// Copyright 2014 Google Inc. All Rights Reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//
// Created by postproc-cld2 4.0 on 2014-02-04 09:02:17
// From command line:
//  --cld2 --cc --opensource --just_read_raw --quad --standard --minchars=2 
//  --mincount=2 --max_items_per_langscript=12000 --flatmap --rr_alloc 
//  --freq_alloc --boostcloseweakerpercent=00 --indirectbits=18 --thresh=240 
//  --v25 --kentries=1024 --tablename=Quad0122 --suppress=bs-Cyrl sr-ME-Latn 
//  sh-Cyrl sh-Latn ce-Cyrl cv-Cyrl    az-Arab az-Cyrl bs-Cyrl kk-Latn 
//  ku-Latn my-Latn ru-Latn tg-Arab tk-Arab ug-Latn za-Hani zzb-Latn 
//  zze-Latn zzh-Latn --remap=xxx-Latn=>ut-Latn tw-Latn=>ak-Latn 
//  nd-Latn=>nr-Latn blu-Latn=>hmn-Latn  --ko_english --force_to_lang_soft 
//  --nosoft_cram2 --nomsidlevel --shapeflatprob --langpriorpercent=10 
//  --skipnuc --noshapeforcetop --noshapeeventop --noshapesteep2 
//  --langcounts --writebin --list_items=120 --max_langs_per_item=3 
//  /hdb1/cld2/probs/p90_raw_quadgrams_2014.utf8 
#include "cld2tablesummary.h"
namespace CLD2 {

// For this build date, looking up 'qpdbmrmxyzptlkuuddlrlrbas' gives ICELANDIC
static const uint32 kQuad0122BuildDate = 20140204;    // yyyymmdd


// Of 1061893 offered items into 1048576 table entries:
// 842536 filled (79%), 4898 merged (0%), 214459 dropped (20%)

// Nil-grams: 19 languages
//     GREEK MALAYALAM TELUGU TAMIL GUJARATI THAI KANNADA PUNJABI 
//     GEORGIAN SINHALESE ARMENIAN LAOTHIAN KHMER DHIVEHI CHEROKEE 
//     SYRIAC LIMBU ORIYA INUKTITUT 

// Uni-grams: 4 languages
//     Japanese Korean Chinese ChineseT 

// Words/Quads: 143 languages in range ENGLISH..X_KLINGON:
//     ENGLISH DANISH DUTCH FINNISH FRENCH GERMAN HEBREW ITALIAN 
//     NORWEGIAN POLISH PORTUGUESE RUSSIAN SPANISH SWEDISH CZECH 
//     ICELANDIC LATVIAN LITHUANIAN ROMANIAN HUNGARIAN ESTONIAN 
//     Unknown BULGARIAN CROATIAN SERBIAN IRISH GALICIAN TAGALOG 
//     TURKISH UKRAINIAN HINDI MACEDONIAN BENGALI INDONESIAN LATIN 
//     MALAY WELSH NEPALI ALBANIAN BELARUSIAN JAVANESE OCCITAN URDU 
//     BIHARI ARABIC CATALAN ESPERANTO BASQUE INTERLINGUA 
//     SCOTS_GAELIC SWAHILI SLOVENIAN MARATHI MALTESE VIETNAMESE 
//     FRISIAN SLOVAK FAROESE SUNDANESE UZBEK AMHARIC AZERBAIJANI 
//     TIGRINYA PERSIAN BOSNIAN NORWEGIAN_N XHOSA ZULU GUARANI 
//     SESOTHO TURKMEN KYRGYZ BRETON YIDDISH SOMALI UIGHUR KURDISH 
//     MONGOLIAN SINDHI RHAETO_ROMANCE AFRIKAANS LUXEMBOURGISH 
//     TIBETAN ASSAMESE CORSICAN INTERLINGUE KAZAKH LINGALA PASHTO 
//     QUECHUA SHONA TAJIK TATAR TONGA YORUBA MAORI WOLOF ABKHAZIAN 
//     AFAR AYMARA BASHKIR BISLAMA DZONGKHA FIJIAN GREENLANDIC HAUSA 
//     HAITIAN_CREOLE INUPIAK KASHMIRI KINYARWANDA MALAGASY NAURU 
//     OROMO RUNDI SAMOAN SANGO SANSKRIT SISWANT TSONGA TSWANA 
//     VOLAPUK ZHUANG KHASI SCOTS GANDA MANX AKAN IGBO 
//     MAURITIAN_CREOLE HAWAIIAN CEBUANO HMONG NYANJA PEDI SESELWA 
//     VENDA WARAY_PHILIPPINES NDEBELE X_PIG_LATIN X_KLINGON 

// TopLanguage  TokenCount
//  ENGLISH 5681
//  DANISH 6791
//  DUTCH 4519
//  FINNISH 8294
//  FRENCH 5204
//  GERMAN 6989
//  HEBREW 8816
//  ITALIAN 1634
//  Japanese 4553
//  Korean 136
//  NORWEGIAN 5433
//  POLISH 8733
//  PORTUGUESE 4461
//  RUSSIAN 8677
//  SPANISH 3008
//  SWEDISH 8227
//  CZECH 14701
//  ICELANDIC 8790
//  LATVIAN 8793
//  LITHUANIAN 8709
//  ROMANIAN 11257
//  HUNGARIAN 8732
//  ESTONIAN 8101
//  Unknown 14021
//  BULGARIAN 8663
//  CROATIAN 4585
//  SERBIAN 12191
//  IRISH 7706
//  GALICIAN 3529
//  TAGALOG 1633
//  TURKISH 8711
//  UKRAINIAN 8685
//  HINDI 14214
//  MACEDONIAN 8723
//  BENGALI 8685
//  INDONESIAN 2759
//  LATIN 4713
//  MALAY 2253
//  WELSH 6895
//  NEPALI 8768
//  ALBANIAN 7660
//  BELARUSIAN 8787
//  JAVANESE 4431
//  OCCITAN 4645
//  URDU 8717
//  BIHARI 9074
//  ARABIC 9023
//  CATALAN 4450
//  ESPERANTO 6594
//  BASQUE 4267
//  INTERLINGUA 612
//  SCOTS_GAELIC 5572
//  SWAHILI 3370
//  SLOVENIAN 5809
//  MARATHI 8775
//  MALTESE 8102
//  VIETNAMESE 7636
//  FRISIAN 4270
//  SLOVAK 8704
//  ChineseT 585
//  FAROESE 8247
//  SUNDANESE 4679
//  UZBEK 21885
//  AMHARIC 8748
//  AZERBAIJANI 8799
//  TIGRINYA 8728
//  PERSIAN 8853
//  BOSNIAN 2628
//  NORWEGIAN_N 4517
//  XHOSA 5240
//  ZULU 2750
//  GUARANI 8147
//  SESOTHO 1622
//  TURKMEN 14775
//  KYRGYZ 17420
//  BRETON 5427
//  YIDDISH 8744
//  SOMALI 5941
//  UIGHUR 14978
//  KURDISH 8764
//  MONGOLIAN 8782
//  SINDHI 8783
//  RHAETO_ROMANCE 3965
//  AFRIKAANS 4856
//  LUXEMBOURGISH 5496
//  TIBETAN 5186
//  ASSAMESE 8713
//  CORSICAN 2969
//  INTERLINGUE 1228
//  KAZAKH 17354
//  LINGALA 1565
//  PASHTO 8755
//  QUECHUA 4818
//  SHONA 3250
//  TAJIK 8640
//  TATAR 17530
//  TONGA 2533
//  YORUBA 8664
//  MAORI 4207
//  WOLOF 5651
//  ABKHAZIAN 8687
//  AFAR 3411
//  AYMARA 1704
//  BASHKIR 8723
//  BISLAMA 822
//  DZONGKHA 754
//  FIJIAN 1490
//  GREENLANDIC 3033
//  HAUSA 2610
//  HAITIAN_CREOLE 5977
//  INUPIAK 939
//  KASHMIRI 7012
//  KINYARWANDA 3236
//  MALAGASY 2985
//  NAURU 2324
//  OROMO 3183
//  RUNDI 1168
//  SAMOAN 2483
//  SANGO 1432
//  SANSKRIT 17558
//  SISWANT 2565
//  TSONGA 1828
//  TSWANA 1066
//  VOLAPUK 2883
//  ZHUANG 2870
//  KHASI 1534
//  SCOTS 2165
//  GANDA 4246
//  MANX 5320
//  AKAN 3082
//  IGBO 3500
//  MAURITIAN_CREOLE 1358
//  HAWAIIAN 1363
//  CEBUANO 1388
//  HMONG 2053
//  NYANJA 2052
//  PEDI 531
//  SESELWA 698
//  VENDA 1125
//  WARAY_PHILIPPINES 1702
//  NDEBELE 138
//  X_PIG_LATIN 6757
//  X_KLINGON 5786



// Recognized language-script combinations [193]:
static const char* const kQuad0122RecognizedLangScripts = 
  "aa-Latn ab-Cyrl af-Latn ak-Latn am-Ethi ar-Arab ar-Beng ar-Cyrl "
  "ar-Deva ar-Hebr ar-Latn as-Beng ay-Latn az-Latn ba-Cyrl be-Cyrl "
  "bg-Cyrl bg-Latn bh-Deva bi-Latn bn-Beng bn-Latn bo-Cyrl bo-Tibt "
  "br-Latn bs-Arab bs-Latn ca-Latn ceb-Latn co-Latn crs-Latn cs-Cyrl "
  "cs-Latn cy-Latn da-Arab da-Latn de-Latn dz-Tibt en-Arab en-Latn "
  "eo-Latn es-Cyrl es-Latn et-Latn eu-Latn fa-Arab fa-Hebr fa-Latn "
  "fi-Latn fj-Latn fo-Latn fr-Arab fr-Cyrl fr-Latn fy-Latn ga-Latn "
  "gd-Latn gl-Latn gn-Latn gv-Latn ha-Latn haw-Latn hi-Arab hi-Deva "
  "hi-Latn hmn-Latn hr-Arab hr-Latn ht-Latn hu-Cyrl hu-Latn ia-Latn "
  "id-Arab id-Latn ie-Latn ig-Latn ik-Latn is-Latn it-Latn iw-Hebr "
  "iw-Latn ja-Arab ja-Cyrl ja-Latn jw-Latn kha-Latn kk-Arab kk-Cyrl "
  "kl-Latn ko-Cyrl ko-Latn ks-Arab ks-Deva ku-Arab ky-Arab ky-Cyrl "
  "la-Latn lb-Latn lg-Latn ln-Latn lt-Latn lv-Latn mfe-Latn mg-Latn "
  "mi-Latn mk-Cyrl mk-Latn mn-Cyrl mn-Latn mr-Deva ms-Latn mt-Latn "
  "na-Latn ne-Deva nl-Latn nn-Latn no-Latn nr-Latn nso-Latn ny-Latn "
  "oc-Arab oc-Latn om-Latn pl-Cyrl pl-Latn ps-Arab pt-Latn qu-Latn "
  "rm-Latn rn-Latn ro-Cyrl ro-Latn ru-Cyrl rw-Latn sa-Deva sa-Latn "
  "sco-Latn sd-Arab sg-Latn sk-Latn sl-Cyrl sl-Latn sm-Latn sn-Latn "
  "so-Latn sq-Cyrl sq-Latn sr-Cyrl sr-Latn ss-Latn st-Latn su-Latn "
  "sv-Cyrl sv-Latn sw-Latn tg-Cyrl ti-Ethi tk-Cyrl tk-Latn tl-Arab "
  "tl-Cyrl tl-Latn tlh-Latn tn-Latn to-Latn tr-Cyrl tr-Latn ts-Latn "
  "tt-Cyrl tt-Latn ug-Arab ug-Cyrl uk-Cyrl uk-Latn un-Cyrl un-Latn "
  "ur-Arab uz-Arab uz-Cyrl uz-Latn ve-Latn vi-Arab vi-Latn vo-Latn "
  "war-Latn wo-Latn xh-Latn yi-Hebr yo-Latn za-Latn zh-Hant-Latn zu-Latn "
  "zzp-Latn ";

static const uint32 kQuad0122Size = 262144;    // Bucket count
static const uint32 kQuad0122KeyMask = 0xfffc0000;    // Mask hash key

static const IndirectProbBucket4 kQuad0122[kQuad0122Size] = {
  // hash_indirect[4], tokens[4] in UTF-8
   {{0x7bc40002,0x58fc0003,0x39580004,0x62880005}},	// [000] rniu, _ཟུངས_, _pbrs_, nxeo, 
   {{0x7bc40006,0x63a80007,0x69c40008,0x27ec0009}},	//   sniu, hhen, gnhe, _ahen_, 
   {{0x6b8c000a,0x52e0000b,0x27ec000c,0xa3c4000d}},	//   bjag, _पर्स, _bhen_, उचा_, 
   {{0x06b4000e,0x69c4000f,0x63a80010,0x81c80011}},	//   _জড়ি, anhe, jhen, লতি_, 
   {{0x63a80012,0x27ec0013,0x13b40014,0x00000000}},	//   dhen, _dhen_, یٖتھ_, --, 
   {{0x6fdc0015,0x24500016,0x99740017,0x63a80018}},	//   léct, _bơm_, _тумш, ehen, 
   {{0x93a40019,0x24500016,0x9484001a,0xd3a4001b}},	//   ишид, _cơm_, рылд, ирип, 
   {{0x6fdc001c,0x63a8001d,0x27ec001e,0xb444001f}},	//   néct, ghen, _ghen_, _የክልሉ, 
   {{0xca440020,0x06040021,0x51840022,0x20a00023}},	//   _ዕይታዎ, _внук_, ауна, _ዝመረጹ_, 
   {{0x68040024,0x63a80025,0x55e40026,0x0f1c0027}},	//   _sėdi, ahen, _тозб, पर्स_, 
   {{0x63a80028,0x75280029,0x6aac002a,0x2474002b}},	//   bhen, _iedz, zzaf, _gām_, 
   {{0x63a8002c,0x7528002d,0x6e3c002e,0x6f1c002f}},	//   chen, _hedz, trsb, ubsc, 
   {{0x75280030,0x6e3c0031,0xd1740032,0x69c40033}},	//   _kedz, ursb, _ҡыҫы, ynhe, 
   {{0x75280034,0x70540035,0x7bc80036,0x41a00037}},	//   _jedz, _هنتا, édun, _ओतएस, 
   {{0x75280038,0x6b8c0039,0x6fdc003a,0x69c4003b}},	//   _medz, tjag, féct, vnhe, 
   {{0x7528003c,0x69c4003d,0x6d400008,0x2fc8003e}},	//   _ledz, wnhe, ólab, _ujag_, 
   {{0x6b8c003f,0x75280040,0x69340041,0x27ec0042}},	// [010] rjag, _oedz, йнау, _rhen_, 
   {{0x27ec0043,0x63a80044,0x75280045,0x7ac40046}},	//   _shen_, zhen, _nedz, істе, 
   {{0x69c40047,0x2b580048,0x27ec0049,0x6fdc004a}},	//   rnhe, _tbsc_, _phen_, sécu, 
   {{0x63a8004b,0x7528004c,0x2450004d,0x4ba4004e}},	//   xhen, _aedz, _rơm_, _төгү_, 
   {{0x7528004f,0xd5ac0050,0x24500051,0x00000000}},	//   _bedz, کہٕ_, _sơm_, --, 
   {{0x27ec0052,0x63a80053,0x7df40054,0x24740055}},	//   _when_, when, _uńst, _pām_, 
   {{0x27ec0056,0x75280057,0x21680058,0x63a80059}},	//   _then_, _dedz, қини_, then, 
   {{0x27ec003e,0x6288005a,0x63a8005b,0x387c005c}},	//   _uhen_, txeo, uhen, ævre_, 
   {{0x63a8005d,0xe298005e,0x6728005f,0x16580060}},	//   rhen, уап_, _ieej, _مسلک_, 
   {{0x24740061,0x21a40062,0x21680063,0x75280064}},	//   _tām_, сиом, ћини_, _gedz, 
   {{0x2a680065,0x66080066,0x66000067,0x5f040068}},	//   hwab_, _huek, _iilk, йзна, 
   {{0x66080069,0x63a4006a,0x6600006b,0xf374006c}},	//   _kuek, êhnd, _hilk, _وطند, 
   {{0x6600006d,0x6728006e,0x7528006f,0x2a68003e}},	//   _kilk, _meej, _yedz, jwab_, 
   {{0x67280070,0x66000071,0x66080072,0x3cf40073}},	//   _leej, _jilk, _muek, ंधले_, 
   {{0x66000074,0x7b840075,0x66080076,0x6fdc0077}},	//   _milk, يارە, _luek, téct, 
   {{0x67280078,0x66000079,0x28bc007a,0x1db80073}},	//   _neej, _lilk, ्पनि, _उगवत, 
   {{0x6d40007b,0x6600007c,0x00000000,0x00000000}},	// [020] ólac, _oilk, --, --, 
   {{0x46d8007d,0x2d980032,0x6600007e,0x75e4007f}},	//   _बड़ह, _көсө_, _nilk, tòzm, 
   {{0x75280080,0x67280081,0xdb040082,0x63b80083}},	//   _redz, _beej, _omkø, _omwn, 
   {{0x75280084,0x2a6c0085,0x2a680086,0x66080087}},	//   _sedz, ́mbɛ_, bwab_, _buek, 
   {{0x66000088,0x67280089,0x7528008a,0x6608008b}},	//   _bilk, _deej, _pedz, _cuek, 
   {{0xdb14008c,0x8e54008d,0x6600008e,0x5d78008f}},	//   ábær, מינג_, _cilk, ראַק, 
   {{0x66000050,0x75280090,0x67280091,0x986c0092}},	//   _dilk, _vedz, _feej, _ባልሆኑ_, 
   {{0x66080093,0x67280094,0x75280095,0x66000096}},	//   _fuek, _geej, _wedz, _eilk, 
   {{0x66080097,0x6fdc0098,0x68040064,0x00000000}},	//   _guek, kécr, _dėdu, --, 
   {{0x41380020,0x75280099,0x6728009a,0x2008009b}},	//   _በአገሪ, _uedz, _zeej, _čair_, 
   {{0x6728009c,0x6608009d,0x81e4009e,0x45f4009f}},	//   _yeej, _zuek, _মূহ_, _افلح_, 
   {{0x7bc800a0,0x660000a1,0x6608009a,0x613400a2}},	//   édul, _zilk, _yuek, _aýlı, 
   {{0x2fd800a3,0x660000a4,0x00000000,0x00000000}},	//   rosg_, _yilk, --, --, 
   {{0x66000050,0xa2c400a5,0x4ea400a6,0x816400a7}},	//   _xilk, ापर्, арҳа, _гръб_, 
   {{0x7c8400a8,0x63b800a9,0x417000aa,0x6fb4007b}},	//   путе, _ymwn, _راوس, _ومتا, 
   {{0x48ec00ab,0x00000000,0x00000000,0x00000000}},	//   _अरबो_, --, --, --, 
   {{0x681400ac,0x672800ad,0xedd400ae,0x00000000}},	// [030] _işdə, _reej, _ويبد, --, 
   {{0x672800af,0x660800b0,0x48a800b1,0x00000000}},	//   _seej, _ruek, лтем_, --, 
   {{0xd24400b2,0xe71800b3,0x672800b4,0x660800b5}},	//   _ڪن_, ليات_, _peej, _suek, 
   {{0xd36400b6,0x932800b7,0x950c00b8,0x00000000}},	//   _غه_, ተንቀሳ, _ākāṃ, --, 
   {{0xd24400b9,0x660000ba,0x672800bb,0xf1c800bc}},	//   _تن_, _pilk, _veej, िचान, 
   {{0xcfcc00bd,0x6728002e,0xe8940023,0xe44800be}},	//   রতিন, _weej, _ዘጸግም_, للتى_, 
   {{0x660000bf,0x6728000d,0x680400c0,0x00000000}},	//   _vilk, _teej, _pėdu, --, 
   {{0xe3b000c1,0x625800c2,0xa2c40073,0x660800c3}},	//   برت_, арор_, ापल्, _tuek, 
   {{0x660000c4,0x660800c5,0x68040064,0x00000000}},	//   _tilk, _uuek, _vėdu, --, 
   {{0x6600002d,0x11d400c6,0x00000000,0x00000000}},	//   _uilk, يوية_, --, --, 
   {{0xdf1400c7,0x00000000,0x00000000,0x00000000}},	//   жьгь, --, --, --, 
   {{0x14d400c8,0x225800c9,0x63b800ca,0x00000000}},	//   _וועל_, _виды_, _umwn, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa0a400cb,0xd9bc00cc,0x5be000cd,0x00000000}},	//   _малд, _অৱনম, पत्व, --, 
   {{0x28d800ce,0xd12c009f,0x00000000,0x00000000}},	//   _बुलि, _شمي_, --, --, 
   {{0xd43c0092,0x00000000,0x00000000,0x00000000}},	//   _አይጠቅ, --, --, --, 
   {{0x5f8000cf,0x00000000,0x00000000,0x00000000}},	// [040] _فۇگە, --, --, --, 
   {{0x999000d0,0x00000000,0x00000000,0x00000000}},	//   kryť_, --, --, --, 
   {{0xe7c800d1,0x00000000,0x00000000,0x00000000}},	//   ﻫﯟﺍﻟ, --, --, --, 
   {{0x6ac400d2,0x00000000,0x00000000,0x00000000}},	//   étfú, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x45b400d3,0x85b400d4,0x00000000,0x00000000}},	//   огію_, оліс_, --, --, 
   {{0xdb0400d5,0x00000000,0x00000000,0x00000000}},	//   _alké, --, --, --, 
   {{0xd32400d6,0xddc400d7,0xd25800d8,0x8c1800d9}},	//   цьки, sukň, ацо_, בוקי, 
   {{0xdcfc00da,0x2c1000c5,0x00000000,0x00000000}},	//   _kopē, _दूनू_, --, --, 
   {{0xd76400db,0x60cc00dc,0x00000000,0x00000000}},	//   _دەچى_, _śama, --, --, 
   {{0xdb0400dd,0xdcfc00de,0x897800df,0xef1000cf}},	//   _elké, _mopē, בריצ, нүйө, 
   {{0x28bc00e0,0x09a400dc,0xb4c800e1,0x649800cf}},	//   ्पति, _गत्य, ैथी_, _утур_, 
   {{0x2308004b,0x00000000,0x00000000,0x00000000}},	//   _اتمي_, --, --, --, 
   {{0xdcfc00e2,0x717400e3,0x24a800e4,0xa11400e5}},	//   _nopē, _رهبا, _ñumí_, _ٹوٹت, 
   {{0xac9400e6,0x2ca400e7,0xdb1400e8,0xac1800e9}},	//   чавш, áld_, fiyà, собу_, 
   {{0x7b8800ea,0x81c800eb,0x00000000,0x00000000}},	//   ољуб_, লতঃ_, --, --, 
   {{0x1ea800ec,0x00000000,0x00000000,0x00000000}},	// [050] _هاٿي_, --, --, --, 
   {{0x3ea400ed,0x0c8400ee,0xdcfc00ef,0xc87800f0}},	//   ømte_, _дымм, _copē, иџе_, 
   {{0xbdf800f1,0xfeb800f2,0x00000000,0x00000000}},	//   _بريا_, _هایت_, --, --, 
   {{0xaa5800f3,0x00000000,0x00000000,0x00000000}},	//   _лиму_, --, --, --, 
   {{0xa9c000f4,0xff7c008f,0x68040024,0x466800f5}},	//   _كۅرۉ, יטאמ, _pėds, ррем_, 
   {{0xdc5400f6,0xe79400f2,0x00000000,0x00000000}},	//   _بریک, _کاسک, --, --, 
   {{0xdb1400d2,0xb50800f7,0x00000000,0x00000000}},	//   liyá, زۉنۅ_, --, --, 
   {{0xd90c00f8,0x00000000,0x00000000,0x00000000}},	//   _لیے_, --, --, --, 
   {{0x970000d1,0x00000000,0x00000000,0x00000000}},	//   _كېمى, --, --, --, 
   {{0xd6c400f9,0x20d400fa,0x00000000,0x00000000}},	//   _عملی, зімс, --, --, 
   {{0x9d4400fb,0x00000000,0x00000000,0x00000000}},	//   үемд, --, --, --, 
   {{0x6d4000fc,0x5f0400fd,0x92b800fe,0x1e9400d8}},	//   ólan, язма, _আঁৰ_, пргр, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdd9000ff,0xddc40083,0x75e40100,0xb0680101}},	//   روز_, mukŋ, tòzi, حصیل_, 
   {{0xa0a40102,0x00000000,0x00000000,0x00000000}},	//   _хайд, --, --, --, 
   {{0x5f740103,0x3c18007f,0x9b080104,0x00000000}},	//   _رابر, _nčve_, снаб_, --, 
   {{0x0b400105,0x00000000,0x00000000,0x00000000}},	// [060] энтн, --, --, --, 
   {{0x7e640106,0xeb980107,0x8e5400df,0x00000000}},	//   _ipip, биӣ_, _צייג_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x87000108,0xe79c000d,0x55e40108,0x00000000}},	//   няше, _तारs, подб, --, 
   {{0x7e640109,0x00000000,0x00000000,0x00000000}},	//   _mpip, --, --, --, 
   {{0x7e64010a,0x3394010b,0x00000000,0x00000000}},	//   _lpip, дайё, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x154400d8,0x00000000,0x00000000,0x00000000}},	//   _неам, --, --, --, 
   {{0xc0f0010c,0x3014010d,0xdddc010e,0x4a98010f}},	//   _ግርም_, мдор, _çyňs, צייג, 
   {{0x7e640110,0xc0540111,0x25a00112,0x00000000}},	//   _apip, пія_, öhle_, --, 
   {{0xdb140113,0x92680114,0x00000000,0x00000000}},	//   yiyá, _грка_, --, --, 
   {{0xc7b000d9,0xc3300115,0x00000000,0x00000000}},	//   תבר_, _נוס_, --, --, 
   {{0xbf140116,0x0dc80117,0x3d180118,0x00000000}},	//   _җүрә, суми_, बुले_, --, 
   {{0x7e640119,0x4158011a,0x00000000,0x00000000}},	//   _epip, _הדוג, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xeb98010b,0x2dd4011b,0x7ac4011c,0x00000000}},	// [070] биң_, _ожир, нсфе, --, 
   {{0xdb14010e,0x00000000,0x00000000,0x00000000}},	//   mnyý, --, --, --, 
   {{0xdd14011d,0xdb14011e,0x9a64001f,0xd1c00092}},	//   _توپخ, siyá, ስተኛው_, _ስኬት_, 
   {{0xdb14011f,0xdc34010f,0xdba00023,0xd9bc00cc}},	//   piyá, _קארט_, _ወለዶም_, _অৱদম, 
   {{0xa5080120,0x25d80121,0x3d14000d,0x00000000}},	//   оела_, омды_, _दलमे_, --, 
   {{0xddd40122,0xf6500123,0xf6d40101,0xe94400f2}},	//   _kryš, طئه_, رزند, _ترحی, 
   {{0x07440124,0x00000000,0x00000000,0x00000000}},	//   _нхам, --, --, --, 
   {{0xc0f00125,0x22140126,0xe3b00127,0x60cc0055}},	//   _ግርማ_, мфор, ضرب_, _śamo, 
   {{0xd24c0128,0x7bc80129,0xd11c0073,0x28bc012a}},	//   لني_, édui, _म्हण_, ्पवि, 
   {{0x6d40012b,0xd24c006c,0x6d1c012c,0xb0c8012d}},	//   ólal, گنی_, _ब्लग_, ाऊंग, 
   {{0x5f4400f1,0x00000000,0x00000000,0x00000000}},	//   وندل, --, --, --, 
   {{0xd24c012e,0xe290012f,0xdd8400e5,0x00000000}},	//   دنی_, _لذت_, ڈجسٹ, --, 
   {{0xe2980130,0xdcb00131,0xc2e80132,0xf1a80133}},	//   _фал_, ھىر_, _اعام_, زایه_, 
   {{0x44c40134,0x4a280135,0xdcb00136,0xd1280137}},	//   _kɑ_, _སྦེལ_, پىر_, _ۇقۇۇ_, 
   {{0x3a200113,0x5fd40138,0x00000000,0x00000000}},	//   wpip_, _оциф, --, --, 
   {{0x44c40134,0x5f4400f1,0x00000000,0x00000000}},	//   _mɑ_, _ځنګل, --, --, 
   {{0x98b00139,0x00000000,0x00000000,0x00000000}},	// [080] _ıbız_, --, --, --, 
   {{0xddd4013a,0x1dd000cd,0x00000000,0x00000000}},	//   _fryš, _सदित, --, --, 
   {{0x44c4013b,0xddc400b0,0x00000000,0x00000000}},	//   _nɑ_, nukō, --, --, 
   {{0x3a20013c,0x07a0013d,0x00000000,0x00000000}},	//   ppip_, кахн, --, --, 
   {{0x9f50003e,0x7bc4013c,0x35c4013e,0x00000000}},	//   _chyé_, miiu, надҳ, --, 
   {{0x44c4013f,0x7bc40140,0x28d80141,0xe7380142}},	//   _bɑ_, liiu, _बुकि, _blŵs_, 
   {{0x5efc00dc,0x799c0143,0x00000000,0x00000000}},	//   रेत्_, _iorw, --, --, 
   {{0x799c0144,0xb2740145,0x28bc0146,0x7bc4003a}},	//   _horw, елиш, ्परि, niiu, 
   {{0x799c0147,0x6f080122,0x31340148,0x00000000}},	//   _korw, žeck, непр, --, 
   {{0x799c0149,0xdb14014a,0xd468014b,0x00000000}},	//   _jorw, liyä, _мизе_, --, 
   {{0x799c014c,0x7bc40093,0x93a8014d,0x6d40014e}},	//   _morw, kiiu, _واصف_, ólam, 
   {{0x799c014f,0xefd00023,0xee200150,0x00000000}},	//   _lorw, ኩምዎ_, лемi_, --, 
   {{0x799c0151,0x41700152,0xdcfc0153,0xeac80154}},	//   _oorw, رایس, _kopė, _শর্ম, 
   {{0x799c0155,0x00000000,0x00000000,0x00000000}},	//   _norw, --, --, --, 
   {{0xe94400e5,0xdb140139,0x00000000,0x00000000}},	//   ہرای, kiyä, --, --, 
   {{0x4a280156,0x53dc0157,0x799c0158,0x7bc40140}},	//   _སྦུལ_, मविश, _aorw, giiu, 
   {{0x799c0159,0x6f0c015a,0xed00015b,0x00000000}},	// [090] _borw, _igac, ্রেস_, --, 
   {{0x6e2c015c,0x7bc40093,0x799c015d,0x88c4015e}},	//   _iwab, aiiu, _corw, وتال, 
   {{0x799c015f,0x6e2c0160,0xa37c0161,0x7bc40162}},	//   _dorw, _hwab, loŵe, biiu, 
   {{0x6e2c0163,0xa6340164,0x44c40165,0xdb140166}},	//   _kwab, енді, _rɑ_, giyä, 
   {{0x6e2c0167,0x799c0168,0x6f0c0169,0x00000000}},	//   _jwab, _forw, _mgac, --, 
   {{0xc864016a,0x44c4016b,0xe298016c,0x6b9c016d}},	//   _отби, _pɑ_, ҷаи_, _hosg, 
   {{0x6e2c016e,0x6b9c016f,0x69c40170,0x316c0171}},	//   _lwab, _kosg, mihe, dedz_, 
   {{0x6f0c0172,0x6e2c0173,0xe298016c,0xdb140174}},	//   _ngac, _owab, заи_, ábør, 
   {{0x6e2c00d2,0x799c0099,0x65600175,0x6b9c0176}},	//   _nwab, _yorw, _tblh, _mosg, 
   {{0x6f0c0177,0x69c40178,0x6b9c0179,0x44c40165}},	//   _agac, nihe, _losg, _tɑ_, 
   {{0x6b9c017a,0x60e8011b,0x00000000,0x00000000}},	//   _oosg, ямом_, --, --, 
   {{0x69c4017b,0x6e2c017c,0x6b9c017d,0x8280017e}},	//   hihe, _bwab, _nosg, _ақид, 
   {{0x69c4017f,0x1d0800cf,0x00000000,0x00000000}},	//   kihe, зеги_, --, --, 
   {{0x236c0180,0x69c40181,0x6f0c0182,0xeac80183}},	//   leej_, jihe, _egac, _শৰ্ম, 
   {{0x30740046,0xae040184,0x6b9c0185,0x6e2c0186}},	//   _ауыс, торҙ, _bosg, _ewab, 
   {{0x63a80187,0x6b9c0188,0x799c0189,0x61e0018a}},	//   nken, _cosg, _sorw, loll, 
   {{0x799c018b,0x63a8018c,0x6e2c018d,0x6b9c00a3}},	// [0a0] _porw, iken, _gwab, _dosg, 
   {{0x61e0018e,0x63a8018f,0x236c0190,0x69c40191}},	//   noll, hken, heej_, gihe, 
   {{0x6b9c0192,0x799c0193,0x7bc40194,0x57440195}},	//   _fosg, _vorw, piiu, енеб, 
   {{0x63a80196,0x69c40197,0x236c0198,0x1bb80199}},	//   jken, aihe, jeej_, _راجع_, 
   {{0x61e0019a,0x63a8019b,0x69c4019c,0x799c019d}},	//   koll, dken, bihe, _torw, 
   {{0x61e0019e,0x69c4019f,0x63a801a0,0x224c01a1}},	//   joll, cihe, eken, duek_, 
   {{0x316c01a2,0x61e001a3,0x63a801a4,0x9f500166}},	//   vedz_, doll, fken, _biyü_, 
   {{0x63a801a5,0x6f0801a6,0x1b0400cc,0x00000000}},	//   gken, žeci, ষুণে_, --, 
   {{0x61e001a7,0x224c0097,0x6d4001a8,0x6f0c01a9}},	//   foll, guek_, ólak, _rgac, 
   {{0x6e2c01aa,0x756400dd,0x6f0c01ab,0x23b00118}},	//   _rwab, _شیعہ_, _sgac, _ráje_, 
   {{0x6e2c01ac,0x316c005f,0x2ee8003e,0x4ac401ad}},	//   _swab, redz_, _syaf_, _रेनव, 
   {{0x9b9400c6,0x63a801ae,0x61e001af,0xb4cc01b0}},	//   _ảήǎ_, cken, aoll, रपी_, 
   {{0x61e001b1,0x69c401b2,0x6e2c01b3,0x6b9c01b4}},	//   boll, yihe, _qwab, _rosg, 
   {{0x61e001b5,0x6b9c01b6,0x28d800bc,0x00000000}},	//   coll, _sosg, _बुझि, --, 
   {{0x6b9c01b7,0x645401b8,0x10080150,0x6f0c01b9}},	//   _posg, _äzit, _ةتتى_, _tgac, 
   {{0x6e2c01ba,0x6f0c01bb,0x69c401b2,0x09b801bc}},	//   _twab, _ugac, wihe, ोच्य, 
   {{0x6e2c01bd,0x6b9c01be,0x61f401bf,0xeb98010b}},	// [0b0] _uwab, _vosg, _æglæ, пиң_, 
   {{0x63a801c0,0x00000000,0x00000000,0x00000000}},	//   zken, --, --, --, 
   {{0x69c401c1,0x63a801c2,0x6b9c01c3,0x224c01c4}},	//   rihe, yken, _tosg, zuek_, 
   {{0x69c401c5,0x38c801c6,0x63a801c7,0xc6d001c4}},	//   sihe, хуун_, xken, лслө, 
   {{0x63a801c8,0x61e001c9,0x224c005a,0x659401ca}},	//   vken, yoll, xuek_, каду, 
   {{0x61e001cb,0x00000000,0x00000000,0x00000000}},	//   xoll, --, --, --, 
   {{0x61e001cc,0x69d40196,0x63a801cd,0xa71401ce}},	//   voll, _ijze, tken, _амбі, 
   {{0x61e001cf,0x224c01c0,0xfa2400cc,0x63a801d0}},	//   woll, tuek_, _পিতল_, uken, 
   {{0x61e001d1,0xe73801d2,0xe1f801b9,0x7d0801d3}},	//   toll, _нең_, мги_, _kérü, 
   {{0x236c01d4,0x224c01c6,0xf7700014,0xd3e401d5}},	//   seej_, ruek_, _پاہ_, _یقلی, 
   {{0x63a801d6,0x224c009d,0x00000000,0x00000000}},	//   pken, suek_, --, --, 
   {{0x61e001d7,0x224c005a,0x00000000,0x00000000}},	//   soll, puek_, --, --, 
   {{0x61e001d8,0x33b00137,0xdb5001d9,0x00000000}},	//   poll, _دەير, یَس_, --, 
   {{0x614401da,0x61e001db,0xdd90009f,0x00000000}},	//   _река, qoll, جوس_, --, 
   {{0xb02401dc,0x1fb401dd,0xdb7800c7,0x00000000}},	//   _trườ, _аспр, мсаш_, --, 
   {{0x1e8401de,0x9f4000d0,0xcb6401df,0xede401e0}},	//   _алим, blká_, касе_, кһөҙ_, 
   {{0xdcfc005f,0x7eb801e1,0xda6401e2,0x00000000}},	// [0c0] _kopī, _dúpé, خازي, --, 
   {{0xdb0401e3,0x00000000,0x00000000,0x00000000}},	//   _omkö, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69d401e4,0x7774001f,0x00000000,0x00000000}},	//   _ejze, _በዝቋላ_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xceb0010f,0xdcfc00ef,0xd94401e5,0xb8d800cc}},	//   סיג_, _nopī, _шеги, _ছশ_, 
   {{0x629c01e6,0x6d4001e7,0x52c800cd,0xd394008e}},	//   äson, ólai, ाप्स, кәдә_, 
   {{0xc7a001e8,0x43800075,0x07a001e9,0xd43c0092}},	//   _киск, للىق, _касн, _አይፈቀ, 
   {{0x07a001ea,0xa66401eb,0xc7a001a9,0x00000000}},	//   _татн, _مطلو, _титк, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3db800eb,0x70540066,0x00000000,0x00000000}},	//   ঁচাল, دنجا, --, --, 
   {{0x75380010,0x12e40150,0x00000000,0x00000000}},	//   lavz, _иілг, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdcfc002b,0x2614012d,0xbb4c01ec,0xc234011a}},	//   _gopī, _फंसी_, _ﺍﻻﻨ_, _ירדו_, 
   {{0xc1f4008f,0x00000000,0x00000000,0x00000000}},	//   _שמוץ_, --, --, --, 
   {{0x7d0801ed,0x6ce40137,0x23b0013a,0x00000000}},	//   _sérü, _ۅزجە, _kája_, --, 
   {{0x395801ee,0x317c0139,0x23b001ef,0x7b1401f0}},	// [0d0] _bcrs_, _kavz_, _jája_, рдух, 
   {{0x23b001f1,0x395800a3,0x700001f2,0x6fe00073}},	//   _mája_, _ccrs_, _ịcha, नववं, 
   {{0x23b00022,0xc7b801d5,0xeff801f3,0x090401f4}},	//   _lája_, мёд_, _ወረድ_, тчам, 
   {{0x6d5401f5,0xe6d4009d,0x6f1c01f6,0x66b40150}},	//   lgza, лцлэ, ncsc, лбеу, 
   {{0x2b5801f7,0x499001ed,0x9de401d9,0x00000000}},	//   _icsc_, _پیار, _شہہٕ_, --, 
   {{0x6d5401f8,0x248401f9,0x2b5801fa,0x273001fb}},	//   ngza, _prlm_, _hcsc_, ạn_, 
   {{0xa3e801fc,0x87d801fd,0x67d401fe,0x00000000}},	//   ндка_, _قبرس_, _бову, --, 
   {{0xe3e801ff,0x9f400200,0x94c801e2,0x00000000}},	//   رکان_, rokë_, عاوې_, --, 
   {{0xd1c00201,0x3d1400bc,0x3878012d,0x00000000}},	//   ስጠት_, _दलले_, _zsrr_, --, 
   {{0x05740202,0x45a00131,0x2bc401f2,0x6738010e}},	//   _جارد, _خەتك, ịcha_, lawj, 
   {{0x9fc80203,0x6e3c002f,0x00000000,0x00000000}},	//   егна_, essb, --, --, 
   {{0x44240204,0xc5f80198,0x2618004d,0x3c180100}},	//   mpn_, ɓɓai_, _kèo_, _sčvo_, 
   {{0xdb040205,0x00000000,0x00000000,0x00000000}},	//   _ilkç, --, --, --, 
   {{0xd00c0206,0x237c0207,0x2618001e,0x5fc400af}},	//   _کلي_, _hawj_, _mèo_, _लगवल, 
   {{0x26180208,0x00000000,0x00000000,0x00000000}},	//   _lèo_, --, --, --, 
   {{0x29100209,0x6d5401a4,0x9f400066,0x7c3c00d8}},	//   _agza_, agza, koké_, rsrr, 
   {{0x1988020a,0x44240175,0x26180208,0x00000000}},	// [0e0] нбаи_, hpn_, _nèo_, --, 
   {{0x237c01d4,0x4424020b,0x9f40020c,0xa78400e5}},	//   _lawj_, kpn_, doké_, یشنو, 
   {{0x180c020d,0x6ee4020e,0x5748020f,0xddc40210}},	//   िदेव_, _مسیل, езем_, pukł, 
   {{0x237c0211,0x29100165,0x261801fb,0xded00023}},	//   _nawj_, _egza_, _bèo_, _ኩሉን_, 
   {{0x9f400066,0x20000010,0x47300212,0x75380010}},	//   goké_, imki_, сніс, tavz, 
   {{0xa5080131,0x00000000,0x00000000,0x00000000}},	//   ھىيە_, --, --, --, 
   {{0xdd300213,0x4424007f,0x38c80214,0x00000000}},	//   zəşt, gpn_, _شاسی_, --, 
   {{0x237c0007,0x7f440215,0x9f400216,0x6e3c0217}},	//   _cawj_, _ndiq, boké_, yssb, 
   {{0x237c0218,0x75380219,0x00000000,0x00000000}},	//   _dawj_, pavz, --, --, 
   {{0x74c4021a,0x1048021b,0x7f44021c,0x4638008f}},	//   _پښتن, нями_, _adiq, _נעבע, 
   {{0x9424021d,0x4424021e,0x6674021f,0x260000bc}},	//   _смее, cpn_, _مدەر, षगरी_, 
   {{0x92b00154,0xae4c0220,0x00000000,0x00000000}},	//   _ঐশী_, _ﺑﻪﺭﯞ_, --, --, 
   {{0x518400d1,0x2618004d,0x6e3c0221,0xcae00027}},	//   _буйа, _xèo_, ussb, _कुंड_, 
   {{0xad240222,0x2a780223,0x7c840224,0x6d5401f5}},	//   شىرى, _rssb_, әуре, ugza, 
   {{0x2ca40225,0x237c0226,0x67380227,0xef100228}},	//   âld_, _yawj_, yawj, _мүнө, 
   {{0x8bb40116,0x06dc0154,0x00000000,0x00000000}},	//   уқму_, বেটি, --, --, 
   {{0xeff80125,0xc9840229,0x68040064,0x00000000}},	// [0f0] _ወረዳ_, лужи, _gėdy, --, 
   {{0x9f40022a,0x00000000,0x00000000,0x00000000}},	//   voké_, --, --, --, 
   {{0x6d44022b,0x7640022c,0x2618007f,0xac9400ee}},	//   _idha, _avmy, _sèo_, _танш, 
   {{0x4424022d,0x9f400066,0x4ae4022e,0x00000000}},	//   vpn_, toké_, _бўга, --, 
   {{0x2c400064,0x00000000,0x00000000,0x00000000}},	//   lėd_, --, --, --, 
   {{0x9f400122,0x237c0097,0x6d44022f,0x44240230}},	//   roké_, _sawj_, _jdha, tpn_, 
   {{0x29040231,0x9f400232,0x6d440233,0x27e80198}},	//   _àla_, soké_, _mdha, ƴan_, 
   {{0x67d40234,0x26180235,0xd3440236,0x00000000}},	//   _тобу, _tèo_, لیمه_, --, 
   {{0x6d440237,0x44240109,0x602000ef,0x00000000}},	//   _odha, spn_, _mēme, --, 
   {{0x6d440238,0x44240239,0x1304023a,0x2114023b}},	//   _ndha, ppn_, шный_, шфиё, 
   {{0x237c0070,0x68040024,0x3d1c01e1,0x66e401ee}},	//   _tawj_, _sėdy, _làwó_, _соҡа, 
   {{0x6d44023c,0x6440023d,0xe7b4023e,0x00000000}},	//   _adha, _ivli, ंसिप, --, 
   {{0xdea0023f,0x2000009b,0x7f440240,0xd1e80092}},	//   زیدی, rmki_, _vdiq, መሮች_, 
   {{0x6d4400b8,0x23b00241,0x224c0242,0x5bac0243}},	//   _cdha, _kájo_, mrek_, घस्व, 
   {{0x6d44002b,0xe0600244,0x00000000,0x00000000}},	//   _ddha, _بێجی, --, --, 
   {{0x6d440245,0x23b001e1,0xf9a40023,0x224c0210}},	//   _edha, _májo_, _ወከፎም_, orek_, 
   {{0x19c40246,0x9d44010b,0x224c0247,0x23b00248}},	// [100] абам, _кепд, nrek_, _lájo_, 
   {{0xd9440249,0x3d1c01e1,0x6440012c,0x6d4001a8}},	//   режи, _dàwó_, _ovli, ólat, 
   {{0xa3e4024a,0x3f80024b,0x1b48024c,0x9f040133}},	//   पका_, _kaiu_, _изни_, _حوکو, 
   {{0xd628024d,0xad24024e,0x06dc0154,0x00000000}},	//   воде_, _پریو, বেছি, --, 
   {{0x3f80024f,0x64400250,0x99740251,0x6d400252}},	//   _maiu_, _avli, _кувш, ðlag, 
   {{0x224c0253,0x3f800254,0x00000000,0x00000000}},	//   drek_, _laiu_, --, --, 
   {{0x224c0255,0xdcec007f,0x98a40256,0x39380257}},	//   erek_, kebč, _тиве, ዮናውያ, 
   {{0x224c0258,0xb17c01e4,0x3d1c0241,0x98500133}},	//   frek_, toĥo, _yàwó_, _هێڕش, 
   {{0x64400259,0x9f40025a,0x224c025b,0x672c00c7}},	//   _evli, tokî_, grek_, ñaje, 
   {{0xd5a800af,0xb17c0115,0xdd18025c,0x00000000}},	//   _कविज, roĥo, għżi, --, 
   {{0x09f4025d,0x6d4400cd,0x224c025e,0x22500210}},	//   שמים_, _rdha, arek_, ązka_, 
   {{0xc474025f,0x224c0260,0x3f800261,0x4fc40262}},	//   _כתבו_, brek_, _caiu_, рсоа, 
   {{0x6d440263,0x224c0264,0x80c40154,0x00000000}},	//   _pdha, crek_, _রুদ্, --, 
   {{0x60200265,0x0dc80266,0x705801b9,0x3ea40267}},	//   _sēme, туми_, _бакр_, ämta_, 
   {{0x3f800268,0x8bc40269,0xab94026a,0x7c84026b}},	//   _faiu_, асад, бављ, оуте, 
   {{0x3f80026c,0x21f800e4,0x00000000,0x00000000}},	//   _gaiu_, mèha_, --, --, 
   {{0x2fc8026d,0x6d40008c,0xba7400db,0x21f8020c}},	// [110] _imag_, ólas, ياكت, lèha_, 
   {{0x6d44026e,0x48a8026f,0xbd6c0023,0x6d400162}},	//   _udha, ктем_, _ድሌቶም_, ðlad, 
   {{0x2d800270,0xb440010a,0x2ed80154,0xec140271}},	//   _iahe_, _доiи, _সরিষ, _دوجد, 
   {{0xd3640272,0x2d800273,0xc60c00dc,0x224c0274}},	//   _عه_, _hahe_, ाद्य_, yrek_, 
   {{0x2d800275,0x6440026c,0xb644013d,0x00000000}},	//   _kahe_, _svli, _şürä, --, 
   {{0x2fc801a9,0x6aac0083,0x69340276,0x224c0277}},	//   _lmag_, myaf, _ынгу, vrek_, 
   {{0x2d800278,0x23b001d3,0x6aac01d3,0x00000000}},	//   _mahe_, _fájl_, lyaf, --, 
   {{0x86b0005e,0x224c0279,0x2d8000af,0xe3b0027a}},	//   _мәлі, trek_, _lahe_, ثرت_, 
   {{0x6aac027b,0x27ec027c,0xc568027d,0x224c027e}},	//   nyaf, _iken_, _لحال_, urek_, 
   {{0x224c027f,0x2fc80280,0x3f800281,0x2d800282}},	//   rrek_, _amag_, _saiu_, _nahe_, 
   {{0x60080283,0x27ec017a,0x25a401ab,0x224c003e}},	//   лном_, _kken_, _ioll_, srek_, 
   {{0x1fb40284,0x25a40285,0x2fc80286,0x224c0287}},	//   ссор, _holl_, _cmag_, prek_, 
   {{0x21680288,0x25a40289,0x4ac4028a,0x2d80028b}},	//   _били_, _koll_, _रेलव, _bahe_, 
   {{0x3f80028c,0x2fc80276,0x6aac0099,0x25a400ef}},	//   _waiu_, _emag_, dyaf, _joll_, 
   {{0x27ec028d,0x2d800198,0x6054028e,0x00000000}},	//   _oken_, _dahe_, _انعط, --, 
   {{0x25a4028f,0x6d400252,0x3f8000d8,0x69d80036}},	//   _loll_, ólar, _uaiu_, éwen, 
   {{0x6aac016b,0x1dd8007b,0x2b380276,0x00000000}},	// [120] gyaf, _مبدع_, рясэ_, --, 
   {{0x2d800290,0x25a40291,0x27ec0292,0x20100293}},	//   _gahe_, _noll_, _aken_, _hiyi_, 
   {{0x20100294,0xddd40006,0x1834007b,0x00000000}},	//   _kiyi_, _kryž, صراح, --, 
   {{0x27ec0295,0x9f400296,0x6aac0297,0x2010002e}},	//   _cken_, kokí_, byaf, _jiyi_, 
   {{0x95c80298,0x6aac0230,0x25a40299,0x75e4026c}},	//   лука_, cyaf, _boll_, mòzz, 
   {{0x27ec029a,0x2010029b,0x9474029c,0x4e78010f}},	//   _eken_, _liyi_, مدعا, טאנצ, 
   {{0x9484026f,0x25a4029d,0xf484029e,0x00000000}},	//   сылд, _doll_, تاشی, --, 
   {{0x2ca4022c,0x2914029f,0xe81c02a0,0x201002a1}},	//   øldi_, ğdaş_, _बंता_, _niyi_, 
   {{0x1a9800c8,0x25a402a2,0x518402a3,0x1544010b}},	//   ריִע, _foll_, буна, _гезм, 
   {{0x25a402a4,0x2fc802a5,0x20100295,0x00000000}},	//   _goll_, _smag_, _aiyi_, --, 
   {{0x201000ca,0x2ed000dc,0x00000000,0x00000000}},	//   _biyi_, सप्त, --, --, 
   {{0x06dc02a6,0x25a402a7,0x6aac02a8,0x03a002a9}},	//   _বৃটি, _zoll_, yyaf, _нихо, 
   {{0x2d8002aa,0xa3e402ab,0xddd40153,0x91e40117}},	//   _pahe_, पकर_, _dryž, _лоде, 
   {{0x25a402ac,0x00000000,0x00000000,0x00000000}},	//   _xoll_, --, --, --, 
   {{0x2d8002ad,0xe81c00e1,0x2d18012d,0x4bd800f2}},	//   _vahe_, _बंधा_, _दलील_, هبرد_, 
   {{0x2fc802ae,0x6d400008,0x2d8000f2,0xb004002b}},	//   _umag_, ðlab, _wahe_, _kuḍy, 
   {{0x0dc802af,0x2d8002b0,0xaa580063,0xe94401b9}},	// [130] _буни_, _tahe_, ризу_, قرای, 
   {{0x602002b1,0x201002b2,0xe81c02ab,0x27ec02b3}},	//   _hēma, _ziyi_, _बंदा_, _sken_, 
   {{0x6aac02b4,0x602002b5,0x201002b6,0x25a402b7}},	//   syaf, _kēma, _yiyi_, _roll_, 
   {{0x25a402b8,0x201002b9,0x9f400022,0xaa9402ba}},	//   _soll_, _xiyi_, mokã_, _димч, 
   {{0xe5a402bb,0x25a402bc,0x60200171,0x00000000}},	//   жили, _poll_, _mēma, --, 
   {{0x3c1802bd,0x00000000,0x00000000,0x00000000}},	//   _sčvi_, --, --, --, 
   {{0x25a402be,0x8728022e,0x00000000,0x00000000}},	//   _voll_, _бўза_, --, --, 
   {{0x27ec02bf,0xe79402c0,0x25a402c1,0x661c020c}},	//   _uken_, _باسک, _woll_, _ésko, 
   {{0x7d000241,0x25a402c2,0xe81c02c3,0x00000000}},	//   _kárí, _toll_, _बूता_, --, 
   {{0xd5840272,0x201002c4,0xa5f802c5,0x00000000}},	//   _وێنه_, _siyi_, _тезу_, --, 
   {{0xa06802c6,0x201002c7,0x349402c8,0x6aa80129}},	//   шана_, _piyi_, _нафр, _àeff, 
   {{0x7d000241,0x229402c9,0x00000000,0x00000000}},	//   _lárí, _ولاس, --, --, 
   {{0x614402ca,0x712401b9,0x23b000e5,0x828402cb}},	//   _дела, غریل, _lájk_, _دجال, 
   {{0x6d4002cc,0x00000000,0x00000000,0x00000000}},	//   ólap, --, --, --, 
   {{0x1d0802cd,0x201002ce,0x628802cf,0x00000000}},	//   реви_, _tiyi_, lveo, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7d000241,0x660002d0,0x00000000,0x00000000}},	// [140] _bárí, _ohlk, --, --, 
   {{0x7e6402d1,0x63b80042,0x7cf402d2,0x00000000}},	//   _iqip, _llwn, gþrú, --, 
   {{0xdb0402d3,0x3e6402d4,0x2d9402d5,0xdcfc0064}},	//   _kokë, löt_, _хрыс, _kapč, 
   {{0x62880254,0x00000000,0x00000000,0x00000000}},	//   kveo, --, --, --, 
   {{0x1828006c,0x3e6402d6,0x672c0054,0x75f4022e}},	//   اقچی_, nöt_, ñaja, _bоzо, 
   {{0xdcfc007f,0xd1c0001f,0xd4f001c6,0x85000133}},	//   _lapč, ድበት_, мжлө, ژوون, 
   {{0xa3e400cd,0x00000000,0x00000000,0x00000000}},	//   पकं_, --, --, --, 
   {{0x938802d7,0xdb040036,0x3e6402d8,0x8c18011a}},	//   рска_, _nokë, köt_, סופי, 
   {{0x602002b1,0x6288000f,0x00000000,0x00000000}},	//   _rēma, gveo, --, --, 
   {{0x506402d9,0x7174007b,0x11d402da,0x00000000}},	//   отма, أهدا, تتعد, --, 
   {{0x7e640194,0xdb040200,0xab300139,0x1c1402db}},	//   _aqip, _bokë, _uñçı_, _दंगल_, 
   {{0x4fc402dc,0xe2a80014,0xd99c02dd,0x3e6401a8}},	//   існа, _گامن_, _ﺍﻷﺴﺩ_, föt_, 
   {{0x8d7402de,0xdcfc02df,0x776002e0,0x9f4c01d3}},	//   ياسا, _dapč, _mcmx, ónál_, 
   {{0xe2a802e1,0x75e402e2,0x00000000,0x00000000}},	//   _دامن_, tòzy, --, --, 
   {{0x6020005f,0x3b2802e3,0x0ba4014b,0xd66c0150}},	//   _tēma, _ọyị_, ошам, _ﺴﻔﻴﺭ_, 
   {{0xc05002e4,0x35cc02e5,0x00000000,0x00000000}},	//   _חזק_, ़फड़, --, --, 
   {{0x9a940201,0x7ac402e6,0xdb2402e7,0xaa5402e8}},	// [150] _መካከል_, мсфе, سولی, яваш, 
   {{0x49b802e9,0x9f4000e4,0xf7700133,0x00000000}},	//   جارد_, pokã_, ێان_, --, 
   {{0x9f4002ea,0xe71802eb,0xdb14007f,0x00000000}},	//   loká_, ميات_, riyò, --, 
   {{0x5c78008f,0x6b7402ec,0x628802ed,0x7af80162}},	//   _פארה, _элму, yveo, ðatæ, 
   {{0xa5f802ee,0xf77002ef,0x00000000,0x00000000}},	//   беду_, ئام_, --, --, 
   {{0x75f4022e,0x00000000,0x00000000,0x00000000}},	//   _qоzо, --, --, --, 
   {{0x23b002f0,0xe3b0007b,0x00000000,0x00000000}},	//   _háji_, فرة_, --, --, 
   {{0x58000131,0x3e64023a,0x33f402f1,0x625801d5}},	//   _كۈلك, yöt_, мчыс, брор_, 
   {{0xdb04020c,0xdcfc0100,0xf3c802f2,0x68f401ef}},	//   _cokè, _rapč, تبوه_, _hyzd, 
   {{0x23b000d0,0x31240137,0x62880254,0x7abc011a}},	//   _máji_, үдөг, rveo, יצחו, 
   {{0x602402f3,0xf1a8027d,0xdef40023,0x00000000}},	//   ядна, تايه_, ሉውን_, --, 
   {{0xdee402f4,0x1ae402f5,0x3e6402f6,0xd00c0133}},	//   зоми, পেয়া, töt_, ێلی_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3e6402f7,0x00000000,0x00000000,0x00000000}},	//   röt_, --, --, --, 
   {{0x9f9002f8,0xdb0402d3,0x3e6402f9,0x00000000}},	//   lší_, _tokë, söt_, --, 
   {{0x656002fa,0x9f4002fb,0x3e6402fc,0xab6400de}},	//   _lclh, boká_, pöt_, _neļā, 
   {{0x9f9002fd,0x2bac02fe,0x99740108,0x00000000}},	// [160] nší_, _टकरा, зуеш, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xad240131,0x985402ff,0x9f900030,0x779400f2}},	//   _تىپى, яташ, hší_, ویسا, 
   {{0xdb040098,0xab6400ef,0x9f9000d7,0x00000000}},	//   _loké, _ceļā, kší_, --, 
   {{0x9f900300,0x656c0301,0x0b40010b,0xb17c01e4}},	//   jší_, đahn, _янян, soĥi, 
   {{0x8af80302,0x9f9002fd,0xbbdc0303,0x00000000}},	//   _להכי, dší_, _यदुक, --, 
   {{0x68f4010b,0x00000000,0x00000000,0x00000000}},	//   _gyzd, --, --, --, 
   {{0xdb04011c,0xc8d8011a,0x97c40304,0x440000db}},	//   _pokè, _הקלט, _эйбе, нчыб, 
   {{0xe890001f,0xd0440213,0x31340305,0x51840114}},	//   _የሚሰጡ_, əmək, мепр, пуна, 
   {{0xdb040098,0x9f400306,0x00000000,0x00000000}},	//   _coké, voká_, --, --, 
   {{0x26140307,0x60200171,0x00000000,0x00000000}},	//   _फूटी_, _dēmo, --, --, 
   {{0x57d80034,0x9f900308,0x212401ab,0x76440309}},	//   _भदोह, bší_, aclh_, šiyu, 
   {{0xc20401b9,0xc7b0011a,0x7188024c,0x00000000}},	//   تقین_, גבר_, _мадҳ_, --, 
   {{0x9f400122,0x8d84010b,0x23b00118,0x00000000}},	//   roká_, чумд, _ráji_, --, 
   {{0x9f400232,0x00000000,0x00000000,0x00000000}},	//   soká_, --, --, --, 
   {{0xdb04030a,0x2d840010,0xe8780014,0x00000000}},	//   _zoké, žle_, ۪ماغ_, --, 
   {{0xdcf000da,0xfe70030b,0xad84030c,0x6a14030d}},	// [170] īgāk, _یدی_, _قادۇ, дмау, 
   {{0x6e2c030e,0xc0d0001f,0xfe240124,0x8b64030f}},	//   _itab, _ያጋሩ_, _џьын, _کادم, 
   {{0x6e2c003e,0x9f900118,0x672c0022,0x00000000}},	//   _htab, zší_, ñajo, --, 
   {{0x68f40122,0x9f900118,0xaa5c01ec,0x00000000}},	//   _vyzd, yší_, _кемi, --, 
   {{0xd2440310,0x6e280311,0xc6680312,0xe81c01ad}},	//   _جن_, _îmbă, сшее_, _बूरा_, 
   {{0x9f900313,0x68f401f1,0x6e2c01f7,0xd90c004b}},	//   vší_, _tyzd, _mtab, ایې_, 
   {{0x24080314,0xdb04003e,0x2a680315,0xdcfc00cd}},	//   онки_, _roké, ltab_, _kapā, 
   {{0x9f900316,0x6e2c0317,0xdcfc0318,0x46f000db}},	//   tší_, _otab, _japā, _كۋار, 
   {{0x6e2c0319,0x2a68031a,0xd764031b,0x6728031c}},	//   _ntab, ntab_, _تنقی, _ifej, 
   {{0x9f90031d,0xdcfc00e2,0xd24c006c,0x00000000}},	//   rší_, _lapā, شچه_, --, 
   {{0x2a68031e,0x60e80108,0x00000000,0x00000000}},	//   htab_, юмом_, --, --, 
   {{0x9f90031f,0x2a680320,0x6728031c,0x6d400321}},	//   pší_, ktab_, _jfej, ðlan, 
   {{0x6e2c01ab,0xfe780322,0xc61c0154,0x93600022}},	//   _ctab, чүп_, নীরা_, _рҭыҧ, 
   {{0xfd640323,0x6e2c00c6,0x2a680324,0x00000000}},	//   энгү, _dtab, dtab_, --, 
   {{0x98b80325,0x9b940326,0x00000000,0x00000000}},	//   kapā_, ولست, --, --, 
   {{0x67280327,0x7e640124,0xdb1c0139,0x00000000}},	//   _nfej, _зеиҧ, _äyüp, --, 
   {{0xdcfc0055,0x6e2c00a2,0x98b80055,0x00000000}},	// [180] _dapā, _gtab, dapā_, --, 
   {{0x8d740328,0xdb0400fd,0x00000000,0x00000000}},	//   _قاپا, _ilkü, --, --, 
   {{0x2d8c013f,0x2a6800c5,0xfa8c001f,0x1d080329}},	//   ɛee_, atab_, _መካኒክ_, _фени_, 
   {{0x2a68032a,0x00000000,0x00000000,0x00000000}},	//   btab_, --, --, --, 
   {{0x4cd000bd,0x473002bf,0x2fd8032b,0x6e2c01a9}},	//   _দুপু, тніс, érgi_, _xtab, 
   {{0x672800ef,0x23b000d7,0x38c800f2,0x00000000}},	//   _efej, _máju_, _فازی_, --, 
   {{0x644c005f,0xdcfc0055,0x00000000,0x00000000}},	//   ņain, _yapā, --, --, 
   {{0x4338001f,0x12c40150,0x00000000,0x00000000}},	//   _በኢየሩ, _ﺨﻁﻭﺭ, --, --, 
   {{0xe7bc032c,0x2128032d,0x00000000,0x00000000}},	//   ्फरप, _şaha_, --, --, 
   {{0x6e2c0327,0xa6e0032e,0xa114032f,0x00000000}},	//   _rtab, _óðag, کوپت, --, 
   {{0x200002b1,0x82300330,0x934400d8,0x00000000}},	//   _ūhia_, _یروا, _жнее, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6444000a,0xdde00331,0xc330011a,0x2a680332}},	//   šhit, _šušk, _סוס_, xtab_, 
   {{0x6e2c0333,0x2a680334,0xdcfc002b,0x00000000}},	//   _vtab, vtab_, _sapā, --, 
   {{0xdb0400dd,0xdb14007f,0xdcfc0335,0x00000000}},	//   _elkü, lkyè, _papā, --, 
   {{0x2a680336,0x6e2c0337,0xdd980107,0xcf240338}},	//   ttab_, _ttab, ошӣ_, _غربي, 
   {{0x6e2c0339,0x8e38007b,0x6934033a,0xdb14033b}},	// [190] _utab, _بسعر_, ензу, nkyè, 
   {{0x2a68033c,0x3df4023a,0x98b802b1,0x67280327}},	//   rtab_, _изыс, wapā_, _sfej, 
   {{0x2a68033d,0x98b8033e,0x2250033f,0xdcfc0340}},	//   stab_, tapā_, ązki_, _tapā, 
   {{0x2a680341,0x3ec40342,0x3774013d,0x00000000}},	//   ptab_, _örtü_, вышс, --, 
   {{0x2a680343,0xc79001e0,0x00000000,0x00000000}},	//   qtab_, ерҙы, --, --, 
   {{0xb5c80344,0xdb4c01d9,0xf6500345,0x00000000}},	//   وونم_, _پێے_, شئه_, --, 
   {{0x98b802b5,0x6728031c,0x39140117,0x00000000}},	//   papā_, _tfej, _амрр, --, 
   {{0xf804013d,0x78b80158,0x672801bf,0xe3b00346}},	//   _ачун, øvve, _ufej, طرب_, 
   {{0xd24c0347,0xe7380348,0xd76401b9,0x4cd00349}},	//   مني_, _мең_, _سنلی, _দুমু, 
   {{0x85b800cf,0x1300034a,0xd1c4034b,0x11e002dd}},	//   _بارس_, ызым, елье_, лжым, 
   {{0x21f8034c,0x00000000,0x00000000,0x00000000}},	//   nèhi_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf1a8034d,0xb17c01e4,0x33b000d1,0x00000000}},	//   سایه_, toĥt, _خەير, --, 
   {{0xd24c034e,0x6fdc00e4,0x00000000,0x00000000}},	//   _انو_, hĩch, --, --, 
   {{0xa07400ee,0x23b000e5,0x00000000,0x00000000}},	//   _чылш, _fájt_, --, --, 
   {{0xefe0001f,0x00000000,0x00000000,0x00000000}},	//   ነችው_, --, --, --, 
   {{0xdb04033b,0x1a04034f,0x00000000,0x00000000}},	// [1a0] _alkò, епам, --, --, 
   {{0xdcfc0276,0x99840350,0xd8240351,0x4f040352}},	//   _capă, علاو, еджи, _янын_, 
   {{0x9f4000e4,0x0d38011a,0x00000000,0x00000000}},	//   pokä_, _מגיב, --, --, 
   {{0x627801e4,0xd7080353,0x9a9c0354,0x00000000}},	//   rʈoj, пнее_, _лугi, --, 
   {{0x2b140354,0x00000000,0x00000000,0x00000000}},	//   _аьрр, --, --, --, 
   {{0xa5c00022,0x00000000,0x00000000,0x00000000}},	//   аҩуе, --, --, --, 
   {{0x09e00355,0x799c02d0,0x00000000,0x00000000}},	//   _сорн, _inrw, --, --, 
   {{0x7bc401f4,0x2ca40254,0x00000000,0x00000000}},	//   nhiu, äldi_, --, --, 
   {{0xc3e001e2,0x629c0108,0x00000000,0x00000000}},	//   دګلو, äsop, --, --, 
   {{0x98b80356,0x461000f2,0x00000000,0x00000000}},	//   capă_, _موقر, --, --, 
   {{0x6444000a,0x7bc40357,0xdb10008c,0xc1b401c0}},	//   šhir, khiu, _ágæt, хлэх_, 
   {{0xe3b00014,0xd2440166,0x00000000,0x00000000}},	//   _پرٔ_, _зэки, --, --, 
   {{0x7bc40066,0x82b00214,0x80a000cf,0x00000000}},	//   dhiu, _محوط, _ەمىن, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb3a40358,0x00000000,0x00000000,0x00000000}},	//   _खचाख, --, --, --, 
   {{0x7bc40359,0x799c035a,0x7b640276,0xdb0c01e1}},	//   ghiu, _anrw, лтуе, _ńjáj, 
   {{0xdbcc035b,0x8880035c,0x21f800f2,0x00000000}},	// [1b0] _añón, گیزن, wèhi_, --, 
   {{0x7bc40270,0x00000000,0x00000000,0x00000000}},	//   ahiu, --, --, --, 
   {{0x799c02d0,0xbdf8035d,0x00000000,0x00000000}},	//   _dnrw, _ثريا_, --, --, 
   {{0x7bc4035e,0x21f8020c,0x57b0035f,0xeb04004e}},	//   chiu, rèhi_, ғбәт, _үпүп, 
   {{0x6b9c0360,0x6b8c0361,0xdbcc0022,0x21f800f2}},	//   _insg, mdag, _eñón, sèhi_, 
   {{0x6b8c0362,0x2484003e,0xfa780023,0x00000000}},	//   ldag, _pslm_, _ካላኣይ_, --, 
   {{0x6b8c0363,0x765c00b8,0x00000000,0x00000000}},	//   odag, _ārye, --, --, 
   {{0xe2980364,0xe65c0365,0xc6a4014b,0x00000000}},	//   даи_, ştığ, _прзи, --, 
   {{0x6b8c0366,0x24840367,0x27fc0042,0x00000000}},	//   idag, _wslm_, mlwn_, --, 
   {{0x27fc0368,0x69c40369,0x6b8c036a,0x9e7c0023}},	//   llwn_, nhhe, hdag, _ዕላማና_, 
   {{0x602002b5,0x6b8c036b,0x6e28010f,0x00000000}},	//   _kēmi, kdag, ŭebl, --, 
   {{0x6b8c036c,0xc3c8036d,0x7bc4036e,0x00000000}},	//   jdag, _عظام_, xhiu, --, 
   {{0x63a8036f,0x6b8c0370,0x93b4025f,0x21680371}},	//   mjen, ddag, _שלנו_, _жили_, 
   {{0x1d080372,0x6b8c0373,0x7bc40374,0xd2540375}},	//   деги_, edag, whiu, _ישנה_, 
   {{0x7bc40376,0x22500034,0x63a80377,0x6b8c0378}},	//   thiu, ązku_, ojen, fdag, 
   {{0x63a80379,0x6b8c037a,0xa00800c6,0x00000000}},	//   njen, gdag, _تقبل_, --, 
   {{0x4b2000d6,0xd00c037b,0x65bc00f2,0x1988037c}},	// [1c0] рмув, _بلي_, _rèhn, мбаи_, 
   {{0x63a8037d,0x7f440369,0x7bc4037e,0x38780109}},	//   hjen, _heiq, shiu, _pprr_, 
   {{0x63a8037f,0x6b8c0380,0x7bc40381,0x00000000}},	//   kjen, bdag, phiu, --, 
   {{0x7bc40357,0x63a80382,0x99800383,0x6b8c0076}},	//   qhiu, jjen, _kukū_, cdag, 
   {{0x63a80384,0xcf90008f,0x7f44003a,0x2b5c033f}},	//   djen, יטא_, _meiq, ówce_, 
   {{0x69c40385,0x986401ed,0x589401e0,0x63a80386}},	//   chhe, _لیئے_, _ишбу, ejen, 
   {{0x94840387,0x63a80388,0x53e40022,0xa614035b}},	//   тылд, fjen, кциа, ызшә, 
   {{0x63a80389,0x66040184,0x61e0038a,0x00000000}},	//   gjen, _ҡотҡ, enll, --, 
   {{0x8260038b,0x721801a9,0x9f40038c,0x00000000}},	//   لهين, нжир_, bokú_, --, 
   {{0x6b8c038d,0xa3f4038e,0xdcfc0030,0xd54801d5}},	//   zdag, ější_, _dopĺ, _آلاو_, 
   {{0x63a8038f,0x6b8c0390,0x30140391,0xe3b001d9}},	//   bjen, ydag, лдор, _گرٕ_, 
   {{0x7f440007,0x63a80392,0x69c40165,0x6b8c0169}},	//   _ceiq, cjen, zhhe, xdag, 
   {{0x7f440393,0xe3b001d9,0x6b8c0394,0x81400116}},	//   _deiq, _درٕ_, vdag, اھۇم, 
   {{0x3df40395,0x225800d7,0x00000000,0x00000000}},	//   изяс, áske_, --, --, 
   {{0x6b8c0396,0x80a00397,0x76400211,0x4fc40398}},	//   tdag, _نمون, _lwmy, _аспа, 
   {{0x7f440399,0x321c039a,0x8e24039b,0x6b8c039c}},	//   _geiq, _hivy_, _ифод, udag, 
   {{0x321c0170,0x69c4039d,0xc984039e,0x00000000}},	// [1d0] _kivy_, thhe, кужи, --, 
   {{0x6b8c039f,0x602003a0,0x69c40369,0x2fd800a3}},	//   sdag, _sēmi, uhhe, lisg_, 
   {{0x6b8c03a1,0x660c03a2,0xdb040022,0x2fd801ab}},	//   pdag, ïakm, _pokã, oisg_, 
   {{0x6b8c01b9,0x69c40023,0xe114008f,0x2fd801ab}},	//   qdag, shhe, אַנז_, nisg_, 
   {{0x6d4403a3,0x63a803a4,0x61e00368,0x76400042}},	//   _keha, vjen, ynll, _cwmy, 
   {{0x6d4403a5,0xa50803a6,0x2b4801d9,0x321c03a7}},	//   _jeha, нела_, laac_, _nivy_, 
   {{0x63a803a8,0x6d4403a9,0x69d40327,0x9f4000d0}},	//   tjen, _meha, _imze, rokú_, 
   {{0x6d4403aa,0x9f400030,0x63a8030a,0x638401c6}},	//   _leha, sokú_, ujen, угиа, 
   {{0x63a803ab,0x7f440393,0x6d4403ac,0x442401ab}},	//   rjen, _reiq, _oeha, sqn_, 
   {{0x6d4403ad,0x004403ae,0x7f440097,0xc50803af}},	//   _neha, نیتي_, _seiq, _قتال_, 
   {{0x046403b0,0x63a8031c,0x321c02f0,0x61e00042}},	//   _штам, pjen, _divy_, rnll, 
   {{0xdb0403b1,0x6440014f,0x321c03b2,0x1ec8008e}},	//   _loká, _iwli, _eivy_, елми_, 
   {{0x6d4403b3,0x7f4403b4,0x69d403b5,0xfb8403b6}},	//   _beha, _veiq, _omze, یدری, 
   {{0x614403b7,0x6d4403b8,0x7dd403b9,0xbbbc03ba}},	//   _сека, _ceha, _küsə, ईस्क, 
   {{0x6d4403bb,0x224c03bc,0x2b480014,0x2fd800e8}},	//   _deha, lsek_, faac_, bisg_, 
   {{0x69d403bd,0x7dd403be,0x6d4403bf,0x1f640262}},	//   _amze, _müsə, _eeha, _ским, 
   {{0x224c03c0,0x6d4403c1,0xc0dc0092,0x9b0403c2}},	// [1e0] nsek_, _feha, ነውም_, узад, 
   {{0x6d4403c3,0x644003c4,0x5fb80073,0x98a403c5}},	//   _geha, _owli, _उकडल, лизе, 
   {{0xdb0403c6,0x9f0403c7,0x00000000,0x00000000}},	//   _doká, _جوکو, --, --, 
   {{0x6d440323,0x224c0365,0x69d40221,0x2b480009}},	//   _zeha, ksek_, _emze, caac_, 
   {{0x6d4403c8,0x644003c9,0x224c03ca,0x00000000}},	//   _yeha, _awli, jsek_, --, 
   {{0xf484004b,0x6d4401c4,0x644003cb,0x257003cc}},	//   لابی, _xeha, _bwli, يۇقس, 
   {{0x321c007f,0x629c03cd,0x2ee003ce,0xd32403cf}},	//   _rivy_, åson, _पख्त, льпи, 
   {{0x325403d0,0x321c03d1,0x43800131,0xd46800fd}},	//   авир, _sivy_, ملىق, _җиде_, 
   {{0x64400003,0xdb0401ed,0x224c03d2,0xdde00150}},	//   _ewli, _elkö, gsek_, _ﺍﺳﺎﺑ, 
   {{0x602000da,0x644003cb,0x2fd80042,0x8678011a}},	//   _lēmu, _fwli, wisg_, _ארמו, 
   {{0x4610006c,0x224c01c4,0x09f4025d,0x661c007f}},	//   _اولر, asek_, רמים_, _èska, 
   {{0x6d4403d3,0x2fd801ab,0xf4840133,0x00000000}},	//   _seha, uisg_, _ماڵی, --, 
   {{0x80c403d4,0x2fd803d5,0x224c00e5,0x00000000}},	//   _ৰুদ্, risg_, csek_, --, 
   {{0x3134010b,0x2b480009,0x6d440200,0xec340022}},	//   _текр, waac_, _qeha, ингь, 
   {{0x6d4403d6,0x48bc015b,0xdb0400c7,0x2b480009}},	//   _veha, _আশ্র, _roká, taac_, 
   {{0x6d4403d7,0xdb0401ed,0x6e98009d,0x00000000}},	//   _weha, _soká, _авир_, --, 
   {{0x6d4403d8,0x2d84004a,0x2b4803d9,0xdb040306}},	// [1f0] _teha, ôles_, raac_, _poká, 
   {{0x6d44019b,0x00000000,0x00000000,0x00000000}},	//   _ueha, --, --, --, 
   {{0xdb0403da,0x765c00dc,0x224c03db,0x00000000}},	//   _voká, _ārya, zsek_, --, 
   {{0x224c03dc,0xe71803dd,0xdcfc0034,0xe75803de}},	//   ysek_, نيات_, _napę, тиді_, 
   {{0x98a8005f,0xdb0403df,0x6440010a,0xdd0c03e0}},	//   ējām_, _toká, _swli, _kışa, 
   {{0x2d9003e1,0x69d400aa,0x224c03e2,0xefc80092}},	//   ndze_, _umze, vsek_, _አዛዥ_, 
   {{0x2d900099,0x928c0150,0x00000000,0x00000000}},	//   idze_, _ﻓﺴﻭﻑ_, --, --, 
   {{0x7c280005,0x7dd403e3,0xe3b003e4,0x00000000}},	//   ídri, _vüsə, ترت_, --, 
   {{0xae1403e5,0x779003e6,0xa1c4036b,0x224c03e7}},	//   णगान_, _ریوا, ибид, usek_, 
   {{0x224c03e8,0x2d9001fa,0x00000000,0x00000000}},	//   rsek_, jdze_, --, --, 
   {{0x224c03e9,0xa0680063,0x600803ea,0x00000000}},	//   ssek_, њама_, кном_, --, 
   {{0x224c03eb,0x2d9003ec,0x9f8001e1,0x00000000}},	//   psek_, edze_, _tóí_, --, 
   {{0x2bc8000d,0x224c0327,0xe2840066,0x00000000}},	//   रसना, qsek_, _خطای, --, 
   {{0x629803ed,0x7bc800e2,0x2dc401ec,0xdcfc0210}},	//   _irwo, īdum, йқын_, _zapę, 
   {{0xdd0c03ee,0x5ea401b9,0x7bc803ef,0x51b4010f}},	//   _dışa, _چمبل, ūdum, _כּהן_, 
   {{0x5ea40014,0x2d840129,0x2d9000d7,0x62980210}},	//   _نمبل, ôler_, adze_, _krwo, 
   {{0x5d74014b,0x00000000,0x00000000,0x00000000}},	// [200] _кунф, --, --, --, 
   {{0x200003f0,0x27ec01e4,0x13bc00cc,0x00000000}},	//   llki_, _ĉena_, ইফয়, --, 
   {{0xdca403f1,0xdb040109,0x5fb800bc,0x27e8022e}},	//   _тани, _alkô, _उकाल, еan_, 
   {{0x629802d0,0xed0400d1,0xd9e0000d,0x6d4003f2}},	//   _orwo, _دوپپ, _खदकत_, ðlav, 
   {{0x23a803f3,0x95840228,0xdd0c0166,0xaa6401af}},	//   कानद, илде, _yışa, _леяһ, 
   {{0xd9b800c7,0x00000000,0x00000000,0x00000000}},	//   _рымч_, --, --, --, 
   {{0x92e003f4,0xfcd802d3,0x629802d0,0x48e003f5}},	//   _ধরে_, _ጭቡጥ_, _arwo, _дорв, 
   {{0x629800d8,0x672c0113,0x2d900210,0x00000000}},	//   _brwo, ñajt, zdze_, --, 
   {{0xd62803f6,0x95a400ec,0x558800d8,0x00000000}},	//   _розе_, _پٽان, _ибам_, --, 
   {{0x225803f7,0xda1403f8,0x1458010b,0x6298015d}},	//   áska_, थगित_, _ашды_, _drwo, 
   {{0x60cc03f9,0x629803fa,0x93880209,0xc95002e4}},	//   _ƙama, _erwo, _асла_, חמת_, 
   {{0x03a003fb,0x22580306,0x43d001e2,0x439001af}},	//   _михо, šska_, _وڅيړ, _маєс, 
   {{0xb638037e,0xf19403fc,0xd1c801e0,0x00000000}},	//   _ｄｋ_, _гиль, _илде_, --, 
   {{0x2d9003fd,0x200003fe,0x00d403ff,0x1138005b}},	//   udze_, alki_, ابیت_, _ряды_, 
   {{0xf2e800bd,0x2d900400,0xac940108,0x00000000}},	//   _পরিণ, rdze_, щавш, --, 
   {{0x23a80401,0x00000000,0x00000000,0x00000000}},	//   कायद, --, --, --, 
   {{0x29040402,0xe9780137,0x212800a2,0x0a68011c}},	// [210] _šla_, лбаш_, _şahi_, ърви_, 
   {{0x09c000c7,0x00000000,0x00000000,0x00000000}},	//   әаҧҟ, --, --, --, 
   {{0xbef80403,0x65bc020c,0x6d400008,0x272c032e}},	//   _مریض_, _wèhk, ðlau, _nónó_, 
   {{0x7d0800c5,0xdc98008f,0xdb04007c,0x00000000}},	//   üdse, _עירל, _bokä, --, 
   {{0xc98400a8,0x1adc0404,0x4668030d,0x27e80115}},	//   _куви, _नेपथ, трем_, ĵan_, 
   {{0x65bc020c,0x7c940405,0xdcfc012c,0x5f080406}},	//   _kèhi, _اشیا, _napě, _सरस्_, 
   {{0x29040407,0x23d40408,0xf87000d7,0x00000000}},	//   _ála_, йцир, ľším_, --, 
   {{0xf87002fb,0x6298007f,0x92e003d4,0x850000ec}},	//   žším_, _prwo, _ধৰে_, ٽوڊن, 
   {{0xe1f80409,0x661c007f,0x00000000,0x00000000}},	//   лги_, _èsko, --, --, 
   {{0xa2e4040a,0x9440040b,0xbec40024,0x00000000}},	//   _қолд, _کھون, šūki, --, 
   {{0x66e401e0,0xdcfc00d7,0x349401ee,0xf5d40244}},	//   _тоҡа, _sopľ, _мафр, _بڵنگ, 
   {{0x6298040c,0x9f4002fb,0x3b7c0092,0xfa900023}},	//   _trwo, boký_, _ቢሮዎች_, _ብጭብጢ_, 
   {{0xcd3c040d,0x62980223,0xc1b000c7,0x33f401d3}},	//   ﯨﻨﯩﯔ_, _urwo, _дәны, _بسلس, 
   {{0xa068040e,0x8e0400d4,0x00000000,0x00000000}},	//   _бака_, йняв_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdcfc040f,0xf2e803d4,0xdca401d5,0x186801a9}},	//   _topľ, _পৰিণ, _ғами, ғади_, 
   {{0x0b400410,0x628803cb,0x765c0055,0x00000000}},	// [220] янтн, nweo, _āryo, --, 
   {{0x5d840411,0xf1c00412,0x6d400413,0x00000000}},	//   _الدل, एसएन, ðlat, --, 
   {{0x9724007b,0x00000000,0x00000000,0x00000000}},	//   مفاو, --, --, --, 
   {{0xd6280414,0x98a40032,0xa3d802a0,0x99800118}},	//   годе_, _һиге, डोम_, _tuků_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9f400306,0x18a40415,0x661c007f,0x4d78010f}},	//   voký_, _лагм, _èskl, ָרקע, 
   {{0xd39400d1,0xdcfc0171,0x00000000,0x00000000}},	//   йәдә_, _nopļ, --, --, 
   {{0x13680416,0xb6c40417,0x62880142,0xdef401f3}},	//   ушки_, _мөлд, fweo, ለሞን_, 
   {{0x9f400418,0x023401d3,0x00000000,0x00000000}},	//   hokó_, یثیت_, --, --, 
   {{0x9f400122,0x27200051,0x672c0419,0x00000000}},	//   roký_, _ẳng_, ľaje, --, 
   {{0x672c041a,0x9f400122,0x3448013e,0x395801bf}},	//   žaje, soký_, _тӯли_, _mdrs_, 
   {{0x9268041b,0x00000000,0x00000000,0x00000000}},	//   _брка_, --, --, --, 
   {{0x63ac0086,0xd9f8041c,0x938801ee,0xdcfc00cd}},	//   _òana, ्तात_, _асһа_, _āyāt, 
   {{0xea0001fb,0xe2a80014,0x2b940051,0x00000000}},	//   _đắp_, _خامن_, _ục_, --, 
   {{0x6ae000cd,0x00000000,0x00000000,0x00000000}},	//   पप्र, --, --, --, 
   {{0x39580175,0x27ec00df,0x4fc40209,0xd1b80133}},	//   _adrs_, _ĉeno_, _ысла, _جاڤا_, 
   {{0x8d840276,0x2fc8041d,0x6d40041e,0x00000000}},	// [230] _лунд, _ilag_, ðlas, --, 
   {{0x6f0c041f,0x9f40011f,0x24880034,0x09dc009e}},	//   _izac, bokó_, łami_, _বীজা, 
   {{0x2fc80420,0x645c0421,0x6d400422,0x6e3c0423}},	//   _klag_, _āsio, ılad, lpsb, 
   {{0x6e3c017a,0x00000000,0x00000000,0x00000000}},	//   opsb, --, --, --, 
   {{0xe6100424,0x00000000,0x00000000,0x00000000}},	//   وشت_, --, --, --, 
   {{0x6f0c0425,0x00000000,0x00000000,0x00000000}},	//   _mzac, --, --, --, 
   {{0x6aac0009,0xa508011c,0x00000000,0x00000000}},	//   lxaf, шека_, --, --, 
   {{0x05740426,0xd24c004b,0x39580427,0x6f0c02d0}},	//   _گارد, چني_, _zdrs_, _ozac, 
   {{0x27ec0428,0x6f0c00ca,0x6aac0429,0xc568042a}},	//   _ijen_, _nzac, nxaf, _محال_, 
   {{0x0574042b,0x2fc8042c,0x39580066,0x225802fb}},	//   _دارد, _alag_, _xdrs_, šsko_, 
   {{0x2fc8042d,0x6f0c042e,0xe108042f,0x6e3c0430}},	//   _blag_, _azac, ренд_, epsb, 
   {{0x2fc80431,0x5fb801f9,0x00000000,0x00000000}},	//   _clag_, _उकळल, --, --, 
   {{0x27ec0051,0xb9240124,0x6f0c012d,0x21280432}},	//   _mjen_, resẽ_, _czac, _şahu_, 
   {{0x6f0c0433,0x6aac0009,0xf1940108,0x00000000}},	//   _dzac, dxaf, _ничь, --, 
   {{0x6f0c0434,0x2fc80435,0x79600241,0xc100009d}},	//   _ezac, _flag_, _láwà, _хүнл, 
   {{0x6d400436,0x2fc80437,0xdee401b9,0x2ca401e3}},	//   ðlar, _glag_, _мойи, ålda_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [240] --, --, --, --, 
   {{0x27ec0438,0x00000000,0x00000000,0x00000000}},	//   _ajen_, --, --, --, 
   {{0x2fc80165,0x27ec0439,0x00000000,0x00000000}},	//   _ylag_, _bjen_, --, --, 
   {{0xdb04043a,0x00000000,0x00000000,0x00000000}},	//   _mokú, --, --, --, 
   {{0xdb04043b,0x27ec0051,0x00000000,0x00000000}},	//   _lokú, _djen_, --, --, 
   {{0x27ec043c,0xd1bc0023,0x1dcc0073,0x349400f5}},	//   _ejen_, ቶታት_, होचत, закр, 
   {{0xb17c01e4,0xa86401ee,0x00000000,0x00000000}},	//   niĥe, _нерҙ, --, --, 
   {{0x27ec02d3,0x7bc4043d,0x2bdc043e,0x440000cf}},	//   _gjen_, nkiu, नोपा, мчыб, 
   {{0x5184004e,0xd5740108,0x7bc400c0,0x00000000}},	//   оуна, _мужь, ikiu, --, 
   {{0x2fc8043f,0x05600440,0xe6d401c6,0x00000000}},	//   _slag_, _овун, _эцсэ, --, 
   {{0x2fc80441,0x7bc40442,0x6f0c0034,0x00000000}},	//   _plag_, kkiu, _szac, --, 
   {{0xea00001e,0xdb0400d0,0xac540023,0x00000000}},	//   _đập_, _dokú, ዝኣብሄ, --, 
   {{0x2fc80443,0x00000000,0x00000000,0x00000000}},	//   _vlag_, --, --, --, 
   {{0x6e3c0444,0x4cd000cc,0x7dd001e3,0x6f0c00d7}},	//   rpsb, _দুগু, _läsf, _vzac, 
   {{0x619400aa,0x00000000,0x00000000,0x00000000}},	//   _راوړ, --, --, --, 
   {{0x6e3c0445,0x2fc800ee,0x7dd0007c,0x6aac0009}},	//   ppsb, _ulag_, _näsf, txaf, 
   {{0x6d4003ee,0xfd6800e4,0x6f0c0446,0x00000000}},	// [250] ılab, nesỹ, _uzac, --, 
   {{0x27ec0385,0x88c40447,0xad4000f7,0x2a840092}},	//   _sjen_, يتال, _سۉرۉ, ርተኞች_, 
   {{0x6e2c01d4,0x6e24014b,0x48a80448,0x6aac0449}},	//   _huab, _iihb, штам_, sxaf, 
   {{0x6e2c044a,0xdb040248,0x8b6400f2,0x25dc044b}},	//   _kuab, _lokù, _بادم, कोनी_, 
   {{0xe5a4044c,0xf770044d,0x27ec044e,0x00000000}},	//   зили, ضان_, _vjen_, --, 
   {{0x6e24016d,0x6e2c044f,0x00000000,0x00000000}},	//   _jihb, _muab, --, --, 
   {{0x60cc0198,0xc44401ed,0x27ec0450,0x69c400f1}},	//   _ƙamm, زیشن_, _tjen_, mkhe, 
   {{0x6e24014f,0xd5e001f2,0x89d40451,0xe3a80452}},	//   _lihb, twọ, _اوڀر_, скид_, 
   {{0x67280453,0x6e2c0134,0x03a00454,0x00000000}},	//   _igej, _nuab, зиқо, --, 
   {{0xdb040030,0x6e240455,0x7bc4005a,0xbbb80456}},	//   _pokú, _nihb, zkiu, _इक्क, 
   {{0x6e2c01ab,0x2a680457,0xa0a40458,0x7bc40006}},	//   _auab, huab_, чанд, ykiu, 
   {{0x6e2c0459,0x27fc045a,0x69c4045b,0x3108045c}},	//   _buab, nown_, hkhe, өнөп_, 
   {{0x6e24045d,0x88c0045e,0xdb04045f,0x6e2c004e}},	//   _bihb, ্পিক, _enkê, _cuab, 
   {{0x69c40460,0x6e2c0461,0x20540462,0x7dd0013d}},	//   jkhe, _duab, _етир, _mäsg, 
   {{0x7bc40357,0x63b80463,0x5f800132,0xc18001d3}},	//   tkiu, _kown, _كۇدە, _فیکٹ, 
   {{0x61e00464,0x67280465,0x69c40466,0x7bc40467}},	//   lill, _ngej, ekhe, ukiu, 
   {{0x61e00468,0xc0400020,0x6e2c0469,0x63b80142}},	// [260] oill, _የተባለ, _guab, _mown, 
   {{0x6728046a,0x3ea0046b,0x6e240097,0x6d40046c}},	//   _agej, _irit_, _gihb, ılac, 
   {{0x60c000ee,0x27fc0135,0x00000000,0x00000000}},	//   nylm, fown_, --, --, 
   {{0x3ea0046d,0x88b0036b,0x69c401f5,0x00000000}},	//   _krit_, ریقچ, akhe, --, 
   {{0xd5b8046e,0x3f8000ec,0x2a680211,0x6e2c005a}},	//   йск_, _mbiu_, cuab_, _xuab, 
   {{0x75d4046f,0x61e00470,0xd004009e,0x95f4033f}},	//   بيتا, jill, োদয়_, इवेट_, 
   {{0x672c0471,0x63b80042,0x74140345,0xd8b40472}},	//   žaja, _bown, ووتا, _عمرخ, 
   {{0xb9e8044e,0x660c03a2,0x61e00473,0x93880474}},	//   _ዮም_, ïakr, eill, сска_, 
   {{0x63b80475,0xdb0401e1,0xe7e0000d,0x63bc01f4}},	//   _down, _pokù, _खगता_, ösna, 
   {{0x61e00476,0x3f80003a,0x63b802d0,0x6e2c0332}},	//   gill, _abiu_, _eown, _ruab, 
   {{0x6e240477,0x3ea00478,0x63b80142,0x6e2c0479}},	//   _rihb, _arit_, _fown, _suab, 
   {{0x3ea0047a,0x63b8047b,0x61e0047c,0x6e24047d}},	//   _brit_, _gown, aill, _sihb, 
   {{0x6e24047e,0x23a8047f,0x3ea0045a,0xe2a800ec}},	//   _pihb, कारद, _crit_, _واهن_, 
   {{0x61e00480,0x6e2c0481,0x3ea00482,0x6e24014f}},	//   cill, _vuab, _drit_, _qihb, 
   {{0x3ea00483,0x6e24047e,0x60c002d0,0x7c840484}},	//   _erit_, _vihb, cylm, нуте, 
   {{0x3ea00485,0xcf240486,0x6e2c0487,0x2a680488}},	//   _frit_, _عربي, _tuab, tuab_, 
   {{0x3ea00489,0xadf4048a,0x46d80307,0x7dd0010b}},	// [270] _grit_, _опиш, _मेंह, _bäsd, 
   {{0xfb3401c0,0xfbd001ed,0x8a900051,0x00000000}},	//   _үнээ, پتہ_, nộim, --, 
   {{0x69c4048b,0x2a680070,0x2d8000a3,0x00000000}},	//   rkhe, suab_, _ibhe_, --, 
   {{0x69c4048c,0x7dd0010b,0xda6400ec,0x00000000}},	//   skhe, _päsg, _ڪاٽي, --, 
   {{0x27fc048d,0x63b8048e,0x61e0048f,0x26080490}},	//   rown_, _rown, yill, ितली_, 
   {{0xd1240491,0x63b80492,0x27fc0076,0x998000ef}},	//   _لم_, _sown, sown_, _tukš_, 
   {{0xdb0402bd,0x63b80493,0xf674009d,0x00000000}},	//   _ankè, _pown, _үгсэ, --, 
   {{0x67280223,0x7c380494,0x29100495,0xf7940276}},	//   _ugej, _évre, _izza_, _пасэ, 
   {{0x61e00496,0x24880497,0x614401f0,0x00000000}},	//   till, ňam_, мепа, --, 
   {{0x61e00498,0x7dd00499,0x63b80263,0x3ea00023}},	//   uill, _käse, _wown, _rrit_, 
   {{0x61e0049a,0x7dd0049b,0x00000000,0x00000000}},	//   rill, _jäse, --, --, 
   {{0x61e0049c,0xdee4049d,0x9424049e,0x60c00209}},	//   sill, доми, _قولۇ, rylm, 
   {{0x7dd0049f,0x9f4004a0,0xe06003e6,0x00000000}},	//   _läse, kokö_, رێکی, --, 
   {{0x61e004a1,0xbb2c04a2,0x29100083,0xa3d803ba}},	//   qill, ﻧﺪﻩ_, _ozza_, डोर_, 
   {{0x9f400023,0x7dd000fd,0x3ea004a3,0x00000000}},	//   nikë_, _näse, _writ_, --, 
   {{0x3ea004a4,0xea000016,0xdb040036,0x00000000}},	//   _trit_, _đạp_, _unkë, --, 
   {{0x291004a5,0x3ea004a6,0x2fd801f5,0x997401f4}},	// [280] _azza_, _urit_, ërge_, дуеш, 
   {{0x7dd00139,0x4e000022,0xea9401c6,0x260c012d}},	//   _bäse, _изыб, эшсэ, _ढीली_, 
   {{0x9f400240,0x672c00d0,0xf8a401c6,0x00000000}},	//   jikë_, ľajn, эгжү, --, 
   {{0xbb2c040d,0x672c04a7,0x9f40036e,0x2bdc041c}},	//   ﻧﺪﻯ_, žajn, dikë_, नोदा, 
   {{0x291004a8,0x7dd00139,0x00000000,0x00000000}},	//   _ezza_, _täsd, --, --, 
   {{0x9f400240,0x00000000,0x00000000,0x00000000}},	//   fikë_, --, --, --, 
   {{0x629c00b5,0x9f8001e7,0x438000d1,0x00000000}},	//   æson, _dóú_, چلىق, --, 
   {{0x438004a9,0xa3d804aa,0x00000000,0x00000000}},	//   نلىق, डोल_, --, --, 
   {{0x248400ca,0xd16400a7,0xdcfc00de,0xc0400092}},	//   _eplm_, мъни, _kapē, _የተቻለ, 
   {{0x7dd004ab,0x9f400200,0x056001a9,0x00000000}},	//   _läsb, bikë_, _авфн, --, 
   {{0x1cd80327,0xdcfc0171,0x00000000,0x00000000}},	//   ྡགས_, _mapē, --, --, 
   {{0x7dd00267,0x9f400100,0x68e000a2,0x00000000}},	//   _näsb, nikè_, _ýlde, --, 
   {{0x441804ac,0xff0404ad,0xc7b004ae,0xa3bc04af}},	//   _וואס, вярн, דבר_, ीघर_, 
   {{0x22480432,0x00000000,0x00000000,0x00000000}},	//   _çaka_, --, --, --, 
   {{0xc04c0046,0xac1804b0,0xc170011a,0x00000000}},	//   _ші_, зову_, _יחס_, --, 
   {{0x7dd000fd,0x7b6404b1,0xc0c804b2,0x00000000}},	//   _räse, ктуе, _አካሉ_, --, 
   {{0x9f4002d3,0x98b800b0,0x00000000,0x00000000}},	// [290] zikë_, kapē_, --, --, 
   {{0x7dd0014a,0x2d8000cd,0xac94009b,0x00000000}},	//   _päse, _ubhe_, _заош, --, 
   {{0x6ce404b3,0xbc9404b4,0xbdf8009f,0xfeb80244}},	//   _سزدە, _иңрә, _تريا_, _فایت_, 
   {{0x6d5403d1,0xdb0400e4,0x7dd001e6,0xad10035b}},	//   laza, _hoký, _väse, _аҿҳә, 
   {{0x6b8c04b5,0x248404b6,0xa56401d5,0x672c0427}},	//   meag, _splm_, فگان, žajo, 
   {{0x6d5404b7,0x9f40044e,0xdcec0006,0x6b8c04b8}},	//   naza, tikë_, gebė, leag, 
   {{0x26c804b9,0x291004ba,0x83d8033f,0x67d404bb}},	//   šao_, _uzza_, यफलआ, _зову, 
   {{0x6b8c04bc,0x6d5404bd,0x7dd004be,0x9f400023}},	//   neag, haza, _käsc, rikë_, 
   {{0x601404bf,0xcaa002d3,0x6b8c0363,0x21740107}},	//   náme, _ወጺኦም_, ieag, нунр, 
   {{0x6b8c04c0,0x7dd004c1,0x9f40036e,0xe0d804c2}},	//   heag, _mäsc, pikë_, зво_, 
   {{0x9f4004c3,0x7dd004c4,0xe7e004c5,0x6b8c04c6}},	//   liké_, _läsc, যকীয, keag, 
   {{0xc0c804c7,0x6b8c04c8,0x00000000,0x00000000}},	//   _አካል_, jeag, --, --, 
   {{0x6d540364,0x6d40046c,0x712401ed,0x7dd001c7}},	//   faza, ılan, ٹریل, _näsc, 
   {{0x6b8c00ad,0x00800139,0x00000000,0x00000000}},	//   eeag, _аккү, --, --, 
   {{0x6b8c04c9,0x9f40020c,0xdb0400d7,0x48c00154}},	//   feag, hiké_, _doký, ্পুর, 
   {{0x6b8c04ca,0x7dd00221,0xdcfc00ef,0x00000000}},	//   geag, _bäsc, _sapē, --, 
   {{0x7dd00267,0xdcfc00e2,0x00000000,0x00000000}},	// [2a0] _väsb, _papē, --, --, 
   {{0x200004cb,0x7dd004cc,0x8d740131,0xa7340023}},	//   loki_, _däsc, _كاپا, _ብሓፈሻ, 
   {{0x6b8c04cd,0x7dd00166,0x987c0205,0x00000000}},	//   beag, _täsb, tçıt_, --, 
   {{0x48c000bd,0x2ca404ce,0x601404cf,0x200004d0}},	//   ্পূর, ælde_, lámb, noki_, 
   {{0x7dd004d1,0x601400d2,0x69d000e2,0xdcfc00de}},	//   _gäsc, cáme, _ūdeņ, _tapē, 
   {{0x200004d2,0x38c804d3,0x601404d4,0x00000000}},	//   hoki_, _قازی_, námb, --, 
   {{0x200004d5,0x046000ee,0x765c0055,0x00000000}},	//   koki_, гтым, _āryu, --, 
   {{0x6d5404d6,0x601404d7,0x2000023a,0x00000000}},	//   zaza, hámb, joki_, --, 
   {{0x200004d8,0x6d5404d9,0x46b40034,0x9f400214}},	//   doki_, yaza, _आपयह, ciké_, 
   {{0x6b8c01c0,0xb9e4001f,0x453004da,0x74a00131}},	//   zeag, _ጫና_, _مىكر, _ﺋﯧﭽﯩ, 
   {{0x200003c1,0xc05404db,0xdb0404dc,0x6d5404dd}},	//   foki_, нія_, _kokó, vaza, 
   {{0x6d5404de,0x200004df,0x6b8c01c6,0xdb0400a2}},	//   waza, goki_, xeag, _soký, 
   {{0x6d5404e0,0xdb0404e1,0x6b8c04e2,0x92dc00cc}},	//   taza, _mokó, veag, _দুৰ_, 
   {{0xdb0404e3,0x2bc804e4,0x717404e5,0x7dd004e6}},	//   _lokó, रस्थ, _شهبا, _räsc, 
   {{0x6d5404e7,0x200004e8,0x6b8c04e9,0xc198008f}},	//   raza, boki_, teag, _משגי, 
   {{0x6d5404ea,0x200004eb,0xfc3000c6,0x7dd00036}},	//   saza, coki_, صحف_, _päsc, 
   {{0x6b8c04ec,0x00000000,0x00000000,0x00000000}},	// [2b0] reag, --, --, --, 
   {{0x601404ed,0x6b8c04ee,0x5928031c,0xe7bc0183}},	//   ráme, seag, _སྔངས_, _আগেয, 
   {{0x7dd004ef,0x764000a2,0x636002e3,0x9f40020c}},	//   _wäsc, _atmy, ịnii, wiké_, 
   {{0x7dd00221,0x9f400066,0x6b8c01d5,0x377404f0}},	//   _täsc, tiké_, qeag, гышс, 
   {{0x2b480276,0xdb040139,0xd9f804af,0x00000000}},	//   mbac_, _xokü, ्तखत_, --, 
   {{0x2a6801b9,0x9f40020c,0x200004f1,0x77a801d9}},	//   mrab_, riké_, zoki_, ٘ێہہ_, 
   {{0x20000296,0x76400083,0x9f4004f2,0x23f40107}},	//   yoki_, _etmy, siké_, кчиё, 
   {{0xa82403e6,0x66640014,0x200000f1,0xe3b0007b}},	//   _شکان, _لُرٕ, xoki_, شرب_, 
   {{0x7dd004f3,0x200004f4,0x2a68006e,0x221404f5}},	//   _läsa, voki_, nrab_, кфор, 
   {{0x20000083,0x25dc00bc,0x00000000,0x00000000}},	//   woki_, कोशी_, --, --, 
   {{0x200004f6,0x7dd004f7,0x2a6804f8,0xb9280055}},	//   toki_, _näsa, hrab_, _byuṅ_, 
   {{0x644004f9,0x25dc04fa,0x23e804fb,0x2a6801a9}},	//   _itli, कोरी_, _غذای_, krab_, 
   {{0x200004fc,0x60140085,0x00000000,0x00000000}},	//   roki_, támb, --, --, 
   {{0x2a6804fd,0x7dd00139,0xd6540375,0xa06800cf}},	//   drab_, _bäsa, כישת_, _жака_, 
   {{0x200004fe,0x7dd004ff,0xa074035b,0x20740500}},	//   poki_, _cäsa, _рылш, _рулё, 
   {{0x60140085,0x22580306,0x6aa80501,0x5f74009f}},	//   sámb, šsku_, _šefa, _شابر, 
   {{0x3ae80502,0x50180302,0x48c0015b,0x2a680503}},	// [2c0] ربری_, _קופו, ্পোর, grab_, 
   {{0x656002b9,0xd9440504,0x18a4036b,0x7dd00139}},	//   _ndlh, тежи, казм, _fäsa, 
   {{0xdb040034,0x64400505,0x2a680506,0x764000b5}},	//   _pokó, _ntli, arab_, _stmy, 
   {{0x656002c4,0x5b1400f7,0x00000000,0x00000000}},	//   _adlh, _үмүт, --, --, 
   {{0x64400507,0x320c0209,0xdb0400e4,0x46b40073}},	//   _atli, yldy_, _vokó, _आपणह, 
   {{0xdb040034,0x00000000,0x00000000,0x00000000}},	//   _wokó, --, --, --, 
   {{0x799c03a2,0x64400010,0x00000000,0x00000000}},	//   _iarw, _ctli, --, --, 
   {{0x656002c4,0x799c0508,0x04dc0055,0x32980120}},	//   _edlh, _harw, _jāṇu, евиќ_, 
   {{0x64400509,0x877800c8,0x7640050a,0x3134050b}},	//   _etli, _קאמי, _utmy, лепр, 
   {{0x799c050c,0x5ec40154,0x00000000,0x00000000}},	//   _jarw, _লেভে, --, --, 
   {{0x799c050d,0xdc8c044e,0x225c000d,0x73c401e0}},	//   _marw, ዝነበረ_, _evwk_, _бәпе, 
   {{0x6d40050e,0x799c050f,0x444401d9,0x64980116}},	//   ılam, _larw, _شرمہ, _ятур_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2d840510,0x799c0511,0x7dd002d1,0x64400267}},	//   ýle_, _narw, _päsa, _ytli, 
   {{0xf41400c8,0x00000000,0x00000000,0x00000000}},	//   ָפּ_, --, --, --, 
   {{0x04dc0055,0xdcfc00c0,0x2a6801a9,0x98b80064}},	//   _cāṇu, _lapė, trab_, lapė_, 
   {{0x799c0512,0x2ec4010b,0xdb0401e1,0x00000000}},	// [2d0] _barw, _сөнм, _sokò, --, 
   {{0x6f0c0513,0x799c0514,0xc27802e4,0x2a680515}},	//   _iyac, _carw, ורמי, rrab_, 
   {{0x2d900516,0x48c000bd,0xd2440517,0x60140518}},	//   meze_, ্প্র, _گن_, láma, 
   {{0x2d900519,0x6f0c0083,0x26780276,0x6440051a}},	//   leze_, _kyac, ескэ_, _rtli, 
   {{0x799c051b,0xd244051c,0x6440036b,0x1d88001f}},	//   _farw, _دن_, _stli, _ሕዝቦች_, 
   {{0x799c051d,0x2d90051e,0x6f0c051f,0x7dd00520}},	//   _garw, neze_, _myac, _läsn, 
   {{0xfd500521,0x6b9c0522,0x60140523,0x6d400162}},	//   _aghụ, _kasg, háma, ðlay, 
   {{0x2d900524,0x60140525,0x799c0526,0xe2b80063}},	//   heze_, káma, _zarw, ећој_, 
   {{0x2d900527,0x799c0528,0x6b9c0529,0x6f0c052a}},	//   keze_, _yarw, _masg, _nyac, 
   {{0x2d90052b,0x6b9c052c,0xc0c4001f,0x00000000}},	//   jeze_, _lasg, _ችሏል_, --, 
   {{0x2d90052d,0x6f0c052e,0x00000000,0x00000000}},	//   deze_, _ayac, --, --, 
   {{0xa0a4052f,0x6f0c0530,0xd24c0531,0x44240532}},	//   _ҡалд, _byac, _کنو_, _شراف, 
   {{0xdcb00533,0x6f0c0534,0x2d900535,0x62640536}},	//   ڭىز_, _cyac, feze_, _свла, 
   {{0x2d900537,0x6f0c0538,0x00000000,0x00000000}},	//   geze_, _dyac, --, --, 
   {{0x6b9c0539,0x6f0c053a,0xd00c00aa,0x9f400418}},	//   _basg, _eyac, _ډلو_, likí_, 
   {{0x799c053b,0x6b9c053c,0x69d8053d,0xabd40114}},	//   _sarw, _casg, ëwen, ацуј, 
   {{0x799c053e,0xfeb4053f,0x60140540,0x6b9c0541}},	// [2e0] _parw, _төнь, cáma, _dasg, 
   {{0x799c0542,0x6b9c03d5,0x3c940543,0x62980544}},	//   _qarw, _easg, _پیرز, _mswo, 
   {{0x6b9c0545,0x799c0433,0x47c800f1,0x00000000}},	//   _fasg, _varw, کالۍ_, --, 
   {{0x799c0546,0x6b9c0368,0xb8cc000d,0x62980210}},	//   _warw, _gasg, _कछ_, _oswo, 
   {{0x799c0547,0x62980421,0xa5bc00b8,0xdcfc0153}},	//   _tarw, _nswo, _puųp, _papė, 
   {{0x7dd00030,0x9f8001e1,0xd1d40092,0x00000000}},	//   _mäso, _kóó_, ርቱት_, --, 
   {{0x6b9c0548,0x62980549,0x9484054a,0x00000000}},	//   _yasg, _aswo, уылд, --, 
   {{0x2d90054b,0x88f00050,0x6f080034,0x9f400093}},	//   zeze_, _آفت, żeci, fikí_, 
   {{0x2d90054c,0x1544054d,0x7dd0007c,0x57a401af}},	//   yeze_, _безм, _näso, _ишҡа, 
   {{0x6f0c0230,0x2d90054e,0x60140113,0xfa740023}},	//   _ryac, xeze_, váma, እሰናይ_, 
   {{0x6298007f,0x6f0c04ce,0xc68c0014,0xe4740006}},	//   _eswo, _syac, _وِہ_, _вучэ, 
   {{0x2d90054f,0x8f4402d5,0xb4c00550,0xdb0401e1}},	//   weze_, ыход, ँही_, _onkà, 
   {{0x7dd0007c,0x00000000,0x00000000,0x00000000}},	//   _väsn, --, --, --, 
   {{0x6f0c0551,0x6aa80552,0x60140553,0x6b9c0554}},	//   _vyac, _šefo, ráma, _sasg, 
   {{0x6b9c0555,0x80a00214,0xac940556,0x601400e4}},	//   _pasg, _همون, шавш, sáma, 
   {{0x2d900557,0x672c0558,0x6b9c0455,0x7dd001f4}},	//   seze_, žaji, _qasg, _häsl, 
   {{0xeb980559,0x2d90055a,0x6b9c0151,0x63bc049f}},	// [2f0] ниң_, peze_, _vasg, ösni, 
   {{0x6b9c055b,0xddc40064,0x00000000,0x00000000}},	//   _wasg, pukš, --, --, 
   {{0x6b9c055c,0x7dd0008e,0x00000000,0x00000000}},	//   _tasg, _mäsl, --, --, 
   {{0x6b9c007b,0x7dd001e3,0x61540092,0x00000000}},	//   _uasg, _läsl, መቤታች, --, 
   {{0x200c013f,0x9f800241,0x00000000,0x00000000}},	//   _ɔfi_, _kóò_, --, --, 
   {{0xe4c4055d,0xe5a404a9,0x7dd0055e,0x855400f2}},	//   ийли, рики, _näsl, ایار_, 
   {{0x23d4055f,0xdb0400dd,0xd854010b,0x69d400de}},	//   ицир, _inká, _весө, _ilze, 
   {{0x62640560,0xea0001dc,0x57b00220,0x9f400561}},	//   авиа, _đẹp_, _мұхт, tikí_, 
   {{0x7dd00209,0x766800f1,0x00000000,0x00000000}},	//   _bäsl, _مینې_, --, --, 
   {{0x5bd000dc,0xd1c4030d,0xa3d80562,0x1b000154}},	//   _सत्व, илые_, डोज_, লেকে_, 
   {{0x7dd004f3,0xa0680563,0xdb0c03b2,0x00000000}},	//   _säso, ъана_, ádúg, --, 
   {{0x62980564,0x6fcc002d,0x5438008f,0x69d4002f}},	//   _tswo, _jûch, _סענא, _llze, 
   {{0x442c0196,0x733400cf,0xdde801d5,0x3344013d}},	//   _iig_, _ارمئ, نرسه_, _уҗым_, 
   {{0x442c0565,0xdb0401b8,0x5c9002d3,0x1c4401b9}},	//   _hig_, _kokö, _ምልክታ_, ингм, 
   {{0x442c0566,0x3f8400c5,0xe0d001d9,0x1d080567}},	//   _kig_, õmus_, _گٲں_, теви_, 
   {{0x69d40568,0x442c0569,0xdb040124,0x6014056a}},	//   _alze, _jig_, _mokö, mámo, 
   {{0x442c056b,0x3d1c0241,0xdcfc00b8,0x4a4000d8}},	// [300] _mig_, _báwí_, _kapī, жнув, 
   {{0x442c056c,0x26dc0099,0x9c580116,0x7dd00037}},	//   _lig_, dzwo_, _ишму_, _käsm, 
   {{0x6fcc056d,0x60140077,0x8f500150,0x442c056e}},	//   _bûch, námo, _انۋش, _oig_, 
   {{0x442c056f,0xcc38008f,0x7dd00139,0x1b0000cc}},	//   _nig_, _שעכט, _mäsm, লেগে_, 
   {{0x9f800570,0x2d840137,0x00000000,0x00000000}},	//   _yóò_, òleg_, --, --, 
   {{0x442c0571,0x7c2403be,0x98a40572,0xf43401a9}},	//   _aig_, lmir, _киге, бекэ, 
   {{0x442c0573,0x2bdc0574,0x39580575,0x7dd0007c}},	//   _big_, नोका, _iers_, _näsm, 
   {{0x442c0576,0x93880577,0x6fcc002d,0x6014056a}},	//   _cig_, тска_, _gûch, dámo, 
   {{0x442c0578,0x3c3c0579,0x7c24057a,0x3958057b}},	//   _dig_, _lív_, imir, _kers_, 
   {{0x442c057c,0x7c24057d,0x8678011a,0x00000000}},	//   _eig_, hmir, _ברמו, --, 
   {{0x3958057e,0x442c0302,0x321c0109,0x6014057f}},	//   _mers_, _fig_, _vhvy_, gámo, 
   {{0x3958004e,0x6e940580,0x15e00456,0x00000000}},	//   _lers_, биму, कोरर_, --, 
   {{0x7c240581,0x39580582,0xd24c0583,0x7dd00166}},	//   dmir, _oers_, _کنڈ_, _täsl, 
   {{0x442c0584,0x39580585,0x60140005,0x5ec4009e}},	//   _zig_, _ners_, bámo, _লেহে, 
   {{0x442c0586,0x60140587,0xf04404fb,0xdb040588}},	//   _yig_, cámo, _اعتی, _mokõ, 
   {{0x7c240522,0x9f400589,0x442c058a,0x69d402f0}},	//   gmir, rikã_, _xig_, _slze, 
   {{0x3958058b,0x8d84058c,0x69d4058d,0x6fcc045f}},	// [310] _bers_, _кунд, _plze, _rûch, 
   {{0xc6680020,0x3958058e,0x6fcc000f,0x6d98023a}},	//   _አፍሪካ_, _cers_, _sûch, _своё_, 
   {{0x3958058f,0x9f400590,0x7c240200,0x00000000}},	//   _ders_, liká_, bmir, --, 
   {{0x39580591,0x7c240276,0xe7180592,0x26dc0036}},	//   _eers_, cmir, هيات_, tzwo_, 
   {{0x39580593,0x2b580048,0xe6880594,0x9f400122}},	//   _fers_, _iesc_, انتى_, niká_, 
   {{0x442c0595,0x39580596,0x9f8001a8,0xe7740139}},	//   _sig_, _gers_, _lóð_, kıçı, 
   {{0xe3b00597,0x6014056a,0xd90c0451,0x98a8025c}},	//   كرة_, xámo, _ٻڌل_, _rebħ_, 
   {{0x7dd00598,0x442c01d4,0x86e4036b,0x60140599}},	//   _räsm, _qig_, _кўзд, vámo, 
   {{0x36d4059a,0x2b58059b,0xdcfc005f,0x07500131}},	//   _дотр, _mesc_, _papī, _ﺋﻪﯓ_, 
   {{0x7c24005f,0x9f4000d7,0x6014059c,0x00000000}},	//   zmir, diká_, támo, --, 
   {{0x442c059d,0x6514059e,0x291000a2,0x21a4059f}},	//   _tig_, _اوائ, _jyza_, _ҳилм, 
   {{0x601405a0,0x42b000aa,0x672c05a1,0x442c00a3}},	//   rámo, _ولاړ, žaju, _uig_, 
   {{0x53980302,0x60140005,0x02c005a2,0xe1f00150}},	//   _תינו, sámo, _филү, _ىست_, 
   {{0x2b58030a,0x32b800c6,0xdb04035b,0x7dd0023a}},	//   _aesc_, _خدمة_, _mokô, _täsm, 
   {{0x7c2405a3,0x98b802b1,0x714000cf,0x91b8011a}},	//   tmir, rapī_, _تۉپۅ, _תמצי, 
   {{0x9f8005a4,0x395805a5,0x2b5805a6,0x7dd005a7}},	//   _góð_, _sers_, _cesc_, _käsk, 
   {{0x2b5805a8,0xeb5405a9,0x00000000,0x00000000}},	// [320] _desc_, زىلگ, --, --, 
   {{0x7dd00598,0x2b580327,0x7e6400e4,0x2488033f}},	//   _mäsk, _eesc_, _ivip, łamy_, 
   {{0x395805aa,0x2b5805ab,0x7dd00520,0x00000000}},	//   _vers_, _fesc_, _läsk, --, 
   {{0x7e6405ac,0x3958015d,0x29100432,0x00000000}},	//   _kvip, _wers_, _dyza_, --, 
   {{0x395805ad,0xada805ae,0xe77400ac,0xdb040124}},	//   _ters_, _صدیق_, zıçı, _pokõ, 
   {{0x05140055,0x6ca405af,0x00000000,0x00000000}},	//   _hūṃp, _اصیل, --, --, 
   {{0x66d001d3,0x2910010b,0x9f4000d0,0x7f44036e}},	//   tókö, _gyza_, ziká_, _ofiq, 
   {{0x2b58004e,0x544400db,0x00000000,0x00000000}},	//   _xesc_, _ۇنئك, --, --, 
   {{0x9f800174,0x6b880139,0x00000000,0x00000000}},	//   _róð_, _öege, --, --, 
   {{0x104805b0,0x7f4405b1,0x6aa801fa,0x168403e6}},	//   лями_, _afiq, _šefk, _ناڕێ, 
   {{0x7e6400cd,0x672c0010,0x49b800df,0x00000000}},	//   _avip, žajt, אמיס, --, 
   {{0x942405b2,0x9f4000d0,0xb4d405b3,0x82900137}},	//   _умее, tiká_, हनी_, تۇۇچ, 
   {{0x7e640055,0x7dd00166,0x4ed400eb,0x00000000}},	//   _cvip, _gäsk, সপ্ল, --, 
   {{0x7e6405b4,0x604002e3,0x2b580120,0xf53801e4}},	//   _dvip, _ịmep, _sesc_, _maĥo_, 
   {{0xad240075,0x25dc05b5,0x7e64003a,0x7dd00139}},	//   زىرى, कोटी_, _evip, _mäsh, 
   {{0xdb040036,0x1b00015b,0x7dd0007c,0x291005b6}},	//   _onkä, লেছে_, _läsh, _ryza_, 
   {{0x2b58004e,0xb4d400bc,0x00000000,0x00000000}},	// [330] _vesc_, हनु_, --, --, 
   {{0x2ba805b7,0x7dd0007c,0x00000000,0x00000000}},	//   _चोरा, _näsh, --, --, 
   {{0xa8980220,0x8a74016c,0x7e6405b8,0x6d4402d0}},	//   ркеу_, риҷӣ_, _zvip, _ifha, 
   {{0x61c405b9,0xc95401e0,0x7e640022,0x7f440477}},	//   _लक्ष, ртҡы, _yvip, _xfiq, 
   {{0x25ec05ba,0x00000000,0x00000000,0x00000000}},	//   _अगदी_, --, --, --, 
   {{0x3e5c008f,0xd65c030d,0x00000000,0x00000000}},	//   נדוס, _гiод, --, --, 
   {{0x290405bb,0x67d405bc,0xdb0401e6,0x6d4401ab}},	//   _âla_, _дову, _enkä, _mfha, 
   {{0x666401d9,0xb76400fb,0xf41c00fe,0x00000000}},	//   _وُزٕ, _нтуй, _পূবৰ_, --, 
   {{0x6d4401c7,0x622400d1,0x0584014b,0x00000000}},	//   _ofha, يىبل, _гуем, --, 
   {{0xd24c05bd,0x7dd0049f,0x672c05be,0x7f44031c}},	//   کنی_, _väsk, žajs, _sfiq, 
   {{0x7e64008c,0x8c400209,0x00000000,0x00000000}},	//   _svip, üşle, --, --, 
   {{0x6d4405bf,0x2464005f,0x1e0005c0,0x9ea805c1}},	//   _afha, mēm_, लक्ष_, авма_, 
   {{0x6d4403d5,0x630405c2,0x7dd00209,0x2464005f}},	//   _bfha, _بوشل, _häsi, lēm_, 
   {{0x7dd005c3,0x224c05c4,0x25dc03e5,0xd1380139}},	//   _käsi, mpek_, कोची_, _taƅa_, 
   {{0x8c4005c5,0x224c0209,0x2464005f,0x7a300241}},	//   десе, lpek_, nēm_, _lótì, 
   {{0xb06805c6,0x224c05c7,0x7dd000d0,0xe4f0000d}},	//   _اصول_, opek_, _mäsi, _अइनि_, 
   {{0x19c405c8,0x224c009b,0x9a6800c6,0x7dd0007c}},	// [340] обам, npek_, شمال_, _läsi, 
   {{0x3ea005c9,0x00000000,0x00000000,0x00000000}},	//   _isit_, --, --, --, 
   {{0x7dd005ca,0x9f0401b9,0xd7c40108,0x6d400205}},	//   _näsi, _دوکو, жёло, ılat, 
   {{0x224c05cb,0x2464005f,0x3ea00010,0x76440022}},	//   kpek_, dēm_, _ksit_, зҭаа, 
   {{0xd5b805cc,0x07a00022,0x9f400432,0x00000000}},	//   иск_, ьацн, mikä_, --, 
   {{0x7dd000a2,0x9f40008e,0x00000000,0x00000000}},	//   _bäsi, likä_, --, --, 
   {{0xb4d405cd,0x25f001ad,0x00000000,0x00000000}},	//   हने_, ेवजी_, --, --, 
   {{0x7dd0014a,0x6aa805ce,0x98b80006,0xb9e40092}},	//   _däsi, _šefi, lapį_, _ኩሽ_, 
   {{0x73c401e0,0x7e600356,0xfbe80051,0x00000000}},	//   жәһе, âmpl, _đế_, --, 
   {{0x3f8005cf,0xd4680276,0x7dd00139,0xcb1005d0}},	//   _aciu_, _виже_, _fäsi, ולח_, 
   {{0x2464005f,0x3ea005d1,0x629c005c,0x00000000}},	//   cēm_, _asit_, æsor, --, 
   {{0x8c4005d2,0x601400ae,0x00000000,0x00000000}},	//   üşme, námh, --, --, 
   {{0x7dd001b8,0x00000000,0x00000000,0x00000000}},	//   _zäsi, --, --, --, 
   {{0x68e00254,0x821005d3,0x7dd00139,0x00000000}},	//   _üldg, _قونص, _yäsi, --, 
   {{0xfd1005d4,0x3ea005d5,0x320c05d6,0x101400c6}},	//   نجف_, _esit_, mody_, _وبعد, 
   {{0x80d405d7,0x320c05d8,0xb17c01e4,0x9e6401d3}},	//   मनरे, lody_, riĥu, _کاٹن, 
   {{0x2464005f,0x320c002d,0xfb8400c7,0x00000000}},	// [350] zēm_, oody_, ьырн, --, 
   {{0x7dc405d9,0x320c05da,0x48a80139,0xa9c000db}},	//   _يقين, nody_, итем_, رۅزۉ, 
   {{0x2d8005db,0x0ffc05dc,0x9f40013d,0x00000000}},	//   _iche_, _उदाश_, bikä_, --, 
   {{0x320c05dd,0xdec002d3,0x246400e2,0x7dd005de}},	//   hody_, _ኻልእ_, vēm_, _räsi, 
   {{0x320c033f,0x9bb8011a,0x00000000,0x00000000}},	//   kody_, _הצרפ, --, --, 
   {{0x64a405df,0x246400da,0x0dc40023,0x858801a9}},	//   зака, tēm_, _ጽሓፊ_, рёда_, 
   {{0x2d8001f7,0xd5ac05e0,0x00000000,0x00000000}},	//   _mche_, طفي_, --, --, 
   {{0x3cfc05e1,0xe3b805e2,0x7dd005e3,0x2fc805e4}},	//   ילונ, сби_, _väsi, _noag_, 
   {{0x27ec05e5,0xd24c05e6,0x320c0170,0x2d800521}},	//   _imen_, هني_, fody_, _oche_, 
   {{0x7dd00209,0x2d800521,0x320c0034,0x3f80010f}},	//   _täsi, _nche_, gody_, _sciu_, 
   {{0x224c05e7,0x601405e8,0x2fc801c3,0xe04405e9}},	//   spek_, lámi, _boag_, янни, 
   {{0x2fc80005,0xd8d40375,0x224c05ea,0x25a40375}},	//   _coag_, פורט_, ppek_, _hall_, 
   {{0x320c05eb,0x25a405ec,0x27ec007f,0x02a40276}},	//   body_, _kall_, _mmen_, _фрем, 
   {{0x21a405ed,0x25a405ee,0x7dd00267,0x2d8005ef}},	//   _хикм, _jall_, _läsv, _cche_, 
   {{0x27ec05f0,0x25a4011a,0x91b8011a,0x712400cf}},	//   _omen_, _mall_, _למסי, _ۉرۉل, 
   {{0x2d8000b4,0x27ec0280,0x9e6405f1,0x3ea005f2}},	//   _eche_, _nmen_, _евид, _tsit_, 
   {{0x6d4005f3,0x3ea005f4,0x8f78011a,0x9b4400db}},	// [360] ılar, _usit_, _הנפק, _ۉندو, 
   {{0x0b4005f5,0x25a40192,0x27ec05f6,0xd7e801e0}},	//   _үнэн, _nall_, _amen_, әмде_, 
   {{0x18340345,0x9b4400db,0x00000000,0x00000000}},	//   سراح, _ىندو, --, --, 
   {{0x291c0198,0x6ac805f7,0x25a40042,0x779405f8}},	//   ƙwan_, ðsfó, _aall_, بیرا, 
   {{0xb4e405f9,0x25a405fa,0x601401e7,0x00000000}},	//   _पेड़_, _ball_, rámh, --, 
   {{0x25a405fb,0x2d800395,0x60780020,0x7ae405fc}},	//   _call_, _xche_, _በሰጡት_, mzit, 
   {{0x25a405fd,0x320c031d,0x7ae405fe,0x6fdc00e1}},	//   _dall_, vody_, lzit, _पतलू, 
   {{0x2ca4022c,0x320c05ff,0x07a00600,0xc7a00601}},	//   ældi_, wody_, _пасн, _писк, 
   {{0x7ae40602,0x320c0603,0x25a40604,0x2fc801ab}},	//   nzit, tody_, _fall_, _roag_, 
   {{0x20100605,0x7dd000c5,0x27ec0606,0x7ae40165}},	//   _akyi_, _käsu, _zmen_, izit, 
   {{0x2fc80607,0x93140608,0x320c0609,0xc1b401c0}},	//   _poag_, _کوشش, rody_, члэх_, 
   {{0x2d80060a,0x25a4060b,0x14240139,0x27ec0208}},	//   _sche_, _zall_, _эдем, _xmen_, 
   {{0xe80c060c,0xb8d8031c,0x7ae401f5,0x320c0072}},	//   िकता_, _ྙན_, jzit, pody_, 
   {{0x2010016b,0x7ae4060d,0x00000000,0x00000000}},	//   _ekyi_, dzit, --, --, 
   {{0x622400f7,0x104801b9,0x7dd0007c,0x7ae4002f}},	//   _تووە, _уяли_, _näsu, ezit, 
   {{0x7bc40200,0x00000000,0x00000000,0x00000000}},	//   gjiu, --, --, --, 
   {{0x25ec060e,0x2d80060f,0xfd100583,0x00000000}},	// [370] _अगली_, _tche_, نجہ_, --, 
   {{0x2d8000b4,0xab90001f,0x00000000,0x00000000}},	//   _uche_, ዝበዋል_, --, --, 
   {{0x7ae40083,0x25a4030a,0x6d540165,0x00000000}},	//   azit, _rall_, mbza, --, 
   {{0x25a40610,0x60140077,0xa64c0023,0x7ae40327}},	//   _sall_, támi, _ዝተወደ, bzit, 
   {{0xf7700611,0xe5a40612,0x25a40613,0x6b8c0614}},	//   طان_, дили, _pall_, mfag, 
   {{0x60140615,0xf6500616,0xd6cc0617,0x2f240618}},	//   rámi, ائن_, شقى_, _gūgū_, 
   {{0x25a40619,0x27ec0263,0x6b8c0421,0x6aac061a}},	//   _vall_, _tmen_, ofag, lvaf, 
   {{0x7dd0061b,0x27ec061c,0x25a4061d,0x21280115}},	//   _häst, _umen_, _wall_, _ŝaho_, 
   {{0x6448061e,0x6b8c0607,0x7dd0061f,0x25a4011a}},	//   _žlič, ifag, _käst, _tall_, 
   {{0x69c40620,0x7dd00621,0xc5f8007b,0xbb840150}},	//   njhe, _jäst, _اعرض_, _ﺩﻋﻤﻪ_, 
   {{0x7ae40622,0x7dd0049f,0x6b8c0623,0xf62800d4}},	//   zzit, _mäst, kfag, _хіти_, 
   {{0x7dd00624,0x5ec400bd,0x27fc0368,0xc10000d1}},	//   _läst, _লেগে, nnwn_, _җүмл, 
   {{0x21680625,0xdf000083,0x6b8c0626,0x71f80014}},	//   _дили_, kuŋŋ_, dfag, _کرنس_, 
   {{0x63a80627,0x7dd00628,0x6aac022e,0x00000000}},	//   lden, _näst, dvaf, --, 
   {{0x62880629,0xf1a803e6,0x6b8c062a,0xb0680592}},	//   lteo, _راوه_, ffag, _فصيل_, 
   {{0x7ae401c0,0x7dd00139,0x00000000,0x00000000}},	//   tzit, _räsu, --, --, 
   {{0x7dd00628,0x6288062b,0x7ae401c8,0xda640592}},	// [380] _bäst, nteo, uzit, بازي, 
   {{0x63a802f6,0x22580122,0x628800c6,0x6b8c062c}},	//   hden, ásky_, iteo, afag, 
   {{0x63a8062d,0x7ae401d3,0x6288062e,0x00000000}},	//   kden, szit, hteo, --, 
   {{0x63a8062f,0xca7402d3,0xdb040200,0x225800d7}},	//   jden, _ኢልኩም_, _jakë, šsky_, 
   {{0x7dd0049f,0x63a80630,0x1dd00037,0x00000000}},	//   _fäst, dden, _हवात, --, 
   {{0x7dd00631,0x63a80632,0xdb040200,0x74140633}},	//   _gäst, eden, _lakë, کوبا, 
   {{0x7dd00634,0x63a801f5,0x2874010b,0x34940635}},	//   _häss, fden, _пытр, хайр, 
   {{0x63a80226,0xb9e8044e,0xdef4001f,0xb6c80014}},	//   gden, _ኮም_, ፉልን_, _ٹارے_, 
   {{0x3a380636,0x6288017a,0x6aa8032e,0x826001c8}},	//   _kirp_, gteo, _áeft, نهين, 
   {{0x7dd00637,0x63a80638,0x764002d0,0x80a40154}},	//   _mäss, aden, _iumy, গমন্, 
   {{0x7dd00639,0x63a8063a,0xc054063b,0x7760025c}},	//   _läss, bden, мія_, _kemx, 
   {{0xdb040200,0x6aac0162,0x95980092,0x63a80139}},	//   _cakë, yvaf, ፊዎችን_, cden, 
   {{0x6288063c,0x7dd0063d,0x6b8c05ac,0x68e4003e}},	//   cteo, _näss, vfag, zzhd, 
   {{0x7640063e,0x6014003a,0xfe24009d,0x00000000}},	//   _mumy, dámu, вьсн, --, 
   {{0x3b4c063f,0x7640007f,0xab940640,0x7dd00641}},	//   _ọdịk, _lumy, нављ, _räst, 
   {{0xdb0400f2,0x2ba80642,0x7dd00112,0x00000000}},	//   _kakè, _चोखा, _bäss, --, 
   {{0x7dd00643,0x69c40644,0x76400153,0x0dc800f3}},	// [390] _päst, tjhe, _numy, _дуни_, 
   {{0x6b8c0645,0x63a80646,0xdb240647,0xdb0402e2}},	//   sfag, zden, رولی, _makè, 
   {{0x7dd004f3,0x7760009a,0x63a80648,0x61ec0649}},	//   _väst, _bemx, yden, _ïale, 
   {{0x5ec4045e,0x7640064a,0x7dd00065,0x2ca4022c}},	//   _লেটে, _bumy, _fäss, ældu_, 
   {{0x7dd0064b,0x389000e2,0x6014003a,0xf4140154}},	//   _täst, vērš_, cámu, াগার_, 
   {{0xd124064c,0x3a38062c,0x00000000,0x00000000}},	//   _مم_, _girp_, --, --, 
   {{0x63a800a2,0x23d4064d,0x2a68030a,0x7dd0013d}},	//   tden, ецпр, lsab_, _käsr, 
   {{0x63a803bd,0x33f4064e,0x60140419,0x00000000}},	//   uden, кчыс, námt, --, 
   {{0x2a68064f,0x7dd00139,0x76400064,0xe2980120}},	//   nsab_, _mäsr, _gumy, чап_, 
   {{0x62880650,0xdb040100,0x21a401c0,0x00000000}},	//   rteo, _dakè, хиом, --, 
   {{0x62880651,0x63a80652,0xdb0402d3,0x764000ca}},	//   steo, pden, _pakë, _zumy, 
   {{0x64400653,0x65600654,0x2a6800af,0x63a80007}},	//   _iuli, _helh, ksab_, qden, 
   {{0x64400655,0x65600656,0x201c00da,0x2a680218}},	//   _huli, _kelh, ēti_, jsab_, 
   {{0x3f84003d,0x7dd000fd,0xdca40657,0x6560062c}},	//   żmu_, _räss, наги, _jelh, 
   {{0x65600658,0x64400659,0xdb040200,0x00000000}},	//   _melh, _juli, _takë, --, 
   {{0x6440065a,0x3a38065b,0xdb04065c,0x6560065d}},	//   _muli, _sirp_, _haké, _lelh, 
   {{0x6440065e,0xdb040066,0x9b0401e0,0x89d4065f}},	// [3a0] _luli, _kaké, хзад, کولر_, 
   {{0xdb040316,0x64400660,0x7dd001e3,0x76400661}},	//   _jaké, _ouli, _väss, _rumy, 
   {{0x64400662,0xdb040663,0x2ca400b5,0xbc740150}},	//   _nuli, _maké, ældt_, _جۇزب, 
   {{0x7dd00664,0x2a680218,0x3a380309,0x2b480665}},	//   _täss, bsab_, _wirp_, ccac_, 
   {{0x64400666,0x65600667,0x00000000,0x00000000}},	//   _auli, _belh, --, --, 
   {{0x64400668,0xdb040669,0xf484030f,0x99140006}},	//   _buli, _rakè, نابی, _зьбі, 
   {{0x65600652,0x6014066a,0xdb040214,0x6aa802d2}},	//   _delh, náms, _sakè, _áefr, 
   {{0x6440066b,0x7640014a,0xdb0402bd,0x6560066c}},	//   _duli, _tumy, _pakè, _eelh, 
   {{0x6560066d,0x6440066e,0x8a100014,0x5184066f}},	//   _felh, _euli, _شِہت, нуна, 
   {{0x64400670,0x65600671,0x8e700672,0x82300133}},	//   _fuli, _gelh, ққош, ێریا, 
   {{0x91a4063f,0xdb04020c,0xa64c0023,0xfbe000cd}},	//   _atọ_, _daké, _ዝተዓደ, नसाम, 
   {{0x04d80302,0xdb040066,0x656001a4,0x7de401ec}},	//   _מקבל, _takè, _zelh, ңірд, 
   {{0x64400673,0xa3d4033d,0xbed8030d,0x9f4001f4}},	//   _zuli, _सकत_, едях_, ynkö_, 
   {{0x2d840674,0x00000000,0x00000000,0x00000000}},	//   üle_, --, --, --, 
   {{0x64400675,0xd12c0014,0xac180676,0x02140677}},	//   _xuli, _دۅد_, дову_, _רחום_, 
   {{0xfba80678,0x00000000,0x00000000,0x00000000}},	//   нтуй_, --, --, --, 
   {{0x2b480113,0xdec000c7,0x2a680100,0x00000000}},	// [3b0] rcac_, _кәро, usab_, --, 
   {{0xc8640679,0x5e140022,0x2b4801e4,0x2a680205}},	//   етди, _изыӡ, scac_, rsab_, 
   {{0xd364067a,0x2a68067b,0x6560067c,0x6b7405a2}},	//   _په_, ssab_, _relh, _илну, 
   {{0xed78067d,0x6560067e,0x6440067f,0x2a680254}},	//   _እምበር_, _selh, _ruli, psab_, 
   {{0x64400680,0x65600681,0xd2440682,0x7dd00254}},	//   _suli, _pelh, _خن_, _käsp, 
   {{0x65600455,0xe894035b,0x7dd001f4,0x00000000}},	//   _qelh, _иагь, _jäsp, --, 
   {{0x65600683,0xdb040684,0x64400685,0x2eb802f5}},	//   _velh, _raké, _quli, ুনিষ, 
   {{0x64400686,0xdb040687,0x7dd00267,0x65600688}},	//   _vuli, _saké, _läsp, _welh, 
   {{0x9f40044e,0x65600689,0xdb04068a,0x6440068b}},	//   shkë_, _telh, _paké, _wuli, 
   {{0x6560068c,0x7dd0007c,0xc1000166,0x00000000}},	//   _uelh, _näsp, лүлл, --, 
   {{0x6440068d,0x00000000,0x00000000,0x00000000}},	//   _uuli, --, --, --, 
   {{0x2258068e,0x00000000,0x00000000,0x00000000}},	//   _жиды_, --, --, --, 
   {{0x3f8c068f,0xdb0401f1,0x2d90017a,0x73c4007b}},	//   ędu_, _také, ffze_, _حينم, 
   {{0xd24c0690,0xa0c40691,0x00e001d3,0xe9f800e4}},	//   _بنو_, _ليتو, _متعی, tvẽ_, 
   {{0xa0a40692,0xa3d4033f,0xdcb000d1,0x6aa800de}},	//   _райд, _सका_, جىز_, _šefp, 
   {{0xd00c0693,0x8d740014,0x00000000,0x00000000}},	//   _ولو_, _یاپا, --, --, 
   {{0x9f440694,0xd9440695,0xdb200205,0x00000000}},	// [3c0] _ñoñ_, вези, _ütüy, --, 
   {{0x1c440696,0xc0f40023,0x7dd001e3,0xdcec0205}},	//   _ином, _ዋላስ_, _gäsp, şkıs, 
   {{0x1d080697,0x8dd8011a,0x6cb801af,0x00000000}},	//   _цени_, _חקיק, _зыяр_, --, 
   {{0x6298002d,0x200004ce,0x00000000,0x00000000}},	//   _opwo, nnki_, --, --, 
   {{0x68e00037,0x4cd40011,0xc62005ac,0x20000698}},	//   _üldn, _ডেপু, _পঢ়া_, inki_, 
   {{0xd9440063,0x00000000,0x00000000,0x00000000}},	//   _јеви, --, --, --, 
   {{0x62980699,0xbf000034,0x0460069a,0x44a0069b}},	//   _apwo, ैथुन_, атым, لموق, 
   {{0xc0d4069c,0x601400e5,0x71740066,0x00000000}},	//   ኮነስ_, zámr, گهدا, --, 
   {{0xdb0400d2,0xd20805f5,0x6f08033f,0x8c1804ae}},	//   _inkó, дэнд_, żecz, ווקי, 
   {{0xb9cc0023,0xba08069d,0x14c800c7,0xc0540092}},	//   _ዳአ_, _ፋና_, _ҭыҧи_, _የተቸገ, 
   {{0x6298069e,0xdb0403fa,0x066c0131,0x00000000}},	//   _epwo, _ankü, ﭽﯩﻠﯩ, --, 
   {{0xb4c0069f,0x543406a0,0x00000000,0x00000000}},	//   ुही_, _شرار, --, --, 
   {{0xf19406a1,0xd33402d5,0x00000000,0x00000000}},	//   _биль, _рэжы, --, --, 
   {{0x200006a2,0x33780150,0x00000000,0x00000000}},	//   anki_, _ﭼﻴﻠﻲ_, --, --, 
   {{0x61ec06a3,0x709406a4,0x9f400118,0xd7e001f9}},	//   _ïala, _сайф, liký_, पसाच, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3b6402e8,0x7b640354,0xeb980209,0x7c340150}},	// [3d0] ръсв, ртсе, миң_, ретх, 
   {{0x601406a5,0x00000000,0x00000000,0x00000000}},	//   lámp, --, --, --, 
   {{0xdd900014,0x00000000,0x00000000,0x00000000}},	//   _اوپ_, --, --, --, 
   {{0xba2800d1,0xc7b801f4,0x00000000,0x00000000}},	//   ىسەم_, ьёз_, --, --, 
   {{0x3a7406a6,0xd1c40023,0xa5f80107,0x00000000}},	//   _кляр, ሽሓት_, неду_, --, 
   {{0x28f8035b,0xa82403e6,0xf6500244,0x16a406a7}},	//   _зегь_, _ڵکان, زئه_, увши_, 
   {{0x20000034,0x62980076,0x478806a8,0x02d800dc}},	//   ynki_, _spwo, _осам_, यन्न, 
   {{0x3d3c06a9,0x778400db,0xe284011c,0xf77006aa}},	//   וגוס, _ەجەك, глии, _واق_, 
   {{0xba080020,0x23c406ab,0x614406ac,0x21680116}},	//   _ገቢ_, वाबद, лепа, нипи_, 
   {{0x85b806ad,0xa3b40220,0xa1c400d8,0x00000000}},	//   _تارس_, _әбді, убод, --, 
   {{0x20d40046,0xf4840006,0x00000000,0x00000000}},	//   уіпс, _вучн, --, --, 
   {{0xb2240137,0xd24c05a9,0x00000000,0x00000000}},	//   лмөл, زچۇ_, --, --, 
   {{0xf1a803e6,0xe29806ae,0x2000012d,0x91e000cc}},	//   رایه_, _чал_, rnki_, _পদৰ্, 
   {{0x200001fa,0x326400d1,0xdb1c06af,0x00000000}},	//   snki_, _өтәв, _éxéc, --, 
   {{0xa07400c7,0x597401ec,0x00000000,0x00000000}},	//   _сылш, ғызу, --, --, 
   {{0x1d08010b,0x307406b0,0x00000000,0x00000000}},	//   _җеми_, _тушс, --, --, 
   {{0xdb04033b,0x8f980677,0x00000000,0x00000000}},	// [3e0] _ankò, _טיקי, --, --, 
   {{0x2f1c01d3,0x80a4000d,0x00000000,0x00000000}},	//   ságú_, _औनाइ, --, --, 
   {{0x68e00037,0x00000000,0x00000000,0x00000000}},	//   _üldl, --, --, --, 
   {{0xd708034b,0x80a806b1,0x00000000,0x00000000}},	//   ннее_, _जनने, --, --, 
   {{0xdb0402e2,0xcc3800c8,0x00000000,0x00000000}},	//   _enkò, _רעכט, --, --, 
   {{0xe9380131,0x94a800c7,0x394c03e0,0x0f3400df}},	//   رسەت_, етиа_, _üds_, ארנט_, 
   {{0x24640022,0x00000000,0x00000000,0x00000000}},	//   ахыҳ, --, --, --, 
   {{0xb27406b2,0xedd00316,0x752400bc,0x27b400d8}},	//   алиш, _सक्छ, řizo, _кљус, 
   {{0xd620030d,0x00000000,0x00000000,0x00000000}},	//   _дiаа, --, --, --, 
   {{0xb6a406b3,0xbbe000bc,0x00000000,0x00000000}},	//   _йиғл, नसुक, --, --, 
   {{0x50640220,0x335400db,0x70940107,0x569400fb}},	//   ытпа, _күйө_, шанф, _шаҡт, 
   {{0x7528005f,0x9f4001d3,0x8934010f,0x6fd401f9}},	//   _izdz, dikó_, טריע_, _ढवळू, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc330010f,0x0d9001d3,0x0dc806b4,0x00000000}},	//   _פוס_, حیدح, хуми_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xeeb806b5,0x00000000,0x00000000,0x00000000}},	//   _алиш_, --, --, --, 
   {{0xf33002d3,0xab3801ec,0x9fb40055,0x00000000}},	// [3f0] _ብትብዓ, тпау_, cāñ_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa3d4033d,0xf98806b6,0x290401ef,0x00000000}},	//   _सकल_, انمي_, _žlab_, --, 
   {{0x68e00037,0x00000000,0x00000000,0x00000000}},	//   _üldm, --, --, --, 
   {{0xe61006b7,0xa6340212,0x872801d5,0x00000000}},	//   يشت_, анді, хўжа_, --, 
   {{0xdb0406b8,0xd1dc0020,0x1d680092,0x8934009f}},	//   _fakâ, ንበብ_, ቲስቶች_, _معزا, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe298013e,0x6d4006b9,0xe8e00490,0xe3b8014b}},	//   ваи_, ılay, पनीच, тби_, 
   {{0xdb040109,0x7cc406ba,0xf65000db,0x00000000}},	//   _zakâ, ﺯﻣﯘﻧ, _فئل_, --, 
   {{0x846406bb,0xdb0400e4,0x6728005f,0xe80c012c}},	//   _бъде, _hakã, _izej, िकका_, 
   {{0x23c406bc,0x3494010b,0xe10806bd,0x6f0c06be}},	//   वादद, _гахр, тенд_, _axac, 
   {{0x229406bf,0xa27806c0,0x442406c1,0x00000000}},	//   _видя, _абду_, _صراف, --, 
   {{0x61ec03a2,0xe1f006c2,0x2ec000c7,0x00000000}},	//   _ïalo, _وست_, зҩым, --, 
   {{0x5f7406c3,0xf274009f,0x00000000,0x00000000}},	//   داگر, _اَوھ, --, --, 
   {{0xdca406c4,0xd00c00ec,0x30b401e2,0x00000000}},	//   шави, _ڪلي_, _هلوځ, --, 
   {{0x3cec0208,0xd12c06c5,0x00000000,0x00000000}},	//   _đkvđ_, _غمي_, --, --, 
  
   {{0x68e000c5,0xdb0406c6,0xd00c06c7,0x00000000}},	// [400] _üldj, _sakâ, _تلي_, --, 
   {{0x7e6406c8,0xad2400d1,0x00000000,0x00000000}},	//   _iwip, _گىپى, --, --, 
   {{0x18a406c9,0x6fa803d4,0x00000000,0x00000000}},	//   раем, গাৰে, --, --, 
   {{0x7e6406ca,0x00000000,0x00000000,0x00000000}},	//   _kwip, --, --, --, 
   {{0x7e64009f,0xdcfc00d0,0x00000000,0x00000000}},	//   _jwip, _napĺ, --, --, 
   {{0xd49806cb,0x5d7804ac,0x7e6400ca,0x6728005f}},	//   ври_, דאַק, _mwip, _dzej, 
   {{0x1ccc038f,0x672806cc,0xdb040109,0x186806cd}},	//   ྱའི_, _ezej, _hakà, _шави_, 
   {{0x7f44013e,0x00000000,0x00000000,0x00000000}},	//   _ngiq, --, --, --, 
   {{0x67280327,0x00000000,0x00000000,0x00000000}},	//   _gzej, --, --, --, 
   {{0x7f44003a,0x00000000,0x00000000,0x00000000}},	//   _agiq, --, --, --, 
   {{0x7e640227,0x461006ce,0x67280327,0x301406cf}},	//   _awip, _بولر, _zzej, йдор, 
   {{0xa4d400db,0x88480023,0x00000000,0x00000000}},	//   _уюуш, _ንነብሰ, --, --, 
   {{0xdb0405da,0x227806d0,0x9f4002e2,0x3f140395}},	//   _nakà, _ملنگ_, tikò_, ждяс, 
   {{0x7e6406d1,0x271401fb,0xfd4406d2,0x8d8406d3}},	//   _dwip, ềng_, жэтн, шумд, 
   {{0x308400c6,0xbc4806d4,0xdcfc00d7,0x00000000}},	//   _العف, ичте_, _zapĺ, --, 
   {{0x80a80490,0x7ff4007b,0x8d780092,0x00000000}},	//   _जनते, _وسيا, ርሳቸው_, --, 
   {{0x6e9406d5,0x7e6405c7,0xdb0400c7,0xbea800ec}},	// [410] _الخا, _gwip, _rakã, _نهين_, 
   {{0x68e000af,0x3978029c,0xdb040022,0x00000000}},	//   _üldk, لصمد_, _sakã, --, 
   {{0x7e6406d6,0x6d4406d7,0x5c30036b,0x672806d8}},	//   _zwip, _igha, تکیز, _szej, 
   {{0xdb0406d9,0xddd4010e,0x27680214,0xef18031c}},	//   _fakà, _atyň, اشای_, żżu_, 
   {{0x23c4024a,0xd7e800cf,0x00000000,0x00000000}},	//   वासद, دونۇ_, --, --, 
   {{0xa50806da,0x6d440135,0xe5a406db,0x625806dc}},	//   лела_, _jgha, сики, қрир_, 
   {{0x6d4406dd,0x00000000,0x00000000,0x00000000}},	//   _mgha, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69d406de,0x316c06df,0x6d4406e0,0x02c401b9}},	//   _koze, fadz_, _ogha, рқли_, 
   {{0x6d4406e1,0x69d406e2,0x27fc00a9,0xbbd406e3}},	//   _ngha, _joze, liwn_, _धक्क, 
   {{0x7e6406e4,0xdb04043b,0xa87800c8,0xc3400408}},	//   _swip, _maká, װאָר, _мĕн_, 
   {{0x6d4406e5,0xdb0406e6,0x312400f7,0x27fc015d}},	//   _agha, _laká, өдөг, niwn_, 
   {{0xfe7806e7,0x6d4406e8,0x26dc009a,0x69d402d0}},	//   шүп_, _bgha, nywo_, _ooze, 
   {{0x69d406e9,0x442c00a2,0x27fc0142,0xbbe000cd}},	//   _noze, _hhg_, hiwn_, नस्क, 
   {{0x6d44031c,0xe05400c6,0x68e000c5,0x63ac06ea}},	//   _dgha, _اختب, _üldh, _óans, 
   {{0x69d403bd,0x7e6406eb,0x442c032e,0x21e800d7}},	//   _aoze, _twip, _jhg_, _dúhe_, 
   {{0x69d406ec,0x4a4006ed,0x27fc015d,0x24980092}},	// [420] _boze, знув, diwn_, _መክሊት_, 
   {{0x69d406ee,0xdb0400d2,0x3ea00086,0x442c032e}},	//   _coze, _caká, _ipit_, _lhg_, 
   {{0x442c06ef,0xc310009e,0x97d800c0,0x27fc0042}},	//   _ohg_, াইটি_, льду_, fiwn_, 
   {{0x69d406f0,0x263c0030,0x442c06f1,0x6d440003}},	//   _eoze, _dňom_, _nhg_, _zgha, 
   {{0x236c0399,0x7c2406f2,0x224c0327,0x8c18011a}},	//   daej_, mlir, jqek_, _תוכי, 
   {{0x7c2406f3,0xd1dc0125,0x69d406f4,0x3ea005da}},	//   llir, ንበት_, _goze, _mpit_, 
   {{0x442c06f5,0x3ea00295,0xa8a406f6,0x27fc015d}},	//   _bhg_, _lpit_, _وصفو, biwn_, 
   {{0xdb0403c6,0x73d806f7,0x938806f8,0x325406f9}},	//   _zaká, рдир_, уска_, овир, 
   {{0x316c06fa,0x69d406fb,0xdb040621,0x7c240332}},	//   tadz_, _yoze, _enkö, ilir, 
   {{0x442c0175,0x7c24022e,0x1ad403d4,0xf8dc043e}},	//   _ehg_, hlir, _সেৱা, _यथाय, 
   {{0x316c06fc,0x3ea006fd,0xe80c0073,0x46100133}},	//   radz_, _apit_, िकचा_, _عومر, 
   {{0x442c0280,0x316c0419,0x68e8013a,0x73c401af}},	//   _ghg_, sadz_, _ředk, _фәке, 
   {{0xc0e406fe,0x316c003e,0x74b806ff,0x00000000}},	//   لفین_, padz_, ्मवृ, --, 
   {{0x94240131,0x6d440327,0x799c02d0,0xf15801e0}},	//   _ئوچۇ, _qgha, _nbrw, _тикш_, 
   {{0x3ea00700,0x818402de,0x70540244,0x442c010b}},	//   _epit_, _انىق_, _بنبا, _yhg_, 
   {{0x68e0007d,0x69d400a2,0xdb040701,0x00000000}},	//   _üldi, _soze, _saká, --, 
   {{0x69d40702,0x6d440703,0x2d84067c,0xdb0401ef}},	// [430] _poze, _tgha, òles_, _paká, 
   {{0x6d440704,0x799c03ac,0x7c240705,0x6d980108}},	//   _ugha, _cbrw, alir, _твоё_, 
   {{0xdb040706,0x69d40707,0xd1500023,0x51780092}},	//   _vaká, _voze, _ዘጠቓል, _በአንተ_, 
   {{0x69d40708,0x799c0042,0x80a80709,0xe50c00bc}},	//   _woze, _ebrw, _जनसे, ाअघि_, 
   {{0x69d4070a,0xdb04070b,0x61e00113,0x442c0142}},	//   _toze, _taká, ykll, _rhg_, 
   {{0x27fc00a9,0x442c070c,0x799c03ac,0xd6cc01c8}},	//   siwn_, _shg_, _gbrw, ئقو_, 
   {{0x442c070d,0xd1e8001f,0x2bfc00cd,0x5450070e}},	//   _phg_, ሆኑት_, _एषां_, үвәт, 
   {{0xe788004b,0x61e00113,0xc2b002dd,0xf7940064}},	//   _خپره_, wkll, зөкш, _насэ, 
   {{0x2be0070f,0xd7e800d1,0xb5c80345,0x00000000}},	//   _नवना, _ئوقۇ_, _گولم_, --, 
   {{0xe1f80710,0x21a400f7,0x442c0711,0xbb3c008f}},	//   рго_, циом, _whg_, נעזי, 
   {{0x3ea00712,0x60080713,0xa068026a,0x04b40050}},	//   _spit_, ином_, јама_, _دپاں_, 
   {{0xd9a40714,0x7a300715,0x3ea004e6,0x00000000}},	//   _ऑस्ट, mäte, _ppit_, --, 
   {{0x7a300716,0xa490004b,0xfbcc03d4,0x224c031c}},	//   läte, _ریښت, ৰোঁত, qqek_, 
   {{0x6b9c02d0,0x81bc0154,0x9f400108,0x00000000}},	//   _absg, ীসহ_, kikö_, --, 
   {{0x7a300717,0xdb040139,0x7dd0013d,0x7c240718}},	//   näte, _kakç, _mäsx, tlir, 
   {{0x1ae40719,0x7c24071a,0x799c02d0,0x717000db}},	//   ообм, ulir, _sbrw, _قۇۋا, 
   {{0x3ea0071b,0x533404ac,0x9e64071c,0x7c24071d}},	// [440] _upit_, ַנען_, _باعن, rlir, 
   {{0xa2b0071e,0x7a30071f,0x99880024,0x27ec031c}},	//   _अनन्, käte, _ribų_, _ċena_, 
   {{0x9b440720,0x0d200372,0x7c240721,0xd00c0424}},	//   _وندو, _жүрү, plir, _سلی_, 
   {{0x77940722,0x7a300723,0x6abc0334,0x7c24022e}},	//   ثیرا, däte, _frsf, qlir, 
   {{0xdb040194,0xc7a006ed,0xd6d000f2,0x00000000}},	//   _sakæ, ќичк, بقش_, --, 
   {{0xdcec0205,0x88c401ef,0x7a30013d,0x27300137}},	//   lebı, _spěš, fäte, رۉلس, 
   {{0xdb040724,0xe9700725,0xd14801b9,0x14c80108}},	//   _bakç, _سۇند, یشدن_, рыли_, 
   {{0x7dd002f6,0xd6a80214,0x9998007f,0x942000db}},	//   _väsy, _پدرم_, wopň_, بوعۇ, 
   {{0xd1c8035b,0x7dd00166,0x95c801f4,0x00000000}},	//   аунд_, _fäsx, _клаб_, --, 
   {{0x68e8012c,0x2be00034,0x69cc0316,0x7a30008e}},	//   _ředi, _नवभा, सायी, bäte, 
   {{0xc9500302,0x26c000b0,0x7a300139,0x00000000}},	//   ומת_, āhoe_, cäte, --, 
   {{0x784c044e,0x68300726,0x386c01bf,0x80a80027}},	//   _ብኣንጻ, rådg, _ædru_, _जनरे, 
   {{0xdb040054,0x68e00037,0x37bc0154,0x614000c7}},	//   _jakä, _üldv, _অকার, мҵәа, 
   {{0x68300450,0x9f4001f4,0x01a40153,0x00000000}},	//   måde, yikö_, _мкчк_, --, 
   {{0xad240727,0x68300728,0x661c02d2,0xec240116}},	//   سىرى, låde, _íske, كىسپ, 
   {{0x06c00729,0x3eb0049b,0xaa5402e8,0x9f4001f4}},	//   ্নতি, ältä_, зваш, vikö_, 
   {{0x1618072a,0x201000d0,0x6830072b,0xe978072c}},	// [450] धवार_, ézie_, nåde, йбаш_, 
   {{0xf41003d4,0x9f400108,0xba4400c0,0x00000000}},	//   াতিৰ_, tikö_, _šįry, --, 
   {{0xa8980220,0x6d540034,0x7f84072d,0x00000000}},	//   скеу_, mcza, _علین, --, 
   {{0x27e801ed,0x6d54033f,0x8038008f,0xdb04007c}},	//   óan_, lcza, ַנגע_, _bakä, 
   {{0xf1bc072e,0x6b8c072f,0x9f4002f6,0xabb40022}},	//   ्ञान, mgag, sikö_, _даҟә, 
   {{0x7a300730,0x6b8c0731,0x6aac0732,0xe2980032}},	//   täte, lgag, mwaf, ҡай_, 
   {{0x7d1800fe,0x69cc0490,0x15400733,0x6aac04ba}},	//   _øvst, साठी, нешм, lwaf, 
   {{0x6b8c0734,0x7a300735,0x6aac01f7,0xa3b80736}},	//   ngag, räte, owaf, صابر_, 
   {{0x7a300737,0xe1f80209,0x68300738,0x651401ed}},	//   säte, йги_, rådd, _کوائ, 
   {{0xc4c4023f,0x7a300739,0x6b8c073a,0xf4840116}},	//   _وتاو, päte, hgag, чуән, 
   {{0x6d54068f,0x6aac073b,0x6b8c073c,0xc614073d}},	//   dcza, hwaf, kgag, दकीय_, 
   {{0x6aac013b,0x683000b5,0x6d54033f,0xdd90073e}},	//   kwaf, både, ecza, کوس_, 
   {{0x63a8073f,0x33f40740,0xdea0036b,0x24500741}},	//   meen, _تسلس, ریدی, _hám_, 
   {{0x63a80742,0x6b8c0083,0x52d4011a,0x00000000}},	//   leen, egag, _מונע_, --, 
   {{0x71f80743,0x24500744,0x628801f4,0x00000000}},	//   _برنس_, _jám_, lueo, --, 
   {{0x24500745,0x6b8c0746,0x2f1402e3,0x6d540747}},	//   _mám_, ggag, ụga_, acza, 
   {{0x20000748,0x1fd000cc,0xdcec03e0,0x6d540210}},	// [460] miki_, াসদস, rebı, bcza, 
   {{0x63a80749,0x4ef80375,0xdb040022,0x6b8c074a}},	//   heen, _להפו, _rakä, agag, 
   {{0x2450074b,0x63a8074c,0xf1d001fb,0x4dd80375}},	//   _nám_, keen, _hạch_, _החיו, 
   {{0x6b8c074d,0x63a8074e,0xb8d4074f,0x00000000}},	//   cgag, jeen, _झन_, --, 
   {{0x63a80750,0xdb0401e6,0x20000270,0x1a640133}},	//   deen, _bakå, iiki_, _ریای_, 
   {{0x20000751,0xf1d00016,0x2450001e,0x9b44009f}},	//   hiki_, _mạch_, _bám_, _ونگو, 
   {{0x24500016,0x63a80752,0xddd400b8,0x05700753}},	//   _cám_, feen, _avyū, راود, 
   {{0x63a80754,0x24500755,0x6d54068f,0x20000756}},	//   geen, _dám_, zcza, jiki_, 
   {{0x20000757,0x6d54068f,0xd14801b9,0x00000000}},	//   diki_, ycza, یشگن_, --, 
   {{0x200003a0,0xe56000d7,0x6b8c022e,0x00000000}},	//   eiki_, _päťč, zgag, --, 
   {{0x20000758,0x63a80759,0x92bc00bd,0x68e000c5}},	//   fiki_, been, ীনে_, _üldt, 
   {{0x63a80429,0x2000075a,0xf1d00016,0x6d540034}},	//   ceen, giki_, _bạch_, wcza, 
   {{0xf194075b,0xf1d00208,0x92d800fe,0x00000000}},	//   _жиль, _cạch_, _ডেৰ_, --, 
   {{0x20000270,0x752400bc,0x7e440354,0x00000000}},	//   aiki_, řizu, ехсе, --, 
   {{0x2000075c,0x6d540034,0x245001fb,0x1b58063f}},	//   biki_, rcza, _xám_, _ọnụm, 
   {{0x6aac016b,0x2000075d,0x7f84075e,0x6d40022e}},	//   twaf, ciki_, _كلىن, оlar, 
   {{0x6b8c075f,0xf1d0001e,0xe1e80050,0xdb14007f}},	// [470] rgag, _gạch_, _دى۪و_, ndyè, 
   {{0x2fc801d4,0x6aac0230,0x63a80760,0x78700022}},	//   _hnag_, rwaf, zeen, _ẽvae, 
   {{0x63a80761,0x6aac0762,0x67d40763,0x6fd00764}},	//   yeen, swaf, можу, धापू, 
   {{0x24500765,0x63a80766,0x6aac0767,0x00000000}},	//   _rám_, xeen, pwaf, --, 
   {{0x24500232,0x63a80768,0x0ae80769,0x00000000}},	//   _sám_, veen, _طرحي_, --, 
   {{0x63a8076a,0x64a4076b,0xae1c01ad,0x2fc801e7}},	//   ween, дака, पकिन_, _lnag_, 
   {{0x63a8076c,0x2000076d,0x2bd0076e,0xb7c800f7}},	//   teen, yiki_, हापा, تبەك_, 
   {{0x2450076f,0x2fc80770,0x7a300771,0x320c0109}},	//   _vám_, _nnag_, mäta, endy_, 
   {{0x20000772,0x63a80773,0x27ec0774,0x65840022}},	//   viki_, reen, _ilen_, _ҕыҕз, 
   {{0x13040775,0x63a80776,0x2fc80777,0x68e0007d}},	//   ьный_, seen, _anag_, _ülds, 
   {{0xf1d00016,0x2fc801c3,0x63a80778,0x7a30014a}},	//   _sạch_, _bnag_, peen, näta, 
   {{0x2fc80779,0x63a80429,0x320c00c7,0x9f4001f4}},	//   _cnag_, qeen, andy_, yhkä_, 
   {{0x6288077a,0x2fc8077b,0x784c05d1,0x02a402e8}},	//   queo, _dnag_, _işve, _хрем, 
   {{0xdca4077c,0x7a30077d,0xb8e00135,0xf1d0001e}},	//   маги, käta, _ཀླ_, _vạch_, 
   {{0x27ec077e,0x2000077f,0x7a3001f4,0x5bb401f0}},	//   _olen_, piki_, jäta, мсаф, 
   {{0x7a300780,0xfcd00023,0xf1d00208,0xbb500220}},	//   däta, _ብደገ_, _tạch_, _ﺎﻨﻲ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [480] --, --, --, --, 
   {{0xbe3400db,0x00000000,0x00000000,0x00000000}},	//   _سۉزب, --, --, --, 
   {{0x2fc80781,0x16c40782,0x27ec0783,0x9f400784}},	//   _ynag_, लम्ब, _blen_, shkä_, 
   {{0x9d9801c8,0x00000000,0x00000000,0x00000000}},	//   _انھئ_, --, --, --, 
   {{0xdb040022,0x1ccc031c,0x00000000,0x00000000}},	//   _lakú, ྱའམ_, --, --, 
   {{0x7ae40223,0x1868020f,0xdcfc03e0,0x00000000}},	//   myit, _маги_, _hapı, --, 
   {{0x27ec0785,0xdcfc0365,0xc9240786,0xdb040030}},	//   _flen_, _kapı, _жорж_, _nakú, 
   {{0x27ec0787,0x7ae40788,0x21e80789,0x2bd0078a}},	//   _glen_, oyit, _búho_, हाया, 
   {{0x5184078b,0x2fc8078c,0x68e00037,0x00000000}},	//   муна, _rnag_, _üldr, --, 
   {{0x2fc8078d,0x2258078e,0x978c0354,0x672c0210}},	//   _snag_, íska_, _гiур_, żajc, 
   {{0x764801e2,0x27ec02f6,0x68300267,0x7ae4078f}},	//   _iidy, _ylen_, låda, hyit, 
   {{0x33b40014,0xd24c01d9,0x926806ed,0xdcfc0790}},	//   _سٕتر, _پۆد_, _дрка_, _napı, 
   {{0x201000d0,0x6830007c,0x00000000,0x00000000}},	//   ézia_, nåda, --, --, 
   {{0x7a300227,0x2f14063f,0xdb040419,0x00000000}},	//   yäta, ụgo_, _fakú, --, 
   {{0x76480791,0xd12c0014,0x7ae40337,0x2fc80332}},	//   _midy, _خۅد_, eyit, _tnag_, 
   {{0x68300267,0x76480792,0x7a300108,0x00000000}},	//   kåda, _lidy, väta, --, 
   {{0x2bd0033d,0xdb0401f1,0x3c440024,0x00000000}},	// [490] हाबा, _zakú, тэрв, --, 
   {{0x7a300793,0x27ec02d2,0x7bc002d2,0xa9c000db}},	//   täta, _slen_, _ómun, دۅسۉ, 
   {{0x27ec0794,0x3d100490,0x7ae40795,0x7994010b}},	//   _plen_, णपणे_, ayit, тихф, 
   {{0x7ae40796,0x7a300054,0x76480797,0x2b580798}},	//   byit, räta, _aidy, _ufsc_, 
   {{0xf7700799,0x7a30079a,0x7648079b,0x27ec02d3}},	//   شان_, mätn, _bidy, _vlen_, 
   {{0x7a30079c,0x8b940139,0x00000000,0x00000000}},	//   päta, _эрүч, --, --, 
   {{0xdcfc079d,0x7a300054,0x7648079e,0x24e8079f}},	//   _yapı, qäta, _didy, ямки_, 
   {{0xdb0401f1,0x1ad404c5,0x76480165,0x27ec07a0}},	//   _rakú, _সেয়া, _eidy, _ulen_, 
   {{0x764807a1,0x52a407a2,0x68e407a3,0x00000000}},	//   _fidy, евым_, lyhd, --, 
   {{0x67280022,0x764807a4,0xa4d40024,0x59d000bc}},	//   _iyej, _gidy, _позі, सायर, 
   {{0x67280263,0x68e4005b,0xa0c401f7,0x35d407a5}},	//   _hyej, nyhd, ريحو, _шофё, 
   {{0x6e24001f,0x76480161,0x672804ba,0x7ae407a6}},	//   _akhb, _zidy, _kyej, yyit, 
   {{0xdcb007a7,0xdb040248,0x63b803cb,0x59d000cd}},	//   گىز_, _fakù, _iawn, सामर, 
   {{0xf1d00016,0x7ae407a8,0x63b8003d,0x764807a9}},	//   _hạnh_, vyit, _hawn, _xidy, 
   {{0x229807aa,0x63b807ab,0x672807ac,0x98b80205}},	//   lèk_, _kawn, _lyej, yapı_, 
   {{0xdcfc00ac,0x195407ad,0x7ae4009a,0xef2002e3}},	//   _qapı, _ｋｅｎ_, tyit, ụzịa, 
   {{0xf1d007ae,0x2be007af,0x672806d9,0x229807b0}},	// [4a0] _mạnh_, _नवरा, _nyej, nèk_, 
   {{0xf1d007ae,0x7ae407b1,0x63b807b2,0x4b2000d4}},	//   _lạnh_, ryit, _lawn, умув, 
   {{0xdcfc07b3,0x672807b4,0x8d8402d3,0xdca407b5}},	//   _tapı, _ayej, _ንምባል_, _џами, 
   {{0x764802fa,0x672804ba,0x7ac400c7,0x2bd007b6}},	//   _sidy, _byej, _иҩба, हाणा, 
   {{0x22980214,0x76480042,0x6fd007b7,0xdb080254}},	//   jèk_, _pidy, धातू, önäi, 
   {{0x86c007b8,0x7a3000fd,0x683007b9,0x22980669}},	//   ايون, mäto, råda, dèk_, 
   {{0x764807ba,0x67280117,0x3f800268,0x68e000af}},	//   _vidy, _eyej, _odiu_, _üldp, 
   {{0x764807bb,0xf1d00016,0x6728036e,0xc0d80240}},	//   _widy, _cạnh_, _fyej, ሕኒሕ_, 
   {{0x764807a9,0x63b807bc,0x75280034,0x2bd00490}},	//   _tidy, _dawn, _wydz, हाता, 
   {{0xa2b007bd,0x3f8007be,0x75280034,0x6830050a}},	//   _अनर्, _adiu_, _tydz, nådn, 
   {{0x6814068f,0x63b807bf,0x823007c0,0xeb0c07c1}},	//   ląda, _fawn, دريا, _सख्त_, 
   {{0x63b80363,0x229807c2,0x20d40024,0xdb040162}},	//   _gawn, bèk_, džią_, _fakø, 
   {{0x91e407c3,0x1e70054a,0x22980066,0xd954001f}},	//   _поде, ағыс, cèk_, ውንታን, 
   {{0x92f007c4,0x3f8007c5,0xd174013d,0x68e40108}},	//   ığım, _ediu_, _чыды, yyhd, 
   {{0x63b80072,0xe57000c8,0x7c8407c6,0x7a30007c}},	//   _yawn, יַן_, луте, tätn, 
   {{0x7e0400db,0x00000000,0x00000000,0x00000000}},	//   _ۅسپۅ, --, --, --, 
   {{0xdb24072d,0x00000000,0x00000000,0x00000000}},	// [4b0] نوفی, --, --, --, 
   {{0x8fd001ee,0x00000000,0x00000000,0x00000000}},	//   _рәүә, --, --, --, 
   {{0xa77407c7,0x7a300724,0x2d8007c8,0x6728007f}},	//   влеч, mätl, _idhe_, _syej, 
   {{0x7a30013d,0x672807c9,0x2298034c,0xd12403e6}},	//   lätl, _pyej, yèk_, _ۆم_, 
   {{0x69c007ca,0xd12407cb,0x63b807cc,0x68e4005b}},	//   _óleo, _چم_, _rawn, syhd, 
   {{0xd12407cd,0x63b80399,0xe5a407ce,0x693407cf}},	//   _نم_, _sawn, тики, _ангу, 
   {{0x47880276,0x229800f2,0x64bc07d0,0x00000000}},	//   _нсам_, wèk_, ्मेश, --, 
   {{0xe79400dd,0x229807d1,0x7a300166,0x00000000}},	//   _جاسک, tèk_, hätl, --, 
   {{0x661c06ea,0x88b0015b,0x3f840321,0x45a007d2}},	//   _ísko, _টপিক, ómum_, _مەشك, 
   {{0x229807d3,0x2d800055,0x76b8030d,0x00000000}},	//   rèk_, _ndhe_, _ялур_, --, 
   {{0x63b807d4,0x3f800023,0xa06807d5,0x20100165}},	//   _tawn, _pdiu_, ьана_, ézio_, 
   {{0xdee407d6,0x229800f2,0xb22400cf,0xa07400db}},	//   воми, pèk_, кмөл, нгүч, 
   {{0x7a300166,0x80dc00fe,0xdcec07d7,0x00000000}},	//   fätl, _ফেশ্, dabā, --, 
   {{0x91e007d8,0x6288007b,0x7a3007d9,0x00000000}},	//   _воше, mreo, väto, --, 
   {{0x443c07da,0x3f80022e,0x1d08011c,0x00000000}},	//   omu_, _tdiu_, феви_, --, 
   {{0x2d8007db,0x443c07dc,0x63ac07dd,0x3f8007de}},	//   _edhe_, nmu_, _ñand, _udiu_, 
   {{0x443c07df,0x7a300724,0x628807e0,0x8eb00066}},	// [4c0] imu_, bätl, nreo, _نميش, 
   {{0x443c07e1,0x1868005b,0x628801e7,0x9c5800db}},	//   hmu_, дажи_, ireo, _ошму_, 
   {{0x443c07e2,0x81c0015b,0x9f0407e3,0x7a30005b}},	//   kmu_, _একা_, _سوگو, säto, 
   {{0x1cc007e4,0x628807e5,0x443c0216,0xd70807e6}},	//   _གླར_, kreo, jmu_, мнее_, 
   {{0x443c07e7,0x969406bb,0x75f4067c,0x7c2407e8}},	//   dmu_, треш, _làze, moir, 
   {{0x7c2407e9,0x09b00003,0x1dc0043e,0x661c032e}},	//   loir, _དྲྭ_, शयित, _ískl, 
   {{0x26d807ea,0x7c2401ab,0x00000000,0x00000000}},	//   _àson_, ooir, --, --, 
   {{0x7c2407eb,0x628807ec,0x938800f0,0x25a40142}},	//   noir, freo, фска_, _ebll_, 
   {{0x628807ed,0x98800118,0x427007ee,0x5fd400bc}},	//   greo, _míče_, агыс, धानल, 
   {{0x443c07ef,0x7c2407f0,0x00000000,0x00000000}},	//   amu_, hoir, --, --, 
   {{0x7c2407f1,0x6fb407f2,0x82d40327,0x443c07f3}},	//   koir, همدا, ྲྀཏའ, bmu_, 
   {{0x628807f4,0x25a807f5,0x130401af,0x443c06be}},	//   breo, đale_, _изем, cmu_, 
   {{0x7c2407f6,0x6ad007f7,0x2bd007f8,0xc014005b}},	//   doir, _सपेर, हासा, рмящ, 
   {{0x827404ac,0x80a8012c,0xdb0401a8,0x00000000}},	//   _יעדע_, _जनचे, _bakþ, --, 
   {{0x7c240597,0xfbc407b7,0xd01800f3,0xc0e0009b}},	//   foir, _लोहम, _офи_, _војк, 
   {{0x7c2407f9,0x0a6807fa,0x683000cc,0x00000000}},	//   goir, држи_, vådo, --, 
   {{0x3b5407fb,0x63ac0588,0xba7407fc,0x00000000}},	// [4d0] ркур, _ñane, لالت, --, 
   {{0x2d80036e,0x7c2401f4,0x7a300139,0x00000000}},	//   _udhe_, aoir, bätm, --, 
   {{0x443c07fd,0x7c2407fe,0xef10004b,0x6288030a}},	//   ymu_, boir, _خټک_, zreo, 
   {{0xe678005e,0x628807ff,0x7c240800,0x3b640801}},	//   ейді_, yreo, coir, _върв, 
   {{0xdb040432,0x443c0802,0x00000000,0x00000000}},	//   _kaký, vmu_, --, --, 
   {{0xdb04012c,0x443c0803,0xf62402bf,0x62880804}},	//   _jaký, wmu_, адіо, vreo, 
   {{0x443c0805,0xe3b000c6,0xbe9c01a9,0xf9640345}},	//   tmu_, مرة_, _ta談i, _ئۆمێ, 
   {{0x62880806,0x8d8402d3,0x1cc0025c,0x6934036b}},	//   treo, _ንዝብል_, _གླས_, _анҳу, 
   {{0x6ad00807,0x63b00010,0x32d402d5,0x6814012d}},	//   _सपोर, _čenč, ацэс, lądo, 
   {{0xe0d80808,0x62880809,0x7c24080a,0x00000000}},	//   ево_, rreo, zoir, --, 
   {{0x443c080b,0x7c24009f,0x6288080c,0x00000000}},	//   pmu_, yoir, sreo, --, 
   {{0x6288080d,0x7c24005a,0x7a3001f4,0x443c06be}},	//   preo, xoir, vätm, qmu_, 
   {{0x21a4080e,0x7c24080f,0xdb040432,0x784c06be}},	//   _билм, voir, _baký, _xğvq, 
   {{0x41b40764,0x7c240810,0xa0c40811,0x127800df}},	//   _असिस, woir, _ميتو, _טאנע, 
   {{0x7c240812,0xa0a40813,0x71240814,0xdb040432}},	//   toir, _сайд, _پرول, _daký, 
   {{0x0ca0044e,0xabf40815,0x9ad40816,0xd12c00ae}},	//   _ምግላጽ_, ачущ, люзі, _عمي_, 
   {{0x7c240817,0xdf480818,0x00000000,0x00000000}},	// [4e0] roir, _язид_, --, --, 
   {{0x7e640819,0x7c24081a,0xd944081b,0x00000000}},	//   _itip, soir, гези, --, 
   {{0x7c24081c,0x7a30081d,0x00000000,0x00000000}},	//   poir, lätk, --, --, 
   {{0x788003c6,0x38c801d5,0x661c02d2,0x00000000}},	//   _návš, _یازی_, _ískj, --, 
   {{0x2bd0081e,0x00000000,0x00000000,0x00000000}},	//   हारा, --, --, --, 
   {{0x1cc0081f,0x7e640161,0xda6400ec,0x00000000}},	//   _གློ_, _mtip, _لاڳي, --, 
   {{0x1cd80327,0x54a4007b,0x06c000cc,0x00000000}},	//   འདི_, احتف, ্নগি, --, 
   {{0x7e640820,0x7a30081d,0x00000000,0x00000000}},	//   _otip, kätk, --, --, 
   {{0x7a300821,0x00000000,0x00000000,0x00000000}},	//   jätk, --, --, --, 
   {{0x506401c0,0x7a300822,0x00000000,0x00000000}},	//   лтма, dätk, --, --, 
   {{0x7e640823,0x30140824,0x6ad00825,0xc0540826}},	//   _atip, идор, _सप्र, лія_, 
   {{0x1cc0025c,0x7a300139,0x00000000,0x00000000}},	//   _གླེ_, fätk, --, --, 
   {{0xb8d0031c,0x81e0015b,0x81c00154,0xdb040827}},	//   _ྐད_, _নগর_, _একর_, _makó, 
   {{0xdb0401ed,0x00000000,0x00000000,0x00000000}},	//   _lakó, --, --, --, 
   {{0x9f50007f,0x70940828,0xc98400d1,0x2bd00829}},	//   _olyè_, _тайф, ғузи, हाला, 
   {{0xdb040259,0x7a3001f1,0x49b8082a,0x7e64082b}},	//   _fakü, bätk, کارد_, _ftip, 
   {{0x69c0082c,0xdb0401f1,0x7b640354,0x62840055}},	// [4f0] _ólek, _taký, стсе, _āhok, 
   {{0x2c50033f,0x00000000,0x00000000,0x00000000}},	//   _sądu_, --, --, --, 
   {{0xdb040085,0x87e4082d,0x48a80024,0x00000000}},	//   _bakó, люде, этам_, --, 
   {{0xf868082e,0xaa94082f,0xdb040139,0x37740830}},	//   امني_, _кимч, _yakü, бышс, 
   {{0xc7900831,0xdae401ed,0xe9a801d9,0x5fd40073}},	//   арҙы, _پہلو_, _لگان_, धातल, 
   {{0xdb0c008c,0x2a68000d,0x65c4004e,0x00000000}},	//   _þjál, mpab_, рбка, --, 
   {{0x35f80832,0x7a3001f4,0x98f001e2,0x00000000}},	//   درند_, däth, _وګما, --, 
   {{0x69c80833,0xaac80834,0xe2840835,0x62d40836}},	//   _होती, रिपक, алии, لآخر, 
   {{0x22140837,0x620401b9,0xf3c800ae,0x00000000}},	//   ифор, аtlа, طبيه_, --, 
   {{0x7a3002f6,0xdb04007f,0x7e640166,0xa204004e}},	//   vätk, _kakò, _rtip, рпод, 
   {{0xa0a40838,0xdb0402bd,0x7e640839,0xf4840111}},	//   шанд, _jakò, _stip, _гучн, 
   {{0x7e64083a,0xdb04033b,0xf1a8083b,0x60240657}},	//   _ptip, _makò, پایه_, рдма, 
   {{0x236c047e,0xdb0402bd,0x3f8c083c,0xd1e80092}},	//   mbej_, _lakò, ğdu_, _ህጎች_, 
   {{0x6144083d,0x7e640232,0x3f8c00ac,0x910403e6}},	//   _кела, _vtip, şdu_, اسیۆ, 
   {{0xdcb00075,0x00000000,0x00000000,0x00000000}},	//   غىر_, --, --, --, 
   {{0x7e64009d,0x1ec80107,0x236c047e,0x7a30083e}},	//   _ttip, _алии_, nbej_, mäti, 
   {{0x1a04083f,0x7a300840,0x7e640841,0x00000000}},	// [500] апам, läti, _utip, --, 
   {{0xdb04007f,0x236c0842,0x8e78011a,0x00000000}},	//   _bakò, hbej_, _שניה, --, 
   {{0x7a3001b8,0xd8240843,0x00000000,0x00000000}},	//   näti, аджи, --, --, 
   {{0x2a680218,0x236c016d,0xad6400f2,0x00000000}},	//   bpab_, jbej_, _پایه, --, 
   {{0x4cb802a6,0xddd40232,0x236c014f,0x59740024}},	//   _উপযু, _zvyš, dbej_, _выбу, 
   {{0x7a300844,0xc6f40845,0x85740131,0x473000d4}},	//   käti, шніх_, қсәт_, цніс, 
   {{0x9f4002f6,0x3ea00327,0x7a300108,0x00000000}},	//   lkkä_, _lqit_, jäti, --, 
   {{0x25a805ce,0xd7f0007b,0x236c014f,0xb274009b}},	//   đala_, _بكر_, gbej_, блиш, 
   {{0x9f40005b,0xaac80846,0xf1b8031c,0x7a300847}},	//   nkkä_, रियक, loġi_, täth, 
   {{0x7a3001b8,0x00000000,0x00000000,0x00000000}},	//   fäti, --, --, --, 
   {{0x799c03ac,0x236c047e,0x00000000,0x00000000}},	//   _mcrw, bbej_, --, --, 
   {{0xc0cc02d3,0x95c8010a,0x00000000,0x00000000}},	//   ባብሮ_, _пуçа_, --, --, 
   {{0x63ac0848,0x799c03ac,0x03a000d8,0x00000000}},	//   _ñana, _ocrw, _фичо, --, 
   {{0x7a300793,0x2d84056d,0x23080849,0xfccc0023}},	//   bäti, ûle_, _حتمي_, _ኣሞጽ_, 
   {{0x52b4084a,0x320c084b,0x69c002d2,0xf07801a9}},	//   _अनुस, midy_, _ólei, _ёйиш_, 
   {{0x320c05d6,0x80dc00fe,0x2d8c0356,0x00f4011a}},	//   lidy_, _ফেক্, şee_, _כמוך_, 
   {{0xdd90006c,0xab38084c,0x00000000,0x00000000}},	// [510] _کوپ_, упау_, --, --, 
   {{0x320c06d9,0x53a4084d,0x672c031c,0x00000000}},	//   nidy_, क्तश, żajk, --, 
   {{0xb9c4084e,0x236c014f,0x661c032e,0x00000000}},	//   تقلي, ybej_, _íski, --, 
   {{0xb5c801d9,0x320c03d1,0x1cc0031c,0x799c02d0}},	//   یونم_, hidy_, _གླི_, _ecrw, 
   {{0x320c03d1,0x683005ac,0x7b8400db,0x236c016d}},	//   kidy_, nådi, _باپە, vbej_, 
   {{0xe298016c,0x78bc0175,0x6abc02d0,0x320c030a}},	//   ҳаи_, _fsrv, _issf, jidy_, 
   {{0x320c0170,0xfa340133,0x236c047e,0x00000000}},	//   didy_, _گرێد, tbej_, --, 
   {{0x2488084f,0xe3b80850,0x81c000bd,0xe2980107}},	//   čam_, уби_, _একই_, гаи_, 
   {{0x320c0851,0x236c016d,0xaab801ad,0x00000000}},	//   fidy_, rbej_, ॉटिक, --, 
   {{0x7a300852,0x85b801d9,0x236c016d,0x00000000}},	//   täti, _جارس_, sbej_, --, 
   {{0x236c016d,0xe1240853,0x00000000,0x00000000}},	//   pbej_, смни, --, --, 
   {{0x7a300854,0x9f40005b,0x6abc035a,0x236c016d}},	//   räti, ykkä_, _ossf, qbej_, 
   {{0x62640855,0x7a30049b,0x320c0170,0x6d400209}},	//   _увла, säti, bidy_, ýlan, 
   {{0x8d600021,0x7a300856,0x1d080137,0xda5800d1}},	//   звре, päti, геги_, ғраш_, 
   {{0x6abc0857,0x23bc00cd,0x00000000,0x00000000}},	//   _assf, ्यपद, --, --, 
   {{0x6830013c,0x7a3001e3,0x44c40051,0x00000000}},	//   bådi, nätv, _mđ_, --, 
   {{0x6b9c0175,0x59840858,0x44c4004d,0x799c035a}},	// [520] _dcsg, йлаб, _lđ_, _pcrw, 
   {{0x200c068f,0x9f400859,0x6b9c0142,0x00000000}},	//   ślić_, rkkä_, _ecsg, --, 
   {{0x44c401fb,0x6abc035a,0x18a40108,0x00000000}},	//   _nđ_, _essf, саем, --, 
   {{0xd498085a,0x1cc0025c,0x7794085b,0x00000000}},	//   ҳри_, _གླག_, تیرا, --, 
   {{0xe7f807f7,0xec340133,0x41b4085c,0xd37800d1}},	//   ्फ़ा_, _گوێگ, _असंस, ңчи_, 
   {{0x99d4085d,0xd498085e,0xd944085f,0x7bc40860}},	//   _اتحا, гри_, _геги, ldiu, 
   {{0x320c0170,0x44c4001e,0x1ccc0327,0x00000000}},	//   vidy_, _cđ_, ཱའི_, --, 
   {{0xc7a00861,0x07a005f5,0x44c4004d,0x00000000}},	//   _ниск, _насн, _dđ_, --, 
   {{0xe6b401d5,0x320c0118,0x7bc40862,0x00000000}},	//   _ولفگ, tidy_, idiu, --, 
   {{0xca180075,0x63ac0863,0x46e400d1,0xaac80864}},	//   ﺷﻘﺎ_, _ñann, _удун_, रितक, 
   {{0x320c0865,0x44c4004d,0x546806ed,0x53a4013d}},	//   ridy_, _gđ_, _саем_, _гаеб, 
   {{0x69c00162,0x7bc4036e,0x00000000,0x00000000}},	//   _ólev, jdiu, --, --, 
   {{0xd33400db,0x09b00327,0xd2440304,0x320c0866}},	//   _اعاع, _དྲྀ_, _лэки, pidy_, 
   {{0xc5180597,0x1cc00867,0xacf80868,0x68300869}},	//   _рιӣκ, _གླང_, ангу_, rådi, 
   {{0x5064086a,0x63580055,0x6ad0086b,0x00000000}},	//   _утла, _ṃnib, सम्र, --, 
   {{0xbea800ec,0x00000000,0x00000000,0x00000000}},	//   _ڇهين_, --, --, --, 
   {{0x4e940101,0xeb98086c,0xc0d000cf,0x34b400cd}},	// [530] _اشعر, лиң_, _ويۇب, ंबुद, 
   {{0x7bc4086d,0xdc5401ed,0xde440014,0x6b8800de}},	//   adiu, صرہک, _ویَو_, _ķegu, 
   {{0x3178068f,0x7a3002f6,0xbdf8086e,0xa8740220}},	//   órzy_, jätu, _دريا_, ілді, 
   {{0x7a300166,0x00000000,0x00000000,0x00000000}},	//   dätu, --, --, --, 
   {{0x6abc02d0,0x44c40051,0x7a3001f4,0x00000000}},	//   _ussf, _sđ_, vätv, --, 
   {{0x25a805ce,0x24e8086f,0x4b400014,0x2bd00870}},	//   đalo_, имли_, _وٹھہ, हाका, 
   {{0x69c40871,0x44c401fb,0x00000000,0x00000000}},	//   mdhe, _qđ_, --, --, 
   {{0x69c40872,0xca180873,0x44c40208,0x00000000}},	//   ldhe, ﺴﯩﺰ_, _vđ_, --, 
   {{0xe1f80874,0x6fdc0574,0xca1800d1,0x00000000}},	//   иги_, यानं, ﺷﺘﺎ_, --, 
   {{0x26cc0875,0x7bc40007,0x44c40208,0x00000000}},	//   _ireo_, zdiu, _tđ_, --, 
   {{0x69c40876,0x7a300877,0x2900004e,0x63ac00e4}},	//   idhe, mätt, nzha_, _ñano, 
   {{0x7a300878,0xa2d40879,0x26cc087a,0x6fa40490}},	//   lätt, _ويات, _kreo_, ग्लं, 
   {{0x63a80434,0x69d4087b,0x69c4087c,0xa2e4087d}},	//   mfen, _onze, kdhe, _фолд, 
   {{0xdd90087e,0x63a8087f,0x69c40880,0x7a300881}},	//   بوس_, lfen, jdhe, nätt, 
   {{0x69c40882,0x27140883,0x442c0165,0xdb780884}},	//   ddhe, तपुर_, _kkg_, исаш_, 
   {{0x69d40885,0x63a80886,0x7bc40887,0x7a300888}},	//   _anze, nfen, udiu, hätt, 
   {{0x63a80889,0x7bc4088a,0x7a30088b,0xda64088c}},	// [540] ifen, rdiu, kätt, تازي, 
   {{0x69c4088d,0x8eb0088e,0x7a30088f,0x4a400890}},	//   gdhe, _کمیش, jätt, днув, 
   {{0x7a300891,0x26cc008f,0x442c05c7,0x52b40892}},	//   dätt, _areo_, _okg_, _अन्स, 
   {{0x69d40893,0x26cc0077,0x69c40894,0x63a801a4}},	//   _enze, _breo_, adhe, jfen, 
   {{0x26cc0895,0x33f800e8,0x63a80042,0x7a300139}},	//   _creo_, _néxa_, dfen, fätt, 
   {{0xdb0401b8,0x63a80896,0x26cc0897,0x75240898}},	//   _bakö, efen, _dreo_, şizm, 
   {{0x63a80899,0x5fc8089a,0x26cc0109,0x442c089b}},	//   ffen, ियाल, _ereo_, _bkg_, 
   {{0x63a800a9,0x442c05b1,0x26cc0005,0x044006ed}},	//   gfen, _ckg_, _freo_, мејн, 
   {{0x26cc089c,0x7a30089d,0x442c089e,0x6b60089f}},	//   _greo_, bätt, _dkg_, _hágó, 
   {{0x914808a0,0x154400a8,0x63a80036,0x7a3008a1}},	//   ична_, _дезм, afen, pätu, 
   {{0x53a408a2,0x96c006ab,0x1ddc08a3,0x26cc08a4}},	//   _мажб, लिकॉ, मानत, _zreo_, 
   {{0x442c08a5,0x69c401d3,0x00000000,0x00000000}},	//   _gkg_, zdhe, --, --, 
   {{0x69c408a6,0x53140214,0x7a30007c,0x20f40051}},	//   ydhe, _بذار, näts, ái_, 
   {{0x3f8408a7,0x69c401d9,0xc69008a8,0x2a6c08a9}},	//   ómur_, xdhe, ואש_, _çebi_, 
   {{0x6e3400b5,0xdb1402e2,0x442c00a2,0x00000000}},	//   rlzb, leyè, _ykg_, --, 
   {{0x69c408aa,0x395800ef,0xf1b80327,0x7a3004ab}},	//   wdhe, _agrs_, leġ_, käts, 
   {{0x7a3008ab,0x69c40023,0x8bfc0349,0xdb140100}},	// [550] yätt, tdhe, ্কলন_, neyè, 
   {{0x395804cc,0x69c401a4,0xe7380032,0x7a3004cc}},	//   _cgrs_, udhe, ҙел_, däts, 
   {{0x69c408ac,0x26cc08ad,0x7a3008ae,0x888000f2}},	//   rdhe, _sreo_, vätt, بیزن, 
   {{0x69c40023,0x6b60032e,0x2900030a,0xa7a80108}},	//   sdhe, _dágó, rzha_, ёкла_, 
   {{0x7a3008af,0x9ba008b0,0x63a80165,0x244000e4}},	//   tätt, _سەلى, vfen, nóme_, 
   {{0x26cc084c,0x69d408b1,0x442c08b2,0xd6cc0472}},	//   _vreo_, _unze, _skg_, اقو_, 
   {{0x7a3008b3,0x6ab803be,0xdb2001e1,0xb2d00051}},	//   rätt, şafı, _àtòy, _đềxe, 
   {{0x26cc08b4,0x7a3008b5,0x63a808b6,0xa2e408b7}},	//   _treo_, sätt, ufen, зоид, 
   {{0x63a808b8,0xdb04006a,0x63ac02d1,0x26cc01e4}},	//   rfen, _wakö, _ñanm, _ureo_, 
   {{0x130408b9,0xe1f8009d,0x00000000,0x00000000}},	//   яный_, сго_, --, --, 
   {{0x63a808ba,0x442c003e,0x363401d5,0x35680276}},	//   pfen, _tkg_, _آرقس, _фрун_, 
   {{0x442c08bb,0x601400c0,0xdb1408bc,0x00000000}},	//   _ukg_, kšme, beyè, --, 
   {{0x644808bd,0x317c0010,0xf1b8025c,0x62640408}},	//   mmei, _fevz_, beġ_, _эвла, 
   {{0x644808be,0xc0e00023,0x00000000,0x00000000}},	//   lmei, ምሃር_, --, --, 
   {{0x1fb408bf,0xdb040109,0xd65c02dd,0xe08801f7}},	//   _еспр, _lakô, _бiзд, _اَبو_, 
   {{0x644808c0,0x1e8408c1,0x395804cc,0x717000d1}},	//   nmei, _елим, _sgrs_, _كۇۋا, 
   {{0x644808c2,0x8f9808c3,0x00000000,0x00000000}},	// [560] imei, _היפי, --, --, 
   {{0x644808c4,0xb10000ee,0x7a3008c5,0x5fc800c5}},	//   hmei, _öýün, väts, ियवल, 
   {{0x23bc01bc,0x64480097,0xdb14007f,0x00000000}},	//   ्याद, kmei, zeyè, --, 
   {{0x7a300730,0x6b6001d3,0x5c7401af,0x00000000}},	//   täts, _vágó, _мәғр_, --, 
   {{0x644800af,0xdb0400c7,0x7e600113,0x998400db}},	//   dmei, _pakõ, ímph, _ىلحو, 
   {{0xdb040109,0x7a3008c6,0x644808c7,0x00000000}},	//   _dakô, räts, emei, --, 
   {{0x644808c8,0x7a30013d,0x00000000,0x00000000}},	//   fmei, bätr, --, --, 
   {{0x438008c9,0x279408ca,0x7a30000d,0xf1b80327}},	//   ىلىق, _ошур, päts, weġ_, 
   {{0x683008cb,0x00000000,0x00000000,0x00000000}},	//   rådt, --, --, --, 
   {{0x644808cc,0x6830005c,0x444401d9,0xdb14007f}},	//   amei, båds, _ہرنہ, reyè, 
   {{0x644808cd,0xf1b80003,0x00000000,0x00000000}},	//   bmei, reġ_, --, --, 
   {{0x04d80302,0xdb1402e2,0xf1b80327,0x661c08ce}},	//   _לקבל, peyè, seġ_, _ískr, 
   {{0x80a008cf,0x80ac00cc,0x1ad40073,0x00000000}},	//   ومین, টিষ্, ठमोठ, --, 
   {{0x244000d7,0x00000000,0x00000000,0x00000000}},	//   róme_, --, --, --, 
   {{0x7d2408d0,0x6fa40490,0x00000000,0x00000000}},	//   ефте, _कापू, --, --, 
   {{0x2c0c0574,0x00000000,0x00000000,0x00000000}},	//   _सगळं_, --, --, --, 
   {{0x0a68041b,0x2cc80064,0x7a3001f4,0x00000000}},	// [570] срби_, _žudė_, vätr, --, 
   {{0x64480007,0xba7400cf,0xa2cc08d1,0x00000000}},	//   zmei, عاقت, तित्, --, 
   {{0xe7f8012d,0x00000000,0x00000000,0x00000000}},	//   ंसला_, --, --, --, 
   {{0x27e808d2,0xbea8036b,0x00000000,0x00000000}},	//   ðan_, _بهین_, --, --, 
   {{0x6fa408d3,0x644808d4,0x00000000,0x00000000}},	//   _कानू, vmei, --, --, 
   {{0x25a008d5,0x7a3001e3,0xf5840116,0x00000000}},	//   ühl_, sätr, ىشىپ, --, 
   {{0x644808d6,0x63ac02d1,0x00000000,0x00000000}},	//   tmei, _ñank, --, --, 
   {{0x683008d7,0xf9900050,0x3cfc08d8,0x6448002f}},	//   råds, _لبہ_, מלונ, umei, 
   {{0xb9dc02d3,0x1cc0025c,0x5908031c,0xb2d00051}},	//   _በታ_, _གླན_, _གཟོས_, _đểxe, 
   {{0x644808d9,0xa878008f,0x672c0210,0x00000000}},	//   smei, ֿאָר, żajs, --, 
   {{0xd5a4035c,0xddd4010b,0xc42808da,0x00000000}},	//   _آلمی, _atyş, _люде_, --, 
   {{0xa2f408db,0xdea008dc,0xa2cc08dd,0x00000000}},	//   _опеч, پیدی, तिद्, --, 
   {{0x21a401b9,0x00000000,0x00000000,0x00000000}},	//   _жилм, --, --, --, 
   {{0xdd9008de,0x23bc08df,0x00000000,0x00000000}},	//   ضور_, ्यवद, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xaac806ab,0x8c4008e0,0xf3f800e2,0x00000000}},	//   रिंक, весе, _kuģa_, --, 
   {{0x19c408e1,0x00000000,0x00000000,0x00000000}},	// [580] мбам, --, --, --, 
   {{0x0d8008e2,0xd7c40490,0x00000000,0x00000000}},	//   _ильн, _रोजच, --, --, 
   {{0x3f8008e3,0x1c4408e4,0xaaa800cf,0x1b78007b}},	//   _keiu_, _оном, _ۉچكۅ_, _وصحة_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa3e006e3,0x3f8008e5,0x00000000,0x00000000}},	//   दान_, _meiu_, --, --, 
   {{0x3f800254,0x628400b8,0x00000000,0x00000000}},	//   _leiu_, _āhop, --, --, 
   {{0x68300158,0xe8b00137,0x00000000,0x00000000}},	//   rådr, _مەلج, --, --, 
   {{0x3f8000c5,0x4bf8008f,0x93ec0073,0x96b800f3}},	//   _neiu_, ַליס, _जवळच_, _музу_, 
   {{0x6fdc08e6,0x683003cd,0x03e400f1,0x672c0327}},	//   यासं, pådr, بډلي_, żajr, 
   {{0x3f8008e7,0x8640009d,0xfce00023,0x00000000}},	//   _aeiu_, _ануж, _ነውጺ_, --, 
   {{0x3f80026c,0xd4c408e8,0x69c8010e,0x00000000}},	//   _beiu_, _تغذي, _öleň, --, 
   {{0xb4bc08e9,0xc95008c3,0x00000000,0x00000000}},	//   ेटी_, כמת_, --, --, 
   {{0xb8d008ea,0x3f80003e,0x0dc80395,0x00000000}},	//   _ཐད_, _deiu_, оуви_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7c84084c,0x3f800437,0x8bc408eb,0x7a300108}},	//   куте, _feiu_, мсад, vätp, 
   {{0x25a80552,0xa3e008ec,0x200008ed,0x2cac031c}},	//   đali_, दाय_, chki_, ċed_, 
   {{0x244008ee,0x59080327,0x00000000,0x00000000}},	// [590] nóma_, _གཟུས_, --, --, 
   {{0x2fc808ef,0xf99008f0,0x00000000,0x00000000}},	//   _haag_, لبم_, --, --, 
   {{0x2fc808f1,0xd7d80490,0xa3e008f2,0x79a402e8}},	//   _kaag_, णांच, दाम_, ърте, 
   {{0x244008f3,0x2fc805e4,0xfaf001ed,0xf77008f4}},	//   kóma_, _jaag_, دثہ_, لاه_, 
   {{0x2d8008f5,0x2fc808f6,0x63ac0022,0x7ac4030d}},	//   _kehe_, _maag_, _ñani, _исре, 
   {{0x2fc808f7,0xa2cc08f8,0x6d400209,0x2d8008f9}},	//   _laag_, तिस्, ýlaw, _jehe_, 
   {{0x2d8008fa,0x6fa40574,0x290408fb,0xd46408fc}},	//   _mehe_, _काढू, _åla_, нище_, 
   {{0x2d8008fd,0x2fc80014,0x00000000,0x00000000}},	//   _lehe_, _naag_, --, --, 
   {{0x3f800254,0xa3e006e3,0xdb0c03b2,0x10a00150}},	//   _reiu_, दाब_, ídøg, қиян, 
   {{0x2d8008fe,0x27ec08ff,0x35b40276,0xc650036b}},	//   _nehe_, _hoen_, _ибур, _شفاک, 
   {{0x2fc800e8,0xb5440022,0x00000000,0x00000000}},	//   _baag_, _иҧша_, --, --, 
   {{0x27ec0900,0x2fc80901,0x5f040902,0x00000000}},	//   _joen_, _caag_, езма, --, 
   {{0x27ec0903,0x2fc80904,0x645801e2,0x2d800905}},	//   _moen_, _daag_, _iiwi, _behe_, 
   {{0x20000906,0x645802b5,0x27ec0907,0xc1e00150}},	//   shki_, _hiwi, _loen_, _شۋجي, 
   {{0x62880908,0x2fc800ad,0x2d800909,0xa2cc090a}},	//   lseo, _faag_, _dehe_, तिव्, 
   {{0x27ec090b,0x2d80090c,0x6458090d,0x2fc8090e}},	//   _noen_, _eehe_, _jiwi, _gaag_, 
   {{0x6458090f,0x62880910,0x00000000,0x00000000}},	// [5a0] _miwi, nseo, --, --, 
   {{0x2d800911,0x7f440912,0x64580913,0x62880914}},	//   _gehe_, _iziq, _liwi, iseo, 
   {{0x27ec03cb,0x2fc800e8,0xe2340023,0x00000000}},	//   _boen_, _yaag_, _ርእስና, --, 
   {{0x27ec0915,0x64580916,0x2d800295,0x25a4015d}},	//   _coen_, _niwi, _zehe_, _acll_, 
   {{0x27ec0917,0x2d8002b9,0xf984013e,0x6830003b}},	//   _doen_, _yehe_, _аҳзо, rådp, 
   {{0x27ec0295,0x64580099,0x2d8001c4,0xceb0010f}},	//   _eoen_, _aiwi, _xehe_, טיד_, 
   {{0x8cd00918,0x64580919,0xb4bc00e1,0x27ec0165}},	//   डियो, _biwi, ेटे_, _foen_, 
   {{0x27ec04c4,0x6458091a,0xb4b0007d,0xe2300344}},	//   _goen_, _ciwi, _ओही_, یکوب, 
   {{0x7ae4091b,0x6458091c,0xa2cc0882,0x2fc8091d}},	//   nxit, _diwi, तिष्, _raag_, 
   {{0x6458091e,0x27ec091f,0x2fc80920,0x7ae4004e}},	//   _eiwi, _zoen_, _saag_, ixit, 
   {{0x7f440921,0x2d8007dd,0x2fc8062c,0x244000e4}},	//   _aziq, _rehe_, _paag_, sóma_, 
   {{0x2d800922,0x64580923,0xa2cc00dc,0x24400124}},	//   _sehe_, _giwi, तिश्, póma_, 
   {{0x2d800924,0xb8ec031c,0x04400354,0xb4b0000d}},	//   _pehe_, _ྱག_, _сецн, _ओहु_, 
   {{0xa2cc0882,0x64580925,0x2fc80926,0x2ee00927}},	//   तिर्, _ziwi, _waag_, _पपीत, 
   {{0x7f440928,0x2fc80929,0x2d800156,0x6458092a}},	//   _eziq, _taag_, _vehe_, _yiwi, 
   {{0x2d80092b,0x41b00137,0x00000000,0x00000000}},	//   _wehe_, _لمۇر, --, --, 
   {{0x27ec092c,0x2d80092d,0x7ae40472,0x6d400793}},	// [5b0] _roen_, _tehe_, gxit, ülab, 
   {{0x27ec092e,0xfe70092f,0x2d800418,0xb4b000af}},	//   _soen_, _ادي_, _uehe_, _ओहू_, 
   {{0xf77004d3,0xe6100930,0x27ec0931,0x00000000}},	//   ڵان_, یشت_, _poen_, --, 
   {{0xe7180597,0x6d440932,0x00000000,0x00000000}},	//   ويات_, _izha, --, --, 
   {{0xf7700933,0x64580934,0x27ec030a,0xc4a80150}},	//   صان_, _riwi, _voen_, _ﺴﻴﺘﻌ, 
   {{0x64580935,0x6aac00ec,0x27ec01c7,0x2bc80118}},	//   _siwi, mtaf, _woen_, ाएका, 
   {{0x27ec0936,0xf98802dd,0x628800a3,0x64580937}},	//   _toen_, _سەنۋ_, wseo, _piwi, 
   {{0xc44400dd,0x64580309,0x6aac022f,0x62880938}},	//   ریشن_, _qiwi, otaf, tseo, 
   {{0x64580939,0x62880354,0x764801d5,0x52800830}},	//   _viwi, useo, _fhdy, агыб, 
   {{0x6458093a,0x6288093b,0x67280327,0x6d4405c7}},	//   _wiwi, rseo, _ixej, _ozha, 
   {{0xa3e0093c,0x3494093d,0x67280327,0x6458093e}},	//   दाद_, _бахр, _hxej, _tiwi, 
   {{0xbbe007f7,0xbec8010b,0x6288093f,0xe31400f3}},	//   _पचेक, еңиз_, pseo, _имењ, 
   {{0x6d440940,0x7648049b,0x67280327,0x7ae40941}},	//   _azha, _yhdy, _jxej, xxit, 
   {{0x67280327,0xdb14010e,0x00000000,0x00000000}},	//   _mxej, gdyý, --, --, 
   {{0x6aac0942,0x5fa80073,0xc22001d3,0x00000000}},	//   etaf, _कापल, _لکھو, --, 
   {{0x6d440943,0x7ae401c0,0x6aac041e,0x9f04004b}},	//   _dzha, txit, ftaf, _لوبو, 
   {{0xdfd0066d,0x7f440944,0x6d44030a,0x6aac005c}},	// [5c0] _ميں_, _uziq, _ezha, gtaf, 
   {{0x8a000945,0x6d400793,0x7ae40946,0x00000000}},	//   азуе, ülac, rxit, --, 
   {{0x7e640947,0x6d44067c,0x18a40948,0x6aac0949}},	//   _huip, _gzha, таем, ataf, 
   {{0x7ae4094a,0x6600094b,0x600408a5,0x0d2000db}},	//   pxit, _allk, _dómg, _түсү, 
   {{0xc7a0094c,0x07a0094d,0x6aac01f5,0x68e401ab}},	//   ричк, рачн, ctaf, axhd, 
   {{0x7e640421,0x8640094e,0x00000000,0x00000000}},	//   _muip, анчж, --, --, 
   {{0x7e640926,0x48e0013e,0x9854094f,0x1cc80327}},	//   _luip, _корв, _аташ, _ླགས_, 
   {{0xd1e002d3,0x44f00145,0xccf000d9,0x8cd00950}},	//   ምዓት_, شسىز, שכה_, डितो, 
   {{0x7e640951,0x60140153,0x98a80210,0x00000000}},	//   _nuip, ešmo, _rybę_, --, 
   {{0xca340952,0x46440022,0x5064004e,0x00000000}},	//   ﻗﻘﺎ_, _азун_, ктма, --, 
   {{0x09f4011a,0x00000000,0x00000000,0x00000000}},	//   דמים_, --, --, --, 
   {{0xc0580953,0x80a00954,0x00000000,0x00000000}},	//   кія_, _कमरे, --, --, 
   {{0x7e640955,0x80ac04c5,0x66000240,0x67280327}},	//   _cuip, টিগ্, _yllk, _xxej, 
   {{0x273007ae,0xfd540055,0xd1740124,0x6e440956}},	//   ỡng_, _hreṣ, _рыды, انسم, 
   {{0xdeb0005e,0xab940957,0xfe240958,0xb4b00959}},	//   _құры, ливі, рьян, _ओहो_, 
   {{0x6aac095a,0x63ac095b,0x7e64095c,0x6d440219}},	//   ttaf, _ñant, _fuip, _vzha, 
   {{0x600403b2,0xdcec00e2,0xfb840006,0x7cfc007c}},	// [5d0] _dómd, fabē, рысн, tärö, 
   {{0x6aac095d,0x49b8095e,0xa4cc0219,0x00000000}},	//   rtaf, بارد_, ščič, --, 
   {{0x7e6401a4,0x67d40261,0x5fa8095f,0x00000000}},	//   _zuip, ложу, _कामल, --, 
   {{0x6e340960,0x6aac01a8,0x9e9400db,0x87700961}},	//   lozb, ptaf, _شاۋچ, рғаш, 
   {{0x3a840962,0xa3e002ab,0x7cfc005b,0x24500118}},	//   _высв, दास_, pärö, _mšmt_, 
   {{0xd1240963,0xc5e804c5,0x2a680964,0x600403b2}},	//   _هم_, কসভা_, mqab_, _tómg, 
   {{0xc7c40965,0x64b40966,0x6004032e,0x00000000}},	//   _исаи, احتر, _hóme, --, 
   {{0x6e3401c4,0x600402d2,0x00000000,0x00000000}},	//   hozb, _kóme, --, --, 
   {{0xca340952,0x316c0175,0xdb14007f,0xdcfc00d7}},	//   ﻗﺘﺎ_, fcdz_, ldyò, _repč, 
   {{0xa0740967,0x6e3408a4,0x66000968,0x60e80969}},	//   лымш, jozb, _ullk, емом_, 
   {{0x7e64096a,0x2a68022e,0x902000ec,0x00000000}},	//   _suip, hqab_, ڍڙيو, --, 
   {{0x7e64096b,0x00000000,0x00000000,0x00000000}},	//   _puip, --, --, --, 
   {{0x443c096c,0xd24c096d,0x7e64096e,0x00000000}},	//   mlu_, تنی_, _quip, --, 
   {{0xdca4096f,0x1ba801d3,0x91e00798,0xa0a4004e}},	//   лаги, کاسٹ_, _гоше, _бакд, 
   {{0x443c0970,0x63ac0309,0x5bb4039b,0xf1a80133}},	//   olu_, _ñans, лсаф, _شاوه_, 
   {{0x443c0971,0x7e640972,0x00000000,0x00000000}},	//   nlu_, _tuip, --, --, 
   {{0x8c400973,0x9e5803a6,0x443c0974,0x8eb00975}},	// [5e0] сете, _проф_, ilu_, _هميش, 
   {{0x443c0976,0x7a3003fa,0x998400e3,0x600402d2}},	//   hlu_, lätz, الاو, _dóme, 
   {{0x443c0977,0x9d380134,0x00000000,0x00000000}},	//   klu_, _ɔyɛɛ_, --, --, 
   {{0x443c0978,0xda640979,0x2a680218,0x236c0010}},	//   jlu_, _ماسي, bqab_, jcej_, 
   {{0x6004097a,0x7414097b,0x00000000,0x00000000}},	//   _góme, یوتا, --, --, 
   {{0x443c097c,0x7c24084c,0x7a30097d,0xd1d402d3}},	//   elu_, lnir, hätz, ራቤት_, 
   {{0x295406bb,0x5fa80574,0x443c097e,0x7c24097f}},	//   _вътр, _काढल, flu_, onir, 
   {{0x7c240980,0x443c0981,0x73d80982,0xdb1400a2}},	//   nnir, glu_, тдир_, ldyñ, 
   {{0x7c240983,0x51840984,0xca3400d1,0x70540345}},	//   inir, луна, ﺗﯘﺵ_, ینخا, 
   {{0x443c0985,0x236c00d0,0x29240986,0x60040241}},	//   alu_, acej_, špaš_, _nómb, 
   {{0x443c0987,0x7c240988,0x52380023,0x98a801ef}},	//   blu_, knir, _ከባቢኦ, _rybě_, 
   {{0x7c240989,0xb4e0098a,0x2a6801a9,0x0440030d}},	//   jnir, दमी_, yqab_, _лехн, 
   {{0xa3e0098b,0x4ea4098c,0xc0e401d3,0xdb2001e1}},	//   दार_, ырна, نفین_, _àtèy, 
   {{0x2fcc098d,0x2a680218,0xae9401e1,0x7c24098e}},	//   žeg_, vqab_, _fẹnu, enir, 
   {{0x02140302,0x2a68098f,0x6e3405d6,0xc0e000ea}},	//   _תחום_, wqab_, rozb, _гојк, 
   {{0xab740990,0x6b740991,0x0a680992,0x2d84033f}},	//   ргаш, рлау, ержи_, źle_, 
   {{0x7a3002f6,0x7c28004a,0x6a140993,0x00000000}},	// [5f0] läty, édra, амау, --, 
   {{0x443c0994,0x7c240995,0x236c0007,0x6fdc05d7}},	//   zlu_, anir, zcej_, याकं, 
   {{0xdd90040d,0x443c0996,0x7a3002f6,0xfbd00014}},	//   _بوپ_, ylu_, näty, _کتٍ_, 
   {{0x443c0997,0x78bc0998,0x60040789,0x7c240999}},	//   xlu_, _dprv, _tóme, cnir, 
   {{0x443c0978,0x66e4099a,0x2a680327,0x7a300108}},	//   vlu_, рола, qqab_, häty, 
   {{0x6abc02d0,0xd5ac0014,0x7a300108,0x443c099b}},	//   _ipsf, ِہٕ_, käty, wlu_, 
   {{0x26c000d0,0xfdf802e4,0x78b80419,0x7a3001f4}},	//   ňho_, רצות_, čavá, jäty, 
   {{0x443c099c,0x7a30023a,0xa934014b,0x00000000}},	//   ulu_, däty, _беҳш, --, 
   {{0x443c099d,0xa204099e,0x13e400fd,0x36d4010a}},	//   rlu_, ипид, рмый_, _лотр, 
   {{0xd24c099f,0x7c240083,0xe1f809a0,0x7a3004e6}},	//   وني_, znir, тго_, wätz, 
   {{0x443c09a1,0x7c2409a2,0x60040162,0x9f4001f4}},	//   plu_, ynir, _rómb, nkkö_, 
   {{0xdcfc005f,0x6abc03ac,0x443c09a3,0x00000000}},	//   _nepā, _opsf, qlu_, --, 
   {{0x63ac0054,0xf38c008f,0x21740137,0x7a30002f}},	//   _ñanq, _טראָ, _куйр, rätz, 
   {{0x7a3009a4,0xdd90036b,0x44c401d3,0xae940241}},	//   sätz, غوز_, _kő_, _tẹnu, 
   {{0xd24c00aa,0xa0a409a5,0x6abc03ac,0xa2cc00dc}},	//   _تنو_, _тайд, _apsf, तिक्, 
   {{0x78bc0158,0xdcfc00ef,0xdca401d5,0xd00c09a6}},	//   _rprv, _cepā, лаҳи, _يلو_, 
   {{0x7c2409a7,0x999c063f,0x78bc09a8,0x600409a9}},	// [600] rnir, _ótū_, _sprv, _tómb, 
   {{0x99740046,0x7c2409aa,0xa3e009ab,0x00000000}},	//   руаш, snir, दाँ_, --, 
   {{0x44c400dd,0x6abc02d0,0x1d0809ac,0xee08008f}},	//   _nő_, _epsf, _рени_, _תּפֿ, 
   {{0xb5fc0327,0xdddc0100,0x7c240113,0x00000000}},	//   _miġe, _sipň, qnir, --, 
   {{0x7bc40276,0x1dc801ad,0x8c1800d9,0xdb140139}},	//   meiu, ाजपत, _יוטי, deyç, 
   {{0x7bc409ad,0x75d4009f,0x44c400e5,0x00000000}},	//   leiu, صيبا, _bő_, --, 
   {{0xb4e009ae,0xb5fc0135,0xa3e000cd,0x7a3000fd}},	//   दमे_, _niġe, दां_, dätx, 
   {{0xc7a009af,0x07a009b0,0x75f400db,0xb6c40209}},	//   _миск, _масн, _vàzq, _гөкд, 
   {{0x47d000ec,0x836001b9,0x0ca00037,0xa2cc00cd}},	//   _بيقر, زگنل, _ओम्म, तिग्, 
   {{0x44c400dd,0xe87400db,0x7bc409b1,0x7a300108}},	//   _fő_, _ئچەگ, heiu, täty, 
   {{0x69d8008f,0x25f409b2,0xd6b4030d,0xdb140432}},	//   אַרו, ्सरी_, _гiум, leyä, 
   {{0x24f409b3,0xb5fc025c,0xa3e009b4,0x63ac02d1}},	//   _учур, _diġe, दाः_, _ñanp, 
   {{0xc7b0025f,0x7bc409b5,0x9f500241,0x7a30005b}},	//   חבר_, deiu, _joyè_, säty, 
   {{0x82300836,0x9f400108,0x90e4009f,0x7a3001f4}},	//   _وروا, ykkö_, _نسبن, päty, 
   {{0x7bc40270,0x09cc015b,0x00000000,0x00000000}},	//   feiu, রামা, --, --, 
   {{0xb5fc0003,0x110400ec,0x00000000,0x00000000}},	//   _jiġb, _مٺڙي_, --, --, 
   {{0x201009b6,0xb5fc0003,0x3c5800a8,0xdcec0153}},	// [610] ëzie_, _miġb, ритэ_, kabė, 
   {{0x2b84004d,0x00000000,0x00000000,0x00000000}},	//   ặc_, --, --, --, 
   {{0xc7c409b7,0x7bc40393,0x600409b8,0x6cd400cf}},	//   исди, beiu, _hóma, _اقجا, 
   {{0x7bc40276,0xf7f404fb,0x600409b9,0xb5fc025c}},	//   ceiu, يسند, _kóma, _niġb, 
   {{0x6b8c09ba,0x09cc00bd,0x25f409bb,0xe9a80214}},	//   maag, রাবা, ्सली_, _مگان_, 
   {{0x6b8c09bc,0x80ac09bd,0x63b80042,0x48740244}},	//   laag, য়িত্, _sbwn, _ندرس, 
   {{0x69c409be,0x247c0020,0xe380001f,0x600403b2}},	//   mehe, _ጥቅምት_, _የቀረበ_, _lóma, 
   {{0x6b8c09bf,0x69c409c0,0xf7700131,0xb5fc025c}},	//   naag, lehe, _ياق_, _riġe, 
   {{0x216809c1,0x65940276,0x600409c2,0x6b8c0194}},	//   липи_, _газу, _nóma, iaag, 
   {{0xa20409c3,0x69c409c4,0x26cc0395,0x6b8c09c5}},	//   спод, nehe, _iseo_, haag, 
   {{0x6b8c09c6,0x629c0122,0x69c405ac,0x6d40000d}},	//   kaag, ásob, iehe, ülal, 
   {{0x6b8c0549,0xdcfc054e,0x24400022,0x92c400fe}},	//   jaag, _lepă, kómi_, _উপৰ_, 
   {{0x69c409c7,0x6b8c09c8,0x60040077,0xe29809c9}},	//   kehe, daag, _cóma, _сал_, 
   {{0x63a809ca,0x69c409cb,0x600409cc,0x26cc0109}},	//   lgen, jehe, _dóma, _mseo_, 
   {{0x63a809cd,0x6b8c09ce,0x7bc40356,0x6c74009d}},	//   ogen, faag, teiu, жуух, 
   {{0x63a809cf,0x6b8c09d0,0x60140006,0x26cc0129}},	//   ngen, gaag, kšmi, _oseo_, 
   {{0x63a809d1,0x69c403d1,0x600409d2,0x7bc409d3}},	// [620] igen, fehe, _góma, reiu, 
   {{0x69c409d4,0x63a80369,0x200009d5,0x9f5006af}},	//   gehe, hgen, lkki_, _noyé_, 
   {{0x63a809d6,0x395c049f,0x26cc09d7,0xdcfc0276}},	//   kgen, ävs_, _aseo_, _depă, 
   {{0x6b8c074d,0x2000049b,0x63a809d8,0xa6e8004d}},	//   caag, nkki_, jgen, _trự, 
   {{0xa3e009d9,0x69c409da,0x9f500085,0xb4e00882}},	//   दाई_, behe, _boyé_, दम्_, 
   {{0x63a809db,0x473002bf,0xb6940092,0x00000000}},	//   egen, чніс, _ኃይለኛ_, --, 
   {{0x63a809dc,0x26cc00df,0xddd40055,0x00000000}},	//   fgen, _eseo_, _atyū, --, 
   {{0x6814006d,0x63a809dd,0xc87c0724,0xb27409de}},	//   ządz, ggen, ışta_, олиш, 
   {{0xb1c80131,0xdcec00c0,0x00000000,0x00000000}},	//   иңда_, pabė, --, --, 
   {{0x6b8c09df,0x600409e0,0x20000108,0xa2cc0303}},	//   zaag, _róma, ekki_, तिज्, 
   {{0x6b8c09e1,0xb5fc0135,0xd24c00ec,0x600408a5}},	//   yaag, _tiġb, ونڊ_, _sóma, 
   {{0x63a809e2,0xc4d0011a,0x69c401c7,0x6b8c058a}},	//   cgen, _מגע_, zehe, xaag, 
   {{0x69c409e3,0x934400ee,0x03a00107,0x5fa8044b}},	//   yehe, _унде, _хичо, _कारल, 
   {{0x6b8c09e4,0x387801ab,0x15f800bc,0x20000108}},	//   waag, _otrr_, ्सिर_, akki_, 
   {{0x6b8c09e5,0x69c409e6,0x00000000,0x00000000}},	//   taag, vehe, --, --, 
   {{0x69c409e7,0x600409e8,0x6814012d,0x00000000}},	//   wehe, _tóma, sądz, --, 
   {{0x69c409e9,0x15f8012c,0xdb2001e1,0x00000000}},	// [630] tehe, ्सार_, _àtìy, --, 
   {{0x26cc0770,0x6b8c09ea,0x63a809eb,0x00000000}},	//   _rseo_, saag, zgen, --, 
   {{0x63a809ec,0x094809ed,0x6b8c09ee,0x69c409ef}},	//   ygen, учаи_, paag, rehe, 
   {{0x69c409f0,0x600400d2,0x6b8c09f1,0x267800a8}},	//   sehe, _lómn, qaag, аскэ_, 
   {{0x69c4052f,0xefd00023,0xe73800ea,0x00000000}},	//   pehe, _ብኢድ_, јел_, --, 
   {{0x69c4009a,0x2a7800ef,0x41d40210,0x00000000}},	//   qehe, _itsb_, _भोंस, --, 
   {{0x63a809f2,0x200009f3,0x60300421,0xa3e809f4}},	//   tgen, ykki_, lāme, идка_, 
   {{0x63a809f5,0x26cc09f6,0xe298035b,0x247400b8}},	//   ugen, _tseo_, ааи_, _nāme_, 
   {{0x232809f7,0xe29809f8,0xa02401f4,0x00000000}},	//   ропи_, шап_, htöä, --, 
   {{0x63a809f9,0x00000000,0x00000000,0x00000000}},	//   sgen, --, --, --, 
   {{0xd12c01ed,0x600401a8,0x00000000,0x00000000}},	//   ہمی_, _dómn, --, --, 
   {{0x3494009d,0x20000108,0x00000000,0x00000000}},	//   _хацр, ukki_, --, --, 
   {{0x2000049b,0xe2980114,0x00000000,0x00000000}},	//   rkki_, _ђак_, --, --, 
   {{0x320c0042,0x00000000,0x00000000,0x00000000}},	//   chdy_, --, --, --, 
   {{0x2120002f,0x00000000,0x00000000,0x00000000}},	//   _ähh_, --, --, --, 
   {{0x1c440111,0xcb6402e8,0x63bc01d5,0x00000000}},	//   інам, жате_, еsni, --, 
   {{0x1988013e,0x8af40213,0x00000000,0x00000000}},	// [640] ибаи_, şənl, --, --, 
   {{0x7f440944,0xa2a009fa,0x00000000,0x00000000}},	//   _iyiq, _खिन्, --, --, 
   {{0x2474002b,0xd87400db,0x00000000,0x00000000}},	//   _yāme_, زااب, --, --, 
   {{0xefd00023,0x00000000,0x00000000,0x00000000}},	//   _ብኢደ_, --, --, --, 
   {{0xdddc01af,0xa3cc00af,0x24400419,0x60300055}},	//   _lipō, शजन_, nómu_, cāme, 
   {{0xd49809fb,0x5d78010f,0x1dc800cd,0x15b809fc}},	//   ари_, באַק, ाजित, рыды_, 
   {{0x1db009fd,0x999800b0,0xc31400cc,0xc924009d}},	//   _जानत, hopū_, _ডুলি_, _дорж_, 
   {{0x7f440921,0x999802b5,0xe3b800e5,0x04500633}},	//   _oyiq, kopū_, gfű_, وئيد, 
   {{0x2488071b,0x1dc8078a,0x2474002b,0x320c015d}},	//   ćama_, ाजात, _rāme_, thdy_, 
   {{0x24740093,0x6ed80118,0x00000000,0x00000000}},	//   _sāme_, मिसु, --, --, 
   {{0x104809fe,0xa3b4069f,0x600409ff,0x7f440a00}},	//   иями_, _चॉक_, _cómo, _ayiq, 
   {{0x320c0a01,0x15f80073,0x00000000,0x00000000}},	//   shdy_, ्सवर_, --, --, 
   {{0x247400cd,0x20100200,0x00000000,0x00000000}},	//   _vāme_, ëzia_, --, --, 
   {{0x60040077,0xa02401f4,0x00000000,0x00000000}},	//   _fómo, ttöä, --, --, 
   {{0x7f4401f0,0x24740a02,0x31740210,0xcf9801ee}},	//   _eyiq, _tāme_, ądzą_, _кјп_, 
   {{0x80c40210,0xa2a00709,0x00000000,0x00000000}},	//   ़बरे, _खिम्, --, --, 
   {{0x09cc015b,0xa0240108,0x00000000,0x00000000}},	// [650] রাসা, stöä, --, --, 
   {{0x1db00882,0x8d8802dd,0x00000000,0x00000000}},	//   _जायत, _ﺒﺩﺃﺕ_, --, --, 
   {{0x2d900a03,0x6030005f,0x00000000,0x00000000}},	//   maze_, sāme, --, --, 
   {{0x2d9005ce,0xb5fc0327,0x7b0401d3,0xdcd8010f}},	//   laze_, _riġa, ötté, _פֿיש, 
   {{0xb5fc0003,0x9aa401af,0x00000000,0x00000000}},	//   _siġa, _нурһ, --, --, 
   {{0x2d900a04,0xb5fc0327,0xdc540133,0x00000000}},	//   naze_, _piġa, _ورێک, --, 
   {{0x69d40a05,0x7e600268,0xf8b4084c,0x92a80154}},	//   _iaze, ìmpi, _обрэ, খবো_, 
   {{0x6d440a06,0x2d900a07,0x60040030,0x00000000}},	//   _myha, haze_, _rómo, --, 
   {{0x26d804d4,0xdddc007f,0x29000a08,0x6fa401f9}},	//   _éso_, _sipō, lyha_, _काजू, 
   {{0x69d40a09,0x659401c0,0x23280116,0x35f80a0a}},	//   _jaze, _хажу, _қоли_, _ورلد_, 
   {{0x69d40a0b,0x6d440a0c,0x290001ed,0x2d9004ba}},	//   _maze, _nyha, nyha_, daze_, 
   {{0x69d40a0d,0x31700032,0x4ab8000d,0x00000000}},	//   _laze, нғәт, _उहंव, --, 
   {{0x442c017a,0x21680a0e,0x6d440a0f,0xb5fc031c}},	//   _ijg_, _лили_, _ayha, _miġn, 
   {{0x2d900a10,0x60040085,0x999802b5,0xb2840006}},	//   gaze_, _tómo, ropū_, _цыцк, 
   {{0x290000c7,0xacf40014,0x00000000,0x00000000}},	//   jyha_, وسِت, --, --, 
   {{0x9f840108,0xa3e001f9,0x00000000,0x00000000}},	//   _эгид, दाट_, --, --, 
   {{0x7f440944,0x6d440857,0xaae40a11,0x9f040a12}},	// [660] _uyiq, _eyha, وسكو, _رودو, 
   {{0x4a400a13,0x2d900a14,0x442c007f,0xed580107}},	//   енув, caze_, _ljg_, соӣ_, 
   {{0x9d440a15,0x290001d3,0x00000000,0x00000000}},	//   _хенд, gyha_, --, --, 
   {{0x69d4011c,0x00000000,0x00000000,0x00000000}},	//   _eaze, --, --, --, 
   {{0x69d40a16,0xb4e40a17,0x00000000,0x00000000}},	//   _faze, कम्प_, --, --, 
   {{0x69d40a18,0x442c007c,0x00000000,0x00000000}},	//   _gaze, _ajg_, --, --, 
   {{0x2d8401ed,0x00000000,0x00000000,0x00000000}},	//   űleg_, --, --, --, 
   {{0x69d40a19,0x2d900a1a,0x442c01a4,0x799c02d0}},	//   _zaze, zaze_, _cjg_, _hdrw, 
   {{0x2d900a1b,0xa3e00a1c,0x69d40a1d,0x32540139}},	//   yaze_, दाज_, _yaze, мвир, 
   {{0x8af80a1e,0x2d90014b,0x442c072b,0x69d40166}},	//   צהיי, xaze_, _ejg_, _xaze, 
   {{0xd54801d9,0x442c0076,0x600403f2,0x2d90013a}},	//   _الاو_, _fjg_, _tóml, vaze_, 
   {{0x2d900a1f,0x38a00311,0x4dc8005e,0x9f5000a2}},	//   waze_, mără_, ﻪﺗﯩﻨ, _alyñ_, 
   {{0x2d900a20,0x93440a21,0x91e401a9,0x00000000}},	//   taze_, _энде, _ноде, --, 
   {{0x6d44035b,0x1db00073,0x00000000,0x00000000}},	//   _pyha, _जाणत, --, --, 
   {{0x69d40a22,0xc1b80302,0x38a00276,0xa3e00490}},	//   _raze, _המוש, nără_, दाच_, 
   {{0x69d40a23,0x2d900a24,0x799c0585,0x6d4402fb}},	//   _saze, saze_, _adrw, _vyha, 
   {{0x69d40a25,0x24740a26,0xfb340a27,0xed5800ee}},	// [670] _paze, _māma_, ентэ, соң_, 
   {{0x799c03ac,0x3ea400d0,0x5e680050,0x69d403e3}},	//   _cdrw, ámte_, _گٔیہ_, _qaze, 
   {{0x799c0368,0x7e44030d,0x3d2005ac,0x00000000}},	//   _ddrw, _яхъе, _মুঠ্_, --, 
   {{0x24740a28,0x69d40a29,0x29000a2a,0x8d8400f2}},	//   _nāma_, _waze, ryha_, _بشکن, 
   {{0x60300a2b,0xd7ec0a2c,0x69d40a2d,0x799c02d0}},	//   nāma, شكو_, _taze, _fdrw, 
   {{0x68e001ed,0x7d080194,0x2900035b,0x2120010b}},	//   _áldo, ødsg, pyha_, _ýhhg_, 
   {{0x442c0a2e,0x2488098d,0x60300882,0xfbd00133}},	//   _pjg_, ćamo_, hāma, _شتێ_, 
   {{0x60300882,0xa2a007b7,0x55700166,0xd0740092}},	//   kāma, _खिद्, нгәт, _አሰራሩ_, 
   {{0x7c280077,0x25f401ad,0x24740a2f,0x00000000}},	//   édri, _एचपी_, _dāma_, --, 
   {{0x85b801d9,0x60300a30,0x38a00311,0xa3b00864}},	//   _دارس_, dāma, bără_, ञ्ज_, 
   {{0x9fc80a31,0x6b9c03ac,0x38a00356,0x12c801ec}},	//   огна_, _odsg, cără_, _ﻓﻴﻜﻭ, 
   {{0x60300421,0xdbf00118,0x00000000,0x00000000}},	//   fāma, třís, --, --, 
   {{0x64480a32,0x443c0a33,0x9440014d,0x00000000}},	//   mlei, mou_, _جھون, --, 
   {{0x443c0a34,0x00000000,0x00000000,0x00000000}},	//   lou_, --, --, --, 
   {{0x64480a35,0x1d080a36,0xe0d40006,0x247400b8}},	//   olei, цеви_, _цюль, _yāma_, 
   {{0x64480a37,0x443c0a38,0xa3b000dc,0xdbf00118}},	//   nlei, nou_, ञ्च_, přís, 
   {{0x64480a39,0x443c0a3a,0x600400d2,0x8c400a3b}},	// [680] ilei, iou_, _lómk, тете, 
   {{0x64480a3c,0x443c0a3d,0xeb540447,0x3e740108}},	//   hlei, hou_, رىلگ, _iät_, 
   {{0x64480a3e,0x443c0a3f,0x3e740a40,0xd7f8084c}},	//   klei, kou_, _hät_, жул_, 
   {{0x443c0a41,0x64480369,0x57480a42,0x3e740a43}},	//   jou_, jlei, озем_, _kät_, 
   {{0x443c0a44,0x7c240a45,0x64480a46,0x629c01ed}},	//   dou_, miir, dlei, ásol, 
   {{0x64480a47,0x3e740a48,0x7c240a49,0x443c0165}},	//   elei, _mät_, liir, eou_, 
   {{0x3e7401e6,0x94a80a4a,0xd94403f6,0x6d40025c}},	//   _lät_, ітка_, _цеви, żlav, 
   {{0x64480a4b,0x443c0a4c,0x7c240a4d,0x60300882}},	//   glei, gou_, niir, yāma, 
   {{0x3e7401e6,0xcd4c0092,0x247400cd,0x00000000}},	//   _nät_, _በድንገ, _vāma_, --, 
   {{0x7c240a4e,0x64480a4f,0x38a00356,0x00000000}},	//   hiir, alei, pără_, --, 
   {{0x64480a50,0x7c240a51,0x6fb40a52,0x93140451}},	//   blei, kiir, ىمدا, _ڪوشش, 
   {{0x443c0a53,0x60300a54,0x7c240a55,0x3e740139}},	//   cou_, tāma, jiir, _bät_, 
   {{0x7c240a56,0x6b9c01ab,0x25f40073,0x69c00139}},	//   diir, _rdsg, ्सची_, _öleg, 
   {{0x60300a2b,0x3e740793,0x14c00490,0x600400ae}},	//   rāma, _dät_, _शहाण, _lómh, 
   {{0x7c240a57,0x603000dc,0xb5fc0135,0x00000000}},	//   fiir, sāma, _riġl, --, 
   {{0x7df80166,0x7c240a58,0x09a40a59,0x09c40a5a}},	//   _aşsı, giir, खल्य, रज्य, 
   {{0xfc6402e8,0xaa540a5b,0x00000000,0x00000000}},	// [690] търн, еваш, --, --, 
   {{0x443c0a5c,0x7c240083,0x64480a5d,0xa2a000af}},	//   zou_, aiir, zlei, _खिस्, 
   {{0x443c0a5e,0x7c240a5f,0x64480a60,0x8ca002dd}},	//   you_, biir, ylei, _جەزو, 
   {{0x27e80a61,0x443c0a62,0x7c240a63,0x7d080a64}},	//   ñan_, xou_, ciir, ødse, 
   {{0x443c0a65,0x64480660,0x65c40064,0x7c28067c}},	//   vou_, vlei, ебла, èdre, 
   {{0x443c0a66,0x64480a67,0x6aac0a68,0x19e40327}},	//   wou_, wlei, muaf, སྐྱབ, 
   {{0x443c0a69,0x60040491,0x64480a6a,0xe3b00597}},	//   tou_, _fómh, tlei, هرة_, 
   {{0x37a80137,0x443c0a6b,0x00000000,0x00000000}},	//   _отун_, uou_, --, --, 
   {{0x64480a6c,0x6aac0a6d,0x20100023,0xb5fc0003}},	//   rlei, nuaf, ëzim_, _miġj, 
   {{0x443c0a6e,0xe1f00491,0x7c240a6f,0xb6100882}},	//   sou_, اسة_, ziir, āṣit, 
   {{0x60240a70,0x64480a71,0x443c0a72,0x6aac0418}},	//   една, plei, pou_, huaf, 
   {{0x600400d2,0x443c0a73,0x6aac0a74,0x64480007}},	//   _kómi, qou_, kuaf, qlei, 
   {{0x7c240a75,0x4f040a76,0x2474002b,0x21a4022e}},	//   viir, енян_, _kāmo_, _зилм, 
   {{0x2c7404ce,0xdd900a77,0x69c00a78,0x7c240a79}},	//   _båd_, طور_, र्मी, wiir, 
   {{0x7c240a7a,0xd00c0a7b,0x3e740139,0x91b40a7c}},	//   tiir, _گلي_, _wät_, _נפקא_, 
   {{0x3e740a7d,0x6aac0a7e,0xb5fc025c,0x2c740a7f}},	//   _tät_, fuaf, _riġm, _dåd_, 
   {{0x60040a80,0x7c240750,0xd00c082e,0x1f6402bf}},	// [6a0] _nómi, riir, _دلي_, _яким, 
   {{0x7c240a81,0x0b400372,0xa3b0033f,0x600401e7}},	//   siir, унун, फ़्त_, _sómh, 
   {{0x7c240a82,0x1be80a83,0xcdb4011a,0xdb1403b9}},	//   piir, _едни_, _אפיה_, leyü, 
   {{0x60040085,0x95f803ce,0x2c0001e0,0x7c240a84}},	//   _bómi, ्स्ट_, _күсм, qiir, 
   {{0x600409ff,0xdb04002f,0x6d400003,0xc8480240}},	//   _cómi, _abkö, żlat, _ዝኣምን, 
   {{0x20100a85,0x60040a86,0x9998012d,0x0f34010f}},	//   ëzij_, _dómi, żyły_, ערסט_, 
   {{0xe3d8009e,0x6fb00073,0x60040a87,0x00000000}},	//   থানব, _झालं, _tómh, --, 
   {{0xccf006a9,0xb5fc0327,0x0440041b,0x60300a88}},	//   רכה_, _xiġj, лејн, dāmo, 
   {{0x07b4007b,0x600402d2,0x52240a89,0xc7a00229}},	//   _سهلة_, _gómi, ефна, _щитк, 
   {{0x872000d4,0x00000000,0x00000000,0x00000000}},	//   _смуж, --, --, --, 
   {{0x313400fd,0x00000000,0x00000000,0x00000000}},	//   тенр, --, --, --, 
   {{0x2c7400ed,0x00000000,0x00000000,0x00000000}},	//   _råd_, --, --, --, 
   {{0x24740055,0x69c00a8a,0x00000000,0x00000000}},	//   _yāmo_, र्डी, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa4a401e1,0x00000000,0x00000000,0x00000000}},	//   _ibòí, --, --, --, 
   {{0x59c406ab,0x6aac0a8b,0xdfd005d9,0x2c7400b5}},	//   _रॉबर, tuaf, _نيٺ_, _våd_, 
   {{0x7b740597,0x314c02d3,0x49c8005b,0x88b400fe}},	// [6b0] اطفا, _ማሕበር, зуем_, ীয়াক, 
   {{0xd8e00327,0x6d400a8c,0x3cec00d7,0x00000000}},	//   སའཕྲ, ülas, ťdva_, --, 
   {{0x48a80a8d,0x6aac0134,0xac18094f,0x247400dc}},	//   ятам_, suaf, _жону_, _rāmo_, 
   {{0x629c01ed,0x6aac0618,0xf7700a8e,0xc8480023}},	//   ások, puaf, ماه_, _ዝኣመን, 
   {{0x6aac0395,0xc6680a8f,0x00000000,0x00000000}},	//   quaf, чшее_, --, --, 
   {{0x60040a90,0xa5640a91,0x64a40a92,0xd7000a93}},	//   _vómi, نگان, вака, рзши, 
   {{0x69c00a94,0x94d001f7,0xe89401c6,0x24740055}},	//   र्णी, ليوش, _шавь, _vāmo_, 
   {{0x60040a95,0x69c003e0,0x86b00150,0x00000000}},	//   _tómi, _öleb, _бәкі, --, 
   {{0x27ec0a96,0x69c00a97,0x64b401ef,0x00000000}},	//   _inen_, र्थी, dřiš, --, 
   {{0x603000b0,0x09cc0154,0x00000000,0x00000000}},	//   tāmo, রাকা, --, --, 
   {{0xba04001f,0xf484033a,0x21680120,0x00000000}},	//   _ግድ_, _бучн, ќини_, --, 
   {{0xe1f00a98,0x69c00a99,0x00000000,0x00000000}},	//   اسک_, र्ती, --, --, 
   {{0xf58400db,0xb9f80092,0x00000000,0x00000000}},	//   _ششەپ, _ዘፀ_, --, --, 
   {{0x1cdc031c,0x603000b0,0xfe78009d,0x614400fb}},	//   _རླུ_, pāmo, _үүн_, _иела, 
   {{0x64580a9a,0x27ec0a9b,0xaec002dd,0x5bb400c0}},	//   _khwi, _onen_, _құрл, ксаф, 
   {{0xdb140100,0x27ec0a9c,0x00000000,0x00000000}},	//   deyò, _nnen_, --, --, 
   {{0xdb0c0a9d,0x19940114,0xda640a9e,0x1b4800d8}},	// [6c0] _öküz, вјер, ناطي, фзаи_, 
   {{0x204c0020,0x27ec0a9f,0x00000000,0x00000000}},	//   _ማህበረ, _anen_, --, --, 
   {{0x6458016b,0x35c4033f,0x05100154,0x00000000}},	//   _ohwi, ल्फ़, িপুর_, --, 
   {{0x645802c4,0x8c400724,0x09cc015b,0x661c0006}},	//   _nhwi, äşte, রাগা, _įska, 
   {{0xc6d00aa0,0x00000000,0x00000000,0x00000000}},	//   لتوت, --, --, --, 
   {{0x27ec0aa1,0x997400db,0x69c00aa2,0x00000000}},	//   _enen_, _шумш, र्दी, --, 
   {{0xb5fc003d,0xaad401e1,0x00000000,0x00000000}},	//   _jiġi, _òlòó_, --, --, 
   {{0x64580aa3,0x38bc0aa4,0x27ec0295,0x983402d5}},	//   _chwi, mír_, _gnen_, _рэгі, 
   {{0x51840aa5,0xf5b400dd,0xb5fc003d,0x38bc03da}},	//   куна, _مشاھ, _liġi, lír_, 
   {{0xf6640137,0x53300022,0x00000000,0x00000000}},	//   _сезү, леқт, --, --, 
   {{0xb5fc0327,0x60040174,0x76480118,0x38bc0aa6}},	//   _niġi, _lómu, _ikdy, nír_, 
   {{0x53440aa7,0x03a00aa8,0x00000000,0x00000000}},	//   _ихла, _вицо, --, --, 
   {{0x40340aa9,0x38bc0aaa,0x4ea40801,0xf2c400d1}},	//   реяс, hír_, ърна, _сөйи, 
   {{0x4204013e,0x270400cc,0x00000000,0x00000000}},	//   _инчо_, _শেডো_, --, --, 
   {{0x82bc038f,0x64b40118,0x60040aab,0x00000000}},	//   _མདོའ, přiš, _rómv, --, 
   {{0xb5fc0003,0x64580472,0x600408a5,0xc0c40114}},	//   _diġi, _xhwi, _bómu, _руше_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [6d0] --, --, --, --, 
   {{0x27ec03f9,0x60040321,0x0e440166,0x8d54013d}},	//   _snen_, _dómu, _шэйм, _үтүч, 
   {{0xe5a40aac,0x38bc032e,0x00000000,0x00000000}},	//   ҳили, gír_, --, --, 
   {{0xac1800d6,0x7648010b,0xfb84074d,0x92000055}},	//   _чому_, _akdy, _вырн, _śālo, 
   {{0xf7700aad,0xe5a40aae,0xa6c40aaf,0x82bc0135}},	//   زان_, гили, اقتى, _མདེའ, 
   {{0xd6cc0220,0x64580ab0,0x00000000,0x00000000}},	//   سقى_, _shwi, --, --, 
   {{0x25a807c4,0x64580161,0xdb140413,0xf650009f}},	//   ğal_, _phwi, leyð, آئن_, 
   {{0x27ec0ab1,0x00000000,0x00000000,0x00000000}},	//   _unen_, --, --, --, 
   {{0x36d402bf,0x53c4010b,0xdb1406ea,0x051000eb}},	//   _котр, угым_, neyð, িপের_, 
   {{0x71a40220,0x00000000,0x00000000,0x00000000}},	//   ңаөз, --, --, --, 
   {{0x66000165,0xe1240ab2,0x00000000,0x00000000}},	//   _iolk, умни, --, --, 
   {{0x6600012c,0x6abc031c,0xb5fc025c,0xc5e80154}},	//   _holk, _oqsf, _riġi, _কতটা_, 
   {{0x66000ab3,0x764809a5,0xd12c0ab4,0xb5fc025c}},	//   _kolk, _ykdy, قمی_, _siġi, 
   {{0xb5fc0327,0x60040162,0x44e00ab5,0x712401b9}},	//   _piġi, _rómu, _kı_, اریل, 
   {{0x66000ab6,0x6abc035a,0x44e006be,0x38bc0306}},	//   _molk, _aqsf, _jı_, xír_, 
   {{0x44e00ab7,0x66000ab8,0x38bc0ab9,0xb5fc0327}},	//   _mı_, _lolk, vír_, _viġi, 
   {{0x44e00aba,0xdee40798,0x66000abb,0x600402d2}},	// [6e0] _lı_, _сопи, _oolk, _dómt, 
   {{0x3ea009d3,0xdddc0100,0x4d440116,0xb5fc0135}},	//   _ivit_, _sipņ, _әпюн_, _tiġi, 
   {{0x44e00abc,0x3ea002bf,0x57a401c6,0x00000000}},	//   _nı_, _hvit_, гшла, --, 
   {{0xb8dc0abd,0x3ea000fe,0x204c001f,0x1cdc031c}},	//   _आम_, _kvit_, _ማኅበረ, _རླག_, 
   {{0xc7a00abe,0x12ac00fe,0x2244017a,0xf1b8031c}},	//   сичк, _কন্দ, kolk_, siġi_, 
   {{0x7ae40abf,0x38bc0ac0,0x66000067,0x44e00ac1}},	//   mvit, pír_, _colk, _bı_, 
   {{0x7ae40ac2,0x66000066,0x44e003be,0x3f800270}},	//   lvit, _dolk, _cı_, _ofiu_, 
   {{0x33740ac3,0x44e00ac4,0x7bc40ac5,0x7ae400c5}},	//   шгир, _dı_, nfiu, ovit, 
   {{0x7ae40ac6,0x66000ac7,0x22440ac8,0x60040ac9}},	//   nvit, _folk, folk_, _lóms, 
   {{0x66000aca,0x66800acb,0x7ae40acc,0x7e60057b}},	//   _golk, _بیول, ivit, ïmpl, 
   {{0x59c40acd,0x3ea00100,0x7ae40ace,0xb0340acf}},	//   र्यर, _avit_, hvit, инош, 
   {{0x660005b1,0x5338074d,0x00000000,0x00000000}},	//   _zolk, _пулă, --, --, 
   {{0x66000ad0,0x3ea001a6,0x22440ad1,0x7ae40477}},	//   _yolk, _cvit_, bolk_, jvit, 
   {{0x27300016,0x7ae40ad2,0x44e003ee,0x1cdc025c}},	//   ạng_, dvit, _yı_, _རླང_, 
   {{0x3ea00ad3,0x7bc40ad4,0x8bc40ad5,0xfe24040e}},	//   _evit_, ffiu, лсад, сьян, 
   {{0x3a380109,0x600409f3,0x60c4000d,0x7ae402d2}},	//   _ajrp_, _dóms, _ähma, fvit, 
   {{0xaed407d6,0xce680ad6,0x59c40ad7,0x7ae40ad8}},	// [6f0] _топш, _прод_, र्भर, gvit, 
   {{0x7bc40194,0xdb140ad9,0x3f1402dd,0xfaa80ada}},	//   afiu, reyð, _ыдыс, اهلي_, 
   {{0x2d800943,0x7ae40adb,0x2ee805c7,0xb5fc0135}},	//   _ifhe_, avit, _hraf_, _jiġu, 
   {{0x47700046,0x2ee80092,0x7ae4020b,0x44e00adc}},	//   сқау, _kraf_, bvit, _rı_, 
   {{0x44e00add,0x6f1c0ade,0x09cc03d4,0xc6a40166}},	//   _sı_, nzsc, ৰাবা, уреи, 
   {{0x6b8c0adf,0x247402b1,0x66000014,0x6aac007f}},	//   lbag, _hāmi_, _qolk, mraf, 
   {{0x66000ae0,0x224405e4,0x67d40209,0x6b8c0363}},	//   _volk, volk_, _кову, obag, 
   {{0x69c40ae1,0x6b8c0ae2,0x22440ae3,0x6aac0ae4}},	//   lfhe, nbag, wolk_, oraf, 
   {{0x2d800943,0x21f402bf,0x6258020a,0xca340ae5}},	//   _ofhe_, аїнс, крор_, ﺗﺘﺎ_, 
   {{0x20c402bf,0x69c4007b,0x6b8c0ae6,0xd04803e3}},	//   айом, nfhe, hbag, _isfə, 
   {{0x7ae40ae7,0x2ee80ae8,0x6aac0ae9,0x60300aea}},	//   zvit, _araf_, hraf, lāmi, 
   {{0x71580aeb,0x2ee80368,0x2d94013f,0x60040030}},	//   ырыс_, _braf_, ɔdeɛ_, _róms, 
   {{0x1f540aec,0x60300aed,0x68e0000f,0x2ee80142}},	//   ртнё, nāmi, _âldf, _craf_, 
   {{0x2ee80aee,0x62880aef,0x6aac0af0,0x24840109}},	//   _draf_, mpeo, draf, _ktlm_, 
   {{0x2ee80af1,0x7bc40af2,0x6aac0549,0x6b8c0076}},	//   _eraf_, tfiu, eraf, fbag, 
   {{0x6b8c0af3,0x69c40af4,0x3ea000f3,0x628800b0}},	//   gbag, efhe, _tvit_, opeo, 
   {{0x7bc40af5,0x9aa40af6,0x7ae404cc,0x603000e2}},	// [700] rfiu, شماو, uvit, jāmi, 
   {{0x20e402b5,0x6b8c0af7,0x600401a8,0x61e00472}},	//   _kēi_, abag, _tóms, ndll, 
   {{0x7ae40af8,0x6aac0af9,0x6b8c0afa,0x18680120}},	//   svit, araf, bbag, важи_, 
   {{0x69c00afb,0x603003a0,0x69c40afc,0x24740055}},	//   _ölen, fāmi, afhe, _gāmi_, 
   {{0xda640afd,0xfe3c00b5,0x68e401ab,0x4cc80154}},	//   _ناسي, pはdb_, avhd, ায়দু, 
   {{0x25a40042,0x69c40afe,0x3a28013d,0xceb0011a}},	//   _cdll_, cfhe, _сегү_, קיו_, 
   {{0xdcfc00e2,0x59c40aff,0x61e00042,0x247400b8}},	//   _iepē, र्णर, ddll, _yāmi_, 
   {{0xb2b80b00,0xd9440b01,0x53e401f4,0x00000000}},	//   глиф_, _беҳи, рцка, --, 
   {{0x73c40184,0x38780076,0xb5fc0327,0x59c40b02}},	//   _ғәйе, _hurr_, _siġu, र्थर, 
   {{0x1db00574,0x387802d3,0x14ac0b03,0x2ee80200}},	//   _जागत, _kurr_, _टिपण, _rraf_, 
   {{0x2ee800f3,0x7d0808fb,0x6b8c0b04,0x855400e5}},	//   _sraf_, ødsl, ybag, _پیٹر_, 
   {{0x6f1c0b05,0x38780004,0x2ee8084c,0x64c002e3}},	//   tzsc, _murr_, _praf_, ịich, 
   {{0xb8d80156,0x69c4017a,0xac180107,0x2ee806be}},	//   _མཀ_, yfhe, ҳову_, _qraf_, 
   {{0x6f1c0b06,0x6aac0395,0x8d14013e,0xdcfc00de}},	//   rzsc, vraf, ангӣ_, _nepē, 
   {{0x6b8c0b07,0xac180b08,0x2450004d,0x38780254}},	//   tbag, гову_, _sơmi_, _nurr_, 
   {{0x6aac0b09,0x2ee80b0a,0x6b740166,0x6b8c0072}},	//   traf, _traf_, слау, ubag, 
   {{0x6b8c0b0b,0xc9840a2c,0xed580032,0x60040413}},	// [710] rbag, لشاي, тоң_, _tómr, 
   {{0x6aac0b0c,0x79f4040e,0x38780b0d,0xdcfc0171}},	//   rraf, озух, _burr_, _cepē, 
   {{0x38780b0e,0xc8640b0f,0x24740b10,0x69c4007b}},	//   _curr_, атди, _tāmi_, rfhe, 
   {{0x62880b11,0x6aac00a8,0x24840b12,0x60300b13}},	//   ypeo, praf, _rtlm_, tāmi, 
   {{0xa6c80b14,0x66e400c2,0x6aac00ac,0x9ba000db}},	//   улла_, сола, qraf, _رەلى, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x38780b15,0x00000000,0x00000000,0x00000000}},	//   _gurr_, --, --, --, 
   {{0xd3440133,0xa0a400fb,0x00000000,0x00000000}},	//   ڕینه_, ҙамд, --, --, 
   {{0x26cc00ec,0xa7140640,0x13e40166,0x00000000}},	//   _upeo_, _удаљ, смый_, --, 
   {{0xe1f80b16,0xe53400c0,0xe0e401e1,0x00000000}},	//   уго_, _лезь, _òòka_, --, 
   {{0xd24c0b17,0x62880b18,0x655400ec,0x00000000}},	//   رچه_, speo, _اپاء, --, 
   {{0x60040b19,0x62880b1a,0x9f0400c6,0x00000000}},	//   _cómp, ppeo, موجو, --, 
   {{0x201c0953,0x64480b1b,0x61e0074d,0x60040162}},	//   ėti_, moei, pdll, _dómp, 
   {{0x64480b1c,0x99e00154,0x00000000,0x00000000}},	//   loei, _মক্ক, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x64480b1d,0xb5fc0003,0x24400419,0x00000000}},	//   noei, _jiġr, tómy_, --, 
   {{0x2a700334,0x2a78058a,0x38780b1e,0xb5fc0327}},	// [720] _bizb_, _cusb_, _surr_, _miġr, 
   {{0x644801a4,0x38780b1f,0x69c001d3,0xd9440395}},	//   hoei, _purr_, _ölel, бези, 
   {{0x1d080b20,0x64480942,0xe8900240,0x00000000}},	//   _сени_, koei, _ዝቐርቡ_, --, 
   {{0x2ca40b21,0x64480120,0xb5fc031c,0x38780254}},	//   âlde_, joei, _niġr, _vurr_, 
   {{0x64480086,0x00000000,0x00000000,0x00000000}},	//   doei, --, --, --, 
   {{0x38780b22,0x19f80276,0x3a2c0139,0xcaf401c8}},	//   _turr_, _сэмь_, _ödp_, _اسٽب, 
   {{0x64480b23,0x387801ab,0x54e400ae,0x00000000}},	//   foei, _uurr_, إستق, --, 
   {{0x64480005,0x1cdc0327,0x24740055,0x61e402d2}},	//   goei, _རླབ_, _nāmu_, _óhlj, 
   {{0xd20801c0,0x8778011a,0x00000000,0x00000000}},	//   гэнд_, _תאמי, --, --, 
   {{0x64480086,0x836001d5,0x2a700139,0xe5c80b24}},	//   aoei, سگنل, _xizb_, _نظمه_, 
   {{0x50640b25,0x644801f5,0x683000d0,0x93e4022e}},	//   йтма, boei, sťde, _гўлл, 
   {{0x68e00a85,0xcfa80271,0xa2a00b26,0x7664009f}},	//   _âlde, دادم_, _खिच्, _اُڄم, 
   {{0x0e40001f,0x247400e2,0x0f100b27,0x00000000}},	//   _የህክም, _dāmu_, डनेस_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6c8400c6,0x6a680006,0x3b380092,0x41c0007b}},	//   تلزم, _užfi, _በመጨመ, _رقيق, 
   {{0x09b000cd,0x00000000,0x00000000,0x00000000}},	//   ुभ्य, --, --, --, 
   {{0xca700b28,0xfd1001ed,0x3c58084c,0xa37c0142}},	// [730] سناک, وجہ_, ситэ_, ndŵa, 
   {{0x6fb40b29,0xff180375,0xae0c00bc,0x00000000}},	//   _امکا, _לקחת_, _सकिन_, --, 
   {{0x9f50033b,0x69c00b2a,0x91c800cd,0x00000000}},	//   _anyè_, _ölem, त्यै, --, 
   {{0x64480077,0x603000e2,0xcfa80154,0x00000000}},	//   xoei, sāmv, গ্রন, --, 
   {{0xc9840b2b,0x64480798,0x66040b2c,0x47d800cc}},	//   _губи, voei, жпла, ণালী, 
   {{0xb5fc0135,0xe89402e8,0xf9640133,0xa5080b2d}},	//   _siġr, _магь, _کۆمێ, иела_, 
   {{0x64480b2e,0xf6500b2f,0x00000000,0x00000000}},	//   toei, رئه_, --, --, 
   {{0x24080b30,0x4cc000eb,0x00000000,0x00000000}},	//   рнии_, শবপু, --, --, 
   {{0x28e0069f,0x64480b31,0x13040b32,0x59c40b33}},	//   फिकि, roei, жный_, र्वर, 
   {{0x7d080b34,0xd1c40108,0x00000000,0x00000000}},	//   ødsk, олье_, --, --, 
   {{0x64480b35,0x247404fe,0xe4d80b36,0xdbc400c5}},	//   poei, _pāmu_, _خوات_, mööd, 
   {{0xdbc40254,0x00000000,0x00000000,0x00000000}},	//   lööd, --, --, --, 
   {{0x5ab80156,0xe2980b37,0xd24c0b38,0x942400cf}},	//   པཕབམ, _тал_, رچۇ_, _بونۇ, 
   {{0x216800d8,0x00000000,0x00000000,0x00000000}},	//   _кили_, --, --, --, 
   {{0xd24c0b39,0x00000000,0x00000000,0x00000000}},	//   _جنو_, --, --, --, 
   {{0x60300b3a,0x82c4031c,0x69c000a2,0x6f0c0332}},	//   tāmu, _ཁྱོའ, _ölej, íocá, 
   {{0x21e002b1,0x1a040b3b,0x5d7401f0,0x00000000}},	// [740] _tōhē_, опам, _мунф, --, 
   {{0x0d80026b,0x00000000,0x00000000,0x00000000}},	//   _ольн, --, --, --, 
   {{0xa3e80b3c,0xd82401f4,0x00000000,0x00000000}},	//   मया_, оджи, --, --, 
   {{0x20000b3d,0x00000000,0x00000000,0x00000000}},	//   njki_, --, --, --, 
   {{0x0aa00046,0x8700034b,0xd6d400db,0x00000000}},	//   _оңтү, дяще, تتاغ, --, 
   {{0x82c4025c,0x94a80124,0xdbc40037,0xcb1000d9}},	//   _ཁྱེའ, атиа_, gööd, _חלש_, 
   {{0x1fb004c5,0x799c04e6,0xf8b001ed,0x08c00b3e}},	//   ট্যস, _ierw, _سکا_, _обрн, 
   {{0x799c0b3f,0xf3f800f0,0x00000000,0x00000000}},	//   _herw, сниш_, --, --, 
   {{0x799c00ee,0x69c00b40,0xcfe00154,0x9f5c01ec}},	//   _kerw, र्की, যামন, _ﺍﺭﻻﯞ_, 
   {{0x3218006d,0x799c0b41,0x63ac02a8,0xd2580b3e}},	//   óry_, _jerw, _ƴanc, јци_, 
   {{0x799c0b42,0xf4840b43,0x6d40003d,0x00000000}},	//   _merw, _راضی, żlaz, --, 
   {{0x799c0b44,0x61ec0b45,0x661c0153,0x00000000}},	//   _lerw, _ɗali, _įski, --, 
   {{0x91e40b46,0x799c0b47,0x3de403d4,0x161c00af}},	//   _моде, _oerw, মানল, _भतार_, 
   {{0x799c0b48,0x00000000,0x00000000,0x00000000}},	//   _nerw, --, --, --, 
   {{0xcfe401b9,0xcc28009d,0xc0f00092,0x00000000}},	//   _дўпп, ацад_, ቃብር_, --, 
   {{0x799c0b49,0xef9801a9,0x7d08007c,0x00000000}},	//   _aerw, _укиш_, ädsa, --, 
   {{0x799c0b4a,0x0dc8006c,0x60cc0b4b,0x3e880356}},	// [750] _berw, _куни_, _ćami, _cîtă_, 
   {{0x799c0142,0x7b6401e0,0x59c40b4c,0x00000000}},	//   _cerw, фтсе, र्लर, --, 
   {{0x799c0b4d,0x69c00b4e,0xdbc40037,0x00000000}},	//   _derw, र्गी, vööd, --, 
   {{0x799c0b4f,0xdddc0166,0x7a2001e3,0x6fac00fe}},	//   _eerw, _kipş, _nötf, ট্ৰে, 
   {{0x799c0b50,0x7db40517,0xdbc400c5,0xf7700b51}},	//   _ferw, _عصیا, tööd, ناه_, 
   {{0x6b9c015d,0x00000000,0x00000000,0x00000000}},	//   _hesg, --, --, --, 
   {{0x6b9c0209,0x7a2001e3,0x2408010b,0x87d4007b}},	//   _kesg, _bötf, йнки_, _وغرا, 
   {{0x6b9c0b52,0xe2980b53,0x5924031c,0x3d3c008f}},	//   _jesg, баи_, _རྟིས_, יגוס, 
   {{0x799c0b54,0x7c28004e,0x6b9c010b,0x3dd80175}},	//   _yerw, èdri, _mesg, yerw_, 
   {{0xdafc0589,0x6b9c01a4,0xd26000fd,0x35b40b55}},	//   _pãºc, _lesg, нкый, _обур, 
   {{0x6b9c0857,0x5574010f,0xa3d402e8,0xf484009b}},	//   _oesg, _זעען_, _ножч, _жучн, 
   {{0xf40802dd,0x349401c0,0x3dd8015d,0x00000000}},	//   _ويلى_, _цацр, werw_, --, 
   {{0xe2840b56,0x6d4006af,0xdd9000e5,0x00000000}},	//   _элли, ûlan, ٹوز_, --, 
   {{0x1d080b57,0xc4bc012c,0x649c0241,0x00000000}},	//   беги_, _एमाओ, _ṣiye, --, 
   {{0x799c0b58,0x6b9c0036,0x3dd800ca,0xa0680b59}},	//   _rerw, _besg, rerw_, _лака_, 
   {{0x799c0b5a,0x6b9c0b5b,0x00000000,0x00000000}},	//   _serw, _cesg, --, --, 
   {{0x6b9c0b5c,0x799c0b5d,0xcb6400a8,0x00000000}},	// [760] _desg, _perw, зате_, --, 
   {{0x09e00b5e,0x00000000,0x00000000,0x00000000}},	//   ноун, --, --, --, 
   {{0x799c0b5f,0x6b9c0b60,0x99480b61,0x5f7401e2}},	//   _verw, _fesg, حلال_, _باګر, 
   {{0x799c0b62,0x6b9c015d,0xf7b800db,0x00000000}},	//   _werw, _gesg, تۇرع_, --, 
   {{0x799c0b63,0x15f80210,0x00000000,0x00000000}},	//   _terw, _एचआर_, --, --, 
   {{0xd4980b64,0x98a40b65,0x6b9c009a,0x799c04e6}},	//   бри_, _ниге, _zesg, _uerw, 
   {{0x62980009,0xcfe00011,0x2c4000c0,0x00000000}},	//   _awwo, যাতন, lėda_, --, 
   {{0x04600b66,0xb4ac0b67,0x493800d9,0xe87400d1}},	//   нтым, _कटी_, _הגלו, _قەلب_, 
   {{0xdb14020c,0x24a40092,0x00000000,0x00000000}},	//   èbèr, _ሊደርስ_, --, --, 
   {{0xe60801e2,0x00000000,0x00000000,0x00000000}},	//   _وزلو_, --, --, --, 
   {{0x69c00b68,0xe0840014,0x00000000,0x00000000}},	//   र्टी, وێوو_, --, --, 
   {{0x5ed4015b,0x7a20010b,0x6cd401ec,0x00000000}},	//   দিনে, _hötd, _ﺘﺴﺨﻴ, --, 
   {{0x6b9c0b69,0x244805d9,0x3f1402e8,0x7a2001e3}},	//   _resg, _بجلي_, едяс, _götg, 
   {{0x99cc03f4,0x6b9c04d4,0xacf80816,0x3e040395}},	//   রযুক, _sesg, онгу_, нясв, 
   {{0x3b000369,0xdddc01ed,0x6b9c0b6a,0x7a200139}},	//   exiq_, _cipő, _pesg, _mötd, 
   {{0x26180100,0x00000000,0x00000000,0x00000000}},	//   _nèon_, --, --, --, 
   {{0x6b9c00e4,0xeb980116,0x8d8400db,0x2c400064}},	// [770] _vesg, йиң_, _нунд, gėda_, 
   {{0x6b9c0b6b,0x00000000,0x00000000,0x00000000}},	//   _wesg, --, --, --, 
   {{0xe6100133,0xddcc0419,0xaadc0118,0x00000000}},	//   ێشت_, dobň, _नैरक, --, 
   {{0xe7180b6c,0x6d44004b,0x69c00b6d,0x1ee8036b}},	//   ييات_, _ixha, र्जी, _اویی_, 
   {{0x37740b6e,0x7c28036e,0x443806be,0x00000000}},	//   нышс, ëdre, _ıq_, --, 
   {{0x8f480023,0x95740092,0x00000000,0x00000000}},	//   _ሓድነቶ, _ራሳችን_, --, --, 
   {{0x39a401d9,0x0744004b,0x999800e5,0x00000000}},	//   _سینہ, _کړای_, cipő_, --, 
   {{0x6d440b6f,0x60c40209,0x3e6401e6,0x41cc00cd}},	//   _mxha, _ähmi, möte_, त्नस, 
   {{0x651400b2,0x7668004b,0x3e640b70,0x00000000}},	//   _ڪوائ, _ځینې_, löte_, --, 
   {{0x6d440b71,0x7a2000a2,0x69c00b72,0x06380b73}},	//   _oxha, _götd, र्ची, _اسرع_, 
   {{0x6d440218,0xa0680b74,0x34940b75,0x6514038b}},	//   _nxha, жана_, _захр, _توائ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d440b76,0x6d480311,0x3b000429,0x7a2006be}},	//   _axha, şeal, xxiq_, _höte, 
   {{0x7a200b77,0x02680108,0x00000000,0x00000000}},	//   _köte, _ушей_, --, --, 
   {{0x442c0050,0x6024041b,0xdcfc00ef,0x00000000}},	//   _kmg_, _одка, _iepī, --, 
   {{0x7a20049f,0x442c0b78,0x59c401ad,0x5dd401ec}},	//   _möte, _jmg_, _रॉजर, _ﺘﻤﻬﻴ, 
   {{0x442c0b79,0x435402d3,0x6d440b7a,0x7a200112}},	// [780] _mmg_, _ምትብባ, _exha, _löte, 
   {{0x4a400b7b,0x00000000,0x00000000,0x00000000}},	//   внув, --, --, --, 
   {{0x41cc0b7c,0xb4ac0b7d,0xd7e402bf,0x57e80b7e}},	//   त्यस, _कटे_, діло, ждем_, 
   {{0x6cd40150,0x00000000,0x00000000,0x00000000}},	//   _ﺘﺴﺠﻴ, --, --, --, 
   {{0xc7a00b7f,0x07a00b80,0x00000000,0x00000000}},	//   тичк, тачн, --, --, 
   {{0x7a200598,0x9508025c,0xd9440b81,0x5ec802dd}},	//   _böte, ཀྱའི_, _жеги, _ﺑﻴﯟﺭ, 
   {{0x442c0209,0x44840032,0xa3e800dc,0xddcc00d7}},	//   _bmg_, үбән_, मयं_, robň, 
   {{0x442c037e,0xdec00b82,0x4cc800eb,0xa4900066}},	//   _cmg_, ድሶን_, ায়কু, اینت, 
   {{0x26b00075,0x07a001c0,0xd2440b83,0x442c0b84}},	//   _مەنز, _шатн, дэни, _dmg_, 
   {{0x6fc00073,0xe2340023,0x8af8010f,0x00000000}},	//   _वाहू, _ክብርና, קהיי, --, 
   {{0x7a200b85,0x442c0b86,0x7d0801e3,0x00000000}},	//   _göte, _fmg_, ädsl, --, 
   {{0x442c0089,0x4de402e5,0xa3e800cd,0x5dd401ec}},	//   _gmg_, _छोड़े_, मयः_, _ﺘﺤﻭﻴ, 
   {{0x244807c0,0x522400d8,0x00000000,0x00000000}},	//   _عجمي_, _офка, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfe240b87,0x39580b88,0x442c0142,0xc1b8011a}},	//   тьян, _nyrs_, _ymg_, _ומוש, 
   {{0x5064006c,0x91c80882,0x5fc402ab,0x7e6001a4}},	//   _ўтка, त्रै, _वायल, ïmpr, 
   {{0x39580076,0x625c020c,0xc054011a,0xea1800db}},	// [790] _ayrs_, kèol, _בזק_, пжаш_, 
   {{0x6d440b89,0x395802d2,0xc95802d5,0x00000000}},	//   _txha, _byrs_, оўе_, --, 
   {{0x6d440944,0xe9440b8a,0xd2440617,0xff50004b}},	//   _uxha, ررئی, _ەن_, _مخی_, 
   {{0x39580450,0xc61400dc,0x7a200b8b,0x0134011a}},	//   _dyrs_, थस्य_, _röte, ורבת_, 
   {{0x76c40b8c,0x442c01c7,0x7a200166,0x368800fb}},	//   نغول, _rmg_, _söte, үсән_, 
   {{0x37a80b8d,0xe4c400d1,0x7a2001b8,0x649800f7}},	//   птән_, ейки, _pöte, птир_, 
   {{0x7a200139,0x00000000,0x00000000,0x00000000}},	//   _qöte, --, --, --, 
   {{0xe7940b8e,0x7bc00793,0xe7380368,0x7a20007c}},	//   _سارک, _ömut, _ddŵr_, _götb, 
   {{0x38c4068c,0x6e3400a2,0x59c40b8f,0x00000000}},	//   _tèrç_, kizb, र्कर, --, 
   {{0x7a200b90,0x6e3400d0,0x973003c7,0xdb1400e5}},	//   _töte, jizb, _حکما, ngyá, 
   {{0x6e340b91,0x442c0b92,0x4ecc00cc,0x90b0035b}},	//   dizb, _tmg_, িটোল, гәыш, 
   {{0x3074084c,0x7a200139,0x00000000,0x00000000}},	//   куяс, _xötb, --, --, 
   {{0x443c0b93,0x6e340b94,0x7df0013f,0x80a80118}},	//   mnu_, fizb, lɔsɔ, _झिके, 
   {{0x91e0016c,0x61440b95,0x9f500162,0x626401c0}},	//   _боше, _пела, _doyð_, _явла, 
   {{0x1d080b96,0x6138010f,0x00000000,0x00000000}},	//   чеви_, _מײַס, --, --, 
   {{0xc87c0b97,0x00000000,0x00000000,0x00000000}},	//   ışla_, --, --, --, 
   {{0x34dc0b98,0xcfe0015b,0x7e640022,0x34ac00bc}},	// [7a0] _मन्द, যাশন, _иеиҧ, _घट्द, 
   {{0x443c0b99,0x8e940375,0x7df0013f,0xdb1400e5}},	//   hnu_, _רדיו_, kɔsɔ, ggyá, 
   {{0xd7f80262,0x68e0002d,0x625c004e,0x59c40b9a}},	//   зул_, _âldl, vèol, र्गर, 
   {{0x443c0b9b,0x41cc0b9c,0xf6ec031c,0x96e800d3}},	//   jnu_, त्तस, _རླུང, зька_, 
   {{0x443c0b9d,0xc0e40882,0x7c240b9e,0xd37800d1}},	//   dnu_, rāṇi_, mhir, үчи_, 
   {{0x443c0b9f,0xd4980ba0,0x7c240ba1,0x00000000}},	//   enu_, при_, lhir, --, 
   {{0x3b380020,0x1dd00a28,0x443c0ba2,0x5fc40574}},	//   _በመጀመ, द्यत, fnu_, _वाढल, 
   {{0x443c0ba3,0x7c240ba4,0x73d801a9,0x00000000}},	//   gnu_, nhir, фдир_, --, 
   {{0xe7d40ba5,0x7c240175,0xd65c074d,0x27e801e4}},	//   lığı, ihir, _дiад, ɾan_, 
   {{0x443c0ba6,0x7c240ba7,0x00000000,0x00000000}},	//   anu_, hhir, --, --, 
   {{0x7c240ba8,0x443c0ba9,0xe7d40baa,0xd1380212}},	//   khir, bnu_, nığı, яхи_, 
   {{0x6fc00073,0xfd540055,0x00000000,0x00000000}},	//   _वाळू, _upeṣ, --, --, 
   {{0x7c240bab,0x6e340bac,0xad240131,0x4ea40006}},	//   dhir, tizb, ھىرى, эрна, 
   {{0xad2403cc,0xf1a40073,0x231401af,0x00000000}},	//   پىرى, _खजिन, _шєхс, --, 
   {{0xc0e00b3e,0x8c640bad,0xe8200bae,0x6e3400d7}},	//   _бојк, етад, _मतला_, rizb, 
   {{0xe7d40baf,0x50640bb0,0x2ef40bb1,0x6a980150}},	//   dığı, _ятла, _азир, _ﺘﻨﻭﻉ_, 
   {{0xf1a40bb2,0xc87c0abc,0x6b74053f,0x7d08005c}},	// [7b0] _खजान, ışma_, тлау, ødsr, 
   {{0x7c2400ec,0x443c0bb3,0xe91800d4,0x3b54022e}},	//   ahir, znu_, мозі_, укур, 
   {{0x443c0bb4,0x7c240bb5,0xdb1401d3,0xac9402dd}},	//   ynu_, bhir, rgyá, _шанш, 
   {{0x7c240bb6,0x68e0000f,0x443c0009,0x3e6401e3}},	//   chir, _âldm, xnu_, möta_, 
   {{0x66e40bb7,0x6d400174,0x00000000,0x00000000}},	//   тола, úlaf, --, --, 
   {{0x27e80bb8,0x625c026c,0x7bc001a8,0xe7d40bb9}},	//   žan_, tèom, _ömur, bığı, 
   {{0xe7d40342,0x88b80327,0xa81c01ca,0x00000000}},	//   cığı, _པའིར, _дзвi, --, 
   {{0x443c0bba,0xd7ec00b2,0xf9900014,0x67d401e0}},	//   unu_, _وڃن_, _نبہ_, _шобу, 
   {{0x443c0bbb,0x7a2000b0,0x69c00bbc,0x13e4008e}},	//   rnu_, _höta, _öles, тмый_, 
   {{0xd24c0bbd,0x7c240489,0x7a200139,0x7d08007c}},	//   يني_, zhir, _köta, ädsk, 
   {{0x61440bbe,0x65180bbf,0x59c40bc0,0x00000000}},	//   тена, _تقاس_, र्टर, --, 
   {{0x443c0bc1,0x7a200267,0x7c24036e,0x5ed400eb}},	//   qnu_, _möta, xhir, দিসে, 
   {{0x69d40bc2,0x7c240433,0xdb0402fb,0x92e4010b}},	//   _obze, vhir, _odká, _аңың_, 
   {{0x7c240325,0xdb2401e1,0x00000000,0x00000000}},	//   whir, _ìpér, --, --, 
   {{0x7c240bc3,0x2730001e,0xe0440bc4,0xa3b40bc5}},	//   thir, ạnh_, _инки, _जया_, 
   {{0x7c240357,0x8c400261,0x69d40112,0x44e001d3}},	//   uhir, аесе, _abze, _mű_, 
   {{0xeab0066d,0x68f404cc,0x7c240bc6,0x68e0000f}},	// [7c0] یعے_, _arzd, rhir, _âldj, 
   {{0x68f40232,0x7a200309,0x3ea00428,0xe7d40bc7}},	//   _brzd, _böta, _iwit_, tığı, 
   {{0x7c240bc8,0x3ea00165,0xd7c401a9,0x00000000}},	//   phir, _hwit_, вёло, --, 
   {{0x7c240bc9,0x3ea002bd,0x59c40bca,0x00000000}},	//   qhir, _kwit_, र्जर, --, 
   {{0x68f4002f,0xd6280835,0x00000000,0x00000000}},	//   _erzd, моде_, --, --, 
   {{0x7ae40bcb,0xdcec0bcc,0x3ea00428,0x6d400bcd}},	//   mwit, labı, _mwit_, úlag, 
   {{0x7ae405e4,0x7a2001e6,0x98a40131,0xa4900bce}},	//   lwit, _göta, _шиве, میلت, 
   {{0x7bc40bcf,0xa7840597,0x0b9c00b7,0x6d400129}},	//   ngiu, _مشكو, _ጎንደር_, ûlai, 
   {{0x7ae4031c,0x32540bd0,0x6f0800e8,0x3ea00bd1}},	//   nwit, лвир, _mëbë, _nwit_, 
   {{0x3f800bd2,0x7bc40007,0x7e600356,0x7a200108}},	//   _agiu_, hgiu, împl, _yöta, 
   {{0x3ea00bd3,0x85980bd4,0x9f4c0232,0xdcec00fd}},	//   _awit_, _חשבו, čným_, kabı, 
   {{0x7ae40bd5,0xc950025f,0x6e940bd6,0x6f08002e}},	//   kwit, ימת_, лиму, _nëbë, 
   {{0xcd940023,0x00000000,0x00000000,0x00000000}},	//   _ጉዕዞና_, --, --, --, 
   {{0x7ae40bd7,0x7bc400c5,0x01300133,0xab900150}},	//   dwit, egiu, اعید, _ﺑﯩﻴﻚ_, 
   {{0x1dd004e4,0x7ae40354,0x8bc40bd8,0xc2780bd9}},	//   द्धत, ewit, ксад, _קרוי, 
   {{0x7bc40bda,0xdfd000b2,0x3ea002e2,0xe3c80077}},	//   ggiu, _هيٺ_, _fwit_, mañá_, 
   {{0x41cc0882,0x7a200267,0x3c580276,0x7ae40bdb}},	// [7d0] त्वस, _söta, титэ_, gwit, 
   {{0xf7f40502,0x2ee80bdc,0x7bd00024,0x00000000}},	//   یسند, _isaf_, _čiuž, --, 
   {{0x2d800bdd,0x3ea0061c,0x7ae4011f,0x6d400bcd}},	//   _ighe_, _zwit_, awit, úlad, 
   {{0x7ae40bde,0x3ea0007f,0xf9680064,0x7a200254}},	//   bwit, _ywit_, труй_, _vöta, 
   {{0x463007dd,0x52ac0131,0xa3b8000d,0x9ba00116}},	//   аҭар, _ﺳﻪﯞﻩ, _अएब_, _دەقى, 
   {{0x6b8c0bdf,0xc9840be0,0x6aac0be1,0x7a2000b0}},	//   lcag, _шуми, msaf, _töta, 
   {{0xd5ac0be2,0xd8b40214,0x7a2001d3,0x00000000}},	//   سفي_, _مگنا_, _kötn, --, 
   {{0x6b8c0be3,0x69c40be4,0xd4640be5,0x2fc80218}},	//   ncag, lghe, лище_, _ncag_, 
   {{0x6aac0be6,0x2bd40be7,0x65940be8,0x2d800be9}},	//   nsaf, ड्या, _базу, _oghe_, 
   {{0x2d8007ae,0x27ec0bea,0x6aac0099,0x7bc40beb}},	//   _nghe_, _haen_, isaf, zgiu, 
   {{0x69c40bec,0x27ec0bed,0x3ea00bee,0x7ae40bef}},	//   ighe, _kaen_, _swit_, zwit, 
   {{0x25a40bf0,0x7ae40bf1,0x27ec0bf2,0x2484011c}},	//   _hell_, ywit, _jaen_, _iulm_, 
   {{0x25a40bf3,0x63a80bf4,0x27ec0bf5,0x64580bf6}},	//   _kell_, maen, _maen_, _ikwi, 
   {{0x63a80bf7,0x27ec0bf8,0x24840bf9,0x25a40bfa}},	//   laen, _laen_, _kulm_, _jell_, 
   {{0x61e00bfb,0xdcec0bfc,0x25a40bfd,0x2ee801f2}},	//   mell, tabı, _mell_, _esaf_, 
   {{0x61e00bfe,0x63a80bff,0x6b8c074d,0x41cc0c00}},	//   lell, naen, gcag, त्रस, 
   {{0x7bc40c01,0x64580bd7,0xdcec0c02,0x6aac0c03}},	// [7e0] rgiu, _mkwi, rabı, gsaf, 
   {{0x25a40c04,0x7ae40c05,0x63a80c06,0xdcec0c07}},	//   _nell_, rwit, haen, sabı, 
   {{0x61e00801,0x27ec0399,0x63a80c08,0x20100c09}},	//   iell, _baen_, kaen, _koyi_, 
   {{0x27ec0097,0x6b8c0c0a,0x64580c0b,0x69c40731}},	//   _caen_, ccag, _nkwi, aghe, 
   {{0x61e00c0c,0x63a80c0d,0x27ec0c0e,0x20100c0f}},	//   kell, daen, _daen_, _moyi_, 
   {{0x64580c10,0x20100c11,0x61e00c12,0x25a40c13}},	//   _akwi, _loyi_, jell, _cell_, 
   {{0x61e00138,0x27ec0097,0x25a40c14,0x09bc0489}},	//   dell, _faen_, _dell_, _ཁྐྲ_, 
   {{0x63a80c15,0x61e0049b,0x201002b9,0x27ec0493}},	//   gaen, eell, _noyi_, _gaen_, 
   {{0x61e00c16,0x57440c17,0x969007d6,0x25a40c18}},	//   fell, _снаб, _ایتش, _fell_, 
   {{0x64580c19,0x25a40c1a,0x2fc80c1b,0x228808ce}},	//   _ekwi, _gell_, _scag_, _dúk_, 
   {{0x63a80c1c,0x20100c1d,0x27ec0007,0x2bd401ad}},	//   baen, _boyi_, _yaen_, ड्डा, 
   {{0x25a40c1e,0x63a80097,0x0ee805cc,0x69c40c1f}},	//   _zell_, caen, ньги_, zghe, 
   {{0x25a40c20,0x69c40c21,0x248401b9,0x5fc40c22}},	//   _yell_, yghe, _zulm_, _वारल, 
   {{0x7a200a48,0x60c00c23,0x6aac01bf,0x69c40327}},	//   _sötn, bulm, vsaf, xghe, 
   {{0x6b8c074d,0x60c00c24,0x420401d9,0x1b100154}},	//   tcag, culm, _حسنہ, _ঠেলে_, 
   {{0x6aac0c25,0x7c840c26,0x20100b45,0x2ee803f9}},	//   tsaf, суре, _goyi_, _tsaf_, 
   {{0x6b8c0c27,0x27ec0097,0x6d40022c,0x7a2008a5}},	// [7f0] rcag, _raen_, úlab, _vötn, 
   {{0x6b8c0c28,0x6aac0c29,0x69c40363,0x27ec0c2a}},	//   scag, rsaf, ughe, _saen_, 
   {{0x69c40c2b,0x6aac0c2c,0x63a80c2d,0xa3e40c2e}},	//   rghe, ssaf, yaen, _फसल_, 
   {{0x67d40c2f,0x25a40c30,0xac180c31,0x69c40332}},	//   роду, _sell_, _рому_, sghe, 
   {{0x63a80c32,0x25a40c33,0x24840023,0x27ec05c7}},	//   vaen, _pell_, _sulm_, _vaen_, 
   {{0x63a80c34,0x64580c35,0x27ec0c36,0x60c00c37}},	//   waen, _skwi, _waen_, yulm, 
   {{0x25a40c38,0x63a80c39,0x27ec0c3a,0x7a200254}},	//   _vell_, taen, _taen_, _mötl, 
   {{0x25a40c3b,0x60c00c3c,0x81c0035b,0x00000000}},	//   _well_, vulm, әанҧ, --, 
   {{0x61e00c3d,0x25a40c3e,0x21280198,0x52a40006}},	//   tell, _tell_, _ƙaho_, авым_, 
   {{0x63a80c3f,0x60c00c40,0x2010043b,0x04640220}},	//   saen, tulm, _soyi_, _өтем, 
   {{0x63a80c41,0x36040bbf,0x8ca4000d,0x2010022e}},	//   paen, _دولف, टीमो, _poyi_, 
   {{0x61e00c42,0x64580c43,0x60c00c44,0x2288011f}},	//   sell, _ukwi, rulm, _túk_, 
   {{0x60c00c45,0x61e00c46,0x00000000,0x00000000}},	//   sulm, pell, --, --, 
   {{0x61e00c47,0x2010013f,0x6e240076,0x60c00c48}},	//   qell, _woyi_, _clhb, pulm, 
   {{0xdca40c49,0x7a200793,0x2010017a,0x60c00477}},	//   раби, _söto, _toyi_, qulm, 
   {{0x7a2001b8,0x00000000,0x00000000,0x00000000}},	//   _pöto, --, --, --, 
  
   {{0xdee40c4a,0xb0680c4b,0xa2bc0c4c,0x7a2001a8}},	// [800] _топи, _حصول_, _शिफ्, _fötl, 
   {{0x6d400597,0x6e24005a,0x6494031c,0xa2bc01ad}},	//   úlac, _glhb, _iġif, _शिन्, 
   {{0x2d9403a5,0x57a40c4d,0xa3e4012d,0x00000000}},	//   _урыс, ашла, _फसं_, --, 
   {{0xded40201,0x9f400240,0xb17c01e4,0x7d1c0c4e}},	//   _ይሁን_, jekë_, neĥa, myrs, 
   {{0xc6a00371,0xdddc0055,0xdb04036e,0x7d0801bf}},	//   орщи, _nipū, _mekë, ådsf, 
   {{0xdb040023,0x7a20008e,0xe9a80c4f,0x00000000}},	//   _lekë, _kötm, _مدفن_, --, 
   {{0x55040209,0x628402b5,0x00000000,0x00000000}},	//   рчла, _ōhop, --, --, 
   {{0x43800c50,0x999800b0,0x98680276,0x748c00d1}},	//   يلىق, kipū_, _рибб_, _ﻗﺎﭼﯩ, 
   {{0x63bc0c51,0xb17c01e4,0x3a380139,0x7d1c0b6a}},	//   ósna, deĥa, _kmrp_, hyrs, 
   {{0x7d1c06a3,0xf53801e4,0xd4d40953,0xc0340014}},	//   kyrs, _leĥi_, _відэ, ۪ژوک, 
   {{0xdb040c52,0x506401b9,0x92d4015b,0xe4f800dc}},	//   _bekë, итма, াটে_, ्मणि_, 
   {{0x32440032,0x76580c53,0xdb040240,0x7a200166}},	//   реүг, lovy, _cekë, _sötl, 
   {{0x32940597,0x00000000,0x00000000,0x00000000}},	//   _التأ, --, --, --, 
   {{0x76580306,0x8318010f,0x00000000,0x00000000}},	//   novy, _בודז, --, --, 
   {{0x0ba40c54,0x0c84010b,0x7d1c0432,0x00000000}},	//   ишам, рыгм, gyrs, --, 
   {{0xf21c0c2e,0xdb0404e6,0x7658009f,0x6fc00490}},	//   _पकड़_, _gekë, hovy, _वाटू, 
   {{0xc9840588,0x32d001fb,0xaed40640,0x76580c53}},	// [810] ауеи, này_, _уопш, kovy, 
   {{0x765807a8,0x6f1c003e,0x7a2000a2,0x0ca8008e}},	//   jovy, mysc, _hötj, _итми_, 
   {{0x6f1c02d0,0x76580153,0x7d0801e3,0x00000000}},	//   lysc, dovy, ädst, --, 
   {{0xd1240c55,0xa7740c56,0x6d480311,0x6aa8025c}},	//   _ہم_, блеч, şeas, _ħeff, 
   {{0x8b64006c,0xd12400f1,0x8b000210,0x00000000}},	//   _خادم, _ځم_, łębs, --, 
   {{0x2d900c57,0xdddc002b,0x00000000,0x00000000}},	//   ncze_, _ripū, --, --, 
   {{0x92d40c58,0xdb2403e6,0xf6080133,0x9f40036e}},	//   াটো_, _نوێی, شتوه_, tekë_, 
   {{0xa3e80c59,0xded4001f,0x5fc40c5a,0x6f1c00d7}},	//   удиа_, _ይሁኑ_, _वाइल, kysc, 
   {{0x9f400c5b,0x765800c7,0xdb04036e,0x32d00051}},	//   rekë_, bovy, _rekë, gày_, 
   {{0xdb0401bf,0x765802f0,0x32d40006,0xdddc0055}},	//   _udkå, covy, іцыс, _vipū, 
   {{0x1fa801b9,0xe49800d8,0x34940c5c,0x2d900210}},	//   лкни_, _скеч_, _дахр, dcze_, 
   {{0xdee40c5d,0x999802b5,0x7a20007c,0x9f400c5e}},	//   боми, tipū_, _rötm, leké_, 
   {{0x28c802ab,0x7a2001e3,0x00000000,0x00000000}},	//   ांडि, _sötm, --, --, 
   {{0x2168044c,0x7d1c0c5f,0x999800b0,0x656001f4}},	//   _йили_, tyrs, ripū_, _kylh, 
   {{0x6fc00490,0x5bb40c60,0x65600108,0x00000000}},	//   _वाचू, йсаф, _jylh, --, 
   {{0x6f1c0c61,0x6d40022c,0x62640131,0x2d90033f}},	//   bysc, úlaa, _ئاچق, acze_, 
   {{0x20d003df,0x765800ca,0x88d0031c,0x80bc0073}},	// [820] lái_, yovy, _ཌཱུར, लंके, 
   {{0x7d1c06a3,0xf9c40c62,0x00000000,0x00000000}},	//   pyrs, تحری, --, --, 
   {{0x20d00c63,0xd238008f,0xe3ac02f5,0x2ca4000f}},	//   nái_, נגעל, _গানব, âldt_, 
   {{0x7a20008e,0x9f400100,0xb6c801d3,0xdb0400e5}},	//   _kötk, tekè_, لاتے_, _leké, 
   {{0x20d000c7,0x9f5000a2,0x765802f0,0x3cf80175}},	//   hái_, _anyú_, tovy, lvrv_, 
   {{0x20d0035b,0xdb040c64,0x3a28013d,0x38c8030f}},	//   kái_, _rekè, _тегү_, _پاسی_, 
   {{0x76580c65,0x26180c66,0x6f1c0034,0xdb04020c}},	//   rovy, _बकरी_, zysc, _sekè, 
   {{0x76580c67,0x2904041a,0xb2b80c68,0x2d900210}},	//   sovy, _šlag_, алиф_, zcze_, 
   {{0x46a00c69,0x7a200267,0x76580022,0x2d900210}},	//   _натв, _nötk, povy, ycze_, 
   {{0xe46409a5,0xdb040c6a,0xf23806ed,0x388803e0}},	//   _ýöne_, _ceké, рпош_, _ağri_, 
   {{0x20d000c7,0xa5cc00bc,0x09f4011a,0x00000000}},	//   gái_, _सातौ, זמים_, --, 
   {{0x6f1c074d,0x2d90068f,0x897808a8,0x136800d4}},	//   tysc, wcze_, טריצ, _йшли_, 
   {{0x20d0035b,0x814001d5,0x00000000,0x00000000}},	//   aái_, قنین, --, --, 
   {{0x20d00c63,0x2d840c6b,0xdb0401c7,0x388803e0}},	//   bái_, øle_, _geké, _eğri_, 
   {{0x3134040e,0x2d900034,0x20d003df,0xf1a000d1}},	//   _фейр, rcze_, cái_, _ﺋﯘﻗﯘ, 
   {{0x6494031c,0x95580023,0xd378010a,0x2d900210}},	//   _wġig, _ኲናትን_, _рчç_, scze_, 
   {{0x6494031c,0x7a200c6c,0xa66801ee,0x2d900210}},	// [830] _iġie, _köth, _йыhа, pcze_, 
   {{0x6d18031c,0x30ec00dc,0x64940003,0xa9c00137}},	//   ུགདེ_, _जनाः_, _uġig, بۅسۉ, 
   {{0xda180037,0x9f400c6d,0x2ea801f9,0x9dd4011a}},	//   _धवरत_, veké_, _कबुत, _וותק_, 
   {{0x2bc803cc,0x6494031c,0x9f40034c,0x00000000}},	//   _өлүп_, _jġie, weké_, --, 
   {{0x65600649,0x6494025c,0x9f400214,0xd7e401ec}},	//   _sylh, _mġie, teké_, імше_, 
   {{0xa934010b,0xc1b402a0,0x2bd40c6e,0x05b808f0}},	//   _дегш, _आयेग, ड्रा, ادشت_, 
   {{0x2408011b,0xdb04003e,0x00000000,0x00000000}},	//   инки_, _reké, --, --, 
   {{0x64940327,0xa2bc0c6f,0xb17c0115,0x2ea80c70}},	//   _nġie, _शिद्, teĥn, _कबूत, 
   {{0x625c0561,0x20d00789,0xe4f800cd,0x00000000}},	//   dèor, wái_, ्महि_, --, 
   {{0xf7700c71,0x20d00124,0x68e00b21,0x00000000}},	//   _ساق_, tái_, _âlds, --, 
   {{0x21680c72,0xa0a400fd,0x7a20013d,0x00000000}},	//   рини_, әшүл, _sötk, --, 
   {{0x20d0035b,0x7a20005b,0x00000000,0x00000000}},	//   rái_, _pötk, --, --, 
   {{0x443c0c73,0x6d400579,0x64480c74,0x83640c75}},	//   miu_, úlan, mnei, _ادال, 
   {{0x443c0c76,0x62980c77,0x64940135,0xa0a400ee}},	//   liu_, _itwo, _iġib, _дакд, 
   {{0xdcb00c78,0x443c0069,0x64940327,0x64480c79}},	//   بىز_, oiu_, _fġie, onei, 
   {{0x64480c7a,0x00000000,0x00000000,0x00000000}},	//   nnei, --, --, --, 
   {{0x64480c7b,0x443c0093,0x64940135,0x7d08007c}},	// [840] inei, iiu_, _jġib, ådsb, 
   {{0x64480226,0x6298007f,0xc1b400ce,0x6494031c}},	//   hnei, _mtwo, _आयोग, _mġib, 
   {{0x1d080c7c,0x443c0c7d,0x64480c7e,0x8d7405d9}},	//   _тени_, kiu_, knei, _واپا, 
   {{0x64480007,0x62980034,0x443c0c7f,0x7a2001f4}},	//   jnei, _otwo, jiu_, _möti, 
   {{0x443c0c80,0x6494031c,0x64480c81,0x00000000}},	//   diu_, _nġib, dnei, --, 
   {{0x8c1c03f4,0x7c24007d,0x18a40c82,0x1da80490}},	//   নোদন_, lkir, _магм, करित, 
   {{0xfed00c58,0x7a2008d5,0x443c0c83,0x7c240083}},	//   িবিধ, _nöti, fiu_, okir, 
   {{0x7c240c84,0x443c0c85,0x64480c86,0x8898011a}},	//   nkir, giu_, gnei, _כבלי, 
   {{0x7c24071a,0x63b80042,0x64940135,0x1da80c87}},	//   ikir, _ddwn, _rġie, करात, 
   {{0x443c0c88,0x6448021c,0x7c240c89,0x63ac00df}},	//   aiu_, anei, hkir, _ĵane, 
   {{0x7c240c8a,0x82300c8b,0x62980c8c,0xb0c4012d}},	//   kkir, بريا, _etwo, लूंग, 
   {{0x443c0c8d,0x64480c8e,0x00000000,0x00000000}},	//   ciu_, cnei, --, --, 
   {{0xc7b0025f,0x7c240c8f,0xaaa8033f,0x9268033a}},	//   ובר_, dkir, _चौंक, _крка_, 
   {{0x7c240c90,0x99cc0183,0x7a2008a5,0x0dc80c91}},	//   ekir, ৰযুক, _föti, шуми_, 
   {{0x7c240135,0x7a2002d2,0x7d0801e3,0x00000000}},	//   fkir, _göti, ädsp, --, 
   {{0x7c240c92,0x9be4025c,0x09c00c93,0xdd98013e}},	//   gkir, _སྒྱོ, शल्य, ишӣ_, 
   {{0x8d840c94,0x00000000,0x00000000,0x00000000}},	// [850] _мунд, --, --, --, 
   {{0x443c0c95,0x64480226,0x7c240c96,0x3b54023b}},	//   ziu_, znei, akir, фкур, 
   {{0xdb1409a5,0x644802f6,0x443c0198,0xab940212}},	//   mgyý, ynei, yiu_, _нині, 
   {{0x443c0c97,0x9f5002e2,0xa7740c98,0x64480369}},	//   xiu_, _bayè_, плеч, xnei, 
   {{0x9be40c99,0x443c0c9a,0x66040c9b,0x00000000}},	//   _སྒྲོ, viu_, зпла, --, 
   {{0x9f50033b,0x656400af,0x443c0034,0x64480042}},	//   _dayè_, ühho, wiu_, wnei, 
   {{0x443c0c9c,0x62980034,0x64480007,0x666401d9}},	//   tiu_, _stwo, tnei, _ہُرٕ, 
   {{0x644804cc,0xa02401f4,0xb50800db,0x00000000}},	//   unei, isöä, تۉمۅ_, --, 
   {{0x443c0c9d,0x13040c9e,0xe58401e0,0xe2980063}},	//   riu_, зный_, _етеү, љао_, 
   {{0x443c0c9f,0x7c240ca0,0x7a200793,0x64480ca1}},	//   siu_, zkir, _pöti, snei, 
   {{0x443c0ca2,0x7c240ca3,0x6d4006ea,0xa2bc0073}},	//   piu_, ykir, úlal, _शिव्, 
   {{0xdee40ca4,0x44240ca5,0x0d380092,0xecd000eb}},	//   поми, _ظراف, _አስፋል, াবাড, 
   {{0x62980034,0xd5d0000d,0x7c240ca6,0xe3b8002d}},	//   _utwo, _सामज, vkir, shűs_, 
   {{0xe1f00ca7,0x7c24094a,0x7a2002b5,0x9f500ca8}},	//   _سست_, wkir, _töti, _jayé_, 
   {{0x9f500ca9,0x7c240caa,0x0bb80cab,0x7a2001d3}},	//   _mayé_, tkir, өттө_, _kötv, 
   {{0x5fc405ba,0x9f400093,0x7c240cac,0x9f500cad}},	//   _वाटल, lekí_, ukir, _layé_, 
   {{0x7c240cae,0xfe7801ec,0x00000000,0x00000000}},	// [860] rkir, _мүм_, --, --, 
   {{0x7c240caf,0x4ef8008f,0x4dd800bc,0x00000000}},	//   skir, _פליג, ख्दै_, --, 
   {{0xd00c01b9,0x00000000,0x00000000,0x00000000}},	//   _شلی_, --, --, --, 
   {{0x7c240054,0x7f3c001f,0xd7080108,0x8eb00066}},	//   qkir, _አንዳች, йнее_, _تمیش, 
   {{0xa2bc07b7,0x9f500cb0,0x7c28017a,0x38c80133}},	//   _शिष्, _bayé_, ëdru, _ژاری_, 
   {{0x28c808f2,0x00000000,0x00000000,0x00000000}},	//   ांशि, --, --, --, 
   {{0xf8e0069f,0x48e0011b,0xb7e00073,0x98a400f3}},	//   _नहिय, _порв, _गॉथम_, _хибе, 
   {{0xe97004a9,0x18a40cb1,0x32980261,0x9f500100}},	//   _شۇند, _маҳм, овиќ_, _tayè_, 
   {{0x9f5000e8,0x5fc40490,0xb2740131,0xe7d00cb2}},	//   _fayé_, _वाजल, млиш, _हातप, 
   {{0xa2bc0cb3,0xf8e00cb4,0x42700cb5,0x6368009d}},	//   _शिर्, _नहाय, нгыс, өрөг_, 
   {{0x85980302,0x85e401c6,0x5dd402dd,0x00000000}},	//   _השבו, _хдхв_, _ﺘﺤﻘﻴ, --, 
   {{0x68e0013d,0x6d400174,0x00000000,0x00000000}},	//   _älde, úlam, --, --, 
   {{0x7a20032e,0x03a00cb6,0xcf2400ae,0x00000000}},	//   _hötu, _чичо, سرحي, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x5fc40574,0x7a20032e,0xaaf406be,0x00000000}},	//   _वाचल, _jötu, _köçü_, --, 
   {{0x7d080158,0x7a200cb7,0x7e600356,0x2d9c010e}},	//   ådsa, _mötu, împr, _şwed_, 
   {{0x2288002d,0x00000000,0x00000000,0x00000000}},	// [870] _tźke_, --, --, --, 
   {{0xe9440cb8,0x7ed400c6,0x79f4011c,0x00000000}},	//   ورای, _أزيا, нзух, --, 
   {{0x3e640008,0xf98800c6,0x9f5006af,0xac180cb9}},	//   götu_, أنمي_, _rayé_, _дону_, 
   {{0xa2bc0cba,0x6fac02ab,0xdb1400e5,0x00000000}},	//   _शिल्, चरिं, ggyó, --, 
   {{0x9f5007ea,0xf77002e9,0xa6c800d4,0xe7040cbb}},	//   _payé_, هاه_, ілка_, بسای, 
   {{0x7a200cbc,0xdb04002d,0xdaa002dd,0xb17c01e4}},	//   _bötu, _fekâ, _شەمپ, reĥj, 
   {{0x80d800ab,0x9f4000d7,0x00000000,0x00000000}},	//   _बहें, vekí_, --, --, 
   {{0x7a2001b8,0x9f500cbd,0x3e6401d3,0x94700cbe}},	//   _dötu, _wayé_, lött_, نگنا, 
   {{0x65940a52,0x9f400093,0x9f5001e1,0xb9fc0092}},	//   _жазу, tekí_, _tayé_, _ቅቤ_, 
   {{0x7a2001a8,0x00000000,0x00000000,0x00000000}},	//   _fötu, --, --, --, 
   {{0x7a200008,0x00000000,0x00000000,0x00000000}},	//   _götu, --, --, --, 
   {{0xeb0c0cbf,0x7a200cc0,0xaaf403e0,0x33d4003b}},	//   _सपूत_, _hött, _göçü_, _зішт, 
   {{0xd0900cc1,0x7a200cc2,0xd24c00aa,0xdb040cc3}},	//   _müəy, _kött, انۍ_, _pekí, 
   {{0x3e6401ed,0x7a2001d3,0xfd6401ec,0x00000000}},	//   jött_, _jött, енгү, --, 
   {{0x7a200cc4,0x21200194,0x3e6401ed,0x00000000}},	//   _mött, _æhh_, dött_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xcb640cc5,0x3e64007c,0x00000000,0x00000000}},	// [880] дате_, fött_, --, --, 
   {{0x7a200267,0x3e6401ed,0x00000000,0x00000000}},	//   _nött, gött_, --, --, 
   {{0xdb1400e5,0x00000000,0x00000000,0x00000000}},	//   tgyó, --, --, --, 
   {{0x81b004c5,0x7a200cc6,0x57440124,0x00000000}},	//   টলি_, _rötu, мнеб, --, 
   {{0xc68c01d9,0x7a200112,0xe6b401d5,0xdb1400e5}},	//   لِن_, _bött, فلنگ, rgyó, 
   {{0x59740064,0x00000000,0x00000000,0x00000000}},	//   _жыбу, --, --, --, 
   {{0x7a200267,0x00000000,0x00000000,0x00000000}},	//   _dött, --, --, --, 
   {{0xf318013e,0x61e403e0,0xe70800db,0x00000000}},	//   зоиш_, _ıhla, تتۅن_, --, 
   {{0x7a20049f,0x02a00276,0xe43001d3,0x00000000}},	//   _fött, крэм, دہند, --, 
   {{0x7a200cc7,0x6d400162,0x00000000,0x00000000}},	//   _gött, úlak, --, --, 
   {{0x845404a9,0xd5480133,0x40a40cc8,0xd1380cc9}},	//   ярәт_, _بلاو_, мъян_, юхи_, 
   {{0x3e64066d,0x53440cca,0x8f0801d5,0x00000000}},	//   zött_, _охла, охга_, --, 
   {{0x7d080158,0x00000000,0x00000000,0x00000000}},	//   ådsn, --, --, --, 
   {{0xb64007ad,0xe2a80ccb,0x42040107,0x4304009f}},	//   _ｍｍ_, _راهن_, _ончо_, _آيوَ_, 
   {{0x7a200ccc,0x82600451,0x3d940063,0x4638010f}},	//   _löts, _جهون, тиср, קעלע, 
   {{0x321c0124,0x9f4005da,0xeeb80075,0x787803b2}},	//   _hovy_, bekà_, _елиш_, lívf, 
   {{0x3e6401ed,0x7c840ccd,0x321c02fb,0x3ec40166}},	// [890] tött_, туре, _kovy_, _исэб, 
   {{0x6ae000fe,0x26d80171,0x00000000,0x00000000}},	//   নিলো, _īso_, --, --, 
   {{0x64dc0cce,0x7a200ccf,0xdd9000db,0x26d80153}},	//   _महेश, _rött, _حوپ_, _ūso_, 
   {{0x9f400cd0,0x9f4c067c,0x61fc00de,0x7a200139}},	//   leká_, ènço_, ēsli, _sött, 
   {{0x200c013f,0xa9080014,0x7a200cd1,0x870400be}},	//   _ɑfi_, _کٲزٕ_, _pött, ببال, 
   {{0xf7700cd2,0x321c0122,0x9f400093,0x81e000fe}},	//   جام_, _novy_, neká_, _পোন_, 
   {{0x69d4014b,0x9f4c00bc,0x7a200254,0x6d400174}},	//   _icze, čném_, _vött, úlah, 
   {{0xe8e800aa,0x00000000,0x00000000,0x00000000}},	//   _ورځو_, --, --, --, 
   {{0x7a200cd3,0x68f40175,0xdddc00d0,0xe2840798}},	//   _göts, _hszd, _lipš, нлии, 
   {{0xf674022e,0x00000000,0x00000000,0x00000000}},	//   _агуэ, --, --, --, 
   {{0x644406af,0xb5c80014,0x321c01f5,0xa878008f}},	//   éhis, _زونم_, _dovy_, ּאָר, 
   {{0xdb0401a2,0xa29400d4,0x934001ec,0x00000000}},	//   _leká, _заді, _әнше, --, 
   {{0xd12c0cd4,0x69d40034,0x442c0cd5,0xd24c0cd6}},	//   لمی_, _ocze, _ilg_, _گنو_, 
   {{0xd00c005e,0x321c010e,0xdc980cd7,0xdb0401ef}},	//   _ۇلى_, _govy_, зташ_, _neká, 
   {{0x22440cd8,0xb28400c7,0xd24c029c,0x00000000}},	//   milk_, _рыцк, _دنو_, --, 
   {{0x69d407c5,0x321c03d1,0x52100075,0xbfa80014}},	//   _acze, _zovy_, _адәт, _کاژٕ_, 
   {{0x442c0cd9,0xba4401d3,0xde3c0092,0x2f5400c0}},	// [8a0] _mlg_, نچسٹ, ደማይገ, _атэс, 
   {{0x4a400cda,0x00000000,0x00000000,0x00000000}},	//   гнув, --, --, --, 
   {{0xd8240cdb,0x442c0cdc,0x9d440cdd,0x7a200267}},	//   нджи, _olg_, _ченд, _söts, 
   {{0x3d1c00af,0x22440076,0xc7ac0592,0xd5d00073}},	//   नहीं_, hilk_, مّم_, _साहज, 
   {{0xdb040cde,0x2c0c00cd,0x00000000,0x00000000}},	//   _feká, हारं_, --, --, 
   {{0xceb00bd9,0x8ca40c22,0xd9440798,0x00000000}},	//   ריג_, टीको, _зеги, --, 
   {{0x442c0cdf,0x85b40050,0x321c00c7,0x22440175}},	//   _blg_, راوس_, _rovy_, dilk_, 
   {{0x442c007b,0xda0c0ce0,0x321c02f0,0x3ea00ce1}},	//   _clg_, सावत_, _sovy_, _otit_, 
   {{0x442c0ce2,0x9f500139,0x06800131,0x676401af}},	//   _dlg_, _bayí_, ъгән, _антҡ, 
   {{0x442c08fb,0xc21400d4,0xf5440240,0x00000000}},	//   _elg_, еєю_, _ንፕረዚ, --, 
   {{0x3ea00ce3,0x6d480276,0x53a40ce4,0xeb0c00dc}},	//   _atit_, şeaz, _заеб, _सप्त_, 
   {{0x442c0ce5,0x6e940166,0x00000000,0x00000000}},	//   _glg_, киму, --, --, 
   {{0x93440ce6,0x321c0022,0x3ea0004d,0x9f4000d0}},	//   _янде, _tovy_, _ctit_, teká_, 
   {{0xbe880ce7,0x44100ce8,0x442c0064,0xdb0c0241}},	//   ессе_, _афәт, _zlg_, _àjùl, 
   {{0x2d840ce9,0xdb040124,0x24880419,0x00000000}},	//   äle_, _reká, ňame_, --, 
   {{0x3ea0038f,0x799c0cea,0xdb0402fb,0x656400c5}},	//   _ftit_, _afrw, _seká, ühhi, 
   {{0xdb040ceb,0x6494031c,0x00000000,0x00000000}},	// [8b0] _peká, _aġil, --, --, 
   {{0xdddc00f3,0x799c03ac,0x7a20032e,0x00000000}},	//   _tipš, _cfrw, _sötr, --, 
   {{0x7a200793,0x6c54016c,0x2d580cec,0xff5000f2}},	//   _pötr, _акну, _цинь_, _نخی_, 
   {{0x69d4068f,0x22440010,0x00000000,0x00000000}},	//   _wcze, zilk_, --, --, 
   {{0x799c00a9,0x8038008f,0x69d40ced,0x041c00cc}},	//   _ffrw, ענדע_, _tcze, _বগলী_, 
   {{0x9f50006a,0x69d4068f,0x442c0005,0xdb04037e}},	//   _yayâ_, _ucze, _slg_, _bekæ, 
   {{0x442c0cee,0x224409a8,0xcacc03d4,0x00000000}},	//   _plg_, vilk_, ৰিওফ, --, 
   {{0x47840022,0x2ca0022e,0x00000000,0x00000000}},	//   _зызб, _mthd_, --, --, 
   {{0xdc2c0a28,0xe6940cef,0x442c0cf0,0x22440427}},	//   _jñān, _ризы, _vlg_, tilk_, 
   {{0x442c0421,0x20c400cd,0x9f400139,0x00000000}},	//   _wlg_, _विदध, lekç_, --, 
   {{0xa2bc0cf1,0x442c0cf2,0x65140cf3,0x3ea00cf4}},	//   _शिक्, _tlg_, _جوائ, _stit_, 
   {{0x442c0cf5,0x22440cf6,0x3ea00cf7,0x728801c6}},	//   _ulg_, silk_, _ptit_, мбөг_, 
   {{0x53980bd4,0x26dc002f,0x22440cf8,0x00000000}},	//   _חינו, ntwo_, pilk_, --, 
   {{0x27fc0cf9,0x78780798,0xabc401e0,0x00000000}},	//   hdwn_, míve, ҫарҙ, --, 
   {{0xdc2800aa,0x2ee8004e,0x78780cfa,0x00000000}},	//   وسره_, _epaf_, líve, --, 
   {{0x5f040cfb,0x153c0055,0x26dc007f,0x00000000}},	//   _азиа, _cāṇī, ktwo_, --, 
   {{0x78780cfc,0x27fc0cfd,0x3ea00194,0x63a803fa}},	// [8c0] níve, ddwn_, _utit_, iben, 
   {{0x3b000cfe,0x7f40003a,0x00000000,0x00000000}},	//   rviq_, úmqu, --, --, 
   {{0x63a80399,0xd7f80cff,0x5f440d00,0x28c80d01}},	//   kben, дул_, _سنگل, ांगि, 
   {{0x69c0025a,0x63a80d02,0x64940135,0x862001b9}},	//   _ôlen, jben, _vġil, یکلل, 
   {{0x63a80d03,0x3b000d04,0x81b400cc,0x6d4006ea}},	//   dben, qviq_, _ছান_, úlav, 
   {{0x63a80d05,0x7878012c,0x6b9c01f5,0x64440066}},	//   eben, díve, _zfsg, èhin, 
   {{0xd9440d06,0xdb040790,0x25a80451,0x00000000}},	//   _реви, _bekç, ردٻي_, --, 
   {{0x63a80d07,0xd7040d08,0xb9dc0092,0x00000000}},	//   gben, _изби, _አሳ_, --, 
   {{0x97e803be,0x26dc068f,0xd1c80d09,0x78780120}},	//   ışdı, ctwo_, мунд_, gíve, 
   {{0x6488009d,0x00000000,0x00000000,0x00000000}},	//   мсөг_, --, --, --, 
   {{0x1be00d0a,0x427001c6,0xdb0401f4,0x00000000}},	//   खभाल_, ргэс, _hekä, --, 
   {{0x9f5001e1,0x78780120,0x705402f2,0xf1d4000d}},	//   _bayà_, bíve, انحا, _दावन, 
   {{0x78780798,0xdd380356,0x61400022,0x00000000}},	//   cíve, _păşe, иҵәа, --, 
   {{0xdb14033b,0xd24c01d9,0xdb0401f4,0x2ba400ce}},	//   mayè, _گنڈ_, _mekä, गुना, 
   {{0xdb040793,0x7d24014b,0x00000000,0x00000000}},	//   _lekä, афте, --, --, 
   {{0xc61c0d0b,0x4fc40d0c,0xe7d00d0d,0x26dc0076}},	//   _भव्य_, _рска, _हाइप, ytwo_, 
   {{0xdb040840,0xeb0c012c,0x6b740d0e,0xdb140100}},	// [8d0] _nekä, समेत_, улау, nayè, 
   {{0x63a80d0f,0x6abc0212,0x4e4002f2,0xacf80064}},	//   zben, _vvsf, _ئێسق, _зноу_, 
   {{0x656c03f9,0xaab40220,0x78780d10,0x00000000}},	//   ƙahi, _әйгі, zíve, --, 
   {{0xdb040d11,0xdb140100,0x64a401ec,0x6d400d12}},	//   _bekä, kayè, ңала, úlau, 
   {{0x787806ed,0x63a801e3,0x27fc015d,0x99b000cc}},	//   xíve, vben, rdwn_, _চাৰক, 
   {{0x787806ed,0x9f500241,0xdb04013d,0x63a80d13}},	//   víve, _jayá_, _dekä, wben, 
   {{0x26dc0034,0xdb0403e0,0x00000000,0x00000000}},	//   stwo_, _pekç, --, --, 
   {{0x78780d14,0x63a80d15,0xc6a4084c,0xdb1402e2}},	//   tíve, uben, _аржи, fayè, 
   {{0xdb040d16,0x06980d17,0xdb140100,0x6ae00011}},	//   _gekä, _آخرت_, gayè, নিকো, 
   {{0x63a80d18,0x78780d19,0x7d080267,0x6e20007c}},	//   sben, ríve, ådsk, ölbl, 
   {{0x787806ed,0x9f4c0316,0x516400f7,0x614400d8}},	//   síve, čním_, лүшү_, уена, 
   {{0xdb080122,0x2ba40d1a,0x05dc002b,0x00000000}},	//   šnéh, गुमा, प्रब, --, 
   {{0x9f500241,0x64480005,0xf8d00950,0x8384005b}},	//   _bayá_, miei, _हम्प, _рыже, 
   {{0xdd900d1b,0x64480d1c,0x00000000,0x00000000}},	//   صور_, liei, --, --, 
   {{0x1fb40276,0x6448062c,0x61440d1d,0x00000000}},	//   _йспр, oiei, _щека, --, 
   {{0x8c400d1e,0xaca800dd,0xdb1406af,0xb17c01e4}},	//   бесе, کھیے_, layé, reĥt, 
   {{0x9b0401ec,0x99e40026,0xddb8011c,0x00000000}},	// [8e0] ызад, лжад, _пунш_, --, 
   {{0x9a680d1f,0x64480d20,0xd5d004af,0x00000000}},	//   رمال_, hiei, _साइज, --, 
   {{0xdb040844,0x64480d21,0x62800142,0x09e00229}},	//   _sekä, kiei, imlo, сохн, 
   {{0x7d540201,0x00000000,0x00000000,0x00000000}},	//   _መሆናቸ, --, --, --, 
   {{0x64480d22,0xb3140327,0x764400c7,0xf1d401f9}},	//   diei, ིདབང_, аҭаа, _दालन, 
   {{0x38c80d23,0x62800d24,0xdb1402e2,0x00000000}},	//   _لاری_, jmlo, vayè, --, 
   {{0x64480d25,0x54e400c6,0x629c04d4,0x20c40d26}},	//   fiei, استق, íson, _विषध, 
   {{0x62800d27,0x4d78008f,0xdef00092,0xdb040a43}},	//   emlo, ערקע, _ልጁን_, _tekä, 
   {{0xd5d40d28,0x73c40032,0x634002d3,0x629c01e4}},	//   _متاث, гәһе, _ክትግበ, ŭson, 
   {{0xdb140d29,0x64480076,0xdb0401e3,0x00000000}},	//   rayè, aiei, _gekå, --, 
   {{0x6448003e,0x80a0072d,0xdcfc0171,0xf1b8025c}},	//   biei, یمین, _cepļ, raġ_, 
   {{0x64480d2a,0x3d080d2b,0x00000000,0x00000000}},	//   ciei, हिने_, --, --, 
   {{0x9f500789,0x5f000d2c,0x6e940d2d,0x00000000}},	//   _payá_, शिष्_, ригу, --, 
   {{0x2c0003d4,0x705400cf,0xc2c001c8,0x00000000}},	//   _একেই_, انڭا, _ايوي, --, 
   {{0x621000dc,0xd9b000cc,0x28c80d2e,0x00000000}},	//   तारौ_, _চাংম, ांछि, --, 
   {{0x80a00d2f,0x00000000,0x00000000,0x00000000}},	//   _امين, --, --, --, 
   {{0xead40d30,0x3c58084c,0xe9d80d31,0x00000000}},	// [8f0] розь, уитэ_, кмач_, --, 
   {{0x6d400d32,0xbf140014,0x7f3c008f,0x64480c86}},	//   úlas, _اوٝب, _רעזו, ziei, 
   {{0x64480368,0x98e0037e,0xdd38054e,0x00000000}},	//   yiei, ne版i, măşa, --, 
   {{0xead40d33,0x79940107,0x00000000,0x00000000}},	//   _комь, _ҳирф, --, --, 
   {{0x2ba40b7c,0x62800072,0x69dc08df,0x9bb8011a}},	//   गुणा, ymlo, _पापी, _בצרפ, 
   {{0xc984013e,0x79940d34,0x78780419,0x00000000}},	//   _буби, _гирф, tívc, --, 
   {{0x64480077,0x3d080d35,0x00000000,0x00000000}},	//   tiei, हिये_, --, --, 
   {{0x7cec0d36,0x57b000cf,0x2408014b,0x00000000}},	//   _hörö, _ۇڭۇز, тнии_, --, 
   {{0x64480428,0x7cec01ed,0x00000000,0x00000000}},	//   riei, _körö, --, --, 
   {{0x64480153,0x3d08000d,0x5ea400f2,0x78780d37}},	//   siei, हिमे_, یمجل, míva, 
   {{0x69dc0d38,0x78780d39,0xc32003f4,0x62800d3a}},	//   _पानी, líva, _বেশি_, rmlo, 
   {{0x5f040d3b,0x660c02a8,0xdb1406af,0x649400c0}},	//   азма, ɓaka, sayé, _ašig, 
   {{0x9e640d3c,0x02a40640,0xdb1406af,0x38bc0248}},	//   لاسن, _срем, payé, _kárá_, 
   {{0xd3540375,0x38bc01e1,0x21a40d3d,0x00000000}},	//   _דיני_, _járá_, _тикм, --, 
   {{0xdea001d3,0x92000171,0x00000000,0x00000000}},	//   _ڈیجی, _šāga, --, --, 
   {{0x38bc01e1,0x38ac01e1,0x78780022,0xdb0400d7}},	//   _lárá_, _lòrò_, kíva, _odkô, 
   {{0x20100d3e,0x6d400d3f,0x451800cc,0xa29c06be}},	// [900] _inyi_, úlar, তনিক_, _ərşə_, 
   {{0x7878012c,0x00000000,0x00000000,0x00000000}},	//   díva, --, --, --, 
   {{0x26180918,0xa3b4000d,0xc8c401d9,0x5cf4010a}},	//   पानी_, झरा_, لوٕن_, _тяпу, 
   {{0x2ca40077,0x20000d40,0x1b4801f0,0x00000000}},	//   ílde_, ndki_, _азми_, --, 
   {{0x38bc01e1,0x38ac0248,0x7cec01e6,0x8f9802e4}},	//   _bárá_, _bòrò_, _förö, דיני, 
   {{0x69dc069f,0x20c40d41,0x7cec01ed,0x4788074d}},	//   _पायी, _विंध, _görö, ĕсем_, 
   {{0x01b80d42,0xc32004c5,0xdb0400d0,0xe8500133}},	//   ংলাদ, _বেলি_, _nekú, _کۆند, 
   {{0x20100d43,0x94840d0e,0xdb2401e1,0x787801ef}},	//   _nnyi_, шылд, _ìpór, bíva, 
   {{0x46a00d44,0x38bc0248,0x38ac01e1,0x7cec0139}},	//   _матв, _fárá_, _fòrò_, _yörö, 
   {{0x201000b4,0x38ac0428,0x2000031c,0x5184009d}},	//   _anyi_, _gòrò_, edki_, иуна, 
   {{0xdb140548,0x2258020c,0x9f8c000d,0x85200107}},	//   kayï, éska_, _mõõk_, _мӯъҷ, 
   {{0x4ea4006c,0x9200005f,0x13680d45,0x04d8011a}},	//   ирга, _šāda, _ишли_, _יקבל, 
   {{0xb8d80d46,0xdb040241,0x2eec0d47,0xc438011a}},	//   _ཚས_, _eekú, ïef_, _בתאי, 
   {{0x20100d48,0xdb0401e1,0xa37401f7,0x00000000}},	//   _enyi_, _fekú, _اَهڙ, --, 
   {{0x1e3801d9,0x2ca40d49,0xdd380356,0x412400f0}},	//   اغُک_, ëld_, răşa, _војо_, 
   {{0x7cec0d4a,0x8f440d4b,0x7054034c,0xc0c40798}},	//   _sörö, _вход, _دنبا, _туше_, 
   {{0x7648009a,0x64940d4c,0xf3f80154,0x7cec00e5}},	// [910] _omdy, _išie, _আচার_, _pörö, 
   {{0x6d340d4d,0xe91800d4,0x0904009b,0x78780d4e}},	//   _геоф, лозі_, ичем, víva, 
   {{0x7cec0d4f,0x88c40228,0x69dc0490,0x38bc0cad}},	//   _vörö, شتال, _पाठी, _rárá_, 
   {{0x27e80510,0x6e24047e,0xa7b800f7,0x78780d50}},	//   ýan_, _hohb, улду_, tíva, 
   {{0x7cec00dd,0x76480175,0xab0000bc,0x38bc01e1}},	//   _törö, _bmdy, _kříž_, _párá_, 
   {{0xd6cc0058,0x78780077,0x00000000,0x00000000}},	//   رقى_, ríva, --, --, 
   {{0x6e24016d,0x29040d51,0xdef0069d,0x787800e4}},	//   _mohb, _éla_, ልቅና_, síva, 
   {{0xd36c05d9,0x3d0801bc,0x95d40d52,0xfd580375}},	//   ڙهي_, हिते_, адәт_, ישוי_, 
   {{0xdb040d53,0x03a0013e,0xe214007b,0x38ac0241}},	//   _sekú, биқо, مبدع, _tòrò_, 
   {{0x6e24014f,0x649400c0,0x00000000,0x00000000}},	//   _nohb, _ašie, --, --, 
   {{0x9f5c038e,0x26180d54,0x20000a73,0x660002d0}},	//   ětí_, पाठी_, tdki_, _ialk, 
   {{0x66000d55,0x6e2401ab,0xca3008b0,0x3ec80107}},	//   _halk, _aohb, ﺭﺍﺭ_, ақим_, 
   {{0x238401d9,0x53980302,0x200000ab,0x1858010f}},	//   _أشِ, _עיסו, rdki_, רכרע, 
   {{0xb3740302,0x6600049b,0xdb0400d2,0x64940cf4}},	//   _بدمش, _jalk, _tekú, _išib, 
   {{0x66000d56,0x6298004c,0xdca40d57,0x6d400162}},	//   _malk, _huwo, саби, úlap, 
   {{0x66000d58,0x62980d59,0xebb80a28,0x201001f2}},	//   _lalk, _kuwo, yoḥ_, _unyi_, 
   {{0x63b800a9,0x62980066,0x1868036b,0x7b840131}},	// [920] _mewn, _juwo, қади_, زارە, 
   {{0x63b80a73,0x62980d5a,0x69dc0490,0x66000d5b}},	//   _lewn, _muwo, _पाणी, _nalk, 
   {{0x6298014f,0x5fbc0254,0xd9440d5c,0xa3f8076e}},	//   _luwo, _्याल, щежи, ्याप_, 
   {{0x63b80d5d,0x66000d5e,0x764802c4,0xb9000d5f}},	//   _newn, _aalk, _smdy, _दम_, 
   {{0x62980d60,0x6e24014f,0xe6b4036b,0xd6280138}},	//   _nuwo, _yohb, قلنگ, лоде_, 
   {{0xceb00bd9,0x7a20002f,0x66000d61,0xd9b00154}},	//   ליד_, _lötz, _calk, _চাকম, 
   {{0x66000d62,0x7ae40d63,0x969001b9,0x5504009d}},	//   _dalk, ltit, _کیتش, счла, 
   {{0x7ae4004b,0x78780048,0x62980d64,0xd24c0014}},	//   otit, mívo, _buwo, کۆت_, 
   {{0x8c180d65,0x1368023a,0x2fdc010e,0x5724007b}},	//   רופי, ышки_, _öwgi_, _ارزق, 
   {{0x66000d66,0x7ae40d67,0x62980d68,0x8af800c8}},	//   _galk, itit, _duwo, נהיי, 
   {{0xefe402d3,0x7ae4034b,0x63b80368,0xd6d8009e}},	//   _ምሳይ_, htit, _fewn, _ধনিয, 
   {{0x6e240d69,0x7ae40d6a,0x787801f1,0xd9dc009e}},	//   _sohb, ktit, zívn, ড়িম, 
   {{0x447804ac,0x62980337,0x6e240076,0x7ae401e4}},	//   _ענדע, _guwo, _pohb, jtit, 
   {{0x7ae40d6b,0x66000d6c,0x63b8068f,0xdb1400d2}},	//   dtit, _xalk, _zewn, gayí, 
   {{0x90a40d6d,0x63b80204,0x7ae40d6e,0x8bc40d6f}},	//   _احتم, _yewn, etit, йсад, 
   {{0x7a200086,0x7ae40d70,0x6e24013f,0x6298020b}},	//   _götz, ftit, _wohb, _yuwo, 
   {{0x2fc80d71,0x7ae40d72,0x78780038,0x9e6404fb}},	// [930] _idag_, gtit, tívn, _ژاپن, 
   {{0x80d8015b,0xdb240d73,0x1828036b,0x00000000}},	//   ববর্, غولی, یقلی_, --, 
   {{0x7ae40af5,0x6f0c0232,0x7d080d74,0x27d80276}},	//   atit, _hrac, ådst, иджь_, 
   {{0x66000d75,0x6f0c0d76,0x2df40014,0x787801f1}},	//   _salk, _krac, _آگر, sívn, 
   {{0x66000d77,0xd3640d78,0xda08000d,0x8c9c0d79}},	//   _palk, _آه_, _होवत_, _खंडो, 
   {{0xd1240d7a,0x6aac0109,0x62980d7b,0x2ba4012c}},	//   _قم_, mpaf, _ruwo, गुरा, 
   {{0x63b8006d,0xe3b00491,0x66000d7c,0x62980d7d}},	//   _pewn, ورة_, _valk, _suwo, 
   {{0x66000d7e,0x6f0c0d7f,0x6aac01f5,0x00000000}},	//   _walk, _orac, opaf, --, 
   {{0x27ec0d80,0x68e40d81,0x6f0c063f,0x66000d82}},	//   _iben_, lthd, _nrac, _talk, 
   {{0x2fc80d83,0x63b8068f,0x60e80d84,0x317c0331}},	//   _adag_, _wewn, амом_, _bzvz_, 
   {{0x6f0c0d85,0x27ec0d86,0x7ae4009d,0x68e40175}},	//   _arac, _kben_, ztit, nthd, 
   {{0x62980d87,0x7ae40d88,0x68e40368,0x6aac01e4}},	//   _tuwo, ytit, ithd, kpaf, 
   {{0xc3040d89,0x27ec0d8a,0x6f0c0d8b,0x64940003}},	//   _دباو, _mben_, _crac, _eġit, 
   {{0x7ae4074d,0x2fc80194,0x5bb005f9,0xf38001e0}},	//   vtit, _edag_, जर्व, _яғым, 
   {{0x27ec09f0,0x6f0c0d8c,0x7ae40784,0x63500092}},	//   _oben_, _erac, wtit, _ይቆጣጠ, 
   {{0x27ec005a,0x2ba40b02,0x00000000,0x00000000}},	//   _nben_, गुला, --, --, 
   {{0x7ae40d8d,0x6f0c0d8e,0x68e40042,0x9aa401d9}},	// [940] utit, _grac, ethd, زماو, 
   {{0x27ec0d8f,0x7ae40d90,0x78780d91,0x2fc80175}},	//   _aben_, rtit, tívo, _zdag_, 
   {{0x7ae40d92,0x6f0c0552,0xd238010f,0xcc800150}},	//   stit, _zrac, סגעל, _ﺣﯟﺍﮔ, 
   {{0x7ae40d93,0xb6c801ed,0x27ec0200,0x6f0c02d0}},	//   ptit, ماتے_, _cben_, _yrac, 
   {{0x7ae40d94,0xd9d00075,0x6f0c00d8,0xa3ac0037}},	//   qtit, _يەرگ, _xrac, कडन_, 
   {{0xd9440d95,0x1f5c0092,0x00000000,0x00000000}},	//   _деги, _ወንድም, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x25a40076,0x00000000,0x00000000,0x00000000}},	//   _efll_, --, --, --, 
   {{0xd2580601,0xcc38010f,0x00000000,0x00000000}},	//   ицо_, יעקט, --, --, 
   {{0x6f0c0d96,0xe6d808a5,0x4270013d,0x00000000}},	//   _rrac, _óráð, мгыс, --, 
   {{0x4a7804ac,0x6494012c,0x2fc800ca,0xa5940d97}},	//   שריב, _všic, _pdag_, _хрущ, 
   {{0x40340c9e,0x6aac022c,0x35e000e1,0x00000000}},	//   деюс, ypaf, _नाड़, --, 
   {{0x64940010,0xb8fc0327,0xfbc000eb,0x00000000}},	//   _išia, _ཡའ_, ইলাত, --, 
   {{0xe3b8002d,0x68e40042,0x656c0205,0x00000000}},	//   njűn_, ythd, şahe, --, 
   {{0x6f0c0d98,0xac180d99,0x81e000fe,0x705401ec}},	//   _wrac, бову_, _পোক_, _ىنتا, 
   {{0x2610068f,0x69dc0490,0x2fc80d9a,0x31340075}},	//   _धोनी_, _पाही, _udag_, _меһр, 
   {{0x6f0c0d9b,0x27ec0649,0x97e80d9c,0x785c007f}},	// [950] _urac, _rben_, ışlı, tčvn, 
   {{0x27ec0d9d,0x6aac00df,0x0ba800d1,0x00000000}},	//   _sben_, rpaf, _ھاجى_, --, 
   {{0xeff002d3,0x649400d0,0x6aac01e4,0xc8640d9e}},	//   _ውሑድ_, _ošia, spaf, отди, 
   {{0x9ce801d9,0xae180034,0x68e40d9f,0x3d080da0}},	//   _اوَے_, दावन_, rthd, हिरे_, 
   {{0xe5a40da1,0x00000000,0x00000000,0x00000000}},	//   пили, --, --, --, 
   {{0xe5a40364,0x59e00490,0x80d8009e,0x978001d5}},	//   чики, _पायर, _বনস্, ریله, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x27ec0da2,0x63780276,0x26180da3,0x537000ec}},	//   _uben_, йспр_, पाही_, ڙهيء, 
   {{0x0518015b,0xe3b00da4,0xe7080451,0x28d00da5}},	//   তনের_, ورک_, _دڪان_, _हिडि, 
   {{0x29040789,0x46600c50,0xc6840244,0xb5d400f3}},	//   _álas_, _تۇتق, _بێتن_, _ожуј, 
   {{0x21680da6,0xa30801d9,0x00000000,0x00000000}},	//   сини_, _گراے_, --, --, 
   {{0xc2f0015b,0xd12c0592,0xcfac0150,0x00000000}},	//   জিবি_, امَ_, _ﺳﯩﺮﻗ, --, 
   {{0x443c006f,0xdb140784,0x00000000,0x00000000}},	//   mhu_, kayá, --, --, 
   {{0x443c0da7,0x3d080da8,0x61440da9,0x161c0412}},	//   lhu_, हिले_, _нела, पायर_, 
   {{0x443c0daa,0x91b80375,0x20540dab,0xc3200154}},	//   ohu_, _המצי, _нтир, _বইটি_, 
   {{0x443c0dac,0x4ac40dad,0x70380022,0x98a4010b}},	//   nhu_, _लिखव, _мчыс_, җиде, 
   {{0x443c0dae,0x8c400daf,0x00000000,0x00000000}},	// [960] ihu_, хете, --, --, 
   {{0x443c0db0,0x97e80db1,0x6d4001ab,0x00000000}},	//   hhu_, ışmı, ùlac, --, 
   {{0x443c0db2,0xd88801ed,0x69dc0db3,0x71e800fe}},	//   khu_, مپئن_, _पारी, _কোঁচ_, 
   {{0x443c0db4,0x01c00729,0x261002e5,0x5fbc0490}},	//   jhu_, ্ভিদ, _धोबी_, ्णिल, 
   {{0x443c0db5,0x7878022a,0x7c2403b2,0x90a00150}},	//   dhu_, lívk, mjir, _ﺍﻟﺤﻔ_, 
   {{0x443c0db6,0xa7fc045f,0x7c240db7,0x4b780375}},	//   ehu_, _skűt, ljir, _לאכו, 
   {{0x443c0084,0x5fbc012c,0xe3b8000f,0x785c0100}},	//   fhu_, ्णाल, rjűn_, lčvm, 
   {{0x7c240db8,0x443c0db9,0x3f800268,0xe3b8002d}},	//   njir, ghu_, _oziu_, sjűn_, 
   {{0xdb0401ed,0x97000131,0x26180073,0xa3ac0dba}},	//   _nekü, _سېغى, पाशी_, _कभर_, 
   {{0xdb040124,0x31340dbb,0x7c24026c,0x96640dbc}},	//   _hekó, деор, hjir, _экзе, 
   {{0x443c0dbd,0x64940dbe,0xd538009d,0x00000000}},	//   bhu_, _išin, _уяач_, --, 
   {{0x443c0dbf,0x7c240dc0,0xdb0401ed,0x7878013a}},	//   chu_, jjir, _bekü, dívk, 
   {{0x7c24002d,0x4ea40a89,0x2d740131,0x69dc0027}},	//   djir, ярна, ﺸﯩﻨﻰ_, _पाली, 
   {{0xdb04033f,0xdcfc00b8,0x00000000,0x00000000}},	//   _lekó, _śvād, --, --, 
   {{0xda0800af,0xc2780375,0x629c00d7,0x00000000}},	//   _होइत_, _הרגי, ísov, --, 
   {{0x7c240dc1,0x41580375,0xdb0401d3,0x00000000}},	//   gjir, _לדוג, _fekü, --, 
   {{0xdb040dc2,0x7b180276,0x629c01e4,0x00000000}},	// [970] _gekü, потр_, ŭsov, --, 
   {{0x443c0007,0xca700dc3,0x7c2401c8,0x79a400f0}},	//   zhu_, رناک, ajir, ерце, 
   {{0x24880030,0x7c3809c2,0x7c24058a,0x443c0588}},	//   ňami_, ñará, bjir, yhu_, 
   {{0xf7700dc4,0x64940064,0x443c0200,0x00000000}},	//   گام_, _ašin, xhu_, --, 
   {{0x26180dc5,0x443c0dc6,0x66e4039b,0xdb140407}},	//   पाली_, vhu_, фола, payá, 
   {{0xf7700199,0x00000000,0x00000000,0x00000000}},	//   دام_, --, --, --, 
   {{0x443c0dc7,0x64840332,0xb6cc06be,0x35f80066}},	//   thu_, nóig, _şütü, ثرند_, 
   {{0x2910003e,0xd24c004b,0x443c0418,0x870401af}},	//   _irza_, یني_, uhu_, _нязе, 
   {{0x443c06e4,0x13040dc8,0x64840332,0x00000000}},	//   rhu_, дный_, hóig, --, 
   {{0x443c0dc9,0x68e001e6,0x3c3c00e4,0x64840022}},	//   shu_, _älds, _míva_, kóig, 
   {{0x443c0dca,0xdb040dcb,0x3c3c03b2,0xdcf400e2}},	//   phu_, _jekò, _líva_, ācīb, 
   {{0x291001fa,0x26100dcc,0x3c3c00e4,0x443c01b3}},	//   _mrza_, _धोती_, _oíva_, qhu_, 
   {{0xdb040d29,0x94240075,0x7c24022e,0x23280117}},	//   _lekò, _تونۇ, vjir, _фоли_, 
   {{0x29100dcd,0x64840332,0xdb1406be,0x00000000}},	//   _orza_, fóig, layç, --, 
   {{0xdcb00075,0xa2d80825,0x6484007b,0xc32000fe}},	//   ئىر_, फूर्, róif, _বেচি_, 
   {{0x6e200008,0xbd080150,0x8c9c000d,0x97e803e0}},	//   ölbr, _ورﯨﻨ, _खंरो, ışkı, 
   {{0x1a040dce,0x59e0098a,0x5f740dcf,0x7c240dd0}},	// [980] мпам, _पादर, _تاثر, rjir, 
   {{0x29100dd1,0x648400c6,0x3ea00538,0x7c240009}},	//   _brza_, lóid, _iuit_, sjir, 
   {{0xd00c0dd2,0x78780dd3,0x3ea007ea,0x3c3c00e4}},	//   _صلی_, lívi, _huit_, _eíva_, 
   {{0x3ea00dd4,0xdb040100,0x64840dd5,0xc3200c58}},	//   _kuit_, _dekò, nóid, _বেছি_, 
   {{0x3ea00998,0x787800d8,0x7bc40dd6,0x87000cc9}},	//   _juit_, nívi, maiu, вяще, 
   {{0x3ea000d8,0x7bc40dd7,0x6484007b,0x00000000}},	//   _muit_, laiu, hóid, --, 
   {{0xa8180dd8,0x3ea00dd9,0xdb0400e4,0xf1c80150}},	//   تتەر_, _luit_, _tekó, _ﻓﺘﻨﺘ, 
   {{0x7bc40dda,0x672c0023,0x3ea0007f,0x159000d1}},	//   naiu, ënjë, _ouit_, ﻟﯘﺷﯩ, 
   {{0x68e004f3,0x3ea00ddb,0xa3ac05f9,0x6484007b}},	//   _äldr, _nuit_, कड़_, dóid, 
   {{0x7bc40ddc,0xdb140054,0x7878004e,0x6aa800d8}},	//   haiu, mayä, dívi, _éefe, 
   {{0x7bc40ddd,0x649400bc,0x648401e7,0xdb140dde}},	//   kaiu, _kšil, fóid, bayç, 
   {{0x3ea00ddf,0x68e004f3,0x28d000bc,0x648400ae}},	//   _buit_, _ålde, _हिसि, góid, 
   {{0x3ea00de0,0x7bc401ab,0xc7b0011a,0x02c0010a}},	//   _cuit_, daiu, כבר_, _айчо, 
   {{0x3ea00de1,0x246404fe,0x3c3c03b2,0x3b000327}},	//   _duit_, rēme_, _ríva_, dwiq_, 
   {{0x2f240de2,0x3ea0003a,0xac180de3,0x41d80375}},	//   _bëgë_, _euit_, пову_, _וחוס, 
   {{0x3ea00de4,0xdb040699,0xdb140de5,0x7bc40de6}},	//   _fuit_, _rekò, kayä, gaiu, 
   {{0x2f24002e,0x3ea00ba1,0x787800cf,0x00000000}},	// [990] _dëgë_, _guit_, cívi, --, 
   {{0xdb04007f,0xaf540022,0x648400e4,0x00000000}},	//   _pekò, _онқә, póig, --, 
   {{0x3ea0017a,0x7bc4054e,0x30bc0154,0xe7f40de7}},	//   _zuit_, baiu, _অমুস, ечлэ, 
   {{0xec3404ac,0xb52402a6,0x1ee8036b,0x799c03ac}},	//   _נאָר_, বনাথ_, _بویی_, _egrw, 
   {{0x2ee805b1,0x6b9c03ac,0xe8780014,0x9b4001d9}},	//   _jqaf_, _igsg, _ہجرچ_, _یۆہو, 
   {{0x648400d8,0x6014008e,0x26f000cc,0xd6740116}},	//   zóid, _kümä, চিলো_, ىڭلا_, 
   {{0x67d40640,0x00000000,0x00000000,0x00000000}},	//   _пову, --, --, --, 
   {{0x69c40de8,0x2ca00de9,0x6a78026c,0x58000131}},	//   lahe, _muhd_, dìfi, _مۈمك, 
   {{0xae5c0150,0x00000000,0x00000000,0x00000000}},	//   _ﺍﺳﺎﯞ_, --, --, --, 
   {{0x69c40dea,0x3ea00deb,0x26dc0bd7,0x64940024}},	//   nahe, _ruit_, muwo_, _išim, 
   {{0x26dc0dec,0x64840ded,0x3ea00dee,0x00000000}},	//   luwo_, tóid, _suit_, --, 
   {{0x69c40def,0x78780232,0x3ea00df0,0x6b9c0112}},	//   hahe, tívi, _puit_, _ngsg, 
   {{0x69c40df1,0x64840df2,0x82800116,0x7bc40099}},	//   kahe, róid, _иңиз, vaiu, 
   {{0x3ea000f7,0x63a80df3,0x69c40df4,0x2ca0020c}},	//   _vuit_, lcen, jahe, _buhd_, 
   {{0x63a80df5,0x69c40df6,0x6a780268,0x6abc03ac}},	//   ocen, dahe, cìfi, _awsf, 
   {{0x63a80df7,0x3ea00df8,0x26dc0df9,0x248c0dfa}},	//   ncen, _tuit_, kuwo_, nmem_, 
   {{0x2be00316,0x8d740131,0xcb640276,0x69c40dfb}},	// [9a0] _फारा, _ۋاپا, еате_, fahe, 
   {{0x63a80334,0x26dc0099,0x3b000309,0xda0800c5}},	//   hcen, duwo_, rwiq_, _होखत_, 
   {{0x63a80dfc,0xdb140dfd,0x248c0548,0x6abc03ac}},	//   kcen, wayä, kmem_, _ewsf, 
   {{0x63a80dfe,0x5e440014,0x26dc07a9,0x248c0dff}},	//   jcen, _آنگٕ, fuwo_, jmem_, 
   {{0x69c40e00,0x26dc0e01,0x248c0010,0x00000000}},	//   bahe, guwo_, dmem_, --, 
   {{0x69c40e02,0xdb1403f0,0x55040262,0x672c0e03}},	//   cahe, rayä, ечиа, äaja, 
   {{0x64940e04,0x63a8003a,0x00000000,0x00000000}},	//   _išij, fcen, --, --, 
   {{0x26dc0161,0xc5100150,0x63a80e05,0xdb140113}},	//   buwo_, ابوت, gcen, payä, 
   {{0x9f500548,0x88540375,0x28740124,0x96b80107}},	//   _mayó_, _נשמע_, _рырр, _хубу_, 
   {{0x63a80e06,0x25a806f6,0x7e600e07,0xdbdc01e1}},	//   acen, _قدمي_, émpl, _síìf, 
   {{0x63a80e08,0xc68c009f,0x00000000,0x00000000}},	//   bcen, _اِل_, --, --, 
   {{0x63a80e09,0x69c40e0a,0x161c0490,0x8538011a}},	//   ccen, zahe, पावर_, _מגבי, 
   {{0x69c40e0b,0x601401b8,0x244801f7,0x91e000fb}},	//   yahe, _sümä, _تجلي_, _йәнһ, 
   {{0x28d0000d,0x69c40009,0x00000000,0x00000000}},	//   _हिलि, xahe, --, --, 
   {{0x69c40e0c,0xbd680e0d,0x26dc0161,0x246400e2}},	//   vahe, ерте_, zuwo_, lēma_, 
   {{0x69c40e0e,0x9f500154,0x4178010f,0x8aa401f4}},	//   wahe, _cayó_, _מנוב, ержд, 
   {{0x63bc03b2,0x00000000,0x00000000,0x00000000}},	// [9b0] ðsni, --, --, --, 
   {{0x320c00d8,0x69c40798,0x248c0e0f,0x63a80e10}},	//   nddy_, uahe, zmem_, zcen, 
   {{0x69c40e11,0x26dc0e12,0x63a80e13,0x29000e14}},	//   rahe, wuwo_, ycen, uwha_, 
   {{0x69c40e15,0x26dc0e16,0x63a80e17,0x67d400db}},	//   sahe, tuwo_, xcen, тоду, 
   {{0x69c40e18,0x1cdc0135,0x290002b9,0x377406d3}},	//   pahe, _ལའོ_, swha_, лышс, 
   {{0x26dc0086,0x64940308,0xdb1c0241,0xdaa00116}},	//   ruwo_, _všim, _ìyáp, _ئەلپ, 
   {{0x26dc006f,0x9f5001e1,0x248c0e19,0x61e401e3}},	//   suwo_, _jayò_, tmem_, _öhli, 
   {{0x26dc0e1a,0x756801d3,0x63a80c5e,0x9f4001f4}},	//   puwo_, رینہ_, ucen, mekö_, 
   {{0x23780e1b,0x2b480e1c,0x14200e1d,0x9f500248}},	//   æsj_, nzac_, рдым, _layò_, 
   {{0x63a80e1e,0x248c09ab,0x2b48005a,0xc0240023}},	//   scen, smem_, izac_, _ሲቪላው, 
   {{0xa0680e1f,0x63a80e20,0x1cdc025c,0x00000000}},	//   дана_, pcen, _ལའེ_, --, 
   {{0x321c0e21,0x00000000,0x00000000,0x00000000}},	//   _envy_, --, --, --, 
   {{0xa2e40e22,0x442c058a,0xdcf40205,0x9f5003e3}},	//   _ролд, _iog_, _ıcım, _ücün_, 
   {{0x442c045a,0x2f8400fb,0x2b48012d,0x00000000}},	//   _hog_, ыҙын_, dzac_, --, 
   {{0x1fb40e23,0x442c0114,0xdca40e24,0x217400c8}},	//   _испр, _kog_, таби, _בײַם_, 
   {{0x442c0e25,0xdb0401b8,0x9f5001e1,0x785c0100}},	//   _jog_, _mekö, _dayò_, pčvi, 
   {{0x442c01d4,0x4f040e26,0x1e84049e,0x649401fa}},	// [9c0] _mog_, _анын_, _илим, _ašik, 
   {{0x4a400e27,0x442c0e28,0x8f340375,0x0a140014}},	//   анув, _log_, _סניף_, نہُک_, 
   {{0x442c0e29,0x2dd800c8,0xdb040793,0x9d440e2a}},	//   _oog_, _אַרב, _nekö, _ренд, 
   {{0x442c0e2b,0xca300e2c,0x2b48067c,0x461000f2}},	//   _nog_, ﺭﺍﺕ_, bzac_, یونر, 
   {{0x2b480210,0x98b00205,0x656c0e2d,0x00000000}},	//   czac_, ıcım_, şahl, --, 
   {{0x442c0e2e,0x649405a1,0xdb040e2f,0xdef001f3}},	//   _aog_, _ušij, _bekö, _ሌኒን_, 
   {{0x442c0e30,0x85000e31,0x5d78008f,0xa3ac0073}},	//   _bog_, لوون, ואַק, कडं_, 
   {{0x442c0e32,0x78780e33,0x00000000,0x00000000}},	//   _cog_, tívu, --, --, 
   {{0x442c0c30,0xb2740131,0xdc440092,0x00000000}},	//   _dog_, ллиш, _መወሰኑ, --, 
   {{0x442c0e34,0xc0d0001f,0x00000000,0x00000000}},	//   _eog_, ራለሁ_, --, --, 
   {{0x442c0e35,0xdb040e36,0xd4040116,0x765801f4}},	//   _fog_, _gekö, _аяли, mivy, 
   {{0x765805d9,0x312405f5,0x648401e7,0x73c402dd}},	//   livy, вдүг, róic, _сәке, 
   {{0x1cdc031c,0x9f500241,0x787806ea,0x661002d2}},	//   _ལའུ_, _sayò_, lívs, _ákkú, 
   {{0x442c0190,0xc20c0a81,0xdb0c0241,0x00000000}},	//   _zog_, _ؤن_, _ájùl, --, 
   {{0x442c0e37,0x2d840e38,0x00000000,0x00000000}},	//   _yog_, åle_, --, --, 
   {{0x3d0805ba,0x64b00e39,0x442c01d9,0x76580e3a}},	//   हिजे_, _fāif, _xog_, hivy, 
   {{0xbd680276,0x76580153,0x998801ef,0xfb340e3b}},	// [9d0] ерӂе_, kivy, _bobů_, антэ, 
   {{0x2b480df5,0x5fb40034,0x201c00e2,0x9f40005b}},	//   rzac_, ूरथल, ētie_, tekö_, 
   {{0x2d580323,0x26cc0e3c,0x39a40890,0x7d08005c}},	//   _чинь_, _sveo_, ршув, ædst, 
   {{0x1ab000fe,0xdd38011a,0x672c01f4,0x00000000}},	//   _চিৰা, _נערכ, äajo, --, 
   {{0x442c0e3d,0xd7ec0e3e,0xdb040793,0x64840798}},	//   _rog_, سكو_, _sekö, jóia, 
   {{0x442c07d6,0x69dc0574,0x7f3c0375,0xfd100e3f}},	//   _sog_, _पाटी, ועדו, _اجی_, 
   {{0x442c0e40,0x78780030,0x46dc0037,0x78ac0419}},	//   _pog_, tívt, _नमकह, ľové, 
   {{0x442c0e41,0x76580af9,0x78ac0306,0x48640395}},	//   _qog_, aivy, žové, _ръгб, 
   {{0x97e80e42,0x442c0e43,0xe2980364,0x765807a8}},	//   ıştı, _vog_, наи_, bivy, 
   {{0x442c0e44,0x76580e45,0x93c80050,0x00000000}},	//   _wog_, civy, ٘ایہ_, --, 
   {{0x009c0150,0xd7740023,0x00000000,0x00000000}},	//   _ﺍﻟﺒﺤ_, _ክሓተካ_, --, --, 
   {{0xe0440e46,0xe2980124,0x00000000,0x00000000}},	//   унми, ьаҿ_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9f400e47,0x21680e48,0x1d0800db,0x26180e49}},	//   ngké_, _пили_, неги_, पाटी_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x5f04035b,0x30740354,0x6bb400d4,0x24c400cc}},	//   _бзиа, _вуьс, исує, _এমাহ, 
   {{0x1ec801b9,0xaab801d9,0x00000000,0x00000000}},	// [9e0] _ялпи_, ندٕر_, --, --, 
   {{0xd9ac01ad,0xde040798,0x00000000,0x00000000}},	//   टडेट, _спои, --, --, 
   {{0x1cdc038f,0x9c640e4a,0x61e4007c,0x1c10000d}},	//   _ལའི_, _مهدو, _öhlu, _ढोअल_, 
   {{0x64940135,0x53800092,0x00000000,0x00000000}},	//   _eġiz, _የዳዊት_, --, --, 
   {{0x237c0007,0xdb040022,0x6d680356,0x00000000}},	//   _nywj_, _pekõ, ăpaţ, --, 
   {{0xdb04000f,0x20000e4b,0x00000000,0x00000000}},	//   _dekô, heki_, --, --, 
   {{0x76580e4c,0x20000e4d,0xd944036b,0xd4980e4e}},	//   rivy, keki_, _севи, нри_, 
   {{0x20000e4f,0x76580e50,0x97e80e51,0x53e40006}},	//   jeki_, sivy, ışsı, уцка, 
   {{0x20000e52,0xe8500e53,0x02a0013d,0x00000000}},	//   deki_, _بۆند, йрэм, --, 
   {{0x32540e54,0x967400c0,0x00000000,0x00000000}},	//   рвор, _сыбі, --, --, 
   {{0x427001c6,0x64840332,0x4638010f,0x80a400cc}},	//   сгэс, móin, _רעבע, কীস্, 
   {{0x64840e55,0x2000037e,0x53a401f0,0xc950011a}},	//   lóin, geki_, _садб, ממת_, 
   {{0x26180073,0x00000000,0x00000000,0x00000000}},	//   पाची_, --, --, --, 
   {{0xf194040e,0xc32c0e56,0x648401e7,0x00000000}},	//   _киль, _رەپ_, nóin, --, 
   {{0x64b000a3,0x8c64010b,0x00000000,0x00000000}},	//   _gāid, гтад, --, --, 
   {{0x20000365,0xb3740023,0xade80e57,0x00000000}},	//   ceki_, _ካናዳን_, ञ्जन_, --, 
   {{0xaa540e58,0xdf5400f1,0x0dc80063,0xadd40114}},	// [9f0] аваш, _پريښ, _пуни_, _копљ, 
   {{0xdb040b21,0x64840e59,0x00000000,0x00000000}},	//   _rekô, jóin, --, --, 
   {{0xe7b40e5a,0x648408de,0xfd7401c4,0x00000000}},	//   لماد, dóin, _глээ, --, 
   {{0x64b0005f,0x6fb40e5b,0x27e80037,0x00000000}},	//   _jāie, ंडिं, üan_, --, 
   {{0x65c40e5c,0xe6940022,0x00000000,0x00000000}},	//   абла, аиды, --, --, 
   {{0x20000e5d,0x27e80e5e,0x648408de,0xade800cd}},	//   zeki_, żan_, góin, ञ्चन_, 
   {{0x29040e5f,0x85540e60,0x20000944,0x69d4002d}},	//   _èla_, دیار_, yeki_, _idze, 
   {{0x20000e61,0x00000000,0x00000000,0x00000000}},	//   xeki_, --, --, --, 
   {{0x20000e62,0x009c01ec,0x00000000,0x00000000}},	//   veki_, _ﺍﻟﺘﺤ_, --, --, 
   {{0xf7700e63,0x20000e64,0x99480e65,0xba900150}},	//   _راق_, weki_, nışa_, _ﺒﺎﻟﻙ_, 
   {{0x21680e66,0x60240e67,0x8c380112,0x69ac000d}},	//   тини_, адна, _mißb, _जलनी, 
   {{0x20540cdb,0x00000000,0x00000000,0x00000000}},	//   ртор, --, --, --, 
   {{0x1cdc003d,0x20000e68,0x4f040209,0xdea001d5}},	//   _ལའང_, reki_, анян_, غیدی, 
   {{0x443c0e69,0x20000e6a,0x69d407a9,0x6494031c}},	//   lku_, seki_, _ndze, _aġix, 
   {{0xdd900e6b,0xe1080e6c,0x200008a7,0x6280036e}},	//   زور_, _рейд_, peki_, mllo, 
   {{0x443c0e6d,0x64480e6e,0x69d40e6f,0x3ba4036b}},	//   nku_, nhei, _adze, слаҳ, 
   {{0x62800e70,0x64480e71,0x19c40e72,0x1ae400e9}},	// [a00] ollo, ihei, ибам, розм, 
   {{0x6f0805d1,0x64480e73,0x62800005,0x785c0841}},	//   çece, hhei, nllo, jčvr, 
   {{0x64480e74,0x62800e75,0xaab80e76,0x3c3c022c}},	//   khei, illo, ندەر_, _lívi_, 
   {{0x443c0bb8,0x64480e77,0x62800e78,0x69d40e79}},	//   jku_, jhei, hllo, _edze, 
   {{0x64480e7a,0x648401d3,0x62800200,0x99480139}},	//   dhei, tóin, kllo, bışa_, 
   {{0x443c0e7b,0x7ae40e7c,0x1dc40e7d,0x38c80e7e}},	//   eku_, muit, वरित, _ماری_, 
   {{0x7ae40e7f,0x64480597,0x443c01d9,0x628002c4}},	//   luit, fhei, fku_, dllo, 
   {{0x64480e80,0x62800e81,0x443c0e82,0x7ae4009f}},	//   ghei, ello, gku_, ouit, 
   {{0x77940e83,0x78a000aa,0x55e40e84,0x1dc40e85}},	//   _ایشا, _iimv, _возб, वरात, 
   {{0x443c0e86,0x6448002d,0x7ae402b1,0x62800174}},	//   aku_, ahei, iuit, gllo, 
   {{0x443c0e87,0x7ae40e88,0x78a00085,0x64480e89}},	//   bku_, huit, _kimv, bhei, 
   {{0x7ae40e8a,0x443c0e8b,0x62800e8c,0x3f800198}},	//   kuit, cku_, allo, _byiu_, 
   {{0x7ae40e8d,0x78a00099,0xad240e8e,0xd37004fb}},	//   juit, _mimv, ڭىزى, _بهش_, 
   {{0x7ae40e8f,0x78a00e90,0x6e940e91,0x201c00b0}},	//   duit, _limv, сигу, ētia_, 
   {{0x8bc40724,0x0ed00490,0xb0f8020f,0xc0e00e92}},	//   исад, _तिकड, _сейф_, _дојк, 
   {{0x78a00e93,0x7ae40e94,0xada400d1,0x00000000}},	//   _nimv, fuit, раңл, --, 
   {{0x7ae40e95,0x9988007f,0xf3f8015b,0x994806b9}},	// [a10] guit, _dabō_, _অফার_, tışa_, 
   {{0x64480399,0x443c0e96,0x656c03be,0x8c380e78}},	//   zhei, zku_, şahi, _bißc, 
   {{0x443c0e97,0x78a00085,0x64480151,0x99480e98}},	//   yku_, _bimv, yhei, rışa_, 
   {{0x7ae40e99,0x64480007,0x6f0c0334,0x443c0009}},	//   buit, xhei, _ksac, xku_, 
   {{0x443c0e9a,0x7ae40e9b,0x62800e9c,0x3b6406bb}},	//   vku_, cuit, yllo, _дърв, 
   {{0x64a40e9d,0x6f0c009f,0x2fc80e9e,0xaa440e56}},	//   бака, _msac, _leag_, _انسى, 
   {{0xd5ac0e9f,0x6f0c022e,0x25ec000d,0x62800200}},	//   رفي_, _lsac, _घाठी_, vllo, 
   {{0x6f0c02ce,0x2408013e,0x2fc80356,0x64480ea0}},	//   _osac, унии_, _neag_, uhei, 
   {{0x6f0c063f,0x27ec0ea1,0x628000cf,0x6aac0327}},	//   _nsac, _icen_, tllo, nqaf, 
   {{0x78a00ea2,0xe20801e1,0x00000000,0x00000000}},	//   _zimv, _gbọ́_, --, --, 
   {{0x2fc80ea3,0x6f0c0ea4,0x64480ea5,0x846406bb}},	//   _beag_, _asac, phei, _къде, 
   {{0x7ae40d04,0x53740020,0x64480007,0x443c02d1}},	//   yuit, _አዳዲስ_, qhei, qku_, 
   {{0x64580ea6,0x02a40ea7,0x6f0c0ea8,0x9e6400c6}},	//   _imwi, _трем, _csac, ماسن, 
   {{0xe1f00b28,0x7ae40ea9,0x62800113,0x00000000}},	//   _رست_, vuit, qllo, --, 
   {{0x6f0c0921,0x64580998,0x27ec0eaa,0x6efc01e6}},	//   _esac, _kmwi, _ocen_, _påbö, 
   {{0x68e4089c,0x27ec00f2,0x2fc80ea0,0x648400e4}},	//   duhd, _ncen_, _geag_, kóim, 
   {{0x78a00eab,0x7ae40798,0x44fc0eac,0xdb1400a2}},	// [a20] _rimv, uuit, ্মিক_, bayý, 
   {{0x20100ead,0x27ec0eae,0x64840332,0x5cf400c0}},	//   _hayi_, _acen_, dóim, _ляму, 
   {{0x64580eaf,0x20100eb0,0x00000000,0x00000000}},	//   _omwi, _kayi_, --, --, 
   {{0x7ae40eb1,0x20100eb2,0x44fc00cc,0x00000000}},	//   puit, _jayi_, ্মাক_, --, 
   {{0x20100eb3,0x25a40042,0x00000000,0x00000000}},	//   _mayi_, _bgll_, --, --, 
   {{0x64580eb4,0x20100c09,0x27ec0eb5,0x00000000}},	//   _amwi, _layi_, _ecen_, --, 
   {{0x78a00eb6,0x18680640,0x64840332,0x00000000}},	//   _timv, _бави_, póil, --, 
   {{0x20100eb7,0x00000000,0x00000000,0x00000000}},	//   _nayi_, --, --, --, 
   {{0x2fc8011c,0x661002f6,0x90a001ec,0xa49000f2}},	//   _reag_, ökkä, _ﺍﻟﺘﻔ_, ذیهت, 
   {{0x64580428,0x20100009,0xdb140113,0x6f0c01ab}},	//   _emwi, _aayi_, layó, _rsac, 
   {{0x20100eb8,0x53140eb9,0x25ec05dc,0x00000000}},	//   _bayi_, _گذار, _घाती_, --, 
   {{0x2010011f,0x0ee80eba,0x6f0c0ebb,0xb6cc06be}},	//   _cayi_, льги_, _psac, _şüyü, 
   {{0x64b00374,0x82c4031c,0x20100ebc,0x64940ebd}},	//   _iāia, _གསརའ, _dayi_, _všit, 
   {{0x0af001c6,0x427002dd,0x00000000,0x00000000}},	//   үүнэ, _егіс, --, --, 
   {{0x201000ca,0x64940ebe,0x64b000b0,0x2fc800a3}},	//   _fayi_, _tšit, _kāia, _teag_, 
   {{0x20100198,0x6f0c03f0,0x64940306,0xc98400fb}},	//   _gayi_, _tsac, _ušit, ҡужи, 
   {{0x64b002b5,0x6f0c0ebf,0x6a34026a,0x764800a2}},	// [a30] _māia, _usac, онађ, _oldy, 
   {{0x27ec0ec0,0x6aac0023,0x20100ec1,0xa3800037}},	//   _scen_, rqaf, _zayi_, öõig, 
   {{0x20100ec2,0x6e240109,0x27ec0ec3,0xfe240022}},	//   _yayi_, _inhb, _pcen_, _хьын, 
   {{0xac180ec4,0x64b004fe,0xf99006b7,0x20100429}},	//   _тому_, _nāia, ربل_, _xayi_, 
   {{0x667404fb,0x68e402f6,0xe5a40b3b,0xe70400f2}},	//   يدتر, suhd, оили, تسای, 
   {{0xf7700ec5,0x68e4005b,0x648401e7,0xe6180022}},	//   ران_, puhd, róim, рдк_, 
   {{0x27ec011c,0xdee40023,0xa7e40150,0xdb1400e4}},	//   _tcen_, _ምጣነ_, _وكسى, mbyá, 
   {{0xdb140100,0x78b801d3,0x64840022,0x47f0009d}},	//   mayò, ívve, móik, _хүдр, 
   {{0x52a40ec6,0x20100ec7,0x8c10009e,0x2bb0012c}},	//   овым_, _rayi_, হাপন_, _झलना, 
   {{0x20100ec8,0x00000000,0x00000000,0x00000000}},	//   _sayi_, --, --, --, 
   {{0xdde80ec9,0x20100100,0x648400e4,0xdd0c0166}},	//   یرسه_, _payi_, nóik, dışe, 
   {{0x64580516,0x44f00eca,0x6e240208,0x00000000}},	//   _umwi, mã_, _anhb, --, 
   {{0x44f00c67,0x20100943,0x2d840ecb,0x00000000}},	//   lã_, _vayi_, ülen_, --, 
   {{0x20100ecc,0xdca4041b,0x44f00165,0x648400e4}},	//   _wayi_, жави, oã_, kóik, 
   {{0x20100ecd,0x1d080ece,0x44f00ecf,0xdfd000dd}},	//   _tayi_, шеви_, nã_, _ہيں_, 
   {{0x44f00004,0x00000000,0x00000000,0x00000000}},	//   iã_, --, --, --, 
   {{0xdd940ed0,0xf7cc0ed1,0x44f00ed2,0x7b8400d1}},	// [a40] саңы, ﮔﻪﻧﺪ, hã_, سارە, 
   {{0x09e00131,0x44f00124,0x00000000,0x00000000}},	//   дофн, kã_, --, --, 
   {{0x57a40ed3,0x44f00589,0x6d400165,0xad5802e8}},	//   ошла, jã_, ùlat, _грях_, 
   {{0x7e7c0ed4,0x00000000,0x00000000,0x00000000}},	//   lorp, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7e7c0ed5,0xdb14007f,0xc68c01d9,0xe9a8009f}},	//   norp, bayò, نِن_, _هدفن_, 
   {{0x3af40ed6,0x44f00004,0xdb140309,0x00000000}},	//   läp_, gã_, mayñ, --, 
   {{0x7e7c0ed7,0xdfe40b03,0x77940ed8,0x00000000}},	//   horp, _कागद_, _فیضا, --, 
   {{0x166406bb,0x3a380003,0x44f00c67,0xcc38008f}},	//   _двам, _korp_, aã_, שעפט, 
   {{0x44f00589,0x5184036b,0x7e7c0140,0x00000000}},	//   bã_, жума, jorp, --, 
   {{0x32d000d2,0x44f00004,0x7e7c0373,0x3a3805b1}},	//   _bôyá_, cã_, dorp, _morp_, 
   {{0x64b00325,0x3af400a2,0x00000000,0x00000000}},	//   _kāin, käp_, --, --, 
   {{0xdb140784,0x3c3c0174,0xfd540055,0x64b000de}},	//   kayñ, _lívs_, _iveṣ, _jāin, 
   {{0x9de40ed9,0x7e7c0eda,0x6aa800d8,0x421401d9}},	//   _སྐྱེ, gorp, _éefi, _وٲنج_, 
   {{0x82c4081f,0x25b800ac,0xac940edb,0xc5cc0154}},	//   _གསོའ, _əsl_, завш, _রামপ, 
   {{0x5ea800eb,0x00000000,0x00000000,0x00000000}},	//   _কবরে, --, --, --, 
   {{0x7e7c0edc,0x44f00004,0x3af4010e,0x00000000}},	// [a50] borp, zã_, gäp_, --, 
   {{0x09e009bd,0x44f00004,0x7e7c0edd,0xba7400f1}},	//   ন্না, yã_, corp, والت, 
   {{0x3a380e29,0x44f00004,0xefc80023,0x8c34014b}},	//   _dorp_, xã_, _ኽሳዕ_, _донӣ_, 
   {{0x44f00004,0x3af40ede,0x3a3800a3,0xac0800db}},	//   vã_, bäp_, _eorp_, _اردە_, 
   {{0x87040edf,0xfe700133,0xdb14007f,0x3af4008e}},	//   تبال, _سدی_, sayò, cäp_, 
   {{0xd1240597,0x44f00ee0,0x3a380076,0x64a40ee1}},	//   _كم_, tã_, _gorp_, пака, 
   {{0x44f00589,0x35f806c2,0x5b500092,0x00000000}},	//   uã_, ترند_, _መመደቡ, --, 
   {{0x44f00ee2,0xf9640244,0x00000000,0x00000000}},	//   rã_, _تۆمێ, --, --, 
   {{0xfd5400dc,0x44f00ee3,0x16140210,0x00000000}},	//   _dveṣ, sã_, _धोकर_, --, 
   {{0x44f00ee4,0xfd5400b8,0x00000000,0x00000000}},	//   pã_, _eveṣ, --, --, 
   {{0x7e7c0ee5,0xd12c0133,0x1fa8005b,0x00000000}},	//   vorp, ۆمی_, йкни_, --, 
   {{0x44d400a8,0x7e7c0373,0xa0680640,0x2910012d}},	//   mă_, worp, сама_, _msza_, 
   {{0x44d400a8,0x7e7c0ee6,0xd12c0ee7,0xa0c40ee8}},	//   lă_, torp, نمی_, _کيبو, 
   {{0x629c0316,0x04fc0154,0x5398011a,0x00000000}},	//   ůsob, ্মীর_, _פיסו, --, 
   {{0x44d40262,0x64b002b5,0x7e7c0ee9,0x5c680092}},	//   nă_, _māio, rorp, _ተለይቶ_, 
   {{0x5ba80eea,0x09e000bd,0x3a38032e,0x00000000}},	//   скам_, ন্মা, _sorp_, --, 
   {{0x7e7c01e4,0x1cdc031c,0x9aa4007b,0x8f600092}},	// [a60] porp, _ལའམ_, سماو, ለካከቶ, 
   {{0x3af40eeb,0x64b002b1,0x7e7c0eec,0x9e08007b}},	//   räp_, _rāin, qorp, _ايدك_, 
   {{0x44d4084c,0x18a40eed,0x246400de,0x00000000}},	//   jă_, чаем, lēmu_, --, 
   {{0x44d4084c,0x64b002b1,0x3a380582,0x38c80133}},	//   dă_, _pāin, _worp_, ماڵی_, 
   {{0xe79401d9,0x60cc0210,0x00000000,0x00000000}},	//   ٘اوک, _łaml, --, --, 
   {{0x7ae40eee,0x7bc40024,0x44d4054e,0xfd54002b}},	//   mrit, lbiu, fă_, _sveṣ, 
   {{0x44d4084c,0x7ae40eef,0xf8e00034,0x198405d9}},	//   gă_, lrit, _पटिय, _رجسٽ, 
   {{0x64b00ef0,0x7bc4003a,0xe7c80327,0xdb0802d2}},	//   _tāin, nbiu, _ċaħħ, _ínóv, 
   {{0x7ae40ef1,0x00000000,0x00000000,0x00000000}},	//   nrit, --, --, --, 
   {{0x7ae40ef2,0x44d40276,0xc0d0001f,0x09e000cc}},	//   irit, bă_, ያለሁ_, ন্ঠা, 
   {{0x44d40262,0x7ae40ef3,0xfd5400b8,0x66800ef4}},	//   că_, hrit, _tveṣ, _جیول, 
   {{0xd9d000cc,0x2d840ef5,0x00000000,0x00000000}},	//   ালিম, ülem_, --, --, 
   {{0x9fa401e0,0x838001f4,0x00000000,0x00000000}},	//   дырҙ, _пыше, --, --, 
   {{0x8d740ef6,0x693401ef,0x00000000,0x00000000}},	//   كازا, _hřeš, --, --, 
   {{0x7ae40ef7,0x82300ef8,0x09e000bd,0x2d840ef9}},	//   erit, _سروا, ন্ডা, æle_, 
   {{0x7ae40efa,0x81340efb,0x10780131,0xfe700efc}},	//   frit, _ءسوز_, ﻧﺎﺯﯨ, ندۀ_, 
   {{0x44d40262,0xdb100248,0x00000000,0x00000000}},	// [a70] ză_, _ògìr, --, --, 
   {{0x6d5802a8,0x00000000,0x00000000,0x00000000}},	//   _ƙwad, --, --, --, 
   {{0x7ae40efd,0x7bc4026c,0xfeb80424,0xd36403e6}},	//   arit, bbiu, _وایت_, _ڤه_, 
   {{0x44d4084c,0x9cd40375,0xf99000c6,0x64840efe}},	//   vă_, _קורה_, ابك_, lóiv, 
   {{0x8b640eff,0x00000000,0x00000000,0x00000000}},	//   _راحم, --, --, --, 
   {{0x44d40262,0xa5640f00,0x3cf80f01,0x6abc035a}},	//   tă_, وگان, _بعید_, _itsf, 
   {{0x69c40f02,0x44d4054e,0x6d54002f,0xf6500137}},	//   mbhe, uă_, nzza, دئن_, 
   {{0x44d40262,0x69c408c2,0x8a6002f2,0x00000000}},	//   ră_, lbhe, _تێڕۆ, --, 
   {{0x44d400a8,0x7d1c0f03,0x04fc015b,0x64840124}},	//   să_, zvrs, ্মের_, kóiv, 
   {{0xe0d80f04,0x7bc40f05,0x44d4084c,0x61440f06}},	//   ово_, zbiu, pă_, деоа, 
   {{0x69c40f07,0x7ae401a2,0x09e002f5,0x45480120}},	//   ibhe, zrit, ন্থা, _учам_, 
   {{0x7ae40f08,0x69c40f09,0x7158010b,0x00000000}},	//   yrit, hbhe, ярыс_, --, 
   {{0x6d54026c,0x7e600066,0x6d400f0a,0x00000000}},	//   ezza, èmpo, ølan, --, 
   {{0x7ae40f0b,0x6e340200,0x00000000,0x00000000}},	//   vrit, gjzb, --, --, 
   {{0x7ae40f0c,0x6abc02d0,0x91b8011a,0xd12c0f0d}},	//   writ, _atsf, _ומצי, _نمو_, 
   {{0x68e40cf9,0xb5fc031c,0x69c4009a,0x00000000}},	//   drhd, _imġe, ebhe, --, 
   {{0x7ae40f0e,0x6d540f0f,0x7bc40f10,0x64b00421}},	// [a80] urit, azza, rbiu, _sāil, 
   {{0x1cb80f11,0xd94400ee,0xdb100241,0x00000000}},	//   _واجب_, мези, _ògír, --, 
   {{0x27fc0368,0xd8b800db,0x00000000,0x00000000}},	//   ffwn_, زداا_, --, --, 
   {{0x2d9400ee,0x776400db,0x00000000,0x00000000}},	//   _ярыс, úixo, --, --, 
   {{0xc7a00f12,0x202c0020,0x69c401e3,0x00000000}},	//   вицк, _እየተከ, bbhe, --, 
   {{0xf67405f5,0x4aa40131,0x75d40f13,0x69c401c3}},	//   эглэ, _окян_, ريبا, cbhe, 
   {{0xdb0400b5,0x693400bc,0x00000000,0x00000000}},	//   _afkø, _přeš, --, --, 
   {{0xd7040f14,0x73d80440,0x04600f15,0x00000000}},	//   _озби, чдир_, ктым, --, 
   {{0x693401ef,0x00000000,0x00000000,0x00000000}},	//   _vřeš, --, --, --, 
   {{0xba080f16,0xd6240f17,0x6204013a,0x82900116}},	//   _ዋና_, _تعري, _čulí, نۇنچ, 
   {{0x63b8015d,0x693400bc,0x427001c6,0xdcfc013a}},	//   _ffwn, _třeš, тгэс, _vzpě, 
   {{0x741403e6,0x7c580092,0x00000000,0x00000000}},	//   _سوتا, _ሀገሪቱ, --, --, 
   {{0x41bc0825,0x24500162,0x2d980131,0x00000000}},	//   _श्वस, _dámd_, ﻘﯩﻨﻰ_, --, 
   {{0xb63004ce,0x1e7002dd,0x6d540112,0x68e0005c}},	//   _ｐｒ_, лғыс, tzza, _ældg, 
   {{0x6d54011c,0x320c0f18,0x00000000,0x00000000}},	//   uzza, medy_, --, --, 
   {{0x320c0c5e,0xc170011a,0x00000000,0x00000000}},	//   ledy_, _שחק_, --, --, 
   {{0x69c40afe,0xe2300214,0x64840022,0x3f1400c0}},	// [a90] tbhe, _شکیب, póiv, _адыс, 
   {{0x69c40175,0x648401e7,0x00000000,0x00000000}},	//   ubhe, lóit, --, --, 
   {{0x69c40f19,0x24500022,0xf8b000d1,0x00000000}},	//   rbhe, _háme_, لةن_, --, 
   {{0x64840022,0x69c407fc,0x385800f2,0xe47c0205}},	//   nóit, sbhe, وشند_, çtüğ, 
   {{0x320c01a2,0x0c6402d3,0x66e4020a,0x66040f1a}},	//   kedy_, _ተፈጢሩ_, хола, епла, 
   {{0x247c069c,0x24500e96,0xd6cc0f1b,0x7a1c007f}},	//   _ኣባላት_, _máme_, حقو_, pٍta, 
   {{0x64b004fe,0x245002f0,0xf41803d4,0xf8b40153}},	//   _tāim, _láme_, থানৰ_, _абсэ, 
   {{0xe7f8038e,0x00000000,0x00000000,0x00000000}},	//   _एउटा_, --, --, --, 
   {{0x64b002b5,0x25a8034c,0x130407d8,0x63040f1c}},	//   _kāik, _فضای_, еный_, رودل, 
   {{0x320c0f1d,0xc0880b82,0x00000000,0x00000000}},	//   gedy_, _ማህጸን_, --, --, 
   {{0x64b002b5,0xfd9002dd,0x00000000,0x00000000}},	//   _māik, _ﻓﻜﺎﻥ_, --, --, 
   {{0xdee40f1e,0x1b04015b,0x00000000,0x00000000}},	//   номи, রিতে_, --, --, 
   {{0xe80005ba,0x644803fa,0x232800c2,0x320c06d9}},	//   ळ्या_, mkei, _холи_, bedy_, 
   {{0x644802f6,0x24500122,0x320c02fb,0x00000000}},	//   lkei, _dáme_, cedy_, --, 
   {{0x62800f1f,0xda000bae,0x26f400eb,0x00000000}},	//   molo, र्फत_, _ইনফো_, --, 
   {{0x62800f20,0x64480f21,0x64840077,0x26cc003e}},	//   lolo, nkei, cóit, _oweo_, 
   {{0x6d5802a8,0x1e84033a,0x6448005b,0xd1280228}},	// [aa0] _ƙwac, _плим, ikei, _وقۇۇ_, 
   {{0x09e00f22,0x64480f23,0x3d18000d,0x6d6000cd}},	//   ন্সা, hkei, _पनपे_, _śvaś, 
   {{0x64480f24,0x0d200f25,0x64840f26,0x00000000}},	//   kkei, _йүрү, nóis, --, 
   {{0x62800f27,0xdad00075,0x38600013,0x6d400108}},	//   holo, _مەرھ, òir_, älae, 
   {{0x0c200801,0xdb100241,0x00000000,0x00000000}},	//   _смян, _ògàr, --, --, 
   {{0x62800f28,0x64b002b5,0x648400e4,0xa5c000c7}},	//   jolo, _kāih, kóis, иҩуе, 
   {{0x62800af2,0x6448002f,0x320c0419,0x00000000}},	//   dolo, fkei, vedy_, --, 
   {{0x62800f29,0x64480f2a,0x64b002b5,0xd6d00f2b}},	//   eolo, gkei, _māih, _مقر_, 
   {{0x62800f2c,0x68e001e6,0xb27400d1,0xe8180073}},	//   folo, _åldr, клиш, _नोटा_, 
   {{0x42700f2d,0xa6a80137,0x24500419,0x644801f4}},	//   лгыс, _قالق_, _ráme_, akei, 
   {{0x320c0f2e,0x00000000,0x00000000,0x00000000}},	//   redy_, --, --, --, 
   {{0x644802c1,0x62800421,0x320c0306,0x68e0005c}},	//   ckei, aolo, sedy_, _ælde, 
   {{0x62800f2f,0xff040f30,0x320c0a85,0xc4380302}},	//   bolo, лярн, pedy_, _מתאי, 
   {{0x628007d5,0x6e9401a9,0x00000000,0x00000000}},	//   colo, тигу, --, --, 
   {{0xfd100f31,0x8140032f,0x648401e7,0x00000000}},	//   یجہ_, _منون, móir, --, 
   {{0x64840553,0xeb400092,0x00000000,0x00000000}},	//   lóir, _የመግለ, --, --, 
   {{0x64b000b0,0x4ea40f32,0x6604000d,0x0a6800d8}},	// [ab0] _pāik, _проа, õhkk, пржи_, 
   {{0x64840f33,0xc9d003e6,0xdbdc032e,0x60cc033f}},	//   nóir, اماک, _bíóf, _łami, 
   {{0x26cc01af,0x0d480691,0x64480f34,0xe7380042}},	//   _sweo_, _رشدي_, ykei, _ngŵr_, 
   {{0x62800f35,0x64840597,0x00000000,0x00000000}},	//   zolo, hóir, --, --, 
   {{0x81d40729,0x64b002b1,0x648400c7,0x00000000}},	//   িলত_, _tāik, kóir, --, 
   {{0x62800f36,0xa5080cfc,0xdb14019f,0xc9840f37}},	//   xolo, дека_, rayô, _зуби, 
   {{0x62800f38,0x64840597,0x64480f39,0xc1b000c7}},	//   volo, dóir, tkei, қәлы, 
   {{0x62800f3a,0x23280107,0x00000000,0x00000000}},	//   wolo, доии_, --, --, 
   {{0xe2980aa5,0x64480f3b,0x648401e7,0x26d80ca8}},	//   маи_, rkei, fóir, _ìso_, 
   {{0x64480f3c,0x64840597,0x62800618,0xdb040129}},	//   skei, góir, uolo, îmée, 
   {{0x62800f3d,0x00000000,0x00000000,0x00000000}},	//   rolo, --, --, --, 
   {{0x64840597,0x64b002b5,0xb5fc025c,0x14c800f2}},	//   róis, _rāih, _imġa, _آهنی_, 
   {{0x9e640f3e,0x942400cf,0x649401ef,0x00000000}},	//   ناسن, _جونۇ, _ošiz, --, 
   {{0x62800f3f,0x64b000b0,0x3f8c0f40,0x1d0809a5}},	//   qolo, _pāih, ādu_, меги_, 
   {{0x8d600f41,0x248c0de2,0x11d4007b,0x00000000}},	//   авре, olem_, _شوية_, --, 
   {{0x248c0f42,0x00000000,0x00000000,0x00000000}},	//   nlem_, --, --, --, 
   {{0xcb640f43,0x248c0f44,0x70540354,0x00000000}},	// [ac0] вате_, ilem_, _сĕте, --, 
   {{0x248c0671,0x64b000b0,0xddcc00c0,0x00000000}},	//   hlem_, _tāih, lobž, --, 
   {{0x98a40f45,0x328402dd,0x00000000,0x00000000}},	//   виже, _ﺭﺌﻴﺱ_, --, --, 
   {{0x248c01ef,0xa9940116,0x00000000,0x00000000}},	//   jlem_, ھشەت, --, --, 
   {{0x248c0f46,0x9aa40f47,0xd730009d,0x00000000}},	//   dlem_, _لمحو, рдлө, --, 
   {{0x248c0f48,0x629c0f49,0x62f80154,0x00000000}},	//   elem_, ïsol, ্টায়_, --, 
   {{0xd4980354,0xda000f4a,0x00000000,0x00000000}},	//   мри_, र्णत_, --, --, 
   {{0x3dd80036,0x248c0f4b,0x85400166,0x00000000}},	//   harw_, glem_, рэше, --, 
   {{0x64840597,0xa2d40f4c,0xc7a00f4d,0x07a00f4e}},	//   tóir, _मौद्, _витк, _ватн, 
   {{0x248c0f4f,0x54c40022,0x6d400158,0x6eb8012d}},	//   alem_, _абжб, ølak, _एंबु, 
   {{0x64840597,0x38640109,0xc9cc00d1,0x00000000}},	//   róir, _kmmr_, _ﺗﯘﻳﻐ, --, 
   {{0x648400c6,0x248c0393,0xef64009d,0x00000000}},	//   sóir, clem_, гэгү, --, 
   {{0xb8f40f50,0xebb80882,0x291c0374,0x64840f51}},	//   _ེས_, niḥ_, āwai_, póir, 
   {{0x3dd80042,0x3f140798,0x00000000,0x00000000}},	//   garw_, јдрс, --, --, 
   {{0xebb80a28,0x24500f52,0x8c380112,0x00000000}},	//   hiḥ_, _háma_, _mißv, --, 
   {{0x99d003d4,0x09c800dc,0x648400e4,0x8f440117}},	//   ালোক, िर्य, nóip, _аход, 
   {{0x24500f53,0x6e440f54,0x63bc030a,0x99d003d4}},	// [ad0] _jáma_, _منظم, ñsni, ালৈক, 
   {{0x321c0f55,0x248c0f56,0xdb0402d2,0x24500f57}},	//   _javy_, zlem_, _afkó, _máma_, 
   {{0x248c0f58,0x321c00e4,0xb8b4007b,0x648400e4}},	//   ylem_, _mavy_, لإنت, kóip, 
   {{0xdd900f59,0x2fd801ab,0x321c00d7,0x00000000}},	//   _دوپ_, nasg_, _lavy_, --, 
   {{0x2450013a,0xb8140022,0x00000000,0x00000000}},	//   _náma_, шҧтә, --, --, 
   {{0x248c0649,0x321c0f5a,0xfd4c01e1,0x00000000}},	//   wlem_, _navy_, _ninọ, --, 
   {{0x69d40f5b,0x79a40f5c,0x248c0f5d,0x00000000}},	//   _ieze, _врте, tlem_, --, 
   {{0x72080014,0xebb80055,0x00000000,0x00000000}},	//   ێہنہ_, biḥ_, --, --, 
   {{0x248c0f5e,0x69d4066d,0x321c06d9,0x2c040490}},	//   rlem_, _keze, _bavy_, ह्यू_, 
   {{0x69d40f5f,0x24500f60,0x321c0076,0x248c0f61}},	//   _jeze, _dáma_, _cavy_, slem_, 
   {{0x69d40f62,0x248c0f63,0xa0680f64,0x00000000}},	//   _meze, plem_, еана_, --, 
   {{0x69d40f65,0x6d5803f9,0x2fd80192,0x24500cde}},	//   _leze, _ƙwan, gasg_, _fáma_, 
   {{0x442c0f66,0x321c06d9,0x64b000b0,0xa06800d1}},	//   _ing_, _favy_, _pāiw, _җапа_, 
   {{0x69d40f67,0x442c003e,0x321c010e,0x00000000}},	//   _neze, _hng_, _gavy_, --, 
   {{0x442c0f68,0xdc980408,0x00000000,0x00000000}},	//   _kng_, еташ_, --, --, 
   {{0x442c0098,0x69d40156,0x61f00311,0x62200131}},	//   _jng_, _aeze, şelă, _ئۈگە, 
   {{0x0fc0052f,0xdd940ed0,0x442c0f69,0x3dd8020c}},	// [ae0] _уйын, таңы, _mng_, parw_, 
   {{0x442c0f6a,0xdbd00f6b,0x69d40205,0x4a400798}},	//   _lng_, rüñi, _ceze, бнув, 
   {{0x442c0f6c,0x9d440f6d,0x20d00986,0x2d8401ed}},	//   _ong_, _сенд, nši_, ület_, 
   {{0xebb80a28,0x442c0083,0x69d40857,0x37c401e0}},	//   tiḥ_, _nng_, _eeze, рҙаб, 
   {{0x69d40f6e,0xf484030f,0x649c02dd,0x2d840135}},	//   _feze, یابی, _ﺟﺎﭘﭙ, żlet_, 
   {{0x442c0f6f,0x69d40f70,0x20d00960,0x00000000}},	//   _ang_, _geze, kši_, --, 
   {{0x442c0f71,0x20d00f72,0xdcfc005f,0x550401c0}},	//   _bng_, jši_, _izpē, учла, 
   {{0x20d000bc,0x00000000,0x00000000,0x00000000}},	//   dši_, --, --, --, 
   {{0x69d40f73,0x32540f74,0x442c0f75,0xd24405f5}},	//   _yeze, ивир, _dng_, гэни, 
   {{0x442c0f76,0x8b54011a,0x69d40f77,0x245001ef}},	//   _eng_, טיפס_, _xeze, _váma_, 
   {{0x321c0851,0x442c00a3,0xf1940212,0x00000000}},	//   _vavy_, _fng_, ринь, --, 
   {{0xa0340f78,0x442c0f79,0x312401c0,0x67200023}},	//   لىپت, _gng_, гдүг, _ተልእኾ, 
   {{0x321c0f7a,0x3b000477,0x752800d0,0x8c38002f}},	//   _tavy_, jtiq_, _hrdz, _mißt, 
   {{0x20d009a8,0x442c01a6,0x82f4011a,0x00000000}},	//   bši_, _zng_, _עצוב_, --, 
   {{0x442c0f7b,0xefc40f7c,0xad2400d1,0x00000000}},	//   _yng_, _ጸጋይ_, جىزى, --, 
   {{0x69d40f7d,0xda0005f9,0x6b740f7e,0x00000000}},	//   _seze, र्सत_, албу, --, 
   {{0x69d40f7f,0xdbdc0d12,0x81d40154,0x3e900240}},	// [af0] _peze, _víðf, িলর_, _ሓብሬታ_, 
   {{0x6f0c0bf1,0x69d403e3,0x00000000,0x00000000}},	//   _ipac, _qeze, --, --, 
   {{0x69d40f80,0x7e600036,0xac940f81,0x00000000}},	//   _veze, ëmpe, _ванш, --, 
   {{0x69d40f82,0x6f0c02e3,0x64b000b0,0x26dc01ee}},	//   _weze, _kpac, _māit, tswo_, 
   {{0x69d40f83,0x64b00607,0x75280064,0x99880064}},	//   _teze, _lāit, _ardz, _bobų_, 
   {{0xc8d40f84,0x26dc0112,0x20d00bf1,0x442c0f85}},	//   _مزرع, rswo_, yši_, _sng_, 
   {{0xe3b006d5,0x442c0f86,0x05740f87,0x6f0c0055}},	//   يرة_, _png_, داشد, _lpac, 
   {{0x20d00bb8,0x29000f88,0xc8b40032,0xa4440f89}},	//   vši_, mtha_, _асҡы, рнид, 
   {{0x442c0f8a,0x20d00784,0x383401c6,0x290005e0}},	//   _vng_, wši_, _унтр, ltha_, 
   {{0x20d00f8b,0x67280f8c,0x6d5802a8,0x29000f8d}},	//   tši_, _irej, _ƙwal, otha_, 
   {{0x29000f8e,0x6f0c0f8f,0xa2d40f90,0x67280f91}},	//   ntha_, _apac, _मौर्, _hrej, 
   {{0x20d00f92,0x67280f93,0xa0680f94,0x6f0c00ae}},	//   rši_, _krej, тама_, _bpac, 
   {{0x6f0c0334,0x29000f95,0x6d4001f4,0x00000000}},	//   _cpac, htha_, älan, --, 
   {{0x21a40f96,0x67280f97,0x29000f98,0x245002f0}},	//   _килм, _mrej, ktha_, _kámo_, 
   {{0xdb100f99,0x20d003f0,0xe0d4011b,0x2900025c}},	//   _ágús, qši_, _тюль, jtha_, 
   {{0x67280f9a,0x3b000f9b,0x29000f9c,0x245001ef}},	//   _orej, ttiq_, dtha_, _mámo_, 
   {{0x5ba80f9d,0x2d840f9e,0x29000f9f,0x24500248}},	// [b00] ткам_, üler_, etha_, _lámo_, 
   {{0x29000072,0x672c01e4,0x3b0001d5,0x00000000}},	//   ftha_, ĥajl, rtiq_, --, 
   {{0x29000597,0x67280fa0,0xd7f80fa1,0x4f8401d9}},	//   gtha_, _arej, вул_, _مایہ, 
   {{0x6f0c00e4,0xe8e80fa2,0x75280332,0xc7c0005b}},	//   _ypac, ارلو_, _rrdz, осши, 
   {{0x29000fa3,0x68e001bf,0x3b00014f,0x1dd8012d}},	//   atha_, _ældn, qtiq_, _बजात, 
   {{0x6728067d,0x29000fa4,0xdcfc00ef,0x00000000}},	//   _drej, btha_, _uzpē, --, 
   {{0x290000c6,0x672801ed,0x98a402bf,0x0f280092}},	//   ctha_, _erej, _виве, _ሲያስረ, 
   {{0x67280fa5,0x44a00137,0x64b000b0,0x249c0042}},	//   _frej, يموق, _rāit, _chwm_, 
   {{0x67280fa6,0x00000000,0x00000000,0x00000000}},	//   _grej, --, --, --, 
   {{0x64b002b5,0x32540fa7,0x6f0c0fa8,0xdcfc0210}},	//   _pāit, свор, _rpac, _wypę, 
   {{0x6f0c0fa9,0x543401d9,0x672801f1,0xf3e80154}},	//   _spac, _پرار, _zrej, ক্ষর_, 
   {{0x50640faa,0x7c3c001f,0xe1f40124,0x7ea0002f}},	//   ртоа, _አገሪቱ, аҳә_, nöpf, 
   {{0x53a40fab,0x4c14035c,0x61f80fac,0xd250007b}},	//   _тадб, یبرس, åblå, _ونص_, 
   {{0x8d740a2c,0x7ea00fad,0x64b00374,0x7f940212}},	//   لازا, höpf, _tāit, іарх, 
   {{0x8c640fae,0xa3bc060c,0x7ea00e78,0x7d240faf}},	//   атад, _आलम_, köpf, офте, 
   {{0x4fc40120,0x6e940214,0xceb800d8,0x00000000}},	//   _тска, _گلخا, _иљо_, --, 
   {{0x6f0c0fb0,0x22980066,0x9f9400a2,0x2900031c}},	// [b10] _upac, lèka_, _küýi_, wtha_, 
   {{0x290000cd,0x67280240,0x00000000,0x00000000}},	//   ttha_, _rrej, --, --, 
   {{0x290000fb,0x672800f3,0xf9900344,0x3d24005b}},	//   utha_, _srej, وبم_, _дьяв, 
   {{0x67280fb1,0x29000fb2,0x5cc001c6,0xcc840345}},	//   _prej, rtha_, _хөрв, _ئۆره_, 
   {{0x29000fb3,0xdee402d3,0xdc340a1e,0x00000000}},	//   stha_, _ዝባን_, _הארט_, --, 
   {{0x290000c6,0x4f28001f,0xb5c80fb4,0x6728036e}},	//   ptha_, _ሲያደር, لوهم_, _vrej, 
   {{0x48a80fb5,0xe89401c0,0x67280327,0x2900025c}},	//   _атам_, _гавь, _wrej, qtha_, 
   {{0x67280fb6,0x00000000,0x00000000,0x00000000}},	//   _trej, --, --, --, 
   {{0x67280fb7,0xe4d80133,0x00000000,0x00000000}},	//   _urej, _ڕوات_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x25d800c7,0x75800116,0x516400cf,0x00000000}},	//   _амҷы_, _оңша, йүшү_, --, 
   {{0x237c0211,0x823c0092,0x00000000,0x00000000}},	//   _txwj_, _ይገመታ, --, --, 
   {{0x443c0fb8,0x2450032e,0x00000000,0x00000000}},	//   mju_, _jámm_, --, --, 
   {{0xb6cc0fb9,0xd00c00f1,0x41d8012d,0x00000000}},	//   _şükü, ولۍ_, _मजिस, --, 
   {{0x443c0006,0xdd900fba,0x20e40014,0x00000000}},	//   oju_, سور_, _آبٲ, --, 
   {{0x1fb40fbb,0x00000000,0x00000000,0x00000000}},	//   _ускр, --, --, --, 
   {{0x8c400fbc,0xbbb80574,0x3a44016c,0x99e400f7}},	// [b20] чете, _अलीक, омаҳ, йжад, 
   {{0x443c0fbd,0xda640150,0x4a400fbe,0x91000345}},	//   hju_, حاري, пнув, _بژیو, 
   {{0x443c0fbf,0xdc680fc0,0x7ea0002f,0x00000000}},	//   kju_, _банд_, töpf, --, 
   {{0x443c0fc1,0x00000000,0x00000000,0x00000000}},	//   jju_, --, --, --, 
   {{0x443c0fc2,0x7c240fc3,0xc5cc015b,0xdb0408a5}},	//   dju_, mdir, _রাজপ, _afkö, 
   {{0x7c240fc4,0x443c0fc5,0x38c80fc6,0x07f40124}},	//   ldir, eju_, _ناری_, ахәы_, 
   {{0x89d80375,0x7c240009,0x443c0fc7,0x00000000}},	//   _תחלי, odir, fju_, --, 
   {{0xa3a80fc8,0x443c0fc9,0x78c401f2,0xc51000d1}},	//   _गृह_, gju_, _ịkwọ_, سبىت, 
   {{0x64b000b0,0x93880fca,0x55e40fcb,0xd4080150}},	//   _pāir, ыска_, _гозб, _ەتتم_, 
   {{0x443c0fcc,0x0504015b,0x00000000,0x00000000}},	//   aju_, লয়ের_, --, --, 
   {{0x7c240fcd,0x443c0fce,0xdcfc0118,0x00000000}},	//   kdir, bju_, _vypě, --, 
   {{0x443c0fcf,0x64b000b0,0x50640108,0x6d400108}},	//   cju_, _wāir, ётна, älam, 
   {{0x7c240fd0,0x09e009bd,0x3f80002e,0x64b002b5}},	//   ddir, ন্টা, _cxiu_, _tāir, 
   {{0x7c240fd1,0xdb1001e1,0x00000000,0x00000000}},	//   edir, _ògùr, --, --, 
   {{0x62640fd2,0x7c2406be,0x00000000,0x00000000}},	//   _بانق, fdir, --, --, 
   {{0x7c240fd3,0x00000000,0x00000000,0x00000000}},	//   gdir, --, --, --, 
   {{0x64b000b0,0xada40116,0x49c80107,0x92e400cc}},	// [b30] _māip, саңл, гуем_, _পহু_, 
   {{0x443c038f,0x7b740597,0x6d400158,0x7c240fd4}},	//   zju_, أطفا, ølas, adir, 
   {{0x7c240fd5,0x443c0fd6,0xba740150,0x00000000}},	//   bdir, yju_, ساكت, --, 
   {{0xd90c004b,0x7c240115,0xf9a40014,0x00000000}},	//   کیې_, cdir, سٕنُ, --, 
   {{0xe7380fd7,0x443c0fd8,0xba0800d1,0x7b64010a}},	//   рел_, vju_, شتەك_, _етре, 
   {{0x1b04015b,0x00000000,0x00000000,0x00000000}},	//   রিখে_, --, --, --, 
   {{0x443c0fd9,0x2eb40d79,0x87e40395,0x00000000}},	//   tju_, ंदुत, _гюзе, --, 
   {{0xc6d402f5,0x443c0fda,0x9f5400e8,0x159401ec}},	//   _সমীচ, uju_, ëgëm_, _ﺀﻭﺗﯩ, 
   {{0x443c0fdb,0x38340fdc,0xa5f8026a,0xa9680724}},	//   rju_, _энтр, _везу_, _сиңа_, 
   {{0x443c0fdd,0x7c240fde,0x95e400db,0x00000000}},	//   sju_, zdir, _ويقۇ, --, 
   {{0x443c0fdf,0xa0a40fe0,0x7c240fe1,0x257401d5}},	//   pju_, жанд, ydir, _بهاس, 
   {{0x1fa80fe2,0x60cc05be,0xbbb80fe3,0x00000000}},	//   икни_, _čamd, _अलेक, --, 
   {{0x64580fe4,0x7c240fe5,0xaab40fe6,0x00000000}},	//   _ilwi, vdir, _अंगक, --, 
   {{0x645801af,0x02a4084c,0x7ea00fe7,0x2174014b}},	//   _hlwi, _урем, köpe, _муйр, 
   {{0xa3bc05ba,0x7c240fe8,0xed340276,0x00000000}},	//   _आला_, tdir, пэтэ, --, 
   {{0x7c240fe9,0xdbc801c6,0x00000000,0x00000000}},	//   udir, ргад_, --, --, 
   {{0x7c240fea,0x53800023,0x6d400feb,0x00000000}},	// [b40] rdir, _ከዳዓት_, ølar, --, 
   {{0x19940063,0xe27000d1,0x1f940092,0x00000000}},	//   ојер, ﺴﺎﻻﻡ_, መዘገበ_, --, 
   {{0x7c240209,0x64580fec,0x00000000,0x00000000}},	//   pdir, _olwi, --, --, 
   {{0x7c240fed,0xb5fc0135,0xdc780092,0x00000000}},	//   qdir, _imġi, _የብሉይ_, --, 
   {{0xc6f40a4a,0x16a80fee,0x00000000,0x00000000}},	//   жніх_, авди_, --, --, 
   {{0x64580fef,0x7ae40ff0,0xd4c40ff1,0x00000000}},	//   _alwi, msit, осип, --, 
   {{0x7ae40ff2,0xdd2400c0,0x00000000,0x00000000}},	//   lsit, _lūžt, --, --, 
   {{0xd8300014,0x7ae40ff3,0xb17c008f,0xe6c400db}},	//   _تٍر_, osit, naĥe, زتۇي, 
   {{0x7ae40ff4,0x78bc047e,0x55e40ff5,0x60c8016b}},	//   nsit, _hurv, _моаб, ɔmmɔ, 
   {{0x78bc0ff6,0x245000c6,0x3cf80ff7,0x645803cb}},	//   _kurv, _lámh_, kurv_, _elwi, 
   {{0x7bc40ff8,0x78bc0108,0x49b80677,0xe634009d}},	//   kciu, _jurv, ימיס, _эхтэ, 
   {{0x7ae40ff9,0x7bc40007,0x00000000,0x00000000}},	//   ksit, jciu, --, --, 
   {{0xb17c01e4,0x78bc007c,0x00000000,0x00000000}},	//   daĥe, _lurv, --, --, 
   {{0x7648033b,0x248801f1,0x30e40116,0xb5d80183}},	//   _jody, čame_, _есиң, _সাঁচ, 
   {{0x7ae40ffa,0x78bc0ffb,0x76480ffc,0x00000000}},	//   esit, _nurv, _mody, --, 
   {{0x2584006a,0x76480ffd,0xeb5c001f,0x66d00cad}},	//   lêlë_, _lody, _ለመግለ, _jókò, 
   {{0x7ae40ffe,0x06cc015b,0x94f8025c,0x78bc00b8}},	// [b50] gsit, _রিভি, _དཀའི_, _aurv, 
   {{0x7bc40fff,0x76481000,0x78bc00e2,0x6e181001}},	//   aciu, _nody, _burv, _ايدس_, 
   {{0xfe701002,0x7ae41003,0xa81400f7,0x9ac00327}},	//   _جدي_, asit, здеш, ċċab, 
   {{0xf7701004,0x78bc1005,0x7ae41006,0x7bc408e5}},	//   ھان_, _durv, bsit, cciu, 
   {{0x2ca81007,0x7ae41008,0x78bc0489,0x76481009}},	//   mmad_, csit, _eurv, _body, 
   {{0x2ca8100a,0x764800cd,0xc984100b,0x6e24100c}},	//   lmad_, _cody, _дуби, _jahb, 
   {{0x69c4100d,0x7648002d,0x67d4100e,0x6e24100f}},	//   mche, _dody, _нову, _mahb, 
   {{0x69c41010,0x7d7c00c8,0x32c0007f,0x2ca8037e}},	//   lche, ינוו, _bòy_, nmad_, 
   {{0x76481011,0x2ca800c5,0x68e4058a,0xe35400ee}},	//   _fody, imad_, lshd, яткэ, 
   {{0x2ca81012,0x09ac00bd,0x35f406d3,0x6abc1013}},	//   hmad_, _চ্যা, _опур, _musf, 
   {{0x69c41014,0x766401d9,0x2ca80067,0xddcc0153}},	//   iche, _تُلم, kmad_, sibū, 
   {{0x7ae41015,0x645800aa,0x69c41016,0x271c007f}},	//   ysit, _ulwi, hche, _kňn_, 
   {{0x6e241017,0x76480161,0x24501018,0x271c007f}},	//   _bahb, _yody, _námi_, _jňn_, 
   {{0x69c41019,0x6e24101a,0x248c0373,0x27fc0007}},	//   jche, _cahb, loem_, hgwn_, 
   {{0x61e0101b,0xdca403a6,0x6abc101c,0x69c4101d}},	//   mall, зави, _ausf, dche, 
   {{0x248c0151,0x24500241,0x27fc0369,0x2ca8058a}},	//   noem_, _bámi_, jgwn_, gmad_, 
   {{0x78bc101e,0x7ae4101f,0x7bc41020,0x69c41021}},	// [b60] _surv, usit, rciu, fche, 
   {{0x7bc41022,0x78bc1023,0x69c41024,0x6abc0175}},	//   sciu, _purv, gche, _dusf, 
   {{0x764802d5,0xda001025,0x7bc41026,0x61e00194}},	//   _rody, र्गत_, pciu, iall, 
   {{0x7ae41027,0x248c1028,0x271c0100,0x76480006}},	//   psit, joem_, _bňn_, _sody, 
   {{0x61e01029,0x69c4102a,0x248c102b,0x7ae4102c}},	//   kall, bche, doem_, qsit, 
   {{0x69c4102d,0x78bc102e,0x1dbc102f,0xdbcc0139}},	//   cche, _turv, ्डित, _bıço, 
   {{0x20c001dc,0x80d800bd,0x76480099,0x00000000}},	//   _nói_, _মৎস্, _vody, --, 
   {{0x76481030,0x6d4002f6,0x6ab4009a,0x32c0007f}},	//   _wody, älai, _zizf, _pòy_, 
   {{0x19581031,0x26d80158,0xd65c030d,0x00000000}},	//   _таңы_, _æsop_, _кiад, --, 
   {{0x20c001fb,0x51841032,0xc0c00023,0x00000000}},	//   _bói_, зума, _ጸማም_, --, 
   {{0x6e24006c,0x60cc08ad,0xefe40020,0x03d80183}},	//   _rahb, _čamc, ዛመዱ_, _ধাৰণ, 
   {{0x61e01033,0x20c00120,0x578802d3,0x69c40b70}},	//   aall, _dói_, _ንሓንቲ_, zche, 
   {{0x61e01034,0x69c41035,0x6e24014f,0x6f1c01a4}},	//   ball, yche, _pahb, uwsc, 
   {{0x61e01036,0x6abc0b34,0x6e24014f,0xbb60001f}},	//   call, _rusf, _qahb, _ለመቋቋ, 
   {{0xac940251,0x8d741037,0x69c41038,0x20c00016}},	//   давш, ساسا, vche, _gói_, 
   {{0x6e2405b1,0x6abc1039,0x3a380356,0x2ca8103a}},	//   _wahb, _pusf, _anrp_, umad_, 
   {{0x69c4103b,0x6e24016d,0x1c1c0dba,0xcee8103c}},	// [b70] tche, _tahb, _पसरल_, _اربن_, 
   {{0x69c4103d,0x2450012c,0x248c017a,0x2ca800ad}},	//   uche, _vámi_, zoem_, smad_, 
   {{0x69c4103e,0x2918103f,0xc0200c58,0xfaa800c6}},	//   rche, تقاد_, ধাৰণ_, أهلي_, 
   {{0x69c41040,0xd1241041,0x68e40009,0x6abc1042}},	//   sche, _یم_, rshd, _tusf, 
   {{0x69c41043,0x68e405b1,0x7ea01044,0x27fc0042}},	//   pche, sshd, löpa, rgwn_, 
   {{0x61e01045,0x660c0e3c,0x2ee80af9,0x63b80142}},	//   xall, đako, _mvaf_, _sgwn, 
   {{0x7ea00793,0x68e4022e,0xf6081046,0x00000000}},	//   nöpa, qshd, ستوه_, --, 
   {{0x20c01047,0x482000db,0x624c032e,0xd3440133}},	//   _rói_, _سۉتق, _núor, ژینه_, 
   {{0x27ec1048,0x20c001fb,0x320c0142,0x00000000}},	//   _iden_, _sói_, ffdy_, --, 
   {{0x7ea00621,0x60e81049,0x248c003e,0x45a008b0}},	//   köpa, омом_, soem_, _كەشك, 
   {{0x26cc0640,0x624c0419,0x00000000,0x00000000}},	//   _hteo_, _súos, --, --, 
   {{0xd36c104a,0x94240131,0x20c00208,0xdee40454}},	//   اهی_, _يولۇ, _vói_, моми, 
   {{0xfe78104b,0xd12c104c,0x9f40036e,0x00000000}},	//   зүп_, همی_, makë_, --, 
   {{0x61e0104d,0x13e0015b,0x02a4104e,0x9f40036e}},	//   qall, _যায়, _эрем, lakë_, 
   {{0x61ec03f9,0x00000000,0x00000000,0x00000000}},	//   _ɓall, --, --, --, 
   {{0x27ec104f,0x26cc1050,0x9f400200,0x00000000}},	//   _nden_, _oteo_, nakë_, --, 
   {{0x20100223,0xe8b80327,0x5dd40137,0x4f20004e}},	// [b80] _ibyi_, _བཤུག, _оюну, _адыб, 
   {{0x27ec1051,0x6d5802a8,0xcf900375,0x00000000}},	//   _aden_, _ƙwat, _בטח_, --, 
   {{0xa3bc0574,0xf3e8015b,0x9f400200,0x00000000}},	//   _आलं_, ক্টর_, kakë_, --, 
   {{0x27ec1052,0x8d741053,0xb17c0115,0x9f400200}},	//   _cden_, _زاپا, naĥa, jakë_, 
   {{0xda641054,0x01e00729,0xaa080014,0x245001ef}},	//   _قاسي, _মানদ, _کزُل_, _jámu_, 
   {{0x27ec1055,0x850004d3,0x2450013a,0x00000000}},	//   _eden_, چوون, _mámu_, --, 
   {{0x201002c4,0x34940124,0x85001056,0x2298020c}},	//   _obyi_, накр, نوون, mèkh_, 
   {{0xb9e80020,0x3e580100,0x2298020c,0x00000000}},	//   _ክስ_, _lٍt_, lèkh_, --, 
   {{0x60cc0552,0x05cc01bc,0x245008a5,0x8cac05c0}},	//   _čama, _स्वब, _námu_, ंगतो, 
   {{0x2488098d,0x657800c6,0x60cc00b0,0xdbd41057}},	//   čama_, ábhá, _ōama, _hääd, 
   {{0x09f4025f,0x7bc8013f,0x9f400066,0x65b81058}},	//   ומים_, _ɑdur, lakè_, _хуур_, 
   {{0xdbd41059,0x9f40036e,0x3f8c0b97,0x00000000}},	//   _jääd, cakë_, ğdun_, --, 
   {{0x9f40020c,0x00000000,0x00000000,0x00000000}},	//   nakè_, --, --, --, 
   {{0x7ea0005b,0x24500306,0x00000000,0x00000000}},	//   töpa, _dámu_, --, --, 
   {{0x2d840724,0xf27001d9,0x313400cf,0x01f8011a}},	//   çle_, _لێکھ, _чейр, _ופול, 
   {{0x4ba40228,0x9f4000f2,0xd9380092,0x06cc00eb}},	//   дөгү_, kakè_, _የሚያዋ, _রিসি, 
   {{0x27ec0295,0x78c40521,0x9f400100,0x7ea001f4}},	// [b90] _rden_, _ịkpọ_, jakè_, söpa, 
   {{0x614400db,0x7ea001e3,0x9f400200,0x00000000}},	//   _زىۋە, löpn, zakë_, --, 
   {{0x26cc0270,0x0fe0033f,0xc86401c6,0xf3e403d4}},	//   _steo_, परपढ, мтди, _গানৰ_, 
   {{0xc1980375,0xad100022,0x6d400108,0x6d540432}},	//   חשבי, _иҿҳә, älau, myza, 
   {{0x7ac4105a,0x6d5401ed,0x4ab0035b,0x6d400158}},	//   _ассе, lyza, _аҩар, ålaf, 
   {{0xe5a4105b,0x00000000,0x00000000,0x00000000}},	//   нили, --, --, --, 
   {{0xdb100086,0xe8b8025c,0x1cd8031c,0x7aa408ca}},	//   _ògòr, _བཤིག, ོེར_, _риёз, 
   {{0x27ec105c,0x39a40014,0xd58403e6,0x383401af}},	//   _uden_, _شینہ, رێنه_, _инср, 
   {{0x2cb801ab,0x9f400240,0x22980214,0x7790105d}},	//   _misd_, rakë_, lèki_, _پیوا, 
   {{0x64b0005f,0x245002fb,0xdbd400a2,0x9f400200}},	//   _jāiz, _rámu_, _täçd, sakë_, 
   {{0x9f40105e,0x398c0023,0x6d5400a2,0x00000000}},	//   maké_, _ንታሕቲ_, jyza, --, 
   {{0x2cb800a3,0x9f40034c,0x00000000,0x00000000}},	//   _nisd_, laké_, --, --, 
   {{0x91dc0c58,0x24500174,0x2d84002d,0xc334009f}},	//   _মাৰ্, _dámt_, ûlen_, _آڻبا_, 
   {{0x2cb800a3,0x2298020c,0x9f40034c,0xd65c0354}},	//   _aisd_, kèki_, naké_, _кiед, 
   {{0xdd90105f,0x9f400066,0x6d5402d0,0x00000000}},	//   اوز_, iaké_, gyza, --, 
   {{0x9f400502,0x6d580c09,0x00000000,0x00000000}},	//   haké_, _ƙwar, --, --, 
   {{0x9f401060,0x85400153,0x00000000,0x00000000}},	// [ba0] kaké_, _šėls, --, --, 
   {{0x9f400232,0xdbd402f6,0xcfb40375,0x2cb801c3}},	//   jaké_, _sääd, _אלפי_, _eisd_, 
   {{0x7ea00793,0xdbd40f23,0x9f400214,0x69a400dc}},	//   löpo, _pääd, daké_, _करणी, 
   {{0x2298020c,0x57a4009d,0xd7f000ae,0x00000000}},	//   sèkh_, ншла, اكش_, --, 
   {{0x9f400214,0xf4e40150,0x00000000,0x00000000}},	//   faké_, _ﺍﻹﺸﻜ, --, --, 
   {{0x9f4000f2,0x6d401061,0x86c0009a,0x00000000}},	//   gaké_, ålag, ديون, --, 
   {{0x2298020c,0x245001a8,0x00000000,0x00000000}},	//   cèki_, _náms_, --, --, 
   {{0x69a41062,0x9f40020c,0x7ea00108,0x5fb001f9}},	//   _करती, pakè_, köpo, ीखाल, 
   {{0x087400c8,0xb5fc0135,0x9f4004fb,0x8410010b}},	//   _נעמט_, _alġe, baké_, умых, 
   {{0x9f400066,0x00000000,0x00000000,0x00000000}},	//   caké_, --, --, --, 
   {{0xe5041063,0x00000000,0x00000000,0x00000000}},	//   _لبني, --, --, --, 
   {{0x25a00e78,0xe534010f,0x00000000,0x00000000}},	//   ühle_, _שטײט_, --, --, 
   {{0x2cb800ca,0xbfa81064,0x2d980131,0x814001d5}},	//   _risd_, етре_, ﺘﯩﻨﻰ_, ننین, 
   {{0x6d540034,0xfe241065,0xc324007b,0x0e440166}},	//   tyza, льсн, _أكون_, хэмм, 
   {{0xf1a800f1,0x3cdc09ab,0x00000000,0x00000000}},	//   _ډاډه_, गीले_, --, --, 
   {{0x6d54068f,0xbc381066,0x9f40020c,0x301400c7}},	//   ryza, ىسقا_, zaké_, _рдир, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [bb0] --, --, --, --, 
   {{0x6d40005b,0x06cc0154,0xb17c00df,0x00000000}},	//   älas, _রিলি, naĥo, --, 
   {{0x9f4000e4,0x6d4001e3,0x5e58009f,0x00000000}},	//   vaké_, ålad, _آلپس_, --, 
   {{0x6b741067,0xe7b400be,0x00000000,0x00000000}},	//   _алму, نماد, --, --, 
   {{0x9f40034c,0x7ea001e3,0x00000000,0x00000000}},	//   také_, köpl, --, --, 
   {{0xf6d40214,0x00000000,0x00000000,0x00000000}},	//   ازند, --, --, --, 
   {{0x9f40034c,0x60cc00f3,0x1fac07f7,0x00000000}},	//   raké_, _čamo, _टण्ड, --, 
   {{0x24881068,0x9f40034c,0x23341069,0x00000000}},	//   čamo_, saké_, вхор, --, 
   {{0x9f40106a,0x130400c9,0xb884010b,0x97300014}},	//   paké_, вный_, _сурй, _پکنا, 
   {{0x68e0037e,0xf770106b,0xfa700023,0x57a401af}},	//   _ælds, _طاق_, _በየናይ_, _рысҡ, 
   {{0x2168106c,0x35d4009d,0xa3c00709,0x3f8c03e0}},	//   фини_, _сохё, ःखद_, ğdum_, 
   {{0x2054106d,0x3f8c106e,0x7ea001f4,0x00000000}},	//   ттор, şdum_, töpo, --, 
   {{0xb17c01e4,0x00000000,0x00000000,0x00000000}},	//   baĥo, --, --, --, 
   {{0x6448106f,0xc44400f2,0x00000000,0x00000000}},	//   ljei, _آیکن_, --, --, 
   {{0x62800158,0x26080b4c,0x2618000d,0x00000000}},	//   mnlo, _सानी_, _मउनी_, --, 
   {{0x64481070,0x00000000,0x00000000,0x00000000}},	//   njei, --, --, --, 
   {{0x62801071,0x6448021c,0x00000000,0x00000000}},	// [bc0] onlo, ijei, --, --, 
   {{0x62801072,0x64481073,0x1b040183,0x4ef808a8}},	//   nnlo, hjei, ৰিলে_, _קליג, 
   {{0xa3d00490,0x62800af9,0x00000000,0x00000000}},	//   वडा_, inlo, --, --, 
   {{0x38600491,0x6280002f,0xdca40a5b,0x00000000}},	//   óir_, hnlo, _јами, --, 
   {{0x8cac01ad,0x8d901074,0x62800327,0x00000000}},	//   ंगरो, _ملیش, knlo, --, 
   {{0x628001a4,0xace800f2,0x00000000,0x00000000}},	//   jnlo, _تریل_, --, --, 
   {{0x9f4002b5,0x97c41075,0xf3f801ec,0x48e0022e}},	//   kakï_, _айбе, еңе_, _восв, 
   {{0xb8b40046,0x98a41076,0x62800051,0xf49800d1}},	//   _сөзі, _рибе, enlo, رھات_, 
   {{0x68e0019b,0x799c00a9,0x846002e8,0xd36c00d1}},	//   _ældr, _hyrw, ръще, غۇت_, 
   {{0x799c03a2,0xd4f4010b,0x6280032e,0x00000000}},	//   _kyrw, _аяды, gnlo, --, 
   {{0x66801077,0xd16402e8,0x8678011a,0x00000000}},	//   _دیول, тъпи, _קרבו, --, 
   {{0x628001f4,0x75280064,0xaed408ca,0x4e780023}},	//   anlo, _isdz, ломш, _ኣብራሃ_, 
   {{0x260806ab,0x2eec0694,0x92681078,0x00000000}},	//   _सामी_, éef_, _орка_, --, 
   {{0x5c1004c5,0xc1701079,0xc7b00375,0x03a00107}},	//   হযোগ_, ادیت, יבר_, _тичо, 
   {{0xac18107a,0x5064107b,0x8cac107c,0x998800de}},	//   нову_, _атпа, ंगलो, _dabū_, 
   {{0x660c107d,0x62780419,0x00000000,0x00000000}},	//   đaki, pňoc, --, --, 
   {{0x6a14107e,0x69a40037,0x98b80064,0x00000000}},	// [bd0] лмау, _करही, lypė_, --, 
   {{0x245000d7,0x79d400d4,0x00000000,0x00000000}},	//   _lámp_, ижує, --, --, 
   {{0x9f4c00dd,0xe7f401c6,0x00000000,0x00000000}},	//   önöm_, гчлэ, --, --, 
   {{0x1ee8107f,0x00000000,0x00000000,0x00000000}},	//   _تویی_, --, --, --, 
   {{0x3c4405f5,0x628003a2,0x69a40825,0xe618011c}},	//   _тээв, ynlo, _करवी, едл_, 
   {{0x66041080,0xdb1c0174,0x00000000,0x00000000}},	//   упка, _ívág, --, --, 
   {{0x26080574,0x799c03cb,0x6b9c03cb,0x62801081}},	//   _साठी_, _gyrw, _hysg, vnlo, 
   {{0x62800475,0x00000000,0x00000000,0x00000000}},	//   wnlo, --, --, --, 
   {{0x29001082,0x86c0004b,0x64480e03,0x3f8c0205}},	//   luha_, _څيړن, rjei, ğduk_, 
   {{0x67281083,0x20d41084,0xe0d800c7,0x00000000}},	//   _isej, лімс, нво_, --, 
   {{0x29001085,0x6f0c0309,0x628003cd,0x507800b8}},	//   nuha_, _aqac, rnlo, _ṇāṃ_, 
   {{0x34941086,0x26080c22,0x942400f7,0xc0f40092}},	//   _кахр, _साडी_, _مومۇ, ላለሻ_, 
   {{0x29001087,0x6b9c1088,0x67280135,0x00000000}},	//   huha_, _nysg, _jsej, --, 
   {{0x29001089,0xfd64108a,0x4e7802d3,0x21a40e46}},	//   kuha_, ангү, _ኣብርሃ_, _йилм, 
   {{0x9f400085,0x6b9c02d0,0x999802b1,0xe0d00214}},	//   makí_, _aysg, tepō_, _ازت_, 
   {{0x2900108b,0x9f400093,0x6b9c03cb,0x672803ac}},	//   duha_, lakí_, _bysg, _osej, 
   {{0xcb64108c,0xabc40184,0x6b9c0368,0x6728025c}},	// [be0] гате_, рауҙ, _cysg, _nsej, 
   {{0x6b9c0cfd,0x9f400418,0xdd380311,0x2900108d}},	//   _dysg, nakí_, _căţe, fuha_, 
   {{0x6728108e,0x2900015c,0x2298108f,0x18a40e92}},	//   _asej, guha_, lèks_, гажм, 
   {{0x9f400093,0xdc6805f5,0xd7cc033f,0x00000000}},	//   hakí_, _чамд_, हुंच, --, 
   {{0x6b9c1090,0x2298007f,0x799c012d,0x050000fe}},	//   _gysg, nèks_, _wyrw, লবোৰ_, 
   {{0x29001091,0x799c06a3,0x9f4006c6,0xd06c0055}},	//   buha_, _tyrw, jakí_, _ṃśaḥ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x26081092,0x04601093,0xc89400db,0xf31800d8}},	//   _साथी_, йтым, _бууө, воиш_, 
   {{0x07a009a5,0x9f400022,0x00000000,0x00000000}},	//   _гатн, hakâ_, --, --, 
   {{0x471800c8,0x22980669,0x00000000,0x00000000}},	//   _אומג, dèks_, --, --, 
   {{0x26081094,0x1fa00150,0x8a94010f,0x94041095}},	//   _साती_, _ﺍﺭﺍﻻ_, רכיװ_, _مواه, 
   {{0xb0e80137,0x70940395,0x00000000,0x00000000}},	//   ндүз_, рамф, --, --, 
   {{0x29001096,0x087400c8,0x04901097,0xa3d01098}},	//   zuha_, רעכט_, _النح, वडर_, 
   {{0x65ac0943,0x29001099,0x7e28109a,0x6b9c109b}},	//   ṱhed, yuha_, ліса_, _rysg, 
   {{0x70a402d3,0x2900031c,0xecc4009d,0x00000000}},	//   ገብረሉ_, xuha_, ршгү, --, 
   {{0x6b9c0368,0xe944109c,0xc9840116,0x29000327}},	//   _pysg, یرای, қузи, vuha_, 
   {{0x2900109d,0xdd380356,0x00000000,0x00000000}},	// [bf0] wuha_, _păţe, --, --, 
   {{0x7ed40491,0x2900109e,0x26080073,0x6e9402da}},	//   _ازيا, tuha_, _साधी_, _خلخا, 
   {{0x66740502,0x6b9c0af9,0x6728109f,0x00000000}},	//   یدتر, _wysg, _ssej, --, 
   {{0x290010a0,0x386401ab,0xab9402bf,0x00000000}},	//   ruha_, _clmr_, _вимі, --, 
   {{0x290010a1,0x260805f9,0x66b410a2,0x6b9c0857}},	//   suha_, _सादी_, абду, _uysg, 
   {{0x09dc00bd,0x290010a3,0x957002d3,0x67280010}},	//   _ঢাকা, puha_, _እንቋዕ_, _vsej, 
   {{0x0ba802dd,0x01e00154,0x00000000,0x00000000}},	//   _زاڭى_, _মালদ, --, --, 
   {{0x67280184,0x9f400085,0x3ce805f9,0xf77002f2}},	//   _tsej, wakí_, _जबसे_, _کاف_, 
   {{0x672810a4,0xe3a8016c,0x9f400418,0x66d401f7}},	//   _usej, ъкид_, takí_, _ضيائ, 
   {{0x9f4000e4,0xbb880150,0x00000000,0x00000000}},	//   hakã_, _ﺭﺃﻴﻪ_, --, --, 
   {{0xe04410a5,0x21a401b9,0x9a740375,0xb46410a6}},	//   анни, ринм, שתתף_, ркөл, 
   {{0x1b2c0020,0xf48410a7,0x2298033b,0x33d40153}},	//   _ብርቱካ, _лучн, tèks_, _лішт, 
   {{0xa2e410a8,0x00000000,0x00000000,0x00000000}},	//   _толд, --, --, --, 
   {{0x442c0ad3,0x8fa0003b,0x00000000,0x00000000}},	//   _hag_, іаре, --, --, 
   {{0x442c10a9,0xa0a4010b,0x216800d1,0x94ec0213}},	//   _kag_, _какд, _шики_, _bəə_, 
   {{0x442c10aa,0x00000000,0x00000000,0x00000000}},	//   _jag_, --, --, --, 
  
   {{0x6b8400c6,0x59d40116,0x94ec03b9,0x1cd80327}},	// [c00] مشكل, لغار, _dəə_, ོེང_, 
   {{0x442c10ab,0x7ea0049f,0xd0e410ac,0x4a4010ad}},	//   _lag_, köpi, _حکیم_, онув, 
   {{0x442c00ca,0x7e7c05be,0xdca410ae,0x00000000}},	//   _oag_, mirp, _вани, --, 
   {{0x442c10af,0x7e7c05b1,0x4904007d,0x6a840022}},	//   _nag_, lirp, _हमरो_, алӡа, 
   {{0x7c2410b0,0xc5cc03d4,0x7e7c01e7,0x00000000}},	//   meir, _ৰাজপ, oirp, --, 
   {{0x7c2410b1,0x442c10b2,0x7e7c0309,0x236c10b3}},	//   leir, _aag_, nirp, dzej_, 
   {{0x442c0c30,0x9f4005da,0xa3c000dc,0x00000000}},	//   _bag_, hakà_, ःखं_, --, 
   {{0x7c2410b4,0x442c10b5,0x7e7c01ab,0xcdb4011a}},	//   neir, _cag_, hirp, ספקה_, 
   {{0x7e7c10b6,0xa30000fd,0xb27400d1,0x938802e8}},	//   kirp, зүче, йлиш, ъска_, 
   {{0x442c03d5,0x59a810b7,0xc0f4001f,0xb17c0115}},	//   _eag_, _करार, ላለሁ_, laĥi, 
   {{0x442c10b8,0x518410b9,0xd5480014,0x25a80198}},	//   _fag_, рупа, _جلاو_, ƙala_, 
   {{0x442c0226,0x7c2410ba,0x044000c2,0xb17c00df}},	//   _gag_, jeir, _мехн, naĥi, 
   {{0x7c2410bb,0x236c068f,0xa3b40864,0xe2f80014}},	//   deir, czej_, छेद_, _مونڈ_, 
   {{0x442c10bc,0xbe88034b,0x00000000,0x00000000}},	//   _zag_, ассе_, --, --, 
   {{0x7c240cfd,0x442c10bd,0xd08400c9,0xb7f80950}},	//   feir, _yag_, _выпи, ुलाम_, 
   {{0x7c2410be,0x442c0014,0xf8b00764,0x2b48004e}},	//   geir, _xag_, जगोप, txac_, 
   {{0x35700092,0x9f4000e4,0x4ea400d8,0x7c840022}},	// [c10] ቻልበት_, rakã_, _врна, цуре, 
   {{0x248810bf,0x9f40035b,0xba740472,0x7e7c00ef}},	//   čami_, sakã_, يالت, cirp, 
   {{0x7c2410c0,0x9f4002ea,0x2d58030d,0xc0d001f3}},	//   beir, maká_, _синь_, ካፈል_, 
   {{0x7c2410c1,0x9f4010c2,0x26080b03,0x00000000}},	//   ceir, laká_, _साही_, --, 
   {{0x442c10c3,0xfe7010c4,0x8d74001f,0xfb84010b}},	//   _rag_, _ردی_, ረጋቸው_, _дырн, 
   {{0x442c10c5,0x9f4002ea,0xc0f4001f,0x1b0403d4}},	//   _sag_, naká_, ላለህ_, ৰিখে_, 
   {{0xe29810c6,0x442c10c7,0x98780882,0x67d401af}},	//   ған_, _pag_, ṣām_, _гобу, 
   {{0xe3e804d3,0x442c01d4,0x4a7000ec,0xa4440b01}},	//   اکان_, _qag_, _اُڀر, снид, 
   {{0x442c10c8,0xe29810c9,0x9f4002ea,0xd8b400dd}},	//   _vag_, лаи_, kaká_, _اگلا_, 
   {{0x442c10ca,0x7c2410cb,0x9f400308,0x236c033f}},	//   _wag_, zeir, jaká_, rzej_, 
   {{0x442c10cc,0x236c006d,0x217410cd,0x7c2400e5}},	//   _tag_, szej_, супр, yeir, 
   {{0x7c2410ce,0x442c0441,0x21a410cf,0x672c0135}},	//   xeir, _uag_, _қийм, ħajf, 
   {{0x7c2410d0,0x6d4010d1,0xa37c02ce,0x7e7c10d2}},	//   veir, ålan, kaŵi, tirp, 
   {{0x1d0810d3,0x53980375,0x7c240368,0x93c00311}},	//   леги_, _גינו, weir, ţăto, 
   {{0x7c2410d4,0xc32c01d9,0x00000000,0x00000000}},	//   teir, _رٕژ_, --, --, 
   {{0x3e7806be,0x600800f3,0x5f28014b,0x00000000}},	//   _mütə_, _сним_, _боим_, --, 
   {{0x7c2410d5,0x5ba806a6,0x7e7c0b1a,0xd7f801a9}},	// [c20] reir, укам_, pirp, ҳул_, 
   {{0x7c2410d6,0x0f340375,0x7e7c0784,0x46c800bc}},	//   seir, _פריט_, qirp, ादनह, 
   {{0xd7f810d7,0x7c2410d8,0x97c400c6,0x2fcc0331}},	//   гул_, peir, مقاو, žege_, 
   {{0x18a410d9,0x574410da,0x6b880010,0x06cc00eb}},	//   щаем, йнеб, _žege, _রিজি, 
   {{0xb17c01e4,0xd49810db,0x9988013a,0x00000000}},	//   raĥi, һри_, _tabů_, --, 
   {{0xc7a00902,0x00000000,0x00000000,0x00000000}},	//   чичк, --, --, --, 
   {{0x260810dc,0x398400f2,0xa2ac00cd,0x00000000}},	//   _सारी_, _بیاف, ुगन्, --, 
   {{0xe9e40589,0x6d5803f9,0x00000000,0x00000000}},	//   ãºva_, _ƙwaz, --, --, 
   {{0xe80c10dd,0xe850105d,0x7794030f,0x00000000}},	//   _हाता_, _تۆند, _بیشا, --, 
   {{0x48fc00bc,0x00000000,0x00000000,0x00000000}},	//   शूको_, --, --, --, 
   {{0x661405d1,0x3b000455,0x614000c7,0x86b4009f}},	//   _özka, hriq_, ҧҵәа, _اُلر_, 
   {{0x518410cf,0xc9500375,0xdbd4008e,0xf48401d5}},	//   _қула, למת_, _cäüd, _باطی, 
   {{0x9f4002ea,0x00000000,0x00000000,0x00000000}},	//   taká_, --, --, --, 
   {{0x8d7410de,0xf1c80075,0x00000000,0x00000000}},	//   مازا, _ئاشۇ_, --, --, 
   {{0x865810df,0xdd380276,0xc20410e0,0xdbd40139}},	//   נדלי, văţa, _اقىن_, _fäüd, 
   {{0x9f4010e1,0x3dcc013f,0x4fc410e2,0xdbd4008e}},	//   saká_, _ɔkwɑ_, _уска, _gäüd, 
   {{0x260810e3,0x9f400270,0xaa5410e4,0xbea800ec}},	// [c30] _साली_, paká_, оваш, _ڏهين_, 
   {{0x7f94010a,0x4e9401e2,0x00000000,0x00000000}},	//   _хаьх, _دشعر, --, --, 
   {{0xac9400c2,0xdd380311,0x7ed4020e,0x3b00022e}},	//   _маош, răţa, _وزیا, ariq_, 
   {{0xf77010e5,0x27e810e6,0xbd8804fb,0x0ff80401}},	//   کام_, úan_, _چنین_, ्लिश_, 
   {{0x94f40135,0x65c410e7,0x499010e8,0x00000000}},	//   ྗེའི_, обла, _کیار, --, 
   {{0xa56410e9,0xdde400cd,0x517402dd,0x00000000}},	//   يگان, _āpūr, _ﺸﺒﺎﻁ_, --, 
   {{0x6d580b45,0x00000000,0x00000000,0x00000000}},	//   _ƙway, --, --, --, 
   {{0xe45810ea,0x66d000c7,0x8cac10eb,0xdb100241}},	//   ржи_, _ẽkur, ंगटो, _ọ̀wọ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x625810ec,0xdbd40724,0xe2900736,0x6e20000d}},	//   ррир_, _säüd, بذب_, õlbl, 
   {{0x60240c98,0x63f810ed,0x6aa40165,0xa3b800f1}},	//   одна, _نفاس_, ilhf, داګر_, 
   {{0x81700150,0x00000000,0x00000000,0x00000000}},	//   _ﺸﺒﻜﺔ_, --, --, --, 
   {{0x69d40221,0x2480020c,0x7ea010ee,0xaaa800bc}},	//   _ofze, éhmu_, köpt, कताक, 
   {{0x68f402fb,0xb8fc031c,0xa3d00073,0x00000000}},	//   _ovzd, _རྕ_, वडक_, --, 
   {{0xdd9010ef,0x1b0403d4,0xdbd40139,0x29000327}},	//   ذور_, ৰিছে_, _täüd, jrha_, 
   {{0x8c4010f0,0x69d40196,0x20f40421,0xc5f0015b}},	//   месе, _afze, māi_, চ্চা_, 
   {{0x2900025c,0x00000000,0x00000000,0x00000000}},	// [c40] erha_, --, --, --, 
   {{0x7ea010f1,0x3b0010f2,0x61e0036e,0x1e84026b}},	//   töpu, rriq_, nbll, _флом, 
   {{0x2d84002d,0x17c800c7,0x3b0000e4,0x00000000}},	//   ûlet_, агеи_, sriq_, --, 
   {{0x186810f3,0xd6d8005b,0x7ac40117,0x00000000}},	//   јади_, атк_, _нимҷ, --, 
   {{0xc5f009bd,0x160c10f4,0xc6d00150,0x3b000113}},	//   চ্ছা_, _सादर_, وتوت, qriq_, 
   {{0x473010f5,0x38c803e6,0x95700023,0x8f9800d9}},	//   ьніс, _هاری_, _እንቛዕ_, סיסי, 
   {{0x29000142,0xc1e00037,0xd94400d8,0x9f400139}},	//   crha_, _ग़जब_, _ќеби, lakä_, 
   {{0xe8b000db,0x00000000,0x00000000,0x00000000}},	//   _كەلج, --, --, --, 
   {{0x833001c6,0x2450013a,0x00000000,0x00000000}},	//   дных, _jámy_, --, --, 
   {{0xd25810f6,0x20f40421,0xf1b80327,0xc60000db}},	//   рци_, fāi_, leġi_, _озуй, 
   {{0x98c800bc,0x645c002f,0x6e200037,0xc1b4009d}},	//   िदिए, ösic, õlbm, жлэх_, 
   {{0x7ea001e6,0xe4e80035,0xb11800db,0xc56000ec}},	//   köps, _طعمه_, _ۇقتا_, _تڏهي, 
   {{0x78a0014b,0x64940208,0x00000000,0x00000000}},	//   _mkmv, _rơix, --, --, 
   {{0x4170004b,0x00000000,0x00000000,0x00000000}},	//   _ښايس, --, --, --, 
   {{0xc10000cf,0xa6e8004d,0x7058013e,0x00000000}},	//   _قووي, _giươ, _гайр_, --, 
   {{0x3e540baa,0x3f8c05d1,0x4bd800f2,0x00000000}},	//   _aştı_, ğdur_, شبرد_, --, 
   {{0x3f8c03be,0x29000327,0x3f6800f3,0x00000000}},	// [c50] şdur_, wrha_, _мићо_, --, 
   {{0xe80c10f7,0x24500122,0x7c60001f,0x00000000}},	//   _हाहा_, _dámy_, ደሌለው_, --, 
   {{0xf7d802e3,0x278801e0,0xa7a80116,0xfeb810f8}},	//   _ịrụp, әреү_, әкла_, _بايت_, 
   {{0x2ee803f9,0x29000393,0x245002f0,0xac9410f9}},	//   _kwaf_, rrha_, _fámy_, _хамш, 
   {{0x872400c6,0x09e0015b,0x490402a0,0x46300022}},	//   تعام, মণবা, _हमको_, мҭар, 
   {{0xe80c10fa,0x00000000,0x00000000,0x00000000}},	//   _हावा_, --, --, --, 
   {{0x2fc80280,0x224810fb,0x363400ae,0x00000000}},	//   _ogag_, _đak_, برنس, --, 
   {{0x2fc80428,0xd70002dd,0x00000000,0x00000000}},	//   _ngag_, _бiра, --, --, 
   {{0xc6a410fc,0xd7e800db,0xa3b4012d,0xa0a40107}},	//   _држи, _دوقۇ_, छें_, ҷанд, 
   {{0x27ec10fd,0xf77010fe,0x2fc810ff,0x6aa81100}},	//   _heen_, _شاق_, _agag_, _कठोर, 
   {{0xa0a41101,0x644c0086,0xba04001f,0x61440aa8}},	//   занд, _òaio, _ውድ_, чена, 
   {{0x26c41102,0x26cc00b0,0x27ec0363,0x24881103}},	//   _hilo_, _kueo_, _jeen_, _ñam_, 
   {{0x27ec1104,0x25a4015d,0x00000000,0x00000000}},	//   _meen_, _hyll_, --, --, 
   {{0x27ec1105,0x64581106,0x2ee81107,0xd35406a9}},	//   _leen_, _howi, _dwaf_, _מיני_, 
   {{0x64581108,0x2fcc1109,0x97300092,0x00000000}},	//   _kowi, žega_, _በውድድ, --, 
   {{0x26c4110a,0x27ec110b,0x3eb8110c,0x6b8801a6}},	//   _lilo_, _neen_, smrt_, _žega, 
   {{0x20100230,0x2ee803f9,0x26c401c4,0x2d84004a}},	// [c60] _icyi_, _gwaf_, _oilo_, ûler_, 
   {{0x6280110d,0x26c4110e,0x6458110f,0x9e280050}},	//   nilo, _nilo_, _lowi, _آدم_, 
   {{0x27ec1110,0x5ca41111,0x9f4000c7,0xf1b80135}},	//   _been_, _ниоб, sakä_, teġi_, 
   {{0x62801112,0x26c40b23,0x27ec002e,0x64581113}},	//   hilo, _ailo_, _ceen_, _nowi, 
   {{0x27ec1114,0x62801115,0xc04c001f,0xe80c1116}},	//   _deen_, kilo, _እየተገ, _हारा_, 
   {{0x6b880f99,0x62801117,0x26c401a6,0x00000000}},	//   _þega, jilo, _cilo_, --, 
   {{0x26c41118,0x62801119,0x6458111a,0x27ec111b}},	//   _dilo_, dilo, _bowi, _feen_, 
   {{0x27ec111c,0x6458111d,0x26c40270,0x62800165}},	//   _geen_, _cowi, _eilo_, eilo, 
   {{0x26c4111e,0x6458111f,0x00000000,0x00000000}},	//   _filo_, _dowi, --, --, 
   {{0x62801120,0x25a41121,0x26c4020c,0x645803ac}},	//   gilo, _fyll_, _gilo_, _eowi, 
   {{0x76481122,0x2ee81123,0x27ec0694,0x25a40142}},	//   _indy, _swaf_, _yeen_, _gyll_, 
   {{0x64581124,0x62800618,0x76440198,0x2f880124}},	//   _gowi, ailo, ɓiya, жәон_, 
   {{0x27e81125,0xe4540b43,0x26c41126,0x8898011a}},	//   ðani_, _تفنگ, _yilo_, מבטי, 
   {{0xdee40201,0x64581127,0x62801128,0xc0f40020}},	//   ሜሪካ_, _zowi, cilo, ላለም_, 
   {{0xbfec0c58,0x64581129,0x8c64112a,0xfe7000e3}},	//   _কাৰণ_, _yowi, птад, ادُ_, 
   {{0x4fc4074d,0x2ee80175,0x00000000,0x00000000}},	//   _эска, _twaf_, --, --, 
   {{0x27ec112b,0xfbd00597,0xddc80311,0x99880010}},	// [c70] _reen_, اتف_, _înşi, _rabš_, 
   {{0x27ec0c3e,0x7ea0112c,0x49c800c7,0x4a2400c7}},	//   _seen_, söpr, суам_, џьаб, 
   {{0x88c4112d,0x80a4112e,0x26c4089c,0x27ec112f}},	//   ستال, _زمین, _rilo_, _peen_, 
   {{0x76481130,0x2c080502,0x26cc0069,0x7f84006c}},	//   _andy, _بعدی_, _pueo_, _آلین, 
   {{0x64581131,0x26c41132,0x27ec1133,0x2ca81134}},	//   _rowi, _pilo_, _veen_, mlad_, 
   {{0x2ca81135,0x64581136,0x27ec1137,0x62801138}},	//   llad_, _sowi, _ween_, xilo, 
   {{0x64581139,0x26c40978,0x27ec113a,0x2ca8058a}},	//   _powi, _vilo_, _teen_, olad_, 
   {{0x7648113b,0x2ca8113c,0x26c4016d,0x260801ad}},	//   _endy, nlad_, _wilo_, _साकी_, 
   {{0x26c4113d,0x2ca800a9,0x64580810,0xe298113e}},	//   _tilo_, ilad_, _vowi, жап_, 
   {{0x6458016b,0x2ca8113f,0x62801140,0x25a41141}},	//   _wowi, hlad_, uilo, _tyll_, 
   {{0x62801142,0x2ca81143,0x25a40076,0x64580f85}},	//   rilo, klad_, _uyll_, _towi, 
   {{0x1de40b4c,0x62780122,0x660c02a8,0xd5980375}},	//   कर्ष_, jňov, ɗaka, _ובעל, 
   {{0x2ca81144,0x62780122,0x248c1145,0x76481146}},	//   dlad_, dňov, mnem_, _yndy, 
   {{0x248c1147,0x62801148,0x21681149,0xe1f000f2}},	//   lnem_, qilo, _мили_, _شست_, 
   {{0x248c0de4,0x2ca801d9,0xdca4114a,0x2d94114b}},	//   onem_, flad_, дави, ертс, 
   {{0x248c114c,0x4e1c0abd,0x9f04114d,0x00000000}},	//   nnem_, म्बई_, _قوبو, --, 
   {{0x248c114e,0xfb84114f,0x00000000,0x00000000}},	// [c80] inem_, ردری, --, --, 
   {{0x2ca81150,0x248c1151,0x77f81152,0x261800c5}},	//   alad_, hnem_, ुल्क_, _मउगी_, 
   {{0x248c1153,0x9f400030,0x627802f0,0xb80800fe}},	//   knem_, jakú_, bňov, _ৰোগত_, 
   {{0x248c1154,0x9f940139,0xe99400f2,0x62781155}},	//   jnem_, _cüçi_, رهنگ, cňov, 
   {{0x248c1156,0x4aac1157,0x00000000,0x00000000}},	//   dnem_, _जीवव, --, --, 
   {{0xa3c002a0,0xf4841158,0x644c0086,0x248c0393}},	//   ंधन_, کاتی, _òaij, enem_, 
   {{0xceb004ac,0x18681159,0xfbb00183,0x248c0010}},	//   דיג_, _дави_, _কলিত, fnem_, 
   {{0x60cc01fa,0x7414115a,0x85400139,0x00000000}},	//   _čamp, روخا, тэше, --, 
   {{0xd6240597,0x3a38115b,0x00000000,0x00000000}},	//   _يعطي, _karp_, --, --, 
   {{0x5184115c,0xfbb002f5,0x041c04c5,0x7648115d}},	//   дума, _কলাত, _মোদী_, _undy, 
   {{0x248c115e,0x1bec01ad,0x62780306,0x2ca8115f}},	//   bnem_, जराल_, yňov, ylad_, 
   {{0x2ca801e3,0x00000000,0x00000000,0x00000000}},	//   xlad_, --, --, --, 
   {{0x2ca81160,0x62780308,0x25b400db,0xcfa800f2}},	//   vlad_, vňov, _قۇۇد_, تادم_, 
   {{0x3a381161,0x2ca81162,0x8d680261,0x91f002e5}},	//   _narp_, wlad_, ојба_, _आजिज_, 
   {{0x62780122,0xf1b80135,0x7ea001e3,0x2ca81163}},	//   tňov, teġu_, röpp, tlad_, 
   {{0x4fc41164,0xa3b400e1,0x3a38045a,0x2ca81165}},	//   _оспа, छेक_, _aarp_, ulad_, 
   {{0x7b181166,0x0dc81167,0x2ca81168,0x627802fb}},	// [c90] мотр_, _муни_, rlad_, rňov, 
   {{0x70541169,0x248c116a,0x627802fb,0x27880137}},	//   _آنکا, znem_, sňov, үрдү_, 
   {{0x248c116b,0x62780232,0x25a803f9,0xfbd001ed}},	//   ynem_, pňov, ƙali_, اتہ_, 
   {{0x248c0369,0x67d40117,0x4aac000d,0x00000000}},	//   xnem_, ходу, _जीरव, --, 
   {{0x248c0fb7,0x2ef8009a,0x0a6800d8,0x64a40022}},	//   vnem_, nssf_, _дрви_, ҽака, 
   {{0x248c116c,0x00000000,0x00000000,0x00000000}},	//   wnem_, --, --, --, 
   {{0x248c0fb7,0x64a4116d,0x00000000,0x00000000}},	//   tnem_, нака, --, --, 
   {{0x248c116e,0x00000000,0x00000000,0x00000000}},	//   unem_, --, --, --, 
   {{0x248c116f,0x97000075,0x3a380309,0x00000000}},	//   rnem_, _مېنى, _yarp_, --, 
   {{0x248c1170,0x22141171,0x3f8403b2,0x00000000}},	//   snem_, хфир, úmum_, --, 
   {{0x248c1172,0x00000000,0x00000000,0x00000000}},	//   pnem_, --, --, --, 
   {{0x24180108,0xef200210,0x00000000,0x00000000}},	//   _ходы_, ężny_, --, --, 
   {{0x270c0574,0x00000000,0x00000000,0x00000000}},	//   _समोर_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa068004e,0x00000000,0x00000000,0x00000000}},	//   _нака_, --, --, --, 
   {{0xdca41173,0x3a380afb,0x00000000,0x00000000}},	//   хаби, _sarp_, --, --, 
   {{0x3a381174,0x4dec00cc,0x00000000,0x00000000}},	// [ca0] _parp_, _জাৰ্_, --, --, 
   {{0x7f441175,0x4aa401af,0x9aa41176,0x00000000}},	//   _iriq, екун_, رماو, --, 
   {{0xdb0402f0,0x5804007b,0x00000000,0x00000000}},	//   _myké, فواك, --, --, 
   {{0x3a381177,0x8d741178,0xcdcc004b,0x7f4406be}},	//   _warp_, _ساپا, _نښې_, _kriq, 
   {{0x3a3802d5,0xb5fc0327,0x6d401179,0x7d1c0010}},	//   _tarp_, _joġg, ålav, ltrs, 
   {{0x7ae4117a,0x7f44020c,0x3898007f,0x81c400cc}},	//   mpit, _mriq, dčre_, _োজন_, 
   {{0x7ae4117b,0x7d1c01e0,0xd4c40131,0x00000000}},	//   lpit, ntrs, нсип, --, 
   {{0x7ae40451,0x7f4401a9,0x38c80133,0xf2c8012d}},	//   opit, _oriq, _زازی_, रद्घ, 
   {{0x7ae4117c,0x96b8117d,0x1368117e,0x574400fb}},	//   npit, _فائز_, яшки_, _янаб, 
   {{0xc0f4001f,0x7ae4117f,0x4b78010f,0x7d1c1180}},	//   ዋለሁ_, ipit, פטיג, ktrs, 
   {{0x7f441181,0x27e80004,0x25a0002f,0x00000000}},	//   _ariq, ñang_, ühlt_, --, 
   {{0x7f441182,0xa0341183,0x00000000,0x00000000}},	//   _briq, نىپت, --, --, 
   {{0x7f441184,0x7ae40115,0x00000000,0x00000000}},	//   _criq, jpit, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xac181185,0xcee800f2,0x00000000,0x00000000}},	//   мову_, _کربن_, --, --, 
   {{0x7f441186,0xef100137,0xfa0800eb,0x6aa800cd}},	//   _friq, _күмө, র্মল_, कत्र, 
   {{0x7ae41187,0x6e981188,0x6a140166,0x00000000}},	// [cb0] gpit, _овир_, кмау, --, 
   {{0x6f1c0e78,0x00000000,0x00000000,0x00000000}},	//   mtsc, --, --, --, 
   {{0x6f1c1189,0xfe70004b,0x7ae4118a,0x91a4000d}},	//   ltsc, _ددي_, apit, _घुमै, 
   {{0x6d4400aa,0x6f1c0196,0xbd880014,0x39a4118b}},	//   _irha, otsc, _سنُن_, ушув, 
   {{0xd364118c,0x6f1c118d,0xb8d80c2e,0x752800e2}},	//   _ئه_, ntsc, _घी_, _apdz, 
   {{0x6f1c118e,0xfa080154,0x38980100,0x1670118f}},	//   itsc, র্বল_, včre_, ақур, 
   {{0x6f1c1190,0xc44401ed,0xdddc01ef,0xbba800d1}},	//   htsc, ٹیشن_, _dopň, ﺋﯩﻠﻪ_, 
   {{0x6f1c002f,0x68e4002f,0xa44401d5,0x00000000}},	//   ktsc, mphd, тнид, --, 
   {{0xe718021a,0xa9a400d1,0x6f1c01a4,0x92f4007b}},	//   _زيات_, _чиңд, jtsc, نفيذ_, 
   {{0xe584052f,0x2168016c,0x3e741191,0x6d441192}},	//   _итеү, диои_, _käte_, _orha, 
   {{0x6f1c1193,0xd24c1194,0x6d4401d4,0x7ae41195}},	//   etsc, غچه_, _nrha, zpit, 
   {{0x6f1c1196,0x7f4400d8,0x7ae403f0,0x3e740139}},	//   ftsc, _priq, ypit, _mäte_, 
   {{0x6d441197,0x54780375,0x6728025c,0xdb0400e4}},	//   _arha, _קטנו, _jpej, _tyké, 
   {{0x6d440055,0xa1880354,0x8d8c0023,0x00000000}},	//   _brha, _обла_, _ዘስምዖ_, --, 
   {{0x6f1c1198,0x7ae40309,0x6b8808a5,0x00000000}},	//   atsc, wpit, _þegj, --, 
   {{0x7f441199,0x7bc000d2,0x2c74119a,0x60240022}},	//   _triq, _úmuk, _nådd_, _рдиа, 
   {{0x6d44119b,0x7d1c0fb7,0x6f1c0c8c,0x7ae40841}},	// [cc0] _erha, strs, ctsc, upit, 
   {{0x7ae4119c,0xb5fc0327,0xf9c4009d,0x672c0327}},	//   rpit, _koġe, газү, ħajl, 
   {{0xd8380323,0x67280cad,0x1be8034b,0x6d4400b8}},	//   дэл_, _apej, _одни_, _grha, 
   {{0x7ae4119d,0xa904036b,0xa3c00401,0x05b40210}},	//   ppit, ابلن, ंधा_, ेइनब, 
   {{0x7ae402d1,0xadd8033f,0xca1801ec,0x00000000}},	//   qpit, बुकऔ, _ﺴﻴﺩ_, --, 
   {{0x32f8013f,0x6d440142,0x09e0119e,0x00000000}},	//   _bɛyε_, _yrha, _ворн, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7434084c,0x04600108,0x2bb801f9,0x00000000}},	//   униф, итым, _आरमा, --, 
   {{0xd20801c6,0x660c01d3,0x6f1c119f,0x2bc411a0}},	//   мэнд_, ánké, xtsc, लेपा, 
   {{0x6f1c04cc,0x00000000,0x00000000,0x00000000}},	//   vtsc, --, --, --, 
   {{0x09f4011a,0x00000000,0x00000000,0x00000000}},	//   כמים_, --, --, --, 
   {{0x6f1c11a1,0x2c7401bf,0xc5780375,0x00000000}},	//   ttsc, _kåde_, _קראת, --, 
   {{0x15b4040d,0x7bc000d2,0x6f1c11a2,0x81400214}},	//   ﻤﯩﺰﺩ, _úmuh, utsc, هپیم, 
   {{0x2c74019b,0x6f1c11a3,0x8d7411a4,0x9f5002bd}},	//   _måde_, rtsc, نازا, _meyè_, 
   {{0x6f1c11a5,0x2bc411a6,0x00000000,0x00000000}},	//   stsc, लेना, --, --, 
   {{0x6f1c11a7,0x91f000af,0x6d440306,0x3e7411a8}},	//   ptsc, _आजुओ_, _vrha, _räte_, 
   {{0x201c11a9,0x2c7411aa,0x3e7411ab,0xca1801ec}},	// [cd0] əti_, _rådd_, _säte_, _ﺴﻴﺭ_, 
   {{0x160c0c5a,0x3a7411ac,0x6d4402fb,0x2c7411ad}},	//   _सागर_, алур, _trha, _sådd_, 
   {{0x672811ae,0x2cb80048,0x7ac411af,0x6d4411b0}},	//   _spej, _thsd_, рсте, _urha, 
   {{0x2c7408d7,0x9f50007f,0x3e74007c,0xb95400cf}},	//   _både_, _beyè_, _väte_, جئكت, 
   {{0x160c0574,0x8d7400d1,0xf7700ada,0x362401e1}},	//   _साखर_, _ساھا, ياه_, _ẹ́hì, 
   {{0xa3e404fa,0x9f4004bf,0x9f5002e2,0x3e74002f}},	//   बुन_, jaký_, _deyè_, _täte_, 
   {{0x6ed411b1,0xb5c80472,0x00000000,0x00000000}},	//   _यूसु, نوهم_, --, --, 
   {{0x9f500100,0x6728031c,0x00000000,0x00000000}},	//   _feyè_, _tpej, --, --, 
   {{0x2c74005c,0x86b001ec,0xd5ac01d3,0x00000000}},	//   _gåde_, _кәкі, قہے_, --, 
   {{0x57a401e0,0xe6a40166,0xf77006c2,0x00000000}},	//   _сысҡ, _субү, _باف_, --, 
   {{0x641400c6,0x216811b2,0x250811b3,0x208811b4}},	//   _مواط, хини_, _سرای_, ейни_, 
   {{0xdee411b5,0x2054084c,0xf48411b6,0x00000000}},	//   ломи, утор, _кучн, --, 
   {{0x443c11b7,0x3db00ed1,0x2bc41025,0x730400d4}},	//   mdu_, ﺳﺘﯩﻘ, लेमा, _впіз, 
   {{0x443c11b8,0x91e00114,0x00000000,0x00000000}},	//   ldu_, _лоше, --, --, 
   {{0x443c11b9,0xff1411ba,0x661403e0,0x69c001ef}},	//   odu_, িবেশ_, _özku, _úleh, 
   {{0x443c11bb,0x41dc11bc,0x2bc40073,0x672c0003}},	//   ndu_, पुरस, लेभा, ħajj, 
   {{0xc0dc0020,0x443c11bd,0x8c4000a7,0x6d4007b9}},	// [ce0] ኒየም_, idu_, щете, ålar, 
   {{0xda6411be,0x443c11bf,0x2c7411c0,0x00000000}},	//   داري, hdu_, _råde_, --, 
   {{0x9f5011c1,0xf8a811c2,0x443c0115,0x2bc407af}},	//   _seyè_, نگره_, kdu_, लेबा, 
   {{0x386011c3,0x443c11c4,0xa6d400cc,0x779411c5}},	//   ðir_, jdu_, _সৌধট, لیزا, 
   {{0x9f500098,0x4bf805d0,0x2af40006,0x87000108}},	//   _beyé_, _אלכס, _вясё, бяще, 
   {{0x443c11c6,0x0f34025f,0xda7011c7,0x9f4001b8}},	//   edu_, טרנט_, _اُس_, dakü_, 
   {{0x7c24009a,0xca7402dd,0x48e0010a,0x00000000}},	//   ofir, _сәті_, _госв, --, 
   {{0x7c2411c8,0x443c11c9,0x98a411ca,0xb8b402dd}},	//   nfir, gdu_, _сибе, _төзі, 
   {{0xb27411cb,0x7c2404ba,0x55e411cc,0x5748008e}},	//   илиш, ifir, _бозб, _язам_, 
   {{0x443c11cd,0x7c2411ce,0x427011cf,0xc5b4009d}},	//   adu_, hfir, йгыс, _өрхө, 
   {{0x7c2411d0,0x443c11d1,0x256401d9,0x13e811d2}},	//   kfir, bdu_, _پالُ, _змей_, 
   {{0x94180134,0x443c11d3,0x00000000,0x00000000}},	//   _ɔpɛ_, cdu_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7c2411d4,0x6b8808a5,0x938801af,0x00000000}},	//   efir, _þegi, _осһа_, --, 
   {{0x7c2411d5,0x00000000,0x00000000,0x00000000}},	//   ffir, --, --, --, 
   {{0xaed406ed,0x00000000,0x00000000,0x00000000}},	//   _коиш, --, --, --, 
   {{0x6e9400d6,0xeeb801d5,0x629c00e4,0x645c01f4}},	// [cf0] _випу, _илиш_, ésog, ösii, 
   {{0x443c11d6,0x28d811d7,0x7c2411d4,0xce3000f1}},	//   zdu_, _बंदि, afir, _اودک, 
   {{0xa93400a8,0xa3e401ad,0x693401ec,0x5ed80154}},	//   рееш, बुड_, рнеу, বীদে, 
   {{0x443c11d8,0x7c240175,0x00000000,0x00000000}},	//   xdu_, cfir, --, --, 
   {{0x443c11d9,0xe73811da,0xa63402dd,0x4a080064}},	//   vdu_, тел_, инді, _пэвм_, 
   {{0xa50811db,0xe64411dc,0xf9d4010b,0xdb4c0014}},	//   века_, рекп, _горэ, _کێے_, 
   {{0x37a80cef,0x3e7400af,0x443c11dd,0x64980351}},	//   ктән_, _jäta_, tdu_, ктир_, 
   {{0x443c11de,0x3e7411df,0x7cdc0010,0x23280107}},	//   udu_, _mäta_, _očrn, воии_, 
   {{0xe298016c,0xe3b800a7,0xe1f00214,0xe520000d}},	//   каи_, ъби_, يسد_, _महकि_, 
   {{0xc6a411e0,0x443c016d,0xf5980209,0x09e0009e}},	//   _срби, sdu_, ýýär_, মণকা, 
   {{0x443c016d,0x7c240008,0x09d011e1,0x00000000}},	//   pdu_, yfir, _तलैय, --, 
   {{0x942409b3,0x443c11e2,0x44f00276,0xa0a411e3}},	//   _نومۇ, qdu_, mţ_, рамд, 
   {{0xa3c00073,0x44f00356,0xffa4009d,0x42e40024}},	//   ंधळ_, lţ_, ёлгү, _сцеб, 
   {{0x9f4000d2,0x6144074d,0x1d0811e4,0x38bc00c7}},	//   wakó_, _века, кеги_, míre_, 
   {{0x44f0084c,0x8d6011e5,0xd24c11e6,0x4d60041b}},	//   nţ_, овре, _زني_, окрв, 
   {{0x5f7403e6,0x2be0041c,0xdf48009d,0x00000000}},	//   _ناخر, गुलं_, _азид_, --, 
   {{0x5f7403e6,0x0b4011e7,0x38bc11e8,0x657c03b9}},	// [d00] _ڕاگر, онтн, níre_, _əsha, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd00c11e9,0x7c24015c,0x9f5c0724,0x38bc0332}},	//   _علی_, pfir, ştä_, híre_, 
   {{0x7c240009,0x59740022,0x18a40108,0x00000000}},	//   qfir, лыҵу, шаем, --, 
   {{0x27e811ea,0x3e74007c,0x68e80064,0x2bc401f9}},	//   ñana_, _zäta_, _čede, लेदा, 
   {{0xd944074d,0x7ea001f4,0x00000000,0x00000000}},	//   _кеги, töpy, --, --, 
   {{0x74a8010b,0x00000000,0x00000000,0x00000000}},	//   лсиң_, --, --, --, 
   {{0xe97001ec,0x4938011a,0x00000000,0x00000000}},	//   _عۇند, _בגלו, --, --, 
   {{0x9f4002e2,0x3b0001a9,0x04c4104c,0xe72800f1}},	//   zakò_, nsiq_, جويي_, _مسلو_, 
   {{0x6b880432,0x96b811eb,0x00000000,0x00000000}},	//   _ýege, _рубу_, --, --, 
   {{0x705411ec,0x38640109,0x2c7401e6,0xc22000f2}},	//   مندا, _komr_, _låda_, تکنو, 
   {{0x224803f9,0x3e7401e3,0x00000000,0x00000000}},	//   _ɗaki_, _räta_, --, --, 
   {{0x838011ed,0xc37001d9,0x69c00118,0x91a4000d}},	//   _мыше, _وُمب, _úlev, _घुरै, 
   {{0x3e7400d7,0x25a80205,0x00000000,0x00000000}},	//   _päta_, şale_, --, --, 
   {{0xbd680262,0x6b8801e4,0x6fa80073,0x7e68007c}},	//   арте_, _ɾegu, _घडवू, ödpa, 
   {{0x2c7404f3,0x80a4004b,0x3e74007c,0xbbe80014}},	//   _båda_, _ومون, _väta_, ٔرٕم_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [d10] --, --, --, --, 
   {{0x3e740267,0x00000000,0x00000000,0x00000000}},	//   _täta_, --, --, --, 
   {{0xac9811ee,0x00000000,0x00000000,0x00000000}},	//   _مندا_, --, --, --, 
   {{0x1ee80214,0x2fcc01a6,0xec34010f,0x00000000}},	//   _جویی_, žegu_, _פאָר_, --, 
   {{0x321c00e4,0x00000000,0x00000000,0x00000000}},	//   _ocvy_, --, --, --, 
   {{0x2ca80475,0xf77011ef,0xca700244,0x490c0210}},	//   load_, بام_, _بچرک, _डिपो_, 
   {{0x6d4003f2,0x00000000,0x00000000,0x00000000}},	//   ælah, --, --, --, 
   {{0x290011f0,0x4ad811f1,0x38bc0f33,0x8704005b}},	//   msha_, _बढाव, tíre_, _вяже, 
   {{0x290011f2,0x4e14012c,0x87e4014b,0x00000000}},	//   lsha_, तलाई_, _бюҷе, --, 
   {{0x38bc11f3,0x2900022b,0x659411f4,0x6e340841}},	//   ríre_, osha_, _лазу, jezb, 
   {{0x290011f5,0xa06811f6,0xa18811f7,0xd1c4009d}},	//   nsha_, гана_, убна_, йлье_, 
   {{0x290011f8,0x3b000113,0x27fc015d,0xca180150}},	//   isha_, ysiq_, nawn_, _ﺴﻴﺴ_, 
   {{0x248c11f9,0xa0a40131,0x290011fa,0x6fa4012d}},	//   miem_, _қаид, hsha_, _गुआं, 
   {{0x290011fb,0x248c00da,0x3d3802b5,0x27fc0368}},	//   ksha_, liem_, _pōw_, hawn_, 
   {{0xf1a811fc,0x29000240,0xb3240327,0xdcb006ba}},	//   _پاوه_, jsha_, _འདོང_, كىس_, 
   {{0x248c11fd,0x290003a2,0x2ca805c7,0x23840023}},	//   niem_, dsha_, goad_, _ክስዕብ_, 
   {{0x27fc0369,0x6e34009b,0x290011fe,0xdca40b01}},	// [d20] dawn_, bezb, esha_, _ҳани, 
   {{0x290011ff,0x248c1200,0x3b000477,0x00000000}},	//   fsha_, hiem_, rsiq_, --, 
   {{0x248c1201,0x68f40369,0x27fc0204,0x61e0011f}},	//   kiem_, _cwzd, fawn_, icll, 
   {{0x248c11f9,0x69d41202,0x17f80597,0xbc7400cf}},	//   jiem_, _egze, اراة_, _بۇرب, 
   {{0x248c0029,0x50181203,0x29000014,0xb324031c}},	//   diem_, רונו, asha_, _འདེང_, 
   {{0x29001204,0x47300006,0x00000000,0x00000000}},	//   bsha_, яніс, --, --, 
   {{0x490c00e1,0x248c00de,0x00000000,0x00000000}},	//   _डियो_, fiem_, --, --, 
   {{0x248c1205,0x73d8036b,0x06e400fb,0xa81800cf}},	//   giem_, шдир_, шмәк_, _ەتەر_, 
   {{0x6e340007,0x00000000,0x00000000,0x00000000}},	//   yezb, --, --, --, 
   {{0x85741206,0x248c002d,0x47dc00eb,0x00000000}},	//   рсәт_, aiem_, মরণী, --, 
   {{0x248c1207,0x9598084c,0x69c01155,0xc0e41208}},	//   biem_, _стау_, _úlet, یفین_, 
   {{0x248c1209,0x00000000,0x00000000,0x00000000}},	//   ciem_, --, --, --, 
   {{0x934400a8,0x6e34009d,0x2fcc0036,0x00000000}},	//   _ынде, tezb, äeg_, --, 
   {{0x2900120a,0x00000000,0x00000000,0x00000000}},	//   ysha_, --, --, --, 
   {{0x90e4120b,0xb5fc0327,0x2ca8120c,0x7ae8007f}},	//   _استن, _loġo, toad_, _čdta, 
   {{0x81dc015b,0x6b7400d4,0x00000000,0x00000000}},	//   তরণ_, олбу, --, --, 
   {{0x2900120d,0xfbd0007b,0x00000000,0x00000000}},	// [d30] wsha_, فتك_, --, --, 
   {{0x248c120e,0x00000000,0x00000000,0x00000000}},	//   ziem_, --, --, --, 
   {{0x27e8120f,0xdb0402fb,0x39580327,0x29001210}},	//   ñano_, _vyká, _ġesù_, usha_, 
   {{0x29001211,0x248c004e,0xda1c000d,0x00000000}},	//   rsha_, xiem_, _पाथत_, --, 
   {{0x248c1212,0x27fc1213,0x2900031c,0x2bc400cd}},	//   viem_, rawn_, ssha_, लेशा, 
   {{0xf1c8060c,0x248c0034,0x9ba00131,0x2900036e}},	//   रधान, wiem_, _غەلى, psha_, 
   {{0x248c0029,0xe4c41214,0x29000327,0x2bc406e3}},	//   tiem_, ойки, qsha_, लेरा, 
   {{0x7b08008c,0x2ee801b8,0x00000000,0x00000000}},	//   _ástæ, _otaf_, --, --, 
   {{0x248c1215,0xf7701216,0x00000000,0x00000000}},	//   riem_, _كاك_, --, --, 
   {{0x248c0029,0x38bc02fb,0x3e7404cc,0xbb3c008f}},	//   siem_, míra_, _räto_, רעזי, 
   {{0x645c0730,0x248c00e2,0x2ee81217,0x7de001e1}},	//   ösis, piem_, _ataf_, _làsó, 
   {{0x9fc81218,0xb1840030,0x356800d1,0x248c020c}},	//   игна_, íťaz, _урун_, qiem_, 
   {{0x1ea801e2,0x00000000,0x00000000,0x00000000}},	//   لاسي_, --, --, --, 
   {{0x82200003,0xa3e400c5,0xc0740092,0x00000000}},	//   _འཁྲི_, बुर_, _ሊገመግ, --, 
   {{0xa3c003f3,0xc4d40154,0x9cc81219,0x00000000}},	//   ंधक_, _সবুজ, ғыңа_, --, 
   {{0x33b00131,0x1be8013e,0xda700050,0x00000000}},	//   _تەۋر, рдаи_, ڈُر_, --, 
   {{0x68e809a8,0x5ea4121a,0x81dc0183,0xda70009f}},	// [d40] _čeda, _ومبل, তৰণ_, وُر_, 
   {{0x38bc013d,0x00000000,0x00000000,0x00000000}},	//   díra_, --, --, --, 
   {{0x6ee4121b,0x2124014f,0xd7f80958,0xdca4014b}},	//   _وسیل, ntlh_, аул_, _маои, 
   {{0x5748121c,0x38bc02d2,0x00000000,0x00000000}},	//   изем_, fíra_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x81dc0c58,0xad240345,0x00000000,0x00000000}},	//   তৰত_, _بریو, --, --, 
   {{0x81dc0154,0x92e40154,0x00000000,0x00000000}},	//   তরা_, _বটে_, --, --, 
   {{0xa3e4121d,0x00000000,0x00000000,0x00000000}},	//   बुल_, --, --, --, 
   {{0x0a4c02d3,0x00e00150,0x676401ee,0x00000000}},	//   _መማህራ, _ﺍﻟﺨﺘ, _ентҡ, --, 
   {{0x8628121e,0x672c031c,0x00000000,0x00000000}},	//   _نغمہ_, ħajt, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb324025c,0x00000000,0x00000000,0x00000000}},	//   _འདིང_, --, --, --, 
   {{0xb63c00b5,0xdb740092,0x00000000,0x00000000}},	//   _ｇｐ_, _የመያዝ_, --, --, 
   {{0xdb04005b,0x8c6401a9,0x00000000,0x00000000}},	//   _lykä, отад, --, --, 
   {{0xe57000c8,0x2b480301,0x00000000,0x00000000}},	//   ײַל_, tvac_, --, --, 
   {{0xdddc033f,0xdb04121f,0x4fc40a89,0x2ee802d2}},	// [d50] _dopł, _nykä, _ьска, _utaf_, 
   {{0x8a140035,0x63bc0162,0x37c000eb,0x00000000}},	//   تظرا, ýsni, ইশার, --, 
   {{0x09041220,0x4c80036b,0x00000000,0x00000000}},	//   ючам, _قیسق, --, --, 
   {{0xe9e40589,0x00000000,0x00000000,0x00000000}},	//   ãºba_, --, --, --, 
   {{0x81dc0183,0xd6e400fe,0x24e402dd,0x15c001ec}},	//   তৰি_, _নিউয, _ﺍﻨﺘﻬ, _ﺯﺍﺭﺩ, 
   {{0xe7fc01f9,0x00000000,0x00000000,0x00000000}},	//   _उजवा_, --, --, --, 
   {{0x9fa000e8,0x00000000,0x00000000,0x00000000}},	//   tëër_, --, --, --, 
   {{0x92e40154,0x00000000,0x00000000,0x00000000}},	//   _বয়ে_, --, --, --, 
   {{0x383400d3,0x672c0135,0x00000000,0x00000000}},	//   _інфр, ħajs, --, --, 
   {{0xaabc1221,0x7d0802f0,0x00000000,0x00000000}},	//   ्गिक, ádsk, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x55b80375,0x00000000,0x00000000,0x00000000}},	//   _המעו, --, --, --, 
   {{0x442c1222,0xaabc1223,0x64880113,0x1ec80166}},	//   _ibg_, ्गाक, 鯵ill, йлми_, 
   {{0x68e81224,0x442c007c,0xdcfc00d7,0xa6dc00cc}},	//   _čedn, _hbg_, _vypľ, _ডবাট, 
   {{0xdddc012d,0x9f400c5e,0x5fac0073,0x40e40345}},	//   _popł, ické_, _घडवल, _بوبێ_, 
   {{0x442c1225,0xda1c0490,0x98a4031c,0x00000000}},	//   _jbg_, _पाहत_, ċoċ_, --, 
   {{0x20001226,0x442c0221,0x3e74000d,0x6e4803b2}},	// [d60] maki_, _mbg_, _jätk_, ðsbý, 
   {{0x20001227,0xdb041228,0xa6e801fb,0x442c0175}},	//   laki_, _szkó, _khươ, _lbg_, 
   {{0xceb01229,0x20000270,0x442c0798,0x4dd80375}},	//   _איז_, oaki_, _obg_, _לחיו, 
   {{0x2000122a,0xdca40364,0xda1c00af,0x442c122b}},	//   naki_, _хами, _पावत_, _nbg_, 
   {{0x200003a0,0x60d4047e,0x9f4000e4,0xe7fc000d}},	//   iaki_, _miym, pakõ_, _उजरा_, 
   {{0x2000122c,0x442c122d,0x00000000,0x00000000}},	//   haki_, _abg_, --, --, 
   {{0x2000122e,0x442c122f,0xa6e80208,0x00000000}},	//   kaki_, _bbg_, _nhươ, --, 
   {{0x20001230,0xdb04023a,0x28f80262,0xf48410e8}},	//   jaki_, _tykä, _фэрэ_, باتی, 
   {{0x20001231,0x06e0009e,0x442c1232,0x00000000}},	//   daki_, নীবি, _dbg_, --, 
   {{0x20000093,0x877802e4,0x442c1233,0xd2581234}},	//   eaki_, _האמי, _ebg_, сци_, 
   {{0x2bb80b26,0xa6e807ae,0x20001235,0x00000000}},	//   _आर्थ, _chươ, faki_, --, 
   {{0x442c1236,0x20001237,0x9f5000a2,0xa3e40210}},	//   _gbg_, gaki_, _adyñ_, बुआ_, 
   {{0xefc80020,0x60d400ee,0x00000000,0x00000000}},	//   _በዚያ_, _diym, --, --, 
   {{0x3eb80076,0xdb040241,0x8bc40124,0x00000000}},	//   glrt_, _òmùg, ҧсад, --, 
   {{0x20001238,0x68e8009b,0x61ec03e0,0x00000000}},	//   baki_, _čedo, _şalg, --, 
   {{0x60d405d1,0x20001239,0x00000000,0x00000000}},	//   _giym, caki_, --, --, 
   {{0xfc1401c6,0x00000000,0x00000000,0x00000000}},	// [d70] эмтэ, --, --, --, 
   {{0x6d40123a,0x5f100b67,0x3f7c123b,0x00000000}},	//   ælas, _तित्_, _לאחס, --, 
   {{0x20e4123c,0xba740131,0x6d40123d,0xda1c00c5}},	//   _kēia_, راكت, çlad, _पारत_, 
   {{0x6b880432,0x00000000,0x00000000,0x00000000}},	//   _ýego, --, --, --, 
   {{0xcb4405f5,0x442c0165,0x00000000,0x00000000}},	//   _эхни, _rbg_, --, --, 
   {{0x2000123e,0x442c123f,0xf218012d,0x00000000}},	//   zaki_, _sbg_, _दाग़_, --, 
   {{0x20001240,0x0a50001f,0x64a41241,0xb93400ea}},	//   yaki_, _ለማሳካ, мака, _перј, 
   {{0x200000aa,0xc86401a9,0x00000000,0x00000000}},	//   xaki_, _этги, --, --, 
   {{0x200003b4,0x9730004b,0x60d4014f,0xdee40092}},	//   vaki_, _ټکنا, _riym, ማዊና_, 
   {{0xa6e807ae,0x20001242,0x7cdc02b1,0x60d401d5}},	//   _phươ, waki_, _hōre, _siym, 
   {{0x7cdc1243,0x20001244,0xa0a41245,0x26c41246}},	//   _kōre, taki_, данд, _ihlo_, 
   {{0x60d41247,0x44e01248,0x2054016c,0x20000418}},	//   _qiym, _iñ_, фтор, uaki_, 
   {{0x20001249,0x64480cfd,0x7cdc04fe,0x00000000}},	//   raki_, mdei, _mōre, --, 
   {{0x2000124a,0xa6e801dc,0x44e00986,0xe2c8036b}},	//   saki_, _thươ, _kñ_, _بوتو_, 
   {{0x2000124b,0x6280124c,0x26c40418,0xed34124d}},	//   paki_, mhlo, _mhlo_, нэтэ, 
   {{0x2000124e,0x3994007d,0x6280124f,0x3e741250}},	//   qaki_, _तs_, lhlo, _mäti_, 
   {{0x6d40022c,0x3e7400af,0x64481251,0x00000000}},	// [d80] ælar, _läti_, idei, --, 
   {{0x62801252,0x7f441253,0x26c40117,0x44e00428}},	//   nhlo, _isiq, _nhlo_, _oñ_, 
   {{0x64581254,0x3e740139,0x23c800bc,0xdc68014b}},	//   _onwi, _näti_, ाइँद, _данд_, 
   {{0x7d1c1255,0x6458013f,0xccf002e4,0x644801bf}},	//   murs, _nnwi, _שכר_, jdei, 
   {{0x44e01256,0xc6f4063b,0x64481257,0x7d1c1258}},	//   _añ_, дніх_, ddei, lurs, 
   {{0x64581259,0x26c404c4,0x6448125a,0x7d1c0175}},	//   _anwi, _chlo_, edei, ours, 
   {{0x7d1c125b,0x7ae4125c,0x644801a8,0x948400ee}},	//   nurs, lqit, fdei, дыпд, 
   {{0x3ae4125d,0x7f440b6f,0x3e7401b8,0x73c4125e}},	//   _köp_, _osiq, _däti_, нәле, 
   {{0x44e00dd4,0x7ae4125f,0xb5fc0135,0x73340873}},	//   _eñ_, nqit, _loġi, رىدا, 
   {{0x64581260,0x64481261,0x07a01262,0x62801263}},	//   _enwi, adei, _раун, ghlo, 
   {{0x7f441264,0x20e40069,0x7d1c1265,0x7ae40023}},	//   _asiq, _pēia_, jurs, hqit, 
   {{0x7d1c1266,0x62801267,0x76481268,0xc56000ec}},	//   durs, ahlo, _hady, _جڏهي, 
   {{0x27e81269,0x7648126a,0x6280126b,0x2eec002e}},	//   ñani_, _kady, bhlo, ëef_, 
   {{0x6280126c,0x7ae40429,0x7d1c126d,0x7648010b}},	//   chlo, dqit, furs, _jady, 
   {{0x7648126e,0x7f440928,0xa3e40034,0x6458000f}},	//   _mady, _esiq, बुक_, _ynwi, 
   {{0x7648126f,0x290c0115,0x3c580276,0x7ae40327}},	//   _lady, _ĉea_, мисэ_, fqit, 
   {{0x7ae400aa,0x7cdc02b5,0x10e40046,0x8d740092}},	// [d90] gqit, _rōre, _ﺍﻟﺠﻨ, ከላቸው_, 
   {{0x76481270,0x7a381271,0x3ae4007c,0x2bc40401}},	//   _nady, мпур_, _döp_, लेगा, 
   {{0x80a41272,0x6f1c0005,0x64480368,0x7cdc0374}},	//   _سمین, lusc, ydei, _pōre, 
   {{0x6d441273,0x764802d0,0x64480369,0x7f4402d0}},	//   _isha, _aady, xdei, _ysiq, 
   {{0x6f1c1274,0x76481275,0x6d4401d5,0x2bc41276}},	//   nusc, _bady, _hsha, लेखा, 
   {{0x6d440649,0x64480007,0x7648058a,0xec140150}},	//   _ksha, wdei, _cady, _توڭد, 
   {{0x76481277,0x64481278,0x7cdc0374,0x6f1c1279}},	//   _dady, tdei, _tōre, husc, 
   {{0x6d44127a,0x7648127b,0x4dd800fe,0x00000000}},	//   _msha, _eady, _বজোৱ, --, 
   {{0x6448127c,0x6f1c127d,0x7d1c127e,0xe298127f}},	//   rdei, jusc, zurs, зап_, 
   {{0x27281280,0x76481281,0x6d441282,0xe1f00597}},	//   mún_, _gady, _osha, دسة_, 
   {{0x6d441283,0x272800c6,0x9f5c03ee,0x628001b9}},	//   _nsha, lún_, ştü_, rhlo, 
   {{0x6280006c,0x76480209,0x66001284,0x6e241285}},	//   shlo, _zady, _helk, _achb, 
   {{0x66001286,0x6d441287,0x76481288,0x6f1c04cc}},	//   _kelk, _asha, _yady, gusc, 
   {{0x66001289,0x21a4013d,0x9d440114,0xda1c000d}},	//   _jelk, _пилм, негд, _पाइत_, 
   {{0x6600128a,0x7b840131,0x999802b5,0x6d44128b}},	//   _melk, ھارە, repū_, _csha, 
   {{0x6f1c128c,0x8c40128d,0x7f440a2e,0x660000dd}},	//   busc, лесе, _tsiq, _lelk, 
   {{0x6d44128e,0x7f440944,0x6f1c128f,0x1fb40845}},	// [da0] _esha, _usiq, cusc, _яскр, 
   {{0x6d44044e,0x7ae41290,0xabc400fb,0x66001291}},	//   _fsha, rqit, тауҙ, _nelk, 
   {{0x76481292,0xdb04005c,0x98d800f2,0x7d1c022e}},	//   _rady, _lykø, سباز_, qurs, 
   {{0xd704055f,0x76481293,0x3ae40598,0xa2c001ad}},	//   езди, _sady, _töp_, _रीस्, 
   {{0x27281294,0x66001295,0x76481296,0x7ae40eda}},	//   gún_, _belk, _pady, qqit, 
   {{0x66000745,0x2c740194,0x7648058a,0xe7680118}},	//   _celk, _rådi_, _qady, nářů, 
   {{0x76481297,0x6d4407d6,0x6f1c1298,0xceb00a1e}},	//   _vady, _xsha, zusc, איג_, 
   {{0x66001299,0x64a00421,0x7648129a,0x6f1c0789}},	//   _eelk, sēin, _wady, yusc, 
   {{0xc7a003a6,0x6600129b,0x76480882,0xfe2005f9}},	//   _битк, _felk, _tady, _बांस_, 
   {{0x73c40032,0x60c80134,0x7178129c,0x6f1c07c5}},	//   нәһе, ɛmmɔ, дбор_, vusc, 
   {{0x2b9001f1,0x85f405d0,0x7334129d,0x00000000}},	//   môcť_, _נמאס_, رىگا, --, 
   {{0x6d4401a9,0x8230129e,0x00000000,0x00000000}},	//   _rsha, پریا, --, --, 
   {{0x6600129f,0x6f1c0036,0x93240214,0x00000000}},	//   _yelk, uusc, _سرشن, --, 
   {{0x6f1c12a0,0x6d440076,0xdddc0118,0x00000000}},	//   rusc, _psha, _kopř, --, 
   {{0x8d7412a1,0xac9412a2,0xdcec00de,0x00000000}},	//   راسا, вавш, dzbē, --, 
   {{0x6f1c12a3,0x6d4401f5,0xc1b8011a,0x00000000}},	//   pusc, _vsha, _ממוש, --, 
   {{0x00d812a4,0xfaf012a5,0x92dc015b,0x27280005}},	// [db0] _ثبوت_, مثل_, _তবু_, xún_, 
   {{0x6d4412a6,0xdb2412a7,0x6abc01ad,0x6f0c12a8}},	//   _tsha, ئولی, ्गेर, _ivac, 
   {{0x2bc40073,0x7d080332,0x8fd000fb,0x00000000}},	//   लेजा, ádst, _шәүә, --, 
   {{0x6600049b,0x6f0c0882,0x272812a9,0xa97001e1}},	//   _selk, _kvac, tún_, _ìdíè_, 
   {{0x6600049b,0x36e80075,0x00000000,0x00000000}},	//   _pelk, ۈرۈپ_, --, --, 
   {{0x272812aa,0x7cdc0374,0x693412ab,0xd6c401d5}},	//   rún_, _hōra, _ингу, نمنی, 
   {{0x660012ac,0x7cdc04fe,0x272812ad,0xb5fc00e4}},	//   _velk, _kōra, sún_, _noġu, 
   {{0x660012ae,0x3e74092e,0x6f0c08a4,0xdddc00bc}},	//   _welk, _hätt_, _ovac, _dopř, 
   {{0x7cdc02b1,0x130012af,0xd84000bc,0x3e7400c5}},	//   _mōra, азым, áčů_, _kätt_, 
   {{0x60e80454,0xfe2009ab,0x00000000,0x00000000}},	//   ммом_, _बाइस_, --, --, 
   {{0x6f0c12b0,0xfdac0729,0x21a412b1,0x3e7401e6}},	//   _avac, _খণ্ড, тинм, _mätt_, 
   {{0xdee412b2,0x3e7404f3,0x6f0c04ce,0xd24c0014}},	//   коми, _lätt_, _bvac, ٕنی_, 
   {{0x10e401ec,0xcf4001f4,0x00000000,0x00000000}},	//   _ﺍﻟﺼﻨ, аняй, --, --, 
   {{0x443c12b3,0x91e012b4,0x6f0c012c,0x02a40212}},	//   leu_, _коше, _dvac, _ярем, 
   {{0x6f0c12b5,0x27ec12b6,0xdcb012b7,0x00000000}},	//   _evac, _ofen_, لىس_, --, 
   {{0x443c12b8,0x7cdc01ab,0x00000000,0x00000000}},	//   neu_, _cōra, --, --, 
   {{0x8c4012b9,0x00000000,0x00000000,0x00000000}},	// [dc0] шете, --, --, --, 
   {{0x27ec12ba,0x3e7412bb,0x00000000,0x00000000}},	//   _afen_, _pätu_, --, --, 
   {{0x443c12bc,0x6f0c05b8,0xdca400c7,0x984802e8}},	//   keu_, _zvac, _аани, дяла_, 
   {{0xd6e0012d,0xda1c000d,0x00000000,0x00000000}},	//   ykłą_, _पाकत_, --, --, 
   {{0x443c12bd,0x38bc00c7,0x481001ca,0x00000000}},	//   deu_, níri_, рміс, --, 
   {{0x7c2412be,0x27ec12bf,0xdddc00bc,0x15d40014}},	//   lgir, _efen_, _popř, نگاں_, 
   {{0x92dc03f4,0x443c12c0,0x27ec0295,0x349412c1}},	//   _তবে_, feu_, _ffen_, лакр, 
   {{0x443c12c2,0x38c812c3,0x99980118,0x00000000}},	//   geu_, _سازی_, lepů_, --, 
   {{0x938812c4,0x7c2412c5,0xb9d00092,0x61ec010b}},	//   ьска_, igir, _ሴራ_, _şala, 
   {{0x6f0c0301,0x7c2412c6,0x3e7401e3,0x38bc00e4}},	//   _rvac, hgir, _mäts_, díri_, 
   {{0x443c12c7,0x1424035b,0x6f0c12c8,0x00000000}},	//   beu_, _адем, _svac, --, 
   {{0x443c12c9,0x61f412ca,0x638000c7,0x7c2400a2}},	//   ceu_, ızla, рҳәа, jgir, 
   {{0x38bc00e4,0xff040166,0x00000000,0x00000000}},	//   gíri_, иярн, --, --, 
   {{0x7c2412cb,0x7cdc0374,0xb5fc00e4,0x00000000}},	//   egir, _rōra, _toġu, --, 
   {{0x3e740628,0x31340137,0x826800e5,0x00000000}},	//   _rätt_, _сейр, _تشنہ_, --, 
   {{0x3e740628,0x6abc12cc,0x7cdc0374,0x8eb00137}},	//   _sätt_, ्ग्र, _pōra, _چەحت, 
   {{0x4ea412cd,0x3e7412ce,0x6f0c00b8,0xfbd0007b}},	// [dd0] _арна, _pätt_, _uvac, قتك_, 
   {{0x443c12cf,0x3b540733,0x7c2412d0,0x637801e1}},	//   zeu_, шкур, agir, _hùnú, 
   {{0x443c12d1,0xc0bc0023,0x9f4801f4,0xe6880022}},	//   yeu_, _ሰጊሩ_, äkös_, ҕәак_, 
   {{0x443c0137,0x7cdc04fe,0xc1980375,0x3ba00092}},	//   xeu_, _tōra, ושבי, ቂያዎች_, 
   {{0x443c12d2,0x3e7401e6,0x3b6400a7,0xd36412d3}},	//   veu_, _tätt_, _кърв, _اه_, 
   {{0xe5a412d4,0x443c12d5,0x2cb80165,0xd1b8001f}},	//   лили, weu_, _hksd_, _ታላቁ_, 
   {{0x443c12d6,0x2cb80165,0x00000000,0x00000000}},	//   teu_, _kksd_, --, --, 
   {{0x443c0069,0x27ec0295,0xdddc033b,0x67d412d7}},	//   ueu_, _ufen_, _enpň, _бобу, 
   {{0x443c12d8,0x2cb8020b,0xe3b80150,0x00000000}},	//   reu_, _mksd_, эби_, --, 
   {{0x443c12d9,0x7c2412da,0x03a01086,0x53c412db}},	//   seu_, zgir, лиқо, ыгым_, 
   {{0x443c12dc,0x00000000,0x00000000,0x00000000}},	//   peu_, --, --, --, 
   {{0xa35412dd,0x7c240072,0xa06812de,0x38bc0022}},	//   _مختص, xgir, хама_, tíri_, 
   {{0x6d4012df,0xbe840116,0x00000000,0x00000000}},	//   çlan, иқии, --, --, 
   {{0x10a00046,0x53980bd9,0x3cec00d2,0xdb0400a2}},	//   _қиын, _אינו, ídvo_, _cyký, 
   {{0x7c2412e0,0x5bbc0882,0x00000000,0x00000000}},	//   tgir, ्ध्व, --, --, 
   {{0xb5fc0135,0x3e74000d,0x7c240356,0x38bc00c7}},	//   _inġe, _päts_, ugir, píri_, 
   {{0x5f4412e1,0x5ac812e2,0x3d1800e1,0x5ba80c60}},	// [de0] _صندل, елам_, बूजे_, хкам_, 
   {{0xd1b80020,0xddb412e3,0x00000000,0x00000000}},	//   _ታላቅ_, _محجب, --, --, 
   {{0x7c2412e4,0x88bc00eb,0x00000000,0x00000000}},	//   pgir, েদনক, --, --, 
   {{0xd70812e5,0xc0bc02d3,0xd8b800db,0x178400db}},	//   енде_, _ሰፊሩ_, رداا_, лгем, 
   {{0x7cdc00b0,0x47300722,0x7d1c0194,0x2c7400b5}},	//   _hōro, مروز, lrrs, _vådt_, 
   {{0x09e012e6,0x7cdc0374,0xc7a012e7,0xa6140022}},	//   _горн, _kōro, щичк, азшә, 
   {{0x98a4010b,0x74a8010b,0x04c400f2,0x00000000}},	//   _биве, ксиң_, گويي_, --, 
   {{0x7cdc02b5,0x673012e8,0x00000000,0x00000000}},	//   _mōro, økjæ, --, --, 
   {{0xe9d000aa,0xb5fc0327,0x88b012e9,0x04c412ea}},	//   _هغې_, _anġe, _اینچ, دويي_, 
   {{0xd9f412eb,0x00000000,0x00000000,0x00000000}},	//   ेरित_, --, --, --, 
   {{0x27e80fb7,0x3cf801f1,0x00000000,0x00000000}},	//   žane_, jprv_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb040306,0xcf24009f,0x00000000,0x00000000}},	//   _mykó, درجي, --, --, 
   {{0x0cbc12ec,0xc7b00bd4,0x00000000,0x00000000}},	//   ्ष्म, מבר_, --, --, 
   {{0xc278008f,0x2028005b,0x00000000,0x00000000}},	//   _ארגי, ätiö_, --, --, 
   {{0x2c7412ed,0x629c00d7,0x00000000,0x00000000}},	//   _råds_, ésov, --, --, 
   {{0x3a3812ee,0x39580010,0x7d1c12ef,0xebc40166}},	// [df0] _bbrp_, _arrs_, arrs, рәнн, 
   {{0x2fc80165,0x09e00154,0x00000000,0x00000000}},	//   _izag_, যর্থ, --, --, 
   {{0x7ac412f0,0xac18004e,0x00000000,0x00000000}},	//   ссте, _иону_, --, --, 
   {{0xa564034c,0x6f1c0d27,0xa8340640,0x8ca000db}},	//   یگان, orsc, редљ, _اەرو, 
   {{0x660412f1,0x39580254,0x6e480023,0x00000000}},	//   апла, _errs_, _ብምንጽ, --, 
   {{0x955c001f,0xcfc400cc,0x6f1c12f2,0xe5080b24}},	//   ተሰቡን_, _এলান, irsc, نيتو_, 
   {{0x6f1c101d,0x6b8c020c,0x61ec0166,0x00000000}},	//   hrsc, lzag, _şalo, --, 
   {{0x2334013e,0x38bc02f0,0x00000000,0x00000000}},	//   ахор, fíru_, --, --, 
   {{0xe3b012f3,0x6b8c12f4,0x27fc0399,0x130412f5}},	//   غرب_, nzag, mbwn_, аный_, 
   {{0x659412f6,0x6f1c110c,0x6b8c01c4,0x24f800db}},	//   _казу, drsc, izag, _анжы_, 
   {{0x348401c6,0x6b8c022e,0xd24c0133,0x00000000}},	//   ргөг, hzag, بچن_, --, 
   {{0x7cdc02b5,0x622400d1,0x00000000,0x00000000}},	//   _rōro, _چىشل, --, --, 
   {{0xdee412f7,0x22480276,0x63040131,0xaac412f8}},	//   роги, _апли_, _ئوتل, वताक, 
   {{0x6b8c0bd7,0x7cdc02b1,0xe29812f9,0x41e412fa}},	//   dzag, _pōro, _шал_, _сіда, 
   {{0x6f1c12fb,0x2fc8005a,0x9cb412fc,0x00000000}},	//   arsc, _ezag_, لمست, --, 
   {{0x701c00cc,0x00000000,0x00000000,0x00000000}},	//   ধ্বজ_, --, --, --, 
   {{0x2d5401e4,0xed58005f,0xc608015b,0x3ae812fd}},	// [e00] _eĥe_, āža_, _রানা_, ابری_, 
   {{0x7cdc02b1,0x2b5812fe,0x00000000,0x00000000}},	//   _tōro, _drsc_, --, --, 
   {{0xd82412ff,0x6b8c002d,0x09e003d4,0x61ec0166}},	//   иджи, azag, যৰ্থ, _ğall, 
   {{0x2b581300,0x6b8c067c,0x38600789,0x77941079}},	//   _frsc_, bzag, ñir_, میزا, 
   {{0x87001301,0x68f402d0,0x30d800df,0x00000000}},	//   ояще, _etzd, אַװע, --, 
   {{0x66cc01a8,0x38980374,0x3eb8002f,0xc68c01d9}},	//   júkd, pōro_, nort_, وِن_, 
   {{0x3218068f,0x5c440092,0x00000000,0x00000000}},	//   órym_, _የሻዕቢ, --, --, 
   {{0x3eb80493,0x00000000,0x00000000,0x00000000}},	//   hort_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3eb812ed,0xd2581302,0x6aa802d2,0x959801af}},	//   jort_, тци_, _íeft, _итеу_, 
   {{0x6b8c1303,0x3eb81304,0x00000000,0x00000000}},	//   zzag, dort_, --, --, 
   {{0x85980375,0x6d4005d1,0x38bc00bc,0xd7a80073}},	//   _בשבו, çlam, píru_, _कशाच, 
   {{0x3eb81305,0x6f1c1306,0x4fc401c6,0x25a80205}},	//   fort_, ursc, рсна, şalt_, 
   {{0x6f1c1307,0xd1b8001f,0x3eb81308,0x00000000}},	//   rrsc, _ታዋቂ_, gort_, --, 
   {{0x70580323,0x8cb801d9,0xac181309,0x320c130a}},	//   _байр_, ندرس_, лову_, mady_, 
   {{0x6b8c01c0,0x3d18130b,0x66cc00d2,0x705400f1}},	//   tzag, _फिरे_, múke, _چنګا, 
   {{0x6a140961,0x3eb8130c,0x00000000,0x00000000}},	// [e10] ймау, bort_, --, --, 
   {{0x320c130d,0xdb24130e,0x6b8c130f,0xed5001d9}},	//   nady_, صومی, rzag, _ٹھس_, 
   {{0x7ed400c6,0x2ee01310,0xab6400ef,0x6b8c00e5}},	//   _بزيا, _iihf_, _spļā, szag, 
   {{0x320c1311,0x4c8007d6,0x00000000,0x00000000}},	//   hady_, _بیرق, --, --, 
   {{0x320c1312,0xe7381313,0x61ec00a2,0x00000000}},	//   kady_, уел_, _şalm, --, 
   {{0x320c1314,0x2328013e,0x23680135,0x2ee803e0}},	//   jady_, ҳоии_, _ħaj_, _muaf_, 
   {{0xbe3c0375,0x320c0432,0x561000ec,0x00000000}},	//   דעות, dady_, سويء, --, 
   {{0x3eb81315,0x4428067c,0x228800d7,0x6b88010e}},	//   zort_, üc_, _múke_, _ýegs, 
   {{0x320c0170,0x228800d0,0x6aa802d2,0xea9800b8}},	//   fady_, _lúke_, _íefs, cuṃ_, 
   {{0xf6740597,0x320c1316,0x00000000,0x00000000}},	//   _والخ, gady_, --, --, 
   {{0x3eb81317,0x61441318,0xe0d8011c,0x38bc00e5}},	//   vort_, щена, лво_, pírt_, 
   {{0x3eb81319,0xb5fc025c,0xa0a4030d,0x00000000}},	//   wort_, _inġa, самд, --, 
   {{0xd12c0b29,0x3eb8131a,0x23680240,0x320c131b}},	//   ومی_, tort_, _çaj_, bady_, 
   {{0x201c131c,0x320c0009,0x61440816,0xfd6401c6}},	//   şti_, cady_, _гека, онгү, 
   {{0x6280131d,0xd24c131e,0x2244131f,0xdee4039b}},	//   mklo, _سني_, melk_, роҳи, 
   {{0x3eb81320,0xe2981321,0xd12c007b,0x00000000}},	//   sort_, _шаһ_, _أمي_, --, 
   {{0x3eb81322,0xcb641323,0x05900055,0x00000000}},	// [e20] port_, бате_, _vāṇy, --, 
   {{0x9be401ec,0xd9c801e1,0x22440432,0x00000000}},	//   ріңк, _ẹ̀kẹ, nelk_, --, 
   {{0x2b4801d9,0x62801324,0x1ea800ec,0x00000000}},	//   awac_, iklo, _لاھي_, --, 
   {{0xea980882,0xda700050,0xac680023,0x00000000}},	//   tuṃ_, _کُس_, _ሰሪሖም_, --, 
   {{0xb5fc00e4,0x62801325,0x22440064,0x4cb8011a}},	//   _anġa, kklo, kelk_, _תזכו, 
   {{0x628000f3,0x27e80419,0x3c44009f,0x00000000}},	//   jklo, ľana_, _اَڏِ, --, 
   {{0x998406d5,0x27e81326,0x320c0851,0x5d7800c8}},	//   _الأو, žana_, vady_, טאַק, 
   {{0x320c1327,0x00000000,0x00000000,0x00000000}},	//   wady_, --, --, --, 
   {{0x320c1311,0x68e0020c,0xd2081328,0x00000000}},	//   tady_, _èlda, лэнд_, --, 
   {{0xd0ac013f,0x9f500407,0x66cc0af2,0x6280003e}},	//   _fɛɛf, _leyó_, túke, gklo, 
   {{0x320c1329,0x94040bbf,0x5274132a,0x2124067c}},	//   rady_, _هواه, _қуду, gulh_, 
   {{0x320c132b,0x62800d04,0x629c07ea,0x2b48012d}},	//   sady_, aklo, ésor, ywac_, 
   {{0x320c132c,0xff0402e8,0x434000c0,0x00000000}},	//   pady_, зясн, _нецв, --, 
   {{0xacf8132d,0xdddc0100,0x320c0009,0x00000000}},	//   ингу_, _enpō, qady_, --, 
   {{0x2124067c,0x60dc007f,0x00000000,0x00000000}},	//   culh_, ňsma, --, --, 
   {{0xce300502,0x41c0038b,0x00000000,0x00000000}},	//   _کودک, _عقيق, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [e30] --, --, --, --, 
   {{0x2b48132e,0x61ec0139,0xac98132f,0x00000000}},	//   rwac_, _ğalk, _چندا_, --, 
   {{0x61ec1330,0x00000000,0x00000000,0x00000000}},	//   _şalk, --, --, --, 
   {{0xb0c8102f,0xbdf804f2,0xb4c80354,0x62800210}},	//   रतिग, _پریا_, _йоiа, zklo, 
   {{0x2ca81331,0x62801332,0x66b41333,0x00000000}},	//   mnad_, yklo, обду, --, 
   {{0x2ca81334,0x49f00327,0xc68c0014,0xc984014b}},	//   lnad_, _བཅིལ_, ڈِچ_, _луби, 
   {{0x2ca80489,0x224400e2,0x6ac4043e,0x00000000}},	//   onad_, velk_, वतीर, --, 
   {{0x2ca81335,0xa6c800fb,0x22440332,0x00000000}},	//   nnad_, ылһа_, welk_, --, 
   {{0xb5fc0327,0x62801336,0x2ca80254,0x22441337}},	//   _inġn, tklo, inad_, telk_, 
   {{0x2ca800a9,0xe298026a,0x62800100,0x00000000}},	//   hnad_, рао_, uklo, --, 
   {{0xe0441338,0x2ca81339,0xa068133a,0xf5e4010a}},	//   онни, knad_, аана_, _хіум, 
   {{0x6280133b,0xa0980395,0x00000000,0x00000000}},	//   sklo, ртоф_, --, --, 
   {{0x3f84133c,0x2ca8133d,0x6280133e,0x248c0267}},	//   ámu_, dnad_, pklo, mhem_, 
   {{0x248c133f,0xb9400020,0x9f500100,0x3f8c0034}},	//   lhem_, _ነዋሪዎ, _beyò_, ądu_, 
   {{0x7cdc02b1,0x1d081340,0x3f840030,0xdc981341}},	//   _hōri, реби_, šmu_, аташ_, 
   {{0x90c01342,0x9f500699,0x2ca81343,0x248c1344}},	//   _обще, _deyò_, gnad_, nhem_, 
   {{0x9e90069c,0x8af403be,0x2d90011c,0x20000cb4}},	// [e40] _ሃገርና_, _şəra, azze_, mbki_, 
   {{0x7cdc02b1,0x4a4006ed,0x2ca81345,0x9f4400a2}},	//   _mōri, мнув, anad_, _ýoñ_, 
   {{0x248c0649,0x57e81346,0xdb0401e6,0x2ca80009}},	//   khem_, адем_, _nykö, bnad_, 
   {{0x442c056a,0x2ca80009,0xaf3400f2,0x00000000}},	//   _ncg_, cnad_, _بویژ, --, 
   {{0x7d000241,0x69c01347,0x248c1348,0xdd9000f1}},	//   _fàrò, _ølen, dhem_, _روڼ_, 
   {{0x442c00a3,0x2d8405ac,0x248c0135,0x20d00332}},	//   _acg_, øleg_, ehem_, láid_, 
   {{0x442c0296,0x248c0003,0x00000000,0x00000000}},	//   _bcg_, fhem_, --, --, 
   {{0x442c1349,0x99880100,0x248c134a,0x0680134b}},	//   _ccg_, _rebň_, ghem_, згән, 
   {{0x9268134c,0xc7a00139,0x15d001ec,0x845000f7}},	//   арна_, _житк, _ﺘﺭﺩﺩ, بۉنچ, 
   {{0xb5fc0327,0xc21402bf,0x154400ee,0x91e000fb}},	//   _inġo, оєю_, _мезм, мәйһ, 
   {{0x442c0072,0x2ca80009,0x10e402dd,0x00000000}},	//   _fcg_, ynad_, _ﺍﻟﺒﻨ, --, 
   {{0x442c020b,0x2ca8058a,0xbfc001e1,0x00000000}},	//   _gcg_, xnad_, _íbọm_, --, 
   {{0x2ca8134d,0xc6c0030d,0x15fc134e,0x00000000}},	//   vnad_, _айăк, _उभार_, --, 
   {{0x9f500100,0x20000254,0x25fc0b4c,0x00000000}},	//   _peyò_, abki_, रुपी_, --, 
   {{0x2d840e96,0x66cc01a2,0x2ca8134f,0x442c0175}},	//   ále_, núka, tnad_, _ycg_, 
   {{0x61ec0724,0x20d000ae,0x4e1400bc,0x2ca8000d}},	//   _ğali, gáid_, _भएकै_, unad_, 
   {{0x2d840552,0x2ca81350,0x228802d2,0x61ec06be}},	// [e50] šle_, rnad_, _húka_, _şali, 
   {{0x248c0cf4,0x6e940022,0xa5540153,0x228808a5}},	//   zhem_, _хиоу, ščią, _kúka_, 
   {{0x37f801f2,0x2ca807b9,0x228803b2,0x248c1351}},	//   _ịkụz, pnad_, _júka_, yhem_, 
   {{0x63ac0008,0x228800d0,0x66cc06ea,0x20d00f47}},	//   _þang, _múka_, dúka, cáid_, 
   {{0x22881352,0x236c0003,0x20d000e5,0x00000000}},	//   _lúka_, xxej_, sáig_, --, 
   {{0xd62403bd,0x442c1353,0x4ddc03d4,0x7cdc02b5}},	//   _རྐྱབ_, _scg_, _ব্যং, _rōri, 
   {{0x442c1354,0xb5fc0327,0x20000034,0x07080412}},	//   _pcg_, _inġl, ybki_, _सौरव_, 
   {{0x7cdc02b1,0x248c0100,0x00000000,0x00000000}},	//   _pōri, uhem_, --, --, 
   {{0x248c1355,0xec78004d,0x9f50041e,0x00000000}},	//   rhem_, _độc_, _neyð_, --, 
   {{0x248c1356,0x228800d2,0xdb040108,0x00000000}},	//   shem_, _búka_, _tykö, --, 
   {{0x63ac1357,0x6b88033f,0x248c03e0,0x00000000}},	//   _žand, _żegl, phem_, --, 
   {{0x442c1358,0x7cdc0374,0x9f500174,0x228802d2}},	//   _ucg_, _tōri, _beyð_, _dúka_, 
   {{0x64480076,0xef6401c6,0x1ea81359,0x00000000}},	//   meei, мъёо, ماسي_, --, 
   {{0x6448135a,0x9f5006ea,0x228800d7,0x12f8011a}},	//   leei, _deyð_, _fúka_, _ההסב, 
   {{0x40b40276,0x00000000,0x00000000,0x00000000}},	//   _ориӂ, --, --, --, 
   {{0xb5fc0003,0x6448135b,0x201c0024,0x00000000}},	//   _anġl, neei, ėtis_, --, 
   {{0x20d00597,0xcb64135c,0x63ac02d2,0x00000000}},	// [e60] ráid_, пате_, _þand, --, 
   {{0x64480069,0x20d000c6,0x00000000,0x00000000}},	//   heei, sáid_, --, --, 
   {{0x8e780375,0x6448135d,0xc4c8033f,0x5dd800fe}},	//   _הניה, keei, ाताओ, _ব্ৰু, 
   {{0x6448135e,0x8d74135f,0xace80066,0x00000000}},	//   jeei, _راپا, _گریل_, --, 
   {{0x64480158,0xbab401d9,0xebc001af,0x45c00150}},	//   deei, _قۅرب, _аҡти, _ﺨﺼﻭﺼ, 
   {{0x3b0002d1,0x00000000,0x00000000,0x00000000}},	//   mpiq_, --, --, --, 
   {{0xd4981360,0x00000000,0x00000000,0x00000000}},	//   йри_, --, --, --, 
   {{0x73c40184,0xb4c81361,0x64481362,0x228803b2}},	//   мәле, ोगे_, geei, _rúka_, 
   {{0x3b0002d1,0x17840aac,0x10e40220,0x228800d7}},	//   npiq_, _эгам, _ﺍﻟﺘﻨ, _súka_, 
   {{0x46a01363,0x9f500174,0x4b78008f,0x673c0037}},	//   _заув, _reyð_, צטיג, _äsja, 
   {{0x7f441364,0x86b41365,0x7cdc00b0,0x461001d5}},	//   _apiq, _عُمر_, _hōru, _سونر, 
   {{0x7cdc04fe,0x66cc01f1,0x91c00116,0x00000000}},	//   _kōru, núkn, мәқл, --, 
   {{0xd7000064,0x00000000,0x00000000,0x00000000}},	//   _зiха, --, --, --, 
   {{0x7cdc00b0,0x2ee403fa,0x61ec0c3c,0xdb98001f}},	//   _mōru, ölf_, _şalv, _ለመያዝ_, 
   {{0x7280010c,0x7f441366,0x00000000,0x00000000}},	//   _ዕለታዊ_, _epiq, --, --, 
   {{0x6ac401bc,0x3e7400d7,0x00000000,0x00000000}},	//   वत्र, _mäty_, --, --, 
   {{0x9408013f,0x20d001e7,0x2bd800f2,0xa0d40244}},	// [e70] ɑbɔ_, báib_, زارک_, _تحوڵ, 
   {{0x1ee804fb,0x00000000,0x00000000,0x00000000}},	//   _گویی_, --, --, --, 
   {{0x644800ad,0xbec800ef,0xac941367,0x66cc0419}},	//   yeei, _dzīļ, _жанш, fúkn, 
   {{0x6d440028,0xdcb007d2,0x61e40118,0x48c800fe}},	//   _ipha, _لىپ_, _úhle, িদ্ৰ, 
   {{0xb8f405f9,0x0ae80451,0xfe7012e9,0x64481368}},	//   _सी_, _درجي_, _شدی_, veei, 
   {{0x3e740221,0x00000000,0x00000000,0x00000000}},	//   _sätz_, --, --, --, 
   {{0x64480158,0x00000000,0x00000000,0x00000000}},	//   teei, --, --, --, 
   {{0x29001369,0x6d44136a,0x1540136b,0x7658002d}},	//   mpha_, _mpha, теъм, advy, 
   {{0x6448136c,0x2900136d,0xe7180472,0x00000000}},	//   reei, lpha_, _ذيات_, --, 
   {{0xe2980212,0x00000000,0x00000000,0x00000000}},	//   іан_, --, --, --, 
   {{0x6d440211,0xaa5c0092,0x64480076,0x66cc0419}},	//   _npha, _ለማሟላ, peei, lúko, 
   {{0xa0680640,0x55b80375,0xd5a4136e,0x00000000}},	//   цама_, _ומעו, _تلمی, --, 
   {{0x6d44136f,0x29000770,0xdd901370,0x61ec0356}},	//   _apha, hpha_, ھور_, _şalu, 
   {{0xdd901371,0x6d4400d2,0x9d440114,0x915800cd}},	//   پور_, _bpha, мегд, _āśvā, 
   {{0x929003b7,0x00000000,0x00000000,0x00000000}},	//   _јајц, --, --, --, 
   {{0x5f28039b,0x25fc0490,0x8c401372,0x6c5400d4}},	//   _доим_, रुती_, кесе, нтує, 
   {{0x6d441373,0x60d40810,0x92c00183,0x00000000}},	// [e80] _epha, _ihym, ্দৰ_, --, 
   {{0x6d440076,0x3b000194,0x9a681374,0x00000000}},	//   _fpha, rpiq_, غمال_, --, 
   {{0xceb004ac,0x99481375,0x81dc0154,0x00000000}},	//   _ביז_, تلال_, ধুর_, --, 
   {{0x7cdc02b1,0x228800e4,0x3e7401f4,0x5ca41376}},	//   _pōru, _oúko_, _räty_, _цимб, 
   {{0x3b0401e1,0x3b000309,0x38c800e5,0x00000000}},	//   _dépò_, qpiq_, _ہاری_, --, 
   {{0x3e7400d0,0x6d4402d0,0xc5100116,0x00000000}},	//   _päty_, _ypha, ھبىت, --, 
   {{0x98a41377,0x5fdc0073,0x745400e5,0x00000000}},	//   _живе, नेतल, ٹھائ, --, 
   {{0x7cdc02b1,0x60d40042,0x2bd4000d,0x66cc00d7}},	//   _tōru, _nhym, _दरमा, búko, 
   {{0x6560062c,0x00000000,0x00000000,0x00000000}},	//   _erlh, --, --, --, 
   {{0x32541378,0x73c40184,0x66cc00d0,0x8778011a}},	//   хвор, мәһе, núkl, _ואמי, 
   {{0xd73c0354,0x00000000,0x00000000,0x00000000}},	//   _гiуд, --, --, --, 
   {{0x60d41379,0x6d4400d2,0x25a80691,0x61ec00fd}},	//   _chym, _rpha, _عدلي_, _şalt, 
   {{0x6d44137a,0xe2a811fc,0x00000000,0x00000000}},	//   _spha, _کانن_, --, --, 
   {{0x2bd404af,0x2900137b,0x60d40076,0x00000000}},	//   _दरबा, ypha_, _ehym, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf8b807f7,0x20d000ae,0x00000000,0x00000000}},	//   इकोप, ráic_, --, --, 
   {{0x27e80010,0x20d001e7,0x66cc00d7,0x00000000}},	// [e90] žank_, sáic_, fúkl, --, 
   {{0x6f0c137c,0x2fc80280,0x8d8400cf,0x6d440051}},	//   _iwac, _iyag_, _жумд, _tpha, 
   {{0x6d440028,0x6f0c006f,0xdeb002dd,0x29000129}},	//   _upha, _hwac, _сұры, upha_, 
   {{0x2900137d,0xa7140046,0x229401e1,0x00000000}},	//   rpha_, емді, _kùkù_, --, 
   {{0x2900003a,0x6134137e,0xba0800d1,0xbae400db}},	//   spha_, _külç, ستەك_, ركۅي, 
   {{0x6f0c0925,0x29000354,0xaa44049b,0x92c00eac}},	//   _mwac, ppha_, ävää_, ্দু_, 
   {{0x6f0c009a,0xe89401c4,0xb9c4022e,0x00000000}},	//   _lwac, _завь, _аёти, --, 
   {{0xc0bc044e,0x6f0c137f,0x2fc80c6a,0x20d000e4}},	//   _ሰፊሕ_, _owac, _oyag_, káia_, 
   {{0x27ec1380,0x6f0c1381,0x60d41382,0x572000db}},	//   _igen_, _nwac, _rhym, _مۉنك, 
   {{0x68e81383,0x60d41384,0x00000000,0x00000000}},	//   _hied, _shym, --, --, 
   {{0x68e81385,0x21681386,0x6f0c1387,0xa0a41388}},	//   _kied, чини_, _awac, еанд, 
   {{0x6f0c1389,0x205402f4,0xb4e80e56,0x68e8138a}},	//   _bwac, хтор, _قىلم_, _jied, 
   {{0x68e8138b,0x443c138c,0x6f0c0083,0x645802d0}},	//   _mied, mfu_, _cwac, _iawi, 
   {{0x6458138d,0x00000000,0x00000000,0x00000000}},	//   _hawi, --, --, --, 
   {{0x27ec138e,0x60d4138f,0x64581390,0x6f0c0b6f}},	//   _ogen_, _thym, _kawi, _ewac, 
   {{0x68e81391,0x64581392,0x443c1393,0x27ec1394}},	//   _nied, _jawi, nfu_, _ngen_, 
   {{0x6d401395,0x64581396,0x443c0451,0x6f0c1397}},	// [ea0] çlar, _mawi, ifu_, _gwac, 
   {{0x27ec1398,0x20101399,0x68e8004c,0x443c022e}},	//   _agen_, _heyi_, _aied, hfu_, 
   {{0x68e8139a,0xd7f8139b,0x2010139c,0x443c139d}},	//   _bied, пул_, _keyi_, kfu_, 
   {{0x6458139e,0xb5fc0003,0x25fc00c5,0x26c4139f}},	//   _nawi, _inġi, रुसी_, _aklo_, 
   {{0x201013a0,0x6d500882,0x443c039a,0x00000000}},	//   _meyi_, ādaś, dfu_, --, 
   {{0x201013a1,0x27ec13a2,0x443c13a3,0x645813a4}},	//   _leyi_, _egen_, efu_, _aawi, 
   {{0x68e813a5,0x443c13a6,0x645813a7,0x00000000}},	//   _fied, ffu_, _bawi, --, 
   {{0x63ac13a8,0x645813a9,0x68e813aa,0x443c13ab}},	//   _žana, _cawi, _gied, gfu_, 
   {{0x645813ac,0x36e40022,0x645c0109,0x938813ad}},	//   _dawi, _абаҳ, ôsia, яска_, 
   {{0x68e800da,0x201001e1,0x443c13ae,0x6f0c13af}},	//   _zied, _aeyi_, afu_, _rwac, 
   {{0x2010016b,0xc5ec01d9,0x6f0c13b0,0x13e813b1}},	//   _beyi_, _آم_, _swac, _емей_, 
   {{0x645813b2,0x6f0c007f,0x443c0076,0x92c00011}},	//   _gawi, _pwac, cfu_, ্দে_, 
   {{0x201013b3,0xb4cc01f9,0x00000000,0x00000000}},	//   _deyi_, ळती_, --, --, 
   {{0x6458006d,0x81dc0154,0x00000000,0x00000000}},	//   _zawi, ধুই_, --, --, 
   {{0xb81013b4,0x20d000c6,0xc0bc0023,0x8c6413b5}},	//   ाराम_, máin_, ሰሎም_, нтад, 
   {{0x6f0c13b6,0x20d000c6,0x64580014,0x20100009}},	//   _twac, láin_, _xawi, _geyi_, 
   {{0x68e813b7,0xeeb8006c,0x27ec0295,0x6f0c13b8}},	// [eb0] _ried, _олиш_, _rgen_, _uwac, 
   {{0x68e813b9,0x20100198,0x20d000c6,0x443c0099}},	//   _sied, _zeyi_, náin_, zfu_, 
   {{0x68e813ba,0x2010016b,0x27ec13bb,0x443c13bc}},	//   _pied, _yeyi_, _pgen_, yfu_, 
   {{0x20d006d5,0x26c40232,0x88c413bd,0x443c13be}},	//   háin_, _sklo_, رتال, xfu_, 
   {{0x645813bf,0x68e813c0,0xed58005f,0xe738084c}},	//   _rawi, _vied, āžu_, фел_, 
   {{0x68e813c1,0x645813c2,0xe5a413c3,0x443c0493}},	//   _wied, _sawi, кили, wfu_, 
   {{0x68e80664,0x443c13c4,0xdddc02e2,0x20d000c6}},	//   _tied, tfu_, _enpņ, dáin_, 
   {{0x27ec04ce,0x645802d1,0x443c13c5,0x69d40bbc}},	//   _ugen_, _qawi, ufu_, _izze, 
   {{0xe29813c6,0x443c13c7,0x6458006f,0x2010007f}},	//   дап_, rfu_, _vawi, _reyi_, 
   {{0x645805d9,0x201013c8,0x443c13c9,0x20d000c6}},	//   _wawi, _seyi_, sfu_, gáin_, 
   {{0x201013ca,0x443c13cb,0x6fe80171,0xeaec0118}},	//   _peyi_, pfu_, _līcī, जदुत_, 
   {{0xa0a413cc,0x1e0807af,0x443c13cd,0x237408de}},	//   тамд, वर्ष_, qfu_, _لاتح, 
   {{0x2d8413ce,0xe2b413cf,0xb38400c6,0x20d0007b}},	//   ølen_, _искэ, _مجوه, báin_, 
   {{0x9f9c03b7,0x2010013f,0x20d008de,0x69d40083}},	//   _ação_, _weyi_, cáin_, _ozze, 
   {{0x716413d0,0xdca413d1,0x228802d2,0x00000000}},	//   _مايك, вави, _lúkk_, --, 
   {{0x1f6413d2,0xeaec09ab,0x64940332,0xb92400c7}},	//   _аким, जदूत_, _dáig, pysẽ_, 
   {{0x69d413d3,0xdddc0024,0x00000000,0x00000000}},	// [ec0] _azze, _kopū, --, --, 
   {{0xdee4048a,0x8a0013d4,0x64940332,0x00000000}},	//   _шопи, изуе, _fáig, --, 
   {{0xd00c0046,0x649413d5,0x00000000,0x00000000}},	//   _الۋ_, _káid, --, --, 
   {{0x66cc00d2,0xf81408f0,0x00000000,0x00000000}},	//   lúkh, اساگ, --, --, 
   {{0x69d400dd,0x64940332,0x16a0035b,0x63ac00de}},	//   _ezze, _máid, аҳаҭ, _žann, 
   {{0x64940597,0xc7a013d6,0x1dd4007a,0x3ce0000d}},	//   _láid, шичк, _धरात, lmiv_, 
   {{0xc60800bd,0xd498010a,0x20d001e7,0x00000000}},	//   _রাখা_, дрп_, váin_, --, 
   {{0xb4cc0574,0x236800ef,0xdb240241,0x00000000}},	//   ळते_, _šaja_, _òpóp, --, 
   {{0x20d000c6,0x705413d7,0x430413d8,0x8c40054e}},	//   táin_, ۇندا, кхэм_, âşie, 
   {{0x7694002e,0x28740124,0x38bc0306,0x3ce00477}},	//   _bàye, _аӡәы_, víry_, hmiv_, 
   {{0x63ac00fc,0x20d013d9,0x705400ec,0x649401e7}},	//   _þann, ráin_, هندا, _báid, 
   {{0x2ebc13da,0x20d00491,0x64940332,0x5344030d}},	//   ोत्त, sáin_, _ráig, _ахка, 
   {{0x20d013db,0x64940332,0x8f08074d,0x00000000}},	//   máil_, _dáid, ьхна_, --, 
   {{0x395805be,0x6fe8005f,0x8d740132,0x20d0007b}},	//   _osrs_, _rīcī, پاسا, láil_, 
   {{0x395801fa,0xac9413dc,0x649401e7,0xd174004e}},	//   _nsrs_, гавш, _fáid, _шыды, 
   {{0xb5fc0135,0x649413dd,0x20d0007b,0x705806ed}},	//   _inġu, _gáid, náil_, _чаир_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [ed0] --, --, --, --, 
   {{0x20d00491,0x6f1c11a2,0xdb2413de,0x4338010f}},	//   háil_, mssc, اولی, ועמב, 
   {{0x6f1c13df,0x2bd413e0,0x1ea80451,0x2d840037}},	//   lssc, _दरवा, _ساٿي_, äled_, 
   {{0xb4cc0490,0xf77005d9,0x00000000,0x00000000}},	//   ळतो_, ڪام_, --, --, 
   {{0xfeb813e1,0x9cd413e2,0x6f1c13e3,0x20d00597}},	//   _سایت_, _תורה_, nssc, dáil_, 
   {{0xf77013e4,0x2ca813e5,0x6e340399,0x39580175}},	//   تام_, liad_, ngzb, _fsrs_, 
   {{0x88800502,0x64a413e6,0xdbd80166,0x69d402d0}},	//   _پیشن, лака, _eçäk, _uzze, 
   {{0x20d00491,0x2ca80cfd,0x637813e7,0x224801e4}},	//   gáil_, niad_, есор_, _ŝak_, 
   {{0xb5fc031c,0x228803b2,0x649401e7,0x638400d8}},	//   _anġu, _húki_, _ráid, угпа, 
   {{0x6f1c13e8,0x2ca813e9,0x68f401d5,0x3f840162}},	//   dssc, hiad_, _kuzd, ømum_, 
   {{0xe43413ea,0x6f1c13eb,0x649401e7,0x20d000ae}},	//   _مفاد, essc, _páid, báil_, 
   {{0x68f413ec,0x20d00597,0x27e8110c,0x6f1c0e78}},	//   _muzd, cáil_, žanu_, fssc, 
   {{0x2ca80f7b,0x10a013ed,0x3f8400d2,0x6f1c13ee}},	//   diad_, сиян, âmu_, gssc, 
   {{0x248c0316,0x61e400bc,0x00000000,0x00000000}},	//   lkem_, _úhlo, --, --, 
   {{0x2ca80cfd,0x68f405a1,0xdcb013ef,0x6f1c0076}},	//   fiad_, _nuzd, مىس_, assc, 
   {{0xaa700020,0x2ca80cfd,0x7d1c13f0,0x39580120}},	//   _ለማረጋ, giad_, rsrs, _rsrs_, 
   {{0x2b580048,0x395813f1,0x6f1c02d0,0x00000000}},	// [ee0] _cssc_, _ssrs_, cssc, --, 
   {{0x248c033d,0x68f413f2,0x22880162,0x395800e2}},	//   hkem_, _buzd, _búki_, _psrs_, 
   {{0x248c102c,0xdca40e58,0x2ca80368,0x984813f3}},	//   kkem_, _бани, biad_, еяла_, 
   {{0x68f413f4,0x395809a8,0x649401e7,0x2ca803cb}},	//   _duzd, _vsrs_, _láib, ciad_, 
   {{0x248c012c,0x2368009b,0x91c813f5,0xc608015b}},	//   dkem_, _šajn_, _सुनै, _রাজা_, 
   {{0x60c401ee,0x248c13f6,0x3a380113,0xb5fc0327}},	//   hokm, ekem_, _ucrp_, _maġg, 
   {{0x20d00491,0x60c40066,0xd4c401ec,0x2614000d}},	//   táil_, kokm, лсип, _नजरी_, 
   {{0xd3781064,0x00000000,0x00000000,0x00000000}},	//   ечо_, --, --, --, 
   {{0x20d00491,0xb2b807d6,0x60c40306,0x781013f7}},	//   ráil_, клиф_, dokm, ारीक_, 
   {{0x2ca80dd4,0x20d00597,0x68f413f8,0xcb54011a}},	//   ziad_, sáil_, _yuzd, נסיה_, 
   {{0xd14813f9,0x649401e7,0x27e813fa,0x248c0118}},	//   رشدن_, _dáib, žant_, bkem_, 
   {{0x6f1c13fb,0x248c13fc,0x2ca8003e,0x63800124}},	//   tssc, ckem_, xiad_, сҳәа, 
   {{0xb4c009d9,0x6d5413fd,0x03a0034b,0x6f1c0ade}},	//   ंकी_, wwza, _лицо, ussc, 
   {{0x2ca8048e,0x6f1c13fe,0x20bc01f2,0x00000000}},	//   wiad_, rssc, ọkpụ_, --, 
   {{0x2ca800a9,0xac1813ff,0x2d841400,0x6d5401f5}},	//   tiad_, кову_, âle_, uwza, 
   {{0x2b580421,0x81a8015b,0x2ca80165,0x6f1c1401}},	//   _pssc_, _খরচ_, uiad_, pssc, 
   {{0x2ca81402,0x68f41403,0x6494035b,0xdddc007f}},	// [ef0] riad_, _suzd, _háic, _lapň, 
   {{0x2ca800a9,0x68f40030,0x2c1403d4,0x248c1404}},	//   siad_, _puzd, িলেই_, zkem_, 
   {{0x2ca81405,0xc0f4001f,0x248c1406,0x00000000}},	//   piad_, ፋፈል_, ykem_, --, 
   {{0x76481407,0xf77000ec,0x68f40166,0x6c78010f}},	//   _abdy, ڻان_, _vuzd, _סאָפ, 
   {{0xdc3404ac,0x61d01408,0x248c00bc,0x2cb800ef}},	//   _דארט_, _हर्ष, vkem_, _ijsd_, 
   {{0x68f41409,0x66e4140a,0x00000000,0x00000000}},	//   _tuzd, шола, --, --, 
   {{0xd84000c6,0x248c140b,0x60c40369,0x649401e7}},	//   _ŕōś_, tkem_, yokm, _ráib, 
   {{0x64940332,0x3218022e,0x7de000e5,0x38c801c4}},	//   _sáib, аryo_, lásé, _буун_, 
   {{0x248c140c,0xf87002fb,0x2a7001f5,0xa9a40116}},	//   rkem_, šším_, _knzb_, _сиңд, 
   {{0x248c140d,0x3634004b,0x64940332,0x13e4013d}},	//   skem_, _هرمس, _báic, шмый_, 
   {{0xe0d8140e,0x61440408,0x05440137,0x2a6001e7}},	//   кво_, шена, _сүйл_, idhb_, 
   {{0x6e240013,0x00000000,0x00000000,0x00000000}},	//   _adhb, --, --, --, 
   {{0xa3e80243,0x1ea8140f,0x649400ae,0x9878010f}},	//   _मणि_, ناسي_, _táib, דארט, 
   {{0x53980302,0xc1b00124,0x60c40158,0xd36c1410}},	//   _בינו, _гәмы, sokm, _آهو_, 
   {{0x212403e6,0x5de40395,0x00000000,0x00000000}},	//   _ڵبژێ, ржва, --, --, 
   {{0x91b800d9,0x00000000,0x00000000,0x00000000}},	//   _במצי, --, --, --, 
   {{0xcc1405f5,0x63ac0427,0xaf4801d5,0x66cc03b2}},	// [f00] рчсө, _žanj, _یشیل_, lúku, 
   {{0x8f180677,0x5e700244,0x00000000,0x00000000}},	//   _שוית, _بۆسڕ, --, --, 
   {{0xd8380323,0x2a7002b5,0x03f803d4,0x5fa8000d}},	//   вэл_, _dnzb_, _এজনী_, _चेतल, 
   {{0x2d941411,0xb5fc025c,0xdddc0100,0xd1d00023}},	//   _ырыс, _maġe, _rapň, ረፍቲ_, 
   {{0x769401e1,0x473002bf,0x66cc0124,0xc7a01412}},	//   _aàya, жніс, húku, оицк, 
   {{0xd05c03e3,0x81a800cc,0x00000000,0x00000000}},	//   _diqə, _খৰছ_, --, --, 
   {{0x66cc0d12,0x28400092,0x00000000,0x00000000}},	//   júku, _የምኩራ, --, --, 
   {{0xd7041413,0xb4c01414,0x228800d0,0x132c0092}},	//   _взаи, ंके_, _múku_, _በነጻነ, 
   {{0x228800d7,0x00000000,0x00000000,0x00000000}},	//   _lúku_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x09f40302,0x00000000,0x00000000,0x00000000}},	//   ימים_, --, --, --, 
   {{0xdcec02d5,0x629c00db,0x93e401b9,0x9998007f}},	//   mybė, èsor, _кўлл, rapň_, 
   {{0xbfa81415,0x6b4801e4,0xdcec0024,0xd14801d5}},	//   атре_, _oɾga, lybė, رشگن_, 
   {{0x2288043b,0xc0cc0020,0x00000000,0x00000000}},	//   _búku_, _አየር_, --, --, 
   {{0xdcec0006,0xb5fc025c,0x64940022,0x8e7c0092}},	//   nybė, _gaġe, _uáic, _ያገኛሉ_, 
   {{0x30140323,0x228800d2,0x00000000,0x00000000}},	//   _удир, _dúku_, --, --, 
   {{0x3c580276,0xebc4070e,0x7de000e5,0xebd801f0}},	// [f10] шитэ_, сәнн, tásé, удаш_, 
   {{0xdcec0006,0x3a7400a8,0xdb0400e5,0xba740108}},	//   kybė, олур, ámáb, огущ, 
   {{0xd3641416,0x1618006d,0x2904003d,0x6100003a}},	//   _که_, _नज़र_, _ħlas_, _tēle, 
   {{0xb4c00316,0x6844036b,0x4ba400f7,0x6c540137}},	//   ंको_, ёнла, _көзү_, _укму, 
   {{0xdd14010e,0x00000000,0x00000000,0x00000000}},	//   _käşg, --, --, --, 
   {{0x6b8c00dc,0x00000000,0x00000000,0x00000000}},	//   myag, --, --, --, 
   {{0x6b8c1417,0xdcec0024,0xdd1400fd,0xa3c801f9}},	//   lyag, gybė, _mäşg, लॅन_, 
   {{0xe45805c5,0xb834010b,0x6b8c1418,0xb5fc0003}},	//   ужи_, _месщ, oyag, _raġe, 
   {{0x6b8c1419,0x1304034b,0xf7940153,0x00000000}},	//   nyag, бный_, _датэ, --, 
   {{0x6b8c062c,0x66cc00e4,0x25fc0456,0x00000000}},	//   iyag, túku, रुखी_, --, 
   {{0xf65000db,0xd83c0010,0x91c80073,0x60e8009b}},	//   _زئل_, ščec_, _सुदै, лмом_, 
   {{0x65cc0014,0x6b8c141a,0x41400023,0xdb0c01d3}},	//   ीपà_, kyag, _ንካልኦ, őkép, 
   {{0x23280aa5,0x6b8c0796,0x6304141b,0xdd14010e}},	//   _соли_, jyag, _اوتل, _bäşg, 
   {{0xf4840131,0xb5fc0327,0xc20c0014,0xdee4141c}},	//   _гуән, _taġe, _کٔژ_, соги, 
   {{0x753c0730,0x6b8c04ba,0xdcf8141d,0x317802c1}},	//   _ärzt, eyag, افرت_, ärzt_, 
   {{0x30740408,0x00000000,0x00000000,0x00000000}},	//   _дуьс, --, --, --, 
   {{0x6b8c141e,0x5f4401d3,0xdddc01ef,0xc10001f7}},	// [f20] gyag, _انخل, _topů, _اوڊي, 
   {{0x7810141f,0x4b20003b,0x00000000,0x00000000}},	//   ार्क_, ямув, --, --, 
   {{0x6b8c1368,0x18681420,0x00000000,0x00000000}},	//   ayag, лажи_, --, --, 
   {{0xdcec0006,0x6b8c1421,0x2000033f,0x48e01422}},	//   vybė, byag, ncki_, похв, 
   {{0xcb400020,0x20000114,0x6b8c1423,0x00000000}},	//   ንተርኔ, icki_, cyag, --, 
   {{0xdcec02d5,0xb4c001ad,0x00000000,0x00000000}},	//   tybė, ंक्_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdcec0006,0x629c0240,0xf48400f2,0xd8b401e2}},	//   rybė, ëson, تاتی, _امرخ, 
   {{0xd6d01424,0xdcec0153,0x00000000,0x00000000}},	//   _فقر_, sybė, --, --, 
   {{0x321801a2,0xd2581425,0x20001426,0x00000000}},	//   úry_, уци_, ecki_, --, 
   {{0xe6b40014,0x66cc1427,0x920000b8,0x00000000}},	//   _ظلمگ, rúkt, _ũāsa, --, 
   {{0x06cc03d4,0x6b8c0198,0x64940332,0x00000000}},	//   িগণি, yyag, _háin, --, 
   {{0xe8181428,0x00000000,0x00000000,0x00000000}},	//   दरता_, --, --, --, 
   {{0x200004ce,0x0dc80f43,0xf1941429,0xc324007b}},	//   acki_, губи_, _миль, _اكون_, 
   {{0x6494007b,0x6b8c0083,0x8140009a,0x25fc044b}},	//   _máin, wyag, _فنون, रुटी_, 
   {{0x6b8c142a,0x64940332,0x63ac142b,0xaa700092}},	//   tyag, _láin, _žani, _ለማሸጋ, 
   {{0xcf2405d4,0x8af403e3,0x00000000,0x00000000}},	// [f30] _اربي, _şəba, --, --, 
   {{0x6b8c142c,0x649408a5,0x00000000,0x00000000}},	//   ryag, _náin, --, --, 
   {{0x2bd4142d,0xad4000f7,0xc86401d5,0x00000000}},	//   _दरका, _تۉزۉ, йтди, --, 
   {{0x66cc0436,0x63ac00ee,0xc6a4142e,0x610000ef}},	//   júkr, _ýang, әрди, _jēla, 
   {{0x41cc0316,0x649401e7,0x074400c0,0x69b80562}},	//   _सुनस, _báin, схем, ्थही, 
   {{0x6494007b,0xaa840133,0x63ac032e,0x00000000}},	//   _cáin, _گۆڕم_, _þani, --, 
   {{0x6494142f,0x20001430,0xe858014b,0xdaa00116}},	//   _dáin, ycki_, _кавш_, _تەلپ, 
   {{0x25fc1431,0x6d401432,0x20d00332,0x00000000}},	//   रुजी_, çlay, láiv_, --, 
   {{0x649400c6,0x00000000,0x00000000,0x00000000}},	//   _fáin, --, --, --, 
   {{0x649401e7,0x66cc03b2,0x00000000,0x00000000}},	//   _gáin, rúks, --, --, 
   {{0xa1c41422,0xdb0401a8,0x00000000,0x00000000}},	//   юбод, _ómög, --, --, 
   {{0xa91006ab,0x7de00241,0x610000ef,0x00000000}},	//   डीएफ_, _lásí, _cēla, --, 
   {{0x2d841433,0x64480fac,0x2bd4033f,0x610000de}},	//   älen_, mfei, _दरगा, _dēla, 
   {{0x21681434,0x64481435,0xdddc0276,0xae0400fb}},	//   _вики_, lfei, _nopţ, зорҙ, 
   {{0xe0d81436,0xd0800092,0x00000000,0x00000000}},	//   _квк_, _ይጨምሩ_, --, --, 
   {{0x64481437,0xdee4013e,0xceb400fb,0x50d400e5}},	//   nfei, соҳи, йҙө_, _وزٹر, 
   {{0xbbb40073,0x64481438,0xdaa80117,0x63ac010b}},	// [f40] ंपेक, ifei, авад_, _ýand, 
   {{0x7cf80115,0x62800c6a,0x6d4001ab,0x64480142}},	//   _aŭre, njlo, àlac, hfei, 
   {{0x358c044e,0x7de00241,0x58841439,0x6448143a}},	//   ንያታት_, _dásí, жыла, kfei, 
   {{0x20c8143b,0x6448002d,0x649401e7,0x00000000}},	//   रविध, jfei, _sáin, --, 
   {{0x7de0143c,0x2ca40af9,0x64480042,0x00000000}},	//   _fásí, ëlde_, dfei, --, 
   {{0x7cf801e4,0x550400a8,0x98a80051,0x00000000}},	//   _eŭre, очиа, _vqbđ_, --, 
   {{0xd498143d,0x86c0143e,0xc92401af,0x00000000}},	//   ири_, بيون, _морж_, --, 
   {{0x64480007,0xb198001e,0x7f44009a,0x672c143f}},	//   gfei, _ngưỡ, _oqiq, šaja, 
   {{0x649400ae,0x00000000,0x00000000,0x00000000}},	//   _táin, --, --, --, 
   {{0x38641440,0x3b000007,0x649400ae,0x96b800db}},	//   _hamr_, iqiq_, _háil, _тубу_, 
   {{0x7f441441,0xc0f402d3,0x3b0005b1,0x99981442}},	//   _aqiq, ጋገሪ_, hqiq_, kapō_, 
   {{0x92c800bd,0x76581443,0x00000000,0x00000000}},	//   লগে_, levy, --, --, 
   {{0x610000da,0xff0402e8,0x649401e7,0x630000d1}},	//   _vēla, дясн, _máil, _كۈيل, 
   {{0x76580451,0x3b001444,0xbbb40490,0x673c1445}},	//   nevy, dqiq_, ंपैक, _åsje, 
   {{0x7f44009a,0x2ee00270,0xc0bc02d3,0x0ca801f0}},	//   _eqiq, _vhhf_, ደሎም_, атаи_, 
   {{0x76581446,0x321c0109,0x90e404fb,0x649400d8}},	//   hevy, _hevy_, _بستن, _náil, 
   {{0x76581447,0x4a7401e0,0x610000ef,0x00000000}},	// [f50] kevy, ҙыҡт, _jēln, --, 
   {{0x321c035b,0x00000000,0x00000000,0x00000000}},	//   _jevy_, --, --, --, 
   {{0x27880372,0x64480368,0x649400ae,0x80a4030f}},	//   өрдү_, yfei, _báil, _رمین, 
   {{0x321c1448,0x64940597,0x6d441449,0x38640009}},	//   _levy_, _cáil, _iqha, _camr_, 
   {{0x649400c6,0xca740032,0x1ee803b6,0x2d90144a}},	//   _dáil, _һуңы, _خویی_, lyze_, 
   {{0x96600046,0xc0f400b7,0x00000000,0x00000000}},	//   екше, ጋገሩ_, --, --, 
   {{0x8554144b,0x64940597,0x4990144c,0xdddc005f}},	//   تیار_, _fáil, _تیار, _kopš, 
   {{0x2334144d,0x20d001f6,0x92000055,0x00000000}},	//   пхор, náit_, _ũāpa, --, 
   {{0x6448144e,0xe3b00597,0x7658144f,0x321c0076}},	//   rfei, عرب_, bevy, _bevy_, 
   {{0x64481450,0x6d441451,0xe298026a,0xdddc0024}},	//   sfei, _oqha, сао_, _lopš, 
   {{0x29001452,0x64481453,0x64940022,0x321c0055}},	//   nqha_, pfei, _háim, _devy_, 
   {{0x69d40240,0x00000000,0x00000000,0x00000000}},	//   _myze, --, --, --, 
   {{0x6d441454,0x29000113,0x00000000,0x00000000}},	//   _aqha, hqha_, --, --, 
   {{0xa528025c,0x00000000,0x00000000,0x00000000}},	//   _ལྷོག_, --, --, --, 
   {{0x64940597,0x999802b5,0x69d4007c,0x63ac010e}},	//   _láim, tapō_, _nyze, _ýanb, 
   {{0x9b04022e,0x00000000,0x00000000,0x00000000}},	//   ззад, --, --, --, 
   {{0x6d440944,0x999800b0,0x75380306,0x649400ae}},	// [f60] _eqha, rapō_, zuvz, _ráil, 
   {{0xc0f40125,0x5cf40d6f,0x649400ae,0x386400b8}},	//   ጋገር_, _няму, _sáil, _samr_, 
   {{0x2d841455,0x649400c7,0xae041456,0x8df8011a}},	//   ølet_, _páil, _توپى, _להית, 
   {{0x20d01457,0x69d41458,0x629c0023,0xbc7400f7}},	//   máis_, _dyze, ësoj, _تۇرب, 
   {{0x76581459,0x672c05ce,0x69d406be,0x20d001e7}},	//   tevy, šajn, _eyze, láis_, 
   {{0x35d4145a,0x649400ae,0x00000000,0x00000000}},	//   молё, _dáim, --, --, 
   {{0x321c145b,0x649400c6,0x7658143a,0x20d0145c}},	//   _revy_, _táil, revy, náis_, 
   {{0x321c04e6,0x75380306,0xd3a4011c,0x00000000}},	//   _sevy_, ruvz, зроп, --, 
   {{0x65600ba1,0xd62800ee,0x321c0022,0x07a0145d}},	//   _eslh, _гозе_, _pevy_, _затн, 
   {{0xcb100375,0x610000e2,0x00000000,0x00000000}},	//   עלת_, _cēlo, --, --, 
   {{0x9f50145e,0xfbc400bd,0x59bc145f,0x20d00789}},	//   _ngyâ_, ্ধিত, ्थिर, jáis_, 
   {{0x20d01460,0x25640014,0x610000de,0x00000000}},	//   dáis_, _زامُ, _tēln, --, 
   {{0x81400edf,0xcb1802ab,0xdddc0064,0x00000000}},	//   ونین, _पौंड_, _ropš, --, 
   {{0x20d001e7,0x59bc07b7,0x00000000,0x00000000}},	//   fáis_, ्थार, --, --, 
   {{0x20d01461,0x81d001f0,0x00000000,0x00000000}},	//   gáis_, _пошх, --, --, 
   {{0x2d900100,0x69d41462,0x00000000,0x00000000}},	//   ryze_, _ryze, --, --, 
   {{0x2900094a,0xff500214,0x69d40240,0x20d01463}},	// [f70] wqha_, _یخی_, _syze, ráit_, 
   {{0x6f0c1464,0x64940332,0x2d84003b,0x20d00042}},	//   _itac, _ráim, øles_, sáit_, 
   {{0xb5fc038f,0x6d441465,0x20d01466,0x96200154}},	//   _paġn, _uqha, cáis_, নলাম_, 
   {{0xdddc1467,0x69d401a2,0x20d000c6,0x00000000}},	//   _uopš, _vyze, láir_, --, 
   {{0x29000054,0x69d40210,0x6b7401a9,0x00000000}},	//   sqha_, _wyze, _ўлгу, --, 
   {{0xa528003d,0x20d00597,0x6f0c009f,0x672c00de}},	//   _ལྷུག_, náir_, _mtac, šajo, 
   {{0x24e81468,0x644c0124,0x2900031c,0x2b4806be}},	//   омки_, _ñaik, qqha_, ltac_, 
   {{0x64940597,0xc21c05f9,0x00d80131,0x20d0007b}},	//   _táim, _मजहब_, ﯟﺍﺗﻘ, háir_, 
   {{0x6f0c1469,0x20d00005,0x86b002dd,0xa2e4146a}},	//   _ntac, záis_, _пәкі, моид, 
   {{0x20d00407,0x4abc146b,0x672803ac,0xc0cc0092}},	//   yáis_, ्विव, _ivej, _አየሁ_, 
   {{0x6100005f,0x5bb8146c,0xb38401c6,0x2b4803e3}},	//   _vēlo, _इश्व, длөл, htac_, 
   {{0xe2f80046,0x20d004d4,0x00000000,0x00000000}},	//   _деді_, váis_, --, --, 
   {{0x4abc07b7,0x10a0146d,0x2b480113,0x6d40146e}},	//   ्वाव, тиян, jtac_, àlan, 
   {{0x12f80302,0x443c146f,0x672800ca,0x20d01470}},	//   _והסב, lgu_, _mvej, táis_, 
   {{0x6f0c1471,0x443c1472,0xdcb01473,0x236c1474}},	//   _etac, ogu_, نىس_, lvej_, 
   {{0x20d00597,0x67281475,0x236c0419,0x00000000}},	//   ráis_, _ovej, ovej_, --, 
   {{0x236c04ce,0x9f041476,0x2d841477,0x443c1478}},	// [f80] nvej_, _توخو, øler_, igu_, 
   {{0x7cf80115,0x443c1479,0x629c0023,0xb5fc0135}},	//   _eŭra, hgu_, ësoh, _raġo, 
   {{0x443c001f,0xaf580020,0xfe140316,0xd7f800a8}},	//   kgu_, ያደርገ, _त्यस_, оул_, 
   {{0x236c00b5,0x00000000,0x00000000,0x00000000}},	//   kvej_, --, --, --, 
   {{0x7c24147a,0x2b48147b,0x672800f3,0x59bc00bc}},	//   mair, ctac_, _cvej, ्थहर, 
   {{0x7c24147c,0x443c147d,0x67280006,0x236c00b5}},	//   lair, egu_, _dvej, dvej_, 
   {{0xd824147e,0x090000c7,0x249c0042,0x236c01bf}},	//   _одви, _апсн, _blwm_, evej_, 
   {{0x7c24147f,0x443c1480,0x09e01481,0x38c81482}},	//   nair, ggu_, _росн, _رازی_, 
   {{0x61ec01e4,0x236c005c,0x00000000,0x00000000}},	//   _ĝala, gvej_, --, --, 
   {{0x7c241483,0x443c1484,0x6f0c036b,0x4b78011a}},	//   hair, agu_, _rtac, קאיו, 
   {{0x7c241485,0x6f0c1486,0x67281487,0x236c01bf}},	//   kair, _stac, _zvej, avej_, 
   {{0x7c241488,0x249c0142,0x6f0c09ab,0xe7f409bb}},	//   jair, _glwm_, _ptac, ुँचा_, 
   {{0x7c241489,0x53e008ec,0xdddc012d,0x20d00332}},	//   dair, _परिश, _napł, táir_, 
   {{0x769400e8,0x8d740014,0x6f0c00d7,0x63ac010b}},	//   _bàyi, ٘ارا, _vtac, _ýana, 
   {{0x7c24148a,0x8c6400cf,0x20d0148b,0xbdd401f4}},	//   fair, мтад, ráir_, ворщ, 
   {{0x6f0c074d,0x7c24148c,0x53e00b8f,0x20d00332}},	//   _ttac, gair, _पराश, sáir_, 
   {{0x6f0c148d,0xfbd0007b,0xaed40798,0x00000000}},	// [f90] _utac, لتك_, _поиш, --, 
   {{0x2b48148e,0x443c148f,0x7c2400e4,0x00000000}},	//   rtac_, zgu_, aair, --, 
   {{0x7c241490,0x443c1491,0x672807f5,0xac9401c0}},	//   bair, ygu_, _svej, _занш, 
   {{0x7c241492,0x4b940020,0xe8c80490,0x66f8010e}},	//   cair, መልክቶ_, िकेच, _aňka, 
   {{0xfe7001ed,0x236c01bf,0x443c0200,0x00000000}},	//   _صدی_, xvej_, vgu_, --, 
   {{0x443c1493,0x236c00b5,0x7f3c010f,0xf804013d}},	//   wgu_, vvej_, קעוו, нчән, 
   {{0xdddc0034,0xfd6400b8,0x249c03cb,0xe2980131}},	//   _zapł, _bhuṃ, _plwm_, җан_, 
   {{0xfdf80302,0x443c1494,0x236c1495,0x3de400cc}},	//   וצות_, ugu_, tvej_, _মলমল, 
   {{0x610000da,0x67281496,0x602800e4,0x00000000}},	//   _vēlm, _uvej, hêmí, --, 
   {{0x7c241497,0x443c0cfd,0x236c1498,0x00000000}},	//   zair, sgu_, rvej_, --, 
   {{0x236c04ce,0x7c241499,0xa068149a,0xb524030d}},	//   svej_, yair, пана_, _аьчк, 
   {{0x236c037e,0x7c240036,0x8af403e3,0x00000000}},	//   pvej_, xair, _şəla, --, 
   {{0x442c149b,0x7c24149c,0xc0cc001f,0xa2940212}},	//   _idg_, vair, _አየለ_, _паді, 
   {{0x442c04e6,0xdea0036b,0x7c24149d,0x00000000}},	//   _hdg_, ایدی, wair, --, 
   {{0x7c24149e,0x442c149f,0x008400ee,0x27e800d0}},	//   tair, _kdg_, _акйү, ľany_, 
   {{0xda6414a0,0x442c14a1,0x27e80306,0x00000000}},	//   کاري, _jdg_, žany_, --, 
   {{0x442c14a2,0x5ba814a3,0x6fe80171,0x00000000}},	// [fa0] _mdg_, чкам_, _cūcī, --, 
   {{0x4a4014a4,0xd00c14a5,0x00000000,0x00000000}},	//   лнув, _پلی_, --, --, 
   {{0x442c14a6,0x00000000,0x00000000,0x00000000}},	//   _odg_, --, --, --, 
   {{0x442c14a7,0xdca414a8,0x4c8000d4,0x5ca401a9}},	//   _ndg_, _чами, _блюв, _чимб, 
   {{0x290414a9,0xa0200254,0x00000000,0x00000000}},	//   _élan_, _ööun, --, --, 
   {{0x442c0221,0xd94400d8,0x610000ef,0x00000000}},	//   _adg_, _пеги, _cēlk, --, 
   {{0x442c14aa,0x38c814ab,0x60d40022,0x98a4085f}},	//   _bdg_, _قاری_, _okym, _зиве, 
   {{0x442c14ac,0x00000000,0x00000000,0x00000000}},	//   _cdg_, --, --, --, 
   {{0x442c009a,0x78a0032e,0x00000000,0x00000000}},	//   _ddg_, _ilmv, --, --, 
   {{0x442c0477,0x60d400ee,0x91e002d9,0x958400d8}},	//   _edg_, _akym, ләйһ, _плзе, 
   {{0x442c14ad,0x63ac00a2,0xc1b4009d,0x00000000}},	//   _fdg_, _ýann, елэх_, --, 
   {{0x442c14ae,0x395813bb,0x312400f7,0x00000000}},	//   _gdg_, _mprs_, ндүг, --, 
   {{0x7cf800df,0xb5fc025c,0x4474010f,0xd25014af}},	//   _aŭro, _raġj, _רעדל_, _منش_, 
   {{0x442c14b0,0x92dc03d4,0x6f080115,0x8d8401d5}},	//   _zdg_, _দূৰ_, ŭeco, нубд, 
   {{0xc17005af,0x6fe8002b,0x646402d2,0x417014b1}},	//   _مديت, _sūcī, _ætiþ, _مايس, 
   {{0x290400e4,0x6fe800ef,0x41d8011a,0x00000000}},	//   _ũlao_, _pūcī, _מחוס, --, 
   {{0x6ad802a6,0x7cf804ac,0x6fb802bf,0xebc41206}},	// [fb0] _ভূগো, _eŭro, _ігор_, тәнн, 
   {{0x8d8401d5,0xab500092,0x00000000,0x00000000}},	//   _зумд, _ሕይወቱ, --, --, 
   {{0xdeb00046,0x69c014b2,0x64940332,0x7ac414b3}},	//   _тұры, _žleb, _iáiv, усте, 
   {{0x64940022,0x00000000,0x00000000,0x00000000}},	//   _háiv, --, --, --, 
   {{0x442c14b4,0xcb4402e8,0x877001ec,0x2204022e}},	//   _rdg_, _яхни, ығаш, 壮hma_, 
   {{0xf548069c,0x2b580048,0xaad800bc,0xe810012d}},	//   _ዘይኮነ, _ipsc_, _बीचक, _ड्रा_, 
   {{0x395814b5,0x442c14b6,0x64a40556,0x569014b7}},	//   _gprs_, _pdg_, кака, рајт, 
   {{0x291014b8,0x61ec01e4,0x00000000,0x00000000}},	//   _itza_, _ŝalo, --, --, 
   {{0xa6f4010b,0x68e802d0,0xa6c80150,0xfa2403d4}},	//   _азаш, _ihed, _قورل_, _পাতল_, 
   {{0x442c063f,0x60d40267,0xb9280208,0x61000171}},	//   _wdg_, _skym, _nhuệ_, _hēli, 
   {{0xa0a40364,0x68e814b9,0x24540244,0x00000000}},	//   ванд, _khed, _لناس, --, 
   {{0x442c14ba,0x68e814bb,0x0048004b,0x00000000}},	//   _udg_, _jhed, ریخي_, --, 
   {{0x626414bc,0x68e814bd,0x64dc01f9,0x00000000}},	//   _авла, _mhed, मतीश, --, 
   {{0x68e80076,0xdee40818,0x00000000,0x00000000}},	//   _lhed, тоги, --, --, 
   {{0x63a814be,0xdef800ee,0x26d801c7,0x68e8007c}},	//   lzen, зың_, _ësou_, _ohed, 
   {{0x39580223,0x68e80076,0x6dbc00c7,0x60d400a2}},	//   _rprs_, _nhed, _ẽkõi, _ukym, 
   {{0x644c0086,0x1ec8013e,0xc0c00092,0x00000000}},	// [fc0] _ñaiu, _олии_, ቶአል_, --, 
   {{0x63a814bf,0x68e814c0,0xfce40032,0x7be80166}},	//   izen, _ahed, тоғо, _ıruı, 
   {{0x68e80a28,0x3eb814c1,0x63a80205,0x00000000}},	//   _bhed, mirt_, hzen, --, 
   {{0x68e814c2,0x38c814c3,0x26c40115,0x7794034c}},	//   _ched, راضی_, _ajlo_, هیزا, 
   {{0x68e814c4,0x63a80196,0x610000e2,0x3eb814c5}},	//   _dhed, jzen, _dēli, oirt_, 
   {{0x63a814c6,0x68e8120c,0xc6f400d4,0xc68c01f7}},	//   dzen, _ehed, вніх_, يِن_, 
   {{0xd9e410f7,0x68e80dc9,0x63a814c7,0xb5fc0003}},	//   _करित_, _fhed, ezen, _jaġi, 
   {{0x3eb814c8,0x68e80731,0x7afc14c9,0x73c414ca}},	//   hirt_, _ghed, _hirt, ләле, 
   {{0x44f4007b,0x3eb80205,0x63ac0432,0x63a814cb}},	//   خروج_, kirt_, _ýanl, gzen, 
   {{0x7afc14cc,0x07a014cd,0xd9e404fa,0x00000000}},	//   _jirt, _таун, _करात_, --, 
   {{0x63a814ce,0x7afc0839,0x00000000,0x00000000}},	//   azen, _mirt, --, --, 
   {{0xb5fc0327,0x22880030,0x68e80200,0x08ac0241}},	//   _naġi, _múky_, _xhed, _àìtó_, 
   {{0x63a814cf,0x7afc14d0,0x228800d0,0x4fc401af}},	//   czen, _oirt, _lúky_, тсна, 
   {{0x717414d1,0x7afc0254,0x3eb80f42,0xdd000205}},	//   _مهتا, _nirt, girt_, çuğu, 
   {{0xb5fc003d,0xc0bc02d3,0xdddc007f,0x00000000}},	//   _baġi, _ደጊም_, _lapņ, --, 
   {{0x7afc14d2,0x3eb80fa3,0x672c00da,0x2fc80218}},	//   _airt, airt_, šaji, _txag_, 
   {{0x68e800a9,0x7afc14d3,0x6b7414d4,0x3eb814d5}},	// [fd0] _rhed, _birt, ылау, birt_, 
   {{0x68e814d6,0x649400c6,0x7afc14d7,0x3eb800ae}},	//   _shed, _háit, _cirt, cirt_, 
   {{0x63a814d8,0x68e814d9,0x7afc14da,0x88c414db}},	//   zzen, _phed, _dirt, پتال, 
   {{0x63a8083a,0x7afc14dc,0x764800a2,0x8c640150}},	//   yzen, _eirt, _acdy, _جەرل_, 
   {{0x7afc14dd,0x6100005f,0x6494007b,0xe7380107}},	//   _firt, _vēli, _máit, хел_, 
   {{0xf77014de,0x64940491,0x4aa414df,0x68e814e0}},	//   غان_, _láit, _गतिव, _whed, 
   {{0x68e814e1,0x6fd402ab,0x6e2403b9,0xdd1006be}},	//   _thed, _युसू, _mehb, _müşv, 
   {{0x63a814e2,0x6e2414e3,0x7afc01c4,0x8af40213}},	//   tzen, _lehb, _zirt, _şəha, 
   {{0x7afc14e4,0x63a814e5,0x00000000,0x00000000}},	//   _yirt, uzen, --, --, 
   {{0x63a814e6,0x7afc01d9,0x6e24016d,0x9f4c003e}},	//   rzen, _xirt, _nehb, _énéh_, 
   {{0x63a814e7,0x60cc00c8,0x649400ae,0xe29814e8}},	//   szen, _ĉamb, _báit, _җай_, 
   {{0x237414e9,0x3eb80e78,0x649401e7,0x1fa8010b}},	//   _ماتح, wirt_, _cáit, екми_, 
   {{0x2b4c04e6,0xd12c0fa2,0x649400ae,0x6e2414ea}},	//   _äech_, يمی_, _dáit, _behb, 
   {{0x614414eb,0xb5fc0327,0xc0bc0023,0x9d44010b}},	//   _бека, _saġi, _ደጊመ_, легд, 
   {{0x6e24025c,0xd83c09a8,0xd24c143e,0x2d9414ec}},	//   _dehb, ščic_, _رني_, артс, 
   {{0x7afc14ed,0x33b00075,0x61000393,0xe72404d3}},	//   _sirt, _دەۋر, _cœle, _وڵ_, 
   {{0x7afc14ee,0x3eb802d3,0x6494007b,0xb5fc025c}},	// [fe0] _pirt, pirt_, _háis, _vaġi, 
   {{0x9a6814ef,0x6600020c,0x9e6414f0,0x7afc0014}},	//   عمال_, _nglk, _свод, _qirt, 
   {{0x7afc14f1,0xdddc005f,0xc0bc02d3,0x61ec0115}},	//   _virt, _sapņ, _ደጊሙ_, _ŝalj, 
   {{0x7afc14f2,0x98d814f3,0x649400c6,0xd82414f4}},	//   _wirt, رباز_, _máis, удди, 
   {{0x3ce014f5,0xf1b80327,0xd6d80022,0x00000000}},	//   mliv_, raġi_, нтк_, --, 
   {{0x7afc14f6,0x3ce00423,0x2d840158,0x05380092}},	//   _uirt, lliv_, åleg_, _አክራሪ, 
   {{0x64940491,0xd40414f7,0x39040022,0x63ac00a2}},	//   _náis, ляпи, _тҟеб, _ýanj, 
   {{0x93880120,0xb4c00037,0x6d4008c2,0x00000000}},	//   есоа_, ूके_, àlai, --, 
   {{0x64940597,0x00000000,0x00000000,0x00000000}},	//   _ráit, --, --, --, 
   {{0x61000270,0x73c40032,0x649400ae,0x518401ca}},	//   _lēlu, ләһе, _báis, гума, 
   {{0x6e2414f8,0x4ea40364,0xdd1000ac,0x649401e7}},	//   _rehb, ҳрва, _rüşv, _cáis, 
   {{0x93e4006c,0x6e2414f9,0x629c02d3,0x764403f9}},	//   _йўлл, _sehb, ësor, ɗiya, 
   {{0xe4380882,0x527414fa,0x00000000,0x00000000}},	//   āṇāṃ_, _ماغز, --, --, 
   {{0x4ea414fb,0x6e24014f,0x649414fc,0x644c00e4}},	//   урма, _qehb, _fáis, _ñair, 
   {{0x6e2414fd,0xc2c014fe,0x64940332,0x6e540092}},	//   _vehb, _ديوي, _táit, _ምዝገባ, 
   {{0x64940597,0x6e2414ff,0x3ce01500,0x61000171}},	//   _háir, _wehb, gliv_, _cēlu, 
   {{0x6e24016d,0x610000ef,0x80a400f1,0x00000000}},	// [ff0] _tehb, _dēlu, _دمين, --, 
   {{0xb5fc0124,0x29040066,0xd1dc0023,0xa3c80073}},	//   _haġu, _élak_, _ቓላት_, लॅट_, 
   {{0x649400c6,0xb5fc031c,0x281403c7,0x00000000}},	//   _máir, _kaġu, لواس, --, 
   {{0xb4c0038e,0xdddc0316,0x6494007b,0xa77400cf}},	//   ूको_, _např, _láir, илеч, 
   {{0xd3641501,0x2ca80597,0xfa2400eb,0x00000000}},	//   _به_, mhad_, _পারল_, --, 
   {{0xd1241502,0x6494007b,0x2ca80489,0x947001d9}},	//   _وم_, _náir, lhad_, ۪گلا, 
   {{0xe5a40075,0x00000000,0x00000000,0x00000000}},	//   рийи, --, --, --, 
   {{0x2ca80142,0x63ac010e,0x00000000,0x00000000}},	//   nhad_, _ýank, --, --, 
   {{0x6494007b,0xbd080055,0xe2c81503,0x2ca8015d}},	//   _báir, _kuũã, клид_, ihad_, 
   {{0x649400ae,0xe2980640,0x2ca80327,0xbb3c00df}},	//   _páis, тао_, hhad_, געזי, 
   {{0x2ca81504,0x20c402bf,0x6494007b,0x41cc085c}},	//   khad_, ийом, _dáir, _सुखस, 
   {{0x672c1505,0x64940077,0x3ce01506,0x24181507}},	//   šaju, _váis, xliv_, _роды_, 
   {{0x64581508,0xdee41180,0x248c01a6,0xfe780137}},	//   _ibwi, иоми, mjem_, гүп_, 
   {{0x2ca81509,0x649400ae,0xdddc0118,0x93100244}},	//   ehad_, _gáir, _zapř, _بووش, 
   {{0x2904150a,0x1d0800f7,0x69c00010,0xa0a40064}},	//   _élah_, теби_, _žlen, _вайд, 
   {{0x2ca8150b,0x98b8150c,0xa3c8150d,0x9f04150e}},	//   ghad_, kupā_, _ईशा_, _پودو, 
  
   {{0x2d84150f,0x64581510,0x3d1c01e1,0xe8a002d3}},	// [1000] äler_, _mbwi, _bàwò_, _ገምጋም_, 
   {{0x3ce01511,0x248c1512,0x8e800022,0x4aa41513}},	//   sliv_, hjem_, _дгье, акун_, 
   {{0x64581514,0x18681515,0x248c00cc,0x5ea407d6}},	//   _obwi, кажи_, kjem_, _ممکل, 
   {{0x248c038f,0x2ca80013,0x6fac0154,0x2138022e}},	//   jjem_, chad_, _টুয়ে, хshi_, 
   {{0x3d1c01e1,0x96640209,0x00000000,0x00000000}},	//   _fàwò_, икде, --, --, 
   {{0x64581516,0x610000ef,0xdef40023,0x248c0210}},	//   _abwi, _jēls, _ገዝኣ_, ejem_, 
   {{0x7cf801e4,0xf77000d1,0x780401f0,0x00000000}},	//   _aŭri, غاچ_, _лӯла, --, 
   {{0xd764066d,0x248c0240,0x649401e7,0xf2c4009d}},	//   _پارٹ, gjem_, _sáir, өөли, 
   {{0x64940491,0xb5fc003d,0x07a00064,0x796001e1}},	//   _páir, _raġu, _датн, bàwò, 
   {{0x64581517,0x82900372,0x2ca80156,0x00000000}},	//   _ebwi, يۇنچ, zhad_, --, 
   {{0x7cf80115,0x248c0219,0x6ecc000d,0x00000000}},	//   _eŭri, bjem_, _सदबु, --, 
   {{0x644c00c7,0xe60403b9,0x65b800db,0x2ca80200}},	//   _ñaip, _köşə, _суур_, xhad_, 
   {{0x64940491,0x00000000,0x00000000,0x00000000}},	//   _táir, --, --, --, 
   {{0x64940022,0x02d00345,0x00000000,0x00000000}},	//   _háip, _وتوخ, --, --, 
   {{0x2ca80192,0x6e940184,0xb5fc00e4,0x7094013d}},	//   thad_, _ғину, _taġu, _гайф, 
   {{0xf548044e,0x20d00077,0xbd44007b,0xacf80137}},	//   _ዘይኰነ, záiz_, تنفي, унбу_, 
   {{0x90a41518,0x2ca81519,0x3d1c01e1,0x4ee400c0}},	// [1010] _محکم, rhad_, _pàwò_, _вінз, 
   {{0x2ca8034c,0x00000000,0x00000000,0x00000000}},	//   shad_, --, --, --, 
   {{0xc864151a,0x248c00d7,0x00000000,0x00000000}},	//   итди, yjem_, --, --, 
   {{0xb8e80902,0x659400c7,0x00000000,0x00000000}},	//   афче_, ҩаду, --, --, 
   {{0x6d400436,0x248c0219,0x27e80267,0x3d1c0241}},	//   álaf, vjem_, åan_, _tàwò_, 
   {{0xe5a4151b,0xe6040213,0x27e800df,0xaa94007b}},	//   йили, _döşə, ĥan_, _الآث, 
   {{0x248c151c,0x27e802f0,0xb93400d8,0x00000000}},	//   tjem_, ťan_, _мерј, --, 
   {{0xdb4c0014,0x6494007b,0xd73c01ec,0x00000000}},	//   _تێے_, _cáip, _бiрд, --, 
   {{0x248c151d,0xa9a4151e,0x7de40210,0x41cc000d}},	//   rjem_, _тиңд, _गर्ग_, _सुजस, 
   {{0x248c0427,0x00000000,0x00000000,0x00000000}},	//   sjem_, --, --, --, 
   {{0x64580175,0x248c0010,0xfa98010f,0x63b400c7}},	//   _tbwi, pjem_, ידזש_, шәҧх, 
   {{0x6458151f,0x00000000,0x00000000,0x00000000}},	//   _ubwi, --, --, --, 
   {{0x64481520,0xe3740137,0x00000000,0x00000000}},	//   mgei, _ылды, --, --, 
   {{0x64481521,0xdc340139,0x64a4030d,0x00000000}},	//   lgei, _bäğd, _каçа, --, 
   {{0xd9e40037,0x1dd00a8a,0xb928002b,0x00000000}},	//   _करइत_, _दुखत, bhuṃ_, --, 
   {{0x64481522,0xede401e0,0x63ac00a2,0xdca40395}},	//   ngei, өһөҙ_, _žany, щаби, 
   {{0x1be8013e,0x64481523,0xbd4401d9,0x5ac80798}},	// [1020] удаи_, igei, _ژھرى, глам_, 
   {{0x64480097,0x00000000,0x00000000,0x00000000}},	//   hgei, --, --, --, 
   {{0xd8380323,0x6448017a,0xceb0008f,0x00000000}},	//   гэл_, kgei, _מיז_, --, 
   {{0x63ac010b,0x1784004e,0x8f500345,0x00000000}},	//   _ýanw, йгем, _بنیش, --, 
   {{0xb8d01524,0x19300023,0x97540114,0x50d8010f}},	//   _ओत_, _ኣፍጋኒ, стељ, נקנא, 
   {{0x22bc1525,0x6d400d12,0x00000000,0x00000000}},	//   yňka_, álag, --, --, 
   {{0x649400c6,0x7d1c020c,0x74a800ee,0x64481526}},	//   _páip, nprs, исиң_, fgei, 
   {{0x7338016c,0x644800d4,0x6d401527,0x00000000}},	//   азир_, ggei, šlag, --, 
   {{0x4c9800df,0x00000000,0x00000000,0x00000000}},	//   טשקע, --, --, --, 
   {{0x64481528,0x926801c6,0x00000000,0x00000000}},	//   agei, уриа_, --, --, 
   {{0x86780302,0x64480334,0xd4d40006,0xdb0402d2}},	//   _תרבו, bgei, _лідэ, _ómæg, 
   {{0x7d1c0122,0x27e8012d,0x00000000,0x00000000}},	//   dprs, żane_, --, --, 
   {{0xdc340166,0x00000000,0x00000000,0x00000000}},	//   _säğd, --, --, --, 
   {{0x2c74063f,0x52b00137,0xc7b0011a,0x00000000}},	//   _ụd_, _رەجئ, לבר_, --, 
   {{0x2cb81529,0x7094152a,0x6100005f,0xdc340166}},	//   _pmsd_, _макф, _vēlr, _qäğd, 
   {{0xdc340166,0x6ad000cd,0x00000000,0x00000000}},	//   _väğd, तक्र, --, --, 
   {{0x3a380048,0x4054152b,0x1ea800f1,0xdc3400fd}},	// [1030] _bdrp_, _رئيس, _چاپي_, _wäğd, 
   {{0xff5000c6,0x6f1c01f5,0x64480399,0x705401d3}},	//   _أخي_, mpsc, zgei, _اچھا, 
   {{0x6d4008de,0x7c5804da,0x6f1c00a3,0x6448152c}},	//   álad, شلەر_, lpsc, ygei, 
   {{0x6d54002f,0x6f1c0064,0x00000000,0x00000000}},	//   mtza, opsc, --, --, 
   {{0x6d54152d,0x644807de,0x645400e5,0x00000000}},	//   ltza, vgei, őzik, --, 
   {{0x6d54152e,0x89f8152f,0x7ac4026b,0x00000000}},	//   otza, _معزز_, _ессе, --, 
   {{0x6d54152d,0x64481530,0x3b640014,0x00000000}},	//   ntza, tgei, _وێہہ, --, 
   {{0x6d5405f5,0x67d41531,0x60cc0115,0xe5a40131}},	//   itza, _добу, _ĉamo, йиһи, 
   {{0x1cb00dd4,0xc6481532,0xc538001f,0x66640014}},	//   ྐྲི_, _مجال_, _አይችሉ, _وُرٕ, 
   {{0xadf81533,0x27ec05f5,0x64481534,0x21f8084c}},	//   ंधान_, _izen_, sgei, ихнэ_, 
   {{0x20881535,0x6f1c01f5,0x00000000,0x00000000}},	//   айни_, epsc, --, --, 
   {{0x34941536,0x74b800c0,0x00000000,0x00000000}},	//   _нахр, _луіс_, --, --, 
   {{0x23280108,0x00000000,0x00000000,0x00000000}},	//   _толи_, --, --, --, 
   {{0x71241537,0x6b8c005a,0x61ec01e4,0x6d541538}},	//   _کرول, dxag, _ŝalu, ftza, 
   {{0x7a400248,0xc0d400d1,0x00000000,0x00000000}},	//   _látà, ﻟﯟﻩﺗ, --, --, 
   {{0x27ec1539,0x6fd4012c,0x00000000,0x00000000}},	//   _ozen_, _युकू, --, --, 
   {{0x6d5405f5,0x765c008c,0x7d1c08a4,0x6b8c153a}},	// [1040] atza, _öryg, sprs, gxag, 
   {{0x63ac00a2,0x00000000,0x00000000,0x00000000}},	//   _ýanu, --, --, --, 
   {{0x656001d4,0x27ec153b,0x7ca80092,0x92040055}},	//   _nplh, _azen_, _መፈለግ_, _upāũ, 
   {{0x7a400ca8,0xf984013e,0x00000000,0x00000000}},	//   _bátà, оҳҳо, --, --, 
   {{0x9a8401e0,0x9058011a,0x00000000,0x00000000}},	//   _һуңл, שכנת, --, --, 
   {{0x6560003e,0x27ec153c,0x66cc0419,0x00000000}},	//   _bplh, _dzen_, tĺka, --, 
   {{0x98a4153d,0x27ec153e,0x09e00131,0x1868153f}},	//   _диве, _ezen_, _жорн, _кави_, 
   {{0x2c000327,0x00000000,0x00000000,0x00000000}},	//   _མུཉྩ_, --, --, --, 
   {{0xb9e81540,0xccf00bd4,0xe8e81541,0x00000000}},	//   _ሮሜ_, וכה_, _طرفو_, --, 
   {{0x32540108,0x610000ef,0x00000000,0x00000000}},	//   чвор, _sēlp, --, --, 
   {{0x52a802e5,0x95c400f1,0x00000000,0x00000000}},	//   _छतीस, _بياه, --, --, 
   {{0xe4640790,0x00000000,0x00000000,0x00000000}},	//   _çöpe_, --, --, --, 
   {{0xf31401c0,0x6b8c0429,0x61ec00df,0x88ac00cc}},	//   _эдлэ, xxag, _ŝalt, _কদমক, 
   {{0x6f1c01a4,0x6d54002f,0x00000000,0x00000000}},	//   rpsc, ttza, --, --, 
   {{0x6d54009d,0x6f1c007c,0x00000000,0x00000000}},	//   utza, spsc, --, --, 
   {{0x6d540323,0x6f1c1542,0x8538008d,0xfa24015b}},	//   rtza, ppsc, יגלי, _পাগল_, 
   {{0x6d541543,0x6d4006ea,0x00000000,0x00000000}},	// [1050] stza, álab, --, --, 
   {{0xdb2401b9,0x528000d1,0x8d84014b,0x00000000}},	//   سومی, _ﺩﯦﯖﯩ, _думд, --, 
   {{0x888004fb,0x6f0c1544,0x27ec1545,0xeb9801e0}},	//   ویسن, _huac, _szen_, шиҡ_, 
   {{0x6f0c05d9,0xdddc03e0,0x53c81546,0x00000000}},	//   _kuac, _hapş, ापाश, --, 
   {{0x0a680640,0xdddc0205,0x807c00df,0x00000000}},	//   _крви_, _kapş, ינאצ, --, 
   {{0xe6101547,0x6f0c001e,0x6f04047e,0xa5081548}},	//   رشت_, _muac, _jihc, бека_, 
   {{0x6f0c1549,0x00000000,0x00000000,0x00000000}},	//   _luac, --, --, --, 
   {{0x27ec01c6,0x2b48030a,0xd1cc0023,0x22480116}},	//   _tzen_, ouac_, ቦነት_, әпни_, 
   {{0x6f0c0491,0x69c00010,0x27ec154a,0x4668011c}},	//   _nuac, _žleh, _uzen_, _врем_, 
   {{0xf770154b,0x672801c8,0x6f04154c,0x7eb0002f}},	//   _جاف_, _iwej, _nihc, _zäpf, 
   {{0x6728154d,0x2168154e,0x2b48154f,0x63041550}},	//   _hwej, щини_, huac_, _کوتل, 
   {{0x67281551,0x6f0c1552,0xf4680092,0x00000000}},	//   _kwej, _buac, ዲቀርብ_, --, 
   {{0x337401c6,0x00000000,0x00000000,0x00000000}},	//   _огцр, --, --, --, 
   {{0x6f040399,0x6f0c0092,0x67280083,0xc444006c}},	//   _cihc, _duac, _mwej, _ایکن_, 
   {{0x67280117,0x6f0c003a,0x21a401c0,0x91e01553}},	//   _lwej, _euac, _хийм, _поше, 
   {{0x5f74027a,0x6728054c,0x6f0c1554,0x236c033f}},	//   _فاخر, _owej, _fuac, owej_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [1060] --, --, --, --, 
   {{0x6d400491,0x6f040399,0x0f7808a8,0x99980166}},	//   álac, _gihc, _פריל, gapş_, 
   {{0x58841555,0x236c0477,0x1ea80451,0xdc6801c4}},	//   зыла, hwej_, _ناھي_, _ланд_, 
   {{0x67281556,0x3f8001e4,0x00000000,0x00000000}},	//   _bwej, _kriu_, --, --, 
   {{0x7c241557,0xebb80882,0x6f04009a,0xc7a00b59}},	//   mbir, teḥ_, _yihc, ницк, 
   {{0x7c241558,0x6728025c,0x75280175,0xd65c02dd}},	//   lbir, _dwej, _pwdz, _мiнд, 
   {{0x7c241559,0x00000000,0x00000000,0x00000000}},	//   obir, --, --, --, 
   {{0x7c24155a,0x6728031c,0x49380375,0xe3b8002d}},	//   nbir, _fwej, _לגלו, rbűn_, 
   {{0x7c240e14,0x12e4155b,0x00000000,0x00000000}},	//   ibir, зінг, --, --, 
   {{0x0bb40375,0x6f0c155c,0x7c24155d,0x1d340023}},	//   פלים_, _ruac, hbir, _ክግንዘ, 
   {{0x3f80155e,0x6f0c0051,0x00000000,0x00000000}},	//   _ariu_, _suac, --, --, 
   {{0x3f80068c,0x6b8803b2,0xd0a80107,0xb64802dd}},	//   _briu_, _áegg, стод_, _ﻋﻨ_, 
   {{0x7c24155f,0x6f0c1560,0x3f801561,0x6728031c}},	//   dbir, _quac, _criu_, _xwej, 
   {{0x3f800a73,0x6f04014f,0x6f0c0051,0xdcec00b8}},	//   _driu_, _qihc, _vuac, _ījān, 
   {{0xa2d81562,0x51841563,0x6f04047e,0x6c8400f1}},	//   नकर्, _хула, _vihc, ولسم, 
   {{0xfd7405f5,0x6f0c1564,0x2b48005a,0xdddc00a2}},	//   элсэ, _tuac, tuac_, _wapş, 
   {{0xdddc1565,0x3f801566,0x7864007f,0x6f04014f}},	// [1070] _tapş, _griu_, _mčvč, _tihc, 
   {{0x7c241567,0x0dc81568,0x67281569,0x00000000}},	//   abir, _гуми_, _rwej, --, 
   {{0x7c24156a,0x7eb000a2,0x67280327,0xad4000f7}},	//   bbir, _däpd, _swej, _جۉزۉ, 
   {{0x7c2403e0,0xec34010f,0x00000000,0x00000000}},	//   cbir, _קאָר_, --, --, 
   {{0x3b64156b,0xe738156c,0x66cc0419,0x00000000}},	//   _първ, цел_, bĺkl, --, 
   {{0x0a680798,0x00000000,0x00000000,0x00000000}},	//   _урми_, --, --, --, 
   {{0x5550156d,0xdaa0075e,0x00000000,0x00000000}},	//   نپور, _جەلپ, --, --, 
   {{0x672804ba,0x3fbc00d1,0x236c0210,0x00000000}},	//   _twej, ﻧﻼﺭﻧ, twej_, --, 
   {{0x7eb0023a,0xe3b8156e,0x00000000,0x00000000}},	//   _häpe, юби_, --, --, 
   {{0x21a40131,0x236c0de2,0x7eb001f4,0x00000000}},	//   диом, rwej_, _käpe, --, 
   {{0x7c24156f,0xa0680276,0x854411ca,0xe1f001b9}},	//   ybir, оана_, _хэзе, کسک_, 
   {{0x3f801570,0x7eb001b8,0x7c241571,0xa878008f}},	//   _priu_, _mäpe, xbir, קאָר, 
   {{0x2d800055,0x7f04010b,0x7eb01572,0x13a80345}},	//   _arhe_, нҗид, _läpe, _ونمی_, 
   {{0xf3f40831,0x442c1573,0x76941574,0x1d081575}},	//   _яңы_, _heg_, _bàyy, жеви_, 
   {{0x442c1576,0x386002ce,0xaf3404d3,0x7eb01577}},	//   _keg_, ŵiri_, ووێژ, _näpe, 
   {{0x442c1578,0x7c240a49,0x3cf8033f,0xa3e00073}},	//   _jeg_, ubir, ंगें_, _धडा_, 
   {{0x442c1579,0x7c24157a,0x88d0009e,0x5f44004b}},	// [1080] _meg_, rbir, ়তাক, _غندل, 
   {{0x7c24157b,0x4a4003b7,0xda64157c,0x00000000}},	//   sbir, кнув, باري, --, 
   {{0x9984157d,0x2d800055,0x442c0254,0x00000000}},	//   بلاو, _grhe_, _oeg_, --, 
   {{0x442c157e,0x6b8801a6,0x28a402dd,0x7c24157f}},	//   _neg_, _šege, ншіг, qbir, 
   {{0x69d41580,0x3c4800f1,0x158c00d1,0x27e8025c}},	//   _exze, _وګړی_, _ﻛﯧﺴﯩ, żann_, 
   {{0x442c1581,0x3cf00024,0xa3e00210,0x00000000}},	//   _aeg_, šovė_, _धड़_, --, 
   {{0x442c1582,0x98541086,0x8a00004e,0x00000000}},	//   _beg_, _оташ, _азре, --, 
   {{0x442c0070,0x33741583,0xc4f400db,0x06800304}},	//   _ceg_, егир, وعيا_, егән, 
   {{0x442c1584,0x92681585,0xd24400ee,0x1670014b}},	//   _deg_, орна_, мэни, _ақлр, 
   {{0x39580218,0xc5a400b2,0x46441586,0x442c1587}},	//   _kqrs_, _ڪڏهن_, _озун_, _eeg_, 
   {{0x70541473,0x442c1588,0x00000000,0x00000000}},	//   ىندا, _feg_, --, --, 
   {{0xc5a400b2,0x442c1589,0x3cf8033f,0x312400cf}},	//   _تڏهن_, _geg_, ंगों_, мдүг, 
   {{0xcee8158a,0x9f4c01e1,0x00000000,0x00000000}},	//   قرآن_, _ńfò_, --, --, 
   {{0x442c0cf9,0x8d74158b,0x2d800010,0x00000000}},	//   _zeg_, وازا, _prhe_, --, 
   {{0x442c158c,0x00000000,0x00000000,0x00000000}},	//   _yeg_, --, --, --, 
   {{0x442c0175,0x7eb00108,0x00000000,0x00000000}},	//   _xeg_, _räpe, --, --, 
   {{0x3eb40118,0x6af400d8,0x00000000,0x00000000}},	// [1090] _šatů_, езаф, --, --, 
   {{0x7eb00793,0x76940de2,0xe73800ee,0x271c00eb}},	//   _päpe, _tàyy, җек_, _নিলো_, 
   {{0x2d800004,0xab6c001f,0x6e34022e,0x14dc00bc}},	//   _urhe_, ስተዋል_, mazb, मवाण, 
   {{0x1cb0025c,0x6e3401a6,0xf990007b,0xab9400f3}},	//   ྐྲད_, lazb, جبك_, _замљ, 
   {{0x442c158d,0xfeb804fb,0x2ca805b1,0xcb44010a}},	//   _reg_, _رایت_, mkad_, _юхни, 
   {{0x442c158e,0x2ca801e3,0xa50800c0,0xdb24158f}},	//   _seg_, lkad_, пека_, _سوفی, 
   {{0x442c1590,0x26c81591,0xc5e400eb,0xe45000ae}},	//   _peg_, đao_, গেনা_, هضة_, 
   {{0x2ca81592,0xb8f400eb,0x00000000,0x00000000}},	//   nkad_, _সী_, --, --, 
   {{0x442c1593,0x29101594,0xe3b000c6,0x6e3401c4}},	//   _veg_, _huza_, طرة_, kazb, 
   {{0x442c1595,0x29101596,0x7538003e,0x65941597}},	//   _weg_, _kuza_, bsvz, _пазу, 
   {{0x442c1598,0x2ca81599,0x2910159a,0x80dc000d}},	//   _teg_, kkad_, _juza_, नवले, 
   {{0x442c004e,0x2ca801e3,0x00000000,0x00000000}},	//   _ueg_, jkad_, --, --, 
   {{0xc00003f4,0x2ca8079b,0x6d40159b,0x2910159c}},	//   ূর্ণ_, dkad_, álan, _luza_, 
   {{0x5398159d,0x29100100,0xabd80150,0x00000000}},	//   _מינו, _ouza_, _ﺃﺼﻘﺎ, --, 
   {{0xd24c159e,0x29100223,0x427802d3,0x2ca8007f}},	//   _انى_, _nuza_, _እሙናት_, fkad_, 
   {{0xfe780024,0x00000000,0x00000000,0x00000000}},	//   žį_, --, --, --, 
   {{0x60c4159f,0xcb6415a0,0xdca415a1,0x00000000}},	// [10a0] mikm, нате_, _ҷани, --, 
   {{0x291015a2,0x38c006be,0x8c4003e0,0x00000000}},	//   _buza_, _içrə_, ışab, --, 
   {{0xdca415a3,0x291015a4,0x8e5400d9,0xb8e400f1}},	//   _зани, _cuza_, _אייג_, نګره, 
   {{0x60c415a5,0x2ca8049f,0x99880118,0x1cb80066}},	//   nikm, ckad_, _webů_, _راجب_, 
   {{0x6100003a,0x481000d4,0xab6c0092,0x00000000}},	//   _cœli, уміс, ስተውል_, --, 
   {{0x29100099,0x7e7c05be,0x60c40986,0x00000000}},	//   _fuza_, ndrp, hikm, --, 
   {{0x291007f5,0x55040276,0x00000000,0x00000000}},	//   _guza_, нчиа, --, --, 
   {{0x09e015a6,0x60c415a7,0x20d00135,0x73c40352}},	//   _сосн, jikm, wġin_, кәле, 
   {{0x291015a8,0xc68c01d3,0xe70805a9,0xb7940345}},	//   _zuza_, _گِل_, ستۇن_, _جڤات, 
   {{0xdb080066,0x291015a9,0x4b78011a,0x00000000}},	//   ènèh, _yuza_, לאפו, --, 
   {{0x60c415aa,0xc68c0a81,0xd46815ab,0xefd402d3}},	//   fikm, _دِل_, _ниже_, ከይድ_, 
   {{0x60c415ac,0x25a00112,0x00000000,0x00000000}},	//   gikm, ähle_, --, --, 
   {{0x6e3401c4,0x62200137,0x00000000,0x00000000}},	//   tazb, دۉۉل, --, --, 
   {{0xc0000c58,0x00000000,0x00000000,0x00000000}},	//   ূৰ্ণ_, --, --, --, 
   {{0x6e3415ad,0xc2780302,0x60c415ae,0xad240075}},	//   razb, _מרגי, bikm, ئىرى, 
   {{0x291015af,0x60c4029f,0x20d00327,0x6fb415b0}},	//   _ruza_, cikm, nġil_, _لمبا, 
   {{0x2910098d,0x2ca815b1,0x7bc015b2,0x7f840592}},	// [10b0] _suza_, rkad_, _žmur, _ملين, 
   {{0x2ca815b3,0xed500014,0x6e3403b9,0x00000000}},	//   skad_, _پھس_, qazb, --, 
   {{0xba74021f,0xe8580024,0x00000000,0x00000000}},	//   داقت, даеш_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7eb000b0,0xe694034b,0x973015b4,0x00000000}},	//   _häpa, киды, لکلا, --, 
   {{0x60c415b5,0x291015b6,0x7eb00037,0xe570007b}},	//   zikm, _tuza_, _käpa, لطب_, 
   {{0x60c415b7,0x00000000,0x00000000,0x00000000}},	//   yikm, --, --, --, 
   {{0x38c801c0,0x00000000,0x00000000,0x00000000}},	//   _зуун_, --, --, --, 
   {{0x7eb00037,0x00000000,0x00000000,0x00000000}},	//   _läpa, --, --, --, 
   {{0x2b480129,0xf65000ec,0x6ecc06e3,0x00000000}},	//   irac_, _هئم_, _सदगु, --, 
   {{0x60c415b8,0x7eb00254,0x00000000,0x00000000}},	//   tikm, _näpa, --, --, 
   {{0x2b4815b9,0x622000d1,0x00000000,0x00000000}},	//   krac_, _ھۈجە, --, --, 
   {{0x2bdc01d9,0x60c415ba,0x3f840316,0x6d4002f0}},	//   _मडगा, rikm, ímu_, šlal, 
   {{0x60c415bb,0x2b4815bc,0xc32c0014,0x3af40254}},	//   sikm, drac_, _نٕچ_, käpa_, 
   {{0x60c402e2,0x5c5415bd,0xda700050,0x00000000}},	//   pikm, ктаф, یُر_, --, 
   {{0x9f8400c7,0x8c4015be,0x5cf40212,0xdcb015bf}},	//   _агид, иесе, тягу, جىر_, 
   {{0x25b80213,0x2b4815c0,0x00000000,0x00000000}},	// [10c0] _əsla_, grac_, --, --, 
   {{0x0f34008f,0x00000000,0x00000000,0x00000000}},	//   _שריט_, --, --, --, 
   {{0x386415c1,0x9d380134,0x8c380112,0x00000000}},	//   _pbmr_, _ɛyɛɛ_, _soße, --, 
   {{0xdca415c2,0x8d7415c3,0x2b4815c4,0xc3240011}},	//   _рами, _شاپا, brac_, _মিনি_, 
   {{0x2b48003a,0x81b40154,0xdb0800ae,0x00000000}},	//   crac_, চপি_, únói, --, 
   {{0xad240345,0x00000000,0x00000000,0x00000000}},	//   _جریو, --, --, --, 
   {{0xceb0025f,0x60d400e4,0xd94400f0,0x46a000d8}},	//   שיו_, _ojym, _јеби, рајв, 
   {{0x3804014b,0x14c800c7,0x00000000,0x00000000}},	//   _бобҳ, ьыли_, --, --, 
   {{0xf9f40154,0x833001c6,0x00000000,0x00000000}},	//   _জলিল_, аных, --, --, 
   {{0x73c40184,0x78a0047e,0x60d400a2,0x00000000}},	//   кәһе, _homv, _ajym, --, 
   {{0x78a015c5,0xc1b401c6,0x00000000,0x00000000}},	//   _komv, влэх_, --, --, 
   {{0x934415c6,0x823002d3,0x660c0882,0x2b480129}},	//   _анде, _ጻዕርታ, śakt, yrac_, 
   {{0x78a002ce,0x628c0332,0xddcc00c0,0x00000000}},	//   _momv, ánoí, bebū, --, 
   {{0x78a015c7,0x2b48067c,0x00000000,0x00000000}},	//   _lomv, vrac_, --, --, 
   {{0x2d840914,0x2b480067,0x60dc007f,0x00000000}},	//   íle_, wrac_, ōsma, --, 
   {{0x78a00944,0x60d40023,0x2b4815c8,0x00000000}},	//   _nomv, _gjym, trac_, --, 
   {{0x6100003a,0x80a415c9,0x09c800dc,0x00000000}},	// [10d0] _cœlu, _خمين, ऽप्य, --, 
   {{0x7eb015ca,0x2b4815cb,0x9408016b,0x6144129d}},	//   _täpa, rrac_, ɔbɔ_, _شىۋە, 
   {{0x78a015cc,0x1af00154,0x00000000,0x00000000}},	//   _bomv, _অংশে_, --, --, 
   {{0x78a00491,0xa52400d1,0xdd9000ec,0x3af40022}},	//   _comv, қмид, _اوٽ_, räpa_, 
   {{0x78a015cd,0x46300124,0x00000000,0x00000000}},	//   _domv, иҭар, --, --, 
   {{0xc9840022,0xf624009f,0x3af40139,0x00000000}},	//   _иуби, لّهُ, läpn_, --, 
   {{0x090400c7,0x3af40309,0xa2e415ce,0xe568009d}},	//   _ачам, qäpa_, ғонд, хийд_, 
   {{0x57b015cf,0xb88400db,0x00000000,0x00000000}},	//   рбәт, _кууй, --, --, 
   {{0x68e815d0,0xa0a415d1,0x386000a3,0x363400db}},	//   _iked, ҳанд, òire_, ارۇس, 
   {{0x27ec15d2,0x78a015d3,0x625815d4,0x00000000}},	//   _iyen_, _zomv, хрир_, --, 
   {{0xa0a415d5,0x245415d6,0x68e80083,0x27ec15d7}},	//   ганд, _مناس, _kked, _hyen_, 
   {{0xe3b80108,0x00000000,0x00000000,0x00000000}},	//   _плеч_, --, --, --, 
   {{0x6458009a,0x27ec007f,0x934403cc,0x64a40022}},	//   _icwi, _jyen_, _مىنۇ, _иаҧа, 
   {{0x290c01ee,0x63a815d8,0x27ec15d9,0x00000000}},	//   _liea_, myen, _myen_, --, 
   {{0xdef815da,0x27ec15db,0x68e815dc,0x925414b7}},	//   дың_, _lyen_, _oked, _сајт_, 
   {{0x290c0069,0x27ec0789,0x68e801e1,0x7c2400c7}},	//   _niea_, _oyen_, _nked, рзаҧ, 
   {{0x27ec15dd,0x78a003cd,0x6458045a,0x7b840116}},	// [10e0] _nyen_, _romv, _mcwi, جازە, 
   {{0x290c0b45,0x78a015de,0x68e815df,0xf8ac15e0}},	//   _aiea_, _somv, _aked, चस्प, 
   {{0x7eb002b5,0x27ec02e2,0x78a00161,0x63a80097}},	//   _häpo, _ayen_, _pomv, hyen, 
   {{0xd7f815e1,0x27ec15e2,0x26c40407,0xeaf807a7}},	//   нул_, _byen_, _amlo_, ىرەت_, 
   {{0x63a815e3,0x96e815e4,0x78a00165,0x97c4008e}},	//   jyen, нька_, _vomv, ыйде, 
   {{0x68e815e5,0x27ec002d,0x78a015e6,0x00000000}},	//   _eked, _dyen_, _womv, --, 
   {{0x1c1c0d79,0x00000000,0x00000000,0x00000000}},	//   युअल_, --, --, --, 
   {{0x27ec15e7,0x00000000,0x00000000,0x00000000}},	//   _fyen_, --, --, --, 
   {{0x63a815e8,0x82f405d9,0x939415e9,0x80e000eb}},	//   gyen, گريز_, اجعا, নগঞ্, 
   {{0x64580042,0x201000e5,0x37e4022e,0x00000000}},	//   _ecwi, _agyi_, _боғг, --, 
   {{0x63a8017a,0x68e802d0,0x82f401e2,0x461001e2}},	//   ayen, _yked, دريز_, _اومر, 
   {{0x63a815ea,0x7a4800e2,0x6fb415eb,0x20d0031c}},	//   byen, lītē, لمجا, nġih_, 
   {{0x63a81423,0x4fc415ec,0xb3d40032,0x32e00432}},	//   cyen, усна, _әйҙә, _açyş_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xccf815ed,0x626415ee,0x7eb000c5,0x8c6415ef}},	//   ећа_, _خانق, _täpn, лтад, 
   {{0x7b640daf,0x61f415f0,0x27e815f1,0x953c0092}},	//   әтте, üzle, żani_, _አይነተ, 
   {{0x7afc01ab,0xfce815f2,0xed5001d9,0x00000000}},	// [10f0] _bhrt, افقي_, _ژھر_, --, 
   {{0x68e815f3,0x290c0032,0x27ec15f4,0x7afc0306}},	//   _sked, _siea_, _ryen_, _chrt, 
   {{0x63a815f5,0x7afc0ba7,0xe94415f6,0x27ec0100}},	//   zyen, _dhrt, شرای, _syen_, 
   {{0x27ec007f,0x7afc002f,0x39e8010b,0x2bdc012d}},	//   _pyen_, _ehrt, уьун_, _यशपा, 
   {{0x68e80254,0xae180037,0x00000000,0x00000000}},	//   _vked, _दलान_, --, --, 
   {{0x63a815f7,0x893415f8,0x27ec02e2,0xdd0c013d}},	//   vyen, _معرا, _vyen_, _kışn, 
   {{0x290c15f9,0x63a8017a,0x00000000,0x00000000}},	//   _tiea_, wyen, --, --, 
   {{0x63a815fa,0x68e815fb,0x9f480200,0x00000000}},	//   tyen, _uked, çkës_, --, 
   {{0xe2980598,0x27ec004d,0x6d4000d7,0x00000000}},	//   вап_, _uyen_, šlah, --, 
   {{0x63a815fc,0x26c401e2,0x52a4023a,0xf77003c7}},	//   ryen, _umlo_, ивым_, _عاق_, 
   {{0x63a815fd,0x7eb015fe,0xa3e001f9,0x200c0248}},	//   syen, _däpl, _धडक_, _ńfi_, 
   {{0x63a815ff,0x6458014b,0x60dc007f,0xd598011a}},	//   pyen, _ucwi, čsmo, _בבעל, 
   {{0x2d841600,0x63a80200,0x7798010a,0x98bc0055}},	//   ælen_, qyen, _укăр_, _ūtī_, 
   {{0x27e80209,0x7eb00139,0xe2c81601,0xe29810fc}},	//   ýany_, _gäpl, _جوتو_, _јак_, 
   {{0x7a400008,0x9c580139,0x00000000,0x00000000}},	//   hátí, кшау_, --, --, 
   {{0xdddc02b5,0xdca401b9,0x16d000dc,0x9c241602}},	//   _hapū, шаби, _तद्ब, рдад, 
   {{0x9b441603,0x7a401604,0x2c000574,0x5b34084c}},	// [1100] شناو, játí, लेलं_, рэбу, 
   {{0x62801605,0xcb641606,0x2ee0084d,0x00000000}},	//   ndlo, рафе_, पकृत, --, 
   {{0x2d840a64,0x81e409bd,0x00000000,0x00000000}},	//   ålet_, _মৃত_, --, --, 
   {{0x57a41607,0x62800142,0x25e80456,0x00000000}},	//   ишла, hdlo, _छड़ी_, --, 
   {{0xd7041608,0x00000000,0x00000000,0x00000000}},	//   азди, --, --, --, 
   {{0x7d041609,0x63ac0209,0x62800d27,0xdddc0055}},	//   lmis, _ýany, jdlo, _napū, 
   {{0xc81c0020,0x0570075e,0x6280160a,0x7d041577}},	//   ስትመን, قايد, ddlo, omis, 
   {{0x48e0160b,0x6d4000c6,0x3a38160c,0x99980374}},	//   _досв, álai, _herp_, hapū_, 
   {{0x7d04160d,0x999804fe,0x7eb00793,0xf48403e6}},	//   imis, kapū_, _päpl, لاکی, 
   {{0x6d40143f,0x7d04160e,0x628001f5,0x5184160f}},	//   šlai, hmis, gdlo, аума, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x62801610,0xae1805d7,0xd0181086,0x324401e0}},	//   adlo, _दलहन_, ъфо_, шеүг, 
   {{0x7d04007d,0x7eb01611,0x00000000,0x00000000}},	//   dmis, _täpl, --, --, 
   {{0xb8f803bd,0x7d041612,0x00000000,0x00000000}},	//   _ོམ_, emis, --, --, 
   {{0x02f804ae,0x7d04005c,0xdd0c0139,0x00000000}},	//   _שלומ, fmis, _qışn, --, 
   {{0x7d041613,0xb0341614,0xf004014b,0x00000000}},	//   gmis, _униш, _гӯги, --, 
   {{0x80240014,0xf07800c7,0xcee8006c,0x00000000}},	// [1110] _بر٘م, _аиқә_, _لردن_, --, 
   {{0x7d04049b,0xe84002d3,0x2d8401bf,0xc9840124}},	//   amis, _ከምዘሎ, åles_, иуеи, 
   {{0xacb400aa,0x3a3809b1,0x7d041615,0x76580175}},	//   _همدغ, _derp_, bmis, dgvy, 
   {{0x6d541616,0x7f841617,0x620400ac,0xf68801d3}},	//   muza, _الین, ürlə, یننٹ_, 
   {{0x3cf410f7,0x7bd80365,0x386001ab,0x6280015d}},	//   ंतरे_, şvur, òira_, ydlo, 
   {{0x36c400d4,0x00000000,0x00000000,0x00000000}},	//   обіг, --, --, --, 
   {{0x20d00038,0x98580882,0x6d54036e,0xf9d40209}},	//   lšie_, ṇāt_, nuza, _дорэ, 
   {{0x6f1c074d,0x3a3801a6,0x21681618,0xdddc1619}},	//   kqsc, _zerp_, қими_, _sapū, 
   {{0x6d54161a,0xc32404c5,0x20d00030,0x158c0131}},	//   huza, _মিহি_, nšie_, _ﻛﯧﺘﯩ, 
   {{0x6d54161b,0x62800280,0x66e80107,0x00000000}},	//   kuza, udlo, _субҳ_, --, 
   {{0x6280161c,0x7d04161d,0x20d001f1,0xe5f4161e}},	//   rdlo, ymis, hšie_, _اكاد, 
   {{0x6d54161f,0x34941620,0x2418023a,0x20d000d7}},	//   duza, _махр, _соды_, kšie_, 
   {{0x20d00038,0xa0a41621,0xdfd01622,0x25600429}},	//   jšie_, _ҳайд, سيس_, lól_, 
   {{0x6d541623,0x20d000d0,0xb37001d9,0x00000000}},	//   fuza, dšie_, _کۯیش, --, 
   {{0x7d04033d,0xa0a41624,0x6d541625,0x25601626}},	//   tmis, _гайд, guza, nól_, 
   {{0x3a381627,0x7d041628,0x00000000,0x00000000}},	//   _serp_, umis, --, --, 
   {{0x2d841477,0x4a000327,0x5e6000cf,0x00000000}},	// [1120] åler_, _མཛུལ_, _ىچسە, --, 
   {{0x7f440d04,0x6d541629,0x7d1c0175,0xd1f40023}},	//   _iviq, buza, pqrs, ለውቲ_, 
   {{0x5d840597,0xd238008f,0x25600321,0x7d04162a}},	//   _الجل, רגעל, jól_, pmis, 
   {{0x3a380926,0x2560011f,0x20d000d0,0x82f40327}},	//   _werp_, dól_, bšie_, _པེའུ_, 
   {{0x3a380b21,0x6da402a8,0x6d400bcd,0x69d80112}},	//   _terp_, nɗan, álav, ßwer, 
   {{0x6da403f9,0x7eb0010e,0x00000000,0x00000000}},	//   iɗan, _säpj, --, --, 
   {{0x237c0ac5,0xaadc0574,0x6d400153,0xed6c0092}},	//   _aswj_, _मदतक, šlav, _ሴክተር_, 
   {{0x38c80345,0x00000000,0x00000000,0x00000000}},	//   _ئاسی_, --, --, --, 
   {{0x6d54162b,0xd628014b,0x00000000,0x00000000}},	//   zuza, _бозе_, --, --, 
   {{0x2560066d,0x273c02ea,0x6d54162c,0x53e40022}},	//   ból_, _wâná_, yuza, ицҿа, 
   {{0x76480cfd,0x201c00bc,0x2560007b,0x4a98010f}},	//   _iddy, ětin_, cól_, אייג, 
   {{0x9f50011f,0x65b8004e,0x09f4011a,0x00000000}},	//   _iyyê_, _туур_, ממים_, --, 
   {{0x6d54162d,0x73c400fb,0x00000000,0x00000000}},	//   wuza, _фәйе, --, --, 
   {{0x6d54162e,0x20d001a2,0x12180006,0xd1b80372}},	//   tuza, všie_, _сюды_, _ماعا_, 
   {{0xf15801c0,0x55f400eb,0x00000000,0x00000000}},	//   _тийш_, _চলুক_, --, --, 
   {{0x6d54162f,0x853800c8,0x20d000d0,0x4ba4004e}},	//   ruza, טגלי, tšie_, бөгү_, 
   {{0x76481630,0x7b141631,0x3174012d,0x4ee40064}},	// [1130] _oddy, здух, ńczę_, _гінз, 
   {{0x6d540230,0x70541632,0x20d001f1,0x00000000}},	//   puza, _انکا, ršie_, --, 
   {{0x25600429,0x6e9400f1,0xe9781633,0xfeb8007b}},	//   xól_, _هلکا, рбеш_, _دايت_, 
   {{0x76480cfd,0x6d441634,0x20d001a2,0x00000000}},	//   _addy, _ivha, pšie_, --, 
   {{0x65601635,0x752800e2,0x2cb80f85,0x2560007f}},	//   _sqlh, _atdz, _ilsd_, wól_, 
   {{0xf7701636,0x2560066d,0xc3240729,0x7f3c008f}},	//   عان_, tól_, _মিলি_, נעוו, 
   {{0x79a40046,0x0ba80137,0x00000000,0x00000000}},	//   _ерте, _شاڭى_, --, --, 
   {{0x25601637,0x76480731,0x09bc0154,0x00000000}},	//   ról_, _eddy, _আশপা, --, 
   {{0xc10405f5,0x87d80014,0x8c38002f,0x6304009a}},	//   үүлл, _صبرس_, _roßl, يوبل, 
   {{0x67280003,0xc6d401d3,0x00000000,0x00000000}},	//   _itej, _اترت, --, --, 
   {{0x21681638,0xe0d81639,0xa0c41541,0x2a300023}},	//   шини_, иво_, قيدو, _ብኢትዮ, 
   {{0x237c0457,0x6728025c,0x98b40135,0x00000000}},	//   _tswj_, _ktej, ġgħu_, --, 
   {{0x443c163a,0xe298163b,0x67280135,0xd12c01d9}},	//   mau_, _вал_, _jtej, _یمو_, 
   {{0x443c163c,0x6728163d,0x6304163e,0x7eb00254}},	//   lau_, _mtej, _بوتل, _käpi, 
   {{0xa0a4163f,0xde0402dd,0x443c0076,0x00000000}},	//   _макд, іпби, oau_, --, 
   {{0x1b4800cf,0x00000000,0x00000000,0x00000000}},	//   изби_, --, --, --, 
   {{0x6d441640,0x67281641,0x7eb002f6,0x443c0c1f}},	// [1140] _evha, _ntej, _läpi, iau_, 
   {{0x443c1642,0xe8c4038f,0x3f801132,0x1e3400db}},	//   hau_, _གཏུག, _isiu_, _بةةج, 
   {{0x443c1643,0xdca41644,0x67281645,0x6d401646}},	//   kau_, _дани, _atej, álat, 
   {{0x18681647,0x443c1648,0x4524031c,0xa3b80d79}},	//   ради_, jau_, _ལྕེར_, घना_, 
   {{0x443c1649,0xd708164a,0x473002bf,0x7c24164b}},	//   dau_, анде_, дніс, mcir, 
   {{0x443c164c,0xdddc1165,0x00000000,0x00000000}},	//   eau_, _japů, --, --, 
   {{0x443c164d,0x672801f2,0x7c24011c,0x00000000}},	//   fau_, _etej, ocir, --, 
   {{0x443c164e,0x7c24164f,0x00000000,0x00000000}},	//   gau_, ncir, --, --, 
   {{0x7c2401a6,0x25b803e3,0xa8a400ae,0x00000000}},	//   icir, _əsli_, _عصفو, --, 
   {{0x443c0421,0xe7d4006c,0x76481650,0x67440118}},	//   aau_, _عملگ, _uddy, řují, 
   {{0x443c1651,0x69c01652,0x3f801653,0x8af80a1e}},	//   bau_, _žlez, _asiu_, שהיי, 
   {{0xa0200205,0x7c2400d7,0x00000000,0x00000000}},	//   _çöla, jcir, --, --, 
   {{0x7c241654,0x64d8008f,0xbfa81655,0xbf3412e7}},	//   dcir, _פֿעס, отре_, мнящ, 
   {{0x69c00254,0x00000000,0x00000000,0x00000000}},	//   _üleg, --, --, --, 
   {{0xac940cc9,0x7db4007b,0xccc80798,0x00000000}},	//   павш, وصفا, аѓал_, --, 
   {{0x6d4400b5,0x00000000,0x00000000,0x00000000}},	//   _vvha, --, --, --, 
   {{0x1ea800ec,0x3b640395,0x00000000,0x00000000}},	// [1150] _ڇاپي_, дъхв, --, --, 
   {{0x443c1656,0x6384013c,0xba9802bf,0x6d401657}},	//   zau_, lîná, овує_, álas, 
   {{0x443c1658,0x6728038e,0x20d001f1,0x2cb80204}},	//   yau_, _stej, lšia_, _tlsd_, 
   {{0x2d801659,0x5d7800c8,0x443c165a,0x7eb0165b}},	//   _ishe_, _פארק, xau_, _räpi, 
   {{0x443c165c,0x7b64165d,0x8b64165e,0x20d000d0}},	//   vau_, _отре, _باجم, nšia_, 
   {{0x443c165f,0x3ddc0183,0x00000000,0x00000000}},	//   wau_, _ধৰিল, --, --, 
   {{0x443c1660,0x20d00030,0xeaf8012c,0xe5780c60}},	//   tau_, hšia_, ्गीत_, ёзи_, 
   {{0x443c0ef0,0x67280135,0x38c8009d,0x00000000}},	//   uau_, _ttej, _дуун_, --, 
   {{0x443c1661,0x20d001f1,0x67281662,0x00000000}},	//   rau_, jšia_, _utej, --, 
   {{0x443c1663,0x7eb01664,0x20d000d0,0x00000000}},	//   sau_, _täpi, dšia_, --, 
   {{0x443c1665,0xc0e8001f,0x69c01666,0x00000000}},	//   pau_, _መማር_, _üled, --, 
   {{0x443c0286,0xe0d800d8,0x00000000,0x00000000}},	//   qau_, свм_, --, --, 
   {{0x2d801667,0xa29400d6,0x7c241668,0xf3801669}},	//   _ashe_, _наді, vcir, _ағым, 
   {{0xca34166a,0x2260012d,0x00000000,0x00000000}},	//   _koʝu_, órkę_, --, --, 
   {{0x7c2401f5,0xe29801af,0x59740092,0x00000000}},	//   tcir, _ваһ_, _ጽሁፎች_, --, 
   {{0xa0a40022,0x0d8001c6,0x20d00419,0x6c74009d}},	//   _хаид, элсн, bšia_, муух, 
   {{0x6d4008a7,0x5f44166b,0x2d80036e,0x9058011a}},	// [1160] álar, _عندل, _eshe_, _הכפת, 
   {{0x7c24166c,0xca8001c6,0xaae40472,0x2bdc166d}},	//   scir, нгуй, وسلو, _यशरा, 
   {{0xca340069,0x7c240327,0x00000000,0x00000000}},	//   _noʝu_, pcir, --, --, 
   {{0x76440b45,0x00000000,0x00000000,0x00000000}},	//   ɗiyy, --, --, --, 
   {{0x6b8801a6,0x8d9001d5,0x00000000,0x00000000}},	//   _šegv, _قلیش, --, --, 
   {{0xd9440372,0x3ca40ed1,0x7bc4166e,0x00000000}},	//   _неги, ﺎﻳﺴﻰ_, mziu, --, 
   {{0x09e0166f,0xfa2c0327,0x7bc4002f,0x00000000}},	//   _зорн, _ཧྥརན_, lziu, --, 
   {{0x89d80375,0x603c037e,0x00000000,0x00000000}},	//   _החלי, _ｇmai, --, --, 
   {{0x7bc41670,0x00000000,0x00000000,0x00000000}},	//   nziu, --, --, --, 
   {{0x7eb0000d,0x20d000d0,0x00000000,0x00000000}},	//   _käpu, všia_, --, --, 
   {{0x70541671,0x00000000,0x00000000,0x00000000}},	//   وندا, --, --, --, 
   {{0x69c000c5,0x85980375,0x53a400d8,0x20d000d0}},	//   _ülee, _לשבו, _наеб, tšia_, 
   {{0x70ac0073,0x00000000,0x00000000,0x00000000}},	//   _चवील, --, --, --, 
   {{0x20d01672,0x00000000,0x00000000,0x00000000}},	//   ršia_, --, --, --, 
   {{0x7eb000af,0x1aac00fe,0x7bc40153,0x00000000}},	//   _näpu, ছোৱা, eziu, --, 
   {{0x20d00030,0x66140419,0x00000000,0x00000000}},	//   pšia_, _úzke, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [1170] --, --, --, --, 
   {{0x2d801673,0x6da40198,0x00000000,0x00000000}},	//   _tshe_, nɗak, --, --, 
   {{0x7bc4060a,0x2d80006f,0xfc3001d3,0x00000000}},	//   aziu, _ushe_, ئحہ_, --, 
   {{0x6d541674,0x00000000,0x00000000,0x00000000}},	//   mrza, --, --, --, 
   {{0x7bc41675,0x2cf80490,0x0b8806ed,0x99600118}},	//   cziu, ंतील_, _усни_, _míře_, 
   {{0x6b8c0796,0x6d541676,0xe61000f2,0x00000000}},	//   mvag, orza, پشت_, --, 
   {{0x56901677,0x6b8c1678,0xe57800d4,0x00000000}},	//   тајт, lvag, ізи_, --, 
   {{0xe3b81679,0x6adc0d2c,0x88800214,0x850000d1}},	//   жби_, _मदुर, _سیتن, رۈشن, 
   {{0x69c4167a,0x6b8c167b,0x6d54167c,0xa3b81291}},	//   lzhe, nvag, hrza, تاثر_, 
   {{0x6b8c0d04,0x69c40200,0x00000000,0x00000000}},	//   ivag, ozhe, --, --, 
   {{0x69c4167d,0x6d540034,0x7bc408e5,0xf8c400cd}},	//   nzhe, jrza, zziu, लोकय, 
   {{0x6d541505,0x9424167e,0x69c40489,0x7eb00254}},	//   drza, _قومۇ, izhe, _läpt, 
   {{0x6d54033f,0x9960013a,0xf434004e,0x4fa0167f}},	//   erza, _díře_, _чечэ, вияв, 
   {{0xe29800a8,0x71241680,0x7bc40023,0x128801e2}},	//   _фак_, بریل, vziu, _ومنی_, 
   {{0x6b8c1681,0x6d54012d,0xa068030d,0xe3f801f7}},	//   evag, grza, _дайа_, _اوڇڻ_, 
   {{0x69c41682,0x7bc41683,0xa2d41684,0xeff80023}},	//   dzhe, tziu, यचक्, ለይዎ_, 
   {{0xcb641685,0x69c40dd4,0x09a80eac,0x6b8c1686}},	// [1180] мате_, ezhe, _গেলা, gvag, 
   {{0x9f500589,0x7bc41687,0x7eb00793,0x0f540375}},	//   _czyå_, rziu, _päpu, _קיים_, 
   {{0x58841688,0x6b8c1689,0x7bc404cc,0x9f940588}},	//   дыла, avag, sziu, _хықә, 
   {{0x7e7c0af5,0x7bc41570,0x00000000,0x00000000}},	//   lerp, pziu, --, --, 
   {{0x69c405c7,0x6b8c00ef,0x00000000,0x00000000}},	//   azhe, cvag, --, --, 
   {{0x7e7c0af5,0x07a0026a,0xca80022e,0x20d000c0}},	//   nerp, таљн, еrеn, kšio_, 
   {{0x7e7c168a,0xe97001ec,0x20d00010,0x00000000}},	//   ierp, _مۇلد, všin_, --, 
   {{0x7e7c168b,0xe464062d,0x00000000,0x00000000}},	//   herp, _çöle_, --, --, 
   {{0x46e400fd,0xfa2c0327,0x20c000ae,0x16640114}},	//   ядән_, _ཧྥོན_, _móid_, _овам, 
   {{0xeb9000c8,0x7e7c168c,0xd2580108,0x00000000}},	//   אָט_, jerp, цци_, --, 
   {{0x20d00301,0x6b8c0810,0xca540a7c,0x7eb00108}},	//   ršin_, zvag, וייז_, _läps, 
   {{0x3b180309,0x049000c6,0x20c001e7,0x00000000}},	//   _lirq_, _للمح, _nóid_, --, 
   {{0x8260168d,0x7e7c168e,0x20d000f3,0x7eb001f4}},	//   رهێن, ferp, pšin_, _näps, 
   {{0x7e7c168f,0xdcfc00bc,0x6d541690,0x20d00784}},	//   gerp, _trpě, trza, qšin_, 
   {{0x7eb00793,0x6d541691,0x41c00014,0xfa2c0327}},	//   _räpt, urza, _لٲوِ, _ཧྥེན_, 
   {{0x20c000c6,0x20d002f0,0x8f6400e5,0x00000000}},	//   _cóid_, nšil_, _قلعے_, --, 
   {{0x6b8c1692,0x69c40369,0x8d980092,0xfa3401d5}},	// [1190] uvag, wzhe, ገላቸው_, چرمد, 
   {{0x6b8c1693,0x3b1804cc,0x32c001e1,0x69c40112}},	//   rvag, _cirq_, _fòye_, tzhe, 
   {{0x6b8c1694,0x6ab401e4,0xe854007b,0xf3880051}},	//   svag, _ĉefĵ, فناد, _lợ_, 
   {{0x69c40dd4,0x23b40248,0x4c8001b9,0x807c010f}},	//   rzhe, _jùjú_, _جیرق, ַנוצ, 
   {{0xe7381695,0xf3880016,0x7eb00139,0x69c400e5}},	//   чел_, _nợ_, _täpt, szhe, 
   {{0xdddc1696,0x66041697,0xbb481698,0x99980050}},	//   _hapš, нпла, _زلفن_, _کپٲر_, 
   {{0x4920016c,0xe5701699,0xdddc0064,0x00000000}},	//   _рӯзҳ, اطت_, _kapš, --, 
   {{0x63840124,0x7e7c169a,0x233414a8,0xf3880208}},	//   егиа, zerp, нхор, _bợ_, 
   {{0x7e7c030d,0x4680169b,0x2b4806af,0x4db800cc}},	//   yerp, _ақла, nsac_, _উখোৱ, 
   {{0x1304169c,0x261802ab,0x7e7c009d,0x45a000db}},	//   нный_, _पलटी_, xerp, _لەتك, 
   {{0xd12c169d,0xe1f802d5,0x00000000,0x00000000}},	//   یمی_, яго_, --, --, 
   {{0xa0a40657,0xd36c0214,0x7eb001f4,0x00000000}},	//   хамд, جهی_, _näpr, --, 
   {{0x7e7c169e,0xfd4c0241,0x645c004e,0x20c00332}},	//   terp, _fonọ, òsiu, _róid_, 
   {{0xdcb00ed1,0x7e7c0e78,0x7eb0005b,0x20c00332}},	//   گىر_, uerp, _räps, _sóid_, 
   {{0x7e7c169f,0x224400b5,0x7eb001f4,0xf3880051}},	//   rerp, malk_, _säps, _zợ_, 
   {{0xdcb016a0,0x7e7c16a1,0xd12c16a2,0xa0c400e3}},	//   دىر_, serp, _امي_, _سيخو, 
   {{0x3b18047e,0xfa2c031c,0x6b8816a3,0x9b0416a4}},	// [11a0] _pirq_, _ཧྥུན_, _šegr, езад, 
   {{0x3b1816a5,0x7e7c16a6,0xab780092,0x22440010}},	//   _qirq_, qerp, _የያዘው_, nalk_, 
   {{0x2d84005c,0x2bd40037,0xcee00150,0x00000000}},	//   ælet_, _ठेठा, _сұрқ, --, 
   {{0x7eb0007d,0x224416a7,0x0d8016a8,0x20d008a4}},	//   _täps, halk_, _слюн, kšim_, 
   {{0x2b4816a9,0x20d0151c,0xb7d80451,0xb8d80037}},	//   csac_, jšim_, ڻوڪا_, _छव_, 
   {{0x09bc015b,0xf3880208,0x224416aa,0xd5140241}},	//   _আশরা, _rợ_, jalk_, _ọ̀d, 
   {{0xf3880016,0xceb00375,0xd6c407d6,0xaa640139}},	//   _sợ_, ריו_, ومچی, _шерһ, 
   {{0xd3a416ab,0x69c000c5,0x3374013e,0x00000000}},	//   ероп, _ülea, вгир, --, 
   {{0x850016ac,0x20d002f0,0x00000000,0x00000000}},	//   دوين, ršil_, --, --, 
   {{0xf38807ae,0x00000000,0x00000000,0x00000000}},	//   _vợ_, --, --, --, 
   {{0x20d002fb,0xf48416ad,0x25a00112,0xfbe400cc}},	//   pšil_, _لاشی, ählt_, _মৰমত, 
   {{0x6adc16ae,0x20d00010,0x2b480076,0x00000000}},	//   _मद्र, bšim_, ysac_, --, 
   {{0x73c416af,0x22440373,0xb4cc10fa,0x60d4007f}},	//   _шәке, balk_, रफी_, èzma, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7eb0014a,0x20c00332,0xe2a80330,0x441001af}},	//   _päpr, _dóib_, _تانن_, _ифәт, 
   {{0xfaa401b9,0xd78800cd,0x00000000,0x00000000}},	//   қшун, _oṃ_, --, --, 
   {{0xdddc01a6,0xafc401e0,0x3c580276,0x00000000}},	// [11b0] _vapš, _рәнй, эитэ_, --, 
   {{0x2d8401bf,0x00000000,0x00000000,0x00000000}},	//   æles_, --, --, --, 
   {{0x2b4816b0,0xd788002b,0xb4b00073,0xdddc00e2}},	//   ssac_, _aṃ_, _ऐकू_, _tapš, 
   {{0x48cc00bd,0xf9680276,0x22440010,0x28140472}},	//   িক্র, эруй_, zalk_, نواس, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69d40574,0x20d008a4,0x2ca800af,0x6120063f}},	//   _येथी, všim_, ljad_, ịlit, 
   {{0xd6cc00cf,0x224416b1,0xfa2c031c,0xe5a40075}},	//   تقو_, valk_, _ཧྥིན_, тийи, 
   {{0x224416b2,0x7eb016b3,0x3af40267,0x2ca80427}},	//   walk_, _läpp, läpp_, njad_, 
   {{0x224416b4,0xe3b00597,0x69d40490,0xd76402dd}},	//   talk_, شرة_, _येती, _لەنى_, 
   {{0x7eb016b5,0x2ca816b6,0xf7700a0a,0x3af40254}},	//   _näpp, hjad_, _داف_, näpp_, 
   {{0xb38405f5,0x22440427,0x1fb812eb,0xd7000024}},	//   влөл, ralk_, उन्ड, _лiта, 
   {{0x2ca816b7,0x20d007f5,0x645c0005,0x3af40036}},	//   jjad_, pšim_, ósid, häpp_, 
   {{0x248c16b8,0x2ca816b9,0x224416ba,0xe28416bb}},	//   mdem_, djad_, palk_, _алли, 
   {{0x248c16bc,0xe194022e,0x236c012d,0x00000000}},	//   ldem_, _ариэ, mtej_, --, 
   {{0x20c00332,0x236c016d,0xdd90007b,0x00000000}},	//   _cóic_, ltej_, جوز_, --, 
   {{0x248c16bd,0xa3e4121d,0x1fb416be,0x2ca803b2}},	//   ndem_, _नशा_, _асор, gjad_, 
   {{0x248c16bf,0x0c2016c0,0x236c0070,0x5a6416c1}},	// [11c0] idem_, рмун, ntej_, ккаб, 
   {{0x248c16c2,0x1d2416c3,0x3ce00218,0x2ca800c5}},	//   hdem_, _имом, sniv_, ajad_, 
   {{0x2ca80327,0x00000000,0x00000000,0x00000000}},	//   bjad_, --, --, --, 
   {{0xd7f816c4,0x248c16c5,0x236c036e,0x00000000}},	//   мул_, jdem_, ktej_, --, 
   {{0x248c16c6,0x69c000c5,0x569002dd,0x00000000}},	//   ddem_, _ülen, ғақт, --, 
   {{0x248c003d,0x7ccc16c7,0xf6280137,0x00000000}},	//   edem_, rşru, رتتۇ_, --, 
   {{0x248c003a,0xd944009b,0xa2c40303,0x00000000}},	//   fdem_, _шеви, िसन्, --, 
   {{0x09e001c0,0x248c15b7,0x00000000,0x00000000}},	//   _тосн, gdem_, --, --, 
   {{0x2c6c00dd,0xb9ec0023,0x53e402e8,0xd7880055}},	//   lódó_, _ኔራ_, ъцка, _uṃ_, 
   {{0x857416c8,0x248c16c9,0x20d00010,0x00000000}},	//   хсәт_, adem_, lših_, --, 
   {{0x154406ed,0x7eb016ca,0x4a5800d9,0x236c0419}},	//   _реем, _räpp, ודיו, atej_, 
   {{0xc5a416cb,0x236c0455,0xa5d8010f,0xef6401c6}},	//   _جڏهن_, btej_, _אַני, лэгү, 
   {{0x35a81533,0x2ca809a8,0x00000000,0x00000000}},	//   _कपड़, vjad_, --, --, 
   {{0x7a48005f,0xb6e00327,0x2ca8058a,0x00000000}},	//   nūtē, _སམྦྷ, wjad_, --, 
   {{0x9104044c,0x2ca800af,0x20d0110c,0x8c640fca}},	//   _ичид, tjad_, kših_, ктад, 
   {{0x20d00fb7,0x2d84013c,0x0214011a,0x6fb416cc}},	//   jših_, æleq_, _בחום_, _ممبا, 
   {{0x2ca816cd,0x7eb016ce,0x0a6800c7,0xe68c0139}},	// [11d0] rjad_, _täpp, дреи_, _ürçü, 
   {{0x2ca800c5,0x248c16cf,0x2d840327,0x00000000}},	//   sjad_, zdem_, ħleb_, --, 
   {{0x29d400db,0x2ca80254,0x7ff416d0,0xe9b4035b}},	//   دياس, pjad_, _مسیا, ыбжь, 
   {{0xcc8404d3,0xa214010f,0x00000000,0x00000000}},	//   _جۆره_, אַנס_, --, --, 
   {{0x27e80a9d,0x20c00120,0xa2c416d1,0x3af40036}},	//   çan_, _jóia_, िसम्, päpp_, 
   {{0x69c00037,0x236c16d2,0x27e8025c,0x26c00022}},	//   _üleo, vtej_, ħan_, óho_, 
   {{0x248c03fa,0x20d00219,0x24f401c0,0x00000000}},	//   tdem_, bših_, лчир, --, 
   {{0xdb1c0122,0x248c16d3,0xdcfc054e,0x386000a3}},	//   _švéd, udem_, _ispă, òirt_, 
   {{0x248c16d4,0x20c00798,0xe2b4009d,0x00000000}},	//   rdem_, _nóia_, гснэ, --, 
   {{0xf77016d5,0x248c0483,0x6d5804fe,0x236c16d6}},	//   _گاہ_, sdem_, _āwan, rtej_, 
   {{0x236c16d7,0xe47416d8,0x00000000,0x00000000}},	//   stej_, _булэ, --, --, 
   {{0xd5b800c8,0xf77001d9,0x20c00798,0x236c16d9}},	//   _אזעל, _داہ_, _bóia_, ptej_, 
   {{0x64480069,0x442c05da,0x2c6c00e5,0x00000000}},	//   maei, _ifg_, zódó_, --, 
   {{0x35d805f9,0x66f416da,0x644816db,0xdcfc054e}},	//   _भेड़, ेतिक_, laei, _ospă, 
   {{0x5de40801,0x68e801e4,0xdc980354,0xf1a800f2}},	//   ужва, _ĉedn, нташ_, _لايه_, 
   {{0x644816dc,0x27e8012d,0x7e640022,0xdb84004e}},	//   naei, żany_, ыхҭҵ, лгби, 
   {{0x20d008a4,0x442c16dd,0xda580e58,0xe3b801d3}},	// [11e0] vših_, _mfg_, ереш_, nyű_, 
   {{0x7bc00cc1,0x644816de,0x1e8416df,0xb4b001ad}},	//   _ümum, haei, _слом, _ऐक्_, 
   {{0x5f7416e0,0x69c016e1,0x628016e2,0x1ce4031c}},	//   _شاکر, _ülel, ielo, ྫོད_, 
   {{0x628016e3,0x5ca416e4,0x2bd40574,0x57e816e5}},	//   helo, _симб, _ठेवा, ндем_, 
   {{0x38c816e6,0x628016e7,0x644816b8,0x20d00427}},	//   _یاری_, kelo, daei, rših_, 
   {{0x628016e8,0x442c07d6,0x69c007f7,0x00000000}},	//   jelo, _afg_, लनशी, --, 
   {{0x628016e9,0x6da40198,0x60d40124,0xcad40115}},	//   delo, lɗar, _omym, _עולת_, 
   {{0x442c16ea,0x628016eb,0x550400fd,0x1ae401d5}},	//   _cfg_, eelo, ычла, _роҳм, 
   {{0x628016ec,0xb4e406e3,0xe3b800e5,0x00000000}},	//   felo, _नदी_, gyű_, --, 
   {{0x628016ed,0x644816ee,0x037416ef,0x00000000}},	//   gelo, aaei, احيت_, --, 
   {{0x442c002d,0xc1b405f5,0x645c04d4,0x6448003a}},	//   _ffg_, глэх_, ósic, baei, 
   {{0x628000fb,0x942400db,0x1304008e,0x6604002f}},	//   aelo, _смде, _өзем, ühke, 
   {{0xb4c016f0,0xba00001f,0x00000000,0x00000000}},	//   ँसी_, _ቁጭ_, --, --, 
   {{0x94000451,0x63bc05ac,0x1db00073,0x8d8401d5}},	//   _پوڙه, øsne, ीनंत, лубд, 
   {{0xb7fc04c5,0x3dd8009e,0xf17003e6,0xc6b4011a}},	//   েশিত_, _দুবল, _بێجگ, נהלי_, 
   {{0xd13c0092,0x28b800bc,0x00000000,0x00000000}},	//   ካባቢው, _आवधि, --, --, 
   {{0x4bd804fb,0x00000000,0x00000000,0x00000000}},	// [11f0] ربرد_, --, --, --, 
   {{0x6e9400cf,0x00000000,0x00000000,0x00000000}},	//   _ئلدا, --, --, --, 
   {{0xad8400d1,0x20c001e7,0xa2c400dc,0x00000000}},	//   _ئاخۇ, _móin_, िसत्, --, 
   {{0xac9416f1,0x628016f2,0x69c016f3,0x20c000ae}},	//   _тамш, zelo, _ülem, _lóin_, 
   {{0x644816f4,0x4920013e,0x499016f5,0x05b80214}},	//   vaei, рӯҳҳ, _گیار, کدشت_, 
   {{0x628016f6,0x9ba002de,0x20c00332,0x00000000}},	//   xelo, _بەكى, _nóin_, --, 
   {{0x628016f7,0x4990168d,0x644816f8,0xb4c00037}},	//   velo, _دیار, taei, ँसू_, 
   {{0x628016f9,0x57b00075,0xe3b801d3,0x38a400d8}},	//   welo, сбәт, tyű_, _лјуб, 
   {{0x628016fa,0x644816fb,0x290c16fc,0x38341142}},	//   telo, raei, _ihea_, _ынтр, 
   {{0x27ec004e,0x673800b5,0x6280017a,0x68e816fd}},	//   _ixen_, mpwj, uelo, _hjed, 
   {{0x26c416fe,0x628016ff,0x68e81700,0x64481701}},	//   _illo_, relo, _kjed, paei, 
   {{0x62801702,0x442c1703,0x6b040327,0x00000000}},	//   selo, _ufg_, _མེའོ_, --, 
   {{0x628016ec,0x68e802d3,0x5f041704,0x20c0007b}},	//   pelo, _mjed, изма, _fóin_, 
   {{0x68e8045f,0x290c062c,0x6280011f,0xfbd0134e}},	//   _ljed, _lhea_, qelo, _सेगम, 
   {{0x68e81705,0x63a80077,0x290c01c4,0xadc401e0}},	//   _ojed, lxen, _ohea_, барһ, 
   {{0x63a81706,0x68e81707,0x290c0332,0x60d400a2}},	//   oxen, _njed, _nhea_, _umym, 
   {{0x63a81708,0x26c41709,0xdee4170a,0x69c000af}},	// [1200] nxen, _ollo_, _вопи, _ülej, 
   {{0x290c170b,0x63a8170c,0x68e8170d,0x19940640}},	//   _ahea_, ixen, _ajed, ијер, 
   {{0x290c01a6,0x68e801a6,0x59840352,0x00000000}},	//   _bhea_, _bjed, рлеб, --, 
   {{0x26c4170e,0x290c170f,0x7f44004b,0x68e81710}},	//   _allo_, _chea_, _kwiq, _cjed, 
   {{0x68e81711,0x290c01e7,0x90740a7c,0x00000000}},	//   _djed, _dhea_, שענא_, --, 
   {{0x68e81712,0x290c02b5,0x00000000,0x00000000}},	//   _ejed, _ehea_, --, --, 
   {{0x68e8037e,0x290c1713,0x20d00030,0x09e001c0}},	//   _fjed, _fhea_, lšiu_, _дорн, 
   {{0x26c41714,0x5fa40574,0xb4c01715,0x68e81716}},	//   _ello_, खमाल, ँसे_, _gjed, 
   {{0x63a81717,0xa5080131,0xd1d4010c,0x20d000d0}},	//   gxen, دىيە_, ርደት_, nšiu_, 
   {{0x68e81718,0x0634001f,0x00000000,0x00000000}},	//   _zjed, ከናወነ, --, --, 
   {{0xd7f81719,0x20d000d0,0x37b800cc,0x59c40b02}},	//   _чуң_, hšiu_, _অধিৰ, लनिर, 
   {{0x7648171a,0xefe8001f,0x2f880022,0x4fc4009d}},	//   _hedy, _መላው_, гәон_, асга, 
   {{0x7528171b,0xdc2c03be,0x7648171c,0x20d001f1}},	//   _hudz, _sığo, _kedy, jšiu_, 
   {{0x7528171d,0x7648068f,0x7b1003fa,0xfbcc0154}},	//   _kudz, _jedy, läuf, লপাত, 
   {{0x7528171e,0x42500244,0x412400f3,0x00000000}},	//   _judz, _بۆپر, _којо_, --, 
   {{0x7528171f,0x76481720,0x00000000,0x00000000}},	//   _mudz, _ledy, --, --, 
   {{0x75281721,0x7f44014b,0x68e81722,0x00000000}},	// [1210] _ludz, _gwiq, _rjed, --, 
   {{0x68e81723,0x69c000af,0x75280099,0x76480214}},	//   _sjed, _ülek, _oudz, _nedy, 
   {{0xc8a806bb,0x290c01ee,0x6e2402d0,0x7b100112}},	//   къде_, _phea_, _ighb, käuf, 
   {{0x2cac0037,0x20d000d7,0xb4c000bc,0x00000000}},	//   _õed_, bšiu_, ँसो_, --, 
   {{0x290c06d6,0x68e8044e,0x75281724,0x764803cb}},	//   _vhea_, _vjed, _audz, _bedy, 
   {{0x75281725,0x290c04fe,0x20d000f3,0x76481726}},	//   _budz, _whea_, lšit_, _cedy, 
   {{0x68e81727,0x76481728,0x290c1729,0x7528172a}},	//   _tjed, _dedy, _thea_, _cudz, 
   {{0x68e81326,0x7528172b,0x7648172c,0x63a8172d}},	//   _ujed, _dudz, _eedy, txen, 
   {{0x6e24047e,0xe2980209,0x82600131,0x7648015d}},	//   _oghb, гап_, قۇشن, _fedy, 
   {{0x63a8172e,0x6d4414dc,0x68f8172f,0x26c41730}},	//   rxen, _owha, lowd, _ullo_, 
   {{0x75281731,0xd24c1732,0x67280200,0x6024009d}},	//   _gudz, ژنی_, _huej, йдна, 
   {{0x67201733,0x6e240477,0xf4841734,0x76481735}},	//   _hilj, _aghb, _мучн, _zedy, 
   {{0x443c1736,0x6d441737,0x67201738,0x66001739}},	//   mbu_, _awha, _kilj, _hylk, 
   {{0x443c173a,0x6d440280,0x7528173b,0x6600023a}},	//   lbu_, _bwha, _yudz, _kylk, 
   {{0x2d94173c,0xdca4173d,0xdafc0589,0x91e0173e}},	//   ортс, бави, pãºl, _ноше, 
   {{0x6720173f,0x443c1740,0x6e24016d,0x5c240154}},	//   _lilj, nbu_, _eghb, বর্গ_, 
   {{0x6d4400b0,0x68f81741,0x67280153,0xdd940150}},	// [1220] _ewha, dowd, _nuej, шаңы, 
   {{0x443c006c,0x6ab40369,0x9e641742,0x20d013aa}},	//   hbu_, _cozf, _увод, ršiu_, 
   {{0x76481743,0x6d440142,0x68f8058a,0x443c025c}},	//   _redy, _gwha, fowd, kbu_, 
   {{0x75281744,0x76481745,0xad240014,0x443c0003}},	//   _rudz, _sedy, _گریو, jbu_, 
   {{0x7d041746,0x75280dc7,0x764805b8,0x8b6400d1}},	//   mlis, _sudz, _pedy, _лияв_, 
   {{0x7d041747,0x6600002d,0x75281748,0x645c148b}},	//   llis, _bylk, _pudz, ósin, 
   {{0x7d041749,0x6720174a,0x7648174b,0x75280810}},	//   olis, _dilj, _vedy, _qudz, 
   {{0x7d04174c,0x764800a9,0x443c05db,0x3f800356}},	//   nlis, _wedy, gbu_, _opiu_, 
   {{0x672800c7,0x67200327,0x57e8023a,0x00000000}},	//   _guej, _filj, _сдам_, --, 
   {{0x7d04174d,0x6600174e,0x6720174f,0x7648020c}},	//   hlis, _fylk, _gilj, _uedy, 
   {{0x443c1750,0x8af805e1,0x75280810,0x5228001f}},	//   bbu_, רהיי, _uudz, _ተናግሯ, 
   {{0x7d041751,0x443c1752,0x7b100112,0x67201753}},	//   jlis, cbu_, bäug, _zilj, 
   {{0x7d041754,0x7eb00108,0x00000000,0x00000000}},	//   dlis, _häpy, --, --, 
   {{0x7d041755,0x7eb0005b,0x660000a2,0xdcfc0055}},	//   elis, _käpy, _yylk, _āvād, 
   {{0x7d041756,0x1cb0025c,0x799c0175,0x6ab402f0}},	//   flis, _དྭང_, _nrrw, _rozf, 
   {{0x7058004e,0x69c00037,0xc0e400f3,0x00000000}},	//   _таир_, _ülei, _нојк, --, 
   {{0xcee81757,0x7eb001f4,0x00000000,0x00000000}},	// [1230] _مردن_, _läpy, --, --, 
   {{0x443c1758,0x6e24014f,0x6728036e,0x0dc80117}},	//   zbu_, _ughb, _ruej, _буми_, 
   {{0x7d041759,0x443c175a,0x6ab4001e,0x20d000bc}},	//   blis, ybu_, _vozf, pšit_, 
   {{0x2d80175b,0x1f2401d9,0x20d0009b,0x00000000}},	//   _iphe_, _دِیہ, lšir_, --, 
   {{0xd364175c,0x6728175d,0x443c0232,0x68f8175e}},	//   _ته_, _quej, vbu_, rowd, 
   {{0xd124175f,0xe5a41760,0x66001761,0x67281762}},	//   _يم_, жики, _pylk, _vuej, 
   {{0x67201763,0x00000000,0x00000000,0x00000000}},	//   _vilj, --, --, --, 
   {{0x2d8001e0,0x443c1764,0x68f8058a,0x67280200}},	//   _mphe_, ubu_, qowd, _tuej, 
   {{0x443c1765,0x7b100e78,0x78ac0306,0xe79400f2}},	//   rbu_, bäud, ťové, _بازک, 
   {{0x660014cf,0x443c1766,0x6720062c,0x799c015d}},	//   _tylk, sbu_, _uilj, _yrrw, 
   {{0x7d041767,0x60e81768,0xd04c00ac,0x7b10002f}},	//   ylis, имом_, licə, säug, 
   {{0x7d04036b,0x443c011f,0xa0681769,0x6b9c176a}},	//   xlis, qbu_, шама_, _orsg, 
   {{0x6458176b,0x7d04176c,0x2d80176d,0x788008a5}},	//   _idwi, vlis, _aphe_, _hávæ, 
   {{0x7d04176e,0x6910005c,0xe3f800ec,0x00000000}},	//   wlis, låed, _ٽوڙڻ_, --, 
   {{0x7d04176f,0x931004d3,0xd4400092,0xd24c009a}},	//   tlis, _تووش, _የቀበሌ, _شني_, 
   {{0x691000b5,0x1be806ed,0xda6400ec,0x00000000}},	//   nåed, адби_, ڪاري, --, 
   {{0x7d041770,0x2d80009f,0x5ba81771,0x3fc801e2}},	// [1240] rlis, _ephe_, шкам_, _ددغی_, 
   {{0xda640597,0xd1c01772,0xd04c03b9,0x00000000}},	//   تاري, _ድርብ_, dicə, --, 
   {{0x1d081773,0x6458068f,0x98481774,0x9984007b}},	//   _вени_, _odwi, аяла_, تلاو, 
   {{0x6458090c,0x7d040548,0x2bd400c5,0x23c80b98}},	//   _ndwi, qlis, _ठेका, िनाद, 
   {{0xda640451,0x6d5800b0,0x473001e2,0x00000000}},	//   _واسي, _āwai, وروز, --, 
   {{0x8f981775,0x64580134,0xd9440364,0x3ce00254}},	//   ייני, _adwi, _меги, liiv_, 
   {{0x628403b2,0x77f400ec,0x00000000,0x00000000}},	//   _óhoy, _کڻائ, --, --, 
   {{0xd3780354,0x6910005c,0x6b9c010e,0x00000000}},	//   ачо_, gåed, _yrsg, --, 
   {{0xb864004b,0x88b0006c,0xc474036b,0x00000000}},	//   _واړو, _تینچ, تینچ_, --, 
   {{0x64581776,0x3ce0007d,0x37c40131,0x4b780a1e}},	//   _edwi, hiiv_, _мәһб, סטיג, 
   {{0xbb5c00b5,0x80d400cc,0xc0cc0023,0xf9ec00cc}},	//   ntzス_, দচন্, _ቢሎም_, _কৰতল_, 
   {{0x53a400ae,0x6ab81777,0x00000000,0x00000000}},	//   _وماك, _ेत्र, --, --, 
   {{0x69c0007d,0x73c40032,0x2428009f,0x00000000}},	//   _ülev, _хәйе, _اسمٿ_, --, 
   {{0x2bd40316,0x82f41778,0x7b101779,0x00000000}},	//   _ठेगा, _وروز_, häub, --, 
   {{0x823000f1,0x463800df,0x00000000,0x00000000}},	//   _غروا, שעלע, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [1250] --, --, --, --, 
   {{0x7f84177a,0x6b50032e,0xc98401d5,0x705400e5}},	//   _کلین, _aðgá, жуди, _بچھا, 
   {{0x2d80014b,0xa2a006e3,0x00000000,0x00000000}},	//   _uphe_, _कोफ्, --, --, 
   {{0xd04c0cc1,0x26f40db3,0x3df4177b,0x8ca010de}},	//   ticə, ेत्र_, _ізяс, _تەرو, 
   {{0x6d5401ed,0x23d8177c,0x4788177d,0xdc34008f}},	//   lsza, _बेंद, рсем_, _מארט_, 
   {{0x6b8c177e,0x00000000,0x00000000,0x00000000}},	//   mwag, --, --, --, 
   {{0x6b8c177f,0x6d541780,0x6910005c,0x00000000}},	//   lwag, nsza, tåed, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6b8c1781,0x7b10002f,0x00000000,0x00000000}},	//   nwag, säue, --, --, 
   {{0x65941782,0x2cb801ab,0x6b8c01a4,0x6d541783}},	//   _назу, _losd_, iwag, ksza, 
   {{0x6b8c1784,0xe29816c3,0x6d541785,0x7b100112}},	//   hwag, _ҳал_, jsza, läuc, 
   {{0x6b8c1786,0x69c00037,0x34f0013d,0xd3e400cf}},	//   kwag, _üleu, _үҗәт, تتۉۉ, 
   {{0xe2981787,0xe7bc1788,0x6b8c01f5,0x6d54033f}},	//   _гал_, ्निप, jwag, esza, 
   {{0x2cb800a3,0x6b8c0747,0x539805d0,0x00000000}},	//   _aosd_, dwag, _לינו, --, 
   {{0x6d5400dd,0xdca41789,0x3ce00037,0x00000000}},	//   gsza, пави, tiiv_, --, 
   {{0x2cb800a3,0x6b8c178a,0xe7bc01bc,0x91b8011a}},	//   _cosd_, fwag, ्नाप, _למצי, 
   {{0x6b8c178b,0x2cb800d2,0x5b24178c,0x00000000}},	// [1260] gwag, _dosd_, سفال, --, 
   {{0xcff40375,0xff240811,0x0dc40023,0x3ce00254}},	//   _מצפה_, _تبعی, _ጽሒፉ_, siiv_, 
   {{0x6b8c0083,0x7b100e78,0xd83801c6,0x00000000}},	//   awag, täub, бэл_, --, 
   {{0x1868178d,0x6b8c178e,0x779401ed,0x8f5001b9}},	//   сади_, bwag, ویزا, _تنیش, 
   {{0x7b100086,0x6b8c0230,0x4730178f,0x5ba00032}},	//   räub, cwag, еніс, _яһағ, 
   {{0x7b100112,0x00000000,0x00000000,0x00000000}},	//   säub, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd9440107,0x00000000,0x00000000,0x00000000}},	//   _меҳи, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb6c8066d,0x6d541790,0x313401f0,0x261801f9}},	//   _بارے_, ysza, меор, येही_, 
   {{0x6b8c1791,0x69c000af,0x97000131,0x142400f3}},	//   zwag, _ület, _قېچى, _едем, 
   {{0x6b8c0af9,0x00000000,0x00000000,0x00000000}},	//   ywag, --, --, --, 
   {{0x04401792,0x6d5400b5,0xc4d0011a,0x4ea400f0}},	//   _чечн, wsza, _אגף_, прва, 
   {{0x6d541793,0x52740fc0,0x0ee81468,0xe3b400cc}},	//   tsza, _худу, сьми_, _জেকব, 
   {{0x6b8c1794,0xdcfc00bc,0x00000000,0x00000000}},	//   wwag, _uspě, --, --, 
   {{0x902804ce,0x6b8c1795,0x6d541796,0x8538010f}},	//   _уцка_, twag, rsza, מגלי, 
   {{0x6d54066d,0x4ea41797,0xfc3015b0,0x2ef41798}},	// [1270] ssza, _ерна, احف_, _озир, 
   {{0x6b8c1799,0x6d54179a,0x00000000,0x00000000}},	//   rwag, psza, --, --, 
   {{0x6b8c179b,0x7c580131,0x2cb800a3,0x8c34014b}},	//   swag, زلەر_, _tosd_, _нонӣ_, 
   {{0xd1dc02d3,0x6b8c01a4,0x7b100036,0xc7700150}},	//   _ዓዋተ_, pwag, täuc, еткө, 
   {{0x3a380223,0xfb84010a,0x00000000,0x00000000}},	//   _ffrp_, _пырн, --, --, 
   {{0x3a380048,0x660400a8,0x7b100e78,0x00000000}},	//   _gfrp_, мпла, räuc, --, 
   {{0xf650179c,0x60c403cd,0x06ac0154,0x00000000}},	//   ائه_, ykkm, _কতদি, --, 
   {{0x23340107,0xfbc4012d,0xf77002f2,0x61ec0055}},	//   мхор, लैकम, _ڕام_, _śalo, 
   {{0xd36c0451,0xd70000c0,0x00000000,0x00000000}},	//   لهي_, _кiра, --, --, 
   {{0x69c0007d,0x13040a8f,0x41400116,0xa1c40a5b}},	//   _üles, мный_, ндоң, дбод, 
   {{0xf3800220,0x2088179d,0xc1040116,0x00000000}},	//   _ұғым, ойни_, нүкл, --, 
   {{0xd36c0214,0x6594014b,0x00000000,0x00000000}},	//   دهی_, _наҷу, --, --, 
   {{0x343800f2,0xd24c00db,0x00000000,0x00000000}},	//   _رسند_, اچۇ_, --, --, 
   {{0xc444179e,0xd36c0244,0x62240116,0x00000000}},	//   _بیکن_, _ئهو_, _قىشل, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdcb00131,0x6e3401c6,0xa2c4179f,0xb3540244}},	//   خىر_, _үхэх, िसक्, _تییا_, 
   {{0xd9d000d1,0x9f1800ae,0x00000000,0x00000000}},	// [1280] ھەرگ, _وآخر_, --, --, 
   {{0xd94417a0,0x00000000,0x00000000,0x00000000}},	//   дежи, --, --, --, 
   {{0x224000c5,0xab6400de,0x4d440064,0x00000000}},	//   _õhku_, _atļā, _опэн_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x46a017a1,0x00000000,0x00000000,0x00000000}},	//   качв, --, --, --, 
   {{0x26180ce0,0x6aa00332,0x00000000,0x00000000}},	//   येली_, _ólfa, --, --, 
   {{0x23c80490,0x27f80129,0x0514007b,0x89d800d9}},	//   िनंद, égné_, وزيع_, _וחלי, 
   {{0x69c000c5,0xe87401b9,0x128802e8,0x48e017a2}},	//   _üler, _سنلگ, ощни_, _ротв, 
   {{0x96c80014,0x4cc40154,0x00000000,0x00000000}},	//   _ببرِ_, রোপু, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x224817a3,0xd4c400c6,0xe4a40212,0x00000000}},	//   _đake_, _تغطي, _пріо, --, 
   {{0x3cf40b98,0x00000000,0x00000000,0x00000000}},	//   ्कने_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6ee8041a,0x00000000,0x00000000,0x00000000}},	//   džbe, --, --, --, 
   {{0x248817a4,0x7bc4003a,0x1af80154,0x00000000}},	// [1290] _ñame_, gyiu, ্গনে_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x806817a5,0xdb2417a6,0x06c40150,0x00000000}},	//   _عمیق_, رومی, _ﺒﺠﻨﺩ, --, 
   {{0xf77003e6,0x3dd800cc,0x00000000,0x00000000}},	//   ڤان_, _দুকল, --, --, 
   {{0xd3640272,0x00000000,0x00000000,0x00000000}},	//   _حه_, --, --, --, 
   {{0xda7c00d0,0x00000000,0x00000000,0x00000000}},	//   íďte_, --, --, --, 
   {{0x2d900223,0xd6240b3b,0x2d840327,0x00000000}},	//   nwze_, ноше_, ħlew_, --, 
   {{0xf77017a7,0xe3b817a8,0x69c4009f,0x00000000}},	//   _چال_, зби_, myhe, --, 
   {{0xf77017a9,0x291c04ba,0x69c400e5,0x07e400f1}},	//   _نال_, mmwa_, lyhe, _کېږی_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69c417aa,0xdb14003e,0xd70002dd,0x2010012d}},	//   nyhe, écén, _кiта, _szyi_, 
   {{0xe0d00214,0x00000000,0x00000000,0x00000000}},	//   ازد_, --, --, --, 
   {{0x248c17ab,0x291c0810,0x7bc40007,0x6f040051}},	//   meem_, imwa_, xyiu, _bkhc, 
   {{0x248c0694,0xe29817ac,0x69c417ad,0x00000000}},	//   leem_, _хак_, kyhe, --, 
   {{0xdd9017ae,0x21a40137,0x1d140798,0x00000000}},	//   دوز_, _чийм, еќар, --, 
   {{0x248c17af,0x02dc00c5,0x00000000,0x00000000}},	//   neem_, _फगुन, --, --, 
   {{0x5ac801d5,0x80cc01f9,0x3dd800cc,0x00000000}},	// [12a0] плам_, ासीं, _দুখল, --, 
   {{0x248c17b0,0x19f40f5c,0xd1c00092,0x00000000}},	//   heem_, нџер, _ድርቅ_, --, 
   {{0x248c17b1,0x69c400e5,0x00000000,0x00000000}},	//   keem_, gyhe, --, --, 
   {{0x58940133,0x248c0de2,0x7bc40022,0xa2a017b2}},	//   عجاز, jeem_, pyiu, _कोस्, 
   {{0x248c17b3,0xc7a017b4,0x00000000,0x00000000}},	//   deem_, лицк, --, --, 
   {{0x69c417b5,0x6d4017b6,0x00000000,0x00000000}},	//   byhe, ílag, --, --, 
   {{0x248c17b7,0x69c00ef5,0x69100267,0x69c40175}},	//   feem_, _ülep, måen, cyhe, 
   {{0x691017b8,0x248c0de2,0xf8d4033f,0x00000000}},	//   låen, geem_, _दतिय, --, 
   {{0xf318016c,0x20c001e7,0x741417b9,0x38380240}},	//   моиш_, _lóis_, کوکا, _ብሓሳብ, 
   {{0x35c400c7,0x7b100112,0xdb040166,0x00000000}},	//   _иазҳ, zäun, _ömäg, --, 
   {{0xb9cc044e,0x20c017ba,0x248c0694,0x00000000}},	//   _ሰነ_, _nóis_, beem_, --, 
   {{0x248c17bb,0x85f4011a,0x00000000,0x00000000}},	//   ceem_, _אצבע_, --, --, 
   {{0xbfa817bc,0x7b10005b,0x00000000,0x00000000}},	//   нтре_, väun, --, --, 
   {{0x63ac0960,0xf48403e6,0x841000d4,0x00000000}},	//   _šang, _ساڵی, _сміх, --, 
   {{0x518417bd,0x290403b2,0x51a80395,0xc0e00240}},	//   _чула, _ílag_, _хълм_, ነሎም_, 
   {{0x0cdc0729,0xdd980107,0x6604002f,0x00000000}},	//   ভক্ত, ӯшӣ_, ühki, --, 
   {{0x7bf817be,0x82440092,0x00000000,0x00000000}},	// [12b0] ентр_, _የአባቶ, --, --, 
   {{0x69c417bf,0x691017c0,0x63bc17c1,0x248c17c2}},	//   tyhe, gåen, øsni, zeem_, 
   {{0x291c00ca,0x248c0083,0x6ac004aa,0x00000000}},	//   tmwa_, yeem_, _शकीर, --, 
   {{0x69c417c3,0x291c17c4,0x248c17c5,0x00000000}},	//   ryhe, umwa_, xeem_, --, 
   {{0x8d24010b,0x248c00d8,0xdcfc0055,0x8038010f}},	//   _онүң_, veem_, _uppā, גנדע_, 
   {{0x69c400b5,0x248c00e8,0x00000000,0x00000000}},	//   pyhe, weem_, --, --, 
   {{0x20f400b0,0xa2a017c6,0x248c17c7,0x20c000ae}},	//   hāia_, _कोष्, teem_, _móir_, 
   {{0x26240198,0x71540023,0x00000000,0x00000000}},	//   rɓo_, _መሰላቶ, --, --, 
   {{0x248c0694,0xc6a40f5c,0x764c00e5,0x00000000}},	//   reem_, _пржи, élyü, --, 
   {{0x248c17c8,0x63ac0327,0x82440092,0x00000000}},	//   seem_, _ġand, _የበሽታ, --, 
   {{0xa06817c9,0x64a400d1,0x63ac17ca,0xc0e00023}},	//   мана_, _җаһа, _šand, _ነጊሱ_, 
   {{0xa2a017cb,0x726c001f,0x20c00332,0x98a800ef}},	//   _कोर्, _ተጠየቀ_, _róis_, _kubā_, 
   {{0x644817cc,0x20c017cd,0x1ea80451,0x442c17ce}},	//   mbei, _sóis_, واسي_, _igg_, 
   {{0x644817cf,0x20c000c6,0xa2e4084c,0x601c00d0}},	//   lbei, _cóir_, _шолд, _rámč, 
   {{0xb8e40135,0xe0d817d0,0x628017d1,0x644801c4}},	//   _ཏྭ_, _овк_, mflo, obei, 
   {{0x644817d2,0x753c00dd,0x6c7401c0,0x00000000}},	//   nbei, _érze, луух, --, 
   {{0x691017d3,0x442c020b,0x644817d4,0x20c001e7}},	// [12c0] tåen, _mgg_, ibei, _fóir_, 
   {{0x628017d5,0x4a4017d6,0x64480369,0xcb64011c}},	//   nflo, инув, hbei, тафе_, 
   {{0x6910003b,0x9d4417d7,0xcee001ec,0x00000000}},	//   råen, _шенд, _тұрқ, --, 
   {{0xc86017d8,0x6a140131,0xd7e4155b,0x0c7000db}},	//   атши, ھبەر, кіло, _ەگەد, 
   {{0x7d0417d9,0x7b1017da,0x6280017a,0x644801ab}},	//   mois, läum, kflo, dbei, 
   {{0x442c17db,0x7d0417dc,0xa2a00829,0x628001e4}},	//   _agg_, lois, _कोल्, jflo, 
   {{0x442c17dd,0x057017de,0x644817df,0x2eec0de2}},	//   _bgg_, لايد, fbei, éefi_, 
   {{0x7d0417e0,0xd3a417e1,0x224817a3,0x6280017a}},	//   nois, вроп, _đaka_, eflo, 
   {{0x628017e2,0x7b100112,0xf48402f2,0x44b00150}},	//   fflo, häum, ناکی, рбыс, 
   {{0x7d0417e3,0x442c0e21,0x644800d8,0x628006ea}},	//   hois, _egg_, abei, gflo, 
   {{0x7d040664,0xf484104a,0x765817e4,0x442c0010}},	//   kois, _ماشی, mavy, _fgg_, 
   {{0x7d04023a,0x63ac00f3,0x6ee80841,0x20f402b1}},	//   jois, _šane, džba, tāia_, 
   {{0x7d0417e5,0xb4c017e6,0x248800c7,0x20c00332}},	//   dois, ुसी_, _ñama_, _póir_, 
   {{0x765817e7,0x69c000d8,0xa4400133,0x00000000}},	//   navy, _àleg, _پێیو, --, 
   {{0x2fcc0bb8,0x7d0417e8,0x1ee80271,0x00000000}},	//   šeg_, fois, روفی_, --, 
   {{0x8c3803fa,0x69101512,0x442c00d8,0x7b100b70}},	//   _maßg, gåel, _xgg_, säul, 
   {{0x765817e9,0x20c00597,0xfb34009d,0x00000000}},	// [12d0] kavy, _tóir_, интэ, --, 
   {{0x765817ea,0x7b100112,0x00000000,0x00000000}},	//   javy, bäum, --, --, 
   {{0x7d0417eb,0x765805b4,0x6d4001e4,0x2d840135}},	//   bois, davy, ŭlab, ħles_, 
   {{0xe7f401c0,0x00000000,0x00000000,0x00000000}},	//   лчлэ, --, --, --, 
   {{0x628017ec,0x644803cd,0xcfe400fe,0x00000000}},	//   yflo, vbei, _গঁড়_, --, 
   {{0x442c17ed,0xba2816a0,0x64480042,0x2ed017ee}},	//   _sgg_, رسەم_, wbei, _हतोत, 
   {{0x644817ef,0x62800158,0xc87800d8,0x00000000}},	//   tbei, vflo, _оџа_, --, 
   {{0x261809bb,0x63ac0327,0x38a400d8,0x00000000}},	//   येगी_, _ġanb, _кјуб, --, 
   {{0x644817f0,0x628017f1,0x765817f2,0xf7940953}},	//   rbei, tflo, bavy, _катэ, 
   {{0x7d0417f3,0x644817f4,0x6280002f,0x39540241}},	//   zois, sbei, uflo, _àasà_, 
   {{0x273817f5,0x628017f6,0x7d0400ec,0x7d000356}},	//   _hèn_, rflo, yois, _hârş, 
   {{0x628009cc,0x20c000c6,0x273817f7,0xb7f403d4}},	//   sflo, _cóip_, _kèn_, _জৰিত_, 
   {{0x27380699,0x7d0417e5,0x6e2803be,0xe3640212}},	//   _jèn_, vois, əmbə, _скли, 
   {{0x249c0457,0x273817f8,0x7d04014b,0xd12c05af}},	//   _hawm_, _mèn_, wois, _کمي_, 
   {{0xa0a4152d,0x691017f9,0x249c0190,0x7d04049b}},	//   _байд, tåel, _kawm_, tois, 
   {{0x7b100730,0x765817fa,0xdb100241,0x00000000}},	//   räum, zavy, _ègús, --, 
   {{0xcb6417fb,0x765817fc,0x2d840274,0x5334010f}},	// [12e0] лате_, yavy, çler_, ָנען_, 
   {{0x249c0b89,0x7f4417fd,0x8f980302,0x7d0402f6}},	//   _lawm_, _itiq, _טיפי, sois, 
   {{0x7d0417fe,0x98a41553,0x9a140276,0x00000000}},	//   pois, лиже, уфаш, --, 
   {{0x249c0218,0x273817ff,0x765801f7,0x00000000}},	//   _nawm_, _bèn_, wavy, --, 
   {{0x76581800,0xe7940014,0x00000000,0x00000000}},	//   tavy, لاوک, --, --, 
   {{0x27381801,0x1ae4004e,0x41d0043e,0x70e000bc}},	//   _dèn_, _согм, दनास, _पग्ल, 
   {{0x76581802,0x7f4401a9,0x00000000,0x00000000}},	//   ravy, _ltiq, --, --, 
   {{0x76581803,0x249c0070,0x2ed01804,0x98a80356}},	//   savy, _cawm_, _हत्त, _dubă_, 
   {{0x249c01d4,0x273800f2,0x76581805,0x07a01806}},	//   _dawm_, _gèn_, pavy, _латн, 
   {{0x63ac0232,0x3254013e,0x4b78008f,0x45d00022}},	//   _šanc, швор, עטיג, рцәт, 
   {{0x249c0218,0x7f441807,0xf0b41808,0x81401809}},	//   _fawm_, _atiq, айнь, ینین, 
   {{0x27380502,0x249c0218,0x6ac000dc,0x00000000}},	//   _yèn_, _gawm_, _शक्र, --, 
   {{0xe4c800ec,0x00000000,0x00000000,0x00000000}},	//   _جبلن_, --, --, --, 
   {{0x11d4180a,0x249c0218,0x8c380e78,0x00000000}},	//   _متعد, _zawm_, _maße, --, 
   {{0x249c0070,0xdb040036,0xbdd400f5,0x0ca8180b}},	//   _yawm_, _erkë, борщ, нтаи_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xaa54055f,0x00000000,0x00000000,0x00000000}},	// [12f0] иваш, --, --, --, 
   {{0x2738180c,0x38640129,0x00000000,0x00000000}},	//   _rèn_, _admr_, --, --, 
   {{0x273802bd,0x2eec00e8,0xe8580153,0x0dc802e8}},	//   _sèn_, éefu_, ваеш_, _чупи_, 
   {{0x386405d5,0x27380669,0x8c040154,0xdd9000ec}},	//   _cdmr_, _pèn_, লেষন_, _بوٽ_, 
   {{0x0a68180d,0x249c01d4,0x3cf40b67,0xc2080037}},	//   _први_, _rawm_, ्करे_, _सुनब_, 
   {{0xc0e0044e,0x249c0211,0x65c4036b,0x27380ba1}},	//   _ነዊሕ_, _sawm_, ибла, _vèn_, 
   {{0x8c0400eb,0x00000000,0x00000000,0x00000000}},	//   লেশন_, --, --, --, 
   {{0x6d44180e,0xdb04020c,0x38600597,0x2738180f}},	//   _mtha, _arkè, óirt_, _tèn_, 
   {{0x6d44089c,0x14b41810,0xc6000171,0x00000000}},	//   _ltha, _आचरण, dzēš_, --, 
   {{0xa2e41811,0x6ee80841,0x87040064,0x00000000}},	//   роод, džbo, _сябе, --, 
   {{0x25b81812,0x249c0190,0x6d441813,0xda0803f9}},	//   _جهاد_, _tawm_, _ntha, ɓuɓɓ, 
   {{0x20541814,0xdb040036,0xb9dc0240,0x00000000}},	//   штор, _erkè, _ኡይ_, --, 
   {{0x6d441815,0x443c1816,0x62940419,0x00000000}},	//   _atha, mcu_, ôzos, --, 
   {{0x6d440649,0x443c1817,0x7f440393,0x00000000}},	//   _btha, lcu_, _vtiq, --, 
   {{0x91e01818,0x443c0ffb,0xdd901819,0x1c380006}},	//   _моше, ocu_, غور_, вязь_, 
   {{0x443c181a,0x1c44181b,0x6d44181c,0xe2a80451}},	//   ncu_, рнам, _dtha, _ساڻن_, 
   {{0x6d44181d,0x7f441730,0x443c181e,0x2b480077}},	// [1300] _etha, _utiq, icu_, gpac_, 
   {{0x443c0369,0x2eec0036,0x00000000,0x00000000}},	//   hcu_, éeft_, --, --, 
   {{0x8c380112,0x1af80154,0x00000000,0x00000000}},	//   _saße, ্গলে_, --, --, 
   {{0x186807d6,0xdca405f5,0x443c181f,0x1be801ee}},	//   тади_, _тами, jcu_, _адми_, 
   {{0x443c1820,0x2b4804ce,0x00000000,0x00000000}},	//   dcu_, cpac_, --, --, 
   {{0x236c1821,0xdb040687,0xb4c0143b,0x60d4015d}},	//   drej_, _orké, ुस्_, _llym, 
   {{0x98640014,0x6d4400a3,0x53780023,0x7fb40118}},	//   _نیاے_, _xtha, _ጠባያት_, ुहुँ, 
   {{0x38640276,0x63ac1822,0x39a40014,0x443c03e0}},	//   _udmr_, _šana, _پیچہ, gcu_, 
   {{0xa3641823,0xdb040264,0x78a0003a,0x236c1824}},	//   مپيۇ, _arké, _iamv, grej_, 
   {{0x443c1825,0x60d40209,0x73c400fb,0x78a01826}},	//   acu_, _alym, иәһе, _hamv, 
   {{0x78a01827,0x443c1828,0x60d41829,0x799c02d0}},	//   _kamv, bcu_, _blym, _jsrw, 
   {{0x443c182a,0x78a0182b,0x4610182c,0x236c182d}},	//   ccu_, _jamv, _بومر, brej_, 
   {{0x77f4107c,0x6d44182e,0xa4f4182f,0xca3008b0}},	//   _अशोक_, _stha, _دکور_, ﺮﻻﺭ_, 
   {{0x0ee81830,0x60d40810,0x78a01831,0x28dc00af}},	//   тьми_, _elym, _lamv, _मतभि, 
   {{0x799c03ac,0x00000000,0x00000000,0x00000000}},	//   _nsrw, --, --, --, 
   {{0x60d41832,0xebc400d1,0x78a01833,0x6d440051}},	//   _glym, бәгн, _namv, _vtha, 
   {{0x6cd400cf,0x00000000,0x00000000,0x00000000}},	// [1310] _ۇقدا, --, --, --, 
   {{0x6e941834,0x6d440086,0x443c1835,0x49c81836}},	//   _الدا, _ttha, zcu_, куем_, 
   {{0x6d441837,0x2b481838,0x78a01839,0x443c183a}},	//   _utha, spac_, _bamv, ycu_, 
   {{0x78a0037e,0x443c011f,0xe6d802d2,0x00000000}},	//   _camv, xcu_, _þrúð, --, 
   {{0x443c0552,0x78a00156,0xfe70183b,0x09dc0154}},	//   vcu_, _damv, _عدی_, _বুখা, 
   {{0x6b9c0005,0x236c0cf4,0x443c033f,0x00000000}},	//   _issg, vrej_, wcu_, --, 
   {{0xe298183c,0x443c183d,0x799c02d0,0x9f9003b2}},	//   қан_, tcu_, _gsrw, _løða_, 
   {{0xfdf80302,0x78a003cd,0x443c183e,0x67d4146a}},	//   ימוש_, _gamv, ucu_, _лобу, 
   {{0x68e8183f,0x290c1840,0xe3e8034c,0x443c1841}},	//   _imed, _ikea_, دکان_, rcu_, 
   {{0x443c1842,0x236c1843,0x78a01844,0x60d40af9}},	//   scu_, rrej_, _zamv, _slym, 
   {{0xa0a41845,0x60d41846,0x78a01847,0x26c41848}},	//   банд, _plym, _yamv, _iolo_, 
   {{0x26c41849,0x236c0fb7,0x6b9c0857,0x00000000}},	//   _holo_, prej_, _ossg, --, 
   {{0x26c40418,0x68e801e0,0x60d40af9,0x64580857}},	//   _kolo_, _mmed, _vlym, _iewi, 
   {{0x6458184a,0xdca400c7,0x00000000,0x00000000}},	//   _hewi, әааи, --, --, 
   {{0x6458184b,0x9f50011f,0x68e8184c,0x290c00b0}},	//   _kewi, _ayyô_, _omed, _okea_, 
   {{0x26c4184d,0x68e80048,0x290c02e3,0x9f900162}},	//   _lolo_, _nmed, _nkea_, _føða_, 
   {{0x78a0016d,0x64580066,0x5ba80006,0x5a6400cf}},	// [1320] _ramv, _mewi, ыкам_, йкаб, 
   {{0x290c166a,0x68e8184e,0x26c4184f,0x20100548}},	//   _akea_, _amed, _nolo_, _iyyi_, 
   {{0x66dc007f,0x78a01850,0xceb00375,0x6b9c002f}},	//   _kèkf, _pamv, _זית_, _essg, 
   {{0x64580cfd,0x26c40069,0xd7f81142,0x2fdc05d1}},	//   _newi, _aolo_, лул_, _özgü_, 
   {{0x26c40038,0x96e81851,0x78a0016d,0x00000000}},	//   _bolo_, лька_, _vamv, --, 
   {{0x68e81852,0x290c1853,0x8f98025d,0x99d40024}},	//   _emed, _ekea_, טיני, _любч, 
   {{0x26c41854,0x290c0270,0x78a00bd7,0x98a41855}},	//   _dolo_, _fkea_, _tamv, _ливе, 
   {{0x26c4011c,0x6458003e,0x00000000,0x00000000}},	//   _eolo_, _cewi, --, --, 
   {{0x64581856,0x26c41857,0x77f405d9,0x00000000}},	//   _dewi, _folo_, _بڻائ, --, 
   {{0x26c41858,0x68e809a8,0x9f90022c,0x09dc03d4}},	//   _golo_, _zmed, _røða_, _বুটা, 
   {{0x20100198,0x64580de2,0x705405d9,0xd9f81223}},	//   _ayyi_, _fewi, يندا, ्थित_, 
   {{0x64581859,0x26c4185a,0x2ed000dc,0xdddc033f}},	//   _gewi, _zolo_, हस्त, _odpł, 
   {{0x26c40472,0xf2c40139,0xe51c00cd,0xe50401f7}},	//   _yolo_, _дөни, _पठति_, _ببلي, 
   {{0xd9f8185b,0x26c4014b,0xee2001ec,0x6d400332}},	//   ्थात_, _xolo_, дегi_, ílao, 
   {{0x64580921,0x8c64185c,0xa2a0185d,0xad24185e}},	//   _yewi, йтад, _कोट्, قىسى, 
   {{0xd24c0050,0xdbd4022c,0x8d840032,0x09dc015b}},	//   _تۆگ_, tøða, _һумд, _বুঝা, 
   {{0x41b000db,0x4fc4004e,0xaf5400ec,0x00000000}},	// [1330] _ومۇر, _ыска, _برعڪ, --, 
   {{0x68e8185f,0x290c045f,0x9408016b,0x63bc0267}},	//   _smed, _skea_, ɛbɔ_, äsni, 
   {{0x26c41860,0x09dc0183,0x8d78001f,0xe9440133}},	//   _rolo_, _বুজা, ርሲቲው_, زرای, 
   {{0x26c41861,0x81c80154,0x41780677,0x7f841862}},	//   _solo_, _রেড_, רנאב, _بلین, 
   {{0x64581863,0x68e80810,0x26c41864,0x645c01d5}},	//   _rewi, _vmed, _polo_, аsin, 
   {{0x64581865,0x26c401d9,0x321c02f0,0x63ac013a}},	//   _sewi, _qolo_, _ozvy_, _šano, 
   {{0x6458033f,0xe450007b,0x00000000,0x00000000}},	//   _pewi, وضة_, --, --, 
   {{0x68e81866,0x26c40085,0xa3b81867,0x24c8004e}},	//   _umed, _wolo_, لاخر_, ргип_, 
   {{0x26c41868,0x108c00d1,0x00000000,0x00000000}},	//   _tolo_, _ﻛﯚﺯﯨ, --, --, 
   {{0x64581869,0x2130003e,0x26c4186a,0xf6d40137}},	//   _wewi, _siyh_, _uolo_, _ىزلد, 
   {{0x64580086,0x6aa40332,0x00000000,0x00000000}},	//   _tewi, idhf, --, --, 
   {{0x7b1003fa,0x140802e3,0xa878010f,0x00000000}},	//   läut, ịrịo, סאָר, --, 
   {{0x7950007f,0x6264014b,0x00000000,0x00000000}},	//   _kòwò, _двла, --, --, 
   {{0x63a8186b,0x21740276,0x73040212,0xa2a000ce}},	//   mven, _дуир, _епіз, _कोच्, 
   {{0x63a8186c,0x712407d6,0x108c00d1,0xc6080154}},	//   lven, تریل, _ﻛﯚﺭﯨ, ষেরা_, 
   {{0x63a8186d,0x161c00e1,0x79600241,0x7b100112}},	//   oven, येटर_, _láwá, häut, 
   {{0x9b44186e,0x00000000,0x00000000,0x00000000}},	// [1340] زناو, --, --, --, 
   {{0x63a8186f,0xeb541870,0x00000000,0x00000000}},	//   iven, سىمگ, --, --, 
   {{0x18a40945,0x63ac010e,0x00000000,0x00000000}},	//   жаем, _šanl, --, --, 
   {{0xa3a801ad,0x0d2000cf,0x00000000,0x00000000}},	//   खटा_, _жүсү, --, --, 
   {{0x63a80cf9,0xd7041871,0x00000000,0x00000000}},	//   jven, озди, --, --, 
   {{0x63a81872,0x645c1873,0x2d8400f7,0x4ff8008f}},	//   dven, ðsin, àleg_, יִונ, 
   {{0x63a81874,0x8c380730,0xd4980114,0x273000db}},	//   even, _maßn, арп_, رۉمس, 
   {{0x94a81875,0xa3d400dc,0x63a81876,0x00000000}},	//   ртка_, सनं_, fven, --, 
   {{0x60cc0135,0x63a81877,0x161c03ce,0x00000000}},	//   _ċamp, gven, येजर_, --, 
   {{0x1440001f,0x0bb40375,0x71780107,0x7b100112}},	//   _የጀመሩ, קלים_, ббор_, mäus, 
   {{0x63a81878,0x3fd001ec,0x7b101196,0x00000000}},	//   aven, _ﮔﺮﺍﻧ, läus, --, 
   {{0x63a81879,0x8598011a,0x00000000,0x00000000}},	//   bven, _כשבו, --, --, 
   {{0x4ea4187a,0x63a800a8,0xdb0402d2,0x00000000}},	//   орва, cven, _arkí, --, 
   {{0xd138187b,0x00000000,0x00000000,0x00000000}},	//   _кхи_, --, --, --, 
   {{0x7b100730,0xd1f402d3,0x00000000,0x00000000}},	//   häus, ፈልቲ_, --, --, 
   {{0xdcec005f,0x00000000,0x00000000,0x00000000}},	//   tubā, --, --, --, 
   {{0x6b7414d4,0x00000000,0x00000000,0x00000000}},	// [1350] ялау, --, --, --, 
   {{0x39580142,0x7054187c,0x423400df,0x00000000}},	//   _bwrs_, _بنکا, ַנדל_, --, 
   {{0x63a805b8,0x395800a9,0x8c34014b,0x00000000}},	//   zven, _cwrs_, _монӣ_, --, 
   {{0xe5a4187d,0x6ee8187e,0x63a8187f,0x672001fa}},	//   ҷики, džbi, yven, _shlj, 
   {{0x66dc07b0,0x24880309,0xf6800118,0x98a801ef}},	//   _lèke, _ñami_, ěžně_, _hubě_, 
   {{0x63a81880,0xe5a41881,0x98a801ef,0x00000000}},	//   vven, зики, _kubě_, --, 
   {{0x395800a9,0x7b100112,0x00000000,0x00000000}},	//   _gwrs_, räut, --, --, 
   {{0x7b1001c7,0x7950007f,0xdb0c01e1,0x00000000}},	//   bäus, _wòwò, _òjòj, --, 
   {{0x3a38030d,0x63a81882,0xed8002d3,0x00000000}},	//   _ygrp_, uven, _ይግበር_, --, 
   {{0x67201883,0x3964005b,0x92601884,0x7674014b}},	//   _uhlj, _ässä_, ىگىم, _олуф, 
   {{0x66dc020c,0xa0a41885,0x00000000,0x00000000}},	//   _cèke, панд, --, --, 
   {{0x21041886,0xd12c04d3,0x659400a6,0xa0a41887}},	//   रवेश_, ێمی_, _маҷу, чамд, 
   {{0xdfd0099f,0x2b5800ca,0xa3481064,0x63a8003a}},	//   ريس_, _nwsc_, _узла_, qven, 
   {{0x6fd00332,0x0afc0154,0xdea01888,0x00000000}},	//   _sócú, ্গুল_, ریجی, --, 
   {{0x2cf81889,0x00000000,0x00000000,0x00000000}},	//   ्कूल_, --, --, --, 
   {{0x201c0cc1,0x2b58031c,0xd944010b,0x1f64011c}},	//   ətin_, _bwsc_, җеди, _еким, 
   {{0x7124188a,0x0df002d3,0x2b580142,0x6d6000b8}},	// [1360] _ترول, _ግደፍ_, _cwsc_, _āvaś, 
   {{0x39580042,0x8c38002f,0x7b1001f4,0x00000000}},	//   _pwrs_, _haßl, väus, --, 
   {{0x1d08188b,0xda08007b,0x00000000,0x00000000}},	//   _гени_, حياه_, --, --, 
   {{0x7b100d16,0x00000000,0x00000000,0x00000000}},	//   täus, --, --, --, 
   {{0x8c38002f,0x00000000,0x00000000,0x00000000}},	//   _maßl, --, --, --, 
   {{0x7b1003fa,0x00000000,0x00000000,0x00000000}},	//   räus, --, --, --, 
   {{0xceb00375,0xe7c001ad,0xc51000f2,0x1d900092}},	//   תיו_, _शपथप, کبوت, _ምግቦች_, 
   {{0x636001f2,0x15b80220,0xd37813d6,0x1cb80327}},	//   _ịnar, _қызы_, бчо_, _ཙོས_, 
   {{0x66dc0066,0x629401e4,0x00000000,0x00000000}},	//   _sèke, ĵzon, --, --, 
   {{0x66dc020c,0xe97000f7,0x43d0007b,0x00000000}},	//   _pèke, _سۇۇد, عزيز, --, 
   {{0xa6a800db,0x00000000,0x00000000,0x00000000}},	//   _باقق_, --, --, --, 
   {{0x09f40375,0x2a600208,0x2c1c000d,0x855400df}},	//   למים_, zahb_, _मरलू_, _זשאב_, 
   {{0xa3cc10dc,0xbff8188c,0xdfd005d9,0x9fa40032}},	//   रहण_, зеях_, نيٽ_, мырҙ, 
   {{0x9f4c022c,0x00000000,0x00000000,0x00000000}},	//   ðnám_, --, --, --, 
   {{0x050c00fe,0x00000000,0x00000000,0x00000000}},	//   াগৰৰ_, --, --, --, 
   {{0xc8a805f9,0xd7bc0073,0x01f8011a,0x00000000}},	//   _घोंट, ्हाच, _לפול, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [1370] --, --, --, --, 
   {{0x8018188d,0xa3cc000d,0x6ed000bc,0x98a801ef}},	//   _عزيز_, रहत_, _सकिँ, _tubě_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3ce0188e,0xeff00023,0x00000000,0x00000000}},	//   chiv_, _ቃልዕ_, --, --, 
   {{0xd3640272,0x47880408,0x00000000,0x00000000}},	//   _جه_, ссем_, --, --, 
   {{0x2ca8188f,0x7b100e78,0xae000210,0xf1dc07b7}},	//   ldad_, säur, _ईशान_, मनान, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2ca81890,0xdddc007f,0x81c80154,0x00000000}},	//   ndad_, _depň, _রইল_, --, 
   {{0x2ca81891,0x2cb80b45,0xe73800a9,0xdb040419}},	//   idad_, _mnsd_, _grŵp_, _hrká, 
   {{0x2ca80399,0xe2980063,0xe1f81892,0x00000000}},	//   hdad_, цао_, жго_, --, 
   {{0x2ca80198,0x93c81893,0xb5fc0003,0x00000000}},	//   kdad_, مایہ_, _reġg, --, 
   {{0xe3b800f0,0x14c800f1,0x00000000,0x00000000}},	//   _млеч_, _وهلی_, --, --, 
   {{0x2ca81894,0x7648030a,0xdddc0100,0x33b004b3}},	//   ddad_, _yfdy, _zepň, _مەير, 
   {{0x2ca80dd4,0x248c1895,0x00000000,0x00000000}},	//   edad_, lfem_, --, --, 
   {{0xa0a41896,0x3ce00218,0x93100137,0x248c007c}},	//   _жайд, thiv_, _جووش, ofem_, 
   {{0xb5fc031c,0xc97c0092,0x00000000,0x00000000}},	//   _weġg, _ያልፋል_, --, --, 
   {{0xdb041897,0x248800e8,0x69c00ca8,0x00000000}},	// [1380] _arká, _ñamu_, _àlej, --, 
   {{0x3ce00218,0x2ca805d5,0x9db800c0,0x8d640092}},	//   shiv_, adad_, _дыму_, ድባቸው_, 
   {{0x1d2400d1,0x69100267,0x2ca81898,0xb8200037}},	//   _омом, våer, bdad_, _बरहम_, 
   {{0xa3cc1899,0xdddc0100,0xf1a0000d,0x753c00e5}},	//   रहा_, _repň, _ओईसन, _érzi, 
   {{0x8cd8189a,0xd7080276,0xdaa00124,0x2c0000db}},	//   नसरो, онде_, _иҳаҩ, _бүтм, 
   {{0x473000d6,0x248c0158,0xb5fc031c,0x38c80244}},	//   вніс, efem_, _leġe, _کاسی_, 
   {{0x248c015d,0xceb00a7c,0x691001e3,0x00000000}},	//   ffem_, כיג_, råer, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x224805d1,0x81c80154,0x6910007c,0x00000000}},	//   _şaka_, _রেল_, påer, --, 
   {{0xd628189b,0x660c123d,0x662800e5,0x56f0009d}},	//   _дозе_, şaka, áskö, _шүлс, 
   {{0x9484189c,0x97000075,0x02a002d5,0x2ca80067}},	//   _жылд, _كېچى, трым, ydad_, 
   {{0x3d08033f,0x00000000,0x00000000,0x00000000}},	//   वकों_, --, --, --, 
   {{0x0440189d,0xb5fc031c,0xef6401c6,0x823000e5}},	//   _речн, _deġe, ээнү, ٹریا, 
   {{0x2cb8189e,0x8230030f,0x00000000,0x00000000}},	//   _snsd_, عریا, --, --, 
   {{0xdc38189f,0xc3240597,0x2ca80369,0x201c0213}},	//   _açık, _تكون_, tdad_, ətim_, 
   {{0x66dc020c,0x2ca805c7,0xec340139,0x00000000}},	//   _mèka, udad_, енбь, --, 
   {{0x2ca818a0,0x2d8c002e,0x28d40073,0x00000000}},	// [1390] rdad_, ŋee_, _दवबि, --, 
   {{0xcf2418a1,0x7a54007b,0x00000000,0x00000000}},	//   _تربي, نضما, --, --, 
   {{0x2ca80280,0x7c580131,0xeb340131,0xc5f000cc}},	//   pdad_, سلەر_, _ۋىجد, _চুনা_, 
   {{0x2ca80067,0x00000000,0x00000000,0x00000000}},	//   qdad_, --, --, --, 
   {{0xf7f418a2,0xf748007b,0x00000000,0x00000000}},	//   پسند, وجوه_, --, --, 
   {{0xf77018a3,0xdb04037e,0x16a418a4,0xb3b40154}},	//   شاه_, _arkæ, евши_, টহাজ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x291800d2,0xfb0000b0,0x00000000,0x00000000}},	//   _ósa_, āīō_, --, --, 
   {{0xe3b018a5,0xbef8037e,0x93a0022e,0xd36c009f}},	//   ارب_, _sにmn, _ro惣x, مهي_, 
   {{0x248c004e,0xe3b000cf,0x14200022,0x00000000}},	//   sfem_, _ۅرت_, ыдым, --, 
   {{0x22140108,0x668001e2,0x00000000,0x00000000}},	//   эфир, _لیږل, --, --, 
   {{0xe3b0007b,0x00000000,0x00000000,0x00000000}},	//   _مرت_, --, --, --, 
   {{0xca3418a6,0xb5fc0135,0xcf400108,0xd8d400d9}},	//   _iaʝu_, _veġe, лняй, גורט_, 
   {{0xd36c16cb,0xc760010c,0x6224185e,0x644818a7}},	//   _اهو_, _ስደተኛ_, _كىشل, lcei, 
   {{0xca34166a,0x628000b5,0x64480356,0xe0d800d4}},	//   _kaʝu_, mglo, ocei, _нвк_, 
   {{0x644818a8,0x628018a9,0x7cfc0139,0x00000000}},	//   ncei, lglo, gärе, --, 
   {{0xc5f004c5,0x644800a3,0x00000000,0x00000000}},	// [13a0] _চুমা_, icei, --, --, 
   {{0x62800652,0x00000000,0x00000000,0x00000000}},	//   nglo, --, --, --, 
   {{0x984802e8,0x62800142,0x00000000,0x00000000}},	//   пяла_, iglo, --, --, 
   {{0x38600491,0x66dc0066,0x48e000c0,0xe8e80ee8}},	//   úir_, _rèka, лохв, ورنو_, 
   {{0x64480007,0x66dc007f,0xcc38010f,0x47d00154}},	//   dcei, _sèka, _מעכט, _দেবী, 
   {{0x62800427,0x00000000,0x00000000,0x00000000}},	//   jglo, --, --, --, 
   {{0x25a400d8,0x9a7c0092,0x86c002de,0x00000000}},	//   _csll_, _ያምናል_, ايىن, --, 
   {{0xd37818aa,0x628018ab,0x00000000,0x00000000}},	//   пчо_, eglo, --, --, 
   {{0x48e018ac,0x00000000,0x00000000,0x00000000}},	//   _сотв, --, --, --, 
   {{0x628018ad,0x66dc007f,0x15b0129d,0x57bc01f9}},	//   gglo, _tèka, _مەتس, ्हीह, 
   {{0x64480007,0x661018ae,0xdb04013d,0xb5fc031c}},	//   bcei, _پژوا, _irkä, _weġb, 
   {{0x644818af,0xfbe005f9,0x1db801ad,0x62800356}},	//   ccei, फनाम, _उपजत, aglo, 
   {{0xb4dc0490,0x628018b0,0x00000000,0x00000000}},	//   डसी_, bglo, --, --, 
   {{0xa3cc070f,0x00000000,0x00000000,0x00000000}},	//   रहर_, --, --, --, 
   {{0x4d2400d8,0x00000000,0x00000000,0x00000000}},	//   еќаа, --, --, --, 
   {{0x42a402d3,0x7094013d,0x4ba4004e,0x48d800cc}},	//   _ገበናት_, _раиф, нөгү_, _ভদ্ৰ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [13b0] --, --, --, --, 
   {{0xff5000c6,0x64480369,0xbb1800d1,0x3f6402e8}},	//   _اخي_, zcei, ىزلا_, _стъб, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x1cb8025c,0x6d5401a4,0x79a40124,0x00000000}},	//   _ཙོག_, mpza, ыруе, --, 
   {{0x6d540d27,0x00000000,0x00000000,0x00000000}},	//   lpza, --, --, --, 
   {{0x6b8c18b1,0xbdf818b2,0x6280062c,0x00000000}},	//   mtag, _آریا_, xglo, --, 
   {{0x6b8c18b3,0xa50818b4,0x660400a7,0x94ec03b9}},	//   ltag, мека_, ъпка, lşən_, 
   {{0xdb040624,0x628018b5,0xe3b818b6,0x69c40472}},	//   _erkä, wglo, дби_, mxhe, 
   {{0xf770086e,0x644818b7,0x628018b8,0x291c0472}},	//   _هال_, rcei, tglo, mlwa_, 
   {{0x6b8c18b9,0x291c18ba,0x644818bb,0x56f018bc}},	//   itag, llwa_, scei, _күчс, 
   {{0x291c18bd,0x69c418be,0x6b8c1368,0xb6e401af}},	//   olwa_, nxhe, htag, _сютк, 
   {{0x63ac0b4b,0x6b8c18bf,0x62800042,0x64480369}},	//   _šanu, ktag, sglo, qcei, 
   {{0x6b8c18c0,0x628018c1,0x6d5401f5,0x69c4036e}},	//   jtag, pglo, epza, hxhe, 
   {{0xe1f01060,0x6b8c18c2,0x1cb80003,0x3ae418c3}},	//   _پست_, dtag, _ཙོང_, _köpe_, 
   {{0x8d6015ed,0x6b8c18c4,0x69c40200,0x00000000}},	//   ивре, etag, jxhe, --, 
   {{0x01c000c7,0xb3540345,0x00000000,0x00000000}},	//   _арҩҭ, _جییا_, --, --, 
   {{0x6b8c10c7,0xcb6418c5,0x291c0a07,0x6d540d27}},	// [13c0] gtag, кате_, dlwa_, apza, 
   {{0x291c18c6,0xc0c400fb,0x61ec00cd,0x1e9418c7}},	//   elwa_, _рәүи, _śaly, _ррир, 
   {{0x7f440d04,0x598418c8,0x394401ef,0x00000000}},	//   _huiq, тлеб, _čmss_, --, 
   {{0x1b48036b,0x291c02e2,0x6b8c18c9,0x00000000}},	//   _озми_, glwa_, btag, --, 
   {{0x6b8c00ad,0x272801f1,0x660c18ca,0xe97000f7}},	//   ctag, kúnd_, şakl, _ۇۇلد, 
   {{0x66dc007f,0x291c18cb,0x68e8031c,0xd5b800d8}},	//   _dèko, alwa_, _ċede, дси_, 
   {{0x66dc04fb,0x1dd018cc,0x186801a9,0x349418cd}},	//   _tèkn, सहित, _оави_, гайр, 
   {{0xdddc00b0,0xa3cc00cd,0xb4dc06e3,0x00000000}},	//   _nepō, रहं_, डसे_, --, 
   {{0xccf0025f,0x07a00598,0xc7a018ce,0x7f440481}},	//   יכה_, _катн, _китк, _nuiq, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xebb80a28,0x6b8c18cf,0xdb040240,0x00000000}},	//   maḥ_, ztag, _askë, --, 
   {{0xebb80882,0x6b8c18d0,0x85f40375,0x290403b2}},	//   laḥ_, ytag, _בצבע_, _ílat_, 
   {{0x7f441730,0xdddc007f,0x6b8c18d1,0x9960012c}},	//   _cuiq, _depō, xtag, _níže_, 
   {{0xebb81161,0x6b8c01e3,0x291c0472,0x41c00014}},	//   naḥ_, vtag, zlwa_, _چٲوِ, 
   {{0xcfc8045e,0xdb0400e8,0x518402dd,0x00000000}},	//   _লেখন, _eskë, _рула, --, 
   {{0xebb81161,0x6b8c18d2,0xa25001d9,0x8c38002f}},	//   haḥ_, ttag, _پھیش, _maßv, 
   {{0xebb80a28,0x6b8c18d3,0xfc6402e8,0x7b4400d1}},	// [13d0] kaḥ_, utag, ръсн, ۇئەل, 
   {{0x6b8c18d4,0x7a400232,0xebb80882,0x2fd80368}},	//   rtag, vští, jaḥ_, mysg_, 
   {{0x6b8c18d5,0xebb80a28,0x291c18d6,0xac98007b}},	//   stag, daḥ_, tlwa_, _كندا_, 
   {{0x6b8c18d7,0x6d44003e,0x69c40023,0x25b8022a}},	//   ptag, _iuha, rxhe, _čsl_, 
   {{0x6d4418d8,0x0a6818d9,0xb5fc0327,0x27280022}},	//   _huha, _орви_, _reġa, húne_, 
   {{0x6f1418da,0xebb80882,0x6604010b,0xdbc4002f}},	//   nozc, gaḥ_, лпла, löße, 
   {{0x6d4418db,0x291c07ab,0x8c38002f,0x00000000}},	//   _juha, plwa_, _paßw, --, 
   {{0x66dc02e2,0x63880240,0xe3a80114,0x2d980150}},	//   _zèkl, _nënç, екид_, _ﺘﺴﻤﻰ_, 
   {{0x6d4418dc,0xdddc0100,0x82600131,0x937001e1}},	//   _luha, _repō, لۇشن, _è̟̟t, 
   {{0x63ac0bb8,0x2fd80cfd,0x130400c9,0xebb80882}},	//   _šans, dysg_, лный_, caḥ_, 
   {{0x6d4418dd,0xc0cc02d3,0x7f4418de,0x85440024}},	//   _nuha, _ኣምር_, _suiq, _рэзе, 
   {{0x69c0004a,0x00000000,0x00000000,0x00000000}},	//   _àleu, --, --, --, 
   {{0x6d44166a,0x7f4418df,0x77600218,0x02c001af}},	//   _auha, _quiq, _xwmx, _вилү, 
   {{0x6d4418e0,0x201c18e1,0x27280419,0x236c01bf}},	//   _buha, āti_, búne_, msej_, 
   {{0x217401c6,0x236c00d7,0x9b0401a9,0x00000000}},	//   _сулр, lsej_, ҳзад, --, 
   {{0x7f440393,0xeff00023,0x00000000,0x00000000}},	//   _tuiq, _ሃልዩ_, --, --, 
   {{0xebb81161,0x6d4418e2,0x9c2418e3,0x00000000}},	// [13e0] yaḥ_, _euha, удад, --, 
   {{0x6d440109,0x656003ac,0x00000000,0x00000000}},	//   _fuha, _owlh, --, --, 
   {{0x6d440537,0xebb80a28,0x57bc02ab,0x79e801d3}},	//   _guha, vaḥ_, ्ह्ह, خواہ_, 
   {{0xf754069c,0x5e440014,0xe6b401b9,0x0d80010a}},	//   _ዝተፈላ, _جنگٕ, یلنگ, _улюн, 
   {{0x7d0418e4,0xebb818e5,0x6d4418e6,0x236c0419}},	//   mnis, taḥ_, _zuha, jsej_, 
   {{0x7d0418e7,0x6d4418e8,0x236c0030,0x0858004e}},	//   lnis, _yuha, dsej_, _үчтө_, 
   {{0xebb81161,0x057017de,0xb9240241,0x00000000}},	//   raḥ_, مايد, _musẹ_, --, 
   {{0x337418e9,0xebb80a28,0x2ed018ea,0x321c0022}},	//   агир, saḥ_, _सक्त, _ryvy_, 
   {{0x7d0418eb,0xd70818ec,0xebb80882,0x324c0092}},	//   inis, _знае_, paḥ_, _ነበረባ, 
   {{0x7d0418ed,0x92b400c6,0x272800e4,0x15440064}},	//   hnis, احظا, túne_, _бежм, 
   {{0xf48403e6,0x6f1402fb,0x25640014,0x2fd80042}},	//   _ناشی, vozc, _نانُ, wysg_, 
   {{0x6d4418ee,0x2ba418ef,0x7d0418f0,0x272800e4}},	//   _ruha, _ऑनला, jnis, rúne_, 
   {{0x7d0418f1,0x6d4418f2,0xdb0400e4,0x799c035a}},	//   dnis, _suha, _eské, _lprw, 
   {{0x6d4418f3,0x0dc818f4,0x02a000a7,0x69c00bcd}},	//   _puha, нуби_, _гръм, _áleg, 
   {{0x7d0418f5,0x6d44002e,0x864802d3,0x6f140866}},	//   fnis, _quha, _ሓጢኣት, rozc, 
   {{0x7d0418f6,0x6d4418f7,0x6c540474,0x506401af}},	//   gnis, _vuha, ркау, _стка, 
   {{0x6d4418f8,0xdbc40730,0x799c127b,0x6f1401e4}},	// [13f0] _wuha, röße, _aprw, pozc, 
   {{0x7d0418f9,0x9f400004,0x1df401d3,0x81c80154}},	//   anis, szkã_, اکیب_, _রেট_, 
   {{0x7d0418fa,0x629c013f,0xce300214,0x2b480784}},	//   bnis, ɑsod, _دودک, sqac_, 
   {{0xd244168d,0x01f8008f,0x61f40aa6,0x660c03e0}},	//   _ژن_, עפאל, úzli, şakk, 
   {{0x2d9005f5,0x0b8800a7,0x00000000,0x00000000}},	//   ltze_, _ясни_, --, --, 
   {{0x2d9001c4,0x6b9c02d0,0x00000000,0x00000000}},	//   otze_, _ipsg, --, --, 
   {{0x2d9018fb,0xe7240051,0xe4c40dab,0x00000000}},	//   ntze_, _cưỡ, ийки, --, 
   {{0x67d418fc,0x2d9001a1,0x23b418fd,0xe7240208}},	//   _кобу, itze_, لمعس, _dưỡ, 
   {{0xd76401ec,0xd3440133,0xe3b0007b,0x78a40037}},	//   _نەنى_, لینه_, زرة_, õive, 
   {{0x3ae404f3,0x00000000,0x00000000,0x00000000}},	//   _köpa_, --, --, --, 
   {{0x20c405f5,0x03c402dd,0x236c00d7,0x1b2000cc}},	//   айнм, _әсем, ssej_, _ভূঁই_, 
   {{0xf53000c6,0x236c18fe,0x00000000,0x00000000}},	//   _فإن_, psej_, --, --, 
   {{0x7d0418ff,0x3ae41900,0x8c380e78,0x2d901901}},	//   vnis, _löpa_, _maßs, etze_, 
   {{0x7d041902,0x00000000,0x00000000,0x00000000}},	//   wnis, --, --, --, 
   {{0x6b9c03ac,0xa3cc012d,0x00000000,0x00000000}},	//   _apsg, रहक_, --, --, 
   {{0x7d041903,0x8c40004e,0x00000000,0x00000000}},	//   unis, жете, --, --, 
  
   {{0x5a641904,0x7d041905,0x959802d3,0x2d901906}},	// [1400] икаб, rnis, _ለይትን_, atze_, 
   {{0x7d041907,0x799c03ac,0x00000000,0x00000000}},	//   snis, _pprw, --, --, 
   {{0x7d041908,0xb5fc0327,0x8e78011a,0x00000000}},	//   pnis, _reġo, _בניה, --, 
   {{0xd7f81909,0x7d04190a,0xfc040166,0x3ae401e3}},	//   кул_, qnis, _гомү, _döpa_, 
   {{0x9ac40014,0x00000000,0x00000000,0x00000000}},	//   _پۯاہ_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x18a4059f,0x98a4030d,0xc6a0003b,0x00000000}},	//   _кавм, _киве, ірши, --, 
   {{0xe97001ec,0x63b80042,0xb788190b,0x23b003ce}},	//   _ءۇند, _brwn, _бәке_, जिंद, 
   {{0x63b803cb,0x1cb8031c,0x79540244,0x00000000}},	//   _crwn, _ཙོན_, _ئێڵا, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x80b00011,0x3ce00037,0x94a801ee,0xd4a4022e}},	//   টান্, kkiv_, _атла_, _вией, 
   {{0x1cb0031c,0x63b80142,0x8c38002f,0x8d740345}},	//   ྟབས_, _frwn, _maßr, یازا, 
   {{0x893400c8,0x63b80142,0xaac8190c,0x645c0165}},	//   ירטע_, _grwn, रामक, ñsie, 
   {{0xafc4030c,0x00000000,0x00000000,0x00000000}},	//   _ۇيعى, --, --, --, 
   {{0xdb040054,0x272800c6,0x8c6401b9,0x2d90005a}},	//   _askï, núna_, итад, utze_, 
   {{0x2d9001c0,0x8bb400d1,0x6fb40066,0x00000000}},	//   rtze_, ақму_, _همبا, --, 
   {{0x6f9400c6,0x00000000,0x00000000,0x00000000}},	// [1410] _الخض, --, --, --, 
   {{0x8d8400cf,0x8aa400ea,0x7bc000de,0x00000000}},	//   _кумд, јрад, _šmuc, --, 
   {{0xc984190d,0xdb2401d3,0x41bc190e,0x00000000}},	//   рузи, حولی, एमएस, --, 
   {{0xcc840133,0x00000000,0x00000000,0x00000000}},	//   _خۆره_, --, --, --, 
   {{0x47880408,0xfbc80b98,0xdc980a7c,0x1ac400cc}},	//   тсем_, रमणम, _גירל, _এতৰা, 
   {{0x27280af2,0xd5940092,0x00000000,0x00000000}},	//   fúna_, _መርምሮ_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe91800d6,0x64440477,0xe2840116,0x88440345}},	//   _собі_, _ğhis, әлни, _ئیشق_, 
   {{0xa824190f,0xdd001710,0xd5ac0014,0x5fc4000d}},	//   _اکان, šuću, وہے_, _लपइल, 
   {{0xa2e41910,0x27281911,0xe2c8009d,0x00000000}},	//   соод, búna_, улод_, --, 
   {{0xa0681912,0xa0c41913,0xe04401d5,0x00000000}},	//   лана_, ميدو, йнни, --, 
   {{0x21a4039b,0xa3b800ec,0x00000000,0x00000000}},	//   _ҳикм, _ماتر_, --, --, 
   {{0xe2981914,0x63b80223,0xc32c0014,0x00000000}},	//   _бал_, _urwn, _ہٕچ_, --, 
   {{0x63a81915,0x00000000,0x00000000,0x00000000}},	//   mwen, --, --, --, 
   {{0xd00c00db,0x00000000,0x00000000,0x00000000}},	//   _ۋلى_, --, --, --, 
   {{0x1c4400c0,0x00000000,0x00000000,0x00000000}},	//   снам, --, --, --, 
   {{0x2554002d,0xd0f8008f,0x00000000,0x00000000}},	// [1420] _hāld_, _תּור, --, --, 
   {{0x2554002d,0x9a681916,0x1cb8031c,0x63a801c7}},	//   _kāld_, امال_, _ཙོམ_, iwen, 
   {{0x63a81917,0x60d41918,0xdca4022e,0x00000000}},	//   hwen, _koym, _лани, --, 
   {{0x272800d2,0x60d4037e,0x57e81919,0x69c000bc}},	//   vúna_, _joym, лдем_, _šlec, 
   {{0x63a8191a,0x00000000,0x00000000,0x00000000}},	//   jwen, --, --, --, 
   {{0x63a8191b,0x60d40477,0xaac81221,0x8f9800d9}},	//   dwen, _loym, राणक, ריסי, 
   {{0x63a8191c,0xc7ac01ed,0x38600174,0xc0f80092}},	//   ewen, وڑے_, ðirs_, ፈጽሙ_, 
   {{0x63a8191d,0xf4d8191e,0x98a416a3,0x2728191f}},	//   fwen, рмиш_, dmoć_, rúna_, 
   {{0x96941920,0x73340116,0x00000000,0x00000000}},	//   _греш, يىبا, --, --, 
   {{0xd344036b,0x69c00077,0x77e401ad,0x00000000}},	//   لیچه_, _álec, कनीक_, --, 
   {{0x3ae40793,0x60d401a9,0x63a80036,0x51840108}},	//   _löpo_, _boym, awen, щупа, 
   {{0x63a81921,0x60d40076,0x39580789,0x66dc007f}},	//   bwen, _coym, _mtrs_, _rèki, 
   {{0x63a80944,0x60d41922,0x94a801ee,0x03a000f3}},	//   cwen, _doym, _атһа_, _ницо, 
   {{0xb5fc038f,0x66dc0100,0x39581923,0x63bc1924}},	//   _reġj, _pèki, _otrs_, æsne, 
   {{0xc170007b,0x70581925,0x00000000,0x00000000}},	//   _فديت, _кайр_, --, --, 
   {{0x9984006d,0x60d41926,0x90e41927,0x48c000fe}},	//   łoś_, _goym, _دستن, _শত্ৰ, 
   {{0xdb0400e4,0x4f6801d5,0x4ea400d8,0x8c40030d}},	// [1430] _eskí, _ёшим_, _лрна, çесе, 
   {{0x6e980006,0xaac800bc,0x25a80210,0x00000000}},	//   _твор_, राधक, łali_, --, 
   {{0x63a81928,0x7f3c00c8,0x39580334,0x60d40718}},	//   zwen, _געזו, _ctrs_, _yoym, 
   {{0x63a81929,0x0ca8192a,0x6aa40112,0x77540023}},	//   ywen, _стои_, sehf, _ዝተመሰ, 
   {{0x63a8192b,0x3958004e,0x25540055,0x78a4000d}},	//   xwen, _etrs_, _māle_, õiva, 
   {{0x9ba0192c,0xe738192d,0x63a8192e,0x201c054e}},	//   _تەكى, шел_, vwen, ştig_, 
   {{0x63a8192f,0x55501930,0x04140241,0x00000000}},	//   wwen, وپور, _àjẹk, --, 
   {{0x3ddc0154,0x00000000,0x00000000,0x00000000}},	//   _ডেডল, --, --, --, 
   {{0x68e81931,0x63a81932,0xd36c05d9,0x98f000aa}},	//   _iled, uwen, نهي_, _تګلا, 
   {{0x63a81933,0x68e8038e,0x60d41934,0x2bd000bc}},	//   rwen, _hled, _soym, _सपना, 
   {{0x63a81935,0x68e81936,0x2b58070d,0x290c0158}},	//   swen, _kled, _ltsc_, _kjea_, 
   {{0x63a81937,0x60d41938,0x68e8020c,0x00000000}},	//   pwen, _qoym, _jled, --, 
   {{0x63a80912,0x2b581939,0x60d4062c,0x442400db}},	//   qwen, _ntsc_, _voym, _اراف, 
   {{0x68e80368,0x539802e4,0x77640003,0x00000000}},	//   _lled, _כינו, ġixx, --, 
   {{0x8234193a,0x2b580098,0x290c0005,0x60d4193b}},	//   _ارشا, _atsc_, _ojea_, _toym, 
   {{0x3958193c,0xb3700050,0xdf480276,0xdb0c02d2}},	//   _rtrs_, _تۯیش, _кзид_, _íjúl, 
   {{0xa2cc193d,0xc0f00092,0x00000000,0x00000000}},	// [1440] ताप्, _ሃምሳ_, --, --, 
   {{0x68e8193e,0x290c005a,0x255400e2,0xe7240133}},	//   _aled, _ajea_, _zāle_, _سڵ_, 
   {{0x68e8193f,0x00000000,0x00000000,0x00000000}},	//   _bled, --, --, --, 
   {{0x68e81940,0x718c00df,0xedc801f7,0x00000000}},	//   _cled, רװאַ, _اِٽي_, --, 
   {{0x68e8020c,0x26c401e7,0x26e4033f,0x27281941}},	//   _dled, _bnlo_, कसूर_, rúnn_, 
   {{0x68e81942,0x61ec0b45,0x290c0789,0xda700014}},	//   _eled, _ƙall, _ejea_, _زُر_, 
   {{0x68e81943,0xa2cc1944,0x7a3001e1,0xf8b81945}},	//   _fled, तान्, _dótí, _гөл_, 
   {{0xe3b8031c,0x86040131,0x983400c0,0x00000000}},	//   _ཙནྡ྄, تقىق_, _дэзі, --, 
   {{0xded0069c,0x394401f9,0x00000000,0x00000000}},	//   _ከምኡ_, _iims_, --, --, 
   {{0xb5fc003d,0x068000cf,0x00000000,0x00000000}},	//   _leġi, _огун, --, --, 
   {{0x611000e2,0xf7080208,0x68e803ac,0x255400b8}},	//   zāle, của_, _yled, _pāle_, 
   {{0x39441946,0x4fc40150,0x00000000,0x00000000}},	//   _jims_, осга, --, --, 
   {{0x39440b0e,0x7afc0010,0xe4c802e9,0xc498011a}},	//   _mims_, _omrt, _دبلن_, _כשאת, 
   {{0xdb0401ef,0x00000000,0x00000000,0x00000000}},	//   _prký, --, --, --, 
   {{0xccf80640,0xb62c00b5,0xad240d1f,0x25540055}},	//   аћа_, _ｒｈ_, كىسى, _tāle_, 
   {{0x39440793,0x66dc00f2,0x201407ea,0x8b6400c6}},	//   _nims_, _hèkt, écié_, قائم, 
   {{0xebc4013d,0x00000000,0x00000000,0x00000000}},	// [1450] чәнн, --, --, --, 
   {{0x6110005f,0x39441947,0x29c801e0,0x63bc0efa}},	//   rāle, _aims_, йтеү_, åsni, 
   {{0xba7410e0,0xe9441056,0x68e81948,0x7bc008ce}},	//   باقت, سرای, _pled, _ámun, 
   {{0x39441949,0x66dc007f,0x7648010b,0x68e8037e}},	//   _cims_, _lèkt, _agdy, _qled, 
   {{0x7afc0cf9,0x3944005c,0x68e8194a,0xa2cc194b}},	//   _fmrt, _dims_, _vled, ताम्, 
   {{0x2ca8194c,0x68e813e9,0x9ba00c50,0xf770194d}},	//   lead_, _wled, _سەمى, ئان_, 
   {{0xd6cc194e,0x68e8194f,0x39440100,0x00000000}},	//   اقى_, _tled, _fims_, --, 
   {{0x2ca81950,0xaac800dc,0x999401d9,0x68e803ac}},	//   nead_, रावक, _ژھۆر_, _uled, 
   {{0x291c1951,0xe2981952,0x2c1c00fe,0x53c400db}},	//   mowa_, бап_, পেৰে_, згым_, 
   {{0x291c1953,0x66dc01e1,0x26c40241,0xb9e01954}},	//   lowa_, _pèku, _unlo_, _ጥብ_, 
   {{0x7d080122,0xe1241955,0xd1dc02d3,0xe298190b}},	//   édsk, змни, _ዕርቂ_, _ғай_, 
   {{0x23741956,0xd5980375,0x00000000,0x00000000}},	//   _فاتح, _לבעל, --, --, 
   {{0x2ca81957,0xb5fc038f,0x44380694,0x626400d8}},	//   dead_, _reġi, _àq_, _евла, 
   {{0x291c1958,0x248c1959,0x442c195a,0x835001d3}},	//   howa_, lgem_, _izg_, _ٹھکا, 
   {{0x66dc0066,0x291c195b,0x2ca800c6,0xb4540133}},	//   _hèks, kowa_, fead_, _رخۆش, 
   {{0x248c092e,0x7afc0118,0x2ca80354,0x61e0195c}},	//   ngem_, _smrt, gead_, myll, 
   {{0x291c195d,0x6ab40115,0x61e0195e,0x3944195f}},	// [1460] dowa_, _bazf, lyll, _rims_, 
   {{0xe3280156,0x8b200b32,0x4b2003b7,0x66dc0066}},	//   _ཤེསཔ_, едуе, емув, _mèks, 
   {{0x61e01960,0x66dc020c,0x291c1961,0x00000000}},	//   nyll, _lèks, fowa_, --, 
   {{0x291c1962,0x442c01a9,0x2ca801c3,0x61e000ad}},	//   gowa_, _ozg_, cead_, iyll, 
   {{0x4cb8025f,0x61e01963,0x6cc407d6,0x39440158}},	//   _הזכו, hyll, _ўқув_, _vims_, 
   {{0x61e00652,0xb4b40c2e,0x248c0036,0x645c0165}},	//   kyll, _छोड़_, egem_, ñsin, 
   {{0x291c1964,0x61e01965,0x3944014a,0x66dc020c}},	//   bowa_, jyll, _tims_, _rèkt, 
   {{0x94a80d30,0x38c804d3,0x442c05c7,0x61e01966}},	//   стка_, _باسی_, _bzg_, dyll, 
   {{0x61e000ad,0x81c803d4,0x57e801c6,0x69d00356}},	//   eyll, _ৰেল_, _удам_, ădeş, 
   {{0x61e01967,0x248c0261,0x76480006,0x6b480024}},	//   fyll, agem_, _ugdy, _užge, 
   {{0x66dc0066,0x9f4c0030,0xbbc80864,0x442c022e}},	//   _vèkt, ľným_, रमुक, _ezg_, 
   {{0xc0580046,0x9f4c0122,0x66dc020c,0x442c0112}},	//   зір_, žným_, _wèkt, _fzg_, 
   {{0x61e00731,0xc2041968,0x942400db,0x2ca81163}},	//   ayll, ققین_, _эмде, vead_, 
   {{0x61e01969,0x61340008,0x291c196a,0x823003c7}},	//   byll, jálf, zowa_, ظریا, 
   {{0x291c196b,0xac94196c,0x255400cd,0x4298011a}},	//   yowa_, мавш, _kāla_, _הסוב, 
   {{0x291c196d,0x255400b8,0x48b400fe,0x00000000}},	//   xowa_, _jāla_, _অক্ৰ, --, 
   {{0x57c40574,0x2ca80fb2,0x8aa4196e,0x0f2402bf}},	// [1470] लमोह, read_, зред, _ньом, 
   {{0x291c196f,0x2ca81970,0x61100aed,0xf1b01971}},	//   wowa_, sead_, māla, _जनान, 
   {{0xa2cc085c,0x291c1972,0x80b0015b,0x2ca800c5}},	//   तात्, towa_, টার্, pead_, 
   {{0xfbd01973,0xdddc0316,0xbb50037e,0xd1e0001f}},	//   ختہ_, _nepř, _dgmシ_, _ምኞት_, 
   {{0x291c1974,0x61100061,0xa7b80137,0x00000000}},	//   rowa_, nāla, юлду_, --, 
   {{0x291c1975,0xd2440597,0xe5a40075,0xdb040140}},	//   sowa_, _لن_, дики, _askæ, 
   {{0x67200fb7,0x248c00cf,0x61101976,0xd5ac0691}},	//   _vklj, tgem_, hāla, لفو_, 
   {{0x61101977,0x61e01978,0x248c1979,0x00000000}},	//   kāla, vyll, ugem_, --, 
   {{0x248c197a,0x61e000a9,0xed80044e,0xddcc0086}},	//   rgem_, wyll, _ክግበር_, rabũ, 
   {{0x67200bb8,0xb9dc067d,0x61e0197b,0x80a0197c}},	//   _uklj, _በቲ_, tyll, ग्ने, 
   {{0x61e00076,0xdfd000ec,0x00000000,0x00000000}},	//   uyll, ھيس_, --, --, 
   {{0x61e0197d,0x66dc07b0,0xa2bc197e,0xdfd001c8}},	//   ryll, _tèks, _वोर्, پيس_, 
   {{0x61e00f7b,0x1ea8197f,0xf484074d,0xa2cc0303}},	//   syll, ياسي_, _чухн, ताद्, 
   {{0x61e01980,0x216800d1,0x95940023,0xdddc013a}},	//   pyll, _дики_, _ዘርብሕ_, _zepř, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc4d8015b,0x1be80353,0x61101981,0x00000000}},	//   _বগুড়, одби_, bāla, --, 
   {{0x645802ce,0xaac80d79,0x613401f6,0x6110002b}},	// [1480] _mfwi, रांक, tálf, cāla, 
   {{0x4f041982,0x4aa40137,0x3ae4010e,0xec3401b9}},	//   _онын_, мкун_, _köpi_, رولگ, 
   {{0x64581983,0x98480126,0x61341984,0xd1dc0092}},	//   _ofwi, ояла_, rálf, _ዕይታ_, 
   {{0x395c005f,0x48e01985,0x00000000,0x00000000}},	//   īvs_, кохв, --, --, 
   {{0x7d041986,0xda641987,0x48dc0037,0x00000000}},	//   miis, _ياسي, _ककरो_, --, 
   {{0x7d041988,0x64581989,0x3f5402b5,0x66dc0066}},	//   liis, _afwi, _mäu_, _sèkr, 
   {{0x0570198a,0x25a40036,0xdddc0118,0x255400b8}},	//   نايد, _cpll_, _pepř, _pāla_, 
   {{0x73d8086f,0x46e40724,0xd378074d,0xc5f000cc}},	//   здир_, здән_, очо_, _চুঙা_, 
   {{0xdddc00bc,0x25540055,0x00000000,0x00000000}},	//   _vepř, _vāla_, --, --, 
   {{0x7d04198b,0x64580117,0x66800014,0x68e80327}},	//   hiis, _efwi, _میٖل, _ċedi, 
   {{0x7d04198c,0xdb0400fd,0x2554198d,0x569401af}},	//   kiis, _iskä, _tāla_, _наҡт, 
   {{0x6110198e,0x7d04198f,0xcfa401c6,0x3214002b}},	//   tāla, jiis, мшги, _ādyā_, 
   {{0x7d041990,0x230800aa,0xb9e0001f,0x6b480010}},	//   diis, _کتني_, _ጥጥ_, _ožga, 
   {{0x61101991,0x69c000f3,0x75201992,0x60640022}},	//   rāla, _šlem, lomz, _ҧхыҷ, 
   {{0x7d040050,0x2fcc0356,0x00000000,0x00000000}},	//   fiis, ţeg_, --, --, 
   {{0x7d041993,0x75200921,0x201c0276,0x611000dc}},	//   giis, nomz, ştia_, pāla, 
   {{0xfd4402d5,0xdb0401e3,0x00000000,0x00000000}},	// [1490] тэрн, _oskä, --, --, 
   {{0x0dc806bb,0xc98407d6,0x705401d9,0x94000213}},	//   _думи_, дуди, _تچھا, ükə_, 
   {{0x7d041994,0x75200912,0x61ec02a8,0x00000000}},	//   biis, komz, _ƙali, --, 
   {{0x7d041995,0xa8141996,0x61340789,0x00000000}},	//   ciis, ндеш, rálg, --, 
   {{0xa874005e,0x78640046,0xc7a81997,0xd874007b}},	//   _үлгі, ткіз, تدال_, رموت_, 
   {{0x797c1682,0x6b8c1998,0x7ac41999,0x00000000}},	//   _ṅwet, muag, _иссе, --, 
   {{0xa2cc0882,0x2cb816b8,0x6b8c199a,0xdcec00c0}},	//   तास्, _kasd_, luag, gubė, 
   {{0xdb04013d,0x75200156,0x00000000,0x00000000}},	//   _eskä, gomz, --, --, 
   {{0x61340122,0x6b8c199b,0x2408199c,0xe298199d}},	//   nále, nuag, янии_, пап_, 
   {{0xe1f8199e,0x6b8c0076,0x7d04199f,0xd1b800ec}},	//   зго_, iuag, ziis, ڳاپا_, 
   {{0x6b8c0421,0xb59400c7,0x77500023,0x7d0419a0}},	//   huag, _аихш, _ንተሳተ, yiis, 
   {{0x7d040014,0x68f8029f,0x8cd003ce,0x33b000db}},	//   xiis, _çadı, डाफो, _چەير, 
   {{0x7d0419a1,0x6b8c0407,0xdb04005b,0x255400dc}},	//   viis, juag, _yskä, _kālo_, 
   {{0x61340232,0x6b8c19a2,0x7d0419a3,0x2d5400fe}},	//   dále, duag, wiis, _båe_, 
   {{0x7d0419a4,0xdca40fd7,0xa0a419a5,0x6b8c0076}},	//   tiis, нави, _зайд, euag, 
   {{0x6b8c096b,0x611019a6,0x3f5400b0,0x00000000}},	//   fuag, mālo, _täu_, --, 
   {{0x7d0419a7,0x613419a8,0x6b8c19a9,0x1954037e}},	// [14a0] riis, ráld, guag, _ｊｕｎ_, 
   {{0x7d0419aa,0x2cb80077,0x752019ab,0x2d540158}},	//   siis, _easd_, zomz, _fåe_, 
   {{0x7d0419ac,0x752019ad,0x6b8c00ad,0x611019ae}},	//   piis, yomz, auag, nālo, 
   {{0x7d0419af,0x2cb801c3,0x21200066,0x6b480427}},	//   qiis, _gasd_, nokh_, _vžga, 
   {{0xbb440124,0x255400cd,0x82540092,0xe7940014}},	//   _аҵак, _bālo_, _ቁሳቁሶ, ناوک, 
   {{0x7520014b,0xdb0c01e1,0x00000000,0x00000000}},	//   womz, _ìjàl, --, --, 
   {{0x1868016c,0x940800ac,0x6b480153,0xaa280014}},	//   _нави_, əbə_, _užga, _ہسہٕ_, 
   {{0xdb040036,0x2cb8002e,0xd94419b0,0x932400f2}},	//   _opkë, _xasd_, _чеби, کربن, 
   {{0xc6c00046,0x7520002f,0xc7a00139,0x00000000}},	//   _өйтк, romz, _йитк, --, 
   {{0xb6c8040b,0x877802e4,0x518419b1,0x27e805ac}},	//   _تارے_, _מאמי, нума, øane_, 
   {{0x61340122,0xe6d80008,0x7520009f,0x6b8c005a}},	//   zále, _þráð, pomz, zuag, 
   {{0x6b8c020b,0x2d5403cd,0x814402f2,0x00000000}},	//   yuag, _råe_, ێنین, --, 
   {{0x201c19b2,0x2cb80165,0xa2cc00dc,0x6b8c009d}},	//   ştin_, _rasd_, ताश्, xuag, 
   {{0x6b8c00ca,0x27280321,0x613419b3,0x3ddc0154}},	//   vuag, túni_, vále, _ডেইল, 
   {{0xa2cc0882,0x00000000,0x00000000,0x00000000}},	//   तार्, --, --, --, 
   {{0x6b8c19b4,0x0ccc09bd,0x613402fb,0x6110005f}},	//   tuag, রস্ত, tále, nāll, 
   {{0x7d2402e7,0xc32001af,0x8538011a,0x00000000}},	// [14b0] افقن, _шмәк, לגלי, --, 
   {{0x6b8c19b5,0xbb8419b6,0xca700133,0x61340118}},	//   ruag, اللي, اناک, rále, 
   {{0x6b8c19b7,0x6134043b,0xbf1419b8,0x00000000}},	//   suag, sále, _сүрә, --, 
   {{0x61340122,0x6c7800c8,0x6b8c04c9,0x2cb80789}},	//   pále, _קאָפ, puag, _uasd_, 
   {{0x6b8c19b9,0x255400b8,0x00000000,0x00000000}},	//   quag, _pālo_, --, --, 
   {{0xf1b0012d,0x00000000,0x00000000,0x00000000}},	//   जबान, --, --, --, 
   {{0xdb0c01e1,0x00000000,0x00000000,0x00000000}},	//   _ìjál, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69c000bc,0xd9b000db,0x233419ba,0x25540171}},	//   _šleh, _مەەد, кхор, _tālo_, 
   {{0xa2e419bb,0xdb880150,0x06a800cc,0x00000000}},	//   тоод, _ﺗﻪﺯﻯ_, _গচকি, --, 
   {{0xe3b019bc,0x182801d3,0x00000000,0x00000000}},	//   _چرت_, _فقہی_, --, --, 
   {{0x656019bd,0xf49419be,0xd24c0014,0x00000000}},	//   _itlh, _مشهد, ٝنی_, --, 
   {{0x3ae4049f,0xfe7819bf,0xe29819c0,0x9878010f}},	//   _köpt_, нүп_, _жал_, וארט, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x61ec0b45,0x65600455,0x81c40171,0x00000000}},	//   _ƙalu, _jtlh, _blēž, --, 
   {{0xe6d801a8,0x3ae4007c,0x00000000,0x00000000}},	//   _þræð, _löpt_, --, --, 
   {{0x1c4419c1,0x9fac0051,0x00000000,0x00000000}},	// [14c0] тнам, gđôg_, --, --, 
   {{0x6560014c,0xa3c8000d,0x00000000,0x00000000}},	//   _otlh, _लछन_, --, --, 
   {{0x656019c2,0xd94419c3,0xdcec05d1,0x6134021c}},	//   _ntlh, вежи, şkır, cálc, 
   {{0x3ae400b0,0xb4b000c5,0x6b4800c0,0xd86000c7}},	//   _röpu_, _ओसे_, _užgn, рҵаҩ, 
   {{0x656019c4,0x64540118,0x00000000,0x00000000}},	//   _atlh, ězil, --, --, 
   {{0xb8700092,0x00000000,0x00000000,0x00000000}},	//   _አሮጌው_, --, --, --, 
   {{0xe71c037e,0x3ae401e3,0xb27400d1,0xe8b019c5}},	//   _vs嵐_, _döpt_, ңлиш, _گەنج, 
   {{0x399c19c6,0x48e01214,0x98a419c7,0xf4340209}},	//   mís_, _косв, _шибе, лейэ, 
   {{0x656019c8,0x969419c9,0x399c19ca,0xd1e00023}},	//   _etlh, _ареш, lís_, ምዒት_, 
   {{0xf1b000bc,0x69c000c0,0x00000000,0x00000000}},	//   _जनआन, _šlei, --, --, 
   {{0x399c19cb,0x00000000,0x00000000,0x00000000}},	//   nís_, --, --, --, 
   {{0x61340118,0x3ae401e3,0x7cf801d3,0x13e8004e}},	//   válc, _köps_, _hírf, _омей_, 
   {{0x399c0597,0x53b406b1,0x9fa401e0,0xa2bc19cc}},	//   hís_, _अनिश, лырҙ, _वोक्, 
   {{0x80b005ac,0x272819cd,0xf19401af,0x59e000cd}},	//   টাগ্, búnu_, _бикь, पहार, 
   {{0x799c003a,0x00000000,0x00000000,0x00000000}},	//   _nqrw, --, --, --, 
   {{0x399c19ce,0x69c005f7,0xdeb001ec,0x7094014b}},	//   dís_, _álei, _құсы, _саиф, 
   {{0x19c00032,0x7b7400ae,0x00000000,0x00000000}},	// [14d0] ҙәрг, لطلا, --, --, 
   {{0x613419cf,0x399c19d0,0x7af400d4,0x00000000}},	//   mála, fís_, азує, --, 
   {{0xd36419d1,0xce3019d2,0x613400dd,0x399c180f}},	//   _گه_, _خودک, lála, gís_, 
   {{0xfc640c04,0x2d9019d3,0x656001c7,0x50c000dc}},	//   _върн, muze_, _rtlh, षयिष, 
   {{0xd36419d4,0x613400dd,0x9cd40302,0x2d9019d5}},	//   _ده_, nála, _עושה_, luze_, 
   {{0x76c40131,0xddcc19d6,0x399c067c,0xa5b80640}},	//   لغىل, labš, bís_, ећих_, 
   {{0x399c19d7,0x61340597,0x2d900223,0xf9d419d8}},	//   cís_, hála, nuze_, _корэ, 
   {{0x65600455,0x00000000,0x00000000,0x00000000}},	//   _vtlh, --, --, --, 
   {{0x2d9019d9,0x00000000,0x00000000,0x00000000}},	//   huze_, --, --, --, 
   {{0x2d9019da,0xba0800b7,0x613419db,0xdb0403b2}},	//   kuze_, _ገባ_, dála, _sskú, 
   {{0x2d9019dc,0x6560047e,0xb1d80108,0x00000000}},	//   juze_, _utlh, вьях_, --, 
   {{0x2d90016c,0x201c03ee,0x00000000,0x00000000}},	//   duze_, ştim_, --, --, 
   {{0x613419dd,0x2d9001f5,0xd24c00f1,0x6384005b}},	//   gála, euze_, تنۍ_, _сгла, 
   {{0x2d9019de,0xe29819df,0x272819e0,0x6d40004a}},	//   fuze_, _чак_, múns_, ïlan, 
   {{0x2d9019e1,0xd3340375,0x931019e2,0x399c004e}},	//   guze_, _גרסה_, _دووش, xís_, 
   {{0x399c19e3,0x613401e7,0x00000000,0x00000000}},	//   vís_, bála, --, --, 
   {{0x613419e4,0x5f2806ed,0x00000000,0x00000000}},	// [14e0] cála, _поим_, --, --, 
   {{0x80a019e5,0x3f8019e6,0x399c19e7,0x6b480064}},	//   ग्रे, _iviu_, tís_, _užgl, 
   {{0x588419e8,0x80d80490,0x2d900526,0x8cbc19e9}},	//   гыла, यापे, cuze_, _लोको, 
   {{0x399c19ea,0x3ae401b8,0xd83819eb,0x00000000}},	//   rís_, _pöps_, нэл_, --, 
   {{0xb8dc19ec,0xdef40201,0x399c180f,0xd708010b}},	//   _अस_, _ለምን_, sís_, ннде_, 
   {{0xd5b819ed,0x399c19ee,0x00000000,0x00000000}},	//   еси_, pís_, --, --, 
   {{0x7bc419ef,0x63b80113,0x98a40421,0x613400e5}},	//   lviu, _aswn, aloā_, zála, 
   {{0xdb0408fb,0xa2a80412,0x97740c4f,0x7bc40064}},	//   _askø, _जॉब्, _مُرش, oviu, 
   {{0x27280f71,0x12e40046,0x7bc419f0,0x705419f1}},	//   gúns_, гінг, nviu, یندا, 
   {{0x7cf819f2,0x613400dd,0x7bc419f3,0x2d9019f4}},	//   _fírg, vála, iviu, yuze_, 
   {{0x3f8019f5,0xb9cc02d3,0x7cf8004e,0x80b0015b}},	//   _aviu_, _ኰነ_, _gírg, য়ান্, 
   {{0x2d9019f6,0x613419f7,0xd1c8151e,0x27280332}},	//   vuze_, tála, _үлде_, súnt_, 
   {{0x8cbc006d,0x8fe0052f,0x2d9019f8,0x72d403a6}},	//   _लोगो, сәйҙ, wuze_, _волф, 
   {{0x61340597,0x438019f9,0x838000aa,0x2d9019fa}},	//   rála, _الوق, _اټوم, tuze_, 
   {{0x613419fb,0x518419fc,0xad2417de,0x7bc40393}},	//   máln, _сула, لىسى, eviu, 
   {{0x2d90043b,0x613401ed,0xaf5400c7,0x00000000}},	//   ruze_, láln, _ҩнқә, --, 
   {{0x7bc40d04,0xc0c0001f,0x2d9004ba,0x23680327}},	// [14f0] gviu, ትንም_, suze_, _ħajk_, 
   {{0x613419fd,0x2fc819fe,0x3a380204,0x63bc037e}},	//   náln, _irag_, _bzrp_, æsni, 
   {{0xc330025f,0x7bc40869,0xa85400cf,0x00000000}},	//   צוע_, aviu, акеч, --, 
   {{0x2fc80151,0x3f800ffb,0x80d800dc,0xcb440209}},	//   _krag_, _yviu_, याये, _әхми, 
   {{0x613419ff,0x6f14010a,0x7bc40356,0x80b000eb}},	//   káln, onzc, cviu, টাচ্, 
   {{0x6b8c1a00,0x2fc801ab,0x613402f0,0x8038010f}},	//   mrag, _mrag_, jáln, אנדע_, 
   {{0x6b8c1a01,0xdac40075,0xeb341a02,0x61341a03}},	//   lrag, _خېلى_, _مىڭد, dáln, 
   {{0x2bc81a04,0x63841a05,0x7cf81a06,0x6b8c1368}},	//   रिपा, агиа, _vírg, orag, 
   {{0x2fc80218,0xe6940276,0x61340306,0x6b8c1a07}},	//   _nrag_, _визы, fáln, nrag, 
   {{0x61101a08,0x61341a09,0x36d401af,0x201c05d1}},	//   māli, gáln, _лоур, ştik_, 
   {{0x7cf8066d,0x6b8c1a0a,0x2fc801d9,0x6ed8146b}},	//   _híre, hrag, _arag_, मानु, 
   {{0xe0441a0b,0x2fc81a0c,0x6b8c1a0d,0x6f140007}},	//   инни, _brag_, krag, enzc, 
   {{0x613403f7,0x9f040a2c,0x2fc81a0e,0x6110005f}},	//   báln, لوحو, _crag_, nāli, 
   {{0x7cf800c6,0xd5c002b5,0x2fc81a0f,0xdcec00bc}},	//   _míre, _whāū_, _drag_, ědče, 
   {{0x6b8c0731,0x442c1a10,0xdc981a11,0x255400ef}},	//   erag, _hyg_, кташ_, _bāli_, 
   {{0x6b8c1a12,0xa2cc00a5,0x2fc81a13,0x61101a14}},	//   frag, ताक्, _frag_, kāli, 
   {{0x6b8c1a15,0x613400dd,0x9b041a16,0x2fc8017a}},	// [1500] grag, lálo, азад, _grag_, 
   {{0x7bc41a17,0x442c00b5,0x0f78011a,0x61100a88}},	//   rviu, _myg_, _שאיב, dāli, 
   {{0x61340765,0x442c0006,0x7e7c1a18,0x6b8c1a19}},	//   nálo, _lyg_, marp, arag, 
   {{0x6b8c1368,0x7e7c1a1a,0x98a41a1b,0x18a41a1c}},	//   brag, larp, риде, радм, 
   {{0x7bc40d04,0xc7a00e91,0x78b00024,0x6b8c1a1d}},	//   qviu, жичк, _įkvė, crag, 
   {{0x7cf80491,0x7e7c0af5,0x61340cde,0x255400e2}},	//   _díre, narp, kálo, _zāli_, 
   {{0x7e7c013c,0x7cf8007b,0x442c1a1e,0x61341a1f}},	//   iarp, _tírd, _ayg_, váln, 
   {{0x7e7c1a20,0x442c04ce,0xd3a41a21,0xd6e00210}},	//   harp, _byg_, ароп, wałą_, 
   {{0x2bc808dd,0x613403c6,0x395801c7,0x08f80014}},	//   रिया, táln, _hurs_, _شرٲب_, 
   {{0x06f01a22,0x7e7c1a23,0xa2cc00cd,0x00000000}},	//   _अतएव_, jarp, ताग्, --, 
   {{0x61341a24,0x7e7c1a25,0xc68c0014,0x7054158b}},	//   ráln, darp, _زِن_, ینگا, 
   {{0x6b8c0731,0x39581a26,0x2d8400bc,0xd38800a7}},	//   yrag, _murs_, álem_, _айде_, 
   {{0x6ef80268,0x7e7c03cb,0x03a000d8,0x052401af}},	//   _lìbe, farp, _мицо, _тоцк_, 
   {{0x6b8c1a27,0x7e7c1a28,0x2fc81a29,0x613401d3}},	//   vrag, garp, _vrag_, láll, 
   {{0x13b40cb2,0x395800a3,0x2bc81a2a,0x61341a2b}},	//   _अनुभ, _nurs_, रिभा, cálo, 
   {{0x7e7c0140,0x90e403e6,0x613401ed,0x6c54068e}},	//   aarp, _خستن, náll, скау, 
   {{0x6b8c1a2c,0x2fc80098,0xfbd0007b,0x3d080037}},	// [1510] urag, _urag_, وتك_, _सगरे_, 
   {{0x6b8c1a2d,0x395805d1,0x2bc80b4c,0x00000000}},	//   rrag, _burs_, रिबा, --, 
   {{0x39581a2e,0x6b8c1a2f,0x7cf801e7,0x6e280790}},	//   _curs_, srag, _dírb, şebb, 
   {{0x6b8c1a30,0x6110005f,0x69c40158,0x69c000e2}},	//   prag, tāli, rvhe, _šles, 
   {{0xd5ac0050,0x613400e5,0x9cd4011a,0xa7a80114}},	//   ہہٕ_, dáll, _הורה_, укла_, 
   {{0x39580561,0x442c1a31,0x69c402c4,0x7cf8007b}},	//   _furs_, _ryg_, pvhe, _víre, 
   {{0xa50803b7,0x442c1a32,0x094800c7,0x39581a33}},	//   лека_, _syg_, _ачаи_, _gurs_, 
   {{0x201c084c,0x613401ed,0xa84801ed,0x7e7c1a34}},	//   ştii_, gáll, _ملزم_, zarp, 
   {{0xe3b000c6,0xf77018fd,0x7e7c1a35,0x232801f0}},	//   سرة_, _ياك_, yarp, лоии_, 
   {{0x61341a36,0xd3441a37,0x69c002d2,0x232800d8}},	//   tálo, مینه_, _áles, ѓони_, 
   {{0x7e7c1a38,0x2b58004e,0x2d8402f0,0xca3c02dd}},	//   varp, _lusc_, šlej_, _ﺟﺎﺯ_, 
   {{0x613403f7,0x30741a39,0x66dc007f,0x442c1a3a}},	//   rálo, журс, _rèky, _tyg_, 
   {{0x7e7c1a3b,0x442c07d6,0x62240131,0x61440075}},	//   tarp, _uyg_, شىڭل, _һека, 
   {{0x7e7c013c,0x5de40022,0x95981954,0x00000000}},	//   uarp, бжга, _ወርቅን_, --, 
   {{0x61441a3c,0x7e7c1a3d,0x80d81a3e,0x613400e5}},	//   _лека, rarp, यादे, lálm, 
   {{0x7e7c1a3f,0x3d080574,0x2b581a40,0x02b41546}},	//   sarp, _सगळे_, _busc_, _असुन, 
   {{0x7e7c1a41,0x39581a42,0xbe54004b,0x8c401a43}},	// [1520] parp, _surs_, _وردګ, зете, 
   {{0x7e7c0680,0x39581570,0x613401ed,0x6ed8194b}},	//   qarp, _purs_, záll, माणु, 
   {{0x2b580327,0x1d0800ee,0x8e380451,0x8e54008f}},	//   _eusc_, _бени_, _مسٽر_, _לייג_, 
   {{0x2b581a44,0x7e600134,0x39580010,0xd00c00f2}},	//   _fusc_, ɛmpa, _vurs_, _آلی_, 
   {{0x25541a45,0x61341a46,0x02b41a47,0x2bc800dc}},	//   _mālu_, váll, _असंभ, रिणा, 
   {{0x611006c8,0x3ce01a48,0x39581a49,0x7cf80332}},	//   mālu, ljiv_, _turs_, _fírc, 
   {{0xceb00302,0x61100421,0x39580d27,0x613401ed}},	//   פיה_, lālu, _uurs_, táll, 
   {{0x3ce007f5,0x4d78010f,0x8a000166,0x8a14011a}},	//   njiv_, ארקע, _эзсе, _החלו_, 
   {{0xbee80490,0x95c40214,0xe5080208,0x38600113}},	//   _ऐकून_, _گياه, vặt_, ñiru_, 
   {{0x27f8007d,0x2bc8193d,0x2d8419b3,0xa6a80345}},	//   _üsna_, रिता, álek_, _نامق_, 
   {{0x2d84031c,0xc6d4009d,0x00000000,0x00000000}},	//   ġlek_, _устө, --, --, 
   {{0x61101a4a,0x463800c8,0x613401ed,0xca340375}},	//   kālu, _געבע, lálj, מניה_, 
   {{0x92d404c5,0xd4340137,0x304800ec,0x00000000}},	//   _সতী_, _اعاب, شلسٽ_, --, 
   {{0x613400dd,0x2b5800db,0x41701a4b,0x00000000}},	//   nálj, _rusc_, _کاوس, --, 
   {{0xc2781a4c,0xe2a81a4d,0x2b5801fa,0x0ca80107}},	//   _גרוי, _خانن_, _susc_, лтаи_, 
   {{0xdb0400dd,0x6b740139,0x00000000,0x00000000}},	//   _eskü, жлау, --, --, 
   {{0x61101140,0xa2cc08e6,0x3b540107,0x996000d0}},	// [1530] gālu, ताच्, зкур, _ríše_, 
   {{0x7cf8004e,0xdd9005d9,0x34c41a4e,0x6e9400ae}},	//   _pírc, _ڪوٽ_, वयुद, _بلدا, 
   {{0x99600232,0x2b580161,0x0dc81a4f,0x6908022e}},	//   _píše_, _wusc_, _супи_, аsdа, 
   {{0xdcb01a50,0x2b580393,0x4a7401e0,0x38580127}},	//   _قىپ_, _tusc_, рыҡт, مشهد_, 
   {{0x6fc801ad,0x66e41a51,0x7f48072d,0x00000000}},	//   िटिं, жола, _خلیق_, --, 
   {{0x38a000b0,0xf7480fb4,0x613401d3,0x2ca80165}},	//   _rōrō_, ملني_, gálj, lfad_, 
   {{0x7cf801d3,0xa5640244,0x1c5403e0,0x00000000}},	//   _híra, زگان, şüşü, --, 
   {{0xe91802bf,0x611000e2,0x2ca80332,0x24e80117}},	//   _тобі_, nālt, nfad_, рмии_, 
   {{0x9f4c00bc,0x80d818cc,0xb0dc024a,0x613401d3}},	//   žném_, यासे, यानग, bálj, 
   {{0x7cf81a52,0x61341a53,0x00000000,0x00000000}},	//   _míra, rálm, --, --, 
   {{0xf7480491,0x04740517,0x614407c6,0xe0d807a5}},	//   _اللي_, _هلاک_, жена, авн_, 
   {{0x6fb80135,0xa2a810eb,0x2d901a54,0xa2cc1a55}},	//   _བརྡའ, _जॉर्, drze_, ताङ्, 
   {{0x3f840300,0x613400dd,0x03640050,0x22c000b0}},	//   ému_, lálk, _أتی_, _pōkē_, 
   {{0x236c1a56,0x00000000,0x00000000,0x00000000}},	//   mpej_, --, --, --, 
   {{0xdd901a57,0x2ca80267,0x255400e2,0x61341a58}},	//   ظور_, ffad_, _tālu_, nálk, 
   {{0xdcb01a59,0xdc6805f5,0x61101a5a,0x20d40111}},	//   بىر_, раад_, tālu, _фікс, 
   {{0x60d41a5b,0x69c01a5c,0x2d901a5d,0x6e280205}},	// [1540] _inym, _šlep, arze_, ğeba, 
   {{0x2d90068f,0x80d80574,0x7cf81a5e,0x61341a5f}},	//   brze_, यावे, _díra, kálk, 
   {{0x3eb81a60,0x7cf800e4,0xa2a0146c,0x25540171}},	//   mert_, _eíra, _खान्, _māls_, 
   {{0x3eb81a61,0x6fe000bd,0x61341a62,0x2ca80332}},	//   lert_, _পেয়ে, dálk, cfad_, 
   {{0x394000da,0x3eb80204,0x7cf8032e,0x613400e5}},	//   ķis_, oert_, _gíra, tálj, 
   {{0x3eb81a63,0xdb0402e2,0xd56404b0,0xf77000ec}},	//   nert_, _eskò, отип, واڙ_, 
   {{0x3eb804c4,0x611000e2,0x613401d3,0x7cf81a64}},	//   iert_, nāls, rálj, _zíra, 
   {{0x3eb81a65,0x60d40083,0x92d400fe,0x6b840244}},	//   hert_, _nnym, _সতে_, _بشێل, 
   {{0x3eb81a66,0x14a41a67,0xdbd8004e,0x287400c7}},	//   kert_, क्षण, nçàv, _хыср, 
   {{0x60d41a68,0x613400dd,0x20000034,0x3eb8045f}},	//   _anym, lálh, dzki_, jert_, 
   {{0xd62805cc,0x74141a69,0x00000000,0x00000000}},	//   _тоже_, توکا, --, --, 
   {{0x613400dd,0x3eb801a4,0x00000000,0x00000000}},	//   nálh, eert_, --, --, 
   {{0x3eb81a6a,0x200400a2,0x53380354,0x30c800e5}},	//   fert_, _ýoil_, _кукă, لڈکپ_, 
   {{0x6ef801e1,0x2d900034,0x7cf80241,0xfe7001d3}},	//   _bìba, trze_, _ríra, ہدہ_, 
   {{0x417008c9,0x7cf81a6b,0x2d841a6c,0x26d8016b}},	//   _قايس, _síra, éle_, _ɑso_, 
   {{0xac581a6d,0x01f80375,0x7cf808a5,0xc10401e2}},	//   сааф_, _כפול, _píra, _يووي, 
   {{0x2000006d,0x3eb81a6e,0x2ca81a6f,0x80d81152}},	// [1550] czki_, bert_, rfad_, यारे, 
   {{0x3eb800db,0x0a680107,0x7cf81a70,0x8a681a71}},	//   cert_, рраи_, _víra, ршаб_, 
   {{0x6d341a72,0x80b003f4,0x6cd41a73,0xfd1000dd}},	//   _неоф, য়ার্, _فقدا, رجہ_, 
   {{0x7cf81a74,0x7c3806ea,0x02b41a75,0x613400e5}},	//   _tíra, ðaræ, _अस्न, gálh, 
   {{0x39480145,0x00000000,0x00000000,0x00000000}},	//   ڭشەپ_, --, --, --, 
   {{0x61340646,0x00000000,0x00000000,0x00000000}},	//   tálk, --, --, --, 
   {{0xe298052f,0x2bc81a76,0xd6cc131e,0x7cf8012c}},	//   ҙан_, रिवा, طقي_, _mírn, 
   {{0xd5ac099f,0x61340122,0xe2980588,0x79581086}},	//   افي_, rálk, әан_, _фитр_, 
   {{0x25a800e8,0x00000000,0x00000000,0x00000000}},	//   ŋal_, --, --, --, 
   {{0x61341a77,0x68e81a78,0x290c0093,0xa20402bf}},	//   máli, _hoed, _hmea_, зпод, 
   {{0x3eb81a79,0x68e81a7a,0x26c40421,0x80d80316}},	//   vert_, _koed, _ialo_, याले, 
   {{0x3eb81859,0x26c41a7b,0x00000000,0x00000000}},	//   wert_, _halo_, --, --, 
   {{0x68e81a7c,0x26c41a7d,0x3eb81a7e,0x290c0605}},	//   _moed, _kalo_, tert_, _mmea_, 
   {{0x26c41a7f,0x3eb81a80,0x68e801f5,0x611000e2}},	//   _jalo_, uert_, _loed, tāls, 
   {{0x26c41a81,0x3eb81a82,0xca3004a2,0x64581a83}},	//   _malo_, rert_, ﺯﯨﺮ_, _kgwi, 
   {{0x3eb81a84,0x68e808c8,0x61341a85,0x9f840395}},	//   sert_, _noed, káli, _егид, 
   {{0x6458055a,0x26c40421,0x9098011a,0x00000000}},	// [1560] _mgwi, _oalo_, _הספק, --, 
   {{0x290c1a86,0x9ccc0327,0x7cf802d2,0x613416d9}},	//   _amea_, _ཌོམྦ, _gírn, dáli, 
   {{0x68e81a87,0x64581a88,0xf8b801e0,0x64bc0073}},	//   _boed, _ogwi, ҙөң_, ्याळ, 
   {{0x62801a89,0x64581a8a,0x68e81a8b,0x26c41a8c}},	//   halo, _ngwi, _coed, _aalo_, 
   {{0x62801a8d,0x68e81a8e,0x613401d3,0xb6c400c7}},	//   kalo, _doed, gáli, мҩад, 
   {{0x26c41a8f,0x64580bd7,0xcb6400d8,0xda701a90}},	//   _calo_, _agwi, _харе_, _سُر_, 
   {{0x26c4154c,0x62801a91,0x68e80483,0x18681a92}},	//   _dalo_, dalo, _foed, _габи_, 
   {{0x68e81a93,0x290c0270,0x7cf80118,0x2368025c}},	//   _goed, _gmea_, _míro, _ħajr_, 
   {{0x62801a94,0x26c41a95,0x61341a96,0x82f401e2}},	//   falo, _falo_, cáli, ګريز_, 
   {{0x26c41a97,0xa2a00490,0x00000000,0x00000000}},	//   _galo_, _खाण्, --, --, 
   {{0x56940184,0x68e80810,0xd7f81a98,0x7cf801e1}},	//   _маҡт, _yoed, _туң_, _níro, 
   {{0x26c41a99,0x62801a9a,0x6458031c,0x93a81a9b}},	//   _zalo_, aalo, _ggwi, _هاتف_, 
   {{0x26c41a9c,0xe5041a9d,0x2554005f,0x93441a9e}},	//   _yalo_, _تبلي, _tālr_, _енде, 
   {{0x26c4004d,0x7b000254,0x0e0809a5,0x91e00166}},	//   _xalo_, _jöud, бэби_, _зәмһ, 
   {{0xa2a00574,0x61341315,0x39441a9f,0x645802d0}},	//   _खात्, záli, _ohms_, _ygwi, 
   {{0x7cf801ef,0x00000000,0x00000000,0x00000000}},	//   _díro, --, --, --, 
   {{0x68e80f7b,0x201c0ab7,0x00000000,0x00000000}},	// [1570] _roed, ştir_, --, --, 
   {{0x7cf800dd,0x68e81aa0,0x290c01bf,0x00000000}},	//   _hírl, _soed, _smea_, --, 
   {{0x26c41aa1,0x68e81aa2,0x7bc0025a,0x00000000}},	//   _ralo_, _poed, _âmun, --, 
   {{0xf9901aa3,0x26c41aa4,0x61340d10,0x39440810}},	//   ابل_, _salo_, táli, _chms_, 
   {{0x26c41aa5,0x62801aa6,0x68e81aa7,0x79a401e0}},	//   _palo_, yalo, _voed, _үрсе, 
   {{0x68e81aa8,0xd7ec08b0,0x61341aa9,0x26c41aaa}},	//   _woed, شكى_, ráli, _qalo_, 
   {{0x26c41aab,0x61341aac,0x68e81aad,0x7cf80789}},	//   _valo_, sáli, _toed, _oírl, 
   {{0x62801aae,0x290c1aaf,0x61341ab0,0x2248010f}},	//   walo, _umea_, páli, _ŝako_, 
   {{0x26c41ab1,0xa2a01ab2,0xf7940006,0x00000000}},	//   _talo_, _खाद्, _патэ, --, 
   {{0x62800618,0x613401d3,0xd8640150,0x00000000}},	//   ualo, nálv, _ﺷﯩﻌﯟ, --, 
   {{0x62801ab3,0x291c01f7,0x64580165,0x4424179e}},	//   ralo, onwa_, _tgwi, _کراف, 
   {{0x64581ab4,0x291c0223,0x61340162,0x00000000}},	//   _ugwi, nnwa_, hálv, --, 
   {{0x73e402bf,0x291c0099,0x2d84000f,0x9f4c00bc}},	//   _поїз, inwa_, âlen_, žním_, 
   {{0x63a81ab5,0x6134022c,0x62801ab6,0x00000000}},	//   mten, jálv, qalo, --, 
   {{0xdca407d6,0xdddc0171,0x00000000,0x00000000}},	//   мави, _iepū, --, --, 
   {{0x20541ab7,0x7cf81ab8,0x3f840393,0x00000000}},	//   _отпр, _víro, ámus_, --, 
   {{0x0fc01ab9,0xd1e002d3,0x00000000,0x00000000}},	// [1580] _айын, _ዝሞተ_, --, --, 
   {{0xc31c1aba,0xe908025c,0xdb1c01b8,0x8e8000c7}},	//   _নীতি_, _གཏུབ_, _ävüd, _игье, 
   {{0x63a81abb,0x18a41abc,0x8fe403e6,0xdb04007c}},	//   hten, даем, _فزیۆ, _oskö, 
   {{0xf4d8045e,0x63a81abd,0x2d9401c6,0xdddc0064}},	//   _তত্ব, kten, _ярьс, _lepū, 
   {{0x09bc038f,0x63a81abe,0x2d840118,0x4cb8011a}},	//   _ཀརྨ_, jten, šlet_, _וזכו, 
   {{0x613405a4,0x291c0083,0x63a80112,0xd1e00023}},	//   málu, anwa_, dten, _ዝሞቱ_, 
   {{0x63a81abf,0xceb00302,0x613401d3,0x00000000}},	//   eten, דיו_, lálu, --, 
   {{0x63a800ed,0x6b480153,0x89d4007b,0x00000000}},	//   ften, _užgr, _توفر_, --, 
   {{0x63a81ac0,0x613401d3,0xc0180055,0x00000000}},	//   gten, nálu, cūḍe_, --, 
   {{0xdcfc00ef,0x00000000,0x00000000,0x00000000}},	//   _appļ, --, --, --, 
   {{0xae940248,0x572000cf,0x54680500,0x00000000}},	//   _mẹtt, _كۉچك, _даем_, --, 
   {{0x63a804ac,0x776000f1,0x1e701ac1,0x613400e5}},	//   bten, _kumx, ңғыс, zálv, 
   {{0x63a81ac2,0x6f4000b8,0xc0581ac3,0x611000e2}},	//   cten, _aśiṣ, дір_, rālp, 
   {{0x7cf801e7,0xf4240154,0x00000000,0x00000000}},	//   _dírm, _পরপর_, --, --, 
   {{0x291c007f,0x272800d7,0x3f841ac4,0x00000000}},	//   ynwa_, gúny_, ámur_, --, 
   {{0x0ccc0c58,0xdec00240,0xdbd80139,0x00000000}},	//   ৰস্ত, ስትኻ_, kçäv, --, 
   {{0x8aa41ac5,0x8f44014b,0x00000000,0x00000000}},	// [1590] дред, _оход, --, --, 
   {{0x2d841ac6,0x27280419,0x00000000,0x00000000}},	//   áles_, búny_, --, --, 
   {{0x63a81ac7,0x6f141ac8,0x61341ac9,0x705400f2}},	//   zten, mizc, rálv, _تنکا, 
   {{0x63a81aca,0x6f1403ee,0xd2440228,0x00000000}},	//   yten, lizc, _ۅن_, --, 
   {{0x6d4c1acb,0x0ba80e56,0x291c0100,0x00000000}},	//   mmaa, _باجى_, rnwa_, --, 
   {{0xd2441acc,0x6d4c1acd,0x613400dd,0x6f141432}},	//   _من_, lmaa, lált, nizc, 
   {{0x6d4c1ace,0x16841acf,0x3a3800a2,0x79a40408}},	//   omaa, راوێ, _gyrp_, _ирте, 
   {{0x6d4c1ad0,0x613400dd,0xe3b0109c,0x00000000}},	//   nmaa, nált, هرخ_, --, 
   {{0x63a81ad1,0x6d4c1ad2,0x7cf801d3,0x391400db}},	//   uten, imaa, _bírj, _рмтр, 
   {{0x63a81ad3,0x6d4c1ad4,0x61340332,0x061c0023}},	//   rten, hmaa, hált, ትራውነ, 
   {{0xa0a40364,0x6d4c1ad5,0xe1f000f2,0x613400e5}},	//   нанд, kmaa, اسخ_, kált, 
   {{0x6d4c0009,0x64c4009f,0x36040066,0x00000000}},	//   jmaa, _سيتل, _جومف, --, 
   {{0xf4841ad6,0x6d4c1ad7,0x613408de,0xc4cc01ed}},	//   _рухн, dmaa, dált, _مےں_, 
   {{0x65601ad8,0x6d4c0430,0x201c0311,0x00000000}},	//   _kulh, emaa, ăti_, --, 
   {{0x65601ad9,0x61341ada,0x6d4c017a,0xd1b801d3}},	//   _julh, fált, fmaa, _فاٹا_, 
   {{0x65600cfc,0x6d4c1adb,0x613401d3,0x10a0030d}},	//   _mulh, gmaa, gált, _биън, 
   {{0x24e000fe,0x7cf800e5,0x00000000,0x00000000}},	// [15a0] _বতাহ, _hírk, --, --, 
   {{0x6f141adc,0x64bc0a59,0x80d800bc,0xed580107}},	//   cizc, ्युश, याके, зоӣ_, 
   {{0x656001e4,0x6d4c058a,0x613401d3,0xdc68014b}},	//   _nulh, bmaa, bált, _нанд_, 
   {{0x6d4c0050,0x97a41add,0x61340d12,0x57a41ade}},	//   cmaa, еркл, máls, ешка, 
   {{0x65601adf,0x7d0402c4,0x613401d3,0x00000000}},	//   _aulh, mhis, láls, --, 
   {{0x7d041ae0,0x8f9800c8,0x65601ae1,0xc6f41ae2}},	//   lhis, פיצי, _bulh, нніх_, 
   {{0x65601ae3,0x64bc0034,0x9484010b,0x613401d3}},	//   _culh, ्यूश, ныпд, náls, 
   {{0x65600066,0xe8b41ae4,0x73d81086,0x38c81ae5}},	//   _dulh, mışı, ддир_, _غازی_, 
   {{0xe8b41ae6,0xa5080131,0xb4b40124,0xe8b00116}},	//   lışı, بىيە_, еиқә, _خەنج, 
   {{0x55e402bf,0x668001d9,0x613401d3,0x7d041ae7}},	//   _позб, _نیٖل, zált, hhis, 
   {{0xc0cc069c,0x7d041ae8,0xe8b41ae9,0x6d4c1aea}},	//   _ኢሎም_, khis, nışı, ymaa, 
   {{0x7d041aeb,0x6d4c0050,0x7cf80118,0x80d8024a}},	//   jhis, xmaa, _dírk, यागे, 
   {{0x7d041aec,0x04540491,0x73c40184,0x65600ac5}},	//   dhis, _كلمة_, _рәйе, _zulh, 
   {{0xe8b403ee,0x7cf801d3,0x02a002e8,0x6d4c1aed}},	//   kışı, _hírh, _бръм, wmaa, 
   {{0x6d4c1aee,0xd24c01d9,0x7cf8032e,0x7d0401e7}},	//   tmaa, _دۆد_, _gírk, fhis, 
   {{0x7d041aef,0x6d4c1af0,0xe8b40ac1,0x82380375}},	//   ghis, umaa, dışı, _מעוצ, 
   {{0x613419f9,0xf0780022,0x00000000,0x00000000}},	// [15b0] rált, _еиқә_, --, --, 
   {{0x6d4c1af1,0xadf40953,0x7d040009,0x98a40115}},	//   smaa, _апош, ahis, rloĝ_, 
   {{0x7d041af2,0x6d4c1af3,0x4db80011,0xe8b400fd}},	//   bhis, pmaa, _উপকূ, gışı, 
   {{0x69c0006a,0x6d4c1af4,0xfe701af5,0x613401d3}},	//   _âlem, qmaa, _پدی_, lálr, 
   {{0xd3641af6,0x65601af7,0xa2a01af8,0x00000000}},	//   _خه_, _sulh, _खाल्, --, 
   {{0x65601af9,0xe8b4013d,0x00000000,0x00000000}},	//   _pulh, bışı, --, --, 
   {{0x2bc8146b,0x65601afa,0xf9d41afb,0x28c400c7}},	//   रिका, _qulh, _йорэ, _ишаҳ, 
   {{0x09e4015b,0x00000000,0x00000000,0x00000000}},	//   পনদা, --, --, --, 
   {{0xe85801c0,0xd3441afc,0xbd9c0023,0x7cf800e5}},	//   _цааш_, چینه_, ፍነቶም_, _sírk, 
   {{0xdb0c006a,0x779000dd,0x69d41afd,0xf59800ee}},	//   _âkôz, _ایوا, _krze, çýär_, 
   {{0x7d041afe,0x764402a8,0x51f400ec,0x00000000}},	//   yhis, ƙiya, نسٽر, --, 
   {{0x69d41aff,0x7d041b00,0x00000000,0x00000000}},	//   _mrze, xhis, --, --, 
   {{0x7d040084,0x0fc00107,0x00000000,0x00000000}},	//   vhis, айян, --, --, 
   {{0x69d40034,0xe8b406b9,0xd36c00e3,0x00000000}},	//   _orze, yışı, _بهو_, --, 
   {{0x7d041b01,0xe8b400ac,0xc0c00023,0x00000000}},	//   this, xışı, ድሕር_, --, 
   {{0xbddc0241,0x6ef801ab,0xad3802bf,0x61341b02}},	//   _aṣòf, _lìbh, ечує_, ráls, 
   {{0x7d040c11,0x69d41b03,0x5ba81b04,0x00000000}},	// [15c0] rhis, _arze, ькам_, --, 
   {{0x69d41b05,0x7cf81b06,0xe8b41b07,0x597400c0}},	//   _brze, _míri, tışı, выду, 
   {{0x1d0818ec,0x7cf81b08,0xfd240133,0x00000000}},	//   _жени_, _líri, _مودێ, --, 
   {{0xe8b41b09,0x69d41afd,0xd83801c0,0x4c801b0a}},	//   rışı, _drze, мэл_, _клюв, 
   {{0x69d41b0b,0xdb04037e,0x1cc0031c,0xda6416ac}},	//   _erze, _opkø, _གྲར_, _لازي, 
   {{0x4730063b,0xa3d41b0c,0xbc6801ed,0xe8b41b0d}},	//   аніс, हिन_, _تجھے_, pışı, 
   {{0x69d4068f,0x05800046,0x5ee80150,0x75d41b0e}},	//   _grze, ауым, _ءﻭﺭ_, ايبا, 
   {{0x88b00133,0x00000000,0x00000000,0x00000000}},	//   _نیمچ, --, --, --, 
   {{0x7cf80798,0x69d40456,0x660c01e4,0xca3c0150}},	//   _círi, _zrze, ĝaka, _ﺟﺎﺕ_, 
   {{0x7cf800c6,0xe6c400c6,0x6e2803ee,0x572401d5}},	//   _díri, _متمي, şebi, _شرذق, 
   {{0x4a98010f,0xcb1002e4,0x613400e5,0x00000000}},	//   וייג, שלת_, válr, --, 
   {{0x7cf800c6,0x00000000,0x00000000,0x00000000}},	//   _fíri, --, --, --, 
   {{0x7cf81b0f,0x80d8190c,0x33940153,0x00000000}},	//   _gíri, याजे, _салё, --, 
   {{0x04401b10,0xe57001ed,0x439001e0,0xda0001f9}},	//   _течн, _خطے_, _ташс, लनात_, 
   {{0x6fe80de2,0x7f581b11,0xac941b0a,0x00000000}},	//   _bëcë, тарс_, лавш, --, 
   {{0xdde002d1,0xc0e4009b,0x00000000,0x00000000}},	//   ñušu, _воћк, --, --, 
   {{0xdb241b12,0xa3d401ad,0x00000000,0x00000000}},	// [15d0] گولی, हिय_, --, --, 
   {{0x69d41b13,0x2fc8058a,0x00000000,0x00000000}},	//   _prze, _isag_, --, --, 
   {{0xc9841b14,0xbf141b15,0x80d80073,0x20a80b02}},	//   тузи, _түрә, याचे, _कामध, 
   {{0x7c581b16,0x1cc0025c,0xa3d40bc0,0x69d40427}},	//   رلەر_, _གིར_, हिम_, _vrze, 
   {{0x6d5c1b17,0x69d4068f,0xfb840024,0x00000000}},	//   _iisa, _wrze, _высн, --, 
   {{0x6d5c1b18,0x69d4006d,0x6b8c1b19,0x00000000}},	//   _hisa, _trze, msag, --, 
   {{0x7cf81b1a,0x6b8c1b1b,0xdb2410e5,0x48a81b1c}},	//   _síri, lsag, _صوفی, _отам_, 
   {{0x6d5c1b1d,0x7cf80227,0x2fc800a3,0x6b8c1b1e}},	//   _jisa, _píri, _osag_, osag, 
   {{0x6b8c1b1f,0xc6a40022,0xed10004d,0x224000d7}},	//   nsag, _ареи, _đối_, _šhk_, 
   {{0x6d5c1b20,0x6b8c1b21,0x6aa40007,0x7cf81b22}},	//   _lisa, isag, nghf, _víri, 
   {{0x69c41b23,0x6d5c0124,0x6b8c0007,0x5ed00f22}},	//   nwhe, _oisa, hsag, _সকলে, 
   {{0x6d5c1b24,0xd5f8008f,0xdfd00451,0x00000000}},	//   _nisa, _אפער, ٽيس_, --, 
   {{0x2d8002b1,0x69c40175,0x952000f1,0xc2b00150}},	//   _awhe_, hwhe, _دکوم, _көнш, 
   {{0x6b8c1b25,0x6110005f,0x21a40bd6,0x539805d0}},	//   dsag, nālz, _бикм, _ניצו, 
   {{0x6d5c1b26,0x69c0006a,0xa6cc009e,0x6b8c1b27}},	//   _bisa, _âleh, লাপট, esag, 
   {{0x6d5c1b28,0xa0a40364,0x6b8c01a8,0xdb1401f4}},	//   _cisa, _саид, fsag, nvyö, 
   {{0x6b8c1b29,0x6d5c1b2a,0x69c40072,0x09bc031c}},	// [15e0] gsag, _disa, ewhe, _ཀརྴ_, 
   {{0x4aa40372,0x2bc81b2b,0xcb9401d5,0x3ae81b2c}},	//   лкун_, रिजा, انلش_, خبری_, 
   {{0x6d5c1b2d,0x2d941b2e,0x6b8c1b2f,0x00000000}},	//   _fisa, _кряс, asag, --, 
   {{0x98481b30,0xbb7410de,0x386003b2,0x00000000}},	//   няла_, _نۇرع, øir_, --, 
   {{0x9b441b31,0x69c400b0,0x6b8c1b32,0x88e801e2}},	//   _منحو, awhe, csag, عظمې_, 
   {{0x6d5c1b33,0xc86c02d3,0x7e7c0175,0xdb0c01f4}},	//   _zisa, _ብዓይኒ_, nbrp, öjän, 
   {{0x6d5c1b34,0x7b00005b,0x00000000,0x00000000}},	//   _yisa, _yöun, --, --, 
   {{0x1cc01b35,0x6d5c1b36,0x80d41b37,0xd3781b38}},	//   _གིས_, _xisa, _बोले, нчо_, 
   {{0x28e014df,0x96941b39,0xdec00023,0x00000000}},	//   फारि, _бреш, ስስን_, --, 
   {{0xc7d4011a,0x00000000,0x00000000,0x00000000}},	//   _גומי_, --, --, --, 
   {{0xd34401b9,0x22280014,0x613400e4,0xcb340115}},	//   نیچه_, ہٲیی_, tálp, ראיי_, 
   {{0x6b8c1b3a,0x7cf801e1,0x0524030d,0x142400d4}},	//   ysag, _kíru, _йохк_, _йдем, 
   {{0x2d80013f,0x1cc0025c,0xd9b000bc,0xcfa40108}},	//   _swhe_, _གྲེ_, ीबुट, ышни, 
   {{0x6d5c1b3b,0x6b8c1b3c,0x0fe00032,0x69c41b3d}},	//   _sisa, vsag, _ғөмү, ywhe, 
   {{0xd1380354,0x032001e2,0x00000000,0x00000000}},	//   _пхи_, _دفوټ, --, --, 
   {{0x6b8c1b3e,0x2fc80218,0x6d5c1b3f,0x4638008f}},	//   tsag, _tsag_, _qisa, געלע, 
   {{0x6e9400a8,0x6b8c013c,0x7cf801e1,0xab941b40}},	// [15f0] _кипу, usag, _níru, شلاغ, 
   {{0x6b8c1b41,0xa3d41b42,0x6d5c1b43,0x80240014}},	//   rsag, हित_, _wisa, _در٘م, 
   {{0x6b8c1b44,0xfaa81b45,0x69c41b46,0x00000000}},	//   ssag, اهمي_, uwhe, --, 
   {{0x6b8c1b47,0xfc6402e8,0x69c41b48,0x75dc0356}},	//   psag, _гърн, rwhe, _măză, 
   {{0x7648010b,0x75dc054e,0xa684004e,0x00000000}},	//   _azdy, _lăză, аллд, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xba74066d,0x6eac038e,0xf77001d3,0x0df40023}},	//   _چاہت, _जानु, _ہال_, _ወልፊ_, 
   {{0xa774156c,0x291801e3,0x611000b8,0x00000000}},	//   _влач, _ösa_, bāly, --, 
   {{0xf7700502,0x320c0030,0x7cf802d2,0x53d00c22}},	//   _فال_, ezdy_, _gíru, तिषश, 
   {{0xdec01b49,0x257800c7,0x7cf800e5,0x3358004e}},	//   ስትን_, _абжь_, _hírt, гүчө_, 
   {{0x75dc0356,0xc0c00023,0xb6e400cf,0x00000000}},	//   _căză, _ድሑር_, _уютк, --, 
   {{0xa3d40034,0xa2a80b7c,0xa0a41b4a,0x00000000}},	//   हिद_, ज्ज्, шамд, --, 
   {{0x320c0034,0xd3e400db,0xe3b000ec,0x00000000}},	//   azdy_, _ەتۉۉ, _ڇرڪ_, --, 
   {{0xe2980a31,0x5398011a,0x00000000,0x00000000}},	//   _рак_, _יינו, --, --, 
   {{0x1cc01b4b,0x21a405f5,0x2cb800a3,0xd12c00ec}},	//   _གྲུ_, _тийм, _bbsd_, _ڪمي_, 
   {{0x25ec1b4c,0xd24c1b4d,0xa3c80034,0xa0740166}},	//   _अपनी_, _غني_, _ऊना_, _тыкш, 
   {{0xcb641b4e,0x2cb80334,0x71240fa2,0xd12c0b24}},	// [1600] иате_, _dbsd_, _درول, _تمي_, 
   {{0x1e941b4f,0x7cf801e1,0x00000000,0x00000000}},	//   _трир, _ríru, --, --, 
   {{0x9f041a69,0xda5801e0,0x9d441b50,0x0e98011a}},	//   _موکو, траш_, _венд, _בשיל, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3ab4013d,0xf7040166,0x6eac1b51,0x00000000}},	//   _гәет, бҗам, _जामु, --, 
   {{0x7cf81b52,0xd5b801a9,0x00000000,0x00000000}},	//   _víru, вси_, --, --, 
   {{0x95c81b53,0x2b5401d5,0x55040262,0x349406b4}},	//   тула_, _ایلد_, ичиа, байр, 
   {{0x75dc0356,0x76480216,0x040c0154,0x320c0419}},	//   _răză, _vzdy, াপনী_, vzdy_, 
   {{0x7cf800e5,0xbdec01ec,0x00000000,0x00000000}},	//   _hírs, _ﻋﻤﻴل_, --, --, 
   {{0x87780a7c,0x96b800f5,0x25700228,0x0bb400d9}},	//   _סאבי, _шубу_, زۇۇس, סלים_, 
   {{0x0a440023,0x6ec40073,0x00000000,0x00000000}},	//   _ንኢሰያ, ाजसु, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x72d40e58,0x00000000,0x00000000,0x00000000}},	//   _голф, --, --, --, 
   {{0xb8d8025c,0xff041b54,0xef540022,0x62200137}},	//   _མཁ_, оясн, скгь, تۉۉل, 
   {{0x51841b55,0xad241b56,0x0ca80c60,0x00000000}},	//   _тула, مىسى, ктаи_, --, 
   {{0x1cc00327,0x00000000,0x00000000,0x00000000}},	//   _གྲཱ_, --, --, --, 
   {{0xebd8010b,0xc0c00092,0x00000000,0x00000000}},	// [1610] ыдаш_, ስንም_, --, --, 
   {{0x61b0168d,0x7cf801d3,0x37cc0154,0x00000000}},	//   _بڕیا, _bírs, লমার, --, 
   {{0xba740e8e,0x63b4054e,0xc330011a,0x00000000}},	//   تاقت, ăzni, קוע_, --, 
   {{0xe5780107,0x835400b8,0x00000000,0x00000000}},	//   қзи_, _mātṝ, --, --, 
   {{0x1cc00003,0x2d900034,0x2ca8005f,0xc7c400d8}},	//   _གྲི_, lsze_, mgad_, рсеи, 
   {{0xa3d41b57,0x2ca800c5,0xeb34075e,0x637801a9}},	//   हिस_, lgad_, _چىڭد, қсир_, 
   {{0x7cf802d2,0x79940166,0x2d900210,0x253800d8}},	//   _gírs, _мирф, nsze_, лчиќ_, 
   {{0x2ca81b58,0x6fb80073,0x00000000,0x00000000}},	//   ngad_, ेबां, --, --, 
   {{0x291c1b59,0x2ca81b5a,0xe4580108,0x00000000}},	//   miwa_, igad_, ыжи_, --, 
   {{0x291c1b5b,0xdddc1b5c,0x13041b5d,0x0a440023}},	//   liwa_, _lepš, йный_, _ንኢሳያ, 
   {{0x2d900034,0x27fc0175,0x00000000,0x00000000}},	//   jsze_, lywn_, --, --, 
   {{0x291c1b5e,0xf1a803e6,0xb9f0001f,0x83540055}},	//   niwa_, گایه_, _ዐዐ_, _dātṝ, 
   {{0x2ca81b5f,0x00000000,0x00000000,0x00000000}},	//   dgad_, --, --, --, 
   {{0x291c1b60,0xf1a804d3,0xdcb01b61,0x5438008f}},	//   hiwa_, دایه_, ुज्ञ, _גענא, 
   {{0x291c1b62,0x236c044e,0x2ca8007f,0x6b480064}},	//   kiwa_, lqej_, fgad_, _užgy, 
   {{0x2ca81b63,0x291c1b64,0x442c0158,0xf1a804d3}},	//   ggad_, jiwa_, _kxg_, _ئاوه_, 
   {{0x291c1b65,0x817c001f,0x33840023,0x00000000}},	// [1620] diwa_, _የተባሉ_, _ሓደሓደ_, --, 
   {{0xee38013e,0x2ca81b66,0x60c401d3,0x60c01b67}},	//   унӣ_, agad_, lekm, _ñomb, 
   {{0x291c1b68,0x236c036e,0x248c01ef,0x00000000}},	//   fiwa_, hqej_, kaem_, --, 
   {{0x98a41b69,0x291c1b6a,0x1cc00327,0xcca000db}},	//   сиде, giwa_, _གིི_, _ىڭقى, 
   {{0xc7a01b6b,0x1cc00135,0x248c1b6c,0x00000000}},	//   зичк, _གྲག_, daem_, --, 
   {{0xd3781b6d,0x05d00490,0xaee40882,0xf1a81b6e}},	//   қчи_, थिंब, miṣy, _कमलन, 
   {{0x291c1b6f,0xe7080133,0x00000000,0x00000000}},	//   biwa_, گتۆن_, --, --, 
   {{0x291c1b70,0x94a81b71,0x33741b72,0x248c020c}},	//   ciwa_, утка_, огир, gaem_, 
   {{0x2d841b73,0x442c056a,0x037417b9,0x2d900210}},	//   ález_, _cxg_, یحیت_, zsze_, 
   {{0x35c41b74,0x2d900210,0x00000000,0x00000000}},	//   _мазҳ, ysze_, --, --, 
   {{0x2ca81b75,0x7bc001b8,0x442c00d8,0x248c0139}},	//   ygad_, _ämuf, _exg_, baem_, 
   {{0xd46803fb,0x442c045a,0xa3d403ce,0x4a58123b}},	//   _сиде_, _fxg_, हिश_, טדיו, 
   {{0x2d90006d,0x6eac1b76,0xdddc03ef,0x00000000}},	//   wsze_, _जादु, _repš, --, 
   {{0x0dc806c0,0xa3d41b77,0x2d900210,0x00000000}},	//   луби_, हिर_, tsze_, --, 
   {{0x291c1b78,0x1cc00003,0x2d841b79,0x80d4012c}},	//   yiwa_, _གྲང_, èle_, _बोके, 
   {{0x2d901b7a,0x291c1b7b,0x50641b7c,0x60c4083c}},	//   rsze_, xiwa_, _утка, cekm, 
   {{0x2ca81b7d,0x291c1b7e,0x442c00d8,0x2d9001d3}},	// [1630] rgad_, viwa_, _xxg_, ssze_, 
   {{0x291c1b7f,0x2d90068f,0xbb841b80,0x3f14004e}},	//   wiwa_, psze_, سلمي, _ндыс, 
   {{0x291c1b81,0xba740aa0,0x9bb80003,0x248c0007}},	//   tiwa_, سالت, _པདྨོ, yaem_, 
   {{0x27fc020c,0x877001d5,0x46b0012d,0x00000000}},	//   tywn_, зғаш, ूज़्, --, 
   {{0x291c1b82,0xfd44009d,0xaee40055,0x00000000}},	//   riwa_, _хээн, ciṣy, --, 
   {{0x291c1b83,0xbb400131,0xc6a41b84,0x069001d3}},	//   siwa_, ﻜﯩﻦ_, срди, ساتھ, 
   {{0x24e80c04,0x291c1b85,0x248c0bed,0x442c056a}},	//   имки_, piwa_, taem_, _sxg_, 
   {{0x291c1b86,0xa3d41b87,0xa8340063,0x00000000}},	//   qiwa_, हिल_, _дебљ, --, 
   {{0x248c0798,0xd7c0031c,0xe3b000ae,0x00000000}},	//   raem_, _གརགྱ, ذرة_, --, 
   {{0xe2981b88,0x6d04012c,0x60c4020c,0xe5e4158b}},	//   јан_, रसँग_, wekm, _وزای, 
   {{0x60c400da,0xfcbc001f,0x1ea801e2,0x00000000}},	//   tekm, _ታዳጊ_, یاسي_, --, 
   {{0xaee40a28,0x00000000,0x00000000,0x00000000}},	//   yiṣy, --, --, --, 
   {{0x60c41b89,0x1cc00327,0xa03400db,0x00000000}},	//   rekm, _གྲཊ_, زىست, --, 
   {{0x1cc00156,0xaee40a28,0x60c40fda,0x00000000}},	//   _གིང_, viṣy, sekm, --, 
   {{0x62801b8a,0xdd901b8b,0x63b4054e,0x00000000}},	//   mblo, بوز_, ăznu, --, 
   {{0xd47c001f,0x2c14000d,0xd24c00ae,0x00000000}},	//   _የቀድሞ_, _नइखू_, _جنى_, --, 
   {{0x8c401b8c,0x5f741b8d,0x63ac007c,0x00000000}},	// [1640] дете, _بابر, _åand, --, 
   {{0x62801b8e,0xaee40882,0x0ae400a7,0x20a800bc}},	//   nblo, riṣy, одуй_, _काँध, 
   {{0xd12c1b8f,0x76440198,0xa3d41b90,0x62800af9}},	//   _سمی_, ƙiyi, हिँ_, iblo, 
   {{0x7d08002d,0xd7f800a8,0x9d4404b1,0x00000000}},	//   êdsd, иул_, _фемд, --, 
   {{0x7d041b91,0xacb01b92,0x80bc00dc,0x5fc801ad}},	//   mkis, _سەلب, ष्ये, िबिल, 
   {{0x7d041b93,0x96b81b94,0x6280134a,0x00000000}},	//   lkis, руду_, jblo, --, 
   {{0x20a81524,0xf1a80037,0x7d041b95,0x6eac0118}},	//   _कांध, _कमइन, okis, _जासु, 
   {{0x7d041b96,0x628004ce,0xa3d41b97,0x00000000}},	//   nkis, eblo, हिं_, --, 
   {{0x62801b98,0x00000000,0x00000000,0x00000000}},	//   fblo, --, --, --, 
   {{0x7d041b99,0x273000db,0x2aec04af,0x613400e5}},	//   hkis, _كۉنس, घायु_, mály, 
   {{0x7d041b9a,0x157001b9,0x914801d5,0xd5840244}},	//   kkis, _ўқиё, ичма_, _بێعه_, 
   {{0x38600960,0x35c4014b,0x00000000,0x00000000}},	//   žiru_, _маҷҳ, --, --, 
   {{0xf6c8003d,0x10481b9b,0x62801b9c,0x7d041b9d}},	//   _གྲོང, ряни_, bblo, dkis, 
   {{0x8d741b9e,0x69c00598,0x7d041b9f,0x62801ba0}},	//   قارا, _äleg, ekis, cblo, 
   {{0xc278008f,0x9f40023a,0x3eb00030,0x53d0086b}},	//   _דרוי, yykö_, _žltá_, तिकश, 
   {{0xab74016c,0x75200472,0x7d041ba1,0x4598008f}},	//   згаш, nimz, gkis, יסלע, 
   {{0x0a6807dd,0x00000000,0x00000000,0x00000000}},	// [1650] ареи_, --, --, --, 
   {{0x7d041ba2,0xfbd0040b,0x80bc0b7c,0x613401ed}},	//   akis, کتہ_, ष्ठे, dály, 
   {{0x7d041ba3,0x0dc8085f,0xe73801e0,0x75201ba4}},	//   bkis, _тупи_, ҙек_, kimz, 
   {{0x7d041ba5,0x4a7401e0,0x62801ba6,0x39a400d4}},	//   ckis, сыҡт, zblo, ьшув, 
   {{0x66e41ba7,0x62801ba8,0x00000000,0x00000000}},	//   зола, yblo, --, --, 
   {{0x6280019b,0xeb081b06,0xff7c008f,0xdbc40254}},	//   xblo, _اقسى_, סטומ, tööe, 
   {{0x80ac05ba,0x1cc0025c,0xe5a40131,0xe3c800e4}},	//   _झाले, _གྲཌ_, чийи, kuñá_, 
   {{0x6134066d,0x62801ba9,0x24e8013e,0x00000000}},	//   bály, wblo, смии_, --, 
   {{0x13e40166,0x00000000,0x00000000,0x00000000}},	//   змый_, --, --, --, 
   {{0x7d040072,0x46600116,0x00000000,0x00000000}},	//   zkis, _قۇشق, --, --, 
   {{0xa0680661,0x61441baa,0x69c0013d,0x59dc012d}},	//   йана_, зена, _äled, _नज़ार, 
   {{0x55b8011a,0x00000000,0x00000000,0x00000000}},	//   _למעו, --, --, --, 
   {{0x62801bab,0x25701bac,0x14c804fb,0x7d0403e0}},	//   pblo, _hál_, _دهنی_, vkis, 
   {{0x63a81bad,0x7d040bc9,0x2570032e,0x626401f4}},	//   muen, wkis, _kál_, _эвка, 
   {{0x63a81bae,0x7d041baf,0x63ac0fac,0x331800f2}},	//   luen, tkis, _åanb, _بزند_, 
   {{0x25701bb0,0x63a80dd4,0x20c81bb1,0x7d041bb2}},	//   _mál_, ouen, _طبعي_, ukis, 
   {{0x212001af,0x7d041bb3,0x63a80d63,0x80bc043e}},	// [1660] mikh_, rkis, nuen, ष्णे, 
   {{0x7d041bb4,0x60d41bb5,0x75201bb6,0x7d08002d}},	//   skis, _haym, zimz, êdsb, 
   {{0x60d41bb7,0x9d441bb8,0x7d3c001f,0x2000014b}},	//   _kaym, _неод, _በፖለቲ, lyki_, 
   {{0x63a81bb9,0x613401ed,0x57e81bba,0x23bc1bbb}},	//   kuen, tály, йдем_, ्बाद, 
   {{0x60d40588,0x87e011ed,0x63a81bbc,0x9f4000e4}},	//   _maym, еюще, juen, sykõ_, 
   {{0x63a81bbd,0x60d41bbe,0x613401ed,0x25701bbf}},	//   duen, _laym, rály, _bál_, 
   {{0x25700077,0x38c803e6,0x9a8400d1,0x63a80393}},	//   _cál_, _واری_, _муңл, euen, 
   {{0x25700316,0xd3a41bc0,0x613401ed,0x60d41bc1}},	//   _dál_, проп, pály, _naym, 
   {{0x07a01bc2,0x1cc0031c,0xc7a01bc3,0x1488107b}},	//   _патн, _གྲབ_, _питк, _ۇپاي_, 
   {{0x87780bd9,0x257000ae,0xd6281bc4,0x20000210}},	//   _לאמי, _fál_, _лозе_, dyki_, 
   {{0x60d41bc5,0xe6b401d5,0x63a80076,0x54341bc6}},	//   _baym, _آلمگ, auen, _کرار, 
   {{0x63a81bc7,0x60d41bc8,0x26d8013b,0x00000000}},	//   buen, _caym, _ɔsom_, --, 
   {{0x63a81bc9,0x60d41bca,0x35a4008e,0x5ed40154}},	//   cuen, _daym, _хаҗг, দানে, 
   {{0x417000f2,0x733414fb,0x00000000,0x00000000}},	//   بایس, _تىتا, --, --, 
   {{0xb1180050,0x69d800b0,0x60d4002f,0x00000000}},	//   _وقتا_, āwek, _faym, --, 
   {{0x60d41bcb,0x80b400cf,0x00000000,0x00000000}},	//   _gaym, _كەپش, --, --, 
   {{0xa3d4006d,0x3c58084c,0x6454002d,0x2000012d}},	// [1670] हिए_, зитэ_, ęzig, cyki_, 
   {{0xdb14033b,0x88e401ec,0x60d40139,0x00000000}},	//   ntyè, _ﺍﻗﺘﻀ, _zaym, --, 
   {{0x60d41bcc,0x63a81bcd,0x00000000,0x00000000}},	//   _yaym, zuen, --, --, 
   {{0x60d41bce,0xe6c41bcf,0x12800240,0x00000000}},	//   _xaym, लज्ज, ረትኣብ_, --, 
   {{0x25701bd0,0x61340077,0x63a8009d,0xdb14033b}},	//   _sál_, rálx, xuen, ktyè, 
   {{0x25701bd1,0xb9041bd2,0x63a80207,0x00000000}},	//   _pál_, _भो_, vuen, --, 
   {{0x20000034,0x2120014b,0x63a8003e,0x79a400d8}},	//   zyki_, yikh_, wuen, _прте, 
   {{0x63a81bd3,0xa9080be2,0x24080022,0x25701bd4}},	//   tuen, _بيرل_, жнии_, _vál_, 
   {{0x60d40bf1,0x290c1bd5,0xfbe01bd6,0xe7b400f1}},	//   _raym, _ilea_, नियम, _زماد, 
   {{0x63a81bd7,0x68e801f1,0x21200ac5,0x1cc0031c}},	//   ruen, _hned, wikh_, _གྲན_, 
   {{0x63a81bd8,0x68e81bd9,0x290c1bda,0x2120003a}},	//   suen, _kned, _klea_, tikh_, 
   {{0x2000068f,0x245401d5,0x60d41bdb,0x00000000}},	//   tyki_, _قناس, _qaym, --, 
   {{0xe2981bdc,0x21200020,0x63a80c46,0x68e81bdd}},	//   _дал_, rikh_, quen, _mned, 
   {{0x60d41bde,0x2000033f,0x00000000,0x00000000}},	//   _waym, ryki_, --, --, 
   {{0x68e81bdf,0x60d41be0,0xdef800ee,0x60c00124}},	//   _oned, _taym, бың_, _ñomo, 
   {{0x5908025c,0x68e804ba,0x60d402d0,0x00000000}},	//   _གཞེས_, _nned, _uaym, --, 
   {{0xe3b801ed,0x1dcc012d,0x2ba41be1,0x3d14012d}},	// [1680] ntű_, _हैरत, गंगा, नोगे_, 
   {{0x290c1be2,0x68e81be3,0x272000bc,0x5f2800d8}},	//   _alea_, _aned, nčně_, _фоом_, 
   {{0x290c04cc,0x68e80003,0x00000000,0x00000000}},	//   _blea_, _bned, --, --, 
   {{0x290c1be4,0x58b8007b,0x7f680150,0x00000000}},	//   _clea_, تائج_, _ﺒﻭل_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x290c0e39,0x68e81be5,0x6b88005a,0x75d400ae}},	//   _elea_, _ened, _çega, فيتا, 
   {{0x7afc0477,0x63ac0115,0x290c0f85,0xcb640cb6}},	//   _iort, _ĥana, _flea_, _царе_, 
   {{0x7afc1be6,0x68e80076,0x97c401b9,0x14ac0073}},	//   _hort, _gned, _ойбе, _टाळण, 
   {{0x1cc00003,0x96b81be7,0xdec01954,0x8d800092}},	//   _གིན_, _мужу_, ድስን_, ንባታው_, 
   {{0x69c00793,0x7afc1bce,0x39440254,0xf1f4068e}},	//   _älec, _jort, _hkms_, езоэ, 
   {{0x7afc1be8,0x776802d0,0xca880150,0x673c032e}},	//   _mort, _iidx, _ﺗﯘﺳﻪ_, _ísja, 
   {{0x7afc0323,0x249c009f,0x96ac000d,0x272001ef}},	//   _lort, _gdwm_, _घाँउ, ačně_, 
   {{0x7afc0151,0x7648010b,0x00000000,0x00000000}},	//   _oort, _hydy, --, --, 
   {{0x7afc1be9,0x63ac03cd,0x15f0121d,0xd5c00073}},	//   _nort, _åana, _अपार_, _शहाज, 
   {{0x6454033f,0x7768013d,0xccf80063,0x00000000}},	//   ęzie, _midx, оћа_, --, 
   {{0x3cf00a28,0x50641b10,0x61e4032e,0x00000000}},	//   ṣṭvā_, _отпа, _áhla, --, 
   {{0x7afc1bea,0x76481beb,0x00000000,0x00000000}},	// [1690] _bort, _lydy, --, --, 
   {{0x68e81bec,0x5908025c,0x290c0076,0x49b80736}},	//   _sned, _གཞུས_, _slea_, قاصد_, 
   {{0x1cc00135,0x76480217,0x290c1bed,0x31b800e5}},	//   _གྲམ_, _nydy, _plea_, néz_, 
   {{0xe94401b9,0xfe240124,0x00000000,0x00000000}},	//   ررای, _шьын, --, --, 
   {{0x76480209,0x31b801ed,0x293c0046,0x39440009}},	//   _aydy, héz_, ﻟﯩﭗ_, _dkms_, 
   {{0x7afc1bee,0x9de401d9,0x76481bef,0x316802f0}},	//   _gort, _تہہٕ_, _bydy, _liaz_, 
   {{0x76480368,0x68e8025c,0xba900150,0x6e200332}},	//   _cydy, _tned, _ﺗﯘﻧﮕ, úlbh, 
   {{0x67d41bf0,0x7afc05f5,0x68e81bf1,0x764803cb}},	//   _побу, _zort, _uned, _dydy, 
   {{0x7afc0598,0x77680077,0x00000000,0x00000000}},	//   _yort, _fidx, --, --, 
   {{0x7afc1bf2,0x18281bf3,0x05741bf4,0xdedc0023}},	//   _xort, _عقلی_, _قاصد, ቕትን_, 
   {{0x76481bf5,0xe1241bf6,0xe7f8012c,0xf4f801d3}},	//   _gydy, емни, ्नका_, سویں_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa3d4069f,0x31681bf7,0x00000000,0x00000000}},	//   हिओ_, _diaz_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2c740521,0x23b802bd,0x00000000,0x00000000}},	//   _ụda_, lèj_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x1ae41bf8,0xa3d41bf9,0x23b80100,0x5ba81b0a}},	// [16a0] ноам, हिट_, nèj_, якам_, 
   {{0x7afc1bfa,0x9b441bfb,0xcca00150,0xda580120}},	//   _qort, رناو, _ەڭلى, преш_, 
   {{0x7afc1bfc,0x3944020c,0x291c007f,0x59840108}},	//   _vort, _pkms_, ďwan_, хлеб, 
   {{0x76480cfd,0x7afc1bfd,0x3f80003e,0x00000000}},	//   _rydy, _wort, _ktiu_, --, 
   {{0x69d41bfe,0x76480368,0x00000000,0x00000000}},	//   _esze, _sydy, --, --, 
   {{0x7afc01bf,0x8f9800d9,0xcf9000d9,0x00000000}},	//   _uort, ליני, נטו_, --, 
   {{0xceb000c8,0x09e0010a,0x00000000,0x00000000}},	//   טיג_, _йорн, --, --, 
   {{0x69c00793,0x38c8004b,0x799c03ac,0x05700b24}},	//   _älea, _تاسی_, _ivrw, داود, 
   {{0x44f01bff,0x69d40210,0x00000000,0x00000000}},	//   اسىز, _zsze, --, --, 
   {{0x0bb40375,0x78a004e6,0x71781c00,0x76480142}},	//   עלים_, _hdmv, мбор_, _tydy, 
   {{0x95c81c01,0x3f8000b0,0x31680085,0x6234009d}},	//   _хлеб_, _atiu_, _piaz_, күшю_, 
   {{0x31b800e5,0x76440205,0x80bc17ee,0x00000000}},	//   réz_, ğiyd, ष्ले, --, 
   {{0x6454000f,0x506400a8,0x31680419,0x764403e0}},	//   ęzic, этоа, _viaz_, şiyd, 
   {{0xad2403cc,0x55f000fe,0x00000000,0x00000000}},	//   چىسى, জনীক_, --, --, 
   {{0xad241c02,0xac9408e1,0x0ca80022,0x6fd00154}},	//   نىسى, кавш, зтзи_, ামেই, 
   {{0xa3d401f9,0x00000000,0x00000000,0x00000000}},	//   हिच_, --, --, --, 
   {{0x8aa41c03,0x799c02d0,0xcee800ec,0xc0c00092}},	// [16b0] еред, _avrw, _فردن_, ድንም_, 
   {{0x2fc81c04,0xef1000f7,0x69d4033f,0x4f28069d}},	//   _ipag_, _түгө, _psze, ደጊዮር, 
   {{0x7dc41c05,0x3978187f,0x00000000,0x00000000}},	//   _یقین, есію_, --, --, 
   {{0x2fc81c06,0xd24404d3,0x6b880139,0x00000000}},	//   _kpag_, _ۆن_, _çego, --, 
   {{0xd2441c07,0x69d4068f,0x6d4c1c08,0x63ac01e4}},	//   _چن_, _wsze, mlaa, _ĥano, 
   {{0x6d4c1c09,0xd24415fa,0x2d80036e,0xe5a41c0a}},	//   llaa, _نن_, _kthe_, вики, 
   {{0x6d4c1574,0xbb5808ca,0xe6580023,0x00000000}},	//   olaa, _чарх_, _ቅንጸላ, --, 
   {{0x6d4c1c0b,0x23b8033b,0x00000000,0x00000000}},	//   nlaa, tèj_, --, --, 
   {{0x6d4c1c0c,0xe694035b,0x46681c0d,0xe3e80ee8}},	//   ilaa, _аизы, _ерем_, بکان_, 
   {{0x2d801c0e,0x6d4c1c0f,0x77980108,0x21c802dd}},	//   _othe_, hlaa, _чкфр_, _ﺒﻴﺭﻭ, 
   {{0x6d4c1c10,0x3f8000a8,0x2d8001d4,0x2fc80076}},	//   klaa, _stiu_, _nthe_, _apag_, 
   {{0x6d4c01a4,0x23b8007f,0x00000000,0x00000000}},	//   jlaa, pèj_, --, --, 
   {{0x2d801c11,0x6d4c1c12,0x02c01c13,0x4ab0193d}},	//   _athe_, dlaa, _билү, ुभाव, 
   {{0x63a81c14,0xfbe01c15,0x00000000,0x00000000}},	//   mren, निसम, --, --, 
   {{0x6d4c1c16,0x2d8007ab,0x613801c0,0x9d4400e5}},	//   flaa, _cthe_, _очир_, نئرن, 
   {{0x6d4c1c17,0x63a81a44,0xfd64009d,0x00000000}},	//   glaa, oren, унбү, --, 
   {{0x2d801c18,0xefc802d3,0x765c0306,0x8d6001ec}},	// [16c0] _ethe_, ሽቶይ_, _úryv, рвте, 
   {{0xc0480201,0x6d4c1c19,0x63a81c1a,0xb7d40241}},	//   _ማስታወ, alaa, iren, _nṣaf, 
   {{0x63a81c1b,0x6d4c1c1c,0xdca400c7,0x00000000}},	//   hren, blaa, _иани, --, 
   {{0x63a808ad,0x26c41c1d,0x6d4c1af4,0x00000000}},	//   kren, _ablo_, claa, --, 
   {{0x69c001b8,0xcba0010a,0x00000000,0x00000000}},	//   _älen, _каяй, --, --, 
   {{0x799c02d0,0x14d80073,0x4cc803d4,0xdce41c1e}},	//   _tvrw, _मोजण, ৱাণু, _mikč, 
   {{0x28dc0d0a,0x26c4005a,0x2a3400a8,0x00000000}},	//   _नोकि, _dblo_, _бэтр, --, 
   {{0x26c400df,0x46e400fd,0x73d800ee,0xd3780395}},	//   _eblo_, едән_, едир_, мчо_, 
   {{0x63a81c1f,0xda6405d9,0x00000000,0x00000000}},	//   gren, _ساڳي, --, --, 
   {{0x14ac0490,0x6d4c0205,0x00000000,0x00000000}},	//   _टाकण, zlaa, --, --, 
   {{0x63a81c20,0x6d4c1c21,0x2fc80327,0xdce40064}},	//   aren, ylaa, _spag_, _aikč, 
   {{0x94241c22,0x14241c23,0x6d4c0de2,0x2d8000cd}},	//   _имее, _идем, xlaa, _rthe_, 
   {{0x63a81c24,0x73c40032,0x64b00150,0x6d4c01a4}},	//   cren, _сәйе, _اڭىر, vlaa, 
   {{0xb904025c,0xd1b800db,0x6d4c1b9d,0xebc40116}},	//   _ཨལ_, _قاعا_, wlaa, қәмн, 
   {{0x6d4c1c25,0x7e281c26,0x6a7801e1,0xd1380107}},	//   tlaa, віта_, _lúfó, _охи_, 
   {{0x0fe00137,0x6d4c1c27,0x00000000,0x00000000}},	//   _көгү, ulaa, --, --, 
   {{0x6d4c1c28,0x257007f5,0xfbd000c6,0x4ea41c29}},	// [16d0] rlaa, _išle_, يتك_, _ирна, 
   {{0x6d4c1c2a,0xadd8035b,0x00000000,0x00000000}},	//   slaa, _змоу_, --, --, 
   {{0x63a81c2b,0x6d4c1c2c,0x2d800928,0x7b64005e}},	//   zren, plaa, _uthe_, ртте, 
   {{0x6b58026c,0xa81400f7,0x6a780174,0x6d4c0014}},	//   dìge, лдеш, _búfó, qlaa, 
   {{0xa6c8074d,0x499001ed,0xb30c0327,0x61e002d0}},	//   елла_, _چیئر, གྲོང_, zvll, 
   {{0x63a81c2d,0xc6a40137,0x9ba00137,0x00000000}},	//   vren, трди, _دەكى, --, 
   {{0x63a81c2e,0x855401d3,0x00000000,0x00000000}},	//   wren, نیئر_, --, --, 
   {{0x61e00175,0x00000000,0x00000000,0x00000000}},	//   vvll, --, --, --, 
   {{0xe2981c2f,0x63a81c30,0xa9a40116,0x00000000}},	//   нап_, uren, _шиңд, --, 
   {{0xe1f81c31,0x63a81c32,0xd3440345,0xe284035b}},	//   его_, rren, هینه_, ылои, 
   {{0x9af80375,0xdee40107,0xba900150,0x00000000}},	//   תפתח, қови, _ﺗﯘﻳﮕ, --, 
   {{0x645403be,0x63a81c33,0xdce40064,0x00000000}},	//   əzin, pren, _pikč, --, 
   {{0x7d08002d,0x84640395,0xdca41c34,0x00000000}},	//   êdsm, _ръже, ғази, --, 
   {{0xd1b8001f,0xb3700014,0x53980a7c,0x5dd41c35}},	//   ታለች_, _گۯیش, _טינו, любу, 
   {{0xd7d80456,0x00000000,0x00000000,0x00000000}},	//   _मैनच, --, --, --, 
   {{0x7e7c0407,0x2cb806af,0xd24c007b,0x1e840116}},	//   scrp, _ccsd_, _عني_, _өлим, 
   {{0xdc2800f1,0x00000000,0x00000000,0x00000000}},	// [16e0] رسره_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69c00793,0x2cb80175,0xee38004e,0x5d680798}},	//   _älel, _fcsd_, _үнө_, _пиом_, 
   {{0x2cb80048,0x00000000,0x00000000,0x00000000}},	//   _gcsd_, --, --, --, 
   {{0x6ac809bd,0x00000000,0x00000000,0x00000000}},	//   রয়ো, --, --, --, 
   {{0xda641c36,0x3ce01c37,0x69d802b1,0x2d8400db}},	//   _مازي, ldiv_, āwer, íleg_, 
   {{0x645c1c38,0xceb00302,0x6b580241,0x00000000}},	//   ýsin, ציה_, bìgb, --, 
   {{0xd9441c39,0x3ce01c3a,0x00000000,0x00000000}},	//   _себи, ndiv_, --, --, 
   {{0x28dc1533,0x337410fc,0x61e402d2,0x249803b2}},	//   _नोटि, јгор, _áhlj, ðsma_, 
   {{0x518404a9,0x7d08000f,0x89d41c3b,0x00000000}},	//   лума, êdsj, _جوہر_, --, 
   {{0x1ac400cd,0x00000000,0x00000000,0x00000000}},	//   र्यथ, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3ce00334,0xb4e019cc,0xf2c400fb,0x00000000}},	//   ddiv_, दयी_, _көни, --, 
   {{0x4ea41c3c,0x52741c3d,0xefd00023,0x2744013a}},	//   ырма, _суду, _ብኣይ_, cíně_, 
   {{0xc2781a4c,0x3ce00175,0x62241c3e,0x00000000}},	//   _ארוי, fdiv_, _پويە, --, 
   {{0x257005a1,0x3ce00334,0x3ce8012d,0xa1a401af}},	//   _ušle_, gdiv_, _चोदे_, _тышһ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [16f0] --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7c580131,0x00000000,0x00000000,0x00000000}},	//   پلەر_, --, --, --, 
   {{0x6ce40228,0x2cb8045a,0x69c000ee,0x00000000}},	//   _ئزدە, _ucsd_, _älem, --, 
   {{0xa92400d7,0xad2400d1,0x00000000,0x00000000}},	//   _nižň, _مىھى, --, --, 
   {{0x66041c3f,0x16a41363,0x00000000,0x00000000}},	//   ипла, авши_, --, --, 
   {{0x369401ec,0x00000000,0x00000000,0x00000000}},	//   сшіс, --, --, --, 
   {{0x77901c40,0x6d5c0076,0x00000000,0x00000000}},	//   _کیوا, _jhsa, --, --, 
   {{0x739805f5,0x7dcc014a,0x23340107,0x27440118}},	//   лтэс_, _kösö, ихор, tíně_, 
   {{0xa1c40953,0x13041c41,0xae0400e1,0x34940022}},	//   абод, иный_, रहान_, _ҳацр, 
   {{0x6d5c1c42,0xdce400e2,0x65d41c43,0xe4b800c0}},	//   _ohsa, _likā, _خياط, _алеі_, 
   {{0x61441c44,0x3ce00334,0x7dcc01e3,0xd24c00f1}},	//   рема, xdiv_, _lösö, ړنۍ_, 
   {{0x248c1c45,0x3ce0030a,0xfe78049e,0x31d00882}},	//   mbem_, vdiv_, лүп_, āraṃ_, 
   {{0x64581c46,0x6d5c1c47,0xde500b82,0x3ce00175}},	//   _izwi, _ahsa, _መትከል, wdiv_, 
   {{0xdce41c48,0x3ce00334,0x00000000,0x00000000}},	//   _aikā, tdiv_, --, --, 
   {{0xdcb00447,0x6d5c0113,0x248c0548,0x25dc00af}},	//   تىر_, _chsa, nbem_, _कईनी_, 
   {{0x3ce01c49,0xdc6801c6,0x1b480107,0xae480014}},	// [1700] rdiv_, таад_, взаи_, نشہٕ_, 
   {{0x6d5c1c4a,0x6458014b,0x33c00131,0x3ce01c4b}},	//   _ehsa, _mzwi, _ﻣﻪﺯﻣ, sdiv_, 
   {{0xa2bc1c4c,0x2f38001f,0x3ce00175,0x5fdc0f4a}},	//   _शान्, _የህፃና, pdiv_, मिकल, 
   {{0x497002d5,0x1d080f64,0x8cb402dd,0x6c74014b}},	//   іліс, _реми_, _ەگەس_, _гурх, 
   {{0x6458006f,0x87d400f7,0xbd440451,0x18340127}},	//   _nzwi, لبوس_, _ننڍي, جراح, 
   {{0xbd380117,0x00000000,0x00000000,0x00000000}},	//   _рӯҳу_, --, --, --, 
   {{0x645800ca,0xe9380131,0xc6d001d5,0x6d5c010e}},	//   _azwi, خسەت_, زتوت, _yhsa, 
   {{0xb4e000dc,0x3e7c01e1,0x05a4000d,0xf49800d1}},	//   दये_, _yàtó_, _गिरब, اھات_, 
   {{0x74140349,0x00000000,0x00000000,0x00000000}},	//   াপ্ট_, --, --, --, 
   {{0x6fac01ad,0x64581c4d,0x00000000,0x00000000}},	//   _जिबू, _dzwi, --, --, 
   {{0x25a81c4e,0x6458013e,0x248c011f,0xd25800a7}},	//   _مدني_, _ezwi, bbem_, ъци_, 
   {{0xae0407f7,0x00000000,0x00000000,0x00000000}},	//   रहसन_, --, --, --, 
   {{0x53f81c4f,0x9fa40032,0x348400fb,0x22580210}},	//   _جراح_, йырҙ, _кѳҙг, ęska_, 
   {{0x6d5c022e,0xdce40055,0x00000000,0x00000000}},	//   _shsa, _rikā, --, --, 
   {{0x2d841aa7,0xdce40270,0x4d240261,0x70941c50}},	//   ële_, _sikā, аќаа, _лайф, 
   {{0xff1404c5,0x3e7c0ca8,0xdce40055,0x332c0327}},	//   _সদৃশ_, _pàtó_, _pikā, lidx_, 
   {{0x64580175,0xa2bc043e,0x7dcc0108,0x25dc0037}},	// [1710] _xzwi, _शाम्, _pösö, _कैनी_, 
   {{0x4ea41c51,0x332c0175,0x91d8060c,0x69c00139}},	//   _триа, nidx_, _बनाई, _älek, 
   {{0x6d5c02b9,0x257001a6,0xc0e8072d,0x3eb400d7}},	//   _thsa, _ošla_, _صفین_, ňatí_, 
   {{0xdb1400dd,0x6f04014f,0xdce41c52,0xb4e000dc}},	//   rtyá, _hohc, _tikā, दयो_, 
   {{0x27e81c53,0x2ee0006a,0x80bc00dc,0xdb1400e5}},	//   ían_, _kahf_, ष्टे, styá, 
   {{0xfbac0a59,0x320c00a2,0x00000000,0x00000000}},	//   _चितम, kydy_, --, --, 
   {{0x6f04047e,0xa3d807f7,0xa2bc1c54,0x27e8010f}},	//   _mohc, डौन_, _शाब्, ŭan_, 
   {{0x25a81c55,0xe3b81c56,0x8d280023,0x398c01e1}},	//   čal_, гби_, _ተወሃሂ, _wòsò_, 
   {{0x64a41c57,0x6f040076,0x248c15c0,0xb6e00108}},	//   _ғала, _oohc, rbem_, öään, 
   {{0xf7700491,0x6f04014f,0x6594009d,0x00000000}},	//   _قال_, _nohc, _гажу, --, 
   {{0xa2e407d6,0xa2281c58,0xe1080f06,0x6ae00154}},	//   _ҳолд, ужна_, генд_, নাপো, 
   {{0xc568027d,0x201c01e4,0xf49400db,0x00000000}},	//   _شحال_, ŝtim_, _ۇشۇد, --, 
   {{0xa2e41c59,0x63840640,0x6f040455,0x64581c5a}},	//   _голд, _угла, _bohc, _uzwi, 
   {{0xe2981c5b,0x320c010e,0x00000000,0x00000000}},	//   _сак_, bydy_, --, --, 
   {{0x6f040477,0x2c84063f,0x00000000,0x00000000}},	//   _dohc, _ụmị_, --, --, 
   {{0x2d6c1c5c,0xdee4013e,0x8d500023,0xfbac1c5d}},	//   _ﺳﺎﻧﻰ_, шоҳи, _መብርሂ, _चिदम, 
   {{0x5ac81c5e,0x6e2c0020,0x6ae0015b,0xe3c003e0}},	// [1720] ллам_, ደሚገባ, নানো, _çığ_, 
   {{0xda64007b,0x3ce80037,0x9f0415b4,0x00000000}},	//   ماضي, _चोरे_, _چوکو, --, 
   {{0x58841c5f,0x80dc00bc,0x00000000,0x00000000}},	//   была, _बसाइ, --, --, 
   {{0xd838152d,0xd5b8016c,0x00000000,0x00000000}},	//   лэл_, ҳси_, --, --, 
   {{0xdc2c0020,0x62800175,0x37f80276,0xd4980075}},	//   _በመሆኑ, kclo, релэ_, ңри_, 
   {{0x99741c60,0xe7d401d5,0x47300212,0x00000000}},	//   _гуаш, تمهگ, пніс, --, 
   {{0x6d4000fc,0x62800072,0x2c74063f,0x7d08002d}},	//   élag, dclo, _ụdi_, êdsw, 
   {{0x18681c61,0x764403ee,0x7bc4003a,0xe9701c62}},	//   _баби_, şiyo, otiu, _قۇلد, 
   {{0x7bc41c63,0x68fc00a3,0x00000000,0x00000000}},	//   ntiu, _òsda, --, --, 
   {{0x62801c64,0x8a100014,0x7bc4003a,0x00000000}},	//   gclo, _بِہت, itiu, --, 
   {{0x14c81c65,0x8af8008d,0xcfa41206,0x00000000}},	//   _были_, אליז, әшми, --, 
   {{0x7bc40357,0x320c1c66,0x6f04047e,0xdb1401f4}},	//   ktiu, rydy_, _sohc, ltyä, 
   {{0x2570098d,0x6f04014f,0x41c00014,0x6280045a}},	//   _ušla_, _pohc, _ہٲوِ, bclo, 
   {{0x7bc4003a,0x62800072,0xdb1401f4,0x2560032e}},	//   dtiu, cclo, ntyä, gólf_, 
   {{0x91841c67,0x51841c68,0x7bc4003a,0xd1f00023}},	//   _اجتم, _уула, etiu, ግሰቲ_, 
   {{0x69c001b8,0x7bc4036e,0xdb14005b,0x00000000}},	//   _älei, ftiu, htyä, --, 
   {{0x101400f1,0x00000000,0x00000000,0x00000000}},	// [1730] _دبغد, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7bc41c69,0x104c001f,0xc278010f,0x00000000}},	//   atiu, _ማስቀመ, ארבי, --, 
   {{0x2040001f,0x764403ee,0xfbd001ed,0x7bc408c2}},	//   _የሕብረ, ğiyl, بتہ_, btiu, 
   {{0x7bc41c6a,0x62801c6b,0x7644083c,0x6ae000fe}},	//   ctiu, yclo, şiyl, নাবো, 
   {{0xe7381c6c,0xdb140139,0x00000000,0x00000000}},	//   јек_, gtyä, --, --, 
   {{0x6b8c0385,0x00000000,0x00000000,0x00000000}},	//   lpag, --, --, --, 
   {{0x69c41253,0x6b8c1c6d,0x62800455,0x63840124}},	//   mthe, opag, wclo, огиа, 
   {{0x6b8c1c6e,0x6280007c,0xf7940064,0x00000000}},	//   npag, tclo, _натэ, --, 
   {{0x6b8c1c6f,0x27ec1c70,0xe298026a,0xcfbc015b}},	//   ipag, _iren_, шао_, ইবান, 
   {{0x27ec1c71,0x69c41c72,0x63ac0115,0xe50814fe}},	//   _hren_, nthe, _ĥanu, _پيشو_, 
   {{0x69c41c73,0x27ec138f,0x291c1c74,0x25701c75}},	//   ithe, _kren_, nhwa_, _išlo_, 
   {{0x291c0810,0x7bc41c76,0x00000000,0x00000000}},	//   ihwa_, xtiu, --, --, 
   {{0x69c41c77,0x6b8c1c78,0x27ec005a,0x00000000}},	//   kthe, dpag, _mren_, --, 
   {{0x1d081c79,0x291c1c7a,0xdc981c7b,0xdca41c7c}},	//   аеви_, khwa_, иташ_, жаби, 
   {{0x27ec1c7d,0x6b8c1c7e,0x7bc41c7f,0x00000000}},	//   _oren_, fpag, ttiu, --, 
   {{0x69c41c80,0x6b8c1c81,0x92cc1c82,0xdee41c83}},	// [1740] ethe, gpag, ৱাৰ_, _допи, 
   {{0x7bc41c84,0x00000000,0x00000000,0x00000000}},	//   rtiu, --, --, --, 
   {{0x7bc41c85,0xd8880952,0x69c41c86,0x27ec1c87}},	//   stiu, لپان_, gthe, _aren_, 
   {{0x7bc41c88,0x57e81c89,0x27ec1c8a,0x61e402d2}},	//   ptiu, идем_, _bren_, _áhlu, 
   {{0x7bc40cfe,0x6b8c010a,0x27ec1c8b,0x07a01c8c}},	//   qtiu, cpag, _cren_, дачн, 
   {{0x69c413ee,0x00000000,0x00000000,0x00000000}},	//   bthe, --, --, --, 
   {{0x27ec1c8d,0x25dc1b76,0xb2740116,0xdb140108}},	//   _eren_, _कैदी_, үлиш, rtyä, 
   {{0x291c1c8e,0x27ec1c8f,0xd1b80201,0xd3a41c90}},	//   chwa_, _fren_, ታወቀ_, ороп, 
   {{0x27ec1c91,0xc0d00240,0x00000000,0x00000000}},	//   _gren_, _ብሳላ_, --, --, 
   {{0xb6c80014,0x92681c92,0x63ac01e4,0xd6280536}},	//   _دارے_, ирна_, _ĥant, _козе_, 
   {{0xf4841c93,0x6b8c1c94,0x4a780677,0x3f8403b2}},	//   _فاشی, zpag, יריב, ímun_, 
   {{0x6b8c1c95,0xb8a40092,0xe1ec00ec,0x00000000}},	//   ypag, _ሊቀጥል_, اڳو_, --, 
   {{0xd1b80020,0x8f081c96,0x6b8c0175,0x69c41c97}},	//   ታወቁ_, ахва_, xpag, zthe, 
   {{0xb8fc0ed9,0x69c41c98,0x291c0810,0x6b8c0175}},	//   _འི_, ythe, zhwa_, vpag, 
   {{0x06280201,0x6b8c1c99,0x69c400a3,0x00000000}},	//   _እንደነ, wpag, xthe, --, 
   {{0x6b8c1c9a,0x69c40998,0x645c000d,0x412800f3}},	//   tpag, vthe, üsig, _мојо_, 
   {{0x6b8c1c9b,0x8c38002f,0xdb9c0150,0xbd6801ec}},	// [1750] upag, _meßg, _ﺀﯨﺮﻯ_, ірсе_, 
   {{0x6b8c1c9c,0x27ec1c9d,0xfbac043e,0x00000000}},	//   rpag, _rren_, _चिरम, --, 
   {{0xa2bc1c9e,0x41241c9f,0x69c41ca0,0xe6881ca1}},	//   _शास्, _رفیق, uthe, ەنتى_, 
   {{0x27ec1ca2,0x6b8c1ca3,0x69c41ca4,0x7d08002d}},	//   _pren_, ppag, rthe, êdst, 
   {{0x6b8c1ca5,0x6d4c1ca6,0xe75801ec,0x00000000}},	//   qpag, moaa, биді_, --, 
   {{0x69c41ca7,0x6d4c1ca8,0x20400092,0xa594020f}},	//   pthe, loaa, _የንብረ, прищ, 
   {{0x79a41ca9,0x27ec1caa,0x291c0161,0x6d4c1cab}},	//   _орте, _wren_, phwa_, ooaa, 
   {{0x6d4c1cac,0x291c1cad,0x00000000,0x00000000}},	//   noaa, qhwa_, --, --, 
   {{0x27ec1cae,0xe3b000c6,0x7bc0014a,0xd1b8001f}},	//   _uren_, ررة_, _ämut, ታወቅ_, 
   {{0x6d4c0108,0x00000000,0x00000000,0x00000000}},	//   hoaa, --, --, --, 
   {{0x6d4c005b,0xf74800f1,0x22480116,0x64740150}},	//   koaa, _بللي_, спни_, _егеу, 
   {{0xfbac03e5,0x61340153,0x74f80b01,0x00000000}},	//   _चिलम, kšle, _мехр_, --, 
   {{0x656808cb,0x20541caf,0x645c1cb0,0x02c001c0}},	//   mmeh, ятор, üsid, _жилү, 
   {{0x65681cb1,0x00000000,0x00000000,0x00000000}},	//   lmeh, --, --, --, 
   {{0x6d4c0607,0x656806d9,0x12f80375,0x00000000}},	//   foaa, omeh, _להסב, --, 
   {{0x65681cb2,0x63ac0fac,0xc2c00451,0x6d4c0108}},	//   nmeh, _åans, _ريڊي, goaa, 
   {{0x25dc0034,0x00000000,0x00000000,0x00000000}},	// [1760] _कैसी_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x58841cb3,0x6d4c06d9,0xed8000d1,0x4f840014}},	//   пыла, boaa, _аңси, _وایہ, 
   {{0x65680477,0x2bdc00cd,0x9d4400fb,0x00000000}},	//   jmeh, _नैवा, _хемд, --, 
   {{0xebc0052f,0x7d0406ea,0x656812bb,0x00000000}},	//   _иҡти, mjis, dmeh, --, 
   {{0x7d041cb4,0x96b81cb5,0x00000000,0x00000000}},	//   ljis, суду_, --, --, 
   {{0x7c24084c,0x7d04037e,0x6b880200,0x97bc01ec}},	//   lzir, ojis, _çegr, _әрбi, 
   {{0x48e01cb6,0x56300023,0x6568000d,0x00000000}},	//   _посв, _ክንክእ, gmeh, --, 
   {{0xa2bc1cb7,0x12e41cb8,0xb9f80240,0x00000000}},	//   _शाश्, пінг, _ዘሁ_, --, 
   {{0x7d041cb9,0x7c240083,0x47d00ccb,0x656800d0}},	//   hjis, izir, _سيمر, ameh, 
   {{0x7c240a40,0xa2bc1cba,0x7d040162,0xf8e001f9}},	//   hzir, _शार्, kjis, _नसाय, 
   {{0x7d041cbb,0x00000000,0x00000000,0x00000000}},	//   jjis, --, --, --, 
   {{0x0f70036b,0x85001cbc,0x1b2000fe,0x6d4c01f4}},	//   нғир, _سوون, _মদনে_, voaa, 
   {{0x7c241cbd,0x69c0168c,0x941c083c,0x645c0112}},	//   dzir, _åleg, ığıy, üsie, 
   {{0xa6c000fe,0x6d4c1cbe,0x7d0408a5,0x00000000}},	//   _এসময়, toaa, fjis, --, 
   {{0x7d04069c,0x6edc0166,0xd0180395,0x0be402dd}},	//   gjis, _bābü, _гфо_, _ﻏﻴﺭﻫ, 
   {{0x2b5005be,0x6f0001ed,0x61441cbf,0x92bc00cc}},	// [1770] _pkzc_, ölcs, _تىيە, ঁজী_, 
   {{0x6d4c1cc0,0x3b541cc1,0x7d08002d,0x7d04005b}},	//   soaa, екур, êdsr, ajis, 
   {{0x7c2404ba,0x2bdc07b7,0x995c0118,0xdce40153}},	//   azir, _नैरा, _kůň_, _likę, 
   {{0x7c24110c,0x7d040014,0x79240b00,0x00000000}},	//   bzir, cjis, ньчж, --, 
   {{0x66e41cc2,0x066400d1,0xa2bc1cc3,0xa7a80022}},	//   дола, ﻴﯩﻨﯩ, _शाल्, цкла_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x65681cc4,0xd5ac0d62,0x0a68030d,0x00000000}},	//   tmeh, لہٕ_, _ырми_, --, 
   {{0xfdf80302,0x87e4014b,0x00000000,0x00000000}},	//   לצות_, _нюзе, --, --, 
   {{0x0474066d,0x65681cc5,0x94700e4a,0x25dc10eb}},	//   _ہلاک_, rmeh, نگها, _कैरी_, 
   {{0x65681cc6,0x69c00793,0xdb140789,0x232800d4}},	//   smeh, _äles, tuyé, іони_, 
   {{0xf7481cc7,0x7c2402e8,0x21681cc8,0x61441cc9}},	//   _علمي_, zzir, жини_, дена, 
   {{0x8c38002f,0xb0640014,0x00000000,0x00000000}},	//   _meßb, کھى۪, --, --, 
   {{0xd9a805d7,0xb0f801c6,0x00000000,0x00000000}},	//   _चट्ट, чээх_, --, --, 
   {{0x69d41cca,0xf1a8004b,0xdb1406af,0x7c240010}},	//   _opze, _ځايه_, puyé, vzir, 
   {{0x7d041ccb,0x00000000,0x00000000,0x00000000}},	//   tjis, --, --, --, 
   {{0x7c2401c0,0x7d040009,0x00000000,0x00000000}},	//   tzir, ujis, --, --, 
   {{0x7d041ccc,0x7c241ccd,0x5f28023a,0x1ae401b9}},	// [1780] rjis, uzir, _моим_, моам, 
   {{0x2a6c01e4,0x76441cce,0xfe9400f2,0xcfb40677}},	//   _ŝeba_, şiyi, _سیرج, _קליי_, 
   {{0x1d081ccf,0x3f80003a,0x25dc00ab,0x02cc00dc}},	//   _дени_, _huiu_, _कैली_, त्यभ, 
   {{0xb7c400c7,0x39400254,0x00000000,0x00000000}},	//   еркқ, õis_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x386001e4,0x02cc00cd,0xe9a800f7,0x00000000}},	//   ĥir_, त्मभ, زدۅن_, --, 
   {{0xd5b81cd0,0x75840241,0x00000000,0x00000000}},	//   іск_, _ẹgbé, --, --, 
   {{0x06801cd1,0xfd6400b8,0x49b00150,0x00000000}},	//   нгән, _pauṃ, _шәуу, --, 
   {{0x69c00036,0x661c0213,0xa3d81cd2,0x00000000}},	//   _äler, _əski, डौल_, --, 
   {{0x59d002fe,0x78a001e6,0x2544005f,0x1cdc0327}},	//   _सहार, _hemv, vēle_, _རིའ_, 
   {{0x32181ab0,0x78a001e3,0xc1b401c6,0x5f0000cd}},	//   áry_, _kemv, млэх_, शान्_, 
   {{0x92bc00bd,0x3f8007c5,0xdce40064,0x00000000}},	//   ঁজে_, _buiu_, _tikę, --, 
   {{0x78a01cd3,0x3f801cd4,0x066400d1,0x00000000}},	//   _memv, _cuiu_, ﻴﯩﻠﯩ, --, 
   {{0x78a01cd5,0x3f8007c5,0x00000000,0x00000000}},	//   _lemv, _duiu_, --, --, 
   {{0x6ef400a2,0x31341cd6,0x00000000,0x00000000}},	//   _aýbä, _пекр, --, --, 
   {{0x3f800268,0xde3c001f,0xecc4009d,0x00000000}},	//   _fuiu_, ደሚያገ, эшгү, --, 
   {{0x3f801cd7,0x3c580276,0x7c840354,0x6af40166}},	// [1790] _guiu_, дитэ_, тусе, нзаф, 
   {{0x799c0142,0xc278010f,0x00000000,0x00000000}},	//   _bwrw, ַרדי, --, --, 
   {{0x78a01cd8,0x7ac40801,0xc9841cd9,0x799c0042}},	//   _bemv, ъсте, фузи, _cwrw, 
   {{0x1cdc0003,0x25601cda,0x3d1c01e1,0xa3340023}},	//   _རིར_, kóla_, _tíwa_, _ብወትሃ, 
   {{0x22580210,0x00000000,0x00000000,0x00000000}},	//   ęski_, --, --, --, 
   {{0x78a000f1,0x7c2005d1,0xaad40248,0x00000000}},	//   _eemv, _ümra, _àlàó_, --, 
   {{0x6aa41cdb,0x05f4002b,0x799c0042,0x369401ec}},	//   mahf, _bhūḥ_, _gwrw, тшіс, 
   {{0x6aa405b1,0x2d801cdc,0x6610031c,0xa020032e}},	//   lahf, _muhe_, _ċekċ, _þögn, 
   {{0x2d801cdd,0x2fc80218,0xf778031c,0x68e8004e}},	//   _luhe_, _nqag_, _fiħ_, _iaed, 
   {{0x290c18a6,0x68e81cde,0x78a01cdf,0xa2041ce0}},	//   _hoea_, _haed, _zemv, епод, 
   {{0x68e81ce1,0x3f800a73,0x290c02b5,0x78a01ce2}},	//   _kaed, _suiu_, _koea_, _yemv, 
   {{0x4acc0db3,0x3f800311,0x290c01a6,0x6b9c03ac}},	//   स्तव, _puiu_, _joea_, _owsg, 
   {{0x290c1ce3,0x2d800270,0x68e804ce,0x256000d2}},	//   _moea_, _auhe_, _maed, cóla_, 
   {{0x68e81ce4,0x1cdc0156,0x2d801ce5,0x657800b0}},	//   _laed, _རིཤ_, _buhe_, _hiwh, 
   {{0x6aa402d0,0x00000000,0x00000000,0x00000000}},	//   dahf, --, --, --, 
   {{0x20000054,0x68e81ce6,0x2d801ce7,0x00000000}},	//   pxki_, _naed, _duhe_, --, 
   {{0x1c441ce8,0x78a01ce9,0x65780455,0x799c02d0}},	// [17a0] хнам, _remv, _miwh, _swrw, 
   {{0x78a01cea,0x63a81ceb,0x64580334,0x68e80334}},	//   _semv, isen, _mywi, _aaed, 
   {{0x63a81cec,0x68e81ced,0xefbc001f,0x78a01cee}},	//   hsen, _baed, ታየው_, _pemv, 
   {{0x63a81cef,0x68e81730,0x26c40784,0x657802b1}},	//   ksen, _caed, _aclo_, _niwh, 
   {{0x68e81cf0,0x63a81cf1,0x645801c8,0x18681cf2}},	//   _daed, jsen, _nywi, чади_, 
   {{0x63a81cf3,0x78a01cf4,0x290c007f,0x68e80381}},	//   dsen, _wemv, _eoea_, _eaed, 
   {{0x63a81cf5,0x68e8001f,0x64580784,0x78a01cf6}},	//   esen, _faed, _aywi, _temv, 
   {{0x63a81cf7,0x645803cb,0x68e81cf8,0x6124032e}},	//   fsen, _bywi, _gaed, _hólf, 
   {{0x64581cf9,0x63a81cfa,0x65781cfb,0x57b00220}},	//   _cywi, gsen, _diwh, _сұлт, 
   {{0x2560026c,0x290c01f7,0x2bd000af,0x6458012d}},	//   róla_, _zoea_, हऽता, _dywi, 
   {{0x63a81cfc,0x290c0a73,0x130400fd,0xca38001f}},	//   asen, _yoea_, _үзем, _ጨዋታዎ, 
   {{0x63a81cfd,0x2d801cfe,0x645803cb,0x256000e4}},	//   bsen, _ruhe_, _fywi, póla_, 
   {{0x2d801cff,0x645800a9,0x63a801d3,0xdd681d00}},	//   _suhe_, _gywi, csen, _ﺳﺎﭘﺎ_, 
   {{0x2d80005b,0x4474010f,0x00000000,0x00000000}},	//   _puhe_, _נעגל_, --, --, 
   {{0xdb0c0241,0xd138010a,0xca2c0150,0x64581d01}},	//   _àjùm, _нхи_, _ﺩﻓﺎ_, _zywi, 
   {{0xb9180055,0xdb14007f,0x66040108,0x9f40013d}},	//   _gneḥ_, lryè, ähki, evkä_, 
   {{0x68e80393,0x2d8000ca,0xfe7001ed,0x6124032e}},	// [17b0] _raed, _wuhe_, لدہ_, _bólf, 
   {{0x68e80097,0x394400ef,0x2d8000d7,0xcf2401c8}},	//   _saed, _ajms_, _tuhe_, _سرخي, 
   {{0xc3300302,0x290c079b,0xe94413f9,0x63a81d02}},	//   נוע_, _poea_, پرای, zsen, 
   {{0x9f5002e2,0x6ecc1d03,0x1d780092,0x7be000cc}},	//   _aryè_, द्रु, _በሴቶች_, _নপৰো, 
   {{0x257005ce,0x290c1d04,0x68e8006f,0x657802b1}},	//   _ušli_, _voea_, _vaed, _riwh, 
   {{0xd7ec0b38,0x61240008,0x64581d05,0x68e81d06}},	//   زكى_, _gólf, _rywi, _waed, 
   {{0x68e816b8,0x290c1d07,0x657800b0,0x63a80334}},	//   _taed, _toea_, _piwh, wsen, 
   {{0x63a81d08,0x26c40354,0x798800f2,0x31680208}},	//   tsen, _wclo_, _édwa, _nhaz_, 
   {{0xe2981d09,0xa77400fd,0x232802e8,0xd9b00133}},	//   мап_, _алач, допи_, _مڕۆد, 
   {{0x3168003a,0xdedc02d3,0x00000000,0x00000000}},	//   _ahaz_, ሕትን_, --, --, 
   {{0x657804fe,0x64580034,0x672002d0,0xf3c81d0a}},	//   _tiwh, _wywi, _illj, وبیه_, 
   {{0x63a81d0b,0xa2bc1d0c,0x6e2800df,0x3d1c01e1}},	//   psen, _शाक्, ĝebl, _ríwo_, 
   {{0xa3e40dc5,0x61e000a9,0x256000d2,0x254400e2}},	//   _पनि_, swll, lólo_, cēla_, 
   {{0xb46402bf,0x53980375,0x61e00142,0xa1f403f6}},	//   _скіл, _חיסו, pwll, _аџиј, 
   {{0xdca41d0d,0xdb14010b,0x00000000,0x00000000}},	//   кави, gtyý, --, --, 
   {{0x3168025c,0x326001d9,0xa3e407f7,0x61241d0e}},	//   _ghaz_, _دۆپہ, _पना_, _sólf, 
   {{0x4fe401c0,0x4c801d0f,0xfb841d10,0x3d1c0241}},	// [17c0] _амын_, рлув, ادری, _wíwo_, 
   {{0x25600296,0x4b201d11,0x61241d12,0x9b3c0092}},	//   kólo_, амув, _bólg, _በየካቲ, 
   {{0x18a412b4,0x9d4400fd,0x00000000,0x00000000}},	//   ваем, _аенд, --, --, 
   {{0x67201d13,0xdcfc1d14,0xe99404fb,0x61240a87}},	//   _allj, _kupč, اهنگ, _dólg, 
   {{0x2ba81d15,0x6ac80c58,0x67200076,0x3ab4008e}},	//   _चौपा, ৰয়ো, _bllj, _бәет, 
   {{0xcf9000c8,0x3ce00158,0x612408a5,0x00000000}},	//   סטו_, leiv_, _fólg, --, 
   {{0xdcfc0010,0x60d402d0,0x394401f4,0xaa6401af}},	//   _lupč, _obym, _tjms_, _берһ, 
   {{0x18681d16,0x254400e2,0x67201d17,0x13a400e5}},	//   _жаби_, tēla_, _ellj, نچتی_, 
   {{0x67400014,0xdb140100,0x98340006,0x00000000}},	//   _گێوٕ, tryè, _рэві, --, 
   {{0x51841d18,0x31681d19,0x60d40129,0xf8640117}},	//   кума, _shaz_, _abym, _авғо, 
   {{0x1d30001f,0x54c413cf,0x2f1c01e1,0xcb10010f}},	//   _በገንዘ, _абеб, _sìgo_, ילז_, 
   {{0x498402d3,0xf8b40959,0x00000000,0x00000000}},	//   _ንነብሱ_, ुलिय, --, --, 
   {{0xc05802bf,0xf2c400d1,0x6d401d1a,0xc95000d9}},	//   вір_, _йөни, élam, שמר_, 
   {{0x8230183b,0x00000000,0x00000000,0x00000000}},	//   اریا, --, --, --, 
   {{0xc20c1d1b,0x5fb00037,0xfc380092,0x00000000}},	//   _тє_, _जिअल, _በመፈለ, --, 
   {{0x612401e7,0x8d740133,0x00000000,0x00000000}},	//   _rólg, ئاسا, --, --, 
   {{0x8aa41d1c,0x61241d1d,0x00000000,0x00000000}},	// [17d0] вред, _sólg, --, --, 
   {{0x6e9800a7,0xef1000f1,0x00000000,0x00000000}},	//   _явор_, _چټک_, --, --, 
   {{0xdcfc041a,0x7bc00158,0x6d3401a9,0xce680f06}},	//   _zupč, _åmun, _бенф, _юрид_, 
   {{0x3ce0002f,0x205c0092,0x00000000,0x00000000}},	//   ceiv_, _ለሕብረ, --, --, 
   {{0x2ca81d1e,0xaac40451,0xb81400c7,0x8c640006}},	//   maad_, _مڪان, аҧтә, _штод, 
   {{0xd2441d1f,0x2ca80050,0xe5a400d1,0x2eb01d20}},	//   _هن_, laad_, гики, _जयोत, 
   {{0xa2e401d5,0x00000000,0x00000000,0x00000000}},	//   қонд, --, --, --, 
   {{0xa3e81d21,0xdedc1772,0x2ca81d22,0x49440166}},	//   едиа_, ሕትና_, naad_, _рэгб, 
   {{0x291c1d23,0x2ba81d24,0x1ae403d4,0xa0a41d25}},	//   mkwa_, _चौमा, নাৰা, һанд, 
   {{0x2ca80014,0x291c009a,0xdcfc0e04,0xb9dc0023}},	//   haad_, lkwa_, _rupč, _አቲ_, 
   {{0xa0a41d26,0xbbd01d27,0x291c01f2,0x2ca81d28}},	//   ланд, _सङ्क, okwa_, kaad_, 
   {{0xdcfc0960,0x291c1d29,0x2ca80009,0xe1241d2a}},	//   _pupč, nkwa_, jaad_, умми, 
   {{0x2ca80050,0x291c1d2b,0xf4840408,0xd36c00f2}},	//   daad_, ikwa_, _тухн, تهی_, 
   {{0x248c1d2c,0xdb140113,0xfe7815bf,0x944001d3}},	//   lcem_, kuyá, күп_, _چھین, 
   {{0x14e40c58,0x2ca80014,0x3ce00c86,0x25600174}},	//   কাৰী_, faad_, teiv_, hólm_, 
   {{0x248c1d2d,0x02cc1d2e,0x2ca81d2f,0x5f340166}},	//   ncem_, त्रभ, gaad_, _әхиф, 
   {{0x3ce00183,0x61240a90,0x20040023,0x248c0381}},	// [17e0] reiv_, _cóle, _çoi_, icem_, 
   {{0x5eac015b,0x291c1d30,0x4f98010f,0x248c0205}},	//   ঞ্জে, ekwa_, _רביצ, hcem_, 
   {{0x2ca80050,0x99141d31,0x248c0010,0xadb40150}},	//   baad_, льді, kcem_, _پۇقا_, 
   {{0x60c406a3,0x2ca81d32,0x248c1d33,0x00000000}},	//   ngkm, caad_, jcem_, --, 
   {{0xb8dc1d34,0x645c00af,0x248c1d35,0x420c00dc}},	//   _आय_, üsil, dcem_, ाहुः_, 
   {{0x291c1d36,0x2c10012c,0x248c00d8,0xcc3800df}},	//   akwa_, णहरू_, ecem_, _װעלט, 
   {{0xf48405c2,0x94840209,0x8b200798,0xd9440117}},	//   қуқн, лыпд, _удре, _беви, 
   {{0x82bc031c,0x73d801a9,0x2ba809ab,0x00000000}},	//   _མཐུའ, вдир_, _चौडा, --, 
   {{0x56f01d37,0xede000bc,0x00000000,0x00000000}},	//   _гүлс, _पन्छ, --, --, 
   {{0x0b380020,0x1cdc031c,0x2ca81d38,0x32541d39}},	//   _በከተማ, _རིཀ_, zaad_, ивпр, 
   {{0x2ca80050,0x248c1d3a,0x8b54010f,0xaf340092}},	//   yaad_, bcem_, רייס_, _ባለማወ, 
   {{0x2ca80a81,0x461000aa,0x53a41086,0x248c0de2}},	//   xaad_, _دومر, _бадб, ccem_, 
   {{0xbf9400e5,0x3d081d3b,0xbe340092,0x00000000}},	//   یگیڈ, हाने_, _አስገዳ, --, 
   {{0x2ca80050,0x61240008,0x11f40014,0xabdc0150}},	//   waad_, _róle, _موتک_, _ﺇﺴﻨﺎ, 
   {{0x2ca81d3c,0x2d841d3d,0x70941d3e,0xa634001f}},	//   taad_, êle_, _кайф, _እንደሰ, 
   {{0xad241a59,0x61241d3f,0xac94141c,0x00000000}},	//   جىرى, _póle, рааш, --, 
   {{0x2ca81d40,0x5fb0000d,0x6714000d,0x999800a2}},	// [17f0] raad_, _जिएल, _तकलक_, lypň_, 
   {{0x2ca81d41,0x61240789,0xdec000d1,0x659000b8}},	//   saad_, _vóle, _мәсо, _hāhe, 
   {{0x6590170b,0x7b641d42,0x2ca80b21,0x248c1d43}},	//   _kāhe, стте, paad_, ycem_, 
   {{0x61240085,0x2ba81715,0x7c84013e,0x2ca80014}},	//   _tóle, _चौथा, _гуре, qaad_, 
   {{0x65901d44,0xef480023,0xe6c400ae,0x00000000}},	//   _māhe, _ዓብደል, لتغي, --, 
   {{0x81d8045e,0x291c1d45,0x645c00c5,0x248c012d}},	//   ঠিত_, skwa_, üsim, wcem_, 
   {{0x2ba8038e,0x6ab402d0,0x248c1d46,0xff18011a}},	//   _चौता, _idzf, tcem_, רקות_, 
   {{0x6590002b,0xfe38010f,0x00000000,0x00000000}},	//   _nāhe, טרוי_, --, --, 
   {{0xa6340020,0xe450007b,0x00000000,0x00000000}},	//   _እንዲሰ, غضب_, --, --, 
   {{0x248c1d47,0xd36c1d48,0xe1f802bf,0xdedc0023}},	//   scem_, وهي_, вго_, ሕድና_, 
   {{0x248c1d49,0x62641d4a,0x30a00150,0xc7940408}},	//   pcem_, рвна, _ﺃﺩﺒﻴ_, _арçы, 
   {{0x65900055,0x61240321,0x6ae000fe,0xe4740166}},	//   _cāhe, _sólb, নাটো, _кулэ, 
   {{0xdcfc1d4b,0x65900055,0x84640395,0x5f8000d1}},	//   _atpğ, _dāhe, _съже, غۇدە, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdcfc00b8,0x9d5401d5,0xe50800cd,0xdd9006c2}},	//   _aupā, لنست, वापि_, توز_, 
   {{0x06ac1d4c,0xa2cc02c3,0x10a0030d,0x00000000}},	//   চ্চি, थभक्, _диън, --, 
  
   {{0x5ac81d4d,0x1be80107,0x00000000,0x00000000}},	// [1800] клам_, ъдаи_, --, --, 
   {{0x256009cc,0x5a940454,0xdd881171,0x00000000}},	//   fólk_, рраф, _ибод_, --, 
   {{0xd12c04d3,0x2d84012c,0x00000000,0x00000000}},	//   _رمی_, ílet_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x59d00aff,0xe50800cd,0x00000000,0x00000000}},	//   _सहकर, वानि_, --, --, 
   {{0x501802e4,0x256006ea,0x8f980677,0xda6406c5}},	//   כונו, bólk_, דיסי, _نازي, 
   {{0x61340e3c,0xceb00375,0x98a402bf,0x7bc41d4e}},	//   ršlj, קיה_, _вибе, luiu, 
   {{0xd9440209,0x2c0c03d4,0x00000000,0x00000000}},	//   _теби, _সেয়ে_, --, --, 
   {{0x659002b5,0x7bc41d4f,0xa91c00ef,0x569400fb}},	//   _rāhe, nuiu, _dižd, _ҡаҡт, 
   {{0x7bc41d50,0x4c2c0092,0x9654030d,0x00000000}},	//   iuiu, _በጉባኤ, _къеч, --, 
   {{0x79801d51,0x65900374,0x00000000,0x00000000}},	//   _kimw, _pāhe, --, --, 
   {{0x1cdc025c,0x7bc40869,0x00000000,0x00000000}},	//   _རིཊ_, kuiu, --, --, 
   {{0x50641d52,0x79801d53,0x25a807f5,0x7bc40194}},	//   ртна, _mimw, ćale_, juiu, 
   {{0x79801d54,0x659002b5,0x63bc1d55,0x30040022}},	//   _limw, _wāhe, ásne, азҭг, 
   {{0xfd881d56,0x8d741d57,0x65900374,0x3f84066a}},	//   иёти_, لارا, _tāhe, ímur_, 
   {{0x7980015c,0xc27800c8,0x427806a9,0xdcfc00ef}},	//   _nimw, _ברוי, _באוג, _pupā, 
   {{0x7bc41d58,0xdb140986,0x0b88011c,0x00000000}},	// [1810] guiu, kuyä, тсби_, --, 
   {{0x7980035a,0xa91c01a6,0x2d840789,0xbcf001e4}},	//   _aimw, _miže, íles_, roɩa, 
   {{0x79800537,0x7bc40093,0xc0580014,0xa91c0010}},	//   _bimw, auiu, _مشیا_, _liže, 
   {{0x645c00af,0xdcfc00b0,0x7bc404cc,0x79800142}},	//   üsik, _tupā, buiu, _cimw, 
   {{0x612405a4,0x79801d59,0x6d5c0522,0x7bc41730}},	//   _jóla, _dimw, _iksa, cuiu, 
   {{0x66e41d5a,0x6d5c089c,0x798008e7,0xa6c81d5b}},	//   сока, _hksa, _eimw, улка_, 
   {{0xa3a8134e,0x6b8c031c,0x9f4c01d3,0x00000000}},	//   गीन_, lqag, énél_, --, 
   {{0x69c41d5c,0x24e8013e,0x2248107d,0x00000000}},	//   muhe, умии_, _ćak_, --, 
   {{0x3d08069f,0x69c418a6,0xf7940953,0xd05c03b9}},	//   हाते_, luhe, _матэ, _taqə, 
   {{0x79800516,0x00000000,0x00000000,0x00000000}},	//   _zimw, --, --, --, 
   {{0x69c40334,0x79800223,0x04b40014,0xa91c00ef}},	//   nuhe, _yimw, _نپاں_, _eiže, 
   {{0x61241d5d,0x592c0135,0x61441d5e,0x25601d5f}},	//   _bóla, ྩིགས_, сема, kóli_, 
   {{0x69c41d60,0x00000000,0x00000000,0x00000000}},	//   huhe, --, --, --, 
   {{0x6d5c1d61,0x61241d62,0x5398025f,0x2294007b}},	//   _aksa, _dóla, _עיצו, _الغس, 
   {{0xb638001f,0x69c40037,0x27ec1d63,0x61240332}},	//   _እንደቀ, juhe, _lsen_, _eóla, 
   {{0x2ba81533,0x61341d64,0x27ec1d65,0x6124032e}},	//   _चौहा, kšli, _osen_, _fóla, 
   {{0x79801d66,0x27ec013f,0xf388001e,0x6b8c1d67}},	// [1820] _rimw, _nsen_, _lợn_, gqag, 
   {{0xa3a81d68,0x7bc40393,0x79801d69,0x69c402d2}},	//   गीय_, ruiu, _simw, fuhe, 
   {{0x69c41d6a,0x27ec1d6b,0x6d5c0418,0x79800455}},	//   guhe, _asen_, _fksa, _pimw, 
   {{0x1d081d6c,0x79800784,0x6e2003cd,0x6b8c0327}},	//   _семи_, _qimw, ølbe, bqag, 
   {{0x7bc41730,0x69c41d6d,0x7980009f,0x00000000}},	//   quiu, auhe, _vimw, --, 
   {{0x798000ca,0x1cdc025c,0x69c41d6e,0x25a4015d}},	//   _wimw, _རིཌ_, buhe, _bwll_, 
   {{0x79801d6f,0xa91c0171,0xc6d01d70,0x27ec1d71}},	//   _timw, _siže, ستوت, _esen_, 
   {{0xf8b0034c,0x25a40042,0xf3f8010b,0xecc007f7}},	//   _آکا_, _dwll_, иңе_, एलएफ, 
   {{0xb6380020,0xc7a0050b,0x4acc1d72,0xd3781d73}},	//   _እንዲቀ, _нитк, स्कव, лчо_, 
   {{0xb378037e,0x795400a2,0x61241d74,0x00000000}},	//   _sでbs, _düwş, _róla, --, 
   {{0x6124066a,0x23a805f9,0xf3880208,0x16a80107}},	//   _sóla, चीबद, _gợn_, _авҷи_, 
   {{0xc5f00302,0x61241d75,0x4a78010f,0x09f4011a}},	//   _מדע_, _póla, טריב, צמכם_, 
   {{0x69c40112,0x00000000,0x00000000,0x00000000}},	//   zuhe, --, --, --, 
   {{0x65901d76,0x4ac406ab,0x69c402c4,0xa7fc01d3}},	//   _hāha, _लाइव, yuhe, _szűk, 
   {{0xd04403be,0xe188001e,0x65901d77,0xdce80055}},	//   _əməl, _hẳn_, _kāha, _śnāt, 
   {{0x61241d78,0x25601d79,0x69c41d7a,0xfd880107}},	//   _tóla, tóli_, vuhe, сёри_, 
   {{0x659004fe,0xdcfc0311,0x69c41d7b,0x8d8401b9}},	// [1830] _māha, _supă, wuhe, руҳд, 
   {{0x69c41d7c,0x4ea401c0,0xdcfc054e,0x69c0072b}},	//   tuhe, _уриа, _pupă, _ålek, 
   {{0x2ba81d7d,0x0a680107,0xb05400f1,0x6b8c01a9}},	//   _चौरा, ураи_, _دپکت, sqag, 
   {{0x69c41d7e,0x6d5c0bc9,0xf38801fb,0xacc800f7}},	//   ruhe, _uksa, _rợn_, _өгүз_, 
   {{0x69c41d7f,0x66e4007f,0x6b8c0869,0x00000000}},	//   suhe, _lékņ, qqag, --, 
   {{0x69c402f6,0x25a40368,0xa59412e7,0x2cb80208}},	//   puhe, _pwll_, орищ, _hdsd_, 
   {{0x69c40023,0x6590002b,0x254400e2,0xd90c01d3}},	//   quhe, _bāha, lēli_, ریے_, 
   {{0xe3b81d80,0x1cdc0135,0xe3b00244,0x659000cd}},	//   аби_, _རིབ_, ورخ_, _cāha, 
   {{0x27ec1d81,0x6590002b,0x00000000,0x00000000}},	//   _usen_, _dāha, --, --, 
   {{0xdb14049b,0xf388004d,0xe2c816ac,0x25a403cb}},	//   styö, _tợn_, جودو_, _twll_, 
   {{0x8ebc009e,0xe508002b,0xd24c00e5,0x00000000}},	//   ইভাগ, वादि_, ہنی_, --, 
   {{0x6f04004d,0x659000b8,0xd24c004b,0x28d003ba}},	//   _anhc, _gāha, ځنی_, _हाफि, 
   {{0xd24c0edf,0x20540108,0x2ba809ab,0x00000000}},	//   فنی_, ютор, _चौला, --, 
   {{0xed5000c6,0xe2981d82,0xe7f0033f,0x5f740127}},	//   _ו̾_, _так_, _आईना_, تاجر, 
   {{0x1cdc031c,0x8e801d83,0x21680798,0x5fb4012d}},	//   _རིད_, дгре, _кики_, _अटकल, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8c38002f,0xd00c007b,0x1c440022,0x93540345}},	// [1840] _meßw, _للي_, цнам, _ارۆچ, 
   {{0x2cb8010a,0x5de40354,0x98a401a6,0xa0c40ee8}},	//   _edsd_, _джоа, rhoč_, _ايکو, 
   {{0xa3a8023e,0x7f5c1d84,0x5d740117,0x00000000}},	//   गीत_, morq, _мумф, --, 
   {{0x6d4007ea,0x7f5c1d85,0x200401ab,0x47e000cc}},	//   élat, lorq, _àois_, পিনী, 
   {{0xc7900137,0x65901d86,0x61240241,0x37f8010b}},	//   وشوب, _rāha, _lólo, селэ_, 
   {{0xd5b81d87,0x27e81d88,0x6e380428,0x98a81d89}},	//   аси_, çana_, _ñabü, ımın_, 
   {{0x65900374,0x7f5c0077,0xe188004d,0x27e8031c}},	//   _pāha, iorq, _sẳn_, ħana_, 
   {{0xe9700220,0x89d41c3b,0x1de0012d,0x612402d2}},	//   _كۇلد, _گوہر_, _पहनत, _sóln, 
   {{0x25a8098d,0xc2f0045e,0x7f5c03f0,0x969400a7}},	//   ćala_, জানি_, korq, _дреш, 
   {{0x65900325,0x63bc01ed,0x7f5c06af,0x25b40014}},	//   _wāha, ásna, jorq, _کۆٹھ_, 
   {{0x659004fe,0x28d01d8a,0x7f5c1d8b,0x612400d8}},	//   _tāha, _हामि, dorq, _cólo, 
   {{0xd1381d8c,0xf3880051,0x940400f1,0x00000000}},	//   рхо_, _hợm_, _وواه, --, 
   {{0x61fc00e2,0x6590002b,0xb6440150,0xa91c01ef}},	//   āsla, _jāhn, _ﺎﻑ_, _jiža, 
   {{0x254400e2,0x7f5c003a,0x00000000,0x00000000}},	//   vēli_, gorq, --, --, 
   {{0x61241d8d,0x03540a7c,0x0ca801f0,0x645c000d}},	//   _gólo, _ויגש_, итаи_, üsiv, 
   {{0x69c003d4,0x2544005f,0xf3880208,0xdce40064}},	//   _ålei, tēli_, _lợm_, _mikė, 
   {{0x61240077,0x7f5c003a,0xa91c0219,0xe1e801d9}},	// [1850] _móll, borq, _niža, _نى۪و_, 
   {{0x6f041d8e,0x9508031c,0x06dc00eb,0x00000000}},	//   _unhc, _ཀོའི_, _যোনি, --, 
   {{0x3f680798,0x00000000,0x00000000,0x00000000}},	//   _фиќо_, --, --, --, 
   {{0xec141d8f,0x67d4119e,0x3bd40139,0x00000000}},	//   _فوجد, зоду, bäq_, --, 
   {{0x3d081d90,0x65900055,0x38640042,0xf3880208}},	//   हारे_, _cāhn, _cymr_, _bợm_, 
   {{0xdce40064,0xa91c0171,0x00000000,0x00000000}},	//   _bikė, _diža, --, --, 
   {{0xd7f8151c,0x98a402f0,0x978000f2,0xf4a80092}},	//   _ғσя_, choď_, ریمه, _መቀመጥ_, 
   {{0x61240005,0x67d416c3,0x7f5c022e,0x00000000}},	//   _cóll, _нобу, zorq, --, 
   {{0x6124002e,0x7f5c0407,0xa4440116,0x29d4007c}},	//   _dóll, yorq, янид, låa_, 
   {{0x61241d91,0xdedc0023,0x0584014b,0x00000000}},	//   _pólo, ዕትን_, _дудм, --, 
   {{0x644c0953,0xaadc012a,0x238401d9,0x626400a8}},	//   _žaid, न्यक, _کٔتِ, явоа, 
   {{0x659000b0,0x63ac0327,0x612400e5,0xa4d400d4}},	//   _hāho, _ħanf, _góll, _ході, 
   {{0x65900325,0x7f5c1d92,0xd12c1d93,0xc2f00154}},	//   _kāho, torq, امُ_, জাবি_, 
   {{0x61240085,0x4ac41d94,0x606c001f,0x5398011a}},	//   _tólo, _लागव, _በንግድ_, _היסו, 
   {{0xc254040b,0x65900374,0x61241d95,0x7f5c0393}},	//   _بخشت, _māho, _hólm, rorq, 
   {{0x7f5c1d96,0x91b80375,0x00000000,0x00000000}},	//   sorq, _המקי, --, --, 
   {{0xc1d81d97,0x3b181d98,0x7f5c02d1,0x00000000}},	// [1860] _बहुग, _porq_, porq, --, 
   {{0x1cdc1b35,0x613400f3,0x7f5c0784,0xa91c0010}},	//   _རིམ_, ršlu, qorq, _riža, 
   {{0x659000b8,0x00000000,0x00000000,0x00000000}},	//   _sāhn, --, --, --, 
   {{0xa91c1d99,0x00000000,0x00000000,0x00000000}},	//   _piža, --, --, --, 
   {{0x612400e4,0x6ec404f2,0x4c801436,0x00000000}},	//   _róll, _عتیق, _плюв, --, 
   {{0x7bc40137,0x28d005f9,0x61241d9a,0xd39400fd}},	//   mriu, _हाथि, _sóll, җәдә_, 
   {{0x98a41d9b,0x61240436,0xc87c1432,0x18a41d9c}},	//   _ниве, _póll, ışan_, _навм, 
   {{0x7794036b,0x39b802e2,0x7bc4000d,0x00000000}},	//   _قیصا, mčs_, oriu, --, 
   {{0x39b80100,0x7bc40076,0xdb1400a2,0xdddc013a}},	//   lčs_, nriu, gryç, _vzpř, 
   {{0x96641d9d,0xdce402d5,0xa91c012c,0x7bc40024}},	//   _екзе, _tikė, _jižn, iriu, 
   {{0x612400e8,0x7bc41d9e,0x39b81d9f,0x0ed00d79}},	//   _tóll, hriu, nčs_, _ताबड, 
   {{0x7bc41da0,0x53b404a9,0xa91c01a6,0xf48401d5}},	//   kriu, _еғир_, _ližn, _قاشی, 
   {{0xb4e8007d,0x612402fb,0x69c008fb,0x7acc033f}},	//   मजी_, _gólm, _ålev, ालाअ, 
   {{0x7bc41da1,0xa91c1da2,0x00000000,0x00000000}},	//   driu, _nižn, --, --, 
   {{0x7bc41da3,0x39b8007f,0x00000000,0x00000000}},	//   eriu, jčs_, --, --, 
   {{0x7bc404cc,0x29d405ac,0x39b80100,0x00000000}},	//   friu, våa_, dčs_, --, 
   {{0x70541da4,0xc158025f,0x799c02d0,0x7bc41da5}},	// [1870] _زندا, _משהו_, _atrw, griu, 
   {{0x6590002b,0x29d40158,0x00000000,0x00000000}},	//   _bāhl, tåa_, --, --, 
   {{0x79a4074d,0x65901da6,0x799c035a,0x7bc41da7}},	//   ерче, _rāho, _ctrw, ariu, 
   {{0xba741da8,0x7bc41da9,0x29d40158,0x50bc00dc}},	//   رالت, briu, råa_, ्लिष, 
   {{0x7bc41daa,0x799c083a,0xc2f0045e,0x6d4c1dab}},	//   criu, _etrw, জাতি_, mnaa, 
   {{0x6d4c1dac,0x0f180490,0x6b9c002f,0xe3e80014}},	//   lnaa, _नकोस_, _itsg, ۪کان_, 
   {{0x25a808ad,0x6d4c1dad,0x6124032e,0x00000000}},	//   ćalo_, onaa, _sólm, --, 
   {{0x6d4c1dae,0x63bc0122,0x56900131,0x2fd80051}},	//   nnaa, ásno, наәт, ktsg_, 
   {{0x6d4c1daf,0xe3e8036b,0x644c0006,0x659002b1}},	//   inaa, تکان_, _žaib, _tāho, 
   {{0x6d4c0a4e,0x20f8004d,0x6aa41db0,0x63ac031c}},	//   hnaa, _ỏi_, nbhf, _ħand, 
   {{0x6d4c1db1,0x69c400a9,0xa3000032,0x6aa41db0}},	//   knaa, nrhe, еүҙе, ibhf, 
   {{0xe7d01db2,0x254400da,0x7bc40006,0x6d4c1db3}},	//   _समाप, tēlu_, yriu, jnaa, 
   {{0x6b9c1db4,0x69c40730,0x6d4c1db5,0x92bc0154}},	//   _ntsg, hrhe, dnaa, ুড়ে_, 
   {{0x65681db6,0xf1a81db7,0x7bc40357,0x6d4c1db8}},	//   lleh, _کاوه_, vriu, enaa, 
   {{0x4ac406ab,0xa91c110c,0x6d4c1db9,0xa3a8134e}},	//   _लाजव, _nižo, fnaa, गीर_, 
   {{0x6d4c1dba,0x69c41dbb,0x39b8033b,0xc0d80023}},	//   gnaa, drhe, včs_, ርቦም_, 
   {{0x8c401dbc,0x799c0368,0x5fd01dbd,0x63ac1dbe}},	// [1880] вете, _strw, _तमिल, _çand, 
   {{0x7bc41dbf,0x65681dc0,0x6d4c1dc1,0x39b80100}},	//   rriu, hleh, anaa, tčs_, 
   {{0x69c41dc2,0x6d4c1dc3,0x2d9400a7,0x65900055}},	//   grhe, bnaa, _пряс, _bāhm, 
   {{0x7bc41dc4,0x6d4c0014,0x61240174,0x5cc40014}},	//   priu, cnaa, _sólj, _کتھِ, 
   {{0x66001dc5,0x69c41dc6,0x65681dc7,0xaab81dc8}},	//   _arlk, arhe, dleh, زدەر_, 
   {{0x61240579,0xc3200729,0x7c241dc9,0x656801e0}},	//   _bólk, যোতি_, myir, eleh, 
   {{0x65680086,0x69c403cb,0x799c012d,0xb81c03d4}},	//   fleh, crhe, _utrw, _দেশত_, 
   {{0x6ba4049f,0xdb0400cc,0x65681dca,0xf388004d}},	//   _åtgä, _avkø, gleh, _hợi_, 
   {{0x7c241dcb,0xa3a80490,0x6600002f,0xb9cc1954}},	//   nyir, गील_, _erlk, _ሲሶ_, 
   {{0x612419cf,0x656806a3,0xc7a0013d,0x00000000}},	//   _fólk, aleh, _рифк, --, 
   {{0x7c241dcc,0x6d4c1dcd,0x65681dce,0x77f81682}},	//   hyir, ynaa, bleh, ṱaḓ, 
   {{0xf38807ae,0x7c240134,0x14241dcf,0x6d4c1dd0}},	//   _lợi_, kyir, _одем, xnaa, 
   {{0x28d01dd1,0x7c240223,0x61ec0e04,0x03140133}},	//   _हासि, jyir, _ćale, ستیت_, 
   {{0x7c24006f,0x6d4c1dd2,0x69c40142,0x00000000}},	//   dyir, wnaa, yrhe, --, 
   {{0x6d4c1dd3,0x9f50007f,0xae4403c7,0x6aac00fe}},	//   tnaa, _msyè_, رپرو, _চালো, 
   {{0x6d4c1dd4,0xa91c1dd5,0x69c40118,0x42c401af}},	//   unaa, _rižo, vrhe, _егән_, 
   {{0x6d4c1dd6,0x4ea41dd7,0xc0d80023,0xdb241dd8}},	// [1890] rnaa, _орна, ርኦም_, کولی, 
   {{0x6d4c1dd9,0xdb140699,0x69c41dda,0x0a680022}},	//   snaa, nsyè, trhe, ореи_, 
   {{0x6d4c1ddb,0x7054036b,0x6568058a,0x7c241418}},	//   pnaa, _زنگا, yleh, ayir, 
   {{0x69c41ddc,0x7c241ddd,0x6b9c02fa,0x6d4c0014}},	//   rrhe, byir, _ttsg, qnaa, 
   {{0x066404a2,0x7c841dde,0x7c240796,0xdc440374}},	//   ﺴﯩﻨﯩ, _ауре, cyir, _tūār, 
   {{0x65680649,0x7a8400db,0x96d8134e,0x00000000}},	//   wleh, رشەم, प्लॉ, --, 
   {{0x65681ddf,0xf3880016,0xd5ac0a81,0x966000d8}},	//   tleh, _gợi_, مہٕ_, лкше, 
   {{0xa5641de0,0x96640023,0x00000000,0x00000000}},	//   رگان, _ምንጽጻ, --, --, 
   {{0x13e41de1,0xa3a80b7d,0xc7640075,0xa3c00dad}},	//   емый_, गीं_, _قائى, ौंध_, 
   {{0x69c003a1,0x65681de2,0x254400e2,0x00000000}},	//   _åles, sleh, tēls_, --, 
   {{0x21681de3,0x6e2005ac,0x660000d7,0x25a80066}},	//   зини_, ølbl, _urlk, _رضای_, 
   {{0x7c240548,0x61241de4,0xdce4002b,0x00000000}},	//   yyir, _kóli, _vikī, --, 
   {{0x44241de5,0x612409f3,0xf3f41de6,0x00000000}},	//   _تراف, _jóli, _аңы_, --, 
   {{0x7c241446,0xd1b80092,0x00000000,0x00000000}},	//   vyir, ዳለች_, --, --, 
   {{0xdd901de7,0x61441de8,0x3fd002f5,0x3d28015e}},	//   اور_, _пека, িবেষ, وتری_, 
   {{0x7c240433,0xaadc012c,0x00000000,0x00000000}},	//   tyir, न्सक, --, --, 
   {{0xf388001e,0x9b880f84,0x7c240337,0xdb5001f7}},	// [18a0] _sợi_, سنال_, uyir, هَر_, 
   {{0x38e8031c,0xa91c00ef,0x7c240022,0x612401a8}},	//   _ལིངྒ, _dižm, ryir, _sólh, 
   {{0x7c241de9,0xdddc0034,0xda640338,0x28d00456}},	//   syir, _wypł, راطي, _हाशि, 
   {{0x61241dea,0x59d0073d,0xd7f81deb,0x830c031c}},	//   _bóli, दंबर, зук_, _ཏོའུ_, 
   {{0xa7fc01ed,0x61241dec,0xe84801f7,0x7b8401ec}},	//   _szűr, _cóli, وجهن_, _ағад, 
   {{0x07a00640,0x2ba8012d,0x00000000,0x00000000}},	//   ћајн, _चौटा, --, --, 
   {{0x61241ded,0x60d4003a,0x00000000,0x00000000}},	//   _eóli, _ocym, --, --, 
   {{0x61241dee,0x2610000d,0x00000000,0x00000000}},	//   _fóli, _थपरी_, --, --, 
   {{0xe9700075,0x84940597,0x53441def,0x00000000}},	//   _ئۇند, رئيس_, ехна, --, 
   {{0xa91c0fb7,0x60d402d0,0x2d84004e,0xf5240327}},	//   _nižj, _acym, ílez_, ལིངྒ_, 
   {{0x53c01df0,0xa2a000bc,0x46a0014b,0x00000000}},	//   _शिवश, _गभर्, _сахв, --, 
   {{0xa5c00598,0xb7f41df1,0x629405c7,0x50640f89}},	//   _төше, _इनाम_, ñzor, етга, 
   {{0x06641df2,0x6d401df3,0xdb14007f,0xd614009f}},	//   ﺴﯩﻠﯩ, èlam, psyè, _آڪڙا_, 
   {{0x8460001f,0x4ea41df4,0x00000000,0x00000000}},	//   _ስትሆን_, эрма, --, --, 
   {{0x28d00d0d,0x7dc401a9,0x00000000,0x00000000}},	//   _हालि, лётд, --, --, 
   {{0xe7f00490,0xa91c02f0,0x0ed006e3,0x00000000}},	//   _आईला_, _pižm, _तावड, --, 
   {{0x50641df5,0xd24c00f1,0x8f08010a,0x00000000}},	// [18b0] _ятка, _خنډ_, _ехна_, --, 
   {{0xa91c0427,0x61240174,0x6e94072d,0x00000000}},	//   _vižm, _róli, _جلدا, --, 
   {{0xa7fc00dd,0x2a8401f0,0x00000000,0x00000000}},	//   _gyűj, тъаҳ, --, --, 
   {{0x61240008,0x61e40295,0xac941df6,0x00000000}},	//   _póli, _ähle, _шамш, --, 
   {{0x2ca81df7,0x00000000,0x00000000,0x00000000}},	//   mbad_, --, --, --, 
   {{0x2ca81df8,0x20d800a2,0x3834035b,0xaa58009b}},	//   lbad_, _išiō_, ынчр, _жигу_, 
   {{0x659002b1,0x36940220,0x569007b5,0xf6641df9}},	//   _kāhi, ушіс, шајт, лешү, 
   {{0x2ca81dfa,0x61240d12,0x00000000,0x00000000}},	//   nbad_, _tóli, --, --, 
   {{0x290c1dfb,0x65901dfc,0x44281dfd,0x2ca81dfe}},	//   _inea_, _māhi, ác_, ibad_, 
   {{0x2ca80a06,0x60d40142,0x066400cf,0x00000000}},	//   hbad_, _scym, _كااپ, --, 
   {{0xa0a41dff,0x290c05ac,0xfdcc015b,0x2ca81e00}},	//   канд, _knea_, _লন্ড, kbad_, 
   {{0x65901d86,0xdb14020c,0x00000000,0x00000000}},	//   _nāhi, rsyé, --, --, 
   {{0x290c0270,0x2ca81e01,0xc444006c,0xe3540304}},	//   _mnea_, dbad_, _سیدن_, _иткэ, 
   {{0x545004a9,0x0bc800d1,0x2ca8002f,0x224800cd}},	//   _әвәт, _ﺗﻪﻫﺮ, ebad_, _śaku_, 
   {{0x290c0270,0xbcf001e4,0x2ca80112,0xdcfc0055}},	//   _onea_, koɩt, fbad_, _utpī, 
   {{0xf28800c8,0x2ca801a4,0x65900055,0xa91c0171}},	//   _אָפֿ, gbad_, _cāhi, _dižk, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [18c0] --, --, --, --, 
   {{0x290c150c,0x2ca81e02,0x00000000,0x00000000}},	//   _anea_, abad_, --, --, 
   {{0x3eb81e03,0x2ca81e04,0xabc400fb,0x59740022}},	//   mart_, bbad_, _ҙарҙ, ҭыҵу, 
   {{0x3eb81e05,0x2ca801ab,0xf3880208,0x5824004e}},	//   lart_, cbad_, _hợt_, кмеб, 
   {{0x6c7405f5,0x0d2000f7,0x569002dd,0x00000000}},	//   _бурх, _түтү, қақт, --, 
   {{0x3eb81e06,0x290c0d43,0x612406ea,0x3cf801f9}},	//   nart_, _enea_, _gólv, _उघडे_, 
   {{0x7afc1e07,0x63ac031c,0x612408a5,0x588400c7}},	//   _iart, _ħana, _hólu, хыҧа, 
   {{0x7afc1e08,0x3eb80876,0xdb140113,0xf3f81e09}},	//   _hart, hart_, muyñ, ениш_, 
   {{0x3eb800c0,0x17841e0a,0x6124148b,0x2c0400dc}},	//   kart_, _агам, _jólu, रियं_, 
   {{0x7afc05f5,0x00000000,0x00000000,0x00000000}},	//   _jart, --, --, --, 
   {{0x3eb80493,0x2ca80067,0x6d400066,0x00000000}},	//   dart_, ybad_, èlak, --, 
   {{0x7afc0240,0xd3c4010b,0x25a00419,0x00000000}},	//   _lart, _айдй, íhle_, --, 
   {{0x4fc40801,0x65900374,0x7afc1e0b,0xdedc0023}},	//   ъсна, _rāhi, _oart, ንስኡ_, 
   {{0x0cc80bb2,0x63ac1e0c,0xdb140113,0xf3880208}},	//   िल्म, _çana, kuyñ, _cợt_, 
   {{0x65901e0d,0x2ca801a4,0x39440109,0xabdc01ec}},	//   _pāhi, tbad_, _omms_, _ﺇﻴﻘﺎ, 
   {{0xad241e0e,0x61240321,0xac18004e,0x2ca80037}},	//   دىرى, _bólu, нобу_, ubad_, 
   {{0x7afc1e0f,0x3eb81e10,0x2ca81e11,0x25a80989}},	// [18d0] _bart, bart_, rbad_, ćali_, 
   {{0x3eb81e12,0x7afc1e13,0x65900053,0x2ca80e89}},	//   cart_, _cart, _wāhi, sbad_, 
   {{0x61241e14,0x659002b1,0xfb8412c4,0x7afc1e15}},	//   _vólv, _tāhi, рытн, _dart, 
   {{0x7afc1e16,0xe8580e67,0x612402d2,0xe5a40131}},	//   _eart, наеш_, _fólu, ңили, 
   {{0x1cdc0003,0x61240162,0xa7e4129d,0xdd3800df}},	//   _ལྡི_, _tólv, اكتى, _נעשכ, 
   {{0xd1d402d3,0xd7ec1456,0x00000000,0x00000000}},	//   ካእታ_, سكى_, --, --, 
   {{0x3a8402d5,0x3d080073,0xa91c01ef,0xe6d8032e}},	//   _вытв, हाचे_, _liži, _áríð, 
   {{0x3eb818a6,0x7afc1e17,0x3944031c,0x290c01c6}},	//   zart_, _zart, _gmms_, _unea_, 
   {{0xa8541e18,0x7afc1e19,0x0ed006ab,0xe3b000c6}},	//   _скач, _yart, _तांड, حرب_, 
   {{0x31681e1a,0x788000bc,0xd7e800db,0xc5e800cc}},	//   _akaz_, _dívč, _سومۇ_, কিবা_, 
   {{0x3eb81e1b,0x6ab41e1c,0xa5200209,0xe4d40b73}},	//   vart_, _mezf, _гүйҗ, _مقاد, 
   {{0xf1a804d3,0x672001a6,0x6ab40165,0x6590002b}},	//   کایه_, _holj, _lezf, _bāhv, 
   {{0xa2e41e1d,0x67201e1e,0xd24c01b9,0x00000000}},	//   _болд, _kolj, قنی_, --, 
   {{0x6ff4025c,0x612401ed,0x62040050,0xabdc0150}},	//   _བརྫུ_, _rólu, _موتٕ, _ﺇﺴﻘﺎ, 
   {{0xe4f80782,0x61241e1f,0xf388001e,0x3eb80112}},	//   ्यपि_, _bólt, _vợt_, rart_, 
   {{0x7afc1e20,0x5c141c65,0x3eb81e21,0xdce40055}},	//   _sart, льзу, sart_, _vikį, 
   {{0x3eb81e22,0x6ab40419,0x00000000,0x00000000}},	// [18e0] part_, _bezf, --, --, 
   {{0x7afc1e23,0x3eb8013c,0x4c800890,0xaac41e24}},	//   _qart, qart_, слув, لتمن, 
   {{0x7afc1e25,0x9d441e26,0x65901e27,0x18a41e28}},	//   _vart, _бенд, _kāhu, гаем, 
   {{0x7afc1e29,0x61241427,0x00000000,0x00000000}},	//   _wart, _tólu, --, --, 
   {{0x7afc1e2a,0x65901e2b,0x23641505,0x1cdc025c}},	//   _tart, _māhu, kolj_, _ལྡག_, 
   {{0x6590166a,0x7afc0c8c,0x9f4c02e2,0x6e340ca8}},	//   _lāhu, _uart, ènèl_, _àgbè, 
   {{0x6720041a,0xd5641e2c,0x39440139,0x95c8074d}},	//   _dolj, лтип, _tmms_, хула_, 
   {{0x18681e2d,0x39440162,0x659000b8,0x00000000}},	//   _заби_, _umms_, _nāhu, --, 
   {{0x67201e2e,0x6d400607,0x74541e2f,0xd6780116}},	//   _folj, ūlag, جھائ, ﻤﯩﻼﺭ_, 
   {{0xa3b410f7,0x67201e30,0x23641e31,0xa91c0301}},	//   _जबर_, _golj, golj_, _riži, 
   {{0x6124022c,0x6590002b,0x4d7c0046,0x00000000}},	//   _nóls, _bāhu, _ﺣﺎﯞﯨ, --, 
   {{0x672005be,0x6590002b,0xe1c40073,0xa91c00ef}},	//   _zolj, _cāhu, _विरघ, _piži, 
   {{0x5edc015b,0xc0581e32,0x23641a48,0x0440030d}},	//   য়নে, гір_, bolj_, _лецн, 
   {{0x7f941e33,0x61241427,0x6720025c,0x25bc0139}},	//   сарх, _sólt, _xolj, _äylä_, 
   {{0x1cdc0135,0x3134010b,0xdddc013a,0xc20c01af}},	//   _ལྡང_, _вейр, _kypř, _ує_, 
   {{0x31681e34,0xa12401d9,0x61e40139,0x0c841e35}},	//   _ukaz_, _نوى۪, _ähla, гызм, 
   {{0x8aa40edb,0x70580131,0xfbd001d9,0x3d940150}},	// [18f0] гред, _шаир_, ۪تہ_, _қияр, 
   {{0x612408a5,0x00000000,0x00000000,0x00000000}},	//   _fóls, --, --, --, 
   {{0x6720000f,0x296400f1,0x00000000,0x00000000}},	//   _rolj, لیسۍ_, --, --, 
   {{0x67201e36,0x27380036,0xf7840014,0xcc840133}},	//   _solj, _kèng_, ۅلنَ, _مۆزه_, 
   {{0xc7c40022,0x9cd4011a,0x00f8010f,0x00000000}},	//   усеи, _דורה_, טזאם_, --, 
   {{0x27380036,0x637c020c,0x28d01b97,0x59d00118}},	//   _mèng_, mèng, _हाकि, दूहर, 
   {{0x23640fb7,0x61ec0cf4,0xf0440092,0x00000000}},	//   volj_, _ćalo, _የኦሊም, --, 
   {{0xa5241e37,0xf60802f2,0xdddc01ef,0x64a400f0}},	//   рмид, اتوه_, _cypř, јапа, 
   {{0xc0ec1e38,0x65900b3a,0x2738034c,0x888006ce}},	//   _ቅዳሴ_, _rāhu, _nèng_, _ایشن, 
   {{0x36d40d1d,0x24a40014,0x48ec00bc,0xdb0c03e0}},	//   _гофр, دٕکِ, ीएको_, şköp, 
   {{0xf7701e39,0x659002b1,0x26c401e4,0x27ec01c7}},	//   _راك_, _pāhu, _idlo_, _hpen_, 
   {{0x3e7c01e1,0x00000000,0x00000000,0x00000000}},	//   _látí_, --, --, --, 
   {{0x27380066,0x68e81e3a,0x612405f7,0xa0740220}},	//   _cèng_, _mbed, _sóls, рынш, 
   {{0x27380036,0x6124148b,0x765806be,0x00000000}},	//   _dèng_, _póls, _çayç, --, 
   {{0xa0a41e3b,0x63a81e3c,0x65900053,0x68e81e3d}},	//   _кайд, lpen, _tāhu, _obed, 
   {{0xf38801dc,0x63a81e3e,0x27ec1e3f,0x68e80327}},	//   _hợp_, open, _open_, _nbed, 
   {{0x4d6002bf,0x5bc40372,0x00000000,0x00000000}},	// [1900] ікув, شقال, --, --, 
   {{0x63a81e40,0xed580107,0x61e00200,0x00000000}},	//   ipen, воӣ_, otll, --, 
   {{0x27ec1e41,0x61e01e42,0xeb740006,0x13f0000d}},	//   _apen_, ntll, сытэ, _अन्ह_, 
   {{0x57a41e43,0x760001ed,0x26c41e44,0x637c04fb}},	//   ашка, házá, _adlo_, lènd, 
   {{0x76001e45,0x63a80196,0x25a400db,0x2738004d}},	//   kázá, jpen, _atll_, _xèng_, 
   {{0x68e81e46,0x73d801d5,0xe7b000db,0x00000000}},	//   _ebed, ҳдир_, سۅمد, --, 
   {{0x291c01ee,0x00000000,0x00000000,0x00000000}},	//   bjwa_, --, --, --, 
   {{0xa91c0c53,0x68e80241,0x25a000d0,0x73d801d5}},	//   _bižu, _gbed, íhla_, гдир_, 
   {{0x27e81e47,0x63a81e48,0x07a0136b,0xc7a00c56}},	//   çant_, gpen, _матн, _митк, 
   {{0x2738020c,0x00000000,0x00000000,0x00000000}},	//   _rèng_, --, --, --, 
   {{0x63a80036,0xe6d802d2,0xe5c800f2,0x00000000}},	//   apen, _áráð, _مظنه_, --, 
   {{0x94841e49,0x61240321,0x637c020c,0x73341e4a}},	//   _кылд, _sólr, yèng, _گىتا, 
   {{0xb4c4060c,0x637c00db,0x3ccc00fe,0x93241e4b}},	//   ौली_, fènd, াভাৱ, _پرشن, 
   {{0x73340075,0x637c1e4c,0x00000000,0x00000000}},	//   _دىتا, gènd, --, --, 
   {{0xb63804ce,0x637c020c,0xd13801af,0x00000000}},	//   _ｄｌ_, wèng, _ахп_, --, 
   {{0x637c020c,0xdedc0023,0x61340153,0x00000000}},	//   tèng, ንትኻ_, kšly, --, 
   {{0xe4f80a28,0x7bc0003a,0x00000000,0x00000000}},	// [1910] ्यति_, _æmul, --, --, 
   {{0x8aa41e4d,0x637c0214,0xf0040107,0x7b140305}},	//   ррад, rèng, _кӯҳи, одух, 
   {{0xc9840965,0x63a805f5,0x27ec0204,0x291c1e4e}},	//   ауди, zpen, _spen_, tjwa_, 
   {{0x27381e4f,0x637c1e50,0xe6181e51,0x68e80165}},	//   _mène_, mène, ғди_, _qbed, 
   {{0x63a81e52,0x6d4c1e53,0x291c02c4,0x637c1e54}},	//   xpen, miaa, rjwa_, lène, 
   {{0x22000309,0x6aa805d1,0x00000000,0x00000000}},	//   nçhá_, _şeff, --, --, 
   {{0x291c00fb,0x76000118,0xf3880208,0xda6c00ec}},	//   pjwa_, vázá, _rợp_, _ٻڏل_, 
   {{0x6d4c0eda,0x68e80640,0x34f00131,0xe1f80022}},	//   niaa, _ubed, җҗәт, ҳго_, 
   {{0x63a81e55,0x6d4c0418,0x637c004a,0x5edc009e}},	//   upen, iiaa, hène, য়তে, 
   {{0x63a81e56,0x6d4c00c5,0xe1f8004e,0xe2c81e57}},	//   rpen, hiaa, гго_, دودو_, 
   {{0x63a81e58,0x22481d39,0x27380129,0xd00401e0}},	//   spen, упни_, _cène_, ҙере_, 
   {{0x61e0004e,0x6d4c0108,0x00000000,0x00000000}},	//   rtll, jiaa, --, --, 
   {{0x65680093,0x02c00166,0xd494011a,0x84640395}},	//   moeh, _дилү, _הכנת_, _тъже, 
   {{0x2cb80165,0x65681e59,0xe2c81e5a,0xdee40114}},	//   _aesd_, loeh, _صوبو_, љови, 
   {{0x443c1e5b,0x9d54182f,0x637c1e5c,0x6d4c1e5d}},	//   lzu_, منست, rènd, fiaa, 
   {{0x6d4c1e5e,0xe0d815ed,0x443c1e5f,0xe6d80d12}},	//   giaa, _сви_, ozu_, _áræð, 
   {{0x443c1e60,0x28d01e61,0x2cb80789,0xdd10025c}},	// [1920] nzu_, _हाजि, _desd_, _iżżu, 
   {{0x65681e62,0x443c009d,0x5a9401f0,0x6c5400d4}},	//   hoeh, izu_, сраф, іттє, 
   {{0x656801ee,0x637c0129,0x6d400309,0xb7ec0154}},	//   koeh, cène, ëlac, ওয়াত_, 
   {{0x6d4c0936,0xdef800c7,0x00000000,0x00000000}},	//   ciaa, _рыҩ_, --, --, 
   {{0x7d041e63,0xdb0801e7,0x00000000,0x00000000}},	//   mdis, ánói, --, --, 
   {{0x7d041e64,0x443c1e65,0xdb0c0241,0xdcfc00ef}},	//   ldis, dzu_, _àjàm, _tupē, 
   {{0x7d041e66,0x98a41e28,0xbda40023,0xd5e80451}},	//   odis, _гибе, ዋህቦም_, اعتن_, 
   {{0x74140f1b,0x65680327,0xa91c0171,0xe7f001f9}},	//   قوبا, goeh, _dižs, _आईचा_, 
   {{0x7d041e67,0x1cdc0135,0x2738007f,0x00000000}},	//   idis, _ལྡབ_, _sène_, --, 
   {{0x7d04049b,0x2738067c,0x612408ce,0xdb100139}},	//   hdis, _pène_, _sólp, _ügär, 
   {{0x443c1e68,0x6568020c,0xaadc00bc,0xfd5800b8}},	//   azu_, boeh, न्टक, bhaḥ, 
   {{0x637c1e69,0x7d041e6a,0x25b40014,0x225000d0}},	//   vène, jdis, _بۆٹھ_, úzka_, 
   {{0x50641e6b,0x7d041e6c,0x6d4c1e6d,0x850004d3}},	//   стна, ddis, viaa, _روون, 
   {{0x7d040548,0x27381e6e,0x32380023,0x637c1e6f}},	//   edis, _tène_, _ብጉልባ, tène, 
   {{0x6d4c1e70,0x8d741e71,0xb80002f5,0x7980035a}},	//   tiaa, مارا, ্হিত_, _ohmw, 
   {{0x7d041e72,0x637c06af,0x00000000,0x00000000}},	//   gdis, rène, --, --, 
   {{0x6d4c1e73,0x00000000,0x00000000,0x00000000}},	// [1930] riaa, --, --, --, 
   {{0x6d4c1e74,0x7d041e75,0xfb841e76,0x798002d0}},	//   siaa, adis, пыхн, _ahmw, 
   {{0x443c1e77,0x637c0228,0xac941e78,0x7d041e79}},	//   zzu_, lènc, _манш, bdis, 
   {{0x443c1e7a,0x6d4c0140,0x7d0401e4,0x00000000}},	//   yzu_, qiaa, cdis, --, 
   {{0x637c1e7b,0xe4f80882,0xf9901e7c,0xf4ac0150}},	//   nènc, ्यसि_, ربم_, _ﺴﺘﺸﻜ, 
   {{0x443c1e7d,0x65681e7e,0xd5ac0014,0x16a400d4}},	//   vzu_, woeh, چہٕ_, овши_, 
   {{0xf7700502,0x65681e7f,0xd5ac0d62,0x00000000}},	//   راه_, toeh, نہٕ_, --, 
   {{0x443c05f5,0x63ac05d1,0x67d400cf,0xe57800f0}},	//   tzu_, _çank, _мобу, јзи_, 
   {{0x443c04ce,0xa4440075,0x51a002dd,0x00000000}},	//   uzu_, юнид, _ﺍﻟﺨﻁ_, --, 
   {{0xa1c41e80,0x1cdc1e81,0x637c0228,0x7d04036e}},	//   обод, _ལྡན_, dènc, zdis, 
   {{0x443c0034,0xa7fc01ed,0xb5940124,0x7d041e82}},	//   szu_, _gyűr, _еихш, ydis, 
   {{0x21681e83,0x20881e84,0xe3b0009f,0x798002d0}},	//   рими_, ийни_, _قرت_, _xhmw, 
   {{0x637c00f7,0x7d041e85,0x8ee00154,0x00000000}},	//   gènc, vdis, য়নগ, --, 
   {{0x6d5c0227,0x7d041e86,0xfe781e87,0x1798011a}},	//   _ajsa, wdis, йүп_, יישב, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2fcc1e88,0x7d041e89,0x637c020c,0x3ba40022}},	//   šega_, udis, bènc, злаҳ, 
   {{0x637c0228,0x6e20022c,0x6d40017a,0x00000000}},	// [1940] cènc, ølbr, ëlaa, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7d040334,0x09e0023a,0x00000000,0x00000000}},	//   pdis, дохн, --, --, 
   {{0x7d040d62,0x1d081e8a,0x00000000,0x00000000}},	//   qdis, _теми_, --, --, 
   {{0x386000ac,0x6aa806be,0x09e400eb,0x00000000}},	//   çir_, _şefe, ফিগা, --, 
   {{0xcb24004b,0xd7780023,0x3860003d,0x7bc400c0}},	//   _وړلو_, _ፖሊቲካ_, ħir_, msiu, 
   {{0x98a400ee,0xae0c0406,0xc68c009f,0x00000000}},	//   _миве, हियन_, نِه_, --, 
   {{0x38c800aa,0x7bc40006,0x1c0c0acd,0x7388010b}},	//   _داسی_, osiu, सिपल_, әриң_, 
   {{0x7bc41e8b,0x74140597,0x799c1e8c,0x9f4000f2}},	//   nsiu, سودا, _hurw, atké_, 
   {{0x799c1e8d,0x637c00f7,0xa3280113,0x128802e8}},	//   _kurw, vènc, _p葵ac, ищни_, 
   {{0x799c1e8e,0xd258010b,0x4b78010f,0x00000000}},	//   _jurw, рцп_, שטיג, --, 
   {{0x09cc03f4,0x799c1e8f,0x7bc41e90,0x637c0228}},	//   _রহমা, _murw, ksiu, tènc, 
   {{0x7bc40007,0x6e94024c,0x00000000,0x00000000}},	//   jsiu, зигу, --, --, 
   {{0x637c0372,0x799c14dc,0x00000000,0x00000000}},	//   rènc, _ourw, --, --, 
   {{0x637c0228,0x799c1e91,0xf4cc015b,0x63ac031c}},	//   sènc, _nurw, লভীব, _ħani, 
   {{0x13dc00cc,0x00000000,0x00000000,0x00000000}},	//   _বৈয়, --, --, --, 
   {{0x7bc41e92,0x799c02d0,0x637c1e93,0x00000000}},	// [1950] gsiu, _aurw, lèna, --, 
   {{0x799c1e94,0x7ff41e95,0x9f4000d7,0x00000000}},	//   _burw, _آسيا, ytké_, --, 
   {{0x7bc41e96,0x799c0042,0x637c020c,0xb17c01e4}},	//   asiu, _curw, nèna, ntĥo, 
   {{0x799c1e97,0xc9841e98,0x00000000,0x00000000}},	//   _durw, цузи, --, --, 
   {{0x2d881730,0xd90c01ed,0x5edc015b,0x6f040175}},	//   mmae_, ھیے_, য়রে, _kahc, 
   {{0x799c1e99,0x2738007f,0x637c020c,0x2d880381}},	//   _furw, _bèna_, kèna, lmae_, 
   {{0x6b9c1e9a,0x799c1e9b,0x6f04047e,0x637c020c}},	//   _husg, _gurw, _mahc, jèna, 
   {{0x69c41e9c,0x6aa41e9d,0x6b9c1e9e,0xe3b81e9f}},	//   mshe, lchf, _kusg, бби_, 
   {{0x69c40731,0x1c0c05d7,0xc6e4109a,0x6b941ea0}},	//   lshe, सियल_, _міжп, _kizg, 
   {{0x6b9c1ea1,0x46681ea2,0x799c0223,0x69c41ea3}},	//   _musg, _крем_, _yurw, oshe, 
   {{0x69c41ea4,0x6b941ea5,0x637c1ea6,0x6aa41ea7}},	//   nshe, _mizg, gèna, ichf, 
   {{0x293400df,0x00000000,0x00000000,0x00000000}},	//   פאָן_, --, --, --, 
   {{0x6f041ea8,0x2ee001ee,0x6b9c0209,0x69c41ea9}},	//   _bahc, _bchf_, _nusg, hshe, 
   {{0x637c00f2,0xdd90004b,0x53980375,0x6d400af9}},	//   bèna, ځوس_, _פיצו, ëlan, 
   {{0x6b9c1eaa,0x69c41eab,0x637c067c,0x6f040009}},	//   _ausg, jshe, cèna, _dahc, 
   {{0xf1a8168d,0x6b9c026c,0x7bc41eac,0x6b94005f}},	//   _باوه_, _busg, tsiu, _aizg, 
   {{0xd00c1ead,0x69c41eae,0x5ac81eaf,0x6b941eb0}},	// [1960] _ملي_, eshe, йлам_, _bizg, 
   {{0x7bc41eb1,0x799c1eb2,0x6b941eb3,0x6b9c01c3}},	//   rsiu, _purw, _cizg, _dusg, 
   {{0x7bc41eb4,0xdca41768,0x799c0784,0x6b9c005a}},	//   ssiu, _нани, _qurw, _eusg, 
   {{0x68f80649,0x6aa4000f,0x59d000e1,0x7bc41eb5}},	//   gewd, achf, दूगर, psiu, 
   {{0x69c41eb6,0x6b9c1eb7,0x6b9403f9,0x799c1594}},	//   ashe, _gusg, _fizg, _wurw, 
   {{0x799c0230,0x69c40009,0x473002bf,0xd5b81eb8}},	//   _turw, bshe, нніс, бси_, 
   {{0x799c1eb9,0x69c41eba,0xbacc01ec,0x00000000}},	//   _uurw, cshe, _ﻗﯘﺷﺎ, --, 
   {{0x34941ebb,0x6b94022e,0x637c02e2,0x18a4074d}},	//   майр, _zizg, vèna, _хаам, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x637c0699,0x88380302,0xe72800aa,0xdcfc0064}},	//   tèna, _התמו, _وسلو_, _tupė, 
   {{0xb9e407db,0x2d88003a,0xcb10011a,0x25700228}},	//   _ከኣ_, ymae_, גלת_, رۇۇس, 
   {{0x2738007f,0x8678008f,0x6f04047e,0xd1381ebc}},	//   _jènn_, _פראו, _sahc, схо_, 
   {{0xcfa411ed,0x6f04014f,0x637c020c,0x6aa40042}},	//   яшни, _pahc, sèna, ychf, 
   {{0x2fcc1ebd,0x69c41ebe,0x6b9c00a3,0x637c07c2}},	//   šego_, yshe, _rusg, pèna, 
   {{0x6b9c0421,0x6f040007,0x6b940240,0x69c40067}},	//   _susg, _vahc, _rizg, xshe, 
   {{0x6b9407d6,0x6b9c1ebf,0x69c4005c,0x6aa40142}},	//   _sizg, _pusg, vshe, wchf, 
   {{0xfe7000dd,0x2d881ec0,0x69c41ec1,0x8138005e}},	// [1970] ندہ_, rmae_, wshe, _ءسىز_, 
   {{0x69c41ec2,0x6b9401b9,0x2d88003a,0x00000000}},	//   tshe, _qizg, smae_, --, 
   {{0x6aa41ec3,0xac980220,0xdb241ec4,0x69c40ba7}},	//   rchf, _وندا_, بولی, ushe, 
   {{0x69c41ec5,0x6aa41ec6,0xe8541ec7,0x66000334}},	//   rshe, schf, وناد, _rslk, 
   {{0x68f81ec8,0x69c41ec9,0xfc6400a7,0x6b941eca}},	//   rewd, sshe, _зърн, _tizg, 
   {{0x69c41ecb,0x76c400d1,0x00000000,0x00000000}},	//   pshe, ىغىل, --, --, 
   {{0xb4e8000d,0x76c4036b,0x69c40003,0x00000000}},	//   यभू_, رغول, qshe, --, 
   {{0x61e40209,0xbe3c0375,0xa4f80073,0x44a000db}},	//   _ähli, מעות, ्येच_, رۅتق, 
   {{0xd85400db,0x00000000,0x00000000,0x00000000}},	//   _жетө, --, --, --, 
   {{0x45a008c9,0x644c02d5,0xdedc1b49,0xd34403e6}},	//   _كەتك, _žais, ንትን_, وینه_, 
   {{0x77640137,0x63ac0135,0xa51c0153,0x00000000}},	//   éixe, _ħanu, _вялi, --, 
   {{0x637c0ba1,0x00000000,0x00000000,0x00000000}},	//   cènn, --, --, --, 
   {{0xa2e40dd8,0x00000000,0x00000000,0x00000000}},	//   _жолд, --, --, --, 
   {{0xb37c02d3,0x33940108,0xdddc00de,0xb38400c0}},	//   _ብብዙሕ_, _зачё, _uzpū, _зліл, 
   {{0x1b0400bd,0x1d080261,0x2fc81ecc,0x81b40011}},	//   রামে_, оеви_, _evag_, _চমক_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9b040aa5,0xc0ec001f,0x27380100,0x1f640b01}},	// [1980] мзад, _ቅዳሜ_, _rènn_, _оким, 
   {{0x2738007f,0x4c8006ed,0x98a003e0,0x5ac8003b}},	//   _sènn_, тлув, _ıkı_, ілем_, 
   {{0x63500118,0x9d441ecd,0x5d6800d8,0x00000000}},	//   měně, _женд, _миом_, --, 
   {{0x312000dc,0x00000000,0x00000000,0x00000000}},	//   यायः_, --, --, --, 
   {{0xc7a00314,0x07a01ece,0x00000000,0x00000000}},	//   вичк, вачн, --, --, 
   {{0xf1c00030,0x3ce01ecf,0x764400c7,0x00000000}},	//   úšky_, lgiv_, нҭза, --, 
   {{0x8a000faa,0xda700050,0x312000dc,0xdedc001f}},	//   _изре, _شُر_, यामः_, ንስና_, 
   {{0x3ce01ed0,0x00000000,0x00000000,0x00000000}},	//   ngiv_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2e4400e8,0x00000000,0x00000000,0x00000000}},	//   _jëfé_, --, --, --, 
   {{0x2fc81ed1,0x333c0332,0xcad4011a,0x850005af}},	//   _svag_, _vlvx_, ווית_, روین, 
   {{0x92bc03f4,0x91481ed2,0xae0c00af,0x00000000}},	//   ইলে_, ічна_, हिसन_, --, 
   {{0xf6ec031c,0x54340832,0xffe40229,0x72d401af}},	//   _ལྡོང, _ترار, кюрн, _золф, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2010058a,0x7f941ed3,0x9f5000e5,0x00000000}},	//   _eryi_, тарх, óbát_, --, 
   {{0x2fc8002b,0x25a000d7,0x00000000,0x00000000}},	//   _tvag_, íhli_, --, --, 
   {{0x63ac1ed4,0xc0dc0020,0x506401a9,0xcfa802f2}},	// [1990] _çant, ንንም_, _ютка, _بابم_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd3641af6,0x8cc800af,0x00000000,0x00000000}},	//   _ڕه_, तृशो, --, --, 
   {{0x2d981ed5,0x2ca81ed6,0x9cd400d9,0x00000000}},	//   _iise_, mcad_, _אורה_, --, 
   {{0x6d9001a2,0x2ca80014,0xd7041ed7,0x2d981ed8}},	//   _sťah, lcad_, енше_, _hise_, 
   {{0x2d981ed9,0x249c02d3,0xdac40131,0x00000000}},	//   _kise_, _ቀዳሞት_, _سېنى_, --, 
   {{0x2ca80009,0x1b040154,0x92bc00eb,0xe58400db}},	//   ncad_, রাণে_, ইলো_, رۅشۉ_, 
   {{0x2d981eda,0xe4581edb,0x92bc03d4,0x64a40124}},	//   _mise_, яжи_, ইলৈ_, _ҟала, 
   {{0x2d981edc,0xd7640132,0x2ca80009,0xdcfc0171}},	//   _lise_, _كەنى_, hcad_, _pupī, 
   {{0x78a41edd,0x2d981ede,0xf748004b,0xb38c0023}},	//   žive, _oise_, _تللي_, _መኣዝን_, 
   {{0x2d981edf,0xdedc1ee0,0xa0680640,0xe0441ee1}},	//   _nise_, ንድን_, зама_, енми, 
   {{0xa0341ee2,0x4fa01ee3,0x1b04015b,0x2ca80067}},	//   رىست, лияв, রাতে_, dcad_, 
   {{0x03640014,0xf36401e0,0x638400db,0x00000000}},	//   _تٔتی_, _үтән, _ягла, --, 
   {{0x2d981ee4,0x637c020c,0xa4fc0327,0x2ca80009}},	//   _bise_, nènm, _དྲོག_, fcad_, 
   {{0x71580046,0x2d981ee5,0x2ca80009,0x00000000}},	//   _орыс_, _cise_, gcad_, --, 
   {{0x2d981ee6,0x8c400a5b,0x2600012d,0x3ce00254}},	// [19a0] _dise_, гете, _वैसी_, rgiv_, 
   {{0x2d981ee7,0x2ca80067,0x612402d2,0x00000000}},	//   _eise_, acad_, _róly, --, 
   {{0x533404ac,0x2d981ee8,0x795403e6,0x2ca80009}},	//   ענען_, _fise_, نێسا, bcad_, 
   {{0x5974034c,0x60c41ee9,0x97c41eea,0x2d981bce}},	//   رداز, nakm, ейде, _gise_, 
   {{0xc8c41eeb,0xa4fc025c,0xd4981b15,0x2c001eec}},	//   روون_, _དྲེག_, үри_, _күтм, 
   {{0xd5b81eed,0x2d981eee,0xe7380142,0x00000000}},	//   пси_, _zise_, _stŵr_, --, 
   {{0xceb0025f,0x2d981eef,0x6ff4031c,0x60c41ef0}},	//   ניה_, _yise_, _བརྐུ_, kakm, 
   {{0x38c81ef1,0x59741ef2,0x60c41ef3,0x2d98008e}},	//   _زاری_, _чыгу, jakm, _xise_, 
   {{0x75d4021a,0x60c406df,0x12e401ce,0x7c240005}},	//   ريکا, dakm, нінг, nxir, 
   {{0x637c1ef4,0x63800124,0x00000000,0x00000000}},	//   lènj, аҳча, --, --, 
   {{0x60c401e4,0xd2581ef5,0x65900055,0xd34401d5}},	//   fakm, яци_, _lāhy, ویچه_, 
   {{0x4a580677,0x60c400ef,0x00000000,0x00000000}},	//   לדיו, gakm, --, --, 
   {{0xb4bc0316,0xb4040107,0x5eb00154,0x00000000}},	//   अरी_, _рӯйд, _জয়ে, --, 
   {{0x2d981ef6,0xae0c069f,0x72d4009b,0xf0b001d3}},	//   _sise_, हिलन_, _рокф, دیکھ, 
   {{0x2d980b91,0xf8d00574,0x60c41d9f,0x8778010f}},	//   _pise_, हणाय, bakm, פאלי, 
   {{0x51840b8d,0x032007dd,0x3014035b,0xad240075}},	//   _яула, _адән, _адир, خىرى, 
   {{0x2ca801d9,0x863c1ef7,0x00000000,0x00000000}},	// [19b0] rcad_, ባልነት, --, --, 
   {{0x659000b8,0x2d981ef8,0x2ca81ef9,0x3eb40419}},	//   _dāhy, _wise_, scad_, čatí_, 
   {{0x70541efa,0x2d981efb,0x412407d6,0x7c240de2}},	//   _سنگا, _tise_, _شفیق, axir, 
   {{0x637c0d29,0x2d980c3a,0x6c54104e,0xe8580153}},	//   vènm, _uise_, _акму, маеш_, 
   {{0x7c841efc,0x66e41efd,0x27e8145e,0x00000000}},	//   _буре, вола, îan_, --, 
   {{0x63ac0115,0x9ba000d1,0x637c02e2,0xece000bc}},	//   _ɩand, _ئەلى, tènm, _फाँफ, 
   {{0xa4fc1efe,0x77640005,0xa5c4013d,0x00000000}},	//   _དྲུག_, éixa, төзе, --, 
   {{0x2000033f,0xf9880220,0x799400f3,0x00000000}},	//   ywki_, _كەلۋ_, _бисф, --, 
   {{0x78a401a6,0xc76400d1,0x80b0012d,0x60c41eff}},	//   živc, _كائى, ंडसे, vakm, 
   {{0x7bc0036e,0xdedc0092,0x00000000,0x00000000}},	//   _çmue, ንድና_, --, --, 
   {{0x21681f00,0x61440a83,0x60c41f01,0x7c240083}},	//   дини_, вена, takm, zxir, 
   {{0x35f81370,0x6aa81f02,0x25a00419,0x00000000}},	//   _سرمد_, _şefl, íhlu_, --, 
   {{0x60c41f03,0x7c240e14,0x00000000,0x00000000}},	//   rakm, xxir, --, --, 
   {{0x22141f04,0xd24c04fb,0xf1a80133,0x6448002f}},	//   _афир, _ژنو_, بایه_, mzei, 
   {{0x64481f05,0x60c41f06,0x6590002b,0x5de4011c}},	//   lzei, pakm, _sāhy, ъжва, 
   {{0x7c2401c6,0x8d600354,0xdcf40153,0x65900055}},	//   txir, авсе, plyč, _pāhy, 
   {{0x64480639,0x9f840853,0x5f741f07,0x00000000}},	// [19c0] nzei, _игид, _لادر, --, 
   {{0x64480730,0x63bc1f08,0x7c240014,0x0b40008e}},	//   izei, ásny, rxir, анун, 
   {{0x64480730,0xdd881ee3,0x5a941f09,0x26000210}},	//   hzei, _обод_, траф, _वैली_, 
   {{0xd7f80372,0x7c240bc9,0xdca41f0a,0x39401f0b}},	//   дук_, pxir, _шами, óis_, 
   {{0x87e00b32,0x48e00410,0xd7880066,0x00000000}},	//   ающе, рочв, وختم_, --, 
   {{0x64481f0c,0x7a100055,0x00000000,0x00000000}},	//   dzei, _ṛtuy, --, --, 
   {{0xd5640131,0x6448002f,0xd7c405af,0x74541f0d}},	//   ктип, ezei, روژه_, گھائ, 
   {{0x64480730,0x01ac00cc,0x00000000,0x00000000}},	//   fzei, _কিংদ, --, --, 
   {{0x06801f0e,0x644803fa,0x312000dc,0x33741f0f}},	//   лгән, gzei, यासः_, лгир, 
   {{0x87b40375,0x60c00115,0x833001c6,0x8c400139}},	//   _סלבס_, _ĵoma, иных, _öşeg, 
   {{0x55041f10,0xd7640137,0xd7d00118,0x00000000}},	//   _ачла, _كەچى_, _सिँच, --, 
   {{0x5184026a,0x64480e78,0x506401c6,0x00000000}},	//   ђуна, bzei, втга, --, 
   {{0x93441f11,0xe81400e1,0x1ae001f9,0x2ec4004e}},	//   _инде, ढिया_, _पांथ, лөнм, 
   {{0xc0ec001f,0x91e001e0,0x704400cf,0x00000000}},	//   _ህዳር_, _кәмһ, _ەردە, --, 
   {{0x8d741f12,0x00000000,0x00000000,0x00000000}},	//   نارا, --, --, --, 
   {{0xd7d01f13,0x4ee00011,0x00000000,0x00000000}},	//   _सिंच, য়েল, --, --, 
   {{0x80b00073,0x00000000,0x00000000,0x00000000}},	// [19d0] ंडरे, --, --, --, 
   {{0x16001f14,0x312000cd,0xaa9401a9,0xeeb8010a}},	//   लबार_, यावः_, гизч, _ялош_, 
   {{0xfaa4016c,0x64481f15,0x00000000,0x00000000}},	//   ршун, zzei, --, --, 
   {{0x61e401e3,0x00000000,0x00000000,0x00000000}},	//   _åhle, --, --, --, 
   {{0xbc68009f,0xe7580150,0x00000000,0x00000000}},	//   _لمَن_, ниді_, --, --, 
   {{0x637c0066,0x6448022e,0x00000000,0x00000000}},	//   rènk, vzei, --, --, 
   {{0x78a41326,0xd764005e,0xdb04012c,0x3a980276}},	//   živa, دەلى_, _utká, _акрэ_, 
   {{0x2408169c,0x64481f16,0x637c1f17,0xf8e402de}},	//   ении_, tzei, mèni, _ەسەپ, 
   {{0x290c1f18,0x68e81f19,0xdbd003fa,0xdb1400ee}},	//   _iaea_, _iced, _müßt, hsyý, 
   {{0x64481f1a,0x290c1f1b,0x386001e7,0x00000000}},	//   rzei, _haea_, úire_, --, 
   {{0x64481f1c,0x290c1f1d,0x26c401e4,0x637c020c}},	//   szei, _kaea_, _ielo_, nèni, 
   {{0x26c41f1e,0x71241e4a,0x61440eed,0xb5580139}},	//   _helo_, لىپم, уема, _иихф_, 
   {{0x26c41f1f,0x290c096b,0x25a41f20,0x68e80198}},	//   _kelo_, _maea_, _hull_, _mced, 
   {{0x25a41f21,0x26c4098d,0x290c1f22,0x5f041f23}},	//   _kull_, _jelo_, _laea_, ызга, 
   {{0x26c41f24,0x290c00fb,0x68e8127b,0x63a81f25}},	//   _melo_, _oaea_, _oced, lqen, 
   {{0x61e01f26,0x26c41f27,0x68e800aa,0x25a41f28}},	//   mull, _lelo_, _nced, _mull_, 
   {{0x61e01f29,0x63a80944,0x25a4007c,0xdc6801c6}},	// [19e0] lull, nqen, _lull_, хаад_, 
   {{0x290c0093,0x68e81f2a,0x26c41f2b,0x25a40109}},	//   _aaea_, _aced, _nelo_, _oull_, 
   {{0x61e01f2c,0x290c00fb,0x637c1f2d,0x2738067c}},	//   null, _baea_, gèni, _gèni_, 
   {{0x68e81f2e,0x61e00194,0x290c0142,0xe0e00011}},	//   _cced, iull, _caea_, _বসুন, 
   {{0x26c41f2f,0x290c00fb,0x00000000,0x00000000}},	//   _belo_, _daea_, --, --, 
   {{0x61e01f30,0x26c41f31,0x290c0421,0x68e8127b}},	//   kull, _celo_, _eaea_, _eced, 
   {{0x26c41f32,0x290c1509,0x25a407de,0x61e01f33}},	//   _delo_, _faea_, _cull_, jull, 
   {{0x26c41f34,0x290c1f35,0x25a40e21,0x14c80022}},	//   _eelo_, _gaea_, _dull_, хыки_, 
   {{0x26c41f36,0x63a80944,0x00000000,0x00000000}},	//   _felo_, gqen, --, --, 
   {{0x26c41f37,0x25a41f38,0xd6281f39,0x660c0210}},	//   _gelo_, _full_, _позе_, łaka, 
   {{0x61e01f3a,0xdb040598,0x6aa80790,0x25a40f85}},	//   gull, _itkä, _şefk, _gull_, 
   {{0x94841f3b,0x26c40f72,0x3ea4013f,0x00000000}},	//   _йылд, _zelo_, ɛmti_, --, 
   {{0x54341f3c,0x61e01368,0xdce40171,0xca6801ec}},	//   _حرار, aull, _dikļ, зiлi, 
   {{0x61e01f3d,0x26c40077,0x73340131,0x00000000}},	//   bull, _xelo_, _خىتا, --, 
   {{0x61e01f3e,0x25a40077,0x25dc0037,0x00000000}},	//   cull, _xull_, _गमछी_, --, 
   {{0x27381f3f,0x637c1f40,0x70440150,0x00000000}},	//   _vèni_, vèni, _ەرگە, --, 
   {{0xd1f8044e,0x6fd802e5,0xde40001f,0x7c840395}},	// [19f0] ዋእቲ_, _भटिं, ከላከል, буфе, 
   {{0x39441f41,0xead41f42,0x68e81f43,0xdbdc0162}},	//   _alms_, рожь, _sced, _víðg, 
   {{0x26c41f44,0x290c1f45,0xcbc400f1,0xfb840108}},	//   _relo_, _paea_, _څېرو_, сытн, 
   {{0x26c41f46,0x25a41f47,0x78a41f48,0x63a802d1}},	//   _selo_, _rull_, živn, yqen, 
   {{0x26c41f49,0x25a406bb,0x290c1f4a,0x61e01f4b}},	//   _pelo_, _sull_, _vaea_, zull, 
   {{0x61e00cfe,0x290c0053,0x68e8009a,0x7bc00023}},	//   yull, _waea_, _wced, _çmua, 
   {{0x290c1f4c,0xd5ac0c8b,0xb0b406ab,0x68e80356}},	//   _taea_, وفو_, ंडाग, _tced, 
   {{0x25a40228,0x61e01f4d,0x26c41f4e,0x68e80af2}},	//   _vull_, vull, _welo_, _uced, 
   {{0xa3e40c66,0xa8541f4f,0x26c41f50,0x25a40493}},	//   बंध_, _ткач, _telo_, _wull_, 
   {{0x61e01f51,0xe2981f52,0x26c40421,0x25a41f53}},	//   tull, кап_, _uelo_, _tull_, 
   {{0xe1241f54,0x61e00140,0xe4d40814,0x63a81f55}},	//   амни, uull, _نقاد, sqen, 
   {{0x61e01f56,0xa3e406ab,0x65780117,0x63a8014f}},	//   rull, बंद_, _ukwh, pqen, 
   {{0x61e01f57,0x31681f58,0x22580034,0x00000000}},	//   sull, _djaz_, ńsk_, --, 
   {{0x61e01f59,0xdee41f5a,0xd0040063,0xc58400f1}},	//   pull, јови, јере_, _شپږم_, 
   {{0x61e01f5b,0x3f8400da,0xdd901a9b,0x00000000}},	//   qull, ēmu_, قوس_, --, 
   {{0x20541f5c,0x637c1f5d,0xdb14002e,0xa2dc043e}},	//   _втор, gènv, ppyë, पलक्, 
   {{0x67200327,0x00000000,0x00000000,0x00000000}},	// [1a00] _onlj, --, --, --, 
   {{0xb17c01e4,0x4b200329,0x8b200d1d,0x00000000}},	//   muĥa, омув, одуе, --, 
   {{0xa3e41f5e,0x7f5c0113,0x5f440014,0xa6880150}},	//   बूत_, mirq, _منکل, _ﺯﺍﻻﻝ_, 
   {{0xd944026a,0xdb0402d3,0x7f5c0113,0x00000000}},	//   једи, _kukë, lirq, --, 
   {{0x7d041f5f,0xd70419bf,0x4cb802e4,0x985406ed}},	//   meis, изди, _בזכו, јтеш, 
   {{0xed5801f1,0x73d802a9,0x9f400200,0x765c032e}},	//   ďže_, қдор_, dukë_, _þryk, 
   {{0x645c1f60,0x1c0c02ab,0x60d402d0,0xdb040200}},	//   úsin, सिकल_, _odym, _lukë, 
   {{0x7d041f61,0x44a0104b,0x66040784,0x7f5c03b9}},	//   neis, يمىق, çhka, hirq, 
   {{0x6aa81f62,0x7f5c02d1,0x195802dd,0x00000000}},	//   _şefi, kirq, _заңы_, --, 
   {{0x7d041f63,0x60d41f64,0x16740063,0xdb041f65}},	//   heis, _adym, _кћер, _utkä, 
   {{0x7d041f66,0x154400f3,0x00000000,0x00000000}},	//   keis, _кежм, --, --, 
   {{0x7d04023a,0xdb040023,0xd1381f67,0x7778022e}},	//   jeis, _bukë, тхо_, lovx, 
   {{0x7d041f68,0x6720000f,0x60d41f69,0x4ea41f6a}},	//   deis, _ynlj, _ddym, ирва, 
   {{0x9324021a,0xc05800d6,0x7f5c0309,0xdb040240}},	//   _څرګن, рію_, girq, _dukë, 
   {{0x7d041f6b,0x637c004e,0x29dc03b2,0xf1940395}},	//   feis, gènu, _máað_, _ликь, 
   {{0x7d041f6c,0x00000000,0x00000000,0x00000000}},	//   geis, --, --, --, 
   {{0x6e941f6d,0x7f5c0784,0x644c0024,0x8aa40cb6}},	// [1a10] _گلدا, birq, _žaiz, аред, 
   {{0x7f5c0309,0x7c200841,0x00000000,0x00000000}},	//   cirq, _šmrc, --, --, 
   {{0x6e941f6e,0xdb0401c7,0x637c0214,0x00000000}},	//   _دلدا, _zukë, mènt, --, 
   {{0xd2440050,0x637c00f2,0x7d0401e4,0x31781f6f}},	//   _ہن_, lènt, ceis, nosz_, 
   {{0xff501f70,0x00000000,0x00000000,0x00000000}},	//   _رخی_, --, --, --, 
   {{0xa3e4000d,0x00000000,0x00000000,0x00000000}},	//   बंस_, --, --, --, 
   {{0x31780827,0x00000000,0x00000000,0x00000000}},	//   kosz_, --, --, --, 
   {{0xa5241f71,0x637c00f2,0x660c0210,0x4b50009f}},	//   смид, hènt, łako, _اَڀر, 
   {{0x52e000e1,0x7f5c0784,0x14201f72,0xc0ec01f3}},	//   पलूस, yirq, здым, _ህዳሴ_, 
   {{0x7d041f73,0xdddc0118,0x7f5c025c,0x00000000}},	//   zeis, _expř, xirq, --, 
   {{0x7d041f74,0xdb0400e8,0xc4cc01d3,0x77901a4b}},	//   yeis, _sukë, _ہےں_, _تیوا, 
   {{0x9f40020c,0x7f5c1f75,0xdb040240,0x7d0401f4}},	//   muké_, wirq, _pukë, xeis, 
   {{0x7d041f76,0xdb04007f,0x9f4000f2,0x7f5c02d1}},	//   veis, _fukè, luké_, tirq, 
   {{0x7d041f77,0x602400c7,0x2164013d,0x00000000}},	//   weis, _ҳдиа, ртүг, --, 
   {{0x7d041f78,0x7f5c0986,0xe0600133,0x5330041b}},	//   teis, rirq, تێکی, _хејт, 
   {{0x21f00548,0xed58013e,0x20c401b9,0xa0580f47}},	//   máh_, ҳоӣ_, _уйим, _مؤخر_, 
   {{0x21f00429,0x637c0066,0x7f5c02d1,0xdee40120}},	// [1a20] láh_, bènt, pirq, _лопи, 
   {{0x7d041f79,0x637c1f7a,0x7f5c0113,0x9f04004b}},	//   seis, cènt, qirq, _اودو, 
   {{0x9938063b,0x7d0411ad,0x38c81f7b,0x21f0011f}},	//   ляду_, peis, لاشی_, náh_, 
   {{0x9f40020c,0x29dc03b2,0x81c803d4,0xf8b80022}},	//   duké_, _sáað_, _ৰঙা_, рҩа_, 
   {{0x637c020c,0x9b8812ea,0x645c00d0,0x98a400c7}},	//   nèns, _منحل_, úsil, аиҵе, 
   {{0x21f00548,0xeb740153,0xabc401af,0x00000000}},	//   káh_, _дысэ, _фарҙ, --, 
   {{0xceb00bd9,0x8f980a1e,0x21f0011f,0x637c0066}},	//   ליג_, ניצי, jáh_, hèns, 
   {{0x73d81f7c,0xdb04020c,0x21f00429,0x9484010b}},	//   адир_, _sukè, dáh_, йыпд, 
   {{0x637c02e2,0x51a00150,0x562801ec,0x932400f2}},	//   yènt, _ﺍﻟﺘﻁ_, _әжем_, مردن, 
   {{0x1b040154,0x870800e5,0x9f400241,0x00000000}},	//   রাকে_, _معمہ_, buké_, --, 
   {{0x21f00429,0x637c0ffb,0x9f400214,0x4b78010f}},	//   gáh_, vènt, cuké_, רטיג, 
   {{0xd14801b9,0x4a98010f,0x2bd80ebb,0x00000000}},	//   اشدن_, טייג, _ढिला, --, 
   {{0x637c0137,0x2738067c,0x3da40107,0x31781f7d}},	//   tènt, _gèns_, ҷруб, rosz_, 
   {{0x21f00548,0xdce40139,0x11f41f7e,0x6e200a7f}},	//   báh_, _pkkğ, _هوتک_, ålbo, 
   {{0x21f0011f,0x7e280d30,0x3134014b,0x858001e1}},	//   cáh_, біта_, _мекр, _ẹniẹ, 
   {{0x78a41f7f,0xa1b402f2,0x00000000,0x00000000}},	//   živj, _بجوڵ, --, --, 
   {{0x637c00e4,0x00000000,0x00000000,0x00000000}},	// [1a30] pènt, --, --, --, 
   {{0x321c00d7,0x8aa401a9,0x00000000,0x00000000}},	//   _krvy_, срад, --, --, 
   {{0xc9841f80,0x00000000,0x00000000,0x00000000}},	//   буди, --, --, --, 
   {{0x28f80108,0x2c700ca8,0x00000000,0x00000000}},	//   редь_, _ẹdun_, --, --, 
   {{0x6aa80276,0x6d4c0b4f,0xa6c81f81,0x6358007f}},	//   _şefu, mhaa, алла_, wňnm, 
   {{0x70b41f82,0x21f0011f,0x9f400066,0x7b6401ec}},	//   ंडुल, yáh_, tuké_, _етсе, 
   {{0x21f00429,0x7f3c010f,0x888000e5,0x00000000}},	//   xáh_, רעוו, _کیشن, --, 
   {{0x6d4c1f83,0xa4440116,0x21f000d7,0x00000000}},	//   nhaa, жнид, váh_, --, 
   {{0x86e81f84,0x38340276,0xdb04002e,0x21f00548}},	//   _معاف_, _ентр, _suké, wáh_, 
   {{0xe1f81f85,0x21f0011f,0x00000000,0x00000000}},	//   аго_, táh_, --, --, 
   {{0x6d4c1f86,0x46681f87,0x97300fa2,0x00000000}},	//   khaa, _срам_, _تکنا, --, 
   {{0x21f00429,0x6b28031c,0x637c07b0,0x00000000}},	//   ráh_, _ལོའོ_, tèns, --, 
   {{0x6d4c1f88,0x23281f89,0x21f0011f,0x656800d7}},	//   dhaa, _воли_, sáh_, mneh, 
   {{0x65681f8a,0xdb04003e,0x637c04fb,0x443c1f8b}},	//   lneh, _tuké, rèns, myu_, 
   {{0x637c0502,0xa3e40c2e,0xfe7800f7,0x21f00548}},	//   sèns, बूर_, сүн_, qáh_, 
   {{0x6d4c1f8c,0xdb14023a,0x00000000,0x00000000}},	//   ghaa, nsyö, --, --, 
   {{0x443c1f8d,0x6600005a,0x65681f8e,0x78a40010}},	// [1a40] nyu_, _lplk, ineh, živk, 
   {{0x443c013f,0x61e00194,0x6d4c058a,0x6568002f}},	//   iyu_, orll, ahaa, hneh, 
   {{0x9a680597,0x5ca400c2,0x0b14007b,0x68f80142}},	//   جمال_, _минб, تقلة_, ffwd, 
   {{0x6d4c1f8f,0x443c1f90,0x98a41f91,0x6aa80790}},	//   chaa, kyu_, циде, _şeft, 
   {{0xd7081f92,0x18681f93,0x65680030,0x443c1f94}},	//   инде_, шади_, dneh, jyu_, 
   {{0x501806a9,0x443c1f95,0x6568035a,0x4730187f}},	//   יונו, dyu_, eneh, мніс, 
   {{0xd9440d06,0x656803fa,0x1a640066,0x00000000}},	//   _деви, fneh, _بیای_, --, 
   {{0x443c0083,0x65681f96,0x058001ec,0x00000000}},	//   fyu_, gneh, муым, --, 
   {{0x443c1f97,0xa3e40d2c,0x61e00077,0x87e40046}},	//   gyu_, बूल_, erll, _وتكە, 
   {{0x72d00131,0x321c1f98,0x32541f99,0x63e000d1}},	//   رەبچ, _prvy_, звор, رۋىل, 
   {{0x6d4c102c,0x65681f9a,0x443c1574,0xc0d80023}},	//   yhaa, bneh, ayu_, _ክኢላ_, 
   {{0x65681f9b,0xc68c0014,0x443c04ce,0x3ce4033f}},	//   cneh, _شِن_, byu_, गलों_, 
   {{0x61e01f9c,0x443c1f9d,0x7c200306,0x00000000}},	//   arll, cyu_, _šmrn, --, 
   {{0x61e0037e,0x6d4c00b0,0xd14801d5,0x300400c7}},	//   brll, whaa, اشگن_, озҭг, 
   {{0xd1c805f5,0x6d4c1f9e,0xb63c00b5,0x201c02b1}},	//   _тулд_, thaa, _ｇｓ_, ātia_, 
   {{0x2afc012c,0x00000000,0x00000000,0x00000000}},	//   र्नु_, --, --, --, 
   {{0xc0d802d3,0xd1480014,0xc0f40023,0x6b84014f}},	// [1a50] _ክኢሉ_, _مشکن_, ልኦም_, tlhg, 
   {{0x6d4c1f9f,0xe86405f5,0x65681f98,0xa03401ec}},	//   shaa, үхдү, zneh, _رىپت, 
   {{0x2fc8079b,0x6d4c198f,0x6568058a,0xa8880116}},	//   _hwag_, phaa, yneh, әйла_, 
   {{0x443c1fa0,0xf9901fa1,0x00000000,0x00000000}},	//   yyu_, نبن_, --, --, 
   {{0x88041fa2,0x6d5c1fa3,0x656801f1,0x7af001b8}},	//   تظام, _imsa, vneh, äitö, 
   {{0x39a803e3,0xdc38011a,0xe5a400cf,0x49b80133}},	//   _ağsu_, _העשר, пики, _نارد_, 
   {{0x65681fa4,0x24880cf4,0x443c03f0,0x63b8015d}},	//   tneh, _šam_, wyu_, _stwn, 
   {{0x443c0bed,0x70b401ad,0x38c80137,0xd88401d9}},	//   tyu_, ंडोल, _муун_, _کھٔن_, 
   {{0x65681fa5,0x3f980368,0x443c0099,0x00000000}},	//   rneh, ymru_, uyu_, --, 
   {{0x65681fa6,0x443c1fa7,0xdb14023a,0x69c0025c}},	//   sneh, ryu_, ssyö, _ħlej, 
   {{0x443c1fa8,0x776400db,0x656800d7,0x66e401af}},	//   syu_, èixe, pneh, _моҡа, 
   {{0x21681fa9,0x443c0bf1,0xe8900023,0x61e00200}},	//   сими_, pyu_, _ዝሓስቡ_, rrll, 
   {{0x4ac80da0,0x00000000,0x00000000,0x00000000}},	//   िराव, --, --, --, 
   {{0x6d5c1faa,0xdb040158,0x98780375,0xca6800fa}},	//   _amsa, _utkø, מארט, зiмi, 
   {{0x61441fab,0xf9f80327,0x3f980327,0xdddc013a}},	//   _нека, _པཱེན_, rmru_, _vypů, 
   {{0x2d941fac,0xdd88013e,0x91d8010f,0x00000000}},	//   друс, ёбад_, _פֿופ, --, 
   {{0x2fc80368,0xdddc01ef,0x00000000,0x00000000}},	// [1a60] _gwag_, _typů, --, --, 
   {{0x6d5c03bd,0xa3cc1fad,0xdc6801d5,0xd1b00345}},	//   _emsa, षीय_, _ҳамд_, _تیێک, 
   {{0x1d080334,0x00000000,0x00000000,0x00000000}},	//   _лени_, --, --, --, 
   {{0xed040137,0x00000000,0x00000000,0x00000000}},	//   _قوپپ, --, --, --, 
   {{0x0c2002d5,0x680001d3,0xbb740eff,0xd7c40073}},	//   _змян, _rájö, _قۇرع, रींच, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d5c022c,0x8b2000a7,0x68f0005b,0x00000000}},	//   _ymsa, _ядре, ähdö, --, 
   {{0xf9041fae,0x6aa008a5,0x00000000,0x00000000}},	//   _تأسی, _úlfa, --, --, 
   {{0xd3781faf,0x97c40345,0x00000000,0x00000000}},	//   йчо_, _رقاو, --, --, 
   {{0x15b00533,0x6610088b,0xcc540375,0xd8cc00d1}},	//   _كەتس, äkkä, פסיק_, _ﻗﯩﻼﻟ, 
   {{0x2fc81590,0x201000ca,0x00000000,0x00000000}},	//   _swag_, _asyi_, --, --, 
   {{0xf8cc1fb0,0x92bc0154,0x2fd8007b,0x984c06be}},	//   ारिय, েলে_, يوجد_, lğıc_, 
   {{0xb4e8121d,0xc95000d9,0x91cc000d,0x00000000}},	//   बली_, תמר_, _दबवै, --, 
   {{0x27e8026c,0xd14800f2,0x4ea41fb1,0x984c0213}},	//   àani_, _گشتن_, ярма, nğıc_, 
   {{0xf8cc1fb2,0x6fd80574,0xfe7000c6,0xf1c80150}},	//   ाराय, _भटकं, هدف_, _بوعى_, 
   {{0x2fc80280,0xdb04013c,0xd24c01d3,0x00000000}},	//   _twag_, _nukâ, _لنڈ_, --, 
   {{0x2fc8012d,0xf41400df,0x00000000,0x00000000}},	// [1a70] _uwag_, ופּ_, --, --, 
   {{0x7b141fb3,0x41a80037,0x00000000,0x00000000}},	//   ндух, _घूँस, --, --, 
   {{0x7f3c0302,0x442801fb,0xc0f40023,0xe3bc0154}},	//   _לעזו, ̣c_, ልጦም_, _ইয়াব, 
   {{0x6d5c1fb4,0x2bb40412,0xe8f80816,0xb4f801f9}},	//   _umsa, _अंपा, ілл_, ्जोप_, 
   {{0xe7381fb5,0x00000000,0x00000000,0x00000000}},	//   жел_, --, --, --, 
   {{0x2d881fb6,0x66e41fb7,0xbdf81fb8,0x0ebc0709}},	//   llae_, фока, _بریا_, ्रिड, 
   {{0x2d880393,0x00000000,0x00000000,0x00000000}},	//   olae_, --, --, --, 
   {{0xe3b81fb9,0x92bc0154,0xe57801a9,0x64a4004e}},	//   оби_, েলো_, ўзи_, майа, 
   {{0x2d881fba,0x79240354,0x00000000,0x00000000}},	//   ilae_, _яьрж, --, --, 
   {{0xf8681fbb,0x9f400270,0xaadc1fbc,0xba080092}},	//   _عملي_, tukí_, मणिक, _ወባ_, 
   {{0x77900b29,0x8c1000eb,0x00000000,0x00000000}},	//   _حیوا, সমিন_, --, --, 
   {{0x61441fbd,0xb5c80066,0x00000000,0x00000000}},	//   фема, _روهم_, --, --, 
   {{0x34941fbe,0x942400d1,0xd36c00f1,0x00000000}},	//   _зацр, _يومۇ, اهۍ_, --, 
   {{0x51940020,0x626405c5,0xdb040784,0x2d88199b}},	//   መለከተ_, _овла, _pukí, elae_, 
   {{0x8fa01fbf,0x00000000,0x00000000,0x00000000}},	//   таре, --, --, --, 
   {{0xa06800db,0x00000000,0x00000000,0x00000000}},	//   _майа_, --, --, --, 
   {{0xdc6801c6,0xd00c02dd,0x25a00419,0x00000000}},	// [1a80] цаад_, _ەلۋ_, íhly_, --, 
   {{0x2d881fc0,0x39a80166,0xa3e400ab,0xe84000bc}},	//   alae_, _aşsa_, _फिन_, ůběž, 
   {{0x5de41fc1,0xd378010f,0x9f041bf4,0x9f2000d1}},	//   _южна, קרעט, _فوکو, _كۈڭۈ, 
   {{0x9cb41fc2,0x2d88003a,0x58841fc3,0xa3ac1fc4}},	//   _زمست, clae_, мыла, कदा_, 
   {{0x6c7401c6,0xbe640023,0x00000000,0x00000000}},	//   _зурх, _ፍልጠታ, --, --, 
   {{0xd5b81fc5,0x9f4000d7,0x00000000,0x00000000}},	//   оси_, ytký_, --, --, 
   {{0xfbb00f22,0x00000000,0x00000000,0x00000000}},	//   _ছবিত, --, --, --, 
   {{0xb4e81d8a,0x5edc00cd,0x00000000,0x00000000}},	//   बले_, कृत्_, --, --, 
   {{0x12e41cb8,0x00000000,0x00000000,0x00000000}},	//   мінг, --, --, --, 
   {{0x46e4010b,0x92bc009e,0x8838011a,0x662800e5}},	//   _одун_, েল্_, _ותמו, éskö, 
   {{0x3b181fc6,0x85741fc7,0xdb04002e,0x2d88003a}},	//   _marq_, ясәт_, _mukà, ylae_, 
   {{0x3b180784,0x78a40306,0x00000000,0x00000000}},	//   _larq_, živu, --, --, 
   {{0x59cc0574,0x104802bf,0x2d88017a,0x4fc401c4}},	//   हीतर, іями_, vlae_, ьсна, 
   {{0x2bb413b4,0x733407d2,0x63bc0419,0x40340114}},	//   _अंबा, _سىبا, ísne, њерс, 
   {{0x2d881fc8,0x26d8016b,0x00000000,0x00000000}},	//   tlae_, _ɛso_, --, --, 
   {{0xa3e4069f,0x66040784,0x00000000,0x00000000}},	//   बूक_, çhki, --, --, 
   {{0x3b1801a9,0x2d880af9,0x25e400bc,0x00000000}},	// [1a90] _barq_, rlae_, _टिभी_, --, 
   {{0x2d8805e4,0x09a407b7,0x00000000,0x00000000}},	//   slae_, गद्य, --, --, 
   {{0x2d881fc9,0x00000000,0x00000000,0x00000000}},	//   plae_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3b18036b,0xf21005f9,0x00000000,0x00000000}},	//   _farq_, ़बड़_, --, --, 
   {{0x06cc00eb,0xe7940066,0x64a40124,0x00000000}},	//   _রাহি, راشک, ҭака, --, 
   {{0x2bb401ad,0x8d90001f,0x69c00135,0x855400e5}},	//   _अंडा, _ሁኔታው_, _ħlew, ویئر_, 
   {{0xad44001f,0x09c8000d,0x00000000,0x00000000}},	//   _የወጣቶ, ाठीय, --, --, 
   {{0xa7740006,0x7d0001e3,0x3b18022e,0xe3b0007b}},	//   _злач, _ömse, _yarq_, درب_, 
   {{0x46800e46,0x4e0c1fca,0x7c2001a6,0xdb041aa9}},	//   _иқла, ाबाई_, _šmrk, _kuká, 
   {{0xdb040022,0xe5e41fcb,0x36d401f0,0x00000000}},	//   _juká, _سزای, _рохр, --, 
   {{0x261001a6,0x00000000,0x00000000,0x00000000}},	//   _išo_, --, --, --, 
   {{0xdb0403f7,0xd24c1fcc,0x80a80154,0x00000000}},	//   _luká, لنی_, কুন্, --, 
   {{0x3eac1fcd,0xdb0400c7,0x38600332,0x00000000}},	//   ødt_, _ouká, úiri_, --, 
   {{0x236404f3,0x3eb8004e,0x00000000,0x00000000}},	//   milj_, rcrt_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x63ac0395,0xa06800ee,0xdd9401ec,0x00000000}},	// [1aa0] _èand, _хапа_, даңы, --, 
   {{0x23640267,0x4c800116,0xdb0401d3,0x00000000}},	//   nilj_, улув, _buká, --, 
   {{0x590806a6,0xd9441fce,0x261000d7,0xdb0401ef}},	//   зеем_, нежи, _nšo_, _cuká, 
   {{0xdb0403da,0x225000d0,0x6a9400d4,0x00000000}},	//   _duká, úzky_, трує, --, 
   {{0xdb040022,0x261000ef,0xb71800f3,0x00000000}},	//   _euká, _ašo_, долф_, --, 
   {{0x7bc41fcf,0xc7a01fd0,0xdb0400d7,0x00000000}},	//   mpiu, гичк, _fuká, --, 
   {{0x06cc015b,0x95c8109a,0x7bc41fd1,0x00000000}},	//   _রাশি, чула_, lpiu, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7bc405b1,0xd7c80338,0xf8cc1fd2,0x00000000}},	//   npiu, _رواه_, ारीप, --, 
   {{0xf48407d6,0x85000214,0x00c80150,0x7bc400c0}},	//   _یاشی, پوین, _ﺒﺘﺭﺘ, ipiu, 
   {{0x82d4009d,0x00000000,0x00000000,0x00000000}},	//   эдэс_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x45080003,0xba08001f,0x2bb41098,0x23640cf4}},	//   _ཁྲིར_, _ወጣ_, _अंधा, bilj_, 
   {{0x4ea41fd3,0xbfa81fd4,0x91e000fb,0x00000000}},	//   ерба, етсе_, _йәмһ, --, 
   {{0x8318123b,0x00000000,0x00000000,0x00000000}},	//   _מוגז, --, --, --, 
   {{0xdb040232,0x2bb41fd5,0x6ab81f14,0x00000000}},	//   _ruká, _अंदा, इड्र, --, 
   {{0xcb44009d,0x00000000,0x00000000,0x00000000}},	// [1ab0] нхжи, --, --, --, 
   {{0x62240228,0x8c3401f0,0xbc381fd6,0x00000000}},	//   _سوۋە, _ҷомӣ_, رسقا_, --, 
   {{0x4ea401c0,0xdeb40375,0x6e940022,0xf8cc00dc}},	//   _яриа, _בפתח_, _шиоу, ारूप, 
   {{0xc9840a11,0x3a740022,0x00000000,0x00000000}},	//   رشاي, ылхр, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7e7400a2,0xdaa00137,0xaa5c0408,0x4ba400db}},	//   _çepç, _چەكپ, _дегi, _чөбү_, 
   {{0xf7701fd7,0xc444130e,0x236400f3,0x00000000}},	//   حان_, کیشن_, vilj_, --, 
   {{0x7c2001a6,0x69c41fd8,0xa52400d1,0x00000000}},	//   _šmri, mphe, тмид, --, 
   {{0x23640960,0x00000000,0x00000000,0x00000000}},	//   tilj_, --, --, --, 
   {{0x69c41fd9,0x291c017a,0x00000000,0x00000000}},	//   ophe, ldwa_, --, --, 
   {{0x69c41fda,0xa3e402ab,0xe51400a8,0x04840014}},	//   nphe, बूज_, _афлэ, بٕکی_, 
   {{0xa0681fdb,0x69c40472,0x6f04007b,0x236401a6}},	//   дама_, iphe, _abhc, silj_, 
   {{0x62240131,0xa07402dd,0x69c401ab,0x30741fdc}},	//   رىڭل, тынш, hphe, гурс, 
   {{0x2d980009,0x2244002d,0x5f0400a7,0xe2841fdd}},	//   _ahse_, pylk_, ъзга, _илли, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x60240124,0x7bc40270,0x69c41fde,0x1fb4014b}},	//   _адиа, tpiu, dphe, _исор, 
   {{0x291c0c8a,0x5ba81fdf,0x8c40023a,0x7bc400a3}},	// [1ac0] ddwa_, дкам_, аете, upiu, 
   {{0x7bc41fe0,0x00000000,0x00000000,0x00000000}},	//   rpiu, --, --, --, 
   {{0x7bc41fe1,0x1b0400fe,0x986400e5,0x00000000}},	//   spiu, ৰালে_, ھیئے_, --, 
   {{0xd7e41fe2,0x7bc41fe3,0x09e00640,0x61e4007c}},	//   віко, ppiu, роцн, _åhlu, 
   {{0x69c406a3,0xeb300228,0x00000000,0x00000000}},	//   aphe, _گۉلد, --, --, 
   {{0x69c401d4,0x73c401e0,0x34bc00dc,0x00000000}},	//   bphe, ңәле, ैर्द, --, 
   {{0x69c40e89,0xceb00302,0x00000000,0x00000000}},	//   cphe, סיה_, --, --, 
   {{0x38c81fe4,0xdb040166,0x68d4013d,0xe6c40220}},	//   _ساری_, _bukç, _бюфф, _ەتني, 
   {{0x49140490,0x5dc401ec,0x00000000,0x00000000}},	//   _नसतो_, _ﺩﻨﻴﻴ, --, --, 
   {{0x2bb41fe5,0x00000000,0x00000000,0x00000000}},	//   _अंसा, --, --, --, 
   {{0x0f3c0092,0x00000000,0x00000000,0x00000000}},	//   _ዓለማየ, --, --, --, 
   {{0x27e81fe6,0x98b80024,0x00000000,0x00000000}},	//   šane_, ėpė_, --, --, 
   {{0x69c40165,0xc1741422,0x543406c2,0x00000000}},	//   zphe, рлящ, _جرار, --, 
   {{0x995c00bc,0x130402dd,0xc7b0011a,0x00000000}},	//   _nůž_, _شىعۋ_, יבש_, --, 
   {{0x7e4400f3,0xdcfc00d7,0x814400db,0x291c0210}},	//   ахте, _dupľ, _چنىن, ydwa_, 
   {{0x63ac02e8,0xf8cc1fe7,0x6e241710,0x637c007f}},	//   _èanc, ारोप, _vrhb, dèny, 
   {{0x63ac021c,0x09c80a59,0xcf9800d8,0x00000000}},	// [1ad0] _éant, ाठ्य, _ојо_, --, 
   {{0x69c41fe8,0x3b541fe9,0x9510031c,0x6f040332}},	//   tphe, акур, _ཉིའི_, _ubhc, 
   {{0x66e4036b,0x69c4009a,0x00000000,0x00000000}},	//   ҳола, uphe, --, --, 
   {{0xfce400d8,0x2d9801ef,0x00000000,0x00000000}},	//   _коџо, _uhse_, --, --, 
   {{0xdb040793,0x6d4c1fea,0xd8b40214,0x310400dc}},	//   _bukä, mkaa, اگفا_, ष्यः_, 
   {{0x6d4c0d62,0x77841feb,0x69c41fec,0x27fc0042}},	//   lkaa, аліз, pphe, rtwn_, 
   {{0x7f3c008f,0x27fc0042,0x00000000,0x00000000}},	//   ועגו, stwn_, --, --, 
   {{0x6d4c1fed,0x6b84036b,0x25881e4a,0x00000000}},	//   nkaa, lohg, رچاپ_, --, 
   {{0x386000c6,0x4aa400dc,0x6d4c1fee,0xe3a8059f}},	//   úirt_, _कृतव, ikaa, нкид_, 
   {{0x96c803f3,0x6d4c1fef,0x344400d1,0x6b8401a9}},	//   _स्पॉ, hkaa, рүши_, nohg, 
   {{0xe65800c6,0x21681ff0,0x61441ff1,0x15e8012d}},	//   _ثلاث_, еини_, гена, _टियर_, 
   {{0x6d4c1ff2,0x6b84014f,0x00000000,0x00000000}},	//   jkaa, hohg, --, --, 
   {{0x6d4c0050,0x6568049b,0x69c00109,0xf2f803e6}},	//   dkaa, mieh, _élef, روێژ_, 
   {{0x65681ff3,0x6d4c1ff4,0x34940107,0x00000000}},	//   lieh, ekaa, _тачр, --, 
   {{0xfe781ff5,0x1d08163f,0x6d4c01d9,0xc1040075}},	//   түн_, неви_, fkaa, _күнл, 
   {{0x6d4c1ff6,0x2bb41df0,0x60541063,0x00000000}},	//   gkaa, _अंशा, _منعط, --, 
   {{0x5f741ff7,0x220401d9,0x64481ff8,0x9f4002b5}},	// [1ae0] _مادر, _شِکٲ, nyei, tukä_, 
   {{0x60d4037e,0x64480086,0x6d4c1ff9,0x656803fa}},	//   _heym, iyei, akaa, hieh, 
   {{0x6d4c01d9,0x65681ffa,0x4ef80a7c,0x00000000}},	//   bkaa, kieh, _אליג, --, 
   {{0x39401ffb,0x60d41ffc,0x6d4c0072,0xdbdc01e1}},	//   ðis_, _jeym, ckaa, _tíàg, 
   {{0x7d041ffd,0x60d41ffe,0x656817b8,0x48e01fff}},	//   mfis, _meym, dieh, сочв, 
   {{0x7d042000,0x7c242001,0x60d402d1,0xf7702002}},	//   lfis, mvir, _leym, ڭاچ_, 
   {{0x7d042003,0xbacc0ed1,0x6568002f,0x4ed8010f}},	//   ofis, _ﺗﯘﺗﺎ, fieh, ײַונ, 
   {{0x74142004,0x98a41eed,0x1ae40c60,0x656803ac}},	//   لوبا, _бибе, _шоҳм, gieh, 
   {{0x7c242005,0x1368192a,0xb6c41206,0x7d042006}},	//   nvir, ешни_, _көйд, ifis, 
   {{0xa3e42007,0x7c2404ba,0x932401d5,0xdb0401f4}},	//   _फिर_, ivir, چرگن, _etkö, 
   {{0x60d42008,0x656801f1,0x6d4c0548,0x7d040250}},	//   _beym, bieh, ykaa, kfis, 
   {{0x518403b7,0x656801f1,0x60d42009,0x6d4c0009}},	//   ѓуна, cieh, _ceym, xkaa, 
   {{0x7d04200a,0x60d4200b,0x8f080116,0x50640006}},	//   dfis, _deym, нхва_, утна, 
   {{0x7d04200c,0x7c24200d,0x96c802ab,0x60d400ad}},	//   efis, dvir, _स्मॉ, _eeym, 
   {{0x7d04200e,0x6d4c200f,0x8d742010,0xadd40063}},	//   ffis, tkaa, هارا, робљ, 
   {{0x7d042011,0x60d42012,0x9f400589,0x41c00046}},	//   gfis, _geym, trkã_, _اقيق, 
   {{0x6d4c2013,0x7c24005c,0x417400f1,0x92b40154}},	// [1af0] rkaa, gvir, _داوس, জরী_, 
   {{0x65680639,0x6d4c2014,0x7d042015,0x0ca8013d}},	//   zieh, skaa, afis, _үтми_, 
   {{0x6d4c0cfe,0x7c24005b,0x6a1402dd,0x7d042016}},	//   pkaa, avir, рмеу, bfis, 
   {{0x7c2405b8,0xa3e42017,0x7d04009f,0x97200014}},	//   bvir, _फिल_, cfis, ۪ہلو, 
   {{0x644803ac,0x00000000,0x00000000,0x00000000}},	//   xyei, --, --, --, 
   {{0xb8ec0a28,0x656801c7,0x24b40150,0x65c40064}},	//   _श्_, wieh, _ﹼﻘﺘﻬ, абка, 
   {{0x65682018,0xdde40064,0xe634009d,0x00000000}},	//   tieh, _įpūt, рхлэ, --, 
   {{0x79a403b7,0x63bc0c5e,0x6fb401f9,0x64480108}},	//   _груе, ísno, ंदां, tyei, 
   {{0x656817b8,0x00000000,0x00000000,0x00000000}},	//   rieh, --, --, --, 
   {{0x60d42019,0x6568201a,0x06cc0154,0xd0b006be}},	//   _seym, sieh, _রাকি, mşək, 
   {{0x60d4201b,0x7c240e8a,0x7d04201c,0x65680196}},	//   _peym, zvir, yfis, pieh, 
   {{0xa0a4201d,0x7c24022c,0x602401c0,0x60d4047e}},	//   ианд, yvir, адма, _qeym, 
   {{0x7c24003e,0x60d4022e,0x974c0241,0x00000000}},	//   xvir, _veym, _ọ̀rọ_, --, 
   {{0x60d4201e,0x7d04201f,0x7c242020,0xddc401a9}},	//   _weym, wfis, vvir, ибги, 
   {{0x60d42021,0xfcdc0092,0x399c01e7,0x00000000}},	//   _teym, _ሕንጻ_, líse_, --, 
   {{0x7c240953,0x81c8009e,0x00000000,0x00000000}},	//   tvir, _লিপ_, --, --, 
   {{0xdee417fb,0x7d042022,0x7c24004c,0x00000000}},	// [1b00] _копи, rfis, uvir, --, 
   {{0x9e6405b0,0xd00c1de5,0xe190001f,0x00000000}},	//   _ввод, _کلی_, _ማህበሩ_, --, 
   {{0x399c0597,0x200000c5,0x7d042023,0x7d0001e3}},	//   híse_, ltki_, pfis, _ömso, 
   {{0x7c242024,0x06cc0154,0x8d7400f1,0xd8240139}},	//   pvir, _রাগি, _ناټا, идеи, 
   {{0x20002025,0x7794190f,0x2b9001b9,0x3de800cc}},	//   ntki_, میرا, _کیلس, _পহিল, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb0c02d3,0xcb6400a8,0x09e010fc,0x212000b5}},	//   _libë, _таре_, _морн, kdkh_, 
   {{0x27e82026,0x399c00c6,0x00000000,0x00000000}},	//   šana_, físe_, --, --, 
   {{0x362401d3,0x8cd40037,0x2000012d,0x9344007b}},	//   _گواہ, बरतो, jtki_, لخدم, 
   {{0x39442027,0x7338016c,0xb3542028,0x534400c7}},	//   _homs_, узор_, скош, рхиа, 
   {{0x39442029,0xe6b401d5,0x8ab4010f,0x2000202a}},	//   _koms_, _المگ, יליג_, etki_, 
   {{0x3f5402b5,0x39440024,0xdb0c0240,0x20000010}},	//   _räua_, _joms_, _bibë, ftki_, 
   {{0x7afc05a1,0x3944202b,0x399c01e7,0xd414072d}},	//   _ocrt, _moms_, císe_, _خباث, 
   {{0x3944202c,0x27f80217,0xb8d8031c,0xdb0c0240}},	//   _loms_, _åsne_, _ཛུ_, _dibë, 
   {{0xaa040316,0x39440b4f,0x2000012d,0x00000000}},	//   _रहेछ_, _ooms_, atki_, --, 
   {{0x3944202d,0xac1800f7,0xa3cc202e,0xdb0c0200}},	//   _noms_, лобу_, षीक_, _fibë, 
   {{0xdb0c007f,0x3168009d,0x299800d1,0x00000000}},	// [1b10] _kibè, _imaz_, ﯘﺭﭼﻪ_, --, 
   {{0x2ef4202f,0x7afc00db,0x0ac4010b,0x00000000}},	//   _узор, _ccrt, рщам, --, 
   {{0x39440793,0x6f140407,0x49a40e92,0x00000000}},	//   _boms_, mezc, ајда, --, 
   {{0xdb0c2030,0x39442031,0x6f142032,0xe85802e8}},	//   _libè, _coms_, lezc, лаеш_, 
   {{0xdbd4010e,0xec34010f,0x00000000,0x00000000}},	//   _käýe, _האָר_, --, --, 
   {{0xd7ec2033,0x6f142034,0x2d88054e,0x8704011c}},	//   ركى_, nezc, loae_, ряде, 
   {{0x31682035,0x3944014a,0xaa5819ba,0x00000000}},	//   _omaz_, _foms_, _сиву_, --, 
   {{0x39442036,0x2000033f,0x2d88003a,0x26c80115}},	//   _goms_, ytki_, noae_, ŝao_, 
   {{0xa8242037,0xe2b401c6,0xf9640345,0xa85401f4}},	//   _دکان, йснэ, _بۆنێ, _укач, 
   {{0xda0c0c4c,0xb9e002d3,0x36d42038,0xdb0c036e}},	//   _सहमत_, _እብ_, _моур, _ribë, 
   {{0xe69403dd,0x6f140154,0xdb0c020c,0xdb040124}},	//   _الاد, dezc, _dibè, _pukú, 
   {{0x67202039,0xa5340276,0x2258033f,0x2600002e}},	//   _halj, _ынеч, ąsk_, móo_, 
   {{0x6720203a,0x24f80022,0x260017bb,0xa878010f}},	//   _kalj, _анҵы_, lóo_, ראָר, 
   {{0x2000203b,0x67200bc9,0x9e640131,0x00000000}},	//   rtki_, _jalj, مازن, --, 
   {{0x6720203c,0x3eac203d,0x2000203e,0xaea800c6}},	//   _malj, ädt_, stki_, لطفل_, 
   {{0x7afc05be,0x5f74203f,0x00000000,0x00000000}},	//   _scrt, _گابر, --, --, 
   {{0x67200b21,0x39442040,0x02d8000d,0x00000000}},	// [1b20] _oalj, _roms_, _मजाभ, --, 
   {{0x39442041,0x67202042,0x5f741056,0x26001bce}},	//   _soms_, _nalj, _دابر, kóo_, 
   {{0x2600172e,0x394404cc,0x4f200139,0x61e0036e}},	//   jóo_, _poms_, _эдэб, nsll, 
   {{0xdb0c043b,0x98d82043,0xe1900092,0xdcfc0166}},	//   _mibé, اباز_, _ማኅበሩ_, _tupı, 
   {{0x67201368,0xdb0c2044,0x39442045,0x06cc015b}},	//   _balj, _libé, _voms_, _রাজি, 
   {{0x7afc07f5,0x78180037,0x00000000,0x00000000}},	//   _ucrt, _धनीक_, --, --, 
   {{0x39442046,0xdb0c0ba1,0x260000e8,0x61e002d0}},	//   _toms_, _ribè, góo_, jsll, 
   {{0x6720002d,0xdb0c00db,0x00000000,0x00000000}},	//   _ealj, _sibè, --, --, 
   {{0x672002d3,0x38600e89,0xded40092,0x00000000}},	//   _falj, ùird_, ራሩን_, --, 
   {{0x69c02047,0x8c180302,0x67202048,0x26000077}},	//   _élec, נויי, _galj, bóo_, 
   {{0x71782049,0xc1b401c6,0x01c401d3,0x00000000}},	//   ибор_, йлэх_, یویٹ_, --, 
   {{0xdb0c204a,0xd138204b,0x1b0400fe,0x00000000}},	//   _dibé, ухо_, ৰাটে_, --, 
   {{0xc058204c,0x6f140407,0xdb0c204d,0x63b800a2}},	//   бір_, tezc, _tibè, _guwn, 
   {{0x80dc0729,0xc0580845,0x3f640138,0x00000000}},	//   _ভাণ্, сію_, птсб, --, 
   {{0x65b40f8b,0x6f14204e,0xdb0c204f,0x00000000}},	//   _tšhe, rezc, _gibé, --, 
   {{0x63b80054,0x1aa80183,0x0c84013d,0x5dac0ef6}},	//   _yuwn, খুৱা, бызм, _ﺳﺎﻧﺴ, 
   {{0xdb0c020c,0x88d4015b,0x68fc00a2,0x00000000}},	// [1b30] _zibé, _হালক, _ösdi, --, 
   {{0x8aa406ed,0x2d54003b,0x00000000,0x00000000}},	//   бред, _gåen_, --, --, 
   {{0xdb242050,0x2bb40490,0x9ed80032,0x26000077}},	//   تولی, _अंका, _өмөт_, xóo_, 
   {{0xe8542051,0x01f8010f,0xe6d02052,0x00000000}},	//   يناد, רפאל, हर्ज, --, 
   {{0x67202053,0x26002054,0x29d40216,0x1b0400fe}},	//   _palj, wóo_, sťa_, ৰাজে_, 
   {{0x27e82055,0x2fc8089c,0x78a400e4,0x00000000}},	//   šano_, _mtag_, ýiva, --, 
   {{0x39a80139,0x63b80210,0x00000000,0x00000000}},	//   _aşsu_, _suwn, --, --, 
   {{0x6720094a,0xdb0c2056,0x2fc82057,0xd1dc0023}},	//   _walj, _ribé, _otag_, ዓወተ_, 
   {{0x67202058,0xdb0c2059,0x2fc80070,0x25e405f9}},	//   _talj, _sibé, _ntag_, _टिकी_, 
   {{0x97000075,0x399c00d2,0x442001e4,0x51f400ec}},	//   _يېنى, mísa_, ĉj_, ڊسٽر, 
   {{0xe298205a,0x4424205b,0x2fc801f5,0x00000000}},	//   ран_, _گراف, _atag_, --, 
   {{0x2d5401bf,0x00000000,0x00000000,0x00000000}},	//   _såen_, --, --, --, 
   {{0xa2e4205c,0x2bb4205d,0xdef80184,0x399c00d2}},	//   _долд, _अंगा, һың_, nísa_, 
   {{0xdb0c205e,0x20e8004d,0x3d0c012c,0x61e0036e}},	//   _tibé, ời_, ड्ने_, psll, 
   {{0xdef8205f,0x61442060,0x2fc80048,0x290c013f}},	//   лың_, _мека, _etag_, _obea_, 
   {{0x2fc8030d,0x68e82061,0x00000000,0x00000000}},	//   _ftag_, _nded, --, --, 
   {{0x2d54072b,0xdb5001f7,0xccb00139,0x80a800eb}},	// [1b40] _tåen_, وَر_, дәрь, _ক্র্, 
   {{0x68e82062,0x3f540036,0x290c054e,0x4c640276}},	//   _aded, _käum_, _abea_, циун_, 
   {{0x1d082063,0x9d442064,0x19f80276,0x2fc8022e}},	//   _кени_, _денд, рэзь_, _ztag_, 
   {{0x98480032,0x290c0076,0x19880022,0x00000000}},	//   ияла_, _cbea_, шбеи_, --, 
   {{0x68e82065,0x3ce00218,0x57a42066,0xbd880451}},	//   _dded, maiv_, ошка, _ننڍن_, 
   {{0x68e82067,0xc950035b,0x3ce001e7,0x00000000}},	//   _eded, зтәы, laiv_, --, 
   {{0xda0c2068,0x3178012d,0xe7b000db,0x8a00009b}},	//   _सहित_, ynsz_, رۅمد, _озре, 
   {{0x3ce0007f,0x73d801b9,0xc5a401c8,0xd9540244}},	//   naiv_, бдир_, يُون_, _بنرخ, 
   {{0x8d58008f,0xd3782069,0x00000000,0x00000000}},	//   יכקי, ичо_, --, --, 
   {{0x3ce001d4,0x68e80419,0x27f8007c,0x00000000}},	//   haiv_, _zded, _åsna_, --, 
   {{0x2fc8206a,0x20100100,0x68e801bf,0x00000000}},	//   _stag_, _apyi_, _yded, --, 
   {{0xdbd00e2d,0xca480150,0x00000000,0x00000000}},	//   _küät, _ﻁﻠﺏ_, --, --, 
   {{0xad2406ba,0x06cc0183,0xb37c0092,0x00000000}},	//   ۋىسى, _ৰাতি, ኖረውን_, --, 
   {{0xdb0c025a,0x8de81b15,0x0cd0206b,0xdc780092}},	//   _sibî, ифба_, तर्म, _ተመራጭ_, 
   {{0x2010007f,0x25fc070f,0x7f940107,0x4ea401a9}},	//   _epyi_, रूपी_, фарх, юрма, 
   {{0x2fc8206c,0x8d7401ed,0x3da4206d,0xe8d80037}},	//   _ttag_, زازا, друб, _ढ़ेच, 
   {{0x0ca8206e,0x2fc8003e,0x00000000,0x00000000}},	// [1b50] ртви_, _utag_, --, --, 
   {{0x399c066a,0x88d4015b,0x68e80042,0x63bc0162}},	//   vísa_, _হাইক, _sded, ísni, 
   {{0xdb0c01d3,0x68e80200,0x00000000,0x00000000}},	//   óján, _pded, --, --, 
   {{0x26c40204,0x7ec001e1,0x00000000,0x00000000}},	//   _sflo_, _tàpó, --, --, 
   {{0xdd380375,0x5d380375,0x25fc07af,0x00000000}},	//   _הערכ, _התרא, रूनी_, --, 
   {{0x94f40327,0x399c03b2,0xf748009a,0x00000000}},	//   བུའི_, rísa_, يلني_, --, 
   {{0x3b6401d9,0xe618013e,0x0cbc00eb,0x00000000}},	//   _تێلہ, ёди_, েণীত, --, 
   {{0xded4206f,0x3f540036,0xd90c01d9,0x68e82070}},	//   _ኪዳን_, _räum_, _میٔ_, _uded, 
   {{0x2cb800b5,0xdb0400a2,0xb50800f7,0x9fe400eb}},	//   _mgsd_, _luký, تۉنۅ_, _পঙ্গ, 
   {{0x26c4014b,0xe694035b,0x36d400f3,0x00000000}},	//   _uflo_, _еизы, _жофр, --, 
   {{0x232800c2,0x46680a5b,0xff8400a2,0xf0880115}},	//   _ҳоли_, _трам_, _üçiň_, _ענ_, 
   {{0xe2982071,0x9f400316,0xd24c06f6,0xdb14007f}},	//   _қай_, mské_, انَ_, npyò, 
   {{0x9f40031d,0x23281159,0xa3e40d2e,0x3ce004cc}},	//   lské_, _голи_, _फिट_, vaiv_, 
   {{0x442c0f89,0x80cc2072,0x443c0003,0x00000000}},	//   _irg_, _थ्रे, mxu_, --, 
   {{0x9f400300,0x2bb41533,0x442c0263,0xd24c2073}},	//   nské_, _अंजा, _hrg_, _منو_, 
   {{0x442c06df,0xa6c00154,0xe0d802e8,0xbac003d4}},	//   _krg_, উরিট, _уви_, ইৰাছ, 
   {{0x52dc000e,0x27e82074,0x00000000,0x00000000}},	// [1b60] _মাতৃ, šanj_, --, --, 
   {{0x8b202075,0x797c007f,0x3ce00332,0x3db002dd}},	//   ндуе, tčwo, saiv_, _ﺳﯟﯨﻘ, 
   {{0x9f400122,0x00000000,0x00000000,0x00000000}},	//   jské_, --, --, --, 
   {{0x442c2076,0x9f4002fd,0x18a42077,0x78a40022}},	//   _org_, dské_, паем, ýivo, 
   {{0x69c00085,0x98a42078,0xdbd0013d,0x443c0327}},	//   _élen, чиде, _qüät, jxu_, 
   {{0x2b14030d,0xdb0c00e5,0x00000000,0x00000000}},	//   _оьср, _kibí, --, --, 
   {{0x442c2079,0xded41e38,0x443c1bce,0x8b000118}},	//   _arg_, _ኪዳነ_, exu_, ářec, 
   {{0x442c207a,0xceb006a9,0xd76401d3,0x00000000}},	//   _brg_, עיה_, _کارٹ, --, 
   {{0x442c01c7,0x443c207b,0xd1d00092,0xe7b00137}},	//   _crg_, gxu_, ያዙት_, رۅۅد, 
   {{0x442c207c,0x3254207d,0x9f400216,0x99880118}},	//   _drg_, двор, bské_, _krbů_, 
   {{0x442c207e,0x443c00e8,0x5ee000cc,0x00000000}},	//   _erg_, axu_, বলাই, --, 
   {{0x65b4207f,0x443c030d,0x463800c8,0x442c0115}},	//   _tšha, bxu_, _לעבע, _frg_, 
   {{0xc0582080,0xdb0c007b,0x4fc42081,0x94200131}},	//   пір_, _aibí, ясна, _سوغۇ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x80dc00bd,0x2cb8020b,0x00000000,0x00000000}},	//   _ভার্, _pgsd_, --, --, 
   {{0xebd800a7,0x00000000,0x00000000,0x00000000}},	//   ждаш_, --, --, --, 
   {{0x7bc0004a,0xdb0401e1,0x9f40022a,0x0ba818fd}},	// [1b70] _émul, _nukó, zské_, مائى_, 
   {{0x8aa42082,0xdcec0882,0x7ac42083,0x14f800eb}},	//   пред, ākār, есце, ্যয়ী_, 
   {{0x70542084,0xaa182085,0xd8c801f2,0x25a800d0}},	//   _رنگا, تياط_, _ịpịr, ňali_, 
   {{0x9f400232,0xdb042086,0xf99000ec,0x443c0175}},	//   vské_, _zukü, هبن_, yxu_, 
   {{0x443c2087,0x7c84014b,0x00000000,0x00000000}},	//   xxu_, _зуре, --, --, 
   {{0x9f4003c6,0xaae00927,0x49b82088,0x00000000}},	//   tské_, _फ़िक, _هارد_, --, 
   {{0x442c1570,0x60c40267,0xe6180212,0x88b401af}},	//   _srg_, yckm, іди_, _еҫер_, 
   {{0x442c2089,0x9f400e96,0x443c05f5,0x36180212}},	//   _prg_, rské_, txu_, яцію_, 
   {{0xdb1000e4,0x6d5c01ef,0x80dc00eb,0x00000000}},	//   _ágãr, _mlsa, _ভাল্, --, 
   {{0xa1c4163b,0x04fc00bd,0x9f40012c,0x443c208a}},	//   мбод, ্যের_, pské_, rxu_, 
   {{0x6d5c208b,0xd76401d5,0xf99001d3,0x00000000}},	//   _olsa, _تنلی, _شبہ_, --, 
   {{0x442c0f03,0xdb040005,0xdb0c01e7,0x00000000}},	//   _trg_, _yukó, _ribí, --, 
   {{0x442c208c,0x443c208d,0xdb0c0419,0x00000000}},	//   _urg_, qxu_, _sibí, --, 
   {{0x6d5c208e,0xd24c04d3,0x671c0210,0x00000000}},	//   _alsa, انێ_, फ़िक_, --, 
   {{0xf1a8208f,0x00000000,0x00000000,0x00000000}},	//   تایه_, --, --, --, 
   {{0x2d942090,0xb3800023,0x00000000,0x00000000}},	//   ерус, _ዕብዳን_, --, --, 
   {{0x71242091,0x9f500ad9,0x1b48013e,0x00000000}},	// [1b80] _سريل, ðbót_, озаи_, --, 
   {{0x6d5c2092,0xda6400c6,0x00000000,0x00000000}},	//   _elsa, واضي, --, --, 
   {{0x69c001ed,0x09e001d5,0xd94400d4,0x00000000}},	//   _élel, вохн, межи, --, 
   {{0xed0401ec,0x00000000,0x00000000,0x00000000}},	//   _كوپپ, --, --, --, 
   {{0x1b200022,0x48e000a7,0xca680150,0x00000000}},	//   _иҟаҳ, точв, дiгi, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x16dc01ad,0x00000000,0x00000000,0x00000000}},	//   _नजीब, --, --, --, 
   {{0x98a40228,0x73d80209,0x77a40ba1,0xddcc00e5}},	//   _жибе, пдир_, dòxe, nzbő, 
   {{0x15e81098,0xd824084c,0x46cc043e,0x00000000}},	//   _टिकर_, _юдаи, _स्वह, --, 
   {{0xc87c2093,0x00000000,0x00000000,0x00000000}},	//   üşen_, --, --, --, 
   {{0x5504022e,0x00000000,0x00000000,0x00000000}},	//   _жчла, --, --, --, 
   {{0xdb0c05da,0x00000000,0x00000000,0x00000000}},	//   _libà, --, --, --, 
   {{0x85002094,0x93442095,0x81c80154,0x00000000}},	//   _شوون, _онде, _লিঃ_, --, 
   {{0xb8e00489,0x4508025c,0xb8d0031c,0xcdd82096}},	//   _གཔ_, _གཡོར_, _ནཻ_, жња_, 
   {{0x42f8123b,0x00000000,0x00000000,0x00000000}},	//   _והוס, --, --, --, 
   {{0xd24c0014,0xcfb401ec,0x00000000,0x00000000}},	//   _منڈ_, _ﺼﺎﺩﻗ, --, --, 
   {{0xada400d1,0x3d9401f4,0x00000000,0x00000000}},	// [1b90] даңл, титр, --, --, 
   {{0x6a740174,0xca4401ec,0x00000000,0x00000000}},	//   _nýfø, _ﺘﻀﺭ_, --, --, 
   {{0x6f040055,0x386001c3,0x6d5c03e0,0x65a400e5}},	//   _ichc, ùirn_, _tlsa, lóhe, 
   {{0x69c006fd,0xfaa42097,0x6e24036b,0x4508025c}},	//   _élem, тшун, _ishb, _གཡེར_, 
   {{0xe7382098,0xbef82099,0x7cd8010b,0x2ee0209a}},	//   зел_, _عریض_, _юмяр_, _kehf_, 
   {{0x61340724,0x6604209b,0xd8200b7e,0x84780023}},	//   _külä, епка, удши, _ይስማዕ_, 
   {{0xe6101da4,0x09040588,0x556000d1,0x00000000}},	//   اشت_, _очам, گۇنك, --, 
   {{0x69c4209c,0x65a400e5,0x23d41771,0x39a401a9}},	//   mqhe, kóhe, нцор, _ашув, 
   {{0x291c209d,0x96c803f3,0xdb0c00dd,0x67d400ee}},	//   mewa_, _स्कॉ, _hibá, _чозу, 
   {{0x291c209e,0x65b41ebd,0xb714005b,0x00000000}},	//   lewa_, _tšho, _идущ, --, 
   {{0x69c4209f,0xb1d80108,0xf1b80327,0x00000000}},	//   nqhe, мьях_, wwġa_, --, 
   {{0x291c20a0,0x6f0401b9,0x00000000,0x00000000}},	//   newa_, _achc, --, --, 
   {{0x25ac20a1,0xdb0c043b,0x6e2420a2,0x00000000}},	//   mmel_, _libá, _ashb, --, 
   {{0x291c20a3,0x61340598,0x25ac20a4,0x2328013e}},	//   hewa_, _bülä, lmel_, _хоки_, 
   {{0x291c20a5,0x61340139,0x8fa00276,0x00000000}},	//   kewa_, _cülä, уаре, --, 
   {{0x291c20a6,0x6f0402d0,0x69c40175,0xdb14005b}},	//   jewa_, _echc, dqhe, npyö, 
   {{0x291c20a7,0xd00c14a0,0xf1a803e6,0x6e2401a9}},	// [1ba0] dewa_, _هلي_, _تاوه_, _eshb, 
   {{0xe62407ae,0x25ac0327,0x31c40166,0xddcc00e5}},	//   _đông_, hmel_, _ясәв, szbő, 
   {{0x291c20a8,0x9f400030,0x613420a9,0x2d840165}},	//   fewa_, nskí_, _gülä, élec_, 
   {{0x291c20aa,0x399c20ab,0x00000000,0x00000000}},	//   gewa_, mísk_, --, --, 
   {{0x7bc420ac,0x31040882,0x779420ad,0xb9080073}},	//   qqiu, ष्टः_, نیرا, _मज_, 
   {{0x4508025c,0xdb140108,0x25ac0135,0x61340139}},	//   _གཡུར_, epyö, emel_, _yülä, 
   {{0x291c20ae,0x888001ec,0xd7040166,0x65a400e5}},	//   bewa_, _ұлтж, _үзби, zóhe, 
   {{0x07a00831,0x291c20af,0x058020b0,0x25ac005c}},	//   _ҡатн, cewa_, луым, gmel_, 
   {{0x17840022,0x00000000,0x00000000,0x00000000}},	//   _згам, --, --, --, 
   {{0x25ac08cd,0xd6280261,0x62f00022,0xb35400f5}},	//   amel_, _нозе_, аҧшт, ткош, 
   {{0x941c00ac,0x74140214,0xcb10011a,0x00000000}},	//   _ərəb_, روگا, אלת_, --, 
   {{0x25d81060,0x02a020b1,0x6f0404cc,0xff2004ce}},	//   _آهنگ_, ырым, _schc, _rayと, 
   {{0x6e240022,0x4084010b,0x613420b2,0x00000000}},	//   _sshb, гурб, _sülä, --, 
   {{0x291c20b3,0x9f4000d7,0x399c032e,0x00000000}},	//   zewa_, bskí_, físk_, --, 
   {{0xbe8820b4,0x291c20b5,0xdb0c005c,0x61340139}},	//   есте_, yewa_, _kibæ, _qülä, 
   {{0x429800d9,0xb03407a5,0x00000000,0x00000000}},	//   _מסוב, _аниш, --, --, 
   {{0x291c004c,0xfbd0009a,0x320c0432,0x00000000}},	// [1bb0] vewa_, متل_, ltdy_, --, 
   {{0x6e2401ee,0x63ac011c,0x61340724,0x291c20b6}},	//   _tshb, _èant, _tülä, wewa_, 
   {{0x291c20b7,0x6e24006c,0x7af8022c,0x25ac0109}},	//   tewa_, _ushb, óvta, ymel_, 
   {{0xa6dc00cc,0x00000000,0x00000000,0x00000000}},	//   _ঠাইট, --, --, --, 
   {{0x291c20b8,0xe72805f5,0xc770004e,0xaee40055}},	//   rewa_, долд_, лткө, ceṣy, 
   {{0x291c20b9,0x36e80a52,0x9ba00075,0x00000000}},	//   sewa_, ىرىپ_, _نەقى, --, 
   {{0x291c20ba,0x966018d9,0x25ac20bb,0x048c01e1}},	//   pewa_, икше, tmel_, _àjẹs, 
   {{0xd5ac20bc,0x847401e1,0x3f5401c7,0x9f4000d0}},	//   يفو_, _aáwẹ, _häut_, vskí_, 
   {{0x25ac20bd,0x9f400c67,0xac9401f3,0xc1b40588}},	//   rmel_, nskã_, _ሙስሊም_, қәкы, 
   {{0xdd0000f3,0x25ac072b,0xdb14005b,0x9f4000d0}},	//   _čučk, smel_, spyö, tskí_, 
   {{0x36d409fe,0x96c803f3,0x2ba8000d,0x320c00a2}},	//   _сохр, _स्टॉ, _कठना, gtdy_, 
   {{0x27e811f9,0x27ec0183,0x399c20be,0x9f4000d0}},	//   šanu_, _kven_, vísk_, rskí_, 
   {{0xd24c20bf,0x9f400004,0x84740248,0x25fc033f}},	//   منی_, jskã_, _fáwẹ, रूरी_, 
   {{0x7bc006ed,0x399c20c0,0x00000000,0x00000000}},	//   _émui, tísk_, --, --, 
   {{0xdd9020c1,0x81c8009e,0xc1e00150,0xc10401e0}},	//   لوس_, _লিক_, _حۋجي, _йүнл, 
   {{0x20540025,0x399c20c0,0x1cb4031c,0x160003ce}},	//   _атор, rísk_, _ཝུད_, रंतर_, 
   {{0xa068011c,0x9c2420c2,0x00000000,0x00000000}},	// [1bc0] _цапа_, ъдад, --, --, 
   {{0xddc40022,0xfe7801c6,0xc1b400c7,0x386001ab}},	//   _ибои, _зүг_, _шәҿы, ùirm_, 
   {{0x27ec20c3,0x6bd404da,0x5908005b,0x00000000}},	//   _aven_, نتەر, деем_, --, 
   {{0x77a40ba1,0x795402f2,0x00000000,0x00000000}},	//   dòxa, دێرا, --, --, 
   {{0x1e1c1ee0,0x27ec03cd,0x81ac0154,0x4c8002e8}},	//   _ስልጠና, _cven_, কআপ_, _вляв, 
   {{0x7d0420c4,0x7c2420c5,0xb6c800e5,0x00000000}},	//   lgis, mwir, راتے_, --, 
   {{0x27ec20c6,0x3f5401c7,0x7c2420c7,0x160002a0}},	//   _even_, _häus_, lwir, रंधर_, 
   {{0x699420c8,0x00000000,0x00000000,0x00000000}},	//   _брух, --, --, --, 
   {{0x7c2420c9,0x7d0420ca,0x27ec0e04,0x81c80154}},	//   nwir, igis, _gven_, _লিগ_, 
   {{0x1cb40135,0xe8f8016c,0x7c240810,0x3f540036}},	//   _ཝུན_, _олӣ_, iwir, _mäus_, 
   {{0x7c2420cb,0x7d0400fb,0x27ec0010,0x27e820cc}},	//   hwir, kgis, _zven_, šant_, 
   {{0x7c2420cd,0x09d402a6,0x4270130f,0x00000000}},	//   kwir, _হিমা, ргюс, --, 
   {{0x27ec067c,0x752001f7,0x7c2420ce,0x320c0466}},	//   _xven_, memz, jwir, stdy_, 
   {{0x69c00395,0x7c2420cf,0x9f400c67,0xc32c0050}},	//   _èleg, dwir, vskã_, _وٕن_, 
   {{0x313420d0,0x7dc401b9,0x7c24002f,0x00000000}},	//   _бейр, иётд, ewir, --, 
   {{0x2d54037e,0x7c24002f,0x00000000,0x00000000}},	//   _nået_, fwir, --, --, 
   {{0x7c241813,0x7c9400c6,0x3cf801ad,0xaf600092}},	// [1bd0] gwir, لشكا, एलजे_, _ማገልገ, 
   {{0x9f400004,0x7658023a,0x317820d1,0xf3f403d4}},	//   rskã_, kyvy, lisz_, _অহাৰ_, 
   {{0x7c24090c,0x6f0000a3,0xe8f8013d,0x00000000}},	//   awir, òlcu, енеч_, --, 
   {{0x7c240537,0x13c80183,0x9f4002fd,0x31781f6f}},	//   bwir, লীয়, mská_, nisz_, 
   {{0x9f4004bf,0x78240a2c,0xcbb40220,0x65a420d2}},	//   lská_, لعول, _ағаш_, jóha, 
   {{0xbdf820d3,0xdb0c0724,0xdb040793,0x00000000}},	//   _ثریا_, _cibä, _sukö, --, 
   {{0x9f4003c6,0x2d54019b,0xdb0c0793,0x00000000}},	//   nská_, _fået_, _dibä, --, 
   {{0x2d54019b,0xa52412d7,0x27ec003b,0x8a74014b}},	//   _gået_, умид, _tven_, _зиҳӣ_, 
   {{0x27ec009a,0xe70420d4,0xe3b820d5,0x95b4035b}},	//   _uven_, _مسای, нби_, ыршә, 
   {{0x611820d6,0x399c09f3,0x7d040790,0xdb0c0139}},	//   _mālō, vísi_, zgis, _gibä, 
   {{0x9f400313,0x2d980ac8,0x7520014b,0x7c240099}},	//   jská_, _okse_, bemz, zwir, 
   {{0x9f400122,0xf53000c6,0x7c240042,0x00000000}},	//   dská_, _وإن_, ywir, --, 
   {{0x7d0420d7,0x645c03cd,0xa07401ec,0x00000000}},	//   vgis, øsid, уынш, --, 
   {{0x2d982005,0x57d00ed1,0x7c240bd7,0x3f5401c7}},	//   _akse_, ﻟﺪﯨﺮ, vwir, _räus_, 
   {{0x31780034,0x7d0420d8,0x00000000,0x00000000}},	//   bisz_, tgis, --, --, 
   {{0x7c2420d9,0x3178033f,0x1278010f,0x7d0420da}},	//   twir, cisz_, _ראקע, ugis, 
   {{0x8c4020db,0x5ba820dc,0x2120003e,0x81c8009e}},	// [1be0] бете, екам_, mekh_, _লিট_, 
   {{0x200020dd,0x7c2420de,0x2d9805ac,0x9f400216}},	//   muki_, rwir, _ekse_, bská_, 
   {{0x7c2420df,0x200020e0,0x2d980270,0x752001f7}},	//   swir, luki_, _fkse_, yemz, 
   {{0xd7e820e1,0x588420e2,0x200001af,0x7c2402ce}},	//   емде_, лыла, ouki_, pwir, 
   {{0x200020e3,0x1d98001f,0x8d94001f,0x7c240309}},	//   nuki_, _መብቶች_, _መጥቷል_, qwir, 
   {{0x2d5420e4,0xdbd00037,0x3178012d,0x765820e5}},	//   _fåes_, _müüt, zisz_, tyvy, 
   {{0x200020e6,0x06cc0c58,0x795403e6,0xdbd00254}},	//   huki_, _ৰাখি, _پێشا, _lüüt, 
   {{0x200020e7,0xd90c20e8,0x550420e9,0x00000000}},	//   kuki_, _ریت_, учка, --, 
   {{0xe97020ea,0x12e420eb,0x200020ec,0x9f400306}},	//   _بۇند, лінг, juki_, zská_, 
   {{0x200020ed,0x7520021a,0x3178033f,0x926803c5}},	//   duki_, semz, wisz_, ерма_, 
   {{0x362400dd,0x5fbc01ad,0x069002dd,0x5dc80150}},	//   _خواہ, _एंजल, _ﭘﺎﻳﯩ, _ﻓﺎﻻﺴ, 
   {{0x9f400232,0x200020ee,0x6ae0033f,0x32400023}},	//   vská_, fuki_, _फ़्र, _ንዘለኣ, 
   {{0x69c020ef,0xb4e020f0,0x9f4002f0,0xc1740108}},	//   _élev, थरी_, wská_, слящ, 
   {{0x9f400232,0x3178068f,0x00000000,0x00000000}},	//   tská_, sisz_, --, --, 
   {{0x3178006d,0x21200472,0x4380007b,0xd06006be}},	//   pisz_, bekh_, _دلوق, _ərən, 
   {{0x9f400232,0x200020f1,0xac180114,0x00000000}},	//   rská_, buki_, кобу_, --, 
   {{0x200020f2,0x6b7420f3,0xab740117,0x00000000}},	// [1bf0] cuki_, алау, агаш, --, 
   {{0x9f4000bc,0x952c0327,0x00000000,0x00000000}},	//   pská_, _ྩིའི_, --, --, 
   {{0xb36802d3,0x4290001f,0x8aa420f4,0xdd9001d9}},	//   _ሽወደን_, _ማንነት_, урад, _ژوپ_, 
   {{0x65b40f8b,0x2d9800c5,0x00000000,0x00000000}},	//   _tšhi, _ukse_, --, --, 
   {{0x6d4c20f5,0x0af0009d,0x00000000,0x00000000}},	//   mjaa, _гүзэ, --, --, 
   {{0x6d4c20f6,0x28d4134e,0x5c78010f,0x77840024}},	//   ljaa, _ड्रि, _יארה, бліз, 
   {{0x200020f7,0xff58010f,0x6d4c0e03,0x34c001e1}},	//   zuki_, רבוך_, ojaa, _ẹdọ_, 
   {{0x6d4c20f8,0x2000105c,0x69d420f9,0x00000000}},	//   njaa, yuki_, _itze, --, 
   {{0x13e40724,0x7bc00098,0x20000208,0x6d4c005b}},	//   амый_, _émut, xuki_, ijaa, 
   {{0x200019a2,0xc984036b,0xdbd000af,0x466802bf}},	//   vuki_, _руҳи, _rüüt, _прем_, 
   {{0x216820fa,0x21c40374,0xdbd000af,0x6d4c057b}},	//   вини_, _kēhi_, _süüt, kjaa, 
   {{0x200020fb,0x6d4c20fc,0x80dc015b,0xdbd000c5}},	//   tuki_, jjaa, _ভাঙ্, _püüt, 
   {{0x324002d3,0x6d4c01f5,0x21200083,0x656801ab}},	//   _ንዘልኣ, djaa, rekh_, mheh, 
   {{0x200020fd,0x263404fe,0x6d4c20fe,0x212001b3}},	//   ruki_, _kāo_, ejaa, sekh_, 
   {{0x200020ff,0xdea001d5,0x6d4c017a,0x925400f0}},	//   suki_, تیدی, fjaa, _вајт_, 
   {{0x6d4c2100,0x21c40374,0xdd902101,0xdbd000c5}},	//   gjaa, _nēhi_, آور_, _tüüt, 
  
   {{0x6448172e,0x69d40323,0x20000944,0x00000000}},	// [1c00] nxei, _atze, quki_, --, 
   {{0x6d4c2102,0x0b402103,0x64480d2a,0x5f74143e}},	//   ajaa, онун, ixei, _خابر, 
   {{0x6d4c0254,0x4ef8011a,0x00000000,0x00000000}},	//   bjaa, _בליג, --, --, 
   {{0xd7f82104,0x3f982105,0x394002d1,0xd23800df}},	//   вук_, loru_, ñis_, כגעל, 
   {{0x38602106,0x65682107,0x69d42108,0x00000000}},	//   áir_, dheh, _etze, --, 
   {{0x3f982109,0x35b40131,0x00000000,0x00000000}},	//   noru_, әбир, --, --, 
   {{0x25fc1d94,0x964405f5,0x386015ad,0x12c40066}},	//   रंगी_, рэлд, šir_, یتدپ, 
   {{0x3f980316,0xa6e80016,0x65680280,0x74140597}},	//   horu_, _ngươ, gheh, موبا, 
   {{0x0680210a,0x5344210b,0x3374013e,0x00000000}},	//   йгән, ахна, йгир, --, 
   {{0x4494210c,0x96940262,0x69d4002d,0x847c0023}},	//   рвью_, _креш, _ytze, _ዕድመን_, 
   {{0x69c0066d,0x3f98210d,0x65680472,0xe7b4210e}},	//   _élet, doru_, bheh, _اللھ, 
   {{0x92d4045e,0x5064210f,0x65682110,0x00000000}},	//   িণে_, атга, cheh, --, 
   {{0x938806bb,0xd0700023,0xa594009f,0x00000000}},	//   _иска_, _ኣድላዩ_, _اُنڪ, --, 
   {{0x09d400bd,0x3f982111,0x6d4c0cf9,0xc0ec0092}},	//   _হিসা, goru_, wjaa, _ኅዳር_, 
   {{0x6d4c2112,0xfeb801f7,0xadd40063,0x720401e2}},	//   tjaa, لافت_, собљ, _اوعم, 
   {{0x7d68036b,0x658000b0,0x417400f1,0x06cc03d4}},	//   ашув_, tēhi, _وايس, _ৰাছি, 
   {{0x6d4c2113,0x21c402b5,0x4ae80108,0x00000000}},	// [1c10] rjaa, _rēhi_, вьем_, --, 
   {{0x6d4c2114,0x3f9819f5,0x658002b1,0x8cb800dc}},	//   sjaa, coru_, rēhi, _शृणो, 
   {{0x21c40374,0x6d4c01f5,0x7a300332,0x00000000}},	//   _pēhi_, pjaa, vótá, --, 
   {{0x658002b5,0x797c00b0,0xb4e002c3,0x00000000}},	//   pēhi, tōwa, थरो_, --, 
   {{0x6c842115,0x7c84084c,0x2fc8003e,0x63a02116}},	//   _طلسم, _дуре, _juag_, ylln, 
   {{0x2fc80190,0xa7a82117,0x65a400e5,0xbd9c0092}},	//   _muag_, ыкла_, tóho, _ሀብታም_, 
   {{0x6568052f,0x2fc80190,0xd6cc2118,0x21c400b0}},	//   theh, _luag_, رقي_, _tēhi_, 
   {{0x79942119,0x3afc0ca8,0xf42000fe,0xd6b80154}},	//   _дисф, _tápà_, বিনৰ_, ুরূপ, 
   {{0x64480005,0x65680108,0x7958022e,0x00000000}},	//   uxei, rheh, _титр_, --, 
   {{0x6568211a,0x68e8211b,0x63a00194,0x3f9800e8}},	//   sheh, _heed, ulln, xoru_, 
   {{0x63a00998,0x68e8211c,0x26c40010,0x69c001d3}},	//   rlln, _keed, _iglo_, _éles, 
   {{0x68e80a81,0x656801ee,0x3f98211d,0x63a00175}},	//   _jeed, qheh, woru_, slln, 
   {{0x3f98211e,0x3438211f,0x68e82120,0x2fc80457}},	//   toru_, _پسند_, _meed, _cuag_, 
   {{0x68e82121,0x358c044e,0xdcf4007f,0xfe4401c6}},	//   _leed, _ሕቶታት_, riyč, омгү, 
   {{0xdee4036b,0x25fc2122,0xdef82123,0x00000000}},	//   _қони, रंटी_, кың_, --, 
   {{0x68e80c3e,0x3f982124,0x290c2125,0x00000000}},	//   _need, soru_, _ncea_, --, 
   {{0x3f980588,0x26c401fa,0x8c4010e2,0x2fc80076}},	// [1c20] poru_, _oglo_, пете, _guag_, 
   {{0x290c084c,0x00000000,0x00000000,0x00000000}},	//   _acea_, --, --, --, 
   {{0xcf540d65,0x68e80548,0x2fc80211,0x0f5400c8}},	//   _הבית_, _beed, _zuag_, _היים_, 
   {{0x26c4010f,0x2fc80211,0x68e80009,0x290c2126}},	//   _aglo_, _yuag_, _ceed, _ccea_, 
   {{0x290c0175,0x68e82127,0xf77800c7,0x00000000}},	//   _dcea_, _deed, аҧа_, --, 
   {{0x07b4007b,0x99e800f2,0x482000db,0x00000000}},	//   مهنة_, _معرق_, سىىق, --, 
   {{0x68e82128,0xdb2400aa,0x75880023,0x00000000}},	//   _feed, _پوځی, _ዝህልዎ_, --, 
   {{0x68e82129,0xf3f8006c,0xf8b8212a,0x26c402f0}},	//   _geed, аниш_, _көл_, _eglo_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x68e8212b,0x2fc80441,0x721809ac,0xe80c1c54}},	//   _zeed, _ruag_, ажор_, _समता_, 
   {{0x68e8212c,0x2130003e,0xcb9804ae,0x2d8401d3}},	//   _yeed, _bayh_, רסיט, élek_, 
   {{0x2fc80457,0x68e8058a,0x00000000,0x00000000}},	//   _puag_, _xeed, --, --, 
   {{0x2fc80218,0x5434212d,0x91c80fc8,0xf2c4212e}},	//   _quag_, _درار, _संवै, _мөни, 
   {{0x2fc80070,0xdb0c05ac,0x5694030d,0x00000000}},	//   _vuag_, _gibø, _таçт, --, 
   {{0xad240075,0x43d001e2,0xcd340240,0x00000000}},	//   يىسى, _وڅیړ, _ብሽክለ, --, 
   {{0x2fc8212f,0x21301529,0x6ed801f9,0xed0405af}},	//   _tuag_, _gayh_, _ब्रँ, تورپ, 
   {{0x68e82130,0x636c2131,0x31680200,0x00000000}},	// [1c30] _reed, _dúnf, _ilaz_, --, 
   {{0x3168030a,0x68e82132,0x25f8000d,0x7c842133}},	//   _hlaz_, _seed, _ईटली_, чусе, 
   {{0x39440175,0x636c0241,0x31680165,0x68e82134}},	//   _bnms_, _fúnf, _klaz_, _peed, 
   {{0x9f50007f,0x68e80429,0xe91802bf,0xad4000f7}},	//   _avyè_, _qeed, роді_, _تۉرۉ, 
   {{0xbae800bd,0x2d880381,0x68e82135,0x316804a7}},	//   _পারছ, mnae_, _veed, _mlaz_, 
   {{0xe7382136,0xadec05f9,0x68e80e21,0x7c700092}},	//   рек_, _जबान_, _weed, ቸግራል_, 
   {{0x636c2137,0x68e82138,0x2d882139,0xfb84213a}},	//   _húng, _teed, onae_, _хыян, 
   {{0x2d88213b,0xa9080014,0x636c0248,0x290c0356}},	//   nnae_, _خٲرٕ_, _kúng, _ucea_, 
   {{0x25fc130b,0x2d88213c,0x386008c2,0x00000000}},	//   रूजी_, inae_, ùirt_, --, 
   {{0x31680166,0xa5f8213d,0xe3580484,0x50cc0055}},	//   _alaz_, _вежу_, ршиш_, _ānāṃ_, 
   {{0xe124213e,0x2d88213f,0x31680156,0x7af803b2}},	//   омни, knae_, _blaz_, óvti, 
   {{0x24182140,0x65780493,0xd1c40006,0x614400d8}},	//   _воды_, _umwh, ўляе_, цема, 
   {{0x2d880493,0x1fa801b9,0x9f400419,0x00000000}},	//   dnae_, икми_, mskú_, --, 
   {{0x2d882141,0x3168013d,0x658002b5,0x9f4000d0}},	//   enae_, _elaz_, rēhu, lskú_, 
   {{0x316804cc,0x3eac2142,0x82200327,0x8fa02143}},	//   _flaz_, ådt_, _འགྲི_, фаре, 
   {{0x2d881730,0x9f4001f1,0x31680156,0x636c02d2}},	//   gnae_, nskú_, _glaz_, _búng, 
   {{0x636c007b,0x442c02d2,0x00000000,0x00000000}},	// [1c40] _cúng, _jsg_, --, --, 
   {{0x2d8816b8,0x9f04158b,0x636c0332,0x1dd02144}},	//   anae_, _بودو, _dúng, _दंपत, 
   {{0x442c0263,0xb6040139,0x636c2145,0x63bc0419}},	//   _lsg_, _kráş, _túnf, ísny, 
   {{0x9f4000d0,0x28d409ab,0x00000000,0x00000000}},	//   jskú_, डुलि, --, --, 
   {{0x636c2146,0x9f400419,0x87d0027d,0x00000000}},	//   _gúng, dskú_, وغوا, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x636c0022,0x5f1000dc,0x645c2147,0x6724000d}},	//   _múnd, _तान्_, øsin, õhja, 
   {{0x200001a9,0x29d401a9,0x00000000,0x00000000}},	//   krki_, _хўрс, --, --, 
   {{0x17840064,0x00000000,0x00000000,0x00000000}},	//   _дгам, --, --, --, 
   {{0x636c002d,0x8c180375,0xb27400d8,0x00000000}},	//   _núnd, סויי, злош, --, 
   {{0x31682148,0x8b00012c,0x9f4000d7,0x20002149}},	//   _plaz_, _úřed, bskú_, erki_, 
   {{0x442c04cc,0x77a4004e,0xdc3803e0,0x00000000}},	//   _fsg_, dòxi, hçıv, --, 
   {{0x31680165,0xe73001d3,0x00000000,0x00000000}},	//   _vlaz_, _غصے_, --, --, 
   {{0xd2580798,0x00000000,0x00000000,0x00000000}},	//   _вци_, --, --, --, 
   {{0x442c0076,0x2d880393,0x636c214a,0x2000012d}},	//   _zsg_, tnae_, _dúnd, arki_, 
   {{0x31680b91,0x200005be,0xc0d0001f,0x442c0142}},	//   _ulaz_, brki_, ጥቷል_, _ysg_, 
   {{0xfbd0214b,0x636c214c,0x2d88214d,0xa114004b}},	// [1c50] نتل_, _fúnd, rnae_, _رسيږ, 
   {{0x636c214e,0x8aa4214f,0xdcf40882,0x2d880493}},	//   _gúnd, оред, riyā, snae_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd5a4015e,0xdeb40375,0x636c032e,0xd36400f1}},	//   _سف_, _מפתח_, _túng, _ړه_, 
   {{0x5f1000dc,0x9cd402e4,0xef3402d3,0x9f400030}},	//   _ताम्_, _מורה_, _ብምድል, vskú_, 
   {{0x442c05e4,0xd24400c6,0x00000000,0x00000000}},	//   _rsg_, _كن_, --, --, 
   {{0x81ac009e,0x442c03e0,0x9f400030,0x37a8010b}},	//   _কংস_, _ssg_, tskú_, цтцн_, 
   {{0x442c2150,0x636c003a,0x20000ad9,0x09bc031c}},	//   _psg_, _múne, yrki_, _གངྒ_, 
   {{0x02c4036b,0x9f4000d0,0xa7742151,0xf48400d8}},	//   оқли_, rskú_, _елач, дуќн, 
   {{0x468007d6,0x86f0009f,0x00000000,0x00000000}},	//   _оқла, _آياچ, --, --, 
   {{0xe2982152,0xd24c04d3,0x636c00c6,0x26cc0618}},	//   сан_, ۆنی_, _rúnd, āloā_, 
   {{0x442c2153,0xd24c004b,0xe2980124,0x00000000}},	//   _tsg_, چنی_, иаҿ_, --, 
   {{0x55502154,0x645c2155,0xd24c2156,0x442c2157}},	//   _سپور, äsid, ننی_, _usg_, 
   {{0xdc3803be,0x77a4004e,0x80a0043e,0x5438010f}},	//   xçıv, tòxi, _गुणे, _לענא, 
   {{0x75f80139,0x6ac000eb,0xa49001e2,0x81a801e2}},	//   _gäzā, শুতো, _تیښت, _وضعې_, 
   {{0xbae82158,0x77a4004e,0xadec012d,0x636c01e1}},	//   _পাইছ, ròxi, _जबरन_, _wúnd, 
   {{0x5bc42159,0x636c0248,0x00000000,0x00000000}},	// [1c60] سقال, _túnd, --, --, 
   {{0x636c215a,0x9cc8215b,0x2f1401d3,0x10380375}},	//   _fúne, рыңа_, rúgó_, _פגיע, 
   {{0x069000d1,0xeb5400cf,0x00000000,0x00000000}},	//   _ﭘﺎﻛﯩ, بىلگ, --, --, 
   {{0x25700008,0x9f04006c,0xad24215c,0x00000000}},	//   _hálf_, _بوگو, _قىپى, --, 
   {{0xe7f4012c,0x645c0158,0x1cb801e2,0x00000000}},	//   ुंगा_, øsil, _دادب_, --, 
   {{0x50180302,0x636c002d,0x00000000,0x00000000}},	//   מונו, _lúnb, --, --, 
   {{0xc71400f1,0x00000000,0x00000000,0x00000000}},	//   ستوئ_, --, --, --, 
   {{0x1dbc00dc,0x7afc0175,0xd91800f1,0x18680672}},	//   ्दित, _hdrt, _ديرش_, _лаби_, 
   {{0x186800c7,0x00000000,0x00000000,0x00000000}},	//   _уааи_, --, --, --, 
   {{0xb4ac038e,0xb4bc0574,0xca7402d3,0x00000000}},	//   _गरी_, _आणी_, በርኩም_, --, 
   {{0x1dbc215d,0x00000000,0x00000000,0x00000000}},	//   ्दात, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2448215e,0x00000000,0x00000000,0x00000000}},	//   _وجهي_, --, --, --, 
   {{0x645c01f4,0x00000000,0x00000000,0x00000000}},	//   äsie, --, --, --, 
   {{0x7f94215f,0xd24401c6,0x3134004e,0x4ad0000d}},	//   харх, _хэли, _жейр, _तलबव, 
   {{0x646400ee,0xad242160,0x65a401d3,0x8d74029e}},	//   _ätiý, بىرى, tóhi, سازا, 
   {{0x0dc8039b,0x01342161,0x0ca8030d,0x00000000}},	// [1c70] руҳи_, _سعيد, стви_, --, 
   {{0x83680201,0x65a401ed,0x3f840098,0x61f4013d}},	//   _ስለዚህ_, róhi, émut_, _äglä, 
   {{0x6e94084c,0xadb4005b,0xcfa80244,0x00000000}},	//   _цину, _обош, _پاکم_, --, 
   {{0x636c00d2,0xdd902162,0xb4bc01f9,0x00000000}},	//   _kúnc, _لوپ_, _आणू_, --, 
   {{0xf7702163,0x19c00b8d,0xf9900691,0x69c000f2}},	//   گان_, тәрг, دبل_, _èlem, 
   {{0x80a007f7,0x8038011a,0x00000000,0x00000000}},	//   _ऐडसे, פנוע_, --, --, 
   {{0x95d40724,0x797c02b1,0x00000000,0x00000000}},	//   үдәт_, kōwh, --, --, 
   {{0xdbcc06be,0xa96802f2,0x8a740117,0x00000000}},	//   _qıçl, _بمرم_, _диҳӣ_, --, 
   {{0x291c009a,0x636c0241,0x00000000,0x00000000}},	//   mfwa_, _rúnb, --, --, 
   {{0xe1f82164,0x066400dd,0x65a41d0e,0xa90c000d}},	//   ого_, _ٹائپ, jóhv, _हाँफ_, 
   {{0xdb0c007f,0x85440276,0x00000000,0x00000000}},	//   _kibò, _нэде, --, --, 
   {{0x291c2165,0xdb0c0139,0x00000000,0x00000000}},	//   nfwa_, _sibü, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2ce80327,0xd42400ec,0x68ec0162,0x00000000}},	//   _འབུབ, _آڻين_, ðadj, --, 
   {{0x291c2166,0x636c2167,0x02a401c0,0x7094001f}},	//   kfwa_, _túnb, _эрдм, _ያድርጉ_, 
   {{0x61e000db,0x27e80306,0x00000000,0x00000000}},	//   mpll, šany_, --, --, 
   {{0x672002ae,0x1fb42168,0xdbd40724,0x3f840393}},	// [1c80] _oblj, _осор, _mäçe, émus_, 
   {{0xbb5403e6,0x40e80244,0x00000000,0x00000000}},	//   رۆزب, _بوکێ_, --, --, 
   {{0x7afc0010,0x00000000,0x00000000,0x00000000}},	//   _vdrt, --, --, --, 
   {{0x2d8401d3,0xdbd4010b,0x8c0800fe,0x00000000}},	//   élet_, _näçe, ৰিজন_, --, 
   {{0xb4ac038e,0x60240134,0x87d42169,0x257003b2}},	//   _गरे_, _wɔmf, وبوس_, _máld_, 
   {{0x7afc0010,0x00000000,0x00000000,0x00000000}},	//   _udrt, --, --, --, 
   {{0x8b000316,0xb0a4216a,0x745400e5,0x1a640244}},	//   _úřad, _गुनग, کھائ, _تیای_, 
   {{0xd8241b88,0x743412e7,0x05b4216b,0x86b001ec}},	//   _одби, ениф, وديت_, тәуі, 
   {{0x160007f7,0xe8041431,0x00000000,0x00000000}},	//   रूजर_, _रिया_, --, --, 
   {{0xd7f80022,0x7980035a,0x32540454,0xd6280798}},	//   _гуҧ_, _hmmw, евор, _мозе_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe7f40034,0x80a0076e,0xe8040709,0x00000000}},	//   ुंचा_, _गुहे, _रिमा_, --, 
   {{0xc0c8084c,0x00000000,0x00000000,0x00000000}},	//   дуре_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x79800083,0x490c121d,0x4390216c,0xc32c00d1}},	//   _ommw, _डालो_, _шашс, _ئەپ_, 
   {{0x9f4002fd,0x320c010e,0x00000000,0x00000000}},	//   mský_, mudy_, --, --, 
   {{0x9f4004bf,0x320c216d,0xdb0c0ba1,0xf41c015b}},	// [1c90] lský_, ludy_, _ribò, তিকর_, 
   {{0x636c00d2,0x7980216e,0x257003b2,0x00000000}},	//   _kúna, _ammw, _tálg_, --, 
   {{0xdeb0005e,0x9f400e96,0x257000e4,0x291c216f}},	//   _бұры, nský_, _hále_, tfwa_, 
   {{0x4adc2170,0x2d8c0de2,0x645c03cd,0xdd10010e}},	//   _प्रव, _ñee_, øsik, müşi, 
   {{0x291c2171,0x636c0597,0xba742172,0x9d1800c8}},	//   rfwa_, _lúna, _یافت, _צושט, 
   {{0x79800337,0x00000000,0x00000000,0x00000000}},	//   _emmw, --, --, --, 
   {{0x6d5c2173,0x9f400122,0x25700241,0xe61800d4}},	//   _kosa, jský_, _lále_, їди_, 
   {{0x6d5c2174,0x9f400122,0x6b84022e,0x320c00a2}},	//   _josa, dský_, lihg, dudy_, 
   {{0x6d5c2175,0x4ad00073,0xe36400cf,0x00000000}},	//   _mosa, _तलाव, екпи, --, 
   {{0x6d5c2176,0x27ec020c,0x636c09f3,0x67200010}},	//   _losa, _iwen_, _búna, _ublj, 
   {{0x636c00c6,0x69c8020c,0xf7700075,0x27ec0156}},	//   _cúna, _kiee, _ئاق_, _hwen_, 
   {{0x6d5c2177,0x27ec2178,0x636c007b,0xa3d42179}},	//   _nosa, _kwen_, _dúna, _зодч, 
   {{0x27ec0699,0x6568217a,0x00000000,0x00000000}},	//   _jwen_, mkeh, --, --, 
   {{0x27ec13ca,0x443c217b,0x9f40217c,0x25700316}},	//   _mwen_, mvu_, bský_, _dále_, 
   {{0x6d5c217d,0x27ec217e,0x443c217f,0x63a02180}},	//   _bosa, _lwen_, lvu_, moln, 
   {{0x6d5c2181,0x69c82182,0x27ec2183,0x63a0022e}},	//   _cosa, _niee, _owen_, loln, 
   {{0x6d5c2184,0x443c2185,0x41ac033f,0x65680022}},	// [1ca0] _dosa, nvu_, _टीएस, ikeh, 
   {{0x6d5c02d0,0x443c2186,0x3ab40131,0x90980375}},	//   _eosa, ivu_, вәбт, _מספק, 
   {{0x6d5c2187,0x69c802ea,0x65682188,0x27ec2189}},	//   _fosa, _biee, kkeh, _awen_, 
   {{0x443c04b9,0x6d5c218a,0x27ec0295,0x69c806d1}},	//   kvu_, _gosa, _bwen_, _ciee, 
   {{0x69c8218b,0x63a0218c,0x9f4000bc,0x656800d7}},	//   _diee, koln, zský_, dkeh, 
   {{0x6d5c055a,0x27ec218d,0x443c00d2,0x69c80076}},	//   _zosa, _dwen_, dvu_, _eiee, 
   {{0x69c80270,0x6d5c218e,0x27ec218f,0x443c2190}},	//   _fiee, _yosa, _ewen_, evu_, 
   {{0x9f4003c6,0x27ec0097,0x09d41c82,0x636c2191}},	//   vský_, _fwen_, _হিচা, _rúna, 
   {{0x443c022c,0x636c03b2,0x00000000,0x00000000}},	//   gvu_, _súna, --, --, 
   {{0x320c2192,0x9f400232,0x07a00139,0x63a02193}},	//   tudy_, tský_, _баун, goln, 
   {{0x27ec083a,0x69c80066,0x443c2194,0x257002fb}},	//   _zwen_, _yiee, avu_, _sále_, 
   {{0x9f402195,0x443c2196,0x65682197,0xb4840032}},	//   rský_, bvu_, ckeh, _икеһ, 
   {{0x63a02198,0x09d403d4,0x443c0051,0x00000000}},	//   boln, _হিছা, cvu_, --, 
   {{0x6d5c2199,0x63a0219a,0x9f40219b,0x636c219c}},	//   _sosa, coln, pský_, _túna, 
   {{0x636c219d,0x25700248,0x5f1001f9,0x00000000}},	//   _kúnn, _wále_, _तार्_, --, 
   {{0xd13805f5,0x6d5c219e,0xd6b0009e,0x257000d7}},	//   _ххк_, _qosa, _চলায, _tále_, 
   {{0x6d5c219f,0xc0f40023,0x00000000,0x00000000}},	// [1cb0] _vosa, ፍኦም_, --, --, 
   {{0x6d5c21a0,0x65680419,0x00000000,0x00000000}},	//   _wosa, zkeh, --, --, 
   {{0x6d5c21a1,0x69c821a2,0x27ec21a3,0x443c21a4}},	//   _tosa, _piee, _swen_, zvu_, 
   {{0x27ec21a5,0x443c21a6,0x6d5c21a7,0xfaa421a8}},	//   _pwen_, yvu_, _uosa, ушун, 
   {{0xfe7004d3,0x69c8002f,0x0c840139,0xdce4002b}},	//   _ندێ_, _viee, _чынм, _ulkā, 
   {{0x443c1418,0x00000000,0x00000000,0x00000000}},	//   vvu_, --, --, --, 
   {{0x63a021a9,0xe80c07f7,0x65680419,0x00000000}},	//   voln, _समका_, tkeh, --, 
   {{0x63a0068f,0x27ec007f,0x636c0332,0x64a4004e}},	//   woln, _twen_, _cúnn, кайа, 
   {{0x65680639,0x67d421aa,0x636c0241,0x27ec21ab}},	//   rkeh, _розу, _dúnn, _uwen_, 
   {{0x443c21ac,0x656821ad,0x934021ae,0xd5a407d6}},	//   rvu_, skeh, анье, _یللی, 
   {{0x443c21af,0x2c1c015b,0xf7d008b0,0x636c0ca8}},	//   svu_, নিয়ে_, ﮕﯩﻠﻪ, _fúnn, 
   {{0x98a40421,0x636c0248,0x63a021b0,0x00000000}},	//   leoā_, _gúnn, soln, --, 
   {{0x63a00f72,0xb0a421b1,0x42c0015b,0x6620000d}},	//   poln, _गुदग, োরেশ, _महुए_, 
   {{0x25ac21b2,0xffa405f5,0xf1b40131,0xe2c800f7}},	//   llel_, улгү, _ﭼﯩﻘﻘ, _قوشو_, 
   {{0x25ac21b3,0x539802e4,0x8e8021b4,0x00000000}},	//   olel_, _קיצו, агре, --, 
   {{0xd00c00b2,0xe04421b5,0x00000000,0x00000000}},	//   _ڀلي_, _ании, --, --, 
   {{0x91b80375,0x636c0419,0x00000000,0x00000000}},	// [1cc0] _קמפי, _júno, --, --, 
   {{0x25ac21b6,0x832c031c,0x9f400174,0x9e64014b}},	//   hlel_, _ཨིསུ_, rskó_, _авод, 
   {{0xefe00092,0x25ac0139,0x00000000,0x00000000}},	//   ናየው_, klel_, --, --, 
   {{0x588421b7,0xa3d021b8,0x00000000,0x00000000}},	//   кыла, वदा_, --, --, 
   {{0x7d0801e1,0x636c01e1,0x25ac21b9,0x00000000}},	//   _eèrà, _rúnn, dlel_, --, 
   {{0x636c1941,0x25ac0254,0xa9c400cf,0x00000000}},	//   _súnn, elel_, _ۅزقو, --, 
   {{0xd5b821ba,0x645c21bb,0x25ac05d5,0x75d4143e}},	//   мси_, äsin, flel_, ديبا, 
   {{0x25ac21bc,0x3dc00100,0x69b40037,0x00000000}},	//   glel_, nmiw_, ेषणी, --, 
   {{0x92ac00fe,0xd0e021bd,0x18a400c7,0x41cc00c5}},	//   _কলে_, _क्षण_, _раам, _संउस, 
   {{0x31bc0b7c,0x45d00022,0x00000000,0x00000000}},	//   ोद्ध, ыцәт, --, --, 
   {{0xcb100302,0xdb0c0793,0x23780023,0x25ac0156}},	//   בלת_, _fibö, ësja_, blel_, 
   {{0x3a380f85,0x82a00022,0x00000000,0x00000000}},	//   _msrp_, ршье, --, --, 
   {{0x3a3800a3,0x636c0248,0x8fe000fb,0x00000000}},	//   _lsrp_, _kúnl, шәйҙ, --, 
   {{0x69c000f2,0x00000000,0x00000000,0x00000000}},	//   _èlev, --, --, --, 
   {{0x636c00c6,0xc33002e4,0x43800345,0x257021be}},	//   _múnl, _כוס_, _خلوق, _hála_, 
   {{0x518421bf,0x257021c0,0x4638010f,0xb1140114}},	//   _шула, _kála_, ועלע, _смиш, 
   {{0x3cd421c1,0x636c01e1,0xd1f80023,0x00000000}},	// [1cd0] ржус, _oúnl, ጋእቲ_, --, 
   {{0x3a38009a,0x257021c2,0xf3f41c82,0x201c0276}},	//   _bsrp_, _mála_, _আমাৰ_, ătit_, 
   {{0x257000d2,0xe8041f14,0x3dc00455,0xdb080162}},	//   _lála_, _रिहा_, bmiw_, ínái, 
   {{0x3a3805da,0x67d421c3,0x00000000,0x00000000}},	//   _dsrp_, году, --, --, 
   {{0x6024016b,0x2d881730,0x4b500014,0x31b802f0}},	//   _kɔma, miae_, _پێار, céze_, 
   {{0x2d880483,0x6f140097,0x636c0332,0x00000000}},	//   liae_, ngzc, _cúnl, --, 
   {{0x25ac0770,0x6ab402d0,0x00000000,0x00000000}},	//   tlel_, _uzzf, --, --, 
   {{0x224804b9,0x2d880483,0x257021c4,0x61e4062c}},	//   _čak_, niae_, _bála_, _çhli, 
   {{0x69d421c5,0x257000d2,0x636c01e1,0x25ac21c6}},	//   _huze, _cála_, _fúnl, rlel_, 
   {{0x68f821c7,0x25ac0122,0x69d421c8,0x2570007b}},	//   lawd, slel_, _kuze, _dála_, 
   {{0x69d421c9,0xa18821ca,0xa1c421cb,0xe28421cc}},	//   _juze, ебна_, лбод, улни, 
   {{0x69d421cd,0x9f5c012c,0x257001e7,0x68f821ce}},	//   _muze, čtí_, _fála_, nawd, 
   {{0x69d421cf,0x2d881730,0x701802dd,0x4ac00b98}},	//   _luze, diae_, кірт_, वेतव, 
   {{0xe29821d0,0x02c00724,0x69d40156,0x9ea821d1}},	//   _пал_, _килү, _ouze, евга_, 
   {{0x3eac037e,0x2d8821d2,0xe80c0034,0xab68012d}},	//   ædt_, fiae_, _समझा_, zyżó, 
   {{0x2d881730,0x3a380334,0xdd10010e,0xdca4011c}},	//   giae_, _rsrp_, _düşu, габи, 
   {{0x1c4421d3,0x69d421d4,0x68f821d5,0xf1a802f2}},	// [1ce0] ынам, _auze, dawd, _جاوه_, 
   {{0x69d421d6,0x3a3801f7,0xe80c0073,0x23b80241}},	//   _buze, _psrp_, _समजा_, bèje_, 
   {{0xd94421d7,0x69d40165,0x2d8816b8,0x636c0241}},	//   лежи, _cuze, biae_, _rúnl, 
   {{0x69d421d8,0x2d881730,0x68f821d9,0x00000000}},	//   _duze, ciae_, gawd, --, 
   {{0xb6c801ed,0x645c0108,0x00000000,0x00000000}},	//   ھاتے_, äsil, --, --, 
   {{0x69d421da,0x07a021db,0xc7a01920,0xb6c800e5}},	//   _fuze, бачн, бичк, پاتے_, 
   {{0x2a3400a8,0x69d421dc,0x257021dd,0xea6421de}},	//   _кэтр, _guze, _sála_, _پھلی, 
   {{0x636c007b,0x68f80067,0x2570032e,0x049801e1}},	//   _dúnm, cawd, _pála_, _ìlọr, 
   {{0x69d4152d,0x349421df,0x938821e0,0x337421e1}},	//   _zuze, рапр, есна_, игир, 
   {{0x69d40dd4,0x28b800a8,0x2d88003a,0x257003b2}},	//   _yuze, _русэ_, ziae_, _vála_, 
   {{0x3938001f,0x636c01e1,0x60c80213,0x2d88003a}},	//   _በምዕራ, _gúnm, əlmə, yiae_, 
   {{0x25700085,0x76480175,0x2d880381,0xd13821e2}},	//   _tála_, _irdy, xiae_, ххо_, 
   {{0x2d8816b8,0x645c21e3,0x00000000,0x00000000}},	//   viae_, øsit, --, --, 
   {{0x44781a4c,0x84140375,0x00e400d1,0x00000000}},	//   _אנדע, _עקוב_, _ﺋﯩﺸﻘ, --, 
   {{0x2d880483,0x1b180154,0x636c0cad,0x024001f7}},	//   tiae_, ড়াই_, _oúnj, _هَوَ, 
   {{0x6024016b,0x2d880393,0x00000000,0x00000000}},	//   _wɔma, uiae_, --, --, 
   {{0x2d880de4,0x31780175,0x00000000,0x00000000}},	// [1cf0] riae_, mhsz_, --, --, 
   {{0x2d880483,0xadd80124,0x68f80083,0x23b8007f}},	//   siae_, _имоу_, wawd, pèje_, 
   {{0x2d8816b8,0x6fdc015b,0x68f821e4,0x69d403e3}},	//   piae_, _বিয়ে, tawd, _quze, 
   {{0x8880035c,0x69d421e5,0x636c0ca8,0xb33c0135}},	//   میزن, _vuze, _rúnm, koħo, 
   {{0x68f8006d,0x764821e6,0x636c0248,0x0ca821e7}},	//   rawd, _ardy, _dúnj, _سطحي_, 
   {{0x68f800a9,0x69d421e8,0x186421e9,0x645c0f23}},	//   sawd, _tuze, раши_, äsim, 
   {{0x7f3c00c8,0x636c0248,0x6f0402e2,0x9ba021ea}},	//   געוו, _fúnj, _mdhc, _بەلى, 
   {{0xd3440b28,0x49b80214,0x68f8014f,0xb4e40051}},	//   یینه_, _سازد_, qawd, _nhàđ, 
   {{0x27fc0369,0x44280ba1,0xe7041d0a,0x00000000}},	//   qswn_, ïc_, _نسای, --, 
   {{0xe3b000c6,0x2d980010,0x636c21eb,0x00000000}},	//   غرة_, _ljse_, _túnm, --, 
   {{0xc5f401b9,0x2b4001e7,0x67240254,0x37c401f7}},	//   _ёғи_, idhc_, õhju, _ايلف, 
   {{0xd24c107f,0xe04406b3,0xa0680640,0xf6f00241}},	//   بچه_, анми, вама_, _iṣẹt, 
   {{0xdfa421ec,0x30740064,0x320c21ed,0x10a000cf}},	//   لحسي, бурс, ardy_, жиян, 
   {{0x25700241,0x30740108,0x60d000ef,0x00000000}},	//   _kálo_, суюс, _ņemā, --, 
   {{0x0fc000d6,0x9cf421ee,0x00000000,0x00000000}},	//   ійсн, ичаш, --, --, 
   {{0x257004bf,0xaaa80cb4,0xdcb021ef,0x00000000}},	//   _málo_, _कड़क, قىز_, --, 
   {{0x25700241,0x9f40007c,0x5ba800f5,0x8c4000c7}},	// [1d00] _lálo_, dskö_, вкам_, оете, 
   {{0xdcf406b9,0x00000000,0x00000000,0x00000000}},	//   ıcın, --, --, --, 
   {{0x19f800a8,0x629c002f,0x00000000,0x00000000}},	//   тэзь_, ßsoh, --, --, 
   {{0x636c04d4,0x5ca4033a,0x4e2400db,0x00000000}},	//   _búnk, _вимб, _тоюн_, --, 
   {{0x97c421f0,0x31b80306,0x888001c6,0x00000000}},	//   айде, néza_, олцж, --, 
   {{0x636c002d,0x320c0209,0xdb50009f,0x257001ef}},	//   _dúnk, yrdy_, _بَس_, _bálo_, 
   {{0x31b8019f,0xf62800cf,0x00000000,0x00000000}},	//   héza_, اتتۇ_, --, --, 
   {{0x636c21f1,0x00000000,0x00000000,0x00000000}},	//   _fúnk, --, --, --, 
   {{0x68ec056a,0xa9980395,0xd4980395,0x00000000}},	//   ñade, _сърф_, ърк_, --, 
   {{0x33740108,0x68f400d7,0x00000000,0x00000000}},	//   сгор, ľadň, --, --, 
   {{0x0bb40302,0x200c0618,0x6f040175,0xa2c801bc}},	//   שלים_, _āfia_, _rdhc, _हृद्, 
   {{0x672c041a,0xc68c01d9,0x00000000,0x00000000}},	//   đaje, _تِم_, --, --, 
   {{0x49040490,0x5434009f,0x00000000,0x00000000}},	//   हणतो_, _خرار, --, --, 
   {{0x35a002d3,0x00000000,0x00000000,0x00000000}},	//   _ውህበት_, --, --, --, 
   {{0x59a421f2,0x9f4001f4,0x00000000,0x00000000}},	//   गकार, yskö_, --, --, 
   {{0x6c840736,0x37ac0154,0x00000000,0x00000000}},	//   ملزم, গগির, --, --, 
   {{0x7cd801ca,0x31b800d7,0x8f08030d,0x3d180037}},	// [1d10] рмур_, céza_, _ихна_, _फारे_, 
   {{0x8ae410f5,0xac9421f3,0x6fb400f1,0xaa5800f3}},	//   ріал, _ҳамш, _دمخا, лизу_, 
   {{0x1fe0015b,0x636c01e1,0x00000000,0x00000000}},	//   _বিএস, _súnk, --, --, 
   {{0x2b40037e,0x645c0793,0x2bd821f4,0xac9401c6}},	//   sdhc_, äsik, _ماسک_, _гамш, 
   {{0x66e421f5,0x3f8400e8,0x257001e1,0x41d00b98}},	//   бола, ëmug_, _sálo_, _संघस, 
   {{0xdc3804ac,0x8038008f,0x77840212,0x00000000}},	//   _געשר, ינדע_, оліз, --, 
   {{0x8234001f,0xb9e40212,0x4ac021f6,0x00000000}},	//   _ይካሄዳ, _міти, वेशव, --, 
   {{0xe29821f7,0x636c000f,0x17e400cc,0x00000000}},	//   ғам_, _túnk, _নিৰি, --, 
   {{0x636c01b8,0x21680aac,0xa2c811bc,0xe5e401ec}},	//   _húni, ҳини_, हेन्, _ﺍﻨﻌﻜ, 
   {{0xc6a421f8,0x36d400d8,0xdcf40166,0x35f81291}},	//   _креи, _дофр, kiyğ, _چرند_, 
   {{0x216821f9,0x636c00dd,0x614421fa,0xe29821fb}},	//   гини_, _júni, бена, ѓам_, 
   {{0x249c0457,0x636c21fc,0x31b80306,0x00000000}},	//   _txwm_, _múni, téza_, --, 
   {{0x64c401d5,0x3ce021fd,0x00000000,0x00000000}},	//   _ايشل, vciv_, --, --, 
   {{0x442c0ac5,0x31b802f0,0x257008ce,0x00000000}},	//   _ipg_, réza_, _málm_, --, 
   {{0x1d0808da,0x2bbc0b8f,0x636c02d2,0x3ce001e7}},	//   леви_, ्गना, _núni, tciv_, 
   {{0x442c0ac5,0x00000000,0x00000000,0x00000000}},	//   _kpg_, --, --, --, 
   {{0x645c005b,0xd11400d9,0x9b0421fe,0x00000000}},	// [1d20] äsih, _הקפה_, йзад, --, 
   {{0x442c21ff,0x636c2200,0x3ce0054e,0x00000000}},	//   _mpg_, _búni, sciv_, --, 
   {{0x20002201,0x25701f60,0x3ce0054e,0x00000000}},	//   lski_, _páll_, pciv_, --, 
   {{0x442c107d,0x6e2000db,0x2000033f,0x636c02d2}},	//   _opg_, àlbe, oski_, _dúni, 
   {{0xf4240003,0xdcb000cf,0x442c0f85,0x00000000}},	//   _འདེད_, _رىس_, _npg_, --, 
   {{0x394002d5,0x20000280,0x7c242202,0xc7a02203}},	//   žis_, iski_, mtir, пичк, 
   {{0x7c242204,0xd9442205,0xe3180156,0x8af806a9}},	//   ltir, _леви, ྱུནཔ_, _תהלי, 
   {{0x442c01c4,0xd5b80a8f,0x200000c5,0x60d40142}},	//   _bpg_, ысл_, kski_, _ngym, 
   {{0x7c242206,0x94a82207,0x442c0b0e,0xb4d82208}},	//   ntir, ытка_, _cpg_, _ाली_, 
   {{0x20000552,0x7c242209,0x2d840077,0x60d40a08}},	//   dski_, itir, élez_, _agym, 
   {{0x7c24006c,0x6024013f,0x442c220a,0x636c00d2}},	//   htir, _dɔmm, _epg_, _lúnw, 
   {{0x442c0077,0x00000000,0x00000000,0x00000000}},	//   _fpg_, --, --, --, 
   {{0x442c0998,0x2bbc00cd,0x00000000,0x00000000}},	//   _gpg_, ्गमा, --, --, 
   {{0x7c24220b,0x60d400dd,0x40341fbe,0x909c0055}},	//   dtir, _egym, џерс, _āśāy, 
   {{0x7c24220c,0x20000254,0x00000000,0x00000000}},	//   etir, aski_, --, --, 
   {{0x7c24220d,0x2000220e,0x636c1d75,0x95f8015b}},	//   ftir, bski_, _rúni, _ইমাম_, 
   {{0xac18220f,0x7c242210,0x442c0798,0xdb681ee0}},	// [1d30] розу_, gtir, _xpg_, _ቱሪዝም_, 
   {{0x636c2211,0x645c0108,0x00000000,0x00000000}},	//   _púni, äsii, --, --, 
   {{0x7c242212,0x25701d0e,0x2bbc00bc,0x60d4010e}},	//   atir, _sálm_, ्गबा, _ygym, 
   {{0xac182213,0x7c242214,0x636c01e1,0x79a400d8}},	//   _кому_, btir, _fúnw, прче, 
   {{0x7c242215,0x636c01e1,0x7c8400d8,0xfb541d37}},	//   ctir, _gúnw, _еуре, تپەد, 
   {{0x636c1427,0x442c2216,0x00000000,0x00000000}},	//   _túni, _rpg_, --, --, 
   {{0xf4240003,0x442c008b,0x65c400f5,0xe80419cc}},	//   _འདུད_, _spg_, обка, _रिका_, 
   {{0x24081ab7,0x20002217,0x442c0042,0xa2c800dc}},	//   ании_, yski_, _ppg_, _हृष्, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa2042218,0xdb1c01a8,0x6384109a,0x00000000}},	//   опод, ympí, ігна, --, 
   {{0x20002219,0x7c2401c0,0xa1b80021,0xe69400c6}},	//   wski_, ztir, иумф_, _بلاد, 
   {{0x200004b9,0x7c24221a,0x6024221b,0x2454221c}},	//   tski_, ytir, _wɔmm, _وناس, 
   {{0x442c1ded,0x8444221d,0x3074013e,0x7c240009}},	//   _upg_, _دخال, пурс, xtir, 
   {{0x2000221e,0xc0cc0201,0x6448221f,0x00000000}},	//   rski_, _በኩል_, mvei, --, 
   {{0xb8fc0867,0x636c01e1,0x9d4401d5,0x00000000}},	//   _རྔ_, _súnw, оевд, --, 
   {{0x20002220,0x5bd00b33,0x00000000,0x00000000}},	//   pski_, तद्व, --, --, 
   {{0x64482221,0x7c240083,0x00000000,0x00000000}},	// [1d40] nvei, utir, --, --, 
   {{0x64482222,0x9b0402dd,0x63ac02d2,0xda64007b}},	//   ivei, ізед, _íand, ياضي, 
   {{0x62802223,0x2f540022,0xcf54011a,0x644810f1}},	//   nzlo, _хтыс, _ובית_, hvei, 
   {{0x6448032e,0x2570032e,0xb4d801ef,0x00000000}},	//   kvei, _dálk_, _ाले_, --, 
   {{0x7c242224,0x68ec0724,0x18342225,0x64482226}},	//   qtir, ñada, تراح, jvei, 
   {{0x636c2227,0x65780165,0xdbcc0724,0x7dd801e4}},	//   _kúnu, _alwh, _tıñl, _eŭse, 
   {{0x7afc2228,0x64482229,0xd9580640,0x628000d7}},	//   _iert, evei, _краљ_, jzlo, 
   {{0x7afc0204,0x1868006c,0x8ebc015b,0x98a4222a}},	//   _hert, _каби_, _আলমগ, _дибе, 
   {{0x7afc222b,0x335400cf,0x644802d2,0x00000000}},	//   _kert, зүлө_, gvei, --, 
   {{0x3944222c,0x7afc222d,0x872800f1,0x7c200166}},	//   _hams_, _jert, _نغمې_, _ämru, 
   {{0x394403a2,0x64481140,0x953c074d,0x00000000}},	//   _kams_, avei, _аслă_, --, 
   {{0x3944222e,0x7afc222f,0x00000000,0x00000000}},	//   _jams_, _lert, --, --, 
   {{0x644804fb,0x7afc0b21,0x25a000d7,0x00000000}},	//   cvei, _oert, éhle_, --, 
   {{0x25a82230,0x7afc2231,0x394400b0,0xb4c82232}},	//   čale_, _nert, _lams_, ोखी_, 
   {{0xccf8026a,0x645c023a,0x628000d7,0x00000000}},	//   ића_, äsiv, czlo, --, 
   {{0x3944005f,0x7afc2233,0x636c03b2,0x7058014b}},	//   _nams_, _aert, _dúnu, _гаир_, 
   {{0x7afc2234,0x7d242235,0x67f001e1,0x6b7405a2}},	// [1d50] _bert, ьфре, _mójò, плау, 
   {{0x39440395,0x31680156,0x00000000,0x00000000}},	//   _aams_, _hoaz_, --, --, 
   {{0x64482236,0x3168030a,0x49a400d8,0x00000000}},	//   zvei, _koaz_, ојда, --, 
   {{0x7afc2237,0x316801c4,0x39442238,0x64482239}},	//   _eert, _joaz_, _cams_, yvei, 
   {{0x66e4223a,0x636c00d2,0x31680198,0x7afc223b}},	//   пола, _kúnt, _moaz_, _fert, 
   {{0xe738223c,0x7afc223d,0x31680165,0xaa58223e}},	//   сек_, _gert, _loaz_, _лигу_, 
   {{0x39440093,0xa8a404d3,0x64480007,0x7768022e}},	//   _fams_, _کڵاو, wvei, _dodx, 
   {{0x7afc223f,0x64482240,0x3944014a,0x3168030a}},	//   _zert, tvei, _gams_, _noaz_, 
   {{0x291c00b5,0xc4440214,0x7afc01a9,0x13e40166}},	//   mgwa_, تیشن_, _yert, пмый_, 
   {{0x64482241,0x25702242,0xd04c00ac,0x628017da}},	//   rvei, _máli_, _ödəm, tzlo, 
   {{0xa91c02d5,0x31682243,0x61440902,0x00000000}},	//   _amži, _boaz_, пена, --, 
   {{0x24181301,0xdcf40882,0x636c0413,0x6280002f}},	//   _годы_, khyā, _rúnu, rzlo, 
   {{0x316801c6,0x25ac2244,0x62802245,0x00000000}},	//   _doaz_, moel_, szlo, --, 
   {{0xdcf40a28,0x636c007b,0x7768058a,0x54640107}},	//   dhyā, _cúnt, _xodx, _хашм_, 
   {{0x291c2246,0x12f80302,0x636c00c6,0x8fa02247}},	//   kgwa_, _ההצב, _dúnt, харе, 
   {{0x7afc2248,0x25ac2249,0xa0a4224a,0x316801c6}},	//   _sert, noel_, _найд, _goaz_, 
   {{0x1fb40276,0x636c01e1,0x9b080aac,0x3944045a}},	// [1d60] _нсор, _fúnt, йнаб_, _rams_, 
   {{0x3944224b,0x636c224c,0x3168009d,0x7afc224d}},	//   _sams_, _gúnt, _zoaz_, _qert, 
   {{0x7afc224e,0x19b8224f,0xaee40882,0x25ac05e4}},	//   _vert, будь_, saṃy, koel_, 
   {{0x7afc2250,0xdcf40a28,0x25ac2251,0x291c2252}},	//   _wert, bhyā, joel_, ggwa_, 
   {{0x25ac2253,0x672c05a1,0x7b8401ec,0xdb1c0332}},	//   doel_, đajn, _قاسە, ampá, 
   {{0x7afc2254,0x636c056a,0x291c2255,0x4cb80375}},	//   _uert, _xúnt, agwa_, _לזכו, 
   {{0x25ac2256,0x67200784,0x9a1005d9,0x4b780a7c}},	//   foel_, _dclj, _سڃاڻ, _פאלו, 
   {{0x25ac0368,0x2a6400a3,0xfcdc0023,0x00000000}},	//   goel_, _àlba_, _ንሕጊ_, --, 
   {{0xb4c806ab,0xb89800e5,0x00000000,0x00000000}},	//   ोखे_, _بھائ_, --, --, 
   {{0x316805c7,0xb27400d8,0x00000000,0x00000000}},	//   _soaz_, длош, --, --, 
   {{0x25ac2257,0x636c08a5,0x00000000,0x00000000}},	//   boel_, _rúnt, --, --, 
   {{0x25ac0687,0x92c02258,0x636c2259,0x95c800d8}},	//   coel_, _ışın, _súnt, _улеб_, 
   {{0x645c225a,0x316805c7,0x636c0124,0x25a80451}},	//   äsit, _voaz_, _púnt, _بدلي_, 
   {{0x3358084c,0x636c02d2,0x0874010f,0x249800d7}},	//   _факэ_, _dúns, לעכט_, úsme_, 
   {{0xae1c1533,0x316805c7,0x25700162,0xfe540006}},	//   बंधन_, _toaz_, _sáli_, нкрэ, 
   {{0xdcf40882,0x2570225b,0x645c01e3,0x00000000}},	//   thyā, _páli_, åsig, --, 
   {{0x636c21eb,0x00000000,0x00000000,0x00000000}},	// [1d70] _gúns, --, --, --, 
   {{0x636c0241,0x257003b2,0x644c0064,0x00000000}},	//   _húnr, _váli_, _šaik, --, 
   {{0x68ec1280,0xe9f80220,0x2d84004a,0x636c110e}},	//   ñado, інді_, èles_, _kúnr, 
   {{0xd244225c,0x2570225d,0xfbd80a17,0xad400228}},	//   _ین_, _táli_, _भूकम, _جۉرۉ, 
   {{0x25ac225e,0x291c020c,0xb4c800e1,0xd24400ec}},	//   voel_, rgwa_, ोखो_, _ڌن_, 
   {{0x25ac0af9,0x00000000,0x00000000,0x00000000}},	//   woel_, --, --, --, 
   {{0x25ac0430,0xe5a4225f,0x0bd00116,0x00000000}},	//   toel_, мики, _ﭘﯘﻗﺮ, --, 
   {{0xc1740198,0x2bbc1df0,0x00000000,0x00000000}},	//   _kiɗe_, ्गवा, --, --, 
   {{0x290c2260,0x68e801e1,0x9420010b,0x25ac030a}},	//   _idea_, _ifed, вмые, roel_, 
   {{0x27ec2261,0xb2f4023a,0xe2980063,0x636c2131}},	//   _iten_, няющ, жао_, _rúns, 
   {{0x25ac2262,0xd5ac2263,0xda7800c8,0xa63402bf}},	//   poel_, طفی_, ַנשר, _інді, 
   {{0x36342264,0x645c023a,0x27e80356,0x00000000}},	//   _سرمس, äsis, ţanu_, --, 
   {{0xd24c2265,0x5f940116,0x00000000,0x00000000}},	//   هنی_, җиңт, --, --, 
   {{0xdfd02266,0x443c2267,0x27ec01e4,0x03c40032}},	//   ئيس_, mwu_, _mten_, _эсем, 
   {{0x443c0943,0x27ec0004,0x9d54182f,0xdef80510}},	//   lwu_, _lten_, ونست, йың_, 
   {{0x290c2165,0x27e80943,0x27ec0428,0x636c2268}},	//   _ndea_, ̭ana_, _oten_, _túns, 
   {{0xed340323,0x27ec2269,0x443c226a,0xa2c80b4c}},	// [1d80] ээрэ, _nten_, nwu_, हेर्, 
   {{0x290c226b,0x68e8226c,0x443c226d,0x00000000}},	//   _adea_, _afed, iwu_, --, 
   {{0x27ec226e,0xddc4023a,0x9cc801ec,0x00000000}},	//   _aten_, _обои, сыңа_, --, 
   {{0x3d1810f7,0x443c05db,0xaac401b9,0x5c14010a}},	//   _फाटे_, kwu_, رتلن, _оьгу, 
   {{0x7d04226f,0x4f8401d9,0x4c6401a9,0x00000000}},	//   mais, _رایہ, _жиян_, --, 
   {{0x7d042270,0x68e80489,0x290c2271,0x443c0135}},	//   lais, _efed, _edea_, dwu_, 
   {{0x27ec2272,0x443c2273,0xa3c02274,0x68e803cb}},	//   _eten_, ewu_, ंतन_, _ffed, 
   {{0x4d78010f,0x6eb004af,0x699400c0,0x5de401ec}},	//   ַריע, _आँसु, _зрух, _ﻋﺎﻤﻴ, 
   {{0x443c05db,0x00000000,0x00000000,0x00000000}},	//   gwu_, --, --, --, 
   {{0x7d042275,0x636c004e,0x00000000,0x00000000}},	//   hais, _búnq, --, --, 
   {{0x7d042276,0x443c0094,0x7e68007c,0x80a800eb}},	//   kais, awu_, ädpl, _গণগ্, 
   {{0x7d042277,0x443c00ca,0xc5f002e4,0x00000000}},	//   jais, bwu_, _ידע_, --, 
   {{0x147400db,0x7d042278,0xb2a80014,0x00000000}},	//   _تااج, dais, تُھم_, --, 
   {{0xc05801ce,0x636c0248,0x00000000,0x00000000}},	//   фію_, _wúnr, --, --, 
   {{0x8d742279,0x7d04227a,0x4240035b,0x3134010b}},	//   وارا, fais, _ахыб, _зейр, 
   {{0x7d04227b,0x7520009f,0xc0cc01f3,0x00000000}},	//   gais, ngmz, በርም_, --, 
   {{0x2bbc227c,0xd7dc07f7,0x9a6c0092,0x00000000}},	// [1d90] ्गला, _फूलच, _በላከው_, --, 
   {{0x25701427,0x27ec0055,0x00000000,0x00000000}},	//   _hált_, _rten_, --, --, 
   {{0xfd1c00c6,0x27ec227d,0x290c0004,0x7e040100}},	//   _ŝάŝ_, _sten_, _pdea_, _pčsň, 
   {{0x7d04227e,0x317801f0,0xe94401d5,0x443c012d}},	//   cais, nksz_, عرای, ywu_, 
   {{0x16700131,0x25700162,0x5d78010f,0x00000000}},	//   ңқур, _mált_, _זארק, --, 
   {{0x9bf8011a,0x00000000,0x00000000,0x00000000}},	//   _מהשט, --, --, --, 
   {{0x443c227f,0x00000000,0x00000000,0x00000000}},	//   wwu_, --, --, --, 
   {{0x443c0034,0x290c2280,0x68e8009f,0xa524013e}},	//   twu_, _udea_, _ufed, хмид, 
   {{0x27ec10f5,0x09c800cd,0x31b801ef,0x00000000}},	//   _uten_, िषीय, cézi_, --, 
   {{0x7d042281,0x443c2282,0x00000000,0x00000000}},	//   zais, rwu_, --, --, 
   {{0x7d042283,0x81e40011,0x25702284,0x00000000}},	//   yais, মীন_, _sálu_, --, 
   {{0xe45000c6,0x00000000,0x00000000,0x00000000}},	//   _مضت_, --, --, --, 
   {{0x7d042285,0xdeb801f3,0x00000000,0x00000000}},	//   vais, ሲውን_, --, --, 
   {{0x7d042286,0x2d842287,0xdfd000ae,0x00000000}},	//   wais, ëlen_, طيز_, --, 
   {{0xb80400dc,0x00000000,0x00000000,0x00000000}},	//   _bhṛś, --, --, --, 
   {{0x80b400d1,0x00000000,0x00000000,0x00000000}},	//   _ۋەھش, --, --, --, 
   {{0x7d040b86,0xdee42288,0xdb1c023a,0x25700aab}},	// [1da0] rais, _попи, ympä, _háls_, 
   {{0x7d042289,0xd9b8228a,0x9b440127,0x24c000cc}},	//   sais, ेष्ट, عناو, _উলাহ, 
   {{0x7d04228b,0x4ef80302,0xb0680d73,0xb5200210}},	//   pais, _מהיו, _فصیل_, _यालय_, 
   {{0x4aac0490,0x25700008,0x18a4228c,0xa9c40066}},	//   _जुळव, _máls_, наем, نزنو, 
   {{0xb8e8130b,0xeaf800d1,0x00000000,0x00000000}},	//   _उर_, سرەت_, --, --, 
   {{0xaee40882,0xdb240248,0x9af4007b,0xa8540166}},	//   raṇy, _àpàp, _سكرت, тешә, 
   {{0x8ba0030d,0x00000000,0x00000000,0x00000000}},	//   _сирж, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x81e4015b,0x320000e8,0x44f00116,0x00000000}},	//   মীম_, _ňiy_, دسىز, --, 
   {{0xecc4228d,0x3f840de2,0x32540454,0x26b000db}},	//   लेटफ, ëmul_, ввор, دەۅز, 
   {{0x067c0ed1,0x00000000,0x00000000,0x00000000}},	//   ﺭﺍﻟﯩ, --, --, --, 
   {{0x54680801,0x4a9800c8,0x63ac032e,0x00000000}},	//   _наем_, לייג, _íann, --, 
   {{0xc95006a9,0x257001ed,0x636c002d,0x00000000}},	//   אמר_, _vált_, _túnp, --, 
   {{0x136400b2,0x42700139,0x65cc02dd,0x00000000}},	//   _ڊاڪٽ, _әгъс, _ﺗﺎﯕﺠ, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2ef40c04,0x2a6c0210,0x00000000,0x00000000}},	// [1db0] _изпр, _łeb_, --, --, 
   {{0x8aa4228e,0xa6d404c5,0x7980002f,0xa91c01ef}},	//   нред, _স্ফট, _almw, _mlže, 
   {{0x02f8010f,0x00000000,0x00000000,0x00000000}},	//   פלאמ, --, --, --, 
   {{0xc17403f9,0xc0bc02d3,0x397800d3,0xecc401c6}},	//   _kiɗa_, _ተጋሩ_, нсію_, _ашгү, 
   {{0x6d5c228f,0x6844036b,0x6d4c058a,0x00000000}},	//   _insa, тнла, mdaa, --, 
   {{0x6d4c2290,0xdc540014,0x8d8401b9,0x98e400fb}},	//   ldaa, _شرُک, _آشگن, нсәһ, 
   {{0x61ec2291,0x6d4c0014,0x6d5c04ce,0xe568009d}},	//   _čalo, odaa, _knsa, дийд_, 
   {{0x6d4c2292,0x58000075,0x00000000,0x00000000}},	//   ndaa, _چۈنك, --, --, 
   {{0x6d5c0280,0x69c82293,0x5ef40882,0x6d4c2294}},	//   _mnsa, _ihee, ्रम्_, idaa, 
   {{0xb9e02295,0x6d5c08cd,0x69c80270,0x6d4c0014}},	//   _ብቻ_, _lnsa, _hhee, hdaa, 
   {{0x69c80190,0xdce40a54,0x6d4c2296,0x6d5c2297}},	//   _khee, _lokā, kdaa, _onsa, 
   {{0x798002d0,0x250800f2,0x00000000,0x00000000}},	//   _xlmw, _آرای_, --, --, 
   {{0x65682298,0x69c800a3,0xdce400e2,0x2328009d}},	//   mjeh, _mhee, _nokā, _жоли_, 
   {{0x6d5c2299,0x6d4c229a,0x69c81368,0x6568229b}},	//   _ansa, edaa, _lhee, ljeh, 
   {{0x6d4c01f5,0xee140006,0xfe7801c6,0x69c801f4}},	//   fdaa, льтэ, хүн_, _ohee, 
   {{0x6568229c,0xc17403f9,0x2d9400ee,0x69c800ad}},	//   njeh, _fiɗa_, грус, _nhee, 
   {{0x1ae4229d,0xcd2402e8,0xa0a4030d,0x00000000}},	// [1dc0] возм, ъжте_, _шаид, --, 
   {{0xa3c01fe5,0x6d4c229e,0x69c8229f,0x3b84001f}},	//   ंति_, adaa, _ahee, ካሪዎች_, 
   {{0x3f9822a0,0x69c807ab,0x6d4c102c,0xd944010b}},	//   miru_, _bhee, bdaa, кежи, 
   {{0x3f98122d,0x6d4c0050,0x69c822a1,0xa91c02fb}},	//   liru_, cdaa, _chee, _alžb, 
   {{0x69c814cc,0xa3c00d35,0xdce40055,0xdcf422a2}},	//   _dhee, ंता_, _gokā, nkyč, 
   {{0x3f9822a3,0x69c822a4,0xa9240030,0x31b800bc}},	//   niru_, _ehee, _rožň, lézt_, 
   {{0x6d5c22a5,0x7bdc009a,0x8f980a7c,0xb59408ca}},	//   _ynsa, _iiru, ויסי, ликш, 
   {{0x7bdc22a6,0x46e40184,0x69c80072,0xb8f40055}},	//   _hiru, ндән_, _ghee, _kiṭī, 
   {{0x73d822a7,0x3f9822a8,0x999802b5,0x674401d3}},	//   ндир_, kiru_, nupō_, ítjü, 
   {{0x97000075,0x9694053f,0x7bdc22a9,0x3f9822aa}},	//   _ئېغى, _иреш, _jiru, jiru_, 
   {{0x6d4c0050,0x69c8009a,0x999800b0,0x00000000}},	//   ydaa, _yhee, hupō_, --, 
   {{0x7bdc22ab,0x6d4c22ac,0x705422ad,0x999802b1}},	//   _liru, xdaa, هنجا, kupō_, 
   {{0x68ec0789,0x7bdc01ab,0x93880798,0x1b1800eb}},	//   ñadi, _oiru, _оска_, ন্যে_, 
   {{0x7bdc22ae,0xafc41e0e,0x3f9822af,0xdce4005f}},	//   _niru, ايسى, giru_, _rokā, 
   {{0x6d4c22b0,0xcdd80640,0x00000000,0x00000000}},	//   tdaa, дња_, --, --, 
   {{0x7bdc22b1,0x672c05ce,0x2bc400e1,0xf1b80327}},	//   _airu, đaji, वतभा, buġa_, 
   {{0x6d4c22b2,0x7bdc22b3,0x69c822b4,0x00000000}},	// [1dd0] rdaa, _biru, _rhee, --, 
   {{0x09c81161,0x7bdc22b5,0x6d4c22b6,0x69c822b7}},	//   िष्य, _ciru, sdaa, _shee, 
   {{0x69c80457,0x7bdc22b8,0x70540133,0x00000000}},	//   _phee, _diru, _شنگا, --, 
   {{0x6d5c22b9,0x6d4c0050,0x6024013f,0xdce4150c}},	//   _unsa, qdaa, _kɔmp, _tokā, 
   {{0x7bdc22ba,0xec3400c8,0x69c80810,0x7648010e}},	//   _firu, _גאָר_, _vhee, _asdy, 
   {{0x7bdc22bb,0x69c80d8b,0xb7480150,0x00000000}},	//   _giru, _whee, кпіз_, --, 
   {{0x69c822bc,0x656800fb,0x6f040455,0xdcf4012d}},	//   _thee, tjeh, _mehc, łcąc, 
   {{0x6f04012c,0x69c80009,0x2b400036,0x00000000}},	//   _lehc, _uhee, lehc_, --, 
   {{0x7b080724,0x7bdc22bd,0xf7701893,0x3f980453}},	//   _östä, _yiru, _ڈال_, yiru_, 
   {{0xf77022be,0x67d422bf,0x6f04047e,0x656822c0}},	//   _وال_, _созу, _nehc, sjeh, 
   {{0x656822c1,0xdde0107d,0x00000000,0x00000000}},	//   pjeh, _žuži, --, --, 
   {{0x3f9822c2,0x21681188,0x208822c3,0xe6c001c8}},	//   wiru_, хими_, ейми_, _پڪڙي, 
   {{0x3f9822c4,0x31b80118,0x717000cf,0x00000000}},	//   tiru_, vézt_, تۇيا, --, 
   {{0xdca401d5,0x00000000,0x00000000,0x00000000}},	//   қази, --, --, --, 
   {{0xe1f013e1,0x7bdc22c5,0x3f9822c6,0x1b18015b}},	//   _است_, _riru, riru_, ন্ডে_, 
   {{0x3f9822c7,0x7f9400ac,0x999800b0,0xd00c00f1}},	//   siru_, _müqə, tupō_, _ځلي_, 
   {{0x7bdc22c8,0x3f9805ce,0xe0d81985,0x9a6815b4}},	// [1de0] _piru, piru_, _яви_, کمال_, 
   {{0x3f98094a,0x7bdc03f0,0x7b840131,0x999802b1}},	//   qiru_, _qiru, جارە, rupō_, 
   {{0x7bdc22c9,0xf3f40183,0x1d081b50,0xb8f400cd}},	//   _viru, _ইয়াৰ_, _пени_, _niṣī, 
   {{0x7bdc22ca,0x9f9407dd,0xdc6801c6,0x00000000}},	//   _wiru, _шықә, _замд_, --, 
   {{0xb8f40055,0x00000000,0x00000000,0x00000000}},	//   _aiṣī, --, --, --, 
   {{0x7bdc16b8,0x47300212,0x3dc0015d,0x5fb4190c}},	//   _uiru, йніс, lliw_, ृतिल, 
   {{0x8b000118,0x645c1f53,0xaa6401ee,0x00000000}},	//   ířec, åsin, _керһ, --, 
   {{0x29540408,0x00000000,0x00000000,0x00000000}},	//   _къур, --, --, --, 
   {{0x7dd800c8,0x644c00f3,0x18a422cb,0x660002d0}},	//   _aŭsk, _šair, _саам, _ewlk, 
   {{0x88380375,0xa2640208,0x00000000,0x00000000}},	//   _אתמו, _trộ, --, --, 
   {{0x4ebc03f4,0x8778008f,0xe78400d8,0x717400ae}},	//   _আল্ল, _ראבי, _туѓо, لهدا, 
   {{0x6f04014f,0x00000000,0x00000000,0x00000000}},	//   _sehc, --, --, --, 
   {{0x3dc022cc,0x7dd8010f,0x3448013e,0x00000000}},	//   dliw_, _eŭsk, _рӯйи_, --, 
   {{0x1b18000e,0x823022cd,0x8474001f,0x6f04014f}},	//   ন্তে_, جریا, ራክሽን_, _qehc, 
   {{0xa3c010f4,0x6f0422ce,0x6024016b,0x3dc00142}},	//   ंतर_, _vehc, _wɔmp, fliw_, 
   {{0x7de402dd,0x00000000,0x00000000,0x00000000}},	//   сірд, --, --, --, 
   {{0xcb1806ed,0x6f0422cf,0xf414010f,0x00000000}},	// [1df0] еќе_, _tehc, יפּ_, --, 
   {{0x3dc022d0,0x7ff40c8b,0x00000000,0x00000000}},	//   aliw_, _اسيا, --, --, 
   {{0xe8dc00dc,0xe9b40124,0x00000000,0x00000000}},	//   यश्च, абжь, --, --, 
   {{0x7f9406be,0x00000000,0x00000000,0x00000000}},	//   _rüqə, --, --, --, 
   {{0x660002b9,0x6a840022,0xc77000db,0x00000000}},	//   _swlk, ылҧа, йткө, --, 
   {{0x6b8002e3,0x2d88020c,0x5c3400df,0x7ac40408}},	//   ịgbo, lhae_, _דרשן_, _ӳсте, 
   {{0x2d880069,0xdb1000e4,0xe570007b,0x00000000}},	//   ohae_, _ägár, قطة_, --, 
   {{0x2d8822d1,0xb8f400b8,0x87e401a9,0x69c40150}},	//   nhae_, _viṣī, _бюже, _төзб, 
   {{0xb81c202e,0x872422d2,0x64a422d3,0xa3c003e5}},	//   _नियम_, _معام, рапа, ंतल_, 
   {{0x65141a90,0x00000000,0x00000000,0x00000000}},	//   _چوائ, --, --, --, 
   {{0x651422d4,0x2d8822d5,0x6eb000c5,0xc6780023}},	//   _نوائ, khae_, _आँगु, ክራሲያ_, 
   {{0x672c05ce,0x00000000,0x00000000,0x00000000}},	//   đaju, --, --, --, 
   {{0xa4d400d4,0xb63c0092,0x9d4400e5,0x00000000}},	//   _тоді, _ሰርተፊ, یئرن, --, 
   {{0x645822d6,0x248c01d4,0x2d8800b0,0x00000000}},	//   _irwi, mzem_, ehae_, --, 
   {{0x8fa022d7,0x81e0015b,0xb804002b,0x1d9422d8}},	//   царе, _পৌর_, _kiṃś, араё, 
   {{0x6458033f,0xb5d001ec,0x00000000,0x00000000}},	//   _krwi, _ﺗﺎﻟﻌ, --, --, 
   {{0x71240137,0x9b0407a5,0x64580332,0x248c22d9}},	// [1e00] _ارىل, изад, _jrwi, nzem_, 
   {{0x2d8800fb,0x248c22da,0xee3801f0,0x00000000}},	//   ahae_, izem_, ънӣ_, --, 
   {{0x81e400bd,0x590800a7,0x00000000,0x00000000}},	//   মীর_, веем_, --, --, 
   {{0x2d8822db,0x1c1c044b,0x00000000,0x00000000}},	//   chae_, _पिपल_, --, --, 
   {{0x98a422dc,0xfaf801d3,0x01e00150,0x00000000}},	//   шиде, _مہذب_, _ﺍﻟﻔﺨ, --, 
   {{0x248c22dd,0xab0822de,0xc7a000a7,0x7c2422df}},	//   dzem_, _متفق_, оичк, muir, 
   {{0xdab822e0,0x645822e1,0x644c00c0,0x00000000}},	//   _شهرت_, _arwi, _šaip, --, 
   {{0x27e80084,0x4aac000d,0x645822e2,0x00000000}},	//   ̭ani_, _जुटव, _brwi, --, 
   {{0xdef80023,0xd3a40835,0x94a802e8,0x94840166}},	//   ዋሩን_, ироп, ътка_, рыйд, 
   {{0x7e7c0649,0x64582182,0x00000000,0x00000000}},	//   kyrp, _drwi, --, --, 
   {{0x0cc022e3,0x7c2422e4,0x672c110c,0xbf2000c5}},	//   _शर्म, huir, đajt, _बाड़न_, 
   {{0x7c240841,0x6458010a,0x9fa40032,0x45d41884}},	//   kuir, _frwi, ҡырҙ, _ﺟﺎﻳﻼ, 
   {{0x636c00d2,0x248c0034,0x7c240841,0x53a40117}},	//   _lúny, czem_, juir, _кадб, 
   {{0x7c2422e5,0x4ea422e6,0x833000c0,0x00000000}},	//   duir, арба, _мніх, --, 
   {{0x2d8822e7,0xcd041d0f,0x00000000,0x00000000}},	//   thae_, ичаи, --, --, 
   {{0x7c2422e8,0x2d8800d8,0x518400f0,0x00000000}},	//   fuir, uhae_, _њука, --, 
   {{0x427c0020,0x70580b2c,0xc4d0008f,0x61ec0171}},	// [1e10] _ጦርነት_, _сапр_, ַגע_, _čali, 
   {{0x25a81821,0x636c03b2,0xc25001d3,0x1b180154}},	//   čali_, _búny, _اکیڈ, ন্সে_, 
   {{0x2d880393,0xa91c01f1,0x9be801e0,0x7f3c05d0}},	//   phae_, _dlžn, _ҡырҡ_, _יעזו, 
   {{0x79a422e9,0xac1800d6,0xf99022ea,0xd5a422eb}},	//   орче, _йому_, وبن_, _رف_, 
   {{0x7c240276,0x1c1c0037,0x00000000,0x00000000}},	//   cuir, _पियल_, --, --, 
   {{0x248c0fb7,0x98f40075,0x636c01e1,0x6b74036b}},	//   vzem_, لغۇچ, _fúny, _улгу, 
   {{0x636c22ec,0xff180375,0x7f3c010f,0x48f400bc}},	//   _gúny, בקות_, דעוו, उँदो_, 
   {{0xd364034c,0x248c00f7,0xa9a40050,0xefe402d3}},	//   _בه_, tzem_, _امرى, ማማዕ_, 
   {{0xe3b822ed,0xd764036b,0xb80400dc,0x00000000}},	//   лби_, _گنلی, _viṃś, --, 
   {{0x64a422ee,0x248c22ef,0xa068036b,0x442c0051}},	//   _қала, rzem_, қага_, _vqg_, 
   {{0xe29822f0,0x248c1b7a,0x7c240276,0x00000000}},	//   уан_, szem_, zuir, --, 
   {{0xa06822f1,0xbb240150,0x69ac01f9,0xc1780166}},	//   гама_, _ﹼﺴﻡ_, जवटी, рҗи_, 
   {{0x64581389,0x645c22f2,0x555022f3,0xe4540209}},	//   _urwi, æsid, _رپور, _ыкды, 
   {{0x64480368,0xdd140432,0x63840209,0x00000000}},	//   mwei, _bäşd, _ыгла, --, 
   {{0x6448097d,0xfe4401e0,0x5ba8023b,0x048000cd}},	//   lwei, әнғо, ҳкам_, _ākṛt, 
   {{0x7c2422f4,0x64480295,0xb3240327,0xdcb015bf}},	//   tuir, owei, _འཐོང_, كىز_, 
   {{0x644822f5,0x9d4401e0,0x05dc000d,0x00000000}},	// [1e20] nwei, _һенд, _पूछब, --, 
   {{0x7c2422f6,0xdca422f7,0x2eec013f,0x1e8400d8}},	//   ruir, _ҳами, ɛefo_, _глом, 
   {{0x644822f8,0x7c2408ad,0x9d4422f9,0x5398008d}},	//   hwei, suir, _ленд, ניעו, 
   {{0x2d980048,0xdca422fa,0x6448043b,0x588422fb}},	//   _gmse_, _гами, kwei, йыла, 
   {{0x7c2422fc,0x4f840014,0x2d9822fd,0x48100212}},	//   quir, _ضایہ, _төрө_, зміс, 
   {{0x644822fe,0xb324031c,0xacb000d1,0x3e58013a}},	//   dwei, _འཐེང_, _غەلب, _kčt_, 
   {{0xd5b822ff,0x2d9803d4,0x94100213,0x2b9001d5}},	//   лси_, _ymse_, ədək_, _تیلس, 
   {{0x644803fa,0x3e58033b,0xa3800254,0x00000000}},	//   fwei, _mčt_, õõnd, --, 
   {{0x12e40046,0x64482300,0x3e58033b,0xe9701075}},	//   йінг, gwei, _lčt_, _تۇند, 
   {{0x6ac4000f,0xdb10013d,0x675400e5,0x758801e2}},	//   _útfû, _ägär, _وینس_, دۍچې_, 
   {{0x3e58033b,0xd4e400a7,0x588401ec,0x00000000}},	//   _nčt_, _люли, _тыңа, --, 
   {{0x644803fa,0x43d001d9,0x7a1c054e,0x00000000}},	//   bwei, _ہٲنز, mătă, --, 
   {{0x657c0267,0x00000000,0x00000000,0x00000000}},	//   öshe, --, --, --, 
   {{0x3e58033b,0x2d982301,0x2ee401bf,0x00000000}},	//   _bčt_, _smse_, ølf_, --, 
   {{0x7a1c084c,0x8778008d,0x72040bbf,0x31340137}},	//   nătă, נאלי, _بوعم, _дейр, 
   {{0xad242302,0x3e580100,0x00000000,0x00000000}},	//   تىرى, _dčt_, --, --, 
   {{0xab740120,0x48f400bc,0x6fb42303,0xc9840022}},	// [1e30] огаш, उँसो_, _ومبا, ҩуеи, 
   {{0x3e580699,0xdd14013d,0xdce40064,0x00000000}},	//   _fčt_, _täşd, _mokę, --, 
   {{0x64481a80,0x7ff42304,0x00000000,0x00000000}},	//   zwei, _وسیا, --, --, 
   {{0xf1c812eb,0x2d98009a,0x6448152c,0x00000000}},	//   रतिन, _umse_, ywei, --, 
   {{0x2bd80133,0x19c01de6,0x64482305,0xe5ac0241}},	//   _ناسک_, фәрг, xwei, _ìbẹ́, 
   {{0x27e02306,0xb8d406c2,0x26c00135,0x00000000}},	//   öhn_, ستنش, żhom_, --, 
   {{0xf1c808e6,0x39a401d9,0x870400db,0xff18011a}},	//   रतान, _کینہ, _ۇبال, זקות_, 
   {{0x64482307,0xe5782308,0xdaa02309,0x6e34000d}},	//   twei, рзи_, _تەمپ, itzb, 
   {{0xa8a4168d,0x6448230a,0xf9d400a8,0xa3e806ed}},	//   _بڵاو, uwei, _хотэ, јдоа_, 
   {{0x64481c1b,0xe3b001d5,0x00000000,0x00000000}},	//   rwei, برب_, --, --, 
   {{0x6448230b,0x7a1c0276,0x61440153,0x2168146a}},	//   swei, cătă, оена, аини_, 
   {{0xc1740198,0x64a400d1,0x64480036,0x00000000}},	//   _kiɗi_, _қаһа, pwei, --, 
   {{0x3e5802e2,0x9fc80353,0xc4c401f7,0x27fc0327}},	//   _sčt_, игма_, _اتاو, npwn_, 
   {{0xf1b8025c,0x00000000,0x00000000,0x00000000}},	//   rrġa_, --, --, --, 
   {{0xaf98230c,0xf644010a,0x00000000,0x00000000}},	//   стях_, _яхăн, --, --, 
   {{0xa0a4230d,0x3e58007f,0xa3c0230e,0x00000000}},	//   _майд, _včt_, ंतक_, --, 
   {{0xf1a804d3,0xdc6801c6,0x00000000,0x00000000}},	// [1e40] _داوه_, шаад_, --, --, 
   {{0x7dd800c8,0x3e5802bd,0x0b40024c,0x00000000}},	//   _aŭst, _tčt_, мнун, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x5f44230f,0x61e400d2,0x7a1c0356,0xd238010f}},	//   _انگل, _éhlu, vătă, יגעל, 
   {{0xa3b80490,0x00000000,0x00000000,0x00000000}},	//   चवा_, --, --, --, 
   {{0x9af4007b,0x0f3400df,0x00000000,0x00000000}},	//   _ذكرت, ַרפט_, --, --, 
   {{0x3c340139,0x00000000,0x00000000,0x00000000}},	//   läv_, --, --, --, 
   {{0x7a1c0356,0xdb1c01e7,0x05b41541,0xd90c029e}},	//   rătă, ilpí, يديت_, _شیت_, 
   {{0x13682310,0x38c801d3,0x00000000,0x00000000}},	//   ашни_, _طاری_, --, --, 
   {{0xe7b000cf,0x00000000,0x00000000,0x00000000}},	//   _كۅند, --, --, --, 
   {{0x658400ae,0x00000000,0x00000000,0x00000000}},	//   áthó, --, --, --, 
   {{0x25a001c7,0x506407a5,0x02a000c7,0x00000000}},	//   éhlt_, отга, ьрым, --, 
   {{0x49082311,0xf7780327,0xb6240220,0x00000000}},	//   ारतो_, _koħ_, _ﺫﻩ_, --, 
   {{0xb3240dd4,0x00000000,0x00000000,0x00000000}},	//   _འཐིང_, --, --, --, 
   {{0xb8cc031c,0x6e3401bf,0xca3802dd,0x00000000}},	//   _པཨ_, utzb, _ﻓﻤﺎ_, --, 
   {{0x3f740166,0x30142312,0x257001ef,0x00000000}},	//   _aşuı_, _едир, _bály_, --, 
   {{0x392c001f,0xe570008f,0xd7c80a59,0x2610012d}},	// [1e50] ተዳደራ, ײַן_, िताच, _धौनी_, 
   {{0xc1740198,0xba740214,0x00000000,0x00000000}},	//   _riɗi_, ژانت, --, --, 
   {{0x9ff400f1,0xbfb400ae,0x00000000,0x00000000}},	//   _وزیږ, _تحيت, --, --, 
   {{0xb9e80046,0x81e402f5,0x4c80036b,0x00000000}},	//   іміз_, মীক_, _قیزق, --, 
   {{0xa2c0190c,0x4ab401f9,0x00000000,0x00000000}},	//   _रुन्, _अडकव, --, --, 
   {{0x36e80145,0x00000000,0x00000000,0x00000000}},	//   يرىپ_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe7942313,0x2bd82314,0x00000000,0x00000000}},	//   _کارک, भगवा, --, --, 
   {{0x69d81ccd,0x68e80327,0x00000000,0x00000000}},	//   mmwe, _iged, --, --, 
   {{0x69d82315,0x2328041b,0xe3b0007b,0x00000000}},	//   lmwe, љони_, عرة_, --, 
   {{0x27ec2316,0xd5a40efc,0x69d80549,0x00000000}},	//   _huen_, _کلنی, omwe, --, 
   {{0x27ec0066,0x68e80327,0x69d802e2,0xdee40092}},	//   _kuen_, _jged, nmwe, ማዋን_, 
   {{0xc0bc0020,0x27e42317,0x290c01e0,0x27ec005a}},	//   _ተቋም_, _kiln_, _meea_, _juen_, 
   {{0x221400a7,0x201c2318,0x330800db,0x3c3401e3}},	//   _ефир, čti_, _ۇيۇپ_, väv_, 
   {{0x657804fe,0x63a02319,0x68e8231a,0xe8e405d9}},	//   _kowh, miln, _oged, _ڄڻ_, 
   {{0x68e8231b,0x657801d9,0x63a0231c,0x27ec06af}},	//   _nged, _jowh, liln, _ouen_, 
   {{0x27ec05f5,0x6280231d,0x657802b1,0x6b80063f}},	// [1e60] _nuen_, lylo, _mowh, _ịgak, 
   {{0x63a0231e,0x68e8231f,0x847402d3,0x69d801f5}},	//   niln, _aged, ራርሓን_, emwe, 
   {{0x5ed8015b,0x62802320,0xaac40214,0x27ec2321}},	//   _ব্রে, nylo, وتمن, _auen_, 
   {{0x27ec2322,0x290c00a8,0x63a02323,0x65781a7b}},	//   _buen_, _ceea_, hiln, _nowh, 
   {{0x7d042324,0x63a02325,0x27e400a2,0x290c2326}},	//   mbis, kiln, _biln_, _deea_, 
   {{0x27ec0323,0x26c4038e,0x62802327,0x69d82328}},	//   _duen_, _bylo_, kylo, amwe, 
   {{0x63a02329,0x68ec232a,0x290c0076,0x27ec005a}},	//   diln, žada, _feea_, _euen_, 
   {{0x7d04232b,0xb6080316,0x6578232c,0x27ec00db}},	//   nbis, jišť, _cowh, _fuen_, 
   {{0x27ec00e8,0x7d04232d,0xe3b8002d,0xb6080c5e}},	//   _guen_, ibis, rrűn_, dišť, 
   {{0x63a0232e,0xb5fc0135,0x7c24232f,0x7d04020c}},	//   giln, _arġe, irir, hbis, 
   {{0x27ec152d,0x7c2407d6,0x7d042330,0x00000000}},	//   _zuen_, hrir, kbis, --, 
   {{0x27ec2331,0x7c242332,0x9594001f,0x6578010e}},	//   _yuen_, krir, ዎቻችን_, _gowh, 
   {{0x63a02333,0x7d042334,0x6280002e,0x26c40200}},	//   biln, dbis, aylo, _zylo_, 
   {{0x62802335,0x7c242336,0x7d042337,0x00000000}},	//   bylo, drir, ebis, --, 
   {{0x43380302,0x69c0022c,0xbb60001f,0x62800210}},	//   _העוב, _íleg, _ለማቋቋ, cylo, 
   {{0x7d041089,0x7c242338,0x3eac02f0,0x00000000}},	//   gbis, frir, _šitý_, --, 
   {{0x7c242339,0x0ae800db,0xc0bc0092,0x3d94233a}},	// [1e70] grir, مراي_, _ተቋሙ_, хитр, 
   {{0x290c233b,0xefe40023,0x7d04058a,0x00000000}},	//   _seea_, ዛማዲ_, abis, --, 
   {{0x7d0422a9,0x7c24233c,0x27ec0a40,0x48a81945}},	//   bbis, arir, _suen_, әтем_, 
   {{0x290c01ee,0xfaa40e46,0x776802d0,0x24880135}},	//   _qeea_, хшун, _andx, _żamm_, 
   {{0x27ec233d,0x17240156,0x6280233e,0x7c2407ea}},	//   _quen_, _རྐངམ_, zylo, crir, 
   {{0x27ec01c7,0x6578233f,0xf7940006,0x0058011a}},	//   _vuen_, _sowh, начэ, פשות_, 
   {{0x63a02340,0x62800076,0x657802b1,0x69d8009a}},	//   viln, xylo, _powh, pmwe, 
   {{0x68e82341,0x63a00034,0x27ec2342,0x0ef8012c}},	//   _uged, wiln, _tuen_, ्रुस_, 
   {{0x63a02343,0x26c40042,0xb60800d7,0x00000000}},	//   tiln, _wylo_, višť, --, 
   {{0x62802344,0xb370001f,0x7d04002f,0x00000000}},	//   tylo, _ብቻውን_, zbis, --, 
   {{0x63a00fb7,0xa91c110c,0xc7f400b5,0xe3b001d3}},	//   riln, _alži, lパ_, ٹرک_, 
   {{0x7c242345,0xa0a42346,0xfe782347,0x00000000}},	//   yrir, дамд, җүм_, --, 
   {{0x63a02348,0x31b802fb,0xb16400fb,0x25ac2349}},	//   piln, nézy_, хняһ, mnel_, 
   {{0x98a404fe,0x7dd80115,0x7c24234a,0x63a0234b}},	//   ngoā_, _aŭsp, vrir, qiln, 
   {{0xe2981def,0x7c2402d1,0x7f900166,0x2eb4234c}},	//   _фай_, wrir, _näqe, естс, 
   {{0x25ac234d,0x7c24234e,0x31680036,0xb5fc0135}},	//   nnel_, trir, _gnaz_, _urġe, 
   {{0x7d04234f,0x7c2405b8,0x6f180332,0x00000000}},	// [1e80] rbis, urir, éacó, --, 
   {{0x7c242350,0x9f042351,0x2000033f,0x00000000}},	//   rrir, _تودو, mpki_, --, 
   {{0x68ec0030,0x7c24000d,0x00000000,0x00000000}},	//   ľadn, srir, --, --, 
   {{0x7c240801,0xd00c2352,0x18a4005b,0x00000000}},	//   prir, _حلی_, маем, --, 
   {{0x7f900724,0x38600162,0x00000000,0x00000000}},	//   _täqd, íir_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb33c0327,0x76b400c7,0x00000000,0x00000000}},	//   jiħa, хәац, --, --, 
   {{0x25ac2353,0xdb1c0200,0x00000000,0x00000000}},	//   gnel_, kopë, --, --, 
   {{0x93242354,0xe97000cf,0x73c4010b,0x31b800d0}},	//   وردن, _حۇند, нәке, cézy_, 
   {{0x25ac0548,0xd78800f2,0x00000000,0x00000000}},	//   anel_, _بخرم_, --, --, 
   {{0xa2c01971,0x32180232,0x00000000,0x00000000}},	//   _रुद्, éry_, --, --, 
   {{0x54680024,0x00000000,0x00000000,0x00000000}},	//   _маем_, --, --, --, 
   {{0xc0582355,0x53b4036b,0x31680208,0xa9d400d1}},	//   мір_, _оғир_, _vnaz_, ﯘﺭﯨﻴ, 
   {{0x0ef82356,0x00000000,0x00000000,0x00000000}},	//   ्रेस_, --, --, --, 
   {{0xf40000eb,0x00000000,0x00000000,0x00000000}},	//   _এটির_, --, --, --, 
   {{0xdb1c180f,0x00000000,0x00000000,0x00000000}},	//   lopè, --, --, --, 
   {{0xcee801d9,0x7de40220,0xfa50001f,0x0b840014}},	// [1e90] _وردن_, тірд, _ዘላለማ, وٝری_, 
   {{0xdb1c0066,0xc0840092,0xf4000154,0xc904012d}},	//   nopè, ሮግራሙ_, _এটার_, शर्म_, 
   {{0x25ac2357,0x00000000,0x00000000,0x00000000}},	//   ynel_, --, --, --, 
   {{0x68ec01f1,0x31b82358,0x6f142359,0x00000000}},	//   ľado, tézy_, lazc, --, 
   {{0x68ec0232,0x6d4c235a,0x3ea0001f,0xd9141bf4}},	//   žado, meaa, _ፍልሰታ_, ريوش_, 
   {{0x6d4c235b,0x7b64235c,0x4df00b26,0x00000000}},	//   leaa, _итсе, _अढाई_, --, 
   {{0x80c8015b,0xb9c400cf,0x00000000,0x00000000}},	//   রেপ্, رقۇي, --, --, 
   {{0x25ac0dd4,0xc8640801,0x6d4c235d,0x2d88016b}},	//   unel_, _отзи, neaa, nkae_, 
   {{0x3834235e,0xa2c001f9,0x00000000,0x00000000}},	//   _интр, रॅन्, --, --, 
   {{0xbab01c82,0x1828107f,0xe298026a,0xdb1c00db}},	//   _কৰিছ, _رقمی_, зао_, gopè, 
   {{0x25ac235f,0x2d88020b,0x6d4c023a,0xd5ac01d3}},	//   pnel_, kkae_, keaa, شفی_, 
   {{0x68f800d2,0x60242360,0x09bc00cc,0x30740023}},	//   ncwd, ндма, েদকা, _ኪመጽእ_, 
   {{0x80c800bd,0x6d4c2301,0x1b180011,0x1fb406ed}},	//   রেন্, deaa, ন্টে_, есвр, 
   {{0xdb1c02d3,0xdfd02361,0xe2982362,0xa91c00ef}},	//   ropë, ايس_, _нал_, _ilžu, 
   {{0xdd902363,0x4dc40131,0x1ea82364,0x00000000}},	//   هوس_, ﯩﻜﯩﻨ, ساسي_, --, 
   {{0x0ef801ad,0x00000000,0x00000000,0x00000000}},	//   ्रॉस_, --, --, --, 
   {{0xdb1c0085,0x00000000,0x00000000,0x00000000}},	// [1ea0] lopé, --, --, --, 
   {{0x5bc42365,0x6f1402ea,0xa3c02366,0x68ec1d55}},	//   رقال, cazc, ूति_, žadl, 
   {{0x6d4c01c7,0x8b8400db,0x8b2000d8,0x00000000}},	//   beaa, راكۅ, удхе, --, 
   {{0x3804013e,0x00000000,0x00000000,0x00000000}},	//   водҳ, --, --, --, 
   {{0x4c640873,0x645c0008,0xa3c0146b,0x1ba801d3}},	//   _зиян_, æsil, ूता_, _فاسٹ_, 
   {{0x50180375,0xdb1c2367,0x00000000,0x00000000}},	//   לונו, kopé, --, --, 
   {{0x5bbc2368,0x00000000,0x00000000,0x00000000}},	//   ्तीव, --, --, --, 
   {{0x09e02369,0xd498013e,0xe3b8000f,0x00000000}},	//   _босн, зро_, brűk_, --, 
   {{0x73d8236a,0xdb1c00db,0x46e401e0,0x34940064}},	//   мдир_, topè, мдән_, тапр, 
   {{0x96941142,0xb5fc031c,0x2cec000d,0xd2540066}},	//   _преш, _erġa, _झल्ल_, فیتش_, 
   {{0xdb1c1497,0x6d4c0083,0xf194236b,0x932401d5}},	//   ropè, yeaa, винь, ورگن, 
   {{0xdce402e2,0x0ef805d7,0xdb0c236c,0x81b40154}},	//   _ankč, ्र्स_, _akbü, _জীব_, 
   {{0x5fd0007d,0x6d4c0076,0x00000000,0x00000000}},	//   _दीहल, veaa, --, --, 
   {{0x73c401e0,0x6d4c0066,0x733410de,0x3da40107}},	//   _шәйе, weaa, _شىبا, ҳруб, 
   {{0x6f14236d,0xdb1c003e,0x7c2800b8,0x00000000}},	//   razc, copé, _ādra, --, 
   {{0x8d74236e,0xdb0c00e5,0x2fdc0153,0x00000000}},	//   رازا, _okbó, _žygį_, --, 
   {{0xb81c16da,0x6fb801b9,0x00000000,0x00000000}},	// [1eb0] _निगम_, _огир_, --, --, 
   {{0x6d4c08e3,0x764801bf,0x7f94074d,0x00000000}},	//   seaa, _opdy, _баьх, --, 
   {{0x6d4c0641,0x6db4236f,0xf7780327,0x7dfc02e2}},	//   peaa, _айну, _jiħu_, _pčse, 
   {{0xa91c151c,0xdeb00220,0x99980100,0x00000000}},	//   _možg, _тұсы, nspň_, --, 
   {{0x39442370,0x00000000,0x00000000,0x00000000}},	//   _dbms_, --, --, --, 
   {{0x39440280,0x386401a6,0x1864119e,0x39b80100}},	//   _ebms_, _drmr_, таши_, včse_, 
   {{0x97301b2c,0x00000000,0x00000000,0x00000000}},	//   شکلا, --, --, --, 
   {{0x7f90013d,0x9c8400ef,0x80c407b6,0x00000000}},	//   _mäqa, _fočē, रथमे, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb1c2371,0xe1f80137,0xe7182372,0x00000000}},	//   topé, мго_, _آيات_, --, 
   {{0xe29802ac,0x05440323,0xa5340108,0x00000000}},	//   фан_, _зүйл_, _анеч, --, 
   {{0xdb1c2373,0x709c0882,0xe4d800c6,0xd24c0592}},	//   ropé, _śikṣ, _قوات_, آنَ_, 
   {{0x8edc03f4,0x00000000,0x00000000,0x00000000}},	//   _ব্লগ, --, --, --, 
   {{0xb8040055,0x764800a2,0x00000000,0x00000000}},	//   _akṛś, _ypdy, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdcb02374,0x3bd40139,0x32d40024,0x00000000}},	//   لىز_, däqa_, _сціс, --, 
   {{0xa91c04b9,0x5f040801,0x67202375,0x1be8013e}},	// [1ec0] _možd, _изпа, _odlj, ддаи_, 
   {{0x8c402376,0x60d400b5,0x1e840fc0,0x7f900166}},	//   рефе, _izym, _алом, _fäqa, 
   {{0xdee42377,0x00000000,0x00000000,0x00000000}},	//   _јони, --, --, --, 
   {{0x984800d4,0xdca4022e,0x00000000,0x00000000}},	//   дяка_, _аами, --, --, 
   {{0x17a0013e,0x46a4000d,0x2ce4022e,0xe9940066}},	//   ақаҳ, _केबह, _бўёв, دهنگ, 
   {{0x7f900bc9,0x00000000,0x00000000,0x00000000}},	//   _yäqa, --, --, --, 
   {{0x98b003ee,0x41b411a0,0x595400f3,0xd938014b}},	//   ıyı_, ीवास, _иђах, _очаш_, 
   {{0x3254013e,0xceb000d9,0x00000000,0x00000000}},	//   ҳвор, ייו_, --, --, 
   {{0x74140244,0x645c007c,0xddcc00e5,0x85700150}},	//   دوخا, åsip, nybű, рлых, 
   {{0x79802378,0xb9ec02d3,0x27f80066,0xa91c0427}},	//   _homw, _ኔረ_, _ésna_, _požg, 
   {{0x79800925,0x60d42379,0x00000000,0x00000000}},	//   _komw, _azym, --, --, 
   {{0x28d80050,0x316c237a,0x8230158b,0x00000000}},	//   बेकि, ñez_, گریا, --, 
   {{0x79800925,0x60d4033f,0x24940014,0x9474007b}},	//   _momw, _czym, _مۅٹھ_, _جداا, 
   {{0x79800925,0x9f5002e2,0x03a0237b,0x8230085b}},	//   _lomw, _juyè_, _кичо, دریا, 
   {{0xdb0400bc,0x5274010b,0xca6801ec,0xa3c003ce}},	//   ámýc, _шуду, гiнi, ूतर_, 
   {{0xa91c0232,0x7980237c,0x31341d0f,0x7f900139}},	//   _kože, _nomw, _сеир, _väqa, 
   {{0xebd80a31,0xa91c237d,0x7aec016b,0x7f900139}},	// [1ed0] едаш_, _jože, ɛntɛ, _wäqa, 
   {{0xa91c04b9,0x4174237e,0xad4000db,0x00000000}},	//   _može, _ماۋس, _گۉرۉ, --, 
   {{0x7980237f,0xa91c0e3c,0xefe4001f,0x7ac40006}},	//   _bomw, _lože, ዛኛው_, асце, 
   {{0x79802380,0xaa9000c7,0x60d4010b,0x7bc002d2}},	//   _comw, аҳҳә, _yzym, _ímun, 
   {{0x68440019,0xa91c08a4,0x6d5c2381,0x79802382}},	//   унла, _nože, _iasa, _domw, 
   {{0x6d5c2383,0x79800295,0x00000000,0x00000000}},	//   _hasa, _eomw, --, --, 
   {{0x6d5c2384,0xe5a42385,0x79800198,0xa7fc002d}},	//   _kasa, лики, _fomw, _grűn, 
   {{0xe4581515,0x79800295,0xa91c0306,0x5550185e}},	//   ежи_, _gomw, _bože, مپىر, 
   {{0x69c80770,0xa91c0063,0xa3e82386,0xd5440108}},	//   _ikee, _vožd, ндиа_, упые_, 
   {{0x6d5c2387,0x4908038e,0x2bd8028a,0x79801813}},	//   _lasa, ारको_, _बीमा, _zomw, 
   {{0x79801813,0x69c82388,0x60d42389,0x6d5c238a}},	//   _yomw, _kkee, _szym, _oasa, 
   {{0x63880051,0x00000000,0x00000000,0x00000000}},	//   _bênê, --, --, --, 
   {{0xf48403f6,0x643800df,0x00000000,0x00000000}},	//   _вујн, _נײַג, --, --, 
   {{0x443c238b,0x6d5c238c,0x6458238d,0x1ec800db}},	//   mtu_, _aasa, _iswi, елги_, 
   {{0x69c8238e,0xa91c238f,0xaf9800d4,0x5398011a}},	//   _okee, _zože, ттях_, _ריצו, 
   {{0x5bbc1161,0x69c80070,0x5de42390,0x2d942391}},	//   ्त्व, _nkee, ужба, арус, 
   {{0x7980004c,0x3ba4013e,0x70540354,0x00000000}},	// [1ee0] _romw, алаҳ, _кĕте, --, 
   {{0x443c2392,0x69c82393,0x6d5c2394,0x79802395}},	//   itu_, _akee, _easa, _somw, 
   {{0x6d5c2396,0x443c2397,0x79801813,0x00000000}},	//   _fasa, htu_, _pomw, --, 
   {{0x6d5c2398,0x79800455,0x4e78010f,0x6458012d}},	//   _gasa, _qomw, _נאכצ, _oswi, 
   {{0x443c2399,0x8eb004fb,0x79800099,0x6c74239a}},	//   jtu_, _نمیش, _vomw, _курх, 
   {{0x6d5c239b,0x69c8239c,0x443c0c67,0x79800925}},	//   _zasa, _ekee, dtu_, _womw, 
   {{0x6d5c239d,0x645802c4,0x443c239e,0x7980239f}},	//   _yasa, _aswi, etu_, _tomw, 
   {{0x6d5c0a81,0xa91c041a,0x69c8005a,0xd7f000ae}},	//   _xasa, _pože, _gkee, _هكر_, 
   {{0x38c8168d,0x7bdc23a0,0x94741c36,0xf8b004d3}},	//   _شاری_, _khru, ادعا, _بکا_, 
   {{0xa91c0010,0xdb1c0518,0x44940108,0xb4c406b1}},	//   _vože, kopí, увью_, _एडी_, 
   {{0x443c23a1,0x645807a9,0x3f980003,0x00000000}},	//   atu_, _eswi, dhru_, --, 
   {{0xa91c151c,0xa6942377,0x00000000,0x00000000}},	//   _tože, _труј, --, --, 
   {{0x443c23a2,0x80c80154,0x00000000,0x00000000}},	//   ctu_, রেস্, --, --, 
   {{0xa3c000cd,0x94a801af,0xc62400cc,0x00000000}},	//   ूतः_, _отһа_, _মহতা_, --, 
   {{0x6d5c23a3,0xcdd823a4,0x27e80268,0x02f800d9}},	//   _pasa, ења_, ìani_, _אלומ, 
   {{0x6d5c23a5,0x64580368,0x68ec0024,0x46a400c5}},	//   _qasa, _yswi, žadi, _कइसह, 
   {{0x6d5c23a6,0x7bdc23a7,0xed5800fb,0xc98400d1}},	// [1ef0] _vasa, _bhru, ноң_, һуди, 
   {{0x6d5c23a8,0x7bdc0bec,0x69c80731,0x6d9000cc}},	//   _wasa, _chru, _skee, _gåan, 
   {{0x443c0323,0xdeb0005e,0x7bdc23a9,0xaa5423aa}},	//   ztu_, _дұры, _dhru, рвеш, 
   {{0x443c23ab,0x6d5c14d0,0x7bdc23ac,0xfc3001d3}},	//   ytu_, _uasa, _ehru, تحہ_, 
   {{0x443c23ad,0x0c84010b,0x7bdc01e7,0x9d180115}},	//   xtu_, _сынм, _fhru, _בורט, 
   {{0x8ae41c26,0x7bdc23ae,0x645804cc,0xab940220}},	//   _бібл, _ghru, _rswi, _тигі, 
   {{0xaab8166d,0x443c0135,0xf60801c8,0x00000000}},	//   _आशिक, wtu_, هتيه_, --, 
   {{0x443c23af,0x7bdc02fd,0x6458003e,0xd6cc00c6}},	//   ttu_, _zhru, _pswi, بقى_, 
   {{0x443c23b0,0xa91c151c,0xe3b8072c,0xdb1c00d7}},	//   utu_, _tožb, кби_, zopí, 
   {{0x443c23b1,0x1c1c00e1,0x645800b5,0x67d40c75}},	//   rtu_, _पिघल_, _vswi, _тозу, 
   {{0x659423b2,0xe10823b3,0x765c00e4,0xa2280395}},	//   _кажу, кенд_, _áryp, ъжна_, 
   {{0x645823b4,0x2934008f,0xc0e0010c,0x926000d1}},	//   _tswi, סאָן_, _ዑመር_, زگىم, 
   {{0x645800ec,0x3f9823b5,0x20b823b6,0x443c23b7}},	//   _uswi, thru_, тынь_, qtu_, 
   {{0xa2e40e26,0x232800d6,0xd0040d6f,0xaf3401d9}},	//   _колд, _роки_, рере_, ٝرِت, 
   {{0xe29823b8,0xd36c009f,0x29d4007c,0x00000000}},	//   _шак_, _زهي_, våan_, --, 
   {{0x7bdc23b9,0xd24c038b,0x80c80eac,0xdb1c23ba}},	//   _shru, _آني_, রেষ্, ropí, 
   {{0xd00c23bb,0x7bdc00a3,0x00000000,0x00000000}},	// [1f00] _قلي_, _phru, --, --, 
   {{0x25a800bc,0x3f8c0037,0x00000000,0x00000000}},	//   čaly_, ödud_, --, --, 
   {{0x9d4423bc,0x7bc001e1,0x00000000,0x00000000}},	//   _кенд, _ímum, --, --, 
   {{0xdc340131,0xa91c0010,0x00000000,0x00000000}},	//   _پىسخ, _rožc, --, --, 
   {{0x7bdc23bd,0x985423be,0x00000000,0x00000000}},	//   _thru, ртеш, --, --, 
   {{0xf74801f7,0x5fc423bf,0x00000000,0x00000000}},	//   الغي_, लकिल, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd4140124,0x9868022e,0x00000000,0x00000000}},	//   қьҩы, _иибб_, --, --, 
   {{0x57e823c0,0x3e58033b,0x5fc423c1,0x18a423c2}},	//   _адам_, _lōt_, लकाल, _таам, 
   {{0x07a023c3,0x88380302,0x00000000,0x00000000}},	//   _даун, _בתמו, --, --, 
   {{0x3e580100,0x00000000,0x00000000,0x00000000}},	//   _nōt_, --, --, --, 
   {{0xa91c0e3c,0x00000000,0x00000000,0x00000000}},	//   _koža, --, --, --, 
   {{0x3448013e,0x73c401ee,0x0fe000db,0x00000000}},	//   _сӯйи_, _гәне, жөнү, --, 
   {{0x926800c7,0xa2c0185d,0xa91c0219,0x48b000fe}},	//   _ариа_, _रुक्, _moža, _জৰুৰ, 
   {{0xbe8823c4,0xa3100030,0x63bc01d3,0x00000000}},	//   асте_, äčšo, ésne, --, 
   {{0x8d7400db,0x40c801f2,0xd12c00db,0xb11423c5}},	//   جاسا, ọrị_, _تۅح_, _умиш, 
   {{0xdce402d5,0x7bf800a8,0x660c107d,0x8c340107}},	// [1f10] _mokė, интр_, ćaki, розӣ_, 
   {{0xdce40064,0x46a4000d,0x00000000,0x00000000}},	//   _lokė, _कइलह, --, --, 
   {{0xd1ec0201,0x00000000,0x00000000,0x00000000}},	//   _ሁለት_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x67d423c6,0x3e58007f,0x3b1803b9,0xfda801af}},	//   боду, _zōt_, _ferq_, _төрҙ_, 
   {{0xa91c0306,0x0a6800f3,0x00000000,0x00000000}},	//   _doža, _ирби_, --, --, 
   {{0xa6c823c7,0xaa9400c6,0xeae40183,0x361802d5}},	//   ылка_, _الأث, _প্ৰম, ацыю_, 
   {{0xa2c00490,0x00000000,0x00000000,0x00000000}},	//   _रुग्, --, --, --, 
   {{0x291c23c8,0x9f5001e1,0x18b023c9,0x64a423ca}},	//   mawa_, _buyì_, _нәшр, сапа, 
   {{0x291c23cb,0x86b002dd,0x4ad80073,0xe358022e}},	//   lawa_, _мәйі, _भराव, ушиш_, 
   {{0x65140ef8,0x6e34110c,0xa91c23cc,0xc6a400f3}},	//   _هوائ, juzb, _zoža, _траи, 
   {{0x291c23cd,0x68ec0232,0xf65000cf,0x070802c3}},	//   nawa_, žadu, _تئك_, _स्तव_, 
   {{0x25ac23ce,0xe1f023cf,0x291c02b5,0x7dfc033b}},	//   miel_, _کست_, iawa_, _pčso, 
   {{0x291c23d0,0xdb1c23d1,0x25ac23d2,0x3e58007f}},	//   hawa_, kopá, liel_, _pōt_, 
   {{0x8fa023d3,0xa7fc0b21,0xdc340166,0x248c01d3}},	//   чаре, _brűk, _bäğe, lyem_, 
   {{0x291c23d4,0xdb1c02fb,0xdca41cf2,0x3b18025c}},	//   jawa_, dopá, баби, _serq_, 
   {{0x291c23d5,0xf1a803e6,0xa06823d6,0xe8180316}},	// [1f20] dawa_, _خاوه_, _сапа_, नीमा_, 
   {{0x25ac23d7,0xa91c23d8,0xa3dc06ab,0x61e423d9}},	//   hiel_, _roža, _थीम_, lmkl, 
   {{0x25ac23da,0x248c016b,0x291c23db,0xa91c0427}},	//   kiel_, hyem_, fawa_, _soža, 
   {{0x291c23dc,0xa91c0b9d,0x248c013f,0x25ac0489}},	//   gawa_, _poža, kyem_, jiel_, 
   {{0x25ac23dd,0xb5fc0003,0xd764036b,0x00000000}},	//   diel_, _irġi, ینچی, --, 
   {{0x9b9423de,0xdb1c0077,0x00000000,0x00000000}},	//   _الست, bopá, --, --, 
   {{0x291c23df,0x25ac207e,0xd1ec0020,0x638401ef}},	//   bawa_, fiel_, _ሁለቱ_, _méně, 
   {{0x291c23e0,0x25ac23e1,0x00000000,0x00000000}},	//   cawa_, giel_, --, --, 
   {{0xf8dc00af,0x09e001c0,0xca6802dd,0x0460084c}},	//   _बरिय, _хотн, гiзi, птэм, 
   {{0x9f94003a,0xfdc40037,0x6e3401b9,0x86940166}},	//   lææ_, वकुफ, yuzb, ртәт_, 
   {{0xa91c23e2,0x25ac23e3,0xcb1023e4,0xb5fc0327}},	//   _možn, biel_, הלת_, _orġi, 
   {{0xf48423e5,0xa91c012c,0x9f500248,0x00000000}},	//   _واشی, _ložn, _wuyì_, --, 
   {{0x13a807d6,0x00000000,0x00000000,0x00000000}},	//   _ینچی_, --, --, --, 
   {{0x291c23e6,0x92a800c6,0xa91c1821,0xf1640241}},	//   zawa_, _খৡৣ_, _nožn, _imọ̀_, 
   {{0x291c23e7,0xfdc405f9,0x04b401ed,0x271c009e}},	//   yawa_, वकूफ, _نھیں_, _নামো_, 
   {{0x291c02c4,0x00000000,0x00000000,0x00000000}},	//   xawa_, --, --, --, 
   {{0x291c23e8,0x06680131,0xd7b823e9,0x0bf000db}},	// [1f30] vawa_, _ﺳﯧﻠﯩ, ेवाच, سياڭ, 
   {{0x291c23ea,0x25ac23eb,0xdb1c23ec,0x00000000}},	//   wawa_, ziel_, topá, --, 
   {{0x291c23ed,0x248c23ee,0x2d84004a,0xcae023ef}},	//   tawa_, zyem_, êles_, केंड_, 
   {{0x6ab81971,0x291c0451,0x25ac1529,0x248c011f}},	//   _आशीर, uawa_, xiel_, yyem_, 
   {{0x291c23f0,0xf77023f1,0x25ac23f2,0x2d9823f3}},	//   rawa_, کان_, viel_, _ilse_, 
   {{0x291c23f4,0x248c1529,0x25ac23f5,0xdb1c00e4}},	//   sawa_, vyem_, wiel_, popá, 
   {{0x291c094a,0x9ba023f6,0x25ac23f7,0xe9e8007b}},	//   pawa_, _تەلى, tiel_, _نفسى_, 
   {{0x248c061c,0x291c0481,0x61e4035a,0xf7700e56}},	//   tyem_, qawa_, xmkl, _ۋال_, 
   {{0x25ac23f8,0x92e400bd,0x00000000,0x00000000}},	//   riel_, যুৎ_, --, --, 
   {{0x25ac23f9,0x248c03e0,0xe3a802e8,0x7e7c0175}},	//   siel_, ryem_, ркод_, yxrp, 
   {{0x25ac23fa,0x2d9800a2,0x248c007f,0x80dc00bc}},	//   piel_, _olse_, syem_, _नरहे, 
   {{0x248c007f,0xe04401a9,0x3688004e,0xa06800db}},	//   pyem_, онми, _усун_, аама_, 
   {{0x10a023fb,0xb5c80214,0x61e423fc,0x00000000}},	//   диян, _اونم_, rmkl, --, 
   {{0xaab823fd,0x92a801ed,0x57f80115,0x00000000}},	//   _आशंक, ائیہ_, ילשו, --, 
   {{0xa91c23fe,0x2d9801a6,0xe81823ff,0x9d541541}},	//   _rožn, _blse_, नीता_, ينست, 
   {{0x290800e8,0x00000000,0x00000000,0x00000000}},	//   ñaal_, --, --, --, 
   {{0x8c402400,0x5ba82401,0x3bd40139,0x00000000}},	// [1f40] мете, акам_, läqi_, --, 
   {{0xa91c2402,0x2d982403,0x00000000,0x00000000}},	//   _božo, _else_, --, --, 
   {{0xdee407a5,0x5398011a,0x00000000,0x00000000}},	//   _фони, סיעו, --, --, 
   {{0xbd24031c,0x00000000,0x00000000,0x00000000}},	//   _འཇིཊ_, --, --, --, 
   {{0x7d042404,0xa91c151c,0x97c42405,0x6f040208}},	//   mcis, _tožn, ойде, _yfhc, 
   {{0x7c242406,0x7d042407,0x1a240014,0x00000000}},	//   msir, lcis, _ورزُ, --, 
   {{0x7c242408,0x07a00261,0xdb1c005c,0x9984010a}},	//   lsir, ќајн, topæ, _мăкш, 
   {{0x7d042409,0x7c240083,0x0d94010f,0x00000000}},	//   ncis, osir, ַכים_, --, 
   {{0x7d04240a,0xdb1c04ce,0xdcf40205,0x00000000}},	//   icis, ropæ, niyı, --, 
   {{0x7c24240b,0x92681914,0x938800c7,0x6d900158}},	//   isir, арма_, рсиа_, _påak, 
   {{0x7dfc0100,0x8af808d8,0x7c24022e,0x7d040205}},	//   _dčsk, יליז, hsir, kcis, 
   {{0x7c24240c,0xdb1c0108,0x6380035b,0x261801e1}},	//   ksir, lopä, дҳәа, _ṣoge_, 
   {{0x7c2408a4,0x00000000,0x00000000,0x00000000}},	//   jsir, --, --, --, 
   {{0x09b41788,0xc05800d6,0x7d04240d,0x7c24240e}},	//   _अद्य, цію_, ecis, dsir, 
   {{0x8d74240f,0x87780677,0x7f900139,0x645c0135}},	//   يارا, סאלי, _xäqi, ħsie, 
   {{0x7c242410,0x75202411,0x7d0400aa,0xdb1c0112}},	//   fsir, namz, gcis, hopä, 
   {{0x7c242412,0xb5fc0327,0xdb1c005b,0xcfa802cb}},	// [1f50] gsir, _irġu, kopä, _نادم_, 
   {{0x09b02413,0x7d042414,0x35cc0cb4,0xf3fc0183}},	//   ंच्य, acis, ावड़, _এবাৰ_, 
   {{0x75201bb6,0x2d98067c,0x7c242415,0x6b50032e}},	//   kamz, _tlse_, asir, _aðgæ, 
   {{0xc8b00d00,0x7d042416,0x7c242417,0x00000000}},	//   ولاک, ccis, bsir, --, 
   {{0x6c78008f,0xdb1c0037,0x67d400f3,0x7c2400e5}},	//   _האָפ, fopä, поду, csir, 
   {{0xbdf82263,0x80c8015b,0xdb1c0112,0xd5bc00b8}},	//   _دریا_, রেক্, gopä, _śāpa_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x75202418,0x7f90013d,0x3ebc011a,0x00000000}},	//   gamz, _väqi, יצוב, --, 
   {{0xf77005d9,0x00000000,0x00000000,0x00000000}},	//   _ڄام_, --, --, --, 
   {{0xf7702419,0x3ca803d4,0x7f900139,0xa91c00d7}},	//   _لام_, _কুঁৱ, _täqi, _možm, 
   {{0x2168241a,0x7c2403da,0xa91c0171,0x00000000}},	//   бини_, zsir, _ložm, --, 
   {{0x7d040548,0x64540083,0x645c0135,0x00000000}},	//   xcis, ăzib, ħsib, --, 
   {{0xa91c241b,0x00000000,0x00000000,0x00000000}},	//   _nožm, --, --, --, 
   {{0x7c24074d,0x224402fa,0x00000000,0x00000000}},	//   vsir, ptlk_, --, --, 
   {{0x7c24241c,0xdb1c0267,0x7d040205,0x00000000}},	//   wsir, nopå, tcis, --, 
   {{0x7c24241d,0xf1a8088c,0x91e0241e,0x7d0406af}},	//   tsir, _وايه_, _поще, ucis, 
   {{0x7d04241f,0xe31801fb,0xa6d000cc,0x00000000}},	// [1f60] rcis, _điể, াধিট, --, 
   {{0xdb1c0158,0x7d041486,0x75200156,0x61f414ea}},	//   kopå, scis, zamz, _hiyl, 
   {{0x4ef8025f,0x7c242420,0x7520014b,0x39b8007f}},	//   _להיו, ssir, yamz, lčsi_, 
   {{0xd7f805c5,0xd00c2421,0x82f8031c,0x21202422}},	//   бук_, _جلی_, _ནུའུ_, nakh_, 
   {{0xdb1c0844,0x636400b0,0x7c242423,0x7794114f}},	//   topä, _kōnē, qsir, ویرا, 
   {{0xc7a02424,0x07a02425,0x60d402f6,0xb8f4007d}},	//   ничк, начн, _myym, _सँ_, 
   {{0xdb1c2426,0x2120009a,0xa3c017ee,0x7520009f}},	//   ropä, kakh_, ्कन_, tamz, 
   {{0x7f90013d,0x99e401af,0x00000000,0x00000000}},	//   _täqw, _эҫең_, --, --, 
   {{0x21202427,0x75202428,0x73c41de6,0x60d40108}},	//   dakh_, ramz, мәке, _nyym, 
   {{0xb9cc001f,0x97c40166,0xd378030d,0x00000000}},	//   _ቶሎ_, _эйзе, счи_, --, 
   {{0xa91c00c0,0xd574003b,0x00000000,0x00000000}},	//   _alžy, _нудь, --, --, 
   {{0x21200472,0xc1080276,0x86780375,0x6aa00205}},	//   gakh_, зэре_, _לרבו, _ülfe, 
   {{0x6ab82429,0xa91c242a,0x9f50010e,0x61f4010b}},	//   _आश्र, _božj, _atyñ_, _diyl, 
   {{0xa91c242b,0xfa080327,0x00000000,0x00000000}},	//   _rožm, _ཆེ༵ན_, --, --, 
   {{0x2120242c,0x61f401a9,0xc7d40375,0x3ec40064}},	//   bakh_, _fiyl, פולי_, естб, 
   {{0x7d24242d,0x61f40139,0x00000000,0x00000000}},	//   еффе, _giyl, --, --, 
   {{0x6ecc242e,0xdb0c07a8,0x3d0c00c5,0xb2740022}},	// [1f70] _दुरु, _imbê, ़ड़े_, _хкқә, 
   {{0xaa9401a9,0x00000000,0x00000000,0x00000000}},	//   мизч, --, --, --, 
   {{0xecf8242f,0xbb840597,0x00000000,0x00000000}},	//   _менш_, علمي, --, --, 
   {{0xba7402dd,0x61f401a9,0xac9401b9,0x00000000}},	//   عالت, _xiyl, _жамш, --, 
   {{0x6d4c020b,0xa3c00490,0x00000000,0x00000000}},	//   mfaa, ्कम_, --, --, 
   {{0x6d4c2430,0x21202431,0x00000000,0x00000000}},	//   lfaa, zakh_, --, --, 
   {{0xb8f42432,0x98b000e2,0xa91c1151,0x6d4c058a}},	//   _सु_, īcām_, _jožk, ofaa, 
   {{0x24082433,0x6d4c2434,0xa2ac2435,0x00000000}},	//   онии_, nfaa, ुपस्, --, 
   {{0x6d4c0421,0x69d800f1,0x00000000,0x00000000}},	//   ifaa, mlwe, --, --, 
   {{0xdb0c006a,0x69d82436,0x6d4c01d9,0x6d9003cd}},	//   _ambê, llwe, hfaa, _gåav, 
   {{0x69d82437,0x7f9000fd,0x21200de2,0xa91c2438}},	//   olwe, _mäqt, takh_, _nožk, 
   {{0x61f4022e,0x2454007b,0x00000000,0x00000000}},	//   _qiyl, _يناس, --, --, 
   {{0x69d82439,0x7dfc243a,0x232807d8,0x6d4c000f}},	//   ilwe, _mōse, _доли_, dfaa, 
   {{0x69d8243b,0xd9a8243c,0x6568243d,0x98b0068f}},	//   hlwe, _कष्ट, ldeh, żyć_, 
   {{0x6d4c243e,0x69d80117,0x63a0009a,0xfe780137}},	//   ffaa, klwe, mhln, чүн_, 
   {{0x6568243f,0x6d4c0083,0xc0bc2440,0xe8e400ec}},	//   ndeh, gfaa, _ሰላሙ_, _مڻ_, 
   {{0x7164005e,0x69d80028,0x6aa4030a,0x00000000}},	// [1f80] _سايك, dlwe, ezhf, --, 
   {{0x69d8000a,0x64482441,0x6d4c2442,0x63a0014b}},	//   elwe, itei, afaa, nhln, 
   {{0x64482443,0x6d4c0218,0x62800165,0x7f5c047e}},	//   htei, bfaa, nxlo, merq, 
   {{0xaae42444,0x656801a4,0x6d4c0067,0xdcb002dd}},	//   رسلو, jdeh, cfaa, _ٴىس_, 
   {{0xdb0c008c,0xa3bc0882,0x80dc04c5,0x2bd80034}},	//   þjón, _इदं_, ণশক্, _बीका, 
   {{0x65680ae3,0x69d805e4,0x64482445,0x7f5c2446}},	//   edeh, alwe, dtei, nerq, 
   {{0x2a34084c,0x64482447,0x46640108,0x00000000}},	//   _пэтр, etei, дрым_, --, 
   {{0x64482448,0x7f5c0113,0x3e480e78,0x3f982449}},	//   ftei, herq, ißt_, hkru_, 
   {{0x39440120,0x27e401ab,0x3f98244a,0x6448244b}},	//   _icms_, _fhln_, kkru_, gtei, 
   {{0x969406bb,0x657814dc,0x27e401ab,0x999802b1}},	//   _ореш, _enwh, _ghln_, kupū_, 
   {{0x6448244c,0x7f5c244d,0xdb0c0200,0x6568244e}},	//   atei, derq, _ambë, bdeh, 
   {{0xdb0c0194,0x644803fa,0x9578001f,0xa91c244f}},	//   _ejbø, btei, ጮቻችን_, _rožk, 
   {{0x14e02450,0x3e4803fa,0x644801e7,0x7afc07f5}},	//   _परिण, eßt_, ctei, _ogrt, 
   {{0x61ec01a2,0x7f5c2451,0x69d80007,0x9f48007f}},	//   _ďale, gerq, zlwe, nmbè_, 
   {{0xdb0c2452,0x77680067,0x51840063,0xdb1c00c7}},	//   _imbè, _madx, _жупа, bopú, 
   {{0xa2ac038e,0x6d4c2453,0x69d80007,0xdedc0023}},	//   ुपर्, ufaa, xlwe, ዒልካ_, 
   {{0xab7407d6,0x6d4c2454,0x2ae000ab,0xc2f00154}},	// [1f90] нгаш, rfaa, _करहु_, চুদি_, 
   {{0x6d4c2455,0x4fc40826,0x7f5c2456,0x656813d5}},	//   sfaa, _іспа, cerq, zdeh, 
   {{0x69d80b58,0x64482457,0x316801c7,0x6d4c01c7}},	//   tlwe, ztei, _kaaz_, pfaa, 
   {{0x64482458,0xa91c2230,0x6aa40165,0x6d4c0009}},	//   ytei, _koži, rzhf, qfaa, 
   {{0xdb0c0214,0x31682459,0x64481437,0xa91c0427}},	//   _ombè, _maaz_, xtei, _joži, 
   {{0xa3dc068f,0x66e4245a,0x23dc13f5,0xa91c0427}},	//   _थीं_, нола, _नींद, _moži, 
   {{0x92c011ba,0xe91800d6,0x3ddc025a,0xa91c245b}},	//   ্ধু_, _нові_, _âzwâ_, _loži, 
   {{0x6448245c,0xdb0c020c,0x7afc0841,0x39440010}},	//   ttei, _ambè, _zgrt, _gcms_, 
   {{0x6568245d,0xa91c245e,0x756801ed,0x77680009}},	//   rdeh, _noži, بینہ_, _fadx, 
   {{0x6568245f,0xf77400c7,0x2fd001a6,0x3f980327}},	//   sdeh, _аҧш_, jozg_, xkru_, 
   {{0x21682460,0x61442461,0x31680009,0x00000000}},	//   пини_, нена, _baaz_, --, 
   {{0x67202462,0x21682463,0x64482464,0x6280036b}},	//   _helj, чими_, ptei, rxlo, 
   {{0x66002465,0x7f5c2466,0x601402e3,0x02cc11a6}},	//   _hulk, terq, _ẹmbr, _सुरभ, 
   {{0x66002467,0xdd902468,0xb46402bf,0x672000f3}},	//   _kulk, گور_, _шкіл, _jelj, 
   {{0x66000664,0xe2982469,0x6d900158,0x7f5c02d1}},	//   _julk, _хай_, _nåas, rerq, 
   {{0xdd90246a,0x6600246b,0x3f98246c,0xdb0c246d}},	//   دور_, _mulk, skru_, _imbé, 
   {{0x7f5c246e,0x6600002d,0x672003ac,0x00000000}},	// [1fa0] perq, _lulk, _oelj, --, 
   {{0x6720246f,0xa3c01533,0x9e642470,0x660005da}},	//   _nelj, ्कि_, _звод, _oulk, 
   {{0xa91c0427,0xcee001ec,0xaec4004e,0x192c0092}},	//   _zoži, _бұрқ, _үбөл, _አምልኮ, 
   {{0xd8242471,0x99d400cf,0xd7f82472,0x80c800fe}},	//   едди, رتاا, пук_, ৰেণ্, 
   {{0x67202473,0x66002474,0x00000000,0x00000000}},	//   _belj, _aulk, --, --, 
   {{0x66002475,0x67200fb7,0xdb0c0066,0xacb000d1}},	//   _bulk, _celj, _ombé, _ئەكب, 
   {{0x66000100,0x67202476,0xdd100055,0x02cc01bc}},	//   _culk, _delj, _aüũu, _सुलभ, 
   {{0x66002477,0x67200254,0x00000000,0x00000000}},	//   _dulk, _eelj, --, --, 
   {{0xdb0c00d5,0x5ed00490,0x67202478,0x380401f0}},	//   _ambé, _दुसऱ, _felj, _розҳ, 
   {{0xc4500597,0x67200209,0x66002479,0xa91c247a}},	//   اضيع, _gelj, _fulk, _roži, 
   {{0x668000aa,0x6600247b,0xa91c0427,0x62840129}},	//   _نیول, _gulk, _soži, _àhol, 
   {{0x672005a1,0xa91c247c,0xa7fc002d,0xc68c0014}},	//   _zelj, _poži, _krűp, _دِم_, 
   {{0xe6280597,0x6600247d,0xdb0c003e,0x92c0015b}},	//   ĥôŗ_, _zulk, _embé, ্ধে_, 
   {{0xa91c01ef,0x00000000,0x00000000,0x00000000}},	//   _voži, --, --, --, 
   {{0x660001d9,0x2fd001a6,0x00000000,0x00000000}},	//   _xulk, rozg_, --, --, 
   {{0xa91c09a8,0x2bd807d0,0x6d900158,0xdce4247e}},	//   _toži, _बीजा, _råas, _alkı, 
   {{0x41c4082e,0x7de40220,0x6d900158,0x6d8401d9}},	// [1fb0] _حقيق, уірд, _såas, _یۅسہ_, 
   {{0x6e940022,0x4ae801f4,0x00000000,0x00000000}},	//   _аиоу, пьем_, --, --, 
   {{0x70e0000d,0x7f90013d,0x00000000,0x00000000}},	//   _नरुल, _täqr, --, --, 
   {{0xba74247f,0xdd140030,0x15c80055,0xd2440133}},	//   داكت, _päťd, _gṛṇī, _ێن_, 
   {{0x66002480,0x67202481,0x9ba00131,0x00000000}},	//   _sulk, _pelj, _ھەمى, --, 
   {{0x66002482,0x5cc005f5,0x00000000,0x00000000}},	//   _pulk, _төсв, --, --, 
   {{0xe5a42483,0x66000009,0x2ca80489,0x04840133}},	//   кики, _qulk, lzad_, کڕای_, 
   {{0x6720030a,0x2d882484,0x00000000,0x00000000}},	//   _welj, njae_, --, --, 
   {{0x67202485,0x290c2486,0x7dfc03a0,0x14202487}},	//   _telj, _ifea_, _mōsa, адым, 
   {{0xc6a42488,0x66002489,0xe298248a,0x75c800bc}},	//   _преи, _tulk, дао_, věze, 
   {{0x2d88248b,0xb2f40b32,0x3dc00227,0xd5ac036b}},	//   kjae_, ляющ, yniw_, صفی_, 
   {{0xe194248c,0x75c80118,0x00000000,0x00000000}},	//   троэ, těze, --, --, 
   {{0x2ca8248d,0xd00c0592,0xe36407a5,0x00000000}},	//   jzad_, يلَ_, _акли, --, 
   {{0x443c0a4d,0x2ca805be,0x645802d0,0x00000000}},	//   muu_, dzad_, _ipwi, --, 
   {{0x443c248e,0x290c0421,0x6d90248f,0x1d0800db}},	//   luu_, _ofea_, _råar, деби_, 
   {{0xa91c23cc,0x443c00b5,0xca64022e,0x00000000}},	//   _kožu, ouu_, _rejа, --, 
   {{0x443c2490,0xd1e8044e,0x4938001f,0x6d90007c}},	// [1fc0] nuu_, _ዘረባ_, _አምራቾ, _påar, 
   {{0x9f042491,0x290c20d6,0x443c0421,0xed58016c}},	//   _جودو, _afea_, iuu_, моӣ_, 
   {{0x443c2492,0x6cb80166,0xc2f00154,0x00000000}},	//   huu_, _җыяр_, চুরি_, --, 
   {{0x443c2493,0x64582494,0x290c0005,0xe3b8009e}},	//   kuu_, _opwi, _cfea_, ুতিব, 
   {{0xc32402a6,0x06ac00fe,0xa91c00ef,0x00000000}},	//   _মানি_, _চুলি, _nožu, --, 
   {{0x443c2495,0x68ec0209,0x645c0327,0x00000000}},	//   duu_, ýada, ħsil, --, 
   {{0x64580295,0xdce4007f,0xabc401e0,0x00000000}},	//   _apwi, _makč, _сарҙ, --, 
   {{0xd4980364,0x443c2496,0xa91c110c,0x75cc0073}},	//   дро_, fuu_, _božu, ावेळ, 
   {{0x443c2497,0xa91c0427,0x9f580200,0x629401bf}},	//   guu_, _požv, _cipë_, øzon, 
   {{0xa91c107d,0xdce40153,0x96b40063,0xb9dc0257}},	//   _dožu, _nakč, _исељ, _ኤሊ_, 
   {{0x64582498,0x443c2499,0xc7d40375,0x00000000}},	//   _epwi, auu_, _יומי_, --, 
   {{0x443c249a,0xe8181b90,0xfbd800eb,0x00000000}},	//   buu_, नीका_, থগিত, --, 
   {{0x443c249b,0xa3c001ad,0xa3dc000d,0x291006be}},	//   cuu_, ्कश_, _थीक_, _əza_, 
   {{0x2fc40254,0x9998013a,0x00000000,0x00000000}},	//   õlg_, kupů_, --, --, 
   {{0xa3c0023e,0x0264008e,0x7e281cd0,0x00000000}},	//   ्कर_, _ашый_, кіта_, --, 
   {{0xc0f00020,0x0dc80835,0x518400d8,0x00000000}},	//   ቀርም_, фуги_, _јука, --, 
   {{0x2d880077,0xa91c00d7,0x7d08032e,0x4fc400c0}},	// [1fd0] rjae_, _možt, _séró, _асна, 
   {{0x2ca80165,0x6f080241,0x6bd800e3,0x00000000}},	//   rzad_, _dèbó, رواس_, --, 
   {{0xc984249c,0x443c249d,0x00000000,0x00000000}},	//   куди, zuu_, --, --, 
   {{0x443c249e,0xf99005d9,0xdd90249f,0xac180276}},	//   yuu_, يبن_, _هوپ_, _пому_, 
   {{0x443c0d62,0x7c8424a0,0x9f58007f,0xb86400f1}},	//   xuu_, _куре, _bipè_, لاوو, 
   {{0x443c24a1,0xfe7024a2,0x1ae003d4,0xa91c0171}},	//   vuu_, _ادی_, _বলৰা, _rožu, 
   {{0x443c00b4,0xc6a400a7,0x98f400d1,0x0948014b}},	//   wuu_, ърди, نغۇچ, _очаи_, 
   {{0x443c248e,0xa91c05ce,0x7d80001f,0x88b401af}},	//   tuu_, _požu, _የሙዚቃ_, _иҫер_, 
   {{0xa3c01ab2,0xb33c031c,0x07440334,0x00000000}},	//   ्कल_, ghħo, _ахем, --, 
   {{0x443c0a4d,0x75c80118,0xdb1c00c7,0x53c400db}},	//   ruu_, tězc, kopý, лгым_, 
   {{0xe29824a3,0x443c0a4d,0xf77024a4,0x64a400c7}},	//   хан_, suu_, _باق_, _әала, 
   {{0xa134007b,0x00000000,0x00000000,0x00000000}},	//   دردش, --, --, --, 
   {{0x443c198f,0xdce40100,0x00000000,0x00000000}},	//   quu_, _pakč, --, --, 
   {{0xa2e424a5,0x442c24a6,0x00000000,0x00000000}},	//   _йолд, _ivg_, --, --, 
   {{0x442c01ed,0x00000000,0x00000000,0x00000000}},	//   _hvg_, --, --, --, 
   {{0xdcb024a7,0x1fb419b8,0x80c80183,0xf2c401e0}},	//   مىز_, _әсир, ৰেষ্, _әсән, 
   {{0xa2ac04e4,0x00000000,0x00000000,0x00000000}},	// [1fe0] ुपक्, --, --, --, 
   {{0x442c24a8,0xc0e40116,0x99980118,0x1f640229}},	//   _mvg_, _йоқк, tupů_, _ском, 
   {{0x2c0403d4,0x00000000,0x00000000,0x00000000}},	//   শীলৈ_, --, --, --, 
   {{0x9f580699,0x18a4005b,0x442c002f,0x98a4031c}},	//   _sipè_, лаем, _ovg_, nfoħ_, 
   {{0x442c05e4,0x491007f7,0xa91c0419,0xbef401f9}},	//   _nvg_, दड़ो_, _rožt, _आणुन_, 
   {{0xa91c02fb,0x00000000,0x00000000,0x00000000}},	//   _božs, --, --, --, 
   {{0x9f58007f,0x442c0d63,0x995800d8,0x2bd00825}},	//   _vipè_, _avg_, _пјаф_, तकरा, 
   {{0x743424a9,0x442c24aa,0xca940115,0x00000000}},	//   аниф, _bvg_, _גדלי_, --, 
   {{0xd32424ab,0x48e00a83,0x9f58020c,0xa91c0024}},	//   льни, _готв, _tipè_, _vožt, 
   {{0x325424ac,0xbef40490,0x045424ad,0x00000000}},	//   авор, _आणून_, اجيت_, --, 
   {{0x442c002f,0xdb1c0210,0x00000000,0x00000000}},	//   _evg_, lopó, --, --, 
   {{0x442c0395,0x733424ae,0x14c8005b,0x0580014b}},	//   _fvg_, دىگا, _пыли_, _гушм, 
   {{0x442c24af,0xc5f00302,0xdb1c24b0,0xc0c824b1}},	//   _gvg_, _הדף_, nopó, гуре_, 
   {{0xa3c001bc,0xdb1c0118,0x00000000,0x00000000}},	//   ्कः_, topý, --, --, 
   {{0x442c002f,0x00000000,0x00000000,0x00000000}},	//   _zvg_, --, --, --, 
   {{0x823024b2,0x8d7424b3,0xc2780bd9,0x00000000}},	//   _اروا, داسا, _טרוי, --, 
   {{0xc32403d4,0xe6e00034,0x0fe000ee,0xdb1c00e4}},	// [1ff0] _মাতি_, _फर्ज, _гөвү, jopó, 
   {{0x798024b4,0xbcf40108,0x00000000,0x00000000}},	//   _anmw, спущ, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x28b80276,0x9f5801e1,0x7c5800db,0x3f8c0254}},	//   кулэ_, _ripé_, ئلەر_, öduv_, 
   {{0x9f5801e1,0x00000000,0x00000000,0x00000000}},	//   _sipé_, --, --, --, 
   {{0x442c24b5,0x26580798,0xdc3800d9,0x00000000}},	//   _rvg_, вриќ_, _בעשר, --, 
   {{0x16a41363,0xa91c0010,0x442c24b6,0xa6c802e8}},	//   ивши_, _anže, _svg_, ълка_, 
   {{0xdce400b8,0xd8840014,0xe57800c7,0x00000000}},	//   _hakā, _چھون_, тзи_, --, 
   {{0x291c24b7,0x18b00116,0xdce424b8,0x39400332}},	//   mbwa_, _мәшр, _kakā, óise_, 
   {{0xe7a802f8,0xdb1c067c,0x69c80fac,0x68e80857}},	//   _कतिप, lopò, _hjee, _ized, 
   {{0xdce424b9,0x26d024ba,0xa2e424bb,0xc79400c7}},	//   _makā, _âzo_, ронд, _ирҧы, 
   {{0x442c172e,0x69c804ba,0x66040030,0xdb1c24bc}},	//   _tvg_, _jjee, íhku, nopò, 
   {{0xe3b024bd,0x291c24be,0xd83c00d0,0x69c801e1}},	//   _ورت_, ibwa_, _účte_, _mjee, 
   {{0xdce400b8,0x1ea80b24,0x00000000,0x00000000}},	//   _nakā, نازي_, --, --, 
   {{0x69c824bf,0x291c033b,0x6ee4009a,0x21a4003b}},	//   _ojee, kbwa_, مسفل, _вийм, 
   {{0x3d20068f,0x69c824c0,0xe1f001fd,0x2d940a89}},	//   बरें_, _njee, _بست_, брус, 
  
   {{0xdce400b8,0x291c007f,0x00000000,0x00000000}},	// [2000] _bakā, dbwa_, --, --, 
   {{0x69c824c1,0x109823e4,0x291c0a49,0xdce400dc}},	//   _ajee, _סביב, ebwa_, _cakā, 
   {{0x68e824c2,0x75ec002d,0xdce407d7,0xcb6424c3}},	//   _azed, lûze, _dakā, рахе_, 
   {{0xdb1c24c4,0x291c0083,0xd5400241,0xf3fc00fe}},	//   topó, gbwa_, _mẹ́f, _এবছৰ_, 
   {{0x8eb024c5,0xa91c24c6,0x69c801f5,0xd54001e1}},	//   _همیش, _požr, _djee, _lẹ́f, 
   {{0xdb1c24c7,0x68e805b8,0x69c804ba,0xdce4002b}},	//   ropó, _dzed, _ejee, _gakā, 
   {{0x68e80107,0xda7001d9,0x79800083,0x291c0a49}},	//   _ezed, _بُز_, _tnmw, bbwa_, 
   {{0xdb1c24c8,0x59dc02a0,0x00000000,0x00000000}},	//   popó, _फीचर, --, --, 
   {{0x73d824c9,0x46e40b8d,0x06e4151e,0xdce4002b}},	//   лдир_, лдән_, лмәк_, _yakā, 
   {{0xd37824ca,0x00000000,0x00000000,0x00000000}},	//   тчи_, --, --, --, 
   {{0xaf0000bd,0x7bdc017a,0xab78010f,0x870800e5}},	//   ্রমণ_, _mkru, אָרז, _شعلہ_, 
   {{0x3d20012d,0x00000000,0x00000000,0x00000000}},	//   बरों_, --, --, --, 
   {{0xdb0c0109,0x93e401d5,0x00000000,0x00000000}},	//   _ombà, _кўкл, --, --, 
   {{0x7bdc013b,0x2cac00ee,0x00000000,0x00000000}},	//   _nkru, _ýedi_, --, --, 
   {{0xdce424cb,0x00000000,0x00000000,0x00000000}},	//   _rakā, --, --, --, 
   {{0xdce41991,0xe7ec02e5,0xd24c01d3,0x00000000}},	//   _sakā, _चीना_, _فنڈ_, --, 
   {{0xdce40f40,0x6be400c6,0xf414010f,0x7054009a}},	// [2010] _pakā, مكرم, מפּ_, _انخا, 
   {{0x95040135,0xfbd0004b,0x69c801f5,0x7bdc013a}},	//   _ངུའི_, وتل_, _sjee, _ckru, 
   {{0x68e800dd,0x9f580109,0x7ff424cc,0xaa5424cd}},	//   _szed, _mipì_, _بسيا, свеш, 
   {{0x7bdc1529,0xe61807d6,0x00000000,0x00000000}},	//   _ekru, қди_, --, --, 
   {{0xe73824ce,0xdb1c1f40,0x75c800bc,0x1ee812ea}},	//   гел_, ropò, tězn, _لویی_, 
   {{0x8a1424cf,0xe57800a9,0x291c04ba,0x23a80241}},	//   _نظرا, glŷn_, sbwa_, _kúje_, 
   {{0xf77024d0,0x69c824d1,0xdb1c004e,0x39400332}},	//   بان_, _tjee, popò, óisc_, 
   {{0x69c80050,0x6b940161,0xdb0c0022,0x9f9401a8}},	//   _ujee, _hozg, _imbá, hæð_, 
   {{0x69d824d2,0xbee402f8,0x68e824d3,0x6f04014f}},	//   mowe, _गर्न_, _uzed, _oghc, 
   {{0x69d824d4,0xf770027d,0x00000000,0x00000000}},	//   lowe, _يال_, --, --, 
   {{0x6b94089e,0x237c044e,0x00000000,0x00000000}},	//   _mozg, _ንገዛእ_, --, --, 
   {{0xa2e424d5,0x69d824d6,0x6b9401e4,0x75ec045f}},	//   _қойд, nowe, _lozg, tûze, 
   {{0xd24c1482,0x248824d7,0x20d424d8,0xaf000183}},	//   ونی_, _çam_, сінс, ্ৰমণ_, 
   {{0x443c24d9,0x69d824da,0x232824db,0x201c007f}},	//   mru_, howe, _соки_, ďti_, 
   {{0xdee424dc,0x236424dd,0x69d824de,0x7bdc0100}},	//   сови, melj_, kowe, _rkru, 
   {{0x443c24df,0xdde824e0,0x6f04016d,0x69d80034}},	//   oru_, ارسه_, _eghc, jowe, 
   {{0x443c24e1,0x69d8068f,0x6b9424e2,0x3f8c00c5}},	// [2020] nru_, dowe, _bozg, ödus_, 
   {{0x6b940007,0x443c24e3,0x69d80086,0x00000000}},	//   _cozg, iru_, eowe, --, 
   {{0x69d8016c,0x443c24e4,0x22440051,0x00000000}},	//   fowe, hru_, nulk_, --, 
   {{0x5d840491,0xd94424e5,0x69d824e6,0x23642230}},	//   _الحل, седи, gowe, helj_, 
   {{0x6b940369,0xdb0c0077,0x236424e7,0x98540798}},	//   _fozg, _embá, kelj_, стеш, 
   {{0x236405be,0x6b9400ee,0xb8f400b8,0x2244007f}},	//   jelj_, _gozg, _akṣī, kulk_, 
   {{0x9f500789,0x69d8012d,0x15c8002b,0x00000000}},	//   _huyó_, bowe, _mṛṇā, --, 
   {{0x98a40262,0x443c24e8,0x4a980a1e,0x8604007b}},	//   _либе, fru_, _גילג, حقيق_, 
   {{0x443c24e9,0x6b9424ea,0x9f580395,0x23641a48}},	//   gru_, _yozg, _pipì_, felj_, 
   {{0x23640427,0x15c800cd,0x136801f0,0x00000000}},	//   gelj_, _nṛṇā, ушии_, --, 
   {{0x443c24eb,0x674400bc,0xf28801c6,0x00000000}},	//   aru_, ňují, рөлд_, --, 
   {{0x68440022,0x67ec0022,0x00000000,0x00000000}},	//   _ынӡа, rúje, --, --, 
   {{0x443c24ec,0xa4840451,0x9f9401a8,0x23640427}},	//   cru_, _وجهن, tæð_, belj_, 
   {{0x4fc424ed,0x06ac02f5,0x69d824ee,0x63a024ef}},	//   ссма, _চুটি, zowe, ckln, 
   {{0x69d824f0,0x82301913,0x6b9424f1,0x741401f7}},	//   yowe, _فريا, _rozg, _اوڪا, 
   {{0x69d80472,0x00000000,0x00000000,0x00000000}},	//   xowe, --, --, --, 
   {{0x6b94009d,0x8c340107,0xa3dc01f9,0x00000000}},	// [2030] _pozg, созӣ_, ढतच_, --, 
   {{0x6844001f,0x69d824f2,0x09b00a59,0x15c80055}},	//   _የልማት, wowe, ूच्य, _gṛṇā, 
   {{0x69d824f3,0xdb0c01bf,0xdcf40419,0x8af403b9}},	//   towe, _ombæ, chyľ, _şəbn, 
   {{0x443c24f4,0x23640010,0x00000000,0x00000000}},	//   yru_, zelj_, --, --, 
   {{0x6d5c22a9,0x69d824f5,0xaad800e1,0x684400d3}},	//   _ibsa, rowe, _बुरक, інка, 
   {{0x69d824f6,0x443c24f7,0xdb0c0162,0x7a300022}},	//   sowe, vru_, _ambæ, _ẽtee, 
   {{0x443c24f8,0x66c40588,0x236409a8,0x87240150}},	//   wru_, цәаж, velj_, _ۇعام, 
   {{0x443c24f9,0xdd040055,0xdc540244,0x00000000}},	//   tru_, _āpīp, _ارێک, --, 
   {{0x443c24fa,0x00000000,0x00000000,0x00000000}},	//   uru_, --, --, --, 
   {{0xdb0c09f3,0x9f58004e,0xe3b824fb,0x00000000}},	//   _embæ, _pipí_, рбо_, --, 
   {{0x6d5c0745,0xa18824fc,0x443c24fd,0x00000000}},	//   _obsa, абна_, sru_, --, 
   {{0x443c24fe,0x23640427,0x2244007c,0xaf000154}},	//   pru_, selj_, rulk_, ্রাণ_, 
   {{0x23640e3c,0x443c02d1,0x00000000,0x00000000}},	//   pelj_, qru_, --, --, 
   {{0xdce4033f,0x25ac0115,0x22440037,0x9ea8009d}},	//   _jaką, lhel_, pulk_, авга_, 
   {{0x1d0824ff,0x9f500248,0x1d9401a9,0x00000000}},	//   иеви_, _buyò_, ораё, --, 
   {{0x6d5c0076,0x9c2401a9,0x00000000,0x00000000}},	//   _cbsa, ждад, --, --, 
   {{0x6d5c02b9,0xa0682500,0x248c1513,0x15c800cd}},	// [2040] _dbsa, _тапа_, nxem_, _tṛṇā, 
   {{0x0fc00046,0x61e41f53,0x5f44141b,0x6d5c02d0}},	//   _ойын, llkl, _بندل, _ebsa, 
   {{0x61e42501,0x00000000,0x00000000,0x00000000}},	//   olkl, --, --, --, 
   {{0xc9802502,0x248c01a9,0x58842503,0x00000000}},	//   души, kxem_, жыка, --, 
   {{0x25ac0214,0xdb1c0200,0xadc401af,0x00000000}},	//   dhel_, nipë, _хаяһ, --, 
   {{0xc7a023b3,0xfbc800ec,0x61e4002f,0x9078011a}},	//   мичк, _اڀري_, hlkl, יטני, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x25ac2504,0xdeec01f3,0x61e4005c,0x34940139}},	//   ghel_, _ጀግና_, jlkl, заир, 
   {{0x93882505,0x00000000,0x00000000,0x00000000}},	//   асна_, --, --, --, 
   {{0x61e42506,0xfbd800cc,0x00000000,0x00000000}},	//   elkl, _থওঁত, --, --, 
   {{0xcb100302,0x25ac009a,0x27e803f9,0xa020000d}},	//   ולת_, bhel_, ɓan_, _ööjo, 
   {{0xdce4033f,0x23a80092,0xdec80023,0xdb0c2507}},	//   _zaką, _ህገወጥ_, _በልካ_, _umbæ, 
   {{0x25d8034c,0x3dc000e8,0xcf980120,0x2eb400cd}},	//   _اهنگ_, diiw_, ајв_, ृप्त, 
   {{0x4ea410e4,0x00000000,0x00000000,0x00000000}},	//   орба, --, --, --, 
   {{0x6d5c01ab,0x625c031c,0xd13800c0,0xb4b401ee}},	//   _pbsa, għoġ, _кхп_, _фиҙә, 
   {{0x51841638,0x4638008f,0x423400df,0x8260009f}},	//   _фука, יעלע, _ונהל_, _آهين, 
   {{0x82b40f50,0xdb24006a,0xc19c0375,0x649c01e4}},	// [2050] _བཟོའ, _âpûp, _כשהי, rɨig, 
   {{0x09d00a28,0x25ac0dd4,0xdec802d3,0x0af001c6}},	//   तव्य, zhel_, _በልኩ_, дүгэ, 
   {{0xaf00015b,0x00000000,0x00000000,0x00000000}},	//   ্রহণ_, --, --, --, 
   {{0x6d5c0c8c,0x67ec04d4,0x25ac009a,0x00000000}},	//   _ubsa, dúja, xhel_, --, 
   {{0xdb1c2508,0x2d982509,0x6d4c250a,0x248c0548}},	//   kipè, _iose_, mgaa, xxem_, 
   {{0x2d98250b,0x7b64250c,0x8a1800f2,0x00000000}},	//   _hose_, _отсе, _نترس_, --, 
   {{0x25ac250d,0x67ec00dd,0x7dfc0270,0xe5a404a9}},	//   thel_, gúja, _sōsi, зийи, 
   {{0x6d4c0680,0x2d98250e,0x00000000,0x00000000}},	//   ngaa, _jose_, --, --, 
   {{0x2d98250f,0x795004d3,0xe3b82510,0x6d4c2511}},	//   _mose_, _شێوا, йби_, igaa, 
   {{0x25ac2512,0x2d982513,0x248c2456,0x6d4c0036}},	//   shel_, _lose_, rxem_, hgaa, 
   {{0x25ac2514,0xaabc0846,0x6d4c2515,0x80c800fe}},	//   phel_, ्पिक, kgaa, ৰেঞ্, 
   {{0x6d4c2516,0x2d982517,0x36040132,0xa3a80014}},	//   jgaa, _nose_, _قولف, _گُتل_, 
   {{0x6d4c2518,0x261001fb,0x30742519,0x65680076}},	//   dgaa, _háo_, мурс, meeh, 
   {{0x2d98020c,0x6d4c251a,0x6568251b,0xdb1c251c}},	//   _aose_, egaa, leeh, cipè, 
   {{0x2d98251d,0x6d4c251e,0x6448251f,0xdb1c0023}},	//   _bose_, fgaa, luei, sipë, 
   {{0x2d982520,0x6d4c2521,0x9ea80aac,0x26100051}},	//   _cose_, ggaa, авҳа_, _máo_, 
   {{0xdb1c2522,0x7a0c2523,0x1c442524,0x64482525}},	// [2060] qipë, _iğti, янам, nuei, 
   {{0x6d4c2526,0x9f580241,0x644800a3,0x75c80118}},	//   agaa, _fipá_, iuei, tězk, 
   {{0xdcf82527,0x2d982528,0x644806c8,0x261001fb}},	//   _گردش_, _fose_, huei, _náo_, 
   {{0x5f442529,0x2d98252a,0xaf0003d4,0x6448252b}},	//   _بنگل, _gose_, ্ৰহণ_, kuei, 
   {{0xa3bc05ba,0x6448252c,0x6568000d,0x4810155b}},	//   ीचा_, juei, deeh, еміс, 
   {{0x261001dc,0x2d980537,0x64480228,0xdb1c252d}},	//   _báo_, _zose_, duei, kipé, 
   {{0x2d98252e,0xd5b8252f,0x261007ae,0x6568002d}},	//   _yose_, йси_, _cáo_, feeh, 
   {{0xdedc0023,0x26100051,0x741402f2,0x2d982530}},	//   ዒልና_, _dáo_, ووبا, _xose_, 
   {{0x64482531,0x27f000c0,0x69940345,0x00000000}},	//   guei, _šonų_, _تێنس_, --, 
   {{0x7dfc007f,0xdee80b82,0x9388035b,0x47c0003b}},	//   _včsy, ሙርን_, ссиа_, _збув, 
   {{0xf28c0998,0x6d4c2532,0x6568009f,0x0ed82533}},	//   criﬁ, ygaa, beeh, _मुंड, 
   {{0x64482534,0x70542535,0x31080137,0x69c00241}},	//   buei, ونجا, өнүп_, _ìlet, 
   {{0x64482536,0x2d982537,0x6d4c2538,0xd3c400cf}},	//   cuei, _rose_, vgaa, _ىتتى, 
   {{0x2258068f,0x30e000dc,0x2d982539,0x6d4c0067}},	//   ńska_, _गुणः_, _sose_, wgaa, 
   {{0x6d4c253a,0xdb1c253b,0x6494031c,0x2d98253c}},	//   tgaa, cipé, _eżiġ, _pose_, 
   {{0x6d4c253d,0x2d980200,0x00000000,0x00000000}},	//   ugaa, _qose_, --, --, 
   {{0x6d4c253e,0x2d980e8a,0x6b7405a2,0x417401ec}},	// [2070] rgaa, _vose_, млау, _سايس, 
   {{0x6d4c253f,0x2d982540,0x65682541,0x9f5801e1}},	//   sgaa, _wose_, zeeh, _tipá_, 
   {{0x2d982542,0x6d4c2543,0x6448002f,0x9d500133}},	//   _tose_, pgaa, zuei, رچێت, 
   {{0xdb1c02f6,0x261001fb,0x2d980064,0x00000000}},	//   enpä, _ráo_, _uose_, --, 
   {{0x656801a4,0x261001fb,0x00000000,0x00000000}},	//   veeh, _sáo_, --, --, 
   {{0x66e41621,0x65680083,0x26100051,0x00000000}},	//   мола, weeh, _páo_, --, 
   {{0x9ba02544,0x6568022f,0xe9180212,0x7f3c00df}},	//   _جەلى, teeh, _мові_, זעוו, 
   {{0x64482545,0xdb1c005b,0xe7ec00e1,0x29980092}},	//   tuei, anpä, _चीरा_, ሊምፒክ_, 
   {{0x7a0c00a2,0x656800a3,0xa3b82546,0x00000000}},	//   _eştd, reeh, قادر_, --, 
   {{0xf7702547,0x65682548,0x2610001e,0x64482549}},	//   _مام_, seeh, _táo_, ruei, 
   {{0x64481140,0xe298254a,0x630401d5,0xb5c800f2}},	//   suei, цан_, بودل, _کونم_, 
   {{0x64480618,0xdb1c254b,0x985c001f,0xa97800df}},	//   puei, ripé, _ሳይሆኑ_, קאָכ, 
   {{0x6448254c,0x7a0c05d1,0x290800e8,0xa3b80066}},	//   quei, _işte, ñaay_, _واتر_, 
   {{0x63040517,0xa7fc01d3,0x00000000,0x00000000}},	//   _قوشل, _zsűr, --, --, 
   {{0xdb0c0129,0x5de402d5,0x00000000,0x00000000}},	//   _embû, джва, --, --, 
   {{0xdd90254d,0x00000000,0x00000000,0x00000000}},	//   خور_, --, --, --, 
   {{0x5f74254e,0xdd9401ec,0xdb1c0108,0x00000000}},	// [2080] _قادر, паңы, ynpä, --, 
   {{0x03c80051,0x00000000,0x00000000,0x00000000}},	//   _điện, --, --, --, 
   {{0x1d08254f,0x61f40649,0x9a682550,0x3a38017a}},	//   _мени_, _khyl, تمال_, _qvrp_, 
   {{0xdca407d6,0x5ca4010a,0x00000000,0x00000000}},	//   _жами, _жимб, --, --, 
   {{0x2a6c00f3,0x61f400d8,0xd7f81d0f,0xf8a401c6}},	//   _ćebe_, _mhyl, оук_, эгдү, 
   {{0x7a0c084c,0xe6c800cd,0xdcfc0064,0x00000000}},	//   _aşte, िपूज, _švėg, --, 
   {{0x6b8002d2,0x00000000,0x00000000,0x00000000}},	//   _ólga, --, --, --, 
   {{0xdce400c0,0xf8b80132,0x00000000,0x00000000}},	//   _sakę, _нөл_, --, --, 
   {{0x13682551,0x4c98008f,0x0ee801ad,0xd49823be}},	//   ошни_, ַשטע, _टर्स_, юрк_, 
   {{0x8898011a,0x69c00ca8,0x00000000,0x00000000}},	//   _ובמי, _ìler, --, --, 
   {{0xc32400fe,0x00000000,0x00000000,0x00000000}},	//   _মাখি_, --, --, --, 
   {{0x61f42552,0x46a008ca,0xc69000d9,0x393c0023}},	//   _chyl, _шахв, _שאף_, ረታዉያ, 
   {{0xe6ac0248,0x00000000,0x00000000,0x00000000}},	//   _ìbòò, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa3bc033f,0x00000000,0x00000000,0x00000000}},	//   ीचर_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3cfc01c0,0x3c58084c,0x00000000,0x00000000}},	// [2090] рvv_, митэ_, --, --, 
   {{0x21f001f1,0x21d41d86,0xac940107,0x61f40200}},	//   máha_, rāhe_, _ҷамш, _zhyl, 
   {{0x21f00af2,0xfd1001ed,0x60d40175,0xa82401d3}},	//   láha_, اجہ_, _zxym, ڑکان, 
   {{0x69c800c8,0x9f5802f6,0x9c800219,0xac942553}},	//   _ĉees, _eipä_, ščad, _замш, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6b7401c4,0x00000000,0x00000000,0x00000000}},	//   _ялгу, --, --, --, 
   {{0xba280014,0x23b40241,0x2fc0045a,0x21f000e4}},	//   _ٲسِم_, _lùjù_, _mmhg_, háha_, 
   {{0x393c02d3,0x21f000e4,0xe2980116,0xf8c001f9}},	//   ረታውያ, káha_, җам_, _शेवय, 
   {{0x290c0395,0x44280ba1,0x61f40142,0xa7b8013d}},	//   _igea_, èc_, _rhyl, _елау_, 
   {{0xdb0c006a,0x61f403a2,0xa91c00c0,0xe2b4009d}},	//   _albê, _shyl, _rožy, есмэ, 
   {{0x61f42554,0x00000000,0x00000000,0x00000000}},	//   _phyl, --, --, --, 
   {{0x22580034,0x68e804ba,0xa0682555,0xa91c0006}},	//   ńsko_, _kyed, пама_, _požy, 
   {{0x32082556,0x6abc0b33,0x224400b5,0x00000000}},	//   _diay_, ्पुर, srlk_, --, 
   {{0x65780374,0x61f40493,0x24580100,0x705002f2}},	//   _hawh, _whyl, mèm_, گۆیا, 
   {{0x61f40649,0x24582557,0x65780374,0x68e804ba}},	//   _thyl, lèm_, _kawh, _lyed, 
   {{0x32080016,0x68e8013e,0x290c2558,0x65782559}},	//   _giay_, _oyed, _ngea_, _jawh, 
   {{0x68e8255a,0x8c40255b,0x657804fe,0xf390001e}},	// [20a0] _nyed, лете, _mawh, _mảnh_, 
   {{0x6abc255c,0x290c0154,0x320805da,0xf3900208}},	//   ्पूर, _agea_, _ziay_, _lảnh_, 
   {{0x68e8255d,0x657802d0,0x66280165,0xf3900051}},	//   _ayed, _oawh, łskʷ, _oảnh_, 
   {{0x2010255e,0x68e80083,0x657802b5,0x644400b0}},	//   _kuyi_, _byed, _nawh, _āhin, 
   {{0x201002a8,0xdb1c255f,0xd7e402d5,0x00000000}},	//   _juyi_, lipí, ніко, --, 
   {{0x657800b0,0x201002a8,0x290c2560,0x24582561}},	//   _aawh, _muyi_, _egea_, dèm_, 
   {{0x68e82562,0x7c242563,0xd9442564,0xd044016b}},	//   _eyed, lpir, _певи, _ɑmɑm, 
   {{0xf39007ae,0x24580100,0x00000000,0x00000000}},	//   _cảnh_, fèm_, --, --, 
   {{0x7c242565,0x68e8013f,0x94a82566,0x2010198f}},	//   npir, _gyed, ятка_, _nuyi_, 
   {{0x3208003e,0x21f00306,0xd244010b,0x7c242567}},	//   _siay_, váha_, нэми, ipir, 
   {{0x65780369,0xdb0c2568,0x0bb40375,0x7c240200}},	//   _fawh, _albë, גלים_, hpir, 
   {{0x7c240cfe,0x20102569,0x65780327,0x24580ba1}},	//   kpir, _buyi_, _gawh, bèm_, 
   {{0x64580472,0xe874001f,0x628402d2,0x53a40006}},	//   _gqwi, _በፍጹም_, _áhon, _падб, 
   {{0x7c24151c,0xaad80037,0x3294007b,0x44f00006}},	//   dpir, _बुझक, _للتأ, _спіс, 
   {{0xfe70066d,0x0ed8256a,0x7c240200,0xbed4119e}},	//   یدہ_, _मुखड, epir, горј, 
   {{0x201000d2,0x46c000c5,0x00000000,0x00000000}},	//   _fuyi_, _वइसह, --, --, 
   {{0x3cfc256b,0x7c24256c,0xa02003e0,0x00000000}},	// [20b0] लेले_, gpir, _şöva, --, 
   {{0xa91c256d,0x21d40882,0x3b54084c,0x00000000}},	//   _inži, māha_, лкур, --, 
   {{0xc3300302,0xa93413d6,0x2458007f,0x00000000}},	//   רוע_, вееш, zèm_, --, 
   {{0x245802bd,0xac18004e,0xcd480107,0x00000000}},	//   yèm_, _оому_, _эчод_, --, 
   {{0x65780374,0xf39001fb,0x7c8400ee,0x1dc0256e}},	//   _rawh, _rảnh_, _йуре, _төрн, 
   {{0x18a0256f,0x65782570,0x98a02571,0xf39001fb}},	//   рашм, _sawh, рише, _sảnh_, 
   {{0x657802b1,0x290c0c86,0xf1e001bc,0x2458033b}},	//   _pawh, _tgea_, नवान, wèm_, 
   {{0xd6cc0491,0xdb0c0ba1,0x6578047e,0xa5080276}},	//   تقى_, _albè, _qawh, мейа_, 
   {{0x68e82572,0x65780810,0xa024009e,0x7a0c2573}},	//   _uyed, _vawh, _বিভব_, _işta, 
   {{0x213005b1,0x20100083,0x245802e2,0x00000000}},	//   _seyh_, _ruyi_, rèm_, --, 
   {{0x65780325,0xa91c01fa,0x20100b45,0x7c242574}},	//   _tawh, _anži, _suyi_, zpir, 
   {{0x20102575,0xa0a400d1,0x7c242576,0x2458007f}},	//   _puyi_, вамд, ypir, pèm_, 
   {{0x7c242577,0x201001b9,0x9f48004e,0x7cf80241}},	//   xpir, _quyi_, llbé_, _múrí, 
   {{0x64482578,0x201002b9,0xe8400023,0xdb0c0174}},	//   mrei, _vuyi_, _ኣይተቐ, _umbø, 
   {{0xd0042579,0xdee41049,0x6448257a,0x6abc257b}},	//   тере_, тови, lrei, ्पोर, 
   {{0xd00c066d,0x6280257c,0x442c002f,0x00000000}},	//   صلہ_, mvlo, _kwg_, --, 
   {{0x6280257d,0xa3c40882,0x4d600798,0xd5bc00b8}},	// [20c0] lvlo, _एषा_, јкув, _śāka_, 
   {{0x7c24257e,0x6448257f,0xd00c2580,0x442c03cb}},	//   rpir, irei, _گلی_, _mwg_, 
   {{0x64482581,0x62802582,0x442c0097,0x8c400276}},	//   hrei, nvlo, _lwg_, леӂе, 
   {{0x64482583,0x18a411db,0x442c05b1,0xd00c2584}},	//   krei, каем, _owg_, _دلی_, 
   {{0x442c0211,0x487000f7,0x98540137,0xffe000b8}},	//   _nwg_, لدوس, ттеш, _ṛṣis_, 
   {{0x62802585,0xda702586,0x7cd8030d,0x00000000}},	//   kvlo, _پُر_, ăмăр_, --, 
   {{0x07a007b5,0x99740022,0xc7a00120,0x4b78010f}},	//   рајн, _иуаш, ријк, _קאלו, 
   {{0x64482587,0x442c2588,0x248805be,0x62802589}},	//   frei, _bwg_, _šama_, dvlo, 
   {{0x6448258a,0xdb0c01d3,0x057000d1,0x649c01e4}},	//   grei, _albé, شايد, sɨin, 
   {{0x442c0207,0x75c800bc,0xb27400d8,0x38040117}},	//   _dwg_, tězs, глош, _созҳ, 
   {{0x26100010,0x442c167c,0xcb340a1e,0x62800b4f}},	//   _cšod_, _ewg_, כניק_, gvlo, 
   {{0x6448258b,0x442c03cb,0xf484258c,0xd4e401d5}},	//   brei, _fwg_, _ماتی, _июли, 
   {{0xc058005e,0x7d000af2,0x037401d3,0x902807d5}},	//   кір_, _úmsh, رحیت_, ьцна_, 
   {{0xdce403e0,0x4fc400c7,0x00000000,0x00000000}},	//   _nokı, тсма, --, --, 
   {{0x2fcc05ce,0x2fd0026c,0x442c01e4,0xa4f400e5}},	//   đeg_, rnzg_, _zwg_, _لکیر_, 
   {{0x442c0457,0x21d402b1,0x7058004e,0x0c8400cf}},	//   _ywg_, pāha_, _заир_, кызм, 
   {{0x6abc258d,0x62940030,0x656c035b,0x03b400fe}},	// [20d0] ्प्र, äzov, _ñahe, ীকৰণ, 
   {{0x8aa4258e,0x60c0010e,0x00000000,0x00000000}},	//   кред, _ýoma, --, --, 
   {{0x65b40413,0x6e941291,0x00000000,0x00000000}},	//   _háhe, _صلحا, --, --, 
   {{0x3eac20e4,0x6448258f,0x2f140014,0x6934049e}},	//   ødte_, yrei, _جِگر, унду, 
   {{0x39440845,0x96640023,0x65b401ef,0x00000000}},	//   рніг, _መርገጻ, _jáhe, --, 
   {{0x64482590,0x442c01d4,0xdb1c004e,0x270c00bc}},	//   vrei, _rwg_, cipà, िखेर_, 
   {{0x64482591,0x442c01ab,0x98e40032,0xbb582592}},	//   wrei, _swg_, ксәһ, _шарх_, 
   {{0x442c01d4,0x64980120,0x60d80356,0x00000000}},	//   _pwg_, етор_, ştmi, --, 
   {{0x2ca82593,0x628001f5,0x240801f0,0xdce4013d}},	//   nyad_, wvlo, ннии_, _yokı, 
   {{0x62801a7c,0x375400db,0x00000000,0x00000000}},	//   tvlo, _ەپەس, --, --, 
   {{0x64482594,0xe4e400ee,0x36d412e7,0x62800165}},	//   srei, _өсдү, _кофр, uvlo, 
   {{0x442c0190,0x62802595,0x291c014b,0xdb1c07c5}},	//   _twg_, rvlo, ncwa_, zipà, 
   {{0x3fc80502,0x62800b4f,0x442c0112,0x00000000}},	//   ندسی_, svlo, _uwg_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x1ea805e6,0x00000000,0x00000000,0x00000000}},	//   راسي_, --, --, --, 
   {{0x25ac2596,0x65b402d2,0x00000000,0x00000000}},	//   nkel_, _fáhe, --, --, 
   {{0x291c009a,0xdb1c004e,0xed340276,0x00000000}},	// [20e0] dcwa_, tipà, рэсэ, --, 
   {{0x9f5c2597,0x61e42598,0x25ac00af,0xdb1c0077}},	//   ötä_, lokl, hkel_, fipá, 
   {{0x25ac2599,0x533400c8,0xdb0c07c5,0xdb1c0109}},	//   kkel_, רנען_, _imbü, ripà, 
   {{0x61e4259a,0x9f580ffb,0x291c01f0,0xe9e40212}},	//   nokl, _ripù_, gcwa_, аціо, 
   {{0x17c80137,0xdce4013d,0xd7c40108,0xdcf40055}},	//   нгди_, _tokı, лёко, bdyā, 
   {{0x25ac259b,0xc9500124,0x50d8010f,0x1ae400f3}},	//   ekel_, атәы, עקסא, _богм, 
   {{0xdb1c259c,0x61e4259d,0xabc401e0,0x21f000bc}},	//   cipá, kokl, _тарҙ, táhl_, 
   {{0xd498259e,0x25ac259f,0x61e425a0,0x5b240124}},	//   еро_, gkel_, jokl, _шьҭа, 
   {{0x5690005e,0x61e400da,0x73d825a1,0x39440165}},	//   рақт, dokl, кдир_, _idms_, 
   {{0x1cb008ea,0x958425a2,0x25ac25a3,0x21f000bc}},	//   ྐྱར_, _әлде, akel_, sáhl_, 
   {{0xdb0c00d2,0x61e425a4,0xe5780042,0x00000000}},	//   _imbó, fokl, rlŷr_, --, 
   {{0x25ac25a5,0x61e425a6,0x65b403b2,0xd9f417ee}},	//   ckel_, gokl, _páhe, ेषित_, 
   {{0xc2e0006c,0xdb0c05d5,0x73c425a7,0xf43411ca}},	//   _қўши, _ambü, _پيغم, _телэ, 
   {{0x4390010b,0x03a003f6,0x21d400dc,0x00000000}},	//   _гашс, _гиљо, bāho_, --, 
   {{0x0ba40046,0x39440789,0x61e425a8,0x2ca80142}},	//   қшам, _odms_, bokl, wyad_, 
   {{0x61e425a9,0xa2d0012c,0x00000000,0x00000000}},	//   cokl, डपर्, --, --, 
   {{0x644400b0,0x7a0c00a2,0x4c140214,0xcc14009a}},	// [20f0] _āhik, _aşto, ابرس, اذرب, 
   {{0x25ac01e4,0xdb1c1e0b,0x00000000,0x00000000}},	//   zkel_, tipá, --, --, 
   {{0xfbd025aa,0x2ca825ab,0x25ac25ac,0x3f840134}},	//   ستك_, syad_, ykel_, ɛmu_, 
   {{0x6e2401ab,0xdb0c0174,0x25ac025c,0x00000000}},	//   _ithb, _umbý, xkel_, --, 
   {{0xf770004b,0x7a0c06be,0x00000000,0x00000000}},	//   ګان_, _eşto, --, --, 
   {{0x2258068f,0x39440f85,0x248825ad,0xdb1c00e5}},	//   ński_, _edms_, _šamo_, pipá, 
   {{0x25ac007d,0x61e425ae,0x98d001f2,0x3944005c}},	//   tkel_, yokl, sịpụ, _fdms_, 
   {{0xa44425af,0x00000000,0x00000000,0x00000000}},	//   анид, --, --, --, 
   {{0x61e425b0,0x00000000,0x00000000,0x00000000}},	//   vokl, --, --, --, 
   {{0x316825b1,0x6e240c8c,0x62640120,0x00000000}},	//   _abaz_, _othb, авоа, --, 
   {{0x224800a7,0xe1f8004e,0x00000000,0x00000000}},	//   ъпни_, кго_, --, --, 
   {{0x31681529,0x61e40024,0x5688010f,0x00000000}},	//   _cbaz_, uokl, _שטײַ, --, 
   {{0x6e240597,0x80c0012c,0x00000000,0x00000000}},	//   _athb, _लेखे, --, --, 
   {{0x443c25b2,0x61e40522,0xdfd025b3,0x21d40374}},	//   msu_, sokl, زيز_, pāho_, 
   {{0xa91c0745,0x61e425b4,0xdc2c03b9,0x5f0402e8}},	//   _každ, pokl, _bığl, рзва, 
   {{0x443c25b5,0x00000000,0x00000000,0x00000000}},	//   osu_, --, --, --, 
   {{0x443c25b6,0xa91c25b7,0x6e24035a,0xdca41fbe}},	// [2100] nsu_, _mažd, _ethb, јази, 
   {{0x443c25b8,0x2fcc0036,0x00000000,0x00000000}},	//   isu_, éegt_, --, --, 
   {{0xfe5804d3,0x5a94013e,0x8f980a1e,0x443c25b9}},	//   _حیزب_, шраф, _סיטי, hsu_, 
   {{0xeaf80075,0xdb1c05d1,0x5d54004e,0x00000000}},	//   ھرەت_, kipç, _өкүт, --, 
   {{0x8d7425ba,0xac740023,0xeaf80116,0x00000000}},	//   _ئاپا, ጠልጢሉ_, پرەت_, --, 
   {{0x6e2402d0,0xdb0c00d7,0x00000000,0x00000000}},	//   _ythb, _hlbí, --, --, 
   {{0x443c25bb,0xdb0c004e,0xa91c16a3,0xdec80092}},	//   esu_, _embò, _bažd, _በውኃ_, 
   {{0x98a425bc,0x18a425bd,0x00000000,0x00000000}},	//   _кибе, _кабм, --, --, 
   {{0x79800428,0x23a800d2,0x443c25be,0xb0c40034}},	//   _iamw, _lúju_, gsu_, _लेंग, 
   {{0x798025bf,0xa3c40882,0x93a425c0,0xdb0c09e8}},	//   _hamw, _एषः_, ршид, _umbó, 
   {{0x443c25c1,0x75ec019f,0xe6840124,0x67ec01ed}},	//   asu_, wûzu, _гәык_, gúju, 
   {{0x443c25c2,0xdb1c25c3,0x932400f2,0xa4f0008e}},	//   bsu_, lipä, درکن, _çişü_, 
   {{0xcfa425c4,0x798025c5,0x8d7402c0,0x84600801}},	//   ашви, _mamw, یارا, _дъще, 
   {{0x79800585,0xdb1c25c6,0xd1001025,0xdc2c0205}},	//   _lamw, nipä, रेषण_, _sığl, 
   {{0xc3f80302,0x76a8013f,0xf23801d5,0x00000000}},	//   _שלוש, bɛye, _ёпиш_, --, 
   {{0xa91c08ad,0x798025c7,0xdb1c25c6,0xd018014b}},	//   _kaže, _namw, hipä, _ифо_, 
   {{0xdb1c25c8,0x4b24007b,0xbc3800be,0xa3bc01f9}},	// [2110] kipä, لعاف, لسلا_, ीचच_, 
   {{0xa91c02d5,0x80c025c9,0x1cb00327,0xdb0c01d3}},	//   _maže, _लेटे, ྐྱེ_, _elbí, 
   {{0x798025ca,0x7a0c00a2,0xdb0c0129,0x7ac417a0}},	//   _bamw, _eştm, _albâ, осце, 
   {{0xfe7025cb,0x7980015d,0xd24400f7,0x00000000}},	//   _کدی_, _camw, _ۉن_, --, 
   {{0x798025cc,0x6d5c03ac,0xa91c0306,0x49b801d5}},	//   _damw, _icsa, _naže, _یارد_, 
   {{0x79800086,0xdb1c00af,0xd2441d00,0x00000000}},	//   _eamw, gipä, _ىن_, --, 
   {{0xe6880137,0x79800142,0xba74007b,0x443c00d7}},	//   انبى_, _famw, _وافت, wsu_, 
   {{0x443c07ad,0x798025cd,0x00000000,0x00000000}},	//   tsu_, _gamw, --, --, 
   {{0x69c825ce,0xdb1c000d,0x00000000,0x00000000}},	//   _imee, bipä, --, --, 
   {{0x443c25cf,0x798025d0,0x639407d8,0xa0a40032}},	//   rsu_, _zamw, сшиф, ҡанд, 
   {{0x443c25d1,0xf77025d2,0x798025d3,0xa2e425d4}},	//   ssu_, _زال_, _yamw, сонд, 
   {{0x443c25d5,0xe8e40327,0xf6502586,0x00000000}},	//   psu_, _སྙོག, _آئل_, --, 
   {{0x69c825d6,0xa91c2375,0x644400b0,0x95e404b3}},	//   _mmee, _gaže, _āhiw, _اينۇ, 
   {{0x6d5c25d7,0x84c000fd,0x00000000,0x00000000}},	//   _acsa, _гәүд, --, --, 
   {{0xa91c25d8,0x65b40122,0x69c825d9,0x5dd8010b}},	//   _zaže, _záha, _omee, гфар_, 
   {{0x2d942503,0x3d2825da,0x91e000a7,0xe3f80451}},	//   орус, شتری_, _ноще, _جوڙڻ_, 
   {{0x798025db,0x3ba40107,0x00000000,0x00000000}},	// [2120] _ramw, олаҳ, --, --, 
   {{0x69c825dc,0xed58016c,0xe8e4025c,0x6ee001f2}},	//   _amee, лоӣ_, _སྙེག, _ịbel, 
   {{0x798025dd,0x2bb80574,0x9f0400f1,0x3eb00311}},	//   _pamw, _इतरा, _دودو, ântă_, 
   {{0x798025de,0xdec8010c,0x00000000,0x00000000}},	//   _qamw, _በልና_, --, --, 
   {{0x79801cbd,0x51580375,0xdb1c16ca,0x67ec01d3}},	//   _vamw, רכנו, tipä, yújt, 
   {{0x798025df,0xd49825e0,0x69c825e1,0xa91c25e2}},	//   _wamw, ғри_, _emee, _raže, 
   {{0xa91c25e3,0xdb1c25e4,0x798025e5,0x65b425e6}},	//   _saže, ripä, _tamw, _sáha, 
   {{0xa91c02d5,0xdb1c25e7,0x69c80036,0x65b40162}},	//   _paže, sipä, _gmee, _páha, 
   {{0xd7f0007b,0xf8b025e8,0x73c400fb,0xdb1c01f4}},	//   _فكر_, _تکا_, жәйе, pipä, 
   {{0xd37825e9,0xa91c098d,0x65b402fb,0x00000000}},	//   учи_, _važe, _váha, --, 
   {{0xc7b00375,0x050c0055,0x58d401ee,0x00000000}},	//   _צבע_, _śītī_, _тоҡт, --, 
   {{0xa91c0118,0xc2b400d4,0x00000000,0x00000000}},	//   _taže, слює_, --, --, 
   {{0xd4f41a57,0x00000000,0x00000000,0x00000000}},	//   _اثاث, --, --, --, 
   {{0x823000dd,0x65b401ef,0x00000000,0x00000000}},	//   _کروا, _jáhn, --, --, 
   {{0x09cc000e,0x765c03cd,0x00000000,0x00000000}},	//   িকতা, _åryd, --, --, 
   {{0x7bdc0003,0x4638010f,0x8de801a9,0x00000000}},	//   _ajru, טעלע, уфга_, --, 
   {{0xdb0c00db,0xeb3825ea,0x69c80076,0x00000000}},	// [2130] _albà, изаш_, _rmee, --, 
   {{0x69c825eb,0x7afc010a,0x00000000,0x00000000}},	//   _smee, _bzrt, --, --, 
   {{0x954003e3,0xa91c013a,0x00000000,0x00000000}},	//   _əşrə, _ražb, --, --, 
   {{0xe8e40327,0x6d5c02d0,0x00000000,0x00000000}},	//   _སྙུག, _ucsa, --, --, 
   {{0xe7380c56,0xa91c0306,0x417c008f,0x00000000}},	//   аел_, _pažb, טנאב, --, 
   {{0x8d740131,0x00000000,0x00000000,0x00000000}},	//   _ئاھا, --, --, --, 
   {{0x660425ec,0x56901677,0x00000000,0x00000000}},	//   опка, дајт, --, --, 
   {{0x69c825ed,0x386001c3,0x00000000,0x00000000}},	//   _umee, àirc_, --, --, 
   {{0x3e70006a,0xe3b825ee,0x69d8014b,0x39140108}},	//   _kötö_, иби_, mnwe, _хмур, 
   {{0x1cb0031c,0x2600002e,0x87d425ef,0x00000000}},	//   ྐྱི_, kóog_, _اغرا, --, 
   {{0x6b8002d2,0x00000000,0x00000000,0x00000000}},	//   _ólgu, --, --, --, 
   {{0x69d825f0,0x33b000d1,0x208801d5,0x7a4000e5}},	//   nnwe, _ۋەير, айми_, _hátá, 
   {{0x09a4069f,0x64a425f1,0xdbc400af,0x7a30007f}},	//   _खवैय, _фала, mööb, _kòtò, 
   {{0x440425f2,0x232825f3,0x69d80112,0x6568002f}},	//   _учеб, _токи_, hnwe, lfeh, 
   {{0xdd9025f4,0x51f401d3,0x00000000,0x00000000}},	//   ووس_, _ڈسٹر, --, --, 
   {{0x656825f5,0x69d80196,0x7bdc0158,0x7a4001d3}},	//   nfeh, jnwe, _sjru, _látá, 
   {{0xfaf80029,0x9f5801e1,0xdbc801c0,0xfb1801d3}},	// [2140] _šī_, _dipò_, агад_, مراں_, 
   {{0x69d825f6,0x7a0c0cc1,0xe81c0c2e,0xdb0c01f6}},	//   enwe, _işti, _पढ़ा_, _albá, 
   {{0x65b425f7,0x9f580241,0x9f0404fb,0xf0000139}},	//   _náho, _fipò_, _گوگو, _чүри, 
   {{0x69d8009a,0x65b40118,0x00000000,0x00000000}},	//   gnwe, _sáhn, --, --, 
   {{0x7a400241,0x00000000,0x00000000,0x00000000}},	//   _bátá, --, --, --, 
   {{0x69d8017a,0x9f58007f,0x1b740214,0x65b400d7}},	//   anwe, _zipò_, _بدحج, _báho, 
   {{0xd5b825f8,0x8f9825f9,0x316c0161,0xdb0c02d2}},	//   иси_, ייסי, ŵezi_, _ambö, 
   {{0x77b4004e,0x7a0c0356,0x656800e5,0x2da40092}},	//   _tàxo, _oşti, gfeh, _ወገኖቼ_, 
   {{0x65b40118,0x81e000eb,0x00000000,0x00000000}},	//   _táhn, থতা_, --, --, 
   {{0xe8e4003d,0x3e7c01e4,0xccf0011a,0x644425fa}},	//   _སྙིག, _oŭt_, וכח_, _āhit, 
   {{0x741425fb,0x65680e78,0xf28801c0,0x4bf8008f}},	//   _کوتا, bfeh, сөлд_, שליס, 
   {{0xd46825fc,0x7658019f,0xa91c00ef,0x65b401ef}},	//   _виде_, muvy, _kaža, _jáhl, 
   {{0x3e7c01e4,0x65b425fd,0x765801f7,0x9f4c0122}},	//   _aŭt_, _záho, luvy, šným_, 
   {{0x9f580699,0xa91c02d5,0xb4c825fe,0x3f9c004e}},	//   _sipò_, _maža, ोपी_, _òvul_, 
   {{0xa91c0960,0x0ef0015b,0xbe8825ff,0x82300b24}},	//   _laža, ছেনঃ_, осте_, _قريا, 
   {{0x65b402fd,0x22500030,0x22a401f0,0xf8bc00cd}},	//   _náhl, ázke_, _хушҳ, ्छाय, 
   {{0xa91c04b9,0x7024031c,0xec1401e2,0xfc6402e8}},	// [2150] _naža, _འཕྲུ_, سواد, дъхн, 
   {{0x765807a8,0xfc3000c6,0x68300248,0x7e7c0042}},	//   kuvy, ضحك_, _lódò, bwrp, 
   {{0x7a400491,0x21d40053,0x41c40014,0x37d0015b}},	//   _rátá, wāhi_, _رٲیِ, াকার, 
   {{0x1cb00135,0x3eac03fa,0x59a402ab,0xa91c2600}},	//   ྐྱང_, ädte_, कॉलर, _baža, 
   {{0x69d82601,0x7a400ca8,0xe72801c6,0x00000000}},	//   rnwe, _pátá, болд_, --, 
   {{0xa91c2602,0x0058011a,0x00000000,0x00000000}},	//   _daža, קשות_, --, --, 
   {{0xc9742603,0xdb0c00b5,0x6568002f,0xa934010a}},	//   _وارث, _albæ, tfeh, _невш, 
   {{0x3178006d,0x795822f7,0x65b40313,0xa91c1dd5}},	//   jesz_, _миср_, _váho, _faža, 
   {{0x317801ed,0x65682604,0x651401ed,0x7e7c0165}},	//   desz_, rfeh, _ہوائ, zwrp, 
   {{0x65682605,0x65b40216,0xe3b823be,0x00000000}},	//   sfeh, _záhl, сбо_, --, 
   {{0x65680639,0x45a00075,0x65142606,0x333c0175}},	//   pfeh, _يەتك, _فوائ, _devx_, 
   {{0x21682607,0x00000000,0x00000000,0x00000000}},	//   щими_, --, --, --, 
   {{0xdb040793,0xe35400ee,0xe5081e24,0xb5c80345}},	//   _ämög, _етйэ, _ايشو_, _بونم_, 
   {{0x66082608,0x21f002fb,0x00000000,0x00000000}},	//   lmek, váhu_, --, --, 
   {{0x0204013e,0x7a0c0139,0x137800f1,0x2174009b}},	//   _оҷон, _iştv, _دجنګ_, _еупр, 
   {{0x3178068f,0x9c242609,0x6608260a,0xd24c00c6}},	//   cesz_, здад, nmek, _إني_, 
   {{0x6608004b,0x00000000,0x00000000,0x00000000}},	// [2160] imek, --, --, --, 
   {{0x6608260b,0xa91c260c,0x65b4013a,0x7658260d}},	//   hmek, _raža, _sáhl, yuvy, 
   {{0x6608260e,0xa91c05a1,0x2008260f,0x00000000}},	//   kmek, _saža, mmbi_, --, 
   {{0xa91c0006,0x9f480122,0xceb00375,0x00000000}},	//   _paža, dobé_, _ניר_, --, 
   {{0xdb0c019f,0x660800c5,0x44f805c7,0x5cf401c4}},	//   _ambô, dmek, _n̪_, _хяну, 
   {{0xa91c098d,0x3a38020b,0x80d4015b,0x6608004b}},	//   _važa, _twrp_, _সরঞ্, emek, 
   {{0x5ac4025c,0x20081418,0xdce40153,0x65b40118}},	//   _གཟིམ, imbi_, _pakė, _táhl, 
   {{0x44f805c7,0x76582610,0x6608010e,0x00000000}},	//   _b̪_, ruvy, gmek, --, 
   {{0xa91c0989,0x62942611,0xb4c800cd,0x317800e5}},	//   _kažn, åzon, ोपे_, vesz_, 
   {{0x44f805c7,0x12e401ec,0x19dc0150,0x88b8011a}},	//   _d̪_, зімг, _ﺃﻓﻀﻠ, _הזמי, 
   {{0x3dc00472,0x317801d3,0x00000000,0x00000000}},	//   khiw_, tesz_, --, --, 
   {{0xa91c08a4,0x21d402b5,0x2bb800cd,0x00000000}},	//   _lažn, kāhu_, _इत्थ, --, 
   {{0x26080d5f,0xf0e81870,0x826001d5,0x73c40150}},	//   ागरी_, زىسى_, وهین, _және, 
   {{0x03a02612,0x7538033f,0x00000000,0x00000000}},	//   _пичо, ńczą, --, --, 
   {{0x7ee42613,0x43802614,0x2fd00010,0x00000000}},	//   ецте, _سليق, rizg_, --, 
   {{0x70580131,0x2b40037e,0xe81c0037,0x00000000}},	//   _даир_, wahc_, _पढला_, --, 
   {{0xa91c02d5,0x62840008,0x6c142615,0x3d3800a8}},	// [2170] _bažn, _áhor, ддаф, яптэ_, 
   {{0xf6b80156,0x66082616,0x2fd001a9,0x00000000}},	//   ྐྱོང, zmek, qizg_, --, 
   {{0xa91c0953,0xfe242617,0x386008c2,0xdb1400b8}},	//   _dažn, _пьян, àirn_, _įcãk, 
   {{0x2bb801f9,0x21d400b8,0x00000000,0x00000000}},	//   _इतका, bāhu_, --, --, 
   {{0x81b003f9,0x2d982618,0x7648036e,0x660803e0}},	//   _jiɓa, _inse_, _avdy, vmek, 
   {{0xdc5404d3,0x8bf404c5,0x2d882619,0xa69410fc}},	//   _کرێک, _অংকন_, ldae_, дриј, 
   {{0x6608261a,0x80d40c58,0xe628004b,0xe5a400d1}},	//   tmek, _সৰঞ্, زګان_, дийи, 
   {{0x2d88261b,0x76480076,0x44f805c7,0x9f48261c}},	//   ndae_, _dvdy, _p̪_, robé_, 
   {{0x6608261d,0x2d88261e,0x00000000,0x00000000}},	//   rmek, idae_, --, --, 
   {{0xe7940a81,0x6608261f,0xd7640075,0xe3b000c6}},	//   _تارک, smek, _يەنى_, ئرة_, 
   {{0x2d980925,0xd7e8129d,0x2d88017a,0xf6502620}},	//   _onse_, _بولۇ_, kdae_, _مئن_, 
   {{0xa91c0006,0x44f805c7,0xdb1c036e,0x00000000}},	//   _mažo, _t̪_, thpë, --, 
   {{0xa91c05a1,0x2d880ea0,0x10a02621,0x00000000}},	//   _lažo, ddae_, виян, --, 
   {{0x2d982622,0x3fcc09bd,0x2d882623,0xf4c40209}},	//   _anse_, লক্ষ, edae_, şýän_, 
   {{0x248c2624,0xa91c2625,0xdb1c0023,0x3dc00fec}},	//   lvem_, _ražn, shpë, thiw_, 
   {{0x5bb40c93,0x21742626,0x21d400b0,0x57a80073}},	//   ःस्व, _цукр, tāhu_, _कव्ह, 
   {{0xa91c1326,0x5ba82627,0xa3b00254,0x8c402628}},	// [2180] _pažn, окам_, _टका_, кете, 
   {{0x2d982629,0x2d880393,0x00000000,0x00000000}},	//   _ense_, adae_, --, --, 
   {{0xa91c04b9,0xdce400b0,0x248c262a,0x4f98011a}},	//   _važn, _kakī, hvem_, _וביצ, 
   {{0xdcf40100,0xa91c262b,0x248c0450,0x00000000}},	//   leyč, _dažo, kvem_, --, 
   {{0x6c740364,0xa91c022a,0x00000000,0x00000000}},	//   _пурх, _tažn, --, --, 
   {{0xa91c107d,0x8c400640,0x60c0010b,0x248c00e5}},	//   _fažo, _јере, _ýomu, dvem_, 
   {{0x7c240054,0x00000000,0x00000000,0x00000000}},	//   lqir, --, --, --, 
   {{0x77b40228,0xc7200032,0x1ddc262c,0x00000000}},	//   _màxi, ндәй, नचित, --, 
   {{0x7c24262d,0x1868262e,0xe8500133,0x00000000}},	//   nqir, _фази_, _مۆند, --, 
   {{0x9268262f,0xf8b005d9,0xa91c2630,0x2d88003a}},	//   орма_, _لکڻ_, _lažl, zdae_, 
   {{0x7c242631,0xc7d4025d,0x3c242632,0x2d880ea0}},	//   hqir, _קובי_, _löv_, ydae_, 
   {{0x225004bf,0x82302633,0xcb100375,0xa91c01ef}},	//   ázka_, کریا, כלת_, _nažl, 
   {{0x3c2400ac,0x461004fb,0x22582634,0x00000000}},	//   _növ_, _شوهر, ąska_, --, 
   {{0x1cb00dd4,0x7c2406be,0x00000000,0x00000000}},	//   ྐྱབ_, dqir, --, --, 
   {{0x657400e5,0x00000000,0x00000000,0x00000000}},	//   őzhe, --, --, --, 
   {{0xa91c0029,0x00000000,0x00000000,0x00000000}},	//   _ražo, --, --, --, 
   {{0x2d882635,0x7c2400aa,0x0ba818fd,0x4cdc00eb}},	// [2190] rdae_, gqir, يائى_, _মরহু, 
   {{0x2d880660,0x09d40490,0x3b542636,0x3c242632}},	//   sdae_, ढच्य, ккур, _döv_, 
   {{0x248c012c,0xbf140050,0x160c2637,0xe9b400c7}},	//   zvem_, _لوٝب, ागार_, нбжь, 
   {{0xac1817d8,0x2d982638,0x7c2401b9,0x00000000}},	//   _ному_, _unse_, bqir, --, 
   {{0x67d42639,0x00000000,0x00000000,0x00000000}},	//   ноду, --, --, --, 
   {{0x77841cb8,0x00000000,0x00000000,0x00000000}},	//   кліз, --, --, --, 
   {{0x26d8013f,0x65b4032e,0x00000000,0x00000000}},	//   _ɛsow_, _háhi, --, --, 
   {{0xff180375,0x65b402fb,0x248c00bc,0xdcf4007f}},	//   וקות_, _káhi, tvem_, zeyč, 
   {{0x248c007f,0xe854072d,0xf8f40024,0x00000000}},	//   uvem_, _سناد, _аптэ, --, 
   {{0xf770263a,0x248c263b,0xa91c0024,0x2488263c}},	//   _نام_, rvem_, _mažm, _šams_, 
   {{0x85880b87,0x7a0c03b9,0x65940107,0x00000000}},	//   _мёда_, _iştr, _пажу, --, 
   {{0x3634263d,0x56b4008f,0x7c24263e,0x00000000}},	//   _شرمس, _אפען_, yqir, --, 
   {{0x60b401d5,0x65b402d2,0x4f480023,0x936c0055}},	//   رمسئ, _náhi, _ንምዝር, _ṅgāṅ, 
   {{0x6448263f,0x78a41073,0x3c2401e3,0xa2e40108}},	//   msei, äivi, _röv_, _полд, 
   {{0x64482640,0xa91c0989,0x00000000,0x00000000}},	//   lsei, _pažl, --, --, 
   {{0x442c2641,0xdca42642,0x64482643,0x12d40150}},	//   _ktg_, наби, osei, _ﺘﺒﻠﻭ, 
   {{0x64482644,0x9f4800cf,0xdcf40100,0x59b42645}},	// [21a0] nsei, lobí_, peyč, _अकबर, 
   {{0x442c019b,0x644801c3,0x7c242646,0x1e8420c8}},	//   _mtg_, isei, rqir, _злом, 
   {{0x64480369,0x9d442647,0xdb1c000d,0x7ddc0139}},	//   hsei, _пенд, mipü, bäsе, 
   {{0xdca42648,0x20180053,0x18682649,0x442c0c86}},	//   _зами, _hipi_, зади_, _otg_, 
   {{0x201818a6,0x7c240194,0x6448005c,0x00000000}},	//   _kipi_, qqir, jsei, --, 
   {{0x6448264a,0xc7a0189d,0x07a007c6,0xd1c40023}},	//   dsei, личк, лачн, _ጽዑቕ_, 
   {{0x2018264b,0x64481140,0xa91c16a3,0x8af40064}},	//   _mipi_, esei, _zažm, _знёс_, 
   {{0x9f48031d,0xa91c151c,0x442c264c,0x6448264d}},	//   dobí_, _lažj, _btg_, fsei, 
   {{0x48e00d1d,0x00000000,0x00000000,0x00000000}},	//   _ботв, --, --, --, 
   {{0x442c264e,0x2018264f,0x61f40209,0xd24c0014}},	//   _dtg_, _nipi_, _akyl, مۆت_, 
   {{0x96942650,0x442c143a,0xa2802651,0x64482652}},	//   _яраш, _etg_, لیوو, asei, 
   {{0x64482653,0x442c2654,0x268814a0,0x324401e0}},	//   bsei, _ftg_, _زخمي_, неүг, 
   {{0x442c0998,0x2018166a,0xc5ec121e,0x00000000}},	//   _gtg_, _bipi_, _آن_, --, 
   {{0x61f402d0,0xa91c0427,0x2268005b,0x7dc401b9}},	//   _ekyl, _ražm, ötkö_, қёсд, 
   {{0x201807ab,0x0290007b,0xca4c0150,0xdb0c2655}},	//   _dipi_, _مؤيد, _ﺍﻋﺎ_, _àjèj, 
   {{0x65b400e4,0x00000000,0x00000000,0x00000000}},	//   _páhi, --, --, --, 
   {{0x32082656,0xa2980b82,0x6ad82429,0xfc300efe}},	// [21b0] _ihay_, _ፈተናን_, भप्र, محل_, 
   {{0x20180048,0x4ea4009b,0x00000000,0x00000000}},	//   _gipi_, _зрма, --, --, 
   {{0x320801fb,0x64480399,0x8ae400d4,0x00000000}},	//   _khay_, zsei, хіал, --, 
   {{0xdb0c006a,0x2018249d,0x32080109,0x64482657}},	//   _kobê, _zipi_, _jhay_, ysei, 
   {{0x50b02658,0x477001ec,0xec14007b,0x6448002f}},	//   ुनिष, лқау, _لوحد, xsei, 
   {{0xa91c02d5,0x66180113,0x644800c5,0xa6980114}},	//   _kažk, _siwk, vsei, дњих_, 
   {{0x3208035a,0x6618012d,0x00000000,0x00000000}},	//   _ohay_, _piwk, --, --, 
   {{0x64482659,0x442c0020,0xe578016c,0xc9840032}},	//   tsei, _ptg_, фзи_, _яуги, 
   {{0x442c265a,0xa814265b,0x6448265c,0xd5ac007b}},	//   _qtg_, _адаш, usei, تفي_, 
   {{0x3208265d,0x68e80c8c,0x6378265e,0x00000000}},	//   _ahay_, _ixed, фсир_, --, 
   {{0x6448265f,0xa2e42660,0x32080280,0x20182661}},	//   ssei, тонд, _bhay_, _ripi_, 
   {{0x32082662,0x442c2663,0x20182664,0x64482665}},	//   _chay_, _ttg_, _sipi_, psei, 
   {{0x442c2666,0x9f480232,0x63840209,0x64480399}},	//   _utg_, sobí_, _агла, qsei, 
   {{0x320814dc,0xb3700092,0x00000000,0x00000000}},	//   _ehay_, ባቢውን_, --, --, 
   {{0x20182667,0x8fa02668,0xdb1c0254,0x00000000}},	//   _vipi_, шаре, ripü, --, 
   {{0x61f40921,0x3208047e,0x20180477,0xa91c00e2}},	//   _ukyl, _ghay_, _wipi_, _dažk, 
   {{0x20182669,0xa3d402e5,0x79580241,0x00000000}},	// [21c0] _tipi_, _सगा_, _lúwà, --, 
   {{0x2018266a,0xa2c411bc,0x200c01e1,0xf38c00df}},	//   _uipi_, ानप्, _òfi_, ּראָ, 
   {{0xcf54025f,0x0f5404ac,0x68e8035a,0x320802d0}},	//   _בבית_, _ביים_, _axed, _yhay_, 
   {{0x3eb800ad,0x29d40306,0xdb1c02f0,0xe9c40022}},	//   myrt_, sťan_, tipó, лахҿ, 
   {{0x893401ec,0x61e408a5,0x00000000,0x00000000}},	//   тпіс_, _íhlu, --, --, 
   {{0xa6ac0183,0x3eb8062c,0xdb1c00e4,0x00000000}},	//   _কেইট, oyrt_, ripó, --, 
   {{0x68e8266b,0x9a140022,0xcb64030d,0x00000000}},	//   _exed, _афаш, _шаре_, --, 
   {{0xa2c400e0,0xd5b00073,0xceb0011a,0xa91c013a}},	//   ानन्, _जवळज, שיה_, _nažh, 
   {{0x65b402f0,0x7afc010e,0x3944266c,0x335400db}},	//   _náhu, _hyrt, _iems_, гүлө_, 
   {{0x7afc0652,0x8d800020,0x3208266d,0x3944005c}},	//   _kyrt, ርበታል_, _shay_, _hems_, 
   {{0x3208266e,0x59b4266f,0xd3940032,0x27e82670}},	//   _phay_, _अकार, еҙҙә_, éane_, 
   {{0x39442671,0x00000000,0x00000000,0x00000000}},	//   _jems_, --, --, --, 
   {{0x6284006a,0x394400b5,0x3eb80076,0x00000000}},	//   _âhon, _mems_, eyrt_, --, 
   {{0x40340d31,0x39442672,0x3eb803cd,0xd160035b}},	//   рерс, _lems_, fyrt_, ынҭқ, 
   {{0x32082673,0xdb0c02d3,0x0db82674,0xe888001f}},	//   _thay_, _dobë, وارث_, _በውስጡ_, 
   {{0x32082675,0x39442676,0x00000000,0x00000000}},	//   _uhay_, _nems_, --, --, 
   {{0x6b740bd6,0x3eb81368,0x52e02677,0x70942678}},	// [21d0] ллау, ayrt_, _पशुस, _сапф, 
   {{0x7afc2679,0x3eb80363,0xd12c00db,0xed501374}},	//   _byrt, byrt_, _دۅڭ_, _گھس_, 
   {{0x7afc0142,0x65b40306,0x6d7c0023,0x00000000}},	//   _cyrt, _záhu, _ብጎይታ_, --, 
   {{0xe944267a,0x7afc0194,0xa91c267b,0xf7700014}},	//   ارای, _dyrt, _kaži, ۪ان_, 
   {{0x9f480085,0x88c4267c,0xdb0c007f,0x3da40953}},	//   lobá_, ختال, _lobè, _трэб, 
   {{0xa91c02d5,0x66e4267d,0xdb1c007f,0x00000000}},	//   _maži, лола, sipò, --, 
   {{0xf770267e,0x3944267f,0xdb0c02e2,0x9ba00c50}},	//   تان_, _fems_, _nobè, _دەلى, 
   {{0x39442680,0x6e242681,0x75d80124,0x00000000}},	//   _gems_, _muhb, кьыс_, --, 
   {{0x7afc044e,0x69d82682,0x00000000,0x00000000}},	//   _zyrt, miwe, --, --, 
   {{0x69d82683,0x13e40724,0xa91c0306,0xa0a40b01}},	//   liwe, лмый_, _naži, ҳамд, 
   {{0x21682684,0x61442685,0xdb0c2686,0x3944009a}},	//   нини_, лена, _cobè, _yems_, 
   {{0x69d82687,0xdb0c068c,0x9f480122,0x525400c7}},	//   niwe, _dobè, dobá_, ыхьӡ, 
   {{0xd24c2688,0x9f4800a3,0x59b40037,0xa91c0c5e}},	//   ينی_, tobà_, _अकसर, _baži, 
   {{0x3eb82689,0x69d8268a,0x76a8016b,0x386001c3}},	//   tyrt_, hiwe, wɛyi, àiri_, 
   {{0x69d8268b,0xd36c16cb,0x2eb41064,0xa91c1ebf}},	//   kiwe, _رهي_, астс, _daži, 
   {{0x69d80451,0x6e24268c,0x3f8c268d,0xdee41086}},	//   jiwe, _duhb, ždu_, воҳи, 
   {{0x3944268e,0x69d8268f,0x672009a8,0x7afc2690}},	// [21e0] _rems_, diwe, _oglj, _syrt, 
   {{0x39442691,0x7afc138f,0x0b402692,0x69d8017a}},	//   _sems_, _pyrt, йнун, eiwe, 
   {{0xdb0c02ea,0x6e240007,0x26c801e4,0xad2400e5}},	//   _kobé, _guhb, ŝaoj_, ارہو, 
   {{0xa91c1b5c,0x69d80a1d,0x7afc036e,0x5cf40024}},	//   _zaži, giwe, _vyrt, _бягу, 
   {{0xdb0c043b,0xd7f82693,0x394401e3,0x7afc0042}},	//   _mobé, нук_, _vems_, _wyrt, 
   {{0x7afc003a,0x69d82694,0x765c0fac,0x2600002e}},	//   _tyrt, aiwe, _åryk, sóol_, 
   {{0x2604069f,0xf1c00232,0x69d82695,0x394404cc}},	//   _हीही_, ášky_, biwe, _tems_, 
   {{0x35b42696,0x69d82697,0xd1f4001f,0xdb0c2698}},	//   рбир, ciwe, _ለፊት_, _robè, 
   {{0x41a80050,0xa2d82699,0x13680801,0x73c401e0}},	//   गानस, _फेब्, ншни_, ҫәһе, 
   {{0xc7a00022,0xb2740408,0x07a00229,0x00000000}},	//   _лиук, алош, _лаун, --, 
   {{0xdb0c02ea,0x63b401ed,0xa91c269a,0xa3d409ab}},	//   _bobé, özna, _raži, _सगर_, 
   {{0x506405f5,0xf484006c,0x0ecc00c5,0xa6ac00fe}},	//   лтга, _ناتی, _हेगड, _কেকট, 
   {{0x6e2407d6,0xa91c02d5,0xdb0c0036,0x50640006}},	//   _suhb, _paži, _dobé, ытна, 
   {{0x69d8269b,0x4fc4269c,0x9f480798,0x00000000}},	//   ziwe, усма, tobá_, --, 
   {{0xa91c02d5,0x8a940220,0x69d8269d,0xb33c0327}},	//   _važi, _ءﻭﻧﺪ, yiwe, jjħi, 
   {{0x69d807a9,0xdb0c269e,0xd1b80228,0x65b4032e}},	//   xiwe, _gobé, _ساعا_, _háhr, 
   {{0x69d8269f,0x41c426a0,0xca4c0150,0x00000000}},	// [21f0] viwe, _دقيق, _ﺍﻋﺘ_, --, 
   {{0x69d826a1,0x0ae826a2,0x6e2420a9,0x4ae8005b}},	//   wiwe, ىراي_, _tuhb, ньем_, 
   {{0x69d807a9,0xd1cc0023,0x786400d1,0x00000000}},	//   tiwe, _ባሮት_, ەدىك, --, 
   {{0x89340597,0x202402e8,0xa91c0153,0x7de001ef}},	//   اعضا, _èpiù_, _mažv, _písň, 
   {{0x69d826a3,0x9ce80014,0xfc780023,0x00000000}},	//   riwe, _لوَے_, _ኣጋጢሙ_, --, 
   {{0xd24426a4,0x65b403c6,0x69d826a5,0xfe7026a6}},	//   _ون_, _náhr, siwe, _بدی_, 
   {{0x69d826a7,0x2ca80009,0xb8fc07b7,0x00000000}},	//   piwe, lxad_, _णे_, --, 
   {{0x69d8004b,0x60c0025c,0x6498026b,0x7de0013a}},	//   qiwe, _żomm, втор_, _tísň, 
   {{0xdb0c0139,0x00000000,0x00000000,0x00000000}},	//   _robé, --, --, --, 
   {{0x6720098d,0xe298026a,0x96900014,0xa3d40073}},	//   _uglj, вао_, _ڈیٖش, _सगळ_, 
   {{0xd5ac26a8,0xdb0c0036,0x21a400c7,0x00000000}},	//   سفی_, _pobé, аинм, --, 
   {{0xd1d0010c,0xa91c00de,0x00000000,0x00000000}},	//   _ከፊቱ_, _dažv, --, --, 
   {{0x81b003f9,0xa11402e9,0xa07401ec,0x55b8011a}},	//   _jiɓi, شوست, шынш, _שמנו, 
   {{0x201c26a9,0xdb1c01b8,0x25ac00c5,0x2600002e}},	//   öti_, mipö, ljel_, kóok_, 
   {{0xdb0c013a,0xdb1c0108,0x00000000,0x00000000}},	//   _blbý, lipö, --, --, 
   {{0x65b401a2,0x91e026aa,0x00000000,0x00000000}},	//   _záhr, _моще, --, --, 
   {{0x5b340f1b,0xa91c01a6,0x60080cdd,0xe7c40073}},	// [2200] لعار, _kažu, _иним_, वसाप, 
   {{0xde28036b,0xed58013e,0xdb0c0356,0x00000000}},	//   _ижод_, коӣ_, _dobî, --, 
   {{0xa91c26ab,0x25ac26ac,0xa3cc2122,0x9f0412ea}},	//   _mažu, kjel_, _रतन_, _خودو, 
   {{0x25ac26ad,0xdb1c0793,0x61e426ae,0x00000000}},	//   jjel_, kipö, nnkl, --, 
   {{0x57a426af,0x61e426b0,0x25ac0118,0xfcc401e0}},	//   ишка, inkl, djel_, _уҙам, 
   {{0x8c400da9,0x61e4002f,0xda641e5a,0xa91c00ef}},	//   _фере, hnkl, _پاسي, _nažu, 
   {{0x4b781203,0x9f58145e,0xd94426b1,0x27e800ae}},	//   _שאלו, _akpë_, _веби, éana_, 
   {{0xd49826b2,0x25ac0240,0x61e401a4,0xdb0c0142}},	//   вро_, gjel_, jnkl, _hobï, 
   {{0x81b003f9,0xa91c00f3,0x56900220,0xf3f821fa}},	//   _giɓi, _sažv, сақт, лниш_, 
   {{0xd1f4044e,0x61e40af9,0xa91c0024,0x00000000}},	//   ለዎት_, enkl, _pažv, --, 
   {{0xa91c1ebf,0x91a009bb,0x00000000,0x00000000}},	//   _dažu, गालै, --, --, 
   {{0x05b000c6,0xdb0c015d,0x6aa0032e,0x00000000}},	//   _وملح, _lobï, _álfe, --, 
   {{0xdb0c0365,0xdb1c0254,0x339400c0,0x00000000}},	//   _albü, mipõ, _галё, --, 
   {{0x61e426b3,0xdb1c0037,0xd1cc0092,0x00000000}},	//   ankl, lipõ, _ባዮች_, --, 
   {{0x82f401b9,0xc32c075e,0x00000000,0x00000000}},	//   _پروز_, _تەپ_, --, --, 
   {{0x823026b4,0x3da426b5,0xdb1c0254,0x00000000}},	//   _بروا, оруб, nipõ, --, 
   {{0xe2380092,0x00000000,0x00000000,0x00000000}},	// [2210] _የተሳና, --, --, --, 
   {{0x2ca801d9,0x00000000,0x00000000,0x00000000}},	//   rxad_, --, --, --, 
   {{0x6e940491,0x00000000,0x00000000,0x00000000}},	//   _الجا, --, --, --, 
   {{0xdb0c26b6,0xf9d400d4,0x00000000,0x00000000}},	//   _albó, оцію, --, --, 
   {{0x2258012d,0xdb1c0037,0xe7f401f9,0x00000000}},	//   ąski_, dipõ, ेतला_, --, 
   {{0x29000882,0x6818007f,0xdb1c01b8,0x9f4826b7}},	//   āha_, _kňdi, vipö, llbò_, 
   {{0x89a40014,0xa91c00ef,0xa68401d5,0x00000000}},	//   _پھاہ_, _ražu, ёлид, --, 
   {{0x394026b8,0xa2c40882,0x6b840c6a,0xdb0c01e1}},	//   ðist_, ानस्, lehg, _mobì, 
   {{0x26c026b9,0xe6941f7a,0x38600013,0x25ac16ba}},	//   šho_, _گلاد, àirt_, rjel_, 
   {{0x87e400fd,0x53c40166,0xdb1c0108,0x00000000}},	//   _тюбе, йгым_, ripö, --, 
   {{0xf77026ba,0xdb1c26bb,0x57f8010f,0xb33c0327}},	//   _تاق_, bipõ, _עלעו, jjħu, 
   {{0xe29801e0,0x25ac031c,0x38600332,0x00000000}},	//   _ҡал_, qjel_, áirg_, --, 
   {{0x61e426bc,0x656826bd,0xa6ac00cc,0x00000000}},	//   rnkl, mgeh, _কেচট, --, 
   {{0x656826be,0xa0a400c7,0xdfd001f7,0x00000000}},	//   lgeh, _ҳаид, سيز_, --, 
   {{0xfe7800f7,0x00000000,0x00000000,0x00000000}},	//   шүн_, --, --, --, 
   {{0xa0a40022,0xdb1006af,0x1d2426bf,0xd254011a}},	//   _гаид, _égér, смам, _השקה_, 
   {{0x0c20075e,0xdc2826c0,0x3dc004cc,0x681800a2}},	// [2220] змун, اسره_, rkiw_, _eňdi, 
   {{0x3dc00227,0x65680ade,0x21f002fb,0x6b8426c1}},	//   skiw_, hgeh, váhy_, gehg, 
   {{0xdb0c02e2,0x656800a2,0x00000000,0x00000000}},	//   _albò, kgeh, --, --, 
   {{0x27e800c6,0x65680d27,0x5f740133,0x00000000}},	//   éann_, jgeh, _ئاکر, --, 
   {{0x8d7400db,0xa2d808e9,0x656826c2,0xdb1c0254}},	//   _ااپا, _फेस्, dgeh, vipõ, 
   {{0x65682287,0x18a402dd,0x00000000,0x00000000}},	//   egeh, _қазм, --, --, 
   {{0x8f980302,0x656826c3,0x2a3426c4,0x9f840051}},	//   טיסי, fgeh, _мэтр, _rôì_, 
   {{0x656826c5,0x7434084c,0x35f401b9,0x75d426c6}},	//   ggeh, ониф, ўпир, تيبا, 
   {{0xdb0c0798,0xdddc00ef,0x932407d6,0xb79400ec}},	//   _mobí, _appū, یرگن, _وائڙ, 
   {{0x32542082,0xd62826c7,0x73d8136b,0xa91c00c0}},	//   овор, _боже_, рдор_, _važt, 
   {{0xc318045e,0x6568002f,0x4b780a7c,0x785401d3}},	//   _দ্বি_, bgeh, נאטו, _ایڈز_, 
   {{0x645c26c8,0x490c00bc,0x00000000,0x00000000}},	//   ásic, तेको_, --, --, 
   {{0xc05801ec,0x1bf800bc,0x00000000,0x00000000}},	//   йір_, ्ताल_, --, --, 
   {{0x741426c9,0xb4e405d7,0xa2c4043e,0x00000000}},	//   _بوتا, फपी_, ानश्, --, 
   {{0xdb0c26ca,0xada401e0,0xab880014,0x2f180108}},	//   _lobâ, ҙаҡл, یٖرن_, ровь_, 
   {{0xc0cc0092,0xa2c400cd,0x00000000,0x00000000}},	//   ጠርም_, ानर्, --, --, 
   {{0xdb0c02fd,0xebd826cb,0xe2a403b2,0x00000000}},	// [2230] _dobí, адаш_, óðve_, --, 
   {{0x8aa4010b,0xdb0c0241,0x00000000,0x00000000}},	//   йред, _tobì, --, --, 
   {{0xc3300375,0xa91c0010,0x656826cc,0xcb08009d}},	//   פוף_, _nažr, ygeh, ухад_, 
   {{0xdb0c26cd,0x6b840112,0x00000000,0x00000000}},	//   _gobí, sehg, --, --, 
   {{0x27e826ce,0xbd8801d9,0x2f1401d9,0x00000000}},	//   éano_, _انُن_, _دِگر, --, 
   {{0xdb0c0276,0x00000000,0x00000000,0x00000000}},	//   _dobâ, --, --, --, 
   {{0x656826cf,0x3ffc008f,0x386000a3,0x00000000}},	//   tgeh, אפגע, àirr_, --, 
   {{0xe4581cb6,0xa91c00e2,0x65680158,0x00000000}},	//   ажи_, _dažr, ugeh, --, 
   {{0x656826d0,0x69c826d1,0x2918004a,0xe7440032}},	//   rgeh, _ilee, _àsa_, _һүҙе_, 
   {{0x656826d2,0x386026d3,0x00000000,0x00000000}},	//   sgeh, áire_, --, --, 
   {{0xf77026d4,0x69c826d5,0x656826d6,0x00000000}},	//   _سال_, _klee, pgeh, --, 
   {{0x216826d7,0x386008a4,0x6e2801e4,0x00000000}},	//   шими_, šire_, ĉebl, --, 
   {{0x9f480085,0xdb0c26d8,0x69c80363,0xa91c0010}},	//   mobú_, _robí, _mlee, _zažr, 
   {{0xd9b426d9,0xe29826da,0xa3cc1a22,0x00000000}},	//   _अक्ट, _вак_, _रति_, --, 
   {{0x69c826db,0xdb0c0118,0x5dd826dc,0x00000000}},	//   _olee, _pobí, афар_, --, 
   {{0x225003c6,0xe1f0034c,0xdb0c0798,0x6b800205}},	//   ázku_, _تست_, _lobã, _ılga, 
   {{0x1b48013e,0xdb0c003a,0x2258012d,0xdc68003b}},	// [2240] изаи_, _vobí, ąsku_, разд_, 
   {{0x69c826dd,0x00000000,0x00000000,0x00000000}},	//   _alee, --, --, --, 
   {{0x8eb00f31,0xdb0c25e6,0x69c826de,0x192c0023}},	//   _ہمیش, _tobí, _blee, _ብሓልዮ, 
   {{0x69c826df,0x5ca4039e,0x00000000,0x00000000}},	//   _clee, _димб, --, --, 
   {{0x69c80156,0xdb0c00d8,0x9f4800d0,0x718c00df}},	//   _dlee, _bobã, dobú_, טװאַ, 
   {{0x69c826e0,0x290c0099,0x3a380618,0x5fcc0490}},	//   _elee, _dzea_, _ttrp_, होचल, 
   {{0xeb9004ac,0x69c826e1,0x7bdc06be,0xa2d807af}},	//   _אָן_, _flee, _imru, _फेल्, 
   {{0x69c826e2,0x9cfc00cc,0x6aa001a8,0x00000000}},	//   _glee, ূখীন_, _álfa, --, 
   {{0x3a24009a,0x249c0042,0xdb1c0784,0x73d80982}},	//   _iimp_, _crwm_, shpä, йдир_, 
   {{0x3a2426e3,0x69c80165,0x249c03cb,0x00000000}},	//   _himp_, _zlee, _drwm_, --, 
   {{0x69c8049b,0xc7b00375,0x3a240254,0x15b000d1}},	//   _ylee, _קבע_, _kimp_, _يەتس, 
   {{0x453000db,0xc2b400d4,0x00000000,0x00000000}},	//   _قىمر, іляє_, --, --, 
   {{0xc95006a9,0x249c0142,0xf434010b,0x00000000}},	//   ומר_, _grwm_, _эелэ, --, 
   {{0x3a241590,0xcf240597,0x2cac0327,0x28bc26e4}},	//   _limp_, ترحي, _ħed_, ्नति, 
   {{0xcdd826e5,0x92f001c6,0x601002d2,0x00000000}},	//   ања_, _цүнх, dæmd, --, 
   {{0x7bdc26e6,0x8658010f,0x00000000,0x00000000}},	//   _amru, ידלי, --, --, 
   {{0x32180a73,0x69c80161,0xfc300966,0x00000000}},	// [2250] mmsy_, _rlee, نحل_, --, 
   {{0x95280003,0x290c0589,0x3a240165,0x69c826e7}},	//   _ཤུའི_, _rzea_, _aimp_, _slee, 
   {{0x69c826e8,0x8ae410f5,0xaa940597,0x6dc00137}},	//   _plee, ціал, ثلاث, _كۅسۅ, 
   {{0x16080034,0x3a2414b0,0x7bdc0200,0x00000000}},	//   _हीलर_, _cimp_, _emru, --, 
   {{0x69c826e9,0xe73826ea,0x3a240156,0x1ee804fb}},	//   _vlee, бел_, _dimp_, _نویی_, 
   {{0x2d880381,0xe730009a,0x00000000,0x00000000}},	//   leae_, رصت_, --, --, 
   {{0x69c80156,0x3a24007c,0x00000000,0x00000000}},	//   _tlee, _fimp_, --, --, 
   {{0xd90c066d,0x2d8826eb,0x386000c6,0x290c01c6}},	//   ئیے_, neae_, áirc_, _tzea_, 
   {{0x478805cc,0x6b940166,0x44280051,0x00000000}},	//   _всем_, _kazg, êc_, --, 
   {{0x6b9426ec,0x00000000,0x00000000,0x00000000}},	//   _jazg, --, --, --, 
   {{0x6b9426ed,0x9f4c02fd,0x3a240165,0xe1f826ee}},	//   _mazg, áním_, _yimp_, йго_, 
   {{0x6b9426ef,0x249c03cb,0x92601870,0x00000000}},	//   _lazg, _trwm_, رگىم, --, 
   {{0x9f4c00bc,0x2bc001f9,0x00000000,0x00000000}},	//   šním_, _एवढा, --, --, 
   {{0xdd9026f0,0x443c26f1,0x00000000,0x00000000}},	//   کور_, mpu_, --, --, 
   {{0x443c26f2,0x6010008c,0x248c0036,0x998402f0}},	//   lpu_, væmd, lwem_, bloň_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6b940399,0x443c0842,0x3a24030a,0x48d80210}},	// [2260] _bazg, npu_, _rimp_, _खेलो_, 
   {{0x3a2426f3,0x443c26f4,0x7b840075,0x58840588}},	//   _simp_, ipu_, بارە, ҧыла, 
   {{0x443c0842,0x2d88003a,0x8c40010b,0x00000000}},	//   hpu_, beae_, _җесе, --, 
   {{0x443c01f2,0x248c02e3,0xdb2401b9,0x3f9826f5}},	//   kpu_, kwem_, زوچی, ldru_, 
   {{0xdce40115,0x3a240489,0x443c0978,0xdb0c26f6}},	//   _bakĥ, _vimp_, jpu_, _dobá, 
   {{0xebb80882,0x3a24003b,0x6b9426f7,0x443c0978}},	//   tuḥ_, _wimp_, _gazg, dpu_, 
   {{0x3a240262,0x2bc00490,0x443c0064,0x248c0210}},	//   _timp_, _शकता, epu_, ewem_, 
   {{0x3a2404d4,0xdb0c0332,0x986803e0,0x00000000}},	//   _uimp_, _gobá, _göğe_, --, 
   {{0x6b9426f8,0x7980035a,0x443c26f9,0x00000000}},	//   _yazg, _ibmw, gpu_, --, 
   {{0x63ac0198,0xaf700023,0x88380375,0xdb0c0306}},	//   _ɗang, ብታትና_, _לתמו, _zobá, 
   {{0x443c26fa,0x3f980327,0x4270009d,0x41a808a3}},	//   apu_, ddru_, нгэс, गांस, 
   {{0x3f98005f,0x443c016d,0x2d88003a,0x00000000}},	//   edru_, bpu_, xeae_, --, 
   {{0x25640014,0x53a426fb,0x85980375,0x443c037e}},	//   _زانُ, _надб, _לשאו, cpu_, 
   {{0x82300ee8,0x798002d0,0x00000000,0x00000000}},	//   بریا, _lbmw, --, --, 
   {{0x263400b0,0x2d880393,0x518400f3,0x00000000}},	//   _kāoa_, teae_, _еупа, --, 
   {{0x3f980ffb,0x260000e8,0x6b940139,0x92f0054e}},	//   adru_, lóor_, _sazg, ăşăm, 
   {{0x263402b5,0x2d8816b8,0x953c001f,0x6b940240}},	// [2270] _māoa_, reae_, _በኢንተ, _pazg, 
   {{0xbca400c6,0xdb0c00d0,0x2d8826fc,0x2600002e}},	//   عملي, _sobá, seae_, nóor_, 
   {{0x6b9426fd,0x7b6426fe,0x2d88003a,0xa3cc23ef}},	//   _vazg, этте, peae_, रसत_, 
   {{0x443c016d,0x3eac26ff,0x6b940139,0x248c0210}},	//   ypu_, ådte_, _wazg, ywem_, 
   {{0x6d5c03ac,0x6b942700,0xa91c00d7,0x21f00327}},	//   _idsa, _tazg, _obže, nġha_, 
   {{0x38600c63,0x98a02701,0x798002d0,0xa9080451}},	//   áira_, тише, _ebmw, ٽيڪل_, 
   {{0xc6a40853,0x248c2702,0x9f5c06af,0xdb0c01e7}},	//   ярди, wwem_, ôté_, _tobá, 
   {{0x386008a4,0x248c033f,0x7980035a,0x443c2703}},	//   šira_, twem_, _gbmw, tpu_, 
   {{0x6f08012c,0x443c2704,0x6adc041c,0xdce8002b}},	//   řech, upu_, _मधुर, _ānīt, 
   {{0x4a28025c,0x00000000,0x00000000,0x00000000}},	//   _སྤོལ_, --, --, --, 
   {{0xa1881d5a,0x443c0978,0xf77002dd,0x248c0af9}},	//   обна_, spu_, _حاق_, swem_, 
   {{0x443c2705,0x6b2c0327,0x00000000,0x00000000}},	//   ppu_, _ཧུའོ_, --, --, 
   {{0xc4f80e83,0x66082706,0x26000de2,0x443c0978}},	//   _اعضا_, mlek, bóor_, qpu_, 
   {{0x6d5c2707,0x442c003a,0x9ea82708,0xa2e4004e}},	//   _adsa, _iug_, овга_, _оолд, 
   {{0x442c2709,0x4424270a,0xd004270b,0x6608270c}},	//   _hug_, _iin_, фере_, olek, 
   {{0x4424270d,0x4a281e81,0x66080724,0x3f98054e}},	//   _hin_, _སྤེལ_, nlek, sdru_, 
   {{0x442c270e,0x9c24270f,0x644c067c,0x66082710}},	// [2280] _jug_, ддад, _çaid, ilek, 
   {{0x44240b45,0x6d5c2711,0x5f4400f1,0xa3cc00cd}},	//   _jin_, _edsa, _تندل, रसि_, 
   {{0x442c2712,0x6608013d,0x6eb42713,0x0e600166}},	//   _lug_, klek, _उपयु, _икэн, 
   {{0x44242714,0x66082715,0x442c0276,0xd9442716}},	//   _lin_, jlek, _oug_, феди, 
   {{0x66082717,0x44242718,0x442c0457,0x645c2719}},	//   dlek, _oin_, _nug_, ásil, 
   {{0x4424271a,0x6ee401b9,0xc7a024fc,0xda64009d}},	//   _nin_, _آسیل, кичк, _овги, 
   {{0x34b808dd,0x442c0375,0x263402b1,0x07a02096}},	//   ेन्द, _aug_, _pāoa_, тајн, 
   {{0x4424271b,0x6608271c,0x629c0618,0x442c271d}},	//   _ain_, glek, āsol, _bug_, 
   {{0x4424271e,0x442c271f,0xa30000fd,0x92e80154}},	//   _bin_, _cug_, ңүче, _মরে_, 
   {{0x2e440100,0x12e402dd,0x442c0e21,0x44242720}},	//   _jèfò_, дімг, _dug_, _cin_, 
   {{0x442c08c2,0x44f0006c,0xa2c407b6,0x25c801d3}},	//   _eug_, فسیز, ानग्, átló_, 
   {{0x44242721,0x442c2722,0x00000000,0x00000000}},	//   _ein_, _fug_, --, --, 
   {{0x442c0bfa,0xf0e800d1,0x00000000,0x00000000}},	//   _gug_, سىسى_, --, --, 
   {{0x44242723,0xdb0c014a,0xa2d807f7,0x78a40108}},	//   _gin_, _kobä, _फेक्, äivy, 
   {{0x442c2724,0x8e240798,0x76580064,0x00000000}},	//   _zug_, дфад, nsvy, --, 
   {{0x44242725,0x442c0457,0x7fb80166,0x60d800df}},	//   _zin_, _yug_, _aşqı, ŝtma, 
   {{0x44242726,0x00000000,0x00000000,0x00000000}},	// [2290] _yin_, --, --, --, 
   {{0x44242727,0x66082728,0x4a280327,0x09c400cd}},	//   _xin_, zlek, _སྤུལ_, लस्य, 
   {{0x660800ee,0xdb0c01c7,0x00000000,0x00000000}},	//   ylek, _nobä, --, --, 
   {{0x6d5c04ce,0x66082729,0x28bc0950,0xa9c000f7}},	//   _udsa, xlek, ्नलि, دۅرۉ, 
   {{0xdd38025f,0x66080dfe,0xe738272a,0x52c808a3}},	//   _מערכ, vlek, пел_, ानुस, 
   {{0xe738272b,0x2d98272c,0xe61004fb,0xa6941b88}},	//   чек_, _hase_, گشت_, ериј, 
   {{0x4424272d,0x6608272e,0x2d98272f,0x442c2730}},	//   _rin_, tlek, _kase_, _sug_, 
   {{0xdb0c2731,0x9f4802fb,0x970000d1,0xe6102732}},	//   _dobä, dobý_, دېمى, دشت_, 
   {{0x66082733,0x74f805f5,0x44242734,0x442c2735}},	//   rlek, дээс_, _pin_, _qug_, 
   {{0xe3b006d5,0x44242736,0xe8bc03f3,0x66082737}},	//   ارة_, _qin_, ्नीच, slek, 
   {{0x44242738,0x66082739,0xdb0c008e,0x00000000}},	//   _vin_, plek, _gobä, --, 
   {{0x442c273a,0x4424273b,0x2b500165,0x52740066}},	//   _tug_, _win_, _lezc_, راپز, 
   {{0x4424273c,0x3074273d,0x10a0273e,0x00000000}},	//   _tin_, курс, гиян, --, 
   {{0x25bc273f,0x44242740,0x2d980363,0x356800fb}},	//   _howl_, _uin_, _aase_, _ерән_, 
   {{0x2d982741,0x9290009b,0x00000000,0x00000000}},	//   _base_, _бајц, --, --, 
   {{0x2d982742,0x25bc0076,0xa3cc033f,0x21740139}},	//   _case_, _jowl_, रसव_, _чукр, 
   {{0x2d980077,0x00000000,0x00000000,0x00000000}},	// [22a0] _dase_, --, --, --, 
   {{0x61e42743,0x25bc01f5,0x2d9826e7,0xbac400cc}},	//   likl, _lowl_, _ease_, _এইবছ, 
   {{0xdee4013e,0x60c42744,0x5eb80154,0x00000000}},	//   _чони, lykm, _উইকে, --, 
   {{0x61e42745,0x00000000,0x00000000,0x00000000}},	//   nikl, --, --, --, 
   {{0x79a40032,0x6818007f,0xe9700145,0x0d740066}},	//   ерҙе, _pňdp, شۇلد, _سیلک_, 
   {{0x2d981b5c,0xb7d801ec,0x61e42746,0xa3e001ad}},	//   _zase_, بوتا_, hikl, नोम_, 
   {{0x7e7c01e0,0x2d982747,0x61e42748,0x25bc2749}},	//   ntrp, _yase_, kikl, _bowl_, 
   {{0xceb0025f,0x25bc1caa,0xdb0c01b8,0x61e4086f}},	//   ריה_, _cowl_, _vobä, jikl, 
   {{0x61e4274a,0x53e4274b,0x2b5401d9,0x9868274c}},	//   dikl, ецна, _سیۆد_, _хизб_, 
   {{0xb5d80150,0xded00092,0xf8b000ec,0x60c400a2}},	//   _ﺀﺑﯩﺰ, ኩሏን_, _مکڻ_, dykm, 
   {{0x25bc274d,0x6b8000fd,0x61e4274e,0xaa2801d9}},	//   _fowl_, _ölge, fikl, _رسہٕ_, 
   {{0xa2c01cd1,0x25bc0003,0x61e4274f,0x00000000}},	//   рәшк, _gowl_, gikl, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2d982750,0x43902751,0xb4cc107c,0xd2580798}},	//   _sase_, _башс, रनी_, _еци_, 
   {{0x2d982752,0x61e40fe3,0x25bc0204,0xef1000f7}},	//   _pase_, bikl, _yowl_, рүнө, 
   {{0x2d9803b4,0x60100158,0x00000000,0x00000000}},	//   _qase_, ræma, --, --, 
   {{0xa91c2753,0x6b74008e,0x8240001f,0x0320013d}},	// [22b0] _obža, клау, _የተሳሳ, _идән, 
   {{0x2d982754,0xa2c423e9,0x6aa0032e,0x00000000}},	//   _wase_, ानच्, _álfk, --, 
   {{0x2d982755,0xbf140bd6,0xdeb00150,0xadbc0064}},	//   _tase_, _бүрә, _кұры, _данi, 
   {{0x2d98003a,0x645c00e4,0x00000000,0x00000000}},	//   _uase_, ásik, --, --, 
   {{0xcf242756,0xdb0c0623,0x25bc0076,0xa30c00e1}},	//   _ترکي, _robå, _rowl_, _हर्ज_, 
   {{0x61e42757,0x25bc039a,0x00000000,0x00000000}},	//   zikl, _sowl_, --, --, 
   {{0x98f404a9,0x9ba00075,0x79a42758,0x6934014b}},	//   ىغۇچ, _خەلى, _өрте, _анбу, 
   {{0x25bc058a,0x00000000,0x00000000,0x00000000}},	//   _qowl_, --, --, --, 
   {{0x61e42759,0x00000000,0x00000000,0x00000000}},	//   vikl, --, --, --, 
   {{0xf770275a,0x13e4008e,0x00000000,0x00000000}},	//   _هام_, кмый_, --, --, 
   {{0x2168275b,0xc648275c,0x25bc1368,0x626402e8}},	//   мини_, _رجال_, _towl_, ъвна, 
   {{0xd3e401d5,0x00000000,0x00000000,0x00000000}},	//   _یقنی, --, --, --, 
   {{0x61e4275d,0x00000000,0x00000000,0x00000000}},	//   rikl, --, --, --, 
   {{0xe28400b1,0x60c4275e,0xe5a4010a,0x5040104e}},	//   _алки, rykm, _пиçи, рерб, 
   {{0xe3b0021a,0x61e4275f,0x52b0007b,0xf644074d}},	//   _مرګ_, pikl, _نموذ, _ыхăн, 
   {{0x8d601429,0x61e4022e,0x00000000,0x00000000}},	//   ивсе, qikl, --, --, 
   {{0x7e7c1a48,0x00000000,0x00000000,0x00000000}},	// [22c0] strp, --, --, --, 
   {{0x9f482760,0x20182761,0x00000000,0x00000000}},	//   robó_, _تتبع_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x18682762,0xa3cc00c5,0x00000000,0x00000000}},	//   дади_, रसँ_, --, --, 
   {{0xd7f82763,0x0c980092,0x00000000,0x00000000}},	//   мук_, _ቅርሶች_, --, --, 
   {{0xda642764,0xbdc800e5,0xb88c0092,0x00000000}},	//   _لاري, _آدھے_, _ማይጨው_, --, 
   {{0xa91c0006,0x1994009b,0x00000000,0x00000000}},	//   _mažy, _ијар, --, --, 
   {{0xd87422f3,0x310400dc,0xa91c0153,0x00000000}},	//   _لائب, रथमः_, _lažy, --, 
   {{0xb4cc13b4,0xa3cc0b7c,0xed880023,0x52c811bc}},	//   रने_, रसं_, _ምጽባይ_, ान्स, 
   {{0x27e8004a,0x0e7402d3,0x674400bc,0x2604004e}},	//   éant_, _ይግብኦ_, čují, кчөг, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x550401d5,0x00000000,0x00000000,0x00000000}},	//   _ичла, --, --, --, 
   {{0x63c40510,0x50640395,0x00000000,0x00000000}},	//   ýunç, ътна, --, --, 
   {{0xa3e02765,0xa3cc00cd,0x00000000,0x00000000}},	//   नोद_, रसः_, --, --, 
   {{0x3d3801f2,0xa91c0024,0x00000000,0x00000000}},	//   _ọwa_, _dažy, --, --, 
   {{0x61f40240,0xac942766,0x2bbc0709,0x00000000}},	//   _gjyl, лабш, ोस्थ, --, 
   {{0x32082767,0xa9a42768,0xd01801af,0x00000000}},	// [22d0] _ikay_, ғилд, _офо_, --, 
   {{0xdce400d7,0xc8b0015e,0x00000000,0x00000000}},	//   _fakľ, یلاک, --, --, 
   {{0x32080784,0x61f400a2,0xdb0c00d7,0x00000000}},	//   _kkay_, _yjyl, _zobú, --, 
   {{0x700001f2,0x684c0023,0x00000000,0x00000000}},	//   _ịcho, _ዝተረድ, --, --, 
   {{0xa884215c,0x00000000,0x00000000,0x00000000}},	//   التى, --, --, --, 
   {{0xaa5c2769,0x00000000,0x00000000,0x00000000}},	//   _негi, --, --, --, 
   {{0x06e0276a,0x320802c2,0xf3f800fe,0x00000000}},	//   _केशव_, _okay_, ঁতাৰ_, --, 
   {{0x320800ca,0x28140133,0x81e800fe,0x00000000}},	//   _nkay_, _ڵواس, _ভৱন_, --, 
   {{0x27e8276b,0xe3b0276c,0x00000000,0x00000000}},	//   éans_, مرد_, --, --, 
   {{0xdb0c0332,0x36880ce8,0x9f5400e5,0x00000000}},	//   _robú, хсән_, égük_, --, 
   {{0xb2f407d8,0xf77001c8,0x04840014,0x2bf000cc}},	//   ияющ, _ذال_, رٕگی_, _জীৱই_, 
   {{0x9f4c03c6,0xa068276d,0x20180240,0xdb0c00d0}},	//   čník_, нама_, _shpi_, _pobú, 
   {{0xa91c02d5,0xc60c11b1,0x23840014,0xc3d802dd}},	//   _pažy, ातीय_, _مٔشِ, _жөнi, 
   {{0x320802d0,0x701801ce,0x42c4014b,0xfe44009d}},	//   _ekay_, віст_, _аҳон_, имгү, 
   {{0x21a4004e,0x4c640116,0xd00c007b,0x00000000}},	//   _бийм, һитн_, سلف_, --, 
   {{0x63b4276e,0x00000000,0x00000000,0x00000000}},	//   šanč, --, --, --, 
   {{0x5ba8276f,0x65782770,0xdb0c0fac,0x00000000}},	// [22e0] нкам_, _mcwh, _hobø, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x779404fb,0xdb0c01bf,0x4c900aac,0x320803ac}},	//   ییرا, _jobø, _қиёс, _ykay_, 
   {{0xdb0c002d,0x9d44010b,0x99b00154,0x05a0000d}},	//   _ynbê, _щемд, চস্ক, _खोलब, 
   {{0xd7e41ed2,0x6010005c,0x06800014,0x29000205}},	//   ліко, hæmm, ۅلوُ, şhan_, 
   {{0xacb011dc,0x00000000,0x00000000,0x00000000}},	//   _بەكب, --, --, --, 
   {{0xb4cc00dc,0x46640166,0x00000000,0x00000000}},	//   रन्_, грым_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x320801f7,0xdb1c2771,0x987410fc,0xa784072d}},	//   _rkay_, skpä, _љубљ, _چشمو, 
   {{0x32080113,0xd3782772,0x08c01422,0xe8f41de6}},	//   _skay_, хчи_, _убун, _әһә_, 
   {{0x0bb402e4,0x00000000,0x00000000,0x00000000}},	//   אלים_, --, --, --, 
   {{0xc2b400d4,0xa56406c2,0x00000000,0x00000000}},	//   улює_, _ندهن, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x40342773,0x44f00006,0xed582774,0x00000000}},	//   серс, _упіс, _žž_, --, 
   {{0x8bc416c3,0x32080051,0x02a00153,0x7e44004e}},	//   қсад, _tkay_, _грым, йхте, 
   {{0x32082775,0x9f482776,0xfd7401c0,0x5fc401ad}},	//   _ukay_, nibê_, йлсэ, रॉबल, 
   {{0xa3e007f7,0x00000000,0x00000000,0x00000000}},	// [22f0] नोव_, --, --, --, 
   {{0xbc680451,0x3b54004e,0x00000000,0x00000000}},	//   املن_, йкур, --, --, 
   {{0x8aa42777,0x00000000,0x00000000,0x00000000}},	//   ырад, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x995401ec,0x00000000,0x00000000,0x00000000}},	//   сiби_, --, --, --, 
   {{0x6d4c2778,0x00000000,0x00000000,0x00000000}},	//   lbaa, --, --, --, 
   {{0x6d4c0067,0x00000000,0x00000000,0x00000000}},	//   obaa, --, --, --, 
   {{0x6d4c2779,0x00000000,0x00000000,0x00000000}},	//   nbaa, --, --, --, 
   {{0x851c277a,0x6d4c277b,0x69d8013f,0x00000000}},	//   मेंट_, ibaa, mhwe, --, 
   {{0xe284035b,0x6d4c0067,0x2328277c,0x53c40166}},	//   алои, hbaa, копи_, игым_, 
   {{0x6d4c1aa7,0x7dd801e7,0xdce40171,0xe3b0277d}},	//   kbaa, _híse, _sakļ, مرگ_, 
   {{0x6d4c0196,0x6010037e,0xe124277e,0x69d80134}},	//   jbaa, ræmm, имни, nhwe, 
   {{0x6d4c277f,0xbb1c07d2,0x00000000,0x00000000}},	//   dbaa, _ﺷﺎﻡ_, --, --, 
   {{0x64482780,0x6d4c0083,0xd46426b1,0x00000000}},	//   mpei, ebaa, _тише_, --, 
   {{0xdd902781,0x69d82782,0x6d4c2783,0x7dd800d2}},	//   يوس_, khwe, fbaa, _líse, 
   {{0x62802784,0x6d4c2785,0x38600552,0x20542786}},	//   mtlo, gbaa, širi_, _ктор, 
   {{0xd00c066d,0x644803f5,0x69d82787,0x27200b4c}},	// [2300] سلہ_, npei, dhwe, मधुर_, 
   {{0x6d4c2788,0xef18013e,0x644801ab,0x62800175}},	//   abaa, тмӣ_, ipei, otlo, 
   {{0x7f5c2789,0x6280021a,0x6d4c0bc1,0x00000000}},	//   marq, ntlo, bbaa, --, 
   {{0xed340323,0x2250278a,0xf958040b,0x7f5c0784}},	//   _гэрэ, ázky_, اساں_, larq, 
   {{0x38600597,0x913800c8,0x62800e78,0x2714004d}},	//   éir_, דענק, htlo, _án_, 
   {{0x7f5c278b,0x7dd8278c,0x6f0803ee,0x00000000}},	//   narq, _díse, şece, --, 
   {{0x69d80117,0x7f5c0194,0x644801f5,0xa4180073}},	//   bhwe, iarq, epei, _नीधप_, 
   {{0x69d8278d,0x7dd80597,0xa2a8278e,0xef3c001f}},	//   chwe, _físe, टिन्, ካሄደው, 
   {{0x0308068f,0x7f5c03f0,0x6280033f,0xdce40205}},	//   _सुबह_, karq, etlo, _kakı, 
   {{0x44f0278f,0x3a3800de,0x00000000,0x00000000}},	//   تسىز, _kurp_, --, --, 
   {{0x6d4c2790,0xcb340a1e,0x6aa001a8,0x628001bf}},	//   ybaa, יניק_, _álft, gtlo, 
   {{0xf4840133,0x37b80183,0x9f4802e2,0xdce42791}},	//   _هاتی, _অতিৰ, libè_, _lakı, 
   {{0x92b4015b,0x6818010e,0x7f5c01a9,0x645c0419}},	//   ছনে_, _aňdy, farq, ásit, 
   {{0x7f5c2792,0x92142793,0x6d4c2794,0xdce405d1}},	//   garq, _धीरज_, wbaa, _nakı, 
   {{0x6d4c2795,0x62802796,0x69d80472,0xd1640395}},	//   tbaa, ctlo, yhwe, _къпи, 
   {{0x6d4c2797,0x69d82798,0x629c1c52,0x00000000}},	//   ubaa, xhwe, āsot, --, 
   {{0xdce42799,0x6d4c279a,0x7f5c279b,0x00000000}},	// [2310] _bakı, rbaa, barq, --, 
   {{0x6d4c279c,0x8aa4279d,0x3a38279e,0xdce40205}},	//   sbaa, иред, _burp_, _cakı, 
   {{0x69d81253,0x6d4c2595,0x7dd8279f,0x3a3827a0}},	//   thwe, pbaa, _síse, _curp_, 
   {{0x80a427a1,0x7dd80316,0x6fd80ffb,0x6d4c27a2}},	//   _امین, _píse, _dìce, qbaa, 
   {{0x69d827a3,0xdce40205,0x00000000,0x00000000}},	//   rhwe, _fakı, --, --, 
   {{0xdce40139,0x681800a2,0xc60c09fa,0x00000000}},	//   _gakı, _yňdy, ात्य_, --, 
   {{0x644803a2,0x69d827a4,0xded0001f,0x3a3800a2}},	//   wpei, phwe, _የዜና_, _gurp_, 
   {{0x69d827a5,0x070400f1,0xadf827a6,0x04380092}},	//   qhwe, هيږي_, ्किन_, _በባለሙ, 
   {{0xdce427a7,0x7f5c0986,0x240827a8,0xdb0c0248}},	//   _yakı, yarq, лнии_, _àjòj, 
   {{0xa3e027a9,0x628027aa,0xe298026a,0xdce40724}},	//   नों_, ttlo, гао_, _xakı, 
   {{0x644827ab,0x66f400ee,0xe74401e0,0xadf8013a}},	//   spei, _упжу, _күҙе_, ्कान_, 
   {{0x64481057,0x7f5c03f0,0xe7380124,0x6d4027ac}},	//   ppei, warq, _реҧ_, _şlan, 
   {{0x7f5c27ad,0x660827ae,0x9f48020c,0xa3b801c8}},	//   tarq, moek, libé_, _ماثر_, 
   {{0xd91827af,0xc3481064,0x660827b0,0x21640137}},	//   טורל, _ряде_, loek, штүг, 
   {{0x7f5c27b1,0x601005f7,0xdce40790,0xa3e000cd}},	//   rarq, næmi, _rakı, नोः_, 
   {{0xdce403ee,0x7f5c02d1,0x9f3401ec,0x660827b2}},	//   _sakı, sarq, реңі, noek, 
   {{0x7f5c27b3,0x5b3427b4,0x3a380165,0xdb0c0306}},	// [2320] parq, معار, _surp_, _dobý, 
   {{0x660827b5,0x2600011f,0x7f5c03f0,0x2d8c0de2}},	//   hoek, róoy_, qarq, _ñeen_, 
   {{0xdce40598,0x660827b6,0x200827b7,0x9f48020c}},	//   _vakı, koek, mobi_, jibé_, 
   {{0x200827b8,0x7dd827b9,0x9f480129,0x657c00a3}},	//   lobi_, _dísc, dibé_, òshl, 
   {{0x1cb827ba,0xdce40ab7,0x660827bb,0x64440374}},	//   _صاحب_, _takı, doek, _ōhin, 
   {{0x200827bc,0x8c4009a5,0x3a3827bd,0x9ad40006}},	//   nobi_, _хере, _turp_, _любі, 
   {{0x644c068c,0x00000000,0x00000000,0x00000000}},	//   _çaij, --, --, --, 
   {{0x200827be,0xd49827bf,0x6608009d,0x00000000}},	//   hobi_, гро_, goek, --, 
   {{0x73d81751,0xdb0c0793,0x3944009f,0xd9780022}},	//   идир_, _lobü, _ifms_, _арҕә_, 
   {{0x249c007f,0x2008009a,0x9f480129,0x00000000}},	//   _dswm_, jobi_, bibé_, --, 
   {{0x660827c0,0x200827c1,0x55e40139,0x9f480129}},	//   boek, dobi_, _ложб, cibé_, 
   {{0x386000f3,0xe5780042,0x9618007b,0xbb4c0150}},	//   širu_, ghŷd_, _صغار_, _ﺍﻹﻴ_, 
   {{0x200827c2,0xdb0c0085,0x2ed027c3,0x73c402dd}},	//   fobi_, _kobó, सन्त, _дәне, 
   {{0x63ac03f9,0x03a00276,0x20080083,0x2cac0306}},	//   _ɗank, _ничо, gobi_, _šedo_, 
   {{0xdb0c0118,0x00000000,0x00000000,0x00000000}},	//   _pobý, --, --, --, 
   {{0x21f027c4,0xdb0c0085,0x00000000,0x00000000}},	//   tšhe_, _lobó, --, --, 
   {{0x200827c5,0x316801c4,0x7dd80332,0x6eb427c6}},	// [2330] bobi_, _idaz_, _sísc, _उपकु, 
   {{0x66080936,0x00000000,0x00000000,0x00000000}},	//   zoek, --, --, --, 
   {{0x6fb427c7,0xfbd000c6,0xd1dc02d3,0xcb1800d8}},	//   _همکا, رتك_, _ዓሌት_, уќа_, 
   {{0x7dd80077,0xdd901b40,0x660801c4,0x311c00cd}},	//   _vísc, _قوپ_, xoek, _नराः_, 
   {{0x7648010b,0x660801e4,0x48d40154,0x7658002b}},	//   _atdy, voek, তপ্র, _āraṇ, 
   {{0x660808c8,0x2ca80978,0xa7a827c8,0x00000000}},	//   woek, mvad_, ркка_, --, 
   {{0x2ca827c9,0x660827ca,0xdb0c0c57,0x00000000}},	//   lvad_, toek, _dobó, --, 
   {{0xa44427cb,0xe61803b7,0xc0e0001f,0x20080472}},	//   онид, јди_, _ነዋሪ_, zobi_, 
   {{0x386000c6,0x9f480066,0xa91c0306,0x2ca8016d}},	//   áirt_, sibé_, _obži, nvad_, 
   {{0x66080151,0x7dd8013d,0x2ca80254,0xdc2c0139}},	//   soek, _mísa, ivad_, _yııl, 
   {{0x2ca827cc,0x7dd800d2,0x6608003e,0x6eb4095f}},	//   hvad_, _lísa, poek, _उपगु, 
   {{0x249c0211,0x9508063f,0x26d80165,0x00000000}},	//   _tswm_, ịzịg, _ęsoh_, --, 
   {{0x200827cd,0x34940b3e,0x2ca80978,0xd24c27ce}},	//   tobi_, _нацр, jvad_, _ینو_, 
   {{0x232827cf,0x2ca827d0,0x25e404af,0xd00c0592}},	//   _коли_, dvad_, जोरी_, َلَ_, 
   {{0x443c27d1,0xa2e4006c,0x53980375,0x2ca8000d}},	//   lqu_, _фойд, _כיסו, evad_, 
   {{0x200827d2,0xe7e801ad,0x2d8c1574,0x00000000}},	//   sobi_, झोता_, _ñeel_, --, 
   {{0x443c27d3,0x1be8013e,0x7dd800bc,0xe204121d}},	// [2340] nqu_, адаи_, _císa, रवीण_, 
   {{0x443c06af,0x7dd808ce,0x20080454,0x6f080205}},	//   iqu_, _dísa, qobi_, şeca, 
   {{0x3f9827d4,0x2ca800af,0x7094001f,0xdb0c27d5}},	//   meru_, avad_, ያደርጉ_, _robó, 
   {{0x2ca8014f,0xdb0c0210,0x00000000,0x00000000}},	//   bvad_, _sobó, --, --, 
   {{0x443c0978,0xdb0c0210,0x00000000,0x00000000}},	//   jqu_, _pobó, --, --, 
   {{0x3f9827d6,0x48d80183,0x443c0978,0x00000000}},	//   neru_, বপূৰ, dqu_, --, 
   {{0xd94400d1,0x443c0003,0x00000000,0x00000000}},	//   _меви, equ_, --, --, 
   {{0x3f9827d7,0x394400d8,0x443c0135,0x99d40244}},	//   heru_, _ufms_, fqu_, _بقرت, 
   {{0x3f9827d8,0x224827d9,0x443c047e,0x7dd80166}},	//   keru_, _čaka_, gqu_, _xísa, 
   {{0x3f98041a,0xc5100131,0x00000000,0x00000000}},	//   jeru_, ببىت, --, --, 
   {{0x443c0766,0x764827da,0x8c18011a,0x2ca8030a}},	//   aqu_, _utdy, שויי, zvad_, 
   {{0x443c016d,0x2ca8016d,0x00000000,0x00000000}},	//   bqu_, yvad_, --, --, 
   {{0x3f9827db,0x798002d0,0x910402e8,0x9f480042}},	//   feru_, _mcmw, ючод, ribî_, 
   {{0xdde000f3,0x2ca8016d,0x7dd80a87,0x603001ef}},	//   _ćušk, vvad_, _rísa, _němě, 
   {{0xfeb827dc,0x63740022,0xadf800bc,0x2ca80455}},	//   يافت_, _ỹngu, ्कलन_, wvad_, 
   {{0x7dd801f1,0x3168005a,0xb62c037e,0xc32c1c3e}},	//   _písa, _udaz_, _ｒｉ_, _جەپ_, 
   {{0x9f840086,0xb05427dd,0xa3e0000d,0xb33c0327}},	// [2350] _eôñ_, ọọrọ_, नोक_, ndħo, 
   {{0x3f9827de,0x7dd809f3,0xdb0c1497,0x2ca827df}},	//   ceru_, _vísa, _robò, rvad_, 
   {{0x2ca8016d,0x443c022e,0x00000000,0x00000000}},	//   svad_, zqu_, --, --, 
   {{0xdb240214,0x2ca8047e,0x443c27e0,0x00000000}},	//   سونی, pvad_, yqu_, --, 
   {{0x6d5c00da,0x2ca8016d,0x00000000,0x00000000}},	//   _iesa, qvad_, --, --, 
   {{0x05a01524,0x798027e1,0xdc38011a,0x443c0978}},	//   _खोजब, _ecmw, _לעשר, vqu_, 
   {{0x6d5c27e2,0xba7427e3,0x443c047e,0xc6a401d5}},	//   _kesa, _يافت, wqu_, юрди, 
   {{0x6d5c27e4,0x3f9827e5,0x80b402f5,0xfb340953}},	//   _jesa, zeru_, ুনত্, _інтэ, 
   {{0x29180ad9,0x3f9827e6,0x443c0ba1,0x649801b9}},	//   _ása_, yeru_, uqu_, ётир_, 
   {{0x443c27e7,0x33d40212,0x00000000,0x00000000}},	//   rqu_, діют, --, --, 
   {{0x443c27e8,0xe71827e9,0x69c803a0,0x3f9827ea}},	//   squ_, _ايات_, _koee, veru_, 
   {{0x3f9827eb,0x9ae8004d,0x443c0978,0x00000000}},	//   weru_, _mabư_, pqu_, --, 
   {{0x69c80032,0xe44827ec,0xddcc151c,0x7dd802d2}},	//   _moee, _التى_, jubš, _bísn, 
   {{0x6d5c0156,0x6458047e,0xe29800d8,0x00000000}},	//   _aesa, _iwwi, _гак_, --, 
   {{0x6d5c27ed,0x3f9827ee,0x00000000,0x00000000}},	//   _besa, reru_, --, --, 
   {{0x3f9827ef,0x64580472,0x1c4427f0,0x2d940166}},	//   seru_, _kwwi, знам, мрус, 
   {{0x3f9827f1,0xa2a827f2,0x3ba40107,0x3d28030f}},	// [2360] peru_, टिव्, млаҳ, زتری_, 
   {{0x6d5c27f3,0x798002d0,0x6eb4023e,0x00000000}},	//   _eesa, _scmw, _उपचु, --, 
   {{0x6d5c27f4,0x69c801e0,0xcf540375,0xf8b401ad}},	//   _fesa, _boee, _מבית_, ंम्प, 
   {{0x6d5c27f5,0xd8380108,0xc8340023,0xbf580055}},	//   _gesa, бэк_, _ክሰምዕ, _ārṣe_, 
   {{0x8eb00214,0x00000000,0x00000000,0x00000000}},	//   _قمیش, --, --, --, 
   {{0x6d5c27f6,0x00000000,0x00000000,0x00000000}},	//   _zesa, --, --, --, 
   {{0x6d5c27f7,0x64580003,0x030800e1,0x8f980a1e}},	//   _yesa, _awwi, _सुलह_, מיסי, 
   {{0x6458003e,0x9f48011f,0x8af8011a,0x7dd801ef}},	//   _bwwi, nibâ_, _ההלי, _míso, 
   {{0x7dd800d2,0xd4981086,0xdb1c0254,0x6d4006be}},	//   _líso, ёри_, hkpü, _şlak, 
   {{0x69c801f5,0xdb1c000d,0xe70800db,0xb9dc0092}},	//   _zoee, kkpü, حتۇن_, _በሱ_, 
   {{0x9f48026c,0x7dd801e1,0x73341870,0x00000000}},	//   ribì_, _níso, بىدا, --, 
   {{0xd498033a,0x00000000,0x00000000,0x00000000}},	//   _грк_, --, --, --, 
   {{0x94240046,0x7dd8012c,0x6d5c27f8,0x3a2401ef}},	//   _емде, _písn, _resa, _mhmp_, 
   {{0x6e94008e,0x00000000,0x00000000,0x00000000}},	//   мигу, --, --, --, 
   {{0x6d5c27f9,0x9f4800eb,0x2d8c0de2,0xd2440137}},	//   _pesa, cibí_, _ñeek_, _ээли, 
   {{0x6d5c27fa,0x42f80302,0x7bdc005c,0xa2a800cd}},	//   _qesa, _להוס, _alru, टिर्, 
   {{0x6d5c27fb,0xfd740323,0x7bdc0083,0x7dd827fc}},	// [2370] _vesa, элтэ, _blru, _tísn, 
   {{0x6e9827fd,0x4ea427fe,0x4ba40137,0x0fe01e4a}},	//   _двор_, _ерма, чөмү_, _чөмү, 
   {{0x69c827ff,0xa3e005d7,0x6010005c,0x00000000}},	//   _poee, नोट_, ræmt, --, 
   {{0x7bdc2800,0x3a240789,0x6d5c2801,0xc3300375}},	//   _elru, _chmp_, _uesa, גוע_, 
   {{0xe73806ed,0x628400e4,0x00000000,0x00000000}},	//   оел_, _ãhov, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x5690147e,0x7c200036,0x64580142,0xaa541cd0}},	//   вајт, _ëmra, _swwi, _іваш, 
   {{0x44a0010b,0xd90c0583,0x3a2401ef,0x00000000}},	//   егиң, ایے_, _ghmp_, --, 
   {{0x66d400b2,0x00000000,0x00000000,0x00000000}},	//   _ڪيائ, --, --, --, 
   {{0x7dd80789,0xa3e80212,0xa2a82802,0xf91c032e}},	//   _aísl, ідна_, टिल्, _íþað_, 
   {{0xa2e42803,0x00000000,0x00000000,0x00000000}},	//   фонд, --, --, --, 
   {{0x67202804,0x00000000,0x00000000,0x00000000}},	//   _izlj, --, --, --, 
   {{0x64580ba7,0x7dd82805,0x64a42806,0x01e400db}},	//   _uwwi, _dísl, _цала, _үйлү, 
   {{0x7dd801f1,0xe2c800f2,0x00000000,0x00000000}},	//   _píso, _ووشو_, --, --, 
   {{0xe7e4007d,0xd3442807,0x00000000,0x00000000}},	//   _कतना_, _تیپه_, --, --, 
   {{0xe1f004fb,0x7dd8066a,0x00000000,0x00000000}},	//   _جست_, _gísl, --, --, 
   {{0xa008007b,0x3f8c0037,0x00000000,0x00000000}},	// [2380] _وقبل_, õdus_, --, --, 
   {{0x67202808,0x00000000,0x00000000,0x00000000}},	//   _ozlj, --, --, --, 
   {{0xf0001206,0xa5bc0024,0x00000000,0x00000000}},	//   _сүри, rmųj, --, --, 
   {{0x7e7c0784,0x9f480109,0x2124013a,0x00000000}},	//   murp, libà_, _úohs_, --, 
   {{0x5fd0006d,0x7e7c2809,0x00000000,0x00000000}},	//   _हवाल, lurp, --, --, 
   {{0x1648011c,0x00000000,0x00000000,0x00000000}},	//   очип_, --, --, --, 
   {{0x37c40184,0x63ac0198,0xa3b0033f,0xdab8007b}},	//   _үҙеб, _ɗant, _ऑफ़_, _ظهرت_, 
   {{0x2cac000a,0xc2140134,0x998405c7,0x00000000}},	//   _šedi_, _nkɔ_, mmoů_, --, 
   {{0xd49802bf,0x38c81079,0xd4040815,0x00000000}},	//   іри_, _عاری_, дяни, --, 
   {{0xc214013b,0x7e7c280a,0x32540276,0x461001b9}},	//   _akɔ_, kurp, нвор, _یولر, 
   {{0xc7b006a9,0x7dd8032e,0x580000d1,0xd734030d}},	//   _שבע_, _písl, _كۈچك, _цхаь, 
   {{0x7e7c03f0,0xe6d802d2,0x00000000,0x00000000}},	//   durp, _íráð, --, --, 
   {{0xd3c4280b,0x660400d5,0x3cf8012d,0x4084004e}},	//   _ойдй, éhke, ंपों_, курб, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb8d00003,0x7e7c280c,0x02a0280d,0x00000000}},	//   _ཐན_, gurp, _арым, --, 
   {{0x8d74280e,0x9f480589,0xfbd004fb,0x0204008e}},	//   باسا, tibã_, یتل_, _үзән, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [2390] --, --, --, --, 
   {{0x7e7c01c0,0xec14280f,0x00000000,0x00000000}},	//   burp, رواد, --, --, 
   {{0x2f1801c6,0x00000000,0x00000000,0x00000000}},	//   _хонь_, --, --, --, 
   {{0x88f001ec,0x00000000,0x00000000,0x00000000}},	//   кілә, --, --, --, 
   {{0x6e2c0429,0x00000000,0x00000000,0x00000000}},	//   mmab, --, --, --, 
   {{0x6e2c2810,0x63ac03f9,0x7b7404fb,0xb4c8033f}},	//   lmab, _ɗans, _لطفا, ईहै_, 
   {{0x6e2c2811,0x4990065f,0xdec00092,0x00000000}},	//   omab, _لیار, _ትተን_, --, 
   {{0x67200427,0xeb34215c,0xa2bc041c,0x00000000}},	//   _vzlj, _يىڭد, षमस्, --, 
   {{0x601004ce,0x69d82812,0xbb1c0150,0x00000000}},	//   kæmp, mkwe, _ﺷﺎﻕ_, --, 
   {{0xdb0c0793,0x69d82813,0x64a40075,0x00000000}},	//   _vobö, lkwe, _җака, --, 
   {{0xd24c2814,0x7dd82815,0x69d82816,0x601000b5}},	//   ینی_, _sísm, okwe, dæmp, 
   {{0x69d82817,0x7dd80232,0x36d40209,0xbbdc00dc}},	//   nkwe, _písm, _шохр, _यत्क, 
   {{0xa3d41413,0xb5c80214,0xa87800df,0xbb3802dd}},	//   _подч, _تونم_, האָר, _ﻗﺎﻡ_, 
   {{0x53a02818,0x644402b5,0x7dd80162,0x6e2c03ac}},	//   _башб, _ōhiw, _vísm, emab, 
   {{0x44240639,0xdee41639,0x9f4800cf,0x236401a6}},	//   _ihn_, хови, ribà_, malj_, 
   {{0x6e2c2819,0xd24c0597,0x644c067c,0x442401ab}},	//   gmab, _اني_, _çais, _hhn_, 
   {{0x921400c8,0x9c240697,0xdd9402dd,0x716400f7}},	// [23a0] _אַזױ_, едад, маңы, _شايك, 
   {{0x7e7c03a2,0x26e400bd,0x4424017a,0x69d8281a}},	//   purp, _কখনো_, _jhn_, ekwe, 
   {{0x4424281b,0x7e7c0309,0x00000000,0x00000000}},	//   _mhn_, qurp, --, --, 
   {{0x69d8281c,0xceb00bd4,0x442401ab,0x09e0036b}},	//   gkwe, _עיר_, _lhn_, лохн, 
   {{0x2364281d,0x7dd80118,0x00000000,0x00000000}},	//   kalj_, _lísk, --, --, 
   {{0x69d8281e,0x4424017a,0x00000000,0x00000000}},	//   akwe, _nhn_, --, --, 
   {{0x2364281f,0x7dd8032e,0x00000000,0x00000000}},	//   dalj_, _nísk, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x09e02820,0xe000012c,0x195801ec,0xbb381884}},	//   _сотн, ोवाद_, _маңы_, _ﻗﺎﻥ_, 
   {{0x44240175,0xb4580020,0x236401a6,0x00000000}},	//   _chn_, _ያደረጉ, galj_, --, 
   {{0x7a7c02d3,0x442401ab,0x6e2c2821,0xa3b00c4c}},	//   _ብቐጥታ_, _dhn_, ymab, _ऑफर_, 
   {{0x4424016b,0xdb0c01e3,0x562800cf,0x8af80a7c}},	//   _ehn_, _inbä, _эжем_, להיי, 
   {{0x236417a3,0x44242822,0x00000000,0x00000000}},	//   balj_, _fhn_, --, --, 
   {{0x44242823,0x7dd803b2,0x9f4800d8,0x44ac0022}},	//   _ghn_, _físk, tibá_, _ñasẽ_, 
   {{0x644c0240,0x82b02824,0x6d480014,0x00000000}},	//   _çair, _محيط, ِلرِ_, --, 
   {{0x6e2c2825,0x51842826,0x00000000,0x00000000}},	//   umab, _чука, --, --, 
   {{0x7dd82827,0x6e2c2828,0x99880153,0x00000000}},	// [23b0] _získ, rmab, _lubų_, --, 
   {{0x7dd800d2,0xdb0c00a2,0xdec80092,0x00000000}},	//   _lísh, _onbä, _አልኩ_, --, 
   {{0xa0340302,0x69d800d2,0xbb8400c6,0x41c40101}},	//   _שאתה_, tkwe, المي, _شقیق, 
   {{0xdb0c0798,0xfaa40139,0x00000000,0x00000000}},	//   _robô, ышун, --, --, 
   {{0x69d8257d,0x19c00daf,0x394401ec,0xc0e02829}},	//   rkwe, шәрг, уніг, _ነጋሶ_, 
   {{0x69d8282a,0x00000000,0x00000000,0x00000000}},	//   skwe, --, --, --, 
   {{0xd7ec282b,0x23640960,0x69d8282c,0xe5a40075}},	//   تكو_, valj_, pkwe, вийи, 
   {{0xfa78069c,0xc06c00b8,0xfa340736,0x7dd802d2}},	//   _ካልኣይ_, _eṣyā, _مرقد, _rísk, 
   {{0x2364282d,0x7dd801e7,0xdb0c007c,0xc0e00092}},	//   talj_, _dísh, _enbä, _ነፋስ_, 
   {{0x7dd8282e,0xdb0c00d7,0x00000000,0x00000000}},	//   _písk, _tobô, --, --, 
   {{0xf674282f,0x236401a6,0xb4580092,0x92000171}},	//   _مانخ, ralj_, _ያደርጉ, _čārl, 
   {{0xa0682830,0x23640e3c,0x7dd801ef,0x00000000}},	//   мама_, salj_, _vísk, --, 
   {{0x44242831,0x93c82832,0x23640e3c,0x25ac007c}},	//   _thn_, سایہ_, palj_, mdel_, 
   {{0x7dd82833,0x1ea82834,0x25ac0548,0x248c0429}},	//   _tísk, وازي_, ldel_, mtem_, 
   {{0x248c2835,0x6fd800a3,0x7dd801e7,0x00000000}},	//   ltem_, _mìch, _hísi, --, 
   {{0x248c2836,0x6b940139,0x33b00131,0x7dd808a5}},	//   otem_, _abzg, _نەۋر, _kísi, 
   {{0x248c2837,0x8c402838,0xa2a823ef,0x5ba81220}},	// [23c0] ntem_, иете, टिक्, мкам_, 
   {{0x248c2839,0x7dd8283a,0x00000000,0x00000000}},	//   item_, _mísi, --, --, 
   {{0x248c283b,0x7dd800d2,0x6f78008f,0xdee4283c}},	//   htem_, _lísi, _אָרג, _рони, 
   {{0x248c283d,0x25ac0010,0x00000000,0x00000000}},	//   ktem_, jdel_, --, --, 
   {{0x9f48003a,0x7dd8283e,0x248c283f,0x49700150}},	//   ribæ_, _rísh, jtem_, рліс, 
   {{0x248c2840,0x25ac2841,0x48100d30,0x00000000}},	//   dtem_, edel_, аміс, --, 
   {{0x248c16b8,0x7c3c0ba7,0x98b00790,0x8c1400f1}},	//   etem_, _iirr, ıcık_, _شيفر_, 
   {{0x7c3c2842,0x25ac005c,0x2d8c002e,0x248c2843}},	//   _hirr, gdel_, _ñeet_, ftem_, 
   {{0x248c0429,0x7c3c2844,0xf8b001d9,0x73d800fb}},	//   gtem_, _kirr, _دکا_, едпр_, 
   {{0x7c3c2845,0x25ac03bd,0x660c2846,0x19580184}},	//   _jirr, adel_, čaka, _хаҡы_, 
   {{0x248c2847,0x27e80c09,0x7c3c2848,0x25ac0135}},	//   atem_, ɗan_, _mirr, bdel_, 
   {{0xcb1006a9,0x248c011f,0x63800124,0x00000000}},	//   ילת_, btem_, аҳәа, --, 
   {{0x248c2849,0x7c3c284a,0x33940064,0x00000000}},	//   ctem_, _oirr, _балё, --, 
   {{0x7c3c284b,0x00000000,0x00000000,0x00000000}},	//   _nirr, --, --, --, 
   {{0xc2c02266,0xb5fc031c,0xef100137,0x6e4400f2}},	//   _نيوي, _ewġe, сүнө, انرم, 
   {{0x7c3c284c,0xfd7401c0,0x61e40112,0x225000d0}},	//   _airr, илсэ, chkl, ízke_, 
   {{0x7c3c284d,0x22480010,0x00000000,0x00000000}},	// [23d0] _birr, _čaki_, --, --, 
   {{0x7c3c284e,0x3b54284f,0x7c842850,0x00000000}},	//   _cirr, икур, јуте, --, 
   {{0x7c3c2851,0x248c00dd,0xaed40220,0xe9782852}},	//   _dirr, ztem_, _сонш, ебеш_, 
   {{0xe7e413b4,0x248c2853,0xefc80023,0xdb1000e5}},	//   कसभा_, ytem_, _አዝዩ_, ágáv, 
   {{0x7c3c0731,0x6e3c045f,0x6d4c0014,0x67d42854}},	//   _firr, _iisb, mcaa, лоду, 
   {{0x6e3c03f9,0x7c3c1368,0x7dd803b2,0xe7280353}},	//   _hisb, _girr, _rísi, нолд_, 
   {{0x6e3c2855,0x6d4c0548,0xdb4c0014,0x6b840455}},	//   _kisb, ocaa, _ژێے_, mghg, 
   {{0x248c2856,0x26c8098d,0x6d4c2857,0x7c3c01c0}},	//   ttem_, ćao_, ncaa, _zirr, 
   {{0x6e3c0385,0xf9d4010b,0x7c3c0009,0x248c0036}},	//   _misb, _тотэ, _yirr, utem_, 
   {{0x248c2858,0x7dd811c3,0x25ac1347,0x6b840097}},	//   rtem_, _vísi, sdel_, nghg, 
   {{0x44f80165,0x998401a6,0x6e3c02d0,0x66d40592}},	//   _wɪ_, lmoš_, _oisb, _حيائ, 
   {{0x64b41f84,0x6e3c2859,0x248c285a,0xdee400c2}},	//   _محتر, _nisb, ptem_, қоби, 
   {{0x248c0429,0x04640022,0x6d4c058a,0x24f80352}},	//   qtem_, _ртем, dcaa, _янды_, 
   {{0x6d4c285b,0x6e3c285c,0x61e4285d,0x6568285e}},	//   ecaa, _aisb, shkl, laeh, 
   {{0x6e3c285f,0xf3f00597,0xd4040451,0x6d4c2860}},	//   _bisb, _بأن_, _حڪيم_, fcaa, 
   {{0x7c3c2861,0x6e3c0014,0xa0a40022,0x65682862}},	//   _sirr, _cisb, _баид, naeh, 
   {{0x6e3c2863,0x62802864,0x214404fe,0xdb781d0f}},	// [23e0] _disb, lulo, āwhā_, есеш_, 
   {{0x65682865,0x63a02866,0x6e3c1196,0x3d0402e5}},	//   haeh, neln, _eisb, _रखीं_, 
   {{0x62802867,0x656803a0,0x6d4c0067,0x24480208}},	//   nulo, kaeh, bcaa, _lúm_, 
   {{0x6d4c07d5,0x5f442868,0x7c3c2869,0x63a0286a}},	//   ccaa, _جنگل, _wirr, heln, 
   {{0x7c3c003d,0x6280286b,0x2448286c,0x7dd800d2}},	//   _tirr, hulo, _núm_, _sísw, 
   {{0xda64286d,0x63a008ad,0x7c3c286e,0x00000000}},	//   _ماري, jeln, _uirr, --, 
   {{0x63a0286f,0x1ae400c9,0x62802870,0xe7e40d2c}},	//   deln, _совм, julo, _कतरा_, 
   {{0x6e3c0a81,0xc0f002d3,0x63a0000d,0x00000000}},	//   _xisb, ጀርስ_, eeln, --, 
   {{0x6448074d,0x1cb80489,0x80a42871,0x244801fb}},	//   gqei, མའི_, _चैले, _cúm_, 
   {{0x61f42872,0x62802873,0x93a42097,0x70540424}},	//   _amyl, fulo, ушид, ینجا, 
   {{0x62802874,0x21e000c7,0xaed40327,0x6d4c0009}},	//   gulo, _sóha_, ུགབོ, ycaa, 
   {{0x15442875,0x244801e7,0x61f40205,0x6d4c0009}},	//   _седм, _fúm_, _cmyl, xcaa, 
   {{0x6e3c2876,0xc1080276,0x24482877,0x4610009a}},	//   _risb, гэре_, _gúm_, _اونر, 
   {{0x61f4009a,0x6e3c047e,0x41c401ec,0x4730030d}},	//   _emyl, _sisb, _ۇقىق, _енĕс, 
   {{0x6d4c07d5,0x6e3c0280,0x438000f7,0x63b400d0}},	//   tcaa, _pisb, _الىق, ôzne, 
   {{0xefbc0023,0x6d4c058a,0x201800ef,0x2c1c00cd}},	//   ቶንዮ_, ucaa, _ekpi_, _बीजं_, 
   {{0x6d4c2878,0x6e3c2879,0x24480208,0x216400cf}},	// [23f0] rcaa, _visb, _xúm_, _өтөг, 
   {{0x0a68287a,0x6d4c287b,0x6e3c0066,0x2ef4287c}},	//   ерди_, scaa, _wisb, _взор, 
   {{0xdb0c003a,0x6e3c287d,0x61f403cb,0x682c00e4}},	//   _habê, _tisb, _ymyl, lúdg, 
   {{0x63a0287e,0xc33005d0,0x00000000,0x00000000}},	//   zeln, צוף_, --, --, 
   {{0x47700046,0x6280287f,0x2d98198f,0xefc80092}},	//   йқау, zulo, _ibse_, _አምድ_, 
   {{0x24482880,0x65682881,0xb68c02d3,0x7dd802d2}},	//   _rúm_, waeh, _ዘይኮኑ_, _dísu, 
   {{0x65c407d8,0x49b00022,0x656800b0,0x63a01bbf}},	//   ибка, _гәлу, taeh, veln, 
   {{0x62802882,0x660c0fb7,0x32082883,0x656800d8}},	//   vulo, čako, _njay_, uaeh, 
   {{0x63a02884,0xa3b82885,0x2bc82886,0x65682887}},	//   teln, نادر_, रापा, raeh, 
   {{0x62802888,0x66182889,0x23d4288a,0x386000e4}},	//   tulo, _wkwk, рцир, ãire_, 
   {{0xa204288b,0xf77002e9,0x63a0288c,0x6568288d}},	//   ипод, _رال_, reln, paeh, 
   {{0x63a0288e,0x6280288f,0xa3b41414,0x38600311}},	//   seln, rulo, _चोर_, ţire_, 
   {{0x7dd8038e,0x63a02890,0x62802891,0x3d04068f}},	//   _míst, peln, sulo, _रखें_, 
   {{0x7dd80232,0x2d982892,0x0eb000af,0x9f480789}},	//   _líst, _abse_, ुमंड, libú_, 
   {{0x21742893,0x2bc82894,0xb7f8072a,0x9d44010b}},	//   _купр, राना, ्चतम_, иевд, 
   {{0x2d982895,0x290c0077,0x61f402f0,0x7dd802d2}},	//   _cbse_, _oxea_, _umyl, _níst, 
  
   {{0xa0a400ee,0xd12c00db,0x4d44011c,0x00000000}},	// [2400] _тапд, _ۉمۉ_, рпун_, --, 
   {{0x7dd803b2,0xb33c0327,0x00000000,0x00000000}},	//   _rísu, leħa, --, --, 
   {{0x0f780a1e,0x7dd80248,0x596401d5,0x00000000}},	//   _בריל, _sísu, аъла, --, 
   {{0x7dd801e7,0xdb0c0200,0x00000000,0x00000000}},	//   _císt, _habë, --, --, 
   {{0x88c400b8,0xdb0c0200,0x00000000,0x00000000}},	//   _niśī, _kabë, --, --, 
   {{0x7dd805f7,0x7c040451,0x051403d4,0xa3b406b1}},	//   _vísu, _اڀرن, দেৱৰ_, _चोल_, 
   {{0x7dd801e7,0x00000000,0x00000000,0x00000000}},	//   _físt, --, --, --, 
   {{0xdb0c0240,0x4e7800df,0x76580064,0x00000000}},	//   _labë, דאקצ, rpvy, --, 
   {{0x335400cf,0x00000000,0x00000000,0x00000000}},	//   бүлө_, --, --, --, 
   {{0x2bc80b7c,0xd3940d52,0xdb0c0248,0x645c0022}},	//   राया, рәдә_, _àkóy, ãsia, 
   {{0x0bb40302,0x52240108,0x00000000,0x00000000}},	//   בלים_, ифма, --, --, 
   {{0x05802896,0x7dd82897,0xd4982898,0x22500306}},	//   _душм, _míss, _арк_, ízka_, 
   {{0x2bc82899,0x7648289a,0xdb0c0240,0x629c0356}},	//   रामा, _hudy, _babë, ăsoa, 
   {{0x7648289b,0xb7f81ab2,0x439000c0,0x00000000}},	//   _kudy, ्चिम_, _маіс, --, 
   {{0xdb0c025a,0x5f18000d,0x32080076,0x60c0025c}},	//   _wabê, _मुद्_, _tjay_, _ġome, 
   {{0x60c0000a,0x7648289c,0x3208289d,0x2bc809fa}},	//   _šome, _mudy, _ujay_, राभा, 
   {{0x6b741919,0xab740228,0xcb440124,0x3218289e}},	// [2410] йлау, йгаш, ахеи, mosy_, 
   {{0xdb0c034c,0x3218289f,0x764828a0,0x7dd828a1}},	//   _kabè, losy_, _oudy, _síst, 
   {{0xdb0c0100,0x2bc828a2,0x7dd80118,0x4ea41fbe}},	//   _jabè, राबा, _píst, _трпа, 
   {{0x321828a3,0xfe2428a4,0xdf5400f1,0x00000000}},	//   nosy_, _мьян, _پریښ, --, 
   {{0x7dd8022c,0xdb0c1497,0x31680165,0x7648033f}},	//   _víst, _labè, _meaz_, _audy, 
   {{0x7648068f,0x2ca807ab,0x321806d9,0x2d8828a5}},	//   _budy, mwad_, hosy_, lgae_, 
   {{0x2ca80368,0x321828a6,0x76480042,0x7dd81427}},	//   lwad_, kosy_, _cudy, _tíst, 
   {{0x2d8828a7,0xe298020a,0x00000000,0x00000000}},	//   ngae_, қам_, --, --, 
   {{0x321803d1,0x2ca80368,0x9f48004e,0xc7a00014}},	//   dosy_, nwad_, ribú_, _ؤری, 
   {{0xdb0c007f,0xe28428a8,0x88c400cd,0xe79411c5}},	//   _babè, блои, _viśī, _دارک, 
   {{0x216828a9,0x316801c4,0x321828aa,0xe7840116}},	//   лини_, _beaz_, fosy_, _вуҗо, 
   {{0x321828ab,0x2ca80100,0xddcc00e2,0xdb0c0200}},	//   gosy_, kwad_, rsbū, _sabë, 
   {{0x31680165,0x672028ac,0xd5a40133,0xdb0c0200}},	//   _deaz_, _hylj, _دلنی, _pabë, 
   {{0xd9180302,0x764806d1,0x23280131,0x4610006c}},	//   רושל, _yudy, _йоли_, _اوچر, 
   {{0xe29828ad,0xdb0c1f3f,0x321805da,0x76481180}},	//   _сай_, _gabè, bosy_, _xudy, 
   {{0x229028ae,0x672002d2,0xdd9001e7,0x527800df}},	//   mák_, _mylj, ثور_, _ענפא, 
   {{0x2ca8089c,0xdb0c007f,0x00000000,0x00000000}},	// [2420] gwad_, _zabè, --, --, 
   {{0x9f8428af,0xdb0c28b0,0x6720090c,0xfb8428b1}},	//   _угод, _habé, _oylj, تدری, 
   {{0xdb0c28b2,0x3f9828b3,0x229028b4,0x77680076}},	//   _kabé, mfru_, nák_, _redx, 
   {{0x3eb828b5,0x2ca80158,0x3f9801e4,0x00000000}},	//   mvrt_, bwad_, lfru_, --, 
   {{0xd7f828b6,0xdb0c02ea,0x764828b7,0x2ca80014}},	//   лук_, _mabé, _sudy, cwad_, 
   {{0x2bc828b8,0x6720002d,0x229028b9,0xdb0c003e}},	//   राणा, _bylj, kák_, _labé, 
   {{0x229028ba,0x3eb8151c,0x764806be,0xc674007b}},	//   ják_, nvrt_, _qudy, محيط_, 
   {{0x229028bb,0x76480564,0x672428bc,0x67200162}},	//   dák_, _vudy, ühja, _dylj, 
   {{0x05700ed1,0xdb0c068c,0x5344009d,0x4d78010f}},	//   سايد, _sabè, йхна, ארפע, 
   {{0xb27428bd,0x229028be,0x672028bf,0xedc4098a}},	//   олош, fák_, _fylj, _लच्छ, 
   {{0x22900429,0x7648079b,0x321828c0,0x644c00d8}},	//   gák_, _uudy, tosy_, _éain, 
   {{0xd4680cfc,0xdb0c003e,0x924c001f,0x506428c1}},	//   _биде_, _cabé, _አደረጃ, йтга, 
   {{0x321828c2,0xdce40327,0x682c0030,0xdb0c02f0}},	//   rosy_, _dekċ, súde, _dabé, 
   {{0x32181311,0x229028c3,0x9590001f,0xdb0c00f2}},	//   sosy_, bák_, ጃዎችን_, _tabè, 
   {{0x823428c4,0x321806d9,0x5184033a,0x229026f6}},	//   تریا, posy_, _лупа, cák_, 
   {{0x2ca80142,0x00000000,0x00000000,0x00000000}},	//   twad_, --, --, --, 
   {{0x2d880381,0x00000000,0x00000000,0x00000000}},	// [2430] rgae_, --, --, --, 
   {{0x2bc806ff,0x4ae80354,0x6b7402dd,0x2d88003a}},	//   राधा, льем_, ілеу, sgae_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd36415fa,0x6dc00228,0x2d88004e,0xa9840137}},	//   _ښه_, _تۅرۅ, _өйүп_, تۅرۅ_, 
   {{0x672028c5,0x2bc828c6,0x7c8428c7,0x229028c8}},	//   _sylj, रादा, _нуре, zák_, 
   {{0x229028c9,0xfe70036b,0x8bc80276,0xb6b8031c}},	//   yák_, _تدی_, _сымб_, _ཚནྡྷ, 
   {{0xc95801a9,0x00000000,0x00000000,0x00000000}},	//   _бўз_, --, --, --, 
   {{0x229028ca,0xdb0c0109,0xdb2401d5,0x79940107}},	//   vák_, _kabî, _ذوقی, _нисф, 
   {{0xa5080801,0x22900548,0x00000000,0x00000000}},	//   репа_, wák_, --, --, 
   {{0x229028cb,0xdb0c28cc,0x22500122,0xd7d40014}},	//   ták_, _sabé, ízko_, _وصلک, 
   {{0xd5ac0502,0x23280364,0xdb0c28cd,0x65941078}},	//   رفی_, рони_, _pabé, _мажу, 
   {{0x229028c3,0x63ac02a8,0x363400c6,0x1b1400eb}},	//   rák_, _ɗany, _فرنس, থেকে_, 
   {{0x229028cb,0x660828ce,0x20d40006,0x94c800f1}},	//   sák_, mnek, цінс, _ناوې_, 
   {{0xa2e428cf,0x645828d0,0x3eb81050,0x229028d1}},	//   _молд, _itwi, tvrt_, pák_, 
   {{0x660828d2,0xdb0c0098,0x22900548,0x5f1800e1}},	//   onek, _tabé, qák_, _मुश्_, 
   {{0x628001a6,0x3f980327,0x00000000,0x00000000}},	//   mrlo, sfru_, --, --, 
   {{0x660828d3,0x9f340220,0x7dd801e7,0x7bd8005b}},	// [2440] inek, сеңі, _dísp, övuo, 
   {{0x62802595,0xc1740198,0x6608002f,0xd9e028d4}},	//   orlo, _doɗe_, hnek, पस्ट, 
   {{0x660828d5,0x644c00b8,0x00000000,0x00000000}},	//   knek, _ũail, --, --, 
   {{0x660828d6,0x18a402bf,0x645828d7,0x628028d8}},	//   jnek, жадм, _otwi, irlo, 
   {{0x645828d9,0xdce40010,0x7dd800d8,0x62800112}},	//   _ntwi, _kekč, _uísq, hrlo, 
   {{0x660801c0,0x9610107c,0x628001a9,0xe51c0037}},	//   enek, डक्ट_, krlo, _पड़ि_, 
   {{0x645828da,0x66080472,0x8b201173,0x070400ec}},	//   _atwi, fnek, _ждре, يڊمي_, 
   {{0xd49828db,0x66080ac8,0xdef402d3,0xfa240327}},	//   аро_, gnek, _ዎያነ_, _འཚིན_, 
   {{0x628028dc,0xb5480022,0x00000000,0x00000000}},	//   erlo, аҧҵа_, --, --, 
   {{0x4f880023,0x28100116,0x00000000,0x00000000}},	//   ንቀቕታ_, _كۈنس, --, --, 
   {{0x9f5805d5,0x62840212,0x2bdc0764,0xb6c401c6}},	//   _impè_, _åhol, _यवसा, _хөлд, 
   {{0x60c028dd,0xd5a404fb,0x00000000,0x00000000}},	//   _šoma, _گلچی, --, --, 
   {{0x628028de,0x682c00c6,0xa3b428df,0x00000000}},	//   arlo, lúda, _चोक_, --, 
   {{0x09c428e0,0x00000000,0x00000000,0x00000000}},	//   _रच्य, --, --, --, 
   {{0x2bc828e1,0x2ee40008,0x926800d8,0x00000000}},	//   रासा, álf_, _трла_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7dd828e2,0x201801a8,0x82340472,0x00000000}},	// [2450] _vísp, ófið_, _تروا, --, 
   {{0x80a428e3,0x660c0427,0xbc68007b,0xcc140066}},	//   _کمین, čaki, تمكن_, آذرب, 
   {{0x660828e4,0x00000000,0x00000000,0x00000000}},	//   ynek, --, --, --, 
   {{0xdd9013ef,0x2bc818cc,0xd0fc0073,0x00000000}},	//   _كوپ_, राहा, _उधाण_, --, 
   {{0x48a8008e,0x00000000,0x00000000,0x00000000}},	//   ртем_, --, --, --, 
   {{0x6608031c,0xa7a828e5,0x00000000,0x00000000}},	//   wnek, скка_, --, --, 
   {{0x660828e6,0xdb0c0109,0x64580034,0xd90c00f1}},	//   tnek, _jabì, _stwi, نیې_, 
   {{0x2bc82017,0x9f5807c5,0x9730141d,0x00000000}},	//   रावा, _empè_, رکلا, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x660828e7,0xe28428e8,0x682c0030,0x46601b56}},	//   snek, плои, búda, _قۇتق, 
   {{0xdce4007f,0x62800430,0x3940107d,0x4cdc00fe}},	//   _rekč, urlo, žist_, _নেমু, 
   {{0x66080784,0xdce40306,0x628028e9,0x69c000bc}},	//   qnek, _sekč, rrlo, _रोमी, 
   {{0x645828ea,0xe36428eb,0x00000000,0x00000000}},	//   _utwi, _екли, --, --, 
   {{0xdfd0035d,0xe3b028ec,0x00000000,0x00000000}},	//   ريز_, _سرت_, --, --, 
   {{0xb8040055,0x88c00154,0x929000d8,0x00000000}},	//   _anṛś, ্নিক, _зајц, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x0d80009d,0x00000000,0x00000000,0x00000000}},	// [2460] элтн, --, --, --, 
   {{0x88c004c5,0x682c0309,0x0c2028ed,0x00000000}},	//   ্নাক, yúda, емун, --, 
   {{0x34a8102f,0x9f0428ee,0xdb0c002f,0x00000000}},	//   _कन्द, _روحو, _unbü, --, 
   {{0x61e40549,0x00000000,0x00000000,0x00000000}},	//   nkkl, --, --, --, 
   {{0x394028ef,0x2bc828f0,0x48e028f1,0x00000000}},	//   äis_, राशा, ноцв, --, 
   {{0xdb0c28f2,0x682c0077,0xd73001c6,0x00000000}},	//   _habí, túda, ндлө, --, 
   {{0xdb0c00d0,0x2bc817c6,0xf1c0013a,0x690403e3}},	//   _kabí, रारा, íšky_, _ərdə, 
   {{0x682c007b,0xceb00375,0x00000000,0x00000000}},	//   rúda, תיה_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x325428f3,0x61e4017a,0x00000000,0x00000000}},	//   мвор, ekkl, --, --, 
   {{0x27e00112,0xc7b0011a,0xe6c400ae,0x00000000}},	//   öhne_, _רבע_, _يتمي, --, 
   {{0xdb0c02f8,0x741400ec,0xa2c00352,0x00000000}},	//   _nabí, _ڪوتا, тәшк, --, 
   {{0x4fc400a7,0x932400e5,0x7bc801e1,0x00000000}},	//   псва, _کرشن, _òduw, --, 
   {{0x741428f4,0xdfd000f1,0x8538011a,0x00000000}},	//   _توتا, نيټ_, _הגדי, --, 
   {{0xa3b416f0,0xef1000f7,0xdb0c02f0,0xca68155b}},	//   _चोट_, түнө, _babí, мiнi, 
   {{0xdb0c1dec,0x61e411a1,0x645c00ae,0x00000000}},	//   _cabí, ckkl, ísig, --, 
   {{0x4fc4035b,0x2bc828f5,0xb0140640,0x3014014b}},	// [2470] _есна, राला, _омиљ, _одир, 
   {{0x77f8012c,0x645c00df,0x00000000,0x00000000}},	//   ्चोक_, ŭsig, --, --, 
   {{0xdb0c00d8,0x00000000,0x00000000,0x00000000}},	//   _fabí, --, --, --, 
   {{0x6c54004e,0xfcf80092,0x00000000,0x00000000}},	//   _окму, ጋግጡ_, --, --, 
   {{0x2038001f,0xf9900bce,0xa88828f6,0x8cc4030d}},	//   _በህብረ, ابم_, ійка_, _хĕлĕ_, 
   {{0x8d7428f7,0xdb0c0308,0x00000000,0x00000000}},	//   _باھا, _zabí, --, --, 
   {{0xdce400da,0xb8d400af,0x61e4143a,0x00000000}},	//   _iekā, _छै_, ykkl, --, 
   {{0xe45828f8,0x3e5802f0,0x00000000,0x00000000}},	//   ожи_, _učte_, --, --, 
   {{0x69c828f9,0xdce40069,0xc74428fa,0xef18012d}},	//   _inee, _kekā, _فضاي, ęży_, 
   {{0x69c801d4,0xf79428fb,0xa2e428fc,0x00000000}},	//   _hnee, _пауэ, доод, --, 
   {{0x9f58019f,0x682c00d0,0x69c828fd,0x00000000}},	//   _umpé_, lúdo, _knee, --, 
   {{0xa3c828fe,0x00000000,0x00000000,0x00000000}},	//   _लचक_, --, --, --, 
   {{0x250813e1,0x61e40373,0xc0c8004b,0xdb0c28ff}},	//   _برای_, rkkl, سېده_, _rabí, 
   {{0xdb0c2900,0xdce400da,0x660c151c,0x94240228}},	//   _sabí, _nekā, čaku, _قونۇ, 
   {{0x5dd82901,0x02c000db,0x4da80116,0x00000000}},	//   офар_, _чийү, ﺷﻠﯩﻨ, --, 
   {{0x69c82252,0x7f7c005e,0xfcf80092,0xe1080f06}},	//   _nnee, ﺌﻴل_, ጋግጥ_, _мейд_, 
   {{0x205407d6,0x3d281b2c,0x1c442902,0x60e800d4}},	// [2480] _ўтир, ستری_, днам, _ємом_, 
   {{0x69c82903,0x9f482904,0x5f741dd8,0x00000000}},	//   _anee, ribó_, _کاکر, --, 
   {{0x684c02d3,0xdb0c008e,0xdce400de,0x00000000}},	//   _ንሰለስ, _tabí, _dekā, --, 
   {{0x9f48026c,0x00000000,0x00000000,0x00000000}},	//   cibò_, --, --, --, 
   {{0x28a81524,0xdce40171,0xd9ac012d,0x00000000}},	//   चौलि, _fekā, _घसीट, --, 
   {{0x69c82905,0x236401fa,0xc950035b,0x682c00d7}},	//   _enee, jblj_, нтәы, súdn, 
   {{0xdb0c025a,0x7bdc007b,0x3c34007c,0x00000000}},	//   _wabâ, _ioru, rävd_, --, 
   {{0x7bdc2906,0xc8800365,0x69c80076,0xdb2002d1}},	//   _horu, üğü_, _gnee, _ñuñu, 
   {{0x7bdc2907,0xb8f400cd,0x00000000,0x00000000}},	//   _koru, _koṭī, --, --, 
   {{0x7bdc08fb,0xbbdc0210,0x00000000,0x00000000}},	//   _joru, _मकोक, --, --, 
   {{0x7bdc2908,0x00000000,0x00000000,0x00000000}},	//   _moru, --, --, --, 
   {{0x7bdc2909,0x15b00075,0x2d8c00e8,0x550402ac}},	//   _loru, _شەخس, _ñeex_, _очла, 
   {{0xf1f401c0,0xdb0c007f,0xc05801ec,0x7bdc0cad}},	//   _үзлэ, _labà, діс_, _ooru, 
   {{0x7bdc290a,0x00000000,0x00000000,0x00000000}},	//   _noru, --, --, --, 
   {{0x682c000f,0xff040108,0x00000000,0x00000000}},	//   dúdl, вятн, --, --, 
   {{0x7094023b,0xdce400e2,0xf07801b9,0xb81400fe}},	//   _заиф, _sekā, _ейиш_, িতিত_, 
   {{0x7bdc290b,0x682c00d2,0xdd1400f7,0x25a8002e}},	// [2490] _boru, fúdl, ептө, _ñale_, 
   {{0x7bdc290c,0x5f180574,0x0ae800db,0x00000000}},	//   _coru, _मुक्_, يراي_, --, 
   {{0xdb0c2852,0xe5680419,0xb81400fe,0x3f140153}},	//   _cabà, _líšč, িতাত_, _адэс, 
   {{0x7bdc0de4,0xdb0c06ed,0xa8740220,0xc33004ae}},	//   _eoru, _sabã, елді, דוע_, 
   {{0xfcf80023,0x00000000,0x00000000,0x00000000}},	//   ጋግጾ_, --, --, --, 
   {{0xfe700214,0x682c00d7,0x7b440116,0x00000000}},	//   _حدی_, rúdo, رئەل, --, 
   {{0x26c002f8,0x68340209,0x48fc05f9,0x9aa00014}},	//   ího_, _aýdý, _शेरो_, _مۅلو, 
   {{0x69c8290d,0x7bdc0365,0xfcf8044e,0x3c3400e4}},	//   _unee, _zoru, ጋግጽ_, räve_, 
   {{0x7bdc290e,0x543400dd,0xa9680724,0xdec80257}},	//   _yoru, کرٹر, _миңа_, _አውን_, 
   {{0x3834013d,0x62640276,0xd4040014,0x7bdc290f}},	//   _анур, нвоа, ى۪نم_, _xoru, 
   {{0xdb0c1dee,0xa2e42910,0x28b40f44,0x00000000}},	//   _kabá, хонд, _आईडि, --, 
   {{0xbbdc1b51,0xe1f00f0d,0x00000000,0x00000000}},	//   _मक्क, اسد_, --, --, 
   {{0x25ac2911,0x64a42912,0xa43812c4,0xc5082913}},	//   meel_, _чала, _езду_, _بتال_, 
   {{0x25ac2914,0xd24c00b2,0xdb0c2915,0x00000000}},	//   leel_, _ڏنو_, _inbö, --, 
   {{0x5f180c2e,0x7bdc2916,0x248c00d8,0x00000000}},	//   _मुख्_, _roru, luem_, --, 
   {{0x7bdc2917,0x25ac2918,0x9f5801e7,0xdb0c0306}},	//   _soru, neel_, _impí_, _nabá, 
   {{0x7bdc2919,0x248c291a,0x10a0010b,0x6ab401d3}},	// [24a0] _poru, nuem_, _биын, _aszf, 
   {{0x25ac291b,0x7bdc291c,0x1f64160b,0xce4401c6}},	//   heel_, _qoru, _яком, _үзье_, 
   {{0x7bdc291d,0x25ac291e,0xdb0c291f,0xf0002920}},	//   _voru, keel_, _babá, _түри, 
   {{0x7bdc2921,0xd70809a5,0xdb0c01e7,0x25ac2922}},	//   _woru, үнде_, _cabá, jeel_, 
   {{0x25ac2923,0x05d0013a,0x00000000,0x00000000}},	//   deel_, थानब, --, --, 
   {{0xeff0044e,0xdb0c0109,0xd6d81468,0x7bdc03ac}},	//   _ፍቓድ_, _tabà, зти_, _uoru, 
   {{0x25ac2924,0x21e003b2,0xea9409a0,0x39581954}},	//   feel_, _jóhs_, _иштэ, ፈሳውያ, 
   {{0xdb0c0548,0x25ac1bce,0x0f34010f,0x8570011c}},	//   _gabá, geel_, ערקט_, глъх, 
   {{0x248c2925,0xd40416a8,0x9984030a,0x25e000c5}},	//   guem_, еяни, lloů_, _ओकरी_, 
   {{0xdb0c1315,0x0900084c,0xd3782926,0x00000000}},	//   _zabá, _спун, ччи_, --, 
   {{0x25ac1dd0,0x7dd800dd,0x454000d1,0xf4842927}},	//   beel_, _dísz, نچۇق, راکی, 
   {{0x7a3800d2,0x25ac0014,0x248c0798,0xfcf80023}},	//   sítf, ceel_, buem_, ጋግጹ_, 
   {{0x0fe00137,0x854001af,0x644c0055,0x00000000}},	//   гөнү, _йэше, _ũaiv, --, 
   {{0xc32c2928,0x00000000,0x00000000,0x00000000}},	//   _گەپ_, --, --, --, 
   {{0xdb0c01e1,0x00000000,0x00000000,0x00000000}},	//   _àkèy, --, --, --, 
   {{0xc32c1a59,0x5678001f,0x427002e8,0x00000000}},	//   _دەپ_, _አይነቱ_, _сгъс, --, 
   {{0xb034010b,0x00000000,0x00000000,0x00000000}},	// [24b0] _иниш, --, --, --, 
   {{0xdb0c1ada,0x25ac2929,0x4f6800db,0x59c41777}},	//   _sabá, zeel_, _эшим_, _रोबर, 
   {{0x25ac292a,0xfc30007b,0x248c0200,0xfee4022e}},	//   yeel_, صحك_, zuem_, _бўям, 
   {{0x25ac1bce,0x00000000,0x00000000,0x00000000}},	//   xeel_, --, --, --, 
   {{0x25ac292b,0x79800204,0x6d5c011f,0x67d4292c}},	//   veel_, _ddmw, _ifsa, коду, 
   {{0x25ac292d,0x6d5c009a,0x6e2c292e,0x248c0369}},	//   weel_, _hfsa, llab, vuem_, 
   {{0x25ac292f,0x6e2c2930,0xd6cc0137,0xdb0c2931}},	//   teel_, olab, ققو_, _tabá, 
   {{0x6e2c2932,0x2bc81d27,0xa91c00a1,0x248c2933}},	//   nlab, राका, _adže, tuem_, 
   {{0x25ac1574,0x6e2c2934,0x3914022e,0x00000000}},	//   reel_, ilab, _бмтр, --, 
   {{0x6e2c2935,0xeff00023,0x25ac2936,0x248c2937}},	//   hlab, _ፍቓዱ_, seel_, ruem_, 
   {{0x6d5c2938,0x25ac057b,0x248c01b8,0xf7700a11}},	//   _ofsa, peel_, suem_, _داق_, 
   {{0x69d82939,0x25ac208d,0x64c4007b,0xd09806be}},	//   njwe, qeel_, _ليصل, lçəy, 
   {{0x248c293a,0x6568293b,0xdd90293c,0x6e2c293d}},	//   quem_, mbeh, یوس_, dlab, 
   {{0x65680627,0x7a38293e,0x6d5c293f,0x6e2c2940}},	//   lbeh, míte, _afsa, elab, 
   {{0x6e2c2941,0x442405b1,0x7a382942,0x00000000}},	//   flab, _ikn_, líte, --, 
   {{0x6e2c2943,0x65682944,0xa6e80016,0xdca40131}},	//   glab, nbeh, _trươ, каби, 
   {{0x7a382945,0xd12c10fe,0x44242946,0xa3e40490}},	// [24c0] níte, _ومى_, _kkn_, _नवा_, 
   {{0x26c40395,0x6e2c2947,0x6d5c03ee,0x4424009f}},	//   _orlo_, alab, _efsa, _jkn_, 
   {{0x44242948,0x7a380332,0x00000000,0x00000000}},	//   _mkn_, híte, --, --, 
   {{0x6e2c2949,0x6568294a,0x58840962,0x4424294b}},	//   clab, jbeh, выка, _lkn_, 
   {{0x26c401c0,0xadc40075,0x4c800153,0xed34294c}},	//   _arlo_, _саяһ, _кляв, _бэрэ, 
   {{0x656801f1,0x798003ac,0xc7a000d8,0x7a38294d}},	//   ebeh, _wdmw, иичк, díte, 
   {{0xa3d41428,0x65680ea0,0x787801d3,0x33740116}},	//   हान_, fbeh, _búvá, ңгир, 
   {{0x4424294e,0x09e007d8,0xdcf4294f,0x00000000}},	//   _akn_, _косн, leyı, --, 
   {{0x4424207a,0x7a3800dd,0x26c401c4,0x09e02950}},	//   _bkn_, gíte, _erlo_, _тотн, 
   {{0xdcf40205,0x00000000,0x00000000,0x00000000}},	//   neyı, --, --, --, 
   {{0x65682951,0x44240036,0x6e2c2952,0x657c022e}},	//   bbeh, _dkn_, ylab, аshd, 
   {{0x850007d6,0x6e2c0077,0x00000000,0x00000000}},	//   اوین, xlab, --, --, 
   {{0xf0e81c02,0xdb0c01b8,0x44242953,0x66100133}},	//   رىسى_, _habä, _fkn_, _دژوا, 
   {{0x44240077,0x6e2c2954,0x74140150,0x6e9401c4}},	//   _gkn_, wlab, _حوتا, лигу, 
   {{0x6e2c2955,0xdcf40205,0x00000000,0x00000000}},	//   tlab, deyı, --, --, 
   {{0x5184115c,0x6e2c00a3,0x00000000,0x00000000}},	//   _рука, ulab, --, --, 
   {{0x6e2c2956,0x44240a4d,0x31782957,0x201c02b1}},	// [24d0] rlab, _ykn_, masz_, ōtia_, 
   {{0x317800f8,0x6e2c2958,0xa3d41c15,0x442405b1}},	//   lasz_, slab, हाय_, _xkn_, 
   {{0xdb0c025a,0x16202122,0x69d82959,0x7a38295a}},	//   _nabä, मवार_, tjwe, zíte, 
   {{0x60c01ebd,0x3c34295b,0x79a400db,0x3178295c}},	//   _šomi, räva_, ирче, nasz_, 
   {{0xa7a8295d,0xbb2c00d1,0x5ec80154,0x6568047e}},	//   екла_, ﻧﻨﻰ_, রহণে, vbeh, 
   {{0xe738295e,0x76400076,0x656801f5,0xdbd0010b}},	//   нел_, emmy, wbeh, _küýs, 
   {{0x3178295f,0x2d9801f7,0xe5a40131,0x00000000}},	//   kasz_, _kcse_, гийи, --, 
   {{0x26c404b9,0x442406f2,0xdb0c01c7,0x656801a4}},	//   _vrlo_, _skn_, _dabä, ubeh, 
   {{0x65682960,0x31780034,0x7dcc0139,0x74f801c6}},	//   rbeh, dasz_, _mösе, вээс_, 
   {{0x7a382961,0x7640062c,0x00000000,0x00000000}},	//   ríte, ammy, --, --, 
   {{0x7a382962,0xa91c098d,0x26c402e8,0x2d980395}},	//   síte, _udžb, _urlo_, _ocse_, 
   {{0x44242963,0x7a3801ed,0x65680455,0x7e7c01e4}},	//   _wkn_, píte, qbeh, vsrp, 
   {{0x442401a6,0x7a38004e,0xbb6c0131,0xb5c80214}},	//   _tkn_, lítc, _ﺷﯘﯕﺎ_, _جونم_, 
   {{0x66082964,0x25bc2965,0x44240113,0xd24c2966}},	//   liek, _hawl_, _ukn_, _کني_, 
   {{0x64402967,0x53980302,0x9f9400c5,0xdb0c013d}},	//   mmli, _ניקו, müük_, _xabä, 
   {{0x660811f9,0xe1f00502,0x2d98007f,0x21740733}},	//   niek, _دست_, _ccse_, _сукр, 
   {{0xbb5800b5,0xd00c004b,0x25bc015d,0x9f3402dd}},	// [24e0] _ageで_, _ډلي_, _mawl_, теңі, 
   {{0x64402968,0x2d9801ab,0x9f042969,0x6608296a}},	//   nmli, _ecse_, _موخو, hiek, 
   {{0x6608296b,0xdee4296c,0x2008296d,0x2bc8296e}},	//   kiek, _сони, mibi_, राजा, 
   {{0x2008296f,0xceb0008f,0x64402970,0x66080af9}},	//   libi_, _פיר_, hmli, jiek, 
   {{0x7a1c012c,0x2cb8030a,0xdbd000c5,0xdb0c0139}},	//   jčte, _gssd_, _küüs, _sabä, 
   {{0xc8c42971,0x3178012d,0xaaac166d,0x00000000}},	//   اوون_, zasz_, _घनचक, --, 
   {{0x645c09cc,0x66082595,0x25bc2972,0xdbd00037}},	//   ísin, fiek, _bawl_, _müüs, 
   {{0x20082973,0x64400649,0x66082974,0xd9442975}},	//   hibi_, emli, giek, _беби, 
   {{0x20082976,0x779404d3,0x25bc003d,0x2bc82977}},	//   kibi_, _نیشا, _dawl_, राचा, 
   {{0x200823db,0x64400270,0x3178012d,0x33742978}},	//   jibi_, gmli, wasz_, шгор, 
   {{0x66082979,0xa91c05be,0x16640640,0x31781790}},	//   biek, _idža, _свем, tasz_, 
   {{0x6440297a,0x66080034,0xf8b801ad,0xe6840116}},	//   amli, ciek, _इनाय, _тәшк_, 
   {{0x3dc000a9,0x657c0bcd,0x3178297b,0x64400175}},	//   ddiw_, ðshe, rasz_, bmli, 
   {{0x682c297c,0x20080548,0x5338030d,0xa3d4084d}},	//   túdi, gibi_, _пуйă, हाण_, 
   {{0x25bc01ab,0xdbd0000d,0x317801d3,0xbe880108}},	//   _yawl_, _düüs, pasz_, лсте_, 
   {{0xa3d402c3,0x7054297d,0xa2640051,0x682c00d7}},	//   हाथ_, _پندا, _muộ, rúdi, 
   {{0x2008297e,0x1ae000bd,0xa91c0960,0xdbd000af}},	// [24f0] bibi_, _গেলে_, _odža, _füüs, 
   {{0x6608297f,0x682c00d8,0xdbd00432,0xb33c031c}},	//   ziek, púdi, _tüýs, leħq, 
   {{0xa3d42980,0x7ff400f1,0xdb0c0241,0x00000000}},	//   हात_, _دسيا, _àkìy, --, 
   {{0xac942981,0x66080036,0x8c5400f7,0x69d42982}},	//   _камш, xiek, _مئسا, णाधी, 
   {{0xa3e42983,0x9f480295,0x69240b3e,0x64401081}},	//   _नवल_, _ùjòn_, јмла, ymli, 
   {{0x25bc00a9,0x6608068f,0x5ea001d9,0xca742984}},	//   _sawl_, wiek, _دۅہل, _مارغ, 
   {{0x66082985,0xa264004d,0x25bc2986,0x00000000}},	//   tiek, _cuộ, _pawl_, --, 
   {{0x20082987,0x6e3c0165,0x25bc2988,0x7eac005b}},	//   zibi_, _jhsb, _qawl_, _höpö, 
   {{0xfa340722,0x20080296,0xb464030f,0xa7b801ee}},	//   _طرفد, yibi_, یدیه, _илау_, 
   {{0x66082989,0x20081529,0x7a38298a,0x13e4023a}},	//   siek, xibi_, míta, имый_, 
   {{0x2168298b,0x7a3801ed,0x6fb8031c,0x6608298c}},	//   кини_, líta, _བལྟའ, piek, 
   {{0xdbd00254,0x7eac01f4,0x00000000,0x00000000}},	//   _süüs, _löpö, --, --, 
   {{0x2008298d,0x046400a8,0xe7b80490,0xa3d4298e}},	//   tibi_, _стем, _इसाप, हाद_, 
   {{0xdb0c00d2,0x248c298f,0xe3b000f2,0xdd9000ec}},	//   _cabû, mrem_, _ذرت_, ڪور_, 
   {{0x20082990,0x5de42991,0x248c007c,0x92540798}},	//   ribi_, ажва, lrem_, _кајт_, 
   {{0x06ac2992,0x248c0483,0x20082993,0x7a3801d3}},	//   কিপি, orem_, sibi_, kíta, 
   {{0x248c06a3,0xb1640032,0x61f402d0,0x20080098}},	// [2500] nrem_, _уныһ, _ilyl, pibi_, 
   {{0x907804ac,0xdfb804fb,0x248c004e,0x20082994}},	//   _שטיי, _شاخص_, irem_, qibi_, 
   {{0x248c2995,0xdcf4007f,0x00000000,0x00000000}},	//   hrem_, mayč, --, --, 
   {{0x248c0903,0x18682996,0xdd20054e,0xdb0c2997}},	//   krem_, вади_, _cîţi, _kabú, 
   {{0xdb0c00d2,0xd7f821ba,0x6c3001ed,0x7c3c036e}},	//   _jabú, кук_, _کہلا, _thrr, 
   {{0xda642998,0x06ac04c5,0x248c2999,0x7ebc01bf}},	//   _ناري, কিনি, drem_, _gåpå, 
   {{0x248c299a,0x68f406be,0x69c005dc,0x00000000}},	//   erem_, _əzdi, _रोकी, --, 
   {{0x248c299b,0x80b807f7,0xd874299c,0x7a38299d}},	//   frem_, ेटाइ, _نائب, bíta, 
   {{0x248c1028,0x6aa801fa,0x7a3800fd,0x918001fb}},	//   grem_, _ćefi, cíta, _nếu_, 
   {{0x53e4299e,0x61f4010e,0x38a00ba1,0x5344299f}},	//   рциа, _alyl, mòr_, ихна, 
   {{0x248c29a0,0x4b7800c8,0xd5b829a1,0x5f04033f}},	//   arem_, כטיג, _асл_, _हेल्_, 
   {{0x248c29a2,0x20180113,0x5064036b,0x94a829a3}},	//   brem_, _ajpi_, итга, _атка_, 
   {{0xfeb829a4,0x248c29a5,0x38a029a6,0x00000000}},	//   یافت_, crem_, nòr_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x61f429a7,0x628403cd,0x38a000a3,0x3eb8015d}},	//   _flyl, _åhop, hòr_, gwrt_, 
   {{0xb398001f,0x4f940588,0x7eac29a8,0x59c401ad}},	//   _ጉዳዩን_, ырҭу, _söpö, _रोलर, 
   {{0x7eac2776,0x8b6400cf,0xd7c40490,0x320829a9}},	// [2510] _pöpö, لاام, लयाच, _imay_, 
   {{0x6fb429aa,0x7a381a09,0x38a00086,0x0a680e92}},	//   _امدا, víta, dòr_, врди_, 
   {{0x0534044e,0xdb0c00d0,0xba740a11,0x248c00d7}},	//   _ብድሕሪ, _zabú, قانت, zrem_, 
   {{0x06ac000e,0xc9840283,0x91800208,0x248c29ab}},	//   কিমি, ружи, _yếu_, yrem_, 
   {{0x32080429,0x38a00561,0x7c84014b,0x7eb0007f}},	//   _mmay_, gòr_, _муре, pòpò, 
   {{0x645c29ac,0x320801b9,0x7a3829ad,0x248c0205}},	//   ísim, _lmay_, ríta, vrem_, 
   {{0x7a3829ae,0xa3d40a8a,0x2cb429af,0x3208035a}},	//   síta, हास_, şadı_, _omay_, 
   {{0x248c29b0,0xff1806a9,0x76c40131,0x3208022e}},	//   trem_, יקות_, زغىل, _nmay_, 
   {{0x38a0067c,0x248c29b1,0xa3b801f7,0xd1e80b82}},	//   còr_, urem_, هادر_, ቆናት_, 
   {{0x320829b2,0x06ac00cc,0x4cb000fe,0x4dcc00fe}},	//   _amay_, কিবি, ীমপু, ৰসিং, 
   {{0x85b80014,0xefe40092,0x248c29b3,0x00000000}},	//   _لاشس_, _ማሟያ_, srem_, --, 
   {{0x248c29b4,0xa06829b5,0x682c007b,0x00000000}},	//   prem_, лама_, rúdu, --, 
   {{0x10a00121,0x00000000,0x00000000,0x00000000}},	//   пиян, --, --, --, 
   {{0xe29829b6,0x657800b0,0x320814dc,0x6458020c}},	//   _бак_, _hewh, _emay_, _iuwi, 
   {{0x670c02f8,0x22940411,0x657802b5,0x645829b7}},	//   िपटक_, _العس, _kewh, _huwi, 
   {{0x645829b8,0x62800728,0x2fc000a2,0x61f4010e}},	//   _kuwi, mslo, _eahg_, _ulyl, 
   {{0x645802ce,0x5ba829b9,0x146027dd,0x657800b0}},	// [2520] _juwi, лкам_, _kọọp, _mewh, 
   {{0x62800656,0x645829ba,0x181400dc,0xdca40131}},	//   oslo, _muwi, _तदेव_, _һами, 
   {{0x645829bb,0x628029bc,0x320814dc,0xcf540302}},	//   _luwi, nslo, _ymay_, _לבית_, 
   {{0x657829bd,0x5ca41142,0xdca429be,0x628001f5}},	//   _newh, _лимб, _лами, islo, 
   {{0x645802d1,0xdb0c0158,0x00000000,0x00000000}},	//   _nuwi, _labø, --, --, 
   {{0x5bf40050,0xb3ac00cc,0xa2981954,0xacb000d1}},	//   _آسا, _কোনজ, _ጉባኤን_, _تەكب, 
   {{0x46640962,0x38a0067c,0xdb0c0ca8,0x7584072d}},	//   брым_, sòr_, _àkày, قیام, 
   {{0x645829bf,0x62802611,0x38a00ba1,0x8e78010f}},	//   _buwi, dslo, pòr_, אנקה, 
   {{0x64580066,0xf3f804a9,0x7a3801ed,0x628029c0}},	//   _cuwi, иниш_, líto, eslo, 
   {{0x27e40198,0x645829c1,0x628029c2,0x6d400115}},	//   _goln_, _duwi, fslo, _ŝlak, 
   {{0x02a029c3,0x56f001c0,0x7a3801d3,0x00000000}},	//   прям, _хүйс, níto, --, 
   {{0x6458016b,0xd7600244,0x00000000,0x00000000}},	//   _fuwi, _بۆژی, --, --, 
   {{0x64580309,0xfbc800cd,0x00000000,0x00000000}},	//   _guwi, रयाम, --, --, 
   {{0xb4e40490,0xb4d40490,0x1368036b,0x7a3801ed}},	//   नही_, हमी_, _ёшли_, kíto, 
   {{0xa3d40abd,0x320801b9,0x7a3801d3,0x64580112}},	//   हार_, _tmay_, jíto, _zuwi, 
   {{0x320829c4,0x64580098,0x7a3829c5,0x705829c6}},	//   _umay_, _yuwi, díto, _каир_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [2530] --, --, --, --, 
   {{0xf1a429c7,0x9f480165,0x00000000,0x00000000}},	//   ग्रन, ñjãb_, --, --, 
   {{0x4ea400f7,0xd1d800b7,0xb4e429c8,0x7a3800e5}},	//   _урпа, _ፖስት_, नहु_, gíto, 
   {{0x2bf40073,0x645c03b2,0x80a402f2,0x00000000}},	//   _इतकं_, ísik, _بمین, --, 
   {{0x657829c9,0x27e409a8,0x7a380118,0xc98401b9}},	//   _rewh, _poln_, mítl, _қуви, 
   {{0x628029ca,0x60c00086,0xd8840014,0x7a3803b2}},	//   yslo, _âome, تھِن_, lítl, 
   {{0x645829cb,0xe73829cc,0xa91c05be,0x65780374}},	//   _suwi, шек_, _idžm, _pewh, 
   {{0x645829cd,0xb8d400db,0x00000000,0x00000000}},	//   _puwi, تتۅش, --, --, 
   {{0xa3d412eb,0x645803f0,0xf1dc00dc,0x6aa4045a}},	//   हाल_, _quwi, यानन, lthf, 
   {{0x628029ce,0xe284010a,0x00000000,0x00000000}},	//   tslo, олои, --, --, 
   {{0x657829cf,0x6aa429d0,0x00000000,0x00000000}},	//   _tewh, nthf, --, --, 
   {{0x645829d1,0x6aa429d2,0x95e40137,0xe50800ec}},	//   _tuwi, ithf, _ويلۇ, _پيتو_, 
   {{0x316c29d3,0x64580280,0x62800250,0xb5940139}},	//   ñeza_, _uuwi, sslo, _хичш, 
   {{0x628029d4,0x7a3800e5,0x7d0001a8,0x00000000}},	//   pslo, yíto, _ýmsi, --, 
   {{0xe29829d5,0x21a409a5,0xddc40353,0x4f380014}},	//   _тай_, _дийм, обви, لتِھ_, 
   {{0xdee4013e,0x99640356,0x5d680117,0x7a3801d3}},	//   боҳи, _mîţu_, риам_, víto, 
   {{0x10a00046,0x9c6401d5,0x8ff800ec,0x00000000}},	// [2540] _жиын, زهاو, _چرپر_, --, 
   {{0x602400d6,0xb0682824,0x682c0306,0x7a3801d3}},	//   _єдна, _اصيل_, zúdr, títo, 
   {{0x99840244,0x00000000,0x00000000,0x00000000}},	//   قلاو, --, --, --, 
   {{0xa3d429d6,0xf1dc146b,0x7a3801ed,0x75fc00e5}},	//   हाँ_, यायन, ríto, _kéze, 
   {{0x7a3800dd,0xb8f400b8,0x41ac29d7,0x48e000f5}},	//   síto, _maṇī, ट्यस, моцв, 
   {{0x7a3829d8,0x75fc01d3,0x5de002dd,0xdcf400cd}},	//   píto, _méze, _ﺇﻗﻠﻴ, cayā, 
   {{0x75fc01d3,0xf1dc29d9,0xe1c8012d,0x7a3800e5}},	//   _léze, यामन, ियाघ, lítm, 
   {{0x95c8026a,0xc9c4004b,0xf8b8010b,0xdcf4010e}},	//   рука_, _وژنه_, _гөк_, ngyį, 
   {{0xa3d429da,0x75fc00dd,0xb1140154,0xe5e800a2}},	//   हां_, _néze, _সর্ব_, _ýaýç, 
   {{0xaf7002d3,0xf1dc0118,0x00000000,0x00000000}},	//   እታትና_, याभन, --, --, 
   {{0x321805da,0x5fdc0404,0x0bb4011a,0xc80400f1}},	//   tnsy_, मानल, חלים_, _بښنه_, 
   {{0xf4840133,0xb9e40092,0x00000000,0x00000000}},	//   _فاتی, _የአ_, --, --, 
   {{0xf48403b6,0x4fc41d4a,0x201c01a9,0x00000000}},	//   _راشی, осва, еti_, --, 
   {{0x75fc01c7,0xd2580114,0xa3d400cd,0x00000000}},	//   _déze, _кци_, हाः_, --, 
   {{0x15ec00c5,0xfb0000e2,0x7a3803b2,0x00000000}},	//   _जवार_, _šūnu_, títl, --, 
   {{0xc33005e1,0x8d741d37,0xc48029db,0x02f802e4}},	//   _קוק_, تاسا, _эләк, _כלומ, 
   {{0x301429dc,0x75fc01d3,0x76b0015b,0x00000000}},	// [2550] _ндир, _kézb, চটিএ, --, 
   {{0x0f800014,0x91a40950,0xebc4013d,0x00000000}},	//   _زیرُ, ट्रै, чәмн, --, 
   {{0xca300952,0xe5ac00d8,0xdd90004b,0x657c022e}},	//   _ﺯﻭﺭ_, _àaçã, _ګوټ_, аshl, 
   {{0x6aa429dd,0x7a3801ed,0x67fc01e1,0x6fd801f9}},	//   rthf, lítj, _mèje, मावू, 
   {{0x6e2c29de,0xb86401e2,0x00000000,0x00000000}},	//   moab, واوو, --, --, 
   {{0x6e2c0770,0x5fdc0490,0x97c0023a,0x7a3801d3}},	//   loab, मायल, ейше, nítj, 
   {{0x98f40131,0x00000000,0x00000000,0x00000000}},	//   يغۇچ, --, --, --, 
   {{0x6e2c00b5,0x3e3c0092,0x00000000,0x00000000}},	//   noab, _በእነር, --, --, 
   {{0xa5080276,0x7a3801d3,0x00000000,0x00000000}},	//   сепа_, kítj, --, --, 
   {{0xe298283c,0x240801d5,0x9984012d,0x6e2c0051}},	//   бао_, ённи_, cioł_, hoab, 
   {{0x6e2c025a,0x232829df,0x82400023,0xb8f400b8}},	//   koab, сони_, _ባህልታ, _paṇī, 
   {{0xd24c168d,0x6e2c0099,0xe928031c,0x75fc0129}},	//   ێنی_, joab, _སྙོབ_, _péze, 
   {{0x6e2c0311,0x00000000,0x00000000,0x00000000}},	//   doab, --, --, --, 
   {{0x50a00131,0x75fc0129,0x6fd41cb8,0x7a3800e5}},	//   رەپل, _véze, місц, gítj, 
   {{0xdee402bf,0xd00413dc,0xdb0c02d2,0xf8b802c3}},	//   чови, чере_, _babý, _इन्प, 
   {{0x1d080228,0x6e2c017a,0x00000000,0x00000000}},	//   беби_, goab, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [2560] --, --, --, --, 
   {{0x92e0015b,0xa13429e0,0x04a400ef,0x00000000}},	//   _নেয়_, _ورکش, _čīlē_, --, 
   {{0x7a3800dd,0x6e2c016b,0x9cc829e1,0xab68007b}},	//   sítm, boab, шыңа_, تحقق_, 
   {{0x98a40588,0x7a3802fb,0xc8c41b87,0x5f7404f2}},	//   зиде, mítk, लिंट, _باکر, 
   {{0x0d80010b,0x00000000,0x00000000,0x00000000}},	//   _ялян, --, --, --, 
   {{0x26081533,0x7d0429e2,0xdb0c29e3,0x00000000}},	//   ़ोसी_, mzis, _zabý, --, 
   {{0x8c4029e4,0xb4d40882,0xa3d407af,0x3ce0003a}},	//   _чере, हम्_, हाई_, lxiv_, 
   {{0xd4980faa,0xceb0025f,0xd5b80166,0xcb34008f}},	//   бро_, גיה_, сск_, _זאלי_, 
   {{0x7d0429e5,0x38c81060,0xdb0c29e6,0x7a3800e5}},	//   nzis, _بازی_, _labü, yítj, 
   {{0x6e2c056a,0xd32429e7,0x7d000008,0x27e00e78}},	//   zoab, зьми, _ýmsu, öhnt_, 
   {{0x316c056a,0xf194010a,0x7a3829e8,0x00000000}},	//   ñezo_, минь, vítj, --, 
   {{0x7d0429e9,0xbbc829ea,0x7a380122,0xa3d401ad}},	//   kzis, रयुक, dítk, हाउ_, 
   {{0x6e2c05da,0x7d0429eb,0x7a3801d3,0x112801f0}},	//   voab, jzis, títj, сюни_, 
   {{0x7d0429ec,0x1ae003f4,0xdb0c29ed,0xd36c00db}},	//   dzis, _গেছে_, _babü, _حۇد_, 
   {{0x6e2c0175,0xc4380302,0x7a3801d3,0x926829ee}},	//   toab, _התגי, rítj, _урла_, 
   {{0xdb0c29ef,0x7a3801ed,0x7d04014b,0xacf800cf}},	//   _dabü, sítj, fzis, онбу_, 
   {{0x7d0429f0,0x6e2c0072,0x7a3800e5,0x00000000}},	// [2570] gzis, roab, pítj, --, 
   {{0xf044144b,0x6e2c01e0,0x7a3819db,0xdb0c012d}},	//   _تعبی, soab, líth, _nabó, 
   {{0x2d580323,0x7d0429f1,0x7a380118,0x00000000}},	//   _минь_, azis, cítk, --, 
   {{0xcbc4004b,0x7d040311,0x6dc000f7,0x4238010f}},	//   _ډېرو_, bzis, _جۅرۅ, ִנגל_, 
   {{0x31680472,0x00000000,0x00000000,0x00000000}},	//   _mfaz_, --, --, --, 
   {{0xfe7029f2,0x3e5800b0,0x2ca801e6,0x7a380332}},	//   _جدی_, _hōta_, mtad_, híth, 
   {{0x2ca829f3,0xf4040183,0x7a3801d3,0x00000000}},	//   ltad_, ৰকাৰ_, kíth, --, 
   {{0xba7400f2,0x06ac00eb,0x00000000,0x00000000}},	//   _سافت, কিলি, --, --, 
   {{0x2ca829f4,0xf77004d3,0x7a3829f5,0xdb4c0014}},	//   ntad_, _ڕان_, zítk, _مێے_, 
   {{0xdb0c0077,0x00000000,0x00000000,0x00000000}},	//   _gabó, --, --, --, 
   {{0x7d0429f6,0x39640423,0xf67401c6,0xe71805af}},	//   zzis, _åsså_, _згхэ, _بيات_, 
   {{0x2ca829f7,0xa91c00f3,0xe5e404fb,0xdb0c29f8}},	//   ktad_, _adži, _تزئی, _kabò, 
   {{0xdb0c007f,0xb5fc0327,0x3ce00393,0xb33c0003}},	//   _jabò, _suġg, xxiv_, egħd, 
   {{0xdb0c0005,0xffa401c0,0x7a3802f0,0x25ac007c}},	//   _xabó, элгү, títk, lfel_, 
   {{0xdb0c004e,0x2ca807de,0x7d04009a,0x2bd00210}},	//   _labò, etad_, wzis, _सफ़ा, 
   {{0x3ce001d4,0x2ca80267,0xa3d40254,0x75fc0129}},	//   txiv_, ftad_, हाक_, _kéza, 
   {{0x2ca829f9,0xf1a8088c,0x25ac29fa,0x7a38012c}},	// [2580] gtad_, _رايه_, ifel_, sítk, 
   {{0x7d0429fb,0xabc40032,0x25ac007f,0x7a3829fc}},	//   rzis, науҙ, hfel_, míti, 
   {{0x75fc06af,0x2ca8030a,0x25ac01e3,0x7d0401d3}},	//   _léza, atad_, kfel_, szis, 
   {{0x25ac0196,0x2ca803f9,0x61e429fd,0xdb0c29fe}},	//   jfel_, btad_, njkl, _sabó, 
   {{0x7a3829ff,0xdb0c2a00,0x25ac2a01,0xb33c025c}},	//   níti, _cabò, dfel_, mgħe, 
   {{0xdb0c033b,0x25ac0e78,0xb33c025c,0x00000000}},	//   _dabò, efel_, lgħe, --, 
   {{0x25ac2a02,0x7a3800e5,0x00000000,0x00000000}},	//   ffel_, yíth, --, --, 
   {{0xfec00729,0xd90c2a03,0xd94400ee,0x68ec0240}},	//   _উপাধ, _پیت_, _жеби, ëndë, 
   {{0xdb0c067c,0x316801a9,0x7a3801d3,0xf1dc00cd}},	//   _tabó, _rfaz_, víth, यासन, 
   {{0x79802a04,0xa3d42a05,0xefcc02d3,0xa91c0010}},	//   _hemw, हाग_, _ኣሎዎ_, _sežg, 
   {{0x2ca82a06,0x79800810,0xa2840032,0x6b800254}},	//   ztad_, _kemw, нъяһ, _õlge, 
   {{0xdef80201,0x7a380077,0x2bd401ad,0xdbd40037}},	//   _ዋርካ_, fíti, _डोना, _hääb, 
   {{0xc5f00375,0x79802a07,0xdbd40037,0x2ca80175}},	//   _בדף_, _memw, _kääb, xtad_, 
   {{0x79802a08,0xbbc82a09,0x7a3801ed,0xdbd40037}},	//   _lemw, रयोक, síth, _jääb, 
   {{0x79802a0a,0x7f5800d1,0xeff00023,0xb33c025c}},	//   _oemw, дарс_, _ግናይ_, fgħe, 
   {{0x2ca82a0b,0x798005b8,0x7a3800ae,0xc32c0116}},	//   ttad_, _nemw, bíti, _خەپ_, 
   {{0x7a3802fb,0x2ca80165,0x823401c8,0x7dc401d5}},	// [2590] cíti, utad_, _جروا, ъёрд, 
   {{0x2ca82a0c,0xbf640014,0x417401ec,0xa91c2a0d}},	//   rtad_, _لگٲو, _كاۋس, _ježe, 
   {{0x2ca82a0e,0x25ac2a0f,0x798004ba,0xdb0c067c}},	//   stad_, yfel_, _bemw, _sabò, 
   {{0xdb240502,0xa91c2a10,0x00000000,0x00000000}},	//   رونی, _leže, --, --, 
   {{0x6d5c2a11,0x798002e2,0x25ac01e6,0x00000000}},	//   _igsa, _demw, vfel_, --, 
   {{0x61e400f3,0x00000000,0x00000000,0x00000000}},	//   zjkl, --, --, --, 
   {{0x25ac0262,0x49b80502,0x79800083,0x3b540022}},	//   tfel_, _وارد_, _femw, _акрр, 
   {{0xba4405f5,0x64982a12,0x7980015d,0x25ac0112}},	//   _ахуй, птор_, _gemw, ufel_, 
   {{0x25ac2a13,0xa91c0030,0x7a381709,0x6d5c0334}},	//   rfel_, _beže, xíti, _mgsa, 
   {{0xc7442a14,0x79800810,0x69002a15,0x69c801c4}},	//   _قضاي, _zemw, ızdı, _haee, 
   {{0x79801813,0xa91c2a16,0x69c80098,0x25ac03fa}},	//   _yemw, _deže, _kaee, pfel_, 
   {{0x6d5c2a17,0x60002a18,0xddc40055,0xdbd4010e}},	//   _ngsa, _môme, _dikś, _täçb, 
   {{0x69c82a19,0xb33c0327,0x00000000,0x00000000}},	//   _maee, ggħb, --, --, 
   {{0xdfd02a1a,0x6d5c010b,0x94242374,0xd7e00073}},	//   ديس_, _agsa, _كونۇ, पायच, 
   {{0x6e280122,0x9f5807c5,0x247c007f,0x7a3801d3}},	//   čebn, _impü_, lňm_, síti, 
   {{0x69c82a1b,0xdb1001ed,0xa3c40073,0x7a3801d3}},	//   _naee, _ígér, _उघड_, lítv, 
   {{0x1c442a1c,0x79802a1d,0x6b840ac5,0x247c0100}},	// [25a0] енам, _remw, fahg, nňm_, 
   {{0x26c42a1e,0x7980006f,0x75fc01ed,0x41ac27a6}},	//   _oslo_, _semw, _nézn, ट्रस, 
   {{0x8f9800c8,0x7980006f,0xdbd40254,0x3eb00356}},	//   _ציטי, _pemw, _rääb, întă_, 
   {{0x5fdc0316,0x79800477,0x69c80042,0x60000129}},	//   मावल, _qemw, _caee, _dôme, 
   {{0x6b842a1f,0x0d202a20,0x26c42a21,0x69c80363}},	//   bahg, _бүтү, _aslo_, _daee, 
   {{0x79802a22,0x6d5c01a6,0xf778031c,0x00000000}},	//   _wemw, _zgsa, _roħs_, --, 
   {{0x69c80093,0x7bdc2a23,0x8f98008f,0xa91c2230}},	//   _faee, _inru, ליסי, _reže, 
   {{0xd4982a24,0x69c80142,0xa91c2a25,0x247c02e2}},	//   про_, _gaee, _seže, fňm_, 
   {{0x57b002dd,0x8a140677,0x00000000,0x00000000}},	//   _бұлт, _נחמו_, --, --, 
   {{0xba0802d3,0x93a4013e,0x656800d0,0x73d808ca}},	//   _ፋሕ_, хшид, aceh, фдор_, 
   {{0x645c2a26,0xa3d42a27,0x69d401f9,0x00000000}},	//   ísir, हाज_, णाची, --, 
   {{0xa91c00de,0x00000000,0x00000000,0x00000000}},	//   _edžu, --, --, --, 
   {{0x7bdc2a28,0x25a82a29,0xa91c0010,0x6b84020c}},	//   _onru, _آدمي_, _teže, yahg, 
   {{0xa91c2a2a,0x00000000,0x00000000,0x00000000}},	//   _idžt, --, --, --, 
   {{0x6f0800df,0x00000000,0x00000000,0x00000000}},	//   ĝeco, --, --, --, 
   {{0x7bdc2a2b,0x6f0801e4,0xa91c01ef,0x00000000}},	//   _anru, ŝeco, _ježc, --, 
   {{0x69c80165,0xa3d40073,0x6b84047e,0xa91c00de}},	// [25b0] _raee, हाच_, tahg, _mežc, 
   {{0x69c804fb,0x2ef4014b,0x0fe0004e,0xfe7000e5}},	//   _saee, _азор, _сөмү, شدہ_, 
   {{0x69c80156,0x6b842a2c,0xdec000c7,0x247c0100}},	//   _paee, rahg, _кәто, zňm_, 
   {{0x6d5c2a2d,0xfa34009f,0x7ac4035b,0x3d0c012d}},	//   _ugsa, هرند, ысуе, _ठेके_, 
   {{0xfd440153,0x00000000,0x00000000,0x00000000}},	//   _бэрн, --, --, --, 
   {{0xea9400aa,0xe7382a2e,0x69c8003e,0x6b840334}},	//   _لارښ, мел_, _waee, qahg, 
   {{0x69c80618,0xa91c00d0,0x97800214,0x247c007f}},	//   _taee, _bežc, شینه, wňm_, 
   {{0xa91c187e,0x660c01f1,0x75fc0129,0xdb0c01e1}},	//   _vežb, ďako, _dézo, _ìjám, 
   {{0x65682a2f,0xf1a400bc,0xa8540117,0x00000000}},	//   rceh, ग्छन, _акач, --, 
   {{0x7a1c007f,0x39142a30,0x00000000,0x00000000}},	//   včti, _смур, --, --, 
   {{0xf1dc2413,0x74e801c6,0xf770007b,0x7a3800e5}},	//   यांन, ддөг_, _طال_, rítv, 
   {{0xddc40115,0x7a382a31,0x21680108,0x00000000}},	//   _bikŝ, sítv, ьими_, --, 
   {{0x64a42a32,0x7a382a33,0x66e800c0,0x00000000}},	//   _рала, pítv, _dūkš, --, 
   {{0xe2982a34,0xdb1c007c,0x630000db,0x00000000}},	//   _жак_, ldpå, _ەۋگە, --, 
   {{0x8e800276,0x765c06af,0xfbe01c15,0x9e5800d8}},	//   игре, _éryt, नासम, драф_, 
   {{0xe1f00133,0xdb1c007c,0xdd90007b,0xf1d8012d}},	//   _خست_, ndpå, شوط_, _बोपन, 
   {{0xd24c0f13,0x4d602a35,0xb33c0003,0xa008007b}},	// [25c0] _بني_, ркув, mgħa, _يقبل_, 
   {{0xd00c035d,0xb33c003d,0x38c800e5,0x00000000}},	//   _ولي_, lgħa, ہاتی_, --, 
   {{0xdb0c2a36,0x682c0419,0x00000000,0x00000000}},	//   _labö, búdz, --, --, 
   {{0xb33c038f,0x38c807d6,0x60d42a37,0x7a1c00b0}},	//   ngħa, فاتی_, _krym, kōte, 
   {{0xc2140134,0x00000000,0x00000000,0x00000000}},	//   _mmɔ_, --, --, --, 
   {{0x7bdc2a38,0x3dc00036,0x88b007d6,0x7a380413}},	//   _unru, leiw_, شیمچ, vítu, 
   {{0xcac42a39,0x86c02a3a,0x6b80000d,0x47c800f1}},	//   _игре_, ليون, _õlga, بانۍ_, 
   {{0xfbe0012c,0x60d4015d,0x39580023,0xdb1c0254}},	//   नावम, _orym, ገሳውያ, rdpä, 
   {{0xd4042a3b,0xb33c031c,0x16940014,0x00000000}},	//   вяни, dgħa, رٕکھ_, --, 
   {{0x9f5800db,0xc770001f,0x3dc001c7,0xb33c031c}},	//   _alpí_, ከናወኑ_, heiw_, egħa, 
   {{0xdddc0374,0x60d42a3c,0xb33c031c,0x7a3801d3}},	//   _aupō, _arym, fgħa, sítu, 
   {{0x75fc01ed,0x60d42a3d,0xf1dc00bc,0xd4980798}},	//   _kézm, _brym, याइन, _жрк_, 
   {{0x60d4015d,0x99840165,0x7a3801d3,0x00000000}},	//   _crym, lloų_, líts, --, 
   {{0x2cb80109,0x60d42a3e,0xc9500375,0x00000000}},	//   _rpsd_, _drym, ימר_, --, 
   {{0x0d640801,0x60d40393,0xa91c00e2,0x682c002d}},	//   възм, _erym, _meža, túdz, 
   {{0xa91c2a3f,0x60d4044e,0x50640fc0,0x1ee801d3}},	//   _leža, _frym, _итоа, روقی_, 
   {{0xebd82a40,0x32180170,0x60d42a41,0xdb1c020c}},	// [25d0] ндаш_, misy_, _grym, lepè, 
   {{0x32182a42,0xa91c2a43,0x7a3800e5,0x00000000}},	//   lisy_, _neža, kíts, --, 
   {{0x67fc02e2,0x7b642a44,0x60d81a14,0x0ac402e8}},	//   _sèjo, ртуе, ātme, ъщам, 
   {{0xf9902a45,0x32182a46,0x5ef8011a,0xb4f40243}},	//   قبه_, nisy_, _נפרד, ेनाय_, 
   {{0xa91c2a47,0xf8a80133,0x00000000,0x00000000}},	//   _beža, ندوه_, --, --, 
   {{0x68442a48,0x00000000,0x00000000,0x00000000}},	//   ынла, --, --, --, 
   {{0x7a382a49,0x2d880093,0x32180109,0xc984084c}},	//   gíts, oaae_, kisy_, _аузи, 
   {{0x85541547,0xdb1c2a4a,0x28080024,0x00000000}},	//   نیار_, depè, _šunį_, --, 
   {{0x89342a4b,0xe4582a4c,0x88800345,0x00000000}},	//   _شعرا, нжи_, _ئیتن, --, 
   {{0x60d40023,0x7a3802d2,0x00000000,0x00000000}},	//   _rrym, bíts, --, --, 
   {{0x2d880053,0x7a382a4d,0xb33c003d,0x32182a4e}},	//   kaae_, mítr, tgħa, fisy_, 
   {{0x75242a4f,0x60d4012d,0x00000000,0x00000000}},	//   _žize, _prym, --, --, 
   {{0xf3c8036b,0xb33c0135,0x657c0162,0xd654011a}},	//   ربیه_, rgħa, ðshu, _עינת_, 
   {{0xf1dc0316,0x60d405e4,0x23282a50,0xca6801ec}},	//   याउन, _vrym, _поли_, лiмi, 
   {{0x442405b1,0x53980375,0x00000000,0x00000000}},	//   _ijn_, _טיסו, --, --, 
   {{0xdb0c2776,0x60000086,0x60d4040c,0x998402f0}},	//   _mabô, _dôma, _trym, choň_, 
   {{0x248c2a51,0x9c242a52,0x1da8102f,0x3dc00036}},	// [25e0] nsem_, гдад, ङ्गत, reiw_, 
   {{0x248c05d5,0xef180107,0xdb1c036e,0x90c00108}},	//   isem_, хмӣ_, qepë, _убье, 
   {{0x9ea801c0,0xa91c2a53,0x44240051,0xd7e001f9}},	//   _явна_, _reža, _mjn_, पासच, 
   {{0x248c2a54,0x533400c8,0xa91c0219,0x442401a4}},	//   ksem_, אנען_, _seža, _ljn_, 
   {{0x248c012c,0x4424010f,0xca682a55,0xa91c00ef}},	//   jsem_, _ojn_, лiгi, _peža, 
   {{0x442402f0,0xdce40153,0xe10400fe,0x32180205}},	//   _njn_, _sekė, _উশাহ_, zisy_, 
   {{0x248c2a56,0xa91c0153,0xcf90010f,0x00000000}},	//   esem_, _veža, זטו_, --, 
   {{0x442400c8,0xd9540014,0x34940588,0xdb1c0124}},	//   _ajn_, _منزخ, ааир, jepé, 
   {{0xa91c2a57,0x7a382a58,0x32182a59,0x248c01ed}},	//   _teža, síts, visy_, gsem_, 
   {{0x44240356,0x07a0030d,0xc7a00108,0x7a3800e5}},	//   _cjn_, _гафн, _гифк, píts, 
   {{0x32182a5a,0x2d88013f,0x8c3402e4,0xdce40153}},	//   tisy_, yaae_, רטיס_, _tekė, 
   {{0xf0e804a9,0xd7e01fbc,0x44240327,0x600005da}},	//   پىسى_, पावच, _ejn_, _rôma, 
   {{0x44f40814,0x321803d1,0xdb1c0066,0x25d80451}},	//   _مروج_, risy_, sepè, _جهنگ_, 
   {{0x76402a5b,0x32180170,0x4424058a,0xcbbc0eac}},	//   llmy, sisy_, _gjn_, _উচ্ছ, 
   {{0x32182a5c,0xa91c2a5d,0x68f8033f,0xb33c031c}},	//   pisy_, _nežn, zywd, mgħo, 
   {{0x51842a5e,0x44240010,0xb33c0003,0x00000000}},	//   _сука, _zjn_, lgħo, --, 
   {{0xada400d1,0x64b801e4,0xfbe00073,0x00000000}},	// [25f0] лаңл, sʈiv, नांम, --, 
   {{0xddc40598,0xa91c01a2,0x44240208,0x60000051}},	//   _tikş, _bežn, _xjn_, _hômn, 
   {{0x8fd00184,0xe97405e6,0xbc381df2,0x80cc009e}},	//   _кәңә, لهاد, اسقا_, ামণ্, 
   {{0x248c2a5f,0xd3642a60,0xa91c09a8,0xc9840137}},	//   ysem_, _ژه_, _dežn, اشاي, 
   {{0x06ac00fe,0x417c011a,0x00000000,0x00000000}},	//   কিছি, תנדב, --, --, 
   {{0x248c151c,0xa6941614,0x6aa000cc,0xdb1c01ed}},	//   vsem_, ариј, _ålfo, zepé, 
   {{0x7a380174,0x248c012d,0x75fc00e5,0x00000000}},	//   rítr, wsem_, _kézh, --, 
   {{0xf9882a61,0x7a3803b2,0xdde40064,0x9b400244}},	//   _منفي_, sítr, _įpūs, _بۆمو, 
   {{0xdb0c006a,0x74f805f5,0xa5082a62,0xa91c0171}},	//   _wabô, гээс_, тепа_, _iežo, 
   {{0x248c2a63,0x00000000,0x00000000,0x00000000}},	//   rsem_, --, --, --, 
   {{0x248c2a64,0x23282a65,0x7a1c0093,0xdb1c020c}},	//   ssem_, тони_, lōta, tepé, 
   {{0xa0682a66,0x248c00c5,0x75fc01d3,0xf1dc2a67}},	//   кама_, psem_, _nézh, यागन, 
   {{0xa91c00e2,0x44240208,0xdb1c01d3,0xb33c031c}},	//   _mežo, _tjn_, repé, bgħo, 
   {{0x2bd405b7,0x6608038f,0x5f042a68,0x53a0009d}},	//   _डोला, lhek, азга, _дашб, 
   {{0x53980302,0x7a1c02b5,0x00000000,0x00000000}},	//   _סיקו, hōta, --, --, 
   {{0x3e580053,0xa91c2a69,0x7a1c02b5,0x21740166}},	//   _kōti_, _režn, kōta, _тукр, 
   {{0x1b7400db,0x64402a6a,0x5ca40120,0x5ba8001b}},	// [2600] لداج, olli, ризб, ккам_, 
   {{0x64402a6b,0x01e800cc,0x1e8400f0,0x4c800116}},	//   nlli, _পতিদ, _клом, юлув, 
   {{0x66082a6c,0xdee410ae,0x4f98011a,0xa91c00d7}},	//   khek, _тони, _בביצ, _bežo, 
   {{0x60000109,0x66082a6d,0x6b541b04,0x64402a6e}},	//   _kômo, jhek, стух, hlli, 
   {{0x3e5802b5,0x66082a6f,0x64402a70,0x8d600212}},	//   _nōti_, dhek, klli, _євре, 
   {{0x64402a71,0x481002bf,0x7a1c007f,0x660801f4}},	//   jlli, оміс, tčts, ehek, 
   {{0x07a00063,0xec2801ee,0x00000000,0x00000000}},	//   цајн, _серҙ_, --, --, 
   {{0x6440049b,0xd5b82a72,0x75fc01ed,0x00000000}},	//   elli, тск_, _kézi, --, 
   {{0x75fc007f,0x186802bf,0x53e400c7,0x46100014}},	//   _jézi, _рази_, ацна, زوٝر, 
   {{0x6440089c,0x75fc06af,0xa91c0432,0x00000000}},	//   glli, _mézi, _mežl, --, 
   {{0x66082a73,0xa3c4033f,0x95c80417,0x75fc2a74}},	//   bhek, उज़_, _аула_, _lézi, 
   {{0x66082a75,0x64402a76,0x2c7c0248,0xb33c031c}},	//   chek, alli, _jádò_, sgħo, 
   {{0x64401529,0x60000120,0xa91c0118,0x9424004e}},	//   blli, _cômo, _nežl, _кмде, 
   {{0x32740092,0x0314029e,0xb33c0003,0xb6100150}},	//   ለሥልጣ, اتیت_, qgħo, _ﺷﻰ_, 
   {{0x60d80a28,0xcfa82a77,0x00000000,0x00000000}},	//   ātma, _یادم_, --, --, 
   {{0x75fc2a78,0x8d7413d0,0xd1b80150,0x29100213}},	//   _bézi, شارا, _شاعا_, _əzab_, 
   {{0xfd8801d5,0x00000000,0x00000000,0x00000000}},	// [2610] рёси_, --, --, --, 
   {{0x75fc0129,0x66082a79,0x9e7400ec,0x6a140116}},	//   _dézi, zhek, _گهٽت, әмду, 
   {{0x2c7c0241,0xa91c00f3,0x660801f4,0x00000000}},	//   _bádò_, _pežo, yhek, --, 
   {{0x66080007,0x7a1c02b1,0x6e040014,0x6440036e}},	//   xhek, tōta, _چِھن, zlli, 
   {{0x64402a7a,0x66081682,0xd7e00490,0x48a80daf}},	//   ylli, vhek, पांच, ттем_, 
   {{0xa7a80228,0x7a1c00b0,0x66080374,0xe728009d}},	//   укка_, rōta, whek, лолд_, 
   {{0xa91c0e3c,0x3e5802e2,0x644001bf,0x00000000}},	//   _težo, _sōti_, vlli, --, 
   {{0x3e5804fe,0x67fc00e4,0x64402a7b,0x660800b5}},	//   _pōti_, _mèji, wlli, uhek, 
   {{0x66082a7c,0x64402a7d,0xa91c2a7e,0x795807a5}},	//   rhek, tlli, _kežm, _витр_, 
   {{0x64402a7f,0xf7702a80,0xe51c00af,0x00000000}},	//   ulli, _قام_, _बइठि_, --, 
   {{0x6608124c,0x64402a81,0x6e3c005c,0xd76400f2}},	//   phek, rlli, _oksb, _انمی, 
   {{0x64402a82,0x66080184,0x3e5800b0,0x00000000}},	//   slli, qhek, _tōti_, --, 
   {{0x2bfc0073,0x6aa40112,0x36341291,0x0fe00073}},	//   _एवढं_, huhf, _برلس, खांश_, 
   {{0x75fc003e,0x6fac0490,0x644003f0,0xa91c00c0}},	//   _rézi, _जाणू, qlli, _nežm, 
   {{0xf1d802e5,0xd24c0133,0x00000000,0x00000000}},	//   _बोवन, بنێ_, --, --, 
   {{0x200803a2,0x75fc00d8,0x5f042a83,0x00000000}},	//   shbi_, _pézi, азҳа, --, 
   {{0x6aa00158,0x00000000,0x00000000,0x00000000}},	// [2620] _ålfj, --, --, --, 
   {{0x61f42a84,0x6e3c2a85,0x7fa40244,0x00000000}},	//   _hoyl, _eksb, _بلدۆ, --, 
   {{0x20182a86,0x34c41b61,0xa91c0219,0x61f42a87}},	//   _impi_, _वन्द, _dežm, _koyl, 
   {{0x61f4006c,0x9b942a88,0x994800c6,0x186801b9}},	//   _joyl, _گلست, هلال_, гади_, 
   {{0x61f41368,0x00000000,0x00000000,0x00000000}},	//   _moyl, --, --, --, 
   {{0xdb1c29ae,0x61f42a89,0xda640451,0x00000000}},	//   lepí, _loyl, _هاري, --, 
   {{0x66182a8a,0x61f400ad,0xdb0c023a,0x8c1805d0}},	//   _bmwk, _ooyl, äjän, _עולי, 
   {{0xe9702a8b,0x38c8085b,0x00000000,0x00000000}},	//   _قۇمد, _پاری_, --, --, 
   {{0x8cd82a8c,0x2018002e,0x04900023,0xf98801e2}},	//   नियो, _ompi_, _መቐይሮ_, _منځي_, 
   {{0xdbd40139,0x75fc01d3,0x00000000,0x00000000}},	//   _näüb, _nézv, --, --, 
   {{0x61f4129f,0x969400db,0x00000000,0x00000000}},	//   _boyl, _ыраш, --, --, 
   {{0x2018094a,0xd4a400ee,0x00000000,0x00000000}},	//   _ampi_, _гидй, --, --, 
   {{0x61f42a8d,0x33940006,0x6fac1431,0x324401e0}},	//   _doyl, _далё, _जादू, йеүг, 
   {{0x6e3c05b1,0x61f400ad,0x33580276,0x7a1c02b5}},	//   _sksb, _eoyl, _калэ_, kōto, 
   {{0xa3d40316,0x61f40076,0xa3c42a8e,0x00000000}},	//   ाएर_, _foyl, उजर_, --, 
   {{0x201806cc,0xa91c09a8,0x61f4010e,0x00000000}},	//   _empi_, _dežj, _goyl, --, 
   {{0x32080875,0x8d8408ca,0x00000000,0x00000000}},	// [2630] _ilay_, _қунд, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3208017a,0x61f4022e,0xc278010f,0x2b18166d}},	//   _klay_, _yoyl, ָרדי, _येशु_, 
   {{0x80cc00bd,0x00000000,0x00000000,0x00000000}},	//   ামর্, --, --, --, 
   {{0x32082a8f,0xdb0c0139,0x75fc01ed,0x5fdc0073}},	//   _mlay_, _abbä, _jézu, _फोडल, 
   {{0x32082a90,0x00000000,0x00000000,0x00000000}},	//   _llay_, --, --, --, 
   {{0x32082a91,0xf1c800cd,0x00000000,0x00000000}},	//   _olay_, िजान, --, --, 
   {{0xf1d81533,0xa91c2a92,0xd6cc06f6,0x49b82a93}},	//   _बोलन, _ježk, ئقي_, _حاسد_, 
   {{0xdb1c084c,0xc7a812e1,0x24082a94,0xd8a40150}},	//   cepâ, _مدال_, инии_, _ۇشەۋ, 
   {{0x61f42a95,0x32082a96,0xc6a40a5b,0x00000000}},	//   _soyl, _alay_, _грди, --, 
   {{0x0e100882,0x320800db,0x61f4036a,0xca2800d1}},	//   ṣṭav, _blay_, _poyl, ﺧﺸﺎ_, 
   {{0x20182a1f,0x61f4047e,0xa91c0010,0x32082a97}},	//   _smpi_, _qoyl, _nežk, _clay_, 
   {{0xa0682a98,0x61f40363,0xb5c80214,0xf1c8012d}},	//   рага_, _voyl, _دونم_, िज़न, 
   {{0xdee401c0,0xdef8010b,0x32082a99,0x61f4002e}},	//   ооги, ңың_, _elay_, _woyl, 
   {{0x32082a9a,0x8d70001f,0x61f42a9b,0xa91c00d0}},	//   _flay_, _ቤታቸው_, _toyl, _bežk, 
   {{0x7e7c0194,0x32080175,0xdbd00139,0x00000000}},	//   rprp, _glay_, _küçs, --, 
   {{0xdb1c0599,0x769001e1,0x92300137,0xb33c031c}},	// [2640] repí, _kóyá, _تىيش, egħh, 
   {{0x2d9801e4,0xa91c09a8,0x20182a9c,0x320801a9}},	//   _edse_, _težj, _umpi_, _zlay_, 
   {{0x2ca4000f,0x5ac82a9d,0x769001e1,0x32082a9e}},	//   _ālde_, рлем_, _móyá, _ylay_, 
   {{0xa3d4006d,0xa2b000cd,0x00000000,0x00000000}},	//   ाएँ_, _अमन्, --, --, 
   {{0x7a1c0093,0x2bd41d94,0x48702a9f,0x00000000}},	//   sōto, _डोका, ودوس, --, 
   {{0x5c0403e6,0xdb1c00d8,0xb7d800ec,0x5b34009d}},	//   _بکرێ_, repâ, صوبا_, _дэбу, 
   {{0x6fac1533,0x46640eed,0x5fb007c1,0x2b901dd8}},	//   _जासू, орым_, _जानल, _سینس, 
   {{0x3e580093,0x75fc01ed,0x27300372,0xb5fc025c}},	//   _tōtu_, _nézt, رۉنس, _kuġi, 
   {{0xa3d4006d,0x69dc04d4,0x39c0007f,0x5fc80846}},	//   ाएं_, _ósea, _včsč_, ाजाल, 
   {{0x96b80064,0xb33c025c,0x00000000,0x00000000}},	//   _вуду_, lgħi, --, --, 
   {{0x32082aa0,0x3944062c,0x167001d5,0x00000000}},	//   _play_, _hyms_, _ўқир, --, 
   {{0x80ac2aa1,0x225000a2,0xf1e800cc,0xb33c025c}},	//   _जमशे, _chyk_, খস্হ_, ngħi, 
   {{0x769001e1,0xdbd00790,0x3c3401f4,0x00000000}},	//   _fóyá, _güçs, sävy_, --, 
   {{0xb5bc03d4,0x00000000,0x00000000,0x00000000}},	//   _অফিচ, --, --, --, 
   {{0x28d0000b,0x657807ea,0x320806d9,0x43700131}},	//   _दैनि, _éché, _tlay_, _تۇپر, 
   {{0x9f5c0296,0xb5fc0327,0x21340129,0x320802d0}},	//   ótá_, _buġi, éché_, _ulay_, 
   {{0x316800dd,0xb33c031c,0xa9a400ee,0x00000000}},	// [2650] _igaz_, dgħi, җилд, --, 
   {{0x5fb00490,0x24880023,0x6f8000cf,0xdfd00451}},	//   _जायल, _çame_, _سۇرۅ, _ٻيٽ_, 
   {{0xa91c2aa2,0x39441368,0x00000000,0x00000000}},	//   _težk, _ayms_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x88c40e26,0xa0240166,0xd5e00051,0xa91c0064}},	//   تتال, _unöç, _giỏ, _keži, 
   {{0xa91c2aa3,0x2ca82aa4,0xc7b8059f,0x00000000}},	//   _ježi, muad_, рёд_, --, 
   {{0xd7ec2aa5,0xf420015b,0xa91c2aa6,0xb33c0135}},	//   اكى_, নকার_, _meži, bgħi, 
   {{0xe298052f,0x316807ab,0xa91c2aa7,0xe81c29d9}},	//   ҙам_, _ngaz_, _leži, _भगवा_, 
   {{0x753401c6,0x39442aa8,0xe5240212,0xdb1c00d7}},	//   дээх, _gyms_, ядип, mepá, 
   {{0xa91c2aa9,0x24080107,0xe7b4134e,0x00000000}},	//   _neži, снои_, _आउटप, --, 
   {{0xf7702aaa,0x21682097,0x4900012c,0xe2980063}},	//   _شال_, йини_, वनको_, љам_, 
   {{0x06c02aab,0x00000000,0x00000000,0x00000000}},	//   ্মদি, --, --, --, 
   {{0xa91c2aac,0x2ab42aad,0xdb0c0036,0x6384013d}},	//   _beži, håb_, _pcbë, _егла, 
   {{0x600005da,0x25ac2aae,0x3168005a,0x9e642aaf}},	//   _kômi, lgel_, _egaz_, كارن, 
   {{0x25ac0368,0xd378011a,0xdb1c03df,0x00000000}},	//   ogel_, _פרקט, kepá, --, 
   {{0x75fc020c,0xc1040116,0x2ab4005c,0x12f8011a}},	//   _hézr, _жүмл, dåb_, _להצב, 
   {{0x25ac04cc,0x60240276,0x75fc00e5,0x00000000}},	// [2660] igel_, _ндиа, _kézr, --, 
   {{0x394401e3,0x25ac0112,0xabc400fb,0x00000000}},	//   _ryms_, hgel_, мауҙ, --, 
   {{0x39442ab0,0x25ac00a2,0x00000000,0x00000000}},	//   _syms_, kgel_, --, --, 
   {{0x38c8130e,0x25ac00f3,0xdb1c00db,0xa6e000eb}},	//   قاتی_, jgel_, repà, বহাট, 
   {{0x25ac2ab1,0xb0d4012d,0xd7f80166,0x00000000}},	//   dgel_, दिएग, йук_, --, 
   {{0x25ac2ab2,0xe8e800f1,0xb33c025c,0x69dc032e}},	//   egel_, ترمو_, sgħi, _ósen, 
   {{0x60000798,0x995400d4,0x00000000,0x00000000}},	//   _cômi, хiви_, --, --, 
   {{0x25ac2ab3,0x3944039a,0xf9c42ab4,0x95c80116}},	//   ggel_, _tyms_, _تحسی, сука_, 
   {{0x05700873,0x55042081,0x00000000,0x00000000}},	//   رايد, ячка, --, --, 
   {{0xc1b80323,0xd7742ab5,0x25ac00d8,0x00000000}},	//   үлэх_, _رائع, agel_, --, 
   {{0x2d9c033f,0x99840156,0x877800d9,0x00000000}},	//   ówek_, nnoů_, _האבי, --, 
   {{0xb9e4044e,0xa91c0427,0xb0b027c6,0x00000000}},	//   _ከአ_, _seži, _जमदग, --, 
   {{0x4638008f,0x482000db,0xa91c00ef,0x93240633}},	//   _פעדע, _تىەق, _peži, ترکن, 
   {{0x86280020,0x5fb001f9,0x00000000,0x00000000}},	//   _ድህነት, _जाणल, --, --, 
   {{0xa91c2ab6,0x316804cc,0xdb1c2ab7,0xb27401d5}},	//   _veži, _tgaz_, lepæ, _ўлиш, 
   {{0xc2780375,0xdddc0118,0x00000000,0x00000000}},	//   _פרחי, _kupř, --, --, 
   {{0x42381203,0xa91c04b9,0x62940306,0x417400f1}},	// [2670] _מנהל_, _teži, ázov, _ښایس, 
   {{0xaf5000c7,0xfd7401c6,0x92bc00cc,0x00000000}},	//   _аҽгә, _үлээ, ঁটী_, --, 
   {{0x3fd801c6,0xdb1c2ab8,0x25ac007c,0x00000000}},	//   _эмээ_, tepá, ygel_, --, 
   {{0x0dc80a2c,0xf4d8009e,0x2ca80165,0x2ab4005c}},	//   _ابدى_, _তথৈব, puad_, råb_, 
   {{0x89340491,0x6e2c2ab9,0xb33c025c,0xdb1c00e4}},	//   أعضا, mnab, mgħu, repá, 
   {{0xd3642aba,0xb5fc0327,0xfeb80bce,0xb33c031c}},	//   _له_, _muġu, _بایت_, lgħu, 
   {{0x25ac0c86,0xc17402a8,0x69dc04d4,0xd6cc2abb}},	//   tgel_, _haɗe_, _óseo, لقو_, 
   {{0x6e2c2abc,0xc17402a8,0x25ac09b6,0x60000798}},	//   nnab, _kaɗe_, ugel_, _vômi, 
   {{0x69d80134,0x6e2c1351,0x00000000,0x00000000}},	//   mdwe, inab, --, --, 
   {{0x25ac2abd,0x93c00311,0x6e2c0112,0x00000000}},	//   sgel_, _ţăra, hnab, --, 
   {{0x6e2c2abe,0xe51c00c5,0x69d8015d,0x00000000}},	//   knab, _बेरि_, odwe, --, 
   {{0x85b02abf,0x00000000,0x00000000,0x00000000}},	//   _чәкч, --, --, --, 
   {{0x6e2c00a9,0xdd900014,0x00000000,0x00000000}},	//   dnab, ێوس_, --, --, 
   {{0x6284062c,0x6e2c2ac0,0xb33c0327,0x201c007f}},	//   _çhoo, enab, egħu, òti_, 
   {{0x2cc80327,0xb33c031c,0xa91c0171,0x6e2c08a5}},	//   ངསའབ, fgħu, _iežu, fnab, 
   {{0x6e2c2ac1,0xdb1c2ac2,0xa3d42ac3,0x53300798}},	//   gnab, lepç, ाएक_, _шејт, 
   {{0x62800cf9,0x20542ac4,0x69d82ac5,0xad6400ae}},	// [2680] lplo, _отор, ddwe, فاكه, 
   {{0xc17402a8,0xa91c00f3,0x6e2c2ac6,0x26c404e6}},	//   _daɗe_, _ježu, anab, _oplo_, 
   {{0x62800100,0x69d80d27,0xb33c0003,0xa91c0171}},	//   nplo, fdwe, bgħu, _mežu, 
   {{0x98a42ac7,0x69d80d27,0x6e2c1eba,0x9f58036e}},	//   диде, gdwe, cnab, _lopë_, 
   {{0xed340323,0x8d742ac8,0x2fc00ac5,0x00000000}},	//   _зэрэ, _تاپا, _ybhg_, --, 
   {{0x7d0401f0,0x8cd81157,0x628001f5,0xa91c0064}},	//   myis, निरो, kplo, _nežu, 
   {{0x7d042ac9,0x2488031c,0xddc400b8,0xe79401d9}},	//   lyis, _ħama_, _nikū, راوک, 
   {{0xd4980b64,0xceb0025f,0x35b40019,0x7d040472}},	//   оро_, דיה_, хбир, oyis, 
   {{0x7d042aca,0x26c40037,0x62802acb,0xeb140248}},	//   nyis, _eplo_, eplo, _òòré_, 
   {{0x9f580023,0xdb1c072b,0x63c401ef,0x00000000}},	//   _copë_, repæ, _čuní, --, 
   {{0x6e2c2acc,0x0ca8033f,0xb6c40cdd,0x8b040153}},	//   ynab, _चम्म, _чөлд, _tręš, 
   {{0x75d40046,0x20c803f3,0x7d04049b,0xd4680724}},	//   _سيتا, िबंध, kyis, _диде_, 
   {{0xdb1c25c6,0x826403e6,0x62800af9,0x92bc015b}},	//   lepä, کهێن, aplo, ঁটে_, 
   {{0x76402acd,0xdb1c06ed,0xc17403f9,0x7d04006f}},	//   lomy, cepç, _raɗe_, dyis, 
   {{0xb8e00135,0x7d041418,0x15f01b76,0x629401d3}},	//   _ཀཱ_, eyis, _आचार_, ázot, 
   {{0xc3300302,0x76402ace,0x6e2c08cd,0x7d041459}},	//   _שוק_, nomy, unab, fyis, 
   {{0xdb1c000d,0xb33c025c,0x00000000,0x00000000}},	// [2690] hepä, rgħu, --, --, 
   {{0x76402acf,0x6b8401ab,0xdb1c0108,0xaed4014b}},	//   homy, ubhg, kepä, _зоош, 
   {{0x76402ad0,0x7d042ad1,0x62540051,0xe7d81df0}},	//   komy, ayis, báod, _योगप, 
   {{0x7640068f,0x7d042ad2,0xdb1c2ad3,0x69d80ea0}},	//   jomy, byis, depä, udwe, 
   {{0x69d82ad4,0x99942ad5,0x69dc2ad6,0xf1c00882}},	//   rdwe, رپور_, _ósem, ष्यन, 
   {{0xca740075,0x9f580100,0x00000000,0x00000000}},	//   _يازغ, _bopè_, --, --, 
   {{0x76400472,0xdb1c2ad7,0x00000000,0x00000000}},	//   fomy, gepä, --, --, 
   {{0x76402ad8,0xf1c000dc,0x6280007c,0x00000000}},	//   gomy, ष्मन, vplo, --, 
   {{0x48742ad9,0x64c400f1,0x62800076,0x00000000}},	//   _آدرس, ريدل, wplo, --, 
   {{0x62802ad4,0xdb1c0037,0x00000000,0x00000000}},	//   tplo, bepä, --, --, 
   {{0x04ec015b,0xa91c0064,0x764000a2,0x00000000}},	//   টনের_, _vežu, bomy, --, 
   {{0xa0a42ada,0x62802adb,0x76402adc,0x7d040a55}},	//   намд, rplo, comy, yyis, 
   {{0x60640116,0x42cc00eb,0x00000000,0x00000000}},	//   нҗиң_, িমেশ, --, --, 
   {{0x660811c0,0xdb1c05ac,0x7a1c00b0,0x7d04005b}},	//   lkek, lepå, rōti, vyis, 
   {{0x6d5800ee,0xcee42add,0x660803ac,0xa2e401fe}},	//   ýwan, ндре_, okek, _чойд, 
   {{0x64402ade,0x7d042adf,0x66082ae0,0x60000798}},	//   loli, tyis, nkek, _rômu, 
   {{0x64402ae1,0x7d040099,0xa91c00e2,0x2240007c}},	// [26a0] ooli, uyis, _mežs, mokk_, 
   {{0x22402ae2,0x9f842ae3,0x7d042ae4,0x60d42ae5}},	//   lokk_, _ягод, ryis, _isym, 
   {{0x7640014b,0x6440004e,0x7d042ae6,0xcfb4011a}},	//   yomy, ioli, syis, _אליי_, 
   {{0x7d040230,0x9f5800e8,0xddc400c7,0xdb1c00c5}},	//   pyis, _nopé_, _oikũ, vepä, 
   {{0x64402ae7,0x76400223,0x6c74035b,0x8f50036b}},	//   koli, vomy, _аусх, _لنیش, 
   {{0x64402ae8,0x66082ae9,0x764004ba,0xf8c0000d}},	//   joli, ekek, womy, _एहीप, 
   {{0x64402aea,0xddc400e4,0x3ce00099,0x76402aeb}},	//   doli, _aikũ, lviv_, tomy, 
   {{0xdb1c00af,0x9f58004a,0x6440003a,0xcb640006}},	//   repä, _copé_, eoli, _часе_, 
   {{0xdddc00da,0xf8d41715,0xdb1c1073,0x9f580129}},	//   _atpū, _धनिय, sepä, _dopé_, 
   {{0x64402aec,0x76402aed,0xa91c0153,0x660801f4}},	//   goli, somy, _vežt, akek, 
   {{0x03c00046,0x325401f0,0xc794211f,0xb33c0327}},	//   усым, квор, _سپنا_, egħr, 
   {{0x66082aee,0xf26c001f,0x68440022,0xa2b00b02}},	//   ckek, _አደገኛ_, _знӡа, _अमर्, 
   {{0x629402fb,0x00000000,0x00000000,0x00000000}},	//   ázor, --, --, --, 
   {{0x20d42aef,0x31780354,0xefb001d3,0xdec80023}},	//   džić_, scsz_, جیدگ, ሽጥን_, 
   {{0x2240031c,0x00000000,0x00000000,0x00000000}},	//   bokk_, --, --, --, 
   {{0xb11400aa,0x931001ed,0xa91c0171,0x00000000}},	//   _لوبغ, _لوڈش, _mežr, --, 
   {{0x313400d1,0xebd8010b,0x30140006,0x0ba42af0}},	// [26b0] _шеир, мдаш_, _адпр, ешем, 
   {{0x6608005a,0x09b800cd,0x00000000,0x00000000}},	//   zkek, ोज्य, --, --, 
   {{0xc1740c09,0xe9d80034,0xcf24143e,0x69dc1427}},	//   _haɗa_, _paź_, _سردي, _ósek, 
   {{0x64402af1,0xc1740b45,0xe80804aa,0x7a1c02b5}},	//   zoli, _kaɗa_, वस्थ_, kōtu, 
   {{0xfbb81d4c,0x2d882af2,0x64402af3,0x79840309}},	//   ীয়ত, mbae_, yoli, ñiwa, 
   {{0x2ca82af4,0x78a42af5,0x64402af6,0x2d880393}},	//   mrad_, áiva, xoli, lbae_, 
   {{0x66082af7,0x7c342af8,0x2ca80112,0x00000000}},	//   tkek, _серх, lrad_, --, 
   {{0x64402af9,0x78a40989,0x2ca814d0,0x2d8801f9}},	//   woli, šiva, orad_, nbae_, 
   {{0x2ca82afa,0x64402afb,0xc1740b45,0xdb1c0fac}},	//   nrad_, toli, _naɗa_, repå, 
   {{0x2ca82afc,0x64400142,0xa2e42afd,0x6fac01f9}},	//   irad_, uoli, воод, _जागू, 
   {{0x2ca80122,0x22402afe,0x00000000,0x00000000}},	//   hrad_, tokk_, --, --, 
   {{0xe5e404fb,0x2ca82aff,0x64402b00,0xe8080118}},	//   _جزئی, krad_, soli, वसका_, 
   {{0x22402b01,0x65c00220,0xc0c800f1,0x00000000}},	//   rokk_, _бұқа, رېده_, --, 
   {{0xc17402a8,0x64402b02,0x2ca82b03,0x2d88003a}},	//   _daɗa_, qoli, drad_, ebae_, 
   {{0x53980375,0x2ca82b04,0x00000000,0x00000000}},	//   _חיצו, erad_, --, --, 
   {{0xc1740b45,0x60d405da,0xfb540131,0x2ca8002f}},	//   _faɗa_, _tsym, ۇراھ, frad_, 
   {{0x2ca82220,0xdc680323,0xdc282073,0x3d28158b}},	// [26c0] grad_, даад_, وسطه_, رتری_, 
   {{0x3ce02b05,0x20d401a6,0x38bc00e4,0x2c6c013a}},	//   rviv_, ržić_, hárã_, _sždc_, 
   {{0x3f982b06,0x2ca82b07,0xdcb00131,0x00000000}},	//   maru_, arad_, _ھىس_, --, 
   {{0x3f982b08,0x3c942b09,0x2ca82b0a,0xc1740b45}},	//   laru_, _میرز, brad_, _yaɗa_, 
   {{0xd7f80276,0x2ca80100,0xa91c013a,0xd838013d}},	//   дуй_, crad_, _sežr, мэк_, 
   {{0x3f982b0b,0x1cc00135,0x8ca401ad,0x00000000}},	//   naru_, _གྱར_, _चितो, --, 
   {{0x69640075,0x7bdc2b0c,0xc95000c7,0x10680150}},	//   ندۇق, _iaru, лтәы, _ﺳﻮﺯﯨ, 
   {{0x7bdc2b0d,0x3f982b0e,0x75b801d5,0x1dc000bc}},	//   _haru, haru_, хлиё_, शभित, 
   {{0x3f982b0f,0x7bdc2b10,0xb8f400b8,0x04b401d3}},	//   karu_, _karu, _kaṭī, نھوں_, 
   {{0x3a240280,0x3f982b11,0x2d880369,0x2c6c00d0}},	//   _hmmp_, jaru_, zbae_, _kľdr_, 
   {{0x7bdc2b12,0x3f982b13,0x81dc09bd,0x04400120}},	//   _maru, daru_, ঠান_, реќн, 
   {{0x7bdc2b14,0x7a1c00b0,0x2ca82b15,0x46a40118}},	//   _laru, pōtu, yrad_, _गितह, 
   {{0x3f982b16,0x9f440208,0x10681870,0x00000000}},	//   faru_, _đoá_, _ﺳﻮﺭﯨ, --, 
   {{0x2ca805c7,0xc950011a,0xae0415bf,0x7b14022e}},	//   vrad_, שמש_, گورى, 智ull, 
   {{0x92f02b17,0x386c0175,0xcdd80114,0x7f940108}},	//   _түнх, _midr_, мња_, расх, 
   {{0x2ca82b18,0x7bdc2b19,0xc0d00023,0x00000000}},	//   trad_, _aaru, ብሶም_, --, 
   {{0x3f982b1a,0xcfa41638,0x2d8816b8,0xcfd82b1b}},	// [26d0] baru_, _ишни, rbae_, দাবন, 
   {{0x7bdc2b1c,0x3f982b1d,0x2ca82b1e,0x8b6400db}},	//   _caru, caru_, rrad_, ناام, 
   {{0xba742b1f,0x3a74035b,0x00000000,0x00000000}},	//   لانت, алхр, --, --, 
   {{0xc330025f,0x7bdc1730,0xa6842b20,0x2ca82b21}},	//   בוע_, _earu, қлид, prad_, 
   {{0x7bdc2b22,0x60000109,0x24580129,0x2ca806be}},	//   _faru, _kômp, lème_, qrad_, 
   {{0x7bdc2b23,0xfe7000aa,0xdddc2b24,0x00000000}},	//   _garu, _ددی_, _kupş, --, 
   {{0x8cd8089a,0x600005da,0xa44400d1,0x5690033a}},	//   निको, _mômp, һнид, бајт, 
   {{0x7bdc2b25,0x2458004a,0x00000000,0x00000000}},	//   _zaru, ième_, --, --, 
   {{0x3f982b26,0x29182b27,0x245806af,0x6b9401a9}},	//   yaru_, _åsa_, hème_, _kezg, 
   {{0x7bdc0a81,0x6b940989,0x87d417b9,0x3f980054}},	//   _xaru, _jezg, _جغرا, xaru_, 
   {{0x3f982b28,0xa228188b,0x6b942b29,0x33f42b2a}},	//   varu_, ежна_, _mezg, рчыс, 
   {{0x3f982b2b,0x6b940165,0x245806af,0x990001e4}},	//   waru_, _lezg, dème_, ŝĉen, 
   {{0x3f982b2c,0x00000000,0x00000000,0x00000000}},	//   taru_, --, --, --, 
   {{0x2a6c1a80,0xe0442b2d,0xe2982b2e,0x2fd00139}},	//   _lieb_, унги, _зак_, gezg_, 
   {{0x3f982b2f,0x7bdc2b30,0x31c8015b,0x24580129}},	//   raru_, _raru, ষয়শ, gème_, 
   {{0x3f982b31,0x55000248,0x00000000,0x00000000}},	//   saru_, _ìṣèl, --, --, 
   {{0x3f982b32,0x6b942b33,0x1be80364,0xb8f40055}},	// [26e0] paru_, _bezg, ндаи_, _maṣī, 
   {{0x3f982b34,0x4d601d11,0xd0f40375,0x6cc401e0}},	//   qaru_, скув, _עמית_, рифҡ, 
   {{0x7bdc2b35,0x2a6c0003,0x6b940311,0xf1c001bc}},	//   _varu, _bieb_, _dezg, ष्वन, 
   {{0x7bdc2b36,0x386c2b37,0x6b9402d0,0x00000000}},	//   _waru, _sidr_, _eezg, --, 
   {{0x2a6c2b38,0x98480b2c,0x00000000,0x00000000}},	//   _dieb_, няка_, --, --, 
   {{0xd6d82b39,0x6b942b3a,0x78a40e3c,0x7bdc2b3b}},	//   ети_, _gezg, šivo, _uaru, 
   {{0x5fb0069f,0xfd5001fb,0x00000000,0x00000000}},	//   _जाईल, _nghẹ, --, --, 
   {{0xa5bc0006,0x1cc0031c,0xdb1c005c,0x00000000}},	//   liųj, _གྱོ_, depø, --, 
   {{0x1cd0031c,0x75fc01d3,0x991402d5,0xe8480137}},	//   _ེགས_, _kézz, _сьві, رجۇن_, 
   {{0x7a1c01af,0x63ac0c09,0xa5bc0024,0xb4e4012c}},	//   pōts, _ɓang, niųj, _पछी_, 
   {{0x2a6c0369,0x245806af,0x8c180375,0xdb1c005c}},	//   _yieb_, xème_, גויי, gepø, 
   {{0x54e42b3c,0xa2d42b3d,0x00000000,0x00000000}},	//   _مستق, _बनर्, --, --, 
   {{0x93e4036b,0x934401ec,0x0fe000db,0x73c4190b}},	//   _бўйл, _өнде, бөнү, _кәне, 
   {{0xc1740198,0x75fc01ed,0x1cc00327,0x94700014}},	//   _faɗo_, _nézz, _གྱེ_, _پۯگا, 
   {{0x6e942b3e,0xdbd00112,0xdddc0166,0x6b942b3f}},	//   рибу, _süßs, _qupş, _rezg, 
   {{0x6b942b40,0x2458004a,0xf1a800bc,0xdfd80107}},	//   _sezg, rème_, _कयिन, нъӣ_, 
   {{0x8234085d,0x2458026c,0x2a6c002f,0x00000000}},	// [26f0] _دروا, sème_, _rieb_, --, 
   {{0xbd682b41,0x798003ac,0x2a6c0112,0xa5bc0064}},	//   урсе_, _afmw, _sieb_, giųj, 
   {{0x7c842b42,0x4f68013d,0x18780023,0xf1a80210}},	//   _ҳусе, _яшим_, _ብሃገር_, _कयान, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6b942b43,0xa9340c9e,0x7c842b44,0xa5bc00c0}},	//   _tezg, шедш, _гусе, biųj, 
   {{0xec240131,0x6b9402d0,0x2c6c00c0,0xbb300092}},	//   _ئىسپ, _uezg, _iždo_, ጥቷቸዋ, 
   {{0xe5700597,0xc98407d6,0x81dc0183,0xbb58030d}},	//   يطة_, _бузи, ঠাত_, _барх_, 
   {{0x1b1c015b,0x0ba80137,0xaa582b45,0x8c34014b}},	//   _বুকে_, _تاڭى_, _рибу_, _роҳӣ_, 
   {{0x69c80cad,0x88800214,0x00000000,0x00000000}},	//   _ibee, _ایتن, --, --, 
   {{0x68e82b46,0x291c01c8,0x135402d3,0x00000000}},	//   _ired, mzwa_, _ግሉጽነ, --, 
   {{0x68e80156,0x291c009f,0x3914247f,0xa5d40798}},	//   _hred, lzwa_, _پوەز, _вжеш, 
   {{0x37041955,0x973000f2,0x00000000,0x00000000}},	//   _учув, _بکها, --, --, 
   {{0x291c2b47,0x69c82b48,0xa5080063,0x00000000}},	//   nzwa_, _mbee, _јела_, --, 
   {{0x68e80066,0xa34801a9,0x00000000,0x00000000}},	//   _mred, _изла_, --, --, 
   {{0x9e640058,0x92f42b49,0x69c82b4a,0x1d9401b9}},	//   لارن, _نفوذ_, _obee, ираё, 
   {{0x44242b4b,0x68e82b4c,0x1cc0031c,0xdca4023a}},	//   _hmn_, _ored, _གྱུ_, иаби, 
   {{0x9c242b4d,0x75fc04cc,0x68e801e1,0x00000000}},	// [2700] адад, _pézz, _nred, --, 
   {{0x291c2b4e,0x69c82b4f,0x9f580589,0x51580375}},	//   dzwa_, _abee, _copã_, _בכפו, 
   {{0xf778003d,0x69c81418,0x68e82b50,0x44242b51}},	//   _naħa_, _bbee, _ared, _mmn_, 
   {{0x69c82b52,0xa5bc0006,0x44242b53,0xdd9000ec}},	//   _cbee, siųj, _lmn_, _ڏوھ_, 
   {{0x80c409bd,0x69c80036,0x7e642b54,0x44242b55}},	//   শিক্, _dbee, mmip, _omn_, 
   {{0x68e803b4,0x44242b56,0x69c80a49,0x99842b57}},	//   _dred, _nmn_, _ebee, dnoť_, 
   {{0x68e82b58,0xd6d80432,0x3e7c012c,0x8f98008f}},	//   _ered, ттл_, _jít_, דיצי, 
   {{0x69c82b59,0x3e7c0316,0x442405da,0x35f42b5a}},	//   _gbee, _mít_, _amn_, спир, 
   {{0x3e7c2b5b,0x93882773,0x998405c7,0xc47401b9}},	//   _lít_, ксна_, lioů_, لینچ_, 
   {{0x5fb0069f,0x44242b5c,0xb804002b,0xe8e805af}},	//   _जागल, _cmn_, _daṃś, _حرفو_, 
   {{0x68e82b5d,0x44242b5e,0x3e7c2b5f,0x9984030a}},	//   _zred, _dmn_, _nít_, nioů_, 
   {{0x741403e6,0x00000000,0x00000000,0x00000000}},	//   _گوتا, --, --, --, 
   {{0x44242b60,0x99840165,0x7e6401ef,0x00000000}},	//   _fmn_, hioů_, dmip, --, 
   {{0x44240073,0x74140b43,0x33840014,0x3e7c001e}},	//   _gmn_, _دوتا, _الغٲ, _bít_, 
   {{0xb4b40032,0x02a02b61,0x2488031c,0x34940139}},	//   _тиҙә, _дрым, _ħami_, _таһр, 
   {{0x51840598,0xef180034,0x99840165,0xad242b62}},	//   _тука, ąż_, dioů_, مىزى, 
   {{0x2458067c,0x82640214,0xbd7800d4,0x00000000}},	// [2710] lèma_, _بهين, рбує_, --, 
   {{0x46a40307,0x7e64000d,0xf4b400cc,0x00000000}},	//   _गिलह, amip, _জৈৱব, --, 
   {{0x7e6400f2,0x2458180f,0xdeb001ec,0x00000000}},	//   bmip, nèma_, _нұры, --, 
   {{0x68e82b63,0x7e640066,0x684400d1,0xcc840133}},	//   _pred, cmip, әнка, _نۆره_, 
   {{0xb9c40597,0x2d982b64,0x291c01c8,0x68e8031c}},	//   تقني, _iese_, uzwa_, _qred, 
   {{0x1cc02b65,0x6e2c2b66,0x68e82b67,0x2d982b68}},	//   _གྱི_, liab, _vred, _hese_, 
   {{0x2d982b69,0x44242b6a,0xb8040882,0x3e7c004d}},	//   _kese_, _rmn_, _saṃś, _xít_, 
   {{0x68e82b6b,0x2d982b6c,0xdb1400c6,0x69c80117}},	//   _tred, _jese_, _ócái, _ubee, 
   {{0x2d982b6d,0x46d4012c,0x00000000,0x00000000}},	//   _mese_, _भैरह, --, --, 
   {{0x6e2c2b6e,0x2d982b6f,0xdb1c0022,0xddc40064}},	//   hiab, _lese_, hepý, _mikš, 
   {{0x7e640309,0xddc400de,0x360400e5,0x00000000}},	//   ymip, _likš, _ڈولف, --, 
   {{0x2d982b70,0x3e7c004d,0x36041291,0x00000000}},	//   _nese_, _rít_, _وولف, --, 
   {{0x44242b71,0xddc408ad,0xd6540375,0x998405c7}},	//   _tmn_, _nikš, _פינת_, zioů_, 
   {{0x2d982b72,0x3e7c2b73,0x3ec80c60,0x00000000}},	//   _aese_, _pít_, ақом_, --, 
   {{0x2d982b74,0xddc402d5,0x53980375,0x6e2c2b75}},	//   _bese_, _aikš, _עסקא, fiab, 
   {{0x2d982b76,0x6e2c2b77,0x3e7c2b78,0x1b1c015b}},	//   _cese_, giab, _vít_, _বুঝে_, 
   {{0x2d982b79,0x7e642b7a,0x5ca400cf,0xdbc801c6}},	// [2720] _dese_, rmip, сизб, лгад_, 
   {{0x2d982b7b,0x78a402fb,0x3e7c2b7c,0x7e64000d}},	//   _eese_, šivk, _tít_, smip, 
   {{0x6e2c2b7d,0xd24c2b7e,0x2d982b7f,0x00000000}},	//   biab, _زنی_, _fese_, --, 
   {{0x2d980660,0x4f840014,0x99840156,0x6e8000e4}},	//   _gese_, _پایہ, rioů_, _ẽngú, 
   {{0xdb1c00dd,0x91b80375,0x2ba4078a,0xed340de7}},	//   lepü, רמני, गृहा, _дэрэ, 
   {{0x818c01ec,0xaab800db,0x00000000,0x00000000}},	//   _ﺒﻘﻴﺔ_, ادەر_, --, --, 
   {{0x2d982b80,0x07a00f14,0x8b200353,0x00000000}},	//   _yese_, чајн, _едре, --, 
   {{0xd5b82b81,0xc6d02002,0xda780032,0x00000000}},	//   уск_, ستىت, _аяҡ_, --, 
   {{0xb78801af,0x00000000,0x00000000,0x00000000}},	//   _кәйе_, --, --, --, 
   {{0x6e2c2b82,0xdb24031c,0x2874010b,0x07a00124}},	//   ziab, _རྟོཌ_, _фытр, _наун, 
   {{0x95c82b83,0x4bf80bd9,0x75a40022,0x33580276}},	//   _була_, אליס, _дылҧ, ранэ_, 
   {{0xdb1c2b84,0x6e2c0077,0x24580ba1,0x00000000}},	//   lepó, xiab, rèma_, --, 
   {{0x2d982b85,0xc0f4001f,0xfbd807f7,0x80b0012d}},	//   _rese_, _ሌተር_, ड़ाम, अंगे, 
   {{0x2d982b86,0xddc40171,0x00000000,0x00000000}},	//   _sese_, _rikš, --, --, 
   {{0x2d982b87,0x87780bd4,0xdb1c0124,0xddc400ef}},	//   _pese_, ראלי, tepý, _sikš, 
   {{0x1cc02b88,0x31340220,0x3eac0efe,0x2d980240}},	//   _གྱང_, _мейр, ádta_, _qese_, 
   {{0x2d982b89,0x6e2c2b8a,0x62840363,0x645c0024}},	// [2730] _vese_, riab, _çhor, įsiv, 
   {{0x2d982b8b,0x6e2c0441,0xfbd004fb,0xaed401c0}},	//   _wese_, siab, فتم_, _доош, 
   {{0x2d982b8c,0x6d40033f,0x6e2c003a,0xe3bc00fe}},	//   _tese_, _ślad, piab, _অসমব, 
   {{0x75200354,0x2d980421,0xddc4005f,0x00000000}},	//   kzmz, _uese_, _tikš, --, 
   {{0x6e3c01a4,0xebc42b8d,0x7d242b8e,0x00000000}},	//   _ijsb, _мәжн, _ефре, --, 
   {{0x6d5c005f,0xac18001b,0x765c0055,0x00000000}},	//   _izsa, _тогу_, _īrya, --, 
   {{0x39c00618,0x7b54007b,0x00000000,0x00000000}},	//   _sōsō_, _فضفض, --, --, 
   {{0xa91c00ef,0x00000000,0x00000000,0x00000000}},	//   _mežz, --, --, --, 
   {{0xe3b02b8f,0xab28010b,0x00000000,0x00000000}},	//   ورد_, _соңа_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc17403f9,0xe2981b88,0x04280023,0xf7702b90}},	//   _haɗi_, јам_, _ብወገን, _كام_, 
   {{0x21680116,0x00000000,0x00000000,0x00000000}},	//   иини_, --, --, --, 
   {{0x6d5c00b0,0xd24c004b,0x79840113,0x00000000}},	//   _nzsa, ځنۍ_, ñiwi, --, 
   {{0x248c016b,0x6e3c036e,0x04642b91,0x00000000}},	//   mpem_, _ajsb, _утем, --, 
   {{0x248c2b92,0x6d5c2b93,0x00000000,0x00000000}},	//   lpem_, _azsa, --, --, 
   {{0x248c003a,0x78a416a3,0xdb1c01d3,0xdd8801f0}},	//   opem_, šivi, repü, рбад_, 
   {{0x248c05b1,0x61f40857,0x6e20017a,0xdb1c0254}},	// [2740] npem_, _inyl, ëlba, sepü, 
   {{0x61e42b94,0xc17403f9,0x248c004e,0x00000000}},	//   ldkl, _naɗi_, ipem_, --, 
   {{0x6d5c02d0,0x6b500023,0x00000000,0x00000000}},	//   _ezsa, _ንጢሞቴ, --, --, 
   {{0xd9d00e8e,0x27e802a8,0x3eb82b95,0x988002d3}},	//   بەرگ, ɓani_, murt_, _ክሰርሑ_, 
   {{0xc1740198,0x97e00588,0x3eb82b96,0xd7f80022}},	//   _baɗi_, мҩаҧ, lurt_, иук_, 
   {{0xacd804ac,0x3940025c,0xd7e400db,0x00000000}},	//   _פֿרי, ħis_, زوعۇ_, --, 
   {{0xc1740b45,0x795403e6,0x4aa4014b,0x87d400db}},	//   _daɗi_, _کێشا, _мкрн_, زبوس_, 
   {{0xd9442b97,0x61e401f5,0x043c0023,0x00000000}},	//   _деби, jdkl, _ይብጻሕ, --, 
   {{0xc1740b45,0x3eb82b98,0x236801e4,0xdb1c0022}},	//   _faɗi_, hurt_, _ĝaja_, pepó, 
   {{0x3eb82b99,0x136811b2,0xd3781638,0x61f40109}},	//   kurt_, ишни_, шчи_, _anyl, 
   {{0x248c013f,0x61e40d27,0x4b78008f,0xe7f40166}},	//   apem_, fdkl, יטיג, _эчтэ, 
   {{0x20182b9a,0x7af80b1a,0x3eb8262b,0x00000000}},	//   _alpi_, øvty, durt_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3eb82b9b,0x10482b9c,0x61e4000f,0x61f4035a}},	//   furt_, рями_, adkl, _enyl, 
   {{0x3eb82b9d,0x63b400d0,0x00000000,0x00000000}},	//   gurt_, ózne, --, --, 
   {{0x20182b9e,0x92642b9f,0x68ec00d7,0x00000000}},	//   _elpi_, _بدتم, ťadi, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [2750] --, --, --, --, 
   {{0x3eb803fa,0x32082ba0,0x6fb82ba1,0x62240014}},	//   burt_, _hoay_, _угор_, _وى۪ل, 
   {{0x0a6816c3,0x3eb807de,0x8ca42ba2,0x8aa401b9}},	//   арди_, curt_, _चिको, юрад, 
   {{0x248c0077,0x99842ba3,0xadd81a71,0x00000000}},	//   ypem_, rhoş_, _умму_, --, 
   {{0x6d5c2ba4,0xa2a001bc,0xbdc400d1,0x00000000}},	//   _uzsa, _कौन्, _تەقۋ, --, 
   {{0xa6941614,0x66e407d6,0x3208004d,0x397c0023}},	//   приј, зока, _loay_, _ብዓልቲ_, 
   {{0x9ba02ba5,0x32080009,0xe5a40131,0x4e0c0401}},	//   _سەنى, _ooay_, пийи, _सवाई_, 
   {{0xd6cc0979,0x6b840368,0x7f3c010f,0xc8a802e8}},	//   اقي_, lchg, יעוו, _въже_, 
   {{0x69d82ba6,0xc1740198,0x00000000,0x00000000}},	//   mewe, _taɗi_, --, --, 
   {{0x6b842ba7,0x4830021a,0x94202ba8,0x61f4072b}},	//   nchg, _غواړ, емье, _snyl, 
   {{0x320828ab,0xe3b0267a,0x6b842ba9,0x98680131}},	//   _boay_, ورگ_, ichg, _اللە_, 
   {{0x61442baa,0x69d82bab,0x00000000,0x00000000}},	//   зема, newe, --, --, 
   {{0x61e42bac,0x69d82bad,0x6fcc00cd,0xb5cc0150}},	//   rdkl, iewe, द्भू, _ﺒﺄﻀﻌ, 
   {{0x69d82bae,0x81dc2baf,0x3eb806f2,0xc31004c5}},	//   hewe, ঠাই_, turt_, াছবি_, 
   {{0xe8e400ec,0x5398011a,0x00000000,0x00000000}},	//   _ڌڻ_, _היצו, --, --, 
   {{0x69d82bb0,0x27e42bb1,0x6b84002d,0xc0e40b82}},	//   jewe, _laln_, echg, ምህር_, 
   {{0x69d82bb2,0x3eb82bb3,0x2fd0043b,0x5ba81e76}},	// [2760] dewe, surt_, ́ngɔ_, йкам_, 
   {{0xdce400da,0x27e4017a,0xcf8c01d9,0x2ee00240}},	//   _iekļ, _naln_, _مژِ_, _fshf_, 
   {{0x69d80161,0x22802bb4,0x8f78011a,0x0f7808c3}},	//   fewe, _jók_, _לניק, _לאיב, 
   {{0x69d809f9,0x63a02bb5,0x3208001e,0x00000000}},	//   gewe, haln, _xoay_, --, 
   {{0x26c40477,0x4c802bb6,0xddd4012d,0xf1c000cd}},	//   _aqlo_, _пляв, zmyś, ष्टन, 
   {{0x9f580004,0x36d42bb7,0x00000000,0x00000000}},	//   _topä_, докр, --, --, 
   {{0x63a02bb8,0x69d82bb9,0x8c180302,0x65780334}},	//   daln, bewe, _פולי, _bgwh, 
   {{0xc17402a8,0x09e02bba,0xd5e0004d,0x63a00175}},	//   _haɗu_, _посн, _khỏ, ealn, 
   {{0xc1740198,0x32080c6a,0x1dcc00dc,0xdce400e2}},	//   _kaɗu_, _roay_, ह्यत, _nekļ, 
   {{0x22801f60,0x32082bbb,0xf6c4022e,0x00000000}},	//   _bók_, _soay_, _биpи_, --, 
   {{0x95c82bbc,0xd6282bbd,0x00000000,0x00000000}},	//   _глеб_, _ложе_, --, --, 
   {{0x63a000af,0x867800d9,0x63800124,0x00000000}},	//   aaln, _הראו, нҳәа, --, 
   {{0x320805da,0x50642bbe,0xd76002f2,0x00000000}},	//   _voay_, зтва, _تۆژی, --, 
   {{0x69d82bbf,0xb4e802ab,0x74142bc0,0x228002d2}},	//   zewe, मटी_, _زوبا, _fók_, 
   {{0x69d800ec,0x93581513,0x6e20017a,0x998402f0}},	//   yewe, _урду_, ëlbo, dnož_, 
   {{0x69d802c4,0x43380375,0xc33000d9,0x00000000}},	//   xewe, _לעוב, _רוק_, --, 
   {{0x1cc00003,0x69d82bc1,0xd24c0050,0xbec40055}},	// [2770] _གྱད_, vewe, _لۆگ_, _śīty, 
   {{0x69d82bc2,0xf778025c,0x705404fb,0xadec00af}},	//   wewe, _daħk_, _زنجا, _चोरन_, 
   {{0x6b842bc3,0x00000000,0x00000000,0x00000000}},	//   rchg, --, --, --, 
   {{0x63a02bc4,0x27e42bc5,0x6b8422f8,0xfb84013d}},	//   zaln, _saln_, schg, _җырн, 
   {{0xba742bc6,0xed500451,0x69d82bc7,0x10400092}},	//   رامت, _شھر_, rewe, _የህትመ, 
   {{0x69d80925,0x63a0058a,0xbea80244,0xf5340240}},	//   sewe, xaln, _بهێن_, _ክትኮነ, 
   {{0x63a00f72,0x69d82bc8,0xb7c800c6,0x96f40798}},	//   valn, pewe, سبوك_, дејт_, 
   {{0x63a02bc9,0x466003cc,0x22800174,0x00000000}},	//   waln, رۇشق, _rók_, --, 
   {{0x92bc045e,0xc17403f9,0xc8b0004b,0xe508027d}},	//   ুটো_, _yaɗu_, _سلاک, زيدو_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x04ec015b,0x62800369,0x1cc0031c,0x00000000}},	//   য়নের_, uqlo, _གྱན_, --, 
   {{0x63a02bca,0xa0a42bcb,0x62802bcc,0x00000000}},	//   saln, мамд, rqlo, --, 
   {{0x63a02bcd,0xa5bc02d5,0x1aa8033f,0xa5080798}},	//   paln, siųs, _चट्ठ, _фела_, 
   {{0x228026b8,0xe2982bce,0x63a003d9,0x04640354}},	//   _tók_, _дак_, qaln, _этем, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb7d40241,0xd5e00051,0x00000000,0x00000000}},	//   _iṣeg, _phỏ, --, --, 
   {{0xdb1c01f4,0x00000000,0x00000000,0x00000000}},	// [2780] nepö, --, --, --, 
   {{0x8d600b32,0x3e7c00df,0x4d6002bf,0xb33c0003}},	//   твуе, _aŭte_, ткув, laħa, 
   {{0x1a280108,0x9e64011c,0xea940139,0x00000000}},	//   ожжи_, _овод, ешчэ, --, 
   {{0x81dc00cc,0xd5e00051,0x00000000,0x00000000}},	//   ঠাক_, _thỏ, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe4f0000d,0x9f4802d2,0x00000000,0x00000000}},	//   _अछ़ि_, _þjón_, --, --, 
   {{0x86c02bcf,0xd5b82bd0,0xdddc2bd1,0x47c800f1}},	//   نيون, осп_, _nupū, تانۍ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x057002dd,0xc670007b,0xb4e802db,0x00000000}},	//   پايد, خطوب, मटे_, --, 
   {{0x69cc0142,0xd394013d,0x00000000,0x00000000}},	//   ŵaet, фәдә_, --, --, 
   {{0x0bb4025f,0x2874052f,0xefe0044e,0x07a02bd2}},	//   ולים_, _яҡшы_, ነታዊ_, _рахн, 
   {{0xa81802dd,0xda1c0118,0x00000000,0x00000000}},	//   _وتەر_, पसित_, --, --, 
   {{0xdb1c000d,0x00000000,0x00000000,0x00000000}},	//   mepõ, --, --, --, 
   {{0xdb1c000d,0x00000000,0x00000000,0x00000000}},	//   lepõ, --, --, --, 
   {{0xf31805f5,0x60c001e4,0xadd40640,0x99840165}},	//   _хойш_, _ĥome, новљ, nnoų_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2f2400e8,0x8bc40063,0xefe0001f,0x00000000}},	// [2790] _bëgé_, дсед, ነሳው_, --, 
   {{0x3dc01c06,0x50640bbf,0xdce403e0,0xdb1c0037}},	//   agiw_, _تطبق, _cekı, hepõ, 
   {{0xdb1c01b8,0x00000000,0x00000000,0x00000000}},	//   zepö, --, --, --, 
   {{0x1cc00156,0x32182bd3,0xc9800023,0x0ddc0092}},	//   _གྱམ_, nksy_, _ክበጽሖ_, _ዓቀፉ_, 
   {{0xd36415fa,0xc03c0020,0x7c840588,0xddd4010e}},	//   _څه_, _ባለሥል, _аусе, lmyş, 
   {{0xd3641af6,0x2ca800c5,0x2d88003a,0xd7e40150}},	//   _مه_, msad_, lcae_, емше_, 
   {{0x7ac42bd4,0x2ca82bd5,0xddd4010e,0x00000000}},	//   _исте, lsad_, nmyş, --, 
   {{0x2d882bd6,0xdb1c0108,0xdddc00c0,0x2ca82bd7}},	//   ncae_, tepö, _rupū, osad_, 
   {{0x2ca81c81,0x79c82bd8,0x2d880393,0x79502bd9}},	//   nsad_, _توقف_, icae_, _پێوا, 
   {{0xdddc02b5,0x2ca8000d,0xddd400a2,0xd8b414af}},	//   _pupū, isad_, kmyş, _سگها_, 
   {{0x34842bda,0x00000000,0x00000000,0x00000000}},	//   нгөг, --, --, --, 
   {{0x2ca82bdb,0x339802d3,0x00000000,0x00000000}},	//   ksad_, መስረተ_, --, --, 
   {{0xa1142bdc,0xdb1c000f,0x2ca82bdd,0x6fb00210}},	//   روست, lepô, jsad_, _जयशं, 
   {{0x201c2bde,0xdee405f5,0x443001b8,0x2ca82bdf}},	//   óti_, ноги, _öx_, dsad_, 
   {{0x93100133,0x6d580003,0x00000000,0x00000000}},	//   _مووش, żwal, --, --, 
   {{0x0ddc001f,0x2ca82be0,0xdce403e0,0x00000000}},	//   _ዓቀፍ_, fsad_, _sekı, --, 
   {{0x15f00c2e,0xc21001d9,0xa514031c,0x2ca82be1}},	// [27a0] _अफसर_, _مٔژ_, ིརིག_, gsad_, 
   {{0x2d880393,0x00000000,0x00000000,0x00000000}},	//   acae_, --, --, --, 
   {{0x3f982be2,0x2ca80192,0x3ce0033b,0x2c00010b}},	//   mbru_, asad_, swiv_, шүрм, 
   {{0x2d882be3,0xe9e40212,0x0f34008f,0xdb1c0c6a}},	//   ccae_, кціо, _טריט_, ngpé, 
   {{0x7b840150,0xe9800131,0x24bc00d1,0xa2a01408}},	//   _لازە, рқун, _ﻣﻪﯞﺟ, _कौस्, 
   {{0xcdcc004b,0x3eb80076,0x00000000,0x00000000}},	//   _پښې_, orrt_, --, --, 
   {{0x8c402be4,0x81b82158,0x2480001f,0xabc401e0}},	//   _сере, ঘ্য_, _የሁለት_, _шарҙ, 
   {{0x96442be5,0xda640ccb,0x35f40120,0xceb0011a}},	//   ээлд, _سازي, тпир, איה_, 
   {{0x7d042be6,0x3f980003,0xdb1c000d,0x2d840139}},	//   nxis, kbru_, repõ, _şlek_, 
   {{0x3d080034,0xdb1c00c5,0x00000000,0x00000000}},	//   _सपने_, sepõ, --, --, 
   {{0x26100998,0xb6c402dd,0xf19400f5,0x00000000}},	//   _cáos_, _рөлд, кинь, --, 
   {{0xca300075,0x3eb8010a,0x00000000,0x00000000}},	//   ﺭﻏﺎ_, drrt_, --, --, 
   {{0xf4842be7,0x7d040227,0x2ca80009,0x00000000}},	//   _شاشی, jxis, xsad_, --, 
   {{0xb4ac0490,0x906021ef,0x3f982be8,0xffe42be9}},	//   गळी_, انسۇ, gbru_, люсн, 
   {{0x518400f3,0x00000000,0x00000000,0x00000000}},	//   _пупа, --, --, --, 
   {{0x2ca82bea,0x2d88003a,0x00000000,0x00000000}},	//   tsad_, ucae_, --, --, 
   {{0x7d042beb,0x2ca81c06,0x2d880381,0x3f982bec}},	// [27b0] gxis, usad_, rcae_, bbru_, 
   {{0x2ca82bed,0x2d882bee,0x2bd82bef,0x00000000}},	//   rsad_, scae_, بارک_, --, 
   {{0x2ca82bf0,0xd5a400f2,0x00000000,0x00000000}},	//   ssad_, _پف_, --, --, 
   {{0x6fcc2bf1,0x2ca82bf2,0x00000000,0x00000000}},	//   द्रू, psad_, --, --, 
   {{0x9f580100,0x2ca8036b,0xf99001c8,0x0854004e}},	//   _anpè_, qsad_, صبن_, нчкө_, 
   {{0xec3404ac,0x76402bf3,0x4914012d,0x00000000}},	//   _יאָר_, enmy, बैगो_, --, 
   {{0xbdd001e4,0x95380092,0x764002d2,0x00000000}},	//   liɨa, _እስከተ, fnmy, --, 
   {{0xba7402de,0x693400e8,0xdb2400e5,0xeb1c01f9}},	//   _ماقت, 茜eya, _شوقی, पनीत_, 
   {{0xd1e0001f,0x9f58007f,0x63b41155,0xa8740064}},	//   ምንት_, _enpè_, ózno, _алаі, 
   {{0x76402bf4,0x00000000,0x00000000,0x00000000}},	//   anmy, --, --, --, 
   {{0x23282bf5,0x00000000,0x00000000,0x00000000}},	//   фони_, --, --, --, 
   {{0x65942bf6,0xa53400f3,0x00000000,0x00000000}},	//   _раду, _инеч, --, --, 
   {{0x66082bf7,0x786405da,0x7d04031c,0x00000000}},	//   mjek, lòva, xxis, --, 
   {{0x66080209,0x3e7c0115,0x73c400f2,0x00000000}},	//   ljek, _aŭta_, _ميهم, --, 
   {{0x8fa02685,0x64402bf8,0x6608208d,0x4fa00395}},	//   расе, mnli, ojek, рисв, 
   {{0xd24c212c,0x66082bf9,0x3c240036,0x7d04009d}},	//   _ونو_, njek, _möve_, txis, 
   {{0x64402bfa,0x60240953,0x660801f5,0xdca41606}},	// [27c0] onli, _адпа, ijek, тази, 
   {{0x7d042bfb,0x64402bfc,0xabc40032,0x66080821}},	//   rxis, nnli, лауҙ, hjek, 
   {{0x64402bfd,0x66082bfe,0x78640268,0xcfb400df}},	//   inli, kjek, jòva, _בליי_, 
   {{0x64400730,0x7d040bc9,0x660804ba,0xb33c0327}},	//   hnli, pxis, jjek, daħl, 
   {{0xc03c0020,0x66080023,0xa9c417b9,0x00000000}},	//   _ባለስል, djek, ازمو, --, 
   {{0x64400936,0x8d742bff,0xfaa410e8,0xc5e800fe}},	//   jnli, _جاپا, _مجری, কাফা_, 
   {{0xc5e800bd,0x46a02c00,0x5984014b,0x00000000}},	//   কানা_, ашыб, _албб, --, 
   {{0x64402c01,0xcb642c02,0x66082c03,0x7640005b}},	//   enli, _расе_, gjek, unmy, 
   {{0xb4ac0490,0x22400ac5,0xf4842c04,0xdddc01ef}},	//   गळे_, dnkk_, دابی, _lupů, 
   {{0xe7c8068f,0x64401427,0x660800e4,0x295402e8}},	//   _रायप, gnli, ajek, _съср, 
   {{0x81ac009e,0x6284003e,0x1de00073,0x81cc00eb}},	//   খলন_, _éhol, _पसंत, রজন_, 
   {{0x64400a85,0x05802c05,0x52d0000d,0x00000000}},	//   anli, _кушм, _तहीस, --, 
   {{0xe7c82c06,0x73c40032,0x798002d0,0xd574005b}},	//   _रामप, _йәне, _mgmw, _ружь, 
   {{0xd01800d8,0x00000000,0x00000000,0x00000000}},	//   ффм_, --, --, --, 
   {{0x5fd01af8,0x00000000,0x00000000,0x00000000}},	//   द्धल, --, --, --, 
   {{0x2008036e,0x00000000,0x00000000,0x00000000}},	//   ajbi_, --, --, --, 
   {{0x0ba407d8,0xdeb00220,0x82340472,0x00000000}},	// [27d0] вшем, _құты, _خروا, --, 
   {{0x798002d0,0x5fd00073,0x7cd80454,0x4ea4022e}},	//   _agmw, द्दल, ъмур_, _ирма, 
   {{0x7ac40b3b,0x9e640023,0xdfd0009f,0x00000000}},	//   исце, _ጸገምና_, _ايپ_, --, 
   {{0xc3300302,0xa3d82c07,0x00000000,0x00000000}},	//   סוף_, _डॉन_, --, --, 
   {{0x66081727,0x644017b8,0x48a8013e,0x6934084c}},	//   vjek, ynli, фтем_, ынду, 
   {{0xa6c82c08,0x00000000,0x00000000,0x00000000}},	//   елка_, --, --, --, 
   {{0x66082c09,0x64402c0a,0x6d5c0200,0x49b800be}},	//   tjek, vnli, _hysa, _يارد_, 
   {{0x24e82c0b,0x7864068c,0x6d5c0306,0xd5e00051}},	//   емии_, ròva, _kysa, _chò, 
   {{0x66082c0c,0xc7c40022,0xe504007b,0x64401d0e}},	//   rjek, _асеи, ابعي, tnli, 
   {{0x6d5c2c0d,0x66081a84,0x644003fa,0xe3b000c6}},	//   _mysa, sjek, unli, حرة_, 
   {{0x21a42c0e,0x6d5c2c0f,0xa6c82c10,0xc7640131}},	//   линм, _lysa, _سوشل_, _شائى, 
   {{0x1e842c11,0xb4642c12,0x6d5c2c13,0x00000000}},	//   ғлам, лкөл, _oysa, --, 
   {{0xf4840261,0xf6500137,0x00000000,0x00000000}},	//   _кујн, _بئل_, --, --, 
   {{0xf778038f,0xf43400f7,0x00000000,0x00000000}},	//   _taħt_, _кечэ, --, --, 
   {{0x6d5c2c14,0x1c4402a9,0x69c8127b,0x02c000cf}},	//   _aysa, ҳнам, _ocee, _тийү, 
   {{0x69c80070,0x6d5c05ac,0x2d942c15,0x68e82c16}},	//   _ncee, _bysa, ирус, _osed, 
   {{0x6d5c015d,0x00000000,0x00000000,0x00000000}},	// [27e0] _cysa, --, --, --, 
   {{0x69c82c17,0x6d5c2c18,0x1098123b,0xbd4401e2}},	//   _acee, _dysa, _רביב, هنځي, 
   {{0x68e82c19,0xd13402d3,0x6d5c058a,0xdd1000de}},	//   _ased, _ኣስተው, _eysa, _kļūt, 
   {{0x1d080aa8,0x6d5c2c1a,0xa7a00150,0x18800023}},	//   _земи_, _fysa, _ﺎﺩﺍﺓ_, _ክሰግር_, 
   {{0x6d5c2c1b,0xd5e0004d,0x00000000,0x00000000}},	//   _gysa, _nhó, --, --, 
   {{0x3db00eac,0x2c0400dc,0x4ed400fe,0x00000000}},	//   ঙ্খল, राणं_, হিৰল, --, 
   {{0x68e82c1c,0xd5e0004d,0x182801d5,0x672c0115}},	//   _esed, _phò, وقچی_, ŝajn, 
   {{0xd4980364,0x34b42c1d,0xa280068f,0xb4b401b9}},	//   нро_, абиё, łość_, айиш, 
   {{0x628400d8,0xe8e800f1,0x2ee000bc,0xc68c0014}},	//   _éhoj, _لرلو_, _पन्त, _ہِل_, 
   {{0x53e40124,0x7864067c,0x743400f5,0x9d1000fe}},	//   уциа, mòvo, рноф, _সেৱন_, 
   {{0xcc54008f,0x00000000,0x00000000,0x00000000}},	//   רביי_, --, --, --, 
   {{0x044000d1,0x2ee000bc,0x00000000,0x00000000}},	//   _һечн, _पनौत, --, --, 
   {{0x2748006a,0x3e7c008f,0x68e805b1,0x386c010e}},	//   _tînï_, _aŭto_, _xsed, _khdr_, 
   {{0x6d5c2c1e,0x74142c1f,0xc05802dd,0x2d8c0003}},	//   _rysa, _خوتا, гіс_, _żee_, 
   {{0x386c01ab,0x00000000,0x00000000,0x00000000}},	//   _mhdr_, --, --, --, 
   {{0x95e000ab,0x00000000,0x00000000,0x00000000}},	//   _खसोट_, --, --, --, 
   {{0xbf140184,0xe8140037,0xc3c000cf,0xd24c00e5}},	// [27f0] _һүрә, _तकला_, _төөл, _ونڈ_, 
   {{0x6d5c04bf,0x00000000,0x00000000,0x00000000}},	//   _vysa, --, --, --, 
   {{0x78bc00da,0xddc400b8,0xdeb002dd,0x6d5c2c20}},	//   _ārva, _cikų, _мұры, _wysa, 
   {{0x68e8007f,0x31680240,0xa9c00228,0x00000000}},	//   _psed, _kzaz_, تۅرۉ, --, 
   {{0xe94404fb,0x7a3801e4,0xae94004d,0x6d5c03e0}},	//   جرای, aŭto, _kẹos, _uysa, 
   {{0x25a8151c,0x68e80dfe,0x00000000,0x00000000}},	//   _žal_, _vsed, --, --, 
   {{0x8d740075,0x66041d0f,0x672c01e4,0xe610007b}},	//   _جاھا, ипка, ĝajo, قشة_, 
   {{0x68e82c21,0x69c80998,0x57b02c22,0x22480115}},	//   _tsed, _ucee, ббәт, _ĉako_, 
   {{0x68e814dc,0xf778031c,0x2918032e,0x3d0800cd}},	//   _used, _daħq_, _æsa_, समये_, 
   {{0x39142c23,0xc6a4009b,0x00000000,0x00000000}},	//   _умур, _брди, --, --, 
   {{0x2a6c2c24,0x316801ed,0x9f580241,0xe3642c25}},	//   _kheb_, _azaz_, _lopò_, ркни, 
   {{0xa4d402bf,0xe3b02c26,0xd5e00051,0x00000000}},	//   _воді, حرک_, _thó, --, 
   {{0x386c0175,0xdddc0356,0xf6741867,0xc5e800cc}},	//   _yhdr_, _lupţ, _االخ, কাদা_, 
   {{0xa0682c27,0x8fa02c28,0xfaf8005f,0xe3b82c29}},	//   тага_, жаре, _šīm_, _рбк_, 
   {{0xdee42c2a,0x31682c2b,0xd36c0451,0x98a40010}},	//   шови, _ezaz_, _ٺهي_, vzoč_, 
   {{0xbdd001e4,0x00000000,0x00000000,0x00000000}},	//   riɨo, --, --, --, 
  
   {{0xa2a00bca,0xd24c009f,0xeb1401e1,0x00000000}},	// [2800] कीर्, _تني_, _òòjé_, --, 
   {{0x2a6c0161,0x5fa8033f,0xd00c007b,0x00000000}},	//   _aheb_, _क़िल, _يلي_, --, 
   {{0xaec00220,0x5ac800fb,0x59842c2c,0x00000000}},	//   _нұрл, тлем_, алеб, --, 
   {{0x2a6c2c2d,0x5fd02c2e,0x3c2401e3,0x00000000}},	//   _cheb_, द्रल, _döva_, --, 
   {{0x386c2c2f,0x6bd41066,0xd944084c,0xa3c42c30}},	//   _phdr_, شتەر, шеди, एला_, 
   {{0x985400a8,0xd6d82c31,0x81cc00eb,0x4870009a}},	//   штеш, вти_, রজি_, يدوس, 
   {{0xda780116,0x00000000,0x00000000,0x00000000}},	//   _җяң_, --, --, --, 
   {{0x6d400055,0x00000000,0x00000000,0x00000000}},	//   _ślai, --, --, --, 
   {{0x81ac015b,0x57e806ed,0xb4e007f7,0xd40403c5}},	//   খলা_, _идам_, दबे_, аяни, 
   {{0xd88802dd,0x00000000,0x00000000,0x00000000}},	//   _ﻗﻮﻳﯟ, --, --, --, 
   {{0xdb0c01ef,0xd7340354,0x32542c32,0xb23c0150}},	//   _odbí, _тхаь, йвор, емнi, 
   {{0x25dc2c33,0xc1ac00d1,0xb9e41954,0xd7f80354}},	//   _कॉपी_, _ﻳﯩﺮﺍ, _ቫን_, _пуç_, 
   {{0x0678011a,0x00000000,0x00000000,0x00000000}},	//   _סנדל, --, --, --, 
   {{0x9fa0002e,0x04d8010f,0x9f580248,0x00000000}},	//   _bëñu_, _סקול, _ropò_, --, 
   {{0xbe882c34,0x6e9400fb,0xae4400f2,0x00000000}},	//   исте_, сибу, مپسو, --, 
   {{0xdddc0356,0x3c24007c,0x82340f17,0xfe0400d8}},	//   _rupţ, _röva_, _وريا, оџум, 
   {{0x25dc2c35,0xacf802dd,0x3c24007c,0xaa580131}},	// [2810] _कॉफी_, ынау_, _söva_, қиду_, 
   {{0xada401e0,0x3cf8000d,0xa2ac0073,0xb33c0327}},	//   раҡл, _उछरे_, ूंच्, taħh, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2a6c0211,0xcb8c02d3,0x14c40a8a,0x00000000}},	//   _qheb_, _ዝጀመረ_, लढाण, --, 
   {{0x105c0092,0x00000000,0x00000000,0x00000000}},	//   _ለህትመ, --, --, --, 
   {{0x1d140375,0x6e0000f1,0x00000000,0x00000000}},	//   _הקשר_, _بېړن, --, --, 
   {{0xd90c00f1,0x00000000,0x00000000,0x00000000}},	//   ویې_, --, --, --, 
   {{0xa3d8012c,0x986800db,0x00000000,0x00000000}},	//   ड्न_, _ەلكە_, --, --, 
   {{0xe4580aa8,0x852003e6,0xa8142519,0x4a7401af}},	//   лжи_, ڵوگۆ, _лдаш, _быҡт, 
   {{0x291c2c36,0x00000000,0x00000000,0x00000000}},	//   mywa_, --, --, --, 
   {{0xe7182c37,0x182801d5,0x61e000a2,0x20040051}},	//   _حيات_, _حقلی_, _ıolb, _đoi_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x25ac2c38,0xa6b800cc,0x00000000,0x00000000}},	//   mael_, _আহিয়, --, --, 
   {{0xa2e4010b,0x25ac020c,0x00000000,0x00000000}},	//   _гокд, lael_, --, --, 
   {{0x66f81025,0xc214013f,0x9e642c39,0x64a40116}},	//   ्मिक_, _toɔ_, مارن, _таһа, 
   {{0x25ac2c3a,0x442401a4,0x2d8400a2,0xa06801a9}},	//   nael_, _hln_, _şler_, таҳа_, 
   {{0x61e42c3b,0x6fb000ab,0x00000000,0x00000000}},	// [2820] mekl, _जयचं, --, --, 
   {{0x61e42c3c,0x60c42c3d,0x44242c3e,0xdddc00ef}},	//   lekl, mukm, _jln_, _dupš, 
   {{0xdddc0f8b,0x60c42c3f,0x6fa801c6,0xd7f80b01}},	//   _eupš, lukm, _өвөг_, ғул_, 
   {{0x61e42c40,0x38c8006c,0x44240ffb,0x4e24010b}},	//   nekl, لاتی_, _lln_, _гоюн_, 
   {{0x25ac00a9,0x7e642c41,0xd838010b,0x5cf4013d}},	//   dael_, mlip, лэк_, _уяну, 
   {{0x7e642c42,0x442403b9,0x61e42c43,0x00000000}},	//   llip, _nln_, hekl, --, 
   {{0x61e42c44,0x248c011f,0x7bdc2c45,0x60c4022e}},	//   kekl, eqem_, _ibru, hukm, 
   {{0x7e64113c,0x61e42c46,0x248c011f,0x7afc2c47}},	//   nlip, jekl, fqem_, _irrt, 
   {{0x44242c48,0x61e42c49,0x99840165,0x7e642c4a}},	//   _bln_, dekl, lhoů_, ilip, 
   {{0x442400b5,0x7e6402c1,0x7afc0200,0x4804014b}},	//   _cln_, hlip, _krrt, _леун_, 
   {{0x25ac1028,0x7bdc2c4b,0x61e42c4c,0x00000000}},	//   bael_, _mbru, fekl, --, 
   {{0x61e42c4d,0x44240789,0xcb100375,0x7e64107d}},	//   gekl, _eln_, ללת_, jlip, 
   {{0x7bdc2c4e,0x661c2c4f,0x44242c50,0x00000000}},	//   _obru, öske, _fln_, --, 
   {{0x7e6401ee,0x7f942c51,0x70a805d7,0x7afc25d7}},	//   elip, зарх, _कबील, _orrt, 
   {{0x61e42c52,0x291c033f,0x403404b0,0xff0406a6}},	//   bekl, zywa_, черс, пятн, 
   {{0x7e642c53,0x61e42c54,0xa29404d3,0xcd44001f}},	//   glip, cekl, _بدوڵ, _በመክፈ, 
   {{0x7bdc01ab,0x7afc0175,0x8d380092,0x4238011a}},	// [2830] _bbru, _arrt, _በዘላቂ, _לנהל_, 
   {{0x7afc020b,0x7e642c55,0x25ac00d8,0x5fa800bc}},	//   _brrt, alip, zael_, करणल, 
   {{0x7e642c56,0xb33c0327,0x00000000,0x00000000}},	//   blip, bbħe, --, --, 
   {{0x291c00aa,0x7e642c57,0x7bdc2c58,0x7afc020b}},	//   tywa_, clip, _ebru, _drrt, 
   {{0x6e2c03e0,0x7afc2c59,0xa7a81d39,0x278800c7}},	//   mhab, _errt, акла_, аӡеи_, 
   {{0x6e2c2c5a,0x61e42c5b,0xa6942424,0x291c033f}},	//   lhab, zekl, ориј, rywa_, 
   {{0x248c011f,0x99840165,0x25ac0113,0x94dc06be}},	//   wqem_, choů_, tael_, _içər_, 
   {{0x6e2c2c5c,0xbb480597,0x0ba80e26,0x6a2404fb}},	//   nhab, _الفن_, _جاڭى_, _بفرم, 
   {{0x25ac2c5d,0x442410eb,0x61e412e8,0x36d400c7}},	//   rael_, _pln_, vekl, _ҭоур, 
   {{0xe70414a5,0x69d82c5e,0x6e2c2c5f,0x25ac016b}},	//   _وسای, lfwe, hhab, sael_, 
   {{0x6e2c2c60,0xf9900014,0x25b827dc,0x44241c1e}},	//   khab, _آبہ_, _نهاد_, _vln_, 
   {{0x6e2c2c61,0x60c42c62,0x61e4017a,0x9f5801e1}},	//   jhab, tukm, uekl, _nnpá_, 
   {{0x61e42c63,0x6e2c2c64,0x248c011f,0x4424000d}},	//   rekl, dhab, qqem_, _tln_, 
   {{0x6e2c003a,0xa878010f,0xf494010a,0x00000000}},	//   ehab, יאָר, _хăрн, --, 
   {{0x61e42c65,0x60c40098,0xbdd001e4,0x7e642c66}},	//   pekl, sukm, liɨi, tlip, 
   {{0x22b400da,0x7e64157b,0x7bdc0bdf,0x69d801f5}},	//   māk_, ulip, _sbru, jfwe, 
   {{0x22b400da,0x7e642c67,0x5ba82c68,0x99840165}},	// [2840] lāk_, rlip, икам_, zioų_, 
   {{0x7e642c69,0x69d82c6a,0x6e2c04ba,0x00000000}},	//   slip, efwe, ahab, --, 
   {{0x6e2c2c6b,0xd24c2c6c,0x22b400da,0x7e640bc2}},	//   bhab, _سنی_, nāk_, plip, 
   {{0x6e2c2c6d,0xceb00375,0x00000000,0x00000000}},	//   chab, _קיר_, --, --, 
   {{0xd7e82c6e,0xf3f800e2,0x24880332,0x00000000}},	//   имде_, loģe_, _éamh_, --, 
   {{0x69d801f5,0x22b400e2,0xe97003cc,0x00000000}},	//   afwe, kāk_, رۇلد, --, 
   {{0xdcf42c6f,0x786400cf,0xea6400e5,0x00000000}},	//   mayı, nòvi, _کھلی, --, 
   {{0xdcf42c70,0x597400c7,0x22b400e2,0x99840165}},	//   layı, _дызу, dāk_, rioų_, 
   {{0x77940244,0x00000000,0x00000000,0x00000000}},	//   _فیشا, --, --, --, 
   {{0x18680c04,0x47c02c71,0x68ec2c72,0x6e2c2c73}},	//   _тази_, _обув, çade, zhab, 
   {{0x92682c74,0x22b4005f,0xd6282c75,0x290000b0}},	//   ирма_, gāk_, _коже_, āhae_, 
   {{0x6e2c2c76,0xdcf40205,0x6ef4013a,0x00000000}},	//   xhab, hayı, hýbá, --, 
   {{0xdcf41ae4,0x764001f4,0x3d040210,0x00000000}},	//   kayı, mimy, रमों_, --, 
   {{0x76402c77,0x22b400da,0x6e2c00ec,0xae1c0037}},	//   limy, bāk_, whab, _नवहन_, 
   {{0xdcf42c78,0x786426b7,0x752003ac,0xdb1c265c}},	//   dayı, gòvi, lymz, ngpä, 
   {{0x2bdc1971,0xac940588,0x9de40327,0x764001f4}},	//   न्ना, зааш, _སྒྱེ, nimy, 
   {{0x6e2c2c79,0x82e4025c,0x8d742c7a,0xdd0c0205}},	// [2850] rhab, _འགོའ, زارا, rışc, 
   {{0x6e2c2c7b,0xd24c1d1f,0x76402c7c,0x22582c7d}},	//   shab, _سنڌ_, himy, čske_, 
   {{0x76402c7e,0x69d81cea,0x7864004e,0x6e2c2c7f}},	//   kimy, tfwe, còvi, phab, 
   {{0x6e2c0921,0x76400223,0x69d80112,0xfa341bf4}},	//   qhab, jimy, ufwe, ورند, 
   {{0x9de40135,0x22b400da,0x76400113,0x01fc08d8}},	//   _སྒྲེ, zāk_, dimy, יפאל, 
   {{0xac5400ec,0xdcf403b9,0x00000000,0x00000000}},	//   _ڀرڳڙ, cayı, --, --, 
   {{0xdce400e2,0x7640033b,0x69d80112,0xac941171}},	//   _izkā, fimy, pfwe, _фаҳш, 
   {{0x764000ca,0x69d80369,0x22b41a14,0x00000000}},	//   gimy, qfwe, vāk_, --, 
   {{0xf7702c80,0xbc680014,0xa9a40131,0xaac80073}},	//   _یام_, _طمہن_, _миңд, ांवक, 
   {{0x87042c81,0x22b4005f,0xe4500116,0x00000000}},	//   _وبال, tāk_, عضة_, --, 
   {{0x2bdc2c82,0xfbcc012c,0x76402c83,0x00000000}},	//   न्या, ालतम, bimy, --, 
   {{0x22b411f9,0x2c6c278a,0x26f82c84,0x15e002ab}},	//   rāk_, _vždy_, ्मीर_, _कॉपर_, 
   {{0x22b4005f,0xdcf4083c,0x00000000,0x00000000}},	//   sāk_, yayı, --, --, 
   {{0x2bdc0b7c,0xa03400cf,0x00000000,0x00000000}},	//   न्मा, سىزت, --, --, 
   {{0x64402c85,0x91a80c58,0xdb0c05ac,0x2c0402e5}},	//   mili, _কাৰ্, _åkøy, राईं_, 
   {{0xdb1c007c,0xd334011a,0x00000000,0x00000000}},	//   ngpå, _מרצה_, --, --, 
   {{0x22402c86,0xdcf42c87,0x61440484,0x64402c88}},	// [2860] mikk_, tayı, _хепа, oili, 
   {{0x61f42c89,0x6618039a,0x2240168c,0x7640019c}},	//   _hayl, _lowk, likk_, zimy, 
   {{0x61f42c8a,0xdcf41ae6,0x76400223,0x64402c8b}},	//   _kayl, rayı, yimy, iili, 
   {{0x64402c8c,0x61f42c8d,0x20182c8e,0x224003a1}},	//   hili, _jayl, _hopi_, nikk_, 
   {{0x64402c8f,0xdcf40790,0xc98000d1,0x0d802c90}},	//   kili, payı, нуши, _плюн, 
   {{0x64402c91,0x20182c92,0x764000ca,0x02d800dc}},	//   jili, _jopi_, wimy, _बहून, 
   {{0x64402c93,0x6618070d,0x20182c94,0x22402c95}},	//   dili, _bowk, _mopi_, kikk_, 
   {{0x61f42c96,0xa3d82c97,0x20182c98,0x64402c99}},	//   _nayl, ड्स_, _lopi_, eili, 
   {{0x76402c9a,0xf434084c,0x2240143a,0x661c10ee}},	//   rimy, депэ, dikk_, öska, 
   {{0x20180de2,0x1cd8031c,0x20d4003a,0x76402c9b}},	//   _nopi_, ྡ྄ར_, dæi_, simy, 
   {{0x61f42c9c,0x46a02c9d,0x224003a1,0x66180493}},	//   _bayl, _захв, fikk_, _fowk, 
   {{0x61f42c9e,0x22402c9f,0x661800a2,0x644012ef}},	//   _cayl, gikk_, _gowk, aili, 
   {{0x61f42ca0,0x20182ca1,0x44440014,0x2bdc0b4c}},	//   _dayl, _bopi_, _کرنہ, न्डा, 
   {{0x20182ca2,0x6e3c2ca3,0x94200228,0x3d0000bc}},	//   _copi_, _smsb, _سوعۇ, रिने_, 
   {{0x224003cd,0x64b40790,0x00000000,0x00000000}},	//   bikk_, _eşiğ, --, --, 
   {{0x61f42ca4,0x7db4007b,0x224000e5,0x00000000}},	//   _gayl, ّصلا, cikk_, --, 
   {{0x32080d62,0x20180421,0xc1bc0302,0xbba82ca5}},	// [2870] _inay_, _fopi_, _המחש, गरूक, 
   {{0x628400d8,0x20182ca6,0x3208004d,0x61f42ca7}},	//   _éhor, _gopi_, _hnay_, _zayl, 
   {{0x61f42ca8,0x15d801ec,0xa7e400d1,0x00000000}},	//   _yayl, _ﺃﺤﺎﺩ, ېكتى, --, 
   {{0x61f4102c,0x64402ca9,0x6e3c02d0,0x19c00022}},	//   _xayl, zili, _umsb, кәуг, 
   {{0x9f58023a,0xfcc800d1,0x20182caa,0x1f500023}},	//   _enpä_, _нурй_, _yopi_, _ዘስደም, 
   {{0x64402cab,0x201802c4,0x6618058a,0xdce400e2}},	//   xili, _xopi_, _sowk, _uzkā, 
   {{0x32082cac,0x02d8000d,0x91bc27a6,0xba0800d1}},	//   _onay_, _बहेन, ्लाई, تتەك_, 
   {{0x64400f7b,0x76c400d1,0x00000000,0x00000000}},	//   wili, رغىل, --, --, 
   {{0x61f42cad,0x3d001971,0x74f801c6,0x9f5801e3}},	//   _rayl, रिये_, пээс_, _inpå_, 
   {{0x61f42cae,0x32082caf,0xe7b42cb0,0x6618020b}},	//   _sayl, _anay_, _آماد, _wowk, 
   {{0x61f42cb1,0x22402cb2,0x20182cb3,0x661800a2}},	//   _payl, tikk_, _ropi_, _towk, 
   {{0x21682896,0x61f42cb4,0x20182cb5,0x2bdc2cb6}},	//   жими_, _qayl, _sopi_, न्ता, 
   {{0x224003a1,0x61f42cb7,0x9f480798,0x00000000}},	//   rikk_, _vayl, cebê_, --, 
   {{0x61f40986,0x22401a82,0x23282cb8,0xdee42cb9}},	//   _wayl, sikk_, _моли_, моги, 
   {{0x2240000d,0xfbcc194b,0x00000000,0x00000000}},	//   pikk_, ालसम, --, --, 
   {{0x74a4095f,0x61f403e3,0x00000000,0x00000000}},	//   चीकृ, _uayl, --, --, 
   {{0x20182cba,0xdb0c0ea0,0x0f4802d3,0x00000000}},	// [2880] _topi_, _gebê, _ዘድልየ, --, 
   {{0x32080109,0x25dc2cbb,0xcf8c01d9,0xcb4801ec}},	//   _znay_, क्ती_, _نژِ_, дiрi, 
   {{0x2bdc2cbc,0x3e480276,0x5f4404fb,0xa2a00490}},	//   न्धा, eşte_, _آنجل, कीच्, 
   {{0xfaf800da,0x1d0800cf,0x00000000,0x00000000}},	//   _šīs_, _деми_, --, --, 
   {{0x249c0218,0x08942cbd,0xd8380006,0x1278010f}},	//   _ntwm_, وضوع_, жэй_, קאנע, 
   {{0x68ec2cbe,0x2bdc29ea,0x399400d2,0x3f980ffb}},	//   çada, न्दा, _bûsó_, ncru_, 
   {{0xdb0c00e8,0x3e480356,0xcb6404c2,0x00000000}},	//   _mebë, aşte_, _жаре_, --, 
   {{0x8a0002e8,0xdb0c0200,0x00000000,0x00000000}},	//   _изсе, _lebë, --, --, 
   {{0x25bc0042,0x1fc400cc,0x62940115,0x00000000}},	//   _ddwl_, শ্যস, ŭzol, --, 
   {{0xdecc010c,0xd5e80014,0x00000000,0x00000000}},	//   ብለን_, _ژٹان_, --, --, 
   {{0xdb0c00d2,0x97242cbf,0x00000000,0x00000000}},	//   _sebê, _تفاو, --, --, 
   {{0xd6242cc0,0xd50800ec,0x00000000,0x00000000}},	//   _تعطي, _وٺان_, --, --, 
   {{0xae0c07f7,0xdb0c0200,0xf8bc00cc,0x00000000}},	//   हासन_, _bebë, _আঙুঠ, --, 
   {{0x74142cc1,0x22580419,0x00000000,0x00000000}},	//   _سوبا, čska_, --, --, 
   {{0xb900025c,0x00000000,0x00000000,0x00000000}},	//   _ཧད_, --, --, --, 
   {{0x3f980ffb,0x32082cc2,0x32d8003e,0x00000000}},	//   acru_, _unay_, méy_, --, 
   {{0x32d82cc3,0x00000000,0x00000000,0x00000000}},	// [2890] léy_, --, --, --, 
   {{0xdb0c2cc4,0x41740150,0x1fc42cc5,0x70542cc6}},	//   _kebè, _جاىس, শ্বস, _سنجا, 
   {{0xfbd000f1,0x7cf801d3,0xba7400e5,0x96ac010a}},	//   شتل_, túrá, چانت, _чiир_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2c040034,0x6fc00183,0xec34010f,0xae0c0037}},	//   राओं_, শ্ৰে, _טאָר_, हावन_, 
   {{0x99840032,0xf414015b,0x661c08c5,0x974c0023}},	//   мтәһ, িসার_, ösko, _ዕንወት, 
   {{0xd5e80135,0x00000000,0x00000000,0x00000000}},	//   _རྒྱག, --, --, --, 
   {{0x31681529,0xe50801e2,0xe75800f2,0x7534009d}},	//   _nyaz_, سيدو_, _کلاغ_, вээх, 
   {{0xdb0c00cf,0x387c0175,0x7b080166,0xe2c80798}},	//   _bebè, cmvr_, _üstä, плод_, 
   {{0x31682cc7,0x33f400f7,0x32d80de2,0xe5e00153}},	//   _ayaz_, тчыс, géy_, _былi_, 
   {{0xdb0c007f,0x00000000,0x00000000,0x00000000}},	//   _debè, --, --, --, 
   {{0xa5082c31,0xe4d801e2,0x00000000,0x00000000}},	//   _хела_, _روغت_, --, --, 
   {{0x31680100,0x60c40327,0xa3c404af,0x3f8c0162}},	//   _dyaz_, rrkm, एलओ_, ødu_, 
   {{0x9e740063,0x00000000,0x00000000,0x00000000}},	//   ећај, --, --, --, 
   {{0x2bdc276a,0xb308009f,0x00000000,0x00000000}},	//   न्सा, _آغول_, --, --, 
   {{0xda582cc8,0x3f98017a,0xf7780327,0x00000000}},	// [28a0] үреш_, pcru_, _waħx_, --, 
   {{0xc5e8015b,0x4d602cc9,0x00000000,0x00000000}},	//   কাটা_, укув, --, --, 
   {{0x4fd41a4c,0xe7c82cca,0x1e842ccb,0x9f48020c}},	//   _אויב_, _राजप, _плом, kebé_, 
   {{0xdca400cf,0x661c007c,0x00000000,0x00000000}},	//   _пами, öskl, --, --, 
   {{0x2bdc2ccc,0x1cc8025c,0x18682ccd,0xae0c0037}},	//   न्हा, _ཊའི_, пади_, हारन_, 
   {{0x25dc2cce,0xb9082982,0x986401d9,0x00000000}},	//   क्सी_, _बह_, ریاے_, --, 
   {{0x32d8011f,0xbbcc012c,0xfce00023,0x629400df}},	//   xéy_, ालीक, _ሓዲጉ_, ŭzoj, 
   {{0xdb0c2ccf,0xca340220,0xa5bc00c0,0x00000000}},	//   _rebè, _ﯗﻟﺖ_, lkųj, --, 
   {{0x788400c7,0x2bdc00dc,0x32d80098,0x98a40107}},	//   _акаҷ, न्वा, wéy_, _чизе, 
   {{0xccf00302,0x88b80375,0x72d000d1,0xa9740798}},	//   רכז_, _מזמי, لەتچ, _русј, 
   {{0x07a02cd0,0xdb0c1d62,0x316805b1,0xf4842c04}},	//   _сахн, _bebé, _syaz_, _یاتی, 
   {{0x32d817bb,0xd1640107,0x00000000,0x00000000}},	//   réy_, еъги, --, --, 
   {{0xdb0c09c2,0x0f38001f,0x32d8003e,0x201c01a9}},	//   _debé, _አስመረ, séy_, аti_, 
   {{0xd754044e,0x63ac10fb,0xdb0c007f,0x148400ec}},	//   _ውሕስነ, _đang, _tebè, _ڪپڙي_, 
   {{0xa3d82cd1,0x00000000,0x00000000,0x00000000}},	//   _डॉट_, --, --, --, 
   {{0xdb0c2cd2,0x28d02356,0x56200183,0x9e6c0092}},	//   _gebé, _समलि, বোৰক_, _በጥሞና_, 
   {{0x31680b6f,0x8bc42cd3,0x00000000,0x00000000}},	// [28b0] _uyaz_, есед, --, --, 
   {{0x7bf82cd4,0x1ea800ec,0x00000000,0x00000000}},	//   ннур_, _ڪاٿي_, --, --, 
   {{0x41740214,0xf1c401f9,0x00000000,0x00000000}},	//   _لایس, _वयान, --, --, 
   {{0xf990168d,0x68ec2cd5,0xcfa80345,0x00000000}},	//   مبه_, çado, _باکم_, --, 
   {{0xd3641732,0x00000000,0x00000000,0x00000000}},	//   _چه_, --, --, --, 
   {{0xd3642cd6,0x97c00c9e,0xab940640,0xc1740a1e}},	//   _نه_, айше, _јављ, נחס_, 
   {{0x9ba00075,0x1cdc031c,0xda0000c5,0x00000000}},	//   _ئەمى, _རཱོ_, _रोवत_, --, 
   {{0x24982cd7,0x64981411,0x00000000,0x00000000}},	//   ísmo_, мтор_, --, --, 
   {{0x9f4800f7,0xe89402d5,0xdb0c2cd8,0x3e4803e0}},	//   rebé_, _разь, _rebé, nşta_, 
   {{0x68e82cd9,0xe3b0007b,0xdb0c2cda,0xe2980114}},	//   _iped, جرة_, _sebé, мао_, 
   {{0xe8d0146b,0x3f8c01a6,0x21a42cdb,0x00000000}},	//   _समुच, žduk_, кинм, --, 
   {{0xa1142cdc,0x1fa800bc,0x00000000,0x00000000}},	//   پوست, कर्ड, --, --, 
   {{0x6f040332,0x3914030d,0x00000000,0x00000000}},	//   _arhc, _умăр, --, --, 
   {{0x25dc1b42,0x68e80083,0x7018177b,0xe3642cdd}},	//   क्री_, _mped, ніст_, _икли, 
   {{0x9e642cde,0xdb0c003e,0x9f480158,0x00000000}},	//   نارن, _tebé, ndbø_, --, 
   {{0xe8d0032c,0x9f580240,0x68e803ac,0x05100154}},	//   _समूच, _hapë_, _oped, িনীর_, 
   {{0x6f0402c4,0x9f58036e,0x1278010f,0xd7d001f9}},	// [28c0] _erhc, _kapë_, _קאפע, _सालच, 
   {{0x9f580023,0xbbcc012c,0xb7bc00de,0x2bdc00bc}},	//   _japë_, ालेक, _koģe, न्ला, 
   {{0x68e82cdf,0x00000000,0x00000000,0x00000000}},	//   _aped, --, --, --, 
   {{0x01b0015b,0xdb0801e1,0x00000000,0x00000000}},	//   _কাঁদ, _ènít, --, --, 
   {{0x68e81529,0xec1000d1,0xdca400d8,0x00000000}},	//   _cped, _گۈلد, _јаги, --, 
   {{0x913808a8,0xe9800131,0x69dc0432,0x8ba026ef}},	//   וענק, сқун, _ösen, _вирж, 
   {{0x68e80428,0x24a4001f,0x2b900d73,0x291801ab}},	//   _eped, _ለሁለት_, _ایمس, _àsan_, 
   {{0x24800020,0x35f42830,0xd498016c,0x7e64004c}},	//   _ከሁለት_, упир, мро_, noip, 
   {{0xaa640108,0x00000000,0x00000000,0x00000000}},	//   _стёк, --, --, --, 
   {{0x7e642ce0,0x98742377,0x00000000,0x00000000}},	//   hoip, _рубљ, --, --, 
   {{0x1db02ce1,0x0bb402e4,0xd774007b,0x00000000}},	//   जरात, כלים_, _شائع, --, 
   {{0x27e82ce2,0xd7d007c1,0x68e8035a,0x7e6400e4}},	//   đane_, _साँच, _yped, joip, 
   {{0xc5101291,0xccd002dd,0x00000000,0x00000000}},	//   _نبوت, _ﻓﻘﺎل_, --, --, 
   {{0xbbcc0303,0x93040798,0x00000000,0x00000000}},	//   ालोक, _аџил, --, --, 
   {{0x1cdc031c,0x92e8036b,0x704401ec,0xd5e00208}},	//   _རཱུ_, _آرتق_, _ەرجە, _giọ, 
   {{0x7e640618,0xfda40640,0xa34c0419,0x9268030d}},	//   goip, ијум, ščák, _юрла_, 
   {{0xd7d000af,0x9f5802bd,0xdd000205,0x00000000}},	// [28d0] _सांच, _lapè_, ğuğu, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x68e82ce3,0x7e64073c,0xbf1416c8,0xe9440214}},	//   _sped, boip, _күрә, گرای, 
   {{0x6a70005c,0xa93401f4,0x00000000,0x00000000}},	//   råfo, лееш, --, --, 
   {{0x6e2c2ce4,0xe9441272,0xf9901ec7,0x2c74009f}},	//   mkab, درای, زبن_, _مُحس, 
   {{0x6e2c2ce5,0x9200002b,0x00000000,0x00000000}},	//   lkab, _śālm, --, --, 
   {{0x2ba82ce6,0xba74075e,0x6e2c009f,0x48ec033f}},	//   _च्या, _چاقت, okab, _इनको_, 
   {{0xba74247f,0xcd440020,0x9f48143a,0xa2e408ca}},	//   _ناقت, _በመንፈ, rdbø_, қомд, 
   {{0x68e82ce7,0x6e2c2ce8,0x9f58036e,0xa95400f3}},	//   _uped, ikab, _papë_, _сваљ, 
   {{0x7e642ce9,0x6e2c2cea,0xa9240154,0x00000000}},	//   zoip, hkab, _মেথড_, --, 
   {{0x6e2c2ceb,0xe2842cec,0x7e6401c8,0x0510015b}},	//   kkab, ллои, yoip, িনের_, 
   {{0xa0a41fd6,0xe3b00014,0x65942ced,0x36342cee}},	//   ламд, جرک_, _саду, _پرمس, 
   {{0x6e2c0067,0xdce40153,0x7e6401f4,0x00000000}},	//   dkab, _pykč, voip, --, 
   {{0x9f580098,0x63042cef,0x6e2c0fda,0xd2a401ec}},	//   _hapé_, _موتل, ekab, _өкше_, 
   {{0x7e642cf0,0xd0040276,0x6e2c0009,0xa2e42cf1}},	//   toip, ыере_, fkab, _сойд, 
   {{0x6e2c2cf2,0x3e7c01e4,0x645c0264,0x3d00190e}},	//   gkab, _oƭte_, ésif, रिले_, 
   {{0xdca42cf3,0x7e642cf4,0x80e8000d,0x6d4006be}},	// [28e0] уази, roip, _ओहिओ_, _əlag, 
   {{0x6e2c0099,0x1c0c2cf5,0x00000000,0x00000000}},	//   akab, साइल_, --, --, 
   {{0x6e44022c,0x7e642cf6,0x6e2c2cf7,0x8f9800df}},	//   útbú, poip, bkab, _ריטי, 
   {{0x6e2c2cf8,0x9f5802e2,0xb4f801ad,0xd1d40092}},	//   ckab, _rapè_, ्टमय_, _ርዳታ_, 
   {{0x9f582b1d,0x3c2400ac,0x1cdc0327,0x394008c2}},	//   _sapè_, _dövr_, _རཱི_, àis_, 
   {{0x7d040516,0xb8dc007d,0x99840165,0x3ce00356}},	//   mvis, _आब_, skoů_, mtiv_, 
   {{0x3ce02165,0xda00000d,0x00000000,0x00000000}},	//   ltiv_, _रोअत_, --, --, 
   {{0xceb00302,0x9f582cf9,0x7d042cfa,0xb3680023}},	//   זיה_, _capé_, ovis, _ሳንዱቕ_, 
   {{0x7d0417f9,0x3ce02cfb,0x25b808a7,0xbec40055}},	//   nvis, ntiv_, ðsla_, _śīly, 
   {{0x7d042cfc,0x28c82cfd,0x88800120,0x00000000}},	//   ivis, _रिति, _глуж, --, 
   {{0x7d04049b,0x32542cfe,0x3ce000c5,0x97540063}},	//   hvis, ивор, htiv_, _стаљ, 
   {{0x3ce02cff,0xdb0c02f0,0x6e2c2d00,0x00000000}},	//   ktiv_, _nebí, xkab, --, 
   {{0xc5f00302,0x6e2c0083,0xc1b80a89,0xca200150}},	//   _לדף_, vkab, ылях_, _ﺸﻁﺏ_, 
   {{0x6d4003b9,0x00000000,0x00000000,0x00000000}},	//   _əlad, --, --, --, 
   {{0xdb0c04d4,0x1c0c0ce0,0x765c00e4,0x7d042d01}},	//   _bebí, साईल_, _êrys, evis, 
   {{0x7d042d02,0x8d840137,0x712404b3,0x21340129}},	//   fvis, гузд, _نىعم, êché_, 
   {{0xdb0c09ff,0x661c023a,0x629413d5,0x7d042d03}},	// [28f0] _debí, öski, ízov, gvis, 
   {{0x6e2c019b,0x6e980798,0x00000000,0x00000000}},	//   skab, _ивор_, --, --, 
   {{0x7d042d04,0xbca80075,0x00000000,0x00000000}},	//   avis, ندەك_, --, --, 
   {{0x7d040e8a,0x2d4c01e4,0xf3e80154,0xe4e40037}},	//   bvis, _tɾe_, _কোমর_, _कहलि_, 
   {{0x3ce02d05,0xab940212,0x9f580129,0x7c84084c}},	//   ctiv_, _вигі, _rapé_, руӂе, 
   {{0x2ca8034c,0xfbcc00bd,0x9f58026c,0x6d5c2d06}},	//   mpad_, র্বত, _sapé_, _ixsa, 
   {{0x2ca82d07,0x9c60215c,0x00000000,0x00000000}},	//   lpad_, _بۇلو, --, --, 
   {{0xc214013f,0x00000000,0x00000000,0x00000000}},	//   _ahɔn_, --, --, --, 
   {{0xdee41e38,0xe57807d6,0x2ca80b4f,0x7d0009c2}},	//   ዝብና_, ъзи_, npad_, _ámst, 
   {{0xa4442d08,0xe2e4003b,0x00000000,0x00000000}},	//   рнод, ажоп, --, --, 
   {{0x9f582d09,0x7d0405b8,0x6378136b,0xa2e4013e}},	//   _tapé_, zvis, ъсир_, шонд, 
   {{0xf7482d0a,0x7d042d0b,0x2ca81ef9,0x6d5c2d0c}},	//   _حلمي_, yvis, kpad_, _oxsa, 
   {{0x25ac2d0d,0x23dc12eb,0x2ca8007c,0x00000000}},	//   mbel_, _मापद, jpad_, --, 
   {{0x7d042d0e,0x645c2d0f,0x2ca8079b,0xe0e40086}},	//   vvis, ésid, dpad_, _òòmo_, 
   {{0xc4442d10,0x6d5c2d11,0x81c00eac,0x7d042d12}},	//   _لیکن_, _axsa, ুভব_, wvis, 
   {{0x630416cb,0x3ce0038f,0x7d042d13,0x25ac2b92}},	//   _موڪل, ttiv_, tvis, nbel_, 
   {{0x25ac04fb,0x1c442d14,0x7d040194,0x2ca82d15}},	// [2900] ibel_, анам, uvis, gpad_, 
   {{0xdb0c2d16,0x09e000fe,0x00000000,0x00000000}},	//   _rebâ, _নোলা, --, --, 
   {{0x3ce02d17,0x7d042d18,0x6d5c2d19,0x25ac2d1a}},	//   stiv_, svis, _exsa, kbel_, 
   {{0x7d042d1b,0x25ac0196,0xd9d02ba5,0x3f942d1c}},	//   pvis, jbel_, تەرگ, şbuğ_, 
   {{0xa04002d3,0x25ac00f3,0x6aa80010,0xd8f4010b}},	//   _ኣብነታ, dbel_, _čefe, рчеь, 
   {{0x25ac2d1d,0x00000000,0x00000000,0x00000000}},	//   ebel_, --, --, --, 
   {{0xb90800aa,0x19b80276,0x00000000,0x00000000}},	//   _څښتن_, _аузь_, --, --, 
   {{0x27e81326,0x34b412d7,0x25ac017a,0xd7d00d26}},	//   đana_, ббиё, gbel_, _साकच, 
   {{0x15e00574,0x8e34010f,0x73c401e0,0xfbcc00eb}},	//   क्षर_, ינקא_, бәйе, র্ণত, 
   {{0x3a240156,0x25ac2d1e,0x28740022,0x71400023}},	//   _homp_, abel_, _лыхр, _ኣስማቶ, 
   {{0xd3782d1f,0x14c00073,0xf2e82d20,0x61e4002f}},	//   ъчи_, _शिकण, اکته_, ffkl, 
   {{0x2ca82d21,0x3a240165,0xabdc0150,0x6d4006be}},	//   ypad_, _jomp_, _ﺇﻫﻤﺎ, _əlab, 
   {{0x32040118,0x00000000,0x00000000,0x00000000}},	//   ěly_, --, --, --, 
   {{0x10482d22,0x3a240b4f,0x50642d23,0x68ec0798}},	//   тями_, _lomp_, ртма, çadi, 
   {{0xc05810f5,0x645c2d24,0x25dc08e9,0xcdd8041b}},	//   рія_, ésie, क्की_, кња_, 
   {{0x7bdc2d25,0x2ca8017a,0x3a242d26,0x82641fb8}},	//   _acru, tpad_, _nomp_, _وهون, 
   {{0x8d8401d5,0x00000000,0x00000000,0x00000000}},	// [2910] рувд, --, --, --, 
   {{0x2ca806a3,0x0ba42d27,0x00000000,0x00000000}},	//   rpad_, ршам, --, --, 
   {{0xd1bc0020,0x25ac0af9,0x6e9401c8,0xadbc00c0}},	//   _ሶስት_, ybel_, _دلجا, _панi, 
   {{0x2ca801e6,0x7bdc0857,0x3a242d28,0x3df400c0}},	//   ppad_, _ecru, _comp_, _дзюс, 
   {{0x3a240165,0x2248002e,0x00000000,0x00000000}},	//   _domp_, _ňakk_, --, --, 
   {{0x3a240156,0x7bdc00c6,0x8aa42d29,0x067c06ba}},	//   _eomp_, _gcru, _врад, ﺯﯨﻨﯩ, 
   {{0x26c02d2a,0x25ac08cd,0x7afc05b1,0x4b500014}},	//   ého_, tbel_, _gsrt, _بێار, 
   {{0x26c82d2b,0xa3a82d2c,0x25ac2d2d,0x3a240165}},	//   čao_, गुन_, ubel_, _gomp_, 
   {{0xa4442d2e,0x7bdc0083,0x69d82d2f,0x693401ee}},	//   йнид, _ycru, mgwe, _унау, 
   {{0xc6e4090b,0x7bdc034c,0x3a240165,0x69d8030a}},	//   _відп, _xcru, _zomp_, lgwe, 
   {{0x9f5808e5,0xe3642d30,0x25ac257c,0xa348041b}},	//   _capì_, скни, pbel_, узна_, 
   {{0xe1f000c6,0x61e40112,0x394001c3,0xa4d400d4}},	//   أسد_, ufkl, ùisg_, _годі, 
   {{0x64a42d31,0x661c01a8,0x9c800118,0x69d80142}},	//   _уала, ösku, řčic, igwe, 
   {{0x8fa01dde,0xa878008f,0x00000000,0x00000000}},	//   заре, טאָר, --, --, 
   {{0x69d82d32,0xb80400cd,0x7bdc003a,0x28d0033f}},	//   kgwe, _adṛś, _rcru, _समझि, 
   {{0x7bdc2d33,0xdb0c0306,0x629401e4,0xfb1801d9}},	//   _scru, _nebá, ŭzos, یراں_, 
   {{0x3a242d34,0x9b9400cf,0x6284002f,0xa29c012d}},	// [2920] _romp_, مشاش, mmko, _ऐंड्, 
   {{0xd37c1505,0xdec000b7,0x3a24002e,0x69d801f5}},	//   šćem_, ትሪክ_, _somp_, egwe, 
   {{0x5f042d35,0x3a242d36,0x9f58007f,0x9f041077}},	//   _узна, _pomp_, _enpò_, _اوجو, 
   {{0xd6d8016c,0x69d80337,0x5984034f,0x00000000}},	//   ҳти_, ggwe, блеб, --, 
   {{0x98480816,0x1cb800e3,0xdb0c2d37,0x62842d38}},	//   ляка_, _حاجب_, _debá, imko, 
   {{0xd6d82d39,0x69d82d3a,0x00000000,0x00000000}},	//   гти_, agwe, --, --, 
   {{0x69d80099,0x3d002d3b,0xfe1c1df1,0x00000000}},	//   bgwe, रिके_, _पचास_, --, 
   {{0xc214013f,0x9f58026c,0x628401e4,0x09e02d3c}},	//   _nnɔ_, _rapì_, jmko, _носн, 
   {{0xd4042cf1,0x00000000,0x00000000,0x00000000}},	//   бяни, --, --, --, 
   {{0x96b82d3d,0x93242c10,0x62842d3e,0x00000000}},	//   _буду_, مرجن, emko, --, 
   {{0x2bdc0b4c,0x36180330,0x9d0400eb,0x87941e24}},	//   न्टा, _پراگ_, োনয়ন_, _اَمر_, 
   {{0x78a40356,0xb33c031c,0xc1ac07d2,0x00000000}},	//   ţivu, xbħu, _ﺳﯩﺮﺍ, --, 
   {{0x9148188b,0x645c2d3f,0x0678008f,0x9f480fac}},	//   учна_, ésic, _ענדל, nebæ_, 
   {{0x6e9406ed,0x6284017a,0x69d80165,0x067c2d40}},	//   живу, amko, zgwe, ﺯﯨﻠﯩ, 
   {{0x62940115,0x00000000,0x00000000,0x00000000}},	//   ŭzor, --, --, --, 
   {{0x28c8146c,0x99840306,0x00000000,0x00000000}},	//   _रिलि, zkoš_, --, --, 
   {{0x261803ce,0xb33c031c,0x00000000,0x00000000}},	// [2930] भाती_, rbħu, --, --, 
   {{0x09b000dc,0xada401e0,0xdb0c299d,0x69d80142}},	//   ुण्य, саҡл, _sebá, wgwe, 
   {{0xaab402bf,0x9f5800e4,0x00000000,0x00000000}},	//   ійді, _yapí_, --, --, 
   {{0x69d8030a,0x2bdc28f5,0x00000000,0x00000000}},	//   ugwe, न्जा, --, --, 
   {{0x69d82d41,0xa9680640,0x7c2c2b96,0x00000000}},	//   rgwe, јила_, ålrø, --, 
   {{0x69d82d42,0x00000000,0x00000000,0x00000000}},	//   sgwe, --, --, --, 
   {{0xe7382d43,0x62842d44,0x00000000,0x00000000}},	//   рей_, ymko, --, --, 
   {{0xe7f4068f,0x998404a7,0x00000000,0x00000000}},	//   _इसका_, skoš_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x68ec067c,0x394000a3,0x00000000,0x00000000}},	//   çadu, ùise_, --, --, 
   {{0x38602d45,0x29001d76,0xc5b0009d,0x00000000}},	//   éire_, āhau_, _ерлө, --, 
   {{0x290c2d46,0x7b200960,0x26c00306,0xaad000c5}},	//   _krea_, _ušuš, áhou_, _हिनक, 
   {{0x291c0921,0x62842d47,0x00000000,0x00000000}},	//   nxwa_, rmko, --, --, 
   {{0xdfd000c6,0x628401e4,0xb46401ec,0x00000000}},	//   بيس_, smko, _екіл, --, 
   {{0x683c026c,0x69c80a55,0xa3a817ee,0x44242d48}},	//   _ièdd, _odee, गुण_, _ion_, 
   {{0x6d0402ab,0x290c005a,0x00000000,0x00000000}},	//   रिंग_, _orea_, --, --, 
   {{0x44242d49,0x62541ebd,0x9c24192a,0xdb980640}},	// [2940] _kon_, tšof, одад, атељ_, 
   {{0x69c814cc,0x44242d4a,0xee38013e,0x1bb82d4b}},	//   _adee, _jon_, анӣ_, شائع_, 
   {{0x44242d4c,0x290c2d4d,0x62840395,0x8af403b9}},	//   _mon_, _area_, _èhos, _üəll, 
   {{0x290c2d4e,0x8f780375,0xd98002dd,0x00000000}},	//   _brea_, _כניק, _ﺩﻭﺭﻩ_, --, 
   {{0x290c2d4f,0x44242d50,0x69c80334,0x9aa80131}},	//   _crea_, _oon_, _ddee, انچە_, 
   {{0x44242d51,0x69c82d52,0x00000000,0x00000000}},	//   _non_, _edee, --, --, 
   {{0x290c005a,0x3e480311,0x00000000,0x00000000}},	//   _erea_, eşti_, --, --, 
   {{0x44242d53,0x3dc00295,0x290c2d54,0xcf900375}},	//   _aon_, naiw_, _frea_, וטו_, 
   {{0x290c0276,0x94842d55,0x76900124,0xa8a42d56}},	//   _grea_, жынд, _ẽysa, _فصلو, 
   {{0x1cdc0156,0xdb0c013c,0x93882d57,0x00000000}},	//   _རཱན_, _vebæ, исна_, --, 
   {{0x44242d58,0x69c800b5,0x645c2d59,0x8c38002f}},	//   _don_, _ydee, ésia, _fußf, 
   {{0x44242d5a,0x00000000,0x00000000,0x00000000}},	//   _eon_, --, --, --, 
   {{0x44242d5b,0xc21800d6,0xdf480020,0x268800aa}},	//   _fon_, ією_, _አስፈፃ, _اخلي_, 
   {{0xdb1c0120,0x00000000,0x00000000,0x00000000}},	//   rapê, --, --, --, 
   {{0x22a404fe,0x7f942d5c,0x00000000,0x00000000}},	//   _pēke_, дарх, --, --, 
   {{0xd1b80133,0x00000000,0x00000000,0x00000000}},	//   _ئاغا_, --, --, --, 
   {{0x44242d5d,0xc0d8001f,0xd36c05a9,0xbd680064}},	// [2950] _yon_, ርቧል_, _سۇڭ_, орфе_, 
   {{0x44242d5e,0xaa5001e1,0x00000000,0x00000000}},	//   _xon_, _ṣàá_, --, --, 
   {{0x94f8003d,0x7ac41064,0xdb1c004e,0xf9900133}},	//   _དགའི_, дсче, napè, ۆبه_, 
   {{0x290c2d5f,0x7b640801,0x88f00150,0x00000000}},	//   _prea_, фтуе, дікә, --, 
   {{0xf9900dc3,0xdde801b9,0xdb1c00e4,0x00000000}},	//   نبه_, _ارپه_, hapè, --, 
   {{0x290c00a8,0x68441719,0xa52401f0,0x00000000}},	//   _vrea_, янла, ҷмид, --, 
   {{0x44242d60,0xbb58030d,0x3cdc0210,0x00000000}},	//   _ron_, _дарх_, गूठे_, --, 
   {{0x44242d61,0x290c2d62,0xdb1c0ba1,0xe618039b}},	//   _son_, _trea_, dapè, сди_, 
   {{0xaa44010b,0x290c0f85,0xa2bc2d63,0x00000000}},	//   _деңл, _urea_, वीन्, --, 
   {{0x44242d64,0x9f5801e1,0xe85801f7,0x00000000}},	//   _qon_, _lapá_, _اسرڻ_, --, 
   {{0x44242d65,0xdb0c2d66,0x683c0129,0x00000000}},	//   _von_, _gebä, _cède, --, 
   {{0x44242d67,0x8c380e78,0x63e401e2,0x00000000}},	//   _won_, _fußg, _کېدې_, --, 
   {{0x44242d68,0x250800f2,0x00000000,0x00000000}},	//   _ton_, _درای_, --, --, 
   {{0x9f582d69,0x44242d6a,0x25bc015d,0x26182d6b}},	//   _papà_, _uon_, _hewl_, भावी_, 
   {{0xe7ec2d6c,0x25bc2d6d,0xe2c800aa,0xdb1c2d6e}},	//   च्या_, _kewl_, _اوبو_, capè, 
   {{0xdd900736,0xdca40124,0x5ca400c7,0xdb1c0200}},	//   ّور_, зааи, зиаб, sapë, 
   {{0x8d600961,0x3dc00036,0xd83c00d0,0xa0c401f7}},	// [2960] евте, raiw_, účka_, _عيدو, 
   {{0x62942d6f,0xe9e40589,0x2d9800a2,0x28e40150}},	//   _hiyo, åºno_, _egse_, _ﺍﺴﺘﻠ, 
   {{0x62942d70,0x4f980375,0x60c4143a,0x00000000}},	//   _kiyo, _לביצ, lskm, --, 
   {{0x62942d71,0x25bc031c,0xdb1c2d72,0x00000000}},	//   _jiyo, _newl_, napé, --, 
   {{0x62942d73,0xdb0c09a5,0xdd902d74,0x60c42d75}},	//   _miyo, _sebä, _سوس_, nskm, 
   {{0x62942d76,0xe9800075,0xdb1c0124,0x00000000}},	//   _liyo, тқун, hapé, --, 
   {{0x8f980bd9,0x62940428,0x91c400cc,0x00000000}},	//   זיצי, _oiyo, ষ্টখ, --, 
   {{0xaad021b8,0x39842d77,0xdb1c00e4,0x00000000}},	//   _हितक, _قیاف, japé, --, 
   {{0xdb1c00d8,0x00000000,0x00000000,0x00000000}},	//   dapé, --, --, --, 
   {{0x6294037e,0x81d4009e,0x00000000,0x00000000}},	//   _aiyo, স্ম_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x62942d78,0xdb1c2d79,0xe6b401b9,0x46a00006}},	//   _ciyo, rapè, _آلنگ, _чацв, 
   {{0x62942d7a,0x9f5800d8,0xd468252c,0x26181d94}},	//   _diyo, _rapá_, _лиде_, भारी_, 
   {{0xc950025f,0x4ea405f5,0x629404ce,0x9f580241}},	//   תמש_, зраа, _eiyo, _sapá_, 
   {{0x9f582d7b,0x62942d7c,0xa91c0010,0x0874008f}},	//   _papá_, _fiyo, _izže, פעלט_, 
   {{0xdb1c2d7d,0x62942d7e,0x6fb400ec,0x76400051}},	//   capé, _giyo, _ڪمدا, nhmy, 
   {{0x8d740597,0xd24c00aa,0xd8600521,0xac942d7f}},	// [2970] سارا, _لنډ_, zọọt, дааш, 
   {{0x6294023b,0x00000000,0x00000000,0x00000000}},	//   _ziyo, --, --, --, 
   {{0x6db4010b,0x9f5801e1,0x00000000,0x00000000}},	//   _ойну, _tapá_, --, --, 
   {{0x62942d80,0x69cc2d81,0x3eac00d7,0xefe800e5}},	//   _xiyo, दृढी, ídte_, _اٹھو_, 
   {{0x8c3809f0,0xbb5000b5,0x202803b2,0x23dc1b76}},	//   _auße, _comサ_, _útið_, _मालद, 
   {{0x6d4003b9,0x00000000,0x00000000,0x00000000}},	//   _əlal, --, --, --, 
   {{0xca7426c0,0x261800e1,0x00000000,0x00000000}},	//   _فارغ, भाली_, --, --, 
   {{0xcfe000cc,0x45a00145,0xff18011a,0x00000000}},	//   য়িন, رەتك, לקות_, --, 
   {{0xc9840323,0x62942d82,0x3a8402d5,0x645c00d8}},	//   _хуви, _riyo, _чырв, ésio, 
   {{0x62942d83,0x7e9c02b5,0xd860063f,0x8c38002f}},	//   _siyo, _hōpe, pọọt, _fuße, 
   {{0x62942d84,0x7e9c0374,0xdb1c2d85,0x00000000}},	//   _piyo, _kōpe, tapé, --, 
   {{0x1c080574,0x629407d6,0x764003cb,0x221402a9}},	//   _होईल_, _qiyo, chmy, ффор, 
   {{0xdb1c2d86,0x66082d87,0x22a400ef,0x62942d88}},	//   rapé, mdek, _dēka_, _viyo, 
   {{0x66082d89,0xdfd000c6,0x62942d8a,0x60c42d8b}},	//   ldek, ضير_, _wiyo, rskm, 
   {{0x2cb80003,0x62942d8c,0xb4242d8d,0x64402d8e}},	//   _བསུབ, _tiyo, _سعوو, mhli, 
   {{0x7e9c00b0,0xa3a82d8f,0x6440014f,0x8c38002f}},	//   _nōpe, गुर_, lhli, _nußb, 
   {{0x6144119e,0xd0640150,0x00000000,0x00000000}},	// [2980] _цепа, _ﺍﻳﯩﭗ_, --, --, 
   {{0x64402d90,0x660802f6,0x5f7400d1,0xdbc401e3}},	//   nhli, hdek, _يادر, _lööf, 
   {{0x66082d91,0x20182d92,0x1e842b2d,0x50180a7c}},	//   kdek, _inpi_, _олом, _וויו, 
   {{0xa2d42d93,0xceb006a9,0x6e3c0477,0x00000000}},	//   _भिन्, _שיר_, _glsb, --, 
   {{0x66082252,0x2018020b,0x64400067,0x00000000}},	//   ddek, _knpi_, khli, --, 
   {{0x645c07ea,0x66080373,0xdf240150,0xf63c00d1}},	//   ésil, edek, _ءﯨﻨﯩ, ﻟﻼﮬ_, 
   {{0xda641216,0x64400571,0x8c380730,0x6d4000ac}},	//   _قاري, dhli, _fußb, _əlam, 
   {{0x66082d94,0x6440002f,0x069002dd,0xe3d400eb}},	//   gdek, ehli, _ﺟﺎﻧﯩ, ত্মব, 
   {{0xdb0c2d95,0xb7bc005f,0x6ba401e3,0x349402e8}},	//   _nebú, _loģi, _åtgå, наир, 
   {{0x64402d96,0x660800ab,0x20080010,0xa3a82ca5}},	//   ghli, adek, jdbi_, गुल_, 
   {{0x78a00223,0x95c80124,0x660801e4,0x8bd4010f}},	//   _humv, _дула_, bdek, וויו_, 
   {{0x78a02d97,0x51840323,0x20182d98,0x34940022}},	//   _kumv, дуга, _anpi_, ьаҿр, 
   {{0x64402d99,0x63ac2d9a,0x00000000,0x00000000}},	//   bhli, _şane, --, --, 
   {{0x64402d9b,0xdb0c2d9c,0x78a02d9d,0x84100022}},	//   chli, _debú, _mumv, _амшх, 
   {{0xb8e00ed9,0x78a00455,0x2c440022,0x00000000}},	//   _ཁས_, _lumv, ҕьаҳ, --, 
   {{0x27e81326,0x201802bd,0x63ac0e04,0x15e02c33}},	//   đani_, _enpi_, _đani, क्चर_, 
   {{0x78a0015c,0x7e9c02b5,0x313400a8,0xc1bc011a}},	// [2990] _numv, _rōpe, _чепр, _ומחש, 
   {{0x660803ee,0x32082d9e,0x4ea404a2,0x4bd800f2}},	//   zdek, _haay_, _орма, تبرد_, 
   {{0x0a682d9f,0x32082da0,0xbb840116,0x00000000}},	//   орди_, _kaay_, _ﺩﺍﻧﻪ_, --, 
   {{0x78a02da1,0x6f04036b,0x32080694,0x644000d7}},	//   _bumv, _ishc, _jaay_, zhli, 
   {{0x78a02da2,0x32082da3,0x66082da4,0xf8a81046}},	//   _cumv, _maay_, vdek, ودوه_, 
   {{0x78a0010f,0x32082da5,0x01380375,0x5c700139}},	//   _dumv, _laay_, ורדת_, _бһут, 
   {{0x645c2da6,0x66082da7,0xe5a40075,0xd1c402d3}},	//   ésim, tdek, нийи, ጽንታ_, 
   {{0x3208089c,0x66082da8,0xd90c00dd,0xba900150}},	//   _naay_, udek, جیے_, _ﺑﺎﻳﮕ, 
   {{0x9f58025a,0x64402da9,0x27e80b45,0x00000000}},	//   _zapä_, thli, ƙan_, --, 
   {{0x68e801f0,0xe3b00597,0x64400007,0xb7fc07f7}},	//   _iqed, درة_, uhli, _एसएम_, 
   {{0x32082daa,0x78a02dab,0x66082dac,0xfbcc0154}},	//   _baay_, _zumv, pdek, র্কত, 
   {{0x78a00516,0x21682dad,0x3208058a,0x64402dae}},	//   _yumv, зими_, _caay_, shli, 
   {{0xdb0c0086,0x6f040c8c,0x10a02daf,0x78a00218}},	//   _debù, _ashc, лиян, _xumv, 
   {{0xe2c82db0,0xc44401d5,0x7018187f,0xe3b000ae}},	//   _فوتو_, _آیدن_, міст_, _صرت_, 
   {{0x32082db1,0x5e9400c6,0x00000000,0x00000000}},	//   _faay_, فلسط, --, --, 
   {{0x68e8014b,0x320800e8,0x00000000,0x00000000}},	//   _oqed, _gaay_, --, --, 
   {{0xa2d4012c,0x0e600166,0x00000000,0x00000000}},	// [29a0] _भिड्, уктн, --, --, 
   {{0x9f480158,0x78a0005c,0xa6c40154,0x202002f0}},	//   kebø_, _rumv, _এমনট, ásič_, 
   {{0x68e801f0,0x78a00c86,0x9f482d8b,0x32082da0}},	//   _aqed, _sumv, jebø_, _yaay_, 
   {{0xda641b45,0x320817bb,0x78a0047e,0xfbd005d9}},	//   راضي, _xaay_, _pumv, _چڪا_, 
   {{0x683c0066,0x78a0047e,0xb3740023,0xfbd000ec}},	//   _sèda, _qumv, _ራዕድን_, _نڪا_, 
   {{0x78a00810,0x36d42db2,0x683c007f,0xdb1c1aa9}},	//   _vumv, вокр, _pèda, lapí, 
   {{0x8c1804ac,0x78a0015c,0x68e801f0,0xcb642db3}},	//   _צולי, _wumv, _eqed, _заре_, 
   {{0x65780142,0xdb1c0f91,0x4b78010f,0x00000000}},	//   _bywh, napí, _זאלו, --, 
   {{0x3208002e,0xd0c80011,0x2ab40248,0xa2bc21b8}},	//   _raay_, _লঙ্ঘ, _túbò_, वीस्, 
   {{0x32082db4,0x4d6800d1,0x335400cf,0x00000000}},	//   _saay_, ﺳﯩﯟﯨ, күлө_, --, 
   {{0x320801f5,0xa91c0427,0x56f002dd,0x142402dd}},	//   _paay_, _izža, _сүйс, _үдем, 
   {{0xb0a405f9,0xdb1c00c7,0x154400d8,0x00000000}},	//   _गंदग, japí, _пеем, --, 
   {{0x50640b2b,0x63800022,0x2c2c0023,0x00000000}},	//   етва, лҳәа, _ተዛሪቡ, --, 
   {{0x32082db5,0x518408ca,0x161c0b4c,0x00000000}},	//   _waay_, дуҳа, भावर_, --, 
   {{0x320800e8,0x27f003e0,0x00000000,0x00000000}},	//   _taay_, _özne_, --, --, 
   {{0xa2d42db6,0xd6b002f5,0xdb1c0407,0xc0d00023}},	//   _भित्, _ঘটায, gapí, እሶም_, 
   {{0x6c740114,0x00000000,0x00000000,0x00000000}},	// [29b0] влађ, --, --, --, 
   {{0xac1800d4,0x6d4003e3,0x00000000,0x00000000}},	//   ьозу_, _əlah, --, --, 
   {{0xbf140131,0x6f0402d0,0x00000000,0x00000000}},	//   _йүрә, _ushc, --, --, 
   {{0xba740244,0x00000000,0x00000000,0x00000000}},	//   هانت, --, --, --, 
   {{0x645c003e,0x5ea40154,0x00000000,0x00000000}},	//   ésik, গীদে, --, --, 
   {{0x7e9c04fe,0x776801f5,0x98a02db7,0x9f4803cd}},	//   _hōpa, _bxdx, шише, tebø_, 
   {{0x7e9c04fe,0x1c082db8,0xaa582db9,0xd1b80020}},	//   _kōpa, _होटल_, _живу_, ዳሉት_, 
   {{0x9f482dba,0xb9c4009f,0x00000000,0x00000000}},	//   rebø_, _مقفي, --, --, 
   {{0x68e80107,0x9f4803cd,0x753401c6,0x94e40ed8}},	//   _uqed, sebø_, гээх, نکوف_, 
   {{0xa2d400dc,0xdb1c02f0,0x22500d2e,0x00000000}},	//   _भिद्, zapí, _smyk_, --, 
   {{0x33f40598,0xb9cc001f,0xe3642dbb,0x00000000}},	//   учыс, _ዳቦ_, ткни, --, 
   {{0x27e82625,0xa0a42dbc,0x55501176,0xc4dc00cc}},	//   đanu_, камд, اپیر, _ভনীজ, 
   {{0xa5082dbd,0x00000000,0x00000000,0x00000000}},	//   _цела_, --, --, --, 
   {{0xa0682dbe,0x910016a4,0x2a7c015d,0x00000000}},	//   фага_, јпре, hlwb_, --, 
   {{0xd4642dbf,0x44e803b2,0xdee40107,0x00000000}},	//   _шише_, lø_, ъови, --, 
   {{0x5254035b,0x645c0066,0xd12c00f1,0x9f480241}},	//   _ахьӡ, èsif, _ژمي_, _àjín_, 
   {{0xa2bc00cd,0x44e801bf,0xc0d00023,0x00000000}},	// [29c0] वीर्, nø_, እቶም_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2b38084c,0xa13413de,0xdb1c295a,0xe7240133}},	//   няцэ_, _سرکش, papí, _اڵ_, 
   {{0x44e81347,0x5d84007b,0x48700271,0x81d40154}},	//   kø_, _للجل, یدوس, স্র_, 
   {{0x17080489,0x61f4044e,0x09e02dc0,0xd9442dc1}},	//   _གནངམ_, _mbyl, рочн, ъеди, 
   {{0x2b4c0118,0xdb1c0022,0x00000000,0x00000000}},	//   _řece_, rapâ, --, --, 
   {{0x7d042dc2,0xca742dc3,0x5a942dc4,0xd6c00ec9}},	//   lwis, رمۇش_, _араф, جمعی, 
   {{0x26182dc5,0xd0b006be,0x89d401f7,0x00000000}},	//   भागी_, _eşəl, _لوفر_, --, 
   {{0x18a42dc6,0x7d042dc7,0x57e82dc8,0x6254000a}},	//   _разм, nwis, _одам_, tšon, 
   {{0xa4900424,0x61f42dc9,0x72d000d1,0x975400f3}},	//   مینت, _abyl, مەتچ, _итељ, 
   {{0x7d042dca,0x07a00e4e,0x00000000,0x00000000}},	//   hwis, _тахн, --, --, 
   {{0x9fa40184,0x44e82dcb,0x06900046,0x3ce00254}},	//   ғырҙ, bø_, _ﺟﺎﻳﯩ, kuiv_, 
   {{0x65b0052f,0x32ec013f,0x855401ed,0x7d040100}},	//   _уҡыт, _mɛyi_, _لیٹر_, jwis, 
   {{0x7e9c02b5,0x00000000,0x00000000,0x00000000}},	//   _rōpa, --, --, --, 
   {{0xb03404a9,0x0dc801a9,0xadd40063,0x9258007b}},	//   نىڭغ, дузи_, ловљ, _يشعر_, 
   {{0x7d042dcc,0x12842dcd,0x24700023,0x7e440124}},	//   fwis, _جمعی_, _ስብሓት_, ахуе, 
   {{0xe9a42dce,0x506400fd,0x7d042dcf,0x8bc4023a}},	// [29d0] қалп, _атна, gwis, всед, 
   {{0xada40032,0x61f400bc,0x261807f7,0x6fb42dd0}},	//   таҡл, _zbyl, _मोनी_, _حمدا, 
   {{0xbed801c0,0x61f801d3,0x8c380112,0x4174030f}},	//   _идэх_, őtle, _fußn, _مایس, 
   {{0x7d042dd1,0x7e9c02b1,0x00000000,0x00000000}},	//   bwis, _tōpa, --, --, 
   {{0x62540219,0xc0d80092,0x8c0800eb,0x00000000}},	//   dšol, _ይባስ_, রাবন_, --, 
   {{0xd3642dd2,0xb8d40214,0xfbcc03d4,0x00000000}},	//   _هه_, شتهش, ৰ্বত, --, 
   {{0x2ca80009,0xdb1c00e4,0x7c380254,0x00000000}},	//   lqad_, rapã, övre, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6148004a,0xe5782dd3,0x00000000,0x00000000}},	//   _mêlé, эзи_, --, --, 
   {{0x44e803d4,0x057401d5,0xdb1c2dd4,0x00000000}},	//   rø_, _یاشد, lapá, --, 
   {{0x7d042dd5,0x637800fd,0x44e821e3,0x00000000}},	//   zwis, эсир_, sø_, --, 
   {{0x9f5803a0,0x7d040034,0xdb0c0216,0x3e780092}},	//   _tapú_, ywis, _nebý, _በፖስታ_, 
   {{0x25ac007f,0xb8f400b8,0x00000000,0x00000000}},	//   mcel_, _veṇī, --, --, 
   {{0x25ac2dd6,0xc5e005f9,0xcd28001f,0x645c00f2}},	//   lcel_, _गाँठ_, ሰግናለ, èsid, 
   {{0xdb1c2dd7,0x7d040ba7,0x9e641fae,0x25ac054e}},	//   kapá, wwis, هارن, ocel_, 
   {{0x25ac2dd8,0x7d042dd9,0x6d400cc1,0x205400d1}},	//   ncel_, twis, _əlav, _әтир, 
   {{0x7d0413eb,0x212400a2,0x5d680022,0x661c007c}},	// [29e0] uwis, _çoh_, хиам_, ösky, 
   {{0x7d042dda,0x683c020c,0x5f742ddb,0x5bc42ddc}},	//   rwis, _bèdm, _ماجر, اقال, 
   {{0x7d042ddd,0x41b82dde,0xc5e005f9,0x61480129}},	//   swis, _आभास, _गांठ_, _fêlé, 
   {{0x7d042ddf,0x98a42de0,0x4e240209,0xdb1c004e}},	//   pwis, гиде, _боюн_, rapà, 
   {{0x6e280428,0x7e642de1,0x91b8011a,0x00000000}},	//   _òeba, mnip, גמני, --, 
   {{0x7e9c02b5,0x8ba000ee,0xd37c16a3,0x7b840220}},	//   _kōpo, _гирж, šćim_, _نازە, 
   {{0xd5e002e3,0xf7040724,0x7e642c4a,0x6e340cad}},	//   _nhọ, рҗем, onip, _àgbé, 
   {{0x7e642de2,0x00000000,0x00000000,0x00000000}},	//   nnip, --, --, --, 
   {{0x80a02de3,0xdb0c014a,0x7e642de4,0x44b02de5}},	//   _गंगे, _lebü, inip, ббыс, 
   {{0x26180574,0x56900220,0x7e642de6,0x036801e1}},	//   _मोठी_, шақт, hnip, _ìsọf, 
   {{0xa3e405ba,0x7e642de7,0x7e9c00b0,0xd5e0004d}},	//   _फार_, knip, _nōpo, _chọ, 
   {{0x3eb80219,0x61e401e3,0x00000000,0x00000000}},	//   dprt_, ggkl, --, --, 
   {{0x53442de8,0x27140208,0x8c080154,0xb7bc0171}},	//   _әхла, _ánh_, রাতন_, _enģe, 
   {{0xdb0c01b8,0x7afc0010,0x33940006,0x7e642de9}},	//   _bebü, _oprt, _калё, enip, 
   {{0x645c004e,0x4e8802e8,0xdb1c0162,0x40340395}},	//   èsie, ещам_, lapæ, щерс, 
   {{0xdb0c2dea,0x645c0129,0xadb42deb,0x877800df}},	//   _debü, ésiv, рбаш, גאלי, 
   {{0x26c000dd,0x6cd40228,0x8c380112,0x00000000}},	// [29f0] ához_, شقاا, _fußl, --, 
   {{0x2ca801d9,0x624400e8,0x7e642dec,0xb2fc031c}},	//   rqad_, _góob, anip, _ྐྱོང_, 
   {{0xdb0c0730,0x2ca80009,0x7c842ded,0x25e409ab}},	//   _gebü, sqad_, суте, _टाली_, 
   {{0x2d88004e,0x06900220,0x7e6401ef,0x00000000}},	//   _үйүп_, _ﺟﺎﻋﯩ, cnip, --, 
   {{0xdb1c2af5,0x6e2c2dee,0x6aa80427,0xdd900137}},	//   rapá, mjab, _čefu, _ووپ_, 
   {{0xdb1c2def,0xf9902df0,0x6d4c01a4,0x00000000}},	//   sapá, سبن_, mzaa, --, 
   {{0x6d4c2df1,0xaa9400d6,0x6f14010a,0xdb4c0014}},	//   lzaa, _вивч, nvzc, _ہێے_, 
   {{0xe6182df2,0x6d4c2df3,0x6ab402d0,0x49b80133}},	//   тди_, ozaa, _itzf, _سارد_, 
   {{0xa4440019,0x6d4c2df4,0xf62800db,0xa5640101}},	//   инид, nzaa, اسىى_, جگان, 
   {{0x22a40374,0x25ac2df5,0x6d4c2df6,0x31182314}},	//   _hēki_, scel_, izaa, दिनः_, 
   {{0x22480116,0x1cd80327,0x8c38002f,0x352802dd}},	//   впни_, _ཡྀན_, _rußl, _ەسىپ_, 
   {{0x6e2c22a9,0x62441bce,0x6d4c01a4,0x00000000}},	//   jjab, _sóob, kzaa, --, 
   {{0xcfb402a6,0xa0a42df7,0x6e2c2df8,0x644c03a2}},	//   _জয়ন, рагд, djab, _ïaio, 
   {{0x6d4c0196,0x26180b03,0x7e9c2df9,0xae0401e0}},	//   dzaa, _मोती_, _pōpo, ҙоуҙ, 
   {{0xa2e42dfa,0x6d4c2d3a,0x645c2dfb,0x612c013d}},	//   _тойд, ezaa, ésiu, _bеlä, 
   {{0x7e640481,0xdee41ee3,0xdcb02dfc,0x6d4c01f5}},	//   unip, лоҳи, قىر_, fzaa, 
   {{0x7e642dfd,0x7afc0263,0x2714000f,0xdb0c067c}},	// [2a00] rnip, _sprt, _lān_, _nebò, 
   {{0x6e2c2dfe,0x0c2000f7,0x8c380112,0x00000000}},	//   ajab, омун, _fußm, --, 
   {{0x6d4c2dff,0x27140055,0x6e2c0055,0x00000000}},	//   azaa, _nān_, bjab, --, 
   {{0x63ac2e00,0x4e002e01,0x7e640309,0x6d4c0175}},	//   _şanl, _дзюб, qnip, bzaa, 
   {{0x39402e02,0xa3b405b5,0x22500306,0x2c100073}},	//   áis_, जडा_, ézky_, _डोकं_, 
   {{0xdb0c02e2,0xfaa401b9,0x81cc00eb,0x00000000}},	//   _debò, _هجری, _লাফ_, --, 
   {{0x39402e03,0x683c0066,0x37c40184,0x1da82e04}},	//   šis_, _mèdh, _һәйб, _कलात, 
   {{0x26182e05,0xd62400c6,0xceb005d0,0x00000000}},	//   _मोदी_, شعبي, חיה_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x07a00117,0x6e2c031c,0x00000000,0x00000000}},	//   _дафн, zjab, --, --, 
   {{0x22480054,0x6d4c2e06,0x74142e07,0x7980015d}},	//   _ŋaka_, zzaa, لوکا, _hymw, 
   {{0xdb1c2e08,0xdec802d3,0x6f080210,0x00000000}},	//   mapä, ጽእን_, łeck, --, 
   {{0xdb1c2e09,0x51842e0a,0x34b42e0b,0x645c004e}},	//   lapä, руна, _امتز, èsic, 
   {{0xdb1c0137,0x645c004a,0x853802e4,0x161c02e5}},	//   capç, ésit, _בגדי, भाकर_, 
   {{0x24982e0c,0xdb1c2e0d,0x6e2c2519,0xc324007b}},	//   ïsme_, napä, tjab, _نكون_, 
   {{0x11e8092f,0x6d4c0d27,0x2370002d,0x42c400d1}},	//   _شعبي_, tzaa, ûzje_, _өгән_, 
   {{0x6e2c2e0e,0xdb1c007d,0x7980002d,0xbca80131}},	// [2a10] rjab, hapä, _nymw, ۇدەك_, 
   {{0x6d4c0936,0x29e40943,0xdb1c2e0f,0x6e2c01c6}},	//   rzaa, _ḓa_, kapä, sjab, 
   {{0x6d4c2e10,0xddd400bc,0x612c0139,0xa91c00d7}},	//   szaa, slyš, _tеlä, _myže, 
   {{0x6d4c01f5,0x80a4135f,0xdb1c0037,0xddd400c0}},	//   pzaa, _دمین, dapä, plyš, 
   {{0x81d411ba,0x79800368,0x1dc01945,0x090400cf}},	//   স্ক_, _cymw, _хөсн, рчем, 
   {{0xefd40092,0x00000000,0x00000000,0x00000000}},	//   ራቸዉ_, --, --, --, 
   {{0x3950013f,0xa9080451,0x00000000,0x00000000}},	//   _ɑnsɑ_, ئيڪل_, --, --, 
   {{0x81cc1d4c,0x683c19c6,0x62540024,0x271400b8}},	//   _লাভ_, _mèdi, ršok, _vān_, 
   {{0x798000a9,0xdb1c2e11,0x67d400ee,0x6498084c}},	//   _gymw, tapç, _гозу, лтор_, 
   {{0xe4482dfc,0x27140882,0x290c2e12,0xa4440117}},	//   الدى_, _tān_, _isea_, снод, 
   {{0x21a4191e,0x24480174,0x38600ba1,0xa91c0432}},	//   йинм, _rúmd_, èire_, _wyžd, 
   {{0x76402e13,0xb3842e14,0xf77018fd,0xa91c0419}},	//   ckmy, өлөл, _غال_, _tyžd, 
   {{0x645c2e15,0xf67419f9,0xf6500228,0x00000000}},	//   ésis, _بالخ, _تئل_, --, 
   {{0x4aa40073,0x73c400f7,0x00000000,0x00000000}},	//   गदाव, _ۇيۇم, --, --, 
   {{0x6440002f,0x00000000,0x00000000,0x00000000}},	//   mkli, --, --, --, 
   {{0x290c2e16,0xfe78104b,0x1d082e17,0x8c38002f}},	//   _osea_, рүм_, леби_, _fußk, 
   {{0xdc680323,0x9f5802b5,0xcfe002f5,0x64402e18}},	// [2a20] гаад_, _hapü_, য়জন, okli, 
   {{0xefd40201,0x64402e19,0x7980017a,0xdb1c0309}},	//   ራቸው_, nkli, _rymw, yapä, 
   {{0x64402e1a,0x290c0b23,0x79800175,0xcee001ec}},	//   ikli, _asea_, _symw, _нұрқ, 
   {{0x290c0048,0xbb300e2c,0xdb1c00c5,0x64402e1b}},	//   _bsea_, ﻪﺳﻰ_, vapä, hkli, 
   {{0x64402e1c,0xd7f82e1d,0x2cd401b9,0x00000000}},	//   kkli, гуй_, _мюрр, --, 
   {{0xaad000e1,0xfc4401ed,0xdb1c023a,0xb9002e1e}},	//   _हिचक, _بھرپ, tapä, _थि_, 
   {{0x6440049f,0x290c1140,0x261805b5,0x01e00349}},	//   dkli, _esea_, _मोही_, য্যদ, 
   {{0xd1dc2e1f,0x64402e20,0x9f5800e4,0xc6f412c4}},	//   ንቦት_, ekli, _hapó_, ёных_, 
   {{0xdb1c2e21,0xd498013e,0x26c40042,0x64402e22}},	//   sapä, лро_, _ewlo_, fkli, 
   {{0x9f580137,0x15e81d8a,0xdb1c2e23,0xb3c8015b}},	//   _japó_, _टावर_, papä, _শাহজ, 
   {{0x6d400cc1,0x9f5800e4,0xe87401b9,0xa91c0306}},	//   _əlaq, _papý_, _بنلگ, _vyže, 
   {{0x64402e24,0x9f5807c5,0x683c004e,0x3ce00174}},	//   akli, _dapü_, _rèdi, kriv_, 
   {{0x6440005c,0x683c0100,0x867808d8,0xc0d80092}},	//   bkli, _sèdi, _גראו, _ይባል_, 
   {{0x64402e25,0x683c0100,0x50642e26,0x53940023}},	//   ckli, _pèdi, стма, _መሓዙት_, 
   {{0xc0581ed2,0x3ce0000d,0x00000000,0x00000000}},	//   сія_, eriv_, --, --, 
   {{0x683c0100,0x60d8007f,0x069007d2,0x00000000}},	//   _vèdi, ņtma, _ﺟﺎﻟﯩ, --, 
   {{0x8d8401b9,0x00000000,0x00000000,0x00000000}},	// [2a30] сувд, --, --, --, 
   {{0x9f582e27,0x7f54001f,0x99b80154,0x00000000}},	//   _capó_, ሙያዎች, ুলোক, --, 
   {{0xa91c0427,0xfbd0007b,0x29d42e28,0x00000000}},	//   _izži, عتك_, قياس, --, 
   {{0x64402e29,0xa2bc2e2a,0x00000000,0x00000000}},	//   zkli, वीट्, --, --, 
   {{0x64402e2b,0x00000000,0x00000000,0x00000000}},	//   ykli, --, --, --, 
   {{0x8aa40577,0xe7382e2c,0x68442e2d,0x00000000}},	//   _град, иел_, юнла, --, 
   {{0x81d40d42,0x24780023,0x62540419,0x00000000}},	//   স্ট_, _ብፖሊስ_, mšov, --, 
   {{0x625402fb,0x5690041b,0x00000000,0x00000000}},	//   lšov, мајт, --, --, 
   {{0x89342e2e,0xe9d80034,0x60c0025c,0x290c01f4}},	//   _اعزا, _idź_, _ħomo, _usea_, 
   {{0xf9902e2f,0x26181889,0x64402e30,0x62542e31}},	//   _سبق_, _मोरी_, ukli, nšov, 
   {{0x64402e32,0xa2282b97,0x074401c6,0x645c0129}},	//   rkli, ажна_, _ухам, ésiq, 
   {{0x64402e33,0x62582e34,0x36d401c6,0x00000000}},	//   skli, ррор_, _хоцр, --, 
   {{0xa2d42e35,0x20882e36,0x00000000,0x00000000}},	//   _भिक्, ийми_, --, --, 
   {{0x625400d0,0xe7ec2e37,0x00000000,0x00000000}},	//   jšov, च्चा_, --, --, 
   {{0x7e9c00b0,0x8fa02e38,0x9e58039b,0x4fa000a7}},	//   _hōpi, даре, араф_, дирв, 
   {{0x7e9c0374,0xb8fc0135,0x3f8400e2,0x1e84109a}},	//   _kōpi, _རྗ_, āmu_, ілам, 
   {{0x9f58067c,0xdbc82e39,0x00000000,0x00000000}},	// [2a40] _papó_, игад_, --, --, 
   {{0x62842e3a,0x81b00198,0x9f580268,0x2a6c003e}},	//   llko, _daɓe, _dapò_, _ajeb_, 
   {{0xe7ec2e3b,0xdb0c01b8,0x3f8c00c5,0xa2bc2e3c}},	//   च्छा_, _lebö, üdud_, वीच्, 
   {{0x94080134,0x625400d7,0x5984011c,0xaac40472}},	//   _ɔmɑn_, ašov, олеб, ستمن, 
   {{0xa3e82413,0xc2140134,0x9f582e3d,0xabd40116}},	//   यला_, _nkɔm_, _tapó_, ززەت, 
   {{0xa3e40cb4,0x62841196,0x00000000,0x00000000}},	//   _फाग_, hlko, --, --, 
   {{0x81b00c09,0x38c82e3e,0xcb640354,0x00000000}},	//   _zaɓe, _گازی_, _даре_, --, 
   {{0x624400e8,0x62842611,0xdb1c00e4,0x8f9800d9}},	//   _sóon, jlko, kapú, סיקי, 
   {{0xd4042e3f,0x97d801e2,0x00000000,0x00000000}},	//   ояни, _نظار_, --, --, 
   {{0xb35400d6,0x62842e40,0x645c0098,0x00000000}},	//   зкош, elko, ésip, --, 
   {{0x683c00db,0x00000000,0x00000000,0x00000000}},	//   _cèdu, --, --, --, 
   {{0xb9e40125,0x8c380112,0x06b40133,0xd5d4030d}},	//   _ያን_, _fußw, _بچوک_, _хiам, 
   {{0xdb0c014a,0x62540122,0xd4680139,0x5468014b}},	//   _gebö, yšov, _киде_, _кадм_, 
   {{0x9f580699,0x62842e41,0x74142e42,0x00000000}},	//   _rapò_, alko, _روبا, --, 
   {{0x62440de2,0x38b008c2,0x628402fb,0x00000000}},	//   _kóol, _làr_, blko, --, 
   {{0x2cb82e43,0xa91c012c,0x9f580ca8,0xf4840133}},	//   _ptsd_, _lyža, _papò_, _باڵی, 
   {{0x62440694,0xebd801a9,0xad400372,0x00000000}},	// [2a50] _móol, йдаш_, رۉسۉ, --, 
   {{0x64dc05ba,0x70542e44,0x8b440b24,0x00000000}},	//   _मिसळ, _رنجا, يضان, --, 
   {{0x62540e9a,0x2bdc0118,0x00000000,0x00000000}},	//   ršov, मणबा, --, --, 
   {{0xc33004ac,0x38b001ab,0x2fd0026c,0x60d400e4}},	//   ווע_, _bàr_, lazg_, _yvym, 
   {{0x4054006c,0x38b001c3,0x62540122,0x00000000}},	//   _رئیس, _càr_, pšov, --, 
   {{0x38b001ab,0x7e9c02b1,0x2fd02e45,0x244800c7}},	//   _dàr_, _rōpi, nazg_, _oúma_, 
   {{0xe7382e46,0x3ffc04ac,0x37a82e47,0x6244002e}},	//   сей_, יפגע, әтән_, _bóol, 
   {{0x62440de2,0xc95807d6,0x38b001ab,0x00000000}},	//   _cóol, _кўз_, _fàr_, --, 
   {{0x29180407,0x38b001ab,0x00000000,0x00000000}},	//   _ésa_, _gàr_, --, --, 
   {{0x67d4009d,0x6284031c,0x00000000,0x00000000}},	//   _хожу, wlko, --, --, 
   {{0x2bfc01ad,0x4de8012c,0xe718007b,0x60d401ef}},	//   र्यू_, टलाई_, _ديات_, _svym, 
   {{0x64c400b2,0xdb1000dd,0x683c026c,0x7e9c0374}},	//   _فيصل, égév, _vèdu, _tōpi, 
   {{0x66082e48,0xd24c0592,0xe2980116,0xf124009d}},	//   meek, انُ_, _һак_, мьёо, 
   {{0xa3e40d1a,0x62840165,0xa878010f,0x60c0010e}},	//   _फाट_, slko, מאָר, _çomm, 
   {{0x44242e49,0xa91c00ef,0x00000000,0x00000000}},	//   _inn_, _izžu, --, --, 
   {{0x6244002e,0x66082e4a,0x442400a3,0xd24c00c6}},	//   _kóom, neek, _hnn_, _منى_, 
   {{0xdb1c03b2,0x00000000,0x00000000,0x00000000}},	// [2a60] lapø, --, --, --, 
   {{0x44242e4b,0x66082e4c,0x4c8006ed,0x2fd001a6}},	//   _jnn_, heek, елув, cazg_, 
   {{0x66082e4d,0x10380375,0x442401ab,0x20e003b2}},	//   keek, _הגיע, _mnn_, _fæið_, 
   {{0xdca42e4e,0x20082e4f,0x66082e50,0x442401ab}},	//   _нами, lebi_, jeek, _lnn_, 
   {{0x44241675,0xbc742e51,0xa91c0122,0x66082e52}},	//   _onn_, _قۇرب, _pyža, deek, 
   {{0x20082e53,0x8c0800eb,0xaac40137,0xd7f801c4}},	//   nebi_, রাউন_, ستۅن, ёул_, 
   {{0xa91c0232,0x1c0003f3,0x7bdc2e54,0x6608011f}},	//   _vyža, _रॉयल_, _idru, feek, 
   {{0x44242e55,0x624400e8,0x15b02e56,0xd4982e57}},	//   _ann_, _bóom, رەتس, әри_, 
   {{0x48e02e58,0x94842e59,0x20082e5a,0x44242e5b}},	//   _потв, зынд, kebi_, _bnn_, 
   {{0x20081710,0x62441bce,0x44240f85,0x244801e7}},	//   jebi_, _wóol, _cnn_, _púma_, 
   {{0x7e9c0053,0x660824c1,0x44240036,0x2fd001a6}},	//   _hōpu, beek, _dnn_, vazg_, 
   {{0x44242e5c,0x7e9c0374,0x00000000,0x00000000}},	//   _enn_, _kōpu, --, --, 
   {{0x20081246,0x95842e5d,0x81cc015b,0x6244002e}},	//   febi_, _элде, _লাশ_, _góom, 
   {{0x44242e5e,0x7bdc2e5f,0xc05802d5,0xdb1c00e4}},	//   _gnn_, _ndru, піс_, sapù, 
   {{0x6254000a,0xff042607,0x8c3803fa,0x2fd0107d}},	//   tšot, нятн, _mußt, razg_, 
   {{0x7bdc2e60,0xade800f2,0x1ee800f2,0x00000000}},	//   _adru, تفرم_, توفی_, --, 
   {{0x20082e61,0x62542ba4,0x2bb805d7,0x44240042}},	// [2a70] bebi_, ršot, इडला, _ynn_, 
   {{0x66082e62,0x20082e63,0x62700421,0x44240fac}},	//   zeek, cebi_, māoa, _xnn_, 
   {{0x81b00b45,0x7bdc03cb,0x66082e64,0x24bc0154}},	//   _haɓa, _ddru, yeek, _ইয়াহ, 
   {{0x81b00198,0x7bdc036e,0x66082e65,0x00000000}},	//   _kaɓa, _edru, xeek, --, 
   {{0x66082e66,0x8d841f10,0xf9902e67,0xcc8403e6}},	//   veek, _хунд, هبه_, _فۆره_, 
   {{0x66082e68,0x81b003f9,0xef3402dd,0x00000000}},	//   week, _maɓa, _ءﯨﺸﯩ, --, 
   {{0x66080c8a,0xba281066,0x645c2e69,0x442401bf}},	//   teek, تسەم_, èsim, _rnn_, 
   {{0x7bdc2e6a,0xdb242e6b,0xe5a404a9,0x4424058a}},	//   _zdru, _توفی, мийи, _snn_, 
   {{0x66082e6c,0x20081aac,0x81cc00bd,0x8c38002f}},	//   reek, yebi_, _লাল_, _fußt, 
   {{0x66082e6d,0x291c2e6e,0xe3b000c6,0x99940050}},	//   seek, mvwa_, خرة_, _کھۅر_, 
   {{0x6e280428,0x4424004d,0xa348109a,0xa5f8003b}},	//   _òebw, _vnn_, ізма_, _межу_, 
   {{0xf7482e6f,0x20081992,0x44240a4e,0x1fc41025}},	//   _علني_, webi_, _wnn_, वर्ड, 
   {{0x24182e70,0x20082e71,0x367000db,0x291c0100}},	//   _моды_, tebi_, _حۇيز, nvwa_, 
   {{0xa91c0122,0x6720110c,0x10a0022e,0xe3640fac}},	//   _lyžo, _krlj, киян, _окли, 
   {{0x20082e72,0x10a02e73,0x00000000,0x00000000}},	//   rebi_, тирн, --, --, 
   {{0x20082e74,0x672005ce,0xbf2801e1,0xfaf80421}},	//   sebi_, _mrlj, _aṣòr, _īī_, 
   {{0x81b002a8,0x20080521,0x6294022e,0xd598010f}},	// [2a80] _gaɓa, pebi_, _ihyo, ַבעל, 
   {{0x1da802e5,0x291c1cea,0x67200841,0xbd44004b}},	//   _कलकत, dvwa_, _orlj, ونځي, 
   {{0x81b00b45,0x712401d5,0xddc4005b,0x00000000}},	//   _zaɓa, _قریل, _обни, --, 
   {{0x7e9c0418,0x5334008f,0x9f9400c7,0xb9b42099}},	//   _pōpu, ונען_, _ныҟә, رمتع, 
   {{0x7e642e75,0x00000000,0x00000000,0x00000000}},	//   miip, --, --, --, 
   {{0x7bdc04b9,0x9f48006a,0x7e642e76,0x672007f5}},	//   _udru, ngbï_, liip, _brlj, 
   {{0x7c3c12ef,0x169401d9,0x00000000,0x00000000}},	//   _iorr, وٕتھ_, --, --, 
   {{0x7e642e77,0x67201050,0x7c3c2e78,0x7e9c02b1}},	//   niip, _drlj, _horr, _tōpu, 
   {{0x7c3c2e79,0x6244002e,0x04140011,0x81b400eb}},	//   _korr, _tóoj, তানী_, টরা_, 
   {{0x7c3c2e7a,0x9f580022,0x672008a4,0x7e642e7b}},	//   _jorr, _hapõ_, _frlj, hiip, 
   {{0x78a80472,0x81b00b45,0x6244002e,0xe7d4036b}},	//   _iidv, _saɓa, _góok, _سمنگ, 
   {{0x7c3c2e7c,0x63ac2e7d,0x68ec0006,0xa91c0219}},	//   _lorr, _şant, žodž, _izžr, 
   {{0x62940280,0x7e64022f,0x7c3c2e7e,0x00000000}},	//   _dhyo, diip, _oorr, --, 
   {{0x78a80356,0x00000000,0x00000000,0x00000000}},	//   _jidv, --, --, --, 
   {{0x627006c8,0x78a82e7f,0x291c004c,0x4ea42e80}},	//   māon, _midv, zvwa_, драа, 
   {{0x78a82e81,0x81b00b45,0x7e6420ac,0x026800fd}},	//   _lidv, _taɓa, giip, _ошый_, 
   {{0x4fc42e82,0x7c3c2e83,0xa91c2e84,0x78a8035a}},	// [2a90] _осна, _borr, _ryžo, _oidv, 
   {{0x6f040016,0x09d40490,0xe54400d8,0x22902e85}},	//   _tphc, डण्य, écéé, máka_, 
   {{0x7c3c2e86,0x22902358,0x7e642e87,0x00000000}},	//   _dorr, láka_, biip, --, 
   {{0x7c3c0076,0x625401fa,0x6d342e88,0x291c02e2}},	//   _eorr, nšop, _земф, tvwa_, 
   {{0x6e3c2e89,0x78a82e8a,0x672008a4,0xdd900451}},	//   _iosb, _bidv, _srlj, _موٽ_, 
   {{0x7c3c2e8b,0x67200b91,0x6e3c2e8c,0x78a80055}},	//   _gorr, _prlj, _hosb, _cidv, 
   {{0x6e3c0660,0x5b00004b,0x86340023,0x8c380112}},	//   _kosb, _مېلم, _ኤለክት, _fußr, 
   {{0x7c3c2e8d,0x6e3c0455,0xfbd001d9,0xf7702e8e}},	//   _zorr, _josb, _متہ_, جاه_, 
   {{0x6e3c0240,0x6294164b,0x2290022a,0x00000000}},	//   _mosb, _rhyo, jáka_, --, 
   {{0x870425aa,0x6e3c2e8f,0x672005ce,0x62940526}},	//   _يبال, _losb, _trlj, _shyo, 
   {{0x63ac2e90,0x62642e91,0x6aa82e92,0x6e3c062c}},	//   _şans, евна, _kief, _oosb, 
   {{0x7e640109,0x6e3c2e93,0xf0880375,0x244801e1}},	//   xiip, _nosb, _הנ_, _túmo_, 
   {{0xc5682ad5,0x7e640108,0x00000000,0x00000000}},	//   _بحال_, viip, --, --, 
   {{0x6aa82e94,0xdfd0007b,0x718000c7,0x61280092}},	//   _lief, طير_, рқье, ድሞቻች, 
   {{0x66182e95,0xfe780372,0x343801d9,0x6e3c2e96}},	//   _kawk, дүн_, _تسند_, _bosb, 
   {{0x7c3c2e97,0x6aa82e98,0x6e3c2e99,0x629400b5}},	//   _sorr, _nief, _cosb, _uhyo, 
   {{0x9c242e9a,0x66182e9b,0x6e3c00a9,0x644c03a2}},	// [2aa0] ндад, _mawk, _dosb, _ïais, 
   {{0xdca42e9c,0x7c3c2e9d,0x6e3c009a,0x6618183a}},	//   хази, _qorr, _eosb, _lawk, 
   {{0xd1d4067d,0x7c3c2e9e,0x6e3c0333,0xf3f41c82}},	//   _ክሳብ_, _vorr, _fosb, _অসমৰ_, 
   {{0x78a82e9f,0x81b00198,0x20182ea0,0xdb1c01b8}},	//   _sidv, _maɓo, _hapi_, mapü, 
   {{0x20182ea1,0xc98004a9,0xdb1c2ea2,0x5f742ea3}},	//   _kapi_, луши, lapü, _زاگر, 
   {{0x20182ea4,0x75242ea5,0x6aa80fac,0x78a80477}},	//   _japi_, _šizo, _eief, _qidv, 
   {{0x6aa808f5,0x20182ea6,0x78a82ea7,0xda642ea8}},	//   _fief, _mapi_, _vidv, _كاري, 
   {{0x66182ea9,0x20182eaa,0x6aa80089,0x78a8003b}},	//   _cawk, _lapi_, _gief, _widv, 
   {{0x1cac2eab,0x9f48006a,0xa4f42eac,0x78a82ead}},	//   _ནངས_, ngbâ_, نکور_, _tidv, 
   {{0x61f42eae,0x201800dd,0x229002fb,0xdb1c2eaf}},	//   _acyl, _napi_, váka_, kapü, 
   {{0x62541ebd,0x6618039a,0x461000aa,0xdb1c014a}},	//   tšop, _fawk, _څومر, japü, 
   {{0x2018079b,0xdb1c2eb0,0x66181605,0x229023d1}},	//   _aapi_, dapü, _gawk, táka_, 
   {{0x26182871,0xeb0c27c6,0xdb1c0022,0x00000000}},	//   _मोटी_, _सन्त_, vapý, --, 
   {{0x20181022,0xdb1c014a,0x22902eb1,0x6e3c2eb2}},	//   _capi_, fapü, ráka_, _sosb, 
   {{0x2018060a,0x6e3c2eb3,0x81b003f9,0x229002f0}},	//   _dapi_, _posb, _gaɓo, sáka_, 
   {{0x20180a73,0x9f580100,0x6e3c0455,0xdb1c00e4}},	//   _eapi_, _rapô_, _qosb, hapó, 
   {{0x31342eb4,0x6aa82eb5,0x7db400c6,0x6e3c017a}},	// [2ab0] _репр, _rief, اصفا, _vosb, 
   {{0x20182eb6,0xdfd005d9,0x6aa80042,0xdb1c0588}},	//   _gapi_, _پيٽ_, _sief, japó, 
   {{0xdb1c00c7,0x6e3c2eb7,0xa91c00d7,0x6aa80171}},	//   papý, _tosb, _vyžm, _pief, 
   {{0x2018009d,0x8a400133,0x244802d2,0x00000000}},	//   _zapi_, دێرن, _rúmm_, --, 
   {{0x20182eb8,0x6aa80158,0x66180072,0x8c380112}},	//   _yapi_, _vief, _rawk, _fußp, 
   {{0xd9402eb9,0x66182eba,0x2018005a,0xdb1c00c7}},	//   реши, _sawk, _xapi_, gapó, 
   {{0x6aa80730,0x66182ebb,0xe3b0221d,0x9ba000f7}},	//   _tief, _pawk, یرد_, _نەكى, 
   {{0x66182b34,0x00000000,0x00000000,0x00000000}},	//   _qawk, --, --, --, 
   {{0xdb0c145e,0x74f805f5,0x81b003f9,0x09d402f5}},	//   _ngbê, нээс_, _saɓo, _হাপা, 
   {{0x61f428a5,0x6aa80064,0x5eac00d1,0x00000000}},	//   _scyl, _čefy, _ﻳﺎﯞﺭ, --, 
   {{0x20182ebc,0x661802d1,0x26c002f0,0x7c2802d2}},	//   _rapi_, _tawk, íhod_, _ódre, 
   {{0x21682ebd,0x20182ebe,0x661802d0,0xe2980120}},	//   дими_, _sapi_, _uawk, ќам_, 
   {{0x20182ebf,0x2934010f,0xe53402e8,0x00000000}},	//   _papi_, דאָן_, _шедь, --, 
   {{0x61f40a73,0x63842ec0,0xdb1c0793,0xd24c004b}},	//   _wcyl, _игла, tapü, منۍ_, 
   {{0x627816c3,0x20182ec1,0x8c38002f,0x09d40154}},	//   _осиё_, _vapi_, _rußp, _হানা, 
   {{0x20182ec2,0x2ee40008,0x61f402d0,0xe124022e}},	//   _wapi_, álfa_, _ucyl, _амии, 
   {{0x20182ec3,0x6b9402d0,0xe7d00ce0,0xdb1c00e4}},	// [2ac0] _tapi_, _azzg, हराप, japò, 
   {{0xefd40020,0xd00c00db,0x00000000,0x00000000}},	//   ያቸው_, _ۇلۋ_, --, --, 
   {{0x22900022,0x00000000,0x00000000,0x00000000}},	//   náko_, --, --, --, 
   {{0x27e803f9,0x5e600137,0x656c0419,0x00000000}},	//   ɗani_, _ئچسە, _ľahn, --, 
   {{0x3ea02ec4,0xd860035b,0x499015cf,0xd8382ec5}},	//   mmit_, аҵаҩ, һшәт, дэй_, 
   {{0x3ea02ec6,0xb7d800c6,0x51580375,0x36d4004e}},	//   lmit_, روبا_, וכנו, гокр, 
   {{0x8c1805d0,0xde3c0092,0x00000000,0x00000000}},	//   _קולי, _ያከናው, --, --, 
   {{0x3ea00d04,0x80b802f5,0x4664008e,0x5ee8012c}},	//   nmit_, _অবন্, крым_, _छिन्_, 
   {{0x3ea02ec7,0xdb1c067c,0x3afc0139,0x00000000}},	//   imit_, capò, líp_, --, 
   {{0x3ea02ec8,0x73382ec9,0x2874030d,0x74342ec9}},	//   hmit_, езор_, _йыхр, уноф, 
   {{0x22500660,0x3ea0011f,0x25bc0042,0x56f002dd}},	//   _blyk_, kmit_, _ffwl_, _түйс, 
   {{0x3ea0016d,0x55042eca,0x00000000,0x00000000}},	//   jmit_, _ачка, --, --, 
   {{0x81cc09bd,0x88c4002b,0x09d40011,0xd3240022}},	//   _লাখ_, _gośī, _হামা, хьҿи, 
   {{0x3ea00429,0x00000000,0x00000000,0x00000000}},	//   emit_, --, --, --, 
   {{0x40342ecb,0x42540014,0x645c0ea0,0xc05800d4}},	//   шерс, _چۆپر, ësie, тія_, 
   {{0x02a42ecc,0x3ea02ecd,0x645c005f,0xdb0c0241}},	//   _крым, gmit_, īsie, _igbè, 
   {{0x8d8401d5,0x00000000,0x00000000,0x00000000}},	// [2ad0] тувд, --, --, --, 
   {{0x3ea02ece,0x06e00154,0x00000000,0x00000000}},	//   amit_, _মহসি, --, --, 
   {{0xe81c2ecf,0x3ea00fa9,0x09d4009e,0x2250010e}},	//   _योगा_, bmit_, _হাবা, _ylyk_, 
   {{0x3ea00276,0xcd04010b,0xa6c400d1,0xa908007b}},	//   cmit_, _ичги, ۇقتى, فيصل_, 
   {{0x656c0419,0x7f84114f,0x00000000,0x00000000}},	//   _ľaho, _ملین, --, --, 
   {{0xdb1c007f,0x00000000,0x00000000,0x00000000}},	//   rapò, --, --, --, 
   {{0x27e82ed0,0x8aa42ed1,0x8a4004d3,0x998400fb}},	//   ğan_, _арад, _پێشن, ктәһ, 
   {{0x27e82ed2,0xa91c01f1,0x65780175,0x00000000}},	//   şan_, _lyži, _pxwh, --, 
   {{0xa5642ed3,0x69d82ed4,0xdb0c0cad,0xe508004b}},	//   دگان, mawe, _agbè, ريدو_, 
   {{0x3ea0044e,0x69d82ed5,0x22502694,0x00000000}},	//   zmit_, lawe, _slyk_, --, 
   {{0x3ea02ed6,0xe364022e,0x00000000,0x00000000}},	//   ymit_, укни, --, --, 
   {{0x69d800b2,0xddd40232,0x244801e1,0xa4d400d4}},	//   nawe, chyň, _múmi_, _боді, 
   {{0xdb0c0241,0xd5ac2ed7,0xa5082ed8,0x00000000}},	//   _egbè, _عفو_, _чела_, --, 
   {{0x69d82ed9,0xa0682eda,0x244800e4,0x81cc00fe}},	//   hawe, хага_, _oúmi_, _লাও_, 
   {{0x69d82edb,0x2eb42edc,0x37d8015b,0x3ea02edd}},	//   kawe, истс, _সামর, tmit_, 
   {{0x3ea02ede,0x69d82edf,0xdee4024c,0xe6d000bc}},	//   umit_, jawe, коҳи, _सबैज, 
   {{0x69d82ee0,0x3ea02ee1,0x6244002e,0xdb0c01e1}},	// [2ae0] dawe, rmit_, _dóot, _igbé, 
   {{0x62842ee2,0x3ea02ee3,0xa3e802a0,0x46b000bc}},	//   loko, smit_, यलट_, ँदाह, 
   {{0x3ea02ee4,0x69d80009,0xa2e000fe,0x5f44007b}},	//   pmit_, fawe, _বহুখ, _إنجل, 
   {{0x24842ee5,0x62842ee6,0x69d82ee7,0x6ab40369}},	//   holm_, noko, gawe, _duzf, 
   {{0x18682ee8,0x6284009f,0x9f8c000d,0xed341de6}},	//   нади_, ioko, rõõm_, _кэрэ, 
   {{0x62842ee9,0xf70807a5,0x00000000,0x00000000}},	//   hoko, вфиқ_, --, --, 
   {{0x69d82eea,0xdb0c01e1,0x00000000,0x00000000}},	//   bawe, _ogbé, --, --, 
   {{0x62441bce,0x86200133,0xda70009f,0x00000000}},	//   _xóot, یکۆل, _اُر_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb0c0248,0x98a400fd,0x00000000,0x00000000}},	//   _agbé, _сизе, --, --, 
   {{0x62842eeb,0x33940006,0x81cc04c5,0xd7bc002e}},	//   foko, ранё, _লাজ_, _l胃kk_, 
   {{0x62842eec,0x66800214,0xc05801ec,0x00000000}},	//   goko, _ویول, ңір_, --, 
   {{0x855401ed,0xc108008e,0x00000000,0x00000000}},	//   _میٹر_, лэре_, --, --, 
   {{0x69d82eed,0x24842cd8,0x645c020c,0xef540124}},	//   zawe, colm_, èsit, акгь, 
   {{0x62842eee,0x69d82eef,0xa91c2195,0xd36c0137}},	//   boko, yawe, _vyži, _رۇح_, 
   {{0x62842ef0,0x244808a7,0x2370045f,0x1c002ef1}},	//   coko, _rúmi_, úzje_, र्सल_, 
   {{0xe6d02cfd,0x69d8006f,0x32082ef2,0x00000000}},	// [2af0] _सब्ज, vawe, _ibay_, --, 
   {{0x69d82ef3,0x7bf82ef4,0xaed400cf,0x00000000}},	//   wawe, лнур_, _коош, --, 
   {{0x69d82ef5,0x9ce80014,0x60c000a2,0x6e94292c}},	//   tawe, _یوَے_, _çomr, _вину, 
   {{0x8d842ef6,0xeb040406,0x00000000,0x00000000}},	//   _бугд, _रहीत_, --, --, 
   {{0x69d82ef7,0x80a42ef8,0x32080694,0xa3e40037}},	//   rawe, _خمین, _mbay_, _बएल_, 
   {{0x62442ef9,0xb80001ad,0x627000b0,0x00000000}},	//   _jóor, ल्लम_, tāok, --, 
   {{0x69d82efa,0x62842efb,0x32082efc,0xbea80244}},	//   pawe, yoko, _obay_, _جهێن_, 
   {{0x628407a9,0x62440248,0x2bdc2efd,0x00000000}},	//   xoko, _lóor, मणका, --, 
   {{0x27b00131,0x24840254,0xe6100066,0x00000000}},	//   _һәқс, tolm_, مشک_, --, 
   {{0x62842efe,0x32082eff,0x290c0798,0x00000000}},	//   woko, _abay_, _ipea_, --, 
   {{0xe29815ed,0x6eb00406,0x78bc0010,0xf77000e5}},	//   као_, _आंगु, _črvi, _ٹال_, 
   {{0xe1242f00,0xf7702f01,0x67241141,0x00000000}},	//   амми, _عال_, åhju, --, 
   {{0x624401e1,0x161c1b51,0x84c40114,0x00000000}},	//   _bóor, _मोटर_, _сљед, --, 
   {{0x32082f02,0x70180845,0x5ed800eb,0xd78c0023}},	//   _ebay_, ліст_, বংসে, _ምንባራ_, 
   {{0x62842f03,0x624400e8,0xceb4004e,0x00000000}},	//   poko, _dóor, иштө, --, 
   {{0x13d82f04,0x62841cdf,0x290c0270,0x201c0024}},	//   _দায়, qoko, _opea_, žti_, 
   {{0x04f000cc,0x9d440114,0x00000000,0x00000000}},	// [2b00] _অনুৰ_, језд, --, --, 
   {{0x26c401af,0x624400e8,0x00000000,0x00000000}},	//   _otlo_, _góor, --, --, 
   {{0x32082f05,0x290c2f06,0x26c42f07,0x00000000}},	//   _ybay_, _apea_, _ntlo_, --, 
   {{0xdb1c2f08,0x38c80133,0xa91c02f0,0x00000000}},	//   kapö, هاتی_, _lyžu, --, 
   {{0x8914036b,0x98a42f09,0xdb1c01f4,0x00000000}},	//   لغوز_, аиде, japö, --, 
   {{0x986400dd,0x1c002f0a,0x00000000,0x00000000}},	//   جیئے_, र्शल_, --, --, 
   {{0x290c05f5,0xd5e0063f,0x46e40032,0x627002b1}},	//   _epea_, _nkọ, ңдән_, pāoh, 
   {{0x960802d5,0xd94400cf,0x422000cd,0x00000000}},	//   тэка_, _кеби, ययोः_, --, 
   {{0xd4982f0b,0x26c400fb,0xd90c2f0c,0xdb0c01bf}},	//   кро_, _etlo_, _آیت_, _afbø, 
   {{0x32080280,0x76d80117,0xb2e001ec,0x00000000}},	//   _sbay_, _будӣ_, _ﻋﻨﻭﺍ, --, 
   {{0x0bb4025f,0x6f08068f,0x78840014,0x84300212}},	//   ילים_, łecz, _پێژِ_, інює, 
   {{0x81b003f9,0xeeb82f0d,0x6244002e,0xe97000f7}},	//   _zaɓi, ғлаш_, _sóor, _بۇۇد, 
   {{0x660c2f0e,0xc6900375,0x00000000,0x00000000}},	//   _ñaka, _ואף_, --, --, 
   {{0x920000e2,0xdb1c0254,0x00000000,0x00000000}},	//   _šādo, lapõ, --, --, 
   {{0x4500081f,0x09d400bd,0xc438011a,0x00000000}},	//   _མདོར_, _হাসা, _בתגי, --, 
   {{0x81ac02a6,0xc5fc04c5,0x8778008f,0x6b740032}},	//   গড়_, ্যথা_, דאלי, ҡлау, 
   {{0x656c01a2,0x38a0067c,0x6244002e,0x8bb4007b}},	// [2b10] _ľahk, mòrf_, _tóor, لإضا, 
   {{0x8bc400c2,0x13d8015b,0xdb1c000d,0x8c5400db}},	//   рсад, _দাড়, hapõ, جئرا, 
   {{0x290c009f,0x2bc8012c,0x8aa4133a,0xdb1c0254}},	//   _spea_, ाँबा, ардд, kapõ, 
   {{0xdb1c0254,0x00000000,0x00000000,0x00000000}},	//   japõ, --, --, --, 
   {{0x6924036b,0xb9e802dd,0xdb1c0254,0x00000000}},	//   смла, рміз_, dapõ, --, 
   {{0x6d4c2f0f,0x26100051,0x7c84014b,0x00000000}},	//   myaa, _ạo_, _дусе, --, 
   {{0x6d4c2f10,0xb92001f2,0x612c0109,0x00000000}},	//   lyaa, _karị_, _kôlô, --, 
   {{0x80b803f4,0xb920063f,0xd704005b,0x6d4c0009}},	//   _অবস্, _jarị_, ёные_, oyaa, 
   {{0x6d4c2f11,0x81b003f9,0x2cb80036,0x290c2f12}},	//   nyaa, _taɓi, _jusd_, _upea_, 
   {{0x6d4c0014,0xdb1c2f13,0x00000000,0x00000000}},	//   iyaa, rapö, --, --, 
   {{0x6d4c2f14,0xdb1c0254,0xa91c0064,0x00000000}},	//   hyaa, bapõ, _vyžu, --, 
   {{0xb92000b4,0x6d4c0a49,0xeb0400c5,0x2448032e}},	//   _narị_, kyaa, _रहैत_, _rúmu_, 
   {{0xc5fc03d4,0x64c42f15,0x60642f16,0xa97800df}},	//   ্যদা_, _ايتل, йҗиң_, ראָכ, 
   {{0xa0742f17,0x6d4c2f18,0x461004fb,0xa0a401c6}},	//   сымш, dyaa, _دوچر, сагд, 
   {{0x6d4c01d9,0x8c380112,0x00000000,0x00000000}},	//   eyaa, _fußz, --, --, 
   {{0xdcb007a7,0x6d4c2f19,0xabd401ec,0x3ce00254}},	//   كىر_, fyaa, _ﺘﺩﺍﻋ, tsiv_, 
   {{0x6d4c2f1a,0xc2c000b2,0xdc7400c7,0x00000000}},	// [2b20] gyaa, _ايڊي, быжь, --, 
   {{0x3ce02f1b,0x2cb80175,0x649c0036,0xb0b4012d}},	//   rsiv_, _dusd_, bèie, ंदरग, 
   {{0x6d4c2f1c,0x158808b0,0x2cb80175,0x00000000}},	//   ayaa, ﺗﯩﺴﯩ, _eusd_, --, 
   {{0x6d4c2f1d,0xaa6400d4,0x79c801a9,0x00000000}},	//   byaa, отік, рқаб_, --, 
   {{0xdd902f1e,0xdcb00220,0xdb0c01e1,0x6d4c0067}},	//   _روس_, _ءىس_, _igbí, cyaa, 
   {{0x7d042f1f,0xb90000e1,0xa91c0024,0x9f48002e}},	//   mtis, _दब_, _ryžt, _ójóo_, 
   {{0x7d042f20,0x09d400bd,0x00000000,0x00000000}},	//   ltis, _হারা, --, --, 
   {{0x645c044e,0xceb00302,0x00000000,0x00000000}},	//   ësin, היה_, --, --, 
   {{0x7d042f21,0xdb1c000d,0xaa4801ee,0x00000000}},	//   ntis, rapõ, _тотҡ_, --, 
   {{0x7d042f22,0x33742f23,0x73d8013e,0xdb1c0254}},	//   itis, жгор, шдор_, sapõ, 
   {{0x7d042f24,0x81b003f9,0x244808a5,0x00000000}},	//   htis, _maɓu, _rúmt_, --, 
   {{0x7d0400ed,0x6d4c2f25,0xd06000ac,0x4b78010f}},	//   ktis, yyaa, ərəc, ראטו, 
   {{0x6d4c0050,0x51842f26,0x60d403cb,0xd38800ee}},	//   xyaa, суна, _cwym, _өйде_, 
   {{0x80b800bd,0x612c0109,0x60d40042,0x249401d9}},	//   _অবশ্, _sôlô, _dwym, _وۅٹھ_, 
   {{0x7d042f27,0x612c0109,0x63ac010f,0x6d4c0009}},	//   etis, _pôlô, _ĝang, wyaa, 
   {{0x7d042f28,0x3d14007d,0x8d8400f7,0x63ac0115}},	//   ftis, _नईखे_, бузд, _ŝang, 
   {{0xdb0c145e,0x6d4c0d04,0x7d042f29,0x60d4015d}},	// [2b30] _ngbâ, uyaa, gtis, _gwym, 
   {{0x6d4c2f2a,0x00000000,0x00000000,0x00000000}},	//   ryaa, --, --, --, 
   {{0xdb0c025a,0x6d4c2f2b,0x63ac0790,0x00000000}},	//   _agbâ, syaa, _şanz, --, 
   {{0x7d0403b2,0x02f8010f,0x00000000,0x00000000}},	//   btis, רלאמ, --, --, 
   {{0x7d042f2c,0x6d4c0cfe,0x627000b0,0x2cb00139}},	//   ctis, qyaa, māot, _tizd_, 
   {{0xd5e00241,0xdb1c0109,0xe9d8033f,0x69c800dc}},	//   _amò, tapô, _weź_, _ह्री, 
   {{0x70b40034,0x00000000,0x00000000,0x00000000}},	//   ंदुल, --, --, --, 
   {{0x81b003f9,0x24e82c31,0xb6580006,0x00000000}},	//   _zaɓu, амии_, йшых_, --, 
   {{0xe4582f2d,0x1fa42f2e,0xd5ac00aa,0x29182f2f}},	//   ижи_, _खण्ड, نځه_, _èsa_, 
   {{0x48742f30,0x38a0068c,0x60d4015d,0x244808ce}},	//   _ادرس, gòrd_, _rwym, _rúms_, 
   {{0x4f78001f,0x16040073,0xdb0c02d2,0x7d0401d3}},	//   _አቤቱታ_, व्हर_, _ofbý, ztis, 
   {{0x7d042f31,0xa3b412eb,0x00000000,0x00000000}},	//   ytis, _झलक_, --, --, 
   {{0x7d04003a,0x00000000,0x00000000,0x00000000}},	//   xtis, --, --, --, 
   {{0x66082f32,0x38a00ba1,0x65940022,0x00000000}},	//   lfek, còrd_, _лаҵу, --, 
   {{0xe2982f33,0x1fa82f34,0xc0e8001f,0x64400369}},	//   _как_, ркви_, ማየሁ_, mjli, 
   {{0x7d042f35,0xdbe02f36,0x38a0067c,0x60d4015d}},	//   ttis, खण्ड_, mòre_, _twym, 
   {{0x7d042f37,0xe0d000c6,0x66082f38,0x38a00ba1}},	// [2b40] utis, _غزة_, ifek, lòre_, 
   {{0x7d042f39,0x64400007,0xdce400de,0xeff80092}},	//   rtis, njli, _izkļ, ቋቸው_, 
   {{0x9f042f3a,0xda6402bf,0x00000000,0x00000000}},	//   _بوجو, овжи, --, --, 
   {{0x6080001f,0x76400175,0x19f40014,0x0b180154}},	//   _የቅጣት_, xjmy, زِتھ_, ণমূল_, 
   {{0xdca40372,0x81b003f9,0x7d042f3b,0x00000000}},	//   _мами, _taɓu, qtis, --, 
   {{0x66082f3c,0x229002f0,0xd6e800d8,0x00000000}},	//   efek, máku_, афил_, --, 
   {{0xc9600491,0x7bdc2f3d,0x229002fb,0x00000000}},	//   _ɑƞɑ_, _ieru, láku_, --, 
   {{0x7bdc2f3e,0x68ec0114,0xdb0c0241,0xa91c00d0}},	//   _heru, šada, _igbà, _vyžr, 
   {{0x7bdc2f3f,0xa90800eb,0x00000000,0x00000000}},	//   _keru, লিউড_, --, --, 
   {{0x3a242f40,0x7bdc2f41,0x248801e4,0x2dcc1884}},	//   _hamp_, _jeru, _ƭama_, _ﺑﯩﻠﻤ, 
   {{0x7bdc27ed,0xd5e80014,0xd1cc0023,0x229002f0}},	//   _meru, _نٹان_, ባራቱ_, háku_, 
   {{0x7bdc2f42,0x3a242f43,0x62841427,0x00000000}},	//   _leru, _jamp_, _íhol, --, 
   {{0x70b402a0,0xd49800d8,0x22900c5e,0x86780115}},	//   ंदेल, _крк_, jáku_, _דראו, 
   {{0x7bdc2f44,0x38a0067c,0x63ac01e4,0x3a24029d}},	//   _neru, bòre_, _ŝane, _lamp_, 
   {{0xb8fc081f,0xff042f45,0xcdd807fa,0x3a240156}},	//   _ཡས_, мятн, иња_, _oamp_, 
   {{0x7bdc2f46,0xb63c00b5,0xb3bc0154,0xfbd001d9}},	//   _aeru, _ｇｒ_, _আজিজ, ۆتم_, 
   {{0x7bdc2f47,0xdb0c0248,0x32180109,0x386c2f48}},	// [2b50] _beru, _agbà, mesy_, _omdr_, 
   {{0x7bdc2f49,0x32182f4a,0xfbd000c6,0xb8f40055}},	//   _ceru, lesy_, نتم_, _ceṭī, 
   {{0x7bdc2f4b,0x627004fe,0x649c0ba1,0xfe7000e5}},	//   _deru, māor, nèia, ردہ_, 
   {{0x321806d9,0x7bdc2f4c,0x3a240375,0xad400137}},	//   nesy_, _eeru, _camp_, _كۉزۉ, 
   {{0xcfa82f4d,0x7bdc2f4e,0x69340137,0x3a24045a}},	//   _حاکم_, _feru, янду, _damp_, 
   {{0xd82011ed,0x386c0618,0x321800e4,0xfeb81e4b}},	//   едши, _cmdr_, hesy_, _دایت_, 
   {{0x645c0023,0x00000000,0x00000000,0x00000000}},	//   ësim, --, --, --, 
   {{0x386c02fa,0x7bdc2f4f,0x32180109,0x3a242f50}},	//   _emdr_, _zeru, jesy_, _gamp_, 
   {{0x32180109,0x848402d3,0xdb0c0241,0x07180d2e}},	//   desy_, _ምእማን_, _igbá, _भैरव_, 
   {{0x7bdc056a,0x3a24107d,0x3914010b,0xfdb80807}},	//   _xeru, _zamp_, _юмур, _अल्फ, 
   {{0x3a240369,0xdbdc01e1,0x321805da,0x66082f51}},	//   _yamp_, _díèd, fesy_, pfek, 
   {{0x67200e3c,0x23c0032e,0x00000000,0x00000000}},	//   _islj, _bæjó_, --, --, 
   {{0x2a6c0134,0x55b80375,0x569808a8,0xf65000db}},	//   _mmeb_, _המנו, _פינצ, _جئل_, 
   {{0x394002f6,0x291c0e14,0x55500c75,0x2290022a}},	//   äisi_, iwwa_, _سپىر, váku_, 
   {{0x7bdc2f52,0x9f480158,0x68f801a4,0x91000014}},	//   _reru, ngbø_, huwd, وژیو, 
   {{0x22900306,0x32182f53,0x68f80432,0x00000000}},	//   táku_, cesy_, kuwd, --, 
   {{0x7bdc2f54,0x3a242f55,0xdd902f56,0xa06801f0}},	// [2b60] _peru, _ramp_, روط_, _гапа_, 
   {{0x3a241bce,0xdb0c0cad,0x229002fb,0x68f801f5}},	//   _samp_, _agbá, ráku_, duwd, 
   {{0x68f80196,0x1c000034,0xafc401ec,0x5018011a}},	//   euwd, र्गल_, _تيپى, _פוטו, 
   {{0x7bdc2f57,0xfe5801d5,0x645c0200,0x37d800cc}},	//   _weru, _بیرب_, ësij, _ঠাইৰ, 
   {{0x7bdc0092,0x3a242f58,0xf91804fb,0xd7e400d4}},	//   _teru, _vamp_, تراژ_, пійо, 
   {{0x3a241bb7,0xd6d8016c,0x7bdc16b8,0x1ae4013d}},	//   _wamp_, бти_, _ueru, _ногм, 
   {{0x6b9400ee,0x3a240356,0x88b001d5,0x00000000}},	//   _gyzg, _tamp_, ریمچ, --, 
   {{0x4b780375,0xd5642f59,0x00000000,0x00000000}},	//   _האלו, зтоп, --, --, 
   {{0x32180030,0xf42000fe,0x5fbc08df,0x993800d4}},	//   vesy_, বাসৰ_, ्डाल, _уяву_, 
   {{0xdecc0023,0xddc801ec,0x81b400eb,0xa17c0092}},	//   እለን_, _ﺑﯩﺰﺑ, য়রা_, _የንፁህ_, 
   {{0x32182f5a,0xa8440244,0x00000000,0x00000000}},	//   tesy_, _تکنۆ, --, --, 
   {{0x63ac008f,0xb9e40b82,0x15440329,0x145800c7}},	//   _ŝanc, _ካን_, _неем, ршҩы_, 
   {{0x32182f5b,0x627002b5,0xdb080162,0x00000000}},	//   resy_, tāor, _ónær, --, 
   {{0x32180170,0xf42000fe,0x04402f5c,0xddd42f5d}},	//   sesy_, বাহৰ_, _печн, lkyň, 
   {{0x98a4009b,0x842000db,0x00000000,0x00000000}},	//   jvoč_, _سىين, --, --, 
   {{0xddd400d0,0x55f80154,0x00000000,0x00000000}},	//   nkyň, _আসুক_, --, --, 
   {{0x7274044e,0x627002b5,0x2bc8012c,0x48d40154}},	// [2b70] _ብረታዊ_, pāor, ाँला, _সম্র, 
   {{0x649c0036,0x7c9400d1,0x00000000,0x00000000}},	//   hèin, ىشلا, --, --, 
   {{0xead8005e,0x69cc0428,0xe7a4005f,0x00000000}},	//   імді_, ñaeo, ādīš, --, 
   {{0xfaf02f5e,0x2ee401a8,0xe9740244,0x6e18009f}},	//   اثل_, álfu_, وهاد, _بيحس_, 
   {{0xddd40030,0x65e401ec,0x5ec00154,0x00000000}},	//   dkyň, _ﺍﺩﯨﻠ, ষীদে, --, 
   {{0xf7702f5f,0xe7380209,0x291c00ca,0xddd40210}},	//   گاه_, жек_, rwwa_, chył, 
   {{0xab9402bf,0x6ac401d5,0x660c0de2,0x00000000}},	//   _циві, _آقرم, _ñakk, --, 
   {{0x09d400eb,0x00000000,0x00000000,0x00000000}},	//   _হাকা, --, --, --, 
   {{0x69c80270,0x88d402f5,0x6cd40150,0x00000000}},	//   _ifee, _সমকক, _ﺘﺨﺯﻴ, --, 
   {{0x68e82f60,0x00000000,0x00000000,0x00000000}},	//   _ived, --, --, --, 
   {{0x1c000918,0x67202f61,0x68e8037e,0x5908031c}},	//   र्टल_, _uslj, _hved, _གདོས_, 
   {{0x68e82f62,0xe5e401d5,0x38a0180f,0x4428012d}},	//   _kved, _آزای, mòra_, śc_, 
   {{0x160410eb,0xc1780116,0x3f9c01ef,0x00000000}},	//   _वॉटर_, яҗи_, _švu_, --, 
   {{0x89200327,0xa0680166,0x00000000,0x00000000}},	//   _རླབྶ_, цага_, --, --, 
   {{0x44242558,0x28dc29c8,0x69c82f63,0xd0040b7e}},	//   _ian_, नीति, _ofee, ьере_, 
   {{0x44242f64,0x68e82f65,0x69c81418,0x4508031c}},	//   _han_, _oved, _nfee, _ཁྱོར_, 
   {{0x41b40014,0x38a0068c,0xb82400fe,0x9c242bcb}},	// [2b80] _سۅسر, hòra_, পাতত_, мдад, 
   {{0xee380364,0x69c82f66,0x44242f67,0xc0cc0092}},	//   онӣ_, _afee, _jan_, ባኛል_, 
   {{0x4424228f,0x68e82f68,0x2ee401a8,0x68ec0419}},	//   _man_, _aved, álft_, šadl, 
   {{0x44242f69,0x1c0007f7,0x00000000,0x00000000}},	//   _lan_, र्जल_, --, --, 
   {{0x4424193f,0x58842f6a,0xddd40419,0x38140108}},	//   _oan_, мыка, vkyň, емлё, 
   {{0x44242f6b,0xdca4152d,0x45081b4b,0x69c801af}},	//   _nan_, _цаги, _ཁྱེར_, _efee, 
   {{0x68e82f6c,0x69c80a49,0xddd400d7,0x2af40108}},	//   _eved, _ffee, tkyň, _пятё, 
   {{0x44242f6d,0xdecc0023,0x80d400eb,0x00000000}},	//   _aan_, እለና_, _তিন্, --, 
   {{0x44242f6e,0xddd42f6f,0xc6a000a7,0x73c401e0}},	//   _ban_, rkyň, ърши, нәйе, 
   {{0x44242f70,0x38a0067c,0xddd42f71,0x96b80064}},	//   _can_, bòra_, skyň, _дуду_, 
   {{0x44242f72,0x68e82f73,0xa2c005d7,0xddd40419}},	//   _dan_, _zved, _रूद्, pkyň, 
   {{0x44242f74,0x926802bf,0x00000000,0x00000000}},	//   _ean_, ірна_, --, --, 
   {{0x44242f75,0xe80403e5,0x68e800b5,0xc0c8084c}},	//   _fan_, _रामा_, _xved, дусе_, 
   {{0x44242f76,0xb6380150,0x00000000,0x00000000}},	//   _gan_, _ﺘﻅ_, --, --, 
   {{0x2bdc0490,0x50280023,0x00ac07d2,0xfbe400eb}},	//   यरसा, _ብዝከኣ, _ﺳﻮﺗﺘ, মলাত, 
   {{0x44242f77,0x6db42f78,0x00000000,0x00000000}},	//   _zan_, ейбу, --, --, 
   {{0x44242f79,0x62440694,0x00000000,0x00000000}},	// [2b90] _yan_, _nóoy, --, --, 
   {{0x44242f7a,0x69c80cf9,0x00000000,0x00000000}},	//   _xan_, _sfee, --, --, 
   {{0xdb0c006a,0xe9442f7b,0x59080327,0x00000000}},	//   _ngbä, کرای, _གདུས_, --, 
   {{0x37d8015b,0xdb0c01d3,0x2bdc012d,0x00000000}},	//   _সাগর, áján, यरहा, --, 
   {{0xe6ec01a2,0xcce40597,0xbd940046,0xd7ec2f7c}},	//   _väčš, _تسجي, _ақтө, ڭكى_, 
   {{0x3b3c0092,0x00000000,0x00000000,0x00000000}},	//   _በጋምቤ, --, --, --, 
   {{0x44242f7d,0x2d982d8b,0x00000000,0x00000000}},	//   _ran_, _hyse_, --, --, 
   {{0x2d982f7e,0x68e80b34,0xfaa400d1,0x4508031c}},	//   _kyse_, _tved, _ашун, _ཁྱུར_, 
   {{0xe57809fe,0x68e80e96,0x44242f7f,0x74f801c0}},	//   язи_, _uved, _pan_, мээс_, 
   {{0x44242f80,0x2d982f81,0x00000000,0x00000000}},	//   _qan_, _myse_, --, --, 
   {{0x44242f82,0xe2982f83,0x2d980e38,0x87042f84}},	//   _van_, зан_, _lyse_, _زبال, 
   {{0x44242f85,0x62440de2,0xdce400d7,0x00000000}},	//   _wan_, _jóox, _vykĺ, --, 
   {{0x44242f86,0xb6380150,0x00000000,0x00000000}},	//   _tan_, _ﺘﺅ_, --, --, 
   {{0x44242f87,0x645c0194,0x64a401c4,0x00000000}},	//   _uan_, êsid, _яала, --, 
   {{0x3d10013f,0x3228023a,0x2d982f88,0x68ec00e5}},	//   _yεwכ_, ötyä_, _ayse_, áadj, 
   {{0x2d980142,0xc2b42f89,0x00000000,0x00000000}},	//   _byse_, _шөпш, --, --, 
   {{0x6294014b,0x1278010f,0x00000000,0x00000000}},	// [2ba0] _ikyo, _מאקע, --, --, 
   {{0x61e42f8a,0x2d980450,0x00000000,0x00000000}},	//   lakl, _dyse_, --, --, 
   {{0x09d42f8b,0x20c4001e,0x62940083,0x6cd40150}},	//   _হাজা, _hôi_, _kkyo, _ﺘﻨﺼﻴ, 
   {{0x61e42f8c,0x2d980142,0x00000000,0x00000000}},	//   nakl, _fyse_, --, --, 
   {{0x9fe00154,0xd5b82f8d,0x00000000,0x00000000}},	//   বলীগ, үси_, --, --, 
   {{0xd6d82f8e,0x20c40016,0xe8042cce,0x61e42f8f}},	//   пти_, _môi_, _राणा_, hakl, 
   {{0x4c901d18,0x61e42f90,0x7e6403a2,0x20c4001e}},	//   _сиёс, kakl, ohip, _lôi_, 
   {{0xc214013f,0x7e6401f7,0x62941418,0x61e42f91}},	//   _nbɔ_, nhip, _nkyo, jakl, 
   {{0x61e42f92,0xd4042f93,0x20c401fb,0x5dd40150}},	//   dakl, няни, _nôi_, _ﺘﺘﻤﻴ, 
   {{0xc2140134,0x62942f94,0x1a6403e6,0x00000000}},	//   _abɔ_, _akyo, _تیڤی_, --, 
   {{0x7e642f95,0xd3782f96,0x61e42f97,0xd7040212}},	//   khip, ячи_, fakl, _їзди, 
   {{0xe6840032,0x20c42f98,0x64640055,0x00000000}},	//   _үҙәк_, _bôi_, _ātių, --, 
   {{0x7e640882,0x99900209,0xc68c13ea,0x0fe000f7}},	//   dhip, ýyň_, _اِن_, лөнү, 
   {{0x62942f99,0x1cdc031c,0x4508031c,0x657c002d}},	//   _ekyo, _ལྦེ_, _ཁྱིར_, úshe, 
   {{0x61e42f9a,0x8330082e,0xb8ec025c,0x2d9803cd}},	//   bakl, _مريض, _ྱང_, _syse_, 
   {{0x61e40365,0x7c3c0784,0x43980302,0x645c0023}},	//   cakl, _anrr, _מבוג, ësiv, 
   {{0x8d742f9b,0xa3cc07f7,0x614405a9,0x09bc00cc}},	// [2bb0] رارا, षुव_, _لىيە, _উজলা, 
   {{0xe80404fa,0x7e6402b5,0x2d980306,0x00000000}},	//   _राधा_, ahip, _vyse_, --, 
   {{0x7c941823,0x2d982f9c,0x7e640882,0xadbc0064}},	//   اشقا, _wyse_, bhip, _манi, 
   {{0x7e642f9d,0x7c3c00e4,0xdd9000ec,0x00000000}},	//   chip, _enrr, _چوٽ_, --, 
   {{0x6e3c0730,0x6e2c2f9e,0x20c401fb,0x7c580131}},	//   _insb, mdab, _xôi_, بلەر_, 
   {{0x6e2c2f9f,0x61e42fa0,0x99840165,0x7b6401ec}},	//   ldab, zakl, adoů_, _өтсе, 
   {{0x61e42fa1,0x6e2c0067,0x81d800cc,0x00000000}},	//   yakl, odab, াণত_, --, 
   {{0x6e2c2fa2,0x7f3c008f,0xfbd00050,0x693401af}},	//   ndab, לעוו, _نتہ_, _инбу, 
   {{0x1fe002a6,0x69d82fa3,0x6e2c00c7,0x59080135}},	//   _বাসস, mbwe, idab, _གདགས_, 
   {{0xdb0c025a,0x69d817da,0x62942fa4,0x20c42fa5}},	//   _ngbû, lbwe, _skyo, _rôi_, 
   {{0x61e42fa6,0x6aa82fa7,0x20c4001e,0x03e000fe}},	//   takl, _khef, _sôi_, _খাদী_, 
   {{0x6e2c0218,0x05b800ab,0x7e640200,0x00000000}},	//   jdab, _उलटब, xhip, --, 
   {{0x61e42fa8,0x6e2c2fa9,0x69d820c7,0x00000000}},	//   rakl, ddab, ibwe, --, 
   {{0x6e3c2faa,0x23342fab,0x61e42fac,0xa0a401c0}},	//   _ansb, _ахир, sakl, тагд, 
   {{0x7e642fad,0x61e42fae,0xe2840209,0x5f0400a7}},	//   thip, pakl, _илки, ъзва, 
   {{0x20c401dc,0xfdd002f5,0x1cdc025c,0x6e2c0158}},	//   _tôi_, িণ্ড, _ལྦུ_, gdab, 
   {{0x65682faf,0x61442fb0,0x6e3c1e0b,0x660c0022}},	// [2bc0] nzeh, _репа, _dnsb, _ñaku, 
   {{0x69d82fb1,0x6e3c0450,0x6e2c2fb2,0x65682fb3}},	//   ebwe, _ensb, adab, izeh, 
   {{0x7e642fb4,0x59082fb5,0x65680112,0x46b000cd}},	//   phip, _གདངས_, hzeh, ुदाह, 
   {{0x7e64094a,0x6e3c0798,0xd12c2fb6,0x65680036}},	//   qhip, _gnsb, _امی_, kzeh, 
   {{0x6aa80066,0x186816c3,0x0d20049e,0x5f741f0d}},	//   _dhef, мади_, _күтү, _ساگر, 
   {{0x656802b9,0x69d80083,0x6aa82fb7,0x394000e2}},	//   dzeh, abwe, _ehef, ģis_, 
   {{0x6aa80943,0xa2c001ad,0x0704004b,0x73c400c7}},	//   _fhef, _रूल्, نيوي_, қәле, 
   {{0xb7bc005f,0x656801c7,0xda6400ec,0x00000000}},	//   _maģi, fzeh, _شازي, --, 
   {{0x34940124,0x78a8037e,0x85000fb4,0x65680036}},	//   лаир, _thdv, لوين, gzeh, 
   {{0x6e2c2fb8,0x5dd401ec,0x850004f2,0x00000000}},	//   zdab, _ﺘﻘﻴﻴ, گوین, --, 
   {{0x6e2c0548,0x741412ea,0x2c3400df,0x00000000}},	//   ydab, نوکا, אָרם_, --, 
   {{0x35c4013e,0x6568002f,0x6e2c058a,0x6aa80200}},	//   _садҳ, bzeh, xdab, _xhef, 
   {{0x51842fb9,0x6e2c00e2,0x00000000,0x00000000}},	//   туна, vdab, --, --, 
   {{0x645c02d3,0x6e2c0009,0x00000000,0x00000000}},	//   ësit, wdab, --, --, 
   {{0x3ce805f9,0x69d80009,0x00000000,0x00000000}},	//   _चौबे_, ybwe, --, --, 
   {{0x68ec2fba,0xe1c000ee,0x6e2c2fbb,0x4ea401a9}},	//   šadi, _гөрй, udab, трга, 
   {{0x6aa82fbc,0x3208035a,0x3134252c,0x00000000}},	// [2bd0] _rhef, _icay_, _сепр, --, 
   {{0x6aa82fbd,0x3f842fbe,0x09c8041c,0xddd400d7}},	//   _shef, ğmur_, ाड्य, rnyš, 
   {{0x6aa80b58,0xddc4068f,0xbae4007b,0xeff80023}},	//   _phef, _dokł, لكلي, ላኸይ_, 
   {{0xbca80075,0x66e407d6,0x6e2c058a,0xe8040a8a}},	//   ىدەك_, ҳока, qdab, _राहा_, 
   {{0x69d826bd,0xdd3003b9,0x00000000,0x00000000}},	//   rbwe, məşq, --, --, 
   {{0xe5a404a9,0x00000000,0x00000000,0x00000000}},	//   һийи, --, --, --, 
   {{0x3208127b,0xd7ec007b,0x00000000,0x00000000}},	//   _ocay_, سكي_, --, --, 
   {{0xe5a40075,0x656801c7,0xf7a800d1,0x80d400eb}},	//   лийи, tzeh, ﺷﯘﻧﺪ, _তিস্, 
   {{0x67d42fbf,0xa5d82fc0,0x00000000,0x00000000}},	//   _бозу, وبکر_, --, --, 
   {{0x32080857,0x65682fc1,0xa63401ec,0x00000000}},	//   _acay_, rzeh, _әнді, --, 
   {{0x65682fc2,0x00000000,0x00000000,0x00000000}},	//   szeh, --, --, --, 
   {{0x27e40295,0x26c4003a,0x656801c7,0x61442fc3}},	//   _heln_, _iulo_, pzeh, гема, 
   {{0x645c069c,0x29180139,0x3e800139,0x00000000}},	//   ësis, _äsad_, dätе_, --, 
   {{0x26c42fc4,0xa0340aaf,0xf1b40032,0x320802d0}},	//   _kulo_, دىست, шҡы_, _ecay_, 
   {{0x26c40ca8,0xa3cc00dc,0xb7bc0171,0x00000000}},	//   _julo_, षुः_, _paģi, --, 
   {{0x26c42fc5,0xe8e405d9,0x1e94030d,0xd354011a}},	//   _mulo_, _وڻ_, ургр, _תיקי_, 
   {{0x20741b74,0x116400dd,0x26c4016d,0xddc4033f}},	// [2be0] _бунё, _ملٹی_, _lulo_, _pokł, 
   {{0xefd4001f,0x21640137,0x00000000,0x00000000}},	//   ካቸው_, _атүг, --, --, 
   {{0x26c42fc6,0x320803ac,0xe72402f2,0x00000000}},	//   _nulo_, _ycay_, _بڵ_, --, 
   {{0x1988013e,0x3ce806e3,0xdef00092,0x00000000}},	//   нбеи_, _चौथे_, _ውሃና_, --, 
   {{0x26c4003a,0x27e40139,0x00000000,0x00000000}},	//   _aulo_, _beln_, --, --, 
   {{0x3ea02fc7,0x26c42fc8,0xf7b807d6,0xc8c403e6}},	//   llit_, _bulo_, نگاش_, دوون_, 
   {{0x26c42fc9,0x3ea00108,0xcc74011a,0xe814000d}},	//   _culo_, olit_, _עגלת_, _दउरा_, 
   {{0x26c4113c,0x3ea02fca,0x00000000,0x00000000}},	//   _dulo_, nlit_, --, --, 
   {{0x18a40137,0x00000000,0x00000000,0x00000000}},	//   _баам, --, --, --, 
   {{0x26c4011f,0xf8b005d9,0x3ea02fcb,0x13680139}},	//   _fulo_, _ڏکڻ_, hlit_, ешми_, 
   {{0x3ea02fcc,0x26c42fcd,0x80d400cc,0x91580241}},	//   klit_, _gulo_, _তিষ্, _ọ̀n_, 
   {{0x645c0240,0x3ea02fce,0x2fc000a2,0x0bb4011a}},	//   ësir, jlit_, _sghg_, טלים_, 
   {{0x3ea02fcf,0x4638008f,0x26c401c6,0xa8180150}},	//   dlit_, _רעדע, _zulo_, _ستەر_, 
   {{0x50642fd0,0x26c4009a,0x3ea02fd1,0x00000000}},	//   утма, _yulo_, elit_, --, 
   {{0x26c42fd2,0x3ea02fd3,0x00000000,0x00000000}},	//   _xulo_, flit_, --, --, 
   {{0x3ea02fd4,0x2bdc0882,0x1cdc0327,0x17740023}},	//   glit_, यर्थ, _ལྦང_, _ክንድኡ_, 
   {{0x9f48025a,0x00000000,0x00000000,0x00000000}},	// [2bf0] nabê_, --, --, --, 
   {{0x3ea02fd5,0x0b8800d8,0x00000000,0x00000000}},	//   alit_, нсеи_, --, --, 
   {{0xfbd000aa,0x0ba428eb,0xbb8400c6,0x5ae400d1}},	//   ستل_, ушам, ملكي, لقلە, 
   {{0x27e40b4b,0x3ea02fd6,0x26c42fd7,0x7f84036b}},	//   _seln_, clit_, _rulo_, _چلین, 
   {{0xc77000f7,0xda14000d,0x3834009d,0x00000000}},	//   өткө, _धउरत_, өнцр, --, 
   {{0x26c42fd8,0xfc6402e8,0x5d78010f,0x00000000}},	//   _pulo_, _лъсн, _יארק, --, 
   {{0x18640801,0x8aa40861,0x03e003d4,0xd6cc004b}},	//   ращи_, _брад, _খালী_, وقو_, 
   {{0xbb840491,0x661c01e4,0x00000000,0x00000000}},	//   _الفي, ĵsko, --, --, 
   {{0xeb980075,0x22500174,0x26c40ca8,0xb93400f3}},	//   _чиң_, _royk_, _wulo_, _летј, 
   {{0x26c42fd9,0x2da001ec,0x3ea02fda,0x00000000}},	//   _tulo_, _ﺃﻭﻟﻰ_, zlit_, --, 
   {{0x3ea02fdb,0xf86825a7,0x3834084c,0x67d4014b}},	//   ylit_, _حملي_, _ынфр, _боҷу, 
   {{0xe6a4004e,0x3ea001b9,0x1fe000eb,0x00000000}},	//   _тузү, xlit_, _বাইস, --, 
   {{0x3ea00205,0x00000000,0x00000000,0x00000000}},	//   vlit_, --, --, --, 
   {{0x3ea0062c,0x00000000,0x00000000,0x00000000}},	//   wlit_, --, --, --, 
   {{0x3ea02fdc,0x9e740063,0x630400d1,0x2328014b}},	//   tlit_, аћај, _ئوبل, _ройи_, 
   {{0x3f8c003d,0x3ea02fdd,0xe2982fde,0x11e00395}},	//   ħdu_, ulit_, _шай_, _джъм, 
  
   {{0x3ea005a4,0x63ac00df,0xd2b4011a,0x9c8800d1}},	// [2c00] rlit_, _ŝanh, _דלקת_, پپاق_, 
   {{0x3ea02fdf,0x998400d7,0x00000000,0x00000000}},	//   slit_, jdoš_, --, --, 
   {{0xf1a82fe0,0x5f440244,0x00000000,0x00000000}},	//   _لایه_, _ئنجل, --, --, 
   {{0x62842fe1,0x38a00428,0x00000000,0x00000000}},	//   nnko, mòri_, --, --, 
   {{0x62842fe2,0xd82422f7,0x397800ec,0x4e24030d}},	//   inko, идди, دشاھ_, _тоян_, 
   {{0x7d042fe3,0x62840112,0x6cb801af,0x2d9801ee}},	//   muis, hnko, _быср_, _сөсө_, 
   {{0x7d042fe4,0x61f402d0,0xf74800ec,0x8c1808c3}},	//   luis, _odyl, العي_, _שולי, 
   {{0x628401a4,0x7d040393,0x59742fe5,0x60d401e3}},	//   jnko, ouis, _кызу, _otym, 
   {{0x7d042fe6,0xca700345,0x00000000,0x00000000}},	//   nuis, _بۆنک, --, --, 
   {{0x62842fe7,0x98a42fe8,0x61f42fe9,0x22900306}},	//   enko, _тизе, _adyl, máky_, 
   {{0x7d042fea,0x229002fb,0x60d42feb,0x98540210}},	//   huis, láky_, _atym, głą_, 
   {{0x7d042fec,0x6284143a,0x00000000,0x00000000}},	//   kuis, gnko, --, --, 
   {{0x7d042fed,0x61f40cfd,0x4fc40801,0x22900306}},	//   juis, _ddyl, исва, náky_, 
   {{0x03742fee,0x7d042fef,0xdedc044e,0x62842ff0}},	//   احیت_, duis, ሕሪኡ_, anko, 
   {{0x60d42ff1,0x92682ff2,0xfc5802d3,0x38a00ba1}},	//   _etym, _арпа_, _የረጋግ, gòri_, 
   {{0xdce40365,0x7d042ff3,0x2c1800dc,0x5f300092}},	//   _aykı, fuis, न्नं_, _ችግራቸ, 
   {{0x7d042ff4,0xa3cc03e5,0x2290219b,0x60d400a2}},	// [2c10] guis, षुक_, jáky_, _gtym, 
   {{0x22900216,0x00000000,0x00000000,0x00000000}},	//   dáky_, --, --, --, 
   {{0x6e942ff5,0x41740066,0x00000000,0x00000000}},	//   _гину, _هایس, --, --, 
   {{0x7d042ff6,0xe8f40597,0xed500014,0x60d401f4}},	//   buis, مستخ, _ٹھر_, _ytym, 
   {{0x7d04213b,0xd364004b,0x98540210,0x423800df}},	//   cuis, _ځه_, złą_, ינאל_, 
   {{0xd3640272,0x26d802fb,0x9f480100,0x00000000}},	//   _فه_, _čsob_, fabè_, --, 
   {{0x62840034,0x78240137,0x998415b2,0xe7380395}},	//   ynko, زعول, rdoš_, уей_, 
   {{0x22900306,0x28200092,0xba0800cf,0x672c0210}},	//   báky_, _ተፎካካ, _ەتەك_, łajo, 
   {{0x22900306,0x8464010b,0xd840022a,0x17e400fe}},	//   cáky_, изиң_, áčí_, _নাৰি, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2c1800dc,0xc66800ee,0x36d42ff7,0x60d4012d}},	//   न्यं_, _ишде_, _дохр, _stym, 
   {{0x62842ff8,0x201805b1,0x36340150,0x00000000}},	//   unko, _sbpi_, _ورنس, --, 
   {{0x62842ff9,0x200c01b8,0x38a00086,0x66080cf0}},	//   rnko, _öfik_, wòri_, mgek, 
   {{0x66082ffa,0x1dd8012c,0x7d042ffb,0x38a02508}},	//   lgek, युनत, vuis, tòri_, 
   {{0x62840158,0x7fb401b9,0xc21001d9,0x2290022a}},	//   pnko, زلرچ, _ۂژ_, záky_, 
   {{0x66082ffc,0x7d042ffd,0xf1d005d7,0x9f482ffe}},	//   ngek, tuis, थुआन, nabé_, 
   {{0x60d4009a,0x38a0068c,0x6608002f,0x2d940153}},	// [2c20] _utym, sòri_, igek, орфс, 
   {{0x7d042fff,0x66080732,0x22900122,0x4d60034f}},	//   ruis, hgek, váky_, чкув, 
   {{0x7d043000,0xec3401b9,0x58840022,0x00000000}},	//   suis, تولگ, ҩыла, --, 
   {{0x7d043001,0xd1d00020,0x35a40020,0x22900122}},	//   puis, _ጨዋታ_, ገንባት_, táky_, 
   {{0x66083002,0x7d043003,0x98a43004,0x649c0ba1}},	//   dgek, quis, биде, nèis, 
   {{0x200824ba,0x22900122,0xd9440116,0x91b800d9}},	//   ngbi_, ráky_, _қези, אמני, 
   {{0x59080003,0x66083005,0x95c80b3b,0x22900306}},	//   _གདམས_, fgek, лупа_, sáky_, 
   {{0x66083006,0x229002f0,0x4664004e,0x9a9c010a}},	//   ggek, páky_, йрым_, _чугi, 
   {{0xa5080131,0xddc40153,0x200803e0,0x4d7800df}},	//   لىيە_, _alkū, kgbi_, ָריע, 
   {{0x84840023,0x00000000,0x00000000,0x00000000}},	//   _ዝብልን_, --, --, --, 
   {{0x9f480214,0xdb0c0241,0x8c180677,0x00000000}},	//   babé_, _igbó, נוטי, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x73c43007,0xdb08032e,0x00000000,0x00000000}},	//   _мәне, _ánæs, --, --, 
   {{0x2e3401f2,0x0f7001d5,0xd9a80154,0x00000000}},	//   _ụf_, зғор, _ওলাম, --, 
   {{0x1cdc0156,0x44780375,0x00000000,0x00000000}},	//   _ལསཔ_, _תנוע, --, --, 
   {{0xae0421ef,0xadd83008,0x00000000,0x00000000}},	//   تورى, рмау_, --, --, 
   {{0xcbc43009,0x463800c8,0x649c068c,0xdb0c0241}},	// [2c30] مزاي, נעמע, mèir, _ogbó, 
   {{0x660802ce,0x649c0ba1,0xddc4013a,0x00000000}},	//   zgek, lèir, _mokř, --, 
   {{0x66080af9,0x6ed40210,0xdfd00066,0x00000000}},	//   ygek, _bąbe, _تيپ_, --, 
   {{0xdb0c0ca8,0x649c067c,0xdd980107,0x2be80154}},	//   _agbó, nèir, ушӣ_, খলেই_, 
   {{0x6f1401af,0xfbe8015b,0x16f40327,0x69340137}},	//   ltzc, _পারত, ྗེའམ_, юнду, 
   {{0xf990300a,0x9f48020c,0x6d4c0009,0x97c400fb}},	//   ربن_, wabé_, mxaa, ҙрәһ, 
   {{0xb8d006e3,0x66082a28,0x6d4c300b,0xaa440032}},	//   _टी_, tgek, lxaa, _һеңл, 
   {{0xc98400f3,0xe8041777,0x00000000,0x00000000}},	//   _лузи, _राका_, --, --, 
   {{0x6608300c,0x6d4c0429,0x649c067c,0x9f480066}},	//   rgek, nxaa, dèir, rabé_, 
   {{0x6608300d,0x6ed40210,0x00000000,0x00000000}},	//   sgek, _ząbe, --, --, 
   {{0x224806ed,0x6608053d,0x17080ed8,0x00000000}},	//   апни_, pgek, _نفلی_, --, 
   {{0x2c180882,0x00000000,0x00000000,0x00000000}},	//   न्तं_, --, --, --, 
   {{0x672002d0,0xe5a400d8,0x00000000,0x00000000}},	//   _hplj, _ќили, --, --, 
   {{0x6d4c058a,0x00000000,0x00000000,0x00000000}},	//   dxaa, --, --, --, 
   {{0xd36c0592,0x10a0300e,0x6d4c058a,0x00000000}},	//   _لهو_, фирн, exaa, --, 
   {{0x30d800cc,0x00000000,0x00000000,0x00000000}},	//   _তিৰস, --, --, --, 
   {{0x1be80364,0x1d08300f,0x9db806a6,0x6d4c0067}},	// [2c40] идаи_, рези_, рыву_, gxaa, 
   {{0x67200989,0xf1b80216,0x656c010e,0x5ed41291}},	//   _oplj, ýše_, _ýahu, _وتجز, 
   {{0xdb0c0241,0x6d4c3010,0x5b24007b,0x2c1800dc}},	//   _agbò, axaa, تفال, न्धं_, 
   {{0x6d4c3011,0x09e003b7,0x9d443004,0xdd940124}},	//   bxaa, доцн, _демд, _ҳаҭы, 
   {{0xa3d8000d,0x00000000,0x00000000,0x00000000}},	//   ़डा_, --, --, --, 
   {{0x2c1800dc,0x8d780092,0x00000000,0x00000000}},	//   न्दं_, ሪያቸው_, --, --, 
   {{0xdb0c0248,0x3d1400fd,0x7e643012,0x59b800bc}},	//   _egbò, läw_, okip, ेशहर, 
   {{0x7e643013,0xddc40118,0x00000000,0x00000000}},	//   nkip, _pokř, --, --, 
   {{0xceb006a9,0x38a0068c,0x5ba800c5,0x35c80022}},	//   ויה_, fòrt_, _करुव, аҳҵо_, 
   {{0x33743014,0xb9e00020,0x88b001d9,0x7e6401f4}},	//   згор, _ጦር_, _ہیۆچ, hkip, 
   {{0x3d140227,0x7e643015,0xdeb80b82,0x00000000}},	//   häw_, kkip, ታምን_, --, 
   {{0x63b40122,0x00000000,0x00000000,0x00000000}},	//   ýzna, --, --, --, 
   {{0x6d4c102c,0x649c067c,0x00000000,0x00000000}},	//   xxaa, rèir, --, --, 
   {{0xad2404da,0x3d140166,0x394001f4,0x00000000}},	//   ۋىزى, däw_, äisy_, --, 
   {{0x649c0561,0x0874010f,0x00000000,0x00000000}},	//   pèir, קעלט_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d4c0009,0xd01802e8,0x656c010e,0x98540210}},	// [2c50] uxaa, _кфн_, _ýaht, słę_, 
   {{0x7e64013c,0x6d4c0014,0xdb1c0306,0x00000000}},	//   akip, rxaa, _šváb, --, 
   {{0x7e64020c,0x6d4c0009,0x00000000,0x00000000}},	//   bkip, sxaa, --, --, 
   {{0xba743016,0x7e643017,0x672c012d,0x3d140139}},	//   وانت, ckip, łajk, bäw_, 
   {{0xf9a401d9,0xf0340023,0x00000000,0x00000000}},	//   وٕمُ, _ብምስም, --, --, 
   {{0xd5e001e1,0xeff80092,0x00000000,0x00000000}},	//   _alò, ላቸዉ_, --, --, 
   {{0x25a80f03,0xefcc01f3,0xfb8400c0,0x00000000}},	//   _šal_, _ኤንድ_, _жытн, --, 
   {{0x5378044e,0x24080131,0x00000000,0x00000000}},	//   _ኣሕዋት_, әнни_, --, --, 
   {{0x69c83018,0xf8f40276,0x649801ee,0x00000000}},	//   _igee, _оптэ, йтор_, --, 
   {{0x68e83019,0x7e64005a,0x33d40212,0xb924007b}},	//   _iwed, zkip, міют, _تفكي, 
   {{0x7e641bb7,0x68e8301a,0x00000000,0x00000000}},	//   ykip, _hwed, --, --, 
   {{0x68e82c6b,0x00000000,0x00000000,0x00000000}},	//   _kwed, --, --, --, 
   {{0x38a0068c,0x613401d3,0xe80401f9,0x00000000}},	//   còrs_, dülá, _राञा_, --, 
   {{0x68e805b8,0x232800d8,0x201c301b,0x00000000}},	//   _mwed, _гоки_, ýti_, --, 
   {{0x1ea8301c,0x69c80a55,0x68e81992,0x1fa8301d}},	//   ماري_, _ogee, _lwed, скви_, 
   {{0x69c8301e,0x4370301f,0x7e640194,0x68e83020}},	//   _ngee, _нуқт, ukip, _owed, 
   {{0x7e643021,0x68e83022,0x00000000,0x00000000}},	// [2c60] rkip, _nwed, --, --, 
   {{0x7e643023,0xeff80201,0x69c83024,0x9f483025}},	//   skip, ላቸው_, _agee, labí_, 
   {{0x68e83026,0xe8043027,0xd24c3028,0x9058011a}},	//   _awed, _राजा_, _شنی_, _הכית, 
   {{0x9f480789,0x19f40014,0x00000000,0x00000000}},	//   nabí_, سِتھ_, --, --, 
   {{0x69c800e4,0xd7f83029,0xf8b001e2,0x00000000}},	//   _dgee, буй_, نکئ_, --, 
   {{0xdcb0302a,0xb8f4302b,0x7d04302c,0x3ce004cc}},	//   _سىز_, _सं_, mris, mpiv_, 
   {{0x25c003be,0xd5e00241,0x7d041d81,0x68e8302d}},	//   ərlə_, _aló, lris, _ewed, 
   {{0x69c804ba,0xc028009e,0x656c0327,0xf4d80117}},	//   _ggee, মায়ণ_, _żaha, омиш_, 
   {{0xd498302e,0x68e800a9,0x7d04302f,0x00000000}},	//   йро_, _gwed, nris, --, 
   {{0x7d043030,0x73c40032,0xdb0802d2,0x00000000}},	//   iris, мәйе, _ínót, --, 
   {{0x7d043031,0x68e80d27,0xe87401d5,0x95c83032}},	//   hris, _zwed, _تنلگ, _лула_, 
   {{0x38a0067c,0x9a940092,0x00000000,0x00000000}},	//   pòrs_, _ሆኖአል_, --, --, 
   {{0x386c00bc,0x416800d8,0x00000000,0x00000000}},	//   _kldr_, пјрм_, --, --, 
   {{0x7d043033,0x94100605,0xf1e00131,0x00000000}},	//   dris, _ɔyɛ_, _ﺋﯩﻨﺘ, --, 
   {{0x7d043034,0x82f400e3,0x00000000,0x00000000}},	//   eris, _فريز_, --, --, 
   {{0x7d043035,0x69ac000d,0x63640023,0x9268030d}},	//   fris, _जरली, _ዝመጣጠ, _ырла_, 
   {{0x7d043036,0x82343037,0xaffc0212,0x21300205}},	// [2c70] gris, _سريا, _копi, _gsyh_, 
   {{0x68e8006f,0xbec80171,0x00000000,0x00000000}},	//   _rwed, _skūš, --, --, 
   {{0x7d043038,0x68e80155,0x00000000,0x00000000}},	//   aris, _swed, --, --, 
   {{0x7d180491,0x68e80d72,0x386c0109,0x3ce8012d}},	//   éasá, _pwed, _aldr_, _चौके_, 
   {{0x7d043039,0xe944303a,0x6d840014,0x499000e5}},	//   cris, برای, _غۅطہ_, ریئر, 
   {{0x01380302,0xdb0c067c,0xd9400137,0x00000000}},	//   פרות_, _ozbè, теши, --, 
   {{0xb8f40243,0x1dd813da,0x00000000,0x00000000}},	//   _सू_, युवत, --, --, 
   {{0x69c80a40,0x386c0327,0x68e8303b,0x56900f5c}},	//   _ugee, _eldr_, _twed, кајт, 
   {{0x68e8303c,0x852003e6,0xe578303d,0xc7c406ed}},	//   _uwed, رودۆ, юзи_, _есеи, 
   {{0x2a6c303e,0xdde404fe,0x00000000,0x00000000}},	//   _hleb_, _āpōp, --, --, 
   {{0xa228303f,0x2a6c3040,0x04fc015b,0x7d0400b5}},	//   ожна_, _kleb_, ্বের_, zris, 
   {{0x7d043041,0x2a6c020b,0x00000000,0x00000000}},	//   yris, _jleb_, --, --, 
   {{0x5ba83042,0x7d04022e,0x00000000,0x00000000}},	//   _कर्व, xris, --, --, 
   {{0x63843043,0x9f480589,0x24802305,0x64a40166}},	//   _огла, jabã_, _öhm_, _юала, 
   {{0x9e643044,0x7d043045,0x4fa0011c,0x00000000}},	//   وارن, wris, вирв, --, 
   {{0xdde801a9,0xd12c00ec,0x00000000,0x00000000}},	//   ترسه_, _چمي_, --, --, 
   {{0xd12c04fb,0x00000000,0x00000000,0x00000000}},	// [2c80] _نمي_, --, --, --, 
   {{0xed3405f5,0x3ac80213,0x5f2828ed,0x00000000}},	//   ээсэ, _aşpa_, _доом_, --, 
   {{0x2a6c062c,0x00000000,0x00000000,0x00000000}},	//   _bleb_, --, --, --, 
   {{0x3a200510,0x7d043046,0x2a6c003e,0x998402f2}},	//   ýip_, pris, _cleb_, ولاو, 
   {{0x611002ea,0x3ea003a2,0xaac43047,0x660c00e4}},	//   _bɛlɛ, moit_, رتمن, _ñaky, 
   {{0xd6d83048,0x3ea005c7,0x2a6c003e,0x1768010b}},	//   оти_, loit_, _eleb_, жрип_, 
   {{0x7a24007f,0xf1a4000d,0x3940010f,0x00000000}},	//   _pčtč, _गुनन, ŭis_, --, 
   {{0x2a6c3049,0xd5641b0a,0x00000000,0x00000000}},	//   _gleb_, дтоп, --, --, 
   {{0x62840162,0x18a400db,0xd40400f5,0x00000000}},	//   _íhoy, _жаам, мяни, --, 
   {{0x09000a89,0x3ea00076,0x985401a9,0xd49801a9}},	//   _шпун, hoit_, _ўташ, ўри_, 
   {{0xd37800d6,0x3ea00649,0x41c4031c,0x73880116}},	//   ючи_, koit_, _གུཔྟ, яриң_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x0fe00228,0x3ea0054e,0x00000000,0x00000000}},	//   көнү, doit_, --, --, 
   {{0x32040209,0x104802bf,0x33940024,0x00000000}},	//   şly_, цями_, _палё, --, 
   {{0xc058242f,0x00000000,0x00000000,0x00000000}},	//   фія_, --, --, --, 
   {{0x02a4035b,0x3ea0036e,0xf48402f2,0xddd4010e}},	//   _ирым, goit_, _تاڵی, njyň, 
   {{0x86580375,0x00000000,0x00000000,0x00000000}},	// [2c90] קדמי, --, --, --, 
   {{0x291800de,0x6ab800cd,0x00000000,0x00000000}},	//   _īsa_, ेद्र, --, --, 
   {{0x2a6c304a,0x00000000,0x00000000,0x00000000}},	//   _pleb_, --, --, --, 
   {{0x0ea405f9,0x3ea0304b,0x2ab4005c,0x00000000}},	//   _कीचड, coit_, kåbe_, --, 
   {{0xf1a41d8a,0x2a6c0076,0x6e2c304c,0x00000000}},	//   _गुमन, _vleb_, meab, --, 
   {{0xe7382e9a,0x6e2c304d,0x1cac025c,0x6e2800e8}},	//   зек_, leab, _ཕེར_, _ñebb, 
   {{0xa6c41a59,0xddc40139,0x2a6c0254,0x3f9c0162}},	//   ىقتى, _kokş, _tleb_, _øvut_, 
   {{0xbb48304e,0x00000000,0x00000000,0x00000000}},	//   _تلفن_, --, --, --, 
   {{0xddc40166,0x00000000,0x00000000,0x00000000}},	//   _mokş, --, --, --, 
   {{0xe4500491,0x6e2c304f,0x67d4010b,0x888001d3}},	//   اضة_, heab, _чожу, _جیتن, 
   {{0xe2840861,0x4e0c0316,0x1cac031c,0x00000000}},	//   елни, िलाई_, _ཕེལ_, --, 
   {{0x69d80042,0xa4d400d4,0x00000000,0x00000000}},	//   ncwe, _зоді, --, --, 
   {{0xe4b80220,0x3ea03050,0x952001b9,0xd36c0214}},	//   _елді_, voit_, _یکیم, لهی_, 
   {{0xa0683051,0x27300427,0xd24c0220,0xa878010f}},	//   чага_, _kšn_, _ۇنى_, לאָר, 
   {{0x3ea026bb,0xa0a43052,0x629c0010,0x6e2c00ae}},	//   toit_, _җанд, čsob, feab, 
   {{0x6e2c3053,0xdb0c003e,0x00000000,0x00000000}},	//   geab, _uzbé, --, --, 
   {{0x3ea03054,0x1c443055,0xeb400092,0x201c0254}},	// [2ca0] roit_, ннам, _የሚገለ, õtis_, 
   {{0x62843056,0x3ea00129,0x4c800353,0x00000000}},	//   liko, soit_, глув, --, 
   {{0x6e2c2caa,0x4fd4011a,0x3124004e,0x79ac00d1}},	//   beab, _רוטב_, _здөг, ﺴﺘﯩﻤ, 
   {{0x6e2c3057,0x69d83058,0x62843059,0xf1a401ad}},	//   ceab, gcwe, niko, _गुडन, 
   {{0x62840810,0x0d2000d1,0x9984030a,0xfcc401ee}},	//   iiko, _йүтү, reoů_, _аҙам, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6284305a,0x7bdc04ce,0x24840254,0x00000000}},	//   kiko, _ifru, dilm_, --, 
   {{0x6284305b,0x34c80303,0x00000000,0x00000000}},	//   jiko, रद्द, --, --, 
   {{0x6284305c,0x19b80323,0x35b4305d,0xddd401d3}},	//   diko, _хувь_, ъбир, nnyű, 
   {{0x6e2c305e,0x62840af9,0x1cac0327,0x2ab4005c}},	//   zeab, eiko, _ཕེས_, råbe_, 
   {{0x6e2c009f,0xd62800d8,0x99d000eb,0x00000000}},	//   yeab, _ноже_, ারীক, --, 
   {{0x6284305f,0x93440ed0,0x39440254,0x2484000d}},	//   giko, _үнде, _krms_, ailm_, 
   {{0x7bdc3060,0x93a801ed,0x6e2c045a,0x7afc0171}},	//   _ofru, _کاشف_, veab, _lvrt, 
   {{0xc0583061,0x74143062,0x7afc0139,0x62843063}},	//   ніс_, _شوبا, _ovrt, aiko, 
   {{0x62843064,0x6e2c3065,0xf16401e1,0x7f943066}},	//   biko, teab, _iyọ̀_, гарх, 
   {{0x7bdc3067,0x62843068,0xad2c0092,0x00000000}},	//   _afru, ciko, _ስርጭቶ, --, 
   {{0x6e2c3069,0x9f48306a,0x7afc00b8,0x7e440124}},	// [2cb0] reab, rabá_, _avrt, ыхре, 
   {{0x6e2c306b,0xf8b801fb,0x705400f7,0xbca800d1}},	//   seab, _nhĩ_, _شنجا, ۈدەك_, 
   {{0x6e2c02ea,0xab6c001f,0x7afc1a48,0x39442517}},	//   peab, _በዚያው_, _cvrt, _arms_, 
   {{0xe8f40244,0x00000000,0x00000000,0x00000000}},	//   نستخ, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6284306c,0xc710002b,0xf8b80208,0x00000000}},	//   ziko, _amūḍ, _chĩ_, --, 
   {{0x6284306d,0x3944004e,0xa694147e,0xfbe800fe}},	//   yiko, _erms_, криј, _পাচত, 
   {{0x6284306e,0xf1640248,0x39440175,0xdd8c00e5}},	//   xiko, _ayọ̀_, _frms_, _اڈہ_, 
   {{0x7afc19d6,0x49000c75,0x799400d8,0x57b004b4}},	//   _zvrt, _сүлг, _битф, лбәт, 
   {{0x6284306f,0x7bdc01c6,0x291c009f,0x00000000}},	//   wiko, _xfru, mtwa_, --, 
   {{0xe2983070,0xe3b802d5,0x9f5c0205,0x00000000}},	//   дан_, ьбо_, ütü_, --, 
   {{0xfbe80183,0xe5a400c7,0x24840037,0x00000000}},	//   _পাছত, _ҧиҧи, silm_, --, 
   {{0xf65000f4,0x95b400c7,0x00000000,0x00000000}},	//   _دئل_, _иршә, --, --, 
   {{0x62843071,0x291c3072,0xf1b400fb,0x00000000}},	//   siko, itwa_, ыҡы_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7bdc3073,0x291c3074,0x62841bce,0xddc400ef}},	//   _sfru, ktwa_, qiko, _alkš, 
   {{0x291c0054,0x21743075,0x21140073,0x00000000}},	// [2cc0] jtwa_, _шукр, _तमिळ_, --, 
   {{0x1f640588,0x28d40131,0x00000000,0x00000000}},	//   _аком, ﻟﻪﺗﻠ, --, --, 
   {{0xdbdc01e1,0x00000000,0x00000000,0x00000000}},	//   _bíòd, --, --, --, 
   {{0xddc400ef,0x1988035b,0x394401ef,0xfde800f1}},	//   _elkš, мбеи_, _prms_, _سکرو_, 
   {{0x2bf000fe,0x00000000,0x00000000,0x00000000}},	//   _চাৰে_, --, --, --, 
   {{0x7afc3076,0x3a2402fa,0x48100212,0x81d800eb}},	//   _tvrt, _wbmp_, иміс, িরি_, 
   {{0x7c3c2d53,0x39440798,0x7afc110c,0x629400b5}},	//   _iarr, _wrms_, _uvrt, _ojyo, 
   {{0x7c3c3077,0xcf9000d9,0x00000000,0x00000000}},	//   _harr, יטו_, --, --, 
   {{0x291c0034,0x75843078,0x81d8015b,0x89d4036b}},	//   ctwa_, ыңда, িরা_, _شولر_, 
   {{0x7c3c3079,0xdb0c0356,0x76d80107,0x00000000}},	//   _jarr, _izbâ, _зудӣ_, --, 
   {{0x7c3c307a,0x00000000,0x00000000,0x00000000}},	//   _marr, --, --, --, 
   {{0x7c3c307b,0x55e40114,0x68ec0356,0x03c00139}},	//   _larr, _родб, ţade, шсым, 
   {{0x7c3c307c,0x316c307d,0x63800124,0x29c000a2}},	//   _oarr, áez_, иҳәа, _ỳaz_, 
   {{0x7c3c307e,0x534401c6,0x00000000,0x00000000}},	//   _narr, _ахиа, --, --, 
   {{0x4ea4009d,0x00000000,0x00000000,0x00000000}},	//   враа, --, --, --, 
   {{0x7c3c307f,0x8d743080,0x6b742cc8,0x291c0472}},	//   _aarr, پارا, ңлау, ytwa_, 
   {{0x7c3c3081,0x201c0137,0x6fc40154,0x79ac00d1}},	// [2cd0] _barr, òtic_, ্রেই, ﺴﺘﯧﻤ, 
   {{0x7c3c3082,0xb034228c,0x5ee00154,0x00000000}},	//   _carr, _снош, _ফিরে, --, 
   {{0x7c3c3083,0x09c80882,0x8bc40138,0x1f2401d9}},	//   _darr, िश्य, тсад, _یِیہ, 
   {{0x7c3c3084,0x63b402f0,0x7de40816,0x3a2001e4}},	//   _earr, ýzni, _вірд, ϲipe_, 
   {{0x69243085,0x6e3c035a,0xc27c05d0,0x574401ec}},	//   умла, _iasb, וראי, ғзым_, 
   {{0x7c3c3086,0x6e3c3087,0xfc6406bb,0x6c78010f}},	//   _garr, _hasb, _късн, _טאָפ, 
   {{0x64a43088,0x6e3c3089,0x291c308a,0x09d8015b}},	//   ғана, _kasb, stwa_, দরবা, 
   {{0x7c3c308b,0x9f5c004a,0xe61801e0,0x00000000}},	//   _zarr, ûté_, хди_, --, 
   {{0x7c3c308c,0x6e3c308d,0x64a40022,0x00000000}},	//   _yarr, _masb, лаиа, --, 
   {{0x649c0228,0x7c3c308e,0x6e3c0af9,0x49b000d1}},	//   nèix, _xarr, _lasb, _йәһу, 
   {{0xf770308f,0xf8683090,0x684401e0,0x6ed40210}},	//   _وام_, _جملي_, _инҡа, _dąbk, 
   {{0x6e3c3091,0x00000000,0x00000000,0x00000000}},	//   _nasb, --, --, --, 
   {{0x81ac09bd,0xa6a800db,0xc1040116,0x00000000}},	//   কেন_, _قاچق_, шүпл, --, 
   {{0x65680526,0xdfd03092,0x6ed4012d,0x04640f06}},	//   myeh, صير_, _gąbk, _штем, 
   {{0x7c3c3093,0x65680280,0x00000000,0x00000000}},	//   _rarr, lyeh, --, --, 
   {{0x7c3c3094,0x6e3c0548,0x442405b1,0x6aa8009b}},	//   _sarr, _casb, _hbn_, _nkef, 
   {{0x65683095,0x61443096,0xdcb01473,0x9c240220}},	// [2ce0] nyeh, _сепа, مىر_, лдад, 
   {{0x7c3c3097,0x61f43098,0x6e3c0e89,0x6aa8035a}},	//   _qarr, _heyl, _easb, _akef, 
   {{0x7c3c3099,0x61f4309a,0x6e3c309b,0x60d4309c}},	//   _varr, _keyl, _fasb, _huym, 
   {{0xe3c400bd,0x7c3c309d,0x61f4047e,0x99d0015b}},	//   _এভাব, _warr, _jeyl, ার্ক, 
   {{0x61f4309e,0x58840598,0x44240b94,0x0d80309f}},	//   _meyl, лыка, _obn_, _глян, 
   {{0x442430a0,0x61f430a1,0x60d40280,0x7c3c30a2}},	//   _nbn_, _leyl, _muym, _uarr, 
   {{0x572430a3,0x6aa80093,0x6e3c00ca,0xfbb830a4}},	//   ارتق, _fkef, _yasb, _अरिम, 
   {{0x61f430a5,0x6e3c058a,0x57b00150,0x00000000}},	//   _neyl, _xasb, _құйт, --, 
   {{0x442430a6,0x8500004b,0xe9a40050,0x20180356}},	//   _bbn_, موين, _پۯون_, _ocpi_, 
   {{0x20180175,0x12e402dd,0x741430a7,0x44240f85}},	//   _ncpi_, лімг, جودا, _cbn_, 
   {{0x61f430a8,0x4424017a,0x47d00451,0xc68c0014}},	//   _beyl, _dbn_, _ايمر, _کِن_, 
   {{0x2018031c,0x656800ca,0x60d4037e,0x442430a9}},	//   _acpi_, byeh, _buym, _ebn_, 
   {{0x442401ab,0x61f430aa,0x60d40139,0x518430ab}},	//   _fbn_, _deyl, _cuym, ууна, 
   {{0x850000aa,0x60d42fbe,0x76400728,0xddd40055}},	//   _اوون, _duym, ldmy, bhyū, 
   {{0xb4c00141,0xceb8026a,0x6e3c30ac,0x61f430ad}},	//   ंगी_, еља_, _pasb, _feyl, 
   {{0x6e3c30ae,0x4ea430af,0x764030b0,0x43b00150}},	//   _qasb, урга, ndmy, _دەپء, 
   {{0x6e3c30b1,0xb80423ef,0x60d4010e,0x31340354}},	// [2cf0] _vasb, रणाम_, _guym, _тепр, 
   {{0x6aa830b2,0x6e3c30b3,0x61f430b4,0x00000000}},	//   _skef, _wasb, _zeyl, --, 
   {{0x649c0228,0x6e3c0ac5,0x61f40009,0xa03400d1}},	//   rèix, _tasb, _yeyl, _ئىپت, 
   {{0x61f400ac,0x60d4011f,0x6e3c30b5,0xb4c02cbb}},	//   _xeyl, _yuym, _uasb, ंगु_, 
   {{0xc27c008f,0x00000000,0x00000000,0x00000000}},	//   ערדי, --, --, --, 
   {{0x1cac0327,0xa764004e,0x00000000,0x00000000}},	//   _ཕེག_, иклд, --, --, 
   {{0x44240010,0x6aa80327,0x57800055,0x6f000332}},	//   _rbn_, _tkef, _kāṇā_, álch, 
   {{0x6aa802d0,0xd75401e2,0x00000000,0x00000000}},	//   _ukef, ؤليت_, --, --, 
   {{0x4424010a,0xb4c02232,0x74f801c0,0x61f430b6}},	//   _pbn_, ंगू_, лээс_, _reyl, 
   {{0x61f430b7,0x278801ee,0x00000000,0x00000000}},	//   _seyl, _иреү_, --, --, 
   {{0x44240175,0x60d401a9,0x00000000,0x00000000}},	//   _vbn_, _suym, --, --, 
   {{0x61f40978,0x614430b8,0x216800d6,0x20180129}},	//   _qeyl, аема, вими_, _scpi_, 
   {{0x2018056a,0x4424004d,0x60d430b9,0x00000000}},	//   _pcpi_, _tbn_, _quym, --, 
   {{0xd46430ba,0x442430bb,0x61f430bc,0x1ea80451}},	//   _више_, _ubn_, _weyl, چاري_, 
   {{0x61f430bd,0x644030be,0x1ea830bf,0x578000b8}},	//   _teyl, mdli, ناري_, _bāṇā_, 
   {{0x53980375,0x1cac031c,0x3afc0248,0x3aec0241}},	//   _ביצו, _ཕེང_, _lápá_, _lòpò_, 
   {{0xc050069c,0x64400b1d,0x7874026c,0x1cb8007b}},	// [2d00] _ኣገልግ, odli, _làva, نائب_, 
   {{0xd1b80201,0xd12c30c0,0xeff8001f,0x2c640014}},	//   ተኞች_, _کمی_, ዋቸው_, ٝدمُ, 
   {{0x9ac401ed,0x00000000,0x00000000,0x00000000}},	//   لگرہ_, --, --, --, 
   {{0x50d00014,0x644030c1,0xf38c010f,0x00000000}},	//   _دٲیر, hdli, עראָ, --, 
   {{0xc9a40556,0xc980005b,0xd83830c2,0x00000000}},	//   авце_, жущи, вэй_, --, 
   {{0xc2e82baf,0x644001a4,0xf1b80030,0x36d41d0f}},	//   _কিনি_, jdli, ýši_, бокр, 
   {{0x644030c3,0x00000000,0x00000000,0x00000000}},	//   ddli, --, --, --, 
   {{0x64400639,0xda700014,0x95c80414,0x6e600092}},	//   edli, _بُر_, купа_, _ወገኖች, 
   {{0x644001a4,0x76400423,0x5fc40073,0x00000000}},	//   fdli, rdmy, ळेतल, --, 
   {{0xb4c0006d,0x534430c4,0x644030c5,0x2450167e}},	//   ंगे_, ахма, gdli, كچىس, 
   {{0x2250207a,0x9d20015b,0x4bf80375,0xf98800f1}},	//   _bnyk_, নিয়ন_, כליס, _شخړه_, 
   {{0x644030c6,0xe63805d9,0x25640014,0x00000000}},	//   adli, _ميمڻ_, _گامُ, --, 
   {{0x93e401b9,0x506430c7,0x6440031c,0x64d000cd}},	//   _кўйл, атва, bdli, सदृश, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2c180490,0x2b4c013a,0x00000000,0x00000000}},	//   _पाहू_, _čec_, --, --, 
   {{0xeff00020,0x66d40006,0x313400d8,0x63bc0210}},	// [2d10] ቃላይ_, _iške, _ѓеор, ęsne, 
   {{0xa3bc07f7,0x00000000,0x00000000,0x00000000}},	//   _आरम_, --, --, --, 
   {{0x29d402dd,0xa7e4278f,0x6e480092,0x00000000}},	//   مياس, ەكتى, ነምግባ, --, 
   {{0x99900209,0x3afc01e1,0x6f140205,0xe97800db}},	//   ýyş_, _sápá_, muzc, лбеш_, 
   {{0xf9900133,0x0dc80cfc,0x5fdc0406,0x9de40014}},	//   وبه_, _јуни_, _मलमल, _چہہٕ_, 
   {{0xb4c020f0,0xd1b8001f,0x22900219,0xf8a80006}},	//   ंगो_, ተኞቹ_, mške_, авік_, 
   {{0xa7a830c8,0x9410013f,0xbb580116,0xdd140166}},	//   ыкка_, _ɔyɔ_, _карх_, _käşe, 
   {{0x232815d1,0x9f48026c,0xc98430c9,0x64400076}},	//   қоми_, ubbé_, _кузи, wdli, 
   {{0xa3c808ec,0x22901109,0x644030ca,0xe63003e3}},	//   लेन_, nške_, tdli, _eşşə, 
   {{0x478830cb,0x66d40010,0xc2e800fe,0x7af801e1}},	//   _исем_, _aške, _কিবি_, _àatà, 
   {{0x644030cc,0xe7b430cd,0x88c400cd,0x00000000}},	//   rdli, _اماد, _vaśī, --, 
   {{0x27202d7b,0x6f1430ce,0x76640014,0xdd1400fd}},	//   món_, duzc, _وُلم, _näşe, 
   {{0x272030cf,0xa5081639,0x5a98010f,0xe5b4008e}},	//   lón_, _села_, רשרא, _уйды, 
   {{0x408800fb,0x81d80154,0x00000000,0x00000000}},	//   рҙом_, িরই_, --, --, 
   {{0xdee430d0,0x27200f71,0x630430d1,0x99580139}},	//   соби, nón_, _اوبل, käşe_, 
   {{0x2250045f,0x27200077,0x92902377,0x2bf000fe}},	//   _unyk_, ión_, _најц, _চাগৈ_, 
   {{0x272030d2,0xdd140139,0x9b8830d3,0xd00c00e5}},	// [2d20] hón_, _däşe, گنال_, ظلہ_, 
   {{0x272030d4,0x00000000,0x00000000,0x00000000}},	//   kón_, --, --, --, 
   {{0x272030d5,0xf1a816e6,0x5f4430d6,0x6f1430d7}},	//   jón_, _مایه_, _انجل, cuzc, 
   {{0x2720097a,0xa3c80490,0xa0340131,0x91000133}},	//   dón_, लेय_, _ئىھت, _بژێو, 
   {{0x18680517,0x00000000,0x00000000,0x00000000}},	//   лади_, --, --, --, 
   {{0x272030d8,0x00000000,0x00000000,0x00000000}},	//   fón_, --, --, --, 
   {{0x272030d9,0xdd1400fd,0xa3c80a8a,0x9f480162}},	//   gón_, _yäşe, लेम_, gabø_, 
   {{0x93f0016b,0xb6c801d3,0x2b90030f,0xb4c01c5d}},	//   _ɔyε_, جاتے_, _تیمس, ंग्_, 
   {{0xf8b81e0e,0x99900034,0xb47800d1,0xbbb800bc}},	//   _көк_, żył_, ийиф_, _अरुक, 
   {{0x272030da,0xf484034d,0x201c00db,0x88c430db}},	//   bón_, تابی, òtil_, _paśū, 
   {{0x2720307d,0xd5b0034c,0x87080014,0x00000000}},	//   cón_, _کفش_, _معنہ_, --, 
   {{0x95480101,0x91e007f7,0x41e402d5,0x0bb4011a}},	//   _مشتق_, कुंज_, зіра, מלים_, 
   {{0xf4841272,0xa3c813f5,0xefe40023,0x00000000}},	//   _واتی, लेब_, ማሚዑ_, --, 
   {{0x644c0198,0x387c0175,0x22900427,0xbbb80118}},	//   _ɗaik, nhvr_, vške_, _अरूक, 
   {{0xfc5802d3,0x00000000,0x00000000,0x00000000}},	//   _ከረጋግ, --, --, --, 
   {{0xa3bc000d,0x072c0150,0x00000000,0x00000000}},	//   _आरत_, _ﺩﯗﯓ_, --, --, 
   {{0x272028f2,0x92541d18,0x320830dc,0x8cd0012d}},	// [2d30] zón_, _вақт_, _iday_, _भूखो, 
   {{0x6f1430dd,0x272030de,0x7bf8008e,0xc4d0011a}},	//   puzc, yón_, йнур_, פגע_, 
   {{0x27201709,0x00000000,0x00000000,0x00000000}},	//   xón_, --, --, --, 
   {{0x272030df,0xf1bc012d,0x00000000,0x00000000}},	//   vón_, _ईरान, --, --, 
   {{0xd5a41fa2,0x7c040116,0x00000000,0x00000000}},	//   _آف_, زبەك, --, --, 
   {{0x27200540,0xd3640272,0x9f4806ea,0x387c0076}},	//   tón_, _قه_, tabø_, ghvr_, 
   {{0x320830e0,0x7b6430e1,0x00000000,0x00000000}},	//   _oday_, _етте, --, --, 
   {{0x272030cf,0x32081bce,0x2bf00349,0x9f4803b2}},	//   rón_, _nday_, _চায়ে_, rabø_, 
   {{0x272030e2,0x04200135,0x9f4805ac,0x64a430e3}},	//   són_, _འཁྱམ_, sabø_, жапа, 
   {{0x272030e4,0x320830e5,0x1cac031c,0x68e80857}},	//   pón_, _aday_, _ཕེབ_, _ited, 
   {{0x320830e6,0x68e800f3,0x7f5c05b1,0x232830e7}},	//   _bday_, _hted, xxrq, шони_, 
   {{0xc6a4011c,0x00000000,0x00000000,0x00000000}},	//   _урзи, --, --, --, 
   {{0x320830e8,0xf49400f2,0x3e7c013a,0x00000000}},	//   _dday_, _کشند, _jíte_, --, 
   {{0x201c30e9,0x68e8055a,0x3208127b,0x28e00037}},	//   üti_, _mted, _eday_, _पढनि, 
   {{0xbbb80406,0x931000db,0x00000000,0x00000000}},	//   _अरेक, _قووش, --, --, 
   {{0x68e8127b,0xe0d8156c,0x43700b01,0x201c031c}},	//   _oted, _кви_, _муқт, żti_, 
   {{0x1c1c000d,0x00000000,0x00000000,0x00000000}},	// [2d40] _पादल_, --, --, --, 
   {{0xa3bc032c,0x9f580200,0x00000000,0x00000000}},	//   _आरा_, _jepë_, --, --, 
   {{0x68e814dc,0x6d5800b0,0x3208035a,0x00000000}},	//   _ated, äwar, _yday_, --, 
   {{0x32080175,0xddc40153,0x5398011a,0x26d801ef}},	//   _xday_, _jokū, ביעו, _čsop_, 
   {{0x81ac015b,0xa3c80490,0xef18033f,0x5fdc2cfd}},	//   কের_, लेत_, ąże_, _मलाल, 
   {{0x7d0430ea,0x36d40b2b,0x00000000,0x00000000}},	//   msis, покр, --, --, 
   {{0x7d0430eb,0x8b200b7f,0x2a7c01d4,0x68e802d0}},	//   lsis, _одре, bhwb_, _eted, 
   {{0xddc400ef,0x00000000,0x00000000,0x00000000}},	//   _nokū, --, --, --, 
   {{0xd49830ec,0x34941f09,0xa50800d1,0x656c031c}},	//   иро_, запр, مىيە_, _żahr, 
   {{0x7d0430ed,0x88b00d73,0x00000000,0x00000000}},	//   isis, _قینچ, --, --, 
   {{0x7d0430ee,0x1cac0135,0xdb0c0139,0x00000000}},	//   hsis, _ཕེན_, _uzbä, --, 
   {{0x7d0430ef,0x95c81920,0x3208022e,0xe9700137}},	//   ksis, _кула_, _qday_, _تۇۇد, 
   {{0xf5240dd4,0x7d0430f0,0x66d430f1,0x00000000}},	//   _འདྲཝ_, jsis, _iška, --, 
   {{0x7d0430f2,0x04400114,0x00000000,0x00000000}},	//   dsis, _жељн, --, --, 
   {{0x81ac09bd,0x7d0430f3,0x4e8800a7,0x320802d0}},	//   কেল_, esis, ащам_, _tday_, 
   {{0x7d0430f4,0x320830f5,0x2a7c0218,0x87780a7c}},	//   fsis, _uday_, xhwb_, באלי, 
   {{0x7d0430f6,0x9f58007f,0x00000000,0x00000000}},	// [2d50] gsis, _lepè_, --, --, 
   {{0x22900219,0x6ed4033f,0x0cd80118,0x00000000}},	//   mška_, _dąbr, _बढीम, --, 
   {{0x68e830f7,0x7d0430f8,0x00000000,0x00000000}},	//   _sted, asis, --, --, 
   {{0x213000e4,0x92bc00fe,0x6fb40101,0x8d5c0092}},	//   _ypyh_, েৱৰ_, _ومکا, _ታዋቂው_, 
   {{0x7d0430f9,0x22900427,0x9e58011a,0xf1bc1408}},	//   csis, nška_, _הכרט, ोधिन, 
   {{0x68e801f1,0x3e7c012c,0x48a830fa,0x9ac00327}},	//   _vted, _víte_, штем_, _ċċed, 
   {{0x68e8068f,0x6aa800df,0xca7401e0,0xd7ec0116}},	//   _wted, _ĉeff, _һуҡы, دكى_, 
   {{0x9f580100,0xba742a8b,0x79900036,0x3e7c01e1}},	//   _depè_, _قاقت, ühwä, _títe_, 
   {{0x68e803cd,0xf8ac0124,0xe48801b9,0x0dc40023}},	//   _uted, _аҩ_, ййид_, _ጸርፊ_, 
   {{0x9f580240,0xe12400d1,0x00000000,0x00000000}},	//   _qepë_, үмни, --, --, 
   {{0xf1a830fb,0x229002d5,0x00000000,0x00000000}},	//   _עס_, eška_, --, --, 
   {{0x7d0430fc,0x2eb430fd,0xd36c009f,0x00000000}},	//   ysis, ंतोत, اهَ_, --, 
   {{0xbbb8038e,0x7d040548,0x37d003d4,0xe3b030fe}},	//   _अर्क, xsis, _স্পৰ, برک_, 
   {{0x154030ff,0xf1e00131,0x00000000,0x00000000}},	//   _чешм, _ﺋﯩﻘﺘ, --, --, 
   {{0xa068005e,0x7d043100,0x10a0009d,0x00000000}},	//   _ғана_, wsis, хирн, --, 
   {{0x7d040680,0x22900010,0x9f6000e5,0x00000000}},	//   tsis, bška_, _épít_, --, 
   {{0x7d043101,0x00000000,0x00000000,0x00000000}},	// [2d60] usis, --, --, --, 
   {{0x7d043102,0x14d4011a,0xe1f801af,0x00000000}},	//   rsis, פועל_, _тѳҫ_, --, 
   {{0x7d0417ce,0x3ce00477,0xaca80014,0x0d20004e}},	//   ssis, sqiv_, تھَے_, _үүсү, 
   {{0x61e43103,0x81ac00bd,0x7d043104,0x1c1c3105}},	//   nckl, কেঃ_, psis, _पावल_, 
   {{0x7d043106,0x00000000,0x00000000,0x00000000}},	//   qsis, --, --, --, 
   {{0x91b80375,0xda6405af,0x00000000,0x00000000}},	//   זמני, _کاسي, --, --, 
   {{0x29180158,0x00000000,0x00000000,0x00000000}},	//   _åsan_, --, --, --, 
   {{0x7e643107,0x6aa80115,0x8b98011a,0x00000000}},	//   njip, _ĉefg, _הבלת, --, 
   {{0xa3c8000b,0x9f580098,0x7e64004c,0x1dbc00dc}},	//   लेस_, _depé_, ijip, ्धित, 
   {{0x05703108,0x2290151c,0x33743109,0x61e4002f}},	//   عايد, vška_, дгор, eckl, 
   {{0x4ce002f5,0x00000000,0x00000000,0x00000000}},	//   _পিছু, --, --, --, 
   {{0x1dbc0b7c,0x6b8003e0,0x00000000,0x00000000}},	//   ्धात, _ülge, --, --, 
   {{0x7e64000f,0x22900118,0x66d400d7,0xc174011c}},	//   djip, uška_, _uška, елящ, 
   {{0x2290310a,0x61e40363,0x82f42927,0x2eb40950}},	//   rška_, ackl, _کروز_, ंत्त, 
   {{0x9f48004e,0xb4b817cb,0x00000000,0x00000000}},	//   dabó_, चती_, --, --, 
   {{0x02a40953,0x8778008f,0xd24409a5,0x7e640200}},	//   _прым, זאלי, _хэки, gjip, 
   {{0xfeb804fb,0xf8cc00cd,0x00000000,0x00000000}},	// [2d70] سافت_, ाषाय, --, --, 
   {{0xddc4007f,0x629402fb,0xfd44009d,0x00000000}},	//   _makň, ézov, ээсн, --, 
   {{0xddc402e2,0xb5dc01ec,0x1c1c000d,0x7c8400d8}},	//   _lakň, _өнiм, _पारल_, хуте, 
   {{0xdfd0310b,0x00000000,0x00000000,0x00000000}},	//   _جيپ_, --, --, --, 
   {{0x7c580075,0x6aa800df,0xf4140183,0x78b80175}},	//   تلەر_, _ĉefd, ত্যৰ_, flvv, 
   {{0x9f480548,0x9f580241,0x6d4c0254,0x00000000}},	//   cabó_, _sepé_, mvaa, --, 
   {{0x6d4c310c,0x61e401e6,0x37d00183,0x89a401d9}},	//   lvaa, yckl, _স্বৰ, _کھاہ_, 
   {{0x24e8310d,0x8d700092,0xdbcc03e0,0xe91800c0}},	//   омии_, _የመስኖ_, _sıçm, _мобі_, 
   {{0x6d4c310e,0x12e402dd,0x6f140210,0x00000000}},	//   nvaa, _ﺍﻟﻨﻭ, hrzc, --, 
   {{0xefdc001f,0xa2e4310f,0x6d4c0108,0x876400f3}},	//   ሔራዊ_, моод, ivaa, _нђел, 
   {{0x3e7c066a,0x06d4015b,0x6d4c3110,0x1b7800df}},	//   _líta_, _সবকি, hvaa, ַטשע, 
   {{0x66d40006,0x7a243111,0x6d4c0037,0x6e2c01e4}},	//   _iško, _tōtō, kvaa, jfab, 
   {{0x61e40198,0x6d4c01a4,0x6f14033f,0xdb0c022a}},	//   rckl, jvaa, erzc, _rybí, 
   {{0x6e2c0196,0x2fc0030a,0x6d4c0ea0,0x9f480100}},	//   efab, _bzhg_, dvaa, dabò_, 
   {{0xa3c804fa,0x6d4c3112,0x6e2c3113,0x7e64020c}},	//   लेश_, evaa, ffab, tjip, 
   {{0x22900219,0x6d4c017a,0x3e7c3114,0x6e2c01bf}},	//   mško_, fvaa, _bíta_, gfab, 
   {{0x9f58025a,0xdb0c0316,0x6d4c1af3,0x1c442f8d}},	// [2d80] _gepî_, _vybí, gvaa, мнам, 
   {{0x28e00034,0x66d40219,0x7e64002d,0x00000000}},	//   _पढ़ि, _oško, sjip, --, 
   {{0x6d4c3115,0x22903116,0x00000000,0x00000000}},	//   avaa, nško_, --, --, 
   {{0x9f480100,0x6d4c01bf,0x7cf4022e,0x22900064}},	//   babò_, bvaa, bоrо, iško_, 
   {{0x0d8000ee,0xed34084c,0x5f740133,0x00000000}},	//   _алян, _пэрэ, _راگر, --, 
   {{0xd6e83117,0x3fb008b0,0x6aa8010f,0xb4bc000d}},	//   офил_, ﺳﺘﺎﻧ, _ĉefe, _आठे_, 
   {{0x7bdc3118,0xc044044e,0xeb300137,0x73d8010b}},	//   _igru, _ብዝተፈ, _مۉلد, үдир_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x66d40024,0x8500009f,0x229000c0,0xc5840116}},	//   _iškl, نوين, eško_, ۋھۇم_, 
   {{0xb4b816ae,0x08c03119,0x68ec311a,0xc7ac00e5}},	//   चते_, _абун, íade, اڑے_, 
   {{0xd628311b,0xa3c80490,0x7bdc01a6,0x6d4c05b8}},	//   _може_, लेल_, _mgru, zvaa, 
   {{0xae1c13f5,0x6d4c01f4,0x987c0213,0x00000000}},	//   _फाइन_, yvaa, mçıq_, --, 
   {{0x1048311c,0x44f002d5,0x7bdc311d,0x12e40150}},	//   ояви_, _апіс, _ogru, _ﺍﻟﻬﻭ, 
   {{0x7bdc034c,0x6d4c311e,0xc058311f,0x9f48067c}},	//   _ngru, vvaa, міс_, vabò_, 
   {{0xf54800b4,0xce68013e,0x37d003d4,0x66d4022a}},	//   _hụ_, орад_, _স্তৰ, _oškl, 
   {{0x7bdc2815,0x6d4c3120,0x78740ba1,0xf5480051}},	//   _agru, tvaa, _dàvi, _kụ_, 
   {{0xf54801f2,0xe1c00184,0x6d4c3121,0x7afc0067}},	// [2d90] _jụ_, _бөрй, uvaa, _awrt, 
   {{0xf5480521,0x6d4c3122,0x80b40022,0x3e7c0306}},	//   _mụ_, rvaa, _ибых, _víta_, 
   {{0x3a240048,0x6e2c3123,0x6d4c3124,0x6aa80115}},	//   _bcmp_, pfab, svaa, _ĉefb, 
   {{0x1dbc0d2c,0x6d4c0d27,0x3a240393,0x3e7c0241}},	//   ्धशत, pvaa, _ccmp_, _títa_, 
   {{0x80183125,0xf5483126,0x3a240334,0x3944054e}},	//   _عزیز_, _nụ_, _dcmp_, _csms_, 
   {{0xb4b80a59,0xf41400fe,0xa3c80118,0x00000000}},	//   चतो_, ত্তৰ_, लेँ_, --, 
   {{0x7afc00a9,0x7c3001d3,0x00000000,0x00000000}},	//   _gwrt, ékrő, --, --, 
   {{0xf5483127,0x22900010,0x7bdc0210,0x66c400e4}},	//   _bụ_, vško_, _zgru, kóke, 
   {{0xf54807ae,0x3944073c,0x386c01bf,0x987c06be}},	//   _cụ_, _gsms_, _fodr_, açıq_, 
   {{0x291c3128,0xf5480016,0x7b0801b8,0x95803129}},	//   muwa_, _dụ_, _ästä, улье, 
   {{0x291c312a,0xa3c809fd,0xf6740882,0x66d402fb}},	//   luwa_, लें_, ṛtaṃ_, _uško, 
   {{0xbbdc1533,0x22900b3d,0xf5480051,0xc5b0004e}},	//   _बल्क, rško_, _fụ_, _ирлө, 
   {{0xf548312b,0x2a6c0369,0x291c312c,0x787400db}},	//   _gụ_, _moeb_, nuwa_, _sàvi, 
   {{0x2a6c312d,0xe4c40116,0x1c1c00c5,0x00000000}},	//   _loeb_, _яйли, _पाइल_, --, 
   {{0x291c312e,0x02c8016c,0xb4240345,0xf5480051}},	//   huwa_, _оқои_, _شعوو, _zụ_, 
   {{0x291c1d1f,0x72940124,0x9400013f,0x7bdc312f}},	//   kuwa_, _ашьх, ɑkɑ_, _sgru, 
   {{0x291c3130,0x7afc0042,0x3a24045a,0x26cc01e7}},	// [2da0] juwa_, _swrt, _rcmp_, imeo_, 
   {{0x291c3131,0x1ab800dc,0xcfb800eb,0x00000000}},	//   duwa_, ेष्ठ, ঃখজন, --, 
   {{0x386c0077,0xc1e4005e,0xefd40092,0xabc41d00}},	//   _rodr_, _ﺍﯞﺩﺍ, ጫቸው_, _ﺩﺍﻧﺎ, 
   {{0x39443132,0x6aa80115,0x26cc01e4,0xb4bc000d}},	//   _psms_, _ĉefc, jmeo_, _आठ्_, 
   {{0x3ea03133,0x291c3134,0x38c83135,0x1c1c0073}},	//   mnit_, guwa_, واتی_, _पाऊल_, 
   {{0x7bdc0209,0x3ea03136,0xf54802e3,0x9f580306}},	//   _ugru, lnit_, _rụ_, _lepí_, 
   {{0x3ea03137,0x291c0333,0x5018011a,0xf5480051}},	//   onit_, auwa_, לוסו, _sụ_, 
   {{0x3ea03138,0x291c23db,0xb4b800dc,0x39440037}},	//   nnit_, buwa_, चत्_, _tsms_, 
   {{0x3ea03139,0x291c009a,0x3e7c0118,0x491407f7}},	//   init_, cuwa_, _líto_, _नियो_, 
   {{0xf54801dc,0x3ea0313a,0xaee40882,0x245015bf}},	//   _vụ_, hnit_, nuṣy, لچىس, 
   {{0x3ea0313b,0x3e7c01e1,0x1c1c000d,0x00000000}},	//   knit_, _níto_, _पाईल_, --, 
   {{0xf548001e,0x9584313c,0x8778008f,0xd6280c9e}},	//   _tụ_, _плее, _מאבי, _ходе_, 
   {{0x3ea000bc,0x00000000,0x00000000,0x00000000}},	//   dnit_, --, --, --, 
   {{0x3ea0313d,0xb624313e,0xbacc02dd,0x00000000}},	//   enit_, _ﯨﻦ_, _ﺑﺎﺑﺎ, --, 
   {{0x78740ffb,0xbfa8313f,0x291c3140,0xc05801ce}},	//   _fàvv, етте_, zuwa_, хія_, 
   {{0x3ea03141,0x291c3142,0x8d840137,0x03b8011a}},	//   gnit_, yuwa_, нузд, _מצול, 
   {{0xdb0c0232,0x2a6c0369,0x291c3143,0x2dd42bda}},	// [2db0] _rybá, _roeb_, xuwa_, тжар, 
   {{0x3ea03144,0x00000000,0x00000000,0x00000000}},	//   anit_, --, --, --, 
   {{0x291c3145,0x2a6c000d,0xefc40023,0x26cc0051}},	//   wuwa_, _poeb_, _ጸግዒ_, ymeo_, 
   {{0x291c3146,0x29d42928,0x81ac09bd,0x3ea03147}},	//   tuwa_, نياس, কেও_, cnit_, 
   {{0xddc403b9,0xdde802f2,0x00000000,0x00000000}},	//   _inkş, _ترپه_, --, --, 
   {{0x291c3148,0xe7383149,0x1d140375,0x79a40022}},	//   ruwa_, дек_, _בקשר_, ырхе, 
   {{0x291c314a,0x8aa40212,0x18640d1d,0x78a400e4}},	//   suwa_, _зрад, тащи_, éiva, 
   {{0x81ac11ba,0x291c314b,0xd6cc314c,0x77a80014}},	//   কেট_, puwa_, يقو_, رێنہ_, 
   {{0x26cc314d,0xe57000c6,0x1660005b,0x995800a2}},	//   rmeo_, شطة_, рвым, jäňe_, 
   {{0x290c0421,0xf990314e,0x3ea0314f,0x00000000}},	//   _ivea_, _طبق_, znit_, --, 
   {{0x3ea03150,0xae20012d,0x00000000,0x00000000}},	//   ynit_, यलान_, --, --, 
   {{0x290c0158,0x00000000,0x00000000,0x00000000}},	//   _kvea_, --, --, --, 
   {{0x3ea000bc,0x3e7c01ef,0x00000000,0x00000000}},	//   vnit_, _síto_, --, --, 
   {{0x3ea00076,0x00000000,0x00000000,0x00000000}},	//   wnit_, --, --, --, 
   {{0x4424010a,0xdee43151,0x3ea03152,0x544000d1}},	//   _icn_, тоби, tnit_, _ئۆپك, 
   {{0x3ea03153,0x44240072,0xdb0c0129,0xc1b4008e}},	//   unit_, _hcn_, _àdéf, _бәгы, 
   {{0xa0681411,0x4424004d,0x81ac0154,0x00000000}},	// [2dc0] _жапа_, _kcn_, কেজ_, --, 
   {{0x3ea03154,0x6aa800c8,0x442400b5,0x3e7c00d0}},	//   snit_, _ĉefa, _jcn_, _títo_, 
   {{0x290c3155,0xa3d03156,0x3ea03157,0x1a281422}},	//   _avea_, वधि_, pnit_, джеи_, 
   {{0x3ea00cfe,0x62840051,0x1c1c0037,0x00000000}},	//   qnit_, nhko, _पाकल_, --, 
   {{0x44243158,0x588409a5,0x98a40427,0x00000000}},	//   _ocn_, кыка, stoč_, --, 
   {{0xdca43159,0x68ec315a,0x44240334,0x38c8315b}},	//   _раги, íada, _ncn_, راشی_, 
   {{0xabc40184,0x290c0254,0x00000000,0x00000000}},	//   _барҙ, _evea_, --, --, 
   {{0x4424315c,0xddc4007f,0x752401e4,0x00000000}},	//   _acn_, _lakō, _ĥizb, --, 
   {{0x4424315d,0x9484315e,0xd4c4300e,0x62840067}},	//   _bcn_, вынд, ксоп, dhko, 
   {{0x442400db,0x73c40184,0x7414315f,0x12e402dd}},	//   _ccn_, ләйе, دودا, кімг, 
   {{0x8c1804ac,0x44240334,0x04603160,0xd7040124}},	//   וויי, _dcn_, ртым, _рзеи, 
   {{0x43901d0b,0x62843161,0xabc40150,0x82f40066}},	//   раюс, ghko, _ﺩﺍﻴﺎ, کریز_, 
   {{0x76400296,0x4424005c,0xf4343162,0x648c00a2}},	//   memy, _fcn_, _белэ, _iºin, 
   {{0x1c1c16f0,0x74140d28,0x78740ffb,0x752000e2}},	//   _पागल_, _صوبا, _tàvu, mumz, 
   {{0x66c401ed,0x7f943163,0x00000000,0x00000000}},	//   lóka, аарх, --, --, 
   {{0x62843164,0xc25400a7,0x645c00e2,0x00000000}},	//   chko, _вкъщ, ēsie, --, 
   {{0x75200921,0x51841ed2,0xfd74084c,0x6e9402dd}},	// [2dd0] numz, _шука, алтэ, _ەلجا, 
   {{0x76403165,0xa3c83166,0x5dc4215c,0x00000000}},	//   hemy, लेक_, امكە, --, 
   {{0x75200921,0x7640023a,0x290c3167,0x6e94014b}},	//   humz, kemy, _svea_, _бину, 
   {{0x75200fec,0x22803168,0xc330011a,0xc0cc0023}},	//   kumz, _kóka_, יוע_, ኣዛር_, 
   {{0xc9840075,0x8d843169,0x66c41686,0x12e40220}},	//   خشاي, _рунд, jóka, _ﺍﻟﻴﻭ, 
   {{0xb4ac0316,0x66d40006,0x6da40588,0xa5240107}},	//   कको_, _iški, _аиҭа, ҳмид, 
   {{0x4424316a,0xe738316b,0xdd100432,0xdc980677}},	//   _rcn_, хей_, _küşt, _טישל, 
   {{0x4424316c,0x764001bf,0x3774064e,0x00000000}},	//   _scn_, gemy, рышс, --, 
   {{0xdd1007c4,0x75201cdf,0x290c03a0,0x39b800a8}},	//   _müşt, gumz, _uvea_, _алтэ_, 
   {{0x229009a8,0x7790158b,0xddc40064,0x00000000}},	//   mški_, _ژیوا, _jokš, --, 
   {{0x22900e04,0x76400064,0x00000000,0x00000000}},	//   lški_, bemy, --, --, 
   {{0x66c408a7,0x22800252,0xe284013e,0xddc4316d}},	//   bóka, _bóka_, улми, _lokš, 
   {{0xddc400b0,0x7520009a,0xf1a4316e,0x6608316f}},	//   _pakō, cumz, арён, maek, 
   {{0x62843170,0x03640050,0x4424147b,0x66083171}},	//   shko, _لٔتی_, _ucn_, laek, 
   {{0x26dc3172,0xe2983173,0xa3c83174,0x66d401a6}},	//   _kiwo_, _пак_, लेख_, _aški, 
   {{0x64403175,0x66083176,0x26dc020c,0x61440022}},	//   leli, naek, _jiwo_, _беиа, 
   {{0x62940230,0xdd1003ee,0xddc40024,0x26dc01e1}},	// [2de0] _imyo, _düşt, _bokš, _miwo_, 
   {{0x76403177,0x21200115,0x22403178,0x2c0000cf}},	//   zemy, mukh_, lekk_, жүрм, 
   {{0x66083179,0x6440084c,0x2008317a,0x30040137}},	//   kaek, ieli, mabi_, _өзөг, 
   {{0x6440077e,0x2008317b,0x66c4317c,0x60dc014f}},	//   heli, labi_, yóka, _hipm, 
   {{0x6608317d,0x60dc0139,0x0930009a,0x00000000}},	//   daek, _kipm, مروج, --, 
   {{0x2008317e,0x6440317f,0x2240003d,0x26dc0076}},	//   nabi_, jeli, hekk_, _aiwo_, 
   {{0x64403180,0xd6d83181,0x76403182,0x26dc0699}},	//   deli, нти_, temy, _biwo_, 
   {{0x26dc0b45,0x21200b6f,0xdca400c2,0x64403183}},	//   _ciwo_, kukh_, _раҳи, eeli, 
   {{0x76403184,0xa508040d,0x26dc3185,0x22403186}},	//   remy, نىيە_, _diwo_, dekk_, 
   {{0x64403187,0x75203188,0xc214013f,0x6294037e}},	//   geli, rumz, _adɔ_, _amyo, 
   {{0x20083189,0x75200065,0x2874030d,0x00000000}},	//   dabi_, sumz, _тытр, --, 
   {{0x75200451,0x8cc81d15,0x66c401d3,0x741404f2}},	//   pumz, _तीनो, lókn, دوگا, 
   {{0x6440318a,0x20080337,0xdd102ca8,0xc6b4010f}},	//   beli, fabi_, _rüşt, _גלאז_, 
   {{0x6440318b,0x62940a49,0x657c318c,0x2ef41d1c}},	//   celi, _emyo, øshe, изгр, 
   {{0x447804ac,0x9f580093,0x60dc047e,0x26dc318d}},	//   _אנגע, _pepá_, _dipm, _yiwo_, 
   {{0x6aa8010f,0x2280318e,0x00000000,0x00000000}},	//   _ĉefo, _tóka_, --, --, 
   {{0xddc40024,0x614403cc,0x60d802e2,0x00000000}},	// [2df0] _pokš, _نىيە, ňtma, --, 
   {{0x66f002b1,0x229009a8,0x20080009,0x70540244}},	//   _hāke, vški_, cabi_, _ئندا, 
   {{0x8bc400a6,0x66d40024,0x66f000b8,0x66c401d3}},	//   усад, _iškv, _kāke, dókn, 
   {{0x6440318f,0xa3c828d4,0x7ff40424,0xad241c62}},	//   zeli, लेट_, _پسیا, _پىسى, 
   {{0x64403190,0x66f03191,0x66080124,0x00000000}},	//   yeli, _māke, vaek, --, 
   {{0x64403192,0x26dc02bd,0x48b000eb,0x00000000}},	//   xeli, _siwo_, টগ্র, --, 
   {{0x26dc3193,0x66083194,0xdb640023,0x00000000}},	//   _piwo_, taek, _ሰሚዖም_, --, 
   {{0x64403195,0x7f3c00c8,0x20083196,0x00000000}},	//   weli, געהו, zabi_, --, 
   {{0xe5a404a9,0x200804ce,0x66083197,0x26dc01e2}},	//   рипи, yabi_, raek, _viwo_, 
   {{0x26dc3198,0x66083199,0x2008009d,0x6440319a}},	//   _wiwo_, saek, xabi_, ueli, 
   {{0x6264319b,0x2008319c,0x6aa808fb,0x291c0083}},	//   авна, vabi_, _kjef, lrwa_, 
   {{0x2008319d,0x60dc002d,0x291c0099,0xa5f80640}},	//   wabi_, _sipm, orwa_, _реду_, 
   {{0x273001dc,0x2008319e,0x2240319f,0xa3c831a0}},	//   _hơn_, tabi_, rekk_, लेज_, 
   {{0x69c8009f,0x644031a1,0x224031a2,0x60dc014f}},	//   _mzee, qeli, sekk_, _qipm, 
   {{0x200831a3,0x1e9431a4,0xfe782dc3,0xd00431a5}},	//   rabi_, арар, гүн_, ресе_, 
   {{0x200831a6,0x291c083a,0x3e7c0085,0x62940472}},	//   sabi_, krwa_, _kíti_, _umyo, 
   {{0x69c802ea,0x614431a7,0x1d081a92,0x60dc02f0}},	// [2e00] _nzee, _тепа, тези_, _tipm, 
   {{0x6aa80810,0x291c1529,0x20080429,0x66d40064}},	//   _ajef, drwa_, qabi_, _išku, 
   {{0x9ea831a8,0xa3c80490,0x291c31a9,0x6aa8143a}},	//   _авна_, लेच_, erwa_, _bjef, 
   {{0x533404ac,0xbe3400db,0x228001e1,0xcb640114}},	//   ינען_, _دۉرب, _móko_, јаце_, 
   {{0x186831aa,0x6aa80139,0x3e7c0162,0x22800ca8}},	//   кади_, _djef, _níti_, _lóko_, 
   {{0x69c803ec,0x6aa8005c,0x3e7c0332,0x00000000}},	//   _dzee, _ejef, _síth_, --, 
   {{0x3cec03f3,0xcb641142,0x27300016,0x69c831ab}},	//   _अंडे_, _каре_, _cơn_, _ezee, 
   {{0x66c431ac,0x3e7c03b2,0x998402b5,0x27300208}},	//   sókn, _bíti_, ngoū_, _dơn_, 
   {{0x66f002b1,0xf8b82cc8,0x3e7c00d0,0x22900010}},	//   _rāke, _йөк_, _cíti_, nšku_, 
   {{0x7ae031ad,0x22900024,0x66f00055,0x843000d4}},	//   _himt, išku_, _sāke, оньє, 
   {{0x66f00325,0x7ae031ae,0xa824247f,0xdd2000b8}},	//   _pāke, _kimt, _اۋىل_, _dįũy, 
   {{0x22800248,0x7ae0025c,0x69dc013a,0x00000000}},	//   _dóko_, _jimt, _úsec, --, 
   {{0x7ae0003e,0x948431af,0x22900306,0xe6b40066}},	//   _mimt, _выйд, jšku_, _النگ, 
   {{0x66f002b5,0x04401b04,0x6aa8008f,0x78b8022e}},	//   _wāke, _мечн, _ĉefm, novv, 
   {{0xceb8026a,0x66f002b1,0xddc40034,0x03a00a5b}},	//   вља_, _tāke, _nakł, _миљо, 
   {{0x9e9431b0,0x7ae031b1,0x49140118,0x00000000}},	//   ماقچ, _nimt, _निलो_, --, 
   {{0x291c0223,0x78b800b5,0xb7f81025,0x7094014b}},	// [2e10] xrwa_, kovv, ुराम_, _гапф, 
   {{0x6aa831b2,0x32080076,0xc1bc0375,0x69c80036}},	//   _sjef, _heay_, _במחש, _rzee, 
   {{0x7ae0020b,0x39f401f2,0x3208062c,0x69c804e6}},	//   _bimt, _ịzọ_, _keay_, _szee, 
   {{0x291c2035,0xba7431b3,0x7ae031b4,0x9f58010e}},	//   trwa_, يانت, _cimt, _depä_, 
   {{0x27300016,0x7ae031b5,0x32080076,0x291c0433}},	//   _sơn_, _dimt, _meay_, urwa_, 
   {{0x6c840597,0x291c1556,0x66e431b6,0x66c431b7}},	//   _السم, rrwa_, бока, tóko, 
   {{0x06dc04c5,0x7ae031b8,0x3e7c00bc,0xd7ec31b9}},	//   _যৌগি, _fimt, _síti_, ركي_, 
   {{0x7ae002d5,0x291c1529,0x6aa801f0,0x69c80036}},	//   _gimt, prwa_, _ujef, _tzee, 
   {{0xddc4068f,0x69c801c8,0x78b800e4,0x22800248}},	//   _zakł, _uzee, bovv, _sóko_, 
   {{0xe5a431ba,0x7ae031bb,0x6ab8127b,0x216800c2}},	//   _қили, _zimt, lowf, ҳими_, 
   {{0x7ae00218,0xe3b000c6,0x68e8054e,0x58b8008f}},	//   _yimt, ثرة_, _hued, _עמעצ, 
   {{0x68e031bc,0x7b180084,0x68e831bd,0x09d80154}},	//   _hild, ḓul, _kued, _ড্যা, 
   {{0x68e031be,0x6f0403ac,0x6474013d,0x3cec0210}},	//   _kild, _awhc, _гыйф, _अंधे_, 
   {{0x68e031bf,0x68e80433,0x232831c0,0x44f831c1}},	//   _jild, _mued, _боки_, _iª_, 
   {{0x68e80a40,0x44f80005,0x1ea80451,0x32080076}},	//   _lued, _hª_, هاري_, _feay_, 
   {{0x320800ad,0x68e806af,0x00000000,0x00000000}},	//   _geay_, _oued, --, --, 
   {{0x6ab801ab,0x7ae00006,0x68e002d0,0x22900118}},	// [2e20] dowf, _rimt, _oild, ušku_, 
   {{0x7ae031c2,0x44f831c3,0x225003f0,0x00000000}},	//   _simt, _mª_, _hayk_, --, 
   {{0x225031c4,0xe7240345,0x00000000,0x00000000}},	//   _kayk_, _تڵ_, --, --, 
   {{0x68e80a40,0x225002d1,0x68e00368,0x7ae031c5}},	//   _bued, _jayk_, _aild, _qimt, 
   {{0x7ae00218,0x225031c6,0x9f58007c,0xd838009d}},	//   _vimt, _mayk_, _depå_, гэй_, 
   {{0x68e831c7,0x68e031c8,0x00000000,0x00000000}},	//   _dued, _cild, --, --, 
   {{0x68e031c9,0x78b831ca,0x44f801e4,0x7ae031cb}},	//   _dild, rovv, _aª_, _timt, 
   {{0x68e804e6,0x68e031cc,0x66c42507,0x00000000}},	//   _fued, _eild, bókm, --, 
   {{0xd5b81e76,0x09f4007b,0x5984004e,0x00000000}},	//   ыск_, _طفلة_, _улаб, --, 
   {{0x68e026b8,0x44f80005,0xf4b800cc,0x657c03cd}},	//   _gild, _dª_, ীদ্ব, øsha, 
   {{0x44f80077,0x291805ac,0x225006be,0xa5bc0153}},	//   _eª_, _åsar_, _bayk_, ngųj, 
   {{0x8500021a,0x25a80552,0x68e031cd,0x6aa8010f}},	//   _کوون, _žale_, _zild, _ĉefk, 
   {{0x68e0006c,0x32080076,0x938800d1,0x7f94010b}},	//   _yild, _veay_, _әсла_, җатх, 
   {{0x68e00050,0x66f004fe,0x00000000,0x00000000}},	//   _xild, _hāka, --, --, 
   {{0x66f031ce,0xfd7405f5,0x66d40006,0x00000000}},	//   _kāka, үлсэ, _iškr, --, 
   {{0x82a41fbe,0x66f00171,0x00000000,0x00000000}},	//   _најж, _jāka, --, --, 
   {{0x66f031cf,0xdc340139,0x00000000,0x00000000}},	// [2e30] _māka, _qäğb, --, --, 
   {{0x68e831d0,0x66f00069,0x6ad02314,0x00000000}},	//   _rued, _lāka, तग्र, --, 
   {{0x68e831d1,0x68e001b9,0xa0340375,0xdb2401b9}},	//   _sued, _rild, _ואתה_, قولی, 
   {{0x68e831d2,0x66f00029,0xdc340139,0x00000000}},	//   _pued, _nāka, _täğb, --, 
   {{0x68e831d3,0x68e031d4,0xa96831d5,0xe94431d6}},	//   _qued, _pild, рила_, ترای, 
   {{0x68e0006c,0x6d5c31d7,0x00000000,0x00000000}},	//   _qild, _irsa, --, --, 
   {{0x68e031d8,0x66f00171,0x00000000,0x00000000}},	//   _vild, _bāka, --, --, 
   {{0xf42431d9,0x9ba008c9,0x68e031da,0x68e831db}},	//   _འཐུད_, _تەمى, _wild, _tued, 
   {{0x6aa801e4,0x66c400e5,0x00000000,0x00000000}},	//   _ĉefh, lókk, --, --, 
   {{0x6d5c08ad,0x22500309,0x68e00c8c,0x67d431dc}},	//   _mrsa, _sayk_, _uild, _дозу, 
   {{0xf868004b,0x00000000,0x00000000,0x00000000}},	//   _دملي_, --, --, --, 
   {{0x6d5c31dd,0x00000000,0x00000000,0x00000000}},	//   _orsa, --, --, --, 
   {{0xa50831de,0x3e7c0579,0x205431df,0x7a4008a5}},	//   _тела_, _mítt_, отвр, _hátæ, 
   {{0x394031e0,0x6e3c31e1,0x225002d1,0xdee431e2}},	//   çisi_, _absb, _wayk_, жови, 
   {{0x6d5c31e3,0x9e6431e4,0x78a401e7,0x00000000}},	//   _arsa, يارن, éivi, --, 
   {{0x6d5c31e5,0x6e3c0175,0x3e7c03b2,0x00000000}},	//   _brsa, _cbsb, _nítt_, --, 
   {{0x20740fab,0x6d5c01ab,0x648c00c6,0xa0740276}},	// [2e40] _дунё, _crsa, _cúig, _дынш, 
   {{0x6d5c09a8,0x648c01e7,0x00000000,0x00000000}},	//   _drsa, _dúig, --, --, 
   {{0x6d5c31e6,0x9b4431e7,0xf1a804d3,0x3e7c0162}},	//   _ersa, تناو, _نایه_, _bítt_, 
   {{0x6d5c03b9,0x19c40353,0x99840472,0x00000000}},	//   _frsa, обем, يلاو, --, 
   {{0x3ea031e8,0x66f00325,0x9b680032,0x3940004e}},	//   miit_, _rāka, ышҡа_, ïis_, 
   {{0x3ea031e9,0x66f031ea,0xc01c03d4,0x00000000}},	//   liit_, _sāka, দ্ৰণ_, --, 
   {{0x66f031eb,0x61f40142,0x00000000,0x00000000}},	//   _pāka, _ofyl, --, --, 
   {{0xad2c0201,0x3ea031ec,0xda6431ed,0x8c1c0f22}},	//   _ድርጅቶ, niit_, _باسي, ন্দন_, 
   {{0x18a431ee,0x94a80261,0x1bec01ad,0x95c80064}},	//   _даам, итоа_, _जलाल_, шука_, 
   {{0x3ea031ef,0x7a400ad9,0x66f002b1,0xe8b031f0}},	//   hiit_, _fátæ, _wāka, _كەنج, 
   {{0x66f00053,0x3ea031f1,0x00000000,0x00000000}},	//   _tāka, kiit_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3ea031f2,0x3b500023,0x41e401ec,0x6488009d}},	//   diit_, _ዘጋጠመ, діра, рсөг_, 
   {{0x339406a6,0x66d402f0,0x00000000,0x00000000}},	//   _налё, _uškr, --, --, 
   {{0xc05810f5,0x3ea00eda,0x61f40042,0x0ee8023a}},	//   ція_, fiit_, _ffyl, рьги_, 
   {{0x3ea00af5,0x82f431f3,0x6d5c31f4,0x0dc80395}},	//   giit_, _بروز_, _prsa, аузи_, 
   {{0x98c80034,0xddd4010e,0x00000000,0x00000000}},	// [2e50] िताए, ndyň, --, --, 
   {{0x3e7c0579,0x6d5c2a53,0x8bc431f5,0xcee831f6}},	//   _sítt_, _vrsa, осед, _پردن_, 
   {{0xa80004d4,0x3ea031f7,0x66c4032e,0x00000000}},	//   _íñig, biit_, bókh, --, 
   {{0x6d5c31f8,0x3ea031f9,0xddd400a2,0x00000000}},	//   _trsa, ciit_, kdyň, --, 
   {{0x6e2c31fa,0x6d5c31fb,0x6f1431fc,0x3e7c041e}},	//   mgab, _ursa, lszc, _vítt_, 
   {{0x66e431fd,0x6d4c31fe,0x6e2c31ff,0xd7a40d79}},	//   пока, mwaa, lgab, गपंच, 
   {{0x6d4c3200,0x3e7c022c,0x6e2c0083,0x2ca000b5}},	//   lwaa, _títt_, ogab, mihd_, 
   {{0x6e2c2747,0x7b181682,0x98f40131,0x6d4c3201}},	//   ngab, ḓuh, زغۇچ, owaa, 
   {{0xad2c0020,0x6d4c3202,0x6e2c3203,0x7754001f}},	//   _ድርጊቶ, nwaa, igab, መሰረተ, 
   {{0x6d4c3204,0x6e2c3205,0x3ea03206,0xe3b00127}},	//   iwaa, hgab, ziit_, فرج_, 
   {{0x6e2c3207,0x6d4c3208,0x3ea03209,0x7790320a}},	//   kgab, hwaa, yiit_, _لیوا, 
   {{0x6d4c320b,0x66f00374,0xd5ac0214,0x20180332}},	//   kwaa, _hāko, ئفی_, _sdpi_, 
   {{0x3ea00af5,0x66f018a6,0x6f14068f,0x7b180943}},	//   viit_, _kāko, eszc, ṱuk, 
   {{0x6e2c320c,0xd57402e4,0x3ea0320d,0x3b500023}},	//   egab, _מתנה_, wiit_, _ዘጋጥመ, 
   {{0x66f0320e,0x6e2c2155,0x3ea0320f,0x5f04166f}},	//   _māko, fgab, tiit_, язва, 
   {{0x6e2c3210,0x66f0123c,0x6d4c3211,0x3ea00194}},	//   ggab, _lāko, fwaa, uiit_, 
   {{0x6d4c3212,0x3ea03213,0x5ce4215c,0x752401e4}},	// [2e60] gwaa, riit_, سكال, _ĥizk, 
   {{0x3ea03214,0x66f000da,0x6e2c3215,0x62843216}},	//   siit_, _nāko, agab, lkko, 
   {{0x6d4c2442,0x3ea03217,0x6e2c3218,0x628401f5}},	//   awaa, piit_, bgab, okko, 
   {{0x66c408a7,0x6d4c0a49,0xddc400ef,0x00000000}},	//   bóki, bwaa, _rakņ, --, 
   {{0x6284023a,0x0d2004a9,0xbdc801d3,0x69dc03b2}},	//   ikko, _пүтү, _گدھے_, _úsel, 
   {{0x7b840150,0x648c00ae,0x62840254,0x913800df}},	//   _قازە, _lúib, hkko, מענק, 
   {{0x6aa800df,0x5018010f,0x63ac0055,0x00000000}},	//   _ĉefv, צוקו, _śann, --, 
   {{0x25a80153,0x00000000,0x00000000,0x00000000}},	//   _žala_, --, --, --, 
   {{0x34941a5c,0x12e40220,0x6f140210,0x5984010a}},	//   дапр, _ﺍﻟﻘﻭ, zszc, _элаб, 
   {{0x62843219,0x6f140034,0xc914008d,0x6e2c321a}},	//   ekko, yszc, _מחמת_, zgab, 
   {{0x6d4c0196,0x6e2c2ce5,0x66f00171,0x00000000}},	//   zwaa, ygab, _jākl, --, 
   {{0x6d4c321b,0x66f00171,0x00000000,0x00000000}},	//   ywaa, _mākl, --, --, 
   {{0xdb0c0205,0x00d801ec,0x6f140210,0x00000000}},	//   _aybü, _ﺜﺎﺒﺘ, wszc, --, 
   {{0xe520038e,0x6284321c,0x6e2c0009,0x3944036e}},	//   _मिति_, akko, wgab, _mpms_, 
   {{0x6e2c321d,0x6d4c0752,0xc4380375,0x2eec01e4}},	//   tgab, wwaa, _לתגי, ĉefo_, 
   {{0x6284321e,0x6d4c321f,0x6f14033f,0x00000000}},	//   ckko, twaa, rszc, --, 
   {{0x6e2c3220,0x6d4c0280,0x1dc001c6,0x506400c0}},	// [2e70] rgab, uwaa, вөрн, _етна, 
   {{0x6e2c3221,0x6d4c3222,0x3df405f5,0x228003b2}},	//   sgab, rwaa, _үзэс, _róki_, 
   {{0x6d4c057b,0x7afc0175,0x3e7c00bc,0x648c01e7}},	//   swaa, _ctrt, _vítr_, _húic, 
   {{0xfbd02ab5,0x66f000da,0x6d4c01a4,0x2280033f}},	//   اتك_, _sāko, pwaa, _póki_, 
   {{0x6d4c3223,0x66f002b1,0x2d4c041a,0xcfa83224}},	//   qwaa, _pāko, _uže_, _خاکم_, 
   {{0x6aa800c8,0xc5f429d9,0x18643225,0xe7303226}},	//   _ĉefu, ीर्य_, даши_, نصب_, 
   {{0x62840b1a,0x648c01e7,0x66f00171,0x00000000}},	//   ykko, _lúic, _vāko, --, 
   {{0x3694023a,0xbb58037e,0x228003b2,0x57f00116}},	//   ешьс, _useで_, _tóki_, нпәт, 
   {{0x39440ac5,0x09d8015b,0x66f00374,0x648c007b}},	//   _gpms_, _ড্রা, _tāko, _núic, 
   {{0x544000d1,0x00000000,0x00000000,0x00000000}},	//   نچىك, --, --, --, 
   {{0x4788010a,0x00000000,0x00000000,0x00000000}},	//   _усам_, --, --, --, 
   {{0x21a400d1,0x62843227,0x00000000,0x00000000}},	//   димм, ukko, --, --, 
   {{0x62840664,0x00000000,0x00000000,0x00000000}},	//   rkko, --, --, --, 
   {{0x6284033d,0x648c007b,0x6304036b,0xc4d80063}},	//   skko, _dúic, _قوتل, _уђе_, 
   {{0x23d03228,0xdfd000ec,0xd36c00f1,0x00000000}},	//   _हरिद, ئيز_, _نهو_, --, 
   {{0x1ea83229,0xd05406be,0xddc40118,0x00000000}},	//   زازي_, _mixə, _zakř, --, 
   {{0x7afc0334,0xb0f801c0,0xdc7400c7,0x00000000}},	// [2e80] _strt, _нээх_, мыжь, --, 
   {{0x0c200209,0x3944045a,0xbc7400cf,0x00000000}},	//   кмун, _rpms_, رۇزب, --, 
   {{0xdb0800a2,0x00000000,0x00000000,0x00000000}},	//   _önür, --, --, --, 
   {{0xba180472,0x00000000,0x00000000,0x00000000}},	//   سيتا_, --, --, --, 
   {{0x6aa8010f,0xda700a81,0x66c400c7,0x7d2400e5}},	//   _ĉeft, _یُس_, nóku, _سہان, 
   {{0x7b1806d6,0xd05403b9,0xd05c03b9,0x00000000}},	//   ḓuv, _bixə, _buqə, --, 
   {{0x66c400e4,0x8cb0012d,0x00000000,0x00000000}},	//   hóku, _आदतो, --, --, 
   {{0xdb0c0034,0x8b98011a,0x66c40124,0x46a000cf}},	//   _wybó, _ובלת, kóku, кшыб, 
   {{0xd448013e,0xfbb00154,0x66c400e4,0x4d78010f}},	//   оянд_, _করিত, jóku, ַרטע, 
   {{0x3374322a,0x00000000,0x00000000,0x00000000}},	//   егор, --, --, --, 
   {{0xf470044e,0x648c0332,0x00000000,0x00000000}},	//   _ብኻልእ_, _súic, --, --, 
   {{0xfbb00154,0x9584014b,0x00000000,0x00000000}},	//   _করাত, _олее, --, --, 
   {{0xddc400bc,0x00000000,0x00000000,0x00000000}},	//   _takř, --, --, --, 
   {{0xa028031c,0xef540124,0x00000000,0x00000000}},	//   _སྐྱང_, нкгь, --, --, 
   {{0x4508025c,0x8898011a,0xd2580f06,0x04400a5b}},	//   _གསོར_, קבלי, _дцп_, _рејн, 
   {{0x648c00e4,0x22b402b1,0x8d84322b,0x66c4041e}},	//   _túic, tāke_, музд, bóku, 
   {{0xc0f40092,0x00000000,0x00000000,0x00000000}},	// [2e90] ግቧል_, --, --, --, 
   {{0x61f800bc,0x00000000,0x00000000,0x00000000}},	//   ětle, --, --, --, 
   {{0x24880198,0x661c0024,0x270c00ab,0xa0280327}},	//   _ɓam_, ųski, _सबेर_, _སྐྲང_, 
   {{0x69dc0122,0x2a680428,0x6aa8010f,0x91d00e49}},	//   _úsek, ñab_, _ĉefs, _सराई, 
   {{0x450808ea,0x6844322c,0x00000000,0x00000000}},	//   _གསེར_, енла, --, --, 
   {{0x225c00da,0xa75402e8,0xa8180345,0x00000000}},	//   ētki_, етищ, ستتر_, --, 
   {{0x7c34322d,0x00000000,0x00000000,0x00000000}},	//   _шерх, --, --, --, 
   {{0xe618322e,0x9ba000f7,0xe578322f,0x00000000}},	//   чди_, _حەمى, ззи_, --, 
   {{0x7ae8033b,0x00000000,0x00000000,0x00000000}},	//   _èdta, --, --, --, 
   {{0xe1f8060c,0x69c8058a,0x66c400c7,0x00000000}},	//   ूर्ण_, _iyee, vóku, --, 
   {{0x69c83230,0xf1a8011a,0x00000000,0x00000000}},	//   _hyee, _פס_, --, --, 
   {{0x290c3231,0x69c83232,0xddc40055,0xe80c00c5}},	//   _kwea_, _kyee, _cakś, हरवा_, 
   {{0x81e8015b,0x1a98010f,0xfbb000fe,0xf7d81870}},	//   মুন_, פישע, _কৰাত, ﻜﯩﻠﻪ, 
   {{0x201c0af2,0x22800162,0xa0a4009d,0x00000000}},	//   ûti_, _róku_, хагд, --, 
   {{0x38780428,0xdc1000ac,0xd4640108,0x00000000}},	//   _òrre_, xşıd, _чище_, --, 
   {{0x13980302,0x69c825d0,0x02c400d1,0xcee4009b}},	//   _מבצע, _oyee, _шийү, едсе_, 
   {{0x69c83233,0x00000000,0x00000000,0x00000000}},	// [2ea0] _nyee, --, --, --, 
   {{0xe0d01fcc,0x00000000,0x00000000,0x00000000}},	//   _حزب_, --, --, --, 
   {{0x69c82f1d,0x6aa8008f,0x00000000,0x00000000}},	//   _ayee, _ĉefr, --, --, 
   {{0x69c83234,0x22802833,0xdc103235,0x19f40a81}},	//   _byee, _tóku_, rşıd, رِتھ_, 
   {{0x290c0198,0x98a4023b,0x0d8000c0,0x18a42083}},	//   _cwea_, ниде, _блян, надм, 
   {{0x7d043236,0x5f400023,0x00000000,0x00000000}},	//   mpis, _ሕልንኦ, --, --, 
   {{0x69c82252,0x4508031c,0x8c400395,0x00000000}},	//   _eyee, _གསུར_, _щере, --, 
   {{0x7d04049b,0x00000000,0x00000000,0x00000000}},	//   opis, --, --, --, 
   {{0x7d043237,0x69c804ba,0x00000000,0x00000000}},	//   npis, _gyee, --, --, 
   {{0x7d043238,0x62940240,0x73c401e0,0x4494005b}},	//   ipis, ëzon, кәйе, евью_, 
   {{0x386c0109,0x66c43239,0x0570035c,0x7d040113}},	//   _indr_, tókt, ناید, hpis, 
   {{0xb3840166,0x00000000,0x00000000,0x00000000}},	//   елүл, --, --, --, 
   {{0x69c80211,0x5184323a,0x2bcc00cd,0x546800d8}},	//   _xyee, хуна, _ऽर्थ, _надм_, 
   {{0xe73001ed,0x648c00ae,0x66c40413,0x00000000}},	//   _حصے_, _húin, sókt, --, 
   {{0x9e94323b,0x7d04323c,0x66f0002b,0x386c003b}},	//   چاقچ, epis, _cākh, _mndr_, 
   {{0xd138323d,0x7d04007c,0xe514000d,0x66c400e5}},	//   _ехо_, fpis, _दौडि_, lókr, 
   {{0x7d04323e,0x648c0597,0xc0bc02d3,0x9f580793}},	// [2eb0] gpis, _múin, ሲሮም_, _zepü_, 
   {{0x22b4323f,0x648c02d2,0xd1c800f2,0x7c3401ec}},	//   māka_, _lúin, _وبکم_, леух, 
   {{0x22b4005f,0x69c800b5,0x7d043240,0x228003b2}},	//   lāka_, _syee, apis, _tókt_, 
   {{0xed500c55,0x386c3241,0xe520000d,0x648c032e}},	//   _پھر_, _andr_, _मिलि_, _núin, 
   {{0x290c01f5,0x0dc81f67,0xe80c0406,0xc0bc0023}},	//   _qwea_, _хуни_, हरला_, _ተጌሩ_, 
   {{0x66f004fe,0xd8201064,0x2ca40008,0x00000000}},	//   _hāki, адши, _öld_, --, 
   {{0x648c008c,0x00580375,0x9984009b,0x66f00055}},	//   _búin, גשות_, rgoš_, _kāki, 
   {{0xddc401e4,0x648c007b,0x9fac00fe,0x00000000}},	//   _lakŝ, _cúin, _গৰুগ, --, 
   {{0x648c0597,0x290c06c8,0x81b00198,0x66f002b1}},	//   _dúin, _uwea_, _keɓe, _māki, 
   {{0x66f00069,0x2374007b,0xd620030d,0x22b400de}},	//   _lāki, ناجح, _хiоа, dāka_, 
   {{0x7d043242,0x648c007b,0x7dd83243,0x2a6c01bf}},	//   zpis, _fúin, _kúsí, _kneb_, 
   {{0x7d043244,0x66f000b8,0x00000000,0x00000000}},	//   ypis, _nāki, --, --, 
   {{0x26cc0770,0x36d43245,0x64983246,0x22b400e2}},	//   mleo_, _соцр, _откр_, gāka_, 
   {{0x910000a8,0x26cc3247,0xf5980209,0x7d0403cd}},	//   рпре, lleo_, şýär_, vpis, 
   {{0x3f8c0122,0x26cc0607,0x6440002f,0x8fa0035b}},	//   ádu_, oleo_, mfli, ааре, 
   {{0x7d041326,0x26cc0943,0x66083248,0x2a6c0076}},	//   tpis, nleo_, nbek, _nneb_, 
   {{0x6aa800c8,0x660801f5,0x0d8001c6,0xf1d43249}},	// [2ec0] _ĉefp, ibek, алтн, _бөрө, 
   {{0x7d04324a,0x225c00da,0x2a6c012c,0xeff8001f}},	//   rpis, ētku_, _aneb_, ፋቸው_, 
   {{0x7dd801e1,0x66080373,0x9f04324b,0x386c0306}},	//   _búsí, kbek, _جوجو, _rndr_, 
   {{0x6440324c,0x8b20005b,0x60cc0356,0x59840139}},	//   hfli, рдце, llbm, клеб, 
   {{0xdb0c01e6,0x6608324d,0x6bd42dfc,0x6440002d}},	//   _nybö, dbek, پتەر, kfli, 
   {{0x2a6c0156,0x6608324e,0x66d40024,0x644001a4}},	//   _eneb_, ebek, _išky, jfli, 
   {{0xd6d8324f,0x22b400e2,0x7be003d4,0x6608002f}},	//   мти_, zāka_, _প্ৰো, fbek, 
   {{0x66080ca8,0x64402501,0x26cc0156,0xd564011c}},	//   gbek, efli, gleo_, втоп, 
   {{0xd94415ed,0x32d8002e,0x66c401d3,0x26b000cf}},	//   _јези, néye_, tókr, حەنز, 
   {{0x98e400c6,0x24501e4a,0x00000000,0x00000000}},	//   _شكاو, مچىس, --, --, 
   {{0xf4fc02e3,0xd788036b,0x648c01e7,0xd7600133}},	//   _dịịr, _تناو_, _túin, _ڕۆژی, 
   {{0x26cc3250,0x05703251,0x55883252,0xddc401e4}},	//   cleo_, _چاود, _обем_, _sakŝ, 
   {{0x05703253,0xd4980139,0x64400036,0x00000000}},	//   _ناود, _орк_, bfli, --, 
   {{0x64400f85,0x22b400e2,0x00000000,0x00000000}},	//   cfli, rāka_, --, --, 
   {{0x66f004fe,0x22b400e2,0x9f5801e1,0x705401d9}},	//   _pāki, sāka_, _sepò_, نچھا, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x32180209,0x7dd808a5,0x66f000ef,0x229001ef}},	// [2ed0] masy_, _rúsí, _vāki, jšky_, 
   {{0x50a004a9,0x32183254,0xc0bc0020,0x66083255}},	//   _ئەسل, lasy_, ተቀር_, zbek, 
   {{0x66f004fe,0x22900419,0x6608072d,0x00000000}},	//   _tāki, ešky_, ybek, --, 
   {{0x3e040801,0x32180209,0x6a140137,0x7d281432}},	//   _вярв, nasy_, умду, ürsü, 
   {{0xf99012fc,0x6608005c,0x648c0332,0xe94400db}},	//   يبه_, vbek, _búil, انتپ, 
   {{0x78643256,0x321800ee,0x648c01e7,0x7c84030d}},	//   لدىك, hasy_, _cúil, _кусе, 
   {{0x32180209,0x66081f05,0xddc4013d,0x648c01e7}},	//   kasy_, tbek, _kakş, _dúil, 
   {{0x2a6c3257,0xc9840022,0x6608017a,0x32183258}},	//   _uneb_, _иузи, ubek, jasy_, 
   {{0x32183259,0x2d88016b,0x26cc325a,0x656c0841}},	//   dasy_, nyae_, rleo_, _šahb, 
   {{0x478800a7,0x798401c7,0x26cc325b,0x00000000}},	//   _осем_, äiwe, sleo_, --, 
   {{0x26cc325c,0x6440325d,0x291c325e,0xa2e431ee}},	//   pleo_, rfli, lswa_, лоод, 
   {{0x3218325f,0x82842097,0xddc403e0,0xf7703260}},	//   gasy_, рқид, _nakş, _باك_, 
   {{0x291c3261,0x64403262,0x1e8401d5,0x00000000}},	//   nswa_, pfli, қлам, --, 
   {{0x291c006f,0x00000000,0x00000000,0x00000000}},	//   iswa_, --, --, --, 
   {{0x32183263,0x291c31b1,0x00000000,0x00000000}},	//   basy_, hswa_, --, --, 
   {{0x291c3264,0xdef80032,0xddc40139,0x22b400e2}},	//   kswa_, дыҡ_, _cakş, māko_, 
   {{0x2d880134,0x22b4005f,0x1c443265,0xdc6801c6}},	// [2ee0] gyae_, lāko_, лнам, наад_, 
   {{0x66f00374,0x0dc428cf,0x00000000,0x00000000}},	//   _hāku, улуй_, --, --, 
   {{0x1bb800c6,0x22b400e2,0x66f000cd,0x0c34007b}},	//   رائع_, nāko_, _kāku, اكمة_, 
   {{0x7b200122,0x648c00c6,0x38c400c7,0x291c0083}},	//   _náuš, _súil, _oĩrõ_, fswa_, 
   {{0x66f03266,0x229000bc,0xd7f801ca,0x38c83267}},	//   _māku, ušky_, нуй_, پاشی_, 
   {{0x32183268,0x62940023,0x17d001ec,0x00000000}},	//   zasy_, ëzoj, _ﺘﻭﺍﺯ, --, 
   {{0xddc4008e,0x32183269,0x1b480395,0x00000000}},	//   _yakş, yasy_, _язви_, --, 
   {{0x31b40521,0x35f4004e,0x66f0326a,0x22b40171}},	//   ụzi_, шпир, _nāku, dāko_, 
   {{0x9484326b,0x1834326c,0x94a8326d,0x3218326e}},	//   гынд, _مراح, етна_, vasy_, 
   {{0x3a24326f,0xfaa4014b,0x00000000,0x00000000}},	//   _hdmp_, _сағо, --, --, 
   {{0x32183270,0x61e800ac,0x964401c0,0x22b400e2}},	//   tasy_, əllə, _бэлд, gāko_, 
   {{0x6b8000db,0x66f000b8,0x24780023,0x490800bc}},	//   _àlge, _cāku, _ክወርድ_, ठीको_, 
   {{0x32183271,0x10483272,0xd3c4010b,0xf4840066}},	//   rasy_, няви_, _өйдй, _پاشی, 
   {{0x85980302,0x22b4005f,0xc0583273,0xf0e800d1}},	//   _אשדו, bāko_, ліс_, ئىسى_, 
   {{0x32183274,0x73340075,0x7f943275,0xddc40139}},	//   pasy_, _ئىبا, барх, _pakş, 
   {{0xa3c007f7,0x6db401ca,0x00000000,0x00000000}},	//   ंथर_, айбу, --, --, 
   {{0xa2c00073,0x00000000,0x00000000,0x00000000}},	// [2ef0] ळकर्, --, --, --, 
   {{0x81e8045e,0x28a83276,0x00000000,0x00000000}},	//   মুহ_, _औषधि, --, --, 
   {{0xca2c0131,0xab380150,0x00000000,0x00000000}},	//   _ﻫﻪﺭ_, тпеу_, --, --, 
   {{0x291c3277,0x316812ba,0x6f0402d0,0x66f000ef}},	//   tswa_, _kraz_, _ithc, _mākt, 
   {{0x8d843278,0x81b002a8,0x291c006f,0x00000000}},	//   _сунд, _keɓa, uswa_, --, 
   {{0xdde80345,0x00000000,0x00000000,0x00000000}},	//   _جرپه_, --, --, --, 
   {{0xdd0c3279,0x291c0d64,0x66f000de,0xddc400c0}},	//   _kışl, sswa_, _nākt, _inkš, 
   {{0x316814cf,0xa684327a,0xa524327b,0xfb34084c}},	//   _oraz_, рлид, амид, _ынсэ, 
   {{0xef180034,0x3a74327c,0x6f0401e7,0x57b018c7}},	//   ąży_, _ултр, _lthc, йбәт, 
   {{0x66f00029,0x22b4005f,0x64b0150d,0xdd0c0139}},	//   _sāku, tāko_, ीकेश, _lışl, 
   {{0x66f002b1,0x3168327d,0xe3b0007b,0xb99400db}},	//   _pāku, _araz_, ترة_, _پلەب, 
   {{0x3168327e,0x61f800bc,0x2c100154,0x22b41c52}},	//   _braz_, ětlo, ালয়ে_, rāko_, 
   {{0x6f04327f,0x26dc004c,0x66040051,0x66f000ef}},	//   _athc, _ihwo_, _đhkh, _vāku, 
   {{0x5f042c74,0x03640014,0x00000000,0x00000000}},	//   изга, _مٔتی_, --, --, 
   {{0x44f80591,0x66f004fe,0xdd9000aa,0x3168005a}},	//   _hê_, _tāku, ښور_, _eraz_, 
   {{0x31683280,0x44f80016,0xddd402d5,0xddc40153}},	//   _fraz_, _kê_, аўзэ, _ankš, 
   {{0x31683281,0x62941ba4,0x6f0402d0,0x20d40006}},	// [2f00] _graz_, _ilyo, _ethc, _вінс, 
   {{0x44f80016,0x24ac00d1,0xdca40107,0x00000000}},	//   _mê_, ﺴﺎﻻﻣ, шази, --, 
   {{0x44f83282,0x66f00029,0x90780375,0x316800d0}},	//   _lê_, _māks, _סטטי, _zraz_, 
   {{0x62940023,0xba0400fe,0xdd0c0139,0x198800c7}},	//   ëzoh, উণ্ড_, _gışl, кбеи_, 
   {{0x44f83283,0x32d80066,0x81e80154,0x00000000}},	//   _nê_, néya_, মুর_, --, 
   {{0x9b043284,0x26dc004c,0x66f000e2,0x1b4800db}},	//   _نظرن, _ahwo_, _nāks, _изги_, 
   {{0xe7e0007d,0x62940a49,0x44f80798,0xdd0c013d}},	//   गेला_, _olyo, _aê_, _yışl, 
   {{0x44f824ba,0xdca42c1d,0x62940175,0x3a240332}},	//   _bê_, _саҳи, _nlyo, _udmp_, 
   {{0x44f80798,0x66f0005f,0x67200010,0xbb3c02dd}},	//   _cê_, _sākt, _evlj, _ﺒﺄﻥ_, 
   {{0x44f83285,0x62942252,0x26dc013f,0x68fc00db}},	//   _dê_, _alyo, _ehwo_, _ésda, 
   {{0x44f80022,0x316800bc,0x00000000,0x00000000}},	//   _eê_, _sraz_, --, --, 
   {{0x44f83286,0x3168054e,0x15440212,0x66f00a88}},	//   _fê_, _praz_, _ведм, _vākt, 
   {{0x44f83287,0x32d8020c,0xddd4012d,0x63ac00b8}},	//   _gê_, géya_, ndyń, _śant, 
   {{0x8500168d,0x629415a9,0x316805c7,0x60c00332}},	//   _بوون, _elyo, _vraz_, _íoml, 
   {{0x4ea43288,0x62943289,0x3168068f,0x81e80eac}},	//   араа, _flyo, _wraz_, মুল_, 
   {{0x7c3c013f,0x31680261,0x44f824ba,0xb8c8031c}},	//   _acrr, _traz_, _yê_, _བཏ_, 
   {{0x44f8004d,0x6e94113e,0xdd0c0139,0x66f00171}},	// [2f10] _xê_, _ۇلدا, _vışl, _jākr, 
   {{0x80a40691,0xb0340114,0x00000000,0x00000000}},	//   _ومين, _унош, --, --, 
   {{0xfbd0328a,0x4e04012c,0xdd0c013d,0xbdf800e5}},	//   وتم_, िँदै_, _tışl, ارہا_, 
   {{0x37cc00fe,0x00000000,0x00000000,0x00000000}},	//   াধাৰ, --, --, --, 
   {{0xdd900451,0x66f000b8,0x00000000,0x00000000}},	//   _فوٽ_, _nākr, --, --, 
   {{0x44f8328b,0x00000000,0x00000000,0x00000000}},	//   _rê_, --, --, --, 
   {{0x44f8328c,0xab9400c6,0xfbd001d9,0xead4009d}},	//   _sê_, _الأغ, _ہتہ_, _говь, 
   {{0x66f0005f,0xebc40022,0x99941206,0x44f80051}},	//   _sāks, _кәҵн, ркәт_, _pê_, 
   {{0x6aa8328d,0xe5a4328e,0x66f007d7,0xab2800ee}},	//   _imef, сипи, _cākr, _шоңа_, 
   {{0x44f8328f,0x00000000,0x00000000,0x00000000}},	//   _vê_, --, --, --, 
   {{0xd7f800c6,0x62942f3b,0x6e3c02d0,0x44f80042}},	//   _щσя_, _plyo, _ocsb, _wê_, 
   {{0xe2983290,0x32d80085,0x26dc006f,0x44f83291}},	//   уам_, téya_, _uhwo_, _tê_, 
   {{0xd6c43292,0x60dc04ce,0xe3b03293,0x6aa83294}},	//   _امنی, _phpm, ترک_, _mmef, 
   {{0x6e3c02d0,0xd24c004b,0x942002dd,0xa0680063}},	//   _acsb, ونۍ_, _емше, ћава_, 
   {{0xdfd02361,0x6d5c2f86,0x6618025c,0x1e94084c}},	//   سير_, _assa, _kewk, брар, 
   {{0x44240175,0x5f040022,0x00000000,0x00000000}},	//   _hdn_, изҳа, --, --, 
   {{0x44243295,0xf1a83296,0x9c243297,0xa0a43298}},	// [2f20] _kdn_, _پايه_, йдад, _гапд, 
   {{0x6aa83299,0x4424329a,0x6e3c0042,0x4c80329b}},	//   _amef, _jdn_, _ecsb, плув, 
   {{0xd7f8329c,0x00000000,0x00000000,0x00000000}},	//   қул_, --, --, --, 
   {{0x6618329d,0xfe9412e9,0x9d44329e,0xba0800c7}},	//   _newk, _بیرج, _лемд, рҭаа_, 
   {{0x7c3c003a,0x7e6401f5,0x2018329f,0x7d2401d3}},	//   _tcrr, mdip, _kepi_, _ذہان, 
   {{0x201832a0,0x6aa802e3,0x7e6432a1,0x2a700135}},	//   _jepi_, _emef, ldip, _ħobż_, 
   {{0x964400ee,0x482000f7,0x00000000,0x00000000}},	//   бэпд, سىيق, --, --, 
   {{0x201832a2,0x7e6432a3,0x38c803e6,0x6618012d}},	//   _lepi_, ndip, داڵی_, _cewk, 
   {{0x442432a4,0x661c08a7,0x98a400b0,0x7e640037}},	//   _bdn_, ðska, aroā_, idip, 
   {{0x20181dd4,0x442432a5,0x78a82959,0x61f432a6}},	//   _nepi_, _cdn_, _umdv, _agyl, 
   {{0x44240175,0x6aa801e4,0x7e6401f5,0xcef000eb}},	//   _ddn_, _ĉefz, kdip, _জব্দ_, 
   {{0x442432a7,0xa6641bc6,0x518400f0,0x7198210e}},	//   _edn_, _وطنو, буга, لنجز_, 
   {{0x7e6432a8,0x44240334,0x94840166,0x00000000}},	//   ddip, _fdn_, _гыйд, --, 
   {{0x20181446,0x44240076,0x6d5c005a,0x7e640254}},	//   _cepi_, _gdn_, _rssa, edip, 
   {{0x201832a9,0x7f940022,0x00000000,0x00000000}},	//   _depi_, парх, --, --, 
   {{0x66180135,0x44240707,0x602000e4,0xb0f800d8}},	//   _xewk, _zdn_, tãmí, _кеиф_, 
   {{0x7bdc0ac5,0xe7fc00bc,0x00000000,0x00000000}},	// [2f30] _azru, ैँमा_, --, --, 
   {{0x44240354,0x20180432,0x1db801ad,0x7e64000d}},	//   _xdn_, _gepi_, _इशरत, adip, 
   {{0xa42c0023,0x00000000,0x00000000,0x00000000}},	//   _ተበጊስ, --, --, --, 
   {{0x247802d3,0x705408cf,0x201832aa,0x6d5c32ab}},	//   _ክወስድ_, _انگا, _zepi_, _tssa, 
   {{0x6d5c32ac,0x201832ad,0xf1c80a59,0x00000000}},	//   _ussa, _yepi_, रथिन, --, 
   {{0x2bd832ae,0x29180135,0x00000000,0x00000000}},	//   _نازک_, _ħsad_, --, --, 
   {{0x442432af,0xaa9432b0,0x34b40073,0xaa5832b1}},	//   _rdn_, _дивч, ुवैद, _киву_, 
   {{0x4424001f,0x6aa832b2,0x9ba000d1,0x0a980055}},	//   _sdn_, _umef, _غەنى, _āḷār, 
   {{0x442432b3,0xe9e40798,0x3a74004e,0x00000000}},	//   _pdn_, ãºdo_, _элтр, --, 
   {{0x79a401af,0x00000000,0x00000000,0x00000000}},	//   _эрсе, --, --, --, 
   {{0x201807ab,0xa2e4036b,0x22b400de,0x6618045a}},	//   _repi_, жонд, lāki_, _tewk, 
   {{0x201832b4,0x4424058a,0x00000000,0x00000000}},	//   _sepi_, _wdn_, --, --, 
   {{0x442432b5,0x941c03e3,0x00000000,0x00000000}},	//   _tdn_, hitə_, --, --, 
   {{0xa06802d5,0xa0a401c0,0x44240112,0x6568003a}},	//   шага_, цагд, _udn_, mveh, 
   {{0xe29832b6,0xaac832b7,0xdef002d3,0x7cf00241}},	//   _вай_, िकाक, ውጻእ_, _lórì, 
   {{0x61f432b8,0x76440309,0x39380092,0x941c03b9}},	//   _ugyl, _ñiyt, _የልዑካ, ditə_, 
   {{0x201832b9,0x7e6432ba,0x656832bb,0x2d98004e}},	// [2f40] _tepi_, rdip, nveh, бөрө_, 
   {{0x201803a0,0x656832bc,0xf3300092,0x22b40171}},	//   _uepi_, iveh, _በተቀና, dāki_, 
   {{0x656803e0,0x656c00a2,0x3f8c000d,0x00000000}},	//   hveh, _šahl, ädud_, --, 
   {{0x7bdc0122,0x68e003ac,0x5ac8005b,0x8af40150}},	//   _vzru, _ahld, шлем_, ініс_, 
   {{0xed3405f5,0xc98000c9,0xc9a41d39,0x7bdc012d}},	//   _нэрэ, дущи, овце_, _wzru, 
   {{0x941c00ac,0x656800e5,0x5e54009f,0x00000000}},	//   bitə_, dveh, _ائگر, --, 
   {{0x7bdc32bd,0x6568000d,0x00000000,0x00000000}},	//   _uzru, eveh, --, --, 
   {{0xcb940214,0x22b400de,0x00000000,0x00000000}},	//   _بنفش_, bāki_, --, --, 
   {{0x22b4005f,0x7afc32be,0x0a4c0023,0x66f0002b}},	//   cāki_, _hurt, _መምሃራ, _vākp, 
   {{0x7afc32bf,0x60c00597,0x394400f1,0x733832c0}},	//   _kurt, _íomh, _iqms_, бзор_, 
   {{0x7afc32c1,0x93a40116,0x96b8004e,0x291802d2}},	//   _jurt, юшид, _куду_, _æsar_, 
   {{0x7afc32c2,0x65680393,0x473002dd,0x257000db}},	//   _murt, bveh, _ініс, بۇۇس, 
   {{0x7afc32c3,0x50643252,0xbb3c02dd,0x00000000}},	//   _lurt, отва, _ﺒﺄﻱ_, --, 
   {{0x7afc0c8c,0xe7e00316,0x769c01e1,0x16840133}},	//   _ourt, गेका_, _déye, _داڕێ, 
   {{0x7afc014a,0x09b406ff,0x339408ca,0x00000000}},	//   _nurt, _आख्य, _хайё, --, 
   {{0xc3300302,0xbb50037e,0x797001e1,0x00000000}},	//   _חוק_, _odmサ_, _ǹwo, --, 
   {{0x7afc32c4,0x00000000,0x00000000,0x00000000}},	// [2f50] _aurt, --, --, --, 
   {{0x7afc32c5,0xc0580212,0xa5dc32c6,0x00000000}},	//   _burt, _дію_, _परसौ, --, 
   {{0x7afc32c7,0x65680433,0xaa540b3b,0x7cf001e1}},	//   _curt, zveh, звеш, _sórì, 
   {{0x656800c7,0xe978004e,0xe3c80166,0x00000000}},	//   yveh, йбеш_, leñä_, --, 
   {{0x65680369,0x941c00ac,0x9f600100,0xecd8000d}},	//   xveh, sitə_, _èpòt_, _बीअफ, 
   {{0x7afc32c8,0x22b4005f,0x61f800bc,0x013808c3}},	//   _furt, rāki_, ětli, קרות_, 
   {{0xaa4402dd,0x24880023,0x25ec00bc,0x661c148b}},	//   _ىنسى, _ሕሙማት_, आइभी_, ðsko, 
   {{0x656832c9,0x648c0332,0x00000000,0x00000000}},	//   tveh, _lúit, --, --, 
   {{0x7afc01c4,0xeb980daf,0xe6100244,0x00000000}},	//   _zurt, _тиң_, وشک_, --, 
   {{0x7afc32ca,0x656832cb,0x1b0c009e,0x3834010b}},	//   _yurt, rveh, _হিতে_, _онур, 
   {{0x769c00e8,0xc9100183,0x7afc0139,0x656801f4}},	//   _séye, _সময়ত_, _xurt, sveh, 
   {{0xf65032cc,0x3f8c03b2,0x00000000,0x00000000}},	//   _لئه_, ødum_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd00432cd,0x26cc0421,0x648c007b,0x307432ce}},	//   зере_, loeo_, _cúit, мусс, 
   {{0xdee432cf,0x769c0de2,0x648c01e7,0x1e940d6f}},	//   зови, _wéye, _dúit, прар, 
   {{0x26cc32d0,0x7afc014f,0x5318010f,0x9230215c}},	//   noeo_, _rurt, _פופצ, _كىىش, 
   {{0xd00c00dd,0x648c00ae,0xf1d40137,0xdce40a2f}},	// [2f60] ئلہ_, _fúit, _жөрө, _arkā, 
   {{0x7afc32d1,0xf1b80030,0x00000000,0x00000000}},	//   _purt, úše_, --, --, 
   {{0x7afc32d2,0xf1a80b28,0x60cc014f,0xe7240244}},	//   _qurt, _هایه_, mobm, _جڵ_, 
   {{0xdc94001f,0xc0d4001f,0x60cc014f,0x8a000395}},	//   _መጨመር_, ሪዝም_, lobm, езце, 
   {{0x7afc32d3,0x3ea000a3,0x00000000,0x00000000}},	//   _wurt, mhit_, --, --, 
   {{0x3ea032d4,0x7afc32d5,0x22b400e2,0x648c01e7}},	//   lhit_, _turt, māku_, _múis, 
   {{0x7afc0196,0x22b4005f,0x00000000,0x00000000}},	//   _uurt, lāku_, --, --, 
   {{0xd94432d6,0x60cc047e,0xd1b80023,0x00000000}},	//   _неби, hobm, _ደሚቑ_, --, 
   {{0x3ea00076,0x22b400e2,0x00000000,0x00000000}},	//   ihit_, nāku_, --, --, 
   {{0x245004da,0x3ea003e0,0x00000000,0x00000000}},	//   نچىس, hhit_, --, --, 
   {{0x648c00ae,0x2ee8015d,0x00000000,0x00000000}},	//   _rúit, ymaf_, --, --, 
   {{0x0bb404ae,0x518432d7,0x648c32d8,0x46a00d30}},	//   ללים_, пуга, _búis, _пахв, 
   {{0x648c00ae,0x5fd005f9,0x3ea032d9,0x00000000}},	//   _cúis, _दुबल, dhit_, --, 
   {{0x648c00ae,0x408400c7,0x6294036e,0x22b40171}},	//   _dúis, нусб, ëzor, dāku_, 
   {{0xc058003b,0x00000000,0x00000000,0x00000000}},	//   чія_, --, --, --, 
   {{0x3ea01368,0x43b8011a,0x00000000,0x00000000}},	//   ghit_, _לזוג, --, --, 
   {{0x3208035a,0x22b400e2,0x2ee80076,0x6fcc0fe3}},	// [2f70] _ifay_, gāku_, rmaf_, _दुरू, 
   {{0x3ea032da,0x648c01e7,0xccd001e2,0x69c40790}},	//   ahit_, _húir, رماښ, şhek, 
   {{0x705432db,0xfb34036b,0xaac82144,0x3ea00055}},	//   _فنکا, енхэ, िकलक, bhit_, 
   {{0xd3642dd2,0x81e00c58,0x22b400e2,0x00000000}},	//   _یه_, _তলত_, bāku_, --, 
   {{0x22b4005f,0x648c01e7,0xed5400df,0x00000000}},	//   cāku_, _múir, _קבֿר_, --, 
   {{0x648c0332,0xd6cc01e2,0x00000000,0x00000000}},	//   _lúir, یقو_, --, --, 
   {{0x8aa4084c,0x3208035a,0x5b2401af,0x78240137}},	//   _ерад, _ofay_, _оятҡ, رعول, 
   {{0x22b400da,0x9ba02160,0x00000000,0x00000000}},	//   nākt_, _جەمى, --, --, 
   {{0x6ac800dc,0xc8a802e8,0x60cc0455,0x64a432dc}},	//   िकीर, _лъже_, yobm, дапа, 
   {{0x290c0084,0x32080548,0x648c00c6,0x3ea032dd}},	//   _itea_, _afay_, _rúis, zhit_, 
   {{0x7790168d,0xc998001f,0x648c0332,0x99940014}},	//   _میوا, _ገልፀው_, _búir, _ٹھۆر_, 
   {{0xd5ac32de,0x648c00c6,0x3ea00023,0x00000000}},	//   افی_, _cúir, xhit_, --, 
   {{0x648c0597,0x81b00198,0xd1800cb9,0x9f4c00d0}},	//   _dúir, _keɓi, вляй, ľník_, 
   {{0xa0341c5c,0x9f4c0308,0x3208035a,0x201c32df}},	//   بىست, žník_, _efay_, úti_, 
   {{0x3ea032e0,0xe50801c8,0x00000000,0x00000000}},	//   thit_, _ايڪو_, --, --, 
   {{0x290c0270,0xdee432e1,0x22b400e2,0xc1b4008e}},	//   _otea_, фоби, tāku_, _зәгы, 
   {{0x3ea032e2,0x32d800d1,0x20c401a9,0x00000000}},	// [2f80] rhit_, ﯜﺭﮔﻪ, _ойим, --, 
   {{0x62840989,0x3ea032e3,0x22b4005f,0xed7802d3}},	//   ljko, shit_, rāku_, _ኣጸጋሚ_, 
   {{0x3ea032e4,0x290c32e5,0x320802d0,0x98a00153}},	//   phit_, _atea_, _yfay_, _ūkį_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x22b4005f,0xddc40064,0x20300023,0x18a4004e}},	//   lāks_, _makū, _ክምስክ, мадм, 
   {{0xb7bc005f,0x81e00eac,0xddc40153,0x7d0401a9}},	//   _leģe, _তলা_, _lakū, mqis, 
   {{0xc8c40272,0x290c0077,0x36d432e6,0x8c4032e7}},	//   بوون_, _etea_, нокр, _шере, 
   {{0x769c020c,0x7d040140,0xda6432e8,0x3cf80254}},	//   _béya, oqis, _غازي, _hirv_, 
   {{0x7d040a55,0x2c0c000d,0x00000000,0x00000000}},	//   nqis, _ढ्ँू_, --, --, 
   {{0x84e400c6,0x3d0404e6,0x00000000,0x00000000}},	//   وفيق_, _möw_, --, --, 
   {{0x04600032,0x3d0432e9,0x32d80de2,0x7d040200}},	//   ттым, _löw_, léyi_, hqis, 
   {{0xd25832ea,0x439032eb,0x22b400de,0x00000000}},	//   ццо_, таюс, dāks_, --, 
   {{0xd5e032ec,0x290c00e4,0x22b400de,0xb7bc0171}},	//   _परिज, _xtea_, vākt_, _deģe, 
   {{0x69b032ed,0x657c0158,0x69c40112,0x00000000}},	//   _आइसी, åshe, ßhei, --, 
   {{0x7d04013c,0x22b400e2,0x84200150,0x648c0332}},	//   eqis, gāks_, _شىين, _túir, 
   {{0x764032ee,0xd5e0255c,0x320803ac,0x3ec400d8}},	//   ngmy, _पराज, _ufay_, всуб, 
   {{0x7d0401b3,0x1dc001c4,0x00000000,0x00000000}},	// [2f90] gqis, гөрн, --, --, 
   {{0x22b400e2,0x3d04010b,0xfc30007b,0x00000000}},	//   sākt_, _döw_, لحم_, --, 
   {{0x7d0432ef,0x3eb0007b,0x290c32f0,0x6e9401af}},	//   aqis, últú_, _stea_, _зину, 
   {{0x417402dd,0x00000000,0x00000000,0x00000000}},	//   _ساۋس, --, --, --, 
   {{0x3d0400a2,0x67f400a2,0xbea8009f,0x00000000}},	//   _göw_, _oýjü, _آهُن_, --, 
   {{0x2ef80158,0x769c00e8,0xba7401d5,0x00000000}},	//   _hisf_, _réya, _یاقت, --, 
   {{0xe73832f1,0x769c0de2,0x00000000,0x00000000}},	//   чей_, _séya, --, --, 
   {{0x377432f2,0x769c002e,0xe71c00a2,0x9ae400db}},	//   тышс, _péya, _güýž, _كۉلك_, 
   {{0xe57032f3,0x22b400e2,0xc86432f4,0x766800f1}},	//   اطب_, zāks_, _отжи, بینې_, 
   {{0xddc400ef,0x27d80064,0x00000000,0x00000000}},	//   _sakū, _едзь_, --, --, 
   {{0xddc40467,0x769c1bce,0xd5d40354,0x00000000}},	//   _pakū, _wéya, _тiом, --, 
   {{0x51f4066d,0x00000000,0x00000000,0x00000000}},	//   کسپر, --, --, --, 
   {{0x62040327,0xb7bc00de,0x66080419,0xd41c00cc}},	//   _ġulġ, _veģe, mcek, _দাৰি_, 
   {{0xe04401c0,0xc44401d5,0x22b400e2,0x660832f5}},	//   энги, _کیگن_, tāks_, lcek, 
   {{0x644032f6,0x3d0400a2,0xdfd032f7,0x00000000}},	//   mgli, _söw_, ايز_, --, 
   {{0x660832f8,0x644032f9,0xb9e4001f,0x22b400de}},	//   ncek, lgli, _ክፉ_, rāks_, 
   {{0x644032fa,0x22b400e2,0x217400ee,0x7cf403b9}},	// [2fa0] ogli, sāks_, _чуйр, lürə, 
   {{0x7d0432fb,0x00000000,0x00000000,0x00000000}},	//   rqis, --, --, --, 
   {{0x2ef801ab,0x7cf40213,0x660832fc,0x00000000}},	//   _fisf_, nürə, kcek, --, 
   {{0x2ebc32fd,0x660832fe,0xeec40150,0x0a6417b4}},	//   ्कृत, jcek, _ليپپ, ерши_, 
   {{0x7d0432ff,0x09e001c0,0x6d480356,0x05ac0118}},	//   qqis, гоцн, _ţeav, _जेलब, 
   {{0x660803cd,0x7cf403b9,0x00000000,0x00000000}},	//   ecek, kürə, --, --, 
   {{0x81b402a6,0x64403300,0x00000000,0x00000000}},	//   _জুম_, dgli, --, --, 
   {{0x64403301,0x66083302,0x7cf40213,0xda7001f7}},	//   egli, gcek, dürə, _حُر_, 
   {{0xd90c0acb,0x2a680165,0x00000000,0x00000000}},	//   _ایت_, ɾab_, --, --, 
   {{0x64403303,0x33743304,0x00000000,0x00000000}},	//   ggli, вгор, --, --, 
   {{0xc61c0eac,0x058001e0,0x3554211f,0x9f4c01e1}},	//   _ধারা_, _ҡушм, رنگز, _àfè_, 
   {{0x64403305,0x81b00198,0x27e00112,0xd16400d1}},	//   agli, _leɓu, ühne_, нъги, 
   {{0xa6a800cf,0x00000000,0x00000000,0x00000000}},	//   _تالق_, --, --, --, 
   {{0x20d4003a,0x769c002e,0x2be0000d,0x00000000}},	//   dæis_, _xéyn, _करलू_, --, 
   {{0xb4cc1431,0x00000000,0x00000000,0x00000000}},	//   लवी_, --, --, --, 
   {{0x3ff43306,0x6b8000db,0x2ebc193d,0x00000000}},	//   اكِر, _àlgi, ्केत, --, 
   {{0x71743307,0x661c3308,0xa2cc3309,0x63ac03f9}},	// [2fb0] _شهدا, ðski, सवर्, _ƙang, 
   {{0x6ac8330a,0xcc8403e6,0x6608009a,0x00000000}},	//   िक्र, رۆزه_, zcek, --, 
   {{0x66080205,0x00000000,0x00000000,0x00000000}},	//   ycek, --, --, --, 
   {{0x98c40421,0x0ddc02d3,0x6e9400d8,0x00000000}},	//   _āuāu_, ሓልፍ_, _риму, --, 
   {{0x7de40046,0x6440330b,0x00000000,0x00000000}},	//   _бірд, ygli, --, --, 
   {{0x48cc015b,0x6d4c330c,0xaca801ed,0x1dc0013d}},	//   িগ্র, mtaa, _کپڑے_, _төсн, 
   {{0x6d4c330d,0x98a0330e,0x6440330f,0xbb58010b}},	//   ltaa, рище, vgli, _парх_, 
   {{0x6d4c3310,0xda6c05d9,0x1be4000d,0xe5780815}},	//   otaa, _وڏن_, _करतल_, дзи_, 
   {{0x6d4c3311,0x644009f0,0xe5a43312,0x66083313}},	//   ntaa, tgli, типи, rcek, 
   {{0x64403314,0x7cf40213,0x6d4c0108,0x2ddc02dd}},	//   ugli, türə, itaa, _ﺃﻭﻟﻤ, 
   {{0x6d4c3315,0x6e280086,0x81fc025c,0xe3b0027d}},	//   htaa, _ôebw, _དཔྱི_, شرد_, 
   {{0x6d4c3316,0x64403317,0xe2983318,0x7cf40213}},	//   ktaa, sgli, фам_, rürə, 
   {{0x6d4c013c,0x6fc40022,0x00000000,0x00000000}},	//   jtaa, ҳарҕ, --, --, 
   {{0xe3b82f34,0xe3b03319,0x7cf406be,0x00000000}},	//   _обл_, _پرت_, pürə, --, 
   {{0xd0041411,0x6d4c331a,0x00000000,0x00000000}},	//   тесе_, etaa, --, --, 
   {{0x6d4c331b,0xd1b0331c,0x66f00055,0x00000000}},	//   ftaa, اییک, _pāky, --, 
   {{0x32d80de2,0x98680139,0x1c44331d,0x1d0800d8}},	// [2fc0] géyu_, _nıği_, кнам, фези_, 
   {{0x66f00a28,0x63ac00b8,0xf00001c4,0x00000000}},	//   _vāky, _śany, _гүри, --, 
   {{0x6d4c331e,0x19f40014,0x201c01a9,0x109808c3}},	//   ataa, ھِتھ_, аtiv_, _חביב, 
   {{0x6d4c331f,0x769c3320,0x1e7400d8,0x00000000}},	//   btaa, _réyo, _рѓос, --, 
   {{0x6d4c074d,0x769c002e,0x00000000,0x00000000}},	//   ctaa, _séyo, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xecf00150,0xc61000cc,0xd6e80395,0x6cc401ee}},	//   _اۋلد, _িয়া_, мфил_, _сирҡ, 
   {{0x3ae83321,0x00000000,0x00000000,0x00000000}},	//   _سبزی_, --, --, --, 
   {{0xceb00d65,0x7bdc3322,0x27e40165,0x769c0de2}},	//   ייה_, _hyru, _ezln_, _wéyo, 
   {{0xb4cc3323,0x7bdc0076,0x657c0158,0x3a242517}},	//   लवे_, _kyru, åsha, _hemp_, 
   {{0xb9ec069c,0x656c3324,0x25a000ac,0xaaa8012c}},	//   _ኔሩ_, _šaht, _əhli_, चोकक, 
   {{0x7bdc0092,0x3a240221,0x6d4c3325,0x386c082b}},	//   _myru, _jemp_, ytaa, _hadr_, 
   {{0x6d4c1574,0x386c3326,0x3a240165,0x1be400af}},	//   xtaa, _kadr_, _memp_, _करऽल_, 
   {{0x94200075,0x7bdc06ea,0x2ebc102f,0xc0583327}},	//   _ئوغۇ, _oyru, ्क्त, кіс_, 
   {{0xff043328,0x63ac0198,0x7bdc3329,0x3a240165}},	//   иятн, _ƙane, _nyru, _oemp_, 
   {{0x6d4c332a,0x3a24009a,0x03d40375,0xc3200116}},	//   ttaa, _nemp_, _שוהם_, _өмәк, 
   {{0x6d4c0af5,0x7bdc332b,0x769c00e8,0x78b8332c}},	// [2fd0] utaa, _ayru, _réyl, kivv, 
   {{0x6d4c332d,0x386c004c,0x7bdc332e,0x32d8002e}},	//   rtaa, _nadr_, _byru, réyu_, 
   {{0x6d4c332f,0x2d9c1ebd,0x3a2405c7,0x6f940114}},	//   staa, šwe_, _bemp_, _синђ, 
   {{0x264401f2,0x7bdc3330,0xbec800ef,0x00000000}},	//   ịozi_, _dyru, _plūš, --, 
   {{0x6d4c3331,0x3a243332,0x386c3333,0x6f04014f}},	//   qtaa, _demp_, _badr_, _huhc, 
   {{0x68443334,0x9f440150,0x25a800a2,0x00000000}},	//   унка, _ﯗﺷﻪﯞ_, _ýali_, --, 
   {{0x005806a9,0x7bdc3335,0x3a242560,0x6f04014f}},	//   דשות_, _gyru, _femp_, _juhc, 
   {{0xd7541e95,0x69c80070,0xd1cc0092,0x00000000}},	//   اليت_, _txee, ጣራት_, --, 
   {{0x78b804ba,0x24f400cf,0x00000000,0x00000000}},	//   bivv, лчор, --, --, 
   {{0x2a6c0399,0x3a243336,0x273400db,0x442001d3}},	//   _haeb_, _zemp_, _مىئس, új_, 
   {{0x31680221,0xc6a4004e,0xe8183337,0x00000000}},	//   _asaz_, _ирди, _न्या_, --, 
   {{0x33f43338,0x00000000,0x00000000,0x00000000}},	//   шчыс, --, --, --, 
   {{0x661c0bcd,0x85200345,0x00000000,0x00000000}},	//   ðsku, _ئوتۆ, --, --, 
   {{0x91003339,0x55b80302,0x2a6c0399,0xffa401c0}},	//   спре, _אמנו, _laeb_, алгү, 
   {{0x8fa0333a,0x6f040098,0xbe840131,0xa0680022}},	//   баре, _cuhc, ақни, _ҟана_, 
   {{0x6f04014f,0x3f9800c7,0x00000000,0x00000000}},	//   _duhc, ryru_, --, --, 
   {{0x7bdc333b,0x3a240381,0xae040032,0x03a40451}},	// [2fe0] _syru, _remp_, роуҙ, _سگھو_, 
   {{0x3a24333c,0x0c20333d,0x3f9800c7,0x00000000}},	//   _semp_, ймун, pyru_, --, 
   {{0x6f040399,0x3a240dd4,0xeff8001f,0x1ec40f47}},	//   _guhc, _pemp_, ጋቸው_, _مقدّ, 
   {{0x752403ee,0x7bdc333e,0x94080134,0x386c333f}},	//   _çizg, _vyru, _ɑmɑn_, _sadr_, 
   {{0x5f743340,0x2a6c0369,0x78b83341,0x7bdc033f}},	//   _شاگر, _daeb_, tivv, _wyru, 
   {{0x386c3342,0x3a240b6f,0x2a6c009d,0x7bdc3343}},	//   _qadr_, _wemp_, _eaeb_, _tyru, 
   {{0x3a243344,0xdb1c01e3,0x7bdc0790,0x69c4002f}},	//   _temp_, öväg, _uyru, ßher, 
   {{0x2a6c0007,0xd9d40154,0x00000000,0x00000000}},	//   _gaeb_, _তৃণম, --, --, 
   {{0x656c01fa,0x00000000,0x00000000,0x00000000}},	//   _šahr, --, --, --, 
   {{0x2bd80073,0x53800023,0xba000092,0xbb5401ec}},	//   _बुडा, _ክመውት_, _ውሉ_, _ﻋﻤﻕ_, 
   {{0x72d000d1,0x9f6001e1,0x00000000,0x00000000}},	//   يەتچ, _àpès_, --, --, 
   {{0x95c8074d,0x52a4007b,0x00000000,0x00000000}},	//   _пула_, اصدق, --, --, 
   {{0x05700133,0xd5d40408,0xd9f409b2,0x00000000}},	//   _هاود, _тiам, ेशित_, --, 
   {{0x6f040455,0xf4843345,0xc10400ae,0x00000000}},	//   _puhc, _خاصی, صوفي, --, 
   {{0x2bd800bc,0xb4d009b2,0x00000000,0x00000000}},	//   _बुढा, वकी_, --, --, 
   {{0xd9f40073,0x8d84187f,0x00000000,0x00000000}},	//   ेशात_, лузд, --, --, 
   {{0xe1840220,0x316801c7,0x75240790,0x52b000cf}},	// [2ff0] _көре_, _usaz_, _çizd, _نەگئ, 
   {{0x90e400ae,0x00000000,0x00000000,0x00000000}},	//   _حسبن, --, --, --, 
   {{0x60f80375,0xdb243346,0x00000000,0x00000000}},	//   _שהתק, لولی, --, --, 
   {{0xb5043347,0xc3300375,0xe91800d4,0x00000000}},	//   रदाय_, מוע_, воді_, --, 
   {{0xa9683348,0xaa8801d5,0x2a6c0254,0x00000000}},	//   тила_, _ینسم_, _vaeb_, --, 
   {{0xe7383349,0x6d5c0483,0x78642160,0xf770004b}},	//   век_, _ipsa, مدىك, ګاه_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2bd800af,0x99842ca8,0x00000000,0x00000000}},	//   _बुता, mboş_, --, --, 
   {{0x67200175,0x2408013e,0x00000000,0x00000000}},	//   _twlj, ънои_, --, --, 
   {{0xe284334a,0xf7d4040d,0x9878008f,0xe58400db}},	//   ални, _ﭘﺎﻳﺪ, _שרעק, _چۅبۉ_, 
   {{0x6d5c1096,0x00000000,0x00000000,0x00000000}},	//   _opsa, --, --, --, 
   {{0x9e64158b,0xd12c009f,0x00000000,0x00000000}},	//   یارن, ومَ_, --, --, 
   {{0x25ac030a,0xa0680063,0x637821f3,0x00000000}},	//   mzel_, њава_, _асир_, --, 
   {{0x4424334b,0x6d5c334c,0xa2340276,0x6d48054e}},	//   _ien_, _apsa, _кэпш, _ţeap, 
   {{0x4424334d,0x6d5c0b4b,0xddc401f0,0x9f4c01e1}},	//   _hen_, _bpsa, абби, _àfí_, 
  
   {{0x25ac0d16,0x9d44334e,0x9c24130f,0x8e040138}},	// [3000] nzel_, резд, идад, рнув_, 
   {{0x4424334f,0x25ac3350,0x4c800261,0x752405d1}},	//   _jen_, izel_, олув, _çize, 
   {{0x44240c3e,0x6d5c127b,0xfa740092,0xdee4030d}},	//   _men_, _epsa, _በምክር_, _вони, 
   {{0x44243351,0x9d443352,0x4e2400cf,0x09b400eb}},	//   _len_, _кемд, _коюн_, _জড়া, 
   {{0x44243353,0x6d5c01c0,0x7e6401c8,0x25ac3354}},	//   _oen_, _gpsa, meip, jzel_, 
   {{0x44243355,0xdca41d3e,0x7e643356,0x3ea00e21}},	//   _nen_, _таги, leip, lkit_, 
   {{0x25ac3357,0x65780076,0x3ea03358,0x07a00114}},	//   ezel_, _arwh, okit_, жајн, 
   {{0x44240226,0x3ea03359,0x7e640099,0xdc2c03be}},	//   _aen_, nkit_, neip, _yığm, 
   {{0x3ea0335a,0xf4d806b3,0xf484335b,0x00000000}},	//   ikit_, лмиш_, مادی, --, 
   {{0x3ea00649,0x7e640022,0xfaa40818,0xb4d01408}},	//   hkit_, heip, _тағо, वके_, 
   {{0x442414f5,0x3ea0335c,0x63ac0b45,0x48041d1b}},	//   _den_, kkit_, _ƙana, _техн_, 
   {{0x4424335d,0x96f8335e,0x6b801ada,0x1dc41c15}},	//   _een_, _شعار_, _álge, लपात, 
   {{0x4424335f,0x3ea00a73,0x7cf00036,0xa1a400fb}},	//   _fen_, dkit_, märf, бырһ, 
   {{0x44243360,0x3ea0039a,0xb2b8190b,0xd378030d}},	//   _gen_, ekit_, _әлиф_, _ачи_, 
   {{0xdc2c3361,0x43400e92,0x8e240f89,0x7f9414b3}},	//   _sığm, _дејв, ифад, оарх, 
   {{0x44243362,0x3ea03363,0x5ca40372,0x7cf0007c}},	//   _zen_, gkit_, ەلكە, närf, 
   {{0xfd740276,0x8d743364,0xc5f0010f,0x25a800a2}},	// [3010] олтэ, جازا, ַדע_, _ýalt_, 
   {{0x7cf03365,0x3ea03366,0x44243367,0x2f100022}},	//   härf, akit_, _xen_, _ỹgua_, 
   {{0x3ea000b5,0x25ac3368,0xeac80165,0xaed4010b}},	//   bkit_, zzel_, _neùé_, _гонш, 
   {{0x3ea03369,0xbad802bf,0xd6c4336a,0x7e64336b}},	//   ckit_, афії_, _رق_, ceip, 
   {{0x6d5c336c,0x6e2c336d,0xbdd4005b,0x00000000}},	//   _upsa, maab, _моющ, --, 
   {{0x6e2c336e,0xb4d00316,0x25ac09a8,0xc7100055}},	//   laab, वको_, vzel_, _anūḍ, 
   {{0x4424336f,0xb4d000bc,0x2b7400f2,0x00000000}},	//   _ren_, वकै_, _دیاگ_, --, 
   {{0x6e2c2f99,0x25ac3370,0xa68401d5,0x069000e5}},	//   naab, tzel_, слид, تاتھ, 
   {{0x44243371,0xddc40f72,0xe2983372,0xe69402dd}},	//   _pen_, _kakš, ҳан_, _қиды, 
   {{0x44243373,0x25ac3374,0x3ea001c6,0x6e2c3375}},	//   _qen_, rzel_, zkit_, haab, 
   {{0xe2983376,0x6e2c3377,0xa2280b32,0x25ac179a}},	//   ган_, kaab, лжна_, szel_, 
   {{0x3ea00227,0x6e2c01d9,0xf674088c,0xf7703378}},	//   xkit_, jaab, _وانخ, _زام_, 
   {{0x6e2c3379,0x7e640333,0x44240c30,0xe5e400f2}},	//   daab, veip, _ten_, _ازای, 
   {{0x6568337a,0x7cf000af,0x442400fd,0xddc4337b}},	//   mweh, märg, _uen_, _nakš, 
   {{0x7e64337c,0x7cf00598,0x6568337d,0x8fa0337e}},	//   teip, lärg, lweh, паре, 
   {{0x539806a9,0x6e2c337f,0x3ea03380,0x2bbc3381}},	//   _תיקו, gaab, ukit_, ्पना, 
   {{0x3ea03382,0x7e643383,0x65683384,0x9f04036b}},	// [3020] rkit_, reip, nweh, _گوجو, 
   {{0x3ea03385,0x62943386,0xe8180cf1,0xd5d407d5}},	//   skit_, _hoyo, नुमा_, _тiем, 
   {{0x62943387,0x6e2c3388,0x26dc2252,0x65680134}},	//   _koyo, baab, _okwo_, hweh, 
   {{0x6e2c0050,0x629406f2,0x65683389,0x7cf000fd}},	//   caab, _joyo, kweh, kärg, 
   {{0x6294338a,0x7cf000af,0x65680230,0x99d400cf}},	//   _moyo, järg, jweh, حتاا, 
   {{0x2bd80709,0x7cf0008e,0x00000000,0x00000000}},	//   _बुवा, därg, --, --, 
   {{0xd6d8338b,0xfd6401f2,0xacb0129d,0x6294035a}},	//   лти_, yerị, _تەلب, _ooyo, 
   {{0x6294338c,0xdca4016c,0x7cf0338d,0x75140798}},	//   _noyo, _таҳи, färg, омиф, 
   {{0x656800ca,0x569001ec,0x7cf0008e,0x00000000}},	//   gweh, жақт, gärg, --, 
   {{0x26dc01f2,0x3f7801a6,0xfd6402e3,0x60c001ab}},	//   _ekwo_, _oču_, werị, _ìomh, 
   {{0x6294338e,0xdbe40316,0x6e2c338f,0x00000000}},	//   _boyo, _करोड_, yaab, --, 
   {{0x65683390,0x6e2c3391,0x7cf00724,0x81b403d4}},	//   bweh, xaab, lärd, _জুই_, 
   {{0x62943392,0x2a3c0023,0x91480006,0x00000000}},	//   _doyo, _ኣኽብሮ, ычна_, --, 
   {{0x6e2c3393,0x1cc00156,0xb5041f13,0x00000000}},	//   waab, གོས_, रदीप_, --, 
   {{0x6e2c3394,0x88980a7c,0x6f0800df,0x4ea43395}},	//   taab, נבלי, ĉeco, браа, 
   {{0x629423db,0x7cf00724,0xbb50037e,0xddc400ef}},	//   _goyo, härd, _oemサ_, _sakš, 
   {{0x6e2c3396,0x60dc0109,0x7cf00724,0xd1e80023}},	// [3030] raab, _fkpm, kärd, መርቲ_, 
   {{0x6e2c3397,0x271400b0,0x62940165,0x27e80213}},	//   saab, _hāne_, _zoyo, şinə_, 
   {{0x62943398,0x65682da1,0x271418a6,0x6e2c3399}},	//   _yoyo, zweh, _kāne_, paab, 
   {{0xaa5804a9,0x6e2c01d9,0x6294002e,0x2714002b}},	//   риду_, qaab, _xoyo, _jāne_, 
   {{0xddc40fb7,0x2bd80c2e,0x7cf0338d,0xe9d80e92}},	//   _takš, _बुरा, färd, јкл_, 
   {{0xd1e8044e,0x7cf0339a,0x29000254,0x00000000}},	//   መርታ_, gärd, öha_, --, 
   {{0xaa440150,0xda2800db,0x00000000,0x00000000}},	//   _ونسى, ايۇۇ_, --, --, 
   {{0x7cf000fd,0x6568339b,0x78a808a5,0x478401ec}},	//   tärg, tweh, _eldv, _қызб, 
   {{0xa56413f9,0x6aa80c8c,0x7cf000fd,0x656801f5}},	//   تگان, _ilef, bärd, uweh, 
   {{0x6294339c,0x6568339d,0x291c0227,0x7cf008c6}},	//   _soyo, rweh, mpwa_, rärg, 
   {{0x6264339e,0x6568339f,0x629433a0,0xa3e81eed}},	//   овна, sweh, _poyo, рдна_, 
   {{0x26dc0eb4,0x7cf033a1,0x4df807f7,0x9f5c03b2}},	//   _ukwo_, märe, ्शाई_, øtí_, 
   {{0x7cf01248,0x629433a2,0x6aa80175,0x754000c7}},	//   läre, _voyo, _mlef, _зҽыз, 
   {{0xf49402d3,0x6aa800a9,0x62941bce,0x81c400c7}},	//   _ይፈልጥ_, _llef, _woyo, _ҭакҧ, 
   {{0x7cf033a3,0x629433a4,0x6aa833a5,0x1e9433a6}},	//   näre, _toyo, _olef, орар, 
   {{0x95e400db,0x00000000,0x00000000,0x00000000}},	//   _ايۇۇ, --, --, --, 
   {{0x7cf00598,0x216833a7,0x00000000,0x00000000}},	// [3040] häre, _типи_, --, --, 
   {{0x7cf00598,0x6aa833a8,0x5f2800f7,0x60dc0f85}},	//   käre, _alef, _коом_, _ukpm, 
   {{0x7cf033a9,0x6aa80793,0x291c0ea0,0xdc38031c}},	//   värd, _blef, epwa_, għġu, 
   {{0x6aa833aa,0xd358008f,0xdee40ce1,0xba080022}},	//   _clef, ידעל, _фоми, сҭаа_, 
   {{0x6aa8030a,0x78800419,0x00000000,0x00000000}},	//   _dlef, _návä, --, --, 
   {{0x7cf033ab,0x00000000,0x00000000,0x00000000}},	//   färe, --, --, --, 
   {{0xda6405d9,0x7cf00724,0x6aa80fac,0x00000000}},	//   _واري, gäre, _flef, --, 
   {{0xd944016c,0x6aa803cb,0x00000000,0x00000000}},	//   _меби, _glef, --, --, 
   {{0x29080194,0xb7bc00ef,0x00000000,0x00000000}},	//   íaat_, _meģi, --, --, 
   {{0xd49833ac,0x7cf033ad,0x769c002e,0x6aa805c7}},	//   рри_, bäre, _réyu, _zlef, 
   {{0x769c00e8,0xfa740092,0x271400b8,0x00000000}},	//   _séyu, _በምድረ_, _pāne_, --, 
   {{0x2bbc084a,0x51840063,0x7cf001e3,0x00000000}},	//   ्पता, оуга, närb, --, 
   {{0x672c05ce,0xd24c0050,0x8af800df,0x00000000}},	//   ćaje, _یۆد_, יפטק, --, 
   {{0xf8bc00ce,0x0f240022,0x00000000,0x00000000}},	//   ्चिय, жьам, --, --, 
   {{0x09b40cf1,0x27140053,0x201c0649,0x788001f1}},	//   _अध्य, _tāne_, ñtia_, _závä, 
   {{0x705433ae,0x00000000,0x00000000,0x00000000}},	//   _کندا, --, --, --, 
   {{0xf8bc33af,0x320803ac,0x100433b0,0xfd100efe}},	// [3050] ्चाय, _igay_, _мянм, نجل_, 
   {{0x6aa833b1,0x00000000,0x00000000,0x00000000}},	//   _slef, --, --, --, 
   {{0x0a6833b2,0x829404d3,0x29c80032,0x7cf00e78}},	//   ирди_, _رگێڕ, әтеү_, färb, 
   {{0x940033b3,0x7cf033b4,0x00000000,0x00000000}},	//   ɔkɔ_, väre, --, --, 
   {{0x6aa80023,0xdaa000db,0x00000000,0x00000000}},	//   _vlef, رەكپ, --, --, 
   {{0x7cf033b5,0x279433b6,0x320801a9,0xdf54004b}},	//   täre, зшир, _lgay_, _بریښ, 
   {{0x7ae00270,0x2488001e,0x32080c8c,0x6aa80156}},	//   _fkmt, _đam_, _ogay_, _tlef, 
   {{0x320833b7,0x3b040369,0x6aa833b8,0x291c0083}},	//   _ngay_, _gimq_, _ulef, ppwa_, 
   {{0x3a6401d9,0x7cf033b9,0xbd98037e,0x36e800d1}},	//   _زُلف, säre, yとma, غرىپ_, 
   {{0x320833ba,0xe71833bb,0x769c0de2,0x7cf033bc}},	//   _agay_, _هيئت_, _séyt, päre, 
   {{0x290433bd,0x32080280,0x994803ee,0xa2e433be}},	//   _iila_, _bgay_, _köşe_, зонд, 
   {{0x290433bf,0x290c06c8,0x21680801,0x6d400265}},	//   _hila_, _kuea_, бими_, _ālan, 
   {{0x290433c0,0xb7bc0029,0xe29807a5,0x00000000}},	//   _kila_, _reģi, _ҳай_, --, 
   {{0x290433c1,0x320833c2,0x2334030d,0x2408010a}},	//   _jila_, _egay_, _ехир, _унки_, 
   {{0x290433c3,0xe29833c4,0x00000000,0x00000000}},	//   _mila_, _гай_, --, --, 
   {{0x290433c5,0x53980375,0xddc400d0,0x63a002f0}},	//   _lila_, _ליצו, _lakť, myln, 
   {{0x290407d6,0x290c007f,0x00000000,0x00000000}},	// [3060] _oila_, _nuea_, --, --, 
   {{0x290433c6,0x7cf00139,0x00000000,0x00000000}},	//   _nila_, därc, --, --, 
   {{0xda0800c6,0x7cf033c7,0x320802d0,0x63a003ac}},	//   مياه_, tärb, _ygay_, nyln, 
   {{0x290418a6,0xd1e802d3,0xf1e0032c,0x63ac0198}},	//   _aila_, መይቲ_, _गुड़_, _ƙanj, 
   {{0x994800a2,0xceb0008f,0x63a033c8,0xdcf40064}},	//   _döşe_, _ניש_, hyln, lvyč, 
   {{0x290433c9,0x63a0007c,0xa95c030d,0x00000000}},	//   _cila_, kyln, ăклă_, --, 
   {{0x9484010b,0xe6ec00dc,0x00000000,0x00000000}},	//   җыпд, _ṣaḍa, --, --, 
   {{0x290c0093,0xda6402dd,0xb4e4023e,0xa91c013a}},	//   _fuea_, _عازي, _भीड़_, _bržd, 
   {{0x290433ca,0xd944030d,0x00000000,0x00000000}},	//   _fila_, _хези, --, --, 
   {{0x290433cb,0x2250010e,0x733833cc,0x08c033cd}},	//   _gila_, _acyk_, озор_, _збун, 
   {{0x7c3c33ce,0x9954005f,0x672c00f3,0x93a80b24}},	//   _mdrr, kļūt_, ćajc, صادف_, 
   {{0x290433cf,0xa3bc0034,0x00000000,0x00000000}},	//   _zila_, _इधर_, --, --, 
   {{0x86780302,0x5184026a,0x257002dd,0x290433d0}},	//   _לראו, чуна, _ақыс, _yila_, 
   {{0x7c3c33d1,0x2714166a,0x29040009,0x45240327}},	//   _ndrr, _hāna_, _xila_, _རྦིར_, 
   {{0x271418a6,0xbef80490,0x59dc07f7,0x4ea40798}},	//   _kāna_, ंगून_, _फुसर, праа, 
   {{0x32080589,0x42540131,0x798003ac,0x00000000}},	//   _ugay_, _كۆپر, _ormw, --, 
   {{0x27140053,0x9f5c01ab,0xcc0833d2,0x00d80133}},	// [3070] _māna_, ùtò_, مزان_, تبێت_, 
   {{0xab7c001f,0x705410e8,0x00000000,0x00000000}},	//   _የሚውል_, _کنگا, --, --, 
   {{0x290418f7,0x290c0421,0x7980127b,0x2ef430d0}},	//   _rila_, _suea_, _armw, _озор, 
   {{0x290433d3,0x271433d4,0x290c04fe,0x59dc000d}},	//   _sila_, _nāna_, _puea_, _फुहर, 
   {{0x290422b9,0x63ac0198,0x798003ac,0x6e3c33d5}},	//   _pila_, _ƙank, _crmw, _idsb, 
   {{0x2ee833d6,0xee700184,0x2904036b,0x48c80183}},	//   llaf_, _яңғы, _qila_, িত্ৰ, 
   {{0x290433d7,0x798003ac,0x99480139,0x00000000}},	//   _vila_, _ermw, _töşe_, --, 
   {{0x290433d8,0x7cf000b0,0x798002d0,0x9f5c00d0}},	//   _wila_, mära, _frmw, äté_, 
   {{0x290433d9,0xa91c05a1,0x7cf033da,0x38b00e89}},	//   _tila_, _brže, lära, _bàrd_, 
   {{0x290433db,0x2ee803fa,0x5c98010f,0x63a0012d}},	//   _uila_, hlaf_, ַשרײ, tyln, 
   {{0x6e3c0194,0xa91c33dc,0x2ee801c7,0x7cf001f4}},	//   _odsb, _drže, klaf_, nära, 
   {{0x63a033dd,0xa91c0010,0xf65033de,0x27140055}},	//   ryln, _erže, _مئه_, _gāna_, 
   {{0x7cf033df,0xf4f801d3,0x00000000,0x00000000}},	//   hära, تویں_, --, --, 
   {{0x26cc0393,0x6e3c01bf,0x232833e0,0x7cf033e1}},	//   lneo_, _adsb, _доки_, kära, 
   {{0xdee433e2,0x7c3c0589,0x91002850,0xd00400a8}},	//   дови, _rdrr, тпре, дере_, 
   {{0xd12c01ed,0xdde001a6,0xfe7814fb,0xbef805c0}},	//   طمہ_, đužu, чүм_, ंगेन_, 
   {{0xd00c33e3,0x7c3c0004,0x26cc0393,0xf1d4009d}},	// [3080] الہ_, _pdrr, ineo_, _зөрө, 
   {{0x2ee8011f,0x6e3c33e4,0x01a801ec,0x7cf0007c}},	//   alaf_, _edsb, _мкқк_, fära, 
   {{0x92c00c58,0x7cf001e6,0x201833e5,0x2ee80af9}},	//   ্তৰ_, gära, _ifpi_, blaf_, 
   {{0x2ee833e6,0x1cc0031c,0xd94400ee,0x798002d0}},	//   claf_, གོང_, деди, _prmw, 
   {{0x26cc0063,0x271400b0,0xae7801c0,0x00000000}},	//   dneo_, _rāna_, _эсэх_, --, 
   {{0x7cf00267,0x2bd806b1,0x27140171,0x383400db}},	//   bära, _बुका, _sāna_, رىبز, 
   {{0x8c400640,0x09dc0154,0x47300ccb,0x2714002b}},	//   _јесе, বেলা, نريز, _pāna_, 
   {{0xda6412ea,0xfaf80032,0x24500131,0x26cc33e7}},	//   _تاسي, _эҫе_, ۇچىس, gneo_, 
   {{0xa91c05ce,0x672c17a3,0xae0002ab,0x27140055}},	//   _prže, ćaja, लेपन_, _vāna_, 
   {{0x271402b1,0x752433e8,0x60cc0175,0x00000000}},	//   _wāna_, _çizm, jnbm, --, 
   {{0x27140325,0xb7880cef,0xa91c33e9,0xdb0401e1}},	//   _tāna_, _хәле_, _vrže, _àmód, 
   {{0x07a033ea,0xd6c4036b,0x2ee8002e,0x4b34011a}},	//   _шахн, _کمچی, xlaf_, ורטל_, 
   {{0xa91c09a8,0x00000000,0x00000000,0x00000000}},	//   _trže, --, --, --, 
   {{0x21f0010b,0x20d80248,0x00000000,0x00000000}},	//   ыҗыс, _ṣiro_, --, --, 
   {{0x09d801f9,0xefe800e5,0x00000000,0x00000000}},	//   _बड्य, سٹرو_, --, --, 
   {{0x7cf033eb,0xb63004ce,0x60d80100,0x00000000}},	//   vära, _ｐｔ_, čtma, --, 
   {{0x823400e3,0x2ee833ec,0x60d8007f,0x2dd4009d}},	// [3090] _شريا, rlaf_, ōtma, хжар, 
   {{0x26cc33ed,0x321801d3,0x00000000,0x00000000}},	//   zneo_, lcsy_, --, --, 
   {{0xf9900272,0x2bd833ee,0x26cc00b5,0xeb08007b}},	//   یبه_, _बुखा, yneo_, أقصى_, 
   {{0x693433ef,0x29d40372,0x6e3c02d0,0x7cf00847}},	//   енду, ىياس, _udsb, rära, 
   {{0x7cf00e03,0xae040220,0x2f14007c,0x14dc00bc}},	//   sära, _سوسى, _håg_, नकाण, 
   {{0x7cf033f0,0x786404a9,0x48bc015b,0x6d4c0254}},	//   lärn, ندىك, েত্র, muaa, 
   {{0x6d4c33f1,0xa7a81ee1,0x00000000,0x00000000}},	//   luaa, якка_, --, --, 
   {{0x6d4c0418,0x3f9c0129,0x657c01bf,0x28dc00cd}},	//   ouaa, _àvue_, æsho, यवहि, 
   {{0x26cc33f2,0x2f1433f3,0x6d4c33f4,0xdb0c0248}},	//   rneo_, _låg_, nuaa, _ìkòy, 
   {{0x26cc0063,0x7cf00724,0x795004d3,0xa91c02fb}},	//   sneo_, härn, _ئێوا, _tržb, 
   {{0xd6cc33f5,0x6d4c33f6,0x77901046,0x7cf033f7}},	//   شقی_, huaa, _نیوا, kärn, 
   {{0x7cf004f3,0x6d4c07dd,0x82841955,0x00000000}},	//   järn, kuaa, тқид, --, 
   {{0x6d4c20ac,0x00000000,0x00000000,0x00000000}},	//   juaa, --, --, --, 
   {{0x6d4c33f8,0x2f14007c,0x00000000,0x00000000}},	//   duaa, _båg_, --, --, 
   {{0x271400b8,0xe0d000db,0xe0600133,0x7cf0013d}},	//   _māno_, _ۅزد_, نێکی, färn, 
   {{0x6d4c04c9,0xdee40c60,0x7cf001e3,0x00000000}},	//   fuaa, хоби, gärn, --, 
   {{0x6d4c0eda,0xe0d01bf4,0x00000000,0x00000000}},	// [30a0] guaa, _مزد_, --, --, 
   {{0x5ce433f9,0x201800d8,0x92c000cc,0x00000000}},	//   ركال, _ufpi_, ্তৃ_, --, 
   {{0xdb8401c6,0x905400d9,0x3d1002c3,0x7cf0008e}},	//   эгжи, _אביו_, _थूरे_, bärn, 
   {{0x1d08084c,0x00000000,0x00000000,0x00000000}},	//   _неми_, --, --, --, 
   {{0xb10000a2,0xfb0000ef,0x198801a9,0x00000000}},	//   _àýón, _žūst_, ябди_, --, 
   {{0x672c1467,0x2bd8000d,0x00000000,0x00000000}},	//   ćajn, _बँचा, --, --, 
   {{0xcb6433fa,0x7f5c01e0,0xb8e801ad,0x00000000}},	//   _паре_, ntrq, _उष_, --, 
   {{0x75240205,0xcf9000d9,0xd5b8004e,0x00000000}},	//   _çizk, רטה_, зсо_, --, 
   {{0x6d4033fb,0xceb00375,0x349433fc,0x7cf001f4}},	//   _ālak, טיה_, вапр, näro, 
   {{0xd5e0063f,0x48e00798,0x00000000,0x00000000}},	//   _anọ, _боув, --, --, 
   {{0x046033fd,0x00000000,0x00000000,0x00000000}},	//   утым, --, --, --, 
   {{0xb6c401ec,0x2f1401e3,0xd3a400db,0x7cf00166}},	//   _шөлд, _råg_, _үркп, käro, 
   {{0x2f1433f3,0x7cf033fe,0x00000000,0x00000000}},	//   _såg_, värn, --, --, 
   {{0x2ed833ff,0x92c000bd,0x2bd81b77,0x73c400c7}},	//   भक्त, ্তে_, _बुझा, _аӡма, 
   {{0x7cf03400,0x00000000,0x00000000,0x00000000}},	//   tärn, --, --, --, 
   {{0x6d4c3401,0xb8fc031c,0x2f143402,0x7cf0008e}},	//   tuaa, _ྣམ_, _våg_, färo, 
   {{0x644c054e,0x00000000,0x00000000,0x00000000}},	// [30b0] şniţ, --, --, --, 
   {{0x6d4c3403,0x2f1401e6,0xbd4400d1,0x00000000}},	//   ruaa, _tåg_, اپلى, --, 
   {{0x6d4c3404,0x271400b0,0x69d801ad,0x00000000}},	//   suaa, _rāno_, _फुजी, --, 
   {{0x7cf03405,0x31680327,0x9f9404ae,0x00000000}},	//   lärl, _kpaz_, _סדרה_, --, 
   {{0x6d4c3406,0xd5a41eeb,0xe8941def,0x27140055}},	//   quaa, _ئف_, кадь, _pāno_, 
   {{0x1864074d,0x00000000,0x00000000,0x00000000}},	//   ваши_, --, --, --, 
   {{0xa0200037,0x277400c0,0xfce4009d,0x00000000}},	//   _ööel, тылё, _соёо, --, 
   {{0x7cf00724,0xa6840131,0x00000000,0x00000000}},	//   härl, тлид, --, --, 
   {{0x7cf00598,0x753405f5,0xe9a801d9,0xd5ac00f1}},	//   kärl, лээх, _تگان_, يځه_, 
   {{0xf8dc07f7,0xe3b001f7,0x6ec000cd,0x00000000}},	//   मकृप, لرج_, रोतु, --, 
   {{0x6288016b,0x31680139,0xc0ec0092,0xdce400c0}},	//   _ɔfof, _apaz_, _ቆሻሻ_, _erkė, 
   {{0x9f5c00d0,0xa6c800ae,0x00000000,0x00000000}},	//   ätí_, _توصل_, --, --, 
   {{0x7cf03407,0x65940022,0x00000000,0x00000000}},	//   färl, _шаду, --, --, 
   {{0x7cf03408,0xe3640139,0x307401d5,0x00000000}},	//   gärl, _акки, лусс, --, 
   {{0x1ea821e7,0xdea0036b,0xa3d43409,0xe2b40153}},	//   واري_, لیدی, _सखि_, _аспэ, 
   {{0xe3b001c8,0x00000000,0x00000000,0x00000000}},	//   _ٽرڪ_, --, --, --, 
   {{0x7cf00598,0xe0d8340a,0x0e600640,0xe0d000db}},	// [30c0] bärl, _ови_, јкун, _ۅزگ_, 
   {{0xa3d411a6,0x0c20340b,0x00000000,0x00000000}},	//   _सखा_, имун, --, --, 
   {{0xe72404d3,0xda7800a7,0x00000000,0x00000000}},	//   _دڵ_, дял_, --, --, 
   {{0xba18340c,0x0a642850,0xd9440023,0x00000000}},	//   ريتا_, врши_, _ብተወፋ, --, 
   {{0x90c801c0,0x1cc00327,0x67200171,0x41c801f9}},	//   _vvрv, གོད_, _atlj, रपटस, 
   {{0x25a80510,0x91b80302,0x752403ee,0xc9a40395}},	//   _ýaly_, ומני, _çizi, ъвче_, 
   {{0x2a7c0218,0x7cf00209,0xda5800a8,0xddc401ef}},	//   bdwb_, närm, _ораш_, _jakž, 
   {{0x38b0340d,0xcb6400a8,0x1af40154,0xea6401af}},	//   _dàra_, _шасе_, ইদহে_, _йњђн, 
   {{0xa91c340e,0xd7a80451,0x7cf0340f,0x00000000}},	//   _trža, _ڪٿان_, härm, --, 
   {{0xd36c2002,0x7cf0338d,0x6ef803b2,0x98f40f06}},	//   قۇت_, kärm, _kúbý, _рябч, 
   {{0x7cf0049f,0x61f401ef,0x56f004b4,0x00000000}},	//   värl, _azyl, _күкс, --, 
   {{0xa91c04b9,0xc6a010fc,0xb35401ed,0x00000000}},	//   _mržn, _врши, نیڈا_, --, 
   {{0x61f4068f,0x25b401d9,0x85b4027d,0xe818074f}},	//   _czyl, _مۆٹھ_, _لاوس_, नुका_, 
   {{0x09dc045e,0x63ac0198,0x38b001e1,0x00000000}},	//   বেকা, _ƙant, _yàra_, --, 
   {{0x92b40f84,0x1cc0031c,0x03a0009b,0x7cf0008e}},	//   _لحظا, གོན_, _вијо, gärm, 
   {{0x32543117,0x6b800789,0x00000000,0x00000000}},	//   _свир, _álgi, --, --, 
   {{0x7cf03400,0xacf800f3,0x00000000,0x00000000}},	// [30d0] märj, енау_, --, --, 
   {{0x4fc43410,0x7cf03411,0x0ba43412,0x4c0400ae}},	//   _асма, bärm, кшем, نظاف, 
   {{0x9464010e,0xfbd016a2,0x00000000,0x00000000}},	//   _gońş, يتم_, --, --, 
   {{0x6e9419c3,0xdb243413,0x00000000,0x00000000}},	//   _симу, اونی, --, --, 
   {{0x38b000a3,0x00000000,0x00000000,0x00000000}},	//   _sàra_, --, --, --, 
   {{0x6d5c025c,0x18740092,0x7cf0007c,0x00000000}},	//   _iqsa, _በችግር_, härj, --, 
   {{0xe8180243,0x7cf00108,0xf1c40d2e,0x00000000}},	//   नुगा_, kärj, _लेसन, --, 
   {{0x7cf00d77,0xf770034c,0x9ba0107b,0xb9540137}},	//   järj, تاه_, _دەمى, _چئلت, 
   {{0xa3b42a05,0x2bbc0b8f,0x7cf0007c,0x00000000}},	//   चैन_, ्पका, därj, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x168403e6,0x7cf001e3,0x61f4012d,0x00000000}},	//   _ڕاوێ, färj, _szyl, --, 
   {{0xe2983414,0x7cf001e6,0x6d5c01b9,0xf1c400af}},	//   хам_, värm, _oqsa, _लेहन, 
   {{0x63ac03f9,0x7cf003fa,0x2d5c0ffb,0xb61c0150}},	//   _ƙans, wärm, jìe_, _ﺤﺎ_, 
   {{0x23840050,0x657802d0,0xf0d402d5,0xd24c00f1}},	//   _مٔتِ, _iswh, аўсю, ينۍ_, 
   {{0x6d5c3415,0xe290007b,0x00000000,0x00000000}},	//   _aqsa, _هذة_, --, --, 
   {{0xde440023,0x00000000,0x00000000,0x00000000}},	//   _ንኽኸው, --, --, --, 
   {{0x212406a3,0xa0a4010b,0xdea0006c,0x00000000}},	// [30e0] _ïoh_, _бапд, لیگی, --, 
   {{0x7cf03416,0xddc40e96,0xa91c0114,0x20543417}},	//   märk, _takž, _pržn, _стир, 
   {{0xa0c4021a,0x5f743418,0xa91c01a6,0x58843419}},	//   _ليکو, _صادر, _bržo, ғыла, 
   {{0x38b001c3,0x657802d0,0x6d400055,0x00000000}},	//   _càrn_, _oswh, _ālav, --, 
   {{0x18a400d1,0x98a42996,0x6d5c06be,0xddc4012d}},	//   ладм, лиде, _gqsa, _jakż, 
   {{0xa91c341a,0xba1800b2,0x7e640254,0x00000000}},	//   _tržn, ريڪا_, lfip, --, 
   {{0xd90c341b,0x657805b1,0xcca0030c,0xc0440023}},	//   _کیت_, _aswh, _اڭقى, _ንዝተወ, 
   {{0x7cf0005b,0xd6d8341c,0x0f34010f,0x00000000}},	//   kärk, этл_, ארקט_, --, 
   {{0x7cf0341d,0x00000000,0x00000000,0x00000000}},	//   järk, --, --, --, 
   {{0xd324341e,0x85b401c4,0x00000000,0x00000000}},	//   льми, ульс_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd3880220,0x00000000,0x00000000,0x00000000}},	//   _үйде_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d5c022e,0xddc4002b,0x454001c8,0x00000000}},	//   _rqsa, _lakų, _انوق, --, 
   {{0x7e64341f,0xdebc0092,0x7cf00254,0xfac40241}},	//   ffip, ሰጠን_, pärj, _ààwè_, 
   {{0x9f5c00d0,0xddc40055,0xc330011a,0x7cf00166}},	//   ätá_, _nakų, _פופ_, bärk, 
   {{0x6d5c0408,0x8d741079,0xac183420,0x37a800cc}},	// [30f0] _qqsa, دازا, возу_, _কেমৰ, 
   {{0x7e640421,0x2d5c0268,0x812c010f,0x00000000}},	//   afip, rìe_, _רויִ, --, 
   {{0x672c3421,0x00d8007b,0x6b743422,0x00000000}},	//   ćajk, _حبيت_, рлеу, --, 
   {{0xddc40055,0x2c1400eb,0x00000000,0x00000000}},	//   _cakų, িরেই_, --, --, 
   {{0x6e2c3423,0x7bdc0998,0x6d5c0784,0xddc400b8}},	//   mbab, _exru, _uqsa, _dakų, 
   {{0x6d4c3424,0xd8203425,0x00000000,0x00000000}},	//   mraa, одши, --, --, 
   {{0x6d4c3426,0xa8640184,0xebc400c7,0x271400cd}},	//   lraa, геҙҙ, _тәан, _kāni_, 
   {{0x6e2c3427,0x657802c4,0x6d4c3428,0x271400de}},	//   nbab, _pswh, oraa, _jāni_, 
   {{0x6d4c3429,0xe91800d4,0xf1c4000d,0x00000000}},	//   nraa, _розі_, _लेलन, --, 
   {{0x6e2c0198,0x6d4c342a,0x7cf0342b,0x00000000}},	//   hbab, iraa, värk, --, 
   {{0x6d4c342c,0x6b8400b5,0x6e2c342d,0xddc400b8}},	//   hraa, nvhg, kbab, _yakų, 
   {{0x6d4c1dc1,0x7cf0342e,0x6578342f,0x271402b5}},	//   kraa, tärk, _tswh, _nāni_, 
   {{0x6d4c1aed,0xa4d4003b,0x00000000,0x00000000}},	//   jraa, _коді, --, --, 
   {{0x6d4c3430,0xa3140124,0x55b8011a,0x64a40454}},	//   draa, _кьиш, _במנו, _ъала, 
   {{0x6d4c3431,0x7cf016ca,0x8fa0084c,0xe29801e0}},	//   eraa, särk, оаре, _аай_, 
   {{0xd36c3432,0x6e2c3433,0xddc4006d,0x6d4c3434}},	//   _آهي_, gbab, _takż, fraa, 
   {{0x7e640869,0xd12c009f,0x2714002b,0x7eb80241}},	// [3100] rfip, _قمي_, _dāni_, _nípe, 
   {{0x6e2c04ba,0x1fa80117,0x00000000,0x00000000}},	//   abab, _акои_, --, --, 
   {{0x6e2c3435,0x6d4c3436,0x7cf03437,0x7e6400ca}},	//   bbab, araa, näri, pfip, 
   {{0x6d4c3438,0x8b2002bf,0x6ee0063f,0x27140055}},	//   braa, ідче, ịbra, _gāni_, 
   {{0x39403439,0x3f7804fe,0x7cf0343a,0x6d4c343b}},	//   éis_, _hōu_, häri, craa, 
   {{0x7cf0343c,0xd54001e1,0x21240200,0x00000000}},	//   käri, _lẹ́g, _çohu_, --, 
   {{0xd6d8343d,0x998401e4,0x7cf0007c,0x271400dc}},	//   кти_, mboŭ_, järi, _yāni_, 
   {{0x3f7804fe,0xd5641a5c,0x7cf0013d,0x00000000}},	//   _mōu_, атоп, däri, --, 
   {{0xef68044e,0x142801ca,0x7cf0007c,0x00000000}},	//   _ህግደፍ, кіно_, tärh, --, 
   {{0xd404343e,0xc974011a,0x00000000,0x00000000}},	//   ияни, _דגמי_, --, --, 
   {{0x6e2c343f,0x7eb806ed,0x3f780374,0x28b800a8}},	//   ybab, _zípe, _nōu_, _сутэ_, 
   {{0x3b180113,0x6d4c3440,0xd628173e,0x6e2c0009}},	//   _murq_, yraa, _роде_, xbab, 
   {{0x6d4c0694,0x271400b0,0x914800a7,0x00000000}},	//   xraa, _rāni_, ъчна_, --, 
   {{0x6d4c3441,0x93880022,0xd1d400d1,0x271400ef}},	//   vraa, _асиа_, лққә_, _sāni_, 
   {{0x6e2c0072,0x6d4c3442,0xbfa823be,0x27140055}},	//   tbab, wraa, атте_, _pāni_, 
   {{0x6d4c3443,0xd5400241,0x38b006af,0x6e2c017a}},	//   traa, _gẹ́g, _sàrl_, ubab, 
   {{0x6d4c3444,0x6e2c3445,0x672c07f5,0xe7ec25c9}},	// [3110] uraa, rbab, ćaji, _चुना_, 
   {{0x6d4c3446,0x6e2c3447,0x2dd401ec,0x00000000}},	//   rraa, sbab, ажұр, --, 
   {{0x6d4c3448,0x27140882,0x769c002e,0xdb2404f2}},	//   sraa, _tāni_, _wéyy, مولی, 
   {{0x6e943449,0x6d4c2253,0x7e280212,0xe91800d4}},	//   _الحا, praa, _віра_, годі_, 
   {{0x6d4c01d9,0xa04c0023,0x9f4c0241,0x00000000}},	//   qraa, _ንምእታ, _àfò_, --, 
   {{0xe7380228,0xc864344a,0x98a000cf,0x00000000}},	//   гек_, ртди, зише, --, 
   {{0xdebc0092,0xcb0801c4,0x00000000,0x00000000}},	//   ሰጠኝ_, _ахад_, --, --, 
   {{0x49b004a9,0x7cf033eb,0x2488344b,0x4990030f}},	//   _мәлу, väri, _şam_, _ویار, 
   {{0xe570007b,0x23840171,0x00000000,0x00000000}},	//   سطة_, _sēj_, --, --, 
   {{0x67d4344c,0x7cf0344d,0x3afc00c7,0x69cc000d}},	//   _лозу, täri, rípe_, _देयी, 
   {{0x24900205,0x00000000,0x00000000,0x00000000}},	//   ızm_, --, --, --, 
   {{0xf770075e,0x27b004a9,0x3afc0022,0x7cf00c48}},	//   _تاك_, _мәқс, pípe_, räri, 
   {{0xa2e416c3,0xd5e00241,0x291c00f1,0x7cf0344e}},	//   _қоид, _gbò, nqwa_, märv, 
   {{0x7cf0344f,0x25ac3450,0xf3c83451,0x20d403de}},	//   päri, myel_, ابیه_, сімс, 
   {{0xa91c0010,0xa0a43452,0x25ac00e5,0x00000000}},	//   _bržk, _ғанд, lyel_, --, 
   {{0x291c01ee,0x7cf03453,0x00000000,0x00000000}},	//   kqwa_, närv, --, --, 
   {{0x25ac3454,0xf1d43455,0xdde83456,0xdce400da}},	// [3120] nyel_, _дөрө, ارزه_, _apkā, 
   {{0x3f780053,0x7cf00267,0xb5dc02dd,0x00000000}},	//   _tōu_, härv, _ﻁﺒﻴﻌ, --, 
   {{0x9f5c3457,0xdee41a39,0x38c800f6,0x1b480124}},	//   ätä_, _гони, یاتی_, узеи_, 
   {{0x7cf016b5,0x25ac007f,0x2714002b,0x60cc3458}},	//   järv, kyel_, _jānu_, libm, 
   {{0x271402b1,0x291c009a,0x26cc003e,0xa3a80490}},	//   _mānu_, gqwa_, dieo_, _गॅस_, 
   {{0xd7f828cf,0x25ac3459,0x48e006bb,0x3ea00841}},	//   луй_, dyel_, почв, ljit_, 
   {{0x07a02850,0x50180375,0x3ea000ad,0x00000000}},	//   зајн, נוקו, ojit_, --, 
   {{0x3ea0345a,0x25ac007f,0x60cc0477,0x8f98010f}},	//   njit_, fyel_, hibm, טיצי, 
   {{0x9484345b,0x25ac345c,0x3dc00472,0x18a40408}},	//   бынд, gyel_, nziw_, _лаам, 
   {{0x89a401b9,0x3ea0345d,0x661c0156,0x74a800ee}},	//   _укув_, hjit_, ñskr, рсиң_, 
   {{0xd6842716,0x60cc06be,0x00000000,0x00000000}},	//   _гулп, dibm, --, --, 
   {{0x27140055,0xd7040022,0x46a00395,0x03c001ec}},	//   _cānu_, _узеи, _нахв, ясым, 
   {{0x7cf02155,0x27140055,0xd1c8009d,0x00000000}},	//   läru, _dānu_, уунд_, --, 
   {{0xc0c8345e,0xd5e00ca8,0x661c0030,0xc0580150}},	//   бусе_, _gbó, ľske, йіс_, 
   {{0x0ca8039b,0xb4d40490,0x932400db,0x661c00d0}},	//   қтаи_, सची_, _ارتن, žske, 
   {{0xad24345f,0x3ea002d3,0x6db40137,0x00000000}},	//   قىرى, gjit_, ойбу, --, 
   {{0x60cc0139,0x00000000,0x00000000,0x00000000}},	// [3130] bibm, --, --, --, 
   {{0xa3b400dc,0x70540214,0x7cf0000d,0x00000000}},	//   चैव_, _بندا, käru, --, 
   {{0x25ac1529,0x66e00421,0xea183460,0x6ed0000d}},	//   zyel_, lēke, ажеш_, _ठगपु, 
   {{0xa91c01a6,0x00000000,0x00000000,0x00000000}},	//   _hrži, --, --, --, 
   {{0x394400d2,0x7cf000c5,0xa91c0010,0x2bd40073}},	//   _cvms_, värv, _krži, _दशका, 
   {{0xa7a818ac,0x00000000,0x00000000,0x00000000}},	//   икла_, --, --, --, 
   {{0x26cc01af,0x2d8816b8,0x00000000,0x00000000}},	//   tieo_, lvae_, --, --, 
   {{0xe6183461,0x25ac3462,0x66e000b0,0x60cc022e}},	//   шди_, tyel_, kēke, zibm, 
   {{0x66743463,0xa9c000cf,0x00000000,0x00000000}},	//   مدکر, _تۅشۉ, --, --, 
   {{0xe4c410f5,0x25ac3464,0x26cc01ee,0x2d880421}},	//   ійни, ryel_, sieo_, ivae_, 
   {{0xe2983465,0x7cf002f6,0x25ac3464,0x7d000221}},	//   аан_, märt, syel_, _ëmse, 
   {{0xf7701f6e,0xae081b37,0x7cf0002f,0x00000000}},	//   _سام_, वधान_, lärt, --, 
   {{0x672c08ad,0xa91c0e04,0x27200183,0x7eb80ca8}},	//   ćaju, _brži, _যিটো_, _nípa, 
   {{0xa0340447,0x6ab40b7d,0x3fc8004b,0x7cf001e3}},	//   تىست, ंसुर, مدزی_, närt, 
   {{0xa91c3466,0x3f8c0122,0x60cc3467,0x2d88003a}},	//   _drži, ídu_, ribm, evae_, 
   {{0x7cf03468,0x60cc020c,0x3ea00076,0xa91c0064}},	//   härt, sibm, ujit_, _erži, 
   {{0x62943469,0x3ea0346a,0x7cf00724,0xe0d8346b}},	// [3140] _inyo, rjit_, kärt, _ввп_, 
   {{0x62940218,0x6284346c,0x7cf00267,0x1c44346d}},	//   _hnyo, ldko, järt, інем, 
   {{0x6284346e,0x00000000,0x00000000,0x00000000}},	//   odko, --, --, --, 
   {{0x6284346f,0x2714002d,0x7eb80174,0x198800c7}},	//   ndko, _lāns_, _fípa, ибеи_, 
   {{0x629400ec,0x00000000,0x00000000,0x00000000}},	//   _mnyo, --, --, --, 
   {{0x7cf03470,0x00000000,0x00000000,0x00000000}},	//   gärt, --, --, --, 
   {{0x629400b4,0xc8c403e6,0x7c3c3471,0x50180375}},	//   _onyo, توون_, _ierr, בוצו, 
   {{0x7c3c3472,0x6294068b,0x7eb80241,0x8f980a7c}},	//   _herr, _nnyo, _yípa, שיקי, 
   {{0x7c3c3473,0x5690005e,0x62840fac,0xee4c0023}},	//   _kerr, зақт, ddko, _ንጽባሒ, 
   {{0x7c3c0731,0x7cf03474,0x62943475,0x62843476}},	//   _jerr, märs, _anyo, edko, 
   {{0x964409a5,0x5f1802ab,0x00000000,0x00000000}},	//   _дэлд, _मूल्_, --, --, 
   {{0x7c3c3477,0x672c2375,0x6284002d,0x78a800d0}},	//   _lerr, ćajt, gdko, _hodv, 
   {{0xf1c42e3b,0x78a81cea,0xa91c05ce,0x7c3c000f}},	//   _लेखन, _kodv, _prži, _oerr, 
   {{0x76403478,0x62943479,0x7c3c0140,0x92040055}},	//   lamy, _enyo, _nerr, _avāï, 
   {{0x78a8037e,0x8500347a,0x7cf00267,0x03c00395}},	//   _modv, _توون, härs, _осъм, 
   {{0x7640347b,0x78a8347c,0x7eb8347d,0xd1380408}},	//   namy, _lodv, _pípa, _кхо_, 
   {{0x7c3c347e,0xa91c04b9,0x54fc2e05,0x9324009f}},	// [3150] _berr, _trži, _उठाए_, _ارڪن, 
   {{0x7c3c347f,0x76403480,0x2d883481,0xcf241b45}},	//   _cerr, hamy, rvae_, _ورجي, 
   {{0x76403482,0x798002d0,0xdce40171,0x1af40154}},	//   kamy, _asmw, _askē, েদনে_, 
   {{0x7cf03483,0x70543484,0x818807d6,0x76403485}},	//   wärt, _بنگا, _انیق_, jamy, 
   {{0x6e3c003a,0x7cf03486,0x78a83487,0xae000b72}},	//   _iesb, tärt, _bodv, लेखन_, 
   {{0x7c3c3488,0x6e3c3489,0x798002d0,0x78a800b8}},	//   _gerr, _hesb, _dsmw, _codv, 
   {{0xe73809fe,0x78a80e3c,0x7640000f,0x798003cb}},	//   щей_, _dodv, famy, _esmw, 
   {{0x7c3c348a,0x7640348b,0x7cf0348c,0x6e3c047e}},	//   _zerr, gamy, bärs, _jesb, 
   {{0x79a4348d,0x7cf002f6,0x7c3c348e,0x6e3c0687}},	//   _орфе, märr, _yerr, _mesb, 
   {{0x6e3c07d5,0x6aa8348f,0x7c3c3490,0x64983491}},	//   _lesb, _hoef, _xerr, стир_, 
   {{0xa3b8007b,0x76403492,0x00000000,0x00000000}},	//   صادر_, bamy, --, --, 
   {{0x6e3c143a,0x6aa80200,0x78a83493,0x76403494}},	//   _nesb, _joef, _zodv, camy, 
   {{0x6aa83495,0x78a800d2,0xa02000c5,0xa91c0064}},	//   _moef, _yodv, _öökl, _eržv, 
   {{0xf49402d3,0x7cf03496,0x65940124,0xdb1c01d3}},	//   _ክፈልጥ_, härr, _маҵу, szpé, 
   {{0xdfd03497,0x6e3c002e,0x7cf0088f,0x44243498}},	//   رير_, _besb, kärr, _ifn_, 
   {{0x6aa8009a,0x6e3c0165,0x1d241b04,0xd00c007b}},	//   _noef, _cesb, змам, طلق_, 
   {{0x6e3c3499,0x64400607,0x7cf0013d,0x00000000}},	// [3160] _desb, oali, därr, --, 
   {{0x2240349a,0x7640349b,0x6e3c349c,0xa63001e1}},	//   lakk_, zamy, _eesb, _jọbè, 
   {{0x6e3c0438,0x64400b23,0x66180083,0x6aa801a4}},	//   _fesb, iali, _ogwk, _boef, 
   {{0x7c3c349d,0x13ac015b,0x7cf0349e,0x4424030a}},	//   _werr, _ছেড়, tärs, _lfn_, 
   {{0x6440349f,0x442434a0,0x00000000,0x00000000}},	//   kali, _ofn_, --, --, 
   {{0x644034a1,0x76400209,0x6e3c0472,0x7c3c34a2}},	//   jali, wamy, _zesb, _uerr, 
   {{0x764034a3,0x6aa80af9,0xacb00e56,0x7cf034a4}},	//   tamy, _foef, _جەلب, särs, 
   {{0x69cc34a5,0x644034a6,0x224034a7,0x61f40205}},	//   _देवी, eali, jakk_, _oyyl, 
   {{0x644034a8,0x764034a9,0x78a800d2,0x948409a5}},	//   fali, ramy, _todv, пынд, 
   {{0x644034aa,0x764034ab,0xd49834ac,0x6aa801f5}},	//   gali, samy, сри_, _zoef, 
   {{0x764034ad,0x442434ae,0x61f400a2,0x00000000}},	//   pamy, _dfn_, _ayyl, --, 
   {{0x2018056a,0x644016b5,0x4424032e,0x00000000}},	//   _agpi_, aali, _efn_, --, 
   {{0x644034af,0x6e3c0789,0x00000000,0x00000000}},	//   bali, _resb, --, --, 
   {{0x6e3c34b0,0x733434b1,0xc0c8084c,0x00000000}},	//   _sesb, _قىتا, пусе_, --, 
   {{0x6e3c0438,0x224034b2,0xceb800ea,0xabcc0150}},	//   _pesb, bakk_, бља_, _ﻓﻁﺎﻋ, 
   {{0x862802d3,0x22400327,0x00000000,0x00000000}},	//   _ደቀንስ, cakk_, --, --, 
   {{0x6aa82112,0x7cf00267,0x6e3c014f,0x91a800cc}},	// [3170] _roef, värr, _vesb, _চেৰ্, 
   {{0x37b803bd,0xc1bc0302,0x6aa8017a,0x6e3c34b3}},	//   ྐྱོད, _למחש, _soef, _wesb, 
   {{0x6aa80549,0x6e3c05d2,0x7cf0002f,0xe46801f4}},	//   _poef, _tesb, tärr, llöä_, 
   {{0x644034b4,0xc3300302,0x6e3c03ac,0x00000000}},	//   zali, תוף_, _uesb, --, 
   {{0x3d9404a9,0x7b64008e,0x69cc1fc4,0x0ef801f9}},	//   _зияр, _үтсе, _देशी, ्षीस_, 
   {{0x644034b5,0x6aa834b6,0xd83c0219,0xec28007b}},	//   xali, _woef, ščna_, _ذكرى_, 
   {{0x6aa81140,0x66e434b7,0x98a000a7,0x7d0001c7}},	//   _toef, мока, тище, _ëmsa, 
   {{0x644034b8,0x37b80156,0x442434b9,0x00000000}},	//   wali, ྐྱེད, _sfn_, --, 
   {{0x442401e7,0xe7ec1b76,0x2240025c,0x00000000}},	//   _pfn_, _चुरा_, vakk_, --, 
   {{0x644034ba,0xa91c0306,0x00000000,0x00000000}},	//   uali, _držt, --, --, 
   {{0x61f402f6,0xa2e434bb,0x290434bc,0x22400003}},	//   _syyl, донд, _ihla_, takk_, 
   {{0x644034bd,0xe29834be,0x80d003f3,0x216834bf}},	//   sali, цам_, डोने, оими_, 
   {{0x644034c0,0x29040649,0x442434c1,0x224034c2}},	//   pali, _khla_, _tfn_, rakk_, 
   {{0x644034c3,0x44240109,0x2918020c,0x224003cd}},	//   qali, _ufn_, _ésau_, sakk_, 
   {{0x290434c4,0x224034c5,0x6568072d,0x00000000}},	//   _mhla_, pakk_, lteh, --, 
   {{0x82b8081f,0x61f4049b,0x13a401d3,0x00000000}},	//   _བཞིའ, _tyyl, _آنٹی_, --, 
   {{0x290401ee,0xdd900f47,0xd180008e,0x91d801ec}},	// [3180] _ohla_, خوذ_, _алый, _дәрi, 
   {{0x29040117,0x9bd4084c,0x656800c7,0x80dc00eb}},	//   _nhla_, мцеш, iteh, _মীর্, 
   {{0x9a8434c6,0xf00005f5,0x38b00e89,0x65680037}},	//   дулл, _бүри, _màrt_, hteh, 
   {{0x2904000a,0x38b001ab,0x7f5c0986,0x00000000}},	//   _ahla_, _làrt_, murq, --, 
   {{0x290401ab,0xc98034c7,0x656800f3,0x7f5c0309}},	//   _bhla_, вущи, jteh, lurq, 
   {{0x4870185e,0x8af403b9,0x00000000,0x00000000}},	//   ندىس, _çənl, --, --, 
   {{0xcb64084c,0x7f5c02d1,0x656834c8,0x8b200153}},	//   _оаре_, nurq, eteh, _адсе, 
   {{0x38c834c9,0x290434ca,0x00000000,0x00000000}},	//   _کاری_, _ehla_, --, --, 
   {{0x656801d3,0xd94434cb,0x7f5c06be,0x00000000}},	//   gteh, _цези, hurq, --, 
   {{0x09000276,0x7f5c0986,0x66e002b5,0x00000000}},	//   _апун, kurq, rēka, --, 
   {{0x61f800ac,0x88c40055,0x6568083e,0x562801f4}},	//   ətli, _deśī, ateh, _джем_, 
   {{0x387c05c7,0x645c0153,0x00000000,0x00000000}},	//   levr_, ėsia, --, --, 
   {{0xf1b802f0,0x54a4007b,0x656806be,0xca180150}},	//   áš_, _يحتف, cteh, _ﺴﺨﺔ_, 
   {{0xf48407d6,0x7f5c0009,0xd16000c7,0x387c03b9}},	//   _ساتی, furq, ннҭқ, nevr_, 
   {{0x7eb80139,0x00000000,0x00000000,0x00000000}},	//   _típl, --, --, --, 
   {{0x0ef801ad,0x00000000,0x00000000,0x00000000}},	//   ्षेस_, --, --, --, 
   {{0xac9434cc,0x72940092,0x00000000,0x00000000}},	// [3190] нааш, _ልማታዊ_, --, --, 
   {{0xdebc001f,0x00000000,0x00000000,0x00000000}},	//   ደበኛ_, --, --, --, 
   {{0xd1d0001f,0x387c06be,0xcf2400ae,0x00000000}},	//   _የላቀ_, devr_, _ترخي, --, 
   {{0x290403a2,0x0dc834cd,0x65680f12,0x69c4004e}},	//   _shla_, _дуги_, yteh, нөзб, 
   {{0x6f0c34ce,0x5e5400c8,0x29040649,0x6568002f}},	//   mmac, _אירע_, _phla_, xteh, 
   {{0x6f0c34cf,0x57d00116,0x00000000,0x00000000}},	//   lmac, ﭘﻠﯩﺮ, --, --, 
   {{0x7b6434d0,0x92a803d4,0x6f0c34d1,0x00000000}},	//   _итте, _গগৈ_, omac, --, 
   {{0x38b0002e,0x661c00d0,0x61e002d2,0x00000000}},	//   _sàrt_, ľsko, _þolg, --, 
   {{0x7888005f,0x6f0c01a4,0x661c02fb,0x38b0002e}},	//   _būvē, imac, žsko, _pàrt_, 
   {{0x6f0c34d2,0x290434d3,0x656834d4,0x79581b0a}},	//   hmac, _uhla_, rteh, _цифр_, 
   {{0x656834d5,0x6f0c34d6,0xc6a40262,0x00000000}},	//   steh, kmac, _орди, --, 
   {{0x4ec0045e,0xf9900014,0x26c801b9,0x6f0c01f5}},	//   ্কুল, _حبہ_, _عطای_, jmac, 
   {{0x6f0c0086,0x29180789,0x672001a6,0x00000000}},	//   dmac, _ésas_, _hulj, --, 
   {{0x672034d7,0x307434d8,0x7f5c34d9,0x6f0c01a4}},	//   _kulj, кусс, turq, emac, 
   {{0x910034da,0x6f0c1f05,0x61e002f0,0x340800cf}},	//   упре, fmac, _žold, _ۉزۉپ_, 
   {{0xd12c040b,0x672034db,0x6f0c34dc,0x7f5c34dd}},	//   شمہ_, _mulj, gmac, rurq, 
   {{0x6720003d,0x7f5c0309,0xa97801e1,0x5fd0000d}},	// [31a0] _lulj, surq, _òjèé_, _सधवल, 
   {{0x9f8434de,0x6f0c0afe,0x672001c7,0x66e000b0}},	//   _згод, amac, _oulj, kēko, 
   {{0x10380375,0x6f0c020c,0x9b180131,0x7f5c0309}},	//   _מגיע, bmac, ستاز_, qurq, 
   {{0x6f0c058a,0xc0f8069d,0x8af403b9,0x4fd400df}},	//   cmac, ሊዝም_, _çəll, _טויב_, 
   {{0xa04c044e,0x7d0004e6,0xda640137,0x61e0032e}},	//   _ንምንታ, _ëmso, _ۋاري, _þold, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x38b00e89,0x387c0165,0x2b9000e5,0x00000000}},	//   _bàrr_, revr_, _پینس, --, 
   {{0x672034df,0x136800d1,0xdb0c01e1,0x00000000}},	//   _dulj, үшни_, _ìkày, --, 
   {{0x6720003e,0x68ec0066,0x09e017a0,0x00000000}},	//   _eulj, èndè, _ботн, --, 
   {{0x6d58000a,0x67200135,0x38b001ab,0x5fb028fe}},	//   šwag, _fulj, _eàrr_, ीनाल, 
   {{0x6f0c34e0,0x38b000a3,0x56f00131,0x6720010e}},	//   ymac, _fàrr_, _йүкс, _gulj, 
   {{0x9f5c00d0,0x95c81515,0x6f0c34e1,0x00000000}},	//   ätý_, _нула_, xmac, --, 
   {{0x672001fa,0xc1b834e2,0x6f0c0175,0x00000000}},	//   _zulj, елях_, vmac, --, 
   {{0x6f0c01a4,0xddc4012d,0x00000000,0x00000000}},	//   wmac, _odkł, --, --, 
   {{0x6f0c34e3,0xceb80114,0x00000000,0x00000000}},	//   tmac, пља_, --, --, 
   {{0x61e00024,0x6f0c08c2,0x00000000,0x00000000}},	//   _žole, umac, --, --, 
   {{0x70540597,0x4dd405af,0x66e000ef,0x00000000}},	// [31b0] _иѕнα_, رترس, dēkl, --, 
   {{0x6f0c34e4,0x7eb80af2,0x9c800427,0x4ec000eb}},	//   smac, _líph, ščne, ্কেল, 
   {{0xc4d000c8,0x6f0c34e5,0xdb24104c,0x00000000}},	//   נגע_, pmac, نولی, --, 
   {{0x59d0068f,0x672008a4,0xd3640133,0x786400d1}},	//   _देहर, _rulj, _ێه_, ۇدىك, 
   {{0x67200664,0xdeb00220,0x3e040064,0x00000000}},	//   _sulj, _тұты, _бярв, --, 
   {{0x9dd40302,0x61e001a8,0x0cdc00cc,0xc17401e4}},	//   _יורק_, _þole, _বীৰত, רחס_, 
   {{0x67200009,0x7c3805c7,0x6d40002b,0x46cc00cd}},	//   _qulj, ñvre, _ālay, तोऽह, 
   {{0x59d01be1,0x672034e6,0x659400c7,0x00000000}},	//   _देवर, _vulj, ҵаҩу, --, 
   {{0x98f40131,0x7eb80332,0x00000000,0x00000000}},	//   رغۇچ, _díph, --, --, 
   {{0x672034e7,0x22440960,0x00000000,0x00000000}},	//   _tulj, _žok_, --, --, 
   {{0x779034e8,0x3fdc00bd,0x9f5c0724,0x00000000}},	//   _هیوا, _ধর্ষ, ätü_, --, 
   {{0x828400d1,0x00000000,0x00000000,0x00000000}},	//   уқид, --, --, --, 
   {{0x20d400d6,0xd12c0592,0xd180020f,0x361401af}},	//   вівс, يمَ_, аляй, _йєшт, 
   {{0x201c0579,0x3e7c0208,0x64a400d8,0xb20400c7}},	//   øti_, _ật_, _јака, ыҵыз_, 
   {{0x10a034e9,0x7eb82852,0xddc80034,0xe8040073}},	//   ширн, _hípi, łoży, षेचा_, 
   {{0x6abc06b1,0x00000000,0x00000000,0x00000000}},	//   ्फोर, --, --, --, 
   {{0xed3405f5,0xd83c0122,0x6b94022e,0xe0d02732}},	// [31c0] гэхэ, áčka_, _arzg, _نزد_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3afc043b,0x7eb834ea,0xd83c09a8,0x4fe400c0}},	//   lípi_, _lípi, ščka_, _амэн_, 
   {{0x9d4402dd,0x9f580200,0x00000000,0x00000000}},	//   _иемд, _lypë_, --, --, 
   {{0x6b9434eb,0x98a434ec,0x4a501d31,0xba0400c7}},	//   _erzg, киде, ркіс, уҧал, 
   {{0x7eb800d2,0x6abc02ab,0x7e64000d,0xef180117}},	//   _síph, ्फॉर, lgip, _омӯ_, 
   {{0x7d1c0113,0x36d42c28,0x8ba00139,0x074000c7}},	//   _iirs, локр, _кирж, ахым, 
   {{0x7e6434ed,0x00000000,0x00000000,0x00000000}},	//   ngip, --, --, --, 
   {{0x7e640254,0x80b400c5,0xf484029e,0x00000000}},	//   igip, ुसाइ, هادی, --, 
   {{0xd90c34ee,0xe7ec34ef,0x733834f0,0x7d1c34f1}},	//   _بیت_, _चुका_, нзор_, _jirs, 
   {{0x7d1c34f2,0x00000000,0x00000000,0x00000000}},	//   _mirs, --, --, --, 
   {{0x7d1c0240,0x3fdc00fe,0x00000000,0x00000000}},	//   _lirs, _ধৰ্ষ, --, --, 
   {{0x7d1c1691,0x067000db,0x00000000,0x00000000}},	//   _oirs, _ئچىڭ, --, --, 
   {{0x7e6434f3,0x61e001a6,0x7d1c34f4,0xfbb400cd}},	//   egip, _žolc, _nirs, ूनाम, 
   {{0xbff834f5,0x99bc04c5,0x00000000,0x00000000}},	//   верх_, _অশোক, --, --, 
   {{0x7d1c0571,0x7e6403b2,0x00000000,0x00000000}},	//   _airs, ggip, --, --, 
   {{0xfac40ca8,0x00000000,0x00000000,0x00000000}},	// [31d0] _ààyè_, --, --, --, 
   {{0x27e80276,0x7e64013c,0xe1840166,0x6d780240}},	//   şani_, agip, _сөюе_, _ከካይዳ_, 
   {{0xfc3034f6,0xaa9402bf,0x00000000,0x00000000}},	//   تحق_, лижч, --, --, 
   {{0x7d1c035a,0x6b9400d7,0x00000000,0x00000000}},	//   _eirs, _vrzg, --, --, 
   {{0x7d1c20c6,0xd5a434f7,0x69cc34f8,0x28740598}},	//   _firs, _اف_, _देखी, гыйр, 
   {{0x7c34196c,0x7d1c34f9,0x6f1c34fa,0x6d4c0a55}},	//   _верх, _girs, _hisc, msaa, 
   {{0x6d4c34fb,0x7eb800db,0x6e2c003a,0x6f1c34fc}},	//   lsaa, _sípi, ocab, _kisc, 
   {{0x6e2c34fd,0x6f1c34fe,0x6d4c34ff,0xa6843500}},	//   ncab, _jisc, osaa, улид, 
   {{0x6d4c3501,0xc8643502,0x6e2c0286,0x0dc40023}},	//   nsaa, _атеи, icab, _ሸርፊ_, 
   {{0x6f1c3503,0x6d4c3504,0x7d1c01d9,0xf7700799}},	//   _lisc, isaa, _xirs, _ژان_, 
   {{0x6f1c0175,0xe7b4007b,0xa48400e5,0x00000000}},	//   _oisc, _حماد, نجھن, --, 
   {{0x6d4c3505,0x6f1c3506,0x68ec0491,0x55500116}},	//   ksaa, _nisc, éadf, شھۇر, 
   {{0x211c3507,0x6d4c01a4,0x6e2c054e,0x00000000}},	//   पदेश_, jsaa, dcab, --, 
   {{0x6f1c0491,0x6d4c3508,0x3fc80345,0x00000000}},	//   _aisc, dsaa, ندزی_, --, 
   {{0x6d4c3509,0x7d1c0077,0xd36c00c6,0xdea0350a}},	//   esaa, _rirs, _فهو_, میدی, 
   {{0x1ea823bb,0x6d4c350b,0x6e2c003c,0x6f1c26c2}},	//   رازي_, fsaa, gcab, _cisc, 
   {{0x7d1c0502,0x6d4c350c,0xd83c0024,0x26180115}},	// [31e0] _pirs, gsaa, ščia_, nɨo_, 
   {{0x6f1c350d,0xf33c001f,0x7d1c350e,0x4c6401c6}},	//   _eisc, _የሰብዓ, _qirs, лиун_, 
   {{0x7d1c350f,0x6d4c3510,0x00000000,0x00000000}},	//   _virs, asaa, --, --, 
   {{0x6e2c3511,0x6f1c3512,0x6d4c279a,0x7d1c3513}},	//   ccab, _gisc, bsaa, _wirs, 
   {{0x7d1c3514,0x6d4c011f,0x3940180f,0xf8b001e2}},	//   _tirs, csaa, èis_, يکئ_, 
   {{0x2cb009a8,0x7d1c01c3,0x7cf00036,0x6f1c002f}},	//   _gozd_, _uirs, härz, _zisc, 
   {{0x261005f9,0xb8fc0073,0x1a640066,0x7cf011a8}},	//   देसी_, _ढग_, _میای_, kärz, 
   {{0x41b405d7,0x6f1c004e,0x271400b8,0x00000000}},	//   ँहास, _xisc, _kāny_, --, 
   {{0xceb002e4,0x66800214,0x00000000,0x00000000}},	//   מיה_, زیول, --, --, 
   {{0x33743515,0x91cc00fe,0xda6400ec,0x00000000}},	//   агор, ৰথমখ, _جاڳي, --, 
   {{0x62980421,0x6e2c0009,0x28d80037,0x00000000}},	//   ēton, ycab, _भगति, --, 
   {{0x6d4c3516,0xd5400241,0x26103517,0xd70401b9}},	//   ysaa, _gé̟g, देही_, _ёзди, 
   {{0x6f1c02e8,0xcad40375,0xa3d800e1,0x85b43518}},	//   _risc, רוכת_, _ठेठ_, _ماوس_, 
   {{0x6f1c3519,0x6e2c009a,0x00000000,0x00000000}},	//   _sisc, wcab, --, --, 
   {{0x403405cc,0x7eb800d2,0x2268023a,0x8898008f}},	//   сесс, _lípu, ätkö_, עבלי, 
   {{0x6d4c0af5,0x261004aa,0x2fcc01e4,0xe9040208}},	//   tsaa, देवी_, ŝego_, _mượ, 
   {{0x6e2c351a,0x6d4c351b,0xe90401fb,0x6f1c3344}},	// [31f0] rcab, usaa, _lượ, _visc, 
   {{0x32080875,0x6d4c351c,0x6e2c09c2,0x5fd40034}},	//   _izay_, rsaa, scab, _डेवल, 
   {{0x6d4c351d,0x6f1c351e,0xddc4033b,0x2cb0351f}},	//   ssaa, _tisc, _lekň, _vozd_, 
   {{0x6f1c0597,0xcee83520,0xaa5804a9,0x2a6800c5}},	//   _uisc, _سرجن_, тиду_, üab_, 
   {{0x68443521,0xa9a43522,0x6d4c058a,0xe9a40108}},	//   анла, рилд, qsaa, ралп, 
   {{0x2d982b76,0xab9401ec,0x00000000,0x00000000}},	//   _irse_, _кигі, --, --, 
   {{0x628000e8,0x999801d9,0x7cf00108,0x00000000}},	//   _ñoog, _یپٲر_, järy, --, 
   {{0x2d980cf4,0x7eb803b2,0xe9040051,0x2714002b}},	//   _krse_, _fípu, _dượ, _yāny_, 
   {{0x7ac43523,0xa5241fbe,0xd6cc00ae,0x00000000}},	//   _усре, јмод, بقي_, --, 
   {{0x37a818ce,0x67d43524,0xa5080640,0x391402e8}},	//   ттән_, _козу, ђена_, _гмур, 
   {{0x36c40137,0xf1a80a1e,0x9f580129,0x32083525}},	//   рбөг, _קס_, _typé_, _azay_, 
   {{0xf77001ec,0x00000000,0x00000000,0x00000000}},	//   _ءال_, --, --, --, 
   {{0x26102982,0x64a43526,0x7cf00e78,0x26c0017a}},	//   देशी_, _вала, rärz, ëhou_, 
   {{0x27e80276,0x7eb8004e,0x7cf00112,0x657400d0}},	//   şanu_, _lípt, särz, ľahč, 
   {{0x2d983527,0x3208007f,0x5ef83528,0x7b2c0139}},	//   _arse_, _ezay_, вхар_, _ağun, 
   {{0x5de43529,0x2d7002d3,0x00000000,0x00000000}},	//   ажба, _ኣላምዶ_, --, --, 
   {{0x1c442c9d,0x3d2803e6,0x00000000,0x00000000}},	// [3200] инам, اتری_, --, --, 
   {{0x7eb803b2,0x91b80375,0xe8e40451,0xdca400d8}},	//   _rípu, _סמיי, _رڻ_, јажи, 
   {{0x2d98039a,0xdb840124,0x9058011a,0x5f0400d4}},	//   _erse_, ргеи, _בכית, _взна, 
   {{0x7eb809e8,0x59d000bc,0xe9040051,0x271400cd}},	//   _pípu, _देउर, _rượ, _tāny_, 
   {{0xed34152d,0x7eb8352a,0x81e800cc,0x00000000}},	//   _гэсэ, _dípt, _ভৰত_, --, 
   {{0xf75400c6,0xd7f8352b,0xa2d4352c,0xddc402e2}},	//   منتج, куй_, मोत्, _rekň, 
   {{0x57a4352d,0x1c080073,0xe84800e3,0x96e80022}},	//   ршла, _वरिल_, اجهن_, кьиа_, 
   {{0x7eb800dd,0x99340814,0xe9040208,0x7cf001f4}},	//   _típu, _نفرت, _vượ, väry, 
   {{0xa2a8193d,0x61e00427,0x068000d1,0x00000000}},	//   टान्, _žoln, ﻩﺗﻠﯩ, --, 
   {{0xe904004d,0x7cf00108,0x00000000,0x00000000}},	//   _tượ, täry, --, --, 
   {{0x94000296,0x00000000,0x00000000,0x00000000}},	//   ɛkɛ_, --, --, --, 
   {{0xd5e00248,0xafc41b56,0x46a001fe,0xd2b401d5}},	//   _gbo̟, ەيسى, _махв, рқиш_, 
   {{0xeeb81b6d,0x3a2413bb,0x7cf00108,0x00000000}},	//   қлаш_, _mgmp_, säry, --, 
   {{0x44f00691,0x7cf0005b,0x33982303,0xbf640051}},	//   _وسوز, päry, _منتج_, _ácực_, 
   {{0xb5e803f4,0x9410013f,0x96d800bc,0x00000000}},	//   _পরিচ, _ɑyɛ_, _बगाउ, --, 
   {{0x3a2405b1,0xa2d40bca,0x00000000,0x00000000}},	//   _ngmp_, मोद्, --, --, 
   {{0x8d84036b,0x320805d1,0x00000000,0x00000000}},	// [3210] шувд, _uzay_, --, --, 
   {{0x2d980fcf,0xcf24352e,0x00000000,0x00000000}},	//   _vrse_, _پردي, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe738352f,0x81e803d4,0x3a24045a,0x00000000}},	//   ңел_, _ভৰি_, _cgmp_, --, 
   {{0x3a240077,0xa8243530,0x3d943531,0x0dc83532}},	//   _dgmp_, مکان, _дияр, _руни_, 
   {{0x2d880428,0x25a80003,0x00000000,0x00000000}},	//   mwae_, _ħal_, --, --, 
   {{0x8aa43533,0x684401e0,0xaa940120,0x81e800fe}},	//   _крад, анһа, _ливч, _ভৰা_, 
   {{0x7980063f,0x00000000,0x00000000,0x00000000}},	//   _ịweg, --, --, --, 
   {{0xc4441208,0xb9340120,0x25a83534,0x00000000}},	//   لیشن_, _метј, ادعي_, --, 
   {{0x7b2c3535,0xf2c000cc,0x00000000,0x00000000}},	//   _oğul, _উদগণ, --, --, 
   {{0x8728036b,0x99940050,0x9c8000d7,0x00000000}},	//   _рўза_, _پھۆر_, áčie, --, 
   {{0x1b78008f,0x64c402dd,0x00000000,0x00000000}},	//   נטרע, _گيتل, --, --, 
   {{0xd36c0e83,0x25a83536,0x7b2c008e,0xe3b01410}},	//   وهی_, _çal_, _ağul, زرگ_, 
   {{0x2d883537,0x65c00220,0xffa401c6,0x25c80205}},	//   dwae_, _мұқа, олгү, ıtlı_, 
   {{0xdcb004a2,0xbe84036b,0x4dc403d4,0x64a40bd6}},	//   ۋىر_, оқни, লপোৱ, _ваһа, 
   {{0x2a6c01d4,0x0cd42baf,0xb5e80c58,0x00000000}},	//   _nceb_, তকোত, _পৰিচ, --, 
   {{0x62843538,0xe1640127,0x00000000,0x00000000}},	// [3220] meko, _ادعي, --, --, 
   {{0xb5d400fe,0x2084007b,0x00000000,0x00000000}},	//   _হুঁচ, _الدّ, --, --, 
   {{0x236400e5,0x00000000,0x00000000,0x00000000}},	//   nulj_, --, --, --, 
   {{0x24843539,0x318400e5,0x00000000,0x00000000}},	//   helm_, _úszó_, --, --, 
   {{0x9db8353a,0xa3d81715,0x236405be,0x59d0353b}},	//   _сыну_, _ठेस_, hulj_, _देखर, 
   {{0x6284353c,0x2a6c353d,0x2484353e,0xa2a80490}},	//   heko, _eceb_, jelm_, टाड्, 
   {{0x35d005f9,0x8c4000f3,0xeaf80116,0x00000000}},	//   _तेज़, _хесе, درەت_, --, 
   {{0x6284353f,0x2bb4069f,0x49c42123,0x5ac8010b}},	//   jeko, ंहरा, рлән_, _ёлам_, 
   {{0xf77004fb,0x68ec00ae,0x00000000,0x00000000}},	//   ساژ_, éadc, --, --, 
   {{0xf4d80184,0x798002d0,0x00000000,0x00000000}},	//   рмош_, _ipmw, --, --, 
   {{0x2364110c,0x62843540,0xb4e83541,0x00000000}},	//   gulj_, feko, _यदी_, --, 
   {{0x93e4006c,0x6444000d,0xd62814b3,0x00000000}},	//   _қўлл, _õhin, _соде_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa6e01125,0xe4f400aa,0x40343542,0x23640010}},	//   _áðre, _وغوښ, зерс, bulj_, 
   {{0x62843543,0x00000000,0x00000000,0x00000000}},	//   beko, --, --, --, 
   {{0x62843544,0x2d883545,0xe8a41546,0x00000000}},	//   ceko, twae_, _गच्च, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3230] --, --, --, --, 
   {{0x2d88073c,0x0ba43546,0x00000000,0x00000000}},	//   rwae_, йшем, --, --, 
   {{0xebd806ed,0x7b2c0b97,0x00000000,0x00000000}},	//   јдеш_, _uğul, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x98a00a83,0x62843547,0x1cb0025c,0xc8643548}},	//   дише, zeko, _ྐོར_, стди, 
   {{0xe7383549,0x62841aac,0x201c01e4,0xcb0801c4}},	//   шей_, yeko, ɾtis_, _бхад_, 
   {{0x2ee80cfd,0x628401c6,0x00000000,0x00000000}},	//   nnaf_, xeko, --, --, 
   {{0x6284354a,0xa91c0153,0xfe38011a,0x24c8004e}},	//   veko, _apže, זרחי_, игип_, 
   {{0x7d000221,0x6284354b,0x23640427,0x00000000}},	//   _ëmst, weko, tulj_, --, 
   {{0x8724354c,0xe2842461,0xc7c41fbe,0x00000000}},	//   _طعام, олни, _усаи, --, 
   {{0x2484354d,0x66e002b5,0x6284017a,0x00000000}},	//   selm_, tēku, ueko, --, 
   {{0x6284354e,0x2364009b,0x6b80007c,0x00000000}},	//   reko, sulj_, _älgf, --, 
   {{0x64a4354f,0xa06807fa,0x236400f3,0xd46416a4}},	//   _фака, јава_, pulj_, _дише_, 
   {{0x64403550,0x201c3551,0xdd9001ed,0x44243552}},	//   mbli, äti_, ڈوز_, _ign_, 
   {{0xdd9024e0,0x3f9c0174,0x26cc0051,0x00000000}},	//   ووز_, _ávum_, nheo_, --, 
   {{0x25400020,0x64403553,0x3be80184,0x00000000}},	// [3240] _የነበሩ, obli, әлеү_, --, 
   {{0x442433cb,0xee38013e,0xdb980640,0xa2d4146c}},	//   _jgn_, инӣ_, итељ_, मोर्, 
   {{0x64403554,0x26cc01e0,0x798002d0,0x00000000}},	//   ibli, kheo_, _spmw, --, 
   {{0x64401196,0x7980035a,0xaf3401d3,0x00000000}},	//   hbli, _ppmw, _ڈویژ, --, 
   {{0x64402506,0x44243555,0xe8c40073,0x09300b24}},	//   kbli, _ogn_, वसूच, وروج, 
   {{0x44243556,0x6c743557,0x25fc05f9,0xb92400dc}},	//   _ngn_, _нусх, _लड़ी_, _niḥś, 
   {{0x64403558,0x68ec00c6,0x07a00640,0xc7a0041b}},	//   dbli, éada, дајн, дијк, 
   {{0x38603559,0x35b4355a,0xddc402e2,0x64402a38}},	//   şir_, збир, _lekō, ebli, 
   {{0x94a8355b,0x4424355c,0x1868355d,0xc0f80023}},	//   атна_, _bgn_, _вази_, ጋጊሙ_, 
   {{0x6440251e,0x387800a3,0x1cb00327,0x00000000}},	//   gbli, _ùrr_, _ྐོས_, --, 
   {{0x4424355e,0x26cc0332,0x2ee8355f,0x00000000}},	//   _dgn_, bheo_, ynaf_, --, 
   {{0x26cc3560,0x7f88044e,0x4424060a,0x64403561}},	//   cheo_, _ምልካዊ_, _egn_, abli, 
   {{0x64403562,0xd20801c6,0x0900030d,0x6454022e}},	//   bbli, рэнд_, _апăн, аzid, 
   {{0x4424007c,0x93e401d5,0x2ee80142,0x349401f0}},	//   _ggn_, _мўйл, wnaf_, _хакр, 
   {{0x2444010a,0x7f943563,0x00000000,0x00000000}},	//   _хĕсс, марх, --, --, 
   {{0xad241a59,0x44240d27,0x66100254,0x2f100248}},	//   كىرى, _zgn_, _õhkõ, _ẹgba_, 
   {{0xee38010b,0x2ee80142,0x00000000,0x00000000}},	// [3250] инң_, rnaf_, --, --, 
   {{0x44240077,0x00000000,0x00000000,0x00000000}},	//   _xgn_, --, --, --, 
   {{0xfe7000dd,0xf99004d3,0x2fc400cc,0xca5000d1}},	//   عدہ_, ێبه_, ølgd_, _ﺋﻪﺭ_, 
   {{0x9f5c0158,0x3eb400d0,0x64400010,0x00000000}},	//   åtå_, ľatá_, zbli, --, 
   {{0x644000a9,0xad240220,0xae0404da,0x00000000}},	//   ybli, _ءىسى, _روسى, --, 
   {{0x26cc02b5,0x53c8043e,0x00000000,0x00000000}},	//   wheo_, ानाश, --, --, 
   {{0x26cc2ee9,0x44243564,0x8ae402bf,0x64400fac}},	//   theo_, _rgn_, _діал, vbli, 
   {{0x25ac01c4,0xddd400a2,0x00000000,0x00000000}},	//   txel_, ngyş, --, --, 
   {{0x44243565,0xaa441945,0xa2a800cd,0x00000000}},	//   _pgn_, _меңл, टास्, --, 
   {{0x64403566,0x26cc0789,0x63b40419,0x00000000}},	//   ubli, sheo_, äzno, --, 
   {{0x26cc052f,0xf7703567,0xddc4007f,0x33d400d4}},	//   pheo_, _لان_, _rekō, діят, 
   {{0x64403568,0xf77000ae,0x442415c0,0x00000000}},	//   sbli, _جاك_, _wgn_, --, 
   {{0x44243569,0x26101d8a,0xe5a4356a,0x273027b7}},	//   _tgn_, देखी_, _хили, _hán_, 
   {{0x97402d2b,0x27300ca8,0x44240267,0xdb1c036e}},	//   šćen, _kán_, _ugn_, typë, 
   {{0x8fa00abe,0x273001f1,0x34080150,0x65680ff3}},	//   наре, _ján_, _وزىپ_, lueh, 
   {{0x27301f60,0x3dc0014b,0x8664001f,0x00000000}},	//   _mán_, tyiw_, _ተቀብሎ_, --, 
   {{0x2730356b,0x6294356c,0xa06803c5,0x00000000}},	// [3260] _lán_, _iayo, _лапа_, --, 
   {{0x6294356d,0x2730004d,0x00000000,0x00000000}},	//   _hayo, _oán_, --, --, 
   {{0x6294356e,0x6568356f,0x26dc2252,0x37e00183}},	//   _kayo, hueh, _omwo_, _পুনৰ, 
   {{0x2fc43570,0x65680124,0xb4e80882,0x6294002b}},	//   ølge_, kueh, _यद्_, _jayo, 
   {{0x60dc003e,0x200c2630,0x62943571,0x0e9802e4}},	//   _kmpm, šlić_, _mayo, _השכל, 
   {{0x273001dc,0x62943572,0x7bd803b2,0x00000000}},	//   _bán_, _layo, úvus, --, 
   {{0xd6d83573,0x27300016,0x00000000,0x00000000}},	//   йти_, _cán_, --, --, 
   {{0x62943574,0x27303575,0xd5643576,0x65681196}},	//   _nayo, _dán_, птоп, fueh, 
   {{0x569004a2,0x65680124,0x00000000,0x00000000}},	//   дақт, gueh, --, --, 
   {{0x38c83577,0x62943578,0x273008de,0xb33c0092}},	//   _باری_, _aayo, _fán_, _የተገደ, 
   {{0x62943579,0x78a8357a,0x2730357b,0x00000000}},	//   _bayo, _indv, _gán_, --, 
   {{0x6294357c,0x6b800267,0x00000000,0x00000000}},	//   _cayo, _älge, --, --, 
   {{0x6294357d,0x01e00154,0xe6b4114f,0x00000000}},	//   _dayo, _যুবদ, _تلنگ, --, 
   {{0x628000e8,0xdce40139,0xbe8801ec,0x27300cad}},	//   _ñoon, _orkı, үсте_, _yán_, 
   {{0x6294357e,0x44780375,0x27300208,0xb4c803ce}},	//   _fayo, _הנוע, _xán_, ईसी_, 
   {{0x6294357f,0x00000000,0x00000000,0x00000000}},	//   _gayo, --, --, --, 
   {{0xa2a8189a,0xdce41f02,0xac940107,0x00000000}},	// [3270] टार्, _arkı, мааш, --, 
   {{0xb0343580,0xddd401d3,0x62943581,0x48b403d4}},	//   _юнош, ggyő, _zayo, _অগ্ৰ, 
   {{0x62943582,0xdb0c02fb,0x656801c7,0xa0341456}},	//   _yayo, ždýc, zueh, _تىپت, 
   {{0x27303583,0xd6c43584,0x6294036b,0x78a83585}},	//   _rán_, _شق_, _xayo, _andv, 
   {{0x27300ca8,0x3178002d,0xa91c0064,0x00000000}},	//   _sán_, ntsz_, _apža, --, 
   {{0x27300122,0x6da4035b,0x00000000,0x00000000}},	//   _pán_, _еиҭа, --, --, 
   {{0x690c0005,0x656801c7,0xd5ac00f1,0x2d080073}},	//   búen, wueh, یځه_, वतील_, 
   {{0x78a83586,0x273001fb,0xe558026a,0xdaa0215c}},	//   _endv, _ván_, ојој_, _لەمپ, 
   {{0x62943587,0x6aa83588,0xe85800d1,0x6b80007c}},	//   _rayo, _inef, _мааш_, _älgb, 
   {{0x27303589,0x6294358a,0x6aa8358b,0xbb380023}},	//   _tán_, _sayo, _hnef, _ብኣባላ, 
   {{0x6294358c,0x6aa80109,0x7c3805c7,0xc744104c}},	//   _payo, _knef, ñvri, _رضاي, 
   {{0x65680069,0x6294358d,0x3178030d,0x36d4358e}},	//   pueh, _qayo, ftsz_, _похр, 
   {{0xdc082208,0x65680589,0xe3d40154,0x6294358f}},	//   _वर्ड_, queh, _সুখব, _vayo, 
   {{0xdfd0004b,0xdea001b9,0x00000000,0x00000000}},	//   پير_, چیدی, --, --, 
   {{0x62943590,0x1ea8086e,0xdea001b9,0x2ec807d0}},	//   _tayo, ياري_, نیدی, रसूत, 
   {{0x629401a9,0x00000000,0x00000000,0x00000000}},	//   _uayo, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3280] --, --, --, --, 
   {{0x6aa81311,0x68ec0332,0x60240a5b,0xff0000eb}},	//   _anef, éadl, _одпа, ্দেশ_, 
   {{0x0d201b16,0x690c0005,0xaac401d5,0x3ec4024c}},	//   түрү, túen, کتلن, _зинҳ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x61e000ee,0xc950035b,0x00000000,0x00000000}},	//   _ýold, ҭтәы, --, --, 
   {{0x6aa80c8c,0xaf3404d3,0x97a43591,0x00000000}},	//   _enef, _توێژ, дрил, --, 
   {{0x2a7c01d4,0xda643592,0x0c2001fe,0x00000000}},	//   bfwb_, _ياري, _амрн, --, 
   {{0x656c0030,0x6ac403d4,0xa50800d1,0x00000000}},	//   _ťaha, লোবো, ۋىيە_, --, 
   {{0x09dc0156,0xd5b8010a,0x00000000,0x00000000}},	//   _སྟྭ_, юск_, --, --, 
   {{0x78a83593,0x73d83594,0xd36c1e4a,0x7b2c0356}},	//   _undv, здор_, لۇت_, _eşue, 
   {{0x68fc08a5,0x00000000,0x00000000,0x00000000}},	//   _ísda, --, --, --, 
   {{0xe7683595,0x6280002e,0x518400db,0x95c800f3}},	//   _رحمن_, _ñool, муга, _мула_, 
   {{0x4718010f,0x05d0007b,0x00000000,0x00000000}},	//   _וואג, _لزوج, --, --, 
   {{0x7334183c,0x00000000,0x00000000,0x00000000}},	//   _كىتا, --, --, --, 
   {{0x40343596,0x2ef422d7,0xceb80640,0x8500029e}},	//   тесс, езвр, оља_, _جوون, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa07400b8,0xfbd02927,0x00000000,0x00000000}},	// [3290] _aṇuś, یتم_, --, --, 
   {{0xb4bc0764,0x6aa83597,0x32083598,0x00000000}},	//   _इको_, _snef, _iyay_, --, 
   {{0xa2d4258d,0x3a3c0521,0x00000000,0x00000000}},	//   मोक्, _ịgụ_, --, --, 
   {{0x7ae00175,0x950c0327,0x00000000,0x00000000}},	//   _cmmt, _ཌེའི_, --, --, 
   {{0x13c83599,0x690c0077,0x637400a2,0x82d80677}},	//   ानुभ, búel, _künç, וואג_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3208035a,0x00000000,0x00000000,0x00000000}},	//   _oyay_, --, --, --, 
   {{0x3208359a,0xa524359b,0x00000000,0x00000000}},	//   _nyay_, нмид, --, --, 
   {{0x974004b9,0x33280393,0x79f40022,0x00000000}},	//   šćan, _aiax_, _рзух, --, 
   {{0x32080a81,0xe298359c,0x2904359d,0x7ae0037e}},	//   _ayay_, пан_, _ikla_, _ymmt, 
   {{0xa2280276,0xd24c00f1,0x00000000,0x00000000}},	//   яжма_, ینۍ_, --, --, 
   {{0x332804cc,0xf55401c0,0xa2d40027,0x6280002e}},	//   _diax_, _авчэ, मोग्, _ñoom, 
   {{0x257802bd,0x2604033f,0xb5c819be,0x00000000}},	//   mèl_, _हुयी_, _توهم_, --, 
   {{0x320803ac,0x2578359e,0xa2e40b01,0x00000000}},	//   _eyay_, lèl_, _покд, --, 
   {{0x224409a5,0xd0040bd6,0xeae000fe,0x00000000}},	//   _ýok_, хесе_, যকুম, --, 
   {{0x2578359f,0x290400a2,0x02cc012a,0xdca400c7}},	// [32a0] nèl_, _okla_, ासीन, нааи, 
   {{0x225003b2,0xc0f40023,0x63740205,0x00000000}},	//   _heyk_, _ግበሩ_, _günç, --, 
   {{0x61e009a5,0x2250079b,0x257835a0,0xe3c40327}},	//   _ýolb, _keyk_, hèl_, གགྲང, 
   {{0x290405d2,0x68e0015d,0x25781801,0xded8030d}},	//   _akla_, _amld, kèl_, _хьош_, 
   {{0xdcf40100,0xc9800108,0x4934003b,0x00000000}},	//   ltyč, гущи, езію_, --, 
   {{0x257835a1,0x02cc256a,0x22500162,0x00000000}},	//   dèl_, ासुन, _leyk_, --, 
   {{0x662400ac,0x36d435a2,0x00000000,0x00000000}},	//   ərkə, кокр, --, --, 
   {{0x290402e2,0x7ae035a3,0x257835a4,0x6b800267}},	//   _ekla_, _ummt, fèl_, _älga, 
   {{0x29040270,0x257835a5,0x00000000,0x00000000}},	//   _fkla_, gèl_, --, --, 
   {{0x44f000f7,0xdcf40100,0x00000000,0x00000000}},	//   лпыс, ktyč, --, --, 
   {{0x02cc2d6b,0xa7b4009b,0x00000000,0x00000000}},	//   ासून, _исцј, --, --, 
   {{0x257835a6,0x00000000,0x00000000,0x00000000}},	//   bèl_, --, --, --, 
   {{0xc68c0d83,0x25780ba1,0xc21800d4,0x00000000}},	//   _دِن_, cèl_, еєр_, --, 
   {{0x2ec835a7,0x68e00175,0xddd4007f,0xc0f40023}},	//   रस्त, _xmld, mayň, _ግበር_, 
   {{0xbb58037e,0x225003b2,0x4ea400c7,0x61e000ef}},	//   _ledシ_, _feyk_, нраа, _žolt, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8d741054,0x8c640220,0x320802d0,0x6c740063}},	// [32b0] عارا, етед, _uyay_, клађ, 
   {{0xbe3805f5,0x00000000,0x00000000,0x00000000}},	//   _үзэх_, --, --, --, 
   {{0xab740209,0x2578033b,0x00000000,0x00000000}},	//   тгеш, zèl_, --, --, 
   {{0x257811c1,0x7b2c0365,0x29040122,0xdbcc00c7}},	//   yèl_, _ağus, _skla_, _añóm, 
   {{0x6f0c35a8,0x2bac00ab,0x2578068c,0xba741291}},	//   mlac, _टपका, xèl_, اامت, 
   {{0x257835a9,0x01380375,0x656c0419,0xa82435aa}},	//   vèl_, ערות_, _ťaho, نکان, 
   {{0x6f0c35ab,0x3804013e,0x257802e2,0x00000000}},	//   olac, лошҳ, wèl_, --, 
   {{0xd7ec35ac,0x257835ad,0x6f0c35ae,0xdbcc00e4}},	//   تكى_, tèl_, nlac, _eñóm, 
   {{0x6f0c0113,0x88800214,0x22501d1d,0x41e00210}},	//   ilac, _میشن, _reyk_, _पेंस, 
   {{0x6f0c35af,0x257835b0,0x69d8013e,0x3a200022}},	//   hlac, rèl_, mzwe, ýipe_, 
   {{0x69d835b1,0xe7b42a9f,0x25fc2122,0x62800de2}},	//   lzwe, _جماد, _लडकी_, _ñook, 
   {{0x6e3c05be,0x6f0c01f1,0x257835b2,0x6ecc00e1}},	//   _nfsb, jlac, pèl_, _सतगु, 
   {{0x69d835b3,0xe3b00214,0x6f0c15c0,0x3f8c0135}},	//   nzwe, _چرب_, dlac, ħdum_, 
   {{0xb9fc0020,0x6f0c35b4,0xdb1c02f0,0x00000000}},	//   _ሆይ_, elac, vypí, --, 
   {{0xe29810e0,0xfe780372,0x22500280,0x6d5c35b5}},	//   _жай_, нүн_, _teyk_, _avsa, 
   {{0x7b2c00ac,0x525400c7,0xd12c01d3,0x630435b6}},	//   _oğur, _ихьӡ, صمہ_, _جوبل, 
   {{0x656835b7,0x71580006,0x00000000,0x00000000}},	// [32c0] nreh, _прэс_, --, --, 
   {{0x6f0c35b8,0x69d835b9,0x656835ba,0xa2a8090a}},	//   alac, dzwe, ireh, टाक्, 
   {{0x6f0c35bb,0x6d5c0205,0x819c0150,0x00000000}},	//   blac, _evsa, _ﻁﻴﻠﺔ_, --, 
   {{0xd94407c7,0x6f0c35bc,0x656835bd,0xa2d407b7}},	//   веди, clac, kreh, मोच्, 
   {{0x69d801f5,0x39400ea0,0x6568005c,0xacb000cf}},	//   gzwe, ëis_, jreh, _گەلب, 
   {{0x8c4035be,0x656835bf,0x7b2c0311,0xf8ac0210}},	//   _вере, dreh, _eşua, चाइय, 
   {{0x81b803d4,0xacb00137,0x656800e4,0x9ab00451}},	//   চনি_, _دەلب, ereh, _پڄاڻ, 
   {{0x25a80b3d,0x6d5c0076,0x656835c0,0x99e400fb}},	//   _šala_, _yvsa, freh, _иҫең_, 
   {{0x656835c1,0xb8d800cc,0xceb005d0,0x13c800cd}},	//   greh, _চত_, שיח_, ान्भ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6f0c35c2,0x656835c3,0xd824011c,0x00000000}},	//   ylac, areh, _рджи, --, 
   {{0x656835c4,0xddd40100,0x00000000,0x00000000}},	//   breh, payň, --, --, 
   {{0x6f0c0b91,0x84940efc,0xf1c802ef,0xd6c00014}},	//   vlac, رئیس_, روسى_, _مۅژی, 
   {{0x93a40131,0xd3a4084c,0x6f0c35c5,0x6d5c0175}},	//   _ашид, _арип, wlac, _rvsa, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb8d40003,0xb2740a8f,0x7e4400c7,0x6d5c0334}},	//   _ཞོ_, _слиш, ихуе, _pvsa, 
   {{0xddc4033b,0xd4980023,0x506400d8,0x00000000}},	// [32d0] _lekņ, _ገበነኛ_, _итна, --, 
   {{0x2604032c,0x64440254,0x8bc4004e,0x61e000ee}},	//   _हँसी_, _õhit, ксед, _ýola, 
   {{0x6f0c35c6,0x27300010,0x09c800dc,0xac1835c7}},	//   plac, _kšne_, ऽन्य, хожу_, 
   {{0x69d80639,0x6d5c35c8,0x65681347,0xdde00010}},	//   tzwe, _tvsa, yreh, šušt, 
   {{0xa96835c9,0x69d835ca,0x6d5c02d0,0xa88812e7}},	//   хила_, uzwe, _uvsa, ейла_, 
   {{0x1cb0081f,0x2d982b1d,0x69d804ef,0x6b8001e3}},	//   _ཐོར_, _isse_, rzwe, _älgo, 
   {{0x66e435cb,0xf77805d9,0x3ec407c5,0x69d80e78}},	//   лока, نلوڊ_, _èstà_, szwe, 
   {{0x656835cc,0x634002b5,0xe61035cd,0x6d8801e4}},	//   treh, _hēng, یشک_, _tɾad, 
   {{0x634002b5,0x64a400c0,0xe8f835ce,0xc8b035cf}},	//   _kēng, гапа, _знач_, _پلاک, 
   {{0x7b2c07b3,0x656835d0,0xe3b80835,0x67d40354}},	//   _uğur, rreh, ебо_, _йозу, 
   {{0x1cb00135,0x00000000,0x00000000,0x00000000}},	//   _ཐོལ_, --, --, --, 
   {{0x216835d1,0x656835d2,0x2d9835d3,0x66d402ea}},	//   ними_, preh, _osse_, _báke, 
   {{0x2ee80142,0x20d400d4,0xfd54002b,0xdb1c00e5}},	//   diaf_, гівс, bheṣ, nypá, 
   {{0x19b40375,0xa11401e2,0xfd5400b8,0x00000000}},	//   אפשר_, اوست, cheṣ, --, 
   {{0x2d9835d4,0x5454010f,0xdb1c0022,0x2ee8015d}},	//   _asse_, _עסקן_, hypá, fiaf_, 
   {{0x26cc03d1,0x944001ed,0x43c00014,0x66d402d2}},	//   nkeo_, _پھین, _مٲڈٲ, _fáke, 
   {{0x2d98003a,0x21a40166,0xdb1c00e5,0x255c0092}},	// [32e0] _csse_, _сипм, _évéb, _ለነበሩ, 
   {{0x5b340276,0x85002d8f,0x00000000,0x00000000}},	//   гэду, रकिट_, --, --, 
   {{0x2d9835d5,0x160805f9,0x66d40306,0x2ee80042}},	//   _esse_, _हुनर_, _záke, biaf_, 
   {{0xdd1000da,0xddc4007f,0x00000000,0x00000000}},	//   _kļūs, _rekņ, --, --, 
   {{0x9f04066d,0x6d580784,0x850007f7,0x4a5003de}},	//   _لوگو, šwar, रकाट_, скіс, 
   {{0x3ea035d6,0x1d0800cf,0x00000000,0x00000000}},	//   ldit_, _чеги_, --, --, 
   {{0xb8ec35d7,0x3ea035d8,0x6e3401e1,0x00000000}},	//   _लव_, odit_, _ègbé, --, 
   {{0x3ea035d9,0x3d1809bb,0xd5b81c7b,0xe7b000cf}},	//   ndit_, _बीते_, есо_, تۅمد, 
   {{0x3ea035da,0x00000000,0x00000000,0x00000000}},	//   idit_, --, --, --, 
   {{0x1cb00867,0x3ea035db,0xf364084c,0x394400d7}},	//   _ཐོས_, hdit_, аӂин, _itms_, 
   {{0x05b41dd8,0x00000000,0x00000000,0x00000000}},	//   ندیت_, --, --, --, 
   {{0x26cc0789,0x3ea035dc,0x00000000,0x00000000}},	//   ckeo_, jdit_, --, --, 
   {{0x313435dd,0x62b4054a,0x7d1c0112,0x42b80137}},	//   регр, рғыс_, _ohrs, اچىڭ_, 
   {{0x3ea0039a,0x2d980165,0x5064151e,0x261801ad}},	//   edit_, _rsse_, ытма, _परती_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xad240058,0x7d1c01ab,0x2ee835de,0x3ef8084c}},	// [32f0] لىرى, _bhrs, riaf_, унтэ_, 
   {{0x7d1c218f,0x3ea035df,0x2ee80142,0x00000000}},	//   _chrs, adit_, siaf_, --, 
   {{0x39440589,0x7d1c00a3,0x3ea016b8,0xa2a835e0}},	//   _atms_, _dhrs, bdit_, _जोड्, 
   {{0xdb1c00c7,0x00000000,0x00000000,0x00000000}},	//   typá, --, --, --, 
   {{0x2d980254,0xfd4401c6,0xca7000fb,0x9e58011a}},	//   _usse_, _гэсн, ауҙы, _בכרט, 
   {{0x634002b1,0x25a809a8,0x7c3435e1,0xe8200073}},	//   _hēne, _šalo_, _герх, मधला_, 
   {{0xdb1c35e2,0x634000b0,0xdbb4004e,0x00000000}},	//   sypá, _kēne, _карө, --, 
   {{0x6d8801e4,0x468001d5,0x00000000,0x00000000}},	//   _gɾac, ёқла, --, --, 
   {{0x63400029,0xe6180364,0x850435e3,0x26cc0010}},	//   _mēne, ъди_, лдиң_, rkeo_, 
   {{0x3ea035e4,0x26cc00df,0x00000000,0x00000000}},	//   zdit_, skeo_, --, --, 
   {{0x39400276,0x3ea035e5,0x68ec01e7,0x00000000}},	//   ţist_, ydit_, éadu, --, 
   {{0xf77035e6,0x634000b0,0x00000000,0x00000000}},	//   _رام_, _nēne, --, --, 
   {{0xa91c0006,0x3634009a,0x00000000,0x00000000}},	//   _apži, _ارمس, --, --, 
   {{0xa2a80b98,0x00000000,0x00000000,0x00000000}},	//   टाङ्, --, --, --, 
   {{0x634000ef,0x602435e7,0x00000000,0x00000000}},	//   _bēne, рдва, --, --, 
   {{0xe51835e8,0x6f1c0129,0xa1540354,0x00000000}},	//   _नीति_, _chsc, _къош, --, 
   {{0xdcb00447,0x6b8001e6,0x09d403d4,0x6284007c}},	// [3300] يىر_, _älgj, তপুথ, mfko, 
   {{0x628407ab,0xfa2c031c,0x3ea035e9,0xa2a828fe}},	//   lfko, _སུཏན_, sdit_, _जोत्, 
   {{0xda7802e8,0x00000000,0x00000000,0x00000000}},	//   вял_, --, --, --, 
   {{0x2018009d,0x0a6400a7,0x00000000,0x00000000}},	//   _izpi_, арши_, --, --, 
   {{0xdb0c0241,0x661c03b2,0x00000000,0x00000000}},	//   _àjík, ýskl, --, --, 
   {{0xcdcc021a,0x7d1c01bf,0x39440254,0x1a640133}},	//   _کښې_, _uhrs, _vtms_, _چیای_, 
   {{0xfd580055,0xabc40032,0x1a64158b,0x00000000}},	//   _asaḿ, _ларҙ, _نیای_, --, 
   {{0x628401f5,0x1ad401b9,0xab2835ea,0x00000000}},	//   jfko, _тўгр, _مسقل_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x398035eb,0x628435ec,0x9f580129,0xae180037}},	//   mòs_, efko, _expé_, _दरसन_, 
   {{0x398035ed,0x628435ee,0xc7a00139,0x201c0174}},	//   lòs_, ffko, _мифк, ýtil_, 
   {{0x85b40014,0x12e4003b,0x00000000,0x00000000}},	//   _چاوس_, ріог, --, --, 
   {{0x518435ef,0x61e00209,0x2018009d,0x634000b0}},	//   шуна, _ýoll, _azpi_, _rēne, 
   {{0x41e835f0,0xfe70004b,0xdb1c005b,0x92e40011}},	//   рфюм_, ېدل_, lypä, বকে_, 
   {{0x63400325,0x66d435f1,0x7b2c06be,0x942000d1}},	//   _pēne, _háka, _aşum, _بوغۇ, 
   {{0x398002e2,0x66d402d2,0x21ec0022,0x00000000}},	//   kòs_, _káka, ẽha_, --, 
   {{0x0408015b,0x3980067c,0x00000000,0x00000000}},	// [3310] হেদী_, jòs_, --, --, 
   {{0x2e3c01e1,0x63400374,0x7cd835f2,0x3980068c}},	//   _báfó_, _wēne, амур_, dòs_, 
   {{0x63401243,0x66d435f3,0xd5a412e1,0xdb1c023a}},	//   _tēne, _láka, _کف_, kypä, 
   {{0x6a8401b9,0x39800100,0xe9d82503,0x00000000}},	//   ёлла, fòs_, лмеч_, --, 
   {{0xa9a435f4,0x66d402fb,0x3980007f,0xd36400f1}},	//   силд, _náka, gòs_, _ډه_, 
   {{0xbf340326,0x00000000,0x00000000,0x00000000}},	//   _دریغ, --, --, --, 
   {{0x6284017a,0x2618000d,0x00000000,0x00000000}},	//   yfko, _परही_, --, --, 
   {{0x66d40cad,0x39801497,0x0e300023,0xe57801f0}},	//   _báka, bòs_, ኻትኩም, гзи_, 
   {{0x398035f5,0x07a00116,0xa5080124,0x68ec0332}},	//   còs_, сақн, леиа_, éads, 
   {{0xa91c0006,0x47f0014b,0x00000000,0x00000000}},	//   _apžv, _мӯйр, --, --, 
   {{0x64a435f6,0x28140acb,0xa3e82d3c,0x24a40014}},	//   _ҳала, _اواس, удна_, لٕکِ, 
   {{0xa044001f,0xaf7c069d,0x62840112,0x02c80107}},	//   ንዳንዳ, ንነትና_, ufko, рқии_, 
   {{0x64a435f7,0x1a98008f,0x628435f8,0x3f98031c}},	//   _гала, נישע, rfko, wwru_, 
   {{0xb3e803e6,0x61e0010e,0x34940117,0x00000000}},	//   اعیل_, _ýolm, _мачр, --, 
   {{0x66d40745,0x6440030d,0x690c0077,0x505c0023}},	//   _záka, mcli, lúes, _ንዝመጽ, 
   {{0x63100f22,0x1ea835f9,0xfe780137,0xd7200055}},	//   _সংকট_, داسي_, шүм_, _kṛṣ_, 
   {{0x71c4014b,0x05a40b27,0x7b18032e,0x00000000}},	// [3320] _маъҷ, कटिब, fíun, --, 
   {{0x644035fa,0x205401b9,0x97400301,0x398002e2}},	//   ncli, _утир, šćin, vòs_, 
   {{0x712423bb,0x644000a3,0xa0c400f1,0x398002e2}},	//   _بريل, icli, _نيکو, wòs_, 
   {{0x39800ba1,0xd378010f,0x00000000,0x00000000}},	//   tòs_, טרעט, --, --, 
   {{0xcb640220,0x98c400d4,0x00000000,0x00000000}},	//   _қате_, йскл, --, --, 
   {{0x398035fb,0x466401e0,0x66d400e5,0x6c74014b}},	//   ròs_, ҡрым_, _ráka, _мусх, 
   {{0x644035fc,0x398035fd,0xf8b80208,0x00000000}},	//   dcli, sòs_, _chĩa_, --, 
   {{0x644001a6,0x398035fe,0xda6406c5,0xdb0c0248}},	//   ecli, pòs_, _داسي, _àjàk, 
   {{0x64400175,0xdb1c0108,0xf4d8004e,0x35b400d4}},	//   fcli, rypä, имиш_, ібор, 
   {{0x64402ab0,0x00000000,0x00000000,0x00000000}},	//   gcli, --, --, --, 
   {{0xed640064,0x74140472,0x4cb800df,0x00000000}},	//   mažų_, تودا, אמיג, --, 
   {{0x690c0005,0x644000a3,0x96b802da,0x04441ef7}},	//   búes, acli, _حائز_, መስገን, 
   {{0xa6a80532,0x00000000,0x00000000,0x00000000}},	//   _خالق_, --, --, --, 
   {{0x6440003a,0xed6400c0,0x00000000,0x00000000}},	//   ccli, nažų_, --, --, 
   {{0x534406b3,0xbf040073,0xddc4012d,0x00000000}},	//   _ухла, लवून_, _tekś, --, 
   {{0xd5e001e1,0x6b80007c,0x00000000,0x00000000}},	//   _gbọ, _älgi, --, --, 
   {{0x1ac803d4,0x82f80244,0x00000000,0x00000000}},	// [3330] লোৱা, _دروز_, --, --, 
   {{0x634004fe,0x6280002e,0x00000000,0x00000000}},	//   _hēna, _ñoor, --, --, 
   {{0x634002b1,0x6d8801e4,0x690c00e4,0xed640064}},	//   _kēna, _gɾan, kúer, dažų_, 
   {{0x644000c6,0x6e942f5e,0x261802e5,0x00000000}},	//   zcli, _بلحا, _परली_, --, 
   {{0x644035ff,0xc9840588,0x0dc800d1,0x66d40a87}},	//   ycli, суеи, _суни_, _bákn, 
   {{0x6d4c3600,0x0b580956,0x63400171,0x00000000}},	//   mpaa, _مشرب_, _lēna, --, 
   {{0x6440074d,0xa8640184,0x6d4c3601,0x27200208}},	//   vcli, беҙҙ, lpaa, nóng_, 
   {{0x690c056a,0x64400142,0x00000000,0x00000000}},	//   túes, wcli, --, --, 
   {{0x6b843602,0xc44410e8,0x00000000,0x00000000}},	//   lthg, میشن_, --, --, 
   {{0x690c0077,0xe3641ab7,0x644001a6,0x1ce40327}},	//   rúes, окои, ucli, ྫིར_, 
   {{0xd4980354,0x00000000,0x00000000,0x00000000}},	//   ăри_, --, --, --, 
   {{0x64403603,0x6b8400a9,0x6d4c01f5,0x1b78010f}},	//   scli, ithg, kpaa, סטרע, 
   {{0x64400a40,0x66d408ce,0xb5940334,0x854400e5}},	//   pcli, _háko, _ницш, _آتے_, 
   {{0x6d4c01f5,0x27300010,0x6938010e,0xa2a81025}},	//   dpaa, _kšno_, _eňeg, _जोर्, 
   {{0x28d007f7,0x7b180166,0x00000000,0x00000000}},	//   _तकनि, fíul, --, --, 
   {{0x1cb00135,0x6d4c017a,0x66d400e5,0x5e48011c}},	//   _ཐོང_, fpaa, _máko, рпам_, 
   {{0x6d4c3604,0xa0683605,0xeb6c01ec,0x6b840142}},	// [3340] gpaa, _капа_, _ءﺟﻴﻰ_, ethg, 
   {{0x6d8801e4,0x107401e0,0x634000de,0x00000000}},	//   _tɾan, _мәсь_, _zēna, --, 
   {{0x68380023,0x66d43606,0x00000000,0x00000000}},	//   _ብሄራት, _náko, --, --, 
   {{0x6d4c01f5,0x00000000,0x00000000,0x00000000}},	//   bpaa, --, --, --, 
   {{0x3d140bc9,0x6b843607,0xf1dc0118,0x00000000}},	//   häwi_, athg, नैपन, --, 
   {{0x66d40085,0xd76801c0,0x17680075,0x9cb4007b}},	//   _báko, ашид_, арип_, _بمست, 
   {{0xd6d83608,0xcb643609,0x8c40011c,0xed6400c0}},	//   ити_, _маре_, _цесе, ražų_, 
   {{0xd564360a,0x00000000,0x00000000,0x00000000}},	//   отоп, --, --, --, 
   {{0x634002b5,0x66d40008,0xc6f402d5,0x7b2c1b0d}},	//   _rēna, _tákn, ўных_, _oğuz, 
   {{0x634000ef,0x00000000,0x00000000,0x00000000}},	//   _sēna, --, --, --, 
   {{0x634000b0,0x58d401ee,0x00000000,0x00000000}},	//   _pēna, _лоҡт, --, --, 
   {{0xe7a402dd,0x914801b9,0x00000000,0x00000000}},	//   _ءۇيى_, ичга_, --, --, 
   {{0x66d4076f,0xd5ac01d3,0xe72805af,0xd62800d8}},	//   _záko, _شہد_, _اسلو_, _тоде_, 
   {{0x1ce4025c,0x7ce0264d,0x1cb00327,0xf4842313}},	//   ྫིས_, _hörf, _ཐོཊ_, _راتی, 
   {{0x7ce0360b,0x634002b5,0x9268041b,0x09b400cd}},	//   _körf, _tēna, _крпа_, _आप्य, 
   {{0x66d403c6,0x0dec001f,0x6d4c0ea0,0x9324210e}},	//   _nákl, _ቁልፍ_, tpaa, _برتن, 
   {{0xdce405d1,0x7ce0002f,0x6b840142,0x00000000}},	// [3350] _askı, _mörf, wthg, --, 
   {{0x6d4c32ff,0x27200022,0xdde0054e,0x00000000}},	//   rpaa, móne_, ţuşt, --, 
   {{0x6b8402fa,0x272000d0,0x317806d8,0x00000000}},	//   uthg, lóne_, lusz_, --, 
   {{0x6d4c360c,0x6b8403cb,0x66d426f6,0x6dc00137}},	//   ppaa, rthg, _ráko, _كۅزۅ, 
   {{0x6d4c3209,0x3178297b,0xdce40205,0x272000e4}},	//   qpaa, nusz_, _eskı, nóne_, 
   {{0x3d140227,0x6f0c360d,0x201c0112,0x4aa802c3}},	//   yäwi_, loac, ütig_, _घोरव, 
   {{0x7b64360e,0x00000000,0x00000000,0x00000000}},	//   _отте, --, --, --, 
   {{0x31781f6f,0x27200022,0x75280210,0x00000000}},	//   kusz_, kóne_, emdz, --, 
   {{0x7ce00e78,0xe57000c6,0x97301f70,0xe9d80166}},	//   _dörf, رطة_, رکما, _умач_, 
   {{0x66d40745,0x6f0c0522,0x00000000,0x00000000}},	//   _zákl, hoac, --, --, 
   {{0x7ce004f3,0x00000000,0x00000000,0x00000000}},	//   _förf, --, --, --, 
   {{0x272000d0,0x6f0c360f,0xa3040456,0x00000000}},	//   fóne_, joac, रवेज_, --, 
   {{0x171804ac,0x67283610,0x14a40574,0x00000000}},	//   _פונע, mmej, _कोकण, --, 
   {{0x75280408,0x67283611,0x64a43612,0x00000000}},	//   cmdz, lmej, _хака, --, 
   {{0x3d140054,0x7ce03613,0x23280108,0x00000000}},	//   qäwi_, _hörg, _локи_, --, 
   {{0x31783614,0x9fe404c5,0x7ce03615,0x67283616}},	//   busz_, _খুউব_, _körg, nmej, 
   {{0x5d683617,0x7ce03618,0x672800c5,0x2540001f}},	// [3360] сизм_, _jörg, imej, _ከነበሩ, 
   {{0x7ce0008c,0x67280455,0x20541171,0x00000000}},	//   _mörg, hmej, _этир, --, 
   {{0x6f0c0f71,0x2fc43619,0xbaa4059f,0x6728010e}},	//   boac, ølgt_, дулқ, kmej, 
   {{0x6f0c361a,0x0a4802d3,0x672815ad,0x61e00153}},	//   coac, _ዝበልካ, jmej, _žoly, 
   {{0x6728003e,0x7ce011a1,0x00000000,0x00000000}},	//   dmej, _nörg, --, --, 
   {{0x672801f4,0xe80c00cd,0x00000000,0x00000000}},	//   emej, _ṣaṭp, --, --, 
   {{0xb8f4361b,0x9868016c,0x272001f1,0xddc400ee}},	//   _हक_, _ҳизб_, zóne_, _yekş, 
   {{0x35b4361c,0x2b540214,0x00000000,0x00000000}},	//   дбир, _آیند_, --, --, 
   {{0x1868361d,0x09e001b9,0x00000000,0x00000000}},	//   _гази_, _зотн, --, --, 
   {{0x320409a5,0x89d80375,0x6f0c01f7,0x8880361e}},	//   şlyk_, _החמי, zoac, _плуж, 
   {{0x6f0c361f,0x6b8001e3,0xf4980066,0x00000000}},	//   yoac, _älgt, مپکت_, --, 
   {{0x7ce001e6,0x27940116,0xf8b000ec,0x31780c57}},	//   _förg, _юшур, _سکڻ_, tusz_, 
   {{0x7ce03620,0x6f0c0276,0xdb0c3621,0xc3c000f7}},	//   _görg, voac, _arbë, дөөл, 
   {{0x21280998,0x33580262,0x634000ef,0x272000d7}},	//   gmbh_, _дакэ_, _gēno, róne_, 
   {{0x7ce00624,0x0f180597,0x800400cf,0x272000e4}},	//   _mörd, مغرب_, ечте, sóne_, 
   {{0x59bc3622,0x7ce03623,0x705405d9,0xadd83624}},	//   ्हार, _lörd, _ڪندا, омбу_, 
   {{0x6040007f,0x2d5400d7,0x00000000,0x00000000}},	// [3370] fňmč, _ožeň_, --, --, 
   {{0x67283625,0x270402b5,0x00000000,0x00000000}},	//   zmej, mēne_, --, --, 
   {{0x6f0c01f7,0xc4d008a8,0x704402dd,0x67283626}},	//   poac, עגע_, _ىرگە, ymej, 
   {{0x386c3627,0x316801e4,0x6728007c,0x00000000}},	//   _addr_, _kvaz_, xmej, --, 
   {{0x7ce026bc,0x67283628,0xa9680114,0x00000000}},	//   _börd, vmej, цила_, --, 
   {{0x78640058,0x7ff43629,0x6b74362a,0x00000000}},	//   ىدىك, _آسیا, _олгу, --, 
   {{0x2d88362b,0x7ce0362c,0xdc5401d9,0xb8641176}},	//   ltae_, _dörd, _ترُک, راوو, 
   {{0x31680311,0x6728362d,0x2d88003a,0x7ce000e5}},	//   _ovaz_, umej, otae_, _pörg, 
   {{0x7ce0362e,0x06cc045e,0x2d88362f,0x2a6c0798}},	//   _förd, িফলি, ntae_, _ideb_, 
   {{0x386c02fa,0x7ce03630,0x2d88003a,0x6b8001e3}},	//   _gddr_, _görd, itae_, _älgs, 
   {{0xf7703631,0x31683632,0xe2983633,0x6728014f}},	//   _مان_, _avaz_, оан_, pmej, 
   {{0x25a807f5,0x7ce0013d,0x00000000,0x00000000}},	//   _šalu_, _törg, --, --, 
   {{0x7ce03634,0xd1dc0023,0x00000000,0x00000000}},	//   _höre, _ሓፍቱ_, --, --, 
   {{0x7ce03635,0x25ac00fe,0x3a200022,0x00000000}},	//   _köre, mvel_, ýipi_, --, 
   {{0x25ac3636,0x3168022e,0x2d880393,0x942001af}},	//   lvel_, _evaz_, etae_, _имше, 
   {{0x3f6800ac,0x2a6c01e4,0x2128002f,0xb7bc00de}},	//   rğu_, _ndeb_, smbh_, _uzģe, 
   {{0x1cb00003,0x31680007,0x25ac0489,0x2d880280}},	// [3380] _ཐོད_, _gvaz_, nvel_, gtae_, 
   {{0x25ac3637,0x00000000,0x00000000,0x00000000}},	//   ivel_, --, --, --, 
   {{0x1b3c206f,0xdee4036b,0x26dc2f99,0x7ce00267}},	//   _ፖለቲካ, _жони, _olwo_, _rörd, 
   {{0x3dc00227,0x7ce0013d,0x25ac000d,0x00000000}},	//   pxiw_, _sörd, kvel_, --, 
   {{0xd00c0d6d,0x7e643638,0x2d880483,0x25ac01f5}},	//   _ملی_, maip, ctae_, jvel_, 
   {{0x61e00209,0x7ce03639,0x2a6c2d7c,0x7e64363a}},	//   _ýolu, _böre, _edeb_, laip, 
   {{0x25ac363b,0x7ce0007c,0x7608036e,0x69dc013d}},	//   evel_, _vörd, këzë, _üsen, 
   {{0x7e643209,0x7ce0363c,0xda64363d,0xda140037}},	//   naip, _döre, _زاري, _तडपत_, 
   {{0xe97016a0,0xd49835f2,0x7ce0363e,0x7e6402b5}},	//   _مۇند, орн_, _törd, iaip, 
   {{0x7ce0363f,0x7e64035b,0x00000000,0x00000000}},	//   _före, haip, --, --, 
   {{0x1cb00c99,0x7ce03640,0x7e640e8a,0xdb0c0036}},	//   _ཐོན_, _göre, kaip, _arbé, 
   {{0x7e643641,0xeb9000c8,0x7ce00254,0x2d88003a}},	//   jaip, אָך_, _jörb, ytae_, 
   {{0x7ce001e3,0x2d880381,0x78a800b8,0x7e641e0b}},	//   _mörb, xtae_, _kadv, daip, 
   {{0x7ce03642,0x78a8036b,0x301403a6,0xc0cc0092}},	//   _yöre, _jadv, едгр, _ቢቀር_, 
   {{0x78a83643,0x7e641140,0xa2a83644,0x4ea401c6}},	//   _madv, faip, _जोक्, мраа, 
   {{0x78a83645,0x60dc02d0,0x2d880381,0x7e6400c7}},	//   _ladv, _elpm, ttae_, gaip, 
   {{0x78a80156,0x272001e7,0x00000000,0x00000000}},	// [3390] _oadv, nóna_, --, --, 
   {{0x2d881730,0x78a83646,0x00000000,0x00000000}},	//   rtae_, _nadv, --, --, 
   {{0x2d881730,0x7ce00166,0x00000000,0x00000000}},	//   stae_, _börb, --, --, 
   {{0x7ce0049f,0x2d881730,0x00000000,0x00000000}},	//   _röre, ptae_, --, --, 
   {{0x78a83647,0x7ce03648,0x672c01f1,0x27200008}},	//   _badv, _söre, ňajk, jóna_, 
   {{0xe7383649,0xfd6402e3,0xad240c50,0x78a80051}},	//   пек_, harị, _سىزى, _cadv, 
   {{0x7ce00628,0xfd640521,0x78a80010,0xca740116}},	//   _förb, karị, _dadv, _يارغ, 
   {{0x6d5c05b1,0x78a8017a,0x7ce000e5,0x25ac364a}},	//   _kwsa, _eadv, _görb, tvel_, 
   {{0x25ac364b,0x27200332,0x45a000d1,0x00000000}},	//   uvel_, góna_, ئەتك, --, 
   {{0x7ce0364c,0x25ac364d,0x6aa80270,0x78a801f5}},	//   _töre, rvel_, _haef, _gadv, 
   {{0x66d401e1,0x6e3c0857,0x6aa8002f,0xdb1c0022}},	//   _láki, _ogsb, _kaef, hypý, 
   {{0x78a801a6,0x6e3c0112,0x25ac0af9,0x61e40112}},	//   _zadv, _ngsb, pvel_, tzkl, 
   {{0xa4d410f5,0x61e405c7,0x78a800dc,0x00000000}},	//   _поді, uzkl, _yadv, --, 
   {{0x7e64364e,0x6e3c035a,0x255c007f,0x68ec01ab}},	//   waip, _agsb, mňl_, èadh, 
   {{0x6568364f,0xfd64063f,0x6d5c3650,0xfe7800f7}},	//   lseh, barị, _awsa, мүн_, 
   {{0xe3d800c7,0xe1f02e0b,0x00000000,0x00000000}},	//   _мықә_, _مسخ_, --, --, 
   {{0x7e643651,0x1d242f34,0x7ce0007c,0x00000000}},	// [33a0] raip, емам, _rörb, --, 
   {{0x7e643652,0x6e3c02d0,0x67380327,0x7ce03653}},	//   saip, _egsb, _liwj, _sörb, 
   {{0x6aa83654,0x7e643655,0x27203656,0x78a80006}},	//   _baef, paip, zóna_, _radv, 
   {{0x6aa83657,0x65683658,0x1cb0031c,0x6fcc012c}},	//   _caef, kseh, _ཐོམ_, सहरू, 
   {{0x78a83659,0x3940003a,0x6568365a,0x2018365b}},	//   _padv, êis_, jseh, _hypi_, 
   {{0x97a4365c,0x78a8047e,0x255c007f,0x3d1800c5}},	//   ерил, _qadv, dňl_, _बीचे_, 
   {{0x5a9402d5,0x6b80007c,0x7ce0013d,0x00000000}},	//   _праф, _älgp, _törb, --, 
   {{0x6568365d,0x753804cc,0x8c18011a,0x91b0012d}},	//   fseh, _sivz, _זולי, इटमै, 
   {{0x7ce0365e,0x78a80882,0x7ae0000d,0x20180200}},	//   _görc, _tadv, _ilmt, _lypi_, 
   {{0x186800fb,0xd36c00d1,0x73d8365f,0x00000000}},	//   _хажи_, مۇت_, ддор_, --, 
   {{0x6aa80099,0xfd6401f2,0x201801f4,0x97b401a9}},	//   _yaef, tarị, _nypi_, _ясаш, 
   {{0x1db00490,0xf7700133,0x55e417a0,0x272000e4}},	//   ीमात, _ماچ_, _поеб, póna_, 
   {{0x20180309,0x914800d4,0xa2d00118,0x00000000}},	//   _aypi_, ячна_, _डकर्, --, 
   {{0x21380477,0x66d40174,0xc0c83660,0x00000000}},	//   _ciph_, _ráki, нусе_, --, 
   {{0x21381a83,0xfd640521,0x7f943661,0x03a006ed}},	//   _diph_, parị, ларх, _бијо, 
   {{0x66d40118,0xd24c00ec,0x5bf803d4,0xc6100154}},	//   _páki, _ھنڌ_, _অৰ্গ_, াইরা_, 
   {{0xd24c0451,0x1048005b,0x28d0000d,0xf5480051}},	// [33b0] _پنڌ_, _няни_, _तकलि, _dụg_, 
   {{0x6aa83662,0x320803ac,0x7ae001e3,0xe7f000c5}},	//   _saef, _ixay_, _almt, _अइला_, 
   {{0x6aa80810,0xf1c80131,0x00000000,0x00000000}},	//   _paef, _روھى_, --, --, 
   {{0xa8000086,0x6568011f,0x7b7425ef,0x6e3c03ac}},	//   _àñid, yseh, اطلا, _ugsb, 
   {{0xa9a43663,0x6aa83664,0x7bc80de2,0xbea40153}},	//   тилд, _vaef, _àdun, _саўк, 
   {{0x2d983665,0x6aa83666,0x66d40008,0x67380113}},	//   _ipse_, _waef, _jákv, _siwj, 
   {{0x6aa803a0,0x66e43667,0xdb0c0419,0x27e80115}},	//   _taef, кока, ždác, ĝano_, 
   {{0x65683668,0xd6cc0131,0x320802d0,0x27e801e4}},	//   tseh, ققى_, _oxay_, ŝano_, 
   {{0x6934035b,0xd6cc00c6,0x7ce00267,0x65680108}},	//   _анау, تقي_, _höra, useh, 
   {{0x634000b0,0x65680730,0x66d40008,0x7b2c0311}},	//   _hēni, rseh, _nákv, _uşur, 
   {{0xe6943669,0x6568366a,0x2d98020b,0x6d8801e4}},	//   _للاد, sseh, _lpse_, _gɾav, 
   {{0x6144366b,0x656800c5,0x6d58063f,0x2168366c}},	//   кема, pseh, ̣waa, мими_, 
   {{0x64a4366d,0x33280014,0x290002b5,0x6568366e}},	//   _аала, _dhax_, ōhau_, qseh, 
   {{0x2480366f,0x634000ef,0x00000000,0x00000000}},	//   _øhm_, _lēni, --, --, 
   {{0x6d4006c8,0x7ce00205,0x00000000,0x00000000}},	//   _ōlap, _nöra, --, --, 
   {{0x33280003,0x00000000,0x00000000,0x00000000}},	//   _ghax_, --, --, --, 
   {{0x62940796,0xbedc01e1,0x213804cc,0x68e03670}},	// [33c0] _ibyo, _aṣàw, _tiph_, _olld, 
   {{0x20180393,0x4e2400c0,0x00000000,0x00000000}},	//   _typi_, тоун_, --, --, 
   {{0x200c025a,0x20180113,0x5f043671,0x66d40174}},	//   _âfi_, _uypi_, _азна, _háku, 
   {{0x68e03672,0x29043673,0x7ce0010e,0xa6e0032e}},	//   _alld, _ajla_, _döra, _áðhe, 
   {{0x66d40579,0x629404ba,0x3ea03674,0x00000000}},	//   _jáku, _mbyo, meit_, --, 
   {{0x3ea03675,0x7ce0049f,0xdb1c3676,0x66d40113}},	//   leit_, _föra, typó, _máku, 
   {{0x7ce0049f,0x62940d64,0x9b340124,0x63400171}},	//   _göra, _obyo, _ахаш, _fēni, 
   {{0x81e803f4,0xeb0c0cb3,0x3ea03677,0x68e00857}},	//   _যখন_, िकृत_, neit_, _elld, 
   {{0xd9443678,0x66d403c6,0x18a40022,0x3ea0062c}},	//   _рези, _náku, _иаам, ieit_, 
   {{0x3ea03679,0x62941418,0x70d0367a,0x394400e4}},	//   heit_, _abyo, _सकेल, _iums_, 
   {{0x3ea0367b,0x62940083,0x3944367c,0xccf00375}},	//   keit_, _bbyo, _hums_, שכת_, 
   {{0xc2b80212,0x3ea0367d,0x00000000,0x00000000}},	//   влює_, jeit_, --, --, 
   {{0x3944367e,0x3ea0367f,0x316c20ef,0x5504036b}},	//   _jums_, deit_, éez_, _ичка, 
   {{0x3944367e,0xab643680,0x62942f99,0x104800c9}},	//   _mums_, ngüí, _ebyo, ьями_, 
   {{0x39443681,0x33941ee3,0xdb0c00d8,0x32080009}},	//   _lums_, _сайё, _arbí, _wxay_, 
   {{0x3ea03682,0x7ce03683,0x66d40a87,0x02c40073}},	//   geit_, _röra, _fáku, षाणभ, 
   {{0x39443684,0xadb400f7,0x02d80014,0x320802d0}},	// [33d0] _nums_, ыбаш, _شوٝب_, _uxay_, 
   {{0x63400093,0x3d940117,0x00000000,0x00000000}},	//   _sēni, рифр, --, --, 
   {{0x3ea03685,0x66d40122,0x4fc400c7,0x00000000}},	//   beit_, _záku, _рспа, --, 
   {{0x3ea01caa,0xeb0c0490,0x7b180077,0x39440171}},	//   ceit_, िकेत_, díus, _bums_, 
   {{0x3944045a,0xc98400c7,0x00000000,0x00000000}},	//   _cums_, туеи, --, --, 
   {{0x7ce03686,0x69240209,0x29180171,0x00000000}},	//   _hörn, ымла, _īsas_, --, 
   {{0x7ce0066d,0x8aa42f8d,0x634000b0,0x2918139f}},	//   _körn, _ирад, _tēni, _ūsas_, 
   {{0xbb840491,0x394400db,0xf96403e6,0x7ce001e3}},	//   _خلفي, _fums_, _چۆنێ, _jörn, 
   {{0x888000dd,0x3944045a,0x7ce0007c,0xc4443687}},	//   _نیشن, _gums_, _mörn, نیشن_, 
   {{0x3ea00639,0x68e03688,0xe35400ee,0x66d408ce}},	//   zeit_, _ulld, лтмэ, _ráku, 
   {{0x69d83689,0x7b180077,0x3ea001d3,0xa0a40116}},	//   lywe, cíus, yeit_, ңамд, 
   {{0xdb94011a,0x49180118,0x00000000,0x00000000}},	//   נדרט_, यतको_, --, --, 
   {{0x69d8017c,0x3ea0368a,0x80a80154,0x00000000}},	//   nywe, veit_, খাস্, --, 
   {{0x3ea0368b,0x66d4368c,0x30740022,0x00000000}},	//   weit_, _váku, иусс, --, 
   {{0x3ea0368d,0xdee4368e,0x7ce0008c,0xba2003f3}},	//   teit_, гови, _börn, _बर्फ_, 
   {{0x629400ca,0x66d40784,0x4424263e,0x934000fd}},	//   _ubyo, _táku, _izn_, _унъе, 
   {{0x3ea0368f,0x9d440f47,0x7ce03690,0xd12c00e5}},	// [33e0] reit_, ائرن, _dörn, زمہ_, 
   {{0x3ea03691,0x69d83692,0x44243693,0xa0a40fc0}},	//   seit_, dywe, _kzn_, _саод, 
   {{0x3ea03694,0x7ce0049f,0x9f043695,0xf00001c6}},	//   peit_, _förn, _مودو, _дүри, 
   {{0x62843696,0x7ce009a5,0xd9443697,0x4424009f}},	//   ngko, _görn, геди, _mzn_, 
   {{0xf54801dc,0xceb00bd9,0x442401fa,0x69d80368}},	//   _mục_, _פיש_, _lzn_, gywe, 
   {{0x8c4009a5,0xf5480016,0x44243698,0x7b180077}},	//   _гере, _lục_, _ozn_, tíus, 
   {{0x44240024,0x69d83699,0x00000000,0x00000000}},	//   _nzn_, aywe, --, --, 
   {{0xa3c800ab,0x3944369a,0x2a940092,0x7ce00bbc}},	//   ोहन_, _tums_, _ማሽኖች_, _köro, 
   {{0x44240cc1,0x69d8369b,0x59080798,0x00000000}},	//   _azn_, cywe, _зеам_, --, 
   {{0x6d58063f,0x6284017a,0x44240356,0x00000000}},	//   ̣wao, egko, _bzn_, --, 
   {{0x73c4151e,0xf548004d,0x329c0150,0x893000e5}},	//   рәле, _bục_, _ﺁﻤﻭﺱ_, _اٹلا, 
   {{0xf5480016,0x5184369c,0x6284369d,0x4424369e}},	//   _cục_, луга, ggko, _dzn_, 
   {{0xf54807ae,0x7ce00790,0x41e402d5,0x8500369f}},	//   _dục_, _nöro, біра, _گوون, 
   {{0x66d402d2,0xf4340137,0x7ce002fc,0x0cbc0154}},	//   _fáks, _келэ, _sörn, _ইত্ত, 
   {{0xc4f4008d,0xb4b40184,0x85000133,0x69d8012d}},	//   _תמוז_, _биҙә, _دوون, zywe, 
   {{0x4ea436a0,0xf54801fb,0x00000000,0x00000000}},	//   ырга, _gục_, --, --, 
   {{0x705427ba,0x7bd80579,0x7ce008a5,0x00000000}},	// [33f0] _پنجا, øvun, _vörn, --, 
   {{0xeb0c1ab2,0x69d836a1,0x7ce0002f,0x4ba400db}},	//   िक्त_, vywe, _wörn, лөбү_, 
   {{0x6e9436a2,0x7ce00fe7,0xf1a808e6,0x3d9401d5}},	//   _кину, _törn, _चैतन, _қирр, 
   {{0x7ce001e6,0x69d836a3,0xf5480051,0x00000000}},	//   _föro, tywe, _xục_, --, 
   {{0x693436a4,0x7ce00209,0x80a800eb,0x00000000}},	//   анду, _göro, খার্, --, 
   {{0xd364118c,0x69d80591,0xc86436a5,0x8ce02309}},	//   _وه_, rywe, утди, _اقسۇ, 
   {{0x62840af9,0x8464010b,0x00000000,0x00000000}},	//   ygko, ңзиң_, --, --, 
   {{0x44240564,0x2b4c00bc,0x3f8c025c,0x00000000}},	//   _rzn_, _čech_, ħdux_, --, 
   {{0xc9841b88,0xf5480208,0x77900014,0x272000e5}},	//   _љуби, _rục_, _ہیوا, lónk_, 
   {{0xf548004d,0x44240112,0x00000000,0x00000000}},	//   _sục_, _pzn_, --, --, 
   {{0xe2b8025c,0x240801d5,0xdb0c01ef,0x00000000}},	//   _བོདཀ, тнни_, _hrbá, --, 
   {{0x659436a6,0x442436a7,0x00000000,0x00000000}},	//   _ваду, _vzn_, --, --, 
   {{0x628436a8,0x2ee836a9,0x78c401ed,0x7ce00139}},	//   rgko, dhaf_, _átvé, _börl, 
   {{0x442436aa,0x2934010f,0x81c40022,0x7ce001e3}},	//   _tzn_, יאָן_, _ҳаиҧ, _röro, 
   {{0xf54807ae,0xa2e402f6,0x201c066a,0x7ce00166}},	//   _tục_, _войд, æti_, _dörl, 
   {{0xdb0c36ab,0x66d40122,0xdd9036ac,0x53980375}},	//   _orbá, _zákr, يوز_, _ייצו, 
  
   {{0x7ce004f3,0x5d6836ad,0xdcf40024,0xddc40171}},	// [3400] _förl, тизм_, sryč, _iekū, 
   {{0x7ce036ae,0xccc00a8f,0x7bc801e1,0x3d10012d}},	//   _görl, обуй, _àduk, ़कें_, 
   {{0x999802b5,0x644c00fd,0x9078011a,0x00000000}},	//   āpō_, _ğail, _בטיי, --, 
   {{0x2ee836af,0xf54801fb,0x918001fb,0x634002b5}},	//   chaf_, _lụa_, _hết_, _uēnu, 
   {{0x26cc05a1,0x7ce036b0,0x918001fb,0x19f410f3}},	//   djeo_, _hörm, _kết_, јџер, 
   {{0x7df80166,0x7ce001d3,0x1d0836b1,0xdb0c01ef}},	//   _eşsö, _körm, _реги_, _drbá, 
   {{0xcb640a5b,0x06ac0011,0xd69c0150,0x4c98011a}},	//   _васе_, কানি, _ﺃﻤﻭﺭ_, _שבלו, 
   {{0xfd4c0055,0xddc400e2,0x00000000,0x00000000}},	//   _baiḍ, _nekū, --, --, 
   {{0x09e001c0,0xd87400db,0x764400c7,0x92640101}},	//   _дотн, _نااب, аҭҵа, یدحم, 
   {{0x0d940375,0x6f0804a7,0xd90c0753,0xf5480051}},	//   סכים_, čeci, _تیت_, _cụa_, 
   {{0x34941b74,0x7ce001e6,0xf5480208,0x73380454}},	//   _ғайр, _rörl, _dụa_, лзор_, 
   {{0x96b82c10,0xb2a801d9,0x7ce036b2,0x00000000}},	//   _جائز_, چُھم_, _sörl, --, 
   {{0x73c40184,0x7d1c02fb,0xd20801c6,0x35540035}},	//   рәһе, _okrs, тэнд_, _انتز, 
   {{0x3d100034,0x7ce0010e,0x06040166,0x53440408}},	//   ़कों_, _börm, _әнәк_, _кхиа, 
   {{0x2ee80cfd,0xa3c81152,0x00000000,0x00000000}},	//   thaf_, ोहण_, --, --, 
   {{0x2fcc04b9,0x3ec4004e,0x59c40b67,0x00000000}},	//   ćeg_, осуб, लमार, --, 
   {{0x7ce036b3,0xad241ee2,0x00000000,0x00000000}},	// [3410] _törl, مىرى, --, --, 
   {{0x7ce004f3,0xfd1036b4,0x814407d6,0x272000e5}},	//   _förm, وجل_, _گنین, tónk_, 
   {{0x7ce036b5,0x013400c6,0x2ee801a8,0xec14007b}},	//   _görm, _بعيد, phaf_, حواد, 
   {{0xbf1401af,0x00000000,0x00000000,0x00000000}},	//   _дүсә, --, --, --, 
   {{0x26cc01fa,0x06ac0154,0x272000e5,0x56380092}},	//   vjeo_, কামি, sónk_, _የኢዴአ, 
   {{0xac1836b6,0x97000075,0x6ce401d9,0x6d4c058a}},	//   _богу_, ۋېلى, _آسن, mqaa, 
   {{0x6d4c36b7,0x7ce00724,0x26cc052f,0xf548063f}},	//   lqaa, _xörm, tjeo_, _rụa_, 
   {{0x6d4c0140,0x06ac00fe,0xe9440214,0xba74007b}},	//   oqaa, কাভি, _هنرپ, _واقت, 
   {{0x6d4c36b8,0xfcd80020,0x25b836b9,0x00000000}},	//   nqaa, _ኮሌጅ_, ísl_, --, 
   {{0x201c014a,0x26cc1710,0x6d4c0067,0xfd4c00cd}},	//   ütik_, sjeo_, iqaa, _vaiḍ, 
   {{0x7ce00628,0xe7b436ba,0x02c82f0d,0xc1d00882}},	//   _börj, _دماد, иқки_, सङ्ग, 
   {{0x6340003a,0xc17800d1,0x7ce001e3,0x27200124}},	//   _cœna, аҗи_, _rörm, kóni_, 
   {{0x7ce036bb,0xe5b4010b,0x6b840112,0x5edc00eb}},	//   _sörm, _ыйды, huhg, নোডে, 
   {{0x314036bc,0x6d4c0014,0x7ce000e4,0x356800ee}},	//   _ዩኒቨር, dqaa, _pörm, _өрән_, 
   {{0xa35424cc,0x6d4c0194,0xe8f40208,0x7ce001e3}},	//   _اختص, eqaa, _đức_, _förj, 
   {{0xc214016b,0x630436bd,0xf548001e,0x6d4c022f}},	//   _adɔe_, _دوبل, _mụn_, fqaa, 
   {{0xe0d802e8,0x91800208,0x00000000,0x00000000}},	// [3420] _бвп_, _tết_, --, --, 
   {{0x7ce036be,0x6f1c00c8,0x00000000,0x00000000}},	//   _törm, _eksc, --, --, 
   {{0x6d4c20ac,0x7d1c01a6,0xa3c81a04,0xae480014}},	//   aqaa, _vkrs, ोहि_, اشہٕ_, 
   {{0x7ce036bf,0x6d4c0067,0x8f980a7c,0x0c34007b}},	//   _körk, bqaa, _גיטי, حكمة_, 
   {{0x19940114,0x00000000,0x00000000,0x00000000}},	//   сјер, --, --, --, 
   {{0x7ce036c0,0x7d1c3421,0x00000000,0x00000000}},	//   _mörk, _ukrs, --, --, 
   {{0x779436c1,0x00000000,0x00000000,0x00000000}},	//   تیضا, --, --, --, 
   {{0xf1042765,0x00000000,0x00000000,0x00000000}},	//   _रद्द_, --, --, --, 
   {{0xceb00302,0x2cb00198,0x7ce00139,0x487000db}},	//   ליה_, _yazd_, _nörk, زگەس, 
   {{0x7ce00267,0xd4c40354,0x34b40066,0x00000000}},	//   _sörj, ссип, آمدز, --, 
   {{0x3cf00034,0xecc801ad,0x4c98010f,0x00000000}},	//   _इतने_, रातफ, נשטע, --, 
   {{0x6340003a,0x7ce036c2,0x87e400cf,0x6d4c0009}},	//   _pœna, _börk, _اتكە, yqaa, 
   {{0x41e40111,0x6d4c058a,0x955c0092,0x00000000}},	//   піра, xqaa, ተቶችን_, --, 
   {{0x73c401ec,0x00000000,0x00000000,0x00000000}},	//   _дәме, --, --, --, 
   {{0xb4e436c3,0x60d801e3,0x00000000,0x00000000}},	//   नसी_, ötma, --, --, 
   {{0x7ce036c4,0x6d4c0357,0x00000000,0x00000000}},	//   _förk, tqaa, --, --, 
   {{0x7ce036c5,0x7044021f,0x6d4c0009,0x2be0190c}},	// [3430] _görk, _وردە, uqaa, पन्थ, 
   {{0x6d4c36c6,0x63ac00c7,0x260836c7,0x2bac01f9}},	//   rqaa, _ņani, ापती_, _घनदा, 
   {{0xfb8436c8,0x6d4c0067,0x93080154,0x2ef803e0}},	//   зычн, sqaa, রতীপ_, _tmsf_, 
   {{0xb4e400c5,0x6b8401d5,0x61e00210,0x00000000}},	//   नसु_, ruhg, _żoli, --, 
   {{0x6844006c,0x6d4c36c9,0xf548004d,0xed5001f7}},	//   онла, qqaa, _sụn_, _آھر_, 
   {{0x6d8c001f,0xb328031c,0x17140327,0x634000ef}},	//   _ዕርዳታ_, _ལེའང_, ྲོའམ_, _lēnp, 
   {{0xa6c836ca,0x270400e2,0x7b64004e,0xfa540023}},	//   илка_, lēni_, _нтте, ምስምማ, 
   {{0xe57836cb,0xf548004d,0x09c00154,0x00000000}},	//   ази_, _vụn_, ্নবা, --, 
   {{0x24e8013e,0xfaa40014,0x00000000,0x00000000}},	//   имии_, _عجٲی, --, --, 
   {{0xdb0c0d16,0x7ce0007c,0x00000000,0x00000000}},	//   _erbä, _rörk, --, --, 
   {{0x270400b0,0xe3b000f2,0x00000000,0x00000000}},	//   hēni_, ذرد_, --, --, 
   {{0x48f0012c,0x383401c6,0xc8c40456,0x49540023}},	//   ्चको_, _энхр, लावट, _ዝተቐብ, 
   {{0x7ce004f3,0x25a80395,0xb7141e24,0x1a98008f}},	//   _förh, _èal_, _عظمت, סישע, 
   {{0x1ea80451,0x00000000,0x00000000,0x00000000}},	//   ڌاري_, --, --, --, 
   {{0x23282dbf,0x504036cc,0x5ef836cd,0x00000000}},	//   _коки_, дерб, ахар_, --, 
   {{0x7ce01248,0xa2e4013e,0x25a80064,0x9e6436ce}},	//   _törk, _фоид, _šaly_, تاسن, 
   {{0x163400c8,0xef90030f,0x7ce0002f,0x73c400f7}},	// [3440] ַנער_, ویید, _höri, _ويۇم, 
   {{0xd83c0122,0x9c5836cf,0x00000000,0x00000000}},	//   íčka_, ршау_, --, --, 
   {{0x5ba836d0,0x7ce004cc,0x272036d1,0x00000000}},	//   ркем_, _jöri, lónu_, --, 
   {{0xec3413f9,0x613000b5,0x3f6805d1,0x00000000}},	//   سونگ, fælg, mşu_, --, 
   {{0x2eb40a89,0x27040171,0x00000000,0x00000000}},	//   _эсэс, cēni_, --, --, 
   {{0x91b800d9,0x00000000,0x00000000,0x00000000}},	//   ימני, --, --, --, 
   {{0x3f680213,0x2b540214,0xdce40166,0x613003b2}},	//   nşu_, _فیلد_, _upkı, mæld, 
   {{0x4730004b,0xeb300137,0x27200419,0x2bf800cd}},	//   وريز, _كۉلد, kónu_, ्परं_, 
   {{0x7ce001f4,0x00000000,0x00000000,0x00000000}},	//   _pörh, --, --, --, 
   {{0x4494023a,0x7ce0010e,0xb4e436d2,0xd36c03cc}},	//   овью_, _böri, नसे_, نۇت_, 
   {{0xd6d8034c,0xb6cc3535,0xdebc001f,0xe7bc1fad}},	//   _پوشش_, çüsü, ዱሳን_, ्मणप, 
   {{0x27200030,0x7ce036d3,0xd5b80108,0x00000000}},	//   fónu_, _döri, _вск_, --, 
   {{0xc0e8001f,0xf55401c0,0x272002f0,0x61300388}},	//   _ዛሬም_, _эвлэ, gónu_, kæld, 
   {{0x3a2436d4,0x7ce036d5,0x6130005c,0x00000000}},	//   _mymp_, _föri, jæld, --, 
   {{0x7ce036d6,0xdcdc022e,0x386c015d,0xcf3800ae}},	//   _göri, _a築o_, _medr_, لأرض_, 
   {{0xa3c80c4c,0x775036d7,0x403436d8,0x386c0042}},	//   ोहर_, _ሚኒስተ, фесс, _ledr_, 
   {{0x3d94189d,0x7c30013f,0x613000b5,0x00000000}},	// [3450] митр, ɑkrɑ, fæld, --, 
   {{0x6130037e,0xd69c02dd,0x7ce036d9,0x50a000d1}},	//   gæld, _ﺃﻤﻴﺭ_, _yöri, _تەسل, 
   {{0x3f680356,0x00000000,0x00000000,0x00000000}},	//   cşu_, --, --, --, 
   {{0x3168030a,0x704402dd,0x660c032e,0x00000000}},	//   _kwaz_, _ورگە, _þakg, --, 
   {{0x386c05be,0xf5480051,0x0dc836da,0x00000000}},	//   _bedr_, _bụm_, _туни_, --, 
   {{0xe73807dd,0xf548001e,0x386c01ef,0x786400d1}},	//   әеи_, _cụm_, _cedr_, ودىك, 
   {{0x98a000d6,0x27200122,0x613000b5,0x2d880381}},	//   хище, zónu_, sælg, luae_, 
   {{0x7ce036d5,0x31680432,0x6130005c,0x00000000}},	//   _röri, _owaz_, mæle, --, 
   {{0x386c36db,0x2d8836dc,0xe5a400a8,0x00000000}},	//   _fedr_, nuae_, чипи, --, 
   {{0x386c0793,0xb6cc00ac,0x2a6c0009,0x391436dd}},	//   _gedr_, çürü, _heeb_, _жмур, 
   {{0x2a6c0070,0x3168008e,0x2d8800d8,0xe2c80ccb}},	//   _keeb_, _awaz_, huae_, مودو_, 
   {{0xe2981c50,0x27200030,0x2a6c058a,0x7ce0032e}},	//   щам_, tónu_, _jeeb_, _vöri, 
   {{0x2a6c0218,0x6130003b,0x7ce0002f,0x00000000}},	//   _meeb_, hæle, _wöri, --, 
   {{0x2a6c36de,0x25ac36df,0x55b80375,0x2d880381}},	//   _leeb_, mwel_, _למנו, duae_, 
   {{0xe0141715,0xa0680046,0x613036e0,0xe35436e1}},	//   _दुखद_, _қана_, jæle, _этлэ, 
   {{0x2a6c0070,0x272036e2,0xd00400fd,0x2d880083}},	//   _neeb_, móns_, чесе_, fuae_, 
   {{0x25ac36e3,0x31680489,0x272036e4,0x2d880381}},	// [3460] nwel_, _gwaz_, lóns_, guae_, 
   {{0xe7bc07b7,0x25ac0d49,0xddd400a2,0x00000000}},	//   ्माप, iwel_, mgyż, --, 
   {{0x6130019b,0x2704005f,0x2720056a,0x3a24045a}},	//   ræld, lēnu_, nóns_, _symp_, 
   {{0x2a6c0190,0x3f981028,0x2d88016b,0x25ac017a}},	//   _ceeb_, mtru_, buae_, kwel_, 
   {{0x3f9836e5,0x7e640588,0x25ac0cf9,0x2a6c36e6}},	//   ltru_, mbip, jwel_, _deeb_, 
   {{0x7e640477,0xcb0400d1,0x00000000,0x00000000}},	//   lbip, ييەن_, --, --, 
   {{0x3f9828cf,0x2a6c0070,0x4870082a,0x386c1fcd}},	//   ntru_, _feeb_, ردوس, _vedr_, 
   {{0x27200005,0xa2ac0154,0x8c400798,0x2918032e}},	//   dóns_, গাঁও, _чесе, _ísan_, 
   {{0x3a240175,0x994836e7,0xba140055,0xf5480208}},	//   _uymp_, _طلال_, _koḍī, _tụm_, 
   {{0x2a6c0140,0x27200077,0x00000000,0x00000000}},	//   _zeeb_, fóns_, --, --, 
   {{0x7ce00628,0x2a6c0457,0x2720056a,0x80d000cd}},	//   _förv, _yeeb_, góns_, दाने, 
   {{0x2a6c0190,0xdb0c00cf,0xc82402d3,0xf02c001f}},	//   _xeeb_, _arbú, _ስንኩላ, _ተስማም, 
   {{0x41c412c4,0x7ce0032e,0x45d0003b,0x00000000}},	//   нёра, _höru, _поїс, --, 
   {{0x27200005,0x7ce036e8,0x00000000,0x00000000}},	//   bóns_, _köru, --, --, 
   {{0xc10436e9,0x27200005,0x06ac015b,0x7ce008a5}},	//   روفي, cóns_, কারি, _jöru, 
   {{0x73340131,0x2d8816b8,0x00000000,0x00000000}},	//   _تىبا, tuae_, --, --, 
   {{0x9f480589,0xa4840150,0x2a6c0067,0x270400e2}},	// [3470] tzbã_, _ءجۇن, _reeb_, cēnu_, 
   {{0x2a6c01d4,0x237000d2,0x2d880381,0x00000000}},	//   _seeb_, _înjá_, ruae_, --, 
   {{0x2a6c0218,0x2d8836ea,0x3f980356,0xcf9806ed}},	//   _peeb_, suae_, ctru_, _ујп_, 
   {{0x2a6c36eb,0x2d8836ec,0xdfd000f1,0x25ac0042}},	//   _qeeb_, puae_, _شيټ_, ywel_, 
   {{0x272036ed,0x6f0c36ee,0x2d881730,0x2a6c34a6}},	//   zóns_, mnac, quae_, _veeb_, 
   {{0x6d5c36ef,0x2a6c208d,0x98a036f0,0x6f0c36f1}},	//   _itsa, _weeb_, више, lnac, 
   {{0x2a6c36f2,0x25ac36f3,0x6f0c36f4,0xd7540137}},	//   _teeb_, wwel_, onac, ولوت_, 
   {{0x657c01ed,0x752801a4,0x6f0c36f5,0x25ac01f5}},	//   ásho, eldz, nnac, twel_, 
   {{0x25ac0942,0x00000000,0x00000000,0x00000000}},	//   uwel_, --, --, --, 
   {{0x7ce036f6,0x25ac36f7,0x6f0c36f8,0x6d5c0bd7}},	//   _föru, rwel_, hnac, _mtsa, 
   {{0x6f0c36f9,0x7ce036fa,0xdb2000e4,0xb808007b}},	//   knac, _törv, _ñuãt, _فيكم_, 
   {{0x6d5c36fb,0x27201709,0x6f0c36fc,0x7ce03468}},	//   _otsa, róns_, jnac, _hört, 
   {{0x6d5c36fd,0x057436fe,0x672836ff,0x27200005}},	//   _ntsa, _راشد, mlej, sóns_, 
   {{0x67283700,0x3f983701,0x98bc02b5,0x6f0c3702}},	//   llej, ttru_, _kitā_, enac, 
   {{0x6d5c3703,0xe2983704,0x7ce03705,0x98bc00b8}},	//   _atsa, _дай_, _mört, _jitā_, 
   {{0x3f983706,0x7ce0000d,0x44243707,0x00000000}},	//   rtru_, _lört, _iyn_, --, 
   {{0x3f983708,0x44240f7b,0xb900025c,0x270400e2}},	// [3480] stru_, _hyn_, _སྭ_, lēns_, 
   {{0x3e6c01dc,0x6f0c3709,0x4424370a,0x67280122}},	//   ết_, anac, _kyn_, hlej, 
   {{0x6d5c370b,0x6728370c,0x60c001ab,0x6f0c00a3}},	//   _etsa, klej, _ėomh, bnac, 
   {{0x4424193f,0x82cc031c,0x6f0c370d,0x7ce002d2}},	//   _myn_, _ཆོསའ, cnac, _röru, 
   {{0x7ce0370e,0x4424370f,0x67283710,0x7528002d}},	//   _bört, _lyn_, dlej, yldz, 
   {{0x4424007f,0x672801bf,0x23dc3711,0x7ce0032e}},	//   _oyn_, elej, महाद, _pöru, 
   {{0x6728204e,0x442402a4,0x7ce03712,0x98bc005f}},	//   flej, _nyn_, _dört, _citā_, 
   {{0x7ce0008c,0x6728151c,0x6d5c0036,0x35b400d8}},	//   _vöru, glej, _ytsa, ебир, 
   {{0x7ce004f3,0x442402a4,0x94a82390,0x88c00882}},	//   _fört, _ayn_, отна_, āśra, 
   {{0x6f0c068f,0x4424369d,0x6728023a,0x7ce03713}},	//   znac, _byn_, alej, _gört, 
   {{0x6ef0019b,0x44240cfd,0x7ce03714,0x6f0c3715}},	//   _håbe, _cyn_, _hörs, ynac, 
   {{0x4424193f,0x2d4c0e3c,0x7ce03716,0x6728004e}},	//   _dyn_, _užeg_, _körs, clej, 
   {{0x4424039a,0x7ce00724,0x66d40306,0x91480024}},	//   _eyn_, _yört, _náky, ючна_, 
   {{0x34943717,0x44243718,0x210c0764,0x6ef000b5}},	//   _чакр, _fyn_, _सदृश_, _måbe, 
   {{0x442402a4,0x6f0c3719,0x7bd80267,0x7f940408}},	//   _gyn_, tnac, ävul, карх, 
   {{0x6f0c0810,0x69dc00d8,0x21280e89,0x00000000}},	//   unac, _àseg, albh_, --, 
   {{0x50640801,0x4424371a,0x8d740271,0x2184010a}},	// [3490] _отна, _zyn_, بازا, _пăтр, 
   {{0x6f0c371b,0xf548001e,0x656c0200,0xac1800db}},	//   snac, _bụi_, _çahe, позу_, 
   {{0x2fc00112,0x7ce0007c,0x67280108,0xf5480208}},	//   _urhg_, _rört, ylej, _cụi_, 
   {{0x7ce0371c,0x4ea407d6,0xf5480208,0x6130148b}},	//   _börs, _ўрна, _dụi_, mæla, 
   {{0x6d5c371d,0x672800f3,0xe59c0150,0x98bc002b}},	//   _utsa, vlej, _ﺃﻴﺎﺭ_, _sitā_, 
   {{0xa7b414b7,0x6ef0005c,0x7ce0371e,0x98bc00dc}},	//   есиј, _dåbe, _dörs, _pitā_, 
   {{0xddc400da,0x6728371f,0x9ba003cc,0x7ce03720}},	//   _iekš, tlej, _مەلى, _vört, 
   {{0x7ce03721,0x44243722,0x6ef003cd,0x2ee8003e}},	//   _förs, _ryn_, _fåbe, nkaf_, 
   {{0x44243723,0x7ce03724,0x67283725,0x98bc00b0}},	//   _syn_, _tört, rlej, _witā_, 
   {{0x44243726,0x67283727,0x49003728,0x67d400ee}},	//   _pyn_, slej, _шүлг, _позу, 
   {{0x67283729,0x2328372a,0xddc407f5,0x9f5c0205}},	//   plej, зони_, _mekš, çtü_, 
   {{0x4424372b,0xddd401d3,0x7ce0372c,0xddc400ef}},	//   _vyn_, zgyű, _yörs, _lekš, 
   {{0x4424372d,0x26dc009a,0x2d98036e,0x7ce03167}},	//   _wyn_, _iowo_, _nqse_, _mörr, 
   {{0x26dc372e,0x4424372f,0x63780209,0x7ce0061f}},	//   _howo_, _tyn_, _есир_, _lörr, 
   {{0x8fa03730,0x26dc01e1,0x00000000,0x00000000}},	//   ларе, _kowo_, --, --, 
   {{0x26dc3731,0x81c400c7,0xf548004d,0x00000000}},	//   _jowo_, _ааиҧ, _rụi_, --, 
   {{0x629401aa,0xdee40364,0x9f340046,0x26dc1ef4}},	// [34a0] _icyo, _ҷони, деңі, _mowo_, 
   {{0x98bc0311,0x61e40024,0x6ef00726,0x7ce001e3}},	//   _mită_, mykl, _råbe, _rörs, 
   {{0x61e43732,0xdee40835,0xddc400ef,0x9a68007b}},	//   lykl, _зони, _dekš, كمال_, 
   {{0x60dc3733,0x6ef032b8,0x7ce0023a,0xd00c1893}},	//   _hopm, _påbe, _pörs, _چلی_, 
   {{0x7ce0049f,0x3ea03734,0x46d00316,0x60dc3735}},	//   _dörr, mfit_, थानह, _kopm, 
   {{0x6ef004ce,0xf54801fb,0xf8a80133,0xfbc801d5}},	//   _våbe, _tụi_, بگره_, _оғзи_, 
   {{0x7ce004f3,0x26dc3736,0x2b903737,0x61e4010e}},	//   _förr, _bowo_, _نیلس, hykl, 
   {{0x8f98159d,0x61e40953,0x26dc0073,0xda643738}},	//   ליצי, kykl, _cowo_, _ساري, 
   {{0x55043739,0x26dc373a,0x60dc05e4,0x9984373b}},	//   ечна, _dowo_, _oopm, _سلاو, 
   {{0x38c8373c,0x62940223,0x644c373d,0x61e4373e}},	//   _تاری_, _acyo, _şair, dykl, 
   {{0xccf0025f,0x26dc0241,0x3ea001f5,0xd684010a}},	//   רכת_, _fowo_, kfit_, _зулп, 
   {{0x26dc00f2,0x27e00112,0x3ea0036e,0xa3b003ce}},	//   _gowo_, ähne_, jfit_, _ऑनर_, 
   {{0x316c025a,0x61e40153,0x64300023,0x00000000}},	//   èez_, gykl, _ባዕልኹ, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3ea0373f,0x60dc014f,0xbfa83740,0xddc400ef}},	//   ffit_, _dopm, нтте_, _rekš, 
   {{0xad241e87,0xbbbc033f,0xa3d40037,0x940000ec}},	//   چىرى, ोमैक, _सपत_, _لوڙه, 
   {{0x2ee80221,0x61300413,0xddc400ef,0x00000000}},	// [34b0] rkaf_, sæla, _pekš, --, 
   {{0x2ee83741,0x60dc00a2,0x70543742,0x61300174}},	//   skaf_, _gopm, _جندا, pæla, 
   {{0x645c013f,0x823401d5,0x7ce0005b,0xea94009d}},	//   ɛsid, _لریا, _pörr, вшлэ, 
   {{0xc01c0016,0x63400381,0xef1000f7,0x63a417da}},	//   _lược_, _pœni, _түбө, _ähne, 
   {{0x4428001e,0x26dc3743,0x75380208,0x3dc00208}},	//   ́c_, _rowo_, _ohvz, cviw_, 
   {{0xec3400c7,0x26dc0248,0xac1800cf,0x00000000}},	//   _ангь, _sowo_, _жогу_, --, 
   {{0x61e43744,0x8aa40953,0x7ac40724,0x26dc007f}},	//   zykl, _прад, _өсте, _powo_, 
   {{0x78a404b9,0x7ce03745,0x00000000,0x00000000}},	//   điva, _hörp, --, --, 
   {{0x7ce03746,0x644c06be,0x00000000,0x00000000}},	//   _körp, _şaiq, --, --, 
   {{0x61e43747,0x26dc013f,0xc01c01fb,0x98bc054e}},	//   vykl, _wowo_, _cược_, _vită_, 
   {{0xc6e410f5,0xc01c0016,0x638400a7,0xb0d409ae}},	//   _підп, _dược_, ъгна, दानग, 
   {{0x2d88016b,0x61e43748,0x9a1002e3,0x60dc047e}},	//   krae_, tykl, pọtụ, _sopm, 
   {{0x98bc0311,0x058400d8,0x00000000,0x00000000}},	//   _uită_, _чуем, --, --, 
   {{0x2d880660,0x61e43749,0x60dc374a,0x2408022e}},	//   drae_, rykl, _qopm, _онли_, 
   {{0x61e402d5,0x2d88003a,0x1e94374b,0x2334010a}},	//   sykl, erae_, крар, _ихир, 
   {{0xe1f0374c,0x3f8408a4,0x2d88030a,0x61e4374d}},	//   _نسخ_, čmu_, frae_, pykl, 
   {{0x60dc374e,0x2d880381,0x3ea0374f,0x98bc00c0}},	// [34c0] _topm, grae_, rfit_, _hitą_, 
   {{0x98bc02d5,0xa3d40034,0x60dc01bf,0xc01c0051}},	//   _kitą_, _सपा_, _uopm, _xược_, 
   {{0xad240330,0xdd900451,0x7e440408,0x00000000}},	//   ارقو, _ھوس_, ăхсе, --, 
   {{0x2d883750,0xdee43751,0xf54801fb,0x98bc0064}},	//   brae_, _роми, _hụt_, _mitą_, 
   {{0x2d88213b,0x7ce0049f,0xcee00046,0x0d801220}},	//   crae_, _förp, _тұтқ, _клян, 
   {{0x97a43752,0x7ce00166,0x00000000,0x00000000}},	//   врил, _törq, --, --, 
   {{0xdcf402e2,0xf5480051,0xddd4012d,0x644c0139}},	//   nsyč, _mụt_, ybyś, _ğaip, 
   {{0xa3d40d01,0x8c1806a9,0xf54801fb,0xc7c4005b}},	//   समन_, _חולי, _lụt_, тыше_, 
   {{0x9a2401b9,0x7ae03753,0x429c0150,0x5974030d}},	//   _شعرن, _iomt, _ﺘﺄﺘﻲ_, _шыву, 
   {{0x7ae03754,0xdcf4007f,0x98bc0210,0x97c400ae}},	//   _homt, ksyč, _bitą_, _لتصم, 
   {{0x7ae01253,0xf7703755,0x69340356,0xc01c0051}},	//   _komt, _چاچ_, uşeş, _vược_, 
   {{0x51843756,0x958400db,0x69dc00d8,0xf7701e2f}},	//   куга, _алде, _àsec, _ناچ_, 
   {{0x213801ab,0x394c3757,0xf548004d,0xf4240137}},	//   _bhph_, _kids_, _bụt_, _өздү, 
   {{0x7ae03758,0x2d880660,0xf548004d,0x656c06be}},	//   _lomt, vrae_, _cụt_, _çaha, 
   {{0x394c3759,0x7ae0009a,0xceb80640,0x73c4190b}},	//   _mids_, _oomt, мља_, _сәпе, 
   {{0x394c375a,0x2d88375b,0x7ae00912,0xd5b4375c}},	//   _lids_, trae_, _nomt, _अनाज, 
   {{0x2d880165,0xd138014b,0x00000000,0x00000000}},	// [34d0] urae_, _охо_, --, --, 
   {{0x394c1028,0x2d88375d,0x0fe00228,0xcc082088}},	//   _nids_, rrae_, _көбү, وزان_, 
   {{0xa3d40d01,0x7ae0375e,0x291803b2,0xfd440006}},	//   समय_, _bomt, _ísai_, рэтн, 
   {{0x7ae0375f,0x394c3760,0x2d880393,0x0e68027d}},	//   _comt, _aids_, prae_, _تصدي_, 
   {{0x394c3761,0xdb0c0077,0xbb6400b5,0x7ae00129}},	//   _bids_, _arbó, _popワ_, _domt, 
   {{0x6130037e,0x279401c6,0x00000000,0x00000000}},	//   jæll, гшир, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x394c0158,0x98b40139,0x00000000,0x00000000}},	//   _eids_, вләт_, --, --, 
   {{0x6130037e,0xa5240075,0x2b4c01f7,0xc9841677}},	//   fæll, лмид, _iiec_, _јуби, 
   {{0x394c3762,0x33280227,0x7ae00912,0x649801a9}},	//   _gids_, _akax_, _zomt, хтир_, 
   {{0x7ae00912,0xa2e43763,0x29043764,0xe6943765}},	//   _yomt, гонд, _imla_, _ملاد, 
   {{0x68e03766,0xf548004d,0x29040419,0x98bc0064}},	//   _hold, _sụt_, _hmla_, _vitą_, 
   {{0x64a43767,0x68e03768,0x09c0009e,0x23640077}},	//   _бала, _kold, ্নকা, splj_, 
   {{0x68e001fa,0x293400c8,0x2b4c00de,0x05943769}},	//   _jold, טאָן_, _liec_, _ﻛﻪﺳﭙ, 
   {{0xd5100014,0x9a1000b4,0xf54801fb,0x00000000}},	//   _دِود, họpụ, _vụt_, --, 
   {{0x6ef0007c,0xd00c007b,0x00000000,0x00000000}},	//   _påba, ألف_, --, --, 
   {{0x7ae0376a,0xf1d40228,0xf54801fb,0xd26000fd}},	// [34e0] _romt, _көрө, _tụt_, _укый, 
   {{0x7ae0376b,0x68e0376c,0x2164008e,0x00000000}},	//   _somt, _nold, _итүг, --, 
   {{0x30740220,0x9a84376d,0x10980375,0x394c376e}},	//   _туыс, гулл, _אביב, _rids_, 
   {{0x2b4c0048,0x2904376f,0x394c01b8,0xdb0c004e}},	//   _ciec_, _amla_, _sids_, _arbò, 
   {{0x68e03770,0x2b4c3771,0x7ae00327,0xb33c031c}},	//   _bold, _diec_, _vomt, stħg, 
   {{0x7ae01cdf,0x290401ab,0x394c0472,0x68e02278}},	//   _womt, _cmla_, _qids_, _cold, 
   {{0x7ae03772,0x68e02e00,0x57a43773,0x8f20002e}},	//   _tomt, _dold, ушла, _m茜ng, 
   {{0x2b4c0048,0x394c0493,0x7ae021e3,0x68e001d3}},	//   _giec_, _wids_, _uomt, _eold, 
   {{0x2904033b,0x5894034c,0x61303774,0x00000000}},	//   _fmla_, _مجاز, tæll, --, 
   {{0xd9443775,0xd4983776,0x68e03777,0x394c0175}},	//   _сези, хри_, _gold, _uids_, 
   {{0x61303778,0x93a83779,0x01bc0150,0x00000000}},	//   ræll, رادف_, _ﺸﺅﻭﻨ, --, 
   {{0x68e0377a,0xf1c400c0,0x00000000,0x00000000}},	//   _zold, _lašų_, --, --, 
   {{0x68e00bfc,0x00000000,0x00000000,0x00000000}},	//   _yold, --, --, --, 
   {{0x68e0377b,0x00000000,0x00000000,0x00000000}},	//   _xold, --, --, --, 
   {{0x33940fab,0x00000000,0x00000000,0x00000000}},	//   _тайё, --, --, --, 
   {{0x33280bc9,0xa1d00219,0x00000000,0x00000000}},	//   _ukax_, žišč_, --, --, 
   {{0x2b4c003e,0x601000e5,0x00000000,0x00000000}},	// [34f0] _riec_, tűmé, --, --, 
   {{0x2b4c377c,0x00000000,0x00000000,0x00000000}},	//   _siec_, --, --, --, 
   {{0x68e0377d,0x6d580943,0xaa54377e,0xec140736}},	//   _rold, ̭wah, авеш, جواد, 
   {{0xee3800f7,0x00000000,0x00000000,0x00000000}},	//   _үнү_, --, --, --, 
   {{0x68e0377f,0x2b4c001e,0xc9840022,0x00000000}},	//   _pold, _viec_, ууеи, --, 
   {{0x68e0006c,0x2b4c0034,0x798002d0,0xa3c4012d}},	//   _qold, _wiec_, _dvmw, _उछल_, 
   {{0x2b4c3780,0x00000000,0x00000000,0x00000000}},	//   _tiec_, --, --, --, 
   {{0x68e03781,0x9a1001f2,0xa6e43782,0x00000000}},	//   _wold, pọpụ, ржил, --, 
   {{0x68e03783,0x6aa80109,0xe8940024,0x00000000}},	//   _told, _ibef, _вазь, --, 
   {{0x795801f0,0x00000000,0x00000000,0x00000000}},	//   _сифр_, --, --, --, 
   {{0x69c80096,0x00000000,0x00000000,0x00000000}},	//   _hree, --, --, --, 
   {{0x69c83784,0x00000000,0x00000000,0x00000000}},	//   _kree, --, --, --, 
   {{0x6aa80472,0x69d800f1,0x2d4c0010,0xa91c0118}},	//   _mbef, nxwe, _ržen_, _evže, 
   {{0x69c80076,0x6130005c,0xe508009f,0xa508030d}},	//   _mree, mælk, _جيتو_, _шела_, 
   {{0x6aa83785,0x64a43786,0xfe783787,0x6ef0005c}},	//   _obef, _баһа, лүн_, _våbn, 
   {{0x539806a9,0x69c80493,0x9e643788,0xdee40c60}},	//   _סיפו, _oree, شارن, шоби, 
   {{0x69c80218,0xad64007b,0x656801f4,0xd12c00e5}},	// [3500] _nree, ماله, npeh, سمہ_, 
   {{0x6aa83789,0x6ef001bf,0x69d80067,0x656800e4}},	//   _abef, _håbl, dxwe, ipeh, 
   {{0x69c8378a,0xef9c001f,0x63a0378b,0x9f04129e}},	//   _aree, ሌኒየሙ_, ntln, _نودو, 
   {{0x69c80d8b,0xf5480051,0x0a1000ec,0x00000000}},	//   _bree, _lụp_, ڊومح, --, 
   {{0x2a682b76,0x69c8378c,0x7f44378d,0x613001bf}},	//   ñaba_, _cree, mmiq, jælk, 
   {{0x69c8378e,0x6aa8016b,0xa3d40316,0x7f440129}},	//   _dree, _ebef, समा_, lmiq, 
   {{0x69c8378f,0x272002fb,0x6aa80334,0x37a83267}},	//   _eree, lóny_, _fbef, ائتی_, 
   {{0x69c83790,0x6aa80241,0x7f44004e,0x00000000}},	//   _free, _gbef, nmiq, --, 
   {{0x69c80c18,0x7f440472,0x3f5c0208,0xf5480208}},	//   _gree, imiq, _líu_, _bụp_, 
   {{0x3f5c0077,0xf5480208,0xdec81ef7,0xdbd40139}},	//   _oíu_, _cụp_, _አጎአ_, läñg, 
   {{0x3f5c3791,0x73c40032,0xcc540a7c,0x58d401ee}},	//   _níu_, сәле, יסיק_, _йоҡт, 
   {{0x387c3792,0x9644084c,0xefe80092,0x69c802d0}},	//   lavr_, _кэлд, _ዘውዴ_, _yree, 
   {{0x23680122,0xc1b80816,0x95b40139,0xded00023}},	//   _čaje_, алях_, _әрҗә, ረናን_, 
   {{0x6ef000cc,0x969001d3,0x46100592,0x09c00154}},	//   _påbo, _ایکش, _بوهر, ্নচা, 
   {{0x75281813,0x8538011a,0x673402d2,0x00000000}},	//   modz, _שגוי, _áfjó, --, 
   {{0x75283793,0x27202195,0x98bc0393,0x52740131}},	//   lodz, fóny_, _vitę_, _ئاغز, 
   {{0xed50005e,0x272002f0,0x00000000,0x00000000}},	// [3510] سپا_, góny_, --, --, 
   {{0x752805b8,0x6aa8011c,0x8c643794,0x7f44003a}},	//   nodz, _sbef, ртад, amiq, 
   {{0x69c803a2,0x75280099,0x69d80009,0x00000000}},	//   _sree, iodz, wxwe, --, 
   {{0x69c83795,0xd64c063f,0x75283796,0x94080213}},	//   _pree, _kọdụ_, hodz, übə_, 
   {{0x75283797,0x00000000,0x00000000,0x00000000}},	//   kodz, --, --, --, 
   {{0x69c83798,0x6f0c3799,0x75280810,0x00000000}},	//   _vree, liac, jodz, --, 
   {{0x69c8379a,0x3f5c01fb,0xd76424ae,0xf5480051}},	//   _wree, _xíu_, مەلى_, _rụp_, 
   {{0x6f0c379b,0x6d44379c,0x660c0008,0x6aa8379d}},	//   niac, lmha, _þakk, _ubef, 
   {{0x63a4025a,0x9f4c03a1,0xd64c063f,0x69c8379e}},	//   _âhnz, _åfå_, _nọdụ_, _uree, 
   {{0x7528379f,0x6d441549,0x6f0c37a0,0x7c44002d}},	//   godz, nmha, hiac, _útrê, 
   {{0x27200122,0x240837a1,0x6f0c01c8,0x65681aff}},	//   zóny_, унни_, kiac, speh, 
   {{0x216837a2,0xd64c02e3,0x61301873,0x63a0010a}},	//   лими_, _bọdụ_, mæli, rtln, 
   {{0x752837a3,0xd64c01f2,0x3f5c02d2,0x98bc013a}},	//   bodz, _rọgụ_, _síu_, _nitě_, 
   {{0xd46410f5,0x2a7c0190,0x61443529,0x6f0c003a}},	//   _лише_, hawb_, сега, eiac, 
   {{0xa2e437a4,0x201c03ee,0x6f0c37a5,0x6d44007b}},	//   _гойд, çti_, fiac, dmha, 
   {{0xe50816cb,0xd64c063f,0x1cb8031c,0x3f5c0208}},	//   _جيڪو_, _fọdụ_, _ྙིང_, _víu_, 
   {{0x7f4437a6,0x6d4401ab,0x5d680166,0x00000000}},	// [3520] rmiq, fmha, уизм_, --, 
   {{0x3f5c0008,0x7f4437a7,0x6d4437a8,0x7ce0002f}},	//   _tíu_, smiq, gmha, _hörz, 
   {{0x6f0c37a9,0x7ce001ed,0x67280af9,0xa13400e5}},	//   biac, _körz, koej, _پرکش, 
   {{0x6d4414d0,0x752805b8,0x272002fb,0x6130032e}},	//   amha, zodz, póny_, dæli, 
   {{0x75280161,0xae4400db,0x8e0402e8,0x660c02d2}},	//   yodz, _وپپو, _гняв_, _þakh, 
   {{0x6d441552,0xd83812cf,0x6b6400c0,0x7bd80254}},	//   cmha, лэй_, _bėgd, ävus, 
   {{0x7528192e,0xd7c40b87,0x67380023,0xcb64009b}},	//   vodz, сёло, _ብህዝብ, _гасе_, 
   {{0x75280034,0x6728020c,0xc0d40092,0x4acc0073}},	//   wodz, goej, ረዳሉ_, _सोपव, 
   {{0x752837aa,0x186837ab,0x3494011c,0x4ab001c4}},	//   todz, _бази_, оапр, _хөхр, 
   {{0x6f0c37ac,0x613002d2,0x059401ec,0x00000000}},	//   ziac, bæli, _ﻛﻪﺗﭙ, --, 
   {{0x63a409a4,0x752837ad,0x672801bf,0x56f0004e}},	//   _ähnl, rodz, boej, _нүкс, 
   {{0x083800c8,0xf8b005d9,0x752837ae,0x6f0c0077}},	//   _געבל, _رکڻ_, sodz, xiac, 
   {{0x6f0c37af,0x75280433,0x1560063f,0x2d4c0063}},	//   viac, podz, _fọọa, _džej_, 
   {{0x6f0c37b0,0x7ae40254,0x00000000,0x00000000}},	//   wiac, öitj, --, --, 
   {{0x6f0c37b1,0x43641fbe,0x00000000,0x00000000}},	//   tiac, _лајн_, --, --, 
   {{0x87780bd9,0x6b6400c0,0x00000000,0x00000000}},	//   טאלי, _jėge, --, --, 
   {{0x28b8028a,0x6d4437b2,0x00000000,0x00000000}},	// [3530] _इसलि, tmha, --, --, 
   {{0x6f0c0038,0x6d4437b3,0xdbd40139,0x4638008f}},	//   siac, umha, _fäüc, רעמע, 
   {{0x6d4437b4,0x6f0c37b5,0x2d4c05a1,0x644c0356}},	//   rmha, piac, _užem_, _şaiz, 
   {{0x6d4414d0,0xc0d4001f,0x613006ea,0x00000000}},	//   smha, ረዳል_, væli, --, 
   {{0x6f1c01a4,0xa00806be,0x00000000,0x00000000}},	//   _ijsc, _reжi, --, --, 
   {{0x2a7c0218,0x660c08a5,0x7f840244,0x00000000}},	//   sawb_, _þaki, _بلێن, --, 
   {{0x0a680e92,0x6b6400c0,0x00000000,0x00000000}},	//   _брзи_, _bėge, --, --, 
   {{0x316837b6,0xfd4c02e3,0x3b6400a7,0xc998007b}},	//   _otaz_, _obiọ, _хърв, _مخطط_, 
   {{0x67280162,0x00000000,0x00000000,0x00000000}},	//   roej, --, --, --, 
   {{0x7ce00139,0x7c3c02d0,0x61300d12,0x00000000}},	//   _böry, _yzrr, pæli, --, 
   {{0x28140491,0x00000000,0x00000000,0x00000000}},	//   _بواس, --, --, --, 
   {{0xe29837b7,0x4acc23ef,0x232837b8,0x224833d2}},	//   шам_, _सोमव, роми_, ипни_, 
   {{0x7c2803b2,0xd36c00f2,0x8f640014,0x00000000}},	//   _ødrv, _یهو_, ۪لٲے_, --, 
   {{0xb5c800aa,0x2d4c009b,0xf74400b8,0x7ce001e3}},	//   _دوهم_, _džek_, _iṣṭe, _föry, 
   {{0xc444034c,0x7ce037b9,0xe3b037ba,0x212800a3}},	//   _دیدن_, _törz, _آرت_, robh_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2fcc0421,0x6f1c0064,0x660c010e,0x00000000}},	// [3540] āega_, _djsc, _ýakd, --, 
   {{0xa3cc37bb,0xe12400d4,0x644c06be,0x00000000}},	//   रिप_, _ємни, _şaiy, --, 
   {{0xdee40aa5,0xda782203,0x69dc0241,0x00000000}},	//   _дони, аял_, _àsej, --, 
   {{0x3f9837bc,0x0de80092,0x8f9800d9,0x00000000}},	//   muru_, _ዘርፉ_, _דיטי, --, 
   {{0x3f9837bd,0x3a2037be,0x4e240137,0xc04400f1}},	//   luru_, çip_, _моюн_, _بخښو, 
   {{0xdcb001ec,0x3f9800b0,0x00000000,0x00000000}},	//   _تىس_, ouru_, --, --, 
   {{0xa3cc2cfd,0x3f9837bf,0x645c0118,0x00000000}},	//   रिफ_, nuru_, ěsil, --, 
   {{0xa3cc28f5,0x61300008,0x3f9800b0,0x696400cf}},	//   रिन_, mælu, iuru_, زدۇق, 
   {{0x3f9837c0,0x75d4007b,0x00000000,0x00000000}},	//   huru_, سيدا, --, --, 
   {{0x3f98252e,0x31681529,0xd90c01ed,0xd44801f0}},	//   kuru_, _rtaz_, _جیت_, иянд_, 
   {{0x3f9837c1,0x316837c2,0x7e6437c3,0x4acc0490}},	//   juru_, _staz_, kcip, _सोडव, 
   {{0x3f9837c4,0x78b837c5,0x7c280174,0x95c80063}},	//   duru_, levv, _ødru, _вука_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3f9837c6,0x7e640483,0x78b803e0,0x00000000}},	//   furu_, ecip, nevv, --, 
   {{0x3f9837c7,0x94200131,0x7e64003a,0xd6b407d5}},	//   guru_, _توغۇ, fcip, _хiум, 
   {{0x0de80201,0x37bc00bd,0x7e64004b,0x92680e92}},	//   _ዘርፍ_, _অপার, gcip, _трка_, 
   {{0x31680198,0x3f980374,0x6fb401d9,0x00000000}},	// [3550] _utaz_, auru_, _کمجا, --, 
   {{0x7c582dfc,0x714000db,0x00000000,0x00000000}},	//   ەلەر_, _سۉزۅ, --, --, 
   {{0xa3cc37c8,0x3f9837c9,0x78b8047e,0xfb840006}},	//   रिय_, curu_, devv, дычн, 
   {{0x7e6437ca,0x2fc001d5,0x65b008a5,0xc4b407b7}},	//   ccip, _ishg_, _jóhö, _अस्ख, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d5c37cb,0xa3cc37cc,0x78b837cd,0x00000000}},	//   _iusa, रिम_, gevv, --, 
   {{0x6d5c37ce,0x6d5437cf,0x1ac437d0,0x61301427}},	//   _husa, _iiza, _रोकथ, mælt, 
   {{0x6d5437d1,0x49b801d9,0xe578059f,0x67f0032e}},	//   _hiza, _پارد_, бзи_, _aðjú, 
   {{0x6d5437d2,0x3f9837d3,0x6d5c03f0,0xe2a40174}},	//   _kiza, zuru_, _jusa, _óðin_, 
   {{0x3f9837d4,0x6d5437d5,0xdb24023a,0x00000000}},	//   yuru_, _jiza, öpöy, --, 
   {{0x6d5c37d6,0xd91802e4,0xb6cc0790,0x7b08032e}},	//   _lusa, _פועל, çücü, _úrtö, 
   {{0xf77037d7,0x6d5c37d8,0x3f9837d9,0xddd40113}},	//   _شام_, _ousa, vuru_, hayš, 
   {{0x3f9837da,0x6ab80334,0xc0d00023,0x20d400d4}},	//   wuru_, iewf, _ብሱል_, півс, 
   {{0x3f9837db,0x6d5437dc,0x2fc0002f,0xe9c401d3}},	//   turu_, _niza, _bshg_, _یں_, 
   {{0x2fc00789,0xc5ec004b,0x3f980810,0x00000000}},	//   _cshg_, _سړک_, uuru_, --, 
   {{0x6d5437dd,0x6ce402dd,0xd35400d9,0x533000f3}},	//   _aiza, _ﺍﻷﺨﻴ, _ציפי_, _пејт, 
   {{0x6d5437de,0x7e6437df,0xc444006c,0x8ecc03d4}},	// [3560] _biza, rcip, _دیگن_, ৰসংগ, 
   {{0x7e6437e0,0x3f9837e1,0xad2400f7,0xdb8002dd}},	//   scip, puru_, ورلو, ердi_, 
   {{0x3f9837e2,0xe6bc37e3,0x9058011a,0x00000000}},	//   quru_, ्याङ, _לכית, --, 
   {{0x6d5c37e4,0x6d54009d,0x312400cf,0x8b20011c}},	//   _fusa, _eiza, _ндөг, ндхе, 
   {{0x6d5c37e5,0x6d540851,0x613037e6,0x78b837e7}},	//   _gusa, _fiza, bælt, tevv, 
   {{0x6d540323,0x6ef0007c,0x6ce800f1,0x00000000}},	//   _giza, _råbi, _وژلې_, --, 
   {{0x6d5c09f0,0x37bc015b,0xb6c401c6,0x00000000}},	//   _zusa, _অপহর, дөлд, --, 
   {{0x6d5437e8,0x6d5c005c,0x479024ae,0xdb0437e9}},	//   _ziza, _yusa, رجىس, ömän, 
   {{0x6d5c0050,0x98540184,0x6d5437ea,0xd7c807d6}},	//   _xusa, _етеш, _yiza, _گواه_, 
   {{0x636001f2,0xf8c0012c,0x6d540165,0x00000000}},	//   _ịnap, _एसिय, _xiza, --, 
   {{0x27c000c7,0x657802d0,0x63800022,0x00000000}},	//   _аӡым, _ewwh, ҭҳәа, --, 
   {{0x6b640006,0x88380375,0x5748013d,0x574400cf}},	//   _jėga, _פתאו, _узем_, _энеб, 
   {{0x6b640024,0xb33c0135,0x38c40171,0x00000000}},	//   _mėga, stħo, _tūrē_, --, 
   {{0x6d5c37eb,0x00000000,0x00000000,0x00000000}},	//   _rusa, --, --, --, 
   {{0x6d5437ec,0x136837ed,0x6130005c,0xa3cc1546}},	//   _riza, _ушли_, vælt, रिण_, 
   {{0x6d5c37ee,0x3ec421f3,0x8e2c022e,0x00000000}},	//   _pusa, нсуб, аgа_, --, 
   {{0x6d5c37ef,0xa6a800fe,0xb8fc02dd,0x660c02d2}},	// [3570] _qusa, _খোঁট, _әкiм, _þakt, 
   {{0x6d5401b9,0x81fc0375,0x6d5c37f0,0x4fc40150}},	//   _qiza, _להחז, _vusa, _есма, 
   {{0xfe7000dd,0x6d5c04fb,0x6b640024,0x00000000}},	//   ئدہ_, _wusa, _bėga, --, 
   {{0x6d5437f1,0x6d5c37f2,0xa3cc37f3,0xdb2437f4}},	//   _wiza, _tusa, रित_, وولی, 
   {{0x6d5c37f5,0x6d5437f6,0x0d9037f7,0x6ab80175}},	//   _uusa, _tiza, _سیاح, rewf, 
   {{0xba7437f8,0x6d5402d0,0x0dc8014b,0x00000000}},	//   _ۋاقت, _uiza, _куҳи_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd6cc1c62,0x8cd8033f,0x08400014,0xe7301291}},	//   لقى_, नावो, ٘نڈُ, خصت_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x67d400f7,0xf87000d0,0x2910010e,0x7c34032e}},	//   _оозу, čším_, _öza_, _ífré, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x64a437f9,0xa06837fa,0xf548004d,0x91e01422}},	//   _жала, жага_, _lụy_, вояе, 
   {{0x75440153,0x00000000,0x00000000,0x00000000}},	//   _зніз, --, --, --, 
   {{0x8fa037fb,0xdb1c0fac,0x00000000,0x00000000}},	//   каре, lvpå, --, --, 
   {{0xe0dc0154,0x660c02d2,0x00000000,0x00000000}},	//   ডসেন, _þaks, --, --, 
   {{0x2d940108,0xe124014b,0x00000000,0x00000000}},	// [3580] ерхс, _омии, --, --, 
   {{0x61300174,0x00000000,0x00000000,0x00000000}},	//   ræls, --, --, --, 
   {{0xe1f0179e,0x660403b9,0x00000000,0x00000000}},	//   _سسک_, _əhka, --, --, 
   {{0x6130366f,0x00000000,0x00000000,0x00000000}},	//   pæls, --, --, --, 
   {{0xdec80023,0x00000000,0x00000000,0x00000000}},	//   _አሎና_, --, --, --, 
   {{0x3ea037fc,0x00000000,0x00000000,0x00000000}},	//   lgit_, --, --, --, 
   {{0x6ea400dc,0x8cd81be1,0xa85400b1,0x00000000}},	//   ङ्कु, नारो, нешә, --, 
   {{0x8c4037fd,0x461001e1,0x00000000,0x00000000}},	//   _ресе, _sápẹ_, --, --, 
   {{0xb8f400bd,0x3ea037fe,0xd5b80212,0x00000000}},	//   _হক_, igit_, іси_, --, 
   {{0x337437ff,0x1c201414,0x00000000,0x00000000}},	//   нгор, _मशाल_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x0cb810eb,0x6ce40150,0xd244009d,0x00000000}},	//   _उस्म, _ﺍﻷﺤﻴ, дэги, --, 
   {{0x55043800,0x3ea03801,0x54e4007b,0x34943802}},	//   _очка, dgit_, _يستق, _залр, 
   {{0x672c05ce,0x738800ee,0x3dc00042,0xbb500150}},	//   čaje, _ериң_, dwiw_, _ﺎﺯﻱ_, 
   {{0x2a90013f,0x660c02d2,0xc49800d9,0x00000000}},	//   _wɑbɔ_, _þakr, _ושות, --, 
   {{0x3ea03803,0x439001f0,0x00000000,0x00000000}},	//   ggit_, _раъс, --, --, 
   {{0x6ea400dc,0xc334011a,0x00000000,0x00000000}},	// [3590] ङ्गु, _שופ_, --, --, 
   {{0x3d943804,0x3ea03805,0x00000000,0x00000000}},	//   тифр, agit_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6ef00450,0x2f2000c0,0x00000000,0x00000000}},	//   _påbu, mėgo_, --, --, 
   {{0x38c40006,0xd5e001e1,0x00000000,0x00000000}},	//   kūrė_, _nfò, --, --, 
   {{0xf990064c,0xf548004d,0x5d7808d8,0x98a000db}},	//   شبه_, _tụy_, _מאשק, гише, 
   {{0x2d4c009b,0x8aa42708,0x38c40006,0x0ab801b9}},	//   _džet_, _орад, dūrė_, _وطرب_, 
   {{0xa3cc3806,0x00580375,0x2d880381,0xe468005b}},	//   रिस_, ושות_, osae_, kköä_, 
   {{0xc8a80801,0x2d883807,0xe6183808,0xfd6400dc}},	//   _мъже_, nsae_, яди_, _bhuṅ, 
   {{0x6b640006,0x61303809,0xdec8001f,0xc0e0001f}},	//   _jėgo, jælp, _አዎን_, _ናችሁ_, 
   {{0x2d880007,0xd36c1888,0xc7c4072c,0x00000000}},	//   hsae_, یهی_, _юсаи, --, 
   {{0xe5840137,0x00000000,0x00000000,0x00000000}},	//   _كۅبۉ_, --, --, --, 
   {{0x38c40153,0xbbac00dc,0x1718010f,0x00000000}},	//   būrė_, _टङ्क, _צונע, --, 
   {{0x64a4380a,0x69dc0129,0x00000000,0x00000000}},	//   _чака, _àseu, --, --, 
   {{0xd5e001e1,0x2484248f,0x70400124,0x88c00055}},	//   _ifó, malm_, иҕье, _āśle, 
   {{0xd36c16cb,0x3ea01c06,0x3dc0013f,0xd1dc0023}},	//   _اهي_, ugit_, twiw_, _ናውቲ_, 
   {{0x6284380b,0xdce4005f,0x5318008d,0x6ef000b5}},	// [35a0] mako, _atkā, _מוקצ, _råbt, 
   {{0x6284380c,0x2f200024,0x02ac01ad,0xbae402dd}},	//   lako, bėgo_, ट्रभ, _ﺍﻗﺸﺎ, 
   {{0x90780375,0x205400d4,0x00000000,0x00000000}},	//   _מטיי, _ятир, --, --, 
   {{0x6284380d,0x44240407,0x5b340137,0x6ef000b5}},	//   nako, _mxn_, رعار, _dåbs, 
   {{0x7124380e,0xceb000d9,0x00000000,0x00000000}},	//   _سریل, _גיר_, --, --, 
   {{0x6284380f,0x3f98026c,0x248405c7,0x00000000}},	//   hako, orru_, jalm_, --, 
   {{0x62843810,0x62980006,0x7ae4005b,0xe6bc02a0}},	//   kako, ėtoj, öits, ्यूज, 
   {{0xd5e00241,0x6ef00158,0xcf900375,0xcc38008f}},	//   _afó, _håbr, אטה_, _זעלט, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb1003b2,0x00000000,0x00000000,0x00000000}},	//   ógæt, --, --, --, 
   {{0x73c40b65,0xfd6406d6,0x4424004d,0x27e0002f}},	//   тәле, _vhuṅ, _cxn_, ähnt_, 
   {{0x62843811,0x1b0c0154,0x8c1805d0,0xe46801f4}},	//   gako, িককে_, לויי, tköä_, 
   {{0x24842ab1,0x2d880007,0xded00023,0x660c02d2}},	//   balm_, xsae_, የናን_, _þakp, 
   {{0xa3cc3812,0x24843813,0x62840083,0x661c002d}},	//   रिश_, calm_, aako, úske, 
   {{0x13680598,0x4424001e,0x2ca4010b,0x349401af}},	//   _эшли_, _gxn_, _öldi_, _заһр, 
   {{0x2d8801af,0x69dc0077,0x6ce40150,0x00000000}},	//   tsae_, _áseg, _ﺍﻷﺸﻴ, --, 
   {{0x3f983814,0x2d880393,0xd084030d,0xdce801ef}},	// [35b0] arru_, usae_, _пыни, _únět, 
   {{0x2d881730,0x00000000,0x00000000,0x00000000}},	//   rsae_, --, --, --, 
   {{0x2d883815,0x09b801bc,0xbf8401ee,0x00000000}},	//   ssae_, ोट्य, _йыяй, --, 
   {{0xb6cc3816,0x818801b9,0x2d880393,0xb33c0327}},	//   çülü, _تنیق_, psae_, ftħi, 
   {{0x7e44014b,0x00000000,0x00000000,0x00000000}},	//   _бхре, --, --, --, 
   {{0x62843817,0x1cb8025c,0x9ba000db,0xac9401c4}},	//   zako, _ཙིག_, _چەلى, _шагш, 
   {{0x9ba03818,0xdce400b8,0x00000000,0x00000000}},	//   _نەلى, _utkā, --, --, 
   {{0x4424070d,0xe7383819,0x98b4005f,0xf99000d1}},	//   _rxn_, ьей_, īgās_, شبۇ_, 
   {{0xdb0c381a,0xa52401d5,0x00000000,0x00000000}},	//   _esbó, кмид, --, --, 
   {{0x6284381b,0xa3cc1b76,0x3f98015d,0x00000000}},	//   wako, रिल_, yrru_, --, 
   {{0x6284381c,0x23280364,0xf770381d,0x39400198}},	//   tako, дони_, _هان_, ɓis_, 
   {{0x069817ae,0x660c00a2,0x00000000,0x00000000}},	//   _رخصت_, _ýako, --, --, 
   {{0x2484381e,0xe4c40075,0xe7f800bc,0xe5e40271}},	//   palm_, _айли, एईका_, _جزای, 
   {{0x6284381f,0x25ac3820,0xdd903821,0x26cc3822}},	//   sako, mtel_, یوز_, ldeo_, 
   {{0x25ac3823,0xbe841f71,0x660801f5,0x80c400eb}},	//   ltel_, лқни, lzek, শাল্, 
   {{0x3d0402c1,0x0b100eac,0x8fa00f5c,0x1cb80327}},	//   _möwe_, িকুল_, јате, _ཙིང_, 
   {{0x66083824,0x25ac3825,0xf1d4052f,0x0e603826}},	// [35c0] nzek, ntel_, _йөрө, ркун, 
   {{0x1f6400c7,0x5ea8015b,0x25ac04cc,0x660801c4}},	//   _иком, _চোখে, itel_, izek, 
   {{0xdf483461,0x25ac3827,0x660801c7,0xdaa811eb}},	//   _озод_, htel_, hzek, двед_, 
   {{0xe6bc00a5,0x66083828,0x00000000,0x00000000}},	//   ्योज, kzek, --, --, 
   {{0xd00c3829,0xcb04009f,0xb6cc03e0,0x00000000}},	//   _هلی_, ضيون_, çümü, --, 
   {{0x6608382a,0x26dc0699,0xfb840344,0x7b8400cf}},	//   dzek, _anwo_, _مدری, _مارە, 
   {{0x25ac382b,0x6608004c,0x2a6c0175,0x60dc0334}},	//   etel_, ezek, _ffeb_, _mnpm, 
   {{0xdb0c1497,0x3d0400a2,0x6608382c,0xb3a8012d}},	//   _esbò, _döwe_, fzek, _कमबख, 
   {{0x7c3c382d,0x8700005b,0x00000000,0x00000000}},	//   _hyrr, ряще, --, --, 
   {{0x672c0b91,0x386c00ca,0x7c3c09e8,0x26cc0393}},	//   čaja, _ufdr_, _kyrr, adeo_, 
   {{0x25ac382e,0x79800810,0x4c980375,0xc0dc01ec}},	//   atel_, _hwmw, וביו, _ﺀﺗﯘﻳ, 
   {{0x6608382f,0x7c3c3830,0x20080841,0x79a001ec}},	//   bzek, _myrr, dzbi_, _ﺍﻻﯕﻰ_, 
   {{0x25ac2e27,0x66080034,0x73c40032,0x3cf80490}},	//   ctel_, czek, тәһе, _एवढे_, 
   {{0x798000b5,0xd4640023,0x00000000,0x00000000}},	//   _mwmw, _ተቓዉሞ_, --, --, 
   {{0x6e9423b3,0x7c3c00ad,0xa3cc00dc,0x72d40229}},	//   ливу, _nyrr, रिः_, _бойф, 
   {{0x28d81b61,0x00000000,0x00000000,0x00000000}},	//   _योनि, --, --, --, 
   {{0x23683831,0xb644037e,0x8d743832,0x91e00131}},	// [35d0] _čaji_, _ｉｈ_, ئارا, _тәнһ, 
   {{0x7c943833,0x7c3c0042,0x26cc06af,0x81d4074d}},	//   لشما, _byrr, zdeo_, _тоьх, 
   {{0x2d4c1b24,0x7c3c00a9,0x66080083,0xca70179e}},	//   _džep_, _cyrr, zzek, لناک, 
   {{0x7c3c3834,0x8d743835,0xfaf000ec,0x00000000}},	//   _dyrr, _لاسا, يثن_, --, 
   {{0x25ac3836,0x49903837,0x7980015d,0x6a1400f7}},	//   xtel_, شیار, _cwmw, ымду, 
   {{0x7c3c11c3,0xa7a83298,0x0b100011,0xdbd000a2}},	//   _fyrr, екка_, িকেল_, _hüýr, 
   {{0xe7383838,0x6e3c0cfd,0x7c3c00a9,0x25ac0332}},	//   нек_, _hysb, _gyrr, wtel_, 
   {{0x6608152d,0x27e82d2b,0x2a6c004b,0x00000000}},	//   tzek, ćan_, _ufeb_, --, 
   {{0x25ac3839,0x7980015d,0x6608030a,0xe7940133}},	//   utel_, _gwmw, uzek, _ڕاشک, 
   {{0xd464069c,0x25ac383a,0x6608383b,0x69c8383c}},	//   _ተቓውሞ_, rtel_, rzek, _isee, 
   {{0x660800dd,0x6e3c383d,0xccb40327,0xb78800d8}},	//   szek, _lysb, _པིནྶ, _аљче_, 
   {{0x660804e6,0x6e3c035a,0x98bc0153,0x383000db}},	//   pzek, _oysb, _bitė_, _گۉۉز, 
   {{0x6e3c00dc,0x00000000,0x00000000,0x00000000}},	//   _nysb, --, --, --, 
   {{0x25680597,0x9fc8036b,0xa3cc0ce0,0x00000000}},	//   _iúl_, нгга_, रिआ_, --, 
   {{0x602406bb,0xfe78383e,0x69c801ab,0x65680240}},	//   удва, күн_, _lsee, lqeh, 
   {{0x69c8383f,0xb33c0327,0x256808a5,0xf8c007af}},	//   _osee, ftħu, _kúl_, _एस्प, 
   {{0xa0683840,0x25683841,0x69c804ba,0xdbd00432}},	// [35e0] _папа_, _júl_, _nsee, _düýr, 
   {{0x7c3c3842,0x6aa8127b,0x00000000,0x00000000}},	//   _pyrr, _acef, --, --, 
   {{0x69c83843,0x65680023,0x63a001ed,0x6cc401e0}},	//   _asee, hqeh, nuln, рихҡ, 
   {{0x798002d0,0x3ea4072b,0xdee4022e,0x5018011a}},	//   _pwmw, _ømt_, _соми, _טויו, 
   {{0x63a03844,0x6e3c0b21,0xdbd00254,0xae100073}},	//   huln, _gysb, _hüür, _ठेऊन_, 
   {{0x97a43845,0x7c3c2bd6,0x63a03846,0xdd9400c7}},	//   грил, _tyrr, kuln, _иаҭы, 
   {{0x94840831,0x69c804c9,0x63a03847,0x28b400c5}},	//   һынд, _esee, juln, _आउरि, 
   {{0x63a03848,0xb6f41b88,0xdbd000c5,0x9b04036b}},	//   duln, рзиј, _müür, _ёзад, 
   {{0x94841c2f,0x94a83849,0x2568007b,0xdbd00037}},	//   лынд, нтна_, _cúl_, _lüür, 
   {{0x38c8384a,0x05b4384b,0x661c05f7,0x69300753}},	//   _جاری_, اديت_, úska, _وکور, 
   {{0x4c9800c8,0x63a0384c,0xb4e4000d,0x8ca40118}},	//   עשטע, guln, _पची_, _चासो, 
   {{0xf770107f,0x69dc0077,0x43901064,0x25682507}},	//   _هاچ_, _ásec, щаюс, _fúl_, 
   {{0x0ea800e1,0xf40c00fe,0x00000000,0x00000000}},	//   _छाबड, _সুখৰ_, --, --, 
   {{0x91e001e0,0x6fd00073,0xdbd0010b,0x00000000}},	//   _ғәмһ, हिलं, _süýr, --, 
   {{0xffe41b04,0x63a026fc,0x44a000db,0x0f2400c7}},	//   бютн, culn, _امىق, гьам, 
   {{0xa5600014,0x201c0419,0x00000000,0x00000000}},	//   _دۯین, útia_, --, --, 
   {{0x87080248,0xd12400cf,0xfd74009d,0x00000000}},	// [35f0] _jápọ, _مةدى, йлтэ, --, 
   {{0x6aa8384d,0xdbd00254,0x4174009f,0x00000000}},	//   _scef, _füür, _اايس, --, 
   {{0xa3cc084a,0x69c8384e,0xdb0c01c7,0x6e3c017a}},	//   रिए_, _ssee, _opbä, _wysb, 
   {{0xaed416d8,0x00000000,0x00000000,0x00000000}},	//   _томш, --, --, --, 
   {{0x6b640006,0xed580116,0x6e3c02d0,0x247c0150}},	//   _mėgi, _җоң_, _uysb, _ﺣﯘﯕﯟ, 
   {{0x69c8151c,0x2ca4022c,0x8d7405d9,0x2794384f}},	//   _vsee, _øld_, _لاڳا, ашир, 
   {{0x2568007b,0xdd380356,0x66e400db,0xac1800f3}},	//   _súl_, lăşl, иока, _рову_, 
   {{0xb8fc3850,0x69c80b89,0xaac8041c,0xda1402c3}},	//   _तो_, _tsee, _रसिक, _देवत_, 
   {{0x55841e76,0x69c83851,0x36e80eff,0x00000000}},	//   абым_, _usee, ارىپ_, --, 
   {{0x63a03852,0x33280d63,0xa31c0118,0x2d9002dd}},	//   tuln, _ajax_, ědčí_, _ﺟﻪﻟﻰ_, 
   {{0x29043853,0x6b640006,0x00000000,0x00000000}},	//   _illa_, _bėgi, --, --, 
   {{0x256800dd,0x28d834ef,0x63a03854,0xfb0001e1}},	//   _túl_, _योति, ruln, _áàtì_, 
   {{0x63a03855,0x61443856,0xdbd00037,0x236823cc}},	//   suln, иема, _süür, _čaju_, 
   {{0x81b83857,0x84640801,0x28a808df,0xd4640114}},	//   ছিল_, _съде, च्चि, _кише_, 
   {{0x63a0014f,0x61e03858,0x00000000,0x00000000}},	//   quln, _šold, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x29043859,0xa3cc12eb,0x6294385a,0xd24c00cf}},	// [3600] _olla_, रिक_, _idyo, _ۉنۉ_, 
   {{0x7ae0058a,0xdbd00037,0x00000000,0x00000000}},	//   _snmt, _tüür, --, --, 
   {{0x28a8385b,0x8ca4073d,0x2c00010b,0xb7b401ec}},	//   च्छि, _चारो, пүрм, _ﺼﻴﺎﻏ, 
   {{0x2904385c,0x2b4c385d,0x6c540212,0x00000000}},	//   _alla_, _chec_, стує, --, 
   {{0x394c0048,0x62940076,0x29040200,0x00000000}},	//   _phds_, _mdyo, _blla_, --, 
   {{0x4934177b,0xb4e40037,0xdb1c0254,0x00000000}},	//   азію_, _पचे_, lvpü, --, 
   {{0x4784385e,0x62942892,0xd7e400d4,0xb7d8009a}},	//   асым_, _odyo, ріло, اوبا_, 
   {{0x2904385f,0x68e002c4,0x8f980bd9,0x62940a49}},	//   _ella_, _enld, דיקי, _ndyo, 
   {{0x18a43860,0x98a400d8,0x91800051,0xea6400e5}},	//   _вазм, _визе, _mệt_, _اھمی, 
   {{0xd9443861,0x62943862,0xc8e400ec,0x5dcc0150}},	//   _тези, _adyo, _پڙهه_, _ﻗﺴﻤﻴ, 
   {{0x1cb8031c,0x6cd8008f,0xfb0001e1,0x00000000}},	//   _ཙིན_, אַרצ, _áàsì_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8b54008d,0x50640801,0x290400a2,0x201c0162}},	//   ייטס_, итва, _ylla_, útin_, 
   {{0x629402b9,0xa3cc28fe,0x85541968,0x81b800cc}},	//   _edyo, रिख_, _پیپر_, ছিং_, 
   {{0xc05819b6,0xb1e404a9,0x00000000,0x00000000}},	//   لشفا_, рәққ, --, --, 
   {{0x2fcc068f,0x40343863,0xc438011a,0x00000000}},	//   łego_, цесс, _שתהי, --, 
   {{0x705401d9,0x62980153,0xd24c01e2,0x00000000}},	// [3610] _گندا, ėtot, _ډنډ_, --, 
   {{0x7944007f,0xaa4401e0,0xf004014b,0x00000000}},	//   fòwm, ҙелл, _лӯби, --, 
   {{0x705404fb,0x91640241,0x00000000,0x00000000}},	//   _دندا, bọ̀n_, --, --, 
   {{0x33380204,0x00000000,0x00000000,0x00000000}},	//   nosx_, --, --, --, 
   {{0x66e4012c,0xa8b80166,0x00000000,0x00000000}},	//   कासक_, гыйф_, --, --, 
   {{0x31683864,0x78640075,0x7c28009b,0xf53801e4}},	//   _muaz_, يدىك, _ždre, joĥ_, 
   {{0x29043865,0x98a03866,0x00000000,0x00000000}},	//   _vlla_, чище, --, --, 
   {{0x661c000f,0x8aa400f1,0xa6c8009d,0xa6e401c4}},	//   úsko, _خپرې_, улиа_, сжил, 
   {{0xa3a80490,0x9f5c2fda,0x3a7400d8,0x00000000}},	//   गून_, áté_, _флур, --, 
   {{0x29043867,0xf4940212,0x93e008e9,0x24e80022}},	//   _ulla_, орюю, गमंच_, умои_, 
   {{0xf86830bf,0x00000000,0x00000000,0x00000000}},	//   _ضمني_, --, --, --, 
   {{0x0514015b,0x31680166,0xf6d43868,0xdb1003b2}},	//   ঠকের_, _buaz_, _وزند, ógøt, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa3cc10f7,0xd0043869,0xdee4386a,0x3020013e}},	//   रिओ_, бере_, бови, ҷҷӯҳ, 
   {{0x6294386b,0x3338386c,0x00000000,0x00000000}},	//   _udyo, cosx_, --, --, 
   {{0x5e48386d,0xd180013d,0x00000000,0x00000000}},	// [3620] упам_, _елый, --, --, 
   {{0xa0c4386e,0x00000000,0x00000000,0x00000000}},	//   _ايدو, --, --, --, 
   {{0x1fb4386f,0xa3cc28d4,0x9b440014,0x00000000}},	//   _успр, रिट_, ٕناو, --, 
   {{0x9f940254,0xbae402dd,0x6e2801ef,0x00000000}},	//   _müüv_, _ﺍﻗﺒﺎ, _žebe, --, 
   {{0xd94431de,0xd9181b04,0x776801a9,0x00000000}},	//   беди, льк_, _sudx, --, 
   {{0x7f443870,0x2a6800d7,0x00000000,0x00000000}},	//   lliq, ľaba_, --, --, 
   {{0x5bf41973,0x2a6801a6,0x00000000,0x00000000}},	//   _آزا, žaba_, --, --, 
   {{0x7bdc3871,0x9b6800fb,0x7f44290f,0x00000000}},	//   _irru, _ашҡа_, nliq, --, 
   {{0x7f440d04,0x1a043872,0x9214000d,0x00000000}},	//   iliq, _упам, _पेंड़_, --, 
   {{0x7bdc0200,0x00000000,0x00000000,0x00000000}},	//   _krru, --, --, --, 
   {{0x201c3873,0x584400cf,0x00000000,0x00000000}},	//   útil_, _اپاق, --, --, 
   {{0xa3cc05f9,0xf1b800c7,0x00000000,0x00000000}},	//   रिज_, аӡо_, --, --, 
   {{0x15740050,0x66e43874,0xc1b8115c,0x7f4403b9}},	//   _أتھ_, कारक_, блях_, dliq, 
   {{0xf0e804a9,0x7bdc3875,0x00000000,0x00000000}},	//   جىسى_, _orru, --, --, 
   {{0x5ed000eb,0x00000000,0x00000000,0x00000000}},	//   হানে, --, --, --, 
   {{0x7f440cfe,0x6b6400c0,0xa3740345,0x00000000}},	//   gliq, _mėgt, _بخوڵ, --, 
   {{0x7bdc3876,0x6b740213,0x00000000,0x00000000}},	// [3630] _arru, _işgə, --, --, 
   {{0x8c64005e,0x7f443877,0x7528013f,0x7bdc0200}},	//   стад, aliq, nndz, _brru, 
   {{0x7f443878,0x2c180b40,0x41740acb,0x28d800cd}},	//   bliq, _येशू_, _وایس, _योषि, 
   {{0x2fc001b8,0x672c3879,0x7f44387a,0x00000000}},	//   _iphg_, čajk, cliq, --, 
   {{0x6f0c387b,0x69340372,0x7bdc387c,0x29c80032}},	//   mhac, онду, _erru, ртеү_, 
   {{0xd36430a7,0x6b640153,0x00000000,0x00000000}},	//   _يه_, _bėgt, --, --, 
   {{0xd6e0033f,0x00000000,0x00000000,0x00000000}},	//   kołę_, --, --, --, 
   {{0x6f0c387d,0xdecc044e,0x95140135,0x752802c4}},	//   nhac, _ጥዕና_, ྲིའི_, endz, 
   {{0x9f4806af,0x1fc400bc,0x00000000,0x00000000}},	//   ômée_, _लन्ड, --, --, 
   {{0xefe0069c,0x26d801f1,0xe3b0027d,0x98ac054e}},	//   _ናይዚ_, ôsob_, ورج_, rofă_, 
   {{0x6f0c387e,0x6d44387f,0xd6cc0403,0xd88412ea}},	//   khac, ilha, رقی_, _ذهنی, 
   {{0x6d440112,0xdee8001f,0x00000000,0x00000000}},	//   hlha, ኘቱን_, --, --, 
   {{0x6f0c3880,0x2d4c3881,0x21683882,0x67283883}},	//   dhac, _džez_, риги_, mnej, 
   {{0x67283884,0x627c033f,0x657803ac,0x05cc3885}},	//   lnej, dłoż, _itwh, _तैयब, 
   {{0xdea03886,0x6b6402d5,0x6d443887,0xefe002d3}},	//   ویدی, _mėgs, dlha, _ናይዛ_, 
   {{0x7f440cfe,0x6f0c3888,0x6d441196,0xe29806c4}},	//   uliq, ghac, elha, _таи_, 
   {{0x7f442631,0x67283889,0x57a40dba,0xaf340014}},	// [3640] rliq, inej, _गम्ह, سرِت, 
   {{0x69d8192e,0x6728388a,0xbae401ec,0x660c010b}},	//   dvwe, hnej, _ﺍﻗﺘﺎ, _ýaku, 
   {{0x7f44388b,0x6f0c388c,0x5bc4388d,0x6728388e}},	//   pliq, bhac, تقال, knej, 
   {{0x6f0c388f,0x67283890,0xa0c400db,0x6d4400d8}},	//   chac, jnej, _ايگو, alha, 
   {{0x6d4400a9,0x752800d0,0x6d500784,0x6b640064}},	//   blha, yndz, çhañ, _bėgs, 
   {{0x1d083891,0x67280108,0x7bdc0200,0x2f2000c0}},	//   _теги_, enej, _trru, bėgs_, 
   {{0x7bdc3892,0x657814dc,0x66e401ad,0x00000000}},	//   _urru, _atwh, कांक_, --, 
   {{0x3cf8030a,0x67280219,0xd5b83893,0x35f4011c}},	//   _horv_, gnej, асо_, зпир, 
   {{0x3cf83894,0x4ab001c4,0x00000000,0x00000000}},	//   _korv_, _цөхр, --, --, 
   {{0x75283895,0x2bd00037,0x672801f4,0x00000000}},	//   undz, _सनमा, anej, --, 
   {{0x67283896,0xd7c83897,0x657802d0,0x627c012d}},	//   bnej, _خواه_, _etwh, złoż, 
   {{0x672801a2,0x61e0151c,0x62880241,0x55e400d8}},	//   cnej, _šola, _àló, _моеб, 
   {{0x7d1c01fa,0xdce40306,0x7ae4005b,0x6f0c007c}},	//   _omrs, _aukč, öity, vhac, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6f0c3898,0x6b503899,0xf8f80051,0x00000000}},	//   thac, låge, _đợt_, --, 
   {{0x212801c3,0xc330215c,0x244801c8,0x00000000}},	//   anbh_, _لەپ_, _اجهي_, --, 
   {{0x6d44389a,0x0dc8036b,0x6f0c389b,0xbf380212}},	// [3650] tlha, шуви_, rhac, ізує_, 
   {{0x6728389c,0x3cf807c5,0x7c28110c,0xef6401c6}},	//   znej, _corv_, _ždra, _нэмү, 
   {{0x6f0c389d,0x672803f0,0xdbd40037,0x6d4402d0}},	//   phac, ynej, jääg, rlha, 
   {{0x6f0c0227,0x7d1c0083,0x67280419,0x00000000}},	//   qhac, _emrs, xnej, --, 
   {{0x6728389e,0x6f1c00c6,0x49c8389f,0xa9683417}},	//   vnej, _imsc, руем_, щила_, 
   {{0x69dc0077,0x6ef003cd,0x9e58011a,0x00000000}},	//   _ásem, _råby, _לכרט, --, 
   {{0x672838a0,0x3d000574,0xa88801e0,0x00000000}},	//   tnej, _शकते_, айһа_, --, 
   {{0xba740131,0x6ef01f53,0x6b5001e3,0x00000000}},	//   _ياقت, _påby, fåge, --, 
   {{0x672838a1,0x3b640395,0x00000000,0x00000000}},	//   rnej, _църв, --, --, 
   {{0x672838a2,0xe4d438a3,0x6f1c0857,0x239400e2}},	//   snej, ستخب, _lmsc, tāj_, 
   {{0x6f1c0cf9,0x6288016b,0x5ed002f5,0x672838a4}},	//   _omsc, _ɑfof, হাতে, pnej, 
   {{0x6b5001e3,0x98ac38a5,0xd7b8011a,0xe5f400db}},	//   båge, rofą_, _לצער, _ىكاد, 
   {{0xdce40006,0x9f5c00bc,0xd6d40133,0x25d801af}},	//   _sukč, átí_, _رووش_, _ымды_, 
   {{0x6f1c38a6,0xb6440150,0xfd54002b,0x00000000}},	//   _amsc, _ﺎﺓ_, bdeṣ, --, 
   {{0xdee438a7,0xd004151e,0x9f5c012c,0x78bc38a8}},	//   пови, пере_, ští_, _örve, 
   {{0x7d1c07f5,0xdce42625,0x6f1c02d0,0x6d580129}},	//   _smrs, _vukč, _cmsc, ïwan, 
   {{0xdea001d3,0x00000000,0x00000000,0x00000000}},	// [3660] ویگی, --, --, --, 
   {{0x6f1c324c,0x6b18031c,0x60080a89,0x3e7c0118}},	//   _emsc, ྱིའོ_, _гном_, dátů_, 
   {{0x1fb40474,0xc0d800b7,0x00000000,0x00000000}},	//   _эспр, ርኤል_, --, --, 
   {{0xdf14074d,0x9f480241,0x00000000,0x00000000}},	//   _хьоь, _ìjàn_, --, --, 
   {{0xda1400af,0x3cf812e8,0x497038a9,0x5ed00011}},	//   _देखत_, _torv_, еліс, হাদে, 
   {{0x6b500623,0x00000000,0x00000000,0x00000000}},	//   våge, --, --, --, 
   {{0x24980092,0x00000000,0x00000000,0x00000000}},	//   _መሠራት_, --, --, --, 
   {{0x24980201,0x6b5038aa,0xdbd40254,0x6e340cad}},	//   _መሠረት_, tåge, rääg, _ìgbé, 
   {{0xb6c800dd,0xceb0008f,0x998401d9,0x18a400f7}},	//   ماکے_, גיח_, _رلاو, _наам, 
   {{0xf7780327,0xd1c00023,0x6b50007c,0x00000000}},	//   _erħa_, _ትኣቱ_, råge, --, 
   {{0x85b40a81,0x6b50007c,0xccf0011a,0x00000000}},	//   _ہاوس_, såge, תכת_, --, 
   {{0xaa2801d9,0x95c80064,0x00000000,0x00000000}},	//   _اسہٕ_, _гука_, --, --, 
   {{0xc6900a1e,0xd08400ee,0xa2cc00bc,0x41e41cd0}},	//   _נאס_, зыби, _तसर्, ніра, 
   {{0x65c000b5,0x6f1c03ef,0x8658011a,0x00000000}},	//   のhan, _smsc, _הדדי, --, 
   {{0x337401b9,0xc0580d30,0x00000000,0x00000000}},	//   _ўгир, зіт_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69dc06ed,0xf1b01af8,0xfe702004,0x6b180327}},	// [3670] _àsex, _जमिन, ادف_, ྱིལོ_, 
   {{0x661c0413,0x00000000,0x00000000,0x00000000}},	//   úski, --, --, --, 
   {{0xe4ec03f8,0x00000000,0x00000000,0x00000000}},	//   जाति_, --, --, --, 
   {{0xf1b01533,0x6f1c03fa,0x611406be,0x00000000}},	//   _जमान, _umsc, _təlü, --, 
   {{0xdb1c022c,0xa9f8012c,0xa11400f1,0x00000000}},	//   ðvág, ्नेछ_, _رسیږ, --, 
   {{0x3e7c012c,0xac1838ab,0xa8240753,0xa7780063}},	//   rátů_, _догу_, وکان, ољих_, 
   {{0x7b0801ed,0xbb54037e,0x8464010b,0xa2cc230e}},	//   ártó, _webに_, үзиң_, _तसल्, 
   {{0xe57838ac,0x00000000,0x00000000,0x00000000}},	//   ози_, --, --, --, 
   {{0xdce402b5,0xe6181d9c,0xc98438ad,0x00000000}},	//   _hukā, юди_, _хуби, --, 
   {{0xf7700272,0x61e00010,0xdce40055,0x00000000}},	//   _ڵام_, _šolo, _kukā, --, 
   {{0xdce400ef,0x00000000,0x00000000,0x00000000}},	//   _jukā, --, --, --, 
   {{0xdce400b0,0x2d980010,0xaf940023,0x7dd800e5}},	//   _mukā, _ovse_, ውኣትና_, núsá, 
   {{0xd70402bf,0xc6481411,0x00000000,0x00000000}},	//   _інше_, _اجال_, --, --, 
   {{0x672c110c,0x7dd8007b,0x00000000,0x00000000}},	//   čaju, húsá, --, --, 
   {{0x23342c1d,0x50400261,0x2d981141,0x5ef8030d}},	//   _охир, верб, _avse_, охар_, 
   {{0x6d5438ae,0x7dd801ed,0xd15c0023,0xb5940244}},	//   _ahza, júsá, ተረፈን_, _تێیا_, 
   {{0xdce438af,0xddc40034,0xa3a80c70,0xe0d800f5}},	// [3680] _aukā, _szkł, गूर_, _двп_, 
   {{0x51f401ed,0xed3401c6,0x6284031c,0x23d000cd}},	//   _آسٹر, нэхэ, lbko, _तनाद, 
   {{0x62840218,0x00000000,0x00000000,0x00000000}},	//   obko, --, --, --, 
   {{0xe51c38b0,0xec3438b1,0x00000000,0x00000000}},	//   योति_, رونگ, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd5e00051,0x00000000,0x00000000,0x00000000}},	//   _ngó, --, --, --, 
   {{0xabc400fb,0x00000000,0x00000000,0x00000000}},	//   _парҙ, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4a4036cd,0x59740024,0x00000000,0x00000000}},	//   _антв, _цыбу, --, --, 
   {{0x0ef803ba,0x62840327,0x3f98025c,0x6b5001e3}},	//   _एक्स_, ebko, ksru_, måga, 
   {{0x2be01524,0x225000ee,0xa3a80d2c,0x200c0135}},	//   फिया, _azyk_, गूल_, _żfin_, 
   {{0x3d0400a2,0x00000000,0x00000000,0x00000000}},	//   _döwi_, --, --, --, 
   {{0x672c151c,0x2c74032e,0x00000000,0x00000000}},	//   čajt, _júdó_, --, --, 
   {{0x7dd801d3,0x657c0332,0x00000000,0x00000000}},	//   zúsá, íshe, --, --, 
   {{0x8d5c0020,0x628401e3,0x2c740241,0x00000000}},	//   ታወቀው_, bbko, _lúdó_, --, 
   {{0x98ac0210,0x00000000,0x00000000,0x00000000}},	//   rofę_, --, --, --, 
   {{0x98bc0100,0xdce41619,0x00000000,0x00000000}},	// [3690] _aktč_, _sukā, --, --, 
   {{0xcc080d2f,0x705838b2,0x3f98031c,0x00000000}},	//   يزان_, _напр_, bsru_, --, 
   {{0xfe7000f8,0x28d80882,0x1ea800f1,0x00000000}},	//   ادہ_, _योगि, _کاپي_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x01342263,0x63bc054e,0xa9a426ef,0x7dd838b3}},	//   _سعید, ăsni, хилд, rúsá, 
   {{0xa3a807f7,0x2bd800e5,0x940c05c0,0x660c0210}},	//   गूँ_, _ٹاسک_, ानाच_, _żako, 
   {{0x58280135,0x5ed0015b,0xdc440374,0xac5838b4}},	//   _སྨྱོ_, হারে, _tūāp, _хавф_, 
   {{0xd6cc0131,0x6b5001e3,0x00000000,0x00000000}},	//   مقى_, båga, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2918009f,0x37a8013d,0x00000000,0x00000000}},	//   _عقاد_, чтән_, --, --, 
   {{0x7bc8025a,0x64a4013e,0x6e280219,0x78bc08a5}},	//   _âdut, _ҷала, _žebl, _örva, 
   {{0x672c1224,0x62840118,0xf77038b5,0x00000000}},	//   čajs, ubko, _ئال_, --, 
   {{0x64a438b6,0xdfd038b7,0xa06838b8,0x62840112}},	//   _зала, گيز_, зага_, rbko, 
   {{0xe04400cf,0x8cd0012d,0x15f8011a,0x00000000}},	//   енги, ड़फो, _מהנע, --, 
   {{0xdfd000aa,0x61440209,0x00000000,0x00000000}},	//   ديز_, _җена, --, --, 
   {{0xdcb81e61,0x2a6c016d,0x25ac0165,0xbb480150}},	//   ैज्ञ, _ngeb_, ouel_, _ﺇﺭﻫ_, 
   {{0x3f980003,0x00000000,0x00000000,0x00000000}},	// [36a0] ssru_, --, --, --, 
   {{0x6b500158,0x00000000,0x00000000,0x00000000}},	//   våga, --, --, --, 
   {{0x26cc06c8,0x25ac38b9,0xda7800a7,0x5ac8010b}},	//   keeo_, huel_, пял_, злем_, 
   {{0x25ac38ba,0x2bd00d2e,0x6b50007c,0x00000000}},	//   kuel_, _सनरा, tåga, --, 
   {{0x61e038bb,0x00000000,0x00000000,0x00000000}},	//   _šolj, --, --, --, 
   {{0x6b50049f,0x2a6c01e1,0x25ac06af,0xd7f80107}},	//   råga, _egeb_, duel_, зуи_, 
   {{0x6b5001e3,0x1e2c0092,0x00000000,0x00000000}},	//   såga, _በመጠና, --, --, 
   {{0x25ac38bc,0xd90c2ab4,0x00000000,0x00000000}},	//   fuel_, _گیت_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd90c38bd,0xa9741fbe,0x00000000,0x00000000}},	//   _دیت_, _јутј, --, --, 
   {{0x05b41208,0x798003ac,0x07a034cb,0x00000000}},	//   ودیت_, _htmw, _бахн, --, 
   {{0x798002d0,0xd244009d,0x00000000,0x00000000}},	//   _ktmw, еэги, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x506438be,0xdb0808ce,0x00000000,0x00000000}},	//   етба, _ínæs, --, --, 
   {{0xb4ac38bf,0x403438c0,0x5344030d,0x00000000}},	//   गली_, герс, _пхиа, --, 
   {{0x09b8025c,0x1c1c0073,0xca3400d1,0xb80400dc}},	//   _མྱྀ_, _येइल_, ﯕﻼﺭ_, _spṛś, 
   {{0xca6801d5,0x7ee400c7,0x00000000,0x00000000}},	// [36b0] digа, ыцре, --, --, 
   {{0x0f280092,0x48d800cc,0x00000000,0x00000000}},	//   _ተፈራረ, _বক্ৰ, --, --, 
   {{0x798003ac,0x25ac04e6,0xec14027d,0x00000000}},	//   _atmw, zuel_, خواد, --, 
   {{0xa5a00034,0xf9f800cc,0xf9900133,0x28d807b7}},	//   _खिलौ, _আইজল_, ڵبه_, _योजि, 
   {{0x25ac38c1,0xbf140166,0xc9840124,0x00000000}},	//   xuel_, _сүтә, хуеи, --, 
   {{0x20380092,0x00000000,0x00000000,0x00000000}},	//   _የስብከ, --, --, --, 
   {{0xe73838c2,0x25ac0a40,0x00000000,0x00000000}},	//   мек_, wuel_, --, --, 
   {{0x25ac38c3,0x00000000,0x00000000,0x00000000}},	//   tuel_, --, --, --, 
   {{0x6b50007c,0x00000000,0x00000000,0x00000000}},	//   lågo, --, --, --, 
   {{0x25ac21fc,0x69c838c4,0xf5b4011c,0x00000000}},	//   ruel_, _ipee, усъю, --, 
   {{0x25ac38c5,0xd6d401d5,0xe28406dc,0x344400d1}},	//   suel_, رویش_, клни, лүши_, 
   {{0x60cc38c6,0x00000000,0x00000000,0x00000000}},	//   webm, --, --, --, 
   {{0x25ac38c7,0x1c1c05ba,0x1a98010f,0x00000000}},	//   quel_, _येईल_, וירע, --, 
   {{0x64a438c8,0x69c80a49,0xf8c400dc,0xc0500092}},	//   _рака, _mpee, ल्पय, _ቀድሞው, 
   {{0x69dc0142,0x6b5001bf,0x3db80154,0x00000000}},	//   _âsef, vågn, ুয়াল, --, 
   {{0x69c838c9,0x1ea806c7,0x00000000,0x00000000}},	//   _opee, باسي_, --, --, 
   {{0x69c80218,0xd24c0046,0x9e6438ca,0x00000000}},	// [36c0] _npee, _ونى_, твад, --, 
   {{0x4c8038cb,0x798003ac,0xd25400d9,0x00000000}},	//   илув, _rtmw, _בשפה_, --, 
   {{0x69c838cc,0x6b50049f,0x7b3c0841,0x1fa801a9}},	//   _apee, rågn, nčug, _юкни_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xceb004ac,0x98bc0171,0x00000000,0x00000000}},	//   _דיר_, _aktā_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc010001e,0x69c838cd,0x00000000,0x00000000}},	//   _đuổi_, _epee, --, --, 
   {{0xc620015b,0x18340214,0x5b340006,0x00000000}},	//   _পড়া_, _یراح, _рэгу, --, 
   {{0x948438ce,0xa2d4090a,0x00000000,0x00000000}},	//   кынд, यजन्, --, --, 
   {{0xb4ac205d,0x2bc803ce,0x00000000,0x00000000}},	//   गले_, _रहमा, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf48403e6,0x046000db,0x2f14007c,0x5eb800eb}},	//   _ڵاتی, штым, _kåge_, উজডে, 
   {{0x69dc0579,0x7e6000d2,0x8334188c,0xc3c001c0}},	//   _áset, _úmph, рнях, гөөл, 
   {{0x349438cf,0x53e40022,0x2f1401bf,0xc0c80108}},	//   _сакр, _ациа, _måge_, кусе_, 
   {{0x7f9438d0,0x752838d1,0xe7e438d2,0x2f1400fe}},	//   иарх, midz, किया_, _låge_, 
   {{0x752838d3,0x6b5001e3,0xee200150,0x00000000}},	//   lidz, vågo, бебi_, --, 
   {{0xfd7405f5,0x2d9c003e,0x2f14007c,0xdde00b97}},	// [36d0] илтэ, éwe_, _någe_, ğuşu, 
   {{0x75281cbd,0xac1838d4,0x00000000,0x00000000}},	//   nidz, нозу_, --, --, 
   {{0x69c838d5,0x8c6438d6,0x00000000,0x00000000}},	//   _spee, ттад, --, --, 
   {{0x752838d7,0x6b5001e6,0x7b3c05ce,0x69c804ba}},	//   hidz, rågo, jčud, _ppee, 
   {{0x8d8438d8,0x6f0c38d9,0x75280e8a,0x00000000}},	//   _шунд, mkac, kidz, --, 
   {{0x6f0c38da,0xb4ac38db,0x6da400c7,0xe5a40131}},	//   lkac, गलो_, _ииҭа, ңийи, 
   {{0x6d4438dc,0x752838dd,0xb4ac0dba,0x68440024}},	//   moha, didz, गलै_, ынка, 
   {{0x6d4438de,0x6f0c38df,0x00000000,0x00000000}},	//   loha, nkac, --, --, 
   {{0x660438e0,0x7528004c,0xf9d40166,0x69c838e1}},	//   уппа, fidz, _котэ, _upee, 
   {{0x6d4438e2,0x7528003c,0x7c281710,0x27e438e3}},	//   noha, gidz, _ždri, _trln_, 
   {{0x6f0c38e4,0x98bc00cd,0x00000000,0x00000000}},	//   kkac, _uktā_, --, --, 
   {{0x6d4438e5,0x7528004c,0x48e800bc,0x6f0c1a54}},	//   hoha, aidz, चाको_, jkac, 
   {{0x672838e6,0xe5a438e7,0x6f0c0034,0x00000000}},	//   miej, _сили, dkac, --, 
   {{0x6d4438e8,0x660838e9,0x672802d5,0x21c0013f}},	//   joha, myek, liej, _wɔho_, 
   {{0x26dc3142,0x6d4438ea,0x660800dd,0xa2e438eb}},	//   _kawo_, doha, lyek, _бойд, 
   {{0x26dc23db,0x672838ec,0x31cc02dd,0x7c2006be}},	//   _jawo_, niej, _ﺑﻴﯩﻜ, _əmrd, 
   {{0x6d440170,0x26dc38ed,0x6294037e,0x7f44022e}},	// [36e0] foha, _mawo_, _ieyo, roiq, 
   {{0x26dc19f8,0x629438ee,0x6f0c38ef,0x6d4438f0}},	//   _lawo_, _heyo, akac, goha, 
   {{0x672838f1,0x92d403d4,0x6f0c38f2,0x6c7401c6}},	//   kiej, সাৰ_, bkac, руух, 
   {{0x26dc38f3,0x6d440069,0x752838f4,0x6294033b}},	//   _nawo_, aoha, zidz, _jeyo, 
   {{0x6d44035b,0x752838f5,0x672838f6,0x21280e9e}},	//   boha, yidz, diej, oibh_, 
   {{0x629438f7,0x60dc0113,0x2f142dba,0x6d4438f8}},	//   _leyo, _japm, _våge_, coha, 
   {{0x60dc38f9,0x752838fa,0x26dc38fb,0x212801ab}},	//   _mapm, vidz, _bawo_, iibh_, 
   {{0x26dc38fc,0x60dc38fd,0x672838fe,0x752838ff}},	//   _cawo_, _lapm, giej, widz, 
   {{0x75283900,0x26dc3901,0x66083902,0x87000108}},	//   tidz, _dawo_, gyek, сяще, 
   {{0x60dc014f,0x2a3401c6,0x6f0c3903,0x00000000}},	//   _napm, _тэср, zkac, --, 
   {{0x6f0c0bf1,0x75281cbd,0xdb1c02d3,0x21280afe}},	//   ykac, ridz, jtpë, dibh_, 
   {{0xa3a81533,0x6d443904,0x26dc055a,0x66083905}},	//   गंज_, zoha, _gawo_, byek, 
   {{0x6d443906,0x66080526,0xd20805f5,0x62943907}},	//   yoha, cyek, хэнд_, _deyo, 
   {{0x60dc3908,0x26dc0161,0x86340375,0x6f0c033f}},	//   _capm, _zawo_, _גאדג_, wkac, 
   {{0x6d443909,0x60dc0455,0x629402e2,0x20080142}},	//   voha, _dapm, _feyo, gybi_, 
   {{0xe7e40d2c,0x6294390a,0x6d44390b,0x26dc058a}},	//   किता_, _geyo, woha, _xawo_, 
   {{0x6f0c390c,0x6d44390d,0x3134390e,0x016c0023}},	// [36f0] rkac, toha, _вепр, ተረኽበ_, 
   {{0x6f0c390f,0x67280006,0x50a00131,0x62943910}},	//   skac, ziej, _دەسل, _zeyo, 
   {{0x6d443911,0x62943912,0x70543296,0x2d0403ce}},	//   roha, _yeyo, _خندا, _शकील_, 
   {{0xdeb00046,0x8d743913,0x645c00ac,0x6608009a}},	//   _мұсы, _ماسا, əsid, yyek, 
   {{0x60dc0ab7,0x67283914,0x6d443915,0x26dc3916}},	//   _yapm, viej, poha, _rawo_, 
   {{0x26dc3917,0xad240075,0x2d880393,0x0b943918}},	//   _sawo_, _ئىسى, mpae_, _مجرد, 
   {{0x26dc3919,0x6728391a,0x69d400e1,0x2d8816b8}},	//   _pawo_, tiej, _मैरी, lpae_, 
   {{0x2d9c27c4,0x6608391b,0x00000000,0x00000000}},	//   šweu_, tyek, --, --, 
   {{0x6294391c,0x2d880354,0x26dc004c,0x6728391d}},	//   _reyo, npae_, _vawo_, riej, 
   {{0x6294391e,0x26dc391f,0x67283920,0x9f5c007b}},	//   _seyo, _wawo_, siej, átú_, 
   {{0x26dc3921,0x60dc014f,0x630400f1,0x67283922}},	//   _tawo_, _rapm, لودل, piej, 
   {{0x60dc3923,0xf8043924,0x23281d16,0x62643925}},	//   _sapm, _учун, томи_, ивна, 
   {{0x66080369,0x60dc01bf,0x21280afe,0x00000000}},	//   qyek, _papm, tibh_, --, 
   {{0x25ac01f1,0x62943926,0x60dc3927,0x00000000}},	//   mrel_, _weyo, _qapm, --, 
   {{0x5f043928,0x6e3c020c,0xdfd00597,0x1e943929}},	//   азва, _axsb, غير_, ирар, 
   {{0x60dc392a,0x645c0194,0x38ac01e1,0xdb1c0240}},	//   _wapm, ęsid, _kórà_, rtpë, 
   {{0x25ac0936,0xa15406bb,0x60dc392b,0xdef80032}},	// [3700] nrel_, _външ, _tapm, ныҡ_, 
   {{0xdca4392c,0x5f740532,0xccf401f0,0x600800f3}},	//   ражи, _پادر, ққӣ_, _аном_, 
   {{0x2d88013f,0x61e4392d,0xa0681fbe,0x00000000}},	//   apae_, lvkl, _јана_, --, 
   {{0xdee4392e,0x25ac392f,0xdb14013d,0xf38c010f}},	//   _томи, krel_, _äbüz, גראָ, 
   {{0x79540133,0x00000000,0x00000000,0x00000000}},	//   مێرا, --, --, --, 
   {{0x97a43930,0x660c09a5,0x25ac3931,0x48700131}},	//   арил, _ýaky, drel_, يدىس, 
   {{0x81cc015b,0x8ba001b9,0x25ac3932,0xc82001e4}},	//   রটি_, _мирж, erel_, menһ, 
   {{0x3990025a,0x7bdc3933,0xec3401d5,0x25ac0175}},	//   gôsî_, _isru, _اوفگ, frel_, 
   {{0xc6f43934,0x25ac3935,0x140c07f7,0x2b380276}},	//   рных_, grel_, ान्ह_, _сярэ_, 
   {{0x7ae030f4,0x81cc015b,0xd90c37f7,0x61e40427}},	//   _hamt, রটা_, _زیب_, dvkl, 
   {{0x7ae03936,0x25ac3937,0x2f1401e6,0x00000000}},	//   _kamt, arel_, _låga_, --, 
   {{0x7ae02611,0xf0e82b62,0x00000000,0x00000000}},	//   _jamt, گىسى_, --, --, 
   {{0x948400cf,0x00000000,0x00000000,0x00000000}},	//   _кыйд, --, --, --, 
   {{0xf0e816a0,0x2d040490,0x7ae03938,0xdde003b9}},	//   دىسى_, _शकेल_, _lamt, _şuşi, 
   {{0x61e03939,0x2f1801c6,0x00000000,0x00000000}},	//   _šolt, говь_, --, --, 
   {{0x7ae0393a,0x00000000,0x00000000,0x00000000}},	//   _namt, --, --, --, 
   {{0x7bdc393b,0xb63800b5,0xd14801d5,0xe51c033f}},	// [3710] _asru, _ｄｎ_, _لشدن_, योकि_, 
   {{0x3f78009b,0xbcf4234c,0xe2a4032e,0x78bc02d2}},	//   _očuh_, опущ, _æðra_, _örvh, 
   {{0xaff805d9,0x25ac00d0,0x2d88003a,0x00000000}},	//   _صفحا_, zrel_, spae_, --, 
   {{0x7ae0393c,0x25ac0194,0x2d880381,0x00000000}},	//   _camt, yrel_, ppae_, --, 
   {{0x7ae0393d,0x394c0337,0x7bdc00b5,0xba74393e}},	//   _damt, _bkds_, _esru, زانت, 
   {{0x65ac1aa1,0x7ae0127b,0x25ac0419,0x00000000}},	//   _ṱhog, _eamt, vrel_, --, 
   {{0xfb840024,0x1ad400fe,0x00000000,0x00000000}},	//   _мытн, _সচৰা, --, --, 
   {{0x25ac393f,0x7ae03940,0x98b40116,0x00000000}},	//   trel_, _gamt, аләт_, --, 
   {{0xe2983941,0x25ac3942,0xa5243943,0xe69400db}},	//   һан_, urel_, ймид, _ۇلاد, 
   {{0x7ae03944,0x25ac3945,0x263c01e4,0x00000000}},	//   _zamt, rrel_, rʈo_, --, 
   {{0xe2983946,0xe8543947,0x7ae03948,0x68e003ac}},	//   лан_, _اناد, _yamt, _iald, 
   {{0x29043949,0x68e0394a,0x2d84389e,0x332805da}},	//   _hola_, _hald, _člen_, _cmax_, 
   {{0x68e0394b,0x80ac00af,0x3cf8000d,0x00000000}},	//   _kald, _जयदे, _उचले_, --, 
   {{0x61e00fb7,0x68e0394c,0x69d804e6,0x3074005b}},	//   _šols, _jald, iwwe, жутс, 
   {{0x68e0394d,0x6578394e,0xa07402dd,0x2f140267}},	//   _mald, _huwh, _қыпш, _såga_, 
   {{0x657802b5,0x68e00978,0xc18401d3,0x53300798}},	//   _kuwh, _lald, _ویجٹ, _нејт, 
   {{0x2904394f,0x7ae0037e,0x68e000ad,0x5eb800eb}},	// [3720] _oola_, _ramt, _oald, উজলে, 
   {{0x7ae03950,0x29043951,0x68e03952,0x2f143953}},	//   _samt, _nola_, _nald, _våga_, 
   {{0x7ae03954,0x716400f7,0x0d203955,0x9a843956}},	//   _pamt, _بايك, чүрү, булл, 
   {{0x29043957,0x33283958,0x7ae03959,0x68e00582}},	//   _aola_, _xmax_, _qamt, _aald, 
   {{0x68e0395a,0x7ae00218,0xddc40034,0x4e2400ee}},	//   _bald, _vamt, _wykł, _гоян_, 
   {{0x7ae0395b,0x3b0401e2,0x29040f85,0x22500254}},	//   _wamt, _womq_, _cola_, _myyk_, 
   {{0x68e0395c,0x2904395d,0x657800b0,0x779401d5}},	//   _dald, _dola_, _auwh, زیشا, 
   {{0x2904395e,0x68e0127b,0x00000000,0x00000000}},	//   _eola_, _eald, --, --, 
   {{0x68e0395f,0x99f4177b,0x18a4022e,0x00000000}},	//   _fald, _уяві, _газм, --, 
   {{0x68e03960,0x00000000,0x00000000,0x00000000}},	//   _gald, --, --, --, 
   {{0x33280334,0x73383961,0x00000000,0x00000000}},	//   _pmax_, изор_, --, --, 
   {{0x23a81533,0x68e03962,0x2d0405f9,0xd5b803fb}},	//   _किरद, _zald, _शक्ल_, _бск_, 
   {{0x29043963,0x68e01f02,0xd24401c6,0x7c2003e3}},	//   _yola_, _yald, сэни, _əmra, 
   {{0x463800c8,0x2904024c,0x68e01898,0x2bc8000d}},	//   _געדע, _xola_, _xald, _रहला, 
   {{0x33280395,0x1e2c0092,0x4ea401c6,0x00000000}},	//   _tmax_, _በመገና, йраа, --, 
   {{0x33280054,0xd9f80073,0x40340139,0x00000000}},	//   _umax_, ्हात_, чесс, --, 
   {{0x78a83964,0x00000000,0x00000000,0x00000000}},	// [3730] _oddv, --, --, --, 
   {{0xea9c037e,0xb33c0327,0x00000000,0x00000000}},	//   _mm幅_, rrħu, --, --, 
   {{0x4fc43965,0xd148036b,0x68e0022e,0x00000000}},	//   _успа, _لشگن_, _rald, --, 
   {{0x78a80334,0x52d402f5,0xaa5403f6,0x00000000}},	//   _addv, ধাকৃ, овеш, --, 
   {{0x29041709,0x68e03966,0x7bc80793,0x9a740032}},	//   _pola_, _pald, _ädun, әйәт_, 
   {{0xa9683967,0x68e03968,0x65783969,0x63a000bc}},	//   шила_, _qald, _ruwh, ysln, 
   {{0x68e0396a,0x2904396b,0x6b94033f,0x6578010e}},	//   _vald, _vola_, _uwzg, _suwh, 
   {{0x68e0396c,0xd6cc2dc3,0x657802b1,0x2904396d}},	//   _wald, نقى_, _puwh, _wola_, 
   {{0x68e0152d,0x6aa8396e,0xc1a805b3,0x2be001ad}},	//   _tald, _idef, _कटेग, फिका, 
   {{0x2904396f,0x68e02d19,0x756801d3,0x91bc03d4}},	//   _uola_, _uald, مینہ_, ইবাখ, 
   {{0x39400597,0x2f14007c,0x00000000,0x00000000}},	//   éise_, _någo_, --, --, 
   {{0x657804fe,0x6aa80327,0xdb1003b2,0xd7840244}},	//   _tuwh, _jdef, ðgøt, _بچوو_, 
   {{0x38880156,0x00000000,0x00000000,0x00000000}},	//   _étré_, --, --, --, 
   {{0xe3b03970,0x00000000,0x00000000,0x00000000}},	//   _قرب_, --, --, --, 
   {{0xa0683971,0x6aa83972,0x2f1401bf,0xfe780137}},	//   рава_, _odef, _vågn_, йүн_, 
   {{0x6aa83973,0x00000000,0x00000000,0x00000000}},	//   _ndef, --, --, --, 
   {{0x9e642162,0x6e283974,0xd12c01d3,0xdce40055}},	// [3740] زارن, _žebr, رمہ_, _utkī, 
   {{0x6aa83975,0xef180107,0x4d6000d4,0x00000000}},	//   _adef, амӣ_, дкув, --, 
   {{0x691c01e1,0x9b9401d5,0x200c032e,0xe1f000e5}},	//   _mèed, زلشت, _æfi_, _رسک_, 
   {{0x38c803e6,0x00000000,0x00000000,0x00000000}},	//   ڵاتی_, --, --, --, 
   {{0x3ea03976,0x6aa80cfd,0xd94400c9,0xf8b00344}},	//   mait_, _ddef, оеди, فکا_, 
   {{0x3ea03977,0x6aa83978,0xd850004e,0x00000000}},	//   lait_, _edef, мелө, --, 
   {{0xd7f81142,0x6aa8010a,0xe97019c5,0x00000000}},	//   рул_, _fdef, رۇمد, --, 
   {{0x3ea03979,0x38c8397a,0x96e80108,0x00000000}},	//   nait_, _گاری_, рька_, --, 
   {{0x18a4397b,0xdcec397c,0x89d40214,0x00000000}},	//   _ҳаҷм, _libč, _ووفر_, --, 
   {{0x38c8397d,0x30e404c5,0x3ea0397e,0x6aa821ed}},	//   _داری_, _নক্স, hait_, _zdef, 
   {{0x3ea0397f,0x7b3c0064,0x00000000,0x00000000}},	//   kait_, nčuo, --, --, 
   {{0x6aa80109,0x3ea03980,0x00000000,0x00000000}},	//   _xdef, jait_, --, --, 
   {{0x41e43981,0xdef40023,0xc1b801f4,0x00000000}},	//   міра, ለናን_, олях_, --, 
   {{0xe6e0005b,0x91481cd0,0x4a58011a,0x00000000}},	//   äköö, рчма_, ידכו, --, 
   {{0x3ea03982,0x94100605,0x5338010a,0xb5bc00eb}},	//   fait_, _ɛyɛ_, _вупă, _অনিচ, 
   {{0x3ea03983,0x00000000,0x00000000,0x00000000}},	//   gait_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3750] --, --, --, --, 
   {{0xed503984,0xc0f8001f,0x00000000,0x00000000}},	//   رپا_, ለታል_, --, --, 
   {{0x3ea03985,0x7bc80793,0x60d800c5,0xdcec0427}},	//   bait_, _ädul, õtme, _gibč, 
   {{0x8aa40220,0x3ea00072,0xb05401b9,0x00000000}},	//   іред, cait_, _وپکت, --, 
   {{0xa3e02793,0x9ba00131,0x5ef8011a,0x00000000}},	//   _नैन_, _ۋەكى, _הפרד, --, 
   {{0x279407d6,0x00000000,0x00000000,0x00000000}},	//   пшир, --, --, --, 
   {{0x8aa400c7,0xc5e007f7,0x64a40124,0x00000000}},	//   _мрад, कट्य_, ҟана, --, 
   {{0x6aa83986,0x21f0037e,0x7b3c00f3,0x9514031c}},	//   _udef, _jôhô_, nčul, ིིའི_, 
   {{0x80dc06ab,0x39400332,0x31d400cd,0x00000000}},	//   _फसले, éisc_, धबोध, --, 
   {{0x3ea03987,0xe3b807a5,0x00000000,0x00000000}},	//   zait_, ббо_, --, --, 
   {{0x3ea03988,0x6d880038,0xdc3c054e,0x63840024}},	//   yait_, _hľad, mţăm, ягна, 
   {{0x2d98062c,0xdc3c0311,0x3ea00129,0x04f80154}},	//   _owse_, lţăm, xait_, ইসের_, 
   {{0x3ea03989,0x2168398a,0x06c0015b,0xe2982cc8}},	//   vait_, йими_, ্যদি, _һай_, 
   {{0x645c11a9,0xdd90066d,0x00000000,0x00000000}},	//   əsin, ہور_, --, --, 
   {{0x3ea0398b,0xdd90004b,0xe298398c,0x24080276}},	//   tait_, ځور_, _лай_, _ынки_, 
   {{0xa0c400f1,0x00000000,0x00000000,0x00000000}},	//   _کيدو, --, --, --, 
   {{0x3ea0398d,0x00e400dd,0x6b50007c,0x00000000}},	// [3760] rait_, _ہتھی, hågs, --, 
   {{0x3ea0398e,0x00000000,0x00000000,0x00000000}},	//   sait_, --, --, --, 
   {{0x9f5c398f,0x9078011a,0x00000000,0x00000000}},	//   átó_, _לטיי, --, --, 
   {{0xd65c01ec,0x00000000,0x00000000,0x00000000}},	//   _сiзд, --, --, --, 
   {{0xceb01a4c,0x62840114,0x8e800022,0x6b500158}},	//   _איר_, icko, _áĝak, vågt, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8c403990,0x00000000,0x00000000,0x00000000}},	//   _зере, --, --, --, 
   {{0xd6840137,0x35f408da,0x7c2003e3,0x41dc0118}},	//   чукп, дпир, _əmrl, यबास, 
   {{0xda640150,0xd7f800d1,0xcad4011a,0x34940064}},	//   _ءازي, руһ_, _צומת_, мапр, 
   {{0x18a4036b,0x6b500267,0x00000000,0x00000000}},	//   _хажм, bågs, --, --, 
   {{0xb9dc044e,0x6d8800d7,0x85480023,0x73c40166}},	//   _ባህ_, _zľad, _ምጥፋእ, фәле, 
   {{0xc2b800d4,0x00000000,0x00000000,0x00000000}},	//   плює_, --, --, --, 
   {{0x02a401c6,0x00000000,0x00000000,0x00000000}},	//   эрэм, --, --, --, 
   {{0x27e8033f,0xe63800ec,0xd6bc00eb,0x00000000}},	//   łane_, _بيهڻ_, _আসিয, --, 
   {{0x3d000714,0x04c400ec,0x138800ae,0x00000000}},	//   राने_, _رويي_, _اختى_, --, 
   {{0x7ee40108,0x00000000,0x00000000,0x00000000}},	//   нцуе, --, --, --, 
   {{0xa2a00c2e,0x7b3c3991,0xb7b80154,0x00000000}},	// [3770] _ख़त्, rčul, _আনোয়, --, 
   {{0x52b000cf,0x00000000,0x00000000,0x00000000}},	//   _تەڭئ, --, --, --, 
   {{0x4fc40415,0x8c2000cc,0x00000000,0x00000000}},	//   _эспа, _বুজন_, --, --, 
   {{0x6b500250,0xadbc00c0,0x0f240354,0x00000000}},	//   vågs, _камi, _хьом, --, 
   {{0xbca80131,0x49c8005b,0xf98400d4,0xd5a402c9}},	//   زدەك_, суем_, егіо, _جف_, 
   {{0xf9903992,0x7b3c1b5c,0x2ee8009f,0x238400ef}},	//   ابن_, nčuj, ldaf_, _lēja_, 
   {{0x628401e6,0x18640ce1,0x00000000,0x00000000}},	//   ycko, маши_, --, --, 
   {{0xe6183993,0x7b3c13d5,0x2ee80042,0x00000000}},	//   жди_, hčuj, ndaf_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3d003994,0x6f1c002f,0x7b3c0118,0x00000000}},	//   राये_, _llsc, jčuj, --, 
   {{0x7b3c0306,0x2814072d,0x00000000,0x00000000}},	//   dčuj, _تواس, --, --, 
   {{0x37c80156,0x65940395,0x00000000,0x00000000}},	//   _གྱིད, _жаду, --, --, 
   {{0x2ee83995,0x84880023,0x3d003996,0xa91c00ef}},	//   ddaf_, መስልን_, रामे_, _atži, 
   {{0x6f1c03ac,0x72940124,0x26cc00e4,0x657c01e7}},	//   _alsc, _ҧшых, lfeo_, íshu, 
   {{0x982c044e,0xa2e4036b,0x3d0400a2,0x15400139}},	//   _እንተዀ, _жойд, _göwy_, _шешм, 
   {{0x246402d3,0xd00c01ed,0x3f8c00e2,0x1ea83997}},	//   _ታሕሳስ_, گلہ_, īdu_, غازي_, 
   {{0x865402d3,0x3f8c005f,0x11e0004e,0x2ef80108}},	// [3780] _ምትእት, ūdu_, _ажым, _dnsf_, 
   {{0x2ef83998,0x2ee8022f,0x0e603999,0x5d68399a}},	//   _ensf_, adaf_, ткун, цизм_, 
   {{0xda78399b,0xdbf000bc,0x1f640cb6,0x00000000}},	//   оял_, příp, _оком, --, 
   {{0x2ef80048,0x00000000,0x00000000,0x00000000}},	//   _gnsf_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa91c0552,0xad880107,0x3cf8000d,0x00000000}},	//   _nužd, _харҷ_, _उचटे_, --, 
   {{0x6f1c010a,0x34940022,0x00000000,0x00000000}},	//   _ylsc, ҭаир, --, --, 
   {{0x84880023,0x3e38001f,0x5724007b,0x00000000}},	//   መድህን_, _በመድረ, برتق, --, 
   {{0x75d4399c,0xcb2400f1,0x8700005b,0x2488399d}},	//   ريدا, _تړلو_, тяще, _şama_, 
   {{0x798002d0,0x238400ef,0x4870107b,0x97c400ae}},	//   _iumw, _sēja_, رگەس, _يتضم, 
   {{0x7980399e,0x7b3c0010,0xddc4013a,0x00000000}},	//   _humw, včuj, _vykř, --, 
   {{0xe6000139,0x00000000,0x00000000,0x00000000}},	//   тҗән, --, --, --, 
   {{0x06c002f5,0x79800477,0x238400e2,0x00000000}},	//   ্যশি, _jumw, _vēja_, --, 
   {{0x79801cbd,0xcf98399f,0x7b3c0427,0x00000000}},	//   _mumw, жја_, učuj, --, 
   {{0x7b3c1156,0xd17402dd,0x238400e2,0xef100137}},	//   rčuj, зыңы, _tēja_, гүнө, 
   {{0xc3280491,0x3f7802b5,0xe3c41bce,0xdcec00ef}},	//   _يكون_, _pōua_, ññee_, _ribā, 
   {{0x798039a0,0x2ee801ab,0x6f6801ec,0x00000000}},	// [3790] _numw, rdaf_, _ﺳﯟﻋﺎ_, --, 
   {{0xa91c1b5c,0x7c9401d5,0xdcec00b8,0x4478010f}},	//   _kuže, نشما, _pibā, ַנדע, 
   {{0x79800007,0xdb8c0023,0x00000000,0x00000000}},	//   _aumw, _ዝቐውም_, --, --, 
   {{0x160c39a1,0x798039a2,0xfbd039a3,0x3f7800b0}},	//   िहार_, _bumw, شتم_, _tōua_, 
   {{0x79800076,0xb9c400f2,0xa2b01684,0x00000000}},	//   _cumw, نتوه, _अयस्, --, 
   {{0x02dc0316,0x41bc0375,0x3d0001bc,0xd8a400d1}},	//   _बस्न, קצוע, राणे_, ىشىۋ, 
   {{0xa91c39a4,0x3e38001f,0x00000000,0x00000000}},	//   _ružd, _በመደረ, --, --, 
   {{0x68340023,0x27e8008f,0x00000000,0x00000000}},	//   _ክንርድ, ĉan_, --, --, 
   {{0x3a5439a5,0x64a439a6,0x79801418,0x4ab00daf}},	//   _актё, напа, _gumw, _зөһр, 
   {{0xc444040b,0x61200109,0xa91c0024,0xe40413f3}},	//   ویشن_, _kôle, _atžv, езоп, 
   {{0x29c809d7,0x798000ca,0x3d0039a7,0x00000000}},	//   lúa_, _zumw, राते_, --, 
   {{0x6120145e,0xa91c05ce,0x79800223,0xa6c80014}},	//   _môle, _duže, _yumw, _روتل_, 
   {{0x29c81280,0x6d5401e4,0x20d402bf,0x36a8009f}},	//   núa_, _okza, нівс, _آههَ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf484064d,0xa800010e,0x29c80051,0x00000000}},	//   _ручн, _öñde, húa_, --, 
   {{0xa1c40798,0x53a0014b,0x00000000,0x00000000}},	//   _збид, _саъб, --, --, 
   {{0x69c80218,0xce440801,0x27e4010a,0x00000000}},	// [37a0] _nqee, езте_, _lsln_, --, 
   {{0x798039a8,0x6120002d,0x00000000,0x00000000}},	//   _rumw, _bôle, --, --, 
   {{0x79800227,0xaf840184,0x69c805b1,0xf0000131}},	//   _sumw, _аҡса_, _aqee, _күри, 
   {{0x6d5439a9,0x612001a2,0x79800428,0x3ea402d2}},	//   _ekza, _dôle, _pumw, _þmt_, 
   {{0x7980016d,0x00000000,0x00000000,0x00000000}},	//   _qumw, --, --, --, 
   {{0x61200120,0x7980014f,0x00000000,0x00000000}},	//   _fôle, _vumw, --, --, 
   {{0xb908228d,0x69c80869,0x798000ca,0x88e010fc}},	//   _बस_, _eqee, _wumw, ужје, 
   {{0x798039aa,0xa91c39ab,0x29c839ac,0xd5b80798}},	//   _tumw, _ruže, búa_, псо_, 
   {{0xa91c39ad,0x38600198,0x29c804d4,0x00000000}},	//   _suže, ƙiro_, cúa_, --, 
   {{0x27e40115,0xa91c39ae,0x89d40451,0x27e8033f}},	//   _fsln_, _puže, _سومر_, łana_, 
   {{0x56f0010b,0x83a439af,0x00000000,0x00000000}},	//   _бүйс, нтяб_, --, --, 
   {{0x046039b0,0xcc3800df,0x00000000,0x00000000}},	//   ытым, לעיט, --, --, 
   {{0x07041541,0x00000000,0x00000000,0x00000000}},	//   _سيوي_, --, --, --, 
   {{0xa3e00882,0xcf8802e8,0xc108004e,0x00000000}},	//   _नैव_, зсад_, нэсе_, --, 
   {{0xbf1c1d15,0x29c8056a,0x00000000,0x00000000}},	//   नसून_, zúa_, --, --, 
   {{0x6120056d,0x00000000,0x00000000,0x00000000}},	//   _rôle, --, --, --, 
   {{0x741439b1,0xc1b812c4,0x00000000,0x00000000}},	// [37b0] _سوکا, _злых_, --, --, 
   {{0xe6dc35e8,0x612039b2,0xdb1c00c5,0x301400c0}},	//   _मस्ज, _pôle, htpä, _адор, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x29c839b3,0x61200120,0x5b1001e0,0x00000000}},	//   túa_, _vôle, ғмәт, --, 
   {{0xa91c0419,0x7c200213,0x00000000,0x00000000}},	//   _ružb, _əmri, --, --, 
   {{0x612039b4,0x00000000,0x00000000,0x00000000}},	//   _tôle, --, --, --, 
   {{0x29c825e6,0xcb440022,0xf8a80133,0x684402e8}},	//   súa_, _зхаи, ردوه_, ънка, 
   {{0x29c800c7,0x00000000,0x00000000,0x00000000}},	//   púa_, --, --, --, 
   {{0x9fb40316,0x00000000,0x00000000,0x00000000}},	//   vřít_, --, --, --, 
   {{0xe97439b5,0x64bc07f7,0xdb1c0254,0x59d8012d}},	//   _شهاد, ्भेश, atpä, _मैटर, 
   {{0xa91c2d2b,0xe2f40156,0x00000000,0x00000000}},	//   _tužb, _བོདཔ_, --, --, 
   {{0xe5b409a5,0x00000000,0x00000000,0x00000000}},	//   _айды, --, --, --, 
   {{0xf77039b6,0x65c40124,0xc17839b7,0x934039b8}},	//   _اال_, _рбла, нҗи_, рняе, 
   {{0x363439b9,0xc8280023,0x00000000,0x00000000}},	//   _حرمس, _እንሓን, --, --, 
   {{0x10a039ba,0x8fa0035b,0x28c805d7,0xa3b40037}},	//   рисн, иаре, _रानि, _छटि_, 
   {{0x221439bb,0xbf1c0acd,0x00000000,0x00000000}},	//   _афор, नसेन_, --, --, 
   {{0x0d8005f5,0xe7bc0154,0xd36c143e,0x8e800500}},	// [37c0] илтн, _আনোয, _بهي_, ргуе, 
   {{0x61f4009a,0x98ac0418,0xd12c1c4e,0x04ec03d4}},	//   _iryl, kifā_, _ومي_, _চকুৰ_, 
   {{0x61f401a8,0x6e2003e3,0x00000000,0x00000000}},	//   _hryl, _əlbi, --, --, 
   {{0xc0340201,0x61f4007c,0x3d0039bc,0x00000000}},	//   _አስታወ, _kryl, राहे_, --, 
   {{0xaac41867,0x9db80139,0x00000000,0x00000000}},	//   اتمن, _юыну_, --, --, 
   {{0x7b3c009b,0x6e280135,0xd7f839bd,0x00000000}},	//   jčuv, _żebg, дуи_, --, 
   {{0xa8541cd1,0xd7e40212,0xd76801d5,0x00000000}},	//   лешә, тіло, мшид_, --, 
   {{0x8c400408,0x3d003027,0x61f403ac,0xd65c02dd}},	//   _тесе, रावे_, _oryl, _тiлд, 
   {{0xd5641985,0x09e039be,0x5bd0000d,0x00000000}},	//   ктоп, _котн, _सहुव, --, 
   {{0xe29807ae,0x6d880419,0xa25c0092,0x00000000}},	//   _đưa_, _oľan, _ሳትኮን_, --, 
   {{0x337439bf,0x61f439c0,0xd70439c1,0x4cb8010f}},	//   лгор, _aryl, _изжи, ומיג, 
   {{0x61f439c2,0x63b400e5,0x00000000,0x00000000}},	//   _bryl, ázna, --, --, 
   {{0x37c404a9,0x00000000,0x00000000,0x00000000}},	//   _рәһб, --, --, --, 
   {{0x2f1439c3,0x61f439c4,0xc0f40092,0x00000000}},	//   _lågt_, _dryl, _ልበል_, --, 
   {{0x61f403ac,0x20d039c5,0xa91c00d7,0x403439c6}},	//   _eryl, द्धध, _juža, аерс, 
   {{0x4390085a,0x61f40158,0x6eb4012c,0xa91c01a6}},	//   _таъс, _fryl, ेलधु, _muža, 
   {{0xd1d4001f,0x823400ec,0x7f580022,0x00000000}},	// [37d0] ርቶች_, _پريا, татс_, --, 
   {{0x5e642002,0xdb1c067c,0xbec40153,0x32180432}},	//   انكە, lupè, _žūti, mysy_, 
   {{0x28c805d7,0xa91c2630,0x3218010b,0x00000000}},	//   _राबि, _nuža, lysy_, --, 
   {{0xbf1439c7,0x27f800bc,0x7b6439c8,0x7c681fbe}},	//   _күсә, _čsn_, атче, тјуб_, 
   {{0xdb2436c1,0xbf143941,0x321800ee,0xdce40064}},	//   دونی, _түтә, nysy_, _nukė, 
   {{0xf99016e6,0x98ac0270,0xa91c0841,0x98a0013d}},	//   زبه_, tifā_, _buža, бише, 
   {{0x98a0049b,0xa3e0012c,0x8aa4030d,0x225c012d}},	//   щище, _नैं_, _арзд, ętki_, 
   {{0xa6e439c9,0xa91c39ca,0x321839cb,0x9ae400db}},	//   ужил, _duža, kysy_, _مۉمك_, 
   {{0xe57839cc,0x3218010b,0x00000000,0x00000000}},	//   нзи_, jysy_, --, --, 
   {{0x32180432,0x9fb4013a,0x00000000,0x00000000}},	//   dysy_, hřát_, --, --, 
   {{0x281439cd,0x212406a3,0x7bc801b8,0xdb1c0267}},	//   _حواس, _ïohi_, _ädut, stpå, 
   {{0x61f4049f,0x64480421,0xc5f401af,0x28c80210}},	//   _pryl, _āliā, _ағи_, _राडि, 
   {{0x9f4c01e1,0xddd0313e,0x3218010e,0x20b40108}},	//   _éfé_, _ﺟﻴﺎﺑ, gysy_, лёвс, 
   {{0x64a439ce,0x25ac39cf,0x61f405e4,0xf494030d}},	//   _сака, msel_, _vryl, _вăрн, 
   {{0x25ac39d0,0x201c39d1,0x5ef839d2,0x00000000}},	//   lsel_, áti_, нхар_, --, 
   {{0xdb1c39d3,0x543800c8,0x612005da,0x5f0439d4}},	//   cupè, _רעקא, _dôla, ызба, 
   {{0x201c39d5,0xc0f8001f,0x25ac39d6,0x3d0039d7}},	// [37e0] šti_, ወሳል_, nsel_, राले_, 
   {{0x25ac26c5,0x5278008f,0x3c94015e,0x15cc0220}},	//   isel_, _אנפא, شیرز, _ﻛﻪﺯﺩ, 
   {{0x25ac39d8,0x58840046,0x25e4068f,0x6e280171}},	//   hsel_, қыла, _जैसी_, _ļebe, 
   {{0x25ac39d9,0xa91c07f5,0x3f9819f5,0xe7f800dc}},	//   ksel_, _ruža, mpru_, ्मना_, 
   {{0xa91c0006,0x7f4439da,0x25ac376e,0x00000000}},	//   _suža, mniq, jsel_, --, 
   {{0x5f2439db,0xa91c0064,0x4c90014b,0x00000000}},	//   _যদিও_, _puža, _гиёс, --, 
   {{0x25ac39dc,0xdce40006,0xf484179e,0x7f440129}},	//   esel_, _sukė, یادی, oniq, 
   {{0x7f4439dd,0xa2b839de,0x25ac1af3,0x7bdc047e}},	//   nniq, ्लफ्, fsel_, _ipru, 
   {{0x25ac39df,0xdb1c19f5,0x99840165,0x0f78010f}},	//   gsel_, vupè, mzoů_, ערפל, 
   {{0xa91c07f5,0x7f4439e0,0x8cc42144,0x00000000}},	//   _tuža, hniq, ालयो, --, 
   {{0x7f440d04,0xa91c0010,0x7b3c0427,0xf53801e4}},	//   kniq, _kužn, bčut, riĥ_, 
   {{0x23a4069f,0x932439e1,0xa91c39e2,0x7bdc0ffb}},	//   _खबरद, اردن, _južn, _mpru, 
   {{0x25ac39e3,0xd5ac01ed,0xa91c39e4,0x3338031c}},	//   csel_, _عہد_, _mužn, risx_, 
   {{0x73c43088,0x3218349b,0x3494136b,0xa91c0306}},	//   _кәме, rysy_, _такр, _lužn, 
   {{0x70580a93,0xba000092,0x4f680120,0x00000000}},	//   тавр_, _ቁጣ_, ешам_, --, 
   {{0x7f4439e5,0xa91c22c1,0x61200109,0xbec400e2}},	//   gniq, _nužn, _vôla, _žūri, 
   {{0xdb1c20ef,0x2f140267,0x6e280003,0x00000000}},	// [37f0] cupé, _sågs_, _żebb, --, 
   {{0x7bdc0165,0x61200109,0x4c4839e6,0x4638008f}},	//   _bpru, _tôla, няем_, געמע, 
   {{0x3ed40075,0x8c6420c2,0xaed400cf,0x9fb40118}},	//   شقەر, утад, _конш, přát_, 
   {{0x7f4400f7,0x25ac39e7,0x8ca001ad,0x00000000}},	//   cniq, ysel_, गरहो, --, 
   {{0xa91c04b9,0x6f0c39e8,0x25ac0fac,0x00000000}},	//   _dužn, mjac, xsel_, --, 
   {{0x6e2c39e9,0x6f0c04b9,0x25ac0e38,0xa8640032}},	//   mzab, ljac, vsel_, һеҙҙ, 
   {{0x6d44004d,0x25ac39ea,0x36800248,0x00000000}},	//   mnha, wsel_, _ẹfọ_, --, 
   {{0x6f0c39eb,0xa684086c,0x6b9402d0,0x6e2c14ce}},	//   njac, шлид, _itzg, ozab, 
   {{0x6e2c39ec,0xd7041c22,0xa5242097,0x6d4439ed}},	//   nzab, рные_, имид, onha, 
   {{0x25ac39ee,0x6d4439ef,0x6f0c19f5,0x2bc80490}},	//   rsel_, nnha, hjac, ांपा, 
   {{0x6d4439f0,0xf770021a,0xe29839f1,0x23281b74}},	//   inha, _ځان_, кан_, вони_, 
   {{0x6f0c0a55,0xf77039f2,0x233439f3,0x6d440e78}},	//   jjac, _فان_, рхор, hnha, 
   {{0xe5a439f4,0x6f0c2625,0xc0c002d3,0x61e401f5}},	//   _тили, djac, _ድሓር_, uwkl, 
   {{0x6e2c39f5,0x602439f6,0xa91c01f1,0x6d4439f7}},	//   dzab, адга, _mužo, jnha, 
   {{0x2bb0006d,0x9fc800a7,0xdb1c020c,0x00000000}},	//   jąc_, ъгва_, supé, --, 
   {{0x6d440097,0xdd9039f8,0x2bc80073,0x2bb0033f}},	//   enha, قور_, ांना, dąc_, 
  
   {{0x7f440cfe,0xa91c098d,0x660807a9,0x614409a5}},	// [3800] rniq, _ružn, nxek, _вепа, 
   {{0x7f4402d3,0x7bdc0135,0xa91c0427,0xe6780092}},	//   sniq, _ppru, _sužn, _የኢትዮ_, 
   {{0x6f0c004e,0x6e2c39f9,0x6728004b,0xa91c0e04}},	//   bjac, azab, khej, _pužn, 
   {{0x6f0c068f,0x7c4401fa,0x672801e4,0x6d4439fa}},	//   cjac, _čurć, jhej, anha, 
   {{0xcb0400ec,0x5f44211f,0xca8001e0,0x6728036e}},	//   شيون_, _منگل, әгәй, dhej, 
   {{0xa91c16a3,0x6d440208,0x00000000,0x00000000}},	//   _dužo, cnha, --, --, 
   {{0x8c4039fb,0xa91c0989,0x2b902265,0x1ae400ee}},	//   _дере, _tužn, _فیلس, _ковм, 
   {{0x67280115,0x00000000,0x00000000,0x00000000}},	//   ghej, --, --, --, 
   {{0x550439fc,0x56900046,0x66081cdf,0xf48400e5}},	//   ачна, бақт, gxek, یاگی, 
   {{0x6f0c033f,0x9854004e,0x00000000,0x00000000}},	//   zjac, _ктеш, --, --, 
   {{0x6e2c39fd,0x6f0c39fe,0x672839ff,0x78a8005f}},	//   zzab, yjac, bhej, _iedv, 
   {{0x67283a00,0x78a83a01,0x6e2c01a9,0x00000000}},	//   chej, _hedv, yzab, --, 
   {{0x78a8066d,0xf5940491,0x6d4400a9,0x2bb0033f}},	//   _kedv, _التج, ynha, ząc_, 
   {{0x78a80bb8,0xefc00023,0x6d440051,0x00000000}},	//   _jedv, _ድሃይ_, xnha, --, 
   {{0x4ea403b7,0x4ad4102f,0x6f0c0072,0x6d440162}},	//   ираа, ण्डव, tjac, vnha, 
   {{0x78a83a02,0x6e2c3a03,0x6d4403cb,0xe7f829d9}},	//   _ledv, tzab, wnha, ्मता_, 
   {{0x6d443a04,0x1ee8030f,0x200c0241,0x00000000}},	// [3810] tnha, دوقی_, _àfin_, --, 
   {{0xa91c01a2,0x6e2c3a05,0x6d440208,0x6f0c3a06}},	//   _ružo, rzab, unha, sjac, 
   {{0x6d443a07,0x6e2c01ed,0xa91c02f0,0x6d880419}},	//   rnha, szab, _sužo, _kľak, 
   {{0x28c80574,0x3b840046,0x78a8000d,0x2bb0033f}},	//   _राहि, іліг, _aedv, rąc_, 
   {{0x8d743a08,0xe91800d6,0x4990036b,0x3be80213}},	//   _ناسا, лоді_, زیار, _eşq_, 
   {{0x98a00e58,0x78a83a09,0x7ff40811,0xa3e000bc}},	//   пише, _cedv, _اسیا, नौँ_, 
   {{0xe7383a0a,0x67283a0b,0x60d800c5,0x04180154}},	//   лек_, thej, õtmi, _ফেনী_, 
   {{0x660801c0,0x9410013f,0x635002b5,0x6560015d}},	//   txek, _ɔdɔm_, māng, wllh, 
   {{0x65603a0c,0x67283a0d,0x20a80073,0x00000000}},	//   tllh, rhej, करमध, --, 
   {{0x6aa83a0e,0xb8fc2f8b,0x67280537,0xe7f81cd2}},	//   _heef, _তো_, shej, ्मदा_, 
   {{0x25cc00c6,0xd8842b49,0x6aa83a0f,0x67283a10}},	//   _šнĵŋ_, _اهمی, _keef, phej, 
   {{0xc76404a9,0x2c4003f9,0x7b3c02b1,0x6aa80009}},	//   _ئائى, _mɗd_, hōun, _jeef, 
   {{0x78a8003c,0x69dc0793,0xc0d002d3,0x6aa83a11}},	//   _yedv, _äsed, _እሱር_, _meef, 
   {{0x6aa83a12,0x63501d76,0x35280137,0x040c0154}},	//   _leef, kāng, _ۅسۉپ_, ানবী_, 
   {{0xa0a43a13,0x3838044e,0x90c00cef,0x6d880419}},	//   _қанд, _እንተበ, ябре, _fľak, 
   {{0x6aa83a14,0x1e843a15,0xe1f00633,0x840401ed}},	//   _neef, слам, _فسخ_, _előí, 
   {{0x1d883a16,0x1c44151e,0xe1f8011c,0x11d400ae}},	// [3820] ائري_, әнем, _сгп_, _هوية_, 
   {{0xdca43a17,0x6b8800f3,0x63500165,0x6d880419}},	//   сажи, _čegr, fāng, _zľak, 
   {{0x6aa83a18,0x00000000,0x00000000,0x00000000}},	//   _beef, --, --, --, 
   {{0x91c80183,0x78a83402,0xc10401c8,0x00000000}},	//   িবৰ্, _sedv, _اوڍي, --, 
   {{0x28c83a19,0x3ea03a1a,0x6aa83a1b,0x09b00327}},	//   _राशि, mbit_, _deef, _དྷྱ_, 
   {{0x97a40b2b,0x78a80455,0x3ea03a1c,0x9cb401e2}},	//   брил, _qedv, lbit_, _دمست, 
   {{0x6aa83a1d,0x78a828b3,0x0d74006c,0x3ea000ad}},	//   _feef, _vedv, _ایلک_, obit_, 
   {{0x6aa83a1e,0x3ea03a1f,0x6d880b4b,0x78a83a20}},	//   _geef, nbit_, _džaf, _wedv, 
   {{0x94843a21,0xc6f43a22,0xa91c05ce,0x3ea0003a}},	//   йынд, сных_, _mužj, ibit_, 
   {{0x73d83a23,0x6aa83a24,0xd90c3a25,0x661c3a26}},	//   адор_, _zeef, _سیب_, øska, 
   {{0x3ea03a27,0x6aa83a28,0x733403cc,0x3dc004e6}},	//   kbit_, _yeef, قىدا, hriw_, 
   {{0x95c83a29,0x6aa80009,0x3ea00135,0x2bc801f9}},	//   _бука_, _xeef, jbit_, ांता, 
   {{0x3ea003cd,0x6120002e,0xdb1c0022,0x00000000}},	//   dbit_, _tôll, jupí, --, 
   {{0xdbc40209,0x932404d3,0x3ea03a2a,0xdb1c00e4}},	//   _söýg, _گرتن, ebit_, nupâ, 
   {{0x6d880419,0x2ef40108,0x00000000,0x00000000}},	//   _zľah, озвр, --, --, 
   {{0x2138070d,0xa91c1e31,0x6e983a2b,0x3dc0015d}},	//   _emph_, _ružm, рвар_, friw_, 
   {{0x6aa83a2c,0x635002b1,0x0af001c6,0x644c054e}},	// [3830] _reef, wāng, үүгэ, ăniţ, 
   {{0x6aa83a2d,0x3ea00538,0x635002b1,0x2244032e}},	//   _seef, abit_, tāng, _þoka_, 
   {{0x33280174,0x3ea03a2e,0x635000cd,0x00000000}},	//   _klax_, bbit_, bānd, --, 
   {{0x63503a2f,0x00000000,0x00000000,0x00000000}},	//   rāng, --, --, --, 
   {{0xa97804a9,0x9d380276,0xf1a80243,0x6aa83a30}},	//   айду_, _ӂорӂ_, कठिन, _veef, 
   {{0x2d983a31,0x69243a32,0x27943a33,0x6aa83a34}},	//   _itse_, юмла, ошир, _weef, 
   {{0x6aa801f5,0x7e8802d2,0x76840241,0x00000000}},	//   _teef, _áspá, _ẹdọf, --, 
   {{0xa91c0219,0x973001e2,0x00000000,0x00000000}},	//   _kužk, وکنا, --, --, 
   {{0x24e83542,0x5584005b,0x00000000,0x00000000}},	//   ампи_, обым_, --, --, 
   {{0x3ea00369,0x39403a35,0x00000000,0x00000000}},	//   zbit_, éist_, --, --, 
   {{0xe7dc06ab,0x2904058a,0xa2e409a0,0xa91c01ef}},	//   _महिप, _inla_, оонд, _lužk, 
   {{0x2d9800af,0x4428012d,0x3ea0031c,0x04f800eb}},	//   _otse_, ąc_, xbit_, েসের_, 
   {{0x2d983a36,0x26dc00ca,0x6d8801f1,0xa50800f5}},	//   _ntse_, _ibwo_, _uľah, _вела_, 
   {{0xe7dc3a37,0x00000000,0x00000000,0x00000000}},	//   _महाप, --, --, --, 
   {{0xe2983a38,0x3ea03a39,0x33283a3a,0x29043a3b}},	//   _кай_, tbit_, _flax_, _mnla_, 
   {{0xb9140a28,0x1f640006,0x3ea03a3c,0xd00c3a3d}},	//   śaḥ_, ікам, ubit_, خلف_, 
   {{0xe7e81533,0x6d0402ab,0x29042ca8,0x238400de}},	// [3840] झौता_, रांग_, _onla_, _vēju_, 
   {{0x3ea03a3e,0x21380204,0xe0d80b3b,0xdc980408}},	//   sbit_, _umph_, _тво_, рташ_, 
   {{0x2d983a3f,0x26dc2252,0x238400e2,0x00000000}},	//   _etse_, _obwo_, _tēju_, --, 
   {{0x29043a40,0x9f4c01e1,0x00000000,0x00000000}},	//   _anla_, _éfà_, --, --, 
   {{0x2b4c01fa,0x6120000f,0x635000ef,0x00000000}},	//   _djec_, _rôlj, cāne, --, 
   {{0x26dc3a41,0xdcb0215c,0x386c012d,0x00000000}},	//   _abwo_, _زىر_, _pzdr_, --, 
   {{0x01d002a6,0x26dc0083,0xacb002dd,0xabc401af}},	//   িবিদ, _bbwo_, _سەنب, _нарҙ, 
   {{0x29043a42,0xe9a40014,0xdb1c0254,0xaad001f9}},	//   _enla_, _کۯون_, ntpü, _हायक, 
   {{0x56900220,0x39400221,0x00000000,0x00000000}},	//   пақт, éiss_, --, --, 
   {{0x08c00fab,0x62943a43,0x69f00131,0x00000000}},	//   _обун, _afyo, _чүшт, --, 
   {{0x136801a9,0x00000000,0x00000000,0x00000000}},	//   ишми_, --, --, --, 
   {{0x51843a44,0xc7a006ed,0x399001e1,0x395c00e2}},	//   жува, _цицк, _kàs_, lovs_, 
   {{0x167004a9,0x00000000,0x00000000,0x00000000}},	//   _юқир, --, --, --, 
   {{0x395c005f,0x39903a45,0x938800d8,0x44f0003b}},	//   novs_, _màs_, _ксиа_, _опіс, 
   {{0x39900248,0x00000000,0x00000000,0x00000000}},	//   _làs_, --, --, --, 
   {{0xcc083a46,0x2bc800a5,0x4ea402ec,0x395c1d17}},	//   یزان_, ांसा, юрга, hovs_, 
   {{0x395c005f,0xd084084c,0x00000000,0x00000000}},	// [3850] kovs_, _мыни, --, --, 
   {{0x4598008f,0x23b400e4,0x00000000,0x00000000}},	//   יסמע, ẽjey_, --, --, 
   {{0x3d0027f2,0xebd83a47,0x6e940137,0x395c00ef}},	//   राजे_, сдеш_, _ىلدا, dovs_, 
   {{0xa4a401e1,0x39900e89,0x63b41ab0,0xa91c00bc}},	//   _afọ̀, _bàs_, ázni, _tužk, 
   {{0x2b4c02d3,0x39903a48,0xa9a43a49,0x2d9801e3}},	//   _vjec_, _càs_, чилд, _utse_, 
   {{0xa91c3a4a,0xd6cc0075,0x2ee83a4b,0x39900120}},	//   _kuži, ۇقى_, leaf_, _dàs_, 
   {{0xa91c01a6,0x39401497,0x00000000,0x00000000}},	//   _juži, èisa_, --, --, 
   {{0x39900192,0xa91c3a4c,0x661c03cd,0x7ac40395}},	//   _fàs_, _muži, øsko, _осуе, 
   {{0x3d000490,0xa91c02f0,0x395c00ef,0x00000000}},	//   राचे_, _luži, bovs_, --, 
   {{0x67082e2a,0x290400ef,0x395c00ef,0x00000000}},	//   वाहक_, _unla_, covs_, --, 
   {{0xdb1c0306,0xf6500133,0xa91c00c0,0x00000000}},	//   lupá, _یئه_, _nuži, --, 
   {{0x26dc0537,0xa77400cf,0xe2840116,0x00000000}},	//   _ubwo_, _элеч, ялми, --, 
   {{0x6d880038,0x26cc0334,0x00000000,0x00000000}},	//   _zľav, mgeo_, --, --, 
   {{0xa91c2f61,0x2a3c0092,0x68340023,0x60140432}},	//   _buži, _ኬንትሮ, _እንሓስ, jümç, 
   {{0xa0683a4d,0xdb1c0022,0xdce40055,0x00000000}},	//   сава_, hupá, _sukį, --, 
   {{0xa91c1326,0x6294009f,0x26cc02b5,0xdb1c37b5}},	//   _duži, _ufyo, ngeo_, kupá, 
   {{0x14ec03d4,0x6b9c0023,0x6eac012d,0x00000000}},	// [3860] জাৰী_, _ዝሐለፈ_, _ज़रु, --, 
   {{0x4d6003b7,0xd00c00dd,0xa91c0f03,0xdbc40139}},	//   екув, خلہ_, _fuži, _söñg, 
   {{0x26cc0032,0x1f643a4e,0x39900192,0x5f04010a}},	//   kgeo_, _нком, _sàs_, _езна, 
   {{0x6d8838bb,0x7dfc0055,0x39900ca8,0x00000000}},	//   _džab, _cāsã, _pàs_, --, 
   {{0xa91c02f0,0x00000000,0x00000000,0x00000000}},	//   _zuži, --, --, --, 
   {{0x612005da,0x97a43849,0x6014013d,0x2bc8084d}},	//   _bôli, прил, cümç, ांशा, 
   {{0xd7f83a4f,0x395c3a50,0x97c4007b,0x644c002b}},	//   сул_, rovs_, ستثم, _śain, 
   {{0x96e83a51,0x3990068c,0x395c3a52,0x6d8800d0}},	//   ська_, _tàs_, sovs_, _vľav, 
   {{0xaad00892,0x00000000,0x00000000,0x00000000}},	//   _हातक, --, --, --, 
   {{0x6fdc07f7,0x257000d1,0x00000000,0x00000000}},	//   _पहलू, نۇنس, --, --, 
   {{0x26cc0998,0x6d880419,0x00000000,0x00000000}},	//   bgeo_, _uľav, --, --, 
   {{0xa91c3a53,0x7d18007c,0x00000000,0x00000000}},	//   _ruži, övsj, --, --, 
   {{0xa91c0153,0xe73800ec,0xd65c030d,0x67081b51}},	//   _suži, _بينڪ_, _тiад, वारक_, 
   {{0xa91c01a6,0x661c3a54,0x00000000,0x00000000}},	//   _puži, äske, --, --, 
   {{0x04d80375,0xdcec0139,0x27e801e4,0xc5103a55}},	//   _הקול, _sibğ, ʈan_, _سبوت, 
   {{0x7ae40037,0x00000000,0x00000000,0x00000000}},	//   õitl, --, --, --, 
   {{0xfe5413cf,0xed500145,0xd1d40092,0x8aa4010b}},	// [3870] ектэ, پپا_, ይቶች_, җред, 
   {{0xa91c0bb8,0x63501161,0x628c005f,0x00000000}},	//   _tuži, māna, ānoš, --, 
   {{0xa02000c5,0xcf2400e3,0x7b9400d4,0x00000000}},	//   ööta, _فرحي, ерії, --, 
   {{0xcee83a56,0x201c3a57,0x3dd00150,0x00000000}},	//   _اردن_, ätie_, _ﯗﻗﯩﻘ, --, 
   {{0x26cc0998,0x2730004d,0xa8880354,0x00000000}},	//   vgeo_, _háng_, ойла_, --, 
   {{0x612003d1,0x7b3c00b0,0xdb1c0022,0x00000000}},	//   _pôli, hōuh, rupá, --, 
   {{0x63500a28,0xe7383a58,0xdb1001f2,0xdb1c03b2}},	//   hāna, жей_, ọ̀pụ, supá, 
   {{0x2730004d,0xa91c0064,0x8c34014b,0x00000000}},	//   _máng_, _nužv, _доҳӣ_, --, 
   {{0x63500882,0x27303a59,0x27e83a5a,0x26cc3a5b}},	//   jāna, _láng_, ňan_, rgeo_, 
   {{0xba740c78,0x63500882,0x26cc0048,0xe3b83a5c}},	//   _ساقت, dāna, sgeo_, обо_, 
   {{0x69d80730,0x6374013c,0xf74800f1,0x00000000}},	//   ltwe, náng, _کلني_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69d83a5d,0x20d400d4,0x00000000,0x00000000}},	//   ntwe, мівс, --, --, 
   {{0x69d83a5e,0x38603a5f,0x27300208,0x213c01c3}},	//   itwe, şire_, _báng_, òth_, 
   {{0xe0d004fb,0x201c00d2,0x69d83a60,0x27300208}},	//   _یزد_, âti_, htwe, _cáng_, 
   {{0xa91c08a4,0x27300016,0xdbc4007d,0x69d80112}},	//   _gužv, _dáng_, _köög, ktwe, 
   {{0xb7d40cad,0x69d801f5,0xdb1c0200,0x635000b8}},	// [3880] _iṣed, jtwe, lupç, cāna, 
   {{0xa0683a61,0x273003b2,0x69d80e78,0x28c82a67}},	//   _мапа_, _hánd_, dtwe, _रागि, 
   {{0x5fe03a62,0xdbc400c5,0xf0000131,0x69d80582}},	//   _पहिल, _löög, _йүри, etwe, 
   {{0x69d83a63,0x00000000,0x00000000,0x00000000}},	//   ftwe, --, --, --, 
   {{0xceb005d0,0x63743a64,0x28c80316,0x69d83a65}},	//   _שיש_, mánd, _राखि, gtwe, 
   {{0x7f443a66,0x63743a67,0x588400ee,0xf1b802f0}},	//   liiq, báng, мыйа, áši_, 
   {{0xa91c0006,0x69d80430,0x9990033f,0x25a80327}},	//   _nužu, atwe, ódła_, _ħala_, 
   {{0x63500a28,0xd5b80228,0x63742b76,0x3cf83a68}},	//   yāna, осо_, nánd, _harv_, 
   {{0x7d1c3a69,0x63740005,0x3cf83a6a,0x69d83a6b}},	//   _kors, iánd, _karv_, ctwe, 
   {{0xb7d40241,0x635000dc,0xd87400cf,0x63743a6c}},	//   _aṣed, vāna, _قااب, hánd, 
   {{0x3cf80dd4,0x635002b5,0x00000000,0x00000000}},	//   _marv_, wāna, --, --, 
   {{0x7d1c3a6d,0x79881c06,0x63503a6e,0x2730004d}},	//   _lors, _hidw, tāna, _ráng_, 
   {{0x7d1c3a6f,0x273007ae,0x63742b76,0x798804ce}},	//   _oors, _sáng_, dánd, _kidw, 
   {{0x7d1c3a70,0x6374043b,0x63503a71,0x79883a72}},	//   _nors, yáng, rāna, _jidw, 
   {{0x63740077,0x7f443a73,0xdcec00ef,0x00000000}},	//   fánd, fiiq, _libē, --, 
   {{0x7f440cfe,0x63742b76,0x63500aed,0x798808c8}},	//   giiq, gánd, pāna, _lidw, 
   {{0x3cf83a74,0xa91c02f0,0x2d9c0036,0xecc400fb}},	// [3890] _barv_, _zužu, ëwe_, ешеү, 
   {{0x7d1c3a75,0x63740296,0x79883a76,0x273001fb}},	//   _cors, táng, _nidw, _táng_, 
   {{0x6374043b,0xdb1c25e4,0x8c64036b,0xf04401d3}},	//   bánd, kupä, фтад, _سعدی, 
   {{0x0f2400d6,0x637439b3,0x3cf80099,0x79880857}},	//   _цьом, cánd, _earv_, _aidw, 
   {{0x7988025c,0xf414015b,0x6f1c3a77,0x27e43a78}},	//   _bidw, ানির_, _iosc, _spln_, 
   {{0x7d1c3a79,0x69d82940,0x6f1c3a7a,0x3cf805c7}},	//   _gors, rtwe, _hosc, _garv_, 
   {{0x6d443a7b,0xdbc400af,0x79880042,0x6f1c3a7c}},	//   miha, _söög, _didw, _kosc, 
   {{0x6d443a7d,0xe6183a7e,0x798802d0,0x8cc42e1e}},	//   liha, зди_, _eidw, ालको, 
   {{0x7988025c,0x63743a7f,0x2cb001d3,0xa91c1155}},	//   _fidw, náne, _kezd_, _sužu, 
   {{0x6f1c3a80,0x63742b76,0x79880036,0xa2a016d1}},	//   _losc, zánd, _gidw, कुन्, 
   {{0x6b8800dd,0x63743a81,0x6d440857,0x2cb00118}},	//   _kieg, yánd, iiha, _mezd_, 
   {{0x6f1c3a82,0x6d443a83,0x798801e2,0xdbc400c5}},	//   _nosc, hiha, _zidw, _töög, 
   {{0x6b883a84,0x63743a85,0x6d443a86,0x63a002fb}},	//   _mieg, vánd, kiha, spln, 
   {{0x6b883a87,0x6d443a88,0x6f1c03ac,0x63743a89}},	//   _lieg, jiha, _aosc, dáne, 
   {{0xdee43a8a,0xd4643a8b,0x6d443a8c,0x2ef83a8d}},	//   нови, _пише_, diha, _basf_, 
   {{0x67283a8e,0x7d1c3a8f,0x6f1c3a90,0x6b883a91}},	//   nkej, _sors, _cosc, _nieg, 
   {{0x6d443a92,0x6f1c3a93,0x7f443a94,0x63743a95}},	// [38a0] fiha, _dosc, riiq, ránd, 
   {{0x7d1c0050,0xa91c0232,0x63742b76,0x6b88005a}},	//   _qors, _mužs, sánd, _aieg, 
   {{0x7d1c09f0,0x3cf83a96,0x79883a97,0x6b883a98}},	//   _vors, _varv_, _ridw, _bieg, 
   {{0x7f443431,0x6b883a99,0x65603a9a,0x41c4012c}},	//   qiiq, _cieg, holh, _वटास, 
   {{0x6b883a9b,0x63743a9c,0xef20005f,0x3cf83a9d}},	//   _dieg, cáne, _daļā_, _tarv_, 
   {{0x7d1c07de,0x6b88017a,0x79880455,0x212801bf}},	//   _uors, _eieg, _qidw, nkbh_, 
   {{0x7988014f,0xdb1c16ca,0xa8540166,0x00000000}},	//   _vidw, tupä, кешә, --, 
   {{0xa2a01a55,0xef2000ef,0x00000000,0x00000000}},	//   कुम्, _gaļā_, --, --, 
   {{0x65600798,0x79880135,0xdb1c0254,0x646406be}},	//   folh, _tidw, rupä, _əriş, 
   {{0x6b883a9e,0x645c03be,0x65603a9f,0x1da0001f}},	//   _zieg, əsiz, golh, ሃብቶች_, 
   {{0xd5c005dc,0x645c029f,0x67280219,0x26180115}},	//   _शिवज, şsin, bkej, nɨoj_, 
   {{0x6d443aa0,0x67283aa1,0x9f4c007f,0xa2d400cd}},	//   ziha, ckej, _èfè_, _भाण्, 
   {{0x6d443aa2,0x850004d3,0x65603aa3,0xdb1c0fac}},	//   yiha, _ڕوون, bolh, cupå, 
   {{0x65600cfc,0x6f1c1497,0xeb1c02ab,0xd5e00241}},	//   colh, _sosc, _भक्त_, _iyò, 
   {{0x6f1c3aa4,0x4ea43aa5,0xa02000c5,0x61f40042}},	//   _posc, ерза, ööpa, _esyl, 
   {{0x6d443aa6,0x63743aa7,0x2cb00166,0x201c00d7}},	//   wiha, táne, _sezd_, ätia_, 
   {{0x6d443aa8,0x6d883aa9,0x6f1c08e5,0x60cc0115}},	// [38b0] tiha, _džan, _vosc, _ŝimŝ, 
   {{0x637402fb,0x6b883aaa,0x52b00137,0x6d443aab}},	//   ráne, _sieg, _جەڭئ, uiha, 
   {{0x6b883aac,0xdb1c0254,0x00000000,0x00000000}},	//   _pieg, htpõ, --, --, 
   {{0x6d443aad,0x6b88003d,0xf1b800f3,0x98a000e2}},	//   siha, _qieg, ššu_, _ēkā_, 
   {{0x6b8800da,0xef2000e2,0xdce403e0,0x273000e5}},	//   _vieg, _vaļā_, _etkı, _lánc_, 
   {{0x6b883aae,0x684401b9,0xc9d00014,0xc4a800eb}},	//   _wieg, кнла, نزڈب, _গঞ্জ, 
   {{0x6b883aaf,0xd5e00241,0x7d540640,0x65603ab0}},	//   _tieg, _ayò, _сврх, volh, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x67283ab1,0xe5783ab2,0x2bc80073,0x795001d9}},	//   rkej, мзи_, ांका, _گێوا, 
   {{0x67283ab3,0x61f401f5,0xc9843ab4,0xaad011e1}},	//   skej, _rsyl, _чуби, _हाँक, 
   {{0xa2d40e49,0x65603ab5,0x672800f3,0x630416ac}},	//   _भाद्, rolh, pkej, نودل, 
   {{0x656001d3,0xd0b003b9,0xe2983ab6,0x637401ef}},	//   solh, _işəm, ьам_, dánc, 
   {{0x65603ab7,0x637400e5,0x00000000,0x00000000}},	//   polh, tánb, --, --, 
   {{0x6120002d,0xa2a000dc,0xa3b403ce,0x00000000}},	//   _rôls, _क्र्, _चौथ_, --, 
   {{0x14d40a7c,0xb7d40055,0x5ef80022,0x4ab007b7}},	//   _יוסל_, _kṣad, мхар_, ुणाव, 
   {{0x6d54009b,0x53a00fc0,0x2fc40162,0x00000000}},	//   _ajza, _таъб, álga_, --, 
   {{0x61f4014b,0xa2a01b61,0x637400e5,0x00000000}},	// [38c0] _usyl, कुण्, pánb, --, 
   {{0xed3405f5,0xdca43ab8,0x7b3c02b5,0x25a8025c}},	//   лэхэ, тажи, hōut, _ħall_, 
   {{0x20543ab9,0x9ea80b3b,0xb7d400cd,0x00000000}},	//   _штир, _овна_, _oṣad, --, 
   {{0x6d883aba,0xe6bc09ab,0x00000000,0x00000000}},	//   _užan, ोलोज, --, --, 
   {{0x3f800869,0x261801e4,0x5d84007b,0x00000000}},	//   mmiu_, sɨoj_, _للحل, --, 
   {{0xa2a000cd,0x00000000,0x00000000,0x00000000}},	//   कुत्, --, --, --, 
   {{0xb6c43abb,0x88b0036b,0xcc840798,0x00000000}},	//   гөлд, شینچ, _абре_, --, 
   {{0xb6f40b3e,0xdb1c0254,0xe7f83abc,0x00000000}},	//   узиј, ttpõ, ्मजा_, --, 
   {{0xc6f43abd,0xda643abe,0xae040cb4,0x59843abf}},	//   тных_, _شاري, रियन_, _алаб, 
   {{0x3f80036e,0xe6bc03ce,0x00000000,0x00000000}},	//   hmiu_, ोलॉज, --, --, 
   {{0x78b8026c,0x37c400d1,0x857001c0,0xd8740101}},	//   mavv, _сәлб, рлэх, _شائب, 
   {{0x637401ed,0x95c83ac0,0x660c0153,0x00000000}},	//   vánc, _жука_, _šake, --, 
   {{0x201c023a,0x3f803ac1,0xe464000d,0x00000000}},	//   ätin_, dmiu_, ööre_, --, 
   {{0x78b82b1d,0x7bdc0166,0x273001d3,0xe7f80a8a}},	//   navv, _oqru, _tánc_, ्मचा_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x63740316,0xaad01f14,0x273003b2,0x386c0142}},	//   ránc, _हाइक, _kána_, _mydr_, 
   {{0x27300030,0x7db4007b,0x78b80205,0x00000000}},	// [38d0] _jána_, لصلا, kavv, --, 
   {{0x63743ac2,0x2730022c,0x3f80013c,0x00000000}},	//   mána, _mána_, amiu_, --, 
   {{0x63743ac3,0x27303ac4,0x00000000,0x00000000}},	//   lána, _lána_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa2d43ac5,0x25780129,0x637401d3,0x2730032e}},	//   _भास्, lèle_, nána, _nána_, 
   {{0x999422ad,0x78b804ba,0x7d18007c,0x00000000}},	//   دپور_, gavv, övst, --, 
   {{0x1864036b,0x63743ac6,0xdcec0064,0x00000000}},	//   лаши_, hána, _aibė, --, 
   {{0x273000ae,0x661c0267,0x660c025c,0x637401d3}},	//   _bána_, äsko, _ġakb, kána, 
   {{0x637401ed,0x273001e7,0xc79001e0,0xaa5410fc}},	//   jána, _cána_, ырҙы, _сваш, 
   {{0x6ab83ac7,0x63743ac8,0x6b943ac9,0x27303aca}},	//   lawf, dána, _kuzg, _dána_, 
   {{0x6b943acb,0xa3483acc,0x2d801554,0x3f800076}},	//   _juzg, езна_, imhe_, ymiu_, 
   {{0x25783acd,0x6b943ace,0x27303acf,0x21a43ad0}},	//   dèle_, _muzg, _fána_, лимм, 
   {{0x9f5c3ad1,0xaad01533,0x637419db,0x9340005b}},	//   ítí_, _हाईक, gána, сняе, 
   {{0x661c3ad2,0xffa401c0,0xa2b80b98,0xa2d400cd}},	//   øsku, илгү, ्लङ्, _भाव्, 
   {{0x74d83ad3,0x25782a59,0xe28404a9,0xf4840640}},	//   _मातृ, gèle_, _өлки, _кућн, 
   {{0x6d883ad4,0xbe843500,0xd0040640,0x26f001ad}},	//   _džam, иқни, ћете_, _अघोर_, 
   {{0x63743ad5,0x3f803ad6,0x7b3c02b1,0xd3780a7c}},	// [38e0] cána, rmiu_, kōur, _ארקט, 
   {{0x6b943ad7,0x6d880219,0x00000000,0x00000000}},	//   _buzg, _užal, --, --, 
   {{0x5ac83ad8,0x257806af,0x59841de6,0x3f98031c}},	//   елем_, cèle_, ңлеб, qqru_, 
   {{0x6b9413f4,0xda783ad9,0x33a00150,0x00000000}},	//   _duzg, нял_, _ﺃﺨﻔﻲ_, --, 
   {{0x661c369a,0x4e240395,0x00000000,0x00000000}},	//   äskl, _боян_, --, --, 
   {{0x273002fb,0x9d440798,0x2244032e,0x00000000}},	//   _rána_, _сегд, _þoku_, --, 
   {{0x78b83ada,0x7bdc02d1,0x6b9406be,0xfa1c00eb}},	//   ravv, _uqru, _guzg, _দেখল_, 
   {{0x78b83adb,0xa2d4243c,0x273002fb,0x17040214}},	//   savv, _भाष्, _pána_, افظی_, 
   {{0x75840220,0x18a43adc,0xd36c0145,0x386c015d}},	//   аңда, _базм, ۋۇت_, _wydr_, 
   {{0x9df4013f,0x273003b2,0x6b9401d5,0x63743add}},	//   ɛtɔɔ_, _vána_, _yuzg, vána, 
   {{0x985400e4,0x6b940077,0xb6c4010b,0x201c0419}},	//   _сташ, _xuzg, _көпд, ätil_, 
   {{0xe9d000aa,0x257807ea,0x92683ade,0x843002bf}},	//   _دغې_, vèle_, ерга_, снює, 
   {{0x6d8817a3,0xa2d40882,0xc0d0001f,0xb7d400b8}},	//   _džaj, _भार्, _እሱም_, _kṣod, 
   {{0x63743adf,0x257807ea,0x506401c0,0x00000000}},	//   rána, tèle_, гтба, --, 
   {{0x40343ae0,0x637400dd,0x8f0805f5,0x644c002b}},	//   берс, sána, нхаа_, _śaiv, 
   {{0x63743ae1,0x25783ae2,0x6b940205,0x916401e1}},	//   lánn, rèle_, _ruzg, bò̟n_, 
   {{0x6b9402ce,0x9268166f,0x2578387a,0xe1c000fb}},	// [38f0] _suzg, _ярка_, sèle_, _мөрй, 
   {{0x3208325f,0x69dc01b8,0x6b94009d,0x9a800092}},	//   _iray_, _äsei, _puzg, ንድነው_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x32080139,0x6b940166,0xca8001a9,0x00000000}},	//   _kray_, _vuzg, оrаl, --, 
   {{0xac9400ee,0x32080009,0x6ab80072,0x00000000}},	//   _вагш, _jray_, rawf, --, 
   {{0xf9903ae3,0x6b943ae4,0x3c941188,0xc62000eb}},	//   سبه_, _tuzg, _гирё, _বইলা_, 
   {{0xe7383ae5,0x60c8000f,0xc8b00150,0x00000000}},	//   кек_, _ôfme, асқы, --, 
   {{0x32083ae6,0x65c40818,0x00000000,0x00000000}},	//   _oray_, абиа, --, --, 
   {{0x7b3c04fe,0xc30400fe,0x9b400244,0x49003947}},	//   pōur, _উকলি_, _بۆنو, _гүлг, 
   {{0x63503ae7,0x637400e5,0x00000000,0x00000000}},	//   māni, gánn, --, --, 
   {{0xf77015fa,0x32083ae8,0x00000000,0x00000000}},	//   _کال_, _aray_, --, --, 
   {{0x31f43ae9,0x32083aea,0xe2843aeb,0x478402dd}},	//   _བརྡར_, _bray_, илни, _сызб, 
   {{0x320800ad,0x85a40640,0xdb1c01bf,0x60780092}},	//   _cray_, _сјед, rupø, _በትጋት_, 
   {{0x32083aec,0x6d883aed,0x00000000,0x00000000}},	//   _dray_, _džak, --, --, 
   {{0xa0682826,0x32083aee,0xe86002d3,0x63501991}},	//   тава_, _eray_, _ድሕሪኡ_, hāni, 
   {{0x63743aef,0x32083af0,0x00000000,0x00000000}},	//   máno, _fray_, --, --, 
   {{0x637400dd,0x32083af1,0x6e283af2,0x00000000}},	// [3900] láno, _gray_, _żebr, --, 
   {{0x127800c8,0xa2a000dc,0x00000000,0x00000000}},	//   _באפע, कुर्, --, --, 
   {{0xdee43af3,0x63741ab0,0x9aa40fb4,0x1ec8030d}},	//   _кони, náno, لماو, _илни_, 
   {{0xe8083af4,0x320802d0,0x057c0023,0x63500171}},	//   विना_, _yray_, _ብጥበብ_, fāni, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3ea03af5,0x63743af6,0x23c43af7,0x00000000}},	//   lcit_, káno, _विंद, --, 
   {{0xd7f81142,0xc6200eac,0x660c0327,0x637400e5}},	//   тул_, _বেলা_, _ġaka, vánn, 
   {{0x3ea03af8,0x96e83af9,0x35b43afa,0x660c0c5c}},	//   ncit_, тька_, ббир, _šaka, 
   {{0x94a81cc9,0x38c801ed,0x3dc03afb,0x3ea00381}},	//   ктна_, _ماضی_, nsiw_, icit_, 
   {{0x96a403f3,0xdb0c0158,0xb4d0012c,0x3d0c000d}},	//   _ट्रॉ, _avbø, षले_, _डोमे_, 
   {{0x63743afc,0x6d8805be,0x58f8031c,0x74140154}},	//   ránn, _džah, _ྒྲགས_, ান্ট_, 
   {{0x3dc01c06,0x32082517,0x3ea002f0,0xd6843594}},	//   ksiw_, _pray_, jcit_, _кулп, 
   {{0xd25800ee,0x3ea000d7,0x644c002b,0x00000000}},	//   тцн_, dcit_, _śait, --, 
   {{0x3ea016b8,0xae0405d7,0x63743afd,0x00000000}},	//   ecit_, रिसन_, báno, --, 
   {{0x32080158,0x69dc0793,0xe8080b7d,0xd3783afe}},	//   _wray_, _äsev, विया_, _ичи_, 
   {{0x25780ba1,0x3e7c0024,0x32081a7b,0x00000000}},	//   mèla_, kštį_, _tray_, --, 
   {{0x32083aff,0x26c0013b,0x9f5c3b00,0x6d880064}},	// [3910] _uray_, _ɛho_, ítá_, _užak, 
   {{0x201400d0,0x98b00118,0x224400a2,0xe8080fe6}},	//   ócií_, ěděl_, _ýoka_, विमा_, 
   {{0x25780ba1,0x3fc800db,0x00000000,0x00000000}},	//   nèla_, _кыян_, --, --, 
   {{0x27300232,0x637400dd,0x63503b01,0xfbd0007b}},	//   _ráno_, jánl, tāni, بتك_, 
   {{0x2578020c,0xe73801e0,0x63741a1f,0x3e7c0064}},	//   hèla_, ҫел_, záno, gštį_, 
   {{0x6e2c3b02,0x9f5802bd,0x635019ae,0x25a800a2}},	//   myab, _aspè_, rāni, _įal_, 
   {{0x2d983b03,0x01380302,0x2d90009a,0xac94059f}},	//   _huse_, שרות_, _iize_, _ваҳш, 
   {{0x2d983b04,0x005802e4,0x2d900407,0x63503b05}},	//   _kuse_, ישות_, _hize_, pāni, 
   {{0x6e2c3b06,0xd70405cc,0x2328016c,0xdb24006c}},	//   nyab, сные_, ҳони_, _اوقی, 
   {{0xf9903b07,0x2d983b08,0x2d900472,0x9f5802e2}},	//   _قبل_, _muse_, _jize_, _espè_, 
   {{0x23283b09,0x2d983b0a,0x2d903b0b,0x25780ba1}},	//   гони_, _luse_, _mize_, gèla_, 
   {{0x2d903b0c,0xe6940491,0xf77005a9,0x637401a2}},	//   _lize_, _الإد, _قان_, ráno, 
   {{0x2d9802d3,0x6e2c3b0d,0xf414015b,0x3ea0036e}},	//   _nuse_, jyab, ানগর_, vcit_, 
   {{0x2d900513,0x10a03b0e,0x63743b0f,0x25780ba1}},	//   _nize_, зирн, páno, bèla_, 
   {{0x2d983b10,0x1dd83b11,0x3ea00369,0x2578067c}},	//   _ause_, यूनत, tcit_, cèla_, 
   {{0x2d983b12,0xdd900597,0x2d9001c4,0x2ca001ab}},	//   _buse_, كور_, _aize_, echd_, 
   {{0x2d903b13,0x3ea03b14,0x6e2c3b15,0x637400d7}},	// [3920] _bize_, rcit_, gyab, nánm, 
   {{0x3ea00483,0x2d900030,0x27e8012d,0x00000000}},	//   scit_, _cize_, łany_, --, 
   {{0x2d981e54,0x6e2c0009,0x66f83b16,0xd36c0066}},	//   _euse_, ayab, ्याक_, _زهی_, 
   {{0xcee0005e,0x2ca00876,0x6e2c2aed,0x2d90002d}},	//   _нұсқ, achd_, byab, _eize_, 
   {{0x2d900100,0x6e2c0230,0x660c0024,0xdb1c3b17}},	//   _fize_, cyab, _šakn, nspé, 
   {{0x2d900083,0xdb1c000d,0xb7d8072d,0x00000000}},	//   _gize_, lupü, لوتا_, --, 
   {{0xb90014cf,0x108000d1,0x41d800cd,0x00000000}},	//   _था_, ﻨﯩﺪﯨ, भूतस, --, 
   {{0x6294079b,0x2d903b18,0x2b90036b,0xaac4007b}},	//   _ngyo, _zize_, _قیلس, _وتقن, 
   {{0x2d903b19,0xa804056a,0x63743b1a,0xf8b80022}},	//   _yize_, _poñí, ránl, _teĩ_, 
   {{0x9b40168d,0xe9700f78,0x2578068c,0x62943902}},	//   _بۆچو, _قۇند, tèla_, _agyo, 
   {{0xd1b802d3,0xdb1c0254,0xd794007b,0x644c0055}},	//   ታዊት_, kupü, _الصخ, _śair, 
   {{0x6e2c0a55,0x2578068c,0xf77000ec,0x00000000}},	//   yyab, rèla_, _کاڄ_, --, 
   {{0x2578068c,0xdb1c0037,0x6e2c058a,0x00000000}},	//   sèla_, dupü, xyab, --, 
   {{0x2d983b1b,0x2578180f,0x62943b1c,0x98ac0064}},	//   _ruse_, pèla_, _egyo, rifė_, 
   {{0x50640517,0x40343b1d,0x8898008f,0x2d900790}},	//   ётга, перс, רבלי, _rize_, 
   {{0x2d903b1e,0x2d983b1f,0x6e2c3b20,0xe808081e}},	//   _size_, _puse_, tyab, विता_, 
   {{0x2d90020c,0x2d980393,0x5f2c0092,0xddc40064}},	// [3930] _pize_, _quse_, ደሌላቸ, _pykš, 
   {{0x6e2c3b21,0xdb1c239b,0x2ca00192,0x661c3b22}},	//   ryab, kupó, uchd_, äski, 
   {{0x6e943b23,0x2d9803f9,0x6e2c3b24,0x60c8045f}},	//   _мину, _wuse_, syab, _ôfma, 
   {{0x2d900225,0x2d983b25,0x2ca001c7,0x00000000}},	//   _wize_, _tuse_, schd_, --, 
   {{0x4990168d,0x2d980009,0x660c031c,0xaa580131}},	//   سیار, _uuse_, _ġako, шиду_, 
   {{0xa7a83b26,0x2d90039a,0xc27c0a1e,0x660c3b27}},	//   акка_, _uize_, ארדי, _šako, 
   {{0xe80806e3,0x00000000,0x00000000,0x00000000}},	//   विधा_, --, --, --, 
   {{0x3ae03b28,0x00000000,0x00000000,0x00000000}},	//   _pōpō_, --, --, --, 
   {{0xe5580114,0xe8480092,0x00000000,0x00000000}},	//   ијој_, _እንዲጎ, --, --, 
   {{0x59100dd4,0xe8083b29,0x63500882,0x37a80daf}},	//   _ཉོགས_, विदा_, hānt, штән_, 
   {{0xe8543b2a,0x2bd000e1,0xdb100241,0x00000000}},	//   _بناد, _हिफा, _ọ̀tọ, --, 
   {{0x65943b2b,0x63743b2c,0xded81954,0x00000000}},	//   _даду, mánk, ኮትን_, --, 
   {{0x637426f6,0x69dc007c,0x00000000,0x00000000}},	//   lánk, _åsed, --, --, 
   {{0x6608055a,0xdb1c3b2d,0x00000000,0x00000000}},	//   mvek, rspé, --, --, 
   {{0x5f043b2e,0xa2e43b2f,0x2ee83535,0x8fa03b30}},	//   озва, _дойд, ffaf_, дасе, 
   {{0x1ea830bf,0x64400beb,0x9ea8009d,0x00000000}},	//   شاري_, mzli, рваа_, --, 
   {{0xdef80831,0x1d243b31,0x25ac008b,0x63743b32}},	// [3940] лыҡ_, омам, npel_, hánk, 
   {{0x63503a71,0x38603b33,0x660800f1,0x27301f08}},	//   rānu, şiri_, ivek, _bánk_, 
   {{0x64403b34,0x61e43b35,0x63743b36,0x5b240022}},	//   nzli, ltkl, jánk, жьла, 
   {{0x63503b37,0x64403b38,0x66080158,0xbd440014}},	//   pānu, izli, kvek, _کھرى, 
   {{0x198801b9,0x00000000,0x00000000,0x00000000}},	//   абди_, --, --, --, 
   {{0x660828b3,0x97a43b39,0x83a0001f,0x61e4002f}},	//   dvek, орил, _ወደዚህ_, itkl, 
   {{0x660800f1,0x644001a6,0x25ac3b3a,0x61e400bb}},	//   evek, jzli, epel_, htkl, 
   {{0xa2d41b57,0x64400354,0x61e43b3b,0x8f9802e4}},	//   _भाग्, dzli, ktkl, סיפי, 
   {{0x8d900014,0xdb1c0077,0x61e40175,0x27300208}},	//   _رٔہت, supó, jtkl, _mánh_, 
   {{0x2bd02982,0x3b040399,0x73d81ee3,0x53e400c7}},	//   _हिमा, _hamq_, бдор_, оцма, 
   {{0x63500882,0x25ac002d,0x61e40549,0x2730004d}},	//   yānt, apel_, etkl, _oánh_, 
   {{0x6608090c,0x6fd01431,0x61e4002f,0x6d880171}},	//   bvek, _तटबं, ftkl, _užav, 
   {{0x7ae005b1,0xb9e4001f,0xf7703b3c,0x61e4005c}},	//   _mcmt, _ያኔ_, _قاچ_, gtkl, 
   {{0xa3b402ab,0x2578067c,0x95800092,0x3cd003d4}},	//   _चौक_, nèll_, ነቶችን_, স্তৱ, 
   {{0x27300016,0x2f183b3d,0x61e40b4f,0xad240873}},	//   _bánh_, бовь_, atkl, ۋىرى, 
   {{0x21383b3e,0x27303b3f,0x2fcc1b24,0x6e9801c0}},	//   _elph_, _cánh_, čeg_, свар_, 
   {{0x63500882,0x63743b40,0xd1480214,0x27300051}},	// [3950] rānt, zánk, _نشدن_, _dánh_, 
   {{0xfa48069d,0x0ca80107,0x00000000,0x00000000}},	//   _ፓርላማ, ртаи_, --, --, 
   {{0x0b88036b,0x660805b8,0x60f8011a,0x3328002f}},	//   асди_, zvek, _ההתק, _koax_, 
   {{0x7ae001c8,0x63741ab0,0x273001fb,0x00000000}},	//   _ccmt, vánk, _gánh_, --, 
   {{0x6440019b,0x3b040399,0xb3e00154,0x00000000}},	//   zzli, _damq_, ববিজ, --, 
   {{0x7ae000b5,0x99d006ba,0x63742358,0xec3400c7}},	//   _ecmt, رقىت, tánk, _енгь, 
   {{0x3d943b41,0x00000000,0x00000000,0x00000000}},	//   _цирр, --, --, --, 
   {{0x63743b42,0x66083b43,0x394c0fac,0xd7ec3b44}},	//   ránk, tvek, _emds_, اكي_, 
   {{0x59d000af,0x25ac257c,0xe9d00451,0x00000000}},	//   _सियर, upel_, _سٺا_, --, 
   {{0x64403b45,0x69d83b46,0x63743b47,0xa444034b}},	//   tzli, muwe, pánk, знод, 
   {{0x29043b48,0x64400489,0xe2983b49,0x3b040399}},	//   _iala_, uzli, йан_, _yamq_, 
   {{0x29043b4a,0x64403b4b,0x66083b4c,0x33283b4d}},	//   _hala_, rzli, pvek, _coax_, 
   {{0x29043b4e,0x27300085,0x69d83b4f,0x61e4061f}},	//   _kala_, _náni_, nuwe, utkl, 
   {{0x29043b50,0x27300016,0x29fc01a2,0x39800ba1}},	//   _jala_, _sánh_, _mňa_, pòse_, 
   {{0x69d83b51,0x61e43b52,0xca4c0131,0x63740124}},	//   huwe, stkl, ﻏﺮﺍ_, háni, 
   {{0x29043b53,0x69d83b54,0x29fc09a5,0x27300ca8}},	//   _lala_, kuwe, _oňa_, _báni_, 
   {{0x0e603b55,0x69d80428,0x29040311,0xd354011a}},	// [3960] ектн, juwe, _oala_, _מיקי_, 
   {{0x69d83b56,0x2b4c3b57,0x27303b58,0xe0d8033a}},	//   duwe, _amec_, _dáni_, _уво_, 
   {{0x69d83b59,0x2730004d,0x29fc3b5a,0xa0200254}},	//   euwe, _tánh_, _aňa_, ööda, 
   {{0x29043b5b,0x23a0068f,0x394c02c4,0x69d83b5c}},	//   _aala_, _mój_, _smds_, fuwe, 
   {{0x6374307d,0x69d83b5d,0x00000000,0x00000000}},	//   gáni, guwe, --, --, 
   {{0x29043b5e,0x29fc01a2,0xdcb03b5f,0x6d883b60}},	//   _cala_, _dňa_, _سىر_, _džas, 
   {{0x29043b61,0x69d8000f,0x17640055,0x9b4400f2}},	//   _dala_, auwe, _kṛṣī, _فنآو, 
   {{0x69d83b62,0x29043b63,0x2bd001bc,0x86c00131}},	//   buwe, _eala_, _हिता, ىيىن, 
   {{0x63741280,0xa2d40574,0x8d140014,0x69d83b64}},	//   cáni, _भाज्, _ظٲہر_, cuwe, 
   {{0x27e80227,0x23a0012d,0x69f0004e,0xf434068e}},	//   ńana_, _bój_, _рүшт, деоэ, 
   {{0x72c40228,0x291400d7,0x00000000,0x00000000}},	//   үбүз, ýbaš_, --, --, 
   {{0x29043b65,0x17840228,0xe80802ab,0xdce400ef}},	//   _zala_, _эгем, विरा_, _aukļ, 
   {{0x9584005e,0x51843b66,0x29043b67,0x4cc4015b}},	//   _елде, зува, _yala_, র্টু, 
   {{0x29043b68,0x3d0c00c5,0x395c017a,0x273002d2}},	//   _xala_, _डोले_, nnvs_, _ráni_, 
   {{0x84e436e9,0x9f5826b7,0x69d803fa,0x9690006c}},	//   _رفيق_, _espí_, zuwe, _تیکش, 
   {{0x273002fb,0x69d80066,0xed5001d9,0x69cc07af}},	//   _páni_, yuwe, چھس_, _सिली, 
   {{0x74142304,0xb7d400b8,0x660c025c,0x00000000}},	// [3970] _روکا, _iṣud, _ġakk, --, 
   {{0x2bd005f9,0x9b6400d1,0x63741155,0x00000000}},	//   _हिदा, ۈنلۈ, váni, --, 
   {{0x29043b69,0x62980316,0x3d0c0490,0x69d83b6a}},	//   _rala_, ětov, _डोळे_, wuwe, 
   {{0x69d83b6b,0x637409c2,0xfbd03b6c,0x00000000}},	//   tuwe, táni, اتل_, --, 
   {{0x29043b6d,0xa2a007f8,0xbb4c0150,0x00000000}},	//   _pala_, कुट्, _ﻁﺒﻌ_, --, 
   {{0x63743b6e,0x29043b6f,0x69d808e7,0xe8080073}},	//   ráni, _qala_, ruwe, विला_, 
   {{0x637404d4,0x69d83b70,0xfa240327,0x25a80135}},	//   sáni, suwe, འདུན_, _ħalq_, 
   {{0x29043b71,0x69d83b72,0x2b4c0077,0xa2a01a55}},	//   _wala_, puwe, _umec_, कुञ्, 
   {{0x29043b73,0x6d88071b,0x69d8208d,0x6aa803ac}},	//   _tala_, _užas, quwe, _ifef, 
   {{0x29040069,0x6d5800f2,0x00000000,0x00000000}},	//   _uala_, éwah, --, --, 
   {{0x6aa80270,0x69c82d8b,0x00000000,0x00000000}},	//   _kfef, _hvee, --, --, 
   {{0x4cc40154,0x661c007c,0x00000000,0x00000000}},	//   র্চু, äsks, --, --, 
   {{0x3980067c,0x00000000,0x00000000,0x00000000}},	//   lòsa_, --, --, --, 
   {{0xe69400c7,0x59100327,0xe3b800d8,0x00000000}},	//   _еиҵы, _ཉོབས_, _дбк_, --, 
   {{0xdef80831,0xd0043b74,0x10a03b75,0xdee43b76}},	//   ҙың_, мере_, тисн, мови, 
   {{0x69c8005b,0xdb1c0108,0x057402f2,0xb4000150}},	//   _ovee, lupö, _باڵد, _сүюд, 
   {{0x9e6400f2,0x626400d1,0x59d0000d,0x00000000}},	// [3980] ذارن, _تاغق, _सिधर, --, 
   {{0x6aa83b77,0xef18013e,0x201c0037,0x4d6000d8}},	//   _afef, омӣ_, ätis_, вкув, 
   {{0x69c804c9,0xf1a8168d,0x1ae43b78,0x4cc40183}},	//   _avee, _وایه_, доем, ৰ্ভু, 
   {{0x6ea405f9,0x26f805d7,0x235c02e3,0xda64027d}},	//   _कलयु, ्योर_, ọlfụ_, واشي, 
   {{0xd9443b79,0x9f580589,0x6aa80175,0x4ef8011a}},	//   меди, _espã_, _dfef, _והכו, 
   {{0x6aa80354,0x38c83b7a,0x63743b7b,0x26103b7c}},	//   _efef, ساتی_, mánu, तिनी_, 
   {{0x69c83b7d,0x6aa81f69,0x273001ef,0x00000000}},	//   _evee, _ffef, _lánu_, --, 
   {{0x6d8805a1,0x61f40857,0x8f980375,0xe9a800f7}},	//   _užar, _opyl, חיקי, زدۇن_, 
   {{0x63ac009b,0x18a400f7,0x98a43b7e,0x2730032e}},	//   _čana, _жазм, _жизе, _nánu_, 
   {{0x3980067c,0x6d9006be,0x00000000,0x00000000}},	//   bòsa_, cıağ, --, --, 
   {{0x61f40006,0x741400c6,0xdecc02d3,0x69c83b7f}},	//   _apyl, روحا, ብሉን_, _zvee, 
   {{0x2bd022e3,0x60c8045f,0xe9380150,0xd5b80395}},	//   _हिसा, _ôfmj, _وسەت_, _дск_, 
   {{0xc1b83b80,0x41e402d5,0xe6c401e2,0x46a000f3}},	//   млях_, кіра, _ستني, _рачв, 
   {{0x273001e1,0xdbc40432,0x7124129d,0x00000000}},	//   _dánu_, _göçg, رىزم, --, 
   {{0x61e00115,0x04d80375,0xdb1c000d,0x00000000}},	//   _ĥole, _וקול, lupõ, --, 
   {{0xb8e00135,0x660c3b81,0x6e9400c7,0x00000000}},	//   _གབ_, _šaki, еибу, --, 
   {{0x8af403be,0xd1b8005e,0x63743b82,0xd1d4001f}},	// [3990] şəkk, _باعا_, gánu, ክቶች_, 
   {{0xfa0c025c,0x00000000,0x00000000,0x00000000}},	//   _གླེན_, --, --, --, 
   {{0x6aa83b83,0x69c83b84,0x31703b85,0x00000000}},	//   _pfef, _svee, mozz_, --, 
   {{0x6dc000cf,0xdb1c000d,0x00000000,0x00000000}},	//   _مۅرۅ, kupõ, --, --, 
   {{0x63741b73,0x2bd00073,0xf8e000cd,0x00000000}},	//   mánt, _हिवा, _नाशय, --, 
   {{0x63743b86,0xde1400c8,0x27300162,0x00000000}},	//   lánt, _אַלץ_, _lánt_, --, 
   {{0x2d901d00,0xdb1c01f4,0x00000000,0x00000000}},	//   _ﺑﻮﻳﻰ_, vupö, --, --, 
   {{0x6aa8009a,0x6e28033f,0x7c280129,0x63743b87}},	//   _ufef, _żeby, _àdra, nánt, 
   {{0x29d42266,0x317001ed,0x3a2004e6,0xdb1c1b99}},	//   _سياس, kozz_, äipt_, gupõ, 
   {{0x7c440209,0x27300118,0x63743b88,0x89143b89}},	//   _öwrü, _ránu_, hánt, _تبرئ, 
   {{0x61f43b8a,0x0590006c,0xa2e43b8b,0x63740022}},	//   _spyl, _یاتگ, нонд, kánt, 
   {{0xe6103b8c,0x273002f0,0x637400c7,0x00000000}},	//   _مشت_, _pánu_, jánt, --, 
   {{0x27300162,0x63740332,0xe6180a5b,0x00000000}},	//   _dánt_, dánt, _хдл_, --, 
   {{0x637400e5,0xdb1c00d7,0x213c0332,0x00000000}},	//   vánu, lupô, óth_, --, 
   {{0xe46400c5,0xb424007b,0xaf340014,0x201c32bc}},	//   ööde_, _لعيو, ھرِت, ãti_, 
   {{0x53980375,0x63743b8d,0x69d40171,0x00000000}},	//   _ציפו, gánt, _āzen, --, 
   {{0x31703b8e,0xdce4013d,0xe1943b8f,0x00000000}},	// [39a0] bozz_, _sukı, _проэ, --, 
   {{0x63740022,0x00000000,0x00000000,0x00000000}},	//   aánt, --, --, --, 
   {{0x59d00cb4,0x2578068c,0x00000000,0x00000000}},	//   _सिहर, rèlh_, --, --, 
   {{0x2bd03b90,0x27300077,0x63743b91,0x00000000}},	//   _हिरा, _máns_, máns, --, 
   {{0x63743b92,0x27301427,0xf8b03b93,0xd35400d9}},	//   láns, _láns_, لکا_, עיני_, 
   {{0x37f8084c,0xdce40166,0x4934187f,0x6d880064}},	//   декэ_, _tukı, нзію_, _užap, 
   {{0x69dc08fb,0x8d6002e8,0x00000000,0x00000000}},	//   _åsen, _свре, --, --, 
   {{0xdb0c01e3,0x00000000,0x00000000,0x00000000}},	//   _avbö, --, --, --, 
   {{0x637400d2,0xcb64005b,0x00000000,0x00000000}},	//   háns, _чате_, --, --, 
   {{0x63741ab0,0x34940798,0xd8740137,0x98a4361e}},	//   káns, капр, _كااب, _чиже, 
   {{0x7f443b94,0x25bc0327,0x63740008,0xdb1c000d}},	//   khiq, _ewwl_, jáns, supõ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7f44058a,0xff600092,0x63743b95,0x00000000}},	//   dhiq, _ተለያዩ_, vánt, --, 
   {{0x63740008,0x2bd00d2e,0x00000000,0x00000000}},	//   fáns, _हिला, --, --, 
   {{0x63743b96,0x8f840063,0xdb1c3b97,0x00000000}},	//   tánt, ећал, mspæ, --, 
   {{0x93243b98,0x7f44014f,0x69c00764,0xdb1c36e0}},	//   _سربن, ghiq, रीडी, lspæ, 
   {{0x63740e55,0x00000000,0x00000000,0x00000000}},	// [39b0] ránt, --, --, --, 
   {{0xcee83b99,0x63743b9a,0xbd780212,0x95740023}},	//   _کردن_, báns, ебує_, _ከባብን_, 
   {{0x63740c63,0x8c643b9b,0x1ea80451,0xb92400b8}},	//   pánt, хтад, _ڪاپي_, _saḿś, 
   {{0x7f440986,0x2578067c,0xee7002dd,0x0dc80117}},	//   chiq, rèli_, _ұңғы, _нуги_, 
   {{0x6f1c3046,0x6f0c3b9c,0x3d0c0073,0x00000000}},	//   _insc, mdac, _डोके_, --, 
   {{0xdb1c005c,0xdd1400d7,0x2874008e,0x00000000}},	//   jspæ, _päťb, кыйр, --, 
   {{0xd940241e,0xdb1c3b9d,0x18643b9e,0x6f0c08c2}},	//   рещи, dspæ, каши_, odac, 
   {{0xe6183b9f,0x78b80083,0x27300ca8,0x00000000}},	//   дди_, abvv, _ráns_, --, 
   {{0xd70434d8,0x3b640801,0xe644016c,0x63741f08}},	//   тные_, _сърв, тепп, záns, 
   {{0x6d443ba0,0x6f0c3ba1,0x69c001bc,0x31f40327}},	//   nhha, hdac, रीणी, _བརྟར_, 
   {{0x6f1c3ba2,0x142002d5,0xe89400c7,0x6f0c01ab}},	//   _onsc, адэм, _ражь, kdac, 
   {{0x69d82a28,0xdd0001a6,0x6f0c3ba3,0x637401d3}},	//   orwe, _čuči, jdac, váns, 
   {{0x6f0c220c,0xdea00b43,0x6b880327,0x6728036e}},	//   ddac, ییدی, _mheg, mjej, 
   {{0x6f1c3ba4,0x67283ba5,0x6b880477,0x69d804ba}},	//   _ansc, ljej, _lheg, irwe, 
   {{0xe3643ba6,0x69d80730,0x7f443ba7,0x6f0c01f5}},	//   _икки, hrwe, thiq, fdac, 
   {{0xd36c0597,0x67283ba8,0x7f440357,0x66f83806}},	//   _وهو_, njej, uhiq, ्यटक_, 
   {{0xdd903ba9,0xe0d43baa,0x7f4402d3,0x1d08016c}},	// [39c0] لور_, _июнь, rhiq, меаи_, 
   {{0x6b882dab,0x6f1c3bab,0x6f0c3bac,0x7f443bad}},	//   _aheg, _ensc, adac, shiq, 
   {{0x7f443bae,0x69d82426,0x6b88004c,0x0d203baf}},	//   phiq, erwe, _bheg, шүрү, 
   {{0x5e8401d9,0x69d80142,0x67280327,0xda78011c}},	//   _لٔجم, frwe, jjej, мял_, 
   {{0x6b880050,0x672801fa,0x69dc3bb0,0xaae43bb1}},	//   _dheg, djej, _åsel, اسمو, 
   {{0x6d443bb2,0x49703bb3,0xdca40b3e,0x6b880e78}},	//   chha, аліс, _јави, _eheg, 
   {{0x69d81983,0x28a401ec,0x00000000,0x00000000}},	//   arwe, ушіг, --, --, 
   {{0x6b88047e,0x67280240,0xa3d4000d,0xdce0000d}},	//   _gheg, gjej, िओन_, _पाँछ, 
   {{0xb908015b,0xdb1c3bb4,0x00000000,0x00000000}},	//   _বস_, tspæ, --, --, 
   {{0x985411ca,0x6b88036e,0x970000d1,0x6f0c012d}},	//   _итеш, _zheg, _چېغى, zdac, 
   {{0x8490044e,0x44240212,0x6f0c3bb5,0xdb1c3bb6}},	//   _መቓልሕ_, вцям_, ydac, rspæ, 
   {{0x6b880472,0xdb1c3bb4,0xa8540798,0xc6a02377}},	//   _xheg, sspæ, _стуј, _крши, 
   {{0xdb1c3bb7,0x35d40108,0x6f0c00d7,0x00000000}},	//   pspæ, _солё, vdac, --, 
   {{0xf8b4367a,0x74141ec7,0x25a8007b,0xdb1c3bb8}},	//   ुरिय, _موتا, _أدني_, lspä, 
   {{0x4ea403b7,0xc0580111,0x6f0c002f,0xef1000db}},	//   врза, віт_, tdac, бүнө, 
   {{0x6f0c3bb9,0xdb1c3bba,0x00000000,0x00000000}},	//   udac, nspä, --, --, 
   {{0x6f0c3bbb,0x7f940107,0x6b881848,0x92680816}},	// [39d0] rdac, ратх, _rheg, _юрка_, 
   {{0x50b42ecf,0x6b883bbc,0x4fc43bbd,0x6f0c284c}},	//   _अभिष, _sheg, _исма, sdac, 
   {{0x6b88207f,0xe6fc031c,0x6ab80175,0xdb1c007c}},	//   _pheg, _དྲྀན_, tbwf, kspä, 
   {{0x6f1c3bbe,0x41c43bbf,0x6d443bc0,0xcf24143e}},	//   _unsc, _حقیق, shha, _شرجي, 
   {{0x6b881682,0x69d82c6a,0x98bc3bc1,0xdb1c007c}},	//   _vheg, urwe, _aktı_, dspä, 
   {{0x3208090c,0xbfc40118,0xdb1c002f,0x2a68003d}},	//   _msay_, řížs, espä, ħab_, 
   {{0x6b880c3a,0x6d543bc2,0x67283bc3,0xdb1c01c7}},	//   _theg, _imza, tjej, fspä, 
   {{0x320814dc,0x6d54009a,0x6b881ab4,0xdb1c01e3}},	//   _osay_, _hmza, _uheg, gspä, 
   {{0x67283bc4,0x64a43bc5,0x2558084c,0x67f802d2}},	//   rjej, лапа, ернэ_, _bújö, 
   {{0xc98424a0,0x67283bc6,0xe50800ec,0xdb1c0254}},	//   _руби, sjej, ريجو_, aspä, 
   {{0x32083bc7,0xf2840248,0x799401c6,0x67280200}},	//   _asay_, _ibẹ̀_, _тифф, pjej, 
   {{0x67283bc8,0xdef401f3,0xa9e00150,0x00000000}},	//   qjej, ዎትን_, _ﺍﻻﯕﺴ, --, 
   {{0x6d543bc9,0x20d402bf,0x25780066,0x59c4090a}},	//   _omza, лівс, wèlu_, रीपर, 
   {{0x06e03bca,0xa11405ae,0xdb1c007c,0x75440024}},	//   _गाँव_, دوست, mspå, _кніз, 
   {{0xe3b03bcb,0x3208035a,0xdb1c0267,0x504000cf}},	//   _ارت_, _esay_, lspå, берб, 
   {{0x6d543bcc,0x2eb41614,0x1c440220,0xe9c401d3}},	//   _amza, исус, ңнам, _وں_, 
   {{0x1e843bcd,0xdb1c01e3,0x00000000,0x00000000}},	// [39e0] улам, nspå, --, --, 
   {{0xccc00006,0x00000000,0x00000000,0x00000000}},	//   йбуй, --, --, --, 
   {{0x06e03bce,0x9f5c291f,0xdb1c023a,0xdee402e8}},	//   _गांव_, ító_, yspä, _йони, 
   {{0x6d543bcf,0x9a6803cc,0xdb1c007c,0x00000000}},	//   _emza, ىمال_, kspå, --, 
   {{0x2578068c,0x176400b8,0xdb1c007c,0x630c0154}},	//   nèls_, _kṛṣā, jspå, ষাপট_, 
   {{0x3f803bd0,0xed3400a8,0xdb1c3bd1,0x00000000}},	//   lliu_, _кэсэ, dspå, --, 
   {{0xb8cc000d,0xdb1c3bd2,0x176400cd,0x182400f2}},	//   _गल_, tspä, _mṛṣā, اقعی_, 
   {{0xd5b83bd3,0xdb1c005b,0x5ed40154,0x8c18011a}},	//   нсо_, uspä, ড্রে, _אולי, 
   {{0x261002ab,0x59843bd4,0x660c01fa,0xdb1c3bd5}},	//   तिषी_, _блаб, _šakr, rspä, 
   {{0x63500882,0x3f800007,0x2578180f,0xd90c3bd6}},	//   māny, hliu_, dèls_, _ریب_, 
   {{0x3f800024,0xdb1c007c,0x47d03bd7,0x4914011a}},	//   kliu_, pspä, _هيلر, _תקבל_, 
   {{0x461024d0,0x00000000,0x00000000,0x00000000}},	//   _گوهر, --, --, --, 
   {{0x2578067c,0xc05802dd,0x3f800064,0x00000000}},	//   gèls_, ңіс_, dliu_, --, 
   {{0x386c01a9,0xc69008a8,0x3f800064,0x00000000}},	//   _kxdr_, _פאס_, eliu_, --, 
   {{0x68f43bd8,0x660c02d2,0xe50800cd,0x00000000}},	//   _özde, _áakr, _वसति_, --, 
   {{0x3f800ba3,0x91f80085,0x320803f0,0x72d412d7}},	//   gliu_, ɛ́ng, _tsay_, _тоиф, 
   {{0x6e9801c0,0x2578068c,0x3ef80276,0x320803ac}},	// [39f0] твар_, cèls_, ынтэ_, _usay_, 
   {{0x27e80054,0x80dc009e,0xf3fc0327,0x3f803bd9}},	//   ńani_, ম্ব্, _ྐྱོད_, aliu_, 
   {{0x3f803bda,0x63ac00f3,0x6b7401c0,0x04d8011a}},	//   bliu_, _čank, алжу, תקבל, 
   {{0x3f800ffb,0xa8243bdb,0x8d740133,0x7bd803b2}},	//   cliu_, یکان, _ڕازا, ávua, 
   {{0x2bd000e1,0xa8c430c2,0x00000000,0x00000000}},	//   _हिका, айлд, --, --, 
   {{0x26c8071b,0x00000000,0x00000000,0x00000000}},	//   _žao_, --, --, --, 
   {{0xe73000c6,0xab940212,0x00000000,0x00000000}},	//   قصة_, _виві, --, --, 
   {{0xdb1c0267,0x661c1f53,0x00000000,0x00000000}},	//   tspå, åsko, --, --, 
   {{0x2578180f,0x6350002b,0x00000000,0x00000000}},	//   xèls_, cāny, --, --, 
   {{0x66d405d9,0x39400d27,0x25781497,0xdb1c01e3}},	//   _چيائ, ëist_, vèls_, rspå, 
   {{0xc86439c1,0x2d800165,0xdb1c3bdc,0xe364014b}},	//   _стаи, ilhe_, sspå, икои, 
   {{0x3634107f,0x25780561,0xdb1c0267,0x9fb0000d}},	//   _گرمس, tèls_, pspå, _आà_, 
   {{0xf7703bdd,0x6d883bde,0xd24c009f,0x00000000}},	//   _عام_, _džaz, ِنُ_, --, 
   {{0xe0443bdf,0xa0683be0,0x00000000,0x00000000}},	//   анги, вага_, --, --, 
   {{0x2d8002c4,0x1f5401b9,0x25780ba1,0x4f380014}},	//   dlhe_, атаё, sèls_, ھتِھ_, 
   {{0x3f8023e0,0x2d80067c,0x2578067c,0x00000000}},	//   uliu_, elhe_, pèls_, --, 
   {{0xd36c3be1,0x176400b8,0x5de400d4,0xe3b0009f}},	// [3a00] _تهي_, _tṛṣā, ржза, _ارڪ_, 
   {{0xfe443be2,0x3f803be3,0x00000000,0x00000000}},	//   анғо, sliu_, --, --, 
   {{0x3f8000db,0x00000000,0x00000000,0x00000000}},	//   pliu_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdca43b7e,0x201801a6,0x3980067c,0x00000000}},	//   _ваги, _hrpi_, lòsi_, --, 
   {{0x9d540137,0x9d443be4,0x25a8010e,0x5fd807af}},	//   _ئنست, _тегд, _çaly_, _बटाल, 
   {{0xe7440724,0x3980067c,0x9f4c01e1,0x59d03be5}},	//   әүче_, nòsi_, _èfó_, _सिकर, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfbd8009e,0xd564337e,0x00000000,0x00000000}},	//   _সহিত, итоп, --, --, 
   {{0x201806af,0x98b800bc,0x00000000,0x00000000}},	//   _orpi_, _उभिए, --, --, 
   {{0xf8b43be6,0x56f00220,0x33740816,0x201c143a}},	//   ुरीप, _дүйс, йгор, åtil_, 
   {{0x395c3be7,0x0c7c0023,0x92680f89,0x00000000}},	//   livs_, _ንታሪኽ_, врга_, --, 
   {{0x644400af,0x20183be8,0x00000000,0x00000000}},	//   _ühin, _arpi_, --, --, 
   {{0x395c3be9,0x05703bea,0x76f800cc,0x00000000}},	//   nivs_, _واود, _অফিছ_, --, 
   {{0x201816a3,0xbfa800f7,0xd3c4215c,0xb4b401ee}},	//   _crpi_, итте_, _ئتتى, _киҙә, 
   {{0xf8b40316,0xc4980a1e,0xcc08105d,0x00000000}},	//   ुरुप, _בשות, ێزان_, --, 
   {{0x2d801a7f,0x201801e4,0x7bd8022c,0x59d00c4c}},	// [3a10] tlhe_, _erpi_, ávun, _सिगर, 
   {{0x69dc00cc,0x52b000cf,0x5058010a,0x00000000}},	//   _åsei, _دەڭئ, _армă, --, 
   {{0x3980067c,0x395c3beb,0x4ba40137,0x690403b9}},	//   còsi_, divs_, рөгү_, _ördə, 
   {{0x5ea4013e,0x7b640108,0xed5001d3,0xadbc0064}},	//   _гурҷ, отче, _کھر_, _памi, 
   {{0xf8b43bec,0x00000000,0x00000000,0x00000000}},	//   ुरूप, --, --, --, 
   {{0x2aac3bed,0x684401d5,0x59c404e4,0x9f4c0248}},	//   _bóbó_, йнла, रीधर, _èfò_, 
   {{0xf9903bee,0x00000000,0x00000000,0x00000000}},	//   ذبه_, --, --, --, 
   {{0xd6cc04a9,0x2ee83bef,0x7ae4026c,0x7c38007c}},	//   ىقى_, ngaf_, òitt, ävre, 
   {{0xe57814a4,0x281403e6,0x00000000,0x00000000}},	//   лзи_, _گواس, --, --, 
   {{0xa5080063,0x2b5c0142,0xa0200254,0x00000000}},	//   ћена_, liwc_, ööka, --, 
   {{0xa41402f5,0x64a43bf0,0xe61000f2,0x00000000}},	//   াহ্য_, _һала, زشک_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x26cc3bf1,0x00000000,0x00000000,0x00000000}},	//   maeo_, --, --, --, 
   {{0x66083bf2,0x26cc3bf3,0x39800561,0x00000000}},	//   mwek, laeo_, tòsi_, --, 
   {{0x66083bf4,0x00000000,0x00000000,0x00000000}},	//   lwek, --, --, --, 
   {{0x660801c8,0x2918013f,0x3980067c,0x26cc3bf5}},	//   owek, _ɔsaa_, ròsi_, naeo_, 
   {{0x66083bf6,0xf1d405f5,0x25ac01f5,0xdb1c03b2}},	// [3a20] nwek, _мөрө, nqel_, mspø, 
   {{0x66083bf7,0x3980067c,0x26cc0393,0xdb1c03cd}},	//   iwek, pòsi_, haeo_, lspø, 
   {{0x61e43bf8,0x66083bf9,0x201802d1,0x661c08fb}},	//   lukl, hwek, _urpi_, åskj, 
   {{0x588401e0,0x5f043bfa,0xeb5400d1,0x60cc3bfb}},	//   ҙыла, _узма, يىلگ, labm, 
   {{0xceb01a4c,0x395c1570,0x66083bfc,0x588407dd}},	//   _מיר_, tivs_, jwek, әыла, 
   {{0x66080161,0x60cc014f,0xd5b80c60,0x2aac01e1}},	//   dwek, nabm, қси_, _póbó_, 
   {{0xd7f83bfd,0x395c01e6,0x61e43bfe,0xdb1c0158}},	//   уул_, rivs_, hukl, kspø, 
   {{0x61e43bff,0x35b43c00,0x395c07de,0x26cc0393}},	//   kukl, обир, sivs_, gaeo_, 
   {{0x66083c01,0xdb1c3c02,0xeb300228,0xf8b82cc8}},	//   gwek, dspø, _تۉند, _көй_, 
   {{0x61e43c03,0xf8ac0307,0x26cc0175,0x9808072d}},	//   dukl, _चलिय, aaeo_, _متصف_, 
   {{0xd4983596,0x16140307,0x26cc0393,0x60cc0477}},	//   ыри_, तिहर_, baeo_, dabm, 
   {{0x66083c04,0x26cc003a,0x67f8010f,0x8724022e}},	//   bwek, caeo_, _כּנס, _гўша_, 
   {{0x66083c05,0xf8ac2e05,0xd7f800fb,0x00000000}},	//   cwek, _चलाय, _шуҡ_, --, 
   {{0x067804ac,0x661c1600,0x00000000,0x00000000}},	//   _ענגל, æske, --, --, 
   {{0x03c00124,0x61e40153,0x7bd80162,0x00000000}},	//   _есым, aukl, ávul, --, 
   {{0xbfa83c06,0x61e43c07,0xeeb806b3,0x53440cdd}},	//   стре_, bukl, рлаш_, _ыхла, 
   {{0x61e40365,0x2ee83c08,0x60cc022e,0x00000000}},	// [3a30] cukl, rgaf_, babm, --, 
   {{0x4c4831af,0x2ee80142,0x00000000,0x00000000}},	//   ляем_, sgaf_, --, --, 
   {{0xfbd0034c,0x66083c09,0x70940cc9,0xbc68007b}},	//   فتن_, zwek, _фанф, ممكن_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3cf0036e,0x00000000,0x00000000,0x00000000}},	//   çovë_, --, --, --, 
   {{0x7ff40502,0xad240131,0x6e2c3c0a,0xa7b40640}},	//   _بسیا, _بىسى, mxab, осиј, 
   {{0x61e403ee,0x6608020c,0x26cc3c0b,0x3b640a81}},	//   zukl, wwek, taeo_, _کێنہ, 
   {{0xe73807dd,0x59c4038e,0x66083c0c,0x61e43c0d}},	//   реи_, रीहर, twek, yukl, 
   {{0x60cc3c0e,0x6e2c009a,0x26cc3c0f,0x7ae400ae}},	//   yabm, nxab, raeo_, óite, 
   {{0x61e407f5,0x66080d47,0xb664001f,0x26cc0393}},	//   vukl, rwek, _ዲፕሎማ_, saeo_, 
   {{0x66083c10,0x26cc003a,0x0a080011,0x6e2c01a9}},	//   swek, paeo_, _শপিং_, hxab, 
   {{0x61e43c11,0xf7700491,0xfcf002d3,0x6e2c009a}},	//   tukl, _كان_, _ሃናጺ_, kxab, 
   {{0xdb1c3c12,0x2918013b,0x1b78010f,0x00000000}},	//   rspø, _ɔsan_, שטרע, --, 
   {{0xdb1c2d75,0x61e43c13,0xc8b803ce,0xf674009d}},	//   sspø, rukl, ॉरिट, _эгчэ, 
   {{0x61e43c14,0x10a03c15,0x48f83c16,0x26100b27}},	//   sukl, дирн, ल्यो_, तिकी_, 
   {{0x61e43c17,0x68ec0198,0xd00c01d9,0x00000000}},	//   pukl, ɗade, کلہ_, --, 
   {{0x6e2c2798,0x60cc0477,0x61e401a9,0xe0d8361e}},	// [3a40] gxab, pabm, qukl, _квп_, 
   {{0xf1b8012c,0x320c05d1,0x48f80d0d,0x9c183c18}},	//   íše_, çeye_, ल्मो_, ицеф_, 
   {{0xdaa801f0,0x00000000,0x00000000,0x00000000}},	//   авед_, --, --, --, 
   {{0x3074010a,0x00000000,0x00000000,0x00000000}},	//   _хуьс, --, --, --, 
   {{0xcb043c19,0x4aa43c1a,0x00000000,0x00000000}},	//   زيون_, әкән_, --, --, 
   {{0xb7c400d1,0x00000000,0x00000000,0x00000000}},	//   приқ, --, --, --, 
   {{0x98bc084c,0x273001ed,0xded40023,0x00000000}},	//   _altă_, _hány_, _ካቢነ_, --, 
   {{0x7f440784,0xcc54011a,0x00000000,0x00000000}},	//   nkiq, _ובלי_, --, --, 
   {{0x55043c1b,0xcf900375,0x7a1801e2,0x00000000}},	//   очна, וטה_, _دښار_, --, 
   {{0x63743c1c,0xe9702e56,0x7f440309,0xd94400ec}},	//   mány, _كۇند, hkiq, _بئري, 
   {{0x7f440d04,0x273001ed,0x73c40724,0x637401d3}},	//   kkiq, _lány_, чәле, lány, 
   {{0x63b42b57,0x63ac310a,0x8604072d,0x00000000}},	//   ízna, _čant, حقیق_, --, 
   {{0x69dc08fb,0x6fcc00c5,0x15b000d1,0x6e2c3c1d}},	//   _åset, _तबहू, _تەخس, xxab, 
   {{0xa9b81df2,0x77603c1e,0x7640010b,0x00000000}},	//   ﻧﺪﯨﺴ, limx, mymy, --, 
   {{0x7640010b,0x637401ed,0xf4840133,0x00000000}},	//   lymy, hány, _عاتی, --, 
   {{0xadb43c1f,0x6e2c01c6,0x61f401ed,0x00000000}},	//   збаш, txab, églá, --, 
   {{0x76400209,0x0dc80a93,0x48f83c20,0x00000000}},	// [3a50] nymy, руби_, ल्डो_, --, 
   {{0x661c05ac,0x776001d5,0x6e2c058a,0x2730013a}},	//   åski, himx, rxab, _dány_, 
   {{0x41740220,0x76403c21,0x75380213,0x00000000}},	//   _تايس, hymy, _movz, --, 
   {{0x2d840075,0x9508025c,0x90e43c22,0x7f440113}},	//   ﺪﯨﻜﻰ_, _ཀིའི_, _اسکن, ckiq, 
   {{0x637401ed,0x692401b9,0x7640010e,0x1de0000d}},	//   gány, змла, jymy, _पियत, 
   {{0xefd40201,0x764000ee,0x753800df,0x4cc400fe}},	//   ርገው_, dymy, _novz, ৰ্জু, 
   {{0x6d443c23,0xe7383c24,0x644c03f9,0x18a03c25}},	//   mkha, йек_, _ƙaim, нашм, 
   {{0x6d443c26,0x637401ed,0xe8f80451,0xe7280107}},	//   lkha, bány, _گذرڻ_, соид_, 
   {{0x6d4420a2,0x764000ee,0xc9840640,0x9f5c06af}},	//   okha, gymy, _дужи, ïté_, 
   {{0x6d443c27,0x69c83699,0x644400c5,0x00000000}},	//   nkha, _iwee, _ühik, --, 
   {{0x6aa800fb,0x69c80099,0x75380427,0x76400076}},	//   _kgef, _hwee, _dovz, aymy, 
   {{0x69c83c28,0x6d443c29,0xd7f80375,0x7c38005c}},	//   _kwee, hkha, _להעל, øvri, 
   {{0x6d4400dc,0x69c80083,0x3980068c,0xe604005b}},	//   kkha, _jwee, pòst_, örää, 
   {{0x69c83c2a,0x55b80375,0x6d440472,0x27300118}},	//   _mwee, _המסו, jkha, _rány_, 
   {{0x65603c2b,0x69c800aa,0x201c2485,0x601000e4}},	//   milh, _lwee, íti_, _ẽmby, 
   {{0x6aa83c2c,0x64400408,0x1ea82085,0x69c83c2d}},	//   _ngef, myli, صاري_, _owee, 
   {{0x69c802e3,0x9f5808a7,0x6d440270,0x67380067}},	// [3a60] _nwee, _uppí_, fkha, _mowj, 
   {{0x6aa83c2e,0x65603c2f,0x637401ed,0x7f440309}},	//   _agef, nilh, vány, skiq, 
   {{0x64400cfd,0x76403c30,0x69c83c31,0x91380375}},	//   nyli, zymy, _awee, _העיק, 
   {{0x6d443c32,0x69c80337,0x637401d3,0x65600477}},	//   akha, _bwee, tány, hilh, 
   {{0x64403c33,0x6d440198,0x6aa80036,0xf38c010f}},	//   hyli, bkha, _dgef, בראָ, 
   {{0x6d443c34,0xdd90006c,0x69c80522,0x3dc00bc9}},	//   ckha, _سوز_, _dwee, mpiw_, 
   {{0x65603c35,0x69c80a49,0x06e000bd,0x7760022e}},	//   dilh, _ewee, _মসজি, timx, 
   {{0x64403c36,0x764000ee,0xdb1c002f,0xfb1800e5}},	//   dyli, tymy, nspü, _برآں_, 
   {{0x7538389c,0x69c81c1d,0x65603c37,0x21380076}},	//   _povz, _gwee, filh, _ooph_, 
   {{0x764009a5,0x661c3c38,0x65600115,0x224003cd}},	//   rymy, æska, gilh, dykk_, 
   {{0x76403c39,0x69c83c3a,0xa2bc0490,0x69dc2dba}},	//   symy, _zwee, _व्ह्, _åser, 
   {{0xc7b006a9,0x394c007b,0xe6b401d5,0x6738010b}},	//   _טבע_, _hlds_, _قلمگ, _gowj, 
   {{0x644000ad,0xf8d01428,0x21f000ee,0x6d443c3b}},	//   ayli, _सजाय, вҗыс, ykha, 
   {{0x9f58026c,0x65603c3c,0x67380009,0xc1a400d8}},	//   _appà_, cilh, _zowj, ејси, 
   {{0xdb1c3c3d,0xf1d80210,0x8004004e,0x00000000}},	//   nspó, _भटकन, нчте, --, 
   {{0x6d440bc9,0x64600210,0x00000000,0x00000000}},	//   wkha, ówił, --, --, 
   {{0x6d443c3e,0x394c3c3f,0x33280051,0x00000000}},	// [3a70] tkha, _olds_, _inax_, --, 
   {{0x95080156,0x9f580ffb,0x69c80099,0x0ca8016c}},	//   _ཀིསི_, _eppà_, _rwee, стаи_, 
   {{0x6d443c40,0x69c826e7,0x60f8011a,0xf79c01ec}},	//   rkha, _swee, _והתק, _өмiр_, 
   {{0x6d443c41,0x65603c3c,0x00000000,0x00000000}},	//   skha, zilh, --, --, 
   {{0x6d443c42,0xdb0c07a8,0xa9780415,0x63740077}},	//   pkha, _kubê, ойду_, ránx, 
   {{0x7ac43c43,0x67383c44,0x6da43c45,0xba743c46}},	//   _үсте, _sowj, _زمزم, رانت, 
   {{0x65603c47,0x27943c48,0x00000000,0x00000000}},	//   vilh, мшир, --, --, 
   {{0x69c831da,0x6aa80a40,0x64403c49,0x394c032e}},	//   _twee, _ugef, vyli, _elds_, 
   {{0x65603c4a,0x50bc1533,0xd7543c4b,0x644000a9}},	//   tilh, ्राष, بليت_, wyli, 
   {{0x64403c4c,0x33280354,0x2b4c0165,0xa6b80241}},	//   tyli, _anax_, _hlec_, _kọkà, 
   {{0x65603c4d,0xa2e42c1d,0x2b4c3c4e,0x00000000}},	//   rilh, монд, _klec_, --, 
   {{0x65603c4f,0x21380393,0x7c281d0e,0x00000000}},	//   silh, _soph_, _ádre, --, 
   {{0x65603c50,0x26dc007f,0x64400688,0x8ee000cc}},	//   pilh, _idwo_, syli, মভাগ, 
   {{0x224003a1,0xdb1c3c51,0x644000c0,0x661c00cc}},	//   rykk_, nspò, pyli, åsku, 
   {{0x307416a4,0x00000000,0x00000000,0x00000000}},	//   еутс, --, --, --, 
   {{0xfe7803cc,0x660c0064,0x6cd40150,0x00000000}},	//   зүм_, _šaky, _ﺘﺩﺭﻴ, --, 
   {{0x2fcc3c52,0xdb1c3c53,0x1e841078,0x8cbc00bc}},	// [3a80] ćega_, rspü, флам, _ल्हो, 
   {{0xc19401b9,0xdb1c002f,0x60080229,0x00000000}},	//   _سیزع, sspü, _дном_, --, 
   {{0x60dc03ac,0x6e280003,0x91a40037,0x00000000}},	//   _idpm, _ġebe, _टूटै, --, 
   {{0x26dc0472,0x9f5802bd,0x9a843c54,0x6e2819d6}},	//   _ndwo_, _espò_, мулл, _šebe, 
   {{0x6f18009d,0xdb1c0210,0x00000000,0x00000000}},	//   _эцэс_, wspó, --, --, 
   {{0x17240489,0x26dc0134,0xc9803c55,0xdb0c0240}},	//   _འོངམ_, _adwo_, кущи, _kubë, 
   {{0xe9700e56,0x00000000,0x00000000,0x00000000}},	//   دۇلد, --, --, --, 
   {{0x2b4c0048,0x3f800311,0x77940101,0x00000000}},	//   _glec_, noiu_, ریشا, --, 
   {{0x4514045e,0xc2140134,0x394c045a,0x9db401ec}},	//   ়ানক_, _nsɔ_, _tlds_, псiз, 
   {{0x56900046,0x4a540302,0x74343542,0x09e001c6}},	//   нақт, _חשמל_, еноф, _шоун, 
   {{0xc214016b,0x61e43c56,0x3f800083,0x00000000}},	//   _asɔ_, erkl, koiu_, --, 
   {{0x86b40014,0xf424004e,0x95c8009b,0x325400d8}},	//   _قُمر_, _үздү, _дука_, евмр, 
   {{0x51840e27,0x3f803c57,0x48f80764,0xc5100330}},	//   дува, doiu_, ल्वो_, ربیت, 
   {{0x157401d9,0x301400c0,0x00000000,0x00000000}},	//   _تٔتھ_, ндгр, --, --, 
   {{0x61e40076,0x73d8010b,0x33280135,0x7414007b}},	//   arkl, _эдйр_, _tnax_, _أوبا, 
   {{0x3328005a,0x3f800356,0x00000000,0x00000000}},	//   _unax_, goiu_, --, --, 
   {{0x61e40010,0x00000000,0x00000000,0x00000000}},	// [3a90] crkl, --, --, --, 
   {{0x30143c58,0x9f480395,0x72d000d1,0xdee80023}},	//   _здор, hubè_, _جەڭچ, _ቅንኢ_, 
   {{0x2b4c3c59,0xdb243c5a,0x201c01e3,0x00000000}},	//   _plec_, کونی, åtit_, --, 
   {{0xcee83c5b,0x3f800356,0xea9401c6,0x00000000}},	//   _بردن_, coiu_, ншлэ, --, 
   {{0x9f581ffb,0x6f0c3c5c,0xd7ec0228,0x3cdc07b7}},	//   _uppá_, meac, ەكى_, गृहे_, 
   {{0x6f0c3c5d,0x1cac0003,0xdb0c00f2,0x6cc40014}},	//   leac, _པུར_, _lubè, _سٲرٕ, 
   {{0x80d404c5,0x7c843c5e,0x2d803c5f,0x00000000}},	//   _তাম্, _ауте, mohe_, --, 
   {{0x6f0c3c60,0x2d803c61,0x2b4c012d,0x661c01bf}},	//   neac, lohe_, _ulec_, æsko, 
   {{0x6f0c00a3,0x7bd80174,0x00000000,0x00000000}},	//   ieac, ávuv, --, --, 
   {{0x6f0c0ea3,0x69d83c62,0xdb0c0ba1,0x3f8002c4}},	//   heac, mswe, _aubè, zoiu_, 
   {{0x69d83c63,0x78ac0122,0x6f0c0204,0x1cac0327}},	//   lswe, ňové, keac, _པུལ_, 
   {{0xdb0c0ba1,0x2d803c64,0x00000000,0x00000000}},	//   _cubè, hohe_, --, --, 
   {{0x6f0c3c65,0x69d83c66,0x2d803c67,0xdb0c180f}},	//   deac, nswe, kohe_, _dubè, 
   {{0xdb0c067c,0x69d83c68,0x2d8000b5,0x6f0c0076}},	//   _eubè, iswe, johe_, eeac, 
   {{0x6f0c0597,0x3f800276,0x69d8002f,0x4f340023}},	//   feac, toiu_, hswe, _ኣከያይ, 
   {{0x6f0c3c69,0x6fe000af,0x69d83c6a,0x221400c7}},	//   geac, _फिरं, kswe, _зфор, 
   {{0x2d800270,0x3f803c6b,0x9e64178c,0x9f200131}},	// [3aa0] fohe_, roiu_, رارن, نۈگۈ, 
   {{0x69d83c6c,0x2d800223,0x3f80054e,0xdc9800db}},	//   dswe, gohe_, soiu_, птеш_, 
   {{0x6f0c3c6d,0x69d83c6e,0x3f800356,0x5ba80166}},	//   beac, eswe, poiu_, чкем_, 
   {{0x6f0c327f,0x69d80d3a,0xdb0c002e,0x9b94036b}},	//   ceac, fswe, _kubé, رلشت, 
   {{0x2d803c6f,0x69d83c70,0x661c01bf,0x00000000}},	//   bohe_, gswe, æskl, --, 
   {{0x59c43c71,0x48f80b68,0xdcec013d,0x00000000}},	//   रीगर, ल्लो_, _tibı, --, 
   {{0x69d805e4,0xd1f002d3,0x97a40139,0xba7400cf}},	//   aswe, _ውዲት_, нрил, راچت, 
   {{0x69d82305,0x00000000,0x00000000,0x00000000}},	//   bswe, --, --, --, 
   {{0x2b9004d3,0xdb0c2a4a,0x6a8401ee,0x00000000}},	//   _ئینس, _rubè, _актҡ, --, 
   {{0x1cac0135,0x7ae00036,0x58b8014d,0x3a240042}},	//   _པུས_, _hdmt, _رائج_, _irmp_, 
   {{0x6f0c00ec,0xdb0c0129,0x661c248f,0x00000000}},	//   yeac, _aubé, åskr, --, 
   {{0xd5b8084c,0x6f0c01ab,0x00000000,0x00000000}},	//   _еск_, xeac, --, --, 
   {{0x2d803c72,0xd4683c73,0x6f0c0332,0x00000000}},	//   yohe_, تحکم_, veac, --, 
   {{0x7bdc0f89,0x6f0c045f,0xb7f43c74,0x00000000}},	//   _ovru, weac, _इमाम_, --, 
   {{0x6f0c2d53,0x7ae0030d,0x7954002e,0x00000000}},	//   teac, _odmt, _tàwf, --, 
   {{0x69d83c75,0x6628013d,0xdcf4002b,0xcf401411}},	//   yswe, _üpkä, _ācām, دىرۋ, 
   {{0x6f0c3c76,0x2d803c77,0x7bdc0274,0x9fa40184}},	// [3ab0] reac, tohe_, _avru, тырҙ, 
   {{0x6f0c3c60,0xfbd804c5,0x32083c78,0x0a6804a9}},	//   seac, _সহজত, _ipay_, үрди_, 
   {{0x69d804ce,0x2d803c79,0x2fd80597,0x68f43c7a}},	//   wswe, rohe_, _توجد_, _özdi, 
   {{0x69d83c7b,0x6e94007b,0x00000000,0x00000000}},	//   tswe, _للجا, --, --, 
   {{0x2d803c7c,0x69d80112,0x7bdc0321,0x3eb40419}},	//   pohe_, uswe, _evru, ťatá_, 
   {{0xcee80014,0x00000000,0x00000000,0x00000000}},	//   _برگن_, --, --, --, 
   {{0x3a2405b1,0x69d83c7d,0xbc9400ea,0x7bd80162}},	//   _ermp_, sswe, _барј, ávut, 
   {{0x69d823f3,0x32083c7e,0x7c2803b2,0x25b802f0}},	//   pswe, _opay_, _ádra, íslo_, 
   {{0x48a80032,0x49003c7f,0x00000000,0x00000000}},	//   _етем_, _бүлг, --, --, 
   {{0xdb0c3c80,0x64a43c81,0x64bc07c1,0xb9c4007b}},	//   _rubé, капа, ोरेश, _إقلي, 
   {{0x32083c82,0x29043c83,0xc5b02bda,0x00000000}},	//   _apay_, _ibla_, _өрлө, --, 
   {{0x3fc800dd,0xe6101bf4,0xdb0c00e5,0x00000000}},	//   ہدری_, _نشت_, ődön, --, 
   {{0x20d400d6,0xe1640127,0xff500092,0x818401d5}},	//   ківс, ندسي, _መለማመ, лҳиж, 
   {{0xb4640046,0x55e001d5,0x0cc8190c,0x00000000}},	//   _өкіл, _тошб, िरोम, --, 
   {{0x29040109,0x32081496,0xb4243c84,0x00000000}},	//   _mbla_, _epay_, _معيو, --, 
   {{0x6ecc0cf9,0x9f58168c,0xdb0c04d4,0x6e2800d7}},	//   는bet, _oppå_, _tubé, _šeba, 
   {{0x2904007f,0x6e440023,0x4fa001f4,0x00000000}},	// [3ac0] _obla_, _ዘዘኻኽ, ритв, --, 
   {{0x6444033d,0x9d44005b,0xdb1c007c,0x5ce400db}},	//   _ühis, ъезд, nspö, ئكال, 
   {{0xdee43c85,0xeb54005e,0xdb1c01f4,0x9a8c0023}},	//   _иони, گىنگ, ispö, _ዝሓዘለ_, 
   {{0xdb24036b,0x9aa41b12,0x29043c86,0x1b9800c6}},	//   کوچی, نماو, _abla_, ذئاب_, 
   {{0x9f4805ac,0x6f0800e4,0x9f040150,0x320801ef}},	//   dtbø_, _ñeca, _كوگو, _xpay_, 
   {{0x4a5001ec,0x7bd80162,0x31c000d1,0x00000000}},	//   шкіс, ávus, ﻣﺪﯨﻜ, --, 
   {{0x7d1c00c6,0x69dc05ac,0x6c742716,0xd7f80b5e}},	//   _iars, _æsen, _бутх, фул_, 
   {{0x29043c87,0x7d1c2720,0x00000000,0x00000000}},	//   _ebla_, _hars, --, --, 
   {{0x7d1c3c88,0x68ec00dd,0xcb640114,0x00000000}},	//   _kars, ándé, _рате_, --, 
   {{0xdcfc16a3,0x35541e4b,0x00000000,0x00000000}},	//   kopč, اندز, --, --, 
   {{0xdec0069c,0x32080072,0x29540801,0xae1800ab}},	//   ትራን_, _spay_, _сътр, _नैनन_, 
   {{0x7d1c3c02,0x47e000fb,0x00000000,0x00000000}},	//   _lars, _тәшҡ, --, --, 
   {{0x7d1c3c89,0xc58400d1,0x00000000,0x00000000}},	//   _oars, رھۇم_, --, --, 
   {{0x7d1c3c8a,0x3cf8282c,0x4638010f,0x09d40154}},	//   _nars, _ncrv_, _קעגע, _সমমা, 
   {{0xd378334a,0x62943c8b,0x66702a77,0x00000000}},	//   _очи_, _ezyo, _نگیر, --, 
   {{0x7d1c3c8c,0x0cc8085c,0xdb0c0356,0x2bd40073}},	//   _aars, िर्म, _subî, डीफा, 
   {{0x7d1c3c8d,0x32080c67,0x09d4009e,0x60c00311}},	// [3ad0] _bars, _upay_, _সমভা, _şome, 
   {{0x7d1c3c8e,0x32dc00d2,0x50643c8f,0x1710031c}},	//   _cars, bâyí_, _атма, _ཉིའམ_, 
   {{0x290400db,0xfbd000ec,0xfa3401d5,0x00000000}},	//   _rbla_, قتن_, یرهد, --, 
   {{0x7d1c3c90,0x95000003,0x63b4012c,0x09d40eac}},	//   _ears, _མཁའི_, ízni, _সমবা, 
   {{0x6f1c00c6,0x290400ef,0x7bd806ea,0x00000000}},	//   _iasc, _pbla_, ávur, --, 
   {{0x7d1c3c91,0x6f1c3c92,0xbca80131,0x5df8010f}},	//   _gars, _hasc, ردەك_, _אפשנ, 
   {{0x6f1c04c4,0x0ba43a0a,0x7c34236b,0x29040254}},	//   _kasc, _ашам, _керх, _vbla_, 
   {{0xe6183c93,0x6f1c167a,0x00000000,0x00000000}},	//   еди_, _jasc, --, --, 
   {{0x7d1c3c94,0x6b883c95,0x3694005b,0x00000000}},	//   _yars, _ikeg, ишьс, --, 
   {{0x6f1c3c96,0xd58403e6,0x89143c97,0x9f480217}},	//   _lasc, هێنه_, _جبرئ, stbø_, 
   {{0x6f1c010a,0x00000000,0x00000000,0x00000000}},	//   _oasc, --, --, --, 
   {{0xba000092,0x2334014b,0x2bd4044b,0x00000000}},	//   _ሃቅ_, ухор, डीया, --, 
   {{0x6b8801af,0xbbe00ce0,0x95e401ec,0xc1ac1870}},	//   _mkeg, _पट्क, _مينۇ, _ﺳﻮﺭﺍ, 
   {{0x6b8801af,0x6f1c3c98,0xb8f40055,0x60c00139}},	//   _lkeg, _aasc, _veṇū, _şomb, 
   {{0xdee43c99,0x6f1c3c9a,0xd00409a5,0x7d1c022e}},	//   лови, _basc, лере_, _rars, 
   {{0x6f1c3c9b,0x44243c9c,0xe1f8022e,0x00000000}},	//   _casc, _irn_, _зги_, --, 
   {{0x7d1c3c9d,0x6f1c3c9e,0x442401a6,0x614402a9}},	// [3ae0] _pars, _dasc, _hrn_, _бепа, 
   {{0xdca42ae3,0x7d1c3c9f,0x44243ca0,0x6b883ca1}},	//   гази, _qars, _krn_, _akeg, 
   {{0xeff80020,0xa068008e,0x9f480118,0x5c200154}},	//   ገባው_, _чана_, lubí_, ভঙ্গ_, 
   {{0x7d1c3ca2,0x6f1c2508,0x2ef80048,0x20180309}},	//   _wars, _gasc, _gcsf_, _ispi_, 
   {{0x7d1c3ca3,0xd9443ca4,0x69dc01bf,0x2bd428f5}},	//   _tars, леди, _æsel, डीबा, 
   {{0x6b883ca5,0x6f1c12fe,0x7d1c01ab,0x00000000}},	//   _ekeg, _zasc, _uars, --, 
   {{0x6f1c0429,0x4424002f,0x98640014,0x9f4801ef}},	//   _yasc, _nrn_, دیاے_, hubí_, 
   {{0xdb0c3ca6,0x1ce00327,0x00000000,0x00000000}},	//   _kubí, སུམ_, --, --, 
   {{0xdec0044e,0x59080120,0xd62400ae,0x00000000}},	//   ትራና_, _пеам_, اعبي, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x33743ca7,0x44243ca8,0x349407a5,0x00000000}},	//   игор, _crn_, ранр, --, 
   {{0x7ae4007b,0x083800df,0x00000000,0x00000000}},	//   óith, _רעאל, --, --, 
   {{0x6f1c3ca9,0x44243caa,0xdb0c3cab,0x20183cac}},	//   _rasc, _ern_, _kubâ, _aspi_, 
   {{0x6f1c3cad,0xdb0c0395,0x442415ac,0x85f4011a}},	//   _sasc, _subì, _frn_, _עמוס_, 
   {{0x44243cae,0xcf981b88,0xc0580220,0xb3d40032}},	//   _grn_, еја_, гіт_, _өйҙә, 
   {{0xa3b81f5e,0x6f1c016d,0x41b400f1,0xdb0c013a}},	//   _अंत_, _qasc, شمېر, _bubí, 
   {{0xdb0c0789,0x442414b2,0x62980210,0x00000000}},	// [3af0] _cubí, _zrn_, ętoc, --, 
   {{0x6fb83caf,0x6f1c2155,0x6b88041e,0x661c01bf}},	//   _игор_, _wasc, _skeg, æski, 
   {{0x6f1c3cb0,0xc1740302,0x6f0800e4,0x5ea40011}},	//   _tasc, _לחץ_, _ñeco, গুলে, 
   {{0xfbd03886,0xfb3405f5,0x2ef83cb1,0x6f1c3cb2}},	//   ستم_, йнхэ, _ucsf_, _uasc, 
   {{0xdef40092,0xe8900240,0xf1b41b6e,0xde440066}},	//   ገናኝ_, _ምቕራቡ_, ंदिन, _پیلو_, 
   {{0x6844006c,0xed50066d,0xa9a43cb3,0x69243cb4}},	//   инла, _بھر_, шилд, рмка, 
   {{0xa3b821bd,0x00000000,0x00000000,0x00000000}},	//   _अंध_, --, --, --, 
   {{0x6b883cb5,0x4ba400f7,0xf1b40073,0x85b00166}},	//   _ukeg, _сөзү_, ंदान, бәкч, 
   {{0x44243cb6,0x7d7800aa,0xdb0c0077,0xdb1c002d}},	//   _srn_, _شمېر_, _xubí, rspô, 
   {{0xa508026a,0xc9843cb7,0x44243cb8,0x6e280135}},	//   њена_, _суби, _prn_, _ġebl, 
   {{0x28143cb9,0xa3e802e8,0xf990007b,0xe8d001f9}},	//   _خواس, ъдна_, _ربك_, हरीच, 
   {{0x86b00220,0xb07c07d2,0x00000000,0x00000000}},	//   _уәкі, _ﭼﺎﭘﭽ, --, --, 
   {{0x26cc06d6,0x4424020b,0x7ae4007b,0x36c401af}},	//   mbeo_, _wrn_, óiti, _уңып_, 
   {{0x64a43cba,0x3f680356,0x9f483cbb,0x21c802dd}},	//   _кала, aşul_, rubí_, _ﺒﺨﺼﻭ, 
   {{0xa0a43cbc,0xdb0c09c2,0x2bd40073,0xdfa400ae}},	//   равд, _subí, _डौला, لحري, 
   {{0x6d543cbd,0x8c1800fe,0xd47800df,0x26cc0051}},	//   _alza, ণমান_, _שאקל, nbeo_, 
   {{0x1cac0327,0x11e00064,0x00000000,0x00000000}},	// [3b00] _པུང_, _джым, --, --, 
   {{0x5bac3cbe,0x3f6803e0,0x00000000,0x00000000}},	//   टद्व, mşum_, --, --, 
   {{0xdef40020,0x201802d1,0x516400f7,0x00000000}},	//   ገናኛ_, _uspi_, _түрү_, --, 
   {{0x6d543cbf,0xdb0c0077,0x00000000,0x00000000}},	//   _elza, _tubí, --, --, 
   {{0x1c10000d,0x3f6806be,0x00000000,0x00000000}},	//   _ठनकल_, nşum_, --, --, 
   {{0x26cc0393,0xaac400d1,0x320c03e0,0x00000000}},	//   ebeo_, لتۇن, çeyi_, --, 
   {{0xded4001f,0x2054010f,0x5fa80073,0xb6c40137}},	//   _ይሄን_, ייַל_, _कळाल, бөлд, 
   {{0x36d4026a,0xaf8c001f,0x26cc00df,0xdb0c0432}},	//   љопр, _መብትና_, gbeo_, _ytbý, 
   {{0xf8b801af,0xdef40092,0x00000000,0x00000000}},	//   _йөй_, ገናኙ_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb0c0083,0xd4983cc0,0xca840023,0x00000000}},	//   _kubà, ъри_, _ንዓኹም_, --, 
   {{0x34943cc1,0x98bc007f,0x00000000,0x00000000}},	//   _қайр, _motč_, --, --, 
   {{0x60c03cc2,0xdb0c004e,0x98bc007f,0x3f680356}},	//   _şoma, _mubà, _lotč_, rşul_, 
   {{0x32d4004d,0x24940014,0x00000000,0x00000000}},	//   ấy_, _گۅپھ_, --, --, 
   {{0x657c01ed,0xb4c43cc3,0x8598011a,0x00000000}},	//   éshe, ौरी_, _ששוו, --, 
   {{0x6d5402f0,0x00000000,0x00000000,0x00000000}},	//   _slza, --, --, --, 
   {{0x7eb8004e,0x5ca400d1,0x00000000,0x00000000}},	// [3b10] ргус_, ەللە, --, --, 
   {{0x6d540208,0xd0840108,0xb11400f1,0x00000000}},	//   _qlza, _выми, _اودغ, --, 
   {{0x6fb400f1,0x00000000,0x00000000,0x00000000}},	//   _دمجا, --, --, --, 
   {{0x98bc0100,0xfb4c0248,0x00000000,0x00000000}},	//   _dotč_, _ààlà_, --, --, 
   {{0x0dc806b3,0x26f40154,0x00000000,0x00000000}},	//   _шуни_, _আসলো_, --, --, 
   {{0x6d5404cc,0x2bd83cc4,0xac183cc5,0x95fc0154}},	//   _ulza, _مارک_, _йогу_, ্টাম_, 
   {{0x0c7001d9,0x00000000,0x00000000,0x00000000}},	//   _بۯاد, --, --, --, 
   {{0x782400cf,0x0078011a,0x00000000,0x00000000}},	//   زعىل, יתוי_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d4001ab,0x26cc0076,0x1c0c00c5,0x00000000}},	//   _òlad, sbeo_, _सहमल_, --, 
   {{0xdb0c0f91,0x66d43cc6,0x00000000,0x00000000}},	//   _hubá, _هيائ, --, --, 
   {{0xdb0c1ab0,0xa06801d5,0xdc340677,0x00000000}},	//   _kubá, ҳага_, צארט_, --, 
   {{0xa5083cc7,0xe3b001a9,0x65c40f1a,0x9f4800d8}},	//   _бела_, _کرت_, _убла, jubá_, 
   {{0xa0683cc8,0xa18801d5,0x1a98010f,0x225400ef}},	//   гага_, убга_, טירע, _čekā_, 
   {{0x2328144d,0x60cc02d0,0x00000000,0x00000000}},	//   _бойи_, rbbm, --, --, 
   {{0xdb0005e4,0x64a400fd,0xd0040114,0x00000000}},	//   rmoë, _каһа, љете_, --, 
   {{0x9f48026c,0x453c001f,0x60cc00e4,0x00000000}},	// [3b20] rubà_, _ይገኙበ, pbbm, --, 
   {{0xf1b401ad,0x51f401d3,0xd00c1c3b,0xad6406c2}},	//   ंदरन, _اسٹر, بلہ_, ياله, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xda78016a,0xdb0c02f0,0xee380022,0xe0d00633}},	//   лял_, _bubá, ынӡ_, _بزک_, 
   {{0x98bc02e2,0x88cc0154,0x00000000,0x00000000}},	//   _wotč_, _রাজক, --, --, 
   {{0x9d543cc9,0xdca400c7,0xd7f80107,0xdb0c1b22}},	//   _انست, _гаги, гуи_, _dubá, 
   {{0x3d1400af,0x386001e4,0x00000000,0x00000000}},	//   ड़ीं_, ĝiro_, --, --, 
   {{0x6d980ffb,0x76b80116,0x38600115,0xcc7400d9}},	//   nìan, шлир_, ŝiro_, _העלה_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa3b8242e,0x926801a9,0x6e2801ef,0x00000000}},	//   _अंश_, ҳрга_, _šebk, --, 
   {{0xdb0c00d0,0xb7bc00de,0x3f68010e,0x00000000}},	//   _zubá, _orģi, gşuk_, --, 
   {{0x04602bce,0x91f0025c,0x00000000,0x00000000}},	//   ятым, _བཀྱག_, --, --, 
   {{0x92683cca,0x6d98026c,0xdb1c005b,0x00000000}},	//   урна_, dìan, mppä, --, 
   {{0xdb1c005b,0x257001ec,0x4970030d,0x00000000}},	//   lppä, _оқыс, _ялĕс, --, 
   {{0xf4843ccb,0x51841b74,0xd3c41411,0x850000ec}},	//   _باشی, _ҳуна, _اتتى, _روين, 
   {{0xa3b40b4c,0x00000000,0x00000000,0x00000000}},	//   जदर_, --, --, --, 
   {{0x91f0025c,0x51843ccc,0x82f800cf,0x00000000}},	// [3b30] _བཀྲག_, _гуна, _ارىز_, --, 
   {{0xf48c044e,0xdb0c0332,0xfb4c01e1,0xf1b800d7}},	//   _ሓንሳብ_, _rubá, _ààjà_, íšu_, 
   {{0xdb0c0599,0x00000000,0x00000000,0x00000000}},	//   _subá, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x91f00135,0xe8780023,0x00000000,0x00000000}},	//   _བཀླག_, _ይሕግዝ_, --, --, 
   {{0xf9903ccd,0x4ae407d6,0xddd4068f,0x98a03cce}},	//   ربه_, _гўза, czył, мише, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xba743ccf,0x28f800a8,0x9f5c06af,0xfb34009d}},	//   _فاكت, _везь_, îté_, _энтэ, 
   {{0xe5683cd0,0x69c83cd1,0x395c003a,0x387401e7}},	//   риод_, _itee, chvs_, éarú_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf74800ec,0x00000000,0x00000000,0x00000000}},	//   _ٿلهي_, --, --, --, 
   {{0x98bc00cd,0x28a40562,0x00000000,0x00000000}},	//   _hotā_, गेरि, --, --, 
   {{0x85a40640,0x20540395,0x00000000,0x00000000}},	//   _ујед, отбр, --, --, 
   {{0x363400f7,0xd46403f6,0x09cc0154,0x00000000}},	//   _ورۇس, _мише_, _রিফা, --, 
   {{0x69c80a49,0xc6900023,0x10a00166,0x00000000}},	//   _otee, ልጸልካ_, фисн, --, 
   {{0x69c83cd2,0x5fb405d7,0x6d980268,0x27e4002f}},	// [3b40] _ntee, _आंकल, rìan, _lvln_, 
   {{0x90c03cd3,0x3d140034,0x201c01a8,0x00000000}},	//   _обье, ड़ें_, ætis_, --, 
   {{0x69c83cd4,0xa0a43cd5,0xdb1c005b,0x2bd40bae}},	//   _atee, _фанд, yppä, डीला, 
   {{0xddd40034,0x795401e1,0xe7fc01f9,0x00000000}},	//   rzył, _pàwo, ईंना_, --, 
   {{0x69c800db,0x09e02c0b,0xddd4033f,0x00000000}},	//   _ctee, дочн, szył, --, 
   {{0xd1dc0023,0xb5c803d4,0x00000000,0x00000000}},	//   _ንኣብ_, _শিলচ, --, --, 
   {{0xd83805f5,0x69c83cd6,0xb880044e,0x7ae40332}},	//   рэл_, _etee, _ይቕጽል_, óits, 
   {{0x5914031c,0x7b840150,0xa2dc07f7,0x98bc00ef}},	//   _ྲིམས_, _رازە, परफ्, _dotā_, 
   {{0x69c8062c,0xdb1c005b,0x95980092,0x00000000}},	//   _gtee, rppä, _ወጣቱን_, --, 
   {{0x70b805ba,0x94a81cc9,0x18680022,0xce34011a}},	//   _आलेल, итна_, _кази_, קאית_, 
   {{0x4cb8011a,0xba000023,0x661c01bf,0xdb880240}},	//   יזיו, _ግሊ_, æskr, _ንኣዳም_, 
   {{0xfa28025c,0xaab005d7,0x69c803cd,0x1cac0327}},	//   _རློན_, ुँचक, _ytee, _པུན_, 
   {{0x6d5800b0,0xc6140212,0x69c80051,0x00000000}},	//   ūwai, _моїх_, _xtee, --, 
   {{0xf8d804c5,0x3d140034,0x09cc015b,0x00000000}},	//   _সাঁথ, ड़ों_, _রিমা, --, 
   {{0x4f683cd7,0x09d40073,0x00000000,0x00000000}},	//   ашам_, _डब्य, --, --, 
   {{0x999001f1,0x70940022,0x2b9401e3,0x6ad8000d}},	//   ždňa_, _ҭаиф, råck_, _ढ़ेर, 
   {{0x4ea402dd,0x1ee8109c,0xd1d40092,0x11d4007b}},	// [3b50] ірба, صولی_, ጭቶች_, _بتعد, 
   {{0x7bc80327,0xf8b80051,0xddd40210,0x00000000}},	//   _ħdur, _ngĩ_, dzyń, --, 
   {{0x69c838d5,0x31bc2aab,0x7c941a4b,0xd1dc0023}},	//   _stee, _অবিশ, وشما, _ንኣቦ_, 
   {{0xca7003e6,0x98bc00de,0x00000000,0x00000000}},	//   وناک, _rotā_, --, --, 
   {{0x091c02f5,0x00000000,0x00000000,0x00000000}},	//   পাসু_, --, --, --, 
   {{0x98bc0055,0x39880023,0x63740327,0x6f8c0150}},	//   _potā_, _ንቃልሲ_, rġni, _ﺒﻌﻀﺎ_, 
   {{0x6d98026c,0x90800092,0x00000000,0x00000000}},	//   nìam, _የትጥቅ_, --, --, 
   {{0x82b80f50,0xe7383cd8,0x9ba03cd9,0x69c80a49}},	//   _དཔེའ, сеи_, _كەلى, _ttee, 
   {{0x29d43cda,0x69c82ddf,0xddd40034,0xf9900137}},	//   _رياس, _utee, czyń, ربۇ_, 
   {{0xf7701af6,0xfbd000e5,0x00000000,0x00000000}},	//   _یان_, _ستہ_, --, --, 
   {{0x23280364,0x00000000,0x00000000,0x00000000}},	//   бони_, --, --, --, 
   {{0x6374151c,0x6d98026c,0x00000000,0x00000000}},	//   kšne, dìam, --, --, 
   {{0x63740427,0x09cc00eb,0x00000000,0x00000000}},	//   jšne, _রিডা, --, --, 
   {{0x2488010c,0x3fc8114f,0x00000000,0x00000000}},	//   _ማሕሙድ_, قدری_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x68ec016b,0x26dc0248,0xf3c802f2,0x00000000}},	//   ɔade, _jewo_, _ببوه_, --, 
   {{0x26dc01f2,0x31703cdb,0x00000000,0x00000000}},	// [3b60] _mewo_, bizz_, --, --, 
   {{0x62943cdc,0x26dc3cdd,0x31700064,0x00000000}},	//   _iyyo, _lewo_, cizz_, --, 
   {{0x61e417c0,0xd00c03e6,0x63b401a9,0xcb0400ec}},	//   lskl, _یلی_, _kiyn, ڳيون_, 
   {{0x9f5819f5,0x6e48022c,0x60dc0156,0x5f740150}},	//   _eppò_, ðsbó, _hepm, _ءادر, 
   {{0xcb0414fe,0x60dc020b,0x98bc0276,0xf8b001ed}},	//   سيون_, _kepm, _notă_, چکا_, 
   {{0x63b402d1,0x61e40112,0xf8b03cde,0xddd4033f}},	//   _liyn, iskl, نکا_, rzyń, 
   {{0xdca43cdf,0xddd4033f,0x17680116,0x7b840137}},	//   _хави, szyń, йрип_, _قارە, 
   {{0x63b40784,0x60dc002d,0x7f4400d8,0x00000000}},	//   _niyn, _lepm, njiq, --, 
   {{0x26dc020b,0x61e43ce0,0x98bc0311,0x00000000}},	//   _dewo_, jskl, _cotă_, --, 
   {{0x56903ce1,0x26dc0241,0x94843ce2,0x60dc3ce3}},	//   мақт, _eewo_, зымд, _nepm, 
   {{0x62943ce4,0x63b43ce5,0xb4bc03ba,0x61e401f5}},	//   _ayyo, _biyn, _अली_, eskl, 
   {{0x63b406be,0x26dc002f,0x61e43ce6,0x637400d7}},	//   _ciyn, _gewo_, fskl, yšne, 
   {{0x7f440357,0xb7e01025,0x60dc014f,0x46a03ce7}},	//   djiq, _गौतम_, _bepm, _зацв, 
   {{0x7e643ce8,0x63b42a1f,0x26dc033b,0x86780375}},	//   dzip, _eiyn, _zewo_, _פרגו, 
   {{0x3170003d,0x60dc1017,0xb4e83ce9,0x7e64009a}},	//   rizz_, _depm, यणी_, ezip, 
   {{0x6d980268,0xa2dc0490,0x63b40166,0x61e401bf}},	//   rìam, परण्, _giyn, bskl, 
   {{0x0dc801f0,0x00000000,0x00000000,0x00000000}},	// [3b70] суби_, --, --, --, 
   {{0x63b43cea,0x00000000,0x00000000,0x00000000}},	//   _ziyn, --, --, --, 
   {{0x8c640440,0x00000000,0x00000000,0x00000000}},	//   чтад, --, --, --, 
   {{0xeab000e5,0x00000000,0x00000000,0x00000000}},	//   نٹا_, --, --, --, 
   {{0x6f0c3ceb,0x60dc009a,0x7bc000b0,0x69242b39}},	//   mfac, _yepm, _ōmut, дмла, 
   {{0x6f0c3cec,0xdb0c019f,0x26dc013f,0x2d90009a}},	//   lfac, _kubû, _sewo_, _ukze_, 
   {{0xd94002e8,0xa7a83ced,0x6f0c00ae,0x00000000}},	//   тещи, окка_, ofac, --, 
   {{0x6f0c1eaa,0x80380302,0x6a143cee,0x6d443bdc}},	//   nfac, לנוע_, _омбу, ljha, 
   {{0x6f0c3cef,0x62981afd,0x63b4011f,0x09d40eac}},	//   ifac, ętok, _riyn, _সমকা, 
   {{0x6e2c3cf0,0x63b43cf1,0x6d440007,0x6f0c002f}},	//   ivab, _siyn, njha, hfac, 
   {{0x7e6404c4,0x79840221,0x6f0c022f,0x60dc0455}},	//   zzip, éiwe, kfac, _repm, 
   {{0xe2983cf2,0x63b4036b,0xdb080030,0x60dc047e}},	//   жам_, _qiyn, _šnúr, _sepm, 
   {{0xa3b80412,0x6f0c3cf3,0xdb000e78,0x61e40254}},	//   _अंक_, dfac, hloß, uskl, 
   {{0x66083cf4,0x6f0c3cf5,0xa0a405f5,0xaec00220}},	//   mtek, efac, дагд, ғұрл, 
   {{0x6f0c0a55,0x63b43cf6,0xdfd00be2,0x6e2c3cf7}},	//   ffac, _tiyn, ئير_, evab, 
   {{0x67283cf8,0x61e43cf9,0x6b983cfa,0x8fa03cfb}},	//   ndej, pskl, jlwg, васе, 
   {{0x66083cfc,0x67283cfd,0xdef80184,0xe2a80531}},	// [3b80] ntek, idej, йыҡ_, _باغن_, 
   {{0x6f0c208d,0x7e643cfe,0x672800bc,0x38600115}},	//   afac, rzip, hdej, ŝiri_, 
   {{0x6f0c3cff,0x7e643d00,0x66083d01,0x6e2c1b5a}},	//   bfac, szip, htek, avab, 
   {{0x67283d02,0x6b980207,0xddc43d03,0x00000000}},	//   jdej, glwg, _обми, --, 
   {{0x67280003,0x66083d04,0x55500240,0x00000000}},	//   ddej, jtek, _ዝፈጠሮ, --, 
   {{0x66083d05,0x67280b4f,0x00000000,0x00000000}},	//   dtek, edej, --, --, 
   {{0xa3b81f13,0x66083d06,0x2bf40006,0x00000000}},	//   _अंग_, etek, _пятр, --, 
   {{0x7bdc3d07,0x6b980175,0xf48400e5,0x00000000}},	//   _iwru, clwg, ہاجی, --, 
   {{0x66083d08,0x8a000801,0x35b43d09,0x00000000}},	//   gtek, _изте, нбир, --, 
   {{0x6f0c3d0a,0x7bdc020c,0x7ae03d0b,0xb4e800dc}},	//   zfac, _kwru, _hemt, यणे_, 
   {{0x7ae03d0c,0x66083d0d,0x6f0c03cb,0x6e2c3d0e}},	//   _kemt, atek, yfac, zvab, 
   {{0x6728004e,0x660800df,0x7ae0007c,0x6e2c03b2}},	//   cdej, btek, _jemt, yvab, 
   {{0xc3c01c13,0x394c3d0f,0x66080548,0xf4bc0154}},	//   нөөл, _kods_, ctek, _আজীব, 
   {{0x7ae03d10,0x92bc00bd,0x6f0c0561,0xc0dc0023}},	//   _lemt, ইরে_, wfac, _ንቓል_, 
   {{0x6f0c3d11,0x6440003a,0x394c3d12,0x00000000}},	//   tfac, cxli, _mods_, --, 
   {{0x7ae03d13,0x3a240048,0x6b980369,0x6f0c022f}},	//   _nemt, _osmp_, xlwg, ufac, 
   {{0x171003bd,0x6d443d14,0x6f0c3d15,0x7bdc0724}},	// [3b90] _ཉིནམ_, tjha, rfac, _awru, 
   {{0x6f0c3d16,0x6e2c3d17,0x4fc43d18,0x394c3d19}},	//   sfac, rvab, _осма, _nods_, 
   {{0x660805f5,0x7ae03d1a,0x6e2c0882,0x6f0c3d1b}},	//   ztek, _bemt, svab, pfac, 
   {{0x3b040798,0x3a240139,0x66083d1c,0x2bd43d1d}},	//   _ccmq_, _bsmp_, ytek, डीगा, 
   {{0x7954002e,0x7ae03d1e,0x3328058a,0x64400175}},	//   _jàww, _demt, _maax_, zxli, 
   {{0x33281570,0x6608383d,0xa908009f,0x67280327}},	//   _laax_, vtek, سيبل_, wdej, 
   {{0xa7b4026a,0x9f4800d2,0x394c0334,0x660801a4}},	//   нсиј, vubú_, _dods_, wtek, 
   {{0x4918038e,0x7ae03d1f,0x33283d20,0x66f403b9}},	//   _यसको_, _gemt, _naax_, dəkç, 
   {{0x67283d21,0x656002c4,0x394c1cf3,0xa2dc3d22}},	//   rdej, thlh, _fods_, परस्, 
   {{0x66083d23,0x7bc83d24,0x394c3d25,0x08400014}},	//   rtek, _éduc, _gods_, _لۆتُ, 
   {{0x66083d26,0x33283d27,0x68e00c8c,0x7ae0192e}},	//   stek, _baax_, _ield, _yemt, 
   {{0x68e03d28,0x66083d29,0x62643d2a,0xdb0c0798}},	//   _held, ptek, евма, _subú, 
   {{0x68e03d2b,0x632000bd,0x332800ca,0x3a24003e}},	//   _keld, যালয়_, _daax_, _xsmp_, 
   {{0x68e01710,0x602414a8,0x00000000,0x00000000}},	//   _jeld, ндга, --, --, 
   {{0x68e03d2c,0x307400ee,0x33280009,0x00000000}},	//   _meld, вутс, _faax_, --, 
   {{0x79540de2,0x33280009,0x2fc001e7,0x68e03d2d}},	//   _fàww, _gaax_, _duhg_, _leld, 
   {{0xe8e400b2,0x79540de2,0x68e03d2e,0x7ae00153}},	// [3ba0] _پڻ_, _gàww, _oeld, _remt, 
   {{0x7ae03d2f,0x6d40007f,0x52a4013d,0x00000000}},	//   _semt, _òlal, _явым_, --, 
   {{0xdee423c4,0x394c3d30,0x3a2405b1,0x3328002e}},	//   _пони, _rods_, _ssmp_, _yaax_, 
   {{0x29043d31,0x68e03d32,0x7ae0014f,0x394c00e2}},	//   _acla_, _aeld, _qemt, _sods_, 
   {{0x68e03d33,0x7ae03d34,0x6298033f,0x394c045a}},	//   _beld, _vemt, ętow, _pods_, 
   {{0x68e03d35,0x7ae0003c,0x3f800153,0xacb000cf}},	//   _celd, _wemt, lniu_, _چەكب, 
   {{0x7ae03d36,0x779404d3,0x3f800421,0xc8c41d57}},	//   _temt, پیشا, oniu_, روين_, 
   {{0x68e000af,0x3f803d37,0x3ae80330,0xda6400ec}},	//   _eeld, nniu_, _زبری_, _ٻاري, 
   {{0x68e03d38,0x5c38001f,0x394c2821,0x3f803d39}},	//   _feld, _የሚጠይ, _tods_, iniu_, 
   {{0x69f00228,0x3328011f,0x2904009f,0xd90c0543}},	//   _түшт, _saax_, _gcla_, _طیب_, 
   {{0x72d43d3a,0xf8a400e1,0x38780267,0x00000000}},	//   конф, _ओरिय, _ärr_, --, 
   {{0x68e03d3b,0x637401fa,0x24500372,0x1b1c009e}},	//   _zeld, tšna, شچىس, ফাকে_, 
   {{0x3f800034,0xd76003e6,0x68e03d3c,0x201c0205}},	//   dniu_, _لۆژی, _yeld, çtin_, 
   {{0x3f800034,0x33283d3d,0x63640162,0xafc401e0}},	//   eniu_, _waax_, _nónf, кәмй, 
   {{0x33281bce,0xd3780354,0x00000000,0x00000000}},	//   _taax_, _нчи_, --, --, 
   {{0x3f801570,0xc4980375,0xb8ec031c,0x28a41b76}},	//   gniu_, _משות, _ྲུ_, गेटि, 
   {{0x32080784,0x00000000,0x00000000,0x00000000}},	// [3bb0] _uqay_, --, --, --, 
   {{0x3f803d3e,0x27e8094a,0x313425ff,0x0a680022}},	//   aniu_, ņani_, _реор, ҟреи_, 
   {{0x68e03d3f,0x00000000,0x00000000,0x00000000}},	//   _reld, --, --, --, 
   {{0x68e03d40,0xa82403e6,0xaa5406ed,0x00000000}},	//   _seld, ێکان, квеш, --, 
   {{0x68e0005f,0x7c940220,0xa0200432,0x80a41888}},	//   _peld, _ەشقا, _ýörl, _لمین, 
   {{0x68e0047e,0xed0402dd,0xb6780023,0x3f68010e}},	//   _qeld, _جوسپ, _ክትኮኑ_, lşup_, 
   {{0x68e03d41,0x7c8435f2,0x01380375,0xe73000ae}},	//   _veld, _буте, תרות_, لصة_, 
   {{0x68e03d42,0x45a015bf,0x61e00166,0x35cc0241}},	//   _weld, گەتك, _çolg, _ẹbẹ_, 
   {{0x68e01125,0xdce8054e,0xe9b4010a,0x00000000}},	//   _teld, _înău, _абаь, --, 
   {{0x29043d43,0x2d8001ab,0x68e002d0,0x3f803d44}},	//   _ucla_, nnhe_, _ueld, zniu_, 
   {{0xf7f43d45,0x3f803d46,0x63640162,0xa2dc0073}},	//   _مسند, yniu_, _jóng, परल्, 
   {{0xd57002d3,0xa9980150,0x00000000,0x00000000}},	//   _ብወግዒ_, _ﺘﻬﻠﻜ_, --, --, 
   {{0x63640077,0x66040124,0x00000000,0x00000000}},	//   _lóng, _рпла, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdee43d47,0xd0043d48,0x232801b9,0x9e643d49}},	//   кови, кере_, _жойи_, ھارن, 
   {{0x3d141d27,0x66180ac5,0x93f806a9,0x44243d4a}},	//   न्ने_, _kpwk, _חלקי, _isn_, 
   {{0x3f803d4b,0xe3c80051,0x00000000,0x00000000}},	// [3bc0] rniu_, _bằg_, --, --, 
   {{0x442405b1,0x3f800006,0x4d603d4c,0x63640051}},	//   _ksn_, sniu_, акув, _bóng, 
   {{0x27203d4d,0x61400248,0x3f80033f,0x636400ae}},	//   _मसूर_, _ẹlé, pniu_, _cóng, 
   {{0x44243d4e,0x5ea400ae,0x00000000,0x00000000}},	//   _msn_, _لمجل, --, --, 
   {{0xd94400ee,0xabc401e0,0x636402d2,0x59640166}},	//   кеди, _ҡарҙ, _tónf, къка, 
   {{0x442402fb,0x63743d4f,0xdca4009d,0x00000000}},	//   _osn_, kšno, _ааги, --, 
   {{0x8c403d50,0x636404d4,0x00000000,0x00000000}},	//   _кере, _góng, --, --, 
   {{0x7bb4004e,0x7c38031c,0x00000000,0x00000000}},	//   _сөзу, ċarġ, --, --, 
   {{0x44240455,0x04280a28,0x8f9802e4,0x636401e1}},	//   _asn_, māṇa, ויקי, _mónd, 
   {{0x73d83d51,0x20183d52,0x15b014fb,0x00000000}},	//   ндор_, _oppi_, جەتس, --, 
   {{0x44243d53,0x3d140b7c,0xd704035b,0x00000000}},	//   _csn_, न्ये_, _азеи, --, 
   {{0x44243d54,0x3f5c02d2,0xf36400e5,0x99dc00c0}},	//   _dsn_, _bíum_, ائدی, _гiда_, 
   {{0x4424003e,0x20183d55,0xddd40034,0x00000000}},	//   _esn_, _appi_, rzyś, --, 
   {{0x3374010b,0xc1b806a6,0x06800139,0x646403b2}},	//   _әгир, клях_, _әгән, ítið, 
   {{0x84e42085,0x656c03a2,0x63643d56,0x93a421f9}},	//   _شفيق_, _ïaha, _bónd, _ишид, 
   {{0x63643d57,0x6d980ffb,0x00000000,0x00000000}},	//   _cónd, hìat, --, --, 
   {{0x6364204e,0xdbc800af,0x51843d58,0x9fa401e0}},	// [3bd0] _dónd, _mõõt, _ауна, уырҙ, 
   {{0x636400eb,0xd1b80150,0xdbc80037,0xdfd000ec}},	//   _póng, _تاعا_, _lõõt, _گيٽ_, 
   {{0x6d98026c,0x2d80180f,0x44240175,0x7054007b}},	//   dìat, rnhe_, _xsn_, _إنجا, 
   {{0x4ea43d59,0xfe7000dd,0x63643d5a,0x7b9400d4}},	//   _арга, حدہ_, _gónd, арії, 
   {{0x2ee80a55,0x3c2c01d3,0x7de40064,0x5ea40117}},	//   maaf_, tóvá_, _вісд, _бурҷ, 
   {{0x2ee83d5b,0xbdc40075,0xac9405f5,0x2ef801ec}},	//   laaf_, _ئەلۋ, _багш, _تىڭد_, 
   {{0xe738005b,0xd2e0012d,0x38980092,0x0428002b}},	//   еей_, _ख़ूब_, ህጉሪቱ_, bāṇa, 
   {{0x2ee822a9,0x6c3001ed,0xab941b4f,0x7c3801bf}},	//   naaf_, _پہچا, _сабљ, ævre, 
   {{0x090400c7,0xda143d5c,0x00000000,0x00000000}},	//   _ачем, _مسلک, --, --, 
   {{0x2ee83d5d,0x6364180f,0x6d980ffb,0x4424045a}},	//   haaf_, _móne, cìat, _psn_, 
   {{0xa2e43d5e,0x2ee80ba7,0x847c02d3,0x779000e5}},	//   лонд, kaaf_, _ዓቕምን_, _ڈیوا, 
   {{0xe61004fb,0x201c05d1,0x4424007f,0x6374107d}},	//   _هشت_, çtim_, _vsn_, ršno, 
   {{0x2ee80ba7,0x44240175,0xc8c4043e,0x5ee000cc}},	//   daaf_, _wsn_, _ललाट, _ফালে, 
   {{0xa5081b88,0x26cc003a,0x80b00073,0x637400c0}},	//   _чека_, lceo_, ंधले, pšno, 
   {{0x44243d5f,0x63640048,0x2ee8198f,0xa0680153}},	//   _usn_, _pónd, faaf_, хава_, 
   {{0x80d43d60,0x2ee83d61,0x636402d2,0x26cc3d62}},	//   _ब्रे, gaaf_, _bóne, nceo_, 
   {{0x2244079d,0x8fa03d63,0xe1f004fb,0x00000000}},	// [3be0] _çok_, сате, _اسب_, --, 
   {{0x636400db,0xab5c031c,0x9f4803e0,0x00000000}},	//   _dóne, _jiżf, lubü_, --, 
   {{0x20181f60,0x2ee8198f,0xde20001f,0x9f042c04}},	//   _uppi_, baaf_, ስተዋወ, _یوگو, 
   {{0x9a8407d6,0x67d000e2,0x0b4001c6,0xdb8400c7}},	//   лулл, _mājd, йнхн, ыгеи, 
   {{0x04280882,0x4ce000eb,0xe7cc0046,0x00000000}},	//   rāṇa, _পারু, _ﻗﺎﺭﺟ, --, 
   {{0x63643d64,0x80a8012c,0xa134010f,0x04e001e1}},	//   _jónb, _गराइ, ראַק_, _ńṣọg, 
   {{0x8d603d65,0xd7f8084c,0x6d980268,0x00000000}},	//   _увре, хул_, rìat, --, 
   {{0x57a40ed6,0x35f40a15,0x47843d66,0x78a40118}},	//   ышла, апир, лсым_, řivo, 
   {{0xcb64084c,0x3d14012c,0x05dc01ad,0x00000000}},	//   _сате_, न्थे_, पीलब, --, 
   {{0x3494040e,0x2ee8208d,0x80d406e3,0x00000000}},	//   иапр, zaaf_, _ब्ले, --, 
   {{0x0d940302,0xed7c001f,0x2ee80a55,0xf3640276}},	//   רכים_, _ተጨባጭ_, yaaf_, иӂин, 
   {{0x78a83d67,0x3d140a28,0x2ee80009,0x07a0014b}},	//   _izdv, न्ते_, xaaf_, _лахн, 
   {{0x0fe01c13,0x80c00154,0x5fac313e,0x00000000}},	//   өөнү, ্রন্, _ﺳﺎﭘﺘ, --, 
   {{0xaf28001f,0x2ee83d68,0x31340f37,0x140800f3}},	//   _ትችላለ, waaf_, шегр, _зхип_, 
   {{0x2ee80a55,0x6d4001c3,0xdb0c0432,0x04400120}},	//   taaf_, _òlai, _subý, _гејн, 
   {{0x63640ba1,0xdc08015b,0x60cc01ab,0x0c8401ec}},	//   _póne, রবাস_, acbm, қызм, 
   {{0x2ee83d69,0xccf815ed,0xeeb81638,0x636401e1}},	// [3bf0] raaf_, еће_, тлаш_, _fónb, 
   {{0x81e82f04,0x63740fb7,0x2ee8198f,0x8c643947}},	//   মূহ_, jšnj, saaf_, лтед, 
   {{0xab5c003d,0x7bc806af,0x67d00171,0x3d1400cd}},	//   _jiżg, _édul, _kāje, न्धे_, 
   {{0x2ee83d6a,0xab5c031c,0x0f243d6b,0x6e9400d4}},	//   qaaf_, _miżg, _сьом, _виму, 
   {{0xaa440acf,0xabdc01ec,0x00000000,0x00000000}},	//   релл, _ﺇﻨﻬﺎ, --, --, 
   {{0x99840032,0x3d14146b,0x48980023,0x00000000}},	//   ҫтәһ, न्दे_, _ሕንጻጽ_, --, 
   {{0xab5c025c,0x26cc00b5,0x00000000,0x00000000}},	//   _niżg, tceo_, --, --, 
   {{0xe73800c7,0x80c000fe,0xe61801d5,0x00000000}},	//   теи_, ্ৰপ্, вди_, --, 
   {{0x7b643d6c,0x26cc3d6d,0x6b8817a4,0x00000000}},	//   _утре, rceo_, _ijeg, --, 
   {{0xba740e6b,0xa6dc00bd,0xab5c025c,0x69d83d6e}},	//   _طاقت, _যাওয়, _biżg, mpwe, 
   {{0x4830021a,0x6b88143a,0x02c4004e,0x00000000}},	//   _دواړ, _kjeg, йинү, --, 
   {{0xab5c031c,0x69d801a4,0x67d000ef,0x00000000}},	//   _diżg, opwe, _vājd, --, 
   {{0x6b880023,0x69d8033b,0xca440092,0x00000000}},	//   _mjeg, npwe, _ሙዚቃዎ, --, 
   {{0xe50801e2,0x00000000,0x00000000,0x00000000}},	//   _شيبو_, --, --, --, 
   {{0x63643d6f,0x363404d3,0xd46402bf,0x6b880588}},	//   _cónc, _پرۆس, _вище_, _ojeg, 
   {{0xab5c0003,0xd0040640,0x6aa802d0,0x6258014b}},	//   _jiżd, јете_, _ozef, _арор_, 
  
   {{0x53980302,0xdcec00b8,0x69d801f5,0x622400d1}},	// [3c00] _ביקו, _ambā, jpwe, _ئىخل, 
   {{0x6b883d70,0x00000000,0x00000000,0x00000000}},	//   _ajeg, --, --, --, 
   {{0xa0683d71,0x69d8017a,0x6b881710,0x6aa800a2}},	//   _рана_, epwe, _bjeg, _azef, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69d80280,0x6b8802d3,0x88cc03d4,0x00000000}},	//   gpwe, _djeg, _ৰাজক, --, 
   {{0x6aa80099,0x49702626,0x6b8800a2,0xc9a40329}},	//   _dzef, оліс, _ejeg, авче_, 
   {{0x69d801f5,0xc2ec00cc,0x63743d72,0x00000000}},	//   apwe, _কানি_, ršnj, --, 
   {{0x6b880023,0x00000000,0x00000000,0x00000000}},	//   _gjeg, --, --, --, 
   {{0xb8cc03d4,0x67d000dc,0x00000000,0x00000000}},	//   _গল_, _rāje, --, --, 
   {{0x7bc03d73,0x1adc0154,0x248800b8,0x00000000}},	//   _himu, _ডায়া, _śama_, --, 
   {{0x6ac400d2,0x79980161,0x69303ccb,0x948400ee}},	//   _étfú, movw, _رکور, рыпд, 
   {{0x7bc03d74,0x00000000,0x00000000,0x00000000}},	//   _jimu, --, --, --, 
   {{0x75d40dd8,0x7bc006d6,0x27e805ce,0x67d000b8}},	//   _ايتا, _mimu, ćane_, _vāje, 
   {{0x63640022,0xab5c0003,0x74140345,0x00000000}},	//   _pónc, _tiżg, _هوتا, --, 
   {{0x969004fb,0xdb1c012c,0x4fc401c0,0xd174010b}},	//   _دیکش, _švýc, рсга, гыңы, 
   {{0x7bc03d75,0x45000003,0x60d80e51,0x4ea43d76}},	//   _nimu, _མཐོར_, ıtma, арза, 
   {{0x79980161,0xab5c031c,0x65840022,0x0dc80454}},	// [3c10] kovw, _jiże, _ñuhã, туби_, 
   {{0x7bc03d77,0x61e00f7d,0x7998014b,0xab5c0003}},	//   _aimu, _çola, jovw, _miże, 
   {{0x6364066d,0x6b880301,0x6aa8033f,0xdb000165}},	//   _hóna, _pjeg, _szef, lmoù, 
   {{0x41c43629,0x7bc03d78,0xbec40153,0xb6080419}},	//   _دقیق, _cimu, _šūvi, _kašľ, 
   {{0xab5c3d79,0x7bc03d7a,0x63643d7b,0xba2800f7}},	//   _niże, _dimu, _jóna, لسوم_, 
   {{0x63643a6c,0x7bc03d7c,0x69d801f5,0xeff0001f}},	//   _móna, _eimu, rpwe, ልገው_, 
   {{0x7bc03d7d,0x6d54003a,0x63640efe,0x6b883d7e}},	//   _fimu, _ioza, _lóna, _tjeg, 
   {{0x6d543d7f,0xab5c031c,0x4ba40724,0x7bc03d80}},	//   _hoza, _biże, _төзү_, _gimu, 
   {{0x6d543d81,0x6aa80117,0x00000000,0x00000000}},	//   _koza, _uzef, --, --, 
   {{0x6d543d82,0xab5c0327,0x6b9801d9,0xc9843d83}},	//   _joza, _diże, lowg, _туби, 
   {{0x69c000f1,0x69c8020b,0x53c401c0,0x7bc03d84}},	//   _iile, _huee, йгэм_, _yimu, 
   {{0x69c03d85,0x6d543d86,0x6d40008c,0x7bc018f7}},	//   _hile, _loza, _ólaf, _ximu, 
   {{0x69c03d87,0xf7703d88,0x63640597,0x65943d89}},	//   _kile, _تال_, _cóna, _ладу, 
   {{0x6d543d8a,0x69c0016d,0xdecc044e,0xab5c031c}},	//   _noza, _jile, _እንኮ_, _jiżb, 
   {{0x201c3d8b,0xab5c0135,0x92e40183,0x91000108}},	//   ïti_, _miżb, _পাৰ_, япре, 
   {{0x69c03d8c,0x6d540dd4,0x63743d8d,0x636408de}},	//   _lile, _aoza, kšni, _fóna, 
   {{0x7bc03d8e,0x6d541aac,0x69c03d8f,0x6b980050}},	// [3c20] _rimu, _boza, _oile, dowg, 
   {{0xab5c0327,0x00000000,0x00000000,0x00000000}},	//   _niżb, --, --, --, 
   {{0x69c80e39,0x7bc0003e,0x63740419,0x3ec41171}},	//   _auee, _pimu, ešni, _минҳ, 
   {{0x7bc020ac,0x69c80789,0x6d5402d0,0x78a400bc}},	//   _qimu, _buee, _eoza, řivk, 
   {{0x69c03d90,0x7bc03d91,0x6d543d92,0x79980161}},	//   _bile, _vimu, _foza, tovw, 
   {{0xdd903d93,0x6d543d94,0x69c03d95,0xab5c0003}},	//   _روز_, _goza, _cile, _riże, 
   {{0x7bc03d96,0x69c03d97,0xdcb00150,0xeff0001f}},	//   _timu, _dile, _ءىز_, ልፈው_, 
   {{0x69c00876,0x6d543d98,0x7bc0003a,0xab5c031c}},	//   _eile, _zoza, _uimu, _piże, 
   {{0x69c03d99,0xd5b80372,0x6d543d9a,0x69c81081}},	//   _file, лсо_, _yoza, _guee, 
   {{0x8e5400c8,0x09cc0154,0x00000000,0x00000000}},	//   צייג_, _রিচা, --, --, 
   {{0xb7bc00ef,0x63643d9b,0x00000000,0x00000000}},	//   _apģe, _sóna, --, --, 
   {{0x69c03d9c,0xab5c0327,0xfcf80092,0x948402dd}},	//   _zile, _tiże, _ወዳጅ_, _қылд, 
   {{0xc794066d,0x86c000c6,0x69c03d9d,0x6d401427}},	//   _اپنا_, _عيون, _yile, _ólag, 
   {{0x69c007a9,0x6364022c,0x51843d9e,0x80d4012d}},	//   _xile, _vóna, сума, बुले, 
   {{0x6b980014,0x67d0005f,0xe3c80208,0xcf8801c6}},	//   yowg, _kāja, _hằn_, гсад_, 
   {{0x7d1c00f1,0x6364041e,0x6d543d9f,0x67d03da0}},	//   _abrs, _tóna, _soza, _jāja, 
   {{0x67d00029,0x8d843da1,0x42dc010f,0xedd4007b}},	// [3c30] _māja, бужд, _עקזע, زياد, 
   {{0x8d740046,0x82340150,0x6d540139,0x7afc00de}},	//   حارا, _ءريا, _qoza, _ērta, 
   {{0x69c03da2,0x6d540bb8,0x92e8045e,0x2f180962}},	//   _rile, _voza, মলী_, _конь_, 
   {{0x6d54379d,0xcf2404fb,0x67d00055,0xe3c80208}},	//   _woza, _اردي, _nāja, _oằn_, 
   {{0x69c03da3,0x6d543d81,0x69c83da4,0x6b980014}},	//   _pile, _toza, _quee, rowg, 
   {{0x98bc007f,0x69c03da5,0xd9403da6,0xc27c0375}},	//   _entč_, _qile, деши, נרגי, 
   {{0x69c03da7,0x7b440131,0x00000000,0x00000000}},	//   _vile, تئەل, --, --, 
   {{0x69c03da8,0x67d000b8,0x248800b8,0x00000000}},	//   _wile, _cāja, _śamo_, --, 
   {{0x14d82d6c,0xe3c8004d,0xab5c031c,0x61e00003}},	//   _म्हण, _cằn_, _tiżb, _ħolo, 
   {{0xe5783da9,0x04200489,0x2bb83daa,0x69c03b63}},	//   рзо_, _འགྱམ_, ेदवा, _uile, 
   {{0xa34823b3,0x63640332,0x00000000,0x00000000}},	//   азна_, _dónn, --, --, 
   {{0x7d000248,0x63783dab,0x6ed80b4c,0x86b00150}},	//   _kárà, рсор_, _फ्लु, _нәпі, 
   {{0xc1780209,0xe3c80208,0xdec00092,0x9f4c0ca8}},	//   йҗи_, _gằn_, ስያና_, _ìfé_, 
   {{0x6f1c3dac,0x80c0015b,0xe0443dad,0x7d000241}},	//   _absc, ্রস্, онги, _márà, 
   {{0x0420003d,0x6e3c0857,0x24800ade,0x3d1001ad}},	//   _འགྲམ_, _arsb, _ähm_, _ढाबे_, 
   {{0x4ce0009e,0xdb000ea0,0x63640419,0xdee400ae}},	//   _পাগু, rloë, _ióno, تأسي, 
   {{0x63640694,0x2fcc0115,0x00000000,0x00000000}},	// [3c40] _yónn, ĉega_, --, --, 
   {{0x6f1c3dae,0x63a4007c,0x630400f1,0x6f0800ef}},	//   _ebsc, llkn, _اوکل, _ķece, 
   {{0x5ac81b04,0x6e3c007c,0x28dc0118,0x00000000}},	//   алем_, _ersb, _न्धि, --, 
   {{0x3e700231,0x2b14012c,0x00000000,0x00000000}},	//   _côté_, फ्लु_, --, --, 
   {{0x67d00a28,0x64c801f9,0x6fb8002b,0x00000000}},	//   _rāja, रशाळ, ्दरू, --, 
   {{0xd7f83daf,0x7d000241,0x61e00327,0xe3c80051}},	//   ауи_, _dárà, _ħoll, _rằn_, 
   {{0x17683db0,0x984813f3,0x67d000b8,0x00000000}},	//   ирип_, ряла_, _pāja, --, 
   {{0x3f803db1,0x8b200f14,0xa9cc0150,0x00000000}},	//   niiu_, _одсе, _ﯗﻋﯩﺴ, --, 
   {{0x27e8098d,0x59840261,0x67d03db2,0x00000000}},	//   ćana_, _длаб, _vāja, --, 
   {{0xd90c07d6,0xd6e000bd,0x6364032e,0xe3c80208}},	//   _شیب_, _যাওয, _bóno, _vằn_, 
   {{0x61f403d1,0x05703db3,0x9734009d,0xd178002b}},	//   _avyl, بايد, _мэдч, _ṛṣīn_, 
   {{0x92683db4,0xd3783db5,0x67d000de,0x636401e1}},	//   арга_, рчо_, _kājn, _wónn, 
   {{0x61e00200,0x636402d2,0x00000000,0x00000000}},	//   _çoll, _tónn, --, --, 
   {{0xab5c0135,0x61f40024,0x73c40209,0x3ce4033f}},	//   _miża, _dvyl, _нәме, गरों_, 
   {{0x75283db6,0x40341faf,0xab5c025c,0x61f40857}},	//   medz, мерс, _liża, _evyl, 
   {{0x75281aa1,0x63640174,0x71f43db7,0x62980356}},	//   ledz, _jónl, _епиф, ştoa, 
   {{0x6f1c3db8,0x98bc02b5,0xacf83db9,0x63640306}},	// [3c50] _vbsc, _kotē_, йнау_, _zóno, 
   {{0x75281aa1,0x8c6400c6,0x256808ce,0xbe8801ec}},	//   nedz, يطان, _kúla_, істе_, 
   {{0x256801f1,0x7528004c,0x06880150,0x00000000}},	//   _júla_, iedz, _ﯗﻟﻤﯩ, --, 
   {{0x75281aa1,0xab5c025c,0x25681427,0x92bc0154}},	//   hedz, _biża, _múla_, েরী_, 
   {{0x75283dba,0x6f0c01a9,0x29100205,0x41743dbb}},	//   kedz, mgac, _özak_, _رایس, 
   {{0x6e2c3dbc,0xab5c0003,0x4bd80c62,0x75283dbd}},	//   mwab, _diża, _نبرد_, jedz, 
   {{0x75283dbe,0x2d800521,0x6e2c3dbf,0x61e00135}},	//   dedz, mihe_, lwab, _ħolm, 
   {{0x6f0c3dc0,0x75e001f2,0x00000000,0x00000000}},	//   ngac, _ịzac, --, --, 
   {{0xe5783bcd,0x75280810,0x6e2c00aa,0x6f0c01ab}},	//   йзи_, fedz, nwab, igac, 
   {{0x7ac4005e,0x75283dc1,0xa508026a,0x2d803dc2}},	//   _істе, gedz, љена_, nihe_, 
   {{0x6e2c3dc3,0x6f0c011f,0x79a410fc,0x256800ae}},	//   hwab, kgac, _црте, _cúla_, 
   {{0xd6b42fc0,0x2d800051,0x00000000,0x00000000}},	//   _کشمک, hihe_, --, --, 
   {{0x752806d6,0x6e2c00d2,0x2d803dc4,0xe64403c5}},	//   bedz, jwab, kihe_, _хелп, 
   {{0x6e2c3dc5,0x7528192e,0x636402fb,0x256803b2}},	//   dwab, cedz, _tóno, _fúla_, 
   {{0x66083dc6,0x67d0005f,0x9f4c02fb,0x2d800098}},	//   luek, _mājo, šník_, dihe_, 
   {{0x6e2c2959,0x6f0c198f,0x10a002bf,0x22140276}},	//   fwab, ggac, хисн, _ефор, 
   {{0x5c880184,0x6e2c3dc7,0x660801c4,0xe1243dc8}},	// [3c60] әйем_, gwab, nuek, _емпи, 
   {{0x2d800516,0x67283dc9,0xdd903dca,0x6f0c1554}},	//   gihe_, heej, روض_, agac, 
   {{0xa0a43dcb,0x6f0c01b9,0x67283dcc,0x6e2c0083}},	//   _ханд, bgac, keej, awab, 
   {{0xe3c80016,0x6e2c3dcd,0x20082dee,0x75280034}},	//   _nằm_, bwab, mubi_, zedz, 
   {{0x75283dba,0x20083dce,0x6e2c2935,0x2d800230}},	//   yedz, lubi_, cwab, bihe_, 
   {{0xbd4401d9,0x98bc0055,0x2d8001ab,0x00000000}},	//   _تھرى, _antā_, cihe_, --, 
   {{0x75280e8a,0x20083dcf,0xb88002d3,0xd83805f5}},	//   vedz, nubi_, _ክቕጽል_, сэл_, 
   {{0x75283dd0,0x672801f2,0xe3c801fb,0x212801ab}},	//   wedz, geej, _cằm_, hebh_, 
   {{0x20081cdf,0x75282196,0x35b40408,0x63640174}},	//   hubi_, tedz, мбир, _vónl, 
   {{0x2008124c,0x6f0c01b9,0xab5c031c,0x98a400c7}},	//   kubi_, zgac, _jiżn, _еизе, 
   {{0x63641bb0,0x75283dd1,0x6e2c054c,0x20080a49}},	//   _tónl, redz, zwab, jubi_, 
   {{0x752806d6,0x20083dd2,0x2d800223,0xdb00002e}},	//   sedz, dubi_, zihe_, mmoó, 
   {{0x75280e8a,0x660806d1,0x212801fa,0x2d800526}},	//   pedz, cuek, febh_, yihe_, 
   {{0xf0e823f6,0x7bdc3dd3,0x3a240109,0x200800d2}},	//   تىسى_, _otru, _mpmp_, fubi_, 
   {{0x200815ad,0x3a24020b,0xb4e802db,0x6f0c01b9}},	//   gubi_, _lpmp_, बरी_, tgac, 
   {{0x6e2c3dd4,0x2d80020c,0x6f0c01c3,0x8cb0012d}},	//   twab, wihe_, ugac, _अरबो, 
   {{0x6f0c3dd5,0x7bdc3dd6,0x2d803dd7,0x3f5c02d2}},	// [3c70] rgac, _atru, tihe_, _píur_, 
   {{0x6e2c3dd8,0x67283dd9,0x6f0c0192,0x8c400139}},	//   rwab, zeej, sgac, _öşke, 
   {{0x20083dda,0x6e2c18bd,0x2d803ddb,0x32180113}},	//   cubi_, swab, rihe_, ltsy_, 
   {{0x2d803ddc,0x7bdc3ddd,0x00000000,0x00000000}},	//   sihe_, _dtru, --, --, 
   {{0x7bdc3dde,0x3218325f,0x6e2c2798,0xe3c8004d}},	//   _etru, ntsy_, qwab, _rằm_, 
   {{0xdb000129,0x7ae40174,0x9f48032e,0x00000000}},	//   bloï, ðitr, gsbæ_, --, 
   {{0x27e808a4,0x32180109,0xdb0000cf,0x27b40114}},	//   ćano_, htsy_, cloï, мљис, 
   {{0x66083ddf,0xdbb40220,0x86b001ec,0x00000000}},	//   tuek, _жасө, нәлі, --, 
   {{0xc2ec045e,0x67283de0,0xb4e802a0,0x2008009d}},	//   _কালি_, reej, बरू_, zubi_, 
   {{0x660801c4,0x00000000,0x00000000,0x00000000}},	//   ruek, --, --, --, 
   {{0x66083de1,0xe3c8004d,0x38c83de2,0x92bc0154}},	//   suek, _tằm_, _хуун_, েরো_, 
   {{0x20082aed,0x66083de3,0x87040150,0xb8f400b8}},	//   vubi_, puek, _ءبال, _teṣū, 
   {{0x2008063f,0x67d000ef,0xf2c401f4,0x00000000}},	//   wubi_, _mājm, есён, --, 
   {{0x20083de4,0x00000000,0x00000000,0x00000000}},	//   tubi_, --, --, --, 
   {{0x10a00131,0x32180109,0xa0683de5,0xfd540055}},	//   вирн, atsy_, цава_, cceṣ, 
   {{0x20083de6,0xa3b80150,0x92bc0c58,0xe7380142}},	//   rubi_, _باتر_, েৰে_, ndŵ_, 
   {{0x20083de7,0x8fa03de8,0xe29800f3,0x00000000}},	// [3c80] subi_, тате, _фап_, --, 
   {{0xab5c0327,0x00000000,0x00000000,0x00000000}},	//   _biżo, --, --, --, 
   {{0x63b4138f,0x3a2405b1,0x63640174,0x3d1401ad}},	//   _khyn, _spmp_, _nónk, न्गे_, 
   {{0xab5c0135,0xdaa83de9,0x7bdc0381,0xa3ac05dc}},	//   _diżo, овед_, _vtru, कति_, 
   {{0xdcfc0010,0xdb500014,0x00000000,0x00000000}},	//   lipč, _یَس_, --, --, 
   {{0xed34084c,0xdb000ba1,0x9298011a,0xf1b801ec}},	//   _пэсэ, ploï, חינת, _ﺤﺎﻟﺘ, 
   {{0xa3ac0cb4,0x7bdc3dea,0xdecc0020,0xfac80184}},	//   कता_, _utru, _እንኳ_, _еңел_, 
   {{0x96e80826,0xab5c031c,0x63b43deb,0x3a240129}},	//   цька_, _jiżl, _nhyn, _tpmp_, 
   {{0x7e6430b5,0xc6d000d1,0x79840036,0x32180332}},	//   nyip, ختىت, éiws, xtsy_, 
   {{0xb4e813b4,0x94843dec,0x636401e1,0x3218014b}},	//   बरे_, дымд, _fónk, vtsy_, 
   {{0xd8743ded,0xa4f400f2,0x00000000,0x00000000}},	//   _غائب, رکور_, --, --, 
   {{0x63b43dee,0x63643def,0xab5c025c,0x8c18011a}},	//   _chyn, _jónh, _niżl, חוטי, 
   {{0xeb90008f,0xef5400c7,0x00000000,0x00000000}},	//   אָם_, ҭкгь, --, --, 
   {{0x63b40076,0x00000000,0x00000000,0x00000000}},	//   _ehyn, --, --, --, 
   {{0xe7380161,0x4fc401c6,0x00000000,0x00000000}},	//   loŵa_, дсаа, --, --, 
   {{0xab5c003d,0x75383df0,0xc3f8011a,0x636402d2}},	//   _riżo, _havz, _ולהש, _nónh, 
   {{0xadb40261,0x78a8143a,0x00000000,0x00000000}},	// [3c90] ебаш, _lydv, --, --, 
   {{0x75383df1,0x23b001ed,0x2568032e,0x3d94009d}},	//   _javz, mája_, _núll_, виур, 
   {{0x7538006c,0xfbd03df2,0x50a00150,0xb32c0327}},	//   _mavz, لتن_, _شەرل, _ཧྲོང_, 
   {{0x499001ed,0x63640241,0x91f00037,0x09a4084d}},	//   ھیار, _rónk, _अबाज_, गत्य, 
   {{0xfaa8027d,0x8d741411,0x69243df3,0x7bd80022}},	//   وهمي_, _قاسا, емла, ãvur, 
   {{0x7538389e,0xb4e80243,0x636401e1,0x00000000}},	//   _navz, बरो_, _pónk, --, 
   {{0x18d4113c,0x98a03df4,0x18a03df5,0x23b000e5}},	//   رِيد_, лише, лашм, hája_, 
   {{0x23b001ed,0x00000000,0x00000000,0x00000000}},	//   kája_, --, --, --, 
   {{0x63b40cfd,0xb32c0135,0x2568032e,0xc9d41bf4}},	//   _rhyn, _ཧྲེང_, _fúll_, _آزرب, 
   {{0x63b43df6,0x6aa80b6f,0x636409c2,0xab5c0003}},	//   _shyn, _iyef, _ióni, _miżm, 
   {{0xa2c0190c,0x75380076,0x6aa80158,0x5f000882}},	//   रेन्, _davz, _hyef, षणम्_, 
   {{0xf7703df7,0x6aa804ba,0x63643df8,0xf5380115}},	//   _پام_, _kyef, _kóni, roĥa_, 
   {{0x066400cf,0x3d1001ad,0x636402d2,0x23b03df9}},	//   _تااپ, _ढाले_, _jóni, gája_, 
   {{0x67380007,0x6aa8011c,0x63643dfa,0x61e00154}},	//   _hawj, _myef, _móni, _বিদআ, 
   {{0xdfd00597,0x1fb43dfb,0x25f801ad,0x63b43dfc}},	//   اير_, есар, ोंकी_, _thyn, 
   {{0xe298156b,0x75381154,0x7e640083,0x63b40306}},	//   _най_, _zavz, tyip, _uhyn, 
   {{0xdd903dfd,0x67383dfe,0xb91001f2,0x6aa83dff}},	// [3ca0] هور_, _mawj, _celụ_, _nyef, 
   {{0x44243e00,0xd2980302,0x7538022e,0x00000000}},	//   _kpn_, _משפט, _xavz, --, 
   {{0x6aa83e01,0x2618001e,0xab5c0327,0x5bc800dc}},	//   _ayef, hèo_, _tiżl, िदेव, 
   {{0x5f043e02,0x6aa80083,0x7e6400ca,0x10f000f1}},	//   _язма, _byef, pyip, _لګېد, 
   {{0x21383e03,0x636409c2,0x78a83e04,0xce4400c0}},	//   _kaph_, _cóni, _sydv, _ззяе_, 
   {{0x21380784,0x44243e05,0x2618180f,0x2c0c00cd}},	//   _japh_, _opn_, dèo_, ांशं_, 
   {{0x6aa8037e,0x213801ab,0xab5c003d,0x8c40010b}},	//   _eyef, _maph_, _miżj, _йере, 
   {{0x67380007,0x21380fec,0x63643e06,0xe7f005f9}},	//   _cawj, _laph_, _fóni, _घबरा_, 
   {{0x59083e07,0x7bc806af,0x78a80af9,0xfaa40214}},	//   _неам_, _éduq, _wydv, _شجری, 
   {{0x4424020b,0x78a80ea0,0x73d83e08,0xd40401fe}},	//   _bpn_, _tydv, мдор_, нями, 
   {{0xbaa400d1,0x34943e09,0x00000000,0x00000000}},	//   _чуңқ, танр, --, --, 
   {{0x44240a2e,0x23b001d3,0xa2c000cd,0x00000000}},	//   _dpn_, tája_, रेभ्, --, 
   {{0x44243e0a,0x63640005,0xb13402d3,0x6444032e}},	//   _epn_, _xóni, _ብምውሳ, _áhin, 
   {{0x44243e0b,0x0fe00137,0x67380009,0x19cc00d1}},	//   _fpn_, лөмү, _zawj, _ﻗﻮﻟﻠ, 
   {{0xd3a43e0c,0x21380100,0x67380399,0xb91001f2}},	//   _прип, _daph_, _yawj, _selụ_, 
   {{0x69dc0798,0xa2a80490,0x23b01315,0x00000000}},	//   _éseg, _घरच्, pája_, --, 
   {{0xab5c025c,0x44240311,0x80c00154,0x00000000}},	// [3cb0] _fiżj, _zpn_, ্রগ্, --, 
   {{0x44240175,0x239400e2,0x00000000,0x00000000}},	//   _ypn_, māja_, --, --, 
   {{0x63640789,0x6fb800f3,0x00000000,0x00000000}},	//   _sóni, _огор_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x239400da,0x7ae43e0d,0x394c0175,0x9f4c01e1}},	//   nāja_, ñita, _bnds_, _ìfá_, 
   {{0x21380a40,0x67383e0e,0x636406ea,0x2d843e0f}},	//   _xaph_, _sawj, _vóni, _öle_, 
   {{0x279407d6,0x013802e4,0x3d940107,0xfaa40131}},	//   кшир, גרות_, _сирр, кшән, 
   {{0x63643a6c,0x6ed402ab,0x394c3e10,0xd6cc3e11}},	//   _tóni, युचु, _ends_, يقى_, 
   {{0x2b4c3e12,0x67d000e2,0x6aa807a5,0x00000000}},	//   _inec_, _māji, _uyef, --, 
   {{0x44243e13,0x2394005f,0x08400014,0x636403b2}},	//   _ppn_, dāja_, _مۆتُ, _jónv, 
   {{0xa2e43e14,0x21383e15,0x00000000,0x00000000}},	//   конд, _raph_, --, --, 
   {{0x44242238,0x7eb8032e,0x00000000,0x00000000}},	//   _vpn_, _júpí, --, --, 
   {{0xa2f000e1,0xdcfc3e16,0x239400e2,0x26d80165}},	//   _अजीज_, hipā, gāja_, ñsou_, 
   {{0x44243e17,0x64a407dd,0x91e03e18,0x201800db}},	//   _tpn_, _иала, роре, _pqpi_, 
   {{0x44243e19,0x2b4c003a,0xab5c0135,0x00000000}},	//   _upn_, _onec_, _viżj, --, 
   {{0xd00c3e1a,0x44c4016b,0x660801c4,0x6440257c}},	//   تلف_, mɑ_, orek, mvli, 
   {{0x66083e1b,0x0e600dbb,0xab5c0135,0xb32c0327}},	// [3cc0] nrek, актн, _tiżj, _ཧྲིང_, 
   {{0x5bc83e1c,0x2b4c0327,0x61e43e1d,0xa2c01c15}},	//   िद्व, _anec_, mpkl, रेण्, 
   {{0x5f043e1e,0x64400373,0x44c4016b,0x76400810}},	//   _изна, nvli, nɑ_, zvmy, 
   {{0x67d0005f,0x9a843e1f,0x23b000e5,0x00000000}},	//   _gāji, кулл, zájn_, --, 
   {{0x394c0198,0x644000c5,0xf1a803e6,0x66083e20}},	//   _pnds_, hvli, _زایه_, jrek, 
   {{0x61e02e11,0xb8140055,0xa9b403e6,0x644001f5}},	//   _çolu, _aṭad, ۆلۆژ, kvli, 
   {{0x660807dd,0x2b4c00db,0xa2c001bc,0x81d80011}},	//   erek, _fnec_, रेत्, াঠি_, 
   {{0x98bc0055,0x478400db,0x00000000,0x00000000}},	//   _hotī_, ксым_, --, --, 
   {{0x66083e21,0x98bc00b0,0x64400066,0x63641d0e}},	//   grek, _kotī_, evli, _jónu, 
   {{0x56900220,0x76400158,0xceb0010f,0x20080427}},	//   лақт, rvmy, סיז_, krbi_, 
   {{0x66083e22,0x64401a7c,0x00000000,0x00000000}},	//   arek, gvli, --, --, 
   {{0x23940029,0x00000000,0x00000000,0x00000000}},	//   tāja_, --, --, --, 
   {{0x51840a13,0x43943e23,0x66083e24,0x2368025c}},	//   вува, раяс, crek, _ċajt_, 
   {{0x23940882,0x62b43e25,0xaf4c0092,0xc68c009f}},	//   rāja_, ығыс_, _አለመገ, _بِه_, 
   {{0x61e40af9,0xa73816a3,0x657c036e,0xc5a400ec}},	//   apkl, ščeš, ëshe, _جُون_, 
   {{0x63641604,0x239400e2,0x00000000,0x00000000}},	//   _bónu, pāja_, --, --, 
   {{0x27e805ce,0x28a82982,0x6e98299f,0x30c40154}},	// [3cd0] ćani_, _चुनि, хвар_, ্রেস, 
   {{0xdcfc0882,0x6e94005e,0x8c6404b3,0xc0b000d1}},	//   tipā, _ەلحا, ктед, ﺳﺘﻪﻗ, 
   {{0x0ca80364,0x3d9404c2,0x6608283f,0xaf4c04b2}},	//   фтаи_, шифр, zrek, _አገልገ, 
   {{0x09c81a67,0xe9f80046,0xc4740375,0xdcfc0882}},	//   ाद्य, енді_, כתבו_, ripā, 
   {{0xab5c0327,0x67d000b8,0x6364032e,0x6a240633}},	//   _jiżi, _jājv, _tónv, افتم, 
   {{0xab5c031c,0x6440017a,0x99840356,0x67d000de}},	//   _miżi, yvli, rtoş_, _mājv, 
   {{0xe5a40019,0x8bc43e26,0xa7a83e27,0x684400ee}},	//   ғини, _асад, нкка_, унйа, 
   {{0x2b4c0010,0x27e802f0,0x290803e0,0x00000000}},	//   _unec_, ďan_, şaa_, --, 
   {{0x63640077,0xfb843e28,0xab5c0327,0x66080066}},	//   _mónt, _тырн, _niżi, urek, 
   {{0x66083e29,0x64403e2a,0xe4583e2b,0x69d80472}},	//   rrek, tvli, ежо_, mqwe, 
   {{0x78543e2c,0x25680030,0x483000f1,0x79580fac}},	//   _نیوز_, _júli_, _خواړ, _шифр_, 
   {{0x64403e2d,0x44c4016b,0x25681427,0x4204035b}},	//   rvli, rɑ_, _múli_, аҧиг, 
   {{0x66043e2e,0x2ed800bd,0x2328016c,0x44c4013f}},	//   _спла, তরাষ, _ҷойи_, sɑ_, 
   {{0xab5c0135,0x44c4013b,0x61440114,0x00000000}},	//   _diżi, pɑ_, ћева, --, 
   {{0x5f043e2f,0x4430068c,0x64400334,0x25a43e30}},	//   лзва, _èx_, qvli, moll_, 
   {{0x6364035b,0xab5c0003,0x61e40250,0x69d800b5}},	//   _cónt, _fiżi, ppkl, kqwe, 
   {{0xfd580943,0x200805be,0x53980375,0xe0d80108}},	// [3ce0] _khaḽ, srbi_, _ריפו, _пвп_, 
   {{0xc2ec03d4,0x25a400cf,0x63640162,0x63a43e31}},	//   _কাটি_, noll_, _vónu, lokn, 
   {{0xe2c800aa,0x7ae40407,0x8c403e32,0x6364007b}},	//   _توکو_, ñito, йефе, _fónt, 
   {{0x25a404c4,0x63643e33,0x63a43e34,0x00000000}},	//   holl_, _tónu, nokn, --, 
   {{0x69d83e35,0x67d000de,0x38c800e5,0x00000000}},	//   gqwe, _māju, ھاتی_, --, 
   {{0x63a43e36,0xdca43e37,0x636401e1,0x5ca43e38}},	//   hokn, _баги, _kóns, _бигб, 
   {{0x25a404ce,0x63a43e39,0x6364008c,0xd5b800c5}},	//   doll_, kokn, _jóns, _उठबज, 
   {{0x2bd801ad,0x63a43e3a,0x00000000,0x00000000}},	//   _बंता, jokn, --, --, 
   {{0xe9a80372,0x2b580ba1,0xdcfc054e,0x25a4025c}},	//   ردۇن_, _òsca_, cipă, foll_, 
   {{0x25680085,0x25a405c7,0x26d80165,0xfaa408ca}},	//   _yúli_, goll_, ñsor_, _бағо, 
   {{0xa2c01f13,0x63640162,0xab5c0327,0x00000000}},	//   रेस्, _nóns, _siżi, --, 
   {{0xc5e0015b,0xab5c0135,0x63a43e3b,0xb78800b1}},	//   _মিরপ, _piżi, gokn, _шәле_, 
   {{0x25a401e6,0x636400ae,0x00000000,0x00000000}},	//   boll_, _rónt, --, --, 
   {{0xe3bc0491,0x147425aa,0x25a43e3c,0xab5c0003}},	//   _ķαŧ_, _ماعج, coll_, _viżi, 
   {{0x63a43e3d,0x04d8011a,0x2bd806e3,0x00000000}},	//   bokn, _אקול, _बंधा, --, 
   {{0x63a43e3e,0x67d000e2,0xab5c0327,0x00000000}},	//   cokn, _gāju, _tiżi, --, 
   {{0x51843e3f,0xc2ec00cc,0x4dd41d0a,0x8bc401ec}},	// [3cf0] _буна, _কাচি_, اترس, ңсед, 
   {{0xab5c0003,0x256802d2,0x00000000,0x00000000}},	//   _jiżv, _púli_, --, --, 
   {{0x7ae006af,0x417416ac,0x70540244,0x00000000}},	//   _bfmt, _دايس, _ئنجا, --, 
   {{0x7ae00076,0x6a1402c9,0xdcfc0356,0x67d00171}},	//   _cfmt, لبتر, tipă, _mājt, 
   {{0xc17401d5,0x25a4062c,0x00000000,0x00000000}},	//   _ضدیت, yoll_, --, --, 
   {{0xab5c025c,0x636403b2,0x256800e5,0x63a400e5}},	//   _niżv, _jónr, _túli_, zokn, 
   {{0xe7383e40,0x25a43e41,0x636401e1,0x4ae4022e}},	//   вей_, voll_, _mónr, _бўза, 
   {{0xa7643e42,0x3de8009e,0x66e40f5c,0x67541e2f}},	//   ркид, _পিতল, јопа, شخبر, 
   {{0x98b42c22,0x57200372,0x2bd80037,0x00000000}},	//   лләт_, تۉنك, _बूता, --, 
   {{0x79c83e43,0x270407ae,0x63a43132,0x00000000}},	//   _موقف_, ồn_, wokn, --, 
   {{0x29043e44,0xb9c43e45,0x79e00248,0x63a43e46}},	//   _idla_, _اقلي, _iṣọn_, tokn, 
   {{0x78f00ca8,0xab5c0135,0xb594008e,0x25a4007c}},	//   _iṣẹj, _viżw, _һичш, soll_, 
   {{0x25a43e47,0x27e81674,0x63a43e48,0x65941241}},	//   poll_, ćanu_, rokn, _каду, 
   {{0xa2c00b98,0xa5081789,0x63a43e49,0x64543e4a}},	//   रेष्, _река_, sokn, äzis, 
   {{0x29040472,0xa2e40984,0x98bc00c7,0xdec00092}},	//   _mdla_, _койд, _potĩ_, ቻውን_, 
   {{0x636406ea,0x00000000,0x00000000,0x00000000}},	//   _vóns, --, --, --, 
   {{0xa2c02311,0x29043e4b,0x67d000de,0x00000000}},	// [3d00] रेश्, _odla_, _kājs, --, 
   {{0xab5c003d,0xc1740c09,0x290413ce,0x3d1000e1}},	//   _miżu, _buɗe_, _ndla_, ालें_, 
   {{0xc17402a8,0x67d000e2,0x00000000,0x00000000}},	//   _cuɗe_, _mājs, --, --, 
   {{0x29043e4c,0x00000000,0x00000000,0x00000000}},	//   _adla_, --, --, --, 
   {{0xfe0400c7,0xcb640114,0x00000000,0x00000000}},	//   _ыҟам, јаче_, --, --, 
   {{0x56600201,0x1d083e4d,0x256808ce,0x00000000}},	//   ግዚአብ, _шеги_, _kúlu_, --, 
   {{0xd8383e4e,0x2b9001d3,0x00000000,0x00000000}},	//   тэл_, _کینس, --, --, 
   {{0x29040944,0xcb64016c,0xab5c0034,0x7c3c0022}},	//   _edla_, _касе_, _biżu, _isrr, 
   {{0xd5b806ac,0xcb643e4f,0x00000000,0x00000000}},	//   ксо_, _тате_, --, --, 
   {{0xd5643e50,0xab5c031c,0x3cf8143a,0x00000000}},	//   ртип, _diżu, _jerv_, --, 
   {{0x3cf80522,0xa73801fa,0xc8d8010f,0x5fd00073}},	//   _merv_, ščaš, _סקאט, _दंगल, 
   {{0x339401d5,0x00000000,0x00000000,0x00000000}},	//   самё, --, --, --, 
   {{0xab5c0135,0x672c00e4,0x68ec01e1,0xda0c000d}},	//   _tiżv, _ñaja, _índí, _सिफत_, 
   {{0xdd18003d,0x3cf83e51,0x3d100d0a,0x74f80276}},	//   għżu, _nerv_, ालों_, _секр_, 
   {{0x636403b2,0x6d4001e7,0x8f840114,0x7d0000e5}},	//   _vónr, _ólai, аћал, zárí, 
   {{0xc17403f9,0x33280014,0x636401e1,0x63740064}},	//   _ruɗe_, _ubax_, _wónr, kšny, 
   {{0x7d1c01ee,0xcce43e52,0x3cf8030a,0xde500092}},	// [3d10] _bcrs, لساي, _berv_, _መካከል, 
   {{0x201c00f7,0x65b0022e,0xd1b804b3,0x67d00171}},	//   àtic_, _jаhо, _جاعا_, _mājr, 
   {{0x3cf805c7,0x637400d7,0x8bc401a9,0x00000000}},	//   _derv_, ešny, асдд, --, 
   {{0x798802d0,0xbf140150,0x00000000,0x00000000}},	//   _amdw, _мүсә, --, --, 
   {{0x5660044e,0xaa443e53,0x3cf8030a,0x65bc0066}},	//   ግዚኣብ, селл, _ferv_, lèhe, 
   {{0xab5c038f,0x7e60026c,0xbd880014,0x6e3c02d0}},	//   _riżu, _àmpa, _ننُن_, _issb, 
   {{0x256801ed,0x79880857,0xe728009d,0x085401c4}},	//   _múlt_, _dmdw, гойд_, рчлө_, 
   {{0xe6183e54,0xe738035b,0x00000000,0x00000000}},	//   гди_, уеи_, --, --, 
   {{0x9f5c3e55,0x6b883e56,0x65b0022e,0xca740131}},	//   été_, _imeg, _bаhо, _ئازغ, 
   {{0x29040944,0xba7404fb,0x2ef80036,0x6f1c0175}},	//   _udla_, _بافت, _lesf_, _lcsc, 
   {{0xfbd00014,0x67d000ef,0x00000000,0x00000000}},	//   _رتہ_, _vājs, --, --, 
   {{0x48fc012c,0x6e3c035a,0xa5f82f5c,0x00000000}},	//   रणको_, _ossb, _беду_, --, 
   {{0x6b883e57,0xc6a40640,0xc17800d1,0x256808ce}},	//   _mmeg, _тржи, иҗи_, _súlu_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe1f03e58,0x6e3c035a,0xdee402bf,0x00000000}},	//   _کسب_, _assb, йови, --, 
   {{0xfdd800ec,0x00000000,0x00000000,0x00000000}},	//   لائڻ_, --, --, --, 
   {{0x6f1c0175,0xa3dc0490,0x7c3c005a,0x25683e59}},	// [3d20] _dcsc, _थंड_, _ssrr, _fúlt_, 
   {{0x6b883e5a,0x22580022,0xb1c80014,0xdca41d0f}},	//   _ameg, _аиҩы_, _پِپن_, бази, 
   {{0xa0683e5b,0x6e3c3e5c,0x61f400a9,0x3cf8143a}},	//   _сана_, _essb, _hwyl, _verv_, 
   {{0x44fc03d4,0x61f4017a,0xef20005f,0x798803ac}},	//   ্ভিক_, _kwyl, _ceļā_, _smdw, 
   {{0x3cf83e5d,0x17e00150,0x00000000,0x00000000}},	//   _terv_, _ﺍﻨﺘﺯ, --, --, 
   {{0x6b883e5e,0x7f443e5f,0x61f40363,0x28a809ab}},	//   _emeg, ldiq, _mwyl, _चुहि, 
   {{0x1cb00156,0x69dc3e60,0x26140037,0x00000000}},	//   _ཝཊི_, _ésen, फूसी_, --, 
   {{0x4520081f,0x9b9400c6,0x798803ac,0x2c0c043e}},	//   _འཁུར_, _الرت, _wmdw, _हितं_, 
   {{0x671800e1,0xab5c031c,0x61f403cb,0x798803ac}},	//   _धारक_, _viżt, _nwyl, _tmdw, 
   {{0x79883e61,0x2c0c0490,0x00000000,0x00000000}},	//   _umdw, ांचं_, --, --, 
   {{0xd7e81e2d,0x9f500086,0x7bc00165,0x4d58010f}},	//   _смее_, ùbûr_, _khmu, אדיצ, 
   {{0x6d400579,0x4c9800c8,0x61f40368,0x8c18011a}},	//   _ólav, רשטע, _bwyl, נוכי, 
   {{0x7f443e62,0x96b800d1,0x0ea43e63,0x2ef80129}},	//   ddiq, _сужу_, _कुंड, _resf_, 
   {{0x61f40368,0xab5c031c,0x799803ac,0xf0e81870}},	//   _dwyl, _jiżr, nnvw, شىرى_, 
   {{0xc058160b,0xab5c0327,0x61f40368,0x73c43e64}},	//   біт_, _miżr, _ewyl, _мәме, 
   {{0x61f40142,0x4ea406ed,0x00000000,0x00000000}},	//   _fwyl, брза, --, --, 
   {{0x61f40cfd,0x6b88010e,0x67d00171,0xdcfc0064}},	// [3d30] _gwyl, _rmeg, _mājp, lipę, 
   {{0x6b883e65,0x9e941e4a,0x00000000,0x00000000}},	//   _smeg, زاقچ, --, --, 
   {{0x6f1c013f,0x7f440014,0xdb000165,0xaed402dd}},	//   _tcsc, bdiq, lloù, _монш, 
   {{0x7bc0033f,0x2e8800d1,0x00000000,0x00000000}},	//   _chmu, _көзи_, --, --, 
   {{0xdb243e66,0x78a405d1,0x6e3c02d0,0x7f94009d}},	//   تونی, şivl, _ussb, _хаях, 
   {{0xed501973,0x98bc3e67,0x7bc0000d,0x00000000}},	//   _تھر_, _altı_, _ehmu, --, 
   {{0x6d542dab,0x2ca40a85,0x6d443e68,0x4cb000fe}},	//   _inza, _âld_, mdha, _জলকু, 
   {{0x6d443e69,0x6b883e6a,0xa9d40154,0x8a74014b}},	//   ldha, _umeg, সীগঞ, _либӣ_, 
   {{0xe5783e6b,0xb8d00bae,0x6d443e6c,0xc98400ea}},	//   изи_, _टु_, odha, _лужи, 
   {{0x6d443e6d,0xa5080640,0x00000000,0x00000000}},	//   ndha, јена_, --, --, 
   {{0x69c03e6e,0x6d443e6f,0x6d54055a,0x78ac02fb}},	//   _ihle, idha, _mnza, čové, 
   {{0x61f400a9,0x6d4403d5,0x67d000ef,0x256802d2}},	//   _pwyl, hdha, _gājp, _púls_, 
   {{0x69c00652,0x6d440066,0x88a800cc,0x67283e70}},	//   _khle, kdha, গেশক, mfej, 
   {{0x67280003,0xc17403f9,0x61f4062c,0x55a401ed}},	//   lfej, _buɗa_, _vwyl, _وجوہ, 
   {{0x6d441161,0x50403e71,0x69c03e72,0x7dd001e1}},	//   ddha, мерб, _mhle, _lósì, 
   {{0x6d543e73,0x69c002c4,0x22440331,0x6d443e74}},	//   _anza, _lhle, _šoku_, edha, 
   {{0x20d40953,0x69c03e75,0x7f4406af,0x6d440067}},	// [3d40] _мінс, _ohle, rdiq, fdha, 
   {{0x7bc00048,0x69c006e4,0x7f440fed,0x6d4400dc}},	//   _shmu, _nhle, sdiq, gdha, 
   {{0xe5203ad3,0xdcec0356,0x672800e5,0x28a80118}},	//   _मानि_, _albă, kfej, _चुलि, 
   {{0x69c02939,0x6d443e76,0x6d543e77,0x00000000}},	//   _ahle, adha, _enza, --, 
   {{0x6d443e78,0x69c03e79,0x00000000,0x00000000}},	//   bdha, _bhle, --, --, 
   {{0x69c03e7a,0x6d443e7b,0xfd64009d,0x00000000}},	//   _chle, cdha, _энгү, --, 
   {{0x69c03e7c,0x672801f4,0x00000000,0x00000000}},	//   _dhle, ffej, --, --, 
   {{0x69c03e7d,0x386001fa,0x7bdc3e7e,0x672801d3}},	//   _ehle, ćir_, _iuru, gfej, 
   {{0x7bdc3e7f,0x69c03e79,0xab5c0327,0x0f78010f}},	//   _huru, _fhle, _tiżr, ירקל, 
   {{0x69c03e80,0xb8f400b8,0xceb000d9,0xd5b8033a}},	//   _ghle, _kuṭī, ויח_, јси_, 
   {{0x7bdc3e81,0x92b40154,0x6614012d,0x00000000}},	//   _juru, _জলে_, ązka, --, 
   {{0x7bdc3e82,0xd6283e83,0x88380302,0xc1740198}},	//   _muru, _воде_, _כתבו, _ruɗa_, 
   {{0x7bdc3e84,0x6d440050,0xc6a005f5,0x2c84037e}},	//   _luru, ydha, _орши, のdvd_, 
   {{0x98bc033b,0x6d440014,0x00000000,0x00000000}},	//   _latč_, xdha, --, --, 
   {{0x7bdc3e85,0x6730119a,0x6d440158,0x2ef4109a}},	//   _nuru, _åkjø, vdha, ззбр, 
   {{0x65bc0066,0x6d440067,0x045000f2,0x40340022}},	//   mèha, wdha, _آئود, ьесс, 
   {{0x7e600137,0xa1143e86,0x65bc00f2,0x660c003b}},	// [3d50] _àmpl, _کوپت, lèha, _åakt, 
   {{0x7bdc3e87,0x6d440a4d,0x82341cc7,0xd01800d8}},	//   _buru, udha, _آريا, _кфм_, 
   {{0x6d443e88,0x7bdc3e89,0x65bc0214,0x32180432}},	//   rdha, _curu, nèha, lusy_, 
   {{0x7bdc3e8a,0x23940029,0x69c03e8b,0xa2c03e8c}},	//   _duru, tāji_, _shle, रेक्, 
   {{0x69c03e8d,0x7bdc3e8e,0x2fc80363,0x32183e8f}},	//   _phle, _euru, mmag_, nusy_, 
   {{0x7bdc3e90,0x6d541dc9,0x6d4401d9,0x98bc01fb}},	//   _furu, _unza, qdha, _antđ_, 
   {{0x657c0023,0x2fc801c3,0x69c0013a,0x6728367d}},	//   ëshm, omag_, _vhle, tfej, 
   {{0x32183e91,0x16041f13,0x60c80213,0x86b001ec}},	//   kusy_, _शिखर_, ülmə, мәлі, 
   {{0x7bdc3e92,0x69c03e93,0x672806d8,0x38b401e7}},	//   _zuru, _thle, rfej, túrú_, 
   {{0x69c03e94,0x7bdc3e95,0x95803e96,0x39143e97}},	//   _uhle, _yuru, елье, _омур, 
   {{0x7bdc3e98,0x3210013f,0x65bc020c,0xe3b0007b}},	//   _xuru, ɑnyɔ_, gèha, فرح_, 
   {{0x63783e99,0x58b8011a,0x00000000,0x00000000}},	//   ссор_, _המעצ, --, --, 
   {{0xf7703e9a,0xa6c80efc,0x32183e9b,0x00000000}},	//   _جال_, _اوشل_, gusy_, --, 
   {{0xa2c002ab,0x65bc0214,0xa0683e9c,0x22443e9d}},	//   रेग्, bèha, бага_, _šoks_, 
   {{0xdfd00597,0x90c005c5,0x65bc020c,0x94280327}},	//   فيس_, ебре, cèha, _ཨཱརྱ_, 
   {{0x32183e9e,0xa2043e9f,0x2fc80ea0,0x660c03cd}},	//   busy_, _епид, gmag_, _åaks, 
   {{0xd24c3ea0,0x00000000,0x00000000,0x00000000}},	// [3d60] _مني_, --, --, --, 
   {{0x7bdc3ea1,0xdca43ea2,0x64440077,0x8e041b0a}},	//   _puru, пази, _áhis, янув_, 
   {{0x7bdc3ea3,0x50d80375,0xdee407a5,0x291003e0}},	//   _quru, _לחיצ, _нони, _özay_, 
   {{0x7bdc3ea4,0xf1e0000d,0x00000000,0x00000000}},	//   _vuru, _गूड़_, --, --, 
   {{0x7bdc3ea5,0x00000000,0x00000000,0x00000000}},	//   _wuru, --, --, --, 
   {{0x239400da,0xd7f80276,0x09e000fe,0xdb24036b}},	//   māju_, буи_, নীভা, توچی, 
   {{0xb8f40a28,0x7bdc058a,0x9b940345,0x00000000}},	//   _सः_, _uuru, _فلست, --, 
   {{0x4c980375,0x780c07c1,0x00000000,0x00000000}},	//   _הבלו, _सटीक_, --, --, 
   {{0xc6f43c1b,0x2394005f,0xf1e000af,0x248802d3}},	//   чных_, nāju_, _गूढ़_, _ሕመረት_, 
   {{0x99841a57,0xd90c004b,0x00000000,0x00000000}},	//   _علاو, _صیب_, --, --, 
   {{0x201c00cf,0x2eb817c6,0x8570009d,0x00000000}},	//   àtil_, _आर्त, хлэх, --, 
   {{0xe5200316,0x32180432,0x92683be4,0x65bc00f2}},	//   _माथि_, tusy_, брга_, rèha, 
   {{0x95c83ea6,0x3f800240,0x6900013d,0x00000000}},	//   _лука_, dhiu_, _öydä, --, 
   {{0x239400e2,0x2fc800d7,0x463800df,0x00000000}},	//   dāju_, wmag_, _לעדע, --, 
   {{0x321800ee,0xf4842c04,0x8f0801c0,0x00000000}},	//   susy_, _تاشی, йхаа_, --, 
   {{0x3f803ea7,0x65bc0066,0x6e4400f1,0x00000000}},	//   ghiu_, nèhn, ونزم, --, 
   {{0x2fc83ea8,0x9f883ea9,0x2dd43eaa,0x00000000}},	// [3d70] rmag_, _añón_, джар, --, 
   {{0x2fc83eab,0xcf240f01,0x3208035a,0xbeec000d}},	//   smag_, _کردي, _ivay_, _छ्ीन_, 
   {{0xd9e400cc,0x0e480240,0x99840432,0x00000000}},	//   _নিগম, _መካኒዝ, msoň_, --, 
   {{0x3f803eac,0x624801d9,0xdfd000f1,0x312401c6}},	//   chiu_, _آیہ_, _ټيټ_, _эдүг, 
   {{0x657c0023,0xa9683dab,0xa02401f4,0x8e540354}},	//   ëshk, жила_, _työä, _хĕлл, 
   {{0xa2c006ab,0x99840209,0x00000000,0x00000000}},	//   रेट्, nsoň_, --, --, 
   {{0x186400a7,0xa3c03ead,0xab9400d4,0x7c340108}},	//   дащи_, ्गम_, _живі, _перх, 
   {{0x320803d1,0x5a300bd6,0x00000000,0x00000000}},	//   _ovay_, хнәт, --, --, 
   {{0xdb241b8d,0x65c40022,0x66140034,0xa9a401d9}},	//   _توقی, мбиа, ązko, _قمرى, 
   {{0xd58404d3,0x491403ce,0x00000000,0x00000000}},	//   وێنه_, _नाटो_, --, --, 
   {{0x32080857,0x59200214,0x99940014,0xe61001e2}},	//   _avay_, _شکوف, _کھۆر_, رشک_, 
   {{0x3208007f,0xc7a80137,0x3f800240,0xe704109c}},	//   _bvay_, _ادئل_, xhiu_, _آسای, 
   {{0xa5083eae,0xc6483b7a,0xc44404fb,0x00000000}},	//   _дела_, _دجال_, زیکن_, --, 
   {{0xa1140aa0,0x3f800374,0x98bc002b,0x00000000}},	//   بوست, whiu_, _hatā_, --, 
   {{0x2bd83eaf,0xdee43339,0x32080c8c,0x00000000}},	//   _बंगा, доби, _evay_, --, 
   {{0xe2983eb0,0x23940029,0x63043eb1,0x3f800270}},	//   _май_, tāju_, _کوکل, uhiu_, 
   {{0x98bc3eb2,0x00000000,0x00000000,0x00000000}},	// [3d80] _matā_, --, --, --, 
   {{0x3f80036e,0x78a40790,0x98bc002b,0x26d80205}},	//   shiu_, şivi, _latā_, ısoy_, 
   {{0x62842fb3,0x5158011a,0xa2d41fc4,0x4914000d}},	//   lzko, _וכיו, णशक्, _नाजो_, 
   {{0x628401c4,0x5de401e0,0x98bc0055,0x00000000}},	//   ozko, _ожма, _natā_, --, 
   {{0x09e03eb3,0x62843eb4,0xa2c008a3,0x00000000}},	//   вочн, nzko, रेच्, --, 
   {{0x6284009d,0xdca4022e,0x00000000,0x00000000}},	//   izko, _жаги, --, --, 
   {{0x9f880165,0x8c40094e,0x6c3001d9,0x44240055}},	//   _uñón_, _иере, _مہلا, _nqn_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x65bc0066,0xa5bc00c0,0x00000000,0x00000000}},	//   rèhn, mtųj, --, --, 
   {{0x62843eb5,0x28a83eb6,0xa5bc0153,0x2dc802dd}},	//   dzko, _चुकि, ltųj, _ﺒﺎﻟﺤ, 
   {{0x5dc817de,0x225000a2,0x6284009d,0xdcec00de}},	//   _ﺑﻮﻟﺴ, _aryk_, ezko, _ambī, 
   {{0x22503eb7,0x4424037e,0x98bc00cd,0x93880a4a}},	//   _bryk_, _dqn_, _gatā_, існа_, 
   {{0x4424051f,0x91480395,0xa5bc00c0,0xbec400ef}},	//   _eqn_, очва_, itųj, _šūni, 
   {{0x0fe0004e,0x00000000,0x00000000,0x00000000}},	//   көмү, --, --, --, 
   {{0x6284009d,0x81d43eb8,0xd3a401b9,0x4f68180b}},	//   azko, торх, _орип, ошам_, 
   {{0x69dc3eb9,0x04c400f1,0x00000000,0x00000000}},	//   _èseg, _غويي_, --, --, 
   {{0x2250002d,0x62840034,0x329401d9,0xa2c0010b}},	// [3d90] _gryk_, czko, _سٔدر, _бәрк, 
   {{0x717400c6,0x00000000,0x00000000,0x00000000}},	//   _أهدا, --, --, --, 
   {{0xa73817a3,0x657c0240,0xd6800150,0x00000000}},	//   ščiš, ëshi, _ﺨﻁﻴﺭ_, --, 
   {{0x4fc402d5,0x00000000,0x00000000,0x00000000}},	//   _існа, --, --, --, 
   {{0xa3c013e0,0x63643eba,0x3df400a7,0x4ea41fbe}},	//   ्गत_, _cóny, _изяс, _црна, 
   {{0xf7780327,0x98bc002b,0x9f4c0ca8,0x18880023}},	//   _ruħa_, _satā_, _ìfò_, _ንሕዝቢ_, 
   {{0xbc2401ee,0xf99000ae,0x00000000,0x00000000}},	//   _иєти, جبن_, --, --, 
   {{0x44240113,0xf424015b,0x80cc00fe,0x2ee80042}},	//   _rqn_, ববার_, ়ুক্, ncaf_, 
   {{0x26781142,0x442400d8,0x2fd800a3,0x00c42d40}},	//   яскэ_, _sqn_, _misg_, ﻨﯩﺴﺘ, 
   {{0xcfe40154,0x88c400ae,0x00000000,0x00000000}},	//   গীয়_, _قتال, --, --, 
   {{0x7ae43ebb,0x98bc02b5,0x442406af,0xa3e801ca}},	//   žite, _tatā_, _qqn_, ядна_, 
   {{0x62843ebc,0x22500ea0,0x2fd801ab,0x57c829d7}},	//   tzko, _pryk_, _nisg_, ागृह, 
   {{0x97c016cb,0x665807d5,0xe290007b,0x6284153b}},	//   _حڪوم, _халă, اذج_, uzko, 
   {{0x23940029,0x66083ebd,0xa068376d,0x62843ebe}},	//   tājs_, msek, пага_, rzko, 
   {{0xa0683ebf,0x62843ec0,0x98bc084c,0xb464007b}},	//   чава_, szko, _iată_, _لديه, 
   {{0x225004ce,0x2d9000ca,0x6608005a,0x7dd406be}},	//   _tryk_, _amze_, osek, müsə, 
   {{0x5398025f,0x2fd8015d,0x2bd80412,0xe29819ba}},	// [3da0] _מיקו, _disg_, _बंजा, _хап_, 
   {{0x660802f6,0x2fd801c3,0x5bb80882,0xdb0c110e}},	//   isek, _eisg_, ेष्व, _àdúg, 
   {{0x66080ac5,0x26dc2252,0x602402d5,0x32cc022e}},	//   hsek, _ogwo_, _ядна, mоya_, 
   {{0x66083ec1,0x6364056a,0x26dc063f,0x2ee83ec2}},	//   ksek, _cónx, _ngwo_, ccaf_, 
   {{0xcb0400b2,0x66083ec3,0x4f04010b,0xae7000d1}},	//   ريون_, jsek, _янян_, _پۇلغ, 
   {{0x26dc3ec4,0x00000000,0x00000000,0x00000000}},	//   _agwo_, --, --, --, 
   {{0xa3c03ec5,0x66083ec6,0xd7f83ec7,0xdca400f3}},	//   ्गा_, esek, чул_, _чави, 
   {{0x66083ec8,0x00000000,0x00000000,0x00000000}},	//   fsek, --, --, --, 
   {{0x940803be,0x2c54001f,0x98bc054e,0x21e400d0}},	//   əmək_, _የሚሰጡ, _bată_, _nôh_, 
   {{0x63b4010e,0x9d9002dd,0x200801a9,0xdecc0023}},	//   _akyn, ктiл, ksbi_, ቢርና_, 
   {{0xd4983ec9,0x98bc084c,0x66080083,0xe52000c5}},	//   яри_, _dată_, asek, _मारि_, 
   {{0x66083eca,0x26dc0083,0xd24401c6,0xdb0801f4}},	//   bsek, _ggwo_, нэги, _änär, 
   {{0x2fd80368,0x98bc0311,0x9984030a,0x66083ecb}},	//   _risg_, _fată_, ntoů_, csek, 
   {{0x6440090c,0x60dc0129,0x8658011a,0x00000000}},	//   bwli, _cgpm, _מדדי, --, 
   {{0x40340209,0x657401d3,0x2bd800c5,0x00000000}},	//   лерс, özhe, _बूझा, --, 
   {{0x63ac01e4,0x325401c6,0xddd4012d,0x00000000}},	//   _ĉang, _авир, czyź, --, 
   {{0x21e4002d,0x2ee83ecc,0x00000000,0x00000000}},	// [3db0] _gôh_, rcaf_, --, --, 
   {{0x2fd8015d,0x00000000,0x00000000,0x00000000}},	//   _wisg_, --, --, --, 
   {{0x628c041a,0x66081bd4,0x00000000,0x00000000}},	//   ćnoš, zsek, --, --, 
   {{0xfbd00451,0x3b640801,0x2fd801c3,0x00000000}},	//   متن_, лъчв, _uisg_, --, 
   {{0xaa443ecd,0x8d743ece,0xb9e80220,0x3cfc012d}},	//   телл, _كاسا, еміз_, _लड़के_, 
   {{0x6e2c3ecf,0xb9083ed0,0xbb180131,0x6608000d}},	//   mtab, ىزىم_, ﺰﻧﻰ_, vsek, 
   {{0xac941b74,0xd82002bf,0x98bc054e,0x6608005a}},	//   _равш, адщи, _rată_, wsek, 
   {{0x66083ed1,0x6e2c04ba,0xe73821e2,0x67d000cd}},	//   tsek, otab, феи_, _yājy, 
   {{0x98bc0356,0x66083ed2,0xc5e400cc,0x00000000}},	//   _pată_, usek, _গটঙা_, --, 
   {{0x66083ed3,0xd5ac3ed4,0x63b43ed5,0xbdcc0150}},	//   rsek, يفي_, _skyn, _ﺒﺎﻟﻔ, 
   {{0x3de803d4,0x2dcc17de,0x6e2c3ed6,0x644001a4}},	//   _পিছল, _ﺑﻮﻟﻤ, htab, uwli, 
   {{0x6e2c3ed7,0x26dc02e3,0x66083ed8,0x00000000}},	//   ktab, _ugwo_, psek, --, 
   {{0x6e2c3ed9,0x98bc0311,0x63ac01e4,0x168403e6}},	//   jtab, _tată_, _ĉand, _لاوێ, 
   {{0xc1740c09,0x67d00882,0x200800f3,0x61440063}},	//   _kuɗi_, _rājy, tsbi_, њева, 
   {{0x6e2c3eda,0x1fb43edb,0x81440014,0x602402e8}},	//   etab, всар, نچھن, ъдва, 
   {{0x7e6401c4,0x63b400a2,0x00000000,0x00000000}},	//   txip, _ukyn, --, --, 
   {{0x6e2c3edc,0x20080998,0x1ea827e3,0x1d243edd}},	// [3dc0] gtab, ssbi_, ذاري_, кмам, 
   {{0x998400e8,0x67d00055,0xa3d80210,0x00000000}},	//   rsoŋ_, _vājy, ़दक_, --, 
   {{0x6e2c3ede,0x9b040131,0x5b24009d,0x00000000}},	//   atab, взед, вьла, --, 
   {{0xd24c3837,0xdee43edf,0x00000000,0x00000000}},	//   _انی_, _шоми, --, --, 
   {{0xd9d03ee0,0x98bc0064,0xe1880023,0x00000000}},	//   لەرگ, _matą_, _ማለትዩ_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6aa802c4,0x97a42461,0x9bd40022,0x35b40075}},	//   _exef, крил, _ацаш, һбир, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xcf900bd4,0x35b43a49,0x15a80395,0x00000000}},	//   יטה_, лбир, дъни_, --, 
   {{0x3b040399,0x7ae401e4,0x22b80210,0x00000000}},	//   _hemq_, ɾita, _mąką_, --, 
   {{0xe8183ee1,0x263c01e4,0x6e2c01e4,0x98bc0064}},	//   _धिया_, nʈoj_, ztab, _batą_, 
   {{0xb9d01ee0,0x6e2c0958,0x7998007f,0x00000000}},	//   _ስማ_, ytab, livw, --, 
   {{0x7ae002fa,0x95843ee2,0x6e2c3ee3,0x98bc3ee4}},	//   _mgmt, _илде, xtab, _datą_, 
   {{0xc3c40323,0x657c044e,0xa3dc0cb4,0x6e2c3ee5}},	//   лөөл, ësht, _थूक_, vtab, 
   {{0x394c3778,0xf4843ee6,0x00000000,0x00000000}},	//   _mads_, _حاشی, --, --, 
   {{0xdcfc005f,0x7998014f,0x394c2517,0x00000000}},	//   kipē, hivw, _lads_, --, 
   {{0x6e2c3ee7,0x25a801e4,0xa3c01b76,0xab5c012d}},	// [3dd0] utab, _ŭali_, ्गर_, _giży, 
   {{0xbcf400d4,0xb4e00118,0x00000000,0x00000000}},	//   ипущ, _थलो_, --, --, 
   {{0x82b43047,0x6aa806be,0x6614012d,0xd24c01c8}},	//   _محیط, _sxef, ązki, _انڌ_, 
   {{0xc1740198,0x9984033f,0x207800df,0x00000000}},	//   _ruɗi_, proś_, _נארא, --, 
   {{0x394c3ee8,0x00000000,0x00000000,0x00000000}},	//   _bads_, --, --, --, 
   {{0x394c004e,0xc27c00d9,0x69243ee9,0xa90801f7}},	//   _cads_, ורדי, умка, ريبل_, 
   {{0x394c3b08,0x01380302,0x782400be,0x3d942cdd}},	//   _dads_, דרות_, لعيل, _тирр, 
   {{0x3b040399,0x394c3eea,0x64a43eeb,0x00000000}},	//   _gemq_, _eads_, ғама, --, 
   {{0x394c007f,0x65bc020c,0x98bc0153,0x00000000}},	//   _fads_, lèhi, _ratą_, --, 
   {{0x2b4c0de4,0x394c005f,0x61e0004a,0xbec40153}},	//   _haec_, _gads_, _éoli, _šūki, 
   {{0x23280364,0x290400da,0xa3c02c2e,0x00000000}},	//   нони_, _iela_, ्गल_, --, 
   {{0x29043eec,0xf7d408b0,0x78bc0162,0x6384009b}},	//   _hela_, _ﺟﺎﻳﺪ, _ørva, угма, 
   {{0x29043eed,0x2b4c00c7,0x0c740092,0x98bc0064}},	//   _kela_, _maec_, _በዚህች_, _vatą_, 
   {{0x29043eee,0x65bc00f2,0xe474007b,0x5698010f}},	//   _jela_, kèhi, _مطبخ, _אינצ, 
   {{0xc344030d,0x98bc0210,0x3074003b,0x00000000}},	//   _кĕв_, _tatą_, аутс, --, 
   {{0x29043eef,0x2b4c0048,0x00000000,0x00000000}},	//   _lela_, _naec_, --, --, 
   {{0x290401e0,0xac540092,0x256801d3,0x00000000}},	// [3de0] _oela_, _የሚፈጸ, _súly_, --, 
   {{0x29043ef0,0x1be83ef1,0x601401af,0xc1940244}},	//   _nela_, еджи_, _йємє, _ئیسع, 
   {{0x2b4c003a,0x00000000,0x00000000,0x00000000}},	//   _baec_, --, --, --, 
   {{0x290406c8,0x50180302,0x2b4c3ef2,0x263c01e4}},	//   _aela_, _אוטו, _caec_, rʈoj_, 
   {{0xf1a83ef3,0x394c29ef,0x6fb00073,0x7998057d}},	//   _سایه_, _pads_, ंवरू, tivw, 
   {{0x29043ef4,0x3cec01ed,0x65bc00f2,0x9f0400db}},	//   _cela_, _üdv_, bèhi, _جوڭو, 
   {{0x29043ef5,0x79981529,0xdcfc005f,0x62800327}},	//   _dela_, rivw, sipē, _żool, 
   {{0x2904208d,0x2b4c0494,0x394c039a,0xca8001e0}},	//   _eela_, _gaec_, _wads_, ргәй, 
   {{0x29043ef6,0xc1740b45,0x030800e1,0x7d0800b0}},	//   _fela_, _huɗu_, _वज़ह_, pūrē, 
   {{0x29043ef7,0x74343ab8,0x18680b96,0x89d41291}},	//   _gela_, аноф, _пази_, _موقر_, 
   {{0xa3c000dc,0xcdb40375,0x27e40208,0x00000000}},	//   ्गं_, רפיה_, _guln_, --, 
   {{0x29043ef8,0x69dc00d8,0x522428a8,0x506401d5}},	//   _zela_, _éser, лфга, қтга, 
   {{0xd20805f5,0x51843ef9,0x29042045,0x43943efa}},	//   ээнд_, гува, _yela_, саяс, 
   {{0x29043efb,0xc5f0011a,0x733400cf,0x00000000}},	//   _xela_, _הדס_, دىڭا, --, 
   {{0xb404036b,0x94d000cc,0x00000000,0x00000000}},	//   _тўлқ, _দ্ৰৌ, --, --, 
   {{0xa3c00a28,0x8d743efc,0xf2e8036b,0x2ef43efd}},	//   ्गः_, گارا, _جکده_, рзар, 
   {{0x4ea43efe,0x7c3c0ffb,0x2b4c0165,0x00000000}},	// [3df0] урва, _aprr, _raec_, --, 
   {{0x2b4c3eff,0xdd1c01e1,0x00000000,0x00000000}},	//   _saec_, _níńd, --, --, 
   {{0x6adc3f00,0x29043f01,0x0ca80107,0x00000000}},	//   यश्र, _rela_, хтаи_, --, 
   {{0x8f442a30,0x7ae40122,0x65bc020c,0xaa5400f3}},	//   _сход, žitn, rèhi, ивеш, 
   {{0x29043f02,0x753801ef,0x00000000,0x00000000}},	//   _pela_, _obvz, --, --, 
   {{0x2b4c0198,0x290400f1,0x09ac16da,0xc27c008f}},	//   _waec_, _qela_, टवेय, ערגי, 
   {{0x785c054e,0x98bc0153,0x2b4c22d5,0x00000000}},	//   _năvă, _katę_, _taec_, --, 
   {{0x29043f03,0x00000000,0x00000000,0x00000000}},	//   _wela_, --, --, --, 
   {{0x29043f04,0xeb980139,0x98bc3f05,0x26d80108}},	//   _tela_, _зиң_, _matę_, äso_, 
   {{0xe7ec04fa,0x29043f06,0x3a7400ee,0x847c0023}},	//   _चंपा_, _uela_, _улур, _ይመርሕ_, 
   {{0x657c0023,0xe3643f07,0x78540066,0x00000000}},	//   ëshq, акни, _هیوز_, --, 
   {{0x7c2803cd,0x00000000,0x00000000,0x00000000}},	//   _ådre, --, --, --, 
   {{0xa2d40472,0x00000000,0x00000000,0x00000000}},	//   شيست, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd0040798,0x7ae4022e,0xdfd00f17,0x00000000}},	//   иере_, оitl, قيس_, --, 
   {{0xa2cc01ad,0x00000000,0x00000000,0x00000000}},	//   _सरप्, --, --, --, 
   {{0x98bc012d,0x00000000,0x00000000,0x00000000}},	// [3e00] _datę_, --, --, --, 
   {{0x9cf434ac,0x4d600212,0x0d7401d9,0x00000000}},	//   рчаш, окув, لیُک_, --, 
   {{0x1c443f08,0x1fa80120,0x200c0241,0x00000000}},	//   рнем, _акни_, _ìfi_, --, 
   {{0x63a40098,0x6e3c0332,0xf7d40046,0xa5bc0064}},	//   nnkn, _fpsb, _ﺟﺎﻋﺪ, otųs, 
   {{0x7ae403c6,0x63a400e5,0xa5bc00c0,0xbe8401ee}},	//   žito, inkn, ntųs, _уңал, 
   {{0x1d8003e6,0x9c5801af,0x0b7c0092,0x3f803f09}},	//   _بگرێ, _ишбу_, ሪምየር_, lkiu_, 
   {{0x984802e8,0xe8000073,0x00000000,0x00000000}},	//   тяла_, ळीला_, --, --, 
   {{0x69dc011c,0x3f803f0a,0x785c0356,0xa5bc0064}},	//   _èsen, nkiu_, _răvă, ktųs, 
   {{0xd0f81715,0xe9a401d9,0x00000000,0x00000000}},	//   ्रमण_, _گۯون_, --, --, 
   {{0x818c00b8,0x00000000,0x00000000,0x00000000}},	//   _ṛṣyā, --, --, --, 
   {{0x057012b7,0x73d83d51,0xc57000c6,0x61f400ee}},	//   تايد, лдор_, تطيع, _atyl, 
   {{0x79600241,0x00000000,0x00000000,0x00000000}},	//   báwà, --, --, --, 
   {{0x7f440097,0x98bc012d,0xa5bc00c0,0x00000000}},	//   deiq, _ratę_, gtųs, --, 
   {{0x785c0356,0x116400f2,0xc1b81b0a,0x849400e5}},	//   _tăvă, جلسی_, илях_, ائیس_, 
   {{0x7414024e,0x19d00150,0x00000000,0x00000000}},	//   _اوبا, _ﺟﻮﻟﺠ, --, --, 
   {{0x6e943956,0x7f440369,0x04d80375,0x661c00d0}},	//   бибу, geiq, _בקול, šske, 
   {{0x645c005f,0xe7ec023e,0x00000000,0x00000000}},	// [3e10] āsie, _चूना_, --, --, 
   {{0x7dd0005b,0x25a80174,0x3014004e,0x65bc01e1}},	//   häsf, _íalt_, _лдор, bèhu, 
   {{0x70543f0b,0x8c640228,0xdcec0010,0x3f800064}},	//   _انجا, штад, _gobč, bkiu_, 
   {{0x201c00d0,0xcee800f2,0x09ac2e35,0x00000000}},	//   átie_, _جردن_, टव्य, --, 
   {{0x6f0c3f0c,0x0a6802e8,0x61f40051,0x5b3000e5}},	//   maac, ържи_, _xtyl, سٹور, 
   {{0x6f0c3f0d,0xadbc030d,0x00000000,0x00000000}},	//   laac, _чагi, --, --, 
   {{0x6d443f0e,0xe73802dd,0xfaa40131,0x27943f0f}},	//   meha, гей_, йшән, йшир, 
   {{0x6d443f10,0x6f0c3f11,0xa7643f12,0x99840306}},	//   leha, naac, скид, rtoš_, 
   {{0x28f80153,0xc98400f3,0x00000000,0x00000000}},	//   _безь_, _кужи, --, --, 
   {{0x2d8013c4,0x6f0c198f,0x059000f2,0x00000000}},	//   nkhe_, haac, تابگ, --, 
   {{0x61f43f13,0xa2e43f14,0x6f0c01f7,0x2d800009}},	//   _styl, йонд, kaac, ikhe_, 
   {{0x6d443f15,0xdfe83769,0x6f0c01f7,0xdcec0219}},	//   heha, ғдад_, jaac, _robč, 
   {{0x6d443f16,0xf668034c,0x7f4419a2,0x6f0c198f}},	//   keha, _نحوه_, veiq, daac, 
   {{0x6d440124,0x67283f17,0xf778025c,0xa50803f6}},	//   jeha, lgej, _ruħi_, _сека_, 
   {{0x6f0c0050,0xdec000b7,0xddd4033f,0x77900133}},	//   faac, ሻውን_, rzyż, _رییا, 
   {{0x6f0c279a,0x6d440066,0xa49000f1,0x00000000}},	//   gaac, eeha, _ویښت, --, 
   {{0x6d443f18,0x61f43f19,0x3f800153,0x00000000}},	// [3e20] feha, _utyl, rkiu_, --, 
   {{0x3f800153,0x6d400205,0x00000000,0x00000000}},	//   skiu_, _ılac, --, --, 
   {{0x6f0c22a9,0x7f44003a,0x67280432,0x5174011a}},	//   baac, peiq, kgej, _הגיב_, 
   {{0x6f0c074d,0x6d4400d8,0x5a6400db,0x00000000}},	//   caac, aeha, йкеб, --, 
   {{0x629800df,0x00000000,0x00000000,0x00000000}},	//   ŝtof, --, --, --, 
   {{0x6d443f1a,0x672804ba,0xadc401af,0x00000000}},	//   ceha, egej, _маяһ, --, 
   {{0x6444025a,0xadb405a9,0x480400d8,0x2bf43f1b}},	//   _âhih, _بۇلا_, бејн_, _мятр, 
   {{0x35f43f1c,0x67280b4f,0x47843f1d,0x00000000}},	//   опир, ggej, йсым_, --, 
   {{0x7dd0007c,0x00000000,0x00000000,0x00000000}},	//   räsf, --, --, --, 
   {{0x6f0c208d,0xd56400d8,0xc4c001ec,0x00000000}},	//   zaac, стип, _ﺭﺍﺒﻌ, --, 
   {{0x6f0c3f1e,0x670001f2,0x89d4006c,0x79880857}},	//   yaac, _ịkes, _اولر_, _ildw, 
   {{0x29c82b76,0x6d443f1f,0x00000000,0x00000000}},	//   núan_, zeha, --, --, 
   {{0x5924031c,0x6f0c3f20,0x00000000,0x00000000}},	//   _རྐོས_, vaac, --, --, 
   {{0x6f0c3f21,0x75d406f6,0x7dd001e3,0x00000000}},	//   waac, _بيتا, näsd, --, 
   {{0x6f0c074d,0x349401af,0xe46800cf,0xc5a401f7}},	//   taac, _файр, _ەلۉۉ_, _دُون_, 
   {{0xc41413ea,0x6d44166a,0xc3302dfc,0xaad82232}},	//   _اغوا_, weha, _كەپ_, बेडक, 
   {{0x6f0c3f22,0x2d800770,0x7988127b,0x67f4025c}},	// [3e30] raac, tkhe_, _oldw, _iġje, 
   {{0x6d443f23,0x6f0c3f24,0x910400a8,0x8c6401ec}},	//   ueha, saac, _учид, йтед, 
   {{0x6d443f25,0xa1140075,0x6f0c01c7,0x00000000}},	//   reha, _بوپت, paac, --, 
   {{0x6d443f26,0x79883f27,0x6f0c0067,0x98bc0064}},	//   seha, _aldw, qaac, _antį_, 
   {{0x2bb0006d,0x6d443f28,0xe9d035b6,0x00000000}},	//   jące_, peha, وغت_, --, 
   {{0xe7ec032c,0xcdd801e0,0x2bb0012d,0x00000000}},	//   _चंदा_, _љњм_, dące_, --, 
   {{0x69dc02e8,0x29c8056a,0x98e40032,0x67283f29}},	//   _èsem, búan_, әсәһ, tgej, 
   {{0xe6183f2a,0x29c804d4,0x63ac01e4,0x79880857}},	//   ади_, cúan_, _ĉano, _eldw, 
   {{0x67283f2b,0xc8b00103,0xd0f83f2c,0x2bb00210}},	//   rgej, _کلاک, ्राण_, gące_, 
   {{0x893400aa,0x67280ea0,0x6b8808a5,0x1dbc00cd}},	//   _دعرا, sgej, _hleg, ्तयत, 
   {{0x6b883f2d,0x765c0882,0xf2c8008d,0x18281079}},	//   _kleg, ārya, _סע_, _نقلی_, 
   {{0x7dd000fd,0x48f0012c,0x2328024c,0x00000000}},	//   mäse, ुरको_, шоми_, --, 
   {{0x7dd00724,0x6b883f2e,0xdcec00ef,0x2bb00210}},	//   läse, _mleg, _lobā, cące_, 
   {{0x6b883f2f,0xa1b80798,0x00000000,0x00000000}},	//   _lleg, румф_, --, --, 
   {{0x6b883f30,0x7dd000fd,0xdcec0171,0xaad800bc}},	//   _oleg, näse, _nobā, बेतक, 
   {{0x6b883f31,0x944001ed,0xe3b03f32,0x2d9c0036}},	//   _nleg, _کھین, _ترت_, èwen_, 
   {{0x7ae40232,0x5d143f33,0x8fa006ed,0x7dd00958}},	// [3e40] žitk, قباز, фате, häse, 
   {{0x7dd00724,0xc2c4004b,0xdca40c17,0x2d9800cf}},	//   käse, _ويډي, оази, бөсө_, 
   {{0x6b883f34,0x29c82b76,0x7dd0023a,0xa0683f35}},	//   _bleg, túan_, jäse, _тана_, 
   {{0x7dd00139,0xda7801f4,0x00000000,0x00000000}},	//   däse, иял_, --, --, 
   {{0x5924031c,0x798803ac,0x29c801d3,0x00000000}},	//   _རྐུས_, _pldw, rúan_, --, 
   {{0x99383f36,0x29c80005,0x7dd0008e,0x4a50003b}},	//   ряду_, súan_, fäse, ькіс, 
   {{0x6b883f37,0x9f400200,0x7dd0013d,0xa93400cf}},	//   _fleg, _nikë_, gäse, سبوچ, 
   {{0xdff001ad,0x6b883f38,0x9078011a,0x00000000}},	//   _आंनद_, _gleg, יטצי, --, 
   {{0xdcec005f,0x00000000,0x00000000,0x00000000}},	//   _zobā, --, --, --, 
   {{0x2bb0033f,0xf7780003,0x661c3f39,0x69cc0042}},	//   rące_, _ruħu_, áska, ïaet, 
   {{0x7dd00724,0x6b880165,0x09e00154,0x94a83f3a}},	//   cäse, _yleg, _নৌকা, ртпа_, 
   {{0x9f400023,0x741401d3,0xd1dc0b82,0x7dd03f3b}},	//   _dikë_, _ہوتا, ናዊት_, näsb, 
   {{0xcb100302,0x057003e6,0x95c81149,0x00000000}},	//   ולר_, ساید, _кука_, --, 
   {{0x85b40050,0x00000000,0x00000000,0x00000000}},	//   _واوس_, --, --, --, 
   {{0xcf9815ed,0xd17401ec,0x00000000,0x00000000}},	//   аја_, быңы, --, --, 
   {{0x201c3f3c,0xd0f8166d,0x75d400ec,0x4ea4030d}},	//   átia_, ्रहण_, _بيڪا, орза, 
   {{0x59c80882,0x00000000,0x00000000,0x00000000}},	// [3e50] ितार, --, --, --, 
   {{0x32082f05,0x6b883f3d,0x9f40007f,0x7bc03f3e}},	//   _iway_, _sleg, _likè_, _akmu, 
   {{0x6b883f3f,0x32080c8c,0xc0580212,0x00000000}},	//   _pleg, _hway_, _дія_, --, 
   {{0xfbd03f40,0x32080c8c,0x7dd03f41,0x3cc802dd}},	//   نتن_, _kway_, väse, _ﺩﺍﺌﻤ, 
   {{0x6b883f42,0x3208127b,0x24e40150,0x00000000}},	//   _vleg, _jway_, _ﺍﺯﯞﻟ, --, 
   {{0xa2cc1b6e,0x320814dc,0x7bc03f43,0xc0582ab4}},	//   _सरस्, _mway_, _ekmu, _اشیا_, 
   {{0x7bc003a0,0x98bc0139,0x6d543f44,0x32080c8c}},	//   _fkmu, _botı_, _iaza, _lway_, 
   {{0x7dd00724,0x32080c8c,0xe44808b0,0x6b88033f}},	//   räse, _oway_, ەلدى_, _uleg, 
   {{0x6d543f45,0xd7043f46,0x32080c8c,0x7dd03f47}},	//   _kaza, чные_, _nway_, säse, 
   {{0xb9983f48,0x9f4002d3,0xbbd403e6,0x87e4010a}},	//   _двух_, _pikë_, _فڕۆک, _дюде, 
   {{0x1b0c09bd,0x32083f49,0x7dd00221,0xf2840ca8}},	//   _হাতে_, _away_, läsc, _ifẹ̀_, 
   {{0x6d543f4a,0x320814dc,0x00000000,0x00000000}},	//   _laza, _bway_, --, --, 
   {{0x320814dc,0x69c005b1,0xc1b400c7,0x00000000}},	//   _cway_, _kkle, дәны, --, 
   {{0x6d543f4b,0x320814dc,0xa6e00008,0xc5a40014}},	//   _naza, _dway_, öðug, _گُڈن_, 
   {{0x32082f05,0x00000000,0x00000000,0x00000000}},	//   _eway_, --, --, --, 
   {{0x7ae401a2,0x20882c1d,0x32080c8c,0x7dd004e6}},	//   žiti, айҳи_, _fway_, käsc, 
   {{0x6d543f4c,0x32080c8c,0x69c03f4d,0x00000000}},	// [3e60] _baza, _gway_, _okle, --, 
   {{0x6d543f4e,0xc0f80020,0xe3b000ec,0x00000000}},	//   _caza, ቋቋም_, _ترڪ_, --, 
   {{0x6d543f4f,0x938002d3,0x3208127b,0x225003e0}},	//   _daza, _ይከኣሎ_, _zway_, _hsyk_, 
   {{0xcb100490,0x78bc0174,0x3208127b,0x712400e5}},	//   डणगड_, _ørvi, _yway_, _ٹریل, 
   {{0x32080c8c,0x7dd03f50,0x9f400248,0x8a000166}},	//   _xway_, gäsc, _niké_, езче, 
   {{0x6d5409a5,0x69c0020b,0xe7ec05f9,0x7c283be7}},	//   _gaza, _ckle, _चूहा_, _ådro, 
   {{0x8c403f51,0x9f40007f,0x00000000,0x00000000}},	//   _пере, _pikè_, --, --, 
   {{0x69c03f52,0x6d543f53,0xb6c40228,0x88b0006c}},	//   _ekle, _zaza, мөлд, رینچ, 
   {{0x6d540ac1,0x69c003c1,0xd5b83f54,0x9f40007f}},	//   _yaza, _fkle, йсо_, _vikè_, 
   {{0x1dbc1157,0x9f40002e,0x32080c8c,0x6d5400ac}},	//   ्तित, _diké_, _rway_, _xaza, 
   {{0x32082f05,0x225000a2,0x9f40033b,0xbb300131}},	//   _sway_, _asyk_, _tikè_, ﯨﮕﻪ_, 
   {{0x32080c8c,0x9580033f,0xa99401ec,0xd628020f}},	//   _pway_, _żąda, _ىشەت, _годе_, 
   {{0x1dbc3f55,0x7d1c0427,0x3208127b,0x201c1427}},	//   ्तात, _odrs, _qway_, átin_, 
   {{0x32080c8c,0x7d1c0200,0x62800171,0x00000000}},	//   _vway_, _ndrs, _ļoot, --, 
   {{0x6d543f56,0x6280031c,0x3208127b,0x00000000}},	//   _raza, _żoot, _wway_, --, 
   {{0x320814dc,0x6d543f57,0x7d1c02d0,0x3c18007f}},	//   _tway_, _saza, _adrs, dčv_, 
   {{0x6d543f58,0x2bb0068f,0x32080c8c,0xc0f8001f}},	// [3e70] _paza, jąca_, _uway_, ቋቋመ_, 
   {{0x6d543f59,0x7d1c05be,0x2bb0012d,0x00000000}},	//   _qaza, _cdrs, dąca_, --, 
   {{0x6d543f5a,0x7dd03f5b,0xfa280327,0x00000000}},	//   _vaza, wäsc, _ལའུན_, --, 
   {{0x69c03f5c,0x6d543f5d,0x7dd00036,0x660c010e}},	//   _skle, _waza, täsc, _çakg, 
   {{0x6d543f5e,0x2fc83f5f,0x6f1c02d0,0x3b000113}},	//   _taza, mlag_, _idsc, ñiqa_, 
   {{0x2fc83f60,0x7dd03f61,0x7d1c02d0,0xd940005b}},	//   llag_, räsc, _gdrs, веши, 
   {{0xc8643f62,0x69c00219,0xf9903dbb,0x00000000}},	//   ятди, _vkle, دبن_, --, 
   {{0x2fc83f63,0x69c00034,0x7d1c0dfe,0x7dd001c7}},	//   nlag_, _wkle, _zdrs, päsc, 
   {{0x7dd03f64,0xaa5400ee,0x2fc83f65,0x00000000}},	//   läsa, _юваш, ilag_, --, 
   {{0x2fc83f66,0x661c0306,0x00000000,0x00000000}},	//   hlag_, šsko, --, --, 
   {{0xa3483f67,0x2fc83f68,0xc7b812c4,0x64b001e4}},	//   озна_, klag_, _лёд_, rցio, 
   {{0x9f4002ea,0xe2a40174,0x00000000,0x00000000}},	//   _tiké_, _íðka_, --, --, 
   {{0x9f400270,0x7ae409a8,0x2fc83f69,0x3c18007f}},	//   _uiké_, žitv, dlag_, zčv_, 
   {{0x6f1c3f6a,0x201c003a,0x5ecc00d1,0x7dd001f4}},	//   _adsc, átio_, ﻛﺸﯜﺭ, käsa, 
   {{0x2fc80334,0xe8000073,0x2bb0012d,0x1b0c00eb}},	//   flag_, ळीचा_, ząca_, _হাসে_, 
   {{0x2fc83f6b,0x6f1c0198,0x201c0552,0x2f541ff1}},	//   glag_, _cdsc, štio_, нтус, 
   {{0xd24c3f6c,0x660c0432,0x00000000,0x00000000}},	// [3e80] _ەنۋ_, _çakd, --, --, 
   {{0x6f1c02d0,0x3be80139,0x2fc80076,0x4d44084c}},	//   _edsc, _aşqa_, alag_, мпун_, 
   {{0x5f042c9d,0x2fc83f6d,0xd02001c0,0x00000000}},	//   _озна, blag_, _имэй, --, 
   {{0x5ac80261,0x9aa405af,0x00000000,0x00000000}},	//   олем_, وماو, --, --, 
   {{0x999804fe,0xfbd00014,0x00000000,0x00000000}},	//   ōpō_, نتچ_, --, --, 
   {{0xd7f800c7,0xdd9001ed,0x2bb0012d,0xdd141bf4}},	//   оуи_, _شوز_, rąca_, _زورخ, 
   {{0x98640014,0x9b34010a,0x00000000,0x00000000}},	//   بیاے_, _охаш, --, --, 
   {{0x1dbc00dc,0xd65c01ec,0x4c98011a,0x00000000}},	//   ्तवत, _шiлд, _ובלו, --, 
   {{0x8ac03f6e,0x99380024,0xa3d03f6f,0x00000000}},	//   _айтж, _мяжу_, वतन_, --, 
   {{0x75d43f70,0xf5380115,0x2fc80010,0xceb000d9}},	//   عيدا, riĥo_, zlag_, כיח_, 
   {{0x2fc83f71,0xd4983f72,0x660c031c,0xdb0c0248}},	//   ylag_, юри_, _ħake, _ìjók, 
   {{0x92683f73,0x2fc80051,0xd244009d,0x00000000}},	//   орга_, xlag_, мэги, --, 
   {{0x2018067c,0x2fc80549,0x4394005b,0xe0e40208}},	//   _avpi_, vlag_, таяс, _đòan_, 
   {{0x23b0025c,0x00000000,0x00000000,0x00000000}},	//   rġja_, --, --, --, 
   {{0x2fc83f74,0xef100137,0x5ec40154,0xdb000037}},	//   tlag_, лүнө, লেমে, looõ, 
   {{0x2fc80036,0x7dd0005b,0x78bc0162,0x96b0012d}},	//   ulag_, väsa, _ørvu, आपपॉ, 
   {{0x2dd4084c,0x00000000,0x00000000,0x00000000}},	// [3e90] ежар, --, --, --, 
   {{0x2fc83f75,0x660c0200,0xd08401ec,0x29c800e5}},	//   slag_, _çake, _жыми, rúak_, 
   {{0x2fc83f76,0x4c0000d1,0x3cf0012d,0x00000000}},	//   plag_, ئېرل, ेड़े_, --, 
   {{0x09a40073,0x7dd001f4,0xf42000fe,0x00000000}},	//   कच्य, räsa, _বহাৰ_, --, 
   {{0xa9681b88,0x3ee43f77,0x200c08a5,0x1dbc0b02}},	//   зила_, _аюрв, _æfir_, ्तशत, 
   {{0xac180f37,0x6e2c3f78,0x7dd001e6,0xde44004b}},	//   _ногу_, muab, läsn, _سیمو_, 
   {{0x1dbc3f79,0x6e2c3f7a,0xa7e43f7b,0x1b0c0154}},	//   ्तरत, luab, ىكتى, _হারে_, 
   {{0xe5080451,0x00000000,0x00000000,0x00000000}},	//   ڻيجو_, --, --, --, 
   {{0x6e2c3f7c,0xeb983ad0,0x00000000,0x00000000}},	//   nuab, _диң_, --, --, 
   {{0xe57000c6,0x399001e1,0x29c800e4,0xe404026b}},	//   اطة_, _pàse_, kúai_, нзоп, 
   {{0xbb283ce1,0x5f102a09,0x7dd00139,0x00000000}},	//   _ﻣﻪﻥ_, तरम्_, käsn, --, 
   {{0x6b9800fd,0x6e2c3f7d,0x4ad03f7e,0x201c0419}},	//   _çagı, kuab, _तराव, átim_, 
   {{0x888001d3,0xe6440166,0x00000000,0x00000000}},	//   _سیکن, _челп, --, --, 
   {{0x6e2c3f7f,0x201c1050,0x24e80137,0x15880150}},	//   duab, štim_, _эмки_, _ﯗﺭﺳﯩ, 
   {{0x25a43f80,0x2bb00034,0x00000000,0x00000000}},	//   mill_, jąco_, --, --, 
   {{0x25a4000d,0xdee400d8,0x00000000,0x00000000}},	//   lill_, еоби, --, --, 
   {{0x63a43f81,0xdb00017a,0x25a43f82,0x00000000}},	// [3ea0] mikn, sioë, oill_, --, 
   {{0x25a43f83,0x628402f0,0x0dc400a8,0x00000000}},	//   nill_, myko, елуй_, --, 
   {{0xa0a43f84,0x62843f85,0x25a40036,0xa0c400e3}},	//   _чанд, lyko, iill_, _سيحو, 
   {{0x63a43f86,0x00000000,0x00000000,0x00000000}},	//   nikn, --, --, --, 
   {{0x25a43f87,0x6e2c003a,0x628401d3,0x29000205}},	//   kill_, cuab, nyko, ıhan_, 
   {{0xdca43f88,0x63a43f89,0x25a40117,0xd8080131}},	//   _заги, hikn, jill_, пхил_, 
   {{0x99800064,0xdc3000ef,0x00000000,0x00000000}},	//   _ūkų_, bļāv, --, --, 
   {{0x63a4003e,0x25a40363,0x4c38011a,0x62843f8a}},	//   jikn, eill_, _מתלב, kyko, 
   {{0x25a43f8b,0x63a43f8c,0x98bc00b0,0x95c80137}},	//   fill_, dikn, _patē_, зуна_, 
   {{0x38c820bf,0x25a43f8d,0x62843f8e,0x00000000}},	//   _قاضی_, gill_, dyko, --, 
   {{0x63a43f8f,0xdcec00ef,0x04600229,0x00000000}},	//   fikn, _albī, гтям, --, 
   {{0x63a40ac5,0x25a40731,0x00000000,0x00000000}},	//   gikn, aill_, --, --, 
   {{0x32180408,0x6298010f,0x628401d3,0x7dd001f4}},	//   ussy_, ŝton, gyko, jäso, 
   {{0x63a401a4,0xdb080fac,0x395c003a,0x4ad0000d}},	//   aikn, _ånær, ndvs_, _तरसव, 
   {{0xc4f41a4c,0x9f4003c1,0xf4840345,0x00000000}},	//   _אזוי_, _eikí_, _جاشی, --, 
   {{0x7dd0014a,0x6e2c3f90,0x9ac00003,0x00000000}},	//   fäso, tuab, ċċja, --, 
   {{0x8d8411ed,0x826405d9,0xd24c05d9,0x6e2c003a}},	// [3eb0] нужд, _مهين, _چنڊ_, uuab, 
   {{0x6e2c3f91,0xd24c05d9,0xfd1000c6,0x3ef801c6}},	//   ruab, _ننڊ_, مجم_, _үнээ_, 
   {{0x70943f92,0x6e2c0134,0x00000000,0x00000000}},	//   _ранф, suab, --, --, 
   {{0x2bb0033f,0x25a40036,0x7dd00139,0x00000000}},	//   rąco_, zill_, bäso, --, 
   {{0x6e2c3f93,0x2fd801f9,0x41743c5b,0x25a4062c}},	//   quab, _ihsg_, _شایس, yill_, 
   {{0x25a43f94,0x63a43f95,0x00000000,0x00000000}},	//   xill_, zikn, --, --, 
   {{0x25a4092e,0x62843f96,0x2d9000e2,0x5ec40154}},	//   vill_, zyko, _ilze_, লেদে, 
   {{0x25a43f97,0xb8641ec7,0x6d40002f,0x7dd001f4}},	//   will_, ااوو, _ölab, häsl, 
   {{0x25a43f98,0xe80c2871,0xe94401b9,0x62840076}},	//   till_, _सबका_, _لرای, xyko, 
   {{0x62843f99,0x88e0015b,0x25a40363,0x201c00d7}},	//   vyko, নুষক, uill_, átik_, 
   {{0x63a43f9a,0x23283f9b,0x25a43f9c,0x9f5c036e}},	//   tikn, мони_, rill_, ëtë_, 
   {{0x62843f9d,0xe2b401c0,0x25a43f9e,0xd7e800f7}},	//   tyko, всгэ, sill_, _قولۇ_, 
   {{0xf7703f9f,0x63a43fa0,0x25a43fa1,0xf7000139}},	//   _دال_, rikn, pill_, _уҗым, 
   {{0x63a43fa2,0xf1b40184,0x62843fa3,0xe5a43fa4}},	//   sikn, лҡы_, ryko, _шили, 
   {{0x10a00022,0x00000000,0x00000000,0x00000000}},	//   аирн, --, --, --, 
   {{0x7c281061,0x62840064,0x00000000,0x00000000}},	//   _ådri, pyko, --, --, 
   {{0xe29806a6,0x00000000,0x00000000,0x00000000}},	// [3ec0] _цап_, --, --, --, 
   {{0xac74001f,0x846002d3,0x0e6021f3,0x7dd001f4}},	//   _በኋላም_, _ስራሕን_, шкун, räso, 
   {{0x7dd00267,0xd6b003d4,0x01e400d1,0x8cb401d9}},	//   säso, _চৰায, _ﺋﻮﻳﻨ, نگِس_, 
   {{0xa3d00882,0xcb0400ec,0x00000000,0x00000000}},	//   वति_, پيون_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x399001ab,0xca9c0150,0xdca40107,0xaa6400cf}},	//   _bàsa_, _ﺃﺒﻌﺩ_, _ҷаҳи, انوۉ, 
   {{0xa3d01c9e,0xdca43fa5,0x3ce003d4,0x00000000}},	//   वता_, _рави, _প্রৱ, --, 
   {{0xdca401b9,0x3c3c00d0,0x00000000,0x00000000}},	//   _заҳи, mív_, --, --, 
   {{0x3c3c3fa6,0x201c2625,0x7dd00108,0x00000000}},	//   lív_, štih_, häsm, --, 
   {{0xe7ec02ab,0x63b400a2,0x00000000,0x00000000}},	//   _चूका_, _ajyn, --, --, 
   {{0x92ac3fa7,0x63b40158,0x629801e4,0x3c3c0419}},	//   _করে_, _bjyn, ŝtol, nív_, 
   {{0x69dc3fa8,0x03c4005b,0x00000000,0x00000000}},	//   _èser, исям, --, --, 
   {{0x796800b0,0x63ac00df,0x86c03fa9,0x00000000}},	//   _tīwē, _ĉant, _پيون, --, 
   {{0xf4843faa,0x660c3fab,0x00000000,0x00000000}},	//   _مابی, _çaka, --, --, 
   {{0xa5bc0024,0x3c3c0419,0x7dd00108,0x00000000}},	//   krųj, jív_, räsl, --, 
   {{0x63b40023,0x40340063,0x00000000,0x00000000}},	//   _gjyn, јетс, --, --, 
   {{0x7c9402f2,0x00000000,0x00000000,0x00000000}},	// [3ed0] یشما, --, --, --, 
   {{0xcce4075e,0x3154023a,0x661c3fac,0x7174007b}},	//   نساي, _своё, áski, _إهدا, 
   {{0x8d74168d,0x692401d5,0x00000000,0x00000000}},	//   _یاسا, ҳмла, --, --, 
   {{0xff0421df,0x00000000,0x00000000,0x00000000}},	//   _вярн, --, --, --, 
   {{0xaa441e87,0x98bc0024,0xbea40024,0x99dc0064}},	//   انتى, _katė_, _ваўк, _зiма_, 
   {{0x5ec400fe,0xbd68030d,0xa214010f,0xab30013d}},	//   লেহে, _ирсе_, אַקס_, kıçı_, 
   {{0x92ac015b,0x98bc0024,0xc17400d9,0x98a000db}},	//   _করো_, _matė_, יחס_, йише, 
   {{0xda9405f5,0x7b640114,0xe7381ca9,0x00000000}},	//   _өгсө, _ктуе, хеи_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9f400241,0xe2980022,0x00000000,0x00000000}},	//   _miká_, ҵам_, --, --, 
   {{0x64a43fad,0xab300139,0xe80c0037,0x00000000}},	//   уана, gıçı_, _सबटा_, --, 
   {{0x92ac3fae,0xe29806ed,0x00000000,0x00000000}},	//   _কৰে_, еам_, --, --, 
   {{0x3c3c01d3,0x1718011a,0x00000000,0x00000000}},	//   zív_, _נוסע, --, --, 
   {{0xf67400f1,0xbfc800d1,0xdcec0118,0xa0a4009d}},	//   _خامخ, چارە_, _době, гагд, 
   {{0x3fc83faf,0x201c3fb0,0x00000000,0x00000000}},	//   ندری_, éti_, --, --, 
   {{0xfdd80451,0x8fa0074d,0x7dd00108,0x63b4010e}},	//   چائڻ_, басе, räsm, _ujyn, 
   {{0x1ea836e9,0x29c800eb,0x130000c7,0x9244010a}},	// [3ee0] راري_, núas_, _узым, _бзыб_, 
   {{0x3c3c3fb1,0x00000000,0x00000000,0x00000000}},	//   tív_, --, --, --, 
   {{0x24e4015b,0x61f43fb2,0x1cb80e55,0x81680150}},	//   পুরহ, _huyl, رائب_, _كەڭك_, 
   {{0x9f400270,0x61f401b9,0x9d440139,0x00000000}},	//   _fiká_, _kuyl, _өемд, --, 
   {{0xab3000ac,0x3c3c0f91,0x7dd001e3,0x00000000}},	//   zıçı_, sív_, näsk, --, 
   {{0xdd903fb3,0x00000000,0x00000000,0x00000000}},	//   _اوس_, --, --, --, 
   {{0x7e640cc9,0x7dd0005b,0xaf900023,0x00000000}},	//   lvip, häsk, _ቀሪብና_, --, 
   {{0x7f443fb4,0x92ac03d4,0x7dd026bb,0x7e64000d}},	//   nfiq, _কৰো_, käsk, ovip, 
   {{0x7e6401bf,0x629801e4,0x7dd001f4,0x00000000}},	//   nvip, ŝtoj, väsj, --, 
   {{0xd40402e8,0x7e643fb5,0x93240066,0x00000000}},	//   лями, ivip, گردن, --, 
   {{0x7e643fb6,0xdb0002f0,0x660c010b,0x73d80818}},	//   hvip, dnoú, _çakn, кдор_, 
   {{0xb9d007db,0x61f400fd,0xdcec0118,0x7e640153}},	//   _ድማ_, _buyl, _sobě, kvip, 
   {{0x61f4013c,0x7f440009,0x7e640477,0xdcec0118}},	//   _cuyl, dfiq, jvip, _pobě, 
   {{0x61f43fb7,0xba00063f,0xab3003e3,0x00000000}},	//   _duyl, _ọọ_, pıçı_, --, 
   {{0x7f440194,0x399001ab,0x6ff4033f,0x213c00a3}},	//   ffiq, _làso_, _kąci, òtha_, 
   {{0x29c800fc,0x7f5800c7,0x9984012c,0x4fc401c0}},	//   núar_, ласс_, spoň_, усга, 
   {{0x61f40100,0x6e3c030d,0x7640017a,0x7e640455}},	// [3ef0] _guyl, _qqsb, ntmy, gvip, 
   {{0x7dd00267,0xe18401ec,0xa6e00174,0x00000000}},	//   näsh, _көсе_, øðif, --, 
   {{0x7e640140,0x6c540220,0x61f401f5,0xadf000e1}},	//   avip, ркеу, _zuyl, _अंकन_, 
   {{0x9f40043b,0xc8fc06ab,0xdb243fb8,0xdb0c0248}},	//   _tiká_, ॉर्म_, لومی, _àdìg, 
   {{0x6f0c355e,0xdb000156,0x00000000,0x00000000}},	//   mbac, nnoù, --, --, 
   {{0x6f0c3fb9,0x940800ac,0xda600212,0xe7ec000d}},	//   lbac, şmək_, івщи, _चूजा_, 
   {{0x6f0c3fba,0x27943fbb,0x201c00f3,0xa82402f2}},	//   obac, ишир, štiv_, شکان, 
   {{0x6f0c0a5c,0x6e2c3d6d,0x6d443fbc,0x764009e8}},	//   nbac, orab, lfha, ftmy, 
   {{0xbb840597,0x6e2c3fbd,0x6d443fbe,0xd98c0150}},	//   _القي, nrab, ofha, _ﺒﻠﺩﻩ_, 
   {{0x7dd03fbf,0x6d440e9e,0xa9343fc0,0x29c80077}},	//   väsk, nfha, _خبرچ, rúas_, 
   {{0x7e640e8a,0x61f40342,0x6f0c3fc1,0x29c808a5}},	//   zvip, _suyl, kbac, búar_, 
   {{0xa2e43fc2,0x61f4067c,0x62641318,0x7dd00958}},	//   ионд, _puyl, авма, täsk, 
   {{0x61f403f0,0x3b000986,0x7f44022e,0x00000000}},	//   _quyl, ñiqi_, vfiq, --, 
   {{0xdcfc00da,0x6f0c0086,0x6e2c3fc3,0xd6240261}},	//   āvīg, ebac, drab, _тоше_, 
   {{0x6f0c3fc4,0x66080209,0x9f5c24ba,0x2f0c01a9}},	//   fbac, lpek, ëtï_, _bоg_, 
   {{0x6e2c3fc5,0x64403fc6,0x61f43fc7,0x7dd00227}},	//   frab, mtli, _tuyl, mäsi, 
   {{0x6d443fc8,0x6e2c3fc9,0x64403fca,0x66083fcb}},	// [3f00] ffha, grab, ltli, npek, 
   {{0x7e643fcc,0x656007a9,0xd24c04fb,0x644005e4}},	//   rvip, ndlh, _کنی_, otli, 
   {{0x64403fcd,0x6f0c3fce,0x7e643fcf,0x66080036}},	//   ntli, bbac, svip, hpek, 
   {{0x64403fd0,0xfb180050,0x6d4001e6,0xdcf40259}},	//   itli, اراں_, _ölan, ıcıl, 
   {{0x64403fd1,0x6e2c266b,0x7dd0324c,0x76400175}},	//   htli, crab, häsi, xtmy, 
   {{0x64403fd2,0x7dd01073,0x656000d0,0x66080010}},	//   ktli, käsi, jdlh, dpek, 
   {{0x66083fd3,0x5b34084c,0x2b5401d3,0x7dd001f4}},	//   epek, _вэзу, _گیند_, väsh, 
   {{0xc214013f,0x644003cd,0x00000000,0x00000000}},	//   _owɔ_, dtli, --, --, 
   {{0x64403fd4,0x660c0d31,0x00000000,0x00000000}},	//   etli, _çakl, --, --, 
   {{0x6f0c05ce,0x18a4004e,0xc8a4000d,0x1b0c00eb}},	//   zbac, _казм, _केवट, _হাটে_, 
   {{0xc214016b,0x660822d0,0x6f0c3fd5,0xa3d01a2a}},	//   _awɔ_, apek, ybac, वतं_, 
   {{0x6e2c05da,0x6f0c3fd6,0x93a43fd7,0x00000000}},	//   yrab, xbac, ршод, --, 
   {{0x9f400664,0x64403fd8,0xd5b83fd9,0x6f0c0175}},	//   _mikä_, atli, _иск_, vbac, 
   {{0x6f0c3b08,0x6e2c3fda,0x6b980369,0x2f0c01a9}},	//   wbac, vrab, zhwg, _sоg_, 
   {{0x64403fdb,0xc214013f,0x3be803e3,0x92f0004e}},	//   ctli, _ewɔ_, _eşqi_, _мүнх, 
   {{0x6e2c3fdc,0xa3d0085c,0x2f0c022e,0x95880092}},	//   trab, वतः_, _qоg_, ቄዎችን_, 
   {{0x74d8015b,0x1128013e,0x31340c5c,0x67f4010e}},	// [3f10] _সলিউ, _июни_, _лепр, _išje, 
   {{0x6f0c3fdd,0x6e2c3fde,0x6d442caa,0x8c64004e}},	//   sbac, rrab, ufha, итед, 
   {{0x6e2c3fdf,0x201c012c,0x9f40008e,0x660c0135}},	//   srab, átit_, _bikä_, _ħakm, 
   {{0x6e2c0882,0x66083fe0,0x00000000,0x00000000}},	//   prab, ypek, --, --, 
   {{0x64403fe1,0x80a404fb,0x6d440112,0x201c0b9d}},	//   ztli, _همین, pfha, štit_, 
   {{0x9f400664,0xba7401d9,0x98bc00b8,0xad2415bf}},	//   _eikä_, تامت, _gatī_, _دىسى, 
   {{0x6c843fe2,0xa7a83fe3,0xa2cc21b8,0x00000000}},	//   _الزم, лкка_, _धुन्, --, 
   {{0xd5e001e1,0x78641c02,0x2fc80421,0x644001bf}},	//   _arò, زدىك, noag_, vtli, 
   {{0x466015bf,0xca54010a,0x00000000,0x00000000}},	//   تۇشق, _тĕпп, --, --, 
   {{0x66083fe4,0x660c1395,0x64403fe5,0x847c0023}},	//   rpek, _çakm, ttli, _ክመርሕ_, 
   {{0x64401dfe,0x07a001d9,0xc8b03fe6,0x00000000}},	//   utli, _وۅتُ, _بلاک, --, 
   {{0x06cc00fe,0xd8840271,0x00000000,0x00000000}},	//   াইবি, _دهمی, --, --, 
   {{0x66043e1e,0x9f5c025a,0x7dd8063f,0x7dd0005b}},	//   _упла, ëtí_, ụsir, säsi, 
   {{0x64400086,0x91000801,0x7dd001f4,0xa6e00174}},	//   ptli, зпре, päsi, øðuf, 
   {{0xdfd0046f,0x7dd00309,0x98bc0055,0x6440022e}},	//   كيس_, qäsi, _ratī_, qtli, 
   {{0xd00c193a,0x4fa00801,0x8fa01d0f,0xd5e00241}},	//   علق_, писв, пасе, _iró, 
   {{0x98bc0a26,0x67c0005f,0x1d2401af,0xfd6800c7}},	// [3f20] _patī_, mējd, ймам, mosẽ, 
   {{0x201c3fe7,0x944001d3,0x2eb40212,0x0d7401d9}},	//   átis_, _بھین, істс, میُک_, 
   {{0x261805f9,0x1c4402e8,0xec3401b9,0x00000000}},	//   _मौसी_, снем, قولگ, --, 
   {{0x201c02d5,0xcc380014,0x00000000,0x00000000}},	//   štis_, ازٕچ_, --, --, 
   {{0x090c03d4,0xa2cc0db3,0xccf40107,0x1fe400f1}},	//   _সাজু_, _धुम्, рқӣ_, _نکړي_, 
   {{0xf8b03fe8,0x98bc0022,0x5d8400c6,0xed343fe9}},	//   وکا_, _hatĩ_, _الآل, _мэсэ, 
   {{0x3ea03fea,0x98bc00e4,0xb7a0022e,0x23b00003}},	//   lzit_, _katĩ_, _do壮t, lġju_, 
   {{0x9484052f,0xd4983feb,0xdb0c01e1,0xacb000d1}},	//   ҡынд, ғро_, _àdàg, _تەمب, 
   {{0xc6f40b30,0x7adc000d,0x00000000,0x00000000}},	//   щных_, _बरिअ, --, --, 
   {{0x3f800268,0x3ea00165,0x00000000,0x00000000}},	//   hjiu_, izit_, --, --, 
   {{0x2ed4038e,0xf48404d3,0x774001d9,0x4d78010f}},	//   _दर्त, زادی, _ہێژم, אריע, 
   {{0xc7f40302,0xb92400e4,0xb4d807f7,0x0874008f}},	//   _הזאת_, _nosẽ_, _ारी_, _לעבט_, 
   {{0x2bc83fec,0x112802e8,0x69d0010e,0xd5e00051}},	//   िकता, люви_, _äheñ, _trò, 
   {{0x3ea01310,0x00000000,0x00000000,0x00000000}},	//   dzit_, --, --, --, 
   {{0x44d400c7,0x3ea00156,0xd40401d5,0x7dd00108}},	//   _g̃_, ezit_, _уяли, näsu, 
   {{0x403410fc,0x3ea00208,0x00000000,0x00000000}},	//   џетс, fzit_, --, --, 
   {{0x59b807f8,0x2fc80076,0x660c025c,0x201c0413}},	// [3f30] ेवार, roag_, _ħakk, átir_, 
   {{0x32083fed,0x3328031c,0xa2b40490,0x7dd00254}},	//   _itay_, _hdax_, ईपर्, käsu, 
   {{0xed580184,0xc8a42208,0x7dd001f4,0x00000000}},	//   лоҡ_, _केंट, jäsu, --, 
   {{0xeab001ed,0x7c94007b,0x60d80205,0x00000000}},	//   وٹا_, أشكا, ütme, --, 
   {{0xd6c4036b,0xba240220,0x7af800d0,0x3328002f}},	//   _آق_, здік, _šatá, _mdax_, 
   {{0xa9683fee,0x386c005c,0xa8880408,0x9f5801f4}},	//   рика_, _brdr_, ийла_, _etpä_, 
   {{0xab943fef,0xe73800c0,0x00000000,0x00000000}},	//   _диві, аей_, --, --, 
   {{0x32083ff0,0x33283d27,0x386c0109,0x660c01b8}},	//   _otay_, _ndax_, _drdr_, _çakk, 
   {{0x3b780276,0x2b4c0332,0xf6080133,0xdb0c01e1}},	//   _уйтэ_, _ibec_, یتیه_, _àdág, 
   {{0x5ec404c5,0x9f5800d8,0x332801bf,0x7c34031c}},	//   লেকে, _cupê_, _adax_, żerż, 
   {{0xd7f800c6,0xe3b81c22,0x32083ff1,0x7dd03ff2}},	//   _вσу_, ибо_, _atay_, mäst, 
   {{0x7dd03ff3,0x394c0010,0x00000000,0x00000000}},	//   läst, _zbds_, --, --, 
   {{0xb92400e4,0x7f98013d,0x00000000,0x00000000}},	//   _rosẽ_, _níqa, --, --, 
   {{0xa1143ff4,0xa05402d3,0x33280393,0x98bc0022}},	//   توست, _ምልክታ, _edax_, _satĩ_, 
   {{0x2b4c04bf,0x32083ff5,0x3074023a,0x00000000}},	//   _obec_, _etay_, путс, --, 
   {{0x2a6c003e,0x7dd03ff6,0xdd9000e5,0x00000000}},	//   _oreb_, häst, ڈور_, --, 
   {{0xdd903ff7,0x2a6c01d4,0x2a7c0218,0x7dd03ff8}},	// [3f40] وور_, _nreb_, jxwb_, käst, 
   {{0x5bd00882,0x3ea002d3,0xfd6401c0,0x7dd0005b}},	//   तत्व, rzit_, янзү, jäst, 
   {{0xb92400e4,0x7dd00108,0x00000000,0x00000000}},	//   _tosẽ_, däst, --, --, 
   {{0x29043ff9,0x2a6c062c,0x23c8078a,0x320802d0}},	//   _afla_, _breb_, रविद, _ytay_, 
   {{0xdde807d6,0x7dd001e6,0x2a6c045a,0x00000000}},	//   _نرسه_, fäst, _creb_, --, 
   {{0x7dd03ffa,0xdca43ffb,0x9f400241,0x2a6c00ef}},	//   gäst, _даги, _nikú_, _dreb_, 
   {{0x23c828a2,0xa098010f,0x2a6c06be,0x00000000}},	//   रवाद, ייַט, _ereb_, --, 
   {{0x7d1c3ffc,0x29040008,0x394c0175,0x7dd00108}},	//   _hers, _efla_, _wbds_, räsu, 
   {{0x7d1c3ffd,0x2a6c3ffe,0xda643fff,0xd5b83e09}},	//   _kers, _greb_, _بازي, исо_, 
   {{0x7dd04000,0xdb000037,0x00000000,0x00000000}},	//   mäss, hnoü, --, --, 
   {{0x7d1c4001,0x26dc0943,0x7dd04002,0x32080375}},	//   _mers, _ezwo_, läss, _stay_, 
   {{0x7d1c1f9c,0x43940108,0x00000000,0x00000000}},	//   _lers, даюс, --, --, 
   {{0x798829e5,0x7d1c0225,0x7dd0088f,0x74141dd8}},	//   _kodw, _oers, näss, _کوبا, 
   {{0x7d1c0eda,0xbe5802d3,0xd1c801c6,0x7dd001f4}},	//   _ners, _ምርጫታ, румд_, iäss, 
   {{0x34944003,0x798830ac,0x7dd04004,0x00000000}},	//   _хайр, _modw, häss, --, 
   {{0x79884005,0x7d1c4006,0xb4b400fb,0xdcec0171}},	//   _lodw, _aers, _миҙә, _lobē, 
   {{0x7d1c4007,0x59c81b61,0x51844008,0x2d804009}},	// [3f50] _bers, ाकार, _дуна, tjhe_, 
   {{0x7d1c400a,0x798800a9,0x2b4c0607,0x0a2c0020}},	//   _cers, _nodw, _sbec_, _አፍሪካ, 
   {{0x7d1c400b,0x7dd0049b,0x00000000,0x00000000}},	//   _ders, väst, --, --, 
   {{0x7d1c400c,0x2a6c0010,0x9f580241,0x7dd02305}},	//   _eers, _preb_, _nupè_, fäss, 
   {{0x7d1c193f,0x79880944,0x6f1c0036,0x7e441b0a}},	//   _fers, _bodw, _iesc, _охре, 
   {{0x7d1c400d,0x6f1c400e,0x798803cb,0xf9a40014}},	//   _gers, _hesc, _codw, وٕنُ, 
   {{0x6f1c400f,0x7dd002f6,0x79880042,0xdcec0171}},	//   _kesc, räst, _dodw, _dobē, 
   {{0xe61807d6,0x2a6c0a14,0x7d1c097d,0xa6841e83}},	//   бди_, _treb_, _zers, злид, 
   {{0x7d1c0c3a,0x3964049b,0x6b880421,0xdb2415f6}},	//   _yers, össä_, _ioeg, _رولی, 
   {{0x6f1c4010,0x6b884011,0x79884012,0x290400d8}},	//   _lesc, _hoeg, _godw, _ufla_, 
   {{0xb8d00f22,0xe71819bc,0x95204013,0xa6f4084c}},	//   _টু_, _هيات_, رکوم, _езеш, 
   {{0x6f1c4014,0x6b884015,0x79880944,0x5ec40011}},	//   _nesc, _joeg, _zodw, লেটে, 
   {{0x6b884016,0x79884017,0x2568010b,0x660401d5}},	//   _moeg, _yodw, _галп_, _эпла, 
   {{0x64a44018,0x6f1c0393,0x6b884019,0x741000d1}},	//   _нала, _aesc, _loeg, رۈۋا, 
   {{0x6f1c401a,0x7d1c020c,0xa06800a7,0xe47401c4}},	//   _besc, _rers, щава_, _хулэ, 
   {{0x7d1c401b,0x6b883eb7,0x442401f5,0x9f580518}},	//   _sers, _noeg, _ivn_, _kupé_, 
   {{0x6f1c1e13,0x3d080316,0x8fa013f3,0x4424371a}},	// [3f60] _desc, ाँले_, хате, _hvn_, 
   {{0x7d1c044e,0xdef80510,0x7dd002f6,0x6f1c0221}},	//   _qers, рың_, väss, _eesc, 
   {{0xb63004a9,0x6f1c401c,0x4424020c,0x6b880549}},	//   _ﺑﯘ_, _fesc, _jvn_, _boeg, 
   {{0x6f1c401d,0x7d1c401e,0x7988401f,0x6b8816b8}},	//   _gesc, _wers, _sodw, _coeg, 
   {{0x7d1c4020,0x6b880007,0x7988068f,0x442401f5}},	//   _ters, _doeg, _podw, _lvn_, 
   {{0x7d1c4021,0x7dd01b5d,0x442408cb,0x9f501477}},	//   _uers, räss, _ovn_, åbær_, 
   {{0x6b880a85,0x6b8c025a,0x6f1c0429,0x7dd04022}},	//   _foeg, êngê, _yesc, säss, 
   {{0x79884023,0x6f1c00db,0x6b880142,0x7dd008a1}},	//   _wodw, _xesc, _goeg, päss, 
   {{0x7bc009b6,0x44244024,0x89d404fb,0x79880477}},	//   _ijmu, _avn_, _کولر_, _todw, 
   {{0x442401f5,0x257c0023,0x00000000,0x00000000}},	//   _bvn_, _ንወጻኢ_, --, --, 
   {{0x661801e1,0x3358084c,0x00000000,0x00000000}},	//   _ewwk, оанэ_, --, --, 
   {{0xd7e813d6,0x07a04025,0x00000000,0x00000000}},	//   _умее_, _пахн, --, --, 
   {{0x44244026,0xd1b802dd,0x7bc0037e,0xb3780023}},	//   _evn_, ماسا_, _mjmu, _ክከውን_, 
   {{0x6f1c4027,0x741404d3,0x44240212,0x48e0012c}},	//   _sesc, _قوتا, _fvn_, टेको_, 
   {{0x44f44028,0x25a84029,0xf0e80131,0x69a039c5}},	//   _عروج_, _بدني_, زىرى_, कोटी, 
   {{0xa5080135,0xc4380375,0x5ec4015b,0x6f1c014f}},	//   _གཅོག_, _התהי, লেছে, _qesc, 
   {{0x6f1c402a,0x6b880399,0x2018007f,0x67c000e2}},	// [3f70] _vesc, _roeg, _ewpi_, nēja, 
   {{0x6f1c04e6,0x5064036b,0x6b880214,0x46ac0037}},	//   _wesc, _етма, _soeg, _जइसह, 
   {{0xcee8402b,0x6f1c402c,0x6b8800c5,0x2bc80404}},	//   _گردن_, _tesc, _poeg, िकला, 
   {{0xfc30326c,0xfbd000ec,0x31340023,0x6f1c402d}},	//   احل_, هتن_, _እምበር, _uesc, 
   {{0x6b880cf9,0xcee81a4d,0x69b00490,0x7dd00108}},	//   _voeg, _دردن_, _अगदी, räsr, 
   {{0xac18402e,0x67c0005f,0x98bc0139,0xad240116}},	//   _могу_, dēja, _antı_, _زىرى, 
   {{0x6b88400c,0x27200154,0x31f801f9,0x00000000}},	//   _toeg, _যাবো_, ंदुळ_, --, 
   {{0xf47c02d3,0x44240327,0x225c0210,0x67c00171}},	//   _ንመላእ_, _rvn_, łtki_, fēja, 
   {{0x4424402f,0x3b780166,0x00000000,0x00000000}},	//   _svn_, _эйтэ_, --, --, 
   {{0x4424005f,0x00000000,0x00000000,0x00000000}},	//   _pvn_, --, --, --, 
   {{0xb8084030,0x64a44031,0xf494005b,0xa3e80395}},	//   _فيلم_, фана, еряю, ждна_, 
   {{0x61c4085c,0x31f80490,0xa5f82bbd,0x9f5802f0}},	//   लक्ष, ंदूळ_, _деду_, _tupé_, 
   {{0x67c000e2,0x2d1c01ad,0x1b78010f,0x00000000}},	//   cēja, _फ़ूल_, קטשע, --, 
   {{0x44244032,0xdb0c032e,0xdb0002d2,0x00000000}},	//   _tvn_, _ádög, hnoð, --, 
   {{0x5040035b,0xd0044033,0xa2cc3ec5,0x00000000}},	//   керб, десе_, _धुर्, --, 
   {{0x64a40075,0xe7dc190c,0x00000000,0x00000000}},	//   _наһа, मतिप, --, --, 
   {{0xa1c44034,0xd2600228,0x53a00b01,0x00000000}},	// [3f80] _обид, _акый, _шаъб, --, 
   {{0x69c000f2,0xe0d800f0,0x660c0200,0x00000000}},	//   _njle, _мвп_, _çaku, --, 
   {{0x67c0005f,0xed3401c0,0xe2c800ec,0x00000000}},	//   zēja, ээтэ, _دوکو_, --, 
   {{0x69c04035,0x9f500267,0x00000000,0x00000000}},	//   _ajle, åbär_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x13b80825,0x67c0005f,0x00000000,0x00000000}},	//   _उद्भ, vēja, --, --, 
   {{0x88b007d6,0xfaf801e0,0x00000000,0x00000000}},	//   پینچ, _еҫе_, --, --, 
   {{0xa508031c,0x67c000e2,0x69c001bf,0x7bc04036}},	//   _གཅུག_, tēja, _ejle, _ujmu, 
   {{0x28740022,0x00000000,0x00000000,0x00000000}},	//   _ҿыцр, --, --, --, 
   {{0x9f5c006a,0x67c0005f,0xb8f400eb,0x00000000}},	//   êtê_, rēja, _সঃ_, --, 
   {{0x3494013e,0x67c000e2,0xdb0003b2,0xdee40023}},	//   ханр, sēja, dioú, ማልአ_, 
   {{0x67c0005f,0x00000000,0x00000000,0x00000000}},	//   pēja, --, --, --, 
   {{0x95844037,0x00000000,0x00000000,0x00000000}},	//   _олде, --, --, --, 
   {{0xdedc0023,0x41e40816,0x00000000,0x00000000}},	//   ንካን_, віса, --, --, 
   {{0x855406a9,0x44a000c6,0x603c0311,0x04604038}},	//   _חשוב_, _لموق, _rămî, _атым, 
   {{0x13a401d5,0xa3e407f7,0x96e000bc,0x00000000}},	//   _آچدی_, _बीप_, _पराउ, --, 
   {{0x660c4039,0xa5e80014,0xcd28005e,0x395c01b8}},	// [3f90] _çakt, _بى۪ل_, قسان_, kevs_, 
   {{0xc12c001f,0x395c00e2,0x00000000,0x00000000}},	//   ስታውቃ, jevs_, --, --, 
   {{0xdb000165,0x7dd0403a,0x395c0171,0x00000000}},	//   lioù, räsp, devs_, --, 
   {{0xfa34044e,0x69b0000d,0x00000000,0x00000000}},	//   _ኣይኮኑ, _अगही, --, --, 
   {{0x63740209,0x8fd001e0,0xfbd0009a,0x00000000}},	//   _hünä, _зәҡә, جتل_, --, 
   {{0xfd102966,0x6844403b,0xa3e4130b,0x519c02d3}},	//   _نجف_, енка, _बीन_, _ግዝኣተ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe61805bc,0x23a001ef,0xac180117,0x00000000}},	//   пди_, _kóje_, _моҳу_, --, 
   {{0xbb4801d5,0x00000000,0x00000000,0x00000000}},	//   _تلقن_, --, --, --, 
   {{0x395c00ef,0xcb641954,0x00000000,0x00000000}},	//   cevs_, ተጀመረ_, --, --, 
   {{0x23a001e1,0x00000000,0x00000000,0x00000000}},	//   _lóje_, --, --, --, 
   {{0x67c000e2,0xdee40023,0x00000000,0x00000000}},	//   mējo, ማልእ_, --, --, 
   {{0x27ec403c,0xf770403d,0x65940024,0x67c000e2}},	//   mmen_, _خال_, _паду, lējo, 
   {{0x27ec0c38,0xbba80150,0x00000000,0x00000000}},	//   lmen_, _ﻋﻠﻤﻪ_, --, --, 
   {{0x27ec2153,0xdec01ee0,0x63740139,0x67c000e2}},	//   omen_, ጵያን_, _cünä, nējo, 
   {{0x27ec403e,0x6374014a,0xa2e4403f,0x660c0139}},	//   nmen_, _dünä, _пойд, _çaks, 
   {{0xd24c06f6,0x27ec4040,0x323401c0,0x049800b8}},	// [3fa0] _هني_, imen_, _ихэс, _āpṛt, 
   {{0x27ec4041,0xdca44042,0x4f0405f5,0x67c000e2}},	//   hmen_, нази, _үнэн_, kējo, 
   {{0x27ec4043,0x63740209,0x00000000,0x00000000}},	//   kmen_, _günä, --, --, 
   {{0x27ec4044,0x9f9c025a,0x67c0005f,0xa3e401ad}},	//   jmen_, bïá_, dējo, _बीम_, 
   {{0x27ec4045,0xf1a84046,0x61ec017a,0x00000000}},	//   dmen_, _رایه_, ombl, --, 
   {{0x27ec4047,0xacf417de,0x637400fd,0x8cc801f9}},	//   emen_, رسەت, _yünä, _तुको, 
   {{0x395c4048,0xdca400d8,0x913800df,0x00000000}},	//   revs_, _џаби, לעסק, --, 
   {{0x48700633,0xaac40133,0x395c3a26,0xdb0c0241}},	//   ادوس, رتۆن, sevs_, _ìjàk, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x27ec4049,0xdb000165,0xe530035b,0xd76400cf}},	//   amen_, vioù, аҵшь, بەچى_, 
   {{0xd6d8404a,0x67c000e2,0x27ec022e,0x442400d4}},	//   _کوشش_, cējo, bmen_, нцям_, 
   {{0x27ec34fe,0x61ec01f5,0xdb000fac,0x2ca4008e}},	//   cmen_, embl, gioø, _ülde_, 
   {{0x6374013d,0x00000000,0x00000000,0x00000000}},	//   _sünä, --, --, --, 
   {{0xdb00030a,0x5184404b,0xd08400ee,0xca2c01ec}},	//   rioù, хума, ныби, _ﺫﻫﺏ_, 
   {{0x9f580ffb,0x23a00419,0x660c404c,0xc05800d4}},	//   _tupì_, _sóje_, _çakr, ніт_, 
   {{0x61ec404d,0xb274404e,0x04d8011a,0x00000000}},	//   ambl, _алиш, _מקול, --, 
   {{0x69b00034,0x4ea4404f,0x67c0005f,0x00000000}},	// [3fb0] _अगली, хрва, zējo, --, 
   {{0x27ec4050,0x213c00a3,0xcf2400f1,0x00000000}},	//   zmen_, òtht_, _ګردي, --, 
   {{0x9b0c063f,0xa3e40073,0x0ca80107,0xbd440137}},	//   _ịhịa_, _बीड_, чтаи_, اپمى, 
   {{0x27ec0998,0x67c0005f,0xc4d0008f,0x00000000}},	//   xmen_, vējo, אגע_, --, 
   {{0xa9684051,0x27ec4052,0x6e0000aa,0x4ae401d5}},	//   дила_, vmen_, _څېړن, хўжа, 
   {{0x27ec06f2,0xade41df1,0x67c0005f,0x00000000}},	//   wmen_, _कठिन_, tējo, --, 
   {{0x27ec4053,0x6d540218,0x186406bb,0x2c0401f0}},	//   tmen_, _ibza, ващи_, _рӯзм, 
   {{0x27ec4054,0x67c0005f,0xd7ec00c6,0x3e380023}},	//   umen_, rējo, يكو_, _ክርእይ, 
   {{0x27ec4055,0x9f5c4056,0x67c000e2,0xdb1c0158}},	//   rmen_, êté_, sējo, øvåg, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x27ec2b92,0x6a8401e0,0x00000000,0x00000000}},	//   pmen_, _ялҡа, --, --, 
   {{0x872801d5,0xe7940798,0x00000000,0x00000000}},	//   _хўжа_, _шиењ, --, --, 
   {{0x7cf80086,0x6d540334,0xdec0001f,0x00000000}},	//   _kûrü, _obza, ጵያና_, --, 
   {{0x67e4033f,0xdb0003cd,0x00000000,0x00000000}},	//   bójc, sioø, --, --, 
   {{0xdfd01fbb,0x64a44057,0x61ec02d3,0x9f5800e4}},	//   ليس_, _шака, rmbl, _nupã_, 
   {{0xdee44058,0x6d544059,0x9f580022,0xdb00017a}},	//   воби, _abza, _tupí_, rhoë, 
   {{0x20d00a59,0x00000000,0x00000000,0x00000000}},	// [3fc0] _दुरध, --, --, --, 
   {{0x2fcc341a,0xa3e40c2e,0x661c03b2,0x67c000ef}},	//   čega_, _बीत_, ásky, dējm, 
   {{0xa0a4405a,0x81d809bd,0x9f400100,0xdfe801c0}},	//   _ранд, িষদ_, _dikò_, _одод_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xba540214,0x9f5800c7,0x452400cc,0x88ac00eb}},	//   انتع, _tupâ_, _মানক_, _চুলক, 
   {{0x7f4420ef,0x7e64339b,0x9c580304,0xad2408de}},	//   lgiq, mwip, _ошбу_, _مرفو, 
   {{0xdcec0171,0xdb800064,0x00000000,0x00000000}},	//   _mobī, _краi_, --, --, 
   {{0x7f44405b,0xdcec0171,0x00000000,0x00000000}},	//   ngiq, _lobī, --, --, 
   {{0x95c8405c,0x7e640076,0xa3e40037,0x00000000}},	//   дуна_, nwip, _बीध_, --, 
   {{0x63a40254,0xdcec00de,0x6964210e,0x00000000}},	//   ehkn, _nobī, _مدمق, --, 
   {{0x7e64405d,0x058002dd,0x00000000,0x00000000}},	//   hwip, руым, --, --, 
   {{0x7e64405e,0xb3a4075e,0x00000000,0x00000000}},	//   kwip, اجدۇ, --, --, 
   {{0xe8f40184,0x99840165,0x39b800c0,0x00000000}},	//   _иһә_, nsoů_, _tęsė_, --, 
   {{0x7e640687,0xbba80220,0x7760405f,0x00000000}},	//   dwip, _ﻋﻠﻴﻪ_, lemx, --, 
   {{0x75284060,0x76404061,0x53e40022,0x80040137}},	//   madz, lumy, _ициа, ичте, 
   {{0x75281399,0xa2cc0a59,0x00000000,0x00000000}},	//   ladz, _धुक्, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3fd0] --, --, --, --, 
   {{0x75284062,0x26041d15,0x1ee830d1,0x81d4030d}},	//   nadz, _हंसी_, رولی_, _воьх, 
   {{0x76404063,0x8c6402a9,0xeb38329b,0xebc400c7}},	//   humy, ътад, езеш_, гәан, 
   {{0x75284064,0x09c812ec,0xed5022f3,0x76404065}},	//   hadz, िव्य, _گھر_, kumy, 
   {{0x75284066,0x6f0c0208,0xdb4c0014,0x3b640395}},	//   kadz, mcac, سَو_, ръхв, 
   {{0x75280029,0x76404067,0x6e2c4068,0x9f58035b}},	//   jadz, dumy, msab, _tupã_, 
   {{0x75284069,0x9f9c025a,0x6e2c406a,0x6d44406b}},	//   dadz, bïä_, lsab, mgha, 
   {{0x6d44406c,0x7640406d,0x6e2c37bc,0xc7700228}},	//   lgha, fumy, osab, рткө, 
   {{0x2d90406e,0x4ab43174,0x75280e8a,0x7640406f}},	//   _koze_, _अधिव, fadz, gumy, 
   {{0x75284070,0x6e2c4071,0xf9904072,0x2d904073}},	//   gadz, isab, _وبل_, _joze_, 
   {{0x2d9008ad,0x6f0c4074,0x7760009a,0x6d440072}},	//   _moze_, kcac, bemx, igha, 
   {{0xf7704075,0x2d900960,0x6d440978,0x76404076}},	//   _وان_, _loze_, hgha, bumy, 
   {{0x7528192e,0x764000ca,0x6658030d,0x00000000}},	//   badz, cumy, _чалă, --, 
   {{0xa0684077,0x6e2c4078,0x26dc01e1,0x6d44014f}},	//   нага_, dsab, _iywo_, jgha, 
   {{0x656003b7,0x6f0c4079,0x66081f55,0x6e2c0083}},	//   melh, fcac, lqek, esab, 
   {{0x6f0c407a,0x6d44407b,0x2d90030a,0x6560407c}},	//   gcac, egha, _aoze_, lelh, 
   {{0x6e2c2cf2,0x7f44407d,0xe298407e,0x66080117}},	// [3fe0] gsab, rgiq, _чап_, nqek, 
   {{0x6d44016d,0x65602e10,0x6f0c407f,0x644005c7}},	//   ggha, nelh, acac, ouli, 
   {{0x2d904080,0x6f0c02fa,0x61fc01e2,0x7e6402b9}},	//   _doze_, bcac, _iipl, swip, 
   {{0x752805b8,0xd24c4081,0x6e2c1c06,0x76404082}},	//   zadz, _بنی_, bsab, yumy, 
   {{0x64404083,0xd00c073e,0x67280007,0x75284084}},	//   huli, _ولی_, daej, yadz, 
   {{0xa3e416f0,0x61fc0793,0x76400a1d,0x2d90010e}},	//   _बीस_, _jipl, vumy, _goze_, 
   {{0x64404085,0x75280e8a,0x61fc4086,0x65604087}},	//   juli, vadz, _mipl, delh, 
   {{0x75284088,0x76400516,0x2d9000ca,0xdb4c0133}},	//   wadz, tumy, _zoze_, _رێت_, 
   {{0x2bb0006d,0x75280e8a,0xc214013f,0x6608401f}},	//   jący_, tadz, _ntɔ_, gqek, 
   {{0x64404089,0x35b4408a,0x6560408b,0x26083a64}},	//   fuli, рбор, gelh, _dúo_, 
   {{0x6440408c,0x7528408d,0xc214016b,0x22400de2}},	//   guli, radz, _atɔ_, eukk_, 
   {{0x7528408e,0x7640408f,0xd2444090,0x6e2c4091}},	//   sadz, pumy, лэги, ysab, 
   {{0x75284092,0x65604093,0x8778008f,0x64400129}},	//   padz, belh, _ראדי, auli, 
   {{0xf4843135,0x65600077,0x63b403cb,0x43840150}},	//   _نابی, celh, _emyn, _ۇلىق, 
   {{0x64404094,0x6f0c074d,0x2d904095,0x4fc405f5}},	//   culi, tcac, _roze_, гсаа, 
   {{0x6e2c4096,0x2d904097,0x22404098,0x63ac025c}},	//   tsab, _soze_, bukk_, _ċang, 
   {{0x2d904099,0xadb4409a,0x7f983822,0x23240032}},	// [3ff0] _poze_, абаш, _níqu, _өфөг, 
   {{0x6e2c409b,0x61fc409c,0x6d44409d,0x6f0c409e}},	//   rsab, _gipl, ugha, scac, 
   {{0x6e2c409f,0x6d4440a0,0x2d9005a1,0xfd10007b}},	//   ssab, rgha, _voze_, سجل_, 
   {{0x61fc40a1,0x6d4440a2,0x2d90007f,0x81640014}},	//   _zipl, sgha, _woze_, _پۆہۆ, 
   {{0x692440a3,0x644040a4,0x15f406ab,0xe9d01b45}},	//   амла, zuli, ीदार_, يغت_, 
   {{0x67c0005f,0x644040a5,0x8d8440a6,0x65603b52}},	//   mēji, yuli, _сумд, xelh, 
   {{0x656040a7,0x06cc03d4,0x67c000e2,0x66080784}},	//   velh, াইছি, lēji, wqek, 
   {{0x644040a8,0x2240020c,0x6560017a,0x681000b8}},	//   vuli, yukk_, welh, _nāde, 
   {{0x656040a9,0x644040aa,0x67c000e2,0xbb4840ab}},	//   telh, wuli, nēji, _حلقن_, 
   {{0x67280083,0x09280451,0xb4c00412,0x00000000}},	//   saej, _سسئي_, ंपू_, --, 
   {{0x656040ac,0x638440ad,0x753c033f,0x45240eac}},	//   relh, агна, órza, _মাদক_, 
   {{0x644040ae,0x61fc40af,0x60dc000f,0x68100055}},	//   ruli, _sipl, _rypm, _cāde, 
   {{0x656040b0,0x61fc40b1,0x2128007f,0x644040b2}},	//   pelh, _pipl, tabh_, suli, 
   {{0x1a9804ac,0x67c0005f,0x68ec02a8,0xa3e40dba}},	//   דישע, dēji, ƙadd, _बीर_, 
   {{0x61fc40b3,0x5f0440b4,0x10880131,0x224040b5}},	//   _vipl, изва, _ﻗﯧﺮﯨ, sukk_, 
   {{0x63b40ac8,0x1ea8314c,0x2240020c,0x717015bf}},	//   _umyn, پاري_, pukk_, قۇۋا, 
  
   {{0x1e8440b6,0x5d1440b7,0x61fc40b8,0x8fa040b9}},	// [4000] шлам, لباز, _tipl, цате, 
   {{0x0d8040ba,0x67f40006,0xdc9800f7,0x60083c85}},	//   олун, _išju, ктеш_, _ином_, 
   {{0x16e000bc,0x59c801f9,0x00000000,0x00000000}},	//   _पर्ब, ाकघर, --, --, 
   {{0x9f4001b8,0x5f740075,0x5454008f,0x67c000de}},	//   _aikö_, _ئادر, יסען_, bēji, 
   {{0x67c000e2,0xda700014,0x00000000,0x00000000}},	//   cēji, تُش_, --, --, 
   {{0xd87440bb,0xdb000129,0x00000000,0x00000000}},	//   لاعب, phoï, --, --, 
   {{0x97a440bc,0x588440bd,0x38c840be,0x1b480395}},	//   ирил, рыла, داشی_, _изви_, 
   {{0xaaa40184,0x9f4002f6,0x7f9800d8,0xda641cc7}},	//   ргәҙ, _eikö_, _tíqu, _پاري, 
   {{0xd94409a5,0xe8940034,0x9984004b,0x6810002b}},	//   _вези, gółó, _پلاو, _cādb, 
   {{0xd90c40bf,0xc6f42f6a,0x98bc0064,0xd5ac00e5}},	//   _غیب_, шных_, _actą_, بہت_, 
   {{0x6d7800c8,0xb4c000e1,0x67c0005f,0xd8880451}},	//   אָרװ, ंपे_, zēji, _جپان_, 
   {{0x394c01e2,0xb464008e,0xd3240124,0x73880139}},	//   _hcds_, акүл, шьои, уроң_, 
   {{0xd1b81075,0x394c0083,0xf7700532,0x12e410da}},	//   ناسا_, _kcds_, _واچ_, рінг, 
   {{0x23a001e1,0x660c0098,0x67c000e2,0x05d0007b}},	//   _fójo_, _éaka, vēji, _وزوج, 
   {{0x04400261,0x394c0327,0x3a240142,0x681000de}},	//   _дејн, _mcds_, _lwmp_, _tāde, 
   {{0x67c0005f,0x394c002f,0x321802f0,0xbfa84031}},	//   tēji, _lcds_, ppsy_, атуе_, 
   {{0x7ae005da,0xdfd00451,0xff2801d5,0x59d42cbb}},	// [4010] _nymt, سيٰ_, рўси_, धवार, 
   {{0x67c000da,0x394c009a,0x17040327,0xa2b40118}},	//   rēji, _ncds_, _ངུའམ_, ैपर्, 
   {{0x6c540046,0x67c000e2,0x00000000,0x00000000}},	//   скеу, sēji, --, --, 
   {{0x9f4001b8,0x3a240142,0x7ae00368,0x67c000e2}},	//   _sikö_, _bwmp_, _bymt, pēji, 
   {{0x7b74007b,0x00000000,0x00000000,0x00000000}},	//   تطلا, --, --, --, 
   {{0x320840c0,0x320005da,0xba7440c1,0xda600212}},	//   _muay_, _jihy_, غانت, ївщи, 
   {{0x01380302,0x332801ab,0x394c0142,0x68100055}},	//   ברות_, _oeax_, _dcds_, _sādb, 
   {{0x3328022e,0x7ae40003,0x00000000,0x00000000}},	//   _neax_, żita, --, --, 
   {{0x386c1fc0,0xd70407d8,0x2b4c00db,0x7ae0037e}},	//   _esdr_, щные_, _icec_, _gymt, 
   {{0xbb44010b,0x00000000,0x00000000,0x00000000}},	//   _çärä, --, --, --, 
   {{0x232840c2,0x332801ab,0x7ae00240,0x00000000}},	//   лони_, _beax_, _zymt, --, 
   {{0x29fc0306,0x00000000,0x00000000,0x00000000}},	//   _mňam_, --, --, --, 
   {{0x68e004ce,0x00000000,0x00000000,0x00000000}},	//   _hyld, --, --, --, 
   {{0x3208089c,0xe3b800fd,0x68e040c3,0xe29801e0}},	//   _duay_, _әби_, _kyld, _ҡай_, 
   {{0x320003d1,0x33280076,0x80e00154,0x10a040c4}},	//   _dihy_, _feax_, ফেন্, пирн, 
   {{0x24500232,0x2a6c151c,0x00000000,0x00000000}},	//   mám_, _oseb_, --, --, 
   {{0x24500122,0x320826b6,0x614440c5,0x290440c6}},	// [4020] lám_, _guay_, _лепа, _ogla_, 
   {{0x67c0005f,0x00000000,0x00000000,0x00000000}},	//   mēju, --, --, --, 
   {{0xdc2840c7,0x7ae001e6,0x67c0005f,0x3a240042}},	//   اسطه_, _symt, lēju, _swmp_, 
   {{0xdd9040c8,0x290440c9,0x3a240042,0x7ae0015d}},	//   _کوس_, _agla_, _pwmp_, _pymt, 
   {{0x23700227,0x29041c06,0x200003a0,0x245025fd}},	//   _mayj_, _bgla_, _iiki_, hám_, 
   {{0x200040ca,0x68e00b21,0x245040cb,0x386c0109}},	//   _hiki_, _byld, kám_, _psdr_, 
   {{0x200040cc,0x8c4040cd,0x394c40ce,0x2d98004e}},	//   _kiki_, _нере, _vcds_, _төтө_, 
   {{0x245040cf,0x200023db,0x2904102c,0x7b8402dd}},	//   dám_, _jiki_, _egla_, _باسە, 
   {{0x8f980bd9,0x5ac80798,0x00000000,0x00000000}},	//   טיקי, _слам_, --, --, 
   {{0x200040d0,0x68e0019b,0x67c000da,0x245000bc}},	//   _liki_, _fyld, dēju, fám_, 
   {{0x68e039c2,0x3208005a,0x3328000d,0x00000000}},	//   _gyld, _suay_, _peax_, --, 
   {{0x200040d1,0xa3e40037,0x67c00171,0x00000000}},	//   _niki_, _बीआ_, fēju, --, 
   {{0x320807ae,0x518440d2,0x6444143a,0x00000000}},	//   _quay_, бува, _åhin, --, 
   {{0x20003142,0x245003f7,0x68e0010b,0x00000000}},	//   _aiki_, bám_, _yyld, --, 
   {{0x681000da,0x200040d3,0xefe40023,0x0570027d}},	//   _kāda, _biki_, ማምዑ_, _راود, 
   {{0x20003142,0x681000e2,0x28c800cd,0x67c000de}},	//   _ciki_, _jāda, िपति, bēju, 
   {{0x200040d4,0x67c0005f,0x7c3801a6,0x681000b8}},	// [4030] _diki_, cēju, švrl, _māda, 
   {{0x20000924,0x00000000,0x00000000,0x00000000}},	//   _eiki_, --, --, --, 
   {{0x200040d5,0x70540f54,0xdbd403b2,0x00000000}},	//   _fiki_, _بنجا, tøðl, --, 
   {{0x8f4400c9,0x681000cd,0x0ba833d2,0xdb0c0241}},	//   _уход, _nāda, دائى_, _òdìd, 
   {{0x245000dd,0x75381156,0x68e040d6,0xc33402e4}},	//   zám_, _odvz, _syld, פוס_, 
   {{0x9f40049b,0x68e0000f,0x2fc80af9,0xdcec0205}},	//   _ehkä_, _pyld, lnag_, _elbı, 
   {{0x681000b8,0xc19c0a1e,0x67c000e2,0x01380375}},	//   _bāda, רשוי, zēju, זרות_, 
   {{0x2fc840d7,0x2a6c01d4,0x245004bf,0x6810002b}},	//   nnag_, _tseb_, vám_, _cāda, 
   {{0x68e00b21,0x00000000,0x00000000,0x00000000}},	//   _wyld, --, --, --, 
   {{0x24500232,0x290440d8,0x67c000e2,0x68e040d9}},	//   tám_, _ugla_, vēju, _tyld, 
   {{0xe36440da,0xa3e40118,0x24e800d8,0x7854114f}},	//   окни, _बीउ_, рмни_, _فیوز_, 
   {{0xd8d41a4c,0xc7640075,0x245040db,0x2fc80218}},	//   _וועט_, _دائى, rám_, jnag_, 
   {{0x200006e4,0x7cf040dc,0x24500306,0xa2f4012d}},	//   _riki_, _kórí, sám_, ीखेज_, 
   {{0x64a440dd,0x200040de,0x67c0005f,0x2fc80076}},	//   _мала, _siki_, rēju, enag_, 
   {{0x200040df,0xa0683aeb,0x67c0005f,0x910040e0}},	//   _piki_, шава_, sēju, дпре, 
   {{0x884802d3,0x67c0005f,0x2fc840e1,0x7cf00ca8}},	//   _ዘይተደ, pēju, gnag_, _lórí, 
   {{0x200040e2,0x44240f7b,0xa3e405f9,0xa22400f2}},	// [4040] _viki_, _hwn_, _बीए_, _برعه, 
   {{0x44242a1f,0x64400373,0xef18013e,0x00000000}},	//   _kwn_, orli, имӣ_, --, 
   {{0x200040e3,0x00000000,0x00000000,0x00000000}},	//   _tiki_, --, --, --, 
   {{0x644040e4,0x200040e5,0x5334008f,0x9a84010b}},	//   irli, _uiki_, ַנצן_, жукл, 
   {{0x644040e6,0x442440e7,0x63b400d7,0x1f940240}},	//   hrli, _lwn_, ézny, መዝገበ_, 
   {{0x44240302,0x1278008f,0x2a6800d8,0x644001d5}},	//   _own_, יאנע, çaba_, krli, 
   {{0x68100882,0x09d80327,0x213840e8,0x5edc033f}},	//   _pāda, _ལཉྫ_, _mdph_, _कुत्_, 
   {{0x201800ca,0x64400213,0x8c180a7c,0xd7f8121c}},	//   _mtpi_, drli, _כולי, шул_, 
   {{0x644040e9,0x442440ea,0x3ea040eb,0x3ae840ec}},	//   erli, _awn_, nyit_, _طبری_, 
   {{0x44240007,0x3ea00086,0x68ec00bc,0x6e28013d}},	//   _bwn_, iyit_, řada, _çebe, 
   {{0x644005ce,0x68100318,0x89d406ce,0x68ec0198}},	//   grli, _tāda, _بولر_, ƙada, 
   {{0xb9e402d3,0x44240042,0xf2e8036b,0x00000000}},	//   _ክሊ_, _dwn_, یککه_, --, 
   {{0x644040ed,0xc7f40375,0x2a380092,0x00000000}},	//   arli, _וזאת_, _አውታሮ, --, 
   {{0x44240399,0x06800014,0x6440022e,0xd4980cb6}},	//   _fwn_, _آلوُ, brli, _ври_, 
   {{0x442440ee,0x142802bf,0xdcec02f0,0x2fc80af9}},	//   _gwn_, _тіло_, _babč, tnag_, 
   {{0x2fc80421,0x03c402dd,0x4fc40006,0x00000000}},	//   unag_, _осым, ісва, --, 
   {{0x2fc840ef,0xdcec01a6,0xd9e80490,0xb63c00b5}},	// [4050] rnag_, _dabč, टतात_, _ｇｕ_, 
   {{0xfd5001f2,0x2fc840f0,0xd0840108,0xfe7000e5}},	//   mahụ, snag_, _дыми, کدہ_, 
   {{0x4424003a,0x3ea00076,0xaae801e1,0x00000000}},	//   _xwn_, ayit_, _èsúó_, --, 
   {{0xdcec0f91,0x09c00073,0x213801ef,0x00000000}},	//   _gabč, वच्य, _zdph_, --, 
   {{0xae0402dd,0x6dc00372,0x7cf00241,0x0a680124}},	//   _ءوسى, _كۅرۅ, _pórí, рреи_, 
   {{0xa96840f1,0x644040f2,0xdcec007f,0xadbc030d}},	//   сика_, yrli, _zabč, _сагi, 
   {{0xe738181b,0xe5a40131,0x00000000,0x00000000}},	//   бей_, җини, --, --, 
   {{0x4424003a,0x644001a9,0x00000000,0x00000000}},	//   _rwn_, vrli, --, --, 
   {{0x645c0276,0x442403cb,0x16600eed,0xca7440f3}},	//   ăsim, _swn_, евым, _بازغ, 
   {{0xe298052f,0x644040f4,0x4424033f,0xddd4010b}},	//   ҡан_, trli, _pwn_, gtyň, 
   {{0x64402a28,0xe8781f84,0x00000000,0x00000000}},	//   urli, _دماغ_, --, --, 
   {{0x644040f5,0x3ea040f6,0xe6940150,0x74e801c6}},	//   rrli, yyit_, _ىلاد, өдөг_, 
   {{0x9f5840f7,0x7d18030a,0xa5080408,0xdcec00d7}},	//   _tupú_, ñvsk, _лела_, _rabč, 
   {{0x67e43eba,0x44240393,0x681000e2,0x8fa000c7}},	//   dóji, _twn_, _jādo, ҭаре, 
   {{0x64a440f8,0x6440022e,0x602402e8,0x2328024c}},	//   _хайа, qrli, ядва, _лойи_, 
   {{0x64a43d09,0x39400198,0x00000000,0x00000000}},	//   _маһа, ɗisu_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [4060] --, --, --, --, 
   {{0xdb000798,0xa0740022,0x52d4011a,0x00000000}},	//   lhoç, _еымш, _מופע_, --, 
   {{0x27e80306,0x3ea040f9,0x00000000,0x00000000}},	//   ňany_, syit_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdc940092,0x00000000,0x00000000,0x00000000}},	//   መርመር_, --, --, --, 
   {{0x2ac02d8b,0xceb0008f,0x88b001d5,0x00000000}},	//   _sæbø_, _טיר_, کیمچ, --, 
   {{0xb7d8007b,0x68ec00bc,0x8930072d,0x00000000}},	//   يوتا_, řadn, رعوا, --, 
   {{0xcc540375,0x9c2401a9,0x00000000,0x00000000}},	//   _מבלי_, _мдҳд, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x25a405b1,0x00000000,0x00000000,0x00000000}},	//   gkll_, --, --, --, 
   {{0x79880516,0x97d80108,0xd37c012d,0x00000000}},	//   _indw, _льду_, śćmi_, --, 
   {{0xb4cc1d15,0x28c8227c,0x64900024,0x3dc400fe}},	//   _रखी_, िपरि, džią, ্তিল, 
   {{0x518440fa,0x68100055,0x00000000,0x00000000}},	//   пува, _yādo, --, --, 
   {{0x75d440fb,0x05380020,0x1aec03d4,0xe6c400ae}},	//   _تيتا, _በአሜሪ, _ওলাই_, _تتمي, 
   {{0x798802d0,0x349401c6,0x18500023,0x00000000}},	//   _mndw, _цайр, _ዘይኣማ, --, 
   {{0x63a440fc,0x3ce02cf5,0xffe4004e,0x00000000}},	//   ckkn, _कड़े_, еюун, --, 
   {{0x0d64023a,0x798802d0,0xa3e402db,0x00000000}},	// [4070] зъем, _ondw, _बीट_, --, 
   {{0x79880084,0x00000000,0x00000000,0x00000000}},	//   _nndw, --, --, --, 
   {{0xa11440fd,0xb2840022,0x68100171,0x23a001ef}},	//   _توپت, _хықк, _rādo, _sóji_, 
   {{0x79883ff0,0x4ea41180,0x0fe00137,0x20d400c0}},	//   _andw, _ерга, _чөгү, _džią_, 
   {{0x9f940375,0x681000cd,0x7d2800e5,0x00000000}},	//   _חדרה_, _pādo, érsü, --, 
   {{0xb30c0327,0x00000000,0x00000000,0x00000000}},	//   _གུའང_, --, --, --, 
   {{0x290000c7,0x00000000,0x00000000,0x00000000}},	//   äha_, --, --, --, 
   {{0xe61840fe,0x798840ff,0xbb581513,0x00000000}},	//   оди_, _endw, _насх_, --, 
   {{0x6b884100,0xa50400dc,0x09040395,0x681000de}},	//   _ineg, रश्च_, _ечем, _tādo, 
   {{0xa3e423ef,0x00000000,0x00000000,0x00000000}},	//   _बीज_, --, --, --, 
   {{0x6b884101,0x00000000,0x00000000,0x00000000}},	//   _kneg, --, --, --, 
   {{0x84c00032,0xdcec0055,0xd884009f,0x00000000}},	//   _үҙид, _jabā, _آھون_, --, 
   {{0x6b880a2e,0xb46401ec,0x00000000,0x00000000}},	//   _mneg, _үкіл, --, --, 
   {{0xdcec0029,0xe4c41f71,0x452400fe,0x00000000}},	//   _labā, _ойли, _মাকক_, --, 
   {{0x6b884102,0x11d4007b,0xeff40092,0x00000000}},	//   _oneg, ذوفة_, _ጉምዝ_, --, 
   {{0xa3e44103,0x6b88025c,0x00000000,0x00000000}},	//   _बीच_, _nneg, --, --, 
   {{0xc1b4008e,0x2f1800db,0x00000000,0x00000000}},	// [4080] _зәвы, سىلگ_, --, --, 
   {{0x6b884104,0xdca400f3,0x204000e5,0x00000000}},	//   _aneg, мази, _لڑرہ, --, 
   {{0xdef84105,0xdcec00b8,0x5edc0825,0x00000000}},	//   сың_, _babā, _कुर्_, --, 
   {{0xf00001c0,0x29fc01ef,0x80bc01f9,0x00000000}},	//   _бүси, _mňau_, ोपीं, --, 
   {{0xbe840598,0x6b884106,0xf8b801ad,0x00000000}},	//   _яңал, _dneg, ेप्प, --, 
   {{0x6b884107,0x00000000,0x00000000,0x00000000}},	//   _eneg, --, --, --, 
   {{0xa3dc4108,0xb4cc09fd,0xaf3801a8,0xb788151e}},	//   तका_, _रखे_, _óþæg, зәле_, 
   {{0xcb640276,0x00000000,0x00000000,0x00000000}},	//   _оасе_, --, --, --, 
   {{0x384802d3,0xdc3c0118,0x00000000,0x00000000}},	//   _ዘይምእ, _míče, --, --, 
   {{0xdc3c0122,0x798800f1,0x18684109,0x00000000}},	//   _líče, _undw, _мази_, --, 
   {{0x69dc00c6,0x23a001e1,0xe8c800cd,0x00000000}},	//   _ísea, _lóju_, िपृच, --, 
   {{0x03f805af,0x00000000,0x00000000,0x00000000}},	//   وژيک_, --, --, --, 
   {{0x057001b9,0x5edc00af,0x00000000,0x00000000}},	//   راید, _कुल्_, --, --, 
   {{0xab5c025c,0x00000000,0x00000000,0x00000000}},	//   _imże, --, --, --, 
   {{0x2eec0989,0xcf981614,0x7bc00c8c,0x98bc0e51}},	//   _šef_, оја_, _ommu, _katı_, 
   {{0x325400c7,0x6e940a5b,0xf2c401c6,0x0874010f}},	//   _звир, нибу, _зөги, ועלט_, 
   {{0xadf4410a,0x427400ee,0x00000000,0x00000000}},	// [4090] епаш, _агыс, --, --, 
   {{0x7bc0410b,0x6b88410c,0x9e94410d,0xdcec3da0}},	//   _ammu, _sneg, راقچ, _sabā, 
   {{0xb4cc1889,0x6810002b,0xdcec00ef,0x00000000}},	//   _रखो_, _pādm, _pabā, --, 
   {{0xcf2407c0,0x2fcc002e,0xaa5800d1,0x65ac08a5}},	//   _تردي, _ñeg_, зиду_, _múha, 
   {{0x65ac00d2,0x29fc0209,0x00000000,0x00000000}},	//   _lúha, _oňat_, --, --, 
   {{0x7bc02252,0xad2407a7,0x00000000,0x00000000}},	//   _emmu, _سىرى, --, --, 
   {{0xe738410e,0x98bc03ee,0x9880013a,0x00000000}},	//   пей_, _batı_, bíče_, --, 
   {{0x6b88209c,0xa6940261,0x0a6816a4,0x00000000}},	//   _uneg, ерој, _мрзи_, --, 
   {{0xab280598,0xa6e405f5,0xe6100014,0x00000000}},	//   _моңа_, эжил, دشب_, --, 
   {{0x79f40022,0xe8940006,0xc888009a,0x49200117}},	//   _азух, _пазь, _وخال_, _рӯдҳ, 
   {{0x69c0410f,0x64a44110,0xa3e81d4a,0xf2c80115}},	//   _imle, хана, здна_, _פע_, 
   {{0xe3b04111,0x237400ae,0x00000000,0x00000000}},	//   ارد_, راجح, --, --, 
   {{0x86b00220,0x6d54033f,0x00000000,0x00000000}},	//   _шәкі, _ocza, --, --, 
   {{0x84c00724,0x98bc4112,0x00000000,0x00000000}},	//   _җәүд, _zatı_, --, --, 
   {{0xe3b00597,0x23a002f0,0x201c4113,0x98bc0205}},	//   _مرة_, _sóju_, ëti_, _yatı_, 
   {{0x201c4114,0xc1780024,0xc22400f2,0x98bc008e}},	//   īti_, žė_, _لکسو, _xatı_, 
   {{0x201c4115,0xa2a801d9,0xdc3c0118,0x00000000}},	// [40a0] ūti_, _رُدٕ_, _víče, --, 
   {{0xe1f04116,0x00000000,0x00000000,0x00000000}},	//   _حسب_, --, --, --, 
   {{0x63044117,0xc8dc0037,0xccb00166,0x00000000}},	//   _توکل, _पुलट, гәть, --, 
   {{0x50180375,0x6d5403ee,0x69c04118,0x6cd821f3}},	//   _מוטו, _ecza, _amle, ффус_, 
   {{0xfe0400c7,0x7e0400c7,0x00000000,0x00000000}},	//   _аҟам, _аҧаз, --, --, 
   {{0x98bc0205,0x00000000,0x00000000,0x00000000}},	//   _satı_, --, --, --, 
   {{0x97a402e8,0x00000000,0x00000000,0x00000000}},	//   ерпл, --, --, --, 
   {{0x7bc04119,0xb6c4411a,0xb7d80ef8,0x69dc1427}},	//   _ummu, көлд, بوبا_, _ísen, 
   {{0xc79000db,0x3ae80066,0x00000000,0x00000000}},	//   اشىب, _آبزی_, --, --, 
   {{0x85b4411b,0xb8e801d3,0x00000000,0x00000000}},	//   ельс_, _قبضے_, --, --, 
   {{0x681000dc,0xddc40153,0x98bc0205,0x00000000}},	//   _nādh, _apkū, _tatı_, --, 
   {{0x69c00427,0x00000000,0x00000000,0x00000000}},	//   _zmle, --, --, --, 
   {{0x160801ad,0x046002dd,0x69c003cb,0x00000000}},	//   _हंटर_, _ұтым, _ymle, --, 
   {{0x68100882,0x67e4033f,0x00000000,0x00000000}},	//   _bādh, bójs, --, --, 
   {{0x681000dc,0x941c0408,0x00000000,0x00000000}},	//   _cādh, _урлă_, --, --, 
   {{0x8d74411c,0x681000b8,0x9f5802f0,0x00000000}},	//   کارا, _dādh, _tupý_, --, 
   {{0xa3dc1cd2,0xcd2833d2,0x00000000,0x00000000}},	// [40b0] तकर_, كسان_, --, --, 
   {{0x30141d56,0x201c0137,0x7c3c01f4,0x23a0012d}},	//   _идор, ític_, _bvrr, _wójt_, 
   {{0x9f5800db,0xfe08007b,0x6810002b,0xc8dc012d}},	//   _cupó_, رقمي_, _gādh, _पुंट, 
   {{0xa03800c8,0xdb241617,0x6d54033f,0x69c00010}},	//   _קערפ, نومی, _wcza, _smle, 
   {{0xdb0c0008,0x408801d5,0x00000000,0x00000000}},	//   þjál, _قپیپ_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x68101c52,0x00000000,0x00000000,0x00000000}},	//   _kādi, --, --, --, 
   {{0x68100171,0x49b81bf4,0x00000000,0x00000000}},	//   _jādi, _کارد_, --, --, 
   {{0x7bd8004a,0xdcec0311,0xc8480023,0x68100055}},	//   évue, _tabă, _ዘይምዕ, _mādi, 
   {{0x69c0411d,0x6810411e,0x00000000,0x00000000}},	//   _umle, _lādi, --, --, 
   {{0x6f1c0221,0x00000000,0x00000000,0x00000000}},	//   _ofsc, --, --, --, 
   {{0x681000cd,0x3774004e,0x660c0055,0x00000000}},	//   _nādi, _бышс, _ũaku, --, 
   {{0x68100a28,0x27ec411f,0xc79001e0,0xe69400c7}},	//   _sādh, mlen_, _арҙы, _шиды, 
   {{0xa0684120,0x6f1c0cf9,0x67284121,0xc214013f}},	//   мага_, _afsc, lbej, _nsɔe_, 
   {{0xddd403c6,0xc0bc044e,0x90c00a5b,0x00000000}},	//   jvyš, _ሰውራ_, абре, --, 
   {{0x65ac00d2,0x2f540166,0x6810002b,0xf1b800e2}},	//   _kúho, лтус, _cādi, īša_, 
   {{0xd098044e,0x27ec4122,0xe1244123,0x75f40109}},	// [40c0] ፈላለዩ_, ilen_, _импи, làza, 
   {{0x27ec4124,0x6f1c02d0,0xdb000165,0xf424015b}},	//   hlen_, _efsc, choù, _ভিতর_, 
   {{0x27ec4125,0x6728020c,0x65ac00d7,0x25f8000d}},	//   klen_, kbej, _lúho, _उठनी_, 
   {{0x27ec4126,0xdb1001b8,0x8c401d5b,0x681000b8}},	//   jlen_, _ägüp, реце, _gādi, 
   {{0x27ec4127,0x67280455,0x9b9401d5,0x61ec4128}},	//   dlen_, dbej, _یلست, olbl, 
   {{0x27ec4129,0xaae40451,0x00000000,0x00000000}},	//   elen_, دسمو, --, --, 
   {{0xd7f80276,0x27ec412a,0xdcb00131,0x9b900451}},	//   муи_, flen_, _ئىز_, _پڇاڙ, 
   {{0x27ec412b,0x672822ec,0x65ac0789,0x61ec0112}},	//   glen_, gbej, _búho, hlbl, 
   {{0x1a041411,0x1ae40798,0xcf90011a,0x00000000}},	//   _апам, _роам, שטח_, --, 
   {{0xd824412c,0x661c0321,0x65ac00d0,0x14c8005b}},	//   _аджи, íska, _dúho, дыми_, 
   {{0x27ec412d,0x6728412e,0xa3dc412f,0x667000d1}},	//   blen_, bbej, तकं_, لگۈر, 
   {{0x3014005e,0x61ec0af9,0x7ae40135,0xfbe000cc}},	//   ғдар, elbl, żitu, _বওঁত, 
   {{0x65ac003c,0xddd402f0,0x6810411e,0xd5b84130}},	//   _kúhl, zvyš, _rādi, _оск_, 
   {{0x6810002b,0x28a800cd,0x00000000,0x00000000}},	//   _sādi, _कथमि, --, --, 
   {{0xd1740220,0x40340a0e,0x681000b8,0xef1000db}},	//   ныңы, иерс, _pādi, йүнө, 
   {{0x65ac00d2,0x61ec257c,0x9f580100,0x60d8002d}},	//   _lúhl, albl, _supò_, ûtma, 
   {{0xfe700597,0x7d0c016b,0x2ef44131,0x112800d1}},	// [40d0] يدك_, ɛnsɛ, узар, _оюни_, 
   {{0x68ec0316,0x6728009b,0xf53801e4,0x3f8402d2}},	//   řadi, zbej, naĥ_, _ómun_, 
   {{0x681000e2,0xfbd0004b,0x00000000,0x00000000}},	//   _tādi, ښته_, --, --, 
   {{0x7a3801f2,0x6f1c00d8,0x5e9401e1,0x7b64020f}},	//   _ụtar, _ufsc, _léṣì, итче, 
   {{0x65ac00d2,0xa9684132,0x6728014f,0xba4400d1}},	//   _búhl, еила_, vbej, ңхәй, 
   {{0x2fc801d4,0x27ec4133,0x3170020c,0x00000000}},	//   liag_, wlen_, nezz_, --, 
   {{0x27ec066d,0x186400a7,0xc19c011a,0xd994215c}},	//   tlen_, гащи_, ושגי, انىت_, 
   {{0x27ec4134,0x2fc80076,0x00000000,0x00000000}},	//   ulen_, niag_, --, --, 
   {{0x6728105c,0x27ec4135,0x3338003e,0x317001d3}},	//   rbej, rlen_, dasx_, kezz_, 
   {{0x27ec4136,0x49004137,0x6728014f,0xb54400c7}},	//   slen_, _күлг, sbej, аҧша_, 
   {{0x6934013e,0x67280455,0x7ae40003,0xe3b000ae}},	//   _анҷу, pbej, żitt, مرح_, 
   {{0xc62404c5,0x6728014f,0x00000000,0x00000000}},	//   _মিঠা_, qbej, --, --, 
   {{0x2fc800b5,0x6810002b,0xc44440bf,0x4908190c}},	//   diag_, _cādv, ریکن_, ाशको_, 
   {{0xe3b003e6,0xdee40b01,0x21f4007b,0x00000000}},	//   _گرت_, ҳоби, اكسس, --, 
   {{0x55501d37,0xbb4400a2,0xdfd04138,0x24e8026b}},	//   _اپىر, _çägä, ميس_, _ямки_, 
   {{0xe8540023,0xdee40798,0x00000000,0x00000000}},	//   _ዘይተቐ, гоби, --, --, 
   {{0x93f8008d,0x1e844139,0xe2c800ec,0x00000000}},	// [40e0] _אלקי, ылам, _سودو_, --, 
   {{0xa0c4413a,0xd1b80092,0x00000000,0x00000000}},	//   _ميخو, _ሰምቶ_, --, --, 
   {{0x681000e2,0x9b680114,0x988001ef,0x00000000}},	//   _kādu, ешла_, _píča_, --, 
   {{0x65ac01a2,0x19f401d9,0x00000000,0x00000000}},	//   _súhl, گِتھ_, --, --, 
   {{0x3f801730,0x60d400e2,0x68100055,0x00000000}},	//   mdiu_, šamā, _mādu, --, 
   {{0xf8b000aa,0x44f0413b,0xa00000b4,0x3f80004e}},	//   يکا_, _ọ_, _ọchị, ldiu_, 
   {{0x7a4000b8,0x00000000,0x00000000,0x00000000}},	//   _sãtā, --, --, --, 
   {{0x3f80413c,0x9484413d,0xd9b000db,0xda6400ec}},	//   ndiu_, ңынд, _گەتد, _ٽاري, 
   {{0xd90c040b,0x36d4413e,0x35b4413f,0x44f0004d}},	//   _ٹیب_, ропр, ибир, _ạ_, 
   {{0xd90c26f0,0x3f80036e,0x660c002b,0x00000000}},	//   _عیب_, hdiu_, _ũakr, --, 
   {{0x05800220,0xf53801e4,0x2ed0012d,0xb4c000cd}},	//   суым, raĥ_, _सख्त, ूपे_, 
   {{0x2fc801d4,0x3f800023,0x7c200010,0xd3780408}},	//   xiag_, jdiu_, _čmrl, хчо_, 
   {{0x3a2405b1,0x44f00248,0x95c84140,0xb59400d8}},	//   _jtmp_, _ẹ_, _пука_, _вилш, 
   {{0xc640009f,0x00000000,0x00000000,0x00000000}},	//   _اَوي, --, --, --, 
   {{0x31704141,0x2fc801d4,0x25f803ce,0x00000000}},	//   rezz_, tiag_, _उठती_, --, 
   {{0x668001d5,0x3338031c,0x4cbc00fe,0xddd40210}},	//   _اییل, qasx_, ্থমু, jtył, 
   {{0x2fc805c7,0x1ee80066,0xade80066,0x00000000}},	// [40f0] riag_, پولی_, نفرم_, --, 
   {{0x2fc80211,0x3f8007c5,0x386c01f5,0x91d003d4}},	//   siag_, adiu_, _opdr_, _দীৰ্, 
   {{0x3a240175,0x82f801d5,0xc8c04142,0x709401f0}},	//   _atmp_, _لریز_, _वेंट, _танф, 
   {{0x5b100831,0xc0700020,0xd7e400ae,0x2ec43947}},	//   ҙмәт, _ሥልጣን_, _ذك_, _көзм, 
   {{0x2d840261,0x386c0077,0x5b100daf,0xd8b400f2}},	//   _óleo_, _apdr_, әмәт, یگما_, 
   {{0x3a240077,0xe968033a,0xacf8014b,0x00000000}},	//   _dtmp_, такл_, _ангу_, --, 
   {{0xa7b41b88,0x7c844143,0xadf812eb,0xb4c000cd}},	//   исиј, _луте, ्गठन_, ूपो_, 
   {{0xe9444144,0x661c4145,0x8af40213,0x2d804146}},	//   _چرای, ísko, çəsi, ldhe_, 
   {{0x46800116,0x44f00248,0x00000000,0x00000000}},	//   сқла, _ṣ_, --, --, 
   {{0x2d804147,0xf6681564,0xd704023a,0x00000000}},	//   ndhe_, احيه_, шные_, --, 
   {{0x23284148,0x2d8014d0,0xa7744149,0x084001d9}},	//   кони_, idhe_, _влеч, _اۆبُ, 
   {{0xe284414a,0xf5e8004e,0x38c8009d,0x00000000}},	//   алми, кмөл_, _суун_, --, 
   {{0x2d903a0e,0x2d80414b,0x3a240175,0x05040154}},	//   _onze_, kdhe_, _xtmp_, োরের_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2d800882,0x6ad02894,0x681000e2,0x94d000f3}},	//   ddhe_, तपुर, _tādu, _мољц, 
   {{0x7880012c,0x3f80414c,0x2d900010,0x2d800009}},	//   lává, udiu_, _anze_, edhe_, 
   {{0xdd90414d,0xd004414e,0x3f80414f,0xe2984150}},	// [4100] يور_, рете_, rdiu_, _рап_, 
   {{0x63b401a8,0x788000bc,0xdb000205,0x00000000}},	//   _hlyn, nává, lkoç, --, 
   {{0x628420a4,0x1c384151,0xddd400d7,0x00000000}},	//   lvko, тязь_, jvyť, --, 
   {{0x2d900912,0x1a2800d6,0x2d802878,0x6ad02802}},	//   _enze_, вжди_, adhe_, तपूर, 
   {{0x63b44152,0x788000bc,0x386c0051,0x661c1427}},	//   _mlyn, kává, _spdr_, ískl, 
   {{0xdd904153,0x63b40368,0x00000000,0x00000000}},	//   _بوس_, _llyn, --, --, 
   {{0x8c40204c,0xdca44154,0x7880038e,0xb7c44155}},	//   _мере, _тави, dává, йриқ, 
   {{0x27fc0042,0x00000000,0x00000000,0x00000000}},	//   _chwn_, --, --, --, 
   {{0xa5bc0064,0xe7440139,0x00000000,0x00000000}},	//   mpųj, сүче_, --, --, 
   {{0x55044156,0x63b40209,0xab64005f,0x5fc400bc}},	//   ична, _alyn, _viļņ, रोतल, 
   {{0x63b44157,0x201c4158,0x62840419,0xd6e00210}},	//   _blyn, ítil_, evko, wałę_, 
   {{0x81b00198,0x63b44159,0x00000000,0x00000000}},	//   _ruɓa, _clyn, --, --, 
   {{0x2d80415a,0x7880013a,0x00000000,0x00000000}},	//   ydhe_, bává, --, --, 
   {{0x463804ac,0x63b4015d,0x6e28415b,0x22a80064}},	//   _יעדע, _elyn, _çebi, dėką_, 
   {{0x63b400a9,0x4fc4415c,0x764008ce,0x44f004b3}},	//   _flyn, асаа, lsmy, _وسىز, 
   {{0x63b40368,0x6810005f,0x9fa401e0,0x00000000}},	//   _glyn, _kādr, быуҙ, --, 
   {{0x7640007c,0x2d80036e,0x00000000,0x00000000}},	// [4110] nsmy, tdhe_, --, --, 
   {{0x7174415d,0x7178415e,0xac8c001f,0x6810002b}},	//   _اهدا, _сбор_, ነርሱም_, _mādr, 
   {{0x6fb4415f,0x2d8002d3,0x753803ee,0x69dc1427}},	//   _همدا, rdhe_, _mevz, _ísei, 
   {{0x753805d5,0x6f9400c6,0x2d800240,0x78800118}},	//   _levz, _الحض, sdhe_, zává, 
   {{0x114802d3,0x681000b8,0x6a8401d5,0x764001ef}},	//   _ንምድሓ, _nādr, слла, jsmy, 
   {{0x75384160,0x2d90339b,0x76404161,0xaa9401b9}},	//   _nevz, _unze_, dsmy, _қизч, 
   {{0x788000bc,0x764000d7,0x00000000,0x00000000}},	//   vává, esmy, --, --, 
   {{0xacf8036b,0x764001a8,0x00000000,0x00000000}},	//   _анҳу_, fsmy, --, --, 
   {{0x68100055,0x76404162,0xac900092,0x78800118}},	//   _cādr, gsmy, _የሚጠጉ_, tává, 
   {{0xe2984163,0xdcec0118,0x2bb4012d,0x45a00137}},	//   ҳам_, _nabě, ंसवा, تەتك, 
   {{0x63b403c6,0x78800118,0x00000000,0x00000000}},	//   _plyn, rává, --, --, 
   {{0x63ac025c,0xf1a80375,0x61fc036e,0x78800118}},	//   _ċans, _אס_, _shpl, sává, 
   {{0xe5684164,0x1b7800c8,0x61fc0334,0x75384165}},	//   _билд_, נטשע, _phpl, _fevz, 
   {{0x13004166,0xa114276c,0x00000000,0x00000000}},	//   язям, صورت, --, --, 
   {{0x62840254,0x108800d1,0xb61001ec,0xa444009f}},	//   svko, _ﺗﯧﺮﯨ, _ﺴﺭ_, _اَبو, 
   {{0x44244167,0x75384168,0x50640023,0x63b44169}},	//   _itn_, _zevz, _ምግላጽ, _ulyn, 
   {{0x44240218,0x6440416a,0x13b4011a,0x00000000}},	// [4120] _htn_, lsli, _להקל_, --, 
   {{0x4424416b,0x644001ab,0x00000000,0x00000000}},	//   _ktn_, osli, --, --, 
   {{0xdef8416c,0x6aa40154,0x44240108,0xe8e400ec}},	//   тың_, _খেলো, _jtn_, _آڻ_, 
   {{0x6440416d,0x67380083,0xdcec0118,0x2f1c00e5}},	//   isli, _newj, _zabě, _vágó_, 
   {{0x2018416e,0x6440002d,0x2240037e,0xab6400e2}},	//   _hupi_, hsli, nskk_, daļā, 
   {{0x2018416f,0x09e04170,0x64404171,0x7e644172}},	//   _kupi_, почн, ksli, mtip, 
   {{0x58844173,0x64404174,0x44244175,0x753800ef}},	//   сыла, jsli, _ntn_, _revz, 
   {{0x644039c2,0x21384176,0x20184177,0x76404178}},	//   dsli, _leph_, _mupi_, tsmy, 
   {{0xd9444179,0x64400660,0x673801c8,0x985002d3}},	//   _гези, esli, _dewj, _ዘይምህ, 
   {{0x4424417a,0x999401d9,0x6440417b,0xdb00000d}},	//   _btn_, _چھژر_, fsli, rkoä, 
   {{0x65ac00d2,0x7e6433eb,0x2018417c,0x73d80117}},	//   _lúhw, htip, _nupi_, идор_, 
   {{0x7e64417d,0xa784009f,0x00000000,0x00000000}},	//   ktip, _وشنو, --, --, 
   {{0x20180270,0x64400151,0x0ec42ba2,0x12e402dd}},	//   _aupi_, asli, _रेंड, сінг, 
   {{0x2018073c,0x4424417e,0xf4340276,0x7e640115}},	//   _bupi_, _ftn_, _декэ, dtip, 
   {{0x7e6401f5,0x64400175,0x00000000,0x00000000}},	//   etip, csli, --, --, 
   {{0x20180438,0x7e64002f,0x00000000,0x00000000}},	//   _dupi_, ftip, --, --, 
   {{0x7e64417f,0x6e980364,0xd1c80276,0x442403e0}},	// [4130] gtip, швар_, _бунд_, _ztn_, 
   {{0x20184180,0x44244181,0x00000000,0x00000000}},	//   _fupi_, _ytn_, --, --, 
   {{0x6ad0085c,0x7e644182,0x20180010,0xccf80063}},	//   तप्र, atip, _gupi_, ућа_, 
   {{0x8264034c,0x6af40816,0x6e9400d8,0xfe7000e5}},	//   _بهین, озеф, _диму, بدہ_, 
   {{0x0b54052f,0xc3340375,0x2bbc0f44,0x6fb40214}},	//   арҙы_, לוף_, ्फबा, _همگا, 
   {{0x6e2c4183,0x201801f7,0xa2d805c0,0x00000000}},	//   mpab, _yupi_, नपत्, --, 
   {{0xab6400e2,0x29fc00d0,0xa82401d5,0x98a01c35}},	//   taļā, _kňaz_, زکان, дище, 
   {{0x44244184,0xe7a802e8,0x00000000,0x00000000}},	//   _rtn_, рвил_, --, --, 
   {{0x6e2c4185,0x44244186,0x9ba0075e,0x97800330}},	//   npab, _stn_, _تەنى, بینه, 
   {{0x44240263,0x7ac44187,0xba7401b9,0x201c01d3}},	//   _ptn_, _эссе, _عاقت, ítik_, 
   {{0x87e43f51,0x64404188,0x64a44189,0x00000000}},	//   _люде, usli, цана, --, 
   {{0x201807dd,0x6e2c0036,0x213801bf,0x44240051}},	//   _rupi_, kpab, _seph_, _vtn_, 
   {{0x2018418a,0x44240042,0x7e64072b,0x00000000}},	//   _supi_, _wtn_, xtip, --, 
   {{0x2018418b,0x6440418c,0xa50801b9,0xe604009f}},	//   _pupi_, psli, _кела_, _بِتَ, 
   {{0x1fa8418d,0x6440031c,0x00000000,0x00000000}},	//   акви_, qsli, --, --, 
   {{0xa3bc08a3,0x25fc069f,0x7e64418e,0xd5e0004d}},	//   _इति_, _रीती_, ttip, _trọ, 
   {{0x6e2c1089,0xdb04418f,0x7e644190,0x00000000}},	// [4140] gpab, ümün, utip, --, 
   {{0xdd904191,0x20184192,0xc06002d3,0x9cf403f6}},	//   بوط_, _tupi_, _ዕግርግ, очеш, 
   {{0x7e644193,0xdc980228,0x20180194,0x1be802e8}},	//   stip, шташ_, _uupi_, аджи_, 
   {{0x7e644194,0x00000000,0x00000000,0x00000000}},	//   ptip, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x0c2000d3,0xf1b800e2,0x4aa405a2,0xdb1c01e3}},	//   _імун, īši_, скән_, åväg, 
   {{0x20000270,0x65ac00d7,0x00000000,0x00000000}},	//   _mhki_, _lúhu, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6e2c01c4,0x6994009d,0x00000000,0x00000000}},	//   zpab, _эртх, --, --, 
   {{0x24502374,0xfa680092,0x00000000,0x00000000}},	//   رچىس, _ሳይኖር_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69dc0413,0x65ac00d0,0x6adc00cc,0x00000000}},	//   _íset, _súhv, _বৰডো, --, 
   {{0x85540375,0x16d8000d,0x00000000,0x00000000}},	//   _ושוב_, _बखुब, --, --, 
   {{0x09b44195,0x200001a9,0x6e2c4196,0x00000000}},	//   _अत्य, _chki_, tpab, --, 
   {{0xcd284197,0x00000000,0x00000000,0x00000000}},	// [4150] لسان_, --, --, --, 
   {{0xab5c0327,0x6e2c4198,0x7dc0007c,0xaa44010b}},	//   _imżi, rpab, _lösf, җекл, 
   {{0xe8a80073,0x6e2c4199,0xdb0001ef,0x00000000}},	//   _कथेच, spab, ckoú, --, 
   {{0x207804ac,0x16d8012d,0x00000000,0x00000000}},	//   _פארא, _बखूब, --, --, 
   {{0xe73801e0,0x80a4085b,0xfbd00472,0x00000000}},	//   ҙеп_, _فمین, ختل_, --, 
   {{0x2d84000f,0xdd180139,0xc27c00df,0x00000000}},	//   _ûle_, _içşi, ירדי, --, 
   {{0x01380375,0x00000000,0x00000000,0x00000000}},	//   חרות_, --, --, --, 
   {{0x4e1c1fd2,0xd5bc00b8,0xbb5801fe,0x00000000}},	//   _बढाई_, _śāpo_, _масх_, --, 
   {{0xbdf80014,0x685402d3,0x00000000,0x00000000}},	//   _درێا_, _ዘይምት, --, --, 
   {{0x77bc0077,0x00000000,0x00000000,0x00000000}},	//   _réxe, --, --, --, 
   {{0xb9c42781,0xdb0c0248,0x24e801a9,0x00000000}},	//   _تقلي, _òdòd, смни_, --, 
   {{0x7dc0007c,0x24680150,0xa2e401a9,0x00000000}},	//   _gösf, _ۇمتپ_, зомд, --, 
   {{0x659428f1,0xcfc000eb,0x00000000,0x00000000}},	//   _наду, ্কান, --, --, 
   {{0x27ec419a,0x4e1c00af,0x21680063,0x00000000}},	//   loen_, _बढ़ई_, љиви_, --, 
   {{0x9100419b,0x1fb4419c,0x00000000,0x00000000}},	//   епре, псар, --, --, 
   {{0x27ec419d,0x8fa02fc3,0xe298419e,0x00000000}},	//   noen_, насе, _гаи_, --, 
   {{0xd12c01ed,0x27ec01c4,0x00000000,0x00000000}},	// [4160] ئمہ_, ioen_, --, --, 
   {{0x613805f5,0x27ec419f,0x1334069d,0x944000e5}},	//   _учир_, hoen_, _ኤኮኖሚ, _تھین, 
   {{0x27ec0068,0x61ec41a0,0xdcec0139,0x7dc001e3}},	//   koen_, mobl, _pobı, _lösg, 
   {{0x61ec41a1,0xda6400c6,0x27ec41a2,0x9a8401a9}},	//   lobl, كاتي, joen_, зукл, 
   {{0x27ec22b6,0xf38c008f,0x25640100,0x2bbc01ad}},	//   doen_, יראָ, _kňlč_, ्फ़ा, 
   {{0x61ec41a3,0xb92400e4,0xdb0001c7,0x00000000}},	//   nobl, _hasẽ_, ljoë, --, 
   {{0x27ec41a4,0x38c80edf,0x75240342,0x6adc00fe}},	//   foen_, غاتی_, _şizo, _বৰদো, 
   {{0x27ec41a5,0x61ec41a6,0xeb4800db,0x00000000}},	//   goen_, hobl, _وشقو_, --, 
   {{0x3ea01730,0xdb000036,0x1aa800cc,0x3964014b}},	//   nxit_, ijoë, _খেৰা, _онаҳ, 
   {{0x61ec0316,0x3ea000db,0xd4e401f4,0x00000000}},	//   jobl, ixit_, зюми, --, 
   {{0x61ec41a7,0x27ec1bbc,0xd88801d9,0x00000000}},	//   dobl, boen_, _دپان_, --, 
   {{0xb46400cf,0x00000000,0x00000000,0x00000000}},	//   пкүл, --, --, --, 
   {{0xa3bc05ba,0x7dc004cc,0x96f800cf,0x11480023}},	//   _इतर_, _gösg, _اعار_, _ንምውሓ, 
   {{0xd49802bf,0x61ec037e,0x870800e5,0x00000000}},	//   _гри_, gobl, _طعنہ_, --, 
   {{0x3ea041a8,0xdcec0139,0x009400cf,0x00000000}},	//   exit_, _rabğ, нирэ, --, 
   {{0x61ec01ab,0x04d8011a,0x7dc001e3,0x719400b8}},	//   aobl, _לקול, _lösd, _ṛgād, 
   {{0x394c41a9,0x61ec2e36,0x27300092,0x00000000}},	// [4170] _odds_, bobl, _በኢህአ, --, 
   {{0x27ec41aa,0x2bb41d2e,0x61ec41ab,0xa2d841ac}},	//   zoen_, ंस्थ, cobl, नपर्, 
   {{0x753c012d,0x00000000,0x00000000,0x00000000}},	//   órzy, --, --, --, 
   {{0xf1b800e2,0x394c011a,0x27ec41ad,0xbb440139}},	//   īšu_, _adds_, xoen_, _çälä, 
   {{0x3ea0004e,0xf1b800e2,0x0a6800c7,0x27ec41ae}},	//   cxit_, ūšu_, среи_, voen_, 
   {{0xba740150,0x6c54010b,0x00000000,0x00000000}},	//   عانت, _окгу, --, --, 
   {{0x27ec1859,0xe7381c22,0x00000000,0x00000000}},	//   toen_, оей_, --, --, 
   {{0x8c3401f0,0x00000000,0x00000000,0x00000000}},	//   _моҳӣ_, --, --, --, 
   {{0x27ec41af,0x660441b0,0x2b4c17cd,0xcfbc0154}},	//   roen_, мпиа, _idec_, _ইদান, 
   {{0x27ec41b1,0xe610007b,0x00000000,0x00000000}},	//   soen_, خشب_, --, --, 
   {{0x61ec036b,0x27ec41b2,0xe6100133,0xfbc40303}},	//   vobl, poen_, _یشت_, लोकम, 
   {{0xd6cc41b3,0x3ea0011f,0xe6980330,0x61ec007f}},	//   اقی_, yxit_, _وپاش_, wobl, 
   {{0x61ec41b4,0x2b4c05b1,0xfe1c000d,0x00000000}},	//   tobl, _mdec_, _भंइस_, --, 
   {{0x7dc041b5,0x213c00c6,0x661c0321,0x660401d5}},	//   _köse, úth_, ísku, _ўпка, 
   {{0xdfd041b6,0xe3e000c7,0x25640100,0x3074005b}},	//   نيس_, _аҩнқ, _vňlč_, нутс, 
   {{0x61ec006c,0x7dc00598,0xe3b8033a,0x661c00df}},	//   sobl, _möse, _фби_, ŭsku, 
   {{0x7dc041b7,0x61ec41b8,0x16004142,0x3d1001f9}},	// [4180] _löse, pobl, _रीडर_, थेने_, 
   {{0x61ec01a9,0x09b000eb,0x00000000,0x00000000}},	//   qobl, ঝোতা, --, --, 
   {{0xb9240022,0x00000000,0x00000000,0x00000000}},	//   _tasẽ_, --, --, --, 
   {{0x3ea00227,0x92c00183,0x00000000,0x00000000}},	//   pxit_, ্থৰ_, --, --, 
   {{0x7f440789,0x77bc00e8,0x672c01e4,0x397441b9}},	//   maiq, _néxa, _ĵajp, еллё, 
   {{0x7dc041ba,0x8b900166,0x00000000,0x00000000}},	//   _böse, ерәч, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7f440cfe,0x7dc00036,0x4fb8008f,0x480400d8}},	//   naiq, _döse, ַציא, мејн_, 
   {{0xda640451,0x27e00c6a,0x68ec0db1,0x00000000}},	//   _تازي, éhna_, ğada, --, 
   {{0x65ac0030,0x332806af,0x68ec41bb,0x4ab000ee}},	//   _súhr, _sfax_, şada, _шөхр, 
   {{0x79880472,0x7dc0007c,0x058001ec,0x1ad0000d}},	//   _iadw, _göse, туым, _देतथ, 
   {{0x798841bc,0xdcec003a,0x439441bd,0xe97000db}},	//   _hadw, _habē, ваюс, _لۇۇد, 
   {{0x7d1c09a8,0x79880489,0x81e8015b,0x667001b9}},	//   _ogrs, _kadw, বতন_, _یگیر, 
   {{0x798841be,0x7dc0002f,0x733400cf,0x00000000}},	//   _jadw, _lösb, بىڭا, --, 
   {{0x7988038f,0x1cc8003d,0x53e4004e,0xdeb001ec}},	//   _madw, ླགས_, _оциа, құры, 
   {{0x80a003f3,0x7f440357,0xef6405f5,0x798841bf}},	//   _ऑपरे, gaiq, ээгү, _ladw, 
   {{0x7c3c02d0,0x0d64023a,0x798803ac,0xed5001d9}},	// [4190] _awrr, дъем, _oadw, ُھس_, 
   {{0x798841c0,0xccf80063,0x00000000,0x00000000}},	//   _nadw, оће_, --, --, 
   {{0x8c64009d,0x00000000,0x00000000,0x00000000}},	//   ьтад, --, --, --, 
   {{0x798802d0,0x7f4400db,0x96ac12eb,0x95800064}},	//   _aadw, caiq, टहाउ, _šąla, 
   {{0xba2841c1,0x798841c2,0x7c580131,0xfa640014}},	//   وسوم_, _badw, كلەر_, ندوٝ, 
   {{0x798800a9,0xae0441c3,0x00000000,0x00000000}},	//   _cadw, _سوزى, --, --, 
   {{0x798841c4,0x8cb401d9,0x1dc0013d,0x00000000}},	//   _dadw, _تۯاس_, _сөтн, --, 
   {{0x2b4c004b,0xa6840209,0x798802d0,0xead80150}},	//   _udec_, елид, _eadw, _ембі_, 
   {{0xdcec01e4,0x798841c5,0x7b6400f3,0x468001a9}},	//   _dobĵ, _fadw, _штре, тқла, 
   {{0x6d4441c6,0x77bc0f71,0x1a780014,0x798803cb}},	//   naha, _véxa, _عشقک_, _gadw, 
   {{0x6d4406c8,0x7dc00112,0x24f40276,0xe36401d5}},	//   iaha, _hösc, эчир, нкни, 
   {{0x7dc00036,0x6e3c03ac,0x00000000,0x00000000}},	//   _kösc, _owsb, --, --, 
   {{0x6d4441c7,0x6b8841c8,0xaca00020,0xac7c0020}},	//   kaha, _maeg, _ለዚህም_, _ከዚህም_, 
   {{0x6b880007,0x6f1c02d0,0x7dc00036,0x00000000}},	//   _laeg, _agsc, _mösc, --, 
   {{0x6d4441c9,0x7dc00639,0x7f440d04,0x6e3c0139}},	//   daha, _lösc, taiq, _awsb, 
   {{0x672841ca,0x2f5441cb,0x7bc80064,0x00000000}},	//   ncej, ктус, _įduo, --, 
   {{0x6d4441cc,0xc0bc0092,0x00000000,0x00000000}},	// [41a0] faha, _ሰውም_, --, --, 
   {{0x4d603529,0x6f1c0036,0xdb0800d5,0x201c01a8}},	//   лкув, _egsc, _énér, ítis_, 
   {{0x6b8841cd,0x798841ce,0x6e3c02d0,0xbb440139}},	//   _baeg, _radw, _ewsb, _çäkä, 
   {{0x6b880007,0x798841cf,0x7dc023eb,0x6d442367}},	//   _caeg, _sadw, _bösc, aaha, 
   {{0x6d4441d0,0x6b880207,0x798805e4,0x614c02d3}},	//   baha, _daeg, _padw, _ንምዕባ, 
   {{0x7dc002c1,0x79880455,0x1ba801d3,0x67280fac}},	//   _dösc, _qadw, _کاسٹ_, ecej, 
   {{0x6b88031c,0xadb40ef6,0x79880477,0x1d080353}},	//   _faeg, _جۇلا_, _vadw, _хеви_, 
   {{0x7988013f,0x6b882a9a,0x7dc00036,0x68100aea}},	//   _wadw, _gaeg, _fösc, _zādz, 
   {{0x7bc041d1,0x7dc004cc,0x7988002d,0x9f400200}},	//   _ilmu, _gösc, _tadw, _ajkë_, 
   {{0x9324168d,0x81b002a8,0x75d40451,0xceb00375}},	//   کردن, _kuɓu, ئيدا, טיח_, 
   {{0x6b8841d2,0x855401d3,0x00000000,0x00000000}},	//   _yaeg, ریٹر_, --, --, 
   {{0x6d4441d3,0x057000f2,0x00000000,0x00000000}},	//   zaha, پاید, --, --, 
   {{0x6d4441d4,0xd2440323,0x741401d9,0x77bc003e}},	//   yaha, ээни, _یوتا, _héxo, 
   {{0x6d440014,0x75d4038b,0xff20037e,0x00000000}},	//   xaha, _جيتا, _rayの, --, 
   {{0x7bc041d5,0x92c01c82,0x6d4441d6,0xfd60063f}},	//   _olmu, ্থে_, vaha, _wezụ, 
   {{0x6d4441d7,0x70e041d8,0x6fd001f9,0x068000fb}},	//   waha, _नशील, _सगळं, _ргән, 
   {{0x6810002b,0x80041422,0x00000000,0x00000000}},	// [41b0] _cādy, учре, --, --, 
   {{0x7bc041d9,0x6b8800b5,0x6d440798,0x7dc00b70}},	//   _almu, _saeg, uaha, _rösc, 
   {{0x6d4441da,0x6b8841db,0xc62404c5,0x2f28022e}},	//   raha, _paeg, _মিছা_, _tўg_, 
   {{0xd1b8044e,0x7dc041dc,0xa11400db,0x00000000}},	//   _ደምበ_, _pösc, _جوپت, --, 
   {{0x6b882f06,0x6d4441dd,0x7f9441de,0xff0400c0}},	//   _vaeg, paha, _саях, _бярн, 
   {{0x7bc041df,0x39481823,0xfa3441e0,0x6d4441e1}},	//   _elmu, ىشىپ_, ارند, qaha, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x68100055,0x00000000,0x00000000,0x00000000}},	//   _yādy, --, --, --, 
   {{0xba742088,0xdb240014,0xc61800e1,0x672841e2}},	//   _مالت, _شولی, नदेय_, rcej, 
   {{0x672800f3,0x48a80276,0xe6940022,0x00000000}},	//   scej, _нтем_, еиҩы, --, 
   {{0x69c041e3,0x00000000,0x00000000,0x00000000}},	//   _ille, --, --, --, 
   {{0x69c00165,0x290401d5,0x7dc00139,0x05900133}},	//   _hlle, _izla_, _mösa, _ڕابگ, 
   {{0xe56841e4,0xdebc00b7,0x7dc00267,0x256841e5}},	//   _жилд_, ሰቡን_, _lösa, _жалп_, 
   {{0xc0e41b49,0x00000000,0x00000000,0x00000000}},	//   _ሞራል_, --, --, --, 
   {{0x69c041e6,0x681000b8,0x00000000,0x00000000}},	//   _mlle, _sādy, --, --, 
   {{0x717000d1,0x681000cd,0xd004009b,0xc2241291}},	//   لۇۋا, _pādy, весе_, _مکسو, 
   {{0x69c041e7,0x4f2000db,0xbb3c01ec,0x1e840166}},	// [41c0] _olle, рдуб, _ﻓﺈﻨ_, ълам, 
   {{0x629401b2,0x5d1441e8,0x7dc00112,0xdb000254}},	//   _iryo, نباز, _bösa, rkoü, 
   {{0x60080063,0x00000000,0x00000000,0x00000000}},	//   _оном_, --, --, --, 
   {{0x62940306,0xacf40640,0x68100055,0x00000000}},	//   _kryo, учуј, _tādy, --, 
   {{0xa3e809ab,0x290400d7,0x00000000,0x00000000}},	//   _मदन_, _azla_, --, --, 
   {{0x3f800618,0x8a8401d9,0xd874072d,0x00000000}},	//   leiu_, کھہِ_, ناعب, --, 
   {{0x62940083,0x69c000a3,0x7dc0007c,0xa53c0092}},	//   _lryo, _dlle, _gösa, _የሠራዊ, 
   {{0x629441e9,0x77bc0077,0xd7b00490,0x7bc0003a}},	//   _oryo, _véxo, _जवळच, _ulmu, 
   {{0x35f401a9,0x00000000,0x00000000,0x00000000}},	//   лпир, --, --, --, 
   {{0x69c00142,0x3d20033f,0x00000000,0x00000000}},	//   _glle, _बलों_, --, --, 
   {{0x62940230,0x3a2441ea,0x3f80003e,0xe7940133}},	//   _aryo, _hump_, keiu_, _ڕاوک, 
   {{0xccf0025f,0x3a2405b1,0x15fc012d,0x00000000}},	//   יכת_, _kump_, _उठकर_, --, 
   {{0x645c0006,0x3f80026c,0x69c041eb,0x62942b75}},	//   ąsia, deiu_, _ylle, _cryo, 
   {{0x629441ec,0x72040597,0x988000d7,0xcb10011a}},	//   _dryo, اوسم, _míľa_, ילר_, 
   {{0x3a2441ed,0x62940a49,0x225c012d,0x78b800e5}},	//   _lump_, _eryo, ątka_, nyvv, 
   {{0x7dc005d5,0x316c0118,0x00000000,0x00000000}},	//   _rösa, řez_, --, --, 
   {{0xdcec00c0,0x1ad0000d,0x00000000,0x00000000}},	// [41d0] _kabė, _देलथ, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3a243371,0x3f800ffb,0xa514008f,0x2ec40166}},	//   _bump_, ceiu_, אַנג_, _йөзм, 
   {{0x8aa400a7,0x3a240356,0x69c0036e,0x161001f9}},	//   ържд, _cump_, _plle, डगार_, 
   {{0xd9400351,0x7dc00139,0xe464000d,0x579c0023}},	//   беши, _hösn, _ööga_, ግዛእቲ_, 
   {{0x2d8041ee,0x7c8441ef,0x69c00240,0x7864007b}},	//   mehe_, _куте, _vlle, لديك, 
   {{0x2d8041f0,0x29040789,0xd874216b,0x00000000}},	//   lehe_, _vzla_, اميت_, --, 
   {{0x69c000fb,0xa93411f7,0x8a400345,0x00000000}},	//   _tlle, _безш, _ئێتن, --, 
   {{0x7dc004f3,0x2d8041f1,0x2bb80073,0x00000000}},	//   _lösn, nehe_, _आवडा, --, 
   {{0xc86400c7,0x9f500248,0x00000000,0x00000000}},	//   _штаи, boyè_, --, --, 
   {{0x629441f2,0x1aa80154,0x00000000,0x00000000}},	//   _pryo, _খেয়া, --, --, 
   {{0x2d800924,0xb7bc00de,0x69b80210,0x00000000}},	//   kehe_, _kuģn, ्सपी, --, 
   {{0x2d8041f3,0x00000000,0x00000000,0x00000000}},	//   jehe_, --, --, --, 
   {{0x2d801423,0xa444036b,0x3f800356,0x00000000}},	//   dehe_, _ёнид, teiu_, --, 
   {{0x2d800270,0x629441f4,0xdca40116,0xd24c00f1}},	//   eehe_, _tryo, һази, _ځني_, 
   {{0xd24c41f5,0x62940223,0x3f800268,0xd378011a}},	// [41e0] _فني_, _uryo, reiu_, _טרקט, 
   {{0x3a2441f6,0xdca441f7,0x53180375,0x3f8019f5}},	//   _rump_, лази, _אופצ, seiu_, 
   {{0x3a2441f8,0x27e841f9,0xa068009d,0x00000000}},	//   _sump_, čanj_, _яана_, --, 
   {{0xeb5441fa,0x3a2441fb,0x6d400254,0x9074010f}},	//   لىمگ, _pump_, _õlan, _געטא_, 
   {{0x201000ca,0x2d8041fc,0x00000000,0x00000000}},	//   mmyi_, behe_, --, --, 
   {{0x3834117e,0x00000000,0x00000000,0x00000000}},	//   анкр, --, --, --, 
   {{0xb7c42097,0x4df800d9,0x00000000,0x00000000}},	//   ириқ, _נפלא, --, --, 
   {{0x4aa441fd,0x7dc0008e,0x00000000,0x00000000}},	//   ткән_, _xösn, --, --, 
   {{0xdcec0006,0x2bb80ce0,0xcfb4011a,0x00000000}},	//   _pabė, _आवता, טלקי_, --, 
   {{0xefd40b82,0x645c0153,0x9f500108,0xbb3c02dd}},	//   ረበዳ_, ąsin, llyä_, _ﻓﺈﻥ_, 
   {{0x8d58008f,0xcdf4010f,0x292400d0,0x00000000}},	//   עכטי, רמיי_, ápať_, --, 
   {{0x2d800526,0x3cdc00af,0x57e802e8,0xd3a441fe}},	//   zehe_, _गइने_, _ядем_, уроп, 
   {{0x2d800526,0x9f50005b,0x00000000,0x00000000}},	//   yehe_, ilyä_, --, --, 
   {{0xb7bc00de,0x9f5001f4,0x00000000,0x00000000}},	//   _kuģo, hlyä_, --, --, 
   {{0x860441ff,0xc05800d3,0xc9b40375,0x2d800165}},	//   _حقوق_, літ_, נהלת_, vehe_, 
   {{0x2d802bae,0x00000000,0x00000000,0x00000000}},	//   wehe_, --, --, --, 
   {{0xa3e805ba,0x2d804200,0x2dd44201,0x00000000}},	// [41f0] _मदत_, tehe_, ажар, --, 
   {{0x82344202,0xc0f802d3,0xad4000cf,0x00000000}},	//   _اريا, _ገጾም_, تۉسۉ, --, 
   {{0x2d804203,0xcd043252,0x7dc00139,0xac180108}},	//   rehe_, учаи, _tösn, вожу_, 
   {{0x2d804204,0x7dc005d5,0x27e80010,0x6adc00fe}},	//   sehe_, _hösl, čank_, _বৰগো, 
   {{0xa9684205,0x2d804206,0xc214013f,0x6a143f54}},	//   вила_, pehe_, _mpɔn_, амду, 
   {{0x9f5020ef,0xa85407fa,0x2fc80165,0xad840051}},	//   voyé_, атиј, lhag_, _tựđộ, 
   {{0x6d540bd7,0xdb0008a7,0x7dc00724,0x7c34014b}},	//   _idza, skoð, _mösl, _гесх, 
   {{0x2fc84207,0x7dc03b52,0x9f500129,0x6284012d}},	//   nhag_, _lösl, toyé_, ywko, 
   {{0x66e44208,0x2c50033f,0xfb3400a8,0x00000000}},	//   ропа, ląd_, _ынтэ, --, 
   {{0x2fc80007,0x645400d7,0x00000000,0x00000000}},	//   hhag_, ázio, --, --, 
   {{0xa3e82007,0x6d54090c,0x9d2000bd,0x2fc80589}},	//   _मदद_, _mdza, _পড়ুন_, khag_, 
   {{0xd6d40424,0x00000000,0x00000000,0x00000000}},	//   اویش_, --, --, --, 
   {{0xd24c4209,0x6d5402ce,0xe5a4033a,0x628409b6}},	//   ونَ_, _odza, _вили, uwko, 
   {{0x6d54420a,0x2c50033f,0x628404e6,0x205401ee}},	//   _ndza, kąd_, rwko, итбр, 
   {{0x26cc0561,0xe3c00e2d,0x9f5001f4,0x00000000}},	//   lzeo_, _akış_, ylyä_, --, 
   {{0x4424420b,0x6d540925,0x2fc8420c,0x7dc0420d}},	//   _iun_, _adza, ghag_, _pöso, 
   {{0x4424420e,0x03a4024c,0x2174030d,0x00000000}},	// [4200] _hun_, _виқо, _кунр, --, 
   {{0x4424420f,0x442016cb,0x5d184210,0x7dc020b2}},	//   _kun_, _hii_, نتاج_, _gösl, 
   {{0xa0a44211,0x44244212,0x2fc801c3,0x1b4801f0}},	//   _танд, _jun_, bhag_, взеи_, 
   {{0x44244213,0x6d544214,0x44201574,0x2fc801c3}},	//   _mun_, _edza, _jii_, chag_, 
   {{0x44204215,0x6d540175,0xf1a803e6,0x9524031c}},	//   _mii_, _fdza, _شایه_, _རྔའི_, 
   {{0x44244216,0x44204217,0x7e644218,0xfb7401b9}},	//   _oun_, _lii_, muip, _گپرگ, 
   {{0x44244219,0x442000d8,0x5f1826e4,0x00000000}},	//   _nun_, _oii_, _मृत्_, --, 
   {{0x4420421a,0x98bc0055,0xdcec00e2,0xd7f807a5}},	//   _nii_, _cetā_, _labī, ъул_, 
   {{0x4424421b,0x3ae8036b,0x77bc002e,0x7e6400b0}},	//   _aun_, _صبری_, _jéxi, nuip, 
   {{0x4424421c,0x77bc421d,0x442003c1,0x7c20421e}},	//   _bun_, _méxi, _aii_, _himr, 
   {{0x4424421f,0x2fc800c6,0x44204220,0x77bc4221}},	//   _cun_, yhag_, _bii_, _léxi, 
   {{0x44244222,0x44201574,0x07a04223,0x2fc80007}},	//   _dun_, _cii_, _махн, xhag_, 
   {{0x44204224,0x44244225,0x7c204226,0x7e640194}},	//   _dii_, _eun_, _mimr, juip, 
   {{0xd4980588,0x2fc8089c,0x44244227,0x7c204228}},	//   _ари_, whag_, _fun_, _limr, 
   {{0x44204229,0x44240876,0xa2740220,0xdcec005f}},	//   _fii_, _gun_, _құру_, _dabī, 
   {{0xa1280801,0x7c20422a,0x44201574,0x7e640270}},	//   _paзc, _nimr, _gii_, fuip, 
   {{0x4424422b,0xab281b74,0x7e64422c,0xeb98422d}},	// [4210] _zun_, қола_, guip, ғил_, 
   {{0x4424422e,0x4420422f,0x14c80490,0x7c204230}},	//   _yun_, _zii_, ानपण, _aimr, 
   {{0x44204231,0x44240050,0x26cc011c,0x09ac02f5}},	//   _yii_, _xun_, zzeo_, কসমা, 
   {{0x7c204232,0x2fc80369,0x8f080022,0xdcfc0306}},	//   _cimr, qhag_, _ахга_, cepč, 
   {{0x7c204233,0x7e640784,0xdb4c0014,0x98bc00ef}},	//   _dimr, cuip, رَو_, _retā_, 
   {{0x6d544234,0x09ac04c5,0x6db44235,0x7c2002d2}},	//   _udza, কসভা, _уйгу, _eimr, 
   {{0x6e2c0a4d,0x7c2000cc,0xed0401ed,0xf9900244}},	//   lqab, _fimr, _طورپ, ببن_, 
   {{0x44240c3e,0x7c2000ad,0x2d90045a,0xefd40092}},	//   _run_, _gimr, _haze_, ረበዉ_, 
   {{0x26cc05ce,0x2d901505,0x4420110e,0x6e2c4236}},	//   uzeo_, _kaze_, _rii_, nqab, 
   {{0x44244237,0x66e44238,0xf9d40262,0x7ae4007b}},	//   _pun_, _қола, _доуэ, úite, 
   {{0x2d900537,0x44204239,0x44240978,0x80dc0eac}},	//   _maze_, _pii_, _qun_, _মুন্, 
   {{0x4424423a,0xf770423b,0x44200083,0x852400b8}},	//   _vun_, _يان_, _qii_, _dārḍ, 
   {{0x442406e4,0x79a4084c,0xdcec00ef,0xdb00007c}},	//   _wun_, _урӂе, _pabī, skoö, 
   {{0xa068423c,0x77bc0f71,0x4424423d,0x2d90423e}},	//   лага_, _réxi, _tun_, _naze_, 
   {{0x4424423f,0xdee4001f,0x1f5401b9,0xbb2401ec}},	//   _uun_, ኛውን_, йтаё, _ﺼﻨﻑ_, 
   {{0x442003a0,0x7e64017a,0xa0a4322f,0x00000000}},	//   _uii_, tuip, _ғамд, --, 
   {{0x2d904240,0xe2984241,0xd00405c5,0x6e2c4242}},	// [4220] _baze_, _сап_, сете_, gqab, 
   {{0x2d90019f,0xdee4136b,0x7c202611,0x63b40076}},	//   _caze_, _ҳоми, _simr, _hoyn, 
   {{0x2d904243,0xa3bc4244,0x7e644245,0x63b44246}},	//   _daze_, _ेता_, suip, _koyn, 
   {{0xefd40020,0xd24c2814,0x6e2c01d9,0x3f8400d2}},	//   ረበው_, _تنی_, bqab, _úmu_, 
   {{0x7e644247,0xb7d80214,0x7c200055,0x645400d7}},	//   quip, یوتا_, _vimr, ázij, 
   {{0x63b40579,0xdca400d1,0x98bc0356,0x2d902517}},	//   _loyn, _лаги, _netă_, _gaze_, 
   {{0x7c204248,0x8d180014,0x63b4058a,0xfb8400f1}},	//   _timr, _مزٲر_, _ooyn, _ودری, 
   {{0x63b44249,0x2d900944,0x7ac40166,0x81c000eb}},	//   _noyn, _zaze_, _мөла, ূচি_, 
   {{0xcf900302,0x2d90424a,0x06d80154,0x24380092}},	//   לטה_, _yaze_, _ডুবি, _የሰፈነ, 
   {{0xf9c4424b,0x9484424c,0x00000000,0x00000000}},	//   _بحری, бымд, --, --, 
   {{0xc7ac05cc,0xfd6401f2,0x00000000,0x00000000}},	//   _её_, wurị, --, --, 
   {{0x63b4424d,0x629802b1,0x61fc0205,0x4e0c0118}},	//   _coyn, āton, _akpl, _तीनै_, 
   {{0x63b4158c,0x6e2c01d9,0x59bc424e,0xa3e80027}},	//   _doyn, xqab, ्सपर, _मदर_, 
   {{0x7dc0007c,0x5064014b,0x00000000,0x00000000}},	//   _dösk, йтба, --, --, 
   {{0x2d90424f,0x518401e0,0x4ea400fd,0xbfa801e0}},	//   _raze_, _һуна, әрба, әтсе_, 
   {{0x2d90209c,0x61fc4250,0x2d840034,0x63b40014}},	//   _saze_, _ekpl, _źle_, _goyn, 
   {{0x2d9005a1,0x518411f7,0x11e8038b,0xd24c0451}},	// [4230] _paze_, _луна, _معدي_, _ڪنڌ_, 
   {{0x6e2c0014,0x63b401d5,0x71780395,0x00000000}},	//   rqab, _zoyn, _тбор_, --, 
   {{0x82341e4b,0x3a380427,0xfc6402e8,0x63b4022e}},	//   _وریا, _črpa_, зъчн, _yoyn, 
   {{0x2d90136f,0xfd100597,0x7dc00267,0xff28022e}},	//   _waze_, رجل_, _lösh, _гўри_, 
   {{0x81bc4251,0x2d904252,0x6e2c4253,0x7c580075}},	//   _আগত_, _taze_, qqab, للەر_, 
   {{0xad8400cf,0xfaf00451,0xbca400db,0x00000000}},	//   _باحۇ, رثن_, تمۅي, --, 
   {{0xa7a807d6,0xd90c00dd,0xf990221c,0x00000000}},	//   икка_, ہیے_, عبه_, --, 
   {{0x2bd80244,0x00000000,0x00000000,0x00000000}},	//   _ئاسک_, --, --, --, 
   {{0x63b41125,0x00000000,0x00000000,0x00000000}},	//   _royn, --, --, --, 
   {{0x63b4022e,0x7dc008a5,0x00000000,0x00000000}},	//   _soyn, _rösk, --, --, 
   {{0x63b44254,0x63844255,0x79a422bf,0xa3e80120}},	//   _poyn, огна, _эрте, идоа_, 
   {{0xe2984256,0xf1a800d9,0x63b44257,0x00000000}},	//   аам_, _בס_, _qoyn, --, 
   {{0x87040228,0x63b40156,0xdee40092,0x69dc01e1}},	//   _ابال, _voyn, ኛውና_, _ìses, 
   {{0x38a000a8,0x27e805ce,0xe5a40440,0x76440166}},	//   _fără_, čanu_, _фики, _çiya, 
   {{0x1fb44258,0xe2800150,0xa11401e2,0x00000000}},	//   осар, _ﺩﻴﻬﻡ_, زورت, --, 
   {{0x0fb0068f,0x7dc04259,0x8fa0425a,0xa06801d5}},	//   ीसगढ, _tösk, масе, лаҳа_, 
   {{0x7dc0007c,0x00000000,0x00000000,0x00000000}},	// [4240] _hösi, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x0d20425b,0xdef8425c,0x00000000,0x00000000}},	//   дүрү, уың_, --, --, 
   {{0x772404c5,0xcb640953,0x7dc00139,0x00000000}},	//   _যজ্ঞ_, жаце_, _mösi, --, 
   {{0xf38c00c8,0x1988036b,0x98bc0064,0xcee001ec}},	//   טראָ, ибди_, _metą_, _жұтқ, 
   {{0x3e74425d,0x9f500589,0x8e040276,0x00000000}},	//   mät_, boyã_, _мняв_, --, 
   {{0x3e74425e,0x00000000,0x00000000,0x00000000}},	//   lät_, --, --, --, 
   {{0xb7bc00e2,0xdb4c03e6,0x7b8400cf,0xcb64425f}},	//   _kuģi, _شێت_, _عازە, _масе_, 
   {{0x3e744260,0x99e44261,0xeb540150,0x00000000}},	//   nät_, _джад, _رىلگ, --, 
   {{0x6a8401d9,0x7ac40bd6,0x3e7401f4,0x00000000}},	//   _عشقٕ, _мөһа, iät_, --, 
   {{0x3e74005b,0x97c4007b,0x69b80b6d,0x00000000}},	//   hät_, _وتصم, ्सरी, --, 
   {{0x3e744262,0x47c04263,0x394c01bf,0x00000000}},	//   kät_, _обхв, _heds_, --, 
   {{0x3e74049b,0x77bc4264,0x96940395,0x8c1800d9}},	//   jät_, _déxt, _фреш, יוטי, 
   {{0x7dc029ef,0x3e744265,0xd5ac01d9,0x00000000}},	//   _fösi, dät_, _شہج_, --, 
   {{0x394c1948,0x44f00798,0x00000000,0x00000000}},	//   _meds_, _опшс, --, --, 
   {{0x394c4266,0x64441368,0x942000f7,0x3e74008e}},	//   _leds_, _çhia, _توعۇ, fät_, 
   {{0x394c002d,0x7ed401d9,0xdfd000ec,0x3e74013d}},	// [4250] _oeds_, ٘زلا, ريٰ_, gät_, 
   {{0x71400e26,0x7dc001f4,0x4cbc00cc,0x00000000}},	//   _سۉرۅ, _yösi, _এইবু, --, 
   {{0x0ca84267,0xdcfc02b5,0x9f500248,0x00000000}},	//   штаи_, tepā, boyà_, --, 
   {{0x60f80302,0x3e7400fd,0x00000000,0x00000000}},	//   _להתק, bät_, --, --, 
   {{0xa9a4036b,0xd15c02d3,0xfbdc02ab,0x394c0c18}},	//   зилд, _ንምትግ, _मगरम, _beds_, 
   {{0x394c0793,0xdcfc03a0,0x7a3000d8,0xdeb80375}},	//   _ceds_, sepā, _sótã, _המשל, 
   {{0x27440020,0xa82408dc,0x225c033f,0x417c0a7c}},	//   _የቀረበ, سکان, ątki_, ינגב, 
   {{0x394c00d2,0x7b0805f7,0x3328022e,0x7dc0002f}},	//   _eeds_, ðstæ, _ngax_, _bösw, 
   {{0xeb9818ce,0xc7a006dc,0x394c045a,0xca703c5a}},	//   _киң_, зиқк, _feds_, _زناک, 
   {{0x394c01ab,0x7dc04268,0xd83c0010,0x98bc0064}},	//   _geds_, _pösi, ščan_, _setą_, 
   {{0x23284269,0x64a4426a,0xe19401c6,0x764403e3}},	//   йони_, чана, үргэ, _çiyn, 
   {{0x2b4c004e,0x27e8426b,0x3e7400fd,0x00000000}},	//   _jeec_, _ñan_, yät_, --, 
   {{0x29040005,0xaabc0b02,0xa5f8426c,0xdebc01f3}},	//   _hyla_, ्निक, _леду_, ደቡን_, 
   {{0x3e74426d,0x2904426e,0x3cdc007d,0xc8ac0490}},	//   vät_, _kyla_, _गइले_, _झपाट, 
   {{0x5500068f,0x77bc1709,0x2b4c0327,0x10a00d1d}},	//   _रुपए_, _téxt, _oeec_, нирн, 
   {{0x3e74426f,0x29044270,0xaabc1223,0xe3b00066}},	//   tät_, _myla_, ्नाक, _سرب_, 
   {{0x4ad80d01,0x8e803947,0xf8a808a3,0x92f00117}},	// [4260] _मेलव, нгте, _कप्प, _зӯрх, 
   {{0x3e744271,0x5f741272,0x7dc001e3,0x29040790}},	//   rät_, _کادر, _lösv, _oyla_, 
   {{0x3e7436be,0xdcfc0276,0x91b80375,0x2b4c058a}},	//   sät_, depă, _המיי, _beec_, 
   {{0x3e744272,0xcb0400b2,0xd7d80037,0x00000000}},	//   pät_, ڻيون_, _बगइच, --, 
   {{0x20004273,0x7f444274,0x00000000,0x00000000}},	//   _ikki_, mbiq, --, --, 
   {{0x2904038e,0x2c7400b5,0x7e6402d1,0x4ad80073}},	//   _byla_, båd_, mrip, _मेळव, 
   {{0x2b4c00cf,0xef280790,0x7e64002f,0x00000000}},	//   _feec_, şüş_, lrip, --, 
   {{0x394c4275,0x7f44047e,0x7e64054e,0x29040064}},	//   _weds_, nbiq, orip, _dyla_, 
   {{0x5ac84276,0x7e644277,0x66704278,0x00000000}},	//   _улам_, nrip, نگور, --, 
   {{0xddd4068f,0xdcfc0311,0x136800d1,0x7e644279}},	//   jwyż, cepă, әшни_, irip, 
   {{0x29040048,0x79980af2,0x49380375,0x41b000dc}},	//   _gyla_, mdvw, _הגבו, ञानस, 
   {{0x7e64427a,0x7f440455,0x6d40000d,0x00000000}},	//   krip, jbiq, _õlav, --, 
   {{0xd7080262,0x64440363,0xe7a8012a,0x7f44427b}},	//   _унде_, _çhin, कारप, dbiq, 
   {{0x7dc001b8,0x2000427c,0x7998192e,0x7f44003a}},	//   _kösu, _akki_, ndvw, ebiq, 
   {{0x3cdc05ba,0xf8cc000d,0x53e401af,0x00000000}},	//   _गेले_, ़निय, _нциа, --, 
   {{0x7e6401e4,0x9324007b,0x00000000,0x00000000}},	//   frip, _عربن, --, --, 
   {{0x7dc00639,0x7e64427d,0xa3c80ce0,0xcd282674}},	// [4270] _lösu, grip, लघर_, مسان_, 
   {{0x2000427e,0x2b4c0005,0xaabc00bc,0x00000000}},	//   _ekki_, _seec_, ्नसक, --, 
   {{0x7e64427f,0x2b4c00e2,0x301400f3,0x7dc002d2}},	//   arip, _peec_, _одор, _nösu, 
   {{0x6da81682,0x7e644280,0xb7bc0171,0x290400c0}},	//   _ḓadz, brip, _kuģu, _ryla_, 
   {{0x2c740158,0x29044281,0x00000000,0x00000000}},	//   såd_, _syla_, --, --, 
   {{0x6e3c0857,0x49901e7c,0x00000000,0x00000000}},	//   _itsb, عیار, --, --, 
   {{0x6d444282,0xfc640801,0x013800d9,0x8c404283}},	//   mbha, _пътн, הרות_, ışsa, 
   {{0x78640058,0x6d440876,0x00000000,0x00000000}},	//   ردىك, lbha, --, --, 
   {{0xb9044284,0x6d44379c,0x98bc38a5,0x629804fe}},	//   _पे_, obha, _metę_, ātok, 
   {{0x6d444285,0xe4584286,0x29040153,0x12e400cc}},	//   nbha, ожо_, _tyla_, _নৰ্দ, 
   {{0x6d444287,0x98680150,0x29041ea0,0x00000000}},	//   ibha, _ولكە_, _uyla_, --, 
   {{0xf7701060,0x7dc004f3,0x6d440013,0x6d2c031c}},	//   _ماه_, _höst, hbha, _ཧུའེ_, 
   {{0x27ec4288,0x6d4400d2,0x7dc04289,0xbec800e2}},	//   mnen_, kbha, _köst, _krūš, 
   {{0x27ec428a,0xfe7805f5,0x644400ad,0xe0d001d9}},	//   lnen_, үүн_, _çhio, پٲر_, 
   {{0x27ec428b,0x6d44428c,0x7f4400ac,0x6e3c428d}},	//   onen_, dbha, tbiq, _atsb, 
   {{0x27ec428e,0x6d44428f,0x7dc04290,0x7e644291}},	//   nnen_, ebha, _löst, trip, 
   {{0x27ec4292,0x64404293,0x22144294,0xd12c066d}},	// [4280] inen_, lpli, _офор, امہ_, 
   {{0x27ec4295,0x3f4c07ae,0x7e644296,0xdb080066}},	//   hnen_, ếu_, rrip, _ènér, 
   {{0x64404297,0x7e644298,0x225c0034,0x27ec00f2}},	//   npli, srip, ątku_, knen_, 
   {{0x27ec0936,0x6d441552,0xfe7801c6,0x644001ab}},	//   jnen_, abha, _нүб_, ipli, 
   {{0x27ec1196,0x61ec017a,0xaf8401e0,0x6d444299}},	//   dnen_, onbl, _яҡта_, bbha, 
   {{0x27ec429a,0x389c01e4,0x6d4400a3,0x00000000}},	//   enen_, _pĉr_, cbha, --, 
   {{0x39401a4c,0x27ec0730,0x6440429b,0xe7a80073}},	//   ĝis_, fnen_, jpli, कांप, 
   {{0x3940008f,0x48cc015b,0x59bc012c,0x61ec2305}},	//   ŝis_, িপূর, ्सहर, hnbl, 
   {{0x7dc0008c,0x6440429c,0x00000000,0x00000000}},	//   _föst, epli, --, --, 
   {{0x7dc02799,0x27ec429d,0xa2a00316,0x756401ed}},	//   _göst, anen_, खिन्, ریعہ_, 
   {{0xf484429e,0x6444062c,0x27ec03cd,0xa8180014}},	//   رادی, _çhil, bnen_, _کتٕر_, 
   {{0x7dc0429f,0x00000000,0x00000000,0x00000000}},	//   _köss, --, --, --, 
   {{0x6440000d,0xd5b842a0,0x932403e6,0x80dc0011}},	//   apli, _мск_, بردن, _মুল্, 
   {{0x7dc03167,0x1df83174,0x61ec01ef,0xdbd80166}},	//   _möss, ्तोष_, gnbl, lçäs, 
   {{0x7dc001e3,0x00000000,0x00000000,0x00000000}},	//   _löss, --, --, --, 
   {{0x3f64039b,0xc32402f5,0xa8040077,0x61ec002d}},	//   ктуб, পড়ি_, miñá, anbl, 
   {{0x7dc00108,0x6d4442a1,0xda0c01f9,0x00000000}},	// [4290] _nöss, tbha, ितात_, --, 
   {{0x6d4442a2,0xed5042a3,0x3df4036b,0xbe180212}},	//   ubha, اپا_, взус, джує_, 
   {{0x7dc042a4,0x27ec42a5,0x6d4442a6,0xa3c40146}},	//   _röst, ynen_, rbha, _एवम_, 
   {{0x5c040075,0x7dc042a7,0x6d4442a8,0x00000000}},	//   ىكلە, _böss, sbha, --, 
   {{0x27ec0ff7,0x7dc042a9,0xbec80171,0x00000000}},	//   vnen_, _pöst, _prūš, --, 
   {{0x2fc8010a,0x644042aa,0x7dc006be,0x00000000}},	//   lkag_, ypli, _qöst, --, 
   {{0x644042ab,0x27ec03d4,0x00000000,0x00000000}},	//   xpli, tnen_, --, --, 
   {{0x27ec092e,0x644042ac,0x6b980369,0x675442ad}},	//   unen_, vpli, qdwg, رخبر, 
   {{0x27ec42ae,0x2fc8089c,0x6d400254,0x7dc000fd}},	//   rnen_, ikag_, _õlas, _töst, 
   {{0x644042af,0xa8040005,0x27ec01c6,0xa4440117}},	//   tpli, fiñá, snen_, ннод, 
   {{0x644042b0,0x27ec01e3,0x00000000,0x00000000}},	//   upli, pnen_, --, --, 
   {{0x64400d27,0x61ec0042,0x6444062c,0x7dc0005b}},	//   rpli, wnbl, _çhim, _yöss, 
   {{0x64404240,0x10a000d1,0x9754011a,0x00000000}},	//   spli, қитн, _ניסו_, --, 
   {{0x644042b1,0x2fc80076,0x645401d3,0x0b3c0092}},	//   ppli, ekag_, ázis, _ይጠቀማ, 
   {{0x308402d3,0xdfd00451,0x00000000,0x00000000}},	//   _ምውጻእ_, هيس_, --, --, 
   {{0x61f40006,0x2fc8020c,0x660042b2,0x00000000}},	//   _šalč, gkag_, lolk, --, 
   {{0xd00c00c6,0x98bc01ef,0x00000000,0x00000000}},	// [42a0] صلك_, _betě_, --, --, 
   {{0x629401b9,0x660002fb,0x75240166,0x00000000}},	//   _isyo, nolk, _ğizz, --, 
   {{0x9cf4074d,0x0b3c0092,0x7dc00108,0xe10800f5}},	//   хчаш, _ይጠቁማ, _söss, _хенд_, 
   {{0xf8b01c93,0x660042b3,0x62940585,0x2fc80076}},	//   یکا_, holk, _ksyo, ckag_, 
   {{0x660042b4,0xdde842b5,0x4fa00131,0xf8a816d1}},	//   kolk, _فرسه_, _сияв, कम्प, 
   {{0xd1cc0020,0x3ea042b6,0x6600003e,0x2eec032e}},	//   _ጥቂት_, mvit_, jolk, _þefa_, 
   {{0x3ea042b7,0x7dc00036,0xd5b80022,0x660042b8}},	//   lvit_, _wöss, ҧсо_, dolk, 
   {{0x3f800268,0x6d400254,0x7dc0070a,0xfe1400bc}},	//   nfiu_, _õlar, _töss, _तीतस_, 
   {{0x629407ab,0x97b400fd,0x36d42218,0xe7f4033f}},	//   _nsyo, _үсеш, топр, आवजा_, 
   {{0x6600003e,0x3ea042b9,0x00000000,0x00000000}},	//   golk, ivit_, --, --, 
   {{0x629442ba,0x3ea00cb9,0x574400d4,0x00000000}},	//   _asyo, hvit_, _знеб, --, 
   {{0xa804056a,0x3ea042bb,0x4394117e,0x00000000}},	//   riñá, kvit_, гаюс, --, 
   {{0x66000a81,0x51840a13,0xf4840101,0x00000000}},	//   bolk, нува, راگی, --, 
   {{0x3ea03619,0x320405da,0x6600003e,0xcb10123b}},	//   dvit_, ôly_, colk, טלר_, 
   {{0x3f8042bc,0x3ea016b8,0x0b3c001f,0x349400d4}},	//   ffiu_, evit_, _ይጠቅማ, _райр, 
   {{0xc9140375,0x3ea0007c,0x7f940022,0x00000000}},	//   תחלת_, fvit_, ласх, --, 
   {{0x3ef800a8,0x7dc0002f,0x3ea00413,0x8e74007b}},	// [42b0] ентэ_, _rösr, gvit_, عارض, 
   {{0x2fc8003b,0x81d40408,0x00000000,0x00000000}},	//   skag_, _боьх, --, --, 
   {{0x3ea042bd,0x00000000,0x00000000,0x00000000}},	//   avit_, --, --, --, 
   {{0x0fe000cf,0x4ee40064,0x00000000,0x00000000}},	//   _сөгү, _зігз, --, --, 
   {{0xa4a401e1,0xada400c7,0x41c800bc,0x6abc08df}},	//   _asọ̀, _ҧаҭл, _रकमस, ्नेर, 
   {{0x87500092,0x00000000,0x00000000,0x00000000}},	//   _መቀላቀ, --, --, --, 
   {{0x66000e29,0xed041e4a,0x48cc015b,0xd9400395}},	//   volk, _شورپ, িপ্র, шещи, 
   {{0xa6840364,0x660042be,0x14380092,0x00000000}},	//   влид, wolk, _አሰራሩ, --, 
   {{0xe6182a20,0x468006b3,0x64c401e2,0x69b80210}},	//   мди_, уқла, ږيدل, _एचपी, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3ea00427,0xa774009b,0x00000000,0x00000000}},	//   zvit_, _алеч, --, --, 
   {{0x660042bf,0xf86800ec,0x224403e0,0x00000000}},	//   solk, _سمهي_, _çokk_, --, 
   {{0x76c442c0,0x660042c1,0x00000000,0x00000000}},	//   _مغول, polk, --, --, 
   {{0x66000014,0x00000000,0x00000000,0x00000000}},	//   qolk, --, --, --, 
   {{0xdd9042c2,0x00000000,0x00000000,0x00000000}},	//   یور_, --, --, --, 
   {{0x3f800421,0xdfd03a16,0x54500116,0x00000000}},	//   ufiu_, جير_, _өвәт, --, 
   {{0x62940280,0x2a7c0218,0x3ea042c3,0x25f400e1}},	// [42c0] _usyo, jtwb_, uvit_, एचपी_, 
   {{0xdca4006c,0x00000000,0x00000000,0x00000000}},	//   кази, --, --, --, 
   {{0x3ea042c4,0xa038007b,0x00000000,0x00000000}},	//   svit_, _تأخر_, --, --, 
   {{0x9c80151c,0x98b003e6,0x5b2402e9,0x00000000}},	//   ščob, یڤاڵ, نفال, --, 
   {{0xdab842c5,0x00000000,0x00000000,0x00000000}},	//   بهشت_, --, --, --, 
   {{0x6d400254,0x3fc801d3,0x497000d4,0x764403e3}},	//   _õlap, _آدھی_, иліс, _çiyi, 
   {{0x38c8141d,0x1d080114,0x29241884,0x00000000}},	//   عاتی_, _цеви_, ﻠﻪﭖ_, --, 
   {{0x76743cc5,0x00000000,0x00000000,0x00000000}},	//   глиф, --, --, --, 
   {{0x4b7800c8,0x73c40184,0x7bc004ba,0x00000000}},	//   _קאמו, ғәйе, _iomu, --, 
   {{0x75d442c6,0x35b40a93,0xab28007b,0x00000000}},	//   ايدا, убор, _أسفل_, --, 
   {{0x81e804c5,0xd6d800b2,0x98340153,0x00000000}},	//   যকা_, _ڪوشش_, _рэзі, --, 
   {{0x7bc042c7,0x00000000,0x00000000,0x00000000}},	//   _jomu, --, --, --, 
   {{0x7bc042c8,0xc2b80212,0x7ae400ae,0x628801e1}},	//   _momu, вляє_, úith, _ìló, 
   {{0x7bc042c9,0x8af400ac,0x00000000,0x00000000}},	//   _lomu, _şəkl, --, --, 
   {{0xc0bc2295,0xcf9803b7,0xa2c03531,0x3a2c0051}},	//   _ደግሞ_, мја_, _һәрк, _midp_, 
   {{0x7bc042ca,0x938842cb,0x6e9400d1,0xca740092}},	//   _nomu, _цска_, либу, _የግእዝ_, 
   {{0xfbdc0037,0x91480902,0x00000000,0x00000000}},	// [42d0] _मगजम, _очна_, --, --, 
   {{0xab5c006d,0x8678011a,0x00000000,0x00000000}},	//   _może, ורמו, --, --, 
   {{0x69b807f7,0x4ad80073,0x80c400cd,0xfe24009d}},	//   _एचबी, _मेजव, रहणे, рьтн, 
   {{0x8af400ac,0x6f8000db,0xb9a400e5,0x00000000}},	//   _çəkm, _دۇرۅ, یمنٹ, --, 
   {{0x7bc00483,0x6a8442cc,0x602c0115,0xab5c012d}},	//   _domu, улла, _iŝma, _noże, 
   {{0x98bc0205,0x00000000,0x00000000,0x00000000}},	//   _actı_, --, --, --, 
   {{0xe73842cd,0x7bc042ce,0x6d5442cf,0xec6803e6}},	//   ней_, _fomu, _ieza, _سڵاو_, 
   {{0x7bc042d0,0x6d540109,0xab5c033f,0x99940116}},	//   _gomu, _heza, _boże, вкәт_, 
   {{0x6d5442d1,0x00000000,0x00000000,0x00000000}},	//   _keza, --, --, --, 
   {{0x7bc042d2,0x6d5442d3,0x80d40011,0xc98400f3}},	//   _zomu, _jeza, _সশস্, _шуби, 
   {{0x6d5442d4,0xa3e823b3,0x7bc042d5,0x69c00857}},	//   _meza, една_, _yomu, _iole, 
   {{0x64a40831,0x69c042d6,0xf8b00137,0x7bc001a9}},	//   _ҡала, _hole, _بةك_, _xomu, 
   {{0x5b78010f,0x1b78010f,0x00000000,0x00000000}},	//   ערשא, עטשע, --, --, 
   {{0x6d5442d7,0x69c042d8,0x24a40014,0x213c0e89}},	//   _neza, _jole, _مٕتِ, ùth_, 
   {{0x69c042d9,0x4ad81cc3,0x00000000,0x00000000}},	//   _mole, _मेघव, --, --, 
   {{0x69c042da,0x6d5405c7,0xa3b80244,0xd004008e}},	//   _lole, _aeza, _سابر_, гесе_, 
   {{0x6d5442db,0x80dc2158,0x7bc042dc,0x69c042dd}},	// [42e0] _beza, _মুখ্, _romu, _oole, 
   {{0x7bc042de,0x6d5442df,0x4f040372,0xd83c09a8}},	//   _somu, _ceza, унун_, ščin_, 
   {{0x6d5442e0,0x7bc042e1,0xd08c06be,0x00000000}},	//   _deza, _pomu, kıət, --, 
   {{0x9f0442e2,0xc0cc044e,0xd5e001f2,0xd9bc42e3}},	//   _موجو, በኣር_, _kpọ, ्स्ट, 
   {{0x6d5442e4,0x7bc005b8,0x5e5400cf,0x00000000}},	//   _feza, _vomu, _حئجر, --, 
   {{0x6d5442e5,0x7bc042e6,0xc4d00210,0x00000000}},	//   _geza, _womu, दनाओ, --, 
   {{0x69c042e7,0x2d942be9,0x69c40254,0x00000000}},	//   _dole, _тряс, öhea, --, 
   {{0x69c002d0,0xab5c033f,0x85880150,0x39a400e5}},	//   _eole, _poże, _ﺒﺤﺭﺍ_, désű_, 
   {{0x69c00bed,0x6d5442e8,0xd9442472,0xa3c807f7}},	//   _fole, _yeza, _бези, ोसन_, 
   {{0x69c042e9,0x4a580a7c,0x6d5406be,0x00000000}},	//   _gole, _נדבו, _xeza, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69c042ea,0x00000000,0x00000000,0x00000000}},	//   _zole, --, --, --, 
   {{0x69c042eb,0x00000000,0x00000000,0x00000000}},	//   _yole, --, --, --, 
   {{0x69c007a9,0x86980302,0x00000000,0x00000000}},	//   _xole, _ניוז, --, --, 
   {{0xd01842ec,0x04c442ed,0x00000000,0x00000000}},	//   ефа_, _مووي_, --, --, 
   {{0x6d5442ee,0x629842ef,0x9f50033b,0x937800ae}},	//   _seza, ātor, nnyè_, _أصغر_, 
   {{0x6d5442f0,0x2e24007b,0x00000000,0x00000000}},	// [42f0] _peza, لفرف, --, --, 
   {{0x78a842f1,0x6d5442f2,0x00000000,0x00000000}},	//   _ordv, _qeza, --, --, 
   {{0x6d5442f3,0x628c07f5,0xac942077,0x4c5442f4}},	//   _veza, čnoš, раеш, اضطر, 
   {{0xcc0842f5,0x6d5442f6,0xdd940124,0x00000000}},	//   رزان_, _weza, лаӡы, --, 
   {{0x78a842f7,0x81e8015b,0x64440076,0x39a401d3}},	//   _ardv, যকর_, _çhiv, zésű_, 
   {{0x684442f8,0xa9a40982,0xa8c401c6,0x00000000}},	//   анка, рикд, ийлд, --, 
   {{0x69c042f9,0xb8640592,0x7988035a,0x27600092}},	//   _vole, مايو, _dbdw, _ለቀረበ, 
   {{0x69c042fa,0x574402e8,0xac180114,0xe7a8020f}},	//   _wole, азъм_, _робу_, твил_, 
   {{0x6b8800ca,0x78a80006,0x2c400064,0x00000000}},	//   _ibeg, _erdv, _dėde_, --, 
   {{0x69c042fb,0x6aa842fc,0x958042fd,0x39a401d3}},	//   _uole, _iref, олье, tésű_, 
   {{0x67d40a15,0x6aa842fe,0x00000000,0x00000000}},	//   _кожу, _href, --, --, 
   {{0x6aa842ff,0x6b880327,0x00000000,0x00000000}},	//   _kref, _jbeg, --, --, 
   {{0x6b884300,0x00000000,0x00000000,0x00000000}},	//   _mbeg, --, --, --, 
   {{0xe0444301,0x6aa805d9,0xa0684077,0xf65004d3}},	//   инги, _mref, кага_, _رئه_, 
   {{0x6b884302,0x90c04303,0x1f5401b9,0x00000000}},	//   _obeg, обре, итаё, --, 
   {{0x6aa84304,0x387801bf,0x00000000,0x00000000}},	//   _oref, _årre_, --, --, 
   {{0x5de4009d,0x00000000,0x00000000,0x00000000}},	// [4300] ажаа, --, --, --, 
   {{0x6b884305,0x27e80308,0xa0740166,0x2d98004e}},	//   _abeg, čany_, _кымш, лөсө_, 
   {{0x6aa84306,0x601800e4,0x00000000,0x00000000}},	//   _aref, rïmb, --, --, 
   {{0x5ac8052f,0x6aa829ef,0x28a80037,0xec6801c8}},	//   клем_, _bref, किनि, اصلو_, 
   {{0x6aa84307,0x2b480789,0xdcec00d0,0x1a640345}},	//   _cref, ñaca_, _jabĺ, شیای_, 
   {{0x6b882784,0x20b84308,0x6aa800a9,0xceb00302}},	//   _ebeg, _उपाध, _dref, _ויש_, 
   {{0xa3c44309,0x02b4038e,0x6aa8127b,0xd7f80117}},	//   _एवं_, ुहुन, _eref, куи_, 
   {{0x6b88145e,0x4c980375,0x6aa8010a,0x57a4430a}},	//   _gbeg, _בבלו, _fref, ршка, 
   {{0x6aa8430b,0x19940640,0x1ae400a8,0x798802d0}},	//   _gref, _вјер, _тоам, _tbdw, 
   {{0x14c800c9,0x6b88430c,0xd1c80023,0xd4440092}},	//   выми_, _zbeg, በታት_, _የተፈቀ, 
   {{0xd944014b,0x00000000,0x00000000,0x00000000}},	//   _беҷи, --, --, --, 
   {{0xc7c40b32,0x395c014a,0x75d411e6,0x926801b9}},	//   _выше_, lavs_, _گيتا, крга_, 
   {{0x92680801,0x59d8000d,0x00000000,0x00000000}},	//   ърна_, _भतार, --, --, 
   {{0xab5c025c,0x395c00b5,0x34940166,0x5064430d}},	//   _moża, navs_, _гакр, итба, 
   {{0xd1740220,0x4ee00011,0x00000000,0x00000000}},	//   лыңы, _মডেল, --, --, 
   {{0x430801f2,0x31c001d9,0x9f8c00a2,0xb35401d5}},	//   ọpị_, _کۅسہ, _nýä_, _укиш, 
   {{0x5184430e,0x683400c0,0x7414430f,0xddd40210}},	// [4310] _куна, _išde, _پوکا, dsył, 
   {{0xcd284310,0x270407ae,0x6aa84311,0x6b884312}},	//   نسان_, ồng_, _rref, _sbeg, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa1140150,0x4ea40139,0x00000000,0x00000000}},	//   _دوپت, _крга, --, --, 
   {{0xe0e80ba1,0xc33402e4,0xaa880244,0x8e540408}},	//   _tròç_, קוס_, انتم_, _тĕлл, 
   {{0xc9840d09,0xab5c031c,0x0dc84313,0x9f8c00a2}},	//   руди, _doża, _руми_, _eýä_, 
   {{0x6b88031c,0x7c940efe,0x00000000,0x00000000}},	//   _tbeg, _وشفا, --, --, 
   {{0x6aa84314,0x6b880450,0x6eac0034,0x25a81432}},	//   _tref, _ubeg, ीमपु, _şal_, 
   {{0x6aa84315,0xbb480014,0x66e44316,0xba74007b}},	//   _uref, _خلقن_, сопа, _واكت, 
   {{0x395c4317,0x00000000,0x00000000,0x00000000}},	//   cavs_, --, --, --, 
   {{0x24e84318,0x02d00316,0x00000000,0x00000000}},	//   умни_, हन्न, --, --, 
   {{0x48c00022,0x37c400ec,0x2b5c0042,0x00000000}},	//   _гәҩа, _ويلف, nawc_, --, 
   {{0xf7704319,0x870400c9,0x00000000,0x00000000}},	//   _زان_, _тяже, --, --, 
   {{0xf650431a,0x00000000,0x00000000,0x00000000}},	//   _آئن_, --, --, --, 
   {{0x27ec0196,0x87d805f9,0xc60004af,0x00000000}},	//   oien_, _बताऊ, रकीय_, --, 
   {{0x5438008f,0xa06800c7,0xdee401a9,0x00000000}},	//   _געקא, каҳа_, боби, --, 
   {{0x4420431b,0x00000000,0x00000000,0x00000000}},	// [4320] _ihi_, --, --, --, 
   {{0x27ec431c,0x44200161,0x6444062c,0xeef402d5}},	//   hien_, _hhi_, _çhis, іятэ, 
   {{0x4420431d,0x27ec431e,0x7dc0066d,0x61ec431f}},	//   _khi_, kien_, _kösz, mibl, 
   {{0x27ec4320,0x61ec4321,0xab5c0034,0xda644322}},	//   jien_, libl, _poża, ماتي, 
   {{0x27ec4323,0x44204324,0x395c005f,0xef9001b9}},	//   dien_, _mhi_, tavs_, _زیلد, 
   {{0x61ec4325,0x27ec0cf9,0x44204326,0x1d08094e}},	//   nibl, eien_, _lhi_, _беги_, 
   {{0x44204327,0xa3c84328,0x395c1e0b,0x00000000}},	//   _ohi_, ोसा_, ravs_, --, 
   {{0x27ec4329,0x4420432a,0x5bf40050,0x61ec432b}},	//   gien_, _nhi_, _آرا, hibl, 
   {{0x95c8432c,0x61ec432d,0x92c000cc,0x60cc0419}},	//   гуна_, kibl, _এই্_, hybm, 
   {{0x4420432e,0x27ec432f,0x61ec4330,0xceb00375}},	//   _ahi_, aien_, jibl, פית_, 
   {{0x18341060,0xab5c006d,0x61ec4331,0x44200013}},	//   _طراح, _możn, dibl, _bhi_, 
   {{0x27ec4332,0x61ec01ab,0xd8240022,0x00000000}},	//   cien_, eibl, _удеи, --, 
   {{0x44204333,0x98bc00b0,0x8c18011a,0x00000000}},	//   _dhi_, _tetē_, טוטי, --, 
   {{0x61ec4334,0x44204335,0x86780bd4,0x41e40953}},	//   gibl, _ehi_, _תרגו, піса, 
   {{0x10144336,0x44204337,0xb7ec00dc,0x712400d1}},	//   مبرد, _fhi_, _जगाम_, زىرم, 
   {{0x44204338,0x61ec017a,0x9cb80327,0x00000000}},	//   _ghi_, aibl, བྱབས, --, 
   {{0xa3cc0574,0xab5c025c,0xbd24025c,0xeeb806b3}},	// [4330] _शकत_, _bożn, _འཛུཊ_, шлаш_, 
   {{0x27ec4339,0x7174034c,0x47180a1e,0x82d801ec}},	//   zien_, _بهدا, רומג, _ыдыс_, 
   {{0x2bdc433a,0x27ec433b,0x69c402f6,0x2c400024}},	//   _मतदा, yien_, öhem, _bėda_, 
   {{0x27ec433c,0x8d14016c,0x2d080490,0x44200200}},	//   xien_, анҷӣ_, _वडील_, _xhi_, 
   {{0x27ec433d,0x4ea40598,0xfc303fe2,0x2b5c0165}},	//   vien_, _урна, رحم_, rawc_, 
   {{0x27ec433e,0x00000000,0x00000000,0x00000000}},	//   wien_, --, --, --, 
   {{0x27ec433f,0xf9a801e1,0xc98400c7,0x798400ae}},	//   tien_, _ilè̟_, _ҳуеи, سؤول, 
   {{0xe7380124,0x3c4405f5,0x27ec0165,0x2c400153}},	//   шеи_, _хэрв, uien_, _gėda_, 
   {{0x27ec4340,0x61ec0213,0x44200142,0x7dc000e5}},	//   rien_, yibl, _rhi_, _rösz, 
   {{0x44204341,0x27ec4342,0x26cc2244,0xfbe40241}},	//   _shi_, sien_, ryeo_, _àárè_, 
   {{0x44204343,0x27ec4344,0x61ec4345,0x00000000}},	//   _phi_, pien_, vibl, --, 
   {{0x23284346,0x44200218,0xd708063f,0x61ec0477}},	//   иони_, _qhi_, ịrịr, wibl, 
   {{0xab5c031c,0x44204347,0xffa4009d,0x66580354}},	//   _lożo, _vhi_, үлгү, _талă, 
   {{0x64c401e2,0x3f78002b,0x00000000,0x00000000}},	//   _ويشل, _ḍu_, --, --, 
   {{0x44204348,0x9fc805f5,0x10a04349,0x38c4068c}},	//   _thi_, агва_, мирн, mèrç_, 
   {{0x4420434a,0x64440309,0xdf48434b,0x00000000}},	//   _uhi_, _çhiq, рзад_, --, 
   {{0xe298434c,0x61ec434d,0xc33000db,0xddc4410a}},	// [4340] _тап_, pibl, _سەس_, обаи, 
   {{0x61ec434e,0x6284434f,0x7dc001f4,0x2c400064}},	//   qibl, mtko, _yösy, _sėda_, 
   {{0x63b4002d,0xa554001f,0x2c4000c0,0x00000000}},	//   _knyn, _መጠናቀ, _pėda_, --, 
   {{0x5f742e67,0x2d844350,0x63a44351,0x62840af9}},	//   _بادر, _ölen_, ndkn, otko, 
   {{0x1a944352,0x4a500212,0x3b004353,0xcb040451}},	//   تجاج, дкіс, çiq_, ٺيون_, 
   {{0xdd904354,0x6298033f,0x7e64009a,0x7f4439da}},	//   _توس_, łtow, msip, lciq, 
   {{0x628400af,0x7e644355,0x7d1c022e,0x63b4010e}},	//   htko, lsip, _uzrs, _onyn, 
   {{0x62842ff9,0x63b40083,0x7c3c009d,0x7e640254}},	//   ktko, _nnyn, _iurr, osip, 
   {{0xab5c006d,0x7c3c3077,0x62844356,0xd5b8005a}},	//   _możl, _hurr, jtko, асн_, 
   {{0x7c3c4357,0x18684358,0x7e644359,0x63b4435a}},	//   _kurr, _важи_, isip, _anyn, 
   {{0x6284435b,0x7c3c01f5,0x00000000,0x00000000}},	//   etko, _jurr, --, --, 
   {{0x7e64435c,0x7c3c435d,0xf4840583,0xb6c401af}},	//   ksip, _murr, _ہابی, _ниеһ, 
   {{0x7c3c0323,0x7e64435e,0x68340006,0x25a40175}},	//   _lurr, jsip, _išda, bdll_, 
   {{0x8500021a,0x7e640ffb,0xf4840344,0x7f44003a}},	//   _ښوون, dsip, _فابی, eciq, 
   {{0x7c3c435f,0x62844360,0x00000000,0x00000000}},	//   _nurr, atko, --, --, 
   {{0x7760009a,0xb4c80f4a,0xb35401d5,0x00000000}},	//   namx, ोनी_, _экиш, --, 
   {{0x7c3c152d,0x7e641187,0x62844361,0x6fb400e5}},	// [4350] _aurr, gsip, ctko, _ہمدا, 
   {{0x7c3c4362,0x71783cc5,0x8d744363,0x0ca80022}},	//   _burr, _убор_, تارا, итеи_, 
   {{0x7c3c4364,0xfc6402e8,0x7e644365,0x00000000}},	//   _curr, дъчн, asip, --, 
   {{0x7c3c4366,0x00000000,0x00000000,0x00000000}},	//   _durr, --, --, --, 
   {{0x8d744367,0x7c5804a9,0x6f1c01a9,0xcf2401c8}},	//   _واسا, ملەر_, _uzsc, _گرگي, 
   {{0x7c3c4368,0xae044369,0x2bdc166d,0xa85400d8}},	//   _furr, _روزى, _मतवा, птиј, 
   {{0x7c3c436a,0x6e3c436b,0x98bc0024,0x6d4423bd}},	//   _gurr, _husb, _metė_, mcha, 
   {{0x628414cf,0x6d44436c,0x77600b6f,0xab5c0003}},	//   ytko, lcha, gamx, _kożm, 
   {{0xc984436d,0x6d44436e,0x7c3c436f,0x6e3c4370}},	//   _мужи, ocha, _zurr, _jusb, 
   {{0x6d444371,0x6e3c4372,0x79980100,0xd5e000c7}},	//   ncha, _musb, cevw, ежьи, 
   {{0x6d440588,0xa5081a92,0x80d02b1b,0x6e340327}},	//   icha, сена_, _হেন্, _mizb, 
   {{0x6d444373,0x62844374,0x2a9c0100,0x7e6432bb}},	//   hcha, ttko, _kňb_, ysip, 
   {{0x6d444375,0x2a9c007f,0x6e3c0455,0x9f500162}},	//   kcha, _jňb_, _nusb, doyð_, 
   {{0x6e3407f5,0xf60803e6,0x6d444376,0x64b80117}},	//   _nizb, _وتوه_, jcha, _гуиё_, 
   {{0x65604377,0x6e3c101c,0x6d444378,0x55b80375}},	//   malh, _ausb, dcha, _למסו, 
   {{0x7e644379,0x6e3c047e,0x6d44437a,0x7c3c437b}},	//   tsip, _busb, echa, _rurr, 
   {{0x6e3c01d9,0x6d44127b,0x7c3c437c,0x7e64437d}},	// [4360] _cusb, fcha, _surr, usip, 
   {{0x7c3c437e,0x7e64437f,0x6e34011f,0x6d444380}},	//   _purr, rsip, _cizb, gcha, 
   {{0x77600b6f,0x7c3c4381,0x6e3c0165,0x91380a1e}},	//   yamx, _qurr, _eusb, _לעיק, 
   {{0x6d444382,0x7c3c08e5,0x65600b45,0x7e644383}},	//   acha, _vurr, halh, psip, 
   {{0x6d440457,0x65601455,0x24400ac9,0x7c3c002d}},	//   bcha, kalh, _lóm_, _wurr, 
   {{0x6d444384,0x7c3c4385,0x5f744386,0xdb4c04d3}},	//   ccha, _turr, _باگر, _ڵێت_, 
   {{0x65604387,0x65a400b0,0x7c3c0ba7,0x39a400ef}},	//   dalh, _mōhē, _uurr, _rūsē_, 
   {{0x799821a3,0x6e34009a,0x48701870,0x00000000}},	//   sevw, _zizb, ردىس, --, 
   {{0x6e340007,0xa3c400e1,0x6560067c,0x6e3c0014}},	//   _yizb, _एवज_, falh, _xusb, 
   {{0x65604388,0xd5b84389,0x6e34438a,0x94f40327}},	//   galh, сси_, _xizb, _པཨཱི_, 
   {{0x2440004e,0xb4c80c4c,0xd90c438b,0x00000000}},	//   _cóm_, ोने_, _حیث_, --, 
   {{0x2ca40a85,0x6d44438c,0x2440438d,0xedb81d03}},	//   _âlde_, zcha, _dóm_, _उच्छ, 
   {{0x6560438e,0x6d44438f,0x00000000,0x00000000}},	//   balh, ycha, --, --, 
   {{0x65604390,0x6d444391,0x6e3c4392,0x75d404fb}},	//   calh, xcha, _rusb, _زيبا, 
   {{0x6e3c0192,0x6d44100f,0x2440032e,0x6e34036e}},	//   _susb, vcha, _góm_, _rizb, 
   {{0x6d444393,0x6e3c4394,0x2c4000c0,0x00000000}},	//   wcha, _pusb, _sėdo_, --, 
   {{0x6e3c102c,0x00000000,0x00000000,0x00000000}},	// [4370] _qusb, --, --, --, 
   {{0x6d444395,0xf1d0038e,0x6e3c014f,0x6e34022e}},	//   ucha, _सकिन, _vusb, _qizb, 
   {{0x2440001e,0xe13000c7,0x00000000,0x00000000}},	//   _xóm_, _аҽры, --, --, 
   {{0x6d444396,0x6e3c4397,0x00000000,0x00000000}},	//   scha, _tusb, --, --, 
   {{0x6e3c4398,0xa9a4010b,0xff0400c0,0x00000000}},	//   _uusb, дилд, _зярн, --, 
   {{0x6d444399,0xd6e0009e,0x28a81777,0x680000ef}},	//   qcha, মপায, किलि, dēda, 
   {{0x65603c50,0x98a03d6b,0xa3cc00e1,0x00000000}},	//   valh, вище, _शकल_, --, 
   {{0x6560439a,0x244003f2,0x08400014,0x482000cf}},	//   walh, _róm_, ونڈُ, رۉشق, 
   {{0x6560439b,0x244000db,0x97300214,0x00000000}},	//   talh, _sóm_, نکها, --, 
   {{0xa4440120,0x7ae408c2,0x490000db,0x00000000}},	//   мнод, ùite, _пүлг, --, 
   {{0x6560439c,0x236000b5,0x00000000,0x00000000}},	//   ralh, takj_, --, --, 
   {{0x6560439d,0x6440439e,0x2b480113,0x68340064}},	//   salh, rqli, ñach_, _išdo, 
   {{0x6560439f,0x2d900585,0x65a404fe,0xbfc800d1}},	//   palh, _obze_, _pōhē, ۋارە_, 
   {{0x360443a0,0x244043a1,0x614406ed,0x062443a2}},	//   _كونف, _tóm_, ќева, _эфем, 
   {{0x1fa80329,0x352800cf,0x64400327,0x2c0c00cd}},	//   окви_, _ىسىپ_, qqli, िकां_, 
   {{0x88ac045e,0x3ec40107,0x00000000,0x00000000}},	//   _কথাক, нибҳ, --, --, 
   {{0x630401b9,0x9f50002e,0x0d740014,0xbef803ce}},	// [4380] _زودل, liyë_, ڈیُک_, ंपेन_, 
   {{0x88c400b8,0x2cb0022a,0x80d000cc,0x00000000}},	//   _kuśī, _brzd_, _হেণ্, --, 
   {{0x60080063,0x91b8011a,0x00000000,0x00000000}},	//   _мном_, _ומיי, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2904007c,0x00000000,0x00000000,0x00000000}},	//   _axla_, --, --, --, 
   {{0x62941418,0x3ea00428,0x3f8043a3,0x7d5401d5}},	//   _mpyo, mwit_, lgiu_, _سفرچ, 
   {{0x3ea01af3,0x3f8000c0,0x8c400205,0x00000000}},	//   lwit_, ogiu_, ışca, --, 
   {{0x3f8043a4,0x62940022,0x3ea00076,0xf7040166}},	//   ngiu_, _opyo, owit_, нҗем, 
   {{0x3ea043a5,0x598443a6,0x88c400b8,0xb4c801ad}},	//   nwit_, _олаб, _auśī, ोन्_, 
   {{0xc6f443a7,0x200000f3,0xca9c0240,0x00000000}},	//   ьных_, _ljki_, _ግቡኦም_, --, 
   {{0xdcec3279,0xf8b801c0,0x57480064,0x00000000}},	//   _kabı, _хөл_, _дзем_, --, 
   {{0x3ea00135,0x18a401f0,0x98a4014b,0x00000000}},	//   kwit_, _наҷм, _ниҷе, --, 
   {{0x518443a8,0x95c8189b,0x3f8005d5,0x00000000}},	//   мува, _мука_, dgiu_, --, 
   {{0x3ea043a9,0x3f800064,0x00000000,0x00000000}},	//   dwit_, egiu_, --, --, 
   {{0x863404ae,0x70c843aa,0x00000000,0x00000000}},	//   _קרוב_, रहेल, --, --, 
   {{0x3f8043ab,0x6fa80574,0x94200372,0x9fa401e0}},	//   ggiu_, _चोखं, _جوعۇ, ныуҙ, 
   {{0xd1c80323,0xadb40209,0x629401e1,0x3ea00135}},	// [4390] _дунд_, нбаш, _gpyo, gwit_, 
   {{0x3f8043ac,0xd36c00db,0x00000000,0x00000000}},	//   agiu_, _حۇڭ_, --, --, 
   {{0x3ea0079b,0x32100109,0x6b7402dd,0x88c400b8}},	//   awit_, mozy_, елеу, _kuśū, 
   {{0x321043ad,0x3ea043ae,0x60d4025d,0xec240137}},	//   lozy_, bwit_, _נורא_, رىشپ, 
   {{0x9f8800af,0xdcfc00c0,0x00000000,0x00000000}},	//   tööd_, kepė, --, --, 
   {{0xac78001f,0xc27c010f,0x00000000,0x00000000}},	//   ብሔርም_, קרוי, --, --, 
   {{0x316003b9,0xb86401f7,0x50dc07b7,0x00000000}},	//   _mehz_, نايو, ननिष, --, 
   {{0x01381203,0xe3c80f71,0x321005d6,0x9ba008b0}},	//   ורות_, _mañá_, hozy_, _مەمى, 
   {{0x321043af,0x2d8000ad,0xfb8400c7,0x88c4002b}},	//   kozy_, oghe_, _шырн, _suśī, 
   {{0x2d8043b0,0x499004d3,0xdcec05d1,0x87640150}},	//   nghe_, _شیعر, _zabı, _ﺍﺩﻩﭖ_, 
   {{0xdcec0724,0x32100109,0xf77043b1,0x2d8043b2}},	//   _yabı, dozy_, _چاه_, ighe_, 
   {{0x1ac400bd,0xf74836e9,0xe29843b3,0xf77043b4}},	//   _শেয়া, _قلمي_, пам_, _ناه_, 
   {{0xa2d443b5,0x00000000,0x00000000,0x00000000}},	//   ريست, --, --, --, 
   {{0xa0a443b6,0xdfd00451,0x7a2400cf,0x00e40066}},	//   нагд, گير_, pòte, نتزی, 
   {{0x1fb443b7,0x3ea00548,0x3f8004cc,0x9f50002e}},	//   нсар, wwit_, tgiu_, liyé_, 
   {{0x3ea043b8,0xdfd043b9,0x8fa01bc2,0x2d8001f5}},	//   twit_, دير_, ласе, eghe_, 
   {{0x3f8043ba,0xdd9043bb,0x32100109,0xdcec0205}},	// [43a0] rgiu_, ُور_, bozy_, _rabı, 
   {{0xdcec2706,0x3f802b1d,0x3210037e,0x3ea00af9}},	//   _sabı, sgiu_, cozy_, rwit_, 
   {{0x3ea03280,0x3f840116,0x51580375,0xed3400a8}},	//   swit_, _иғва, _מכיו, вэцэ, 
   {{0x986401ed,0x2d800072,0xdcec43bc,0x19f40014}},	//   ہیئے_, aghe_, _qabı, کِتھ_, 
   {{0x20101aac,0xa13401d5,0xd7f800c7,0x00000000}},	//   moyi_, _ترکش, ҷуп_, --, 
   {{0x201043bd,0xdd9001f7,0x2d800051,0x00000000}},	//   loyi_, _حوس_, cghe_, --, 
   {{0xdcec0724,0xd7f843be,0xc0d002d3,0x680000e2}},	//   _tabı, зуп_, _ብሰሪ_, rēdn, 
   {{0x201043bf,0x2b900214,0x9f8c00a2,0x321043c0}},	//   noyi_, _نیمس, _nýü_, zozy_, 
   {{0x9f50007f,0xf48400e5,0x00000000,0x00000000}},	//   riyè_, ھادی, --, --, 
   {{0x201043c1,0xab5c0327,0x9f50007f,0x4aa401d5}},	//   hoyi_, _rożi, siyè_, _якун_, 
   {{0x2010055a,0x3210022a,0x00000000,0x00000000}},	//   koyi_, vozy_, --, --, 
   {{0xab5c003d,0xb46443c2,0x3210033f,0xfa540023}},	//   _pożi, нкүл, wozy_, _ዝተሰማ, 
   {{0x3210289f,0x20100efc,0x70c81db2,0x2d80022e}},	//   tozy_, doyi_, रह्ल, yghe_, 
   {{0x68242d44,0x2bdc28f0,0x00000000,0x00000000}},	//   róde, _मत्थ, --, --, 
   {{0x316001fa,0x2ed800cd,0x00000000,0x00000000}},	//   _vehz_, णन्त, --, --, 
   {{0x741443c3,0x201043c4,0x9d780023,0x386c0306}},	//   _جوبا, goyi_, _ብቀጻሊ_, _mvdr_, 
   {{0x321005da,0xa2c01321,0x00000000,0x00000000}},	// [43b0] pozy_, _кәрк, --, --, 
   {{0x9e8c001f,0x1944037e,0x00000000,0x00000000}},	//   _ህክምና_, _ｙｅｔ_, --, --, 
   {{0x20100296,0xc5f000c8,0x705415d6,0xdb1c0129}},	//   boyi_, נדע_, _جنجا, _évêc, 
   {{0x8c5400db,0x00000000,0x00000000,0x00000000}},	//   _ۋئزا, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2fc8017a,0xd938001f,0x4f04030d,0x00000000}},	//   ljag_, _ራሳችን, ăнăн_, --, 
   {{0xcd3443c5,0x00000000,0x00000000,0x00000000}},	//   _سرسب, --, --, --, 
   {{0xe73843c6,0x660c01e4,0x7c340b87,0x2fc80c6a}},	//   мей_, _ƭako, _бесх, njag_, 
   {{0x66e443c7,0x16600024,0x00000000,0x00000000}},	//   топа, авым, --, --, 
   {{0x201001a9,0x00000000,0x00000000,0x00000000}},	//   zoyi_, --, --, --, 
   {{0x20103142,0x667402c0,0x00000000,0x00000000}},	//   yoyi_, ردکر, --, --, 
   {{0x9f500066,0x3cf400dc,0x00000000,0x00000000}},	//   piyé_, ्पते_, --, --, 
   {{0xd24c4209,0xe5a443c8,0x7a24067c,0x2fc800ad}},	//   ينَ_, _аили, lòta, djag_, 
   {{0x20100b45,0xb2040124,0x154001af,0xd5bc00ef}},	//   woyi_, лҵыз_, _кешм, _šāva_, 
   {{0x201043c9,0x2b4c004e,0x98bc00e4,0x94d00798}},	//   toyi_, _ofec_, _petĩ_, _војц, 
   {{0x2fc800d5,0x56900131,0x78bc2bb4,0xab5c0210}},	//   gjag_, _саәт, _árve, _kożu, 
   {{0xf1d40323,0x201043ca,0x9d44020f,0x5d680108}},	// [43c0] _өөрө, royi_, везд, дизм_, 
   {{0x2b4c067c,0x201002a8,0x8bd001b9,0x00000000}},	//   _afec_, soyi_, یقلش, --, 
   {{0xc1e401ec,0x2d9443cb,0x00000000,0x00000000}},	//   _ﺍﺑﺰﺍ, ыртс, --, --, 
   {{0x201043cc,0xda64027d,0xad24007b,0xa2c400cd}},	//   qoyi_, ناتي, اركو, ामप्, 
   {{0xe7c43c16,0xd12c00aa,0x2b4c0334,0x00000000}},	//   वानप, _هڅې_, _dfec_, --, 
   {{0x1d0802e8,0x00000000,0x00000000,0x00000000}},	//   _жеги_, --, --, --, 
   {{0x0cd000db,0x00000000,0x00000000,0x00000000}},	//   _коёю, --, --, --, 
   {{0xd6d81830,0xb880001f,0x3874031c,0x69c401f4}},	//   дто_, _የክፍለ_, _ċarġ_, öher, 
   {{0x6824033f,0x7d1c010e,0x68ec0115,0x96080006}},	//   wódc, _hyrs, ĝada, дэна_, 
   {{0x7d1c06a3,0xa2c416d1,0x2c400153,0xd4500092}},	//   _kyrs, ामन्, _sėdi_, _የተፈፀ, 
   {{0x57a41cd1,0x7988035a,0x7d1c005b,0x70d009bb}},	//   _ашла, _icdw, _jyrs, _हथेल, 
   {{0xa78443cd,0x7d1c43ce,0x62ec0154,0x00000000}},	//   _مشهو, _myrs, _টুইট_, --, 
   {{0x80d009bd,0xd1640724,0xb5c40ae5,0x35b000cc}},	//   _হেল্, къви, ﯩﯖﯩﺰ, _চকীহ, 
   {{0x98ac06be,0x00000000,0x00000000,0x00000000}},	//   lafı_, --, --, --, 
   {{0x6298084c,0x2250002d,0x85980a1e,0x7d1c03cb}},	//   ătoa, _etyk_, _חשוו, _nyrs, 
   {{0x79880857,0xffe4004e,0x98ac03e0,0x00000000}},	//   _lcdw, аюун, nafı_, --, 
   {{0x403443cf,0x798803ac,0x7a24007f,0x2fc8007c}},	// [43d0] ретс, _ocdw, zòta, rjag_, 
   {{0x88340201,0x2a6c070d,0x998c0421,0x7d1c43d0}},	//   ብረተሰ, _rveb_, fofō_, _byrs, 
   {{0x7d1c0368,0x2fc80ea0,0x8bc4010b,0xe7380142}},	//   _cyrs, pjag_, ксдд, ndŵr_, 
   {{0xfbd00451,0x0fe000f7,0x0ba80a11,0xd6e043d1}},	//   يتن_, _төгү, بائى_, गनाथ_, 
   {{0xd6c443d2,0x9f940375,0x682403b2,0x00000000}},	//   _اق_, _גדרה_, jóda, --, 
   {{0x7d1c43d3,0x798803ac,0x14c000dc,0x68340153}},	//   _fyrs, _ccdw, षमाण, _išdi, 
   {{0x3da40c04,0xe5a443d4,0x79880204,0xf99043d5}},	//   _тряб, қини, _dcdw, تبن_, 
   {{0x2b4c00db,0xac940022,0x7a240561,0x00000000}},	//   _ufec_, _иаҳш, ròta, --, 
   {{0x6b8843d6,0xc984035b,0x9ba01411,0x2a780174}},	//   _iceg, _ауеи, _دەنى, _ísb_, 
   {{0x7a240d29,0x6aa82e12,0x9f8c032e,0xe45801d5}},	//   pòta, _isef, _lýð_, нжо_, 
   {{0x66d80248,0xe36443d7,0x225043d8,0x88800244}},	//   _bùkú, лкни, _styk_, _ئیبن, 
   {{0xf1a80302,0x0a240092,0x00000000,0x00000000}},	//   _מס_, ስፈራራ, --, --, 
   {{0x21741377,0x6f1c01c7,0x00000000,0x00000000}},	//   лувр, _nysc, --, --, 
   {{0xb2f407d8,0xddd40309,0xa508209b,0x00000000}},	//   ряющ, kuyš, _пела_, --, 
   {{0x6f1c02d0,0xc8b002ab,0x9f8c08a5,0x22500210}},	//   _aysc, ंटिट, _býð_, _wtyk_, 
   {{0x8c400abc,0x6b8800f2,0x6aa803ac,0x814400f1}},	//   ışla, _nceg, _osef, انځن, 
   {{0xd004034b,0x7d1c43d9,0x00000000,0x00000000}},	// [43e0] уете_, _syrs, --, --, 
   {{0x7d1c0652,0xf1d443da,0x6b88035a,0x6f1c033f}},	//   _pyrs, _көсө, _aceg, _dysc, 
   {{0x6aa80134,0x6f1c0036,0x307402ac,0x682400d7}},	//   _asef, _eysc, _куяс, zóda, 
   {{0x2f300055,0xdb0003b9,0xdee4022e,0x00000000}},	//   _ṅge_, ndoç, _боми, --, 
   {{0x7d1c04cc,0x98bc00c0,0x93f800df,0x00000000}},	//   _wyrs, _petį_, עלני, --, 
   {{0x7d1c43db,0x9f500008,0x798803ac,0x00000000}},	//   _tyrs, ábær_, _qcdw, --, 
   {{0x6aa80944,0x798803ac,0xb7880166,0xed340153}},	//   _esef, _vcdw, вәле_, _вэтэ, 
   {{0xfaf801e0,0x95fc012d,0x6824368c,0x00000000}},	//   _иҫе_, ैक्ट_, tóda, --, 
   {{0x7bc043dc,0xbab40050,0x98ac06b9,0x9b04023a}},	//   _inmu, _خۅشب, rafı_, _сзад, 
   {{0x68240553,0x2618068c,0x068000d1,0x2d8401e3}},	//   róda, dèos_, _ﻫﻪﻗﯩ, _ölet_, 
   {{0x4d7804ac,0xddd401ed,0x682402f0,0x4e14011a}},	//   ערטע, ntyű, módn, רחיב_, 
   {{0x682401d3,0xb6c801d3,0xccf0011a,0x00000000}},	//   lódn, _لاتے_, מכת_, --, 
   {{0xf0e80131,0x7a24004e,0x00000000,0x00000000}},	//   ھىرى_, nòto, --, --, 
   {{0xab5c031c,0x9f8c02d2,0x00000000,0x00000000}},	//   _inże, _sýð_, --, --, 
   {{0xdebc044e,0x7df4012d,0x00000000,0x00000000}},	//   _ኰይኑ_, ańsk, --, --, 
   {{0x6f1c00e4,0x60d80158,0xb2b807a5,0x00000000}},	//   _pysc, øtma, _алиф_, --, 
   {{0x8c4043dd,0xa2c443de,0x2c500213,0xfd7401c0}},	// [43f0] ışma, ामण्, _işdə_, өлтэ, 
   {{0x6b8843df,0x7bc00112,0x6f1c0306,0x00000000}},	//   _sceg, _anmu, _vysc, --, 
   {{0xe0540583,0xbd8800f1,0x6f1c012d,0x644c43e0}},	//   _نیّت_, انمن_, _wysc, _čaik, 
   {{0x645401e4,0xab9443e1,0x00000000,0x00000000}},	//   ŭzig, риді, --, --, 
   {{0x7c580131,0xff2801d5,0x4ea40454,0x41740116}},	//   نلەر_, _бўри_, _ёрма, _ئاۋس, 
   {{0x7bc001e4,0xf3fc015b,0x680000e2,0x42dc010f}},	//   _enmu, ীতির_, mēdi, עקגע, 
   {{0x63a043e2,0xd1f40092,0x68ec010f,0xd1d00092}},	//   _ñong, _ለጌታ_, ĝado, _ከጌታ_, 
   {{0x6aa80943,0x7df40034,0x68ec0115,0xaba80066}},	//   _tsef, yńsk, ŝado, _جهرم_, 
   {{0x6aa843e3,0xdebc02d3,0xd6a401b9,0xa98400db}},	//   _usef, _ኰይና_, لگوم_, _نۅشۅ_, 
   {{0xab5c033f,0x00000000,0x00000000,0x00000000}},	//   _tożs, --, --, --, 
   {{0xa5081d83,0x69c043e4,0xe7c41c15,0x74540023}},	//   тена_, _inle, वादप, _ዘተግብ, 
   {{0x78bc43e5,0x00000000,0x00000000,0x00000000}},	//   _árva, --, --, --, 
   {{0xa2c40a99,0x52a400a7,0x682401d3,0x00000000}},	//   ामध्, авям_, lódo, --, 
   {{0xc3c401e0,0x00000000,0x00000000,0x00000000}},	//   рөҫл, --, --, --, 
   {{0x24080107,0x7cdc0171,0x27300051,0x00000000}},	//   _инки_, _kārš, _ạnh_, --, 
   {{0x91000220,0x5f0443e6,0x682401d3,0x00000000}},	//   іпте, азба, zódn, --, 
  
   {{0xe7ec007d,0x7a2400db,0x7cdc00ef,0x00000000}},	// [4400] _जतना_, xòto, _mārš, --, 
   {{0x68340006,0x68240646,0x3cf42d81,0xdcfc0171}},	//   _išdu, kódo, ्पले_, egpā, 
   {{0x9f50019f,0x320c00e8,0xdef80209,0x00000000}},	//   riyâ_, éeye_, хың_, --, 
   {{0x9f0443e7,0x9f50011f,0x68000171,0x00000000}},	//   _نوجو, siyâ_, bēdi, --, 
   {{0x1cc80327,0x0b4000d1,0x00000000,0x00000000}},	//   ིདང_, әнән, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdcb043e8,0x57a43999,0x682443e9,0x00000000}},	//   _بىز_, ашпа, ródn, --, 
   {{0x69c043ea,0x8c4013d6,0xddc400d0,0x2d840432}},	//   _enle, _фете, _sukň, _öler_, 
   {{0x3a2c020b,0x597403e6,0x4b78011a,0x00000000}},	//   _thdp_, _نداز, _שאמו, --, 
   {{0xd5b800e4,0xf8b801fb,0x85b4010b,0x00000000}},	//   тси_, _trĩ_, альс_, --, 
   {{0x2e2c02d2,0x0a1002f2,0x00000000,0x00000000}},	//   _hófý_, _بولح, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x290843eb,0x69c0045f,0x59d800e1,0xe678004b}},	//   şaat_, _ynle, _बकार, _ملنګ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x999c3b28,0x8c40247e,0xcf8802a9,0x00000000}},	//   _aitū_, ışka, ксад_, --, 
   {{0xac700023,0x941c010a,0x00000000,0x00000000}},	//   _ኣልማዝ_, _юрлă_, --, --, 
   {{0xb8f80156,0x44f0031c,0x682401d3,0x00000000}},	// [4410] _ོཝ_, _བཟོར_, zódo, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x823443ec,0x93f8002e,0x7a241497,0x00000000}},	//   _بريا, _f胃tt, ròtl, --, 
   {{0x6800005f,0x00000000,0x00000000,0x00000000}},	//   pēdi, --, --, --, 
   {{0x7cfc0e38,0x8aa4010b,0x89f400c7,0xe7c40b9a}},	//   _pårø, рред, аҭар_, वासप, 
   {{0x682443ed,0x00000000,0x00000000,0x00000000}},	//   tódo, --, --, --, 
   {{0x9f50011f,0x39780111,0x7cdc00de,0x00000000}},	//   liyá_, рсію_, _pārš, --, 
   {{0xac180114,0xe76800cf,0x00000000,0x00000000}},	//   _собу_, اڭان_, --, --, 
   {{0xe61843ee,0x29d400ec,0x00000000,0x00000000}},	//   лди_, _ٿياس, --, --, 
   {{0xa2c407d0,0x69c043ef,0xe7c42886,0x00000000}},	//   ामस्, _unle, वाहप, --, 
   {{0x24780023,0x6844009f,0x00000000,0x00000000}},	//   _በደላት_, _اَصل, --, --, 
   {{0x64a407d6,0x6aac025c,0x00000000,0x00000000}},	//   _ҳака, ħaff, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9660005b,0x64a443f0,0x00000000,0x00000000}},	//   _экше, _гака, --, --, 
   {{0x25a443f1,0x00000000,0x00000000,0x00000000}},	//   mell_, --, --, --, 
   {{0x25a443f2,0x2f3000b8,0x00000000,0x00000000}},	//   lell_, _ṅga_, --, --, 
   {{0x1ea843f3,0x63a443f4,0x00000000,0x00000000}},	// [4420] دازي_, mekn, --, --, 
   {{0x63a443f5,0xfa540023,0x81cc00eb,0x00000000}},	//   lekn, _ዝሰማማ, লসহ_, --, 
   {{0x9b4443f6,0xd5f8010f,0x20b80108,0xe0440354}},	//   مناو, נפער, _сыпь_, _ынни, 
   {{0x28bc1fe7,0xdca443f7,0x3e880166,0x92c803d4}},	//   ्मनि, _қаби, _кимү_, লনৰ_, 
   {{0x25a443f8,0x3d180c4c,0xc0f8001f,0x00000000}},	//   kell_, _बुरे_, ጊዜም_, --, 
   {{0x63a443f9,0x25a443fa,0xf9c443fb,0x62840254}},	//   hekn, jell_, تحصی, iuko, 
   {{0x383400c7,0x63a43e49,0x2b480841,0x00000000}},	//   онкр, kekn, žaca_, --, 
   {{0x0ae4013d,0xf65400d8,0x00000000,0x00000000}},	//   рдәй_, овиќ, --, --, 
   {{0x25a443fc,0x63a443fd,0xb6f80131,0x44f00327}},	//   fell_, dekn, شىدا_, _བཟུར_, 
   {{0x25a443fe,0x78bc0261,0xab5c025c,0xcb9001f3}},	//   gell_, _árvo, _inża, _መዝሙረ_, 
   {{0x9d24015b,0x6284017a,0xe34c01e1,0x00000000}},	//   _বলুন_, euko, _ṣánp, --, 
   {{0x628443ff,0x63a44400,0x00000000,0x00000000}},	//   fuko, gekn, --, --, 
   {{0x62844401,0xe7c40b02,0x7ae408c2,0x13a40133}},	//   guko, वारप, ùith, لۆژی_, 
   {{0x25a44402,0x07340302,0x415400ea,0x00000000}},	//   cell_, _האדם_, зврс, --, 
   {{0x63a44403,0xc0c84404,0xcf980261,0x68340024}},	//   bekn, буте_, лја_, _išdr, 
   {{0x63a44405,0x1fc40107,0x13a40066,0xb4e42e04}},	//   cekn, оруҳ, _اچدی_, फनी_, 
   {{0x2dd422d7,0x62844406,0x00000000,0x00000000}},	// [4430] ожар, cuko, --, --, 
   {{0xa2c44407,0xcb1c0490,0x7008009e,0xbc84004d}},	//   ामर्, _बडबड_, লতেও_, ưởn, 
   {{0x313400f3,0x9f50010b,0x00000000,0x00000000}},	//   _фенр, lnyý_, --, --, 
   {{0x25a435ca,0x60d800af,0x92c8009e,0x00000000}},	//   zell_, ätme, লনী_, --, 
   {{0x1cc80dd4,0x6a140372,0x6a841cb8,0x28bc00cd}},	//   ིདཔ_, омду, ілка, ्मभि, 
   {{0x25a40137,0xc9844408,0x63a4005f,0x0dc84409}},	//   xell_, суди, zekn, _суми_, 
   {{0x25a4440a,0x6284440b,0x8cb401d9,0x63a4440c}},	//   vell_, zuko, _دۯاس_, yekn, 
   {{0x6284440d,0xe74401e0,0xdcec0055,0x00000000}},	//   yuko, әүҙе_, _udbā, --, 
   {{0x25a43402,0x62842e48,0x00000000,0x00000000}},	//   tell_, xuko, --, --, 
   {{0x63a4440e,0x6284440f,0x25a4030a,0x00000000}},	//   wekn, vuko, uell_, --, 
   {{0x62844410,0x24084411,0x00000000,0x00000000}},	//   wuko, инои_, --, --, 
   {{0x62844412,0x682400e5,0x00000000,0x00000000}},	//   tuko, zódj, --, --, 
   {{0xf7701d1f,0x63a44413,0x62844414,0x8724113e}},	//   _سان_, rekn, uuko, _اعام, 
   {{0x62844415,0x27ec4416,0x63a41aa9,0x7ae400a3}},	//   ruko, lhen_, sekn, ùiti, 
   {{0x62844417,0xa0344418,0x213c04cc,0xa0680e54}},	//   suko, قىست, äth_, раба_, 
   {{0x24740061,0x6d544419,0xbbb813e0,0xdee401e5}},	//   mām_, _afza, _इफेक, ооби, 
   {{0x4420441a,0x27ec441b,0x9d2403f4,0x24741991}},	// [4440] _iki_, ihen_, _বলেন_, lām_, 
   {{0x23840050,0x787001d3,0x91d802dd,0x4420441c}},	//   _أکِ, _jóvá, _кәсi, _hki_, 
   {{0x2474441d,0x442029f1,0x7158441e,0x9b6810fc}},	//   nām_, _kki_, _урыс_, ашла_, 
   {{0x27ec09a8,0x7a2400db,0x00000000,0x00000000}},	//   jhen_, mòti, --, --, 
   {{0x27ec441f,0x00000000,0x00000000,0x00000000}},	//   dhen_, --, --, --, 
   {{0x27ec4420,0x24740061,0x09e00c98,0x44204421}},	//   ehen_, kām_, мочн, _lki_, 
   {{0x247411f9,0x44204422,0x00000000,0x00000000}},	//   jām_, _oki_, --, --, 
   {{0x44204423,0x24744424,0x3dd804cc,0xa3cc134e}},	//   _nki_, dām_, _horw_, राफ_, 
   {{0xa3cc4425,0x95c8390e,0x00000000,0x00000000}},	//   रान_, ауна_, --, --, 
   {{0x44204426,0x18a44427,0x98a44428,0x75c80116}},	//   _aki_, _мазм, _мизе, стиң_, 
   {{0x247400da,0x3dd80810,0x27ec4429,0x2a3401c0}},	//   gām_, _morw_, bhen_, _хэтр, 
   {{0x27ec442a,0x00000000,0x00000000,0x00000000}},	//   chen_, --, --, --, 
   {{0x44200574,0xb17c02d3,0xf8b0009f,0x9148011c}},	//   _dki_, _ንዝኾነ_, _آکڻ_, ичва_, 
   {{0x4420442b,0x247400da,0x61ec43a9,0x60cc0175}},	//   _eki_, bām_, ghbl, fxbm, 
   {{0x4420442c,0x7a241c69,0x24741c52,0x4f68442d}},	//   _fki_, gòti, cām_, ишам_, 
   {{0x35e00bb2,0xa020442e,0xb2740075,0x28bc1db2}},	//   _पकड़, _çöll, _елиш, ्मति, 
   {{0xb8dc025c,0x6b50442f,0x7df4012d,0x6e240842}},	// [4450] _ཇན_, _lógó, yńst, tlhb, 
   {{0x27ec4430,0x442001c0,0x61ec4431,0x7a2400db}},	//   zhen_, _zki_, chbl, bòti, 
   {{0x44204432,0x27ec0023,0x7a24004e,0x43840244}},	//   _yki_, yhen_, còti, _علیق, 
   {{0xa3cc4433,0x25b800e2,0x27ec0240,0x6824012d}},	//   राय_, ēsli_, xhen_, ródk, 
   {{0xed1400dd,0x2474005f,0x16182ac3,0x09dc0011}},	//   _کہاں_, zām_, नकार_, _ভগবা, 
   {{0x24740a28,0x63b800e2,0x00000000,0x00000000}},	//   yām_, ētni, --, --, 
   {{0x1ee804d3,0x2fd80165,0x68240d50,0xe94400e5}},	//   _نوێی_, _kosg_, lódi, _ہرای, 
   {{0x24744424,0xab5c025c,0xc5e000dc,0x61ec030a}},	//   vām_, _inżo, गस्य_, zhbl, 
   {{0x27ec4434,0x44204435,0xe9440214,0x2fd84436}},	//   rhen_, _rki_, _فرای, _mosg_, 
   {{0x27ec4437,0x2474441d,0x28bc4438,0x88c44439}},	//   shen_, tām_, ्मदि, _وتال, 
   {{0x44201390,0x26cc0005,0x7c4400a2,0x92c800cc}},	//   _pki_, sxeo_, _üwrü, লনো_, 
   {{0x24740061,0x442001a9,0x00000000,0x00000000}},	//   rām_, _qki_, --, --, 
   {{0x24741991,0xa6340220,0xa3cc443a,0x61ec443b}},	//   sām_, _енді, राब_, thbl, 
   {{0x24740f40,0x2cb001d3,0x2054443c,0x00000000}},	//   pām_, _oszd_, зтар, --, 
   {{0x4420443d,0x35f804fb,0x00000000,0x00000000}},	//   _tki_, _برند_, --, --, 
   {{0x4420443e,0x660001d9,0x2fd808c2,0x6130013d}},	//   _uki_, lilk, _cosg_, _añlí, 
   {{0x1e84443f,0x3170007f,0x7a24007f,0xa02003e0}},	// [4460] ялам, bazz_, sòti, _çöml, 
   {{0x63b41dcd,0x66004440,0x618002d3,0x7a240100}},	//   _hayn, nilk, ሕዳራዊ_, pòti, 
   {{0x63b44441,0x61fc4442,0x1c444443,0xad244444}},	//   _kayn, _impl, чнем, ورمو, 
   {{0x5ac84445,0x62940175,0x6b5001e1,0x00000000}},	//   йлем_, _kqyo, _rógó, --, 
   {{0x63b44446,0x66004447,0x61fc0051,0xd12c1a4b}},	//   _mayn, kilk, _kmpl, _لمی_, 
   {{0x27fc0142,0x6600003e,0x00000000,0x00000000}},	//   _amwn_, jilk, --, --, 
   {{0x66004448,0x229401bf,0x49700101,0x7b840116}},	//   dilk, hæk_, ردوآ, _يارە, 
   {{0x63b44449,0x8a8401d9,0x00000000,0x00000000}},	//   _nayn, تھہِ_, --, --, 
   {{0x61fc444a,0xda6401ec,0xe7ec00c5,0x36d40108}},	//   _ompl, _ءاري, _जतरा_, фопр, 
   {{0xf9c4444b,0x66000263,0x644c0114,0x63b4058a}},	//   _تحری, gilk, _čair, _aayn, 
   {{0x63b4444c,0x62940166,0x682401d3,0x8570009d}},	//   _bayn, _aqyo, zódi, элэх, 
   {{0x63b4444d,0x18a4013e,0x9268444e,0x00000000}},	//   _cayn, _маҷм, йрга_, --, 
   {{0x63b4444f,0x2fd808c2,0x3170031c,0x00000000}},	//   _dayn, _rosg_, tazz_, --, 
   {{0x66004450,0xf4844451,0x46100f1b,0x313400ee}},	//   cilk, _قابی, _كونر, дегр, 
   {{0x85980302,0xdf5802e3,0x63b4058a,0xc0c8084c}},	//   _השוו, _ọnụa, _fayn, путе_, 
   {{0xa3cc3174,0x63b44452,0x22944453,0x682401d3}},	//   राण_, _gayn, bæk_, tódi, 
   {{0xadb44454,0xa5e80014,0x3f140798,0x31700327}},	// [4470] мбаш, _دى۪ل_, едтс, pazz_, 
   {{0x63b44455,0x317005b1,0x09d800dc,0x932401d3}},	//   _zayn, qazz_, _भवेय, _ورکن, 
   {{0x68244456,0xb03405f5,0x2fd800a3,0x63b44457}},	//   sódi, _онош, _tosg_, _yayn, 
   {{0x63b44458,0xd7e4007b,0xf1b800de,0x28bc09fa}},	//   _xayn, _شك_, ēšu_, ्मसि, 
   {{0xa3cc05ba,0x61fc000f,0x66004459,0x47d800cc}},	//   रात_, _ympl, yilk, _বগলী, 
   {{0xa858026a,0x66000009,0x7b640ce8,0xa96800d8}},	//   ојих_, xilk, _үтте, цика_, 
   {{0x7c84445a,0x6600445b,0x8934007b,0x6fe01be1}},	//   _путе, vilk, أعشا, _नवां, 
   {{0x7b08007b,0x6600012d,0x18a01171,0x00000000}},	//   ástá, wilk, таъм, --, 
   {{0x6600445c,0x00000000,0x00000000,0x00000000}},	//   tilk, --, --, --, 
   {{0xd704169c,0x63b4445d,0x2ca4000f,0xe47404b4}},	//   ьные_, _sayn, _âlds_, мумэ, 
   {{0x6600445e,0x6adc445f,0x7c280171,0x79a4010a}},	//   rilk, _मथुर, _ūdri, _ярте, 
   {{0xd91830fb,0x66004460,0x63b44461,0xa3cc1152}},	//   _וועל, silk, _qayn, राध_, 
   {{0x28bc043e,0x63b40363,0x66004462,0x00000000}},	//   ्मवि, _vayn, pilk, --, 
   {{0x63b44463,0x2294037e,0x66000067,0x35d40108}},	//   _wayn, ræk_, qilk, _почё, 
   {{0x63b44464,0x1fb44465,0xb5c80014,0xa3cc4466}},	//   _tayn, мсар, _روٹم_, राद_, 
   {{0xdfd00597,0x8fa04467,0x4fa00395,0x60780023}},	//   خير_, касе, кисв, _ክውገድ_, 
   {{0xdc2c0a28,0xd0040108,0x00000000,0x00000000}},	// [4480] jñān, фете_, --, --, 
   {{0x61fc4468,0x0d80003b,0x00000000,0x00000000}},	//   _umpl, клун, --, --, 
   {{0x81440597,0x0d20010b,0x00000000,0x00000000}},	//   _яєиσ_, вүрү, --, --, 
   {{0x62840b4f,0x78bc3b7b,0xdee401d5,0x14d4010f}},	//   orko, _árvi, _жоми, וועל_, 
   {{0x6d4003b2,0x00000000,0x00000000,0x00000000}},	//   _úlan, --, --, --, 
   {{0x98c4154e,0x62844469,0x19f40014,0xdd90446a}},	//   дсил, irko, بِتھ_, _جوس_, 
   {{0x26d801b8,0x62840e78,0xce44010b,0x3d1800ab}},	//   äson_, hrko, _цзре_, _बँटे_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xab5c033f,0x628401bf,0xdc2c0055,0x00000000}},	//   _noży, jrko, cñān, --, 
   {{0xd498446b,0x00000000,0x00000000,0x00000000}},	//   орм_, --, --, --, 
   {{0x98d00118,0x335400cf,0x00000000,0x00000000}},	//   _थपिए, нүйө_, --, --, 
   {{0x09300137,0x136801b9,0xd68400db,0xab5c012d}},	//   _شىنح, ўшни_, _жукп, _boży, 
   {{0x9f5000e4,0x96940120,0xa2c4446c,0x8838123b}},	//   biyú_, _цреш, ामग्, _ותאו, 
   {{0x75d4038b,0xab5c033f,0x00000000,0x00000000}},	//   _سيبا, _doży, --, --, 
   {{0x6284446d,0x30140261,0x0ee4033f,0x60e4013a}},	//   arko, едвр, ओन्स_, _čumá, 
   {{0x7198004b,0x09d8193d,0x4034010b,0x54340633}},	//   _کندز_, _भव्य, весс, _غرغر, 
   {{0xb8d0081f,0xa2c0446e,0x00000000,0x00000000}},	// [4490] _ཟག_, _йәрк, --, --, 
   {{0xe2a401a8,0xc334010f,0x682400e5,0x00000000}},	//   _áðan_, _שוץ_, lódt, --, 
   {{0x3d9436cb,0x00000000,0x00000000,0x00000000}},	//   тихр, --, --, --, 
   {{0xcfa401a9,0x00000000,0x00000000,0x00000000}},	//   _ўшни, --, --, --, 
   {{0x22a0016b,0x7a240086,0xd9400107,0x7eb801e7}},	//   _kɔka_, jòts, қеъи, rúpá, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdcec0034,0x57bc00d1,0x99d00228,0x00000000}},	//   _odbę, ﻣﻠﯩﺮ, اقىت, --, 
   {{0x6284446f,0xad840137,0xbb84007b,0x8b340150}},	//   yrko, _تاڭۇ, _للفي, _قۋار_, 
   {{0xa3cc044b,0xd90c00dd,0xe50800f1,0x00000000}},	//   रास_, لیے_, ړيدو_, --, 
   {{0x2a6c01e2,0x700002e3,0xa2bc0825,0x00000000}},	//   _iweb_, ịcha, शिस्, --, 
   {{0x64c806ab,0x2a6c005a,0xc7b834be,0x33280067}},	//   िमेश, _hweb_, _мёд_, _ayax_, 
   {{0xab5c0034,0x62840210,0xe8bc05c0,0x00000000}},	//   _poży, trko, ्मीच, --, 
   {{0x0704021a,0x62844470,0x2a6c0175,0x48e4012c}},	//   _کيږي_, urko, _jweb_, जनको_, 
   {{0xa3cc00dc,0x2a6c4471,0x628401e3,0x25b800e2}},	//   राह_, _mweb_, rrko, ēsls_, 
   {{0x2a6c0048,0x30744472,0xa6b000cc,0x2b4800d7}},	//   _lweb_, кутс, _জপিয়, žach_, 
   {{0x62844473,0x2b4c036e,0x23640432,0x00000000}},	//   prko, _ngec_, _ýoj_, --, 
   {{0xddc401d5,0xa2e401a9,0x00000000,0x00000000}},	// [44a0] нбаи, _чопд, --, --, 
   {{0xa3cc0b03,0xad640214,0x5318011a,0xff2400fb}},	//   राव_, نامه, _מופצ, емғо, 
   {{0x394c0618,0x2a6c2a6a,0xe8e4009f,0x00000000}},	//   _rgds_, _aweb_, _ئڻ_, --, 
   {{0x1e9400d8,0x00000000,0x00000000,0x00000000}},	//   _пргр, --, --, --, 
   {{0x06dc015b,0x00000000,0x00000000,0x00000000}},	//   _বেসি, --, --, --, 
   {{0x7e644474,0xcb0400c6,0x386c0142,0x1278010f}},	//   mpip, عيون_, _pwdr_, לאנע, 
   {{0x772c044e,0x7e644475,0xe9702928,0xbad8015b}},	//   _ስትራተ, lpip, شۇند, _দেখছ, 
   {{0x8c404476,0xda700014,0x2a6c0175,0x7e640113}},	//   _бесе, _مُر_, _fweb_, opip, 
   {{0x7e644477,0x00000000,0x00000000,0x00000000}},	//   npip, --, --, --, 
   {{0x473012cd,0x94844478,0x80e0000d,0x00000000}},	//   ыныс, нымд, नहाइ, --, 
   {{0xf8b801c4,0x00000000,0x00000000,0x00000000}},	//   _цөл_, --, --, --, 
   {{0x7e6402d1,0x00000000,0x00000000,0x00000000}},	//   kpip, --, --, --, 
   {{0xa2bc07b6,0x55e44479,0x7e640309,0xd7040408}},	//   शिष्, _подб, jpip, _язди, 
   {{0xdb00447a,0x7e64447b,0x045400e5,0x00000000}},	//   ndoñ, dpip, بجیت_, --, 
   {{0x78a8037e,0xa3cc00e1,0x4fc401c0,0x00000000}},	//   _jpdv, राश_, нсаа, --, 
   {{0x6298084c,0xb4cc0d2c,0x2b480114,0x22a0013b}},	//   ător, रमी_, žaci_, _wɔka_, 
   {{0x7e64447c,0xa3cc447d,0x00000000,0x00000000}},	// [44b0] gpip, रार_, --, --, 
   {{0xab5c025c,0x3d94447e,0x00000000,0x00000000}},	//   _inżi, лиур, --, --, 
   {{0xac94005b,0x3c180100,0x8d7400db,0x2a6c013a}},	//   таеш, zčve_, _ۋاسا, _sweb_, 
   {{0xb7c403a2,0x7e64030d,0x207808a8,0x00000000}},	//   leãƒ, bpip, _קארא, --, 
   {{0x61f80793,0xbf1429db,0x00000000,0x00000000}},	//   _äblü, _бүтә, --, --, 
   {{0x2a6c0334,0x19f00022,0x7c8401ec,0x00000000}},	//   _vweb_, аҟур, _әуре, --, 
   {{0x27e80b45,0x2000020b,0x7c2c06af,0xad242160}},	//   _ƴan_, _ymki_, éorè, _شىرى, 
   {{0x9ba0030c,0x00000000,0x00000000,0x00000000}},	//   _نەمى, --, --, --, 
   {{0xdcec0316,0x81b800cc,0x00000000,0x00000000}},	//   _odbě, ছাত_, --, --, 
   {{0x6aa802d0,0x00000000,0x00000000,0x00000000}},	//   _ipef, --, --, --, 
   {{0x22500113,0x06dc015b,0x7e640113,0x3c18007f}},	//   _suyk_, _বেশি, zpip, sčve_, 
   {{0x7e641bb7,0xa2bc11a6,0x2ed007f7,0xf770007b}},	//   ypip, शिल्, _सपूत, _هاه_, 
   {{0x06dc015b,0x00000000,0x00000000,0x00000000}},	//   _বেরি, --, --, --, 
   {{0x6aa801e0,0x682404d4,0x20000098,0xf65000ec}},	//   _mpef, códr, _smki_, _طئه_, 
   {{0x91001b88,0xab5c031c,0x7e6402d1,0x00000000}},	//   апре, _enżi, wpip, --, 
   {{0x7e64447f,0xe3b04480,0xd84c063f,0x6aa84481}},	//   tpip, _ضرب_, kọnd_, _opef, 
   {{0x5398025f,0xc0d002d3,0x7e640784,0xdcf40139}},	// [44c0] _חיפו, _ብደም_, upip, _ıbız, 
   {{0x4d604482,0xd24c07d6,0x629000d7,0x00000000}},	//   икув, _گنی_, ľkoľ, --, 
   {{0x6aa81140,0x7e6402d1,0x6304035c,0x67f40419}},	//   _apef, spip, _سوگل, _kájd, 
   {{0x5f044483,0x7e644484,0x28c400dc,0x710000c7}},	//   _азма, ppip, विनि, _уҧса, 
   {{0x7e6402d1,0x00000000,0x00000000,0x00000000}},	//   qpip, --, --, --, 
   {{0xa3cc05d7,0x68340153,0x00000000,0x00000000}},	//   राँ_, _išdy, --, --, 
   {{0x06dc04c5,0xdcec007f,0x09e01677,0x20100337}},	//   _বেলি, _kebč, ројн, onyi_, 
   {{0x67f40038,0x20104485,0x3210010a,0x77980107}},	//   _nájd, nnyi_, znzy_, хкир_, 
   {{0xf9fc0ed9,0x68241ada,0x46640276,0xdb0003b9}},	//   ྐྲུན_, tódr, крэм_, deoç, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa3cc4486,0xb4cc43de,0x682409c2,0x00000000}},	//   रां_, रमे_, ródr, --, 
   {{0x20104487,0xd5bc005f,0xd70400c7,0x00000000}},	//   jnyi_, _šāda_, _изеи, --, 
   {{0x682404d4,0xf3740092,0x93400116,0x38bc0248}},	//   pódr, _ጠንክሮ_, شىسۇ, bárá_, 
   {{0x2010198f,0x34944488,0x00000000,0x00000000}},	//   enyi_, _бакр, --, --, 
   {{0x67f401ed,0x4dd803d4,0x8500178c,0x00000000}},	//   _fájd, ণসমূ, _پوين, --, 
   {{0xa3cc0882,0x81e40154,0x00000000,0x00000000}},	//   राः_, পোল_, --, --, 
   {{0x51840124,0x02a40153,0x00000000,0x00000000}},	// [44d0] _иуна, _крэм, --, --, 
   {{0x20102f99,0x28c402ab,0x0a4402d3,0x4cd80154}},	//   anyi_, विमि, ንእሰያ, _যেগু, 
   {{0xdbc80254,0x4084013d,0x67f4022a,0x6aa801f4}},	//   _lõõs, _куяб, _háje, _spef, 
   {{0x4ea44489,0x6b7400f7,0x00000000,0x00000000}},	//   _ирга, улду, --, --, 
   {{0x3b840046,0x3f1402e8,0xfaf015eb,0xc0d00023}},	//   рліг, _вдяс, يثه_, _ብደሙ_, 
   {{0xc984448a,0xc32000fe,0xf8b80051,0x00000000}},	//   туди, নেকি_, _bsĩ_, --, 
   {{0xb4cc448b,0x6e24016d,0x69240006,0xfce4004e}},	//   रमो_, mohb, ымка, _коёо, 
   {{0x01380375,0x25a801e4,0x680000e2,0x64a4448c}},	//   כרות_, _ŝal_, lēdz, қама, 
   {{0x67f4012c,0x2ee80e14,0x00000000,0x00000000}},	//   _náje, nyaf_, --, --, 
   {{0x60900020,0x7ae4448d,0x6e240477,0xb9940137}},	//   _ዝግጅት_, äite, nohb, _ەلەب, 
   {{0x2408448e,0x20101529,0xd9b003e6,0x00000000}},	//   енни_, ynyi_, _دڕند, --, 
   {{0xa3cc1e61,0x8284448f,0x67f40216,0x6e24016d}},	//   राइ_, ақид, _báje, hohb, 
   {{0xe5a44490,0x27ec1509,0x926001b9,0x00000000}},	//   _били, mken_, یگیم, --, 
   {{0x27ec4491,0xab5c025c,0x020401f0,0x00000000}},	//   lken_, _inżu, рҷон, --, 
   {{0x6e240477,0x201001d3,0x64a400cf,0x74b801ec}},	//   dohb, tnyi_, _сайа, _ауыс_, 
   {{0x95d40131,0x20100083,0xe0442360,0x00000000}},	//   _адәт_, unyi_, унби, --, 
   {{0x27ec4492,0x5d684493,0x28c40d0d,0xe214007b}},	// [44e0] iken_, еизм_, विडि, _مبدع, 
   {{0xdd9014c3,0x20104487,0x9d444494,0xc2c405d9}},	//   صوص_, snyi_, гезд, _ميڊي, 
   {{0x27ec4495,0x67f40316,0x1be812e7,0xa3cc28fe}},	//   kken_, _záje, нджи_, राऊ_, 
   {{0x27ec0460,0x20100007,0xac240845,0x61ec0267}},	//   jken_, qnyi_, афік, lkbl, 
   {{0x9f480254,0x680000ef,0x00000000,0x00000000}},	//   ämäe_, bēdz, --, --, 
   {{0x27ec0936,0x61ec4496,0x3ea0084c,0xdbc8000d}},	//   eken_, nkbl, mtit_, _rõõs, 
   {{0x3ea04497,0xae040184,0x27ec4498,0x00000000}},	//   ltit_, _торҙ, fken_, --, 
   {{0xd6d84499,0x3ea0449a,0xdbc800c5,0x38340e92}},	//   ето_, otit_, _põõs, јнир, 
   {{0xb4cc0a28,0xa3cc084a,0x35f4449b,0x61ec449c}},	//   रम्_, राई_, ипир, kkbl, 
   {{0x27ec449d,0x3ea0449e,0xceb006a9,0x61ec01f5}},	//   aken_, itit_, צית_, jkbl, 
   {{0x2ed0449f,0x3ea044a0,0x27ec44a1,0x9a840116}},	//   _सप्त, htit_, bken_, _шуңл, 
   {{0x3ea044a2,0x27ec44a3,0x07b400c6,0x61ec017a}},	//   ktit_, cken_, _مهمة_, ekbl, 
   {{0x518444a4,0x439411ed,0x3ea00023,0x6e240455}},	//   лува, щаяс, jtit_, yohb, 
   {{0x54e4007b,0xa3cc0118,0x00000000,0x00000000}},	//   _مسبق, राउ_, --, --, 
   {{0x349444a5,0x10140214,0x3ea0083e,0x2ee80042}},	//   _тайр, هبرد, etit_, wyaf_, 
   {{0x3ea044a6,0x087400c8,0x75380219,0x325400f3}},	//   ftit_, טעלט_, _izvz, _квир, 
   {{0x6e9444a7,0x9f4000e4,0x4ea406a6,0xbd4400d1}},	// [44f0] ризу, _hokê_, ырва, ەپلى, 
   {{0x27ec44a8,0x61ec44a9,0xf8b401f9,0x00000000}},	//   zken_, ckbl, ंबाय, --, 
   {{0x3ea044aa,0x2ee831e5,0x27ec3b43,0x320c0de2}},	//   atit_, syaf_, yken_, éeyu_, 
   {{0xa3cc44ab,0x27ec005a,0xbc6800cf,0x6e2403e0}},	//   राए_, xken_, امنن_, sohb, 
   {{0x3ea044ac,0x27ec0165,0x81b80154,0x955c0023}},	//   ctit_, vken_, ছার_, ደስትን_, 
   {{0x4ea400c7,0xaa4444ad,0x00000000,0x00000000}},	//   _ирҳа, шелл, --, --, 
   {{0x27ec44ae,0x28c444af,0x3e180276,0x00000000}},	//   tken_, विधि, _сорэ_, --, 
   {{0x27ec44b0,0xa68444b1,0xe51800bc,0xec240116}},	//   uken_, алид, नअघि_, _ئىرپ, 
   {{0xe61844b2,0xdcec00de,0x29d400ec,0x61ec44b3}},	//   кди_, _iebā, _پياس, ykbl, 
   {{0x28c4194b,0xda6c009f,0x00000000,0x00000000}},	//   विदि, _آڏن_, --, --, 
   {{0x27ec0dd4,0xf7f405d9,0xe7941a4b,0x64a444b4}},	//   pken_, _ڏسند, _ناشک, шана, 
   {{0x3ea00429,0xab5c025c,0x00000000,0x00000000}},	//   ytit_, _dażg, --, --, 
   {{0x3ea0005a,0x00000000,0x00000000,0x00000000}},	//   xtit_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xab5c006d,0x614444b5,0x61ec44b6,0x3c3c00d2}},	//   _każd, рева, rkbl, líve_, 
   {{0x3ea044b7,0x1f6444b8,0x2ae400bc,0xdcec00ef}},	//   ttit_, ркам, कहाँ_, _nebā, 
   {{0x3ea032ff,0xdcec0139,0x75380010,0x2ca00208}},	// [4500] utit_, _bdbğ, _zzvz, ethd_, 
   {{0x527827af,0xa3cc07af,0xdca40395,0x00000000}},	//   _שניא, राक_, иази, --, 
   {{0x3ea044b9,0x9f400023,0x6f1c0381,0xa2bc1a47}},	//   stit_, _kokë_, _exsc, शिक्, 
   {{0x3ea044ba,0x9c24010b,0xd5c0000d,0x00000000}},	//   ptit_, шдед, _वोईज, --, 
   {{0x3ea03209,0x63a000e4,0xb92401e1,0xd9d000d1}},	//   qtit_, _ñonu, _àsẹ_, يەرگ, 
   {{0xded0044e,0x3c3c0332,0xc9a4034f,0x00000000}},	//   _ኩልና_, díve_, ивче_, --, 
   {{0xed3405f5,0x00000000,0x00000000,0x00000000}},	//   _гэтэ, --, --, --, 
   {{0x9f4000e4,0x7dd001e1,0x00000000,0x00000000}},	//   _rokê_, bósà, --, --, 
   {{0x8f9805e1,0x7bc001f7,0x9984010a,0xf8e400fe}},	//   דיפי, _iamu, _кăпш, _কেশৱ_, 
   {{0x7bc044bb,0x880800f1,0x49c400d8,0xdb6402dd}},	//   _hamu, _یعنې_, _клун_, _ﺷﯩﻼﯞ, 
   {{0x1cdc0327,0x9484010b,0x00000000,0x00000000}},	//   ྣའི_, шыпд, --, --, 
   {{0x7bc044bc,0xa3cc1bbb,0xc3200154,0x00000000}},	//   _jamu, राग_, নেছি_, --, 
   {{0x7bc00751,0x46a00024,0x00000000,0x00000000}},	//   _mamu, _мацв, --, --, 
   {{0x7bc044bd,0x1164006c,0x00000000,0x00000000}},	//   _lamu, شلری_, --, --, 
   {{0x661c44be,0x16b429ea,0xded0001f,0x1368004e}},	//   éske, _अनुब, _የዞኑ_, _ишпи_, 
   {{0x7bc044bf,0x741444c0,0xd25844c1,0x4ea4024c}},	//   _namu, _دوبا, _ицо_, ирза, 
   {{0x705444c2,0x6454010f,0x00000000,0x00000000}},	// [4510] _گنجا, ŭzit, --, --, 
   {{0x7bc044c3,0x98bc0139,0x81d4074d,0x00000000}},	//   _aamu, _letı_, _доьх, --, 
   {{0x7bc03182,0x67f40022,0xab5c0327,0x9f4001e1}},	//   _bamu, _lája, _laże, _lokè_, 
   {{0x81b8015b,0xa0202e11,0x63a000c7,0xaa5800d1}},	//   ছাঃ_, _çöpl, _ñont, гиду_, 
   {{0x7bc044c4,0x201c44c5,0x67f400d0,0x00000000}},	//   _damu, étie_, _nája, --, 
   {{0x7bc00381,0x7ae4000d,0x00000000,0x00000000}},	//   _eamu, äita, --, --, 
   {{0x7bc044c6,0x6d54035a,0xb8680063,0xe578010b}},	//   _famu, _igza, ајње_, ңзи_, 
   {{0xe73807a2,0xa6940b3e,0x3c3c1315,0x9988113e}},	//   лей_, број, tíve_, _ەملە_, 
   {{0xf41c03d4,0xaac400ec,0xd5d0150d,0x37380108}},	//   নতাৰ_, _دڪان, तांज, ичью_, 
   {{0x7bc044c7,0x49b81b06,0xe68802dd,0xe69400c7}},	//   _zamu, _جارد_, _ەنشى_, аиҩы, 
   {{0x7bc044c8,0x69c0138f,0xf49444c9,0x3c3c00d7}},	//   _yamu, _iale, оряю, síve_, 
   {{0x69c044ca,0x7bc00694,0x6b980770,0x67f400e4}},	//   _hale, _xamu, ngwg, _fája, 
   {{0x97540302,0x28c416d1,0x7afc06be,0x00000000}},	//   _הינו_, विवि, _ərto, --, 
   {{0x69c044cb,0x2918016b,0x00000000,0x00000000}},	//   _jale, _ɛsan_, --, --, 
   {{0x9f4002d3,0x67f401f1,0xa5080395,0x06dc00eb}},	//   _tokë_, _zája, _щека_, _বইটি, 
   {{0x6d5409a5,0xd00444cc,0xdcfc00d0,0xdcec0356}},	//   _agza, бесе_, tepľ, _lebă, 
   {{0x69c044cd,0x00000000,0x00000000,0x00000000}},	// [4520] _oale, --, --, --, 
   {{0x7bc044ce,0xdcec054e,0x00000000,0x00000000}},	//   _samu, _nebă, --, --, 
   {{0x7bc044cf,0xf1d444d0,0xad5802a9,0x772c0092}},	//   _pamu, दारन, ррух_, _ስድስተ, 
   {{0x6d5444d1,0x69c044d2,0x7bc044d3,0xa3cc0027}},	//   _egza, _aale, _qamu, राट_, 
   {{0x69c044d4,0x7bc005b8,0x644400c0,0x00000000}},	//   _bale, _vamu, imki, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69c00996,0x00000000,0x00000000,0x00000000}},	//   _dale, --, --, --, 
   {{0xb8d0367a,0x7bc005d9,0x9f400699,0x67f444d5}},	//   _ओह_, _uamu, _pokè_, _pája, 
   {{0x69c044d6,0x9f4000e8,0x8c4005c5,0xb78801e0}},	//   _fale, _boké_, _хете, гәһе_, 
   {{0x69c044d7,0xceb00bd4,0x6444017a,0xab5c031c}},	//   _gale, ליח_, emki, _vaże, 
   {{0xddc40024,0xc954007b,0x98bc013d,0xab5c012d}},	//   _atkū, _المش_, _tetı_, _waże, 
   {{0x69c044d8,0x79880857,0x80cc0bae,0x67f43df9}},	//   _zale, _hddw, हिने, _hájn, 
   {{0x69c044d9,0xa3cc00ce,0x35c4059f,0xd018059f}},	//   _yale, राज_, _мадҳ, ҳфа_, 
   {{0x69c044da,0x644444db,0x00000000,0x00000000}},	//   _xale, amki, --, --, 
   {{0xb60800d0,0x04c408f0,0x1b600092,0x00000000}},	//   _vyšľ, _هووي_, ውስትራ, --, 
   {{0xc05801ec,0xacb401d9,0x00000000,0x00000000}},	//   сір_, ۪ماغ, --, --, 
   {{0x798844dc,0xdec01945,0x9f40002e,0x00000000}},	// [4530] _oddw, мәро, _yoké_, --, 
   {{0xd0440cc1,0x4ac4012d,0x0c7402cb,0x00000000}},	//   _əmək, लिसव, مدصد, --, 
   {{0xab7c00a2,0xa3cc05c0,0x0c841e35,0x00000000}},	//   _çöký, राच_, сызм, --, 
   {{0x69c044dd,0x79880c8c,0x6fb4007b,0xefd00240}},	//   _sale, _addw, _بمحا, ቦድያ_, 
   {{0x69c044de,0x67f40306,0x25e801f9,0xab2800d8}},	//   _pale, _bájn, _चकली_, јола_, 
   {{0x69c044df,0x7d2400d2,0x7e600098,0xd7a410eb}},	//   _qale, étsé, _émpa, क्सच, 
   {{0x69c044e0,0xd94044e1,0x684444e2,0x80cc44e3}},	//   _vale, меши, онка, हिये, 
   {{0x79880337,0x6b7444e4,0xac1800f7,0x00000000}},	//   _eddw, _флау, _тобу_, --, 
   {{0x69c044e5,0x6b8844e6,0x9f400208,0xca700133}},	//   _tale, _ideg, _poké_, _رناک, 
   {{0x888044e7,0x69c044e8,0xc0e00023,0x997c0356}},	//   _فیتن, _uale, _ነውሪ_, măşi_, 
   {{0xf2c827af,0x3c3c20d2,0x00000000,0x00000000}},	//   _שע_, líva_, --, --, 
   {{0xa348327c,0x6444058a,0x00000000,0x00000000}},	//   изна_, umki, --, --, 
   {{0x9f400098,0x67f402f0,0xf1d40073,0x3c3c0022}},	//   _toké_, _hájo, दांन, níva_, 
   {{0x6ecc0316,0x3c3c00e4,0x762401ec,0x67f401ef}},	//   सिनु, iíva_, _еміз, _kájo, 
   {{0x6b8844e9,0x630400aa,0xdfd03037,0x67f401e1}},	//   _odeg, _ژوبل, ويس_, _jájo, 
   {{0x6b8844ea,0x67f40306,0x3c3c00e4,0x9f580139}},	//   _ndeg, _májo, kíva_, _äyüp_, 
   {{0x67f401e1,0x9e640214,0x5de002dd,0xddc40055}},	// [4540] _lájo, تازن, _ﺍﻷﻭﺴ, _utkū, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xad6404fb,0x67f401f1,0xd5f8008f,0x69dc44eb}},	//   ساله, _nájo, ספער, पानी, 
   {{0x6b881529,0x06dc0183,0x5ac844ec,0x48b400fe}},	//   _cdeg, _বেছি, илем_, _অপূৰ, 
   {{0x7d2400dd,0x6b8803cb,0x3ea401c7,0x3c3c00e4}},	//   _کہان, _ddeg, _ëmt_, gíva_, 
   {{0x6b8844ed,0x3f8019f5,0x81b800fe,0x67f400e5}},	//   _edeg, laiu_, ছাক_, _bájo, 
   {{0xf8b4000d,0x23c8258d,0x9b940b24,0x6bd410e0}},	//   ंबइय, ियाद, _ولست, تتەر, 
   {{0x67f401e1,0x8c402e9a,0x3f8001ab,0x7674041b}},	//   _dájo, _жесе, naiu_, плиф, 
   {{0x3c3c00e4,0x00000000,0x00000000,0x00000000}},	//   cíva_, --, --, --, 
   {{0x3f8044ee,0xd78800e5,0x6b8844ef,0x00000000}},	//   haiu_, _چناو_, _zdeg, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x926844f0,0xab5c025c,0xd3780798,0x938800d8}},	//   ирга_, _każa, шчо_, јсна_, 
   {{0x246402b5,0x00000000,0x00000000,0x00000000}},	//   _rēme_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xab5c031c,0xd17402dd,0x00000000,0x00000000}},	//   _laża, йыңы, --, --, 
   {{0x6824068f,0x668001b9,0x00000000,0x00000000}},	//   wódz, _تییل, --, --, 
   {{0xb8dc038f,0x8d841411,0xab5c0327,0x84240150}},	// [4550] _ཆར_, قشان, _naża, _تىين, 
   {{0x6b883503,0x506401d9,0xb0f801af,0x00000000}},	//   _sdeg, _واجِ, _геоф_, --, 
   {{0x321044f1,0x31340b16,0x7c8400d8,0x00000000}},	//   mizy_, _хенр, дуче, --, 
   {{0x321044f2,0xab5c44f3,0x3c3c44f4,0x09b007b6}},	//   lizy_, _baża, tíva_, ंज्य, 
   {{0xa96803a6,0x80b42b1b,0x48b400fe,0x00000000}},	//   била_, ুমণ্, _অপেৰ, --, 
   {{0x32100109,0x997c0311,0xf46c001f,0x3c3c20d2}},	//   nizy_, răşi_, ሰብሰብ_, ríva_, 
   {{0x2d8044f5,0x67f401ed,0x997c0311,0x38580006}},	//   mahe_, _fájl, săşi_, орыю_, 
   {{0x2d8044f6,0xd5e001e1,0x24880115,0x997c054e}},	//   lahe_, _atò, _ĉam_, păşi_, 
   {{0x32100851,0x4abc01ad,0x26d800c7,0x6aac0327}},	//   kizy_, _एनिव, ãso_, ħafs, 
   {{0x2d8044f7,0xc9f400c6,0xd704023a,0xddc40139}},	//   nahe_, _بسرع, яные_, _mukş, 
   {{0xab5c012d,0x69dc28fe,0x00000000,0x00000000}},	//   _zaża, पाठी, --, --, 
   {{0x2d8044f8,0x24ac00cc,0x00000000,0x00000000}},	//   hahe_, গিলহ, --, --, 
   {{0x2d8044f9,0x9c800153,0xc79001af,0xc6840244}},	//   kahe_, ėčia, _ерҙы, _بێخن_, 
   {{0x60140598,0x970000d1,0x2d8044fa,0x00000000}},	//   kümä, _سېپى, jahe_, --, 
   {{0xe3c02a15,0xa06844fb,0x3f80026c,0x2d800066}},	//   _alış_, саба_, taiu_, dahe_, 
   {{0x753c0e78,0x53a00137,0xa06801d5,0x9e640816}},	//   ürze, _كۅپك, _қама_, звад, 
   {{0x35d01533,0x442044fc,0x3f8044fd,0x67f402fb}},	// [4560] _थोड़, _iji_, raiu_, _nájm, 
   {{0x62841326,0x2d8044fe,0x614444ff,0x44200098}},	//   msko, gahe_, _непа, _hji_, 
   {{0xe7bc07b6,0x64544500,0x62844501,0x51740375}},	//   ्याप, _kiyi, lsko, _מגיב_, 
   {{0x64544502,0x81b800fe,0x62844503,0x931000f2}},	//   _jiyi, ছাও_, osko, _آویش, 
   {{0x62841225,0x64544504,0x442005d9,0x2d800230}},	//   nsko, _miyi, _mji_, bahe_, 
   {{0x64544505,0x20100cc1,0x62844506,0x2d8004fb}},	//   _liyi, liyi_, isko, cahe_, 
   {{0x44204507,0x628403a2,0x070400c7,0x00000000}},	//   _oji_, hsko, ҧхьи_, --, 
   {{0x44204508,0x64544509,0x2010450a,0x321005da}},	//   _nji_, _niyi, niyi_, zizy_, 
   {{0x62841326,0xfaa4424b,0x95c8450b,0x3c3c0022}},	//   jsko, _تجزی, буна_, lívo_, 
   {{0x62840bb8,0x94f80ad3,0x4420450c,0x64541ced}},	//   dsko, ྒྱའི_, _aji_, _aiyi, 
   {{0x6284450d,0x67f4012c,0xca300150,0x00000000}},	//   esko, _zájm, _ﺭﺍﺠ_, --, 
   {{0x64540083,0x2d800223,0x2010450e,0x00000000}},	//   _ciyi, zahe_, jiyi_, --, 
   {{0x6284450f,0x64544510,0x20100cc1,0x2d804511}},	//   gsko, _diyi, diyi_, yahe_, 
   {{0x442005db,0x64540086,0x201c4512,0xdb000112}},	//   _eji_, _eiyi, étin_, deoü, 
   {{0x2d8008f5,0x20104513,0x321005da,0x69dc2677}},	//   vahe_, fiyi_, rizy_, पाती, 
   {{0x999c02d5,0x64544514,0x20100bd7,0x62844515}},	//   _kitų_, _giyi, giyi_, bsko, 
   {{0x9f400270,0x2d804516,0x628401d3,0x00000000}},	// [4570] _fokí_, tahe_, csko, --, 
   {{0xce30021a,0x1ee84517,0xbb8000d1,0x999c0153}},	//   رواک, غولی_, _ﻧﯩﻤﻪ_, _mitų_, 
   {{0x999c02d5,0x64544518,0x2d804519,0x3c3c00e4}},	//   _litų_, _yiyi, rahe_, gívo_, 
   {{0x645406e4,0x2d801f44,0x20100342,0xd9a80154}},	//   _xiyi, sahe_, ciyi_, _গোলম, 
   {{0x2d800069,0x8234451a,0x2fd8002f,0x2fc800a2}},	//   pahe_, _زریا, _insg_, mdag_, 
   {{0xbc68345f,0x2fc8451b,0x8d8c0020,0xae2000e1}},	//   زمۇن_, ldag_, ሆናቸው_, _मदिन_, 
   {{0x7c2002d2,0x2fc800a3,0xcc840133,0x00000000}},	//   _fjmr, odag_, _رۆشه_, --, 
   {{0x2fc81af3,0x6284451c,0xcbe401c6,0x999c00c0}},	//   ndag_, ysko, _эцги, _bitų_, 
   {{0x6454451d,0x94f8025c,0x3c440953,0x2fc80076}},	//   _riyi, ྒཱའི_, _чэрв, idag_, 
   {{0x2010451e,0x4420020c,0x2fc83bb8,0x00000000}},	//   ziyi_, _sji_, hdag_, --, 
   {{0x2fc8451f,0x20104520,0x64544521,0x39400198}},	//   kdag_, yiyi_, _piyi, ƙisa_, 
   {{0x628405ce,0x2fc80936,0x645407d6,0x201002c4}},	//   tsko, jdag_, _qiyi, xiyi_, 
   {{0xe5a44522,0x64540810,0x62844523,0x67f401d3}},	//   _жили, _viyi, usko, _lájk, 
   {{0x64544524,0x20100bd7,0x2fc80942,0x61440354}},	//   _wiyi, wiyi_, edag_, дега, 
   {{0x62844525,0x64540c11,0x20104526,0x20544527}},	//   ssko, _tiyi, tiyi_, дтар, 
   {{0x62844528,0x2fc84529,0xe2982950,0x00000000}},	//   psko, gdag_, _даи_, --, 
   {{0x2a6c020c,0x2010452a,0xddc4004e,0xe6680092}},	// [4580] _nteb_, riyi_, мбаи, _ተባብሮ_, 
   {{0x2010452b,0x27fc003a,0x5d1403b6,0x2fc801ab}},	//   siyi_, _llwn_, وباز, adag_, 
   {{0x2a6c00a9,0xdb58084c,0x20102ca8,0x00000000}},	//   _ateb_, оюл_, piyi_, --, 
   {{0xab5c068f,0x00000000,0x00000000,0x00000000}},	//   _ważn, --, --, --, 
   {{0xbb341884,0xd12c072d,0x1a280395,0x00000000}},	//   ﺮﯨﻢ_, _ممی_, ожди_, --, 
   {{0xab5c025c,0xdcfc0030,0x1d08452c,0x386c0129}},	//   _fażo, lapč, _деги_, _ptdr_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x1bf0000d,0xebc001af,0x3e64452d,0x00000000}},	//   _अकिल_, _бәшн, _köt_, --, 
   {{0x7e64014b,0x68fc06be,0x00000000,0x00000000}},	//   nqip, _əsdi, --, --, 
   {{0x3e640267,0x2fc801ed,0x94842ff2,0x94a800fb}},	//   _möt_, zdag_, мымд, отма_, 
   {{0x2fc80151,0x246400b0,0xcd940375,0x7e640240}},	//   ydag_, _pēma_, ודית_, hqip, 
   {{0x61fc0010,0x201c3e60,0x00000000,0x00000000}},	//   _alpl, étil_, --, --, 
   {{0xdcfc0100,0x3e643672,0x656c452e,0x867000d4}},	//   dapč, _nöt_, _şahe, _аліє, 
   {{0xd49800f3,0x00000000,0x00000000,0x00000000}},	//   _дри_, --, --, --, 
   {{0x2fc8452f,0x2464005f,0x74f800d1,0x4fc44530}},	//   tdag_, _tēma_, _хейр_, мсаа, 
   {{0x765816cb,0x3e640c86,0x61fc02d0,0x2fc84531}},	//   _hivy, _böt_, _elpl, udag_, 
   {{0x76584532,0x40344533,0x2dd44534,0xeb983052}},	// [4590] _kivy, тетс, нжар, җил_, 
   {{0x2fc84535,0x80cc01ad,0x67f40306,0xfbd0030f}},	//   sdag_, हिशे, _pájk, یتن_, 
   {{0x2a6c0793,0x26cc0e3c,0x2fc84536,0x9f4000c7}},	//   _steb_, zveo_, pdag_, _pokã_, 
   {{0x3e640008,0xca300150,0x00000000,0x00000000}},	//   _föt_, _ﺭﺍﺽ_, --, --, 
   {{0x8d740075,0x3e644537,0xa9684538,0xbb180035}},	//   _ياسا, _göt_, пила_, وزها_, 
   {{0xe738052f,0x76584539,0xa9682c68,0x00000000}},	//   үек_, _nivy, чика_, --, 
   {{0x3e640793,0x58000075,0x78a800b5,0xa8540f14}},	//   _zöt_, گۈنك, _cqdv, нтиј, 
   {{0x3e64005b,0x00000000,0x00000000,0x00000000}},	//   _yöt_, --, --, --, 
   {{0xfb340024,0xc96800f3,0x00000000,0x00000000}},	//   _антэ, _дјед_, --, --, 
   {{0x2328013e,0x656c453a,0x5740236f,0xdcec013a}},	//   ҷоми_, _şahb, ыныб, _nebě, 
   {{0x7658453b,0x67f40241,0x67d40114,0x4ac40118}},	//   _divy, _láji, _пожу, लिकव, 
   {{0x2328016c,0x06b40154,0xf1a800d9,0x00000000}},	//   зоми_, জিবি, _לס_, --, 
   {{0x76580218,0xdcfc0427,0xf770453c,0x00000000}},	//   _fivy, vapč, _ئام_, --, 
   {{0x80cc0574,0x59e002ab,0xe5a4453d,0xd24c03e6}},	//   हिले, पायर, _чики, ینێ_, 
   {{0x60242c71,0x3e64453e,0x7e640784,0x2b1000c5}},	//   едва, _söt_, wqip, _देसु_, 
   {{0x765805c7,0xdee407a5,0x00000000,0x00000000}},	//   _zivy, ноби, --, --, 
   {{0xd0042cc8,0x2264012d,0xe28401d5,0x00000000}},	// [45a0] хете_, ówką_, _ялпи, --, 
   {{0xab5c033f,0x20c40212,0xdee40107,0x81640244}},	//   _inży, _зйом, _ҷоми, _جندۆ, 
   {{0x2720001e,0xdc981c89,0xb5ac009e,0x7e640784}},	//   ỳnh_, яташ_, _কোঁচ, sqip, 
   {{0xdee41638,0x2b10000d,0x00000000,0x00000000}},	//   _зоми, _देहु_, --, --, 
   {{0x67380007,0x7e6420ac,0x3a2000e4,0xdee40798}},	//   _nywj, qqip, éipo_, _џоги, 
   {{0x09e0453f,0x2f1000d1,0x98c42b2e,0xa3bc012d}},	//   лочн, _ئېكر, есил, ुएँ_, 
   {{0x7658033b,0x00000000,0x00000000,0x00000000}},	//   _rivy, --, --, --, 
   {{0x765800ec,0xb8e80490,0x6018007f,0xab68007b}},	//   _sivy, _लई_, lůmb, _يحقق_, 
   {{0xdb0402f6,0x95c80114,0xd6b40451,0xdb140241}},	//   ämän, пуна_, رندڙ_, _àbày, 
   {{0x35f40e92,0x00000000,0x00000000,0x00000000}},	//   тпор, --, --, --, 
   {{0x765817e4,0x69dc4540,0x88ac009e,0x09c402dd}},	//   _vivy, पारी, কিউক, _سۇيۋ_, 
   {{0x388c012c,0x7ae401c7,0xdcec01ef,0x00000000}},	//   měr_, äitw, _sebě, --, 
   {{0xc7d40a7c,0x76580055,0x00000000,0x00000000}},	//   _רודי_, _tivy, --, --, 
   {{0xefbc001f,0x28c400cd,0x41c40108,0x00000000}},	//   _ሳቢያ_, विचि, лёса, --, 
   {{0x1dcc00af,0x00000000,0x00000000,0x00000000}},	//   _होइत, --, --, --, 
   {{0xc0340133,0x68e40108,0x00000000,0x00000000}},	//   ێژێک, ähdi, --, --, 
   {{0xe3c40295,0xfe7011e6,0x518400d8,0x00000000}},	// [45b0] _òñan_, مدل_, _пуна, --, 
   {{0xbd680006,0x00000000,0x00000000,0x00000000}},	//   ерце_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7c9404a9,0xab5c0327,0x4914000d,0x00000000}},	//   اشلا, _tażm, _भइबो_, --, 
   {{0x69dc038e,0xf8b80022,0xbb8406f6,0xa9a40107}},	//   पाली, _apĩ_, الهي, вилд, 
   {{0x9f400270,0x2aa821dd,0x00000000,0x00000000}},	//   _uoká_, rúb_, --, --, 
   {{0x6bc40022,0x3200013a,0x00000000,0x00000000}},	//   _ираҧ, _mlhy_, --, --, 
   {{0xe8c010f7,0xd7ec0116,0x00000000,0x00000000}},	//   _शनीच, قكى_, --, --, 
   {{0x98b00882,0xb8e84541,0x2d9000ef,0xd6a400f2}},	//   āyā_, _लै_, _kdze_, نگوم_, 
   {{0x388c0316,0xdb140241,0x00000000,0x00000000}},	//   běr_, _àbáy, --, --, 
   {{0xa5081d0f,0x201c4542,0xe7b4007b,0x888001d5}},	//   фена_, étik_, _لماد, _ёғил, 
   {{0xe69400c7,0xdef40023,0xf86800ae,0x00000000}},	//   _аиды, _ዉግእ_, _أمني_, --, 
   {{0x65c44543,0xab5c031c,0x2d9000ef,0xb6bc030d}},	//   _абла, _pażj, _odze_, _ницi, 
   {{0x7e600098,0x1a98008f,0xc0e00092,0x00000000}},	//   _émpi, וישע, _ነፍሴ_, --, 
   {{0xdcfc4544,0x24084545,0x320000d0,0x00000000}},	//   kapā, _онки_, _dlhy_, --, 
   {{0x2d90013f,0xca301d00,0x850000e5,0x10a000d8}},	//   _adze_, _ﺭﺍﺱ_, _لوڈن, јитн, 
   {{0x22580427,0xdcfc00cd,0x00000000,0x00000000}},	// [45c0] _tipk_, dapā, --, --, 
   {{0xd1b800f7,0x00000000,0x00000000,0x00000000}},	//   _قاپا_, --, --, --, 
   {{0x60240953,0xe8e405d9,0xa3d4012c,0xc7ac00e8}},	//   _адна, _اڻ_, _सफा_, _ñёw_, 
   {{0x2d900943,0x388c00bc,0x00000000,0x00000000}},	//   _edze_, věr_, --, --, 
   {{0xe7e40c66,0xdd9001d9,0x20000209,0x00000000}},	//   काना_, _پوز_, _ilki_, --, 
   {{0x67f400dd,0x3ea016b8,0x388c0118,0x97e80139}},	//   _máju, muit_, těr_, _ışqı, 
   {{0x3ea04546,0x67f40248,0xda7001d9,0x00000000}},	//   luit_, _láju, _چُر_, --, 
   {{0xc61c0729,0x77940214,0x00000000,0x00000000}},	//   _নীলা_, ایشا, --, --, 
   {{0x3ea04547,0x656c4252,0x20000270,0x00000000}},	//   nuit_, _şaha, _mlki_, --, 
   {{0xa65003e6,0x3ea00076,0xd5b802a9,0x7ae40037}},	//   مێنت, iuit_, фси_, äitu, 
   {{0xf8b815bf,0xca300150,0x00000000,0x00000000}},	//   _чөл_, _ﺭﺍﺀ_, --, --, 
   {{0x63b40076,0x3ea00165,0x06600022,0x65740205}},	//   _cbyn, kuit_, ыҵәҟ, ızha, 
   {{0x51844548,0x3ea04549,0x4394005b,0x46a00064}},	//   кува, juit_, шаяс, _вачв, 
   {{0x3ea02047,0x63b4454a,0x3244454b,0x00000000}},	//   duit_, _ebyn, انسف, --, 
   {{0x3ea03a2a,0x00000000,0x00000000,0x00000000}},	//   euit_, --, --, --, 
   {{0x23a80574,0x3ea0454c,0x9fa40032,0x67f40241}},	//   _कायद, fuit_, лыуҙ, _fáju, 
   {{0x3ea0454d,0xc058454e,0xadb40137,0x4ea402e8}},	// [45d0] guit_, тір_, лбаш, ърва, 
   {{0x63b40118,0x200000ef,0x9258007b,0xa6e00162}},	//   _zbyn, _elki_, _تشعر_, óðig, 
   {{0x23a8038e,0xe7e4454f,0x83344550,0x3ea02ab9}},	//   _कामद, कामा_, _مریض, auit_, 
   {{0x3ea04551,0xc0e0044e,0xab5c003d,0x00000000}},	//   buit_, _ነፍሲ_, _każi, --, 
   {{0x3ea04552,0xfee4036b,0xfb340105,0x00000000}},	//   cuit_, _кўрм, анцэ, --, 
   {{0x692401b9,0x00000000,0x00000000,0x00000000}},	//   лмла, --, --, --, 
   {{0x200013bb,0x8bc44553,0x5fa80b98,0xdb00000d}},	//   _ylki_, _исад, ङ्कल, deoõ, 
   {{0xac7400f1,0xdd980117,0x00000000,0x00000000}},	//   _لاړش, _ошӣ_, --, --, 
   {{0x48dc012c,0x7ae401f4,0x00000000,0x00000000}},	//   _कपको_, äitt, --, --, 
   {{0xa5c401e1,0x57441411,0xab5c025c,0x66680023}},	//   _gbọ́, ызым_, _nażi, _ተባሂላ_, 
   {{0x3ea04554,0x638400d8,0x00000000,0x00000000}},	//   zuit_, лгна, --, --, 
   {{0xe2984555,0x1cb8031c,0x9878008f,0x3c3c00d0}},	//   нам_, མྦི_, _נאנט, tívi_, 
   {{0xab5c003d,0x3ea00393,0x3160002f,0xd1e80092}},	//   _bażi, xuit_, _bghz_, _ዘሮች_, 
   {{0xa0a40323,0x3ea000cf,0x00000000,0x00000000}},	//   лагд, vuit_, --, --, 
   {{0x1fb44556,0xdb000036,0x00000000,0x00000000}},	//   лсар, tgoë, --, --, 
   {{0x3ea04557,0xf5240cef,0xe3b000c6,0x307413b5}},	//   tuit_, _әфән, _طرب_, рурс, 
   {{0xc0500020,0xab5c025c,0x5fa816d1,0x3ea0003a}},	// [45e0] _በእርግ, _fażi, ङ्गल, uuit_, 
   {{0x1d084558,0x5d844559,0xb2140108,0x00000000}},	//   нези_, الال, _вьющ, --, 
   {{0x3ea0455a,0xab5c0135,0xd5f8010f,0x00000000}},	//   suit_, _każw, עפער, --, 
   {{0x63a4455b,0x3ea0455c,0xdd900050,0x9e64455d}},	//   ngkn, puit_, _گوس_, _ماسن, 
   {{0x3ea0455e,0x00000000,0x00000000,0x00000000}},	//   quit_, --, --, --, 
   {{0xdd90455f,0x83f0016b,0x656c4560,0x00000000}},	//   _دوس_, _biɑk, _şahn, --, 
   {{0x67f401f1,0x491400cd,0x00000000,0x00000000}},	//   _nájs, _भेदो_, --, --, 
   {{0x57a44561,0x7ae44562,0x00000000,0x00000000}},	//   ушка, äits, --, --, 
   {{0xa944052f,0x199400f3,0x00000000,0x00000000}},	//   лдәһ, _бјер, --, --, 
   {{0xdcfc0356,0x09e001af,0x00000000,0x00000000}},	//   capă, _лоун, --, --, 
   {{0x1cb80156,0xce340375,0x9f5408a5,0x00000000}},	//   མསི_, ראית_, _ágæt_, --, 
   {{0x660c03a2,0x59e0076e,0xf434010b,0x45444563}},	//   _ïakn, पावर, ремэ, ычым_, 
   {{0xa3d40d5f,0x85002a9f,0x00000000,0x00000000}},	//   _सफर_, لوین, --, --, 
   {{0xded00936,0x00000000,0x00000000,0x00000000}},	//   _ue당_, --, --, --, 
   {{0xfe34063f,0x158c0150,0x00000000,0x00000000}},	//   ọọts_, _ﻛﯘﺗﯩ, --, --, 
   {{0x12e40212,0xa9e000dc,0x74144564,0x00000000}},	//   _біог, _गच्छ_, _خوبا, --, 
   {{0xe7e413f5,0x67f40419,0x00000000,0x00000000}},	// [45f0] काता_, _zájs, --, --, 
   {{0x272007ae,0x00000000,0x00000000,0x00000000}},	//   ẳng_, --, --, --, 
   {{0x61f800af,0x2bc81414,0x00000000,0x00000000}},	//   ötle, _रसदा, --, --, 
   {{0x41740244,0x2f48004e,0x00000000,0x00000000}},	//   _پایس, _үпүп_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc984009d,0x00000000,0x00000000,0x00000000}},	//   ууди, --, --, --, 
   {{0xa3d41092,0x7ae404e6,0xfb0000ef,0x00000000}},	//   _सफल_, äitr, _šūts_, --, 
   {{0xe7383826,0xe8880208,0x00000000,0x00000000}},	//   кей_, rẻ_, --, --, 
   {{0x57e44565,0x16604566,0x158c0150,0x00000000}},	//   рдым_, овым, _ﻛﯘﺑﯩ, --, 
   {{0x24640374,0xba5400d8,0x06b400eb,0x00000000}},	//   _hēmi_, _гвуј, জিলি, --, 
   {{0x246400b0,0x36e8113e,0x7ae400df,0x00000000}},	//   _kēmi_, _ەرىپ_, ĥite, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf770168d,0x27ec4567,0x63a40158,0xe6100133}},	//   _ران_, mjen_, rgkn, _وشت_, 
   {{0x6f0c4568,0xb9240124,0xffa430ab,0x569800df}},	//   dzac, _resẽ_, өлгү, _יינצ, 
   {{0xa0342033,0xa0684569,0x2de40150,0x64a4001b}},	//   لىست, таба_, _ﺍﻷﻋﻤ, _тайа, 
   {{0x27ec456a,0x6e240399,0xb9240022,0xfe78456b}},	//   njen_, enhb, _pesẽ_, лүм_, 
   {{0xd00c00c6,0x27ec282c,0x5d6801af,0xb4240736}},	// [4600] ذلك_, ijen_, визм_, _دعوو, 
   {{0x27ec02d3,0x88a8009e,0x00000000,0x00000000}},	//   hjen_, _খননক, --, --, 
   {{0x27ec456c,0xfb180014,0x8d60003b,0x5f740066}},	//   kjen_, گراں_, івце, _پاجر, 
   {{0x27ec0003,0x9f4001e1,0xfcd80023,0xa3bc0037}},	//   jjen_, _mokú_, _ጭብጢ_, ुएट_, 
   {{0x27ec456d,0x6f0c033f,0x7ad4007b,0x50180a7c}},	//   djen_, czac, إقتص, _יוטו, 
   {{0xc9a40063,0x61ec007c,0x986400e5,0x00000000}},	//   авље_, njbl, لیئے_, --, 
   {{0x9c580ce8,0x27ec0200,0x00000000,0x00000000}},	//   _ашау_, fjen_, --, --, 
   {{0x27ec456e,0xd6d84316,0x3c3c0030,0x960c03ce}},	//   gjen_, вто_, tívu_, ाफ्ट_, 
   {{0xddc400b8,0x58d00150,0x00000000,0x00000000}},	//   _nukū, соқт, --, --, 
   {{0xe8380316,0xceb00302,0x7b08456f,0x395800d7}},	//   ější, קית_, ırtı, _úrso_, 
   {{0x2dd81a4c,0x6f0c4570,0x27ec0b21,0x3c3c13d5}},	//   אַרב, zzac, bjen_, sívu_, 
   {{0xdb000ba1,0x27ec4571,0x6f0c012d,0xb78812b9}},	//   ngoï, cjen_, yzac, _сәке_, 
   {{0x9f500108,0x6e240051,0xfbd800cc,0x53444572}},	//   nkyä_, ynhb, _থকাত, рхна, 
   {{0xddc400b8,0x05d001d9,0x54640640,0x79884573}},	//   _dukū, _وٲنج, _књиз, _jedw, 
   {{0x79884574,0x94844575,0x50642b2d,0x78bc01e3}},	//   _medw, _тылд, ртга, _ärvd, 
   {{0x6f0c0372,0x79884576,0x80cc0490,0x44040124}},	//   tzac, _ledw, हिजे, _мчыб, 
   {{0xc3300131,0x3ef80276,0x662400e4,0x79880142}},	// [4610] _يەپ_, антэ_, _ñukã, _oedw, 
   {{0x7988014b,0x6f0c4577,0x27ec4578,0xb638037e}},	//   _nedw, rzac, zjen_, _ｄｏ_, 
   {{0x201c0137,0x27ec02f6,0x6f0c4579,0x4338141d}},	//   ètic_, yjen_, szac, _مسیج_, 
   {{0x798802d0,0x7c9400f2,0x00000000,0x00000000}},	//   _aedw, زشما, --, --, 
   {{0x7988457a,0x656c3bc1,0x27ec457b,0xe7e413f7}},	//   _bedw, _şahm, vjen_, कासा_, 
   {{0x798803cb,0x00000000,0x00000000,0x00000000}},	//   _cedw, --, --, --, 
   {{0x27ec069c,0x2900457c,0x88800d73,0x7988457d}},	//   tjen_, áha_, زیشن, _dedw, 
   {{0x7988127b,0x7e600098,0xa684457e,0x60d801bf}},	//   _eedw, _émpr, блид, åtmi, 
   {{0x27ec457f,0x29000f8b,0x79880042,0x00000000}},	//   rjen_, šha_, _fedw, --, 
   {{0x27ec4580,0x79884581,0x6b884582,0x6008010b}},	//   sjen_, _gedw, _heeg, _iýme, 
   {{0x6b88007d,0x27ec4583,0xddc40006,0xab5c031c}},	//   _keeg, pjen_, _sukū, _vażu, 
   {{0x27ec02d3,0x6b884584,0xa6c810ed,0x240801d5}},	//   qjen_, _jeeg, _موصل_, унми_, 
   {{0x6b884585,0x79881cdf,0x9f4001e1,0xefe80023}},	//   _meeg, _yedw, _wokú_, _ዘሎዋ_, 
   {{0x6b881574,0xc4cc0011,0xe7e41d94,0x660400cf}},	//   _leeg, িমবঙ, कावा_, _ыпла, 
   {{0x61444586,0x00000000,0x00000000,0x00000000}},	//   сева, --, --, --, 
   {{0x1f644587,0x9f50005b,0x78bc01e3,0xaf7800d4}},	//   скам, ykyä_, _ärve, исує_, 
   {{0xc214016b,0x62900030,0x60081427,0x9f400248}},	// [4620] _atɔe_, ýkoľ, _nýme, _yokù_, 
   {{0x6b880421,0x3cf400bc,0x00000000,0x00000000}},	//   _aeeg, ंहले_, --, --, 
   {{0x6b884588,0x59ac0490,0xefe802d3,0x201c0098}},	//   _beeg, _घाबर, _ዘሎዉ_, étis_, 
   {{0x44d400a8,0x6b884589,0x798802e2,0x66000175}},	//   _mă_, _ceeg, _sedw, hklk, 
   {{0x6b881990,0x3f80458a,0x7988458b,0xeb340023}},	//   _deeg, mbiu_, _pedw, _እናገለ, 
   {{0x3ea0458c,0x38c8458d,0x3f800153,0x9f50005b}},	//   mrit_, لابی_, lbiu_, rkyä_, 
   {{0x7d241973,0x246404fe,0x6b88458e,0x60080432}},	//   _بہان, _kēmu_, _feeg, _eýme, 
   {{0x3ea0458f,0x79881cdf,0x6b884590,0x984801e0}},	//   orit_, _wedw, _geeg, ыяла_, 
   {{0x3ea04591,0x3f8000d8,0x9b04010b,0xa3bc121d}},	//   nrit_, ibiu_, _узад, ीजन_, 
   {{0x7988009a,0x6b884592,0x44d4054e,0x3ea04593}},	//   _uedw, _zeeg, _bă_, irit_, 
   {{0x44d41142,0x89d80302,0xd7a800b2,0x6b884594}},	//   _că_, _תחבי, _مٿان_, _yeeg, 
   {{0x44d4084c,0x38c804d3,0xefe802d3,0xccf00375}},	//   _dă_, _ماڵی_, _ዘሎዎ_, לכת_, 
   {{0xb59418f4,0xfd540882,0xe7e43c74,0xd90c4595}},	//   _дилш, rveṣ, कारा_, _زیک_, 
   {{0x3ea04596,0x44d40276,0x8488010c,0x069c00d1}},	//   drit_, _fă_, _መሰሉን_, _ﺋﻪﻣﯩ, 
   {{0x3ea04597,0x61f801e6,0x741403e6,0xefe80240}},	//   erit_, ötla, _ووتا, _ዘሎው_, 
   {{0x3ea04598,0x44f0005e,0xf1ac16d1,0x938801f0}},	//   frit_, _ءسوز, ञ्जन, _сска_, 
   {{0x6b884599,0x3ea0459a,0x69dc0134,0x74d00b02}},	// [4630] _reeg, grit_, _ɔseb, धिकृ, 
   {{0x6b88459b,0xa2d401ad,0x00000000,0x00000000}},	//   _seeg, यटर्, --, --, 
   {{0x3ea0459c,0x6b88459d,0x3f8008e5,0xb03410fc}},	//   arit_, _peeg, bbiu_, _мнош, 
   {{0x3ea0459e,0x82940133,0xca300150,0xc0e00240}},	//   brit_, _بگێڕ, _ﺭﺍﺝ_, _ነፍሒ_, 
   {{0x3ea0459f,0x6b8845a0,0xada401ec,0x00000000}},	//   crit_, _veeg, _қаңл, --, 
   {{0x6ce415fa,0x6b8845a1,0x600801a2,0xf1ac00dc}},	//   _وړان, _weeg, _výme, ञ्चन, 
   {{0xe7e413b4,0x9f40007f,0x6b8845a2,0xdd0c00ac}},	//   काला_, _ankè_, _teeg, mışa, 
   {{0xdd0c07c4,0x2d800013,0x44d40356,0x5ea000db}},	//   lışa, lbhe_, _ră_, _رۅۅل, 
   {{0x44d41142,0xe3c40295,0xfb84010a,0x779045a3}},	//   _să_, _òñin_, _хысн, ریوا, 
   {{0x3f8045a4,0x848802d3,0x069000dd,0xdd0c45a5}},	//   zbiu_, _መሰልን_, _ہاتھ, nışa, 
   {{0xa3e845a6,0x25dc0574,0x18b0035b,0x2d801cf8}},	//   адна_, _कोणी_, _жәыр, ibhe_, 
   {{0x44d400a8,0x3ea01368,0x73740124,0x00000000}},	//   _vă_, yrit_, зырх, --, 
   {{0x26c80214,0xdd0c0790,0x672c0010,0xe75802dd}},	//   _خطای_, kışa, _žajf, _тиді_, 
   {{0x3ea045a7,0xa3d80c2e,0xf74815f2,0x26dc0099}},	//   vrit_, _डोर_, _الهي_, _irwo_, 
   {{0x3ea000ad,0xdb1001d3,0x00000000,0x00000000}},	//   writ_, ágút, --, --, 
   {{0x3ea045a8,0x273c001f,0x5f042519,0x25dc000d}},	//   trit_, _አሳስበ, озба, _कोती_, 
   {{0x3f8045a9,0x3ea045aa,0xd0040a83,0x1754010f}},	// [4640] rbiu_, urit_, цете_, ַסער_, 
   {{0x3ea045ab,0x644445ac,0x62941446,0x6144013e}},	//   rrit_, llki, _ivyo, _мепа, 
   {{0x2464005f,0x644445ad,0x3ea045ae,0x9d4402e8}},	//   _tēmu_, olki, srit_, цежд, 
   {{0xdee445af,0x3ea045b0,0x26dc04ba,0xda7845b1}},	//   _доми, prit_, _orwo_, аяк_, 
   {{0x6444058a,0x1cdc0327,0x6d403bb6,0xd6ac00cc}},	//   ilki, ལའང_, _ølan, _কনভয, 
   {{0x0e6000d1,0x19f401d9,0x3958032e,0x00000000}},	//   _окян, تِتھ_, _úrsk_, --, 
   {{0x23a80574,0x2b4c0165,0x26dc45b2,0xdcb00131}},	//   _कांद, _ezec_, _arwo_, _تىز_, 
   {{0x6c742386,0x6294009f,0x00000000,0x00000000}},	//   _хурх, _ovyo, --, --, 
   {{0xc6f445b3,0x6444058a,0x00000000,0x00000000}},	//   жных_, dlki, --, --, 
   {{0x6444058a,0xe7440166,0x00000000,0x00000000}},	//   elki, чүче_, --, --, 
   {{0x629445b4,0x00000000,0x00000000,0x00000000}},	//   _avyo, --, --, --, 
   {{0x54800092,0x59e0041c,0x00000000,0x00000000}},	//   _የደረቅ_, पाकर, --, --, 
   {{0x93440597,0xf0e826a2,0xd62845b5,0xd6d800f2}},	//   تخدم, ڭىزى_, _коде_, _خوشش_, 
   {{0x72040597,0x644401d9,0xd6300014,0x41e401ce}},	//   أوسم, alki, _تِتھ, міса, 
   {{0x386c02fb,0xcf8800fd,0xac6c0092,0x00000000}},	//   _judr_, исад_, ስቶስም_, --, 
   {{0x386c0122,0x753c0112,0xd37801f0,0xb62401ec}},	//   _mudr_, ürzu, _тчк_, _ﺭﻁ_, 
   {{0x656c0c07,0xfe7045b6,0x823405d9,0x4dcc2b1b}},	// [4650] _şahi, ندل_, _ڪريا, রাসং, 
   {{0xc2f405ac,0x2b4c0210,0x00000000,0x00000000}},	//   _চেকি_, _rzec_, --, --, 
   {{0xdd0c0bcc,0x2d8045b7,0x82b80327,0x8234216b}},	//   rışa, rbhe_, _བདོའ, _تريا, 
   {{0xf8e400e1,0x62940022,0x80e0000d,0x00000000}},	//   _कपड़ा_, _yvyo, _पछतइ, --, 
   {{0xde442dcd,0x0dc8084c,0xcb180120,0xdd0c0b97}},	//   _کیلو_, _куви_, јќе_, pışa, 
   {{0x24500122,0x28b80597,0x386c015d,0xdcec0024}},	//   máme_, مطبخ_, _budr_, _nebė, 
   {{0x644445b8,0x245002fd,0xf9681de6,0x00000000}},	//   ylki, láme_, әрәй_, --, 
   {{0xbcb40306,0x2fc845b9,0xa68400d1,0x00000000}},	//   žším, neag_, плид, --, 
   {{0xe61845ba,0x82b8003d,0x245045bb,0xd90c01d3}},	//   йди_, _བདེའ, náme_, نیے_, 
   {{0x97303321,0x386c0042,0x2fc845bc,0x644445bd}},	//   رکنا, _fudr_, heag_, wlki, 
   {{0x245045be,0xa9a400fb,0x00000000,0x00000000}},	//   háme_, _миҡд, --, --, 
   {{0x245002fb,0x2a6c04e6,0x88c0009e,0x64440009}},	//   káme_, _kueb_, ্মদক, ulki, 
   {{0x66e41171,0x26dc0516,0x83f0013b,0x2fc801ab}},	//   _хола, _urwo_, _biɑr, deag_, 
   {{0x24500232,0xdcec0006,0x3d1c0073,0x00000000}},	//   dáme_, _gebė, _मधले_, --, 
   {{0x6008010e,0x753c0e78,0x9660003b,0x1540014b}},	//   _aýma, ürzt, _якше, _пешм, 
   {{0x2fc805e4,0x24500118,0x00000000,0x00000000}},	//   geag_, fáme_, --, --, 
   {{0x83f0016b,0xfd6800e4,0x00000000,0x00000000}},	// [4660] _wiɑs, mesẽ, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2fc801c3,0x614407d5,0x00000000,0x00000000}},	//   beag_, _хена, --, --, 
   {{0x26cc0770,0x25dc2982,0x2fc8054e,0x00000000}},	//   kweo_, _कोसी_, ceag_, --, 
   {{0xc0c000b7,0x1a6402f2,0x386c0055,0x8d8c01ec}},	//   ስፖራ_, سیای_, _sudr_, _ﺟﯘﺭﺕ_, 
   {{0xceb00bd4,0x386c013a,0x90700244,0x00000000}},	//   _איש_, _pudr_, _تهێش, --, 
   {{0xa3bc45bf,0x588402f1,0x2bdc0950,0x00000000}},	//   ीजा_, чыла, _नोवा, --, 
   {{0x4c980375,0x00000000,0x00000000,0x00000000}},	//   _לבלו, --, --, --, 
   {{0x25dc012c,0xb6f800d1,0x00000000,0x00000000}},	//   _कोही_, زىدا_, --, --, 
   {{0x9f4003a0,0x2a6445c0,0x14c8005b,0x6abc0139}},	//   _hokó_, _gilb_, быми_, _äsfa, 
   {{0x26d80267,0x00000000,0x00000000,0x00000000}},	//   åsor_, --, --, --, 
   {{0xddcc01d3,0x00000000,0x00000000,0x00000000}},	//   _mibő, --, --, --, 
   {{0xa3bc033f,0x518445c1,0xdcec0153,0xa920032e}},	//   ीज़_, зуба, _tebė, _óþre, 
   {{0x59280003,0x24500316,0x656c03e3,0x6008013a}},	//   _སྨོས_, váme_, _şahv, _rýma, 
   {{0x7bc00393,0x2fc801c3,0x41540063,0x3cf8012d}},	//   _obmu, teag_, еврс, ूनों_, 
   {{0x764808fb,0x24500308,0x13680108,0xf2100210}},	//   lldy, táme_, _ушки_, डोज़_, 
   {{0x2fc845c2,0x2dd43004,0x76480076,0xd1c800f3}},	// [4670] reag_, мжар, oldy, _лунд_, 
   {{0x7bc00083,0x24500122,0x2a6c0369,0x2bf8015b}},	//   _abmu, ráme_, _rueb_, _আগেই_, 
   {{0x2a6c0098,0x7ae045c3,0x00000000,0x00000000}},	//   _sueb_, _armt, --, --, 
   {{0x2a640036,0xb05400ec,0x245000d7,0x7d5400db}},	//   _silb_, _آھست, páme_, رئلئ, 
   {{0x78b8010a,0xa96845c4,0xeaf800bc,0x60080432}},	//   etvv, оила_, ्नेत_, _uýma, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7ae00c8c,0x06b400fe,0x00000000,0x00000000}},	//   _ermt, জিছি, --, --, 
   {{0x2a6c0428,0x7ae045c5,0x49b8029e,0x18640395}},	//   _tueb_, _frmt, _گارد_, мащи_, 
   {{0x672c0427,0xaa840014,0x671c023e,0xfc30007b}},	//   _žajb, _کۆڈم_, _बेशक_, _صحف_, 
   {{0x49b80502,0x25dc012c,0x43c40131,0xe57000ae}},	//   _دارد_, _कोशी_, ﯨﺴﯩﺪ, خطة_, 
   {{0x69c045c6,0x00000000,0x00000000,0x00000000}},	//   _ible, --, --, --, 
   {{0xe824034c,0x25dc02ab,0x7648062c,0x9f4001e1}},	//   _غذای, _कोरी_, aldy, _mokò_, 
   {{0x656c0356,0xfd680022,0xf6500133,0xf3640108}},	//   _şahu, resẽ, _ڵئه_, етён, 
   {{0xa0680fcb,0xe7e445c7,0x64a445c8,0xa50845c9}},	//   жава_, काका_, _жака, _мела_, 
   {{0x69c045ca,0x7ae401c7,0x00000000,0x00000000}},	//   _mble, äitz, --, --, 
   {{0xe3b00127,0x232801a9,0x00000000,0x00000000}},	//   _شرب_, _мойи_, --, --, 
   {{0x442045cb,0x69c00216,0xc0ec0092,0xff2445cc}},	// [4680] _imi_, _oble, _ቅደም_, ربری, 
   {{0x442045cd,0x68e00c8c,0xc6880092,0x00000000}},	//   _hmi_, _orld, _ማተሚያ_, --, 
   {{0x44201c06,0x9b6845ce,0x2bc8033f,0xa13445cf}},	//   _kmi_, ошла_, _रसखा, _زردش, 
   {{0x69c045d0,0x1b4800c7,0x00000000,0x00000000}},	//   _able, озеи_, --, --, 
   {{0x442045d1,0xa3d40b27,0x764845d2,0x00000000}},	//   _mmi_, _हसन_, yldy, --, 
   {{0x69c01529,0x09e002e8,0x00000000,0x00000000}},	//   _cble, кочн, --, --, 
   {{0x442045d3,0x6454016b,0x69c00036,0x3e840241}},	//   _omi_, _ohyi, _dble, _fétò_, 
   {{0x69c045d4,0x442045d5,0x6454013b,0x23a80490}},	//   _eble, _nmi_, _nhyi, _कागद, 
   {{0x7c2000a3,0x65c400d1,0x95c801f4,0x00000000}},	//   _immr, ﯩﻴﯩﻠ, оуна_, --, 
   {{0x442045d6,0x64540134,0x75d445d7,0x89a400ee}},	//   _ami_, _ahyi, ريجا, _окув_, 
   {{0xd5e00241,0x3dd80368,0x44202238,0x25dc0073}},	//   _awọ, _marw_, _bmi_, _कोळी_, 
   {{0x69c00010,0x656c45d8,0x00000000,0x00000000}},	//   _zble, _şaht, --, --, 
   {{0x442045d9,0x64440055,0x00000000,0x00000000}},	//   _dmi_, _īhit, --, --, 
   {{0x442045da,0x3494011b,0x6454013f,0x69c005b1}},	//   _emi_, _закр, _ehyi, _xble, 
   {{0x442045db,0x44f0004b,0xdcec0171,0x693401ef}},	//   _fmi_, _لسيز, _debī, _třeť, 
   {{0x4420058e,0x600801ef,0x741400f2,0x00000000}},	//   _gmi_, _dýmo, _سوخا, --, 
   {{0xcdd80640,0x84240372,0x6008010e,0x3dd8012d}},	// [4690] жње_, _جىين, _iýml, _barw_, 
   {{0x9f400100,0x3dd8015d,0xedd4007b,0x4420022e}},	//   _pokò_, _carw_, عياد, _zmi_, 
   {{0x3dd80142,0x442000c7,0x550c0037,0x999c01ef}},	//   _darw_, _ymi_, ानिए_, _aktů_, 
   {{0xcfa80014,0x69c004cc,0x44200334,0x62a80327}},	//   _بادم_, _sble, _xmi_, żpoż, 
   {{0x82341060,0x3dd845dc,0x2fd80e89,0x491400e1}},	//   _سریا, _farw_, _iasg_, _भेजो_, 
   {{0x3dd803cb,0x2d840432,0x00000000,0x00000000}},	//   _garw_, _ýle_, --, --, 
   {{0xd94045dd,0xda6007d8,0x24500022,0x00000000}},	//   леши, ывши, háma_, --, 
   {{0x2d9001c4,0xc60400dc,0x6e240098,0x24500022}},	//   _heze_, षस्य_, lihb, káma_, 
   {{0x442045de,0xdaa00131,0x68e00076,0x2fd80142}},	//   _rmi_, _مەنپ, _wrld, _masg_, 
   {{0x442045df,0x645445e0,0x88c402dd,0x69c045e1}},	//   _smi_, _shyi, _يتال, _uble, 
   {{0x442045e2,0x656c45e3,0x2d9045e4,0x68e00175}},	//   _pmi_, _şahs, _meze_, _urld, 
   {{0x2d9045e5,0x442045e6,0x5928031c,0x2c000183}},	//   _leze_, _qmi_, _སྨིས_, লোৰে_, 
   {{0xb3b03323,0xe5a445e7,0xddc445e8,0x249c001f}},	//   _झारख, _зили, _lukš, _ቀደምት_, 
   {{0x2d9045e9,0x2fd80142,0x48c0015b,0x00000000}},	//   _neze_, _aasg_, ্মীর, --, 
   {{0x645445ea,0x2038001f,0x7e600066,0x2fd8015d}},	//   _thyi, _የዴሞክ, _èmpi, _basg_, 
   {{0x442003a5,0x2fd808c2,0x82e40124,0x68e4023a}},	//   _umi_, _casg_, _абиҧ, ähdy, 
   {{0xddc40953,0xd24c00b2,0x2fd803cb,0x2c000183}},	// [46a0] _aukš, _ڏني_, _dasg_, লোৱে_, 
   {{0x20100796,0x27fc0204,0x7c20037e,0x60080118}},	//   shyi_, _lown_, _smmr, _týmo, 
   {{0x2d9045eb,0xfce0044e,0x61fc00b5,0x32040790}},	//   _deze_, _ሓደጋ_, _iopl, ölye_, 
   {{0x2d90017a,0xf00000fb,0x00000000,0x00000000}},	//   _eeze_, _күси, --, --, 
   {{0xd12c0502,0x3dd8015d,0x1768010b,0x00000000}},	//   _نمی_, _tarw_, үрип_, --, 
   {{0x4a5000d4,0x00000000,0x00000000,0x00000000}},	//   гкіс, --, --, --, 
   {{0x787c00e4,0x245001d3,0x63b4012d,0x00000000}},	//   _oĩve, záma_, _ocyn, --, 
   {{0x61fc047e,0x245000d2,0x2d9045ec,0x00000000}},	//   _lopl, yáma_, _zeze_, --, 
   {{0x87e009fe,0x27fc45ed,0x2d9045ee,0x61fc127b}},	//   ующе, _down_, _yeze_, _oopl, 
   {{0x61fc45ef,0x656c45d8,0x4b2000d8,0x5ec800eb}},	//   _nopl, _şahr, _смув, রিপে, 
   {{0xab5c0327,0x32f0016b,0x57a401af,0x00000000}},	//   _ibża, mɑyɛ_, _зшла, --, 
   {{0x893402e4,0x27fc0f85,0xf48404f2,0x245000c7}},	//   _ארבע_, _gown_, _یابی, táma_, 
   {{0x61fc1798,0x8c1802e4,0x0ecc0456,0x6b8c03f2}},	//   _bopl, לוטי, _सैंड, ðagi, 
   {{0xd4980209,0x245045f0,0x45d0022e,0x00000000}},	//   _ери_, ráma_, _бошс, --, 
   {{0x61fc076f,0xc0c845f1,0x27fc0280,0xe7e40073}},	//   _dopl, нуте_, _yown_, काचा_, 
   {{0x660c03a2,0x61fc14dc,0x4dd400f1,0x24500022}},	//   _ïakr, _eopl, کترس, páma_, 
   {{0x40341c22,0x61fc06d9,0x2d9045f2,0xa3d80cb4}},	// [46b0] уетс, _fopl, _peze_, _डोट_, 
   {{0x2fd800a9,0x61fc45f3,0xddc40010,0x00000000}},	//   _wasg_, _gopl, _pukš, --, 
   {{0x2d9045f4,0x463800c8,0x2fd845f5,0x661c007f}},	//   _veze_, לעמע, _tasg_, èski, 
   {{0x2d200574,0x2d90000f,0xddc4107d,0x1ea800ec}},	//   _मधील_, _weze_, _vukš, _ڪاٽي_, 
   {{0x27fc0042,0x6e24047e,0x0a68035b,0x00000000}},	//   _rown_, pihb, чреи_, --, 
   {{0x27fc232c,0xddc4005f,0xaa4445f6,0x692401b9}},	//   _sown_, _tukš, ъелл, кмла, 
   {{0x6b74334a,0x27fc0ac5,0x290045f7,0x00000000}},	//   _албу, _pown_, âha_, --, 
   {{0x6d5445f8,0x4ab0013d,0x15c80150,0xf8e445f9}},	//   _izza, _бөкр, _ﺒﻤﻨﻬ, اسوپ, 
   {{0x32f0013f,0xeb9804a9,0x7c380129,0xe738035b}},	//   bɑyɛ_, _ниң_, évre, ьеи_, 
   {{0xfbd045fa,0xd5e00022,0xe47445fb,0x00000000}},	//   _پتہ_, ажьи, кумэ, --, 
   {{0x61fc45fc,0x64a445fd,0xc5d000eb,0x00000000}},	//   _ropl, ъана, ়ালপ, --, 
   {{0x61fc45fe,0x2328013e,0xc7a80220,0xe3b01095}},	//   _sopl, доми_, _ءدال_, جرد_, 
   {{0x22b40134,0x00000000,0x00000000,0x00000000}},	//   _kɛkɛ_, --, --, --, 
   {{0x9f40006a,0xa11445ff,0x61fc100f,0xe4c403c5}},	//   _kokö_, پورت, _qopl, _айки, 
   {{0x1fb4074d,0xb76401e0,0x614414b3,0x00000000}},	//   ксар, _итәй, тева, --, 
   {{0x63b40b6f,0x9f4000e4,0x6e340200,0x93c00356}},	//   _ucyn, _mokö_, _ajzb, şări, 
   {{0x1f644600,0x6d544601,0x00000000,0x00000000}},	// [46c0] ткам, _azza, --, --, 
   {{0x62840af9,0x600802f0,0x61fc005c,0x00000000}},	//   mpko, _kýmk, _uopl, --, 
   {{0xdcb00075,0x62844602,0xba8000d1,0x245000e4}},	//   شىش_, lpko, ﻧﺪﻩﻙ_, námo_, 
   {{0x6598001f,0x8f640e8e,0xe1b007f7,0x628401f5}},	//   _መጠበቅ_, رمەك_, _जाँघ, opko, 
   {{0x6d540a49,0xdbdc0248,0x0b40013d,0x00000000}},	//   _ezza, _bíòb, анцн, --, 
   {{0x95980023,0x62840254,0x00000000,0x00000000}},	//   ዋታትን_, ipko, --, --, 
   {{0xed340276,0x245000c7,0x00000000,0x00000000}},	//   _бэтэ, jámo_, --, --, 
   {{0x9f50010b,0x00000000,0x00000000,0x00000000}},	//   lkyñ_, --, --, --, 
   {{0x5a6400c7,0x15a80801,0x644402b1,0xe1b0012d}},	//   _акаб, мъни_, _īhip, _जांघ, 
   {{0x35f44603,0x069c00d1,0x6d5400a2,0x9e540150}},	//   упор, _ﺋﻪﻗﯩ, _yzza, нтiз, 
   {{0xa8a40a98,0x62844604,0x00000000,0x00000000}},	//   _مصنو, epko, --, --, 
   {{0x3c3c0030,0x60080118,0x4c98010f,0xb7d84605}},	//   tívy_, _dýmk, ושטע, _سوتا_, 
   {{0x25b44606,0xb46400d1,0xb6c4013d,0x00000000}},	//   åblå_, ккүл, _сөйд, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9f4000c7,0x62840af9,0x00000000,0x00000000}},	//   _mokõ_, apko, --, --, 
   {{0x2258005a,0x72d40117,0xc03400d8,0x00000000}},	//   _ehpk_, _боиф, ансј, --, 
   {{0xdcfc4607,0xd258030d,0x1dc0009d,0x00000000}},	// [46d0] kapē, _оцо_, өөрн, --, 
   {{0xcd28158b,0xd24c00ec,0x91e001ee,0x00000000}},	//   وسان_, _ڏنڊ_, _тәмһ, --, 
   {{0x7998007f,0xa7fc01d3,0xa9a401d5,0x00000000}},	//   davw, lműe, ҳилд, --, 
   {{0xeb38010b,0xab5c012d,0x90400345,0x00000000}},	//   нзеш_, _zaży, _ئۆره, --, 
   {{0x41c008ec,0x394c0363,0x6250037e,0xa9a44608}},	//   श्वस, _ayds_, kæol, гилд, 
   {{0x7c5810a8,0x201c005f,0x684002d3,0x2b900051}},	//   ىلەر_, ītie_, _ኣባላት, ạc_, 
   {{0xac180063,0x6d5402d0,0x98a01422,0x61e802d2}},	//   _зову_, _uzza, бище, _ófle, 
   {{0xd7ec04a9,0x5b1023c9,0x6d5802a8,0x6008032e}},	//   ككى_, рмәт, ƙwab, _rýmk, 
   {{0x98bc0006,0xbb844609,0x270c0892,0x00000000}},	//   _rytą_, _خلقي, िनेर_, --, 
   {{0x32000232,0xdb040158,0x6b98460a,0x49900244}},	//   _nohy_, åmån, lawg, _ئیغر, 
   {{0x49440006,0x00000000,0x00000000,0x00000000}},	//   _рэаб, --, --, --, 
   {{0x22580240,0x4424460b,0x6b980327,0x00000000}},	//   _shpk_, òm_, nawg, --, 
   {{0x2bc405ba,0x32000118,0x00000000,0x00000000}},	//   ळ्या, _bohy_, --, --, 
   {{0x600800ee,0x6b980009,0x00000000,0x00000000}},	//   _iými, hawg, --, --, 
   {{0xc44801b9,0x2b48033f,0x9fc8460c,0x1dc40118}},	//   _لیدن_, żach_, нгва_, र्फत, 
   {{0x6284460d,0xfe78086c,0x6304460e,0x7998007f}},	//   ppko, күм_, _موبل, zavw, 
   {{0x6444460f,0x32000170,0x6b9801d9,0x5438008f}},	// [46e0] moki, _fohy_, dawg, _רעפא, 
   {{0xdb0c003e,0xe0d8009b,0x00000000,0x00000000}},	//   _édég, _зво_, --, --, 
   {{0x61f84610,0x787c0022,0x6444010a,0x5ba841e5}},	//   ötlu, _oĩva, ooki, екем_, 
   {{0xcaec01d9,0x0ecc1533,0x320006d9,0x7b8402dd}},	//   चमंड_, _सैकड, _zohy_, рғад, 
   {{0x2000020c,0x5f0407d6,0xfe780139,0xd1480023}},	//   _ioki_, _ёзга, _рүз_, _መስተው, 
   {{0x20001243,0x64444611,0xcebc0118,0x5f741a90}},	//   _hoki_, hoki, ěřte_, _جاگر, 
   {{0x20004612,0x64444613,0xdcfc00b0,0x6b98058a}},	//   _koki_, koki, rapē, bawg, 
   {{0xb8cc4614,0xc8c412e3,0x20004615,0x64444616}},	//   _कट_, اوين_, _joki_, joki, 
   {{0x64444617,0x20004618,0x00000000,0x00000000}},	//   doki, _moki_, --, --, 
   {{0x200003c1,0x94844619,0xd5b8461a,0x00000000}},	//   _loki_, лымд, хси_, --, 
   {{0x6444461b,0x32000851,0x7434461c,0x1dc41944}},	//   foki, _rohy_, иноф, र्यत, 
   {{0x2000461d,0x6444461e,0xb4d402ab,0x386008c2}},	//   _noki_, goki, _हनी_, _òir_, 
   {{0x32000109,0x613001d3,0x245000d1,0x00000000}},	//   _pohy_, yűlé, غچىس, --, 
   {{0xd574461f,0x07f400c7,0x1dc400dc,0x00000000}},	//   _судь, _ахәы_, र्मत, --, 
   {{0x64444620,0x20004621,0x25dc0be7,0x4fc401c6}},	//   boki, _boki_, _कोटी_, лсаа, 
   {{0x64444622,0x20000286,0xb2742d3c,0x00000000}},	//   coki, _coki_, _клиш, --, 
   {{0xc0580046,0x320005da,0x00000000,0x00000000}},	// [46f0] уір_, _tohy_, --, --, 
   {{0xc0c002d3,0xdbdc032e,0x7094014b,0x00000000}},	//   _ድሒሩ_, _síðb, _каоф, --, 
   {{0x20000924,0xda840023,0x00000000,0x00000000}},	//   _foki_, _ዝሰፈኖ_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3ec4012c,0x6b98058a,0x8aa44623,0xbea40064}},	//   ěstí_, rawg, уред, _лаўк, 
   {{0x64444624,0x20002aac,0x60081d1d,0x6b980142}},	//   zoki, _zoki_, _rými, sawg, 
   {{0x2000006c,0x64444625,0x9f4002f6,0xab9402bf}},	//   _yoki_, yoki, _enkä_, _вибі, 
   {{0x64444626,0x2000022e,0xa8044627,0x00000000}},	//   xoki, _xoki_, рзил, --, 
   {{0x64444628,0xe634040e,0x00000000,0x00000000}},	//   voki, ихоэ, --, --, 
   {{0x64440083,0x78c801e3,0xe39401ec,0x00000000}},	//   woki, åsvä, _ﻛﯩﻴﻢ_, --, 
   {{0x3a641e24,0x00000000,0x00000000,0x00000000}},	//   _اُلف, --, --, --, 
   {{0xe3644629,0x60080030,0x98780677,0x00000000}},	//   икни, _tými, _סאנט, --, 
   {{0x2000462a,0x9340005b,0x87041867,0x00000000}},	//   _roki_, жняе, _حبال, --, 
   {{0x20002173,0x00000000,0x00000000,0x00000000}},	//   _soki_, --, --, --, 
   {{0x6444462b,0x2000462c,0xdfd040c7,0x9100462d}},	//   poki, _poki_, ييس_, опре, 
   {{0x9f84462e,0x644401f0,0x47a40154,0x5ec80154}},	//   ргад, qoki, ক্রী, রিসে, 
   {{0x2000462f,0x5ea44630,0x21a40352,0xe8e400ec}},	// [4700] _voki_, شمال, _кипм, _کڻ_, 
   {{0x6350001f,0x3cf400bc,0x00000000,0x00000000}},	//   መዘገበ, ूहले_, --, --, 
   {{0x20000924,0x1c440e92,0x201c0066,0x63500092}},	//   _toki_, анжм, ètis_, _ማስጠበ, 
   {{0x1c440108,0xed580116,0x00000000,0x00000000}},	//   шнем, ھشەت_, --, --, 
   {{0x9e6403e6,0xda644631,0x8b203cc5,0x3f804632}},	//   _ناسن, авди, одце, mciu_, 
   {{0x3f804633,0x6b8c01a8,0x9c84007b,0x00000000}},	//   lciu_, ðagr, _نشره, --, 
   {{0x3ea04634,0xd7f800ee,0x6c3000e5,0x8bd80171}},	//   lsit_, вуп_, _کہنا, _šķūņ, 
   {{0x3f804635,0x960c10dc,0x9d440107,0x3ea04636}},	//   nciu_, िस्ट_, _беҳд, osit_, 
   {{0x3ea04637,0x1dc400dc,0x3f800153,0xcb6400d8}},	//   nsit_, र्थत, iciu_, _вате_, 
   {{0x9a6837f4,0x3ea04638,0xf7540092,0x655000ec}},	//   _شمال_, isit_, _ዋናውን, ڻھوء, 
   {{0xdc8c067d,0x3f8001f1,0xd944147e,0x3ea00200}},	//   _ዝነበረ_, kciu_, _тежи, hsit_, 
   {{0x3ea04639,0x1dc40882,0x661c034c,0x245000ae}},	//   ksit_, र्तत, èskr, námh_, 
   {{0xfbe002f5,0x850000f1,0x3ea00200,0x00000000}},	//   ণাপত, موین, jsit_, --, 
   {{0x3f80463a,0x3ea00200,0x061400cf,0x00000000}},	//   eciu_, dsit_, _ۅزۉب_, --, 
   {{0x7648463b,0x3ea0463c,0x775802d3,0x00000000}},	//   mody, esit_, _ወታሃደ, --, 
   {{0x7648463d,0x3ea00200,0xdcfc0064,0x00000000}},	//   lody, fsit_, lapė, --, 
   {{0x3ea0463e,0x787c00c7,0xc7d40375,0x8d74007b}},	// [4710] gsit_, _oĩvo, סומי_, لاضا, 
   {{0x7648463f,0x201c00b0,0x8d844640,0xbe1800d4}},	//   nody, ītia_, руад, ажує_, 
   {{0x3ea04641,0x201c02b5,0x00000000,0x00000000}},	//   asit_, ūtia_, --, --, 
   {{0x3f800ba3,0x37ac00bd,0x76484642,0x3ea0003a}},	//   cciu_, ক্তর, hody, bsit_, 
   {{0x76484643,0x3ea000dd,0x8c4000a2,0x00000000}},	//   kody, csit_, _üşme, --, 
   {{0x91b800dc,0xfa040451,0x29100139,0x00000000}},	//   श्चै, يونٽ, _üzak_, --, 
   {{0x2d804644,0x7c841188,0x8ec000f1,0xbd6800f3}},	//   mche_, _муте, _دښځو, _врте_, 
   {{0x01384645,0x2d804646,0x3cf402f0,0x00000000}},	//   ירות_, lche_, ňavá_, --, 
   {{0x6f0c4647,0x764837ae,0x2d8024a6,0x2ca001bf}},	//   nyac, fody, oche_, lshd_, 
   {{0x2d804648,0x76484649,0x00000000,0x00000000}},	//   nche_, gody, --, --, 
   {{0x2d80464a,0x3f80033f,0xa4440137,0x6934009d}},	//   iche_, yciu_, йнод, _унжу, 
   {{0x3ea0464b,0x6f0c0986,0x2d80464c,0xdc8c0023}},	//   ysit_, kyac, hche_, _ዝነብረ_, 
   {{0x7648464d,0x245020c0,0x6f0c464e,0x3ea0464f}},	//   body, námi_, jyac, xsit_, 
   {{0x76484650,0x6f0c4651,0x2d804652,0xdb0c004a}},	//   cody, dyac, jche_, édéc, 
   {{0xa0341473,0x62240131,0x2d804653,0xe29010e8}},	//   مىست, لىڭل, dche_, _کذب_, 
   {{0x3ea04654,0x2d800d16,0x6f0c0205,0x41c4000d}},	//   tsit_, eche_, fyac, _लउकस, 
   {{0x3f804655,0x3ea04656,0x98bc00bc,0xaf48007b}},	// [4720] rciu_, usit_, _bytě_, لشكل_, 
   {{0x3f802b1d,0x3ea04657,0x9d441df9,0x600802d2}},	//   sciu_, rsit_, безд, _rýmu, 
   {{0x3ea04658,0x3f804659,0x00000000,0x00000000}},	//   ssit_, pciu_, --, --, 
   {{0x3ea0465a,0x2d80465b,0x6f0c0789,0x6d580198}},	//   psit_, ache_, byac, ƙwan, 
   {{0x6f0c465c,0x3ea00200,0x00000000,0x00000000}},	//   cyac, qsit_, --, --, 
   {{0x2d80465d,0x5dd400f7,0x527800df,0x00000000}},	//   cche_, _уюму, אנסא, --, 
   {{0x1cb0025c,0xc8c4015e,0x26dc0419,0xf2c400dc}},	//   _དའི_, موون_, _aswo_, _लङ्घ, 
   {{0x3754001f,0xeb740064,0x00000000,0x00000000}},	//   _ምስክሮ, _дыфэ, --, --, 
   {{0x26dc03a2,0x6294015d,0x00000000,0x00000000}},	//   _cswo_, _nwyo, --, --, 
   {{0x26dc0649,0x00000000,0x00000000,0x00000000}},	//   _dswo_, --, --, --, 
   {{0x76480953,0xf8ac0c2e,0xd7e400d4,0x9f500108}},	//   rody, _घटिय, _гіло, ljyä_, 
   {{0x6f0c0c09,0x83841164,0x00000000,0x00000000}},	//   yyac, зыре, --, --, 
   {{0x2d80465e,0x62940399,0x60dc465f,0x14d80490}},	//   yche_, _cwyo, _aspm, _बनवण, 
   {{0xf8dc0abd,0xa7fc002d,0x62940142,0x34940153}},	//   _मनाय, nműn, _dwyo, _дакр, 
   {{0x6f0c058a,0x94844660,0x00000000,0x00000000}},	//   wyac, _уылд, --, --, 
   {{0x50641220,0xac78001f,0xb4d400e1,0x1dc40dba}},	//   стга, _እነሱም_, हबी_, र्सत, 
   {{0x4dcc1c82,0x00000000,0x00000000,0x00000000}},	// [4730] ৰাসং, --, --, --, 
   {{0x2d804661,0x6f0c4662,0x69dc013f,0x245000c7}},	//   uche_, ryac, _ɔses, vámi_, 
   {{0x2d804663,0x6f0c4664,0x03dc0c58,0x656c0213}},	//   rche_, syac, ধাৰণ, _şahz, 
   {{0x2d804665,0x6f0c4666,0x7c880023,0xbe88030d}},	//   sche_, pyac, ምህላው_, _ӳссе_, 
   {{0x2fc813ce,0x4f644667,0x6f0c0309,0x1dc44668}},	//   mfag_, _دادف, qyac, र्हत, 
   {{0x2fc8168c,0x80a403e6,0x00000000,0x00000000}},	//   lfag_, _بمێن, --, --, 
   {{0x600801f1,0x2fc8003e,0xde4400f1,0xe8180798}},	//   _týmt, ofag_, _بیلو_, ициј_, 
   {{0xa6844669,0x7c84466a,0x00000000,0x00000000}},	//   олид, _хуре, --, --, 
   {{0xe618466b,0xe73824ce,0x1dc441ac,0xd70434d8}},	//   иди_, реп_, र्वत, жные_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x5ac40135,0x2fc803cd,0x13380092,0x00000000}},	//   _གདོམ, kfag_, _ያስገነ, --, 
   {{0xd15c1772,0xe3980063,0xd88400e5,0x85c000e5}},	//   _ተስፋን_, шњој_, _بھون_, _کےدو, 
   {{0xe5a4466c,0x2fc8383d,0x363401d3,0x00000000}},	//   _дили, dfag_, _کرنس, --, 
   {{0x25680228,0xd24c00e3,0xda78010f,0x95e40137}},	//   _калп_, َنَ_, ינשר, _وينۇ, 
   {{0x15400724,0x2054001f,0x216802e8,0x30740137}},	//   _оешм, _ለዴሞክ, риви_, зуус, 
   {{0xdfd016a2,0x81c8005f,0x00000000,0x00000000}},	//   بير_, _spēļ, --, --, 
   {{0x80dc466d,0xfd7800e5,0x61e808a5,0x21744130}},	// [4740] _पनवे, مشاں_, _óflo, _мунр, 
   {{0x656c09a5,0x20100589,0x6d5802a8,0x39400a9d}},	//   _şahy, skyi_, ƙwal, şisi_, 
   {{0xe7d805f9,0x5e840014,0x1dc400cd,0x00000000}},	//   ढ़ाप, _ڈٔجم, र्षत, --, 
   {{0x20e8008f,0xf5380115,0x9f400200,0x00000000}},	//   _iĝi_, naĥa_, _jakë_, --, 
   {{0x6b8c009d,0x00000000,0x00000000,0x00000000}},	//   ñaga, --, --, --, 
   {{0xa3a81d68,0x00000000,0x00000000,0x00000000}},	//   गृत_, --, --, --, 
   {{0x660c0649,0xdca4466e,0x2450466f,0x00000000}},	//   _ïaky, _фаби, lámu_, --, 
   {{0x99a40227,0x00000000,0x00000000,0x00000000}},	//   _ńuńt_, --, --, --, 
   {{0xdcfc4670,0x482000f7,0x2af400c0,0x00000000}},	//   kapī, بىيق, _няфё, --, 
   {{0x82e80327,0xd624007b,0x7bc00051,0xaa6401ee}},	//   _སླེའ, تعبي, _hcmu, _етєк, 
   {{0xd7f81ed2,0x39580008,0x37ac015b,0xdc380213}},	//   _вул_, _árs_, ক্ষর, lçıs, 
   {{0x38c803e6,0x970000d1,0xbb3800d1,0x00000000}},	//   _ناڵی_, _يېغى, ﮔﯜﻥ_, --, 
   {{0x7bc04671,0xc2b802bf,0x01e40eac,0xd90c02f2}},	//   _mcmu, оляє_, মানদ, _سیک_, 
   {{0x15e007f7,0x2d980150,0x00000000,0x00000000}},	//   _कोचर_, _ﺘﺩﻋﻰ_, --, --, 
   {{0xcf984672,0xc0bc0020,0x2fc84673,0x3a2c0789}},	//   ија_, _ሲባል_, tfag_, _mmdp_, 
   {{0xdc384674,0x3a2c0064,0x00000000,0x00000000}},	//   kçıs, _lmdp_, --, --, 
   {{0x2fc813ce,0xd1c80117,0x00000000,0x00000000}},	// [4750] rfag_, _кунд_, --, --, 
   {{0x2fc84675,0x9f400100,0x77501ef7,0xdc382b24}},	//   sfag_, _makè_, _ሚንስተ, dçıs, 
   {{0x7ae0035a,0x9f40007f,0xccf80114,0x00000000}},	//   _asmt, _lakè_, шћа_, --, 
   {{0x29180882,0xbc180212,0x4ad40014,0xdbd4340f}},	//   _āsa_, жіші_, قاتھ_, jääd, 
   {{0x7ccc00da,0xa3ac1cd2,0xac5801a9,0x00000000}},	//   vērš, _ओएस_, _ҳавф_, --, 
   {{0xf53801e4,0xd6c000eb,0x00000000,0x00000000}},	//   zaĥa_, ্টায, --, --, 
   {{0xa9684676,0x7ae003ac,0xdcec003d,0x00000000}},	//   щика_, _esmt, _rebħ, --, 
   {{0xe73801e0,0xb8641e5a,0x00000000,0x00000000}},	//   йей_, وايو, --, --, 
   {{0x3a2c022e,0xac78001f,0x2b580332,0x00000000}},	//   _fmdp_, _እነሆም_, _ásc_, --, 
   {{0xba7431f0,0x78b804ba,0xe29800c7,0x00000000}},	//   _قالت, buvv, ҩан_, --, 
   {{0x888001b9,0x6d5400a2,0x9f40036e,0xf3e400fe}},	//   _ўғил, _jyza, _pakë_, গানৰ_, 
   {{0x888000dd,0x6d540200,0x00000000,0x00000000}},	//   _ٹیکن, _myza, --, --, 
   {{0xc8b401e0,0xe6884677,0x73740124,0x00000000}},	//   _ысҡы, _انتى_, дырх, --, 
   {{0xd24c04d3,0x3f840327,0x00000000,0x00000000}},	//   ێنێ_, _żmu_, --, --, 
   {{0x69c04678,0xe3b00597,0x6d54010b,0xaf300092}},	//   _mcle, _كرة_, _nyza, _በመለወ, 
   {{0x9f400418,0x1e842e36,0x00000000,0x00000000}},	//   _haké_, злам, --, --, 
   {{0x6d5428e5,0x69c002d0,0xf8b81b76,0xdbcc03e0}},	// [4760] _ayza, _ocle, _इम्प, _hıçk, 
   {{0x9f400316,0x245002fb,0xdbcc013d,0x3d1800bc}},	//   _jaké_, rámu_, _kıçk, पनले_, 
   {{0x9f403386,0x00000000,0x00000000,0x00000000}},	//   _maké_, --, --, --, 
   {{0x69c005d5,0xdc383535,0x6d540432,0x9f042586}},	//   _acle, tçıs, _dyza, _فوجو, 
   {{0x91dc03d4,0x00000000,0x00000000,0x00000000}},	//   মাৰ্, --, --, --, 
   {{0xdd904679,0xdca4467a,0x672c01e4,0x78b80083}},	//   _سور_, _наги, _ɾajt, tuvv, 
   {{0xdb0029d3,0x6d54010b,0x88e00798,0xdc3808a9}},	//   rgoñ, _gyza, ежје, sçıs, 
   {{0x9f40033b,0x68e000d8,0xa528031c,0x78b801b9}},	//   _pakè_, _dsld, _སྟེག_, ruvv, 
   {{0xc6f4467b,0x5ec800bd,0x8c4006bb,0xd6d81b74}},	//   зных_, রিকে, _чете, ёти_, 
   {{0xe9f00124,0x69c0007b,0xdbd4005b,0x00000000}},	//   _аҧшы, _gcle, sääd, --, 
   {{0x78b801d5,0xdbd401f4,0x00000000,0x00000000}},	//   quvv, pääd, --, --, 
   {{0x43941e76,0x00000000,0x00000000,0x00000000}},	//   наюс, --, --, --, 
   {{0xaa800209,0x69c0127b,0xf62800db,0x00000000}},	//   _üýtg, _ycle, _وتتۇ_, --, 
   {{0xbbc800bc,0x69c00419,0xe73800ec,0x00000000}},	//   रभुक, _xcle, _بيهڪ_, --, 
   {{0xa3a808f2,0x3134014b,0x95e40137,0x8658011a}},	//   गृह_, февр, _ويچۇ, _הדגי, 
   {{0xd3d800c6,0x63a00115,0x85540375,0x6d54467c}},	//   _طبعا_, _ĵong, _משוב_, _ryza, 
   {{0x984c467d,0x02a402d5,0x6d54467e,0x5184030d}},	// [4770] nğın_, _прэм, _syza, _нуна, 
   {{0xf53800df,0x6d5400d7,0xbf3401f4,0x00000000}},	//   naĥo_, _pyza, хнущ, --, 
   {{0x6b8c005a,0xaab0012d,0xb0e0000d,0x5ec800eb}},	//   ñago, ुंभक, _पनिग, রিগে, 
   {{0x69c0467f,0x7988057b,0x0d980032,0x6d544680}},	//   _scle, _afdw, ртҡы_, _vyza, 
   {{0x3f6806ed,0x69c00205,0xcee8132f,0x526802dd}},	//   _ниџо_, _pcle, _ارجن_, _ﺳﻮﯕﯩ, 
   {{0x2d84033d,0x5ec80154,0x00000000,0x00000000}},	//   _üle_, রিখে, --, --, 
   {{0x248801fa,0x58d00798,0x00000000,0x00000000}},	//   _čamo_, војт, --, --, 
   {{0xd7ec192c,0x9f400ffb,0xdbcc0166,0x00000000}},	//   لكى_, _saké_, _rıçk, --, 
   {{0x9f400c6a,0x49c80107,0x00000000,0x00000000}},	//   _paké_, _гуем_, --, --, 
   {{0xa5280135,0x7b7400c6,0x0904010b,0x6aa8127b}},	//   _སྟུག_, _أطفا, _нчем, _ivef, 
   {{0xc8644681,0xa50800f3,0xf8b021ef,0x00000000}},	//   _етди, цена_, _مةن_, --, 
   {{0xa714026a,0x78bc0158,0x798802d0,0x6aa808a5}},	//   _одељ, _årva, _zfdw, _kvef, 
   {{0x9f40038e,0x39404682,0x62500393,0xf53801e4}},	//   _také_, şist_, dæor, baĥo_, 
   {{0x754801ed,0xdbcc0166,0x20c800f1,0x00000000}},	//   épzé, _tıçk, يبزي_, --, 
   {{0x6b884683,0xd58404d3,0x203c02d3,0xd92c0092}},	//   _ofeg, _تێپه_, _የብለይ, _እንደዋ, 
   {{0x6aa802d0,0xa2bc1cba,0x00000000,0x00000000}},	//   _ovef, वंद्, --, --, 
   {{0x5de401c0,0x0ba02440,0x93404684,0xbec40055}},	// [4780] мжаа, ወዳደር_, _инъе, _śūbh, 
   {{0x6b880e26,0xe0d831e2,0x8ecc0154,0x847c0023}},	//   _afeg, _дво_, রিংগ, _ፕረስን_, 
   {{0x61444685,0x6aa84686,0x216821fa,0x9be400d4}},	//   _цена, _avef, _фини_, ділк, 
   {{0xd5cc0208,0x27e80051,0xad644687,0x00000000}},	//   _nềng_, _óanh_, راله, --, 
   {{0x798802d0,0x00000000,0x00000000,0x00000000}},	//   _pfdw, --, --, --, 
   {{0x6b8802e3,0xd9184132,0x09e0026a,0x2a640208}},	//   _efeg, жьи_, вољн, _chlb_, 
   {{0xa3bc4688,0xb7880166,0x00000000,0x00000000}},	//   आला_, пәле_, --, --, 
   {{0x2eec0010,0xff380092,0x00000000,0x00000000}},	//   _šefi_, _በመስመ, --, --, 
   {{0xb6f80075,0xd6d800d6,0x248c016b,0x656c01e4}},	//   سىدا_, іти_, ɔmmɔ_, _ĝaha, 
   {{0x83f0016b,0x78a8037e,0x47d80eac,0xd1c00092}},	//   _nkɑb, _tvdv, ভাগী, ቻቸት_, 
   {{0x6aa80099,0x5ec80154,0xcdb4011a,0x00000000}},	//   _zvef, রিটে, ופיה_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x43940640,0x5184004e,0x61c81a75,0x00000000}},	//   ђарс, дуба, िभूष, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x101403e6,0x00000000,0x00000000,0x00000000}},	//   وبرد, --, --, --, 
   {{0x21284689,0x23c402a0,0x00000000,0x00000000}},	//   سيقی_, _वायद, --, --, 
   {{0x80a00574,0xeeb81a71,0x00000000,0x00000000}},	// [4790] गीबे, ялаш_, --, --, 
   {{0xc2082abb,0x6b88468a,0x6250003a,0x00000000}},	//   _يقين_, _sfeg, sæor, --, 
   {{0x29180cc1,0x82341c36,0x6aa80008,0x7c84468b}},	//   _əsas_, _جريا, _svef, вуче, 
   {{0xe0d0008f,0x5ec80154,0x00000000,0x00000000}},	//   _גײט_, রিজে, --, --, 
   {{0x0f502099,0x8aa40a5b,0x09c00022,0x00000000}},	//   _شکرگ, фред, валҟ, --, 
   {{0x2ac4468c,0x00000000,0x00000000,0x00000000}},	//   _җәдв, --, --, --, 
   {{0x8bc4468d,0x3b640050,0x00000000,0x00000000}},	//   _осад, _یێمہ, --, --, 
   {{0x7d242580,0xa6e43752,0x6aa80334,0xe5780107}},	//   _شفقن, ежил, _tvef, ӯзи_, 
   {{0x1dc42e1e,0xeb9804a9,0x7c38004a,0xdedc0023}},	//   र्कत, _миң_, èvre, _ዓቐን_, 
   {{0xe3b0468e,0x81d400cc,0x201c02e2,0x7d240432}},	//   گرد_, _সোন_, ètiz_, _öwsü, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9d18011a,0xc6d001ec,0x00000000,0x00000000}},	//   פורט, _аскө, --, --, 
   {{0xf60804d3,0xdeec010c,0xddcc01ef,0x00000000}},	//   ستیه_, ቆብን_, _libš, --, 
   {{0x9f4001e1,0x55e007a5,0x00000000,0x00000000}},	//   _onkò_, _бошб, --, --, 
   {{0x25a4468f,0xa0684690,0xa6bc0154,0xe04402e8}},	//   mall_, зава_, ্টওয়, енви, 
   {{0x25a44691,0xd4640108,0x00000000,0x00000000}},	//   lall_, _пище_, --, --, 
   {{0x9f400d29,0x63a44692,0x30744693,0x9e64011c}},	// [47a0] _ankò_, makn, турс, евад, 
   {{0x63a44694,0x25a44695,0x44200457,0x78480118}},	//   lakn, nall_, _hli_, měve, 
   {{0x44204696,0x1dc44697,0x25a40076,0x22840208}},	//   _kli_, र्गत, iall_, _hôk_, 
   {{0x63a44698,0x44200076,0xca440150,0xe3b000eb}},	//   nakn, _jli_, _ﺅﺜﺭ_, ট্রব, 
   {{0x25a44699,0x628406be,0x00000000,0x00000000}},	//   kall_, nqko, --, --, 
   {{0x63a4469a,0x25a4469b,0x998c0118,0xd8e4030d}},	//   hakn, jall_, rifů_, ецип, 
   {{0x4420469c,0x25a4469d,0x6454013f,0xf8b00f00}},	//   _oli_, dall_, _okyi, شکا_, 
   {{0x63a4469e,0x81d400bd,0xd5c00034,0x4420469f}},	//   jakn, _সোম_, _शाहज, _nli_, 
   {{0x25a446a0,0x63a446a1,0x09bc015b,0x9f4000e4}},	//   fall_, dakn, _ইসরা, _hakâ_, 
   {{0xceb00d65,0x25a446a2,0x6454013b,0x78bc33b8}},	//   נית_, gall_, _akyi, _årvo, 
   {{0x44204374,0x62840327,0x2a340153,0x00000000}},	//   _bli_, eqko, _рэтр, --, 
   {{0x63a446a3,0x00000000,0x00000000,0x00000000}},	//   gakn, --, --, --, 
   {{0x25a446a4,0x442000a3,0x56f00116,0xc68c00ec}},	//   ball_, _dli_, _сүпс, _هِن_, 
   {{0x442046a5,0x645446a6,0x68ec033f,0x41e4109a}},	//   _eli_, _ekyi, łade, ліса, 
   {{0x442046a7,0x63a446a8,0x50640261,0x00000000}},	//   _fli_, bakn, етаа, --, 
   {{0x4420156b,0x63a446a9,0xa35001f2,0x2ca4032e}},	//   _gli_, cakn, ọkọt, _ældi_, 
   {{0x5fe00490,0x00000000,0x00000000,0x00000000}},	// [47b0] _पसरल, --, --, --, 
   {{0xaab0146b,0xa2d80d2e,0x00000000,0x00000000}},	//   ुंसक, _पैट्, --, --, 
   {{0x09bc0d42,0x44200664,0x6ad80574,0x7dc4028e}},	//   _ইসলা, _yli_, णब्र, اقمن, 
   {{0x44200381,0xef1000f7,0x2eec46aa,0x75280064}},	//   _xli_, _күбө, _šefu_, izdz, 
   {{0x1fc82158,0x25a42679,0x3b8401ec,0x4af000c7}},	//   _লোকস, yall_, уліг, ыҟау, 
   {{0x7c20007c,0x25a40036,0x63a446ab,0x00000000}},	//   _elmr, xall_, zakn, --, 
   {{0x25a446ac,0x63a446ad,0x999c0024,0x8d7446ae}},	//   vall_, yakn, _aktų_, _ساسا, 
   {{0x25a446af,0xe944036b,0x752800e2,0x00000000}},	//   wall_, _یرای, dzdz, --, 
   {{0x25a446b0,0xa7641621,0x63a446b1,0xb62002d3}},	//   tall_, ъкид, vakn, _ስለዝዀ, 
   {{0x2284002d,0x9f4000c7,0x63a406fd,0x85040116}},	//   _rôk_, _hakã_, wakn, едоң_, 
   {{0x63a4041a,0x3a080b43,0x00000000,0x00000000}},	//   takn, _سکوی_, --, --, 
   {{0x66b446b2,0x25a401c7,0x4420011c,0x9f4001e1}},	//   _абду, sall_, _qli_, _sakí_, 
   {{0x27ec46b3,0x9f400589,0x3774010a,0x00000000}},	//   mden_, _makã_, _йышс, --, 
   {{0x63a446b4,0x27ec46b5,0x216822bf,0x1fb801ad}},	//   sakn, lden_, диги_, इल्ड, 
   {{0x63a432b4,0x205446b6,0x442046b7,0xa03412b7}},	//   pakn, втар, _tli_, نىست, 
   {{0x27ec46b8,0x442046b9,0x78480316,0x26cc0063}},	//   nden_, _uli_, pěve, oteo_, 
   {{0x27ec46ba,0x26cc46bb,0x1ea846bc,0x9f4046bd}},	// [47c0] iden_, nteo_, بازي_, _takí_, 
   {{0x27ec049b,0x2164013d,0x3860025c,0x00000000}},	//   hden_, _үтүг, ċiri_, --, 
   {{0x61fc46be,0x27ec0209,0x37ac015b,0xe04446bf}},	//   _inpl, kden_, ক্টর, _анни, 
   {{0x27ec0460,0xd1d402d3,0x00000000,0x00000000}},	//   jden_, _ሪኢቶ_, --, --, 
   {{0x27ec46c0,0x7ad40597,0xd12c0424,0x61ec017a}},	//   dden_, اقتص, _همی_, odbl, 
   {{0xc8c404d3,0x787c00b8,0xcb0446c1,0x672800de}},	//   چوون_, _aũva, ئيون_, dzej, 
   {{0x27ec46c2,0xc8c442b5,0x61ec003e,0xdca446c3}},	//   fden_, نوون_, idbl, _шави, 
   {{0x6b840597,0x9f401a44,0x7e7c46c4,0xa7fc01ed}},	//   _مشكل, _kakà_, _hirp, zműv, 
   {{0x7e7c46c5,0x99e40184,0x59d446c6,0x61fc017a}},	//   _kirp, _ижад, _لغار, _onpl, 
   {{0xae0446c7,0x7e7c045f,0x9f4005da,0x9f98000d}},	//   रायन_, _jirp, _makà_, _hääd_, 
   {{0x7e7c46c8,0x00000000,0x00000000,0x00000000}},	//   _mirp, --, --, --, 
   {{0xd6d046c9,0x9f980037,0x47d03bd7,0x68ec012d}},	//   _نقص_, _jääd_, _نيمر, ładc, 
   {{0x26cc0005,0xae0402ab,0xe6b446ca,0x301400d1}},	//   cteo_, रामन_, _ملنگ, қдар, 
   {{0x85000272,0x7e7c01f4,0x00000000,0x00000000}},	//   _چوون, _nirp, --, --, 
   {{0xa7fc01ed,0x8500009a,0x00000000,0x00000000}},	//   rműv, _نوون, --, --, 
   {{0x61fc46cb,0x7e7c46cc,0x1dc400dc,0x271400cc}},	//   _enpl, _airp, र्घत, _তইতো_, 
   {{0x2ef4035b,0x7e7c46cd,0x9f4000c7,0x2dd446ce}},	// [47d0] ызар, _birp, _rakã_, лжар, 
   {{0x27ec46cf,0x9f400022,0xdde00790,0x7e7c00ef}},	//   zden_, _sakã_, ğuşt, _cirp, 
   {{0x27ec46d0,0x7e7c46d1,0x6728025c,0x3034014b}},	//   yden_, _dirp, zzej, _бенё, 
   {{0xc4d004ac,0x201c0200,0x00000000,0x00000000}},	//   יגע_, ëtit_, --, --, 
   {{0x27ec46d2,0x61fc002d,0x2a340276,0x2b480ba1}},	//   vden_, _ynpl, лэкр, çac_, 
   {{0x27ec46d3,0xa96846d4,0x8d8400cf,0x00000000}},	//   wden_, нила_, _шумд, --, 
   {{0x27ec46d5,0x600800a2,0x29000124,0xa8540a5b}},	//   tden_, _aýmy, ãha_, лтиј, 
   {{0x26cc46d6,0x27ec46d7,0xe73802ce,0x7e7c01f7}},	//   tteo_, uden_, laŵi_, _zirp, 
   {{0x9f4046d8,0x1bc801d9,0x45a00131,0xeff00092}},	//   _kaká_, _سُلی_, لەشك, _ግንድ_, 
   {{0x27ec46d9,0x26cc46da,0x9f40012c,0xc0d00023}},	//   sden_, rteo_, _jaká_, _እደሊ_, 
   {{0xb8e81c82,0x26cc0407,0x27ec46db,0x9f4046dc}},	//   _লৈ_, steo_, pden_, _maká_, 
   {{0xe7380161,0x61fc02d0,0x00000000,0x00000000}},	//   haŵi_, _snpl, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x78480118,0xe5a446dd,0x00000000,0x00000000}},	//   pěvc, _сики, --, --, 
   {{0x61ec03ac,0x7e7c0784,0x61440353,0x9f4001e1}},	//   rdbl, _rirp, уева, _sakà_, 
   {{0x7e7c46de,0x05cc46df,0xdee446e0,0x61fc0d27}},	//   _sirp, त्रब, лоби, _wnpl, 
   {{0x7e7c46e1,0x1f640ff1,0xd00c007b,0x78480118}},	// [47e0] _pirp, укам, ألق_, něva, 
   {{0x7e7c022e,0x61fc46e2,0x9e2400d1,0x00000000}},	//   _qirp, _unpl, دىئو, --, 
   {{0x7e7c46e3,0xfcf4001f,0x82640150,0x201c003a}},	//   _virp, _ግብጽ_, _مۇڭن, ëtis_, 
   {{0xc17802d5,0x98c4016c,0x2d84002d,0xeff8001f}},	//   žės_, ҳсил, _ûlen_, ገበው_, 
   {{0xae440086,0x7e7c4171,0x201c46e4,0x00000000}},	//   òñòb, _tirp, ūtis_, --, 
   {{0x98c40116,0xdbd4008e,0x00000000,0x00000000}},	//   гсил, läüd, --, --, 
   {{0xc0d80023,0x00000000,0x00000000,0x00000000}},	//   ይብሉ_, --, --, --, 
   {{0x6d580198,0xb8140b3e,0xae040456,0x4b200166}},	//   ƙwar, рдиј, राथन_, рмәв, 
   {{0x95c846e5,0x9f400108,0xf1b4000d,0x00000000}},	//   нуна_, _enkö_, _अएलन, --, 
   {{0x68ec068f,0x5a5400a7,0x60080306,0x9f500432}},	//   łada, _събу, _výmy, njyñ_, 
   {{0x97c446e6,0x741446e7,0xae0408f2,0x4a70009f}},	//   _مقاو, لودا, रातन_, _اُلر, 
   {{0xfcf4044e,0x22580ac5,0x661c0240,0x00000000}},	//   _ግብጺ_, _akpk_, ëskr, --, 
   {{0x23c409bb,0x96940395,0x00000000,0x00000000}},	//   _वारद, _среш, --, --, 
   {{0xb59446e8,0xc6900a1e,0xc1e80500,0x65ac0022}},	//   _тикш, _האס_, льсе_, rõhí, 
   {{0x29340201,0x667004fb,0x6a6c03b2,0xcf9800d8}},	//   _እንደማ, _بگير, búff, ејз_, 
   {{0x9f4000d0,0x668001d5,0x9580033f,0x00000000}},	//   _saká_, _دییل, łądk, --, 
   {{0x447c010f,0x00000000,0x00000000,0x00000000}},	// [47f0] _אנהע, --, --, --, 
   {{0x0ca8010b,0x81d40408,0x00000000,0x00000000}},	//   етди_, _лоьх, --, --, 
   {{0x9f4046e9,0x26f0000d,0xab9400d1,0x00000000}},	//   _vaká_, _अछ्र_, للاغ, --, 
   {{0x81440344,0x3cf80356,0x00000000,0x00000000}},	//   _چنین, _drrv_, --, --, 
   {{0x9f400030,0xefc8001f,0x00000000,0x00000000}},	//   _taká_, ጠናው_, --, --, 
   {{0x8d7446ea,0x82d40327,0xaa440063,0x00000000}},	//   _مازا, _ཏཱལའ, јекл, --, 
   {{0xf9a801e1,0xad2415bf,0x00000000,0x00000000}},	//   _ibè̟_, _ئىزى, --, --, 
   {{0x5b100598,0x69d40c2e,0xaa94035b,0x01380375}},	//   смәт, _मॉरी, _виач, טרות_, 
   {{0x78a4071b,0xed5804a9,0xe7380114,0x29340092}},	//   ćiva, _чоң_, ђео_, _እንዲማ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe7b40214,0x64a40e92,0xa44446eb,0x00000000}},	//   _نماد, јама, инод, --, 
   {{0xf77046ec,0x7cf000e5,0x00000000,0x00000000}},	//   _کام_, lórá, --, --, 
   {{0xf04402d3,0x59d806ab,0x00000000,0x00000000}},	//   _የብሎም, _मॉडर, --, --, 
   {{0x4f280020,0x2934010c,0x05840107,0xe12446ed}},	//   ዲያደር, _እንዳማ, _судм, амги, 
   {{0x28dc0dad,0xc4480214,0xa0a446ee,0x69cc0b26}},	//   _महफि, _میدن_, рабд, _सानी, 
   {{0x09ac015b,0x92c400fe,0x88c400eb,0x00000000}},	//   চ্চা, ৈয়ে_, _শনাক, --, 
  
   {{0xa2e4036b,0x6444009a,0x00000000,0x00000000}},	// [4800] _топд, mnki, --, --, 
   {{0x6294102c,0x64440334,0x9cf40063,0x4e000b3b}},	//   _ityo, lnki, ичеш, озуб, 
   {{0x644446ef,0x91b80375,0xdb840124,0x63b401ef}},	//   onki, _במיי, агеи, _kdyn, 
   {{0x644446f0,0x60dc46f1,0x78bc2d8b,0xa0680e92}},	//   nnki, _ippm, _årvi, _јама_, 
   {{0x644446f2,0x200046f3,0xe8080412,0xd1480240}},	//   inki, _inki_, वाना_, _ዘስተው, 
   {{0xfe780724,0xca2c01d9,0x00000000,0x00000000}},	//   _сүз_, وٝن_, --, --, 
   {{0x2b4c074d,0x68ec0034,0x63b446f4,0x23c401f9}},	//   _exec_, ładn, _odyn, _वांद, 
   {{0xe97046f5,0x644401f5,0xf704010b,0x00000000}},	//   سۇند, jnki, йҗем, --, 
   {{0x5ac8004e,0x00000000,0x00000000,0x00000000}},	//   _шлам_, --, --, --, 
   {{0x60dc1a82,0x63b409a5,0x644402f6,0x00000000}},	//   _oppm, _adyn, enki, --, 
   {{0x200046f6,0x629446f7,0x2450022a,0x00000000}},	//   _onki_, _atyo, lámy_, --, 
   {{0x386000c6,0x923c0023,0x644401bf,0xb9f40240}},	//   _óir_, _ኣብራሃ, gnki, _ሞሳ_, 
   {{0x63b40368,0x60dc0175,0x69cc29d7,0xb3e801d9}},	//   _ddyn, _appm, _सामी, نٹھل_, 
   {{0x200046f8,0x644446f9,0x9fd402f5,0x95800210}},	//   _anki_, anki, হযোগ, łąbk, 
   {{0xd0843596,0x629446fa,0xae0401ad,0x0efc46fb}},	//   рыги, _etyo, रासन_, ईम्स_, 
   {{0x63b446fc,0xe8080034,0x9fa40032,0xa80400c7}},	//   _gdyn, वाया_, йыуҙ, meñá, 
   {{0xadd846fd,0xa2c001e0,0xbfa80354,0x0ca00023}},	// [4810] лмау_, _нәрк, ртсе_, _ምቁራጽ_, 
   {{0x200046fe,0xa2801176,0x00000000,0x00000000}},	//   _enki_, _ریفو, --, --, 
   {{0x63b400a9,0xe808012c,0x717405af,0x00000000}},	//   _ydyn, वामा_, _دهدا, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x78480316,0xcdc001ec,0x7cf001d3,0x00000000}},	//   těvn, _қаңқ, tórá, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x65ac0084,0x644446ff,0x2b8c007b,0x984c03e3}},	//   _ṱhod, ynki, _cócó_, _aşıb_, 
   {{0x2fc84700,0x68ec0034,0x2b4c00db,0xae0405dc}},	//   ngag_, łado, _txec_, रावन_, 
   {{0xdcec0139,0x786400d1,0x6a1401af,0x00000000}},	//   _kgbğ, غدىك, _лмау, --, 
   {{0xe2984701,0xbd4400e5,0x00000000,0x00000000}},	//   һам_, _انہي, --, --, 
   {{0x62941529,0x68f40451,0xf41000fe,0xa6e4032e}},	//   _styo, _دٻاء, াসনৰ_, fuðá, 
   {{0xf7f40451,0x64444702,0x69cc0c22,0x00000000}},	//   _وسند, unki, _साडी, --, 
   {{0x73484703,0x00000000,0x00000000,0x00000000}},	//   ачёв_, --, --, --, 
   {{0x923c044e,0x6ec0012c,0x2ee84704,0x64440210}},	//   _ኣብርሃ, _लमजु, dwaf_, snki, 
   {{0x1fb42fde,0x793802d3,0x9db801ec,0x10a04705}},	//   йсар, _እንተት, ғызу_, зисн, 
   {{0xdfd04706,0x2fc83424,0x9f84009d,0x00000000}},	//   ثير_, ggag_, сгад, --, 
   {{0xc4480214,0x2ee8007f,0x00000000,0x00000000}},	// [4820] _میگن_, gwaf_, --, --, 
   {{0x9f400589,0x2fc81713,0xe8084707,0x1d08329b}},	//   _nakå_, agag_, वाडा_, лези_, 
   {{0x60dc4708,0x83f0013f,0x0d2000f7,0x9638010f}},	//   _uppm, _nkɑk, пүрү, נגעט, 
   {{0xbbb41223,0x00000000,0x00000000,0x00000000}},	//   ुलेक, --, --, --, 
   {{0xcf900375,0xdea00133,0x5f7433ae,0x00000000}},	//   _מטר_, _ریای, _دادر, --, 
   {{0x784800bc,0x24500306,0xe5cc0432,0x6ad8010a}},	//   těvo, rámy_, _ýeňň, ăмлă, 
   {{0xd7f800f7,0xc3040154,0x00000000,0x00000000}},	//   гуп_, উনটি_, --, --, 
   {{0x69cc4108,0x18a407d6,0x37a803d4,0x684000c7}},	//   _साथी, _ҳажм, _গাহৰ, мҽха, 
   {{0xdb0c023a,0xaac4007b,0x5018011a,0x00000000}},	//   äjäl, _وتكن, טוקו, --, 
   {{0x98a40209,0x473000fb,0xd9442b2e,0x00000000}},	//   _гиже, яныс, _лези, --, 
   {{0x2fc8058a,0x94a801ec,0x5fb817ee,0x00000000}},	//   ygag_, ытпа_, ेलाल, --, 
   {{0xb1680092,0x28dc4709,0x2ee80042,0x4d78010f}},	//   _ተስማሚ_, _महति, ywaf_, טריע, 
   {{0xcc3800c8,0xa80404d4,0x00000000,0x00000000}},	//   רעכט, señá, --, --, 
   {{0x04e403d4,0x290c012d,0x00000000,0x00000000}},	//   _ওপৰৰ_, ślał_, --, --, 
   {{0x463800c8,0x2ee8003e,0xb9200248,0x84800023}},	//   _געגע, wwaf_, _rirọ_, ነብርን_, 
   {{0xef98470a,0x957c0139,0xfa000154,0x044400d8}},	//   ркаш_, _qaƅu, ্সিল_, _нејн, 
   {{0x8d84470b,0x15bc08b0,0xe80807f7,0x7ae40c3c}},	// [4830] مشان, _ﻣﯘﺩﺩ, वाता_, çitl, 
   {{0x764803cd,0x2fc801ab,0x69cc07b7,0x6dc000cf}},	//   nndy, sgag_, _साधी, بۅسۅ, 
   {{0x2ee807ab,0x03ec0154,0x63ac0139,0x7e78013a}},	//   swaf_, টারী_, _önnä, _řapí, 
   {{0x6e941216,0x09b008a3,0x00000000,0x00000000}},	//   _ولجا, ील्य, --, --, 
   {{0x6e94470c,0xcf2400ec,0xd6c442f4,0x02fc00df}},	//   _фигу, _طرحي, _تق_, ָלומ, 
   {{0xae04129d,0x80cc0154,0x00000000,0x00000000}},	//   _بوسى, াবর্, --, --, 
   {{0xab780020,0xa968470d,0x7c040137,0x6f0c03e3}},	//   ባቸዋል_, шика_, تبەك, lxac, 
   {{0xe738470e,0xec240ef6,0x00000000,0x00000000}},	//   ией_, _بىرپ, --, --, 
   {{0x6f0c004e,0x00000000,0x00000000,0x00000000}},	//   nxac, --, --, --, 
   {{0xc8a80c04,0x00000000,0x00000000,0x00000000}},	//   _бъде_, --, --, --, 
   {{0x67d410f5,0x240824ca,0xf98800c6,0xe5682838}},	//   _можу, анни_, _انمي_, ринд_, 
   {{0x195400d9,0x00000000,0x00000000,0x00000000}},	//   _ובעל_, --, --, --, 
   {{0xb6c00022,0x2bd03cbe,0x00000000,0x00000000}},	//   _зҩыд, _हाना, --, --, 
   {{0x64a4470f,0xa3b84710,0x7d18005c,0x00000000}},	//   _дака, داگر_, øvsk, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x91d80bae,0x00000000,0x00000000,0x00000000}},	//   म्बई, --, --, --, 
   {{0xfe7839af,0x00000000,0x00000000,0x00000000}},	// [4840] йүм_, --, --, --, 
   {{0x9d44023a,0x5d68084c,0x69d4000d,0x74c000cd}},	//   оезд, аизм_, _मउगी, _विमृ, 
   {{0xa0684711,0x55b80375,0x16a410eb,0x291801e1}},	//   _вана_, שמעו, _गब्ब, _ńsan_, 
   {{0x6f0c0005,0x5b2400e3,0xbfd800f1,0x00000000}},	//   bxac, يفال, _دېرش_, --, 
   {{0xdcfc00d7,0x00000000,0x00000000,0x00000000}},	//   napĺ, --, --, --, 
   {{0x97380125,0x00000000,0x00000000,0x00000000}},	//   _ኢንዱስ, --, --, --, 
   {{0x5f7403e6,0x00000000,0x00000000,0x00000000}},	//   _داگر, --, --, --, 
   {{0xd6d84712,0xd7f84713,0x69d43712,0xbb380150}},	//   ато_, рук_, _özen, _ﮔﯘﻝ_, 
   {{0xaad0012c,0x76480158,0x00000000,0x00000000}},	//   _समयक, tndy, --, --, 
   {{0x9f404714,0xfaa40107,0xd90c4715,0x8a700014}},	//   _bakú_, _мағо, _لیت_, _ہێۆچ, 
   {{0xc7ac016c,0x76480158,0x00000000,0x00000000}},	//   _оё_, rndy, --, --, 
   {{0x4394005b,0xaab0012d,0x00000000,0x00000000}},	//   маюс, ुंचक, --, --, 
   {{0x1cd80135,0xf4844716,0x83840c75,0xe9700228}},	//   _འདའ_, _کاتی, дыре, _قۇۇد, 
   {{0x8cc8033f,0x00000000,0x00000000,0x00000000}},	//   _हमलो, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x36340502,0x6f0c0137,0x88b808a8,0x7414451a}},	//   _برچس, txac, יזלי, _روخا, 
   {{0x51844717,0x00000000,0x00000000,0x00000000}},	// [4850] _муна, --, --, --, 
   {{0xccf80640,0xae040ebb,0x6f0c4718,0x00000000}},	//   иће_, राइन_, rxac, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x68ec0034,0xcbc4004b,0xe570010f,0x92bc0154}},	//   ładk, تېرو_, ײַב_, ীবী_, 
   {{0xd138001f,0xe8081df0,0x4ae80108,0x00000000}},	//   ረጋቸው, वासा_, рьем_, --, 
   {{0xa3e003f3,0x00000000,0x00000000,0x00000000}},	//   _नॉन_, --, --, --, 
   {{0x1cd80135,0x692428f6,0x28f80139,0x00000000}},	//   _འདར_, ямка, сэлэ_, --, 
   {{0x7af0023a,0x1c00000d,0x00000000,0x00000000}},	//   ähtä, _रोपल_, --, --, 
   {{0xd70405cc,0x6b8800ca,0x562802d3,0xe7382ba8}},	//   зные_, _igeg, _ስለዝበ, сеп_, 
   {{0xe8084719,0x6aa80241,0x59d00d2e,0x2bd00073}},	//   वाहा_, _iwef, _सायर, _हाडा, 
   {{0x6aa8471a,0xf2c80a1e,0x00000000,0x00000000}},	//   _hwef, _תע_, --, --, 
   {{0x1cd80489,0xd9c4015b,0x67d40229,0x0afc00eb}},	//   _འདལ_, _এসএম, _ходу, ্নীল_, 
   {{0x59d0471b,0x0508015b,0xe5a40022,0x00000000}},	//   _सामर, শনের_, _еили, --, 
   {{0xf770471c,0x6aa81418,0x9f400030,0xe8080490}},	//   _شان_, _mwef, _takú_, वावा_, 
   {{0x6aa80944,0x216839c8,0x16580066,0x00000000}},	//   _lwef, сиви_, _اسنک_, --, 
   {{0x6b88471d,0x201001d4,0x6aa804ba,0x78bc143a}},	//   _ngeg, ujyi_, _owef, _ærve, 
   {{0x6fac1d15,0xdd90027d,0xcf180014,0x6a6c00d7}},	// [4860] _ज़रू, فوذ_, ٝرٕچ_, zúfa, 
   {{0x6b88471e,0x0e60471f,0x99c40154,0xa6bc00cc}},	//   _ageg, екун, _এস্ক, _অহাট, 
   {{0xdef84720,0x2bfc00c5,0x59d00412,0x00000000}},	//   шың_, _रोहू_, _साबर, --, 
   {{0x6aa81418,0xae044721,0x3ae807d6,0x9a840500}},	//   _bwef, राउन_, قبتی_, пукл, 
   {{0xb7d400b8,0xca7401ec,0x3c4801e2,0x00000000}},	//   _kṣve, _ﺸﺎﺒﻪ_, مګړی_, --, 
   {{0x7848038e,0x69d4189f,0x3ea04722,0x6b8808e7}},	//   pěvk, _özel, mpit_, _egeg, 
   {{0xdca44723,0x3ea04724,0x6b8c0427,0x9f400241}},	//   _хаби, lpit_, žaga, _rakù_, 
   {{0x3ea00108,0x644401e1,0xdca41188,0x00000000}},	//   opit_, _ìhih, _маҳи, --, 
   {{0x2bd005ba,0x6aa80cfd,0x3ea0020c,0x9aa40133}},	//   _हाता, _gwef, npit_, _رماو, 
   {{0x3ea04725,0x984c05d1,0xddcc031c,0x0f34011a}},	//   ipit_, rşın_, _nibż, פריט_, 
   {{0x1cd808ea,0xd7f84726,0x17840220,0x3ea005b1}},	//   _འདས_, _гул_, _егем, hpit_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe80835e8,0xc7a04727,0x066000c7,0x00000000}},	//   वारा_, _чичк, ьҵәҟ, --, 
   {{0x997c0311,0x7ae40327,0x00000000,0x00000000}},	//   căţi_, ħith, --, --, 
   {{0x3ea0039a,0xe3e002f5,0x00000000,0x00000000}},	//   epit_, যয়ব, --, --, 
   {{0xdddc00d7,0x00000000,0x00000000,0x00000000}},	//   lopň, --, --, --, 
   {{0x3ea0113c,0x325401af,0x263c0419,0x4034008e}},	// [4870] gpit_, _овир, zňom_, хетс, 
   {{0xcb440323,0x6aa80810,0x6b8801ab,0xeff00092}},	//   үхди, _rwef, _sgeg, _ግዕዝ_, 
   {{0x3ea00108,0x00000000,0x00000000,0x00000000}},	//   apit_, --, --, --, 
   {{0x9200005f,0x6aa8007f,0x3a2c06be,0x53bc1cc3}},	//   žādi, _pwef, _aldp_, ्लिश, 
   {{0xfbd02f01,0xddc80356,0x00000000,0x00000000}},	//   اتم_, _înşu, --, --, 
   {{0xba240220,0xaa442f89,0x00d80133,0xb9c400ae}},	//   ндік, ьелл, _ببیت_, فقهي, 
   {{0xe8081889,0xc98400c7,0x0afc0154,0x69d40139}},	//   वाला_, _ҵуеи, ্নেল_, _özem, 
   {{0x6aa804ba,0x6b8804e6,0x3a2c00d7,0x00000000}},	//   _twef, _ugeg, _eldp_, --, 
   {{0xd6cc092f,0x997c00a8,0x1cd80135,0xaad04728}},	//   لقي_, tăţi_, _འདོ_, _समिक, 
   {{0xba742aa5,0x539c0092,0x7af400d4,0x263c0419}},	//   _كالت, ኃናዊት_, _язує, pňom_, 
   {{0xa3e82685,0x7e6024c8,0xdb0c01d3,0x64a4074d}},	//   одна_, _ímpe, óköz, ьана, 
   {{0xd6cc25da,0x3e744729,0x3ea0472a,0xaad000cd}},	//   دقی_, mäte_, ypit_, _समाक, 
   {{0x8284472b,0xa5f8472c,0x3e74008e,0x00000000}},	//   нқид, _меду_, läte_, --, 
   {{0x6d54002d,0x7ae40200,0x00000000,0x00000000}},	//   _oxza, çiti, --, --, 
   {{0x3ea00204,0x1cd8025c,0x61440d1d,0x6d58002f}},	//   wpit_, _འདེ_, фева, ßwal, 
   {{0xd004472d,0x3ea0472e,0x00000000,0x00000000}},	//   месе_, tpit_, --, --, 
   {{0x6d54058a,0x3ea000bc,0xddcc025c,0x00000000}},	// [4880] _axza, upit_, _tibż, --, 
   {{0x3ea0472f,0x3e740724,0x050c00fe,0x00000000}},	//   rpit_, käte_, ানীৰ_, --, 
   {{0x3ea04730,0xe5c024ae,0x5164004e,0x3e740108}},	//   spit_, _ﻣﯘﻣﻜ, _жүрү_, jäte_, 
   {{0x3ea04731,0x9b444732,0x6f080e04,0x5fb0033f}},	//   ppit_, وناو, _šece, _ज़िल, 
   {{0x5f04006c,0x3ea00357,0x59d001bc,0xb5fc031c}},	//   _ўзга, qpit_, _सादर, loġe, 
   {{0x9e744733,0x716407d2,0x3e740166,0x00000000}},	//   _آهست, _تاۋك, fäte_, --, 
   {{0x26101715,0x8cb80014,0xc8b0143e,0xadb400db}},	//   तानी_, _ودٲس_, نصيب, _سۇنا_, 
   {{0x7d180627,0xb6f41b88,0xabd40120,0x00000000}},	//   øvsu, езиј, _пцуј, --, 
   {{0xc6f44734,0x8c400212,0x00000000,0x00000000}},	//   дных_, _рете, --, --, 
   {{0x3e74008e,0x00000000,0x00000000,0x00000000}},	//   bäte_, --, --, --, 
   {{0x99484735,0xf64800cf,0x28a40037,0x3e740139}},	//   _بلال_, _ۉستۉ_, _गढ़पि, cäte_, 
   {{0x78b80175,0xb5fc0327,0xb7d84736,0x977c010a}},	//   msvv, doġe, _روتا_, _кулă_, 
   {{0xe9800124,0x74c000dc,0xd9f02072,0x23700210}},	//   _иқән, _विवृ, _आघात_, _czyj_, 
   {{0x06341564,0x2ca00204,0x88c400bc,0x2c74005c}},	//   _يسوع_, yphd_, spěš, måde_, 
   {{0xd0184737,0x30841c43,0x2c7401bf,0xe7080137}},	//   офа_, فلسف, låde_, _وتۇن_, 
   {{0x4ea40b7f,0xd6f03806,0x4fc405f5,0x00000000}},	//   држа, _अनाथ_, ьсга, --, 
   {{0x27e807dd,0xcefc015b,0x40843624,0x64544738}},	// [4890] _ñane_, ৃন্দ_, турб, ézie, 
   {{0xff0400c9,0x2bd019cc,0x00000000,0x00000000}},	//   ъясн, _हाहा, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x447c00c8,0x25e402ab,0xe570008f,0x3e740419}},	//   ַנגע, _जॉनी_, אַד_, väte_, 
   {{0xd6c44739,0x89f40022,0x69d4008e,0x35d4012d}},	//   _حق_, мҭар_, _özek, _दाढ़, 
   {{0x9f40012c,0x2bd0012c,0xa2b000bc,0xaa4400db}},	//   _jaký_, _हावा, _अबस्, ةنتى, 
   {{0x2900473a,0x2c740267,0x7d1803cd,0x00000000}},	//   íha_, tådd_, øvst, --, 
   {{0x3e74473b,0xd7ec2928,0xfbc400ec,0x00000000}},	//   räte_, مكى_, _ليفٽ, --, 
   {{0x0a6807b5,0x2c7403cd,0xa6840116,0x15bc00d1}},	//   _држи_, rådd_, нлид, ﻠﻤﯩﻐ, 
   {{0xa3e037f3,0x06c0045e,0xe61000c6,0x38c80131}},	//   न्न_, ্বলি, اشة_, чуән_, 
   {{0x2610473c,0xe63401c6,0x00000000,0x00000000}},	//   ताबी_, _үхлэ, --, --, 
   {{0x2c7400b5,0xdc1003b9,0x00000000,0x00000000}},	//   både_, _məğz, --, --, 
   {{0x27ec473d,0x66e4473e,0x8724473f,0xe2b401c0}},	//   meen_, _чола, _تعام, эснэ, 
   {{0x1fb8033f,0x68ec033f,0x383000db,0xb5fc031c}},	//   ेल्ड, ładu, _مۉۉز, toġe, 
   {{0x59d00073,0x27ec0076,0x00000000,0x00000000}},	//   _सासर, oeen_, --, --, 
   {{0x27ec4740,0xdfd0007b,0xb5fc0135,0x4dc400eb}},	//   neen_, طيط_, roġe, র্মূ, 
   {{0x64444741,0xd00c00ae,0x00000000,0x00000000}},	// [48a0] miki, حلق_, --, --, 
   {{0x64444742,0x27ec4743,0xa4fc0135,0xd12c0f31}},	//   liki, heen_, _ཟློག_, جمہ_, 
   {{0x27ec4744,0x61ec4745,0x61442143,0xae0417ee}},	//   keen_, mebl, _чена, राजन_, 
   {{0x61ec4746,0x27ec4747,0x00000000,0x00000000}},	//   lebl, jeen_, --, --, 
   {{0x27ec4748,0xa3e006e3,0x64444749,0xbe840139}},	//   deen_, न्य_, iiki, _аңал, 
   {{0x61ec04ac,0x1a640b28,0x648401ab,0x9b340022}},	//   nebl, ریای_, _sųil, _ҧхаш, 
   {{0x1cd81b35,0x6444474a,0x27ec474b,0x49b4036b}},	//   _འདི_, kiki, feen_, راود_, 
   {{0x27ec474c,0x6444474d,0x61ec474e,0x59d00833}},	//   geen_, jiki, hebl, _सावर, 
   {{0x61ec474f,0x2600130b,0x60cc0455,0x26cc3a6c}},	//   kebl, _वोही_, hubm, gueo_, 
   {{0x2c744750,0x9f400093,0x64440270,0x439402dd}},	//   råde_, _hakó_, eiki, ғарс, 
   {{0x64444751,0x61ec4752,0x27ec474c,0x997400fd}},	//   fiki, debl, been_, _чуаш, 
   {{0x64440516,0x27ec2fa9,0x60cc014f,0x78480118}},	//   giki, ceen_, dubm, těvu, 
   {{0x61ec4753,0x28184754,0x46a000f3,0x9f4000e5}},	//   febl, _تفنگ_, _бачв, _makó_, 
   {{0x61ec4755,0x51840261,0x9f4000e5,0x00000000}},	//   gebl, еуба, _lakó_, --, 
   {{0x2bd009d9,0x64444756,0x03b00c58,0xb7f40263}},	//   _हाला, biki, _কাৰণ, _आसाम_, 
   {{0x1fc4024c,0x64c40073,0x00000000,0x00000000}},	//   круҳ, _वितळ, --, --, 
   {{0x61ec4757,0x9f4001f1,0xb2744758,0x2dd40150}},	// [48b0] bebl, _taký_, _илиш, кжар, 
   {{0x04b400dd,0x61ec4759,0x7bc0003a,0x27ec475a}},	//   _تھیں_, cebl, _admu, zeen_, 
   {{0x27ec0d62,0x9f40011f,0xf0780032,0x261001ad}},	//   yeen_, _bakó_, _ойош_, ताती_, 
   {{0x27ec475b,0x8c64475c,0xbca4475d,0x7c840108}},	//   xeen_, رطان, امني, гуче, 
   {{0x27ec475e,0x8aa4013d,0x00000000,0x00000000}},	//   veen_, хред, --, --, 
   {{0x27ec475f,0x64444760,0x7bc04761,0x6ad029d9}},	//   ween_, ziki, _edmu, _समीर, 
   {{0x27ec4762,0x64444763,0xed14066d,0xa3e0433a}},	//   teen_, yiki, _جہاں_, न्ड_, 
   {{0x644401c0,0x6360063f,0xfbd80bc0,0x27ec0036}},	//   xiki, ịnis, _डायम, ueen_, 
   {{0x27ec1e15,0x03ec00bd,0x61ec0fac,0x7ae40205}},	//   reen_, য়ামী_, yebl, çitt, 
   {{0x27ec4764,0x64444765,0x61ec00cf,0x4a2400c7}},	//   seen_, wiki, xebl, _џьаб, 
   {{0x27ec4766,0x88c44767,0x61ec00c8,0x31f4031c}},	//   peen_, _ستال, vebl, _བལྟར_, 
   {{0xe6104768,0x61a81c15,0x27ec01d9,0x61ec079b}},	//   اشک_, कर्ष, qeen_, webl, 
   {{0x61ec4769,0x26cc476a,0x6444476b,0x5434211f}},	//   tebl, queo_, riki, ئرپر, 
   {{0x6444476c,0x3e7401b8,0xe644476d,0xe80810fa}},	//   siki, käta_, _шелп, वाका_, 
   {{0x61ec476e,0xa0680a83,0x69c0476f,0x9f404770}},	//   rebl, дава_, _mdle, _nakò_, 
   {{0x61ec4771,0x64444772,0xe2c801d9,0xdee44773}},	//   sebl, qiki, _قوبو_, коби, 
   {{0x60cc0354,0x1cd80003,0x69c00609,0xc68c001f}},	// [48c0] subm, _འདང_, _odle, _መሣሪያ_, 
   {{0x44204774,0x29044775,0x69c0243b,0x61ec036e}},	//   _hoi_, _orla_, _ndle, qebl, 
   {{0x44204776,0xa3e00b98,0x60cc047e,0x23b400cd}},	//   _koi_, न्थ_, qubm, _अजाद, 
   {{0x442000a8,0x69c04777,0x9f400699,0x5ba000fb}},	//   _joi_, _adle, _dakò_, рһағ, 
   {{0x44204778,0x7a3445a7,0x29044779,0x263c0419}},	//   _moi_, _làte, _arla_, lňou_, 
   {{0x4420477a,0xa3e04438,0x69c00205,0x00000000}},	//   _loi_, न्त_, _cdle, --, 
   {{0x4420477b,0x88b001b9,0xdb0000e4,0x00000000}},	//   _ooi_, لیلچ, mboí, --, 
   {{0x4420477c,0x7bc0477d,0x1cc0025c,0x69c0477e}},	//   _noi_, _udmu, _གྷར_, _edle, 
   {{0x7c200192,0x4810477f,0x95c84780,0x29044781}},	//   _iomr, рмыс, муна_, _erla_, 
   {{0x645400ca,0x44204782,0xceb00302,0x7c204783}},	//   _ajyi, _aoi_, סית_, _homr, 
   {{0x44204784,0x290408a4,0x7a3400cf,0x2c7401e6}},	//   _boi_, _grla_, _càte, låda_, 
   {{0x44204785,0x683403b2,0xe8e811e6,0x263c0419}},	//   _coi_, _rádg, _سرمو_, dňou_, 
   {{0xa3e00d2b,0x1cc0025c,0x7c200158,0x44200375}},	//   न्ध_, _གྷལ_, _momr, _doi_, 
   {{0x44204786,0x3e740054,0x7a34002e,0xb9cc001f}},	//   _eoi_, yäta_, _fàte, _ደን_, 
   {{0x44204787,0x76480986,0x7c20127b,0x5064009d}},	//   _foi_, midy, _oomr, втаа, 
   {{0x44204788,0xa3e0216a,0xfa00015b,0x7c200213}},	//   _goi_, न्द_, ্সটল_, _nomr, 
   {{0xcdd80640,0x7528002d,0xda000490,0x76480076}},	// [48d0] дње_, lydz, लयात_, oidy, 
   {{0x31c001d9,0x764800ad,0x8d842c7a,0x02a40395}},	//   _دۅسہ, nidy, نشان, _тръм, 
   {{0x70544789,0x7c20478a,0x68340008,0x4420020b}},	//   _مندا, _bomr, _háde, _yoi_, 
   {{0x68341de4,0x44200208,0x3e7400e4,0x13b400eb}},	//   _káde, _xoi_, räta_, _ঝাড়, 
   {{0x76480280,0x9f400241,0x00000000,0x00000000}},	//   kidy, _wakò_, --, --, 
   {{0x76480067,0x2ef800d7,0x9f400241,0x00000000}},	//   jidy, _issf_, _takò_, --, 
   {{0x7648478b,0x3e74241c,0xbd68084c,0xdef00023}},	//   didy, qäta_, _арте_, _ሂቡና_, 
   {{0x2dc80150,0x76480363,0xee8400c7,0x7c2006be}},	//   _تاڭۋ_, eidy, _шыҟо, _gomr, 
   {{0x4420478c,0xdac40075,0x6834478d,0x76480076}},	//   _roi_, _مېنى_, _náde, fidy, 
   {{0x69c0019b,0x7c2001f1,0x263c0030,0x764800ad}},	//   _udle, _zomr, yňou_, gidy, 
   {{0x4420478e,0x7c20478f,0x92e00183,0x28dc0037}},	//   _poi_, _yomr, নটো_, _महटि, 
   {{0x44200a73,0x7a3400db,0x7648062c,0x263c00d0}},	//   _qoi_, _vàte, aidy, vňou_, 
   {{0x44204790,0x27fc0cfd,0x7a340295,0x205402f4}},	//   _voi_, _iawn_, _wàte, ҳтар, 
   {{0x27fc038f,0xf77006fe,0x68340077,0x6728007f}},	//   _hawn_, _بام_, _dáde, myej, 
   {{0x44204791,0x20544792,0x672807ac,0x622400d1}},	//   _toi_, гтар, lyej, نىڭل, 
   {{0xa06800f7,0x69cc0cb4,0x44200072,0x263c0419}},	//   хаба_, _साझी, _uoi_, rňou_, 
   {{0x67284793,0x2ef801c7,0x27fc015d,0x91b00183}},	// [48e0] nyej, _cssf_, _mawn_, _জাৰ্, 
   {{0x7c204794,0x6294089c,0x63b44795,0x59d005d7}},	//   _somr, _iuyo, _heyn, _साइर, 
   {{0x7c203733,0x61fc03a2,0x62944796,0x68340118}},	//   _pomr, _iapl, _huyo, _záde, 
   {{0x629419d9,0x76484797,0x63b40477,0x3cf8004e}},	//   _kuyo, zidy, _jeyn, _vsrv_, 
   {{0x61fc4798,0x7e600998,0x63b44799,0x67280223}},	//   _kapl, _ímpo, _meyn, jyej, 
   {{0x2c7403d4,0x6294479a,0x63b4479b,0x61fc479c}},	//   råda_, _muyo, _leyn, _japl, 
   {{0x7648479d,0x6294479e,0x27fc015d,0x61fc479f}},	//   vidy, _luyo, _bawn_, _mapl, 
   {{0x61fc47a0,0x62940083,0x27fc03cb,0x63b40213}},	//   _lapl, _ouyo, _cawn_, _neyn, 
   {{0x764847a1,0x629447a2,0xe8082c33,0x27fc47a3}},	//   tidy, _nuyo, वाजा_, _dawn_, 
   {{0x14c8169c,0xa3e042e3,0x1cc00003,0x7528012d}},	//   ными_, न्स_, _གྷོ_, tydz, 
   {{0x63b447a4,0x764847a5,0xd7e400d6,0x9a7802d3}},	//   _beyn, ridy, _біло, ስወከፍ_, 
   {{0x61fc47a6,0x629447a7,0x683447a8,0x67280083}},	//   _aapl, _buyo, _páde, byej, 
   {{0xfe0419e5,0x63b447a9,0x629404cf,0x74c03599}},	//   रयास_, _deyn, _cuyo, _विकृ, 
   {{0x61fc47aa,0x69d403ee,0x629447ab,0x63b4058a}},	//   _capl, _özet, _duyo, _eeyn, 
   {{0x61fc060a,0x27fc0295,0x261047ac,0xa3e011d7}},	//   _dapl, _yawn_, तारी_, न्ह_, 
   {{0x63b447ad,0x2ef80618,0x1cc0025c,0x629400b5}},	//   _geyn, _pssf_, _གྷེ_, _fuyo, 
   {{0x629447ae,0x61fc0369,0xa2c004a9,0x43d40137}},	// [48f0] _guyo, _fapl, _мәрк, _ازىز, 
   {{0x63b447af,0x61fc47b0,0x7e7c01ef,0x00000000}},	//   _zeyn, _gapl, _chrp, --, 
   {{0x823404e5,0xe7f8227c,0x63b40067,0x00000000}},	//   _دريا, ्यमा_, _yeyn, --, 
   {{0xaed4214f,0x66e400af,0x63b40009,0x629447b1}},	//   _комш, _कहलक_, _xeyn, _yuyo, 
   {{0x705401d9,0x61fc47b2,0x27fc0042,0x0ac40108}},	//   _منگا, _yapl, _rawn_, ущем, 
   {{0x692447b3,0x27fc1caa,0x3dcc0154,0xfb780139}},	//   имла, _sawn_, র্বল, _şäär_, 
   {{0x27fc47b4,0x2d8406af,0x68341315,0xaad0216a}},	//   _pawn_, _àle_, _nádc, _समकक, 
   {{0x7c34010a,0xdcec0171,0xc770004e,0x00000000}},	//   _лесх, _uzbā, йтпө, --, 
   {{0x63b447b5,0xe73847b6,0xdb2447b7,0x261047b8}},	//   _reyn, теп_, _پولی, ताली_, 
   {{0x62940526,0x63b447b9,0xe64447ba,0x00000000}},	//   _ruyo, _seyn, реоп, --, 
   {{0x63b447bb,0x629447bc,0x61fc47bd,0x672802d3}},	//   _peyn, _suyo, _rapl, syej, 
   {{0x629447be,0x638447bf,0x2328136b,0x63b40009}},	//   _puyo, игна, воми_, _qeyn, 
   {{0x61fc47c0,0x626410de,0x6294036b,0x69d40793}},	//   _papl, لاسق, _quyo, _özes, 
   {{0x63b40050,0x6294009a,0xe5a406b3,0x61fc0978}},	//   _weyn, _vuyo, _тики, _qapl, 
   {{0x602447c1,0x1fb447c2,0x216847c3,0x63b4102c}},	//   адва, исар, тиви_, _teyn, 
   {{0x629447c4,0x20dc025a,0xdfd00597,0x26cc0109}},	//   _tuyo, rïi_, تير_, oreo_, 
   {{0x61fc0649,0x20dc006a,0x26cc05da,0x71700131}},	// [4900] _tapl, sïi_, nreo_, يۇۋا, 
   {{0x1cc0031c,0xe3b0004b,0x9f500de2,0x20d447c5}},	//   _གྷུ_, _ارګ_, leyë_, _кімс, 
   {{0xdcb00075,0x25dc47c6,0x9fc801a9,0x00000000}},	//   زىش_, _खानी_, _игна_, --, 
   {{0x3b8002d3,0x26cc01e4,0x1ea83bd7,0x00000000}},	//   _ይሓይሽ_, kreo_, _لاسي_, --, 
   {{0x3c48004b,0x53980375,0xa2a801f9,0xa2cc000d}},	//   نګړی_, דינו, जीच्, _तिफ्, 
   {{0x98c447c7,0x7a340e89,0x26cc47c8,0xa2cc1fc4}},	//   асил, _bàta, dreo_, _तिन्, 
   {{0x7a3400db,0xaf3403e6,0x4b5000d1,0xc5b80154}},	//   _càta, _نوێژ, йъәт, ংলাপ, 
   {{0x588447c9,0x68340118,0xfca800f1,0x6a6c02d2}},	//   шыла, _rádc, _لاړو_, dúfu, 
   {{0xf9c40166,0x36d402e8,0xd62400ae,0x00000000}},	//   _газү, щопр, لعدي, --, 
   {{0x7a3400e8,0xd94447ca,0x49e40050,0x80ac2cc5}},	//   _fàta, _кези, _نغمہ, _ছিন্, 
   {{0x0d940302,0x7414475c,0x3ae0007f,0xcd940375}},	//   יכים_, مودا, lòp_, ידית_, 
   {{0x26cc47cb,0x9f50145e,0x1cd80135,0x69d40790}},	//   breo_, reyê_, _འདན_, _özer, 
   {{0x26cc3a64,0xc458023a,0xd90c0133,0x969447cc}},	//   creo_, риях_, _ریک_, _треш, 
   {{0xe7f807b7,0x25dc00ab,0x00000000,0x00000000}},	//   ्यथा_, _खायी_, --, --, 
   {{0x68340122,0xa3e001ad,0x2fc40150,0x0678123b}},	//   _háda, _नॉक_, йраң, _שנול, 
   {{0x7f94086f,0x3ae00100,0x044400f0,0xa020032e}},	//   жатх, kòp_, _мејн, _íöll, 
   {{0xe7f806e3,0x9f50007f,0xeb980131,0xd12c00cf}},	// [4910] ्यता_, neyè_, қил_, سۅڭ_, 
   {{0x313447cd,0x59d007f8,0x2aac01e1,0x00000000}},	//   _геор, _सागर, _lóbò_, --, 
   {{0x03ec00bd,0xbe8847ce,0x26cc0fcf,0xbd6847cf}},	//   য়ারী_, рсте_, zreo_, арце_, 
   {{0xc5f00882,0xa2cc47d0,0x5d84013e,0x7a3400a3}},	//   _अस्य_, _तिम्, стуҷ, _ràta, 
   {{0xa9a447d1,0x27140085,0x59d00490,0x7a3400a3}},	//   билд, pɛnɛ_, _साखर, _sàta, 
   {{0x8d7447d2,0x6d580e78,0x20580023,0x66000175}},	//   _نازا, ßwas, _ወብሳይ, xdlk, 
   {{0x2ef403be,0x32000109,0x1c000037,0x00000000}},	//   şafı_, _mahy_, _रोकल_, --, 
   {{0x32000851,0x26cc47d3,0x1cc0025c,0xc0d802d3}},	//   _lahy_, treo_, _གྷི_, ክእሉ_, 
   {{0x68340077,0x2aac01e1,0x3ae0180f,0xe4c400d1}},	//   _cáda, _dóbò_, còp_, әйми, 
   {{0x26cc47d4,0xa2cc03f8,0x320006d9,0xe61847d5}},	//   rreo_, _तिब्, _nahy_, удо_, 
   {{0xb8cc0729,0x26cc1505,0x084001d9,0x00000000}},	//   _কয়_, sreo_, _وۆتُ, --, 
   {{0xa414015b,0x0ec403ba,0x442403b2,0x24500064}},	//   াস্য_, _लिंड, ðm_, kšme_, 
   {{0x32000280,0xe78400db,0x00000000,0x00000000}},	//   _bahy_, _الشپ, --, --, 
   {{0x60cc0175,0xc4480066,0x00000000,0x00000000}},	//   trbm, _چیدن_, --, --, 
   {{0x320003d1,0x2c50012d,0xaad00456,0xfbd80456}},	//   _dahy_, lądu_, _समझक, _डालम, 
   {{0xa0a41884,0x25dc13f7,0xe7f800c5,0x00000000}},	//   _қамд, _खाडी_, ्यिा_, --, 
   {{0xe7e82413,0x32000332,0xd00412e7,0xa2b00037}},	// [4920] झ्या_, _fahy_, щете_, _अबट्, 
   {{0xf1d401c6,0xdddc012d,0xe1f8009b,0x00000000}},	//   _мөсө, wopł, _сго_, --, 
   {{0x23bc0034,0x3ae00100,0x00000000,0x00000000}},	//   _्याद, wòp_, --, --, 
   {{0xc0d8044e,0xdee408e1,0x307402a9,0x3ae00ba1}},	//   ክእል_, _ломи, _муяс, tòp_, 
   {{0x200047d6,0x1cd82fb5,0x68e001d5,0x32000009}},	//   _iaki_, _འདམ_, _aqld, _yahy_, 
   {{0x200047d7,0x81c80729,0x9f40007f,0xfe780228}},	//   _haki_, োজক_, _dakô_, _түз_, 
   {{0x200047d8,0x68340332,0xda700014,0xed340153}},	//   _kaki_, _sáda, _ہُر_, _дэтэ, 
   {{0x200047d9,0x4aa447da,0x779847db,0xb8f00cba}},	//   _jaki_, шкән_, шкир_, _वट_, 
   {{0x50180302,0x386002b5,0xfb5400ec,0x00000000}},	//   רופו, ōiro_, _بھاد, --, 
   {{0x200047dc,0x683401d3,0x6f0800d7,0x00000000}},	//   _laki_, _váda, _šeck, --, 
   {{0x20000418,0x948447dd,0x320000e4,0xf8b847de}},	//   _oaki_, йымд, _rahy_, _төл_, 
   {{0x200047df,0x49140302,0x32000170,0xd6d82950}},	//   _naki_, _לקבל_, _sahy_, _бтк_, 
   {{0x7a340241,0x00000000,0x00000000,0x00000000}},	//   _jàto, --, --, --, 
   {{0x7e602959,0x00000000,0x00000000,0x00000000}},	//   _ímph, --, --, --, 
   {{0x200047e0,0x25dc007d,0x54a400c6,0x4fc401c6}},	//   _baki_, _खाती_, _احتف, йсаа, 
   {{0x200047e1,0xf48447e2,0x16140490,0xdbf00118}},	//   _caki_, _باتی, तावर_, _bříz, 
   {{0x200047e3,0x320047e4,0x43843e52,0xa3e006e3}},	// [4930] _daki_, _tahy_, _ىلىق, _नॉट_, 
   {{0x8778010f,0xe2a403b2,0x1afc00cc,0x00000000}},	//   ראמי, _æðan_, ংমাই_, --, 
   {{0x20001132,0xfbd000aa,0xacf813b1,0x59d00490}},	//   _faki_, ځته_, рнеу_, _साजर, 
   {{0xfbd047e5,0x20000270,0x64840055,0x6e4400ef}},	//   فته_, _gaki_, _uųit, _žubī, 
   {{0x8fd00831,0x68e0045a,0xe9f801ec,0x00000000}},	//   _мәҡә, _sqld, инді_, --, 
   {{0x200047e6,0x8cb847e7,0xb9e80220,0x00000000}},	//   _zaki_, _مدرس_, йміз_, --, 
   {{0x200047e8,0xd7ec04da,0xdbf000bc,0x7d24014b}},	//   _yaki_, چكى_, _zříz, _ефте, 
   {{0xd7ec1b16,0xa6c839f6,0x200047e9,0x013802e4}},	//   نكى_, алиа_, _xaki_, מרות_, 
   {{0x25dc1889,0x68340f91,0x49c80139,0x00000000}},	//   _खादी_, _fádn, _буем_, --, 
   {{0x6aa801ee,0x0a68026a,0x24e8013e,0x00000000}},	//   _itef, _срби_, амои_, --, 
   {{0xe57047ea,0xe86c0092,0x00000000,0x00000000}},	//   بطة_, ድረግም_, --, --, 
   {{0xf1a80375,0xd7e800db,0x7a3401e1,0x69c40162}},	//   _יס_, _نومۇ_, _yàto, ðhef, 
   {{0xe29847eb,0x200047ec,0xf86847ed,0x683400d7}},	//   раг_, _raki_, _امني_, _hádo, 
   {{0xa50847ee,0xe6100214,0x00000000,0x00000000}},	//   _века_, _زشت_, --, --, 
   {{0x91003d2a,0xdecc02d3,0x7e6000d8,0x10a001b9}},	//   мпре, _ኣዲኡ_, _ímpi, дисн, 
   {{0xdbf00316,0x6aa80421,0xe29847ef,0x3e740030}},	//   _příz, _otef, _каи_, mäti_, 
   {{0x200047f0,0xd24c1973,0x3e740793,0x683447f1}},	// [4940] _vaki_, رنہ_, läti_, _ládo, 
   {{0x200047f2,0x629000d0,0x224c0267,0x44e047f3}},	//   _waki_, úkoľ, _öfk_, oñ_, 
   {{0x200047f4,0x683447f5,0x6aa80857,0x3e74014a}},	//   _taki_, _nádo, _atef, näti_, 
   {{0x44e047f6,0xf1a847f7,0x200047f8,0x205447f9}},	//   iñ_, _پایه_, _uaki_, _фтор, 
   {{0xda6447fa,0x7a34002e,0x3e740793,0x78a800b5}},	//   овди, _fàtl, häti_, _stdv, 
   {{0x68342af5,0x316c054e,0x00000000,0x00000000}},	//   _bádo, şeze_, --, --, 
   {{0x6aa847fb,0xd7f80124,0x3ea0036e,0x08f40ada}},	//   _etef, ауп_, lqit_, قريب_, 
   {{0xdc3400d1,0x3e7400fd,0x00000000,0x00000000}},	//   _بىرخ, däti_, --, --, 
   {{0xb5fc038f,0x7b840150,0x44e00139,0xdecc0240}},	//   loġi, _ءازە, eñ_, _ኣዲኣ_, 
   {{0x291801e7,0x3e74013d,0x99480064,0x00000000}},	//   ógaí_, fäti_, _кпзб_, --, 
   {{0x6aa80175,0x44e0002e,0x3ea0036e,0x00000000}},	//   _ztef, gñ_, hqit_, --, 
   {{0x660c02a8,0x00000000,0x00000000,0x00000000}},	//   _ɗaki, --, --, --, 
   {{0x44e047fc,0x261001ad,0x25e401ad,0x3ea0036e}},	//   añ_, ताखी_, _जॉकी_, jqit_, 
   {{0x7e04000b,0xd4980114,0x658400e4,0x00000000}},	//   रयोग_, _кри_, ñuhä, --, 
   {{0xf4340276,0xfa880023,0xdecc0023,0x00000000}},	//   _некэ, _ምዃነይ_, _ኣቲኻ_, --, 
   {{0x3ea0011f,0xef9847fd,0xc6c001af,0x00000000}},	//   fqit_, скаш_, _эйәк, --, 
   {{0x5edc009e,0xd4a002dd,0xa6440345,0x00000000}},	// [4950] _নৈবে, _ﺍﻟﺠﻨ_, _بخۆن, --, 
   {{0xbe180212,0x00000000,0x00000000,0x00000000}},	//   ожує_, --, --, --, 
   {{0x201401a2,0xfe0806f6,0x68ec033f,0x648400b8}},	//   ácií_, تقلي_, ładz, _kųip, 
   {{0x68340518,0x506400d4,0x6e940117,0x00000000}},	//   _rádo, _єтна, _ниму, --, 
   {{0xa9a447fe,0x27e800c7,0x00000000,0x00000000}},	//   пилд, _ñani_, --, --, 
   {{0x9f40011f,0xba2805a9,0xa2cc18cc,0x683400d0}},	//   _ubká_, قسىم_, _तिस्, _pádo, 
   {{0x98a02f59,0xe8f8023b,0x7c48148b,0x00000000}},	//   нище, ёли_, ðsrá, --, 
   {{0x683401d3,0x25dc0037,0x3e7400d7,0x1ad800cc}},	//   _vádo, _खाही_, väti_, _ধনৰা, 
   {{0x41dc11a0,0x6aa801e3,0xb86400f1,0x00000000}},	//   _बालस, _utef, باوو, --, 
   {{0x3e74014a,0x29d40150,0x7ae40e89,0x00000000}},	//   täti_, _ءياس, àite, --, 
   {{0xd7a000e8,0xe568084c,0x00000000,0x00000000}},	//   _njoη, синд_, --, --, 
   {{0x3e7447ff,0x3ea00023,0x4acc00c5,0x00000000}},	//   räti_, yqit_, _हटाव, --, 
   {{0x9878008d,0xa3e02c35,0x3a74010a,0x00000000}},	//   _פאנט, न्ग_, _алăр, --, 
   {{0x3e7401b8,0x00000000,0x00000000,0x00000000}},	//   päti_, --, --, --, 
   {{0x55b80375,0xd5ac188d,0xa2cc0fe6,0xf58400db}},	//   _המצו, _صفي_, _तिव्, _ۉشۉپ, 
   {{0xada00589,0xe3b80b96,0x00000000,0x00000000}},	//   ãºna, _уби_, --, --, 
   {{0x683401ef,0x00000000,0x00000000,0x00000000}},	// [4960] _rádl, --, --, --, 
   {{0x3ea00023,0x68340118,0x00000000,0x00000000}},	//   rqit_, _sádl, --, --, 
   {{0xa0680372,0x68340306,0x1be80108,0x6e3401e1}},	//   _гана_, _pádl, йджи_, _ńgbé, 
   {{0x683404d4,0x41dc0d2b,0x00000000,0x00000000}},	//   _bádm, _बाँस, --, --, 
   {{0x3ea00140,0x68344800,0xf6e80327,0x63a40076}},	//   qqit_, _cádm, _འདེང, ickn, 
   {{0x1ea800aa,0x64a002b1,0x00000000,0x00000000}},	//   _پاڼي_, _rēin, --, --, 
   {{0x64a00093,0x48a44575,0x23bc00cd,0x00000000}},	//   _sēin, птым_, ्णाद, --, 
   {{0xd6d800d6,0x8d580375,0x310c00dc,0x1de001f9}},	//   бто_, _הכלי, हितः_, _पाडत, 
   {{0xa2cc0882,0xbbd82e1e,0x7c38017a,0x41dc1bbb}},	//   _तिष्, डलीक, ëvru, _बांस, 
   {{0xceb00302,0xd90c4801,0x09e000f3,0x00000000}},	//   עית_, _میت_, _поун, --, 
   {{0x25dc4802,0x26102ce1,0x2d8402f0,0x00000000}},	//   _खारी_, ताजी_, _úlet_, --, 
   {{0x897800c8,0x64a00374,0x00000000,0x00000000}},	//   _פראצ, _tēin, --, --, 
   {{0x8334011c,0x00000000,0x00000000,0x00000000}},	//   енях, --, --, --, 
   {{0xa2cc44af,0x2c740140,0x25a401ab,0x00000000}},	//   _तिर्, rådi_, ccll_, --, 
   {{0xd8e402dd,0x00000000,0x00000000,0x00000000}},	//   _ﺍﻛﻪﻟ, --, --, --, 
   {{0x4fc401c6,0x04d80a7c,0x00000000,0x00000000}},	//   ясга, _הקהל, --, --, 
   {{0x64a00421,0x26100490,0xdddc00bc,0x648400df}},	// [4970] _lēil, ताची_, lopř, _קעפּ_, 
   {{0x71780798,0x3da4004e,0x00000000,0x00000000}},	//   _мбпр_, ерцб, --, --, 
   {{0xfe7000c6,0x00000000,0x00000000,0x00000000}},	//   ادق_, --, --, --, 
   {{0x683400d7,0x00000000,0x00000000,0x00000000}},	//   _pádm, --, --, --, 
   {{0xa3e012eb,0x25dc34f8,0xd6c40214,0xdddc0118}},	//   न्ट_, _खाली_, _جق_, hopř, 
   {{0x7c582e51,0xee900014,0x417401ec,0x6f0c01f5}},	//   يلەر_, _شۯاک, _تاۋس, mvac, 
   {{0x2ee800fc,0xa8883da1,0x200c022c,0xe8f802bf}},	//   ltaf_, ойка_, _økið_, іли_, 
   {{0x660c02a8,0x888006ce,0x2ee8208d,0x7a340e89}},	//   _ɗaku, ریشن, otaf_, _làth, 
   {{0xfaf04803,0x2ee80cfd,0xd70434d8,0xc5e42fb5}},	//   _مثل_, ntaf_, дные_, _འཁྱི, 
   {{0x28dc0490,0x41dc3be5,0x00000000,0x00000000}},	//   नंदि, _बाइस, --, --, 
   {{0x6d440399,0x6f0c1505,0xab5c025c,0x91e00eac}},	//   nzha, hvac, _beżg, য়াখ, 
   {{0x6d444804,0xf77003e6,0x2ee8020c,0x80ac00fe}},	//   izha, _ڵان_, ktaf_, _ছিল্, 
   {{0x1cc00135,0x7a3401c3,0x27ec02a8,0x6f0c00d0}},	//   _གྷན_, _bàth, mfen_, jvac, 
   {{0xc5e40ed9,0x27ec0639,0x6f0c16d1,0x7a3401ab}},	//   _འཁྲི, lfen_, dvac, _càth, 
   {{0x160405f9,0x7a3401ab,0x386c00c7,0x27ec04e6}},	//   _वोटर_, _dàth, _éirõ_, ofen_, 
   {{0x6d4406e4,0x3e740036,0x00000000,0x00000000}},	//   dzha, hätt_, --, --, 
   {{0x2cac0640,0x27ec101c,0x1ea8004b,0x1300010b}},	// [4980] _čeda_, ifen_, تازي_, _азым, 
   {{0xd12c01ed,0x7a3401ab,0xb7d40ca8,0x3e740254}},	//   دمہ_, _gàth, _iṣee, jätt_, 
   {{0x27ec03e0,0x5c04130f,0xa0c4009f,0x6d4403ac}},	//   kfen_, дяла, _تيجو, gzha, 
   {{0xa3e0166d,0x27ec01f5,0x61ec4805,0x7a3401e1}},	//   न्च_, jfen_, lfbl, _tàtk, 
   {{0x6d44030a,0x27ec0327,0x8c4403b9,0xeef40024}},	//   azha, dfen_, _sağç, _пярэ, 
   {{0x27ec4806,0x68340332,0x00000000,0x00000000}},	//   efen_, _hádh, --, --, 
   {{0x27ec4807,0xf8b000f1,0xdca4030d,0x00000000}},	//   ffen_, اکئ_, _цаби, --, 
   {{0x27ec00a9,0xdb4c03e6,0x7a340248,0x25a80166}},	//   gfen_, _پێت_, _màti, _ğala_, 
   {{0xa3e002f8,0x7bc000ef,0x00000000,0x00000000}},	//   न्छ_, _iemu, --, --, 
   {{0x7bc04808,0x27ec4809,0x61ec01f5,0xca80009d}},	//   _hemu, afen_, jfbl, _агуй, 
   {{0x7bc0480a,0xe8ec05d9,0x6f0c006f,0x7a3401c3}},	//   _kemu, _هڻي_, zvac, _ràth, 
   {{0x7bc0480b,0x68340232,0x6f0c480c,0x7a3401c3}},	//   _jemu, _nádh, yvac, _sàth, 
   {{0x7bc0480d,0x3e74014a,0xc2b802bf,0x07a0480e}},	//   _memu, näts_, мляє_, _рачн, 
   {{0x7bc0480f,0xd3a001ec,0x00000000,0x00000000}},	//   _lemu, _ﺍﯞﯨﻖ_, --, --, 
   {{0xf70801fb,0x6f0c007f,0x00000000,0x00000000}},	//   _hủ_, wvac, --, --, 
   {{0x7bc04810,0x6f0c4811,0x7a34004e,0x2ee8031c}},	//   _nemu, tvac, _dàti, ttaf_, 
   {{0x6e2400fb,0x7a3400a3,0xb27400f0,0x683401ef}},	// [4990] tjhb, _tàth, _плиш, _sádk, 
   {{0xab5c4812,0x7bc01730,0x7a3400db,0x6d444813}},	//   _jeże, _aemu, _fàti, tzha, 
   {{0x7bc04814,0x2ee84815,0x3e7401e6,0xf7080051}},	//   _bemu, staf_, vätt_, _lủ_, 
   {{0x6d440dd4,0x09d40574,0x7bc04816,0x7054007b}},	//   rzha, ठल्य, _cemu, _أنحا, 
   {{0x6d4401d3,0xb82405ac,0x27ec05c7,0xd4a002dd}},	//   szha, যঘাত_, vfen_, _ﺍﻟﺴﻨ_, 
   {{0xdeb802e4,0x7f9438be,0x00000000,0x00000000}},	//   _ממשל, _шаях, --, --, 
   {{0x27ec0ab7,0x7bc04817,0x3e74049f,0x7a340137}},	//   tfen_, _femu, rätt_, _xàti, 
   {{0x7bc04818,0x27ec4819,0x7e600998,0x3e74049f}},	//   _gemu, ufen_, _ímpr, sätt_, 
   {{0x27ec481a,0xf708001e,0x00000000,0x00000000}},	//   rfen_, _củ_, --, --, 
   {{0x7bc00640,0xa524481b,0x1780481c,0xe524481d}},	//   _zemu, емод, ыгым, едоп, 
   {{0x7bc0481e,0x27ec481f,0xab5c0135,0x69c04820}},	//   _yemu, pfen_, _deże, _iele, 
   {{0x29044821,0x7a3400db,0x3a2c00d7,0x00000000}},	//   _isla_, _ràti, _zodp_, --, 
   {{0x7a3400db,0x68344822,0x00000000,0x00000000}},	//   _sàti, _nádi, --, --, 
   {{0x69c04823,0x97540302,0xe7f80864,0xdb0001bf}},	//   _jele, _אינו_, ्यका_, rboø, 
   {{0x61ec017a,0x68340332,0xc224179e,0x00000000}},	//   rfbl, _pádh, _یکسو, --, 
   {{0x69c04824,0x1de00574,0x683403b2,0xe3b8004e}},	//   _lele, _पाहत, _bádi, _эби_, 
   {{0x7bc04825,0x68344826,0x1e843c5e,0x29040327}},	// [49a0] _remu, _cádi, елам, _lsla_, 
   {{0x7bc04020,0x68341ada,0x9d444827,0x290400d7}},	//   _semu, _dádi, незд, _osla_, 
   {{0x7bc04828,0x163400c8,0x628c0036,0x00000000}},	//   _pemu, ענער_, mmbo, --, 
   {{0x3e744829,0xa0680364,0x1de0482a,0x56780023}},	//   täts_, _хама_, _पावत, _ኣዒንቱ_, 
   {{0x2904482b,0x7bc005b8,0xa3dc2e05,0x5f74482c}},	//   _asla_, _vemu, _ढाई_, _ساحر, 
   {{0xf708001e,0x7bc0482d,0x3e740e78,0xdb00067c}},	//   _rủ_, _wemu, räts_, scoï, 
   {{0x7bc0482e,0x628c0433,0x7d2432db,0xd8502309}},	//   _temu, imbo, _جہان, лекө, 
   {{0x69c0482f,0xfba40f4c,0x1e2c001f,0x7bc0019b}},	//   _eele, _ओलिम, _በማጠና, _uemu, 
   {{0xc6f42ecc,0x8c404830,0x2c7408cb,0x29044831}},	//   еных_, _сете, rådt_, _esla_, 
   {{0xe9a80451,0x16940014,0x00000000,0x00000000}},	//   _قدمن_, ژٕکھ_, --, --, 
   {{0x74144832,0x628c0810,0x59080327,0x00000000}},	//   نودا, dmbo, _གནིས_, --, 
   {{0xf7080016,0xda1c0ce0,0x058001e0,0x3cf80419}},	//   _tủ_, पावत_, ыуым, _mprv_, 
   {{0xab5c025c,0x00000000,0x00000000,0x00000000}},	//   _teże, --, --, --, 
   {{0x69c04833,0x96040597,0x056005f5,0x86980677}},	//   _xele, _سبتم, _өвчн, _זיגז, 
   {{0x2cac0e3c,0x683424c8,0x970000d1,0x00000000}},	//   _čedo_, _sádi, _شېھى, --, 
   {{0x4ea44834,0x237002e3,0x628c27f8,0x00000000}},	//   ержа, ọlọj, ambo, --, 
   {{0x6e9801c0,0xfe1c033f,0x00000000,0x00000000}},	// [49b0] двар_, नांस_, --, --, 
   {{0x50a00075,0x7f58020f,0x2bb807f7,0xb4e40037}},	//   _مەسل, хаус_, आर्थ, _कमाय_, 
   {{0x1de00825,0x00000000,0x00000000,0x00000000}},	//   _पारत, --, --, --, 
   {{0x447c010f,0xa25c0023,0x00000000,0x00000000}},	//   ִנגע, _ደቅናን_, --, --, 
   {{0x2440002e,0x8cd001ad,0x6e94007b,0x00000000}},	//   _yómb_, _डिवो, _للحا, --, 
   {{0x25e42802,0x00000000,0x00000000,0x00000000}},	//   ज्ञी_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69c04835,0x3c940364,0x683401ef,0x2c744836}},	//   _wele, _бисё, _ládv, råds_, 
   {{0xfae000bc,0xfc640395,0x6ed40950,0x1e2c0092}},	//   íště_, _сърн, यूचु, _በማጥና, 
   {{0x69c04837,0x3b544838,0x683402fb,0x316c0118}},	//   _uele, _скур, _nádv, řezy_, 
   {{0x95802f23,0x628c0477,0x7c240022,0x00000000}},	//   илье, vmbo, ŷire, --, 
   {{0x25dc2017,0x2af4007d,0x39400115,0xa534013d}},	//   _खाकी_, _इहाँ_, ĝist_, енүч, 
   {{0xca8c044e,0x66e44839,0x1de0033f,0x6604483a}},	//   _ምዃኖም_, _рола, _पालत, _апла, 
   {{0x628c483b,0x1fc8483c,0x00000000,0x00000000}},	//   umbo, िण्ड, --, --, 
   {{0xa5200116,0xa0a40137,0x90c00108,0xa2cc11a6}},	//   _түнҗ, табд, ибре, _तिक्, 
   {{0x64a002b5,0x233421b5,0xdfd0007b,0x628c01ab}},	//   _rēih, _ахор, شيط_, smbo, 
   {{0x7a341574,0xe28400f3,0x00000000,0x00000000}},	// [49c0] _kàtt, _илии, --, --, 
   {{0x7a34002e,0xd24c3c19,0xdd9400db,0x1de001f9}},	//   _jàtt, _وني_, نجاع, _पाळत, 
   {{0x6144483d,0x7a34002e,0x00000000,0x00000000}},	//   _рена, _màtt, --, --, 
   {{0x6444004d,0x683402f0,0xad5834bb,0x00000000}},	//   nhki, _zádv, хрух_, --, 
   {{0x5908025c,0x6d400254,0xdd9400c7,0x00000000}},	//   _གནངས_, _ülan, хаҧы, --, 
   {{0xd91807d8,0x7a34002e,0x9cb4007b,0x00000000}},	//   дьи_, _nàtt, _لمست, --, 
   {{0x68340241,0xaa940022,0xa3e0483e,0x6e64014b}},	//   _ládu, ыгшә, दला_, _серҷ, 
   {{0xb7880bd6,0x6c7401c6,0x00000000,0x00000000}},	//   нәле_, _буух, --, --, 
   {{0xb6f8185e,0x64440014,0x3ab4013d,0xd6d800d4}},	//   رىدا_, dhki, _сәет, єти_, 
   {{0x75d441b6,0x14c80c9e,0x35b40153,0x00000000}},	//   ديدا, мыми_, ыбор, --, 
   {{0x9804483f,0x7a341bce,0x81c802f5,0x3494004e}},	//   _аялд, _dàtt, উলা_, лаор, 
   {{0x683403b2,0x3860005a,0x6fe03885,0x00000000}},	//   _bádu, _ñir_, _फाइं, --, 
   {{0x7a341574,0xb034036b,0x1de00406,0x36d401f0}},	//   _fàtt, қнаш, _पांत, _солр, 
   {{0x2ef800ca,0x7a341bce,0xab5c025c,0x00000000}},	//   _rpsf_, _gàtt, _jeża, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x683400d2,0x64444840,0x7a3401e1,0xab5c033f}},	//   _fádu, chki, _kàts, _leża, 
   {{0x7a34002e,0x009400a8,0x01d80154,0xadf40150}},	// [49d0] _yàtt, ритэ, দ্ধদ, лпаш, 
   {{0xab5c031c,0x0378011a,0x00000000,0x00000000}},	//   _neża, _בתחת_, --, --, 
   {{0x24400162,0x683402f0,0xebd800d8,0x9f480419}},	//   _hóma_, _zádu, едеш_, čkár_, 
   {{0xaed40cef,0x2ef8009f,0x29184841,0xfbd04842}},	//   _йомш, _tpsf_, _čsa_, قته_, 
   {{0x2fc84843,0xaa580075,0x00000000,0x00000000}},	//   maag_, ниду_, --, --, 
   {{0x2fc84844,0x6a840724,0x6d40000d,0x3dcc00fe}},	//   laag_, ылла, _ülao, ৰ্বল, 
   {{0xe8f400c6,0x6444005b,0xdecc0023,0xe5a400d1}},	//   استخ, yhki, _ኣቲና_, һипи, 
   {{0x2fc80050,0xa6e405f5,0xa8044845,0xab9402dd}},	//   naag_, гжил, узил, _бибі, 
   {{0xe5a44846,0x7a3400e8,0x3c580276,0x00000000}},	//   липи, _pàtt, _ритэ_, --, 
   {{0x2fc80942,0x00000000,0x00000000,0x00000000}},	//   haag_, --, --, --, 
   {{0x2fc80067,0xc49c0150,0x00000000,0x00000000}},	//   kaag_, _ﺍﻟﺒﺘ_, --, --, 
   {{0x999c007f,0x2fc80660,0xe35401c0,0x683400d8}},	//   _antň_, jaag_, гтгэ, _pádu, 
   {{0x2fc84847,0x4de0012c,0xf6080133,0x4e000dba}},	//   daag_, खलाई_, رتیه_, रजाई_, 
   {{0x64444848,0x6fe002ab,0xb9080055,0x06240150}},	//   shki, _फाउं, _ahiṃ_, _شۋجي_, 
   {{0x213c19f9,0x66004849,0x66e400d1,0xf6500137}},	//   áth_, melk, _роһа, _بئن_, 
   {{0x2fc80014,0xd004484a,0xa03419c5,0x00000000}},	//   gaag_, лесе_, دىرت, --, 
   {{0x4420484b,0x64540537,0x26cc484c,0xf3c8484d}},	// [49e0] _ini_, _imyi, nseo_, _شبيه_, 
   {{0xa204484e,0x53980375,0x6600484f,0x69c401a8}},	//   _спод, _איפו, nelk, ðhel, 
   {{0x629c4850,0x44204851,0x6d4000c5,0xd654011a}},	//   _iipo, _kni_, _ülal, ניעת_, 
   {{0x2fc84852,0xdecc1ee0,0x50d800c8,0x66004853}},	//   caag_, ብሊክ_, _אקטא, helk, 
   {{0x629c4854,0xda784855,0x44204856,0xab5c031c}},	//   _kipo, няк_, _mni_, _peża, 
   {{0x442001b9,0x58f8025c,0x629c4857,0x00000000}},	//   _lni_, _ྒྱུས_, _jipo, --, 
   {{0x44204858,0x66004859,0x629c485a,0x9d44485b}},	//   _oni_, delk, _mipo, _севд, 
   {{0x629c485c,0x4420485d,0x8c4014a4,0x28d40037}},	//   _lipo, _nni_, _лесе, _धिरि, 
   {{0x6600485e,0x629c0588,0xab5c0135,0xaae4485f}},	//   felk, _oipo, _teża, _نسلو, 
   {{0x44204860,0x64544861,0xd94404a9,0xb7880032}},	//   _ani_, _amyi, _йези, нәһе_, 
   {{0x44204862,0xf8c8000d,0x2fc8058a,0xdcec00de}},	//   _bni_, _रबिय, yaag_, _izbē, 
   {{0x629c4863,0x00000000,0x00000000,0x00000000}},	//   _aipo, --, --, --, 
   {{0x44204864,0x66004865,0x92684866,0x2fc84867}},	//   _dni_, belk, ерва_, vaag_, 
   {{0x44204868,0x629c4869,0x6600058a,0x2fc81a78}},	//   _eni_, _cipo, celk, waag_, 
   {{0x629c486a,0x506405f5,0x4420486b,0x2fc80067}},	//   _dipo, гтаа, _fni_, taag_, 
   {{0xa2cc0574,0x4420486c,0x629c00c7,0x244003f2}},	//   _तिच्, _gni_, _eipo, _tóma_, 
   {{0xcdd826e5,0x2fc8486d,0x629c06d9,0x68340306}},	// [49f0] ење_, raag_, _fipo, _kádr, 
   {{0x7c20007f,0x442001b9,0x1ee8036b,0x683400bc}},	//   _anmr, _zni_, ئولی_, _jádr, 
   {{0x4420486e,0x705400aa,0xca6802dd,0xd24c0451}},	//   _yni_, _نندا, рiнi, _ونڊ_, 
   {{0x78b8074d,0x6600068f,0x629c486f,0x00000000}},	//   dpvv, zelk, _zipo, --, 
   {{0x629c047e,0x66004870,0x00000000,0x00000000}},	//   _yipo, yelk, --, --, 
   {{0x68340232,0x629c0d81,0x64a000b0,0xfbd00b38}},	//   _nádr, _xipo, _kēit, قتۇ_, 
   {{0x7a344871,0xe7e801f9,0xda6c01f7,0x00000000}},	//   _pàtr, झ्झा_, بُو_, --, 
   {{0x26cc27be,0x66004872,0x00000000,0x00000000}},	//   tseo_, welk, --, --, 
   {{0x4420036b,0x66044873,0x9be801af,0x00000000}},	//   _rni_, аппа, _шырҡ_, --, 
   {{0xdb0005f7,0x26cc003a,0x6b8801a4,0x6600017a}},	//   mboð, rseo_, _izeg, uelk, 
   {{0x81dc000e,0x44204874,0x26cc4875,0xdb002833}},	//   ণ্ড_, _pni_, sseo_, lboð, 
   {{0xd7544876,0x629c4877,0x66004878,0x44204879}},	//   الیت_, _sipo, selk, _qni_, 
   {{0x629c2af2,0x660005f5,0xe2840853,0x4420487a}},	//   _pipo, pelk, илми, _vni_, 
   {{0x442025a9,0x46800046,0x629c0869,0x66000784}},	//   _wni_, _ықпа, _qipo, qelk, 
   {{0x2054487b,0x629c016d,0x4420487c,0x6728025c}},	//   атар, _vipo, _tni_, lxej, 
   {{0x4420487d,0x6454487e,0x8fa0487f,0x629c047e}},	//   _uni_, _umyi, жате, _wipo, 
   {{0x6b880516,0xdee44880,0xd0040861,0xe24c044e}},	// [4a00] _nzeg, рози, шете_, _ሃገርና, 
   {{0xa3e40cb4,0x244001e1,0xe2984881,0xca680150}},	//   _काँप_, _kómo_, _шап_, рiмi, 
   {{0xa0680022,0x6b884882,0xab5c012d,0xa3c8000d}},	//   _аана_, _azeg, _beżo, _लजा_, 
   {{0x1ec84883,0x9310006c,0x717000db,0x516400cf}},	//   _илми_, _اویش, _رۇقا, _түсү_, 
   {{0x6b88068f,0xab5c0327,0x244047f1,0x6edc0073}},	//   _czeg, _deżo, _lómo_, _पियु, 
   {{0x6b884884,0x8a1400d1,0x22480051,0x99f400d4}},	//   _dzeg, لتىس_, nhbk_, ряді, 
   {{0xa3e4012c,0xdc984885,0x6b884886,0x3834005b}},	//   कलाप_, _аташ_, _ezeg, йнкр, 
   {{0xd7f80372,0x687c02d3,0x6834219b,0xab6400ef}},	//   тук_, _ኣባይቲ_, _sádr, _saļņ, 
   {{0x683400c6,0x2cac009b,0x76480042,0x59d41913}},	//   _pádr, _čedi_, thdy, _نغار, 
   {{0xaa084887,0x99740166,0x316c0356,0xdcec0171}},	//   _مزمل_, _куеш, şezi_, _uzbē, 
   {{0x24404888,0x3d04033f,0x18a44889,0xd4a001ec}},	//   _cómo_, _रनों_, _таем, _ﺍﻟﺒﻨ_, 
   {{0x15e0033f,0x87e002e8,0x00000000,0x00000000}},	//   _खाकर_, _дюше, --, --, 
   {{0x78a8488a,0x59b80490,0xab5c031c,0xc7f40375}},	//   _hudv, _उभार, _neżl, _כזאת_, 
   {{0x78a8003c,0x6298007f,0x3134013d,0x00000000}},	//   _kudv, ňton, бегр, --, 
   {{0x765800ca,0x60ac0075,0x3494084c,0x78a80064}},	//   _imvy, _ﻳﺎﺧﺸ, _лакр, _judv, 
   {{0x78a8047e,0x85980375,0xc454027d,0x854000fb}},	//   _mudv, _בשוו, _وضيع, _фэше, 
   {{0x5ca41c5c,0x78a8488b,0x2d84488c,0xab5c031c}},	// [4a10] ەلمە, _ludv, _šle_, _reżo, 
   {{0xfe70004b,0x6d400037,0x6edc0037,0xdb000174}},	//   ودل_, _ülak, _पिठु, vboð, 
   {{0x6b8800dd,0xb7f8166d,0xac18005b,0x27f001d3}},	//   _szeg, ्जाम_, ложу_, őzni_, 
   {{0xf3900241,0x29000784,0x70543267,0x8bb401ec}},	//   _aṣia_, çham_, _چنگا, рқау_, 
   {{0x6a1405f5,0x78a802d2,0x4ae80108,0x67280003}},	//   ймду, _audv, тьем_, xxej, 
   {{0xa968488d,0x78a81050,0xdb00041e,0x00000000}},	//   лила_, _budv, rboð, --, 
   {{0xda6000e6,0xab5c0135,0x01fc0677,0x00000000}},	//   явши, _teżo, דפול, --, 
   {{0x83f00134,0xdb000436,0x0f4c0092,0x78a800d7}},	//   _amɑn, pboð, _መመስረ, _dudv, 
   {{0xc9e80022,0xa2880092,0x00000000,0x00000000}},	//   _афед_, _በጅጅጋ_, --, --, 
   {{0x78a800d2,0x2328013e,0xca740116,0xe64400d8}},	//   _fudv, ҳоми_, _ئارغ, сеоп, 
   {{0xda78008f,0x78a808fb,0x9d1c0150,0x8d280023}},	//   _ענער, _gudv, _ءﺩﯗﺭ, _ተዋሃሂ, 
   {{0x4aa810f7,0x6aa009f0,0xe28c022e,0x00000000}},	//   _चढाव, _hilf, _shа_, --, 
   {{0xe5a4488e,0xc6a4084c,0x6728031c,0x8d880150}},	//   _лили, _треи, qxej, _ﺒﻭﺴﺕ_, 
   {{0xe5a4005e,0xdb0006ed,0x6aa8004c,0x7ae401ab}},	//   _уики, scoç, _muef, àiti, 
   {{0x6aa0488f,0x1a9800c8,0x6aa801c7,0x6d400254}},	//   _milf, טישע, _luef, _ülah, 
   {{0x35680116,0x92c400cc,0x00000000,0x00000000}},	//   _әрән_, _উমৰ_, --, --, 
   {{0x2010409c,0x6aa002d0,0x9ee808de,0x6e344890}},	// [4a20] rdyi_, _oilf, طفال_, _bozb, 
   {{0x213c0e89,0x00000000,0x00000000,0x00000000}},	//   ùths_, --, --, --, 
   {{0xdee4016c,0x8f64136b,0xdcb000d1,0x00000000}},	//   роҷи, _ғарб_, سىش_, --, 
   {{0x6aa04891,0x1ea81b80,0x00000000,0x00000000}},	//   _ailf, _ماسي_, --, --, 
   {{0x6aa80ffb,0x78a84892,0x00000000,0x00000000}},	//   _cuef, _sudv, --, --, 
   {{0x79a4052f,0x6e3408a4,0x6aa804e6,0xfce4036b}},	//   әрҙе, _gozb, _duef, _қоғо, 
   {{0x61e80008,0xdd90005e,0x6aa04893,0x26d801d3}},	//   _öflu, _ءوز_, _dilf, áson_, 
   {{0x6aa84894,0x78a8047e,0x7d1c0112,0x6e340419}},	//   _fuef, _vudv, _irrs, _zozb, 
   {{0x6e344895,0x6aa04896,0x95c84897,0x6aa80036}},	//   _âgbï, _filf, луна_, _guef, 
   {{0x22582a1f,0x6aa04898,0x6e340139,0x00000000}},	//   _nmpk_, _gilf, _xozb, --, 
   {{0xd7f800f4,0x99844899,0x64a000b0,0x00000000}},	//   _бул_, _الاو, _rēir, --, 
   {{0x3d0044ab,0xf8b800c7,0x7cdc054e,0x2258489a}},	//   _रहने_, _itĩ_, mără, _ampk_, 
   {{0xd79406d5,0x1db80243,0x5f080154,0x7cdc054e}},	//   _الشخ, ेरात, রমুখ_, lără, 
   {{0x6aa0022f,0xa784489b,0x3dd8003a,0x87b40166}},	//   _xilf, _بشمو, _ndrw_, _куәт_, 
   {{0x6e34489c,0x69c401a8,0xdcec0118,0xd498010a}},	//   _rozb, ðhei, _vybě, _йри_, 
   {{0x6fb812ab,0xa5641fae,0xd3a4004e,0x1e2c0092}},	//   ргар_, _بدهن, _уркп, _በማገና, 
   {{0x403400c9,0x6e34489d,0x7d1c02d0,0xc43c011a}},	// [4a30] четс, _pozb, _arrs, _תתחי, 
   {{0x6aa80204,0xf8b80022,0x29000784,0x22a40050}},	//   _ruef, _otĩ_, çhak_, _گٔیہ, 
   {{0xefe80092,0x00000000,0x00000000,0x00000000}},	//   ቅመው_, --, --, --, 
   {{0x6aa0489e,0x7cdc0356,0x4ad401d9,0x2fcc032e}},	//   _silf, dără, ماتھ_, _þeg_, 
   {{0xab280b2d,0x6aa82560,0x6aa00076,0x7d1c489f}},	//   рола_, _quef, _pilf, _errs, 
   {{0x6e3405a1,0x2fd80036,0x6f1c349c,0x0a680124}},	//   _uozb, _hdsg_, _irsc, ыреи_, 
   {{0x7cdc0356,0x00000000,0x00000000,0x00000000}},	//   gără, --, --, --, 
   {{0x6f1c1e31,0x98a0010b,0xe7a800f3,0x00000000}},	//   _krsc, мище, швил_, --, 
   {{0xed5848a0,0x6aa048a1,0xb8d00d5f,0xf8b800e4}},	//   _соң_, _tilf, _टू_, _etĩ_, 
   {{0xf9d400a8,0x3e740036,0xdb10007c,0x00000000}},	//   _ноуэ, wätz_, ögår, --, 
   {{0x7cdc0356,0x00000000,0x00000000,0x00000000}},	//   cără, --, --, --, 
   {{0xf770004b,0x6f1c48a2,0x00000000,0x00000000}},	//   _ګام_, _orsc, --, --, 
   {{0xd7ec00ae,0x00000000,0x00000000,0x00000000}},	//   _شكو_, --, --, --, 
   {{0x2fd80005,0x3e7401c7,0x3b000200,0x00000000}},	//   _adsg_, sätz_, çiqi_, --, 
   {{0x6f1c48a3,0x7de00241,0x2fd80112,0x614448a4}},	//   _arsc, _lásà, _bdsg_, цева, 
   {{0xe3b015d6,0xe2e448a5,0xa2b00412,0x44c401d3}},	//   _غرب_, _джип, _इंप्, mő_, 
   {{0x63b40472,0x27fc0399,0x44c400dd,0xb3e802dd}},	// [4a40] _ifyn, _mbwn_, lő_, _اعىل_, 
   {{0x6f1c003b,0xf1980ae5,0x00000000,0x00000000}},	//   _drsc, ﻛﺘﻪﭘ, --, --, 
   {{0x6f1c101c,0x1be848a6,0x5ba800db,0x44c400e5}},	//   _ersc, иджи_, акем_, nő_, 
   {{0xdee4136b,0x9b4416ac,0x7cdc0356,0x00000000}},	//   _қоҳи, يناو, vără, --, 
   {{0xb5fc025c,0xa2b003ce,0x00000000,0x00000000}},	//   liġe, _इंफ्, --, --, 
   {{0x27fc058a,0x7cdc054e,0x2b9001d5,0x44c401d3}},	//   _abwn_, tără, ریلس, kő_, 
   {{0x63b40368,0xb5fc0135,0x00000000,0x00000000}},	//   _ofyn, niġe, --, --, 
   {{0x44c401ed,0xe97003cc,0x2c440014,0x00000000}},	//   dő_, رۇند, _ٹیٖپ_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7cdc0311,0xd0100154,0x00000000,0x00000000}},	//   pără, হায়_, --, --, 
   {{0x3b0401e1,0x00000000,0x00000000,0x00000000}},	//   bépò_, --, --, --, 
   {{0x24900208,0xb5fc025c,0x25a80139,0x00000000}},	//   _chym_, diġe, _şalt_, --, 
   {{0x61fc05b1,0x938816a4,0x6d400254,0x00000000}},	//   _bbpl, рсна_, _ülav, --, 
   {{0x28d00034,0xd5ac00e5,0x4730187f,0x00000000}},	//   _सबमि, _جہد_, _юніс, --, 
   {{0x61fc02c4,0x63b400a9,0x09cc0154,0x00000000}},	//   _dbpl, _ffyn, _রামা, --, 
   {{0x80dc0254,0xcd28411c,0x00000000,0x00000000}},	//   _फिरे, یسان_, --, --, 
   {{0xdb0006af,0x64540373,0xadd8329e,0x00000000}},	// [4a50] rcoû, ëzie, ймау_, --, 
   {{0x32541ed2,0x6f1c00f3,0xff040b7e,0xabb800d1}},	//   _хвор, _vrsc, ьясн, _ﺧﯩﻴﺎ, 
   {{0x0ea402e5,0x833448a7,0x6fb40c75,0x00000000}},	//   _कंकड, _فریض, _ىمدا, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x44c4066d,0x6f1c48a8,0x09cc00eb,0x00000000}},	//   ző_, _ursc, _রাবা, --, 
   {{0x6f0c00ec,0xab5c0003,0xd7ec00d1,0x26d800e5}},	//   mwac, _jeżi, ۇكى_, ásom_, 
   {{0x6f0c002d,0xac1848a9,0x290000e4,0x625c0241}},	//   lwac, _лову_, ïha_, _ṣoko, 
   {{0x3d00028a,0x6f0c009f,0x44c401ed,0xfbcc0303}},	//   _रहते_, owac, vő_, ारणम, 
   {{0x9ba01066,0x24900363,0x6f0c13ee,0xbae4007b}},	//   _كەمى, _rhym_, nwac, _يكفي, 
   {{0x44c4066d,0xe3b016e6,0x24900652,0xe648228e}},	//   tő_, کرد_, _shym_, спод_, 
   {{0x6f0c48aa,0xa50848ab,0x244003b2,0x79500133}},	//   hwac, щена_, _hómi_, _لێوا, 
   {{0x6f0c48ac,0x44c401d3,0x244001e1,0xd0100011}},	//   kwac, rő_, _kómi_, হাড়_, 
   {{0x934048ad,0xe69400c7,0xd9f0000d,0x44c400e5}},	//   еняе, _еиды, _घामत_, ső_, 
   {{0xe29848ae,0x6f0c48af,0x201c48b0,0xb6a402dd}},	//   саг_, dwac, _şti_, _жиіл, 
   {{0x249048b1,0x057448b2,0xab5c031c,0x24400248}},	//   _thym_, _باشد, _deżi, _lómi_, 
   {{0x6f0c48b3,0x753c02c1,0xb5fc031c,0x00000000}},	//   fwac, ärze, riġe, --, 
   {{0x5ea4282b,0x27ec48b4,0x6f0c48b5,0xc1e801d5}},	// [4a60] سمال, igen_, gwac, _وکسل_, 
   {{0x6444049b,0x27ec04cc,0x61fc02d0,0x3d18033f}},	//   lkki, hgen_, _ubpl, फिले_, 
   {{0x602448b6,0x6f0c0050,0xd2380375,0xdcec0171}},	//   _една, awac, _הגיל, _izbī, 
   {{0x27ec0460,0x644448b7,0x6f0c00ca,0xb36c0023}},	//   jgen_, nkki, bwac, በራዉን_, 
   {{0x1fe4021a,0x6f0c0083,0x6444023a,0x70440092}},	//   _وکړي_, cwac, ikki, _የለባቸ, 
   {{0x27ec48b8,0x61ec48b9,0x98c40075,0x24400252}},	//   egen_, ngbl, псил, _dómi_, 
   {{0xdd8400dd,0xd7f80124,0xaf400092,0x99980210}},	//   _رجسٹ, буп_, _የመሰለ, _żyły_, 
   {{0xf86800ae,0x00000000,0x00000000,0x00000000}},	//   تمعي_, --, --, --, 
   {{0xab5c0034,0x92c4009e,0x244002d2,0x00000000}},	//   _odży, _উম্_, _gómi_, --, 
   {{0x27ec000f,0x0f540375,0x00000000,0x00000000}},	//   agen_, פיים_, --, --, 
   {{0xab5c48ba,0x24400085,0x6d400254,0xd77401d3}},	//   _reżi, _zómi_, _ülat, _کااع, 
   {{0x6f0c0bf1,0x61ec0af9,0x00000000,0x00000000}},	//   ywac, egbl, --, --, 
   {{0x63a400c7,0x09cc00eb,0x00000000,0x00000000}},	//   дырҕ, _রাতা, --, --, 
   {{0x644420ac,0x61ec48bb,0xb5640116,0x82a448bc}},	//   akki, ggbl, _ойлa, ешсе, 
   {{0x6f0c0a55,0xc5f8011a,0x00000000,0x00000000}},	//   wwac, _הפוט, --, --, 
   {{0xb4d80574,0x11f4034c,0xb36c02d3,0x403448bd}},	//   ाळी_, _کودک_, በራውን_, несс, 
   {{0xb274006c,0xd1e00023,0x61ec0175,0xc0580212}},	// [4a70] _олиш, _ዝዓቢ_, bgbl, чір_, 
   {{0x6f0c48be,0x27ec0007,0x244048bf,0xdd1000a2}},	//   rwac, zgen_, _rómi_, _küňr, 
   {{0x6f0c48c0,0x24403d64,0x00000000,0x00000000}},	//   swac, _sómi_, --, --, 
   {{0x26d800dd,0x244000e4,0x60d404ae,0xdc54028e}},	//   ások_, _pómi_, _קורא_, ورنک, 
   {{0xe468023a,0x5ebc0131,0x8d700092,0x00000000}},	//   ltöä_, ﻢﻛﯚﺭ, ባራቸው_, --, 
   {{0xd5a448c1,0xae0408b0,0x6e9422c3,0x27ec0208}},	//   _لف_, _توسى, _цигу, wgen_, 
   {{0x98b40348,0x644448c2,0x27ec48c3,0xe468005b}},	//   үләт_, ykki, tgen_, ntöä_, 
   {{0x27ec48c4,0x2d9000d8,0x68340030,0x244021f1}},	//   ugen_, _izze_, _hádz, _tómi_, 
   {{0xe468005b,0x61ec01e3,0x00000000,0x00000000}},	//   htöä_, ygbl, --, --, 
   {{0x27ec48c5,0x6d40000d,0xb4d80073,0x29d400ec}},	//   sgen_, _ülas, ाळू_, _آياس, 
   {{0x240848c6,0x27ec017a,0x7de801d3,0xe5a40798}},	//   онни_, pgen_, lésü, ќини, 
   {{0x61c43f55,0x7ae42481,0xa2b01fd5,0x32000055}},	//   वर्ष, šite, _इंद्, _abhy_, 
   {{0x64440664,0x7a34004e,0xe73800a8,0xf87000db}},	//   rkki, _ràtz, _фел_, _حۇيج, 
   {{0x2d901418,0x6444346c,0x7d1803b2,0x00000000}},	//   _ozze_, skki, ævsk, --, 
   {{0x69dc0270,0x61ec238a,0xd2ec030d,0x00000000}},	//   _ēsel, rgbl, _хlор, --, 
   {{0xb92400e4,0x9f5002bd,0xa3b4084d,0x00000000}},	//   _pysẽ_, deyò_, _च्च_, --, 
   {{0x2d900a49,0x9f480a9d,0xfbcc18cc,0x649c0241}},	// [4a80] _azze_, _öküz_, ारसम, _ṣiwa, 
   {{0x9d4448c7,0xc0dc0023,0xdbc403e3,0x7de801d3}},	//   мезд, ሕለል_, _köçd, désü, 
   {{0x649401e7,0x9cf40022,0x00000000,0x00000000}},	//   ráif, ьчаш, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2904020c,0x2d901418,0x2d842dba,0x649400e4}},	//   _apla_, _ezze_, _ølen_, aáig, 
   {{0x4fa00116,0x649401e7,0x00000000,0x00000000}},	//   _шияв, láid, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd6d848c8,0x69c4008c,0xdddc00b0,0xd7e40212}},	//   ото_, ðher, kopū, фіко, 
   {{0x3e380201,0xd90c48c9,0x290403cd,0x6d400254}},	//   _በማድረ, _چیت_, _epla_, _ülar, 
   {{0xd90c48ca,0x00000000,0x00000000,0x00000000}},	//   _نیت_, --, --, --, 
   {{0xb4d80073,0x98a400d8,0xd6180014,0x00000000}},	//   ाळे_, _жиже, متھا_, --, 
   {{0x8c400166,0x00000000,0x00000000,0x00000000}},	//   _äşte, --, --, --, 
   {{0x43941220,0x79880142,0x683400d0,0x8898011a}},	//   каюс, _hydw, _nády, _ובאי, 
   {{0xe468023a,0x5bcc00d1,0x00000000,0x00000000}},	//   ttöä_, _ﻗﯩﺰﻻ, --, --, 
   {{0x06800014,0xdbc40432,0x7de801d3,0x00000000}},	//   _جلوُ, _göçd, zésü, --, 
   {{0xeeb801b9,0x649401e7,0x683400d7,0x76480432}},	//   злаш_, gáid, _sádz, lkdy, 
   {{0xe468023a,0x09cc0154,0x00000000,0x00000000}},	// [4a90] stöä_, _রাসা, --, --, 
   {{0x244002f0,0xe4e400bc,0x00000000,0x00000000}},	//   _dómu_, _किमि_, --, --, 
   {{0x64940332,0x00000000,0x00000000,0x00000000}},	//   báid, --, --, --, 
   {{0x7c9404fb,0x7de801d3,0x649448cb,0x00000000}},	//   نشنا, tésü, cáid, --, 
   {{0xfbd048cc,0x244000d2,0x29040009,0x764803cd}},	//   شتن_, _gómu_, _spla_, kkdy, 
   {{0x19e80489,0xa2b003ce,0x7988015d,0x09cc0154}},	//   _རྐྱབ, _इंस्, _bydw, _রাহা, 
   {{0x2b480552,0x79880368,0x0c7448cd,0x9f5003b2}},	//   šac_, _cydw, _قدرد, leyð_, 
   {{0xe73848ce,0x0cc80574,0x79880142,0x6d4448cf}},	//   зеи_, ाठीम, _dydw, myha, 
   {{0x6d4448d0,0xd7040b32,0x9f501427,0x00000000}},	//   lyha, еные_, neyð_, --, 
   {{0x6b8848d1,0x79880042,0x7d280139,0x00000000}},	//   _iyeg, _fydw, _üssä, --, 
   {{0x6d4448d2,0x6b880124,0x7f4448d3,0x79880368}},	//   nyha, _hyeg, zyiq, _gydw, 
   {{0x6b880337,0x75b40032,0x2cb000a2,0xf74800ec}},	//   _kyeg, нғәт_, _muzd_, _ڪلهي_, 
   {{0x6d443c7e,0xe72848d4,0xc61400eb,0x00000000}},	//   hyha, _холд_, ়াবা_, --, 
   {{0x3d00033d,0xe604023a,0xdddc02b5,0x60c00010}},	//   _रहले_, ärää, tipō, _čomb, 
   {{0x6b880083,0x7f44009a,0x6d4400e4,0x91000108}},	//   _lyeg, wyiq, jyha, лпре, 
   {{0xdddc00b0,0x6b88238e,0x6d4403ac,0x00000000}},	//   ripō, _oyeg, dyha, --, 
   {{0x6b8848d5,0x64940597,0x00000000,0x00000000}},	// [4aa0] _nyeg, ráid, --, --, 
   {{0x649400c6,0x00000000,0x00000000,0x00000000}},	//   sáid, --, --, --, 
   {{0x6b8848d6,0x38b80022,0x6d4448d7,0x00000000}},	//   _ayeg, _oĩra_, gyha, --, 
   {{0x6b8848d8,0x2d9448d9,0x798848da,0x24400a87}},	//   _byeg, трус, _rydw, _tómu_, 
   {{0x6b880230,0x76483c8f,0x1b2000c7,0x99740240}},	//   _cyeg, ykdy, ыҟаҳ, _ይሕሸኒ_, 
   {{0xdcb008b0,0x961c0037,0x6d440857,0x64940332}},	//   _مىس_, _बफेट_, byha, náib, 
   {{0x6b8848db,0x00000000,0x00000000,0x00000000}},	//   _eyeg, --, --, --, 
   {{0xb9080316,0xb78802d9,0x00000000,0x00000000}},	//   _बि_, мәле_, --, --, 
   {{0xbbcc0316,0x6b881418,0x767412d7,0xaab80014}},	//   ारीक, _gyeg, клиф, _قدٕر_, 
   {{0x79880142,0x64540200,0x00000000,0x00000000}},	//   _tydw, ëzin, --, --, 
   {{0xbb4001ec,0x473048dc,0x00000000,0x00000000}},	//   _ﯞﺍﻥ_, نریز, --, --, 
   {{0xa2b0012d,0x00000000,0x00000000,0x00000000}},	//   _इंश्, --, --, --, 
   {{0xfdf005f9,0x00000000,0x00000000,0x00000000}},	//   _चांस_, --, --, --, 
   {{0xc7a00395,0x00000000,0x00000000,0x00000000}},	//   _сичк, --, --, --, 
   {{0x248001af,0xc690008f,0x116407d6,0x6d44035a}},	//   bokm_, _גאס_, رلری_, xyha, 
   {{0x24400321,0xe4e407b6,0x6d440857,0x00000000}},	//   _dóms_, _किति_, vyha, --, 
   {{0xf2c401c0,0xa3bc473c,0xadf400db,0x00000000}},	// [4ab0] _шөни, इडर_, кпаш, --, 
   {{0x6b880223,0x247448dd,0x9f500174,0x6d4448de}},	//   _ryeg, māma_, reyð_, tyha, 
   {{0x2440148b,0x9f5003b2,0x00000000,0x00000000}},	//   _tómt_, seyð_, --, --, 
   {{0x6d4448df,0x649401e7,0x2ca8007c,0x00000000}},	//   ryha, máic, öad_, --, 
   {{0x3a2c1161,0x2fc848e0,0x6ecc0034,0x247448e1}},	//   _bndp_, mbag_, दीशु, nāma_, 
   {{0x2fc848e2,0x3a2c48e3,0x6b881459,0xba240220}},	//   lbag_, _cndp_, _vyeg, лдік, 
   {{0x2fc8062c,0x64940332,0xf3e800fe,0x7ae40003}},	//   obag_, náic, ট্যৰ_, ġita, 
   {{0x2fc848e4,0x29000309,0x3858005b,0x7ac4008e}},	//   nbag_, çhaq_, ерью_, _әсте, 
   {{0x81dc03d4,0x6b880223,0xdb2400f1,0x7c2400e2}},	//   ণ্ট_, _uyeg, _ټولی, ķirt, 
   {{0xb0e002ab,0x2ee80e14,0xe64448e5,0x24741a14}},	//   _फिंग, iraf_, теоп, dāma_, 
   {{0x2ee848e6,0x39f00220,0x490010de,0x649400e4}},	//   hraf_, _اۋىز, _сүйг, jáic, 
   {{0x2fc80369,0x2ee80ac5,0xdb0001ab,0xe47c48e7}},	//   jbag_, kraf_, mcoò, _ötüş, 
   {{0x626448e8,0x828439b8,0xdc3400df,0x00000000}},	//   ناسق, лқид, דארט_, --, 
   {{0x2ee848e9,0x26d80306,0x06e00131,0x00000000}},	//   draf_, ásou_, _ﺋﻪﺳﻪ, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2fc848ea,0xd0041de6,0x78bc01d3,0x69c0041c}},	//   gbag_, кесе_, _érve, रुती, 
   {{0x2ee848eb,0x10a02218,0xd9f00073,0x93f80375}},	// [4ac0] graf_, ритн, _घालत_, _חלפי, 
   {{0x2fc80076,0x6d1c01ad,0xeaac010a,0x00000000}},	//   abag_, फिंग_, _угiу_, --, 
   {{0xdca448ec,0x3be801e0,0x2fc80363,0x649400e4}},	//   важи, елеү_, bbag_, cáic, 
   {{0x628c48ed,0xbbcc48ee,0xdc2801f7,0x00000000}},	//   llbo, ारेक, بسطه_, --, 
   {{0x628c0af9,0xda78447e,0x00000000,0x00000000}},	//   olbo, мяк_, --, --, 
   {{0x3e880166,0x8a000395,0x6fa401ec,0x00000000}},	//   _чигү_, изче, _ﻋﺭﻀﺎ_, --, 
   {{0x38c848ef,0x628c04e6,0x29000309,0x00000000}},	//   راثی_, ilbo, çhap_, --, 
   {{0x8c4048f0,0x38c801e1,0xb8141614,0x628c48f1}},	//   _кесе, _aìrò_, удиј, hlbo, 
   {{0xc6f434d8,0x8c40341e,0x6c7448f2,0xdb0c01e1}},	//   вных_, _тете, _сурх, _ídàg, 
   {{0xb7880184,0x8f98008f,0x60dc00f3,0x628c007c}},	//   мәһе_, ויפי, _ovpm, jlbo, 
   {{0x999c00b0,0x38c80241,0x499001d3,0x2fc800b5}},	//   _motū_, _dìrò_, _پیٹر, ybag_, 
   {{0x2ee848f3,0x247400e2,0x574800ee,0x00000000}},	//   yraf_, tāma_, _озем_, --, 
   {{0x38b80f99,0xc458034b,0x60c000ef,0x00000000}},	//   _hér_, тиях_, _čoma, --, 
   {{0x320400ee,0x38b801d3,0xc33000d1,0x64940022}},	//   ýly_, _kér_, زەپ_, táic, 
   {{0x2fc80334,0xd0184130,0x76c40154,0xded40023}},	//   tbag_, мфа_, _এটিএ, _ካባኻ_, 
   {{0x38b80f99,0x2ee82ad4,0xbbcc0316,0x649448f4}},	//   _mér_, traf_, ारोक, ráic, 
   {{0x2fc848f5,0x38b848f6,0xaf40001f,0xa2c0013d}},	// [4ad0] rbag_, _lér_, _የዘላለ, _гәск, 
   {{0x2ee848f7,0xedd4007b,0x31342cdd,0x00000000}},	//   rraf_, اياد, _беор, --, 
   {{0x94140490,0x2ee80790,0x50a000d1,0x00000000}},	//   _तसाच_, sraf_, _نەسل, --, 
   {{0xead80220,0x32103e8f,0x2ee80356,0x30340108}},	//   емді_, lezy_, praf_, _семё, 
   {{0xbf1446e8,0x38b80098,0x7ae402f0,0xd6c40346}},	//   _күтә, _aér_, šitn, _دق_, 
   {{0x321048f8,0xecd448dc,0xba082374,0x38b848f9}},	//   nezy_, _محرک, نتىك_, _bér_, 
   {{0x83f00134,0x38b81bce,0xb5fc031c,0x7d1803b2}},	//   _mmɑr, _cér_, riġl, ævst, 
   {{0x38b848fa,0xbb301884,0x6bd81f0d,0x00000000}},	//   _dér_, ﺭﺳﻪ_, _سوئس_, --, 
   {{0x645402d3,0xfc640801,0xa68448fb,0x672c01a6}},	//   ëzim, _търн, ллид, _šajb, 
   {{0x2cac045f,0xb5fc0003,0x38b80646,0x91bc0118}},	//   _hied_, liġj, _fér_, ्रोइ, 
   {{0x38b848fc,0x2cac1368,0x00000000,0x00000000}},	//   _gér_, _kied_, --, --, 
   {{0x2cac0652,0x26d801ed,0xb5fc025c,0x00000000}},	//   _jied_, ásos_, niġj, --, 
   {{0x2cac48fd,0x05100154,0x00000000,0x00000000}},	//   _mied_, িমের_, --, --, 
   {{0x2cac48fe,0x2ab8033b,0x38b80165,0x910002d9}},	//   _lied_, _mèb_, _yér_, әпте, 
   {{0x628c48ff,0x38b80de2,0x00000000,0x00000000}},	//   rlbo, _xér_, --, --, 
   {{0x2ab8067c,0x91bc01ad,0xdddc0118,0x00000000}},	//   _oèb_, ्रॉइ, topů, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [4ae0] --, --, --, --, 
   {{0x533400c8,0xbbcc4900,0x00000000,0x00000000}},	//   _ענין_, ार्क, --, --, 
   {{0x2cac4901,0x21684902,0x2440002e,0x247400e2}},	//   _bied_, _чини_, _yómp_, nāmo_, 
   {{0xdb0402f0,0x00000000,0x00000000,0x00000000}},	//   šmín, --, --, --, 
   {{0x38b80f99,0x20104903,0x2cac2517,0x2d0c02ab}},	//   _sér_, meyi_, _died_, सबॉल_, 
   {{0x20104904,0x38b84905,0x2ab8007f,0x6454045f}},	//   leyi_, _pér_, _dèb_, ëzij, 
   {{0xdd904906,0x2cac0254,0xe3d800cc,0xb6f800d1}},	//   _طور_, _fied_, _থানব, ھىدا_, 
   {{0x20104907,0xdb00172e,0x2cac1c1d,0x2ab802bd}},	//   neyi_, scoñ, _gied_, _fèb_, 
   {{0x94844908,0x38b80694,0x57b002dd,0xea8800d1}},	//   ғынд, _wér_, _құпт, رخۇن_, 
   {{0x38b84909,0x2010007f,0x2cac490a,0x4ef8010f}},	//   _tér_, heyi_, _zied_, עליג, 
   {{0x2010490b,0x2cac0007,0x321003d1,0xb594490c}},	//   keyi_, _yied_, vezy_, ринш, 
   {{0x2010490d,0xb7d8075e,0x04b400e5,0x938801d5}},	//   jeyi_, _شوتا_, دھوں_, есга_, 
   {{0x2010490e,0x69c00d2c,0x290c07f5,0x32100d2e}},	//   deyi_, रुवी, čkaš_, tezy_, 
   {{0x51843252,0x00000000,0x00000000,0x00000000}},	//   губа, --, --, --, 
   {{0x649400c6,0x3210490f,0x20101432,0xd9f001f9}},	//   máin, rezy_, feyi_, _घाईत_, 
   {{0x5184052f,0x649400c6,0x321005da,0x201004ba}},	//   _ҡуна, láin, sezy_, geyi_, 
   {{0x2cac4910,0xe8140927,0x2dd42b39,0x00940276}},	// [4af0] _ried_, ढ़ता_, ижар, ситэ, 
   {{0x64940553,0x2cac4911,0x00000000,0x00000000}},	//   náin, _sied_, --, --, 
   {{0x20104912,0x2cac4913,0x867825f9,0x0fe0010b}},	//   beyi_, _pied_, ערבו, _гөзү, 
   {{0x20101b0d,0x7c840902,0xfbd0007b,0xe9a802f2}},	//   ceyi_, буче, كته_, ۆگان_, 
   {{0x69d81d15,0x2cac0030,0x6a1400cf,0x00000000}},	//   _नजदी, _vied_, имду, --, 
   {{0xe9a820d3,0x2ab802e2,0xa9680353,0x2cac4914}},	//   نگان_, _vèb_, кила_, _wied_, 
   {{0x61e8045f,0x2ab84915,0x2cac4916,0xa85416a4}},	//   _ôfle, _wèb_, _tied_, итиј, 
   {{0xa6e44917,0x332800a3,0x2ab8007f,0x86b001ec}},	//   ажил, _orax_, _tèb_, бәкі, 
   {{0xfd10066d,0xb8fc0882,0x6d4000db,0x645400e2}},	//   _وجہ_, _तौ_, _àlab, ūzik, 
   {{0x7b74275c,0x20104918,0x64944919,0x09cc00eb}},	//   _اطفا, zeyi_, gáin, _রাকা, 
   {{0x5050001f,0x2010491a,0x69c0491b,0x2eb000bc}},	//   _መገንባ, yeyi_, _ifle, जदुत, 
   {{0x63b800bc,0x201000e8,0x94c800f1,0x00000000}},	//   ětno, xeyi_, کایې_, --, 
   {{0x649408de,0x20101b91,0x26780166,0xe6181188}},	//   báin, veyi_, _искэ_, _адл_, 
   {{0xe5a4491c,0xe2980323,0x3328020c,0x2010491d}},	//   _кили, таг_, _drax_, weyi_, 
   {{0x2010491e,0xa0681575,0x21a40120,0x00000000}},	//   teyi_, вава_, ривм, --, 
   {{0x2eb0012c,0x00000000,0x00000000,0x00000000}},	//   जदूत, --, --, --, 
   {{0x4420491f,0x33280407,0x20104920,0x69c004e6}},	// [4b00] _iai_, _grax_, reyi_, _ofle, 
   {{0x20101432,0x25a8010e,0x00000000,0x00000000}},	//   seyi_, _şaly_, --, --, 
   {{0x44204921,0x5bc42309,0x20102892,0x8fc00022}},	//   _kai_, لقال, peyi_, саӡҵ, 
   {{0x69c04922,0x44204923,0x12c40150,0x69c400e5}},	//   _afle, _jai_, _ﺒﻨﻅﺭ, űhel, 
   {{0x68e0013a,0x31d800cc,0x00000000,0x00000000}},	//   _avld, _তাতশ, --, --, 
   {{0x44204924,0x69c007ab,0x5f3c001f,0x00000000}},	//   _lai_, _cfle, _በራሳቸ, --, 
   {{0x44204925,0xdca44926,0x7d241973,0x09cc00bd}},	//   _oai_, _вави, _دہان, _রাখা, 
   {{0x44204927,0x69c0127b,0x3834084c,0x672c00ef}},	//   _nai_, _efle, снир, _šaja, 
   {{0xa2b04928,0x69c00042,0x95c84929,0x3604007b}},	//   _इंग्, _ffle, куна_, موظف, 
   {{0x4420492a,0x64540083,0x6d400e89,0x8af80677}},	//   _aai_, _alyi, _àlac, _בהמי, 
   {{0x4420492b,0x7c20492c,0xb7e80729,0x6454007f}},	//   _bai_, _kamr, ক্ষত_, _blyi, 
   {{0x4420492d,0x33280030,0xba3c0055,0xb59401d5}},	//   _cai_, _prax_, _bhįg, _қийш, 
   {{0x4420492e,0x629c01fa,0x649400ae,0xa8a400ec}},	//   _dai_, _bhpo, páin, _اصلو, 
   {{0x4420492f,0x7c200589,0x629c0810,0x3dd81327}},	//   _eai_, _lamr, _chpo, _nerw_, 
   {{0x44204930,0x93e407d6,0xd49822bf,0x64544931}},	//   _fai_, _кўпл, _ири_, _flyi, 
   {{0x44204932,0x7c200fb7,0xc0c80107,0x64940332}},	//   _gai_, _namr, руре_, náil, 
   {{0xb8d84933,0x3dd80042,0x7054113e,0xcdd80a5b}},	// [4b10] _མང_, _berw_, _ۇندا, вње_, 
   {{0x44204437,0x7c20005a,0x6494007b,0xd1f00023}},	//   _zai_, _aamr, háil, ፍስቲ_, 
   {{0x44204934,0x7c200472,0xc27c0375,0x705407f2}},	//   _yai_, _bamr, _ברזי, _هندا, 
   {{0x7c204935,0x44204936,0x69c0026c,0x3dd80af9}},	//   _camr, _xai_, _sfle, _eerw_, 
   {{0x69c04937,0x7c200e02,0xeb0800f4,0x649400c6}},	//   _pfle, _damr, اقتى_, dáil, 
   {{0x2fd80142,0xb5fc0327,0xc0dc0023,0xdb0400e5}},	//   _hesg_, biġi, ዕለሉ_, ámán, 
   {{0x9f9c0166,0x94140490,0x9c800427,0x7c20002f}},	//   _eçäk_, _तसंच_, _ščeg, _famr, 
   {{0x649400c6,0x7c200142,0xc95002dd,0xdbc4010e}},	//   gáil, _gamr, йтқы, _köýd, 
   {{0x44204938,0x2d900204,0x2fd80334,0xa7a80022}},	//   _rai_, _hyze_, _mesg_, ыкиа_, 
   {{0x44204939,0x7ae400e4,0x2bd40709,0x00000000}},	//   _sai_, âite, दरवा, --, 
   {{0x44201f4c,0x27f813ea,0x6454493a,0x64940332}},	//   _pai_, _مفاد_, _plyi, báil, 
   {{0x4420493b,0x2fd80472,0x649400c6,0x629c0023}},	//   _qai_, _nesg_, cáil, _shpo, 
   {{0x4420493c,0x6f1c017a,0x85b000d1,0xa6c41411}},	//   _vai_, _nssc, _мәнч, _اقتى, 
   {{0x4420493d,0xf770493e,0x614447c7,0xdddc00e2}},	//   _wai_, _تام_, бега, kopš, 
   {{0x4420493f,0x6f1c4940,0x64a44941,0x20544942}},	//   _tai_, _assc, _лака, бтар, 
   {{0x44e00c07,0x7d1c06ed,0x44204943,0xdddc0841}},	//   mı_, _rsrs, _uai_, dopš, 
   {{0x44e04944,0x8fa04945,0x7c204946,0x6f1c0334}},	// [4b20] lı_, зате, _ramr, _cssc, 
   {{0x7c2026b8,0x2174013e,0x7ae40427,0xb5fc031c}},	//   _samr, _гумр, šitk, tiġi, 
   {{0x44e04947,0x7c204948,0x6f1c4949,0xa068494a}},	//   nı_, _pamr, _essc, _бана_, 
   {{0x7c20494b,0x7d1c037e,0x672c031c,0x25a00118}},	//   _qamr, _vsrs, _ġajn, _úhlu_, 
   {{0x3f84025a,0x09cc00bd,0x44e02a15,0x7c20494c}},	//   _âmu_, _রাজা, hı_, _vamr, 
   {{0x44e00cc1,0x7c2003f0,0x29b400d1,0x00000000}},	//   kı_, _wamr, يجىڭ, --, 
   {{0x8d6028cf,0x44e0494d,0x6494494e,0x63b4007c}},	//   _евре, jı_, táil, _ogyn, 
   {{0x44e012ca,0xacb00075,0x63b40142,0x00000000}},	//   dı_, _قەلب, _ngyn, --, 
   {{0x649400c6,0x915c004d,0x6f1c00e4,0x76b81fbe}},	//   ráil, _mắt_, _xssc, јлор_, 
   {{0x14c8005e,0x273407a7,0x63b4494f,0x44e00ac1}},	//   лыми_, زىپس, _agyn, fı_, 
   {{0x44e00598,0x99484950,0x1cb40003,0xf4940020}},	//   gı_, _حلال_, _ཚངས_, _ማቅረብ_, 
   {{0x0d940375,0x69300214,0x6ac40162,0x977c0354}},	//   מכים_, _آکور, _útfø, _пулă_, 
   {{0x7ae40491,0x13684951,0x20bc01f2,0x4c98010f}},	//   áith, ушни_, _ọkpụ_, טשטע, 
   {{0x44e04952,0xf8840014,0x63b401d3,0xf1c8007b}},	//   bı_, _أچُ, _egyn, شورى_, 
   {{0x44e04953,0x61fc0334,0x915c004d,0xf8b80208}},	//   cı_, _dcpl, _bắt_, _trĩu_, 
   {{0x6f1c05b1,0x61fc02d0,0x2d900c5e,0x915c0208}},	//   _pssc, _ecpl, _ryze_, _cắt_, 
   {{0x2d900240,0x61fc0205,0x649400e4,0x00000000}},	// [4b30] _syze_, _fcpl, káij, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x61e8045f,0x63b4010e,0x6fb44954,0x00000000}},	//   _ôfla, _ygyn, _ومدا, --, 
   {{0x6f1c0175,0x8bb401ec,0x09b008a3,0x00000000}},	//   _tssc, сқау_, ुड्य, --, 
   {{0x44e00c02,0x70544955,0x6f1c04cc,0xe9d801f0}},	//   zı_, _هنگا, _ussc, акл_, 
   {{0x44e00bc7,0x672c00e2,0xfaa8007b,0x09cc0154}},	//   yı_, _šajo, مهني_, _রাঙা, 
   {{0xd94000a7,0xa8580640,0xc984010b,0x60c000d7}},	//   дещи, ијих_, щуди, _čomk, 
   {{0x25e02208,0x44e000fd,0x05100055,0x6e240175}},	//   पण्ण, vı_, _hiṇḍ, ldhb, 
   {{0x49184709,0x59c400bc,0x00000000,0x00000000}},	//   _मनवो_, रुहर, --, --, 
   {{0x44e04956,0xa504025c,0x7b640209,0x63b40142}},	//   tı_, _མྱུག_, _этсе, _sgyn, 
   {{0xe9744957,0xa50810f6,0x64a44958,0x630c015b}},	//   _بهاد, шена_, жана, িয়ায়_, 
   {{0x44e04947,0x76580eed,0x649400e4,0x00000000}},	//   rı_, _elvy, máik, --, 
   {{0x44e01ae6,0x24740aed,0xe3b04959,0x87242984}},	//   sı_, nāmi_, برد_, _دعام, 
   {{0x26cc495a,0x44e0495b,0x672801bf,0x915c0051}},	//   mpeo_, pı_, mvej, _sắt_, 
   {{0x6024495c,0x26cc0789,0x6728495d,0x7ae4025c}},	//   одва, lpeo_, lvej, ġiti, 
   {{0x7ae4495e,0x9fc801c0,0x26cc0129,0x00000000}},	//   šiti, ргаа_, opeo_, --, 
   {{0xd00c495f,0x67284960,0x0c980092,0x00000000}},	// [4b40] خلق_, nvej, _ሆቴሎች_, --, 
   {{0x24740aed,0xe0d84961,0x67280108,0x1e940150}},	//   dāmi_, _кво_, ivej, ірар, 
   {{0x41d002f8,0x0590001f,0x260000ab,0x915c0208}},	//   _त्यस, _ማንበብ_, _शानी_, _tắt_, 
   {{0x6aa00309,0x71584962,0xa3e80782,0x6e3402d0}},	//   _ahlf, _ырыс_, मणि_, _enzb, 
   {{0x1ea8038b,0x6d400129,0x57e001ec,0xeef40024}},	//   _ناسي_, _àlan, _ﺍﺩﯨﺮ, _нярэ, 
   {{0x98c44963,0x5398011a,0xab5c012d,0xfe44009d}},	//   осил, בינו, _jeży, _эмгү, 
   {{0xa3e829d9,0x08c001e0,0xa0bc0150,0x59c400cd}},	//   मणा_, үбән, _ﺑﺎرﯨ, रुषर, 
   {{0x247407d7,0x00000000,0x00000000,0x00000000}},	//   bāmi_, --, --, --, 
   {{0x672801bf,0xa02000a2,0x0b14007b,0x2474002b}},	//   gvej, _įöll, _وقفة_, cāmi_, 
   {{0x164800cf,0x55040139,0x00000000,0x00000000}},	//   рчип_, очма, --, --, 
   {{0xd7e402bf,0x34944964,0x00000000,0x00000000}},	//   _діло, занр, --, --, 
   {{0xb9c80201,0x2bb00c2e,0x63e00131,0x24400419}},	//   _ሲሉ_, ुँचा, ىۋىل, _kómy_, 
   {{0x59dc443a,0x6e240009,0xd7740956,0xac50010e}},	//   _नजार, ydhb, _بااع, lỳän, 
   {{0x999c0421,0xd6c40214,0x765800c0,0x00000000}},	//   _latō_, _همچی, _ulvy, --, 
   {{0x551c0034,0x6454045f,0x00000000,0x00000000}},	//   _बनिए_, êzic, --, --, 
   {{0x24740882,0x91c82e35,0xa504031c,0x03c400f5}},	//   yāmi_, _त्रै, _མྱིག_, _осьм, 
   {{0xd2444965,0x051000dc,0x7f9401ec,0xca680150}},	// [4b50] _дэни, _piṇḍ, датх, тiлi, 
   {{0x551c4966,0x00000000,0x00000000,0x00000000}},	//   _बनाए_, --, --, --, 
   {{0x0ca8036b,0x59dc3812,0xbd681f39,0xbac80014}},	//   атди_, _नज़र, орце_, ۪ژٲن_, 
   {{0x26cc0393,0x24744967,0xae4400f2,0x09cc00fe}},	//   ypeo_, tāmi_, _کپسو, _ৰাধা, 
   {{0xab281086,0xbca800d1,0xa03800d9,0xdd8c01d3}},	//   сола_, ڭدەك_, _הערפ, نڈہ_, 
   {{0x9af00075,0x9ba013bd,0x672801bf,0x649400e4}},	//   ركىت, رەلى, vvej, táik, 
   {{0xded402d3,0x576c02d3,0x6f1803e0,0x00000000}},	//   _ካባና_, ስዋእቲ_, şacı, --, 
   {{0x82fc0327,0x67280064,0x00000000,0x00000000}},	//   _ཞྀའུ_, tvej, --, --, 
   {{0x3c6803e6,0xab7c0153,0x00000000,0x00000000}},	//   _بینێ_, _сваi, --, --, 
   {{0x67284968,0x272800d0,0x00000000,0x00000000}},	//   rvej, _vĺn_, --, --, 
   {{0x67284969,0x26cc496a,0xab5c033f,0x00000000}},	//   svej, speo_, _reży, --, 
   {{0x22580b4f,0x00000000,0x00000000,0x00000000}},	//   _slpk_, --, --, --, 
   {{0x7ae4151c,0x39540030,0xa6c80354,0x00000000}},	//   šitv, časť_, _улла_, --, 
   {{0xaadc13da,0x00000000,0x00000000,0x00000000}},	//   नीयक, --, --, --, 
   {{0x2054496b,0x753c03fa,0x6144449b,0x64540023}},	//   птар, ärzt, чева, ëzis, 
   {{0xd37c01a6,0x5040009b,0x2600000d,0x00000000}},	//   šćak_, несб, _शाडी_, --, 
   {{0x1f64064d,0x61e8002d,0x00000000,0x00000000}},	// [4b60] чкам, _ôflo, --, --, 
   {{0xe1f8496c,0x00000000,0x00000000,0x00000000}},	//   _уго_, --, --, --, 
   {{0x6b9c069c,0x628c496d,0x999c00b0,0x91b8011a}},	//   _ዝሓለፈ_, mobo, _patō_, _למיי, 
   {{0xdb580454,0xc61400eb,0x00000000,0x00000000}},	//   йюл_, ়াটা_, --, --, 
   {{0x29040135,0x2000496e,0x00000000,0x00000000}},	//   _aqla_, _icki_, --, --, 
   {{0x4a50496f,0xf5e001e1,0x00000000,0x00000000}},	//   нкіс, _lẹrú_, --, --, 
   {{0xa3bc4970,0x00000000,0x00000000,0x00000000}},	//   ेडा_, --, --, --, 
   {{0x628c4971,0x29040175,0xc860023a,0xda641cc7}},	//   hobo, _dqla_, етьи, _کاري, 
   {{0x628c4972,0x99844973,0x24744974,0x00000000}},	//   kobo, _کلاو, nāmu_, --, 
   {{0x24902f5d,0xc87c00ac,0x00000000,0x00000000}},	//   _akym_, ışam_, --, --, 
   {{0x628c4975,0x18681f5a,0x8d740092,0x00000000}},	//   dobo, _лажи_, _ጨዋታው_, --, 
   {{0x7e60019f,0x4938011a,0x5344035b,0x00000000}},	//   _împf, _לגבו, пхга, --, 
   {{0x628c0408,0xd90c0dc4,0xa3bc2aa1,0x59c4012c}},	//   fobo, _شیک_, ेड़_, रुअर, 
   {{0x628c4976,0xb5582461,0x64540200,0x8f08035b}},	//   gobo, _милф_, ëzir, ҩхаа_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf484030f,0x00000000,0x00000000,0x00000000}},	//   _تاتی, --, --, --, 
   {{0x628c4977,0xaf5c001f,0x33740212,0x09cc03d4}},	// [4b70] bobo, _ለዘላለ, _ігор, _ৰাসা, 
   {{0x628c4978,0x03780375,0x672c0960,0x2000002f}},	//   cobo, _מתחת_, _šajk, _ecki_, 
   {{0xf10400db,0x00000000,0x00000000,0x00000000}},	//   _تۉزۉ_, --, --, --, 
   {{0xfc640801,0x6b744979,0x0a68497a,0xd9940150}},	//   нъчн, млеу, әрди_, _ﺘﺭﺘﺩ_, 
   {{0x0dc82461,0xcfa804fb,0x00000000,0x00000000}},	//   _губи_, _دادم_, --, --, 
   {{0x22940008,0xf9640133,0x2bd8000d,0x00000000}},	//   tæki_, کۆمێ, _ढ़का, --, 
   {{0x8c6401b9,0x00000000,0x00000000,0x00000000}},	//   _етад, --, --, --, 
   {{0x628c497b,0xa6c8497c,0x5b100b8d,0x69c00073}},	//   zobo, олиа_, хмәт, रुजी, 
   {{0x628c497d,0x260009fd,0x443c0208,0x00000000}},	//   yobo, _शादी_, _đv_, --, 
   {{0x2490002d,0x628c497e,0x2bd400dc,0x649400e4}},	//   _skym_, xobo, दरका, náiv, 
   {{0x628c497f,0x79500133,0x00000000,0x00000000}},	//   vobo, _مێوا, --, --, 
   {{0x628c4980,0xecd40034,0x26c000b0,0x64940022}},	//   wobo, डीएफ, _ōhou_, háiv, 
   {{0x649400c7,0x93400108,0x00000000,0x00000000}},	//   káiv, вняе, --, --, 
   {{0x21a44981,0x649400c7,0x46a40ce8,0xdcec0419}},	//   дигм, jáiv, _эшеб, _vzbĺ, 
   {{0xe7d04982,0x00000000,0x00000000,0x00000000}},	//   _सभाप, --, --, --, 
   {{0x628c4983,0x10a02424,0x9f5000ee,0xef180037}},	//   sobo, висн, ngyç_, _नईखऽ_, 
   {{0x628c4984,0x5e48026b,0x00000000,0x00000000}},	// [4b80] pobo, опам_, --, --, 
   {{0xe2902732,0x628c0472,0xf1c400c0,0x3fa40139}},	//   _جذب_, qobo, _pušų_, _ıruı_, 
   {{0xdbc4007d,0xec34036b,0x79500023,0x9f50010e}},	//   _mööd, کونگ, ንያታት, kgyç_, 
   {{0x247402b5,0xdbc40037,0x649400c7,0x2bd40456}},	//   pāmu_, _lööd, aáiv, दरगा, 
   {{0x649403df,0x00000000,0x00000000,0x00000000}},	//   báiv, --, --, --, 
   {{0x0f080154,0x00000000,0x00000000,0x00000000}},	//   রিখঃ_, --, --, --, 
   {{0xd7f803a5,0x2474005f,0xdb040356,0x00000000}},	//   оуп_, nāms_, âmân, --, 
   {{0x3eb84985,0x7ae4007b,0x64440083,0x6c7401c6}},	//   _hirt_, áits, jjki, _зуух, 
   {{0x3eb80036,0x1a044986,0x00000000,0x00000000}},	//   _kirt_, _опам, --, --, 
   {{0x64440218,0x6454045f,0x00000000,0x00000000}},	//   ejki, êzin, --, --, 
   {{0xe01c1b4c,0x38c84987,0x3eb800ef,0xa3e800cd}},	//   _पसंद_, _راضی_, _mirt_, मणं_, 
   {{0x2474005f,0x84340212,0x00000000,0x00000000}},	//   dāms_, внює, --, --, 
   {{0xd6284988,0x3eb800a3,0x00000000,0x00000000}},	//   _моде_, _oirt_, --, --, 
   {{0x3eb801e7,0xf7700451,0x4610009f,0x00000000}},	//   _nirt_, _لاڙ_, _لوهر, --, 
   {{0xaf5c001f,0x3de4009e,0xddcc00ef,0x64940124}},	//   _ለመመለ, মলাল, _embū, váiv, 
   {{0x3eb84989,0xa3e800dc,0xa8040022,0xc4840352}},	//   _airt_, मणः_, mañá, _үләк, 
   {{0xa25c0020,0x3eb80008,0x649400e4,0x00000000}},	// [4b90] _ታሪኩን_, _birt_, táiv, --, 
   {{0x3eb8007b,0x247400ef,0x00000000,0x00000000}},	//   _cirt_, bāms_, --, --, 
   {{0x3eb80c18,0x64940022,0x00000000,0x00000000}},	//   _dirt_, ráiv, --, --, 
   {{0x3eb80076,0x3da40edb,0x8598011a,0x64940022}},	//   _eirt_, труб, חשבו, sáiv, 
   {{0x271c038e,0x3eb804e6,0x0dc817a0,0x649400c7}},	//   _भनेर_, _firt_, _муви_, páiv, 
   {{0x2ee80165,0x6e940107,0x3eb8498a,0xa9a4498b}},	//   msaf_, _чигу, _girt_, нилд, 
   {{0x2cb80327,0xd87400f1,0x7ae4498c,0x00000000}},	//   _བཤིབ, کميت_, áitr, --, 
   {{0x2600375c,0xf8a800c6,0xdbc400c5,0x98a000a7}},	//   _शाही_, وديه_, _sööd, лище, 
   {{0x4918012c,0x2ee80009,0x2bd400bc,0x00000000}},	//   _मनको_, nsaf_, _ड्या, --, 
   {{0xba2801d9,0x6494498d,0x8a3415eb,0x00000000}},	//   _ٲسٕم_, háit, _تعرض, --, 
   {{0x36c40137,0x7e600356,0xdbc40254,0x00000000}},	//   нбөг, _împe, _vööd, --, 
   {{0x3cfc0268,0xe3640137,0x00000000,0x00000000}},	//   àvvi_, екми, --, --, 
   {{0xdbc400af,0xe738016c,0x7ccc05d1,0xa6c8030d}},	//   _tööd, _хел_, _iğre, _элла_, 
   {{0x247400e2,0x160402a0,0x00000000,0x00000000}},	//   tāms_, _शायर_, --, --, 
   {{0x60c000f3,0x00000000,0x00000000,0x00000000}},	//   _čoms, --, --, --, 
   {{0xe3d800bd,0x41d01a22,0x3eb8498e,0x95080327}},	//   _থাকব, _त्रस, _sirt_, _ཀྱིི_, 
   {{0x2b5805d5,0x3eb801ab,0x00000000,0x00000000}},	// [4ba0] _üsch_, _pirt_, --, --, 
   {{0xe1f80108,0xe124014b,0x00000000,0x00000000}},	//   _эго_, _змои, --, --, 
   {{0xf1c80075,0x3eb8498f,0x649400e4,0x7ccc0205}},	//   _توپى_, _virt_, báit, _oğre, 
   {{0x3eb80003,0x649400c6,0x2fc800e8,0x00000000}},	//   _wirt_, máis, ccag_, --, 
   {{0x64940597,0x00000000,0x00000000,0x00000000}},	//   láis, --, --, --, 
   {{0xa8040022,0x00000000,0x00000000,0x00000000}},	//   yañá, --, --, --, 
   {{0x2d944990,0x8e8002e8,0x649401e7,0xe7e00037}},	//   _артс, _сгре, náis, _गड़हा_, 
   {{0x89302d4b,0xebc00022,0x48a44991,0x00000000}},	//   اعوا, _кәшн, нтым_, --, 
   {{0x7f44208d,0xcb640212,0x649400ae,0x8c18010f}},	//   nxiq, _зате_, háis, _צומי, 
   {{0x7ccc0205,0x9a68007b,0xd944004e,0xd90c4992}},	//   _eğre, _عمال_, _пези, _هیت_, 
   {{0x98d803e6,0x00000000,0x00000000,0x00000000}},	//   _رباز_, --, --, --, 
   {{0xe4e0000d,0x2ee80142,0x00000000,0x00000000}},	//   _खबरि_, ysaf_, --, --, 
   {{0x838400fd,0x91e000fb,0x64940022,0x00000000}},	//   гыре, ләнһ, váit, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4654010f,0x649401e7,0x2ee80042,0x00000000}},	//   _אױגן_, gáis, wsaf_, --, 
   {{0x6d400e89,0x2ee801a4,0x85980375,0xb6340150}},	//   _àlai, tsaf_, _משוו, _ﯞﻱ_, 
   {{0x6494007b,0x22944993,0x733401ec,0xeeb801a9}},	// [4bb0] ráit, tækt_, _شىدا, длаш_, 
   {{0x2ee803cb,0x649401e7,0xd2a00354,0x00000000}},	//   rsaf_, báis, _тlаь, --, 
   {{0x64940597,0x2ee84994,0x22940008,0xe8201428}},	//   cáis, ssaf_, rækt_, _मसला_, 
   {{0x649400c6,0x2ee801f0,0x2294072b,0xead4026b}},	//   láir, psaf_, bæks_, водь, 
   {{0xd6c40efc,0xa28001d3,0x00000000,0x00000000}},	//   _خق_, _صیہو, --, --, 
   {{0x6f0c0b45,0x6494007b,0xae0401ec,0xefcc0023}},	//   mtac, náir, _جوسى, እዘዝ_, 
   {{0x6f0c4995,0xbd8401ee,0x7afc0a88,0xdddc00e5}},	//   ltac, _бѳтк, _ārte, cipő, 
   {{0xe7384996,0x6f0c08c2,0x6d440944,0x6494007b}},	//   деи_, otac, mxha, háir, 
   {{0xb8c8069f,0x7c840efb,0xd7041c22,0xa6844997}},	//   _खी_, _суре, вные_, клид, 
   {{0x6f0c4998,0x649400e4,0xdb0c0241,0xd1b80092}},	//   itac, jáir, _ìdág, ዳላት_, 
   {{0x6d444999,0x61e8045f,0x6f0c499a,0xe9b40022}},	//   nxha, _ôfli, htac, _рбжь, 
   {{0x67d400d8,0x00000000,0x00000000,0x00000000}},	//   _роду, --, --, --, 
   {{0x6f0c0309,0xd7240588,0x7f44208d,0x888000f1}},	//   jtac, _аҭыҧ_, xxiq, _ټیکن, 
   {{0x649400ae,0x957c0166,0x6f0c007c,0x00000000}},	//   gáir, _seƅe, dtac, --, 
   {{0x6d440240,0x6f0c15c0,0x00000000,0x00000000}},	//   jxha, etac, --, --, 
   {{0x6f0c499b,0x3e64499c,0x3074499d,0x649426d3}},	//   ftac, _möte_, гуус, ráis, 
   {{0x85200014,0x53a0023b,0x6f0c01ab,0xdee4499e}},	// [4bc0] _شکھٕ, _каъб, gtac, този, 
   {{0x0e60013e,0x3f9c005f,0xae0401e0,0x00000000}},	//   акун, āvu_, лоуҙ, --, 
   {{0xa06800f4,0x6b88014b,0x6f0c0e89,0x3e64002f}},	//   _жана_, _axeg, atac, _nöte_, 
   {{0x6f0c02a8,0x2d94013e,0xf320010c,0xabd40150}},	//   btac, урус, _ዲያቆና, _ﺟﯩﺮﻋ, 
   {{0x6f0c499f,0x3be80137,0x9f400240,0x00000000}},	//   ctac, _үлгү_, _mekë_, --, 
   {{0x9f4002d3,0x239800c0,0x00000000,0x00000000}},	//   _lekë_, _iąją_, --, --, 
   {{0x6b8849a0,0x59200139,0x00000000,0x00000000}},	//   _exeg, рүең, --, --, 
   {{0xdca404a9,0x5ca400a8,0x3b8401af,0x00000000}},	//   _раби, _рибб, _йһег, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdecc001f,0x4aa449a1,0x362400d1,0xd95800f3}},	//   _እኔን_, _акун_, учиң, _орељ_, 
   {{0x57e8023a,0x3e6449a2,0x6f0c012d,0x64940332}},	//   _ждем_, _göte_, ztac, váir, 
   {{0x6f0c49a3,0xd50c0085,0x880800f1,0x9f400200}},	//   ytac, gɛ́b, _يعنې_, _cekë_, 
   {{0x6f0c49a4,0xa25c02d3,0x6d400129,0x9f400200}},	//   xtac, _ታሪኽን_, _àlav, _dekë_, 
   {{0x07a00640,0xc7a02377,0x00000000,0x00000000}},	//   _тачн, _тичк, --, --, 
   {{0xc69030fb,0x7ae00218,0xab5c0327,0x6f0c0113}},	//   _דאס_, _lwmt, _igże, wtac, 
   {{0x6f0c49a5,0xaaa8012c,0xcee80014,0x649400e4}},	//   ttac, _चीनक, ِران_, sáir, 
   {{0xb90449a6,0x6f0c49a7,0x3358084c,0x64940022}},	// [4bd0] _ཨས_, utac, _чапэ_, páir, 
   {{0x6f0c49a8,0x3a2c0077,0x3328009a,0x6d4449a9}},	//   rtac, _nadp_, _isax_, txha, 
   {{0x201400d0,0x733400cf,0x00000000,0x00000000}},	//   ícií_, _شىگا, --, --, 
   {{0x6f0c49aa,0xcfa405f5,0x6d44036e,0xbc1800d4}},	//   ptac, _ашги, rxha, віші_, 
   {{0x7ae00042,0x6f0c03f0,0x6b7400f7,0x200c0213}},	//   _cwmt, qtac, ылду, əfi_, 
   {{0x3a2c0077,0x7bc0003a,0x649449ab,0xfcd00092}},	//   _cadp_, _egmu, háip, _እቴጌ_, 
   {{0x7e600311,0x3a2c06be,0x649400e4,0x00000000}},	//   _împa, _dadp_, káip, --, 
   {{0x9f400100,0x66d800a7,0x3a2c0175,0x0c840022}},	//   _bekè_, ньор_, _eadp_, _рыгм, 
   {{0x6b880117,0x7d08067c,0x7ae00142,0x7ccc06be}},	//   _uxeg, _tèrç, _gwmt, _iğra, 
   {{0xa2c004fa,0x3e64002f,0x00000000,0x00000000}},	//   लदस्, _töte_, --, --, 
   {{0xdd103361,0x490001ec,0xc86401ee,0x95f800c7}},	//   _müşr, _түйг, _итди, хьыӡ_, 
   {{0xf4940b7e,0x1af400cc,0x00000000,0x00000000}},	//   иряю, _ইহতে_, --, --, 
   {{0x7ae00218,0x68e001ab,0xe4c40131,0x02c40137}},	//   _xwmt, _hwld, _өйли, ригү, 
   {{0xe5a41f71,0xd624014b,0x00000000,0x00000000}},	//   _йили, _боше_, --, --, 
   {{0x216821cc,0xe29849ac,0x1e8401b9,0x7ccc06be}},	//   хиви_, _җан_, ҳлам, _oğra, 
   {{0x68e00042,0x00000000,0x00000000,0x00000000}},	//   _mwld, --, --, --, 
   {{0x69c049ad,0x38a806af,0x10a01d0f,0xe2980107}},	// [4be0] _ogle, qûre_, ситн, _паи_, 
   {{0x69c0179c,0x7ccc00fd,0x00000000,0x00000000}},	//   _ngle, _ağra, --, --, 
   {{0xdca449ae,0x7bc00395,0x41a8012c,0xdd1000a2}},	//   гажи, _pgmu, _गरिस, _düşr, 
   {{0x69c00429,0xa06800fd,0x00000000,0x00000000}},	//   _agle, _чама_, --, --, 
   {{0xe22c0023,0x00000000,0x00000000,0x00000000}},	//   _ብምስዓ, --, --, --, 
   {{0x1cb40489,0x1d0800d8,0x00000000,0x00000000}},	//   _ཚངམ_, _пеги_, --, --, 
   {{0x9f40007f,0xc0f40023,0x0e60003b,0x00000000}},	//   _sekè_, ግብሩ_, _укрн, --, 
   {{0x69c049af,0x6d4049b0,0xb6f41b88,0xdecc0092}},	//   _egle, _šlag, азиј, _እኔና_, 
   {{0x8ba0010b,0xeb540150,0x649400e4,0x00000000}},	//   _гитж, _پىلگ, váip, --, 
   {{0x75140e58,0xb3e00154,0x00000000,0x00000000}},	//   амоф, _ভাইজ, --, --, 
   {{0xd7f849b1,0x00000000,0x00000000,0x00000000}},	//   _зул_, --, --, --, 
   {{0x69c0151c,0x45d000d1,0x34940107,0x00000000}},	//   _zgle, _һошс, рамр, --, 
   {{0x649400c7,0x00000000,0x00000000,0x00000000}},	//   ráip, --, --, --, 
   {{0x6d400ad9,0x7d1c0427,0xc058104b,0xc2c4007b}},	//   _álag, _oprs, ۇشقا_, صيفي, 
   {{0xd498082d,0x67880023,0x00000000,0x00000000}},	//   _при_, _ዝስደዱ_, --, --, 
   {{0x2ef42d3c,0xc0f40023,0x253c00b8,0x94a849b2}},	//   избр, ግብሮ_, _āhṛṣ, _ятла_, 
   {{0x62641e4a,0x6fb849b3,0x6e98059f,0xdf5449b4}},	// [4bf0] _چاپق, тгар_, ввар_, антө, 
   {{0xfeb80472,0x00000000,0x00000000,0x00000000}},	//   هالت_, --, --, --, 
   {{0xc0f402d3,0xa27402dd,0x2d840427,0xbe880114}},	//   ግብር_, _тұру_, _žleb_, усте_, 
   {{0x69c049b5,0x00000000,0x00000000,0x00000000}},	//   _sgle, --, --, --, 
   {{0xab2849b6,0xaab449b7,0x8f080354,0x27e800d7}},	//   тола_, айді, _яхна_, _ľan_, 
   {{0x2bd402ab,0x27e849b8,0xad242160,0x3bd40131}},	//   _ड्रा, _žan_, _پىرى, لغۇس, 
   {{0xa9a401d5,0x00000000,0x00000000,0x00000000}},	//   шикд, --, --, --, 
   {{0x7ccc07c4,0x00000000,0x00000000,0x00000000}},	//   _uğra, --, --, --, 
   {{0x574400a7,0x9f400030,0x6b7401af,0x2aa831b7}},	//   изъм_, _sdkú_, _тлау, rúbb_, 
   {{0x3b5400db,0xf1b407d0,0x00000000,0x00000000}},	//   _укур, ंधान, --, --, 
   {{0xe5a43a32,0x2a64009a,0x37e400fe,0x00000000}},	//   рини, _illb_, _গাৰো_, --, 
   {{0x627c044e,0x6f1c49b9,0x3e6401e6,0x2cac01f5}},	//   _ኣብያተ_, _opsc, _möta_, _jhed_, 
   {{0x66e449ba,0xe6440395,0x00000000,0x00000000}},	//   _тола, _велп, --, --, 
   {{0x91e00902,0xe64800d8,0x00000000,0x00000000}},	//   жоре, _јпкд_, --, --, 
   {{0x64a449bb,0x6f1c03ac,0x3e6401e3,0x00000000}},	//   _кака, _apsc, _nöta_, --, 
   {{0x44e001ed,0x00000000,0x00000000,0x00000000}},	//   mű_, --, --, --, 
  
   {{0x7d1c0cf4,0x6f1c02d0,0x00000000,0x00000000}},	// [4c00] _sprs, _cpsc, --, --, 
   {{0x9db842a3,0x9b442c1f,0xd24c0b24,0x3e6401e3}},	//   نداز_, یناو, _يني_, _böta_, 
   {{0x208816c3,0xa0a449bc,0x6f1c03ac,0x00000000}},	//   _айни_, _ванд, _epsc, --, 
   {{0xabb400c7,0x00000000,0x00000000,0x00000000}},	//   әашә, --, --, --, 
   {{0x7e60084c,0x7bc402d5,0x00000000,0x00000000}},	//   _împo, žiuo, --, --, 
   {{0xb8f400c6,0x44e001d3,0x9cb40066,0xd9180108}},	//   مكتب, kű_, _چمست, вьи_, 
   {{0x7d1c16a3,0x3e640267,0x1da849bd,0x44e001d3}},	//   _uprs, _göta_, _करित, jű_, 
   {{0xded40201,0x2cac014f,0x5fc41fe5,0xb78804b4}},	//   _ይህን_, _ghed_, लखिल, ләле_, 
   {{0x6d40002e,0x627400e2,0xa3e849be,0x5efc0037}},	//   _àlar, rņoj, यरन_, _लिफ्_, 
   {{0x1da8072a,0xc95000c7,0x056c0240,0x00000000}},	//   _करात, стәы, _ብጉቡእ_, --, 
   {{0x994849bf,0x44e001ed,0xf7700214,0x70b00150}},	//   _جلال_, gű_, تاژ_, _ﺳﺎﯞﻣ, 
   {{0x25b000d7,0x00000000,0x00000000,0x00000000}},	//   ýzla_, --, --, --, 
   {{0x3d080574,0x25a801e4,0x1da80037,0x43940108}},	//   ांडे_, _ŝalt_, _करऽत, жаяс, 
   {{0xc6900228,0x518449c0,0x00000000,0x00000000}},	//   _وشوع, ауба, --, --, 
   {{0x8fe449c1,0x313400a7,0x41541f5a,0x54e40244}},	//   ицад, щевр, оврс, _ئستق, 
   {{0x7ccc0166,0x61e00e04,0xc10449c2,0x3e64007c}},	//   _ağro, _đole, توفي, _röta_, 
   {{0x3e6401e6,0x25ec05f9,0x2cac0042,0xc7b0010f}},	// [4c10] _söta_, _आजमी_, _rhed_, ַבע_, 
   {{0x2cac49c3,0x7e600276,0xafe40032,0x00000000}},	//   _shed_, _împl, роҡл, --, 
   {{0x6d400419,0x00000000,0x00000000,0x00000000}},	//   _šlab, --, --, --, 
   {{0xbd4400c6,0x7c8449c4,0x00000000,0x00000000}},	//   تنمي, оуче, --, --, 
   {{0xaa5804a9,0x7eb0002f,0x99e403d4,0x3eac00c0}},	//   лиду_, däpf, নলৈক, _šitų_, 
   {{0x0dc849c5,0x417401ec,0x00000000,0x00000000}},	//   _шуми_, _داۋس, --, --, 
   {{0xa3e801ad,0x00000000,0x00000000,0x00000000}},	//   यरम_, --, --, --, 
   {{0xd7ec49c6,0x6c840597,0x07c449c7,0x6d400129}},	//   ىكى_, _الرم, швиқ_, _àlaq, 
   {{0xd1f00f16,0xbb64037e,0xc6840023,0x6d40032e}},	//   ግስት_, _vipロ_, _ዝብለካ_, _álab, 
   {{0xb82403d4,0x44e001d3,0x6e240978,0x361800d4}},	//   ভাগত_, tű_, nehb, ацюю_, 
   {{0xe3b000f1,0x00000000,0x00000000,0x00000000}},	//   ګرد_, --, --, --, 
   {{0xe5a402af,0xd6cc0b43,0x44e001ed,0x216802a9}},	//   _қийи, بقی_, rű_, қиби_, 
   {{0x27ec49c8,0xa6c81e76,0x4e0400bc,0xf65000ec}},	//   maen_, _ёлка_, शलाई_, _ڪئن_, 
   {{0x27ec0cfd,0xe61004fb,0x67280083,0xb66802dd}},	//   laen_, _رشت_, mwej, _киіз_, 
   {{0xa06806bb,0xf65001c8,0x00000000,0x00000000}},	//   гава_, _تئن_, --, --, 
   {{0x27ec49c9,0xd0040184,0x248400e8,0x00000000}},	//   naen_, йесе_, _ñom_, --, 
   {{0x645401e2,0x00000000,0x00000000,0x00000000}},	// [4c20] _ioyi, --, --, --, 
   {{0x27ec1028,0x6454058a,0x6e240112,0xa20425ff}},	//   haen_, _hoyi, gehb, _упод, 
   {{0x61ec49ca,0x27ec49cb,0x5bc449cc,0x645449cd}},	//   mabl, kaen_, مقال, _koyi, 
   {{0x645449ce,0x672849cf,0x6d400306,0x93100244}},	//   _joyi, kwej, _šlac, _بویش, 
   {{0x645449d0,0x27ec49d1,0xa2cc16ae,0x6e24014f}},	//   _moyi, daen_, _धूम्, behb, 
   {{0xd6d849d2,0x645449d3,0x75280210,0x388c01ef}},	//   қти_, _loyi, ywdz, děra_, 
   {{0x629c0521,0x27ec49d4,0x645449d5,0x00000000}},	//   _mkpo, faen_, _ooyi, --, 
   {{0x645449d6,0x27ec3c02,0xd1f0010c,0x00000000}},	//   _noyi, gaen_, ግስተ_, --, 
   {{0x61ec49d7,0x629c0521,0x672849d8,0xba3c0055}},	//   kabl, _okpo, gwej, _bhįt, 
   {{0xb7880184,0x629c01f2,0x7a6400db,0x2d9c0112}},	//   ләһе_, _nkpo, _بئرە, ßweg_, 
   {{0x645449d9,0x27ec0369,0x61ec49da,0xba3c0055}},	//   _boyi, baen_, dabl, _dhįt, 
   {{0x629c01f2,0x27ec49db,0x67280428,0x61ec49dc}},	//   _akpo, caen_, bwej, eabl, 
   {{0x61ec49dd,0x6454047e,0xae1801ad,0x8898010f}},	//   fabl, _doyi, न्डन_, _גבאי, 
   {{0xb9f00020,0x64540472,0x926849de,0x629c0175}},	//   _ነን_, _eoyi, урма_, _ckpo, 
   {{0x645449df,0x4a58010f,0xa3d407f7,0xd0180cb6}},	//   _foyi, נדלו, ाँश_, лфа_, 
   {{0x629c0521,0x645449e0,0x7bc40024,0xe46800db}},	//   _ekpo, _goyi, žiuj, _ۅلۉۉ_, 
   {{0x629c1132,0x667003e6,0x3e6408a5,0xcdd80114}},	// [4c30] _fkpo, _رگیر, _vötn_, гње_, 
   {{0xd1f0067d,0x645449e1,0x6fd80401,0x00000000}},	//   ግስቲ_, _zoyi, _फ्रू, --, 
   {{0x645449e2,0x27ec0007,0x7eb0010e,0x6e240205}},	//   _yoyi, yaen_, däpd, rehb, 
   {{0xac1849e3,0x76440198,0x6e240e78,0x27ec01bf}},	//   роду_, _ɗiya, sehb, xaen_, 
   {{0xa3e80acd,0x3de800bd,0x27ec0b1a,0x00000000}},	//   यरत_, _পারল, vaen_, --, 
   {{0x388c0118,0x27ec0142,0x4ae401a9,0xbea400c0}},	//   věra_, waen_, _ҳўжа, _наўк, 
   {{0x27ec49e4,0x00000000,0x00000000,0x00000000}},	//   taen_, --, --, --, 
   {{0x61ec49e5,0xfd7405f5,0x67280083,0x00000000}},	//   zabl, _элсэ, twej, --, 
   {{0x656c0198,0x61ec49e6,0x6a2400f1,0x999c0064}},	//   _ƙaho, yabl, _وفرم, _botų_, 
   {{0x27ec49e7,0x61ec49e8,0x67280009,0xe9440472}},	//   saen_, xabl, rwej, _ورای, 
   {{0x645449e9,0xb88401d3,0x25a400b8,0x00000000}},	//   _poyi, _کلنٹ, _ṛṣṭi, --, 
   {{0x61ec49ea,0x645401b9,0xae1839d7,0x7ae40356}},	//   wabl, _qoyi, न्तन_, ţite, 
   {{0xe22c0023,0x7eb0007c,0xd6640354,0x00000000}},	//   _ብምልዓ, läpe, lона, --, 
   {{0x645449eb,0x999c00c0,0xd6d402f2,0xaba800d1}},	//   _woyi, _gotų_, _بووش_, ﻴﺘﻘﺎ, 
   {{0x61ec49ec,0x645449ed,0x629c01fa,0x20540d97}},	//   rabl, _toyi, _vkpo, отар, 
   {{0x61ec49ee,0xd12c01ed,0x00000000,0x00000000}},	//   sabl, کمہ_, --, --, 
   {{0x23281cc9,0x34081075,0x61ec49ef,0x7bc40153}},	// [4c40] _топи_, _ازىپ_, pabl, žiuk, 
   {{0xc294158b,0x61ec49f0,0xf000009d,0x7eb00108}},	//   _ریزب, qabl, _үүри, käpe, 
   {{0xae18007a,0x00000000,0x00000000,0x00000000}},	//   न्धन_, --, --, --, 
   {{0xa3e800ab,0x3ec40117,0x39800037,0x00000000}},	//   यरि_, _нимҳ, _लs_, --, 
   {{0x9d0800bd,0x00000000,0x00000000,0x00000000}},	//   রবেন_, --, --, --, 
   {{0xab5c0327,0x3c200100,0x00000000,0x00000000}},	//   _egżo, _sčvč_, --, --, 
   {{0xa3e849f1,0x38c826a8,0x00000000,0x00000000}},	//   यरा_, حاتی_, --, --, 
   {{0xd83849f2,0xdddc02b5,0xacb00228,0x2cd403cf}},	//   рэк_, kipū, _كەلب, _хюрр, 
   {{0xcb6449f3,0x00000000,0x00000000,0x00000000}},	//   _дате_, --, --, --, 
   {{0xda6449f4,0x1acc0150,0x00000000,0x00000000}},	//   _باري, _ﻗﻮﺳﻮ, --, --, 
   {{0x998449f5,0x4a7001d9,0x186810ea,0x999c0064}},	//   _بلاو, _تُلر, _кажи_, _votų_, 
   {{0xd8741f0d,0x00000000,0x00000000,0x00000000}},	//   _بائب, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xcfe40eac,0x4970030d,0x00000000,0x00000000}},	//   _ফাইন, _илĕс, --, --, 
   {{0x850049f6,0x50440023,0x00000000,0x00000000}},	//   _قوون, _መሻርኽ, --, --, 
   {{0x765849f7,0x00000000,0x00000000,0x00000000}},	//   _hovy, --, --, --, 
   {{0xd46849f8,0x76580218,0x00000000,0x00000000}},	// [4c50] _محکم_, _kovy, --, --, 
   {{0x765800e4,0xb62c00b5,0xcdd80114,0x902800c7}},	//   _jovy, _ｕｐ_, рња_, ыцҳа_, 
   {{0xaf28001f,0x00000000,0x00000000,0x00000000}},	//   ስተላለ, --, --, --, 
   {{0x765849f9,0x7094361d,0x7eb00108,0xfc640395}},	//   _lovy, _хамф, väpe, мъчн, 
   {{0xcfa849fa,0xaa44010b,0x00000000,0x00000000}},	//   _خادم_, зелл, --, --, 
   {{0x765802fb,0xa9681180,0x7eb00108,0x00000000}},	//   _novy, йила_, täpe, --, 
   {{0x6b8c0276,0x00000000,0x00000000,0x00000000}},	//   _ţigă, --, --, --, 
   {{0x25ec0490,0x5824031c,0x935c02d3,0xbd4400c6}},	//   _आजही_, _རྒྱོ_, ህርትታ, _تنفي, 
   {{0x765849fb,0xa3e849fc,0x7eb00108,0x26d80200}},	//   _bovy, यरस_, säpe, ëso_, 
   {{0x6e3449fd,0x6ae000cc,0x00000000,0x00000000}},	//   _jazb, _নিপো, --, --, 
   {{0x64a449fe,0xca30001f,0x76582e26,0x6e3449ff}},	//   зана, _በሽታዎ, _dovy, _mazb, 
   {{0x6e340165,0x23280faf,0x00000000,0x00000000}},	//   _lazb, боми_, --, --, 
   {{0xa0340952,0x4ac800dc,0x03bc015b,0x00000000}},	//   ۋىست, ादिव, ূর্ণ, --, 
   {{0x6e344a00,0xf770413a,0xdddc0882,0x1fb400c7}},	//   _nazb, _جام_, ripū, ҧсар, 
   {{0x213c00c6,0x7e600276,0xe22c02d3,0xdddc0153}},	//   íth_, _împi, _ብዝለዓ, sipū, 
   {{0xcfe4015b,0x3de8015b,0xae184a01,0x4ac801bc}},	//   _ফাউন, _পাইল, न्सन_, ादाव, 
   {{0x44204a02,0x13000022,0xb9dc0092,0x00000000}},	// [4c60] _ibi_, _ззым, _ጤፍ_, --, 
   {{0x6e340369,0x00000000,0x00000000,0x00000000}},	//   _cazb, --, --, --, 
   {{0x6e3400f3,0x442003b2,0xa0a44a03,0x6560035a}},	//   _dazb, _kbi_, _наод, nylh, 
   {{0x3d1c4a04,0xdcb03955,0x9b68063b,0x712406ce}},	//   _नहीं_, رىش_, йшла_, _کریل, 
   {{0x44204a05,0x90b00724,0x2258007f,0x6d400aab}},	//   _mbi_, _чәрш, _kopk_, _álan, 
   {{0x44204a06,0x12b40150,0x00000000,0x00000000}},	//   _lbi_, _ﺼﺎﻟﻭ, --, --, 
   {{0x44204a07,0x765800c7,0x09300592,0xad8801f0}},	//   _obi_, _rovy, فريج, _дарҷ_, 
   {{0x44204a08,0x76584a09,0x60c400ee,0x5ac800d8}},	//   _nbi_, _sovy, _jikm, _глам_, 
   {{0x07f40597,0x60c41f5d,0x765802fb,0x6e3400a2}},	//   سريع_, _mikm, _povy, _yazb, 
   {{0x60c4005f,0xa3c017ee,0x7ccc0205,0x7afc002b}},	//   _likm, ्खन_, _ağri, _ārth, 
   {{0x44204a0a,0x34944a0b,0x89d8011a,0x00000000}},	//   _bbi_, данр, _החבי, --, 
   {{0xa78400ec,0x225801ef,0x00000000,0x00000000}},	//   _ڪشمو, _aopk_, --, --, 
   {{0x765800e4,0x4c98010f,0x00000000,0x00000000}},	//   _tovy, משטע, --, --, 
   {{0x44204a0c,0x7ccc0790,0x03bc03d4,0x75d401f7}},	//   _ebi_, _eğri, ূৰ্ণ, _غيبا, 
   {{0x60c44a0d,0x2ea802e5,0x44200d63,0x5064004e}},	//   _bikm, _कठौत, _fbi_, птаа, 
   {{0x6e3400bc,0x60c44a0e,0x9f400c5e,0x00000000}},	//   _sazb, _cikm, _seká_, --, 
   {{0x60c44a0f,0x6e344a10,0x00000000,0x00000000}},	// [4c70] _dikm, _pazb, --, --, 
   {{0x6e3406be,0xed500014,0x629800d7,0x00000000}},	//   _qazb, پھس_, čtoc, --, 
   {{0x6e34012c,0xe13000c7,0x44204a11,0xe8000118}},	//   _vazb, _иҽры, _ybi_, ोलमा_, 
   {{0xfd74009d,0x9ba000d1,0x00000000,0x00000000}},	//   элхэ, ھەلى, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa9a41638,0x8d741ec7,0xae180073,0x6a840408}},	//   милд, _فازا, न्शन_, ьлла, 
   {{0x2d840598,0x60c400a2,0x64940327,0x656003ac}},	//   _äle_, _yikm, lġie, xylh, 
   {{0x60c44a12,0x7eb04432,0x7ae40356,0x4db000cc}},	//   _xikm, mäpa, ţita, _জলপূ, 
   {{0xdedc02d3,0x44200f85,0x64940135,0x7eb001f4}},	//   _ሕቶን_, _rbi_, nġie, läpa, 
   {{0x44204a13,0x00000000,0x00000000,0x00000000}},	//   _sbi_, --, --, --, 
   {{0x44204a14,0x7eb001f4,0xa3e81cd2,0x7afc002b}},	//   _pbi_, näpa, यरल_, _ārti, 
   {{0x4420020c,0x36c401c0,0xe1e41fd2,0x225800d7}},	//   _qbi_, мбөг, कर्ण_, _sopk_, 
   {{0x44204a15,0x60c44a16,0xc7a81c3e,0xf7f408f0}},	//   _vbi_, _rikm, _ادال_, _سسند, 
   {{0x60c44a17,0x4420020c,0x656002d0,0x7eb01b99}},	//   _sikm, _wbi_, pylh, käpa, 
   {{0x44200589,0x3d0c068f,0xa2cc4a18,0x7eb001f4}},	//   _tbi_, _हमें_, _धूर्, jäpa, 
   {{0x44204a19,0x63040116,0x00000000,0x00000000}},	//   _ubi_, _قوبل, --, --, 
   {{0x27fc0369,0x60c43453,0x10a04a1a,0x93f8011a}},	// [4c80] _mdwn_, _vikm, титн, _ולפי, 
   {{0xa3d400c5,0x9f400166,0x3e644a1b,0x00000000}},	//   ाँक_, _lekç_, _köti_, --, 
   {{0x60c44a1c,0xfb5401d3,0x00000000,0x00000000}},	//   _tikm, کراھ, --, --, 
   {{0x27fc0007,0xdb840022,0x5ba8004e,0x00000000}},	//   _ndwn_, мгеи, окем_, --, 
   {{0x628c4a1d,0x82380023,0x429c00cd,0x00000000}},	//   onbo, _ብምስታ, _ṛṣib, --, 
   {{0x628c2507,0x6d68002e,0x64940135,0x539800d9}},	//   nnbo, ñsañ, nġib, חינו, 
   {{0x628c4a1e,0xaca801ed,0xb3a4000d,0x00000000}},	//   inbo, _کھلے_, _गुनख, --, 
   {{0x6c3000dd,0x79980327,0x588400c7,0x00000000}},	//   _مہما, _ħawħ, ьыла, --, 
   {{0x61fc19d6,0xebc001e0,0x00000000,0x00000000}},	//   _odpl, _йәшн, --, --, 
   {{0x628c0d27,0x98ac0259,0x7ccc452e,0x00000000}},	//   jnbo, ınır_, _eşre, --, 
   {{0x7e600276,0xd7f800ee,0xd90c0244,0x8570009d}},	//   _împu, _дул_, _ئیب_, влэх, 
   {{0x61fc4a1f,0x99e4045e,0x628c0b4f,0xa3d44688}},	//   _adpl, _নায়ক, enbo, ाँग_, 
   {{0x4aa40408,0x00000000,0x00000000,0x00000000}},	//   _акăн_, --, --, --, 
   {{0x31344a20,0x628c4a21,0x6d404a22,0xefd40023}},	//   негр, gnbo, _šlam, _ክንዮ_, 
   {{0x3e6400a2,0x6494031c,0x00000000,0x00000000}},	//   _göti_, wġie, --, --, 
   {{0x628c0373,0x78a0209c,0x61fc03ac,0x3de80f22}},	//   anbo, nomv, _edpl, _পাগল, 
   {{0xeb0c084a,0x833400c7,0x15f00490,0xda0c0037}},	// [4c90] _समेत_, _аных, _आजार_, _सांत_, 
   {{0x8d844a23,0xb640037e,0x7eb0005b,0x78a04a24}},	//   وشان, _ｍａ_, täpa, homv, 
   {{0x78a04a25,0x7ccc0213,0x00000000,0x00000000}},	//   komv, _oğru, --, --, 
   {{0x6d400407,0x5ca40131,0x7eb04a26,0x9f500100}},	//   _álam, ىللە, räpa, kayè_, 
   {{0x7eb0023a,0xd9e4015b,0x00000000,0x00000000}},	//   säpa, _নাজম, --, --, 
   {{0x6f0c4a27,0x7eb04a28,0x765c01f4,0x00000000}},	//   muac, päpa, öryl, --, 
   {{0x6f0c4a29,0x00000000,0x00000000,0x00000000}},	//   luac, --, --, --, 
   {{0x78a025d0,0x6f0c0165,0xe468005b,0xf9904a2a}},	//   gomv, ouac, isöä_, جبه_, 
   {{0x6f0c31d3,0x628c4a2b,0x29c801e0,0x80b001f9}},	//   nuac, ynbo, _етеү_, ंतते, 
   {{0x3e6402b5,0xdb240214,0xdb100158,0x00000000}},	//   _pöti_, _سومی, ågås, --, 
   {{0x6f0c4a2c,0x7950168d,0x78a00912,0x39140022}},	//   huac, _نێوا, bomv, _амхр, 
   {{0x78a00998,0xa7744a2d,0x00000000,0x00000000}},	//   comv, _плеч, --, --, 
   {{0x26dc0eb4,0xe3b00e55,0x00000000,0x00000000}},	//   _utwo_, طرح_, --, --, 
   {{0x6f0c4a2e,0x64600034,0xd24c009f,0x151c00cc}},	//   duac, _świą, منُ_, _বছৰী_, 
   {{0x628c3720,0x05744a2f,0x60244a30,0xe568009d}},	//   rnbo, _تاشد, ндва, _хийд_, 
   {{0x9f504a31,0x6f0c0332,0xa40801f9,0xb46003e3}},	//   layé_, fuac, _वाटप_, _şüvə, 
   {{0x6f0c035b,0xba001772,0xde380092,0x00000000}},	// [4ca0] guac, _ግፋ_, _የማይወ, --, 
   {{0x5ea43cd9,0xc79c0020,0x78a04a32,0x61fc005c}},	//   رمال, _ውጤታማ_, zomv, _udpl, 
   {{0x9f400664,0x5bb84433,0x78a007a8,0x6f0c01ab}},	//   _sekä_, ेश्व, yomv, auac, 
   {{0xdee44a33,0x9cb40244,0x00000000,0x00000000}},	//   _поми, رمشت, --, --, 
   {{0x6f0c4a34,0x3cfc012d,0x00000000,0x00000000}},	//   cuac, _लटके_, --, --, 
   {{0x9f500699,0x7ae4054e,0x00000000,0x00000000}},	//   vayè_, ţito, --, --, 
   {{0xdd9006d5,0x98c44a35,0x09000953,0x78a001f5}},	//   _صور_, нсил, гчым, tomv, 
   {{0x20104a36,0x9f400166,0xa3c008f2,0xc8740022}},	//   ngyi_, _tekä_, ्खा_, еџь_, 
   {{0x78a04a37,0x1ae4010b,0x26d801e4,0x00000000}},	//   romv, _чозм, ŭson_, --, 
   {{0x7bc40024,0x78a0257c,0x99740395,0x8af8011a}},	//   žius, somv, _пуеш, _מהמי, 
   {{0x00300023,0xddcc00de,0x09e00229,0x00000000}},	//   _ብጽንዓ, _albū, _сохн, --, 
   {{0x7ccc47af,0x15f00073,0x7eb000e4,0x6d404a38}},	//   _uğru, _आजवर_, käpo, _šlak, 
   {{0x769c010b,0x7eb00267,0x00000000,0x00000000}},	//   _açyş, väpn, --, --, 
   {{0x7ae001e4,0x3e6402d2,0xf77000ec,0x00000000}},	//   _mtmt, _kötu_, _ماڙ_, --, 
   {{0x7eb00254,0xda0c0037,0x00000000,0x00000000}},	//   täpn, _साईत_, --, --, 
   {{0x2ea802e5,0x40344a39,0xf484150e,0x4084004e}},	//   कत्त, лесс, _جاتی, гууб, 
   {{0x3eb80b4b,0xae680014,0xe46801f4,0x00000000}},	// [4cb0] _bhrt_, وٕرن_, ssöä_, --, 
   {{0x6f0c4a3a,0x3eb802f0,0x6d400162,0x00000000}},	//   ruac, _chrt_, _álak, --, 
   {{0x3d08012c,0xf1040137,0x6f0c0332,0x00000000}},	//   ांगे_, _جۉزۉ_, suac, --, 
   {{0xfbd04a3b,0x3eb80112,0x2ef40cb6,0x7eb000fd}},	//   مته_, _ehrt_, _измр, läpl, 
   {{0xf1d40d01,0x00000000,0x00000000,0x00000000}},	//   _दलान, --, --, --, 
   {{0xd5a4087e,0x3e640309,0x6db42c12,0x7afc0055}},	//   _نف_, _bötu_, _айгу, _ārtt, 
   {{0x3de803d4,0x3d080037,0x9930007b,0xda300022}},	//   _পাচল, _हिये_, لفوت, рҵхы, 
   {{0x7e60084c,0xbd4400e3,0x0af0009d,0xd8b400e5}},	//   _împr, _حنفي, _бүдэ, نگنا_, 
   {{0x6da40116,0x6d4002f0,0x7ccc06be,0xead40153}},	//   _чиңа, _šlah, _işra, _розь, 
   {{0x38a807a8,0xcc8403e6,0x1660023a,0x3e64032e}},	//   dûru_, _تۆڵه_, ивым, _fötu_, 
   {{0x3e6401a8,0xc6d001c6,0x00000000,0x00000000}},	//   _götu_, _өслө, --, --, 
   {{0xddcc0316,0x9f5007ea,0x3200020b,0x7d0802d2}},	//   _dobř, sayé_, _adhy_, _hérð, 
   {{0xe73818ec,0x987800c8,0x3e644a3c,0x9f504a3d}},	//   _цел_, _קאנט, _kött_, payé_, 
   {{0x3e6401ed,0xe2980166,0x7eb001f4,0xa5080108}},	//   _jött_, фаг_, väpo, _жека_, 
   {{0x7c2402ce,0x3e643672,0x7ccc0139,0xf2f80133}},	//   ŵiri, _mött_, _oşra, ووێژ_, 
   {{0x3eb80280,0x7eb04a3e,0x61e04a3f,0x6cc801e1}},	//   _shrt_, täpo, _şold, _ṣoní, 
   {{0x7eb04a40,0x20d00073,0x201000e5,0x00000000}},	// [4cc0] bäpl, _दूरध, rgyi_, --, 
   {{0x3e644a41,0x63b400a2,0x7eb04a42,0x8e04117e}},	//   _nött_, _izyn, räpo, кнув_, 
   {{0x69dc0134,0x68e04a43,0x7eb00108,0x00000000}},	//   _ɑset, _ntld, säpo, --, 
   {{0x5bc4007b,0x6d9800f1,0x00000000,0x00000000}},	//   نقال, رمنځ_, --, --, 
   {{0x332805b1,0x765c0108,0x00000000,0x00000000}},	//   _xpax_, öryk, --, --, 
   {{0x7ccc294f,0xcb640063,0x00000000,0x00000000}},	//   _eşra, ђаје_, --, --, 
   {{0x38a8019f,0x2d40001f,0x3e6401e6,0x891000ae}},	//   zûru_, _የሚኖረ, _dött_, لبيئ, 
   {{0x38344a44,0xd6d81f0f,0xc8600022,0xcb0400db}},	//   унир, мто_, итыи, ريۉن_, 
   {{0x3e640267,0x8c18011a,0x77940214,0x6cb80166}},	//   _fött_, _קומי, دیشا, _чырр_, 
   {{0xddcc00bc,0x3e643672,0x6d400153,0x34bc0303}},	//   _pobř, _gött_, _šlai, ोद्द, 
   {{0x63b400ee,0xa2a4013a,0x00000000,0x00000000}},	//   _azyn, चकन्, --, --, 
   {{0x57a44a45,0x4914011a,0xd70400d8,0x897800df}},	//   _ишла, _יקבל_, _азди, _קראצ, 
   {{0x63b4068f,0xa3e009bb,0x7eb001f4,0x00000000}},	//   _czyn, धड़_, täpl, --, 
   {{0x867002bf,0x3e6401e6,0x45d000db,0x00000000}},	//   _кліє, _möts_, _кошс, --, 
   {{0x63b403ac,0xd4984a46,0x00000000,0x00000000}},	//   _ezyn, _ори_, --, --, 
   {{0x6d4000c6,0x22440198,0x7eb001b8,0x855404ae}},	//   _álai, _ɗoki_, säpl, _ישוב_, 
   {{0xc0c84a47,0x4034005b,0xeeb84a48,0x00000000}},	// [4cd0] туре_, шетс, елаш_, --, 
   {{0x51840046,0x388c00bc,0x765c023a,0xa3c000bc}},	//   _аума, měru_, öryh, ्खर_, 
   {{0x3e6401e6,0x63b8012d,0x00000000,0x00000000}},	//   _rött_, ętne, --, --, 
   {{0x50a00075,0x3e644a49,0x63b40209,0xab7400ee}},	//   _ئەرل, _böts_, _yzyn, лгеш, 
   {{0x4ea42df7,0x16000490,0x00000000,0x00000000}},	//   _арва, लणार_, --, --, 
   {{0xdddc0311,0x1ee8158b,0xc334010f,0x0a680022}},	//   ripţ, _سوفی_, שוס_, ьреи_, 
   {{0xab780092,0x7bd800de,0x00000000,0x00000000}},	//   ጣቸዋል_, _šauš, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7c842d30,0x4ab000d1,0x00000000,0x00000000}},	//   _туре, _көкр, --, --, 
   {{0x3d0805ba,0xc98400c7,0x00000000,0x00000000}},	//   ांचे_, _иуеи, --, --, 
   {{0x63b4033f,0xe56801c6,0xe48801c6,0xb46006be}},	//   _szyn, хинд_, ейнд_, _ğürə, 
   {{0x22444a4a,0xf2c800c8,0xa2e433be,0xf8b001ed}},	//   _şok_, _זע_, ломд, _وکٹ_, 
   {{0xc9540032,0x75b401e0,0x00000000,0x00000000}},	//   _ятҡы, лғәт_, --, --, 
   {{0x61e000a2,0xf7b800f2,0x21b00150,0x00000000}},	//   _şolb, _شدنش_, _ﺼﻭﺍﺭ, --, 
   {{0xf1a80244,0x91e001f4,0x910000d4,0x00000000}},	//   نافه_, сосе, йпре, --, 
   {{0x9e644a4b,0x388c0316,0x3e6403e0,0x7eb001e3}},	//   گارن, běru_, _nötr_, räpm, 
   {{0xdca4036b,0x63b400ee,0x00000000,0x00000000}},	// [4ce0] қади, _uzyn, --, --, 
   {{0x9e644a4c,0x0e600107,0x00000000,0x00000000}},	//   دارن, бкун, --, --, 
   {{0x5d840597,0xa068014b,0x7eb00139,0x00000000}},	//   دلال, _зана_, läpk, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x5efc00dc,0xfa8407a5,0x9a8401a9,0x00000000}},	//   _लिट्_, ақам, лукл, --, 
   {{0x8c9400d1,0x00000000,0x00000000,0x00000000}},	//   پپۇز_, --, --, --, 
   {{0xd7f84a4d,0x7f44003a,0x3e640205,0x6d4000c0}},	//   нуп_, lviq, _fötr_, _šlav, 
   {{0xdca44a4e,0x91b802e4,0xb78804b4,0x8d9000ae}},	//   _саби, עמקי, кәле_, _الفش, 
   {{0x57a44a4f,0x00000000,0x00000000,0x00000000}},	//   ышка, --, --, --, 
   {{0x7f440d04,0x388c00bc,0x06e00154,0x8f34010f}},	//   iviq, věru_, _মিশি, נטיג_, 
   {{0x1cd0031c,0x64940135,0xf484297d,0x00000000}},	//   _ེངས_, rġin, لاحی, --, 
   {{0xa3c007b7,0x00000000,0x00000000,0x00000000}},	//   ्खं_, --, --, --, 
   {{0x6d403eba,0x21384a50,0x25ec0073,0xb71800d8}},	//   _álav, _asph_, _आजची_, _ролф_, 
   {{0x7968016b,0x25bc0205,0x00000000,0x00000000}},	//   rɛwf, öylü_, --, --, 
   {{0x3134014b,0xf0e800d1,0x1fe400eb,0x00000000}},	//   шевр, ئىرى_, _ফয়স, --, 
   {{0xd590015b,0x64940327,0x7eb020a9,0x00000000}},	//   _нaвι, nġil, bäpk, --, 
   {{0x21380589,0x6f1c0175,0x92681d39,0x7eb00166}},	// [4cf0] _esph_, _qqsc, _зрна_, cäpk, 
   {{0xefd4069c,0x6cd40131,0x00000000,0x00000000}},	//   _ክንዲ_, لقئا, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xae180316,0x2ca80165,0x00000000,0x00000000}},	//   न्जन_, ôad_, --, --, 
   {{0xae042002,0x447c008f,0xcbb40150,0x00000000}},	//   _پوزى, ענדע, уғаш_, --, 
   {{0xaa444a51,0x6d404a52,0xbdd40212,0xc0f40092}},	//   рекл, _šlau, _горщ, ግጥም_, 
   {{0xe50844ab,0x6f0c4a53,0xfba80352,0x00000000}},	//   _विधि_, lrac, ктәй_, --, 
   {{0x6f0c327f,0xac940209,0x0c840064,0x00000000}},	//   orac, _табш, _сыгм, --, 
   {{0x6f0c1552,0xaa54026b,0x00000000,0x00000000}},	//   nrac, _кваш, --, --, 
   {{0x6f0c4a54,0xa5244a55,0x7cf000e4,0xe52400d8}},	//   irac, амод, _ẽrie, адоп, 
   {{0x6f0c4a56,0xb0b40073,0x00000000,0x00000000}},	//   hrac, ंताग, --, --, 
   {{0x67380211,0x6d440810,0x6d40032e,0xe6d803b2}},	//   _tswj, ivha, _álau, ðróð, 
   {{0x27ec4a57,0x6d40006a,0xe3b04a58,0x828400d1}},	//   mben_, _âlaf, ترد_, йқид, 
   {{0x27ec4a59,0xf7700132,0x6f0c4a5a,0x78a40306}},	//   lben_, _عان_, drac, čive, 
   {{0x6f0c4a5b,0xae18012c,0x2b4800d0,0x6d440175}},	//   erac, न्छन_, ťach_, jvha, 
   {{0x27ec4a5c,0x7eb001f4,0xd004008e,0xe3b000ae}},	//   nben_, mäpi, иесе_, _ورة_, 
   {{0x27ec09f0,0x7eb002f6,0xa3280113,0x6d44004c}},	// [4d00] iben_, läpi, _p葵un, evha, 
   {{0x7f440cfe,0xe0d81149,0x27ec4a5d,0xdbfc3f6f}},	//   rviq, _иво_, hben_, उण्ड_, 
   {{0x6f0c35b8,0x27ec066d,0xdca401c6,0x6d4403b2}},	//   arac, kben_, аажи, gvha, 
   {{0x27ec4a5e,0x5edc033f,0xa0681d5b,0x6d40031c}},	//   jben_, _कंप्_, _рама_, _ġlat, 
   {{0x27ec01ed,0x6d400010,0xbf6400f2,0x6f20012d}},	//   dben_, _šlat, _اگزو, ęzcó, 
   {{0x27ec09f0,0x9d44010a,0x44e800cc,0x81f400cc}},	//   eben_, _кегд, _কিনক_, _জাঁপ_, 
   {{0x88e00120,0x27ec03e0,0x1d080a5b,0x00000000}},	//   ожје, fben_, _јеби_, --, 
   {{0x27ec01ed,0x1b4824fc,0x57a41d0f,0x3940008f}},	//   gben_, _изби_, ишпа, ĉis_, 
   {{0x6c7405f5,0xc6f402d5,0x98bc0276,0x1ba801d3}},	//   _уурх, аных_, _artă_, _شارٹ_, 
   {{0xb7880184,0xab1402d2,0x00000000,0x00000000}},	//   кәһе_, _óráð_, --, --, 
   {{0x27ec4a5f,0x999c04fe,0x8620036b,0xd5b80c91}},	//   bben_, _matū_, تکنل, ъси_, 
   {{0x6f0c4a60,0x254400ef,0x6494031c,0x34940006}},	//   yrac, _dēl_, lġij, самр, 
   {{0xec7004ac,0x61e00209,0x00000000,0x00000000}},	//   פֿט_, _şola, --, --, 
   {{0x6f0c0dfe,0x64940135,0x6f980241,0x00000000}},	//   vrac, nġij, _ọkó, --, 
   {{0x6f0c4a61,0x63b8012d,0x00000000,0x00000000}},	//   wrac, ętna, --, --, 
   {{0x6f0c4a62,0x61ec4a63,0x320c03ee,0x00000000}},	//   trac, abbl, şey_, --, 
   {{0x111c0020,0x6e9805f5,0x2e40001f,0x4ea44a64}},	// [4d10] ስቲያና, гвар_, _የማይመ, аржа, 
   {{0x27ec00dd,0x7e5402bf,0x6f0c4a65,0x00000000}},	//   zben_, овує, rrac, --, 
   {{0x6f0c0876,0x27ec00dd,0x5eb40154,0x00000000}},	//   srac, yben_, _অংশে, --, 
   {{0x9ce80014,0x64940327,0x00000000,0x00000000}},	//   اونے_, eġij, --, --, 
   {{0x6f0c0784,0x27ec4a66,0x2b4800db,0x8e54010a}},	//   qrac, vben_, íac_, _вĕлл, 
   {{0xae041c5c,0x704400db,0xbea40153,0x00000000}},	//   _دوسى, _ئرگە, _маўк, --, 
   {{0x27ec066d,0x9f500113,0x29000022,0x3d94014b}},	//   tben_, mayá_, éha_, _дирр, 
   {{0x27ec4a67,0x9f500113,0x60d8004e,0x1ae403d4}},	//   uben_, layá_, ítmi, _নিৰা, 
   {{0x27ec4a68,0xa6840075,0x9880013d,0x7c2400a3}},	//   rben_, йлид, _cíın_, òire, 
   {{0x27ec00dd,0x9f5002d1,0xe8180fe3,0x7eb01b99}},	//   sben_, nayá_, _धावा_, täpi, 
   {{0xe5a44a69,0x27ec01d3,0x88804a6a,0xb6580006}},	//   сини, pben_, _ویتن, ршых_, 
   {{0x25440029,0x6010022e,0x2a64005c,0x7eb00847}},	//   _vēl_, _nаmа, _holb_, räpi, 
   {{0x79680134,0x2a640254,0x7eb0023a,0x66e40139}},	//   rɛwe, _kolb_, säpi, _уола, 
   {{0x91e00364,0x9f50007f,0x765c01f4,0x00000000}},	//   зоре, vayà_, öryt, --, 
   {{0x165801d9,0x6144023a,0x55f40375,0x00000000}},	//   _حسنک_, щева, _המצב_, --, 
   {{0x6f0801e4,0xdfd000ae,0x00000000,0x00000000}},	//   _ĥecr, سيط_, --, --, 
   {{0xa0a40454,0x00000000,0x00000000,0x00000000}},	// [4d20] _ҳанд, --, --, --, 
   {{0xe3b04a6b,0x2cac05c7,0x00000000,0x00000000}},	//   _ورک_, _aked_, --, --, 
   {{0x628c4a6c,0xa0a44a6d,0xc06402d3,0x5ac8151e}},	//   mibo, _ганд, _ዘገልግ, ңлем_, 
   {{0x64940327,0x00000000,0x00000000,0x00000000}},	//   wġij, --, --, --, 
   {{0x999c04fe,0x2a640332,0x9f5003ac,0x00000000}},	//   _tatū_, _bolb_, bayá_, --, 
   {{0x2a640076,0x6ae0015b,0xd9180124,0x00000000}},	//   _colb_, _নিখো, гьи_, --, 
   {{0x6494038f,0x3f800ffb,0x9cb400f2,0x00000000}},	//   rġij, lziu_, _همست, --, 
   {{0x38c801ed,0xe97000f7,0xcd94011a,0x08f400ae}},	//   جاتی_, بۇمد, _הדלת_, حروب_, 
   {{0x3f804a6e,0xe8182db8,0x61e00139,0x65b00162}},	//   nziu_, _धारा_, _ğoln, yðhú, 
   {{0x628c01d5,0xa6e00174,0x938801a9,0x00000000}},	//   jibo, úðag, ҳсга_, --, 
   {{0x628c4a6f,0x915c01fb,0x582801a9,0x00000000}},	//   dibo, _mặt_, _бўлг_, --, 
   {{0x628c01f5,0x7ae4054e,0xdb0c01e1,0x00000000}},	//   eibo, ţitu, _ńjùw, --, 
   {{0x628c4a70,0x93884a71,0x9f500784,0x7eb00108}},	//   fibo, усна_, yayá_, läpu, 
   {{0x628c4a72,0x3f800006,0x07340375,0x601001d5}},	//   gibo, dziu_, _לאדם_, _sаmа, 
   {{0x54e441ff,0x05d0166b,0x902801c0,0x65b003f2}},	//   _استق, _عزوج, лцаа_, rðhú, 
   {{0x628c057b,0x9f500784,0x00000000,0x00000000}},	//   aibo, wayá_, --, --, 
   {{0x628c4a73,0x4dd40c58,0x73c4151e,0xa7fc002d}},	// [4d30] bibo, ধৰোৱ, _фәне, sjűg, 
   {{0x2cac4a74,0x7414485f,0x394c12e8,0x628c4a75}},	//   _sked_, _اوکا, _ords_, cibo, 
   {{0xebd81c7b,0x5fac00e1,0xa2a44a76,0x7eb001f4}},	//   адеш_, _झुठल, चकर्, jäpu, 
   {{0x2a641c06,0x00000000,0x00000000,0x00000000}},	//   _solb_, --, --, --, 
   {{0x62980122,0x3f8004cc,0xbca4007b,0x394c045a}},	//   čtov, cziu_, أمني, _ards_, 
   {{0x996000bc,0x0dc80798,0x00000000,0x00000000}},	//   líře_, _буби_, --, --, 
   {{0x4a2400c7,0x00000000,0x00000000,0x00000000}},	//   _қьаб, --, --, --, 
   {{0x628c1373,0xa6e44a77,0x2a640fac,0x7ae400df}},	//   zibo, ожил, _wolb_, ŭita, 
   {{0xe61000f2,0x00000000,0x00000000,0x00000000}},	//   وشد_, --, --, --, 
   {{0x2b4c00d2,0xddcc00d0,0x70b4098a,0x61e00139}},	//   _irec_, _hlbš, ंतुल, _ğolo, 
   {{0x2d804a78,0x628c4a79,0x9f402045,0x2b4c030a}},	//   nzhe_, vibo, _sekü_, _hrec_, 
   {{0xa3484a7a,0x628c4a7b,0x2b4c0156,0xc8b41291}},	//   азма_, wibo, _krec_, _اصطب, 
   {{0x628c4a7c,0x63b80034,0x9f4002e2,0x7cf00241}},	//   tibo, ętno, _lekò_, _kòrò, 
   {{0x7d0001d3,0x3f800240,0xf5040014,0x00000000}},	//   _járá, vziu_, _کِٹُ, --, 
   {{0xefd40023,0x00000000,0x00000000,0x00000000}},	//   _ክሕዝ_, --, --, --, 
   {{0x628c4a7d,0xdfe8016c,0xb6cc0205,0x00000000}},	//   sibo, рдад_, şütü, --, 
   {{0x44202047,0x64542001,0x6d401332,0x9e644a7e}},	// [4d40] _ici_, _inyi, _šlap, овад, 
   {{0x64444a7f,0x645401d4,0x3f804a80,0x290401a6}},	//   ldki, _hnyi, rziu_, _ovla_, 
   {{0x44200460,0x64540083,0x64440067,0x915c0208}},	//   _kci_, _knyi, odki, _vặt_, 
   {{0x9f40007f,0x2b4c0156,0xa3ac0b40,0x9b684a81}},	//   _dekò_, _brec_, _कडा_, ишла_, 
   {{0x7d004a82,0x2b4c0228,0x29040c86,0x64544a83}},	//   _bárá, _crec_, _avla_, _mnyi, 
   {{0x2b4c05c7,0xf8b400dc,0x712401ed,0x7eb04a84}},	//   _drec_, ुष्प, _بریل, täpu, 
   {{0x787c4a85,0x64544a86,0x7cf001e1,0x2b4c00a2}},	//   _léve, _onyi, _dòrò, _erec_, 
   {{0x64544a87,0x2b4c00db,0xab0846f5,0x629c01a6}},	//   _nnyi, _frec_, شتۇق_, _ljpo, 
   {{0x2b4c4a88,0x290405d5,0x64440083,0x3a2c030a}},	//   _grec_, _evla_, ddki, _tbdp_, 
   {{0x64544a89,0x0f540302,0x64440067,0x00000000}},	//   _anyi, קיים_, edki, --, 
   {{0xaa400075,0x7968016b,0x2b4c0165,0xfbcc00cc}},	//   _سۆيى, bɛwa, _zrec_, _লভিত, 
   {{0x44204a8a,0x787c067c,0x629c4a8b,0xa8a40220}},	//   _cci_, _béve, _ajpo, _ерік, 
   {{0x3724031c,0x787c06af,0x926800a7,0xfa28031c}},	//   _འདྲལ_, _céve, арва_, _ལྡོན_, 
   {{0x787c2047,0x64544a8c,0x75d41216,0x64444a8d}},	//   _déve, _enyi, _عيبا, adki, 
   {{0x44204a8e,0x81d40323,0x86780302,0x86c014af}},	//   _fci_, дорх, _דרגו, _تيون, 
   {{0x44200334,0x9f4002e2,0x629c01ef,0x04d800df}},	//   _gci_, _rekò_, _ejpo, _דקהל, 
   {{0xcdd84a8f,0x00000000,0x00000000,0x00000000}},	// [4d50] ање_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3ff43955,0x44200a73,0x7cf0007f,0xfbd003e6}},	//   سكەر, _yci_, _ròrò, ۆته_, 
   {{0x2b4c4a90,0x44200393,0x2d8005c7,0xac1801f0}},	//   _prec_, _xci_, rzhe_, соду_, 
   {{0xfbd04a91,0x826403e6,0xca68022e,0x7cf001e1}},	//   نته_, _رهێن, ftgа, _pòrò, 
   {{0x6a844a92,0x2b4c05c7,0x00d81046,0x00000000}},	//   ялла, _vrec_, _دبیت_, --, 
   {{0xc27c0302,0x64940030,0x64440014,0x78a400d7}},	//   שרוי, lšie, ydki, čivn, 
   {{0x2b4c4a93,0x7d0001e1,0xa76400d4,0x7eb00a43}},	//   _trec_, _wárá, зкид, bäps, 
   {{0x6494244f,0x7d000241,0x5fac0037,0x00000000}},	//   nšie, _tárá, _झुाल, --, 
   {{0x787c4a94,0x2fd84a95,0xca740075,0xa9c000db}},	//   _réve, _lgsg_, _بارغ, _كۅشۉ, 
   {{0x787c06af,0x44204a96,0xdd0400a2,0x64940419}},	//   _séve, _pci_, _köšg, hšie, 
   {{0x26d804d4,0x19b80375,0x64944a97,0x7a840132}},	//   ísos_, _המעב, kšie, _ىشەم, 
   {{0x649401f1,0x00000000,0x00000000,0x00000000}},	//   jšie, --, --, --, 
   {{0x27fc0204,0xb6cc4a98,0x216800ee,0x64940419}},	//   _hewn_, şürü, биги_, dšie, 
   {{0x66004a99,0x81b40f22,0x26dc01f7,0x27fc031c}},	//   malk, জেন_, _huwo_, _kewn_, 
   {{0x66004a9a,0x64544a9b,0x787c01ed,0x4ccc01ec}},	//   lalk, _unyi, _téve, _ﺑﺎﻻﻻ, 
   {{0x27fc0f7b,0x00000000,0x00000000,0x00000000}},	// [4d60] _mewn_, --, --, --, 
   {{0x66004a9c,0x27fc0135,0xb3a40412,0x00000000}},	//   nalk, _lewn_, _गुटख, --, 
   {{0x61fc00e2,0xd12c0244,0x9be4003b,0x11d8123b}},	//   _iepl, _یمی_, пілк, _לחיב, 
   {{0xa0a4039b,0x63b4023a,0x28e40150,0x649400d7}},	//   _хамд, _kyyn, _ﺍﺨﺘﻠ, bšie, 
   {{0x61fc4a9d,0x66004a9e,0x26dc4a9f,0x60dc014f}},	//   _kepl, kalk, _nuwo_, _hupm, 
   {{0x63b4049b,0x66004aa0,0x61fc020c,0x9a180a89}},	//   _myyn, jalk, _jepl, сюду_, 
   {{0x66004aa1,0x60dc014f,0xdee4023b,0xacf401d9}},	//   dalk, _jupm, _фоҳи, _ٲسِت, 
   {{0x61fc4aa2,0x0d7404fb,0x670002e3,0x60dc047e}},	//   _lepl, _عینک_, _ịkar, _mupm, 
   {{0x26dc020c,0x66004aa3,0x649405be,0x60dc0477}},	//   _cuwo_, falk, kšib, _lupm, 
   {{0x61fc4aa4,0x66004aa5,0x26dc4aa6,0x6a7c0100}},	//   _nepl, galk, _duwo_, _pèfe, 
   {{0x27fc0cfd,0x75d4384b,0x60dc0477,0x63b40432}},	//   _fewn_, بيدا, _nupm, _ayyn, 
   {{0x5fbc4aa7,0x660000c5,0x27fc0142,0x0d9402e4}},	//   ्धाल, aalk, _gewn_, לכים_, 
   {{0x66004aa8,0x61fc4aa9,0x2ed003d4,0xe8b00244}},	//   balk, _bepl, িৱিষ, _جڕوج, 
   {{0x61fc4aaa,0x66004aab,0x06e003d4,0x55040276}},	//   _cepl, calk, _মিচি, _ечиа, 
   {{0x26dc0198,0x60dc3c56,0x764803cb,0xc1a400ea}},	//   _zuwo_, _cupm, mddy, ејти, 
   {{0x60dc0455,0x26dc00ca,0x61fc035a,0x7bc0022e}},	//   _dupm, _yuwo_, _eepl, _ozmu, 
   {{0xbed817a2,0x99900209,0xe2a804fb,0xe81c2982}},	// [4d70] здух_, şyň_, _ژاپن_, फलता_, 
   {{0x61fc4aac,0x764800a9,0x64944aad,0x629800b0}},	//   _gepl, nddy, ršie, ōtor, 
   {{0x7bc00477,0x06e000bd,0x705401ed,0x76483deb}},	//   _azmu, _মিছি, _ہنگا, iddy, 
   {{0x61fc15d9,0x64940030,0x7c8408ca,0xa03415bf}},	//   _zepl, pšie, нуче, _قىپت, 
   {{0x66004aae,0x61fc01e2,0xaa444aaf,0x64940427}},	//   yalk, _yepl, делл, lšic, 
   {{0x66004ab0,0x79680134,0xfaf0143e,0x60dc016d}},	//   xalk, rɛwn, اثن_, _yupm, 
   {{0xad242e51,0x66004ab1,0xbd680220,0xfbd000d1}},	//   _تىزى, valk, _ерте_, نتۇ_, 
   {{0x66004ab2,0x76581d59,0xf9903dbb,0x7eb04ab3}},	//   walk, _anvy, دبه_, läpp, 
   {{0x7bc0056a,0x76480142,0x54e401ec,0x7c8400d8}},	//   _gzmu, fddy, _ﺍﻟﺨﻼ, _џусе, 
   {{0x649408ad,0x7eb04ab4,0x764803cb,0x63b40108}},	//   kšic, näpp, gddy, _ryyn, 
   {{0x61fc4ab5,0x66004ab6,0xe5781fe2,0x26dc4ab7}},	//   _repl, ralk, ізм_, _wuwo_, 
   {{0x69c04ab8,0x66004ab9,0x61fc4aba,0x26dc4abb}},	//   _izle, salk, _sepl, _tuwo_, 
   {{0x66004abc,0x61fc4abd,0x60dc1263,0x7eb04abe}},	//   palk, _pepl, _supm, käpp, 
   {{0x66000014,0x60dc014f,0x6d0c0490,0x76480076}},	//   qalk, _pupm, _हिंग_, cddy, 
   {{0x67284abf,0x91e02cfe,0x60dc014f,0xa11400f2}},	//   ltej, тосе, _qupm, ظورت, 
   {{0x61fc0921,0x63b4023a,0x60dc047e,0xe2a40150}},	//   _wepl, _tyyn, _vupm, _ﺎﻓﻬﻡ_, 
   {{0x61fc0e96,0xc1780006,0x00000000,0x00000000}},	// [4d80] _tepl, šė_, --, --, 
   {{0xaae00c2e,0x69c04ac0,0x6728045f,0x60dc014f}},	//   _पढ़क, _ozle, itej, _tupm, 
   {{0xa0684ac1,0x787c4ac2,0xa3a80014,0x672826bb}},	//   _дана_, _léva, _دُکل_, htej, 
   {{0x67284ac3,0xe8182232,0xdee4064e,0x98bc01ef}},	//   ktej, _धागा_, _ооми, _drtě_, 
   {{0x764800a9,0x69c04ac4,0x67280200,0x787c00e5}},	//   yddy, _azle, jtej, _néva, 
   {{0xca300114,0xb9e4075e,0x00000000,0x00000000}},	//   вешћ, رتتۇ, --, --, 
   {{0x64940003,0x9c5c0354,0x00000000,0x00000000}},	//   nġis, _кхаi, --, --, 
   {{0xa3ac0cb4,0x9078008f,0x76480142,0x00000000}},	//   कथा_, ַטיי, wddy, --, 
   {{0x69c04ac5,0x7bc003ef,0x00000000,0x00000000}},	//   _ezle, _uzmu, --, --, 
   {{0x787c4ac6,0x1ae4005e,0x7648015d,0x00000000}},	//   _déva, _ﺍﯙﺗﻮ, uddy, --, 
   {{0x7ae001c8,0x2d840427,0x67280254,0x76480042}},	//   _humt, _žlez_, atej, rddy, 
   {{0x7ae04ac7,0x67284ac8,0x00000000,0x00000000}},	//   _kumt, btej, --, --, 
   {{0x7ae04ac9,0xb9c8044e,0x482001d9,0x5fac000d}},	//   _jumt, _ኲሉ_, _شىوق, _झुलल, 
   {{0x7ae04aca,0xeb90008f,0x00000000,0x00000000}},	//   _mumt, אָל_, --, --, 
   {{0x7ae0044e,0x8634008d,0xc6900a1e,0x34940006}},	//   _lumt, _חרוב_, _באס_, _пакр, 
   {{0xfe70004b,0x67340174,0x7c2401ab,0x54a4007b}},	//   یدل_, _ígjá, òirl, _تحتف, 
   {{0x7ae00548,0x7a4800b0,0x15b00150,0x6494031c}},	// [4d90] _numt, _kūtē, _سەڭس, rġit, 
   {{0x6458005f,0x60c4009d,0x649400d0,0x00000000}},	//   ētie, _ehkm, pšic, --, 
   {{0x64944acb,0x7eb04acc,0x00000000,0x00000000}},	//   qšic, räpp, --, --, 
   {{0x320003d1,0x61e00139,0x672801f4,0x00000000}},	//   _hehy_, _ğoli, ytej, --, 
   {{0x7ae0078c,0x7eb00036,0x9f4001f4,0x81b400eb}},	//   _cumt, päpp, _sekö_, জেদ_, 
   {{0x8d744acd,0x9f40145e,0x32000109,0x7ae04ace}},	//   _قازا, _pekö_, _jehy_, _dumt, 
   {{0x63b80034,0x2ebc04e4,0x2d8403cd,0x00000000}},	//   ętni, ्गीत, _åle_, --, 
   {{0x67284acf,0x7ae00115,0x69c02a92,0x787c0124}},	//   ttej, _fumt, _vzle, _péva, 
   {{0xe7384ad0,0x7ae04ad1,0x672801f4,0x3c6802f2}},	//   чеп_, _gumt, utej, _تینێ_, 
   {{0x67284ad2,0x787c00e4,0x6ba40356,0xe6440166}},	//   rtej, _véva, ărgă, хеоп, 
   {{0x67284ad3,0x624c0943,0x7ae007c5,0xc8644ad4}},	//   stej, ṱoko, _zumt, _отди, 
   {{0x67284ad5,0xc2f40154,0x4424067c,0x9f500022}},	//   ptej, _জিবি_, üm_, rayú_, 
   {{0x4680005e,0x68e04ad6,0x33b42401,0x32000419}},	//   _ақпа, _huld, вёрт, _behy_, 
   {{0xdecc001f,0xe57002c9,0x00000000,0x00000000}},	//   ባችን_, _مطب_, --, --, 
   {{0x68e001e3,0x1a98010f,0x216823c5,0x00000000}},	//   _juld, לישע, чиви_, --, 
   {{0x68e04ad7,0x630418fd,0x50400108,0x00000000}},	//   _muld, _كوبل, лесб, --, 
   {{0x68e00793,0x32000109,0xe2982901,0x7c2400a3}},	// [4da0] _luld, _fehy_, _наи_, òirm, 
   {{0x68e02f05,0x7ae04ad8,0x787c01d3,0x53c4008e}},	//   _ould, _rumt, _névn, _ягым_, 
   {{0x7ae04ad9,0x21744ada,0x00000000,0x00000000}},	//   _sumt, _чупр, --, --, 
   {{0x7ae0014f,0x388c00bc,0x78a402f0,0x9b044adb}},	//   _pumt, běry_, čivk, ездд, 
   {{0x68e00493,0xa068035b,0x7ae02b9e,0x7c9400d1}},	//   _auld, _даҽа_, _qumt, ىشچا, 
   {{0x68e04adc,0x20004add,0xcf8c0014,0x7ae0014f}},	//   _buld, _heki_, _اژِ_, _vumt, 
   {{0x20004ade,0x7ae00117,0x68e00072,0x00000000}},	//   _keki_, _wumt, _culd, --, 
   {{0x20004adf,0x7ae04ae0,0x1ca80327,0x891400d1}},	//   _jeki_, _tumt, _པཉི_, رغىز_, 
   {{0x20004ae1,0x7ae0208d,0xc1fc031c,0x689001d3}},	//   _meki_, _uumt, _དབ༵ང_, جینئ, 
   {{0x20004ae2,0x68e04ae3,0x4730009a,0x00000000}},	//   _leki_, _fuld, اريز, --, 
   {{0x68e04ae4,0x04b800dd,0x857001c0,0x75d4028e}},	//   _guld, کھوں_, глэх, ضيحا, 
   {{0x34944ae5,0x00000000,0x00000000,0x00000000}},	//   тамр, --, --, --, 
   {{0x64940153,0x00000000,0x00000000,0x00000000}},	//   ušia, --, --, --, 
   {{0x68e04ae6,0x64940006,0x388c00bc,0x00000000}},	//   _yuld, ršia, věry_, --, 
   {{0x20004ae7,0x64940cf4,0x00000000,0x00000000}},	//   _beki_, mšin, --, --, 
   {{0x20004ae8,0xc058185e,0x64940024,0x388c0118}},	//   _ceki_, ىشقا_, pšia, těry_, 
   {{0x200003ee,0x245804cc,0x787c4ae9,0x320001f4}},	// [4db0] _deki_, sümà_, _lévo, _tehy_, 
   {{0x649402fb,0x2000000d,0xfe7001d9,0x00000000}},	//   nšin, _eeki_, ٝدم_, --, 
   {{0x20004aea,0x787c0798,0x00000000,0x00000000}},	//   _feki_, _névo, --, --, 
   {{0x6ac80146,0x9f402776,0x68e00166,0x6b740c5c}},	//   िग्र, _pekô_, _ruld, клеу, 
   {{0x68e04aeb,0x00000000,0x00000000,0x00000000}},	//   _suld, --, --, --, 
   {{0x200005d1,0xc33404ae,0x64940010,0x0bd801ec}},	//   _zeki_, רוס_, jšin, _ﻁﺭﺩﻫ, 
   {{0x68e04aec,0x20004aed,0x49900e60,0x00000000}},	//   _quld, _yeki_, دیار, --, 
   {{0x6d542165,0x787c4aee,0x64940006,0x68e001a4}},	//   _irza, _dévo, ešin, _vuld, 
   {{0x78640075,0x661401ed,0x648400ae,0xd9b00154}},	//   ادىك, ózko, _hóig, টেলম, 
   {{0x68e04aef,0x6d540950,0x7ecc02dd,0x64940064}},	//   _tuld, _krza, _ﺒﺎﻟﻁ, gšin, 
   {{0xe5a44af0,0x68e00e14,0x79500133,0x00000000}},	//   тини, _uuld, _هێوا, --, 
   {{0xf7704af1,0x6d5401fa,0x3958007b,0xa2e44af2}},	//   _گام_, _mrza, _ársa_, комд, 
   {{0x20004af3,0x81fc0003,0x93400c9e,0x4cc8015b}},	//   _reki_, _དབྱི_, аняе, িদপু, 
   {{0xf7704af4,0x6d544af5,0x20004af6,0x55e000db}},	//   _دام_, _orza, _seki_, _кошб, 
   {{0x2b9007ae,0x200003ee,0x9100026a,0xa0b40640}},	//   ạch_, _peki_, ипре, вљај, 
   {{0x23840014,0xfd6400b8,0x64840332,0x61e00139}},	//   _لٔبِ, _gsuṅ, _sóif, _ğolu, 
   {{0x6d544af7,0x20004af8,0xa3b82c10,0xe2840e58}},	// [4dc0] _arza, _veki_, _تاثر_, _алпи, 
   {{0x6d54110c,0x9b4403e6,0x81fc0327,0x8e804af9}},	//   _brza, ێناو, _དབྲི_, агуе, 
   {{0x64840332,0x5bc81fe7,0x00000000,0x00000000}},	//   _cóig, िध्व, --, --, 
   {{0x6d541326,0x5f044afa,0x787c4afb,0x64840597}},	//   _drza, _изма, _révo, _dóig, 
   {{0x4fa000d6,0x9a844afc,0x787c007f,0x8b200b7e}},	//   _вияв, кукл, _dévl, идце, 
   {{0x6a7c007f,0xcb640640,0xd12c0244,0x00000000}},	//   _dèfo, таље_, _امێ_, --, 
   {{0x81b403f4,0xadc40032,0x6d54033f,0xce34011a}},	//   জের_, _барһ, _grza, _שאלת_, 
   {{0x787c0118,0xe9d80014,0x6e20007c,0xaf3802d2}},	//   _vévo, رگٕچ_, _ölbr, _íþág, 
   {{0x1ae410f5,0x64940316,0x6484007b,0x6d5800b0}},	//   _розм, tšin, _móid, āwae, 
   {{0x64940006,0x869400db,0x199400f3,0x00000000}},	//   ušin, ккыс_, _ијер, --, 
   {{0x64944afd,0x00000000,0x00000000,0x00000000}},	//   ršin, --, --, --, 
   {{0x7f440472,0x6abc00de,0x00000000,0x00000000}},	//   kwiq, _īsfi, --, --, 
   {{0x64944afe,0x00000000,0x00000000,0x00000000}},	//   pšin, --, --, --, 
   {{0x537802d3,0x69c40254,0x00000000,0x00000000}},	//   _ይኸይድ_, üheg, --, --, 
   {{0x2cbc0076,0x84700023,0xd4c400d8,0x00000000}},	//   ylwd_, ብሎምን_, _исип, --, 
   {{0x85000075,0xa5d8010f,0x00000000,0x00000000}},	//   _ئوين, _אַפי, --, --, 
   {{0x81b40011,0x3fb400ae,0x00000000,0x00000000}},	// [4dd0] জেল_, لإكس, --, --, 
   {{0x6d544aff,0x648401e7,0x3df428e8,0x81d80154}},	//   _prza, _póig, изус, াড়_, 
   {{0xdbcc002e,0x6a7c02e2,0xf90c0354,0x70940064}},	//   _añàk, _sèfo, _доiа_, _банф, 
   {{0x6a7c007f,0x4fc44b00,0xa154011a,0x6d5401ef}},	//   _pèfo, _асга, _עברה_, _vrza, 
   {{0x09c84b01,0xff0402d5,0x54e402dd,0x64940064}},	//   ाध्य, _вясн, _ﺍﻟﺴﻼ, dšil, 
   {{0x6e941920,0x6f0c4b02,0xa9a44b03,0x0dc8010b}},	//   _сигу, msac, лилд, _жуби_, 
   {{0x6f0c4b04,0x2cbc0369,0x452c0327,0x6d544b05}},	//   lsac, plwd_, _ཨཱེར_, _urza, 
   {{0xe5a401d5,0x6d4402d0,0x68441069,0x6f0c4b06}},	//   ғими, mwha, униа, osac, 
   {{0x6eb83c16,0xca2400c7,0xe7c00183,0x6d44127b}},	//   ्तपु, _афеи, উশ্য, lwha, 
   {{0x6f0c4b07,0x2284002d,0x6e240007,0x6d4402b1}},	//   isac, _kôke_, nghb, owha, 
   {{0x6d44035a,0x00000000,0x00000000,0x00000000}},	//   nwha, --, --, --, 
   {{0x6d4404fe,0x67544b08,0x36c400cf,0x00000000}},	//   iwha, _مختر, лбөг, --, 
   {{0xe7380262,0x6d442f05,0x27ec4b09,0xddcc0006}},	//   _чел_, hwha, mcen_, _pobū, 
   {{0x27ec2a3d,0x6d44009a,0x787c01ed,0x6f0c017a}},	//   lcen_, kwha, _névj, dsac, 
   {{0x64840077,0x27ec05ac,0x057400db,0xe0600133}},	//   _póid, ocen_, _جاشد, مێدی, 
   {{0x6f0c0e78,0x3eb80010,0x6d444b0a,0x9fe00011}},	//   fsac, _skrt_, dwha, বর্গ, 
   {{0x6f0c00db,0x2364036e,0xe7c8012d,0xd1b800d1}},	// [4de0] gsac, _çoj_, ाइटप, _ۋاپا_, 
   {{0xe1f84077,0x7f4402d1,0x27ec0205,0x6e240327}},	//   _яго_, rwiq, hcen_, gghb, 
   {{0x6f0c14d0,0xe0d82bbd,0x00000000,0x00000000}},	//   asac, _пво_, --, --, 
   {{0xac2400d6,0x6f0c208d,0x63880129,0x27ec0427}},	//   ифік, bsac, _gêné, jcen_, 
   {{0x27ec0618,0x6f0c054e,0x649409a8,0x6d4402b5}},	//   dcen_, csac, jšim, awha, 
   {{0xcde009a5,0x3974004e,0x00000000,0x00000000}},	//   _горй, иллё, --, --, 
   {{0xdca44b0b,0x649400f3,0xd7e424d8,0x648401e7}},	//   _бави, tšil, ліпо, _móib, 
   {{0x2da402f0,0x48a403cf,0xb714011c,0x00000000}},	//   ápeš_, лтым_, адищ, --, 
   {{0x649419d6,0xbb5403e6,0x98bc054e,0xcc740a7c}},	//   ršil, _خۆشب, _astă_, _עגמת_, 
   {{0x64840332,0x27ec0042,0x961c353b,0xd90c35cf}},	//   _nóib, acen_, पलेट_, _فیت_, 
   {{0x64944b0c,0xd5b80137,0x00000000,0x00000000}},	//   mšij, эси_, --, --, 
   {{0xd3244b0d,0x27ec23db,0x64940010,0x6f0c0072}},	//   льги, ccen_, bšim, ysac, 
   {{0x83840124,0x6f0c002f,0x6eb800cd,0x7a480064}},	//   быре, xsac, ्तमु, pūtė, 
   {{0x6d444b0e,0x35d4005b,0x320401d3,0x00000000}},	//   ywha, _колё, úly_, --, 
   {{0x64840597,0x6f0c03f0,0x867806a9,0x06780302}},	//   _dóib, wsac, _ארגו, _אנגל, 
   {{0x6f0c4b0f,0xbf100073,0xc5100035,0xc3e401af}},	//   tsac, ाळून_, _ابوت, _гөрһ, 
   {{0x52a4027a,0xf4840424,0x9fe00183,0x6f0c01ab}},	// [4df0] _مصدق, _ماکی, বৰ্গ, usac, 
   {{0x6f0c34eb,0x518434bf,0x6e244b10,0x649405be}},	//   rsac, _бума, ughb, jšij, 
   {{0x6f0c4b11,0x6d4402b5,0xad240131,0xfee401b9}},	//   ssac, uwha, شىشى, _қўям, 
   {{0x6d444b12,0xe468023a,0xac1838d4,0x6bd801c8}},	//   rwha, mpöä_, тоду_, نواس_, 
   {{0xeab04b13,0x6b64377b,0x6f0c0175,0x6d440857}},	//   يعت_, ркла, qsac, swha, 
   {{0xfbd04b14,0x649402fb,0x6484035b,0x00000000}},	//   ستن_, všim, _kóic, --, 
   {{0x27ec12cb,0x636c0139,0xe968020f,0x5edc000d}},	//   tcen_, _kеnä, тайл_, _कूट्_, 
   {{0x69d403c6,0xe7380124,0x9f500789,0x27ec01bf}},	//   _územ, веи_, cayó_, ucen_, 
   {{0xa68404a9,0xb8ec3042,0xd704005b,0x00000000}},	//   илид, _शी_, аные_, --, 
   {{0xd6cc4b15,0xbb840597,0x27ec0356,0xf96804b4}},	//   وقي_, _الكي, scen_, трәй_, 
   {{0x940800ac,0x64840332,0x28141f0d,0x00000000}},	//   licə_, _róib, _نواس, --, 
   {{0x64944b16,0xefe4010c,0x64840332,0x00000000}},	//   pšim, ምራዊ_, _sóib, --, 
   {{0x64940309,0xa2e430ab,0x940803e3,0x00000000}},	//   qšim, рогд, nicə_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x648401e7,0x61441420,0x00000000,0x00000000}},	//   _cóic, шева, --, --, 
   {{0xd9e0012c,0x648400ae,0xa2e421f3,0x5dc801ec}},	//   _पल्ट, _dóic, _коид, _ﺒﻭﻻﻴ, 
   {{0x648c1682,0x1f644b17,0x4fe44b18,0x64840332}},	// [4e00] ṱisa, шкам, рмун_, _tóib, 
   {{0x60e816c3,0xddc40124,0x94080213,0xc220000d}},	//   _имом_, абзи, dicə_, _बाटब_, 
   {{0x516400fd,0x64940010,0x5c040354,0x9d440108}},	//   _күрү_, všij, аяла, реед, 
   {{0x5040022e,0x00000000,0x00000000,0x00000000}},	//   _деюб, --, --, --, 
   {{0xdde80214,0x00000000,0x00000000,0x00000000}},	//   _لرزه_, --, --, --, 
   {{0xd354025d,0x38c800f2,0x00000000,0x00000000}},	//   ייני_, گاتی_, --, --, 
   {{0x64944b19,0x00000000,0x00000000,0x00000000}},	//   ršij, --, --, --, 
   {{0xdca44b1a,0x5ca44b1b,0xddcc007f,0x787c06af}},	//   _таби, _тибб, _rabň, _kévi, 
   {{0xdd9402dd,0x49c429dc,0x00000000,0x00000000}},	//   _саңы, ллән_, --, --, 
   {{0x8f3408a8,0xdbf001e1,0x00000000,0x00000000}},	//   סטיג_, _s̟èg, --, --, 
   {{0x3a2c0158,0x98484b1c,0x787c06af,0x98b00213}},	//   _icdp_, _аяла_, _lévi, şdım_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd04c06be,0x7eb001f4,0x00000000,0x00000000}},	//   _gicə, säpy, --, --, 
   {{0x394c0165,0x7bc00175,0x947400e5,0x00000000}},	//   _ksds_, _mymu, ادھا, --, 
   {{0x6604000d,0xc59000f3,0x00000000,0x00000000}},	//   _õhka, _мишј, --, --, 
   {{0x61f80790,0x7bc000a2,0xd37823be,0x44f000f2}},	//   ıtla, _oymu, _ачо_, _بسوز, 
   {{0x3dcc013f,0x0ee802bf,0x7bc00142,0x291800b8}},	// [4e10] ɑkwɑ_, тьби_, _nymu, _āsam_, 
   {{0x787c4afb,0x648401e7,0x00000000,0x00000000}},	//   _dévi, _tóic, --, --, 
   {{0x7bc04b1d,0x0d640107,0xcdd80114,0x787c00e5}},	//   _aymu, шъам, тња_, _tévh, 
   {{0xe8f81621,0x940803be,0xa5d800c8,0x7bc00623}},	//   қли_, ticə_, אַני, _bymu, 
   {{0x7bc00cfd,0x648406ed,0x7eb00227,0x2ca80115}},	//   _cymu, _jóia, yäpx, ĵad_, 
   {{0x6494000a,0x7bc000a9,0xaa440b3b,0x00000000}},	//   tšik, _dymu, секл, --, 
   {{0x3a2c4b1e,0x3cf00030,0x7bc01d1d,0x423808c3}},	//   _dcdp_, ľové_, _eymu, ינגל_, 
   {{0x3cf00122,0x394c0e78,0x987802b1,0x649402f0}},	//   žové_, _dsds_, tūā_, ršik, 
   {{0x6a7c0699,0x7bc000a9,0x7eb00054,0x22840109}},	//   _lèfi, _gymu, täpx, _lôka_, 
   {{0xba7406d5,0xe6881a59,0xa6844b1f,0x00000000}},	//   _والت, اندى_, слод, --, 
   {{0x2b4c0393,0x00000000,0x00000000,0x00000000}},	//   _hsec_, --, --, --, 
   {{0x64a44b20,0x7968016b,0x648400d8,0x672c0115}},	//   сама, rɛwt, _bóia, _ĥajf, 
   {{0x69c04b21,0x00000000,0x00000000,0x00000000}},	//   _hyle, --, --, --, 
   {{0x787c4b22,0x26d8012c,0x69c04b23,0x64b00421}},	//   _révi, ůsob_, _kyle, kāig, 
   {{0x69c00204,0xa6e0022c,0x787c4056,0x00000000}},	//   _jyle, øðug, _sévi, --, 
   {{0x69c04b24,0x6a7c0137,0x2b4c04cc,0xa348035b}},	//   _myle, _dèfi, _osec_, _бзиа_, 
   {{0x64444b25,0x9fc805f5,0x1e841cf2,0xd00c007b}},	// [4e20] meki, угаа_, блам, علك_, 
   {{0x64444b26,0x69c04b27,0x6d5802b5,0x7bc0015d}},	//   leki, _oyle, āwan, _rymu, 
   {{0x7bc00cfd,0x2b4c0098,0x69c04b28,0x64b00618}},	//   _symu, _asec_, _nyle, gāig, 
   {{0x7f3c0023,0xe04400ea,0x00000000,0x00000000}},	//   _ኣጋይሽ, _унми, --, --, 
   {{0x29040135,0x6444009d,0x10a000d1,0x394c002f}},	//   _awla_, ieki, _хиян, _ssds_, 
   {{0x69c04b29,0x9f40020c,0x7bc000d7,0x00000000}},	//   _byle, _ngké_, _vymu, --, 
   {{0x64444b2a,0x5d840491,0x2b4c3c57,0x69c0002f}},	//   keki, _الأل, _esec_, _cyle, 
   {{0x69c000a9,0x4b844b2b,0x0d7401b9,0x2b4c0142}},	//   _dyle, рйән_, _دیمک_, _fsec_, 
   {{0xd6d81773,0x69c00365,0xc6f44b2c,0x64444b2d}},	//   лто_, _eyle, бных_, deki, 
   {{0x69c04b2e,0xa8a40137,0x787c00e5,0x751401f4}},	//   _fyle, йрөк, _névv, омоф, 
   {{0x59c4237e,0x64444b2f,0x79680134,0x69c0036e}},	//   _اياك, feki, rɛws, _gyle, 
   {{0x64444b30,0xab5c033f,0x00000000,0x00000000}},	//   geki, _wyże, --, --, 
   {{0x97c4005b,0x473004f2,0x00000000,0x00000000}},	//   _уйде, _فروز, --, --, 
   {{0xc3302928,0x6a7c0100,0x00000000,0x00000000}},	//   رەپ_, _dèfw, --, --, 
   {{0x64444b31,0x69c0045a,0x05801188,0xb6cc0205}},	//   beki, _xyle, _нуъм, ğüdü, 
   {{0x64444b32,0xb6cc15b7,0x00000000,0x00000000}},	//   ceki, şüdü, --, --, 
   {{0x648400e4,0x6e984b33,0x2e400092,0x00000000}},	// [4e30] _kóin, авар_, _ከማይመ, --, 
   {{0x60d400d7,0x00000000,0x00000000,0x00000000}},	//   amym, --, --, --, 
   {{0x648401e7,0x00000000,0x00000000,0x00000000}},	//   _móin, --, --, --, 
   {{0xcc084b34,0x2d8405de,0x1068007b,0x29040042}},	//   ازان_, _ülem_, _إحدى_, _rwla_, 
   {{0x69c04b35,0x9fa401ee,0x00000000,0x00000000}},	//   _syle, _дырҙ, --, --, 
   {{0xe8f84b36,0x3cf8010a,0x70441411,0x2b4c0427}},	//   алк_, _ftrv_, _ارگە, _vsec_, 
   {{0x64444b37,0x787c003e,0x4a7001ec,0xd6cc00eb}},	//   yeki, _lévu, жықт, রদায, 
   {{0x69c00232,0x64444b38,0x6458005f,0x58d007b5}},	//   _vyle, xeki, ētik, мојт, 
   {{0x7c240597,0x64444b39,0x69c0033f,0x7bf80262}},	//   óire, veki, _wyle, _ынтр_, 
   {{0x69c04b3a,0x81b40eac,0x648401e7,0x64444b3b}},	//   _tyle, জেট_, _cóin, weki, 
   {{0x69c0002d,0x00000000,0x00000000,0x00000000}},	//   _uyle, --, --, --, 
   {{0x644401c4,0x64980d1d,0x00000000,0x00000000}},	//   ueki, ртор_, --, --, 
   {{0x64444b3c,0x649404a7,0x64840332,0x7dd002d2}},	//   reki, kšiv, _fóin, _kósí, 
   {{0x64441cd8,0xa18802ec,0x64940010,0x00000000}},	//   seki, абга_, jšiv, --, 
   {{0x64444b3d,0x91e0013e,0x00000000,0x00000000}},	//   peki, доре, --, --, 
   {{0xe6d8008c,0x6444401f,0x00000000,0x00000000}},	//   ðræð, qeki, --, --, 
   {{0x26c40407,0xd36c0451,0x3d0c0073,0x3cf8007c}},	// [4e40] ollo_, _لهي_, डीने_, _strv_, 
   {{0xb8fc081f,0x26c4056a,0x5d580640,0x00000000}},	//   _རྫ_, nllo_, ијер_, --, 
   {{0x21684b3e,0x628c0369,0x1be8035b,0x00000000}},	//   _тини_, mhbo, адеи_, --, 
   {{0x5f2818d9,0x80a80011,0x00000000,0x00000000}},	//   _комм_, _কীর্, --, --, 
   {{0x2cac2630,0x69c44b3f,0x00000000,0x00000000}},	//   _djed_, ühen, --, --, 
   {{0x6494025c,0x628c0208,0x00000000,0x00000000}},	//   aġix, nhbo, --, --, 
   {{0x6b980023,0x64940153,0x00000000,0x00000000}},	//   ሓላለፈ_, lšiu, --, --, 
   {{0x26c44b40,0x3a204b41,0x64840332,0x787c01d3}},	//   ello_, şip_, _sóin, _névt, 
   {{0x2bd805d7,0x68ec01e4,0x87e401e0,0x00000000}},	//   बेदा, ĉada, әһәң_, --, 
   {{0xd9444b42,0x993800c0,0x64940064,0x00000000}},	//   _мези, _вяду_, išiu, --, 
   {{0x99480491,0xceb004ac,0x6610082a,0x54e402dd}},	//   _خلال_, ויז_, رژوا, _ﺍﻟﺒﻼ, 
   {{0xd4980364,0x628c0280,0x26c44b43,0x64940010}},	//   рро_, ehbo, allo_, zšiv, 
   {{0xc87c0639,0xc4580c9e,0x78a00810,0xd1cc001f}},	//   öße_, циях_, mimv, ኤያት_, 
   {{0x78a04b44,0x628c4b45,0x201c00b0,0xc1e8005b}},	//   limv, ghbo, _ētia_, жьте_, 
   {{0x76484b46,0x00000000,0x00000000,0x00000000}},	//   medy, --, --, --, 
   {{0x76484b47,0x2284025a,0x75284b48,0x2ef44b49}},	//   ledy, _fôko_, mudz, ззар, 
   {{0x75284b4a,0x648401e7,0x00000000,0x00000000}},	// [4e50] ludz, _móil, --, --, 
   {{0x628c016d,0x76484b4b,0x8d840451,0x78a00051}},	//   chbo, nedy, يشان, himv, 
   {{0x7528006f,0x649439ae,0x32104b4c,0x7dd001e1}},	//   nudz, ršiv, mazy_, _rósí, 
   {{0x7c844b4d,0x321005da,0x75280099,0x76484b4e}},	//   муче, lazy_, iudz, hedy, 
   {{0x76484b4f,0x75284b50,0x26c403cb,0x23dc00dc}},	//   kedy, hudz, yllo_, नेपद, 
   {{0x75284b51,0x76480034,0x32104b52,0x6a7c007f}},	//   kudz, jedy, nazy_, _nèft, 
   {{0x76481477,0x32100109,0x78a0009a,0x00000000}},	//   dedy, iazy_, fimv, --, 
   {{0x75280433,0x78a04b53,0x321005da,0xb4b40316}},	//   dudz, gimv, hazy_, जको_, 
   {{0x321003c6,0x26c400cf,0x00000000,0x00000000}},	//   kazy_, tllo_, --, --, 
   {{0x26c44b54,0x752805b8,0x76484b55,0xdb243345}},	//   ullo_, fudz, gedy, _رومی, 
   {{0xc8a806bb,0x648400c6,0x75284b56,0x26c40005}},	//   _къде_, _fóil, gudz, rllo_, 
   {{0x26c40077,0x78a00393,0x64840332,0x00000000}},	//   sllo_, cimv, _góil, --, 
   {{0x752800e2,0x76480100,0x64940306,0x628c4b57}},	//   audz, bedy, dšit, thbo, 
   {{0x75284b58,0x32100432,0x76480210,0x00000000}},	//   budz, gazy_, cedy, --, 
   {{0xa0681575,0xf1b00451,0x71584b59,0xd6cc1541}},	//   бава_, نءِ_, ортс_, _حقو_, 
   {{0x628c4b5a,0xdfe801c0,0xdfd000ae,0x00000000}},	//   shbo, сдад_, فيز_, --, 
   {{0xe2982c1d,0x1e844b5b,0x32100109,0xd004005b}},	// [4e60] _гап_, плам, bazy_, яете_, 
   {{0x64544b5c,0x78a04b5d,0x64940024,0x648400ae}},	//   _hayi, zimv, ršiu, _móim, 
   {{0x3af0002e,0x1c4406ed,0x78a01992,0x69c40037}},	//   _sàp_, знем, yimv, ühel, 
   {{0x64544b5e,0x787c0129,0x672800e4,0x93100244}},	//   _jayi, _lévr, kuej, _تویش, 
   {{0x64544b5f,0x20104b60,0x64840597,0x75280bd7}},	//   _mayi, mayi_, _nóim, zudz, 
   {{0x64544b61,0x20104b62,0x78a0009a,0x629c03b2}},	//   _layi, layi_, wimv, _jmpo, 
   {{0x76484b63,0x629c4b64,0x648400c6,0x78a04b65}},	//   vedy, _mmpo, _póil, timv, 
   {{0x20104b66,0x64544b67,0x7528004c,0x26d80ba1}},	//   nayi_, _nayi, vudz, ïson_, 
   {{0x629c14dc,0x7528003c,0x6484007b,0x76484b68}},	//   _ompo, wudz, _cóim, tedy, 
   {{0x20104b69,0x64544b6a,0x8b0000bc,0x7a6400cf}},	//   hayi_, _aayi, ářen, _تئرە, 
   {{0x76484b6b,0x47300b8a,0x20104b6c,0x32104b6d}},	//   redy, وریز, kayi_, vazy_, 
   {{0x629c4b6e,0x75281cbd,0x64544b6f,0x20100227}},	//   _ampo, rudz, _cayi, jayi_, 
   {{0x76484b70,0x787c0231,0x75284b71,0x64544b72}},	//   pedy, _févr, sudz, _dayi, 
   {{0x75284b73,0x645400ad,0x2d8001f4,0x00000000}},	//   pudz, _eayi, yyhe_, --, 
   {{0x321033c8,0x6d5800b0,0x4638010f,0x20100205}},	//   razy_, āwak, _לעגע, fayi_, 
   {{0x20104b74,0x64544b75,0x74142050,0x2ec400dc}},	//   gayi_, _gayi, _کوکا, वत्त, 
   {{0x64944b16,0x32100109,0x009401c6,0x4ea400d8}},	// [4e70] ršit, pazy_, хитэ, пржа, 
   {{0x64544b76,0x20100083,0x00000000,0x00000000}},	//   _zayi, aayi_, --, --, 
   {{0x64544b77,0x20104b78,0x70544b79,0x7afc25d8}},	//   _yayi, bayi_, _قندا, _črta, 
   {{0x645447ad,0x76840100,0x20104b7a,0x62e801d9}},	//   _xayi, _bòyk, cayi_, _دِیہ_, 
   {{0xfbd043f6,0x629c4b7b,0x64b002b5,0xfc304b7c}},	//   هته_, _ympo, nāia, احم_, 
   {{0xa9684b7d,0x64940e3c,0x6484007b,0x672801e4}},	//   жика_, nšir, _róim, vuej, 
   {{0xfb3401c0,0xd9fc00af,0x68ec0115,0x00000000}},	//   _үнсэ, _उभरत_, ĉado, --, 
   {{0xa7644b7e,0x996000d7,0x00000000,0x00000000}},	//   дкид, _míňa_, --, --, 
   {{0x64544b7f,0x6d402045,0x64940cf4,0x660400c5}},	//   _rayi, _älab, kšir, _õhkk, 
   {{0x20104b80,0xdac40131,0x64544b81,0xdb24036b}},	//   zayi_, _قېنى_, _sayi, _آولی, 
   {{0x20104b82,0x1fd82d81,0x999c00c0,0x24e8130f}},	//   yayi_, _भण्ड, _datų_, юмни_, 
   {{0x64544b83,0x64840332,0x19b8011a,0x4cc800cc}},	//   _qayi, _tóim, _ומעב, িদকু, 
   {{0x67284b84,0x64544b85,0x20104b86,0x0b300023}},	//   quej, _vayi, vayi_, _ኣኼበኛ, 
   {{0xa5084b87,0x20104b88,0x61444b89,0x3f8c00e2}},	//   _дека_, wayi_, мега, _ādu_, 
   {{0x64544b8a,0x201042ea,0x20544b8b,0x15f8011a}},	//   _tayi, tayi_, мтар, _והצע, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8fa04b8c,0x20104b8d,0x44f00c67,0xe2984b8e}},	// [4e80] вате, rayi_, _hã_, _маи_, 
   {{0x629c4b8f,0x20104b90,0x44f00c67,0x00000000}},	//   _umpo, sayi_, _kã_, --, 
   {{0x44f04b91,0x20104b92,0x00000000,0x00000000}},	//   _jã_, payi_, --, --, 
   {{0x44f04b93,0x20100472,0x9b882f84,0x00000000}},	//   _mã_, qayi_, ينال_, --, 
   {{0x44f04b94,0x6344013f,0x601c0419,0x2bd80118}},	//   _lã_, _wɔnf, rámč, बेला, 
   {{0x1d082c31,0xbc980014,0x395c01bf,0x00000000}},	//   _меги_, _کمرچ_, tvvs_, --, 
   {{0x44f04b95,0x20e800c8,0x7e7c0c8c,0x672c0115}},	//   _nã_, _iĝis_, _iorp, _ĥaja, 
   {{0x64943896,0x6344013f,0x7e7c4b96,0xdee400c2}},	//   zšir, _kɔnd, _horp, _хоҳи, 
   {{0x44f00589,0xab64005f,0x3db00154,0x00000000}},	//   _aã_, _peļņ, _করিল, --, 
   {{0xda644b97,0x44f04b98,0x7e7c0455,0x69640131}},	//   _تاري, _bã_, _jorp, بدۇق, 
   {{0x99844b99,0x44f00ecf,0x6fd4033d,0x999c0064}},	//   _تلاو, _cã_, _दरभं, _vatų_, 
   {{0x7ae8037e,0x44f04b9a,0x7e7c4b9b,0x2874008e}},	//   _hidt, _dã_, _lorp, _пычр, 
   {{0x7e7c4b9c,0x7684007f,0xddcc0034,0x6d5802b5}},	//   _oorp, _lòyi, _jabł, āwai, 
   {{0x44f04b9d,0x81d800bd,0x03200cb4,0x7e7c01f4}},	//   _fã_, িশন_, _बिरह_, _norp, 
   {{0x44f04b9e,0x7ae82759,0xf1c80b8c,0x64b00607}},	//   _gã_, _midt, سورى_, māin, 
   {{0x20e80115,0x76584b9f,0x7afc0219,0x7ae801bf}},	//   _aĝis_, _havy, _črtn, _lidt, 
   {{0x76584ba0,0x44f00c67,0x11e80be2,0x645800b0}},	// [4e90] _kavy, _zã_, _وعدي_, ētit, 
   {{0x51844ba1,0x64b00421,0x7ae8014f,0xb630037e}},	//   _жума, nāin, _nidt, _ｐｖ_, 
   {{0x44f007ae,0x7e7c4ba2,0xc0cc0023,0x00000000}},	//   _xã_, _dorp, ቢሎም_, --, 
   {{0x6ab808dd,0x7e7c4ba3,0x765812ba,0x7ae80076}},	//   ेत्र, _eorp, _lavy, _aidt, 
   {{0x64b004fe,0x7ae80175,0xa038010f,0xdfd000ec}},	//   kāin, _bidt, _צעשפ, _ميٽ_, 
   {{0x7e7c05f5,0x76584ba4,0xae044ba5,0x1ee81077}},	//   _gorp, _navy, _سورى, _روفی_, 
   {{0x7ae82fd9,0xac944ba6,0x66040254,0x00000000}},	//   _didt, _завш, _õhki, --, 
   {{0x44f04ba7,0x7e7c01c4,0x3c2801c0,0xec1400f2}},	//   _rã_, _zorp, _оюун_, _سوئد, 
   {{0x44f04ba8,0x76581446,0xa6e448ae,0xe7a810d9}},	//   _sã_, _bavy, нжил, явил_, 
   {{0xb6cc4ba9,0x44f00c67,0x3db00c58,0x64b00b23}},	//   şünü, _pã_, _কৰিল, gāin, 
   {{0x76580100,0xe56801c0,0x64a40334,0xc0600092}},	//   _davy, чинд_, еана, _መጻህፍ, 
   {{0x44f04b98,0x6d544baa,0x76584bab,0xe79406ed}},	//   _vã_, _msza, _eavy, _пиењ, 
   {{0x44f00ecf,0x64a40116,0xefe40023,0x3db000fe}},	//   _wã_, _җапа, ዝራዊ_, _কৰাল, 
   {{0xf7704bac,0x44f04bad,0x27384bae,0x76584baf}},	//   _خام_, _tã_, mèn_, _gavy, 
   {{0x64a40953,0x27384bb0,0xa0684bb1,0x00000000}},	//   _пака, lèn_, пава_, --, 
   {{0x6458005f,0xc33000d1,0x00000000,0x00000000}},	//   ētis, _پەس_, --, --, 
   {{0x44204bb2,0x6344013f,0x76581446,0x7afc25d8}},	// [4ea0] _idi_, _bɔne, _yavy, _črto, 
   {{0x7e7c4bb3,0x2174059f,0xdee401f0,0x76584831}},	//   _qorp, _зумр, хози, _xavy, 
   {{0x7e7c4bb4,0x44204bb5,0x21a44bb6,0x27384bb7}},	//   _vorp, _kdi_, _чинм, hèn_, 
   {{0x44204bb8,0x6aa00042,0x7e7c01f5,0x7ae8031c}},	//   _jdi_, _amlf, _worp, _sidt, 
   {{0x7e7c4bb9,0x60c4025c,0x27384915,0x8af40150}},	//   _torp, _ikkm, jèn_, еніс_, 
   {{0x4420006c,0x27384bba,0x7ae80477,0x768401e1}},	//   _ldi_, dèn_, _qidt, _tòyi, 
   {{0x44204bbb,0xd8e44bbc,0x7ae81654,0x76584bbd}},	//   _odi_, нцип, _vidt, _ravy, 
   {{0x7ae84bbe,0x44204bbf,0x76584bc0,0x7d1c02d0}},	//   _widt, _ndi_, _savy, _ivrs, 
   {{0x765802d5,0x7ae84bc1,0x27384bc2,0xaac41e4a}},	//   _pavy, _tidt, gèn_, رتۇن, 
   {{0x44204bc3,0x69f00046,0x199403f6,0x00000000}},	//   _adi_, _күшт, _пјер, --, 
   {{0x44204bc4,0x57e80108,0x34940063,0xfba40118}},	//   _bdi_, _едем_, ванр, _खेतम, 
   {{0x765807a8,0x64b00421,0x27384bc5,0x00000000}},	//   _wavy, sāin, bèn_, --, 
   {{0x44204bc6,0x27384bc7,0x76580124,0x92681fbe}},	//   _ddi_, cèn_, _tavy, прва_, 
   {{0x44204bc8,0x7658009f,0x7d1c4bc9,0x850003e6}},	//   _edi_, _uavy, _ovrs, خوێن, 
   {{0xfd4c063f,0x44204bca,0x50644530,0xf1b80022}},	//   reiị, _fdi_, нтаа, ьӡи_, 
   {{0x64940784,0x69d40073,0x997c0055,0x00000000}},	//   qšip, येटी, _ṃśu_, --, 
   {{0x7ff414a5,0x9268010a,0x660c0213,0x00000000}},	// [4eb0] اسفا, _ерна_, _şikə, --, 
   {{0x44201d35,0x00000000,0x00000000,0x00000000}},	//   _zdi_, --, --, --, 
   {{0x44204bcb,0x7d1c0552,0x51844bcc,0x2738033b}},	//   _ydi_, _cvrs, _чупа, zèn_, 
   {{0x27384bcd,0x66040254,0x3cfc03df,0x6720000d}},	//   yèn_, _õhkv, ívva_, _मिलक_, 
   {{0x6fd405f9,0x7d1c0427,0x752800d0,0xcfa801f7}},	//   _दरिं, _evrs, hrdz, _راحم_, 
   {{0xaa444bce,0xe9a84bcf,0xa9a44bd0,0xe9a40bad}},	//   текл, وگان_, килд, калп, 
   {{0x84ec02e5,0x273800f2,0xbdd40138,0x6d54012d}},	//   _घूंट_, wèn_, _борщ, _usza, 
   {{0x27384bd1,0x29e402a8,0xdeec0150,0xb6cc1cce}},	//   tèn_, rɓa_, _اۋە_, şülü, 
   {{0x44204bd2,0x7528068f,0x7d1c0219,0xaa5400f3}},	//   _rdi_, erdz, _zvrs, _иваш, 
   {{0x44204bd3,0x2d84033d,0x7e60013f,0xb7440451}},	//   _sdi_, _üles_, _ɔmpo, ائيو, 
   {{0xe9744bd4,0x44204bd5,0x27384bd6,0x468001ec}},	//   _جهاد, _pdi_, sèn_, _ұқпа, 
   {{0x64a44bd7,0x27384bd8,0xe20807af,0x6ee801a6}},	//   тама, pèn_, वर्ण_, _ožbo, 
   {{0x44204bd9,0x75284bda,0x00000000,0x00000000}},	//   _vdi_, ardz, --, --, 
   {{0x67284bdb,0x63a000a2,0xf40000eb,0x65c401a9}},	//   mrej, _žons, ্লগর_, _ибла, 
   {{0x44204bdc,0x09e0015b,0x67284bdd,0xf6500137}},	//   _tdi_, নুরা, lrej, _دئن_, 
   {{0x44204bde,0x7bdc00df,0x672801e4,0xa4440114}},	//   _udi_, _ŝrum, orej, _рнид, 
   {{0x7d1c0989,0x23dc0490,0x67284bdf,0x22580153}},	// [4ec0] _svrs, नेशद, nrej, _tapk_, 
   {{0xe1f84be0,0x1d084be1,0x67280115,0x00000000}},	//   _юго_, дежи_, irej, --, 
   {{0x67284be2,0xe0d815ed,0x60244be3,0x6604000d}},	//   hrej, _ово_, _идна, _õhku, 
   {{0xad240efc,0x6f1c003a,0x00000000,0x00000000}},	//   ارلو, _fvsc, --, --, 
   {{0xda780276,0x9b940131,0x03e4015b,0x672801e4}},	//   дяй_, خشاش, কুরী_, jrej, 
   {{0xba18157c,0x249003cb,0x09e005ac,0x6abc03b2}},	//   ريبا_, _llym_, _ন্ধা, _ísfl, 
   {{0x7d1c1a48,0x67284be4,0xdd9000d1,0x00000000}},	//   _uvrs, erej, _ئوز_, --, 
   {{0xc9804705,0x67284be5,0x75280cf4,0xc8600b87}},	//   руши, frej, vrdz, атьи, 
   {{0x67284be6,0xb6cc1b0d,0x2d840139,0xfa3400e5}},	//   grej, şümü, _üler_, _مذاھ, 
   {{0x752801fa,0x249000ee,0x09c40011,0x00000000}},	//   trdz, _alym_, ষেধা, --, 
   {{0xc0604be7,0x69340118,0x672801f4,0x00000000}},	//   _መጻሕፍ, třeš, arej, --, 
   {{0x61fc4be8,0xd7c40107,0x00000000,0x00000000}},	//   _afpl, _иёло, --, --, 
   {{0xd7740137,0x00000000,0x00000000,0x00000000}},	//   _جااع, --, --, --, 
   {{0xc7d40375,0x46a000a7,0xd56400f3,0x00000000}},	//   _סוגי_, _качв, _атип, --, 
   {{0x96900214,0x27fc0142,0x03e400fe,0x00000000}},	//   _میکش, _yfwn_, কুলী_, --, 
   {{0x6484007b,0xefe40023,0x00000000,0x00000000}},	//   _sóiv, ዝያዊ_, --, --, 
   {{0x7968013f,0x21281554,0x4fc40064,0x00000000}},	// [4ed0] rɛwy, arbh_, тсва, --, 
   {{0x6fb401ec,0x32540cc9,0x63a0010e,0x00000000}},	//   _ەمحا, _свор, _ýona, --, 
   {{0x67284be9,0x24900209,0x1ee800e5,0xf004014b}},	//   zrej, _ylym_, رومی_, _бӯзи, 
   {{0x672800b5,0xf8dc033f,0x00000000,0x00000000}},	//   yrej, मगोप, --, --, 
   {{0xa09800c8,0xab284bea,0x00000000,0x00000000}},	//   _נישט, хола_, --, --, 
   {{0x67284beb,0xeab84bec,0xca6002dd,0x00000000}},	//   vrej, эйл_, рекқ, --, 
   {{0xa3a80254,0xc27c00d9,0x4c800101,0xf41800cc}},	//   _गेन_, ורגי, _پیشق, _থানৰ_, 
   {{0x67284bed,0xc1740302,0x5a300139,0xa3dc00bc}},	//   trej, שחק_, анәт, थेँ_, 
   {{0x6484007b,0x67284bee,0x98bc00ef,0x00000000}},	//   _móit, urej, _astē_, --, 
   {{0x67284bef,0x24904bf0,0x00000000,0x00000000}},	//   rrej, _slym_, --, --, 
   {{0x6728037e,0x7fd00118,0x00000000,0x00000000}},	//   srej, _दर्ु, --, --, 
   {{0x67284bf1,0xbb58037e,0x23280117,0x2408010b}},	//   prej, _cのwi, номи_, энми_, 
   {{0xf7702834,0xa3dc202e,0xe6440153,0x7c980092}},	//   _واه_, थें_, _белп, _ጀምሯል_, 
   {{0x71400240,0x00000000,0x00000000,0x00000000}},	//   _ኣካላቶ, --, --, --, 
   {{0x26c44bf2,0x00e44bf3,0x602405f5,0x6484007b}},	//   molo_, لتری, лдва, _bóit, 
   {{0x26c44bf4,0x64840332,0xe45800db,0x9f9003b2}},	//   lolo_, _cóit, _чжи_, føða_, 
   {{0x64840597,0x1f640c98,0xa23401e0,0x6604000d}},	// [4ee0] _dóit, ыкам, _йэнш, _õhks, 
   {{0x26c42ee9,0xd12c01ed,0x35a805b3,0x6ee80153}},	//   nolo_, تمہ_, _छेड़, _užbl, 
   {{0x26c40395,0xc1940244,0x0d2000db,0x00000000}},	//   iolo_, _ئیزع, йүрү, --, 
   {{0x20544bf5,0x26c44bf6,0x628c4bf7,0x9c584bf8}},	//   _стор, holo_, lkbo, عجاز_, 
   {{0x26c44bf9,0xa3a810dc,0xd434011a,0x00000000}},	//   kolo_, _गेम_, רטני_, --, 
   {{0x6d5804fe,0x628c4bfa,0x26c400d8,0xcc30035b}},	//   āwar, nkbo, jolo_, ахәы, 
   {{0x98c402a9,0xd9440592,0x2d84013d,0x00000000}},	//   лсил, ائتي, _ülep_, --, 
   {{0x6b8c00e5,0xe9700e56,0x00000000,0x00000000}},	//   öngé, تۇمد, --, --, 
   {{0x26c44bfb,0x648400c6,0x628c143a,0x4a700014}},	//   folo_, _lóis, kkbo, _گُلر, 
   {{0x26c44bfc,0x0f54025f,0x1ae44bfd,0x628c01f5}},	//   golo_, ניים_, _созм, jkbo, 
   {{0x64840332,0x998408de,0x00000000,0x00000000}},	//   _nóis, _حلاو, --, --, 
   {{0x628c4bfe,0x699401ca,0x00000000,0x00000000}},	//   ekbo, _трух, --, --, 
   {{0x26c44bff,0x788401d9,0xc3480108,0xd36c215c}},	//   bolo_, _مێژِ_, ляре_, سۇد_, 
   {{0x26c40c04,0x5378044e,0x394c0790,0x9f9003b2}},	//   colo_, _ክኸይድ_, _kpds_, vøða_, 
   {{0x349400c2,0x648400ae,0x999c0142,0x00000000}},	//   _вайр, _cóis, _tatŵ_, --, 
   {{0x6344016b,0xbdf80131,0x628c017a,0xf48401d5}},	//   _wɔna, ۇرما_, akbo, _خاتی, 
   {{0xfba4012c,0x00000000,0x00000000,0x00000000}},	// [4ef0] _खेलम, --, --, --, 
   {{0x628c4c00,0xc7d40302,0x12c008b0,0x701403d4}},	//   ckbo, רומי_, ﺮﻟﻪﺭ, িলেও_, 
   {{0xed501c3e,0x00000000,0x00000000,0x00000000}},	//   تپا_, --, --, --, 
   {{0x26c44c01,0xfd104c02,0x3078010f,0x00000000}},	//   zolo_, سجم_, _סאָנ, --, 
   {{0x26c44c03,0xbc3804fb,0x7d04054e,0x00000000}},	//   yolo_, اسما_, vîrş, --, 
   {{0x26c44242,0x64b002b5,0x6e9400db,0x0dc84c04}},	//   xolo_, tāik, _тигу, _зуби_, 
   {{0x26c44c05,0x648400ae,0x00000000,0x00000000}},	//   volo_, _móir, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x394c0fac,0xada401ec,0x0a6800f0,0x66d8011c}},	//   _epds_, _саңл, _пржи_, кьор_, 
   {{0x6344013f,0x2b4c00d2,0x26c4011c,0x69c41dfe}},	//   _bɔnn, _ipec_, uolo_, ühes, 
   {{0x26c44c06,0xc9d00214,0xe89400c7,0x7afc0427}},	//   rolo_, _اماک, _кажь, _črti, 
   {{0x26c44c07,0xe3640f14,0x2904031c,0x66741f70}},	//   solo_, акми, _itla_, ادکر, 
   {{0x26c44c08,0x648400ae,0x7c24007b,0x02c80107}},	//   polo_, _sóis, óiri, лқии_, 
   {{0x64840597,0x26c42c60,0x649415ad,0x00000000}},	//   _cóir, qolo_, nšiz, --, 
   {{0x628c4c09,0x648400ae,0x00000000,0x00000000}},	//   rkbo, _dóir, --, --, 
   {{0x3d1c01e1,0x3d0c01e1,0x0cbc00bc,0x628c007c}},	//   _láwá_, _lòwò_, एकोम, skbo, 
   {{0x6484007b,0xaad40118,0x00000000,0x00000000}},	// [4f00] _fóir, धताक, --, --, 
   {{0x29044c0a,0x6344013f,0x5d684c0b,0x9d44005b}},	//   _otla_, _hɔno, кизм_, иезд, 
   {{0x1278008f,0x66dc007f,0x64440009,0x00000000}},	//   _סאטע, mèkd, ofki, --, 
   {{0x28d401ad,0x91b800d9,0x00000000,0x00000000}},	//   _डीलि, _ימיי, --, --, 
   {{0x64b000b0,0x5f740131,0xdd7001d3,0x00000000}},	//   rāih, _ئاجر, _ڈھاک, --, 
   {{0xcb0400ec,0x394c0332,0x00000000,0x00000000}},	//   جيون_, _ppds_, --, --, 
   {{0x29040204,0x5ebc03d4,0x13d000bc,0x9aa82374}},	//   _ctla_, ্গদে, _सर्भ, ىنچە_, 
   {{0x660c0051,0x00000000,0x00000000,0x00000000}},	//   _đaka, --, --, --, 
   {{0xd6d83993,0x29044c0c,0x69c403fa,0x3d1c01e1}},	//   кто_, _etla_, üher, _fáwá_, 
   {{0x3cf83986,0x64440549,0xd90c030f,0x00000000}},	//   _kurv_, efki, _قیت_, --, 
   {{0x29040421,0xab5c033f,0x00000000,0x00000000}},	//   _gtla_, _dyżu, --, --, 
   {{0xd7e402bf,0x648401e7,0x23880153,0xda00012d}},	//   _кіло, _sóir, kėją_, रुरत_, 
   {{0x63440134,0x648401e7,0xb6300092,0xb6c4004e}},	//   _wɔnn, _póir, _ተጠይቀ, _гөнд, 
   {{0x64440009,0x23880153,0x66040254,0x48f8000d}},	//   afki, dėją_, _õhkp, _लूडो_, 
   {{0x05804c0d,0x6fd807f7,0xc00c0051,0xd498022e}},	//   _муъм, _मरहू, _ývới_, _арп_, 
   {{0x92d404c5,0xdf540032,0xf4844c0e,0xd3a4119e}},	//   িদে_, өнсө, _چاکی, _вроп, 
   {{0x3ef80262,0xeeb801b9,0xa3bc1d68,0x648400ae}},	// [4f10] интэ_, глаш_, _आशय_, _tóir, 
   {{0x6e1800cf,0x00000000,0x00000000,0x00000000}},	//   اياس_, --, --, --, 
   {{0x2b4c1a7b,0xe2a403b2,0x6d100073,0x6abc1d1d}},	//   _spec_, _íðan_, डींग_, _ísfi, 
   {{0x6b7402dd,0x23880064,0x00000000,0x00000000}},	//   йлеу, bėją_, --, --, 
   {{0x6b644c0f,0x13a800cc,0x00000000,0x00000000}},	//   скла, _গঁড়, --, --, 
   {{0x8d8400db,0x00000000,0x00000000,0x00000000}},	//   _кубд, --, --, --, 
   {{0x66dc0066,0x3cf800b8,0x00000000,0x00000000}},	//   nèke, _gurv_, --, --, 
   {{0x7c3428e5,0xe73800c7,0x00000000,0x00000000}},	//   _месх, геи_, --, --, 
   {{0xd70400c9,0xe6440150,0x00000000,0x00000000}},	//   бные_, бепп, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x644400d2,0x29040158,0x29d40046,0x5ae400db}},	//   tfki, _utla_, _اياس, _اقلە, 
   {{0x64840597,0x64440009,0x9ac0031c,0x00000000}},	//   _cóip, ufki, ċċen, --, 
   {{0x26d80228,0x6444002f,0x00000000,0x00000000}},	//   ïsos_, rfki, --, --, 
   {{0x6344013f,0xe6182081,0x61f8022e,0x00000000}},	//   _wɔno, _сдк_, оtla, --, 
   {{0x64444c10,0x00000000,0x00000000,0x00000000}},	//   pfki, --, --, --, 
   {{0x10a011e5,0xfd782832,0x00000000,0x00000000}},	//   писн, یشاں_, --, --, 
   {{0x8500009f,0x701803de,0x00000000,0x00000000}},	// [4f20] _اوڊن, ріст_, --, --, 
   {{0x23880153,0xe7e800cd,0x00000000,0x00000000}},	//   rėją_, ञेया_, --, --, 
   {{0xe9c400e5,0x00000000,0x00000000,0x00000000}},	//   _آں_, --, --, --, 
   {{0x6ca4003b,0x00000000,0x00000000,0x00000000}},	//   оріж, --, --, --, 
   {{0xdfd04c11,0x38c84c12,0xfa840107,0x00000000}},	//   _ريس_, یابی_, оқам, --, 
   {{0x5e9408de,0xc9c40133,0x00000000,0x00000000}},	//   _السط, ڕژنه_, --, --, 
   {{0xd7f84c13,0xdd144c14,0x00000000,0x00000000}},	//   луп_, _دوزخ, --, --, 
   {{0x49500075,0x7f444c15,0x9cb42586,0xcd400014}},	//   سخىس, otiq, _امرت, _ژھۆٹ, 
   {{0x7f444c16,0xdd944c17,0x75d40451,0x00000000}},	//   ntiq, _таңы, ڪيدا, --, 
   {{0x80c4000d,0x4b8400db,0x00000000,0x00000000}},	//   वकुं, _уйун_, --, --, 
   {{0x98480801,0x39584c18,0x74140b6c,0x98a40fbe}},	//   _бяла_, _èrs_, يودا, _лиже, 
   {{0xfbdc4c19,0x169401d9,0x7f444c1a,0x00000000}},	//   _बराम, _گٕتھ_, ktiq, --, 
   {{0xb4e80490,0x66d001a9,0x00000000,0x00000000}},	//   _बळी_, _tаkо, --, --, 
   {{0xc51043fb,0x00000000,0x00000000,0x00000000}},	//   _کبوت, --, --, --, 
   {{0xc690010f,0x55044c1b,0x00000000,0x00000000}},	//   _מאס_, _учла, --, --, 
   {{0x6d40014a,0x05800563,0x213c00a3,0x00000000}},	//   _älai, _хушм, àtha_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [4f30] --, --, --, --, 
   {{0x43d44c1c,0x00000000,0x00000000,0x00000000}},	//   _عزيز, --, --, --, 
   {{0x7f4420ef,0x714000f7,0x09a4000d,0x00000000}},	//   atiq, _تۉزۅ, _केंठ, --, 
   {{0x8c34016c,0x237000a2,0x847c0023,0x00000000}},	//   содӣ_, _ünjä_, _ብቛንቋ_, --, 
   {{0xa03804ac,0x7f444c1d,0x05cc4c1e,0x0fe0009d}},	//   _דערפ, ctiq, _सुनब, _хөвү, 
   {{0x660c1b24,0x64b00421,0xf1bc01bc,0x1c0832ed}},	//   _đako, lāit, _ईशान, हुबल_, 
   {{0x6f0c4c1f,0x7bc00789,0xac941bbc,0x00000000}},	//   lpac, _exmu, _давш, --, 
   {{0x6d444c20,0xa3a84c21,0x48c4015b,0x7c240332}},	//   mtha, _गइल_, শগ্র, óirt, 
   {{0x6d444c22,0x6f0c4c23,0x00000000,0x00000000}},	//   ltha, npac, --, --, 
   {{0xda001533,0x6d444c24,0x6f0c4c25,0xab5c0034}},	//   रुआत_, otha, ipac, _wyżs, 
   {{0x6d444c26,0x6f0c0455,0xe450007b,0x00000000}},	//   ntha, hpac, وضح_, --, 
   {{0x6d440cfd,0x6f0c0bc9,0xa7740e91,0xa3e81a92}},	//   itha, kpac, _млеч, идна_, 
   {{0x6f0c4c27,0x6d444c28,0x057401d9,0xa3a80037}},	//   jpac, htha, _گاشد, _गइळ_, 
   {{0x6d444c29,0x00000000,0x00000000,0x00000000}},	//   ktha, --, --, --, 
   {{0xc0bc044e,0x6d4401d3,0x6f0c1eff,0x00000000}},	//   _ሶማል_, jtha, epac, --, 
   {{0x6d440c8c,0x6f0c4c2a,0x7f442646,0xa034198a}},	//   dtha, fpac, ttiq, تىرت, 
   {{0x7f444c2b,0x6d440cfd,0x1e844c2c,0x93104c2d}},	// [4f40] utiq, etha, олам, _قويش, 
   {{0x6d444c2e,0x7f444c2f,0x69c04c30,0x6ee801a6}},	//   ftha, rtiq, _oxle, _ožbu, 
   {{0x7f444c31,0x6d444c32,0x93c82832,0x6f0c078c}},	//   stiq, gtha, _مایہ_, apac, 
   {{0x7f444c33,0xa0684c34,0x00000000,0x00000000}},	//   ptiq, _тама_, --, --, 
   {{0x6d444c35,0xdee406bb,0x69c04c36,0x20100230}},	//   atha, _моми, _axle, mbyi_, 
   {{0x6d444c37,0x60d44c38,0x00000000,0x00000000}},	//   btha, llym, --, --, 
   {{0x6d444c39,0xdd904c3a,0x60d40108,0x7c2401e7}},	//   ctha, _غور_, olym, óirs, 
   {{0x60d40857,0x00000000,0x00000000,0x00000000}},	//   nlym, --, --, --, 
   {{0xa3a8033d,0x69c0003a,0x7b840150,0xc6f40024}},	//   _गेल_, _exle, _عارە, оных_, 
   {{0xd6d8041b,0x00000000,0x00000000,0x00000000}},	//   јти_, --, --, --, 
   {{0x6f0c0210,0x60d448a2,0x00000000,0x00000000}},	//   zpac, klym, --, --, 
   {{0x6f0c4c3b,0xc87c0e78,0x00000000,0x00000000}},	//   ypac, ößt_, --, --, 
   {{0x6f0c4c3c,0xbbb84c3d,0xd6d801ec,0x60d44c3e}},	//   xpac, _अशोक, _ктк_, dlym, 
   {{0x6d444c3f,0x96a40490,0x60d40076,0x00000000}},	//   ytha, टोशॉ, elym, --, 
   {{0xfbd00729,0x349405c1,0x63440134,0x60d40368}},	//   িধিত, _накр, _yɔnk, flym, 
   {{0x6f0c0bc9,0x6d4401d4,0x66dc0066,0x92a80154}},	//   tpac, vtha, mèka, গকে_, 
   {{0xbd000521,0x98bc0055,0xf004013e,0x66dc04fb}},	// [4f50] _ịkpọ, _astī_, жӯҳи, lèka, 
   {{0x6f0c4c40,0x80dc03d4,0x53a4001f,0xd13800d8}},	//   rpac, _মূদ্, ወያየት_, _кхм_, 
   {{0x6f0c4c41,0x6d444c42,0x66dc00f2,0x60d44c43}},	//   spac, utha, nèka, blym, 
   {{0x6d444c44,0x6f0c4c45,0x660c05be,0x60d40810}},	//   rtha, ppac, _đakm, clym, 
   {{0x6d444c46,0x6f0c094a,0x6e940014,0x66dc0214}},	//   stha, qpac, _فلحا, hèka, 
   {{0x6d444c47,0x6344013f,0xda600251,0x66dc0066}},	//   ptha, _dɔnh, евши, kèka, 
   {{0x4a700046,0x7d24084c,0x66dc00f2,0x00000000}},	//   зықт, _офте, jèka, --, 
   {{0x66dc04fb,0x7c94104c,0xc1bc011a,0x9ac0025c}},	//   dèka, _قشقا, ימוש, ċċan, 
   {{0xe73000c6,0x2cac4c48,0xd704005b,0x00000000}},	//   رصة_, _imed_, пные_, --, 
   {{0x63440134,0x78c401f2,0xe80c000d,0x00000000}},	//   _wɔnk, ịkpọ_, _सभवा_, --, 
   {{0x66dc0066,0x04200154,0x6ee80153,0x00000000}},	//   gèka, _ভাবী_, _užbu, --, 
   {{0x64984c49,0x2a644c4a,0x6d400793,0xb8d4036b}},	//   стор_, _halb_, _älau, _قتنش, 
   {{0x68e84c4b,0x2a644c4c,0xdc340677,0x00000000}},	//   mmed, _kalb_, הארט_, --, 
   {{0x68e84c4d,0x0b1c069c,0x2a6407d6,0x461004d3}},	//   lmed, _ስደተኛ, _jalb_, _کوژر, 
   {{0x66dc0066,0xdbd40162,0x5500033f,0x68e84c4e}},	//   cèka, _løði, _रूपए_, omed, 
   {{0x68e84c4f,0xe0d84c50,0x7ea04c51,0x4304013d}},	//   nmed, ёва_, _köpg, _оҗма, 
   {{0x10a04c52,0x09ac02f5,0x68e84c53,0x60d41bef}},	// [4f60] хитн, _চুমা, imed, rlym, 
   {{0x68e84c54,0x0e604c55,0x03a4023b,0x60d44c56}},	//   hmed, нкун, _ниқо, slym, 
   {{0x60d402fa,0x71000588,0x68e84c57,0x46a000af}},	//   plym, _аҧса, kmed, _ओतनह, 
   {{0x68e84c58,0xe928031c,0xdbd403b2,0x00000000}},	//   jmed, _ལྷེབ_, _bøði, --, 
   {{0x2a64045a,0x00000000,0x00000000,0x00000000}},	//   _balb_, --, --, --, 
   {{0x68e84c59,0x2cac003e,0x2a64004e,0xd9183cc5}},	//   emed, _emed_, _calb_, бьи_, 
   {{0x63440134,0xceb000c8,0xc0c802d3,0x00000000}},	//   _wɔnh, _טיש_, ጽጻር_, --, 
   {{0x68e84c5a,0xdbd4022c,0xf52c02d3,0x6f0c0066}},	//   gmed, _føði, _ተሰማሚ, _èncè, 
   {{0x3f800077,0xd7f80032,0x66dc00f2,0xb6f800d1}},	//   nxiu_, _һул_, wèka, غىدا_, 
   {{0x3f80004e,0x66dc0214,0x9538001f,0xb594014b}},	//   ixiu_, tèka, _በተከሰ, диош, 
   {{0x1dbc085c,0x68e801f1,0xd7f8084c,0x7ea00e78}},	//   ्थित, bmed, _лул_, _töpf, 
   {{0x938807d6,0x74140150,0xd498013e,0x66dc0214}},	//   бсга_, بوحا, сро_, rèka, 
   {{0xb4bc28a2,0x64b002b5,0x66dc0214,0x7ea0010b}},	//   _आदी_, tāir, sèka, _köpd, 
   {{0x1dbc4c5b,0x66dc04fb,0x6d4008fb,0x35b40212}},	//   ्थात, pèka, _ålag, _облр, 
   {{0xf0e8185e,0x64b000b0,0xf8b00d79,0x9028009d}},	//   قىسى_, rāir, _जगाय, йцаа_, 
   {{0x66dc020c,0x73340137,0x3a2c0064,0x00000000}},	//   nèkn, _قىبا, _lddp_, --, 
   {{0x2ef40229,0x00000000,0x00000000,0x00000000}},	// [4f70] дзар, --, --, --, 
   {{0x68e84c5c,0x2cac4c5d,0xdbd406ea,0x7ed400d1}},	//   zmed, _smed_, _røði, ىزلا, 
   {{0x68e84c5e,0xa2d40210,0xf8cc1408,0x00000000}},	//   ymed, _मीट्, ावाय, --, 
   {{0x2a64022e,0xa0600023,0xb3e000bc,0x00000000}},	//   _salb_, _ወጻኢታ, _नराख, --, 
   {{0xddcc0209,0x68e8274e,0x66dc020c,0x64b002b1}},	//   _tabş, vmed, dèkn, iāip, 
   {{0x9f944c5f,0x2a644c60,0xe928025c,0x7c3401c0}},	//   _חדשה_, _qalb_, _ལྷུབ_, _үерх, 
   {{0x68e84c61,0x224c0790,0x87cc0116,0x00000000}},	//   tmed, _öfke_, _ﮔﻪﭘﻠ, --, 
   {{0x2cac4c62,0x6d54035a,0x00000000,0x00000000}},	//   _umed_, _ipza, --, --, 
   {{0xa6e401c0,0x2a640003,0x7b1800f3,0x00000000}},	//   мжил, _talb_, _нотр_, --, 
   {{0x26d0006a,0x00000000,0x00000000,0x00000000}},	//   ôzo_, --, --, --, 
   {{0x68e84c63,0xe5a44c64,0x2d80036e,0x00000000}},	//   pmed, фини, nxhe_, --, 
   {{0x66dc020c,0xe35401c6,0x00000000,0x00000000}},	//   cèkn, мтгэ, --, --, 
   {{0x3ae00ba1,0x7ea001f4,0xe64404b3,0x737400c7}},	//   lòpa_, _höpe, _желп, нырх, 
   {{0x7ea04c65,0x6d5401f5,0xe164009a,0x00000000}},	//   _köpe, _opza, ودزي, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe0d83981,0x00000000,0x00000000,0x00000000}},	//   іва_, --, --, --, 
   {{0x44204c66,0x7ea001e6,0x6d5400e2,0xd6e00210}},	// [4f80] _iei_, _löpe, _apza, bułę_, 
   {{0x44204c67,0x3f800077,0x00000000,0x00000000}},	//   _hei_, rxiu_, --, --, 
   {{0x44204c68,0x629c4c69,0xa0a44c6a,0x1c444c6b}},	//   _kei_, _ilpo, _жанд, днем, 
   {{0x44200953,0xa3d04540,0x80dc0eac,0x00000000}},	//   _jei_, _वडा_, _মূর্, --, 
   {{0x44204c6c,0x629c05b1,0x00000000,0x00000000}},	//   _mei_, _klpo, --, --, 
   {{0x44204c6d,0x7124104a,0x63a0010e,0x00000000}},	//   _lei_, _تریل, _ýonu, --, 
   {{0x442001a4,0x3ce4037e,0x66dc4c6e,0x3de80327}},	//   _oei_, _thmv_, tèkn, _འཛིན, 
   {{0x44204c6f,0x629c0421,0x46a8202e,0x7ea0007c}},	//   _nei_, _llpo, टोसह, _döpe, 
   {{0xb6f44c70,0x629c4c71,0x1dbc00cd,0x00000000}},	//   нзиј, _olpo, ्थवत, --, 
   {{0x44204c72,0x7c204c73,0x66dc020c,0x00000000}},	//   _aei_, _hemr, sèkn, --, 
   {{0x44204c74,0x7c2014af,0xce340375,0x66dc020c}},	//   _bei_, _kemr, ואית_, pèkn, 
   {{0x44204c75,0x629c4c76,0x7c2000a2,0x94a8187f}},	//   _cei_, _alpo, _jemr, ітна_, 
   {{0x44204c77,0xd7e010fa,0x7c204c78,0x92684c79}},	//   _dei_, _परिच, _memr, орва_, 
   {{0x7ea001e3,0x00000000,0x00000000,0x00000000}},	//   _löpb, --, --, --, 
   {{0x44204c7a,0xd4c4390e,0x629c0334,0xd4d8007b}},	//   _fei_, _осип, _dlpo, _وبعض_, 
   {{0x44204c7b,0x629c4c7c,0x7c204c7d,0x660c107d}},	//   _gei_, _elpo, _nemr, _đaki, 
   {{0x80a007d0,0x00000000,0x00000000,0x00000000}},	// [4f90] _ऐतरे, --, --, --, 
   {{0x44200936,0x2d800564,0x7d1c015d,0xfeb80014}},	//   _zei_, txhe_, _bwrs, ٘امت_, 
   {{0x7528005f,0x7d1c0142,0x44204c7e,0x424400c7}},	//   nsdz, _cwrs, _yei_, _рхыб, 
   {{0x8b6800da,0x4420003a,0x2d800240,0xd6c403e6}},	//   ņēmē, _xei_, rxhe_, _ڕق_, 
   {{0xcf240451,0x511c007d,0x628c05a1,0x00000000}},	//   _ترجي, _बबुआ_, žnoš, --, 
   {{0x7ea00793,0x7d1c0042,0xfaa801e2,0x00000000}},	//   _pöpe, _fwrs, وهني_, --, 
   {{0x7c20044e,0xac1809f7,0x6b980724,0x6e2400d5}},	//   _femr, _нову_, _şagı, mahb, 
   {{0xa7644c7f,0x3ae02508,0x7c204c80,0x6e240978}},	//   екид, ròpa_, _gemr, lahb, 
   {{0x6b740166,0x921c04af,0x00000000,0x00000000}},	//   _ялау, भराज_, --, --, 
   {{0x44204c81,0x39640664,0x7c20044e,0xe6100597}},	//   _sei_, ässä_, _zemr, دشة_, 
   {{0x44204c82,0xe2a40162,0xa8141b0a,0xf52c0023}},	//   _pei_, _íðin_, _здеш, _ተደማሚ, 
   {{0x64c84c83,0x44200286,0x7ea00267,0x6f1c035a}},	//   रवेश, _qei_, _köpc, _owsc, 
   {{0x4420493b,0xf7700a81,0xe3b04c84,0x33d400d4}},	//   _vei_, _پان_, ارج_, вірт, 
   {{0x44204c85,0x6e244c86,0xe2984c87,0xe64400cf}},	//   _wei_, jahb, чаг_, _чекп, 
   {{0x67284c88,0x44204c89,0x6f1c03ac,0x6e24020c}},	//   lsej, _tei_, _awsc, dahb, 
   {{0x44204c8a,0x9e644c8b,0x672834e1,0x00000000}},	//   _uei_, کارن, osej, --, 
   {{0x672844d5,0x8fa04c8c,0x68f8047e,0x73640022}},	// [4fa0] nsej, гате, _miwd, _аныҕ, 
   {{0x7c204c8d,0x6e240198,0x2fd8015d,0x672801f4}},	//   _semr, gahb, _dysg_, isej, 
   {{0x20041709,0x7c20487c,0x6f1c035a,0xe0d8119e}},	//   ñois_, _pemr, _ewsc, _нво_, 
   {{0x67284c8e,0x996000bc,0xa0a401c6,0xdd1c01ef}},	//   ksej, tíže_, _чамд, _tíže, 
   {{0x672800d0,0x7c20007c,0x4e1c00fe,0x00000000}},	//   jsej, _vemr, _পাৰ্_, --, 
   {{0x6e244c8f,0x672800b5,0xef10008f,0xcc140137}},	//   cahb, dsej, _כּל_, _үчтө, 
   {{0x61540092,0x00000000,0x00000000,0x00000000}},	//   _ምግቦች, --, --, --, 
   {{0x271c02e2,0xac3800f3,0x48a401f4,0x00000000}},	//   fňn_, _очух_, етьм_, --, 
   {{0xb8e808e9,0x67284c90,0xb4bc00cd,0x1fdc012d}},	//   _ईद_, gsej, _आदौ_, _मरोड, 
   {{0x667004a9,0x95c83246,0x0420009e,0xabc401af}},	//   لگىر, зума_, _ভাষী_, _рауҙ, 
   {{0x439446ee,0x672801f4,0x00000000,0x00000000}},	//   қарс, asej, --, --, 
   {{0x63a00210,0x00000000,0x00000000,0x00000000}},	//   _żona, --, --, --, 
   {{0x087400c8,0x6e240ac5,0x672800cf,0x4790431a}},	//   _רעדט_, yahb, csej, _مجوس, 
   {{0x877800c8,0x15b00075,0x65600042,0xaa800432}},	//   _מאדי, _مەخس, bwlh, _öýtd, 
   {{0x05703b5f,0xd1b81b06,0x04200154,0x66700133}},	//   _مايد, ساسا_, _ভারী_, _ڵگیر, 
   {{0x06800124,0x2fd80142,0x6e240455,0x70bc013a}},	//   _агән, _pysg_, wahb, ्केल, 
   {{0x6e24047e,0x00000000,0x00000000,0x00000000}},	// [4fb0] tahb, --, --, --, 
   {{0xa3a8375c,0x7c2408a7,0x1bf41428,0x51844c91}},	//   _गेट_, ðirn, ेशनल_, _зума, 
   {{0xeab019d2,0x6344016b,0x81d8015b,0x6e2415b7}},	//   یعت_, _wɔnt, ়েব_, rahb, 
   {{0x7c8407d8,0x4ba40137,0x70940166,0x6e24016d}},	//   луче, нөзү_, _рамф, sahb, 
   {{0xaa444c92,0xdfd005d9,0x66dc020c,0x6b64022e}},	//   велл, _نيٽ_, wèkm, ткла, 
   {{0x9b9004a9,0x27fc0042,0x6e240455,0xba2800d1}},	//   شلىت, _sgwn_, qahb, ىسىم_, 
   {{0x68f80477,0xba28007b,0x30c400cc,0xd9400395}},	//   _piwd, رسوم_, ্ষীস, аещи, 
   {{0x67284c93,0xc1740375,0x783800c7,0x00000000}},	//   tsej, רחק_, нџьт_, --, 
   {{0x6728007f,0x00000000,0x00000000,0x00000000}},	//   usej, --, --, --, 
   {{0xd6cc4c94,0x7ea001e6,0x68f80142,0xe80c00c5}},	//   يقي_, _köpa, _wiwd, _सभका_, 
   {{0x67284bef,0x64a44c95,0x66dc020c,0x6aa04c96}},	//   ssej, вана, lèkk, _illf, 
   {{0x23280364,0x660c009b,0x67284c97,0x70bc1bd6}},	//   моми_, _đaku, psej, ्कोल, 
   {{0x7ea04c98,0x61fc0175,0x6728025c,0xe8dc01f9}},	//   _löpa, _pgpl, qsej, मतीच, 
   {{0xbb58037e,0x00000000,0x00000000,0x00000000}},	//   sのgm, --, --, --, 
   {{0xd6d400cf,0x00000000,0x00000000,0x00000000}},	//   _جووش_, --, --, --, 
   {{0x603c0356,0x83300055,0x00000000,0x00000000}},	//   dămâ, _ṛtuś, --, --, 
   {{0x64544c99,0x6aa001e7,0x00000000,0x00000000}},	// [4fc0] _ibyi, _ollf, --, --, 
   {{0x6344013f,0x61fc0857,0x95204c9a,0x00000000}},	//   _wɔns, _ugpl, _حکیم, --, 
   {{0x5dd8059f,0x603c0356,0x7c2403b2,0x00000000}},	//   ффар_, gămâ, ðiro, --, 
   {{0x7ea00428,0x6aa04c9b,0xdb58117e,0x00000000}},	//   _döpa, _allf, дюк_, --, 
   {{0x64544c9c,0xbb5400ae,0x00000000,0x00000000}},	//   _mbyi, انتب, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x98c44c9d,0x603c0356,0x00000000,0x00000000}},	//   ксил, cămâ, --, --, 
   {{0x6aa0035a,0xadb400db,0xaac400d1,0x00000000}},	//   _ellf, _حۇما_, پتۇن, --, 
   {{0x660c05d1,0x00000000,0x00000000,0x00000000}},	//   _şaka, --, --, --, 
   {{0xda640046,0x64540230,0x7ea00108,0x00000000}},	//   _جاري, _abyi, _yöpa, --, 
   {{0xceb0025f,0x25a80198,0x99844c9e,0xd90c0133}},	//   שית_, _ƙala_, _جلاو, _بیب_, 
   {{0xf31401c0,0xb5fc0327,0x00000000,0x00000000}},	//   лдмэ, deġe, --, --, 
   {{0x332c00e8,0x603c0356,0x07a002e8,0xc3480139}},	//   éex_, zămâ, _кацн, кяре_, 
   {{0x64540796,0xe3c40295,0x70bc4c9f,0x00000000}},	//   _ebyi, ùñab_, ्क्ल, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc0f8001f,0x7c2403b2,0x00000000,0x00000000}},	//   _ፈጽሞ_, ðirl, --, --, 
   {{0x0fe000f7,0x00000000,0x00000000,0x00000000}},	// [4fd0] рөнү, --, --, --, 
   {{0x7ea001b8,0x00000000,0x00000000,0x00000000}},	//   _pöpa, --, --, --, 
   {{0xf1944ca0,0xc6240eac,0x518436dd,0x41540064}},	//   _синь, _মামা_, _рупа, _квэс, 
   {{0x603c0311,0x90400133,0x00000000,0x00000000}},	//   rămâ, _خۆره, --, --, 
   {{0x603c0356,0xfc640395,0x00000000,0x00000000}},	//   sămâ, ръхн, --, --, 
   {{0x603c0356,0x00000000,0x00000000,0x00000000}},	//   pămâ, --, --, --, 
   {{0x6aa00334,0x2d840166,0x00000000,0x00000000}},	//   _vllf, _çle_, --, --, 
   {{0xa82404d3,0xdd000841,0x01fc0375,0x00000000}},	//   اکان, _šuću, ופול, --, 
   {{0xfb8411fc,0xbc941fbe,0x00000000,0x00000000}},	//   _نگوی, _татј, --, --, 
   {{0x57e44ca1,0x6aa00c8c,0xa68400c2,0x7ea001e6}},	//   ыдым_, _ullf, улод, _löpn, 
   {{0xe44812b7,0x66743224,0x00000000,0x00000000}},	//   ىلدى_, ندگر, --, --, 
   {{0x692400c7,0x95204ca2,0xe80c4ca3,0x79a40120}},	//   _амҧа, حکوم, _सभटा_, _труе, 
   {{0x29044ca4,0x348401e0,0x205400fb,0x00000000}},	//   _hula_, рҡып_, һтар, --, 
   {{0x216800f5,0x00000000,0x00000000,0x00000000}},	//   ниги_, --, --, --, 
   {{0x29044ca5,0x2054074d,0x00000000,0x00000000}},	//   _jula_, лтар, --, --, 
   {{0x29044ca6,0x64544ca7,0x55b80375,0xab5c033f}},	//   _mula_, _ubyi, _רמקו, _wyży, 
   {{0x29044ca8,0x7c2403b2,0x00000000,0x00000000}},	// [4fe0] _lula_, ðirm, --, --, 
   {{0x80dc0729,0x29040129,0xd00c0014,0x629801f4}},	//   _মূখ্, _oula_, قلہ_, ötod, 
   {{0x21744ca9,0xa0c44caa,0x00000000,0x00000000}},	//   _супр, _ميدو, --, --, 
   {{0x64442f2b,0x247c0020,0xcb0400ec,0x00000000}},	//   ngki, ባበሩት_, گيون_, --, 
   {{0x6d404cab,0x6d8c010e,0x6e3801ef,0x00000000}},	//   _ålan, _ỳaty, _říší_, --, 
   {{0x29044cac,0xcb0405d9,0x66dc0100,0xeb300137}},	//   _bula_, ديون_, bèki, زۉمد, 
   {{0xdd900517,0x893007fc,0x00000000,0x00000000}},	//   _اوز_, معيا, --, --, 
   {{0x29044cad,0x60d44cae,0xc9802be9,0x4b844caf}},	//   _dula_, noym, суши, тйән_, 
   {{0x290402fa,0x5ac80022,0x660c0051,0x00000000}},	//   _eula_, _злам_, _đakr, --, 
   {{0x644401f5,0x00000000,0x00000000,0x00000000}},	//   egki, --, --, --, 
   {{0x29044cb0,0xe3b00154,0x60d401f4,0x75d400ae}},	//   _gula_, _টুলব, koym, شيحا, 
   {{0x60d44cb1,0x2000003e,0xf8b84cb2,0x386001e7}},	//   joym, _ngki_, _шөл_, _úir_, 
   {{0x2f0c00d0,0x29044cb3,0xdc440051,0x00000000}},	//   _oľga_, _zula_, nêđi, --, 
   {{0xc624015b,0x29044cb4,0xd1640395,0x00000000}},	//   _মাথা_, _yula_, лъби, --, 
   {{0x86c032e8,0x249000ad,0x29044cb5,0x81d800eb}},	//   _ديون, _foym_, _xula_, ়েস_, 
   {{0x30144cb6,0x24904cb7,0x60d406ea,0x00000000}},	//   рдар, _goym_, goym, --, 
   {{0xb4c00073,0xc6240011,0x00000000,0x00000000}},	// [4ff0] ःची_, _মাতা_, --, --, 
   {{0x3254276f,0xcd0401c0,0x00000000,0x00000000}},	//   _твор, гчди, --, --, 
   {{0xec14027d,0x60d40175,0x00000000,0x00000000}},	//   لواد, boym, --, --, 
   {{0x2904123c,0x66dc020c,0x00000000,0x00000000}},	//   _rula_, rèki, --, --, 
   {{0x29044cb8,0x765802fd,0x7ea00209,0x03dc0241}},	//   _sula_, _obvy, _köpl, _ńyẹn, 
   {{0x29044cb9,0x5fb8011a,0x6b980142,0x00000000}},	//   _pula_, _יצרנ, rywg, --, 
   {{0xa2d42ecf,0xe50807ae,0x29044cba,0x98bc0e51}},	//   णवत्, _mặc_, _qula_, _artı_, 
   {{0x29044cbb,0x6e340841,0x05cc0cb4,0xe5080208}},	//   _vula_, _hdzb, _सुगब, _lặc_, 
   {{0x29040198,0x24900363,0x79500050,0x2bd8179e}},	//   _wula_, _roym_, _ہێوا, _شارک_, 
   {{0x29044cbc,0xe508004d,0x7f3c010f,0x00000000}},	//   _tula_, _nặc_, געזו, --, 
   {{0x05cc0034,0x29044cbd,0xda78011a,0x00000000}},	//   _सुखब, _uula_, _שנער, --, 
   {{0x64984cbe,0x00000000,0x00000000,0x00000000}},	//   ттор_, --, --, --, 
   {{0x24900363,0x6e3402f0,0x9340005b,0x6444002f}},	//   _voym_, _odzb, оняе, rgki, 
   {{0x7ea04cbf,0xe50801fb,0x00000000,0x00000000}},	//   _röpo, _cặc_, --, --, 
   {{0x00e404fb,0xe5080051,0x60d40174,0x64a4014b}},	//   متری, _dặc_, toym, _вайа, 
   {{0x7ea00421,0xe45801f4,0xb0b8009d,0x00000000}},	//   _pöpo, _ржи_, гуух_, --, 
  
   {{0x60d44cc0,0x10a04cc1,0xf7080051,0xd5e400eb}},	// [5000] roym, цитн, _kủa_, নশৃঙ, 
   {{0x213c08c2,0x5398010f,0x00000000,0x00000000}},	//   àths_, _סייו, --, --, 
   {{0x628c0007,0x6d8c010e,0x00000000,0x00000000}},	//   mjbo, _ỳary, --, --, 
   {{0xdca41fbe,0x60d4014f,0x660c1ea0,0x00000000}},	//   јади, qoym, _şakl, --, 
   {{0x66dc0066,0x00000000,0x00000000,0x00000000}},	//   lèku, --, --, --, 
   {{0x3d2804fb,0x7ea04c51,0x628c0100,0x2ed000cd}},	//   _متری_, _köpm, njbo, तकृत, 
   {{0x81d800bd,0x00000000,0x00000000,0x00000000}},	//   ়ের_, --, --, --, 
   {{0x8c404cc2,0xd7f84cc3,0x26c401a4,0xddcc0064}},	//   _месе, куп_, enlo_, _labū, 
   {{0xcb644cc4,0x7f440393,0xf7080208,0x7ea0007c}},	//   _кате_, nuiq, _bủa_, _löpm, 
   {{0xf7084cc5,0x7d004cc6,0x0f540375,0x042000cc}},	//   _của_, _hims, סיים_, _ভাগী_, 
   {{0x7d004cc7,0x588411db,0x75d400c6,0x15a802e8}},	//   _kims, _выла, إيجا, тъпи_, 
   {{0xd4984cc8,0x09ac03d4,0xe508004d,0xd90c01d3}},	//   тро_, _চুকা, _sặc_, _ٹیک_, 
   {{0x7ea00793,0x3494039b,0x53e43de2,0x3864007c}},	//   _pöpl, _ҳайр, рцна, memr_, 
   {{0xc6d024e0,0x7f44003a,0x1de400af,0x7d004cc9}},	//   _وتوت, duiq, _करूष_, _lims, 
   {{0x34944cca,0xddcc005f,0xe80c00bc,0x00000000}},	//   _гайр, _dabū, _हलमा_, --, 
   {{0x8d844ccb,0x7d00009f,0xd3441046,0x00000000}},	//   یشان, _nims, _پیسه_, --, 
   {{0xe50801fb,0x3eb80175,0x4394023b,0x3f1428e8}},	// [5010] _tặc_, _bmrt_, _маъс, ждус, 
   {{0x7d004ccc,0xb8e8025c,0x764805ac,0xddcc0064}},	//   _aims, _ཊམ_, ngdy, _gabū, 
   {{0x7d000086,0x69140327,0xd16402e8,0x00000000}},	//   _bims, _iġeg, _тъпи, --, 
   {{0x7d000a55,0x50a00046,0x7c94027d,0x66dc4ccd}},	//   _cims, _بەرل, يشنا, lèkt, 
   {{0x7d004cce,0x7f4416b8,0x26c40076,0xcbc40472}},	//   _dims, cuiq, ynlo_, جزاي, 
   {{0xaa484ccf,0x6914031c,0x6e3407f5,0xa9a44cd0}},	//   упка_, _jġeg, _udzb, йилд, 
   {{0x6f0c0309,0xf708004d,0x00000000,0x00000000}},	//   lqac, _rủa_, --, --, 
   {{0x6d444cd1,0x66dc0066,0xf708004d,0x7d004cd2}},	//   muha, hèkt, _sủa_, _gims, 
   {{0x6d444cd3,0x6f0c4cd4,0x09ac00cc,0x00000000}},	//   luha, nqac, _চুখা, --, 
   {{0xf708004d,0x66dc02e2,0x32100210,0x00000000}},	//   _qủa_, jèkt, jczy_, --, 
   {{0xba7407a7,0x7d0002b9,0xadf80037,0x3210012d}},	//   _باقت, _yims, ्खिन_, dczy_, 
   {{0x6d4400d8,0x7d004cd5,0xddcc00ef,0x1954011a}},	//   iuha, _xims, _sabū, _לבעל_, 
   {{0x6d444cd6,0xe7384cd7,0x7c240ad9,0x66dc0100}},	//   huha, _сел_, ðiri, fèkt, 
   {{0x25a8009f,0x2ed04cd8,0x0b340240,0xe04401c4}},	//   _مدعي_, तकोत, _ኣይተዛ, өнги, 
   {{0x6d444cd9,0xd24c00c6,0xdddc00b0,0xc1e400db}},	//   juha, عنف_, tepō, تۋدي, 
   {{0x6d444cda,0x3eb80bb3,0x6914031c,0x64c44cdb}},	//   duha, _smrt_, _iġed, _ديبل, 
   {{0xdfe805f5,0xe2980220,0xdddc02b1,0x6d440242}},	// [5020] удад_, _бап_, repō, euha, 
   {{0x6d444cdc,0x7f44003a,0x4e24004e,0x00000000}},	//   fuha, ruiq, йоун_, --, 
   {{0x50780a28,0x7f440a73,0x6914031c,0x66dc0214}},	//   ṇāṃ_, suiq, _jġed, lèks, 
   {{0x6914025c,0x7ea03653,0x5ba84cdd,0xdc200d2e}},	//   _mġed, _köpk, лкем_, मरेड_, 
   {{0x7f4416b8,0x6d440798,0x66dc1801,0x705002f2}},	//   quiq, auha, nèks, _تۆقا, 
   {{0xdb90001f,0x2b38084c,0x22484cde,0xf7080051}},	//   _ሙዚየም_, ряцэ_, ngbk_, _bủn_, 
   {{0x6d444cdf,0xdd901291,0x00000000,0x00000000}},	//   cuha, _عور_, --, --, 
   {{0x76480142,0x48a40166,0x32100210,0x00000000}},	//   wgdy, йтым_, zczy_, --, 
   {{0x66dc020c,0x4fb8008f,0x32100210,0x00000000}},	//   jèks, ָציא, yczy_, --, 
   {{0x46380020,0xfaa4036b,0x76b84ce0,0x00000000}},	//   _በአገራ, _بجری, рлор_, --, 
   {{0x386400d8,0x00000000,0x00000000,0x00000000}},	//   pemr_, --, --, --, 
   {{0xf4b8045e,0x66dc4ce1,0x3210033f,0x6f0c0309}},	//   ীত্ব, fèks, wczy_, yqac, 
   {{0x6d444ce2,0xc624015b,0x66dc07b0,0x32400023}},	//   zuha, _মারা_, tèkt, _ንምርኣ, 
   {{0x6d444ce3,0x93e401d5,0x506400fb,0x46640395}},	//   yuha, _қўйл, өтба, _гръм_, 
   {{0x3210068f,0x9f880e78,0xc6704ce4,0x66dc4ce5}},	//   rczy_, töße_, _رطوب, rèkt, 
   {{0xd3a4084c,0x6d444ce6,0x00000000,0x00000000}},	//   _гроп, vuha, --, --, 
   {{0x6d444ce7,0x9f8803fa,0xeeb84ce8,0x0094084c}},	// [5030] wuha, röße_, алаш_, читэ, 
   {{0x81d802a6,0xe50801fb,0x6f0c02d1,0x00000000}},	//   ়েই_, _mặn_, rqac, --, 
   {{0x6f0c4ce9,0x6130022c,0xe50801fb,0xad241e4a}},	//   sqac, rðlý, _lặn_, زىشى, 
   {{0x6f0c0455,0xf7080051,0x63a00210,0x00000000}},	//   pqac, _rủn_, _żoni, --, 
   {{0xe508004d,0x6f0c01d5,0x00000000,0x00000000}},	//   _nặn_, qqac, --, --, 
   {{0xfbd04cea,0x00000000,0x00000000,0x00000000}},	//   رتن_, --, --, --, 
   {{0xa88812e7,0x00000000,0x00000000,0x00000000}},	//   ийка_, --, --, --, 
   {{0xd94001d5,0x0d740066,0x00000000,0x00000000}},	//   феъи, _پیچک_, --, --, 
   {{0xe73829db,0x7a3401ed,0xe508004d,0xc9d00066}},	//   шеп_, _sütő, _cặn_, _کماک, 
   {{0xe50801fb,0x2d840129,0xdb0c01e1,0x7c240413}},	//   _dặn_, _àles_, _àdád, ðirv, 
   {{0x478802dd,0x50540023,0xf3e8011a,0xe48801c4}},	//   _әсем_, _ምጽንባ, _סף_, айнд_, 
   {{0x66dc07b0,0xe75800d4,0xd1b80240,0x00000000}},	//   tèks, _виді_, ሰነት_, --, 
   {{0x6f080036,0x00000000,0x00000000,0x00000000}},	//   _éech, --, --, --, 
   {{0x66dc4ceb,0x00000000,0x00000000,0x00000000}},	//   rèks, --, --, --, 
   {{0x20fc01f2,0x66dc0100,0xe0844cec,0x00000000}},	//   ọime_, sèks, يجري, --, 
   {{0xd0044ced,0x7ea00166,0x00000000,0x00000000}},	//   жете_, _töpk, --, --, 
   {{0x7ea0005b,0x00000000,0x00000000,0x00000000}},	// [5040] _höpi, --, --, --, 
   {{0x7ea04cee,0x9b8804fb,0x0e604cef,0x2cac0327}},	//   _köpi, ینال_, мкун, _ċeda_, 
   {{0x5c043930,0x5d680d1d,0x00000000,0x00000000}},	//   ояла, рием_, --, --, 
   {{0xa31c012c,0x1cb8007b,0x00000000,0x00000000}},	//   _बझाङ_, جائب_, --, --, 
   {{0x7ea0014a,0x00000000,0x00000000,0x00000000}},	//   _löpi, --, --, --, 
   {{0xe5080051,0x00000000,0x00000000,0x00000000}},	//   _rặn_, --, --, --, 
   {{0xdcb0198a,0xca44007b,0x2d940354,0x00000000}},	//   _قىس_, زليه_, _ертс, --, 
   {{0x09ac00cc,0x924c0092,0x00000000,0x00000000}},	//   _চুঙা, ንቀሳቃ, --, --, 
   {{0xe74400fd,0x49c4151e,0x00000000,0x00000000}},	//   зүче_, йлән_, --, --, 
   {{0x248802d3,0x35b41d0b,0xe50801fb,0x41bc043e}},	//   _ንየሱስ_, збор, _vặn_, ोपास, 
   {{0x95c84cf0,0x2484001f,0xf8b80139,0x00000000}},	//   рупа_, _ክረምት_, _гөп_, --, 
   {{0xd7f820db,0x00000000,0x00000000,0x00000000}},	//   _кул_, --, --, --, 
   {{0x04b800dd,0x00000000,0x00000000,0x00000000}},	//   تھوں_, --, --, --, 
   {{0x867000d4,0x00000000,0x00000000,0x00000000}},	//   _оліє, --, --, --, 
   {{0x70240327,0x1164036b,0x00000000,0x00000000}},	//   _འབྱུ_, غلری_, --, --, 
   {{0x213c007b,0x2f14005b,0x3494014b,0x00000000}},	//   átha_, здаё, _хаир, --, 
   {{0x3f544cf1,0x660c2ed0,0x00000000,0x00000000}},	// [5050] gäu_, _şaki, --, --, 
   {{0x51840f30,0x86380092,0x00000000,0x00000000}},	//   _дума, _በአነስ, --, --, 
   {{0x7af8074d,0x00000000,0x00000000,0x00000000}},	//   dmvt, --, --, --, 
   {{0x7024081f,0xeb5c02d3,0x3f5401c7,0xc0e80092}},	//   _འབྲུ_, _ሰልፍና_, bäu_, ሚችል_, 
   {{0x0f70052f,0x4ea41fbe,0x8b6400db,0x00000000}},	//   _юғар, _дрва, تاام, --, 
   {{0xfbd04cf2,0x27e80327,0xe8f84cf3,0xf7080208}},	//   ختم_, _ġan_, әли_, _củm_, 
   {{0xba7400cf,0xfcdc0023,0x00000000,0x00000000}},	//   بانت, _ንገጽ_, --, --, 
   {{0x81d80f22,0x00000000,0x00000000,0x00000000}},	//   ়েক_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7ea02045,0xba7402ef,0xe80c0b03,0x779000e5}},	//   _pöpi, _يالت, _हलवा_, ئیوا, 
   {{0x240801d5,0xfe9c0677,0x00000000,0x00000000}},	//   йнни_, ייזמ, --, --, 
   {{0x672c0327,0x385800d4,0x00000000,0x00000000}},	//   _ħajf, _мрію_, --, --, 
   {{0x3ae0067c,0x82440023,0x86b002dd,0x737400c7}},	//   còps_, _ንምርዳ, _жәні, мырх, 
   {{0xb90800cf,0x00000000,0x00000000,0x00000000}},	//   _ازەم_, --, --, --, 
   {{0x64a44cf4,0x7ea00267,0xe2984cf5,0xdddc033f}},	//   _нака, _köpv, _ған_, zepł, 
   {{0x9100013d,0x600806ed,0x70f4003b,0x00000000}},	//   епсе, снам_, дчує, --, 
   {{0x62644cf6,0x20480023,0x7f880092,0x00000000}},	// [5060] _евпа, _ዝኽልክ, _አዘጋጀ_, --, 
   {{0xd3780375,0x3f54002f,0x00000000,0x00000000}},	//   _פריט, räu_, --, --, 
   {{0x9298025f,0xa0684cf7,0x3a2c0334,0xd2980375}},	//   _היית, _лана_, _redp_, _השיט, 
   {{0xd70400fe,0x2fcc107d,0xa0680022,0xc0180055}},	//   লীয়া_, _žege_, _уама_, _nīḍe_, 
   {{0x1ae40305,0x8b2001f4,0x00000000,0x00000000}},	//   подм, едче, --, --, 
   {{0x6fe000b5,0x9c5801d9,0xdb2407d6,0x00000000}},	//   のcaf, _گٔرا_, قوچی, --, 
   {{0xe508004d,0x7c240162,0x00000000,0x00000000}},	//   _bặm_, ðirs, --, --, 
   {{0x63440134,0xfc640014,0x0f1c03d4,0x7f44003a}},	//   _wɔny, _تخسی, _পিতৃ_, oriq, 
   {{0xd6d80c04,0x7f444cf8,0xe50801fb,0x57a44cf9}},	//   йто_, nriq, _dặm_, яшка, 
   {{0xcfb40a1e,0x20fc02e3,0xa3c01b51,0x629801f4}},	//   פליי_, ọihe_, ्पन_, ötol, 
   {{0xe6d801a8,0xe9f00022,0x5804007b,0xfbc001f9}},	//   þráð, _иҧшы, _فواك, _शेतम, 
   {{0xe508004d,0x00000000,0x00000000,0x00000000}},	//   _gặm_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7f444cfa,0x7ea0311d,0x00000000,0x00000000}},	//   driq, _köpu, --, --, 
   {{0x7f44003a,0x932404f2,0xc2c400ae,0x00000000}},	//   eriq, _کربن, ريفي, --, 
   {{0x7f444cfb,0x94a8074d,0x6aa801ef,0x00000000}},	//   friq, _ытла_, _कत्र, --, 
   {{0xb4d809fd,0x6e984cfc,0xc43c0375,0x7f44003a}},	// [5070] ़की_, овар_, _התחי, griq, 
   {{0xf2c401c0,0x00000000,0x00000000,0x00000000}},	//   _цөми, --, --, --, 
   {{0x6c744cfd,0x7f440009,0x00000000,0x00000000}},	//   дулх, ariq, --, --, 
   {{0x7f444cfe,0x1068007b,0xb5fc0327,0x00000000}},	//   briq, _احدى_, teġj, --, 
   {{0x7f44003a,0x00000000,0x00000000,0x00000000}},	//   criq, --, --, --, 
   {{0x6f1c4cff,0xe9a804fb,0xb5fc031c,0xc33400d9}},	//   _itsc, يگان_, reġj, גוס_, 
   {{0xac184d00,0x4a700046,0xe8f84d01,0x888001d3}},	//   _мову_, дықт, олк_, ٹیشن, 
   {{0x6d4400f1,0x7ea002d2,0x6e2401ab,0x3c5801af}},	//   mrha, _döpu, lbhb, _нисэ_, 
   {{0x7c24005a,0x6d4403ac,0x6b7401ee,0x00000000}},	//   ñire, lrha, _юлау, --, 
   {{0xe5a4014b,0x25580276,0x672c031c,0x6d4402d0}},	//   диои, ормэ_, _ħajd, orha, 
   {{0x6f1c08c2,0x6d444d02,0x6298007c,0x00000000}},	//   _ltsc, nrha, ötom, --, 
   {{0x7f44003a,0x6f1c02d0,0x09c001af,0x00000000}},	//   yriq, _otsc, _оҡһо, --, 
   {{0x68e817b8,0x7ea04d03,0x6d440e78,0x6f1c4d04}},	//   mled, _köpt, hrha, _ntsc, 
   {{0x65c424ab,0x68e84d05,0x2cac0368,0xa18801d5}},	//   _обла, lled, _lled_, обга_, 
   {{0x91e04d06,0x2cac007d,0x6f1c4d07,0x7f4402d1}},	//   воре, _oled_, _atsc, wriq, 
   {{0x20f80bae,0x68e84d08,0x7f444d09,0xdbd40194}},	//   ्देश_, nled, triq, rĸúm, 
   {{0xc2b40323,0x68e84d0a,0x6d440ade,0x7d1c0b00}},	// [5080] _зөвш, iled, erha, _strs, 
   {{0x68e8038e,0xb9e40020,0x2cac03cb,0x6d440042}},	//   hled, _ይፋ_, _aled_, frha, 
   {{0x60244d0b,0x68e84d0c,0x2cac4d0d,0x6f1c035a}},	//   _одна, kled, _bled_, _etsc, 
   {{0x68e8019b,0x2cac4d0e,0xb91800e4,0x7f44022e}},	//   jled, _cled_, _eveỹ_, priq, 
   {{0x68e84d0f,0x6d444d10,0x00000000,0x00000000}},	//   dled, arha, --, --, 
   {{0x68e84d11,0x93b4011a,0x7ea002d2,0x00000000}},	//   eled, ולנו_, _pöpu, --, 
   {{0x2cac0493,0x6d440cfd,0x68e84d12,0x7ea001e3}},	//   _fled_, crha, fled, _döpt, 
   {{0x68e8098d,0xc9803312,0x2cac0493,0xf7080208}},	//   gled, туши, _gled_, _hủi_, 
   {{0x96444d13,0x00000000,0x00000000,0x00000000}},	//   мэнд, --, --, --, 
   {{0x69140327,0x68e833d5,0xb5fc031c,0x7ea001a8}},	//   _iġen, aled, leġi, _töpu, 
   {{0x68e84d14,0xd83809a5,0x7ea00108,0xf7080051}},	//   bled, _дэл_, _höps, _mủi_, 
   {{0xb4d81533,0x7ea004f7,0x68e80042,0xd36c0131}},	//   ़के_, _köps, cled, لۇب_, 
   {{0x4394023a,0xe2040051,0x00000000,0x00000000}},	//   ваяс, _đóan_, --, --, 
   {{0x1b3c0023,0x7ea0002f,0x6f1c002f,0x35d4005b}},	//   _ኣይተራ, _möps, _rtsc, _полё, 
   {{0xc1e84d15,0xf0e8185e,0x7ea00267,0x00000000}},	//   дьте_, كىسى_, _löps, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd20805f5,0xa3c006e3,0x2ef44d16,0x4508031c}},	// [5090] _мэнд_, ्पण_, езар, _གཤོར_, 
   {{0x68e80f7d,0x6d440306,0x2cac045a,0xee3000ec}},	//   zled, trha, _sled_, اٽا_, 
   {{0x68e84d17,0x2cac4d18,0x6914003d,0x201c084c}},	//   yled, _pled_, _aġen, _ştie_, 
   {{0x2f28006a,0xb4bc1b57,0x7c8403c5,0x6ce400db}},	//   gîgî_, _इगो_, куче, رزاە, 
   {{0x63500085,0x6f1c4d19,0x68e84d1a,0xfc30007b}},	//   _pɛnɛ, _utsc, vled, شحن_, 
   {{0x68e81e16,0x00000000,0x00000000,0x00000000}},	//   wled, --, --, --, 
   {{0x68e84d1b,0x45080135,0xfd7401c0,0xf7080208}},	//   tled, _གཤེར_, _илрэ, _gủi_, 
   {{0xd7c80034,0x79a40395,0xb4d80d2e,0x00000000}},	//   ापंच, ърче, ़को_, --, 
   {{0x68e8057b,0x7ea00166,0x201c0213,0x7b74007b}},	//   rled, _töpt, _əti_, _لطلا, 
   {{0x6d4003cd,0xe5244965,0x64c400f1,0x7ac43e4f}},	//   _ålas, ндоп, ځيدل, _исхе, 
   {{0xe9444d1c,0xe4c44d1d,0x68e84d1e,0x7ea04d1f}},	//   _سرای, ейни, pled, _köpr, 
   {{0x63a0031c,0x00000000,0x00000000,0x00000000}},	//   _żonq, --, --, --, 
   {{0x850800ce,0xd5ac4d20,0xe6440139,0x00000000}},	//   _संकट_, لفی_, _зелп, --, 
   {{0x7ea001e3,0x0cd84d21,0x00000000,0x00000000}},	//   _löpr, यकुम, --, --, 
   {{0x26c44d22,0x00e42814,0x9f5c0241,0x00000000}},	//   milo_, نتری, _ńtà_, --, 
   {{0x26c44d23,0xf708001e,0xa3c00b4c,0x00000000}},	//   lilo_, _rủi_, ्पद_, --, 
   {{0x645401aa,0xff24066d,0x1e84036b,0xf708004d}},	// [50a0] _icyi, ئبری, нлам, _sủi_, 
   {{0x25a4062c,0x63a401bf,0x8ee400d8,0x00000000}},	//   oyll_, mykn, емув_, --, 
   {{0xa0a44d24,0xb5fc003d,0xdca4114a,0x63a44d25}},	//   _занд, teġi, нажи, lykn, 
   {{0x26c44d26,0x629c4d27,0x25a4062c,0x48b003d4}},	//   hilo_, _hopo, iyll_, ুকুৰ, 
   {{0x629c4d28,0xb90800b8,0x25a403cd,0x7ea0032e}},	//   _kopo, _gniṃ_, hyll_, _döpr, 
   {{0x629c4d29,0x2f28006a,0xf708004d,0x2c1000fe}},	//   _jopo, sîgî_, _tủi_, াৰলৈ_, 
   {{0x629c4d2a,0x3f804d2b,0x2f0c0427,0x00000000}},	//   _mopo, lviu_, _vžge_, --, 
   {{0x629c4d2c,0xa3c00574,0xadb44d2d,0x25a40142}},	//   _lopo, ्पा_, _جۇما_, dyll_, 
   {{0x26c44d2e,0x629c0421,0x56c400a7,0x9b444d2f}},	//   filo_, _oopo, ещна, _سناو, 
   {{0xc6f44d30,0x629c4d31,0x26c400c8,0x64540223}},	//   нных_, _nopo, gilo_, _acyi, 
   {{0xceb01203,0x25a44d32,0x1868030d,0x00000000}},	//   רית_, gyll_, _нажи_, --, 
   {{0x629c1140,0xe68401e0,0x958400b1,0x00000000}},	//   _aopo, еҙәк_, _үлде, --, 
   {{0x629c4d33,0x25a41368,0x00000000,0x00000000}},	//   _bopo, ayll_, --, --, 
   {{0x629c4d34,0x25a44d35,0xf594007b,0x051c00cc}},	//   _copo, byll_, _للتج, _ভিৰৰ_, 
   {{0x629c4d36,0x395c0393,0x25a40142,0x320401f4}},	//   _dopo, ntvs_, cyll_, äly_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x846406bb,0xce680640,0xddcc01ef,0x00000000}},	// [50b0] _съще, зред_, _rabš, --, 
   {{0x629c4d37,0x00000000,0x00000000,0x00000000}},	//   _gopo, --, --, --, 
   {{0xbd180212,0x00000000,0x00000000,0x00000000}},	//   еції_, --, --, --, 
   {{0x629c4d38,0x00000000,0x00000000,0x00000000}},	//   _zopo, --, --, --, 
   {{0x629c4d39,0xa0340375,0xfaf8002b,0x26c44d3a}},	//   _yopo, _בארה_, _bhī_, yilo_, 
   {{0x26c44d3b,0xff0402e8,0x00000000,0x00000000}},	//   xilo_, _бясн, --, --, 
   {{0x26c44d3c,0xfaf800b8,0x6298005b,0xddcc010e}},	//   vilo_, _dhī_, ötoi, _tabš, 
   {{0x26c44d3d,0xfaf800b8,0x00000000,0x00000000}},	//   wilo_, _ehī_, --, --, 
   {{0x25a40368,0x7ea04d3e,0x6454007f,0x2fd80009}},	//   wyll_, _köpp, _rcyi, _jxsg_, 
   {{0xba744d3f,0x63a402f0,0xdb2404f2,0x25a40142}},	//   _مامت, vykn, _شومی, tyll_, 
   {{0x26c44d40,0xa934084c,0x7ea008a5,0xd8740633}},	//   rilo_, _рееш, _möpp, رمیت_, 
   {{0x629c4d41,0x26c44d42,0x25a44d43,0x7ea036b2}},	//   _sopo, silo_, ryll_, _löpp, 
   {{0x629c4d44,0x33d40220,0x25a40072,0x7ea0007c}},	//   _popo, гірт, syll_, _oöpp, 
   {{0x7cf84d45,0x63a4072b,0xf3f40209,0x629c022e}},	//   míre, rykn, ыңы_, _qopo, 
   {{0x20544d46,0x24f44d47,0xe3b006c1,0x00000000}},	//   ктар, _ичир, _چرخ_, --, 
   {{0xe3b04d48,0x629c0161,0x64540223,0xdfd04d49}},	//   _نرخ_, _wopo, _ucyi, ليز_, 
   {{0x629c4d4a,0xe29804b3,0x00000000,0x00000000}},	// [50c0] _topo, _жап_, --, --, 
   {{0x3f804d4b,0x00000000,0x00000000,0x00000000}},	//   rviu_, --, --, --, 
   {{0xf1d44d4c,0xfdd805d9,0x95fc00b8,0xe044022e}},	//   _бөтө, رائڻ_, _āyūṃ, _инни, 
   {{0xed340276,0xa0a401ee,0x00000000,0x00000000}},	//   уэфэ, _рамд, --, --, 
   {{0x7cf800bc,0x7b8401ec,0x00000000,0x00000000}},	//   jíre, ығад, --, --, 
   {{0x69140327,0x7ea00112,0x7cf84d4d,0x38c84d4e}},	//   _eġem, _göpp, díre, کاتی_, 
   {{0x7e7c0332,0xefbc0092,0xcb0401f7,0x00000000}},	//   _iarp, ሰደው_, خيون_, --, 
   {{0x7e7c4d4f,0x7cf81709,0x2b5c062c,0x395c003a}},	//   _harp, fíre, btwc_, rtvs_, 
   {{0x47304d50,0x9b042f8d,0xe28c01a9,0x395c003a}},	//   аныс, _азад, _onа_, stvs_, 
   {{0xa3e410f7,0xabc40184,0x95c80124,0xfaf80418}},	//   _बुध_, _сауҙ, дума_, _uhī_, 
   {{0x7e7c4d51,0x00000000,0x00000000,0x00000000}},	//   _marp, --, --, --, 
   {{0x7e7c0005,0x7cf8012c,0x7ae800b5,0x38600e89}},	//   _larp, bíre, _hkdt, _ùir_, 
   {{0x7e7c0731,0x53440395,0x00000000,0x00000000}},	//   _oarp, ъхна, --, --, 
   {{0x7e7c4d52,0x2d8400f3,0x057019c5,0x1dd0012d}},	//   _narp, _šlem_, _چايد, थपात, 
   {{0x201c0311,0xf1c818fd,0x69940408,0x00000000}},	//   _ştia_, رورى_, _урăх, --, 
   {{0x7e7c00ef,0x85400139,0x33740117,0x00000000}},	//   _aarp, _тэше, _бгир, --, 
   {{0x7e7c036b,0x04c846bc,0xb5fc0135,0x00000000}},	// [50d0] _barp, _جويي_, reġu, --, 
   {{0xa3c04d53,0x71784d54,0x7e7c4d55,0xb27400d8}},	//   ्पर_, _збор_, _carp, _слош, 
   {{0x7e7c0cfd,0x271800cc,0xb5fc00e4,0xff040108}},	//   _darp, _দিছো_, peġu, рятн, 
   {{0xac184d56,0x7e7c4d57,0xa92401b9,0xebd84d58}},	//   ходу_, _earp, қдил, ндеш_, 
   {{0x7e7c0e89,0x6b644d59,0xaa444d5a,0x82440023}},	//   _farp, укла, гелл, _ንምህዳ, 
   {{0xddcc00dd,0x7cf84d5b,0x00000000,0x00000000}},	//   _ebbő, víre, --, --, 
   {{0x3d9406dc,0xcd040022,0x98bc008e,0x66e401b9}},	//   _кирр, _ачаи, _astı_, ғона, 
   {{0x8c5400db,0xd6940131,0x7cf80332,0x48b000fe}},	//   _جئسا, ﯘﻧﻼﺭ_, tíre, ুক্ৰ, 
   {{0xe50801dc,0x7e7c4d5c,0xa6e44d5d,0x6e340790}},	//   _mặt_, _yarp, лжил, _kezb, 
   {{0x8cbc02ab,0x4ab409fa,0xe508004d,0x7e7c4d5e}},	//   लोरो, _अतिव, _lặt_, _xarp, 
   {{0x64a44d5f,0x36940209,0x6e344d60,0x610c01e4}},	//   гана, ршыс, _mezb, _oŝla, 
   {{0xe35405f5,0x6e344d61,0xfbd001d9,0x4dbc009e}},	//   лтгэ, _lezb, _اتہ_, ্থপূ, 
   {{0x6aa04d62,0x21dc0150,0xdd1c01ef,0x00000000}},	//   _kolf, _ﺃﻜﺘﻭ, _míše, --, 
   {{0x6e344d63,0x2174041b,0xdd1c013a,0x996000d7}},	//   _nezb, лубр, _líše, líše_, 
   {{0xa0684d64,0x6aa04d65,0xa1144d66,0x3d18033f}},	//   нава_, _molf, اورت, _बंधे_, 
   {{0x6aa003cb,0xe5080051,0x00000000,0x00000000}},	//   _lolf, _cặt_, --, --, 
   {{0x6e342220,0x44204d67,0x7e7c4d68,0x6aa04d69}},	// [50e0] _bezb, _ifi_, _parp, _oolf, 
   {{0x7e7c4d6a,0xe2984d6b,0x442001bf,0x4fe40137}},	//   _qarp, _чао_, _hfi_, умун_, 
   {{0x7e7c4d6c,0x9a841f71,0x6e34084c,0x2168041b}},	//   _varp, ғулл, _dezb, _џими_, 
   {{0x691402fb,0xe508004d,0x7e7c26de,0x672c0327}},	//   _kšef, _gặt_, _warp, _ħajn, 
   {{0x7e7c4d6d,0x44204d6e,0x6aa01529,0x8c40048a}},	//   _tarp, _mfi_, _bolf, сече, 
   {{0x442002fa,0x34d001f9,0x00000000,0x00000000}},	//   _lfi_, _हद्द, --, --, 
   {{0x44204d6f,0x6aa04d70,0x9f940124,0x26040073}},	//   _ofi_, _dolf, _рыҟә, हेमी_, 
   {{0x44200ca8,0x1d0800db,0x4b200166,0x3ec40818}},	//   _nfi_, _чеби_, шмәв, _сиҳҳ, 
   {{0x6aa001b8,0x6e340099,0x5a540035,0x741402f2}},	//   _folf, _yezb, _مخاز, یودا, 
   {{0x44204d71,0x6b9c01ab,0x00000000,0x00000000}},	//   _afi_, _àsga, --, --, 
   {{0x8b000316,0x44200200,0x672c0200,0x0a1001e2}},	//   ířen, _bfi_, _çajn, _اومح, 
   {{0x44201529,0x6aa04d72,0x79880857,0xa3c000dc}},	//   _cfi_, _zolf, _irdw, ्पं_, 
   {{0x4420005c,0xe7940753,0xe5080051,0x00000000}},	//   _dfi_, _ناوک, _rặt_, --, 
   {{0x44204d73,0x47300323,0x00000000,0x00000000}},	//   _efi_, _уншс, --, --, 
   {{0x2d844d74,0x31344d75,0xc690008d,0x44200368}},	//   _àlex_, ребр, _לאס_, _ffi_, 
   {{0x44204d76,0xbb4c01ec,0x00000000,0x00000000}},	//   _gfi_, _ﺃﻫﻡ_, --, --, 
   {{0xe50807ae,0x6e3401e4,0x1b180154,0xa3c000dc}},	// [50f0] _vặt_, _pezb, নীতে_, ्पः_, 
   {{0x7988127b,0xbf140166,0x00000000,0x00000000}},	//   _ordw, сүрә, --, --, 
   {{0x6e341050,0xdd1c0122,0x51844d77,0x4638008f}},	//   _vezb, _píše, _супа, געבע, 
   {{0x6e340099,0x0cd0009e,0xae440050,0x00000000}},	//   _wezb, ়ত্ত, _چھاو, --, 
   {{0x6aa04d78,0x79884d79,0xfc6402e8,0x6e3406be}},	//   _polf, _ardw, съхн, _tezb, 
   {{0x69244d7a,0x6aa00009,0x5ab40022,0x00000000}},	//   амка, _qolf, ақур_, --, 
   {{0x6aa0014a,0x798803ac,0x7cdc0083,0x00000000}},	//   _volf, _crdw, wčre, --, 
   {{0x6b2401d9,0x00000000,0x00000000,0x00000000}},	//   _نفرٔ, --, --, --, 
   {{0x44204d7b,0x6aa0198f,0x79884d7c,0x752416a3}},	//   _rfi_, _tolf, _erdw, _čiza, 
   {{0x29c8052f,0x6b884d7d,0x44201654,0x7cf84d7e}},	//   _итеү_, _ireg, _sfi_, míra, 
   {{0x44200084,0x99600122,0x6b884d7f,0x00000000}},	//   _pfi_, píše_, _hreg, --, 
   {{0x6b884d80,0x38584d81,0x00000000,0x00000000}},	//   _kreg, _مشهد_, --, --, 
   {{0xa3e423ef,0x00000000,0x00000000,0x00000000}},	//   _बुश_, --, --, --, 
   {{0xe124059f,0x00000000,0x00000000,0x00000000}},	//   имги, --, --, --, 
   {{0x672800db,0xa3e4012d,0x00000000,0x00000000}},	//   lpej, _बुर_, --, --, 
   {{0x60244d82,0xb9dc044e,0x44204d83,0x6b884d84}},	//   рдаа, _ኢያ_, _ufi_, _oreg, 
   {{0x6b880649,0x672800f2,0x6560047e,0x24900419}},	// [5100] _nreg, npej, ltlh, _inym_, 
   {{0x65600770,0x7cf83b00,0x00000000,0x00000000}},	//   otlh, díra, --, --, 
   {{0x65604d85,0x21744d86,0x67280240,0x1d084d87}},	//   ntlh, _тупр, hpej, вежи_, 
   {{0xdb840124,0x5ba8004e,0x00000000,0x00000000}},	//   игеи, ккем_, --, --, 
   {{0x6b884d88,0x3f8406af,0x7bdc033f,0x65604d89}},	//   _creg, _ému_, _śrub, htlh, 
   {{0x6b884d8a,0x60d4489d,0x4fd40375,0x38b806af}},	//   _dreg, lnym, _כוכב_, _mére_, 
   {{0x6b884d8b,0x60d44d8c,0x00000000,0x00000000}},	//   _ereg, onym, --, --, 
   {{0xdcb04d8d,0x6b884d8e,0x60d44d8f,0x7cf80316}},	//   _بىر_, _freg, nnym, bíra, 
   {{0x60d435e5,0x672c0200,0x00000000,0x00000000}},	//   inym, _çajl, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x38b80022,0x999c00e5,0x6b8844ef,0x00000000}},	//   _aére_, _tető_, _zreg, --, 
   {{0x60d4033f,0xd1b80092,0x00000000,0x00000000}},	//   jnym, ደነቅ_, --, --, 
   {{0x6560073c,0x24900175,0x60d44d90,0x667000d1}},	//   atlh, _dnym_, dnym, زگۈر, 
   {{0x38b8002e,0x24800165,0x12e40150,0x00000000}},	//   _dére_, adkm_, рімг, --, 
   {{0xd71c2158,0x93f0000d,0x00000000,0x00000000}},	//   _দিয়া_, _घरकच_, --, --, 
   {{0x2d840077,0x45b40375,0xe70802dd,0x62984d91}},	//   _álei_, _כפול_, _ٴتۇن_, ötor, 
   {{0x85040b8c,0x09d001f9,0x00000000,0x00000000}},	// [5110] _بوين, _तश्य, --, --, 
   {{0x6b88069c,0x9f64001e,0x7cf8012c,0x6e44007b}},	//   _rreg, _đuôi_, víra, إنضم, 
   {{0x6b884d92,0xec14027d,0x60d40e0f,0xcd040166}},	//   _sreg, مواد, bnym, ачди, 
   {{0xbb440724,0x38b80de2,0xa174010f,0x7cf84d93}},	//   _ğärä, _yére_, _פערד_, tíra, 
   {{0xfbd04d94,0x82340220,0xbb44008e,0x00000000}},	//   وته_, _ارۋا, _şärä, --, 
   {{0xe50801fb,0x6b880076,0x6560014f,0x00000000}},	//   _lặp_, _vreg, ytlh, --, 
   {{0x773c001f,0x6b884d95,0x8c1c0154,0x00000000}},	//   _በሁለተ, _wreg, দরবন_, --, 
   {{0x6b884d96,0xf9903669,0x65600455,0x7cf84d97}},	//   _treg, ببه_, vtlh, píra, 
   {{0x6b884d98,0x6f040332,0x9f5c01e1,0x00000000}},	//   _ureg, omhc, _ńtú_, --, 
   {{0x67284d99,0x60d44d9a,0x6f0400a3,0x6560014f}},	//   rpej, znym, nmhc, ttlh, 
   {{0x69140327,0x201c0276,0x6f0400a3,0xbae4007b}},	//   _aġev, _ştim_, imhc, _بكلي, 
   {{0xe5080016,0x23284d9b,0x67284d9c,0x69140216}},	//   _cặp_, ломи_, ppej, _všed, 
   {{0x68e84d9d,0x74f801c0,0x64a4013e,0x60d400d0}},	//   moed, рээс_, _ҳайа, vnym, 
   {{0x68e800a9,0xd6240063,0x60d4033f,0x6560014f}},	//   loed, _лоше_, wnym, ptlh, 
   {{0x35c4136b,0x602401c0,0x64a40166,0xd6d40137}},	//   _машҳ, йдва, _гайа, _دووش_, 
   {{0xe50807ae,0x672c038f,0xb9200248,0x68e84d9e}},	//   _gặp_, _ħajj, _aarọ_, noed, 
   {{0x60d44d9f,0x99600118,0xa364009f,0x00000000}},	// [5120] rnym, _míša_, _اُخو, --, 
   {{0x68e80f7b,0x1ea81d48,0x60d40e0f,0x7cf800e5}},	//   hoed, داري_, snym, gírn, 
   {{0x68e84da0,0x3ce41d8a,0xb324025c,0xa3c04da1}},	//   koed, टकले_, _འཕོང_, ्पक_, 
   {{0x20540640,0x1afc0183,0x80b400db,0xb61c01ec}},	//   _утор, ুৱাই_, _بەرش, _ﺣﯟ_, 
   {{0x68e80cfd,0xdd904da2,0x00000000,0x00000000}},	//   doed, _کوز_, --, --, 
   {{0xd3780375,0xcc300022,0xdddc06be,0x00000000}},	//   טרנט, охәы, cepş, --, 
   {{0x98c44da3,0x68e80368,0x5da400fe,0x00000000}},	//   йсил, foed, _গেৰু, --, 
   {{0xda6400ec,0x00000000,0x00000000,0x00000000}},	//   _گاري, --, --, --, 
   {{0xb8d04da4,0x7cf80646,0x99840345,0xfb840244}},	//   _ऐक_, líro, _گلاو, _بدزی, 
   {{0xda643c4b,0x87e011ed,0x7d000098,0x99380064}},	//   _داري, яюще, _hhms, _бяду_, 
   {{0x68e84da5,0x7cf84da6,0x588400c7,0x8cbc08ec}},	//   boed, níro, _гыла, लोको, 
   {{0xd4984da7,0xd7f801b9,0x00000000,0x00000000}},	//   уро_, _йул_, --, --, 
   {{0x94004614,0xa3e403ce,0xf6c800f1,0x7cf80166}},	//   रेंच_, _बुआ_, _نژدي_, híro, 
   {{0x2fcc02d2,0x00000000,0x00000000,0x00000000}},	//   _þegi_, --, --, --, 
   {{0x69141ebd,0xf0e84da8,0x7cf80306,0x7d00002f}},	//   _tšee, لىسى_, vírn, _ohms, 
   {{0x7cf84da9,0x73c4013d,0xfe7000e5,0x00000000}},	//   díro, _дәге, ہدم_, --, 
   {{0x40341c22,0x3eb80037,0xef984daa,0x00000000}},	// [5130] яетс, _blrt_, шкаш_, --, 
   {{0x33280472,0x68e8004c,0x7cf84dab,0xd258009b}},	//   _itax_, zoed, fíro, _сци_, 
   {{0x7cdc0083,0x0ca8010b,0xcd2800db,0x00000000}},	//   wčra, лтди_, اسئن_, --, 
   {{0x61f84dac,0x00000000,0x00000000,0x00000000}},	//   ütle, --, --, --, 
   {{0xeb984712,0x68e80e29,0xfd104dad,0x7cf82fda}},	//   рил_, voed, رجم_, pírn, 
   {{0xd1cc069c,0x7cf83b82,0x3e180209,0xe3c00139}},	//   _ባይቶ_, bíro, _горэ_, _uzış_, 
   {{0x7cf84dae,0x2ef80150,0x00000000,0x00000000}},	//   círo, _مىڭد_, --, --, 
   {{0xe8f81fbe,0x00000000,0x00000000,0x00000000}},	//   јли_, --, --, --, 
   {{0x68e84daf,0xaa584db0,0xca54010a,0x850401c4}},	//   roed, _визу_, _лĕпп, үүлз, 
   {{0x68e84db1,0x20d400a2,0x691401ef,0x8ad401c8}},	//   soed, _iýiň_, _všeb, _اترئ, 
   {{0x68e81a7c,0xe5a44143,0x212401f1,0xb324025c}},	//   poed, цини, _čoho_, _འཕུང_, 
   {{0x691400fb,0x24084db2,0xe7940120,0x00000000}},	//   _tšeb, инни_, _миењ, --, 
   {{0x7cf801ed,0x7c240113,0x00000000,0x00000000}},	//   zíro, ñiri, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x64a44db3,0x38b80588,0x854401d9,0x7cf80005}},	//   _мака, _héra_, _آبے_, xíro, 
   {{0x38b84db4,0x7cf828d1,0x00000000,0x00000000}},	//   _kéra_, víro, --, --, 
   {{0x1ec8016c,0x26042ce6,0x00000000,0x00000000}},	// [5140] алаи_, हेरी_, --, --, 
   {{0x2cc4031c,0x7ea0005b,0x660c010e,0x7cf84db5}},	//   _གཏུབ, _yöpy, _şaky, tíro, 
   {{0xa0a44db6,0xa0684db7,0x00000000,0x00000000}},	//   _данд, _кана_, --, --, 
   {{0x61fc4db8,0x7cf83b82,0xec6802dd,0x00000000}},	//   _izpl, ríro, йрік_, --, 
   {{0x75240b91,0x6e2805d1,0x7cf81a85,0xacb00e56}},	//   _čizm, _şebe, síro, رەكب, 
   {{0x7cf81dee,0x00000000,0x00000000,0x00000000}},	//   píro, --, --, --, 
   {{0xd1cc044e,0x8d6000ee,0x39ac013f,0x7f44003a}},	//   _ባይታ_, _овре, kɛse_, lsiq, 
   {{0xace80592,0x00000000,0x00000000,0x00000000}},	//   _هرقل_, --, --, --, 
   {{0xd6d8156b,0x7d1c4db9,0xd7f84dba,0x57a44dbb}},	//   ито_, _hurs, шук_, юшка, 
   {{0x19940063,0x00000000,0x00000000,0x00000000}},	//   _мјер, --, --, --, 
   {{0x691402f8,0x7d1c01e4,0x2604000d,0x59841422}},	//   _všec, _jurs, हेली_, _флеб, 
   {{0x7ae40036,0xeea002dd,0x00000000,0x00000000}},	//   éitf, _ﺍﻷﻤﻥ_, --, --, 
   {{0x7d1c4dbc,0x7f4403f0,0xda1c000d,0x00000000}},	//   _lurs, jsiq, _पलात_, --, 
   {{0x7d1c4dbd,0xa3c00406,0x00000000,0x00000000}},	//   _ours, ्पज_, --, --, 
   {{0x7d1c4dbe,0x00000000,0x00000000,0x00000000}},	//   _nurs, --, --, --, 
   {{0xa3e41d72,0x7cf80077,0xfbbc00dc,0xf484411c}},	//   _बुक_, fírm, ्छाम, _رابی, 
   {{0x61fc030a,0x4ad802ab,0x7d1c08fb,0xeeb801b9}},	// [5150] _ezpl, _बदलव, _aurs, блаш_, 
   {{0x7d1c4dbf,0x6ef80ffb,0x6e280205,0x61400240}},	//   _burs, rìbo, _şebb, _ንግዝኣ, 
   {{0x6fdc2232,0x00000000,0x00000000,0x00000000}},	//   _यशवं, --, --, --, 
   {{0x7d1c4dc0,0x2fcc00f3,0xe80c012c,0x7c940114}},	//   _durs, _žegu_, ाइमा_, дршц, 
   {{0xfb244dc1,0x00000000,0x00000000,0x00000000}},	//   وروپ, --, --, --, 
   {{0x7d1c4dc2,0x94f8025c,0x6f1c0393,0x38b8035b}},	//   _furs, _ནེའི_, _iusc, _réra_, 
   {{0x6f1c4dc3,0x69140327,0x201c0276,0x7d1c4dc4}},	//   _husc, _aġer, _ştii_, _gurs, 
   {{0x6d444dc5,0xe7384dc6,0x38b84dc7,0x6f1c0ade}},	//   msha, беи_, _péra_, _kusc, 
   {{0x6d444dc8,0x24881772,0xfaec00fb,0x00000000}},	//   lsha, _ሕማማት_, _аҫ_, --, 
   {{0x38b80129,0x6d444dc9,0x7d1c01d5,0xbb8401e2}},	//   _véra_, osha, _yurs, _زلمي, 
   {{0x6d444dca,0x6f140369,0x7d1c036b,0x6e240e78}},	//   nsha, _mizc, _xurs, ichb, 
   {{0x6d444dcb,0x7f4420ef,0xf2c800c8,0x6f1c0221}},	//   isha, ysiq, _גע_, _ousc, 
   {{0x6f1c07de,0x6d444dcc,0xd36c143e,0xe618034f}},	//   _nusc, hsha, ههَ_, _лдл_, 
   {{0x6f140055,0x00000000,0x00000000,0x00000000}},	//   _nizc, --, --, --, 
   {{0xa5084dcd,0xc7ac1893,0x16841acf,0x21a40120}},	//   _лека_, _سڑک_, _راوێ, чивм, 
   {{0x6f1c4dce,0x6d444dcf,0x7d1c0483,0x80cc0490}},	//   _busc, dsha, _rurs, _सगळे, 
   {{0x7d1c4dd0,0x6f1c4dd1,0x6d444dd2,0x6f144dd3}},	// [5160] _surs, _cusc, esha, _bizc, 
   {{0x6f1c4dd4,0x6d444dd5,0x6f140369,0x7d1c4dd6}},	//   _dusc, fsha, _cizc, _purs, 
   {{0x7f444dd7,0x6f1c3512,0x6f1400b5,0x1278008f}},	//   ssiq, _eusc, _dizc, _פאטע, 
   {{0x6f1c4dd8,0x7d1c4dd9,0x6e244dda,0xdcec00ef}},	//   _fusc, _vurs, achb, _irbī, 
   {{0x6d444ddb,0x6f1c0395,0xfe7000dd,0x7d1c4ddc}},	//   asha, _gusc, _لگا_, _wurs, 
   {{0x6d444ddd,0x9d442369,0xdde81bf4,0x00000000}},	//   bsha, _негд, _هرزه_, --, 
   {{0x6f1c4dde,0x7d1c4ddf,0x6d444de0,0xe5cc010e}},	//   _zusc, _uurs, csha, _çeňň, 
   {{0x4dd80302,0xd7f84de1,0x090000c7,0x00000000}},	//   _החלו, йуп_, нчым, --, 
   {{0x6f140369,0x7c240113,0xb8f407f7,0xb9041be1}},	//   _yizc, ñiru, _हग_, _नद_, 
   {{0x35b44de2,0x2ba80037,0xdcec0171,0x66700116}},	//   дбор, कहरा, _orbī, نگىر, 
   {{0x64580024,0x00000000,0x00000000,0x00000000}},	//   ėtin, --, --, --, 
   {{0x691427c4,0x2eb84de3,0x4df8011a,0x00000000}},	//   _tšea, _इत्त, מפיא, --, 
   {{0xb6c402de,0x38b84de4,0xd7040a8f,0x00000000}},	//   _жөнд, _héro_, _езди, --, 
   {{0x6f1c4de5,0x6d444de6,0x46a04031,0x00000000}},	//   _rusc, ysha, _пачв, --, 
   {{0x6f1c4de7,0x38b8020c,0x6d4411f2,0x6914013a}},	//   _susc, _jéro_, xsha, _mšen, 
   {{0x6f144de8,0x6f1c4de9,0x6d44036b,0x3dc40154}},	//   _sizc, _pusc, vsha, ্থাল, 
   {{0x6d444dea,0x6f144deb,0xc5144dec,0x6e244ded}},	// [5170] wsha, _pizc, _ثبوت, tchb, 
   {{0x6d444dee,0x6f1c1570,0x6e241a80,0x7cf800bc}},	//   tsha, _vusc, uchb, bírk, 
   {{0x6e244def,0x6d444df0,0x6f144df1,0x6f1c4df2}},	//   rchb, usha, _vizc, _wusc, 
   {{0x6e244df3,0x6d444df4,0x00000000,0x00000000}},	//   schb, rsha, --, --, 
   {{0x6d444df5,0x6f1400b5,0x38b806af,0xfb340830}},	//   ssha, _tizc, _aéro_, енчэ, 
   {{0x6d444df6,0x3d18000d,0x00000000,0x00000000}},	//   psha, _बूके_, --, --, 
   {{0xdbd80798,0x6d444df7,0x9c6401e1,0x601803e0}},	//   rçár, qsha, _às̟à_, şüşü_, 
   {{0xa3e4375c,0x691400ef,0xd6cc00f1,0x6b744df8}},	//   _बुझ_, _ešen, یقي_, _олбу, 
   {{0xf708001e,0x7cf800bc,0x00000000,0x00000000}},	//   _hủy_, zírk, --, --, 
   {{0xa524014b,0x779003c7,0x4a24030d,0x00000000}},	//   ммод, ایوا, _хьаб, --, 
   {{0xa5084df9,0x7ae44dfa,0x00000000,0x00000000}},	//   жена_, éite, --, --, 
   {{0x2d9008ad,0x7cf80118,0xc5b000db,0xf73800e5}},	//   _mrze_, vírk, _үркө, _کيوں_, 
   {{0x38b84dfb,0x996001ef,0x00000000,0x00000000}},	//   _zéro_, _víťa_, --, --, 
   {{0x9f54004a,0x1b180011,0x649000ef,0x00000000}},	//   _âgés_, নীকে_, džiņ, --, 
   {{0xddcc025c,0x00000000,0x00000000,0x00000000}},	//   _qabż, --, --, --, 
   {{0x94c8004b,0x70f400d4,0xe7b0000d,0x7bdc0055}},	//   _وايې_, ечує, _जथाप, _śrum, 
   {{0x2d900295,0x98a44dfc,0x2d8400f3,0x1e844dfd}},	// [5180] _arze_, žiće_, _šlep_, млам, 
   {{0x2d900989,0x7cf803da,0x672c036e,0x81e000cc}},	//   _brze_, pírk, _çaju, _তৰণ_, 
   {{0x201c084c,0x9fa0002e,0x7cf80798,0xe3b04689}},	//   _ştiu_, _këër_, líri, _سرک_, 
   {{0x2d9008ad,0xa3e01b51,0x3ce00254,0x00000000}},	//   _drze_, _दशा_, õiv_, --, 
   {{0x8c404dfe,0x38b84dff,0xdf600022,0x10a001af}},	//   тече, _séro_, _шҭақ, _риян, 
   {{0x38b84e00,0xf54000d0,0x00000000,0x00000000}},	//   _péro_, úťky_, --, --, 
   {{0x7c240789,0x2d90033f,0x7af80175,0x7cf800ae}},	//   ñirs, _grze_, rlvt, híri, 
   {{0x52b81d94,0x999c00b8,0x38b84e01,0xb4ac0243}},	//   _उत्स, _hetū_, _véro_, _गवे_, 
   {{0x8c400046,0x691401ee,0x660c01e4,0x6b8c01bf}},	//   _шете, _tšen, _ĝaka, åagt, 
   {{0xc6f42ecc,0x0ccc4251,0x2000009f,0x660c0115}},	//   мных_, িকৃত, _mzki_, _ŝaka, 
   {{0x186803b7,0x8e5408a8,0xa2a0085c,0x9848011c}},	//   _мажи_, וייג_, खान्, _дяла_, 
   {{0x7cf8007b,0x20000427,0x6d8c010e,0x00000000}},	//   fíri, _ozki_, _ỳaky, --, 
   {{0x07a00124,0x7cf802d2,0x00000000,0x00000000}},	//   _иацн, gíri, --, --, 
   {{0x164400f1,0x00000000,0x00000000,0x00000000}},	//   _کړکۍ_, --, --, --, 
   {{0x26d8013f,0x80c80154,0xbbbc243c,0x00000000}},	//   ɑso_, রচন্, ्छुक, --, 
   {{0x92dc0729,0x2b48110c,0x92cc0f22,0x30142b97}},	//   ততে_, šaci_, ষকে_, едбр, 
   {{0xeeb81638,0x00000000,0x00000000,0x00000000}},	// [5190] плаш_, --, --, --, 
   {{0x2d90012d,0x2604302b,0x00000000,0x00000000}},	//   _prze_, हेकी_, --, --, 
   {{0x741438b7,0x2ab8007f,0xbf140116,0xf7080051}},	//   _توکا, _sèbo_, түрә, _qủy_, 
   {{0xfc304e02,0xebc40166,0x91b401a9,0xfce80472}},	//   لحه_, нәзн, _еҳҳт_, وفلي_, 
   {{0xea94010b,0x2b480129,0x00000000,0x00000000}},	//   ешйэ, éac_, --, --, 
   {{0xf708004d,0xc33400d9,0x691400ef,0x9b9001e2}},	//   _tủy_, דוס_, _ešel, الوت, 
   {{0x8c641c00,0x00000000,0x00000000,0x00000000}},	//   _отад, --, --, --, 
   {{0x69140232,0xe73800c7,0xe7a80021,0xb9083cc6}},	//   _všeo, пеи_, звил_, وزيم_, 
   {{0x7ae40036,0x38c401e1,0x38b800e5,0x81e000fe}},	//   éitc, _sèrù_, _kérj_, _তৰা_, 
   {{0xd7041c31,0x2cac4e03,0x64580024,0x8aa40006}},	//   нные_, _hoed_, ėtim, _ўрад, 
   {{0x2cac002d,0x7c240010,0x00000000,0x00000000}},	//   _koed_, žire, --, --, 
   {{0x64a44e04,0x92dc00cc,0x7cf84e05,0x19b4010f}},	//   хама, ততো_, tíri, _אפער_, 
   {{0x2cac4e06,0x290c4e07,0x92cc03d4,0xe4c401c6}},	//   _moed_, mmea_, ষকৈ_, _үйли, 
   {{0x2cac4e08,0x290c4e09,0x6e280790,0x7cf801e7}},	//   _loed_, lmea_, _şebn, ríri, 
   {{0x91e00e58,0x3d1800af,0x00000000,0x00000000}},	//   горе, _बूझे_, --, --, 
   {{0x2cac0b21,0x00000000,0x00000000,0x00000000}},	//   _noed_, --, --, --, 
   {{0x290c0356,0x00000000,0x00000000,0x00000000}},	// [51a0] imea_, --, --, --, 
   {{0x64444e0a,0x0e6028b6,0x290c01a4,0x2a640100}},	//   laki, лкун, hmea_, _nclb_, 
   {{0xd00c00dd,0x2cac03cb,0x200002e2,0x56b4010f}},	//   للہ_, _boed_, _wzki_, עפען_, 
   {{0x2cac4e0b,0x5c044e0c,0x10a00166,0x629000d7}},	//   _coed_, няла, _биюн, škoľ, 
   {{0x691402fb,0x2d8000b0,0x2cac0042,0x7c2402d1}},	//   _všel, awhe_, _doed_, ñirq, 
   {{0x64444e0d,0x60d44e0e,0x00000000,0x00000000}},	//   haki, liym, --, --, 
   {{0x64444e0f,0xad2401d5,0x69140064,0x08f44e10}},	//   kaki, _لرقو, _išej, کروب_, 
   {{0x2cac27c0,0x97a41313,0x672c031c,0x60d401d5}},	//   _goed_, ерол, _ħajr, niym, 
   {{0x64444e11,0x274c0092,0x5ac80354,0xac940244}},	//   daki, _በቁርጠ, _елам_, _جۆنا_, 
   {{0x290c4e12,0x64444e13,0x60d44e14,0x00000000}},	//   amea_, eaki, hiym, --, 
   {{0x64444e15,0x60d40309,0xbb440166,0x00000000}},	//   faki, kiym, _ğäyä, --, 
   {{0x64444e16,0xd7e40a4a,0x18680117,0xbb440139}},	//   gaki, _піло, _хади_, _şäyä, 
   {{0x60d40042,0x439401f4,0x00000000,0x00000000}},	//   diym, гаяс, --, --, 
   {{0x64441b99,0x00000000,0x00000000,0x00000000}},	//   aaki, --, --, --, 
   {{0x6464023a,0x116401d5,0x672c0200,0x00000000}},	//   ätiö, علری_, _çajr, --, 
   {{0x64444e17,0x00000000,0x00000000,0x00000000}},	//   caki, --, --, --, 
   {{0xf1b800da,0xb4dc0490,0x2cac4e18,0x3014144d}},	// [51b0] ņš_, णची_, _roed_, тдар, 
   {{0x2cac002d,0xe5b401e1,0x00000000,0x00000000}},	//   _soed_, _ńyẹ́, --, --, 
   {{0x2cac00c5,0x60d40205,0x81d4014b,0x00000000}},	//   _poed_, biym, _боэх, --, 
   {{0xec140502,0x0ccc02f5,0xc5f0008f,0xa134010f}},	//   نواد, িক্ত, אדע_, _שארק_, 
   {{0x2cac05e4,0xbc184e19,0x2a640051,0x600800e5}},	//   _voed_, ніші_, _pclb_, römé, 
   {{0x64444e1a,0x691400bc,0x2cac4e1b,0x8bc40124}},	//   zaki, _všem, _woed_, _ҧсад, 
   {{0x644441d0,0x2cac1caa,0x7ae40077,0xe9a4187b}},	//   yaki, _toed_, éita, тайп, 
   {{0x2918049f,0x290c0421,0x660c0115,0x394c02c2}},	//   ösa_, umea_, _ŝako, _dvds_, 
   {{0x64444e1c,0x290c4e1d,0xb0c806ab,0x57404e1e}},	//   vaki, rmea_, _रतनग, аныб, 
   {{0x290c0048,0xa6944c70,0x6934036b,0x9c2801ec}},	//   smea_, триј, _анжу, _ﺷﯩﻌﯟ_, 
   {{0x64444e1f,0xb9540137,0x8934007b,0xbb440139}},	//   taki, _مئنت, _أعطا, _şäxä, 
   {{0x6498013e,0x81e000eb,0x00000000,0x00000000}},	//   фтор_, _তরল_, --, --, 
   {{0x64444e20,0x999c00e4,0x60d4022e,0x73740124}},	//   raki, _retũ_, viym, лырх, 
   {{0x64444e21,0xe28c022e,0x7cdc02b1,0x60d40113}},	//   saki, _ekаn_, mōre, wiym, 
   {{0xa0684e22,0x6ef80268,0x60d40113,0x213c068c}},	//   мава_, nìbu, tiym, èth_, 
   {{0x64440a73,0xe0d802bf,0x50a000d1,0x00000000}},	//   qaki, єва_, لەپل, --, 
   {{0x44204e23,0x2fc84e24,0x60d403f0,0xff244e25}},	// [51c0] _igi_, gzag_, riym, ابری, 
   {{0x26c40af2,0x60d44e0e,0x00000000,0x00000000}},	//   nhlo_, siym, --, --, 
   {{0x2b4c4e26,0x629c4e27,0x442001bf,0xdc680107}},	//   _avec_, _inpo, _kgi_, даед_, 
   {{0x7cdc04fe,0x39ac013b,0x60d40113,0x629c00d0}},	//   kōre, wɛso_, qiym, _hnpo, 
   {{0x44204e28,0x660c00df,0x628c0af9,0x00000000}},	//   _mgi_, _ŝakl, odbo, --, 
   {{0x4420207a,0x7cf84e29,0xdddc02b5,0xdee4014b}},	//   _lgi_, víru, nepū, _роги, 
   {{0x44204e2a,0x26c44e2b,0xd8383f3a,0xae0401af}},	//   _ogi_, dhlo_, мэп_, _борҙ, 
   {{0x44204e2c,0x38b801d3,0x7cf800e5,0x00000000}},	//   _ngi_, _kéri_, gírt, --, 
   {{0x629c4e2d,0xdddc00b0,0xb6f40063,0xbb44013d}},	//   _onpo, kepū, лзиј, _şäfä, 
   {{0x628c01f5,0x00000000,0x00000000,0x00000000}},	//   jdbo, --, --, --, 
   {{0xb8e803f4,0xceb005e1,0x44200a2e,0x75d44e2e}},	//   _ঈদ_, ייז_, _bgi_, ايجا, 
   {{0x4420074d,0x628c4e2f,0x629c4e30,0xed740020}},	//   _cgi_, edbo, _anpo, _አጋጣሚ_, 
   {{0x44204e31,0x628c01f5,0xb92400cd,0x00000000}},	//   _dgi_, fdbo, _duḥś, --, 
   {{0x44204e32,0x26c401f1,0x6b9c0008,0x628c282c}},	//   _egi_, chlo_, _ásge, gdbo, 
   {{0x34944e33,0x76484e34,0xe72c04d3,0x55040276}},	//   _байр, mady, _وڵی_, _ичиа, 
   {{0x629c4e35,0x76484e36,0x44201418,0x36d400d1}},	//   _enpo, lady, _ggi_, _шоһр, 
   {{0x38b8002e,0xb4c005f9,0x798803ac,0xd5e0033f}},	// [51d0] _céri_, ूफी_, _lsdw, _पशुओ, 
   {{0x76484e37,0xfe7019f9,0x6ab001ad,0x2fc801f5}},	//   nady, قدم_, _झवेर, rzag_, 
   {{0x5e64198a,0x00000000,0x00000000,0x00000000}},	//   انمە, --, --, --, 
   {{0x38b8003e,0x776001e2,0x442001ab,0xdde00309}},	//   _féri_, kumx, _xgi_, ñušq, 
   {{0x629c000f,0x798803ac,0x76484e38,0x7cf80005}},	//   _ynpo, _asdw, kady, vírt, 
   {{0x69140006,0x798802d0,0x660c01e4,0xad240d1f}},	//   _išei, _bsdw, _ŝakm, _مىسى, 
   {{0x7bcc013f,0xe8f80120,0xbd68030d,0x76484e39}},	//   _ɑnuɑ, нлк_, _ирте_, dady, 
   {{0x7cdc02b5,0x76480076,0x00000000,0x00000000}},	//   tōre, eady, --, --, 
   {{0x77600921,0x798802d0,0x44200254,0x628c01bf}},	//   gumx, _esdw, _rgi_, ydbo, 
   {{0x6b884e3a,0x76484e3b,0xba742756,0x44204e3c}},	//   _iseg, gady, _نامت, _sgi_, 
   {{0x7cf80789,0x798803ac,0x26c402f0,0xa2a004e4}},	//   círs, _gsdw, rhlo_, खास्, 
   {{0x7cdc02b1,0x26c44e3d,0x00000000,0x00000000}},	//   pōre, shlo_, --, --, 
   {{0x765c006d,0x76484e3e,0x6b880135,0x00000000}},	//   óryc, bady, _jseg, --, 
   {{0x628c01f5,0x291c4e3f,0x76484e40,0x00000000}},	//   udbo, _hiwa_, cady, --, 
   {{0x27284e41,0x4420060a,0x291c4e42,0x672802d3}},	//   _hún_, _tgi_, _kiwa_, lqej, 
   {{0x291c4e43,0x44201060,0x27280cad,0x65604e44}},	//   _jiwa_, _ugi_, _kún_, mulh, 
   {{0x27283841,0x291c4e45,0x6b884e46,0x691400bc}},	// [51e0] _jún_, _miwa_, _nseg, _všeh, 
   {{0x291c1aac,0x272827b7,0x00000000,0x00000000}},	//   _liwa_, _mún_, --, --, 
   {{0x6b884e47,0x691401af,0x27284e48,0x660c01e4}},	//   _aseg, _tšeh, _lún_, _ŝakj, 
   {{0x1b484e49,0x9b681d83,0x291c4e4a,0x27280241}},	//   езди_, ешка_, _niwa_, _oún_, 
   {{0x65604e4b,0xd12c1c93,0x7cdc0427,0x798803ac}},	//   hulh, _ومی_, dčrt, _ssdw, 
   {{0x291c0433,0x97a42097,0x61fc0c90,0xbb440724}},	//   _aiwa_, ғрил, _kypl, _ğädä, 
   {{0x27284e4c,0x6b884e4d,0x291c18f7,0x80b81d8a}},	//   _aún_, _eseg, _biwa_, _इकाइ, 
   {{0x291c23f0,0x37e800bd,0x61fc4cff,0x272827b7}},	//   _ciwa_, _পরবর, _mypl, _bún_, 
   {{0x291c4e4e,0x94840046,0x272801fb,0xdb1c005b}},	//   _diwa_, қынд, _cún_, öväe, 
   {{0x27284e4f,0x291c166a,0x6af000aa,0xa9b01682}},	//   _dún_, _eiwa_, _وګور, ṱuṱu, 
   {{0x291c4e50,0x76484e51,0x65604e52,0x7988035a}},	//   _fiwa_, rady, gulh, _usdw, 
   {{0x27284e53,0x76484e54,0x291c4e55,0x26d816b0}},	//   _fún_, sady, _giwa_, ésor_, 
   {{0x76480a28,0x88f00014,0x6560067c,0x61fc0c8c}},	//   pady, _آنت, aulh, _aypl, 
   {{0x291c0451,0x51844e56,0x65604e57,0x00000000}},	//   _ziwa_, луба, bulh, --, 
   {{0x291c23db,0x69301140,0xd1b81c3e,0x6560068c}},	//   _yiwa_, _vāeg, راسا_, culh, 
   {{0xb0344e58,0x61fc033f,0xfbc411bc,0x27280248}},	//   рнаш, _dypl, वनाम, _yún_, 
   {{0x2728004d,0x60d802e2,0x00000000,0x00000000}},	// [51f0] _xún_, ètma, --, --, 
   {{0x4ea44e59,0x00000000,0x00000000,0x00000000}},	//   ырба, --, --, --, 
   {{0xc0f002d3,0x91d00183,0xff044e5a,0x6b884e5b}},	//   ሂሎም_, _দুৰ্, сятн, _sseg, 
   {{0x82344e5c,0xdfd00451,0xb5044a01,0x6288148b}},	//   _پریا, _ڀيٽ_, रतिय_, _ófor, 
   {{0x291c0083,0x395c07c5,0xdb244e5d,0x65600165}},	//   _riwa_, ervs_, لونی, zulh, 
   {{0x27284e5e,0x291c4e5f,0x6b88151c,0x5fa00131}},	//   _rún_, _siwa_, _vseg, _بەكم, 
   {{0x7bdc0a28,0x27280ca8,0x291c4e60,0xd9400108}},	//   _śrut, _sún_, _piwa_, оещи, 
   {{0x291c4e61,0x6b884e62,0x272821eb,0x61f80037}},	//   _qiwa_, _tseg, _pún_, ütli, 
   {{0x291c4e63,0x6b884e64,0x574400c7,0x395c04cc}},	//   _viwa_, _useg, азым_, arvs_, 
   {{0x65604e65,0x291c0cad,0xa6980114,0xdb240345}},	//   tulh, _wiwa_, тњих_, _ئولی, 
   {{0x36940046,0x64a44e66,0xe85402e9,0x291c4e67}},	//   сшыс, аана, _نناد, _tiwa_, 
   {{0x27280570,0x65604e68,0x23282308,0x6aa002d2}},	//   _tún_, rulh, коми_, _hnlf, 
   {{0x38b8002e,0x7ddc05ac,0xa2a0012c,0x22480051}},	//   _céru_, _kåsø, खाल्, tabk_, 
   {{0x38b800e8,0x61fc1979,0x656000d8,0x00000000}},	//   _déru_, _pypl, pulh, --, 
   {{0x61440a31,0xa3e006e3,0x602400d1,0x7ddc03cd}},	//   реба, _दशक_, идва, _måsø, 
   {{0x61fc278a,0x91e000d6,0x7cdc02b5,0x00000000}},	//   _vypl, іоте, kōra, --, 
   {{0x6aa0058a,0x61fc012d,0x00000000,0x00000000}},	// [5200] _onlf, _wypl, --, --, 
   {{0xe2984e69,0x1ea80592,0x395c0076,0x8ec40139}},	//   _рао_, خاري_, yrvs_, агуб_, 
   {{0x5d6800c9,0x9c24119e,0x21a401b9,0x38b801d3}},	//   тием_, адед, _тинм, _kért_, 
   {{0x0c2000fb,0xbb44013d,0x00000000,0x00000000}},	//   ҙмән, _ğäbä, --, --, 
   {{0x60c4035a,0x28a81223,0x38b801d3,0x0c200ce8}},	//   _ilkm, कानि, _mért_, әмән, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdd904e6a,0x98c44e6b,0x9f0400db,0xdd14453c}},	//   _بوز_, исил, _موڭو, _نوسخ, 
   {{0x64544e6c,0xb4c40882,0x25f800e1,0x00000000}},	//   _ndyi, _एते_, _उड़ी_, --, 
   {{0x6e280205,0x00000000,0x00000000,0x00000000}},	//   _şebi, --, --, --, 
   {{0x645402c4,0x597411db,0x6b9c08ce,0x6ea84e6d}},	//   _adyi, _выду, _ásga, घायु, 
   {{0x95c8223e,0x60c402d0,0x38b801ef,0x00000000}},	//   тупа_, _olkm, _séru_, --, 
   {{0x38b84e6e,0xd7f80276,0xd90c07d6,0x7af84e6f}},	//   _péru_, _иул_, _تیب_, lovt, 
   {{0xd4040075,0xe794168d,0x00000000,0x00000000}},	//   ряни, _هاوک, --, --, 
   {{0x60c44e70,0x7af84e71,0x1dc4276a,0x3170020c}},	//   _alkm, novt, लनात, ttzz_, 
   {{0x2d844e72,0x38b8002e,0x7cf40139,0x69140306}},	//   _álex_, _wéru_, _kürğ, _všev, 
   {{0x63a0005f,0x38b8002e,0xb6400150,0x53440354}},	//   _šone, _téru_, _ﺃﻟ_, _кхоа, 
   {{0x8e240107,0x1ee8136e,0x00000000,0x00000000}},	// [5210] афед, گولی_, --, --, 
   {{0x660c0115,0x705400f2,0x00000000,0x00000000}},	//   _ŝaki, _گچسا, --, --, 
   {{0x7af80998,0x51844e73,0x1ee80ee8,0x00000000}},	//   dovt, _тупа, دولی_, --, 
   {{0x7cdc02b1,0x27e802d2,0x00000000,0x00000000}},	//   tōra, _þang_, --, --, 
   {{0xb4c40037,0x207800df,0x7f58010a,0xbb44008e}},	//   _एतै_, _גארא, _каяс_, _ğäcä, 
   {{0x28a82e35,0xbb44013d,0xeec4009f,0x00000000}},	//   काभि, _şäcä, _ايسپ, --, 
   {{0xba744e74,0x69140232,0x9f480428,0x1ee84e75}},	//   تانت, _ošet, _òmòg_, _صوفی_, 
   {{0x7cdc02b5,0xdb080118,0xfc3000ae,0x00000000}},	//   pōra, ěnár, _يحق_, --, 
   {{0x28a81524,0x46600131,0x2a7000a2,0xed58190b}},	//   काबि, قۇشق, _özbo_, _шоң_, 
   {{0x38b801a8,0xfbd001d9,0x9f400108,0x00000000}},	//   _sért_, _کتہ_, _tykö_, --, 
   {{0x80d80d0d,0x00000000,0x00000000,0x00000000}},	//   नोडे, --, --, --, 
   {{0xe7984e76,0x2bbc11bc,0x00000000,0x00000000}},	//   _مختص_, ्नपा, --, --, 
   {{0xd2a40032,0xc7a84e77,0x86b00150,0x38b800e5}},	//   әксе_, _جدال_, _дәні, _vért_, 
   {{0x21684e78,0x46600150,0xf66400db,0xf770009a}},	//   лиги_, _بۇدق, _дешү, _زاه_, 
   {{0xf1b000b2,0x21040014,0x38b84e79,0x00000000}},	//   وءِ_, مبرَ, _tért_, --, 
   {{0x25704e7a,0x7cf400fd,0x64544e7b,0x602401c6}},	//   mál_, _kürş, _udyi, сдаа, 
   {{0x8fa04e7c,0x543800c8,0x4fa00801,0x60084e7d}},	// [5220] пате, _געפא, питв, унам_, 
   {{0x38b800e8,0x7cf44e7e,0x53c400db,0x00000000}},	//   _jérr_, _mürş, _ыгым_, --, 
   {{0x257028cb,0xa068010b,0x690400e5,0x00000000}},	//   nál_, _йана_, tóel, --, 
   {{0xfc380588,0xd5f8010f,0x712402f2,0x61f80254}},	//   рҭа_, אפער, _گریل, ütlu, 
   {{0x257000d0,0xd91800c7,0x00000000,0x00000000}},	//   hál_, қьк_, --, --, 
   {{0x2570429f,0xdb2401b9,0x00000000,0x00000000}},	//   kál_, لوچی, --, --, 
   {{0x1c382401,0xed343163,0x00000000,0x00000000}},	//   _бязь_, _мэтэ, --, --, 
   {{0x2570102c,0x3734013e,0x7cf4372c,0x7af80455}},	//   dál_, ониё, _bürş, sovt, 
   {{0x4ae000f1,0xb4c400cd,0x5fdc01f9,0x00000000}},	//   _کړنل, _एतौ_, _नेमल, --, 
   {{0x21200af2,0x7e7c007f,0x38b817ed,0x257001e7}},	//   _likh_, _jbrp, _pérs_, fál_, 
   {{0x257028bb,0xb7d801d3,0x200002d2,0x00000000}},	//   gál_, _ھوتا_, _lyki_, --, 
   {{0x320000d7,0xb7d84e7f,0xa50400c7,0x00000000}},	//   _ryhy_, _پوتا_, ҩҵәа_, --, 
   {{0x69143351,0xf49002d3,0x00000000,0x00000000}},	//   _všet, _ዝዛረብ_, --, --, 
   {{0x776008a5,0x7ae40597,0xf8840014,0x320039cb}},	//   mrmx, éith, _دٔچُ, _pyhy_, 
   {{0x20004e80,0x693002b1,0x66cc0162,0x690400e5}},	//   _ayki_, _kāea, _búkf, zóem, 
   {{0x69140232,0x1cc00156,0xa5600014,0x2bbc2e35}},	//   _ušet, གིས_, _کۯێن, ्नमा, 
   {{0x7e7c020b,0x2900016b,0xd51400ec,0x00000000}},	// [5230] _bbrp, _ɔha_, _پڙھڻ_, --, 
   {{0x0dc80022,0xdbe000cc,0x00000000,0x00000000}},	//   луеи_, _বৰ্ফ, --, --, 
   {{0x21204e81,0x2000004d,0xfb240131,0x7bdc0055}},	//   _fikh_, _eyki_, ۋروپ, _śrup, 
   {{0xe9a80502,0x7ae401e4,0x00000000,0x00000000}},	//   یگان_, ɩiti, --, --, 
   {{0x765802fb,0x447808a8,0x257000e5,0x00000000}},	//   _odvy, מעאל_, zál_, --, 
   {{0x25704e82,0x41744e83,0xaa443866,0xa9a4010b}},	//   yál_, _بایس, цекл, жикд, 
   {{0xd6cc009e,0x25700548,0x7cf400a2,0x20000166}},	//   িচায, xál_, _sürş, _zyki_, 
   {{0x7658045f,0x257001ed,0x69140171,0x00000000}},	//   _advy, vál_, _ašer, --, 
   {{0x24900221,0x1a7804f2,0x00000000,0x00000000}},	//   _raym_, _چشمک_, --, --, 
   {{0x257028cb,0x24900076,0xe5784e84,0xca744e85}},	//   tál_, _saym_, азо_, _دارغ, 
   {{0xfaa800ec,0xb0c82d6b,0x28a800dc,0x00000000}},	//   _دهلي_, रसाग, कादि, --, 
   {{0x69144e86,0x224c00f3,0xdddc054e,0xf40403d4}},	//   _všes, _žfk_, lepţ, ৰখনৰ_, 
   {{0x23284e87,0x68e84e88,0x225c033f,0x74f801c6}},	//   роги_, mned, ótko_, сээс_, 
   {{0x20004e89,0x00e40150,0x00000000,0x00000000}},	//   _ryki_, _ﺍﻓﺘﺘ, --, --, 
   {{0x691409a8,0x24904e8a,0x2568074d,0x71f80014}},	//   _ušes, _taym_, _тайп_, مرِس_, 
   {{0x10a04e8b,0x232800f3,0x00000000,0x00000000}},	//   мисн, _коии_, --, --, 
   {{0x68e8127b,0x6d5402ac,0x7c240010,0x412800fb}},	// [5240] ined, _avza, žirk, роғо_, 
   {{0x68e84e8c,0x7cdc00b0,0x1aec0154,0x9e644e8d}},	//   hned, tōro, _চীনে_, تارن, 
   {{0x527804ae,0x68e84e8e,0x5d842f84,0x00000000}},	//   _דניא, kned, تلال, --, 
   {{0x5bc40aaf,0xe7c84e8f,0x8c40119e,0x3cf40210}},	//   يقال, िनाप, деце, इकें_, 
   {{0x6d5401fa,0x9e64009f,0x7e78008e,0xe7d8190e}},	//   _evza, _واسن, _гәет_, _बेलप, 
   {{0xec1004a9,0xf1a803e6,0x7cdc00b0,0x6f0401ab}},	//   رۈلد, _ئایه_, pōro, clhc, 
   {{0x693000b0,0x3eb800a3,0x765c033f,0x7b9800e5}},	//   _pāea, _iort_, órym, _گھاس_, 
   {{0xed344e90,0x68e84e91,0x3eb84e92,0x91b80375}},	//   _хэрэ, gned, _hort_, ימצי, 
   {{0x3eb81455,0x1ae4084c,0x75380112,0x1a58009f}},	//   _kort_, _доам, _stvz, _نشاة_, 
   {{0xdddc084c,0x3eb81bce,0x68e80142,0x3ae800f2}},	//   cepţ, _jort_, aned, _ابری_, 
   {{0x3eb84e93,0x68e84e94,0x691401ef,0x0e98011a}},	//   _mort_, bned, _všer, בשיל, 
   {{0x693002b5,0x3eb84e95,0x63a04e96,0x00000000}},	//   _kāen, _lort_, _šona, --, 
   {{0x691427c4,0x37c40032,0x660c00df,0xdc000118}},	//   _tšer, _хәйб, _ŝakt, _očíc, 
   {{0x693002b1,0xd5b80395,0x255400ef,0x2bbc193d}},	//   _māen, _вси_, bāl_, ्नता, 
   {{0xf0e80058,0x00000000,0x00000000,0x00000000}},	//   مىسى_, --, --, --, 
   {{0x1cd00327,0x3eb80205,0x00000000,0x00000000}},	//   ོ༵ས_, _aort_, --, --, 
   {{0x3eb84e97,0x6f040978,0x00000000,0x00000000}},	// [5250] _bort_, tlhc, --, --, 
   {{0x3eb84e98,0x3f14024c,0xed500050,0x68e84e99}},	//   _cort_, ддус, ٹھس_, zned, 
   {{0x3eb84e9a,0x68e80cfd,0xcc800150,0x00000000}},	//   _dort_, yned, _ﺭﻤﻭﺯ_, --, 
   {{0xfd1040ab,0x00000000,0x00000000,0x00000000}},	//   نجن_, --, --, --, 
   {{0x68e84e9b,0x3eb84e9c,0x248400e8,0x3bd400d1}},	//   vned, _fort_, _ñome_, ۋغۇس, 
   {{0x3eb84e9d,0x68e8115d,0x00000000,0x00000000}},	//   _gort_, wned, --, --, 
   {{0x7d0005da,0x68e812e8,0x00000000,0x00000000}},	//   _fkms, tned, --, --, 
   {{0x3eb80221,0x68e84e9e,0x4dc003d4,0x2bbc0b02}},	//   _zort_, uned, ্পদং, ्नदा, 
   {{0x68e84e9f,0x66e41342,0x3eb80724,0x3b544ea0}},	//   rned, зопа, _yort_, _октр, 
   {{0xdddc4ea1,0x68e84174,0x3eb8025c,0xdbc40254}},	//   lepš, sned, _xort_, tööa, 
   {{0xe5a44ea2,0xba7434b1,0x68e800d4,0x00000000}},	//   чини, _تاقت, pned, --, 
   {{0x2d900210,0x00000000,0x00000000,0x00000000}},	//   _msze_, --, --, --, 
   {{0xa71402dd,0xd5ac0244,0x00000000,0x00000000}},	//   _емді, نفی_, --, --, 
   {{0x2d900036,0x28a8185d,0x00000000,0x00000000}},	//   _osze_, कावि, --, --, 
   {{0x27442776,0x253801e2,0x00000000,0x00000000}},	//   bênî_, _استخ_, --, --, 
   {{0x3eb84ea3,0xdddc1f7f,0x55b80302,0x7c240010}},	//   _sort_, jepš, _למצו, žiri, 
   {{0x3eb84ea4,0x1f644ea5,0xc540001f,0xa0a400c7}},	// [5260] _port_, якам, _የተባሉ, _ҵанд, 
   {{0xd00c0411,0x26c40006,0x3eb8013d,0x5398010f}},	//   الك_, nklo_, _qort_, _פייו, 
   {{0x3eb84745,0x00000000,0x00000000,0x00000000}},	//   _vort_, --, --, --, 
   {{0x3eb84ea6,0x693002b5,0x20400133,0x5ba800db}},	//   _wort_, _pāen, _سکرێ, йкем_, 
   {{0xcf8c01d9,0x4fa0030d,0xcb64009b,0x765c0210}},	//   _مژٕ_, _зияв, заче_, óryk, 
   {{0x80d80d2c,0xdc0001ef,0x3ad400ae,0x00000000}},	//   नोरे, _učíc, بيتز, --, 
   {{0x693000b0,0x00000000,0x00000000,0x00000000}},	//   _wāen, --, --, --, 
   {{0x830c0327,0x63a00135,0x7d00045a,0x26c400d7}},	//   _གེའུ_, _ġonn, _ukms, eklo_, 
   {{0x36d43246,0x95440092,0x9b444ea7,0x00000000}},	//   допр, _የተካተ, _رناو, --, 
   {{0xc7d4005b,0x95440092,0xfaa412fd,0x77440092}},	//   ямых_, _የተከተ, _تجری, _ያደረሰ, 
   {{0x59844ea8,0xceb0025f,0x28a84ea9,0x691401ee}},	//   _хлеб, תית_, काशि, _tšep, 
   {{0x2470010e,0x00000000,0x00000000,0x00000000}},	//   gцm_, --, --, --, 
   {{0x28a84eaa,0xcb0400cf,0x66cc00d7,0x00000000}},	//   कारि, _بيەن_, _súke, --, 
   {{0xbb44008e,0x00000000,0x00000000,0x00000000}},	//   _ğälä, --, --, --, 
   {{0x86780375,0x34944eab,0x00000000,0x00000000}},	//   _הרוו, _жайр, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x60540022,0x00000000,0x00000000,0x00000000}},	// [5270] ьетӡ, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x5fdc2ba2,0xf04417b9,0xf90c030d,0x00000000}},	//   _नेवल, _تعدی, _йоiа_, --, 
   {{0xa098011a,0xa2a00073,0x26c402f0,0x443c06be}},	//   _וירט, खाच्, yklo_, _əv_, 
   {{0xa9e4004b,0x00000000,0x00000000,0x00000000}},	//   وګان, --, --, --, 
   {{0x28a80316,0x00000000,0x00000000,0x00000000}},	//   कालि, --, --, --, 
   {{0x5a304eac,0xbc94009b,0x00000000,0x00000000}},	//   ннәт, _пасј, --, --, 
   {{0x248802d3,0x63a00327,0x80a001ad,0x26c402f0}},	//   _ዕማማት_, _ġono, _ऑफसे, tklo_, 
   {{0xd7040a8f,0x3a74188b,0x00000000,0x00000000}},	//   мные_, _плур, --, --, 
   {{0xba7410e0,0x26c4010f,0x2bbc4ead,0xe488009d}},	//   _سالت, rklo_, ्नवा, ойнд_, 
   {{0x26c42867,0xf2c80bd9,0x00000000,0x00000000}},	//   sklo_, _דע_, --, --, 
   {{0x1e084eae,0x66b40f32,0x08081a9b,0x9f580205}},	//   _वर्ष_, _обду, _ازاي_, üyüz_, 
   {{0x06904eaf,0x7b040ba1,0xa6c800ec,0x00000000}},	//   _ساتھ, sòuv, _گوڪل_, --, 
   {{0xbb440724,0xb0c836c7,0xdb2400ac,0x24f44eb0}},	//   _ğämä, रसंग, şqçi, _очир, 
   {{0x18400020,0xdfd005e6,0x9fc800d8,0xbb44013d}},	//   _የቀድሞ, نيز_, огба_, _şämä, 
   {{0xd0042e91,0x64440066,0xe2984eb1,0x00000000}},	// [5280] дете_, mbki, _дап_, --, 
   {{0x9d444eb2,0x13003596,0x0e604ae5,0x64440153}},	//   дежд, _изым, ккун, lbki, 
   {{0xe04401a9,0xc22400f2,0x00000000,0x00000000}},	//   _онни, _سکسو, --, --, 
   {{0x040400bd,0x00000000,0x00000000,0x00000000}},	//   রেণী_, --, --, --, 
   {{0x64440009,0xfe7000f2,0x00000000,0x00000000}},	//   ibki, _مگا_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xcc844eb3,0xa3bc1a2a,0x7cdc00b0,0xcac400c7}},	//   _обсе_, _इथं_, kōri, згәе_, 
   {{0x660c01e4,0x7ae43a35,0x0740005a,0x00000000}},	//   _ŝakp, éits, кхэм, --, 
   {{0xecb000c7,0x35b400a7,0x644400c0,0x00000000}},	//   _аӡәы, ебор, ebki, --, 
   {{0x27e800fc,0xcb10011a,0x00000000,0x00000000}},	//   _þann_, _סלע_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x38c8168d,0xb6c401c6,0x00000000,0x00000000}},	//   _واڵی_, _зөнд, --, --, 
   {{0x6444058a,0x0cc815e0,0x00000000,0x00000000}},	//   abki, _ात्म, --, --, 
   {{0x41e41fe2,0xfa14031c,0x00000000,0x00000000}},	//   віта, ིཟིན_, --, --, 
   {{0x64440009,0x93a401d5,0x34941eed,0xaf380107}},	//   cbki, _жшод, _чаир, ззаф_, 
   {{0x66cc4eb4,0xb9f80023,0xca6801ec,0x09d800cd}},	// [5290] _húka, _ሄግ_, шiлi, _बध्य, 
   {{0x66cc01a8,0x717800d8,0x69d4008e,0x00000000}},	//   _kúka, _ебор_, _üzeg, --, 
   {{0x66cc0162,0x1f240014,0x00000000,0x00000000}},	//   _júka, رِمہ, --, --, 
   {{0x213c00c6,0x2bbc00bc,0x6218011a,0x00000000}},	//   íthe_, ्नला, _מותק, --, 
   {{0x60d41203,0x6a840408,0x66cc4eb5,0xbc180212}},	//   _נושא_, елла, _lúka, міші_, 
   {{0x69940395,0xae442c37,0xb7e800fe,0x00000000}},	//   ерих, _سپرو, _পৰ্ট, --, 
   {{0x64440034,0x98bc0139,0x225c033f,0x7b04180f}},	//   ybki, _aqtı_, ótki_, vòut, 
   {{0x7ae40036,0xb60800d7,0x70bc000d,0x00000000}},	//   éitr, _mušľ, _ईवोल, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x66cc02d2,0x7b140064,0x00000000,0x00000000}},	//   _búka, _адух, --, --, 
   {{0xa5084eb6,0x2b4c0489,0x693002b5,0x36940220}},	//   зена_, _hwec_, _māek, тшыс, 
   {{0x7cdc04fe,0x66cc02d2,0xfb2400db,0x00000000}},	//   tōri, _dúka, _كرەپ, --, 
   {{0x7b04068c,0x64440153,0x33a801c6,0xdb240248}},	//   mòur, rbki, мъёо_, _ẹ̀kọ, 
   {{0x7cdc02b1,0x66cc4eb7,0xbb440139,0x1b7800df}},	//   rōri, _fúka, _şäkä, הטשע, 
   {{0xe5a40137,0x66040166,0x00000000,0x00000000}},	//   _чийи, _япка, --, --, 
   {{0x60240a31,0x7cdc02b5,0x00000000,0x00000000}},	//   едба, pōri, --, --, 
   {{0xd00c0491,0xf484009b,0x00000000,0x00000000}},	// [52a0] ملف_, _рујн, --, --, 
   {{0x5d443306,0x2e340241,0x9f0401e2,0x00000000}},	//   َّاك, _rúfó_, رواو, --, 
   {{0x628c4eb8,0xa3b84eb9,0x00000000,0x00000000}},	//   mebo, _ذاکر_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x63a001a6,0x39d800ab,0x10a00d1d,0xb60800d7}},	//   _šonj, _भेड़ि, _сиян, _zušľ, 
   {{0x7f444eba,0x00000000,0x00000000,0x00000000}},	//   mpiq, --, --, --, 
   {{0x98c400f3,0x00000000,0x00000000,0x00000000}},	//   еспл, --, --, --, 
   {{0x628c4ebb,0x693002b1,0x66cc0162,0xc0f001f3}},	//   hebo, _māeh, _rúka, ቀበሉ_, 
   {{0x7f4403f0,0xcb644d87,0x628c2e49,0x2ee003d4}},	//   npiq, _пате_, kebo, _ভৱিষ, 
   {{0x628c4ebc,0x7c2400f3,0x66cc08a5,0x481001ec}},	//   jebo, žirs, _púka, ымыс, 
   {{0xbb441248,0x628c4ebd,0x18a4014b,0x00000000}},	//   _şähä, debo, _пажм, --, 
   {{0x7f440309,0x7bdc00b8,0x00000000,0x00000000}},	//   kpiq, _śruy, --, --, 
   {{0xd90c4ebe,0x00000000,0x00000000,0x00000000}},	//   _پیک_, --, --, --, 
   {{0x628c4ebf,0xade0007d,0x7f440784,0xc7d4011a}},	//   gebo, _गइलन_, dpiq, _אודי_, 
   {{0x1fdc00cc,0x00000000,0x00000000,0x00000000}},	//   _ভুলস, --, --, --, 
   {{0x0fe001c4,0x00000000,0x00000000,0x00000000}},	//   гөгү, --, --, --, 
   {{0x628c4ec0,0x693002b5,0x7988035a,0x00000000}},	// [52b0] bebo, _pāek, _lpdw, --, 
   {{0x798808c8,0xa2c000d1,0x00000000,0x00000000}},	//   _opdw, _кәск, --, --, 
   {{0x7f440113,0x6c740131,0xcd282162,0x00000000}},	//   apiq, вулх, سسان_, --, 
   {{0xc0f0001f,0xfc3042b5,0x7cdc00b0,0x00000000}},	//   ቀበል_, محه_, kōru, --, 
   {{0x693002b1,0x798802d0,0xdcec0171,0x00000000}},	//   _tāek, _apdw, _apbē, --, 
   {{0xda604ec1,0xef1000f7,0x63a000c0,0x00000000}},	//   авши, _түзө, _šonk, --, 
   {{0x798803ac,0x00000000,0x00000000,0x00000000}},	//   _cpdw, --, --, --, 
   {{0x6d444ec2,0x628c0034,0xd9f0000d,0x00000000}},	//   mpha, zebo, _अखरत_, --, 
   {{0x6d444ec3,0x2cac067c,0x2b4c1418,0x628c4ec4}},	//   lpha, _ined_, _uwec_, yebo, 
   {{0x6b8827be,0x2cac4ec5,0x6d440393,0xf1d0078a}},	//   _ipeg, _hned_, opha, सनान, 
   {{0x6d444ec6,0x628c12ed,0xe618030d,0x00000000}},	//   npha, vebo, ьдо_, --, 
   {{0x7f444ec7,0x628c0b58,0x6d440208,0x3704004e}},	//   ypiq, webo, ipha, кпөг, 
   {{0x5ef40a28,0x628c4ec8,0x6b8801f5,0x290c01c8}},	//   ्वम्_, tebo, _jpeg, mlea_, 
   {{0x66e44ec9,0x6b880076,0x6d4402d0,0x66044eca}},	//   _шола, _mpeg, kpha, _ипла, 
   {{0x628c4ecb,0x290c0421,0x7f4402d1,0xade000c5}},	//   rebo, olea_, wpiq, _गेलन_, 
   {{0x30744ecc,0x6d4403ac,0x55f40375,0x6b880036}},	//   луус, dpha, _במצב_, _opeg, 
   {{0x290c4d5d,0x6d44009a,0x6b8801e1,0xd00c01d9}},	// [52c0] ilea_, epha, _npeg, ۅلہ_, 
   {{0x7f4402d3,0x2cac36db,0x672c00d8,0x290c08c2}},	//   rpiq, _aned_, _éaju, hlea_, 
   {{0x290c4ecd,0x6d4401fb,0x7f4402d1,0xd00c01d3}},	//   klea_, gpha, spiq, ملہ_, 
   {{0x399c0085,0x7f444345,0x2cac06af,0x00000000}},	//   hásá_, ppiq, _cned_, --, 
   {{0x6d444ece,0x399c1aac,0x693000b0,0xa3c000af}},	//   apha, kásá_, _kāew, ंहि_, 
   {{0x290c4ecf,0x2cac030a,0xd9b4009e,0x60d40036}},	//   elea_, _ened_, জনসম, lhym, 
   {{0xd9181de1,0x6d444ed0,0x6b880022,0x290c4ed1}},	//   мьи_, cpha, _epeg, flea_, 
   {{0x290c4ed2,0x588402d5,0xa3c04ed3,0x2cac072b}},	//   glea_, тыка, ंहा_, _gned_, 
   {{0xb7d0009e,0x96440139,0x00000000,0x00000000}},	//   াপ্ট, кэнд, --, --, 
   {{0x290c0093,0xb594004e,0x00000000,0x00000000}},	//   alea_, гиош, --, --, 
   {{0x290c4ed4,0xe18c02d3,0x00000000,0x00000000}},	//   blea_, ዝነበሩ_, --, --, 
   {{0x290c4ed5,0x7cdc00b0,0x6b880022,0x00000000}},	//   clea_, pōru, _ypeg, --, 
   {{0x60d4009f,0xd6d80b3b,0xf2c401c6,0x8c400356}},	//   dhym, _отк_, гөни, âşia, 
   {{0x6d444ed6,0x25fc0c2e,0x59b406b1,0x186c001f}},	//   ypha, _रुकी_, _अपार, _በቀጣይ_, 
   {{0xc1e800c9,0x4718011a,0x6d444ed7,0x00000000}},	//   вьте_, _חוגג, xpha, --, 
   {{0x2ebc01bc,0x60d4015d,0x05700133,0x96a4000d}},	//   ोस्त, ghym, _ئاود, _कोतउ, 
   {{0x30144ed8,0x6d444ed9,0x40340cc9,0x73c40166}},	// [52d0] удар, wpha, реус, _сәне, 
   {{0x6d4400dc,0x752c05da,0x290c01c0,0x6e4400c6}},	//   tpha, _hiaz, zlea_, انضم, 
   {{0x752c01f7,0x6d400135,0x6d440051,0x691401ef}},	//   _kiaz, _ħlas, upha, _všez, 
   {{0x6d440182,0x60d44eda,0x5fdc256a,0x0fe03baf}},	//   rpha, chym, _नेकल, _көзү, 
   {{0x6d444edb,0x752c44f1,0x9fa40184,0xfbd02a14}},	//   spha, _miaz, _йырҙ, يته_, 
   {{0x6d444edc,0x752c04cc,0x00000000,0x00000000}},	//   ppha, _liaz, --, --, 
   {{0x49b8034c,0x6d440113,0x6f04047e,0x66cc00d7}},	//   باشد_, qpha, mohc, _súko, 
   {{0xb92801f2,0x2cac00a9,0x290c0093,0x7c8400d8}},	//   _ikwụ_, _uned_, ulea_, _вуфе, 
   {{0x2fc84edd,0x6b884ede,0x290c4edf,0xe72801f4}},	//   nyag_, _upeg, rlea_, ноид_, 
   {{0x752c0005,0x290c01c0,0x3170020c,0xa694033a}},	//   _aiaz, slea_, kuzz_, уриј, 
   {{0x290c0407,0x24e84140,0x752c4ee0,0x5ef400dc}},	//   plea_, емни_, _biaz, ्वत्_, 
   {{0x64981086,0x6f04016d,0x752c012d,0x684401d5}},	//   хтор_, hohc, _ciaz, _ёнла, 
   {{0x752c03bd,0x68e84ee1,0x74f801c6,0x00000000}},	//   _diaz, mied, тээс_, --, 
   {{0x68e84ee2,0xe68800c6,0x317000e4,0x00000000}},	//   lied, _أنثى_, fuzz_, --, 
   {{0x60d40652,0x752c0109,0xb928063f,0x64a44ee3}},	//   thym, _fiaz, _nkwụ_, _байа, 
   {{0x68e84ee4,0x752c4ee5,0x00000000,0x00000000}},	//   nied, _giaz, --, --, 
   {{0xb9280521,0x645402b9,0x10a04ee6,0x1e844ee7}},	// [52e0] _akwụ_, _ieyi, щитн, ллам, 
   {{0x5398025f,0x68e84ee8,0x93b40302,0x31702040}},	//   _טיפו, hied, _עליו_, buzz_, 
   {{0x64544ee9,0x68e84eea,0x629c23e0,0x1c444eeb}},	//   _keyi, kied, _iapo, гнем, 
   {{0x629c4eec,0x752c02b9,0x645401e1,0x68e84eed}},	//   _hapo, _xiaz, _jeyi, jied, 
   {{0x629c4eee,0x59b43c20,0x64544eef,0x3a540a89}},	//   _kapo, _अपहर, _meyi, аклё, 
   {{0x64544ef0,0x672004b9,0x66cc03b2,0x0b440133}},	//   _leyi, jmlj, _búkm, ارنێ, 
   {{0x68e84ef1,0x3f804d74,0xc0f0001f,0xdb00017a}},	//   fied, ltiu_, ቀጠል_, lvoë, 
   {{0x629c4ef2,0x68e84ef3,0x26d80023,0xba3c0055}},	//   _lapo, gied, ëson_, _anįt, 
   {{0xab080075,0x752c4ef4,0xda643738,0x629c4ef5}},	//   رتۇق_, _riaz, _ماضي, _oapo, 
   {{0xc6f407d8,0x8f78011a,0x65c00116,0x00000000}},	//   лных_, עניק, ﺭﻣﯩﻠ, --, 
   {{0x752c4ef6,0x68e84ef7,0x64544ef8,0x58844ef9}},	//   _piaz, bied, _beyi, _была, 
   {{0xd7f84efa,0x629c4efb,0x64540548,0xdb00017a}},	//   _пул_, _aapo, _ceyi, kvoë, 
   {{0x64544efc,0x629c4efd,0x752c4efe,0x00000000}},	//   _deyi, _bapo, _viaz, --, 
   {{0x6d404eff,0xf0e81823,0x752c0210,0xf31801c4}},	//   _élag, چىسى_, _wiaz, тогш_, 
   {{0xf0e83ce1,0x645418f7,0x629c4f00,0x752c4f01}},	//   نىسى_, _feyi, _dapo, _tiaz, 
   {{0x64544f02,0x2fc84f03,0x629c4f04,0xdb000af9}},	//   _geyi, tyag_, _eapo, fvoë, 
   {{0x629c0b58,0xce682d30,0xe6c00055,0x00000000}},	// [52f0] _fapo, еред_, _śṛṇv_, --, 
   {{0x629c4f05,0x68e8005f,0x645404ba,0x70540014}},	//   _gapo, zied, _zeyi, دچھا, 
   {{0x999c0953,0x3f80381a,0x11e84cdb,0x64544f06}},	//   _metų_, atiu_, _سعدي_, _yeyi, 
   {{0x645400ac,0x27e800a2,0xa3c80073,0xcaf0009d}},	//   _xeyi, _ýang_, ऊनच_, өцлө, 
   {{0x3f804f07,0x629c4f08,0x68e84f09,0x6f040477}},	//   ctiu_, _yapo, vied, pohc, 
   {{0x68e84f0a,0xa9680a31,0x629c1709,0xad480014}},	//   wied, вика_, _xapo, _لٔسن_, 
   {{0x68e84f0b,0x99944028,0x78641183,0xad2400d1}},	//   tied, لپور_, ڭدىك, _نىسى, 
   {{0x2d8003a2,0xa7644f0c,0xd9100022,0x00000000}},	//   mthe_, акид, ҩдәы, --, 
   {{0x64540699,0xca54010a,0x00000000,0x00000000}},	//   _reyi, _йĕпп, --, --, 
   {{0x67200e3c,0xa6e44f0d,0x66e400c7,0x00000000}},	//   umlj, ржол, рооа, --, 
   {{0x68e84f0e,0x2d804f0f,0x64544f10,0x67200fcf}},	//   pied, nthe_, _peyi, rmlj, 
   {{0x2d8006d5,0x629c4f11,0xfbd001d9,0x645403b9}},	//   ithe_, _sapo, _بتہ_, _qeyi, 
   {{0x629c4f12,0x07444f13,0x291c00ca,0x645402bd}},	//   _papo, _схем, _ihwa_, _veyi, 
   {{0xe5a44f14,0x645419a0,0x629c4f15,0x2d800200}},	//   _вики, _weyi, _qapo, kthe_, 
   {{0x20544f16,0x64544f17,0xa3b000e1,0x25fc4f18}},	//   итар, _teyi, _टपक_, _रुची_, 
   {{0x629c4f19,0x2d804f1a,0x3f804f1b,0xfd6800e4}},	//   _wapo, dthe_, ttiu_, pysẽ, 
   {{0x629c4f1c,0x3f8002b5,0x8fa00276,0x2d804f1d}},	// [5300] _tapo, utiu_, оате, ethe_, 
   {{0x3f804f1e,0x629c3beb,0xdb000af9,0xca680150}},	//   rtiu_, _uapo, rvoë, шiмi, 
   {{0x2d80007b,0xa0680022,0xdb000ea0,0x13c80154}},	//   gthe_, _иана_, svoë, _লইয়, 
   {{0xa0a44f1f,0x3f804b84,0x66cc02d2,0x00000000}},	//   _тамд, ptiu_, _búkk, --, 
   {{0x2d8005f6,0x4fa000d4,0x81e80154,0x00000000}},	//   athe_, _дияв, _বডি_, --, 
   {{0x99644f20,0x291c4f21,0x66cc08a5,0x00000000}},	//   атил, _ahwa_, _dúkk, --, 
   {{0x291c0a2e,0x7e7c004e,0x2d80007b,0x999c00c0}},	//   _bhwa_, _icrp, cthe_, _retų_, 
   {{0xdee422f7,0x291c4f22,0x66cc02d2,0x00000000}},	//   _соҳи, _chwa_, _fúkk, --, 
   {{0x69d44f23,0x66cc2959,0x68f800a2,0x00000000}},	//   _üzen, _kúkh, _şadö, --, 
   {{0x4b78025d,0x36d4009d,0x00000000,0x00000000}},	//   _באמו, соор, --, --, 
   {{0x69f01eec,0x92640214,0x00000000,0x00000000}},	//   _нүшт, یدآم, --, --, 
   {{0x57e80724,0x66cc2959,0xf484121b,0x799802d0}},	//   _идем_, _lúkh, حادی, mwvw, 
   {{0x73c40032,0x61fc01e3,0xb78800fb,0x00000000}},	//   сәйе, _axpl, _сәйе_, --, 
   {{0x2d804f24,0x81e800bd,0x3d080073,0x383c0092}},	//   ythe_, _বড়_, िकडे_, _አቀባበ, 
   {{0x69300374,0x95c80640,0x00000000,0x00000000}},	//   _hāer, _јула_, --, --, 
   {{0x40344f25,0xcf4000d1,0x00000000,0x00000000}},	//   жетс, قىرۋ, --, --, 
   {{0xc0580046,0x765802f6,0x22440790,0x528401af}},	// [5310] ріс_, _kevy, _şoke_, _кѳнб, 
   {{0x329401d9,0x69300374,0x765800c7,0x27e800a2}},	//   _أدر, _māer, _jevy, _ýane_, 
   {{0xaa4441fa,0x66cc2833,0x76580455,0xfbe400eb}},	//   ەنتى, _súkk, _mevy, _ফুলত, 
   {{0x2d804f26,0x7658049b,0xebd838ab,0x66cc02d2}},	//   rthe_, _levy, лдеш_, _púkk, 
   {{0x2d804f27,0x693000b0,0xaa440408,0x00000000}},	//   sthe_, _nāer, белл, --, 
   {{0x76584f28,0x8d744f29,0x291c4f2a,0xdb244f2b}},	//   _nevy, _پاسا, _shwa_, مونی, 
   {{0x0b4403e6,0x7e28109a,0x999c00e5,0x00000000}},	//   ارچێ, _віта_, _betű_, --, 
   {{0x291c0117,0x9a7400d1,0x00000000,0x00000000}},	//   _qhwa_, айәт_, --, --, 
   {{0x6d4007ea,0x7658062c,0xe85401ec,0xa6e4009d}},	//   _élab, _bevy, _ۇناد, йжил, 
   {{0x963c0023,0x00000000,0x00000000,0x00000000}},	//   _ተዓጻጻ, --, --, --, 
   {{0xdb244f2c,0x76584f2d,0x64a44f2e,0x66044f2f}},	//   _اولی, _devy, бана, спна, 
   {{0x6aa04f30,0xe35401c0,0x291c058a,0xe7580150}},	//   _half, йтгэ, _uhwa_, _биді_, 
   {{0x6aa04f31,0x00000000,0x00000000,0x00000000}},	//   _kalf, --, --, --, 
   {{0x7790023f,0x96604f32,0x6658030d,0x00000000}},	//   _کییا, _екше, _сакă, --, 
   {{0x6aa004ac,0x61441f5a,0x00000000,0x00000000}},	//   _malf, себа, --, --, 
   {{0x65600280,0x2d5400d7,0x00000000,0x00000000}},	//   mslh, dťe_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [5320] --, --, --, --, 
   {{0x6aa0037e,0x5dd84f33,0x66cc06ea,0xb9dc1ee0}},	//   _nalf, лфер_, _búki, _ኤፍ_, 
   {{0x3ae801d5,0xeb4c0023,0x00000000,0x00000000}},	//   یبتی_, _ዝተጻወ, --, --, 
   {{0x26d80023,0x66cc03b2,0xbc740e56,0x00000000}},	//   ësoj_, _dúki, تۇرب, --, 
   {{0x6aa04f34,0xfe940fa2,0x00000000,0x00000000}},	//   _balf, _ویرج, --, --, 
   {{0x5dd44f35,0x60c400ee,0x9f040137,0x00000000}},	//   _любу, _hokm, _چوڭو, --, 
   {{0x6aa04f36,0x765828b3,0xdca41eed,0x98bc00b8}},	//   _dalf, _revy, _лави, _attā_, 
   {{0x76584f37,0x1d08026a,0x00000000,0x00000000}},	//   _sevy, _себи_, --, --, 
   {{0x693000b0,0x0540001f,0x7ac40166,0x6aa04f38}},	//   _pāer, _የተማሪ, _мөка, _falf, 
   {{0x60c44f39,0x6aa0198f,0x07340b24,0x00000000}},	//   _lokm, _galf, حسيب_, --, 
   {{0x76584f3a,0x60c4035a,0x5ed800fe,0x00000000}},	//   _vevy, _ookm, _দদাই, --, 
   {{0x6aa04f3b,0x2ed44f3c,0x00000000,0x00000000}},	//   _zalf, _धत्त, --, --, 
   {{0x98144f3d,0x693002b5,0x76584f3e,0x31d000dc}},	//   _اباا, _tāer, _tevy, सन्ध, 
   {{0x92684f3f,0x6aa04f40,0xb9100241,0x8778011a}},	//   ырма_, _xalf, _nilẹ_, _תאגי, 
   {{0x60c40183,0x2258020c,0x50644f41,0x00000000}},	//   _bokm, _depk_, йтаа, --, 
   {{0x60c40429,0x2258005a,0x673800a2,0x5184013d}},	//   _cokm, _eepk_, _yuwj, _һума, 
   {{0xc4f84f42,0x60c40209,0xcf2400c6,0x6fb84d58}},	// [5330] _دعوا_, _dokm, مرئي, шгар_, 
   {{0x60c404ba,0x5184013d,0x7ff43918,0x66cc032e}},	//   _eokm, _лума, أسفا, _púki, 
   {{0x6aa04bd9,0x00000000,0x00000000,0x00000000}},	//   _ralf, --, --, --, 
   {{0x6aa04f43,0xe6c405d7,0x2d840661,0x6c143893}},	//   _salf, _लक्ज, _älem_, одеф, 
   {{0x6aa04f44,0x814401d5,0xcfa40353,0x6b6400c7}},	//   _palf, _ونین, _ушни, цкла, 
   {{0x6aa04f45,0x7c240022,0x00000000,0x00000000}},	//   _qalf, ýira, --, --, 
   {{0x60c44f46,0x6aa04f47,0x3bd40131,0x67380432}},	//   _yokm, _valf, يغۇس, _suwj, 
   {{0x6aa04f48,0x69d44f49,0xe8c84f4a,0xfd4401c6}},	//   _walf, _üzem, ргил_, _хэрн, 
   {{0x524002d3,0xbcb40306,0x25440171,0xe7380114}},	//   ዛሕትኦ, šším, _mēle_, јео_, 
   {{0x6aa00b6f,0x66e400d6,0xf1c84f4b,0x27e800ef}},	//   _ualf, іона, रहान, _žans_, 
   {{0x85080116,0x00000000,0x00000000,0x00000000}},	//   йдоң_, --, --, --, 
   {{0xa5084f4c,0xc0d40023,0xdd780375,0x6c78010f}},	//   рема_, _ረጽሚ_, סטרל, סאָפ, 
   {{0x60c401f1,0xc1b400cd,0xf79400c0,0x00000000}},	//   _rokm, ृङ्ग, _нацэ, --, 
   {{0x60c44f4d,0x04fc015b,0xf7704f4e,0x00000000}},	//   _sokm, ীগের_, _ساه_, --, 
   {{0x60c4020c,0x66cc03b2,0x830c031c,0x78c80162}},	//   _pokm, _búkv, _གེཛུ_, _ásvø, 
   {{0xb9100cad,0x9db800f2,0x00000000,0x00000000}},	//   _silẹ_, یداز_, --, --, 
   {{0x0404015b,0x5438008f,0xb9100241,0xa2e4024c}},	// [5340] রেজী_, _דעפא, _pilẹ_, _моид, 
   {{0x60c42b92,0x6e2801e4,0xfdd800ec,0x00000000}},	//   _wokm, _ŝeba, ٽائڻ_, --, 
   {{0x60c44f4f,0x14ac0073,0x00000000,0x00000000}},	//   _tokm, _जोडण, --, --, 
   {{0xfc380124,0x00000000,0x00000000,0x00000000}},	//   сҭа_, --, --, --, 
   {{0x66cc03b2,0x69c44f50,0x78a40332,0xb91001e1}},	//   _húku, ähen, _óivi, _tilẹ_, 
   {{0xd1d0001f,0x320c05d1,0x66cc4f51,0xdddc007f}},	//   _የልብ_, şeye_, _kúku, yapň, 
   {{0x41d001f9,0xeb3000cf,0x00000000,0x00000000}},	//   _सॅमस, رۉمد, --, --, 
   {{0xdcb0129d,0xd05c0213,0x00000000,0x00000000}},	//   _تىر_, fiqə, --, --, 
   {{0x27e80e04,0x66cc0413,0x00000000,0x00000000}},	//   _žanr_, _lúku, --, --, 
   {{0x66cc00c7,0x00000000,0x00000000,0x00000000}},	//   _oúku, --, --, --, 
   {{0xc0d40020,0x75d410fe,0xa2bc1971,0x693002b1}},	//   የሱስ_, سيحا, शान्, _tāep, 
   {{0xd05c03be,0xd90c3b7a,0xc894004e,0x00000000}},	//   biqə, _جیب_, _мучө, --, 
   {{0xd68400ee,0x22440c3c,0x00000000,0x00000000}},	//   _дуйп, _şoka_, --, --, 
   {{0x58f80135,0x66cc4eb5,0x27e8010b,0x00000000}},	//   ྒོམས_, _búku, _ýana_, --, 
   {{0x32dc0ca8,0x610c0153,0x00000000,0x00000000}},	//   _nìye_, kėlę, --, --, 
   {{0x66cc032e,0x316c0427,0x2d8400ef,0x00000000}},	//   _dúku, čez_, _īle_, --, 
   {{0xdc680201,0x850402ef,0x490807b7,0x6fac01f9}},	// [5350] _አምላክ_, _توين, ावतो_, ीमधू, 
   {{0xb8dc0003,0x6da40092,0x00000000,0x00000000}},	//   _ཅོ_, _ወላይታ_, --, --, 
   {{0xbdf800db,0xd9e81b57,0x26d80240,0x00000000}},	//   يرما_, _झेलत_, ësoi_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xaa444f52,0xfc300035,0x8d740133,0x00000000}},	//   пелл, نحه_, _ژارا, --, 
   {{0x7f582daf,0x0dc84f53,0x00000000,0x00000000}},	//   _фарс_, _куби_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x01fc0375,0x213c0332,0x00000000,0x00000000}},	//   יפול, íthi_, --, --, 
   {{0xfaa40108,0xa2bc00cd,0x00000000,0x00000000}},	//   öään_, शाम्, --, --, 
   {{0x1b7000b2,0xd7e435c7,0x3a744f54,0x57e40150}},	//   _سگهج, ямые_, _олур, ядым_, 
   {{0x64a44f55,0xd05c00ac,0x5af8008f,0xc984033a}},	//   пана, siqə, _פלעצ, _фузи, 
   {{0x64a40354,0xbb540023,0x00000000,0x00000000}},	//   чама, _ዝተበላ, --, --, 
   {{0x290c4f56,0xd05c03be,0x00000000,0x00000000}},	//   moea_, qiqə, --, --, 
   {{0x290c0418,0xfbac00dc,0xdb0000e4,0x00000000}},	//   loea_, चितम, yvoí, --, 
   {{0xb5fc031c,0x00000000,0x00000000,0x00000000}},	//   taġe, --, --, --, 
   {{0x290c003a,0x21200051,0xe458119e,0x00000000}},	//   noea_, _qhkh_, _ужи_, --, 
   {{0xd4780375,0x9e38007b,0x00000000,0x00000000}},	// [5360] _האפל, مساء_, --, --, 
   {{0x44201813,0x290c4f57,0x66cc0022,0x142000ee}},	//   _izi_, hoea_, _túku, _ядым, 
   {{0x290c02b5,0xd238011a,0x3d0800bc,0x69c44f58}},	//   koea_, _לגיל, िकले_, ähel, 
   {{0x04040c58,0x64444f59,0x80b40150,0x9c24010b}},	//   ৰেণী_, ncki, _تەرش, пдед, 
   {{0x64441caa,0x6d4006af,0xbe8402dd,0x00000000}},	//   icki, _élan, _оңал, --, 
   {{0x05c84103,0x290c0a73,0x44204242,0x60d400ee}},	//   ाहाब, eoea_, _mzi_, lkym, 
   {{0x66cc4f5a,0xe81001ad,0x88b007d6,0x61b808a3}},	//   _lúks, _डुबा_, کینچ, _उपोष, 
   {{0x442044fc,0x60d40aec,0x4df8011a,0x00000000}},	//   _ozi_, nkym, _הפלא, --, 
   {{0x44204f5b,0xed3405f5,0xacb00137,0x46100014}},	//   _nzi_, _цэрэ, _جەنب, ہوٝر, 
   {{0x64440034,0x7c2039ae,0x00000000,0x00000000}},	//   ecki, _izmr, --, --, 
   {{0x290c0032,0xceb00302,0x3eb80263,0x1bf005d7}},	//   boea_, גית_, _mnrt_, _आइडल_, 
   {{0x48e04f5c,0x66cc0162,0x4420054e,0x518400c7}},	//   _похв, _búks, _bzi_, ҟуга, 
   {{0x5344009d,0xd5b8010a,0x00000000,0x00000000}},	//   яхна, _ӳси_, --, --, 
   {{0x44201aa1,0xd56400ee,0x64444f5d,0x27f800d0}},	//   _dzi_, _етип, acki, úsne_, 
   {{0x44204f5e,0x00000000,0x00000000,0x00000000}},	//   _ezi_, --, --, --, 
   {{0x3eb80ffb,0x47d000db,0x506408ca,0x00000000}},	//   _anrt_, _تيۇر, ятга, --, 
   {{0x30140724,0xaef00327,0x101400f2,0x00000000}},	// [5370] фдар, _ཨམདོ, سبرد, --, 
   {{0x290c0451,0x3f1415ab,0x60d401f4,0x00000000}},	//   zoea_, едус, akym, --, 
   {{0x0ca8036b,0xc6740092,0x00000000,0x00000000}},	//   йтди_, _በአሥራ_, --, --, 
   {{0x60d4005c,0xfd104f5f,0xd5a448ca,0x254400ef}},	//   ckym, هجن_, _یف_, _jēla_, 
   {{0x5ca400cf,0x00000000,0x00000000,0x00000000}},	//   بلنە, --, --, --, 
   {{0x0ac40108,0x840800e5,0x00000000,0x00000000}},	//   ящем, lsőé, --, --, 
   {{0x290c394e,0x64444f60,0xa2bc07d0,0x3d94014b}},	//   toea_, ycki, शात्, _пирр, 
   {{0xd83c0219,0x00000000,0x00000000,0x00000000}},	//   ščno_, --, --, --, 
   {{0x66e407c6,0x00000000,0x00000000,0x00000000}},	//   допа, --, --, --, 
   {{0x2b4c0158,0xb8640050,0x442001ef,0x60d40419}},	//   _itec_, ٘ایو, _rzi_, zkym, 
   {{0x66cc0b21,0x290c257c,0x60d40124,0x00000000}},	//   _súks, poea_, ykym, --, 
   {{0xf990495f,0x661c00bc,0x44200427,0x25440171}},	//   _حبك_, řsko, _pzi_, _cēla_, 
   {{0xe63800c6,0x61e003f9,0x254400e2,0x85b801d9}},	//   _ɑᴊ_, _ƙolo, _dēla_, _گاشس_, 
   {{0x20cc01a8,0xe72800ec,0x00000000,0x00000000}},	//   _nýir_, _ڏسڻو_, --, --, 
   {{0x56901d39,0x60d40419,0x00000000,0x00000000}},	//   _рајт, tkym, --, --, 
   {{0x2b4c0232,0x44204f61,0x6fe80011,0x254400de}},	//   _otec_, _tzi_, _কুইজ_, _gēla_, 
   {{0x44204f62,0x60d40006,0x20cc0174,0x0c74001f}},	// [5380] _uzi_, rkym, _býir_, _አምራች_, 
   {{0x60d44f63,0x00000000,0x00000000,0x00000000}},	//   skym, --, --, --, 
   {{0x2b4c0fac,0x940806be,0x00000000,0x00000000}},	//   _atec_, decə_, --, --, 
   {{0x628c13e8,0x2b4c0142,0xa2c80a8a,0x00000000}},	//   lfbo, _btec_, सॉर्, --, 
   {{0x394c4f64,0xf0000209,0xcb644f65,0xdddc00b0}},	//   _stds_, _бүти, даче_, mapō, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xcb0405d4,0x2b4c00d8,0x7f440784,0xae0401af}},	//   بيون_, _etec_, lqiq, _зорҙ, 
   {{0xdddc02b1,0x80d0015b,0x176800fb,0x3ae804f2}},	//   napō, সোর্, ороп_, _کبری_, 
   {{0x8b6401a9,0x00000000,0x00000000,0x00000000}},	//   _оитв_, --, --, --, 
   {{0x66cc01a2,0x3f4400b0,0x628c01a4,0x2490012d}},	//   _súkr, _möu_, jfbo, _abym_, 
   {{0x58844f66,0xdddc4f67,0xf95801ed,0xb9040011}},	//   _жыла, kapō, _رساں_, _নদ_, 
   {{0x3988003a,0x00000000,0x00000000,0x00000000}},	//   mûs_, --, --, --, 
   {{0x2b4c0137,0x92b407d6,0x3988000f,0x628c01e3}},	//   _xtec_, وحسا, lûs_, ffbo, 
   {{0x7f440fed,0x983c02d3,0x62a40241,0x00000000}},	//   dqiq, _ኣበሃህ, _ìsò, --, 
   {{0x55040276,0x3988003a,0x349401c6,0x254400de}},	//   _очиа, nûs_, _зайр, _tēla_, 
   {{0xd50c0085,0x00000000,0x00000000,0x00000000}},	//   _fɛ́f, --, --, --, 
   {{0x39880a85,0x7f4400f1,0xee7c0023,0x00000000}},	// [5390] hûs_, gqiq, _ብቀረባ_, --, 
   {{0x32543d6b,0x60c0007c,0xfe704f68,0x93240345}},	//   _явор, öomr, لدم_, _تربن, 
   {{0x84e84f69,0x52b000db,0x85041a4b,0xdec80240}},	//   _رفیق_, _كەڭئ, _سوین, _በጀካ_, 
   {{0xad243955,0x50a002de,0x00000000,0x00000000}},	//   رىشى, _جەرل, --, --, 
   {{0x20cc010b,0x9c8000d7,0x00000000,0x00000000}},	//   _iýip_, áčac, --, --, 
   {{0x3b6c0092,0xadbc030d,0x00000000,0x00000000}},	//   ሰባዎች_, _лагi, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d444f6a,0x1cbc025c,0xa9080451,0xdb0002f0}},	//   mqha, _ཇོར_, ڊيڪل_, rvoá, 
   {{0x628c0ea0,0x7c84299f,0x468001d5,0x00000000}},	//   yfbo, _шуре, вқла, --, 
   {{0x6b88031c,0x3a7403f6,0x00000000,0x00000000}},	//   _iqeg, _алфр, --, --, 
   {{0xa2bc1810,0x6d444f6b,0xba740202,0x8d7c001f}},	//   शास्, nqha, _جاقت, _ያውቃል_, 
   {{0x6d440357,0x02a8012d,0x00000000,0x00000000}},	//   iqha, _छोड़न, --, --, 
   {{0x93401de1,0x6b88031c,0xb5fc0327,0xb424009f}},	//   лняе, _jqeg, raġa, َعُو, 
   {{0x6b88031c,0xb5fc025c,0xe284009d,0x00000000}},	//   _mqeg, maġn, элги, --, 
   {{0x628c0798,0xdddc02b1,0x00000000,0x00000000}},	//   rfbo, tapō, --, --, 
   {{0x249003a2,0xdbf800a2,0xdfd00f13,0x10a04f6c}},	//   _ubym_, _ańýa, هيز_, лисн, 
   {{0xd0044f6d,0x2b880030,0x6b880327,0xdddc4f6e}},	// [53a0] еете_, júc_, _nqeg, rapō, 
   {{0x5ea400c6,0x3864004e,0xef08009a,0x00000000}},	//   عمال, zamr_, وغلو_, --, 
   {{0x6b880139,0x00000000,0x00000000,0x00000000}},	//   _aqeg, --, --, --, 
   {{0x5d14006c,0x3f4400b0,0x0c802123,0x1634010f}},	//   رباز, _töu_, гышм, גנער_, 
   {{0x6d440cfe,0xa0341823,0xfe704f6f,0x00000000}},	//   aqha, _سىست, _نگا_, --, 
   {{0x39880393,0x29000438,0x00000000,0x00000000}},	//   tûs_, éhan_, --, --, 
   {{0xd1cc0020,0xca4416ac,0x4ac00137,0x00000000}},	//   _ጥቃት_, رليه_, ايىق, --, 
   {{0x3988002d,0xc87400c7,0x00000000,0x00000000}},	//   rûs_, нџь_, --, --, 
   {{0x9b04177b,0x00000000,0x00000000,0x00000000}},	//   _ззад, --, --, --, 
   {{0x36d44f70,0x254400ef,0x2ab401ec,0x00000000}},	//   тоор, _cēlo_, _аңшы_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x26d80023,0x1cbc031c,0xe8ec0451,0x5fb04f71}},	//   ësor_, _ཇོས_, _وڻي_, ीमाल, 
   {{0x73c40032,0xd6d84130,0x00000000,0x00000000}},	//   тәйе, _нтк_, --, --, 
   {{0xa43000c7,0xe4380055,0x00000000,0x00000000}},	//   шҭыц, _āṇāṃ_, --, --, 
   {{0x59a41fb0,0xd4984f5c,0x00000000,0x00000000}},	//   _कैमर, _ерп_, --, --, 
   {{0x94840209,0x69c4005b,0x61f803b2,0x408400cf}},	//   _чыкд, ähei, útla, лууб, 
   {{0xb0344f72,0x09a80135,0x6d440054,0x75d40451}},	// [53b0] тнаш, _བླླ_, wqha, _سيکا, 
   {{0x6d40020c,0xe7b030a4,0x4ea44f73,0x00000000}},	//   _élak, जितप, эрба, --, 
   {{0xa2bc00cd,0x00000000,0x00000000,0x00000000}},	//   शार्, --, --, --, 
   {{0x2b481dec,0x6d444f74,0x0fe00166,0x7a8400d1}},	//   íaco_, rqha, _йөзү, ۇشىم, 
   {{0x6d442b34,0x2ca80419,0x00000000,0x00000000}},	//   sqha, ľad_, --, --, 
   {{0xdb2407d6,0x2ca84f75,0x69940395,0x00000000}},	//   نونی, žad_, врих, --, 
   {{0x6d44009a,0x2b8800d7,0x00000000,0x00000000}},	//   qqha, súc_, --, --, 
   {{0x6b880003,0x00000000,0x00000000,0x00000000}},	//   _tqeg, --, --, --, 
   {{0x4ab000f7,0x69a04f76,0x00000000,0x00000000}},	//   _бөйр, _कैरी, --, --, 
   {{0xb5fc031c,0x00000000,0x00000000,0x00000000}},	//   raġn, --, --, --, 
   {{0xa5081d83,0x36940220,0xc890004e,0xa5240798}},	//   дена_, ушыс, _булө, кмод, 
   {{0xb5fc031c,0x3b540023,0xa774009d,0x00000000}},	//   paġn, _ዝተጀመ, _алдч, --, 
   {{0x936007dd,0x757c001f,0x25440171,0xe6c400ae}},	//   аҭыҧ, _ተደርጎ_, _tēlo_, _لتغي, 
   {{0x69d400a2,0x2d0c3f7e,0x7c24031c,0x1b7800df}},	//   _üzes, िकुल_, żirg, וטשע, 
   {{0x06680131,0x61444130,0x00000000,0x00000000}},	//   _ﻳﯘﻗﯩ, теба, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x10a000d1,0x504001f4,0x00000000,0x00000000}},	// [53c0] шитн, реуб, --, --, 
   {{0xd37805e1,0x00000000,0x00000000,0x00000000}},	//   _קריט, --, --, --, 
   {{0x181c2db8,0xdca40b32,0x63b401a8,0x69a005d7}},	//   _पर्व_, кажи, _hryn, _कैली, 
   {{0x63b41430,0x3ce000ae,0x00000000,0x00000000}},	//   _kryn, óiv_, --, --, 
   {{0x28c43c74,0x3a980276,0x10a01df2,0x00000000}},	//   वानि, еклэ_, _тиян, --, 
   {{0x63b4015d,0x8b200395,0x00000000,0x00000000}},	//   _mryn, адче, --, --, 
   {{0x3f80315a,0x00000000,0x00000000,0x00000000}},	//   luiu_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3f804f77,0x2d840036,0xda64014b,0x00000000}},	//   nuiu_, _äler_, _авзи, --, 
   {{0x3f800618,0x00000000,0x00000000,0x00000000}},	//   iuiu_, --, --, --, 
   {{0x63b42dc9,0x00000000,0x00000000,0x00000000}},	//   _aryn, --, --, --, 
   {{0x63b44f78,0x3f804f79,0xd7f80276,0x657401d3}},	//   _bryn, kuiu_, _оул_, ázha, 
   {{0x69d40ab7,0xd4043f08,0x63b40368,0xfbb41bd6}},	//   _üzer, тяни, _cryn, ूमिम, 
   {{0x78a0003c,0x00000000,0x00000000,0x00000000}},	//   lemv, --, --, --, 
   {{0x63b4003a,0xd7c40214,0xd0a8009d,0x00000000}},	//   _eryn, _سوژه_, мтад_, --, 
   {{0x78a04f7a,0x7af80455,0x863405d0,0x00000000}},	//   nemv, hivt, _ברוב_, --, 
   {{0x3f804f7b,0x63b44f7c,0xeeb8036b,0x7af80158}},	// [53d0] guiu_, _gryn, нлаш_, kivt, 
   {{0x78a00161,0x77440023,0x59d00243,0x7e5400d4}},	//   hemv, _ከነስተ, तहार, ивує, 
   {{0x28c42cca,0x63b8005f,0x7e4400c7,0x7af801ef}},	//   वामि, ātne, рхуе, divt, 
   {{0x3f804f7d,0x7d2402e8,0x00000000,0x00000000}},	//   buiu_, афче, --, --, 
   {{0x78a001f5,0x661c4f7e,0xbc380066,0x00000000}},	//   demv, ęski, نسها_, --, 
   {{0x8d7401d9,0x28c4243c,0x27e80115,0x00000000}},	//   _لارا, वाभि, _ĥan_, --, 
   {{0x61e002a8,0xc33402e4,0x00000000,0x00000000}},	//   _ƙoli, בוס_, --, --, 
   {{0x2d802dab,0x78a01446,0x00000000,0x00000000}},	//   muhe_, gemv, --, --, 
   {{0xe73800a6,0x466003cc,0x7c340108,0x00000000}},	//   неи_, لۇشق, _ветх, --, 
   {{0x2cac4f7f,0xd704005b,0x00000000,0x00000000}},	//   _haed_, лные_, --, --, 
   {{0x78a00921,0x2d804f80,0x49440262,0xb5fc031c}},	//   bemv, nuhe_, _рэзб, laġj, 
   {{0x63b400a9,0x2a6401c4,0x78a00393,0x00000000}},	//   _pryn, _helb_, cemv, --, 
   {{0x2d800730,0x2a640135,0x2c1403d4,0x00000000}},	//   huhe_, _kelb_, তেৰে_, --, 
   {{0x2d804f81,0x63b44f82,0x2cac0037,0x490800bc}},	//   kuhe_, _vryn, _laed_, ावको_, 
   {{0x2a6405be,0x91e00b7b,0x4ad84196,0x2d80000d}},	//   _melb_, боре, _भवनव, juhe_, 
   {{0x1ea825a7,0x2cac0007,0x63b44f83,0x3f804f84}},	//   کاري_, _naed_, _tryn, tuiu_, 
   {{0x60244f85,0xd36c00c6,0x00000000,0x00000000}},	// [53e0] удаа, _فهي_, --, --, 
   {{0x3f804f86,0x78a00944,0x2a640064,0x0e6000db}},	//   ruiu_, zemv, _nelb_, йкун, 
   {{0x2d804f87,0xa0684f88,0xd83c0006,0x78a00117}},	//   guhe_, _пана_, ščio_, yemv, 
   {{0x5c0425ec,0x2cac0042,0x7af8014f,0x00000000}},	//   ляла, _caed_, wivt, --, 
   {{0x78a04f89,0x7af84f8a,0x3f8005d5,0x00000000}},	//   vemv, tivt, quiu_, --, 
   {{0x2d804f8b,0x78a0209c,0x1a6404fb,0x1fb0033f}},	//   buhe_, wemv, ایای_, ीमीड, 
   {{0x78a004d7,0x7af84f8c,0x4e24011c,0x00000000}},	//   temv, rivt, _борн_, --, 
   {{0x2cac4f8d,0x25a40142,0x7af80477,0x00000000}},	//   _gaed_, dwll_, sivt, --, 
   {{0x57b00150,0x00000000,0x00000000,0x00000000}},	//   сұлт, --, --, --, 
   {{0x2a6403fa,0xd9444f8e,0x78a0004b,0x00000000}},	//   _gelb_, _бежи, semv, --, 
   {{0x69c44f8f,0x00000000,0x00000000,0x00000000}},	//   ähet, --, --, --, 
   {{0x28c40316,0xf4844f90,0x186800d8,0x00000000}},	//   वाणि, جادی, _чади_, --, 
   {{0x2a640998,0x2d8001a6,0x12f00139,0x439401c4}},	//   _yelb_, zuhe_, йҗир, баяс, 
   {{0x2d800230,0x25a40142,0x00000000,0x00000000}},	//   yuhe_, bwll_, --, --, 
   {{0x26d80134,0x25a40142,0x00000000,0x00000000}},	//   ɔso_, cwll_, --, --, 
   {{0x6ad01fbc,0x10e40066,0x00000000,0x00000000}},	//   _तक्र, اژدی_, --, --, 
   {{0x2ef44f91,0x2cac4f92,0x752c4f93,0x73c4151e}},	// [53f0] азар, _raed_, _ihaz, _тәне, 
   {{0x2cac0bed,0xc7d40375,0x2d8000f2,0x00000000}},	//   _saed_, אומי_, tuhe_, --, 
   {{0x752c4f94,0x2cac002d,0x709402d5,0x409404da}},	//   _khaz, _paed_, _канф, شلەر, 
   {{0xebd81cd6,0x70840137,0x2a64002f,0xb5fc031c}},	//   кдеш_, _өгүз, _selb_, taġj, 
   {{0x752c009f,0xfbd80154,0x98a400d7,0xcbb401ec}},	//   _mhaz, _দেবত, _choč_, ығаш_, 
   {{0x4e34431a,0x2d804f95,0x2cac015d,0x2a644f96}},	//   _معزز, puhe_, _waed_, _qelb_, 
   {{0x2cac4e13,0xc33408a8,0x00000000,0x00000000}},	//   _taed_, זוס_, --, --, 
   {{0x6d5401c0,0x752c0521,0x1cbc0327,0x61e82ac2}},	//   _itza, _nhaz, _ཇོག_, _üfle, 
   {{0xa6e41422,0x00000000,0x00000000,0x00000000}},	//   ижил, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x28c40a28,0xe4c44f97,0x752c006f,0x7ac400ee}},	//   वादि, айни, _bhaz, _усте, 
   {{0x3e7c0248,0xba3c0153,0xe354009d,0x00000000}},	//   _kátà_, _paįv, итгэ, --, 
   {{0x68e84f98,0x1d9c001f,0x254400de,0x00000000}},	//   mhed, ጀክቶች_, _mēli_, --, 
   {{0x68e84f99,0x98bc0093,0xf770005e,0x6d54009d}},	//   lhed, _iutā_, _ءان_, _otza, 
   {{0x27ec4f9a,0xa0684f9b,0x6d5400ca,0xa1140acb}},	//   lzen_, кава_, _ntza, لوست, 
   {{0x752c4f9c,0x68e84f9d,0x98bc00b0,0x27ec0156}},	//   _ghaz, nhed, _kutā_, ozen_, 
  
   {{0x27ec4f9e,0x6d544f9f,0x22441432,0x5e5400d1}},	// [5400] nzen_, _atza, _şoku_, لئار, 
   {{0x44204fa0,0x1cbc0489,0x27ec4fa1,0x9e380597}},	//   _iyi_, _ཇོང_, izen_, نساء_, 
   {{0x68e84fa2,0x27ec4fa3,0x1c4426c7,0x4420005b}},	//   khed, hzen_, анем, _hyi_, 
   {{0x44204fa4,0x68e84fa5,0x254400ef,0x752c0200}},	//   _kyi_, jhed, _cēli_, _xhaz, 
   {{0x27ec0460,0x68e84fa6,0xa3e40316,0x6d5401c6}},	//   jzen_, dhed, पनि_, _etza, 
   {{0x27ec4fa7,0x4420005b,0x00000000,0x00000000}},	//   dzen_, _myi_, --, --, 
   {{0xdcfc16a3,0x27ec4fa8,0x68e81aa1,0x4420090c}},	//   lupč, ezen_, fhed, _lyi_, 
   {{0x68e84fa9,0x44204faa,0x27ec0086,0xdd1400d1}},	//   ghed, _oyi_, fzen_, _ئورخ, 
   {{0x44204fab,0xb5fc0003,0x00000000,0x00000000}},	//   _nyi_, maġi, --, --, 
   {{0x320c0790,0xfce44fac,0xb5fc0327,0x00000000}},	//   şeyi_, _тоғо, laġi, --, 
   {{0x44204fad,0x68e84fae,0x752c0161,0xfd580022}},	//   _ayi_, bhed, _phaz, _araẽ, 
   {{0x68e84faf,0x44200c11,0x752c4fb0,0x7c204fb1}},	//   ched, _byi_, _qhaz, _kymr, 
   {{0x44204fb2,0x27ec012d,0x6f040051,0x752c01ef}},	//   _cyi_, czen_, ynhc, _vhaz, 
   {{0x442018f7,0x436800c2,0x193c00b5,0x7c20015d}},	//   _dyi_, раён_, _ｐｄｆ_, _mymr, 
   {{0x44204fb3,0x752c0161,0xfd5800e4,0x50644fb4}},	//   _eyi_, _thaz, _eraẽ, итаа, 
   {{0x44204fb5,0x752c0453,0x73c404b4,0x98bc00b8}},	//   _fyi_, _uhaz, _ләге, _yutā_, 
   {{0x44f84fb6,0x442000b8,0x3394007b,0x00000000}},	// [5410] _خروج_, _gyi_, _الخز, --, 
   {{0x51844fb7,0x00000000,0x00000000,0x00000000}},	//   _кума, --, --, --, 
   {{0x68e81a31,0x27ec4fb8,0x32dc0241,0x8d84010b}},	//   yhed, zzen_, _nìyi_, рузд, 
   {{0xbd18090b,0xfaf800cd,0x00000000,0x00000000}},	//   ації_, _amī_, --, --, 
   {{0x7c201649,0x67204fb9,0x68e80084,0x28c408ec}},	//   _cymr, yllj, vhed, वासि, 
   {{0x66cc02d2,0x23640200,0xa034011a,0x00000000}},	//   _fúky, _çoje_, _לארה_, --, 
   {{0x98a40030,0x68e84fba,0xb5fc0327,0x6d544fbb}},	//   _choď_, thed, baġi, _utza, 
   {{0x27ec4fbc,0xed042037,0x7c20015d,0xcc8403e6}},	//   tzen_, _اورپ, _fymr, _ڕۆڵه_, 
   {{0x8aa42082,0x68e84fbd,0x7c200f7b,0x27ec1543}},	//   _вред, rhed, _gymr, uzen_, 
   {{0x28c44d53,0x27ec4fbe,0x68e84fbf,0x85540020}},	//   वाहि, rzen_, shed, _የተፈጥ, 
   {{0x68e84fc0,0x442002b4,0x27ec00dd,0x6d404fc1}},	//   phed, _syi_, szen_, _élas, 
   {{0x4420007f,0x00000000,0x00000000,0x00000000}},	//   _pyi_, --, --, --, 
   {{0x291c4fc2,0x5f1800cd,0x00000000,0x00000000}},	//   _ikwa_, भवम्_, --, --, 
   {{0x98a400b0,0x8880036b,0x28c41221,0x61ec4fc3}},	//   _ihoā_, _ایکن, वावि, tzbl, 
   {{0x9c80151c,0x91e01a92,0x58a803d4,0x00000000}},	//   ščic, поре, কাৰী, --, 
   {{0xe3b04278,0x4420026c,0x2328013e,0x61ec1196}},	//   _فرخ_, _tyi_, тоҳи_, rzbl, 
   {{0x4420036b,0xa0a40184,0xfd580022,0xa2e400cc}},	// [5420] _uyi_, _һанд, _uraẽ, _নদীখ, 
   {{0xdcfc02fb,0x00000000,0x00000000,0x00000000}},	//   rupč, --, --, --, 
   {{0x291c068b,0x7c204fc4,0x00000000,0x00000000}},	//   _okwa_, _symr, --, --, 
   {{0x291c4fc5,0x98bc054e,0xdcfc16a3,0xd36c10e8}},	//   _nkwa_, _mută_, pupč, _تهی_, 
   {{0xb5fc025c,0x00000000,0x00000000,0x00000000}},	//   raġi, --, --, --, 
   {{0x291c00b4,0x3f8000db,0x4f7c001f,0x7c200306}},	//   _akwa_, mriu_, _እርባታ_, _vymr, 
   {{0xd9184fc6,0x68f80419,0xae0401af,0x00000000}},	//   льи_, _bmwd, _дорҙ, --, 
   {{0x83280135,0xdee40fc0,0xdcac0137,0x38c80214}},	//   _རེའུ_, _тоҳи, _سۉت_, شابی_, 
   {{0x98bc0356,0x964400ee,0xba3c0064,0xb8d0098a}},	//   _aută_, йэнд, _paįs, _ओस_, 
   {{0x3f804fc7,0x291c4fc8,0xfaf80421,0x6d4007ea}},	//   iriu_, _ekwa_, _umī_, _élar, 
   {{0x3f800200,0x00000000,0x00000000,0x00000000}},	//   hriu_, --, --, --, 
   {{0x24540214,0x87e401e0,0x3f80036e,0x97a400d8}},	//   ينپس, рһәң_, kriu_, _гркл, 
   {{0xc7a0074d,0xb4e80404,0x3f800200,0x00000000}},	//   _ницк, _यती_, jriu_, --, 
   {{0x3f804fc9,0xe81c10eb,0x53e40124,0x6b9c010b}},	//   driu_, _पडता_, ацҳа, _äsge, 
   {{0x34944f41,0x07044fca,0x69940354,0x00000000}},	//   _дайр, _ديوي_, _юрăх, --, 
   {{0x3f804fcb,0x705801c0,0x254400ef,0x00000000}},	//   friu_, раар_, _cēlu_, --, 
   {{0x7ae84fcc,0x3f800369,0x254400e2,0xc0580d30}},	// [5430] _oldt, griu_, _dēlu_, сіс_, 
   {{0x7f74003b,0x00000000,0x00000000,0x00000000}},	//   ягує, --, --, --, 
   {{0x3f8019f5,0x74144fcd,0xfe70007b,0x00000000}},	//   ariu_, _دوکا, عدك_, --, 
   {{0x3f804fce,0x7ae8000f,0x82340092,0x254400ef}},	//   briu_, _aldt, _በድሬዳ, _gēlu_, 
   {{0x3f804fcf,0xa2bc1fbc,0x00000000,0x00000000}},	//   criu_, शाच्, --, --, 
   {{0x4ea44fd0,0xe9d84fd1,0x0a684fd2,0x9028035b}},	//   _урма, икл_, урди_, _ацҳа_, 
   {{0x6c84021a,0x28c44fd3,0x2d840165,0x00000000}},	//   _ولسم, वालि, _êle_, --, 
   {{0x7ae84fd4,0xd9400354,0x98bc054e,0x01fc0a7c}},	//   _eldt, мещи, _rută_, טפול, 
   {{0x98bc0276,0xc674001f,0xd76000e5,0x00000000}},	//   _sută_, _በአማራ_, ونٹی, --, 
   {{0x0514002b,0x39e83c1a,0xb5fc00e4,0xc984026b}},	//   _kaṇḍ, рьән_, haġu, _гуди, 
   {{0x7ac44fd5,0x64a40f32,0x3f800369,0x2d800165}},	//   _эсте, оана, zriu_, nrhe_, 
   {{0x291c2da1,0xf2c80302,0x05140882,0x1cbc0327}},	//   _ukwa_, _בע_, _maṇḍ, _ཇོབ_, 
   {{0x23280640,0xa34801d5,0x00000000,0x00000000}},	//   иоми_, рзга_, --, --, 
   {{0x3f8004cc,0x614426b1,0x776403e3,0xd4680240}},	//   vriu_, жева, _çixa, _ጠንጢኑ_, 
   {{0x21684fd6,0x63a00432,0x00000000,0x00000000}},	//   риби_, _ţond, --, --, 
   {{0x3f804fd7,0x1f643b2b,0x00000000,0x00000000}},	//   triu_, жкам, --, --, 
   {{0x254400e2,0x00000000,0x00000000,0x00000000}},	// [5440] _vēlu_, --, --, --, 
   {{0x3f804fd8,0x9e58020a,0xc33000db,0xe2984fd9}},	//   rriu_, рраф_, _سەز_, _тао_, 
   {{0x051400dc,0x254400e2,0x3f800200,0x00000000}},	//   _caṇḍ, _tēlu_, sriu_, --, 
   {{0x3f804fda,0x45f00135,0x05140882,0x657c022e}},	//   priu_, _བཟླས_, _daṇḍ, хshi, 
   {{0x64541459,0x80c004c5,0x09d400cc,0x00000000}},	//   _mfyi, _একপ্, _থেলা, --, 
   {{0xe81c0034,0x1d8800ec,0x8f64003b,0x00000000}},	//   _पड़ा_, _پئسي_, _фарб_, --, 
   {{0xdd904e74,0xfbd804c5,0x051400cd,0xf8b000e5}},	//   _توز_, _দেশত, _gaṇḍ, ٹکا_, 
   {{0x89300a2c,0x1d080640,0x1ba800e5,0xb4e800cd}},	//   وعيا, _теби_, _پارٹ_, _यते_, 
   {{0x629c09a8,0x98bc0210,0x00000000,0x00000000}},	//   _obpo, _nutą_, --, --, 
   {{0xc5a400b2,0x35f4154e,0x60c40334,0x395c003a}},	//   ڪڏهن_, зпор, _lnkm, ppvs_, 
   {{0x77f80084,0x60c402d0,0xe7940014,0x00000000}},	//   _ṱaḓ, _onkm, _ہاوک, --, 
   {{0x98a44fdb,0x98bc0024,0x61782440,0xa3e400cd}},	//   _фиде, _butą_, _ክልላዊ_, पनं_, 
   {{0xc6d04fdc,0x1cbc025c,0x25a80cf4,0x3db000fe}},	//   ستیت, _ཇོན_, _ćale_, ছমিল, 
   {{0x394c01fa,0x65cc0150,0x1fc000cc,0x00000000}},	//   _kuds_, _ﯗﻳﯩﻠ, োনাস, --, 
   {{0x254400e2,0xb5fc003d,0x00000000,0x00000000}},	//   _dēls_, taġu, --, --, 
   {{0x1fd402a6,0x394c004e,0xd3a43d6c,0x1004013d}},	//   _সেইস, _muds_, _дроп, оязм, 
   {{0x7f944fdd,0x06bc0154,0x00000000,0x00000000}},	// [5450] матх, েসরি, --, --, 
   {{0x394c0ea0,0xb8dc031c,0x051400dc,0x25440171}},	//   _ouds_, _ཆལ_, _paṇḍ, _gēls_, 
   {{0x8d7416ac,0x0ca801d5,0x70541411,0x433800f2}},	//   تاذا, итди_, _ىندا, _بسيج_, 
   {{0xdcfc00b0,0xb4e800dc,0xcc840133,0x00000000}},	//   tupā, _यतो_, تۆره_, --, 
   {{0x75b80073,0x205400df,0x00000000,0x00000000}},	//   ेमुळ, _מירל_, --, --, 
   {{0x394c1590,0x0ac407d8,0x6e200b1a,0x051400cd}},	//   _buds_, ющем, _ølbo, _taṇḍ, 
   {{0x26c8001e,0xc09402d3,0xc27c008f,0x88ac00cc}},	//   _đao_, _ውሽጥን_, ברוי, কাসক, 
   {{0x394c4e13,0xab9406ed,0x2b48004e,0x00000000}},	//   _duds_, _набљ, íacs_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x394c00f3,0x00000000,0x00000000,0x00000000}},	//   _fuds_, --, --, --, 
   {{0x2b4c0ba1,0x28f80276,0xf9904fde,0x00000000}},	//   _huec_, _лежь_, _لبن_, --, 
   {{0x629c00f3,0xa5080261,0x29080de2,0x00000000}},	//   _sbpo, сема_, _ñaa_, --, 
   {{0x2b4c067c,0x00000000,0x00000000,0x00000000}},	//   _juec_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2b4c0ba1,0x2b444fdf,0xd1d002d3,0x00e44fe0}},	//   _luec_, _milc_, _ከልቢ_, وتری, 
   {{0xdee40240,0x00000000,0x00000000,0x00000000}},	//   ሚዑን_, --, --, --, 
   {{0x8fa04fe1,0x2b4401e7,0x4fa0034f,0x00000000}},	// [5460] нате, _oilc_, нитв, --, 
   {{0x2b440048,0x629c02d0,0x4f20337e,0x996c06be}},	//   _nilc_, _ubpo, едуб, _nəş_, 
   {{0x2b4c0ba1,0x628c4fe2,0x00000000,0x00000000}},	//   _auec_, mgbo, --, --, 
   {{0x69d40213,0x394c4fe3,0x00000000,0x00000000}},	//   _üzey, _ruds_, --, --, 
   {{0x394c4fe4,0xff080022,0x2b44054e,0x4ac40073}},	//   _suds_, _дҵак_, _bilc_, लांव, 
   {{0x628c4fe5,0xb4e80a28,0x99644fe6,0xd1d0001f}},	//   ngbo, _यत्_, птил, _ከልብ_, 
   {{0x394c1bce,0xca7007d6,0x660c00dc,0x00000000}},	//   _quds_, راوغ, _śakn, --, 
   {{0x2b4c067c,0x2b441db0,0x00000000,0x00000000}},	//   _fuec_, _eilc_, --, --, 
   {{0x394c0204,0xcb6400d8,0x00000000,0x00000000}},	//   _wuds_, _нате_, --, --, 
   {{0x7bc04fe7,0xcff4011a,0x6b9c008e,0x3ae80066}},	//   _irmu, פציה_, _äsga, _ببری_, 
   {{0x18a44fe8,0x98a44fe9,0x7bc00204,0xca60022e}},	//   _нажм, _ниже, _hrmu, monа, 
   {{0x628c01a4,0x15740014,0x00000000,0x00000000}},	//   egbo, _ۂتھ_, --, --, 
   {{0xe9e400c7,0xaf700023,0x00000000,0x00000000}},	//   _ñúre_, ባብትና_, --, --, 
   {{0x7bc00fac,0x628c369d,0xa9e001e1,0x52b000db}},	//   _mrmu, ggbo, _ńkẹ́_, رەجئ, 
   {{0x940800ac,0x88ac015b,0x00000000,0x00000000}},	//   _əməl_, কারক, --, --, 
   {{0x7bc04fea,0x00000000,0x00000000,0x00000000}},	//   _ormu, --, --, --, 
   {{0x84984feb,0x4ea40120,0x00000000,0x00000000}},	// [5470] _رئيس_, зреа, --, --, 
   {{0x9268009d,0x00000000,0x00000000,0x00000000}},	//   _уриа_, --, --, --, 
   {{0x7bc04fec,0x2b4c00cf,0xac940108,0x1ee801e2}},	//   _armu, _suec_, даеш, غومی_, 
   {{0xeae405f9,0xe81c4fed,0x2b44031c,0x00000000}},	//   कस्त_, _पडला_, _silc_, --, 
   {{0xdc3000de,0x00000000,0x00000000,0x00000000}},	//   _pļāp, --, --, --, 
   {{0xbf3800c6,0x4ea42708,0x417401b9,0xc6140183}},	//   _нзяє_, _эрма, _تایس, ডেটা_, 
   {{0x7bc04fee,0xb0e01fe7,0xfaf000ec,0x00000000}},	//   _ermu, _नवाग, دثن_, --, 
   {{0x2b440165,0xac184c04,0xdcfc0356,0x00000000}},	//   _wilc_, _добу_, rupă, --, 
   {{0x7bc001fa,0x628c4fef,0xdee40023,0x00000000}},	//   _grmu, ygbo, ሚዑኒ_, --, 
   {{0xe5780228,0x2b4408c2,0x00000000,0x00000000}},	//   озо_, _uilc_, --, --, 
   {{0xe6184ff0,0xc98401fe,0xab5c0210,0xe85800c0}},	//   юдо_, _хузи, _drże, _даеш_, 
   {{0x59a44ff1,0x69c04ff2,0x00000000,0x00000000}},	//   _कैटर, _irle, --, --, 
   {{0x6844036b,0x290c054e,0x98bc0210,0x00000000}},	//   _ўнла, mnea_, _nutę_, --, 
   {{0x66044294,0x69c005ce,0x290c4ff3,0x9254005b}},	//   _опла, _krle, lnea_, даёт_, 
   {{0xa0204252,0x628c4ff4,0x290c01f7,0x20c8027d}},	//   _çözm, rgbo, onea_, يبري_, 
   {{0x290c3167,0x69c04ff5,0x10a00902,0x00000000}},	//   nnea_, _mrle, кисн, --, 
   {{0xd24c4ff6,0x233400d6,0x290c4ff7,0xd1d00092}},	// [5480] انہ_, _охор, inea_, _ከልቼ_, 
   {{0x290c054e,0xaca00b82,0xc4483267,0x00000000}},	//   hnea_, _ለምለም_, _ویگن_, --, 
   {{0xddcc00e2,0x290c0165,0x5bc400bc,0x00000000}},	//   _iebū, knea_, लम्व, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x5f740372,0x6b980218,0x0b54007b,0x00000000}},	//   _تاجر, gtwg, وشوب_, --, 
   {{0x290c4ff8,0x69c001a6,0xfbd80183,0xda64007b}},	//   enea_, _brle, _দেউত, ذاتي, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3eb84ff9,0x290c4ffa,0x69c00158,0xdcb0005e}},	//   _hart_, gnea_, _drle, _جىر_, 
   {{0x69c04ffb,0x7bc00998,0x06b402f5,0x7d0003ac}},	//   _erle, _urmu, জানি, _imms, 
   {{0xddcc4ffc,0x290c06c8,0x776406be,0x1a641046}},	//   _nebū, anea_, _çixm, _کیژی_, 
   {{0xceb00302,0x2544003a,0xe79408dc,0x38640472}},	//   דית_, _cœlo_, وایک, pbmr_, 
   {{0x3eb802d3,0x980400b1,0x09e008ca,0x00000000}},	//   _lart_, _оялд, _шохн, --, 
   {{0xddcc0153,0xf408007b,0x00000000,0x00000000}},	//   _bebū, سيسى_, --, --, 
   {{0x3eb80210,0x00000000,0x00000000,0x00000000}},	//   _nart_, --, --, --, 
   {{0x98a40034,0x7d0002d0,0x00000000,0x00000000}},	//   _choć_, _omms, --, --, 
   {{0x3eb84ffd,0xf434010b,0x00000000,0x00000000}},	//   _aart_, _пейэ, --, --, 
   {{0x3eb84ffe,0x09c800cd,0x8504009a,0x00000000}},	// [5490] _bart_, _ऽप्य, _جوين, --, 
   {{0x3eb84fff,0x8d8401b9,0x2bb401f9,0xd34402f2}},	//   _cart_, дудд, _आईबा, _زیزه_, 
   {{0xfbd05000,0x3eb85001,0xd1384d01,0x0668313e}},	//   یته_, _dart_, _мхм_, _ﺳﯘﻳﯩ, 
   {{0x3eb85002,0x00000000,0x00000000,0x00000000}},	//   _eart_, --, --, --, 
   {{0x3eb85003,0x69c00421,0x80cc00cd,0x3c640150}},	//   _fart_, _srle, हारे, ткіг, 
   {{0x3eb80493,0x69c009a8,0x7d00349c,0xd1f002d3}},	//   _gart_, _prle, _emms, _ሃይቶ_, 
   {{0xdb0003fa,0xe3b8031c,0xa9a45004,0x2d840332}},	//   stoß, _བླླང, хийд, _íle_, 
   {{0x290c00a8,0x3eb80428,0xd1cc02d3,0xd8740116}},	//   unea_, _zart_, _ኣይተ_, ىمىت_, 
   {{0x290c5005,0x6d4801ab,0x98bc01ef,0x7c840798}},	//   rnea_, _iiea, _hutě_, _јусе, 
   {{0xfb8401d9,0x3eb8022e,0x6f040455,0x06b400cc}},	//   _جدٲی, _xart_, nihc, জাভি, 
   {{0x69c05006,0xd72c02d3,0x00000000,0x00000000}},	//   _urle, _ብእምነ, --, --, 
   {{0xd7545007,0x638401a9,0x00000000,0x00000000}},	//   بلیت_, нгма, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x68e85008,0x6d480437,0xa4300092,0x00000000}},	//   lked, _liea, _በንግድ, --, 
   {{0x67202630,0x56901614,0x3eb80e38,0xa06800ee}},	//   molj, _сајт, _rart_, заба_, 
   {{0x68e85009,0x59140003,0x3eb8500a,0x67201711}},	//   nked, ྲོགས_, _sart_, lolj, 
   {{0x3eb8500b,0x98bc00bc,0xddcc00c0,0x00000000}},	// [54a0] _part_, _autě_, _tebū, --, 
   {{0x6720500c,0x63b4014b,0x6d480076,0x3eb8500d}},	//   nolj, _isyn, _aiea, _qart_, 
   {{0x3eb81c82,0x68e8500e,0x9cc8500f,0x6d481368}},	//   _vart_, kked, зыла_, _biea, 
   {{0x3eb85010,0x672039ae,0xf1a803e6,0x6d480356}},	//   _wart_, holj, _کایه_, _ciea, 
   {{0x3eb85011,0x5b244f35,0x6d48017a,0xbf4400c7}},	//   _tart_, нька, _diea, _аҭал, 
   {{0x3eb80ba1,0x6720107d,0x68e81418,0x4ac4012d}},	//   _uart_, jolj, eked, लागव, 
   {{0xfbd803f4,0x672007f5,0x6d485012,0xdef83419}},	//   _দেখত, dolj, _fiea, _дың_, 
   {{0x6d4801ab,0x63b40267,0x68e85013,0x00000000}},	//   _giea, _osyn, gked, --, 
   {{0x473000b2,0x36d40b59,0x7c2400c7,0x00000000}},	//   گريز, вопр, _рзаҧ, --, 
   {{0x59142fb5,0xd1d00092,0x00000000,0x00000000}},	//   ྲོངས_, _ከግብ_, --, --, 
   {{0x63b45014,0x11380150,0x00000000,0x00000000}},	//   _asyn, _ﺣﺎﯞﯨ_, --, --, 
   {{0x68e85015,0xd90c0517,0xeaf80372,0xd7f8084c}},	//   cked, _دیب_, _ىرەت_, _нул_, 
   {{0x45d001e0,0x00000000,0x00000000,0x00000000}},	//   _ҡошс, --, --, --, 
   {{0xc7e400db,0xc348013d,0x00000000,0x00000000}},	//   _سىىن_, еясе_, --, --, 
   {{0x28c40f4c,0x63b402d0,0x95c8074d,0x6f04014f}},	//   वाचि, _esyn, _хула_, vihc, 
   {{0x90d4179e,0x00000000,0x00000000,0x00000000}},	//   رآزا, --, --, --, 
   {{0x6d481368,0xeeb801b9,0x49380a7c,0x3cf401ad}},	// [54b0] _riea, млаш_, לגלו, ंसने_, 
   {{0x6d4800fb,0x68e801ed,0x7eb85016,0xfe700214}},	//   _siea, zked, нгус_, مدم_, 
   {{0x6d4800da,0xbd680209,0x68e812e8,0xe28c01a9}},	//   _piea, ерче_, yked, _emаs_, 
   {{0x307804ac,0x67205017,0xfe24010b,0x63b40432}},	//   _קאָנ, zolj, уьун, _ysyn, 
   {{0x06b42f8b,0x6d485018,0x7c940131,0x6f04047e}},	//   জাতি, _viea, اشما, pihc, 
   {{0x273800f2,0x6f04014f,0x00000000,0x00000000}},	//   mèng_, qihc, --, --, 
   {{0x99945019,0x68e81666,0x6d48501a,0x27380066}},	//   نپور_, tked, _tiea, lèng_, 
   {{0x88800214,0x7b643452,0x00000000,0x00000000}},	//   ایشن, _әтте, --, --, 
   {{0x68e8501b,0xe73800a6,0x27380066,0x6720072d}},	//   rked, меи_, nèng_, tolj, 
   {{0x68e8501c,0xfd640055,0xa6340023,0x1c18000d}},	//   sked, _akuṇ, _ቢትወደ, _फुटल_, 
   {{0x6720501d,0x273804fb,0x63b40175,0x68e800e5}},	//   rolj, hèng_, _ssyn, pked, 
   {{0xe9443629,0x6720501e,0x27380066,0x63b4007c}},	//   _شرای, solj, kèng_, _psyn, 
   {{0x67202ce2,0x27380066,0x9cd4011a,0x00000000}},	//   polj, jèng_, דורה_, --, 
   {{0xd7240022,0xe5a40798,0x00000000,0x00000000}},	//   _иҭыҧ_, _аики, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x63b40109,0x6fec022e,0x55700116,0x00000000}},	//   _tsyn, _kўch, _өгәт, --, 
   {{0xd0040697,0x63b41477,0x2738020c,0xa50c01f9}},	// [54c0] вете_, _usyn, gèng_, ाचीच_, 
   {{0x1ea8501f,0x8fa02081,0x0e600107,0x00000000}},	//   باري_, рафе, икун, --, 
   {{0x9d4406bb,0xdd900228,0x127800c8,0x16f80327}},	//   вежд, شوش_, _קאטע, ྒྲིམ_, 
   {{0xc1780006,0x2fcc0010,0x5c04010b,0x1634010f}},	//   šės_, _šege_, кяла, דנער_, 
   {{0x622400d1,0xa2c400dc,0x00000000,0x00000000}},	//   _سىڭل, ायप्, --, --, 
   {{0x8c400063,0x27e8010b,0x776403e3,0xabb40022}},	//   јеље, _ýany_, _çixi, уашә, 
   {{0xdc98013e,0xcc30035b,0xb6c400fb,0x9d540117}},	//   _оташ_, лхәы, ғөлд, _рӯзӣ_, 
   {{0x52dc5020,0xdca45021,0x00000000,0x00000000}},	//   _नक्स, _шаби, --, --, 
   {{0x5a940124,0x00000000,0x00000000,0x00000000}},	//   _ареф, --, --, --, 
   {{0xe28c01a9,0x9b445022,0x35b40816,0xe744013d}},	//   _llаb_, _شناو, гбор, гүче_, 
   {{0xa2c400dc,0x13c800cd,0x00000000,0x00000000}},	//   ायन्, ाम्भ, --, --, 
   {{0x57a43955,0xf484179e,0x88900212,0x629802e2}},	//   _ашка, دادی, _виїх, òton, 
   {{0x63a400c7,0xd7b42802,0x00000000,0x00000000}},	//   лырҕ, _अनिच, --, --, 
   {{0x7864007f,0xd1b800ec,0xb5940117,0x00000000}},	//   sčvč, وازا_, _бикш, --, 
   {{0x2738020c,0xb0e000bc,0x6fb40037,0x00000000}},	//   wèng_, _नवआग, _उनहू, --, 
   {{0x058001b9,0x273800f2,0x69c405ac,0xcee80133}},	//   _тушм, tèng_, åhei, ژران_, 
   {{0x31340020,0xb4b407dd,0xab5c031c,0x926813b1}},	// [54d0] _በእግዚ, _аиқә, _arżn, _орна_, 
   {{0xb8d408ea,0x273804fb,0x660c0055,0x00000000}},	//   _ཞི_, rèng_, _śaki, --, 
   {{0x2738020c,0x00000000,0x00000000,0x00000000}},	//   sèng_, --, --, --, 
   {{0x27385023,0x699401a9,0x00000000,0x00000000}},	//   mène_, ҳрих, --, --, 
   {{0xcee85024,0x27385025,0xbc180220,0x0fe001c0}},	//   _قرآن_, lène_, кіші_, _төвү, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe28c022e,0x6e34035a,0x00000000,0x00000000}},	//   _ylаb_, _uzzb, --, --, 
   {{0xe5a45026,0xa5000574,0xeda41086,0x1cb0031c}},	//   қими, _लगेच_, _ишғо, _ཐིར_, 
   {{0xdbd40e78,0x6d545027,0x27380129,0x3b54026b}},	//   mäße, _huza, hène_, _вкур, 
   {{0xc9845028,0x600c0109,0x00000000,0x00000000}},	//   _ауди, lômô, --, --, 
   {{0x66045029,0x6d54502a,0x81e804c5,0xa508013d}},	//   упна, _juza, _মেন_, еена_, 
   {{0x6d54502b,0xa87800c8,0x27380129,0xa50c01f9}},	//   _muza, _װאַר, dène_, ाचेच_, 
   {{0x6d54502c,0x1cb00327,0x7534009d,0xf7940153}},	//   _luza, _ཐིལ_, рээх, _вачэ, 
   {{0x6d54502d,0x27380129,0x06b40154,0x00000000}},	//   _ouza, fène_, জাহি, --, 
   {{0x2738502e,0x97340375,0xe5a4502f,0x6d545030}},	//   gène_, _גרסא_, _сийи, _nuza, 
   {{0x70f400d4,0x00000000,0x00000000,0x00000000}},	//   ачує, --, --, --, 
   {{0x30745031,0x6d545032,0x46b45033,0x00000000}},	// [54e0] русс, _auza, _असाह, --, 
   {{0x6d545034,0x84c40724,0x00000000,0x00000000}},	//   _buza, _сәүд, --, --, 
   {{0x6d544f77,0x273806af,0xb4245035,0xdbd40112}},	//   _cuza, cène_, _معیو, fäße, 
   {{0x6d545036,0x00000000,0x00000000,0x00000000}},	//   _duza, --, --, --, 
   {{0x2544003a,0xeb540e8e,0x5f741e24,0x00000000}},	//   _cœli_, لىنگ, _حاجر, --, 
   {{0x6d545037,0x9d5402f2,0x00000000,0x00000000}},	//   _fuza, _منست, --, --, 
   {{0x6d545038,0x00000000,0x00000000,0x00000000}},	//   _guza, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d545039,0x81e8009e,0xb6f416a4,0x00000000}},	//   _zuza, _মেম_, изиј, --, 
   {{0xeb5404a9,0x6d54503a,0xdb0c005b,0x6e340241}},	//   _ئىلگ, _yuza, ökäy, _àgbì, 
   {{0x6458012c,0x6d540166,0x00000000,0x00000000}},	//   ětin, _xuza, --, --, 
   {{0x2738503b,0x1cb0031c,0xfbb8503c,0xf8b80210}},	//   vène_, _ཐིས_, _इनाम, _आसिय, 
   {{0x290c00d7,0x00000000,0x00000000,0x00000000}},	//   ýkať_, --, --, --, 
   {{0x27381e6f,0x00000000,0x00000000,0x00000000}},	//   tène_, --, --, --, 
   {{0xd138503d,0x245c0022,0xb59401c6,0x00000000}},	//   еха_, _ữme_, _тийш, --, 
   {{0x6d54503e,0x2738503f,0x0fe0004e,0x00000000}},	//   _ruza, rène_, бөгү, --, 
   {{0x6d545040,0x6e982c28,0x443c010a,0x7e6c0150}},	// [54f0] _suza, квар_, _хv_, _ﺷﯘﺑﺎ_, 
   {{0x6d545041,0x50a02309,0x00000000,0x00000000}},	//   _puza, _گەرل, --, --, 
   {{0xadb45042,0x6d545043,0x00000000,0x00000000}},	//   рбеш, _quza, --, --, 
   {{0xcd285044,0x50a03e52,0x6d545045,0x00000000}},	//   رسان_, _دەرل, _vuza, --, 
   {{0x6d5400ca,0x2738067c,0x2078010f,0xaab4155b}},	//   _wuza, nènc_, _בארא, ийді, 
   {{0x8d745046,0x6d545047,0xda6000d4,0x00000000}},	//   _مارا, _tuza, овши, --, 
   {{0x6d5400ec,0x3a2800fd,0xa2c400cd,0x066807d2}},	//   _uuza, лешү_, ायत्, _ﺳﯘﻟﯩ, 
   {{0xad240131,0xd1d00092,0xfbd000db,0x00000000}},	//   _ئىرى, _ከፍቶ_, تتۅ_, --, 
   {{0xac7400f1,0x00000000,0x00000000,0x00000000}},	//   _منځګ, --, --, --, 
   {{0xe738026a,0xa50c00dc,0xefd40023,0x00000000}},	//   ђен_, ाच्च_, _ከይደ_, --, 
   {{0xe5a45048,0xba7400f1,0x00000000,0x00000000}},	//   шини, _داقت, --, --, 
   {{0xf9900244,0xa4440166,0x00000000,0x00000000}},	//   _ربم_, иннд, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf7700502,0x06dc03d4,0xe644010b,0x660c00dc}},	//   _راه_, যোজি, _келп, _śaku, 
   {{0xefd402d3,0xc1e047b8,0x00000000,0x00000000}},	//   _ከይዱ_, नहेग, --, --, 
   {{0x2fcc5049,0x214800e5,0x307400db,0x00000000}},	//   _šega_, ئجسٹ_, йуус, --, 
   {{0x5f0407dd,0x00000000,0x00000000,0x00000000}},	// [5500] азаа, --, --, --, 
   {{0x5438008f,0x5d180131,0x6ecc00bc,0xa20400d4}},	//   _בעפא, ھتاج_, सागु, _впод, 
   {{0xa0a4504a,0x2168504b,0x30e400cc,0x00000000}},	//   _канд, _шини_, _নগৰস, --, 
   {{0xdca44f20,0xa3b83be6,0x616002e3,0x5ca400f0}},	//   ради, _घना_, _ọnwụ, ридб, 
   {{0xfa84504c,0x5bb400d8,0xfc38035b,0x00000000}},	//   йқам, рсеф, уҭа_, --, 
   {{0x3f800153,0xcb640114,0x00000000,0x00000000}},	//   msiu_, шаље_, --, --, 
   {{0xf288008f,0x3f80504d,0x98640014,0x00000000}},	//   אָפֿ, lsiu_, لیاے_, --, 
   {{0x57a4010b,0x97a43d89,0x3f800153,0x98c40815}},	//   ашоа, арол, osiu_, рскл, 
   {{0x6fc82d93,0x3f80504e,0x6e200ac8,0xd1d00092}},	//   रियं, nsiu_, _ølbr, _ከፍታ_, 
   {{0x81bc015b,0x3f800153,0x00000000,0x00000000}},	//   _আপন_, isiu_, --, --, 
   {{0x4ab00037,0x8af8011a,0x3f800419,0x8f340677}},	//   ंजरव, _שהבי, hsiu_, שניף_, 
   {{0x1868504f,0x6b8c1ebd,0x6fc806ab,0x3f800024}},	//   _ради_, šage, रिमं, ksiu_, 
   {{0x660c0a28,0xf9f8009e,0x938800a7,0x3f805050}},	//   _śakt, _অখিল_, ъсна_, jsiu_, 
   {{0x47300212,0x00000000,0x00000000,0x00000000}},	//   _дніс, --, --, --, 
   {{0x57b4012c,0x3f8000c0,0x00000000,0x00000000}},	//   _अनुह, esiu_, --, --, 
   {{0x39440998,0x27385051,0xf0e815bf,0x14740244}},	//   nmms_, mèna_, دىرى_, _ئاغج, 
   {{0x752c5052,0x27380561,0x2ef400d4,0x3f8000c0}},	// [5510] _ikaz, lèna_, бзар, gsiu_, 
   {{0xc7d40375,0x37a803d4,0x00000000,0x00000000}},	//   בומי_, _কছাৰ, --, --, 
   {{0x37dc03d4,0x00000000,0x00000000,0x00000000}},	//   যনিৰ, --, --, --, 
   {{0x98bc00de,0x3f800064,0x00000000,0x00000000}},	//   _mutē_, bsiu_, --, --, 
   {{0x752c5053,0x60d80a1e,0x3f800419,0x00000000}},	//   _mkaz, _עקשנ, csiu_, --, 
   {{0x752c0083,0x5fa00150,0x00000000,0x00000000}},	//   _lkaz, _ءەلم, --, --, 
   {{0x752c5054,0x7db40597,0x09ac00fe,0xc334025d}},	//   _okaz, _وصفا, কিভা, חוס_, 
   {{0x752c5055,0x2d805056,0x44f4031c,0x2918000d}},	//   _nkaz, mshe_, _བཞེར_, õsa_, 
   {{0x1cb0031c,0x7c84084c,0xe7280798,0x00000000}},	//   _ཐྲི_, _фусе, лоид_, --, 
   {{0x2d80009f,0x00000000,0x00000000,0x00000000}},	//   oshe_, --, --, --, 
   {{0x2d803142,0x27380ba1,0xa2c400cd,0xa524117e}},	//   nshe_, gèna_, ायस्, ймод, 
   {{0x2d805057,0x3f800024,0xddcc0171,0xf990007b}},	//   ishe_, ysiu_, _jebš, _آبل_, 
   {{0x09b4000d,0x752c01ef,0x00000000,0x00000000}},	//   _आनुय, _dkaz, --, --, 
   {{0x752c0e61,0xb3b80135,0xf6080133,0x27ec5058}},	//   _ekaz, _བརྫུ, اتیه_, myen_, 
   {{0x27ec5059,0xa114505a,0x2d800240,0x28bc0243}},	//   lyen_, موست, jshe_, ्यपि, 
   {{0x2d800009,0x00000000,0x00000000,0x00000000}},	//   dshe_, --, --, --, 
   {{0x27ec505b,0x1e84505c,0x3f800006,0x9fc801c6}},	// [5520] nyen_, йлам, usiu_, ыгаа_, 
   {{0x3f80505d,0x44200d81,0x27ec0428,0x2d800023}},	//   rsiu_, _ixi_, iyen_, fshe_, 
   {{0x3f80505e,0xe1f0505f,0x27ec5060,0x98a402fb}},	//   ssiu_, _رسد_, hyen_, _skoč_, 
   {{0xa1342163,0xb3b8031c,0x6aa4009e,0x27ec033b}},	//   _درخش, _བརྩུ, _গোলো, kyen_, 
   {{0x27ec5061,0x2d800009,0x28bc00dc,0x46b4041c}},	//   jyen_, ashe_, ्यनि, _असंह, 
   {{0x27ec5062,0x2d805063,0x00000000,0x00000000}},	//   dyen_, bshe_, --, --, 
   {{0x64545064,0x44200393,0x290c5065,0x2d80058a}},	//   _ogyi, _lxi_, fiea_, cshe_, 
   {{0x6454016b,0x6c7401c0,0x27ec000f,0x290c020c}},	//   _ngyi, _муух, fyen_, giea_, 
   {{0x27ec066d,0x83f0013f,0x61ec5066,0x44200200}},	//   gyen_, _mfɑs, hybl, _nxi_, 
   {{0xc6f45067,0x6454013b,0xaae400aa,0x44f40135}},	//   йных_, _agyi, _وسلو, _བཞུར_, 
   {{0x44205068,0x660c0882,0x27ec058a,0x00000000}},	//   _axi_, _śakr, ayen_, --, 
   {{0x27ec5069,0x629c01ab,0x2738067c,0xce34011a}},	//   byen_, _acpo, rèna_, מאית_, 
   {{0x442041a8,0x27ec0fac,0x27380100,0xf44800e5}},	//   _cxi_, cyen_, mènn_, شلسٹ_, 
   {{0x6454506a,0x2d800023,0x2738506b,0x30c400fe}},	//   _egyi, yshe_, pèna_, _একেস, 
   {{0x752c506c,0x4420506d,0xd1f40020,0xd0a805f5}},	//   _tkaz, _exi_, ለፁት_, лтад_, 
   {{0x752c506e,0x442000fb,0xbfa8506f,0x00000000}},	//   _ukaz, _fxi_, әтте_, --, 
   {{0x44f40220,0x2d800076,0x82f801f7,0xce680114}},	// [5530] _ءسىز, wshe_, _گريز_, гред_, 
   {{0x2d805070,0x2564063f,0x74d006b1,0x290c01c4}},	//   tshe_, ịlet_, धाकृ, ziea_, 
   {{0x7054237e,0x8d840228,0x28bc1b61,0x27ec5071}},	//   _وندا, сузд, ्यमि, zyen_, 
   {{0x2d805072,0x27ec5073,0xc0585074,0x00000000}},	//   rshe_, yyen_, _гір_, --, 
   {{0x4fc45075,0x2d805076,0x00000000,0x00000000}},	//   _усна, sshe_, --, --, 
   {{0x28bc00dc,0x00000000,0x00000000,0x00000000}},	//   ्यभि, --, --, --, 
   {{0x27ec5077,0x0c84010b,0x1f000131,0x2bb407f7}},	//   wyen_, _гызм, _تېلف, _आईका, 
   {{0x1cb05078,0x27ec5079,0x25a009a5,0xa764003b}},	//   _ཐིག_, tyen_, _ähli_, окид, 
   {{0x290c04c6,0x61ec0034,0x57e4034b,0x8aa440c4}},	//   riea_, zybl, ждым_, _гред, 
   {{0x27ec507a,0x290c01e0,0x4420004e,0x77340092}},	//   ryen_, siea_, _rxi_, _ሽብርተ, 
   {{0x27ec507b,0xdb240517,0x61ec507c,0x013c0092}},	//   syen_, _بولی, xybl, _በጥቅም, 
   {{0xfbd001d9,0x89340f84,0x22440115,0x27ec507d}},	//   _تتہ_, _اعطا, _ŝoko_, pyen_, 
   {{0x27ec0200,0x737401f4,0x00000000,0x00000000}},	//   qyen_, зысх, --, --, 
   {{0x61ec507e,0xe29800d8,0x00000000,0x00000000}},	//   tybl, јав_, --, --, 
   {{0x2cac507f,0x64a45080,0x676401f7,0x00000000}},	//   _obed_, _дайа, _اُڪل, --, 
   {{0x44f40003,0x44200070,0x61ec0042,0xdd0c0166}},	//   _བཞིར_, _txi_, rybl, dışn, 
   {{0x4420464f,0xdee001ec,0xe3b800d8,0x00000000}},	// [5540] _uxi_, _ﺍﻷﺭﺒ, _тбп_, --, 
   {{0x1cb00135,0xcf4000d4,0x1e840150,0x00000000}},	//   _ཐིང_, днуй, ілем, --, 
   {{0x57b4007d,0xdb0001c7,0x63a4002f,0xdd0c013d}},	//   _अन्ह, stoë, ltkn, gışn, 
   {{0x9b68074d,0x2cac0175,0x01c000cc,0x00000000}},	//   ашка_, _cbed_, _উপপদ, --, 
   {{0x63a402fa,0xcd3c0023,0xcb040451,0x1b485081}},	//   ntkn, _ይኣኽለ, ڪيون_, азди_, 
   {{0x291c00fb,0x2cac05c7,0x29e403f9,0x99645082}},	//   _ajwa_, _ebed_, rɓan_, отил, 
   {{0xcb0405d9,0x7e7c5083,0x63a4035a,0x00000000}},	//   تيون_, _ierp, htkn, --, 
   {{0x81bc0154,0x38c800e5,0x26c40419,0x00000000}},	//   _আপা_, صابی_, edlo_, --, 
   {{0x7e7c1d52,0xd7f85084,0xdddc3b37,0x38c804d3}},	//   _kerp, руй_, kapū, لاکی_, 
   {{0x7bc003f0,0xfaf80421,0x7e7c0356,0x59d45085}},	//   _ismu, _ulī_, _jerp, _وغار, 
   {{0x7e7c46a3,0x18a4036b,0x6350013a,0xa0200139}},	//   _merp, _мажм, _měně, _şöll, 
   {{0x7e7c5086,0x799807ab,0x55040953,0x2be0015b}},	//   _lerp, muvw, ічна, _খেয়ে_, 
   {{0x7e7c000f,0x81e80f22,0xf83801d3,0x00000000}},	//   _oerp, _মেল_, _ازاں_, --, 
   {{0x7e7c0585,0xdcfc0118,0xfd50002b,0x00000000}},	//   _nerp, trpě, _vijṛ, --, 
   {{0x7ae8105c,0x05702ba5,0x00000000,0x00000000}},	//   _modt, _قايد, --, --, 
   {{0x705805f5,0x7ae8037e,0x7e7c5087,0x3b0c0129}},	//   саар_, _lodt, _aerp, _lmdq_, 
   {{0x7e7c5088,0x28bc0c00,0x40343f1c,0x12e402dd}},	// [5550] _berp, ्यति, детс, _дінг, 
   {{0x799802ce,0xfe705089,0x7ae80477,0x00000000}},	//   kuvw, ندم_, _nodt, --, 
   {{0x7e7c508a,0x7bc0508b,0xcdd80640,0x313404b0}},	//   _derp, _asmu, шња_, _неор, 
   {{0x7e7c035a,0xebd808da,0x00000000,0x00000000}},	//   _eerp, йдеш_, --, --, 
   {{0x7e7c0a85,0x7ae801e0,0x60d80375,0xa3dc01ad}},	//   _ferp, _bodt, _הקרנ, णमय_, 
   {{0x7bc0020c,0x291c002d,0xed04004b,0x7e7c032e}},	//   _dsmu, _sjwa_, _کورپ, _gerp, 
   {{0x66e0145e,0x7bc000cf,0x02fc011a,0x00000000}},	//   _lâkû, _esmu, שלומ, --, 
   {{0x28bc508c,0x9f500589,0x7e7c508d,0x76580175}},	//   ्यधि, rzyå_, _zerp, _agvy, 
   {{0x7e7c009a,0x7ae800b5,0xd7640202,0x3cf000af}},	//   _yerp, _fodt, كەنى_, _आवते_, 
   {{0x7ae8508e,0x00000000,0x00000000,0x00000000}},	//   _godt, --, --, --, 
   {{0xe85400c6,0x973000f2,0x28bc07b7,0x00000000}},	//   _فناد, رکها, ्यदि, --, 
   {{0x69c009a5,0x63a40423,0x00000000,0x00000000}},	//   _isle, ttkn, --, --, 
   {{0x81e80154,0x00000000,0x00000000,0x00000000}},	//   _মেং_, --, --, --, 
   {{0x63a4508f,0x36c40212,0xe28401c6,0x00000000}},	//   rtkn, _обіг, ялги, --, 
   {{0x614400ee,0xbbb82c30,0x21685090,0xe298104e}},	//   зева, _इन्क, сиби_, _һап_, 
   {{0x7e7c402f,0x00000000,0x00000000,0x00000000}},	//   _serp, --, --, --, 
   {{0xe2985091,0x25602131,0x635001ef,0x00000000}},	// [5560] _лап_, _hól_, _pěně, --, 
   {{0x69c05092,0x7e7c0240,0x9e580107,0x9754011a}},	//   _osle, _qerp, сраф_, פיעו_, 
   {{0x7e7c5093,0x25605094,0x69c00175,0xd18006a6}},	//   _verp, _jól_, _nsle, _плэй, 
   {{0x7e7c5095,0x6fc85096,0x25605097,0x7ae80477}},	//   _werp, रिशं, _mól_, _sodt, 
   {{0x7e7c5088,0x60c45098,0xe8b80135,0x69c02517}},	//   _terp, _iakm, _དྲེག, _asle, 
   {{0x60c4010c,0x79980175,0x00000000,0x00000000}},	//   _hakm, tuvw, --, --, 
   {{0x60c40a43,0x00000000,0x00000000,0x00000000}},	//   _kakm, --, --, --, 
   {{0x60c45099,0xdcfc00b0,0x7ae80455,0x00000000}},	//   _jakm, rupē, _wodt, --, 
   {{0x60c4509a,0x69c001c0,0x7ae8509b,0x00000000}},	//   _makm, _esle, _todt, --, 
   {{0x2560295f,0x60c4509c,0x35f4509d,0x00000000}},	//   _ból_, _lakm, дпор, --, 
   {{0x60c403ac,0xcfb400eb,0x00000000,0x00000000}},	//   _oakm, ুৎপন, --, --, 
   {{0x60c4011f,0xd84c01f2,0x18a401c6,0x69a00073}},	//   _nakm, tọde_, _хадм, _गमती, 
   {{0xdc8c0020,0xb9e8001f,0xc8c41acf,0x25600332}},	//   መሳሳይ_, _ዮሐ_, _روون_, _eól_, 
   {{0x60c40280,0x256008a5,0x69c002d0,0x00000000}},	//   _aakm, _fól_, _ysle, --, 
   {{0x25601a09,0x60c4509e,0x6700016c,0x31342218}},	//   _gól_, _bakm, _шӯъб, девр, 
   {{0x6ab8509f,0x60c450a0,0x863408c3,0x00000000}},	//   _इस्र, _cakm, _מרוב_, --, 
   {{0x60c450a1,0xc108010b,0x75d450a2,0x00000000}},	// [5570] _dakm, чэре_, _ريکا, --, 
   {{0x60c4035a,0x00000000,0x00000000,0x00000000}},	//   _eakm, --, --, --, 
   {{0xdb00025a,0xedd450a3,0x64580118,0x00000000}},	//   ttoî, بياد, ětiv, --, 
   {{0xfe700372,0x25dc012c,0x6e3402fb,0xbd180212}},	//   ندۅ_, गमती_, _vyzb, пції_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7a840131,0x60c401f5,0x69c00fac,0xcf400150}},	//   ىشىم, _zakm, _psle, _سىزۋ, 
   {{0x60c4102c,0x798802d0,0xe8b8031c,0xed0401ec}},	//   _yakm, _cvdw, _དྲུག, _قوسپ, 
   {{0x25603adf,0x79880857,0x60c400e4,0x69c00010}},	//   _ról_, _dvdw, _xakm, _vsle, 
   {{0x256050a4,0x9ba00a52,0xb86450a5,0x00000000}},	//   _sól_, _لەنى, رايو, --, 
   {{0x256050a6,0x69c050a7,0x6b880c8c,0x752401e4}},	//   _pól_, _tsle, _iveg, _ĉiza, 
   {{0x69c050a8,0x36940150,0x00000000,0x00000000}},	//   _usle, хшыс, --, --, 
   {{0x81bc1c82,0x6b880217,0x1cb00327,0x00000000}},	//   _আপল_, _kveg, _ཐིབ_, --, 
   {{0x2560000f,0x44240205,0x00000000,0x00000000}},	//   _wól_, çm_, --, --, 
   {{0x60c450a9,0x256050aa,0x28bc0a94,0xbefc00dc}},	//   _sakm, _tól_, ्यवि, _एतेन_, 
   {{0xb0c80034,0x224801ec,0xc880013d,0x00000000}},	//   ाएंग, іпби_, ciğä_, --, 
   {{0xa0200c44,0x6b880857,0x00000000,0x00000000}},	//   _çökm, _oveg, --, --, 
   {{0x60c450ab,0xd1740022,0xa44401af,0x00000000}},	// [5580] _vakm, зыӡы, _юнид, --, 
   {{0x60c40548,0x1cdc031c,0x00000000,0x00000000}},	//   _wakm, ལྡན_, --, --, 
   {{0x60c450ac,0x6b8850ad,0xa0c4009a,0x00000000}},	//   _takm, _aveg, _قيدو, --, 
   {{0xc0f8001f,0x00000000,0x00000000,0x00000000}},	//   ለቱም_, --, --, --, 
   {{0x798802d0,0x00000000,0x00000000,0x00000000}},	//   _svdw, --, --, --, 
   {{0x1b3c02d3,0xf1a804d3,0xcb2400f1,0x00000000}},	//   _ፖሊቲካ, _بایه_, وړلو_, --, 
   {{0xdb000129,0x8d60010a,0xa020010b,0xdd9000ae}},	//   stoï, _авсе, _şöhl, _جوز_, 
   {{0xa3dc0316,0x2b440810,0x63b4002d,0xe28c022e}},	//   णमा_, _ehlc_, _opyn, _ldа_, 
   {{0xb7d80a2c,0x0418002b,0x00000000,0x00000000}},	//   سودا_, cūḍa, --, --, 
   {{0x0b4050ae,0x6b9c03cd,0x87000248,0x00000000}},	//   _анун, _åsga, _púpọ, --, 
   {{0x75d40597,0x6b88006f,0x8e940375,0x464c001f}},	//   ريحا, _zveg, ודיו_, _መናገራ, 
   {{0xd7f850af,0xdee00150,0x81bc00cc,0x00000000}},	//   _мул_, _ﺍﻷﺴﺒ, _আপং_, --, 
   {{0x1cb00135,0x6aa400fe,0x00000000,0x00000000}},	//   _ཐིན_, _গোটো, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd7c400aa,0x63b4015d,0x5884030d,0x00000000}},	//   _روژه_, _epyn, _хыçа, --, 
   {{0x2d8c01e4,0xa5e80014,0x1eb80137,0x00000000}},	//   _ĉee_, _ژى۪ل_, үктө_, --, 
   {{0x741450b0,0xaed400a8,0x4ea450b1,0xaac80166}},	// [5590] _سودا, ноаш, дреа, _ürçü_, 
   {{0xa3bc06ab,0x83340022,0x00000000,0x00000000}},	//   ीटर_, _иных, --, --, 
   {{0x6b8804b9,0xbbe800d1,0x00000000,0x00000000}},	//   _sveg, ېرىم_, --, --, 
   {{0x81e802f5,0xe28c022e,0xadbc01ec,0x15e40d2e}},	//   _মেক_, _zdа_, _қабi, _ओपनर_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xaa440408,0x00000000,0x00000000,0x00000000}},	//   нелл, --, --, --, 
   {{0xfe540006,0xac9426b1,0xfd880117,0x00000000}},	//   _акрэ, _павш, _оёти_, --, 
   {{0x6b8850b2,0x2738068c,0xdcfc0064,0xd9400395}},	//   _tveg, mèni_, dupė, лещи, 
   {{0x27380214,0x466000d1,0x00000000,0x00000000}},	//   lèni_, نۇشق, --, --, 
   {{0xd704005b,0x00000000,0x00000000,0x00000000}},	//   енье_, --, --, --, 
   {{0x64a450b3,0x63b40024,0x27380066,0xc9840798}},	//   нана, _spyn, nèni_, _цузи, 
   {{0xed58038e,0x64c82208,0x391400c7,0xb8d400cc}},	//   _již_, ियेश, _имхр, _ছো_, 
   {{0x3958067c,0x27380066,0xf3803007,0x37c43452}},	//   _èrsa_, hèni_, ағым, _ағым_, 
   {{0x27380066,0xa6c801f7,0x00000000,0x00000000}},	//   kèni_, _روبل_, --, --, 
   {{0x273800f2,0xc10400ee,0xe12401af,0x2c10000d}},	//   jèni_, вүнл, емви, _देसू_, 
   {{0x273800f2,0xed58013a,0x00000000,0x00000000}},	//   dèni_, _niž_, --, --, 
   {{0x1e9450b4,0x600806ed,0xb76c010f,0x63b40064}},	// [55a0] ерер, чнам_, ַדאָ, _upyn, 
   {{0xe8bc00dc,0x00000000,0x00000000,0x00000000}},	//   ्युच, --, --, --, 
   {{0xe3b050b5,0x273850b6,0xe0d82dbf,0xa0680408}},	//   _شرک_, gèni_, _евн_, _нана_, 
   {{0x9c2450b7,0x00000000,0x00000000,0x00000000}},	//   ндед, --, --, --, 
   {{0xed580171,0x00000000,0x00000000,0x00000000}},	//   _diž_, --, --, --, 
   {{0x1cb003bd,0xda6450b8,0xd7f80022,0xb4cc000d}},	//   _ཐིམ_, راتي, ҧуп_, _रफ्_, 
   {{0xb9980212,0x5334010f,0xacb00116,0x00000000}},	//   євих_, ענצן_, _چەمب, --, 
   {{0x1570039b,0xc2fc0011,0xdc68009d,0x2c1001f9}},	//   ққиё, ঁচটি_, _хаад_, _देवू_, 
   {{0x7d0050b9,0xdcfc0311,0x0c2001b9,0x487000d1}},	//   _ilms, aspă, _бмтн, ددىس, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xceb00302,0x00000000,0x00000000,0x00000000}},	//   אית_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x27f805ac,0x6298004e,0x35b40153,0x00000000}},	//   øsne_, òtop, _абкр, --, 
   {{0x7d000280,0xa2c450ba,0x00000000,0x00000000}},	//   _olms, ायज्, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x27380502,0x1014034c,0xed5809a8,0x7f940fc0}},	// [55b0] wèni_, ربرد, _riž_, латх, 
   {{0x8e2450bb,0xf9fc0135,0xd34401d5,0x273804fb}},	//   нфед, ྐྱོན_, _سیزه_, tèni_, 
   {{0x1b24009e,0x1ee850bc,0x86780a7c,0x00000000}},	//   যতাই_, بولی_, פראו, --, 
   {{0x7d0002d0,0x27380066,0x61f80fac,0x00000000}},	//   _clms, rèni_, øtle, --, 
   {{0xa2c40490,0x27380066,0xed580010,0x28d00d0d}},	//   ायच्, sèni_, _viž_, _दोषि, 
   {{0x273800f2,0x7d00002f,0x753c002f,0x00000000}},	//   pèni_, _elms, hlsz, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf9fc0327,0xe8bc2d6b,0xc86400db,0x00000000}},	//   ྐྱེན_, ्येच, رەتو_, --, 
   {{0x6d480076,0x66e4013e,0x178000ee,0x00000000}},	//   _ihea, вопа, агым, --, 
   {{0x753c002f,0x00000000,0x00000000,0x00000000}},	//   elsz, --, --, --, 
   {{0x6d4801af,0xadd801ec,0xb74400db,0xb4cc0210}},	//   _khea, здiг, دئيو, रयू_, 
   {{0x6d480092,0x01c004c5,0xa8143d6c,0x00000000}},	//   _jhea, _উপলদ, _идеш, --, 
   {{0x6d480ea3,0x68e81711,0x74f801c0,0x00000000}},	//   _mhea, mjed, хээс_, --, 
   {{0x68e850bd,0xe6102b7e,0x3af01574,0x6d481368}},	//   ljed, _پشت_, _jàpp_, _lhea, 
   {{0x5ec800bd,0x6d48009d,0xa11450be,0xa06850bf}},	//   রামে, _ohea, نوست, даба_, 
   {{0x68e8055a,0xca200092,0xe3b826b1,0x00000000}},	//   njed, _ስጦታዎ, _жби_, --, 
   {{0x1ec80364,0x68e80295,0x53c450c0,0x00000000}},	// [55c0] млаи_, ijed, _агым_, --, 
   {{0x660c0882,0x68e8026c,0x6d4850c1,0x67200162}},	//   _śaky, hjed, _ahea, nnlj, 
   {{0x6d4850c2,0xe12450c3,0x68e850c4,0x271400bc}},	//   _bhea, _амни, kjed, měně_, 
   {{0x68e850c5,0x6d4850c6,0x3974013e,0x00000000}},	//   jjed, _chea, қлиё, --, 
   {{0x6d483c5d,0xdb000112,0xcb640063,0x81e800cc}},	//   _dhea, groß, ваче_, _মেচ_, 
   {{0x68e801bf,0xb1300023,0x00000000,0x00000000}},	//   ejed, _ሰብዓታ, --, --, 
   {{0x6d480ea3,0xcec00316,0x7f5c0113,0x68e850c7}},	//   _fhea, ářů_, _iirq, fjed, 
   {{0x6d4850c8,0x68e802d3,0x7f5c0009,0xc4e400eb}},	//   _ghea, gjed, _hirq, মসুজ, 
   {{0x36d400f3,0x00000000,0x00000000,0x00000000}},	//   гопр, --, --, --, 
   {{0xdb4c0272,0x24900432,0x7f5c0327,0x00000000}},	//   _بێت_, _adym_, _jirq, --, 
   {{0x68e81727,0xd90c50c9,0x81e8015b,0xa97400f3}},	//   bjed, _ویت_, _মেঘ_, _бучј, 
   {{0x68e83c52,0xb4cc00cd,0x00000000,0x00000000}},	//   cjed, रये_, --, --, 
   {{0xd70450ca,0x3af000e8,0xc7a034cb,0x00000000}},	//   _изди, _yàpp_, _вичк, --, 
   {{0x7f5c03f0,0x1ce00327,0x0a2000cc,0x00000000}},	//   _nirq, _ཧོའ_, _ফৰিং_, --, 
   {{0x550400cf,0x00000000,0x00000000,0x00000000}},	//   _ачпа, --, --, --, 
   {{0x6b8c05be,0xdbc80037,0xb2740116,0x73c450cb}},	//   šagi, _hõõr, _өлиш, _йәге, 
   {{0x7f5c047e,0x6d480363,0x324402dd,0xdbc80254}},	// [55d0] _birq, _rhea, теңг, _kõõr, 
   {{0x7f5c50cc,0x6d4836f5,0x63a00fac,0xdbc80254}},	//   _cirq, _shea, _åona, _jõõr, 
   {{0x6d480fa3,0x7f5c50cd,0x249000a9,0x3af0002e}},	//   _phea, _dirq, _ydym_, _ràpp_, 
   {{0xdbc8000d,0x00000000,0x00000000,0x00000000}},	//   _lõõr, --, --, --, 
   {{0x68e81711,0xbd5407dd,0xeab850ce,0xeb9850cf}},	//   vjed, рҭтә, ейл_, хил_, 
   {{0x6d4850d0,0x60c001e4,0xdb0003b2,0x00000000}},	//   _whea, ĵome, ttoá, --, 
   {{0xb7c403a2,0x68e81e31,0x6d4850c6,0xfd8c02d3}},	//   ntãƒ, tjed, _thea, _ኣፍልጦ_, 
   {{0x1ce0003d,0x6d4801f0,0x7f5c50d1,0xdb001ab0}},	//   _ཧོར_, _uhea, _zirq, rtoá, 
   {{0x68e850d2,0x46800131,0x8aa4035b,0x3af0002e}},	//   rjed, ақла, _аред, _tàpp_, 
   {{0x68e81727,0x45a0185e,0x7f5c022e,0x00000000}},	//   sjed, لەتك, _xirq, --, 
   {{0x9dd80150,0xb3b80327,0x00000000,0x00000000}},	//   _ءﺩﯗﺑ, _བརྔུ, --, --, 
   {{0xf2c805e1,0x24082123,0x00000000,0x00000000}},	//   _מע_, енми_, --, --, 
   {{0xa6340046,0x1ce0031c,0x1aa800eb,0x5ec800eb}},	//   _өнді, _ཧོལ_, _গোয়া, রাতে, 
   {{0xa2d41216,0xe5a450d3,0xdddc009b,0x00000000}},	//   ديست, _бики, hapš, --, 
   {{0x7f5c03f0,0xd04c00ac,0x42a400d1,0xe7e00327}},	//   _rirq, _incə, луңғ, ེདམཁ, 
   {{0x7f5c4f40,0x00000000,0x00000000,0x00000000}},	//   _sirq, --, --, --, 
   {{0x7f5c50d4,0xa50400c7,0x00000000,0x00000000}},	// [55e0] _pirq, _аҵҟа_, --, --, 
   {{0x2738068c,0x7f5c1148,0x00000000,0x00000000}},	//   mèns_, _qirq, --, --, 
   {{0xad642d74,0x7f5c0393,0x1d18005b,0xb82400cc}},	//   لانه, _virq, нюдь_, _পৰাত_, 
   {{0x163400c8,0xd24c04d3,0x0c8050d5,0x5ec80154}},	//   אנער_, _ژنی_, бышм, রাধে, 
   {{0xaff400dd,0x7f5c50d6,0x5f4405af,0xeff80092}},	//   _پہلا_, _tirq, _منحل, _ወርዶ_, 
   {{0x4c2801e2,0x00000000,0x00000000,0x00000000}},	//   رتنۍ_, --, --, --, 
   {{0xb3b8025c,0x5ec8015b,0x00000000,0x00000000}},	//   _བརྐུ, রাদে, --, --, 
   {{0xdcb007d2,0xdbc80037,0x95c80022,0x00000000}},	//   _دىر_, _sõõr, ҭуна_, --, 
   {{0xdd940220,0xdbc8000d,0x9c24020f,0x00000000}},	//   _шаңы, _põõr, _сдад, --, 
   {{0x35b450d7,0x00000000,0x00000000,0x00000000}},	//   абор, --, --, --, 
   {{0xdbc8007d,0x8f34008f,0x00000000,0x00000000}},	//   _võõr, רטיג_, --, --, 
   {{0x1ce0025c,0x87e401e0,0x00000000,0x00000000}},	//   _ཧོས_, тһәң_, --, --, 
   {{0x3eb82230,0x27380ba1,0x00000000,0x00000000}},	//   _obrt_, gèns_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x41e40d30,0xd5a040bf,0x850450d8,0xd7d008ec}},	//   біта, _العی, _گوين, तिवच, 
   {{0x16181d8a,0xf0e80131,0x46e400c7,0x2738020c}},	//   _फेयर_, خىرى_, _адән_, sènt_, 
   {{0x932403e6,0x70583bfd,0x850400f1,0x64a801f9}},	// [55f0] _مردن, таар_, _دوين, _कातळ, 
   {{0x6e940120,0xdb0001f4,0x00000000,0x00000000}},	//   рижу, ntoä, --, --, 
   {{0x84e850d9,0x60cc01f4,0x00000000,0x00000000}},	//   _شفیق_, önmä, --, --, 
   {{0x1c1400af,0xe28c01a9,0x7db4007b,0x2ca8000d}},	//   _देहल_, _ulаr_, إصلا, üad_, 
   {{0x92e40154,0xd20000fb,0x00000000,0x00000000}},	//   পসী_, _түңк, --, --, 
   {{0x699450da,0xff040006,0x26140037,0x00000000}},	//   арих, _лясн, _फइली_, --, 
   {{0xaa4450db,0x7e7400dd,0x2fd80e78,0x6ce400f1}},	//   шекл, _چاہئ, _hrsg_, _پړان, 
   {{0x2fd801fa,0x1c1450dc,0xa7b40114,0x00000000}},	//   _krsg_, _देवल_, асој, --, 
   {{0xfaec01ee,0x09e001a9,0x00000000,0x00000000}},	//   _еҫ_, роқн, --, --, 
   {{0xc98450dd,0xb3b80135,0x2738067c,0x78a400de}},	//   _буди, _བརྟུ, vèns_, _ķive, 
   {{0xd83800c6,0xa5081b10,0xd788002b,0x00000000}},	//   _ĩэť_, вена_, aṃ_, --, 
   {{0x7dd001ed,0x2738067c,0x00000000,0x00000000}},	//   lósá, tèns_, --, --, 
   {{0x66e450de,0x26142052,0x3a2c01a9,0x3940031c}},	//   _вола, _फेरी_, _zxdp_, ċist_, 
   {{0x913c0023,0x00000000,0x00000000,0x00000000}},	//   _ተቖጻጺ, --, --, --, 
   {{0xe5a43b9b,0x216850df,0x2738007f,0x212c02d2}},	//   _тийи, тиби_, sèns_, _ífhk_, 
   {{0x602450e0,0x3eb806ea,0x00000000,0x00000000}},	//   адба, _sbrt_, --, --, 
   {{0xde7442c6,0x1e840249,0x4f840014,0xf1d400fb}},	// [5600] لداع, илам, لالہ, _һөтө, 
   {{0x75240115,0x9310004b,0x80b40150,0x9fa00332}},	//   _ĉizi, _وويش, _گەرش, _síóg_, 
   {{0xdd940c8b,0x1278008f,0xd2980375,0x2d9800db}},	//   شجاع, _שאטע, _בשיט, лөтө_, 
   {{0xa0682bcb,0x00000000,0x00000000,0x00000000}},	//   _шама_, --, --, --, 
   {{0xbb340131,0xfe780166,0xa1140116,0x00000000}},	//   ﺮﻩﻙ_, _бүз_, _موھت, --, 
   {{0xc68c0020,0x99d400c6,0x8b200354,0x00000000}},	//   _መጠሪያ_, لتعا, одче, --, 
   {{0x7b84247f,0xb06402d2,0x98c401f4,0x00000000}},	//   _گازە, _áþás, аспл, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x28bc2ecf,0x88b0006c,0xdb000108,0x00000000}},	//   ्यजि, تینچ, ttoä, --, 
   {{0xd6d850e1,0x629850e2,0x29e40b45,0xc6f450e3}},	//   тти_, ótol, rɓar_, иных_, 
   {{0xd564033a,0x00000000,0x00000000,0x00000000}},	//   јтоп, --, --, --, 
   {{0x48e00117,0x00000000,0x00000000,0x00000000}},	//   _мохв, --, --, --, 
   {{0xd70824ce,0x36d40117,0x00000000,0x00000000}},	//   _инде_, _голр, --, --, 
   {{0x473050e4,0x061401d5,0x00000000,0x00000000}},	//   _وروز, ازیب_, --, --, 
   {{0x28bc16d1,0x2fd80009,0xd138030d,0x00000000}},	//   ्यचि, _srsg_, вха_, --, 
   {{0x068050e5,0x12bc02dd,0x09a800cc,0x00000000}},	//   _лгән, _ﺠﻤﻬﻭ, _খনমা, --, 
   {{0xeeb850e6,0x00000000,0x00000000,0x00000000}},	// [5610] ллаш_, --, --, --, 
   {{0xc43c0375,0x59c400bc,0x60c001e4,0x00000000}},	//   _בתחי, लबार, ĵoma, --, 
   {{0x6c7401d5,0x3e6811eb,0x6e1801f7,0xe81c000d}},	//   булх, ршун_, دياس_, _बेना_, 
   {{0xfd1050e7,0x00000000,0x00000000,0x00000000}},	//   وجن_, --, --, --, 
   {{0x8d7450e8,0x7dd000dd,0x05140055,0x2c102d8f}},	//   _چارا, tósá, _adṛḍ, _देखू_, 
   {{0x8d7450e9,0x27e80327,0x8e54010a,0x2ef40114}},	//   _نارا, _ħan_, _кĕлл, _узгр, 
   {{0x7dd001ed,0x2bb800af,0x3d9401fe,0xe880001f}},	//   rósá, _इहवा, _мирр, _የቀረቡ_, 
   {{0xa7d450ea,0x9f6002f0,0x00000000,0x00000000}},	//   متخص, _švéd_, --, --, 
   {{0xe738035b,0x2fc801af,0x2cac50eb,0x9f94002f}},	//   леи_, nwag_, _iced_, _müßt_, 
   {{0xd7040a8f,0x7c24007b,0xe81c0037,0x00000000}},	//   йные_, úire, _बइठा_, --, 
   {{0x2fc80649,0x28b80139,0x00000000,0x00000000}},	//   hwag_, _булэ_, --, --, 
   {{0x2fc80004,0xa5081422,0x46d40037,0x00000000}},	//   kwag_, уема_, _भोरह, --, 
   {{0xd5ac50ec,0x27e815b7,0x4788030d,0x2bf800cd}},	//   وفی_, _çan_, _рсем_, ्निं_, 
   {{0x01e401c6,0x64a80073,0xc0cc0092,0x249c0205}},	//   ойгү, _कावळ, _ቢቂላ_, ştm_, 
   {{0x26c450ed,0xa6c801e0,0xa22802e8,0x00000000}},	//   melo_, _алһа_, ужва_, --, 
   {{0x25a40efa,0x55f40375,0x2fc80af9,0x00000000}},	//   mull_, _למצב_, fwag_, --, 
   {{0x2fc8017a,0x25a4036e,0x00000000,0x00000000}},	// [5620] gwag_, lull_, --, --, 
   {{0x2cac0098,0x63a450ee,0x386000ae,0x00000000}},	//   _aced_, mukn, _úire_, --, 
   {{0x25a450ef,0x26c40770,0xa3b850f0,0xc104010b}},	//   null_, ielo_, _شاکر_, _дүвл, 
   {{0xdca450f1,0x2fc8409c,0x2cac0ba1,0x63a40175}},	//   сади, bwag_, _cced_, oukn, 
   {{0x63a450f2,0x25a450f3,0x2c6c01e1,0x00000000}},	//   nukn, hull_, _sódó_, --, 
   {{0x26c41727,0x628c50f4,0x25a450f5,0x8c40004e}},	//   jelo_, nabo, kull_, чече, 
   {{0x63a40d04,0x00000000,0x00000000,0x00000000}},	//   hukn, --, --, --, 
   {{0x628c50f6,0x25a450f7,0xb924007b,0x7798004e}},	//   habo, dull_, تفعي, акир_, 
   {{0x26c42f42,0x999c00e4,0x19f40014,0x00000000}},	//   felo_, _mytũ_, شِکھ_, --, 
   {{0x26c450f8,0x63a450f9,0x25a40efa,0x2c2000fe}},	//   gelo_, dukn, full_, _বৰকৈ_, 
   {{0x25a450fa,0x628c50fb,0x3ce401a4,0xca6001a9}},	//   gull_, dabo, _knmv_, minа, 
   {{0x26c40032,0x186850fc,0x2fc80076,0xca6001a9}},	//   aelo_, _сади_, ywag_, linа, 
   {{0x628c50fd,0xfd6401f2,0x25a40363,0x63a400e5}},	//   fabo, terọ, aull_, gukn, 
   {{0x26c450fe,0x25a450ff,0x39440066,0xd3241468}},	//   celo_, bull_, llms_, сьми, 
   {{0x25a400f7,0x41e40826,0x8af805d0,0x63a4032e}},	//   cull_, піта, נהלי, aukn, 
   {{0x628c356c,0x63a406d1,0x7bc05100,0xe81c000d}},	//   aabo, bukn, _opmu, _बेडा_, 
   {{0x752c5101,0x2ef45102,0x63a45103,0xf4a000d1}},	// [5630] _ijaz, озар, cukn, _ﺋﯚﺗﯜ, 
   {{0x628c5104,0x2fc80151,0x932400f2,0x3944007c}},	//   cabo, rwag_, _دربن, hlms_, 
   {{0x2fc85105,0x40940075,0x3134016c,0x7bc05106}},	//   swag_, زلەر, _меор, _apmu, 
   {{0x26c45107,0x3ce404d4,0x98bc013d,0xebd8329b}},	//   zelo_, _cnmv_, _ottı_, идеш_, 
   {{0x26c45108,0x752c5109,0x25a40240,0x00000000}},	//   yelo_, _mjaz, zull_, --, 
   {{0x2cac021a,0x26c4510a,0x9ba000db,0x00000000}},	//   _wced_, xelo_, بەكى, --, 
   {{0x26c4510b,0x19840801,0x98bc510c,0x7d2801d3}},	//   velo_, общи_, _attı_, óssá, 
   {{0xe8f8510d,0xed0400db,0x752c510e,0x17140327}},	//   рли_, _بورپ, _njaz, ྲིའམ_, 
   {{0x26c4510f,0x628c5110,0xa6c85111,0x25a401c7}},	//   telo_, yabo, алпа_, wull_, 
   {{0x25a45112,0x09c00154,0x752c5113,0x628c022e}},	//   tull_, ্মবা, _ajaz, xabo, 
   {{0x26c45114,0x628c5115,0x24e85116,0x63a4003e}},	//   relo_, vabo, амни_, wukn, 
   {{0x26c426a5,0x63a43fa0,0x25a45117,0xc95807d6}},	//   selo_, tukn, rull_, _сўз_, 
   {{0x26c45118,0xa3485119,0x752c02bd,0x25a4511a}},	//   pelo_, изма_, _djaz, sull_, 
   {{0x95500020,0x66e42235,0x25a402d3,0x26c4511b}},	//   መለከተ, _фока, pull_, qelo_, 
   {{0x628c511c,0x63a4511d,0xb894001f,0xa508010b}},	//   rabo, sukn, _መቀጠል_, _вейа_, 
   {{0xdfd0511e,0x69c0511f,0x77900133,0x9f840139}},	//   ويز_, _mple, _تییا, жгад, 
   {{0x628c5120,0xe2985121,0x00000000,0x00000000}},	// [5640] pabo, _кап_, --, --, 
   {{0x69c05122,0x27ec0228,0x1ce0081f,0x752c5123}},	//   _ople, ixen_, _ཧོང_, _zjaz, 
   {{0x69c00211,0x290c06d6,0x00000000,0x00000000}},	//   _nple, khea_, --, --, 
   {{0xd83c022a,0xa0c4009f,0xe0d800d8,0xd5b8010f}},	//   íčko_, _بيحو, _твм_, יזעל, 
   {{0x60d402d5,0x69c05124,0x290c01ab,0x00000000}},	//   mdym, _aple, dhea_, --, 
   {{0x60d402d5,0x69c0007b,0x27ec01c4,0x00000000}},	//   ldym, _bple, dxen_, --, 
   {{0x4e24026b,0x00000000,0x00000000,0x00000000}},	//   _дорн_, --, --, --, 
   {{0x60d45125,0x69c0004e,0x290c44ee,0x81bc00cc}},	//   ndym, _dple, ghea_, _ইছা_, 
   {{0x69c05126,0x20100369,0x38700003,0x60d400c0}},	//   _eple, nzyi_, _ġorġ_, idym, 
   {{0xeb300372,0x290c00b0,0xbb2800e5,0x60d40108}},	//   _كۉند, ahea_, _اترے_, hdym, 
   {{0x60d45127,0x752c0003,0x00000000,0x00000000}},	//   kdym, _pjaz, --, --, 
   {{0x290c5128,0x657401ed,0x81b000eb,0x00000000}},	//   chea_, ízha, ওবা_, --, 
   {{0x8d5800c8,0x60d45129,0x49001eeb,0x752c29eb}},	//   יכטי, ddym, _زووق, _vjaz, 
   {{0x167007d6,0x752c012d,0x00000000,0x00000000}},	//   _юқор, _wjaz, --, --, 
   {{0x32041dee,0xfaf800b0,0x26d8013f,0x81d4013e}},	//   ály_, _moī_, ɛso_, морх, 
   {{0xf8bc11b1,0x752c512a,0x79880042,0x60d40064}},	//   ्जिय, _ujaz, _mwdw, gdym, 
   {{0xce68512b,0x3204512c,0x6e9801c6,0x753c0827}},	// [5650] аред_, šly_, йвар_, mosz, 
   {{0xfeb801b9,0xcdd80640,0x753c297b,0xaad8033f}},	//   قامت_, иње_, losz, _योंक, 
   {{0xfbd0168d,0x60d40153,0xf8bc00cd,0x9f4c032e}},	//   ێته_, bdym, ्जाय, _ónýt_, 
   {{0x753c295f,0xc5f0011a,0xbd180212,0xe80c00bc}},	//   nosz, ודע_, оції_, िनमा_, 
   {{0x290c1682,0x69c0512d,0x35cc0c2e,0x999c012c}},	//   vhea_, _sple, ़बड़, _bytů_, 
   {{0x290c04fe,0xe968512e,0x00000000,0x00000000}},	//   whea_, бакл_, --, --, 
   {{0x290c512f,0xd14c001f,0x753c1f6f,0xa9a44c91}},	//   thea_, _ሁኔታው, kosz, чийд, 
   {{0x69c009a8,0x27ec3a49,0xe8e801a9,0x7c480162}},	//   _vple, txen_, смид_, ðsræ, 
   {{0x57e45130,0x290c0072,0x27ec0036,0x753c295c}},	//   здым_, rhea_, uxen_, dosz, 
   {{0x290c5131,0xba745132,0x6b8801f2,0x27ec5133}},	//   shea_, _قامت, _iweg, rxen_, 
   {{0x69c05134,0x6b885135,0x290c0393,0x60d45136}},	//   _uple, _hweg, phea_, ydym, 
   {{0x6b885137,0x753c00dd,0x6d585138,0xd8840214}},	//   _kweg, gosz, nmwa, _فهمی, 
   {{0x6b880327,0x33d402dd,0xe79402f2,0x6d5803ac}},	//   _jweg, мірт, _راشک, imwa, 
   {{0x68f85139,0x6b88513a,0xe68800c6,0x6cf800bc}},	//   _howd, _mweg, _انثى_, ूसँग_, 
   {{0x6720513b,0x6b88513c,0x68f81741,0x753c297b}},	//   milj, _lweg, _kowd, bosz, 
   {{0x672028bf,0x6b880210,0x15f8011a,0x00000000}},	//   lilj, _oweg, _להצע, --, 
   {{0x60d4513d,0x6b8800b4,0x68f8513e,0x6d58513f}},	// [5660] rdym, _nweg, _mowd, dmwa, 
   {{0x68f83b64,0x6d580857,0xc29445cc,0xde680022}},	//   _lowd, emwa, _زیرب, суаa_, 
   {{0x6b8804ba,0x291c0083,0x60d45140,0x00000000}},	//   _aweg, _omwa_, pdym, --, 
   {{0x6b885141,0x6720023a,0x00000000,0x00000000}},	//   _bweg, hilj, --, --, 
   {{0x67205142,0x1c14033d,0x6fbc031c,0xd24c0efc}},	//   kilj, _देखल_, _ཕྱྭའ, _لنی_, 
   {{0x291c0295,0x3f800c95,0x672008a4,0x6d582f63}},	//   _amwa_, mpiu_, jilj, amwa, 
   {{0x672007f5,0x6b885143,0x3f805144,0x2d941de6}},	//   dilj, _eweg, lpiu_, _ортс, 
   {{0x68f80333,0x97a45145,0x6d58035a,0x38c8179e}},	//   _cowd, прол, cmwa, زابی_, 
   {{0x67205146,0x68f8410f,0x6b885147,0x8ba0010b}},	//   filj, _dowd, _gweg, _питж, 
   {{0x660003d4,0x291c0086,0x95c836f0,0x5ec800eb}},	//   fylk, _emwa_, бума_, রাকে, 
   {{0x7ae8105c,0x68f85148,0xaa080014,0x753c5149}},	//   _indt, _fowd, _وزمل_, tosz, 
   {{0x68f80493,0xdb000036,0xe81c000d,0x00000000}},	//   _gowd, kroë, _बेवा_, --, 
   {{0x67201326,0x753c514a,0x439400fb,0x69d401ef}},	//   bilj, rosz, наяс, _ázer, 
   {{0x6600514b,0xdb000d49,0x079808c3,0x05700ee8}},	//   bylk, droë, _פסול, باید, 
   {{0x68f800d8,0x753c01d3,0x66000009,0x6d58514c}},	//   _yowd, posz, cylk, ymwa, 
   {{0xdb000036,0x00000000,0x00000000,0x00000000}},	//   froë, --, --, --, 
   {{0x40341de1,0x20540408,0x00000000,0x00000000}},	// [5670] еетс, çтар, --, --, 
   {{0x6b880537,0x5c2403d4,0x6e981cb8,0xe80c01ef}},	//   _rweg, _বৰ্গ_, івер_, िनता_, 
   {{0x6b88514d,0x6d5803ac,0x7c2400ae,0x00000000}},	//   _sweg, tmwa, úirn, --, 
   {{0x6720514e,0xbd4400d1,0x6d58514f,0x62980419}},	//   zilj, ىپلى, umwa, ótov, 
   {{0xbfa80276,0x6d585150,0xbd44009f,0x00000000}},	//   _нтре_, rmwa, رنهي, --, 
   {{0x187c001f,0x1c144142,0xaa440408,0x68f85151}},	//   _የሀገር_, _देओल_, мелл, _sowd, 
   {{0x68f826de,0x00000000,0x00000000,0x00000000}},	//   _powd, --, --, --, 
   {{0x2d805152,0x6b885153,0x7ae85154,0x68f8058a}},	//   mphe_, _tweg, _endt, _qowd, 
   {{0x672008a4,0x3cf00122,0x6b880223,0xe73809a5}},	//   tilj, ťové_, _uweg, жеп_, 
   {{0xd7545155,0xb5c406ba,0x66000210,0xfbbc0709}},	//   وليت_, ﯨﻤﯩﺰ, tylk, ोबरम, 
   {{0x67205156,0x64a45157,0xe81c00af,0x00000000}},	//   rilj, мана, _बेरा_, --, 
   {{0x291c07a8,0x1ce0025c,0xe854484d,0x2cbc0042}},	//   _umwa_, _ཧོབ_, _قناد, nfwd_, 
   {{0x69d41a22,0x6720031c,0x66000210,0xb5c40150}},	//   भिकी, pilj, sylk, _үйіл, 
   {{0x216803fb,0xe5a40114,0x941c030d,0x00000000}},	//   живи_, _жики, ăрнă_, --, 
   {{0x61445158,0x00000000,0x00000000,0x00000000}},	//   дева, --, --, --, 
   {{0x1ea805d9,0xdb00257c,0x23a802e8,0x00000000}},	//   ڪاري_, troë, _двип_, --, 
   {{0x1f645159,0x2d801a83,0x210c2c35,0x00000000}},	// [5680] дкам, ephe_, _सतीश_, --, 
   {{0x1ea8038b,0x3f800024,0x00000000,0x00000000}},	//   تاري_, rpiu_, --, --, 
   {{0xb9001e81,0xa0680c4a,0x3f80515a,0x7ae80175}},	//   _སྣ_, _мана_, spiu_, _rndt, 
   {{0x3f8008e5,0x9c2402dd,0x7ae802d0,0x00000000}},	//   ppiu_, мдед, _sndt, --, 
   {{0xe81c515b,0x1ea800ec,0x00000000,0x00000000}},	//   _बेला_, _واسي_, --, --, 
   {{0x2a94515c,0x00000000,0x00000000,0x00000000}},	//   ىدىڭ, --, --, --, 
   {{0xadc401af,0x00000000,0x00000000,0x00000000}},	//   _парһ, --, --, --, 
   {{0xa0200365,0x63a40010,0x8c440166,0x00000000}},	//   _şöyl, krkn, _qağä, --, 
   {{0x629c489c,0x99900034,0x969404a9,0x257001ec}},	//   _odpo, ódło_, үрүш, ққыс, 
   {{0x35f4515d,0x7ae8515e,0xa7b401ed,0xd5b8005b}},	//   епор, _undt, ڈشیڈ, осм_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x629c515f,0x63a45160,0xdb0006af,0x00000000}},	//   _adpo, frkn, droé, --, 
   {{0x1ce00135,0x5344447e,0x136800d1,0x00000000}},	//   _ཧོན_, дхва, юшни_, --, 
   {{0x2d805161,0x557008ca,0x59c001f9,0x00000000}},	//   yphe_, _иҳот, _शहार, --, 
   {{0xdb00067c,0x63a40419,0x9e740092,0x00000000}},	//   rroè, arkn, ይንስና_, --, 
   {{0x6ec0038e,0xcfa40116,0x00000000,0x00000000}},	//   र्नु, _ﺷﻪﺭﺗ, --, --, 
   {{0xf07801e0,0xb03400c7,0x7c240332,0x00000000}},	// [5690] жиғә_, хнаш, úirl, --, 
   {{0xb900025c,0xeb981719,0x0dc801d5,0x733400d1}},	//   _སལ_, җик_, жуди_, _سىجا, 
   {{0xdb0006af,0xaad85162,0x70944130,0x3d94011c}},	//   croé, _योगक, _панф, вихр, 
   {{0xa3d4130b,0x2d8006af,0xa9680022,0x00000000}},	//   _सनम_, rphe_, ҿика_, --, 
   {{0x629801a8,0x2078010f,0xdcfc00e2,0x5ec80154}},	//   ðtog, _מארא, espē, রাজে, 
   {{0x8d7400d1,0x2cbc005a,0xa96814b3,0x00000000}},	//   _يازا, sfwd_, пика_, --, 
   {{0xdcfc00ef,0x00000000,0x00000000,0x00000000}},	//   gspē, --, --, --, 
   {{0x7b14004e,0x63a45163,0x61e81427,0x35a8012d}},	//   _nàuf, yrkn, _áfle, _कमज़, 
   {{0x9ba00447,0x7d0402f6,0xa764059f,0x06d00154}},	//   _مەنى, öise, нкид, ়াসি, 
   {{0x3b545164,0xe6185165,0xc98400a8,0xe28c0150}},	//   _акур, здо_, _жуди, _ﺒﺩﻋﻡ_, 
   {{0x6ec000e0,0xdcec00df,0xf99001d9,0xa6f4013d}},	//   र्यु, _subĉ, _نبن_, _үзеш, 
   {{0x29d05166,0x5a28025c,0x00000000,0x00000000}},	//   _iša_, _སྨྲེ_, --, --, 
   {{0xe3b05167,0xdb00002f,0x7534009d,0x00000000}},	//   درج_, nsoß, тээх, --, 
   {{0x95800046,0x6ec05168,0xdb0006af,0xe298009d}},	//   _өлше, र्मु, troé, яаг_, 
   {{0xa1880c04,0xa5082e58,0x71f80014,0xb5c8027d}},	//   ябва_, _нека_, ورِس_, _يوهم_, 
   {{0x2484010e,0x00000000,0x00000000,0x00000000}},	//   _ýom_, --, --, --, 
   {{0x8fa05169,0x4fa0516a,0x6ec000dc,0xdca40022}},	// [56a0] лате, литв, र्भु, ҵаеи, 
   {{0x5f44516b,0x29d00171,0x0f200092,0x00000000}},	//   رنال, _oša_, _ተከለከ, --, 
   {{0x24900076,0x5d68005b,0x00000000,0x00000000}},	//   _keym_, чием_, --, --, 
   {{0x6ec017c6,0xa0a4009d,0x00000000,0x00000000}},	//   र्बु, _яамд, --, --, 
   {{0xfe78516c,0x29d00064,0x00000000,0x00000000}},	//   _жүз_, _aša_, --, --, 
   {{0xdcfc005f,0xbf640014,0x1ce00327,0xfe7800a2}},	//   tspē, _شۯاو, _ཧོམ_, _üį_, 
   {{0x99642cfe,0x9e641e4b,0x00000000,0x00000000}},	//   нтил, _ساسن, --, --, 
   {{0xdb00516d,0xdcfc005f,0x2028001f,0x2bd0043e}},	//   croî, rspē, _ተመስር, _दैवा, 
   {{0xdcfc00e2,0x2d500345,0x00000000,0x00000000}},	//   sspē, _ئێنس, --, --, 
   {{0x5018011a,0x00000000,0x00000000,0x00000000}},	//   פויו, --, --, --, 
   {{0x9f40036e,0x00000000,0x00000000,0x00000000}},	//   _arkë_, --, --, --, 
   {{0xc68c0092,0x00000000,0x00000000,0x00000000}},	//   _መጠለያ_, --, --, --, 
   {{0x38600e89,0x00000000,0x00000000,0x00000000}},	//   _àir_, --, --, --, 
   {{0x249000ad,0xdc100213,0x96b801f0,0x00000000}},	//   _eeym_, nğıc, _худу_, --, 
   {{0xb9e8069c,0xb9cc001f,0xdb000077,0x06d000eb}},	//   _ኮነ_, _ሰኔ_, ntoñ, ়াশি, 
   {{0xa4a40086,0x7414009f,0x00000000,0x00000000}},	//   riòû, _لوبا, --, --, 
   {{0xbfa80276,0x06d00154,0x00000000,0x00000000}},	// [56b0] етхе_, ়ারি, --, --, 
   {{0xdb0006af,0x51840139,0xbed800d8,0x00000000}},	//   droï, _пума, ндух_, --, 
   {{0x3598044e,0xac94023a,0x325400d8,0x00000000}},	//   _መደባት_, ваеш, _швор, --, 
   {{0xeb080b4c,0x00000000,0x00000000,0x00000000}},	//   वस्त_, --, --, --, 
   {{0x4ea42850,0x00000000,0x00000000,0x00000000}},	//   _прва, --, --, --, 
   {{0xfe701aa3,0xaa48516e,0x00000000,0x00000000}},	//   _هدف_, мпла_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x394c0023,0x00000000,0x00000000,0x00000000}},	//   _ምቅይያ, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x29d0516f,0xb8e806ab,0x77904d66,0x24905170}},	//   _tša_, _लॉ_, حیوا, _seym_, 
   {{0x270005f9,0xc8b00532,0x37c402dd,0x5af800df}},	//   _लकीर_, _ملاک, _ұғым_, _קלעצ, 
   {{0x6ec00a94,0x00000000,0x00000000,0x00000000}},	//   र्तु, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa2d4004b,0x9340005b,0x65c400c0,0x00000000}},	//   خيست, иняе, _абка, --, 
   {{0xe578006c,0x78c80fac,0x00000000,0x00000000}},	//   _ўзи_, _åsvø, --, --, 
   {{0xdb0006af,0x00000000,0x00000000,0x00000000}},	//   yroï, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [56c0] --, --, --, --, 
   {{0x64540109,0xa20400c7,0xe194009d,0x00000000}},	//   _izyi, _апод, _ирмэ, --, 
   {{0xbe500023,0x4cd800cc,0x208801d5,0x00000000}},	//   _ዕዳጋታ, ণানু, _ойни_, --, 
   {{0xdca45171,0xd36c04fb,0x9c641d0a,0x60245172}},	//   тади, _دهی_, نهاو, _адма, 
   {{0x20544a2d,0x4fa0013d,0x00000000,0x00000000}},	//   _штор, _кияв, --, --, 
   {{0x9200003a,0xdb000129,0x6ec01d03,0x00000000}},	//   ĭāvi, rroï, र्दु, --, 
   {{0xf9c41680,0x00000000,0x00000000,0x00000000}},	//   احتی, --, --, --, 
   {{0xa2a00882,0xdb0005c7,0x0ae4013d,0x25e40acd}},	//   कृत्, rtoñ, едәй_, टिनी_, 
   {{0xed3401c0,0xdb000113,0xdc68009d,0xb6c4004e}},	//   _сэрэ, stoñ, _цаад_, гөйд, 
   {{0x7d005173,0xed58107d,0xa3e403ba,0x9ba00137}},	//   _homs, _zhž_, फिन_, _مەچى, 
   {{0xceb00302,0xa5500020,0x597400c7,0x260806e3}},	//   בית_, _የኃላፊ, _рызу, ानगी_, 
   {{0xd8245174,0x23dc012d,0x00000000,0x00000000}},	//   _идеи, मिंद, --, --, 
   {{0x69305175,0x7d002611,0x39445176,0x37c400d1}},	//   _دکور, _moms, moms_, _сәйб, 
   {{0x7d003917,0x39445177,0x62985178,0x00000000}},	//   _loms, loms_, ótop, --, 
   {{0x64540083,0x7d005179,0x46a02377,0x00000000}},	//   _ezyi, _ooms, _тајв, --, 
   {{0x39442045,0x00000000,0x00000000,0x00000000}},	//   noms_, --, --, --, 
   {{0x3eb801ee,0x9344007b,0x850400f1,0x00000000}},	// [56d0] _bcrt_, _لخدم, _خوين, --, 
   {{0x3f14517a,0x6e9400db,0x3944004e,0xdcec517b}},	//   адус, الاا, homs_, _dubč, 
   {{0x7d00517c,0x3944517d,0xe2a402d2,0x00000000}},	//   _boms, koms_, _óðal_, --, 
   {{0x7d00517e,0x39442602,0x0f800014,0x00000000}},	//   _coms, joms_, _نیرُ, --, 
   {{0x3944517f,0x02c01810,0x00000000,0x00000000}},	//   doms_, श्वभ, --, --, 
   {{0x3eb80048,0x00000000,0x00000000,0x00000000}},	//   _gcrt_, --, --, --, 
   {{0x7d00013f,0x39440472,0x36fc00e1,0x26c801e4}},	//   _foms, foms_, _लकड़ी_, _ĝao_, 
   {{0x39445180,0xdb000008,0xa818007b,0xdbd4010e}},	//   goms_, stoð, فتخر_, läýe, 
   {{0x7cd40034,0x616001f2,0xa82404fb,0x6d485181}},	//   _wśró, _ọnkụ, دکان, _ikea, 
   {{0x7d000912,0xfb8401d9,0x26a40014,0x49a400f0}},	//   _zoms, _خدٲی, دٕدٲ, _ајда, 
   {{0x394429ef,0x7d000912,0x00000000,0x00000000}},	//   boms_, _yoms, --, --, 
   {{0x39445182,0x81cc0eac,0x7d00022e,0x6384004e}},	//   coms_, লিম_, _xoms, лгма, 
   {{0xa0a40220,0xec34010f,0x00000000,0x00000000}},	//   ғазд, ראָר_, --, --, 
   {{0x6b4c0798,0x290c023a,0x85b000d1,0xe5245183}},	//   fúgi, lkea_, _кәмч, _әдип, 
   {{0x09c00f22,0xbbc016d1,0xdbd400a2,0x00000000}},	//   ্মকা, _शङ्क, däýe, --, 
   {{0x290c5184,0xf1a827b4,0xe3b800f3,0x00000000}},	//   nkea_, ضافه_, _зби_, --, 
   {{0x7d00332c,0xd12c007b,0x00000000,0x00000000}},	// [56e0] _roms, سمك_, --, --, 
   {{0x7d005185,0x6d485186,0x81cc0183,0x290c023a}},	//   _soms, _akea, লিব_, hkea_, 
   {{0xf1d45187,0x290c02f6,0x6d4801ab,0x7d005188}},	//   _көтө, kkea_, _bkea, _poms, 
   {{0x7d000139,0xae5800d4,0xe47c0139,0xd1c40092}},	//   _qoms, трує_, _ütäş, ሽኖች_, 
   {{0x5b240953,0xda780006,0x39442327,0x8ecc015b}},	//   лька, няй_, voms_, রাজগ, 
   {{0x7d000912,0x9e6404fb,0xcb641be7,0x1cb8031c}},	//   _woms, _مازن, гаче_, ྙུང_, 
   {{0x39445189,0xba0000b8,0xf8b801c6,0xdd9035e6}},	//   toms_, _jāḥ_, вөл_, _دوز_, 
   {{0x6d48005a,0x7d000158,0xbc7400d1,0x00000000}},	//   _gkea, _uoms, _ئۇشب, --, 
   {{0x39444a38,0x00000000,0x00000000,0x00000000}},	//   roms_, --, --, --, 
   {{0x290c06c8,0xbb500ed1,0x3944518a,0xaac4007b}},	//   akea_, ﺎﺩﻯ_, soms_, _نتمن, 
   {{0xceb00302,0x3944518b,0x290c0114,0x857001c6}},	//   זית_, poms_, bkea_, йлэх, 
   {{0x2ed0518c,0x290c0789,0xdcfc0024,0x17e40014}},	//   _हस्त, ckea_, rspė, _مستُ, 
   {{0xb6c446e8,0x00000000,0x00000000,0x00000000}},	//   _көнд, --, --, --, 
   {{0xe81c0bb2,0x38c8168d,0x9268005b,0x00000000}},	//   _बेटा_, _ساڵی_, ерба_, --, 
   {{0x95c8518d,0xf194518e,0x06780677,0x00000000}},	//   _чула_, рибь, _אנול, --, 
   {{0xba0000b8,0x4a580677,0x00000000,0x00000000}},	//   _dāḥ_, תדלו, --, --, 
   {{0xeeb8518f,0x386001c3,0x6b4c0162,0x2cb80432}},	// [56f0] клаш_, _ùird_, múgv, _ösdi_, 
   {{0x6d485190,0xefe4001f,0x6b4c0162,0x7eb800db}},	//   _skea, _ማነው_, lúgv, лгус_, 
   {{0x926801c0,0xba00002b,0xcd0401c6,0x62780375}},	//   _яриа_, _gāḥ_, лчди, _בנתנ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc0580efb,0x71240131,0xdc700022,0x00000000}},	//   _бір_, _مىھم, әгәы, --, 
   {{0x6b4c0162,0x49600116,0xee200354,0xba0000cd}},	//   húgv, әниң, _дегi_, _yāḥ_, 
   {{0x290c023a,0xc7700137,0x66740066,0x00000000}},	//   tkea_, өтпө, یددر, --, 
   {{0x5f8801d9,0x6d483425,0xa3d4000d,0x00000000}},	//   _سٕہہ_, _ukea, _सनल_, --, 
   {{0x290c5191,0xe738035b,0x8aa45192,0x6b4c03b2}},	//   rkea_, кеи_, _бред, dúgv, 
   {{0xfa740020,0x290c5193,0xd7041064,0x45a01870}},	//   ጠናከር_, skea_, иные_, مەتك, 
   {{0x79c85194,0x79a416a4,0x490001c6,0x00000000}},	//   _مولف_, _грче, _гүйг, --, 
   {{0xd5b403ce,0x00000000,0x00000000,0x00000000}},	//   _अमरज, --, --, --, 
   {{0x9cd40302,0xe81c09bb,0x00000000,0x00000000}},	//   בורה_, _बेचा_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa2a007b7,0x6b4c1125,0x21740117,0xdcec00de}},	//   कृष्, búgv, ругр, _lubā, 
   {{0xc1b40022,0xd04c03b9,0x6b4c03b2,0x74100116}},	//   _қәгы, _hacə, múgu, تۈۋا, 
   {{0x753c00e5,0xb48401af,0x00000000,0x00000000}},	// [5700] érze, _укыһ, --, --, 
   {{0x38600192,0x26c401e3,0x61e80413,0xba0000dc}},	//   _ùire_, nflo_, _áflo, _tāḥ_, 
   {{0xd04c03e3,0x5dd80b01,0x00000000,0x00000000}},	//   _macə, ъфар_, --, --, 
   {{0xad642f84,0x3074010a,0x81cc0154,0x2d5401bf}},	//   مانه, _гурс, লিদ_, såen_, 
   {{0x3f540ade,0x6b4c00c7,0x00000000,0x00000000}},	//   läum_, húgu, --, --, 
   {{0xa3cc5195,0x6b4c00c7,0x00000000,0x00000000}},	//   _रहन_, kúgu, --, --, 
   {{0xd1cc0020,0xc9a40120,0x6b4c5196,0x00000000}},	//   _ብቃት_, авје_, júgu, --, 
   {{0x4dd8011a,0x00000000,0x00000000,0x00000000}},	//   _בחלו, --, --, --, 
   {{0xd7f85197,0x26c4070d,0x38c80b28,0x00000000}},	//   туй_, fflo_, ناکی_, --, 
   {{0x35b4059f,0x59ac0bae,0xd6b400ec,0xe7440139}},	//   ббор, _टिपर, جندڙ_, бүче_, 
   {{0x0f540302,0x38c80330,0xb8840051,0x6b4c06ea}},	//   שיים_, _ماشی_, _phíđ, túgv, 
   {{0xd7e402bf,0x628c0175,0x499000e5,0x00000000}},	//   _віко, ebbo, _بیٹر, --, 
   {{0xbba40490,0x34940032,0x6b4c06ea,0x00000000}},	//   _ऑटोक, _һайр, rúgv, --, 
   {{0xe7f400ab,0x6b4c0174,0x53442360,0x00000000}},	//   ेहरा_, súgv, рхма, --, 
   {{0x65800053,0x7a08016b,0xded00b82,0xd5d800c5}},	//   _pēhe, bɛte, ረንን_, _बनिज, 
   {{0x09c009bd,0x75d400ec,0x140800c0,0x85b40345}},	//   ্মচা, _نيڪا, _ахоп_, _ئاوس_, 
   {{0x5e640075,0xa3cc00c5,0xb4d400f1,0x00000000}},	// [5710] ەنلە, _रहय_, _نغښت, --, 
   {{0x658000b0,0x56280023,0x00000000,0x00000000}},	//   _wēhe, _ብመንእ, --, --, 
   {{0x658004fe,0x7bc00166,0x45340022,0xdcec002b}},	//   _tēhe, _aqmu, _ыхәт, _subā, 
   {{0xd7a40c2e,0xa3cc0cb4,0x00000000,0x00000000}},	//   _खिंच, _रहम_, --, --, 
   {{0xfc305198,0xac780023,0x6b4c00e4,0x00000000}},	//   وحه_, _ብዓለም_, zúgu, --, 
   {{0x7f945199,0x417412ea,0x09c00154,0x00000000}},	//   _фарх, _دایس, ্মঘা, --, 
   {{0xaa4800cf,0xcb480150,0x00000000,0x00000000}},	//   ыпка_, рiсi, --, --, 
   {{0x6b4c00e4,0x15900116,0x00000000,0x00000000}},	//   vúgu, ﯞﻩﺗﯩ, --, --, 
   {{0x7c2400c6,0xdbd400a2,0x00000000,0x00000000}},	//   úirt, _käýa, --, --, 
   {{0xd764005e,0xa3e401ad,0xa3cc00c5,0x6b4c00c7}},	//   مەنى_, फिस_, _रहब_, túgu, 
   {{0x66e42c1d,0x160c0bc0,0xaa58005b,0x671c00e1}},	//   _ҳола, ानगर_, _сижу_, योगक_, 
   {{0x6b4c00c7,0x00000000,0x00000000,0x00000000}},	//   rúgu, --, --, --, 
   {{0x66e4519a,0xa7a80212,0x6b4c00c7,0x00000000}},	//   _гола, _скла_, súgu, --, 
   {{0xa348519b,0xc68c01d9,0xdce000df,0x81cc0154}},	//   узга_, _کِژ_, rmoĉ, লিস_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x645811a9,0xdcfc00e2,0x3f540036,0x70f400d4}},	//   ətin, rspī, räum_, очує, 
   {{0xde741c3e,0x1ec8016c,0x38600332,0xa3e801af}},	// [5720] مداع, ллаи_, _úirt_, _сдпа_, 
   {{0x93f802e4,0x29c00022,0xa234009d,0x00000000}},	//   _עליי, kóa_, _гэмш, --, 
   {{0xd00c1973,0x6144519c,0xefcc02d3,0x6304129e}},	//   ولہ_, _гена, _ኢደይ_, _نوکل, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69c0406c,0x60d4047e,0x23dc00bc,0x00000000}},	//   _aqle, meym, मिटद, --, 
   {{0x60d4519d,0x5f04519e,0x3ce008a4,0x48a401e0}},	//   leym, _узга, živ_, ҡтым_, 
   {{0xdd9002dd,0x0aa000ec,0x00000000,0x00000000}},	//   _ءور_, سٽيٽ, --, --, 
   {{0x60d42517,0x4b8400ee,0x3a2000df,0xbb500150}},	//   neym, шйән_, ŝipo_, _ﺎﺭﻩ_, 
   {{0x17f800c6,0xd76802a9,0x56f000db,0x00000000}},	//   ارعة_, лшод_, зүлс, --, 
   {{0xd6d8519f,0x60d4014f,0x00000000,0x00000000}},	//   ути_, heym, --, --, 
   {{0x4ef8010f,0x60d451a0,0xda08007b,0x6b4c00e5}},	//   אליג, keym, _حياه_, rúgt, 
   {{0x60d4014f,0x00000000,0x00000000,0x00000000}},	//   jeym, --, --, --, 
   {{0x60d40067,0x79880175,0x00000000,0x00000000}},	//   deym, _htdw, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa3cc0037,0x00000000,0x00000000,0x00000000}},	//   _रहथ_, --, --, --, 
   {{0x60d451a1,0x86340375,0x30142377,0x00000000}},	//   geym, _לרוב_, одбр, --, 
   {{0x1cb8025c,0xc5140220,0x6360063f,0x6e9806ed}},	// [5730] ྙུན_, _ءبىت, ịnar, ивар_, 
   {{0xa3cc007d,0x27e84b16,0xa3e423ef,0x00000000}},	//   _रहत_, _šank_, फिर_, --, 
   {{0x9448009a,0xa280034c,0xedd40691,0xadd802dd}},	//   _ecфt, _آیفو, تياد, рмеу_, 
   {{0x81cc03f4,0x447c010f,0xec1400f1,0x2bb8007b}},	//   লিশ_, ָנגע, يواد, لاتة_, 
   {{0xb94c02d3,0x8bc43f92,0x506401d9,0x9fa40032}},	//   _ምህላዎ, ссед, _دادِ, _мырҙ, 
   {{0x81cc015b,0x8d744b14,0xfbd000ec,0x00000000}},	//   লির_, _هارا, عتن_, --, 
   {{0xecd451a2,0xa6e0009e,0x6564037e,0x201000d0}},	//   _وحرک, বামট, ymkh, čniť_, 
   {{0x5b1051a3,0xe7a8234c,0x2bd851a4,0x798803ac}},	//   змәт, авил_, _پارک_, _dtdw, 
   {{0x0af005f5,0x9f4001ef,0x00000000,0x00000000}},	//   _нүдэ, _hrká_, --, --, 
   {{0x6b880537,0x3f840129,0xe728009d,0x8e2c0240}},	//   _iteg, _émue_, роод_, _ተኸታቲ, 
   {{0x798802d0,0xf3e80375,0xe50801e2,0x00000000}},	//   _gtdw, _שף_, ليدو_, --, 
   {{0x671c0b4c,0xa3e451a5,0x649851a6,0x7c3408a5}},	//   योजक_, फिल_, штор_, _ófrí, 
   {{0x320401f4,0xdb10110e,0x00000000,0x00000000}},	//   älyn_, _ọ̀rọ, --, --, 
   {{0x6b8800ec,0xdb0001df,0xa188036b,0x1b78008f}},	//   _mteg, rroç, ибга_, יטשע, 
   {{0x91e051a7,0xa0a40026,0x7d040108,0x00000000}},	//   море, жабд, öisk, --, 
   {{0x6b8851a8,0x00000000,0x00000000,0x00000000}},	//   _oteg, --, --, --, 
   {{0x6b8851a9,0x60d40579,0xa3cc007d,0x5f0421b5}},	// [5740] _nteg, reym, _रहि_, озаа, 
   {{0x60d451aa,0x00000000,0x00000000,0x00000000}},	//   seym, --, --, --, 
   {{0x9c8831f0,0xb38402f2,0x7e9800cf,0x00000000}},	//   لپاق_, _وجیه, _ۇچار_, --, 
   {{0xa3cc14cf,0xaf3408b0,0x69140cc3,0x60d451ab}},	//   _रहा_, يرەت, _sáen, qeym, 
   {{0x15800952,0x798802d0,0x8e240150,0x00000000}},	//   ﯩﻘﺘﯩ, _stdw, дiгi_, --, 
   {{0x19a80139,0x00000000,0x00000000,0x00000000}},	//   атип_, --, --, --, 
   {{0x6b8851ac,0x9cb451ad,0xa3cc00af,0xd918010b}},	//   _eteg, _ومست, _रहऽ_, иьи_, 
   {{0xad2451ae,0xdd140345,0x00000000,0x00000000}},	//   _فرقو, _بورخ, --, --, 
   {{0x79e801d3,0x6ec01223,0x00000000,0x00000000}},	//   _گواہ_, र्कु, --, --, 
   {{0xcff40375,0x15e802bf,0x00000000,0x00000000}},	//   קציה_, аємо_, --, --, 
   {{0x3ce4014b,0x658002b1,0x7a08013f,0x8e780375}},	//   _kamv_, _pēha, bɛta, יניה, 
   {{0xd4980364,0x938801d5,0x00000000,0x00000000}},	//   шро_, исга_, --, --, 
   {{0x78a0055a,0x439451af,0xdce00219,0x1834484d}},	//   mamv, маяс, jmoč, _براح, 
   {{0x78a051b0,0xdb100129,0x00000000,0x00000000}},	//   lamv, égès, --, --, 
   {{0x645803be,0x37bc015b,0xedc8012c,0x41c40024}},	//   ətim, _অনির, _रहेछ, мёта, 
   {{0x2eec51b1,0x78a00df9,0x00000000,0x00000000}},	//   _şef_, namv, --, --, 
   {{0x752c51b2,0x74144ea7,0xe7ec230e,0x8ea41291}},	// [5750] _imaz, _رودا, जिया_, قصان, 
   {{0x78a00925,0x37bc0154,0x8334009d,0x00000000}},	//   hamv, _অনার, _оных, --, 
   {{0x6ec01cba,0x78a051b3,0x40940131,0x88c0009e}},	//   र्गु, kamv, سلەر, ্যতক, 
   {{0x3ce40a73,0x32100209,0x752c005a,0x78a0009f}},	//   _camv_, myzy_, _jmaz, jamv, 
   {{0x78a00bd7,0x752c0337,0xdfcc00ec,0x316806be}},	//   damv, _mmaz, _مڊل_, mmaz_, 
   {{0x316851b4,0x699403b0,0xae0401d9,0xa3cc0037}},	//   lmaz_, прих, _ٹورى, _रहस_, 
   {{0x752c51b5,0x6b880083,0xc33408a8,0xe9d801b9}},	//   _omaz, _wteg, ווס_, ёки_, 
   {{0xe8f851b6,0x316851b7,0x291851b8,0x78a051b9}},	//   сли_, nmaz_, ósa_, gamv, 
   {{0x6b8851ba,0x6134008e,0x00000000,0x00000000}},	//   _uteg, lülä, --, --, 
   {{0x1dd00ebb,0x31680097,0x28dc07f7,0xdb2400e5}},	//   _सहमत, hmaz_, _मसवि, _فوقی, 
   {{0x2d8001af,0x78a00223,0x316851bb,0x7d28032e}},	//   nqhe_, bamv, kmaz_, _úrsö, 
   {{0x31680097,0xe858008e,0xad5001ec,0x00000000}},	//   jmaz_, _лаеш_, мдiл, --, 
   {{0x27e8007b,0x7d04023a,0x316800d7,0x00000000}},	//   _éan_, öisi, dmaz_, --, 
   {{0x752c13c4,0x61340724,0x66e41171,0xf7c400d1}},	//   _emaz, külä, _хока, _ﻫﻪﻣﺪ, 
   {{0xf7703dfd,0x65800069,0xe29804a2,0xa6e00154}},	//   _شاه_, _iēho, _қан_, বাদট, 
   {{0x485c0020,0x752c0301,0xefd4069d,0x316851bc}},	//   _ወታደሮ, _gmaz, _ራዲዮ_, gmaz_, 
   {{0x94b8011a,0x6024009d,0x00000000,0x00000000}},	// [5760] _המפת, чдаа, --, --, 
   {{0x752c01a2,0x64540bc1,0x78a051bd,0x88c00154}},	//   _zmaz, _iyyi, zamv, ্যিক, 
   {{0xdb000036,0x629c0171,0xbb500150,0xb7000139}},	//   ssoë, _iepo, _ﺎﻭﻻ_, _ñäşl, 
   {{0xad24129e,0x629c51be,0x61443e4f,0x316851bf}},	//   ورنو, _hepo, _хема, cmaz_, 
   {{0x629c51c0,0x63a451c1,0x88c00f22,0x59ac0034}},	//   _kepo, nskn, ্যাক, _टिहर, 
   {{0x629c0588,0x3ce4009a,0x63a451c2,0x78a000f1}},	//   _jepo, _wamv_, iskn, wamv, 
   {{0x78a051c3,0x629c0240,0x00000000,0x00000000}},	//   tamv, _mepo, --, --, 
   {{0x629c51c4,0x6ce8004b,0x2130062c,0x588402d5}},	//   _lepo, _وژنې_, niyh_, чыка, 
   {{0x78a051c5,0x7c2401ab,0xfb840066,0x00000000}},	//   ramv, ùird, _آدری, --, 
   {{0x629c51c6,0x31680097,0x78a051c7,0x752c012c}},	//   _nepo, zmaz_, samv, _smaz, 
   {{0x78a02da1,0x9f400166,0x316851c8,0x6ec027a6}},	//   pamv, _irkä_, ymaz_, र्टु, 
   {{0xe99451c9,0x20100548,0x6e20000d,0xce34011a}},	//   _آهنگ, kyyi_, _ülbe, לאית_, 
   {{0x629c51ca,0x490000db,0x63a4007c,0xd90c01e2}},	//   _bepo, _سووق, gskn, _لیګ_, 
   {{0x629c51cb,0xa3cc302b,0x00000000,0x00000000}},	//   _cepo, _रहर_, --, --, 
   {{0xd0a805f5,0x20100e14,0x3168344b,0x00000000}},	//   йтад_, eyyi_, tmaz_, --, 
   {{0x752c51cc,0x969001b9,0x629c1b99,0x0fe051cd}},	//   _umaz, _تیگش, _eepo, нөгү, 
   {{0x629c51ce,0xb36c0020,0x31684a0f,0x2d800113}},	// [5770] _fepo, በረውን_, rmaz_, wqhe_, 
   {{0x629c51cf,0x316800da,0xd34411fc,0xf1dc0037}},	//   _gepo, smaz_, _ریزه_, मबदन, 
   {{0x753c0e78,0x31681e0c,0x81cc0154,0x1ee824b2}},	//   onsz, pmaz_, লিউ_, تولی_, 
   {{0x629c51d0,0x705451d1,0x6ec02802,0x31680399}},	//   _zepo, _يندا, र्जु, qmaz_, 
   {{0x629c51d2,0xeab00131,0xdb2401d3,0x3b8402dd}},	//   _yepo, نعث_, ڈونی, еліг, 
   {{0x82343c46,0xdb240133,0x98c000b8,0x00000000}},	//   _آریا, وونی, _āvām_, --, 
   {{0x2fc851d3,0xad2451d4,0xe9d800d6,0xba3c0153}},	//   ltag_, _قىسى, іки_, _neįd, 
   {{0xa3cc4c21,0x64b400bc,0x753c01f5,0x06c40150}},	//   _रहल_, _křiž, jnsz, _ﺒﻤﻘﺩ, 
   {{0x2fc851d5,0xfbd051d6,0x7a08016b,0x383402d3}},	//   ntag_, _متل_, bɛto, _ክትርእ, 
   {{0x2fc8481f,0x7c240013,0x6ec00316,0x2cac05c7}},	//   itag_, ùire, र्चु, _hded_, 
   {{0xdb243629,0x6d5851d7,0x64540ac5,0x2fc851d8}},	//   _تولی, olwa, _syyi, htag_, 
   {{0x629c51d9,0x63a401f5,0xa8140120,0x00000000}},	//   _sepo, tskn, _одеш, --, 
   {{0x291c0b6f,0x629c51da,0x68e851db,0x6d58127b}},	//   _ilwa_, _pepo, mded, ilwa, 
   {{0x63a451dc,0x6d5851dd,0x68e851de,0x291c01af}},	//   rskn, hlwa, lded, _hlwa_, 
   {{0x6d5851df,0xa5084961,0x2cac51e0,0x2fc801f5}},	//   klwa, _мека_, _oded_, etag_, 
   {{0x629c052f,0x27ec005b,0x2fc8002f,0x77900244}},	//   _wepo, oven_, ftag_, _جییا, 
   {{0x629c51e1,0x2fc851e2,0x27ec51e3,0x8fa051e4}},	// [5780] _tepo, gtag_, nven_, кате, 
   {{0x6d5851e5,0x2cac003e,0x27ec3544,0x629c00b5}},	//   elwa, _aded_, iven_, _uepo, 
   {{0xa3e412eb,0x291c2252,0x6d5802d0,0x27ec51e6}},	//   फिक_, _olwa_, flwa, hven_, 
   {{0x6d5807ab,0x68e8037e,0x2cac0334,0x27ec0158}},	//   glwa, jded, _cded_, kven_, 
   {{0x27ec0460,0xd24c4f6f,0x68e851e7,0x9b6851e8}},	//   jven_, _منی_, dded, ошка_, 
   {{0x291c51e9,0x6d580c8c,0x4cd802f5,0x8fa00e92}},	//   _alwa_, alwa, ণাগু, _јаре, 
   {{0x27ec51ea,0x1dd051eb,0x999c0006,0xd3340375}},	//   even_, _सहित, _rytų_, ורסה_, 
   {{0x68e851ec,0x27ec0267,0x38c8158b,0x6d58035a}},	//   gded, fven_, سابی_, clwa, 
   {{0xdb003c02,0x00000000,0x00000000,0x00000000}},	//   kroø, --, --, --, 
   {{0x291c51ed,0x68e851ee,0x3f54002f,0x95c80022}},	//   _elwa_, aded, mäus_, оума_, 
   {{0x27ec00db,0x7ae802d0,0x9f40036e,0xc94c0024}},	//   aven_, _iadt, _askë_, _аў_, 
   {{0x7ae84ba8,0x291c02e2,0x6d400174,0x753c01c7}},	//   _hadt, _glwa_, _ílat, unsz, 
   {{0x7ae84511,0x2fc851ef,0x6e24003e,0xfde000bc}},	//   _kadt, xtag_, zzhb, _गैसस_, 
   {{0x2d5400b5,0x2fc801bf,0x6d5802d0,0xd5b801a9}},	//   lået_, vtag_, zlwa, _дси_, 
   {{0x7ae851f0,0x3f542ad7,0x88c00154,0x6d580857}},	//   _madt, häus_, ্যরক, ylwa, 
   {{0x2fc851f1,0x7ae8014f,0x2d54037e,0xba3c010e}},	//   ttag_, _ladt, nået_, _geįe, 
   {{0x403451f2,0x2ef43a23,0x7ae8035a,0x76580108}},	// [5790] ветс, нзар, _oadt, _hyvy, 
   {{0x7ae851f3,0x6d580014,0x0678008f,0x68e851f4}},	//   _nadt, wlwa, ַנדל, zded, 
   {{0x68e851f5,0x6d581a89,0x7b1401ab,0x27ec0165}},	//   yded, tlwa, _gàui, zven_, 
   {{0x7ae80004,0x27ec005c,0x2fc83e04,0x6e240165}},	//   _aadt, yven_, ptag_, rzhb, 
   {{0xeb9851f6,0x0f701ac1,0x3e7c0118,0x68e851f7}},	//   чил_, _ағар, uští_, vded, 
   {{0x4ea451f8,0x317801ed,0x94fc031c,0x3e7c0118}},	//   _юрма, _hisz_, _ཞོའི_, rští_, 
   {{0x6d58434d,0x83f0013f,0x00000000,0x00000000}},	//   plwa, _nyɑn, --, --, 
   {{0x27ec05a1,0xded41b49,0x2d54037e,0x7d0402f6}},	//   tven_, _ጭቆና_, gået_, öist, 
   {{0x68e851f9,0x765800e4,0xe7384494,0x7ae8007b}},	//   rded, _ayvy, зеп_, _fadt, 
   {{0x27e80427,0x00000000,0x00000000,0x00000000}},	//   _šans_, --, --, --, 
   {{0x777851fa,0x6aa0002d,0x79a40139,0x00000000}},	//   _divx, _ielf, _арче, --, 
   {{0x6aa051fb,0x291c51fc,0xf2c8008d,0x672051fd}},	//   _helf, _ulwa_, _לע_, shlj, 
   {{0xd1f0001f,0x74540801,0x6aa00129,0x4aa0000d}},	//   _ልደቱ_, върх, _kelf, _ऐजाव, 
   {{0x201c04fe,0xe5a4004e,0xaa8001a8,0xdb8802dd}},	//   _āti_, _зики, _þýdd, _ﻗﻮﺯﻯ_, 
   {{0x216851fe,0x76580006,0x6aa04118,0x6144009b}},	//   зиви_, _gyvy, _melf, еева, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x1f640032,0x94c800f1,0x00000000,0x00000000}},	// [57a0] екам, _رايې_, --, --, 
   {{0xe9e407ae,0x613801ef,0x00000000,0x00000000}},	//   _đúng_, důle, --, --, 
   {{0x7ae80e78,0x00000000,0x00000000,0x00000000}},	//   _radt, --, --, --, 
   {{0x1c4451ff,0x7ae80c67,0x6aa0003a,0x691408a5}},	//   ннем, _sadt, _aelf, _fáei, 
   {{0x81cc0729,0x2d5403a1,0x6aa05200,0x7ae80ea0}},	//   লিও_, vået_, _belf, _padt, 
   {{0x6aa000a9,0x7ae8014f,0x3f540036,0xb4dc0950}},	//   _celf, _qadt, räus_, _डस्_, 
   {{0x6aa05201,0x2d545202,0xdbd000c5,0x7d04023a}},	//   _delf, tået_, lüüt, öiss, 
   {{0x6aa0127b,0x00000000,0x00000000,0x00000000}},	//   _eelf, --, --, --, 
   {{0xc7d41de1,0x8c405203,0x7ae80280,0x6aa000dd}},	//   емых_, _бете, _tadt, _felf, 
   {{0xc4d004c5,0x6aa003cb,0x00000000,0x00000000}},	//   িযোজ, _gelf, --, --, 
   {{0x60c403ac,0x00000000,0x00000000,0x00000000}},	//   _ockm, --, --, --, 
   {{0x6aa00460,0x81c82158,0x765802f0,0x98a400db}},	//   _zelf, োটা_, _vyvy, _чиде, 
   {{0x93880a8d,0xdcec00ef,0x1a640133,0x53440395}},	//   ясна_, _atbī, _تیژی_, ехва, 
   {{0x60c4035a,0x76580022,0xe7ec0073,0x8c18011a}},	//   _ackm, _tyvy, जिरा_, לוכי, 
   {{0x31782634,0x65780129,0xded00257,0x941c06be}},	//   _pisz_, îchè, የንን_, _ərən_, 
   {{0x0dc8013e,0x3db800cc,0x86580375,0xdbd00254}},	//   ҷуди_, ীবাল, _מדוי, füüt, 
   {{0xb4dc4425,0xa3cc00af,0xe46800db,0x31785204}},	// [57b0] ड़ी_, _रहए_, _ۉلۉۉ_, _visz_, 
   {{0xce685205,0xc43c0302,0x81cc0eac,0x60c402d0}},	//   пред_, _מתחי, লিজ_, _eckm, 
   {{0x850411fc,0x864c0092,0xe46800db,0xf19401c4}},	//   _شوین, _ማንነት, _ىلۉۉ_, _шинь, 
   {{0x6aa05206,0xbd180212,0x7db45207,0xdbd0000d}},	//   _self, нції_, اصلا, büüt, 
   {{0x4fc400c0,0x6aa00142,0x00000000,0x00000000}},	//   _ясна, _pelf, --, --, 
   {{0x2d5401bf,0x61540092,0x00000000,0x00000000}},	//   tåes_, _መብታች, --, --, 
   {{0x2d845208,0x00000000,0x00000000,0x00000000}},	//   _île_, --, --, --, 
   {{0xe7ec033f,0x6aa05209,0x81cc00fe,0x87e400ee}},	//   जिला_, _welf, লিচ_, елиң_, 
   {{0x6aa0520a,0x6b74520b,0xfd44009d,0x3ce00037}},	//   _telf, _алау, _сэрн, õive_, 
   {{0x658000b0,0xe618520c,0x6aa0127b,0xc984030d}},	//   _hēhi, ддо_, _uelf, _зуди, 
   {{0x658002b1,0xb4dc0927,0x64c40073,0x294c0150}},	//   _kēhi, ड़ू_, _वादळ, _ﺍﺭﭖ_, 
   {{0x59b0013d,0xf988007b,0x00000000,0x00000000}},	//   _төшс, _أنني_, --, --, 
   {{0x658000b0,0x81cc00fe,0x81c80154,0x1540520d}},	//   _mēhi, লিছ_, োয়া_, реям, 
   {{0x63a0031c,0xaae00073,0xcc8c0ef6,0x00000000}},	//   _ħond, फ़िक, _ﺗﯩﺰﮔ, --, 
   {{0x4cb40154,0xd7541291,0xa3cc000d,0x00000000}},	//   _ইউনু, _جلوت_, _रहक_, --, 
   {{0x21740063,0x00000000,0x00000000,0x00000000}},	//   ђувр, --, --, --, 
   {{0x2d90520e,0xac900023,0x00000000,0x00000000}},	// [57c0] _atze_, _ዝበሎም_, --, --, 
   {{0xde740a52,0xdd90520f,0xd00c004b,0xdbd0000d}},	//   نداع, لوط_, غلل_, rüüt, 
   {{0x2d545210,0x81cc009e,0xd2b408a8,0x1d085211}},	//   våer_, লিঙ_, _בלית_, межи_, 
   {{0x60c402d0,0x39ac0118,0xdbd00254,0xccd00022}},	//   _uckm, věs_, püüt, ҳцәы, 
   {{0x81c4009e,0x00000000,0x00000000,0x00000000}},	//   _এনি_, --, --, --, 
   {{0x83f0016b,0x7b141e7b,0xf1a803e6,0x3860025c}},	//   _nyɑm, _nàut, _تایه_, _ġir_, 
   {{0x2d542729,0x00000000,0x00000000,0x00000000}},	//   råer_, --, --, --, 
   {{0x23b031a0,0x00000000,0x00000000,0x00000000}},	//   _जिंद, --, --, --, 
   {{0x5ac85212,0xb7d800db,0x59ac000d,0x2d5401e3}},	//   _олам_, رودا_, _टिकर, påer_, 
   {{0xd6d85213,0xaae45214,0x08505215,0x00000000}},	//   фти_, _مسمو, рвью, --, 
   {{0x69140162,0x8b54011a,0x00000000,0x00000000}},	//   _ráev, _יימס_, --, --, 
   {{0xb4dc4425,0x5ed40eac,0x00000000,0x00000000}},	//   ड़े_, _ডোমে, --, --, 
   {{0xaac80562,0x38605216,0xa0100154,0x1c003f6f}},	//   _रामक, _áir_, _সেসব_, लमिल_, 
   {{0x59c40d2c,0x43945217,0x2244002b,0x00000000}},	//   रंपर, рарс, _śoka_, --, 
   {{0xdcec0115,0x9fa401e0,0x00000000,0x00000000}},	//   _subĝ, ҫыуҙ, --, --, 
   {{0x74145218,0x1c002ca5,0x00000000,0x00000000}},	//   _موبا, लमाल_, --, --, 
   {{0x658004fe,0x4fc400a7,0x15e85219,0x46cc521a}},	// [57d0] _rēhi, ъсва, टिकर_, त्वह, 
   {{0xa2d80401,0x00000000,0x00000000,0x00000000}},	//   _पॉप्, --, --, --, 
   {{0x65800374,0x7c2401ab,0x02a40006,0xac940108}},	//   _pēhi, ùirn, _трым, гаеш, 
   {{0x705401ed,0xfd100451,0x506401c6,0xdc5400f2}},	//   _منجا, يجن_, _атга, گرمک, 
   {{0x7b1400db,0x8bc4521b,0x5ed000eb,0x00000000}},	//   _nàus, тсед, _সফরে, --, 
   {{0x6b64521c,0xa2d407b7,0x658000b0,0x2a64005a}},	//   ыкла, म्प्, _wēhi, _pzlb_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb4dc05f9,0xdbd000a2,0x92dc0154,0xa2d803ce}},	//   ड़ो_, _hüýp, ণায়_, _पॉन्, 
   {{0x7b14521d,0xaa9400db,0x00000000,0x00000000}},	//   _càus, _бизч, --, --, 
   {{0xfbd001d9,0x3c4401c6,0x00000000,0x00000000}},	//   _گتہ_, _тэсв, --, --, 
   {{0xdb2401d5,0xc9841cc1,0x668000f1,0xb60800ef}},	//   _حولی, _рузи, لیږل, _nošļ, 
   {{0xa50806a6,0x00000000,0x00000000,0x00000000}},	//   хема_, --, --, --, 
   {{0xf7f4521e,0x00e4521f,0x3cd003d4,0x00000000}},	//   _پسند, یتری, _সোঁৱ, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x21200477,0x6fa807f7,0xf6d40271,0x00000000}},	//   _plkh_, _चौबं, _خزند, --, 
   {{0x46cc454f,0x23340032,0xe1640b24,0xa1140b24}},	//   त्रह, _әхир, ادسي, دورت, 
   {{0xe3b05220,0xa3cc00ab,0xba3c0064,0x92c000cc}},	// [57e0] _ارب_, _रहट_, _neįn, _এঘৰ_, 
   {{0x5ea41dc8,0xa2e45221,0x26c45222,0x139804ae}},	//   امال, _соод, nglo_, _רביע, 
   {{0xdbd00209,0x26c4015d,0x9a840131,0xdba401e1}},	//   _düýp, iglo_, қулл, _ẹ̀ka, 
   {{0x9c24237e,0xdfd00451,0x2d4400c7,0x91b80677}},	//   лдед, _ٿيس_, аҧси_, _אמטי, 
   {{0xdb585223,0x601401af,0x00000000,0x00000000}},	//   нюк_, _сєнє, --, --, 
   {{0x8c4001f4,0x80d02713,0x00000000,0x00000000}},	//   щече, ड्रे, --, --, 
   {{0xcb0407a7,0xdce01050,0x65800374,0x588400ee}},	//   ايىن_, jmoć, _kēhu, лыпа, 
   {{0x391410f6,0xdce005a1,0x0c205224,0x4df800df}},	//   рмир, dmoć, рмән, _אפלא, 
   {{0xed345225,0x7d000327,0xd83800f7,0x31e000bc}},	//   _тэрэ, _inms, ээк_, _पन्ध, 
   {{0xa2d40073,0x3ae81208,0x00000000,0x00000000}},	//   म्म्, _جبری_, --, --, 
   {{0x0f5406a9,0xcf540375,0x4a980a7c,0xaac80bae}},	//   ריים_, רבית_, _ניאג, _रातक, 
   {{0x46640184,0x658000b0,0x628c0334,0xd90c5226}},	//   ырым_, _nēhu, ecbo, _ریخ_, 
   {{0x7d000100,0x00000000,0x00000000,0x00000000}},	//   _mnms, --, --, --, 
   {{0x27f8005c,0x00000000,0x00000000,0x00000000}},	//   æsne_, --, --, --, 
   {{0x34945227,0x86c000f7,0x00000000,0x00000000}},	//   _кайр, _ايىن, --, --, 
   {{0xa2d41223,0x00000000,0x00000000,0x00000000}},	//   म्ब्, --, --, --, 
   {{0xceb80640,0x93a401b9,0x00000000,0x00000000}},	// [57f0] еље_, _ёшид, --, --, 
   {{0xa2c05228,0x9200003a,0x2d8401d3,0xe7c401f9}},	//   _мәск, ĭābi, _élek_, ळंतप, 
   {{0x28a40037,0x518400f5,0x00000000,0x00000000}},	//   _गजलि, _щупа, --, --, 
   {{0x408409a5,0x61f801a8,0x63ac0139,0x219808c3}},	//   _гурб, ætle, _ännä, _שברא, 
   {{0xd7e40597,0x6b745229,0x26c40042,0x3ce00022}},	//   _بك_, алду, yglo_, õiva_, 
   {{0x6458084c,0x7d000076,0x78a401e4,0xd5a4522a}},	//   ştig, _enms, _ĵiva, _وف_, 
   {{0xaa4806bb,0xdb00522b,0x27280208,0x00000000}},	//   ъпка_, groñ, _húng_, --, 
   {{0xe8f8522c,0xc27c008f,0x00000000,0x00000000}},	//   тли_, ערהי, --, --, 
   {{0x69140077,0x178002dd,0x26c4522d,0x057800c7}},	//   _sáes, огым, tglo_, қәкы_, 
   {{0xc1c03769,0x00000000,0x00000000,0x00000000}},	//   ﻭﮔﺮﺍ, --, --, --, 
   {{0x2728004d,0x00000000,0x00000000,0x00000000}},	//   _lúng_, --, --, --, 
   {{0x67d4010a,0x95800006,0x2244002b,0x00000000}},	//   _воду, ўляе, _śoko_, --, 
   {{0x658002b5,0xe364010b,0x3e6c02d2,0x27280051}},	//   _rēhu, икми, _kótí_, _núng_, 
   {{0x290c1505,0x6d48000f,0xe7380acf,0xdbd00254}},	//   ljea_, _ljea, _шел_, _rüüp, 
   {{0x7a08016b,0x6d4800c7,0x7afc00d8,0x21a401b9}},	//   bɛtu, _ojea, _órte, рибм, 
   {{0xe044522e,0x27280208,0x6d48522f,0xdfd05230}},	//   анби, _búng_, _njea, ييز_, 
  
   {{0x272801fb,0xa2cc0864,0x5574010f,0xa07401f4}},	// [5800] _cúng_, _ताप्, _דעקן_, рывш, 
   {{0x1e945231,0xd34400aa,0x6d4801c4,0x27280051}},	//   ррар, _نیټه_, _ajea, _dúng_, 
   {{0x565802d3,0x5d745232,0x00000000,0x00000000}},	//   _ሃንደበ, аудф, --, --, 
   {{0xdbd000af,0x6e300023,0x00000000,0x00000000}},	//   _tüüp, በርካኽ, --, --, 
   {{0x26e402e5,0xccb40212,0x77e40037,0x6e300240}},	//   _कसूर_, ргії_, _कनेक_, በርከኽ, 
   {{0x9e645233,0xdb000165,0x0b4001d5,0x00000000}},	//   _نازن, troñ, ончн, --, 
   {{0x9f400589,0xa2cc1b61,0xf8b85234,0xfaf800b8}},	//   _eskã_, _तान्, гөл_, _bhīr_, 
   {{0x7d000789,0xdb005235,0x6d480200,0xa2d40118}},	//   _unms, rroñ, _gjea, म्त्, 
   {{0xfaf8002b,0x27280208,0x383400c7,0x36d40fac}},	//   _dhīr_, _xúng_, снпр, бопр, 
   {{0x59c40490,0xdb4c0345,0x00000000,0x00000000}},	//   रंदर, _تێت_, --, --, 
   {{0x2a680198,0xceb00375,0x80ac00fe,0x612802d2}},	//   ƙaba_, חית_, _ছান্, _kýld, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x272800d7,0x00000000,0x00000000,0x00000000}},	//   _búnd_, --, --, --, 
   {{0x79885236,0x88540046,0x2728004d,0x00000000}},	//   _kudw, _тиіс_, _rúng_, --, 
   {{0x51845237,0x27280016,0xd1740220,0x4cb4015b}},	//   руга, _súng_, ғыңы, _ইউসু, 
   {{0xd3a45238,0x798804ba,0xba3c0006,0x8678011a}},	//   _кроп, _mudw, _neįm, _ברוו, 
   {{0x79885239,0xc0c00020,0x753c01d3,0x6f640066}},	// [5810] _ludw, _ትንሽ_, misz, مهرم, 
   {{0x6d48002d,0x753c297b,0x79880942,0x63a000a2}},	//   _sjea, lisz, _oudw, _çona, 
   {{0x75240327,0x00000000,0x00000000,0x00000000}},	//   _ċizj, --, --, --, 
   {{0x753c00dd,0xbd68523a,0x272801fb,0xa244114f}},	//   nisz, арче_, _túng_, _ایفل_, 
   {{0xa2cc1d03,0x4ea40063,0x06d400eb,0x00000000}},	//   _ताम्, _врба, _তফসি, --, 
   {{0x753c00e5,0x00000000,0x00000000,0x00000000}},	//   hisz, --, --, --, 
   {{0xaa600023,0x753c0827,0x63b80210,0x00000000}},	//   _ምዕራፋ, kisz, ątni, --, 
   {{0x6f140007,0x6d48209c,0x79880142,0xba3c00a2}},	//   _hozc, _ujea, _dudw, _geįm, 
   {{0x6d58523b,0x468047b3,0x80ac00cc,0x753c1f96}},	//   mowa, оқла, _ছাম্, disz, 
   {{0x79880472,0x6d58523c,0x612800a2,0x09b800fe}},	//   _fudw, lowa, _iýle, _অঙঠা, 
   {{0x79881682,0x6f140175,0xa2cc0073,0x6128010b}},	//   _gudw, _mozc, _ताब्, _yýld, 
   {{0x753c066d,0x6d58523d,0x6b80523e,0x6b88523f}},	//   gisz, nowa, _hilg, _kueg, 
   {{0x6b8803f4,0x6b800598,0x64a400d1,0xba3c0064}},	//   _jueg, _kilg, _һайа, _neįj, 
   {{0x6d580a4d,0x6b80003d,0x6b88006f,0x7988014f}},	//   howa, _jilg, _mueg, _yudw, 
   {{0x6d585240,0x6b8800bd,0x6b805241,0x9f9400a2}},	//   kowa, _lueg, _milg, _düýt_, 
   {{0x6d585242,0xe3c0008e,0x2124011f,0x753c4579}},	//   jowa, _arış_, óoh_, cisz, 
   {{0x6d58006d,0x61280008,0x60d45243,0x6b880c86}},	// [5820] dowa, _nýle, rfym, _nueg, 
   {{0x6b805244,0x612803b2,0x67200427,0x00000000}},	//   _nilg, _sýld, nklj, --, 
   {{0x6d585245,0x6b880421,0x612800a2,0x9d441214}},	//   fowa, _aueg, _aýle, бежд, 
   {{0x6d585246,0x6b880369,0x6b8000a9,0x612800a2}},	//   gowa, _bueg, _ailg, _býle, 
   {{0x6b805247,0x7988014f,0x2bb00bae,0x00000000}},	//   _bilg, _sudw, ुंगा, --, 
   {{0x6f140399,0x6b8804cc,0x6b805248,0xec18151e}},	//   _gozc, _dueg, _cilg, решә_, 
   {{0x6d585249,0x79880ac5,0x6128010b,0x6b802e26}},	//   bowa, _qudw, _eýle, _dilg, 
   {{0x6b88524a,0x6d58068f,0x6b80524b,0x7988047e}},	//   _fueg, cowa, _eilg, _vudw, 
   {{0x6b800003,0x6f140007,0x3eb806d1,0x6b88524c}},	//   _filg, _yozc, _kdrt_, _gueg, 
   {{0xd7f80184,0x35b4524d,0x7988524e,0x753c033f}},	//   _ҡул_, обор, _tudw, wisz, 
   {{0xeb540447,0x753c01ed,0x79e801ed,0x38c80214}},	//   _بىلگ, tisz, _خواہ_, _ناشی_, 
   {{0x6b80524f,0x9f94010b,0xd4980022,0x00000000}},	//   _zilg, _süýt_, ыро_, --, 
   {{0x6b8007d6,0x753c01d3,0x48e0033f,0x00000000}},	//   _yilg, risz, _फ़ोटो_, --, 
   {{0x6d585250,0x87b402e4,0x6b80058a,0xba3c0153}},	//   zowa, _פלוס_, _xilg, _neįk, 
   {{0x6d585251,0x6f142a5c,0x753c1790,0xd0600213}},	//   yowa, _rozc, pisz, ərən, 
   {{0x61f80579,0x6d5801e2,0x6e20000d,0x6f140205}},	//   ætla, xowa, _ülbi, _sozc, 
   {{0x50645252,0x12e43334,0x3eb80175,0xe7ec00e1}},	// [5830] ства, _лінг, _bdrt_, ड़िया_, 
   {{0x6b885253,0xc7240020,0x18140882,0xd244010b}},	//   _rueg, _ስለዚህ, _तथैव_, _гэми, 
   {{0x6d585254,0x6b885255,0xa2cc1810,0x6b8001b9}},	//   towa, _sueg, _तात्, _rilg, 
   {{0x6b880607,0x05d807f7,0x00000000,0x00000000}},	//   _pueg, _बहसब, --, --, 
   {{0x6d58006d,0x6b885256,0x6a843df3,0x00000000}},	//   rowa, _queg, олла, --, 
   {{0x6d585257,0x6b80006c,0x7f945258,0x61280232}},	//   sowa, _qilg, _харх, _výle, 
   {{0x6b805259,0x6d58525a,0x67200427,0x00000000}},	//   _vilg, powa, vklj, --, 
   {{0xad24525b,0x6b80525c,0x6b880139,0xac1800cf}},	//   _بىرى, _wilg, _tueg, _кобу_, 
   {{0x6b80525d,0x3f84525e,0x3b640014,0x6b88000d}},	//   _tilg, _émut_, _کُلِ, _uueg, 
   {{0x637000b5,0x42940b82,0xe73800f0,0x3c4400e3}},	//   mæng, ማንነት_, рео_, _عَلِ, 
   {{0x6370037e,0x672009a8,0xa508525f,0x00000000}},	//   læng, rklj, аена_, --, 
   {{0x73740124,0x00000000,0x00000000,0x00000000}},	//   ҧырх, --, --, --, 
   {{0x27e8020c,0x44240216,0x9cd40375,0xf8b00e56}},	//   _èan_, ám_, חורה_, _سةن_, 
   {{0xe5a40251,0x97e00451,0x7c240192,0x1c540432}},	//   _дики, _آڻين, ùiri, _ýüňü, 
   {{0x637004ce,0x7ec001e1,0x5ec401d9,0x00000000}},	//   hæng, _lápà, ۪ترٲ, --, 
   {{0xa2d802a0,0x6024180b,0x00000000,0x00000000}},	//   _पॉर्, одба, --, --, 
   {{0x9ea85260,0x00000000,0x00000000,0x00000000}},	// [5840] иваа_, --, --, --, 
   {{0x4f040372,0xdbd40166,0x00000000,0x00000000}},	//   онун_, läçe, --, --, 
   {{0xcb0002ab,0xe0d85261,0x2168003b,0x00000000}},	//   लाईड_, _квн_, _вини_, --, 
   {{0xd72802d3,0x6370005c,0x00000000,0x00000000}},	//   _ብዙሕነ, fæng, --, --, 
   {{0x0b905262,0x637000b5,0x93100133,0x00000000}},	//   وجود, gæng, _روێش, --, 
   {{0x78a00175,0x257000e5,0x00000000,0x00000000}},	//   wbmv, láld_, --, --, 
   {{0xcebc012c,0x6370037e,0xdd905263,0x98c41d0b}},	//   _úřad_, mænd, _آور_, оспл, 
   {{0x6370037e,0x257001d3,0xb7c401b9,0xcb001025}},	//   lænd, náld_, проқ, लाउड_, 
   {{0x8c400a52,0x2bd013da,0x36d428a8,0x27fc015d}},	//   _жете, _समया, попр, _crwn_, 
   {{0xa2d801ad,0x00000000,0x00000000,0x00000000}},	//   _पॉल्, --, --, --, 
   {{0x9f400724,0x2d8400dd,0x63b40857,0x4b780375}},	//   _iskä_, _élet_, _avyn, _כאמו, 
   {{0x2bb00034,0x26d8013f,0x637000b5,0xd7f80640}},	//   ुंचा, ɑsom_, hænd, _вук_, 
   {{0x61fc03ac,0x7d04023a,0x27fc0142,0x4d78010f}},	//   _arpl, öisy, _grwn_, ירטע, 
   {{0x63b40024,0x96440166,0x00000000,0x00000000}},	//   _dvyn, _мэйд, --, --, 
   {{0xd1385264,0x2bd008a3,0x15700117,0x00000000}},	//   аха_, _समभा, _оқоё, --, 
   {{0xd4985265,0x0fe000db,0x00000000,0x00000000}},	//   _трк_, мөгү, --, --, 
   {{0x0574004b,0x147401d5,0x272802d2,0x1eb82c12}},	// [5850] _تاود, _باغج, _húna_, өктө_, 
   {{0x272800d2,0x63705266,0x257003b2,0x00000000}},	//   _kúna_, væng, tálg_, --, 
   {{0x272801f1,0x0dc85267,0xf1f4009d,0x00000000}},	//   _júna_, рузи_, _эзнэ, --, 
   {{0x81f801d9,0xba3c010b,0x0ec40073,0x6370005c}},	//   _بہٲر_, _geįi, _लाकड, tæng, 
   {{0x9cb019b6,0x637008a5,0x00000000,0x00000000}},	//   رموت, bænd, --, --, 
   {{0x63705268,0x2fc80218,0x612800a2,0x00000000}},	//   ræng, muag_, _iýla, --, 
   {{0x2728008c,0x2fc85269,0xfa880032,0x65640175}},	//   _núna_, luag_, әсәй_, ylkh, 
   {{0x6370037e,0xac9401c6,0x00000000,0x00000000}},	//   mæne, _хааш, --, --, 
   {{0x25700232,0x272804d4,0x6370005c,0x31d00154}},	//   nále_, _aúna_, læne, াবিশ, 
   {{0x6850069c,0x8aa40276,0x27281d0e,0xc984526a}},	//   _ንኤርት, _фрад, _búna_, _дуди, 
   {{0x2fc801d4,0xfaa8314c,0x2cac0009,0x50c80b9a}},	//   huag_, _ذهني_, _keed_, िलाष, 
   {{0x612800ee,0x2cac526b,0x80e000fe,0x6e20000d}},	//   _oýla, _jeed_, _পোন্, _ülbu, 
   {{0x82e80156,0x68e8103a,0x9d18008f,0x612802d2}},	//   _སྲུའ, meed, צושט, _nýla, 
   {{0x68e80050,0x2cac526c,0x27ec2558,0x272800d2}},	//   leed, _leed_, mwen_, _fúna_, 
   {{0x61280209,0x27ec526d,0x2728007b,0x63700388}},	//   _aýla, lwen_, _gúna_, vænd, 
   {{0x55b8025f,0x2cac526e,0x68e8526f,0x27ec0086}},	//   _המקו, _need_, need, owen_, 
   {{0x637004ce,0x27ec5270,0xd0045271,0x25700419}},	// [5860] tænd, nwen_, пете_, gále_, 
   {{0x27ec092e,0x68e85272,0x61fc0427,0x6fc40124}},	//   iwen_, heed, _trpl, ьауҕ, 
   {{0x68e85273,0x6370037e,0x2cac5274,0xddcc00e2}},	//   keed, rænd, _beed_, _izbū, 
   {{0x637004ce,0x27ec5275,0x68e80014,0x710000c7}},	//   sænd, kwen_, jeed, _иҧса, 
   {{0x68e85276,0x637000b5,0x2cac5277,0x27ec40b1}},	//   deed, pænd, _deed_, jwen_, 
   {{0x27ec5278,0x00000000,0x00000000,0x00000000}},	//   dwen_, --, --, --, 
   {{0xdca45279,0x27ec0a40,0x2cac527a,0x1ee8004b}},	//   _нави, ewen_, _feed_, _پوځی_, 
   {{0x68e801d9,0x2cac527b,0x27281d0e,0x69c006e3}},	//   geed, _geed_, _rúna_, रंजी, 
   {{0xb8d40c2e,0xba3c0024,0x4a20031c,0x27280162}},	//   _जज_, _neįv, འགུལ_, _súna_, 
   {{0x103402e4,0x47300024,0x2bd02802,0xda64030d}},	//   פטים_, еньс, _समता, _евзи, 
   {{0x9a681054,0x27ec0428,0x68e8526f,0x2cac0067}},	//   _امال_, awen_, beed, _yeed_, 
   {{0x27ec0428,0x272800d2,0x68e8527c,0x39400267}},	//   bwen_, _vúna_, ceed, _öis_, 
   {{0x6458084c,0x2fc801d4,0xf484527d,0x942000cf}},	//   ştin, xuag_, بادی, روسۇ, 
   {{0x2fc80083,0xdce00427,0x00000000,0x00000000}},	//   vuag_, dloč, --, --, 
   {{0xf0e80075,0x41e40826,0xa2cc2802,0x00000000}},	//   يىسى_, ніта, _तार्, --, 
   {{0x69c4000a,0xd9bc0154,0x20e40454,0x00000000}},	//   šheg, _আহাম, мсуҳ, --, 
   {{0x752c0170,0xe6c402dd,0x2cac0d63,0x2ef4035b}},	// [5870] _ilaz, _ءتۇي, _reed_, мзар, 
   {{0x752c527e,0x257002fb,0x5184527f,0x2fc85280}},	//   _hlaz, rále_, _нума, ruag_, 
   {{0x27ec5281,0x752c5282,0x68e85283,0x2fc80070}},	//   zwen_, _klaz, yeed, suag_, 
   {{0x637004ce,0x68e85284,0xf1040137,0x71545285}},	//   ræne, xeed, _تۉرۉ_, _آنحض, 
   {{0x68e8015b,0x752c05ce,0x7d24248c,0x2cac000d}},	//   veed, _mlaz, эффе, _veed_, 
   {{0x68e85286,0x31680489,0xf1b02ba2,0x752c0240}},	//   weed, llaz_, _जबान, _llaz, 
   {{0x27ec5287,0x68e85288,0x2cac00af,0x752c01c4}},	//   wwen_, teed, _teed_, _olaz, 
   {{0x752c0109,0x27ec002f,0xed045289,0x00000000}},	//   _nlaz, twen_, _تورپ, --, 
   {{0x27ec528a,0xa2cc3c71,0x3168528b,0x272802d2}},	//   uwen_, _ताल्, ilaz_, _dúnn_, 
   {{0x27ec092e,0x68e8528c,0x752c528d,0x7790528e}},	//   rwen_, seed, _alaz, دیوا, 
   {{0x68e8528f,0xdce009a8,0xe5a45290,0x24e85081}},	//   peed, zloč, ьини, омни_, 
   {{0x752c1529,0x88c40150,0x27ec02e2,0x68e80067}},	//   _claz, _ءتال, pwen_, qeed, 
   {{0x86b00220,0x08400014,0x752c5291,0x00000000}},	//   _пәні, _سۆدُ, _dlaz, --, 
   {{0xb92801f2,0x2b4800c6,0x752c5292,0x66e400c0}},	//   _onwụ_, éach_, _elaz, _цока, 
   {{0x888006ce,0x4adc00cd,0x00000000,0x00000000}},	//   _تیکن, प्यव, --, --, 
   {{0x752c5293,0xf7b401d9,0x386c00e4,0x70f40212}},	//   _glaz, _تۯیش_, _éirô_, нчує, 
   {{0xb92800b4,0x3f040131,0xa44402bf,0x1ea8007b}},	// [5880] _anwụ_, нжаң, _інод, قاضي_, 
   {{0x50cc0a28,0xe7e4068f,0xddcc00e2,0x752c5294}},	//   ānāṃ_, _कहना_, _uzbū, _zlaz, 
   {{0x55505295,0x00000000,0x00000000,0x00000000}},	//   _سپیر, --, --, --, 
   {{0xdce016a3,0x9be402dd,0x00000000,0x00000000}},	//   ploč, дікк, --, --, 
   {{0x6a7401ec,0x00000000,0x00000000,0x00000000}},	//   _ﺸﺭﻭﻉ_, --, --, --, 
   {{0x44fc009e,0x2000010b,0x7c380003,0xddc4014b}},	//   ুঘটক_, _irki_, _ħarġ, _обги, 
   {{0xba3c0006,0xb9845296,0x09e000ea,0x00000000}},	//   _neįt, нтиқ, војн, --, 
   {{0xa2bc043e,0x20000427,0xf8b05297,0x6454035a}},	//   वृत्, _krki_, اکا_, _oxyi, 
   {{0xc8bc17cb,0x3b0400ef,0x00000000,0x00000000}},	//   _एयरट, _pīpē_, --, --, 
   {{0x752c0b91,0xda645298,0x31680cf4,0x1dd0000d}},	//   _slaz, _قاضي, zlaz_, दंपत, 
   {{0x6458084c,0x752c5299,0x6128032e,0x316803e0}},	//   ştil, _plaz, _nýlo, ylaz_, 
   {{0x65740368,0x20000174,0x752c06be,0x05840153}},	//   _chyh, _orki_, _qlaz, куям, 
   {{0x752c1050,0x81cc009e,0x3168030a,0xad24010e}},	//   _vlaz, _শৈল_, vlaz_, lỳär, 
   {{0x3944529a,0x8c400209,0x2bd01b97,0x36d4013d}},	//   lims_, üşin, _समसा, _чокр, 
   {{0x2000529b,0x752c039a,0x3dd8003a,0xc6d01ec7}},	//   _arki_, _tlaz, _nqrw_, _شتوت, 
   {{0x752c04b9,0x3944529c,0x6458529d,0x20000010}},	//   _ulaz, nims_, écié, _brki_, 
   {{0xdbd40037,0x1f240014,0x00000000,0x00000000}},	// [5890] _jääa, کِلہ, --, --, 
   {{0xce68529e,0x2570529f,0x32000122,0x394404cc}},	//   оред_, mála_, _trhy_, hims_, 
   {{0x316852a0,0x257052a1,0xd36c12b7,0x3c9c0521}},	//   plaz_, lála_, _مۇڭ_, _ịzụ_, 
   {{0x200005be,0xad2400a2,0x00000000,0x00000000}},	//   _frki_, dỳär, --, --, 
   {{0x257052a2,0x20000427,0x27340248,0x7f8400cf}},	//   nála_, _grki_, _jùnù_, رلۅن, 
   {{0xba3c0024,0x272800d7,0x00000000,0x00000000}},	//   _neįs, _rúno_, --, --, 
   {{0xad241c5c,0x257000c6,0x2bd0090a,0x00000000}},	//   _كىسى, hála_, _समवा, --, 
   {{0x4a700220,0x394452a3,0x20001d0e,0x00000000}},	//   нықт, gims_, _yrki_, --, 
   {{0x8b6452a4,0xd7e40b32,0x8e600116,0xba740050}},	//   _قائم, емые_, _чеңҗ, _یامت, 
   {{0x2d902a6c,0x257052a5,0x63a0036e,0x65740200}},	//   _kuze_, dála_, _çoni, _shyh, 
   {{0x394452a6,0x26d8033f,0x00000000,0x00000000}},	//   bims_, ęso_, --, --, 
   {{0x2d9052a7,0x67b8117d,0x6e2c1ee0,0x394400db}},	//   _muze_, _فاتح_, ተርናሽ, cims_, 
   {{0x257000c6,0x2d9052a8,0x33d40220,0x291c52a9}},	//   gála_, _luze_, кірт, _iowa_, 
   {{0x20cc1682,0x291c52aa,0x68f800a9,0x00000000}},	//   _ḽi_, _howa_, _hawd, --, 
   {{0x291c23db,0x91e052ab,0x2000009b,0xd6cc11dc}},	//   _kowa_, лоре, _srki_, _اقى_, 
   {{0x291c04cc,0x68f852ac,0x4adc00dc,0x61280216}},	//   _jowa_, _jawd, प्तव, _výlo, 
   {{0x291c52ad,0x2d9052ae,0x68f852af,0x9fc801c0}},	// [58a0] _mowa_, _auze_, _mawd, ягаа_, 
   {{0x2d9052b0,0x291c52b1,0x62900030,0x39441c69}},	//   _buze_, _lowa_, ékoľ, zims_, 
   {{0xaac81b87,0xe28c022e,0x6370007f,0x3944002e}},	//   _राजक, _igа_, cæna, yims_, 
   {{0x291c52b2,0x394452b3,0x68f80368,0x19f401d9}},	//   _nowa_, xims_, _nawd, ہِتھ_, 
   {{0xd24c52b4,0x2000005a,0x310c448b,0xba3c0153}},	//   _ننی_, _urki_, हारः_, _neįr, 
   {{0xdd9052b5,0x291c000a,0x00000000,0x00000000}},	//   _موس_, _aowa_, --, --, 
   {{0x394452b6,0x98a40421,0x291c52b7,0x2d9004a7}},	//   tims_, _aloā_, _bowa_, _guze_, 
   {{0xdbd402f6,0x68f852b8,0xe28c01d5,0x97a403f6}},	//   _pääa, _cawd, _lgа_, нрол, 
   {{0x291c0bd7,0x394452b9,0x2d900bd7,0x68f852ba}},	//   _dowa_, rims_, _zuze_, _dawd, 
   {{0x6c744dc6,0x0e3802d3,0x257002f0,0x2d900432}},	//   _русх, በርኩም, vála_, _yuze_, 
   {{0x18a4355a,0x68f852bb,0xc94c01d5,0x98a4014b}},	//   _заем, _fawd, _бў_, _зиее, 
   {{0x80e00d42,0x291c3743,0x257000c6,0x68f852bc}},	//   _পোস্, _gowa_, tála_, _gawd, 
   {{0x43940032,0x07a00006,0xc7a03893,0x00000000}},	//   лаяс, _бачн, _бичк, --, 
   {{0x257052bd,0x63700579,0x291c03f9,0xe7e452be}},	//   rála_, tæna, _zowa_, _कहता_, 
   {{0x06940302,0x25700296,0x291c52bf,0x41c40024}},	//   _אדום_, sála_, _yowa_, лёта, 
   {{0xf0e82e56,0x2d90009b,0xdb1c0ad9,0xe28c01a9}},	//   بىرى_, _ruze_, _óvæn, _egа_, 
   {{0x2d90098d,0xb4ac0412,0x40341b88,0x068052c0}},	// [58b0] _suze_, गरी_, гетс, _игән, 
   {{0x23880030,0x00000000,0x00000000,0x00000000}},	//   ľujú_, --, --, --, 
   {{0x238801f1,0x255452c1,0xebd4019b,0x7e280006}},	//   žujú_, lāla_, _sへ_, ніца_, 
   {{0xe28c022e,0x06d400fe,0x80a00073,0x00000000}},	//   _zgа_, _তফছি, गुदे, --, 
   {{0x68f852c2,0x255400da,0x291c52c3,0xc05852c4}},	//   _rawd, nāla_, _rowa_, _зір_, 
   {{0x68f852c5,0xaa4452c6,0x2fc852c7,0x2d9000ca}},	//   _sawd, келл, mrag_, _tuze_, 
   {{0x291c166a,0x28d40316,0x68f8047e,0x1ad01fad}},	//   _powa_, _धादि, _pawd, _सारथ, 
   {{0x7c9452c8,0x8d7452c9,0x68f80067,0x255448e1}},	//   _مشكا, _سازا, _qawd, kāla_, 
   {{0xe73810e0,0x68f8014b,0xcdc00150,0xab9400f3}},	//   деп_, _vawd, _шаңқ, _разљ, 
   {{0x64580790,0xecd000ab,0x68f80042,0x27280332}},	//   ştik, _हाँफ, _wawd, _túnm_, 
   {{0x64a452ca,0xdb2452cb,0x68f833e6,0x65c402e8}},	//   кана, _جولی, _tawd, ъбна, 
   {{0x2fc852cc,0x0514002b,0x255400ef,0x00000000}},	//   krag_, _meṇḍ, fāla_, --, 
   {{0x2fc80098,0x2bc81414,0x765801ef,0x00000000}},	//   jrag_, _रिफा, _exvy, --, 
   {{0x69d40793,0x53a004b4,0x00000000,0x00000000}},	//   _äzes, рарб, --, --, 
   {{0x80e009bd,0x2eb804c5,0x9f980166,0x21680305}},	//   _পোষ্, ুভাষ, _käçe_, диви_, 
   {{0x25700306,0x2174024c,0xa2cc1a4e,0x255400ef}},	//   málo_, тугр, _ताक्, bāla_, 
   {{0x637852cd,0x2fc852ce,0xd00c00e3,0x9f980166}},	// [58c0] _осор_, grag_, يلف_, _mäçe_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xba3c0006,0xdb00017a,0xdfd000ec,0x00000000}},	//   _neįp, spoë, _ھيس_, --, 
   {{0x9f9800ee,0x2fc852cf,0x80e0015b,0xdfd00451}},	//   _näçe_, brag_, _পোর্, _پيس_, 
   {{0x307452d0,0xdb880116,0x00000000,0x00000000}},	//   _бурс, _ﺗﻮﺭﻯ_, --, --, 
   {{0xa2d40b4c,0x00000000,0x00000000,0x00000000}},	//   म्च्, --, --, --, 
   {{0xb9e40617,0x4ef800df,0x00000000,0x00000000}},	//   اتتۇ, _קהלו, --, --, 
   {{0x1be852d1,0x00000000,0x00000000,0x00000000}},	//   _одби_, --, --, --, 
   {{0x2bc852d2,0xdb84004e,0x106800d1,0x00000000}},	//   _रिया, _агаи, ﺳﯩﺪﯨ, --, 
   {{0x2554005f,0x4990035b,0x00000000,0x00000000}},	//   vāla_, ышәт, --, --, 
   {{0x75d40472,0x00000000,0x00000000,0x00000000}},	//   ديجا, --, --, --, 
   {{0x255400da,0xb4ac0c93,0x2bc84721,0x18a452d3}},	//   tāla_, गरे_, _रिमा, _радм, 
   {{0x69d40598,0xd6d052d4,0x00000000,0x00000000}},	//   _äzer, _نقش_, --, --, 
   {{0x2fc852d5,0xc0e00023,0x80e00154,0x399800e5}},	//   vrag_, _ሓሳረ_, _পোল্, _kés_, 
   {{0x30e40220,0x673c0240,0xe85001d5,0x320400bc}},	//   лсаң, ësje, _نچید, íly_, 
   {{0x399800f4,0x2fc852d6,0x25703b7b,0xf77000d1}},	//   _més_, trag_, náll_, _ئاچ_, 
   {{0x705805f5,0xea780023,0x2fc80076,0x104802e8}},	// [58d0] хаар_, _ብዕድመ_, urag_, фяви_, 
   {{0x0dc802f4,0xdb00030a,0x2fc852d7,0x612800a2}},	//   дуди_, ksoñ, rrag_, _yýlk, 
   {{0x3998529d,0xa2740150,0x00000000,0x00000000}},	//   _nés_, _бұру_, --, --, 
   {{0x2fc8017a,0x51840408,0x244c00c7,0x00000000}},	//   prag_, _шупа, ẽme_, --, 
   {{0xfc302a14,0xffd801e0,0x63a00240,0x00000000}},	//   يحه_, _иҫтә_, _çont, --, 
   {{0x39980694,0xf59c0092,0x00000000,0x00000000}},	//   _bés_, _ወደዚያ_, --, --, 
   {{0xa96852d8,0x8d8452d9,0x00000000,0x00000000}},	//   ника_, _ауад, --, --, 
   {{0x6c8400dd,0x399852da,0x64580311,0x257000e5}},	//   _ملزم, _dés_, ştii, gáll_, 
   {{0x6c5452db,0x2b4800c6,0x39980248,0xfd4401c0}},	//   _скау, éacs_, _eés_, _тэрн, 
   {{0x399852dc,0x7c240037,0xd2880023,0xd1dc0240}},	//   _fés_, äire, ኒስትሪ_, _ዕጡቕ_, 
   {{0x2d8c020c,0x39980098,0x272852dd,0xe7e400ab}},	//   _kiee_, _gés_, _júni_, _कहवा_, 
   {{0x4adc0b9c,0x27280248,0x00000000,0x00000000}},	//   प्रव, _múni_, --, --, 
   {{0x66e452de,0x10680952,0x6fd4012d,0x00000000}},	//   _бола, ﺳﯩﺮﯨ, यूमू, --, 
   {{0xdc38008f,0x2d8c0076,0x612800a2,0x6658074d}},	//   געשר, _liee_, _iýli, _палă, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2d8c0363,0x21683edf,0x217406ed,0x255400e2}},	//   _niee_, хиби_, ѓувр, mālo_, 
   {{0x656452df,0xe29852e0,0x20540a5b,0x179400df}},	// [58e0] mokh, _пап_, утвр, ָדעל_, 
   {{0x65640aa5,0x2d8c0076,0x272852e1,0xe1f80022}},	//   lokh, _aiee_, _búni_, _зго_, 
   {{0x2554005f,0x614452e2,0x56b4010f,0xfd6401ec}},	//   nālo_, _бена, רפען_, анжү, 
   {{0x656452e3,0x2b98068c,0x61f80008,0x2d8c52e4}},	//   nokh, _bèc_, ætlu, _ciee_, 
   {{0x399852e5,0x60d40368,0x61280321,0x6fb40006}},	//   _sés_, mgym, _nýli, _вёсц, 
   {{0x656452e6,0x399810ba,0x2b980ba1,0x7bc40024}},	//   hokh, _pés_, _dèc_, šiuo, 
   {{0x656452e3,0x2120020c,0x87e015c3,0xa3d40412}},	//   kokh, _kokh_, ەتپە, ांड_, 
   {{0x399800f7,0x60d452e7,0x2120002e,0x64480134}},	//   _vés_, ngym, _jokh_, _ɛfir, 
   {{0x656452e8,0x399852e9,0x28d407d0,0x98140127}},	//   dokh, _wés_, _धारि, ابعا, 
   {{0xd6d852ea,0x399852eb,0x2728043b,0x249052ec}},	//   хти_, _tés_, _yúni_, _agym_, 
   {{0x60d401e6,0xa2cc1098,0x00000000,0x00000000}},	//   kgym, _ताज्, --, --, 
   {{0x656452ed,0x33cc0952,0x6e20004e,0x5894007b}},	//   gokh, _ﺑﻪﺭﻣ, _àlbe, _إجاز, 
   {{0x60d4007c,0xccf0011a,0x00000000,0x00000000}},	//   dgym, זכר_, --, --, 
   {{0x24500145,0x439452ee,0x96b8009b,0x257001d3}},	//   تچىس, сарс, _чуду_, nálj_, 
   {{0x656452ef,0xd4980ff1,0x255400b8,0x00000000}},	//   bokh, _прп_, cālo_, --, 
   {{0x2728022c,0x7414027d,0x60d40076,0x80a00f90}},	//   _rúni_, _نوبا, ggym, गुले, 
   {{0x21200de2,0x2728022c,0x4ea406ed,0x93e401d5}},	// [58f0] _dokh_, _súni_, греа, _сўйл, 
   {{0x2d8c01af,0xec1400f1,0x0874010f,0x00000000}},	//   _siee_, یواد, רעמט_, --, 
   {{0x2d8c016b,0x60cc0ac1,0xadf40107,0x035801ee}},	//   _piee_, _şimş, рпеш, _сүрә_, 
   {{0x2b98067c,0xe7e400af,0x80dc02e5,0xc01801e1}},	//   _pèc_, _कहला_, _फाये, _léṣe_, 
   {{0x6e9452f0,0xfe7001ed,0x6edc29d9,0x8bc452f1}},	//   _вигу, _ہدف_, _पापु, усед, 
   {{0x65643824,0xa3d452f2,0x2d8c013f,0x272803f2}},	//   zokh, ांत_, _wiee_, _túni_, 
   {{0x2bd019e5,0x656452f3,0x2d8c01ee,0x7f5800d1}},	//   _समका, yokh, _tiee_, _сарс_, 
   {{0x61e801b8,0x63a00098,0x00000000,0x00000000}},	//   _äfle, _éong, --, --, 
   {{0xead431af,0x6564009a,0x9a7400d1,0x00000000}},	//   _возь, vokh, лйәт_, --, 
   {{0xe72805f5,0x656452f4,0xd70452f5,0x612802f0}},	//   тоод_, wokh, анье_, _výli, 
   {{0xbb840597,0xc8b007d6,0x656452f6,0x6fe0015b}},	//   _اللي, _هلاک, tokh, নিয়ে, 
   {{0xc98452f7,0x255400e2,0x00000000,0x00000000}},	//   _сузи, rālo_, --, --, 
   {{0x656452f8,0x00000000,0x00000000,0x00000000}},	//   rokh, --, --, --, 
   {{0x656452f9,0x00000000,0x00000000,0x00000000}},	//   sokh, --, --, --, 
   {{0x65640bd7,0x60d40042,0x64a4010a,0xe168020c}},	//   pokh, tgym, _кайа, نصره_, 
   {{0xa0a44889,0xa3d401ad,0xe568009d,0x00000000}},	//   раад, ांद_, _шийд_, --, 
   {{0x60d452fa,0x69c003b2,0x1e9452fb,0x00000000}},	// [5900] rgym, _lvle, арер, --, 
   {{0xa2e42be5,0x60d40250,0xd47808c3,0x00000000}},	//   _тоод, sgym, _באפל, --, 
   {{0x2120020c,0x213c0ba1,0x00000000,0x00000000}},	//   _tokh_, èths_, --, --, 
   {{0xb64c04ac,0x64580276,0xf41c00fe,0xd654011a}},	//   עגאָ, ştiu, _পেটৰ_, ביעת_, 
   {{0x2ca852fc,0x69c052fd,0x5f7433ae,0x00000000}},	//   ñada_, _avle, _ناآر, --, 
   {{0x9f40007f,0xf1a80330,0x787c02d2,0x2ca80205}},	//   _eskò_, _جایه_, _læví, ıada_, 
   {{0x3eb852fe,0xdce001a6,0x272800d7,0xaa800432}},	//   _iert_, looč, _júnu_, _ýýld, 
   {{0x3eb80c3a,0x391452ff,0xd1dc0023,0x0c2000fb}},	//   _hert_, смир, ንብቦ_, смән, 
   {{0x14a4215d,0x69c00365,0x3eb85300,0xb6c40137}},	//   _क्षण, _evle, _kert_, бөйд, 
   {{0x3eb804cc,0xed580010,0x2918007c,0x00000000}},	//   _jert_, _zjž_, ösar_, --, 
   {{0x3eb8066d,0x7d005301,0xdce000d7,0x00000000}},	//   _mert_, _kams, hooč, --, 
   {{0x7d005302,0x58841e49,0x6370037e,0xd49801f0}},	//   _jams, _кыла, bænk, ъро_, 
   {{0x7d005303,0xc5580212,0x69c00010,0x00000000}},	//   _mams, рияє_, _zvle, --, 
   {{0x2bc817ee,0x3eb803b2,0x2728032e,0x00000000}},	//   _रिसा, _nert_, _búnu_, --, 
   {{0x7d0002d0,0x245001d5,0x68400240,0x00000000}},	//   _oams, قچیس, _ክትሓት, --, 
   {{0x3eb80036,0x16b40073,0x8634011a,0x244c035b}},	//   _aert_, _आजुब, _כרוב_, ẽma_, 
   {{0x3eb81125,0xceb8026a,0xdce00331,0x8ea40101}},	// [5910] _bert_, вље_, gooč, لصان, 
   {{0x3eb85304,0xc0e0044e,0x7d000334,0x3f1400a8}},	//   _cert_, _ሓዳር_, _aams, одус, 
   {{0x7d005305,0x2bc811b1,0x3eb85306,0x64580311}},	//   _bams, _रिहा, _dert_, ştit, 
   {{0x7d005307,0x3eb801f5,0x612802d2,0x00000000}},	//   _cams, _eert_, _býlu, --, 
   {{0x3eb85308,0x7d005309,0xa2bc28b8,0x16b40490}},	//   _fert_, _dams, वृक्, _आजूब, 
   {{0x3eb8530a,0x7d00127b,0x3168005a,0x7c2401c7}},	//   _gert_, _eams, loaz_, äira, 
   {{0x7d0002d3,0x2bc81bbb,0x00000000,0x00000000}},	//   _fams, _रिवा, --, --, 
   {{0x7d00530b,0x6370037e,0x3d94530c,0x3168153b}},	//   _gams, tænk, _фитр, noaz_, 
   {{0x6d48530d,0x00000000,0x00000000,0x00000000}},	//   _imea, --, --, --, 
   {{0x25702880,0x637000b5,0x3168005a,0xa3d4530e}},	//   máli_, rænk, hoaz_, ांस_, 
   {{0x3168530f,0x6d480789,0x1e3800c8,0x637001bf}},	//   koaz_, _kmea, ָגרא, sænk, 
   {{0x67d402bf,0x637000b5,0x3168005a,0x7d005310}},	//   _году, mæni, joaz_, _xams, 
   {{0xc4485311,0xa88410fe,0x6d480134,0x6024013f}},	//   شیدن_, _الشى, _mmea, kɔma, 
   {{0x2054052f,0x2cbc03cb,0x00000000,0x00000000}},	//   ҡтар, hawd_, --, --, 
   {{0x2bd01533,0x6d480428,0xe29801e0,0xe3b05312}},	//   _समझा, _omea, _ҙан_, _کرب_, 
   {{0x21a45313,0x3eb85314,0x3168009d,0x00000000}},	//   _қимм, _sert_, goaz_, --, 
   {{0x3eb85315,0x60085316,0xf3f0004d,0x2cbc0142}},	// [5920] _pert_, ынам_, ặc_, dawd_, 
   {{0x7d005317,0x6d485318,0x2bd00490,0xdce000d7}},	//   _sams, _amea, _समजा, rooč, 
   {{0x3eb85319,0xa3d4033d,0x9cc8531a,0x7d00055a}},	//   _vert_, ांव_, гыла_, _pams, 
   {{0x3eb8531b,0x7d000113,0x2368010a,0x63b40af9}},	//   _wert_, _qams, lobj_, _kwyn, 
   {{0x3eb8531c,0x7d000810,0xdca4020a,0x00000000}},	//   _tert_, _vams, _ҳаби, --, 
   {{0x8fa006bb,0x63b400a9,0xda78531d,0x61280122}},	//   _харе, _mwyn, ляй_, _výlu, 
   {{0x7d00531e,0x27280077,0xdca4531f,0xfcc43f6e}},	//   _tams, _lúns_, _габи, _дәлм, 
   {{0x7d005320,0x257002f0,0x291800d1,0x00000000}},	//   _uams, báli_, ﺷﻼﭖ_, --, 
   {{0x61fc0175,0x4730004b,0x612800a2,0x36d400f3}},	//   _lspl, ګريز, _uýlu, оопр, 
   {{0x19b85321,0x316801c4,0xdb0c01f4,0x00000000}},	//   _будь_, zoaz_, äjäm, --, 
   {{0xd9445322,0x63b400a2,0x23680334,0x7768022e}},	//   _лежи, _awyn, dobj_, rodx, 
   {{0x98a40124,0x63b40368,0x316801c6,0x6bd401e2}},	//   _omoĩ_, _bwyn, xoaz_, _دتېر, 
   {{0x61fc2b92,0x63b400a9,0x272801e7,0x3168030a}},	//   _aspl, _cwyn, _púnt_, voaz_, 
   {{0x61fc1d3f,0x63b45323,0x23680175,0xd244010b}},	//   _bspl, _dwyn, gobj_, бэби, 
   {{0x61fc0077,0x98a400e4,0x31685324,0x95c80116}},	//   _cspl, _amoĩ_, toaz_, _сула_, 
   {{0xa3d41025,0x63b40368,0x2bc85325,0x5184009d}},	//   ांश_, _fwyn, _रिला, суга, 
   {{0x64580ab7,0x63b40cfd,0x6edc0d41,0x316801a1}},	// [5930] ştir, _gwyn, _पादु, roaz_, 
   {{0x6d485326,0x16b40490,0x316801c4,0x2cbc0142}},	//   _smea, _आजोब, soaz_, wawd_, 
   {{0x2ca81280,0x70941d56,0x98a400e4,0x2cbc0218}},	//   ñado_, _манф, _emoĩ_, tawd_, 
   {{0x25705327,0x2cbc0042,0x00000000,0x00000000}},	//   táli_, uawd_, --, --, 
   {{0xab5c025c,0xeab85328,0x9c940133,0x100404b4}},	//   _avża, айл_, زانڤ, _уянм, 
   {{0x447c010f,0x257002f0,0x61fc02d0,0x2cbc03cb}},	//   אנדע, ráli_, _yspl, sawd_, 
   {{0xb52801e1,0x00000000,0x00000000,0x00000000}},	//   _akọ̀, --, --, --, 
   {{0x6d485329,0x6370532a,0x29000134,0x14d8532b}},	//   _umea, ræni, _ɔhaw_, _भाषण, 
   {{0xe7380588,0x6f0401ab,0x6d58035a,0x9f5c013a}},	//   иеи_, odhc, mnwa, _čtú_, 
   {{0xa6980640,0x255400e2,0x00000000,0x00000000}},	//   шњих_, māli_, --, --, 
   {{0x6d5814dc,0xf40808a8,0x63b403cb,0x6f0412ef}},	//   onwa, _שפ_, _swyn, idhc, 
   {{0x63b40368,0x2408036b,0x7a5447e7,0x791801b9}},	//   _pwyn, анми_, _عضلا, _гўшт_, 
   {{0x6d58532c,0x68e8532d,0x2554005f,0x2368010a}},	//   inwa, mfed, nāli_, tobj_, 
   {{0x6d5803fa,0x68e8532e,0x257003b2,0xb38000fb}},	//   hnwa, lfed, jálv_, нһыл, 
   {{0x23680175,0xe5780a0e,0xa52400db,0xd7841e5a}},	//   robj_, _кзк_, _ммкд, _بچيو_, 
   {{0x68e8532f,0x6f140175,0x753c5330,0x255400e2}},	//   nfed, _anzc, chsz, kāli_, 
   {{0xfe7802d5,0x23680334,0xdf485331,0xd0045332}},	// [5940] _šį_, pobj_, азад_, оете_, 
   {{0x6d585333,0x67200e3c,0x61fc02d0,0x25540171}},	//   enwa, njlj, _tspl, dāli_, 
   {{0x61fc127b,0x00000000,0x00000000,0x00000000}},	//   _uspl, --, --, --, 
   {{0x6b803fc1,0xa0680640,0x6f0400a3,0x6d585334}},	//   _ahlg, _вама_, adhc, gnwa, 
   {{0x255400e2,0x68e803cb,0x00000000,0x00000000}},	//   gāli_, dfed, --, --, 
   {{0xaff800c8,0x6d585335,0x00000000,0x00000000}},	//   _פּרי, anwa, --, --, 
   {{0x68e821e3,0x6d5803ac,0xdca40117,0x00000000}},	//   ffed, bnwa, _мави, --, 
   {{0x6b80005a,0x255400e2,0x6d5802d0,0xca44027d}},	//   _ehlg, bāli_, cnwa, غليه_, 
   {{0xd8385225,0x25700122,0x48e8000d,0xed34009d}},	//   рэй_, nálu_, _अउरो_, _ээрэ, 
   {{0xdb4c02f2,0x00000000,0x00000000,0x00000000}},	//   _جێت_, --, --, --, 
   {{0x6edc0073,0x00000000,0x00000000,0x00000000}},	//   _पासु, --, --, --, 
   {{0x7af8143a,0x25700c5e,0xf1d017ee,0x00000000}},	//   levt, kálu_, _तटबन, --, 
   {{0xc7a05336,0x8cc80073,0xc86001f4,0x00000000}},	//   _жичк, हणतो, _отши, --, 
   {{0x1cd8031c,0x25700c5e,0x00000000,0x00000000}},	//   _འཐའ_, dálu_, --, --, 
   {{0xdef4044e,0x41e4109a,0xabe001ec,0x257003b2}},	//   ለንን_, міта, _ﺍﻻﻤﺎ, válv_, 
   {{0x3b0402b1,0x6edc205d,0x7af80455,0x00000000}},	//   _hūpē_, _पाहु, hevt, --, 
   {{0xe5701a4c,0xc0d400b7,0x2570013a,0x00000000}},	// [5950] _אַז_, ርመራ_, gálu_, --, 
   {{0x6d585337,0x7af80118,0x4ea4155b,0xa2a83166}},	//   wnwa, jevt, ірза, जुद्, 
   {{0x68e80368,0xb62c04ce,0x6f0401ab,0x6d5802d0}},	//   yfed, _ｕｓ_, rdhc, tnwa, 
   {{0x6d580198,0x255400e2,0xc4f8010f,0x8d841219}},	//   unwa, tāli_, ַזוי_, цузд, 
   {{0x6d585338,0xeb981ab7,0xc05803de,0x00000000}},	//   rnwa, щил_, _дір_, --, 
   {{0x257001ed,0x255400e2,0x7af8000d,0x6d5802d0}},	//   lált_, rāli_, gevt, snwa, 
   {{0x6d5803ac,0x68e80205,0x00000000,0x00000000}},	//   pnwa, tfed, --, --, 
   {{0x257000dd,0x0c8400c7,0x637003b2,0x00000000}},	//   nált_, _дызм, lænt, --, 
   {{0x68e85339,0xdce00115,0x8bc4013d,0x8aa401f4}},	//   rfed, nloĝ, _фсбд, _дред, 
   {{0xc0e002d3,0x7af809a8,0x68e818a9,0x6db406be}},	//   _ሓዳስ_, cevt, sfed, _ağaə, 
   {{0xa5080697,0x68e8533a,0x257001d3,0x80dc190c}},	//   бена_, pfed, kált_, _फाले, 
   {{0xf3f00051,0xda7800d9,0x00000000,0x00000000}},	//   ặn_, _הנער, --, --, 
   {{0x32000076,0x579000f1,0x00000000,0x00000000}},	//   _ashy_, _ګټور, --, --, 
   {{0x257002f0,0x00000000,0x00000000,0x00000000}},	//   válu_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2570533b,0xdce00115,0x00000000,0x00000000}},	//   tálu_, floĝ, --, --, 
   {{0x9d4401e0,0x00000000,0x00000000,0x00000000}},	// [5960] үезд, --, --, --, 
   {{0x61e801b8,0x25701897,0x10a000fd,0xe8d80051}},	//   _äflo, rálu_, _җирн, _ướ_, 
   {{0x6edc007d,0xa0a4533c,0xc0d4069d,0x00000000}},	//   _पारु, _нанд, ርመር_, --, 
   {{0x2570533d,0x00000000,0x00000000,0x00000000}},	//   máls_, --, --, --, 
   {{0x670400b0,0x30742309,0x9d5401d3,0x4fa00d1d}},	//   _kōkē, _журс, _ہنست, _пияв, 
   {{0x2000533e,0x255400e2,0x6370005c,0x5ef80798}},	//   _iski_, mālu_, mæns, _ухмр_, 
   {{0x6370005c,0x1d08533f,0xe3e00154,0x00000000}},	//   læns, _леви_, যবিব, --, 
   {{0xd90c129e,0xdca401c6,0x00000000,0x00000000}},	//   طیت_, _хааи, --, --, 
   {{0x7af85340,0x2554005f,0xda0800f2,0x176800db}},	//   pevt, nālu_, _گياه_, йроп_, 
   {{0x9b445341,0x65a00521,0x257001d3,0xa3d4000d}},	//   _عناو, _ịhap, zált_, ांई_, 
   {{0x257001a8,0xe9700137,0x00000000,0x00000000}},	//   jáls_, رۇۇد, --, --, 
   {{0x4a7800c8,0x1cd8031c,0x82b8031c,0x255400e2}},	//   _פראב, _འཐས_, _དབུའ, kālu_, 
   {{0x257001ed,0xe26c0118,0x6edc00bc,0x320001f4}},	//   vált_, éčné_, _पालु, _sshy_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x20005342,0x32000175,0xd138059f,0x257001d3}},	//   _aski_, _qshy_, бха_, tált_, 
   {{0xd9bc0154,0xdb00007c,0x6fb80fdc,0x255400ef}},	//   _ইমাম, lpoä, жгар_, fālu_, 
   {{0xb4d82052,0xb4b40588,0x257001ed,0x7058009d}},	// [5970] ाली_, _еиқә, rált_, цаар_, 
   {{0xa92402fb,0x4e88005b,0xdce0010f,0x2d840116}},	//   možň, бщем_, rloĝ, ﺭﯨﻨﻰ_, 
   {{0x20005343,0xdce00115,0x0dc8010b,0x6370005c}},	//   _eski_, sloĝ, сузи_, rænt, 
   {{0x853003f9,0x255400ef,0x00000000,0x00000000}},	//   _kiɗa, bālu_, --, --, 
   {{0x8d7401d9,0x2b1804af,0x00000000,0x00000000}},	//   _ہارا, पालु_, --, --, 
   {{0xb4d811b1,0x7ce400b0,0xddc8054e,0x403400f0}},	//   ालु_, _rōrō, _înşt, _џерс, 
   {{0x8d745344,0x2bc85345,0xe9a8036b,0x00000000}},	//   _فارا, _रिका, زگان_, --, 
   {{0xe7a8470c,0x00000000,0x00000000,0x00000000}},	//   овил_, --, --, --, 
   {{0xac9405f5,0x18640131,0x09e001d5,0x0c84010a}},	//   _цааш, маъи_, фоқн, _хывм, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x764402a8,0xfd6401fb,0xb4d82ba2,0x00000000}},	//   _ƙiya, _nhuộ, ालू_, --, 
   {{0x7ce402b5,0xf2c80a7c,0x64a40022,0x00000000}},	//   _tōrō, _כע_, ьама, --, 
   {{0x66e40220,0x670402b5,0xa2b0072a,0x629801e4}},	//   _жола, _pōkē, _अभद्, ɾtoj, 
   {{0x20001529,0x38a002b5,0x255400e2,0xf79400c0}},	//   _rski_, rōrō_, vālu_, _зачэ, 
   {{0xfd640016,0xa1140753,0x88e80327,0xa3c80210}},	//   _chuộ, ووست, _རྡོར, _लटक_, 
   {{0x2554005f,0x55b80375,0xa3d40456,0x00000000}},	//   tālu_, _ומקו, _हिप_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [5980] --, --, --, --, 
   {{0x637000b5,0x63840006,0x00000000,0x00000000}},	//   ræns, _ігна, --, --, 
   {{0x61445346,0xa3d4202e,0x5318008f,0x64442321}},	//   _жена, ांक_, _וויצ, lzki, 
   {{0xa2a83994,0xe8d80051,0x00000000,0x00000000}},	//   जुर्, _ườ_, --, --, 
   {{0xa6d400cc,0x753c0200,0xe4e45347,0x00000000}},	//   ত্যট, ërzi, _कानि_, --, 
   {{0x31c40014,0x644401c6,0x19a85348,0xdb00007c}},	//   _تتیُ, izki, отип_, xpoä, 
   {{0x2554005f,0x00000000,0x00000000,0x00000000}},	//   nāls_, --, --, --, 
   {{0x3f980323,0xdd145349,0x88b001d5,0x00000000}},	//   _hiru_, _تورخ, نیمچ, --, 
   {{0x3f98534a,0x15a00150,0xdb00007c,0x00000000}},	//   _kiru_, _ﺍﻟﺸﯩ, tpoä, --, 
   {{0x3f980a4d,0x6444068f,0xe74400fd,0x255400e2}},	//   _jiru_, dzki, нүче_, kāls_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb4d8000b,0xdb000267,0xa9240306,0xd83801c4}},	//   ाले_, spoä, tožň, _мэл_, 
   {{0xa3d4000b,0x41a4068f,0x28f801c0,0xe7a4313e}},	//   ांग_, _खूबस, _хэхэ_, _كۇيى_, 
   {{0xc87c0730,0xa6d402f5,0x3f98534b,0xfd64004d}},	//   üße_, ত্বট, _niru_, _phuộ, 
   {{0x4394534c,0x85b40ef6,0x067c08b0,0x00000000}},	//   тарс, _قايس_, _ﺭﺍﻳﯩ, --, 
   {{0x3f98534d,0x00000000,0x00000000,0x00000000}},	//   _airu_, --, --, --, 
   {{0xe810534e,0x6444033f,0x05740ca5,0xd36c00db}},	// [5990] ़िया_, czki, _جاود, _نۇح_, 
   {{0x1cd807e4,0xfd6407ae,0x752c03bd,0x255400ef}},	//   _འཐུ_, _thuộ, _hoaz, bāls_, 
   {{0xb81402a6,0x3f98534f,0x752c05c7,0x00000000}},	//   িহিত_, _diru_, _koaz, --, 
   {{0x409407a7,0x752c000f,0xa3d41a4e,0x00000000}},	//   رلەر, _joaz, _हिम_, --, 
   {{0x3f9801c7,0xe570010f,0x00000000,0x00000000}},	//   _firu_, אַג_, --, --, 
   {{0xfbd05350,0x3f985351,0x752c5352,0x00000000}},	//   شته_, _giru_, _loaz, --, 
   {{0x644400b5,0x2fc801bf,0x699401f4,0x00000000}},	//   zzki, lsag_, нрих, --, 
   {{0xb4d83b16,0x29180bc9,0xa80400ee,0x2570041e}},	//   ालो_, ñsa_, езил, jálp_, 
   {{0x3e380020,0x2fc85353,0x291800ac,0x7b08023a}},	//   _በሚደረ, nsag_, ısa_, östä, 
   {{0x7c845354,0x29180083,0xf3f403d4,0x00000000}},	//   _русе, űsa_, ইটাৰ_, --, 
   {{0xd5ac5355,0x752c5356,0xa5083252,0xa89801ec}},	//   یفی_, _boaz, пена_, _екеу_, 
   {{0x2554005f,0x88c4035c,0x08400014,0x64440112}},	//   vāls_, _آتال, _لۆبُ, tzki, 
   {{0x752c5357,0x00e404d3,0x644405c7,0x00000000}},	//   _doaz, ێتری, uzki, --, 
   {{0x66e45358,0x2554005f,0x7c24023a,0xb76400fb}},	//   _чока, tāls_, äiri, _үтәй, 
   {{0x26c45359,0x64441790,0x3f980241,0x2bc80d2e}},	//   malo_, szki, _riru_, _रिझा, 
   {{0x752c530f,0x6024535a,0x00000000,0x00000000}},	//   _goaz, ндба, --, --, 
   {{0x3f98535b,0x2fc80007,0x26c40618,0x65740022}},	// [59a0] _piru_, gsag_, oalo_, _ikyh, 
   {{0x0a34069c,0x3f9802d1,0x752c009d,0x2bc800bc}},	//   ክራስያ, _qiru_, _zoaz, _रिजा, 
   {{0x3f98535c,0xb3440023,0x2fc80437,0xa91c00c0}},	//   _viru_, saçë, asag_, amži, 
   {{0x26c4535d,0x3f9802d1,0x21681058,0x2fc801ab}},	//   halo_, _wiru_, _хими_, bsag_, 
   {{0x26c4535e,0x8cc41eeb,0xf00000d1,0x7f04535f}},	//   kalo_, رووق_, _күти, _иҗад, 
   {{0x23a401a2,0x5f0426f8,0x3b700092,0x395800e5}},	//   _môj_, _язга, ትሪዎች_, _írsz_, 
   {{0x65740124,0x00000000,0x00000000,0x00000000}},	//   _okyh, --, --, --, 
   {{0x2bc85360,0x0c2001e0,0x00000000,0x00000000}},	//   _रिचा, тмән, --, --, 
   {{0xb9085361,0x26c42f07,0x752c03bd,0x00000000}},	//   _बा_, falo_, _roaz, --, 
   {{0x65740022,0x752c05c7,0x00000000,0x00000000}},	//   _akyh, _soaz, --, --, 
   {{0x0f54025f,0x752c0156,0x99d40b24,0xf520187f}},	//   תיים_, _poaz, _ستاا, аннi_, 
   {{0x26c40270,0x2fc80076,0xd404011c,0x00000000}},	//   aalo_, ysag_, няги, --, 
   {{0x752c5362,0x2fc801bf,0x8464008e,0xb9d00092}},	//   _voaz, xsag_, гъре, _ቻለ_, 
   {{0xcc38010f,0x00000000,0x00000000,0x00000000}},	//   לעכט, --, --, --, 
   {{0x752c030a,0xd138030d,0x4d8801ec,0xb5200b67}},	//   _toaz, пха_, _ﺑﺎﯞﯨ, यादय_, 
   {{0xd498236a,0x2fc85363,0x86780375,0x76480153}},	//   _эрк_, tsag_, _מרוו, mzdy, 
   {{0x629c0354,0x2fc800a3,0x74140244,0x00000000}},	// [59b0] _fgpo, usag_, _شودا, --, 
   {{0xa3d41524,0x61ec3778,0xc0c00092,0x4ebc00eb}},	//   _हित_, ønlæ, _ስዕል_, আল্ল, 
   {{0x2fc85364,0x00000000,0x00000000,0x00000000}},	//   ssag_, --, --, --, 
   {{0xf10400db,0x2fc80072,0xa3d40073,0x00000000}},	//   _جۉرۉ_, psag_, ांच_, --, 
   {{0x26c45365,0x629c0175,0x12e000eb,0x00000000}},	//   yalo_, _ygpo, য়ীদ, --, 
   {{0x26c4056a,0xb0e0000d,0xadbc00c0,0x00000000}},	//   xalo_, _फाँग, _магi, --, 
   {{0xa9685366,0xe8fc025c,0xdb4c01d9,0x00000000}},	//   мика_, _དྲུབ_, تَو_, --, 
   {{0x69dc00b8,0x00000000,0x00000000,0x00000000}},	//   _āsed, --, --, --, 
   {{0xfbd0034c,0xa76406dc,0x14d80073,0x00000000}},	//   _هتل_, ккид, _भाजण, --, 
   {{0xe9b40588,0x65740423,0x00000000,0x00000000}},	//   _абжь, _skyh, --, --, 
   {{0xdce80356,0x00000000,0x00000000,0x00000000}},	//   _înăs, --, --, --, 
   {{0x26c45367,0x2bf4007d,0x64bc0709,0x61e8013d}},	//   salo_, _इहां_, ्णेश, _äfli, 
   {{0x291c004c,0xf9905368,0x00000000,0x00000000}},	//   _inwa_, _ابل_, --, --, 
   {{0x290c0323,0x27ec5369,0x26c4536a,0xc7940451}},	//   ldea_, mten_, qalo_, _ڪپڙا_, 
   {{0x27ec536b,0xc5ec004b,0xe64401ec,0x21740395}},	//   lten_, _اړخ_, _шекп, вуар, 
   {{0x290c536c,0x23a40051,0xdb1c02d2,0x2d780055}},	//   ndea_, _tôj_, _óvön, _ṇena_, 
   {{0x27ec536d,0x290c536e,0x629c01a6,0x8fa0011c}},	// [59c0] nten_, idea_, _tgpo, иате, 
   {{0x27ec536f,0xde94009a,0x45240154,0x00000000}},	//   iten_, نجاب, _পতিক_, --, 
   {{0x27ec5370,0x291c0521,0x1e9400a8,0xd0e401d9}},	//   hten_, _onwa_, трар, رکێم_, 
   {{0x27ec5371,0x290c054e,0xa0a45372,0x80dc5373}},	//   kten_, jdea_, _шамд, _फाटे, 
   {{0x27ec5374,0xad641671,0x2cac0175,0x61ec002f}},	//   jten_, داله, _dfed_, ltbl, 
   {{0x27ec2759,0x291c5375,0x201007a8,0x2cac0156}},	//   dten_, _anwa_, mvyi_, _efed_, 
   {{0x27ec5376,0x61ec5377,0x99645378,0xef90036b}},	//   eten_, ntbl, ктил, _ایلد, 
   {{0x27ec5379,0x61ec017a,0x38c84c12,0x764802f0}},	//   ften_, itbl, رابی_, vzdy, 
   {{0x27ec537a,0x61ec0036,0xca8001e0,0x9b04009b}},	//   gten_, htbl, лгәй, _изад, 
   {{0x7e7c0652,0x291c537b,0x61ec007c,0x95c8537c}},	//   _kyrp, _enwa_, ktbl, мума_, 
   {{0x27ec537d,0x603806c8,0x2cac0368,0x00000000}},	//   aten_, _hāmā, _yfed_, --, 
   {{0x291c0280,0x27ec537e,0x60380882,0x62b402dd}},	//   _gnwa_, bten_, _kāmā, ңғыс_, 
   {{0x27ec0460,0xb7d400c6,0x603819ae,0x28b000fb}},	//   cten_, _إقتب, _jāmā, _уҡыя, 
   {{0x6038033e,0x61ec0334,0x00000000,0x00000000}},	//   _māmā, ftbl, --, --, 
   {{0x61ec03b2,0x7e7c01f4,0x00000000,0x00000000}},	//   gtbl, _nyrp, --, --, 
   {{0x12e00eac,0x7bc000a2,0x70dc01f9,0x5184475a}},	//   য়েদ, _owmu, यलेल, туга, 
   {{0x4034169c,0x7bc00810,0x2ef4036b,0x2cac0175}},	// [59d0] аетс, _nwmu, лзар, _rfed_, 
   {{0x7ed4537f,0x753c5380,0xc90803b9,0x61ec0327}},	//   لزما, lksz, _digә, btbl, 
   {{0x27ec0323,0x9fa401e0,0x00000000,0x00000000}},	//   zten_, _ҡырҙ, --, --, 
   {{0x27ec5381,0x7ae802d0,0xd24c05d9,0x628800d8}},	//   yten_, _acdt, _هنڌ_, _ºfor, 
   {{0x27ec5382,0x60380055,0xa2a82d8f,0x00000000}},	//   xten_, _cāmā, जुक्, --, 
   {{0x6f880014,0xc43c008f,0x7e7c007c,0x60380a2f}},	//   _سنزِ_, ותדי, _fyrp, _dāmā, 
   {{0x2b8801a2,0x612800ee,0x7e7c010e,0x753c01d3}},	//   júce_, _aýly, _gyrp, kksz, 
   {{0x2b880030,0xe808004e,0x00000000,0x00000000}},	//   dúce_, енид_, --, --, 
   {{0x290c5383,0x6d585384,0xd7ec02dd,0x60380055}},	//   rdea_, miwa, ككي_, _gāmā, 
   {{0x291c0a73,0xe4e40490,0xd0440213,0x753c033f}},	//   _wnwa_, _काहि_, üməs, eksz, 
   {{0x61ec010a,0x00000000,0x00000000,0x00000000}},	//   xtbl, --, --, --, 
   {{0x27ec5385,0x6d585386,0x6e2000f7,0x3178209c}},	//   pten_, niwa, _àlbu, _nksz_, 
   {{0x649800a8,0x80cc0154,0x888801af,0x00000000}},	//   этор_, িলম্, _юғиh, --, 
   {{0x6d585387,0x61ec007c,0x53a00117,0x00000000}},	//   hiwa, ttbl, сарб, --, 
   {{0x6d585388,0x1f6416c3,0xdde0107d,0x64a4010b}},	//   kiwa, ҳкам, _žužu, _йайа, 
   {{0x6d585389,0x61ec538a,0x61280432,0x00000000}},	//   jiwa, rtbl, _yýly, --, 
   {{0x6d58014c,0x61ec4087,0x7e7c538b,0x00000000}},	// [59e0] diwa, stbl, _syrp, --, 
   {{0x363400db,0x69c0538c,0x61ec0175,0xa6d40154}},	//   _حرۇس, _owle, ptbl, ত্রট, 
   {{0x60380882,0x6d5802d0,0x1754010f,0x00000000}},	//   _sāmā, fiwa, נסער_, --, 
   {{0x6d58538d,0x603800b0,0x00000000,0x00000000}},	//   giwa, _pāmā, --, --, 
   {{0x69c0035a,0xa2b81b61,0x2d980137,0x00000000}},	//   _awle, ्रप्, төрө_, --, 
   {{0x6d580810,0x69c003cb,0x7e7c03b2,0xe7f8007a}},	//   aiwa, _bwle, _tyrp, ्बना_, 
   {{0x6d58538e,0x7ec800e2,0x69dc00b8,0x00000000}},	//   biwa, rūpē, _āsec, --, 
   {{0xc0c0067d,0xaea0538f,0x2378020b,0x6d585390}},	//   _ድሕሪ_, ğışl, _lkpj_, ciwa, 
   {{0x69c0038f,0x60c4030a,0xd7f85391,0x2d500244}},	//   _ewle, _mekm, хуй_, _بێنس, 
   {{0x07f400c6,0x35f45392,0x775400f3,0x60c44cab}},	//   اريع_, апор, ркоф, _lekm, 
   {{0xb520060c,0x69c000a9,0xa2b829ea,0x00000000}},	//   यालय_, _gwle, ्रन्, --, 
   {{0x98a422e9,0x58845393,0x2b880030,0xd1b801ed}},	//   _сиде, _йыла, rúce_, ہارا_, 
   {{0xdce001e4,0xb91001e1,0x51840116,0x69c0012d}},	//   gnoĉ, _oolẹ_, ғува, _zwle, 
   {{0x2378031c,0xc0c00023,0x53442401,0x00000000}},	//   _ckpj_, _ድሕረ_, ухма, --, 
   {{0xd1cc0201,0x6d585394,0x60c45395,0x8778011a}},	//   _ቤቶች_, yiwa, _bekm, _ראוי, 
   {{0x6d585396,0x60c45397,0x51840798,0x00000000}},	//   xiwa, _cekm, ѓува, --, 
   {{0x6d5818f7,0x60c45398,0x44b40022,0xdcec00de}},	// [59f0] viwa, _dekm, _убыс, _dubļ, 
   {{0x6d585399,0x60c4002d,0xce6800d8,0x00000000}},	//   wiwa, _eekm, нред_, --, 
   {{0x6d58539a,0xacb400be,0x00000000,0x00000000}},	//   tiwa, لماغ, --, --, 
   {{0x7a1c0356,0x00000000,0x00000000,0x00000000}},	//   _mătă, --, --, --, 
   {{0x6d58539b,0x00000000,0x00000000,0x00000000}},	//   riwa, --, --, --, 
   {{0x6d58539c,0xd14807d6,0xae040014,0x00000000}},	//   siwa, _آشگن_, _پورى, --, 
   {{0x2ba0539d,0xaa44539e,0x69242c08,0x4424004d}},	//   _ओंका, рейл, имка, ̣m_, 
   {{0xa3d402ab,0x6d58539f,0x00000000,0x00000000}},	//   _हिल_, qiwa, --, --, 
   {{0x2d8c0076,0xa2b84668,0x6354007f,0x3ce000ae}},	//   _ihee_, ्रम्, wņnm, óive_, 
   {{0xe61845fd,0x2d8c020b,0x7a1c0276,0xe73853a0}},	//   вдо_, _hhee_, _bătă, тео_, 
   {{0x2d8c0218,0x7a1c0276,0x8af400ac,0x00000000}},	//   _khee_, _cătă, şəsi, --, 
   {{0x1cd807e4,0xf8b001ed,0x7a1c0356,0x00000000}},	//   _འཐབ_, _ٹکٹ_, _dătă, --, 
   {{0x2d8c00e4,0x60c4017a,0xdcec00de,0x00000000}},	//   _mhee_, _rekm, _rubļ, --, 
   {{0x60c453a1,0x2d8c1368,0xdce001e4,0x00000000}},	//   _sekm, _lhee_, rnoĉ, --, 
   {{0xc0c002d3,0x26d00306,0xd75453a2,0x2d04012d}},	//   _ድሕር_, ózou_, _خلوت_, _रसूल_, 
   {{0x2d8c1368,0xa2b0043e,0x00000000,0x00000000}},	//   _nhee_, _अभक्, --, --, 
   {{0x6564090c,0x1f280023,0x00000000,0x00000000}},	// [5a00] mnkh, _ተቛወም, --, --, 
   {{0x2d8c53a3,0x63b40649,0x4f201353,0xf3f00208}},	//   _ahee_, _ityn, одуб, ặt_, 
   {{0x60c40fb7,0x1cd80135,0x2d8c0810,0x5fd806e3}},	//   _tekm, _འཐད_, _bhee_, यूजल, 
   {{0x2d8c53a4,0x2b440042,0x61fc0857,0x63b4036e}},	//   _chee_, _allc_, _ippl, _ktyn, 
   {{0x6fdc01ad,0xace80769,0x00000000,0x00000000}},	//   _पियू, ارمل_, --, --, 
   {{0x2d8c0093,0x3860041a,0xbf642e0b,0x00000000}},	//   _ehee_, _žiro_, _اگرو, --, 
   {{0x49c41219,0x00000000,0x00000000,0x00000000}},	//   ауым_, --, --, --, 
   {{0x2d8c01f2,0x2d94023a,0x7a1c0311,0xa3d453a5}},	//   _ghee_, _грус, _rătă, हळा_, 
   {{0x1ae41c31,0x8c4053a6,0x00000000,0x00000000}},	//   _возм, _дете, --, --, 
   {{0x61fc1a84,0x8af40213,0x2b440142,0x15a802e8}},	//   _oppl, şəri, _gllc_, къми_, 
   {{0x63b453a7,0x2d8c009a,0xd94400db,0x00000000}},	//   _atyn, _yhee_, _кежи, --, 
   {{0x7a1c0311,0x21200067,0xdcec0166,0x00000000}},	//   _vătă, _nnkh_, _kubı, --, 
   {{0x948453a8,0x61fc53a9,0x1cd80489,0xf9f81c82}},	//   рынд, _appl, _འཐན_, _আছিল_, 
   {{0x58840032,0x7a1c054e,0x96b800f3,0x12e401ec}},	//   _йыһа, _tătă, _руду_, шімг, 
   {{0x75d453aa,0x257001d3,0xe8780092,0xf1c001f9}},	//   _ايبا, hály_, _አሳሰቡ_, षींन, 
   {{0x25702358,0x5edc0154,0x00000000,0x00000000}},	//   kály_, ন্মে, --, --, 
   {{0x4ea453ab,0x93e4036b,0xa2a8012c,0xc0c853ac}},	// [5a10] ареа, _тўйл, जुङ्, русе_, 
   {{0x2d8c1368,0x257053ad,0x00000000,0x00000000}},	//   _shee_, dály_, --, --, 
   {{0x2b8801a2,0xadf42bf6,0x2d8c0270,0x658400e4}},	//   júca_, спеш, _phee_, _ñuhá, 
   {{0xdcec0166,0x2b440327,0x2b8800d0,0x705400f2}},	//   _bubı, _sllc_, dúca_, _هنجا, 
   {{0x25702358,0x2b44045a,0x2cbc0042,0x00000000}},	//   gály_, _pllc_, rbwd_, --, 
   {{0x2d8c53ae,0xa03408c3,0x00000000,0x00000000}},	//   _whee_, _האשה_, --, --, 
   {{0xa2b80882,0x7f5853af,0xbdd4005b,0x2d8c53b0}},	//   ्रत्, _тарс_, _морщ, _thee_, 
   {{0x2d8c0270,0x6f0453b1,0x257001d3,0xa92401a9}},	//   _uhee_, lehc, bály_, сдил, 
   {{0xc1580375,0xdb2453b2,0xdbc4010e,0xaf300092}},	//   ישהו_, _گولی, _köýe, _በማስወ, 
   {{0x6f04016d,0x00000000,0x00000000,0x00000000}},	//   nehc, --, --, --, 
   {{0x63b453b3,0x78ac01a6,0x64a400d1,0x5b2400fb}},	//   _styn, _šovš, йана, _уятҡ, 
   {{0xc98407d6,0x00000000,0x00000000,0x00000000}},	//   _тузи, --, --, --, 
   {{0x4a740184,0x61fc0ffb,0x68e853b4,0x64a401ec}},	//   _сыҡт, _sppl, mged, _қапа, 
   {{0x68e853b5,0x201c0118,0xa2b806ff,0x04e800eb}},	//   lged, _čti_, ्रध्, গজের_, 
   {{0x5edc015b,0x201c00b0,0x68e81418,0x6d480327}},	//   ন্ডে, _ōti_, oged, _ċean, 
   {{0xa0740224,0x059453b6,0xe5041913,0x00000000}},	//   бызш, _باتگ, _طبعي, --, 
   {{0xefe0044e,0xa2b853b7,0x68e800fe,0xdfa802c9}},	// [5a20] _ዓባይ_, ्रद्, iged, اطره_, 
   {{0x68e8324c,0x25700306,0x0d2001c6,0x630401e2}},	//   hged, vály_, үүрү, _اودل, 
   {{0x61fc53b8,0x68e853b9,0x139802e4,0x37b800cc}},	//   _uppl, kged, _תביע, _ইয়াৰ, 
   {{0x2b8853ba,0x2460013f,0x68e80d27,0x9a840032}},	//   vúca_, _kɔm_, jged, ҙулл, 
   {{0x68e853bb,0xd578008f,0xdb585223,0xdcec0166}},	//   dged, אָגר, люк_, _qubı, 
   {{0x25700765,0x1cd8025c,0x68e80036,0xc10401f7}},	//   rály_, _འཐམ_, eged, _اوڏي, 
   {{0x68e853bc,0xdce053bd,0x2ca80153,0xeb3000db}},	//   fged, lnoč, žada_, بۉلد, 
   {{0x2b880030,0x8308031c,0xdcec008e,0x00000000}},	//   rúca_, _ཆིའུ_, _tubı, --, 
   {{0xdc6801c6,0x0d7400f2,0x15a00220,0x1c44022e}},	//   _саад_, _اینک_, _ﺍﻟﺘﯩ, _унам, 
   {{0x3ae853be,0xed5801ef,0x00000000,0x00000000}},	//   _خبری_, _zmž_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb00172e,0x0e9805d0,0xf8b844a5,0x00000000}},	//   mpoñ, טשיל, _төк_, --, 
   {{0xf484028e,0x00000000,0x00000000,0x00000000}},	//   تادی, --, --, --, 
   {{0x2460016b,0x5edc0eac,0x00000000,0x00000000}},	//   _dɔm_, ন্তে, --, --, 
   {{0xd4e42472,0x9f50007f,0x00000000,0x00000000}},	//   _люпи, mtyè_, --, --, 
   {{0xdbc4010b,0x03b800fe,0x73c401af,0x00000000}},	//   _söýe, _জিৰণ, _мәге, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [5a30] --, --, --, --, 
   {{0xd3440517,0xed5801a6,0x9f5002bd,0x4ea42360}},	//   _ایسه_, _smž_, ntyè_, сраа, 
   {{0xdce000d0,0x4ea4035b,0x5fac000d,0x00000000}},	//   anoč, арҵа, _झूठल, --, 
   {{0x91c00831,0x6f04014f,0x00000000,0x00000000}},	//   _мәғл, sehc, --, --, 
   {{0x6b7431ee,0xffe40153,0x31681366,0x441c010f}},	//   олду, _нюрн, mnaz_, ָווס, 
   {{0x6f040455,0x7c940214,0x64580115,0x2078010f}},	//   qehc, سشنا, ŝtig, _כארא, 
   {{0x68e853bf,0xfeb800e5,0x00000000,0x00000000}},	//   tged, _چاہت_, --, --, 
   {{0x5edc2aab,0x05240eac,0x9994009f,0x00000000}},	//   ন্দে, _পত্র_, يپور_, --, 
   {{0xfbe01c15,0x68e853c0,0x3d940251,0x316801c4}},	//   _नियम, rged, _хитр, inaz_, 
   {{0x68e853c1,0xdee8044e,0x6d4800a3,0x316806be}},	//   sged, _መታን_, _hlea, hnaz_, 
   {{0x6d480225,0xa2b8043e,0xab2800fb,0x316853c2}},	//   _klea, ्रस्, _йоҡа_, knaz_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x316800df,0x7d0002d2,0x6c7800df,0xe3b000ae}},	//   dnaz_, _háræ, שאָפ, برج_, 
   {{0x6d481dc2,0x316801c4,0xf7e000d1,0x21a40120}},	//   _llea, enaz_, _ﺋﻪﻣﺪ, живм, 
   {{0x2460013f,0xf2e00183,0x466000db,0xe81000af}},	//   _wɔm_, ম্ভণ, _رۇحق, ़िका_, 
   {{0xa2b853c3,0x31681529,0xf1a80472,0x00000000}},	//   ्रह्, gnaz_, صافه_, --, 
   {{0x1ec8013e,0x2b8800d0,0x7afc00a2,0x00000000}},	// [5a40] илаи_, júco_, _örtg, --, 
   {{0x6d4853c4,0xe3b001d3,0xcf8c0014,0xdce00064}},	//   _alea, _ٹرک_, ٖژِ_, rnoč, 
   {{0x6d4853c5,0x00000000,0x00000000,0x00000000}},	//   _blea, --, --, --, 
   {{0x6d4853c6,0xa2b853c7,0x5fe03507,0xbac000d1}},	//   _clea, ्रव्, _पिपल, _ﮬﯧﺴﺎ, 
   {{0x6d4853c8,0x00000000,0x00000000,0x00000000}},	//   _dlea, --, --, --, 
   {{0xdde803e6,0x6d4853c9,0xcb500214,0x00000000}},	//   _پرسه_, _elea, وننظ, --, 
   {{0x6d4853ca,0x8fa053cb,0x9d44022e,0x00000000}},	//   _flea, _царе, _девд, --, 
   {{0x6d4853cc,0xdb00056a,0x00000000,0x00000000}},	//   _glea, rpoñ, --, --, 
   {{0xdb0036ed,0x00000000,0x00000000,0x00000000}},	//   spoñ, --, --, --, 
   {{0x31680369,0xcc840133,0x00000000,0x00000000}},	//   znaz_, _بچمه_, --, --, 
   {{0xd010015b,0xceb00375,0xda0c00ab,0xf8a401af}},	//   সময়_, וית_, _ानित_, _егеү, 
   {{0xd90c50b5,0x96b802ab,0x7bdc00b8,0x00000000}},	//   _شیخ_, _श्रॉ, _āruj, --, 
   {{0xb7184961,0xd1180d2e,0x00000000,0x00000000}},	//   _голф_, _पोषण_, --, --, 
   {{0xa2b80303,0x75d4007b,0x7afc371e,0xc6f400c0}},	//   ्रष्, _فيتا, _örtd, _мніх_, 
   {{0x20000054,0x95c853cd,0x8b54010f,0x00000000}},	//   _apki_, _тула_, קילס_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa2b8228a,0xf2c400d1,0x316853ce,0xf48400e5}},	// [5a50] ्रश्, _нөви, rnaz_, _ڈاکی, 
   {{0x6d4853cf,0x5edc0eac,0x3168005a,0x0cc02435}},	//   _slea, ন্সে, snaz_, शर्म, 
   {{0x6d4853d0,0x200001a6,0xa91c00d7,0xcfe000cc}},	//   _plea, _epki_, dlžn, _নৈখন, 
   {{0xbd6853d1,0xac940108,0x00000000,0x00000000}},	//   орче_, паеш, --, --, 
   {{0x408453d2,0x6d48062c,0x5fe000c5,0x00000000}},	//   _журб, _vlea, _पियल, --, 
   {{0xaa3402e8,0xf3ec0154,0x2b880419,0xf0040117}},	//   зхищ, _ওনার_, rúco_, _мӯҷи, 
   {{0x6d480165,0x7c4400c0,0xa0200254,0x00000000}},	//   _tlea, _įtrū, öövo, --, 
   {{0x6d4853d3,0x6f14017a,0x00000000,0x00000000}},	//   _ulea, _hazc, --, --, 
   {{0xfaec0032,0x6f1400b8,0x00000000,0x00000000}},	//   _иҫ_, _kazc, --, --, 
   {{0xfbe03711,0x00000000,0x00000000,0x00000000}},	//   _नितम, --, --, --, 
   {{0x6f1400ef,0x00000000,0x00000000,0x00000000}},	//   _mazc, --, --, --, 
   {{0x6f140205,0xdee80092,0x00000000,0x00000000}},	//   _lazc, _መዳን_, --, --, 
   {{0x9fd42f8b,0x00000000,0x00000000,0x00000000}},	//   _সঙ্গ, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7afc53d4,0x12c81870,0xda1c0118,0x00000000}},	//   _örte, _ﺑﯘﻻﺭ, भियत_, --, 
   {{0x55d804ac,0x386008a4,0x200053d5,0xe4e400c5}},	//   _פֿונ, _žiri_, _ppki_, _काटि_, 
   {{0xa3d408e9,0x1dcc49be,0x75d00118,0x00000000}},	// [5a60] _हिट_, हीनत, _vězň, --, 
   {{0x442053d6,0xa0680364,0x1e9427a8,0x5fe001f9}},	//   _iri_, _ҳама_, прер, _पिठल, 
   {{0x9ca8004b,0xa91c0427,0x01080451,0x6d58007f}},	//   مهال_, možf, _وڪرو_, ďwan, 
   {{0xdd9053d7,0x442053d8,0xa06853d9,0xa91c0030}},	//   روش_, _kri_, _гама_, dlžo, 
   {{0x442003a2,0x6f140226,0x8c4000c0,0x4bb001ec}},	//   _jri_, _fazc, неце, ейіс, 
   {{0x15b81c5c,0xf1a804d3,0x6f14022e,0xabfc010a}},	//   ﻠﻪﺭﺩ, _دایه_, _gazc, ăплă_, 
   {{0x99d41867,0x44200200,0xb4ec01f9,0x00000000}},	//   ستغا, _lri_, _झालय_, --, 
   {{0x442053da,0x4dd80375,0x3d14000d,0x00000000}},	//   _ori_, _לחלו, _नोचे_, --, 
   {{0x442005db,0xb90453db,0x59dc01ad,0x1ae428f3}},	//   _nri_, _भए_, _नटवर, _ноам, 
   {{0x35b431e2,0x7bdc00cd,0x00000000,0x00000000}},	//   мбор, _āruh, --, --, 
   {{0xeb5421ea,0x00000000,0x00000000,0x00000000}},	//   _تىلگ, --, --, --, 
   {{0x442053dc,0x7afc0205,0x00000000,0x00000000}},	//   _bri_, _örtb, --, --, 
   {{0x442053dd,0x07f4038b,0x00000000,0x00000000}},	//   _cri_, _فروع_, --, --, 
   {{0x442053de,0x7c200270,0x63a0011c,0x88980375}},	//   _dri_, _mrmr, _èonl, _הבדי, 
   {{0x442053df,0x6f140219,0xd5b800d8,0x00000000}},	//   _eri_, _razc, _усл_, --, 
   {{0x94a853e0,0x442053e1,0xf0e82374,0x6f143b5a}},	//   _утка_, _fri_, تىرى_, _sazc, 
   {{0xf48453e2,0xf4e40131,0x6f1453e3,0x337401d5}},	// [5a70] _تاثی, _ﺋﯚﺗﻜ, _pazc, _огир, 
   {{0x3f1453e4,0x00000000,0x00000000,0x00000000}},	//   ндус, --, --, --, 
   {{0x7c2004fb,0x442005c7,0xfeb81291,0x00000000}},	//   _armr, _zri_, سالت_, --, 
   {{0x442053e5,0x270800ab,0xcbb400d1,0x626400db}},	//   _yri_, _वस्र_, зғаш_, _زاپق, 
   {{0x44200784,0x7d0002d0,0x27e800df,0x0ba4005b}},	//   _xri_, _dbms, _ĥano_, чшем, 
   {{0x7d000175,0x4ad41893,0x25ec01ad,0x00000000}},	//   _ebms, ساتھ_, _अमली_, --, 
   {{0x7f9453e6,0x00000000,0x00000000,0x00000000}},	//   _чарх, --, --, --, 
   {{0xad240c50,0xba0808b0,0xf6e8025c,0x7c200175}},	//   _تىرى, ستىك_, _འཐུང, _frmr, 
   {{0xec6804d3,0xd7ec007b,0x8aa44130,0x00000000}},	//   _بڵاو_, لكي_, _еред, --, 
   {{0x442053e7,0xbc6805d9,0xe64453e8,0xaa5c02dd}},	//   _rri_, _عملن_, деоп, _кезi, 
   {{0xa50853e9,0x442053ea,0x4900009d,0xdb10007c}},	//   оена_, _sri_, _зүйг, ägår, 
   {{0x442053eb,0x00000000,0x00000000,0x00000000}},	//   _pri_, --, --, --, 
   {{0x7afc002f,0x44200051,0x00000000,0x00000000}},	//   _örtc, _qri_, --, --, 
   {{0x4420168c,0x00000000,0x00000000,0x00000000}},	//   _vri_, --, --, --, 
   {{0x26c453ec,0x44201529,0xdce005c7,0x53a00354}},	//   mblo_, _wri_, nnoă, тарб, 
   {{0x26c401c7,0x00000000,0x00000000,0x00000000}},	//   lblo_, --, --, --, 
   {{0x442053ed,0xa3b806d0,0x3ec40022,0x7164007b}},	// [5a80] _uri_, _بابر_, еизҳ, رافك, 
   {{0x26c4037e,0x4f04267c,0x00000000,0x00000000}},	//   nblo_, мнун_, --, --, 
   {{0xe29853ee,0xb7d401e1,0x3f840064,0x00000000}},	//   _фан_, _iṣeb, _ūmus_, --, 
   {{0xf3900ca8,0x0cc0004b,0x9c641d0a,0x00000000}},	//   _iṣan_, پيوټ, وهاو, --, 
   {{0x307401c6,0x00000000,0x00000000,0x00000000}},	//   _зурс, --, --, --, 
   {{0x98b00790,0xf3900055,0x7f900139,0x00000000}},	//   _ıyı_, _kṣan_, bäqa, --, 
   {{0xbfb00011,0xae0401af,0x9cf4014b,0x00000000}},	//   _ছবিঘ, _порҙ, _очаш, --, 
   {{0xd90c11fc,0xb8141614,0x8ee000eb,0x00000000}},	//   شیت_, едиј, ন্দগ, --, 
   {{0x36d453ef,0xff38001f,0xa91c16a3,0x00000000}},	//   нопр, _በማስመ, dožd, --, 
   {{0xdce001e4,0x00000000,0x00000000,0x00000000}},	//   dioĉ, --, --, --, 
   {{0x2490010e,0xf3900241,0xb8d400eb,0x00000000}},	//   _azym_, _nṣan_, _জজ_, --, 
   {{0xb7d40241,0x00000000,0x00000000,0x00000000}},	//   _aṣeb, --, --, --, 
   {{0x2490068f,0x798002ce,0xc87c0e78,0xdec0069d}},	//   _czym_, momw, üßt_, ድሩን_, 
   {{0x798002ce,0xd1b853f0,0xf7e000d1,0x00000000}},	//   lomw, قارا_, _ﺋﻪﻳﺪ, --, 
   {{0xd13853f1,0x2fd80618,0x15f01fd2,0x00000000}},	//   оха_, _svsg_, _अमिर_, --, 
   {{0x6fb853f2,0x349434ac,0x798005b8,0x00000000}},	//   згар_, _пайр, nomw, --, 
   {{0x61440131,0x705801c0,0xdce001e4,0x506400f3}},	// [5a90] رىكە, чаар_, cioĉ, фтва, 
   {{0xa91c0f03,0x798025df,0x00000000,0x00000000}},	//   može, homw, --, --, 
   {{0xa91c2333,0xfc3053f3,0x798053f4,0x6e9401c6}},	//   lože, یحه_, komw, хижу, 
   {{0x3cf400d0,0x25b002f0,0x249000a2,0xad400137}},	//   _ľavá_, ízli_, _yzym_, دۉرۉ, 
   {{0x7bc400a8,0x26c402ea,0xa91c53f5,0x798053f6}},	//   ţiun, yblo_, nože, domw, 
   {{0xfbe00d01,0x00000000,0x00000000,0x00000000}},	//   _निरम, --, --, --, 
   {{0x8d74278f,0xa91c00d0,0xdab40451,0x7a800023}},	//   _قارا, hože, رهيت_, _ሕንገዳ_, 
   {{0x798053f7,0xa91c0306,0x3b640014,0x00000000}},	//   gomw, kože, _یێنہ, --, 
   {{0x2d9c0c8a,0xca7003e6,0x2b8800d7,0xfd7c032e}},	//   mmwe_, رۆچک, húci_, _þáað_, 
   {{0x7ac453f8,0xa91c0552,0xe73000c6,0x920c03e5}},	//   _асце, dože, اصة_, ाबाज_, 
   {{0x2b880038,0x5f0401ad,0x66e40022,0x7afc01e3}},	//   júci_, _सॉफ्_, _ҷола, _örta, 
   {{0x2b8801f1,0x798053f9,0x2d9c18cb,0x00000000}},	//   dúci_, comw, nmwe_, --, 
   {{0xab5c025c,0x2d9c53fa,0x2b88000f,0xa91c0010}},	//   _awżi, imwe_, túch_, gože, 
   {{0xa91c53fb,0x2d9c00ca,0xdbc400c5,0x27ec009d}},	//   sožd, hmwe_, _tööe, muen_, 
   {{0x27ec53fc,0x6b9c04cc,0x2cac030a,0x2b8800d0}},	//   luen_, _èsgu, _oged_, rúch_, 
   {{0x202c0201,0xa91c0122,0x2cac016d,0x290c53fd}},	//   _አመልክ, bože, _nged_, neea_, 
   {{0xd00453fe,0x656453ff,0x27ec5400,0xdfd05401}},	// [5aa0] нете_, mikh, nuen_, ايط_, 
   {{0xe1f85402,0x80ac10f7,0x65645403,0x798002ce}},	//   _его_, _झलके, likh, zomw, 
   {{0x64445404,0x79805405,0x9afc0208,0x27ec01f4}},	//   lyki, yomw, _nitơ_, huen_, 
   {{0x65645406,0x27ec5407,0xa2b8081e,0xe88c02d3}},	//   nikh, kuen_, ्रक्, _ቅድሚኡ_, 
   {{0x60d45408,0x0c805409,0x798000ca,0x6444540a}},	//   maym, лышм, vomw, nyki, 
   {{0x6564540b,0x60d4540c,0x27ec540d,0x2cac030a}},	//   hikh, laym, duen_, _eged_, 
   {{0x6564014b,0x7980009f,0x61ec540e,0x2054001f}},	//   kikh, tomw, nubl, _ለመቀየ, 
   {{0x6564540f,0x60d4094a,0x64440006,0x6d900158}},	//   jikh, naym, kyki, låan, 
   {{0x27ec5410,0x79800003,0x3ba45411,0x65645412}},	//   guen_, romw, _алаҳ, dikh, 
   {{0x79805413,0xd6d84ced,0x61ec5414,0x64445415}},	//   somw, чти_, kubl, dyki, 
   {{0x79805416,0x65645417,0x60d402d1,0x290c0083}},	//   pomw, fikh, kaym, beea_, 
   {{0x61ec5418,0x65645419,0xa91c09a8,0x290c054e}},	//   dubl, gikh, tože, ceea_, 
   {{0x60d4541a,0x6444541b,0x645801e4,0x3ce80037}},	//   daym, gyki, ŝtin, _चएने_, 
   {{0x61ec0129,0xa2b817c6,0x00000000,0x00000000}},	//   fubl, ्रग्, --, --, 
   {{0x03f82ad9,0x41e41fe2,0x6564541c,0x43943dc8}},	//   وژیک_, літа, bikh, уарс, 
   {{0xa91c08ad,0x2b8800d0,0x60d4022e,0x9c840064}},	//   pože, rúci_, gaym, _kočė, 
   {{0x752c541d,0x84240150,0xa91c022a,0xc7b0010f}},	// [5ab0] _inaz, _مىين, ložc, ָבע_, 
   {{0x6d900183,0x00000000,0x00000000,0x00000000}},	//   gåan, --, --, --, 
   {{0x27ec01c0,0x40940131,0x7bc40311,0x61ec0066}},	//   zuen_, پلەر, ţiul, cubl, 
   {{0x8d84005e,0x2d9c35ba,0xfbd003e6,0x60d400a2}},	//   رشان, umwe_, ڵته_, caym, 
   {{0x752c00ec,0x7d74541e,0x27ec009d,0xbd880451}},	//   _mnaz, دالط, xuen_, رنهن_, 
   {{0x65643824,0x7bc00354,0x3f9801ab,0x2d9c0083}},	//   zikh, _dtmu, _ghru_, smwe_, 
   {{0x65640028,0x752c541f,0x6444033f,0x290c0356}},	//   yikh, _onaz, zyki, teea_, 
   {{0x27ec152d,0x656402c4,0x752c0337,0xa924036b}},	//   tuen_, xikh, _nnaz, тдил, 
   {{0x65645420,0xa91c151c,0x290c0276,0x61ec03b9}},	//   vikh, tožb, reea_, zubl, 
   {{0x27ec5421,0x65645422,0x290c5423,0x7c845424}},	//   ruen_, wikh, seea_, _сусе, 
   {{0x65645425,0x27ec5426,0x752c031c,0x290c5427}},	//   tikh, suen_, _bnaz, peea_, 
   {{0x644438ec,0x69c05428,0x27ec03f5,0xdce0025c}},	//   tyki, _itle, puen_, oloġ, 
   {{0x27ec5429,0x6564542a,0x4424007b,0xec3400df}},	//   quen_, rikh, ím_, דאָר_, 
   {{0xe298152d,0x6564542b,0x752c542c,0x60d4542d}},	//   даг_, sikh, _enaz, waym, 
   {{0x65640b6f,0xb7d40241,0xd6cc007b,0x60d4542e}},	//   pikh, _iṣab, _بقى_, taym, 
   {{0x752c19f5,0x61ec542f,0xe3c00166,0x5924031c}},	//   _gnaz, rubl, _aqış_, _འོབས_, 
   {{0x60d45430,0xdce001a6,0x6d9000fe,0x9f84010b}},	// [5ac0] raym, lnoć, tåan, вгад, 
   {{0x61ec24b6,0x60d45431,0xe2c801e2,0x00000000}},	//   publ, saym, _تودو_, --, 
   {{0x60d45432,0x69c05433,0x7bc001a9,0x61ec047e}},	//   paym, _ntle, _stmu, qubl, 
   {{0x61445434,0x60d45435,0x21680212,0x1c445436}},	//   _рема, qaym, _цими_, кнем, 
   {{0x4c100228,0x3f985437,0x1b600022,0x00000000}},	//   لبوس, _thru_, аҭаҟ, --, 
   {{0xdee41ee3,0x00000000,0x00000000,0x00000000}},	//   _шоги, --, --, --, 
   {{0x2b8801f1,0xb9841955,0xb37804ce,0xdb1c02d2}},	//   júcu_, лтиқ, cでus, _þvía, 
   {{0xdce004b9,0x39140a31,0xb7d40248,0x8470001f}},	//   dnoć, умир, _aṣab, _ጥላሁን_, 
   {{0x69c05438,0x38c85439,0x4510025c,0x7afc007c}},	//   _etle, واکی_, _ཏྲེར_, _örto, 
   {{0x752c0c5e,0x6d4000a2,0xe8d80051,0x00000000}},	//   _snaz, _îlar, _ượ_, --, 
   {{0xd00800bd,0x64580115,0x9938014b,0x00000000}},	//   রিয়_, ŝtil, _ояду_, --, 
   {{0xa91c0306,0x00000000,0x00000000,0x00000000}},	//   rožc, --, --, --, 
   {{0x18344e02,0x00000000,0x00000000,0x00000000}},	//   _جراح, --, --, --, 
   {{0x36d4543a,0x52bc000b,0x13a401ed,0xa91c0427}},	//   _сокр, ्रेस, ئنسی_, moža, 
   {{0xa2b8543b,0x7768005a,0x245007d6,0x00000000}},	//   ्रज्, midx, لچیس, --, 
   {{0x4174543c,0x9fa401e0,0x8fc40014,0x7648543d}},	//   لاقس, ғыуҙ, ٖزان, mydy, 
   {{0xa91c1591,0x76480209,0xffb401c6,0x00000000}},	// [5ad0] noža, lydy, ийтэ, --, 
   {{0x644801e1,0x00000000,0x00000000,0x00000000}},	//   _ńfig, --, --, --, 
   {{0x4ea43163,0x7648543e,0xfe704444,0x7db400ae}},	//   траа, nydy, يدم_, لصنا, 
   {{0xbd1800d6,0x776801c4,0xcacc0154,0xfaf80171}},	//   кції_, hidx, _রাইফ, _acī_, 
   {{0x69c0543f,0x200407ea,0x776801c4,0x316801c4}},	//   _stle, çoit_, kidx, miaz_, 
   {{0x7afc03fa,0x31685440,0x76480432,0x00000000}},	//   _örtl, liaz_, kydy, --, 
   {{0x6a845441,0x27e801e4,0xc33404ae,0xb7d40055}},	//   ылка, _ŭan_, יוס_, _rṣab, 
   {{0x4a700efb,0xe8f85442,0x316801c0,0xad2400cf}},	//   лықт, хли_, niaz_, _حىرى, 
   {{0x6c740114,0xfed80166,0x00000000,0x00000000}},	//   _слађ, _öçär_, --, --, 
   {{0xdce0248d,0x52bc1f13,0x49b8132f,0x3168005a}},	//   tnoć, ्रोस, _قاصد_, hiaz_, 
   {{0x69c003a1,0x76485443,0x50d05444,0x2ca80030}},	//   _utle, gydy, तराष, ľadu_, 
   {{0x15780873,0xdce016a3,0xa91c0427,0x2b8800d0}},	//   ﻧﺎﺳﯩ, rnoć, boža, rúcu_, 
   {{0xdce0098d,0x27e81709,0x291c0810,0x5edc015b}},	//   snoć, _ían_, _iawa_, ন্টে, 
   {{0x291c5445,0x20540220,0x76480432,0x00000000}},	//   _hawa_, ңтар, bydy, --, 
   {{0x291c5446,0x316801c4,0x00000000,0x00000000}},	//   _kawa_, fiaz_, --, --, 
   {{0x291c5447,0x3168009d,0xe29808ca,0xba000092}},	//   _jawa_, giaz_, даҳ_, _ቀዶ_, 
   {{0x291c5448,0x5f0401c6,0x23740066,0x00000000}},	// [5ae0] _mawa_, лзаа, _مادح, --, 
   {{0x291c5449,0xc33004a2,0x10a000a8,0x00000000}},	//   _lawa_, _بەس_, сиун, --, 
   {{0x63b4001e,0x1e9400a8,0x3168005a,0x2eb400ee}},	//   _huyn, урар, biaz_, рсус, 
   {{0x291c544a,0x63b4544b,0x2004503f,0x7768005a}},	//   _nawa_, _kuyn, çois_, zidx, 
   {{0xe04401a9,0x00000000,0x00000000,0x00000000}},	//   _ёнги, --, --, --, 
   {{0x8c400640,0x63b400a2,0x764801f4,0xd7f80124}},	//   сеље, _muyn, yydy, ҭуп_, 
   {{0x2740038e,0xdd9005d9,0x19a80228,0xfbe01524}},	//   _méně_, _هوس_, нтип_, _निकम, 
   {{0xdca4544c,0xdee402f4,0x291c544d,0x00000000}},	//   _баби, _шоҳи, _cawa_, --, 
   {{0x291c544e,0x68fc01ab,0xfe4401d5,0x00000000}},	//   _dawa_, òsda, _ёнғо, --, 
   {{0x3ce40cf9,0x316801c6,0xda58084c,0x29081574}},	//   _hdmv_, ziaz_, _преш_, _ñaan_, 
   {{0x291c03f9,0xa91c544f,0x776801c4,0x7c2401e4}},	//   _fawa_, možn, ridx, ĥiru, 
   {{0x291c5450,0xa91c5451,0x76485452,0x9f50023a}},	//   _gawa_, ložn, rydy, ltyä_, 
   {{0x73c40032,0x3168030a,0x178401ee,0x00000000}},	//   шәйе, viaz_, _йѳкм, --, 
   {{0x291c0b45,0xae04033d,0xd12c001f,0xa91c12fe}},	//   _zawa_, _रहलन_, _አለመኖ, nožn, 
   {{0x291c5453,0xc1e83c85,0x316801c4,0xb7d4002b}},	//   _yawa_, льте_, tiaz_, _kṣob, 
   {{0x9f5002f6,0x2618033f,0x291c0de2,0x518428fc}},	//   htyä_, _बनती_, _xawa_, ууга, 
   {{0x31685454,0x63b4067c,0x05745455,0xfbe033af}},	// [5af0] riaz_, _guyn, _داود, _निगम, 
   {{0x31685456,0x7bdc0055,0x00000000,0x00000000}},	//   siaz_, _ārup, --, --, 
   {{0xc2085457,0xf1942ecb,0x7e280006,0xa91c0432}},	//   _یقین_, _винь, ліца_, dožn, 
   {{0xdb244c9a,0x09e000cc,0xd138010a,0x00000000}},	//   یونی, _মহলা, _чхо_, --, 
   {{0x291c5458,0x95880023,0x00000000,0x00000000}},	//   _rawa_, _ሚእትን_, --, --, 
   {{0x291c5459,0x2fc8545a,0xaa44084c,0x00000000}},	//   _sawa_, mpag_, иелл, --, 
   {{0x291c0bed,0x5f600092,0x00000000,0x00000000}},	//   _pawa_, ጋገራቸ, --, --, 
   {{0x291c0113,0x7d0400c5,0x7c4803b2,0x00000000}},	//   _qawa_, õist, ísrá, --, 
   {{0xa91c1710,0x6d58545b,0x3cf00216,0x7d0400df}},	//   božn, mhwa, šové_, ĵist, 
   {{0x753c006d,0x291c545c,0xa764545d,0x21fc0548}},	//   ejsz, _wawa_, ркод, yïh_, 
   {{0x291c545e,0xdb240133,0x63b400a2,0x00000000}},	//   _tawa_, _خولی, _suyn, --, 
   {{0x6e201a36,0x64a4545f,0x6d5807a9,0x63b40113}},	//   _álbu, иана, nhwa, _puyn, 
   {{0xf7705460,0x6d580810,0x63b45461,0x25700327}},	//   _کان_, ihwa, _quyn, nġli_, 
   {{0x27ec5462,0x33180953,0x6d585463,0x00000000}},	//   mren_, ліся_, hhwa, --, 
   {{0x27ec5464,0x91e0084c,0xa91c02fb,0x61445465}},	//   lren_, жосе, nožo, аева, 
   {{0x27ec03f5,0x63b45466,0x614400d8,0x00000000}},	//   oren_, _tuyn, шеба, --, 
   {{0x27ec5467,0x1f645468,0x2fc81c04,0x6d585469}},	// [5b00] nren_, акам, gpag_, dhwa, 
   {{0x27ec04c4,0xdee4546a,0x67200219,0xd004151e}},	//   iren_, рожи, ndlj, рефе_, 
   {{0x27ec546b,0xe298009b,0x5fe00073,0xbea800e5}},	//   hren_, _шао_, _पिकल, اخذے_, 
   {{0x27ec06a3,0x6d58546c,0x91b8011a,0xa0680798}},	//   kren_, ghwa, _שמכי, _аама_, 
   {{0x9f50049b,0x27ec546d,0xa91c1f48,0xef9007d6}},	//   ttyä_, jren_, tožn, _کیلد, 
   {{0x27ec546e,0x67200219,0x61ec017a,0xccf40107}},	//   dren_, jdlj, orbl, лқӣ_, 
   {{0x27ec546f,0xa91c5470,0x9f50023a,0xd334011a}},	//   eren_, rožn, rtyä_, ירסה_, 
   {{0x6d585471,0x27ec0bed,0x9f50023a,0x61ec01ab}},	//   chwa, fren_, styä_, irbl, 
   {{0xd838152d,0x27ec5472,0x1ea805d9,0x5ba833be}},	//   тэй_, gren_, _ساڳي_, _акам_, 
   {{0xa91c09a8,0x35f44f33,0xd5b832ea,0x753c0175}},	//   ložl, бпор, ксм_, wjsz, 
   {{0x27ec5473,0x5efc000d,0x19bc00d1,0xd918010a}},	//   aren_, _लान्_, _ﻧﺎﻣﻠ, _аьл_, 
   {{0xd5644e19,0xb4d00a59,0x5f043f2c,0x00000000}},	//   ртоп, षरे_, स्त्_, --, 
   {{0x53445474,0x27ec005a,0x61ec5475,0x98a45476}},	//   ахва, cren_, erbl, _тиде, 
   {{0x6d580564,0x07a05477,0xc7b0011a,0x70780ca8}},	//   zhwa, _дачн, _ובס_, _ọjó, 
   {{0x30e401ec,0x00000000,0x00000000,0x00000000}},	//   йсаң, --, --, --, 
   {{0x6d580944,0x74f806ed,0xd200009d,0x00000000}},	//   xhwa, _сеир_, бүүк, --, 
   {{0x61ec5478,0xa91c00d7,0x1aec00eb,0x00000000}},	// [5b10] arbl, dožl, চ্যে_, --, 
   {{0x6d585479,0x9268022e,0x00000000,0x00000000}},	//   whwa, _арма_, --, --, 
   {{0x6d58547a,0x27ec547b,0xbfa8547c,0xf1e0547d}},	//   thwa, zren_, ртте_, _फिटन, 
   {{0x27ec547e,0x2fc8062c,0x3f840162,0xefe40092}},	//   yren_, ppag_, _ímun_, ምረው_, 
   {{0x6d58547f,0xab9401ec,0x00000000,0x00000000}},	//   rhwa, биді, --, --, 
   {{0x27ec5480,0x00000000,0x00000000,0x00000000}},	//   vren_, --, --, --, 
   {{0xa9685481,0x6d58055a,0xaa442758,0x00000000}},	//   лика_, phwa, сейл, --, 
   {{0x6d585482,0xed04104c,0x00000000,0x00000000}},	//   qhwa, _دورپ, --, --, 
   {{0x27ec5483,0xf39001e1,0x2d8c4b16,0x290800e8}},	//   uren_, _eṣin_, _ikee_, _ñaam_, 
   {{0x27ec5484,0x0a6800c7,0x61ec0158,0x46602374}},	//   rren_, _иреи_, yrbl, يۇشق, 
   {{0xaa940597,0x27ec01c4,0xca7001d3,0x00000000}},	//   _الاث, sren_, _بناک, --, 
   {{0x27ec5485,0x2b4400ae,0xc8b80037,0x00000000}},	//   pren_, _holc_, _उलिट, --, 
   {{0x6c7800c8,0x86b00220,0x2b44030a,0xf4800023}},	//   ראָפ, _мәні, _kolc_, _የቕርብ_, 
   {{0x660008a5,0xf6680214,0x1c1c01f9,0xbbcc013d}},	//   ptlk, احیه_, _मैफल_, _şäkü, 
   {{0xe5a45486,0x2d8c0582,0x61ec5487,0x88800244}},	//   _лики, _okee_, urbl, _دیکن, 
   {{0x71580305,0x61ec007c,0x00a80150,0xf6500244}},	//   арус_, rrbl, _ﻋﻭﺍﻤ_, _تئه_, 
   {{0xa91c00d7,0x00000000,0x00000000,0x00000000}},	// [5b20] vožl, --, --, --, 
   {{0x66f803f8,0x00000000,0x00000000,0x00000000}},	//   ्भिक_, --, --, --, 
   {{0x21685488,0x25dc00e1,0xdee400d1,0x9f500129}},	//   _бини_, _कौमी_, _қови, nuyé_, 
   {{0xd5f800c8,0x823402d3,0x00000000,0x00000000}},	//   טפער, _ኣመሓዳ, --, --, 
   {{0x307405f5,0x2b440165,0x00000000,0x00000000}},	//   _дурс, _bolc_, --, --, 
   {{0x2d8c5489,0xa3d802ab,0x10a00120,0xdca41b4a}},	//   _ekee_, डीय_, _ѕирн, _ғази, 
   {{0x9964548a,0x0f54008f,0x46d8012d,0x00000000}},	//   йтил, _פילם_, _मज़ह, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2120009a,0x2b440561,0xd94400d1,0x2c440014}},	//   _makh_, _folc_, _қеди, _ویٔپ_, 
   {{0xa91c009b,0x50180302,0x2b440165,0x95c8548b}},	//   nožj, נויו, _golc_, лума_, 
   {{0xe894010c,0x00000000,0x00000000,0x00000000}},	//   _ዘዳግም_, --, --, --, 
   {{0x3a2c548c,0xb3700023,0xa77400db,0x26180037}},	//   _irdp_, _ኣብያን_, йлөч, _बनरी_, 
   {{0x9484548d,0x3a200421,0x1c1c2232,0x00000000}},	//   сынд, āipu_, पिटल_, --, 
   {{0x96b8548e,0xa91c0010,0x00000000,0x00000000}},	//   _суду_, jožj, --, --, 
   {{0x21201bce,0x2570025c,0x00000000,0x00000000}},	//   _bakh_, eġlu_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x21200de2,0x33200327,0xb4c407f7,0x7ae803ac}},	// [5b30] _dakh_, _tahx_, एडी_, _oddt, 
   {{0x257000f3,0x2d8c0363,0xdc34013d,0x00000000}},	//   ršle_, _skee_, _säğa, --, 
   {{0x21200198,0x00000000,0x00000000,0x00000000}},	//   _fakh_, --, --, --, 
   {{0x7ae8548f,0x6ad000af,0x2b4400db,0x247c001f}},	//   _addt, हर्र, _solc_, _የፕሬስ_, 
   {{0x2b443df9,0xec240137,0x00000000,0x00000000}},	//   _polc_, تىشپ, --, --, 
   {{0xaa4800d1,0x225c0790,0x26181d34,0x00000000}},	//   ипла_, _öykü_, _बनली_, --, 
   {{0x3a2c5490,0x2d840077,0x21205491,0x29080de2}},	//   _crdp_, _íleo_, _yakh_, _ñaak_, 
   {{0x3a2c0356,0x00000000,0x00000000,0x00000000}},	//   _drdp_, --, --, --, 
   {{0x5fe02007,0xa91c03c6,0xfb742832,0xc8b000dd}},	//   _पिछल, ložk, _کھنگ, _ہلاک, 
   {{0x5fe0023e,0xdc5400f2,0xd7040108,0x00000000}},	//   _पिघल, _برفک, онье_, --, 
   {{0x3a2c0048,0xe57806bb,0xa91c0122,0xe5a45492}},	//   _grdp_, изо_, nožk, жини, 
   {{0x6ff4031c,0xf2c80a7c,0x29180037,0x00000000}},	//   _པཀྵུ_, _יע_, õsad_, --, 
   {{0x66e45493,0x272000b0,0x9d180a1e,0x9f500129}},	//   _дола, _pōnē_, בורט, suyé_, 
   {{0xa2d425aa,0xa91c0232,0x21201bce,0x9f5006af}},	//   تيست, kožk, _sakh_, puyé_, 
   {{0xa1140633,0x171800df,0x00000000,0x00000000}},	//   يوست, _כוסע, --, --, 
   {{0x7de00cad,0x561001f7,0x00000000,0x00000000}},	//   _lásá, _آويء, --, --, 
   {{0xefe00023,0x826400d1,0x00000000,0x00000000}},	// [5b40] _ናባይ_, زۇڭن, --, --, 
   {{0x2494001f,0xfaac0ca8,0x21205494,0x9e8c0023}},	//   መዘገቡ_, _iṣẹ́_, _wakh_, _ጀሚርና_, 
   {{0x44204496,0x614403b7,0xc224004b,0x21201bce}},	//   _hsi_, _дена, _عکسو, _takh_, 
   {{0x1d085495,0x629c0fb7,0x795c003e,0xc1d400fb}},	//   реди_, _izpo, _kéwe, _мөғә, 
   {{0x5c145496,0x44200316,0xed580010,0x3a2c00a3}},	//   تظار, _jsi_, _dlž_, _srdp_, 
   {{0x8af40213,0x44205497,0x00000000,0x00000000}},	//   şəni, _msi_, --, --, 
   {{0x44205498,0xa3d80490,0xf1a80424,0x00000000}},	//   _lsi_, डीत_, _خایه_, --, 
   {{0x44205499,0x00000000,0x00000000,0x00000000}},	//   _osi_, --, --, --, 
   {{0x44200c8a,0x7d0002d0,0xacb000d1,0x20780023}},	//   _nsi_, _icms, _كەمب, _ተመሪጹ_, 
   {{0x10340302,0x8c180302,0x35f40992,0x7c2002d0}},	//   קטים_, _דומי, ппор, _ismr, 
   {{0x4420549a,0x7d00067c,0x7f900139,0xd5b800d8}},	//   _asi_, _kcms, läqs, јсо_, 
   {{0xd1e02440,0x3940000d,0x00000000,0x00000000}},	//   ዝገባ_, _õis_, --, --, 
   {{0x4420549b,0x2bdc045b,0x7968012d,0x00000000}},	//   _csi_, नीपा, jświ, --, 
   {{0xd1e00020,0x7968033f,0x00000000,0x00000000}},	//   ዝገብ_, dświ, --, --, 
   {{0x4420549c,0x6ec800bc,0x00000000,0x00000000}},	//   _esi_, ाँसँ, --, --, 
   {{0x7d000010,0x7c20549d,0x00000000,0x00000000}},	//   _ncms, _osmr, --, --, 
   {{0x44200309,0x60c401d9,0x6b5c067c,0x629c549e}},	// [5b50] _gsi_, _dfkm, _hège, _ezpo, 
   {{0x6b5c007f,0x3dd803cb,0x10d00150,0xc6b400df}},	//   _kège, _bwrw_, _ﺘﺘﺩﺨ, ַלדז_, 
   {{0x7c2002d0,0x3dd803cb,0x44200076,0x645801e4}},	//   _asmr, _cwrw_, _zsi_, ŝtit, 
   {{0x62180375,0x3dd80142,0x795c00e8,0x442001f4}},	//   _פורק, _dwrw_, _yéwe, _ysi_, 
   {{0x4420549f,0x92cc0c58,0x6b5c0066,0x00000000}},	//   _xsi_, ৱলী_, _lège, --, 
   {{0x6b6454a0,0x3dd803cb,0xbc380592,0xa91c12fe}},	//   якла, _fwrw_, تسما_, moži, 
   {{0x7de0066d,0x3dd8015d,0x00000000,0x00000000}},	//   _vásá, _gwrw_, --, --, 
   {{0xcd34072d,0x684400d8,0x00000000,0x00000000}},	//   _برسب, зниа, --, --, 
   {{0x3d9454a1,0x6d480327,0x5c7454a2,0x4acc00dc}},	//   _цитр, _ioea, _нәшр_, _स्थव, 
   {{0x442054a3,0x537c001f,0x00000000,0x00000000}},	//   _rsi_, _የቅዱስ_, --, --, 
   {{0x442054a4,0x3b640050,0x6d4854a5,0xaa8800c6}},	//   _ssi_, _تُلِ, _koea, _انضم_, 
   {{0x44200f85,0x4acc043e,0x00000000,0x00000000}},	//   _psi_, _स्तव, --, --, 
   {{0xc448107f,0x748c1ee0,0x6d4854a6,0xe72854a7}},	//   زیدن_, _መንገዱ_, _moea, _голд_, 
   {{0x44200f72,0x6d480093,0x2bdc00dc,0xa91c3831}},	//   _vsi_, _loea, नीया, doži, 
   {{0xe2981363,0x26f80fc8,0x4420033f,0x6b5c01e1}},	//   сав_, ्भीर_, _wsi_, _kègb, 
   {{0x44200190,0x629c54a8,0x6d480069,0xbf14012c}},	//   _tsi_, _vzpo, _noea, ड़्न_, 
   {{0x442054a9,0x557400c8,0x2fd8015d,0x2bdc0834}},	// [5b60] _usi_, _מעקן_, _cwsg_, नीमा, 
   {{0x1ea800c6,0x26c4003a,0x6b5c0241,0x6458010f}},	//   ماضي_, nclo_, _lègb, ŝtis, 
   {{0x9cc854aa,0x29080694,0x629c00ef,0x00000000}},	//   была_, _ñaaw_, _uzpo, --, 
   {{0x6d480393,0xad6454ab,0x00000000,0x00000000}},	//   _coea, وانه, --, --, 
   {{0x6d4854ac,0x2fd8015d,0xdca43f07,0x5bc4007b}},	//   _doea, _gwsg_, чади, ستشف, 
   {{0x3dd80142,0x00000000,0x00000000,0x00000000}},	//   _twrw_, --, --, --, 
   {{0x6d900158,0x8e8052d1,0x8fa000c7,0x25700427}},	//   gåas, _згре, _чаре, zšla_, 
   {{0x6d48031c,0xd91802bf,0x225c00d0,0x2560032e}},	//   _goea, ськ_, útky_, _hólf_, 
   {{0x36d4277c,0x6b5c020c,0x00000000,0x00000000}},	//   мопр, _sège, --, --, 
   {{0xd6840022,0x1ae4009d,0x00000000,0x00000000}},	//   зумп, _хожм, --, --, 
   {{0x63600109,0x2d94010a,0x00000000,0x00000000}},	//   _kônf, _арăс, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2c0000dc,0x7afc54ad,0x00000000,0x00000000}},	//   ोऽयं_, _örts, --, --, 
   {{0xa91c54ae,0x00000000,0x00000000,0x00000000}},	//   voži, --, --, --, 
   {{0xe6380451,0x00000000,0x00000000,0x00000000}},	//   _ويهڻ_, --, --, --, 
   {{0xd34454af,0xa3d805f9,0xa91c54b0,0x8678011a}},	//   _کیسه_, डीह_, toži, _לרוו, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [5b70] --, --, --, --, 
   {{0xa91c54b1,0x53a000db,0x61f00205,0x00000000}},	//   roži, _سۅزك, üklü, --, 
   {{0x0ea406ab,0x6d4854b2,0xb7d400b8,0x00000000}},	//   केंड, _poea, _iṣub, --, 
   {{0x02a41cd1,0xa91c0030,0xfd64002b,0x00000000}},	//   _ярым, poži, _kauṇ, --, 
   {{0x2bdc02ab,0xb7d400cd,0xeab854b3,0x00000000}},	//   _नौशा, _kṣub, ойл_, --, 
   {{0xfbd054b4,0x6d9005ac,0x256008a5,0xfd640055}},	//   اتن_, tåas, _gólf_, _mauṇ, 
   {{0x6d4804c9,0xae041d00,0x45c80150,0x00000000}},	//   _toea, _توزى, _ﺒﺈﻋﻼ, --, 
   {{0x66040254,0xa020010e,0xe8f800d8,0x00000000}},	//   _ähki, _įözm, цли_, --, 
   {{0xe73050d8,0x00000000,0x00000000,0x00000000}},	//   نصد_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x178001c6,0xbae4007b,0xc0d00023,0x6b5c01e1}},	//   тгэм, _سكني, ብራህ_, _tègb, 
   {{0x26c40005,0xa6d40154,0x240801d5,0x67d401a9}},	//   sclo_, _দাওয়, онми_, _жоду, 
   {{0x660c01a6,0x546401b9,0x00000000,0x00000000}},	//   _ćaku, даям_, --, --, 
   {{0x290c1028,0xf3800150,0x00000000,0x00000000}},	//   lfea_, лғым, --, --, 
   {{0x795c06fd,0x2bdc16ae,0x00000000,0x00000000}},	//   _héwa, नीता, --, --, 
   {{0x795c034c,0x10a0084c,0x00000000,0x00000000}},	//   _kéwa, ӂиун, --, --, 
   {{0xd0043849,0x490c0316,0x142054b5,0x75c800bc}},	// [5b80] мете_, थ्यो_, _адым, _věze, 
   {{0xe298035b,0x795c065c,0x8c20009e,0x4f840014}},	//   _мап_, _méwa, পমান_, والہ, 
   {{0xdd9054b6,0x795c00f2,0xdbc40ede,0x9d4454b7}},	//   پوش_, _léwa, _köçe, межд, 
   {{0x60c001f1,0x00000000,0x00000000,0x00000000}},	//   žomb, --, --, --, 
   {{0x06e009bd,0x795c525e,0x25600008,0xa91c19d6}},	//   _মানি, _néwa, _tólf_, nožu, 
   {{0x63602776,0x2ca80209,0x6aa400af,0xd04c0213}},	//   _dông, ýada_, गे्र, _necə, 
   {{0x290c54b8,0x78880200,0x00000000,0x00000000}},	//   ffea_, këvë, --, --, 
   {{0x795c00d5,0xa3bc1d24,0x00000000,0x00000000}},	//   _béwa, इदा_, --, --, 
   {{0x6360006a,0x9b0454b9,0x4acc102f,0xd04c03e3}},	//   _kônd, _озад, _स्वव, _becə, 
   {{0x795c54ba,0x290c54bb,0x6ea40764,0x00000000}},	//   _déwa, afea_, _करमु, --, 
   {{0x60d40158,0x00000000,0x00000000,0x00000000}},	//   kbym, --, --, --, 
   {{0xceb00375,0xc1d802dd,0xfd6400b8,0x3d1c012d}},	//   כית_, _ﺁﻨﺫﺍ, _pauṇ, _नसों_, 
   {{0x7bc005d9,0xa3d80574,0x795c002e,0x490000db}},	//   _jumu, डील_, _géwa, _شووق, 
   {{0x7bc054bc,0xfa0c081f,0xd04c00ac,0x8898011a}},	//   _mumu, _གྱོན_, _gecə, _ובדי, 
   {{0x7bc054bd,0x41e454be,0x0620035b,0x78880200}},	//   _lumu, кіта, _афым, bëvë, 
   {{0xde38001f,0x795c002e,0xf4d801b9,0xdbc42ba3}},	//   _የሚያወ, _yéwa, _эмиш_, _göçe, 
   {{0x7bc054bf,0x15c80952,0x6b5c067c,0xcee854c0}},	// [5b90] _numu, ﯖﯩﺰﺩ, _lèga, قران_, 
   {{0xa91c0122,0x37c000fe,0x7ed40244,0x00000000}},	//   ložt, _এবাৰ, نزما, --, 
   {{0x6360006a,0x7bc01140,0x6b5c020c,0x8af40213}},	//   _sông, _aumu, _nèga, şəki, 
   {{0x7bc03b72,0xfa0c2fb5,0xab5c0003,0x626401ec}},	//   _bumu, _གྱེན_, _muże, _ساپق, 
   {{0x7bc00c95,0xef64009d,0x00000000,0x00000000}},	//   _cumu, _зэвү, --, --, 
   {{0x6360006a,0x7bc00502,0x795c00f2,0x4cd400fe}},	//   _gônd, _dumu, _réwa, _হাওঁ, 
   {{0x7bc0003e,0x795c0438,0x7f94035b,0xa91c0118}},	//   _eumu, _séwa, _рарх, kožt, 
   {{0x7bc054c1,0x290c0421,0x4c7001e0,0x0d7401d5}},	//   _fumu, ufea_, _иҫер, _کیچک_, 
   {{0x7bc054c2,0x66e454c3,0x6d5854c4,0x6bd80244}},	//   _gumu, нопа, mkwa, _رواس_, 
   {{0x6d5854c5,0x6360019f,0x178000ee,0x25600419}},	//   lkwa, _kône, лгым, _móle_, 
   {{0x7bc054c6,0xdb1000b5,0x25600241,0x6d5854c7}},	//   _zumu, ågår, _lóle_, okwa, 
   {{0x6d5813a1,0x7bc054c8,0x795c0066,0xab5c0034}},	//   nkwa, _yumu, _téwa, _duże, 
   {{0x649854c9,0x6d5854ca,0x7bc022a9,0xa3d854cb}},	//   ятор_, ikwa, _xumu, डीं_, 
   {{0x69c054cc,0xa91c0118,0x62980254,0x00000000}},	//   _kule, rožu, ütoo, --, 
   {{0x69c02d75,0x6d5854cd,0xa59453ef,0xa91c0118}},	//   _jule, kkwa, _прищ, božt, 
   {{0x69c054ce,0x6d580d27,0x2560033f,0xdbc4013d}},	//   _mule, jkwa, _bóle_, _uöçe, 
   {{0x69c054cf,0x6d580c09,0x60d454d0,0x00000000}},	// [5ba0] _lule, dkwa, rbym, --, 
   {{0x6d5854d1,0x69c054d2,0x3ebc0b1a,0x60d400d7}},	//   ekwa, _oule, øvt_, sbym, 
   {{0x7bc054d3,0xe29854d4,0x69c054d5,0x1754008f}},	//   _sumu, _хан_, _nule, עסער_, 
   {{0x7bc054d6,0x6d5854d7,0xdd940a2c,0x0d20004e}},	//   _pumu, gkwa, رجاع, лүсү, 
   {{0x69c054d8,0x7bc003f0,0x8ccc07f7,0x25600419}},	//   _aule, _qumu, दड़ो, _góle_, 
   {{0x6d580337,0x7bc007a9,0x6b5c1f3f,0xcb6454d9}},	//   akwa, _vumu, _pèga, наче_, 
   {{0xab5c031c,0x7bc054da,0x9f500789,0xc0c00023}},	//   _bużb, _wumu, cuyá_, _ኵዕሶ_, 
   {{0x89f400f4,0xd90c54db,0x6d5854dc,0xdcb00ef6}},	//   رعىز_, صیت_, ckwa, _مىز_, 
   {{0x69c054dd,0x7c2454de,0x7bc054df,0xb7880daf}},	//   _eule, çird, _uumu, мәке_, 
   {{0x69c054e0,0x881001f7,0x00000000,0x00000000}},	//   _fule, ابيط, --, --, 
   {{0xd0080183,0xb5500b82,0x45580023,0x62980254}},	//   ৰিয়_, _ዕረፍት, _ዝረኽበ, ütol, 
   {{0x588454e1,0x46a00fca,0xec680354,0x261000c5}},	//   _пыла, ышыб, _ирĕк_, _तहरी_, 
   {{0x69c00639,0xd498013e,0x24780092,0x53b401a9}},	//   _zule, яро_, _የቦርድ_, нғир_, 
   {{0xd1b852c8,0x69c054e2,0x29081574,0xab5c025c}},	//   كارا_, _yule, _ñaar_, _tuże, 
   {{0x6d58009a,0x69c054e3,0x00000000,0x00000000}},	//   ykwa, _xule, --, --, 
   {{0xf8e009ae,0xf48401d5,0x256000d7,0x00000000}},	//   नरिय, _لاخی, _póle_, --, 
   {{0x06e00729,0x795c003e,0x12e4109a,0x00000000}},	// [5bb0] _মাতি, _léwo, _пінг, --, 
   {{0x636000d8,0x6d5829d0,0x3254014b,0x80780454}},	//   _pône, wkwa, _авор, хбус_, 
   {{0x6d580d27,0x795c002e,0x932401b9,0x9f500432}},	//   tkwa, _néwo, _قرگن, gtyñ_, 
   {{0x6d5800ec,0x69c054e4,0x256001e1,0x00000000}},	//   ukwa, _rule, _tóle_, --, 
   {{0x69c054e5,0x6d5854e6,0xab2854e7,0x3c580276}},	//   _sule, rkwa, дола_, ницэ_, 
   {{0x69c054e8,0x6d5854e9,0x795c003e,0x1bf0000d}},	//   _pule, skwa, _béwo, _घिरल_, 
   {{0xda6054ea,0x8d743009,0xc33406a9,0xaa4454eb}},	//   ивши, _كارا, טוס_, тейл, 
   {{0x69c054ec,0x6ecc2ecf,0xad24198a,0x3d0801f9}},	//   _vule, दुरु, _جىرى, _हाये_, 
   {{0x2d9c009a,0xd8b41410,0x161c000d,0xc0d01954}},	//   mlwe_, نگها_, _बनउर_, ብካሉ_, 
   {{0x69c054ed,0x7c2454ee,0x2d9c0032,0x4680036b}},	//   _tule, çire, llwe_, лқла, 
   {{0x2d9c01ee,0x69c03877,0xa3d805d7,0x3b6402e8}},	//   olwe_, _uule, डीई_, _сътв, 
   {{0xfa0c0003,0xf98805d9,0x0cbc00cc,0x00000000}},	//   _གྱིན_, _ٻنهي_, _উজুত, --, 
   {{0x2d9c54ef,0x9cd4011a,0x00000000,0x00000000}},	//   ilwe_, כורה_, --, --, 
   {{0x987800c8,0x2d9c3058,0x18640798,0x00000000}},	//   _קאסט, hlwe_, _јаши_, --, 
   {{0xe50800dc,0x2b080118,0x00000000,0x00000000}},	//   _वापि_, _सानु_, --, --, 
   {{0x80dc033f,0x00000000,0x00000000,0x00000000}},	//   बरें, --, --, --, 
   {{0x6b5c39d3,0x2d9c0b6f,0x636000d8,0x5f042f09}},	// [5bc0] _règn, dlwe_, _cônc, кзаа, 
   {{0x93f804ac,0xd36c157c,0x2d9c27be,0xa1c41621}},	//   _קליי, _وهي_, elwe_, _ибод, 
   {{0x216800db,0x00000000,0x00000000,0x00000000}},	//   _жини_, --, --, --, 
   {{0x795c0098,0x6564004d,0x00000000,0x00000000}},	//   _réwo, nhkh, --, --, 
   {{0x795c003e,0x6e341196,0x2bdc095f,0xadc401e0}},	//   _séwo, _erzb, नीला, _ҡарһ, 
   {{0xa3d802a0,0xdb1c0790,0x00000000,0x00000000}},	//   डीए_, _övün, --, --, 
   {{0x79800083,0x81d40154,0x6e34012d,0x3f9800ef}},	//   tnmw, _হয়ত_, _grzb, _ikru_, 
   {{0x2bdc1100,0xdd9054f0,0x00000000,0x00000000}},	//   _नौका, _ئور_, --, --, 
   {{0x97a41def,0x00000000,0x00000000,0x00000000}},	//   крол, --, --, --, 
   {{0x473021d0,0xe74400fd,0xdb18036e,0x00000000}},	//   аньс, лүче_, _mitë, --, 
   {{0xdb1854f1,0x6b5c026c,0x0f540375,0x917c01e1}},	//   _litë, _mègl, דיים_, _jẹ́n_, 
   {{0x61e8143a,0xa91c0306,0xfa0805ac,0xd6d80154}},	//   _åfly, sožr, লবদল_, _দাওয, 
   {{0x56f00daf,0x161c033f,0x2b0800bc,0x68fc0162}},	//   _күпс, _बनकर_, _सामु_, ósde, 
   {{0x3f98016b,0x27f801f1,0x9f40003b,0x00000000}},	//   _nkru_, ásne_, _hvkæ_, --, 
   {{0xab5c003d,0x910454f2,0x765c03cd,0x00000000}},	//   _juża, кчад, øryd, --, 
   {{0x656454f3,0xab5c031c,0xf7780327,0x69c403b2}},	//   chkh, _muża, liħ_, íhei, 
   {{0x9f500784,0x6b5c0129,0xc0c800f3,0x00000000}},	// [5bd0] kuyä_, _bègl, тусе_, --, 
   {{0xdb18069c,0x752c0433,0x161400af,0x40341219}},	//   _ditë, _haaz, _तहार_, шеус, 
   {{0x2d9c0b58,0x752c54f4,0xed5801a6,0x6b5c004e}},	//   tlwe_, _kaaz, _liže_, _sègo, 
   {{0x2560317c,0x14e029d9,0x86780375,0xdb180240}},	//   _kóla_, परिण, ורבו, _fitë, 
   {{0x752c54f5,0xed580b91,0x06e0015b,0x6c8401d5}},	//   _maaz, _niže_, _মাসি, دلشم, 
   {{0xfbd054f6,0x6e9454f7,0x3d0800af,0x256000d7}},	//   زته_, _бигу, _हाथे_, _móla_, 
   {{0x256001e1,0x6a141888,0x00000000,0x00000000}},	//   _lóla_, ابتر, --, --, 
   {{0x752c54f8,0x63600798,0xccb000c7,0xb3d80154}},	//   _naaz, _môna, _кәль, _তিনজ, 
   {{0xdce01cce,0x7c8454f9,0xf7780327,0x3d083507}},	//   lioğ, _куфе, fiħ_, _हाते_, 
   {{0xed5805ce,0xdb18020c,0x6f040226,0x75c800bc}},	//   _diže_, _nitè, nghc, _vězn, 
   {{0x752c0a49,0xa50854fa,0x2c0001e0,0x6f0454fb}},	//   _baaz, нена_, _түҙм, ighc, 
   {{0x256054fc,0x752c00c7,0xba740131,0x85b40116}},	//   _bóla_, _caaz, _ئاكت, шәлч, 
   {{0x68e854fd,0xf7780003,0x7d040192,0xdce00205}},	//   maed, biħ_, òisi, hioğ, 
   {{0xb9dc2295,0x68e806d6,0xdb182d6e,0x66e454fe}},	//   _አቶ_, laed, _citè, _сока, 
   {{0x27ec2c0a,0x672054ff,0xf7705500,0x6b5c5501}},	//   lsen_, melj, _بان_, _règl, 
   {{0x66000a81,0x3f985502,0x6b5c2508,0x68e85503}},	//   mulk, _skru_, _sègl, naed, 
   {{0x27ec5504,0x9ad0063f,0x66000306,0xdb180200}},	// [5be0] nsen_, hịag, lulk, _qitë, 
   {{0x27ec5505,0x63600109,0xdb181762,0x752c1418}},	//   isen_, _fôna, _gitè, _zaaz, 
   {{0x68e85506,0x27ec5507,0x752c0337,0x660002f0}},	//   kaed, hsen_, _yaaz, nulk, 
   {{0x27ec5508,0x61ec0998,0x67205509,0xab5c0003}},	//   ksen_, msbl, helj, _ruża, 
   {{0x6720550a,0x27ec550b,0x68e80428,0x6600550c}},	//   kelj, jsen_, daed, hulk, 
   {{0x27ec3778,0x67201326,0xed583c52,0x3f9802d1}},	//   dsen_, jelj, _riže_, _ukru_, 
   {{0x6720550d,0x27ec550e,0xef90006c,0x61ec01e3}},	//   delj, esen_, _بیلد, nsbl, 
   {{0x68e8074d,0x63bc550f,0x61ec0926,0xad24136e}},	//   gaed, _lipn, isbl, _پرفو, 
   {{0xdb185510,0x27ec2aad,0xb8cc28fe,0x752c0083}},	//   _lité, gsen_, _गर_, _raaz, 
   {{0x67205511,0x256000dd,0x61ec5512,0x94841669}},	//   gelj, _róla_, ksbl, ғымд, 
   {{0x68e80770,0x66005513,0x27ec5514,0xdb180c6a}},	//   baed, gulk, asen_, _nité, 
   {{0x25600005,0x68e8003a,0xdb1802bd,0x00000000}},	//   _póla_, caed, _sitè, --, 
   {{0x23800020,0xc9900597,0xdb1800c7,0x27ec5515}},	//   _የህዝብ_, _النظ, _aité, csen_, 
   {{0x13a45516,0xdb180de2,0x6600022a,0x672000f3}},	//   انسی_, _bité, bulk, celj, 
   {{0xdb185517,0xd1385518,0x752c0198,0x63bc5519}},	//   _cité, нха_, _taaz, _dipn, 
   {{0xdb18551a,0xbdfc02f5,0xc5f0008d,0x41c4551b}},	//   _dité, ীবাদ_, _הדק_, сёра, 
   {{0x6b5c04fb,0xdb1802e2,0x00000000,0x00000000}},	// [5bf0] _sègm, _titè, --, --, 
   {{0x2b08551c,0x63bc551d,0xa3d838bf,0xb2743529}},	//   _साधु_, _gipn, डीओ_, _влош, 
   {{0xab5c031c,0x4ea4551e,0x2c0000fe,0x27ec0bbc}},	//   _bużn, ураа, _এনেই_, zsen_, 
   {{0x27ec551f,0xad2415c3,0xc5f008a8,0xeb1c012d}},	//   ysen_, شىتى, מדע_, फ़्त_, 
   {{0x1aec03f4,0x68e85520,0xdb180a40,0x7b6400fd}},	//   চ্ছে_, vaed, _zité, әтче, 
   {{0x68e85521,0x27ec5522,0xdb18002e,0x999400f2}},	//   waed, vsen_, _yité, یپور_, 
   {{0x27ec5523,0xf8e000dc,0xa96808ca,0x66000009}},	//   wsen_, नरूप, кика_, xulk, 
   {{0xc9401621,0x31680369,0x66002665,0x00000000}},	//   сдиқ, nhaz_, vulk, --, 
   {{0x27ec5524,0xa76404a9,0x68e85525,0x39480228}},	//   usen_, икид, raed, اشىپ_, 
   {{0xb8fc0a28,0x66005526,0x68e81509,0xdd0c456f}},	//   _त्_, tulk, saed, _kışk, 
   {{0x27ec5527,0x68e85528,0x672015ad,0xe94421f4}},	//   ssen_, paed, relj, _پرای, 
   {{0x27ec5529,0xd87403e6,0x68e8552a,0x6600031c}},	//   psen_, امیت_, qaed, rulk, 
   {{0x6600552b,0x67201068,0x61ec552c,0xdb180212}},	//   sulk, pelj, wsbl, _sité, 
   {{0xdb18552d,0xb4e40c2e,0x63bc0455,0x629c0022}},	//   _pité, _पड़ी_, _qipn, _pypo, 
   {{0xe298516a,0xa3d803f3,0xc3282baf,0x63bc552e}},	//   тав_, डीज_, মালি_, _vipn, 
   {{0x629c0232,0x2e400020,0x63bc0ea0,0xdb1800e5}},	//   _vypo, _የሚያመ, _wipn, _vité, 
  
   {{0x629c006d,0x3fc82580,0x00000000,0x00000000}},	// [5c00] _wypo, ادری_, --, --, 
   {{0x629c552f,0x256000d2,0xdb180098,0x61ec005c}},	//   _typo, _kólo_, _tité, psbl, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3168003a,0xdd0c0790,0xbfc80c75,0x2eb40107}},	//   chaz_, _dışk, _ماسە_, ссус, 
   {{0xd24c5530,0xd17401c6,0xa3d801f9,0xfc38035b}},	//   _فنی_, _төрх_, डीच_, ыҭа_, 
   {{0xdce45531,0xdd0c0790,0x00000000,0x00000000}},	//   ımın, _fışk, --, --, 
   {{0x99641f71,0x1b000154,0x201001f4,0x00000000}},	//   итил, _এসআই_, ltyi_, --, 
   {{0x6b5c0ffb,0x6e6400db,0x920000cd,0x00000000}},	//   _lègh, _اچكۅ, _śākh, --, 
   {{0x20105532,0xdb08002d,0x4aa4013d,0x68fc03b2}},	//   ntyi_, rmfâ, лкән_, ósda, 
   {{0x27f801f1,0xb6f81e4a,0x2010009a,0xfb845533}},	//   ásna_, دىدا_, ityi_, _ادری, 
   {{0xd6840075,0xed5801a6,0x2010023a,0x7ae8127b}},	//   рупп, _hiža_, htyi_, _iedt, 
   {{0x2bdc43d1,0xc95000c7,0x00000000,0x00000000}},	//   नीका, _ҳтәы, --, --, 
   {{0xb7d45534,0xe9940214,0xda00033f,0x00000000}},	//   _اقتب, _اهنگ, रूरत_, --, 
   {{0x256002d2,0x00000000,0x00000000,0x00000000}},	//   _hóll_, --, --, --, 
   {{0x7ae85535,0x2b085536,0x3168009a,0x3cf800bc}},	//   _medt, _सासु_, thaz_, ुलाइ_, 
   {{0x7ae85537,0xd5400241,0x61f801d3,0x00000000}},	//   _ledt, _dẹ́b, átla, --, 
   {{0xed580552,0x403435c7,0x5dc41870,0x3a2c00c0}},	// [5c10] _niža_, оетс, ەممە, _lsdp_, 
   {{0x7ae812ed,0xb8e80327,0x66100244,0x00000000}},	//   _nedt, _ཉུ_, _بژیا, --, 
   {{0x31685538,0x03a400d8,0x00000000,0x00000000}},	//   phaz_, _фиќо, --, --, 
   {{0x2b0807f7,0xe9d801d5,0x00000000,0x00000000}},	//   _साहु_, қки_, --, --, 
   {{0x3d080c2e,0x40840364,0x3a2c5539,0x7aa4000d}},	//   _हारे_, _дурб, _asdp_, _ओरउअ, 
   {{0x3a2c01ee,0xff04046e,0x82341927,0xed5800ef}},	//   _bsdp_, _мясн, _اریا, _diža_, 
   {{0x3a2c553a,0x0a680801,0x625c0135,0xdce00306}},	//   _csdp_, ърди_, _għoġ, choď, 
   {{0x8d74553b,0x2918553c,0x00000000,0x00000000}},	//   _ئاسا, ýsa_, --, --, 
   {{0x25604888,0x7ae8553d,0xe738104e,0x9a740075}},	//   _sólo_, _fedt, геп_, ийәт_, 
   {{0x2560553e,0x5ea000db,0xa76401c4,0x00000000}},	//   _pólo_, _بۅۅل, скод, --, 
   {{0xc984003b,0x24e801d5,0x00000000,0x00000000}},	//   _куди, лмни_, --, --, 
   {{0x2010049b,0xf2c8008f,0xa0200037,0x00000000}},	//   ytyi_, _טע_, ööko, --, 
   {{0xb37002d3,0x3a2c01ef,0x00000000,0x00000000}},	//   _ኣብዘን_, _zsdp_, --, --, 
   {{0xb9f007db,0x6aa0553f,0xd88401d3,0xe5780166}},	//   _ናብ_, _kylf, _چھین_, _әзи_, 
   {{0xa2e45540,0x41b40406,0x25601d1d,0x91e0361e}},	//   _қонд, ंगलस, _hólm_, зосе, 
   {{0x6264036b,0x201002f6,0x98a00006,0x6378151e}},	//   авҳа, ttyi_, žką_, _әсир_, 
   {{0x1f645541,0x00000000,0x00000000,0x00000000}},	// [5c20] бкам, --, --, --, 
   {{0x44205542,0xed582230,0x2010023a,0x00000000}},	//   _ipi_, _riža_, rtyi_, --, 
   {{0x201002f6,0x3ebc0267,0x2fb80276,0x00000000}},	//   styi_, ävt_, рытэ_, --, 
   {{0xae3400f1,0x1f3000f1,0xa06800f3,0x1c440150}},	//   غونډ, _ډېرځ, _бама_, йнем, 
   {{0x44205543,0x7ae81180,0xad640066,0x00000000}},	//   _jpi_, _pedt, غامه, --, 
   {{0xfe785544,0xeb540046,0x19f40014,0xf8e009b2}},	//   _күз_, يىنگ, مِتھ_, नर्प, 
   {{0x44203743,0x7ae85545,0xdd70040b,0xab5c0327}},	//   _lpi_, _vedt, _ٹھاک, _gużm, 
   {{0x44205546,0xb9100241,0xdd140244,0xdd9000ec}},	//   _opi_, _halẹ_, _دورخ, _ڀوڳ_, 
   {{0x96e85547,0xefdc0020,0xb9100241,0xd8380a89}},	//   льна_, _ዕቅድ_, _kalẹ_, уэй_, 
   {{0x81c000fe,0x00000000,0x00000000,0x00000000}},	//   ুঠি_, --, --, --, 
   {{0x44205548,0xa3bc0918,0x6aa00008,0x2560002e}},	//   _api_, ेदन_, _gylf, _tóll_, 
   {{0xd5645549,0x6b5c00f7,0x53e401c0,0xb91001e1}},	//   стоп, _règi, йцга, _lalẹ_, 
   {{0x9a840032,0xdb18554a,0xa64c0023,0x983401d3}},	//   _туҡл, _lití, _ንዘይተ, _دعاؤ, 
   {{0xc0bc2440,0x2bdc0073,0xe7940133,0xc1c001ec}},	//   ቲክስ_, नीटा, _واوک, _ﺣﺎﺭﺍ, 
   {{0x442011c1,0x75d4554b,0x3134554c,0xdb180109}},	//   _epi_, _بيبا, оевр, _kitâ, 
   {{0x44203e39,0x00000000,0x00000000,0x00000000}},	//   _fpi_, --, --, --, 
   {{0x4420020c,0xdb18554d,0xd324554e,0x00000000}},	// [5c30] _gpi_, _mitâ, _льни, --, 
   {{0x0dc801f4,0x00000000,0x00000000,0x00000000}},	//   гуди_, --, --, --, 
   {{0x833405f5,0xab5c0135,0x1ee812ea,0xbfa801e5}},	//   _энэх, _fużj, شونی_, стте_, 
   {{0x714000db,0x44200200,0x310800db,0x00000000}},	//   _تۉرۅ, _ypi_, _өнүп_, --, 
   {{0x442002fa,0x6aa000a9,0x00000000,0x00000000}},	//   _xpi_, _sylf, --, --, 
   {{0x65901d86,0xaa4400ee,0x09b0043e,0x6b6401a9}},	//   māhe, жекл, ुद्य, юкла, 
   {{0xc04c001f,0x2bdc00c5,0x9b90007b,0x6d4c000d}},	//   _አመሰግ, नीजा, بلوت, öaas, 
   {{0x2ee001fa,0x63600798,0xdb18054e,0xc27c010f}},	//   lbhf_, _cônj, _citâ, טרוי, 
   {{0x7d0400c6,0x45a40131,0xa82401b9,0x6aa0015d}},	//   óise, ۋەتك, تکان, _wylf, 
   {{0xe618554f,0x6aa00158,0x442003b9,0xe154001f}},	//   адо_, _tylf, _rpi_, _የወንጌ, 
   {{0xda001533,0x65c42401,0x7dfc0356,0x02a800bc}},	//   रूआत_, юбна, căsă, _गरेन, 
   {{0x64a45550,0x6ae0015b,0x659002b1,0xdb18015d}},	//   жама, _নাটো, kāhe, _gitâ, 
   {{0xf4800023,0x6fa80412,0xefdc0092,0x02c40026}},	//   _ከቕርብ_, कतां, _ዕቅዱ_, зигү, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4620025c,0xb88400d1,0xc6a401a9,0x00000000}},	//   _འགྲས_, _муәй, _урди, --, 
   {{0xe0d85551,0x44205552,0x2d8c5553,0x3dd8020b}},	//   рва_, _tpi_, _njee_, _rtrw_, 
   {{0x291c5554,0x44205555,0x10a0022e,0x9f500108}},	// [5c40] _mbwa_, _upi_, дитн, yryä_, 
   {{0x7c245556,0x2d8c5557,0x63041ba4,0xdb185558}},	//   çirm, _ajee_, _بودل, _mitã, 
   {{0xa0c400f7,0x291c2252,0x25dc0073,0x68f80210}},	//   _ويدو, _obwa_, कीची_, _odwd, 
   {{0xf1d40323,0xdb180005,0xd1b83c5a,0x31640036}},	//   _хөрө, _vití, _پاپا_, ëlzt_, 
   {{0x6e280cf4,0xf0000116,0x2908002e,0x00000000}},	//   _ćebe, _пүти, _ñaay_, --, 
   {{0x291c5559,0x256006ea,0x1ea8555a,0xda780117}},	//   _abwa_, _bólk_, _نازي_, ияй_, 
   {{0x291c04ba,0x5924025c,0x6b5c067c,0x2cac0489}},	//   _bbwa_, _རྒུས_, _nègu, _ezed_, 
   {{0xdb180109,0xdc2800f2,0x00000000,0x00000000}},	//   _qitâ, _پسره_, --, --, 
   {{0x0d7401ed,0x00000000,0x00000000,0x00000000}},	//   _بینک_, --, --, --, 
   {{0x256019cf,0x63600109,0x795c003e,0x6b5c0129}},	//   _fólk_, _dônk, _réwu, _bègu, 
   {{0xdb180120,0xf2c40011,0x00000000,0x00000000}},	//   _titâ, ্রমণ, --, --, 
   {{0x291c0048,0xdb18555b,0x25f00037,0x00000000}},	//   _gbwa_, _hità, ूंजी_, --, 
   {{0x3bd00de2,0xf83801d9,0x7980006f,0x94a82083}},	//   _jàq_, _دزاں_, mimw, ртна_, 
   {{0x7980555c,0x47300064,0x00000000,0x00000000}},	//   limw, _оніс, --, --, 
   {{0xdb1806d9,0x3bd01bce,0x15740050,0xdb08007c}},	//   _mità, _làq_, _ؤتھ_, mmfä, 
   {{0x3494555d,0x798008e7,0x65901d76,0xa2440014}},	//   _найр, nimw, tāhe, سیُل_, 
   {{0x50640006,0xdce00165,0xb64402dd,0x00000000}},	// [5c50] цтва, zhoă, _ﺎﻕ_, --, 
   {{0x7980555e,0xdb180109,0x2bbc0100,0xd24401c6}},	//   himw, _nità, _gňch_, _дэми, 
   {{0x7980555f,0xaac8012d,0xbe240166,0x00000000}},	//   kimw, िखसक, _öçlä, --, 
   {{0x798001f7,0x2b4401ab,0x659000b0,0x14ac0490}},	//   jimw, _snlc_, pāhe, _घराण, 
   {{0xac085560,0xa91c0960,0xdb1800db,0x60d400c8}},	//   ёнка_, niže, _bità, _מורא_, 
   {{0xab281515,0xdb18026c,0x3bd00694,0x00000000}},	//   сока_, _cità, _dàq_, --, 
   {{0x2d8c01e0,0x7dc415bf,0x7d040332,0x8d840150}},	//   _tjee_, سقۇن, óisc, _дуад, 
   {{0xab5c003d,0x6b5c0268,0x3bd0002e,0x00000000}},	//   _mużi, _règu, _fàq_, --, 
   {{0x02a80dc5,0xa91c3ad4,0x2d9c068f,0xdb1805da}},	//   _गर्न, jiže, mowe_, _fità, 
   {{0x2d9c5561,0xdb1801ab,0xa91c07f5,0x8ae4003b}},	//   lowe_, _gità, diže, _фіал, 
   {{0xe5a45562,0x798001b2,0x2560032e,0xed585563}},	//   зини, bimw, _hóli_, _kož_, 
   {{0x291c015c,0x2d9c068f,0x7980090c,0x636000d8}},	//   _ubwa_, nowe_, cimw, _iôni, 
   {{0xe7385564,0xed585565,0x33d45566,0x29d008a5}},	//   _гел_, _mož_, діст, _háa_, 
   {{0x2d9c5567,0xa2e402ab,0x29d00241,0xed580419}},	//   howe_, करेज_, _káa_, _lož_, 
   {{0x2d9c5568,0x61445569,0xa5d8211f,0x29d002d2}},	//   kowe_, пева, _ابتر_, _jáa_, 
   {{0x29d00570,0x290c556a,0x63600120,0x2d9c0034}},	//   _máa_, ngea_, _môni, jowe_, 
   {{0x2d9c068f,0xdb1800d2,0x1f64115c,0xd00c0014}},	// [5c60] dowe_, _litá, пкам, ێلہ_, 
   {{0x7980556b,0x23840014,0x00000000,0x00000000}},	//   zimw, _ژٔکِ, --, --, 
   {{0x7980556c,0x1d2400a8,0x3bd00de2,0x29d0556d}},	//   yimw, змем, _sàq_, _náa_, 
   {{0x2d9c556e,0xed580316,0x2560556f,0xd5f8008f}},	//   gowe_, _což_, _bóli_, מפער, 
   {{0xdb18004e,0x79800099,0xaadc012c,0xe7ec00bc}},	//   _pità, vimw, नुभक, चीमा_, 
   {{0xdb18172e,0x79801446,0x29d00241,0x60d40042}},	//   _bitá, wimw, _báa_, lcym, 
   {{0x2d9c5570,0xdb180122,0xed5801fa,0x7980090c}},	//   bowe_, _citá, _fož_, timw, 
   {{0x29d00248,0x2d9c033f,0x3bd0002e,0xc3280eac}},	//   _dáa_, cowe_, _tàq_, মাটি_, 
   {{0x79805571,0xdb1835f5,0xa3bc5572,0x2e400092}},	//   rimw, _tità, ेदा_, _የሚደመ, 
   {{0x29d05573,0x79805574,0x60d40113,0x00000000}},	//   _fáa_, simw, hcym, --, 
   {{0x9f5009d7,0x79805575,0x29d003b2,0xdb1801d3}},	//   luyó_, pimw, _gáa_, _gitá, 
   {{0xa91c05ce,0x26d00156,0x00000000,0x00000000}},	//   tiže, ñzor_, --, --, 
   {{0x98d0063f,0x9f500407,0xa7fc01d3,0xe84800ec}},	//   _dịtụ, nuyó_, szűr, _وجهن_, 
   {{0xa91c09a8,0x2d9c5576,0xc7d408a8,0xab5c0327}},	//   riže, zowe_, _צווי_, _pużi, 
   {{0x43945577,0x2d9c5578,0x964401c0,0x656c002d}},	//   харс, yowe_, _хэлд, ânhâ, 
   {{0x3cf80210,0x00000000,0x00000000,0x00000000}},	//   ुलों_, --, --, --, 
   {{0x301405f5,0xed580219,0xc32803d4,0x534400d8}},	// [5c70] ьдар, _rož_, মাজি_, _ехна, 
   {{0x2d9c5579,0x7f580276,0xceb80063,0x256002d2}},	//   wowe_, паус_, бље_, _róli_, 
   {{0x2d9c557a,0xa2d40150,0x290c0066,0xd71803d4}},	//   towe_, _تيپت, ygea_, _থোৱা_, 
   {{0x5064036b,0x7bdc00b0,0x6b5c557b,0x29d003b2}},	//   _етга, _ōrua, _nègr, _ráa_, 
   {{0x2d9c557c,0xa1540bd4,0xac0800d6,0xc58c06d6}},	//   rowe_, _חברה_, інка_, nḓa_, 
   {{0x7c940502,0xd6c424e0,0x2d9c557d,0x628c0e3c}},	//   رشنا, _لق_, sowe_, šnoš, 
   {{0x7ac4016c,0x2d9c0034,0x290c05d5,0xed58013a}},	//   нишҷ, powe_, tgea_, _tož_, 
   {{0x9f500407,0xdb1826f6,0x256003b2,0x00000000}},	//   buyó_, _vitá, _tóli_, --, 
   {{0x6d48557e,0x290c557f,0x29d00248,0x66e4081b}},	//   _inea, rgea_, _wáa_, мопа, 
   {{0x63600120,0x6d4800a3,0x290c045f,0x2918007f}},	//   _tôni, _hnea, sgea_, òsab_, 
   {{0x6d485580,0xdc8c063f,0x60d40142,0x00000000}},	//   _knea, sịtụ_, ycym, --, 
   {{0xb36c0092,0x67f8002b,0xf2c40154,0x00000000}},	//   _ቢሊየን_, _påjā, ্রাণ, --, 
   {{0xc4482352,0x649814cd,0x888050f0,0x247c02d3}},	//   سیدن_, ютор_, _سیدن, _ብጸሎት_, 
   {{0x7c245581,0x60d40042,0x00000000,0x00000000}},	//   çiri, wcym, --, --, 
   {{0x6d485582,0xc6a43be4,0x21a40120,0x60d40042}},	//   _onea, _эрди, дивм, tcym, 
   {{0x6d4801ab,0x1b0400cc,0x75c8013a,0x6590002b}},	//   _nnea, ল্পই_, _vězt, bāha, 
   {{0x6e2800f3,0x60d40142,0x5f742e0b,0xa3b800ae}},	// [5c80] _ćeba, rcym, وائر, _واخر_, 
   {{0x6d485583,0xcfb00451,0x60d40042,0x6b8c0332}},	//   _anea, پٽمب, scym, éagl, 
   {{0xc2f400fe,0x91d80150,0x00000000,0x00000000}},	//   _জাপি_, _мәтi, --, --, 
   {{0x9f503eba,0x6d485584,0x0d20004e,0x00000000}},	//   tuyó_, _cnea, күсү, --, 
   {{0x6b5c0100,0xe04401b9,0x439c002b,0x00000000}},	//   _règr, _ўнги, _ṛṣis, --, 
   {{0x6d485585,0x9f500407,0x25600174,0xcb640114}},	//   _enea, ruyó_, _gólv_, маче_, 
   {{0x7f5c315a,0x6b5c0129,0x00000000,0x00000000}},	//   _iorq, _pègr, --, --, 
   {{0x38345586,0x7f5c5587,0x6d4804cc,0x0b4000b1}},	//   енир, _horq, _gnea, енән, 
   {{0xc2f409bd,0xe9700137,0x00000000,0x00000000}},	//   _জানি_, دۇند, --, --, 
   {{0xb36c0020,0xab5c031c,0x65900882,0x7f5c5588}},	//   _ቢሊዮን_, _bużu, vāha, _jorq, 
   {{0x6d48045f,0x7bc800b5,0x659002b5,0x59740022}},	//   _ynea, _iidu, wāha, _ҭыҵу, 
   {{0x7bc85589,0x00000000,0x00000000,0x00000000}},	//   _hidu, --, --, --, 
   {{0x7bc8558a,0xe7ec0cb4,0xd4980334,0x6d900115}},	//   _kidu, चीदा_, юро_, kĥan, 
   {{0x7bc8558b,0x7f5c558c,0xa91c01a6,0x92680484}},	//   _jidu, _norq, miža, орба_, 
   {{0x7bc8558d,0x00000000,0x00000000,0x00000000}},	//   _midu, --, --, --, 
   {{0xf3f8010b,0x2560558e,0xc69000df,0x00000000}},	//   _ениш_, _bólu_, _שאק_, --, 
   {{0xfe7004fb,0x85b80014,0xdb1800fd,0x7bc8005a}},	// [5c90] یدم_, _تاوس_, _kitä, _oidu, 
   {{0x636006ed,0x7f5c003a,0x7bc8558f,0xdb180139}},	//   _bônu, _corq, _nidu, _jitä, 
   {{0xdb180664,0x7f5c014f,0xf2c40154,0x00000000}},	//   _mitä, _dorq, ্রহণ, --, 
   {{0x0edc05d7,0xa1140046,0x256002d2,0xac94005b}},	//   _प्रड, _كوپت, _fólu_, наеш, 
   {{0x7bc85590,0xa91c08ad,0x7f5c1c69,0x25605591}},	//   _bidu, jiža, _forq, _gólu_, 
   {{0x7bc85592,0x274402b1,0xac940124,0x00000000}},	//   _cidu, _mënä_, _ҟазш, --, 
   {{0xa9a40440,0xf3340023,0x00000000,0x00000000}},	//   никд, _ብዝተሓ, --, --, 
   {{0xe8f807d6,0x7bc85593,0xdb1800af,0x31685594}},	//   чли_, _eidu, _aitä, nkaz_, 
   {{0xed5805ce,0x7f5c036b,0xdb180139,0x00000000}},	//   _niži_, _yorq, _bitä, --, 
   {{0xdb181248,0x7bc85595,0x00000000,0x00000000}},	//   _citä, _gidu, --, --, 
   {{0x316806be,0x00000000,0x00000000,0x00000000}},	//   kkaz_, --, --, --, 
   {{0x7bc85596,0x224401a6,0xa91c0841,0xe9180212}},	//   _zidu, _čok_, biža, _ході_, 
   {{0x7bc85597,0x00000000,0x00000000,0x00000000}},	//   _yidu, --, --, --, 
   {{0xdb18014a,0x316801c4,0x6d4c0083,0xe73800f3}},	//   _gitä, ekaz_, ηaan, _хек_, 
   {{0x7f5c004e,0x25600d12,0x88805598,0x31680139}},	//   _rorq, _bólt_, _سیگن, fkaz_, 
   {{0x7f5c0784,0x65901d76,0x683c0023,0x256002f0}},	//   _sorq, māho, ኬግልስ, _pólu_, 
   {{0x7f5c5599,0x9f40011f,0x6008559a,0x00000000}},	// [5ca0] _porq, _awká_, янам_, --, 
   {{0xe3b00aaa,0x3168009d,0x00000000,0x00000000}},	//   _حرب_, akaz_, --, --, 
   {{0x7bc8559b,0xf8ac0118,0x00000000,0x00000000}},	//   _ridu, _चर्प, --, --, 
   {{0x7bc8559c,0x6b80015d,0x2560559d,0xf2c400fe}},	//   _sidu, _amlg, _gólt_, ্ৰহণ, 
   {{0x7bc8559e,0xdb84559f,0x8c400816,0x8bd402dd}},	//   _pidu, нгди, леце, еміс_, 
   {{0x0494001f,0x659004fe,0x636000d8,0xa91c01a6}},	//   _ዘንድሮ_, kāho, _tônu, viža, 
   {{0x7bc855a0,0x996407b5,0x8d6009a5,0xdb180139}},	//   _vidu, етпл, _өвре, _ritä, 
   {{0x7bc855a1,0xdca455a2,0x63600109,0xdb18023a}},	//   _widu, _заби, _kôns, _sitä, 
   {{0xdb18426d,0x7bc855a3,0x1c4455a4,0xdd9402dd}},	//   _pitä, _tidu, _янам, _жаңы, 
   {{0x7bc80381,0xed580841,0xa91c0e04,0x57b001ec}},	//   _uidu, _riži_, riža, ыұлт, 
   {{0xa91c0024,0xd6d801d9,0x00000000,0x00000000}},	//   siža, _ہوشش_, --, --, 
   {{0xa91c05ce,0x00000000,0x00000000,0x00000000}},	//   ližn, --, --, --, 
   {{0x316820c2,0xa3bc00dc,0x00000000,0x00000000}},	//   vkaz_, ेदं_, --, --, 
   {{0xc95007dd,0x65b400bc,0xa91c0427,0x4bb0010a}},	//   _атәы, váhe, nižn, _уйĕс, 
   {{0x7d0002d0,0xc7b0011a,0xe50800cd,0x00000000}},	//   _odms, _גבס_, _वाचि_, --, 
   {{0x274402b5,0x31680030,0x00000000,0x00000000}},	//   _tënä_, ukaz_, --, --, 
   {{0x3168036b,0x636055a5,0xcee800d1,0xe70802dd}},	// [5cb0] rkaz_, _côns, كران_, _ءتۇن_, 
   {{0xa91c55a6,0x3168005a,0x753c01d3,0xa3bc00dc}},	//   jižn, skaz_, ldsz, ेदः_, 
   {{0xa91c09a8,0xed0000c7,0x00000000,0x00000000}},	//   dižn, _аҟ̆н, --, --, 
   {{0x753c066d,0x61bc00cd,0x00000000,0x00000000}},	//   ndsz, ्दृष, --, --, 
   {{0x753c01f5,0x606000d1,0x3ce000e4,0x6dbc0055}},	//   idsz, _پۇلل, ÿiva_, _ṇasa, 
   {{0x6a8407d6,0x6f14033f,0x4ad401d9,0x00000000}},	//   клла, _uczc, راتھ_, --, 
   {{0x69940801,0x7f9455a7,0x9ba00e56,0x00000000}},	//   крих, _сарх, جەلى, --, 
   {{0x3978005b,0x00000000,0x00000000,0x00000000}},	//   есью_, --, --, --, 
   {{0x6d58545b,0xdda400c7,0x6d900115,0x765c005b}},	//   mjwa, _рырҿ, nĥam, äryn, 
   {{0xe64400a7,0x659002b5,0x6d5802d0,0xe76400f3}},	//   веоп, tāho, ljwa, твоп, 
   {{0xa50855a8,0xe7440032,0xdaa003e6,0x660402e8}},	//   мена_, еүҙе_, _پڕوپ, ъпна, 
   {{0x6d5855a9,0x3870035b,0x00000000,0x00000000}},	//   njwa, рқәт, --, --, 
   {{0x68e855aa,0xb86455ab,0x27940117,0x00000000}},	//   mbed, _ماوو, _ишкр, --, 
   {{0x65900a26,0x27f800d0,0x00000000,0x00000000}},	//   pāho, ásnu_, --, --, 
   {{0xa91c0306,0x00000000,0x00000000,0x00000000}},	//   nižo, --, --, --, 
   {{0x910000fd,0xe52400c7,0x320400e5,0xe5a400db}},	//   ипсе, _рдип, álya_, _шийи, 
   {{0x46600b38,0x64a40640,0x45a400db,0x55b8011a}},	// [5cc0] _شۇڭق, _јапа, _لەگك, _קמפו, 
   {{0xdee4023a,0x4f040107,0xe3b8109a,0x68e855ac}},	//   тожи, кнун_, _ібн_, hbed, 
   {{0x68e80af4,0xa91c02fb,0xc61c009e,0x822c0092}},	//   kbed, vižn, ধিকা_, _ሴክሬታ, 
   {{0x68e855ad,0xa068004e,0x00000000,0x00000000}},	//   jbed, _жама_, --, --, 
   {{0xed5807f5,0x68e855ae,0x00000000,0x00000000}},	//   _nižu_, dbed, --, --, 
   {{0x68e855af,0x291800a3,0x19f40050,0x00000000}},	//   ebed, òsan_, نِتھ_, --, 
   {{0xdef855b0,0xa91c1a48,0x68e826c5,0x81d40154}},	//   _ның_, rižn, fbed, সীর_, 
   {{0x68e855b1,0xd90c55b2,0xed5801ef,0x999c01ef}},	//   gbed, زیت_, _bižu_, _vrtů_, 
   {{0xdb180085,0x36d40ff1,0x9a680451,0xdca40022}},	//   _mitú, лопр, _ڪمال_, _рааи, 
   {{0x61fc01f1,0xed5816a3,0xa91c00ef,0x00000000}},	//   _ovpl, _dižu_, bižo, --, 
   {{0x7af855b3,0xaaa817cb,0x00000000,0x00000000}},	//   mavt, _चुपक, --, --, 
   {{0xf59428ee,0xe8ac013d,0x00000000,0x00000000}},	//   الحج, _çişä, --, --, 
   {{0xc4581de1,0xe150044e,0x61e005a1,0x823404fb}},	//   виях_, _ኣረጋጊ, _čola, یرفا, 
   {{0xd90c55b4,0x7af855b5,0xdb0802d2,0x00000000}},	//   _ایک_, navt, flfé, --, 
   {{0xdb18043b,0x6b8c06af,0x61fc0205,0xd13855b6}},	//   _bitú, éagi, _cvpl, мха_, 
   {{0x0ee80027,0x7af800df,0x00000000,0x00000000}},	//   टर्स_, havt, --, --, 
   {{0x7ff403af,0x7af80a73,0x38600e89,0x63ac01ef}},	// [5cd0] لسلا, kavt, _àird_, blbn, 
   {{0x68e8026a,0x65b40232,0x7af8238f,0x2c1001f9}},	//   zbed, máha, javt, डंसं_, 
   {{0x0cc811b1,0x68e803ee,0x6d5855b7,0x61fc0175}},	//   िश्म, ybed, tjwa, _gvpl, 
   {{0x7af8003b,0x00000000,0x00000000,0x00000000}},	//   eavt, --, --, --, 
   {{0x8d7455b8,0xa7fc01d3,0x68e80158,0x00000000}},	//   _یارا, gyűl, vbed, --, 
   {{0x68e80d27,0xed580301,0x2078010f,0x6d5802d0}},	//   wbed, _rižu_, _טארא, sjwa, 
   {{0x765c0108,0xaa441c3e,0x00000000,0x00000000}},	//   äryl, انبى, --, --, 
   {{0xe9a855b9,0x5c702cc8,0x5b1000d1,0x68e80af9}},	//   رگان_, рләт, амәт, ubed, 
   {{0x68e855ba,0x3e3c001f,0x7af855bb,0xa7d400e5}},	//   rbed, _ባልደረ, bavt, دتبص, 
   {{0x68e84129,0x2cac0086,0xe3e00154,0x321000a2}},	//   sbed, _iyed_, _বিলব, kuzy_, 
   {{0x68e855bc,0x893400ae,0x00000000,0x00000000}},	//   pbed, _لعشا, --, --, 
   {{0x24e80139,0x6d5c01ab,0x2cac01bf,0x00000000}},	//   эмми_, _òsad, _kyed_, --, 
   {{0xf3f44c17,0x9580005b,0x00000000,0x00000000}},	//   аңы_, сляе, --, --, 
   {{0xdb180b19,0xd4240451,0x00000000,0x00000000}},	//   _sitú, اڻين_, --, --, 
   {{0x5210005b,0xdddc0210,0x00000000,0x00000000}},	//   йдёт, zypł, --, --, 
   {{0x00e455bd,0x00000000,0x00000000,0x00000000}},	//   شتری, --, --, --, 
   {{0xd00421fa,0x7af80d04,0x2cac003e,0xc68c0050}},	// [5ce0] лете_, yavt, _nyed_, _دِژ_, 
   {{0x61fc55be,0x386001ab,0xa0a401e0,0x23b402d2}},	//   _tvpl, _àire_, _ҡанд, bæja_, 
   {{0x9d4406bb,0x1ea826c0,0xdcb02002,0x216806dc}},	//   лежд, راطي_, ڭىش_, _зини_, 
   {{0x2cac00b8,0x7af80477,0x1ec80166,0xa3bc150d}},	//   _byed_, wavt, _үлми_, ेदक_, 
   {{0xed3401c6,0x43380023,0x00000000,0x00000000}},	//   рэхэ, _ብምቕባ, --, --, 
   {{0x2010055a,0x78a408fb,0x2cac0f85,0x7af801d5}},	//   muyi_, _øivi, _dyed_, uavt, 
   {{0x7af855bf,0xbf103174,0x201055c0,0x2cac0afa}},	//   ravt, ालीन_, luyi_, _eyed_, 
   {{0xdd9055c1,0x7af855c2,0xa91c09a8,0xfcc404a9}},	//   _اور_, savt, ližj, _кәлм, 
   {{0x8c4055c3,0x20100a73,0xd37c05ce,0x4aa455c4}},	//   _лете, nuyi_, šćih_, ккән_, 
   {{0x65b455c5,0x10340302,0x61e0151c,0xb6f800d1}},	//   váha, נטים_, _čoln, خىدا_, 
   {{0x0f54011a,0x00000000,0x00000000,0x00000000}},	//   איים_, --, --, --, 
   {{0x201055c6,0x94a801b9,0xe60000a2,0x867000d4}},	//   kuyi_, етга_, _öwýä, слює, 
   {{0x948455c7,0x20100a49,0xdef40b82,0x06400023}},	//   уынд, juyi_, ገንና_, _ሕያውነ, 
   {{0xca840023,0x65b455c8,0x00000000,0x00000000}},	//   _ንዕኦም_, ráha, --, --, 
   {{0xa3b40406,0x20d80219,0x5f180154,0x91480798}},	//   _जठर_, kšič_, ড়াও_, нчаа_, 
   {{0x20100921,0x3f980003,0x65b40008,0x116401b9}},	//   fuyi_, _ajru_, páha, دلری_, 
   {{0x2ef455c9,0xc2f4015b,0x201000e4,0x94a855ca}},	// [5cf0] изар, _জারি_, guyi_, _ятка_, 
   {{0x2d40010e,0x4fc400c7,0xdce800b8,0x00000000}},	//   _ỳe_, усба, _ānāp, --, 
   {{0x2cac0092,0xecf84727,0xa7fc01ed,0xc7b0011a}},	//   _syed_, вееш_, gyűj, צבע_, 
   {{0x20100944,0x2cac0204,0x4fc40139,0x00000000}},	//   buyi_, _pyed_, _әсма, --, 
   {{0xe1844494,0xe0f80a7c,0xfd980124,0x00000000}},	//   _төре_, _שלשל, уҩтә_, --, 
   {{0xfbd055cb,0xab2855cc,0xc6180154,0xbed400f0}},	//   سته_, тока_, তবতা_, _горј, 
   {{0xc334025d,0x0a6800ee,0x00000000,0x00000000}},	//   מוס_, эрди_, --, --, 
   {{0x2cac1529,0xf1b401ad,0x291855cd,0xb0b801bc}},	//   _tyed_, ंतिन, üsa_, _आराग, 
   {{0x41b40327,0x4ae80139,0xae0c0db3,0x00000000}},	//   _དེལྟ, _зьем_, ांकन_, --, 
   {{0x659055ce,0x7c9455cf,0xa7b41d39,0x00000000}},	//   māhi, _اشفا, јсиј, --, 
   {{0x61e000f3,0xc2f4009e,0xfbe00241,0xf1b44a76}},	//   _čolo, _জালি_, _iṣọ_, ंतान, 
   {{0xe5a455d0,0xe4c455d1,0x00000000,0x00000000}},	//   рими, ийни, --, --, 
   {{0xa1140014,0x7d0400c6,0xe738022e,0x00000000}},	//   یوست, óisi, _аел_, --, 
   {{0x66e455d2,0xe29855d3,0x57b000cd,0x00000000}},	//   _тока, ваг_, ुगृह, --, 
   {{0xdb18069c,0x2010055a,0x00000000,0x00000000}},	//   _shtë, wuyi_, --, --, 
   {{0x7a4000dd,0x20100a73,0x65901d86,0x386000a3}},	//   látá, tuyi_, kāhi, _àirc_, 
   {{0x9f8455d4,0xe3b82716,0x20d80010,0x65b400e5}},	// [5d00] агад, _иби_, všič_, láho, 
   {{0x44200286,0x93f8008d,0x20100337,0x7a4000e5}},	//   _iqi_, _שליי, ruyi_, nátá, 
   {{0xb8d8025c,0xa91c55d5,0x201002a8,0xdb08002f}},	//   _ཙྪ_, rižj, suyi_, rmfü, 
   {{0x1c4455d6,0xfbe00cad,0x1d0855d7,0x00000000}},	//   инем, _aṣọ_, теди_, --, 
   {{0x3a2c0067,0x20d80219,0x00000000,0x00000000}},	//   _spdp_, ršič_, --, --, 
   {{0xc5e809bd,0xfe78142e,0x3f980113,0xa3b408df}},	//   _কিনা_, _йүз_, _ujru_, जति_, 
   {{0x6574035a,0xdd54074d,0x65b401d3,0x8f9800d9}},	//   _olyh, _къаь, jáho, _סילי, 
   {{0xdd140330,0x4420022e,0x9c8400c0,0x00000000}},	//   _خورخ, _oqi_, _pačė, --, 
   {{0xded40020,0x497000d6,0xa3b40574,0x44200457}},	//   _ይሆን_, ільс, जता_, _nqi_, 
   {{0x65740432,0x56c40395,0x00000000,0x00000000}},	//   _alyh, ищна, --, --, 
   {{0x3c20007f,0xeb5400f7,0x65b401d3,0x00000000}},	//   lòv_, _دىلگ, gáho, --, 
   {{0x65b4012c,0x3dd855d8,0x26d8013f,0x32040419}},	//   sáhn, _murw_, ɛsom_, álym_, 
   {{0x23a4001f,0x23800092,0x00000000,0x00000000}},	//   _ለህዝብ_, _ከህዝብ_, --, --, 
   {{0x56900220,0x442003e3,0x76d80107,0x00000000}},	//   _қақт, _dqi_, _судӣ_, --, 
   {{0x439455d9,0xdeac0198,0xd5b855da,0x200055db}},	//   царс, _tabƙ, _иси_, _avki_, 
   {{0x7388010b,0x65b400d0,0x00000000,0x00000000}},	//   _әриң_, náhl, --, --, 
   {{0x44200b6f,0x29000134,0x9f50023a,0x31340166}},	// [5d10] _gqi_, _ɛha_, ksyä_, _һенр, 
   {{0x65740030,0x709408ca,0xc43c011a,0xff5400d8}},	//   _zlyh, _ҳамф, _יתחי, окуќ, 
   {{0x65900374,0x765c005b,0x00d800e5,0xdec0013d}},	//   wāhi, äryh, ابہت_, зәто, 
   {{0xbd1800d6,0xacf855dc,0x72d801d9,0xa5d8008f}},	//   иції_, унду_, _جِگر_, אַסי, 
   {{0xc05855dd,0x48b800fe,0x00000000,0x00000000}},	//   _кір_, োঁৱৰ, --, --, 
   {{0xa03800c8,0xad241183,0xea94010b,0x27e8036e}},	//   _געשפ, _گىرى, йшйэ, _çani_, 
   {{0xa91c110c,0x03780375,0xaa580eff,0x00000000}},	//   liži, שתות_, العا_, --, 
   {{0x0c840e26,0x4a700046,0x659002b5,0xad2405a9}},	//   _кызм, йықт, pāhi, _دىرى, 
   {{0x6754007b,0x6b8c00ae,0x00000000,0x00000000}},	//   مخدر, éags, --, --, 
   {{0xfbd055de,0xc5e80c58,0x65b401d3,0xe7380063}},	//   _قتل_, _কিবা_, táho, ћен_, 
   {{0x4420020c,0x9b4003e6,0x2fd0022e,0x45a4515c}},	//   _sqi_, _رچوو, _mizg_, يەتك, 
   {{0xb38c0051,0x65b400e5,0x00000000,0x00000000}},	//   _đềth, ráho, --, --, 
   {{0x68f803a2,0x5f0853b7,0x65b401ed,0x63bc55df}},	//   _iewd, ाणम्_, sáho, _phpn, 
   {{0xdb1800c7,0x02040107,0x644401e3,0x98e400fb}},	//   _oitý, оҷон, rvki, _ксәһ, 
   {{0x2fd8002f,0xdb1c0165,0x00000000,0x00000000}},	//   _ausg_, évéd, --, --, 
   {{0xdfd000c6,0xbf1000bc,0x00000000,0x00000000}},	//   كير_, ाल्न_, --, --, 
   {{0x442055e0,0x68f800a2,0xdb1802d2,0x5f04009d}},	// [5d20] _uqi_, _mewd, _ritþ, йзаа, 
   {{0xc3300131,0xdb18010e,0x00000000,0x00000000}},	//   _تەس_, _bitý, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x68f80334,0xdcf8178c,0xa1340cd6,0x00000000}},	//   _newd, اراش_, _اردش, --, 
   {{0xdd901973,0xdce001fa,0xdea0179e,0x00000000}},	//   _ہوس_, hkoć, _کیای, --, 
   {{0xf3f80356,0x00000000,0x00000000,0x00000000}},	//   âţi_, --, --, --, 
   {{0xdb1800a2,0x65b40118,0x3c200100,0x8e8000d8}},	//   _gitý, táhl, sòv_, _егре, 
   {{0xdb1855e1,0x291c04ba,0x6b8c01e7,0x9f500108}},	//   _hitü, _ccwa_, éagr, ssyä_, 
   {{0xdb1855e2,0x68f855e3,0x15b0515c,0x97a4068e}},	//   _kitü, _dewd, ۋەتس, йрол, 
   {{0x7d040008,0x65b400bc,0x3cf00cb4,0x5d74023b}},	//   ðisf, sáhl, आरके_, _туҳф, 
   {{0x68f8031c,0x9d0800eb,0x00000000,0x00000000}},	//   _fewd, রভীন_, --, --, 
   {{0x659000b0,0x8ab408a8,0x1db800cd,0x00000000}},	//   kāhu, _פלאג_, ेषित, --, 
   {{0xf83800e5,0x00000000,0x00000000,0x00000000}},	//   _خزاں_, --, --, --, 
   {{0xf74805d9,0x325455e4,0x2fd801ab,0x53e4035b}},	//   _ضلعي_, овгр, _rusg_, ицҳа, 
   {{0xa7840214,0x68ec0356,0xdb180210,0xa4b00051}},	//   _بشنو, _îndâ, _hitó, _ởcư, 
   {{0x349455e5,0xdb180254,0x6e200139,0x00000000}},	//   _майр, _aitü, _älbi, --, 
   {{0x752c01b2,0xdb180205,0x00000000,0x00000000}},	// [5d30] _ibaz, _bitü, --, --, 
   {{0xa91c09a8,0x2fd001b9,0xdb1855e6,0x00000000}},	//   riži, _qizg_, _citü, --, 
   {{0xdb180077,0xa91c0024,0x8d6800d8,0x00000000}},	//   _litó, siži, лјда_, --, 
   {{0x659000dc,0x00000000,0x00000000,0x00000000}},	//   bāhu, --, --, --, 
   {{0x752c1421,0xdfd00451,0x3e480205,0x00000000}},	//   _mbaz, _ڊيٽ_, _eğt_, --, 
   {{0x661c068f,0x68f80135,0x00000000,0x00000000}},	//   ński, _sewd, --, --, 
   {{0x61e000ef,0x00000000,0x00000000,0x00000000}},	//   _čolk, --, --, --, 
   {{0x7d04007b,0xe96855e7,0xe80801c6,0x752c55e8}},	//   óist, раил_, анид_, _nbaz, 
   {{0x6e240477,0x317801d3,0xe738013d,0xdddc013a}},	//   lthb, _mlsz_, аеп_, dypř, 
   {{0xdedc0023,0xdce016a3,0x6e24037e,0x00000000}},	//   _ንስኺ_, tkoć, othb, --, 
   {{0x752c031c,0xe568129d,0x68f855e9,0x7d041427}},	//   _bbaz, لمدى_, _tewd, ðisg, 
   {{0x29d0098d,0x67d40266,0x28c8012c,0x6e240332}},	//   _išao_, _доду, ाइदि, ithb, 
   {{0x752c02c4,0x321055ea,0x78241e24,0xf77000f1}},	//   _dbaz, erzy_, _فعول, _ګان_, 
   {{0x752c55eb,0xc7c4035b,0xb38c0208,0x00000000}},	//   _ebaz, _усеи, _đểth, --, 
   {{0x27ec55ec,0xdedc044e,0x63600109,0xdb1803e0}},	//   lpen_, _ንስኻ_, _kônz, _ritü, 
   {{0x752c55ed,0x60e855ee,0x65900374,0x27ec55ef}},	//   _gbaz, рмам_, tāhu, open_, 
   {{0x1f6455f0,0xdb180561,0x7f44001f,0x27ec55f1}},	// [5d40] окам, _mitò, _የማይች, npen_, 
   {{0x6360006a,0x27ec55f2,0xde74021f,0xdb08007c}},	//   _lônz, ipen_, يداع, lmfö, 
   {{0x672003ce,0xa91c0306,0x21a455f3,0x00000000}},	//   _मानक_, ližu, _миом, --, 
   {{0x61ec55f4,0x659000b0,0xdb1801e1,0x00000000}},	//   mpbl, pāhu, _nitò, --, 
   {{0x27ec0cf9,0xa91c19d6,0x6e2455f5,0xa2cc00cd}},	//   jpen_, nižu, athb, _धृत्, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x27ec55f6,0x5d141698,0xdbc401f4,0x8aa00395}},	//   epen_, _وِسا, köön, мръд, 
   {{0xdb1855f7,0xdca455f8,0x988001ec,0x81dc00fe}},	//   _pitó, _даби, _ﺨﻁﻭﺓ_, _ডবা_, 
   {{0x77b400cf,0xc7d40312,0x7c240e89,0xd6b400ec}},	//   làxi, омых_, àird, ڪندڙ_, 
   {{0xd6d855f9,0xdb180261,0xa91c0e3c,0xd7780023}},	//   шти_, _vitó, dižu, _ፖሎቲካ_, 
   {{0x3944009a,0x27ec13a5,0xd5b8084c,0x00000000}},	//   pdms_, apen_, исм_, --, 
   {{0x1bfc00e1,0xc2f42b1b,0x88c000dc,0x00000000}},	//   _उबाल_, _জাগি_, _īśva, --, 
   {{0x2bdc3c71,0x5fa83885,0x00000000,0x00000000}},	//   मदया, कवाल, --, --, 
   {{0x80b400e1,0x3210033f,0x6720000d,0x00000000}},	//   _आरजे, trzy_, _मायक_, --, 
   {{0x320401ed,0x752c0327,0x00000000,0x00000000}},	//   ély_, _tbaz, --, --, 
   {{0x752c55fa,0xab5c0034,0xa91c0006,0x59c80490}},	//   _ubaz, _duży, sižv, ागिर, 
   {{0xb0c40034,0xcee837f4,0x2d9803e0,0x00000000}},	// [5d50] लेंग, لران_, _ıse_, --, 
   {{0x344801f0,0x00000000,0x00000000,0x00000000}},	//   _кӯҳи_, --, --, --, 
   {{0x27ec05f5,0x14c40d0b,0xdb1855fb,0x59c8043e}},	//   zpen_, रेरण, _nitñ, ागार, 
   {{0x823455fc,0x315800c6,0x13dc02f5,0x6e2455fd}},	//   _کریا, _الحج_, _বৌয়, rthb, 
   {{0x61e00384,0xd6c002f5,0xab5c0034,0x7bdc02b5}},	//   _čoli, োডিয, _zuży, _ōrur, 
   {{0x4ea40022,0xaa44008e,0x00000000,0x00000000}},	//   _дрба, зекл, --, --, 
   {{0x27ec0204,0x00000000,0x00000000,0x00000000}},	//   wpen_, --, --, --, 
   {{0xad4000f7,0xa9c000cf,0x00000000,0x00000000}},	//   _سۉتۉ, رۅشۉ, --, --, 
   {{0x2d8c55fe,0x69e01505,0x25600122,0x27ec55ff}},	//   _imee_, _šveđ, _góly_, upen_, 
   {{0x27ec5600,0x6ff40003,0xfbcc00dc,0xa68400a7}},	//   rpen_, _བསླུ_, ाषणम, злод, 
   {{0x29d00b91,0x27ec5601,0xdbc41073,0xdb08036e}},	//   _ušao_, spen_, töön, zofë, 
   {{0x2480010a,0x2b4405c7,0x64a45602,0x00000000}},	//   tzkm_, _halc_, зама, --, 
   {{0x2d8c063f,0x2b44030a,0x46a8007d,0x80b00c5a}},	//   _mmee_, _kalc_, _घुरह, _अँधे, 
   {{0x69c85603,0x02c40116,0xdbc4000d,0x00000000}},	//   lmee, дигү, söön, --, 
   {{0x2d8c063f,0x4ac8227c,0xa91c0024,0x69c85604}},	//   _omee_, ाधिव, sižu, omee, 
   {{0xe0d806bb,0x69c85605,0x7158004e,0x65b400e4}},	//   сва_, nmee, орус_, káhi, 
   {{0x69c85606,0x00000000,0x00000000,0x00000000}},	// [5d60] imee, --, --, --, 
   {{0x69c85607,0x2d8c5608,0x2b4401a6,0xa3680139}},	//   hmee, _amee_, _nalc_, _kiеm, 
   {{0x69c80429,0xe2c83738,0xa3b8210e,0x00000000}},	//   kmee, _دودو_, _پاکر_, --, 
   {{0x21a44703,0x69c801a4,0xdef801e0,0x225c00d0}},	//   _химм, jmee, рыҡ_, ätku_, 
   {{0x2b445609,0x69c8560a,0xbb4400c7,0x00000000}},	//   _balc_, dmee, мҵак, --, 
   {{0x2b44560b,0x2d8c063f,0x69c8022f,0x63ac014f}},	//   _calc_, _emee_, emee, nobn, 
   {{0x2b440dd4,0xa7fc0083,0x88c802dd,0x00000000}},	//   _dalc_, kyűs, _ﻗﺭﺍﺀ, --, 
   {{0x63ac047e,0x00000000,0x00000000,0x00000000}},	//   hobn, --, --, --, 
   {{0x63ac06ee,0x2b440156,0x9814007b,0x2d500244}},	//   kobn, _falc_, أبعا, _جێنس, 
   {{0x69c8560c,0x25b00209,0x386001ab,0xe0bc0154}},	//   amee, _akyl_, _àirm_, _অলাভ, 
   {{0x69c80070,0xa91c0419,0xc8d000b8,0x00000000}},	//   bmee, tižt, _śītī, --, 
   {{0x69c801d9,0x2b440489,0x58840022,0x21200208}},	//   cmee, _zalc_, _ныла, _nckh_, 
   {{0x94a83993,0x2b440156,0xdb08560d,0x63ac560e}},	//   стна_, _yalc_, tofè, fobn, 
   {{0xc7d40375,0x25b00254,0xb4bc07f7,0x63ac0327}},	//   _זוגי_, _ekyl_, _अरी_, gobn, 
   {{0xd1b8560f,0x82a45610,0x0bc80131,0x02a450cb}},	//   مارا_, еште, _ﺗﻮﻏﺮ, ертм, 
   {{0xdb0804f3,0x741403e6,0xf77000ec,0x00000000}},	//   llfä, _قوبا, _ساڙ_, --, 
   {{0x40345611,0x63ac01a9,0xc1680b82,0xfbcc5612}},	// [5d70] нетс, bobn, _ተጻራሪ_, ाषाम, 
   {{0x2d8c0af9,0x798003ac,0x00000000,0x00000000}},	//   _smee_, hhmw, --, --, 
   {{0xb4bc038e,0x69c80009,0x15e40150,0x00000000}},	//   _अरु_, ymee, _ﺍﻟﺪﻩ, --, 
   {{0x69c80793,0x71400372,0xac94023a,0xdb08002f}},	//   xmee, _جۉرۅ, маеш, hlfä, 
   {{0x2b4407c5,0x45e00220,0xabd40150,0x69c8000d}},	//   _palc_, _ﺍﻟﻤﺼ, _ﺟﻮﺭﻋ, vmee, 
   {{0x69c85613,0x00000000,0x00000000,0x00000000}},	//   wmee, --, --, --, 
   {{0x69c85614,0x3e180276,0xaa442950,0xe9a44d58}},	//   tmee, _норэ_, фейл, макп, 
   {{0x2b440dd4,0xdb0803fa,0xb4bc012c,0xbdc402dd}},	//   _walc_, elfä, _अरू_, _كەلۋ, 
   {{0xfc305615,0x2b445616,0xed580427,0x2d9c5617}},	//   _محل_, _talc_, _inž_, mnwe_, 
   {{0x69c85618,0xed581710,0x7ae80175,0x25b05619}},	//   smee, _hnž_, _gfdt, _skyl_, 
   {{0xe5a4561a,0x2d9c02e3,0x69c800c5,0xb4e81062}},	//   дини, onwe_, pmee, यडू_, 
   {{0x2d9c561b,0x69c80067,0xa2cc00cd,0xfa340066}},	//   nnwe_, qmee, _धृष्, _سرمد, 
   {{0x63ac561c,0x3d1401e1,0x95802401,0x57b000cf}},	//   tobn, _húwà_, тляе, رڭۇز, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x21200175,0xe8d800a2,0x00000000,0x00000000}},	//   _pckh_, _öỳ_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe3b04e02,0xc5a801d9,0x3d140241,0xdb0801e3}},	// [5d80] _لرد_, _وُڈن_, _lúwà_, llfå, 
   {{0x2be01533,0x27f80030,0x63ac0009,0xe3b0007b}},	//   _पढ़ा, ásny_, qobn, _جرب_, 
   {{0x2168561d,0xa1c4561e,0xdb1801ed,0x6d90022a}},	//   _дини_, _обод, _kitö, rťan, 
   {{0x6d900122,0x00000000,0x00000000,0x00000000}},	//   sťan, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x5f0402dd,0xcb640063,0x00000000,0x00000000}},	//   _ізба, даље_, --, --, 
   {{0xc0dc0092,0x7980035a,0x9da400f2,0x00000000}},	//   ንጉል_, thmw, _قصره, --, 
   {{0x88c00055,0x2d9400c0,0x00000000,0x00000000}},	//   _īśra, _зрус, --, --, 
   {{0xb4bc561f,0x7d00000f,0x195402dd,0x3eb85620}},	//   _अरे_, _iems, зақы_, _hyrt_, 
   {{0x7d005621,0x3eb803b2,0x35f45622,0x6aac0205}},	//   _hems, _kyrt_, нпор, şafa, 
   {{0xb7d80050,0x7d005623,0xdb1801b8,0x76b80276}},	//   _کوتا_, _kems, _bitö, ялор_, 
   {{0xb3e80135,0xd7f812c1,0x7d00009b,0xdce0031c}},	//   _འཕྱུ, _дук_, _jems, djoċ, 
   {{0x7d00008f,0x73c000dc,0x94845624,0x3860372c}},	//   _mems, _aśeṣ, фынд, _çir_, 
   {{0x7d005625,0x2d9c00ca,0x167001ec,0x00000000}},	//   _lems, znwe_, _ақор, --, 
   {{0x03200c2e,0x7d0003ac,0xb594010a,0xc7d4011a}},	//   _बारह_, _oems, _пикш, _קווי_, 
   {{0x7d005626,0xdb18014a,0x86c004b3,0x00000000}},	//   _nems, _gitö, _جيىن, --, 
   {{0xb3e80c99,0x6ab839db,0xc0580a2c,0x4f080202}},	// [5d90] _འཕྲུ, েখযো, وشكا_, قتاپ_, 
   {{0x753c5627,0x6fb400db,0xceb80640,0x0f1800ae}},	//   lesz, رماا, оље_, تغرب_, 
   {{0x7d005628,0x672000af,0x95840023,0x00000000}},	//   _bems, _मासक_, _ምረትን_, --, 
   {{0x29d00e96,0x3eb85629,0x0dc8562a,0x753c01d3}},	//   _však_, _dyrt_, цузи_, nesz, 
   {{0x7d00562b,0x2d9c53f4,0xac0800d4,0xab940150}},	//   _dems, rnwe_, їнка_, ниді, 
   {{0x7d00127b,0x3eb803cd,0x63a001e7,0xeb9800f0}},	//   _eems, _fyrt_, _íont, џик_, 
   {{0x3ce00122,0x6f04562c,0x6e68562d,0x753c01ed}},	//   živa_, mahc, _عمرِ_, kesz, 
   {{0x6f04047e,0x7d002bab,0xcd34009a,0x753c562e}},	//   lahc, _gems, _ترسب, jesz, 
   {{0xec1400f9,0x6d48562f,0x753c5630,0xcc840244}},	//   _سواد, _iaea, desz, _تۆشه_, 
   {{0xdb180793,0x6d485631,0x6f0400d8,0xa92402d2}},	//   _sitö, _haea, nahc, faþá, 
   {{0x6d485632,0x7d00003c,0x753c01d3,0x00000000}},	//   _kaea, _yems, fesz, --, 
   {{0x753c5633,0x7d000051,0x6f6c0150,0x00000000}},	//   gesz, _xems, _ﺴﻠﻔﺎ_, --, 
   {{0x6d485634,0x69d801e2,0xdb180793,0x68e800d2}},	//   _maea, _iiwe, _vitö, mced, 
   {{0x6d480069,0x69d804e6,0x6b8c01ab,0x4cb800eb}},	//   _laea, _hiwe, èagh, েশপু, 
   {{0x69d8138f,0x6f040a2e,0x753c01ed,0x00000000}},	//   _kiwe, dahc, besz, --, 
   {{0x68e85635,0x69d85636,0x6d485637,0x24080108}},	//   nced, _jiwe, _naea, _ении_, 
   {{0x68e801b8,0x69d85638,0x67200010,0x7fb401d5}},	// [5da0] iced, _miwe, oglj, نلرچ, 
   {{0x7d005639,0x6d480418,0x67200010,0x65b40d12}},	//   _sems, _aaea, nglj, ráhu, 
   {{0x6d48563a,0x68e800df,0x17e40150,0xa3e401f9}},	//   _baea, kced, _ﺎﻟﺤﺯ, _बंड_, 
   {{0x69d8563b,0xddb402dd,0x6d4803cb,0x032000c5}},	//   _niwe, رحاب, _caea, _बाँह_, 
   {{0x6d480368,0xbf4400c7,0x7d00007c,0x15e40220}},	//   _daea, _иҭал, _vems, _ﺍﻟﻤﻬ, 
   {{0x68e8563c,0x753c068f,0x7d00003c,0x6d48010a}},	//   eced, zesz, _wems, _eaea, 
   {{0xdef80046,0x8fa0563d,0x6d480bba,0x69d8563e}},	//   _мың_, _саре, _faea, _biwe, 
   {{0x69d8003e,0x6d480368,0xf8b800f7,0x2bdc0764}},	//   _ciwe, _gaea, мөл_, मदशा, 
   {{0x69d8563f,0x753c00dd,0x03200cb4,0xdca400f0}},	//   _diwe, vesz, _बांह_, _џази, 
   {{0x69d81a80,0x00000000,0x00000000,0x00000000}},	//   _eiwe, --, --, --, 
   {{0x6ff4025c,0x69d80cad,0x672002ab,0x753c01ed}},	//   _བསྐུ_, _fiwe, _मारक_, tesz, 
   {{0x68e85640,0xaaa825c9,0x69d85641,0x29c001d3}},	//   cced, _चुटक, _giwe, lóan_, 
   {{0xb7884acd,0x753c5642,0x09d400eb,0x00000000}},	//   _және_, resz, _সবচা, --, 
   {{0x69d85643,0x753c00e5,0x00000000,0x00000000}},	//   _ziwe, sesz, --, --, 
   {{0x69d85644,0x61fc015d,0x753c1f6f,0x6f040477}},	//   _yiwe, _cwpl, pesz, vahc, 
   {{0x69d802b9,0x00000000,0x00000000,0x00000000}},	//   _xiwe, --, --, --, 
   {{0x7bc80649,0x6d484436,0xc0ec0023,0x1b040154}},	// [5db0] _ohdu, _raea, _ቆጸራ_, _রানে_, 
   {{0x6d480618,0xa11401d5,0x05740150,0x9f50007f}},	//   _saea, _یوپت, _لاۋد, npyè_, 
   {{0x6d485645,0x6d9001f1,0x6f0405b1,0x61fc0042}},	//   _paea, sťam, rahc, _gwpl, 
   {{0xd5b04cd8,0x6f04047e,0x0fe0004e,0xdce02ca8}},	//   ीतिज, sahc, _бөжү, rkoğ, 
   {{0x69d85646,0x6d480618,0x67200490,0x31680427}},	//   _riwe, _vaea, _मालक_, mjaz_, 
   {{0x69d85647,0x7bc801ab,0x6d4802b1,0xcfb800cc}},	//   _siwe, _chdu, _waea, _অংকন, 
   {{0x6d48096b,0x69d85648,0x7bc8208d,0x92d00183}},	//   _taea, _piwe, _dhdu, হুৰ_, 
   {{0x6d480bba,0x7c9c001f,0x9f40023a,0xdb180129}},	//   _uaea, ቋቋመው_, _etkä_, _sitô, 
   {{0x69d85649,0xa8c40107,0xa3e411d7,0x7de000d7}},	//   _viwe, ъйид, _बंध_, rísň, 
   {{0x68e8564a,0x69d8564b,0x00000000,0x00000000}},	//   sced, _wiwe, --, --, 
   {{0x6b80564c,0x6720564d,0xfb840108,0x00000000}},	//   _illg, rglj, _сытн, --, 
   {{0xa3e43e63,0x7bc802d3,0x316805b1,0x69d8009f}},	//   _बंद_, _zhdu, jjaz_, _uiwe, 
   {{0xc8800724,0xc6d000f7,0x00000000,0x00000000}},	//   ñğı_, _өскө, --, --, 
   {{0xc8801ae6,0x6ff4031c,0xb38001e0,0x00000000}},	//   ığı_, _བསྟུ_, йһыл, --, 
   {{0x5210005b,0x00000000,0x00000000,0x00000000}},	//   идёт, --, --, --, 
   {{0x29c001d3,0xa3e403ce,0x00000000,0x00000000}},	//   zóan_, _बूथ_, --, --, 
   {{0xd004564e,0xdb18049b,0xdee4564f,0xdf48013e}},	// [5dc0] кете_, _yhtä, вози, мзад_, 
   {{0x64540526,0x5ed45650,0x00000000,0x00000000}},	//   _iryi, نتاز, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6b805651,0xdb0803a1,0x00000000,0x00000000}},	//   _allg, llfø, --, --, 
   {{0xdb080cc3,0x3ce05652,0xad2419bc,0x29c001ed}},	//   sofí, živo_, ارمو, tóan_, 
   {{0xdee41f5a,0x00000000,0x00000000,0x00000000}},	//   _јови, --, --, --, 
   {{0x5398010f,0x8f34011a,0x00000000,0x00000000}},	//   ויסו, _שאלו_, --, --, 
   {{0x0ae4052f,0x98a45653,0x00000000,0x00000000}},	//   ндәй_, šiče_, --, --, 
   {{0x8c402ba5,0xa3b05654,0xdd940ed0,0x91b808a8}},	//   _кете, टका_, _заңы, ומקי, 
   {{0x5a9400c7,0x7bc80208,0x6d900419,0x00000000}},	//   _иреф, _uhdu, eťah, --, 
   {{0x64545655,0x98a05656,0x00000000,0x00000000}},	//   _aryi, ıkı_, --, --, 
   {{0xceb0025f,0xd94415ed,0x64540113,0x9f400023}},	//   יית_, _једи, _bryi, _bukë_, 
   {{0x64545657,0x57a40228,0x89d404fb,0x481002bf}},	//   _cryi, _ишка, _شوهر_, _вміс, 
   {{0xdb080109,0x64545658,0x9f40036e,0x00000000}},	//   nofà, _dryi, _dukë_, --, 
   {{0xf48404d3,0x64540009,0x00000000,0x00000000}},	//   _ڕادی, _eryi, --, --, 
   {{0xd1f0044e,0x6454045a,0x7d04148b,0x00000000}},	//   ልኪቱ_, _fryi, ðisl, --, 
   {{0x371c00e1,0x7c2400a3,0x00000000,0x00000000}},	// [5dd0] _माफ़ी_, àirl, --, --, 
   {{0xdc8c02e3,0x00000000,0x00000000,0x00000000}},	//   tịnụ_, --, --, --, 
   {{0x645800da,0xfbc802f5,0x59b0000d,0x00000000}},	//   ātie, শদাত, ँकार, --, 
   {{0xd9100943,0x90e40efc,0x00000000,0x00000000}},	//   _ndό_, _جسدن, --, --, 
   {{0xdc8c01f2,0x15e402dd,0x7fe801af,0x00000000}},	//   sịnụ_, _ﺍﻟﻴﻬ, _аєса_, --, 
   {{0x447c00c8,0x50440092,0xa3e40037,0x6d900419}},	//   ונדע, _የራሳች, _बंस_, zťah, 
   {{0x7f945659,0xba082f7c,0x833800df,0x00000000}},	//   _тарх, پتىك_, דאוס_, --, 
   {{0x284800ee,0x00000000,0x00000000,0x00000000}},	//   езип_, --, --, --, 
   {{0xbdc400d1,0x396400c7,0x00000000,0x00000000}},	//   _ئەنۋ, рныҳ, --, --, 
   {{0x6b8003cd,0x1780004e,0xfcc8014b,0x00000000}},	//   _ullg, йгым, _русй_, --, 
   {{0x77901b8f,0xba74565a,0xf1b400cd,0x00000000}},	//   تیوا, _پالت, ूतान, --, 
   {{0x78a4565b,0x64540072,0xda78008f,0xb8642a77}},	//   _žive, _pryi, _אנער, _چاوو, 
   {{0x1b0400bd,0x81ac00bd,0xb86402f2,0x00000000}},	//   _রাতে_, গতম_, _ناوو, --, 
   {{0x6d900030,0x6674009f,0x06900583,0xa0a439b8}},	//   sťah, _مدبر, _پاتھ, қазд, 
   {{0xdb081a06,0x26c0565c,0x00000000,0x00000000}},	//   nofá, _áho_, --, --, 
   {{0x6454565d,0x20d401ec,0x1e840ce8,0xa06800c7}},	//   _tryi, гізс, ңлам, наба_, 
   {{0x6454565e,0x7d040252,0x6304036b,0xb3740092}},	// [5de0] _uryi, ðism, _یوکل, _ያለዉን_, 
   {{0x7dec0213,0x9f041176,0x00000000,0x00000000}},	//   _ağsa, اواو, --, --, 
   {{0x3ebc037e,0x160407f7,0x73e40166,0x179400df}},	//   ævt_, वीपर_, _йоөз, נדעל_, 
   {{0x9cc8565f,0xa0680408,0xca1400d1,0x56b4010f}},	//   ныла_, _зама_, _ﺳﯚﺯ_, אפען_, 
   {{0x9f400093,0xa36801a9,0xe0d00214,0xbf6401d9}},	//   _luké_, _chеg, _دزد_, _پۯاو, 
   {{0xcb645660,0x29185661,0x29d000ef,0xec1000d1}},	//   лаче_, ósan_, _ošas_, زۈمد, 
   {{0xd3540375,0x00000000,0x00000000,0x00000000}},	//   טיסי_, --, --, --, 
   {{0xd90c5662,0xd7f85663,0x9db800fd,0x4c6401e0}},	//   سیت_, нуо_, _чыгу_, тиән_, 
   {{0xba18021a,0xa3b40034,0x2600012d,0x00000000}},	//   ريکا_, ड़ता_, वीसी_, --, 
   {{0x9f40019f,0x00000000,0x00000000,0x00000000}},	//   _buké_, --, --, --, 
   {{0xa64c0023,0xcfb4010f,0xd68400d8,0x00000000}},	//   _ዝካየደ, רליי_, ѓуоп, --, 
   {{0x394000ae,0xc7a0013d,0x00000000,0x00000000}},	//   _úis_, _һичк, --, --, 
   {{0xb3740201,0xc45801f4,0x00000000,0x00000000}},	//   _ያለውን_, гиях_, --, --, 
   {{0xc7a002ee,0x260001f9,0x00000000,0x00000000}},	//   _личк, वीही_, --, --, 
   {{0x20005664,0xd5b80452,0x6d5c1427,0x00000000}},	//   _awki_, _пси_, _ósag, --, 
   {{0x26180073,0x00000000,0x00000000,0x00000000}},	//   _भिती_, --, --, --, 
   {{0x6acc0c58,0x03ec0154,0x386001e7,0xf4840133}},	// [5df0] াশযো, জীবী_, _áird_, _ڕاگی, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa3b010b7,0x00000000,0x00000000,0x00000000}},	//   टकर_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xab285665,0xc0c803f6,0x00000000,0x00000000}},	//   вола_, _буре_, --, --, 
   {{0xaa140b7f,0x6e205666,0x8bac0490,0x447c00c8}},	//   афиј, _ålbo, टवेअ, ענגע, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xad240131,0xdb080306,0x2d98002f,0xfaf800de}},	//   _خىرى, rofá, _öse_, _vnīa_, 
   {{0x4b2412dd,0x76580024,0xac9401c6,0x00000000}},	//   _معاف, _arvy, _тааш, --, 
   {{0x78a45667,0x66140122,0x9f400270,0xe7380640}},	//   _živc, ázko, _puké_, њен_, 
   {{0xa80400c7,0x00000000,0x00000000,0x00000000}},	//   ызҿл, --, --, --, 
   {{0x38600b91,0xa508023a,0x00000000,0x00000000}},	//   _šire_, ъема_, --, --, 
   {{0x45e002dd,0x6fc40a59,0x00000000,0x00000000}},	//   _ﺍﻟﻌﺼ, वतां, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa1940114,0x7d04148b,0xa6c801e2,0x260001f9}},	//   ајај, ðisk, _ګوګل_, वीशी_, 
   {{0xc0f402d3,0x91c0023e,0x00000000,0x00000000}},	//   _ልቦም_, _वीआई, --, --, 
   {{0x55b8025f,0xb9dc044e,0x20d40212,0x602401f0}},	// [5e00] _במקו, _ኢየ_, рівс, рдза, 
   {{0xa3b85668,0x38600241,0x00000000,0x00000000}},	//   _جابر_, _áire_, --, --, 
   {{0x2cac045a,0x5ea4007b,0x00000000,0x00000000}},	//   _axed_, جمال, --, --, 
   {{0x16341a4c,0x628c0e13,0x00000000,0x00000000}},	//   ינער_, mzbo, --, --, 
   {{0x628c5669,0xdca4566a,0xed3401c6,0x45e002dd}},	//   lzbo, шади, сэхэ, _ﺍﻟﻔﺼ, 
   {{0xd00c2115,0x1ec80798,0x00000000,0x00000000}},	//   _زلف_, _алги_, --, --, 
   {{0x628c0007,0xdea014a5,0x5dd81180,0xe9e400d7}},	//   nzbo, _بیای, _афар_, _žúre_, 
   {{0xb6c401e0,0xdb080112,0x628c181f,0x00000000}},	//   ҙөлд, llfü, izbo, --, 
   {{0x97a4566b,0x00000000,0x00000000,0x00000000}},	//   ирол, --, --, --, 
   {{0x10340302,0x765800d0,0x00000000,0x00000000}},	//   סטים_, _prvy, --, --, 
   {{0x9a68566c,0x35b4566d,0x628c110c,0x0f540375}},	//   _جمال_, йбор, jzbo, ביים_, 
   {{0xd90c3a25,0xdb080e78,0xdb040ad9,0x867000d4}},	//   _کیک_, hlfü, ðmæl, іляє, 
   {{0x394401b8,0xa3b001bc,0x06d405ac,0x3f9806be}},	//   mems_, टकं_, _দ্দি, _omru_, 
   {{0x3944566e,0xd1b8566f,0x152400c7,0x47300064}},	//   lems_, چارا_, ынҭқ_, _мніс, 
   {{0xd1b85670,0xdb1800e8,0x645800b0,0x76580245}},	//   نارا_, _aktë, ātia, _urvy, 
   {{0x39445671,0x3f985672,0xe6c4009f,0x00000000}},	//   nems_, _amru_, _اتهي, --, 
   {{0x752c03be,0xed585673,0xc1040ef8,0xd36c00cf}},	// [5e10] _icaz, ғол_, زولي, _قۇح_, 
   {{0x29c001ed,0x39445674,0x96b800bc,0x00000000}},	//   tóak_, hems_, _उडाउ, --, 
   {{0x628c5675,0x39440064,0xc7b0011a,0x00000000}},	//   czbo, kems_, קבע_, --, 
   {{0x765c005b,0xa3e4000d,0x00000000,0x00000000}},	//   äryy, _बूँ_, --, --, 
   {{0x39445676,0xa3ac228d,0x3e480166,0x3210012d}},	//   dems_, _कदम_, _eşt_, lszy_, 
   {{0x6a845677,0xa28000e5,0x00000000,0x00000000}},	//   йлла, _بیہو, --, --, 
   {{0x752c00a8,0xeab80724,0x0d64074d,0x69940b01}},	//   _ocaz, ыйк_, _къам, йрих, 
   {{0x78a4237d,0x752c01f0,0x39445678,0x6e240455}},	//   _živa, _ncaz, gems_, muhb, 
   {{0x2d9c5679,0x628c05b1,0x287400fd,0x00000000}},	//   miwe_, zzbo, сыйр, --, 
   {{0x2d9c4ec2,0x629802f0,0x628c155d,0x32100210}},	//   liwe_, útok, yzbo, kszy_, 
   {{0x32100034,0x39440064,0x00000000,0x00000000}},	//   jszy_, bems_, --, --, 
   {{0xe5a4567a,0x2d9c567b,0x6e240175,0x20e4000d}},	//   сими, niwe_, iuhb, _कलेश_, 
   {{0x290c567c,0x7d0401a8,0x6e2414f9,0x66e4567d}},	//   maea_, ðisi, huhb, _лола, 
   {{0x2d9c567e,0x290c567f,0xa3485680,0xd8d40375}},	//   hiwe_, laea_, ызга_, _פוסט_, 
   {{0xf7705681,0x2d9c5682,0x27ec02d3,0x6e240098}},	//   _تان_, kiwe_, lqen_, juhb, 
   {{0x2d9c5647,0x290c3bf3,0x75d800c7,0x628c12eb}},	//   jiwe_, naea_, _кьыс_, rzbo, 
   {{0x2d9c5683,0x61440166,0x628c00e5,0x00000000}},	// [5e20] diwe_, _һена, szbo, --, 
   {{0xa0a40fab,0x290c02b5,0x394401f5,0x3210012d}},	//   _ҳамд, haea_, zems_, bszy_, 
   {{0x614411ca,0x39440204,0xa91c0006,0x2d9c5684}},	//   _лена, yems_, sižy, fiwe_, 
   {{0x2d9c015c,0x21681d5e,0x004800ec,0x00000000}},	//   giwe_, _сими_, _پڌري_, --, 
   {{0x290c0381,0x00000000,0x00000000,0x00000000}},	//   daea_, --, --, --, 
   {{0xdd905685,0x3f980e3c,0x290c5686,0x65742a89}},	//   _کور_, _umru_, eaea_, _loyh, 
   {{0x2d9c5687,0x39445688,0xdee41086,0xef90036b}},	//   biwe_, tems_, _воҳи, _تیلد, 
   {{0x2d9c0796,0x290c003a,0xdd880107,0x2d980137}},	//   ciwe_, gaea_, _ёбад_, _көчө_, 
   {{0x394401c7,0x20105689,0x497000d4,0x32100210}},	//   rems_, nsyi_, їльс, zszy_, 
   {{0x3944568a,0x752c568b,0x77984d9b,0x7b84568c}},	//   sems_, _scaz, ркор_, _بارە, 
   {{0xd6d80022,0x6574568d,0x201005b1,0x27ec011f}},	//   ыти_, _boyh, hsyi_, aqen_, 
   {{0x6574568e,0x290c568f,0x2010005b,0x261800af}},	//   _coyh, caea_, ksyi_, _भिरी_, 
   {{0x9f4007a8,0xb4e85690,0x3210033f,0xdb180306}},	//   _mukâ_, _बली_, wszy_, _akté, 
   {{0x2d9c5691,0xb38c0051,0x32100210,0x00000000}},	//   ziwe_, _đồth, tszy_, --, 
   {{0x439428a8,0xd1380408,0x506418c7,0x00000000}},	//   чарс, лха_, әтба, --, 
   {{0x2d9c5692,0x752c01b3,0x32100034,0x00000000}},	//   xiwe_, _ucaz, rszy_, --, 
   {{0x2d9c5693,0x74145694,0x95c005d9,0x616c001f}},	// [5e30] viwe_, _بوخا, _ويڙه, _አገራዊ_, 
   {{0x2d9c5695,0x32100034,0xb4e800af,0x6e24014f}},	//   wiwe_, pszy_, _बलु_, tuhb, 
   {{0x2d9c5696,0x00000000,0x00000000,0x00000000}},	//   tiwe_, --, --, --, 
   {{0x20102948,0xad2403cc,0x27ec0986,0x6e24022e}},	//   bsyi_, زىتى, yqen_, ruhb, 
   {{0x2d9c5697,0x78a40232,0x290c0b23,0xfd500055}},	//   riwe_, _živn, vaea_, _jajṛ, 
   {{0x82345698,0x290c02b1,0x00000000,0x00000000}},	//   _بریا, waea_, --, --, 
   {{0x2d9c5699,0x290c569a,0x27ec0113,0xc334011a}},	//   piwe_, taea_, wqen_, פוק_, 
   {{0x290c0421,0x2d9c401f,0x386007f5,0x24840135}},	//   uaea_, qiwe_, _šira_, _żomm_, 
   {{0x52f80316,0x290c569b,0x6574022e,0xd7e4005b}},	//   ्राउ_, raea_, _royh, омые_, 
   {{0xbca4569c,0x290c0b23,0x7d04148b,0xfa880166}},	//   _عملي, saea_, ðisv, рсәй_, 
   {{0x290c569d,0x657400e4,0x2918569e,0x07e001d9}},	//   paea_, _poyh, _نقاد_, _کٲتێ, 
   {{0x9f400004,0x65740455,0xe8200073,0x00000000}},	//   _kukã_, _qoyh, _मिपा_, --, 
   {{0x88c40202,0x27ec011f,0x989400d1,0x645800b0}},	//   _اتال, qqen_, _мушә, ātio, 
   {{0x6264569f,0x23280798,0x00000000,0x00000000}},	//   овга, јови_, --, --, 
   {{0xa3e40254,0x00000000,0x00000000,0x00000000}},	//   _बंक_, --, --, --, 
   {{0x64a456a0,0x64980261,0xd2a40220,0xd24c1893}},	//   _майа, _втор_, ікте_, کنہ_, 
   {{0x3528113e,0x00000000,0x00000000,0x00000000}},	// [5e40] _اسىپ_, --, --, --, 
   {{0xe29856a1,0x16040073,0x00000000,0x00000000}},	//   _вао_, वीवर_, --, --, 
   {{0xd5ac03e6,0x201000b5,0x00000000,0x00000000}},	//   _سفی_, ssyi_, --, --, 
   {{0x201001f4,0x00000000,0x00000000,0x00000000}},	//   psyi_, --, --, --, 
   {{0x9b683acc,0x20d4177b,0x1b4800f7,0xa3ac00dc}},	//   ишка_, _фінс, изди_, _कदा_, 
   {{0xdfd00451,0x92bc0183,0x00000000,0x00000000}},	//   _آيس_, েশৰ_, --, --, 
   {{0xdd9056a2,0xdb180254,0x26d000d7,0x00000000}},	//   _قوس_, _ihtü, ýzol_, --, 
   {{0xb4e80243,0x0c200131,0x8d240395,0x38c81291}},	//   _बले_, чмән, _мосв_, یاکی_, 
   {{0x2eec56a3,0xff5c0023,0x4d6001d5,0x5edc08ec}},	//   _şefi_, _ሰማዕኩ_, _ўкув, _कृत्_, 
   {{0xb9f40597,0x5ab8009b,0x00000000,0x00000000}},	//   _ᵜᵜ_, _кћер_, --, --, 
   {{0x95c8447e,0x7c240332,0xd0440092,0x00000000}},	//   иума_, áirf, _የያዕቆ, --, 
   {{0x3ce002fb,0x588400ee,0x2b540014,0x546c0092}},	//   živu_, _мыла, _ویۆد_, _ትላልቅ_, 
   {{0x73c400b1,0xe82019cc,0x00000000,0x00000000}},	//   зәне, _मिया_, --, --, 
   {{0x27f800d0,0x00000000,0x00000000,0x00000000}},	//   ísne_, --, --, --, 
   {{0x7bd80b6f,0x00000000,0x00000000,0x00000000}},	//   imvu, --, --, --, 
   {{0xf7700214,0x057400d1,0x00000000,0x00000000}},	//   _تاچ_, _يايد, --, --, 
   {{0x12e456a4,0x403402dd,0x05d400ae,0x00000000}},	// [5e50] _мінг, метс, _تزوج, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x78a40f72,0xb63c037e,0x00000000,0x00000000}},	//   _živl, _ｇｗ_, --, --, 
   {{0x9f400589,0x7bd8009a,0x100401c0,0xd138074d}},	//   _pukã_, emvu, _мягм, _тхо_, 
   {{0x661c068f,0x6b6402bf,0x4c480108,0x629800d7}},	//   ąski, зкла, ряем_, útov, 
   {{0x92bc09bd,0xe9d856a5,0x777803e3,0x61f80115}},	//   েশী_, әки_, _novx, ŭtle, 
   {{0xae0402dd,0x31784579,0x6a8400c0,0xda600108}},	//   _ءورى, _kosz_, ялка, евщи, 
   {{0x23d0098a,0x7d040321,0x9f400022,0xe9d81fbe}},	//   _दीनद, ðist, _tukã_, љки_, 
   {{0xe73856a6,0x8c5400db,0x7c240e89,0x00000000}},	//   беп_, _بئزا, àirt, --, 
   {{0x9524025c,0x5ea000db,0x00000000,0x00000000}},	//   འུའི_, _تۅۅل, --, --, 
   {{0x8c9c033f,0x00000000,0x00000000,0x00000000}},	//   _खेतो, --, --, --, 
   {{0x7c240597,0xdb0c01e1,0x00000000,0x00000000}},	//   áirg, _òjòw, --, --, 
   {{0x9f400085,0x15e40150,0x00000000,0x00000000}},	//   _luká_, _ﺍﻟﻜﻬ, --, --, 
   {{0xe3c00139,0xb99402dd,0x00000000,0x00000000}},	//   _otış_, _ىلەب, --, --, 
   {{0x317801f5,0x47d035f9,0x21683e4f,0x00000000}},	//   _bosz_, _فيچر, биви_, --, 
   {{0x66ec01d3,0x98a0012d,0x91e00a5b,0x00000000}},	//   _főké, żką_, еосе, --, 
   {{0x64a43c8f,0x25a0090c,0x142002d5,0xe3c0123d}},	// [5e60] _хапа, mikl_, _здым, _atış_, 
   {{0x98a41b24,0xdb08049f,0x77780218,0x00000000}},	//   šiće_, llfö, _xovx, --, 
   {{0xdb0c0118,0x00000000,0x00000000,0x00000000}},	//   ájím, --, --, --, 
   {{0x25a000bc,0x00000000,0x00000000,0x00000000}},	//   nikl_, --, --, --, 
   {{0x61e400f1,0x23780171,0x8f641e4a,0x00000000}},	//   _iikl, _kopj_, تمەك_, --, 
   {{0x20e0043b,0xa3b006ab,0xb4e80034,0xdb2056a7}},	//   mɔi_, टकट_, _बल्_, روعی, 
   {{0x4cb8009e,0xaa440354,0x00000000,0x00000000}},	//   েশগু, çелл, --, --, 
   {{0x6458005f,0x60c406ea,0xb7f80276,0x61e456a8}},	//   ātij, _kykm, ониф_, _jikl, 
   {{0x61e456a9,0xdb08005c,0x7c2456aa,0x00000000}},	//   _mikl, kofø, áird, --, 
   {{0x61e40bed,0x35f456ab,0x5fbc047f,0xb8e40bc0}},	//   _likl, мпор, ्तिल, _एड_, 
   {{0x60c4045f,0xd94456ac,0x7c2456ad,0x00000000}},	//   _lykm, _нежи, šird, --, 
   {{0x61e456ae,0x9dd00150,0x00000000,0x00000000}},	//   _nikl, _ﭘﯩﯖﺸ, --, --, 
   {{0x5fbc23c1,0x00000000,0x00000000,0x00000000}},	//   ्ताल, --, --, --, 
   {{0x23780395,0xb7d81075,0x00000000,0x00000000}},	//   _copj_, _بوتا_, --, --, 
   {{0x61e4008e,0xa3ac2356,0x00000000,0x00000000}},	//   _bikl, _कदर_, --, --, 
   {{0x25a056af,0x5184004e,0x66ec01d3,0x12c40150}},	//   cikl_, чуга, _tőké, _ﺫﺍﻜﺭ, 
   {{0xcee856b0,0x78a41883,0x92bc00bd,0xdb1856b1}},	// [5e70] مران_, _živj, েশে_, _aktí, 
   {{0x61e40270,0x60c4010b,0x753c002f,0x00000000}},	//   _eikl, _dykm, lfsz, --, 
   {{0x0dc856b2,0x61e40fac,0x1ee80fa2,0xa3e406e3}},	//   буди_, _fikl, زونی_, _बूट_, 
   {{0x61e40165,0x260000e1,0x00000000,0x00000000}},	//   _gikl, वीटी_, --, --, 
   {{0x72d801d9,0xdef800c7,0x00000000,0x00000000}},	//   _دِگر_, сыӡ_, --, --, 
   {{0x8d7456b3,0xaa4456b4,0x61e401c0,0x25a00e04}},	//   _کاسا, декл, _zikl, zikl_, 
   {{0x61e40472,0x1b04015b,0x88801079,0x7c2400a3}},	//   _yikl, _রাখে_, کیشن, àirr, 
   {{0xcfac02f5,0x6c8401d9,0x753c01f5,0x60c4010e}},	//   _কঠিন, _قلزم, jfsz, _yykm, 
   {{0xa3e40307,0x2d8c56b5,0x25a0003b,0x888001d5}},	//   _बूझ_, _ilee_, vikl_, عیتن, 
   {{0x6d5814dc,0xe61856b6,0x7b180276,0x7c24007b}},	//   ldwa, одо_, _ноур_, áire, 
   {{0x25a056b7,0x6d5803ac,0x753c002f,0x00000000}},	//   tikl_, odwa, ffsz, --, 
   {{0x6d5856b8,0x64a456b9,0x00000000,0x00000000}},	//   ndwa, дама, --, --, 
   {{0x61e456ba,0x69c856bb,0x6d58127b,0xdb08005c}},	//   _rikl, mlee, idwa, tofø, 
   {{0x61e456bc,0x2d8c208d,0x753c0036,0x6d5802d0}},	//   _sikl, _llee_, afsz, hdwa, 
   {{0xf770516c,0x69c856bd,0x291c014b,0x2d8c00b4}},	//   _حان_, olee, _kdwa_, _olee_, 
   {{0x69c856be,0x5edc0c6f,0x01e400eb,0x00000000}},	//   nlee, _कृष्_, _ফৌজদ, --, 
   {{0x69c856bf,0x6d582252,0x10a0005b,0xd12c007b}},	// [5e80] ilee, ddwa, витн, شمل_, 
   {{0x6d580c8c,0x78a456c0,0x61e456c1,0x2d8c56c2}},	//   edwa, _živk, _wikl, _alee_, 
   {{0x61e456c3,0x291c0921,0x2d8c0477,0x60c4002d}},	//   _tikl, _odwa_, _blee_, _wykm, 
   {{0x2d8c0072,0x291c0083,0xa06807c6,0x69c856c4}},	//   _clee_, _ndwa_, _дама_, jlee, 
   {{0x69c801d9,0x2d8c05c7,0x27fc0393,0x00000000}},	//   dlee, _dlee_, _ntwn_, --, 
   {{0x69c856c5,0x2d8c56c6,0x63ac003e,0x6d585337}},	//   elee, _elee_, nnbn, adwa, 
   {{0x69c856c7,0xcf5404ae,0x2d8c2517,0x00000000}},	//   flee, _קבלת_, _flee_, --, 
   {{0x69c856c8,0x2d8c56c9,0x6d58035a,0xfcd40023}},	//   glee, _glee_, cdwa, _ይመጹ_, 
   {{0xa3dc0014,0x291c04ba,0x81b00154,0xa3ac00cd}},	//   तगा_, _ddwa_, _ওঠা_, _कदं_, 
   {{0xf6982424,0x69c856ca,0x291c02e2,0x8c940014}},	//   звој_, alee, _edwa_, _تھٔز_, 
   {{0x69c856cb,0xa36801a9,0xcb9401b9,0x68f80042}},	//   blee, _chеm, _تنلش_, _ffwd, 
   {{0x69c856cc,0x753c0e78,0xd56456cd,0x00000000}},	//   clee, ufsz, фтоп, --, 
   {{0x61fc56ce,0x00000000,0x00000000,0x00000000}},	//   _atpl, --, --, --, 
   {{0x291c014b,0xdb0802d2,0x00000000,0x00000000}},	//   _zdwa_, fnfé, --, --, 
   {{0xeb9000c8,0x6d5803cb,0xc7d4011a,0x00000000}},	//   אָן_, ydwa, _חוגי_, --, 
   {{0x61f856cf,0x27e804cc,0xe2a401ec,0x00000000}},	//   ítla, _èanc_, _ﺎﺒﻬﻡ_, --, 
   {{0x629801f1,0xdc6402d3,0x7f800213,0x6d5803ac}},	// [5e90] útor, ተነበረ_, _nöqs, vdwa, 
   {{0x2d8c56d0,0x6e9456d1,0x69c801c6,0x325456d2}},	//   _slee_, низу, zlee, _звор, 
   {{0x69c856d3,0x2d8c01f5,0x6d5802d0,0x6f0436f4}},	//   ylee, _plee_, tdwa, rbhc, 
   {{0x02a400c7,0x69c81dd0,0x98a0012d,0xb60800ef}},	//   _шрым, xlee, żkę_, _iešļ, 
   {{0x69c856d4,0x6d5856d5,0x6d5c0ad9,0xc0c856d6}},	//   vlee, rdwa, _ósam, _журе_, 
   {{0x69c856d7,0xcf24007b,0x7dec03e3,0x6d5856d8}},	//   wlee, _ترحي, _ağsu, sdwa, 
   {{0x69c856d9,0x7d040789,0x2d8c0156,0x7dc4104b}},	//   tlee, ñisc, _tlee_, رقۇن, 
   {{0x7d2456da,0x69c8198f,0x2d8c56db,0x5c700bd6}},	//   _аффе, ulee, _ulee_, тләт, 
   {{0x69c856dc,0x00000000,0x00000000,0x00000000}},	//   rlee, --, --, --, 
   {{0x69c856dd,0xaa5856de,0xe7380640,0x7c34033f}},	//   slee, _низу_, чео_, żeró, 
   {{0x69c81af3,0xaa940597,0xe5a41d0f,0x00000000}},	//   plee, _ثلاث, еини, --, 
   {{0x69c856df,0x00000000,0x00000000,0x00000000}},	//   qlee, --, --, --, 
   {{0x61fc01ab,0x95800064,0xed580064,0x9f400166}},	//   _stpl, уляе, _maž_, _yukä_, 
   {{0x33d41c26,0x987800c8,0x06800117,0x00000000}},	//   віст, _מאנט, _аҳон, --, 
   {{0xe5a456e0,0x61440588,0xe2a81a4d,0x3d10000d}},	//   _пики, нева, ساسن_, _ढ़ले_, 
   {{0x63b400c0,0x8fa0035b,0x00000000,0x00000000}},	//   _šanč, ҳауе, --, --, 
   {{0x1f644ea5,0xe3b056e1,0x8c9c0034,0x5f04030d}},	// [5ea0] нкам, _مرد_, _खेलो, езза, 
   {{0x38600b4b,0xdb1803da,0x6454058a,0xf0000116}},	//   _širk_, _oktá, _isyi, рүри, 
   {{0x1d240032,0x61fc0250,0x2168022e,0x00000000}},	//   емем, _utpl, _еини_, --, 
   {{0x645400b5,0x1ee807d6,0x00000000,0x00000000}},	//   _ksyi, زوچی_, --, --, 
   {{0x604407d5,0x7dec0213,0xed5800c0,0x00000000}},	//   _чĕлх, _ağst, _daž_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x68f400bc,0x1d0800f3,0x00000000,0x00000000}},	//   ězdn, _неви_, --, --, 
   {{0x2ee402d2,0x00000000,0x00000000,0x00000000}},	//   _úlfa_, --, --, --, 
   {{0xd84c01f2,0x57a456e2,0x44d0003a,0xa36801a9}},	//   _gọlf_, ешна, _n̄_, _chеk, 
   {{0x5a9456e3,0x9f40023a,0xe8200bae,0xb6c400db}},	//   _преф, _etkö_, _मिरा_, көйд, 
   {{0x645456e4,0x00000000,0x00000000,0x00000000}},	//   _asyi, --, --, --, 
   {{0xceb00d65,0x00000000,0x00000000,0x00000000}},	//   טית_, --, --, --, 
   {{0x25700150,0x00000000,0x00000000,0x00000000}},	//   рқыс, --, --, --, 
   {{0xb9d002d3,0xdb081de4,0xc6a00116,0x480400f0}},	//   _ትም_, mofó, _әрши, _џејн_, 
   {{0x44d006c8,0xdb0856e5,0x5f14009e,0x00000000}},	//   _ē_, lofó, ালাও_, --, 
   {{0x8634123b,0x00000000,0x00000000,0x00000000}},	//   _נרחב_, --, --, --, 
   {{0x64540205,0xf4d801d5,0xdb0800d7,0x00000000}},	// [5eb0] _gsyi, _юмиш_, nofó, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xed580010,0x6d5c0162,0x59b000cd,0x00000000}},	//   _paž_, _ósak, ुकार, --, 
   {{0xe82009d9,0x3d940f64,0xc0d00023,0x00000000}},	//   _मिला_, лихр, እራም_, --, 
   {{0x2fd80597,0xafe40116,0xdecc0023,0x20e40107}},	//   _يوجد_, _җоңл, እዋኑ_, _асрҳ, 
   {{0xc4d427af,0xd6c456e6,0x32000240,0xdb0846dc}},	//   נגס_, _نق_, _kthy_, dofó, 
   {{0xbed400f0,0x0a6856e7,0xeec456e8,0x00000000}},	//   _борј, ярди_, _شيرپ, --, 
   {{0xefcc010c,0x68f40118,0x7dd80174,0xadd4009b}},	//   እዛዝ_, ězdo, vísg, _робљ, 
   {{0xc8d856e9,0x3d94020f,0x00000000,0x00000000}},	//   मेंट, _ситр, --, --, 
   {{0xf7b82d40,0x94ec03e3,0x00000000,0x00000000}},	//   ﻤﺎﻳﺪ, mşək_, --, --, 
   {{0x9f48145e,0xc9841d0f,0x81d80eac,0x4ab800c5}},	//   _bibê_, _пуди, াদত_, _ऊँटव, 
   {{0x888000f2,0x00000000,0x00000000,0x00000000}},	//   _میبن, --, --, --, 
   {{0x69d856ea,0xc448006c,0xe738247f,0xdb0856eb}},	//   _ihwe, ریدن_, _жел_, mofò, 
   {{0xdb0856ec,0x00000000,0x00000000,0x00000000}},	//   lofò, --, --, --, 
   {{0x69d84797,0x98e0037e,0xc6a40131,0x3860025c}},	//   _khwe, _au版i, _ярди, _ġiri_, 
   {{0x386008a4,0x64540793,0xdb0856ed,0x00000000}},	//   _širi_, _tsyi, nofò, --, 
   {{0xf1a824e0,0xe3b8013e,0x7dd800d2,0x6adc00cd}},	// [5ec0] رافه_, _оби_, níse, मधुर, 
   {{0xd00c007b,0xe284014b,0x00000000,0x00000000}},	//   تلك_, _алои, --, --, 
   {{0xe3b056ee,0x201c00b0,0xa22800a7,0x7dd800ae}},	//   _مرگ_, _ātiu_, _южна_, híse, 
   {{0x5bc83f55,0x69d8013b,0x5ce40150,0x3a7400d1}},	//   ित्व, _nhwe, نكال, ғлир, 
   {{0xdb0856ef,0x00000000,0x00000000,0x00000000}},	//   xofó, --, --, --, 
   {{0x69d80134,0x200056f0,0x386000e4,0xcb6403fb}},	//   _ahwe, _itki_, _áiri_, каче_, 
   {{0xcb640640,0x8fa0023a,0xcfac00fe,0x8a14009a}},	//   таје_, _таре, কতখন, نتيس_, 
   {{0x69d80cfd,0x7f5c56f1,0x20000270,0x41d841ac}},	//   _chwe, _harq, _ktki_, _भीमस, 
   {{0x7f5c1bb7,0x69d856f2,0x481056f3,0x497001ec}},	//   _karq, _dhwe, амыс, рлыс, 
   {{0x69d8016b,0xdb0856f4,0x7f5c56f5,0xabc401ee}},	//   _ehwe, rofó, _jarq, _бауҙ, 
   {{0x7f5c22e5,0x2d880037,0x00000000,0x00000000}},	//   _marq, öaeg_, --, --, 
   {{0x6ef80af2,0x78a404a7,0x7f5c0129,0x9f480200}},	//   _kúbó, _živu, _larq, _bibë_, 
   {{0x81d809bd,0xd87400db,0x38600332,0x00000000}},	//   াদা_, _جااب, _éir_, --, 
   {{0xc7a056f6,0x07a001f4,0x00000000,0x00000000}},	//   _кичк, _качн, --, --, 
   {{0xd5b84538,0x91c40063,0xc7d4011a,0x00000000}},	//   _оси_, вљал, _שווי_, --, 
   {{0x69d8009a,0xdcec0118,0x76580153,0x00000000}},	//   _xhwe, ěděn, _isvy, --, 
   {{0x7f5c56f7,0x7bc856f8,0x6d5c0332,0xd17400fb}},	// [5ed0] _barq, _okdu, _ósai, ныҡы, 
   {{0x7f5c56f9,0xb354188c,0x057400db,0xb27401f4}},	//   _carq, _скош, _ماۋد, _блош, 
   {{0x200005d1,0x7f5c022e,0x7c2456fa,0x00000000}},	//   _etki_, _darq, áirn, --, 
   {{0xac94088b,0x7bc8020c,0x9f4802e2,0x6ef802d2}},	//   лаеш, _akdu, _libè_, _búbó, 
   {{0x7c240bb8,0x69d85692,0x7f5c56fb,0x4fc42e26}},	//   širn, _rhwe, _farq, _асва, 
   {{0x69d856fc,0x09c80c00,0x7f5c0067,0xa2d80807}},	//   _shwe, ात्य, _garq, फेक्, 
   {{0xa9a456fd,0x69d856fe,0x6e94014b,0x00000000}},	//   ликд, _phwe, _сиву, --, 
   {{0x69d800fb,0x7bc801e4,0x7f5c0946,0x6f1401ef}},	//   _qhwe, _ekdu, _zarq, _hezc, 
   {{0x7f5c03f0,0xdb080ba1,0xcc840345,0x00000000}},	//   _yarq, rofò, _جۆشه_, --, 
   {{0x468056ff,0xdb08067c,0x8aa40a5b,0x6d6400d7}},	//   иқла, sofò, _иред, štaľ, 
   {{0x69d85700,0x6f145701,0x49001c3e,0x6b800332}},	//   _thwe, _mezc, _күйг, _iolg, 
   {{0x69d85702,0x6f1407de,0x7dd80798,0x79a400f3}},	//   _uhwe, _lezc, mísc, _крче, 
   {{0x6b805703,0x9f480248,0x546401a9,0x00000000}},	//   _kolg, _fibè_, гаям_, --, 
   {{0xe7380372,0x6b800076,0x9cd4011a,0x23780066}},	//   _чек_, _jolg, טורה_, رمزد_, 
   {{0x6b802a89,0xe2985704,0x7f5c03f0,0x7dd800db}},	//   _molg, хав_, _rarq, nísc, 
   {{0x7f5c5705,0x21f8009d,0xdee401a9,0x00000000}},	//   _sarq, _үхнэ_, ҳози, --, 
   {{0xdfd05706,0x64580f40,0xb9d000b7,0x6b8003ac}},	// [5ee0] مير_, ātis, _ትዝ_, _oolg, 
   {{0xd00c5707,0x44205708,0x7f5c5709,0xdee4570a}},	//   سلم_, _ivi_, _qarq, гози, 
   {{0x44200162,0x2610570b,0xe814012d,0x21a40117}},	//   _hvi_, nšo_, _दौसा_, _бинм, 
   {{0x7f5c3431,0x44200158,0x5d14570c,0x1278010f}},	//   _warq, _kvi_, اباز, _נאכע, 
   {{0x6b80570d,0x7f5c570e,0xbd680184,0x9f48004a}},	//   _bolg, _tarq, ерҙе_, _libé_, 
   {{0x6b80570f,0x7c240e3c,0x6f140369,0x442001f7}},	//   _colg, širo, _gezc, _mvi_, 
   {{0x6b805710,0x2610151c,0x44205711,0xcb645712}},	//   _dolg, jšo_, _lvi_, طميه_, 
   {{0x5fbc0562,0xca445713,0x6b800332,0x9f480241}},	//   ्तकल, اليه_, _eolg, _sibè_, 
   {{0x5b3436c1,0x6b805714,0x44205715,0xc980005b}},	//   _معار, _folg, _nvi_, сущи, 
   {{0x7dd8003a,0x38c801b9,0x00000000,0x00000000}},	//   bísc, _یاشی_, --, --, 
   {{0x9f480597,0x35b45716,0x36d4013e,0x44205717}},	//   _cibé_, ибор, ронр, _avi_, 
   {{0x44200943,0x386005a1,0xc95401b9,0x00000000}},	//   _bvi_, _širu_, _бўш_, --, 
   {{0xd3245718,0x44205719,0x9f48571a,0x6b80571b}},	//   льви, _cvi_, _tibè_, _yolg, 
   {{0x4420571c,0xd90c571d,0x26100219,0x8cd409bb}},	//   _dvi_, _بیک_, bšo_, _बरसो, 
   {{0x4420571e,0x6f140099,0xb59402bf,0x9f480332}},	//   _evi_, _rezc, _вийш, _gibé_, 
   {{0x48d80316,0x00000000,0x00000000,0x00000000}},	//   खेको_, --, --, --, 
   {{0x44200007,0xfe5801ec,0x2f14316e,0x46e40166}},	// [5ef0] _gvi_, _ءﺟﯘﺯ_, идаё, _идән_, 
   {{0x32940014,0x2ba80073,0x850400f2,0x00000000}},	//   _نٔخر, _औषधा, _پوین, --, 
   {{0x644c151c,0x6b80571f,0x00000000,0x00000000}},	//   čniš, _rolg, --, --, 
   {{0x6b805720,0x44200221,0x6f140810,0xb05401d3}},	//   _solg, _yvi_, _wezc, _پھرت, 
   {{0x6b8000dd,0xe6d005d7,0x6aac0825,0xd08401f4}},	//   _polg, _हर्ज, टप्र, _сыни, 
   {{0x6a845721,0x6b80006c,0xef6401c0,0x3944003e}},	//   илла, _qolg, _тэмү, efms_, 
   {{0x6b805722,0xf1b80882,0xbb180a8e,0x69942c31}},	//   _volg, _इदान, ازها_, ирих, 
   {{0x6b8000a2,0x9f48004e,0x4df401e0,0x26100427}},	//   _wolg, _ribé_, _аяҡт, všo_, 
   {{0x6b800f7d,0x39ac0118,0x396400c7,0x7af80162}},	//   _tolg, věst_, сныҳ, íatú, 
   {{0x26105723,0x44205724,0x6b800381,0x6d4802d2}},	//   tšo_, _rvi_, _uolg, _hbea, 
   {{0x44201326,0x2d845725,0xb8ec0e49,0x8a68036b}},	//   _svi_, _îles_, _शु_, _яшаб_, 
   {{0x26105726,0x44200051,0xadd801ec,0x65c400db}},	//   ršo_, _pvi_, ндiг, рбма, 
   {{0x6d480491,0x290c05d9,0xd8a405d9,0x44205727}},	//   _mbea, mbea_, _پڇيو_, _qvi_, 
   {{0x66e45728,0x442004ba,0x6d480076,0x290c005a}},	//   _кола, _vvi_, _lbea, lbea_, 
   {{0xa2e4322e,0x6d485729,0x6d1400ab,0x00000000}},	//   ровд, _obea, _ढ़ंग_, --, 
   {{0x602402bf,0x290c016b,0x00000000,0x00000000}},	//   идба, nbea_, --, --, 
   {{0x4420572a,0x9fc801c6,0x60e800c0,0x7d043a6c}},	// [5f00] _uvi_, вгаа_, тмам_, ñism, 
   {{0x6d48572b,0xdee40364,0xa368022e,0xe1f800d8}},	//   _abea, ҳоҷи, _chеt, _иго_, 
   {{0xe2983cc5,0x6144010e,0x6d4830c6,0xdd90007b}},	//   _ран_, _кена, _bbea, يوط_, 
   {{0x80a804c5,0x6d4801ab,0x399801e1,0x3d1008e9}},	//   _কুণ্, _cbea, _kése_, ारें_, 
   {{0x6d48572c,0x00000000,0x00000000,0x00000000}},	//   _dbea, --, --, --, 
   {{0x39980022,0x290c003a,0x8c400114,0x00000000}},	//   _mése_, ebea_, цеље, --, 
   {{0x399801e1,0x8a000120,0xdb080200,0x00000000}},	//   _lése_, озје, lifë, --, 
   {{0xdd90572d,0x98c4033a,0xf8b801c6,0x00000000}},	//   _بور_, испл, лөл_, --, 
   {{0xdb500531,0x7dd80005,0xb7c402a9,0xa3e401f9}},	//   _وَر_, císa, йроқ, _फळं_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd6d8572e,0x00000000,0x00000000,0x00000000}},	//   ъти_, --, --, --, 
   {{0x6d5c03f2,0x9848004e,0xe73400c7,0x00000000}},	//   _ósat, _аяка_, аҵә_, --, 
   {{0x37c400c7,0x8434003b,0x00000000,0x00000000}},	//   _гәнб, оняє, --, --, 
   {{0x13040efb,0x39980789,0x52241b15,0x03240108}},	//   شىرۋ_, _dése_, ифба, ждён, 
   {{0xd1740046,0x32040109,0xd13807d5,0x25fc0210}},	//   қыңы, ëly_, кха_, _रूपी_, 
   {{0x3d10068f,0x3ce00122,0x3998002e,0xdcec0118}},	//   ारों_, živy_, _fése_, áděc, 
   {{0xc1040597,0xd7780023,0x7c240010,0xcee801b9}},	// [5f10] توقي, _ኤረትራ_, širj, چران_, 
   {{0x68f40316,0xcee8328a,0x7dd8572f,0x6d4800a3}},	//   ězdi, نران_, vísa, _sbea, 
   {{0xdb08068c,0x63a00042,0x80a800eb,0x00000000}},	//   mifè, _ïona, _কুদ্, --, 
   {{0xdb085730,0x00000000,0x00000000,0x00000000}},	//   nnfæ, --, --, --, 
   {{0xfc640023,0x25fc466d,0x73c40055,0x00000000}},	//   _ቀልጢፍ, _रूनी_, _ṛṣva, --, 
   {{0xdb085731,0x09ac0490,0x00000000,0x00000000}},	//   nifè, जच्य, --, --, 
   {{0x6d485732,0x4aa44c3d,0x3090001f,0x00000000}},	//   _tbea, _केशव, _የመጠጥ_, --, 
   {{0x7dd80038,0x61f803b2,0x00000000,0x00000000}},	//   písa, ítli, --, --, 
   {{0x290c5733,0x613001a9,0x3c580166,0x00000000}},	//   rbea_, _mаlа, _китэ_, --, 
   {{0x61f801e4,0x00000000,0x00000000,0x00000000}},	//   ŭtli, --, --, --, 
   {{0x6d5c03b2,0xdb0844b3,0x00000000,0x00000000}},	//   _ósas, tofö, --, --, 
   {{0xba745734,0xe2985735,0xdb0802d2,0x00000000}},	//   _باكت, қаб_, gnfæ, --, 
   {{0xe820012d,0x00000000,0x00000000,0x00000000}},	//   _मिटा_, --, --, --, 
   {{0x39980077,0x2c1800cd,0x00000000,0x00000000}},	//   _vése_, नीयं_, --, --, 
   {{0x05480116,0xe61802a9,0x00000000,0x00000000}},	//   _күнл_, _ёди_, --, --, 
   {{0xa0a401b9,0xdb080036,0xa3b801e2,0x00000000}},	//   бабд, tifë, _څادر_, --, 
   {{0xe0d85736,0x00e42ea3,0xa3b8034c,0x25fc012d}},	// [5f20] ува_, زتری, _مادر_, _रंडी_, 
   {{0xdb08036e,0x00000000,0x00000000,0x00000000}},	//   rifë, --, --, --, 
   {{0x69c85737,0x4aa400ab,0x8fa000ea,0xe820000d}},	//   koee, _केलव, џахе, _मिझा_, 
   {{0x63ac5738,0xdef80184,0x628c0006,0xc194036b}},	//   libn, тыҡ_, mybo, _بیرع, 
   {{0x628c5739,0xe0d001d9,0xdb0806af,0x3d1000bc}},	//   lybo, _رٲس_, lifé, ारौं_, 
   {{0xdee40025,0xd00c573a,0xdce000df,0x63ac2323}},	//   _гоги, _سلف_, ndoĉ, nibn, 
   {{0x628c573b,0xdb08573c,0x00000000,0x00000000}},	//   nybo, nifé, --, --, 
   {{0xf3f80154,0x00000000,0x00000000,0x00000000}},	//   _অবসর_, --, --, --, 
   {{0x628c0122,0xeb481698,0x7dd800d2,0xe8f40032}},	//   hybo, _چشمو_, líso, әһә_, 
   {{0x628c02d5,0x01cc01ec,0x8c4000d8,0x00000000}},	//   kybo, _ﺒﻌﻴﻨ, _хефе, --, 
   {{0x63ac01d9,0x69c800fb,0x628c0024,0x9f480241}},	//   dibn, boee, jybo, _nibí_, 
   {{0x628c573d,0xdb1810b8,0xd83830ab,0x00000000}},	//   dybo, _aktø, _бэк_, --, 
   {{0x94a8573e,0x9f4800ae,0x25fc00e1,0xdb0801bf}},	//   утна_, _aibí_, _रूठी_, rnfæ, 
   {{0x63ac0427,0xa368022e,0x00000000,0x00000000}},	//   gibn, _shеr, --, --, 
   {{0xdb08573f,0xd1b80592,0xcf88039b,0x613001d5}},	//   rifè, هارا_, қсад_, _pаlа, 
   {{0x30145740,0x2ee41427,0x00000000,0x00000000}},	//   ждар, _úlfi_, --, --, 
   {{0x85b801d9,0x10480724,0x9f4801e1,0x63ac20c2}},	// [5f30] _داوس_, ыяви_, _tibì_, bibn, 
   {{0xe0d8030d,0x00000000,0x00000000,0x00000000}},	//   ăва_, --, --, --, 
   {{0x613001d5,0xdb080129,0x7dd800d0,0x4aa4098b}},	//   _tаlа, cifé, rísn, _केंव, 
   {{0xfe700597,0x88cc0183,0x3cf8007b,0x0bb401e0}},	//   عدل_, াইতক, معهد_, өтлө_, 
   {{0xcfc000bd,0x46cc1d15,0x7c840063,0x50640120}},	//   ্গবন, _सुनह, зује, _утна, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfbd05741,0x7b442051,0x69c80270,0x5fa021ef}},	//   رته_, سئول, toee, _تەلم, 
   {{0xe9d803b7,0xa8041768,0x29185742,0x4ae401a9}},	//   јки_, озил, úsa_, _ғўза, 
   {{0x2eb851a5,0xaf70001f,0x628c5743,0x63ac022e}},	//   _आशुत, _ለማስገ, zybo, yibn, 
   {{0xe7a82afd,0x00000000,0x00000000,0x00000000}},	//   рвол_, --, --, --, 
   {{0xe5780c69,0x628c493a,0x69c84c48,0xf1d80073}},	//   азн_, xybo, poee, ढतान, 
   {{0x24e85744,0x3cf00c2e,0x2d9c5745,0x628c5746}},	//   имни_, ुँचे_, nhwe_, vybo, 
   {{0x44245747,0x628c0368,0x63ac0010,0x00000000}},	//   ém_, wybo, tibn, --, 
   {{0x628c5748,0xe2980323,0x7c24007b,0x27f800d7}},	//   tybo, ааг_, áiri, ísnu_, 
   {{0x97000075,0x2d9c5749,0xa18802e8,0x10e00150}},	//   _تېپى, khwe_, абва_, _ﻋﺼﺭﻨ, 
   {{0x7c24098d,0x63ac3a97,0x80a8015b,0x628c574a}},	//   širi, sibn, _কুষ্, rybo, 
   {{0x5ef8040e,0x65740472,0x9f840111,0x1fa8013e}},	// [5f40] ахер_, _inyh, огад, акаи_, 
   {{0x7dec574b,0x628c574c,0x63ac01a9,0x00000000}},	//   _işsi, pybo, qibn, --, 
   {{0x46cc00dc,0x6444265c,0x00000000,0x00000000}},	//   _सुमह, ltki, --, --, 
   {{0x2168574d,0x6444107d,0x65640327,0x00000000}},	//   _тими_, otki, ndkh, --, 
   {{0x6444574e,0x65740472,0x6f080205,0x1b6000c7}},	//   ntki, _mnyh, _şece, мҭаҟ, 
   {{0x9f480004,0xda040b3b,0x70500133,0x38c40200}},	//   _dibã_, очип, _سۆما, hërë_, 
   {{0x644400af,0x65740204,0xda783580,0xd37800df}},	//   htki, _onyh, рял_, ירסט, 
   {{0x2d9c01f7,0x20040311,0xdee401d5,0x38c40200}},	//   chwe_, ţoiu_, _гоҳи, jërë_, 
   {{0xa3d8068f,0x46cc574f,0x39980129,0xf1bc00dc}},	//   ़ता_, _सुबह, _césa_, ्कतन, 
   {{0x3998093a,0x6444002f,0x77985750,0x00000000}},	//   _désa_, dtki, скор_, --, 
   {{0x4ef800c8,0xab6008b0,0xd9445751,0x0f540375}},	//   יליג, _سۇيى, _межи, חיים_, 
   {{0xd498074d,0xa9c402dd,0xded40092,0x00000000}},	//   арг_, _есік, ራርና_, --, 
   {{0x7dd801a8,0x644401bf,0x93880395,0x660c5752}},	//   vísl, gtki, асва_, _čake, 
   {{0x657401ed,0x00000000,0x00000000,0x00000000}},	//   _enyh, --, --, --, 
   {{0x7dec05d1,0xb5940063,0x64445753,0x38c40200}},	//   _eşsi, _никш, atki, bërë_, 
   {{0x2d9c009a,0xe28c01a9,0x00000000,0x00000000}},	//   xhwe_, _tgаn_, --, --, 
   {{0x21280633,0x00000000,0x00000000,0x00000000}},	// [5f50] صيلی_, --, --, --, 
   {{0x73385754,0xc4c40451,0x44f400db,0x73c40ce8}},	//   _узор_, _آڪٽو, _تسىز, _хәме, 
   {{0x2d9c5755,0x7ed45756,0xd36c0150,0xe3c00139}},	//   thwe_, وزما, _كۇڭ_, _quış_, 
   {{0x753c5757,0xad24525b,0x00000000,0x00000000}},	//   ngsz, سىتى, --, --, 
   {{0xdd480092,0x3078010f,0x833405af,0x00000000}},	//   _በኮምፒ, _האָנ, _عریض, --, 
   {{0x2d9c0526,0x09c01810,0xceb40131,0x39980129}},	//   shwe_, शव्य, _һәҗ_, _résa_, 
   {{0xe7380032,0x399800d5,0x1b0403d4,0x29380092}},	//   ҙен_, _sésa_, _ৰাখে_, _በሀይማ, 
   {{0x8d745758,0x39980085,0x2b98067c,0xf1bc2c2e}},	//   _باسا, _pésa_, _dèca_, ्किन, 
   {{0xbd445759,0xec1410ef,0xada40131,0x6d585337}},	//   _تنقي, _رواد, _даңл, mewa, 
   {{0x6d58575a,0x6f040334,0xe738026a,0x0b9401d5}},	//   lewa, nchc, љен_, _بجرد, 
   {{0x539c02d3,0xf1bc193d,0x38c4002e,0x00000000}},	//   _ሃለዋት_, ्कान, tërë_, --, 
   {{0x6d5814dc,0x83f00134,0x2c5c0100,0x00000000}},	//   newa, _mpɑe, _kňd_, --, 
   {{0xf990575b,0x291c0a73,0x6444012d,0x00000000}},	//   _جبل_, _iewa_, utki, --, 
   {{0x291c0751,0x6d5818a6,0x2c5c0100,0xdb18010b}},	//   _hewa_, hewa, _mňd_, _oktý, 
   {{0x644414cf,0x67200bb8,0x6d58575c,0x2c5c02e2}},	//   stki, malj, kewa, _lňd_, 
   {{0x291c575d,0x6d58575e,0x6720575f,0x00000000}},	//   _jewa_, jewa, lalj, --, 
   {{0x6d585760,0x291c5761,0xded41772,0xdb18010b}},	// [5f60] dewa, _mewa_, ራይን_, _aktý, 
   {{0x291c5762,0x26000241,0xe298009b,0x7dd81e0b}},	//   _lewa_, _kóo_, _гао_, rísm, 
   {{0xd24c04d3,0x6d585763,0x291c0334,0x00000000}},	//   _ینی_, fewa, _oewa_, --, 
   {{0x6d585764,0x291c5765,0x67205766,0xdc285767}},	//   gewa, _newa_, halj, مسته_, 
   {{0x61fc014f,0x7dd85768,0x25fc0da3,0x260001e1}},	//   _hupl, lísk, _रूसी_, _lóo_, 
   {{0x291c02b5,0x2c5c007f,0xa13404fb,0x7e78008e}},	//   _aewa_, _dňd_, _برگش, _мәет_, 
   {{0x67205769,0x291c342f,0x6d58576a,0x61fc047e}},	//   dalj, _bewa_, bewa, _jupl, 
   {{0x291c576b,0x6d58576c,0x61fc0455,0xdce002f0}},	//   _cewa_, cewa, _mupl, ldoč, 
   {{0x291c0d51,0xdb080597,0x61fc576d,0x00000000}},	//   _dewa_, lifí, _lupl, --, 
   {{0x6720576e,0x260001e1,0x27fc0009,0x61fc127b}},	//   galj, _bóo_, _duwn_, _oupl, 
   {{0x61fc0024,0x2c5c007f,0xdb080332,0xbf9401e1}},	//   _nupl, _zňd_, nifí, _ńfọn_, 
   {{0x7c2407f5,0xd944576f,0x7bd8007c,0x99e400db}},	//   širu, _хеди, llvu, _эжед, 
   {{0x67205770,0xddcc2ba4,0x7bd803b2,0x00000000}},	//   balj, _arbū, olvu, --, 
   {{0x61fc5771,0x6d585772,0x539c0023,0x7dd808a5}},	//   _bupl, zewa, _ግዝያት_, físk, 
   {{0x61fc5773,0x291c5774,0x7dd8032e,0x00000000}},	//   _cupl, _yewa_, gísk, --, 
   {{0x65b40f8b,0xdb0825e6,0xdb185775,0x6d5800e8}},	//   tšhe, difí, _aktü, xewa, 
   {{0x6d582f05,0x752c0323,0xfbdc0a28,0xa3680139}},	// [5f70] vewa, _idaz, यताम, _ikеn, 
   {{0x6d582252,0x7bd801bf,0x7dd832d8,0x00000000}},	//   wewa, jlvu, lísh, --, 
   {{0x6f045776,0x6d585337,0xa03802d3,0xdcf000b8}},	//   rchc, tewa, እተኛታ, _āgār, 
   {{0xdb183841,0x672005a1,0xd1385777,0x6f040b8b}},	//   _októ, zalj, _ухо_, schc, 
   {{0x6d585778,0x291c5779,0x6b643e2e,0x6c8446c6}},	//   rewa, _rewa_, дкла, بلشم, 
   {{0x6d58577a,0xdcfc0421,0x7648577b,0x00000000}},	//   sewa, āvāe, ktdy, --, 
   {{0xbe88577c,0x752c1225,0x291c577d,0x6d58127b}},	//   _есте_, _odaz, _pewa_, pewa, 
   {{0xe808577e,0x3168577f,0x752c5780,0x7d045781}},	//   онид_, ndaz_, _ndaz, ñist, 
   {{0x7c240597,0x7dd802fb,0x9594001f,0x98f000f1}},	//   áirt, získ, ገኙትን_, نګها, 
   {{0x752c0bd7,0x660400a7,0x764801bf,0x260001e1}},	//   _adaz, мпоа, ftdy, _póo_, 
   {{0x67205782,0x291c5783,0x76480432,0x00000000}},	//   ralj, _tewa_, gtdy, --, 
   {{0x67200b91,0x61fc5784,0x00000000,0x00000000}},	//   salj, _rupl, --, --, 
   {{0x61fc5785,0x76580882,0x00000000,0x00000000}},	//   _supl, āraṇ, --, --, 
   {{0x61fc5786,0x7ae4012c,0x7dd80008,0xa2e401c6}},	//   _pupl, řite, tísk, догд, 
   {{0x61fc014f,0x61441f5a,0xe29801c6,0x00000000}},	//   _qupl, мева, цав_, --, 
   {{0x7dd85787,0x60a002d3,0x61fc0455,0x91e05788}},	//   rísk, _ግርጭት_, _vupl, восе, 
   {{0x1f64188c,0xdfd05789,0x64a4578a,0x25c8578b}},	// [5f80] мкам, نير_, _цапа, रवीण, 
   {{0x61fc578c,0xdb08578d,0x3f9c578e,0x7dd808ce}},	//   _tupl, tifí, óvu_, písk, 
   {{0xdb180699,0xb4580020,0x61fc079b,0x7dd8578f}},	//   _oktò, ያደርጉ, _uupl, lísi, 
   {{0x2eb45790,0x399800e8,0xdbf00241,0xdb085791}},	//   хсус, _réso_, _s̟àd, rifí, 
   {{0xdb080005,0x7f4806be,0x00000000,0x00000000}},	//   sifí, _ödqo, --, --, 
   {{0x64540526,0xdb085792,0x39980264,0x00000000}},	//   _mpyi, nnfø, _péso_, --, 
   {{0x7dd848f4,0x00000000,0x00000000,0x00000000}},	//   hísi, --, --, --, 
   {{0xd91802bf,0xfd2403e6,0xdce000d0,0x6454035a}},	//   цьк_, _سوئێ, mkoľ, _opyi, 
   {{0x660c2e6a,0x7dd80789,0x6f0c0098,0x00000000}},	//   _čaka, jísi, _éncé, --, 
   {{0x7dd85793,0x76485794,0x907800d9,0x00000000}},	//   dísi, ttdy, קטיי, --, 
   {{0x645400e4,0x76480158,0x8af8011a,0x00000000}},	//   _apyi, utdy, _והבי, --, 
   {{0xd4e40139,0xc95401a9,0x00000000,0x00000000}},	//   дюги, _жўш_, --, --, 
   {{0x83f0013f,0xdce00030,0x7648002d,0xc87c0112}},	//   _nsɑs, hkoľ, stdy, äßt_, 
   {{0x23780261,0xc9500022,0x00000000,0x00000000}},	//   _cnpj_, _зтәы, --, --, 
   {{0xc3300131,0xdce00030,0x07a01fbe,0x00000000}},	//   جەپ_, jkoľ, _јајн, --, 
   {{0x2b481505,0x752c5795,0xf7700451,0x00000000}},	//   đaci_, _udaz, _جاچ_, --, 
   {{0x3168083a,0x3494010b,0x6f745796,0xef9800d8}},	// [5f90] rdaz_, _чапр, нгаф, пкаш_, 
   {{0x44fc0003,0x00000000,0x00000000,0x00000000}},	//   _དཔོར_, --, --, --, 
   {{0xdde0000a,0xa2c004b4,0x213400e4,0x00000000}},	//   _šušu, _бәтк, ïchí_, --, 
   {{0x727002d3,0x8d741063,0x02640244,0x00000000}},	//   _ኣሉታዊ_, باطا, _جێفێ, --, 
   {{0xad2401ec,0x921c0037,0x00000000,0x00000000}},	//   _ۋىسى, _बबुओ_, --, --, 
   {{0xaa440798,0x00000000,0x00000000,0x00000000}},	//   еекл, --, --, --, 
   {{0x0a6801b9,0x00000000,0x00000000,0x00000000}},	//   юрди_, --, --, --, 
   {{0xa2d409fd,0x1f3402d3,0x320000a2,0xcbbc0154}},	//   _मुफ्, _ብቀዳም, _muhy_, ইতেছ, 
   {{0xa2d4242e,0x9f40025a,0x320000d7,0x00000000}},	//   _मुन्, _vukö_, _luhy_, --, 
   {{0x7dd81f60,0x4b5003e6,0x5ea000cf,0xa684399f}},	//   vísi, _شێعر, _جۅۅل, елод, 
   {{0xdb2452cb,0x2d8c08f5,0x7d045797,0xfb742586}},	//   _سونی, _koee_, žise, _جھنگ, 
   {{0x7dd83a9c,0xe56801c6,0x00000000,0x00000000}},	//   tísi, чимд_, --, --, 
   {{0x2d8c5798,0x46cc02c3,0xd71c00cc,0x385800ae}},	//   _moee_, _सुरह, _দাৰা_, _يشهد_, 
   {{0x7dd85799,0x18642c08,0x61e4579a,0x00000000}},	//   rísi, _чаши_, _shkl, --, 
   {{0x21741fbe,0x7dd809c2,0x10a001b9,0xc6a401d5}},	//   нуар, sísi, ҳитн, _юрди, 
   {{0x600823b3,0x7dd80407,0x3940000d,0x320001ef}},	//   знам_, písi, _öist_, _duhy_, 
   {{0x2b44579b,0x10a0267c,0x55b80375,0x00000000}},	// [5fa0] _oclc_, гитн, _ממקו, --, 
   {{0xcf400108,0x00000000,0x00000000,0x00000000}},	//   лнуй, --, --, --, 
   {{0xdee4579c,0xecd402dd,0xdce00419,0x00000000}},	//   хожи, _ﭘﺮﻭﻛ, ukoľ, --, 
   {{0xd2b40a1e,0x9f480166,0xd24c01f7,0x00000000}},	//   _טלית_, _sibä_, _انَ_, --, 
   {{0x7d040309,0x00000000,0x00000000,0x00000000}},	//   ñisq, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2b44579d,0x2000579e,0xa2d422e3,0xcb0400c6}},	//   _dclc_, _huki_, _मुम्, ريين_, 
   {{0x2000579f,0x4b8400ee,0x4c803ad0,0xfcd40023}},	//   _kuki_, дйән_, тләв, _ክመጹ_, 
   {{0x212057a0,0x9f480139,0xd8380006,0x00000000}},	//   _mekh_, _tibä_, чэй_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x200057a1,0xb6f800d1,0x8f980677,0xc94c01a9}},	//   _luki_, بىدا_, פיטי, _йў_, 
   {{0x65b45723,0x32000209,0x212000e8,0x18a40117}},	//   tšha, _ruhy_, _nekh_, _паем, 
   {{0x38600ba1,0xd7e801af,0x00000000,0x00000000}},	//   _èir_, _емде_, --, --, 
   {{0x7414006c,0x39ac00bc,0x116407d6,0xa2440014}},	//   _یوبا, věsy_, کلری_, ھیُل_, 
   {{0x523002d3,0x200057a2,0xd5b80395,0x00000000}},	//   _ክልቲኦ, _auki_, _нси_, --, 
   {{0x200057a3,0x00000000,0x00000000,0x00000000}},	//   _buki_, --, --, --, 
   {{0x403457a4,0x2d8c062c,0xa2d42e05,0x200057a5}},	// [5fb0] летс, _roee_, _मुठ्, _cuki_, 
   {{0x200057a6,0x320002f0,0xaae0000d,0x92680dab}},	//   _duki_, _tuhy_, _फरलक, _ерма_, 
   {{0x25b00368,0x200001c6,0x00000000,0x00000000}},	//   _ymyl_, _euki_, --, --, 
   {{0x200057a7,0xd13857a8,0x626402dd,0x7d040309}},	//   _fuki_, _эхо_, _شاپق, ñisp, 
   {{0x5fa004a9,0x83f0013f,0x3a2c0175,0x2d8c00ad}},	//   _ھەمم, _mpɑn, _avdp_, _voee_, 
   {{0xfa480023,0x6d1003ba,0x7dd802d2,0x00000000}},	//   _ዘይኮኑ, _ड्रग_, dísu, --, 
   {{0x660c57a9,0xdb08008c,0x2d8c0093,0x9b90033a}},	//   _čako, kifæ, _toee_, ријц, 
   {{0x200004ce,0xdb080d10,0x5c70013d,0x00000000}},	//   _yuki_, rifá, уләт, --, 
   {{0xdb0800d2,0x598057aa,0x92500023,0x765800c0}},	//   sifá, рлыб, _ምውህሃ, _apvy, 
   {{0x8aa457ab,0x6a14009d,0x00000000,0x00000000}},	//   _пред, _амжу, --, --, 
   {{0xe5a4189d,0xfa340451,0x20dc0073,0x00000000}},	//   вини, _مرند, _मर्ढ, --, 
   {{0x2918030a,0xa5940815,0x00000000,0x00000000}},	//   ñsad_, трощ, --, --, 
   {{0x7dd800bc,0x6fd00490,0xbaf400c7,0x00000000}},	//   míst, तकां, _иҭәу_, --, 
   {{0x33d43bb3,0x200002b5,0x2120002e,0x6cc80150}},	//   гіст, _ruki_, _sekh_, _ﻓﺒﺤﺴ, 
   {{0x200057ac,0x569000d8,0x00000000,0x00000000}},	//   _suki_, _вајт, --, --, 
   {{0x200057ad,0x7dd857ae,0x7a4000bc,0xa2d4146b}},	//   _puki_, níst, lštá, _मुण्, 
   {{0x3e6c043b,0x000401ed,0xa18401e0,0xe3b00035}},	// [5fc0] kótá_, اثری, ныҡл, _نرد_, 
   {{0x442057af,0x200057b0,0x2b980036,0x991c07af}},	//   _iwi_, _vuki_, _dèck_, _यज्ञ_, 
   {{0x44200489,0xad6405d9,0x00000000,0x00000000}},	//   _hwi_, ڏانه, --, --, 
   {{0x44203b18,0x200057b1,0x7dd809c2,0xc1b4008e}},	//   _kwi_, _tuki_, jíst, _сәгы, 
   {{0x7dd857b2,0x442057b3,0x2b980036,0xae0401e0}},	//   díst, _jwi_, _gèck_, _ҡорҙ, 
   {{0x442057b4,0x4c9057b5,0xda7801f0,0xda90009d}},	//   _mwi_, ришс, дяи_, иглө, 
   {{0x442057b6,0x2b9857b7,0xe7cc013d,0x00000000}},	//   _lwi_, _mèch_, _şiğä, --, 
   {{0x7dd857b8,0x442044e9,0x399857b9,0x9f4801e1}},	//   gíst, _owi_, _kési_, _nibú_, 
   {{0x442057ba,0x00000000,0x00000000,0x00000000}},	//   _nwi_, --, --, --, 
   {{0xdb1857bb,0x6aac00df,0x7dd80174,0x00000000}},	//   _aktö, ŝafa, rísu, --, 
   {{0xa3d43eb6,0x442057bc,0xdb08002f,0x5964024c}},	//   िकन_, _awi_, infü, _аъла, 
   {{0x442057bd,0xdb080790,0xdb2457be,0xd838300e}},	//   _bwi_, fifç, _سوچی, _жэк_, 
   {{0x44202112,0x399800d2,0x7dd857bf,0x94a81a5c}},	//   _cwi_, _nési_, líss, фтна_, 
   {{0x44200cfd,0x394401e4,0xccf0011a,0x00000000}},	//   _dwi_, lgms_, יכר_, --, 
   {{0x7dd857c0,0x44200248,0x720457c1,0x466457c2}},	//   níss, _ewi_, اورم, _арым_, 
   {{0x399800e8,0x442024b4,0xdb080166,0x00000000}},	//   _bési_, _fwi_, lifä, --, 
   {{0x442057c3,0xdb080436,0x225801c4,0x62880129}},	// [5fd0] _gwi_, nnfó, _eppk_, _àfon, 
   {{0x39980098,0xceb8026a,0xa5c001a8,0xff0801e1}},	//   _dési_, мље_, _þóra, _ẹ̀lú_, 
   {{0x442053ed,0xed3405f5,0xfe08009a,0x00000000}},	//   _zwi_, гэлэ, نقلي_, --, 
   {{0x7dd857c4,0x7bc401c7,0xd6c400f7,0xfd74009d}},	//   xíst, éiun, _ۇق_, илхэ, 
   {{0x7c64006c,0x7a401d55,0x7c200142,0x7dd857c5}},	//   لاول, yštá, _cwmr, víst, 
   {{0x6fd808e5,0x7dd800d8,0xae040150,0xaa4857c6}},	//   tìcu, físs, _موسى, епка_, 
   {{0x7dd8004e,0xdb1001d3,0xe9d800c7,0xcdd800f3}},	//   gíss, ágár, нкк_, _жња_, 
   {{0x6fd80268,0x3ce00135,0x00000000,0x00000000}},	//   rìcu, żiva_, --, --, 
   {{0xcb440588,0x3d9457c7,0x2d9c57c8,0x6d4802d0}},	//   _ахеи, _титр, mkwe_, _icea, 
   {{0x65b427c4,0xe61857c9,0x7dd80005,0x442057ca}},	//   tšho, ндо_, síst, _rwi_, 
   {{0x442013a1,0x00000000,0x00000000,0x00000000}},	//   _swi_, --, --, --, 
   {{0x442057cb,0x2d9c57cc,0x2b9802e2,0xe67802dd}},	//   _pwi_, nkwe_, _sèch_, _үйді_, 
   {{0x69d857cd,0x2d9c0099,0x2b98033b,0xe7380120}},	//   _ikwe, ikwe_, _pèch_, _зел_, 
   {{0x290c084c,0x66e457ce,0x2578013d,0x9cd400d9}},	//   lcea_, _йола, _bülä_, רושה_, 
   {{0x442057cf,0x39980066,0xadf400ab,0xe6101063}},	//   _wwi_, _sési_, ेदान_, _اشت_, 
   {{0x4420013b,0x290c084c,0xb6c40184,0x65a402d2}},	//   _twi_, ncea_, _әсәй, _bóhe, 
   {{0x442057d0,0x69d857d1,0x91e01318,0xdfe80835}},	// [5fe0] _uwi_, _mkwe, соте, едад_, 
   {{0x6d481142,0x2b98180f,0x6aa80154,0x50d40014}},	//   _acea, _uèch_, _কখনো, ازٲر, 
   {{0x69d857d2,0x81080022,0x6d480129,0x7dd80798}},	//   _okwe, _аҕба_, _bcea, xíss, 
   {{0x69d857d3,0x7dd81892,0x6d480332,0xdca400c7}},	//   _nkwe, víss, _ccea, лаеи, 
   {{0x717057d4,0xd24c00f1,0xad241291,0x7dd802d2}},	//   _بۇقا, _وچې_, شرنو, físr, 
   {{0x7dd857d5,0x69c4004a,0xdb0800fd,0x2d9c0083}},	//   tíss, éhen, xifä, akwe_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7dd857d6,0x6d480491,0xf8b857d7,0x80c8000d}},	//   ríss, _gcea, көл_, _रखाइ, 
   {{0x7dd857d8,0xb7c401b9,0x8d90007b,0xdb0857d9}},	//   síss, ироқ, _القش, tifä, 
   {{0x69d857da,0x7dd8004e,0xc98001d5,0x00000000}},	//   _ekwe, píss, _ҳуши, --, 
   {{0x7bc801b9,0xd6d80276,0x00000000,0x00000000}},	//   _ijdu, эти_, --, --, 
   {{0xceb00302,0x290c57db,0x66700131,0xc9800536}},	//   מית_, ccea_, زگىر, _гуши, 
   {{0x589457dc,0x257800a2,0x00000000,0x00000000}},	//   _حجاز, _sülä_, --, --, 
   {{0x887000c7,0xd48000c7,0xe3c4009d,0x00000000}},	//   _ñasẽ, акҭқ, арсү, --, 
   {{0xc6744a2a,0x00000000,0x00000000,0x00000000}},	//   _محيط_, --, --, --, 
   {{0x70581d56,0xb11457dd,0x3494014b,0x00000000}},	//   кабр_, рмаш, _ваир, --, 
   {{0x61442160,0x6ae00034,0x50b80214,0xef10004e}},	// [5ff0] شىلە, _फर्र, ردرد_, жүгө, 
   {{0x6d4857de,0x25780139,0x80f448e5,0x00000000}},	//   _scea, _tülä_, спух, --, 
   {{0xdecc0023,0x00000000,0x00000000,0x00000000}},	//   ጥፋእ_, --, --, --, 
   {{0x02a457df,0xac18524d,0x7bc8107d,0xad400228}},	//   _ырым, воду_, _ajdu, تۉرۉ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69d857e0,0x00000000,0x00000000,0x00000000}},	//   _skwe, --, --, --, 
   {{0xa3d40d01,0xde44179e,0xbea41171,0x00000000}},	//   िकत_, _نیلو_, _лаёк, --, 
   {{0x6d480268,0x3e3c02d3,0xddc8054e,0x00000000}},	//   _ucea, _ካልኣይ, ănţu, --, 
   {{0x290c084c,0x779000f1,0x00000000,0x00000000}},	//   rcea_, ړیوا, --, --, 
   {{0x279457e1,0xed58107d,0xfaa40075,0xd7ec007b}},	//   ршир, _hbž_, ршән, وكي_, 
   {{0x66e457e2,0x290c0356,0x46cc08a3,0x7b1801f4}},	//   рона, pcea_, _सुखह, _сохр_, 
   {{0x69d857e3,0x28740aec,0x39981bce,0xa2d4043e}},	//   _ukwe, _выкр, _bésu_, _मुष्, 
   {{0xe7940133,0x00000000,0x00000000,0x00000000}},	//   _پاشک, --, --, --, 
   {{0x98a057e4,0xe73857e5,0xa6940640,0xc44801d5}},	//   _фише, _рек_, _вриј, پیگن_, 
   {{0xa2d409d9,0xe644010a,0x7e9c00de,0x00000000}},	//   _मुश्, _тейп, _kāpš, --, 
   {{0x2b480198,0x6498014b,0x66e401af,0x00000000}},	//   ɗace_, _атор_, _йоһа, --, 
  
   {{0xd0040aa8,0xb60400d0,0xff0801e1,0xe610009f}},	// [6000] иете_, ťšty, _ẹ̀kú_, _اشڪ_, 
   {{0x2b98020c,0x00000000,0x00000000,0x00000000}},	//   _kècu_, --, --, --, 
   {{0x9e644fdb,0xed5801a6,0xd5ac57e6,0xa5c402d2}},	//   рвед, _bbž_, _رفی_, _glóá, 
   {{0xdc282ea3,0x6b800998,0x399802ea,0x00000000}},	//   نسته_, _anlg, _yésu_, --, 
   {{0x7d04005f,0x93c801d3,0x46cc00c5,0x00000000}},	//   žiso, _سایہ_, _सँझह, --, 
   {{0xda6426c0,0x39980008,0xcb4801ec,0x00000000}},	//   لابي, _lést_, шiрi, --, 
   {{0x3eac05ac,0xc0d4001f,0x9a8457e7,0x00000000}},	//   _ådt_, ያውም_, рулл, --, 
   {{0x5b3400db,0x3998013a,0x00000000,0x00000000}},	//   _چعار, _nést_, --, --, 
   {{0xa7fc002d,0x5b34009f,0x00000000,0x00000000}},	//   rwűn, _نعار, --, --, 
   {{0x7bc801fa,0x00000000,0x00000000,0x00000000}},	//   _ujdu, --, --, --, 
   {{0x7bd857e8,0xa2d405d7,0x6f78008f,0x46642f59}},	//   movu, _मुल्, אָרג, арям_, 
   {{0x7bd857e9,0x5bb457ea,0x00000000,0x00000000}},	//   lovu, _अगुव, --, --, 
   {{0xf164063f,0x14c80108,0x62880248,0x00000000}},	//   shị̀_, тыни_, _àfoj, --, 
   {{0x7bd857eb,0x87d0004b,0x8898011a,0x00000000}},	//   novu, _وغوا, _בבדי, --, 
   {{0x07a0033a,0x00000000,0x00000000,0x00000000}},	//   _фајн, --, --, --, 
   {{0x7bd857ec,0x66143afd,0xd498024c,0x0584010a}},	//   hovu, ízke, _аро_, _дуьм, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [6010] --, --, --, --, 
   {{0xed5801a6,0x7bd801b9,0x00000000,0x00000000}},	//   _sbž_, jovu, --, --, 
   {{0x27e823db,0x7bd857ed,0xecc40032,0xddcc0427}},	//   _ɗan_, dovu, әшеү, _srbš, 
   {{0x7e7803b2,0x00000000,0x00000000,0x00000000}},	//   ævpa, --, --, --, 
   {{0x65a42242,0x8f080124,0x656000e4,0x8c64113e}},	//   _jóha, _ахба_, _ñohe, ртед, 
   {{0x7bd8014b,0xf54001e1,0x00000000,0x00000000}},	//   govu, _ṣẹlẹ, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x26c805a1,0xdce400de,0x6db400db,0x00000000}},	//   _ćao_, ņmāc, _уйбу, --, 
   {{0xe8f857ee,0x7bd80213,0xddcc3e9d,0x00000000}},	//   ыли_, bovu, _urbš, --, 
   {{0x399857ef,0x255c57f0,0x46600075,0x61180270}},	//   _béss_, _mālō_, قۇتق, mālō, 
   {{0x64580356,0x00000000,0x00000000,0x00000000}},	//   ătim, --, --, --, 
   {{0x26cc0421,0x7afc09e8,0x00000000,0x00000000}},	//   _āloā_, _úrta, --, --, 
   {{0x399800bc,0xdce004a7,0x4424033b,0x00000000}},	//   _vést_, rdoć, èm_, --, 
   {{0x3998002e,0x9cd4011a,0xe9a4010a,0x00000000}},	//   _féss_, מורה_, _каçп, --, 
   {{0xdb0800d8,0x00000000,0x00000000,0x00000000}},	//   tifú, --, --, --, 
   {{0x7bd857f1,0xa06857f2,0xa52457f3,0x00000000}},	//   zovu, лаба_, _умид, --, 
   {{0x7bd857f4,0x656457f5,0x60e857f6,0xdb0801e3}},	// [6020] yovu, mekh, умам_, mnfö, 
   {{0x656457f7,0xc33005a9,0x00000000,0x00000000}},	//   lekh, _زەر_, --, --, 
   {{0x644457f8,0xe29857f9,0x6298005b,0xbad400d1}},	//   luki, _сан_, ätod, _ﭘﺎﺋﺎ, 
   {{0x7bd8090c,0x65644a7d,0x9cc800b1,0x00000000}},	//   wovu, nekh, лыла_, --, 
   {{0x644457fa,0x7bd80579,0x61f41368,0x8c40084c}},	//   nuki, tovu, mmyl, зече, 
   {{0x65643bc9,0xdca40116,0xdfd057fb,0x00000000}},	//   hekh, _һаби, _ريز_, --, 
   {{0x644457fc,0x7bd857fd,0xaa8000ee,0x2ba800e1}},	//   huki, rovu, _öýle, _कतरा, 
   {{0x644457fe,0xd90c57ff,0x2b98067c,0x61f40649}},	//   kuki, ریت_, _bècs_, nmyl, 
   {{0xd1f00020,0x64440a49,0x6564090c,0x7bd85800}},	//   ፍሪቃ_, juki, dekh, povu, 
   {{0x64445801,0x2b38084c,0x8d5c0092,0x6e300166}},	//   duki, _вяцэ_, _ሰምተው_, _äkbä, 
   {{0x65640117,0xa45400d7,0x00000000,0x00000000}},	//   fekh, víšť_, --, --, 
   {{0x6564124c,0x64445802,0x6f005803,0xdb085804}},	//   gekh, fuki, _úlce, gnfö, 
   {{0x64445805,0x399801c7,0xd87400cf,0x89d4009f}},	//   guki, _wéss_, _دااب, _اونر_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x65640928,0x64440153,0xb5940108,0x00000000}},	//   bekh, auki, _микш, --, 
   {{0x61f40354,0x55040137,0x00000000,0x00000000}},	//   gmyl, _учка, --, --, 
   {{0x64445806,0x00000000,0x00000000,0x00000000}},	// [6030] cuki, --, --, --, 
   {{0xcee821e7,0x00000000,0x00000000,0x00000000}},	//   هران_, --, --, --, 
   {{0xa3d45807,0xa5340166,0x00000000,0x00000000}},	//   िकर_, _унөч, --, --, 
   {{0x65b41ebd,0xcd285808,0x85300198,0x00000000}},	//   tšhi, اسان_, _koɗa, --, 
   {{0xdb080036,0xef100137,0x91a400e5,0x6cc401a9}},	//   chfë, _жүзө, _ننھے_, ўйла, 
   {{0x656400aa,0x00000000,0x00000000,0x00000000}},	//   zekh, --, --, --, 
   {{0x65645809,0x6444580a,0xcc8403e6,0x00000000}},	//   yekh, zuki, _گۆشه_, --, 
   {{0x6444580b,0xaa8000a2,0x3da40150,0x00000000}},	//   yuki, _öýme, _еруб, --, 
   {{0xe7a80108,0xe88400d4,0x00000000,0x00000000}},	//   ивил_, ігоп, --, --, 
   {{0x6444580c,0x6d58127b,0x65642939,0xe7380063}},	//   vuki, lfwa, wekh, јен_, 
   {{0x6564580d,0x6444580e,0x8aa4580f,0x9f480100}},	//   tekh, wuki, _урад, _kibò_, 
   {{0x64445810,0x7c240311,0x9f480139,0x00000000}},	//   tuki, ţire, _sibü_, --, 
   {{0x65645811,0xdb085812,0x69c85813,0x65a401e1}},	//   rekh, rnfö, mnee, _fóhn, 
   {{0x64445814,0x65642747,0x69c85815,0x61d0041c}},	//   ruki, sekh, lnee, थक्ष, 
   {{0x69c85816,0xdb080158,0x656400e5,0x00000000}},	//   onee, rifø, pekh, --, 
   {{0x69c85817,0x64445818,0x6d5801a4,0xdb080162}},	//   nnee, puki, jfwa, sifø, 
   {{0x69c85819,0x6444581a,0x7d042b57,0x00e42e3e}},	// [6040] inee, quki, žisk, ستری, 
   {{0x69c8581b,0x61f43129,0x9f4800db,0x6d58002f}},	//   hnee, smyl, _ribó_, efwa, 
   {{0x69c80ba7,0x65a40174,0x7a300162,0x6d58581c}},	//   knee, _jóho, _mótá, ffwa, 
   {{0x69c80218,0x9f480ffb,0xa3b40764,0x29180156}},	//   jnee, _cibò_, चोर_, ñsal_, 
   {{0x4c10581d,0x69c8581e,0xaf34581f,0xdef80032}},	//   وبوس, dnee, زرەت, уыҡ_, 
   {{0x69c85820,0x67200427,0xdb18036e,0x7a305821}},	//   enee, jblj, _imtë, _nótá, 
   {{0x19a82928,0x69c80ba7,0xdea003e6,0x6d5802d0}},	//   итип_, fnee, _تیای, bfwa, 
   {{0x8d605822,0x3f985823,0x6d5803ac,0x69d400e5}},	//   _овсе, _horu_, cfwa, _ízel, 
   {{0xa3c80490,0x00000000,0x00000000,0x00000000}},	//   लचा_, --, --, --, 
   {{0x69c85824,0x0b4009a5,0x7a300332,0x3f980254}},	//   anee, _онун, _cótá, _joru_, 
   {{0x3f9807f5,0x69c85825,0x00000000,0x00000000}},	//   _moru_, bnee, --, --, 
   {{0x94a8006c,0x3f985826,0xd5b8072c,0x69c80014}},	//   атга_, _loru_, рсо_, cnee, 
   {{0xa3d40882,0x3f980ca8,0x4df80677,0x00000000}},	//   िकं_, _ooru_, יפטא, --, 
   {{0xfbbc5827,0x3f985828,0x83840108,0x00000000}},	//   ्चिम, _noru_, мысе, --, 
   {{0x2450036b,0xdce00171,0x00000000,0x00000000}},	//   وچیس, deoč, --, --, 
   {{0x30140fb5,0x77680009,0x00000000,0x00000000}},	//   здар, ledx, --, --, 
   {{0x8424167e,0xd2d805f9,0xdc64001f,0xfbbc18cc}},	// [6050] _قىين, _मुरझ, ደነበረ_, ्चाम, 
   {{0xa2d45829,0x3f980ffb,0xa3d400dc,0x6aac01e4}},	//   _मुक्, _coru_, िकः_, ŝafi, 
   {{0x752c582a,0x69c8582b,0x3f98582c,0x6d581cea}},	//   _keaz, ynee, _doru_, tfwa, 
   {{0x6d580e78,0x672001a6,0x69c80009,0xe80c00bc}},	//   ufwa, zblj, xnee, सदमा_, 
   {{0x69c80070,0x3f98582d,0x7648582e,0x7c840063}},	//   vnee, _foru_, hudy, дује, 
   {{0x76481557,0x3f980552,0xfbd003e6,0x316801c4}},	//   kudy, _goru_, پته_, leaz_, 
   {{0x69c8582f,0xa9a401d5,0x8cb803ce,0x00000000}},	//   tnee, зийд, _शेरो, --, 
   {{0xa2cc3806,0x69c85830,0x316801c4,0x00000000}},	//   _सशस्, unee, neaz_, --, 
   {{0x69c85831,0x3f9801a9,0x7a3000e5,0x00000000}},	//   rnee, _yoru_, _pótá, --, 
   {{0x69c85832,0x3f98022e,0x00000000,0x00000000}},	//   snee, _xoru_, --, --, 
   {{0x752c5833,0x76485834,0x67205835,0x7a3000c6}},	//   _beaz, gudy, rblj, _vótá, 
   {{0xa2d40825,0xcfcc08b0,0x69c80449,0x3168005a}},	//   _मुग्, ﻛﺮﺍﺗ, qnee, jeaz_, 
   {{0x3168009d,0x4adc0037,0x764800c0,0x00000000}},	//   deaz_, _पुतव, audy, --, 
   {{0xa3b40034,0x89d401d5,0xd36c01c8,0x2214003b}},	//   चों_, _اوچر_, ههُ_, зфар, 
   {{0xa2d42ce6,0xb92801f2,0xe8100dad,0x232801d5}},	//   _मुख्, _ngwụ_, _डंडा_, _қони_, 
   {{0x65b4000a,0x3f980365,0x7d040006,0xe5240209}},	//   tšhu, _soru_, žisi, _эдип, 
   {{0xb92802e3,0x00000000,0x00000000,0x00000000}},	// [6060] _agwụ_, --, --, --, 
   {{0x65745836,0xe3b05837,0x85ac4668,0xdfd0007b}},	//   _hayh, _سرخ_, _चतुः, ريض_, 
   {{0x3f9800fc,0xa2e4016c,0x65745838,0x316801c4}},	//   _voru_, _хонд, _kayh, beaz_, 
   {{0x21000006,0x6574022e,0x3f980de2,0x00000000}},	//   _ačiū_, _jayh, _woru_, --, 
   {{0x3f985839,0x6574583a,0x00000000,0x00000000}},	//   _toru_, _mayh, --, --, 
   {{0xdbd401e1,0x657406be,0xdd9000f1,0x00000000}},	//   _bùáy, _layh, _ګور_, --, 
   {{0x9d540137,0xe810012d,0xda780395,0x00000000}},	//   _ىنست, _डूबा_, сял_, --, 
   {{0xdd90021a,0x830c025c,0xdb080793,0x65740455}},	//   _ثور_, _ཁུའུ_, lifü, _nayh, 
   {{0x752c583b,0x7768003e,0xd7e40006,0x699c0037}},	//   _reaz, tedx, зіно, _ओकरी, 
   {{0x7648583c,0x316801c6,0x752c0810,0xfb84583d}},	//   tudy, zeaz_, _seaz, _تدری, 
   {{0x65740656,0x2130089c,0x0f540bd9,0x752c002d}},	//   _bayh, kayh_, היים_, _peaz, 
   {{0x7648583e,0x2130017a,0x3168005a,0x00000000}},	//   rudy, jayh_, xeaz_, --, 
   {{0xd7f817a2,0xe794583f,0x65740432,0x31680165}},	//   _лук_, سایک, _dayh, veaz_, 
   {{0x0838025f,0xb4bc38bf,0x63bc010a,0x752c002d}},	//   _פעול, _आधी_, _cmpn, _weaz, 
   {{0xdb085840,0xc3305841,0xd1385842,0x316801c0}},	//   lifó, دەپ_, йха_, teaz_, 
   {{0x66c000c7,0x550400db,0x2ba85843,0x00000000}},	//   _шәыж, _эчка, _कत्थ, --, 
   {{0x057419c5,0x31685844,0xbec400e2,0x7414178c}},	// [6070] _سايد, reaz_, _šūpu, _توخا, 
   {{0xdb0801b8,0xedc42d3b,0x3168005a,0x00000000}},	//   gifü, लच्छ, seaz_, --, 
   {{0xa3c801ad,0xc7d4011a,0xf4841e7c,0x00000000}},	//   लचर_, לומי_, _راکی, --, 
   {{0x93240214,0xa2d444d0,0x30140798,0x291803e0}},	//   _برکن, _मुट्, _одмр, ısak_, 
   {{0xdd8c5845,0xeb985846,0x00000000,0x00000000}},	//   شوو_, жил_, --, --, 
   {{0x82344144,0x2bdc194b,0x4478011a,0x00000000}},	//   _تریا, यवधा, פעול_, --, 
   {{0x5fa00150,0xa2d400dc,0xda6c009f,0x00000000}},	//   _جەلم, _मुञ्, لُو_, --, 
   {{0xfbd004a9,0x00000000,0x00000000,0x00000000}},	//   پتۇ_, --, --, --, 
   {{0x657435f6,0x2bdc084d,0x00000000,0x00000000}},	//   _rayh, यवदा, --, --, 
   {{0x66140232,0x1b9801d9,0x657401a9,0x00000000}},	//   ízko, _وصلک_, _sayh, --, 
   {{0xc9845847,0xa5340137,0x65745848,0x00000000}},	//   _нуди, үнүч, _payh, --, 
   {{0xdce00342,0x65740139,0xe5a4254f,0x00000000}},	//   ndoğ, _qayh, фими, --, 
   {{0xe7380cfc,0xa2d405dc,0x69c4003e,0x5b240022}},	//   _дел_, _मुज्, éheu, _хьӡа, 
   {{0xdb085849,0xe7300214,0xe64402dd,0xf7940153}},	//   lifò, _شصت_, _жекп, _пачэ, 
   {{0x21744166,0x848c02d3,0x6574584a,0xdce00790}},	//   муар, _ቅዋምን_, _tayh, kdoğ, 
   {{0xdb080ba1,0x00000000,0x00000000,0x00000000}},	//   nifò, --, --, --, 
   {{0x91e0584b,0x6ac8193d,0xe3b80798,0xdce00139}},	// [6080] тоте, िपुर, _мби_, ddoğ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe124084c,0xa2d400dc,0xdb0803e0,0x00000000}},	//   _омни, _मुच्, rifü, --, 
   {{0x6444132e,0x1d080353,0x00000000,0x00000000}},	//   orki, цеди_, --, --, 
   {{0x4ac0069f,0xdb08067c,0x613c0419,0x00000000}},	//   _वेबव, difò, rálč, --, 
   {{0x6ac81b61,0x28e00cb4,0x6ea801d9,0x64440067}},	//   िपूर, _पड़ि, _کنِہ_, irki, 
   {{0xee7c0020,0x19f40a81,0x00000000,0x00000000}},	//   _የሚኖሩ_, وِتھ_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd7f8010b,0xb4bc0034,0x497001e0,0x00000000}},	//   жун_, _आधे_, тлыс, --, 
   {{0x4c98011a,0x00000000,0x00000000,0x00000000}},	//   _ובמו, --, --, --, 
   {{0x6444584c,0xf42000fe,0x2af40064,0xbbbc0b8f}},	//   erki, _বিধৰ_, _зяцё, ्चीक, 
   {{0x24841ebd,0xdb08067c,0xd94400f0,0xb8e40154}},	//   _šoma_, cifò, _цеди, _এড_, 
   {{0x6aac0115,0xdb2001e1,0xa3c801f9,0x00000000}},	//   ŝaft, _òróf, लचं_, --, 
   {{0x7d0401e4,0xdce00205,0x00000000,0x00000000}},	//   ɾist, zdoğ, --, --, 
   {{0xdce005d1,0x00000000,0x00000000,0x00000000}},	//   ydoğ, --, --, --, 
   {{0x11641b12,0x00000000,0x00000000,0x00000000}},	//   بلری_, --, --, --, 
   {{0x7ae80ac8,0x4034584d,0xb63802dd,0x2444030d}},	// [6090] _lydt, кетс, _ﺘﻘ_, _пĕтс, 
   {{0x2c0c0c58,0x64580311,0x00000000,0x00000000}},	//   _হবলৈ_, ătit, --, --, 
   {{0x2bdc584e,0x59dc0846,0x00000000,0x00000000}},	//   यवसा, मवार, --, --, 
   {{0x2d880428,0xecf8584f,0x709400f3,0x00000000}},	//   ñae_, пееш_, _замф, --, 
   {{0x6b645850,0x62885851,0xa3b40316,0xe2a401a8}},	//   екла, _àfor, चोक_, öðva_, 
   {{0x77780175,0xdce003e0,0x00000000,0x00000000}},	//   _navx, sdoğ, --, --, 
   {{0xdb1801ed,0x2ca805be,0xdb08067c,0x23d0043e}},	//   _ajtó, šad_, tifò, _सदसद, 
   {{0x2bdc0da5,0x6444148b,0x8d7402ef,0xa9e400f1}},	//   यवहा, yrki, _غازا, رګان, 
   {{0x3178006d,0xa80416c3,0xcc14034c,0x4adc5852}},	//   _masz_, нзил, _آذرب, _पुरव, 
   {{0xbc6800ae,0x8aa4011c,0x00000000,0x00000000}},	//   _تمكن_, _оред, --, --, 
   {{0x65c4250c,0x236400df,0x2c1401ad,0x99c80014}},	//   ебна, _ĝoj_, _फंडू_, _کُنے_, 
   {{0x3178068f,0xdb08002d,0x79a40139,0xa5080395}},	//   _nasz_, chfâ, _ирче, яема_, 
   {{0x64440014,0xd99401f7,0x999414fa,0x00000000}},	//   urki, _سنوت_, _سپور_, --, 
   {{0x64445853,0xc7c40395,0x00000000,0x00000000}},	//   rrki, _юсеи, --, --, 
   {{0x80ec11ba,0xe2985854,0xc5f8014b,0x00000000}},	//   _কলেজ_, чав_, _оғо_, --, 
   {{0xb6380150,0x91e0068e,0x00000000,0x00000000}},	//   _ﺘﺘ_, госе, --, --, 
   {{0x64a45855,0xa0085856,0xdfd05857,0x9f845858}},	// [60a0] _чапа, سقال_, هير_, нгад, 
   {{0x44205859,0xe3b800d8,0x00000000,0x00000000}},	//   _iti_, _хбо_, --, --, 
   {{0xe1f0585a,0x4420585b,0x21a40022,0x2f1401d3}},	//   _مسح_, _hti_, _зинм, _súgó_, 
   {{0x44200652,0x5f040139,0x00000000,0x00000000}},	//   _kti_, _үзма, --, --, 
   {{0x61e4003d,0xdbcc0724,0x7ae8005c,0x10a0014b}},	//   _ikkl, nıçl, _sydt, _биян, 
   {{0xcb0400b2,0x44202c10,0xa3d42d8f,0x77a400cf}},	//   ڙيون_, _mti_, िकट_, _tòxi, 
   {{0x69040cc1,0x4420585c,0x2008058a,0x4ac0146b}},	//   ərdə, _lti_, _iibi_, _वेदव, 
   {{0x4420585d,0xdbd000af,0x09e00a5b,0xdbcc008e}},	//   _oti_, lüüs, лојн, kıçl, 
   {{0x4420585e,0x20085141,0x399801ed,0x7ae80af9}},	//   _nti_, _kibi_, _kész_, _wydt, 
   {{0x2008585f,0x7ae8017a,0xdbd00037,0x00000000}},	//   _jibi_, _tydt, nüüs, --, 
   {{0x44205860,0x2008015c,0x36d4013e,0x399800e5}},	//   _ati_, _mibi_, тонр, _mész_, 
   {{0x20085861,0x00000000,0x00000000,0x00000000}},	//   _libi_, --, --, --, 
   {{0x938800a7,0x49980375,0xd610004e,0xdbcc013d}},	//   псва_, _משאב, _өзлө, gıçl, 
   {{0x44205862,0x3fc40f22,0x20080cad,0xa92002d2}},	//   _dti_, ্তুষ, _nibi_, _íþre, 
   {{0xa784034c,0x1b1003d4,0x31780210,0x00000000}},	//   _جشنو, _সজাই_, _pasz_, --, 
   {{0x20085863,0x2460016b,0xfa700023,0x00000000}},	//   _aibi_, _wɔma_, _በይነይ_, --, 
   {{0x20085864,0x8f44010b,0xdbd00037,0x00000000}},	// [60b0] _bibi_, ехед, füüs, --, 
   {{0x61e45865,0x20085866,0x3178012d,0x00000000}},	//   _ekkl, _cibi_, _wasz_, --, 
   {{0x7c2000a2,0x44f400f1,0x4adc00cd,0xfe700014}},	//   _atmr, _لسیز, _पुंव, ٝدن_, 
   {{0x20080083,0x76485867,0x44200240,0xfd105868}},	//   _eibi_, irdy, _yti_, مجه_, 
   {{0x6ac8085c,0x20080393,0xa3d40073,0x7648002f}},	//   िप्र, _fibi_, िकच_, hrdy, 
   {{0x2008079d,0xdca05869,0x447c0375,0xfc30007b}},	//   _gibi_, раши, פנוע, صحه_, 
   {{0xfbd0009f,0x00000000,0x00000000,0x00000000}},	//   حتن_, --, --, --, 
   {{0x7a8400f1,0x1dc0013d,0xe968586a,0x2008586b}},	//   اشوم, _көчн, фаил_, _zibi_, 
   {{0x2d8c43cc,0x6b74586c,0x7648015d,0x2008586d}},	//   _inee_, _илау, erdy, _yibi_, 
   {{0x4420586e,0xa6840046,0x4aa801ed,0xe618586f}},	//   _rti_, влод, _ٹائپ_, мдо_, 
   {{0x44205870,0x81e802f5,0x2d8c5871,0xf42000fe}},	//   _sti_, যগত_, _knee_, _বিষৰ_, 
   {{0x442015f5,0x64a401a9,0x00000000,0x00000000}},	//   _pti_, вама, --, --, 
   {{0xf9905872,0x76485873,0xf770029e,0xe798007b}},	//   _دبل_, ardy, _گان_, _يختص_, 
   {{0x44200393,0xdbcc0724,0x61e40162,0x7ae40356}},	//   _vti_, rıçl, _skkl, şite, 
   {{0xf7705874,0x20085875,0x399801ed,0x44200142}},	//   _دان_, _ribi_, _rész_, _wti_, 
   {{0x20085876,0x44205877,0x2d8c5878,0xe448007b}},	//   _sibi_, _tti_, _nnee_, _قلبى_, 
   {{0xd12c0014,0xa2cc2356,0x7528005a,0x60080120}},	// [60c0] زمل_, _सशक्, ñeze, днам_, 
   {{0x2d8c5879,0x2008022e,0xdb08007c,0x5f4400cf}},	//   _anee_, _qibi_, mifö, ئنال, 
   {{0xe1f854eb,0xdb08014a,0xdbd00254,0x00000000}},	//   _ого_, lifö, rüüs, --, 
   {{0x21a4587a,0x2008020c,0x00000000,0x00000000}},	//   _римм, _wibi_, --, --, 
   {{0x20080de4,0xef902be7,0x0c700137,0xdb080793}},	//   _tibi_, _گیلد, لدود, nifö, 
   {{0x2d8c587b,0x5c3c0240,0x00000000,0x00000000}},	//   _enee_, _ኣይገር, --, --, 
   {{0x2cb006be,0x9d9000ec,0xef900066,0x00000000}},	//   _əzdi_, _پڇاڻ, _دیلد, --, 
   {{0xc0cc001f,0x2d8c0036,0x65a40241,0x4b8400ee}},	//   _በርስ_, _gnee_, _kóhu, ейән_, 
   {{0x62980419,0xade40064,0x00000000,0x00000000}},	//   ätoj, _сцёк, --, --, 
   {{0x7b840150,0xf6980114,0x82400092,0xf42000fe}},	//   _حارە, евој_, _ክፍተቶ, _বিলৰ_, 
   {{0x8f34008f,0x65a40241,0xd6d81429,0x00000000}},	//   כטיג_, _lóhu, ьти_, --, 
   {{0x98e4587c,0x00000000,0x00000000,0x00000000}},	//   _июлд, --, --, --, 
   {{0x5f0000cd,0x00000000,0x00000000,0x00000000}},	//   वेत्_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4394587d,0x82a400a8,0x02a4587e,0x00000000}},	//   шарс, аште, артм, --, 
   {{0x3fc4045e,0x9ac0025c,0x00000000,0x00000000}},	//   ্তোষ, ċċho, --, --, 
   {{0x53440022,0x62980158,0x00000000,0x00000000}},	// [60d0] _ихна, øtor, --, --, 
   {{0x4ea4587f,0x6e94100b,0x3374399b,0x2d8c5880}},	//   креа, лизу, _сгор, _snee_, 
   {{0x3dc40036,0xdeb001ec,0x00000000,0x00000000}},	//   _bmmw_, бұры, --, --, 
   {{0x65a401e1,0x00000000,0x00000000,0x00000000}},	//   _fóhu, --, --, --, 
   {{0xd1c80020,0xfeb804fb,0xdde00309,0x00000000}},	//   _በሽታ_, _یافت_, ñušp, --, 
   {{0x649c2791,0x00000000,0x00000000,0x00000000}},	//   lçiç, --, --, --, 
   {{0xbea401a9,0x00000000,0x00000000,0x00000000}},	//   _каёк, --, --, --, 
   {{0x2d8c009a,0x987c0213,0x649c15b7,0x00000000}},	//   _unee_, _açır_, nçiç, --, 
   {{0xe73818ce,0xe5a401b9,0xdb0801e3,0xa2c81fc4}},	//   неп_, ҳини, xifö, _हेन्, 
   {{0xfa340ccb,0xbb5400cf,0x00000000,0x00000000}},	//   _چرند, _ەنەب, --, --, 
   {{0xe5a45881,0x29180165,0x8ae400d4,0x00000000}},	//   гини, ñsas_, _ріал, --, 
   {{0xdb0801b8,0xa5740014,0xc0cc0092,0x00000000}},	//   tifö, چُھت, _በርሱ_, --, 
   {{0x69c82301,0x00000000,0x00000000,0x00000000}},	//   miee, --, --, --, 
   {{0xdb0836d5,0x65a40248,0x00000000,0x00000000}},	//   rifö, _róhu, --, --, 
   {{0x61445882,0x21680131,0x27e401e6,0x69d401d3}},	//   лева, ниви_, moln_, _ízes, 
   {{0x69c85883,0x66e40139,0x00000000,0x00000000}},	//   niee, _иоһа, --, --, 
   {{0x1f645884,0xe0d85885,0x69c8011f,0x20c80214}},	// [60e0] лкам, хва_, iiee, ربري_, 
   {{0x5bd000dc,0x69c85886,0x00000000,0x00000000}},	//   _तदेव, hiee, --, --, 
   {{0x69c85887,0x00000000,0x00000000,0x00000000}},	//   kiee, --, --, --, 
   {{0xa07400ee,0x00000000,0x00000000,0x00000000}},	//   _йыгш, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdee45888,0xcc84015e,0x00000000,0x00000000}},	//   _боги, انوه_, --, --, 
   {{0xc0cc02d3,0x69c80d47,0xa2c80303,0x00000000}},	//   _በርሀ_, fiee, _हेम्, --, 
   {{0x69c800af,0x39145889,0x0c20588a,0x00000000}},	//   giee, шмир, шмән, --, 
   {{0x978001d5,0xb81400d8,0x00000000,0x00000000}},	//   ییچه, јдој, --, --, 
   {{0x588401e0,0xfce41188,0x00000000,0x00000000}},	//   _ҡыла, _боғо, --, --, 
   {{0x69c801f5,0x00000000,0x00000000,0x00000000}},	//   biee, --, --, --, 
   {{0x69c80196,0x68ec01d3,0x00000000,0x00000000}},	//   ciee, öndí, --, --, 
   {{0xc84000ee,0x86e001d5,0x00000000,0x00000000}},	//   _гечй, _қўшд, --, --, 
   {{0x27e400b5,0xb9f00023,0x7afc0162,0x00000000}},	//   coln_, _ዓሻ_, _úrts, --, 
   {{0xf1c835ac,0x27e8010f,0x00000000,0x00000000}},	//   نوسى_, _ŭang_, --, --, 
   {{0x1af403d4,0x9a3c0092,0x00000000,0x00000000}},	//   _চলাই_, _አይነቱ, --, --, 
   {{0x2f18023a,0x1014588b,0x649c0205,0x628800e5}},	// [60f0] возь_, ابرد, rçiç, _áfon, 
   {{0x69c8588c,0x3ce800e1,0x63ac0076,0x7f5800c7}},	//   ziee, _जड़े_, ckbn, лаус_, 
   {{0x0dc810f3,0xc4f800f2,0x00000000,0x00000000}},	//   нуди_, _لعیا_, --, --, 
   {{0xdb080036,0x00000000,0x00000000,0x00000000}},	//   ckfé, --, --, --, 
   {{0xa91c588d,0x52740131,0x6b7400db,0x00000000}},	//   ndže, _شاھز, илду, --, 
   {{0xd1e40020,0x00000000,0x00000000,0x00000000}},	//   ሚዎች_, --, --, --, 
   {{0xa91c01fa,0x69c801a4,0x4ea4457e,0x3f6401af}},	//   hdže, tiee, _ёрга, _утяб, 
   {{0x6844588e,0x629802f6,0x00000000,0x00000000}},	//   аниа, ätoi, --, --, 
   {{0xa91c2d2b,0x69c8588f,0xe8f85890,0xac184109}},	//   jdže, riee, ъли_, _розу_, 
   {{0x69c80151,0x5ea00137,0x7ae40356,0x66e4011c}},	//   siee, _دۅۅل, şita, иопа, 
   {{0x2c1c03f4,0x69c85891,0xe81002ab,0xdb2402f2}},	//   _নিয়ে_, piee, _डंका_, _ئومی, 
   {{0x2d9c124c,0xfaa40372,0xf98800ec,0x00000000}},	//   njwe_, _ушун, _ٽنهي_, --, 
   {{0x67d45892,0x27e409a8,0x75285893,0x00000000}},	//   _коду, poln_, ñeza, --, 
   {{0xaaa8584e,0x00000000,0x00000000,0x00000000}},	//   _कथाक, --, --, --, 
   {{0x02c85894,0xdb08002f,0x9f5c0248,0x00000000}},	//   уқни_, chfä, _òté_, --, 
   {{0x5bd00882,0x2b445895,0xe04400d1,0x7c24054e}},	//   _तद्व, _ldlc_, инби, ţiri, 
   {{0xa91c009b,0x00000000,0x00000000,0x00000000}},	// [6100] cdže, --, --, --, 
   {{0x200c0793,0x3f840064,0x00000000,0x00000000}},	//   öfi_, _ėmus_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69d801af,0x69300882,0x9cc80124,0x00000000}},	//   _njwe, _ṣaṣṭ, кыла_, --, 
   {{0x6e28151c,0x9f4801a8,0xb0f8009d,0x00000000}},	//   _čebe, ðjón_, _бэрх_, --, 
   {{0x69d8014b,0x705003e6,0x00000000,0x00000000}},	//   _ajwe, _رۆما, --, --, 
   {{0x2d9c01ee,0x1d940024,0xb78800fb,0xda780395}},	//   bjwe_, _краё, ғәле_, тял_, 
   {{0x0b400139,0x9bd40022,0x00000000,0x00000000}},	//   бнән, ыцҵш, --, --, 
   {{0x481048bd,0x75fc01d3,0x00000000,0x00000000}},	//   омыс, néze, --, --, 
   {{0xcb640276,0x158801ec,0x00000000,0x00000000}},	//   _вафе_, _ﯗﻣﺘﯩ, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdbd4006a,0x58844077,0xc8c45896,0x059851ae}},	//   _käïn, _выка, اوین_, لمپک_, 
   {{0xdfe406b1,0x75fc0419,0x00000000,0x00000000}},	//   कवाद_, vézd, --, --, 
   {{0xdbd42776,0xc3480598,0xa91c041a,0x91e400b5}},	//   _mäïn, иясе_, rdže, _kgでx, 
   {{0xd5b801f0,0x00000000,0x00000000,0x00000000}},	//   _асп_, --, --, --, 
   {{0x75d401f7,0x5184004e,0xb11421fe,0x94a800d8}},	//   _ديبا, шуга, смаш, _атоа_, 
   {{0xd7a8130b,0x753c5897,0x75fc00d2,0x7bc85898}},	// [6110] _चकाच, masz, géze, _omdu, 
   {{0x753c00f8,0x4394030d,0x00000000,0x00000000}},	//   lasz, _даьс, --, --, 
   {{0x824002d3,0x2d9c192e,0x7ed40066,0x238800d7}},	//   _ክፍልታ, tjwe_, يزما, ťujú_, 
   {{0x7bc80117,0xac185899,0x753c01ed,0xbd6806bd}},	//   _amdu, году_, nasz, ирче_, 
   {{0x6298589a,0x69d80076,0xbc4806ed,0xdb1801e3}},	//   ätov, _rjwe, ачје_, _omtä, 
   {{0x753c01ed,0xda9401c6,0x6e9400d8,0xfbc400d4}},	//   hasz, өгчө, _лигу, обіо, 
   {{0x753c514a,0xa9a4457e,0xde4401e2,0xadbc0064}},	//   kasz, йикд, _هیلو_, _завi, 
   {{0x7bc8014b,0xdcb400fd,0x82d802e4,0xae5400ec}},	//   _emdu, ргәч_, יווג_, _پرڳڻ, 
   {{0xcc84168d,0x6d5851b0,0x753c1f6f,0x8880036b}},	//   _خۆشه_, mgwa, dasz, تیشن, 
   {{0x2794075b,0x00000000,0x00000000,0x00000000}},	//   сшир, --, --, --, 
   {{0x66e4589b,0x69d800d2,0xa6c8589c,0x6b8003ac}},	//   сона, _tjwe, улна_, _ialg, 
   {{0x6d58589d,0x6b80589e,0x753c01ed,0x2ce40327}},	//   ngwa, _halg, gasz, _སྙོབ, 
   {{0x6b80589f,0x6d580810,0xdd78008f,0xe6104c12}},	//   _kalg, igwa, נטשל, _کشت_, 
   {{0x6b8058a0,0xf7840014,0x18a00107,0xa6940114}},	//   _jalg, _ولنَ, _хашм, _гриј, 
   {{0x6d5858a1,0x753c58a2,0x00000000,0x00000000}},	//   kgwa, basz, --, --, 
   {{0x6b800793,0xb90800b8,0x75fc01d3,0x00000000}},	//   _lalg, _ariṃ_, téze, --, 
   {{0x6d580113,0x6b80127b,0xe2f801ec,0x00000000}},	// [6120] dgwa, _oalg, теңі_, --, 
   {{0x6b8058a3,0x2a68033f,0x67200010,0xe2c800f1}},	//   _nalg, łaby_, nclj, _موخو_, 
   {{0xf424031c,0x9e6447cf,0x6d580042,0xd00c31b1}},	//   _འཕོད_, свед, fgwa, رلم_, 
   {{0x6e340399,0x6d582f99,0x9d140154,0xdc2800f2}},	//   _dwzb, ggwa, ার্ন_, هسته_, 
   {{0x6b8058a4,0x6f1401a6,0x9f940254,0x00000000}},	//   _balg, _fgzc, _küüs_, --, 
   {{0x6d5804ba,0x753c58a5,0xdb18005c,0xda6401f7}},	//   agwa, zasz, _omtå, مابي, 
   {{0x6b8058a6,0x9a8458a7,0x9f940037,0x3eac01bf}},	//   _dalg, сулл, _müüs_, _ædt_, 
   {{0x1d0858a8,0x6b800332,0x9f940254,0x6d58035a}},	//   _беби_, _ealg, _lüüs_, cgwa, 
   {{0x6b8058a9,0x753c01ed,0x1c440209,0x89d40014}},	//   _falg, vasz, _ынам, صوٝر_, 
   {{0x6b8058aa,0x7bc858ab,0x38a002b5,0x6ba401d9}},	//   _galg, _umdu, _rōrā_, _وصلٕ, 
   {{0x753c179a,0xdb04054e,0x00000000,0x00000000}},	//   tasz, şmân, --, --, 
   {{0x6b8058ac,0x00000000,0x00000000,0x00000000}},	//   _zalg, --, --, --, 
   {{0x753c58ad,0x8b00012c,0x6b8000fd,0xddcc00e2}},	//   rasz, ěřen, _yalg, _apbū, 
   {{0xb6c801d3,0x67fc007f,0x6b8006be,0x00000000}},	//   _پاتے_, tèje, _xalg, --, 
   {{0xd90c58ae,0x753c00dd,0x56f005f5,0xa91c05be}},	//   _تیک_, pasz, _хүнс, ldža, 
   {{0xd49811eb,0xc2c41b80,0x660402d0,0x00000000}},	//   _бро_, سيقي, cmkk, --, 
   {{0xa91c58af,0x5ea40eac,0xbb280150,0xc0141214}},	// [6130] ndža, _গেলে, _زﯨﺪۇ, змущ, 
   {{0xd34435cd,0xa91c0153,0x9f9400ee,0xae1c000d}},	//   _دیسه_, idža, _tüýs_, _बंदन_, 
   {{0x6b8058b0,0x0dc00023,0x00000000,0x00000000}},	//   _ralg, _ጹሑፍ_, --, --, 
   {{0x6b8058b1,0x4ac00574,0x7bd80083,0x934000d1}},	//   _salg, _वेगव, envu, _بىھۇ, 
   {{0x6d5858b2,0x7ae40365,0x6b80007d,0xa91c1aff}},	//   rgwa, şitl, _palg, jdža, 
   {{0x1ae000bd,0x7bd805d5,0x6b8058b3,0x6d5858b4}},	//   গেছে_, gnvu, _qalg, sgwa, 
   {{0x6b8058b5,0x6d5802d0,0x9ba000db,0x00000000}},	//   _valg, pgwa, بەلى, --, 
   {{0x6b8058b6,0x31682035,0x7bd80af9,0x7c2400df}},	//   _walg, nfaz_, anvu, ŭira, 
   {{0x6d4858b7,0xbdf80592,0xcdc008b0,0x00000000}},	//   _idea, _طرفا_, _даңқ, --, 
   {{0x31680369,0x6b8001ab,0x6fc803e3,0xfaa800ec}},	//   hfaz_, _ualg, _böcə, _گهمي_, 
   {{0xf4240135,0x998401fa,0x00000000,0x00000000}},	//   _འཕུད_, žiše_, --, --, 
   {{0xa50803b7,0x00000000,0x00000000,0x00000000}},	//   иена_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe6c400ae,0x00000000,0x00000000,0x00000000}},	//   _وتغي, --, --, --, 
   {{0x31680ac5,0x61381677,0x57200137,0xd7900ef8}},	//   ffaz_, ичар_, _تۉپك, _زليخ, 
   {{0x6d4858b8,0x00000000,0x00000000,0x00000000}},	//   _ndea, --, --, --, 
   {{0xa2c802f8,0x9fc805f5,0x6e2858b9,0x00000000}},	// [6140] _हेर्, агаа_, _čeba, --, 
   {{0x6d4858ba,0x75fc0077,0x62984f63,0x00000000}},	//   _adea, méza, ätos, --, 
   {{0x6d480334,0x75fc58bb,0x21680063,0x21a41246}},	//   _bdea, léza, _кини_, _динм, 
   {{0xb8fc003d,0x6d481529,0x00000000,0x00000000}},	//   _རྨ_, _cdea, --, --, 
   {{0x6d4858bc,0x10a001b9,0x61f4010b,0x00000000}},	//   _ddea, _жиян, mlyl, --, 
   {{0x61f458bd,0x6d4858be,0x5f7458bf,0xa3b80316}},	//   llyl, _edea, _باحر, अघि_, 
   {{0x6d48010a,0x68f40213,0x7bd805c7,0x00000000}},	//   _fdea, əzdi, rnvu, --, 
   {{0xdd9058c0,0xdcb007a7,0x61f400ee,0x38640356}},	//   _تور_, _قىز_, nlyl, ttmr_, 
   {{0xed340323,0x61f4005b,0x91b8010f,0xa2c400cc}},	//   _хэсэ, ilyl, ימקי, _এডোখ, 
   {{0x31680007,0xdb08002d,0x00000000,0x00000000}},	//   zfaz_, rkfâ, --, --, 
   {{0xa2c858c1,0x9a0800b8,0x61f400ee,0x00000000}},	//   _हेल्, _aṃśe, klyl, --, 
   {{0x18680b7b,0x19f80276,0x00000000,0x00000000}},	//   _вади_, _тэзь_, --, --, 
   {{0x97a400f3,0x00000000,0x00000000,0x00000000}},	//   _мркл, --, --, --, 
   {{0xa7fc01d3,0xc0e00092,0x00000000,0x00000000}},	//   ltűn, ኒክስ_, --, --, 
   {{0xd13806bb,0xf62800cf,0x3134014b,0x9f5801f4}},	//   иха_, _اتتۇ_, зебр, impä_, 
   {{0x61f400ee,0x00000000,0x00000000,0x00000000}},	//   glyl, --, --, --, 
   {{0x316804cf,0x25f8012c,0x6fb8023b,0x62980419}},	// [6150] rfaz_, ैगरी_, бгар_, ätor, 
   {{0x59c80c2e,0x31680798,0x4e880138,0x00000000}},	//   ़ोतर, sfaz_, ищем_, --, 
   {{0xbf140116,0x00000000,0x00000000,0x00000000}},	//   дүрә, --, --, --, 
   {{0x60c8002e,0x317800df,0x00000000,0x00000000}},	//   ëmmé, _פאָד, --, --, 
   {{0xfd1058c2,0x320858c3,0x6d48009a,0xab28236b}},	//   نجه_, mmay_, _vdea, бола_, 
   {{0x320858c4,0x447c00c8,0xf7780327,0xdbd40254}},	//   lmay_, ינדע, jeħ_, jääb, 
   {{0x8d7458c5,0x320858c6,0x8eb01c3e,0x7e44010a}},	//   _وارا, omay_, _تەات, _охте, 
   {{0x320814dc,0x6d4801bf,0x7c381427,0x00000000}},	//   nmay_, _udea, ðarú, --, 
   {{0x5b1058c7,0x320803ac,0x00000000,0x00000000}},	//   ммәт, imay_, --, --, 
   {{0x320858c8,0x3b5400f7,0x8a74014b,0x2cbc4283}},	//   hmay_, _окур, _мизӣ_, ızdı_, 
   {{0xdb241547,0xc98458c9,0x320858ca,0x00000000}},	//   _رونی, _муди, kmay_, --, 
   {{0x600000d8,0x320803ac,0x59c8012d,0xba743769}},	//   môme, jmay_, ़ोदर, _تاكت, 
   {{0x320814dc,0x600006ed,0xb5280241,0x00000000}},	//   dmay_, lôme, _gbọ̀, --, 
   {{0x3208127b,0x00000000,0x00000000,0x00000000}},	//   emay_, --, --, --, 
   {{0x600006ed,0x61f400ee,0x3208035a,0xc1e40150}},	//   nôme, tlyl, fmay_, _ﺍﻓﺭﺍ, 
   {{0x320851e2,0x75fc0077,0xe29858cb,0xe1f801d5}},	//   gmay_, péza, _ғам_, ёга_, 
   {{0x61f458cc,0x55b80375,0xdce00205,0x00000000}},	// [6160] rlyl, _למקו, deoğ, --, 
   {{0x320858cd,0x437401ec,0x75fc01d3,0x00000000}},	//   amay_, _تۇسر, nézn, --, 
   {{0x644458ce,0x320858c6,0x53340a1e,0xfbac03d4}},	//   lski, bmay_, _מנין_, কোঁত, 
   {{0x320858cf,0xa06858d0,0x60000120,0x644458d1}},	//   cmay_, _лама_, dôme, oski, 
   {{0xcca000d1,0xaf3400d1,0x00000000,0x00000000}},	//   ىڭكى, سرەت, --, --, 
   {{0x661433d8,0x644458d2,0x60000798,0x7e980451}},	//   _liyk, iski, fôme, _وچار_, 
   {{0xd35400c8,0x7528005a,0x00000000,0x00000000}},	//   ליסי_, ñezk, --, --, 
   {{0x644458d3,0x661402d1,0x67fc0100,0xa5c002d2}},	//   kski, _niyk, vèja, _þóha, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6000315a,0x6444045a,0x320858d4,0x6e340ca8}},	//   lômb, dski, zmay_, _ìgbì, 
   {{0x320814dc,0xb6f806ba,0x46640212,0x35540633}},	//   ymay_, تىدا_, прям_, وندز, 
   {{0x18a458d5,0xd5b8074d,0xdb180200,0x3208127b}},	//   _наем, ссо_, _oltë, xmay_, 
   {{0x644458d6,0x320858d7,0x00000000,0x00000000}},	//   gski, vmay_, --, --, 
   {{0xc7a058d8,0x75fc0306,0x07a00024,0x320858d9}},	//   _пичк, cézn, _пачн, wmay_, 
   {{0x320814dc,0x644458da,0x629800d0,0x9a880092}},	//   tmay_, aski, ätop, ናውኗል_, 
   {{0x320858db,0x644458dc,0x116401b9,0xbb700150}},	//   umay_, bski, ثلری_, _ﺴﻤﻴﻪ_, 
   {{0x32082f05,0x84240e26,0x2a940241,0x30140062}},	// [6170] rmay_, _كىين, _ḿba_, ддар, 
   {{0x32082f05,0x3f9800ca,0xd3a400f5,0x7ff400d1}},	//   smay_, _cnru_, _хрип, ىسلا, 
   {{0x75fc0306,0x3208127b,0x9268030d,0x00000000}},	//   nézo, pmay_, _урпа_, --, 
   {{0x32085310,0x6fb801f9,0x00000000,0x00000000}},	//   qmay_, _इतकं, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x600058dd,0x26240421,0xfc301b45,0x75fc004d}},	//   tôme, _lēoa_, احن_, kézo, 
   {{0x3a2c0204,0xa9a401b9,0x291801e4,0xfd1015bf}},	//   _ctdp_, дийд, ɾsaj_, نجۇ_, 
   {{0x3a2c0077,0x8d7402dd,0x644458de,0x75fc0077}},	//   _dtdp_, _عازا, yski, dézo, 
   {{0x3a2c58df,0x66140113,0x600000d8,0xab8000cf}},	//   _etdp_, _riyk, sôme, _لۇشۉ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6444068f,0x75fc58e0,0xb8640101,0x00000000}},	//   wski, gézo, وایو, --, 
   {{0x644405ce,0xe9440502,0xdb1858e1,0x00000000}},	//   tski, _آرای, _altè, --, 
   {{0x64440aec,0x00000000,0x00000000,0x00000000}},	//   uski, --, --, --, 
   {{0x753400c7,0x00000000,0x00000000,0x00000000}},	//   _ҧэых, --, --, --, 
   {{0x65c458e2,0x2fc001ab,0xa18802e8,0x67fc007f}},	//   _обка, dhhg_, обва_, lèjo, 
   {{0xe1f802d5,0xe45858e3,0xc0e80014,0x00000000}},	//   іга_, _джи_, ۪کھٕ_, --, 
   {{0xd5ac06f6,0x5040004e,0x9f8458e4,0x7ae403e0}},	// [6180] _خفي_, кетб, мгад, ğiti, 
   {{0xffa401c6,0xdb1803b2,0x934058e5,0x7ae40205}},	//   элзү, _umtø, _инье, şiti, 
   {{0x442058e6,0x6000006a,0xa20402bf,0x61e80a87}},	//   _hui_, tômb, _опод, _íflo, 
   {{0x44204c21,0x60244c70,0x249000a2,0x205427a8}},	//   _kui_, _одма, _krym_, _отгр, 
   {{0x442058e7,0x307458e8,0x628c03b2,0xdb18036e}},	//   _jui_, _пурс, lvbo, _ultë, 
   {{0x442058e9,0x4c9058ea,0xdee401af,0x00000000}},	//   _mui_, тишс, _жоги, --, 
   {{0x442058eb,0xfb1801d9,0xdea002f2,0x00000000}},	//   _lui_, _ہراں_, _جیای, --, 
   {{0x44202047,0x09e010fc,0x00000000,0x00000000}},	//   _oui_, којн, --, --, 
   {{0x442058ec,0xf4d803f4,0xb8140b3e,0x7994013d}},	//   _nui_, _সর্ব, ндиј, _җилф, 
   {{0x90980bd9,0xccb000c7,0x00000000,0x00000000}},	//   קסיק, _шәхь, --, --, 
   {{0x442058ed,0x0f540302,0x249055e3,0xa3c00cb4}},	//   _aui_, ויים_, _arym_, ंसन_, 
   {{0x442058ee,0x7c2058ef,0xd49858f0,0x00000000}},	//   _bui_, _kumr, орг_, --, 
   {{0x442058f1,0x394458f2,0x7c200687,0xdb18004a}},	//   _cui_, mams_, _jumr, _alté, 
   {{0x442058f3,0x39441d64,0xdb0801a8,0x75fc58f4}},	//   _dui_, lams_, rkfæ, pézo, 
   {{0x7c200d51,0x86c058f5,0x24900165,0x59b003e5}},	//   _lumr, _ليون, _erym_, _जवार, 
   {{0x442058f6,0x394458f7,0x2490036e,0xdbd401f4}},	//   _fui_, nams_, _frym_, _hään, 
   {{0x7c2058f8,0x442058f9,0xdbd4049b,0x249058fa}},	// [6190] _numr, _gui_, _kään, _grym_, 
   {{0xdbd418db,0xd34458fb,0xa2c858fc,0xfaf800e2}},	//   _jään, _زیره_, _हेक्, _acīm_, 
   {{0x394458fd,0x7c20039a,0x76481477,0x4420004d}},	//   kams_, _aumr, nsdy, _zui_, 
   {{0x394458fe,0xdbd4007d,0xad240075,0x2490010e}},	//   jams_, _lään, رىتى, _yrym_, 
   {{0xeb981607,0x7c2058ff,0x39441039,0xab283acc}},	//   зил_, _cumr, dams_, пола_, 
   {{0x32180851,0x7c205900,0xab281a92,0xdbd40108}},	//   _hisy_, _dumr, чока_, _nään, 
   {{0x32180109,0xa3c013f7,0xdb080e78,0xfbd01e24}},	//   _kisy_, ्फत_, chfü, جتن_, 
   {{0x39445901,0x764821e3,0x8d745902,0xbd7800d4}},	//   gams_, dsdy, _تاسا, _обсє_, 
   {{0x32180875,0x7c205903,0x7648014b,0x6b7412b9}},	//   _misy_, _gumr, esdy, _плау, 
   {{0x442023e0,0x32185904,0xf4d80c58,0x24900200}},	//   _rui_, _lisy_, _সৰ্ব, _rrym_, 
   {{0x44205905,0x7c205906,0x7648007c,0x39440153}},	//   _sui_, _zumr, gsdy, bams_, 
   {{0x32185907,0x442000a8,0xe5a45908,0x3944005f}},	//   _nisy_, _pui_, хими, cams_, 
   {{0x26c45909,0x7c20022f,0xf8840032,0xe3b00f1c}},	//   szlo_, _xumr, _аҡыл_, هرآ_, 
   {{0x442001dc,0x66e4590a,0x3218020c,0x764801bf}},	//   _vui_, _пола, _aisy_, bsdy, 
   {{0xf770590b,0x291c0770,0x32180109,0x44200134}},	//   _خان_, _kgwa_, _bisy_, _wui_, 
   {{0x4420590c,0xe1f0006c,0x7afc03cd,0x2490590d}},	//   _tui_, اسآ_, _ørte, _trym_, 
   {{0xdef81772,0x00000000,0x00000000,0x00000000}},	// [61a0] ላይን_, --, --, --, 
   {{0x321805da,0x6000007f,0x7c20590e,0xd7d0590f}},	//   _eisy_, fôma, _rumr, धोपच, 
   {{0x7c205910,0x32185911,0xdb18004a,0x291c2252}},	//   _sumr, _fisy_, _ulté, _ogwa_, 
   {{0x291c05db,0x7c200477,0x3944004e,0xa0a430ab}},	//   _ngwa_, _pumr, xams_, _замд, 
   {{0x7c205912,0x39440006,0x2c68002d,0x3fc82099}},	//   _qumr, vams_, gúd_, _قدسی_, 
   {{0x291c5913,0x24c000cc,0x00000000,0x00000000}},	//   _agwa_, _উশাহ, --, --, 
   {{0x39445914,0xd004084c,0xdee45915,0xf7780327}},	//   tams_, _чере_, _чови, jnħa_, 
   {{0xdbd4049b,0x7c20034c,0x75fc01ed,0xdee401b9}},	//   _sään, _tumr, tézm, _жоҳи, 
   {{0x39445916,0xd7f85917,0xdbd4023a,0x49700220}},	//   rams_, зун_, _pään, улыс, 
   {{0x291c0337,0x95f837cc,0x76485918,0x487001ec}},	//   _egwa_, ृष्ट_, tsdy, اديس, 
   {{0xd6d85919,0xdbd416b5,0xab68591a,0x3944591b}},	//   яти_, _vään, _تحقق_, pams_, 
   {{0xea882264,0x291c0083,0xaa400131,0xcba00124}},	//   _زخمن_, _ggwa_, _ئۆيى, _ақәҿ, 
   {{0xc8b0591c,0xe124015b,0x629803cd,0xe99400ec}},	//   _مصوب, বরাহ_, åton, _جهنگ, 
   {{0x5ea400bd,0x7ae40276,0x16480131,0x7648143a}},	//   _গেছে, şitu, _ечип_, psdy, 
   {{0xa3c003ce,0x00000000,0x00000000,0x00000000}},	//   ्फ़_, --, --, --, 
   {{0x34940124,0xdb0801e3,0x00000000,0x00000000}},	//   _ааир, ckfå, --, --, 
   {{0xcde000c7,0x00000000,0x00000000,0x00000000}},	// [61b0] ҳәаҿ, --, --, --, 
   {{0x752c03f9,0x60000120,0x3448014b,0x00000000}},	//   _hfaz, tôma, _нӯҳи_, --, 
   {{0x7ff40220,0x00000000,0x00000000,0x00000000}},	//   اسقا, --, --, --, 
   {{0x81e400fe,0xe1600046,0x00000000,0x00000000}},	//   _পীঠ_, _ەگەي, --, --, 
   {{0x752c4242,0xbd441b45,0x628801a8,0xdde00356}},	//   _mfaz, انهي, _áfor, _ţuţu, 
   {{0x82340517,0xa91c591d,0xfd1000c6,0x68f80042}},	//   _جریا, mdži, حجم_, _rywd, 
   {{0xa91c02d5,0xda60224f,0x37c80183,0x68f80142}},	//   ldži, авщи, ৰকাৰ, _sywd, 
   {{0x7c241682,0xa91c0006,0x00000000,0x00000000}},	//   ̭iri, odži, --, --, 
   {{0xa91c02d5,0xe7381914,0x00000000,0x00000000}},	//   ndži, меп_, --, --, 
   {{0xa91c0006,0x752c0798,0xd0440213,0xd7ec00c6}},	//   idži, _afaz, çməs, يكي_, 
   {{0x1bc80014,0x4ebc0154,0x1c1800c5,0xe974009a}},	//   _تُلی_, _আশুল, _फूटल_, _لهاد, 
   {{0x291c0223,0xa91c591e,0x00000000,0x00000000}},	//   _ugwa_, kdži, --, --, 
   {{0x850c130b,0xa91c0558,0x7ae403e0,0x00000000}},	//   सेंट_, jdži, şitt, --, 
   {{0xa6941f5a,0x25f00073,0x00000000,0x00000000}},	//   _ариј, ीतही_, --, --, 
   {{0xbb3c001f,0x38c402b1,0x468001b9,0x21680131}},	//   _ጭንቅላ, rūrū_, _ёқма, миви_, 
   {{0xc1740198,0x7c240115,0x00000000,0x00000000}},	//   kiɗe_, ŭiri, --, --, 
   {{0xa3c044ab,0x64a400c0,0xa91c591f,0x00000000}},	// [61c0] ंसद_, _рапа, gdži, --, 
   {{0xe2980640,0x92600066,0x00000000,0x00000000}},	//   _жао_, دگیم, --, --, 
   {{0xa91c0064,0x5d680108,0x00000000,0x00000000}},	//   adži, дием_, --, --, 
   {{0xa91c5920,0x00000000,0x00000000,0x00000000}},	//   bdži, --, --, --, 
   {{0x66140030,0x00000000,0x00000000,0x00000000}},	//   ízky, --, --, --, 
   {{0x75fc01d3,0x5f0400db,0xa3c01a75,0x0b900116}},	//   tézk, _азга, ंसि_, لجىد, 
   {{0x60000109,0x2d94009d,0x00000000,0x00000000}},	//   lômo, _өртс, --, --, 
   {{0xa91c013a,0x00000000,0x00000000,0x00000000}},	//   ježd, --, --, --, 
   {{0xa3c0216a,0xa91c2a4f,0x752c01d5,0xdb180332}},	//   ंसा_, dežd, _rfaz, _iltí, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7bd85921,0xa91c02d5,0xdddc0306,0x00000000}},	//   mivu, zdži, tupň, --, 
   {{0xf43400ee,0x00000000,0x00000000,0x00000000}},	//   лемэ, --, --, --, 
   {{0x79805922,0x98a421fe,0x75fc5923,0x20080064}},	//   memw, _шиде, nézi, _ohbi_, 
   {{0x7bd85924,0x9f98007d,0x61e4025c,0xdb1806ea}},	//   nivu, _jääb_, _ajkl, _umtó, 
   {{0xd1b82115,0x237c0037,0x00000000,0x00000000}},	//   وارا_, õtja_, --, --, 
   {{0x20080327,0x79800083,0x7bd8005b,0x00000000}},	//   _ahbi_, nemw, hivu, --, 
   {{0x7bd85925,0xa91c02d5,0x349402d5,0x53e40022}},	// [61d0] kivu, udži, _сапр, _ацна, 
   {{0xdb180579,0x7bd800ec,0xa91c5926,0x798002ce}},	//   _altí, jivu, rdži, hemw, 
   {{0xa91c5927,0x999c02b1,0x7e285928,0xa3c046c7}},	//   leže, _autō_, віча_, ्फर_, 
   {{0x61e400c6,0x1ee85929,0x798007a8,0x00000000}},	//   _gjkl, رونی_, jemw, --, 
   {{0x60000120,0x7bd80194,0x8c64592a,0xa91c0010}},	//   cômo, fivu, ттед, neže, 
   {{0x7bd8592b,0x8f6401ed,0x6b640733,0x00000000}},	//   givu, _جلسے_, укка, --, 
   {{0xee900050,0x8d840124,0x3b6400a7,0x5fa000db}},	//   _دۯاک, _иуад, ръчв, _دەلم, 
   {{0x7980592c,0x7bd8017a,0xdcac004b,0x00000000}},	//   gemw, aivu, _ډډه_, --, 
   {{0x7bd8592d,0xa91c1e31,0xbdf8592e,0xe8f8592f}},	//   bivu, ježe, _شرفا_, эли_, 
   {{0xa91c151c,0x7bd85930,0x2d8c5931,0xa68401c6}},	//   deže, civu, _haee_, глод, 
   {{0xe5685932,0x25f00490,0xf4080154,0x00000000}},	//   ىمدى_, ीतली_, লদার_, --, 
   {{0x64a45933,0x2b440156,0x00000000,0x00000000}},	//   гама, _helc_, --, --, 
   {{0x2d8c0270,0x4424001e,0x2b440489,0xf8680b24}},	//   _maee_, êm_, _kelc_, _لمني_, 
   {{0x20540184,0xe6c40592,0x970000d1,0x186426b1}},	//   ҫтар, _متعي, _گېپى, _саши_, 
   {{0x1fb40220,0x2b445934,0x00000000,0x00000000}},	//   қсар, _melc_, --, --, 
   {{0x7bd85935,0xa3c00073,0x9f5c01e1,0x00000000}},	//   zivu, ंसह_, _òtú_, --, 
   {{0x7bd85936,0x60085937,0x10a05938,0x64740724}},	// [61e0] yivu, енам_, битн, _сыйф, 
   {{0x5f4400f7,0x79801446,0x29e402b5,0x00000000}},	//   انال, zemw, kēao_, --, 
   {{0x79805939,0x1e94593a,0x2d8c593b,0xe0440131}},	//   yemw, ырар, _baee_, _әнги, 
   {{0x65640652,0x21a4593c,0x7bd84539,0x2b4400db}},	//   ngkh, _симм, wivu, _aelc_, 
   {{0xf1d4593d,0x25b0062c,0x00000000,0x00000000}},	//   _төрө, _moyl_, --, --, 
   {{0xa91c04a7,0x7980593e,0x2b440042,0x75fc593f}},	//   ndžu, wemw, _celc_, rézi, 
   {{0x79805940,0x2d8c1132,0x2b4405c7,0xa91c1710}},	//   temw, _faee_, _delc_, ježb, 
   {{0x5f042b42,0x75fc5941,0x5d1401d9,0x2d9400d8}},	//   _азҳа, pézi, _مِزا, _крус, 
   {{0x79805942,0x2b44030a,0xe92402d3,0x7bd85943}},	//   remw, _felc_, _ተታሒዞ, pivu, 
   {{0x79805944,0x2b905945,0x2b4405c7,0x7bd80194}},	//   semw, _وینس, _gelc_, qivu, 
   {{0xa91c5946,0x25b0002d,0x61f45947,0xcff4011a}},	//   veže, _boyl_, koyl, רציה_, 
   {{0x2b440165,0x61f45948,0x00000000,0x00000000}},	//   _zelc_, joyl, --, --, 
   {{0xa91c15ad,0x00000000,0x00000000,0x00000000}},	//   teže, --, --, --, 
   {{0xb7d8211f,0xccf0011a,0x00000000,0x00000000}},	//   _جوتا_, מכר_, --, --, 
   {{0xa91c0f03,0x9f5c063f,0x00000000,0x00000000}},	//   reže, _òtù_, --, --, 
   {{0xa91c151c,0x81d44258,0x733400d1,0x00000000}},	//   seže, босх, _ھىجا, --, 
   {{0x2d8c0395,0xc3c400f7,0xee900092,0xa91c33e9}},	// [61f0] _raee_, рөөл, _የሚመጣ_, peže, 
   {{0xb4c02413,0xcee81178,0x00000000,0x00000000}},	//   ंनी_, ىران_, --, --, 
   {{0xa3c0068f,0x2d8c5949,0xdb080fac,0x61f4594a}},	//   ंसर_, _paee_, ckfø, boyl, 
   {{0x80d01b51,0x645800e2,0xdd380356,0x2b444a43}},	//   _ठेके, ņtie, _răţo, _selc_, 
   {{0x2d8c0270,0x6e28594b,0x2b440165,0x00000000}},	//   _vaee_, _čebu, _pelc_, --, 
   {{0xbc38594c,0x2d8c020c,0xfd10007b,0x1b0c03d4}},	//   اسنا_, _waee_, سجن_, িখনে_, 
   {{0x2d8c0093,0x2b440171,0x00000000,0x00000000}},	//   _taee_, _velc_, --, --, 
   {{0xa924322e,0xc82002d3,0xa91c00f3,0x8d7401ec}},	//   шдил, _ተኣማን, vežb, _حاسا, 
   {{0x8b644f3d,0x2b44594d,0x2d2001ad,0x291801e3}},	//   _ماام, _telc_, यशील_, äsa_, 
   {{0x262402b5,0xa7b40640,0xead4030d,0x753c0112}},	//   _hēoi_, рсиј, _козь, ebsz, 
   {{0x98a8005f,0x6d44013f,0x25b00076,0xf8a80424}},	//   ēmām_, ɔhar, _poyl_, ندیه_, 
   {{0xa91c09a8,0xc17403f9,0xb9e40212,0x752800e4}},	//   režb, kiɗa_, _лічи, ñezp, 
   {{0x69c81190,0xa3c002a0,0x61f40072,0x00000000}},	//   mhee, ंसल_, voyl, --, 
   {{0x69c84747,0x8dc802dd,0x00000000,0x00000000}},	//   lhee, _ﻓﻠﺴﻁ, --, --, 
   {{0x753c01ed,0x61f4594e,0x28d8375c,0x8da00150}},	//   bbsz, toyl, _बेति, _ﺍﺗﺎﻕ_, 
   {{0x69c8594f,0xe57800c7,0xc1740198,0xb90800b8}},	//   nhee, _рзи_, fiɗa_, _asiṃ_, 
   {{0x61f45950,0x69c85951,0xdb080b1a,0x2a9400ef}},	// [6200] royl, ihee, skfø, _lāb_, 
   {{0x69c85952,0x1e945953,0x61f41368,0x48e003d4}},	//   hhee, ирер, soyl, _পৰৱৰ, 
   {{0x1e845954,0x69c80014,0xdb185955,0x7e4800e5}},	//   рлем, khee, _oltá, اسطہ_, 
   {{0x61f4047e,0x81e40154,0x00000000,0x00000000}},	//   qoyl, _পীর_, --, --, 
   {{0x69c8423f,0xc214013b,0x1ee807d6,0x00000000}},	//   dhee, mmɔ_, روچی_, --, 
   {{0xdb185956,0x4c1000db,0x69c801f4,0x9e645957}},	//   _altá, يبوس, ehee, _پاسن, 
   {{0x237805b1,0xa3bc00e1,0xc0c40116,0x753c033f}},	//   _mbpj_, _आवन_, _тәңи, ybsz, 
   {{0x69c85958,0xdce00219,0x5c3401b9,0x753c0175}},	//   ghee, lgoč, _نفرط, xbsz, 
   {{0x2d9809c2,0x57a421fa,0xbb540133,0x61e802d2}},	//   _ósea_, ашна, _هۆشب, _íflu, 
   {{0xdb1801ed,0x69c80067,0x0b340092,0x00000000}},	//   _eltá, ahee, ከናወኑ, --, 
   {{0x69c80099,0x7d0000ad,0xdddc02b1,0x3cb800fe}},	//   bhee, _hyms, hupō, _অধিৱ, 
   {{0x69c85959,0xd5b800cf,0x00000000,0x00000000}},	//   chee, тсо_, --, --, 
   {{0xb4c0006d,0x38bc01e1,0x7d000076,0xa3c001bc}},	//   ंने_, _dárú_, _jyms, ंसं_, 
   {{0x13a400dd,0xf4080131,0x7d000175,0x03c4022e}},	//   جنسی_, ايسى_, _myms, оссм, 
   {{0x7d0002f0,0xf1580395,0x00000000,0x00000000}},	//   _lyms, ливш_, --, --, 
   {{0xa91c595a,0xb60800a2,0xc0980023,0x00000000}},	//   leža, _dušý, ፈልጡን_, --, 
   {{0xf8b8257b,0x00000000,0x00000000,0x00000000}},	// [6210] ेनिय, --, --, --, 
   {{0x667036bd,0x69c80072,0xa3c000cd,0xbf3800d4}},	//   _بگیر, zhee, ंसः_, изує_, 
   {{0xed3401c0,0x4e8802e8,0x4ea4009d,0x00000000}},	//   бэлэ, ъщам_, шраа, --, 
   {{0x69c801d4,0x225c0030,0x32142ca8,0x00000000}},	//   xhee, átke_, çayı_, --, 
   {{0x3168054e,0x69c80076,0x00000000,0x00000000}},	//   mgaz_, vhee, --, --, 
   {{0x69c8595b,0xa91c4473,0xd6c42088,0x3168083c}},	//   whee, ježa, _فق_, lgaz_, 
   {{0x0d640c04,0x69c8595c,0x7d00032e,0x2d9401ee}},	//   _възм, thee, _eyms, _гөлө_, 
   {{0x2bd85572,0x31684af6,0xfaf800e2,0xa9a40116}},	//   _भगवा, ngaz_, _acīs_, сиид, 
   {{0x69c8595d,0x7d00595e,0xb4c00490,0x75fc01d3}},	//   rhee, _gyms, ंनो_, hézs, 
   {{0x69c8595f,0x7dc80793,0x6d481368,0x38bc007b}},	//   shee, _gÿsb, _heea, _sárú_, 
   {{0xe6185960,0x6d480731,0x69c80a55,0xdb1802d2}},	//   лдо_, _keea, phee, _altæ, 
   {{0xc098044e,0x6d480731,0x1b180183,0x00000000}},	//   ፈልጥን_, _jeea, নুহে_, --, 
   {{0x69d85961,0xa91c005f,0x6d480363,0xf8a80345}},	//   _imwe, beža, _meea, _ندوه_, 
   {{0x6d485962,0x3168005a,0x4ad800ab,0x00000000}},	//   _leea, egaz_, _बधाव, --, 
   {{0x21a40120,0xa86401af,0x00000000,0x00000000}},	//   бивм, _теҙҙ, --, --, 
   {{0x31680099,0x6d480363,0x2724063f,0xdddc0374}},	//   ggaz_, _neea, ịndu_, tupō, 
   {{0x69d85963,0x10a0418d,0xdfe85964,0xfbb8190c}},	// [6220] _mmwe, питн, гдад_, _अवलम, 
   {{0x7d0008c8,0x316801c6,0x6e280010,0xbfc800d1}},	//   _ryms, agaz_, _čebr, جارە_, 
   {{0x60000261,0x69d85965,0x6d481368,0x28d82c35}},	//   nômi, _omwe, _beea, _बेसि, 
   {{0x6d4807a8,0xa3bc0490,0x00000000,0x00000000}},	//   _ceea, _आवड_, --, --, 
   {{0x6d485966,0x7170215c,0x2a940241,0x2140007f}},	//   _deea, _تۇقا, _ḿbu_, čshč_, 
   {{0xdca40364,0x69d85967,0xac240826,0x59280327}},	//   _қази, _amwe, іфік, _ྤུངས_, 
   {{0xa91c5968,0x6d481368,0x69d80fac,0xfe7003e6}},	//   veža, _feea, _bmwe, _زگا_, 
   {{0x38340d08,0x8328025c,0x6d481368,0x28d805f9}},	//   онир, _ཡུའུ_, _geea, _बेहि, 
   {{0x8c400ea7,0xe28c01a9,0xc0980023,0x00000000}},	//   _нете, _lsа_, ፈልጦን_, --, 
   {{0x69d85969,0x9e9002d3,0x857405f5,0x6d4801f5}},	//   _emwe, _ቃልስና_, үлэх, _zeea, 
   {{0x6d480731,0xa91c08a4,0x7bc8596a,0xdb08002f}},	//   _yeea, reža, _ildu, nkfü, 
   {{0xceb0025f,0xa91c0841,0x00000000,0x00000000}},	//   לית_, seža, --, --, 
   {{0xa91c596b,0xd7f8036b,0xdff813e0,0x25ec012d}},	//   ležn, _йук_, ्ताद_, घवजी_, 
   {{0x75fc0998,0x00000000,0x00000000,0x00000000}},	//   tézs, --, --, --, 
   {{0x69d80cfd,0xd5b806bb,0x600000d8,0x75d44c02}},	//   _ymwe, _бсп_, cômi, _ويتا, 
   {{0x463804ac,0xdb18013d,0x00000000,0x00000000}},	//   _געהע, _iltä, --, --, 
   {{0x7bc8596c,0x614420ea,0xe28c01a9,0x6d480363}},	// [6230] _oldu, زىلە, _esа_, _reea, 
   {{0x6d480076,0x00000000,0x00000000,0x00000000}},	//   _seea, --, --, --, 
   {{0xa91c1711,0xa3bc033d,0x6d4800ad,0xd39400fb}},	//   ježn, _आवत_, _peea, _кәңә_, 
   {{0x7bc8596d,0xa91c151c,0x00000000,0x00000000}},	//   _aldu, dežn, --, --, 
   {{0x6d48596e,0xe9e80030,0xdb0803b2,0x00000000}},	//   _veea, nkúš_, kkfó, --, 
   {{0xeb98596f,0x40345970,0x6d480009,0xaed401c6}},	//   рик_, _херс, _weea, _догш, 
   {{0x853003f9,0x2d9804d4,0xe46c02b5,0xdb080112}},	//   _haɗe, _óseo_, iōāō, ckfü, 
   {{0x7bc85971,0x2be8009e,0x9b5400d1,0xa8540063}},	//   _eldu, গতেই_, биәт_, отој, 
   {{0xdb1802c1,0x48c40011,0xca5002dd,0x00000000}},	//   _altä, শপ্র, _ﻋﺩﺩ_, --, 
   {{0x60000120,0xaa58023a,0xa91c5972,0x6ab0009e}},	//   tômi, _вижу_, bežn, জনবো, 
   {{0x28d81715,0xfd6400b8,0xaa94084c,0x7cf40118}},	//   _बेरि, _aguṇ, _фиеч, _výrů, 
   {{0x69d85973,0x78a40063,0xed580010,0xe5a400a8}},	//   _umwe, _šive, _jdž_, цими, 
   {{0xe91800d6,0x24083946,0xed5802f0,0xbbd40244}},	//   _тоді_, инми_, _mdž_, _بڕۆک, 
   {{0xe7385974,0xdce002b5,0xa91c0841,0xf7940006}},	//   _тек_, ngoā, ležo, _начэ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa03405a9,0x05940133,0xa91c00d7,0x00000000}},	//   قىرت, _رابگ, nežo, --, 
   {{0xdef81ef7,0x74f8009d,0x00000000,0x00000000}},	// [6240] ዋይን_, _гээс_, --, --, 
   {{0xd00c4bf3,0x64545975,0x853002a8,0xdb18005b}},	//   پلم_, _ivyi, _daɗe, _yltä, 
   {{0xd37800c8,0x00000000,0x00000000,0x00000000}},	//   _דריט, --, --, --, 
   {{0xa3c01533,0xa0685976,0xa0a45977,0xa91c0841}},	//   ंसक_, _кама_, _дамд, ježo, 
   {{0x71702302,0x629c107d,0xa3bc0037,0xa91c01a6}},	//   _سۇلا, _hrpo, _आवा_, dežo, 
   {{0x6454019f,0x629c07f5,0x631c0154,0x00000000}},	//   _mvyi, _krpo, _ব্যয়_, --, 
   {{0xe51800cd,0x539800df,0x8ee401f4,0x00000000}},	//   नेति_, שיצו, _дмрв_, --, 
   {{0xa91c151c,0xa3bc00af,0x0d80009d,0x00000000}},	//   režn, _आवऽ_, _олсн, --, 
   {{0xa91c1a48,0xd8380006,0xac780023,0x00000000}},	//   sežn, шэй_, _ጥሒሶም_, --, 
   {{0x7bc803be,0x629c0c8c,0xa91c3831,0xfcc400d1}},	//   _uldu, _orpo, pežn, _мәһм, 
   {{0x6454019f,0xa91c5978,0x00000000,0x00000000}},	//   _avyi, bežo, --, --, 
   {{0xaae400f2,0x00000000,0x00000000,0x00000000}},	//   _عسلو, --, --, --, 
   {{0x629c5979,0x57b001ec,0x645802e2,0xb78801af}},	//   _arpo, _жұпт, ņtin, _ләне_, 
   {{0xf7780003,0x00000000,0x00000000,0x00000000}},	//   biħa_, --, --, --, 
   {{0x645400ca,0x0ef803ce,0x00000000,0x00000000}},	//   _evyi, _्रेस_, --, --, 
   {{0x225c02fd,0x9f58067c,0x116407d6,0xb03419ba}},	//   átka_, lopè_, تلری_, знаш, 
   {{0x629c597a,0x9324009a,0x00000000,0x00000000}},	// [6250] _erpo, _وردن, --, --, 
   {{0xb9f0044e,0x7ff4009a,0xadd800d1,0x46400092}},	//   _ናጻ_, وسلا, әмду_, _የተጠራ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa134008d,0x62e80014,0xc0580024,0x00000000}},	//   _מארק_, _نِیہ_, _мір_, --, 
   {{0x60d400df,0x00000000,0x00000000,0x00000000}},	//   _זושא_, --, --, --, 
   {{0xa91c110c,0xa3bc0037,0x00000000,0x00000000}},	//   težo, _आवस_, --, --, 
   {{0xe6884d2d,0xa91c597b,0x9f5c0241,0x00000000}},	//   ەندى_, bežl, _òtò_, --, 
   {{0xe7d800dc,0x00000000,0x00000000,0x00000000}},	//   योऽप, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa91c0f91,0x69c40200,0x00000000,0x00000000}},	//   pežo, ëhes, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6fc00073,0x00000000,0x00000000,0x00000000}},	//   _एवढं, --, --, --, 
   {{0x9f5802d3,0xba28005e,0x00000000,0x00000000}},	//   ropë_, _اسەم_, --, --, 
   {{0xe6340323,0x21a40798,0x00000000,0x00000000}},	//   _эхлэ, пивм, --, --, 
   {{0x629c0e04,0x00000000,0x00000000,0x00000000}},	//   _vrpo, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [6260] --, --, --, --, 
   {{0x7d04597c,0x629c0010,0x7ddc06be,0x92b800cc}},	//   üism, _trpo, _içsə, _আইৰ_, 
   {{0x629c0c8c,0x9f5800d8,0x20e0003d,0xa0680107}},	//   _urpo, nopé_, _sħiħ_, раҷа_, 
   {{0x9cc8597d,0x2610033f,0x7afc366f,0x1634010f}},	//   йыла_, _धीमी_, _ørti, לנער_, 
   {{0x10a0040d,0xb5fc0135,0x00000000,0x00000000}},	//   _зиян, fuġj, --, --, 
   {{0x9f580093,0xa91c0e3c,0x00000000,0x00000000}},	//   kopé_, režl, --, --, 
   {{0x9d4402bf,0x00000000,0x00000000,0x00000000}},	//   _невд, --, --, --, 
   {{0x3e5802bd,0xa91c0219,0x249003e0,0x49700395}},	//   mčt_, pežl, _osym_, елъс, 
   {{0xa91c597e,0x3e5802e2,0x893000be,0x0d80009d}},	//   ležj, lčt_, رعيا, _ялтн, 
   {{0x69c4069c,0x9f540724,0x0b4403e6,0x20180113}},	//   ëher, _ägär_, _فرمێ, nmpi_, 
   {{0x9f5805d5,0x2018005b,0x3e58033b,0x3d180037}},	//   ropè_, impi_, nčt_, बेरे_, 
   {{0x18680724,0x0a100137,0x68ec139f,0x00000000}},	//   _гади_, _كولح, _žade, --, 
   {{0x3e58007f,0xeac400e4,0x00000000,0x00000000}},	//   hčt_, _ñùre_, --, --, 
   {{0x6490597f,0x481000d6,0x3e58033b,0x00000000}},	//   džić, _зміс, kčt_, --, 
   {{0xd90c1079,0x877800d9,0xa3bc28d4,0x0324005b}},	//   _جیک_, _האוי, _आवर_, едён, 
   {{0xe5180243,0x20180108,0x00000000,0x00000000}},	//   नेहि_, empi_, --, --, 
   {{0x6fb85980,0x39400254,0x5ed80154,0x00000000}},	// [6270] огар_, _õisu_, _বুলে, --, 
   {{0x3e5802e2,0x00000000,0x00000000,0x00000000}},	//   fčt_, --, --, --, 
   {{0x85300b45,0x2d9803b2,0x00000000,0x00000000}},	//   _haɗa, _ósek_, --, --, 
   {{0x2bc411bc,0x85300c09,0x201802f6,0x00000000}},	//   वस्थ, _kaɗa, ampi_, --, 
   {{0x40845981,0xfbd0105f,0x32085982,0xb60800ef}},	//   _пурб, گتن_, mlay_, _izšļ, 
   {{0x32085983,0x853002a8,0xdca05984,0x3e58033b}},	//   llay_, _maɗa, таши, bčt_, 
   {{0xfbd00ccb,0x32085985,0x00000000,0x00000000}},	//   دتن_, olay_, --, --, 
   {{0x32085986,0x78a4341a,0x2b1800dc,0x3d94014b}},	//   nlay_, _šiva, येषु_, _писр, 
   {{0x853003f9,0x765803ac,0x3e180276,0x3208058a}},	//   _naɗa, _avvy, _хотэ_, ilay_, 
   {{0x32085987,0xa91c0219,0x956c0118,0x0a680798}},	//   hlay_, ležk, ářní, _грди_, 
   {{0x32080c8c,0x02b00220,0x00000000,0x00000000}},	//   klay_, _ءﻭﺯﯨ, --, --, 
   {{0x9f580998,0x6aa0035a,0x00000000,0x00000000}},	//   ropé_, _irlf, --, --, 
   {{0x32085988,0x798402d1,0x9f580418,0x20180381}},	//   dlay_, _ñiwa, sopé_, ympi_, 
   {{0x660c01a2,0x853003f9,0x225c2b57,0xa368022e}},	//   _ďaku, _daɗa, átko_, _amеr, 
   {{0x628c0cf9,0x32085989,0x00000000,0x00000000}},	//   uwbo, flay_, --, --, 
   {{0x3208598a,0x85300b45,0x3e580100,0xa0a401a9}},	//   glay_, _faɗa, včt_, мабд, 
   {{0x00e4598b,0xed580841,0x3e580100,0x00000000}},	// [6280] رتری, _možd_, wčt_, --, 
   {{0x9f480100,0x3208598c,0xa91c09a8,0x20180083}},	//   _akbò_, alay_, težj, umpi_, 
   {{0x320814dc,0x3bd0002e,0xfd6401e0,0xdb08007c}},	//   blay_, _jàqe_, енеү, lkfö, 
   {{0x320814dc,0xa91c151c,0x85300198,0xa27c02d3}},	//   clay_, režj, _yaɗa, _ሕልናን_, 
   {{0x3bd0002e,0x3e580100,0xdb08007c,0x1f5401f4}},	//   _làqe_, sčt_, nkfö, _отвё, 
   {{0x6b800334,0xdf38007b,0x00000000,0x00000000}},	//   _cblg, _ذكرت_, --, --, 
   {{0xa91c598d,0x00000000,0x00000000,0x00000000}},	//   bežk, --, --, --, 
   {{0x3f98598e,0xdd90598f,0x98c45990,0xdbd40108}},	//   _haru_, _جور_, дсол, _näön, 
   {{0x3f981bb7,0x60d457cf,0xed5800a2,0xdb18036e}},	//   _karu_, nzym, _dožd_, _kotë, 
   {{0x8c4047ce,0x853002a8,0x3e600311,0x32085991}},	//   _рефе, _raɗa, pătă_, zlay_, 
   {{0x3f985992,0xdb185993,0x7c280472,0x32085994}},	//   _maru_, _motë, _iidr, ylay_, 
   {{0x3f985995,0x3bd01bce,0x32085996,0x94a8036b}},	//   _laru_, _dàqe_, xlay_, отга_, 
   {{0x7c285997,0x32085998,0x00000000,0x00000000}},	//   _kidr, vlay_, --, --, 
   {{0x3f984c97,0x3bd0002e,0x7c285999,0xdb18036e}},	//   _naru_, _fàqe_, _jidr, _notë, 
   {{0x7c280429,0x853023db,0x320814dc,0x00000000}},	//   _midr, _waɗa, tlay_, --, 
   {{0xdb180261,0x3f98599a,0x7c2801a6,0x3208002e}},	//   _potê, _aaru_, _lidr, ulay_, 
   {{0x3f98599b,0x320814dc,0x752c599c,0xdb18599d}},	// [6290] _baru_, rlay_, _igaz, _botë, 
   {{0xed5804b9,0x32082f05,0x3f98599e,0x7c28599f}},	//   _može_, slay_, _caru_, _nidr, 
   {{0x3f9859a0,0xdb1801c7,0x32084dbd,0xa91c0427}},	//   _daru_, _dotë, play_, težk, 
   {{0x320859a1,0x7c2859a2,0x506459a3,0x00000000}},	//   qlay_, _aidr, _отга, --, 
   {{0x7c2800ed,0x3f9859a4,0xed580122,0xdb181d1a}},	//   _bidr, _faru_, _nože_, _hotè, 
   {{0x3f9859a5,0xa91c09a8,0xdb18036e,0x3da405a2}},	//   _garu_, sežk, _gotë, ерәб, 
   {{0x4ea407d6,0x7c2859a6,0x752c04ba,0x37e4015b}},	//   _ўрга, _didr, _ogaz, নকার, 
   {{0xa91c4e86,0xed5807f5,0x2d982776,0xdb1859a7}},	//   leži, _bože_, _ûse_, _zotë, 
   {{0xed5859a8,0xdb1802bd,0x7c2859a9,0x3f9859aa}},	//   _vožd_, _lotè, _fidr, _yaru_, 
   {{0x752c59ab,0x7c2859ac,0x6614062c,0x3f9800e8}},	//   _agaz, _gidr, _shyk, _xaru_, 
   {{0x6e2859ad,0x3a740588,0xdb18067c,0xfbac3f79}},	//   _kieb, _алхр, _notè, चारम, 
   {{0x7c2859ae,0x00000000,0x00000000,0x00000000}},	//   _zidr, --, --, --, 
   {{0x69c859af,0x6e2805da,0xb9340114,0x02c800cd}},	//   mkee, _mieb, _речј, रन्न, 
   {{0x6e2859b0,0x69c859b1,0x752c59b2,0xdb1859b3}},	//   _lieb, lkee, _egaz, _botè, 
   {{0x3f9859b4,0xdb180ba1,0x69c8009d,0xa91c0427}},	//   _raru_, _cotè, okee, deži, 
   {{0x3f9859b5,0x6e28068f,0xdb1859b6,0xe12459b7}},	//   _saru_, _nieb, _dotè, емби, 
   {{0xe0d806bb,0x20d400d4,0x00000000,0x00000000}},	// [62a0] чва_, хівс, --, --, 
   {{0x60d4006d,0x752c0552,0x6e2816b8,0xdb18033b}},	//   rzym, _zgaz, _aieb, _fotè, 
   {{0x3f98005f,0x69c83081,0xdb180023,0x60d4033f}},	//   _varu_, kkee, _votë, szym, 
   {{0x3f9859b8,0x6e28068f,0x69c8058a,0x00000000}},	//   _waru_, _cieb, jkee, --, 
   {{0x6e2859b9,0x63bc08a4,0x3f9859ba,0x69c80050}},	//   _dieb, _kopn, _taru_, dkee, 
   {{0xdb1859bb,0x3f980268,0x69c859bc,0x6e28017a}},	//   _hoté, _uaru_, ekee, _eieb, 
   {{0x7c2859bd,0x6e2859be,0x69c859bf,0x9f580118}},	//   _vidr, _fieb, fkee, nopí_, 
   {{0x69c859c0,0x6e2859c1,0x63bc016d,0xdb18002e}},	//   gkee, _gieb, _lopn, _joté, 
   {{0xdb1859c2,0x752c07d6,0x7c2859c3,0x3914039b}},	//   _moté, _rgaz, _tidr, ъмир, 
   {{0x69c859c4,0xdb1859c5,0xab9801d9,0xfce4022e}},	//   akee, _loté, _ٲخٕر_, _зоғо, 
   {{0x6e280399,0x69c801d9,0x672c02d3,0x05cc05c0}},	//   _yieb, bkee, _ተዓዘብ, ासंब, 
   {{0x69c80076,0xf9580583,0xdb1859c6,0xd8380150}},	//   ckee, _آساں_, _noté, _еэк_, 
   {{0xc45809fe,0xe79459c7,0xdb180561,0x5ebc009e}},	//   ниях_, رایک, _sotè, ্পটে, 
   {{0x63bc0589,0xdb1859c8,0x26c4012c,0x28d859c9}},	//   _copn, _potè, bylo_, _बेटि, 
   {{0x86c02118,0xdb180066,0xa91c59ca,0x752c07de}},	//   _ميون, _boté, veži, _tgaz, 
   {{0x752c59cb,0x3fe003d4,0xdb1859cc,0xdde000a2}},	//   _ugaz, বকোষ, _coté, _çuňu, 
   {{0x6e2859cd,0xdb1807ea,0x00000000,0x00000000}},	// [62b0] _rieb, _doté, --, --, 
   {{0x6e2859ce,0x69c801c0,0xd34459cf,0x00000000}},	//   _sieb, zkee, _سیره_, --, 
   {{0xa91c59d0,0x6e2859d1,0x69c805e4,0xad2400d1}},	//   reži, _pieb, ykee, ھىتى, 
   {{0xad240131,0xa2b402e4,0x63bc0419,0x28d80210}},	//   پىتى, _ספרד_, _zopn, _बेझि, 
   {{0xeb981ea2,0x69c801d4,0xdd8c1cbc,0x79800175}},	//   дил_, vkee, زوو_, dfmw, 
   {{0x6e2859d2,0x00000000,0x00000000,0x00000000}},	//   _wieb, --, --, --, 
   {{0xc3340375,0x69c859d3,0x63b8007c,0xc00400c0}},	//   נוק_, tkee, ötni, _спёк, 
   {{0x5ed8015b,0x69c8208d,0x00000000,0x00000000}},	//   _বুকে, ukee, --, --, 
   {{0xed580010,0x780c0073,0x8e600139,0x26c403cb}},	//   _tožb_, हतूक_, _шеңҗ, wylo_, 
   {{0x69c82665,0x00000000,0x00000000,0x00000000}},	//   skee, --, --, --, 
   {{0x8aa40209,0x63bc3e91,0xe9b40124,0xd99459d4}},	//   _ярад, _ropn, _ибжь, رنیت_, 
   {{0x893400c6,0x63bc0af9,0x00000000,0x00000000}},	//   _أعضا, _sopn, --, --, 
   {{0x0df00020,0x118802d3,0x2d980077,0xdb180036}},	//   ውሮፓ_, _ኣማራጺ_, _óseu_, _roté, 
   {{0xdb1800d5,0x26c4003a,0x00000000,0x00000000}},	//   _soté, pylo_, --, --, 
   {{0xc790005e,0xdb1859d5,0x63bc59d6,0x97e400ec}},	//   _арқы, _poté, _vopn, _جڙيل_, 
   {{0xa3bc06ab,0x64a40022,0x00000000,0x00000000}},	//   _आवक_, _ааиа, --, --, 
   {{0x63bc59d7,0xdb1859d8,0xe45802d5,0xe1240107}},	// [62c0] _topn, _voté, _ўжо_, тмаи, 
   {{0x63bc01bf,0x942000cf,0xaad0179f,0xd00c00ae}},	//   _uopn, _پوپۇ, तनाक, قلق_, 
   {{0x6614012c,0xdb180118,0x00000000,0x00000000}},	//   ůzku, _toté, --, --, 
   {{0xa91c09a8,0x88d400eb,0x91e001f4,0x00000000}},	//   ležu, _তখনক, _воюе, --, 
   {{0xec1003cc,0x6fb00050,0x7b8459d9,0x68ec013a}},	//   ڭۈلد, _گۅلا, лғад, _žadn, 
   {{0x9e6459da,0x64440006,0xdb180432,0x8c400114}},	//   _لارن, ipki, _eltý, шеље, 
   {{0x6fb001d9,0xdee459db,0xd0040276,0x00000000}},	//   _دۅلا, _рови, _рере_, --, 
   {{0x3e7c59dc,0xdee400c2,0x6444020c,0xdb180166}},	//   mít_, _зоҳи, kpki, _iltü, 
   {{0xd7f8287a,0x3e7c59dd,0x9c24059f,0x00000000}},	//   дун_, lít_, _адад, --, 
   {{0x4b8400d1,0x76b80262,0x97a40e48,0x77980107}},	//   _ийун_, елор_, трил, хкор_, 
   {{0xc0d40023,0xfca800f1,0x3e7c59de,0x0f54011a}},	//   የደሉ_, _غاړو_, nít_, כיים_, 
   {{0xd944189d,0x00000000,0x00000000,0x00000000}},	//   _реди, --, --, --, 
   {{0x9984030a,0x73c40daf,0xed584b16,0x00000000}},	//   _hioů_, гәне, _joža_, --, 
   {{0x3e7c30f9,0xed5809a8,0x00000000,0x00000000}},	//   kít_, _moža_, --, --, 
   {{0x59b426e4,0x3e7c038e,0xed58231e,0x318402dd}},	//   _आचार, jít_, _loža_, лтаң, 
   {{0x349459df,0x3e7c0e33,0x00000000,0x00000000}},	//   _баир, dít_, --, --, 
   {{0x224400f3,0x6da401b9,0xdb1803e0,0xcf2400d1}},	// [62d0] _čoke_, ғила, _altü, چراي, 
   {{0xcee859e0,0x3e7c0162,0x7dc4036b,0x56440092}},	//   وران_, fít_, یقلن, _የተደበ, 
   {{0x3e7c01ed,0xa3c000e1,0xa91c00c0,0xebc400c7}},	//   gít_, ूसर_, ležt, қәан, 
   {{0xaa4430cb,0xe81802ab,0xed580427,0xdb1800c7}},	//   ңелл, _नीना_, _boža_, _potî, 
   {{0x68ec01f1,0x61f801ed,0xc1e40032,0x6c84027d}},	//   _ľado, étle, _төрҙ, التم, 
   {{0x3e7c00bc,0x4ea400c7,0xbfa80354,0x68ec01ef}},	//   bít_, _ирба, _итсе_, _žado, 
   {{0x3e7c0419,0x00000000,0x00000000,0x00000000}},	//   cít_, --, --, --, 
   {{0x8d7413d7,0xdb1800ae,0xad2459e1,0x00000000}},	//   _جاسا, _altó, _مىزى, --, 
   {{0x7d042508,0x6e340399,0xa80459e2,0x8c34013e}},	//   üist, _huzb, лзил, _розӣ_, 
   {{0x2794084c,0x6e340166,0xfa880139,0x00000000}},	//   ушир, _kuzb, хсәй_, --, 
   {{0xf990021a,0xa91c570b,0x7d04003d,0x00000000}},	//   _ژبه_, vežu, żist, --, 
   {{0x6d5859e3,0x6e340007,0xbadc00eb,0x00000000}},	//   nawa, _muzb, _ঢুকছ, --, 
   {{0xa91c01a6,0xa878008f,0x00000000,0x00000000}},	//   težu, _נאַר, --, --, 
   {{0x6d5859e4,0x6e3459e5,0xe29859e6,0xa2e43a49}},	//   hawa, _ouzb, наг_, гогд, 
   {{0x6d5859e7,0xe8e800aa,0xe5a40228,0x07a000fb}},	//   kawa, _ترڅو_, _бийи, _баҙн, 
   {{0x6d5859e8,0x3e7c59e9,0x4574010b,0xe4d40035}},	//   jawa, vít_, _өңүр, _مقعد, 
   {{0x6d5859ea,0x64a41555,0x9f8459eb,0x3e7c011f}},	// [62e0] dawa, _сапа, лгад, wít_, 
   {{0x660459ec,0x3e7c59ed,0xe29859ee,0x6d5802b5}},	//   lokk, tít_, _зао_, eawa, 
   {{0x6d5859ef,0x7a3c00e4,0x5ef800c7,0xcfc800db}},	//   fawa, _oĩta, ххар_, راكۅ_, 
   {{0x6d5859f0,0x6e340097,0x660459f1,0x5bbc00dc}},	//   gawa, _duzb, nokk, ्स्व, 
   {{0x9be40220,0x3e7c01ed,0xdea0105d,0xca500150}},	//   лікк, sít_, _گیای, _ﻋﺩﺍ_, 
   {{0xdfd01fbb,0x660459f2,0x6e340427,0x3e7c59f3}},	//   _ايس_, hokk, _fuzb, pít_, 
   {{0x9a840323,0xc0f00023,0x3ab400c7,0x2b540066}},	//   уулл, _ቀይሩ_, шәат, شیند_, 
   {{0x6d58127b,0xa7fc002d,0x1d0801f0,0x66041291}},	//   cawa, brűk, _зеби_, jokk, 
   {{0x660459f4,0x5fb800e1,0x383400f0,0x00000000}},	//   dokk, _ेवाल, јнор, --, 
   {{0x94840220,0xa91c0024,0x6e3400a4,0x9078010f}},	//   қымд, vežt, _yuzb, עטיי, 
   {{0x47840046,0xdb18043b,0x61e40a7f,0xaa6400d4}},	//   усым_, _kotí, _omkl, _втік, 
   {{0xd5ac05d7,0x660459f5,0x75c801e0,0xceb005d0}},	//   टाइज, gokk, ттоң_, ציר_, 
   {{0xb4c003f3,0xdb1859f6,0x8ca4012d,0x9a8401af}},	//   ूने_, _motí, चियो, _шуҡл, 
   {{0x7bd80208,0x04b801d3,0xa91c00d7,0x13a400f2}},	//   nhvu, چھیں_, režt, دنسی_, 
   {{0x6d5859f7,0xcb340302,0x660459f8,0x23780100}},	//   yawa, ראלי_, bokk, _dcpj_, 
   {{0xdb1859f9,0x6604194f,0x6d581574,0x7648007c}},	//   _notí, cokk, xawa, mpdy, 
   {{0x6e340b91,0x6d5859fa,0x948459fb,0x74f800d1}},	// [62f0] _suzb, vawa, _сыйд, _шеир_, 
   {{0x61e459fc,0xfba417ee,0x60c0023a,0x32540cb6}},	//   _emkl, _गोलम, äoma, _квор, 
   {{0x6d5859fd,0x4ea459fe,0xdb1821fc,0x0fe00032}},	//   tawa, ыраа, _botí, _һөжү, 
   {{0xdb180005,0xdddc007f,0xed5001d9,0x52b0012d}},	//   _cotí, nspň, تھس_, ीहीस, 
   {{0xe7b401ad,0x00000000,0x00000000,0x00000000}},	//   _अचलप, --, --, --, 
   {{0x6e340e3c,0x3b840150,0x00000000,0x00000000}},	//   _tuzb, йліг, --, --, 
   {{0x6d5859ff,0x9ba01dc8,0xdb180306,0x7b640395}},	//   pawa, تەلى, _fotí, стче, 
   {{0x6d585a00,0xdb180798,0x66040327,0xae040116}},	//   qawa, _botâ, xokk, _ئورى, 
   {{0x6604023a,0xd8743229,0xbdf80214,0xa8b8013d}},	//   vokk, لميت_, _صرفا_, тыйф_, 
   {{0xed58151c,0xf1f80307,0x7bd8004d,0xa6840006}},	//   _kožo_, ्कड़_, chvu, алод, 
   {{0x85300c09,0x66045a01,0xed580419,0x00000000}},	//   _haɗi, tokk, _jožo_, --, 
   {{0x64a4499d,0x00000000,0x00000000,0x00000000}},	//   аама, --, --, --, 
   {{0xed580010,0x00000000,0x00000000,0x00000000}},	//   _ložo_, --, --, --, 
   {{0x85300198,0x66045a02,0x61e4007c,0xe634030d}},	//   _maɗi, sokk, _smkl, _кхиэ, 
   {{0xa91c0216,0x66045a03,0x00000000,0x00000000}},	//   pežs, pokk, --, --, 
   {{0xe818276a,0x78a40219,0xf1a82144,0xa2e4059f}},	//   _नीता_, _šivi, _चोदन, гоҳд, 
   {{0x5928025c,0x8108004b,0x43940276,0x00000000}},	// [6300] _ཤུབས_, ارزې_, _лунӂ, --, 
   {{0x85300198,0xed582230,0xa2e406ed,0xbfc800d1}},	//   _naɗi, _božo_, _воод, دارە_, 
   {{0xdb18012c,0x425403e6,0x232800f0,0x00000000}},	//   _potí, _دۆزر, _јони_, --, 
   {{0x61e45a04,0x225c02fb,0x21a4014b,0xfc6400f1}},	//   _umkl, átku_, _тимм, مختی, 
   {{0x10a0022e,0xa2d000cd,0x1064014b,0x00000000}},	//   _диян, णैर्, _кияй_, --, 
   {{0x76480209,0xb5fc0327,0x6fd40006,0x6d4c0162}},	//   ypdy, rrġi, _лісц, ðaar, 
   {{0x85300b45,0x61f40208,0x00000000,0x00000000}},	//   _daɗi, onyl, --, --, 
   {{0x29d00165,0x00000000,0x00000000,0x00000000}},	//   _wáan_, --, --, --, 
   {{0xdb1803b7,0x85300b45,0x3d1400ec,0x00000000}},	//   _botã, _faɗi, _اڀار, --, 
   {{0x1ae40697,0x7b845a05,0xf7b80640,0xb7d80133}},	//   _козм, _دارە, угој_, اودا_, 
   {{0x27f80c6a,0xb4c011bc,0x8f34010f,0xca5001ec}},	//   ésna_, ून्_, יטיג_, _ﻋﺩﺓ_, 
   {{0x76482774,0x00000000,0x00000000,0x00000000}},	//   rpdy, --, --, --, 
   {{0x224400f3,0xa368022e,0x00000000,0x00000000}},	//   _čoka_, _elеm, --, --, 
   {{0x76480174,0x00000000,0x00000000,0x00000000}},	//   ppdy, --, --, --, 
   {{0x9f5c063f,0x82a45a06,0x96b801f0,0x00000000}},	//   _ótù_, оште, _шуду_, --, 
   {{0xed580010,0xf1c85a07,0xcad4011a,0x00000000}},	//   _rožo_, دورى_, בולת_, --, 
   {{0x136806b3,0xc3c401c0,0x303803c7,0x00000000}},	// [6310] _ишни_, сөөл, اترک_, --, 
   {{0x33745a08,0x938800c7,0x8f445a09,0xbfd800d4}},	//   _угор, _рсиа_, рхад, адує_, 
   {{0xb4240583,0x853003f9,0xdb180109,0xf19401f4}},	//   _پٹھو, _raɗi, _notà, _линь, 
   {{0x823403e6,0x00000000,0x00000000,0x00000000}},	//   _گریا, --, --, --, 
   {{0x25f8000d,0x00000000,0x00000000,0x00000000}},	//   _उदसी_, --, --, --, 
   {{0x82345a0a,0xf778003d,0xdb1800cf,0xa0340375}},	//   _دریا, jgħ_, _botà, _לאשה_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x82f80302,0x29d0011f,0x3eb40419,0xf7780003}},	//   יצוב_, _gáal_, ňatá_, egħ_, 
   {{0xe7385a0b,0x8b645a0c,0x853003f9,0x29183402}},	//   леп_, _ناام, _taɗi, åsa_, 
   {{0x7dfc0100,0x7c8400d8,0x00000000,0x00000000}},	//   mčsa, _ќуте, --, --, 
   {{0xe5a45a0d,0x61f43626,0x8a400345,0x00000000}},	//   бини, ynyl, _بێبن, --, 
   {{0xed58012c,0xa91c0171,0x00000000,0x00000000}},	//   _jež_, bežp, --, --, 
   {{0x68445a0e,0x45200327,0x65cc00d1,0x00000000}},	//   _унла, ཿཟེར_, ﺗﭽﯩﻠ, --, 
   {{0x06cc00fe,0x24081188,0x86b001ec,0xed58022a}},	//   াছবি, унги_, _дәмі, _lež_, 
   {{0xdb18043b,0x21685a0f,0x4df44c19,0x61f4007c}},	//   _kotá, ливи_, ंचाई_, tnyl, 
   {{0xed5802f8,0x320805da,0x91e03591,0xd2ec0354}},	//   _než_, goay_, посе, _кlор, 
   {{0xdb185a10,0xe3b056e1,0x61f4005c,0xdff401af}},	// [6320] _motá, _فرد_, rnyl, бяжь, 
   {{0x94b8011a,0x00000000,0x00000000,0x00000000}},	//   _עמית, --, --, --, 
   {{0xed585a11,0x320805da,0x1e845a12,0xb42400ae}},	//   _bež_, boay_, слем, _بعيو, 
   {{0xe0d80395,0x72440241,0x00000000,0x00000000}},	//   _бвм_, _únjẹ, --, --, 
   {{0xed582a57,0x629c0798,0x0d200131,0x00000000}},	//   _dež_, _hspo, зүтү, --, 
   {{0x50405a13,0x00000000,0x00000000,0x00000000}},	//   _херб, --, --, --, 
   {{0xdb185a14,0xa3680139,0x00000000,0x00000000}},	//   _botá, _alеk, --, --, 
   {{0x853002a8,0xdb1805d5,0xed3400c0,0x00000000}},	//   _haɗu, _votà, _дэфэ, --, 
   {{0x85300198,0xdb185a15,0xd8b85a16,0x00000000}},	//   _kaɗu, _dotá, ادعا_, --, 
   {{0x629c0b91,0x00000000,0x00000000,0x00000000}},	//   _ospo, --, --, --, 
   {{0x59840006,0xa36801b9,0xdb180112,0x9aa400f2}},	//   _глеб, _elеk, _altö, _دماو, 
   {{0xca3425f9,0xd1e8001f,0xd5b8014b,0xa2ac5a17}},	//   _הנאה_, መበት_, усо_, ुमन्, 
   {{0x629c5a18,0x320806d9,0x80c80154,0x00000000}},	//   _aspo, voay_, _রেস্, --, 
   {{0x07a05a19,0x64540368,0xc7a003f6,0x36d40117}},	//   _начн, _dwyi, _ничк, _молр, 
   {{0xdb1801d3,0xf2e80bce,0x320803ac,0x00000000}},	//   _eltö, شکده_, toay_, --, 
   {{0x629c0334,0x68ec0024,0x00000000,0x00000000}},	//   _dspo, _žadi, --, --, 
   {{0x1cd008ea,0x94745a1a,0xed585a1b,0x614400db}},	// [6330] ེགས_, _ادعا, _rež_, تىقە, 
   {{0x629c0334,0x7dfc007f,0xb4e400bc,0xb5fc0327}},	//   _fspo, včsa, पछी_, rrġu, 
   {{0x6e985a1c,0x629c0072,0x0dc80a5b,0x00000000}},	//   рвер_, _gspo, луди_, --, 
   {{0x6cd40a2c,0x00000000,0x00000000,0x00000000}},	//   يقاا, --, --, --, 
   {{0x853002a8,0xdb1837b5,0x3078010f,0x00000000}},	//   _faɗu, _rotá, _דאָנ, --, 
   {{0x826404d3,0xaa4857bf,0xaffc0354,0x00000000}},	//   _بهێن, апка_, _рогi, --, 
   {{0xdb181705,0x41e003e5,0x0b5401ec,0x00000000}},	//   _potá, _नतमस, арқы_, --, 
   {{0x68445a1d,0x68fc002d,0x9f580267,0xdce800e2}},	//   ониа, ûsdo, ropå_, šnāv, 
   {{0x2d8c0472,0x853002a8,0x7ae4010f,0xdb18362f}},	//   _ibee_, _yaɗu, ĝita, _votá, 
   {{0x2cac009a,0x7ae4010f,0x3a20003d,0x7c941063}},	//   _ired_, ŝita, ċipa_, _عشقا, 
   {{0x22440e04,0x2cac0165,0xd1ec0092,0x4ab0009d}},	//   _čoko_, _hred_, ቀሱት_, _хөлр, 
   {{0xe81806ab,0x2cac5a1e,0xba740066,0x00000000}},	//   _नीरा_, _kred_, _رامت, --, 
   {{0x69d85a1f,0x629c030d,0x00000000,0x00000000}},	//   _ilwe, _sspo, --, --, 
   {{0x69d85a20,0x291c01f0,0x2cac037e,0x98b0033f}},	//   _hlwe, _izwa_, _mred_, _żyć_, 
   {{0x69d800d2,0x23285a21,0x2d8c5a22,0xe2985a23}},	//   _klwe, рови_, _obee_, шав_, 
   {{0x2cac0295,0x21f40212,0x629c5a24,0x715803f5}},	//   _ored_, іївс, _vspo, йрус_, 
   {{0xdfd016a2,0x629c068f,0xdfe801c0,0x2fc00175}},	// [6340] وير_, _wspo, адад_, fjhg_, 
   {{0x69d85a25,0x2d8c01c7,0x00000000,0x00000000}},	//   _llwe, _abee_, --, --, 
   {{0x69d85a26,0x2d8c020c,0x5de412c4,0xe4ec00dc}},	//   _olwe, _bbee_, ожжа, _चेति_, 
   {{0x2cac5a27,0x291c0117,0x60c005ac,0xed8847c5}},	//   _bred_, _ozwa_, øoms, йсік_, 
   {{0x2cac5a28,0x00000000,0x00000000,0x00000000}},	//   _cred_, --, --, --, 
   {{0x81bc000e,0x2d8c01f2,0x69d85a29,0x2cac5a2a}},	//   _অতি_, _ebee_, _alwe, _dred_, 
   {{0x291c0296,0x8e805a2b,0xdcf405d1,0xfe705a2c}},	//   _azwa_, _огре, ğcıl, _سگا_, 
   {{0x7f5c0784,0x224409a8,0x2d8c5a2d,0x2cac2216}},	//   _herq, _čokl_, _gbee_, _fred_, 
   {{0x69d8009a,0x2cac5a2e,0x7f5c0165,0x9cd00345}},	//   _dlwe, _gred_, _kerq, _تڕاژ, 
   {{0x69d85a2f,0xe0085a30,0x76745a31,0x8ca40073}},	//   _elwe, वविद_, плоф, चिरो, 
   {{0x291c0107,0x7f5c047e,0x38c8158b,0x50180375}},	//   _ezwa_, _merq, شاکی_, שויו, 
   {{0x7bc85a32,0xfaa805d9,0x2d8c0327,0x6bd401ec}},	//   _hodu, _پهچي_, _xbee_, _وتەر, 
   {{0x7bc85a33,0x5fd80490,0x4870179e,0x8af403b9}},	//   _kodu, णसाल, _قدوس, _çərk, 
   {{0x7f5c02d1,0x7bc801a9,0xb7d80214,0xd1b80092}},	//   _nerq, _jodu, _دوتا_, ሰዓት_, 
   {{0x9f480ffb,0x8d98001f,0xd1e80798,0x07e40244}},	//   _imbè_, ለቀቀው_, аќал_, _بزنێ, 
   {{0x39440077,0x7bc85a34,0xf0e800d1,0x46a400bc}},	//   ncms_, _lodu, مىزى_, गिरह, 
   {{0x61444da8,0x7f5c5a35,0x7bc80248,0xdb20032e}},	// [6350] سىلە, _berq, _oodu, _öræf, 
   {{0x7bc85a36,0x7f5c5a37,0x76580218,0x00000000}},	//   _nodu, _cerq, _kwvy, --, 
   {{0x8d745a38,0x2cac0552,0x60c01347,0x15fc07af}},	//   قاشا, _sred_, øomr, _उदार_, 
   {{0x2cac5a39,0xdb1801b8,0x00000000,0x00000000}},	//   _pred_, _motä, --, --, 
   {{0x7bc85a3a,0x7f5c0213,0x00000000,0x00000000}},	//   _bodu, _ferq, --, --, 
   {{0xeb985a3b,0x7bc800a8,0x2cac5a3c,0x7f5c0200}},	//   сик_, _codu, _vred_, _gerq, 
   {{0x7bc85a3d,0xfbd004fb,0xed5816a3,0xdb180036}},	//   _dodu, ختن_, _loži_, _notä, 
   {{0x2cac2b92,0x3944020c,0x2d8c5a3e,0x7f5c002f}},	//   _tred_, gcms_, _ubee_, _zerq, 
   {{0x2cac1f7f,0xed581154,0x603402e2,0x7bc85a3f}},	//   _ured_, _noži_, _kņma, _fodu, 
   {{0xbb8c00c6,0x7bc85a40,0x7afc09a8,0xdb243bd6}},	//   _кįѝ͡_, _godu, _žrte, _کومی, 
   {{0x69d80770,0xe5a45a41,0x00000000,0x00000000}},	//   _tlwe, пини, --, --, 
   {{0xf9902ea3,0x69d81cdf,0x7bc80161,0xe5a45a42}},	//   _لبه_, _ulwe, _zodu, чими, 
   {{0xb9c400c6,0x291c5a43,0x7bc801b3,0x993802e4}},	//   _تقني, _uzwa_, _yodu, _התנה, 
   {{0x18a0016c,0x1cc0025c,0x66e41188,0x33b45a44}},	//   _чашм, གྱི_, _нола, мёст, 
   {{0x7f5c0309,0x872801a9,0xa2ac08dd,0x00000000}},	//   _rerq, _тўда_, ुमध्, --, 
   {{0x7f5c5a45,0x47f0009d,0x00000000,0x00000000}},	//   _serq, _хүүр, --, --, 
   {{0x91000a52,0x91e03580,0x3bd0002e,0x00000000}},	// [6360] епте, хоте, _wàqi_, --, 
   {{0x6d4c0de2,0x8fa000c7,0x00000000,0x00000000}},	//   ñaan, науе, --, --, 
   {{0x61445a46,0x7bc85a47,0x7f5c5a48,0x5398011a}},	//   _нена, _rodu, _verq, _פיטו, 
   {{0x7bc85a49,0x29d003b2,0x7f5c031c,0x0dc400d1}},	//   _sodu, _fáai_, _werq, зуши_, 
   {{0x7bc85a4a,0xa1145a4b,0x60340100,0xdb180158}},	//   _podu, _روست, _fņma, _motå, 
   {{0x9f480066,0x7bc85a4c,0x3e58007f,0x3ebc01e3}},	//   _ombé_, _qodu, pōt_, ävts_, 
   {{0x5ed40154,0x39440051,0x00000000,0x00000000}},	//   _দশকে, tcms_, --, --, 
   {{0x7bc85a4d,0xaf3800fd,0xdee40b01,0x4ef8011a}},	//   _wodu, ğışt, _доҳи, _ההלו, 
   {{0x9f481497,0x7bc8047e,0x3944037e,0xfaf80171}},	//   _ambé_, _todu, rcms_, _adīt_, 
   {{0x36d401c6,0x7bc80064,0x00000000,0x00000000}},	//   доор, _uodu, --, --, 
   {{0xf11809d9,0x668012ea,0xb6c801d3,0x08f401d3}},	//   _दर्द_, نیول, زادے_, قریب_, 
   {{0x38c8030f,0xe8ec00ec,0x00000000,0x00000000}},	//   _واشی_, _ھڻي_, --, --, 
   {{0x9f485a4e,0x00000000,0x00000000,0x00000000}},	//   _embé_, --, --, --, 
   {{0x61240421,0x9f480268,0x9f9402d2,0x8898011a}},	//   _mōlī, _umbè_, _hææ_, _לבדי, 
   {{0x07a01fbe,0x964400cf,0x00000000,0x00000000}},	//   _чајн, _ээлд, --, --, 
   {{0xc2c400c6,0x067804ae,0xed580219,0x705801c6}},	//   ريقي, _הנהל, _toži_, жаар_, 
   {{0x009400a8,0x461401d9,0x00000000,0x00000000}},	// [6370] нитэ, _سوٝر, --, --, 
   {{0x74142303,0x00000000,0x00000000,0x00000000}},	//   _زوجا, --, --, --, 
   {{0xa5085a4f,0x1d4802e3,0xd004010a,0x00000000}},	//   _གཙོག_, _ịdịm, çете_, --, 
   {{0xfe70179c,0x9f9401bf,0x9d5000f2,0xdcfc002b}},	//   ادل_, _nææ_, پنوت, _śvān, 
   {{0x3bd01bce,0x00000000,0x00000000,0x00000000}},	//   _làqu_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9f9402d2,0x7b640014,0x00000000,0x00000000}},	//   _bææ_, راوٕ, --, --, 
   {{0xfaf00517,0x00000000,0x00000000,0x00000000}},	//   دثه_, --, --, --, 
   {{0x6d485a50,0x1aec00eb,0x00000000,0x00000000}},	//   _ifea, _চুদে_, --, --, 
   {{0x6b8000ca,0x2bd85a51,0xe64422c3,0x60c00108}},	//   _uclg, _بارک_, меоп, äomi, 
   {{0xba3c00c0,0x00000000,0x00000000,0x00000000}},	//   _drįs, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xba3c0153,0x9ae0010b,0xe6c400ae,0x00000000}},	//   _grįs, _öńün, _يتغي, --, 
   {{0x3c20068c,0xe5a45a52,0x61440150,0x00000000}},	//   nòva_, _жийи, деба, --, 
   {{0xed5807f5,0x628829ef,0x6d4c0de2,0x00000000}},	//   _kožu_, _äfom, ñaal, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [6380] --, --, --, --, 
   {{0x6d485a53,0xe2980640,0xed585a54,0x3bd01bce}},	//   _afea, _дао_, _možu_, _yàqu_, 
   {{0xb4005a55,0x6d480076,0xd5ac37f7,0x00000000}},	//   _сүрд, _bfea, _صفی_, --, 
   {{0x6b940790,0x00000000,0x00000000,0x00000000}},	//   _ızga, --, --, --, 
   {{0x8c403804,0x320401d3,0x5c0400c0,0x00000000}},	//   вече, élye_, мяка, --, 
   {{0xa91c5a56,0x28b0073d,0x6d480857,0x5f740150}},	//   igžd, जिनि, _efea, _تاحر, 
   {{0x9a842cc8,0xca440345,0x9d540150,0x00000000}},	//   фулл, ولوه_, _ينست, --, 
   {{0xdb180030,0x20180309,0x1d081fbe,0x0b400131}},	//   _kotú, llpi_, _деби_, ннән, 
   {{0x3bd0002e,0x6e20002e,0x9804010b,0x00000000}},	//   _sàqu_, _ëlba, дянд, --, 
   {{0xdb1800d7,0x1bf0000d,0x00000000,0x00000000}},	//   _motú, _अगिल_, --, --, 
   {{0xaba40150,0x36d401f0,0x00000000,0x00000000}},	//   _سۇيم_, хонр, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x97c40440,0xd63001d9,0xe818000d,0x00000000}},	//   _ойде, _یِتھ, _नीका_, --, 
   {{0xacd8008f,0xd2580024,0x68ec010b,0x88900117}},	//   פֿרי, жца_, _ýada, _ришх, 
   {{0xd1b800e3,0x11d40330,0xd78c0051,0x00000000}},	//   يارا_, وترد, _yểng_, --, 
   {{0xdb18007b,0xd49800f3,0x00000000,0x00000000}},	//   _botú, _дро_, --, --, 
   {{0x999c0b23,0xdb180332,0xe7f40073,0x7dfc00d7}},	// [6390] _autū_, _cotú, ीकचा_, ačsk, 
   {{0xf4080003,0x6d480b21,0x849801f7,0x00000000}},	//   _གཉིད_, _sfea, _آئيس_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x20180395,0xa2ac00cd,0xaa440022,0x00000000}},	//   alpi_, ुमर्, ҭелл, --, 
   {{0xe810012c,0xcd28114f,0xac18004e,0x00000000}},	//   ठकमा_, آسان_, поду_, --, 
   {{0x7afc0b91,0x6a842c08,0x40880014,0xdb180129}},	//   _žrta, елка, _تھٲپ_, _intê, 
   {{0x8d745a57,0xdb08000f,0x160c00e1,0x91d00210}},	//   _يارا, ldfê, सवार_, _सवाई, 
   {{0xe8c81e87,0x3c205a58,0x00000000,0x00000000}},	//   згил_, ròva_, --, --, 
   {{0x2d9c1283,0xe8f83f51,0x5b100daf,0xed580daf}},	//   mewe_, яли_, кмәт, _моң_, 
   {{0x2d9c5a59,0x612801d3,0x4bd80214,0x3c2000e4}},	//   lewe_, lölé, _ببرد_, pòva_, 
   {{0xc0f0044e,0x7ac45a5a,0x8aa45a5b,0x9f5800e4}},	//   _ቀይሕ_, _исце, _юрад, jopý_, 
   {{0x2d9c0516,0xa50821fa,0x00000000,0x00000000}},	//   newe_, зема_, --, --, 
   {{0x67d45716,0xdb0400dd,0x00000000,0x00000000}},	//   _поду, ümöl, --, --, 
   {{0x2d9c5a5c,0xa91c0024,0x1874011a,0x00000000}},	//   hewe_, rgžd, _נעצר_, --, 
   {{0x2d9c5a5d,0x94203cd7,0xa2e45a5e,0x00000000}},	//   kewe_, умре, ховд, --, 
   {{0x2d9c1dc9,0x00e41888,0x00000000,0x00000000}},	//   jewe_, پتری, --, --, 
   {{0x60240261,0x2d9c5a5f,0xa5080327,0xa3b8431a}},	// [63a0] едаа, dewe_, _གཙིག_, _فادر_, 
   {{0xdee45a60,0x00000000,0x00000000,0x00000000}},	//   нози, --, --, --, 
   {{0x244407ae,0x2d9c0083,0xdb1806af,0xd12c01ed}},	//   _hôm_, fewe_, _entê, لمہ_, 
   {{0x656415e6,0x2444002d,0x2d9c5a61,0x00000000}},	//   nakh, _kôm_, gewe_, --, 
   {{0x61f45a62,0x32e400e8,0x00000000,0x00000000}},	//   miyl, _tëyé_, --, --, 
   {{0x65641c7a,0x999c0ef0,0x61f45a63,0x672c0115}},	//   hakh, _tutū_, liyl, _ĝajn, 
   {{0x672c00c8,0x65645a64,0x2d9c01b2,0x798029ef}},	//   _ŝajn, kakh, bewe_, tgmw, 
   {{0x61f45a65,0xe9701e87,0xdb080036,0x2d9401af}},	//   niyl, لۇمد, ldfë, _ирус, 
   {{0x6564055a,0x60d4023a,0x2444004d,0x69b0033f}},	//   dakh, nyym, _nôm_, _अफरी, 
   {{0x66145a66,0x61f45a67,0xe7700022,0x00000000}},	//   _akyk, hiyl, аҳшь, --, 
   {{0x6564009f,0x9f585a68,0x61f45a69,0xcf90011a}},	//   fakh, lopó_, kiyl, אטת_, 
   {{0x65645a6a,0x24440051,0x81a00092,0x61f45a6b}},	//   gakh, _bôm_, ምአቀፉ_, jiyl, 
   {{0x61f45a6c,0x00000000,0x00000000,0x00000000}},	//   diyl, --, --, --, 
   {{0x2d9c5a6d,0x88b8011a,0x00000000,0x00000000}},	//   zewe_, _מזדי, --, --, 
   {{0x65642935,0x8c180375,0x2d9c5a6e,0xaaa8012c}},	//   bakh, פולי, yewe_, किएक, 
   {{0xdecc02d3,0x661400a2,0x61f40790,0x29d008a5}},	//   ቢኣን_, _gkyk, giyl, _háar_, 
   {{0x3bd000e8,0x857412c4,0xc3c40137,0x30145a6f}},	// [63b0] _làqq_, _слых, төөл, вдар, 
   {{0x2d9c5a70,0x61f40076,0x00000000,0x00000000}},	//   wewe_, aiyl, --, --, 
   {{0x2d9c0516,0x61f45a71,0x00000000,0x00000000}},	//   tewe_, biyl, --, --, 
   {{0xdb185a72,0x61f40790,0xbe880b5e,0xf1240de7}},	//   _intè, ciyl, эсуе_, _аягү, 
   {{0x2d9c5a73,0xdb18019f,0x24440208,0x7c840114}},	//   rewe_, _untê, _xôm_, гује, 
   {{0x6564541f,0x2d9c27be,0x7c2801ab,0x00000000}},	//   zakh, sewe_, _chdr, --, 
   {{0x2d9c4180,0xed5809a8,0x7dfc02e2,0x00000000}},	//   pewe_, _anže_, zčsi, --, 
   {{0x3bd00de2,0xcfe000eb,0x00000000,0x00000000}},	//   _dàqq_, _মদিন, --, --, 
   {{0x6d585a74,0x65640cfe,0x6e280453,0x29d00162}},	//   mbwa, vakh, _iheb, _báar_, 
   {{0x24442ba0,0x661412e8,0x61f42a87,0x7dfc033b}},	//   _rôm_, _skyk, ziyl, včsi, 
   {{0x65645a75,0xba745a76,0xe73806ed,0xd8d40150}},	//   takh, _مانت, ќен_, _ﺘﻐﻼﻟ, 
   {{0xdb24006c,0x7c28036e,0x6d580100,0x7a080118}},	//   _شونی, _zhdr, nbwa, těte, 
   {{0x65645a77,0x6d585a78,0xdb18033b,0x61f45a79}},	//   rakh, ibwa, _antè, viyl, 
   {{0xe29805f5,0xe2a8431a,0x69c85a7a,0xe8181d7d}},	//   маг_, وازن_, ljee, _नीचा_, 
   {{0x61f40342,0x65645a7b,0x7dfc0270,0x6e285a7c}},	//   tiyl, pakh, lōse, _oheb, 
   {{0x69c85a7d,0x2444001e,0x1718010f,0x57b001af}},	//   njee, _tôm_, _קוקע, _ббәт, 
   {{0xdb180d29,0x61f45a7e,0x68e80bd7,0xb5a801ec}},	// [63c0] _entè, riyl, nzed, _سايك_, 
   {{0x61f45a7f,0x6e2802ce,0x29d0011f,0x69c8023a}},	//   siyl, _aheb, _xáar_, hjee, 
   {{0x6e285a80,0xa2e40107,0x61f45a81,0x1e845a82}},	//   _bheb, _ронд, piyl, тлем, 
   {{0x6e285a83,0x69c85a84,0xdddc02b5,0x61440408}},	//   _cheb, jjee, mupū, _шема, 
   {{0xdb185a85,0xdc2815fa,0x3bd0002e,0x6e285a86}},	//   _inté, وسته_, _sàqq_, _dheb, 
   {{0x68e85a87,0x6e280086,0x69c83424,0x628c017a}},	//   dzed, _eheb, ejee, otbo, 
   {{0x628c5a88,0x6e2801ab,0x6d581418,0x3c2000e4}},	//   ntbo, _fheb, bbwa, sòvo_, 
   {{0x225c0232,0x6e285a89,0x63ac003e,0x68e801c7}},	//   átky_, _gheb, hdbn, fzed, 
   {{0xdddc00b0,0xc0d401f3,0xd7e40a4a,0x4b20013d}},	//   hupū, ከተሉ_, віно, лмәв, 
   {{0x69c80083,0xdddc00b0,0x3bd0002e,0x6e280165}},	//   ajee, kupū, _tàqq_, _zheb, 
   {{0x628c5a8a,0xc214013f,0x81e800fe,0x00000000}},	//   jtbo, koɔ_, _বদন_, --, 
   {{0x6e28036e,0x68e803e0,0x00000000,0x00000000}},	//   _xheb, bzed, --, --, 
   {{0x628c5a8b,0x29540801,0xc214013f,0xf79400cf}},	//   etbo, _съхр, doɔ_, _балэ, 
   {{0x628c5a8c,0xdb185a8d,0x090004a9,0xbb4c0220}},	//   ftbo, _anté, _әпән, _ﺃﻨﻪ_, 
   {{0xd90c006c,0xc2140134,0x7768022e,0x86c000f1}},	//   _دیک_, foɔ_, madx, _نيون, 
   {{0x63ac00a3,0x77680009,0x00000000,0x00000000}},	//   adbn, ladx, --, --, 
   {{0x6e280072,0x6fb85a8e,0x04c800f1,0xd404022e}},	// [63d0] _rheb, нгар_, _لويي_, _аяни, 
   {{0x6e285a8f,0x73c40961,0x9f58033b,0x00000000}},	//   _sheb, _сәме, wopò_, --, 
   {{0x628c0066,0x6e285a90,0x69c85a91,0x6d5802d0}},	//   ctbo, _pheb, yjee, tbwa, 
   {{0xbb4c01ec,0x69c8058a,0xfe7000f2,0x00000000}},	//   _ﺃﻨﻨ_, xjee, زدم_, --, 
   {{0xdd8c50e4,0xc0d4001f,0x9f580100,0x8bf000c7}},	//   سوو_, ከተል_, ropò_, аҧах, 
   {{0xe4f4375c,0xab285a92,0x316801c7,0xcee8027d}},	//   ीपति_, нола_, laaz_, _قرأن_, 
   {{0x6e285a93,0xfb840953,0xbe880640,0x69c8002d}},	//   _theb, рычн, _исте_, tjee, 
   {{0x6e2807a8,0xc33404ae,0x68e801c7,0x201000d0}},	//   _uheb, סוק_, tzed, ľniť_, 
   {{0x69c85a94,0x29c801e0,0x201000d0,0xca480150}},	//   rjee, _үтеү_, žniť_, _ﺃﺸﺩ_, 
   {{0x68e814cf,0x69c85a95,0xfbd000f1,0xdb1801ef}},	//   rzed, sjee, _وتل_, _hotý, 
   {{0x628c5a96,0x68e858ad,0xaa544c70,0xdb180022}},	//   xtbo, szed, _свеш, _kotý, 
   {{0x31680009,0xdce00427,0x00000000,0x00000000}},	//   jaaz_, zaoč, --, --, 
   {{0xdb180122,0xe4d80133,0x628c0142,0x00000000}},	//   _motý, روست_, wtbo, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc214013f,0x291c010b,0x00000000,0x00000000}},	//   toɔ_, _hywa_, --, --, 
   {{0x628c5a97,0xa0a401d5,0xdb18013a,0x00000000}},	//   rtbo, лабд, _notý, --, 
   {{0x59b41d15,0xf4840798,0x00000000,0x00000000}},	// [63e0] _अफसर, _куќн, --, --, 
   {{0x5f7400c6,0x4ab00406,0x321801f4,0xdb18032e}},	//   طائر, ंटाव, _eksy_, _rotþ, 
   {{0xdb18003a,0x0c8001e0,0x00000000,0x00000000}},	//   _antî, ҡышм, --, --, 
   {{0xfc540023,0x527808d8,0x8fa001ec,0x00000000}},	//   _ዝተገል, _אנטא, _қасе, --, 
   {{0x291c5a98,0x9e6400aa,0xbcc40184,0xdb1802fb}},	//   _nywa_, _څارن, шҡал, _dotý, 
   {{0xdd9007d6,0x9e641893,0x00000000,0x00000000}},	//   _گور_, _مارن, --, --, 
   {{0x291c020c,0xdee45a99,0xd0045a9a,0x68440092}},	//   _aywa_, _сови, _сере_, _የሁለት, 
   {{0xdd903e1a,0x291c033f,0x3eb8002f,0x1a240014}},	//   _دور_, _bywa_, _irrt_, درتُ, 
   {{0x2fd001a9,0x00000000,0x00000000,0x00000000}},	//   _yozg_, --, --, --, 
   {{0x089406d5,0x97a45a9b,0x291c0618,0x3eb80200}},	//   اضيع_, урил, _dywa_, _krrt_, 
   {{0x75d40769,0xb6c45a9c,0x693401ef,0x0f7800df}},	//   ليدا, рөлд, _přeú, ערטל, 
   {{0xd9441b88,0x38c85a9d,0x0f34008f,0x58840006}},	//   _седи, _لاتی_, טריט_, _быка, 
   {{0x3f98022e,0xdb2401b9,0xf8a800c5,0x34940e92}},	//   _obru_, _شوچی, _कनिय, јагр, 
   {{0x6034007f,0x00000000,0x00000000,0x00000000}},	//   _fņmi, --, --, --, 
   {{0x6b9437be,0x41e01546,0x00000000,0x00000000}},	//   _özge, नसंस, --, --, 
   {{0x3f980327,0x7a2c0af2,0x00000000,0x00000000}},	//   _abru_, sûtf, --, --, 
   {{0xdb18033f,0xf4840244,0x00000000,0x00000000}},	// [63f0] _kotó, _ئابی, --, --, 
   {{0x291804cc,0x2fd0022e,0x1ae80154,0x4fc45a9e}},	//   üsai_, _qozg_, _কখনই_, ысба, 
   {{0xb88801e4,0xdb185a9f,0xae0000bc,0x2ef400ea}},	//   _daŭɾ, _potý, लचलन_, јзер, 
   {{0x659800b0,0x3f98083c,0xdb18012d,0x00000000}},	//   _tāhō, _ebru_, _lotó, --, 
   {{0x6b645aa0,0xe1f4030d,0x00000000,0x00000000}},	//   акла, _тӳр_, --, --, 
   {{0xeb985aa1,0x9cb00075,0xdb180798,0x2078008f}},	//   тик_, زمىت, _notó, _באשא, 
   {{0xaed459e6,0x291c005a,0xda605aa2,0x2618002b}},	//   _товш, _sywa_, овщи, _ṣoma_, 
   {{0x28b0060c,0x99d000d1,0x2ee007b6,0x60e80205}},	//   जिलि, ققىت, पनीत, _öpmü, 
   {{0xdb181280,0x6fc802ab,0x8aa400d1,0x96080154}},	//   _botó, रापं, _әрзд, রতাম_, 
   {{0xdb180077,0xa7640826,0xe7383edd,0x3c48010f}},	//   _cotó, шкод, кеп_, _ערבֿ_, 
   {{0xe9745aa3,0x65c45aa4,0x7a080118,0x00000000}},	//   _نهاد, абна, mětn, --, 
   {{0x291c03d1,0x24800ac5,0x1aec02f5,0xba740150}},	//   _tywa_, tukm_, _চুকে_, _داكت, 
   {{0xdb185aa5,0x291c50d4,0xa7a80022,0xa87800df}},	//   _fotó, _uywa_, _акла_, _סאַר, 
   {{0xdb180034,0xec34010f,0x00000000,0x00000000}},	//   _gotó, יאָר_, --, --, 
   {{0x6fc8189a,0xbb2400d1,0xd7f8011a,0x00000000}},	//   रानं, _ﭼﯩﻦ_, _שהצל, --, 
   {{0x168404d3,0x24f402bf,0x00000000,0x00000000}},	//   _ئاوێ, _вчор, --, --, 
  
   {{0x1f645aa6,0x64a45aa7,0xa06846bf,0x91e00a5b}},	// [6400] икам, _тапа, таза_, цоте, 
   {{0x64545aa8,0xa3e84709,0x0fc00351,0x1f5401a9}},	//   _ityi, _मति_, ойун, ртаё, 
   {{0xd378159d,0x5d6811ed,0x1ec80801,0xdb180100}},	//   _בריט, вием_, ължи_, _lotò, 
   {{0xdb182045,0x6604003e,0x908400db,0x00000000}},	//   _votü, nnkk, انەك_, --, 
   {{0xdcb01b16,0xf3c804fb,0xdb1800db,0x9cf40640}},	//   تىش_, _شبیه_, _notò, јчеш, 
   {{0x3e6804fb,0x0bf00212,0xd1b80092,0x09ac00fe}},	//   _مجری_, опію, ደናቂ_, কাফা, 
   {{0x09ac015b,0x3ce008a4,0x00000000,0x00000000}},	//   কানা, šiv_, --, --, 
   {{0x83f0013f,0x99d401d3,0x6d4c002e,0x00000000}},	//   _kwɑs, شتعا, ñaat, --, 
   {{0xdb185aa9,0x7a2c0b21,0x00000000,0x00000000}},	//   _intí, jûte, --, --, 
   {{0x2ca807ea,0xc7d4023a,0xabc401ee,0x00000000}},	//   çade_, имых_, _лауҙ, --, 
   {{0x64545aaa,0x8c180375,0xec3407d6,0x61e402d0}},	//   _atyi, _יומי, _اولگ, _olkl, 
   {{0xdb184d74,0xc9800abe,0x7a2c0129,0xd56400d8}},	//   _fotò, _души, fûte, штоп, 
   {{0x53445aab,0x6a500421,0xd90c150e,0x65740042}},	//   ихва, _vāfe, _زید_, _ddyh, 
   {{0x61e45aac,0xc7a0013d,0xdb18054e,0x07a0466a}},	//   _alkl, _мичк, _intâ, _мачн, 
   {{0x645400f1,0x6a505aad,0xd244009d,0x00000000}},	//   _etyi, _tāfe, рэги, --, 
   {{0x4e78069c,0x51840261,0x7a2c000f,0xc3301411}},	//   _ኣፍሪቃ_, јува, bûte, بەپ_, 
   {{0x629c0bdf,0x4f685882,0xfe70004b,0x8f445aae}},	// [6410] _eppo, вшем_, ېده_, ахед, 
   {{0x7ff41001,0x61e401e4,0x09d0041c,0x926801af}},	//   يسلا, _elkl, _तव्य, _ирма_, 
   {{0xb8c8081f,0x6fc80034,0x629c009f,0x0dc85aaf}},	//   _བག_, राबं, _gppo, куди_, 
   {{0xa354004b,0x00000000,0x00000000,0x00000000}},	//   _پریږ, --, --, --, 
   {{0x645402c4,0x7eb001ed,0xd01802a9,0xacf8084c}},	//   _xtyi, tópá, _афв_, ынду_, 
   {{0xaa445ab0,0x629c02d0,0x68ec010e,0x7b4400d1}},	//   бекл, _yppo, _ýadi, يئىل, 
   {{0x8d840032,0x7eb001ed,0x00000000,0x00000000}},	//   _вузд, rópá, --, --, 
   {{0x09ac009e,0x00000000,0x00000000,0x00000000}},	//   কাভা, --, --, --, 
   {{0x29000134,0xbca4007b,0x3934009d,0x00000000}},	//   _ɛhaw_, _ومفي, жээс, --, 
   {{0x57e45ab1,0x7d04007b,0x00000000,0x00000000}},	//   йдым_, úise, --, --, 
   {{0xc4d01944,0xe568009d,0x09ac00eb,0x64a40124}},	//   सङ्ख, линд_, কাবা, әага, 
   {{0xf9901216,0xdb18067c,0x7a080118,0x64a4033a}},	//   _يبن_, _totò, nětl, бама, 
   {{0x53c007b7,0x00000000,0x00000000,0x00000000}},	//   शांश, --, --, --, 
   {{0x64485ab2,0x9f58067c,0x5ee800dc,0x7a2c000f}},	//   _ōfis, cipè_, चनम्_, rûte, 
   {{0xdb1800d8,0x09ac0154,0xf7f406c2,0x00000000}},	//   _intã, কাঠা, _بسند, --, 
   {{0x2d8c0218,0xa6c800ec,0x00000000,0x00000000}},	//   _ncee_, _لوڪل_, --, --, 
   {{0x645400f1,0x9f585ab3,0x60085ab4,0xe04815eb}},	// [6420] _utyi, lipé_, гнам_, اشره_, 
   {{0xd12c5ab5,0x2d8c0548,0x25b00009,0x00000000}},	//   رمل_, _acee_, _hayl_, --, 
   {{0x629c5ab6,0xa1345ab7,0x2d8c0036,0x25b004e6}},	//   _uppo, _گردش, _bcee_, _kayl_, 
   {{0xdfd000b2,0xc0cc0020,0x00000000,0x00000000}},	//   _کيس_, _አጭር_, --, --, 
   {{0x30745ab8,0xa1340597,0x25b05ab9,0x93c801d9}},	//   _мурс, _دردش, _mayl_, _شایہ_, 
   {{0x2a640042,0x25b00009,0xd24c0345,0x00000000}},	//   _bwlb_, _layl_, _تنێ_, --, 
   {{0x224008fb,0x25b00076,0x2cac0790,0xd7f800d1}},	//   _kikk_, _oayl_, _esed_, ғуп_, 
   {{0x2d8c05d5,0xdb1800d8,0x25b0058a,0xd2b4011a}},	//   _gcee_, _antã, _nayl_, מלצת_, 
   {{0x5ac85aba,0x224000c5,0x00000000,0x00000000}},	//   _әлем_, _mikk_, --, --, 
   {{0xf674005b,0xf6980114,0x48a40395,0x00000000}},	//   огоэ, авој_, стъм_, --, 
   {{0xaae400f7,0x50180302,0x25b00009,0x0c940150}},	//   _وسمو, רויו, _bayl_, _ندەگ, 
   {{0xdb180cfc,0x6034007f,0x68ec033f,0x18685abb}},	//   _entã, _kņms, _żade, _бади_, 
   {{0x20185abc,0x25b00009,0x69dc01f4,0x00000000}},	//   kopi_, _dayl_, ösee, --, 
   {{0x25b0062c,0x20185abd,0x4810003b,0x00000000}},	//   _eayl_, jopi_, _еміс, --, 
   {{0x20185abe,0x9f585abf,0x25b05ac0,0xb5945ac1}},	//   dopi_, cipé_, _fayl_, _дийш, 
   {{0x224000dd,0xbbb400dc,0xd9a40037,0xf1580107}},	//   _cikk_, ंयुक, _खसोट, риаш_, 
   {{0x6a500bba,0x22401bce,0x7a08012c,0x2ee000cd}},	// [6430] _māfa, _dikk_, větl, पन्त, 
   {{0x752c08ad,0x9f540008,0xdb180ba1,0x201801c8}},	//   _izaz, ögðu_, _ontà, gopi_, 
   {{0x224010f5,0xc454036b,0x56080154,0xdeb002dd}},	//   _fikk_, _وضیع, রতীক_, мұры, 
   {{0x224000d6,0x00000000,0x00000000,0x00000000}},	//   _gikk_, --, --, --, 
   {{0x201827be,0xc0cc0020,0xdb182549,0x32085ac2}},	//   bopi_, _አርሶ_, _antà, mnay_, 
   {{0x32085ac3,0x752c0451,0xfd105ac4,0x20180784}},	//   lnay_, _mzaz, رجن_, copi_, 
   {{0x32085ac5,0x00000000,0x00000000,0x00000000}},	//   onay_, --, --, --, 
   {{0x32085ac6,0x2d8c0998,0x752c5ac7,0x660c01e4}},	//   nnay_, _ucee_, _ozaz, _ĉako, 
   {{0x2cac5ac8,0x765802d5,0x752c0526,0xdb18180f}},	//   _used_, _atvy, _nzaz, _entà, 
   {{0xfe7001ed,0x32085ac9,0x25b006be,0x00000000}},	//   _زدہ_, hnay_, _sayl_, --, 
   {{0x752c0223,0x32085aca,0xe7285acb,0xbb4800ae}},	//   _azaz, knay_, ронд_, _المن_, 
   {{0x291805d5,0x25a40055,0x00000000,0x00000000}},	//   üsas_, _ṛṣṭa, --, --, 
   {{0x3e480365,0x320814dc,0x22405acc,0x25b05acd}},	//   _işte_, dnay_, _rikk_, _vayl_, 
   {{0x66e45ace,0x752c006f,0x20180564,0x22401bce}},	//   _мола, _dzaz, xopi_, _sikk_, 
   {{0x752c5acf,0x224000af,0xdddc0356,0x32085ad0}},	//   _ezaz, _pikk_, nupţ, fnay_, 
   {{0x32085ad1,0x752c0175,0xe6100244,0x00000000}},	//   gnay_, _fzaz, _تشت_, --, 
   {{0x20185ad2,0xa1840032,0xc0cc0092,0x00000000}},	// [6440] topi_, йыҡл, _አርሲ_, --, 
   {{0x32085ad3,0x22400204,0x00000000,0x00000000}},	//   anay_, _wikk_, --, --, 
   {{0x44445ad4,0x5ea42b49,0x61445ad5,0x32085ad6}},	//   _ii_, تمال, _мена, bnay_, 
   {{0x44445ad7,0x5ce4247f,0x201823e0,0x6d4c0113}},	//   _hi_, يكال, sopi_, ñaap, 
   {{0x20185ad8,0x0f1c001f,0x2d40010e,0x00000000}},	//   popi_, ዳመለከ, _ỳer_, --, 
   {{0x44445ad9,0x2ca85ada,0x88cc045e,0xdb185adb}},	//   _ji_, çada_, িনাক, _antá, 
   {{0x75ec000f,0xa3b000c5,0x5d74014b,0x00000000}},	//   _hûze, _ऐसन_, _муаф, --, 
   {{0x7a2c0129,0xb07408a5,0x00000000,0x00000000}},	//   fûta, _óþör, --, --, 
   {{0x44445adc,0xa3e8041c,0xd8080395,0x00000000}},	//   _oi_, _मतं_, ихол_, --, 
   {{0x44445add,0x10980302,0xec100075,0x75ec000f}},	//   _ni_, סביב, _كۈند, _mûze, 
   {{0x32085ade,0x6a500421,0x291804cc,0x7c3805c7}},	//   ynay_, _tāfa, üsar_, mmvr, 
   {{0x44445adf,0x69a013b4,0x32085ae0,0x98e40395}},	//   _ai_, _कॉपी, xnay_, _мюлд, 
   {{0x7c38017a,0x22580064,0x94000116,0x320803ac}},	//   omvr, _atpk_, җоңҗ, vnay_, 
   {{0x44445ae1,0xa3e800cd,0x32085ae2,0x00000000}},	//   _ci_, _मतः_, wnay_, --, 
   {{0x32085ae3,0x6fc85ae4,0x00000000,0x00000000}},	//   tnay_, रासं, --, --, 
   {{0x44380421,0x32080165,0xdb18007c,0xa1480014}},	//   amr_, unay_, _fotö, ٕسٕے_, 
   {{0x320830e0,0x752c4793,0x4438009a,0x3ce400e1}},	// [6450] rnay_, _uzaz, bmr_, कनों_, 
   {{0x44445ae5,0x320814dc,0xceb80114,0x66700244}},	//   _gi_, snay_, иље_, _تگیر, 
   {{0xb8fc0156,0x44440014,0xaad80073,0x320858d7}},	//   _ལཝ_, _ترٹہ, _बॅंक, pnay_, 
   {{0x44445ae6,0xbbc800b5,0x0f500023,0x32085ae7}},	//   _zi_, _ｈメ_, _ዝጀመረ, qnay_, 
   {{0x44445ae8,0x53dc0490,0xbc64177b,0xa36801a9}},	//   _yi_, _नकाश, двік, _plеx, 
   {{0x44445ae9,0x26d00030,0xaa44003b,0x00000000}},	//   _xi_, äzok_, пекл, --, 
   {{0x37d0015b,0x00000000,0x00000000,0x00000000}},	//   িসার, --, --, --, 
   {{0xdddc0276,0x9f940008,0x7d280162,0x14c8043e}},	//   rupţ, _hæð_, ðssæ, ामाण, 
   {{0x6d48005a,0x00000000,0x00000000,0x00000000}},	//   _igea, --, --, --, 
   {{0xcc8404d3,0x6aa0022f,0xa6845aea,0x6d485aeb}},	//   _هۆڵه_, _tplf, плод, şmağ, 
   {{0x44445aec,0xe618085a,0xdb185aed,0xdddc00d7}},	//   _ri_, йдо_, _botõ, lupš, 
   {{0x64a402d5,0xc9840276,0x00000000,0x00000000}},	//   пама, _фужи, --, --, 
   {{0x44445aee,0x69d80086,0xd83c0219,0xc44801d5}},	//   _pi_, _iowe, ščal_, غیدن_, 
   {{0x44445aef,0x69d80302,0xdb1801b8,0x225805b1}},	//   _qi_, _howe, _votö, _ptpk_, 
   {{0x232823b3,0xaabc146b,0x443800b5,0xdb0801bf}},	//   сови_, ्मिक, rmr_, adfæ, 
   {{0x44445af0,0x69d806cc,0x6a500607,0x6d485af1}},	//   _wi_, _jowe, _lāfo, _ngea, 
   {{0x44445af2,0x69d85af3,0x9f9403b2,0x28b00034}},	// [6460] _ti_, _mowe, _bæð_, जिटि, 
   {{0x44445af4,0xaabc2f2e,0x69d85af5,0x6d485af6}},	//   _ui_, ्माक, _lowe, _agea, 
   {{0x69d85af7,0xb37c0023,0x00000000,0x00000000}},	//   _oowe, _ንምዃን_, --, --, 
   {{0x69d85af8,0x75ec0b21,0x00000000,0x00000000}},	//   _nowe, _tûze, --, --, 
   {{0x91b80375,0x9f58004e,0x5d18007b,0x00000000}},	//   _המכי, lipí_, حتاج_, --, 
   {{0x6d485af9,0x69d802b1,0x9f9402d2,0x01a801f7}},	//   _egea, _aowe, _gæð_, _اُڏي_, 
   {{0x6fc813b4,0x00000000,0x00000000,0x00000000}},	//   रारं, --, --, --, 
   {{0x69d85afa,0x386027ac,0x00000000,0x00000000}},	//   _cowe, _çirk_, --, --, 
   {{0x69d85afb,0x39145a0b,0x9c64158b,0x7fa00150}},	//   _dowe, ьмир, _رهاو, _ﺍﯕﯩﺲ_, 
   {{0x69d80086,0x00000000,0x00000000,0x00000000}},	//   _eowe, --, --, --, 
   {{0x2ab40570,0x69d81c1d,0x9a181cb8,0xaac400ae}},	//   rùbá_, _fowe, _люду_, _يتمن, 
   {{0x69d85afc,0x00000000,0x00000000,0x00000000}},	//   _gowe, --, --, --, 
   {{0xd7e41c26,0x00000000,0x00000000,0x00000000}},	//   _ніко, --, --, --, 
   {{0x49381203,0x69d80936,0xdef000b7,0x00000000}},	//   _הגדו, _zowe, ጌልን_, --, 
   {{0x82a45afd,0x7bc805b1,0x9f58026c,0x35f406ed}},	//   нште, _mndu, ripì_, _опкр, 
   {{0x82345afe,0x9f940579,0xdb1801e6,0xdb08007c}},	//   فرقا, _sæð_, _intä, mdfä, 
   {{0x7bc85aff,0xdb085b00,0x324402dd,0x00000000}},	// [6470] _ondu, ldfä, зеңг, --, 
   {{0x6d480192,0x00000000,0x00000000,0x00000000}},	//   _sgea, --, --, --, 
   {{0x8d740150,0xdb0840fc,0x6d480175,0x66840092}},	//   كاشا, ndfä, _pgea, _በተስፋ_, 
   {{0x2ca806ed,0xf1e00073,0x850400f2,0x00000000}},	//   çado_, _नविन, _آوین, --, 
   {{0x69d85b01,0x61d40375,0x9f9403b2,0x00000000}},	//   _rowe, _חורף_, _tæð_, --, 
   {{0x69d85b02,0x3e740124,0xea580a5b,0x00000000}},	//   _sowe, _ẽtee_, ориј_, --, 
   {{0x69d85b03,0x6d4807de,0xcae4012d,0x40340f06}},	//   _powe, _tgea, टैंड_, _черс, 
   {{0x6d48037e,0x7bc85b04,0xbdf80592,0xade800f2}},	//   _ugea, _endu, _فرقا_, _بفرم_, 
   {{0x69d85b05,0xe8f82143,0xdb18007c,0x6ce400f1}},	//   _vowe, юли_, _antä, _تړان, 
   {{0x69d85b06,0xdb180419,0x00000000,0x00000000}},	//   _wowe, _potô, --, --, 
   {{0x69d85b07,0x00000000,0x00000000,0x00000000}},	//   _towe, --, --, --, 
   {{0xf3e81203,0xf99004d3,0x00000000,0x00000000}},	//   _דף_, _مبه_, --, --, 
   {{0x7bc80b21,0x09280150,0xdb185b08,0xddcc0c5e}},	//   _yndu, _اساي_, _entä, _dubň, 
   {{0x33d45b09,0x998401af,0xd8a401f7,0x00000000}},	//   ніст, _етәһ, _آڇيو_, --, 
   {{0x31bc0131,0x3e480139,0x00000000,0x00000000}},	//   ﻧﻠﯩﻜ, _oşta_, --, --, 
   {{0x9f585b0a,0x00000000,0x00000000,0x00000000}},	//   kipã_, --, --, --, 
   {{0x9f580270,0xdb1801e3,0x80c803ce,0x00000000}},	// [6480] sipí_, _intå, रमें, --, 
   {{0xdfa40597,0xdee45b0b,0x65640327,0xd00c33d2}},	//   بحري, мози, lbkh, للق_, 
   {{0xc2f800fe,0x2d9c04ba,0x5e5800ae,0x00000000}},	//   _আঁকি_, ffwe_, زجاج_, --, 
   {{0xdb085b0c,0x320401d3,0x65640332,0x0dc40835}},	//   befê, élyt_, nbkh, души_, 
   {{0xa3b02007,0x68ec068f,0x7bc805b1,0xa3e02aa1}},	//   _ऐसा_, _żadn, _pndu, _दवा_, 
   {{0x69dc0793,0xdbc40209,0xfc1401c0,0x2d9800ee}},	//   ösen, _möçb, эмлэ, _ösen_, 
   {{0xc9580051,0x00000000,0x00000000,0x00000000}},	//   _từlâ, --, --, --, 
   {{0x2d945b0d,0xdb08036e,0xf8b8004e,0x00000000}},	//   _прус, lefë, зөк_, --, 
   {{0x50d8008f,0xdcec00e2,0xd00c00e5,0x00000000}},	//   ַקטא, ājēj, _صلہ_, --, 
   {{0x7bc85b0e,0x4b8406d3,0x9f480306,0x77980137}},	//   _undu, _ойун_, _blbé_, чкор_, 
   {{0xf67401c6,0x1a94007b,0xb59401ec,0x48100139}},	//   эгнэ, _زجاج, нинш, тмэс, 
   {{0x236401fa,0xdb083bd2,0xaabc521a,0x00000000}},	//   _đoja_, hefë, ्मरक, --, 
   {{0xb6f80137,0x00000000,0x00000000,0x00000000}},	//   زىڭا_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb18002f,0x5fd000bc,0xd5b80229,0x07a01d39}},	//   _untä, सानल, _дсп_, _рајн, 
   {{0x3494004e,0xbb4c01ec,0x70584530,0x95c8011c}},	//   _заир, _ﺃﻨﻔ_, заар_, _фука_, 
   {{0x44b45b0f,0xb034341e,0x26d000d7,0x00000000}},	// [6490] _абыс, енаш, äzov_, --, 
   {{0x67ec00d2,0xdb0801c7,0x7dfc0100,0x661c00d0}},	//   _kúja, gefë, mčsy, čske, 
   {{0x539c02d3,0x2d9c1cea,0x00000000,0x00000000}},	//   _ልምዓት_, tfwe_, --, --, 
   {{0xed3405f5,0xbdf80efe,0x00000000,0x00000000}},	//   нэлэ, ورنا_, --, --, 
   {{0xdb0800db,0x00000000,0x00000000,0x00000000}},	//   lefè, --, --, --, 
   {{0x9f585b10,0x69a0012c,0x4ea42f5c,0x00000000}},	//   ripã_, क्नी, _орба, --, 
   {{0xaa440617,0x7f945b11,0x41c400bc,0xd7d00073}},	//   ىنتى, _шарх, _लोडस, तानच, 
   {{0x8d7404d3,0x9f580093,0x00000000,0x00000000}},	//   _زارا, mipá_, --, --, 
   {{0x6d585b12,0x3d100073,0xe4f40118,0x00000000}},	//   mcwa, तपणे_, ीपछि_, --, 
   {{0x6d585b13,0x5fd02ce6,0x67ec02d2,0xead40153}},	//   lcwa, सायल, _búja, _позь, 
   {{0x66e41d56,0x7a0800bc,0xda4400f1,0x66040395}},	//   хона, větv, _ګڼون_, епна, 
   {{0x6d58124c,0x6abc5b14,0x59a401ad,0xdb080036}},	//   ncwa, ्मीर, _कॉपर, zefë, 
   {{0x6d5802d0,0x00000000,0x00000000,0x00000000}},	//   icwa, --, --, --, 
   {{0x6d5802d0,0x966001ec,0x00000000,0x00000000}},	//   hcwa, _өкше, --, --, 
   {{0xe5a400d1,0x21a400d8,0x00000000,0x00000000}},	//   _зийи, нивм, --, --, 
   {{0x93400354,0x6d5802d0,0xe194009d,0x00000000}},	//   унсе, jcwa, эргэ, --, 
   {{0x660432ff,0xbf0843d1,0x6d5803ac,0x00000000}},	// [64a0] mikk, वप्न_, dcwa, --, 
   {{0x66045b15,0x21ec013a,0x00000000,0x00000000}},	//   likk, _dýha_, --, --, 
   {{0xb4000f78,0x9f580109,0x5fd0012c,0x63ac0427}},	//   _түрд, ripà_, साबल, mebn, 
   {{0x66045b16,0x6d582747,0x628c5b17,0x63ac5b18}},	//   nikk, gcwa, mubo, lebn, 
   {{0x6604020c,0x6300015b,0x5ba000fb,0x8d600798}},	//   iikk, _এডিট_, лһағ, увче, 
   {{0x66045b19,0xdb180077,0xec340ec9,0xa03400db}},	//   hikk, _intú, نونگ, _سىزت, 
   {{0x66045b1a,0x628c5b1b,0x9f580789,0xc0f0001f}},	//   kikk, nubo, cipá_, _ሀይሉ_, 
   {{0x6d5803ac,0x00000000,0x00000000,0x00000000}},	//   ccwa, --, --, --, 
   {{0x66045b1c,0x628c5b1d,0x994801d3,0x00000000}},	//   dikk, hubo, _ہلال_, --, 
   {{0x628c124c,0x48100046,0x63ac08fb,0xed3400a8}},	//   kubo, лмыс, jebn, _рэсэ, 
   {{0x63ac0316,0x702c001f,0x628c5b1e,0x8c18010f}},	//   debn, ዳለባቸ, jubo, _צובי, 
   {{0x66040af5,0x00000000,0x00000000,0x00000000}},	//   gikk, --, --, --, 
   {{0x9f5802ea,0x9dcc01ec,0x00000000,0x00000000}},	//   zipá_, ртiп, --, --, 
   {{0x63ac0639,0xd258005b,0x80c43599,0xdb08007f}},	//   gebn, зца_, रिने, tefè, 
   {{0x66042f99,0x628c5b1f,0xdb180789,0x87d400f2}},	//   bikk, gubo, _antú, _سبوس_, 
   {{0xc0cc0020,0xdb085b20,0x59a406ab,0xd4980334}},	//   _አርም_, gefé, _कॉमर, _еро_, 
   {{0x63ac009a,0x00000000,0x00000000,0x00000000}},	// [64b0] bebn, --, --, --, 
   {{0x63ac0009,0x6d5803ac,0x00000000,0x00000000}},	//   cebn, wcwa, --, --, 
   {{0xc0f0001f,0x6d5802d0,0x00000000,0x00000000}},	//   _ሀይል_, tcwa, --, --, 
   {{0x317800df,0x00000000,0x00000000,0x00000000}},	//   _קאָד, --, --, --, 
   {{0x3168155d,0xa17408a8,0x6d5802d0,0x00000000}},	//   mbaz_, _בערד_, rcwa, --, 
   {{0xed14066d,0x66045b21,0x2438001f,0xeab000c6}},	//   _یہاں_, zikk, _በቅድሚ, لعب_, 
   {{0x66045b22,0x6d5802d0,0x7b6400d8,0x00000000}},	//   yikk, pcwa, утче, --, 
   {{0x9b540184,0x63ac5b23,0x6604013c,0x92dc03d4}},	//   ниәт_, zebn, xikk, _দেৱ_, 
   {{0x80c42ecf,0x6a500418,0x66045b24,0x628c5b25}},	//   रिये, _māfi, vikk, zubo, 
   {{0x66042041,0xdb0804e6,0x31684dd9,0x00000000}},	//   wikk, zefé, hbaz_, --, 
   {{0x66045b26,0x63ac0e96,0xdb180798,0x5fd023e9}},	//   tikk, vebn, _latê, सातल, 
   {{0xa5084476,0x66040194,0xdce00306,0x63ac5b27}},	//   дема_, uikk, zboč, webn, 
   {{0x63ac0316,0x628c2747,0x6d4c0de2,0xc1b400c7}},	//   tebn, wubo, ñaay, қәны, 
   {{0x628c5b28,0x628803cd,0x78a400e4,0xaac45b29}},	//   tubo, _åfok, _ãiva, विपक, 
   {{0x63ac01a2,0x66045b2a,0xa2d00073,0xdb0800e5}},	//   rebn, pikk, डमध्, tefé, 
   {{0x628c5b2b,0x66040140,0x96600354,0x00000000}},	//   rubo, qikk, _ткъе, --, 
   {{0xa3b85b2c,0x628c5b2d,0x66140124,0x60242afd}},	// [64c0] _قادر_, subo, _ijyk, вдаа, 
   {{0x628c014a,0x69a028e0,0x6fc800af,0x00000000}},	//   pubo, क्ती, रागं, --, 
   {{0xc294168d,0x628c5b2e,0x3168030a,0x216801f0}},	//   _حیزب, qubo, bbaz_, _оини_, 
   {{0xaf340116,0x00000000,0x00000000,0x00000000}},	//   ھرەت, --, --, --, 
   {{0x6fc856e9,0xdb085b2f,0x90b0104e,0x1ea800f1}},	//   राखं, ldfø, _вәхш, _ښاري_, 
   {{0xad244e5d,0x3a980166,0x00000000,0x00000000}},	//   درمو, еккэ_, --, --, 
   {{0x66140022,0xdb0812ed,0x2fc402d2,0x00000000}},	//   _ojyk, ndfø, _ólga_, --, 
   {{0xdd905b30,0x7a0800bc,0xdb18036e,0x21ec01ef}},	//   _خور_, věts, _hatë, _mýho_, 
   {{0x1c445b31,0xdb18044e,0xdca40cfc,0xb4b00037}},	//   _анам, _katë, _јази, _ऐने_, 
   {{0x661400a2,0xb7d00154,0xda6401d5,0x00000000}},	//   _ajyk, িস্ট, _авжи, --, 
   {{0x61f45b32,0xa3c407f7,0xdb180240,0x80c401ad}},	//   khyl, ईएन_, _matë, रिडे, 
   {{0xdb18025a,0x60c403ac,0x00000000,0x00000000}},	//   _latë, _orkm, --, --, 
   {{0x3a240156,0x09ac00fe,0x61f42611,0x29400220}},	//   momp_, কাখা, dhyl, _ﻛﻮﭖ_, 
   {{0xdb18044e,0x9f48004e,0x3a2405c7,0x2ca85b33}},	//   _natë, _albí_, lomp_, çadi_, 
   {{0x76a8013f,0x75d406f6,0x60c4127b,0xf778031c}},	//   _bɛye, _ميثا, _arkm, maħ_, 
   {{0xed581326,0x6614069c,0x61f400a9,0x3f980356}},	//   _kaže_, _gjyk, ghyl, _acru_, 
   {{0xdb180de2,0x31685b34,0x30145b35,0x335800a8}},	// [64d0] _batë, rbaz_, гдар, _папэ_, 
   {{0x752c5b36,0xed580219,0x3a24030a,0xc3e401e0}},	//   _iyaz, _maže_, homp_, _көсһ, 
   {{0xdb1802d3,0x3a24030a,0x764c5b37,0xfe70036b}},	//   _datë, komp_, _kiay, قدن_, 
   {{0x752c0337,0x3a2405c7,0x60c401bf,0x3f985b38}},	//   _kyaz, jomp_, _frkm, _ecru_, 
   {{0x3a240156,0x0cc00154,0xdb180200,0xaac400cd}},	//   domp_, ্ন্ত, _fatë, विभक, 
   {{0x32080004,0x764c5b39,0xdb18560d,0xf778031c}},	//   liay_, _liay, _katè, jaħ_, 
   {{0x752c04ba,0x3878001f,0x3a24030a,0x7a0800bc}},	//   _lyaz, _በሁለቱ_, fomp_, větr, 
   {{0xdb185b3a,0x752c5b3b,0x764c5b3c,0x3a240156}},	//   _matè, _oyaz, _niay, gomp_, 
   {{0x6e285b3d,0x752c5b3e,0xdb180100,0xd1d00092}},	//   _ikeb, _nyaz, _latè, _የፎቶ_, 
   {{0xa7b42850,0xa8840150,0x80c407b7,0x00000000}},	//   усиј, _ەلشى, रिते, --, 
   {{0x752c5b3f,0x764c5b40,0x3a24030a,0xe64400f3}},	//   _ayaz, _biay, bomp_, леоп, 
   {{0x752c1421,0x00000000,0x00000000,0x00000000}},	//   _byaz, --, --, --, 
   {{0x764c5b41,0x752c0230,0x3208007f,0xf7780003}},	//   _diay, _cyaz, diay_, baħ_, 
   {{0xdb185b42,0xec34008f,0x7d0400ae,0x15680116}},	//   _batè, טאָר_, úisi, _ﻳﯩﺘﯩ, 
   {{0x61f45b43,0x752c5b44,0xdb18004e,0x6e285b45}},	//   thyl, _eyaz, _catè, _okeb, 
   {{0x764c5b46,0xdb085b47,0x6e2802e3,0x18b40124}},	//   _giay, rdfø, _nkeb, _ргәы_, 
   {{0x68e85b48,0x752c5b49,0xdb180023,0x9fc801c0}},	// [64e0] nyed, _gyaz, _patë, нгаа_, 
   {{0x6e285b4a,0x61f45b4b,0x65745b4c,0x645400b5}},	//   _akeb, shyl, _heyh, _iuyi, 
   {{0xa2e45b4d,0xdb185b4e,0x65745b4f,0x9f040fb4}},	//   _сонд, _gatè, _keyh, دواو, 
   {{0xdb18025a,0x9f480589,0x63bc5b50,0x6574010e}},	//   _watë, _albã_, _hapn, _jeyh, 
   {{0x645423db,0x6a500b23,0x65743923,0x5c045b51}},	//   _juyi, _māfu, _meyh, ляка, 
   {{0x68e80bd7,0x69a04728,0x64545b52,0xdb185b53}},	//   dyed, क्सी, _muyi, _haté, 
   {{0xda485b54,0xdb185b55,0x63bc05da,0x64545a26}},	//   нчил_, _katé, _mapn, _luyi, 
   {{0xc214016b,0x645400ad,0x3a240165,0xdce00790}},	//   nnɔ_, _ouyi, uomp_, caoğ, 
   {{0x68e85b56,0xdb185b57,0x64545b58,0x764c5b59}},	//   gyed, _maté, _nuyi, _riay, 
   {{0x752c5b5a,0xed580384,0xdb185b5b,0x764c5b5c}},	//   _ryaz, _važe_, _laté, _siay, 
   {{0x64545b5d,0x3a245b5e,0x752c2a1f,0x660c0115}},	//   _auyi, pomp_, _syaz, _ĉakr, 
   {{0x64545b5f,0xdb080261,0x65743235,0x68e81418}},	//   _buyi, nefí, _ceyh, byed, 
   {{0x55045b60,0xdb180137,0xc4580108,0xf8b801ee}},	//   учна, _satè, лиях_, _рөй_, 
   {{0xdb185b61,0x752c5b62,0x64540477,0x764c0113}},	//   _patè, _vyaz, _duyi, _wiay, 
   {{0xdb185b63,0x764c5b64,0x32080004,0xc024063f}},	//   _baté, _tiay, tiay_, ọọd_, 
   {{0xdb182047,0x752c0223,0x64541418,0x00000000}},	//   _caté, _tyaz, _fuyi, --, 
   {{0x752c0912,0x63bc0369,0x9f4800db,0x64540337}},	// [64f0] _uyaz, _fapn, _albà_, _guyi, 
   {{0x63bc036b,0x73c40bd6,0xb2740e58,0x00000000}},	//   _gapn, _тәме, _клош, --, 
   {{0x1dc4068f,0xdb1800e8,0x75ec045f,0x6e9802bf}},	//   _रोहत, _faté, _rûzj, твер_, 
   {{0x63bc0232,0x75ec002d,0x68e85b65,0x70945b66}},	//   _zapn, _sûzj, yyed, _камф, 
   {{0xdb08002d,0x3078010f,0xeb0c5b67,0xdce003e0}},	//   jefâ, _באָנ, िप्त_, raoğ, 
   {{0xdce00205,0xdb18013a,0x68e85b68,0x00000000}},	//   saoğ, _zaté, vyed, --, 
   {{0x1dc40037,0x09ac0154,0x5fd000bc,0x00000000}},	//   _रोवत, কাঘা, सारल, --, 
   {{0x6e285b69,0xe76c0139,0xb7d40051,0x00000000}},	//   _ukeb, _köçı, _bảoh, --, 
   {{0x69a04c83,0x65740b97,0x00000000,0x00000000}},	//   क्षी, _reyh, --, --, 
   {{0xd7e411ed,0x64545b6a,0x999c0024,0x65745b6b}},	//   имые_, _ruyi, _butų_, _seyh, 
   {{0x68e85b6c,0x645431c5,0xe5685b6d,0x2470007f}},	//   syed, _suyi, кинд_, wņm_, 
   {{0x63bc5b6e,0xe4c42310,0x6574047e,0x661c0306}},	//   _sapn, айми, _qeyh, čsko, 
   {{0x645407d6,0xdb1806af,0x3e6c0241,0x65740162}},	//   _quyi, _raté, _kòtò_, _veyh, 
   {{0xdb185178,0x6574167a,0x645407a9,0x63bc0455}},	//   _saté, _weyh, _vuyi, _qapn, 
   {{0x23281d83,0xdb185b6f,0x69c40605,0x3e6c002e}},	//   тови_, _paté, _ɔhen, _mòtò_, 
   {{0x64545b70,0x63bc012d,0x5ed400f2,0x00000000}},	//   _tuyi, _wapn, یتاز, --, 
   {{0xdfd008e8,0x63f80014,0x63bc000d,0xa1940131}},	// [6500] يير_, _لفظس_, _tapn, лаңч, 
   {{0x38605b71,0xdb18003e,0xa29c121d,0x4f8401d9}},	//   _éire_, _waté, _ओमप्, لامہ, 
   {{0xc3c40131,0xdb185b72,0x80c432c6,0xf0001719}},	//   _көңл, _taté, रिहे, чүри, 
   {{0x628c0561,0x1278010f,0x00000000,0x00000000}},	//   mrbo, _באטע, --, --, 
   {{0x1c445b73,0xcf880131,0xdcf804f2,0x00000000}},	//   андм, _ﻗﯘﺭﯗ, خراش_, --, 
   {{0x628c0072,0x68ec0209,0x9e645b74,0xdfd01359}},	//   orbo, _ýady, _نارن, _بيس_, 
   {{0x291c0054,0xd0045b75,0xfe700133,0xdd900345}},	//   _axwa_, _тере_, _رگا_, _ووس_, 
   {{0x69a000b8,0x00000000,0x00000000,0x00000000}},	//   क्ली, --, --, --, 
   {{0xd7f85b76,0xf9c4004b,0x628c002f,0x00000000}},	//   вун_, لحکی, hrbo, --, 
   {{0x628c0219,0x999c0153,0x00000000,0x00000000}},	//   krbo, _putų_, --, --, 
   {{0x8f7825f9,0xb6c405f5,0xcf540375,0xabd4004b}},	//   כניק, сөлд, יבית_, _دملګ, 
   {{0xe8f401e0,0x3e4806be,0xed580171,0x18a4030d}},	//   рһә_, _bşti_, _kaža_, _вадм, 
   {{0x628c257c,0xdb1800e4,0xc6184166,0x73c41de6}},	//   erbo, _katï, роях_, бәне, 
   {{0xed580024,0x628c0142,0xaabc00cd,0x52b800eb}},	//   _maža_, frbo, ्मचक, _উপবৃ, 
   {{0x3e48084c,0xed580cf4,0x0838011a,0x07400150}},	//   _eşti_, _laža_, _שעול, _ﻛﺎﯓ_, 
   {{0x41680640,0xdb080174,0xd7100210,0x00000000}},	//   ијум_, ldfó, डपीठ_, --, 
   {{0xed585b77,0xdb0805da,0xc05802d5,0xe81c1d24}},	// [6510] қол_, hefà, аіх_, _पदमा_, 
   {{0x76581459,0x3e8c0023,0x2c6c0248,0x0ee80022}},	//   _kuvy, _ኣውሮጳ_, _lódò_, кьеи_, 
   {{0x8d745b78,0x628c037e,0x2fc0017a,0x560803d4}},	//   لاشا, crbo, rdhg_, ৰতীক_, 
   {{0x59a4069f,0x76581446,0xaac4012c,0x683c5b79}},	//   _कॉलर, _muvy, विसक, mède, 
   {{0xfd105b7a,0x81c4215c,0x3e7c5b7b,0x6b640024}},	//   وجه_, _بەقۇ, _pátá_, бкла, 
   {{0x5fcc000d,0xed5800ef,0x00000000,0x00000000}},	//   _होपल, _daža_, --, --, 
   {{0x76585b7c,0x28a8000d,0x00000000,0x00000000}},	//   _nuvy, _कहहि, --, --, 
   {{0xdb185b7d,0x3d94136b,0x31780210,0x00000000}},	//   _antó, _миср, _jesz_, --, 
   {{0xd7d00490,0xed5801a6,0x31785380,0xec700451}},	//   तांच, _gaža_, _mesz_, _رٿا_, 
   {{0x3178066d,0x67ec00d2,0x7a2c00d2,0xaa5802e8}},	//   _lesz_, _kúji, fûts, _бижу_, 
   {{0x7980063f,0x2c6c0241,0x0ca4000d,0x53c80b4e}},	//   _ịweb, _fódò_, _गहुम, ायनश, 
   {{0xdb18172e,0xf3e80bd4,0xaa0801d9,0xf9d40304}},	//   _entó, _אף_, _حٲصل_, _мохэ, 
   {{0x5a08008f,0x1d98001f,0x693421cb,0x00000000}},	//   _גלײַ, ቀሳቃሽ_, _унду, --, 
   {{0xe2985b7e,0xe7380116,0xd2a43c1a,0xa2e400f3}},	//   лаг_, _йел_, әкте_, богд, 
   {{0x2ba82e3b,0xe6940597,0x628c0430,0x48ec0118}},	//   च्या, _العد, urbo, इनको_, 
   {{0x80c40d01,0x83f0013f,0x628c01e6,0x683c020c}},	//   रिले, _guɑn, rrbo, sèdd, 
   {{0x9f845b7f,0x765800c0,0x00000000,0x00000000}},	// [6520] йгад, _zuvy, --, --, 
   {{0x75ec002d,0xde04010b,0x1f540108,0xed5800de}},	//   _rûzi, әпди, стаё, _raža_, 
   {{0x683c004a,0x00000000,0x00000000,0x00000000}},	//   cède, --, --, --, 
   {{0xa524003d,0xdb083b36,0x2aa00210,0x00000000}},	//   _རྙོག_, ánít, dób_, --, 
   {{0x6fc80073,0x00000000,0x00000000,0x00000000}},	//   _होवू, --, --, --, 
   {{0x92dc00bd,0x1fb41fbe,0x0d94035b,0x2c6c0241}},	//   _দেয়_, _усмр, атәы_, _sódò_, 
   {{0xdb185b80,0xef90168d,0x20083199,0x61e45b81}},	//   _antò, _زیند, _imbi_, _kokl, 
   {{0x76581446,0x69d45b82,0x61e40200,0x00000000}},	//   _ruvy, भाषी, _jokl, --, 
   {{0x61e40085,0x76585b83,0xd7c4005b,0x00000000}},	//   _mokl, _suvy, бёно, --, 
   {{0x61e4011f,0x1cb00327,0x00000000,0x00000000}},	//   _lokl, _ྐྱར_, --, --, 
   {{0x6e442bde,0x200806d6,0xdb18067c,0xdb0c023a}},	//   _útbú, _mmbi_, _entò, äkäy, 
   {{0x61e400da,0xdb085b84,0x00000000,0x00000000}},	//   _nokl, cefá, --, --, 
   {{0xd90c5b85,0x20080451,0x490c0037,0x872401a9}},	//   _سید_, _ombi_, _तइयो_, _қўша_, 
   {{0x69c4013f,0x683c0100,0x2a78110e,0x00000000}},	//   _ɔhem, tède, _àgbà_, --, 
   {{0x61e40296,0x5ac40156,0xdb180022,0x12d400cc}},	//   _bokl, _གནསམ, _hatâ, সন্দ, 
   {{0x20085b86,0x34945b87,0xffb401c6,0x2b500118}},	//   _ambi_, _даир, үйтэ, _úzce_, 
   {{0x317801ed,0x50645b66,0x00000000,0x00000000}},	// [6530] _vesz_, стба, --, --, 
   {{0xdb18145e,0x61e40109,0x683c0129,0x557401af}},	//   _matâ, _eokl, pède, _тѳҫт, 
   {{0x41c408a3,0x317801ed,0xb8fc02dd,0x00000000}},	//   _लोकस, _tesz_, _үкiм, --, 
   {{0x20085b88,0x61e4010e,0x37ac0154,0x00000000}},	//   _embi_, _gokl, _কোমর, --, 
   {{0x6288168c,0x6aa000e4,0xdb0801bf,0xfca800f1}},	//   _åfor, _sqlf, nefæ, ماوو_, 
   {{0x61e41d9f,0x59a40a59,0x00000000,0x00000000}},	//   _zokl, क्सर, --, --, 
   {{0x61e45b89,0xdb180139,0xa2840023,0x3ea401f0}},	//   _yokl, _fatí, _ዝኾነን_, _ниёг, 
   {{0x2aa01790,0x2d98072b,0x7bdc0241,0x00000000}},	//   rób_, _øse_, _òrun, --, 
   {{0x2aa0006d,0x00000000,0x00000000,0x00000000}},	//   sób_, --, --, --, 
   {{0xdb185b8a,0x9ba00075,0xa6845b8b,0xcc140fa2}},	//   _zatí, _يەنى, олод, _اذرب, 
   {{0xdb180784,0xe6185b8c,0x62840023,0x69dc0108}},	//   _yatí, идо_, ርባዕተ_, öses, 
   {{0xed580153,0x00000000,0x00000000,0x00000000}},	//   _mažo_, --, --, --, 
   {{0xdb0828b3,0xed5800d7,0xa3c4012d,0x00000000}},	//   gefæ, _lažo_, ईएल_, --, 
   {{0x61e45b8d,0x62640131,0x00000000,0x00000000}},	//   _sokl, قارق, --, --, 
   {{0xe5a40510,0xa2b80154,0xa3480395,0x00000000}},	//   _дийи, ৃঙ্খ, рзва_, --, 
   {{0xe2985b8e,0xdb1800c7,0xa6c80451,0x00000000}},	//   лаҳ_, _hatã, _موڪل_, --, 
   {{0x60085b8f,0xe0d85b90,0xdb1801ef,0x00000000}},	// [6540] анам_, шва_, _ratí, --, 
   {{0x61e42b92,0xa91c0030,0x00000000,0x00000000}},	//   _wokl, mažd, --, --, 
   {{0xdb185b91,0x61e45b92,0xed580010,0xded800c7}},	//   _patí, _tokl, _važn_, шьаш_, 
   {{0xdb180120,0xed5800c0,0xca6801ec,0x00000000}},	//   _latã, _dažo_, _пiкi, --, 
   {{0x9d1808de,0xdb1802d2,0x95901954,0x00000000}},	//   جزاء_, _vatí, _ቁጠባን_, --, 
   {{0x2008080b,0x00000000,0x00000000,0x00000000}},	//   _umbi_, --, --, --, 
   {{0xdb185b93,0xce5000f7,0x00000000,0x00000000}},	//   _satâ, سپۇب, --, --, 
   {{0xdb18025a,0xddf801c0,0xa91c13d5,0x00000000}},	//   _patâ, _тэгш_, každ, --, 
   {{0xb7bc0029,0x59a40aa2,0xdca45b94,0x81bc00cc}},	//   loģi, क्षर, _фази, _ইচা_, 
   {{0xdc9c02d3,0x69dc5b95,0xcd400014,0xdb0801bf}},	//   _ዋርሳይ_, öser, _کھۅٹ, vefæ, 
   {{0x23dc190c,0x00000000,0x00000000,0x00000000}},	//   मानद, --, --, --, 
   {{0xdb08037e,0xe934013d,0x00000000,0x00000000}},	//   tefæ, _çişü, --, --, 
   {{0xdb180109,0x79805b96,0xd7e45b97,0xd7f80354}},	//   _hatà, mamw, _міко, _вуй_, 
   {{0x3dc401d4,0x79805b98,0xdb0801bf,0x00000000}},	//   _lamw_, lamw, refæ, --, 
   {{0x03c802d5,0xdb0801bf,0x69a05b99,0xdc2c0205}},	//   цыяй_, sefæ, क्की, zığl, 
   {{0x79805b9a,0x683c0100,0xed5800e2,0xdb08007c}},	//   namw, mèda, _ražo_, mefä, 
   {{0xf8bc068f,0x94745b9b,0xb0540131,0x00000000}},	// [6550] ्टिय, _بدعا, سپات, --, 
   {{0x79805b9c,0xfe70004b,0x1cb00327,0xa5240327}},	//   hamw, ږده_, _ྐྱེ_, _རྙིག_, 
   {{0x79805b9d,0xb8cc49a6,0xdb185b9e,0xb7bc00e2}},	//   kamw, _ཕད_, _natà, goģi, 
   {{0xa91c0b91,0x79805b9f,0x9f4c01e7,0x13a400e5}},	//   laže, jamw, ófá_, _انھی_, 
   {{0x798052ae,0xdb0801c7,0x660c002e,0x932410e8}},	//   damw, hefä, _ňakk, _درکن, 
   {{0xa91c5ba0,0x81b0009e,0xae040014,0x00000000}},	//   naže, _টোপ_, _کورى, --, 
   {{0xdb1800f7,0x798002d0,0x1dc4012d,0xdb08007c}},	//   _catà, famw, _रोकत, jefä, 
   {{0xe9d80577,0xdb180109,0x79805ba1,0x42a00023}},	//   ски_, _datà, gamw, _ውግኣት_, 
   {{0xacf801ee,0x00000000,0x00000000,0x00000000}},	//   _унау_, --, --, --, 
   {{0xa91c5ba2,0xe7380032,0x72940023,0x00000000}},	//   jaže, йеп_, ፍነታዊ_, --, 
   {{0xdb08362e,0x79805ba3,0xf52802e4,0xe72814a8}},	//   gefä, bamw, _עץ_, сонд_, 
   {{0x2d9c5ba4,0x79805ba5,0x7d0400a3,0x8a400244}},	//   ngwe_, camw, ùisg, _تێبن, 
   {{0x2d9c0521,0x93f8002e,0x67d4013e,0xdb18007b}},	//   igwe_, _s胃ar, _ноду, _iatá, 
   {{0xdb18066d,0xa91c2f61,0x33d45ba6,0xdb08007c}},	//   _hatá, ražd, міст, befä, 
   {{0x2d9c5ba7,0x21680116,0x00000000,0x00000000}},	//   kgwe_, йиви_, --, --, 
   {{0xe5785ba8,0x91e03533,0x00000000,0x00000000}},	//   _узи_, носе, --, --, 
   {{0xdb1801e7,0xa91c0427,0x00000000,0x00000000}},	// [6560] _matá, lažb, --, --, 
   {{0x79805ba9,0x2d9c0083,0x97400cf4,0xd24c01d9}},	//   zamw, egwe_, šćem, ٖنہ_, 
   {{0x798042c8,0xc330113e,0xdb0801e3,0x00000000}},	//   yamw, _شەر_, ldfö, --, 
   {{0xdb185baa,0x6564282c,0xdca45bab,0x2d9c0a49}},	//   _natá, nckh, зади, ggwe_, 
   {{0x79800e8a,0xdb185bac,0xdb085bad,0x443801ab}},	//   vamw, _satà, ndfö, olr_, 
   {{0x2d9c5bae,0x44380092,0x79805baf,0x61f45bb0}},	//   agwe_, nlr_, wamw, lkyl, 
   {{0x44445bb1,0x80c43d60,0x79805bb2,0xdb185bb3}},	//   _mh_, रिके, tamw, _batá, 
   {{0xdca45bb4,0x61f45bb5,0xdb181a36,0x2d940372}},	//   _наби, nkyl, _catá, _орус, 
   {{0x44445bb6,0xfc640502,0x79805bb7,0x5b245bb8}},	//   _oh_, _آخری, ramw, _کفال, 
   {{0x1dd829da,0x79805bb9,0x9ba801d9,0x44440f85}},	//   णावत, samw, _ددرِ_, _nh_, 
   {{0xdb185bba,0x61f400fe,0x79805bbb,0xa91c07f5}},	//   _antö, kkyl, pamw, važe, 
   {{0x44445bbc,0x7c380156,0x67ec00e5,0x00000000}},	//   _ah_, llvr, _sújt, --, 
   {{0x44445bbd,0x6d4c001f,0xa91c00bc,0x7c380af9}},	//   _bh_, ንስፖር, taže, olvr, 
   {{0x44445bbe,0xdb1819b3,0x44380108,0x59d8243c}},	//   _ch_, _zatá, glr_, भावर, 
   {{0x44445bbf,0xa91c0552,0x8838025f,0x5238007b}},	//   _dh_, raže, _התגו, مسرح_, 
   {{0x44445bc0,0xa91c5bc1,0x00000000,0x00000000}},	//   _eh_, saže, --, --, 
   {{0x44445bc2,0x2600002e,0x69a002ab,0x80c421bd}},	// [6570] _fh_, _bóof_, क्टी, रिगे, 
   {{0xd3782461,0x4438366e,0xc0340114,0x00000000}},	//   _учи_, clr_, енуј, --, 
   {{0xed58107d,0x8cbc033f,0xdb080142,0x00000000}},	//   _pgž_, लौनो, sffê, --, 
   {{0x99ac02f5,0x00000000,0x00000000,0x00000000}},	//   কযুক, --, --, --, 
   {{0x44445bc3,0xcd284bf8,0xdb18498d,0x324401af}},	//   _yh_, حسان_, _ratá, _неүг, 
   {{0x44445bc4,0xdb183eba,0xaffc030d,0x82640244}},	//   _xh_, _satá, _тогi, _تهێن, 
   {{0xaa485bc5,0xae040046,0xdb181bd4,0x00000000}},	//   опка_, _قوسى, _patá, --, 
   {{0xe8f85bc6,0x00000000,0x00000000,0x00000000}},	//   жли_, --, --, --, 
   {{0x9f5809d7,0x00000000,0x00000000,0x00000000}},	//   cipó_, --, --, --, 
   {{0x4438037e,0x7d0408c2,0x00000000,0x00000000}},	//   xlr_, ùise, --, --, 
   {{0xdb185bc7,0x7c245bc8,0x443800b5,0x2fc402d2}},	//   _tatá, éire, vlr_, _ólgu_, 
   {{0xc9845bc9,0x00000000,0x00000000,0x00000000}},	//   _хужи, --, --, --, 
   {{0x69d85bca,0x656429ef,0x2d8c01f7,0x44440375}},	//   _inwe, rckh, _mdee_, _ph_, 
   {{0x44445bcb,0x69c85bcc,0xdb085bcd,0x00000000}},	//   _qh_, ldee, rdfö, --, 
   {{0x2d8c02e3,0x69c80014,0x61f40108,0x21a400d8}},	//   _odee_, odee, tkyl, мивм, 
   {{0x69c85bce,0x44380998,0x2d8c5bcf,0xb0c85b99}},	//   ndee, slr_, _ndee_, रिंग, 
   {{0x4444025f,0x61f45bd0,0x69c85bd1,0xb5a800ae}},	// [6580] _th_, rkyl, idee, _رايك_, 
   {{0x61f45bd2,0x2d8c013f,0x69c80014,0x44440f85}},	//   skyl, _adee_, hdee, _uh_, 
   {{0x69d85bd3,0x6810012c,0x4fa00395,0xddcc013a}},	//   _onwe, mědě, тихв, _zubř, 
   {{0x69d85bd4,0x225c0306,0x00000000,0x00000000}},	//   _nnwe, ítku_, --, --, 
   {{0x69c85603,0xdbc4007d,0x91b80375,0xdc28004b}},	//   ddee, _mööb, _ומכי, يسته_, 
   {{0x69d85bd5,0x69c84091,0x2d8c5bd6,0x3cf8012c}},	//   _anwe, edee, _edee_, ्छौं_, 
   {{0x2600002e,0x8fa05bd7,0x4fa000d1,0xdb18467d}},	//   _góog_, _шаре, _ширв, _matç, 
   {{0x69c85bd8,0x9f585bd9,0x69d41025,0xdbc4000d}},	//   gdee, cipò_, भागी, _nööb, 
   {{0xdb1806ed,0x80c42e05,0x00000000,0x00000000}},	//   _antô, रिटे, --, --, 
   {{0x69d844fc,0x69c85272,0x25b01368,0x7bac00cc}},	//   _enwe, adee, _abyl_, _টোৰো, 
   {{0x7bc85bda,0x69c85bdb,0x38c80344,0x261001a6}},	//   _iadu, bdee, زاکی_, ršon_, 
   {{0x7bc8138f,0x69c801d9,0xb4940640,0x349401f0}},	//   _hadu, cdee, нимљ, намр, 
   {{0x7bc85bdc,0x00000000,0x00000000,0x00000000}},	//   _kadu, --, --, --, 
   {{0xf8bc0c2e,0x7bc8001f,0x00000000,0x00000000}},	//   ्टीप, _jadu, --, --, 
   {{0x69d80a85,0xa91c0006,0x36d45bdd,0xf8c80208}},	//   _ynwe, maža, _чойр, _hứ_, 
   {{0xa91c1050,0xa2440014,0x00000000,0x00000000}},	//   laža, ٹیُل_, --, --, 
   {{0xdb1800c7,0x7bc8003e,0x2c5c007f,0x92dc0154}},	// [6590] _hatä, _oadu, _kňde_, থনে_, 
   {{0x7bc85bde,0x614407a7,0x9f48020c,0x7e7c03cb}},	//   _nadu, رىلە, _kobè_, _bwrp, 
   {{0x69c81af4,0x238800d0,0x8608114f,0x00000000}},	//   ydee, šujú_, _رقیق_, --, 
   {{0x7bc80241,0x69c801d9,0xdb18372c,0x1cb00327}},	//   _aadu, xdee, _matä, _ྐྱང_, 
   {{0xdb185bdf,0x913000c7,0xaa480116,0x00000000}},	//   _latä, _рҭах, үпла_, --, 
   {{0x7bc85be0,0x69c80014,0x2600002e,0xed580024}},	//   _cadu, wdee, _tóog_, _maži_, 
   {{0xeab05be1,0xc4b42b88,0x7bc85be2,0x69c85be3}},	//   اعت_, _བརྐྱ, _dadu, tdee, 
   {{0x6b5400a2,0xe3c8013d,0x69c80009,0x3a140124}},	//   _aýgü, _kiñä_, udee, кьыс, 
   {{0x69c85be4,0xf8c807ae,0x7bc85be5,0x9b540032}},	//   rdee, _cứ_, _fadu, миәт_, 
   {{0x7bc85be6,0x69c85be7,0xdbc40254,0xf8c80051}},	//   _gadu, sdee, _sööb, _dứ_, 
   {{0xe5a45be8,0x68100316,0x26d010ba,0xdb180363}},	//   нини, vědě, ízo_, _ratç, 
   {{0x6b805be9,0x7bc81326,0x69c801d9,0x85b424a5}},	//   _helg, _zadu, qdee, тәкч, 
   {{0x7bc85bea,0x6b80006c,0x753401c6,0x26d0008f}},	//   _yadu, _kelg, вэрх, ŭzo_, 
   {{0x6b8000da,0xd7a40490,0x7bc80067,0x68440139}},	//   _jelg, _खायच, _xadu, _янла, 
   {{0x6b805beb,0xed58005f,0x26100030,0xdbc40254}},	//   _melg, _daži_, lšom_, _tööb, 
   {{0xdb08004a,0xe5780139,0x00000000,0x00000000}},	//   uffé, _эзи_, --, --, 
   {{0xc4b42b65,0xf8c80016,0xe3c8013d,0x261000d0}},	// [65a0] _བརྒྱ, _xứ_, _ciñä_, nšom_, 
   {{0x7e7c0368,0xeac4004d,0x05ac012c,0x6b800254}},	//   _pwrp, _đùng_, ट्रब, _nelg, 
   {{0x7bc85bec,0x53980302,0x9f48020c,0x644c5bed}},	//   _radu, _ציטו, _kobé_, mmbi, 
   {{0x7bc85bee,0x626c01e4,0xdd9004fb,0x261001a6}},	//   _sadu, _aĝog, اوش_, kšom_, 
   {{0x3f843088,0x644c5bef,0x26100030,0xdb0805ac}},	//   _ағза, ombi, jšom_, lefø, 
   {{0x6b805bf0,0x7bc85bf1,0x2600002e,0x261000d7}},	//   _celg, _qadu, _jóob_, dšom_, 
   {{0x6b805bf2,0x7bc85bf3,0xad9c002d,0xf8c8001e}},	//   _delg, _vadu, _blźd, _sứ_, 
   {{0x7bc85bf4,0x6b80022f,0x9f48007f,0x3eb80009}},	//   _wadu, _eelg, _robè_, _iprt_, 
   {{0x7bc85bf5,0x644c0810,0xa3c0012c,0xa91c0024}},	//   _tadu, kmbi, ृया_, taža, 
   {{0x6b805bf6,0xdb18014a,0x7bc801c8,0x36d4209b}},	//   _gelg, _patä, _uadu, воор, 
   {{0xdb0800cc,0xb6c409a0,0x7c640092,0x75d4009a}},	//   jefø, төлд, ስፖራው_, نيدا, 
   {{0xdb085522,0xf8c8001e,0x6b8005d5,0xa91c0024}},	//   defø, _tứ_, _zelg, saža, 
   {{0xa91c5bf7,0x9f480100,0x06340055,0x6b80022e}},	//   paža, _wobè_, _gaḍḍ, _yelg, 
   {{0xdb180793,0x926801c0,0x00000000,0x00000000}},	//   _tatä, зраа_, --, --, 
   {{0xed5838bb,0x60c420a2,0xdb084453,0x5fcc0406}},	//   _važi_, _askm, gefø, _होइल, 
   {{0x644c5bf8,0x0b900023,0x69042d9a,0x00000000}},	//   ambi, መሓደር_, _ötdü, --, 
   {{0x7bdc0086,0x009400a8,0x705801c0,0xb0345bf9}},	// [65b0] _òruw, литэ, даар_, внаш, 
   {{0x26000de2,0xa91c041a,0xcf240e8e,0x00000000}},	//   _góob_, kažn, ىراي, --, 
   {{0x3eb8020c,0xa91c15ad,0x60c4062c,0xa2c004a9}},	//   _cprt_, jažn, _eskm, _кәтк, 
   {{0x6b805bfa,0xa91c0153,0xc690010f,0x7c940092}},	//   _selg, dažn, ראף_, _ጄኔራል_, 
   {{0x6b805bfb,0xf8bc06b1,0x733410de,0x1ca40133}},	//   _pelg, ्टोप, _سىڭا, نجوێ, 
   {{0xeb985bfc,0x6060215c,0xef100137,0x629801d3}},	//   фик_, _ئۇلل, _күзө, átog, 
   {{0xe9d00491,0x6b805bfd,0x3eb402f0,0xa91c00ef}},	//   لغة_, _velg, čatá_, gažn, 
   {{0x8d7457d4,0x6b805bfe,0x26100419,0x00000000}},	//   _سارا, _welg, tšom_, --, 
   {{0x6b805bff,0x6c54413f,0x2610009b,0x644c5c00}},	//   _telg, _акау, ušom_, ymbi, 
   {{0x2bd802e1,0xd8741537,0x261000d0,0x6b805c01}},	//   _تارک_, کمیت_, ršom_, _uelg, 
   {{0xf8a853b6,0xaa5800f3,0xf8e40133,0x00000000}},	//   ودیه_, _жижу_, نسیپ, --, 
   {{0x261054ae,0x26000de2,0xdb085c02,0x0594029e}},	//   pšom_, _sóob_, vefø, دادگ, 
   {{0xa91c0024,0x395401ee,0x00000000,0x00000000}},	//   mažo, _йњшт, --, --, 
   {{0xe7b45a86,0x69d40709,0x39440212,0xa91c0e04}},	//   _شمعد, _मोती, _сніг, lažo, 
   {{0x644c143a,0x9f480c5e,0x21685c03,0x00000000}},	//   rmbi, _blbý_, диби_, --, 
   {{0xdb085c04,0xa91c00d7,0x20d40150,0x3f040150}},	//   refø, nažo, кізс, ңжаң, 
   {{0xed581326,0x59a442e3,0xa068036b,0xa5241def}},	// [65c0] _kažu_, क्टर, фаза_, _шмид, 
   {{0x3eb80ac5,0x9f880267,0x443c3e59,0x00000000}},	//   _pprt_, _lööf_, _óv_, --, 
   {{0x26105c05,0xe2980139,0xed5800c0,0x00000000}},	//   všoj_, _юан_, _mažu_, --, 
   {{0xa91c5c06,0xed5805ce,0x3a740075,0x0d800131}},	//   važn, _lažu_, қлир, қлән, 
   {{0xa1140345,0x60c4000d,0xa07401ec,0x26100419}},	//   _شوست, _uskm, _шынш, ešok_, 
   {{0x9e740214,0x38600332,0xed580171,0x00000000}},	//   _لهست, _éiri_, _nažu_, --, 
   {{0x39405c07,0xda485c08,0x683c0066,0x3ce00356}},	//   _šis_, мчил_, mèdh, ţiv_, 
   {{0xa91c3421,0xdb1800e4,0x69d41b87,0xfe500205}},	//   gažo, _katú, _मोदी, ççık_, 
   {{0xa91c5c09,0x261016a3,0xf8f401c0,0x25e428f5}},	//   sažn, pšoj_, уппэ, टानी_, 
   {{0xa91c5c0a,0xdb1800d0,0x9b8800f2,0xed340354}},	//   pažn, _matú, _آنال_, _сэсэ, 
   {{0xa3e45c0b,0xa91c07f5,0xed5800e2,0x9b340022}},	//   फान_, lažl, _dažu_, _рхаш, 
   {{0x4514015b,0xa2c44a18,0x00000000,0x00000000}},	//   _সড়ক_, ाबन्, --, --, 
   {{0xdb185c0c,0x394026d3,0xa91c00a2,0x00000000}},	//   _natú, _áis_, nažl, --, 
   {{0x78a05c0d,0x843400d4,0x2ca8031c,0x00000000}},	//   mumv, иняє, ħadx_, --, 
   {{0x47300046,0x2b4803f9,0x7af801ed,0xddcc00df}},	//   _پروز, ƙace_, nyvt, _subŝ, 
   {{0x7ff41547,0xc33010e0,0x068000d1,0x59a45c0e}},	//   یسلا, تەپ_, _өгән, क्चर, 
   {{0x5690005e,0xa91c0e3c,0x78a00230,0x00000000}},	// [65d0] _сақт, jažl, numv, --, 
   {{0x261000d0,0xa4b408c3,0x00000000,0x00000000}},	//   yšok_, _עלתה_, --, --, 
   {{0x78a000ca,0xb8d4025c,0xad240131,0x645801e4}},	//   humv, _ཞཱ_, گىشى, ĉtit, 
   {{0x78a01b33,0x9f48004e,0x6ae40032,0x8c440139}},	//   kumv, _albó_, ғжиз, _orğä, 
   {{0x83f0013f,0xa91c0232,0x21980a7c,0xbf000118}},	//   _guɑs, važo, _אברא, _číšn, 
   {{0x29000a28,0x60d8008f,0x683c020c,0x78a05c0f}},	//   _āha_, _אַלג, cèdh, dumv, 
   {{0x9f480248,0xdb180419,0xed5800de,0x00000000}},	//   _jobì_, _zatú, _ražu_, --, 
   {{0x683c5c10,0xdab401f7,0x26100419,0x5c700304}},	//   mèdi, اهيت_, ršok_, шләт, 
   {{0x78a05c11,0xa91c5c12,0x9f480241,0x61f4000d}},	//   gumv, ražo, _lobì_, _एकसौ_, 
   {{0xa91c04a7,0x00000000,0x00000000,0x00000000}},	//   sažo, --, --, --, 
   {{0xf778031c,0xe61803c5,0x00000000,0x00000000}},	//   jjħu_, едн_, --, --, 
   {{0x78a001b2,0x00000000,0x00000000,0x00000000}},	//   bumv, --, --, --, 
   {{0x81cc0d42,0x78a05c13,0xb9085c14,0x00000000}},	//   লাম_, cumv, _لزوم_, --, 
   {{0xd91804ae,0xa91c0030,0x6818007f,0x66040200}},	//   _אונל, nažm, bňda, shkk, 
   {{0xe618010a,0xdb1802d2,0x00000000,0x00000000}},	//   _пдк_, _satú, --, --, 
   {{0xbbc0098a,0x156807d2,0x00000000,0x00000000}},	//   _एस्क, _ﺳﯩﺒﯩ, --, --, 
   {{0x602405f5,0x64c4007b,0x00000000,0x00000000}},	// [65e0] гдаа, _صيدل, --, --, 
   {{0xdee43e3f,0xa368022e,0x5fcc007d,0xa2e45c15}},	//   лози, _enеr, _होखल, _боод, 
   {{0x645c5c16,0x78a00230,0x683c5c17,0x00000000}},	//   _iipi, zumv, gèdi, --, 
   {{0x78a05c18,0xdb18498d,0xa91c0118,0x7afc5c19}},	//   yumv, _tatú, tažl, _ürti, 
   {{0x645c5c1a,0x628c5c1b,0x10a000a7,0x7b8401ec}},	//   _kipi, lsbo, _лиян, иғад, 
   {{0xa91c05a1,0x645c5c1c,0x78a00223,0x98c4013e}},	//   gažm, _jipi, vumv, ҳсол, 
   {{0x645c5c1d,0x20181bb7,0x78a00230,0x1c4402dd}},	//   _mipi, mipi_, wumv, _ұнам, 
   {{0x78a05c1e,0xdb1805ac,0x9d540014,0x628c0549}},	//   tumv, _matø, _منزت, isbo, 
   {{0x645c5c1f,0xed580171,0x38440092,0x00000000}},	//   _oipi, _dažs_, _የባለሥ, --, 
   {{0x78a05c20,0x645c5c21,0x20185c22,0x00000000}},	//   rumv, _nipi, nipi_, --, 
   {{0x1034025f,0x628c5c23,0xc6f401c6,0x6e340241}},	//   רטים_, jsbo, гнэх_, _àgbí, 
   {{0x645c5c24,0x0f540302,0x18685c25,0x81cc0154}},	//   _aipi, טיים_, _зади_, লাড_, 
   {{0x20185c26,0x645c5c27,0x628c0430,0x32040153}},	//   kipi_, _bipi, esbo, ūlyk_, 
   {{0x645c5c28,0x36d42075,0x628c36d5,0x7bdc0174}},	//   _cipi, _вокр, fsbo, _órud, 
   {{0x645c54ba,0x628c5c29,0x20180327,0xc87c054e}},	//   _dipi, gsbo, dipi_, ăşel_, 
   {{0xdb085c2a,0x6e2800df,0xe19401c0,0x645c00ae}},	//   lefó, _ĉebo, илсө, _eipi, 
   {{0x30145c2b,0x764c5c2c,0xa6e02880,0x645c0109}},	// [65f0] адар, _ihay, óðve, _fipi, 
   {{0x645c5c2d,0x764c5c2e,0x752c0117,0x628c5c2f}},	//   _gipi, _hhay, _ixaz, bsbo, 
   {{0x764c5c30,0xdb080730,0x1bf8547d,0x66140432}},	//   _khay, gefü, ्सनल_, _ymyk, 
   {{0x645c5c31,0x8d845c32,0x764c007f,0x683c0f87}},	//   _zipi, اشان, _jhay, rèdi, 
   {{0x764c009f,0x2a6400e8,0x645c4a24,0xbd8801c8}},	//   _mhay, _sulb_, _yipi, انهن_, 
   {{0x683c5c33,0x20185c34,0x764c5c35,0x645c07a9}},	//   pèdi, cipi_, _lhay, _xipi, 
   {{0x764c5c36,0x7c28002d,0x5fcc03f8,0x320802d0}},	//   _ohay, _djdr, _होटल, ohay_, 
   {{0xe9d80719,0x320814dc,0x752c01f5,0x1dc0009d}},	//   тки_, nhay_, _oxaz, _мөчн, 
   {{0xa8045c37,0x752c0107,0x6e280241,0x32085c38}},	//   изил, _nxaz, _ijeb, ihay_, 
   {{0x764c0d62,0x66140627,0x320814dc,0x6d4802d0}},	//   _ahay, _smyk, hhay_, _izea, 
   {{0x645c5c39,0x81cc02a6,0x752c0117,0x764c5c3a}},	//   _ripi, লাত_, _axaz, _bhay, 
   {{0x764c4375,0xe5a45c3b,0x645c5c3c,0x628c5c3d}},	//   _chay, шими, _sipi, vsbo, 
   {{0x3208076a,0x764c5c3e,0x9f4801f1,0x260000e8}},	//   dhay_, _dhay, _robí_, _fóon_, 
   {{0x764c5c3f,0x645c5c40,0x2ba8193d,0x78a403cd}},	//   _ehay, _qipi, च्चा, _åiva, 
   {{0x645c5c41,0xdb085c42,0x22145c43,0x628c5c44}},	//   _vipi, lefò, афар, usbo, 
   {{0x645c014f,0x6d485c45,0x66145c46,0x764c0978}},	//   _wipi, _ozea, _umyk, _ghay, 
   {{0x20185c47,0xa0a45c48,0x5f740137,0x1cb0031c}},	// [6600] tipi_, разд, لاار, _ཐཱེ_, 
   {{0x32085c49,0x6e285c4a,0xa2c40574,0x20180810}},	//   ahay_, _ajeb, ाबद्, uipi_, 
   {{0x44385c4b,0x2ba83f55,0x20185c4c,0x670411b1}},	//   mor_, च्छा, ripi_, शनिक_, 
   {{0x44385c4d,0x32085c4e,0x20185c4f,0xa91c09a8}},	//   lor_, chay_, sipi_, ražj, 
   {{0x20185c50,0x3074010b,0xdb080e78,0xd7a40490}},	//   pipi_, _гусс, sefü, _खालच, 
   {{0x290c1aa1,0x44385c51,0x6d48006f,0x20180784}},	//   dzea_, nor_, _dzea, qipi_, 
   {{0x44385c52,0x6d4801c6,0x261000d0,0xda0400a8}},	//   ior_, _ezea, lšou_, ичип, 
   {{0x44385c53,0x6e28036e,0x00000000,0x00000000}},	//   hor_, _gjeb, --, --, 
   {{0x44385c54,0x7e605c55,0x260000e8,0xdc68030d}},	//   kor_, _iimp, _póon_, _разд_, 
   {{0x764c5c56,0x7e605c57,0x44385c58,0x6e285c59}},	//   _shay, _himp, jor_, _zjeb, 
   {{0x7e605c5a,0x764c5c5b,0x32080c8c,0x7c385c5c}},	//   _kimp, _phay, yhay_, movr, 
   {{0x7e60003d,0x764c5c5d,0x44385c5e,0xca7003e6}},	//   _jimp, _qhay, eor_, _بچوک, 
   {{0x7e605c5f,0x44385c60,0x764c06d6,0x26100030}},	//   _mimp, for_, _vhay, jšou_, 
   {{0x32082f05,0x7c385c61,0x764c0076,0xd6d8299f}},	//   whay_, novr, _whay, _ати_, 
   {{0x32083ff0,0x764c0bc9,0xd68400db,0x7e600022}},	//   thay_, _thay, _тулп, _oimp, 
   {{0x764c5c62,0xd7a4012c,0x00000000,0x00000000}},	//   _uhay, _खाँच, --, --, 
   {{0x7c385c63,0x320814dc,0xc95000c8,0x752c0117}},	// [6610] kovr, rhay_, ַמע_, _uxaz, 
   {{0x32085c64,0x6e285c65,0x44385c66,0xc67c0092}},	//   shay_, _sjeb, cor_, _የተሠራ_, 
   {{0x7e605c67,0x7c385c68,0x32085c69,0x6e981a6d}},	//   _bimp, dovr, phay_, увер_, 
   {{0x7e605c6a,0x32085c6b,0x261000d7,0x00000000}},	//   _cimp, qhay_, bšou_, --, 
   {{0xdd8c5c6c,0xeb985c6d,0xe3ac0154,0xcfcc0154}},	//   روو_, гил_, _ছোটব, রাবন, 
   {{0x7c382625,0xab285c6e,0x7e600332,0x8e74104c}},	//   govr, лола_, _eimp, _نارض, 
   {{0xfbd05c6f,0x6e285c70,0xa91c0006,0xaab80424}},	//   بتن_, _tjeb, maži, ادتر_, 
   {{0x290c152d,0x20fc0b23,0x6d485c71,0x2d9800e4}},	//   tzea_, _fāiā_, _tzea, _ÿse_, 
   {{0x44385c72,0x6e38009a,0x1dc001c6,0x6d480356}},	//   yor_, mowb, _хөхн, _uzea, 
   {{0x44385c73,0x7c384a1f,0x290c5c74,0xa91c2109}},	//   xor_, covr, rzea_, naži, 
   {{0x7e604b26,0x2fd000ef,0xddc0012d,0x249001ef}},	//   _yimp, _mazg_, jmoś, _svym_, 
   {{0x44385c75,0x7e6000cf,0xdb1800d8,0xaa5400f3}},	//   wor_, _ximp, _obtê, _увеш, 
   {{0xa91c1aff,0xe94404fb,0xdb18013a,0x00000000}},	//   kaži, _ارای, _matý, --, 
   {{0xd46400a8,0xec34010f,0x09a400bc,0x261000d7}},	//   сире_, מאָר_, _गाँठ, všou_, 
   {{0x81cc2aab,0x3860067c,0xddc002f0,0xa91c00c0}},	//   লাস_, _èira_, bloň, daži, 
   {{0x2328023b,0xdb1800a2,0x261000d7,0x00000000}},	//   воҳи_, _natý, tšou_, --, 
   {{0x7e605c76,0x44385c77,0xe0d85c78,0x6e385c79}},	// [6620] _rimp, por_, ыва_, dowb, 
   {{0xa91c5c7a,0x44385c7b,0x26100419,0x4f840014}},	//   gaži, qor_, ršou_, مامہ, 
   {{0x7e605c7c,0x09a404fa,0x2fd001a6,0xdb18010e}},	//   _pimp, _गांठ, _dazg_, _batý, 
   {{0x81cc00bd,0x7e600455,0x261000d0,0x15e80412}},	//   লাহ_, _qimp, pšou_, टायर_, 
   {{0x7c381326,0xcf880131,0x3ce00115,0x2bd80d79}},	//   tovr, _ﺗﯘﺭﯗ, ĥivo_, _योहा, 
   {{0xc5e41d15,0x2600002e,0x9740107d,0x8f640c60}},	//   गाँठ_, _sóol_, šćim, _гарб_, 
   {{0x7e605c7d,0x7c38005c,0x261000e2,0x00000000}},	//   _timp, rovr, nšos_, --, 
   {{0x7c385c7e,0x260000e8,0x7e605c7f,0x38b000a3}},	//   sovr, _bóom_, _uimp, tàr_, 
   {{0xd7f85c80,0x04fc015b,0x39140d1d,0x00000000}},	//   гун_, ীপুর_, юмир, --, 
   {{0xdb184e6f,0x76b800c0,0x00000000,0x00000000}},	//   _katü, алор_, --, --, 
   {{0xec345c81,0xc5e405f9,0xdb1c0241,0xdb0c0958}},	//   _بولگ, गांठ_, _àyày, ädän, 
   {{0x6f08012c,0x98a40209,0xa91c5c82,0xaae4007b}},	//   _řeck, _гиде, zaži, _بسكو, 
   {{0x2600002e,0x3f980219,0x38b0002e,0xd944447e}},	//   _góom_, _odru_, qàr_, _уеди, 
   {{0x98545c83,0x3f980200,0x8cb8000d,0x1bf812eb}},	//   _утеш, _ndru_, _एहसो, ्सिल_, 
   {{0xdb185c84,0xa91c02d5,0x787401f7,0x00000000}},	//   _natü, važi, _اُڪا, --, 
   {{0xdb1801ed,0x3f9803b2,0x71785c85,0x06940532}},	//   _ható, _adru_, рбар_, _اخوت_, 
   {{0xdb183168,0x261000e2,0x86080f2b,0x25e40b72}},	// [6630] _kató, ršot_, _دقيق_, टारी_, 
   {{0xb4d407f7,0xdb18010b,0x00000000,0x00000000}},	//   सटी_, _satý, --, --, 
   {{0xdb1804d4,0x8d745c86,0xa3e40490,0x6e380009}},	//   _mató, ماشا, फार_, towb, 
   {{0x8d84049b,0xa91c262b,0xdb183eba,0x3f98143a}},	//   сужд, saži, _lató, _edru_, 
   {{0xa91c02d5,0x6e385c87,0x6b645c88,0x81cc0154}},	//   paži, rowb, окла, লাশ_, 
   {{0x4fc45c89,0x7ee400f7,0x00000000,0x00000000}},	//   _усма, تكۅن, --, --, 
   {{0x59d819ec,0x81cc03f4,0xfbd05c8a,0xdb18010e}},	//   _मोहर, লার_, عته_, _tatý, 
   {{0xdb180241,0xae040ed1,0x5dd40014,0x3f980010}},	//   _aató, _بورى, _وژنس_, _zdru_, 
   {{0xe8080116,0xdb1803e0,0x00000000,0x00000000}},	//   инид_, _zatü, --, --, 
   {{0xdb182cd7,0x68ec00d8,0xc6880023,0x00000000}},	//   _cató, _àadm, _መሰልካ_, --, 
   {{0x65c45c8b,0x7e9c054e,0x00000000,0x00000000}},	//   обна, căpă, --, --, 
   {{0xb4d401ad,0x7c040137,0xe508009f,0x00000000}},	//   सटू_, _وبەك, ليجو_, --, 
   {{0x89345c8c,0x67d4074d,0xd740044e,0xa3cc02ab}},	//   _اعضا, _моду, _ማዕርነ, _रसद_, 
   {{0xa2e401c6,0x00000000,0x00000000,0x00000000}},	//   оогд, --, --, --, 
   {{0x8d7c00b7,0x7c24007b,0xdb100205,0x00000000}},	//   ከታተል_, éiri, şgös, --, 
   {{0xdb18033b,0x261056ce,0x00000000,0x00000000}},	//   _katò, ršos_, --, --, 
   {{0x81cc09bd,0xdb1803e0,0x00000000,0x00000000}},	// [6640] লাল_, _satü, --, --, 
   {{0xdfa400c6,0x66ec000d,0x4fe400cf,0x00000000}},	//   تحري, _छपाक_, омун_, --, 
   {{0xdb1802e2,0xdb0801e3,0x26185c8d,0x63b80254}},	//   _latò, lefö, मोथी_, õtnu, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x81b00198,0xdb0801e3,0x0c70029c,0x00000000}},	//   jiɓi, nefö, ودود, --, 
   {{0x3e680d6d,0x1ea805d9,0x8bc002e8,0xa91c00c0}},	//   _هجری_, _پاسي_, дсъд, nažu, 
   {{0xdb1804cf,0xef90528e,0x6d5c0005,0xe7ec5c8e}},	//   _rató, _سیند, _úsan, जाना_, 
   {{0xdb0801b8,0xa3e4000d,0x4ad8000d,0xeb300137}},	//   kefö, फाँ_, _मछरव, رۉند, 
   {{0xdb185c8f,0x225c0122,0xc5f403f9,0xdb08007c}},	//   _catò, ítky_, _giɓi_, jefö, 
   {{0xd7f8013e,0xdb0801e3,0x48e8000d,0xd6d800d8}},	//   руи_, defö, _अऊरो_, атм_, 
   {{0xdb185c90,0x61e4008f,0xdb080e78,0x25a4010e}},	//   _obté, _onkl, uffä, _ŷola_, 
   {{0xd90c036b,0x588400cf,0x00000000,0x00000000}},	//   _لیب_, _дыка, --, --, 
   {{0xf28801c0,0xdb08007c,0x2908010e,0x00000000}},	//   өөнд_, gefö, _ýaap_, --, 
   {{0x61e45c91,0xa91c5c92,0x2a7801e1,0x00000000}},	//   _ankl, gažu, _ágbà_, --, 
   {{0xd8a400b2,0xefcc0023,0x4b78011a,0x00000000}},	//   _اهڙو_, ኢታዊ_, שאלו, --, 
   {{0x20085c93,0xcee85c94,0x63bc01c4,0x6734002d}},	//   _albi_, یران_, _ebpn, ûzje, 
   {{0x2008020b,0x6da4070e,0xdb0801e3,0x00000000}},	// [6650] _blbi_, җила, cefö, --, 
   {{0x61e45c95,0x35b0032c,0xa91c02f0,0x23b0012d}},	//   _enkl, _झाड़, mažt, _जायद, 
   {{0x3204002d,0xddc000df,0xebc400c7,0x00000000}},	//   ëlys_, smoŝ, ҟәан, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x32040153,0xe7ec1b97,0xc0e400c0,0x00000000}},	//   ūlys_, जामा_, _жоўк, --, 
   {{0x60f80375,0x81cc00eb,0x00000000,0x00000000}},	//   _ההשק, লাঃ_, --, --, 
   {{0x61e45c96,0x27e8001e,0x2c5c0100,0x00000000}},	//   _ynkl, _đan_, _jňdi_, --, 
   {{0xdb18004e,0x0e08005b,0xa3e0000d,0x4904012c}},	//   _patò, _тэги_, _नोन_, ाईलो_, 
   {{0xa9245c97,0x393401c0,0x00000000,0x00000000}},	//   ядил, дээс, --, --, 
   {{0xbca400e3,0x00000000,0x00000000,0x00000000}},	//   _آملي, --, --, --, 
   {{0xe7385c98,0xa91c04bf,0x7c245c99,0x00000000}},	//   сен_, važu, èire, --, 
   {{0xdb08007c,0x00000000,0x00000000,0x00000000}},	//   tefö, --, --, --, 
   {{0xa87804ac,0x00000000,0x00000000,0x00000000}},	//   _פאַר, --, --, --, 
   {{0x987825f9,0xdd380375,0xdb080267,0xa6940a5b}},	//   _האסט, מערכ, refö, _ериј, 
   {{0xdb085b00,0x6658010a,0xa91c5c9a,0x00000000}},	//   sefö, _лакă, ražu, --, 
   {{0xdb1001ed,0xa91c0024,0xe7f4012c,0xb7bc00e2}},	//   égér, sažu, ेसका_, riģe, 
   {{0xdb080261,0x2c5c00a2,0x60080107,0x74f8009d}},	// [6660] lefô, _eňdi_, бнам_, _дээс_, 
   {{0xe298010a,0xc67c0092,0x00000000,0x00000000}},	//   _лао_, _የተሰራ_, --, --, 
   {{0x93f8011a,0x00000000,0x00000000,0x00000000}},	//   _הליי, --, --, --, 
   {{0x61e45c9b,0x00000000,0x00000000,0x00000000}},	//   _unkl, --, --, --, 
   {{0x6d5c0789,0xd1b001a9,0x71700131,0x00000000}},	//   _úsal, _سیلک, _شۇلا, --, 
   {{0xec6802dd,0xe81c00bc,0x5f04022e,0x00000000}},	//   ірік_, योमा_, _езга, --, 
   {{0x53980677,0x00000000,0x00000000,0x00000000}},	//   ציקו, --, --, --, 
   {{0xdc6801c4,0x00000000,0x00000000,0x00000000}},	//   _гаад_, --, --, --, 
   {{0xed78044e,0xdca45c9c,0x5ca41b94,0x00000000}},	//   _ብሓባር_, _хази, _хизб, --, 
   {{0x3d080243,0x25b0045a,0x59ac12eb,0xf6980114}},	//   वनीं_, _acyl_, _टावर, овој_, 
   {{0x7bd82959,0x7c2404e6,0xa3e40027,0x4b7800d9}},	//   mdvu, éiru, फाई_, _האבו, 
   {{0x7bd8050a,0x15b00116,0x00000000,0x00000000}},	//   ldvu, رەخس, --, --, 
   {{0xd944010b,0xd7f8141c,0x79a401e0,0x48e00798}},	//   _эеди, _гуй_, _ерҙе, _поцв, 
   {{0x7bd81cea,0xa8a40220,0x00000000,0x00000000}},	//   ndvu, _ірік, --, --, 
   {{0x26180037,0x00000000,0x00000000,0x00000000}},	//   मोही_, --, --, --, 
   {{0xb604030d,0x00000000,0x00000000,0x00000000}},	//   _цӏок, --, --, --, 
   {{0x85b800f1,0x859c0375,0x6818007f,0xab1402d2}},	// [6670] _رايس_, _השחו, wňdi, _íröð_, 
   {{0x15e80073,0xc0580212,0x06b40244,0x337401f4}},	//   टावर_, піх_, _بچیک_, _югор, 
   {{0x32545c9d,0xe7ec0b6d,0xa91c02f0,0x4ea4009d}},	//   _овор, जाता_, nažr, яраа, 
   {{0x1af000cc,0x1ee800f2,0x00000000,0x00000000}},	//   জনাই_, تومی_, --, --, 
   {{0x2cf80709,0x00000000,0x00000000,0x00000000}},	//   ्नेल_, --, --, --, 
   {{0xce685c9e,0xbbe800d1,0x956803b9,0x00000000}},	//   _град_, كرىم_, _saхl, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7bd80254,0x7d2800e5,0x00000000,0x00000000}},	//   advu, ássá, --, --, 
   {{0x200c0006,0x851c06e3,0xa91c0030,0x00000000}},	//   škių_, _पेंट_, važs, --, 
   {{0x69a80a8a,0x629800e5,0x00000000,0x00000000}},	//   _टाकी, átok, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb0803cd,0xdb24150e,0x6ffc002b,0x00000000}},	//   refô, _تومی, _yācñ, --, 
   {{0x7ae402b5,0x7c2c0124,0x00000000,0x00000000}},	//   āite, _ñorã, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x78a401e4,0x00000000,0x00000000,0x00000000}},	//   _ĥivi, --, --, --, 
   {{0x261806ab,0x24840200,0x00000000,0x00000000}},	//   मोशी_, _çomo_, --, --, 
   {{0x7e7c098d,0x1fb41db6,0x15e80210,0x00000000}},	// [6680] _strp, дсер, टारर_, --, 
   {{0x44d0010b,0x10a000d1,0x26181b76,0xa2e400cf}},	//   _iń_, тифн, मोरी_, _жоод, 
   {{0x44445c9f,0x00000000,0x00000000,0x00000000}},	//   _ik_, --, --, --, 
   {{0xe9d8068f,0xdca4132a,0x27e803f9,0xa3e404fa}},	//   jdź_, дади, _ɗana_, फाक_, 
   {{0x44445ca0,0xd59804ce,0x00000000,0x00000000}},	//   _kk_, koの_, --, --, 
   {{0x44445ca1,0x9f480296,0xda78013e,0x61f400a2}},	//   _jk_, _mobú_, ояи_, ljyl, 
   {{0x44445ca2,0x7e7c2e31,0x8fa010fc,0x7bd801f5}},	//   _mk_, _utrp, _јасе, rdvu, 
   {{0x81cc2158,0xa2a416d1,0xdde800f2,0x2ee4032e}},	//   লাক_, _छिन्, _برسه_, _álfa_, 
   {{0x44445ca3,0xdb180793,0xa3cc00cd,0x7c2401e7}},	//   _ok_, _natö, _रसं_, éirs, 
   {{0x44445ca4,0x6a740327,0x00000000,0x00000000}},	//   _nk_, _iġfn, --, --, 
   {{0x44d0030a,0x00000000,0x00000000,0x00000000}},	//   _ań_, --, --, --, 
   {{0x44445ca5,0x186800d8,0x00000000,0x00000000}},	//   _ak_, _дади_, --, --, 
   {{0x44445ca6,0x61f4005c,0x9484010b,0x366801e2}},	//   _bk_, djyl, ьынд, _کشتۍ_, 
   {{0x1cb00327,0x28bc5ca7,0xa3cc00cd,0x3a240332}},	//   _ཐཱན_, ्बरि, _रसः_, limp_, 
   {{0x44445ca8,0x44d005c7,0xdb1800bc,0x8c1802e4}},	//   _dk_, _eń_, _obtí, קולי, 
   {{0x44445ca9,0x3a245caa,0x00000000,0x00000000}},	//   _ek_, nimp_, --, --, 
   {{0x44445cab,0x3d0800ab,0xf10400db,0x00000000}},	// [6690] _fk_, वनों_, رۉسۉ_, --, 
   {{0x81cc04c5,0x3a2405ab,0x72d4234c,0xed5000d1}},	//   লাগ_, himp_, _зооф, ۇپا_, 
   {{0x2bd85cac,0xfe7007d6,0x2b480b45,0xa2c00075}},	//   _योगा, لدن_, ƙaci_, _йәтк, 
   {{0x44445cad,0x263400b0,0x765c02e2,0x44d000a2}},	//   _zk_, pāoe_, nmsy, _yń_, 
   {{0x44445cae,0x3078008f,0x32085caf,0x3a240165}},	//   _yk_, _מאָנ, mkay_, dimp_, 
   {{0x44445cb0,0xe9d8068f,0x32085cb1,0x3a2400d7}},	//   _xk_, wdź_, lkay_, eimp_, 
   {{0xaa445cb2,0x60100008,0x3a240165,0x7c240ba1}},	//   некл, _dæmd, fimp_, èira, 
   {{0xe8f85cb3,0x32085cb4,0x3a2402d2,0x00000000}},	//   зли_, nkay_, gimp_, --, 
   {{0x320803ac,0x47d00154,0x19c04130,0xec241ca1}},	//   ikay_, তাসী, убым, _كىرپ, 
   {{0x0ae85cb5,0x26001bce,0x32080986,0x6d485cb6}},	//   _وراي_, _lóot_, hkay_, _iyea, 
   {{0x44445cb7,0x3208102c,0x61f400ee,0x00000000}},	//   _rk_, kkay_, yjyl, --, 
   {{0x44445cb8,0x64a45cb9,0xdb18014a,0x6d481418}},	//   _sk_, нама, _patö, _kyea, 
   {{0x69d80649,0x32085cba,0xddcc0153,0xa87c030d}},	//   _iawe, dkay_, _subū, _уллă_, 
   {{0x44445cbb,0x69d85cbc,0x6fc03d22,0x320803c4}},	//   _qk_, _hawe, र्मू, ekay_, 
   {{0x69d85cbd,0xed440d62,0xdb08037e,0x61f4037e}},	//   _kawe, _چھ_, uffø, tjyl, 
   {{0xe7ec10f7,0xed4400b2,0x69d85cbe,0xd7f00022}},	//   जावा_, _نھ_, _jawe, _азәы, 
   {{0x44445cbf,0x61f45cc0,0x10a03667,0x6d485cc1}},	// [66a0] _tk_, rjyl, литн, _nyea, 
   {{0x69d85cc2,0x44440302,0x200c012b,0xdb1803d1}},	//   _lawe, _uk_, ófi_, _katô, 
   {{0x69d80428,0x2600002e,0x93b40375,0x32080067}},	//   _oawe, _fóot_, _אליו_, bkay_, 
   {{0x69d85cc3,0xa0685cc4,0x1278008f,0x6010032e}},	//   _nawe, _нама_, _מאטע, _sæmd, 
   {{0x3a24030a,0xa0685cc5,0x59d80073,0x0d8001c6}},	//   vimp_, _хага_, _मोगर, улчн, 
   {{0x69d85cc6,0x6d480076,0xcfcc0154,0x00000000}},	//   _aawe, _dyea, রাউন, --, 
   {{0x69d85cc7,0x3a240311,0x5fc402a0,0x00000000}},	//   _bawe, timp_, _रॉयल, --, 
   {{0x69d85cc8,0x26001bce,0xcb0400ae,0x00000000}},	//   _cawe, _xóot_, عيين_, --, 
   {{0x3a241382,0x6010032e,0xc9f000db,0x00000000}},	//   rimp_, _tæmd, اسىع, --, 
   {{0x4c980302,0x69d802d0,0xdb1800d7,0x320802d0}},	//   _משמע, _eawe, _batô, zkay_, 
   {{0x32080f8f,0x69d85cc9,0x26005cca,0x69bc0490}},	//   ykay_, _fawe, _nóos_, व्ही, 
   {{0x69d85ccb,0xd4f001c4,0x00000000,0x00000000}},	//   _gawe, гжмө, --, --, 
   {{0x765c5ccc,0x4524015b,0xdb180022,0xa3e0000d}},	//   rmsy, _যুবক_, _vatõ, _नोह_, 
   {{0x69d85ccd,0x260001e1,0x3208002e,0x00000000}},	//   _zawe, _bóos_, wkay_, --, 
   {{0x69d85cce,0xe7ec166d,0x3208127b,0x00000000}},	//   _yawe, जारा_, tkay_, --, 
   {{0x69d85ccf,0x75d40d2f,0x32085cd0,0x614400d1}},	//   _xawe, _شيخا, ukay_, ھىلە, 
   {{0x32085cd1,0x614403cc,0x59c00c93,0xe5c40248}},	// [66b0] rkay_, پىلە, व्यर, _àwáà, 
   {{0x32085cd2,0xb4cc00af,0x263400b0,0x6d4800e4}},	//   skay_, रबी_, māoa_, _ryea, 
   {{0x25e4202e,0xbe880276,0x3208127b,0x00000000}},	//   _जोडी_, есче_, pkay_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69d85cd3,0x3ce40109,0x62980122,0x913000c7}},	//   _rawe, _crmv_, átov, _сҭах, 
   {{0x69d85cd4,0x26000de2,0xef5400c7,0x00000000}},	//   _sawe, _jóor_, _акгь, --, 
   {{0x62985cd5,0x40340724,0x69d85cd6,0x956806be}},	//   štov, _серс, _pawe, _daхi, 
   {{0x69d80139,0x00000000,0x00000000,0x00000000}},	//   _qawe, --, --, --, 
   {{0x6d48014b,0x69d8006f,0x7ae400b0,0xe7ec482a}},	//   _uyea, _vawe, āita, जाला_, 
   {{0x69d85cd7,0x8d800092,0x00000000,0x00000000}},	//   _wawe, _ይበቃል_, --, --, 
   {{0x69d85cd8,0x47d0009e,0x68ec030a,0x1bf8010f}},	//   _tawe, তালী, _šadd, _קלעב, 
   {{0xf9903669,0x7d040036,0x00000000,0x00000000}},	//   _هبه_, äisg, --, --, 
   {{0x59d83b90,0x00000000,0x00000000,0x00000000}},	//   _मोटर, --, --, --, 
   {{0x33d45cd9,0x98a05cda,0x81cc2b1b,0xa2a41df0}},	//   ліст, _тише, লাছ_, _छिद्, 
   {{0xd4645882,0x26001bce,0x28200014,0x23280e92}},	//   тире_, _dóor_, _مژھہ, фови_, 
   {{0xa3e00037,0x281c0092,0xe6440fac,0x00000000}},	//   _नोर_, _ስለአካ, _шейп, --, 
   {{0xe6105cdb,0x91001d5b,0xddc801ef,0xad9c0210}},	// [66c0] _مشک_, апте, _šnůr, _moźd, 
   {{0x26000694,0x25e40037,0x00000000,0x00000000}},	//   _góor_, _जोती_, --, --, 
   {{0x30740032,0x644c5cdc,0xd00c00f1,0x00000000}},	//   _ҡурс, mlbi, غلم_, --, 
   {{0xe1245cdd,0x23b0012c,0x9cc85cde,0x0dc401a9}},	//   _амми, _जाँद, дыка_, вуши_, 
   {{0x8cb40137,0x644c017a,0x10a00212,0xe8bc0118}},	//   ندوس_, olbi, _киян, ्बोच, 
   {{0xaa841d55,0xb0bc031c,0x6fc0043e,0x59d8000d}},	//   zmýš, _ཕྱིེ, र्दू, _मोजर, 
   {{0xceb400f7,0x0ab0038b,0x1d94013e,0x644c0fac}},	//   _иштө, لحيد, _арзё, ilbi, 
   {{0x3d881968,0x644c002f,0x89d40014,0x00000000}},	//   _سحری_, hlbi, پوٝر_, --, 
   {{0xd8385cdf,0x7d040036,0x629c0171,0xca44007b}},	//   дэн_, äisd, _lvpo, خليه_, 
   {{0x644c01bf,0x36d401c6,0x195401ec,0x00000000}},	//   jlbi, гоор, нақы_, --, 
   {{0x75d40fb4,0x00000000,0x00000000,0x00000000}},	//   هيدا, --, --, --, 
   {{0xb2741955,0xe8f40032,0x98a400c7,0x644c033f}},	//   ғлаш, тһә_, _аиде, elbi, 
   {{0x629c007c,0xb4cc000d,0x00000000,0x00000000}},	//   _avpo, रबे_, --, --, 
   {{0x263404fe,0xddc0012d,0x00000000,0x00000000}},	//   rāoa_, lloń, --, --, 
   {{0x07a02424,0xfbc45ce0,0x43945ce1,0x56f03769}},	//   _тајн, ल्यम, расс, _түнс, 
   {{0x644c5ce2,0x263402b5,0x26000694,0x35b400a7}},	//   albi, pāoa_, _wóor_, _сбир, 
   {{0x73c40116,0x236400df,0x26000de2,0x938800f3}},	// [66d0] _йәве, _ĝoje_, _tóor_, _осна_, 
   {{0xfbc40316,0x15e800e1,0x96b401ad,0xa3dc00cd}},	//   ल्मम, टाकर_, _अमाउ, णयः_, 
   {{0xd3440b28,0x8d740f87,0x629800e5,0x00000000}},	//   _شیره_, ناشا, átot, --, 
   {{0xed345ce3,0x3f9c0162,0x00000000,0x00000000}},	//   лэлэ, óvur_, --, --, 
   {{0xfd1045d7,0x6cc45ce4,0x629c0427,0x62980153}},	//   يجه_, уйла, _zvpo, štot, 
   {{0xeab85ce5,0xee941bf4,0x00000000,0x00000000}},	//   ейк_, _مدرک, --, --, 
   {{0x8d980014,0xe6d00210,0x00000000,0x00000000}},	//   _ٲخرس_, _तनेज, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xca700032,0x601001bf,0xddcc01ef,0x00000000}},	//   ыуҙы, _hæma, _zubů, --, 
   {{0x7d040664,0xa3e0012d,0x39640124,0x00000000}},	//   äise, _नों_, шныҳ, --, 
   {{0xa3e0033f,0x00000000,0x00000000,0x00000000}},	//   नएस_, --, --, --, 
   {{0xba740075,0x66e40184,0x78b0022c,0xb90c0241}},	//   _ئالت, _ҡола, ðhvø, _jimọ_, 
   {{0x74b85ce6,0xb90c0ca8,0x24200075,0x629c007c}},	//   курс_, _mimọ_, йҗиң, _svpo, 
   {{0xe6104f6f,0x2c78007f,0x478400c7,0xa3480354}},	//   _گشت_, _mèd_, _рыдб, езга_, 
   {{0x2c78033b,0x644c0175,0x6010032e,0x21a40798}},	//   _lèd_, rlbi, _næma, ливм, 
   {{0xe61012fd,0x61445ce7,0x00000000,0x00000000}},	//   _دشت_, геба, --, --, 
   {{0xdfe839f3,0xc6100cf1,0xfbc428d4,0x00000000}},	// [66e0] ндад_, ासीय_, ल्डम, --, 
   {{0xb90c0241,0xa0680354,0x62985ce8,0x00000000}},	//   _aimọ_, хаза_, átos, --, 
   {{0xdb080112,0x23280107,0x37b800fe,0x00000000}},	//   uffü, _чони_, _অসমৰ, --, 
   {{0x6010032e,0x00000000,0x00000000,0x00000000}},	//   _dæma, --, --, --, 
   {{0x9348001f,0xcfcc015b,0x00000000,0x00000000}},	//   _መስተዳ, রাজন, --, --, 
   {{0x9f48014a,0xe1340124,0x9e740214,0x00000000}},	//   _kobü_, _анҭы, _مهست, --, 
   {{0xe92c0092,0x00000000,0x00000000,0x00000000}},	//   _እስረኞ, --, --, --, 
   {{0xdc7400c7,0x497002e8,0x60d40210,0x24900210}},	//   _быжь, блъс, owym, _owym_, 
   {{0xb8142377,0x0a640022,0x77945ce9,0x00000000}},	//   идиј, ырши_, لیشا, --, 
   {{0xed3401c6,0x08f401d5,0x818c0240,0x00000000}},	//   _тэсэ, چریب_, ሓስበሉ_, --, 
   {{0x5fc45cea,0x2c780100,0x2fc40166,0x00000000}},	//   र्यल, _zèd_, _ölge_, --, 
   {{0xc9800116,0x245401a8,0x7ae80c8c,0x75d401c8}},	//   _луши, væma_, _irdt, جيحا, 
   {{0x2ed05ceb,0xd90c0424,0x00000000,0x00000000}},	//   _सन्त, _رید_, --, --, 
   {{0x5fc44a18,0x24900142,0x15c402dd,0x00000000}},	//   र्मल, _dwym_, _ﯨﺰﺩﻩ, --, 
   {{0xd2585cec,0x335400f7,0x00000000,0x00000000}},	//   еца_, рүнө_, --, --, 
   {{0xe6a400db,0xa2a400bc,0xc6900115,0x00000000}},	//   _тушү, _छिर्, _פאפ_, --, 
   {{0x62985ced,0x56900220,0x46140014,0x60d40142}},	// [66f0] átor, _тақт, _طوٝر, gwym, 
   {{0x7ae82dba,0x2c7802bd,0xa6e00174,0x00000000}},	//   _ordt, _rèd_, óðge, --, 
   {{0x62983bde,0x2c785cee,0xbd4400d1,0xeeb80120}},	//   štor, _sèd_, ەپنى, тлеш_, 
   {{0x7bc85cef,0x2c780100,0x5fc417c6,0xd6b400fe}},	//   _abdu, _pèd_, र्बल, _জনায, 
   {{0x7ae8007b,0xfbd000f1,0xfca800f1,0x00000000}},	//   _ardt, ګتن_, هاوو_, --, 
   {{0xab285cf0,0x1d045cf1,0x60105cf2,0xaae4007b}},	//   кола_, реши_, _hæmn, لسعو, 
   {{0x7f585cf3,0x7bc800e4,0x8d845cf4,0x3ee402e8}},	//   _барс_, _dbdu, _бузд, _лютв, 
   {{0x7d045cf5,0x6fc0000d,0x00000000,0x00000000}},	//   äisc, र्रू, --, --, 
   {{0x7ae8002f,0xebd8010a,0x00000000,0x00000000}},	//   _erdt, _идаш_, --, --, 
   {{0xda9405d9,0x24900142,0xd7e401f4,0x00000000}},	//   _چانڊ, _rwym_, амье_, --, 
   {{0x59c00073,0x4aa800cf,0x2490012d,0xe73000ae}},	//   व्हर, _سااپ_, _swym_, تصة_, 
   {{0x25e442e3,0x6d5c056a,0xed5801a6,0x601002d2}},	//   _जोशी_, _úsas, _kzž_, _næmn, 
   {{0x5fc400bc,0x7c340248,0xdb0808a5,0x00000000}},	//   र्डल, _áfrí, ggfæ, --, 
   {{0xe2845cf6,0xa6c839c6,0x25e4000d,0x7a8400db}},	//   илги, _алка_, _जोरी_, _ئشەم, 
   {{0xa1940063,0xe3645cf7,0xd7ec00ae,0x00000000}},	//   ијај, ркви, _زكي_, --, 
   {{0x24905cf8,0xe7ec00bc,0x7d0401bf,0xd6cc009f}},	//   _twym_, जाका_, øisk, _آقي_, 
   {{0x60245cf9,0x6010005c,0x55500150,0xe0d85cfa}},	// [6700] адаа, _dæmn, _وپىر, ъва_, 
   {{0x60d40368,0x66145cfb,0x956806be,0x00000000}},	//   rwym, _hlyk, _vaхt, --, 
   {{0x5d8405a9,0x9f480407,0x21744a03,0x60d4017a}},	//   للال, _robó_, _вугр, swym, 
   {{0x9f48026c,0x6b80032e,0xe3b05cfc,0xddc400db}},	//   _bobò_, _aflg, _ارک_, рбди, 
   {{0x3e7800c7,0x1c2400c7,0x2250010b,0x00000000}},	//   _ẽtĩ_, аҵаҩ_, mlyk_, --, 
   {{0x22500209,0x1ea82764,0xdee4030d,0x00000000}},	//   llyk_, _لاري_, _коги, --, 
   {{0x3f980421,0x601036e0,0x956801a9,0x91c803d4}},	//   _ieru_, _hæmo, _yaхs, ৱাৰ্, 
   {{0x3f985cfd,0x22500209,0x4aa406ab,0x98c43425}},	//   _heru_, nlyk_, _गिरव, асол, 
   {{0x3f98002e,0xb7bc005f,0x69f800cf,0x5fc421b8}},	//   _keru_, liģi, ابىڭ_, र्थल, 
   {{0x3f980198,0x7bc834a2,0x2250010e,0x00000000}},	//   _jeru_, _ubdu, hlyk_, --, 
   {{0x3f985cfe,0x66145cff,0x225000ee,0xf8b8004e}},	//   _meru_, _blyk, klyk_, _өөп_, 
   {{0x3f985d00,0xdebc0023,0x94a801a9,0x00000000}},	//   _leru_, _ሰባኺ_, ктга_, --, 
   {{0x201801af,0x236400df,0x94a802e8,0x44b40395}},	//   khpi_, _ĝoja_, ътна_, обяс, 
   {{0x3f9808e5,0x572400f2,0xaf780092,0x00000000}},	//   _neru_, _پرتق, ርቦትና_, --, 
   {{0x66145d01,0xa91c0153,0x00000000,0x00000000}},	//   _flyk, dažy, --, --, 
   {{0x46685d02,0x22500209,0x3f980166,0x5ee8012c}},	//   _крым_, glyk_, _aeru_, छिन्_, 
   {{0x3f985d03,0x764c3209,0xcf9803b7,0x7c282b94}},	// [6710] _beru_, _ikay, вје_, _omdr, 
   {{0x96d802f8,0xc104038b,0x3f9800e2,0x60105d04}},	//   _बनाउ, غولي, _ceru_, _dæmo, 
   {{0xeb981b6d,0x22505d05,0x3f985d06,0xdb0826bc}},	//   қий_, blyk_, _deru_, ngfä, 
   {{0x764c0a73,0x7c285d07,0x22500204,0x3f980241}},	//   _jkay, _amdr, clyk_, _eeru_, 
   {{0x764c009f,0xddcc0311,0xa9a4515c,0x00000000}},	//   _mkay, _subţ, ەمبى, --, 
   {{0x5fc40f4c,0x20180165,0x3f985d08,0x7d040108}},	//   र्दल, chpi_, _geru_, äisa, 
   {{0x764c5d09,0x2ef40114,0x27e80166,0xce6800f3}},	//   _okay, _узвр, _ğan_, _арад_, 
   {{0x7c285d0a,0xe9d85d0b,0x764c5d0c,0x3f985d0d}},	//   _emdr, уки_, _nkay, _zeru_, 
   {{0x6e285d0e,0x2d9c5d0f,0x4ad44d21,0xde440214}},	//   _imeb, mawe_, _भैरव, _اینو_, 
   {{0x2d9c5d10,0x22500209,0xc6100b7c,0x661400c0}},	//   lawe_, zlyk_, ास्य_, _slyk, 
   {{0x225009a5,0x6614005c,0x59c0000d,0x1540010b}},	//   ylyk_, _plyk, _वॉकर, җерм, 
   {{0xf408159d,0x2d9c5d11,0x645c069c,0xa6c40220}},	//   _אפ_, nawe_, _shpi, _ۇقتى, 
   {{0x6e284fc5,0x7c2800a9,0xa8842ba5,0x7d1c06be}},	//   _mmeb, _ymdr, _التى, _ərso, 
   {{0x2d9c5d12,0x764c5d13,0x23281b0a,0x42c80b01}},	//   hawe_, _ekay, гоги_, аҳон_, 
   {{0x2d9c5d14,0x22504a40,0x3f9800e4,0x6e28035a}},	//   kawe_, tlyk_, _reru_, _omeb, 
   {{0x3f985d15,0x66145d16,0x00000000,0x00000000}},	//   _seru_, _ulyk, --, --, 
   {{0x9fc80323,0x225009a5,0x290c5d17,0xa3640014}},	// [6720] лгаа_, rlyk_, nyea_, _گُدو, 
   {{0x6e285d18,0x2d9c06c8,0x33d40212,0x00000000}},	//   _ameb, eawe_, _діют, --, 
   {{0x3f985d19,0x22500209,0x6d440e78,0xdb08007c}},	//   _veru_, plyk_, ßhan, lffö, 
   {{0x2d9c5d1a,0x3f985d1b,0x201802d1,0xbd4404da}},	//   gawe_, _weru_, shpi_, ەپچى, 
   {{0x601000b5,0x3f985d1c,0x6d442ac2,0xa91c5d1d}},	//   _hæmm, _teru_, şhan, pažy, 
   {{0x8c405d1e,0x6e2800b4,0x44385d1f,0xdb0801e3}},	//   пече, _emeb, nnr_, ygfä, 
   {{0x09c0009e,0xda480131,0x2d9c5d20,0x291800a3}},	//   ্যনা, лчил_, bawe_, ùsan_, 
   {{0xdee4013e,0x2d9c00f1,0x0a5002d3,0x8f34011a}},	//   _коҳи, cawe_, _ምቅርራ, _האלו_, 
   {{0xd90c53e2,0x44380158,0x6d5c00c7,0x764c0139}},	//   عیت_, knr_, _úsap, _rkay, 
   {{0x7c285d21,0x44380334,0x764c27ac,0x77984fac}},	//   _umdr, jnr_, _skay, шкор_, 
   {{0x4438054e,0x891401b9,0xf9c4004e,0x92c000cc}},	//   dnr_, لغیز_, _мажү, _এছ্_, 
   {{0x0f540302,0xdb0803fa,0x443801f5,0x00000000}},	//   מיים_, rgfä, enr_, --, 
   {{0xf8b801ee,0x00000000,0x00000000,0x00000000}},	//   _төй_, --, --, --, 
   {{0x7c3803bd,0x44385d22,0x2d9c07a8,0x657401ed}},	//   nnvr, gnr_, zawe_, _egyh, 
   {{0x2d9c5d23,0x69d00254,0x44281cd0,0x00000000}},	//   yawe_, _üheö, сцям_, --, 
   {{0x764c5d24,0x601001bf,0x6734000f,0x2d9c00e8}},	//   _ukay, _dæmm, úzje, xawe_, 
   {{0x44380175,0xef985d25,0xd4980818,0xf48435cf}},	// [6730] bnr_, икаш_, _ёри_, _بابی, 
   {{0x2d9c5d26,0xd1740ed0,0x7c3801f5,0x44380175}},	//   wawe_, рыңы, jnvr, cnr_, 
   {{0xa3e0375c,0x2d9c5d27,0x63a8002d,0xdec00daf}},	//   _नोट_, tawe_, _ôfna, мәто, 
   {{0x7c38017a,0x00000000,0x00000000,0x00000000}},	//   envr, --, --, --, 
   {{0xfe705d28,0xeb985d29,0x09c00154,0x9d7400db}},	//   ردم_, аил_, ্যমা, زئنچ, 
   {{0x824802d3,0x31d0063f,0x2d9c5d2a,0x6e940a5b}},	//   _ረብሓታ, _ịrịọ_, sawe_, _мигу, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6e285d2b,0x2d9c5d2c,0x7c3801a4,0xe884030d}},	//   _umeb, qawe_, anvr, огип, 
   {{0x2b48033f,0x5fc42802,0xbc9400f3,0x00000000}},	//   łac_, र्वल, _натј, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x09c05d2d,0x69cc08e7,0xd1bc001f,0xfd6402e3}},	//   ্যবা, _ñaeo, ትመት_, ktrọ, 
   {{0xe568084c,0x443801f5,0xb9e40212,0xdb045522}},	//   иинд_, wnr_, _нічи, ømål, 
   {{0x69c85d2e,0xdb0801e6,0xf7340023,0x59c00401}},	//   mfee, uffö, _ብዘይሕ, _वॉटर, 
   {{0x69c85d2f,0x68e85d30,0x44385d31,0x9cd4011a}},	//   lfee, mved, unr_, חושה_, 
   {{0x68e85d32,0xe2985d33,0x69c80081,0xa2d40472}},	//   lved, раб_, ofee, غيرت, 
   {{0x2328016c,0x69c85613,0x6010005c,0x16840345}},	//   гоҳи_, nfee, _væmm, _باوێ, 
   {{0x256401d9,0x68e801ed,0x69c8002d,0x48b40183}},	// [6740] _باغُ, nved, ifee, _অনুৰ, 
   {{0xe29830ba,0x7e6002ce,0x68e80c8c,0x32185d34}},	//   _као_, _shmp, ived, _elsy_, 
   {{0xdc285d35,0x26c45d36,0x69c8017a,0x68e82ca8}},	//   یسته_, ntlo_, kfee, hved, 
   {{0x628c5d37,0xdfd005d9,0x7e600076,0x68e85d38}},	//   mpbo, _ڪيس_, _qhmp, kved, 
   {{0x16b4262c,0x68e85d39,0x69c801e7,0x00000000}},	//   _अम्ब, jved, dfee, --, 
   {{0x70d800c8,0x69c85d3a,0x628c01a4,0xad6437ba}},	//   _פֿרו, efee, opbo, سانه, 
   {{0x68e85d3b,0x7c38017a,0xad9c012d,0x00000000}},	//   eved, rnvr, _koźl, --, 
   {{0xc2140134,0x9d4401b9,0x69c80009,0x1d08064e}},	//   nkɔ_, _дебд, gfee, _кеби_, 
   {{0x626c01e4,0x68e85d3c,0xb4c8007d,0x3f8c0037}},	//   _aŝok, gved, _ईहे_, _õdus_, 
   {{0x7e7c5d3d,0xc0cc0023,0x69c85d3e,0xd8080131}},	//   _kurp, _ኣነስ_, afee, рхил_, 
   {{0x8f7805e1,0x7bd85d3f,0x7e7c5d40,0xc7f40212}},	//   יניק, mevu, _jurp, інює_, 
   {{0x7bd85d41,0x38c80133,0x68e803b9,0x00000000}},	//   levu, _هاتی_, bved, --, 
   {{0x7e7c5d42,0x628c5d43,0x27140208,0x736800d1}},	//   _lurp, epbo, án_, ﻳﺘﯩﺶ_, 
   {{0x7bd85d44,0x7e7c5d45,0x00000000,0x00000000}},	//   nevu, _ourp, --, --, 
   {{0x7e7c1180,0x00000000,0x00000000,0x00000000}},	//   _nurp, --, --, --, 
   {{0x7bd85d46,0xd49803f6,0x71784411,0x00000000}},	//   hevu, _кро_, сбар_, --, 
   {{0x7bd80481,0x7e7c01c0,0x628c0ea0,0x301400ee}},	// [6750] kevu, _aurp, apbo, пдар, 
   {{0x32180399,0x7bd8012c,0xcf88013e,0x37d8015b}},	//   _wlsy_, jevu, рсад_, তাকর, 
   {{0x7bd85d47,0x7e7c5d48,0x69c80ea0,0xb8dc0327}},	//   devu, _curp, yfee, _ཆའ_, 
   {{0x68e803cd,0x7e7c0153,0xacf801ec,0x00000000}},	//   yved, _durp, йнеу_, --, 
   {{0xb4c800af,0x7e7c5d49,0xe6ec0419,0x00000000}},	//   _ईहो_, _eurp, väčš, --, 
   {{0x69c85d4a,0x7bd85d4b,0x68e85d4c,0xfc0400d6}},	//   wfee, gevu, vved, мпіо, 
   {{0x69c85d4d,0x7e7c5d4e,0x5fa000d1,0xfe7000f7}},	//   tfee, _gurp, _سەنم, ردۅ_, 
   {{0x68e8005f,0xad241e87,0x00000000,0x00000000}},	//   tved, _فىزى, --, --, 
   {{0x7bd82143,0x7e7c04cc,0x25e45d4f,0x188002dd}},	//   bevu, _zurp, _जोगी_, еңін, 
   {{0x7bd85d50,0x69c84f30,0x68ec0077,0x00000000}},	//   cevu, sfee, _áadm, --, 
   {{0xe9445d51,0x69c80373,0x81c00154,0x8c8401ee}},	//   _کرای, pfee, ংড়ি_, _уҙһа_, 
   {{0x26000de2,0x26c400d8,0xddc00115,0xd7ec00db}},	//   _jóox_, rtlo_, kloŝ, _ەكو_, 
   {{0x26c402f0,0xddc00115,0xa8880ce8,0x00000000}},	//   stlo_, jloŝ, _уйла_, --, 
   {{0x442c01ab,0xa6c8009a,0xdd8c01ec,0x00000000}},	//   òd_, _هوتل_, _ﺟﯩﻠﺠ_, --, 
   {{0x89300020,0x245401a8,0x3f9c01a8,0x491000bc}},	//   _ኢሕአዴ, næmi_, ðvum_, धनको_, 
   {{0x7bd80564,0x628c01f5,0x00000000,0x00000000}},	//   zevu, rpbo, --, --, 
   {{0x7e7c5d52,0x7bd85d53,0x55b80375,0x63a8000f}},	// [6760] _surp, yevu, _המפו, _ôfno, 
   {{0x7e7c5d54,0x628c4162,0x7d04005b,0xe3b800f0}},	//   _purp, ppbo, äism, _убо_, 
   {{0x7e7c5d55,0x7bd85d56,0xa2a4012c,0x13e40327}},	//   _qurp, vevu, _छिट्, _སྣྲཔ, 
   {{0x25a02a1f,0x7bd819a2,0x7afc00db,0xddc00115}},	//   nakl_, wevu, _àrti, bloŝ, 
   {{0x7bd85d57,0x2600002e,0x644c0009,0x00000000}},	//   tevu, _dóox_, oobi, --, 
   {{0x7e7c5d58,0x61e42c44,0x644c5d59,0x00000000}},	//   _turp, _hakl, nobi, --, 
   {{0x9d6000c6,0x60101125,0x7bd85d5a,0x61e45d5b}},	//   _šɦăɗ, _næmi, revu, _kakl, 
   {{0xadb400c9,0x61e40427,0x7bd80117,0xa2a400e1}},	//   _ощущ, _jakl, sevu, _ज़िन्, 
   {{0x61e45d5c,0x644c5863,0xdd94005e,0x20085d5d}},	//   _makl, kobi, _маңы, _kobi_, 
   {{0x61e45d5e,0x644c05ce,0x2008299d,0x00000000}},	//   _lakl, jobi, _jobi_, --, 
   {{0x644c5d5f,0x61e45d60,0x6fc00d0a,0x00000000}},	//   dobi, _oakl, र्टू, --, 
   {{0xcb101a4c,0x20085d61,0x8af80302,0x6010008c}},	//   _אלע_, _lobi_, _להבי, _dæmi, 
   {{0xa9c45d62,0x53800092,0xc7340023,0x00000000}},	//   _آزمو, ካሄዱት_, _ብዘይቅ, --, 
   {{0x644c5d63,0x2378004e,0x61e45d64,0x200822d5}},	//   gobi, _cgpj_, _aakl, _nobi_, 
   {{0x61e45d65,0x25a02a69,0xdb08143a,0xa3e0012d}},	//   _bakl, bakl_, ggfø, नएज_, 
   {{0x61e45d66,0x92680f89,0x10e40150,0x00000000}},	//   _cakl, срга_, _ﻏﻴﺭﻨ, --, 
   {{0x61e404b9,0x20085d67,0x644c5d68,0xd9bc0eac}},	// [6770] _dakl, _bobi_, bobi, _আসাম, 
   {{0x20085d69,0xdb1825e6,0x61e4035a,0x15b01896}},	//   _cobi_, _actí, _eakl, _تەڭس, 
   {{0x20085667,0x61e45d6a,0x7f945d6b,0xa2c001ee}},	//   _dobi_, _fakl, хахх, _иәтк, 
   {{0x61e405b1,0x9f480120,0x6fc00a59,0x1ee800f1}},	//   _gakl, _robô_, र्जू, غونی_, 
   {{0xc17400f5,0x157c0220,0x00000000,0x00000000}},	//   _плющ, _ﺭﯞﺣﯩ, --, --, 
   {{0x61e45d6c,0xe0f8011a,0x60f8123b,0x00000000}},	//   _zakl, _ולשל, _והשק, --, 
   {{0x61e45d6d,0xaa440209,0x09c00154,0x7d1c06be}},	//   _yakl, мекл, ্যসা, _ərsi, 
   {{0x644c5d6e,0x0af001c0,0x20085d6f,0x61e4008e}},	//   zobi, _үүдэ, _zobi_, _xakl, 
   {{0x629801ed,0x25a00109,0xe8f802bf,0x644c5d70}},	//   átoz, vakl_, іло_, yobi, 
   {{0x200800e8,0x00000000,0x00000000,0x00000000}},	//   _xobi_, --, --, --, 
   {{0x644c5d71,0x1cb80003,0x933c0092,0xaa58009b}},	//   vobi, _མའོ_, _አቤቱታ, _дижу_, 
   {{0x64a45d72,0x09c000fe,0x644c007f,0x6a740064}},	//   мама, ্যহা, wobi, _išfo, 
   {{0x25a00165,0xfbc42894,0x00000000,0x00000000}},	//   rakl_, ल्कम, --, --, 
   {{0x61e45d73,0x7b080162,0x7af40254,0x6010032e}},	//   _sakl, _óstø, _õetü, _tæmi, 
   {{0x61e45d74,0x20085d75,0x25a00784,0x15d000d1}},	//   _pakl, _robi_, pakl_, _ﻛﯚﺭﻩ, 
   {{0x644c5d76,0x61e40548,0x1fa41b61,0x7d04023a}},	//   sobi, _qakl, खण्ड, äisk, 
   {{0x60085d77,0x1cb8031c,0x644c5d78,0x20085d79}},	// [6780] онам_, _མའེ_, pobi, _pobi_, 
   {{0x61e45d7a,0x644c5d7b,0xb3180327,0xb6e00432}},	//   _wakl, qobi, ུགཡང_, _çäýn, 
   {{0x61e45d7c,0x20080793,0x93f8011a,0x00000000}},	//   _takl, _vobi_, _וליי, --, 
   {{0x4edc00eb,0x00000000,0x00000000,0x00000000}},	//   ণমূল, --, --, --, 
   {{0x20085d7d,0xf3300092,0x3cf8012d,0x00000000}},	//   _tobi_, _አስተና, ंमें_, --, 
   {{0x1ea8009a,0x7b841d37,0x00000000,0x00000000}},	//   _وازي_, راتە, --, --, 
   {{0xa6e0008c,0x6fe003d4,0xa3b40037,0x00000000}},	//   óðle, নাশৈ, _चएन_, --, 
   {{0xdb18013a,0xba540137,0x00000000,0x00000000}},	//   _uctí, رچاع, --, --, 
   {{0xacb00075,0x00000000,0x00000000,0x00000000}},	//   _مەنب, --, --, --, 
   {{0xdd94052f,0x395800da,0x00000000,0x00000000}},	//   _хаҡы, ārs_, --, --, 
   {{0x16100037,0x2af40153,0x00000000,0x00000000}},	//   _डकदर_, _пяцё, --, --, 
   {{0xdebc0023,0x00000000,0x00000000,0x00000000}},	//   _ሰኣን_, --, --, --, 
   {{0x0ef80316,0x73c405a2,0xd8a400ec,0x7d040108}},	//   _एप्स_, нәне, _کهڙو_, äish, 
   {{0x6010032e,0x2d900220,0x00000000,0x00000000}},	//   _kæmu, _ﺟﯩﻠﻰ_, --, --, 
   {{0x3dc40d27,0x0cd800dc,0x09c00154,0xbbdc00bc}},	//   _ocmw_, _यन्म, ্যরা, _यसैक, 
   {{0x68ec0841,0x291801bf,0x00000000,0x00000000}},	//   _šadi, øsag_, --, --, 
   {{0x1cc80003,0x568801f7,0x00000000,0x00000000}},	// [6790] ླངས_, _ائڪٽ_, --, --, 
   {{0xdb185d7e,0x705401d5,0xb0540228,0x6d5c01ab}},	//   _octà, رناا, رپات, _ùsai, 
   {{0x1cb80d46,0xb2745d7f,0xf1b8035b,0x601002d2}},	//   _མའུ_, _плош, _нӡа_, _næmu, 
   {{0x709400f3,0x00000000,0x00000000,0x00000000}},	//   _памф, --, --, --, 
   {{0x2ca80491,0x40840588,0x23640115,0xacf85d80}},	//   éad_, _аусб, _ĝoji_, янду_, 
   {{0x6b645d81,0x2f880022,0x00000000,0x00000000}},	//   нкла, _хәан_, --, --, 
   {{0xe7e410f7,0xb8140154,0x8d8400cf,0xfeb81410}},	//   _कसबा_, াফাত_, _жузд, _يافت_, 
   {{0xdb18011f,0x6010032e,0xa9e400f1,0x436c00d1}},	//   _abtó, _dæmu, عګان, ﺰﺩﯨﻦ_, 
   {{0x291826f6,0x5fc40709,0xc8480023,0x00000000}},	//   ása_, र्कल, _ምእማን, --, 
   {{0x8b6400cf,0x7c8400d8,0x00000000,0x00000000}},	//   _قاام, _јуте, --, --, 
   {{0xe97800d8,0x00000000,0x00000000,0x00000000}},	//   _ебеш_, --, --, --, 
   {{0x3b640014,0xe28c01a9,0x00000000,0x00000000}},	//   _شُنِ, _rtа_, --, --, 
   {{0x69340116,0x00000000,0x00000000,0x00000000}},	//   _янду, --, --, --, 
   {{0x33d45d82,0x7d04049b,0x0680014b,0x00000000}},	//   кіст, äisi, _иҳон, --, 
   {{0x15e800ab,0x2cbc0d27,0xe61800a7,0xed5800d7}},	//   _जोकर_, huwd_, _ндк_, _lyž_, 
   {{0x91e05d83,0x49540023,0xf7700345,0x00000000}},	//   лосе, _ምስትብ, _ئاه_, --, 
   {{0x1fb40e1d,0x65800374,0x00000000,0x00000000}},	// [67a0] есер, āwhā, --, --, 
   {{0x2cbc01a4,0x4fe400db,0x00000000,0x00000000}},	//   duwd_, нмун_, --, --, 
   {{0x44445d84,0x2cbc0196,0xf0002f8d,0xe1f802e8}},	//   _ij_, euwd_, шүри, _егн_, 
   {{0x2a6c0369,0xc1b40139,0x601002d2,0xdb085d85}},	//   jmeb_, _шәгы, _ræmu, ínít, 
   {{0x60105d86,0x00000000,0x00000000,0x00000000}},	//   _sæmu, --, --, --, 
   {{0x44445d87,0xd24c004b,0xed5801ef,0x00000000}},	//   _jj_, _ننۍ_, _dyž_, --, 
   {{0xcb041b45,0x44440f85,0x23d000cd,0xef900244}},	//   فيون_, _mj_, द्यद, _ئیمد, 
   {{0x9e641fc2,0xcaf00b24,0x00000000,0x00000000}},	//   _سازن, اسوب, --, --, 
   {{0x1c445d88,0xcd6c0092,0x15e8000d,0x00000000}},	//   _знам, ባቸውና_, _जोगर_, --, 
   {{0x38780267,0x44445d89,0x195401ec,0x00000000}},	//   örr_, _nj_, мақы_, --, 
   {{0xdb045d8a,0xdb085d8b,0x601001bf,0xd5140248}},	//   ämäl, ngfü, _hæms, _ọ̀n, 
   {{0x44445d8c,0x20180113,0x225001c4,0x7d040036}},	//   _aj_, hkpi_, joyk_, äisw, 
   {{0x44445d8d,0x7414005e,0x6bd401ec,0xab60010e}},	//   _bj_, نوحا, _ستەر, _ýürd, 
   {{0x629c0076,0x36d40022,0x444424b6,0x257001ec}},	//   _bwpo, _аокр, _cj_, шқыс, 
   {{0x44445d8e,0x2454008c,0x43842ad5,0x629c0142}},	//   _dj_, væmt_, الفق, _cwpo, 
   {{0x44445d8f,0x72040345,0x88240092,0x00000000}},	//   _ej_, خورم, _ስለተሰ, --, 
   {{0x44445d90,0x629c02d0,0x00000000,0x00000000}},	// [67b0] _fj_, _ewpo, --, --, 
   {{0x44445d91,0x4ea45d92,0x765c369d,0xdb08022c}},	//   _gj_, ерда, llsy, ngfó, 
   {{0xa8000086,0x245400b5,0x629c0142,0x6c7802dd}},	//   òñid, ræmt_, _gwpo, _ﺠﺎﻨﺏ_, 
   {{0xfe705d93,0xed34084c,0x00000000,0x00000000}},	//   مدن_, кэлэ, --, --, 
   {{0x44445d94,0x03e40154,0x765c02d0,0x3208035a}},	//   _yj_, খারী_, ilsy, mjay_, 
   {{0xa13400c8,0x601003b2,0x7c945d95,0x765c0112}},	//   _יארק_, _dæms, اشنا, hlsy, 
   {{0x320802d0,0x00000000,0x00000000,0x00000000}},	//   ojay_, --, --, --, 
   {{0x32080c8c,0xe8f85d96,0x0e0800db,0xc0f80023}},	//   njay_, дли_, _ээги_, ገሰሉ_, 
   {{0x2d8c5d97,0xa3b0012d,0x320803ac,0x9a5400ae}},	//   _ifee_, _ऑयल_, ijay_, خليط_, 
   {{0x765c002f,0x3208035a,0xe92c0092,0x6d44002f}},	//   elsy, hjay_, _እድለኞ, ßhau, 
   {{0x44445d98,0x63a8000f,0x2cac01bf,0x5fc40db3}},	//   _rj_, _ôfni, _hved_, र्टल, 
   {{0xc9845d99,0x320803ac,0x68ec0171,0x99301bf4}},	//   _чужи, jjay_, _šadu, افیت, 
   {{0x4444105c,0xc7700372,0x3208127b,0x00000000}},	//   _pj_, _өткө, djay_, --, 
   {{0x44445d9a,0x02c400d1,0x3208035a,0x00000000}},	//   _qj_, лигү, ejay_, --, 
   {{0x799002ea,0x03e4015b,0x53a05d9b,0x2bc85d9c}},	//   _ékwé, খালী_, расб, _राना, 
   {{0x44445d94,0x320803ac,0xa2e401d5,0x25a408a5}},	//   _wj_, gjay_, ноҳд, _þol_, 
   {{0x444408ad,0xa0a45d9d,0xf3f001fb,0x236400df}},	// [67c0] _tj_, тазд, ộc_, _ĝoju_, 
   {{0x44445d9e,0x2d8c03a0,0x320802d0,0xd02000d4}},	//   _uj_, _afee_, ajay_, амуй, 
   {{0x1cb8025c,0x34445d9f,0x6d480356,0x320803ac}},	//   _མའང_, _сүри_, _axea, bjay_, 
   {{0x44385da0,0xf1c80150,0x320803ac,0x5fc407d0}},	//   lir_, _كوپى_, cjay_, र्जल, 
   {{0x44380491,0x601012e8,0x26180406,0x6dc4006c}},	//   oir_, _dæmr, _पवनी_, ازمل, 
   {{0x2d8c01e1,0x21980150,0x00000000,0x00000000}},	//   _efee_, _ﺘﻘﻠﻴ_, --, --, 
   {{0x6d485da1,0x8aa05da2,0x25b0007c,0x00000000}},	//   _exea, арыд, _odyl_, --, 
   {{0xdecc069c,0xfcc40131,0x4b84010b,0x00000000}},	//   _ኣሰና_, _бәкм, нйән_, --, 
   {{0x98480801,0x0a6400a7,0x765c0194,0x00000000}},	//   дяна_, ърши_, vlsy, --, 
   {{0x44385da3,0x06d802f5,0x25b0010b,0x497001e0}},	//   jir_, ধিনি, _adyl_, шлыс, 
   {{0x61185da4,0x32080c8c,0x2490010e,0x4fb805d0}},	//   _hālā, yjay_, _atym_, וציא, 
   {{0x7c385da5,0xc980136b,0x3494013e,0x76c40432}},	//   livr, _куши, ламр, _aňyý, 
   {{0x44385da6,0x2bc84433,0x37c40032,0x9f480240}},	//   fir_, _रामा, _йәнб, _babë_, 
   {{0x4438221f,0x47305da7,0x611800cd,0x6a640332}},	//   gir_, اریز, _mālā, mófa, 
   {{0x320814dc,0x2490003a,0x6a64007b,0x7bc800d4}},	//   tjay_, _etym_, lófa, _mcdu, 
   {{0x44385da8,0xd1b800f7,0xcad4025d,0x7c385da9}},	//   air_, باسا_, כולת_, hivr, 
   {{0x44385daa,0x32085dab,0x6a64007b,0x7c380158}},	// [67d0] bir_, rjay_, nófa, kivr, 
   {{0x44385dac,0x32080c8c,0x3354004e,0xa2b000fe}},	//   cir_, sjay_, _бүгө_, _চহৰখ, 
   {{0x2cac4a1f,0x6a640332,0x3208035a,0x00000000}},	//   _sved_, hófa, pjay_, --, 
   {{0x387c5dad,0x2cac0165,0x611800dc,0x914801a9}},	//   _livr_, _pved_, _bālā, _жчга_, 
   {{0x98540210,0x00000000,0x00000000,0x00000000}},	//   _złą_, --, --, --, 
   {{0xbfb80502,0x7c385dae,0x2cac0165,0x6a64007b}},	//   _لطفا_, givr, _vved_, dófa, 
   {{0x40345daf,0x499015d6,0xfbd000be,0x00000000}},	//   _терс, لیار, تتن_, --, 
   {{0x44385db0,0x2cac01bf,0x28e800ee,0x7dc4113e}},	//   zir_, _tved_, едип_, _ەتەك, 
   {{0x6010019b,0x44385db1,0x7d04049b,0x49001823}},	//   _kæmp, yir_, äist, рүлг, 
   {{0x44385db2,0xa3ec2cc5,0x7c385db3,0x00000000}},	//   xir_, _ঐক্য_, civr, --, 
   {{0xe5a450e6,0x29d4006c,0x24905db4,0x611800de}},	//   лини, _бўлс, _stym_, _zālā, 
   {{0x44385db5,0xe8f400c6,0xc5f801e0,0x2558104e}},	//   wir_, _مستخ, тғи_, ергэ_, 
   {{0x44385db6,0x200c0793,0x6aa003cb,0xf3ec0183}},	//   tir_, öfik_, _hwlf, ঞানৰ_, 
   {{0xd91800c8,0x44385db7,0x24900332,0xd8b005af}},	//   _רוסל, uir_, _vtym_, _اموخ, 
   {{0x44385db8,0x23280f14,0x952001d5,0x56901fbe}},	//   rir_, хови_, لکیم, _лајт, 
   {{0x09c00011,0x00000000,0x00000000,0x00000000}},	//   ্যকা, --, --, --, 
   {{0xe0840c8b,0xe0d80006,0xe57800d4,0x11d400ae}},	// [67e0] اجري, эва_, _язи_, طولة_, 
   {{0x44385db9,0x6b80020c,0xe61000ec,0x00000000}},	//   qir_, _nglg, _خشڪ_, --, 
   {{0x63780131,0x601000b5,0x7c38004a,0x307416ab}},	//   _ясир_, _dæmp, vivr, рутс, 
   {{0x175400c8,0x52d400c8,0x7c380477,0x6118002b}},	//   אסער_, _גוטע_, wivr, _pālā, 
   {{0x9f480085,0x7c381d4b,0x00000000,0x00000000}},	//   _mabé_, tivr, --, --, 
   {{0x2bc82c2e,0x7f5c0200,0x61180055,0xdee44d01}},	//   _राणा, _tyrq, _vālā, _йоги, 
   {{0x7c385dba,0x70500133,0xd00c02da,0x00000000}},	//   rivr, _بۆلا, _علف_, --, 
   {{0x611800da,0x7d0428ef,0x9f4802e2,0x2a7c0142}},	//   _tālā, äiss, _rabè_, _ciwb_, 
   {{0x68ec01fa,0x9f480561,0x00000000,0x00000000}},	//   _šadr, _sabè_, --, --, 
   {{0x6a641941,0xfce40032,0x38341d5b,0x00000000}},	//   rófa, _йоғо, рнор, --, 
   {{0x9f485dbb,0x36d4013e,0x6aa0015d,0x2bc8202e}},	//   _babé_, шонр, _gwlf, _राता, 
   {{0x98a45dbc,0x9f485dbd,0xc8400116,0x2b10012c}},	//   _биде, _vabè_, _һечй, तहरु_, 
   {{0xb6f800cf,0x00000000,0x00000000,0x00000000}},	//   رىڭا_, --, --, --, 
   {{0x3cec0d79,0xb6c441e5,0x00000000,0x00000000}},	//   _आईने_, _көмд, --, --, 
   {{0x92685dbe,0x43945dbf,0x00000000,0x00000000}},	//   ераа_, сасс, --, --, 
   {{0xa368036b,0x95c85dc0,0xc6a001c6,0x00000000}},	//   _zbеk, _чука_, _урши, --, 
   {{0xb0345dc1,0xe2740137,0x705801c6,0x00000000}},	// [67f0] анаш, рктө, ваар_, --, 
   {{0xa1980150,0x101400f2,0x00000000,0x00000000}},	//   _ﺘﻘﺼﻑ_, دبرد, --, --, 
   {{0xc0582928,0xafe401e0,0x61ec0847,0xc7d4011a}},	//   اشقا_, лоҡл, önlä, רובי_, 
   {{0xc10801e1,0x6dc00137,0x00000000,0x00000000}},	//   _léṣu_, تۅرۅ, --, --, 
   {{0xfaf85dc2,0xe7e40073,0x416803f6,0x00000000}},	//   _arī_, _कसला_, _бјрм_, --, 
   {{0xc06c0882,0x6ab402e8,0xfaf800ef,0x00000000}},	//   kṣyā, асих, _brī_, --, 
   {{0x7d040108,0x8b340116,0x00000000,0x00000000}},	//   äisr, دۋار_, --, --, 
   {{0xa9c000f7,0x00000000,0x00000000,0x00000000}},	//   زۅتۉ, --, --, --, 
   {{0x2d9c5dc3,0x3cec00e1,0xba080131,0xcbc45b7a}},	//   mbwe_, _आईये_, اتىك_, _مزاي, 
   {{0x7d040158,0xfaf80171,0x00000000,0x00000000}},	//   åise, _frī_, --, --, 
   {{0xbb840486,0x66045dc4,0x9f5c001e,0x2d9c0083}},	//   _المي, апна, _ôtô_, obwe_, 
   {{0x6a6409c2,0x2d9c0083,0x7afc5dc5,0xf3f00208}},	//   mófo, nbwe_, _árta, ộn_, 
   {{0x69d80161,0x2d9c0099,0x5a08008f,0xf9905dc6}},	//   _ibwe, ibwe_, _בלײַ, _ربن_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6a6409c2,0x9f48003e,0xe5000037,0x00000000}},	//   nófo, _tabé_, _लपकि_, --, 
   {{0x93400212,0x614400d8,0x00000000,0x00000000}},	//   інте, аеба, --, --, 
  
   {{0x69d84f19,0x46a016c3,0xa5082bbd,0x54b01de6}},	// [6800] _mbwe, _тақв, _репа_, _мәрф, 
   {{0x2d9c1418,0xe7bc05d7,0xdb1000e8,0x3cec000d}},	//   ebwe_, _एएफप, ëgër, _आईबे_, 
   {{0x69d85dc7,0xe2985dc8,0xd00c00f1,0x539802e4}},	//   _obwe, _шан_, بلل_, _שיטו, 
   {{0x0d8001e0,0x2cbc0142,0x23d00b8f,0x00000000}},	//   ҙлән, frwd_, द्रद, --, 
   {{0x0d805dc9,0xdb085b00,0x5c04004e,0x00000000}},	//   әлән, ngfö, ияка, --, 
   {{0x69d85dca,0xa0340075,0x2d9c2252,0x69d401ed}},	//   _abwe, _ئىست, abwe_, őzel, 
   {{0x69d80083,0x6a640077,0x2d9c1418,0xc0e00023}},	//   _bbwe, gófo, bbwe_, _ሓዲሩ_, 
   {{0x68f803cb,0x2cbc0042,0x00000000,0x00000000}},	//   _brwd, brwd_, --, --, 
   {{0xc8c418a1,0x98040209,0xa3d40f44,0x00000000}},	//   لوين_, аянд, सभा_, --, 
   {{0x69d85dcb,0x7d281d89,0xfaf8002b,0xd7f800c7}},	//   _ebwe, ırsı, _trī_, туи_, 
   {{0x6a640077,0x00000000,0x00000000,0x00000000}},	//   cófo, --, --, --, 
   {{0x68f8015d,0xc8c40345,0xc10801e1,0x00000000}},	//   _frwd, دوین_, _wéṣu_, --, 
   {{0xb89406d5,0xdb080267,0x00000000,0x00000000}},	//   _التع, ggfö, --, --, 
   {{0xfaf800ef,0x2bc81223,0x00000000,0x00000000}},	//   _dzīv_, रलया, --, --, 
   {{0xdb1809ff,0x2bc839de,0xd2585dcc,0x335400f7}},	//   _actú, _रासा, вца_, сүнө_, 
   {{0x92683ae4,0xd5b81353,0xcee80133,0x00000000}},	//   трга_, _рск_, ێران_, --, 
   {{0x569002dd,0xd448009d,0x00000000,0x00000000}},	// [6810] _уақт, _аянд_, --, --, 
   {{0x69dc0109,0x74145dcd,0x00000000,0x00000000}},	//   ôsez, _چوکا, --, --, 
   {{0xeeb80e1d,0x51840024,0x00000000,0x00000000}},	//   улеш_, _вуга, --, --, 
   {{0x9f48026c,0x2bc80490,0x00000000,0x00000000}},	//   _tabî_, _राहा, --, --, 
   {{0xac185dce,0x7d045dcf,0x00000000,0x00000000}},	//   лоду_, äisp, --, --, 
   {{0xaae45dd0,0x6a640599,0x7c940214,0xd0180798}},	//   مسعو, tófo, زشها, _рфм_, 
   {{0x99840205,0xadbc0064,0x00000000,0x00000000}},	//   çişe_, _павi, --, --, 
   {{0x6a640077,0xae444d2f,0xe9a80101,0xdb08007c}},	//   rófo, _اپرو, اگان_, ygfö, 
   {{0x6a640587,0x4238011a,0x00000000,0x00000000}},	//   sófo, ינהל_, --, --, 
   {{0x2c6800d0,0xe9f801ec,0x7c8401f4,0x07a00022}},	//   búda_, _әнді_, _футе, әаҟн, 
   {{0xe7385dd1,0x00000000,0x00000000,0x00000000}},	//   уен_, --, --, --, 
   {{0x69d8151f,0xfd6401fb,0x66e4023b,0xe644074d}},	//   _ubwe, _nguộ, _ҳока, семп, 
   {{0xd6cc0e83,0x69c80100,0x00000000,0x00000000}},	//   وقی_, mgee, --, --, 
   {{0x69c85dd2,0x68e85dd3,0x08400014,0x7b080162}},	//   lgee, mwed, _گنڈُ, _ðstø, 
   {{0x68e80cfd,0x626401ec,0xe3641ea2,0x27e40112}},	//   lwed, مارق, скви, meln_, 
   {{0x69c85dd4,0x26c45dd5,0x27e4009a,0x78c4148b}},	//   ngee, mulo_, leln_, _útví, 
   {{0x26c45dd6,0x68e85dd7,0x69c85dd8,0xa6a80154}},	// [6820] lulo_, nwed, igee, _কমিয়, 
   {{0x68e80086,0x26c45dd9,0x69c80076,0xe2980166}},	//   iwed, oulo_, hgee, _йао_, 
   {{0xd00c5dda,0x68e85ddb,0x661400e4,0xdb085ddc}},	//   علم_, hwed, _koyk, cafè, 
   {{0x27e448b3,0xdee41ee3,0x63ac5ddd,0x68e85dde}},	//   heln_, _қоби, labn, kwed, 
   {{0x27e441b7,0x93380020,0x26c45ddf,0x69c80549}},	//   keln_, _አስተሳ, hulo_, dgee, 
   {{0x26c45de0,0x69c80050,0x1ea85de1,0x68e85de2}},	//   kulo_, egee, _ماري_, dwed, 
   {{0x645c02e3,0x27e45de3,0x1cb8025c,0x8fa05de4}},	//   _mkpi, deln_, _མའམ_, _хасе, 
   {{0x26c45de5,0x69c85de6,0xdb083b7b,0x68e80af9}},	//   dulo_, ggee, nafé, fwed, 
   {{0x68e85de7,0x1d2421b5,0x27e403fa,0x63ac0c6a}},	//   gwed, _умам, feln_, kabn, 
   {{0x27e45de8,0x26c45de9,0x645c01f2,0x63ac06fd}},	//   geln_, fulo_, _nkpi, jabn, 
   {{0x81044721,0xe3200156,0x63ac5dea,0x7c28127b}},	//   रमुख_, ོགསཔ_, dabn, _ildr, 
   {{0x68e808e7,0x69c85deb,0xfaf80171,0x667000f2}},	//   bwed, cgee, _dzīt_, وگير, 
   {{0x27e45dec,0xd7f85ded,0x39400a40,0x81c002f5}},	//   beln_, _буй_, _äis_, ূজা_, 
   {{0x26c45dee,0x43945def,0x63ac0198,0x228c02fb}},	//   bulo_, зарс, gabn, _býk_, 
   {{0x26c45df0,0x0838010f,0x9f48013a,0x7bdc0166}},	//   culo_, _געגל, _babí_, _ırul, 
   {{0x8104012c,0x5ecc00eb,0xdb0802d2,0x00000000}},	//   रमूख_, রবাই, gafé, --, 
   {{0x63ac5df1,0x764c05d9,0x645c03a0,0x9f4801e1}},	// [6830] babn, _ijay, _fkpi, _dabí_, 
   {{0x63ac058a,0x9f4801e1,0x73380d1d,0x00000000}},	//   cabn, _tabì_, _взор_, --, 
   {{0x4f685df2,0x69c80014,0xa3d401f9,0x00000000}},	//   ушам_, ygee, सभर_, --, 
   {{0x9f48145e,0x68e800a9,0x764c0055,0x69c80009}},	//   _babâ_, ywed, _jjay, xgee, 
   {{0x26c45df3,0x8bb40220,0x067c008f,0xab60010b}},	//   zulo_, йқау_, אנאל, _ýüzd, 
   {{0x27e45df4,0x69c80014,0x26c400f1,0x0094009d}},	//   xeln_, wgee, yulo_, _хирэ, 
   {{0x69c85df5,0x09d402f5,0x764c5df6,0x27e45df7}},	//   tgee, _দোষা, _ojay, veln_, 
   {{0x7c28148b,0x68e8097d,0x26c45df8,0x63ac09a8}},	//   _eldr, twed, vulo_, zabn, 
   {{0x26c45df9,0x69c85dfa,0x27e45dfb,0x66140579}},	//   wulo_, rgee, teln_, _royk, 
   {{0x764c5dfc,0x6e2817a3,0x68e85dfd,0x63ac0218}},	//   _ajay, _hleb, rwed, xabn, 
   {{0x6e285dfe,0x68e80433,0x63ac02fb,0xba74004b}},	//   _kleb, swed, vabn, _ځانت, 
   {{0x63ac5dff,0x26c45e00,0x27e45e01,0xba7440f3}},	//   wabn, rulo_, seln_, _فانت, 
   {{0xe944598b,0x26c45e02,0x6e280502,0x63ac5e03}},	//   _برای, sulo_, _mleb, tabn, 
   {{0x26c45e04,0xaadc1bd6,0x764c5e05,0x6e285e06}},	//   pulo_, _महाक, _ejay, _lleb, 
   {{0x63ac4859,0x26c40912,0x66140221,0x221425ea}},	//   rabn, qulo_, _toyk, офар, 
   {{0x66745e07,0x6e280521,0xe1245e08,0x00000000}},	//   _بدتر, _nleb, омби, --, 
   {{0x7bdc008c,0x290c0005,0xdb0801a8,0x1fa80107}},	// [6840] _örug, nxea_, rafé, икаи_, 
   {{0x6e283351,0x645c0d04,0xefe002d3,0xe3b05e09}},	//   _aleb, _ukpi, _ናበይ_, _کرک_, 
   {{0xc0e0044e,0x6e285e0a,0x9f480241,0x00000000}},	//   _ሓዲሽ_, _bleb, _tabí_, --, 
   {{0x6e285e0b,0x682c032e,0x8d700133,0x00000000}},	//   _cleb, _húdd, ژاوا, --, 
   {{0x6e2800d2,0x200c0793,0x8d700050,0x1be85e0c}},	//   _dleb, öfis_, ٘اوا, идди_, 
   {{0x6e285e0d,0x09d400eb,0x61f400ee,0x60d40064}},	//   _eleb, _দোলা, ldyl, mtym, 
   {{0x6e285e0e,0x60d45e0f,0xcb040592,0x7bd801f5}},	//   _fleb, ltym, قيون_, rfvu, 
   {{0x61f400ee,0x6e285e10,0x39140cb6,0x0c20104e}},	//   ndyl, _gleb, змир, змән, 
   {{0x60d45e11,0x00000000,0x00000000,0x00000000}},	//   ntym, --, --, --, 
   {{0x3c4826f0,0x60d40006,0xd6ac009e,0x61f40108}},	//   _اثری_, itym, _কমবয, hdyl, 
   {{0x60d45e12,0x9b445e13,0xdce001e4,0x6e2803ac}},	//   htym, _بناو, rboĵ, _yleb, 
   {{0x46d81d8a,0x6e280166,0x60d400a2,0xddc001ef}},	//   _बहरह, _xleb, ktym, hmož, 
   {{0x61f45e14,0x05842e2d,0x938800a7,0x9f4801e1}},	//   ddyl, дурм, исва_, _labà_, 
   {{0xd6181973,0x7e60007f,0x00000000,0x00000000}},	//   اتھا_, _lkmp, --, --, 
   {{0x60d40204,0x682c032e,0x00000000,0x00000000}},	//   etym, _dúdd, --, --, 
   {{0x764c014b,0x06380451,0xb4b401b9,0x06940244}},	//   _ujay, _وسيع_, _ейиш, _بخوت_, 
   {{0x765c5e15,0x60d409a5,0xdce80118,0x691c01e4}},	// [6850] mosy, gtym, čnět, rɨeg, 
   {{0x765c0100,0x9f482db7,0xcf245e16,0x6e2801bf}},	//   losy, _babà_, يراي, _sleb, 
   {{0x6e285e17,0xd1745e18,0x161c2232,0xbd9801f2}},	//   _pleb, сыңы, _पवार_, _ịpụt, 
   {{0xfe705e19,0xda640592,0x2c68003a,0x00000000}},	//   ندن_, _سُ_, túdo_, --, 
   {{0xd9c0015b,0x6e280076,0xc5b000fe,0x00000000}},	//   ্জাম, _vleb, _কামপ, --, 
   {{0x6a640077,0x3078008f,0xab2801e0,0x99a800fe}},	//   mófi, _לאָנ, йола_, ওলোক, 
   {{0x765c5e1a,0x6a640077,0x63b8012d,0x32180210}},	//   kosy, lófi, ótni, _kosy_, 
   {{0x290c05f5,0x6e285e1b,0x321801c7,0x00000000}},	//   txea_, _uleb, _josy_, --, 
   {{0x6a6404d4,0xada401e0,0x00000000,0x00000000}},	//   nófi, _маңл, --, --, 
   {{0x32180456,0xf20c012d,0x00000000,0x00000000}},	//   _losy_, हाड़_, --, --, 
   {{0x765c5e1c,0x9f4801e1,0xe57801c6,0x00000000}},	//   fosy, _kabá_, өзо_, --, 
   {{0x765c583c,0x32180170,0x60d45e1d,0xddc00219}},	//   gosy, _nosy_, ytym, zmož, 
   {{0x80d002a6,0xa8740046,0x00000000,0x00000000}},	//   _সৈন্, _елді, --, --, 
   {{0xf4780020,0x6a645178,0x9f4801e1,0x60d400e4}},	//   _በቅርብ_, dófi, _labá_, vtym, 
   {{0x765c5e1e,0xe2985e1f,0x32185e20,0x00000000}},	//   bosy, саб_, _bosy_, --, 
   {{0x32185e21,0x67200a85,0x60d45e22,0x765c5e23}},	//   _cosy_, mylj, ttym, cosy, 
   {{0x61f40209,0x321800a2,0x9f480248,0x6024004e}},	// [6860] rdyl, _dosy_, _sabà_, пдаа, 
   {{0x60d45e24,0xfdd800ec,0x00000000,0x00000000}},	//   rtym, ڪائڻ_, --, --, 
   {{0x9f485e25,0x60d45e26,0x88c002f5,0x1418008d}},	//   _babá_, stym, ্বিক, _הויב, 
   {{0x60d40210,0x00000000,0x00000000,0x00000000}},	//   ptym, --, --, --, 
   {{0x9e642832,0x62845e27,0x1278010f,0x67200162}},	//   _ہارن, _iiko, _לאטע, hylj, 
   {{0x62845e28,0xec340330,0x67201250,0x307401a9}},	//   _hiko, وونگ, kylj, _жусс, 
   {{0x9e64129e,0x5f04010b,0xf3f00051,0x00000000}},	//   _فارن, _эзва, ội_, --, 
   {{0x62845e29,0x9f480429,0x67200432,0x00000000}},	//   _jiko, _gabá_, dylj, --, 
   {{0x62845e2a,0xd7f85e2b,0x765c0108,0x00000000}},	//   _miko, бун_, vosy, --, 
   {{0xdec82295,0x62845e2c,0x76b85e2d,0x7d000857}},	//   _አሁን_, _liko, олор_, _irms, 
   {{0x62845e2e,0xf544001f,0x765c5e2f,0x6a6401d3}},	//   _oiko, _የኦሮሚ, tosy, zófi, 
   {{0x94a83ae4,0x00000000,0x00000000,0x00000000}},	//   йтга_, --, --, --, 
   {{0x32185e30,0x765c5e31,0x682c5e32,0x73c402d9}},	//   _rosy_, rosy, _súde, мәне, 
   {{0x62845e33,0x765c5e34,0x7d00037e,0xddc0033f}},	//   _aiko, sosy, _mrms, emoż, 
   {{0x62845e35,0x32185e36,0x765c5e37,0x95c80835}},	//   _biko, _posy_, posy, _лупа_, 
   {{0x62845e38,0x3f985e39,0x7d005e3a,0xf1c85e3b}},	//   _ciko, _afru_, _orms, تورى_, 
   {{0x62845e3c,0x41540120,0xcf885e3d,0xf3f400e5}},	// [6870] _diko, евтс, مضان_, _ہتھک, 
   {{0x6284037e,0x93a400ee,0xc104009f,0xcf88014b}},	//   _eiko, _эшид, عولي, ссад_, 
   {{0x2dd45e3e,0x6a645178,0x62845e3f,0x7afc0553}},	//   джер, sófi, _fiko, _árth, 
   {{0x62840537,0x6a645178,0x9cb000d1,0x00000000}},	//   _giko, pófi, ھمىت, --, 
   {{0x7d0002b9,0xdb1800d8,0x4acc00cd,0xc0c8014b}},	//   _crms, _octó, संभव, _нуре_, 
   {{0x62840bd5,0x6f0006ed,0xdb040311,0x00000000}},	//   _ziko, _álco, ămîn, --, 
   {{0x7d000c8c,0x6e940212,0xeb980116,0x00000000}},	//   _erms, _цибу, биһ_, --, 
   {{0xad240aaf,0x62840c11,0x7d00030d,0xae0417de}},	//   _قىزى, _xiko, _frms, _تورى, 
   {{0xa6c8004b,0xbc680014,0x00000000,0x00000000}},	//   ښودل_, _کملن_, --, --, 
   {{0x63a0110c,0xada40032,0xd874009a,0x00000000}},	//   _đono, _хаҡл, وميت_, --, 
   {{0xb8d41b90,0x00000000,0x00000000,0x00000000}},	//   _छौ_, --, --, --, 
   {{0x1b140d42,0x7d0003ac,0x00000000,0x00000000}},	//   _থেকে_, _yrms, --, --, 
   {{0x67205e40,0x00000000,0x00000000,0x00000000}},	//   sylj, --, --, --, 
   {{0xe7280262,0x67205e41,0x00000000,0x00000000}},	//   _молд_, pylj, --, --, 
   {{0x232806ed,0xd4644cf6,0x54645e42,0xd874007b}},	//   цови_, фире_, фарм_, _تموت_, 
   {{0x91e000f0,0x00000000,0x00000000,0x00000000}},	//   косе, --, --, --, 
   {{0x62845e43,0xdb0803b2,0x55b8011a,0x64d001f9}},	// [6880] _viko, vafí, _ומפו, _तमिळ, 
   {{0x62840526,0x2bc808e6,0x4fe401af,0x00000000}},	//   _wiko, _रागा, ммун_, --, 
   {{0x62845e44,0x644c02c4,0xfe78010b,0x9ee8007b}},	//   _tiko, mnbi, зүв_, تفال_, 
   {{0x629c0280,0x7afc5e45,0xdb181497,0x3ce404cc}},	//   _itpo, _árti, _octò, _ppmv_, 
   {{0xdb085e46,0x7874004e,0x1fb40b3e,0x644c5e47}},	//   rafí, làve, _освр, onbi, 
   {{0xdb0809ff,0xfe7003e6,0xed3401c0,0x7e8c010e}},	//   safí, _ڵگا_, ээхэ, _aşpe, 
   {{0x644c5e48,0x787400db,0xe81009bb,0x6f1800f3}},	//   inbi, nàve, ़ाना_, _ецтс_, 
   {{0x7d00020b,0x26c40010,0x644c002f,0x00000000}},	//   _trms, drlo_, hnbi, --, 
   {{0x26c45e49,0x8d601f00,0x81e0015b,0xd7c401f4}},	//   erlo_, _авте, _দফা_, мёно, 
   {{0x629c1326,0xdc280345,0x00000000,0x00000000}},	//   _otpo, _بسره_, --, --, 
   {{0xdb185e4a,0x7874004e,0xcb3c0092,0x00000000}},	//   _ectò, jàve, _ፐርሶኔ, --, 
   {{0x644c5e4b,0xd90c3faa,0x78740137,0xdb080109}},	//   enbi, _نیب_, dàve, mafà, 
   {{0x26c45e4c,0x6b80052f,0x63bc004e,0x2bf003d4}},	//   arlo_, _иҫәб, _bdpn, চাৰে_, 
   {{0x7d0402f6,0x69d401ed,0x97c4036b,0x644c00b5}},	//   äisy, őzet, _آتشم, gnbi, 
   {{0xdb080109,0x787400cf,0x4394567d,0x99c000fe}},	//   nafà, gàve, тасс, ্জীক, 
   {{0x644c5e4d,0x200801f5,0x682c0332,0x00000000}},	//   anbi, _anbi_, _iúda, --, 
   {{0x682c00c6,0xdb080109,0x93a4004e,0x644c00e5}},	// [6890] _húda, hafà, _ошнд, óniá, 
   {{0xa3d45345,0x787400db,0xe8100034,0xc0d002d3}},	//   _हाय_, bàve, ़ाया_, ብረላ_, 
   {{0xfd1053f3,0xcf5c4be7,0xc214013f,0x7874004e}},	//   یجه_, _ሆስፒታ, mmɔn_, càve, 
   {{0x60c01ebd,0x682c0077,0xb42401d3,0x5e6400d1}},	//   šoma, _múda, _آٹھو, ىنلە, 
   {{0xeb984b7d,0x66d40139,0x00000000,0x00000000}},	//   пил_, _kükç, --, --, 
   {{0xeb985e4e,0xdb080109,0x63bc022e,0x8004004e}},	//   чик_, fafà, _xdpn, _ичсе, 
   {{0x682c01e7,0x00000000,0x00000000,0x00000000}},	//   _núda, --, --, --, 
   {{0x973c044e,0xc0d002d3,0x19e80327,0x00000000}},	//   _ኣሕዋት, ብረሉ_, _རྒྱབ, --, 
   {{0x393401c6,0xa90800f1,0x00000000,0x00000000}},	//   вээс, سيدل_, --, --, 
   {{0x2cac0472,0x682c5e4f,0xe7380063,0x26c4002e}},	//   _iwed_, _búda, зео_, trlo_, 
   {{0x2cac0165,0x7874004e,0xe9d00451,0x644c0208}},	//   _hwed_, xàve, _مٺا_, vnbi, 
   {{0xa93421fa,0x6e38008e,0x6934119e,0x00000000}},	//   _пееш, _çabı, _пнеу, --, 
   {{0xdb0401f4,0x00000000,0x00000000,0x00000000}},	//   ämöl, --, --, --, 
   {{0x644c5e50,0x78744b84,0x26c40427,0xa878010f}},	//   unbi, tàve, prlo_, _צאַר, 
   {{0x2cac0399,0xe72801c0,0x2d8c0009,0xdebc001f}},	//   _lwed_, _хойд_, _ogee_, ቶቹን_, 
   {{0x9f480004,0x25a40209,0x2d8c0472,0x629c0393}},	//   _jabå_, _ýol_, _ngee_, _vtpo, 
   {{0x7874004e,0x00000000,0x00000000,0x00000000}},	// [68a0] sàve, --, --, --, 
   {{0x629c04fb,0x2d8c5e51,0x25b05e52,0x7874004e}},	//   _ttpo, _agee_, _heyl_, pàve, 
   {{0x2bc80846,0x2cac0204,0x629c5e53,0x25b00363}},	//   _राजा, _awed_, _utpo, _keyl_, 
   {{0x2cac0369,0x1b480116,0xa3d42052,0x00000000}},	//   _bwed_, үзди_, _हाड_, --, 
   {{0xddc0002e,0x25b05e54,0x15c400d1,0xf1d401af}},	//   lioŋ, _meyl_, ﯨﺪﯨﻐ, _шөрө, 
   {{0x2cac0042,0x3e5800d0,0x25b05e55,0x2d8c5e56}},	//   _dwed_, dčte_, _leyl_, _egee_, 
   {{0xdf140022,0x7ae40356,0x00000000,0x00000000}},	//   _џьгь, ăito, --, --, 
   {{0x682c0332,0xdcb0215c,0x6a64032e,0x00000000}},	//   _rúda, _مىر_, dófs, --, 
   {{0xd7f85e57,0x2cac0007,0x3c8400c7,0x779403e6}},	//   пун_, _gwed_, _акаҳ, نیشا, 
   {{0xdb0400a8,0x497002dd,0x682c00ae,0x00000000}},	//   ămân, ылыс, _púda, --, 
   {{0x25b04831,0x69dc0115,0x00000000,0x00000000}},	//   _beyl_, ĵser, --, --, 
   {{0x2ac004a9,0x3e58033b,0x6d5001a6,0x00000000}},	//   _тәшв, bčte_, škaš, --, 
   {{0x64580232,0x00000000,0x00000000,0x00000000}},	//   čtin, --, --, --, 
   {{0x682c007b,0xd8840451,0x6458007f,0x00000000}},	//   _túda, _ڪپڙن_, ōtin, --, 
   {{0x335400f7,0xa854151e,0x62980115,0x00000000}},	//   түнө_, _шешә, ŭton, --, 
   {{0xa3d409fd,0xd24401c6,0x00000000,0x00000000}},	//   _हाथ_, хэги, --, --, 
   {{0x865c0302,0x85041411,0x461401d9,0x2c680419}},	// [68b0] _מדהי, _موين, _صوٝر, súdi_, 
   {{0x2cac0007,0xc0581ed2,0x15b01411,0x741402f2}},	//   _rwed_, ніх_, _جەڭس, _شوجا, 
   {{0xa3d45e58,0x2cac0175,0xe810012d,0x63a00139}},	//   _हात_, _swed_, ़ाता_, _şong, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8ce01e87,0x0638010f,0x51080354,0x00000000}},	//   اقتۇ, ענדט_, _хĕлĕ, --, 
   {{0xd1b80075,0x62880798,0x4fc4010b,0x1d040137}},	//   _باھا_, _éfor, _ясма, теши_, 
   {{0x5fa004a9,0x9b3c00b8,0x6f640066,0x00000000}},	//   _ئەمم, _kāṇā, _شهرم, --, 
   {{0xad400137,0x00000000,0x00000000,0x00000000}},	//   _پۉتۉ, --, --, --, 
   {{0xac940801,0xc5b00154,0x9b3c00b8,0xdb085e59}},	//   _разш, _কালপ, _māṇā, rafá, 
   {{0xbff801f2,0xe72801c0,0x00000000,0x00000000}},	//   _ịṅụ_, доод_, --, --, 
   {{0xe5a45e5a,0xe7385e5b,0xd1c4001f,0xd75400e5}},	//   кини, фен_, ችሉት_, ہلیت_, 
   {{0xddc005a1,0x78640220,0xe6441c35,0x00000000}},	//   ološ, ккөз, темп, --, 
   {{0x25b0062c,0x2a6c002e,0x00000000,0x00000000}},	//   _veyl_, mleb_, --, --, 
   {{0x2a6c0429,0x25b0009f,0xfd500124,0xa5a029d9}},	//   lleb_, _weyl_, _pehẽ, _क्रौ, 
   {{0x9b3c00cd,0x93400022,0xe36400f0,0x82840818}},	//   _bāṇā, анре, ткви, лқод, 
   {{0x63a00209,0xddc05e5c,0x21dc0150,0x00000000}},	//   _şond, kloš, _ﺇﻤﺒﺭ, --, 
   {{0xddc00552,0x2168013e,0xe57801b9,0x649801a9}},	// [68c0] jloš, фиаи_, _юзи_, _ўтир_, 
   {{0xddc039ae,0x7e8c03b9,0x2a6c0332,0xd24c0014}},	//   dloš, _aşpa, hleb_, ٕنہ_, 
   {{0x44445e5d,0x6aa001af,0x2a6c000d,0x00000000}},	//   _im_, _ntlf, kleb_, --, 
   {{0x44445e5e,0xdca45e5f,0xc5b00154,0x00000000}},	//   _hm_, вади, _কাঁপ, --, 
   {{0x44445e60,0x9984110c,0x50940124,0x8d602ff5}},	//   _km_, _ološ_, _аусӡ, авце, 
   {{0x44445e61,0x682c01f1,0x78a40790,0xad641c43}},	//   _jm_, _súdn, _çivi, دامه, 
   {{0x50404ec9,0x44445e62,0x9f4801e1,0x99d403af}},	//   _терб, _mm_, _labú_, نتظا, 
   {{0x9f640309,0x2250005a,0xddc00024,0x2a6c5e63}},	//   _ñuñu_, nnyk_, bloš, gleb_, 
   {{0x310400dc,0x00000000,0x00000000,0x00000000}},	//   रियः_, --, --, --, 
   {{0x4444011a,0xecb001af,0x00000000,0x00000000}},	//   _nm_, _уҡшы, --, --, 
   {{0x61e45e64,0x2a6c030d,0xa3d4007d,0xd59800b5}},	//   _obkl, bleb_, हलन_, niで_, 
   {{0x44445e65,0x29100597,0x682c03b2,0x00000000}},	//   _am_, ónaí_, _húdl, --, 
   {{0x682c00d2,0x62980115,0x65740210,0x00000000}},	//   _kúdl, ŭtol, _czyh, --, 
   {{0x44445e66,0x61e40e78,0x672c0309,0xc8400354}},	//   _cm_, _abkl, ñojñ, _кечй, 
   {{0x44445e67,0xc34800a7,0x9b3c002b,0xb594030d}},	//   _dm_, вяте_, _pāṇā, _йийш, 
   {{0x44445e68,0x682c00d2,0x86480124,0xf77000ec}},	//   _em_, _lúdl, _аџьа_, _پاڙ_, 
   {{0x44445e69,0xd0840108,0x00000000,0x00000000}},	// [68d0] _fm_, выжи, --, --, 
   {{0x6288011c,0x44445d89,0x4ea43532,0x544000d1}},	//   _èfon, _gm_, врда, _ئۆسك, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xddc000d7,0x1ee81291,0x00000000,0x00000000}},	//   tloš, عونی_, --, --, 
   {{0x44445e6a,0x51841677,0x2a6c0254,0x00000000}},	//   _ym_, _јуна, vleb_, --, 
   {{0xbc6402d5,0x682c02d2,0xa3d40b4c,0x00000000}},	//   авік, _rúdo, हलय_, --, 
   {{0xaa445e6b,0x682c5e6c,0x2a6c00af,0xdb080793}},	//   лекл, _dúdl, tleb_, jafä, 
   {{0xe8f84428,0xddc002fb,0x66e40fc0,0xfb2400d1}},	//   ели_, ploš, қома, شرىپ, 
   {{0x682c00d2,0x2a6c0406,0x00000000,0x00000000}},	//   _fúdl, rleb_, --, --, 
   {{0x3c3000e4,0xddc001ef,0xdd14013d,0x00000000}},	//   _tàva_, dnoř, läşe, --, 
   {{0x44445e6d,0xa68401a9,0xe72828f3,0x2a6c000d}},	//   _rm_, ллод, хонд_, pleb_, 
   {{0x62980232,0x7ce0063f,0x2d9c0117,0x7874026c}},	//   ítom, _ịrig, ncwe_, ràva, 
   {{0x44445e6e,0x69d85e6f,0xc9845e70,0x22505e71}},	//   _pm_, _icwe, _ружи, vnyk_, 
   {{0x44445e72,0xb74400dd,0x62980115,0x00000000}},	//   _qm_, ائیو, ŭtom, --, 
   {{0xd598037e,0x998401e0,0xe2780395,0xdd140139}},	//   xiで_, _итәһ, ещаш_, käşe, 
   {{0xe8101533,0x44445e73,0x9f48215a,0x00000000}},	//   ़ावा_, _wm_, _tabú_, --, 
   {{0x10a00e46,0x44445e74,0x5f445e75,0x60085e76}},	// [68e0] йитн, _tm_, گنال, ннам_, 
   {{0x44445e77,0x2cbc0369,0x69d80e14,0xe2845e78}},	//   _um_, dswd_, _lcwe, _әлми, 
   {{0x69d80117,0x344400d1,0x53980a7c,0x443801ab}},	//   _ocwe, _түри_, _ריטו, mhr_, 
   {{0xe1f05e79,0x2d9c00d2,0x682c0b21,0x6e640212}},	//   _اسد_, gcwe_, _súdl, атіж, 
   {{0x310400cd,0xe12401a9,0x00000000,0x00000000}},	//   रिणः_, _ёмги, --, --, 
   {{0x69d80117,0xa0680209,0x92e403d4,0x00000000}},	//   _acwe, _чага_, পিৰ_, --, 
   {{0x05d40574,0x00000000,0x00000000,0x00000000}},	//   _थांब, --, --, --, 
   {{0x1ae40183,0x44380036,0x7e8c0205,0x00000000}},	//   কিলে_, hhr_, _işpo, --, 
   {{0x38345e7a,0x0b4004b4,0x9848011c,0x00000000}},	//   инир, инән, еяна_, --, 
   {{0x69d80117,0x4d44084c,0x4c800e92,0x310400dc}},	//   _ecwe, _спун_, _глув, रितः_, 
   {{0x38c828c4,0x5ee00011,0x629801e4,0x00000000}},	//   راکی_, ফিকে, ŭtoj, --, 
   {{0x69d80117,0x44380112,0x00000000,0x00000000}},	//   _gcwe, ehr_, --, --, 
   {{0x34945e7b,0x7c380037,0x00000000,0x00000000}},	//   рагр, ohvr, --, --, 
   {{0xb4e4006d,0x57a407d6,0xe8ec05d9,0x44385e7c}},	//   _नही_, _ёшла, _آڻي_, ghr_, 
   {{0x9f480395,0xa3d40c70,0x36d405f5,0x46a000d8}},	//   _tabù_, _हार_, _тойр, _лајв, 
   {{0x34945e7d,0x5184016c,0x926400f2,0x00000000}},	//   _каир, гуза, ادآم, --, 
   {{0x44385e7e,0xb1145e7f,0x00000000,0x00000000}},	// [68f0] bhr_, шмаш, --, --, 
   {{0x44385e80,0x00000000,0x00000000,0x00000000}},	//   chr_, --, --, --, 
   {{0x9e9457b5,0xd1740220,0x4ea45e81,0xc0585e82}},	//   لانچ, тыңы, урза, уіт_, 
   {{0xddc00034,0x2cbc00b5,0xd1640395,0x00000000}},	//   mnoś, tswd_, _бъги, --, 
   {{0xddc0006d,0xdd140724,0x913000c7,0x682c5e83}},	//   lnoś, räşe, _уҭах, _súdm, 
   {{0x7f94009d,0x00000000,0x00000000,0x00000000}},	//   _гарх, --, --, --, 
   {{0x2cbc5e84,0x499003e6,0xff040801,0xddc0033f}},	//   sswd_, میار, _лятн, nnoś, 
   {{0x6fac0154,0x691c01e4,0x8bc40139,0x0e4400c0}},	//   _চায়ে, sɨem, _әсад, _сэгм, 
   {{0xa3d435e8,0xc91000fe,0xe810000d,0x00000000}},	//   _हाल_, িন্ত_, ़ाला_, --, 
   {{0x684400f3,0x62980306,0x44380200,0x00000000}},	//   рноа, ítok, xhr_, --, 
   {{0xddc00034,0x66e45e85,0x8b645085,0x64580374}},	//   jnoś, шона, _صائم, ōtik, 
   {{0xddc0068f,0x69d85e86,0xc5f801b9,0x00000000}},	//   dnoś, _ucwe, уғи_, --, 
   {{0x443803cb,0x4ab00166,0x95200014,0xc92000cc}},	//   thr_, _төһр, ۅکیم, _বেৰত_, 
   {{0xe79404d3,0xddc00034,0xa6941677,0x3e7c022a}},	//   _ئاشک, fnoś, _криј, míte_, 
   {{0xe5a45e87,0xe2985e88,0x2a7c0211,0xe7385e89}},	//   _кийи, таб_, _khwb_, _шек_, 
   {{0x98a002d5,0x44385e8a,0xbb44001f,0xc5b0009e}},	//   šką_, shr_, _እንቅፋ, _কাকপ, 
   {{0x3e7c0122,0xe0445e8b,0x910039c6,0x10a00276}},	// [6900] níte_, анаи, опте, жиун, 
   {{0xddc0012d,0x00000000,0x00000000,0x00000000}},	//   bnoś, --, --, --, 
   {{0x30741301,0xddc0033f,0xdc2803e6,0xe7dc070f}},	//   сутс, cnoś, ێسته_, _मानप, 
   {{0xa3d41533,0x270400da,0x5de45e8c,0xade400d3}},	//   _हाँ_, _mēn_, ржда, йцік, 
   {{0x3e7c02fb,0x3178002f,0x3f9c05c7,0x00000000}},	//   jíte_, _gzsz_, ñvus_, --, 
   {{0x3e7c0232,0xdb1801d3,0x8c400114,0x5da80150}},	//   díte_, _adtá, жеље, _ﺷﯩﻨﻴ, 
   {{0x3ae80214,0x00000000,0x00000000,0x00000000}},	//   ابتی_, --, --, --, 
   {{0x5ca40276,0x3e7c02f0,0x753c0210,0xde34009d}},	//   _виаб, fíte_, yzsz, _тэгь, 
   {{0xa3d45e8d,0xb4d40034,0xddc0033f,0xd83803f5}},	//   हला_, _हमे_, znoś, вэн_, 
   {{0x195402dd,0x36d4004e,0x00000000,0x00000000}},	//   лақы_, боор, --, --, 
   {{0xddc00210,0x00000000,0x00000000,0x00000000}},	//   mioł, --, --, --, 
   {{0x3e7c02fb,0xa3d400c5,0x63a00166,0x00000000}},	//   bíte_, हलऽ_, _ğona, --, 
   {{0x7af8074d,0xddc0068f,0x63a0010e,0xb7e800fe}},	//   lwvt, wnoś, _şona, _কোণত_, 
   {{0x7bd80399,0xddc0033f,0x13a415b4,0x00000000}},	//   ngvu, tnoś, شنری_, --, 
   {{0x753c00e5,0x00000000,0x00000000,0x00000000}},	//   szsz, --, --, --, 
   {{0x35b45e8e,0xddc00034,0x6e380175,0xd498022e}},	//   _убир, rnoś, xhwb, _иро_, 
   {{0x7058152d,0x51845e8f,0xddc00034,0x5064010b}},	// [6910] гаар_, рува, snoś, атжа, 
   {{0xddc0012d,0x00000000,0x00000000,0x00000000}},	//   pnoś, --, --, --, 
   {{0xb8d8025c,0x682c5e90,0x3e7c02fb,0xdb0801d3}},	//   _མཆ_, _súdk, zíte_, bbfé, 
   {{0x7a3c00dd,0x850407d6,0x00000000,0x00000000}},	//   _hétf, _اوین, --, --, 
   {{0xdb08006a,0xace82c31,0x7a3c01d3,0xd0840108}},	//   pafû, умла_, _kétf, _выви, 
   {{0x59240156,0x3e7c031d,0x8c640f5c,0xd6c4129d}},	//   ལགནས_, víte_, штед, _ىق_, 
   {{0xad9c068f,0xeb0800cf,0x00000000,0x00000000}},	//   _paźd, اقبى_, --, --, 
   {{0x3e7c0122,0x2e881719,0x6fdc01f9,0x00000000}},	//   títe_, _сөзи_, _पाडू, --, 
   {{0xbb3808b0,0x682c03b2,0x3978005b,0x00000000}},	//   ﺗﺎﻕ_, _húdi, исью_, --, 
   {{0x68445e91,0x3e7c5e92,0x8ae40212,0xa3d412eb}},	//   ённа, ríte_, _відл, _हाइ_, 
   {{0x3e7c03c6,0x682c0998,0xa3d4007d,0x3ad400cf}},	//   síte_, _júdi, हलस_, _ۇيەز, 
   {{0x60c05e93,0xdb2404fb,0x3e7c0308,0x00000000}},	//   šomi, _دومی, píte_, --, 
   {{0x682c5e94,0xdd140166,0x00000000,0x00000000}},	//   _lúdi, _mäşa, --, --, 
   {{0x21685e95,0x53a05e96,0xb86448c1,0x5d780a7c}},	//   ҳиби_, зарб, _واوو, טארק, 
   {{0x9f4800d7,0x987800df,0xe2980798,0x00000000}},	//   _babý_, _גאסט, ѓаа_, --, 
   {{0x682c000f,0x614402dd,0xddc00210,0x00000000}},	//   _súdh, беба, zioł, --, 
   {{0x682c00d8,0xddc001e4,0x9f800092,0x00000000}},	// [6920] _aúdi, gnoŝ, _ይታያሉ_, --, 
   {{0xdee00150,0x00000000,0x00000000,0x00000000}},	//   зудi_, --, --, --, 
   {{0x2328006c,0x644c5e97,0x93f804ac,0x0d2000f7}},	//   _сони_, mibi, _גליי, үүсү, 
   {{0x7bd80207,0x023401ed,0xe3b04cec,0xddc0012d}},	//   wgvu, _بہرح, _برک_, wioł, 
   {{0x61f45e98,0x00000000,0x00000000,0x00000000}},	//   meyl, --, --, --, 
   {{0x6fd410f5,0x10a0009d,0x00000000,0x00000000}},	//   _місц, _хирн, --, --, 
   {{0x7bd80af4,0xa3d41dd1,0x539805d0,0xdb080feb}},	//   rgvu, _हाई_, ניקו, nafø, 
   {{0x61f45e99,0xddc00210,0x6d4800cd,0x00000000}},	//   neyl, sioł, _śmaś, --, 
   {{0x644c5e9a,0x9f4829ef,0x9f340046,0x60d40113}},	//   kibi, _labü_, _теңі, nuym, 
   {{0x644c5e9b,0x61f45e9c,0xdb0803b2,0x00000000}},	//   jibi, heyl, kafø, --, 
   {{0x7bc85e9d,0x8c1401d5,0x61f42f88,0xfa1801e2}},	//   _iddu, _ديلر_, keyl, _پراګ_, 
   {{0x60d40986,0x61f4047e,0x89d401f7,0xa854004e}},	//   kuym, jeyl, _هومر_, йкөч, 
   {{0x61f403e0,0x3804014b,0x00000000,0x00000000}},	//   deyl, _модҳ, --, --, 
   {{0xc8c40101,0x00000000,0x00000000,0x00000000}},	//   _اوون_, --, --, --, 
   {{0x3258001f,0xdb080162,0x61f425a8,0x6f800150}},	//   _የሥልጣ, gafø, feyl, _ﺩﺍﻫﺎ_, 
   {{0x92685e9e,0x644c009f,0x61f4022e,0xd5b800f3}},	//   урга_, aibi, geyl, _сск_, 
   {{0x644c5e9f,0xfbc8185d,0xf484004b,0x6fb85ea0}},	// [6930] bibi, रणाम, _واخی, игар_, 
   {{0x644c5ea1,0x0574088c,0x682c004e,0x00000000}},	//   cibi, _عايد, _púdi, --, 
   {{0xf1945ea2,0x8f0801c0,0x741408dc,0x61f45ea3}},	//   _минь, ыхаа_, _هوکا, beyl, 
   {{0x7bc85ea4,0x61f401d9,0xd2f401d3,0x00000000}},	//   _addu, ceyl, _پکڑا_, --, 
   {{0x6fb4007b,0x629802f0,0x00000000,0x00000000}},	//   _ومحا, ítov, --, --, 
   {{0xab2800f3,0x7c9400f2,0xef64009d,0xabd400db}},	//   иола_, سشها, _дэбү, ززتت, 
   {{0x682c0af2,0x00000000,0x00000000,0x00000000}},	//   _kúdv, --, --, --, 
   {{0xed140f31,0x7bc80a49,0xe8c801a9,0x00000000}},	//   _وہاں_, _eddu, агил_, --, 
   {{0xf8a81547,0xad400372,0x644c5ea5,0xde440244}},	//   یدیه_, _تۉشۉ, yibi, _بینو_, 
   {{0x3e7c00c7,0x00000000,0x00000000,0x00000000}},	//   míta_, --, --, --, 
   {{0x644c5ea6,0x3e7c0022,0xe61800d8,0x61f40bbc}},	//   vibi, líta_, адн_, yeyl, 
   {{0x644c5ea7,0xa5085ea8,0x60d40784,0x293400c0}},	//   wibi, аема_, yuym, _мэлё, 
   {{0x9f48026c,0xfbe0047f,0x7a3c04cc,0x644c5ea9}},	//   _ebbè_, _नामम, _sétg, tibi, 
   {{0x7ec001e1,0x61b017c6,0x61f40009,0xf4cc313e}},	//   _jápá, जर्ष, weyl, _ﺑﻪﺷﻜ, 
   {{0x682c0b21,0x48f0012c,0x61f40790,0x26c001e1}},	//   _súdw, ्टको_, teyl, _ìho_, 
   {{0x7b28013f,0xbb34001f,0xe81032ed,0x60d40309}},	//   nɛua, _ጠይቀዋ, ़ाका_, tuym, 
   {{0x644c5eaa,0x61f405d1,0x60245eab,0x75e4007b}},	// [6940] pibi, reyl, одаа, _رأيك, 
   {{0xdb1800d8,0x60d40113,0x644c5eac,0x61f45ead}},	//   _detê, ruym, qibi, seyl, 
   {{0x44e45eae,0x7a3c01ed,0x661403b2,0x60d40784}},	//   lö_, _héte, _knyk, suym, 
   {{0x9f485eaf,0x60d40309,0xf1e010eb,0x7a3c01d3}},	//   _babò_, puym, _फायन, _kéte, 
   {{0xdfd40220,0x23840014,0x60d40309,0x1ea82764}},	//   _қоңы, _دٔگِ, quym, _چاري_, 
   {{0x1ea8082e,0x06ac2baf,0x9f485eb0,0x7a3c5eb1}},	//   _ناري_, _কিনি, _dabò_, _méte, 
   {{0x3f98071b,0x7a3c00dd,0x66145eb2,0x8d54013d}},	//   _igru_, _léte, _onyk, йшәт_, 
   {{0x1cb85eb3,0x3e7c00d2,0x44e402f6,0x98c403f5}},	//   _نائب_, bíta_, kö_, осол, 
   {{0x645c02d1,0x9f48067c,0x58845eb4,0xb7e800cc}},	//   _ojpi, _tabó_, жына, _কোষত_, 
   {{0xdb18069c,0x9f485eb5,0x66143c8f,0x7bc8102c}},	//   _jetë, _abbé_, _anyk, _uddu, 
   {{0x9078159d,0x6fdc0574,0xdb180023,0xe0e4015b}},	//   שטיי, _पासू, _metë, নিয়ন, 
   {{0xdb18044e,0x645c0113,0x7a3c5eb6,0xdecc001f}},	//   _letë, _ajpi, _béte, _ጥገና_, 
   {{0x7a3c45a7,0xd90c2a60,0x5fb80316,0x7c285eb7}},	//   _céte, _شید_, इराल, _kodr, 
   {{0x7a3c0231,0x3f98020c,0xdb180023,0x00000000}},	//   _déte, _ngru_, _netë, --, 
   {{0x43945eb8,0x7c285eb9,0x95c85eba,0x661402d2}},	//   дарс, _modr, _купа_, _fnyk, 
   {{0x6fdc0574,0x7c285ebb,0x3f980171,0xd24401c6}},	//   _पाहू, _lodr, _agru_, цэги, 
   {{0x764c5ebc,0xcf98026a,0x73d818d9,0x7c2802d0}},	// [6950] _imay, аје_, _лдпр_, _oodr, 
   {{0x7c285ebd,0x38a00013,0x3e7c00d0,0x00000000}},	//   _nodr, _mòr_, víta_, --, 
   {{0x629800dd,0x764c022e,0x9f48007f,0x3eb8015d}},	//   ítot, _kmay, _sabò_, _cwrt_, 
   {{0x7c2801ab,0x7d0002d0,0x0dc85ebe,0xb2640014}},	//   _aodr, _bsms, ружи_, _ژُھى, 
   {{0x7ec05ebf,0x764c5ec0,0x7c285ec1,0x43d45ec2}},	//   _pápá, _mmay, _bodr, _عزیز, 
   {{0x764c07d6,0x7c285ec3,0xdb180036,0x6ab40120}},	//   _lmay, _codr, _getë, псих, 
   {{0x764c5ec4,0x7f585ec5,0x7c285ec6,0xdb180100}},	//   _omay, _дарс_, _dodr, _jetè, 
   {{0x764c4aed,0x38a00561,0xdb185ec7,0x8d84013e}},	//   _nmay, _bòr_, _metè, _дузд, 
   {{0x7c285ec8,0x38a0180f,0xed580114,0x7d240166}},	//   _fodr, _còr_, _beže_, _оффе, 
   {{0x764c5ec9,0x6e285eca,0x7c9407d6,0x7a3c5ecb}},	//   _amay, _hoeb, _قشلا, _réte, 
   {{0x6e28105c,0xed5800fb,0x00000000,0x00000000}},	//   _koeb, _тоҡ_, --, --, 
   {{0x7c280cf9,0x7a3c01ed,0xba740228,0x38a003cd}},	//   _zodr, _péte, _قانت, _fòr_, 
   {{0x6e283f17,0xa9785378,0x39000022,0x7c280166}},	//   _moeb, _уйду_, _аҟыб, _yodr, 
   {{0x764c00aa,0x44e45ecc,0xdb18033b,0x7a3c01ed}},	//   _emay, rö_, _betè, _véte, 
   {{0x44e45ecd,0xd9e00c2e,0xa6c8088c,0x2bec00cd}},	//   sö_, क्कत_, _اوبل_, च्यं_, 
   {{0x6e281246,0xdb1802bd,0x7a3c01ed,0x26c40158}},	//   _noeb, _detè, _téte, mslo_, 
   {{0x9fc8152d,0xdb185ece,0x26c40010,0x00000000}},	// [6960] йгаа_, _petë, lslo_, --, 
   {{0xa3d41715,0xdb1802d3,0x26c401c8,0x78740561}},	//   _हाट_, _qetë, oslo_, tàvi, 
   {{0x7c285ecf,0xdb185ed0,0x764c5ed1,0x2a6c005c}},	//   _rodr, _vetë, _ymay, koeb_, 
   {{0x7c285ed2,0x629c2819,0x6e28007f,0x63bc06ea}},	//   _sodr, _iupo, _coeb, _hepn, 
   {{0x629c5ed3,0xdb185ed4,0x6e280b4f,0x10a000a7}},	//   _hupo, _ieté, _doeb, _пиян, 
   {{0xdb185ed5,0x26c402d5,0x63bc02d3,0x65740175}},	//   _heté, kslo_, _jepn, _myyh, 
   {{0x629c4892,0xdb1800f2,0xed585ed6,0x38a00ba1}},	//   _jupo, _keté, _reže_, _sòr_, 
   {{0x629c5ed7,0xdb1806af,0x63bc5ed8,0x38a000a3}},	//   _mupo, _jeté, _lepn, _pòr_, 
   {{0x629c5ed9,0x7c280286,0x764c01b9,0x3e7c0022}},	//   _lupo, _todr, _rmay, líto_, 
   {{0x24e004c5,0x26c400fe,0x6e2801e4,0x629c5eda}},	//   যবাহ, fslo_, _zoeb, _oupo, 
   {{0x629c4892,0xed585edb,0x75d45edc,0xe7dc5edd}},	//   _nupo, _veže_, ويدا, _मारप, 
   {{0x0f540302,0xfbb40154,0x00000000,0x00000000}},	//   ליים_, _ঘাটত, --, --, 
   {{0x629c5ede,0x63bc014f,0xdb18020c,0x1868146a}},	//   _aupo, _bepn, _setè, _лади_, 
   {{0x629c04ba,0xdb185edf,0x63bc0205,0x3e7c00d7}},	//   _bupo, _aeté, _cepn, kíto_, 
   {{0x629c5ee0,0x63bc0098,0xdb1801d3,0x764c5ee1}},	//   _cupo, _depn, _beté, _tmay, 
   {{0x629c5ee2,0x764c5ee3,0xdb18067c,0x59080327}},	//   _dupo, _umay, _vetè, _ཀློས_, 
   {{0x6e280421,0xdb185ee4,0x629c5ee5,0xa3d40490}},	// [6970] _roeb, _deté, _eupo, _हाच_, 
   {{0x6e285ee6,0xf4844973,0xcf98041b,0x00000000}},	//   _soeb, _تابی, сја_, --, 
   {{0x02a45ee7,0xdb1800e4,0x765c0142,0x629800df}},	//   _прям, _uetè, onsy, ŭtor, 
   {{0xdb185ee8,0x765c2e49,0xfe705ee9,0x00000000}},	//   _geté, nnsy, هدن_, --, 
   {{0x682c0030,0xddc000bc,0x63bc014f,0x3e7c00bc}},	//   _múdr, nioř, _yepn, mítl_, 
   {{0x32080c8c,0x765c002f,0xad9c012d,0xb54c0116}},	//   lday_, hnsy, _gaźn, ﻟﻼﻫﯘ_, 
   {{0x6e285eea,0x32085ad6,0xdb180022,0xdb0803b2}},	//   _toeb, oday_, _yeté, dafó, 
   {{0x32085eeb,0xe9d81cc9,0x26c40427,0xf1dc0118}},	//   nday_, цки_, vslo_, यलिन, 
   {{0x47e41b4b,0xe7d40212,0x32085eec,0x00000000}},	//   _འཁྱམ, міню, iday_, --, 
   {{0x3e580100,0x765c01f4,0xd5d80118,0xdb081d1d}},	//   včti_, ensy, _भाउज, gafó, 
   {{0x32080c8c,0xfe7000dd,0x682c002d,0x2cac030a}},	//   kday_, _شدہ_, _súds, _hted_, 
   {{0xddc03831,0x26c402d5,0x63bc5eed,0x629c006f}},	//   zlož, rslo_, _sepn, _rupo, 
   {{0x32085ac3,0xdb1800c7,0x385800f2,0x853400db}},	//   dday_, _reté, _کشند_, روسچ, 
   {{0x765c5eee,0x68e85eef,0xdb185ef0,0x32085ef1}},	//   ansy, mted, _seté, eday_, 
   {{0x58f81e81,0x68e85ef2,0x7a3c00e4,0x629c022e}},	//   _དགོས_, lted, _héta, _qupo, 
   {{0x7a3c5ef3,0x32085ef4,0x68e802d0,0x00000000}},	//   _kéta, gday_, oted, --, 
   {{0x68e85ef5,0xf778038f,0x7a3c0241,0x63bc0306}},	// [6980] nted, mgħa_, _jéta, _tepn, 
   {{0x629c08f5,0x7a3c5ef6,0x32080050,0x3e7c0077}},	//   _tupo, _méta, aday_, títo_, 
   {{0x141800c8,0x629c0c67,0x68e85ef7,0xdb18552d}},	//   _וויב, _uupo, hted, _teté, 
   {{0x68e80ab7,0x32085ef8,0xddc05ef9,0x3e7c00d8}},	//   kted, cday_, slož, ríto_, 
   {{0x68e85efa,0x7a3c002e,0x58f8031c,0xa1140b24}},	//   jted, _néta, _དགེས_, _غوست, 
   {{0x2ca85efb,0xad6439b5,0x3a2400b5,0x68e8005c}},	//   íada_, رانه, wjmp_, dted, 
   {{0xddc40a70,0x628400d2,0x2cac04cc,0x60d4222c}},	//   _обви, _khko, _eted_, lrym, 
   {{0x68e81600,0x7a3c5efc,0x998402fb,0x59080327}},	//   fted, _béta, _vlož_, _ཀླུས_, 
   {{0x68e8037e,0xdb085efd,0x628400b5,0x4438009f}},	//   gted, tafó, _mhko, kkr_, 
   {{0x7a3c5efe,0x765c01f5,0x682c00d0,0xf7780003}},	//   _déta, wnsy, _súdr, egħa_, 
   {{0x32085eff,0x99840122,0x68e8127b,0x290c0607}},	//   yday_, _ulož_, ated, avea_, 
   {{0x68e85f00,0x32085f01,0x7a3c003e,0xfd700952}},	//   bted, xday_, _féta, ﺴﺘﺎﻥ_, 
   {{0x68e85f02,0x765c5f03,0xd8241621,0xdb08067c}},	//   cted, rnsy, _одди, cafò, 
   {{0x32080050,0x62845f04,0xed5801a6,0x60d400ad}},	//   wday_, _ahko, _ježa_, drym, 
   {{0x320814dc,0xed58005f,0xf5380118,0xf7780003}},	//   tday_, _meža_, šť_, bgħa_, 
   {{0x6b68006a,0x6284003a,0x60d40042,0x32080009}},	//   lêgë, _chko, frym, uday_, 
   {{0x30145f05,0x32085f06,0x60d45f07,0x629801e4}},	// [6990] ндар, rday_, grym, ŭtop, 
   {{0x32083f49,0x44385f08,0xed580427,0x00000000}},	//   sday_, ckr_, _neža_, --, 
   {{0x2cac5f09,0xb9000156,0x47c0015b,0x68e8009d}},	//   _sted_, _སའ_, _শামী, zted, 
   {{0x32080050,0x7c38017a,0x68e85f0a,0x60d45f0b}},	//   qday_, ekvr, yted, brym, 
   {{0x60d45f0c,0x4fc45f0d,0xdb08004e,0x68e800e4}},	//   crym, _осва, xafò, xted, 
   {{0x62880395,0x7a3c5f0e,0x09c40490,0x68e80030}},	//   _èfor, _réta, ळण्य, vted, 
   {{0x7f942386,0x58f8025c,0xa9a45f0f,0x0dc80798}},	//   _аарх, _དགུས_, нийд, _муаи_, 
   {{0x68e85f10,0x4990168d,0xdb0826b7,0x9f580100}},	//   tted, نیار, tafò, depè_, 
   {{0x2cac014b,0xdbd801e1,0x490000f7,0xdd100790}},	//   _uted_, _fààf, түлг, müşt, 
   {{0x68e85f11,0x7c3801f5,0x290c5f12,0x59805f13}},	//   rted, ckvr, rvea_, ылыб, 
   {{0x7a3c5f14,0xf7780135,0x290c0254,0x00000000}},	//   _wéta, tgħa_, svea_, --, 
   {{0x7a3c5f15,0x68e80c8c,0xdd1003ee,0x3e580100}},	//   _téta, pted, nüşt, pōte_, 
   {{0xb8d40eac,0xa3f4196c,0x6aa00076,0x443800b5}},	//   _জয়_, нявш, _hulf, tkr_, 
   {{0x6284067d,0x6aa05f16,0xd8d4008f,0x2328005b}},	//   _shko, _kulf, _נוצט_, поги_, 
   {{0x443800c6,0x22142902,0x6aa05f17,0x23285f18}},	//   rkr_, нфар, _julf, чови_, 
   {{0x60d45f19,0x24c80116,0x6aa00142,0x845c0092}},	//   trym, _егип_, _mulf, ተማመን_, 
   {{0xe0d85f1a,0x44380311,0xe45809a5,0xdb0802d2}},	// [69a0] ява_, pkr_, _нжи_, hafð, 
   {{0x60d45f1b,0x6aa003ac,0x9f580306,0x00000000}},	//   rrym, _oulf, lepé_, --, 
   {{0xdb1800b5,0xed580010,0x30740107,0x00000000}},	//   _udtø, _reža_, тутс, --, 
   {{0xde7434b1,0x5fe01af8,0x8eb02732,0x9ce40022}},	//   رداع, _पावल, امنش, ецкл, 
   {{0x61e40857,0x24780092,0x00000000,0x00000000}},	//   _ickl, _በሶስት_, --, --, 
   {{0xdee45f1c,0x6aa05f1d,0x00000000,0x00000000}},	//   _поги, _bulf, --, --, 
   {{0x9f580066,0xed585f1e,0x7c3801f5,0x6aa05f1f}},	//   kepé_, _veža_, rkvr, _culf, 
   {{0x20085f20,0x682c000f,0x3ae8002d,0xdd904111}},	//   _habi_, _súdp, rûp_, _موز_, 
   {{0x20085f21,0x61e40a40,0xed580f03,0x26d037b5}},	//   _kabi_, _mckl, _teža_, ázon_, 
   {{0x20085f22,0x6aa05f23,0xfce401b9,0xb8c8084d}},	//   _jabi_, _fulf, _поғо, _खं_, 
   {{0x6aa05f24,0x20080c0b,0x61e45f25,0x4730009d}},	//   _gulf, _mabi_, _ockl, гнэс, 
   {{0x20085f26,0x8b38011a,0x18a40395,0x00000000}},	//   _labi_, _מתבצ, _задм, --, 
   {{0x6aa05f27,0x2498030a,0xdb1809c2,0x09305262}},	//   _zulf, _bipm_, _metí, _مروج, 
   {{0x20082a1f,0x61e4127b,0xdb185f28,0x9f580ffb}},	//   _nabi_, _ackl, _letí, pepè_, 
   {{0xdb180124,0x85040133,0x758001e2,0xdd100205}},	//   _hetâ, نوێن, دیښم, yüşt, 
   {{0x20085f29,0xdb180f91,0x00000000,0x00000000}},	//   _aabi_, _netí, --, --, 
   {{0x9f480ffb,0xd36c0b38,0x44f401d5,0xdd100205}},	// [69b0] _abbà_, شۇڭ_, _یسیز, vüşt, 
   {{0x61e45f2a,0x20085f2b,0xf31800cf,0x349400c0}},	//   _eckl, _cabi_, _жоош_, _шапр, 
   {{0x20085f2c,0xdb1803b2,0x6e945f2d,0x5fe00f90}},	//   _dabi_, _betí, вижу, _पारल, 
   {{0x20080295,0x7ed45f2e,0x067c010f,0x00000000}},	//   _eabi_, ازلا, ִנגל, --, 
   {{0xdb180077,0xfaf8002b,0xdd1005d1,0x00000000}},	//   _detí, _apī_, rüşt, --, 
   {{0x20085f2f,0x2ef421ca,0x7a3c5f30,0x95700023}},	//   _gabi_, _изгр, _béto, _ኩናትን_, 
   {{0x7a3c0129,0x6aa02646,0xaa440209,0x00000000}},	//   _céto, _qulf, кекл, --, 
   {{0x20080c09,0x7a3c5f31,0xdb1800d8,0xae045f32}},	//   _zabi_, _déto, _betâ, _جورى, 
   {{0x20085f33,0x393401c0,0xad2400f1,0x00000000}},	//   _yabi_, гээс, _ګرځو, --, 
   {{0x20085f34,0x00000000,0x00000000,0x00000000}},	//   _xabi_, --, --, --, 
   {{0xb8c800c5,0xe6440063,0x7a3c00e5,0x00000000}},	//   _खू_, венп, _kétl, --, 
   {{0x64a45f35,0xe7dc033f,0x00000000,0x00000000}},	//   кама, _माकप, --, --, 
   {{0x1ccc003d,0xda1c0034,0x9f580214,0x1660010a}},	//   ྱེར_, भारत_, repé_, рвям, 
   {{0xa87800c8,0xdb08007c,0x00000000,0x00000000}},	//   _קאַר, bbfä, --, --, 
   {{0x7a3c002e,0xfbb402c3,0x00000000,0x00000000}},	//   _xéto, ुरतम, --, --, 
   {{0x2008357f,0xdb180124,0xc5a80451,0x00000000}},	//   _sabi_, _hetã, _ڪڏھن_, --, 
   {{0x63a00209,0xdb185f36,0x20085f37,0x60085f38}},	// [69c0] _şonu, _retí, _pabi_, мнам_, 
   {{0x1ccc0f50,0x1af8009e,0xc5a80451,0x20085f39}},	//   ྱེལ_, ্মতে_, _تڏھن_, _qabi_, 
   {{0x7a3c00e8,0x200809a8,0xdb1830d4,0xe2c8027d}},	//   _bétl, _vabi_, _petí, _توجو_, 
   {{0x20085f3a,0xdb1800d8,0x221400c7,0x61e40857}},	//   _wabi_, _letã, _рфор, _uckl, 
   {{0x20085f3b,0xdb1801d3,0x3e7c00e5,0x00000000}},	//   _tabi_, _vetí, níti_, --, 
   {{0xdb18035b,0x7a3c0129,0x00000000,0x00000000}},	//   _retâ, _péto, --, --, 
   {{0x1e945f3c,0xdcb00e56,0xdb1801ef,0x00000000}},	//   _арар, _چىر_, _tetí, --, 
   {{0xdcb000db,0x0dc40023,0x00000000,0x00000000}},	//   _نىر_, _ጽፉፍ_, --, --, 
   {{0xdca45f3d,0xdb080793,0xdb1800d8,0xc8c4143e}},	//   _рази, jafö, _betã, نوين_, 
   {{0xefd4069c,0x7a3c4ac6,0xac042e0b,0xdb085f3e}},	//   _ከቢድ_, _této, _مذمو, dafö, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf1e006bc,0xd00800bd,0xdb180588,0x772401d9}},	//   _फाइन, রায়_, _tetâ, ٖٹھٕ, 
   {{0x73c446e8,0x3e7c01d3,0x00000000,0x00000000}},	//   ләне, gíti_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x60d80a28,0x82a45f3f,0x00000000,0x00000000}},	//   _ātma, иште, --, --, 
   {{0xdb180137,0x3dc40083,0x63a00356,0x926801a9}},	//   _metà, _nemw_, _şont, фрга_, 
   {{0x1ccc08ea,0xb1143daf,0x6da41f71,0xed580427}},	// [69d0] ྱེས_, ымаш, қила, _režo_, 
   {{0xc1040597,0x7a3c00e8,0x20280023,0x53b45b14}},	//   ؤولي, _sétl, _ተማሂር, _अभिश, 
   {{0xb8e4025c,0xbdb0063f,0xed58009b,0xa3c40037}},	//   _ཏས_, _ịnọr, _pežo_, _उड़ि_, 
   {{0x26c00076,0xae1c000d,0x51840de7,0xe0b000cc}},	//   _çhoe_, फाइन_, _ауга, _চিৰন, 
   {{0x733400db,0x20240162,0x00000000,0x00000000}},	//   _شىڭا, ýpið_, --, --, 
   {{0x6f145f40,0x6b6405bc,0xdef80124,0xa3c40210}},	//   _trzc, лкла, ьыӡ_, _उड़ा_, 
   {{0xed58151c,0xdb180588,0xadbc1cd0,0xe1a8000d}},	//   _težo_, _retã, _навi, _कलमघ, 
   {{0xdb180004,0x9e9402ec,0x8cd80037,0x00000000}},	//   _setã, _ماقچ, _निपो, --, 
   {{0x3d945f41,0x8d745f42,0xf1e0012c,0x7a4801e1}},	//   _витр, _شارا, _फाईन, _sètù, 
   {{0x7b08049b,0x3e7c5f43,0x47c00154,0xfaa4035b}},	//   ästä, víti_, _শাহী, ышән, 
   {{0xe7385f44,0x16b40055,0x00000000,0x00000000}},	//   хен_, _įųãü, --, --, 
   {{0x244406af,0xdb0801e3,0x00000000,0x00000000}},	//   _môme_, tafö, --, --, 
   {{0x69c802ea,0xdb180588,0x93600022,0x00000000}},	//   maee, _tetã, ҩҭыҧ, --, 
   {{0xa2e45f45,0xdb18035b,0x5fe05f46,0xdb085f47}},	//   логд, _hetá, _पाइल, rafö, 
   {{0x3e7c5f48,0xa07401ec,0x63a0010e,0x00000000}},	//   síti_, ңызш, _şons, --, 
   {{0x69c85f49,0x91e400b5,0x24e813d6,0xddc02b24}},	//   naee, _jsとx, _змии_, dioş, 
   {{0x22400064,0x6ed000bc,0x00000000,0x00000000}},	// [69e0] _vlkk_, _हिउँ, --, --, 
   {{0xdb180122,0xbf440022,0x4fe400db,0xa71400eb}},	//   _letá, аҭгл, лмун_, াহীম_, 
   {{0x44445f4a,0xdb080109,0x9f5804cc,0xe298223e}},	//   _il_, nafô, cepì_, _пао_, 
   {{0x5d681c22,0x61441ee3,0x2444004a,0xdca4036b}},	//   нием_, _бема, _dôme_, гади, 
   {{0x44445f4b,0x69c80009,0x5fe00073,0x0d20004e}},	//   _kl_, daee, _पाऊल, бүтү, 
   {{0x44445f4c,0x8fa05f4d,0xdfd00451,0x9f580306}},	//   _jl_, _гаре, _ديس_, lepí_, 
   {{0x42841772,0x9f4802f6,0x44445f4e,0x48a402dd}},	//   _ዮሃንስ_, äjän_, _ml_, қтым_, 
   {{0x44445f4f,0x09dc038f,0xdb1825e6,0x69c80b23}},	//   _ll_, _སྐྱ_, _cetá, gaee, 
   {{0x44445f50,0x8cd84d21,0xdb180005,0x7a3c01ed}},	//   _ol_, _नियो, _detá, _hétk, 
   {{0x44445f51,0x69c80175,0xcb4802dd,0x195401ec}},	//   _nl_, aaee, _бiрi, кақы_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69c8003a,0x65601710,0x8cd812eb,0x47845f52}},	//   caee, _žoha, _निमो, ысым_, 
   {{0x44445f53,0xb4c00574,0x09dc0003,0x47c0015b}},	//   _bl_, ुळे_, _སྐྲ_, _শারী, 
   {{0x4444271d,0x00000000,0x00000000,0x00000000}},	//   _cl_, --, --, --, 
   {{0x44445f54,0xdb1800e4,0x244400d7,0xa3c40037}},	//   _dl_, _yetá, _bômb_, _उजर_, 
   {{0x44445f55,0x0fe001c0,0x7e0002e5,0x5fe04a01}},	//   _el_, өөгү, ोयोग_, _पाउल, 
   {{0xd4985f56,0x44445f57,0x00000000,0x00000000}},	// [69f0] _про_, _fl_, --, --, 
   {{0x44445f58,0xfbe00825,0x7338014b,0x8cd800cd}},	//   _gl_, _नागम, _азор_, _निबो, 
   {{0x9fa40032,0xcd2802e7,0x69c80009,0x00000000}},	//   рыуҙ, کسان_, yaee, --, 
   {{0x44445f59,0xddc00311,0x7e280816,0x00000000}},	//   _zl_, rioş, ліча_, --, 
   {{0x69c80607,0x6f040007,0x8c340107,0x00000000}},	//   vaee, swhc, лодӣ_, --, 
   {{0xd6c45f5a,0x26d05f5b,0x44445f5c,0x00000000}},	//   _وق_, ázok_, _xl_, --, 
   {{0x69c80421,0x7a3c01d3,0xc0ec0023,0x9ba0129d}},	//   taee, _kéth, ቅየር_, زەنى, 
   {{0xe8f85f5d,0x00000000,0x00000000,0x00000000}},	//   вли_, --, --, --, 
   {{0x7a3c20ef,0xba281a50,0x69c82f0f,0x6844014b}},	//   _méth, اسىم_, raee, иниа, 
   {{0xc5b401c0,0x7a3c5f5e,0x69c80037,0x00000000}},	//   өрмө, _léth, saee, --, 
   {{0x44445f5f,0x682c00d2,0x69c80165,0x00000000}},	//   _rl_, _kúdz, paee, --, 
   {{0x44445f60,0xdb18037e,0x6618005f,0xa9a400db}},	//   _sl_, _betæ, ētko, _ئمشى, 
   {{0x44445f61,0x64a45f62,0xb8640014,0x6adc03d4}},	//   _pl_, рага, شایو, _মনটো, 
   {{0x44445bcb,0x682c00d2,0xe7b400e2,0xf7701bf4}},	//   _ql_, _lúdz, āvēš, _کاه_, 
   {{0x7a3c5f63,0x65d401a9,0x00000000,0x00000000}},	//   _béth, _кўпх, --, --, 
   {{0x44445f64,0x7a3c0066,0x682c0030,0xa2e4036b}},	//   _wl_, _céth, _núdz, лоҳд, 
   {{0x44445f65,0x7a3c00ae,0xe3b80108,0x06e40150}},	// [6a00] _tl_, _déth, _ибп_, _рмқк_, 
   {{0x44445f66,0x28dc3874,0x1fb45f67,0x00000000}},	//   _ul_, _मिनि, рсар, --, 
   {{0x5de401a9,0x00000000,0x00000000,0x00000000}},	//   ижжа, --, --, --, 
   {{0xdb1806be,0x9f940139,0x00000000,0x00000000}},	//   _hetç, гыҗә, --, --, 
   {{0x61f40008,0xdb1803e0,0x91b8011a,0x1ab000cc}},	//   mfyl, _ketç, _במכי, _ঘটো, 
   {{0x204004d3,0x61f43bb0,0x21740107,0x00000000}},	//   _بکرێ, lfyl, _буҳр, --, 
   {{0xcb045f68,0x5b245f69,0x7a3c01d3,0x8aa0010b}},	//   ليون_, рьла, _héti, орыд, 
   {{0xda781def,0x00000000,0x00000000,0x00000000}},	//   ъял_, --, --, --, 
   {{0x4b840209,0x9848156e,0x00000000,0x00000000}},	//   лйән_, вяна_, --, --, 
   {{0x7a3c5f6a,0xb7d85f6b,0xfc640214,0x3e7c0113}},	//   _méti, دودا_, _اخری, rítu_, 
   {{0xcb641fbd,0x7bc80171,0x61f401e3,0xbbb4278e}},	//   _кафе_, _iedu, kfyl, ुरीक, 
   {{0x7bc80ba7,0xf7780327,0x78640139,0xcb480150}},	//   _hedu, ngħi_, ркүз, _бiтi, 
   {{0x7bc827ed,0xf2c405f5,0xdb1800a2,0x7a3c06af}},	//   _kedu, өөни, _betç, _néti, 
   {{0x7bc85f6c,0x349400c7,0x5fe01715,0xdc24010e}},	//   _jedu, сагр, _पागल, _möįb, 
   {{0x61f40368,0xd5b85f6d,0x00000000,0x00000000}},	//   ffyl, _исп_, --, --, 
   {{0x7bc85f6e,0x7a3c5f6f,0x5184430d,0xd5e800ec}},	//   _ledu, _béti, ауза, _شعبن_, 
   {{0x765c5f70,0x7a3c0798,0xf7780327,0x00000000}},	// [6a10] misy, _céti, dgħi_, --, 
   {{0x765c5f71,0x98a00006,0xdb1802f6,0x7a3c5f72}},	//   lisy, škė_, _ketä, _déti, 
   {{0x753c00dd,0xf4845f73,0xd17402dd,0xed5800ef}},	//   lysz, _پاکی, уыңы, _ieži_, 
   {{0x765c5f74,0x7bc816b8,0x7a3c4ac6,0x9e945f75}},	//   nisy, _aedu, _féti, مانچ, 
   {{0xdb185f76,0x753c01ed,0x3e7c03b2,0x00000000}},	//   _letä, nysz, vítt_, --, 
   {{0x7bc85f77,0x765c5f78,0x00000000,0x00000000}},	//   _cedu, hisy, --, --, 
   {{0x765c5f79,0xdb1801b8,0x53ac05f9,0x7bc85f7a}},	//   kisy, _netä, जुएश, _dedu, 
   {{0x765c02bd,0x5ec80154,0x00000000,0x00000000}},	//   jisy, াংশে, --, --, 
   {{0x29185f7b,0x7bc85f7c,0x44f40135,0x3e7c0d12}},	//   ísa_, _fedu, _བདེར_, rítt_, 
   {{0x7bc85f7d,0x765c017a,0x601c0432,0x6c84007b}},	//   _gedu, eisy, _içmä, _الطم, 
   {{0x765c5f7e,0xe5a404a9,0x29180115,0x61f40042}},	//   fisy, йини, ŭsa_, yfyl, 
   {{0x7bc801c4,0xdb180139,0x00000000,0x00000000}},	//   _zedu, _detä, --, --, 
   {{0xba745f7f,0x753c00dd,0xed581aff,0x7bc85f80}},	//   _بالت, gysz, _beži_, _yedu, 
   {{0x7bc807a9,0x7a3c5f81,0xe978001f,0x6b805f82}},	//   _xedu, _réti, _አሳሳቢ_, _kylg, 
   {{0x765c5f83,0x28dc20f0,0x7a3c5f84,0xb45002d3}},	//   bisy, _मिडि, _séti, _ሃገራዉ, 
   {{0x7a3c5f85,0x6b800076,0xd59800b5,0x22441bce}},	//   _péti, _mylg, ckは_, óok_, 
   {{0x66045f86,0x61f45f87,0x1540136b,0xe4740209}},	// [6a20] mekk, rfyl, _неъм, _гунэ, 
   {{0x66045f88,0xa3bc00ab,0xdb180166,0x6578035b}},	//   lekk, आरओ_, _yetä, ĩchĩ, 
   {{0x4fa001c6,0x00000000,0x00000000,0x00000000}},	//   чихв, --, --, --, 
   {{0x7a3c5f89,0x1d24010b,0xea000051,0x3ea001f4}},	//   _hétv, ймем, _đếy_, öit_, 
   {{0x7bc85f8a,0x51f42cb0,0x634c001f,0x62945f8b}},	//   _pedu, _اسپر, _አቆጣጠ, mmyo, 
   {{0x765c5f8c,0x69dc008c,0x6b805f8d,0xad245f8e}},	//   zisy, ósen, _bylg, ترمو, 
   {{0x66045f8f,0x7bc85f90,0x753c068f,0xc5e002f5}},	//   kekk, _vedu, zysz, য্যপ, 
   {{0x7bc85f91,0x66045f92,0xdb1800c7,0x6b80032e}},	//   _wedu, jekk, _retä, _dylg, 
   {{0xd838152d,0x765c5f93,0x7bc8019b,0x6d4401e4}},	//   гэн_, visy, _tedu, ŝhar, 
   {{0x6b805f94,0xdb185f95,0x765c5f96,0x62940399}},	//   _fylg, _petä, wisy, hmyo, 
   {{0x765c32a9,0x907805e1,0x28dc5195,0xa6e001a8}},	//   tisy, רטיי, _मिथि, _öðla, 
   {{0xdb1802f6,0x62940369,0xdc3400fd,0x66045f97}},	//   _vetä, jmyo, _yäğn, gekk, 
   {{0x765c5f98,0x62940369,0x4a78010f,0xc4940150}},	//   risy, dmyo, _גראב, _ﺜﺎﺒﺘ_, 
   {{0x765c5f99,0x06a0004b,0xdb180022,0x753c012d}},	//   sisy, _کميټ, _tetä, rysz, 
   {{0x765c5f9a,0x66045f9b,0xed5800d7,0x00000000}},	//   pisy, bekk, _veži_, --, 
   {{0x1128005b,0x66045f9c,0x95c80958,0xa50800db}},	//   люзи_, cekk, _сука_, _چىيە_, 
   {{0x51845f9d,0xb0345f9e,0x00000000,0x00000000}},	// [6a30] сува, онаш, --, --, 
   {{0x6d5406be,0x00000000,0x00000000,0x00000000}},	//   _əzad, --, --, --, 
   {{0xedd45f9f,0x8cd800af,0x00000000,0x00000000}},	//   قياد, _निहो, --, --, 
   {{0xd2040228,0x877800df,0x00000000,0x00000000}},	//   _ابدى, נטאז, --, --, 
   {{0xac745f32,0xf7780003,0x6b800a87,0x00000000}},	//   ياتش, mgħu_, _sylg, --, 
   {{0x66045fa0,0x7a3c020c,0x6b80045f,0x3eb8010a}},	//   zekk, _métu, _pylg, _ftrt_, 
   {{0x9f580270,0x447c008f,0x66045fa1,0x7a3c01a8}},	//   pepá_, אנגע, yekk, _létu, 
   {{0x6604011f,0x8fd001e0,0x2e88008e,0x00000000}},	//   xekk, _фәҡә, _төзи_, --, 
   {{0x2d985fa2,0x7a3c020c,0x66045fa3,0x6b80000f}},	//   _àse_, _nétu, vekk, _wylg, 
   {{0x66045fa4,0x4ae401b9,0xddc0012d,0x00000000}},	//   wekk, _гўда, choł, --, 
   {{0x66045fa5,0xbc3800cf,0x00000000,0x00000000}},	//   tekk, _اسقا_, --, --, 
   {{0x28f834d8,0x7a3c004e,0x3ce000f3,0x00000000}},	//   _ведь_, _bétu, šive_, --, 
   {{0x69d85fa6,0x7a840051,0x00000000,0x00000000}},	//   _idwe, ợccà, --, --, 
   {{0x2d8c05d9,0xf98800b2,0x80b006ab,0xdb180158}},	//   _mzee_, _انهي_, _अंबे, _wetå, 
   {{0x62585cb9,0x66045fa7,0x53a01111,0xf778025c}},	//   арар_, pekk, дарб, fgħu_, 
   {{0x7a3c0c6a,0x26d002f0,0xf9cc022e,0x11340092}},	//   _fétu, ázou_, mdo壮, _የመዝና, 
   {{0x69d8014b,0xdb18045f,0x2d8c009f,0xa5085fa8}},	// [6a40] _mdwe, _betû, _nzee_, _тепа_, 
   {{0x6fd40953,0x7d000175,0x7a3c01d3,0x776c06be}},	//   зіцц, _rpms, _hétt, _çoxç, 
   {{0x69d85fa9,0x1ed80597,0x23285faa,0xed5800e2}},	//   _odwe, شباب_, _тони_, _mežu_, 
   {{0x69d80097,0x9f5c0252,0x644c0477,0xaf980f06}},	//   _ndwe, _útí_, lhbi, стух_, 
   {{0x7a3c00e8,0x3ec801ec,0x00000000,0x00000000}},	//   _métt, рқұм_, --, --, 
   {{0x69d80605,0x7a3c0008,0xdfd05fab,0x8cd83abc}},	//   _adwe, _létt, _زير_, _निरो, 
   {{0x291c5fac,0x2d8c0083,0x8f640022,0xda4828e8}},	//   _arwa_, _ezee_, _дарб_, ичил_, 
   {{0x3e5800b0,0x00000000,0x00000000,0x00000000}},	//   kōti_, --, --, --, 
   {{0x69d800a9,0xd90c0405,0x38c80214,0x98045fad}},	//   _ddwe, ئیت_, حابی_, оянд, 
   {{0x69d801b3,0x291c5fae,0x660000a2,0x775400d8}},	//   _edwe, _drwa_, _ıoka, зкоф, 
   {{0x644c0009,0xdb1800d7,0x00000000,0x00000000}},	//   dhbi, _letú, --, --, 
   {{0x291c083a,0x7a3c5faf,0x98a45fb0,0xaae45fb1}},	//   _frwa_, _pétu, _диде, _رسمو, 
   {{0x18685fb2,0xdb185fb3,0x00000000,0x00000000}},	//   _кади_, _netú, --, --, 
   {{0x3ea45fb4,0xaaa805f9,0xe3e4031c,0x7a3c0129}},	//   _limt_, _चूँक, _སྐྱང, _vétu, 
   {{0xd2585fb5,0x7a3c002e,0x32580092,0xf7780135}},	//   аца_, _fétt, _ከሥልጣ, tgħu_, 
   {{0x3ea40b21,0xa0484418,0xdb180789,0x7a3c00e8}},	//   _nimt_, ەككە_, _betú, _gétt, 
   {{0xc69400c8,0x66000022,0xf778025c,0x7a3c00e5}},	// [6a50] _קאפ_, _ñoka, rgħu_, _héts, 
   {{0x7a3c01ed,0x644c5fb6,0x28dc0959,0x00000000}},	//   _kéts, chbi, _मिसि, --, 
   {{0xaaa80c2e,0xe3e4025c,0x04080154,0x4ea403de}},	//   _चूंक, _སྐྲང, শাখী_, іржа, 
   {{0x2d9802fb,0xf778003d,0x00000000,0x00000000}},	//   _úsek_, qgħu_, --, --, 
   {{0xdb180798,0xace81e76,0x621808a8,0x7a3c01d3}},	//   _getú, ёмка_, _פושק, _léts, 
   {{0x6618005f,0x6bd40345,0xceb80114,0x00000000}},	//   ētki, ستتر, _вља_, --, 
   {{0x28dc033d,0xeb982607,0xaa445fb7,0xed58107d}},	//   _मिहि, щик_, зейл, _režu_, 
   {{0xed5816a3,0x644c0489,0x00000000,0x00000000}},	//   _sežu_, zhbi, --, --, 
   {{0x7a3c00fc,0x2d8c01c8,0xd9d000db,0x00000000}},	//   _rétt, _uzee_, رەوگ, --, 
   {{0x25b40882,0x1bf00034,0xa96806b3,0x7a3c0098}},	//   ूर्ण, _घायल_, _қила_, _sétt, 
   {{0x2cac0221,0xaa5800f3,0x00000000,0x00000000}},	//   _hued_, _лижу_, --, --, 
   {{0x291c5fb8,0x69d80944,0x7afc007c,0x00000000}},	//   _trwa_, _udwe, _ärta, --, 
   {{0x291c5fb9,0xed58110c,0x80b05325,0x2ca40254}},	//   _urwa_, _težu_, _अंधे, _kild_, 
   {{0x2ca45fba,0x2cac0007,0x68e8006f,0xf9900050}},	//   _jild_, _mued_, mued, _شبن_, 
   {{0x68e8092e,0xc0d80201,0xdb185fbb,0x2cac04e6}},	//   lued, ኮኖሚ_, _setú, _lued_, 
   {{0x2cac5fbc,0x644c5fbd,0x57540302,0x3e5802b1}},	//   _oued_, shbi, _מבצע_, pōti_, 
   {{0xed5800de,0x2ab001d3,0x68e8127b,0x00000000}},	// [6a60] _mežs_, _láb_, nued, --, 
   {{0x66145fbe,0x3ea45fbf,0x00000000,0x00000000}},	//   _hayk, _simt_, --, --, 
   {{0x66140bf1,0x7a3c5fc0,0x3ea4010a,0x290c013f}},	//   _kayk, _métr, _pimt_, hwea_, 
   {{0x7a3c5fc1,0x661402d1,0x2cac0036,0x68e80433}},	//   _létr, _jayk, _bued_, kued, 
   {{0x2ca45fc2,0x9f58007c,0x00000000,0x00000000}},	//   _bild_, depå_, --, --, 
   {{0x66140bc9,0x2cac0007,0x1ea80451,0xada82002}},	//   _layk, _dued_, _هاري_, مدۇق_, 
   {{0x645c090c,0x2ca4365a,0x60d4135e,0x00000000}},	//   _mmpi, _dild_, lsym, --, 
   {{0x2ca40493,0x66145fc3,0xef905fc4,0x68e804e6}},	//   _eild_, _nayk, _شیند, fued, 
   {{0x58845fc5,0x68e85fc6,0x60d45fc7,0x645c5fc8}},	//   зына, gued, nsym, _ompi, 
   {{0x9c58006c,0x661402d0,0xdb840b3e,0x2ca44a21}},	//   _ушбу_, _aayk, _егзи, _gild_, 
   {{0x7c2841d6,0x66145fc9,0x7a3c5fca,0xb914063f}},	//   _indr, _bayk, _détr, _yadị_, 
   {{0x645c5fcb,0x60d45fcc,0x68e80221,0x66140009}},	//   _ampi, ksym, bued, _cayk, 
   {{0x66145fcd,0xc9805fce,0x68e85fcf,0xd8385fd0}},	//   _dayk, _пуши, cued, _гэй_, 
   {{0xdb1826ff,0x00000000,0x00000000,0x00000000}},	//   _betø, --, --, --, 
   {{0xe7e0000d,0x00000000,0x00000000,0x00000000}},	//   _खयता_, --, --, --, 
   {{0x645c5fd1,0x00000000,0x00000000,0x00000000}},	//   _empi, --, --, --, 
   {{0x764c5fd2,0x7c285fd3,0x30145fd4,0x7a3c002e}},	// [6a70] _ilay, _ondr, мдар, _yétr, 
   {{0x764c0c11,0x2cac5fd5,0xcf980798,0x00000000}},	//   _hlay, _rued_, бје_, --, 
   {{0xfeb835ac,0x66141bb7,0x60d40076,0x68e85fd6}},	//   كانت_, _yayk, asym, zued, 
   {{0x7c285fd7,0x28dc4d53,0x2ca45fd8,0x2cac039a}},	//   _andr, _मिलि, _sild_, _pued_, 
   {{0x2ab05fd9,0x764c04fb,0x51844ed8,0x3dc04f74}},	//   _sáb_, _mlay, _хуна, ñiwa_, 
   {{0x764c5fda,0xb7d40055,0x3ce00124,0x00000000}},	//   _llay, _kṣuc, áiva_, --, 
   {{0xfbd05fdb,0x764c5fdc,0x2ca404ce,0x7a3c20ef}},	//   اته_, _olay, _vild_, _rétr, 
   {{0x7c285fdd,0x68e8000a,0x9f5c5fde,0x764c090c}},	//   _endr, tued, _útá_, _nlay, 
   {{0x2cac007d,0x7a3c5fdf,0x66145fe0,0x53bc01bc}},	//   _uued_, _pétr, _rayk, ्राश, 
   {{0x764c5fe1,0xddc016a3,0x66145fe2,0x68e85fe3}},	//   _alay, mnoš, _sayk, rued, 
   {{0x764c5fe4,0x66140bf1,0x68e80c8c,0x6e282b96}},	//   _blay, _payk, sued, _kneb, 
   {{0x764c5fe5,0x645c020b,0x66140309,0x68e80789}},	//   _clay, _smpi, _qayk, pued, 
   {{0x68e83250,0x764c07a9,0x7a3c5fe6,0x7c285fe7}},	//   qued, _dlay, _tétr, _yndr, 
   {{0xcfe0045e,0x764c5fe8,0x66145fe9,0x7d045fea}},	//   ন্তন, _elay, _wayk, çisi, 
   {{0x66140054,0x4a080135,0x6e2803ac,0x764c5feb}},	//   _tayk, _ཁྲོལ_, _oneb, _flay, 
   {{0x7a3c003e,0x6e2804ba,0x764c037e,0x2a6c5fec}},	//   _jétp, _nneb, _glay, nneb_, 
   {{0xa0a405f5,0x645c0175,0x60d40153,0xe0d84316}},	// [6a80] даад, _tmpi, usym, юва_, 
   {{0xddc0098d,0x6e28012c,0x6618005f,0xbbac012c}},	//   dnoš, _aneb, ētku, _चलेक, 
   {{0x764c036b,0x2a6c0037,0x704400db,0xddc00171}},	//   _ylay, kneb_, رئكك, enoš, 
   {{0x7c283223,0x2a6c5fed,0xd3340a1e,0x6144010b}},	//   _sndr, jneb_, _חרטה_, _жема, 
   {{0x4a080135,0xcfe004c5,0x2a6c5fee,0x00000000}},	//   _ཁྲེལ_, ন্ধন, dneb_, --, 
   {{0x6e285fef,0x2a6c0037,0x63a0010e,0x00000000}},	//   _eneb, eneb_, _şony, --, 
   {{0x21202a1f,0x09a403d4,0x00000000,0x00000000}},	//   _hrkh_, ওঁফা, --, --, 
   {{0x3914209b,0xddc008a4,0x7af801f7,0xcfe00154}},	//   емир, bnoš, rtvt, ন্দন, 
   {{0xd7e43334,0x5fb00034,0x764c022e,0x0d8001c6}},	//   міно, _जलाल, _rlay, _алтн, 
   {{0x7e600280,0x6e2809a8,0xab0804da,0x764c26de}},	//   _hmmp, _zneb, تتۇق_, _slay, 
   {{0x9b445ff0,0x764c5ff1,0x98a00153,0x386c007f}},	//   _تناو, _play, škį_, rndr_, 
   {{0x764c022e,0xca200117,0x00000000,0x00000000}},	//   _qlay, _афши, --, --, 
   {{0x764c0076,0xd7f80408,0x00000000,0x00000000}},	//   _vlay, _дуй_, --, --, 
   {{0x36d400d6,0xdb1802d2,0x00000000,0x00000000}},	//   _зокр, _metþ, --, --, 
   {{0x764c5ba7,0x6ecc013f,0xddc02109,0x00000000}},	//   _tlay, pɑbɑ, znoš, --, 
   {{0x764c5ff2,0x65782056,0x31340139,0xf4d8022e}},	//   _ulay, éché, небр, _емиш_, 
   {{0x39445ff3,0xdb1808a5,0x00000000,0x00000000}},	// [6a90] nyms_, _netþ, --, --, 
   {{0xcf880b3b,0x6e28005c,0x00000000,0x00000000}},	//   осед_, _sneb, --, --, 
   {{0xb8d00135,0xd3442a77,0x39441b21,0x2a6c03cb}},	//   _ཟང_, _غیره_, hyms_, yneb_, 
   {{0xddc0041a,0x11e82088,0xb64004ce,0x9f4802d2}},	//   tnoš, _بعدي_, _ｍｃ_, _abbó_, 
   {{0xdb1800e4,0x6e280427,0x39440076,0xe4680166}},	//   _petÿ, _vneb, jyms_, _unöç_, 
   {{0x32180124,0x9be8025c,0x39440076,0x91f40166}},	//   _hasy_, _རྐྱོ, dyms_, _эчүч, 
   {{0x8cd81f13,0x3218033f,0xddc0260c,0x4a08031c}},	//   _निको, _kasy_, snoš, _ཁྲུལ_, 
   {{0xe9d84712,0x6e285ff4,0x7f945ff5,0x3218035b}},	//   чки_, _uneb, _расх, _jasy_, 
   {{0x321821ed,0x39440076,0x2a6c5ff6,0x00000000}},	//   _masy_, gyms_, rneb_, --, 
   {{0x32185ff7,0x2a6c00af,0x00000000,0x00000000}},	//   _lasy_, sneb_, --, --, 
   {{0xa92402d2,0x00000000,0x00000000,0x00000000}},	//   faþæ, --, --, --, 
   {{0x9f580270,0x32180432,0x39440042,0x6f140210}},	//   tepú_, _nasy_, byms_, _mszc, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6f145ff8,0x9938011a,0xdb18013a,0x00000000}},	//   _oszc, _מתנה, _letý, --, 
   {{0x32182f4a,0xe2985ff9,0x2250005a,0x73300023}},	//   _basy_, зав_, thyk_, _ኣዘኻኺ, 
   {{0xdb1802fb,0xd91000c7,0x321800d7,0xe2b401c4}},	//   _netý, _рдәы, _casy_, _үснэ, 
   {{0x60245ffa,0x321803d1,0x2fd00166,0x8cd801ad}},	// [6aa0] ндаа, _dasy_, _bezg_, _निगो, 
   {{0x32185ffb,0x83d800e5,0x7a200210,0x00000000}},	//   _easy_, _کاکڑ_, _kątó, --, 
   {{0xdb180162,0x4438002d,0x33f4004e,0x00000000}},	//   _betý, mjr_, _рчыс, --, 
   {{0x32181311,0xe4f400dc,0x44385ffc,0x3ce00022}},	//   _gasy_, ेऽपि_, ljr_, áivo_, 
   {{0x62845ffd,0x237000da,0xd36c104c,0xcfd00220}},	//   _ikko, šajā_, _نهی_, _ﺟﯘﺭﺗ, 
   {{0x32180109,0x00000000,0x00000000,0x00000000}},	//   _zasy_, --, --, --, 
   {{0x321800e4,0x5f041422,0x00000000,0x00000000}},	//   _yasy_, _язва, --, --, 
   {{0x7e600076,0x44380076,0xef04000d,0x00000000}},	//   _ummp, hjr_, _रहतऽ_, --, 
   {{0x39440076,0x00000000,0x00000000,0x00000000}},	//   uyms_, --, --, --, 
   {{0x1bb80597,0x394400ad,0xd13c0210,0x6cc401af}},	//   _رائع_, ryms_, _łąki_, _рифҡ, 
   {{0x62845ffe,0x624800a2,0x00000000,0x00000000}},	//   _okko, _aýom, --, --, 
   {{0xd0080c58,0xaac4004b,0xdb180254,0x38c80345}},	//   ৰায়_, _شتمن, _metü, _قاتی_, 
   {{0xe58405f5,0x73c429db,0xd4040107,0x43940150}},	//   втрү, кәне, няви, ғатс, 
   {{0x62845fff,0xd8a405d9,0x34940006,0x7c380427}},	//   _akko, _ڪهڙو_, тагр, njvr, 
   {{0x522407d6,0xd6e401c6,0x321844ef,0x00000000}},	//   нфаа, _бvсг, _pasy_, --, 
   {{0xdb1802d3,0xdb0801e6,0x2fd00166,0x81e400eb}},	//   _aftë, bbfö, _sezg_, প্স_, 
   {{0x067c06a9,0x349400c7,0x8fe449c4,0xa1440171}},	// [6ab0] _מנהל, _иаир, ецед, _noķē, 
   {{0xdb186000,0x62846001,0xb4dc0490,0x6f14033f}},	//   _betü, _ekko, डळी_, _pszc, 
   {{0x628403a0,0xdb1801f1,0xc7d40375,0x9e940014}},	//   _fkko, _metó, גובי_, چانچ, 
   {{0xdb1804d4,0xdb0c0248,0x3ebc00e5,0x00000000}},	//   _letó, _àdùb, ívta_, --, 
   {{0x6f14012d,0x00000000,0x00000000,0x00000000}},	//   _wszc, --, --, --, 
   {{0xe5201944,0x0f340132,0xdb180205,0x5fa000d1}},	//   मिति_, _كةزد, _fetü, _چەكم, 
   {{0x7f946002,0x61f400b5,0x6f140034,0x6ea40124}},	//   _барх, _æglø, _uszc, _ауаҧ, 
   {{0x6e940276,0xdb1801e7,0xda6002e8,0xfb2401e2}},	//   _рибу, _aetó, ивщи, اروپ, 
   {{0xdb1801f1,0xd1c0001f,0x72940023,0x7d04036e}},	//   _betó, _ስጦታ_, _ቀጥታዊ_, çist, 
   {{0xdb180077,0x6d580117,0x6d5406be,0x00000000}},	//   _cetó, mzwa, _əzal, --, 
   {{0x6d580112,0x051400dc,0x85b40131,0x2fc4000d}},	//   lzwa, _kuṇḍ, ләпч, _õlgu_, 
   {{0x6fcc015b,0xca540354,0x00000000,0x00000000}},	//   ালয়ে, _чĕмп, --, --, 
   {{0x69c86003,0x6d586004,0x62980118,0x051400cd}},	//   mbee, nzwa, ůtok, _muṇḍ, 
   {{0x68e86005,0x69c86006,0xe7302cb0,0xa2e400c9}},	//   mred, lbee, _نصب_, когд, 
   {{0xe73810f5,0x67140dad,0x69c86007,0x6490032e}},	//   _цей_, _तनिक_, obee, bæin, 
   {{0x69c86008,0x44380227,0xe524035b,0xb9180882}},	//   nbee, sjr_, _адип, tteḥ_, 
   {{0x4438003b,0x672001e3,0x69c85d3e,0x765c0200}},	// [6ac0] pjr_, lvlj, ibee, ërye, 
   {{0x6d586009,0x68e80c8c,0xdb18600a,0x64a4600b}},	//   dzwa, ired, _metò, _шапа, 
   {{0xe298600c,0x68e80cfd,0xdb1856eb,0x4524015b}},	//   _оао_, hred, _letò, _পথিক_, 
   {{0xfdc00183,0x6284023a,0x69c82112,0x398c0332}},	//   উণ্ড, _ukko, jbee, nósú_, 
   {{0x69c8600d,0x68e8600e,0x6d5801f5,0xe7e00073}},	//   dbee, jred, gzwa, पणाप, 
   {{0x68e8462f,0xddc00122,0x5f04600f,0x69c8303b}},	//   dred, dnoť, _изга, ebee, 
   {{0x68e86010,0xdb180005,0x69c81eb9,0xf40c00eb}},	//   ered, _retó, fbee, শাচর_, 
   {{0x69c86011,0xdd90129e,0x8cd812eb,0x00000000}},	//   gbee, _نوز_, _निचो, --, 
   {{0x68e826c2,0xba0400cf,0x00000000,0x00000000}},	//   gred, _ەستۉ, --, --, 
   {{0xad24021a,0x69c86012,0x38340137,0x0c2000db}},	//   _حرفو, abee, унор, _кмун, 
   {{0x7bd86013,0x69c8427c,0xaae415b4,0x68e86014}},	//   mavu, bbee, _مسنو, ared, 
   {{0x7bd86015,0x68e86016,0x69dc09f3,0xba1800ec}},	//   lavu, bred, óset, _سيتا_, 
   {{0xdb1802d1,0x68e86017,0x5fb000af,0x00000000}},	//   _tetó, cred, जशाल, --, 
   {{0x7bd86018,0xd5c00882,0x79a400fb,0x00000000}},	//   navu, _व्रज, _ирҙе, --, 
   {{0x07f45024,0x00000000,0x00000000,0x00000000}},	//   _شروع_, --, --, --, 
   {{0x7bd86019,0x00000000,0x00000000,0x00000000}},	//   havu, --, --, --, 
   {{0x51845f9d,0x7bd8601a,0xd4985fb2,0xaad8012c}},	// [6ad0] тува, kavu, _оро_, _यौनक, 
   {{0x7bd8601b,0x25bc00bc,0x81e400fe,0x656000a2}},	//   javu, ětle_, প্ল_, _ýoha, 
   {{0x7bd8601c,0x6ad000af,0x6b8c0198,0x051400dc}},	//   davu, _सबेर, ƙagi, _puṇḍ, 
   {{0x68e8601d,0x6d58601e,0x69c8037e,0x00000000}},	//   yred, tzwa, xbee, --, 
   {{0xebc400c7,0x7bd851bc,0x00000000,0x00000000}},	//   гӡеи, favu, --, --, 
   {{0x68e8601f,0x6d586020,0x7bd86021,0x69c8039a}},	//   vred, rzwa, gavu, wbee, 
   {{0x69c8057b,0x94f0025c,0xdb180561,0x4ea46022}},	//   tbee, _བཀའི_, _setò, _араа, 
   {{0x5d506023,0x7bd8013c,0x6d5801f5,0x69c8002f}},	//   ркәт, aavu, pzwa, ubee, 
   {{0x69c81af3,0x8cb8034c,0xa908004b,0xb3d80154}},	//   rbee, _آدرس_, ريدل_, _তানজ, 
   {{0x68e86024,0x7bd86025,0x67200841,0x00000000}},	//   rred, cavu, tvlj, --, 
   {{0x68e84d3c,0xc77000f7,0x69c80af9,0x00000000}},	//   sred, ртпө, pbee, --, 
   {{0xfd6400cd,0x67200e04,0xa8540075,0x68440166}},	//   _aruṇ, rvlj, ткүч, _әнка, 
   {{0x28dc17e6,0x00000000,0x00000000,0x00000000}},	//   _मिटि, --, --, --, 
   {{0x0b840023,0xf99002f2,0x00000000,0x00000000}},	//   _ምንዳይ_, _ببم_, --, --, 
   {{0xb5540055,0x26ec05ac,0x00000000,0x00000000}},	//   _āṅga, _জনকো_, --, --, 
   {{0x7bd86026,0x2d8c009f,0xf77001c8,0xa2e401b9}},	//   zavu, _oyee_, _باه_, коҳд, 
   {{0x7bd86027,0x2d8c6028,0x00000000,0x00000000}},	// [6ae0] yavu, _nyee_, --, --, 
   {{0xfdcc13f7,0x00000000,0x00000000,0x00000000}},	//   ार्फ, --, --, --, 
   {{0x93f800c8,0x2d8c016b,0x9f941d0f,0x00000000}},	//   _אליי, _ayee_, ушаш, --, 
   {{0x221448ab,0x644c0267,0xeea802dd,0x64a40022}},	//   _сфор, lkbi, втік_, _шаҿа, 
   {{0x7bd86029,0xa0740b32,0x61f403cb,0x00000000}},	//   tavu, _бывш, mgyl, --, 
   {{0x61f4602a,0x6e2c031c,0x4c100116,0x00000000}},	//   lgyl, _ħobż, مبىس, --, 
   {{0x7bd8602b,0x2d8c009a,0x2240602c,0x00000000}},	//   ravu, _eyee_, _kokk_, --, 
   {{0x7bd8602d,0x2240602e,0x61f4602f,0xcb0449c2}},	//   savu, _jokk_, ngyl, ايين_, 
   {{0xd7f86030,0x2d8c013b,0x224000e8,0x7bd8427f}},	//   нун_, _gyee_, _mokk_, pavu, 
   {{0x7bd819a2,0x224026ae,0x25b000a2,0xdca40063}},	//   qavu, _lokk_, _agyl_, _сази, 
   {{0xfd50004d,0x76746031,0xf6980063,0x61f4010e}},	//   _nghẽ, илоф, квој_, kgyl, 
   {{0x22400579,0x7a3c0036,0x644c01f5,0x637000e5}},	//   _nokk_, _létz, ekbi, zűné, 
   {{0x80b000af,0x46680276,0x00000000,0x00000000}},	//   _अंगे, урэм_, --, --, 
   {{0xef0400c5,0x2a700327,0x00000000,0x00000000}},	//   _रहलऽ_, ħobż_, --, --, 
   {{0x22403d27,0x0464230c,0xd4980137,0xd5b80fac}},	//   _bokk_, стям, _үрп_, _псп_, 
   {{0x61f400ad,0xea000208,0x22400205,0xe00000bc}},	//   ggyl, _đẫy_, _cokk_, र्सद_, 
   {{0x3f9805be,0x224003b2,0xc3c4009d,0x00000000}},	// [6af0] _azru_, _dokk_, шөөл, --, 
   {{0x644c2a6e,0xfd640055,0x00000000,0x00000000}},	//   ckbi, _uruṇ, --, --, 
   {{0x73340075,0x22406032,0xa2c001ee,0x00000000}},	//   _ئىجا, _fokk_, _мәтк, --, 
   {{0xed5011ef,0x51846033,0xdc8c0023,0x00000000}},	//   يپا_, _буга, ዝገበረ_, --, 
   {{0x48bc0c58,0xb8140c2e,0x3b0c0477,0xbdf80228}},	//   _এট্ৰ, तजाम_, _apdq_, ارما_, 
   {{0x1be402e8,0x2240025c,0x00000000,0x00000000}},	//   адши_, _zokk_, --, --, 
   {{0x8d5c001f,0x9e9404da,0x22400694,0x00000000}},	//   ዳላቸው_, _چاقچ, _yokk_, --, 
   {{0xaa440262,0x2240025c,0x06c401d5,0x00000000}},	//   реил, _xokk_, қҳий_, --, 
   {{0xde600014,0xcd2003e6,0xe9d80210,0xc6d0009d}},	//   _بۯنٹ, _دژای, raź_, өснө, 
   {{0x61f40209,0x7b08007c,0xe728009d,0x00000000}},	//   zgyl, åstä, воод_, --, 
   {{0xbca400e3,0x00000000,0x00000000,0x00000000}},	//   _املي, --, --, --, 
   {{0xc1740198,0xa5246034,0x644c6035,0xc84c0092}},	//   haɗa_, аммд, wkbi, _ህገመን, 
   {{0x22402507,0x00000000,0x00000000,0x00000000}},	//   _rokk_, --, --, --, 
   {{0x22406036,0xa878008f,0xe3b0007b,0x29180327}},	//   _sokk_, _שאַר, ترح_, ħsad_, 
   {{0x22400254,0x00000000,0x00000000,0x00000000}},	//   _pokk_, --, --, --, 
   {{0xa1c46037,0x7a3c0036,0x3ce016a3,0x644c007c}},	//   рбад, _sétz, šivi_, skbi, 
   {{0x61f46038,0xe3b06039,0xc17402a8,0x1fb4603a}},	// [6b00] rgyl, _ورد_, faɗa_, асер, 
   {{0x5f04014b,0x237400ae,0x00000000,0x00000000}},	//   изза, _ناجح, --, --, 
   {{0x4444603b,0xe00005f9,0xc5a805d9,0x22400327}},	//   _io_, र्षद_, _جڏھن_, _tokk_, 
   {{0x4444603c,0xcee40a8f,0x6f8c0150,0x1d2400d4}},	//   _ho_, рдце_, _ﺒﹼﺩﻋ_, имем, 
   {{0x8d6018ac,0x55b80375,0x81dc0154,0x3c940066}},	//   овце, דמנו, _ঠাপ_, میرز, 
   {{0x717002dd,0xddc00356,0xf114010f,0xe0600345}},	//   _عۇلا, fioţ, _פֿרי_, _بێئی, 
   {{0xdb1800dd,0x2008603d,0xada81e87,0x00000000}},	//   _letö, _ibbi_, ندۇق_, --, 
   {{0x9e640133,0x8f50114f,0x00000000,0x00000000}},	//   _ئاسن, _بنفش, --, --, 
   {{0x4444603e,0x2008603f,0xb4e40243,0x3eb82517}},	//   _oo_, _kbbi_, _पटे_, _hurt_, 
   {{0x44440d8e,0x3eb86040,0x57a43529,0xddc0012d}},	//   _no_, _kurt_, ишна, skoń, 
   {{0x61e46041,0x2ca8067c,0x3eb802d2,0x00000000}},	//   _odkl, ïade_, _jurt_, --, 
   {{0xdb1801ed,0x3eb86042,0x00000000,0x00000000}},	//   _betö, _murt_, --, --, 
   {{0x44446043,0x3eb803a1,0x3d04009e,0x898400db}},	//   _bo_, _lurt_, লিক্_, _پپوف_, 
   {{0x948456a6,0x44440302,0xea000016,0x61e46044}},	//   рымд, _co_, _đẩy_, _adkl, 
   {{0x44440d65,0x88380302,0x27f000d0,0x3eb80210}},	//   _do_, _בתגו, ózne_, _nurt_, 
   {{0x44446045,0x20086046,0x6d5c05d5,0x386c005a}},	//   _eo_, _abbi_, _üsag, lidr_, 
   {{0xdb186047,0x245007d6,0xf7780327,0x09d80154}},	// [6b10] _getö, زچیس, egħx_, _ধামা, 
   {{0x44446048,0x4174005e,0x74146049,0x60c0007b}},	//   _go_, زاقس, _اودا, íoma, 
   {{0x3eb8604a,0xfeb8604b,0xc1740198,0x00000000}},	//   _curt_, لانت_, raɗa_, --, 
   {{0x4444604c,0x2008604d,0xadd80137,0xddc02ac2}},	//   _zo_, _ebbi_, умду_, rhoş, 
   {{0x4444604e,0x20080165,0xfde802dd,0x3eb80332}},	//   _yo_, _fbbi_, рдік_, _eurt_, 
   {{0x4444604f,0x3eb86050,0xe8f8024c,0xae04215c}},	//   _xo_, _furt_, ҳли_, _گورى, 
   {{0x3eb86051,0xaa4401e0,0x00000000,0x00000000}},	//   _gurt_, йекл, --, --, 
   {{0xae040131,0x037800d9,0x00000000,0x00000000}},	//   _دورى, יתות_, --, --, 
   {{0x610800e2,0x29d40132,0x00000000,0x00000000}},	//   cēlā, _ۇياس, --, --, 
   {{0x3eb86052,0x6fb80709,0x00000000,0x00000000}},	//   _yurt_, ेडिं, --, --, 
   {{0xab940597,0x0524015b,0x5ca40145,0x29d401c8}},	//   _الاغ, _পথের_, _اللە, _هياس, 
   {{0x44446053,0x80c8015b,0x00000000,0x00000000}},	//   _so_, _লিস্, --, --, 
   {{0x69d86054,0xc9840640,0xc0e402d3,0x059404f2}},	//   _iewe, _тужи, _ምህሮ_, تادگ, 
   {{0x44446055,0x291c6056,0x69d86057,0x64a46058}},	//   _qo_, _iswa_, _hewe, сага, 
   {{0x69d86059,0x00000000,0x00000000,0x00000000}},	//   _kewe, --, --, --, 
   {{0x4444605a,0x69d8605b,0x96d40022,0xd7900066}},	//   _wo_, _jewe, _усшә, _عليخ, 
   {{0x4444605c,0x3eb8605d,0xc1b80034,0x69d8605e}},	// [6b20] _to_, _surt_, _अलीग, _mewe, 
   {{0x69d8605f,0x44446060,0xd12c6061,0x1fb46062}},	//   _lewe, _uo_, عمل_, ссар, 
   {{0x69d86063,0x2a6c020c,0x3eb86064,0x996001ef}},	//   _oewe, kieb_, _qurt_, _míšo_, 
   {{0x69d86065,0x291c0d29,0x61e4037e,0xb7000166}},	//   _newe, _oswa_, _udkl, _çäşl, 
   {{0x291c1418,0x2a6c00d0,0x3d340241,0x00000000}},	//   _nswa_, dieb_, _òwe_, --, 
   {{0x69d80086,0xa06800f7,0x3eb86066,0x20080694}},	//   _aewe, _сага_, _turt_, _ubbi_, 
   {{0x69d86067,0x291c6068,0xcb043738,0xdb082d8d}},	//   _bewe, _aswa_, ميون_, ازته_, 
   {{0x69d80574,0x624800a2,0x22506069,0x00000000}},	//   _cewe, _gýot, nkyk_, --, 
   {{0x291c07ab,0x38c83faa,0x1c4402dd,0x5ad000e5}},	//   _cswa_, جابی_, _лнам, _کےبا, 
   {{0x69d8606a,0xbb00022e,0x00000000,0x00000000}},	//   _eewe, _биpи, --, --, 
   {{0x69d81382,0x2a6c0135,0x5ac826c7,0x386c036e}},	//   _fewe, bieb_, _слем_, ridr_, 
   {{0x69d8606b,0x00000000,0x00000000,0x00000000}},	//   _gewe, --, --, --, 
   {{0x9e1801ec,0xcfe000eb,0x1a6401e2,0x00000000}},	//   ттiг, ন্টন, _پیښی_, --, 
   {{0x69d85617,0x36d40902,0xddc002f0,0x7afc01e3}},	//   _zewe, _докр, jnož, _ärts, 
   {{0x80c804c5,0xe81c0490,0x69d8606c,0x92b4007b}},	//   _লিষ্, _बघता_, _yewe, إحسا, 
   {{0x69d8606d,0x22500ea0,0x5184606e,0x5fb009ab}},	//   _xewe, gkyk_, буза, _जलजल, 
   {{0x948400a8,0x00000000,0x00000000,0x00000000}},	// [6b30] _гынд, --, --, --, 
   {{0x752c606f,0x34b40034,0x806c001f,0x80c805ac}},	//   _iraz, ंदीद, _ተከፈተ_, _লিশ্, 
   {{0x752c02fb,0x624800a2,0xcf981f5a,0x2fc00042}},	//   _hraz, _pýot, уја_, rchg_, 
   {{0x752c6070,0x85046071,0x2fc0002f,0x00000000}},	//   _kraz, _بوین, schg_, --, 
   {{0x69d86072,0x320814dc,0xad246073,0x2a6c0030}},	//   _rewe, mfay_, تىشى, vieb_, 
   {{0x69d86074,0x752c6075,0x320814dc,0xb05401d3}},	//   _sewe, _mraz, lfay_, _بھرت, 
   {{0xeb986076,0x2a6c00d0,0x32080067,0x0dc8299f}},	//   шик_, tieb_, ofay_, _бузи_, 
   {{0x752c6077,0x32080c8c,0x3ef8084c,0xde4400f1}},	//   _oraz, nfay_, _ынсэ_, _ویلو_, 
   {{0x2a6c6078,0x6f046079,0x316c00a2,0x00000000}},	//   rieb_, lthc, _ýezd_, --, 
   {{0x69d8607a,0x3208127b,0x8b3401f0,0x2a6c607b}},	//   _wewe, hfay_, _гӯиё_, sieb_, 
   {{0x752c607c,0x69d8607d,0x81e40f22,0x6f040393}},	//   _araz, _tewe, প্ট_, nthc, 
   {{0x291c607e,0x69d804c4,0x25bc012c,0x880000f1}},	//   _tswa_, _uewe, ětlo_, _کېدو, 
   {{0x32082f05,0x291c0585,0x752c26c2,0xa7a00150}},	//   dfay_, _uswa_, _craz, _ﺎﺭﺩﺓ_, 
   {{0x752c607f,0x320803c4,0x624802d2,0x00000000}},	//   _draz, efay_, _nýor, --, 
   {{0x3208002e,0x752c6080,0x225005e4,0x048801e0}},	//   ffay_, _eraz, tkyk_, иәүи_, 
   {{0x765c6081,0x320803ac,0x21740114,0x00000000}},	//   chsy, gfay_, оузр, --, 
   {{0x752c6082,0x22501979,0x6f040142,0x00000000}},	// [6b40] _graz, rkyk_, ethc, --, 
   {{0x32081af4,0x769c020c,0x22500af9,0x9f9400d8}},	//   afay_, méya, skyk_, ошеш, 
   {{0x752c01f1,0xc2b401c0,0xcdfc037e,0x3208035a}},	//   _zraz, _хөгш, ko的_, bfay_, 
   {{0x752c03ac,0x3208127b,0x00000000,0x00000000}},	//   _yraz, cfay_, --, --, 
   {{0x9568001f,0x6f041db0,0xa0a400db,0xfbac141f}},	//   _አንተን_, athc, _мамд, टेनम, 
   {{0x98a40316,0x62946083,0x8c400640,0x28d400d1}},	//   _proč_, llyo, деље, ﯟﻩﺗﻠ, 
   {{0x2ca803a2,0x60d80055,0x00000000,0x00000000}},	//   ïada_, _ātmy, --, --, 
   {{0x769c0687,0x98a40219,0xa0680107,0x7a38084c}},	//   kéya, _vroč_, _саҳа_, спир_, 
   {{0x7d0401c3,0x6ec40064,0xe8ec00ec,0x00000000}},	//   àisd, _vėbe, هڻو_, --, 
   {{0x5b34182c,0x1bb801ed,0x769c04fb,0x195401ec}},	//   _وعار, _ضائع_, déya, йақы_, 
   {{0xecb00184,0x752c33dc,0x4fb80a7c,0x27f00419}},	//   _яҡшы, _sraz, יציא, ózna_, 
   {{0x752c6084,0x7af8014f,0x32080857,0x00000000}},	//   _praz, muvt, xfay_, --, 
   {{0xdb4c04d3,0x769c034c,0x00000000,0x00000000}},	//   _سێک_, géya, --, --, 
   {{0xc8c4168d,0x3208127b,0xda0400b8,0x00000000}},	//   _بوون_, wfay_, व्रत_, --, 
   {{0x926805f5,0x320814dc,0x6f0401ab,0x752c012d}},	//   араа_, tfay_, xthc, _wraz, 
   {{0x95c80cfc,0x02a4135c,0x069408b0,0x769c6085}},	//   _тука_, друм, ﯟﺍﻟﯩ, béya, 
   {{0x752c6086,0x320814dc,0x7058009d,0x00000000}},	// [6b50] _uraz, rfay_, баар_, --, 
   {{0x320814dc,0xea00004d,0x75d40ee8,0x00000000}},	//   sfay_, _đậy_, _بيکا, --, 
   {{0xcee86087,0xff2800b5,0x3208035a,0x00000000}},	//   شران_, _phpは, pfay_, --, 
   {{0x7af80477,0x714000cf,0x624800a2,0x00000000}},	//   duvt, _كۉزۅ, _wýor, --, 
   {{0xddc00034,0xfe08007b,0x00000000,0x00000000}},	//   lkoś, تقني_, --, --, 
   {{0xfca800f1,0x00000000,0x00000000,0x00000000}},	//   ياوو_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa9c00372,0x5ea000db,0x705801d5,0xaed4014b}},	//   رۅتۉ, _كۅلل, _таҳр_, _моҳш, 
   {{0xd9ac00cc,0xa9683e4f,0x00000000,0x00000000}},	//   ছুসম, сипа_, --, --, 
   {{0xa2a00cb4,0x5e840022,0x8c546088,0x7d0400a3}},	//   _कीन्, _дуӡз, _بئرا, àise, 
   {{0xb8646089,0xdb1801bf,0x769c04fb,0x9990074d}},	//   بايو, _aftæ, wéya, _тiом_, 
   {{0xddc0012d,0xdb98011a,0x00000000,0x00000000}},	//   dkoś, _הסער, --, --, 
   {{0x758c069c,0xe794608a,0xba00035b,0x1a98010f}},	//   _መንገዲ_, _کاشک, _рҧыл, _פינע, 
   {{0x6aa80158,0x769c4a16,0xe0d00014,0x00000000}},	//   lmef, réya, ہٲر_, --, 
   {{0xd464608b,0xdc980115,0x2328011c,0x00000000}},	//   чире_, מישל, щови_, --, 
   {{0x769c020c,0x56901f5a,0x216808ca,0x2aa000e5}},	//   péya, _пајт, биби_, lóbb_, 
   {{0x15f8011a,0xdfe801c6,0xd59c0150,0x00000000}},	// [6b60] _ההפע, йдад_, _бәрi_, --, 
   {{0x60240139,0x6aa80e78,0xdee00150,0x00000000}},	//   ядза, hmef, еудi_, --, 
   {{0x41dc0210,0x51f40066,0x00000000,0x00000000}},	//   बरदस, _کسپر, --, --, 
   {{0x7af80477,0x93c800e5,0x03d8002b,0x00000000}},	//   vuvt, _پایہ_, _ārṣa, --, 
   {{0xe3b0608c,0x6aa83b35,0x9be400d4,0x00000000}},	//   _ترک_, dmef, пійк, --, 
   {{0xdfd0092f,0xe04405f5,0xdee401b9,0x8aa00022}},	//   _سير_, _энги, _ноги, ҽрыд, 
   {{0x8b200114,0x10a0608d,0x70500345,0x8be400cf}},	//   едје, _чирн, _جۆلا, سىيق_, 
   {{0x2018608e,0x6aa80158,0x00000000,0x00000000}},	//   lepi_, gmef, --, --, 
   {{0x98a402b5,0x15e0033f,0x7af8047e,0xe744000d}},	//   _aroā_, _ख़बर_, suvt, õõne_, 
   {{0x2018608f,0x7af80455,0xfce46090,0x00000000}},	//   nepi_, puvt, _ноғо, --, 
   {{0x09d800bd,0x7af8014f,0xbbd800cd,0x00000000}},	//   _ধারা, quvt, डरीक, --, 
   {{0x20184d11,0x7bc8009a,0x6aa80175,0x98c40798}},	//   hepi_, _hfdu, cmef, _ескл, 
   {{0x20186091,0x00000000,0x00000000,0x00000000}},	//   kepi_, --, --, --, 
   {{0x201841f3,0xf31401c6,0x6ec400c0,0x00000000}},	//   jepi_, мдгэ, _lėba, --, 
   {{0x20186092,0xd2580b7e,0x48200137,0x00000000}},	//   depi_, бца_, _سىيق, --, 
   {{0x43946093,0xd5b86094,0x050c0154,0x00000000}},	//   хасс, _уск_, ষয়ের_, --, 
   {{0x201801ee,0x21200208,0xddc0012d,0x857402e8}},	// [6b70] fepi_, _cskh_, skoś, _плъх, 
   {{0x20186095,0xf31801c0,0xddc00210,0x00000000}},	//   gepi_, _доош_, pkoś, --, 
   {{0x229c2776,0x9dc8063f,0xc6200154,0xc7d4011a}},	//   sïka_, _ịpịg, ধারা_, פואי_, 
   {{0x7bc80050,0x32180451,0x00000000,0x00000000}},	//   _afdu, _بيحد_, --, --, 
   {{0x20186096,0x8d843da1,0x00000000,0x00000000}},	//   bepi_, чужд, --, --, 
   {{0x20186097,0x2ab000d7,0x00000000,0x00000000}},	//   cepi_, _všbm_, --, --, 
   {{0xddc00115,0xaa4410de,0x749400d1,0xcaf0009d}},	//   lkoŝ, дейл, ﯞﺍﭘﯩ, хцлө, 
   {{0x769c002e,0x7ae801f4,0x83380677,0xed1400e5}},	//   déyo, _dvdt, לאוס_, _يہاں_, 
   {{0x6aa85629,0x2aa001d3,0xddc001e4,0xac9400db}},	//   rmef, tóbb_, nkoŝ, _жааш, 
   {{0x6fdc0d0a,0x6fb00490,0xfc640395,0x00000000}},	//   यरिं, _जणां, _пъхн, --, 
   {{0xc5b80003,0x7c84010a,0x00000000,0x00000000}},	//   _དཔྱི, _чуте, --, --, 
   {{0xa50820e5,0xf3e80375,0x2aa001d3,0x7afc01e3}},	//   оема_, _כף_, sóbb_, _årta, 
   {{0x16600108,0x81dc00cc,0x00000000,0x00000000}},	//   твям, _ঠাল_, --, --, 
   {{0xc44815b4,0x00000000,0x00000000,0x00000000}},	//   سیجن_, --, --, --, 
   {{0x20186098,0xa2e402e8,0x00000000,0x00000000}},	//   vepi_, ьовд, --, --, 
   {{0xe0d8055f,0x920000dc,0x00000000,0x00000000}},	//   жва_, _śāri, --, --, 
   {{0x20186099,0x602401c6,0x60e8014b,0x00000000}},	// [6b80] tepi_, мдаа, юмам_, --, 
   {{0xf1b000b2,0xdf74609a,0x00000000,0x00000000}},	//   اءِ_, وداب, --, --, 
   {{0x2018609b,0x645c037e,0x545400d9,0x00000000}},	//   repi_, _ilpi, _חביב_, --, 
   {{0x649004ce,0x2018609c,0x21200051,0x9d5401f0}},	//   pæis, sepi_, _tskh_, мӯзӣ_, 
   {{0x2018609d,0xfc140139,0xdddc00e5,0x00000000}},	//   pepi_, емлэ, övőd, --, 
   {{0xa0a40323,0x20180113,0x41a80354,0x00000000}},	//   _цагд, qepi_, ĕвĕн_, --, 
   {{0x6f140113,0x6d5c07c5,0x09cc00cc,0x79540133}},	//   _gpzc, _üsan, _িয়া, کێشا, 
   {{0xdee40364,0x8fa0609e,0x98c4609f,0x4fa0010a}},	//   _ноҳи, _расе, мсол, _рисв, 
   {{0x60c00491,0x588460a0,0xc1740198,0xadb40150}},	//   íomh, дына, faɗi_, _كۇما_, 
   {{0x36d460a1,0xd7f8009d,0x00000000,0x00000000}},	//   ноор, цуи_, --, --, 
   {{0xc6f4009d,0x77982901,0xcff4011a,0x4ff400df}},	//   мнэх_, якор_, וציה_, וזיע_, 
   {{0x7c2860a2,0x645c1948,0xaae4007b,0x00000000}},	//   _hadr, _alpi, _أسلو, --, 
   {{0x08f4007b,0x2c0400cd,0x54340ee8,0x00000000}},	//   _قروب_, _रामं_, ورسر, --, 
   {{0x7c2860a3,0x4a080135,0x3f9806ea,0x2ba40118}},	//   _jadr, _གཡོལ_, _oyru_, गेका, 
   {{0x7c2860a4,0x439460a5,0x4cc4015b,0xd24c0133}},	//   _madr, варс, রীপু, لۆد_, 
   {{0x645c60a6,0x2eec00df,0x061460a7,0xe3e000cc}},	//   _elpi, _ĉef_, _адъю, _বাণব, 
   {{0x78b81418,0x3f98022e,0x7c2860a8,0xb03460a9}},	// [6b90] _kivv, _ayru_, _oadr, ннаш, 
   {{0xcf9815ed,0x764c062c,0xc10460aa,0x78b80003}},	//   оје_, _hoay, ئولي, _jivv, 
   {{0x3ed43306,0x78b801ef,0x00000000,0x00000000}},	//   َقْر, _mivv, --, --, 
   {{0x7c28007d,0x78b817b8,0x764c00c7,0x4a08031c}},	//   _aadr, _livv, _joay, _གཡེལ_, 
   {{0x7c2860ab,0x644c09a8,0x5184074d,0xc1740198}},	//   _badr, žniš, _цуна, yaɗi_, 
   {{0x7c2860ac,0x764c0731,0x78b860ad,0x7c840114}},	//   _cadr, _loay, _nivv, кује, 
   {{0x2744006a,0x7c2860ae,0xbef8007b,0x00000000}},	//   _mênë_, _dadr, _يرفض_, --, 
   {{0xa92460af,0x692460b0,0x24440109,0x7c280c8c}},	//   едил, емиа, _dômy_, _eadr, 
   {{0x7c2860b1,0x78b80083,0xd1e00092,0x00000000}},	//   _fadr, _bivv, _ምዕተ_, --, 
   {{0x6e28052f,0x7c28601a,0x7b0800dd,0x5ed000fe}},	//   _haeb, _gadr, örtö, _হিতে, 
   {{0xe73860b2,0xd6cc60b3,0x6e2800af,0x764c0731}},	//   чен_, یقی_, _kaeb, _boay, 
   {{0x6e280263,0x764c0363,0x6564009f,0x2aa001e1}},	//   _jaeb, _coay, tzkh, bóba_, 
   {{0x7c2860b4,0x6e280770,0x69c80067,0x00000000}},	//   _yadr, _maeb, mcee, --, 
   {{0x6e2860b5,0x7c2860b6,0x81dc0183,0x69c860b7}},	//   _laeb, _xadr, _ঠাই_, lcee, 
   {{0xa69426e5,0x68e83402,0x764c0731,0xc360001f}},	//   _приј, lsed, _foay, _ማዘጋጀ, 
   {{0x69c860b8,0x6e2860b9,0x764c00ad,0x3f9800c7}},	//   ncee, _naeb, _goay, _ryru_, 
   {{0x68e860ba,0x5f4460bb,0xf574002e,0x7790030f}},	// [6ba0] nsed, کنال, _jig茜, _مییا, 
   {{0x645c1730,0x78b805c7,0xe3a80395,0xddc0236c}},	//   _ulpi, _xivv, _нкпд_, fkoş, 
   {{0x6e2860bc,0x68e803ee,0x7c3c004e,0x94c8004b}},	//   _baeb, hsed, _òrri, _وایې_, 
   {{0x7c2804b9,0x614407fa,0x68e860bd,0x69c80218}},	//   _sadr, _зема, ksed, jcee, 
   {{0x6e280263,0x69c80014,0x68e860be,0x00000000}},	//   _daeb, dcee, jsed, --, 
   {{0x8c4060bf,0x68e860c0,0x7c2807d6,0x4a080003}},	//   лече, dsed, _qadr, _གཡུལ_, 
   {{0x8fa0055f,0x7c2860c1,0x3f8c006a,0x27e40198}},	//   _баре, _vadr, _âdu_, daln_, 
   {{0x7c2860c2,0x6e28013d,0x8520012c,0x1ea80451}},	//   _wadr, _gaeb, यबाट_, _ڀاڱي_, 
   {{0x7c2860c3,0x764c00ad,0x7c2400c7,0x980400ee}},	//   _tadr, _roay, _изаҧ, нянд, 
   {{0x6e2804ba,0x69c8058a,0x7c2860c4,0x2aa000e5}},	//   _zaeb, acee, _uadr, róba_, 
   {{0x3f5c0084,0x68e80c8c,0x7bd80810,0x764c0076}},	//   ṋu_, ased, mbvu, _poay, 
   {{0xea0007ae,0x68e8003a,0x69c860c5,0x78b8014f}},	//   _đầy_, bsed, ccee, _wivv, 
   {{0x1cbc49a6,0x764c1368,0x78b80003,0x058401d5}},	//   _ཁངས_, _voay, _tivv, гурм, 
   {{0x764c016b,0x534401c0,0x7af80076,0x00000000}},	//   _woay, нхба, orvt, --, 
   {{0x7bd8004c,0xe4b400f7,0xd2585622,0xb4b00073}},	//   ibvu, тирө, пца_, _ओळी_, 
   {{0x3f5c06d6,0x99840030,0xf4b801ec,0x00000000}},	//   ḓu_, _množ_, _ﺤﺎﺩﺜ, --, 
   {{0x73c40588,0xbf1401e0,0x69dc0162,0x00000000}},	// [6bb0] _аӡба, һүрә, ðsei, --, 
   {{0x6e280007,0x7e60035a,0xe72c0345,0x73c460c6}},	//   _saeb, _almp, _اڵی_, _шәме, 
   {{0x09e400cc,0x7d0401c3,0x00000000,0x00000000}},	//   ফলতা, àisn, --, --, 
   {{0x68e803cb,0x9fa40032,0x69c80429,0x3cb80150}},	//   ysed, тыуҙ, xcee, _ﺸﺎﺭﺤ, 
   {{0x6e280099,0xad240131,0x816401d9,0xfeb80244}},	//   _vaeb, ئىتى, _یۆہۆ, رامت_, 
   {{0xbbe820ea,0x6e2801c8,0x2fe800db,0x68e801bf}},	//   ىرىم_, _waeb, _زىرپ_, vsed, 
   {{0x69c8011f,0x6e28000d,0xa3e060c7,0xfbac044b}},	//   tcee, _taeb, दरत_, टेलम, 
   {{0x68e860c8,0xc33404ae,0x7bd80810,0x69c860c9}},	//   tsed, רוק_, abvu, ucee, 
   {{0x69c860ca,0x3330020c,0x3d0800dc,0x68e802d0}},	//   rcee, hvzx_, _समये_, used, 
   {{0x68e860cb,0x69c8074d,0x7c84010a,0x00000000}},	//   rsed, scee, _йухе, --, 
   {{0xb90813de,0xdb240066,0x00000000,0x00000000}},	//   وزیم_, _لولی, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe944028e,0x00000000,0x00000000,0x00000000}},	//   _جرای, --, --, --, 
   {{0x5ed003f4,0x64a40b20,0x348401e0,0x290c054e}},	//   _হিসে, тага, лҡып_, mtea_, 
   {{0xe29860cc,0x290c60cd,0xe29406ed,0xdce00219}},	//   дав_, ltea_, враќ, vzoč, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x290c60ce,0x80c809bd,0x64a400c7,0x00000000}},	// [6bc0] ntea_, _লিঙ্, _иаиа, --, 
   {{0xa2a01157,0x290c60cf,0x328c01ec,0xc2940133}},	//   _कीर्, itea_, _ﺒﻌﻜﺱ_, _ڕیزب, 
   {{0xe2840798,0x1fb401f0,0x290c0108,0x00000000}},	//   _ални, тсар, htea_, --, 
   {{0x290c0175,0x00000000,0x00000000,0x00000000}},	//   ktea_, --, --, --, 
   {{0xefe002d3,0x6614035b,0x9e6401b9,0xdd900d17}},	//   _ነዳዲ_, _mbyk, _یارن, جوش_, 
   {{0x201c60d0,0x2174023b,0x60d40064,0x00000000}},	//   _úti_, _зуҳр, mpym, --, 
   {{0xcb04092f,0xdee460d1,0xab780023,0xddc4014b}},	//   نيون_, _шови, _ክንየው_, _абби, 
   {{0x290c0311,0x7e6001c3,0x00000000,0x00000000}},	//   ftea_, _ulmp, --, --, 
   {{0xd7f860d2,0xa3e060d3,0x6fd0000d,0x54780092}},	//   мун_, दरा_, _ढ्ँू, _ባለሱቅ_, 
   {{0xea000016,0xdcac0228,0x6b8c525e,0x60d400c0}},	//   _đấy_, _بۉت_, éngé, ipym, 
   {{0x786402e2,0x290c3b28,0xa3c4107c,0x38140014}},	//   _nòve, atea_, एशन_, ن٘کر, 
   {{0xcf900375,0x8a100014,0xb8c803d4,0x78640075}},	//   יטת_, _نِمت, _খং_, ткүз, 
   {{0x290c60d4,0x947404fb,0x2c084ca3,0xd944084c}},	//   ctea_, ندسا, _सामू_, _шеди, 
   {{0x49140bd9,0x767401d2,0x69dc0174,0x00000000}},	//   _סקול_, _әлиф, ðsev, --, 
   {{0xddc0013a,0x00000000,0x00000000,0x00000000}},	//   diož, --, --, --, 
   {{0x17d809bd,0xa5c00209,0x316801c6,0xd5b8011c}},	//   _দায়ি, _гөре, tzaz_, _осп_, 
   {{0x301460d5,0x05743f7b,0xf484020e,0x628400b5}},	// [6bd0] лдар, _پايد, _مادی, _djko, 
   {{0xc0580953,0x316805c7,0x846c0092,0x00000000}},	//   кіх_, rzaz_, _አቅሙን_, --, 
   {{0x290c05f5,0x2ef460d6,0x27f03df9,0x9ce800e5}},	//   ztea_, узер, ózni_, ہونے_, 
   {{0x765c60d7,0x7f94013e,0x7afc005b,0xdb0c01e1}},	//   nksy, шахх, _ärty, _ádùb, 
   {{0xc0c80022,0xbd540022,0x6fa401f9,0x6458007c}},	//   _аусе_, аҭтә, _करवू, ötig, 
   {{0xc1b8063b,0x05780092,0x00000000,0x00000000}},	//   _шлях_, _አንብብ_, --, --, 
   {{0x8e2400ee,0x765c143a,0x61f802d2,0x00000000}},	//   _ифад, kksy, _íbló, --, 
   {{0x290c60d8,0x2b480cf4,0xa9e4004b,0x6e9401e0}},	//   ttea_, ćac_, اګان, _сибу, 
   {{0x290c60d9,0x29185c17,0xb5e00154,0x17d80154}},	//   utea_, ïsa_, _ভাংচ, _দাড়ি, 
   {{0x290c60da,0x6d5860db,0x6cc40032,0xdb080419}},	//   rtea_, mywa, _айҡа, ťnás, 
   {{0x290c60dc,0xfc3060dd,0x6d582f05,0x00000000}},	//   stea_, _بحق_, lywa, --, 
   {{0x290c084c,0x00000000,0x00000000,0x00000000}},	//   ptea_, --, --, --, 
   {{0x6d5860de,0xa3f41064,0x00000000,0x00000000}},	//   nywa, лявш, --, --, 
   {{0xd1d836bc,0x6754036b,0x765c01bf,0xc1dc0709}},	//   ንዘብ_, _مخبر, aksy, बर्ग, 
   {{0x20540efb,0xe73800a8,0x638460df,0x23780214}},	//   қтар, _чей_, угва, رمرد_, 
   {{0x98a404a7,0x6614014f,0xdb080129,0x64a40b01}},	//   _proć_, _ubyk, énét, таҳа, 
   {{0xe4740276,0x00000000,0x00000000,0x00000000}},	// [6be0] _бунэ, --, --, --, 
   {{0x6d5860e0,0xf8c8004d,0x60d400c0,0x00000000}},	//   dywa, _hức_, rpym, --, 
   {{0x83a80dba,0xe124009d,0x00000000,0x00000000}},	//   _गरिआ, _өмни, --, --, 
   {{0x229c0227,0x60d400b5,0x6d58127b,0x5de431df}},	//   kïki_, ppym, fywa, ужда, 
   {{0xf8c80016,0x629460e1,0x61e400e2,0x9cf40c17}},	//   _mức_, moyo, _iekl, учеш, 
   {{0x61e460e2,0x629460e3,0xf8c80208,0x00000000}},	//   _hekl, loyo, _lức_, --, 
   {{0x60c460e4,0x2008009a,0x61e40790,0x62940175}},	//   _hukm, _icbi_, _kekl, ooyo, 
   {{0x61e4151c,0x6d580034,0x60c40724,0xf8c801fb}},	//   _jekl, bywa, _kukm, _nức_, 
   {{0x61e460e5,0x60c40309,0xd7e43981,0x6d580857}},	//   _mekl, _jukm, ліно, cywa, 
   {{0x61e460e6,0x60c460e7,0x629400d5,0xb8ec00dc}},	//   _lekl, _mukm, hoyo, _शं_, 
   {{0xf8c80016,0x60c460e8,0x629460e9,0x2c080406}},	//   _bức_, _lukm, koyo, _सातू_, 
   {{0x69dc008c,0x62940083,0xf8c80051,0x53440116}},	//   ðset, joyo, _cức_, ңхва, 
   {{0x55040953,0x629460ea,0x2498020b,0x4a7800c8}},	//   ычна, doyo, _bkpm_, _אראב, 
   {{0x61e40139,0x765c5fc3,0x200860eb,0xd324026b}},	//   _aekl, sksy, _ncbi_, льби, 
   {{0x61e460ec,0x6d580034,0xe7940014,0x28b80153}},	//   _bekl, zywa, _پاوک, _руцэ_, 
   {{0x60c460ed,0x6294019f,0x61e4020c,0xd8a405d9}},	//   _bukm, goyo, _cekl, _جهڙو_, 
   {{0x6d58035a,0x5184009d,0x00000000,0x00000000}},	// [6bf0] xywa, уува, --, --, 
   {{0x61e451a0,0xc10460ee,0x33740212,0x2c081431}},	//   _eekl, صومي, _вгор, _साधू_, 
   {{0x6d5860ef,0x61e460f0,0x62940d51,0x6458005b}},	//   wywa, _fekl, boyo, ötie, 
   {{0x6d5860f1,0x5224084c,0xf8c80051,0x00000000}},	//   tywa, _сфоа, _xức_, --, 
   {{0xebc400c7,0xa3d800bc,0x81dc00cc,0xc69400df}},	//   аӡеи, _ड्ड_, _ঠাচ_, זאף_, 
   {{0x6d5860f2,0x61e460f3,0xe184008e,0x00000000}},	//   rywa, _zekl, _төсе_, --, 
   {{0x6d5860f4,0x61e460f5,0xc5ec00fe,0x00000000}},	//   sywa, _yekl, কলতা_, --, 
   {{0x7f840491,0x6d5860f6,0xfeb800db,0x60c4013d}},	//   _الفن, pywa, _ماقت_, _yukm, 
   {{0x0d640801,0xa96860f7,0xe40800ac,0x60c449f0}},	//   _съвм, типа_, _çiçə, _xukm, 
   {{0xf8c807ae,0xa8542424,0x629460f8,0xe7380640}},	//   _sức_, ртиј, zoyo, вео_, 
   {{0x629460f9,0xbc680451,0x394800db,0x00000000}},	//   yoyo, _حملن_, _ەشىپ_, --, 
   {{0x249805b1,0x00000000,0x00000000,0x00000000}},	//   _skpm_, --, --, --, 
   {{0x64a41eaf,0x629460fa,0xf8c80051,0x00000000}},	//   иама, voyo, _vức_, --, 
   {{0x61e460fb,0x60c460fc,0x629404ba,0x1278069d}},	//   _sekl, _rukm, woyo, _ተለወጠ_, 
   {{0xf8c807ae,0x60c42b10,0x57f8011a,0xe4f00037}},	//   _tức_, _sukm, _סלקו, _अटकि_, 
   {{0xf8c8001e,0x232802a9,0xef400092,0x00000000}},	//   _hứa_, ноҳи_, _የሚያል, --, 
  
   {{0x629460fd,0x60b400c6,0x249805b1,0x6008466a}},	// [6c00] royo, لمرئ, _tkpm_, кнам_, 
   {{0x62945ad8,0x61e40472,0x291c01f7,0x60c4110c}},	//   soyo, _wekl, _mpwa_, _vukm, 
   {{0x61e460fe,0x629460ff,0xed5801ef,0x00000000}},	//   _tekl, poyo, _sfžp_, --, 
   {{0x60c46100,0x7afc6101,0xf8c801fb,0x2fd001a6}},	//   _tukm, _årti, _lứa_, _efzg_, 
   {{0x2fd001a6,0x3b8401e0,0x00000000,0x00000000}},	//   _ffzg_, әһег, --, --, 
   {{0x644c0399,0xd1b824ae,0xf8c80208,0x10a06102}},	//   njbi, _جاپا_, _nứa_, _миян, 
   {{0x7864180f,0x5fa80037,0xc5ec00eb,0x00000000}},	//   _nòva, _करिल, _কানা_, --, 
   {{0xdb2001a8,0x5cf41f39,0x00000000,0x00000000}},	//   _þríf, _вяжу, --, --, 
   {{0x38c86103,0x00000000,0x00000000,0x00000000}},	//   دابی_, --, --, --, 
   {{0xdca40131,0xefe402d3,0xf8c80208,0xd8380022}},	//   _тази, _ምስዚ_, _cứa_, тэи_, 
   {{0xdd94052f,0xf8c8004d,0x103400d9,0x5ad000e5}},	//   _саҡы, _dứa_, בטים_, _بےبا, 
   {{0x4b78008f,0x00000000,0x00000000,0x00000000}},	//   _באבו, --, --, --, 
   {{0xa9c46104,0xa3e000cd,0x00000000,0x00000000}},	//   _ازمو, दरं_, --, --, 
   {{0x52d8009e,0x644c0175,0x00000000,0x00000000}},	//   _বটবৃ, gjbi, --, --, 
   {{0xd6840022,0x2c080b72,0x92b400ae,0x00000000}},	//   _вупп, _सासू_, لحرا, --, 
   {{0x3a240165,0x00000000,0x00000000,0x00000000}},	//   nemp_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [6c10] --, --, --, --, 
   {{0x752c6105,0xf48403e6,0xada40032,0x3a246106}},	//   _isaz, _دابی, ҙалл, hemp_, 
   {{0x05745d95,0xe7f815c0,0x3a2401ef,0x00000000}},	//   _هاید, ूलता_, kemp_, --, 
   {{0xfe701410,0x3a246107,0x2c080027,0x00000000}},	//   ودن_, jemp_, _साहू_, --, 
   {{0xa5d800c8,0x3a240af9,0x3208127b,0xdb4c01d9}},	//   אַצי, demp_, mgay_, ہَو_, 
   {{0xa3bc1b37,0x752c0161,0x320814dc,0x3ce40549}},	//   ुँच_, _msaz, lgay_, _dwmv_, 
   {{0x3a240156,0xf8c80208,0x788000d0,0x32082fb2}},	//   femp_, _rứa_, závä, ogay_, 
   {{0xdb180548,0x2d8c0218,0x752c6108,0xf8c8004d}},	//   _aftó, _txee_, _osaz, _sứa_, 
   {{0xe9386109,0x752c04ba,0x6f0401fa,0x32080009}},	//   اسبت_, _nsaz, luhc, igay_, 
   {{0x78640268,0x25a4025c,0x32080857,0xe72801c6}},	//   _pòva, _ġol_, hgay_, гоод_, 
   {{0x2bdc610a,0x752c610b,0xdd04509e,0x25a4610c}},	//   _न्या, _asaz, _köşe, _šol_, 
   {{0xa3d80490,0xfa3400ec,0x00000000,0x00000000}},	//   डुन_, _ورند, --, --, 
   {{0x320814dc,0x1e3800c8,0x291c009f,0x9860001f}},	//   dgay_, אגרא, _upwa_, ዴሬሽኑ_, 
   {{0x32080d62,0x644c0369,0x7d0400a3,0x5d78010f}},	//   egay_, ujbi, àisi, אָלנ, 
   {{0x752c1cdf,0x6ec40024,0x86b401ec,0x32080857}},	//   _esaz, _kėbu, _мәмі, fgay_, 
   {{0x57540375,0x3208610d,0xfbac0027,0xa1c40064}},	//   _לבצע_, ggay_, टेटम, сбад, 
   {{0x20c821e7,0x16840133,0x00000000,0x00000000}},	// [6c20] ابري_, _داوێ, --, --, 
   {{0x4fe422dc,0x3a24030a,0x3208610e,0xf1a8007b}},	//   ймун_, zemp_, agay_, شاقه_, 
   {{0x4444610f,0x32081c06,0xd3f001e2,0x00000000}},	//   _in_, bgay_, _ژړېد, --, 
   {{0x44446110,0x6ee410fe,0x2240013e,0x3208127b}},	//   _hn_, تسكل, _unkk_, cgay_, 
   {{0x44446111,0xfff86112,0x5fa800af,0xdd0405d1}},	//   _kn_, _نکات_, _करवल, _döşe, 
   {{0x55b800d9,0x00000000,0x00000000,0x00000000}},	//   אמנו, --, --, --, 
   {{0x907800c8,0x3a246113,0x4c100132,0x89f40372}},	//   _עטלי, temp_, سبوس, ڭعىز_, 
   {{0x78d402e8,0x3e880139,0x00000000,0x00000000}},	//   ожих, _тибү_, --, --, 
   {{0x44446114,0x3a246115,0x00000000,0x00000000}},	//   _on_, remp_, --, --, 
   {{0x44446116,0x49702de5,0xfc640214,0x387808c2}},	//   _nn_, ялыс, _بخری, òrr_, 
   {{0x32080c8c,0x752c0a49,0xdd1000e2,0xda08007b}},	//   ygay_, _ssaz, kļūt, _مياه_, 
   {{0x44446117,0x32086118,0x00000000,0x00000000}},	//   _an_, xgay_, --, --, 
   {{0x37c40131,0xc9806119,0x320803ac,0x00000000}},	//   _мәнб, _нуши, vgay_, --, 
   {{0x94844478,0x200c004e,0x3208611a,0xd99400e5}},	//   сымд, òfil_, wgay_, _پنڈت_, 
   {{0x4444611b,0xf778031c,0x3208127b,0x00000000}},	//   _dn_, bbħa_, tgay_, --, 
   {{0x720447ca,0x752c611c,0x1db81a2a,0x46140050}},	//   تورم, _tsaz, ेशात, _ٹوٝر, 
   {{0x3208611d,0xf434084c,0x8fc4453c,0x0fe000db}},	// [6c30] rgay_, _депэ, مزان, зөбү, 
   {{0x4444611e,0x320814dc,0x6f040455,0x00000000}},	//   _gn_, sgay_, tuhc, --, 
   {{0xb4b42c35,0x4ea4611f,0x1ee84689,0xff040006}},	//   जगी_, брда, لولی_, зячн, 
   {{0xa3ac1533,0xf8c8590f,0x44440f85,0x6f04022e}},	//   _औरत_, रदाय, _zn_, ruhc, 
   {{0x44446120,0xccf80640,0x00000000,0x00000000}},	//   _yn_, уће_, --, --, 
   {{0xeb0800db,0x6adc03d4,0x628808ce,0x3ce00022}},	//   لقتى_, _যিবো, _ífor, ãiva_, 
   {{0xdd040724,0xaa4806ed,0x7f581cd9,0x00000000}},	//   _töşe, ипка_, _ларс_, --, 
   {{0x3ce00276,0xbd880116,0x00000000,0x00000000}},	//   ţiva_, جنۇن_, --, --, 
   {{0xab780092,0xe8c80798,0x00000000,0x00000000}},	//   _እንዲል_, јгол_, --, --, 
   {{0x386c010a,0x00000000,0x00000000,0x00000000}},	//   ghdr_, --, --, --, 
   {{0x69d46121,0x28a400cf,0x00000000,0x00000000}},	//   _джеф, йшүг, --, --, 
   {{0x3cf01533,0x9f480261,0xe5a46122,0xe9180212}},	//   ुंचे_, _bebê_, жими, _воді_, 
   {{0x1c1c0034,0x2a6c0561,0xc984009d,0x00000000}},	//   _मॉडल_, mheb_, _уужи, --, 
   {{0x66e40b96,0xe738055f,0x44446123,0x00000000}},	//   _дока, _век_, _qn_, --, 
   {{0x44446124,0x23280c59,0xe27802e8,0xe794029e}},	//   _vn_, шови_, ащаш_, _باشک, 
   {{0x44440f85,0x863402f2,0xf4d800cc,0x00000000}},	//   _wn_, _رببڕ, _তিৰব, --, 
   {{0x64b00055,0x44440f85,0xdfe80de7,0x00000000}},	// [6c40] _aśiś, _tn_, идад_, --, 
   {{0xc0bc001f,0x33200175,0x00000000,0x00000000}},	//   ታችሁ_, _fphx_, --, --, 
   {{0x5f286125,0xd00c0592,0xddc00118,0xcf8c0014}},	//   роем_, ضلن_, dhoš, نژِ_, 
   {{0x61446126,0xf3f001fb,0x00000000,0x00000000}},	//   _дема, ực_, --, --, 
   {{0x0dc40032,0x2a6c04ba,0x2250010e,0x00000000}},	//   әләй_, dheb_, mjyk_, --, 
   {{0xdee455ee,0xa0686127,0xdc280bce,0x79600248}},	//   _моги, _тага_, شسته_, _láwú, 
   {{0x8fa04c87,0xcb640063,0x00000000,0x00000000}},	//   _жаре, жаје_, --, --, 
   {{0x0ab0007b,0x2250010b,0x00000000,0x00000000}},	//   وحيد, njyk_, --, --, 
   {{0x98486128,0x4284001f,0x4b8400ee,0x69dc0165}},	//   аяна_, _የጥናት_, ййән_, ñsea, 
   {{0xdecc0020,0xdb4c0133,0xfce459d9,0x48140108}},	//   _ብለን_, _لێت_, _моғо, ожью_, 
   {{0x7bc86129,0xd59800b5,0x386c0334,0x00000000}},	//   _igdu, zeい_, rhdr_, --, 
   {{0x6458612a,0x8f980375,0x6280002e,0x2a6c015d}},	//   ötin, שיטי, _ňoon, cheb_, 
   {{0xae0c033f,0xada0032e,0x00000000,0x00000000}},	//   _हासन_, _óútg, --, --, 
   {{0x2bdc0303,0x00000000,0x00000000,0x00000000}},	//   नुपा, --, --, --, 
   {{0x2120020b,0x870400d8,0x00000000,0x00000000}},	//   _apkh_, _дејв_, --, --, 
   {{0xc8fc03d4,0x00000000,0x00000000,0x00000000}},	//   ্বৰত_, --, --, --, 
   {{0x1ad400bd,0x00000000,0x00000000,0x00000000}},	// [6c50] সওয়া, --, --, --, 
   {{0x357c044e,0x2a6c612b,0x7bc8612c,0x00000000}},	//   _ኣስታት_, zheb_, _ngdu, --, 
   {{0x408408da,0xf2c4009d,0x00000000,0x00000000}},	//   футб, _хөги, --, --, 
   {{0x7bc8011f,0x2a6c612d,0x8d74612e,0xbe880395}},	//   _agdu, xheb_, ياشا, осче_, 
   {{0x61e0612f,0x00000000,0x00000000,0x00000000}},	//   ñole, --, --, --, 
   {{0xf07400e5,0x00000000,0x00000000,0x00000000}},	//   _عیاں_, --, --, --, 
   {{0xb0d001f9,0x00000000,0x00000000,0x00000000}},	//   _थंडग, --, --, --, 
   {{0xc94021f3,0xadbc0153,0x00000000,0x00000000}},	//   ддиқ, _бабi, --, --, 
   {{0x387c067c,0x7d0401c3,0xcd3401f7,0x2f146130}},	//   _bmvr_, àist, _برزب, låg_, 
   {{0x9f480b81,0x7aec00ae,0x46cc000d,0x00000000}},	//   _bebè_, últó, _संदह, --, 
   {{0xf99003e6,0xdbc40254,0x00000000,0x00000000}},	//   _یبه_, tööo, --, --, 
   {{0xbb84007b,0x00000000,0x00000000,0x00000000}},	//   _تلمي, --, --, --, 
   {{0x753401c0,0x00000000,0x00000000,0x00000000}},	//   мэрх, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe2a80531,0x2bdc00dc,0x5fa8000d,0x998400fb}},	//   مارن_, नुया, _करइल, _мтәһ, 
   {{0x7afc00b5,0x22446131,0x61c400cd,0x00000000}},	//   _ærte, ñok_, वशेष, --, 
   {{0xdfd000c6,0xdb8c0023,0x00000000,0x00000000}},	// [6c60] فيذ_, _ዝዕድም_, --, --, 
   {{0x2bdc2435,0x071c2982,0xf3f00208,0x92d805ac}},	//   नुमा, _बहाव_, ựa_, _ডটৰ_, 
   {{0xe2986132,0x44386133,0xd00c4c84,0x38b000a3}},	//   _ган_, mdr_, الم_, làrc_, 
   {{0xdb140118,0xc0d40023,0x6ec40064,0x8d940150}},	//   ícíh, ርማር_, _sėbr, _ﺘﺜﺒﺕ_, 
   {{0x2bdc0a94,0x941800ab,0xae0c00af,0x7c341219}},	//   _न्हा, _पॉँच_, _हारन_, делх, 
   {{0x9f4800d5,0x69dc030a,0xcca03769,0x00000000}},	//   _lebé_, ñsen, ىڭلى, --, 
   {{0xbf640a81,0xdee46134,0x4438015d,0x26d0010f}},	//   _تۯاو, _хоби, idr_, ŭzoj_, 
   {{0xed4c2832,0xdee4039b,0x44380334,0x8c400022}},	//   _چھو_, _моҳи, hdr_, мҵӡе, 
   {{0x9f480241,0xd8386135,0xbf1c0118,0x2bdc2c2e}},	//   _sebè_, бэн_, _नहुन_, _न्वा, 
   {{0x645802f6,0x60c000a3,0x36d46136,0x77941208}},	//   ötil, ìomh, моор, ویشا, 
   {{0x1fa80abd,0x9f486137,0xdb18032e,0x00000000}},	//   _करोड, _bebé_, _aftö, --, 
   {{0x7c38057b,0x00000000,0x00000000,0x00000000}},	//   ldvr, --, --, --, 
   {{0x4438009b,0x7c38017a,0x85440166,0x00000000}},	//   fdr_, odvr, нэре, --, 
   {{0x27e801dc,0x7c3827bb,0xf8c81d03,0xd7f800d8}},	//   _đang_, ndvr, रदीप, _ѓул_, 
   {{0x92686138,0xc5ec015b,0xc3480395,0x00000000}},	//   браа_, _কারা_, пяте_, --, 
   {{0x2f146139,0xd0440213,0x4438613a,0xe6d80345}},	//   våg_, əmət, adr_, _بدوڵ_, 
   {{0xd4983c58,0x4438613b,0x35b4084c,0xd34401b9}},	// [6c70] _грн_, bdr_, _юбир, _کیزه_, 
   {{0x2f140267,0x00000000,0x00000000,0x00000000}},	//   tåg_, --, --, --, 
   {{0x78a80083,0x00000000,0x00000000,0x00000000}},	//   ildv, --, --, --, 
   {{0x7c380b4f,0x21dc00b0,0xd164014b,0x00000000}},	//   edvr, tāhō_, _еъги, --, 
   {{0x2f1401e6,0x7c3801f5,0xfaf80171,0x00000000}},	//   såg_, fdvr, _avī_, --, 
   {{0x920000e2,0x7c3801f5,0x2f14007c,0x00000000}},	//   žādu, gdvr, påg_, --, 
   {{0xff040ec6,0x69dc030a,0x7f9401f0,0x00000000}},	//   _пятн, ñseo, _зарх, --, 
   {{0x21dc00b0,0x4438613c,0x00000000,0x00000000}},	//   pāhō_, zdr_, --, --, 
   {{0x4438613d,0x9f4800db,0x7c380175,0x95f0015b}},	//   ydr_, _rebé_, bdvr, ঝলাম_, 
   {{0x68ec003d,0x8b6401ed,0x7d0400ae,0x00000000}},	//   _ħadd, _ٹائم, áise, --, 
   {{0x4438002f,0x00000000,0x00000000,0x00000000}},	//   vdr_, --, --, --, 
   {{0x28d401ad,0x6f0400a3,0x4438015d,0x00000000}},	//   _डंपि, irhc, wdr_, --, 
   {{0x6aa8613e,0x00000000,0x00000000,0x00000000}},	//   mlef, --, --, --, 
   {{0x6aa8613f,0x25dc02c3,0xa3486140,0x3d00000d}},	//   llef, _क्री_, озга_, _रिसे_, 
   {{0x6aa80421,0x4438005c,0xa6940640,0x62586141}},	//   olef, rdr_, _ориј, орар_, 
   {{0x6aa8010a,0x61440107,0x2d0c07f7,0x00000000}},	//   nlef, меба, _समूल_, --, 
   {{0x9ff8007b,0x15f8011a,0x6aa802d0,0x00000000}},	// [6c80] قراء_, _והפע, ilef, --, 
   {{0xf4040183,0x6aa8002f,0x00000000,0x00000000}},	//   শ্বৰ_, hlef, --, --, 
   {{0x69d86142,0x82e8025c,0xe298030d,0x00000000}},	//   _ofwe, _འཆིའ, _мао_, --, 
   {{0x69dc0156,0x6aa801bf,0xdee40023,0xa0200037}},	//   ñsel, jlef, _ዝብኢ_, ööbl, 
   {{0x38b00022,0x6aa86143,0xfaf800b8,0x68fc0332}},	//   hàra_, dlef, _svī_, ásdl, 
   {{0x69d82779,0x80a802f5,0x5f04035b,0x6aa86144}},	//   _afwe, _কংক্, _озга, elef, 
   {{0x2ea801d3,0x7c38017a,0x00000000,0x00000000}},	//   _کھلی_, rdvr, --, --, 
   {{0x99640108,0x00000000,0x00000000,0x00000000}},	//   дтол, --, --, --, 
   {{0x98043004,0x88b0036b,0x00000000,0x00000000}},	//   мянд, چینچ, --, --, 
   {{0x0c206145,0x38b00109,0x6aa803cd,0x2bdc043e}},	//   _имун, fàra_, alef, नुदा, 
   {{0x6aa84df6,0x25b005d6,0x6d4400b0,0x2d98005c}},	//   blef, _azyl_, āhae, _øser_, 
   {{0x6aa86146,0x7864004e,0x00000000,0x00000000}},	//   clef, _mòvi, --, --, 
   {{0xe9700014,0xebc001e0,0xf674009d,0x00000000}},	//   _مۆٹھ, _иҙән, _үглэ, --, 
   {{0x62880cad,0x00000000,0x00000000,0x00000000}},	//   _ìfoj, --, --, --, 
   {{0x3d082871,0x786400cf,0xd2586147,0x2bc001bc}},	//   _समझे_, _nòvi, оца_, षेपा, 
   {{0x80a802a6,0x46a400c7,0xcb3400d9,0x00000000}},	//   _কংগ্, _ишыб, ואלי_, --, 
   {{0x61e009ff,0xd1b86148,0x4a58011a,0xd498034f}},	// [6c90] ñola, زارا_, קדמו, _мро_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb9000327,0x860804f2,0x00000000,0x00000000}},	//   _ཧཕ_, _عقیق_, --, --, 
   {{0x6aa80170,0x7864007f,0x37c000fe,0x00000000}},	//   xlef, _dòvi, _এভাৰ, --, 
   {{0x38b00109,0x6aa86149,0xcd280633,0x00000000}},	//   zàra_, vlef, تسان_, --, 
   {{0x6aa80334,0x00000000,0x00000000,0x00000000}},	//   wlef, --, --, --, 
   {{0x3ea40270,0x6aa8614a,0xf8c80208,0x00000000}},	//   _fkmt_, tlef, _gứi_, --, 
   {{0x6aa80421,0xea944b00,0x7d040332,0x00000000}},	//   ulef, эшлэ, áisc, --, 
   {{0x6aa8010a,0xac940022,0x9f4801e1,0xaa4400ee}},	//   rlef, _зааш, _lebì_, _җелл, 
   {{0x6aa8614b,0x3d9400c7,0xfd000137,0x0cc800bc}},	//   slef, _риур, _түшп, ादीम, 
   {{0x6aa8030d,0x69d800d2,0x7c840395,0xe7a80229}},	//   plef, _tfwe, _руте, явол_, 
   {{0xfd6400b8,0x00000000,0x00000000,0x00000000}},	//   _apuṇ, --, --, --, 
   {{0x95b40166,0x00000000,0x00000000,0x00000000}},	//   еррә, --, --, --, 
   {{0x6c78010f,0x38b00022,0x00000000,0x00000000}},	//   לאָפ, pàra_, --, --, 
   {{0x290c0bba,0xb4c40032,0xe68801ec,0x64a42b95}},	//   luea_, тирҙ, _ىنتى_, _җана, 
   {{0xe0d8614c,0x09c000bd,0x3d001d8a,0x00000000}},	//   зва_, _এ্যা, _रिले_, --, 
   {{0xc33004a9,0xd12c01d3,0x00000000,0x00000000}},	// [6ca0] _ھەر_, یمہ_, --, --, 
   {{0x6564003b,0x00000000,0x00000000,0x00000000}},	//   mykh, --, --, --, 
   {{0xdd903ee6,0x6564614d,0x290c00d8,0x00000000}},	//   گوش_, lykh, huea_, --, 
   {{0xe2981d18,0x2bdc37cc,0x35a42aa1,0x290c0618}},	//   _хам_, नुसा, _गुड़, kuea_, 
   {{0xdd90614e,0x61f4614f,0xfc380588,0x0dc46150}},	//   دوش_, mayl, мҭа_, нуши_, 
   {{0x61f46151,0x645c6152,0x3d20547d,0x00000000}},	//   layl, _jopi, _यहीं_, --, 
   {{0x645c6153,0x00000000,0x00000000,0x00000000}},	//   _mopi, --, --, --, 
   {{0x645c2d5b,0x61f46154,0x8fa000f3,0xefd40023}},	//   _lopi, nayl, _сасе, ርዋይ_, 
   {{0x645c6155,0x00000000,0x00000000,0x00000000}},	//   _oopi, --, --, --, 
   {{0x645c00da,0x92c80eac,0x49706156,0x661400a2}},	//   _nopi, রীয়_, ульс, _acyk, 
   {{0x61f46157,0xfb180014,0xd1d402d3,0x97a4084c}},	//   kayl, _زراں_, ርራብ_, эрил, 
   {{0x61f401f4,0x62880248,0x00000000,0x00000000}},	//   jayl, _ìfoh, --, --, 
   {{0x645c0b58,0x61f46158,0x2bdc44af,0x27f804cc}},	//   _bopi, dayl, नुवा, ögnà_, 
   {{0x645c6159,0x61f40363,0x00000000,0x00000000}},	//   _copi, eayl, --, --, 
   {{0x083805e1,0x43942424,0x61f407d6,0x8838011a}},	//   _מעגל, гарс, fayl, _מתגו, 
   {{0x20d4032e,0x61f44f40,0xd5b8009b,0x00000000}},	//   _bæi_, gayl, _нсп_, --, 
   {{0x764c615a,0x9f480789,0x645c0241,0xb4b400cf}},	// [6cb0] _inay, _debí_, _fopi, _ийиш, 
   {{0x645c615b,0xed5004fb,0xc10416a2,0x00000000}},	//   _gopi, یپا_, اولي, --, 
   {{0x61f4615c,0x69dc0165,0xa0200254,0x00000000}},	//   bayl, ñsek, ööal, --, 
   {{0xa2d40d5f,0x645c0bd7,0x61f401d9,0x20d403b2}},	//   _मंत्, _zopi, cayl, _fæi_, 
   {{0x645c615d,0x764c00ec,0x0cc8000d,0x20d402d2}},	//   _yopi, _mnay, ादेम, _gæi_, 
   {{0xc4d4008f,0x645c615e,0xab2800f3,0x00000000}},	//   אגס_, _xopi, дока_, --, 
   {{0x764c615f,0x6458005b,0x0094013d,0xebc40022}},	//   _onay, ötii, _сирэ, тәан, 
   {{0x764c6160,0xa9246161,0xa9a46162,0xde441b2c}},	//   _nnay, вдил, кийд, _لیمو_, 
   {{0x3d9457c6,0xb7e800cc,0x00000000,0x00000000}},	//   _битр, _খাজত_, --, --, 
   {{0x764c6163,0xb81c216a,0x2bdc00cd,0x61f46164}},	//   _anay, ब्लम_, नुशा, zayl, 
   {{0x764c0198,0x61f46165,0x4ae401a9,0x00000000}},	//   _bnay, yayl, _чўза, --, 
   {{0x645c6166,0x290c0618,0x38b00241,0x00000000}},	//   _sopi, puea_, bàro_, --, 
   {{0x645c6167,0xba746168,0x290c2b76,0xb4d401e1}},	//   _popi, _حالت, quea_, _ìṣeọ, 
   {{0x232800d6,0x645c6169,0x764c5b88,0x61f402d1}},	//   моги_, _qopi, _enay, wayl, 
   {{0xf8c807ae,0x61f40365,0x8880021a,0x645c616a}},	//   _cứu_, tayl, _لیکن, _vopi, 
   {{0x645c0bd7,0x764c00b8,0x60d40334,0x3ce00356}},	//   _wopi, _gnay, tqym, ţivi_, 
   {{0x645c616b,0x61f4616c,0x779008dc,0xd5ac007b}},	// [6cc0] _topi, rayl, _نییا, _وفى_, 
   {{0x61f4616d,0x25dc10fa,0x65f00037,0x764c0139}},	//   sayl, कुरी_, _अजुए_, _znay, 
   {{0x764c01b9,0xa2e409a5,0x27f000d0,0x61f4616e}},	//   _ynay, _шонд, ózny_, payl, 
   {{0x2a0401f2,0x61f4616f,0x7eb800e4,0x21680798}},	//   ịaji_, qayl, kípe, _жими_, 
   {{0x2b440142,0x00000000,0x00000000,0x00000000}},	//   _arlc_, --, --, --, 
   {{0x2bdc00bc,0x00000000,0x00000000,0x00000000}},	//   नुला, --, --, --, 
   {{0x705004d3,0xf8c8004d,0x6dc415bf,0x00000000}},	//   _دۆلا, _mứt_, نزۇل, --, 
   {{0xc214043b,0x2bc007b7,0xf8c80208,0xb7d805af}},	//   ngɔ_, षेधा, _lứt_, کودا_, 
   {{0x7e600597,0x764c0113,0x4a500661,0xf778031c}},	//   _iomp, _rnay, ркыс, laħx_, 
   {{0x7e606170,0xf8c801fb,0x764c427b,0x8c406171}},	//   _homp, _nứt_, _snay, _кеуе, 
   {{0x78b80109,0x2ba8000d,0x62880241,0x00000000}},	//   _vhvv, _चुपा, _ìfow, --, 
   {{0x7e606172,0x5984506f,0x25dc6173,0xda6400c7}},	//   _jomp, _илеб, कुली_, _швеи, 
   {{0x39400491,0x7e606174,0xd1d402d3,0xf8c8004d}},	//   _éis_, _momp, ርካብ_, _bứt_, 
   {{0x7e606175,0xba08001f,0x94843d5e,0xf8c80208}},	//   _lomp, _ጋራ_, тымд, _cứt_, 
   {{0x81e403f4,0xf8c8001e,0x7e606176,0x290000b0}},	//   _নয়_, _dứt_, _oomp, _āhai_, 
   {{0x7e606177,0xd5640124,0x764c6178,0x31346179}},	//   _nomp, _атоп, _unay, лебр, 
   {{0x2ba8084a,0x69dc030a,0xd40401a9,0x00000000}},	// [6cd0] _चुना, ñsei, _ияни, --, 
   {{0x614404a9,0x7e6005da,0x8fc4617a,0x4ee41cd0}},	//   دىكە, _aomp, نزان, відз, 
   {{0x329401d9,0xd9f001f9,0x40340108,0x4fc4009d}},	//   _مٔدر, घरात_, рехс, тсаа, 
   {{0xacf8617b,0xc0e402d3,0x41e40816,0x00000000}},	//   енду_, _ዝህሉ_, _віра, --, 
   {{0x7e60617c,0x867c0375,0x00000000,0x00000000}},	//   _domp, וראו, --, --, 
   {{0x26180c2e,0x7e60003a,0xf7780327,0xbbe800f2}},	//   _भाभी_, _eomp, baħx_, پروم_, 
   {{0x7e6000e8,0xc914037e,0xbfa8010a,0x00000000}},	//   _fomp, _sマ_, _атте_, --, 
   {{0x7e60617d,0x2ec404f0,0x00000000,0x00000000}},	//   _gomp, _сөзм, --, --, 
   {{0x3168083a,0xe8c8617e,0x00000000,0x00000000}},	//   nyaz_, нгил_, --, --, 
   {{0x7e600173,0xead4005b,0x920000cd,0x00000000}},	//   _zomp, _божь, _śāli, --, 
   {{0x6adc1c82,0x7cf801d3,0xf8c80208,0xdb244c8b}},	//   _যিকো, _túrá, _rứt_, _مولی, 
   {{0xa5085111,0xddc000e2,0xf8c80208,0x00000000}},	//   нема_, lkoš, _sứt_, --, 
   {{0x31680369,0x2618000d,0x46cc000d,0x00000000}},	//   jyaz_, _भाठी_, _संकह, --, 
   {{0x26d0617f,0x21a401f0,0x00000000,0x00000000}},	//   ízos_, ҳибм, --, --, 
   {{0xa7a86180,0xf8c801fb,0xe6440137,0xe2b80063}},	//   _якка_, _vứt_, _бейп, ећај_, 
   {{0x2a6c031c,0x26d00115,0x232801f0,0x90841171}},	//   nkeb_, ŭzos_, моҳи_, ҳбуб_, 
   {{0x60240323,0x31680354,0x00000000,0x00000000}},	// [6ce0] лдаа, gyaz_, --, --, 
   {{0x7e606181,0xc5ec015b,0x2a6c000d,0xf7780327}},	//   _somp, _কাটা_, hkeb_, taħx_, 
   {{0x141800c8,0xe2c86182,0xf778031c,0x33f4004e}},	//   _אויב, _плод_, bbħu_, _тчыс, 
   {{0xddc0005f,0x68ec025c,0x7e60013d,0x3168013d}},	//   ekoš, _ħadn, _qomp, byaz_, 
   {{0x6284006c,0x291c01e2,0x7e600ffb,0x1278010f}},	//   _imko, _nqwa_, _vomp, _טאטע, 
   {{0x7e606183,0x2a6c025c,0xec740022,0x57d0000d}},	//   _womp, ekeb_, аҿу_, _सलेह, 
   {{0x7e60325f,0x291c003d,0xcb0405d9,0x46cc00c5}},	//   _tomp, _aqwa_, هيون_, _संगह, 
   {{0x60cc002d,0x2a6c020c,0x00000000,0x00000000}},	//   _hibm, gkeb_, --, --, 
   {{0xd9440592,0x38346184,0x2d9400f3,0x00000000}},	//   ائبي, анпр, _крфс, --, 
   {{0xb8dc05d7,0xfe1400ab,0x4d6001b9,0x6a7416d9}},	//   _आठ_, _डाँस_, _укув, _ráfe, 
   {{0x62841347,0x9f480085,0x1ae40139,0xdb1800a2}},	//   _omko, _yebá_, _соем, _ygtý, 
   {{0x60cc01a9,0xa14400de,0xf778025c,0x31680205}},	//   _libm, _kaķē, xbħu_, yyaz_, 
   {{0x291c014b,0xa2b800dc,0xd404003b,0x26d000d7}},	//   _gqwa_, ्षन्, ляви, ízor_, 
   {{0x62840656,0x8288013e,0x73c400fb,0x00000000}},	//   _amko, ҳсуб_, иәне, --, 
   {{0xfe140c2e,0x7d00035a,0x506401ec,0x13a405af}},	//   _डांस_, _lvms, қтаа, انزی_, 
   {{0xddc06185,0x92b41622,0x562000cc,0x00000000}},	//   zkoš, احسا, _বোৰক_, --, 
   {{0x9484052f,0xf48434c9,0xaf400020,0x7c286041}},	// [6cf0] _бынд, _نادی, _የሚመለ, _obdr, 
   {{0x752c011c,0x31681529,0xa3680139,0xcf981fbe}},	//   _ipaz, ryaz_, _igеn, нје_, 
   {{0x60cc014f,0x2dd42218,0xcf9800d8,0x00000000}},	//   _dibm, ажер, хја_, --, 
   {{0x7c286186,0x60cc002f,0x00000000,0x00000000}},	//   _abdr, _eibm, --, --, 
   {{0xddc02375,0xd16400a7,0x067c010f,0x00000000}},	//   tkoš, _съни, ענדל, --, 
   {{0x6b646187,0x66e00374,0x752c6188,0x04dc00df}},	//   икла, _hēke, _mpaz, עקול, 
   {{0x7c286189,0x66e0170b,0xe9d0007b,0x7b0c010b}},	//   _dbdr, _kēke, يغة_, _ỳurt, 
   {{0x752c0fb7,0x9b9000d1,0xa2b81546,0x00000000}},	//   _opaz, تلىت, ्षय्, --, 
   {{0x6e28618a,0x60cc01a9,0x2a6c618b,0x00000000}},	//   _ibeb, _yibm, rkeb_, --, 
   {{0x6d48618c,0x6d580117,0x7eb800e4,0x00000000}},	//   _irea, mxwa, mípa, --, 
   {{0x752c618d,0x6d48618e,0x9ad001f2,0xa36801a9}},	//   _apaz, _hrea, lịnd, _agеn, 
   {{0x6d48618f,0xf1c46190,0x66e00093,0x65c46191}},	//   _krea, वधान, _nēke, ибна, 
   {{0x6e286192,0x6d5811b0,0x26c00fac,0x6adc00fe}},	//   _mbeb, nxwa, rmko_, _যিটো, 
   {{0x18646193,0x6d480356,0xe2a83f32,0x66740066}},	//   _ваши_, _mrea, چارن_, ادگر, 
   {{0x68e86194,0x6e286195,0x60cc022e,0xe738011c}},	//   lped, _obeb, _ribm, _рей_, 
   {{0x6d486196,0x6d58009a,0x60cc6197,0x672001a6}},	//   _orea, kxwa, _sibm, mtlj, 
   {{0xa2d407b7,0x290c00db,0x645804cc,0x68e853ce}},	// [6d00] _मूर्, nrea_, ötis, nped, 
   {{0x6e286198,0x290c0276,0x68e80006,0x60cc014f}},	//   _abeb, irea_, iped, _qibm, 
   {{0xe2986199,0x6e280083,0x6d48619a,0x290c1594}},	//   _аан_, _bbeb, _area, hrea_, 
   {{0x6d48619b,0xa114619c,0x628401b3,0x290c005a}},	//   _brea, _پوست, _umko, krea_, 
   {{0x6294619d,0x6d58009a,0x2bb40051,0x5f0400c7}},	//   mnyo, gxwa, _ác_, узҵа, 
   {{0x6e28619e,0x23b81533,0x6d48619f,0x629400e5}},	//   _ebeb, _इराद, _drea, lnyo, 
   {{0x6d4861a0,0x2ba8068f,0x290c12cf,0x6294009f}},	//   _erea, _चुदा, erea_, onyo, 
   {{0x6d4861a1,0x62942f99,0x6e2801e1,0x290c005a}},	//   _frea, nnyo, _gbeb, frea_, 
   {{0x6d4861a2,0x290c61a3,0x629461a4,0x6d58035a}},	//   _grea, grea_, inyo, cxwa, 
   {{0x4c240014,0x67201876,0x00000000,0x00000000}},	//   _نظمہ, ftlj, --, --, 
   {{0x752c61a5,0xa2d41428,0x290c084c,0x1bb800dd}},	//   _spaz, _मूल्, area_, _شائع_, 
   {{0x290c61a6,0x629461a7,0x0a6414b7,0x68e8003a}},	//   brea_, jnyo, _врши_, bped, 
   {{0x290c61a8,0xdb4c04d3,0xc9800266,0x00000000}},	//   crea_, _رێک_, _муши, --, 
   {{0xd1d41540,0x78740014,0x6294198f,0x93942dd0}},	//   ርያት_, _دُتا, enyo, لجزا, 
   {{0x83f861a9,0x66e002b5,0x00000000,0x00000000}},	//   ресс_, _pēke, --, --, 
   {{0x78a861aa,0x629461ab,0x35f461ac,0x439400d4}},	//   lodv, gnyo, _упир, іатс, 
   {{0x66e00093,0x98b81f14,0x6d5803ac,0x00000000}},	// [6d10] _vēke, _उठाए, xxwa, --, 
   {{0x8650013f,0x629461ad,0x938861ae,0x6d4861af}},	//   _ahɔh, anyo, _асма_, _rrea, 
   {{0x035830cb,0x629461b0,0x6d480fa3,0xc0c856da}},	//   _күрә_, bnyo, _srea, руте_, 
   {{0x1ee82352,0x68e861b1,0x454407d6,0x7eb80113}},	//   اونی_, yped, _انیق, típa, 
   {{0x2c78007f,0x46d00118,0x78a800e5,0x00000000}},	//   _lède_, _संघह, kodv, --, 
   {{0x6d4861b2,0x68e8074d,0x290c4b54,0xf21c05f9}},	//   _vrea, vped, vrea_, _फाड़_, 
   {{0x6d4861b3,0x7f9461b4,0x6d5802d0,0x290c031c}},	//   _wrea, _дарх, sxwa, wrea_, 
   {{0x6e2861b5,0x6d4861b6,0x92c80c58,0x6da404fb}},	//   _ubeb, _trea, ৰীৰ_, _همزم, 
   {{0x8d7461b7,0xa2b861b8,0x6d481496,0x4c042073}},	//   _ئازا, ्षत्, _urea, _نظاف, 
   {{0x68e861b9,0x290c61ba,0xa8541677,0x4c14104c}},	//   rped, rrea_, стиј, _خبرس, 
   {{0xe94461bb,0xd1d4001f,0x290c00ca,0x2c7806af}},	//   _گرای, ርካታ_, srea_, _cède_, 
   {{0x68e861bc,0x15e000e1,0xcca000cf,0x290c61bd}},	//   pped, कुलर_, _اڭچى, prea_, 
   {{0xe94461be,0x78a800d2,0x672061bf,0x6aa80af9}},	//   _درای, bodv, stlj, moef, 
   {{0x38500023,0x00000000,0x00000000,0x00000000}},	//   _ክፈልጥ, --, --, --, 
   {{0xa2e401b9,0x9f580200,0x00000000,0x00000000}},	//   собд, rapë_, --, --, 
   {{0x569014b7,0x629461c0,0xe61800d8,0x00000000}},	//   _најт, unyo, _сди_, --, 
   {{0x629401ed,0x26d00009,0x00000000,0x00000000}},	// [6d20] rnyo, _iiyo_, --, --, 
   {{0x26d016cb,0x629461c1,0x6aa8225e,0xd1d40f7c}},	//   _hiyo_, snyo, hoef, ርያቱ_, 
   {{0x26d061c2,0xa2b816ae,0x4aa41d34,0x00000000}},	//   _kiyo_, ्षद्, खवाव, --, 
   {{0x26d002a8,0x9f5861c3,0xcf1801d9,0x6fa00150}},	//   _jiyo_, napé_, ارٕچ_, _ﻌﺒﻬﺎ_, 
   {{0x78a861c4,0x26d061c5,0x6d5c00d8,0xa3b801d3}},	//   yodv, _miyo_, _àsal, _جاکر_, 
   {{0x6a740789,0x26d061c6,0x224061c7,0x9f5800e4}},	//   _ráfa, _liyo_, _hakk_, hapé_, 
   {{0x26d0020c,0x6aa861c8,0x9f580066,0x22400254}},	//   _oiyo_, foef, kapé_, _kakk_, 
   {{0x26181e61,0x6aa8017a,0x224034c5,0x6a7408a5}},	//   _भाषी_, goef, _jakk_, _páfa, 
   {{0x224061c9,0xd7f861ca,0x9f58617f,0xd83c0419}},	//   _makk_, лун_, dapé_, účom_, 
   {{0x224061cb,0x96e861cc,0x26d00009,0x81cc0183}},	//   _lakk_, льма_, _aiyo_, _ৰজা_, 
   {{0x26d061cd,0x6aa80072,0x7eb80393,0xf77000f1}},	//   _biyo_, boef, nípo, ګاښ_, 
   {{0x26d061ce,0x2c78026c,0x22400de2,0x8f9802e4}},	//   _ciyo_, _vède_, _nakk_, ריטי, 
   {{0x26183eaf,0x26d00978,0xb90c00e4,0x78a861cf}},	//   _भारी_, _diyo_, hyhẽ_, podv, 
   {{0x629861d0,0x3ce0000d,0x3b94030d,0x693001c8}},	//   éton, _ओंने_, _улçӳ, _آکير, 
   {{0x26d000ca,0x224061d1,0x00000000,0x00000000}},	//   _fiyo_, _bakk_, --, --, 
   {{0x9f5861d2,0x00000000,0x00000000,0x00000000}},	//   capé_, --, --, --, 
   {{0x22400de2,0x00000000,0x00000000,0x00000000}},	// [6d30] _dakk_, --, --, --, 
   {{0x741461d3,0x26d001b9,0x6aa801f7,0x321c0210}},	//   _بودا, _ziyo_, zoef, żwy_, 
   {{0x26d061d4,0x224061d5,0xfe7000f2,0x00000000}},	//   _yiyo_, _fakk_, کدل_, --, 
   {{0x66e0005f,0x224061d6,0x00000000,0x00000000}},	//   _jēka, _gakk_, --, --, 
   {{0xed5861d7,0xa24401d9,0xf1c461d8,0xfeb80633}},	//   рол_, _بیقل_, लेशन, حالت_, 
   {{0x6d5c0241,0x00000000,0x00000000,0x00000000}},	//   _àsam, --, --, --, 
   {{0x6aa861d9,0x261800ab,0x224061da,0x4fc43004}},	//   toef, _भाली_, _yakk_, _ысма, 
   {{0xe9d861db,0x5c70070e,0x2bdc4ead,0x00000000}},	//   шки_, зләт, नुजा, --, 
   {{0x2ba80882,0x6aa80430,0x26d061dc,0x6a7402d2}},	//   _चुरा, roef, _riyo_, _fáfn, 
   {{0x26d061dd,0x6aa80b4f,0x6a74032e,0x00000000}},	//   _siyo_, soef, _gáfn, --, 
   {{0x7ae80048,0x26d061de,0x9f58004e,0x00000000}},	//   _gtdt, _piyo_, tapé_, --, 
   {{0x26d001a9,0x00000000,0x00000000,0x00000000}},	//   _qiyo_, --, --, --, 
   {{0x224061df,0x9f5861e0,0xdb1861e1,0x26d0014b}},	//   _rakk_, rapé_, _aztè, _viyo_, 
   {{0x224061e2,0x7d040597,0x26d000ca,0x68ec031c}},	//   _sakk_, áisi, _wiyo_, _ħadh, 
   {{0x224061e3,0x26d04e35,0x290c06c8,0x4a240135}},	//   _pakk_, _tiyo_, ̄lā_, _རྡོལ_, 
   {{0xef54001f,0x00000000,0x00000000,0x00000000}},	//   _የሚያግ, --, --, --, 
   {{0x15e000ab,0x6a740241,0x00000000,0x00000000}},	// [6d40] _क्टर_, _láfo, --, --, 
   {{0x1fb402bf,0xdf743004,0xe3b0007b,0x48f8000d}},	//   осер, يداب, _يرد_, लीयो_, 
   {{0xe820068f,0xc294221d,0x00000000,0x00000000}},	//   _माना_, _فیسب, --, --, 
   {{0x444461e4,0x7eb801ef,0x00000000,0x00000000}},	//   _ha_, cípl, --, --, 
   {{0x4a240135,0x44380204,0x8cf00953,0x1ee8036b}},	//   _རྡེལ_, oer_, дзіц, اوچی_, 
   {{0x444461e5,0x00000000,0x00000000,0x00000000}},	//   _ja_, --, --, --, 
   {{0x443861e6,0xda780364,0x57e001ec,0x6a7400e5}},	//   ier_, ияи_, _ﺍﺯﯨﺮ, _cáfo, 
   {{0xda6461e7,0x00000000,0x00000000,0x00000000}},	//   تاتي, --, --, --, 
   {{0x444461e8,0x9d440137,0xdd7000e5,0x00000000}},	//   _oa_, _بئزن, _تھاک, --, 
   {{0x443861e9,0x6a740413,0xfbcc00eb,0x00000000}},	//   jer_, _fáfo, রুষত, --, 
   {{0x66e002b5,0xbfdc037e,0xcc840133,0x42840092}},	//   _pēka, _ray第_, _بچنه_, _ከጥንት_, 
   {{0x444461ea,0x7c3861eb,0x443861ec,0x2c7804cc}},	//   _aa_, levr, eer_, _ièda_, 
   {{0x443861ed,0x200801fa,0x1dc83806,0x00000000}},	//   fer_, _odbi_, िधित, --, 
   {{0x444461ee,0x8650013f,0xe82061ef,0x61e461f0}},	//   _ca_, _nkɔf, _माया_, _afkl, 
   {{0x33540137,0x68ec0003,0x00000000,0x00000000}},	//   чүнө_, _ħadi, --, --, 
   {{0x444461f1,0x8650013f,0x1dc861f2,0x44380158}},	//   _ea_, _akɔf, िधात, aer_, 
   {{0xe8201b57,0x1428063b,0x7c3861f3,0x0fe0004e}},	// [6d50] _मामा_, _кіно_, kevr, дөбү, 
   {{0x7c380b91,0x10142586,0x00000000,0x00000000}},	//   jevr, تبرد, --, --, 
   {{0x1ee861f4,0x4ea461f5,0xd34401b9,0xa2b807b7}},	//   مولی_, орда, _بیزه_, ्षश्, 
   {{0x51840323,0x72a40014,0x74141888,0x6a7400e5}},	//   _дуга, _ژٕھن, _بوگا, _ráfo, 
   {{0x7c38205e,0xa2c00139,0x00000000,0x00000000}},	//   fevr, _чәрк, --, --, 
   {{0x444461f6,0x2c780066,0x7c3861f7,0x00000000}},	//   _xa_, _bèda_, gevr, --, 
   {{0x4a24003d,0xff0401b9,0xed580116,0x00000000}},	//   _རྡུལ_, _оятн, роһ_, --, 
   {{0x443861f8,0xe8f861f9,0x499061fa,0x9ba008b0}},	//   zer_, бли_, ویار, رەنى, 
   {{0x443861fb,0x27e80198,0xcbe40124,0x7c3861fc}},	//   yer_, _ƙan_, _дцеи, bevr, 
   {{0x443861fd,0x7c3861fe,0x00000000,0x00000000}},	//   xer_, cevr, --, --, 
   {{0xe820069f,0xe73861ff,0x80f0025c,0x6f040036}},	//   _माठा_, щен_, _བསྐྱ_, nshc, 
   {{0x44386200,0xe5a46201,0xe918003b,0xa92402d2}},	//   wer_, зими, _годі_, gsþá, 
   {{0x69d86202,0x06e00220,0x00000000,0x00000000}},	//   _igwe, _ﺍﻟﻬﺩ, --, --, 
   {{0x44386203,0x44446204,0xfd5800a2,0xd9400fbe}},	//   uer_, _qa_, _agaỳ, _чеши, 
   {{0x44446205,0x69d82d32,0xa2d4012c,0xd7f8011a}},	//   _va_, _kgwe, _मूख्, _ההצל, 
   {{0x66e002b5,0xd5a40dad,0xe5a400d1,0x63bc0010}},	//   _hēko, _टुकड़, _нийи, _vzpn, 
   {{0x69d84520,0x60086206,0xc61807f7,0x6a7400ae}},	// [6d60] _mgwe, йнам_, थलीय_, _ráfl, 
   {{0x44446207,0x44386208,0xc0bc001f,0x4910012d}},	//   _ua_, qer_, ሳችሁ_, _दिनो_, 
   {{0x69d86209,0x5ed4620a,0x00000000,0x00000000}},	//   _ogwe, ستاز, --, --, 
   {{0x6e3806a3,0x66e00093,0x69d8620b,0x27140051}},	//   gewb, _lēko, _ngwe, áng_, 
   {{0x7c38620c,0x80f00327,0x00000000,0x00000000}},	//   tevr, _བསྒྱ_, --, --, 
   {{0x91b80302,0x69d800a9,0x701802bf,0xa18402dd}},	//   _למכי, _agwe, _міст_, _дұға_, 
   {{0x5e94620d,0x8fa035dd,0x7c38620e,0xfa2403d4}},	//   _فلسط, _заре, revr, _মোগল_, 
   {{0xb95400d6,0x6a7402d2,0x00000000,0x00000000}},	//   двищ, _háfj, --, --, 
   {{0x66e000ef,0x2ea800e5,0x00000000,0x00000000}},	//   _bēko, _بھلی_, --, --, 
   {{0x69d80e05,0xdc2801e2,0x00000000,0x00000000}},	//   _egwe, _دسره_, --, --, 
   {{0x35a4033f,0x31b800cd,0x00000000,0x00000000}},	//   _गुज़, _आर्ध, --, --, 
   {{0xe8202cd1,0x69d804ba,0xadf400bc,0x00000000}},	//   _माथा_, _ggwe, आरएन_, --, 
   {{0xd7f81142,0x753c01f5,0x4910012c,0xd5c4012d}},	//   _луй_, uwsz, _दियो_, रेंज, 
   {{0x753c006d,0x2b48012d,0x493800d9,0x00000000}},	//   rwsz, łace_, _לגדו, --, 
   {{0x88b80375,0x81d4015b,0x00000000,0x00000000}},	//   _המגז, সুম_, --, --, 
   {{0xf0e80075,0x66e000ef,0x63b803e0,0x00000000}},	//   قىرى_, _mēkl, ütna, --, 
   {{0x305400aa,0xb12c0023,0x00000000,0x00000000}},	// [6d70] وږسر, _ስርዒታ, --, --, 
   {{0x6d5c06af,0x00000000,0x00000000,0x00000000}},	//   _àsai, --, --, --, 
   {{0x0574129d,0x88e000cc,0x00000000,0x00000000}},	//   _ياۋد, _মিছক, --, --, 
   {{0x9d540092,0x85040244,0x00000000,0x00000000}},	//   _ሁላችሁ, _توین, --, --, 
   {{0x7ed4620f,0x06e00220,0x00000000,0x00000000}},	//   رزما, _ﺍﻟﻤﺩ, --, --, 
   {{0xb12c044e,0x6e38009a,0x69d80368,0x51840117}},	//   _ስርዓታ, sewb, _sgwe, _дуҳа, 
   {{0x6e9405b0,0x66e002b1,0x00000000,0x00000000}},	//   _живу, _rēko, --, --, 
   {{0x66e003a0,0xe8e82dbf,0xc334011a,0x00000000}},	//   _sēko, омид_, תוק_, --, 
   {{0x7d040597,0xe820032c,0x00000000,0x00000000}},	//   áist, _मादा_, --, --, 
   {{0x7d04038f,0xa888160b,0xa6e401a9,0x00000000}},	//   ġist, ійна_, мжол, --, 
   {{0x6d4400b0,0x6298020c,0x68ec025c,0x07e40014}},	//   āhau, étok, _ħadu, _ہِشی_, 
   {{0x69d86210,0xf4080375,0x00000000,0x00000000}},	//   _ugwe, _כפ_, --, --, 
   {{0x7ae400df,0x00000000,0x00000000,0x00000000}},	//   ĉite, --, --, --, 
   {{0x2a7c0070,0xe3f800db,0x64a4022e,0x00000000}},	//   _hlwb_, تىست_, фага, --, 
   {{0x98a021fa,0xb86407d6,0x18a00107,0x00000000}},	//   _шише, _ساوو, _шашм, --, 
   {{0x7eb80030,0xc1e80073,0x00000000,0x00000000}},	//   rípk, टुंब_, --, --, 
   {{0xad9c0034,0x224400d7,0x00000000,0x00000000}},	// [6d80] _jeźd, ľok_, --, --, 
   {{0xa2bc6211,0x22440030,0x71640116,0x66e000de}},	//   _वीर्, žok_, راقك, _lēkm, 
   {{0x7eb8056a,0x5458011a,0x00000000,0x00000000}},	//   lípi, _וכיצ, --, --, 
   {{0x3ea00037,0x00000000,0x00000000,0x00000000}},	//   õit_, --, --, --, 
   {{0x61f46212,0x66e0005f,0xdd903c97,0x7a100064}},	//   mbyl, _sēkl, خوش_, nėtų, 
   {{0xa03402dd,0x00000000,0x00000000,0x00000000}},	//   _تىست, --, --, --, 
   {{0x8eb02dc3,0xa3e401ad,0x7c3800c0,0x00000000}},	//   رمۇش, _फलन_, _įbrė, --, 
   {{0x261800e1,0x2a7c00a9,0x61f42268,0xa06800c7}},	//   _भागी_, _clwb_, nbyl, _уаҳа_, 
   {{0xd83c02f0,0x7f7801ec,0x78d4009d,0x9c2403f6}},	//   _áčka_, _ﺃﻗل_, нжих, _одад, 
   {{0x2ba80141,0x68ec025c,0x61f40142,0x89d40014}},	//   _चुका, _ħadt, hbyl, ظوٝر_, 
   {{0x92c803d4,0x26180037,0x00000000,0x00000000}},	//   ৰীয়_, _भाखी_, --, --, 
   {{0x2a7c6213,0x06942d40,0x00000000,0x00000000}},	//   _glwb_, ﺟﺎﻳﯩ, --, --, 
   {{0x61f46214,0x6b8c01e4,0x00000000,0x00000000}},	//   dbyl, ĝage, --, --, 
   {{0x7eb800d2,0x660000df,0x00000000,0x00000000}},	//   síph, _ĵoke, --, --, 
   {{0x0740035b,0x61f42167,0x6d5c06af,0x47840395}},	//   _ахым, fbyl, _àsav, _осъм_, 
   {{0xd6c0608c,0xddc01b5c,0x61f40af9,0xd5b8277c}},	//   _جمعی, dkož, gbyl, _мсп_, 
   {{0x7eb80261,0xa5c06215,0xaf5c001f,0x948402dd}},	// [6d90] cípi, _бөре, _ለሚመለ, _жынд, 
   {{0xabdc0150,0x7ff46216,0x00000000,0x00000000}},	//   _ﺇﺯﻋﺎ, نسما, --, --, 
   {{0x61f40363,0x339401c6,0x5eb80154,0xe8200a59}},	//   bbyl, _чанё, েদনে, _मासा_, 
   {{0xd24c0451,0xd0640220,0x2ba8000d,0x00000000}},	//   _ڍنڍ_, _ﺍﺷﯩﭗ_, _चुगा, --, 
   {{0xd1c80276,0xf1c407f8,0x00000000,0x00000000}},	//   _фунд_, लेखन, --, --, 
   {{0x9d50004b,0x00000000,0x00000000,0x00000000}},	//   انوت, --, --, --, 
   {{0x7e7800e2,0x81d4015b,0x2c7802e2,0x788800c0}},	//   īvpr, সুদ_, _wèdo_, _mūvė, 
   {{0xe8f86217,0x3ec400c7,0x6a74013d,0xa8040139}},	//   пли_, _асуб, _káfi, kiñä, 
   {{0x8d745734,0x2d9800c7,0x258406af,0x629806af}},	//   _غارا, _ãse_, _mêlé_, étoi, 
   {{0x8c64036b,0x6a740798,0x8c5400db,0xa764361e}},	//   _ўтад, _máfi, _تئرا, екод, 
   {{0x6a740248,0x3e3400db,0x9cd4011a,0x00000000}},	//   _láfi, _سفەر, _נועה_, --, 
   {{0x70bc00dc,0xe82047b8,0xc87c03e3,0x00000000}},	//   ्गुल, _मावा_, _əşya_, --, 
   {{0xba740137,0x81d403d4,0x61f401bf,0x53a00454}},	//   _جالت, _স্ন_, vbyl, ҳарб, 
   {{0x7a100153,0x291801ab,0x00000000,0x00000000}},	//   rėtų, àsau_, --, --, 
   {{0x53a06218,0x61f4002d,0x9878011a,0x00000000}},	//   гарб, tbyl, _מאסט, --, 
   {{0x60e86219,0xe298621a,0xad9c0210,0x26180210}},	//   змам_, чаб_, _udźw, _भाटी_, 
   {{0x6604621b,0x61f4621c,0x563400c8,0x202c001f}},	// [6da0] makk, rbyl, _טאקע_, _አማልክ, 
   {{0x6604621d,0x3e4c01fb,0xddc007f5,0x443c02f0}},	//   lakk, _ớt_, tkož, _úv_, 
   {{0x51740014,0x1ed8621e,0x6fd40006,0x00000000}},	//   وٕہس_, سباب_, віцц, --, 
   {{0xe1f00532,0x1e840b00,0xc22400f2,0x00000000}},	//   _حسد_, элем, _جکسو, --, 
   {{0x6294621f,0x6604002f,0x9be400d4,0x2d8800e4}},	//   miyo, iakk, нійк, úaep_, 
   {{0xe044006c,0x2dc40075,0x00000000,0x00000000}},	//   _янги, тқун_, --, --, 
   {{0x66046220,0x9608009e,0x10a016be,0x3de40117}},	//   kakk, ষ্টম_, _сирн, _айбҳ, 
   {{0x62946221,0x9f580798,0x99642218,0xba54041b}},	//   niyo, capá_, етол, твиј, 
   {{0x26180574,0xef540092,0x00000000,0x00000000}},	//   _भाजी_, _የሚደግ, --, --, 
   {{0x62946222,0x660401f5,0x893000c6,0x2b48033f}},	//   hiyo, eakk, اعيا, łaca_, 
   {{0x62946223,0x66046224,0xe8206225,0x81d400cc}},	//   kiyo, fakk, _मारा_, _স্ম_, 
   {{0x66043778,0x62946226,0xa8040227,0x5ac800f7}},	//   gakk, jiyo, tiñä, _элем_, 
   {{0x62946227,0x00000000,0x00000000,0x00000000}},	//   diyo, --, --, --, 
   {{0x66046228,0x9f5800c7,0x6a746229,0x00000000}},	//   aakk, zapá_, _ráfi, --, 
   {{0x6294622a,0x68ec622b,0x00000000,0x00000000}},	//   fiyo, _çadr, --, --, 
   {{0x66040429,0x6294622c,0x69cc35e0,0x6a74032e}},	//   cakk, giyo, देवी, _páfi, 
   {{0x518427cf,0xd1b80137,0x7eb800d8,0xd7c40345}},	// [6db0] хува, سارا_, nípu, _توژه_, 
   {{0x56900220,0x337400c0,0x69dc05c7,0xb90c0248}},	//   _шақт, _агор, ñsez, _somọ_, 
   {{0x6294622d,0xa3bc0882,0xa3e45b29,0x00000000}},	//   biyo, ेधः_, _फलत_, --, 
   {{0xedd40075,0x6294622e,0xdb0c01e1,0xc7b000df}},	//   نياد, ciyo, _àjùw, אבע_, 
   {{0xe8201524,0x621800df,0x00000000,0x00000000}},	//   _माला_, _קושק, --, --, 
   {{0x6604622f,0x6b6800e2,0x00000000,0x00000000}},	//   zakk, _lūgš, --, --, 
   {{0x66046230,0x9f4800db,0xdb80005b,0x9f580022}},	//   yakk, _debó_, игши, papá_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x66046231,0x2d980022,0x7ae4010f,0x00000000}},	//   vakk, _äse_, ĉita, --, 
   {{0x62945b3f,0x48c000fb,0x00000000,0x00000000}},	//   ziyo, ыҙла, --, --, 
   {{0x62946232,0x7c846233,0x6b680064,0x00000000}},	//   yiyo, _суте, _būgš, --, 
   {{0x66040194,0x291800a3,0x6294058a,0xa774013d}},	//   uakk, àsas_, xiyo, елүч, 
   {{0x62946234,0x68446235,0x69cc6236,0x7534009d}},	//   viyo, _анла, देशी, лэрх, 
   {{0x66046237,0x62946238,0x7eb8215a,0x00000000}},	//   sakk, wiyo, lípt, --, 
   {{0x62946239,0xa7a80724,0xa2e4023b,0xfecc01ec}},	//   tiyo, _юкка_, тобд, _ﺑﺎﯞﺍ, 
   {{0x660420ac,0x00000000,0x00000000,0x00000000}},	//   qakk, --, --, --, 
   {{0x00e404d3,0xe0d8623a,0x069401ed,0xd6cc007b}},	// [6dc0] اتری, два_, _لاکھ, _بقي_, 
   {{0x6294623b,0xa3e4000d,0x00000000,0x00000000}},	//   siyo, _फलि_, --, --, 
   {{0x6294623c,0x645c0393,0x6a7402d2,0xddc0031c}},	//   piyo, _inpi, _háfu, skoż, 
   {{0x644c623d,0x629401b9,0x7e9c02b5,0x828401b9}},	//   ldbi, qiyo, kōpe, _ёқад, 
   {{0xa3e44244,0x20b401d5,0x00000000,0x00000000}},	//   _फला_, _аёвс, --, --, 
   {{0xdb1800dd,0x9f4800cf,0xa0740022,0x20540092}},	//   _aztá, _debò_, _рымш, _ለማቆየ, 
   {{0x3860623e,0x1ea84d49,0x644c020c,0xabb40124}},	//   _đir_, _قاري_, idbi, лашә, 
   {{0x8fa013d6,0x7eb801d3,0xddc00210,0x00000000}},	//   _тасе, típu, rdoł, --, 
   {{0x1c44623f,0x6b680006,0xf8b86240,0x98c42bb7}},	//   _инам, _rūgš, нөк_, ксол, 
   {{0x37c40032,0xe7ec012c,0x7eb80d12,0xad9c0210}},	//   ләйб, चुला_, rípu, _weźc, 
   {{0x25bc0cc1,0x36d41c13,0xfb180014,0x501804ae}},	//   ətli_, лоор, _سراں_, וויו, 
   {{0x645c11c1,0xa3b42871,0x16702f0d,0x644c01ab}},	//   _anpi, _जड़_, рқир, edbi, 
   {{0xb27402af,0xceb006a9,0xd90c6241,0x7eb800e4}},	//   қлаш, שיר_, _بیخ_, líps, 
   {{0xf7540597,0xd59800b5,0xc974025d,0x00000000}},	//   _منتج, beの_, _בגדי_, --, 
   {{0x7c280010,0x8c4003e0,0x4394009d,0x00000000}},	//   _mcdr, _öğes, аарс, --, 
   {{0x645c6242,0xd62400c6,0x70bc2e35,0x3a240051}},	//   _enpi, _شعبي, ्ग्ल, ngmp_, 
   {{0x705805f5,0xd7cc0490,0xd59800b5,0x6a7401a8}},	// [6dd0] наар_, हेरच, meは_, _gáfu, 
   {{0x764c6243,0x9f5800b0,0x9f4802e2,0x68ec00d8}},	//   _haay, kapä_, _rebò_, _éade, 
   {{0x764c6244,0xdb180240,0xa2bc00dc,0x81d40154}},	//   _kaay, _dytë, _वीक्, সুল_, 
   {{0xfe706245,0xed580122,0x764c0694,0x672408fb}},	//   يدن_, _lyže_, _jaay, _åhje, 
   {{0x764c22b9,0x32082da3,0x23c401d9,0x7d000142}},	//   _maay, maay_, _لٕیہ, _cwms, 
   {{0x764c6246,0x32086247,0xdb1801ed,0x6cc40724}},	//   _laay, laay_, _sztá, ыйла, 
   {{0x66e000b0,0xfc306248,0xeb346249,0xa09808a8}},	//   _tēki, تحن_, ارتخ, _טישט, 
   {{0x8650016b,0x764c624a,0x3208624b,0xde44072d}},	//   _akɔn, _naay, naay_, _میمو_, 
   {{0x6e28624c,0xdb1801ef,0xe9a80116,0x00000000}},	//   _iceb, _vztá, عدعن_, --, 
   {{0x6d48624d,0xa88407a7,0x32084091,0x00000000}},	//   _isea, الدى, haay_, --, 
   {{0x3208624e,0x764c624f,0x4ae4036b,0x6d480334}},	//   kaay_, _baay, _рўза, _hsea, 
   {{0x764c6250,0x3ce400ca,0xa9980150,0x3208002e}},	//   _caay, _yumv_, _ازاﻳ, jaay_, 
   {{0x764c6251,0x32086252,0xb95400db,0x0904010a}},	//   _daay, daay_, _پئنت, _рчем, 
   {{0x68e80117,0xd91800df,0x00000000,0x00000000}},	//   mqed, _נוצל, --, --, 
   {{0x387804f3,0x88800502,0x644c6253,0x6e28379d}},	//   örre_, _میکن, rdbi, _oceb, 
   {{0x6d486254,0x67206255,0x2168016c,0x764c6256}},	//   _osea, mulj, ниби_, _gaay, 
   {{0x290c2872,0xd2a4170a,0x9f58006a,0x6d486257}},	// [6de0] nsea_, укте_, zapä_, _nsea, 
   {{0x6e286258,0x764c6259,0x645c625a,0x646402f0}},	//   _aceb, _zaay, _unpi, ásič, 
   {{0x6d48625b,0x32080548,0x764c20fc,0x6720625c}},	//   _asea, baay_, _yaay, nulj, 
   {{0x1ea805d4,0x764c625d,0x32080429,0x6d480334}},	//   راضي_, _xaay, caay_, _bsea, 
   {{0x6d48010a,0xdb180200,0x6dc414fb,0x00000000}},	//   _csea, _tytë, ۇزۇل, --, 
   {{0x6e28625e,0x311813da,0x6d48010a,0x6720625f}},	//   _eceb, _पितृ_, _dsea, kulj, 
   {{0x6d486260,0x290c6261,0x67200e3c,0x6e280334}},	//   _esea, esea_, julj, _fceb, 
   {{0x67206262,0x6d48030d,0x391407c6,0x3a7404a9}},	//   dulj, _fsea, амир, рлир, 
   {{0x764c6263,0x98046264,0x6d480175,0x63bc0200}},	//   _raay, лянд, _gsea, _lypn, 
   {{0x764c6265,0x67206266,0x39440142,0x00000000}},	//   _saay, fulj, rwms_, --, 
   {{0x32086267,0x764c6268,0x9a2400e5,0x00000000}},	//   yaay_, _paay, _مٹان, --, 
   {{0x764c6269,0x7bc856c0,0x3208626a,0x290c626b}},	//   _qaay, _izdu, xaay_, bsea_, 
   {{0xd90c397d,0x764c626c,0x6d480175,0xdb180129}},	//   _عید_, _vaay, _xsea, _sytè, 
   {{0x764c626d,0x2c780699,0x94843419,0xd598037e}},	//   _waay, _pèdi_, уымд, seは_, 
   {{0xd258626e,0xdb0c0724,0x764c626f,0x32083325}},	//   нца_, _ädäb, _taay, taay_, 
   {{0x48f80316,0x752c01d5,0x1af400cc,0x25a40064}},	//   लीको_, _tqaz, _ঘটাই_, _žole_, 
   {{0x32086270,0xd018013d,0x00000000,0x00000000}},	// [6df0] raay_, ефе_, --, --, 
   {{0x7e6002d0,0x32086271,0x629806af,0x6d480175}},	//   _anmp, saay_, étor, _rsea, 
   {{0x4fc401c0,0xcfa80efe,0x1ee82a9f,0x00000000}},	//   усаа, رائم_, نولی_, --, 
   {{0x3208011f,0x6d480334,0x290c02f0,0xa02000a2}},	//   qaay_, _psea, ysea_, _ýönk, 
   {{0x6d480175,0xa2740150,0xc5f4011a,0x00000000}},	//   _qsea, _тұту_, צדס_, --, 
   {{0x7bc8033f,0x6a7402d2,0x3a2000ef,0x00000000}},	//   _bzdu, _náfr, _ķipa_, --, 
   {{0x3cf80010,0x7c840063,0xaed4074d,0x7eb800d7}},	//   _črve_, ључе, _вовш, rípr, 
   {{0x6d480491,0x6e286272,0x290c04ce,0x709401f0}},	//   _tsea, _uceb, tsea_, _саҳф, 
   {{0x8d846273,0x6d48049b,0xfe6c0014,0xa9a400ee}},	//   _сувд, _usea, _سۯو_, рипд, 
   {{0x290c6274,0x7eb80051,0x00000000,0x00000000}},	//   rsea_, lípp, --, --, 
   {{0x290c6275,0x29d801e4,0x00000000,0x00000000}},	//   ssea_, sɨa_, --, --, 
   {{0xd9946276,0x67206277,0x290c0276,0xddc016a3}},	//   انیت_, rulj, psea_, ljoš, 
   {{0x05d00574,0x63bc6278,0x07a00588,0x6a7408a5}},	//   सेंब, _sypn, раҟн, _fáfr, 
   {{0x67206279,0xe738627a,0xd5440640,0xdb1802f0}},	//   pulj, _аек_, јпре_, _syté, 
   {{0xe29840d2,0xd464627b,0x7e9c02b1,0x00000000}},	//   вав_, шире_, hōpa, --, 
   {{0x63bc0232,0x7e9c02b5,0x2a6c020c,0xd2a40063}},	//   _vypn, kōpa, njeb_, аксе_, 
   {{0x64a40131,0x24c80116,0xffa400fb,0xdb18013a}},	// [6e00] _вапа, _игип_, әлеү, _vyté, 
   {{0xc0d0067d,0x7e60627c,0xc0bc0092,0x00000000}},	//   _እቶም_, _snmp, ዳችሁ_, --, 
   {{0x661400bc,0xb40001c0,0x93f8011a,0xd4340677}},	//   _kdyk, _хүсд, _שלטי, _דריק_, 
   {{0x2a6c038f,0xed580427,0x00000000,0x00000000}},	//   jjeb_, _brž_, --, --, 
   {{0xe3b0627d,0x86500134,0x62843764,0x2250002d}},	//   _درک_, _nkɔm, _ilko, mdyk_, 
   {{0x628401ee,0xed58627e,0x2250627f,0x4cb4109a}},	//   _hlko, _drž_, ldyk_, алію_, 
   {{0x8fa06280,0x8650013f,0x21300798,0x2ca801e7}},	//   _даре, _akɔm, ltyh_, éada_, 
   {{0x7bc85e64,0x9f580270,0x22505140,0xcb640063}},	//   _vzdu, kapú_, ndyk_, раће_, 
   {{0xed3405f5,0xa3e400dc,0x7e9c00f3,0xd7f86281}},	//   _гэхэ, _फलं_, sčps, кун_, 
   {{0x66146282,0x26c000e8,0x98c40f5c,0x00000000}},	//   _adyk, elko_, јсил, --, 
   {{0x62845184,0x4adc530e,0x1ae40f15,0x4cb8011a}},	//   _olko, _पंचव, _тоем, _יזמו, 
   {{0xe8f400fb,0x00000000,0x00000000,0x00000000}},	//   шһә_, --, --, --, 
   {{0x225040d6,0x18a40b00,0x98a4013d,0x15a8011c}},	//   ddyk_, _кадм, _киде, тъни_, 
   {{0x68ec0597,0x2250002d,0xd90c01ed,0xc8b0072d}},	//   _éada, edyk_, _ٹیگ_, _وصوب, 
   {{0x26c002fb,0x7eb40139,0xd2d4007b,0xf8b8035b}},	//   blko_, _küpğ, لغرب, moĩ_, 
   {{0x62980129,0x225000a2,0x00000000,0x00000000}},	//   étop, gdyk_, --, --, 
   {{0x94a80598,0x30146283,0x7ae800df,0xf4840424}},	// [6e10] _атна_, йдар, _ludt, _هادی, 
   {{0x62846284,0x60cc00a3,0x7ae86285,0xd34403e6}},	//   _elko, _chbm, _oudt, _پیره_, 
   {{0x60cc00a3,0xed5807f5,0x7ae80477,0x22500064}},	//   _dhbm, _srž_, _nudt, bdyk_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xefb01c3b,0x067c008f,0x7e9c02e2,0xf8b80022}},	//   _کیاگ, כנאל, tčpr, koĩ_, 
   {{0x30842ab5,0xddc000e2,0xbff834e2,0x63a00055}},	//   _السف, ujoš, _верх_, _śoni, 
   {{0x7ae80e89,0x4df4012c,0xc08c0092,0x3da40166}},	//   _cudt, उँदै_, _መረጃን_, йрәб, 
   {{0xe738547c,0xdb0c00bc,0x00000000,0x00000000}},	//   ңеп_, ídán, --, --, 
   {{0xe9d86286,0x7ae801bf,0x00000000,0x00000000}},	//   ыки_, _eudt, --, --, 
   {{0xa9a46287,0xe9a40ed1,0x2c78033b,0x00000000}},	//   _қилд, _қалп, _pèdu_, --, 
   {{0x7ae80004,0xe7380640,0x97600023,0x00000000}},	//   _gudt, ћем_, _ፈተውት, --, 
   {{0x9984000a,0x9f5803a0,0x00000000,0x00000000}},	//   šiše_, tapú_, --, --, 
   {{0x69cc0490,0x287400fd,0x64e000dc,0xe8e80451}},	//   देखी, _гыйр, पदेश, _ڌرڻو_, 
   {{0x23280b7e,0x58f4011a,0x1864014b,0x00000000}},	//   логи_, _המסע_, _гаши_, --, 
   {{0xe7386288,0x7ae80139,0xe2a800ec,0x00000000}},	//   _сей_, _xudt, هارن_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x27306289,0x2250628a,0x2b480034,0x628402fb}},	// [6e20] lán_, rdyk_, łach_, _vlko, 
   {{0x412801e0,0x21a4059f,0xa00833d2,0x00000000}},	//   лоғо_, _ҳимм, اقال_, --, 
   {{0x2730628b,0xe298074d,0x8650016b,0x54740375}},	//   nán_, _бан_, _nkɔk, _הגיע_, 
   {{0x62840664,0xe82005ba,0x00000000,0x00000000}},	//   _ulko, _माझा_, --, --, 
   {{0x27300491,0x7ae8628c,0x82340023,0x491000bc}},	//   hán_, _sudt, _ኣማሓዳ, _दिगो_, 
   {{0x2730628d,0x4438032e,0x3c58084c,0x00000000}},	//   kán_, nfr_, рикэ_, --, 
   {{0x2730628e,0xe8201b57,0x6d5c06ea,0x93f80a7c}},	//   ján_, _माजा_, _ásan, אלצי, 
   {{0x2730628f,0x4a5002e8,0x2b5401d5,0xdd90007b}},	//   dán_, зкъс, غیند_, _فوز_, 
   {{0x20086290,0x08f4006c,0x5dd405ac,0xdb9c0240}},	//   _kebi_, یریب_, _ড্ৰু, ልካዮም_, 
   {{0x7ae800dd,0x27306291,0x00000000,0x00000000}},	//   _tudt, fán_, --, --, 
   {{0x27300553,0x20080ac5,0x8c400798,0x7ae801bf}},	//   gán_, _mebi_, _хехе, _uudt, 
   {{0x042004c5,0x7c3801a4,0x20086292,0x6298004e}},	//   ম্মী_, lfvr, _lebi_, ètol, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc9140302,0x27306293,0x443803b2,0x37f80276}},	//   _פחות_, bán_, gfr_, _текэ_, 
   {{0x27302d4b,0xd6d80212,0x2a7801e1,0x00000000}},	//   cán_, _йти_, _ègbà_, --, 
   {{0x46a40b7f,0x200804cc,0x00000000,0x00000000}},	//   _најв, _aebi_, --, --, 
   {{0x34940022,0xc7a000fb,0xd498014b,0x00000000}},	// [6e30] _маир, _миәк, _брн_, --, 
   {{0x80786294,0xdb18011f,0xe820012c,0x20080205}},	//   ббус_, _aytí, _माछा_, _cebi_, 
   {{0x20086295,0x7ff40b8c,0x78a86296,0x66700133}},	//   _debi_, سسلا, indv, _رگێر, 
   {{0xad9c012d,0x00000000,0x00000000,0x00000000}},	//   _weźm, --, --, --, 
   {{0x20086297,0x27306298,0xac08035b,0xeff002d3}},	//   _febi_, zán_, анла_, ልላይ_, 
   {{0x27306299,0x2008629a,0x00000000,0x00000000}},	//   yán_, _gebi_, --, --, 
   {{0x2730629b,0x70c4629c,0x00000000,0x00000000}},	//   xán_, वतील, --, --, 
   {{0x2730629d,0x20080296,0x00000000,0x00000000}},	//   ván_, _zebi_, --, --, 
   {{0x443800a9,0x20080296,0x273009c2,0x7e7400db}},	//   yfr_, _yebi_, wán_, _عافئ, 
   {{0x27303dfa,0x6d58565e,0x4438003e,0x68440798}},	//   tán_, mvwa, xfr_, цноа, 
   {{0x6d5802d0,0x443803b2,0x00000000,0x00000000}},	//   lvwa, vfr_, --, --, 
   {{0x2730629e,0x61e00153,0x68ec01e7,0x78a8629f}},	//   rán_, žoli, _éado, andv, 
   {{0x273062a0,0x24980109,0xf1b400af,0x6aa862a1}},	//   sán_, _pmpm_, _अँगन, mnef, 
   {{0x27302f5e,0x6aa80008,0x00000000,0x00000000}},	//   pán_, lnef, --, --, 
   {{0x443862a2,0x6aa80083,0x200862a3,0x00000000}},	//   rfr_, onef, _rebi_, --, 
   {{0xe1f862a4,0x27140882,0x6aa862a5,0x232800c2}},	//   рга_, mān_, nnef, лоҳи_, 
   {{0x600862a6,0x6aa862a7,0xdb1800bc,0x5f440451}},	// [6e40] инам_, inef, _rytí, ڪنال, 
   {{0x6d58003c,0x9fc80022,0xc2941291,0x1ac462a8}},	//   dvwa, агза_, _کیرب, _लठ्ठ, 
   {{0xe3b062a9,0x26d00055,0x6aa862aa,0x20080200}},	//   _زرد_, _khyo_, knef, _vebi_, 
   {{0x5d840f1b,0x200862ab,0x6aa8005c,0x00000000}},	//   يلال, _webi_, jnef, --, 
   {{0x27140882,0x6aa801bf,0xdb180118,0xfaf80055}},	//   hān_, dnef, _vytí, _stī_, 
   {{0x27140882,0x7e9c00b0,0xd1b800d1,0x68ec010b}},	//   kān_, pōpo, _خاپا_, _çady, 
   {{0xaff401ed,0x78a80175,0x6aa802d2,0x9b6800d8}},	//   _رہنا_, vndv, fnef, ршла_, 
   {{0xdcf862ac,0x6aa862ad,0x6720110c,0xdb180022}},	//   _نفرت_, gnef, drlj, _pytâ, 
   {{0xdca40124,0xdcb057d4,0xdb4c0133,0xdc680064}},	//   _дааи, _قىر_, _ڤێب_, _каад_, 
   {{0x6aa8002d,0xae480014,0x0c20004e,0xdc280244}},	//   anef, _پشہٕ_, _омун, _خسره_, 
   {{0x67200989,0x76b8215c,0x26d000b8,0x6aa80139}},	//   grlj, йлор_, _bhyo_, bnef, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x95c862ae,0xd7f86140,0x00000000,0x00000000}},	//   руна_, _куй_, --, --, 
   {{0x672005a1,0xeaf800f7,0xba000092,0x942000db}},	//   brlj, _ئرەت_, _ግል_, بوسۇ, 
   {{0x79800142,0x2714002b,0x00000000,0x00000000}},	//   lymw, cān_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x850413bd,0x51840120,0x798062af,0xddc0012d}},	// [6e50] _قوين, цува, nymw, rdoś, 
   {{0xb8800092,0x00000000,0x00000000,0x00000000}},	//   _ይወጣል_, --, --, --, 
   {{0x0574006c,0x6aa862b0,0x00000000,0x00000000}},	//   _فاید, ynef, --, --, 
   {{0x6d58035a,0x00000000,0x00000000,0x00000000}},	//   tvwa, --, --, --, 
   {{0xed5862b1,0x6d582165,0x6aa862b2,0x9bd400d1}},	//   сол_, uvwa, vnef, ﻟﯘﭘﻤ, 
   {{0x6d582165,0x6d5c008c,0x27140882,0xbbe80131}},	//   rvwa, _ásam, yān_, يرىم_, 
   {{0x6aa800fd,0xd598037e,0x6d5802d0,0x6d4c03e0}},	//   tnef, beで_, svwa, çaab, 
   {{0x27141161,0x672062b3,0x00000000,0x00000000}},	//   vān_, vrlj, --, --, 
   {{0x6aa862b4,0xac18010b,0xdb180124,0x6f080210}},	//   rnef, _гозу_, _pytã, _łech, 
   {{0x27140882,0x672005ce,0x6aa862b5,0x00000000}},	//   tān_, trlj, snef, --, 
   {{0x27e862b6,0x25a4010e,0x7c34030d,0x00000000}},	//   _şans_, _ţol_, _цехх, --, 
   {{0x27140882,0x77c8009d,0x672001e3,0x00000000}},	//   rān_, өлөг_, rrlj, --, 
   {{0x9580005b,0xfaf800ef,0x00000000,0x00000000}},	//   еляе, _trīc_, --, --, 
   {{0x67201050,0x2b48012d,0x65c001ec,0xb80800cf}},	//   prlj, łacu_, мұқа, _ۇيۇم_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x25680166,0x00000000,0x00000000,0x00000000}},	//   _гаип_, --, --, --, 
   {{0xe5a400d8,0xb6240150,0x00000000,0x00000000}},	// [6e60] _хипи, _ﺨﺹ_, --, --, 
   {{0xe44810e0,0x90c034d8,0xe354010b,0x637400a2}},	//   _الدى_, ебуе, _етмэ, günç, 
   {{0x5478011a,0xdd30012d,0x8fa00139,0x00000000}},	//   _הטיו, _węży, нафе, --, 
   {{0x754801d3,0x00000000,0x00000000,0x00000000}},	//   _úszó, --, --, --, 
   {{0x222400aa,0x61f4010b,0x00000000,0x00000000}},	//   _وګړي_, mcyl, --, --, 
   {{0x4c100131,0xc0bc0092,0x00000000,0x00000000}},	//   ىبىس, ዳችም_, --, --, 
   {{0xc624009e,0x8e4400d1,0xe80000ab,0xd0040a5b}},	//   য্যা_, زلۈك_, ोरना_, _хесе_, 
   {{0x61f42dc9,0x00000000,0x00000000,0x00000000}},	//   ncyl, --, --, --, 
   {{0x78d4080a,0x69301e4b,0xa03c0092,0x00000000}},	//   мжих, نکور, _ሣምንታ, --, 
   {{0xcc84084c,0x611c0311,0xfc6462b7,0x9f5802b5}},	//   _ебуе_, călţ, _تخری, kapü_, 
   {{0x99e462b8,0x7980015d,0x00000000,0x00000000}},	//   _ежед, symw, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x20bc0825,0x4a58011a,0x61f4007c,0x00000000}},	//   ्ताध, _לדאו, dcyl, --, 
   {{0x17680b7b,0xd13800c7,0x00000000,0x00000000}},	//   _грип_, ҩха_, --, --, 
   {{0x083862b9,0x883800d9,0xc7ac005b,0x62880153}},	//   _העול, _לתגו, _чё_, _įfor, 
   {{0xd1b8007b,0x61f400a2,0x00000000,0x00000000}},	//   ماذا_, gcyl, --, --, 
   {{0x245001b9,0x82342d4b,0xb08400f1,0x00000000}},	// [6e70] رچیس, عرفا, وټرو, --, 
   {{0x4f680c9e,0x00000000,0x00000000,0x00000000}},	//   йшем_, --, --, --, 
   {{0x6e1800ae,0x00000000,0x00000000,0x00000000}},	//   قياس_, --, --, --, 
   {{0xee2001ec,0x6d5c08a5,0x00000000,0x00000000}},	//   тедi_, _ásak, --, --, 
   {{0x50a00132,0xac940107,0x00000000,0x00000000}},	//   _كەرل, мадш, --, --, 
   {{0xd7e40491,0x433804fb,0xfd7401c4,0x00000000}},	//   _لك_, _بسیج_, элчэ, --, 
   {{0xdb4c0050,0x4c7000fb,0x00000000,0x00000000}},	//   لَو_, _үҫер, --, --, 
   {{0xe8f862ba,0x81d4009e,0x7ba4009a,0x2bfc000d}},	//   оли_, _স্ট_, عصوم, _र्रू_, 
   {{0xdb1862bb,0x8d740220,0xeff0001f,0x393401c6}},	//   _vytá, _عارا, ልጋይ_, нээс, 
   {{0x9f580407,0x00000000,0x00000000,0x00000000}},	//   capó_, --, --, --, 
   {{0xc5f40198,0x61f4003a,0x7d1c0171,0x00000000}},	//   _laɓe_, ycyl, _ārsi, --, 
   {{0xe5a41a0b,0x29d44706,0xe6100066,0x00000000}},	//   дими, _قياس, خشد_, --, 
   {{0x2b4462bc,0xeb0c0dba,0x61f4007c,0x00000000}},	//   _hplc_, _सबुत_, vcyl, --, 
   {{0xd94062bd,0x8650016b,0x2b44009f,0x2ca8007b}},	//   _реши, _akɔt, _kplc_, éadh_, 
   {{0xe794249f,0xd7f8011a,0xe7d062be,0xe4e40150}},	//   _تاشک, _והצל, _हरिप, зіңн, 
   {{0x44240205,0x00000000,0x00000000,0x00000000}},	//   şm_, --, --, --, 
   {{0x61f462bf,0x24f4036b,0x3d140241,0x74f801c6}},	// [6e80] rcyl, _ўчир, _múwá_, _нээс_, 
   {{0xf42403f4,0xeb0c0c2e,0xc5f40198,0x44f400fd}},	//   ম্বর_, _सबूत_, _daɓe_, _iä_, 
   {{0x44f462c0,0xfaf800b8,0x00000000,0x00000000}},	//   _hä_, _arīn_, --, --, 
   {{0x44f462c1,0xeea80220,0xe44810de,0x51e000d1}},	//   _kä_, птік_, _الگى_, ركەك, 
   {{0x44f462c2,0x00000000,0x00000000,0x00000000}},	//   _jä_, --, --, --, 
   {{0x44f462c3,0x69c00037,0x00000000,0x00000000}},	//   _mä_, _लड़ी, --, --, 
   {{0x44f462c4,0x224005b1,0xc5f40c09,0xcb640640}},	//   _lä_, _kbkk_, _zaɓe_, даје_, 
   {{0x386062c5,0x7e9c02b5,0x44f4002f,0x5da000fb}},	//   _şir_, kōpi, _oä_, _иҫең, 
   {{0x44f462c6,0xdb4c04d3,0x4a5019b0,0x00000000}},	//   _nä_, _چێت_, ткыс, --, 
   {{0xdb4c04d3,0x779801b9,0x00000000,0x00000000}},	//   _نێت_, зкор_, --, --, 
   {{0x44f40004,0x86500134,0x00000000,0x00000000}},	//   _aä_, _nkɔs, --, --, 
   {{0x98ac62c7,0x44f462c8,0xd9680451,0x7bc803b2}},	//   ınıp_, _bä_, _وٽان_, _iydu, 
   {{0xb4e852f2,0x44f4013d,0x00000000,0x00000000}},	//   यदे_, _cä_, --, --, 
   {{0x44f41248,0xf1d4012c,0x00000000,0x00000000}},	//   _dä_, _दरबन, --, --, 
   {{0x44f40589,0x2240005a,0xf8b001ed,0x88b8011a}},	//   _eä_, _bbkk_, _لکھ_, _ומגז, 
   {{0x44f462c9,0x38c803e6,0x387c01e3,0xd5ac00e5}},	//   _fä_, _باڵی_, _hovr_, _نہج_, 
   {{0x44f462ca,0x224005b1,0x3188022e,0x18540023}},	// [6e90] _gä_, _dbkk_, _kўzi_, _ገበነኛ, 
   {{0xdb1862cb,0x7bc8010e,0xcf880b24,0x291801d3}},	//   _kytä, _oydu, يضان_, ásai_, 
   {{0x44f462cc,0x387c010a,0xda0c0ce0,0x40340107}},	//   _zä_, _movr_, सरात_, техс, 
   {{0x387c0165,0xdde00427,0x44f400fd,0x00000000}},	//   _lovr_, _šušt, _yä_, --, 
   {{0x849862cd,0x7bc83a73,0xf0e802dd,0x44f4013d}},	//   _رئیس_, _aydu, _ءىسى_, _xä_, 
   {{0x2d9800a2,0x6b540395,0x00000000,0x00000000}},	//   _ýsem_, етих, --, --, 
   {{0x4034468d,0xdb180267,0x00000000,0x00000000}},	//   _шерс, _nytä, --, --, 
   {{0xfaf800cd,0x00000000,0x00000000,0x00000000}},	//   _trīn_, --, --, --, 
   {{0x9f480241,0x7bc80162,0x291862ce,0x6d3800df}},	//   _agbè_, _eydu, ésa_, _מתּנ, 
   {{0x44f462cf,0xac18005b,0x7f680139,0x291800c7}},	//   _rä_, _хожу_, _üsqä, ĩsa_, 
   {{0x387c468a,0x8638001f,0x7bc80064,0x66d401ef}},	//   _dovr_, _ኤሌክት, _gydu, háke, 
   {{0x44f40bc9,0xa9083a16,0x00000000,0x00000000}},	//   _pä_, _فيصل_, --, --, 
   {{0x3914035b,0xa968074d,0xe96801d5,0x66d462d0}},	//   _амчр, _хила_, _халл_, jáke, 
   {{0x44f462d1,0x64a400c7,0x66d4013a,0x00000000}},	//   _vä_, хага, dáke, --, 
   {{0x44f40598,0x00000000,0x00000000,0x00000000}},	//   _wä_, --, --, --, 
   {{0x44f462d2,0x228c02f0,0x00000000,0x00000000}},	//   _tä_, _býka_, --, --, 
   {{0x26c062d3,0x00000000,0x00000000,0x00000000}},	// [6ea0] moko_, --, --, --, 
   {{0x228c02f0,0x00000000,0x00000000,0x00000000}},	//   _dýka_, --, --, --, 
   {{0x44440e37,0xa2e421c3,0x3af800e4,0x66d401ed}},	//   _ib_, _поод, _oĩpa_, mákb, 
   {{0x26c062d4,0x66d462d5,0x7bc80210,0x00000000}},	//   noko_, lákb, _rydu, --, 
   {{0x44443c36,0xdca462d6,0x26c001c4,0xd1f0001f}},	//   _kb_, нади, ioko_, ልካች_, 
   {{0x26c062d7,0x644c62d8,0xff241968,0x00000000}},	//   hoko_, nebi, _لبری, --, 
   {{0x44443c36,0xa91c02fb,0x504062d9,0x00000000}},	//   _mb_, vyža, _щерб, --, 
   {{0x644c62da,0xdb1862db,0x26c062dc,0xdb20033f}},	//   hebi, _nytå, joko_, _śród, 
   {{0x26c062dd,0x644c62de,0xf8b80372,0xd8c8084c}},	//   doko_, kebi, мөк_, зынд_, 
   {{0x644c62df,0x9f480241,0x444462e0,0xdb180022}},	//   jebi, _agbé_, _nb_, _pytä, 
   {{0x644c62e1,0x26c0014c,0x7bc862e2,0x26000490}},	//   debi, foko_, _uydu, _व्ही_, 
   {{0x26c062e3,0xb4e800cd,0x00000000,0x00000000}},	//   goko_, यद्_, --, --, 
   {{0x444462e4,0x499001ed,0x1868009b,0x644c0142}},	//   _bb_, _میٹر, _нади_, febi, 
   {{0x444462e5,0x9f480ca8,0xdb18023a,0x09e062e6}},	//   _cb_, _egbé_, _tytä, _сочн, 
   {{0x26c062e7,0x444462e8,0xc34821d7,0x00000000}},	//   boko_, _db_, няте_, --, 
   {{0x444462e9,0x26c003b4,0x60dc009a,0x02a4010b}},	//   _eb_, coko_, empm, грум, 
   {{0x644c62ea,0x705805f5,0x948462eb,0x44445f54}},	// [6eb0] bebi, маар_, _зынд, _fb_, 
   {{0x644c62ec,0x444462ed,0x765c62ee,0x65540375}},	//   cebi, _gb_, ldsy, _סבתא_, 
   {{0xb8fc5a4f,0xcee81bf3,0xdfd005d9,0x7e9c02b5}},	//   _ྡེ_, سران_, ليٰ_, hōpu, 
   {{0x444462ef,0x765c04ce,0x25a40114,0x228c01f1}},	//   _zb_, ndsy, _žoli_, _týka_, 
   {{0x320862f0,0x765c62f1,0xf1d40037,0x753c01d3}},	//   mbay_, idsy, _दरिन, ntsz, 
   {{0x444462f2,0x7d1c0029,0x32080c8c,0x26c062f3}},	//   _xb_, _ārst, lbay_, zoko_, 
   {{0x26c062f4,0x320862f5,0x7c941410,0xbc940092}},	//   yoko_, obay_, دشنا, ፍሪካና_, 
   {{0x32082f05,0x644c62f6,0x26c007a9,0xb4bc1f14}},	//   nbay_, zebi, xoko_, इकु_, 
   {{0x644c62f7,0x26c062f8,0x320801d9,0x765c007c}},	//   yebi, voko_, ibay_, ddsy, 
   {{0x26c062f9,0x8650013f,0x644c05f5,0x320814dc}},	//   woko_, _akɔp, xebi, hbay_, 
   {{0x26c062fa,0x320862fb,0x644c62fc,0x444462fd}},	//   toko_, kbay_, vebi, _rb_, 
   {{0x753c17da,0x00000000,0x00000000,0x00000000}},	//   ftsz, --, --, --, 
   {{0x26c062fe,0x320814dc,0xd1f002d3,0xf9840014}},	//   roko_, dbay_, ልካት_, _مجوٝ, 
   {{0x444462ff,0x32086300,0x291c0100,0x765c0af9}},	//   _qb_, ebay_, _ivwa_, adsy, 
   {{0x644c6301,0x44446302,0x36e800f1,0x6d5c0142}},	//   rebi, _vb_, _ګروپ_, _âsaf, 
   {{0x44446303,0x7afc066d,0x644c098c,0x6d486304}},	//   _wb_, _érte, sebi, _opea, 
   {{0xc5f403f9,0x644c0521,0x00000000,0x00000000}},	// [6ec0] _gaɓa_, pebi, --, --, 
   {{0x44446305,0x32080014,0x7d000076,0xdb180042}},	//   _ub_, abay_, _rtms, _cytû, 
   {{0xe2985fd4,0xc5f402a8,0x32086306,0xdee46307}},	//   _жан_, _zaɓa_, bbay_, вожи, 
   {{0x32086308,0x6d486309,0x21a4022e,0x00000000}},	//   cbay_, _bpea, _аимм, --, 
   {{0x62940007,0x291c01a4,0x00000000,0x00000000}},	//   mhyo, _nvwa_, --, --, 
   {{0xdb18015d,0xdb6800d8,0xf2f80345,0xc1b80408}},	//   _gytû, дрил_, _توێژ_, ăлăх_, 
   {{0x6d48630a,0x10a001b9,0x765c0042,0x00000000}},	//   _epea, _тирн, ydsy, --, 
   {{0x62940007,0x7e9c00b0,0x6d480332,0xcb640063}},	//   nhyo, tōpu, _fpea, ђање_, 
   {{0xfc04004e,0xd90c04f2,0xddc0031c,0x00000000}},	//   _бозү, آیت_, njoż, --, 
   {{0xc5f40198,0x7e9c00b0,0xe8500131,0x3208035a}},	//   _raɓa_, rōpu, مچىد, zbay_, 
   {{0x3208630b,0xc5f402a8,0x9b8800ae,0x00000000}},	//   ybay_, _saɓa_, _تنال_, --, 
   {{0xe8ec00b2,0x473000dd,0x81b00198,0x7e9c0418}},	//   _کڻي_, گریز, zaɓa, pōpu, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3af8630c,0xd1f0044e,0x32080c8c,0x39a40165}},	//   _kép_, ልያት_, wbay_, rīsī_, 
   {{0xc8c4630d,0x320814dc,0xd258630e,0x753c1790}},	//   _جوون_, tbay_, мца_, stsz, 
   {{0xc5f40b45,0x78a8003c,0x3af801fb,0x461401d9}},	//   _taɓa_, lidv, _mép_, _پوٝر, 
   {{0x320814dc,0x3af8630f,0x80dc00cc,0xbeac0205}},	// [6ed0] rbay_, _lép_, বদন্, _üçyü, 
   {{0x320814dc,0xa2c00032,0x6f04004d,0x78a86310}},	//   sbay_, _ғәск, tphc, nidv, 
   {{0xdb1c20ef,0x6d486311,0x66d403da,0x3af86312}},	//   _évèn, _spea, láka, _nép_, 
   {{0x6294047e,0x78a82acd,0x7e440395,0x00000000}},	//   chyo, hidv, ихче, --, 
   {{0x3cec004d,0x00000000,0x00000000,0x00000000}},	//   _bidv_, --, --, --, 
   {{0x3af86313,0x3e68008e,0x00000000,0x00000000}},	//   _bép_, ешән_, --, --, 
   {{0x447c04ac,0x3af80c6a,0x8c400032,0xaa4402dd}},	//   ונגע, _cép_, геҙе, гейл, 
   {{0x3af8001e,0x66d401d3,0xd5d001f9,0x00000000}},	//   _dép_, káka, _सरंज, --, 
   {{0x6b74005e,0x2d986314,0x6d485e1d,0xa91c0024}},	//   _әлеу, _åse_, _upea, ryžo, 
   {{0x0ba46315,0x2eec0036,0x48b00c58,0xb4bc00bc}},	//   _ишем, _hief_, ুগ্ৰ, इको_, 
   {{0x3af801ed,0x7c940137,0x3ea40076,0xa6e40137}},	//   _gép_, _ئشقا, _ymmt_, лжол, 
   {{0x6294009a,0x068401a9,0x00000000,0x00000000}},	//   xhyo, рҳин, --, --, 
   {{0x78a801f0,0xa3e40d41,0x66d46316,0x5e54008f}},	//   bidv, बेन_, gáka, נישע_, 
   {{0x2eec6317,0x78a800cd,0x00000000,0x00000000}},	//   _lief_, cidv, --, --, 
   {{0x62946318,0x3af80208,0x00000000,0x00000000}},	//   thyo, _xép_, --, --, 
   {{0x6aa804e6,0xb294026a,0x2eec04cc,0xdb180022}},	//   nief, ајућ, _nief_, _pytú, 
   {{0x7d0400da,0x00000000,0x00000000,0x00000000}},	// [6ee0] ģisk, --, --, --, 
   {{0x6aa86319,0x6614631a,0x071438d2,0x629458b0}},	//   hief, _heyk, _दबाव_, shyo, 
   {{0x645c631b,0x66140309,0x2eec017a,0x6294003e}},	//   _iapi, _keyk, _bief_, phyo, 
   {{0x645c631c,0xdb1c0231,0x78a80998,0x6aa80ea0}},	//   _hapi, _évén, zidv, jief, 
   {{0x63b40029,0x2eec631d,0x0dc40075,0x78a800d2}},	//   šanā, _dief_, луши_, yidv, 
   {{0x645c631e,0x6614631f,0xa0a4010b,0xc0f00092}},	//   _japi, _leyk, _сагд, ልኛል_, 
   {{0x2eec6320,0x20180882,0x6aa803c1,0x3cec03b2}},	//   _fief_, mapi_, fief, _vidv_, 
   {{0x20186321,0xdd144d66,0x2eec0221,0x6614017a}},	//   lapi_, _مورخ, _gief_, _neyk, 
   {{0x58846322,0x78a82acd,0x00000000,0x00000000}},	//   гына, tidv, --, --, 
   {{0x645c6323,0x20186324,0x3af8004d,0x8d9000c6}},	//   _napi, napi_, _tép_, _الكش, 
   {{0x66146325,0x6aa86326,0x9a640014,0x78a86327}},	//   _beyk, bief, _مۅغل_, ridv, 
   {{0x20186328,0x645c6329,0x78a8003c,0x41b40490}},	//   hapi_, _aapi, sidv, ंपास, 
   {{0x2018632a,0x645c632b,0x78a80115,0x66140205}},	//   kapi_, _bapi, pidv, _deyk, 
   {{0x66d4632c,0x20185abd,0x44f400f0,0x00000000}},	//   ráka, japi_, спрс, --, 
   {{0x2018632d,0x645c632e,0x43941173,0x68ec011c}},	//   dapi_, _dapi, барс, _èada, 
   {{0x68ec0597,0x66140af9,0x645c02d0,0x225003b2}},	//   _éadr, _geyk, _eapi, geyk_, 
   {{0x9f48145e,0x3014632f,0x2eec0e78,0x645c6330}},	// [6ef0] _ngbâ_, идар, _rief_, _fapi, 
   {{0x645c6331,0x20186332,0x2eec0221,0x6700063f}},	//   _gapi, gapi_, _sief_, ịket, 
   {{0x23f80302,0x66140113,0x7ff4007b,0x00000000}},	//   _בהתא, _yeyk, إسكا, --, 
   {{0x645c6333,0xed580114,0x3ef80276,0x3134014b}},	//   _zapi, _psž_, унцэ_, _кемр, 
   {{0xed586334,0x645c6335,0x20186336,0x51846337}},	//   тол_, _yapi, bapi_, _суна, 
   {{0x20186338,0x6aa86339,0xed5800d7,0xaf08007b}},	//   capi_, wief, _vsž_, _لقسم_, 
   {{0x6aa809f2,0x2eec03fa,0x00000000,0x00000000}},	//   tief, _tief_, --, --, 
   {{0xa924633a,0xed041424,0x00000000,0x00000000}},	//   адил, _نورپ, --, --, 
   {{0x661431ac,0xc5f402a8,0xe9d800a7,0xac5800f3}},	//   _reyk, _saɓo_, ъки_, _иааф_, 
   {{0x2d9c633b,0x7b08000d,0x00000000,0x00000000}},	//   mzwe_, õrtö, --, --, 
   {{0xe73815ed,0x2d9c009a,0x66140213,0x00000000}},	//   њем_, lzwe_, _peyk, --, 
   {{0x645c633c,0x20180113,0x69dc39bc,0x4ae401a9}},	//   _sapi, zapi_, _परपी, _сўза, 
   {{0x2d9c633d,0x20180bf1,0xba7405af,0x00000000}},	//   nzwe_, yapi_, _دالت, --, 
   {{0x645c633e,0x69d8633f,0xc5f403f9,0x2d9c014b}},	//   _qapi, _izwe, _taɓo_, izwe_, 
   {{0xa8640831,0x645c6340,0x20186341,0x66140083}},	//   _беҙҙ, _vapi, vapi_, _teyk, 
   {{0x645c6342,0xdf740799,0x20186343,0xdce00115}},	//   _wapi, یداب, wapi_, rvoĉ, 
   {{0x20186344,0xdb181497,0x66d41a03,0x2d9c00ca}},	// [6f00] tapi_, _extè, láko, jzwe_, 
   {{0xb9dc067d,0x60246345,0x645c0066,0x2d9c6346}},	//   _ኢዩ_, рджа, _uapi, dzwe_, 
   {{0x20186347,0x54780302,0x66d40f91,0x00000000}},	//   rapi_, _סטטו, náko, --, 
   {{0x20186348,0x1d086349,0x9da802e8,0x00000000}},	//   sapi_, веди_, къла_, --, 
   {{0x2018634a,0x66d40cde,0x4438634b,0xbf640014}},	//   papi_, háko, ogr_, _گۯاو, 
   {{0x20181bb7,0xd004634c,0x66d4634d,0x91d80150}},	//   qapi_, _вере_, káko, _рәсi, 
   {{0x69d8634e,0x443803cb,0xd138010a,0x00000000}},	//   _azwe, igr_, _пхӳ_, --, 
   {{0x3a741edb,0x69d80100,0x9f480248,0x66d4634f}},	//   слир, _bzwe, _igbà_, dáko, 
   {{0x7e606350,0xa3e42c2e,0x13c000cd,0x00000000}},	//   _iamp, बेत_, _षड्भ, --, 
   {{0x7e606351,0x7878010b,0x20c46352,0x9a2400e5}},	//   _hamp, уйор_, वविध, _چٹان, 
   {{0x5018025f,0x69d86353,0x4ff4008f,0x9b34010b}},	//   כויו, _ezwe, יזיע_, _түйс_, 
   {{0x7e606354,0x443800a9,0xab600220,0xd9440108}},	//   _jamp, egr_, _ءۇيى, _веди, 
   {{0x7e606355,0xaae46356,0x4a98008f,0xb8dc00fe}},	//   _mamp, _اسلو, _ביאג, _আঠ_, 
   {{0x7c386357,0x66d40518,0x9f4801e1,0x176800db}},	//   ngvr, báko, _ogbà_, _арип_, 
   {{0x92a40640,0x9f480241,0xd3e0036b,0xd6d80354}},	//   ајал, _ngbà_, زقری, _ити_, 
   {{0x7e606358,0x66d402fb,0x86c46359,0x69dc01ad}},	//   _namp, nákl, _ويون, _परमी, 
   {{0x9f480248,0x44380076,0xfaf800ef,0x00000000}},	// [6f10] _agbà_, bgr_, _luī_, --, 
   {{0xdb18635a,0x7e601c06,0x25a40209,0x825002d3}},	//   _exté, _aamp, _ýola_, _ሕጽረታ, 
   {{0x7e60635b,0x63a00198,0xc0580220,0x3ef80139}},	//   _bamp, _ƙone, шіт_, анхэ_, 
   {{0x21ec00e4,0x9148022e,0x00000000,0x00000000}},	//   _ẽhe_, _ичга_, --, --, 
   {{0x7e60635c,0x66d402fb,0x2d9c009f,0xc67c0092}},	//   _damp, záko, uzwe_, _እየሠራ_, 
   {{0x7e6003ac,0x00000000,0x00000000,0x00000000}},	//   _eamp, --, --, --, 
   {{0x7e60325f,0xc600045e,0x6f9400c6,0xab7838eb}},	//   _famp, ্ণতা_, _الأض, امعا_, 
   {{0x7e602ebe,0x66d401f1,0xae44004b,0xa91c0153}},	//   _gamp, váko, _دپرو, lyži, 
   {{0xe9a8034c,0xe8c813c3,0x321802e2,0x9f480ca8}},	//   دگان_, лгил_, _mesy_, _igbá_, 
   {{0x7e60635d,0x3218635e,0x66d4635f,0xcc840133}},	//   _zamp, _lesy_, táko, _خۆته_, 
   {{0x6d5802d0,0x92140709,0xe7380139,0x00000000}},	//   lwwa, तराज_, ыен_, --, 
   {{0x7e606360,0x66d46361,0x6d580a55,0x6e38015d}},	//   _xamp, ráko, owwa, ngwb, 
   {{0x69d82798,0x4438005a,0x66d46362,0x00000000}},	//   _uzwe, tgr_, sáko, --, 
   {{0x32180493,0x66d46363,0x6d5822a9,0x00000000}},	//   _aesy_, páko, iwwa, --, 
   {{0x66e46364,0x44386365,0xe2986366,0x68f86367}},	//   _лока, rgr_, гав_, _huwd, 
   {{0x75e001f2,0x9f4801e1,0x23280c60,0xdb0400e5}},	//   _ịzen, _ngbá_, коҳи_, ímél, 
   {{0x32186368,0x443805d5,0x602401c6,0x91e011f4}},	// [6f20] _desy_, pgr_, йдаа, зоте, 
   {{0x81bc03f4,0x7e606369,0x7e10433a,0x68f80083}},	//   েইল_, _samp, ार्ग_, _muwd, 
   {{0x6d58636a,0x7e60636b,0xa21c0408,0x6720636c}},	//   ewwa, _pamp, _панă_, nslj, 
   {{0x7e60636d,0xc2946071,0xbe3400db,0x00000000}},	//   _qamp, _بیرب, تۉرب, --, 
   {{0x628402b5,0xe2c83d93,0x8fa000c7,0x6d5802d0}},	//   _ioko, _لوگو_, _ҵаре, gwwa, 
   {{0x6284636e,0x6f140007,0x9f4801e1,0x4cb41cb8}},	//   _hoko, _fwzc, _egbá_, блію_, 
   {{0x6284636f,0x6d580a55,0xfaf8003a,0x7c380373}},	//   _koko, awwa, _quī_, rgvr, 
   {{0x62846370,0x68f80083,0x672001a6,0x02c807b7}},	//   _joko, _buwd, dslj, लविभ, 
   {{0x62846371,0xcd580014,0x47cc00cc,0xea6400e5}},	//   _moko, _مسٕچ_, হেমী, تھلی, 
   {{0x62846372,0x68f801f5,0x6c740354,0x6298036e}},	//   _loko, _duwd, _мухх, ëtoj, 
   {{0x76b828cf,0x629800e2,0x67206373,0x628439ed}},	//   илор_, ītoj, gslj, _ooko, 
   {{0x62840183,0x21e002b5,0x6a6401d5,0x66d400d0}},	//   _noko, _kōhī_, _وطنل, bákm, 
   {{0x32180170,0xa3e40bc0,0x99d40137,0xf8a80133}},	//   _resy_, बेस_, _اتاا, _نگده_, 
   {{0x62846374,0xd4983129,0x6700063f,0x69dc041c}},	//   _aoko, урм_, ịkat, _परती, 
   {{0x62846375,0x32180270,0xd2d400c6,0xdce0009b}},	//   _boko, _pesy_, مغرب, jvoč, 
   {{0x68f800a2,0x44f401e2,0x00000000,0x00000000}},	//   _yuwd, _کسيز, --, --, 
   {{0xf0e80058,0x764c6376,0x3f68510c,0x00000000}},	// [6f30] لىرى_, _ibay, _ağu_, --, 
   {{0x17240003,0x7c280109,0x09dc0327,0xdb1801ef}},	//   _རྗོམ_, _nddr, སྟྲ_, _sytý, 
   {{0x62846377,0xa91c0006,0x4f68004e,0x85b80066}},	//   _foko, ryži, ышам_, _نایس_, 
   {{0x7c286378,0x62846379,0x2dd4361e,0x00000000}},	//   _addr, _goko, ожер, --, 
   {{0x764c637a,0x3d14012c,0x6d58198f,0xdb180306}},	//   _mbay, नीले_, uwwa, _vytý, 
   {{0x6284055a,0x0f18637b,0x66d400d0,0x00000000}},	//   _zoko, _مغرب_, vákm, --, 
   {{0xeb98637c,0x6284637d,0x31681529,0x270402b5}},	//   рий_, _yoko, lvaz_, _kēne_, 
   {{0x6284637e,0x7c280363,0x17240327,0x00000000}},	//   _xoko, _eddr, _རྗེམ_, --, 
   {{0x6e28637f,0xe8f81f5a,0xb90800f2,0xdb180210}},	//   _ideb, јло_, یزیم_, _bytó, 
   {{0x764c48d8,0x7d040029,0x6720002d,0x7b0c01e4}},	//   _abay, ģist, tslj, fĵuĝ, 
   {{0x31680007,0xe6880b8c,0x7d040311,0x66e400c0}},	//   hvaz_, لندى_, ţist, жона, 
   {{0x764c1529,0xf408011a,0x00000000,0x00000000}},	//   _cbay, _יפ_, --, --, 
   {{0x62846380,0x6e28009f,0xdce00219,0x6720007c}},	//   _roko, _mdeb, zvoč, sslj, 
   {{0x764c07d5,0x62846381,0x290c000d,0x64a4009d}},	//   _ebay, _soko, mpea_, цага, 
   {{0x62840cf1,0x6e286382,0x290c6383,0x21e002b5}},	//   _poko, _odeb, lpea_, _mōhū_, 
   {{0x6e286384,0x28dc6385,0x62840429,0x290c6386}},	//   _ndeb, _नीति, _qoko, opea_, 
   {{0x62846387,0x64c40c8b,0x31680007,0x290c005a}},	// [6f40] _voko, _ويبل, gvaz_, npea_, 
   {{0x6e286388,0x62846389,0x66d400e5,0x5fd401f4}},	//   _adeb, _woko, kákk, оцеф, 
   {{0x6284638a,0x316801fa,0x6e280175,0x9e640b7e}},	//   _toko, avaz_, _bdeb, жвед, 
   {{0x6e281529,0x6284638b,0xd3700345,0x00000000}},	//   _cdeb, _uoko, _تێفک, --, 
   {{0xa3e405dc,0x6e28638c,0x00000000,0x00000000}},	//   बेर_, _ddeb, --, --, 
   {{0x6e28638d,0x1ea800ec,0xcf2c0205,0x00000000}},	//   _edeb, _ڦاسي_, üşüm_, --, 
   {{0x6d5c006a,0x00000000,0x00000000,0x00000000}},	//   _âsan, --, --, --, 
   {{0x6e280472,0xdd901f7a,0xf8b831ee,0xdb200241}},	//   _gdeb, _قوز_, өөл_, _àríf, 
   {{0x764c638e,0xdb18638f,0xdde8009a,0x00000000}},	//   _rbay, _ixtí, _ضرره_, --, 
   {{0x7c2800b5,0x6e2801a6,0xd90c2c04,0xc8c400e3}},	//   _uddr, _zdeb, _ییب_, يوين_, 
   {{0x290c5632,0x97a401b9,0x36d46390,0x4730009d}},	//   apea_, юрил, зонр, мнэс, 
   {{0xc5f40b45,0x00000000,0x00000000,0x00000000}},	//   _zaɓi_, --, --, --, 
   {{0xfaf800da,0x19b4007b,0x58846391,0xc86800ef}},	//   _trīs_, _بحاج, _мыка, _ķīvē, 
   {{0x14c811ed,0x2be017cb,0x27040171,0x00000000}},	//   рыми_, _फरमा, _sēne_, --, 
   {{0x63a003f9,0x270402b1,0xa3e41f13,0x7c3c02d2}},	//   _ƙona, _pēne_, बेल_, _örru, 
   {{0xb38802d3,0x21ec00c7,0x926801a9,0x00000000}},	//   _ዚኸውን_, _ẽha_, шрга_, --, 
   {{0xd36c104b,0x7ce456eb,0x9484010b,0x03ec03d4}},	// [6f50] رۇڭ_, mòrf, _дынд, জুলী_, 
   {{0x316804cc,0x4f686392,0x44b44684,0x00000000}},	//   rvaz_, ишем_, _обыс, --, 
   {{0xb8fc1b4b,0x9f48025a,0x270400b0,0x290c01c4}},	//   _ཡེ_, _ngbä_, _tēne_, zpea_, 
   {{0xc5f403f9,0x82f82ab4,0x9f4801d3,0xb42400e5}},	//   _saɓi_, _گریز_, áján_, _بٹھو, 
   {{0x6e28009a,0x3eb00419,0x704801f0,0x00000000}},	//   _vdeb, _žltú_, _гӯем_, --, 
   {{0xeb986393,0x60f80375,0x188c0023,0x00000000}},	//   йил_, _להשק, _ዝፈጥር_, --, 
   {{0xfd6405db,0xfc3021ec,0x00000000,0x00000000}},	//   _karị, ئحه_, --, --, 
   {{0x6e286394,0x00000000,0x00000000,0x00000000}},	//   _udeb, --, --, --, 
   {{0xc5f40198,0x81b00198,0x290c0421,0x3ea80133}},	//   _taɓi_, taɓi, upea_, _بێنێ_, 
   {{0xfd6402e3,0x290c14b8,0xe7380da9,0x00000000}},	//   _larị, rpea_, бео_, --, 
   {{0x69dc0b7d,0x7b643e4f,0x290c000d,0x00000000}},	//   _परवी, _отце, spea_, --, 
   {{0x6700063f,0x290c32bb,0x00000000,0x00000000}},	//   ịkot, ppea_, --, --, 
   {{0x228c032e,0x09cc00eb,0x00000000,0x00000000}},	//   _mýkt_, াইহা, --, --, 
   {{0xf868004b,0xc8e40244,0x00000000,0x00000000}},	//   _ومني_, _بوتۆ_, --, --, 
   {{0xe2940261,0xa3e405b3,0xa2e4009d,0x76640108}},	//   праќ, बें_, зовд, ötyä, 
   {{0xe1f806f7,0x80d40034,0xe29800a7,0xe52400d8}},	//   сга_, _बीजे, щаб_, _едип, 
   {{0x26d000ca,0x661405be,0xddc00432,0x070401f7}},	// [6f60] _ikyo_, čakč, deoş, _ايڊي_, 
   {{0xd12c044d,0x443c3c38,0xeff00023,0x00000000}},	//   امل_, _øv_, ውጋድ_, --, 
   {{0xe3b056e1,0x2ff801b9,0x5f0400d4,0x00000000}},	//   _سرد_, زونگ_, їзда, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc67c001f,0x6294037e,0x8e4400ae,0x00000000}},	//   _እየሰራ_, mkyo, سلوك_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x629404ce,0xc2140134,0x00000000,0x00000000}},	//   nkyo, nbɔ_, --, --, 
   {{0x224005b1,0xdcb02f7c,0xc8c401ad,0xde380092}},	//   _mckk_, _كىر_, रकंट, _የምናው, 
   {{0x26d004ba,0xe8502374,0xdea002f2,0x00000000}},	//   _akyo_, نچىد, _تیڤی, --, 
   {{0x38a001ab,0xb7d802f2,0x00000000,0x00000000}},	//   _lòrg_, تودا_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x95c80228,0xdb4c04d3,0x55040a89,0xe3a800eb}},	//   суна_, _شێک_, ячна, _খুলব, 
   {{0x26d02f99,0xc2140134,0x5fbc1221,0xb39c074d}},	//   _ekyo_, ebɔ_, ्थाल, алгi, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x798400b0,0x09cc0154,0x00000000,0x00000000}},	//   _tōwā, াইরা, --, --, 
   {{0x51846395,0x11d42e67,0xb80000bc,0x00000000}},	// [6f70] чува, سترد, _ईलाम_, --, 
   {{0x62941418,0x66d401d3,0xce3000f1,0x228c02d2}},	//   akyo, váki, ځواک, _sýkt_, 
   {{0x270402b1,0x7afc01d3,0x00000000,0x00000000}},	//   _kēna_, _érth, --, --, 
   {{0x270400ef,0x63b800d7,0x00000000,0x00000000}},	//   _jēna_, útne, --, --, 
   {{0x270402b1,0x249c0153,0xaffc0354,0x9990010e}},	//   _mēna_, šymų_, _вогi, _ýyň_, 
   {{0xfd106396,0xeff0044e,0x2c6c01ed,0x27040171}},	//   اجن_, ውላው_, ködő_, _lēna_, 
   {{0x68ec04cc,0x660401e3,0x8d74085b,0xe6900240}},	//   _èadi, yckk, _کازا, _ዚገብሮ_, 
   {{0x49600209,0x5c7005a2,0x00000000,0x00000000}},	//   ениң, еләт, --, --, 
   {{0xa9682ed8,0x29186397,0x00000000,0x00000000}},	//   ципа_, èsa_, --, --, 
   {{0x38a02508,0x3b8c0020,0x50bc0882,0x7ce4067c}},	//   _nòrd_, ንያዎች_, ्विष, gòrd, 
   {{0xb9046398,0x26180073,0x629401f4,0x4ae400c0}},	//   _भी_, परली_, ykyo, _еўда, 
   {{0x9f48006a,0x290002b5,0x6cd40150,0x00000000}},	//   _agbû_, _ōhau_, _ﺘﻬﺠﻴ, --, 
   {{0x95801c22,0x38a00013,0xa3e400e1,0x00000000}},	//   вляе, _bòrd_, _बृज_, --, 
   {{0xc8380020,0x38a001c3,0xd84c01fb,0x7ce41f40}},	//   _በበኩላ, _còrd_, _họng_, còrd, 
   {{0xe7180be2,0xf3f00154,0x36e800f2,0x00000000}},	//   _بيعت_, _জ্বর_, تریپ_, --, 
   {{0x81b00198,0x26d0020c,0x7ce4067c,0xaadc227c}},	//   zaɓu, _ukyo_, mòre, मतिक, 
   {{0xd84c004d,0x85b4013d,0xfdb800eb,0x00000000}},	// [6f80] _mọng_, _чәнч, _জর্ড, --, 
   {{0x1fb44990,0x62946399,0xd84c0208,0x27040171}},	//   мсер, skyo, _lọng_, _zēna_, 
   {{0x4444123b,0xd598037e,0xd4780375,0xdb1801f4}},	//   _ic_, ngの_, _ואיל, _hytö, 
   {{0x7bdc00a3,0xdb1801f4,0x644c007c,0x7afc00e5}},	//   _ùrui, _kytö, lfbi, _érti, 
   {{0xdca4639a,0x81b00198,0x0d2000f7,0x44440f85}},	//   мади, taɓu, күтү, _kc_, 
   {{0x16b8639b,0x44443046,0x00000000,0x00000000}},	//   _उद्ब, _jc_, --, --, 
   {{0xdfd03cc6,0x4444639c,0x5040384f,0xd84c0208}},	//   _شير_, _mc_, _шерб, _bọng_, 
   {{0x2ec841ac,0xd84c004d,0x80cc0073,0x00000000}},	//   िकृत, _cọng_, तकवे, --, 
   {{0x4444639d,0x1c44639e,0xd84c0051,0x6b9c06be}},	//   _oc_, _онам, _dọng_, _əsgi, 
   {{0x4444639f,0xdb180306,0xd8b80d17,0x00000000}},	//   _nc_, _extá, تدعا_, --, 
   {{0x0b4005f5,0x7d0063a0,0x270402b5,0x103402e4}},	//   _анхн, _hums, _pēna_, וטים_, 
   {{0x444463a1,0x7d0063a2,0xd84c004d,0x7ce40ba1}},	//   _ac_, _kums, _gọng_, sòrd, 
   {{0x444463a3,0x7d0063a4,0x644c050a,0x59e063a5}},	//   _bc_, _jums, ffbi, _परिर, 
   {{0x444463a6,0x7d0063a7,0x3a2463a8,0xdb2001e1}},	//   _cc_, _mums, lamp_, _òróg, 
   {{0x444463a9,0x270402b1,0xe3c463aa,0x00000000}},	//   _dc_, _tēna_, ертү, --, 
   {{0x444463ab,0x3a2463ac,0x38b401e1,0x59e000dc}},	//   _ec_, namp_, _fùrè_, _परार, 
   {{0x44445e69,0x7d0063ad,0x765c63ae,0x00000000}},	// [6f90] _fc_, _nums, mesy, --, 
   {{0xfe705c81,0x44440f85,0x765c1be9,0x753c63af}},	//   یدن_, _gc_, lesy, musz, 
   {{0x3a2463b0,0xb4bc3daa,0x753c514a,0x6e9463b1}},	//   kamp_, ेकी_, lusz, нижу, 
   {{0x7d0063b2,0x444463b3,0x765c63b4,0xbeac63b5}},	//   _bums, _zc_, nesy, _üçlü, 
   {{0x7d0063b6,0x444463b7,0x32085cba,0xa2c063b8}},	//   _cums, _yc_, mcay_, _сәрк, 
   {{0xf41c00bd,0x32082f05,0x8c400276,0xa3e4012c}},	//   _তাঁর_, lcay_, ăşoa, बेक_, 
   {{0x765c63b9,0xdb4c01d9,0x320803ac,0x00000000}},	//   kesy, مَو_, ocay_, --, 
   {{0x32082f05,0xc3340375,0x753c514a,0x765c033b}},	//   ncay_, דוק_, kusz, jesy, 
   {{0xd84c0016,0x765c63ba,0x32080334,0x753c0c57}},	//   _vọng_, desy, icay_, jusz, 
   {{0x1cdc0135,0x32080c8c,0x753c0034,0xe7a863bb}},	//   _ལེར_, hcay_, dusz, звол_, 
   {{0x765c63bc,0x2d4829d3,0x6a14084c,0x444463bd}},	//   fesy, lúe_, _змеу, _rc_, 
   {{0x3a2463be,0x38a0067c,0x7d003149,0x765c63bf}},	//   camp_, _còrb_, _yums, gesy, 
   {{0x753c066d,0x32082f05,0x444463c0,0x2d4863c1}},	//   gusz, dcay_, _pc_, núe_, 
   {{0x444463c2,0x291c01c7,0x32080c8c,0x3d140073}},	//   _qc_, _iwwa_, ecay_, नीटे_, 
   {{0x444463c3,0xe81405ba,0xfddc03f3,0x69d82f50}},	//   _vc_, _द्या_, _बर्फ, _hywe, 
   {{0xe6180517,0x444463c4,0xdb1802f6,0x6d480023}},	//   _эди_, _wc_, _tytö, _oqea, 
   {{0x44442238,0x753c012d,0x00000000,0x00000000}},	// [6fa0] _tc_, cusz, --, --, 
   {{0x444463c5,0x69d863c6,0x66d40008,0x5f04034b}},	//   _uc_, _mywe, ráku, езжа, 
   {{0x7d0063c7,0x3a240227,0xd00c0451,0x69d8015d}},	//   _sums, yamp_, صلن_, _lywe, 
   {{0x291c0004,0x3a240585,0x1718008f,0x3208127b}},	//   _owwa_, xamp_, פונע, ccay_, 
   {{0x69d863c8,0x3a2463c9,0x7d0063ca,0xbeac00a2}},	//   _nywe, vamp_, _qums, _üçmü, 
   {{0x765c63cb,0x3a24020c,0x00000000,0x00000000}},	//   zesy, wamp_, --, --, 
   {{0x3a240054,0x7d000117,0x69d803ac,0x753c033f}},	//   tamp_, _wums, _aywe, zusz, 
   {{0x7d0063cc,0x2d48172e,0x0d8047da,0x69d863cd}},	//   _tums, búe_, тлән, _bywe, 
   {{0x765c63ce,0x3a2463cf,0x8650013b,0x7d00208d}},	//   vesy, ramp_, _mmɔd, _uums, 
   {{0x69d80cfd,0x291c007f,0x7798036b,0x765c63d0}},	//   _dywe, _dwwa_, дкор_, wesy, 
   {{0x59e03994,0x320814dc,0x3a240054,0xe0dc00cc}},	//   _परवर, ycay_, pamp_, _ভূৱন, 
   {{0x753c4579,0x3208127b,0x999000e5,0x07e00022}},	//   tusz, xcay_, ődők_, ыцым, 
   {{0x765c63d1,0x69d80042,0x320803ac,0x00000000}},	//   resy, _gywe, vcay_, --, 
   {{0x765c63d2,0x753c068f,0x1cdc025c,0xb4bc63d3}},	//   sesy, rusz, _ལེས_, ेके_, 
   {{0x765c63d4,0x320814dc,0xf8b00583,0x753c012d}},	//   pesy, tcay_, _مکھ_, susz, 
   {{0x753c295f,0x32080014,0x7bdc01ab,0xd24401c6}},	//   pusz, ucay_, _ùruu, ээги, 
   {{0x32082f05,0x66d40998,0x00000000,0x00000000}},	// [6fb0] rcay_, rákt, --, --, 
   {{0x32082f05,0x2d4845a7,0xf8d01524,0xb150001f}},	//   scay_, vúe_, सकिय, _ሕይወታ, 
   {{0xfd500882,0x3208127b,0x8d8428c4,0x00000000}},	//   mokṣ, pcay_, کشان, --, 
   {{0x752c00c8,0x2d48172e,0xa2c00316,0x320802d0}},	//   _kvaz, túe_, रचण्, qcay_, 
   {{0x41e4005e,0x7bc80113,0x00000000,0x00000000}},	//   _біра, _axdu, --, --, 
   {{0x2d480005,0x7ce4067c,0x69d80142,0x00000000}},	//   rúe_, vòrc, _rywe, --, 
   {{0xdca063d5,0x2d48172e,0x7f58010b,0x00000000}},	//   ращи, súe_, _парс_, --, 
   {{0x6f0802fd,0x752c04cc,0x387c01f5,0x7ce4067c}},	//   _čech, _ovaz, _anvr_, tòrc, 
   {{0xcb5c002e,0x3ec4013d,0x7a840e56,0x00000000}},	//   _g茜nn_, _ссрб, اشىم, --, 
   {{0xb4bc0dc5,0x01c401ec,0xc79400e5,0x00000000}},	//   ेको_, _ﺭﺃﻴﻨ, ٹھتا_, --, 
   {{0x752c63d6,0xddc0005f,0x45fc0327,0xb4bc00bc}},	//   _avaz, mdoš, _དཔྱས_, ेकै_, 
   {{0x38a00ba1,0x7ce4180f,0xddc000e2,0x693463d7}},	//   _pòrc_, mòra, ldoš, _анду, 
   {{0x291c063f,0x2a6c017a,0x7ce400a3,0xed5801ef}},	//   _uwwa_, mdeb_, lòra, _jpž_, 
   {{0x2a6c00a9,0xe7381c3e,0xf77063d8,0x752c107d}},	//   ldeb_, _жек_, _گاه_, _dvaz, 
   {{0x752c63d9,0x7bc80076,0x142063da,0x00000000}},	//   _evaz, _xxdu, рдсм, --, 
   {{0x2a6c00a9,0xf7701ec7,0xd1c80092,0x00000000}},	//   ndeb_, _داه_, በሰቡ_, --, 
   {{0x910063db,0xe2f80220,0x47f001c6,0x752c0153}},	// [6fc0] ипте, зеңі_, _шүүр, _gvaz, 
   {{0xddc01155,0xd24c0050,0x00000000,0x00000000}},	//   jdoš, ٝنہ_, --, --, 
   {{0x3f9c63dc,0x752c0e8a,0xd434010f,0x00000000}},	//   ávu_, _zvaz, _בריק_, --, 
   {{0x65740023,0x38a00e89,0x26c0037e,0xddc000e2}},	//   _kryh, _mòra_, nnko_, edoš, 
   {{0x7ce401ab,0x0dc463dd,0x9cc800ee,0x26c0005b}},	//   eòra, куши_, мыка_, inko_, 
   {{0x61e44db8,0x0c700075,0x2a7c63de,0x69c40490}},	//   _izkl, لدىد, _anwb_, ापनी, 
   {{0x69dc245f,0x86500134,0x7ce4067c,0x00000000}},	//   üsen, _mmɔb, gòra, --, 
   {{0xdee463df,0xdce063e0,0x2a6c031c,0xcb640114}},	//   _роби, kvoć, gdeb_, таће_, 
   {{0xd838205c,0xed3463e1,0x78d4009d,0x00000000}},	//   мэн_, _бэхэ, лжих, --, 
   {{0xdde001e0,0xd1dc0023,0x26c063e2,0xaa80010e}},	//   _йәһү, ሓፍቲ_, enko_, _äýne, 
   {{0x81d802a6,0x752c00bc,0x09cc03d4,0x9bd40022}},	//   াধি_, _svaz, াইগা, _рцаш, 
   {{0x657403cd,0xb4bc3309,0x00000000,0x00000000}},	//   _bryh, ेक्_, --, --, 
   {{0x98c463e3,0x18a400c7,0x855801ed,0xb93400d8}},	//   _искл, _иадм, نیٹر_, _селј, 
   {{0x09e00b46,0x81d804c5,0x38a0180f,0x09cc009e}},	//   _точн, াধা_, _fòra_, াইখা, 
   {{0xde38044e,0x6574089c,0x7afc00e5,0x1fbc19cc}},	//   _ከምኡው, _eryh, _érts, ्थोड, 
   {{0x752c0175,0x6574036e,0x00000000,0x00000000}},	//   _tvaz, _fryh, --, --, 
   {{0x752c63e4,0x506400db,0x00000000,0x00000000}},	// [6fd0] _uvaz, ктжа, --, --, 
   {{0xc0140354,0x00000000,0x00000000,0x00000000}},	//   имущ, --, --, --, 
   {{0x61e40156,0xfaf8005f,0x2a6c0042,0x3394005a}},	//   _ezkl, _drīz_, ydeb_, _санё, 
   {{0x47cc03d4,0x00000000,0x00000000,0x00000000}},	//   হেকী, --, --, --, 
   {{0x2a6c01d4,0xbdf800f2,0x00000000,0x00000000}},	//   vdeb_, نرها_, --, --, 
   {{0xed5801a6,0xa5d800df,0x00000000,0x00000000}},	//   _vpž_, ײַני, --, --, 
   {{0xddc063e5,0x95000327,0xe0d0010f,0x09c807f8}},	//   rdoš, _མངའི_, _הײם_, ाथ्य, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe8f856fd,0x2a6c00a9,0xe9d806d3,0x28b8084c}},	//   нли_, rdeb_, эки_, еунэ_, 
   {{0xfbd000cf,0x00000000,0x00000000,0x00000000}},	//   حتۇ_, --, --, --, 
   {{0x0eb40118,0x00000000,0x00000000,0x00000000}},	//   _आगाड, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xba743009,0x38a00086,0xb6c40032,0x37d40154}},	//   _خالت, _wòra_, рияһ, _হৃদর, 
   {{0x65740151,0x18642d55,0x3ae8002d,0x00000000}},	//   _vryh, _баши_, rûpe_, --, 
   {{0x61e40034,0x0ed00401,0x9fbc00eb,0x00000000}},	//   _szkl, तवाड, _অর্গ, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdee407d6,0x60e863e6,0x33640092,0x00000000}},	// [6fe0] ҳожи, емам_, _ትውልደ_, --, 
   {{0x61e40427,0xdfd0007b,0x00000000,0x00000000}},	//   _vzkl, ميذ_, --, --, 
   {{0xe29863e7,0x7ce456ed,0xb9080055,0xe12400d1}},	//   _зан_, fòrn, _dhiṅ_, _әмги, 
   {{0x3a2001e4,0x1ed818fd,0x3c580276,0xd12c0137}},	//   _ĵipo_, رباب_, ӂикэ_, زمۅ_, 
   {{0x61e4005f,0xdb2001e1,0x00000000,0x00000000}},	//   _uzkl, _àrúf, --, --, 
   {{0xe13400c7,0x3c580262,0xdb68319b,0x69dc024a}},	//   _инҭы, тикэ_, ерил_, _परजी, 
   {{0x38a00ba1,0xb2000790,0x9e5800c0,0x00000000}},	//   _bòrn_, şüşl, _праф_, --, 
   {{0xd91863e8,0x996405f5,0x38a001ab,0x97a40032}},	//   ньо_, гтол, _còrn_, ғрол, 
   {{0x3ea40194,0x38a001c3,0x9848117e,0x6e2c03b2}},	//   _ilmt_, _dòrn_, няна_, ðabe, 
   {{0x787401ed,0x38a001ab,0x7ce4067c,0x6aac0401}},	//   küvő, _eòrn_, mòro, टफॉर, 
   {{0x9f5c0724,0xdb781955,0x9f480cad,0x1b4800d4}},	//   _ütä_, _ясаш_, _igbó_, _їзди_, 
   {{0x36d42c31,0xcff4011a,0x00000000,0x00000000}},	//   ромр, טציה_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x38a000a3,0x335400f7,0x00000000,0x00000000}},	//   _hòro_, шүнө_, --, --, 
   {{0x7c68001f,0x1cdc0327,0x51840d1d,0x47301f7e}},	//   _ተችሏል_, _ལེཀ_, луза, _اروز, 
   {{0xa5c04afc,0x9f4801e1,0x00000000,0x00000000}},	// [6ff0] _дөре, _ogbó_, --, --, 
   {{0x38a00241,0x9f480241,0x00000000,0x00000000}},	//   _mòro_, _ngbó_, --, --, 
   {{0x00d83c97,0x7ae0010a,0xb90c0248,0x00000000}},	//   ابقت_, klmt, _pamọ_, --, 
   {{0x9f480ca8,0x4ea463e9,0x61e00327,0xbe8800d8}},	//   _agbó_, ырза, żola, лсче_, 
   {{0x07082aa1,0x00000000,0x00000000,0x00000000}},	//   _संभव_, --, --, --, 
   {{0xbfa802dd,0x00000000,0x00000000,0x00000000}},	//   _өтсе_, --, --, --, 
   {{0x6a8463ea,0x753c0112,0x00000000,0x00000000}},	//   илка, hrsz, --, --, 
   {{0xae44021a,0x09cc00fe,0xde4401ec,0x00000000}},	//   _خپرو, াইঘা, _ەرەۋ, --, 
   {{0xacf863eb,0x2be001f9,0x00000000,0x00000000}},	//   _анау_, _फरका, --, --, 
   {{0x27040374,0x1cdc031c,0x9f4801e1,0x00000000}},	//   _hēni_, _ལེག_, _igbò_, --, 
   {{0x7c9438eb,0x3cf00118,0x15e002dd,0x753c0e10}},	//   _اشقا, řové_, _ﺍﺭﺍﺩ, ersz, 
   {{0xfd4c01dc,0x38a00ba1,0xe8140950,0x659400c7}},	//   _nhiề, _fòro_, _द्रा_, ҳаҭу, 
   {{0x5e54008f,0x1a9800df,0x7c3008a5,0x00000000}},	//   סישע_, _שינע, _óhræ, --, 
   {{0x6aa8002f,0x270400de,0x00000000,0x00000000}},	//   lhef, _lēni_, --, --, 
   {{0xa2d463ec,0x66e42b97,0xa34802e8,0x96940107}},	//   ليست, _кока, ъзва_, урӯш, 
   {{0xfd4c0016,0xe57863ed,0x6aa813ee,0xf53800d0}},	//   _chiề, _ази_, nhef, šťa_, 
  
   {{0xe1f8006c,0x614463ee,0xd6cc06f6,0x6024016c}},	// [7000] тга_, реза, _تقي_, идаа, 
   {{0x3ea43223,0x4e940014,0x273c0092,0x00000000}},	//   _slmt_, یٖلس_, _በተሰበ, --, 
   {{0x1f6463ef,0x9f480ca8,0x6aa863f0,0x3ea40175}},	//   ркем, _agbò_, khef, _plmt_, 
   {{0xe29863f1,0x2eec63f2,0x175400c8,0x614463f3}},	//   _рам_, _chef_, יסער_, _кема, 
   {{0x6aa863f4,0xa3b8014d,0x00000000,0x00000000}},	//   dhef, _ساگر_, --, --, 
   {{0xa0a40228,0x1ea80451,0x25ec0037,0x00000000}},	//   _тагд, _ڌاري_, _घरनी_, --, 
   {{0x6aa81682,0x9f480248,0x31780010,0x27040171}},	//   fhef, _egbò_, _zrsz_, _fēni_, 
   {{0xdd145dcd,0x4e940014,0x27040171,0x00000000}},	//   _نورخ, _پھٔج_, _gēni_, --, 
   {{0x78a802b9,0xf8b863f5,0xdc680022,0x4ef80375}},	//   thdv, лөк_, _иаад_, _יהלו, 
   {{0xfaf80055,0x961c4142,0xf8d000bc,0x9f480248}},	//   _asīt_, पर्ट_, सकेप, _ugbó_, 
   {{0x7c2800de,0x9a84205a,0x00000000,0x00000000}},	//   _iedr, _вулл, --, --, 
   {{0x7c2863f6,0x68e00076,0x2eec0200,0x5958010a}},	//   _hedr, alld, _xhef_, _ашкă, 
   {{0x7c2803b4,0x95c80228,0x09e010f3,0xd40402a9}},	//   _kedr, туна_, _доцн, ияви, 
   {{0x7c281dd5,0x394400da,0x37c40124,0xef28004e}},	//   _jedr, mums_, _гәмб, ngüí_, 
   {{0x7c2863f7,0xfd4c001e,0x394463f8,0x00000000}},	//   _medr, _phiề, lums_, --, 
   {{0x7c2863f9,0x6d5c014a,0xcb34011a,0x2ec400cd}},	//   _ledr, _äsag, יאלי_, _वदेत, 
   {{0x70580323,0x394463fa,0x764c00ca,0x7c280368}},	// [7010] лаар_, nums_, _icay, _oedr, 
   {{0x850404fb,0x2eec0023,0x7ce4180f,0x1cdc031c}},	//   _گوین, _shef_, fòrm, _ལེཊ_, 
   {{0x39440198,0xfd4c01fb,0x6aa801e2,0x00000000}},	//   hums_, _thiề, yhef, --, 
   {{0x39440029,0x850435aa,0x2f300210,0x00000000}},	//   kums_, _دوین, rąg_, --, 
   {{0x394411f9,0x68e063fb,0xd1dc02d3,0x518463fc}},	//   jums_, ylld, ዓልቲ_, _туна, 
   {{0x3944005f,0x2eec0175,0xb05401d3,0xab2801a9}},	//   dums_, _whef_, _دھرت, гока_, 
   {{0x6aa863fd,0x31682165,0x76400024,0x9b9000d8}},	//   thef, lwaz_, ėlyj, зијц, 
   {{0x7c28035a,0xa924059f,0x4ea40120,0x00000000}},	//   _eedr, бдил, _трга, --, 
   {{0x394400da,0x7c2863fe,0x31680165,0xac1806b5}},	//   gums_, _fedr, nwaz_, _бозу_, 
   {{0x7c2863ff,0x764c6400,0x6e286401,0x228c02f0}},	//   _gedr, _acay, _heeb, _dýky_, 
   {{0x6aa86210,0x6e286402,0x31680589,0x38a001ab}},	//   phef, _keeb, hwaz_, _gòrm_, 
   {{0xba740597,0x6e286403,0x316815d9,0x7c28005a}},	//   _وانت, _jeeb, kwaz_, _zedr, 
   {{0x7c280b6f,0x6e286404,0x764c0076,0x39446405}},	//   _yedr, _meeb, _dcay, cums_, 
   {{0x6e286406,0x764c035a,0x00000000,0x00000000}},	//   _leeb, _ecay, --, --, 
   {{0x23d06407,0x98a0005b,0x53a06408,0xf42000fe}},	//   _दुखद, _хище, парб, _বাখৰ_, 
   {{0xa2046409,0x6e28640a,0x2168640b,0x764c0076}},	//   спад, _neeb, либи_, _gcay, 
   {{0x31681e1a,0xa6e003b2,0x00000000,0x00000000}},	// [7020] gwaz_, øðue, --, --, 
   {{0xdb0801d3,0x00000000,0x00000000,0x00000000}},	//   szfé, --, --, --, 
   {{0x7c28640c,0x6e28640d,0xf00000d1,0x394400e2}},	//   _redr, _beeb, дүри, zums_, 
   {{0x7c28640e,0x1ec807dd,0x6e28640f,0x00000000}},	//   _sedr, ылеи_, _ceeb, --, 
   {{0x6e280a4d,0xcf8c004b,0x931000f1,0x00000000}},	//   _deeb, وژې_, _وویش, --, 
   {{0x3944005f,0x7b8400d1,0x7c2806be,0x201c032e}},	//   vums_, قابە, _qedr, _ýti_, 
   {{0x6e286410,0xdee401c6,0x3f6845d8,0x00000000}},	//   _feeb, _гови, _uşu_, --, 
   {{0x39446411,0x39140c17,0xa0a41ee3,0x6e281559}},	//   tums_, омир, _таҳд, _geeb, 
   {{0x56f005f5,0xd00c01ed,0x9804010b,0x764c6412}},	//   үүлс, _آلہ_, йянд, _rcay, 
   {{0x6e286413,0x39446414,0x27040171,0x00000000}},	//   _zeeb, rums_, _lēnu_, --, 
   {{0x6e286415,0x39446416,0xb78800fd,0x00000000}},	//   _yeeb, sums_, рәле_, --, 
   {{0x6e286417,0x1cdc031c,0xcf900375,0x394400e2}},	//   _xeeb, _ལེཌ_, לטת_, pums_, 
   {{0xceb00a1e,0x00000000,0x00000000,0x00000000}},	//   פיש_, --, --, --, 
   {{0x94a86418,0xf1c400c0,0x00000000,0x00000000}},	//   утма_, nišų_, --, --, 
   {{0xd258503d,0x4c9808a8,0x2d9c012d,0x00000000}},	//   лца_, נבלו, zywe_, --, 
   {{0x92680598,0x764c568e,0x00000000,0x00000000}},	//   ырга_, _ucay, --, --, 
   {{0x6e286419,0x518400ea,0x8638011a,0x4938010f}},	// [7030] _reeb, љуба, _הרחב_, ָגבו, 
   {{0x3168641a,0x69dc04e6,0x00000000,0x00000000}},	//   rwaz_, üsei, --, --, 
   {{0xd17439fb,0x6e28641b,0x6e182ada,0x270400ef}},	//   шыңы, _peeb, لياس_, _fēnu_, 
   {{0x51843e2e,0x6e28641c,0x2d9c00aa,0x3168007f}},	//   _луга, _qeeb, tywe_, pwaz_, 
   {{0x6e28033d,0xacf8641d,0x0bb40137,0xf8d80073}},	//   _veeb, анду_, өткө_, डवाय, 
   {{0x6e28641e,0xd6cc00bd,0x2d9c0660,0x270400e2}},	//   _weeb, রতিয, rywe_, _zēnu_, 
   {{0x6e280070,0x5b100184,0xebc40124,0x00000000}},	//   _teeb, үмәт, цәан, --, 
   {{0xaa44035b,0x00000000,0x00000000,0x00000000}},	//   цеил, --, --, --, 
   {{0xf4000154,0x779000e5,0x00000000,0x00000000}},	//   ্রির_, ہیوا, --, --, 
   {{0x7c3435ce,0x289800d8,0x2bc82802,0x00000000}},	//   _неух, ртиќ_, िपदा, --, 
   {{0x4838001f,0xf1a807b6,0x0ba40108,0xac180117}},	//   _በአውሮ, चैतन, _ушам, _боҷу_, 
   {{0xaabc4f76,0xf4000154,0x00000000,0x00000000}},	//   _ऋषिक, ্রার_, --, --, 
   {{0x24e8641f,0xa5086420,0x29180306,0xc1c8012d}},	//   имми_, рега_, ísad_, _रखेग, 
   {{0x1cdc07e4,0x00000000,0x00000000,0x00000000}},	//   _ལེབ_, --, --, --, 
   {{0x6fd80034,0x23286421,0xe2b80114,0xe29801c4}},	//   _बुलं, роби_, аћај_, аав_, 
   {{0xe29812d7,0x249400c0,0x00000000,0x00000000}},	//   шаб_, _žemą_, --, --, 
   {{0x637000e4,0x91e001f4,0x270400de,0x273400e4}},	// [7040] _ẽndy, доте, _vēnu_, ẽndy_, 
   {{0x9f7858cb,0x20540006,0x00000000,0x00000000}},	//   исеф_, ўтар, --, --, 
   {{0x8c3801e1,0x00000000,0x00000000,0x00000000}},	//   _è̟ye, --, --, --, 
   {{0x7ce419c6,0x23b4069d,0x00000000,0x00000000}},	//   mòri, ለዋወጥ_, --, --, 
   {{0x9f48006a,0x1cdc031c,0x7ce400cf,0x00000000}},	//   _ngbö_, _ལེད_, lòri, --, 
   {{0xccb400d6,0xa2c000cd,0x4cb40816,0x00000000}},	//   огії_, रचक्, олію_, --, 
   {{0xb64801e1,0x9e646422,0xab600139,0xfe78014b}},	//   _emẹ̀, _وارن, _çüld, _гӯл_, 
   {{0x38600115,0x53980a1e,0x9db8008e,0x27040171}},	//   _ŝir_, ייצו, _кызу_, _lēns_, 
   {{0x09e00640,0x99640212,0xf42000fe,0x00000000}},	//   моћн, ітил, _বাঘৰ_, --, 
   {{0x6284010a,0xd7f801c0,0x88b0129e,0x41d8000d}},	//   _lnko, иун_, وینچ, _भँईस, 
   {{0x9af8002b,0x38a001e1,0x00000000,0x00000000}},	//   _aṃśu, _jòri_, --, --, 
   {{0x998448c1,0x38a06423,0x3a2000a2,0x00000000}},	//   _ولاو, _mòri_, _ýip_, --, 
   {{0xb7880032,0x55040024,0x00000000,0x00000000}},	//   рәһе_, ючна, --, --, 
   {{0x62846424,0x7ce400cf,0xd3240022,0xf40000eb}},	//   _anko, fòri, жьаи, ্রসর_, 
   {{0x1cdc1b35,0x32240135,0x7ce400db,0x00000000}},	//   _ལེན_, _འབྱར_, gòri, --, 
   {{0x645c0354,0xb114030d,0x00000000,0x00000000}},	//   _ebpi, змаш, --, --, 
   {{0xf0e8581f,0xf4840344,0x27040171,0xca94011a}},	// [7050] مىرى_, _فادی, _fēns_, קדמי_, 
   {{0x62846425,0xd0186426,0xfd4c063f,0x7ce400db}},	//   _enko, рфа_, shiọ, bòri, 
   {{0xdce02220,0x7ce400db,0x00000000,0x00000000}},	//   jvođ, còri, --, --, 
   {{0xdce008ad,0x59c80882,0xb2a80050,0x270400e2}},	//   dvođ, ापार, _چُھم_, _zēns_, 
   {{0x25fc06ab,0x067c010f,0x00000000,0x00000000}},	//   रेपी_, ינאל, --, --, 
   {{0x98a800bc,0x6ef001bf,0x00000000,0x00000000}},	//   čbě_, dåbe, --, --, 
   {{0xeb984997,0x62840b21,0x00000000,0x00000000}},	//   сий_, _ynko, --, --, 
   {{0xe7380184,0xa924086f,0x7f8404fb,0xab60010e}},	//   ҙем_, пдил, _تلفن, _çümd, 
   {{0x8c340107,0x2918036e,0x1e300101,0x00000000}},	//   _ҳоҷӣ_, ësa_, _سکنج, --, 
   {{0x50d805ba,0xe6100066,0x00000000,0x00000000}},	//   भविष, کشد_, --, --, 
   {{0x25ec069f,0xbb480597,0xe7380640,0x6fbc01ad}},	//   _घरही_, _ولكن_, љем_, ्पिं, 
   {{0x6604036b,0x00000000,0x00000000,0x00000000}},	//   япма, --, --, --, 
   {{0x7ce40428,0xdb200241,0x00000000,0x00000000}},	//   wòri, _àròf, --, --, 
   {{0x7ce46427,0x442c6428,0x64a46429,0x6fbc041c}},	//   tòri, úd_, чага, ्पां, 
   {{0xa6c40137,0xd7540066,0x00000000,0x00000000}},	//   _ىقتى, _فلوت_, --, --, 
   {{0x3f9c06ea,0x7ce4067c,0x28000118,0x13000395}},	//   øvum_, ròri, ěrně_, езсм, 
   {{0x26c0642a,0x7ce4642b,0xdce007f5,0x25a800f1}},	// [7060] miko_, sòri, zvođ, _ددغي_, 
   {{0x69340166,0x6458004e,0xa3b8642c,0x00000000}},	//   _işeğ, òtid, _هاجر_, --, 
   {{0x8e3402d3,0x3f9c00d2,0xa2e408ca,0x9cc80124}},	//   _ከምዝኸ, âvu_, _ноод, ҩыла_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9f48025a,0x9a10063f,0x10341d37,0x00000000}},	//   _agbô_, _mọtụ, زبەگ, --, 
   {{0x26c0642d,0x644c642e,0x6ef000b5,0x3f8401b9}},	//   hiko_, ngbi, våbe, _оғза, 
   {{0x26c0642f,0x60dc009a,0xac680023,0xaaec00b8}},	//   kiko_, mopm, ደበሮም_, _ṣaḍe, 
   {{0x26c06430,0xdd906431,0x4a500801,0x1cdc031c}},	//   jiko_, _كوز_, екъс, _ལེམ_, 
   {{0x26c06432,0x25fc4d53,0x61e40432,0xf8b800db}},	//   diko_, रेमी_, _jykl, жөй_, 
   {{0x61e44673,0x6ef000b5,0x00000000,0x00000000}},	//   _mykl, råbe, --, --, 
   {{0x26c06433,0x61e46434,0x53d8033f,0x36d40107}},	//   fiko_, _lykl, _मुंश, донр, 
   {{0x26c06435,0x3d3c001f,0x60dc014f,0x00000000}},	//   giko_, _አውቶቡ, hopm, --, 
   {{0x8650016b,0x20080521,0x60dc6436,0x24980175}},	//   _mmɔh, _ogbi_, kopm, _bopm_, 
   {{0x2008145e,0x73c400fd,0x53b401d5,0x644c007c}},	//   _ngbi_, дәме, зғор_, ggbi, 
   {{0x26c06437,0x693403e0,0x00000000,0x00000000}},	//   biko_, _eşeğ, --, --, 
   {{0x6fbc007d,0x26c04b7a,0x61e405ac,0xeac801fb}},	//   ्पसं, ciko_, _bykl, hẹn_, 
   {{0x25a01d8a,0xddc00477,0x75d43997,0x00000000}},	// [7070] cykl_, ngoń, _زيدا, --, 
   {{0x39446438,0x00000000,0x00000000,0x00000000}},	//   irms_, --, --, --, 
   {{0xc1040979,0xdfd005d9,0x73340131,0xdbd0180f}},	//   رومي, نيٰ_, _تىجا, qüèr, 
   {{0x7ff40116,0xffb4009d,0x00000000,0x00000000}},	//   رسلا, эйхэ, --, --, 
   {{0x9e9400db,0x61e40162,0xdbcc0139,0x00000000}},	//   بالچ, _gykl, dıñm, --, 
   {{0x26c06439,0x5064036b,0xb1500092,0xc05800d4}},	//   ziko_, _этма, _ዕርዳታ, _ніс_, 
   {{0xfc30643a,0x26c0643b,0x61e4643c,0x2fc401e6}},	//   احه_, yiko_, _zykl, _älg_, 
   {{0x79840784,0xc9740116,0x00000000,0x00000000}},	//   _šiwa, зәкч_, --, --, 
   {{0x26c0643d,0xedc4021a,0x644c0267,0xeac801e1}},	//   viko_, _کېږي_, ygbi, bẹn_, 
   {{0x26c0643e,0x6d58643f,0x7ce400cf,0x09e001d5}},	//   wiko_, mtwa, fòru, моқн, 
   {{0x6d586440,0x9a1001f2,0x3944002d,0x765c03cd}},	//   ltwa, _pọtụ, arms_, ffsy, 
   {{0x6b800857,0x6d586441,0xfa900205,0x00000000}},	//   _irlg, otwa, çütü_, --, 
   {{0x6d586442,0x098416c3,0xfa340ccb,0x287400db}},	//   ntwa, _халқ_, _سرند, _жыйр, 
   {{0x291c06d6,0x6d586443,0xb808007b,0x61e46444}},	//   _itwa_, itwa, _فيهم_, _rykl, 
   {{0x61e403a1,0x644c6445,0x6d586446,0xa2e46447}},	//   _sykl, rgbi, htwa, довд, 
   {{0x2008070d,0x6d58382f,0x67206448,0x9660013d}},	//   _sgbi_, ktwa, mplj, _акъе, 
   {{0xd24c6449,0x60dc644a,0x03680014,0x205403de}},	// [7080] شنل_, topm, _کٔجی_, дтер, 
   {{0x25fc023e,0x61e40122,0x6d58644b,0x7e600263}},	//   रेणी_, _vykl, dtwa, _sbmp, 
   {{0xe298644c,0x6d58644d,0x9a10063f,0x8c10015b}},	//   _дан_, etwa, _mọrụ, হরান_, 
   {{0x6d58644e,0x38a00ba1,0x60dc047e,0x61e40432}},	//   ftwa, _hòrt_, sopm, _tykl, 
   {{0x291c644f,0x00000000,0x00000000,0x00000000}},	//   _ntwa_, --, --, --, 
   {{0x60dc047e,0x3074030d,0x00000000,0x00000000}},	//   qopm, _пусс, --, --, 
   {{0x291c013b,0x38a01497,0x6d582f63,0x00000000}},	//   _atwa_, _mòrt_, atwa, --, 
   {{0x6294037e,0xda7802d5,0xe8500131,0x6d58035a}},	//   njyo, іяй_, ۇچىد, btwa, 
   {{0x6d5814dc,0x81e000bd,0xe8ec0451,0x98c40166}},	//   ctwa, ধের_, ڍڻو_, _şuıp_, 
   {{0x25a40209,0x7ce40086,0xdb8401d5,0x00000000}},	//   _ýoly_, tòru, _огзи, --, 
   {{0x291c6450,0xdb4c04d3,0xec34006c,0xfa903535}},	//   _etwa_, _ڵێک_, _سونگ, çüsü_, 
   {{0x7d08005c,0xd90c072d,0x00000000,0x00000000}},	//   _hids, _پید_, --, --, 
   {{0x7d086451,0x4870030f,0x8af8011a,0x00000000}},	//   _kids, ردیس, _והאי, --, 
   {{0x7ae06452,0x38a0067c,0x26d0047e,0x00000000}},	//   lomt, _còrt_, _ejyo_, --, 
   {{0x672001a6,0x7d086453,0x386c03cb,0x00000000}},	//   cplj, _mids, medr_, --, 
   {{0x7ae06454,0x7d086455,0x6d586456,0x00000000}},	//   nomt, _lids, ytwa, --, 
   {{0x64586457,0x38a0180f,0x7d086458,0xd4980798}},	// [7090] òtic, _fòrt_, _oids, _дрн_, 
   {{0x629401d4,0x33746459,0x69d40112,0x38a00248}},	//   ajyo, _згор, ßzei, _tòru_, 
   {{0x7ae0645a,0x752c004c,0xde3802d3,0x00000000}},	//   komt, _hwaz, _ከምዝወ, --, 
   {{0x7d0814dc,0x6d58645b,0x2dd4170a,0xfeb8158b}},	//   _aids, ttwa, нжер, وانت_, 
   {{0x6d5814dc,0x7d08645c,0x7ae000d7,0x00000000}},	//   utwa, _bids, domt, --, 
   {{0x6d58645d,0x7d08645e,0x752c645f,0x4084035b}},	//   rtwa, _cids, _mwaz, _иусб, 
   {{0x7d0808c2,0x6d586460,0x2ab001e1,0x00000000}},	//   _dids, stwa, _lábe_, --, 
   {{0x752c6461,0x7d08168c,0x6d580c8c,0xfbd06462}},	//   _owaz, _eids, ptwa, جته_, 
   {{0x752c007f,0x7d083284,0x386c0142,0x6bd800e5}},	//   _nwaz, _fids, fedr_, _کواس_, 
   {{0x7d086463,0x6f086464,0x7b6400c7,0x00000000}},	//   _gids, _hiec, хтәе, --, 
   {{0x752c6465,0x7ae00117,0xbca400e3,0x6b8002d0}},	//   _awaz, bomt, _جملي, _urlg, 
   {{0xd7f800c6,0x6720098d,0x752c6466,0x6f0820ee}},	//   яσя_, rplj, _bwaz, _jiec, 
   {{0xd7546467,0x38a0180f,0x291c6468,0x6f086469}},	//   ولیت_, _còrs_, _utwa_, _miec, 
   {{0x6f08646a,0x6aa81347,0x9a1001f2,0x752c646b}},	//   _liec, lkef, _họpụ, _dwaz, 
   {{0xd87400b2,0x68e0646c,0x752c646d,0x701400eb}},	//   _سميت_, mold, _ewaz, িরাজ_, 
   {{0x6f083f8e,0x38a00561,0x752c0100,0x2a6c014b}},	//   _niec, _fòrs_, _fwaz, neeb_, 
   {{0xe5a40276,0x752c646e,0x6aa803d1,0x68e0062c}},	// [70a0] _чипи, _gwaz, ikef, oold, 
   {{0x68e0646f,0x7ae01cdf,0x2a6c0070,0x2ab0032e}},	//   nold, zomt, heeb_, _jább_, 
   {{0x5454025f,0x6aa80e38,0x7d086470,0x7ae0431a}},	//   _אביב_, kkef, _rids, yomt, 
   {{0x7d08105c,0x6f086471,0x68e06472,0x9984022a}},	//   _sids, _ciec, hold, _leoš_, 
   {{0x6f086473,0x7ce4068c,0x2a6c058a,0x68e06474}},	//   _diec, dòrr, deeb_, kold, 
   {{0x68e05b47,0x6f0816b8,0x7ae0016b,0x6ef00158}},	//   jold, _eiec, womt, råba, 
   {{0x6f080262,0x7d0804ce,0x7ae06475,0x68e06476}},	//   _fiec, _vids, tomt, dold, 
   {{0x6f0801a4,0x7ce4068c,0x6ef000b5,0x61e00003}},	//   _giec, gòrr, låbn, żolu, 
   {{0x68e06477,0xd27802d3,0x0d2000db,0xd90c0101}},	//   fold, _ብኽብሪ_, _бүчү, حیت_, 
   {{0x68e01646,0x752c6478,0x6ef0037e,0x7ae000d2}},	//   gold, _rwaz, nåbn, somt, 
   {{0x752c4aa4,0x65746479,0x7ae001c8,0x2a6c0067}},	//   _swaz, _asyh, pomt, beeb_, 
   {{0x2a6c01d4,0x38a00e89,0x246c02d3,0x2910007b}},	//   ceeb_, _còrr_, _ስምረት_, únaí_, 
   {{0x68e0647a,0xf8b8516c,0x8588647b,0x18a40006}},	//   bold, _жөн_, нёра_, _падм, 
   {{0x752c0bd1,0x9a1002e3,0x38a0067c,0xd1c80092}},	//   _vwaz, _zọpụ, _vòrs_, _ቡልቻ_, 
   {{0x9f5c0241,0x00000000,0x00000000,0x00000000}},	//   _àtè_, --, --, --, 
   {{0x752c647c,0x25fc01f9,0x00000000,0x00000000}},	//   _twaz, रेही_, --, --, 
   {{0x07083ba6,0x752c647d,0x6f08647e,0xe8480150}},	// [70b0] _яхши_, _uwaz, _riec, _ءجۇن_, 
   {{0x6f08647f,0x74142d8d,0x814401b9,0xfbb06480}},	//   _siec, _جودا, انلن, जनाम, 
   {{0x6128025a,0x6f086481,0x4f0813ef,0x6aa803cd}},	//   tölî, _piec, ستاپ_, ykef, 
   {{0xdb080d16,0x2a6c4852,0x52a400c6,0x68e014cb}},	//   nzfä, xeeb_, _أصدق, zold, 
   {{0xa2c006ba,0x2a6c00c5,0x6f086482,0xed581188}},	//   _тәрк, veeb_, _viec, фол_, 
   {{0x6f08068f,0x9a10063f,0x20180113,0x00000000}},	//   _wiec, _sọpụ, ccpi_, --, 
   {{0x9a1001f2,0x6f086483,0x20100030,0x2a6c002e}},	//   _pọpụ, _tiec, ániť_, teeb_, 
   {{0x68e0364b,0x9b900fb4,0x6a846484,0x00000000}},	//   wold, ؤليت, тлиа, --, 
   {{0xe8f86485,0x6aa800fc,0xe9d86486,0x2a6c6487}},	//   мли_, rkef, ьки_, reeb_, 
   {{0x6aa83c12,0x2a6c0218,0xe7a801c6,0x00000000}},	//   skef, seeb_, двол_, --, 
   {{0x68e06488,0xe3c40154,0xfc3001e2,0x00000000}},	//   rold, _শুনব, _دحق_, --, 
   {{0xe5a401a9,0x00000000,0x00000000,0x00000000}},	//   вими, --, --, --, 
   {{0x68e06489,0x00000000,0x00000000,0x00000000}},	//   pold, --, --, --, 
   {{0x69d8009a,0x98a00640,0xd940648a,0x68e06064}},	//   _ixwe, _више, _теши, qold, 
   {{0xe2a8648b,0x38a00192,0x6ef0005c,0x00000000}},	//   وارن_, _tòrr_, våbn, --, 
   {{0x657405da,0xe28402e8,0x9f5c0248,0x00000000}},	//   _tsyh, ълби, _àté_, --, 
   {{0xf1d4648c,0x25fc0073,0xa204648d,0x00000000}},	// [70c0] гөрө, रेशी_, тпад, --, 
   {{0x2d8801e4,0x00000000,0x00000000,0x00000000}},	//   ĥael_, --, --, --, 
   {{0x4438648e,0xd00c1698,0x6ef001bf,0x00000000}},	//   mar_, زلن_, råbn, --, 
   {{0x69d80472,0x6ef001bf,0x00000000,0x00000000}},	//   _oxwe, såbn, --, --, 
   {{0x8d7001d9,0x29180030,0x44380731,0x00000000}},	//   لاوا, ísal_, oar_, --, 
   {{0x55b80302,0xc1040598,0x6c38515c,0xad24009a}},	//   ומנו, _сүзл, ىتىڭ_, ارنو, 
   {{0x4438648f,0x69d802d0,0xdcf000fd,0xd9c801ad}},	//   iar_, _axwe, ñgır, ाप्ट, 
   {{0x44386490,0x3a74470c,0x00000000,0x00000000}},	//   har_, улир, --, --, 
   {{0xad641564,0x3f5c0008,0x9848241e,0x2a9421ef}},	//   _ماله, líu_, мяна_, ادىڭ, 
   {{0x44386491,0x4c6400c7,0x77980798,0xdc9801d5}},	//   jar_, _ииун_, екор_, _ўташ_, 
   {{0x69d8031c,0x3f5c6492,0xdb080112,0x2ba800cd}},	//   _exwe, níu_, tzfä, _कथया, 
   {{0x7c380cfc,0x44386493,0x38a000a3,0x645802bd}},	//   lavr, ear_, _eòrp_, òtin, 
   {{0x44386494,0x25fc6495,0x8ab4008f,0x85740395}},	//   far_, रेली_, _בלאג_, алях, 
   {{0x64d000dc,0x00000000,0x00000000,0x00000000}},	//   _सदृश, --, --, --, 
   {{0xd6d86496,0x2a7801e1,0x07a0119e,0x00000000}},	//   _оти_, _ígbà_, _вајн, --, 
   {{0x44386497,0x387c05c7,0x3f5c6498,0x4b7808a8}},	//   aar_, _havr_, díu_, ואלו, 
   {{0x27f8012d,0x00000000,0x00000000,0x00000000}},	// [70d0] ęsne_, --, --, --, 
   {{0x387c017a,0x3f5c08ce,0x00000000,0x00000000}},	//   _javr_, fíu_, --, --, 
   {{0x80b400cd,0x2ab000e5,0x00000000,0x00000000}},	//   _इतरे, _lába_, --, --, 
   {{0x4ea406bb,0xd59800b5,0xadb42002,0x4de400bc}},	//   ърза, saさ_, лбеш, _छँदै_, 
   {{0xd1e4001f,0x00000000,0x00000000,0x00000000}},	//   ማቾች_, --, --, --, 
   {{0x387c005a,0x6ef00158,0x3f5c6499,0x00000000}},	//   _navr_, påbo, bíu_, --, 
   {{0x69d805b1,0x7f940075,0x3f5c0077,0x00000000}},	//   _sxwe, _карх, cíu_, --, 
   {{0x2ab01bd4,0x00000000,0x00000000,0x00000000}},	//   _bába_, --, --, --, 
   {{0x4438649a,0x10141533,0x6f140399,0x2ab00332}},	//   yar_, _तलाश_, _huzc, _cába_, 
   {{0x4438649b,0x6f140327,0x5dd8010f,0xe728009d}},	//   xar_, _kuzc, _אַבס, ноод_, 
   {{0xa6c80697,0x387c036b,0xcd0000cd,0x00000000}},	//   елна_, _davr_, _vaśī_, --, 
   {{0x4438649c,0x999000a2,0x31781bd4,0x24840166}},	//   war_, _ýyş_, _ossz_, _şom_, 
   {{0xf9903bdb,0x6f140407,0x69d8004b,0x3ae8002d}},	//   _وبه_, _luzc, _uxwe, rûpt_, 
   {{0x2a7c01d4,0x4438649d,0x260c0943,0x6e3801d4}},	//   _hawb_, uar_, ḽo_, hawb, 
   {{0x2a7c0218,0x3f5c0077,0x66e402e8,0x00000000}},	//   _kawb_, xíu_, _йока, --, 
   {{0x443820af,0x387c16a3,0x00000000,0x00000000}},	//   sar_, _zavr_, --, --, 
   {{0x4438649e,0x2a7c0218,0xed74001f,0xdee4023b}},	// [70e0] par_, _mawb_, _በፍቅር_, қоди, 
   {{0x4438649f,0x2a7c01d4,0x3f5c0008,0x1fb44130}},	//   qar_, _lawb_, tíu_, лсер, 
   {{0x444464a0,0x6f1464a1,0x64c400aa,0xd00c007b}},	//   _id_, _cuzc, _ليکل, ألم_, 
   {{0x2a7c0457,0x444464a2,0x3f5c01a8,0x00000000}},	//   _nawb_, _hd_, ríu_, --, 
   {{0xdca44f20,0x7c3864a3,0x3c58084c,0xf1d401af}},	//   лади, tavr, вилэ_, _көфө, 
   {{0xf1d40323,0x4444402f,0x27300010,0x00000000}},	//   _төсө, _jd_, kšn_, --, 
   {{0x8fa012c1,0x6e38089c,0x2a7c00a9,0x44442734}},	//   _ларе, bawb, _bawb_, _md_, 
   {{0xdee430d0,0x44444f98,0xcb643738,0x93f8010f}},	//   _соби, _ld_, اميه_, עלקי, 
   {{0x2a7c0190,0x5ec8015b,0x9990012d,0xf8b804b3}},	//   _dawb_, িকদে, _żył_, көк_, 
   {{0x44440375,0x972464a4,0x1158008f,0x00000000}},	//   _nd_, льмд, עדיע, --, 
   {{0xda6464a5,0x2a7c0070,0xb8ec02ab,0x4b4401d9}},	//   _ماشي, _fawb_, _रग_, _معنہ, 
   {{0x444464a6,0x2a7c0048,0x753c01d3,0x0f54011a}},	//   _ad_, _gawb_, tssz, ניכם_, 
   {{0x444464a7,0x8464044e,0x753c0036,0x91e0012d}},	//   _bd_, _ስምምዕ_, ussz, _कुंज_, 
   {{0x444464a8,0x753c00e5,0x00000000,0x00000000}},	//   _cd_, rssz, --, --, 
   {{0x444464a9,0xc34802e8,0x00000000,0x00000000}},	//   _dd_, ляте_, --, --, 
   {{0x444464aa,0xb6c800dd,0x2a7c0218,0x25ec0073}},	//   _ed_, _جاتے_, _xawb_, _घरची_, 
   {{0x569064ab,0x444464ac,0xb03464ad,0x705801c4}},	// [70f0] _вақт, _fd_, инаш, каар_, 
   {{0x3d181533,0x444423bd,0x6ab00846,0x00000000}},	//   _पढ़े_, _gd_, _जत्र, --, 
   {{0x0838010f,0x9f5c0241,0xcf24009f,0x00000000}},	//   געבל, _àtì_, ارئي, --, 
   {{0x444464ae,0x6f140007,0x00000000,0x00000000}},	//   _zd_, _vuzc, --, --, 
   {{0x444464af,0x2a7c0218,0x3f9c022c,0x85041afc}},	//   _yd_, _rawb_, øvur_, _خوین, 
   {{0x444464b0,0x2a7c64b1,0x6e38014f,0xb80406b1}},	//   _xd_, _sawb_, sawb, रधाम_, 
   {{0x2a7c00a9,0xad2464b2,0xbc38484d,0x6e38014f}},	//   _pawb_, _چىرى, اسها_, pawb, 
   {{0x6e38047e,0x00000000,0x00000000,0x00000000}},	//   qawb, --, --, --, 
   {{0x8fd001ee,0x00000000,0x00000000,0x00000000}},	//   _тәҡә, --, --, --, 
   {{0xe76464b3,0xa7640640,0x49b000c7,0xf8b80051}},	//   авоп, акод, _ҳәоу, ghĩ_, 
   {{0x2a7c0211,0x0bf00150,0x160012eb,0x00000000}},	//   _tawb_, _اياڭ, रेसर_, --, 
   {{0x66e4372a,0xc448036b,0x444463bd,0xd1f0001f}},	//   рома, گیدن_, _sd_, ፍራት_, 
   {{0x444464b4,0x00000000,0x00000000,0x00000000}},	//   _pd_, --, --, --, 
   {{0x444464b5,0x7ae41156,0xc4482be7,0x290000e4}},	//   _qd_, čite, دیدن_, _òha_, 
   {{0x625864b6,0xb8640fba,0x00000000,0x00000000}},	//   крар_, _طاوو, --, --, 
   {{0x444464b7,0x00000000,0x00000000,0x00000000}},	//   _wd_, --, --, --, 
   {{0x444464b8,0x65b8020a,0xdc000034,0x2ab001e1}},	// [7100] _td_, _шукр_, _लण्ड_, _lábo_, 
   {{0x444464b9,0xa5080395,0x00000000,0x00000000}},	//   _ud_, _шепа_, --, --, 
   {{0x2e4002d3,0x9d10015b,0x6fd40006,0x00000000}},	//   _ከምዝመ, _হবেন_, біцц, --, 
   {{0x9f5c01e1,0x00000000,0x00000000,0x00000000}},	//   _àtí_, --, --, --, 
   {{0xf2880139,0x00000000,0x00000000,0x00000000}},	//   _сияһ_, --, --, --, 
   {{0x2ab064ba,0x201c64bb,0xdb681cc9,0x4f9400c7}},	//   _bábo_, _üti_, врил_, ырӡу, 
   {{0x1e940276,0x00000000,0x00000000,0x00000000}},	//   _крар, --, --, --, 
   {{0x0f7800d9,0x60300241,0x00000000,0x00000000}},	//   _באלב, _ṣiṣọ, --, --, 
   {{0x3fa4063f,0x00000000,0x00000000,0x00000000}},	//   ̣sụ_, --, --, --, 
   {{0x2ab00248,0x98040150,0x00000000,0x00000000}},	//   _fábo_, иянд, --, --, 
   {{0x3ea464bc,0xda783410,0x30f800cd,0x07e000d4}},	//   _komt_, _аял_, ्गतः_, жцям, 
   {{0xdaa864bd,0x8f9800d9,0xe9700137,0x00000000}},	//   _швед_, דיטי, تۇۇد, --, 
   {{0x85440166,0x00000000,0x00000000,0x00000000}},	//   жэсе, --, --, --, 
   {{0x14c8034b,0x97a400f3,0x00000000,0x00000000}},	//   тыми_, _врил, --, --, 
   {{0x2d8002b5,0xd1b81f0d,0x00000000,0x00000000}},	//   āhei_, ھارا_, --, --, 
   {{0x59d800c5,0x926801a9,0x00000000,0x00000000}},	//   _बखार, ърга_, --, --, 
   {{0x6fd81533,0x518403b7,0x16000807,0x00000000}},	// [7110] _मशहू, јуба, रेशर_, --, 
   {{0x92d42f8b,0xefec001f,0x2e400240,0x00000000}},	//   িতে_, _ፀሐይ_, _ከምዘመ, --, 
   {{0x2d98007f,0xddc001e4,0x00000000,0x00000000}},	//   _ŧse_, rgoŝ, --, --, 
   {{0x3ea464be,0x5184013d,0x25fc0118,0x00000000}},	//   _comt_, _куга, रेकी_, --, 
   {{0x3ea40327,0x00000000,0x00000000,0x00000000}},	//   _domt_, --, --, --, 
   {{0xeac801fb,0x31742d1c,0xbca4007b,0xd6cc03d4}},	//   hẹt_, ğazı_, يمني, ৰতিয, 
   {{0x8d740075,0x8f08009d,0xaa4400db,0x00000000}},	//   _ھارا, _ахаа_, бейл, --, 
   {{0x2b482804,0x00000000,0x00000000,0x00000000}},	//   čac_, --, --, --, 
   {{0x2eec64bf,0x28e8010b,0xa8c401d5,0xddc0010b}},	//   _ikef_, лдип_, ййид, mgoş, 
   {{0xb4e0012c,0x00000000,0x00000000,0x00000000}},	//   धको_, --, --, --, 
   {{0x2ca4009a,0x00000000,0x00000000,0x00000000}},	//   _iold_, --, --, --, 
   {{0x2ca40375,0x00000000,0x00000000,0x00000000}},	//   _hold_, --, --, --, 
   {{0x81ac03f4,0x2ca464c0,0x16000d0a,0x30f800dc}},	//   _কেন_, _kold_, रेलर_, ्गाः_, 
   {{0x25fc033f,0x94200022,0x9ac00003,0x00000000}},	//   रेगी_, змре, ċċel, --, 
   {{0x2ca464c1,0x290401e3,0x5f0800cd,0xe0d807a5}},	//   _mold_, mmla_, िषम्_, ҳва_, 
   {{0xdb1001ed,0xc44801b9,0x30a00150,0x00000000}},	//   ógép, دیگن_, _ﺍﻷﺨﻴ_, --, 
   {{0xe1f864c2,0x9a1001f2,0xe0d864c3,0x562400fb}},	// [7120] уга_, _pọzụ, гва_, _ужым_, 
   {{0x2eec01af,0x2ca464c4,0x443c01a8,0x9f940150}},	//   _akef_, _nold_, _þv_, йшеш, 
   {{0xa2e464c5,0x61140100,0xd00c007b,0x2904106f}},	//   _гонд, _sņld, فلك_, imla_, 
   {{0xe29864c6,0x6fd802ab,0x3ea40327,0x80b40073}},	//   _сам_, _मशरू, _qomt_, _इतके, 
   {{0x2ca4074d,0x9cc864c7,0xfc380022,0x00000000}},	//   _bold_, лыка_, иҭа_, --, 
   {{0x2ca4378c,0x51f40ee8,0x3cf4012d,0x00000000}},	//   _cold_, _دسپر, ेगें_, --, 
   {{0x3ea42ff9,0x661400c7,0x2ca40267,0xdce00115}},	//   _tomt_, _ogyk, _dold_, ntoĉ, 
   {{0xd00c0597,0xbda400db,0x63b80419,0x00000000}},	//   _ألف_, _وڭشو, útny, --, 
   {{0xd838462e,0x58840372,0x9c5864c8,0x63ac02fb}},	//   лэн_, бына, _مجاز_, hybn, 
   {{0x2ca464c9,0x95c801a9,0x00000000,0x00000000}},	//   _gold_, ҳуга_, --, --, 
   {{0x9a8464ca,0x81ac00cc,0x49b40214,0xcb64014b}},	//   _гулл, _কেম_, لاید_, _гахе_, 
   {{0x2f200024,0x63ac005c,0xcff4011a,0x95c8013d}},	//   _jėga_, dybn, מציה_, гуга_, 
   {{0x95c864cb,0x00000000,0x00000000,0x00000000}},	//   ууна_, --, --, --, 
   {{0x661401ed,0x81ac00cc,0x473045cc,0x00000000}},	//   _egyk, _কেভ_, _کروز, --, 
   {{0x572464cc,0x00000000,0x00000000,0x00000000}},	//   _ارتق, --, --, --, 
   {{0x38c803e6,0x02a40276,0x00000000,0x00000000}},	//   _حاڵی_, прум, --, --, 
   {{0x5184154e,0x95c864cd,0xb0dc033f,0x7bdc02d2}},	// [7130] щува, _щука_, _मददग, _þruf, 
   {{0x61444da8,0x100400a7,0x85b80139,0x8574010a}},	//   زىمە, бяем, _ылыс_, _эльх, 
   {{0x2ca4005c,0x2f200153,0xc104007b,0x00000000}},	//   _rold_, _bėga_, أولي, --, 
   {{0x2ca464ce,0x00000000,0x00000000,0x00000000}},	//   _sold_, --, --, --, 
   {{0x40940075,0x0d64005b,0x2ca4000d,0xcd480120}},	//   تلەر, съем, _pold_, учед_, 
   {{0x7f480075,0x518401f0,0x25fc190e,0xe6c4012d}},	//   شلۇق_, _куҳа, रेटी_, _लग्ज, 
   {{0x2ca40627,0x9f7c001f,0x9b9000f0,0x7ff40066}},	//   _vold_, _የፋይሉ_, дијц, _فسفا, 
   {{0xa92464cf,0x4ea464d0,0x69244411,0x9f5c01e1}},	//   одил, _урга, омиа, _àtá_, 
   {{0x2ca464d1,0x6dc000f7,0x718c0240,0x00000000}},	//   _told_, _تۅشۅ, _ሓላፊት_, --, 
   {{0x7ae41326,0x2d8c0010,0x00000000,0x00000000}},	//   čita, _iree_, --, --, 
   {{0xe738026a,0x2d8c062c,0x290464d2,0x645c0175}},	//   јем_, _hree_, rmla_, _rcpi, 
   {{0x2d8c64d3,0x3e6002b5,0xadec012c,0x00000000}},	//   _kree_, _tōtō_, _जडान_, --, 
   {{0x645c0077,0x2d9c0fec,0xa9a41def,0x5f0800dc}},	//   _pcpi, nxwe_, _филд, िषत्_, 
   {{0x2d8c062c,0x00000000,0x00000000,0x00000000}},	//   _mree_, --, --, --, 
   {{0x25fc19e5,0x7ce40ba1,0x14b80073,0xe28414b3}},	//   रेजी_, tòrz, _उतरण, олви, 
   {{0x2d8c00e4,0xa2285f2d,0xaac81b76,0xdce00115}},	//   _oree_, ржаа_, िफिक, rtoĉ, 
   {{0xdce001e4,0x26d002f0,0x00000000,0x00000000}},	// [7140] stoĉ, ézou_, --, --, 
   {{0x6ab80042,0x38c400e4,0x00000000,0x00000000}},	//   _llwf, mérõ_, --, --, 
   {{0x2d8c0801,0x200c64d4,0x94200137,0x28e002c3}},	//   _aree_, äfi_, _توپۇ, _पदनि, 
   {{0x2d8c1368,0xdd9407dd,0x32280064,0x00000000}},	//   _bree_, ҩаҧы, _гіём_, --, 
   {{0x2d8c64d5,0x6e2c04d4,0xb8cc0327,0x00000000}},	//   _cree_, ñaba, _པྭ_, --, 
   {{0x9b2464d6,0x2d8c64d7,0xd598037e,0x91d80150}},	//   офил, _dree_, kaの_, _тәсi, 
   {{0x2d8c64d8,0x5f0864d9,0x00000000,0x00000000}},	//   _eree_, िषद्_, --, --, 
   {{0x8f9802e4,0x38c40022,0x5d740153,0x00000000}},	//   _דילי, kérõ_, _музф, --, 
   {{0x2d8c64da,0xafc00248,0x00000000,0x00000000}},	//   _gree_, _òòrù, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7ba800cc,0x5a4400c0,0x88c4002b,0x00000000}},	//   _কেৰো, _дэла, daśī, --, 
   {{0x30a00150,0x00000000,0x00000000,0x00000000}},	//   _ﺍﻷﺤﻴ_, --, --, --, 
   {{0x94a800c0,0xd9780139,0x05840818,0x59d40b24}},	//   атва_, _әрҗә_, мурм, _بغار, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x92a40640,0x3944003e,0xd68401a9,0x00000000}},	//   ојал, lsms_, _дупп, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd01853ac,0x00000000,0x00000000,0x00000000}},	// [7150] афе_, --, --, --, 
   {{0xcf88014b,0x45d4010a,0xe72c0244,0x00000000}},	//   исед_, _цоьс, _جڵی_, --, 
   {{0x2d8c020c,0x8f0801b9,0x7ff40345,0x00000000}},	//   _sree_, ахда_, وسما, --, 
   {{0x765c64db,0x2d8c64dc,0x4798008f,0x1db40254}},	//   ngsy, _pree_, ייבס, अनंत, 
   {{0x38c40153,0x00000000,0x00000000,0x00000000}},	//   _kūrė_, --, --, --, 
   {{0xdd8c64dd,0x66d40219,0xc0580111,0x2d8c0363}},	//   اوو_, mške, _міс_, _vree_, 
   {{0x7ae40fb7,0xc4d40677,0xeab0007b,0xe2a40162}},	//   čitn, וגס_, فعة_, øðga_, 
   {{0x2d8c0c30,0x0dc801d5,0x00000000,0x00000000}},	//   _tree_, _кузи_, --, --, 
   {{0x66d40427,0xed500345,0x00000000,0x00000000}},	//   nške, _سپا_, --, --, 
   {{0x6d5864de,0xb6480241,0x28980120,0x38c40124}},	//   muwa, _ilẹ̀, стиќ_, vérõ_, 
   {{0x2f200153,0xdb24114f,0x00000000,0x00000000}},	//   _mėgo_, _فولی, --, --, 
   {{0x9f5064df,0xd598037e,0xfaa800f1,0x38c40022}},	//   édée_, raの_, _وهلي_, térõ_, 
   {{0x6d5864e0,0xe28401c0,0x692401d5,0xe894030d}},	//   nuwa, үлги, _эмла, _надь, 
   {{0xa50864e1,0x765c0ea0,0x3fb800d1,0x5560129d}},	//   сега_, agsy, ﺸﻼﺭﻧ, رۇپك, 
   {{0x291c1f21,0x232864e2,0x6d5864e3,0xe29864e4}},	//   _huwa_, соби_, huwa, бав_, 
   {{0x291c64e5,0x9a100521,0x272025e6,0xa11464e6}},	//   _kuwa_, _fọdụ, _ión_, كورت, 
   {{0x291c20ee,0x6d5864e7,0x6ef0005c,0x2f2000c0}},	// [7160] _juwa_, juwa, håbs, _bėgo_, 
   {{0x291c64e8,0xe45802d5,0x27200241,0xc0e0001f}},	//   _muwa_, _ужо_, _kón_, ናችሁ_, 
   {{0x291c64e9,0x27202242,0x1418010f,0xdce00327}},	//   _luwa_, _jón_, _לויב, stoċ, 
   {{0x272064ea,0x6d5864eb,0x3a24011c,0xc29464ec}},	//   _món_, fuwa, xcmp_, _تیرب, 
   {{0x6d5823db,0x628464ed,0x291c0295,0xa11401ec}},	//   guwa, _iako, _nuwa_, _ءوست, 
   {{0x628464ee,0x00000000,0x00000000,0x00000000}},	//   _hako, --, --, --, 
   {{0x628464ef,0x291c19a2,0x272001fb,0x7e60003a}},	//   _kako, _auwa_, _nón_, _tcmp, 
   {{0x628412eb,0x6d5864f0,0x291c64f1,0x1c1c0034}},	//   _jako, buwa, _buwa_, _पलवल_, 
   {{0x291c64f2,0x588464f3,0x6d5864f4,0x6ef001bf}},	//   _cuwa_, пына, cuwa, råbt, 
   {{0x628464f5,0x291c64f6,0x272001fb,0x38c82e3e}},	//   _lako, _duwa_, _bón_, تابی_, 
   {{0x291805f7,0x2720498c,0x56f000cf,0x00000000}},	//   ísar_, _cón_, нүкс, --, 
   {{0x291c0184,0x4bf808d8,0x00000000,0x00000000}},	//   _fuwa_, _פלאס, --, --, 
   {{0x291c64f7,0x27200077,0xb78801e0,0x00000000}},	//   _guwa_, _eón_, сәһе_, --, 
   {{0x62840069,0x272000c6,0x60cc0175,0x66d40427}},	//   _aako, _fón_, _nmbm, vške, 
   {{0x291c4437,0x628464f8,0x6d5864f9,0x43942082}},	//   _zuwa_, _bako, zuwa, нарс, 
   {{0x628464fa,0x6d5864fb,0x291c0b45,0x92b4007b}},	//   _cako, yuwa, _yuwa_, أحسا, 
   {{0x7c2864fc,0x764c64fd,0xf48401ed,0x628464fe}},	// [7170] _ofdr, _iday, _قادی, _dako, 
   {{0x752c555f,0x2eb40882,0x6284019b,0x6d5864ff}},	//   _itaz, ंस्त, _eako, vuwa, 
   {{0x6d583142,0x62846500,0x00000000,0x00000000}},	//   wuwa, _fako, --, --, 
   {{0x62846501,0x6d586502,0x7c286503,0x4544036b}},	//   _gako, tuwa, _afdr, _تنیق, 
   {{0xdce000d0,0x5194010a,0x00000000,0x00000000}},	//   atoč, _хăла, --, --, 
   {{0xeb986504,0x291c3142,0x6d586505,0x752c0451}},	//   жик_, _ruwa_, ruwa, _mtaz, 
   {{0x6d583142,0x764c6506,0xbfa80032,0xdca0399b}},	//   suwa, _oday, _етте_, тащи, 
   {{0x764c6507,0x6d586508,0x752c0122,0xad240075}},	//   _nday, puwa, _otaz, _يىزى, 
   {{0x27200e26,0x31680bc2,0x752c015c,0x6e286509}},	//   _són_, ntaz_, _ntaz, _ifeb, 
   {{0x764c650a,0xb2fc0003,0x291c650b,0x6d48650c}},	//   _aday, _དེའང_, _vuwa_, _ivea, 
   {{0x66e4650d,0x764c003e,0x291c0198,0x635c0356}},	//   дона, _bday, _wuwa_, _mănî, 
   {{0x291c650e,0x6d480793,0x272006ea,0x2d9806af}},	//   _tuwa_, _kvea, _vón_, _àses_, 
   {{0x6284650f,0x764c2f99,0xdce002fb,0x98a00a2f}},	//   _rako, _dday, ztoč, ūkā_, 
   {{0x62846510,0xe7386511,0xdce001f1,0x27202eb1}},	//   _sako, _дек_, ytoč, _tón_, 
   {{0x752c6512,0x6e280117,0x316801c6,0xa6c800f1}},	//   _etaz, _ofeb, etaz_, _ووتل_, 
   {{0x6e2c09c2,0x60cc009a,0x6d48035a,0x00000000}},	//   ñabl, _smbm, _ovea, --, 
   {{0x62846513,0x64a411dc,0x00000000,0x00000000}},	// [7180] _vako, _жапа, --, --, 
   {{0x6e286514,0x645829d3,0xfd5000b8,0x00000000}},	//   _afeb, ótid, cikṣ, --, 
   {{0x6d486515,0xb40005f5,0x8fa06516,0x1ec80261}},	//   _avea, _бүрд, кафе, олжи_, 
   {{0x6284316f,0x00000000,0x00000000,0x00000000}},	//   _uako, --, --, --, 
   {{0xdce06517,0xeff40092,0x0d940022,0x00000000}},	//   stoč, _ጉዞው_, ҧтәы_, --, 
   {{0x16002cce,0x6e280561,0xdd900517,0xa2c806b1}},	//   रेटर_, _efeb, _یوز_, सोर्, 
   {{0x6e280175,0x6d480857,0x7c8400d1,0xa3ac000d}},	//   _ffeb, _evea, дуқе, कहि_, 
   {{0x0c206518,0x71240244,0x00000000,0x00000000}},	//   нмән, _ترێل, --, --, 
   {{0x9a1001f2,0x78b422c3,0x26c00009,0x60dc0129}},	//   _sọbụ, ейпф, dhko_, onpm, 
   {{0xb4bc068f,0xd7f807d6,0x764c003e,0xa3ac0cb4}},	//   _आते_, жум_, _sday, कहा_, 
   {{0x657400c7,0x90540302,0x6d480099,0xdb140332}},	//   _apyh, וסיף_, _zvea, úcói, 
   {{0x2498054e,0x00000000,0x00000000,0x00000000}},	//   _anpm_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x26c001f4,0x00000000,0x00000000,0x00000000}},	//   ahko_, --, --, --, 
   {{0x36d43e9f,0x81ac03d4,0x160007f7,0xb9ec1ef7}},	//   _покр, _কেল_, रेजर_, _ሔር_, 
   {{0x764c6519,0xa2c801ad,0x31680129,0x00000000}},	//   _uday, सोल्, ttaz_, --, 
   {{0x3494651a,0x752c651b,0x75d4651c,0x00000000}},	// [7190] _запр, _utaz, _سيدا, --, 
   {{0x3168651d,0x8078651e,0x714000db,0xdec00022}},	//   rtaz_, мбус_, _ۅۉرۅ, қәсо, 
   {{0x316801c0,0x6d480267,0x79800142,0x00000000}},	//   staz_, _svea, hwmw, --, 
   {{0x867c008f,0x657400e4,0x714000cf,0x31680200}},	//   ַרוו, _ypyh, _مۉرۅ, ptaz_, 
   {{0xdc380139,0xe0bc00cc,0x00000000,0x00000000}},	//   _açıu, _আদৰন, --, --, 
   {{0xab6424fc,0x6b640166,0x66d40064,0x00000000}},	//   евкл, екка, iška, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6e280944,0x00000000,0x00000000,0x00000000}},	//   _ufeb, --, --, --, 
   {{0xe9d8651f,0x31dc05c0,0x66d400d7,0x3ea80244}},	//   яки_, _यशोध, jška, _تێنێ_, 
   {{0x7c946520,0x00000000,0x00000000,0x00000000}},	//   _لشما, --, --, --, 
   {{0x657411ce,0x66d40024,0x00000000,0x00000000}},	//   _spyh, eška, --, --, 
   {{0x28e0243c,0x00000000,0x00000000,0x00000000}},	//   _पदवि, --, --, --, 
   {{0x2498008b,0xef180003,0xfd840131,0xdb1c01e1}},	//   _pnpm_, _miż_, ﻨﻐﺎﻥ_, _ìyòy, 
   {{0x6384036b,0xef180135,0x26c06521,0x00000000}},	//   нгга, _liż_, shko_, --, 
   {{0x66d40113,0x645800db,0xe2986522,0x059400db}},	//   aška, òtiq, пав_, راڭگ, 
   {{0xef18006d,0x171800df,0x00000000,0x00000000}},	//   _niż_, _צופע, --, --, 
   {{0x20546523,0x00000000,0x00000000,0x00000000}},	// [71a0] етер, --, --, --, 
   {{0xb910063f,0x5f7401ed,0xed880092,0x702401d9}},	//   dolụ_, ٹائر, ፒውተር_, ٖرنٕ, 
   {{0x44386524,0xef180135,0x5438010f,0x00000000}},	//   mbr_, _biż_, _מעיא, --, 
   {{0x21a42d2e,0x7ae43831,0x443800d8,0xd00c007b}},	//   _зимм, čitk, lbr_, حلم_, 
   {{0xef180327,0x00000000,0x00000000,0x00000000}},	//   _diż_, --, --, --, 
   {{0x2240038f,0xa0341e0e,0x44380f64,0x3c58084c}},	//   _hekk_, _سىرت, nbr_, фикэ_, 
   {{0x6d5c6525,0xef18003d,0xef900d73,0x22400162}},	//   _åsan, _fiż_, _پیند, _kekk_, 
   {{0x22401f21,0x212001b3,0xdbd000c5,0xb4bc6526}},	//   _jekk_, _kukh_, müür, _आत्_, 
   {{0x3c840022,0x22402641,0x66c402d2,0xdbd00254}},	//   _икаҳ, _mekk_, _kókf, lüür, 
   {{0xd6f86527,0x22400694,0x2bd000cd,0x00000000}},	//   ृष्ठ_, _lekk_, _थेवा, --, 
   {{0x46dc0490,0x443800b5,0xb90800cd,0x00000000}},	//   मचंह, dbr_, _यद_, --, 
   {{0x22403d27,0x00000000,0x00000000,0x00000000}},	//   _nekk_, --, --, --, 
   {{0x439401a9,0x00000000,0x00000000,0x00000000}},	//   қатс, --, --, --, 
   {{0xdbd00037,0x00000000,0x00000000,0x00000000}},	//   küür, --, --, --, 
   {{0x22406528,0xd610004e,0xdec40023,0x2a78110e}},	//   _bekk_, _өзкө, ጽምን_, _ìgbà_, 
   {{0xed68001f,0x828812d7,0x212001bf,0x44380334}},	//   ተባበር_, нсуб_, _bukh_, abr_, 
   {{0x64585599,0x22406529,0x66c409e8,0xc1e401e0}},	// [71b0] ótic, _dekk_, _bókf, гөрҙ, 
   {{0x212001bf,0x9388652a,0xf484335b,0x00000000}},	//   _dukh_, _есма_, _شاخی, --, 
   {{0x2240652b,0xef18003d,0xc3e400fb,0x00000000}},	//   _fekk_, _piż_, _бөтһ, --, 
   {{0x224009cc,0x1ee81550,0x42980023,0x92f00139}},	//   _gekk_, وولی_, _መጻኢት_, _сүбх, 
   {{0x635c0051,0x00000000,0x00000000,0x00000000}},	//   ệnth, --, --, --, 
   {{0x9600015b,0x6fd40073,0x2ab000d7,0x00000000}},	//   _এলাম_, _येथू, _nábr_, --, 
   {{0x672c0122,0x00000000,0x00000000,0x00000000}},	//   _čajo, --, --, --, 
   {{0x1dd01db2,0xf58c001f,0x3f14004e,0x69940902}},	//   _देवत, _ሚያዚያ_, _бдсс, врох, 
   {{0x7ee4010b,0x6f08652c,0x443803cb,0x8aa40150}},	//   _сцре, _ihec, ybr_, _үред, 
   {{0x6d5800ca,0x4438652d,0xc4e000bc,0x00000000}},	//   mrwa, xbr_, _नदेख, --, 
   {{0x6f0800cd,0x26d00790,0xe738010a,0x2f200064}},	//   _khec, _pmyo_, ьен_, _bėgi_, 
   {{0x6d580936,0x00000000,0x00000000,0x00000000}},	//   orwa, --, --, --, 
   {{0x22403d27,0x9580652e,0x41d0652f,0x33d40220}},	//   _rekk_, аляе, _सेंस, ңіст, 
   {{0x6d586530,0x69c83dc9,0x224003cd,0x279401a9}},	//   irwa, mzee, _sekk_, _ашир, 
   {{0xa2d46531,0x6f0807dd,0x26d004ba,0x44386532}},	//   نيست, _ohec, _tmyo_, rbr_, 
   {{0x6d586533,0x44380798,0x66d40427,0x00000000}},	//   krwa, sbr_, mško, --, 
   {{0x69c86534,0x61446535,0x22406536,0xe1f8036b}},	// [71c0] nzee, теза, _vekk_, фга_, 
   {{0x7ae40bb8,0x81ac03f4,0x1fb46537,0xf1a8064c}},	//   čiti, _কেউ_, ксер, راقه_, 
   {{0x6d58581c,0x44446538,0x22406539,0x6aa8653a}},	//   erwa, _ie_, _tekk_, kjef, 
   {{0x6f08653b,0x6aa80989,0x672c01fa,0x8fa000d8}},	//   _chec, jjef, _čajl, јаце, 
   {{0x4444653c,0x6f080014,0x7d0801ab,0x3cf013f7}},	//   _ke_, _dhec, _phds, ेतले_, 
   {{0x2eec00c8,0x6f0800c7,0x50940022,0x69c800e2}},	//   _ĉefe_, _ehec, _иусӡ, dzee, 
   {{0x6d58653d,0x8cb04970,0x6f0801ab,0x8e440131}},	//   arwa, _अवरो, _fhec, رلۈك_, 
   {{0x69c80036,0x6d5802d0,0x00000000,0x00000000}},	//   fzee, brwa, --, --, 
   {{0x4444653e,0x66d402d5,0xa2b85096,0x6d5802d0}},	//   _oe_, eško, _एकन्, crwa, 
   {{0xa5f801b9,0x00000000,0x00000000,0x00000000}},	//   _o想be, --, --, --, 
   {{0x6aa80789,0x69c80083,0x5a6400db,0x00000000}},	//   bjef, azee, _акеб, --, 
   {{0x4444653f,0x69c80218,0x03dc00cc,0x00000000}},	//   _ae_, bzee, _ধৰ্ণ, --, 
   {{0x44446540,0x69c801f5,0xf8b801c6,0x493401ca}},	//   _be_, czee, _зөн_, _азію_, 
   {{0x44446541,0xe2a403b2,0x00000000,0x00000000}},	//   _ce_, øðna_, --, --, 
   {{0x83f80311,0xe79412ea,0x00000000,0x00000000}},	//   верс_, _مايک, --, --, 
   {{0x44446542,0x6d5800ca,0x00000000,0x00000000}},	//   _ee_, yrwa, --, --, 
   {{0x8cb0095f,0x6f080142,0x57e000bc,0x6d5802d0}},	// [71d0] _अवलो, _rhec, _पशुह, xrwa, 
   {{0x44446543,0x6f080363,0x6aa8000f,0x3f8c0327}},	//   _ge_, _shec, zjef, _ġdur_, 
   {{0xce3000aa,0x6f086544,0x6e946545,0x69c80337}},	//   لواک, _phec, лижу, zzee, 
   {{0x44446546,0x6f080784,0x6d580034,0xd7e40150}},	//   _ze_, _qhec, trwa, _ۇك_, 
   {{0x44446547,0xed580a70,0x6d586548,0x00000000}},	//   _ye_, хол_, urwa, --, 
   {{0x44446549,0x6d5c1061,0x81ac0154,0x66d40419}},	//   _xe_, _åsam, _কেক_, yško, 
   {{0x6f08654a,0xfc6400a7,0x6aa8654b,0xce680107}},	//   _thec, ръчн, tjef, _орад_, 
   {{0xc334025f,0x6a8405f5,0x69c8654c,0x6f08654d}},	//   בוק_, улиа, tzee, _uhec, 
   {{0x6aa8654e,0x987c654f,0xbd686550,0x3f8c0413}},	//   rjef, _açıq_, _архе_, _ádur_, 
   {{0x69c86551,0x6aa86552,0xe7380640,0xcc0801b9}},	//   rzee, sjef, нео_, _قزان_, 
   {{0x44446553,0xd1d44be7,0x6aa8002d,0x66c40241}},	//   _re_, _ኮሚቴ_, pjef, _lóke, 
   {{0xe5a406f7,0x66d439ae,0x69c801a4,0x00000000}},	//   гими, rško, pzee, --, 
   {{0x66c400e4,0x536c02d3,0x00000000,0x00000000}},	//   _nóke, _ድልየት_, --, --, 
   {{0x44446554,0xc44801b9,0x98a00395,0x00000000}},	//   _qe_, خیدن_, _гише, --, 
   {{0x44446555,0x7ae40fb7,0x00000000,0x00000000}},	//   _ve_, čitv, --, --, 
   {{0x44446556,0xd76001ed,0x00000000,0x00000000}},	//   _we_, _انٹی, --, --, 
   {{0x44446557,0xa2b800c5,0xb62c01ec,0x25a40139}},	// [71e0] _te_, _एकठ्, _ﺒﺎ_, _çol_, 
   {{0x44446558,0x602402d5,0x9580030d,0x00000000}},	//   _ue_, уджа, _улье, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd00c4710,0x00000000,0x00000000,0x00000000}},	//   سلن_, --, --, --, 
   {{0x8d7001d9,0x66c408a5,0x4d7000ae,0x00000000}},	//   ماوا, _kókb, مطور, --, 
   {{0xdc286559,0xc10400d1,0x91e000d8,0x6fd401f9}},	//   رسته_, _түзл, _ѓоре, _येवू, 
   {{0xd004655a,0x9f4800cc,0xdee4655b,0x92d403d4}},	//   _бере_, _nybø_, _бови, াকৰ_, 
   {{0xd12c00dd,0x3f980113,0x7bdc08a5,0x00000000}},	//   _ذمہ_, _irru_, _þrum, --, 
   {{0x7c940092,0xad64009f,0xcb04007b,0x893000e5}},	//   ቀበለው_, _ناله, ديين_, یعیا, 
   {{0x6b8c012d,0x9e6400ec,0xadc401af,0x00000000}},	//   łaga, _جاڳن, _тауһ, --, 
   {{0xb7881945,0xb8dc52be,0xbaa4024c,0x1c44014b}},	//   тәле_, _इक_, _вулқ, _анҷм, 
   {{0x645805f7,0xd944655c,0x00000000,0x00000000}},	//   ótin, _беди, --, --, 
   {{0x66c4032e,0x00000000,0x00000000,0x00000000}},	//   _bókb, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3f98036e,0x308401d5,0x4c98010f,0xef1c000d}},	//   _nrru_, یلرف, עשלע, _बूझऽ_, 
   {{0x756401d3,0x66c4655d,0x35b40815,0xa2d80f4a}},	//   _پیسہ_, _póke, _вбир, _नगण्, 
   {{0x3f98655e,0x00000000,0x00000000,0x00000000}},	// [71f0] _arru_, --, --, --, 
   {{0x9e94006c,0x00000000,0x00000000,0x00000000}},	//   یانچ, --, --, --, 
   {{0x672c655f,0x6fd44540,0xc10400ec,0x087400df}},	//   _čajk, _येशू, حولي, רעבט_, 
   {{0xa3a83b90,0x03c400f7,0xf2c40116,0x81ac00eb}},	//   _खपत_, _ысым, _төги, _কেও_, 
   {{0x6da43ba6,0xada46560,0xa2b808a3,0x3f980156}},	//   рила, ралл, _एकत्, _erru_, 
   {{0x6b5450da,0xbdf801f7,0x5058010a,0x00000000}},	//   атих, درما_, _ярмă, --, 
   {{0x92d402a6,0xeab0007b,0x00000000,0x00000000}},	//   াকী_, قعة_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9a1001f2,0x80bc0882,0xa8c404a9,0x8c34013e}},	//   _fọmụ, _एवमे, ийид, _бозӣ_, 
   {{0x3f980368,0x00000000,0x00000000,0x00000000}},	//   _yrru_, --, --, --, 
   {{0x4b30179e,0x00000000,0x00000000,0x00000000}},	//   _اکتس, --, --, --, 
   {{0x2608000d,0x00000000,0x00000000,0x00000000}},	//   _सरदी_, --, --, --, 
   {{0xa8886561,0x7ae401fa,0xa96802e8,0x79a4009b}},	//   _айла_, čitt, _рила_, _грје, 
   {{0xa5086562,0x00000000,0x00000000,0x00000000}},	//   тега_, --, --, --, 
   {{0x23281ee3,0x2f200064,0x00000000,0x00000000}},	//   тоби_, _mėgs_, --, --, 
   {{0xd9d002dd,0x00000000,0x00000000,0x00000000}},	//   _دەۋگ, --, --, --, 
   {{0xe0440022,0x00000000,0x00000000,0x00000000}},	// [7200] инаи, --, --, --, 
   {{0xe3b86563,0x2eec00c8,0x00000000,0x00000000}},	//   _або_, _ĉefa_, --, --, 
   {{0x7c3c0254,0xd6cc0133,0x9f84004e,0x00000000}},	//   _õrri, _رقی_, ргед, --, 
   {{0x53980302,0x3ea00086,0x1dd00118,0x00000000}},	//   _סיכו, ñit_, _देउत, --, 
   {{0x644805da,0xdd90276c,0x2f200064,0xfa9003e0}},	//   _ôfis, توش_, _bėgs_, çümü_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69dc01a2,0x3f980429,0x38c0003a,0x9f040214}},	//   úsen, _urru_, hæræ_, _نوآو, 
   {{0xdee41086,0x8f340375,0xda781429,0x88e000eb}},	//   _тоби, _כאלו_, тяк_, _নীলক, 
   {{0xdfd46564,0xd8386565,0xdef801af,0x00000000}},	//   _соңы, кэн_, _зыҡ_, --, 
   {{0x97c4007b,0x9f5c0248,0x00000000,0x00000000}},	//   لتجم, _àtó_, --, --, 
   {{0x48a46566,0x627c0034,0xe81002ab,0x47840410}},	//   ртым_, _złoż, डेला_, асям_, 
   {{0xd1ec0023,0x81ac00cc,0x00000000,0x00000000}},	//   ቀሰብ_, _কেছ_, --, --, 
   {{0xb7880184,0x80bc0073,0x66240118,0xd61801d9}},	//   тәһе_, _एवढे, _šuká, کتھا_, 
   {{0x35a400c7,0x5fc40a8a,0xafc00241,0x00000000}},	//   ааҭг, लनाल, _òògù, --, 
   {{0x07f400db,0x92680022,0x00000000,0x00000000}},	//   _پروع_, краа_, --, --, 
   {{0x47305896,0xd5b801fe,0xaaa800bc,0x34940107}},	//   _بروز, _асо_, कायक, шаҳр, 
   {{0x51846567,0x672c01fa,0x74146568,0x337401ec}},	// [7210] шува, _čaji, _گودا, _ﺸﻴﻌﻲ_, 
   {{0x92d46569,0xcee8656a,0x00000000,0x00000000}},	//   াকে_, ھران_, --, --, 
   {{0x33940491,0x7414656b,0x00000000,0x00000000}},	//   _الجز, _دودا, --, --, 
   {{0x66c4148b,0x00000000,0x00000000,0x00000000}},	//   _kóka, --, --, --, 
   {{0x9a1002e3,0x8d14016c,0x66c400e5,0xd1c80395}},	//   _dọkụ, андӣ_, _jóka, _рунд_, 
   {{0x9f9400a2,0xbb5400d1,0x00000000,0x00000000}},	//   _hüýr_, _ﺋﯚﻱ_, --, --, 
   {{0x627c033f,0x66c4032e,0x00000000,0x00000000}},	//   _włoż, _lóka, --, --, 
   {{0x3a98656c,0x7058016c,0xea8806ed,0x66c40248}},	//   атью_, _шаҳр_, убил_, _oóka, 
   {{0xa2b80882,0xfe6c0014,0x627c033f,0x28b80209}},	//   _एकस्, _شۯو_, _ułoż, гунэ_, 
   {{0x2d8c656d,0x182802d3,0x66d4151c,0x00000000}},	//   _isee_, _ተቓውሞ, mški, --, 
   {{0x2cf40490,0x7ae400f3,0x7c9400f2,0x00000000}},	//   ेतील_, čitr, _بشقا, --, 
   {{0x66c4656e,0x66e435f2,0x7d2402d2,0x00000000}},	//   _bóka, сома, _útsé, --, 
   {{0xb9e401ee,0x00000000,0x00000000,0x00000000}},	//   _міљи, --, --, --, 
   {{0x66d402d5,0x2d8c009f,0x92d400fe,0xaa0000f1}},	//   iški, _msee_, াকো_, _وېډي, 
   {{0xdce0098d,0x92d40183,0xe644399a,0x40a801b9}},	//   stoć, াকৈ_, _лейп, یخطی_, 
   {{0x2d8c5bd4,0x66d40064,0x00000000,0x00000000}},	//   _osee_, kški, --, --, 
   {{0x2d8c0561,0x00000000,0x00000000,0x00000000}},	// [7220] _nsee_, --, --, --, 
   {{0x6564656f,0x77240014,0xe3b012d3,0x26c001f4}},	//   mukh, _دژیۆ, _فرج_, lkko_, 
   {{0x644c6570,0x9cc8052f,0x2d8c6571,0xb4000eff}},	//   mabi, ҫыла_, _asee_, _жүрд, 
   {{0x644c6572,0x9f5c03b2,0x26c0007c,0x010800f1}},	//   labi, _átí_, nkko_, اتړو_, 
   {{0x1dd01533,0x65640943,0x26c0005b,0xe1940166}},	//   _देखत, nukh, ikko_, _урнэ, 
   {{0x70b801ee,0x00000000,0x00000000,0x00000000}},	//   _кѳсѳ_, --, --, --, 
   {{0x2d8c0270,0x1fd40154,0xcb040451,0x91800051}},	//   _esee_, _তুরস, ڍيون_, _tệp_, 
   {{0x65642ffc,0x60dc6573,0x644c6574,0x0dc401e0}},	//   kukh, lipm, habi, рләй_, 
   {{0x09d802f5,0xd9186575,0x98486576,0x46cc07f7}},	//   _ডুবা, льо_, ляна_, ासनह, 
   {{0x26c002f6,0x6298013f,0x60dc00a2,0x00000000}},	//   ekko_, _ɔtoa, nipm, --, 
   {{0xda780801,0x6e2c0010,0x00000000,0x00000000}},	//   _бял_, žabe, --, --, 
   {{0x60dc0857,0x644c00ad,0x00000000,0x00000000}},	//   hipm, eabi, --, --, 
   {{0x644c6577,0x60dc2171,0x65646578,0x00000000}},	//   fabi, kipm, gukh, --, 
   {{0x97a41318,0x9f9400a2,0x00000000,0x00000000}},	//   _грил, _süýr_, --, --, 
   {{0x94840184,0x60dc010e,0xb9e40092,0x00000000}},	//   _һынд, dipm, _ይል_, --, 
   {{0x656453ff,0x65ac06d6,0x2eec010f,0x8338005b}},	//   bukh, ṱhan, _ĉefo_, счёт_, 
   {{0x1fd40729,0x2d980120,0xa2d80316,0x6564009a}},	// [7230] _তুলস, _àsex_, _नगर्, cukh, 
   {{0x614403cc,0x66d40427,0x00000000,0x00000000}},	//   تىكە, vški, --, --, 
   {{0x175c0023,0x06200023,0x7414009f,0x00000000}},	//   _ተሰዊኡ_, ተዘይነ, _گوگا, --, 
   {{0x2b440223,0x63b80724,0x00000000,0x00000000}},	//   _rwlc_, ätne, --, --, 
   {{0x66d40024,0x741426a8,0x28d8190e,0x00000000}},	//   uški, _دوگا, योडि, --, 
   {{0x66d402d5,0xdca0576f,0x6b5821e2,0xd01802e8}},	//   rški, даши, ашир_, _бфб_, 
   {{0x3ea425e6,0x3ec401ed,0x5b3001ed,0x00000000}},	//   _fnmt_, ártó_, وٹور, --, 
   {{0x644c6579,0x65640cfe,0x2d8c657a,0x0dc8010b}},	//   zabi, yukh, _tsee_, _йузи_, 
   {{0x644c657b,0xa888657c,0x2d8c657d,0x7e6400c6}},	//   yabi, айпа_, _usee_, óipe, 
   {{0x644c021a,0x00000000,0x00000000,0x00000000}},	//   xabi, --, --, --, 
   {{0x644c657e,0x8bc4657f,0x65646580,0x66f00374}},	//   vabi, _усад, wukh, hāke, 
   {{0x644c6581,0x26c00108,0xfc1401c6,0x00000000}},	//   wabi, ukko_, _эмхэ, --, 
   {{0xa5086582,0x26c06583,0xe8946584,0x310800cd}},	//   иема_, rkko_, _мадь, वताः_, 
   {{0x65646585,0x18b400c7,0xdce00419,0x00000000}},	//   rukh, _ҳгәы_, zvoľ, --, 
   {{0x65640882,0x36e82586,0x29040113,0x60dc6586}},	//   sukh, _گروپ_, mlla_, vipm, 
   {{0x644c6587,0x60dc6588,0x2eec0240,0xe24400ae}},	//   sabi, wipm, _njef_, تخسي, 
   {{0x29046589,0x2168658a,0x7534009d,0x00000000}},	// [7240] olla_, ризи_, _нээх, --, 
   {{0x644c658b,0x2904658c,0x9f940254,0x66c401a8}},	//   qabi, nlla_, _tüür_, _kóko, 
   {{0x2904658d,0x94400014,0x3f9c658e,0x93c0054e}},	//   illa_, _تھُن, ívu_, ţări, 
   {{0xe298658f,0x28d8107c,0x2eb853b7,0x21686590}},	//   _там_, योति, _आवृत, _кими_, 
   {{0x29040986,0x62940472,0x01c801e0,0xcd302dd0}},	//   klla_, mdyo, _уҫал_, وروب, 
   {{0x29040784,0x60dc6591,0xbec800de,0x645803b2}},	//   jlla_, qipm, _spīķ, ótih, 
   {{0x3ea40208,0x00000000,0x00000000,0x00000000}},	//   _tnmt_, --, --, --, 
   {{0x29046592,0x62946593,0x66c42833,0x02b805d7}},	//   ella_, ndyo, _sókn, _इकोन, 
   {{0xf8b80184,0x4d68004b,0x7c840092,0xdce00064}},	//   йөк_, _نجلۍ_, _በጎርፍ_, luoč, 
   {{0x1d080c04,0x2ca400e4,0x0d800116,0x66d40153}},	//   _тези_, _gnld_, _юлун, išku, 
   {{0x62940280,0x8ca46594,0x49b400f2,0x37f80166}},	//   kdyo, चारो, ماید_, сенэ_, 
   {{0x29046595,0x95c84494,0xd6d86596,0xf4e40150}},	//   alla_, ауга_, рто_, _ﺍﻳﺘﻜ, 
   {{0x7ae06597,0x6d5c143a,0x29040200,0x2ab001ef}},	//   mimt, _åsat, blla_, _náby_, 
   {{0x7ae06598,0x02b806ab,0x6294009a,0xdce00153}},	//   limt, _इकॉन, edyo, kuoč, 
   {{0x43946599,0x78b800b5,0x66c4659a,0x00000000}},	//   марс, _iovv, _kókl, --, 
   {{0x83f8035b,0x25a4151c,0x62940280,0x78b80455}},	//   цесс_, _šole_, gdyo, _hovv, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [7250] --, --, --, --, 
   {{0xcf9830ba,0x7ae0659b,0x2eec31b2,0x3374659c}},	//   ије_, himt, _sjef_, _егор, 
   {{0x7ae00531,0x764c0731,0x752c0023,0x80bc3885}},	//   kimt, _keay, _huaz, _एवरे, 
   {{0x752c659d,0x78b8659e,0x7c28035a,0x23f80375}},	//   _kuaz, _lovv, _agdr, _להתא, 
   {{0x2904659f,0xaaa80316,0x752c0120,0x8d8402dd}},	//   ylla_, कासक, _juaz, تشان, 
   {{0xd7c838db,0x764c0363,0x78b865a0,0x3168005a}},	//   ानाच, _leay, _novv, muaz_, 
   {{0x447c04ac,0x9be40003,0x7e6400c6,0x66c465a1}},	//   ינגע, _སྨྱོ, óipc, _bókl, 
   {{0xfbd065a2,0x8d8465a3,0x764c1368,0x7ae065a4}},	//   خته_, _музд, _neay, gimt, 
   {{0x290465a5,0x6e2865a6,0x6e4465a7,0x78b8047e}},	//   tlla_, _igeb, _меңз, _bovv, 
   {{0x6d4803f9,0x29040d1d,0x00000000,0x00000000}},	//   _iwea, ulla_, --, --, 
   {{0x6e2801af,0x752c05d5,0x6d48004c,0x764c1368}},	//   _kgeb, _auaz, _hwea, _beay, 
   {{0x752c0083,0x9be40135,0x6d4865a8,0x316801c4}},	//   _buaz, _སྨྲོ, _kwea, kuaz_, 
   {{0xa9a465a9,0x764c0363,0x28f80212,0xe80c0037}},	//   _хилд, _deay, _ледь_, _हरवा_, 
   {{0x66c402ea,0x6d480428,0x6ab80204,0x316801c4}},	//   _tóko, _mwea, _howf, duaz_, 
   {{0x68e065aa,0x6e280198,0x6d4801e2,0x764c0731}},	//   mild, _ogeb, _lwea, _feay, 
   {{0x6e2865ab,0x764c1368,0x2a6c00c5,0x00000000}},	//   _ngeb, _geay, ngeb_, --, 
   {{0x752c65ac,0xdb0801ed,0x3168005a,0x78b801b9}},	// [7260] _guaz, ínés, guaz_, _yovv, 
   {{0x68e065ad,0x6e2865ae,0x7ae065af,0x3ce00490}},	//   nild, _ageb, zimt, _औषधे_, 
   {{0x6d4865b0,0x1e840209,0x752c01c4,0x7ae065b1}},	//   _awea, злем, _zuaz, yimt, 
   {{0x68e065b2,0x6d480076,0xdce00024,0x7ae0036e}},	//   hild, _bwea, ruoč, ximt, 
   {{0x86cc00c6,0x68e065b3,0x1d083117,0x2250037e}},	//   _טּَ_, kild, беди_, mayk_, 
   {{0x6e2865b4,0x7ae00548,0x2a6c031c,0xdfd000ec}},	//   _egeb, wimt, egeb_, _ٻير_, 
   {{0x68e030a8,0x6d480098,0x46cc06ff,0x7ae065b5}},	//   dild, _ewea, ासाह, timt, 
   {{0x78b865b6,0x66c41f60,0xd90c53e2,0x22500113}},	//   _sovv, _bókm, گیت_, nayk_, 
   {{0x6ab80204,0x7ae065b7,0x391465b8,0x78b80455}},	//   _dowf, rimt, ммир, _povv, 
   {{0x7ae065b9,0x68e065ba,0xd90c028e,0x26d00240}},	//   simt, gild, دیت_, ëzon_, 
   {{0x2a6c0369,0x22500784,0x752c65bb,0x3168005a}},	//   bgeb_, kayk_, _suaz, zuaz_, 
   {{0x22500113,0x7ae065bc,0xdb0800e5,0x00000000}},	//   jayk_, qimt, nyfü, --, 
   {{0x68e065bd,0x98a465be,0xaaa8047f,0x18a45cf0}},	//   bild, _ниде, कारक, _надм, 
   {{0x764c009a,0x68e065bf,0x2eb8000d,0x7bdc032e}},	//   _weay, cild, _आव्त, _þrus, 
   {{0xd258074d,0x764c0363,0x6f180042,0xd6d8011c}},	//   йца_, _teay, ymwc, _гтп_, 
   {{0x316801c6,0x752c009f,0x764c0076,0xc738011a}},	//   tuaz_, _tuaz, _ueay, _פתחת, 
   {{0xc2c40597,0xdb0800d7,0x00000000,0x00000000}},	// [7270] ريكي, lyfó, --, --, 
   {{0x66f065c0,0x6d480810,0x6e2801ab,0x316801c6}},	//   māka, _rwea, _sgeb, ruaz_, 
   {{0x66f000da,0xcf2465c1,0x6d4826e7,0x316801c4}},	//   lāka, سراي, _swea, suaz_, 
   {{0x68e065c2,0xe81027a6,0x00000000,0x00000000}},	//   zild, डेटा_, --, --, 
   {{0xfe7065c3,0x66f04424,0x68e04efc,0xacf8322b}},	//   ادم_, nāka, yild, онду_, 
   {{0x6298016b,0x68e00213,0x92640d17,0x66d40118}},	//   _ɔtom, xild, _بدگم, nškr, 
   {{0xddc065c4,0xaaa865c5,0x00000000,0x00000000}},	//   rgoš, कालक, --, --, 
   {{0x6d4865c6,0x68e065c7,0x6e2865c8,0x66f065c9}},	//   _twea, wild, _ugeb, kāka, 
   {{0x68e065ca,0xe9d8487f,0x00000000,0x00000000}},	//   tild, юки_, --, --, 
   {{0x2574022c,0x2d9c00ca,0xac1865cb,0x68e00175}},	//   væl_, mvwe_, _дозу_, uild, 
   {{0x68e065cc,0x6ab80014,0x22500309,0xdb0800d7}},	//   rild, _towf, yayk_, žnár, 
   {{0xdb2407d6,0x536c0023,0x66d40064,0x00000000}},	//   _قولی, _ድልዋት_, eškr, --, 
   {{0x68e065cd,0x66f0005f,0x7afc01ed,0xb7b40137}},	//   pild, gāka, _írta, дөөч, 
   {{0x68e0036b,0x2bd0257b,0xdce001e4,0x2574005c}},	//   qild, तनपा, troĉ, ræl_, 
   {{0xe2a80451,0x00000000,0x00000000,0x00000000}},	//   يارن_, --, --, --, 
   {{0x66f000da,0x626401ec,0x257436e0,0x28d81684}},	//   bāka, باسق, pæl_, योरि, 
   {{0x64b83461,0x66f01a5a,0x91e05211,0x22500784}},	// [7280] _дунё_, cāka, воте, rayk_, 
   {{0x2d9c0af2,0xdce0010f,0xf1b000ec,0xc3300116}},	//   dvwe_, proĉ, دءِ_, _مەس_, 
   {{0xd6d41888,0x00000000,0x00000000,0x00000000}},	//   _رویش_, --, --, --, 
   {{0x6e2c151c,0x44380175,0x3be80137,0x6458022e}},	//   žabn, lcr_, үлдү_, аtig, 
   {{0x8d7065ce,0x205465cf,0x4438003e,0x4d700214}},	//   ناوا, _отвр, ocr_, نطور, 
   {{0x443865d0,0x51f400ec,0x5ba401f0,0x00000000}},	//   ncr_, _آسٽر, дриз, --, 
   {{0x201c4e53,0x28b01a22,0xaaa843d1,0x66f000e2}},	//   _àti_, जानि, कांक, zāka, 
   {{0x44381d8e,0x1ea865d1,0xdde000fb,0x00000000}},	//   hcr_, _باسي_, _иҙеү, --, 
   {{0x645c65d2,0x443801ab,0xa3c0044b,0x00000000}},	//   _odpi, kcr_, ्नड_, --, 
   {{0x66f00318,0x4c80022e,0x00000000,0x00000000}},	//   vāka, _илув, --, --, 
   {{0x1bf00fe3,0xbfec015b,0x66f002b1,0x443865d3}},	//   _अखिल_, _করুণ_, wāka, dcr_, 
   {{0x25a40fb7,0x66f065d4,0x645c030a,0x19c465d5}},	//   _šola_, tāka, _adpi, _обем, 
   {{0x2d9803b2,0xceb005d0,0x00000000,0x00000000}},	//   _áset_, דיר_, --, --, 
   {{0x66f065d6,0x7c38062c,0x27b00116,0x2f1401bf}},	//   rāka, ncvr, тәәс, måge_, 
   {{0xd6d80107,0x2f1401bf,0x69dc00e4,0x00000000}},	//   _мти_, låge_, úsev, --, 
   {{0x60cc0200,0x442801ca,0xc6240154,0x00000000}},	//   _albm, ьцям_, পড়া_, --, 
   {{0x82c8025c,0x4438003e,0xb1145a5e,0x6458022e}},	// [7290] ངྒེའ, bcr_, емаш, аtid, 
   {{0x2bd00950,0x27e80055,0x00000000,0x00000000}},	//   तनमा, _śani_, --, --, 
   {{0x66c405f7,0xdbd40254,0x00000000,0x00000000}},	//   _bókh, _jääo, --, --, 
   {{0xeb980364,0x3f64032e,0x00000000,0x00000000}},	//   ҷик_, _séuð_, --, --, 
   {{0x5e5465d7,0x00000000,0x00000000,0x00000000}},	//   رلوس_, --, --, --, 
   {{0xeb9865d8,0xab28004e,0xdce02ca8,0xda0000c5}},	//   зик_, пока_, rtoğ, _लड़त_, 
   {{0x7f9400c7,0x9cb00e56,0x00000000,0x00000000}},	//   _иарх, امىت, --, --, 
   {{0x65640649,0xa3c065d9,0x00000000,0x00000000}},	//   yrkh, ्नत_, --, --, 
   {{0xa92465da,0x8d7410e0,0xd0000075,0x443800d8}},	//   ндил, _تازا, _чоңқ, ycr_, 
   {{0x6d580c8c,0x8bc465db,0x450c0327,0x00000000}},	//   mswa, _осед, _གེེར_, --, 
   {{0x6d580c8c,0xa2d000dc,0x779065dc,0x00000000}},	//   lswa, ठसम्, لیوا, --, 
   {{0x7ac463e3,0x66c41427,0x2f1401e3,0xfbd80118}},	//   _исче, _kóki, båge_, _भेटम, 
   {{0x6d5814dc,0x4438003a,0x49c41291,0x81e400eb}},	//   nswa, tcr_, _تغاف, _পুন_, 
   {{0x2b9001fa,0x14a407f7,0x182865dd,0x63b80419}},	//   _kšc_, खागण, _فقهی_, ätno, 
   {{0x6d5803ac,0xa3480395,0x00000000,0x00000000}},	//   hswa, язва_, --, --, 
   {{0x44380354,0x6d5865de,0xdce0031c,0x00000000}},	//   scr_, kswa, troċ, --, 
   {{0x66f000e2,0x4438009a,0xdb1c00e5,0x64586316}},	// [72a0] lāko, pcr_, ívéb, ótis, 
   {{0x6d580c8c,0xdce0003d,0xa3b810ed,0x611406be}},	//   dswa, rroċ, _فاجر_, dəlü, 
   {{0x9e6465df,0x6d58127b,0x66f000e2,0x00000000}},	//   евед, eswa, nāko, --, 
   {{0x66c409cc,0x6d5839f0,0xa2b80073,0x62643de2}},	//   _bóki, fswa, _एकट्, _явма, 
   {{0x6d5865e0,0x1d0865e1,0x66f01d76,0xae700131}},	//   gswa, педи_, hāko, شۇلغ, 
   {{0x66f01d76,0x26d00240,0x00000000,0x00000000}},	//   kāko, ëzoj_, --, --, 
   {{0xa3c029ea,0x212800a3,0x9b242ded,0x1a642a77}},	//   ्नि_, _iibh_, нфил, فیای_, 
   {{0x6d5865e2,0xc0f802d3,0xdce000d0,0xd7f801f0}},	//   bswa, ላዎም_, mroč, ҷум_, 
   {{0x6d5865e3,0xf8b800f7,0xdc6801c0,0xdce00306}},	//   cswa, дөй_, _наад_, lroč, 
   {{0xa3c007c1,0xdbd402f6,0x00000000,0x00000000}},	//   ्ना_, _pääo, --, --, 
   {{0xb91001e1,0x36d465e4,0xdaa000d1,0xdce00419}},	//   _kulẹ_, вонр, _مەغپ, nroč, 
   {{0x212865e5,0x89d400f1,0x3964014b,0x00000000}},	//   _libh_, _ګوهر_, _андҳ, --, 
   {{0xb91001e1,0x5884004e,0x058401d5,0x00000000}},	//   _mulẹ_, _зыйа, лурм, --, 
   {{0x212865e6,0xdce00232,0x66f000e2,0xd7f8010a}},	//   _nibh_, kroč, bāko, _нуй_, 
   {{0xdce00030,0x76480174,0x66f00171,0x00000000}},	//   jroč, ðeys, cāko, --, 
   {{0xdce00fb7,0x212865e7,0x6d580c8c,0x7bd80007}},	//   droč, _aibh_, yswa, izvu, 
   {{0x200865e8,0x94a800d8,0x6d580857,0xfde0000d}},	// [72b0] _aybi_, _етна_, xswa, _खेलस_, 
   {{0xe72c04d3,0x66c40162,0x6d58035a,0x00000000}},	//   _دڵی_, _róki, vswa, --, 
   {{0x6d580c8c,0x61e800ac,0x28b0255c,0x2008015d}},	//   wswa, _əllə, जाति, _cybi_, 
   {{0x6d5865e9,0x212801ab,0x7bd80810,0x00000000}},	//   tswa, _eibh_, dzvu, --, 
   {{0x6d5865ea,0x212800a3,0xd20865eb,0xedbc012c}},	//   uswa, _fibh_, _хэнд_, ्नेछ, 
   {{0x6d5814dc,0xdce065ec,0x212801ab,0x506465ed}},	//   rswa, broč, _gibh_, _ятма, 
   {{0x6d5865ee,0xeb9801b9,0xdce000d0,0x2bd02efd}},	//   sswa, фий_, croč, तनधा, 
   {{0xeab00597,0x15dc0150,0x6d58127b,0x00000000}},	//   شعب_, _ﺇﺒﺎﺩ, pswa, --, 
   {{0x28f805f5,0xe9a80214,0xac940124,0x6d5865ef}},	//   дэнэ_, بگان_, _иааш, qswa, 
   {{0x773c0020,0x25a4151c,0x316800d8,0x00000000}},	//   _የተመደ, _šolo_, iraz_, --, 
   {{0x0ba405bc,0x8b6400db,0x786c001f,0x00000000}},	//   _яшам, _ساام, _ተጠያቂ_, --, 
   {{0x66f000e2,0xba74009f,0x387000c7,0x00000000}},	//   rāko, _ماهت, ақәт, --, 
   {{0xdce000d7,0x00000000,0x00000000,0x00000000}},	//   zroč, --, --, --, 
   {{0x316865f0,0x154065f1,0x98a400d7,0x00000000}},	//   draz_, рерм, _zvoľ_, --, 
   {{0x33d40220,0x316801c6,0x21281554,0xe58400f7}},	//   гітт, eraz_, _ribh_, رۅگۉ_, 
   {{0x212865f2,0x316807ab,0xdce00219,0xa6840116}},	//   _sibh_, fraz_, vroč, _рлид, 
   {{0x26d00526,0x66c402d2,0x205402dd,0x00000000}},	// [72c0] _ilyo_, _bókv, втер, --, 
   {{0x7bd80007,0xe35404b4,0x23b800dc,0xdce01155}},	//   yzvu, _итмэ, _उपपद, troč, 
   {{0x316801c4,0xb90c00c7,0x224800d8,0x00000000}},	//   araz_, tuhẽ_, _опни_, --, 
   {{0x316865f3,0xdce000d0,0xdb0800e5,0x88c400eb}},	//   braz_, rroč, lyfö, শফিক, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x504065f4,0xdce000c0,0x21280332,0xce340139}},	//   _верб, proč, _uibh_, нчәч_, 
   {{0x66c43e33,0xfb8401d3,0x5f04030d,0x6d5c02d2}},	//   _hóku, ادتی, _азва, _æsan, 
   {{0xb99865f5,0x66c401d3,0x93f8011a,0x00000000}},	//   евих_, _kóku, ולצי, --, 
   {{0x0d7465f6,0x1d240124,0xeef40953,0x9d500131}},	//   _لینک_, _амам, _сярэ, _ئۆتت, 
   {{0x52bc0141,0x2f1401e6,0x26d015a9,0xc3000154}},	//   _एक्स, måga_, _alyo_, ্দটি_, 
   {{0x661400a2,0x66c401e1,0x316800d0,0x628400d7}},	//   _azyk, _lóku, zraz_, _obko, 
   {{0x316865f7,0x66140210,0x00000000,0x00000000}},	//   yraz_, _bzyk, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x316865f8,0x97a465f9,0x645865fa,0x62843218}},	//   vraz_, _арил, ótip, _abko, 
   {{0x03c405c1,0x00000000,0x00000000,0x00000000}},	//   астм, --, --, --, 
   {{0x66c409f3,0xb5940032,0xbfec00cc,0xc4fc0171}},	//   _bóku, _бииш, _কৰ্ণ_, _ķīše, 
   {{0x3f980b23,0xd44801f0,0x00000000,0x00000000}},	// [72d0] _asru_, _оянд_, --, --, 
   {{0x705465fb,0x316865fc,0xd34465fd,0x0ef80c5a}},	//   اناا, rraz_, _لیسه_, एक्स_, 
   {{0x2d4c0023,0x00000000,0x00000000,0x00000000}},	//   _ዝተካየ, --, --, --, 
   {{0x2dd42838,0x31680bbc,0xa3c01b51,0x66c4655d}},	//   лжер, praz_, ्नर_, _fóku, 
   {{0x26d00240,0x316803b9,0x00000000,0x00000000}},	//   ëzoi_, qraz_, --, --, 
   {{0xcfa4151a,0xd01801af,0x00000000,0x00000000}},	//   _ишби, _жфб_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x427002d3,0x0aa4020a,0xca380023,0x5c700131}},	//   _ድኽነት_, тбиқ_, _ተሳቲፎ, аләт, 
   {{0x6f0800b5,0x3d940166,0xadf40063,0x00000000}},	//   _ikec, _китр, _спаш, --, 
   {{0xcbe40124,0x00000000,0x00000000,0x00000000}},	//   _ицеи, --, --, --, 
   {{0xfbd065fe,0x28d81fe5,0x6614033f,0xb0b002dd}},	//   _وتم_, योगि, _szyk, ргiл, 
   {{0x28b0007d,0x4e1437c8,0xfbdc0154,0x00000000}},	//   जाहि, _तराई_, _ঢুকত, --, 
   {{0x95800962,0xa97800c8,0x255801c0,0xb4c000c5}},	//   бляе, _נאַכ, эрнэ_, ्घू_, 
   {{0x66c465ff,0xa3c010b7,0x69c819a0,0x64a40063}},	//   _róku, ्नल_, myee, ћава, 
   {{0x69c801d9,0x6f086600,0xa2d40472,0x00000000}},	//   lyee, _okec, هيست, --, 
   {{0x29046601,0x18b40124,0x66c4032e,0xc24400fb}},	//   lola_, _агәы_, _póku, рмаҫ, 
   {{0x69c86602,0x7b380115,0xe1f86603,0xca801884}},	// [72e0] nyee, _aĉul, хга_, ﻩﺗﺘﻪ_, 
   {{0x29046604,0x69c801d9,0x6f086605,0x443c000d}},	//   nola_, iyee, _akec, _üv_, 
   {{0x29046606,0xda0800bc,0x69c86607,0x1f642377}},	//   iola_, _हुनत_, hyee, укем, 
   {{0x66c401a8,0x69c81418,0x4aa001f9,0x00000000}},	//   _tóku, kyee, _खोलव, --, 
   {{0x29046608,0x69c80218,0x9ce4010b,0xdbd4002f}},	//   kola_, jyee, лцкл, fäßc, 
   {{0x29046609,0x2f1401e6,0x69c8058a,0xff1400fe}},	//   jola_, råga_, dyee, িদেশ_, 
   {{0x69c801d9,0x66c401a8,0x00000000,0x00000000}},	//   eyee, _jóks, --, --, 
   {{0x2550033b,0x69c8058a,0x00000000,0x00000000}},	//   kņl_, fyee, --, --, 
   {{0x2904660a,0x69c8660b,0x8e2c01a9,0x78d40395}},	//   fola_, gyee, migа_, ижих, 
   {{0x49d4005b,0x8e2c022e,0x00000000,0x00000000}},	//   удью_, ligа_, --, --, 
   {{0x69c80050,0x9a84660c,0x9f4c013d,0x37f80166}},	//   ayee, _булл, _änäs_, тенэ_, 
   {{0x290406c8,0x69c8660d,0x75d408f0,0x8e2c01a9}},	//   aola_, byee, ليجا, nigа_, 
   {{0x2904660e,0x6298013f,0x69c80009,0xe5140037}},	//   bola_, _ɔtot, cyee, _दीहि_, 
   {{0x2904660f,0xc0f0044e,0xa3c00b9c,0x66c405f7}},	//   cola_, _ቁጽሪ_, ्नं_, _bóks, 
   {{0xe3c46610,0x0838008f,0xbb4c01ec,0x28b06611}},	//   артү, _טעגל, _ﺃﺩﻯ_, जारि, 
   {{0x8c18011a,0x80780116,0x00000000,0x00000000}},	//   תולי, һбус_, --, --, 
   {{0x798003ac,0x27f000d7,0x00000000,0x00000000}},	// [72f0] ntmw, ĺzne_, --, --, 
   {{0x6f086612,0x73c46613,0x91300022,0x0fe000db}},	//   _skec, _кәбе, _ҳҭах, бөбү, 
   {{0x74145da7,0xa3c00882,0x2fd80214,0x66c40174}},	//   _خودا, ्नः_, خواد_, _tókt, 
   {{0x69c86614,0x29046615,0x9fa40184,0x8e2c01a9}},	//   yyee, zola_, шыуҙ, gigа_, 
   {{0x29046616,0x69c801d9,0x463c010f,0x00000000}},	//   yola_, xyee, געדע, --, 
   {{0x69c801d4,0x29046617,0xad2400d1,0x40345740}},	//   vyee, xola_, جىتى, _герс, 
   {{0x29046618,0xb1140131,0xfc6400a7,0x6f080327}},	//   vola_, _موڭغ, съчн, _tkec, 
   {{0x29046619,0x66c400c7,0x63b8055e,0x69c8023a}},	//   wola_, _lókr, ätni, tyee, 
   {{0xc5f402a8,0xafe40139,0x00000000,0x00000000}},	//   _keɓe_, _соңл, --, --, 
   {{0x2d8c0770,0x69c801d9,0x29040a8b,0xe7a801b9}},	//   _ipee_, ryee, uola_, ввол_, 
   {{0x2904661a,0xbd98037e,0x66f01c52,0x69c8661b}},	//   rola_, _dとui, lāki, syee, 
   {{0x28d802e5,0x2d8c01f2,0x9b4004d3,0x26540063}},	//   योजि, _kpee_, _بچوو, шњос, 
   {{0x66f000da,0x2904661c,0x270c033f,0x7e640332}},	//   nāki, pola_, सतौर_, óipi, 
   {{0x2904661d,0x64a4661e,0x00000000,0x00000000}},	//   qola_, шага, --, --, 
   {{0xe644661f,0x66f01d76,0x224401c4,0xe4e40150}},	//   _кейп, hāki, ñoko_, гіңн, 
   {{0x2d8c0270,0xd7f80302,0x00000000,0x00000000}},	//   _opee_, _בהצל, --, --, 
   {{0x29fc01e4,0xf1d400db,0x13000150,0x00000000}},	// [7300] nʈa_, бөрө, ізум, --, 
   {{0x66c409f3,0x39400036,0x8e2c022e,0x66f00171}},	//   _tóks, _éise_, vigа_, dāki, 
   {{0x2d8c0418,0xb62c0023,0x00000000,0x00000000}},	//   _apee_, ተዘይቀ, --, --, 
   {{0x2ba86620,0x8e2c01a9,0x00000000,0x00000000}},	//   किना, tigа_, --, --, 
   {{0x644c011f,0x81e4015b,0x66f000e2,0x83dc00cc}},	//   obbi, _পুর_, gāki, _মুচৌ, 
   {{0x98a00069,0xa0680b7e,0x23b829c7,0x71701e4a}},	//   īkī_, _шага_, _उपाद, _رۇما, 
   {{0x8e2c01d5,0x00000000,0x00000000,0x00000000}},	//   sigа_, --, --, --, 
   {{0x8f9810df,0x09e400bd,0x66f0005f,0xd1c802d3}},	//   _בילי, _পড়া, bāki, _አኼባ_, 
   {{0x66f000da,0x95240327,0xddc00427,0x8e2c01a9}},	//   cāki, _རྫའི_, lgož, qigа_, 
   {{0x57a46621,0x98c46622,0x97a40c98,0x779800f3}},	//   ашма, рсил, армл, гкор_, 
   {{0x10340302,0x6298013f,0xbaa4022e,0x00000000}},	//   יטים_, _ɔtor, _гулқ, --, 
   {{0x66c4032e,0x00000000,0x00000000,0x00000000}},	//   _sókr, --, --, --, 
   {{0xc6f82e01,0xceb008a8,0x6bd40150,0x8784009d}},	//   рнях_, קיש_, _پتەر, гөөг_, 
   {{0xf49002d3,0x55046623,0x66d400c0,0xa9c405af}},	//   _ምዝራብ_, рчма, išky, _دزمو, 
   {{0x2ba860c7,0xd6d800f0,0x88b8011a,0x81e400eb}},	//   किया, _атп_, _במגז, _পুল_, 
   {{0x644c0a55,0xe19401c6,0x964400b1,0x00000000}},	//   abbi, өлсө, _тэкд, --, 
   {{0x765c6624,0x94846625,0x417414fb,0x00000000}},	// [7310] masy, _кынд, قالس, --, 
   {{0x66f01a14,0x660000a2,0x00000000,0x00000000}},	//   vāki, _ÿoka, --, --, 
   {{0x66f002b1,0x00000000,0x00000000,0x00000000}},	//   wāki, --, --, --, 
   {{0x25a4151c,0x66f06626,0xbe8800cf,0xf4840345}},	//   _šoli_, tāki, исче_, _ئاکی, 
   {{0x6da46627,0xada428db,0x66c40085,0x8d7440bb}},	//   сила, салл, _mókp, شاشا, 
   {{0x765c6628,0x66f0005f,0x00000000,0x00000000}},	//   hasy, rāki, --, --, 
   {{0xac080064,0x00000000,0x00000000,0x00000000}},	//   ынка_, --, --, --, 
   {{0xc3340302,0x765c00dc,0x66f002b1,0xc94001d5}},	//   חוק_, jasy, pāki, одиқ, 
   {{0x765c6629,0x44240208,0x2d8c01f4,0x645801a9}},	//   dasy, ̀m_, _upee_, аtil, 
   {{0x6584013f,0x765c0076,0x25ac01ef,0x00000000}},	//   _sɔho, easy, _čfl_, --, 
   {{0xe72805f5,0x765c003e,0xec14004b,0x29fc01e4}},	//   лоод_, fasy, _اواد, sʈa_, 
   {{0x2b800034,0x00000000,0x00000000,0x00000000}},	//   móc_, --, --, --, 
   {{0xa9681515,0x958011db,0x2b80407c,0xe94400db}},	//   _сила_, пляе, lóc_, _انتپ, 
   {{0xd76000e5,0x00000000,0x00000000,0x00000000}},	//   _کنٹی, --, --, --, 
   {{0x765c662a,0x4ad8007d,0x81e4009e,0x00000000}},	//   basy, _बताव, _পুং_, --, 
   {{0x64a407dd,0x3940007b,0x282001d9,0x765c662b}},	//   шаҳа, _éisc_, _وژھہ, casy, 
   {{0x644c0395,0x35c401d5,0x00000000,0x00000000}},	// [7320] pbbi, _маъҳ, --, --, 
   {{0xda0800c5,0xe6100133,0x00000000,0x00000000}},	//   _हँसत_, _وشک_, --, --, 
   {{0x4444662c,0x2d4c044e,0x00000000,0x00000000}},	//   _if_, _ዝተኻየ, --, --, 
   {{0x7d080022,0x7e980330,0x5398011a,0x00000000}},	//   _oĩrõ, شنتر_, _עיכו, --, 
   {{0x4444662d,0x6b8001a9,0xba900150,0xa3c0012d}},	//   _kf_, _aqlg, _ﺒﺄﻨﻙ_, ्नक_, 
   {{0x765c662e,0x3ea0038e,0x6294662f,0x30740b00}},	//   zasy, žit_, leyo, _мусс, 
   {{0x765c6630,0x2b80067c,0x44442238,0x00000000}},	//   yasy, góc_, _mf_, --, 
   {{0x62946631,0x765c07ab,0xdee40063,0x0b9000d1}},	//   neyo, xasy, _уоби, سجىد, 
   {{0x44440302,0x38c853f3,0x765c6632,0x66f000da}},	//   _of_, لادی_, vasy, nāku, 
   {{0x444445eb,0x765c6633,0x0dc400a8,0x50d8010f}},	//   _nf_, wasy, _улуй_, ָקטא, 
   {{0x66f06634,0xd7e40046,0x62946635,0x6f0c054e}},	//   hāku, сіпо, keyo, _încî, 
   {{0x44446636,0xc844044e,0xdb0c005b,0x4b3404ae}},	//   _af_, መስለን, äjäk, _הראל_, 
   {{0x62946637,0x87e400fb,0x38c84d4e,0x00000000}},	//   deyo, иһәң_, _پاشی_, --, 
   {{0x765c6638,0x89780302,0x26d00200,0xafc001e1}},	//   sasy, _ערוצ, ëzor_, _óògù, 
   {{0x44446639,0x3ce00037,0x5744007b,0x00000000}},	//   _df_, _कतने_, _اختف, --, 
   {{0x4444663a,0x6294663b,0xd5b801af,0x2ba81788}},	//   _ef_, geyo, _бсо_, किता, 
   {{0x4444663c,0x45300023,0x96ac000d,0x7afc00e5}},	// [7330] _ff_, ተረኽበ, _जोयउ, _írtu, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6294663d,0xd01800f3,0x4ea41d4d,0x00000000}},	//   beyo, уфа_, йрда, --, 
   {{0x4444663e,0xe8b40254,0x5ca80014,0x66f00171}},	//   _zf_, _अच्च, یٖنہ_, bāku, 
   {{0x44443a0e,0x02a401c0,0x3f9c03b2,0x66f0411e}},	//   _yf_, _эрэм, ævur_, cāku, 
   {{0x4444663f,0xd9bc04c5,0x4f586640,0x00000000}},	//   _xf_, ইনাম, _مجرد_, --, 
   {{0xfd1046e6,0xaed40212,0x00000000,0x00000000}},	//   رجه_, _довш, --, --, 
   {{0x66f0005f,0x2b8000ae,0x00000000,0x00000000}},	//   nākt, róc_, --, --, 
   {{0x2d9801e1,0x00000000,0x00000000,0x00000000}},	//   _èse_, --, --, --, 
   {{0x6d480831,0xdd0c1b07,0x28e86641,0x62946642}},	//   _itea, mışl, рдоп_, zeyo, 
   {{0xdd0c0724,0x62946643,0xa6c800f1,0x66f000e2}},	//   lışl, yeyo, لودل_, zāku, 
   {{0x6d480165,0x44445f5c,0x00000000,0x00000000}},	//   _ktea, _sf_, --, --, 
   {{0x44446644,0xdd0c4944,0x62946645,0x89346646}},	//   _pf_, nışl, veyo, _اعصا, 
   {{0xa348006c,0x44446647,0x62940a49,0x00000000}},	//   изга_, _qf_, weyo, --, 
   {{0x6294033b,0x44445182,0x625801b9,0x53a021fe}},	//   teyo, _vf_, ирар_, марб, 
   {{0xdd0c6648,0xded4001f,0x6d48035a,0xd24c00e5}},	//   kışl, ሪቱን_, _otea, ہنہ_, 
   {{0x62946649,0x4444664a,0x6d48013b,0x64a40953}},	// [7340] reyo, _tf_, _ntea, _дапа, 
   {{0x4444664b,0x26c004b9,0x62940921,0x66f00f40}},	//   _uf_, ljko_, seyo, rāku, 
   {{0x66f00029,0x6d48664c,0x9f4803b9,0x00000000}},	//   sāku, _atea, _ümüd_, --, 
   {{0x6d480076,0x62940784,0x26c00010,0x57f80a7c}},	//   _btea, qeyo, njko_, בלעו, 
   {{0xdd0c0598,0x2250002d,0xd12c00cf,0x00000000}},	//   gışl, mbyk_, رمۅ_, --, 
   {{0x6d480597,0xdb68664d,0x00000000,0x00000000}},	//   _dtea, арил_, --, --, 
   {{0xdfd0664e,0x66f000e2,0x6d48664f,0x72a000cf}},	//   _غير_, nāks, _etea, _زەەن, 
   {{0x99646650,0xdd0c008e,0x00000000,0x00000000}},	//   отол, bışl, --, --, 
   {{0x6d48062c,0x00000000,0x00000000,0x00000000}},	//   _gtea, --, --, --, 
   {{0x5b34084c,0xd90c0244,0x28b001f9,0x00000000}},	//   _дэду, خیت_, जागि, --, 
   {{0xd7f80322,0x248c02d3,0x38c81888,0xa3a80210}},	//   руп_, _ምምላስ_, لاگی_, _गज़ल_, 
   {{0x3ea400cc,0x00000000,0x00000000,0x00000000}},	//   _jamt_, --, --, --, 
   {{0x60dc009a,0x4734004b,0xda1c6651,0x66f000e2}},	//   khpm, ګریز, _परित_, vākt, 
   {{0x98ac0100,0xb78801af,0x00000000,0x00000000}},	//   _kifč_, _ләме_, --, --, 
   {{0x92c4330e,0x36d4008e,0x00000000,0x00000000}},	//   ощад, _нокр, --, --, 
   {{0xdd0c1d89,0xda1c000d,0xdce007f5,0x00000000}},	//   yışl, _परात_, broć, --, 
   {{0xdd0c00ac,0x00000000,0x00000000,0x00000000}},	// [7350] xışl, --, --, --, 
   {{0x66f000e2,0x00000000,0x00000000,0x00000000}},	//   sākt, --, --, --, 
   {{0x3ea40354,0x6d486652,0x649800d9,0x4ad800c5}},	//   _bamt_, _stea, _הסתד, _बतलव, 
   {{0x59c86653,0xdd0c6654,0x00000000,0x00000000}},	//   िहार, tışl, --, --, 
   {{0xa2806646,0x867c011a,0x81680395,0x00000000}},	//   _سیلو, שרדו, _мррб_, --, 
   {{0xdd0c6655,0x81e400cc,0xa3c00073,0x459c010f}},	//   rışl, _পুক_, ्नच_, יסדע, 
   {{0x2f1801c0,0x00000000,0x00000000,0x00000000}},	//   _говь_, --, --, --, 
   {{0x6d4805b1,0xc4c81be1,0x00000000,0x00000000}},	//   _ttea, _रक्ख, --, --, 
   {{0x7bd80558,0x6d48143a,0xdd0c6656,0x64400356}},	//   _čauš, _utea, qışl, _şoim, 
   {{0x2c4400c7,0x00000000,0x00000000,0x00000000}},	//   _хьаҳ, --, --, --, 
   {{0xaa9402bf,0x3ea402d1,0x2d9c009a,0xdce00205}},	//   _нижч, _yamt_, lwwe_, luoğ, 
   {{0x2ca46657,0x66d800a7,0x592401d3,0x00000000}},	//   _hald_, сьор_, _ہونے, --, 
   {{0x332800b5,0x2ca44675,0xb6c401e0,0xba74029e}},	//   dmax_, _kald_, фияһ, _زانت, 
   {{0xf7780327,0x00000000,0x00000000,0x00000000}},	//   buħ_, --, --, --, 
   {{0x2ca46658,0x66580408,0x942000f3,0xb5dc002b}},	//   _mald_, _лайă, емре, _āṅgi, 
   {{0x3328005c,0xa3480022,0x00000000,0x00000000}},	//   gmax_, изҳа_, --, --, 
   {{0x3ea46659,0xe29801e0,0xe0d8665a,0x00000000}},	// [7360] _ramt_, _һан_, бва_, --, 
   {{0x3ea4665b,0x65640423,0xdce006be,0x00000000}},	//   _samt_, mskh, duoğ, --, 
   {{0x645c00da,0xe298665c,0x00000000,0x00000000}},	//   _iepi, _лан_, --, --, 
   {{0x645c665d,0xd00c0a12,0x6614023a,0x332801c7}},	//   _hepi, دلم_, _kyyk, cmax_, 
   {{0x65640649,0x6734014f,0x2ca4665e,0x00000000}},	//   nskh, _miyj, _bald_, --, 
   {{0x645c665f,0x2ca46660,0x661401f4,0xac0c00cd}},	//   _jepi, _cald_, _myyk, _ṣaṭt, 
   {{0x645c6661,0x656403a2,0x00000000,0x00000000}},	//   _mepi, hskh, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2ca4019b,0xfe20007d,0xd83809a5,0x3cec0208}},	//   _fald_, _बरिस_, йэн_, _tmdv_, 
   {{0x645c6662,0x4c8000a7,0x4934005b,0x4dd8011a}},	//   _nepi, _плув, язью_, _החמו, 
   {{0x6584013f,0x332800d7,0x9a8c00fb,0xb904197c}},	//   _kɔhw, ymax_, _булh, _नत_, 
   {{0xd6d80b16,0xd7f81638,0x645c003a,0x8f980a1e}},	//   сто_, _қул_, _aepi, זיטי, 
   {{0x6734010b,0x5ebc00cc,0x645c6663,0x992800f5}},	//   _diyj, _আতাই, _bepi, _люка_, 
   {{0x645c6664,0x661401f4,0x00000000,0x00000000}},	//   _cepi, _dyyk, --, --, 
   {{0x645c6665,0x926801c0,0xe8e8009a,0x00000000}},	//   _depi, йраа_, _برنو_, --, 
   {{0x7a780020,0x645c0857,0x673400a2,0x1dbc07b6}},	//   _በቀጥታ_, _eepi, _giyj, ्हात, 
   {{0x33286666,0x645c2486,0xa2cc00dc,0x00000000}},	// [7370] rmax_, _fepi, _सवर्, --, 
   {{0x645c6667,0x00000000,0x00000000,0x00000000}},	//   _gepi, --, --, --, 
   {{0x2ca403b2,0x332800d7,0x00000000,0x00000000}},	//   _rald_, pmax_, --, --, 
   {{0x645c6668,0x2d0400e1,0xadf46669,0x00000000}},	//   _zepi, शक्ल_, мпеш, --, 
   {{0x645c00e4,0x7dc4007b,0x00000000,0x00000000}},	//   _yepi, فتوك, --, --, 
   {{0x8650013f,0x7f4800d1,0xdce00205,0x2ba82802}},	//   _nnɔn, زلۇق_, ruoğ, किला, 
   {{0x2ca4666a,0x7f944483,0x7c64027d,0x00000000}},	//   _vald_, _парх, راول, --, 
   {{0xe9d84945,0x8650013f,0x6120666b,0x2ca4666c}},	//   жки_, _anɔn, rôle, _wald_, 
   {{0x2ca4666d,0xa9244042,0x6f18015d,0x00000000}},	//   _tald_, мдил, mlwc, --, 
   {{0x6f180cfd,0x29100419,0x00000000,0x00000000}},	//   llwc, ôza_, --, --, 
   {{0x645c666e,0x7d04666f,0x656403a2,0x6614005b}},	//   _repi, éise, wskh, _syyk, 
   {{0x645c6670,0x6614023a,0x6af42235,0x65640158}},	//   _sepi, _pyyk, _юзеф, tskh, 
   {{0x6aa8016b,0x628801d3,0x09e400eb,0x00000000}},	//   mdef, őfok, _পডকা, --, 
   {{0x645c6671,0x65646672,0x7c3400a2,0xb93400f3}},	//   _qepi, rskh, _ýerý, _зечј, 
   {{0x18a0010b,0x66e40137,0xf8a80244,0xdef00023}},	//   _ращм, _оока, _ردوه_, _ውጻእ_, 
   {{0x6aa8325f,0x645c6004,0xe5780395,0x00000000}},	//   ndef, _wepi, _дзи_, --, 
   {{0x6aa86081,0x7d1805ac,0x6f18015d,0xa0a40024}},	// [7380] idef, ylvs, dlwc, маад, 
   {{0x65840134,0x645c0093,0x6aa80113,0x48a803d4}},	//   _sɔhw, _uepi, hdef, _চকুৰ, 
   {{0xa3640014,0xa2e46673,0x6f180042,0xe3b0072d}},	//   _تُجو, _жонд, flwc, _شرد_, 
   {{0xfd6400f7,0x626400ee,0x25b06674,0x6aa801bf}},	//   ендү, _ювма, _kryl_, jdef, 
   {{0x6aa86675,0x78a801e3,0x00000000,0x00000000}},	//   ddef, yddv, --, --, 
   {{0x6584016b,0x6aa80221,0x6f18015d,0x00000000}},	//   _wɔhw, edef, alwc, --, 
   {{0x6aa81509,0xfcc40032,0x8fa00124,0x63ac0175}},	//   fdef, _үҙем, _иаре, nvbn, 
   {{0x6aa8332c,0x9e6402e9,0xff246676,0x00000000}},	//   gdef, _زارن, _سبزی, --, 
   {{0x7e600472,0x0d80010a,0x00000000,0x00000000}},	//   _iemp, _илтн, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7e606677,0x691c0100,0x25b00f85,0x00000000}},	//   _kemp, pèen, _aryl_, --, 
   {{0x7e606678,0x6aa86679,0x855801ed,0xa3d00456}},	//   _jemp, cdef, ڈیٹر_, वहन_, 
   {{0x7e604020,0x94a8667a,0xc9a41302,0x058400db}},	//   _memp, отва_, _овце_, курм, 
   {{0xd7f80117,0x00000000,0x00000000,0x00000000}},	//   _муй_, --, --, --, 
   {{0xdce001a6,0x25b00042,0x7e60667b,0x00000000}},	//   jsoč, _eryl_, _oemp, --, 
   {{0x7e60667c,0x59d000cd,0x2fe83769,0x00000000}},	//   _nemp, _तथार, ۋباۋ_, --, 
   {{0x914800a7,0xd5b800d4,0x14c801f4,0x00000000}},	// [7390] ючва_, _єси_, _дыни_, --, 
   {{0x7e60667d,0x622400cf,0x00000000,0x00000000}},	//   _aemp, رولە, --, --, 
   {{0x68ec0649,0x6aa80450,0x249c000d,0x00000000}},	//   _ïade, ydef, õtme_, --, 
   {{0x7e60667e,0x25b000a2,0x6e4400f2,0x00000000}},	//   _cemp, _yryl_, رنتم, --, 
   {{0x7e602508,0x506403a6,0xbdf8314e,0x776802c4}},	//   _demp, _отва, ورها_, hsdx, 
   {{0x7e60667f,0x7124515c,0xadbc02dd,0x3e7401e1}},	//   _eemp, _سىزم, _қазi, _pútà_, 
   {{0xeb906680,0x7e60003a,0xddc00115,0xfc6402e8}},	//   اظت_, _femp, mboŝ, тъчн, 
   {{0x9b901002,0x3218049b,0x00000000,0x00000000}},	//   اليت, _kysy_, --, --, 
   {{0x7d0404c4,0x3dc00036,0x00000000,0x00000000}},	//   éisc, äiwt_, --, --, 
   {{0x7e606681,0x8cb40014,0x4ad8000d,0x00000000}},	//   _zemp, _زگتس_, _बतकव, --, 
   {{0x7e602747,0x8ac4009d,0x00000000,0x00000000}},	//   _yemp, _оёдл, --, --, 
   {{0x25b00267,0x7e606682,0x3a540024,0x00000000}},	//   _pryl_, _xemp, _акцё, --, 
   {{0xb6c000c7,0x00000000,0x00000000,0x00000000}},	//   рҩыд, --, --, --, 
   {{0x18a06683,0x98a029db,0x00000000,0x00000000}},	//   _башм, _бише, --, --, 
   {{0x23281f91,0x64a4035b,0x00000000,0x00000000}},	//   зови_, _ҟана, --, --, 
   {{0x490400bc,0xdecc01f3,0x00000000,0x00000000}},	//   सकको_, ባታን_, --, --, 
   {{0x7e606684,0xe0d800a7,0x91e03129,0x00000000}},	// [73a0] _remp, пва_, готе, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7e606685,0x00000000,0x00000000,0x00000000}},	//   _pemp, --, --, --, 
   {{0x7e600477,0x9da800a7,0x00000000,0x00000000}},	//   _qemp, зъка_, --, --, 
   {{0x62846686,0x8d700244,0x7e6057c6,0xdee401f0}},	//   _icko, هاوا, _vemp, _ҷови, 
   {{0x5ba455ee,0x7e606580,0xa2e0009e,0x0c7c0092}},	//   ериз, _wemp, _যদিও, _የችግሩ_, 
   {{0x91002e58,0x1e940006,0xdee45acb,0xdfa800f2}},	//   _спре, _прар, _зови, _عطسه_, 
   {{0x60cc6687,0x5018011a,0xe39401ec,0x2da401f4}},	//   _hobm, _זולו, _ﺘﺴﻤﺢ_, äpeä_, 
   {{0x58840387,0x80c407b6,0x00000000,0x00000000}},	//   нына, रापे, --, --, 
   {{0x60cc6688,0x49700006,0xae0401af,0x00000000}},	//   _jobm, ыльс, _роуҙ, --, 
   {{0x60cc6689,0x6284668a,0x56f00131,0xd7f800fb}},	//   _mobm, _ocko, лүкс, яуи_, 
   {{0x60cc014f,0xcf90011a,0x95c8668b,0x00000000}},	//   _lobm, נטר_, пуга_, --, 
   {{0xceb00375,0x55040024,0x4668009d,0x00000000}},	//   איר_, ечва, эрэм_, --, 
   {{0x2edc668c,0x80c402ab,0x60cc047e,0x17680116}},	//   _मत्त, राफे, _nobm, _ерип_, 
   {{0x4394668d,0xf484668e,0xd3401424,0x00000000}},	//   ларс, _یادی, افری, --, 
   {{0x35b400c7,0x926800fd,0x3218023a,0x316801c4}},	//   _абир, ярга_, _pysy_, tsaz_, 
   {{0x764c668f,0xa5c00046,0x3f98026c,0xba0402d3}},	// [73b0] _ifay, _көре, _apru_, _ጎኒ_, 
   {{0x100416a8,0x6284035a,0x316801c7,0x00000000}},	//   няем, _ecko, rsaz_, --, 
   {{0xc10400c6,0x6da40276,0xddc001e4,0xa434014b}},	//   دولي, ӂила, rboŝ, _аҷру_, 
   {{0x51846690,0x612006af,0x2f140158,0x877808a8}},	//   _пуга, rôla, vågs_, לאבי, 
   {{0x6da46691,0xc69400df,0x00000000,0x00000000}},	//   тила, טאף_, --, --, 
   {{0xeb986692,0x612005da,0xcf400ef6,0x48a803d4}},	//   дик_, pôla, _مىسۋ, _চক্ৰ, 
   {{0xc104215e,0x764c6693,0x6284035a,0x46c400cd}},	//   _صوفي, _ofay, _ycko, षामह, 
   {{0x7b446694,0x60cc0427,0x89a40116,0xdcb40139}},	//   دئول, _zobm, ейиң_, егәч_, 
   {{0xac8c0020,0x2f140267,0x60cc0477,0x3ea06695}},	//   ነበረም_, sågs_, _yobm, õite_, 
   {{0x764c058a,0xa25c02d3,0x80c4448b,0x00000000}},	//   _afay, ታትናን_, राये, --, 
   {{0x66e40364,0x6bd801d3,0xa9c000cf,0x00000000}},	//   вона, _تواس_, _چۅبۉ, --, 
   {{0x764c07ab,0xd6c05439,0x699400c7,0x00000000}},	//   _cfay, لمپی, _аркх, --, 
   {{0x80c408ec,0x2ba807b7,0x7d540354,0x00000000}},	//   रामे, किका, _ывăх, --, 
   {{0x764c0921,0x64a40640,0xdecc0092,0xac8c0092}},	//   _efay, њава, ባታና_, ነበሩም_, 
   {{0x764c0083,0x638400a7,0x26100562,0x62840205}},	//   _ffay, ъгва, _धुरी_, _pcko, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa5246696,0x60cc0142,0x61e801e4,0xa11402da}},	// [73c0] _имид, _pobm, ĝflo, نورت, 
   {{0x9ff86697,0x60cc014f,0xdebc0092,0x00000000}},	//   وراء_, _qobm, _ሰበካ_, --, 
   {{0x10a06698,0x983c0020,0x80c407f7,0x9e641468}},	//   рихн, _አጠቃቀ, राबे, введ, 
   {{0xe194152d,0x60cc0477,0xde741374,0x0e600116}},	//   _иргэ, _wobm, ئداع, қкән, 
   {{0x60cc047e,0x5de400a7,0xaac4095f,0x00000000}},	//   _tobm, ъжда, वानक, --, 
   {{0x8d100212,0x71700131,0x60246699,0x00000000}},	//   адії, _دۇكا, _адга, --, 
   {{0x8bc000a7,0xa3d000dc,0x3a200010,0xac8c0023}},	//   исъд, वहि_, _šip_, ነበሮም_, 
   {{0x1ea80347,0x2b5404fb,0x00000000,0x00000000}},	//   _غازي_, ایند_, --, --, 
   {{0x3914669a,0xdca40588,0x0c20669b,0x36d40107}},	//   лмир, _иааи, лмән, ҳонр, 
   {{0xd7f8669c,0x20040356,0x00000000,0x00000000}},	//   дум_, şoiu_, --, --, 
   {{0x667008b0,0x8c4040c4,0x36d40107,0x00000000}},	//   ڭگىر, _техе, гонр, --, 
   {{0x3b000054,0x00000000,0x00000000,0x00000000}},	//   _ñiq_, --, --, --, 
   {{0xd90c669d,0xcb340677,0x7bd8669e,0x80b800eb}},	//   _ویب_, _סנדק_, lyvu, _আকন্, 
   {{0x79800e8a,0xd850004e,0x00000000,0x00000000}},	//   mumw, _текө, --, --, 
   {{0x7980669f,0x249c000d,0x00000000,0x00000000}},	//   lumw, õtma_, --, --, 
   {{0x75d40214,0x764c058a,0x480400d8,0x00000000}},	//   _ميبا, _ufay, _шејн_, --, 
   {{0x569002dd,0x79802b4c,0x55040117,0x7bd80064}},	// [73d0] _бақт, numw, _ачна, hyvu, 
   {{0x73c401e0,0x00000000,0x00000000,0x00000000}},	//   _йәбе, --, --, --, 
   {{0x798066a0,0xd01801fe,0x7bd8005b,0x046401ee}},	//   humw, ффа_, jyvu, _ттым, 
   {{0x798066a1,0xfe700517,0xb8e40135,0xb8d4031c}},	//   kumw, قده_, _ཌོ_, _ཝལ_, 
   {{0xd20801c6,0xcdc00150,0x00000000,0x00000000}},	//   _цэнд_, ралқ, --, --, 
   {{0x79800099,0x65600240,0xad2400d1,0x80c400cd}},	//   dumw, _çohe, دىتى, राणे, 
   {{0xeb9866a2,0x7c8450b1,0xefb01079,0x09d800dc}},	//   хий_, руче, _دیاگ, यन्य, 
   {{0x798001c8,0xeab015b0,0xbed40114,0x00000000}},	//   fumw, صعب_, _косј, --, 
   {{0x8d7466a3,0xa91c012c,0x7c9404fb,0x00000000}},	//   _جازا, huže, _چشما, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe6880e76,0xa91c0e3c,0xba7400ec,0x00000000}},	//   ىندى_, juže, _چاهت, --, 
   {{0xa91c0bb8,0x798066a4,0x66e408ca,0x98ac0064}},	//   duže, bumw, уома, _rifą_, 
   {{0x798000ca,0xf8a804d3,0x00000000,0x00000000}},	//   cumw, ردیه_, --, --, 
   {{0x154001e0,0xf8e400db,0x00000000,0x00000000}},	//   серм, _ۅسۉپ, --, --, 
   {{0xe2981d16,0x2ba80073,0xb7c800ae,0x00000000}},	//   нав_, किटा, _لبيك_, --, 
   {{0x2b440427,0x21a401d5,0x05240154,0x00000000}},	//   _mulc_, либм, পদের_, --, 
   {{0x2d8c0218,0x205402dd,0xb2440075,0xd24c66a5}},	// [73e0] _nqee_, гтер, рмуһ, سنل_, 
   {{0x26d066a6,0xa91c09a8,0x15580375,0xe044010b}},	//   _hoyo_, lužb, _רכיב, унжи, 
   {{0x26d066a7,0x798066a8,0x63046520,0xd12c00c6}},	//   _koyo_, zumw, _مودل, أمل_, 
   {{0x798066a9,0x9d44010b,0x26d00334,0xeea80220}},	//   yumw, гедд, _joyo_, ктік_, 
   {{0x26d066aa,0x80c42450,0x644c0051,0x00000000}},	//   _moyo_, रादे, ocbi, --, 
   {{0x504066ab,0x798066ac,0x26d066ad,0x7bd80006}},	//   _герб, vumw, _loyo_, tyvu, 
   {{0x798066ae,0xdfd04f4e,0x26d0058a,0x2b440356}},	//   wumw, _ايز_, _ooyo_, _culc_, 
   {{0x798066af,0x39741d56,0x34d00316,0x26d066b0}},	//   tumw, алиё, _सक्द, _noyo_, 
   {{0xa91c4ca5,0x7bd80153,0x384c0092,0x00000000}},	//   dužb, syvu, _ነበረብ, --, 
   {{0x798066b1,0x7bd800e4,0x00000000,0x00000000}},	//   rumw, pyvu, --, --, 
   {{0x26d066b2,0x798066b3,0xc86c00c7,0xd114011a}},	//   _boyo_, sumw, _қџ_, רקיה_, 
   {{0x26d00113,0x6b940139,0x00000000,0x00000000}},	//   _coyo_, _äzga, --, --, 
   {{0x26d000f2,0xd8940014,0x00000000,0x00000000}},	//   _doyo_, _مٔشد, --, --, 
   {{0xa91c2d2b,0x97a466b4,0x86c401ec,0xc950011a}},	//   tuže, _брил, _ۇيىن, _המס_, 
   {{0xba000020,0x00000000,0x00000000,0x00000000}},	//   _ውል_, --, --, --, 
   {{0x325466b5,0x26d066b6,0x00000000,0x00000000}},	//   рвар, _goyo_, --, --, 
   {{0xaac4629c,0x94846171,0x00000000,0x00000000}},	// [73f0] वातक, _йынд, --, --, 
   {{0xd34401d5,0x6aac02d2,0x6600032e,0x00000000}},	//   _میسه_, _óafv, _þoka, --, 
   {{0x26d066b7,0x00000000,0x00000000,0x00000000}},	//   _yoyo_, --, --, --, 
   {{0x6e9466b8,0x628801ed,0xa3d000e1,0x2d58003b}},	//   риду, őfor, वहर_, видь_, 
   {{0x7c2866b9,0xf1b800bc,0x00000000,0x00000000}},	//   _azdr, _उछिन, --, --, 
   {{0x2a680010,0x00000000,0x00000000,0x00000000}},	//   _žab_, --, --, --, 
   {{0xac0802e8,0xdb4c01d9,0xebc400c7,0xebe40108}},	//   ънка_, وَو_, шәан, ройп, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x26d066ba,0x5ac40220,0xd8e40327,0x00000000}},	//   _royo_, рлым_, རྣཐྲ, --, 
   {{0x6d5866bb,0x26d000f2,0x6e28009d,0x765c002f}},	//   mpwa, _soyo_, _izeb, ebsy, 
   {{0xa91c2d2b,0x6d5802fa,0x26d00ac5,0xaac4047f}},	//   tužb, lpwa, _poyo_, वादक, 
   {{0x66d800a7,0x6d5801f5,0xfaa812ea,0x00000000}},	//   тьор_, opwa, _مهمي_, --, 
   {{0x95801301,0x26d066bc,0x6d5802e2,0xa91c0427}},	//   оляе, _voyo_, npwa, ružb, 
   {{0x69c80218,0x26d066bd,0x6f081710,0x6d5803ac}},	//   mxee, _woyo_, _ljec, ipwa, 
   {{0xd46466be,0x6f0866bf,0x765c0fac,0xdce00327}},	//   рисе_, _ojec, bbsy, stoħ, 
   {{0x6f08036e,0x02e066c0,0x2bb40171,0x00000000}},	//   _njec, नसेन, _māc_, --, 
  
   {{0x3940007b,0x171808a8,0x216866c1,0x6d5802d0}},	// [7400] _éist_, _בוקע, тизи_, jpwa, 
   {{0x205466c2,0x290423ee,0x66f00882,0x1fb44143}},	//   ртар, nnla_, vāky, исер, 
   {{0x444466c3,0x7d0466c4,0x6d580af9,0x6e2866c5}},	//   _ig_, éism, epwa, _azeb, 
   {{0x6d5802d0,0x73c400ec,0xc2941bf4,0x00000000}},	//   fpwa, _ايٽم, _دیرب, --, 
   {{0x444466c6,0x6f08036f,0x69c80211,0xdca401fc}},	//   _kg_, _djec, jxee, иади, 
   {{0x6f08524a,0x6e280433,0x249805b1,0x3d20033f}},	//   _ejec, _dzeb, _jbpm_, यतें_, 
   {{0x444466c7,0x6e28054c,0x6d580ea0,0xec18151e}},	//   _mg_, _ezeb, apwa, лешә_, 
   {{0x444466c8,0x7c280fb7,0x62940100,0xd004074d}},	//   _lg_, _vzdr, nfyo, _тесе_, 
   {{0xcaf0484d,0x6d5802d0,0x00000000,0x00000000}},	//   تسوب, cpwa, --, --, 
   {{0x444466c9,0xa3e402c3,0x6f08012d,0x00000000}},	//   _ng_, भना_, _zjec, --, 
   {{0x21dc1d76,0x7d180122,0x69c80009,0xed3401c8}},	//   _hāhā_, movs, axee, _اولھ, 
   {{0x444466ca,0xd6d866cb,0x69c80218,0xc674001f}},	//   _ag_, тто_, bxee, ጣጠሪያ_, 
   {{0x444466cc,0xca9406a9,0xfec80eac,0x1dc41fbc}},	//   _bg_, _כדאי_, _শতাধ, लमित, 
   {{0x444466cd,0x7d18013d,0x399066ce,0x7f4066cf}},	//   _cg_, novs, màs_, _limq, 
   {{0x444466d0,0xc34866d1,0x399066d2,0xd3340116}},	//   _dg_, ияте_, làs_, لعرع, 
   {{0x444466d3,0x0838025f,0x8fc455cb,0x7f4066d4}},	//   _eg_, _בעול, یزان, _nimq, 
   {{0x4444105c,0x7758069c,0x07f00489,0xa91c66d5}},	// [7410] _fg_, _ወተሃደ, _བཟོཝ_, luža, 
   {{0x444466d6,0x6f081f7f,0x386c01fa,0x7d1802fb}},	//   _gg_, _sjec, nadr_, jovs, 
   {{0x7d1866d7,0x4ea441e4,0x3990067c,0xd244010b}},	//   dovs, ирда, hàs_, _вэги, 
   {{0x444466d8,0x69c8011f,0xdb0801bf,0x6d580857}},	//   _zg_, yxee, lvfæ, tpwa, 
   {{0x444466d9,0x6f0866da,0x7f400009,0x69c866db}},	//   _yg_, _vjec, _dimq, xxee, 
   {{0x4444019b,0xac980075,0x7d1866dc,0x69c80218}},	//   _xg_, انغا_, govs, vxee, 
   {{0x6d5866dd,0x6f0801e6,0x00000000,0x00000000}},	//   spwa, _tjec, --, --, 
   {{0x7f400369,0x69c801c0,0xa91c1050,0x399000db}},	//   _gimq, txee, duža, fàs_, 
   {{0x6e28008f,0x39904b84,0x8e2c022e,0x69c80009}},	//   _uzeb, gàs_, chgа_, uxee, 
   {{0x7f400b6f,0x7d1802fb,0x16f00327,0xaac40b98}},	//   _zimq, covs, _བཏུམ_, वाहक, 
   {{0x6d4066de,0x6bd866df,0xe73866e0,0x69c80ba7}},	//   _iila, _حواس_, лео_, sxee, 
   {{0x6d48004c,0xe5a466e1,0x399066e2,0x6f1866e3}},	//   _kuea, бими, bàs_, nowc, 
   {{0x444466e4,0x399066e5,0x249805b1,0xc62000eb}},	//   _pg_, càs_, _pbpm_, নেনা_, 
   {{0x6d4066e6,0xf99048c1,0x6d480099,0xd5440262}},	//   _jila, _زبه_, _muea, спре_, 
   {{0x6d4066e7,0x675440c7,0x6d480421,0x47c802f5}},	//   _mila, _اختر, _luea, ানহী, 
   {{0x444466e8,0x47f001c6,0x6f18012d,0x9f500332}},	//   _wg_, _гүүр, jowc, ícíl_, 
   {{0x444466e9,0x6d4007d6,0x6f1866ea,0x80c466eb}},	// [7420] _tg_, _oila, dowc, राले, 
   {{0x444466ec,0x6d4066ed,0x7f4066ee,0x00000000}},	//   _ug_, _nila, _simq, --, 
   {{0x7d180841,0x7f40047e,0x862400e5,0x00000000}},	//   vovs, _pimq, _دکھل, --, 
   {{0x6d4066ef,0x2bbc15e0,0x3d8801b9,0x7f400455}},	//   _aila, ्मना, لحتی_, _qimq, 
   {{0x6d4066f0,0x7d181155,0x7f400393,0xcf180014}},	//   _bila, tovs, _vimq, درٕچ_, 
   {{0x6d4066f1,0x225002c4,0x39904b84,0x21dc0055}},	//   _cila, lcyk_, vàs_, _vāhā_, 
   {{0x6d4066f2,0x7d182890,0xcec0012c,0x8e2c01d5}},	//   _dila, rovs, áří_, shgа_, 
   {{0x6d4066f3,0x399066f4,0x7d184dfc,0xb95466f5}},	//   _eila, tàs_, sovs, овищ, 
   {{0x6d4066f6,0x7d180b3d,0x6d4805d5,0x386c01ab}},	//   _fila, povs, _guea, tadr_, 
   {{0x6d4066f7,0x399066f8,0x98c466f9,0x7798661d}},	//   _gila, ràs_, ссил, акор_, 
   {{0x399000db,0xb90007af,0x00000000,0x00000000}},	//   sàs_, _धक_, --, --, 
   {{0x6d4066fa,0xa91c0b91,0x39904d74,0x167001d5}},	//   _zila, ruža, pàs_, чқир, 
   {{0x6d4066fb,0xaac41223,0xc6f81b04,0xf8b001d9}},	//   _yila, वारक, снях_, _ہکھ_, 
   {{0x6d4066fc,0x38c82c26,0x79800083,0x7d04067c}},	//   _xila, _خاصی_, mrmw, éish, 
   {{0x2bbc0714,0xf4900023,0xe81800ec,0x7954009f}},	//   ्मया, _ዝዝረብ_, _پروڙ_, _اَڪا, 
   {{0x2ce4012d,0x63b803b2,0x00000000,0x00000000}},	//   _कत्ल_, ætna, --, --, 
   {{0xa3cc1cd2,0xdb18036e,0xa91c01ef,0x00000000}},	// [7430] _शपथ_, _artë, bržd, --, 
   {{0x2bbc00cd,0xdb08007c,0x313401f4,0x00000000}},	//   ्ममा, lvfä, цезр, --, 
   {{0x6d4066fd,0x6d48025a,0xdfd00451,0x6f1866fe}},	//   _rila, _suea, ويٰ_, towc, 
   {{0x6d4866ff,0x52a4007b,0x00000000,0x00000000}},	//   _puea, _اصدق, --, --, 
   {{0x6d486700,0x6f18068f,0xa91c05ce,0x80b8015b}},	//   _quea, rowc, dužn, _আকর্, 
   {{0x6d406701,0xfbd06702,0xcd000118,0xeb780798}},	//   _qila, کته_, _oběť_, асиј_, 
   {{0xaac40f4c,0x6b540327,0x04dc0a1e,0x00000000}},	//   वालक, _oġge, רקול, --, 
   {{0x6d406703,0x61200109,0x6d486704,0x38600e04}},	//   _wila, vôli, _tuea, _đira_, 
   {{0x6d406705,0xed582d2b,0x442401fb,0x6c740640}},	//   _tila, _brže_, ́m_, _млађ, 
   {{0xe8f86706,0x6d406707,0x612003d1,0x00000000}},	//   рло_, _uila, tôli, --, 
   {{0xa6c86708,0xed58098d,0xdb18067c,0x7980002d}},	//   ална_, _drže_, _ortè, armw, 
   {{0xa91c6709,0x2b2801c4,0x00000000,0x00000000}},	//   drže, _тэзү_, --, --, 
   {{0xa8640184,0x64580998,0xe2a802f2,0xa9681608}},	//   _һеҙҙ, ñtio, یارن_, _тила_, 
   {{0xdb18670a,0xa3e84cd0,0x18a0004e,0x1e3800df}},	//   _artè, адга_, _жашм, יגרא, 
   {{0x7d0400c6,0xed580010,0x18b000c7,0x66580408}},	//   éisi, _ltž_, _цәыр, _кайă, 
   {{0x6ce40118,0x00000000,0x00000000,0x00000000}},	//   कसँग_, --, --, --, 
   {{0xa5642586,0x00000000,0x00000000,0x00000000}},	// [7440] _بدعن, --, --, --, 
   {{0x2a3c2295,0x67244673,0xe084007b,0xdfd01541}},	//   _የኢትዮ, llkj, تجري, ويذ_, 
   {{0x232810f5,0xe29809f8,0x00000000,0x00000000}},	//   _вони_, _кан_, --, --, 
   {{0xd00c00f1,0x00000000,0x00000000,0x00000000}},	//   خلم_, --, --, --, 
   {{0x3c58084c,0xfb3401c6,0x00000000,0x00000000}},	//   билэ_, үнлэ, --, --, 
   {{0x1ee801b9,0x00000000,0x00000000,0x00000000}},	//   دوچی_, --, --, --, 
   {{0xaac44802,0xa91c0b91,0xd00411ac,0x3dd8009e}},	//   वांक, tužn, _дере_, _দেশল, 
   {{0x3a740075,0xf1a802f2,0x0d800166,0x00000000}},	//   члир, _ئاێه_, члән, --, 
   {{0xed5801a6,0xa91c0306,0xc6200154,0x53781954}},	//   _prže_, držb, নেতা_, _ኤይድስ_, 
   {{0x16f00156,0x4c80036b,0xa91c0010,0x00000000}},	//   _བཏངམ_, _олув, sužn, --, 
   {{0x2bbc00dc,0xed3401c0,0xed5814b2,0x00000000}},	//   ्मणा, _хэтэ, _vrže_, --, 
   {{0xd944670b,0xa91c670c,0xdb180306,0x00000000}},	//   _деди, vrže, _orté, --, 
   {{0x6584013f,0xd62400c6,0x00000000,0x00000000}},	//   _kɔhy, تعدي, --, --, 
   {{0xa91c00bc,0x00000000,0x00000000,0x00000000}},	//   trže, --, --, --, 
   {{0xdb18670d,0x09dc0729,0x63bc0e04,0x9268670e}},	//   _arté, _বেপা, _crpn, ираа_, 
   {{0x2bbc1a2a,0x78a8670f,0x38c803e6,0x12840066}},	//   ्मता, ledv, _خاڵی_, تمری_, 
   {{0xd498014b,0x00000000,0x00000000,0x00000000}},	// [7450] _крн_, --, --, --, 
   {{0xf4340276,0xa91c16a3,0x00000000,0x00000000}},	//   _непэ, prže, --, --, 
   {{0x1cc8025c,0x63bc0175,0x00000000,0x00000000}},	//   ཊཡན_, _grpn, --, --, 
   {{0x1dc41889,0x657400e4,0x15fc107c,0x00000000}},	//   लमंत, _yvyh, _उधार_, --, 
   {{0x65840134,0xf8bc00dc,0x78a801d3,0xd1c80818}},	//   _bɔhy, ्ञाय, kedv, _тунд_, 
   {{0x27306710,0xac7402e9,0x7ee40022,0x6458022e}},	//   máne_, ساتش, зцәе, аtiy, 
   {{0x68ec03a2,0x2bbc00dc,0x27300419,0x00000000}},	//   _ïadi, ्मधा, láne_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe8f8633a,0x28b80276,0x00000000,0x00000000}},	//   йли_, бунэ_, --, --, 
   {{0x86500134,0xba080e76,0x2bbc21f6,0xa91c0306}},	//   _anɔp, تتىك_, ्मदा, ružo, 
   {{0x779001ed,0x7d04068c,0x7bdc00e4,0x1aa803d4}},	//   نیوا, èise, _ürup, _খচৰা, 
   {{0xe5a400d1,0x660001a8,0x27306711,0x29d40137}},	//   пими, _þokk, káne_, _ىياس, 
   {{0x63bc6712,0x273000d2,0x6aa8198f,0x69dc6713}},	//   _srpn, jáne_, meef, äsed, 
   {{0x6aa86714,0xa87800c8,0x78a82959,0x00000000}},	//   leef, _האַר, cedv, --, 
   {{0xe738055f,0x00000000,0x00000000,0x00000000}},	//   _лек_, --, --, --, 
   {{0x93406715,0x273000d2,0x6aa86716,0xd1e80092}},	//   енсе, fáne_, neef, መጡት_, 
   {{0x60080daf,0x273000d7,0x00000000,0x00000000}},	// [7460] әнем_, gáne_, --, --, 
   {{0x4dc004c5,0x6aa86717,0xa0686718,0x15f80375}},	//   ্নাং, heef, сажа_, _להפע, 
   {{0x09dc04c5,0x6aa8022f,0xd6cc0133,0x00000000}},	//   _বেমা, keef, _شقی_, --, 
   {{0x61446719,0x273000d2,0x6aa8198f,0x78a803ac}},	//   _нема, báne_, jeef, zedv, 
   {{0x273000d2,0x6aa8671a,0x69dc0450,0xaac40073}},	//   cáne_, deef, øsel, वाईक, 
   {{0xa11400f2,0x00000000,0x00000000,0x00000000}},	//   _روزت, --, --, --, 
   {{0x8fa0671b,0x78a8671c,0xb90c0241,0x6aa8671d}},	//   _паре, vedv, _eemọ_, feef, 
   {{0x6aa83446,0x65840134,0x80c432ed,0x78a80857}},	//   geef, _wɔhy, राके, wedv, 
   {{0x78a8671e,0x00000000,0x00000000,0x00000000}},	//   tedv, --, --, --, 
   {{0x615c0092,0x00000000,0x00000000,0x00000000}},	//   ሃብቶች, --, --, --, 
   {{0xb6f804a2,0x25b0671f,0x3f78005f,0x6aa8198f}},	//   قىدا_, _asyl_, nču_, beef, 
   {{0x6aa86720,0x78a8192e,0x273000d2,0x248c0023}},	//   ceef, sedv, yáne_, _ዝምለስ_, 
   {{0x6abc0109,0x00000000,0x00000000,0x00000000}},	//   ôsfe, --, --, --, 
   {{0x2ed81bd6,0x273000d2,0x69dc005b,0xf8e0000d}},	//   _भक्त, váne_, äsee, _पकिय, 
   {{0x225800b4,0x273000d2,0x00000000,0x00000000}},	//   _ọfụm, wáne_, --, --, 
   {{0xdb200139,0x27306721,0x00000000,0x00000000}},	//   _öräg, táne_, --, --, 
   {{0x56900046,0x3f8402b5,0x867c0375,0x3f780171}},	// [7470] _жақт, _āmua_, _הרחו, eču_, 
   {{0x3cf8068f,0x6aa801f5,0x2730473a,0x00000000}},	//   ्चों_, zeef, ráne_, --, 
   {{0x81446722,0x6aa86723,0xc914011a,0x273000e4}},	//   رنمن, yeef, לחמת_, sáne_, 
   {{0x2bbc0b8f,0x00000000,0x00000000,0x00000000}},	//   ्मसा, --, --, --, 
   {{0xed5804a7,0x6aa8002d,0x80c40118,0x00000000}},	//   _brža_, veef, राखे, --, 
   {{0x6aa86724,0x33280393,0x27140882,0xdca0074d}},	//   weef, llax_, māne_, ваши, 
   {{0xeb9817bc,0x6aa86725,0xed581a48,0xfb2405af}},	//   ций_, teef, _drža_, کروپ, 
   {{0xa91c2aa3,0xaa440150,0x00000000,0x00000000}},	//   drža, мейл, --, --, 
   {{0xe9a84bf3,0x6aa86726,0x27140069,0x2bbc0b7c}},	//   تگان_, reef, nāne_, ्महा, 
   {{0xfe0836e9,0x6aa8198f,0x1e306727,0xddc001e4}},	//   _عقلي_, seef, _شکنج, ncoŝ, 
   {{0x2eec01f5,0x00000000,0x00000000,0x00000000}},	//   _klef_, --, --, --, 
   {{0x98a000da,0x271418a6,0xe9d06728,0x6aa8208d}},	//   ēkā_, kāne_, _لغت_, qeef, 
   {{0xba740b43,0x2bbc00dc,0x00000000,0x00000000}},	//   _سانت, ्मवा, --, --, 
   {{0xc4ac015b,0x2eec6729,0x00000000,0x00000000}},	//   গঞ্জ, _llef_, --, --, 
   {{0x1540672a,0x2eec014b,0xa4fc0073,0x8a4002f2}},	//   терм, _olef_, _उगीच_, _تێکن, 
   {{0xe3180209,0x1d900092,0x3f7814b2,0xc1b40166}},	//   _özüň, _የግብጽ_, vču_, нәгы, 
   {{0xd5ac31ed,0xb0c803ba,0xe6180276,0x09dc0154}},	// [7480] _نفي_, रांग, _фдп_, _বেতা, 
   {{0x21380086,0x2eec0ba1,0xdb1808e5,0x33280009}},	//   umph_, _alef_, _artì, alax_, 
   {{0x2eec672b,0x68ec03a2,0x6264010b,0x998401a6}},	//   _blef_, _ïadu, _овна, _mzoš_, 
   {{0x2eec672c,0x4ea01677,0xcd600240,0x00000000}},	//   _clef_, врша, _ዝተኸፈ, --, 
   {{0x66000209,0xa91c672d,0xc6200154,0x27140171}},	//   _ýokd, ružj, নেরা_, cāne_, 
   {{0xdb083570,0x2eec031c,0x3f782630,0xe7dc002b}},	//   lvfø, _elef_, pču_, महाप, 
   {{0x1ea816cb,0x00000000,0x00000000,0x00000000}},	//   _واري_, --, --, --, 
   {{0x8fa0084c,0x9f540210,0x00000000,0x00000000}},	//   _шасе, łgów_, --, --, 
   {{0x7d0404d1,0x61f4672e,0x5884672f,0x538c0023}},	//   éiss, nzyl, мына, _ዝግደስ_, 
   {{0x67340076,0xa91c0030,0x0d800212,0xd83c02f0}},	//   _ahyj, trža, _шлун, _éčka_, 
   {{0x09dc045e,0xda7800a7,0x3328003a,0x00000000}},	//   _বেদা, _дял_, ylax_, --, 
   {{0x2bbc41ac,0xdb1800d0,0x00000000,0x00000000}},	//   ्मरा, _krtí, --, --, 
   {{0xc990007b,0xac040037,0x00000000,0x00000000}},	//   _للنظ, öövõ, --, --, 
   {{0x3328002e,0x00000000,0x00000000,0x00000000}},	//   wlax_, --, --, --, 
   {{0x33286730,0x00000000,0x00000000,0x00000000}},	//   tlax_, --, --, --, 
   {{0x271404fe,0xdb1800c7,0x00000000,0x00000000}},	//   tāne_, _ortí, --, --, 
   {{0x764c6731,0x78b86732,0x332801c6,0xa5c06733}},	// [7490] _igay, _kavv, rlax_, _йөре, 
   {{0x2eec6734,0x273000c6,0x78b86735,0x33280067}},	//   _slef_, mána_, _javv, slax_, 
   {{0xdb186736,0x78b804ba,0x614406ba,0x27306737}},	//   _artí, _mavv, رىمە, lána_, 
   {{0x78b86738,0x2d94030d,0x33280327,0x00000000}},	//   _lavv, еркс, qlax_, --, 
   {{0xfe7007d6,0x764c01c8,0xa91c3831,0x7cf4004e}},	//   شدن_, _mgay, držn, _màrf, 
   {{0x7c286739,0x3940067c,0x78b8047e,0x764c022e}},	//   _bydr, _èish_, _navv, _lgay, 
   {{0x764c673a,0x7c280368,0x009401c0,0x7d04068c}},	//   _ogay, _cydr, _ширэ, èisa, 
   {{0xe9d8673b,0x4ea45950,0x7c28036e,0x403401f4}},	//   зки_, _юрга, _dydr, _ресс, 
   {{0x78b804ba,0xcd340f47,0xa91c673c,0x2d9800e4}},	//   _bavv, _قرطب, luži, _ëse_, 
   {{0x764c673d,0x6e280248,0x2730673e,0x7c280142}},	//   _agay, _iyeb, dána_, _fydr, 
   {{0x78b806bb,0x7c2803cb,0x58f80327,0x6fb0000d}},	//   _davv, _gydr, ྒྲེས_, ीटिं, 
   {{0x7524090c,0x2730673f,0x6e282252,0x00000000}},	//   _akhz, fána_, _kyeb, --, 
   {{0x78b86740,0xa91c0030,0xe9a41180,0xa9a46741}},	//   _favv, huži, _чалп, _чилд, 
   {{0x6e280354,0x764c0083,0xa91c01a6,0xba08030d}},	//   _myeb, _egay, kuži, _юххе_, 
   {{0x53a007dd,0xc4480ec9,0x6e281418,0x23340354}},	//   ларб, بیدن_, _lyeb, ехар, 
   {{0xa91c0989,0x6e281aac,0x764c0083,0x273002f0}},	//   duži, _oyeb, _ggay, bána_, 
   {{0x6e286742,0x07a00e46,0xe1f8036b,0x78b86743}},	// [74a0] _nyeb, _чақн, чга_, _yavv, 
   {{0x6ab86744,0x61f46745,0x00000000,0x00000000}},	//   _lawf, rzyl, --, --, 
   {{0x6e286746,0xd12c0597,0xd00c0597,0x29040421}},	//   _ayeb, حمل_, ملك_, iila_, 
   {{0x29046747,0x6e286748,0x6ab86749,0x6d5c003d}},	//   hila_, _byeb, _nawf, _ħsar, 
   {{0x2904674a,0x09dc015b,0xed580427,0x3c94010b}},	//   kila_, _বেসা, _držo_, вилё, 
   {{0x2904674b,0xa91c674c,0x5f800075,0x5574008f}},	//   jila_, buži, _مۇئە, געסן_, 
   {{0x78b8674d,0x3dd800bd,0x6e285f23,0x27300118}},	//   _ravv, _দেখল, _eyeb, zána_, 
   {{0xd00c34f6,0x7c28674e,0x78b8674f,0x99646750}},	//   _الف_, _vydr, _savv, нтол, 
   {{0x5d8419b6,0x6e280a49,0x7d4400c7,0x7c280034}},	//   _سلال, _gyeb, _адаҧ, _wydr, 
   {{0x29046751,0x27300316,0x78b80477,0x7c286752}},	//   gila_, vána_, _qavv, _tydr, 
   {{0x6ab8067c,0x27300af2,0x78b8047e,0x00000000}},	//   _fawf, wána_, _vavv, --, 
   {{0x29040069,0x6ab80204,0x273002fb,0x97c40220}},	//   aila_, _gawf, tána_, _үйде, 
   {{0x29046753,0xceb000c8,0x78b806e8,0x95c80640}},	//   bila_, ניש_, _tavv, чуна_, 
   {{0x273040db,0xb7c401d5,0x38c816d0,0xfaa800ec}},	//   rána_, _ариқ, _زاتی_, _رهڻي_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x764c6754,0x2a600051,0x00000000,0x00000000}},	//   _ugay, _đhbk_, --, --, 
   {{0x7cf4004e,0xa91c0e3c,0x41e41cd0,0xc95000df}},	// [74b0] _gàrg, kržl, ліфа, ָמע_, 
   {{0xa91c0b91,0x27146755,0xa4a40086,0x73c400c7}},	//   tuži, māna_, riòù, _иӡба, 
   {{0xa91c15ad,0x6e28003e,0xbf580212,0x733821f3}},	//   držl, _syeb, ерії_, _озор_, 
   {{0xa91c0f03,0x6e2802bd,0x00000000,0x00000000}},	//   ruži, _pyeb, --, --, 
   {{0x6ab800b5,0x29046756,0x7e640113,0x00000000}},	//   _rawf, yila_, ñipa, --, 
   {{0x29046757,0x6e280ea0,0x6ab80076,0xaffc074d}},	//   xila_, _vyeb, _sawf, _догi, 
   {{0x403459fb,0x4ea46758,0x6700000d,0x00000000}},	//   _берс, _праа, _लगलक_, --, 
   {{0x63b804ce,0x29046759,0x00000000,0x00000000}},	//   ætni, wila_, --, --, 
   {{0x6e28675a,0x7cf40192,0x00000000,0x00000000}},	//   _uyeb, _bàrd, --, --, 
   {{0xdb24675b,0x6ab80042,0x00000000,0x00000000}},	//   _یولی, _wawf, --, --, 
   {{0x6ab80694,0x8ae400d6,0xe68801ec,0x8bc400fd}},	//   _tawf, _підл, وندى_, _ясад, 
   {{0xb8e82122,0x7cf401ab,0xf1d000cd,0xaab409ab}},	//   _लो_, _eàrd, समान, _अघिक, 
   {{0x2904675c,0x2d9c3917,0x7cf401c3,0x386000a2}},	//   pila_, ntwe_, _fàrd, _şire_, 
   {{0xd1e40201,0x7cf4068c,0x7c24675d,0x2d9c0433}},	//   ኙነት_, _gàrd, şire, itwe_, 
   {{0x2328675e,0xe298675f,0xc8b002dd,0x47dc00eb}},	//   дови_, мав_, _асқы, _ফেরী, 
   {{0x00e40133,0x27300022,0x27140171,0x00000000}},	//   گتری, máno_, bāna_, --, 
   {{0x27300306,0x6ed4043e,0x271400b8,0x00000000}},	// [74c0] láno_, णानु, cāna_, --, 
   {{0x00e430cd,0x00000000,0x00000000,0x00000000}},	//   دتری, --, --, --, 
   {{0x2d9c0083,0x7cf401e1,0xe2846760,0x27300118}},	//   etwe_, _jàre, _илни, náno_, 
   {{0x2bc406ff,0x9da802e8,0x00000000,0x00000000}},	//   विना, дъка_, --, --, 
   {{0xd1800a89,0xa91c00d0,0x27300f53,0xd654011a}},	//   _кляй, tržl, háno_, דינת_, 
   {{0xb9280241,0x0ca00092,0x273001ef,0x00000000}},	//   _wiwẹ_, _ለችግሩ_, káno_, --, 
   {{0x69dc6761,0xfcc402d3,0x09dc0f22,0x2d9c009f}},	//   äsen, _ጸቕጢ_, _বেলা, atwe_, 
   {{0x27300316,0x50180302,0x1ea8004b,0x00000000}},	//   dáno_, _חולו, _تاسي_, --, 
   {{0x49700ed0,0xebc0035b,0x00000000,0x00000000}},	//   алыс, _ҳәын, --, --, 
   {{0x98c4010b,0xd00c01d3,0x00000000,0x00000000}},	//   тсил, _الہ_, --, --, 
   {{0x7cf4004e,0xb7d0015b,0x61e003cd,0x00000000}},	//   _vàrd, ান্ট, øolj, --, 
   {{0xcf900375,0x4bf804ae,0x00000000,0x00000000}},	//   סטר_, _קלאס, --, --, 
   {{0x59b407b7,0xc6f80dce,0x4bc001c6,0xd1e80092}},	//   _अनिर, тнях_, _бөөг, ዘቡት_, 
   {{0x89d46762,0x271400e2,0x00000000,0x00000000}},	//   _جوهر_, rāna_, --, --, 
   {{0x2bc413f5,0x87d400e3,0x6ed4041c,0x69dc01bf}},	//   विया, _لبيس_, णामु, øsev, 
   {{0x59b40da0,0x47240014,0x7ca4001f,0x4734215c}},	//   _अनार, _پر٘ٲ, _መጽሀፍ_, _پرىز, 
   {{0x85b80eff,0x4174470b,0xdb0803b2,0x7ff40244}},	// [74d0] _алыс_, لالس, lvfó, یسما, 
   {{0x660009a5,0x05740075,0x2bc400cd,0x900801d5}},	//   _ýoka, _ئايد, विमा, وزاق_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2d9c0295,0x765c00a2,0x00000000,0x00000000}},	//   ttwe_, ncsy, --, --, 
   {{0x27300316,0x2bc407b7,0xada46763,0xbd540124}},	//   záno_, विभा, уалл, иҭтә, 
   {{0x4fc4235c,0x2d9c0210,0x00000000,0x00000000}},	//   _исба, rtwe_, --, --, 
   {{0xeab00597,0x8f4403a5,0x7cf46764,0x2d9c0223}},	//   معة_, _ахад, _bàrb, stwe_, 
   {{0x27300316,0x6e440014,0x270000bc,0xad8400d1}},	//   váno_, _منزم, _लगेर_, _مائۇ, 
   {{0xa92465c2,0x66e4020a,0x3ea000a3,0x5ea000db}},	//   лдил, ҳона, òite_, _چۅۅل, 
   {{0xdb180122,0x6d58009a,0x27306765,0x00000000}},	//   _vrtá, mqwa, táno_, --, 
   {{0x66e452e2,0x00000000,0x00000000,0x00000000}},	//   гона, --, --, --, 
   {{0x7cf40137,0x27300306,0xb3b800fe,0x00000000}},	//   _vàre, ráno_, ঁমাজ, --, 
   {{0x6d581cdf,0x2bbc6766,0xddc0054e,0x37d00154}},	//   nqwa, ्मका, mboţ, ানগর, 
   {{0xa91c0552,0x00000000,0x00000000,0x00000000}},	//   tužu, --, --, --, 
   {{0x2d58007f,0x7ca4069d,0x9f4801ef,0x00000000}},	//   _lèe_, _መጽሃፍ_, _šmíd_, --, 
   {{0xa91c6767,0x27140882,0x6d58009a,0x2328013e}},	//   ružu, māno_, kqwa, хоби_, 
   {{0x2a580020,0xa0a46768,0x4424012d,0xa114104c}},	// [74e0] _ለኢትዮ, лаад, łm_, هورت, 
   {{0x7cf408e5,0x67246769,0xa91c2a92,0xe3b800c7}},	//   _màrc, lokj, držk, _збо_, 
   {{0x3da80154,0xb0c8033f,0x10a00139,0x00000000}},	//   ওয়াল, राजग, сихн, --, 
   {{0xde740eff,0x6724676a,0x8f6400d1,0x00000000}},	//   اداع, nokj, چمەك_, --, 
   {{0x1d08676b,0x6d58676c,0x69dc08b9,0xae7000d1}},	//   неди_, gqwa, äsel, زۇلغ, 
   {{0x67240582,0x99640131,0x629400e5,0xdbac00cc}},	//   hokj, қтил, lgyo, _কপৌফ, 
   {{0x6724676d,0x00000000,0x00000000,0x00000000}},	//   kokj, --, --, --, 
   {{0x6294676e,0x646400ac,0x6724025c,0x5398010f}},	//   ngyo, əriş, jokj, גיקו, 
   {{0x7cf435f5,0x38c8114f,0x00000000,0x00000000}},	//   _càrc, نادی_, --, --, 
   {{0x9d44676f,0xb8e40131,0xe9dc0150,0xd7f80150}},	//   _сезд, рсиқ, _ەﻛﻪن_, еум_, 
   {{0x59b40f4c,0x48a46770,0xd6b40451,0x2bc40073}},	//   _अनवर, утым_, هندڙ_, विणा, 
   {{0x62940369,0x7bc80515,0x386001a6,0xdb080162}},	//   jgyo, _irdu, _điru_, rvfó, 
   {{0xc8c403e6,0x92000c4c,0x69dc143a,0xdb1803e0}},	//   _ڕوون_, _रेंज_, øset, _artç, 
   {{0xd838084c,0x00000000,0x00000000,0x00000000}},	//   _пэй_, --, --, --, 
   {{0xdce002f0,0xbef40073,0x3254033a,0xf79400db}},	//   jpoč, _आतून_, иввр, _тайэ, 
   {{0x2bc40b7c,0x7bc86771,0x629401d3,0xdce002f0}},	//   विता, _mrdu, ggyo, dpoč, 
   {{0xdb180724,0xc6946772,0xc0f80092,0xf19400d4}},	// [74f0] _irtä, _اشىع, _ፈሳሽ_, ризь, 
   {{0x7bc86773,0x629404ba,0x7e600129,0x2d5801e1}},	//   _ordu, agyo, _afmp, _rèe_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7e600165,0x2ef4041b,0x6d5802d0,0x00000000}},	//   _cfmp, јздр, tqwa, --, 
   {{0x7bc86774,0x1ee80344,0xcdc002dd,0x3178010f}},	//   _ardu, خونی_, салқ, _באָד, 
   {{0x7bc801ab,0x81bc0f22,0x69dc6775,0x31686776}},	//   _brdu, _অথচ_, äsem, mpaz_, 
   {{0x2bc4095f,0x2bd46777,0xe7cc0150,0x00000000}},	//   विधा, рюлё, _ﯗﻳﺎﻟ, --, 
   {{0xa91c00f3,0x7cf401ab,0x6d5802d0,0x00000000}},	//   mrži, _pàrc, pqwa, --, 
   {{0x7bc8324c,0x3e180104,0x6904022e,0xdaa00116}},	//   _erdu, _ботэ_, аtdа, تەنپ, 
   {{0xa854147e,0x2bc40bca,0xad4000f7,0xdb1801e3}},	//   штиј, विदा, _بۉتۉ, _artä, 
   {{0x7bc801ab,0x672401f5,0x316801a9,0x6bd8072d}},	//   _grdu, tokj, hpaz_, _جواس_, 
   {{0x65c401d5,0x00000000,0x00000000,0x00000000}},	//   абма, --, --, --, 
   {{0xdce00232,0xed5805ce,0x67246778,0x273000e5}},	//   zpoč, _brži_, rokj, lánk_, 
   {{0xddc001fa,0xdb1800a2,0xa7a86779,0xd1e80092}},	//   nboš, _ertä, _акка_, _ዘይቤ_, 
   {{0xe3540323,0x7cf4002e,0x6b800208,0x273000e5}},	//   ртгэ, _jàra, _jvlg, nánk_, 
   {{0xa91c39e2,0x6264677a,0xc5f801ec,0x660000a2}},	//   drži, рваа, _бғм_, _ýoko, 
   {{0x26d0677b,0x7cf40876,0x716400c6,0xf66800ae}},	// [7500] _inyo_, _làra, مالك, _صحيه_, 
   {{0x26d00218,0x555001b9,0xddc00010,0xa0685c83}},	//   _hnyo_, _گپیر, jboš, тажа_, 
   {{0x7cf401c3,0x69dc000d,0x00000000,0x00000000}},	//   _nàra, äsej, --, --, 
   {{0xdb1800d8,0x26c0677c,0x3af86293,0xdce0677d}},	//   _estê, ndko_, _képe_, rpoč, 
   {{0x1088005e,0xdce002fb,0x00000000,0x00000000}},	//   _ﻗﯘﺭﯨ, spoč, --, --, 
   {{0x6b80677e,0x26c00204,0x3d20000d,0x00000000}},	//   _bvlg, hdko_, मकें_, --, 
   {{0xdd90212c,0x26d0677f,0x7cf40e89,0x3af8012c}},	//   _ژور_, _onyo_, _càra, _lépe_, 
   {{0xbab86780,0x26d00c8a,0x2bbc09fa,0xd35400d9}},	//   угих_, _nnyo_, ्मजा, סיפי_, 
   {{0xf1c800cd,0xfaf80171,0x3af800e5,0x00000000}},	//   रियन, _utīm_, _népe_, --, 
   {{0x26d06781,0xd8e40a5b,0x60dc02d0,0xb4d45347}},	//   _anyo_, рцип, njpm, _सचे_, 
   {{0xd7f86782,0x7bc86783,0x3af800c7,0x7cf401c3}},	//   туп_, _urdu, _aépe_, _gàra, 
   {{0x3af8002e,0xed5807f5,0xdb0c0112,0x1988010a}},	//   _bépe_, _srži_, ßdäm, _абди_, 
   {{0xed580fcf,0x8af8010f,0x6600010b,0x00000000}},	//   _prži_, _בלאז, _ýokl, --, 
   {{0x2bbc1152,0x26d06784,0x3af800e4,0x62846785}},	//   ्मचा, _enyo_, _dépe_, _adko, 
   {{0xd68401a9,0x00000000,0x00000000,0x00000000}},	//   _купп, --, --, --, 
   {{0x325405f5,0x8c1802e4,0x2fcc01a6,0x00000000}},	//   свар, דולי, _čeg_, --, 
   {{0x6b540006,0xed580010,0xc950010f,0x273000e5}},	// [7510] _išge, _trži_, ַמף_, zánk_, 
   {{0xa91c1b5c,0x850400f1,0x506460a1,0x3d20012d}},	//   trži, _ووين, ртаа, मकों_, 
   {{0xd3440753,0x00000000,0x00000000,0x00000000}},	//   _نیسه_, --, --, --, 
   {{0x6e9400d1,0x26d0054e,0x31680129,0x69dc16ca}},	//   сиду, _xnyo_, ppaz_, äsek, 
   {{0xa2806786,0x7cf401c3,0x00000000,0x00000000}},	//   _ریلو, _sàra, --, --, 
   {{0x7d0800e4,0xa91c1674,0x6ed402ab,0x7cf40e89}},	//   _cmds, prži, णाहु, _pàra, 
   {{0xddc000e2,0x00000000,0x00000000,0x00000000}},	//   rboš, --, --, --, 
   {{0xfbd01de5,0x00000000,0x00000000,0x00000000}},	//   بته_, --, --, --, 
   {{0x6f086787,0x5ac411db,0x0b540184,0x6288013f}},	//   _imec, слым_, ырҙы_, ɔfod, 
   {{0x3328017a,0x7cf400a3,0xdce00327,0x38b00022}},	//   hoax_, _tàra, proġ, vôrâ_, 
   {{0x29246788,0xfbd00597,0xca700032,0x27306789}},	//   ﻠﯩﭗ_, _يتم_, _һуҙы, láni_, 
   {{0x3af80124,0x6f080356,0x9b8400f1,0xca24030d}},	//   _pépe_, _jmec, _اچول_, _кнеç_, 
   {{0xb6c4052f,0xdb24678a,0x6f0802e3,0xaa4402dd}},	//   цияһ, _اونی, _mmec, _انشى, 
   {{0xed580e9a,0xdb18180f,0x7cf401ab,0x64a40640}},	//   _muž_, _astè, _làrn, љава, 
   {{0x7d040ba1,0x6f08127b,0x2da400d1,0x4ad80037}},	//   èisi, _omec, ﺎﻧﻨﻰ_, _मचाव, 
   {{0x7ca40201,0x61e0678b,0x05080154,0xd83c0118}},	//   _መጽሐፍ_, äolo, লকের_, áčem_, 
   {{0xed5800d0,0xe0540338,0x21680395,0x95c400c0}},	// [7520] _nuž_, مخاب, уизи_, _глыб_, 
   {{0x20541084,0x6f08678c,0xdb1819c6,0xd83c09a8}},	//   стар, _amec, _estè, ščem_, 
   {{0xa3b80722,0x9cc8678d,0xe508678e,0x7d0800e5}},	//   _صادر_, ғыла_, _ليکو_, _rmds, 
   {{0x5d643306,0x628404ce,0x7cf4678f,0xde94007b}},	//   مُؤْ, _udko, _càrn, إجاب, 
   {{0x7cf40e89,0x56980a1e,0x27300419,0x7180024c}},	//   _dàrn, רינצ, gáni_, _оқте, 
   {{0x6f080521,0xed580552,0x96380a1e,0x65740042}},	//   _emec, _duž_, נגסט, _mwyh, 
   {{0x9bc40006,0xed3401c0,0x6d5c6790,0x2bc400dc}},	//   сёлк, цэцэ, _ésan, विषा, 
   {{0x27306791,0x5f040364,0x2918525e,0x7d0802d0}},	//   báni_, _узба, ésan_, _wmds, 
   {{0xed58110c,0x7f640150,0x00000000,0x00000000}},	//   _bržu_, _ﻗﻭل_, --, --, 
   {{0xa36801d5,0x2bc4043e,0x6f080210,0x00000000}},	//   _krеd, विशा, _zmec, --, 
   {{0xd1e80020,0x79800175,0xd8b800e5,0x00000000}},	//   _ዘይት_, ssmw, ندھا_, --, 
   {{0xd6d855c3,0xa91c1156,0xdb1807ea,0x2bc407d0}},	//   уто_, držu, _osté, विरा, 
   {{0x63bc0175,0x858808ca,0xd7f80139,0x61e001f4}},	//   _aspn, йёра_, _әул_, äoll, 
   {{0x7cf401e1,0x72c400cc,0x00000000,0x00000000}},	//   _màro, _একেআ, --, --, 
   {{0x7ca4069c,0xdb186792,0x7cf401e1,0x893400d9}},	//   _መጽሓፍ_, _asté, _làro, _הרגע_, 
   {{0xc8f802f5,0x6574015d,0x6e2c0135,0x00000000}},	//   ীকৃত_, _fwyh, żabi, --, 
   {{0x63bc6143,0xc0c40240,0xd1640395,0x00000000}},	// [7530] _espn, _ኹሎም_, съби, --, 
   {{0x6f086793,0xed58041a,0x78a800d2,0x273000bc}},	//   _smec, _ruž_, nfdv, váni_, 
   {{0x0ee81572,0x00000000,0x00000000,0x00000000}},	//   льди_, --, --, --, 
   {{0xed5808a4,0x2730295a,0x00000000,0x00000000}},	//   _puž_, táni_, --, --, 
   {{0xff502eac,0x7c24442e,0x00000000,0x00000000}},	//   رخم_, şirl, --, --, 
   {{0x27301a03,0x2bc406ff,0xaabc21f2,0x00000000}},	//   ráni_, विला, ्यभक, --, 
   {{0x7f941d56,0xe46801f4,0x8d746794,0x00000000}},	//   _нарх, _hlöä_, _گازا, --, 
   {{0x6f0801c8,0xfe5401ed,0xed5801ef,0x00000000}},	//   _umec, _ٹیوب_, _tuž_, --, 
   {{0x8d7400f1,0xfe54552d,0x0d74072d,0x00000000}},	//   _دازا, _عیوب_, _چیچک_, --, 
   {{0x27143a71,0xa3b8007d,0x00000000,0x00000000}},	//   māni_, _आईल_, --, --, 
   {{0x6d406795,0x27140882,0xa91c0306,0x00000000}},	//   _ihla, lāni_, držt, --, 
   {{0x29d405d4,0x6f180368,0x80d002ab,0x6600010e}},	//   _وياس, nnwc, _डोने, _ýokk, 
   {{0x6d400652,0x27140882,0x1b400014,0x6f180042}},	//   _khla, nāni_, _تھوُ, inwc, 
   {{0xfd6401f2,0x63bc020b,0xf99003e6,0x6aa86796}},	//   _afrị, _pspn, _سبه_, lfef, 
   {{0x6d40124c,0x69c86797,0xe73804b3,0x54340014}},	//   _mhla, lvee, _кек_, قرٲر, 
   {{0x27140882,0x6d400076,0x6264003b,0x00000000}},	//   kāni_, _lhla, івза, --, 
   {{0x69c86798,0xd1c40276,0xcd0000b8,0x00000000}},	// [7540] nvee, олте_, _keśī_, --, 
   {{0x6d400c11,0x61446799,0x7cf400a3,0xa368022e}},	//   _nhla, цеза, _càrl, _prеd, 
   {{0x14d404ac,0xa2e4679a,0xa3b803e6,0x6f18015d}},	//   _וויל_, _донд, _ئاخر_, fnwc, 
   {{0x7cf400a3,0x69c83c63,0x6f180142,0xd1e80023}},	//   _eàrl, kvee, gnwc, _ዘይቲ_, 
   {{0x6d40679b,0x3af8003e,0xdb180036,0x7c240790}},	//   _bhla, _népa_, _usté, ğirm, 
   {{0x273002fb,0x69c80072,0x00000000,0x00000000}},	//   mánu_, dvee, --, --, 
   {{0x6d400810,0x8fa00276,0x69c8679c,0x27300306}},	//   _dhla, _оаре, evee, lánu_, 
   {{0x6d401253,0x00000000,0x00000000,0x00000000}},	//   _ehla, --, --, --, 
   {{0x7f5c02d1,0x6d40679d,0x69c801f5,0xad6402c9}},	//   _hurq, _fhla, gvee, _فاله, 
   {{0x6d4050c8,0xa3b845bf,0x57a4052f,0x97a44d0b}},	//   _ghla, _आईं_, ошма, ормл, 
   {{0x7f5c02d1,0xa14400ef,0x9a840117,0x69c800ef}},	//   _jurq, _izķē, _дулл, avee, 
   {{0x7f5c679e,0x27300306,0x7d680023,0x00000000}},	//   _murq, kánu_, _ዝተነጸ, --, 
   {{0x6b540006,0x3f7802b1,0x6d4000ee,0x15a80395}},	//   _išga, hōu_, _yhla, шъни_, 
   {{0xdb24036b,0x3f7800b0,0x64580153,0x273002f0}},	//   _اوچی, kōu_, žtin, dánu_, 
   {{0xd7e4160b,0x69dc1073,0x6f1803cb,0x00000000}},	//   _філо, äsev, ynwc, --, 
   {{0x1164036b,0x00000000,0x00000000,0x00000000}},	//   قلری_, --, --, --, 
   {{0x273002fb,0x387c0165,0x7cf40192,0xd4e40395}},	// [7550] gánu_, _kevr_, _pàrl, _дюни, 
   {{0x7f5c679f,0x27140a30,0x6aa80369,0x96a42c35}},	//   _burq, vāni_, zfef, ट्रॉ, 
   {{0x74140cd2,0x387c0d27,0x69c80099,0x61f806be}},	//   _روحا, _mevr_, zvee, _ətli, 
   {{0x27140a28,0x6d4067a0,0x387c0dd4,0x7f5c0009}},	//   tāni_, _shla, _levr_, _durq, 
   {{0x6d4067a1,0xbdf800c6,0x6f180042,0x00000000}},	//   _phla, يرها_, rnwc, --, 
   {{0x7f5c67a2,0x7cf400cf,0x6b540432,0x271400e2}},	//   _furq, _fàrm, _ašga, rāni_, 
   {{0x41540261,0x40340150,0x00000000,0x00000000}},	//   _цврс, _жерс, --, --, 
   {{0x69941c35,0x00000000,0x00000000,0x00000000}},	//   прох, --, --, --, 
   {{0xc3340302,0x1ee8036b,0x6d4067a3,0xac9401c6}},	//   ווק_, _اوقی_, _thla, _нааш, 
   {{0x6d40136f,0xe8f862bd,0x3d942cfe,0x69c867a4}},	//   _uhla, сло_, _цифр, rvee, 
   {{0x69c867a5,0x6aa8002f,0x2b600210,0xca540354}},	//   svee, pfef, órcą_, _мĕнп, 
   {{0x3af8003e,0xd83c00d7,0x00000000,0x00000000}},	//   _tépa_, áčam_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x387c0165,0xd46467a6,0xd83c0219,0x18a00816}},	//   _gevr_, зире_, ščam_, _зашм, 
   {{0xfdb81f13,0x47ac0154,0x00000000,0x00000000}},	//   _इन्फ, টিহী, --, --, 
   {{0xaabc03f3,0x7f5c016d,0x27300306,0x2568010a}},	//   ्यिक, _rurq, tánu_, _лаип_, 
   {{0x7f5c568e,0x00000000,0x00000000,0x00000000}},	// [7560] _surq, --, --, --, 
   {{0x2a3c0020,0x7f5c03f0,0x3f7800b0,0x27300306}},	//   _ከኢትዮ, _purq, tōu_, ránu_, 
   {{0xaabc67a7,0x232867a8,0x7f5c67a9,0x54740302}},	//   ्याक, _гони_, _qurq, _מגיע_, 
   {{0x273067aa,0x7c2467ab,0x00000000,0x00000000}},	//   máns_, şirk, --, --, 
   {{0x273067ac,0x00000000,0x00000000,0x00000000}},	//   láns_, --, --, --, 
   {{0x7f5c67ad,0x7cf400a3,0x2174023b,0xd1b00214}},	//   _turq, _tàrm, _муҳр, _سیمک, 
   {{0x2d981061,0x387c0156,0x6bc40022,0xff2400e5}},	//   _åsen_, _revr_, дрыҧ, _قبری, 
   {{0x387c67ae,0xa3b807f7,0x00000000,0x00000000}},	//   _sevr_, _आईई_, --, --, 
   {{0xf8b803a5,0xd8c80276,0x7d04067c,0x7e640113}},	//   teĩ_, бынд_, èiss, ñipu, 
   {{0x7cf4004e,0x49700a89,0xa14400ef,0x00000000}},	//   _màrk, эльс, _uzķē, --, 
   {{0xda6416ac,0x48100139,0x00000000,0x00000000}},	//   _فاشي, емэс, --, --, 
   {{0x2730172e,0xbd8c044e,0x00000000,0x00000000}},	//   dáns_, _ናይቶም_, --, --, 
   {{0x69dc67af,0x273001d3,0x00000000,0x00000000}},	//   äset, vánt_, --, --, 
   {{0x48e034da,0x273008a5,0x271400ef,0x00000000}},	//   _почв, fáns_, dānu_, --, 
   {{0xd90c5c81,0x29140030,0x27301a74,0x83f800c0}},	//   _لیک_, ýbať_, gáns_, перс_, 
   {{0x7cf400e8,0x69dc00cc,0x31780210,0x00000000}},	//   _bàrk, åseg, _pwsz_, --, 
   {{0x86500134,0x273001ed,0x271400e2,0x3af80241}},	// [7570] _abɔf, ránt_, gānu_, _lépo_, 
   {{0x27300077,0xd13000f1,0x0fe000cf,0x00000000}},	//   báns_, رواښ, нөбү, --, 
   {{0x27300005,0xdb1803b2,0xa3b8033f,0x327401f4}},	//   cáns_, _astí, _आईए_, _огнё, 
   {{0xdb1803b2,0xff0402bf,0x518467b0,0x271400ef}},	//   _bstí, нячн, _нуга, bānu_, 
   {{0x62641b56,0x6b4406ea,0x271400ef,0x00000000}},	//   _تاپق, lógg, cānu_, --, 
   {{0x3af801e1,0xfe6c0352,0x7e7400db,0x00000000}},	//   _bépo_, _әү_, _ۋاقئ, --, 
   {{0x236401fa,0xeab0007b,0x00000000,0x00000000}},	//   _čojk_, نعة_, --, --, 
   {{0x7ea43b28,0x00000000,0x00000000,0x00000000}},	//   _pōpō, --, --, --, 
   {{0xad242302,0x3d94013d,0xe9d800d4,0x00000000}},	//   _قىرى, _питр, іко_, --, 
   {{0xecd4104c,0x61e001f4,0x00000000,0x00000000}},	//   _تحرک, äoli, --, --, 
   {{0x27300077,0x38b80022,0x7790135f,0x00000000}},	//   xáns_, _ẽrã_, هیوا, --, 
   {{0xdb180120,0x69dc0641,0x00000000,0x00000000}},	//   _estâ, äses, --, --, 
   {{0x2bc467b1,0x443c0006,0x00000000,0x00000000}},	//   विका, _šv_, --, --, 
   {{0x27304ac2,0x271400e2,0x00000000,0x00000000}},	//   táns_, vānu_, --, --, 
   {{0x53a067b2,0x260c03e5,0xa2d467b3,0x69dc00d7}},	//   карб, _ढेरी_, ويست, ťsed, 
   {{0x273067b4,0x7cf400db,0x00000000,0x00000000}},	//   ráns_, _pàrk, --, --, 
   {{0x2730056a,0x60e800c0,0xdb1803cb,0x386045d8}},	// [7580] sáns_, омам_, _ystâ, _şiri_, 
   {{0x7c240a9d,0x27300077,0x2714005f,0xa0c401f7}},	//   şiri, páns_, rānu_, بيئو, 
   {{0xa2a40316,0xdb1800ee,0xdee406ed,0xd12c00c6}},	//   _छाप्, _artý, можи, جمل_, 
   {{0x271400e2,0x9ed8007b,0xe284010a,0x00000000}},	//   māns_, غذاء_, _юлми, --, 
   {{0x271400de,0xd6e401c6,0x00000000,0x00000000}},	//   lāns_, _нvцг, --, --, 
   {{0xdb6867b5,0x6600010b,0x00000000,0x00000000}},	//   орил_, _ýoku, --, --, 
   {{0x10a0009d,0x320c032e,0x00000000,0x00000000}},	//   _ширн, _þeyr_, --, --, 
   {{0xdd903df7,0x7cf400cf,0x21380309,0x5040010b}},	//   _لور_, _màri, llph_, _ресб, 
   {{0xa2a4095f,0x224005b1,0x7cf4004e,0xdb180166}},	//   _छान्, _jzkk_, _làri, _irtü, 
   {{0x8650013f,0xd83c0030,0x00000000,0x00000000}},	//   _mbɔd, áčom_, --, --, 
   {{0x69dc67b6,0xba18004b,0x07e00212,0xb6f800d1}},	//   äser, تيکا_, вцям, كىدا_, 
   {{0x96440323,0x27140171,0x00000000,0x00000000}},	//   дэгд, dāns_, --, --, 
   {{0xdb180cfc,0x4280001f,0x497028f6,0x00000000}},	//   _estã, ይናንስ_, _аліс, --, 
   {{0xd37867b7,0xa91c0064,0x271400ef,0x00000000}},	//   жча_, kužy, fāns_, --, 
   {{0x8650013b,0x7cf400cf,0xf0e82d40,0x977c0354}},	//   _abɔd, _càri, ۋىرى_, _тулă_, 
   {{0x59d000cd,0xd5b8003b,0x00000000,0x00000000}},	//   तिपर, _дсо_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [7590] --, --, --, --, 
   {{0x25d40375,0x3ea401a6,0x6b440789,0xa5c0013d}},	//   _נותן_, _acmt_, móge, _сөюе, 
   {{0x6b4467b8,0x27140171,0x00000000,0x00000000}},	//   lóge, cāns_, --, --, 
   {{0xfe70006c,0x00000000,0x00000000,0x00000000}},	//   لده_, --, --, --, 
   {{0x6b441ada,0x85040133,0xed3400ee,0x00000000}},	//   nóge, _سوێن, нэкэ, --, 
   {{0xdb1867b9,0x908401ed,0x31340075,0xdca067ba}},	//   _ortó, _زمرے_, _чегр, гаши, 
   {{0xeb9867bb,0x7c842bbd,0xaabc00dc,0x6b540107}},	//   чий_, туче, ्यलक, нтих, 
   {{0x84580302,0x2ca800bc,0x394c0549,0x66d400a2}},	//   ובוס_, řad_, emds_, _mükä, 
   {{0xb5280241,0xc5f40154,0xe9d0007b,0xfda400f3}},	//   _atọ̀, _চেনা_, اغب_, _ајхм, 
   {{0xdb180228,0x2eec2595,0x1cbc025c,0x6b4424c8}},	//   _està, _hoef_, _ཇིར_, dóge, 
   {{0xe73867bc,0x2d9c67bd,0x2eec67be,0x69dc0158}},	//   зен_, luwe_, _koef_, åseb, 
   {{0x3af801ed,0x66e467bf,0xe6c8033f,0xa98400db}},	//   _lépj_, хома, ियेज, _كۅبۅ_, 
   {{0x2d9c0230,0xd9d0215c,0x00000000,0x00000000}},	//   nuwe_, _مەيگ, --, --, 
   {{0x2eec017a,0x2b4c00d7,0xdb1800e5,0x00000000}},	//   _loef_, lmec_, _istá, --, 
   {{0x2d9c67c0,0x66d4013d,0x3cac00cc,0x51c801ec}},	//   huwe_, _cükä, _টোঁৱ, _ﻗﻴﻨﺸ, 
   {{0x2d9c01bd,0x7c3c00ed,0x7cf467c1,0x2714005f}},	//   kuwe_, _ørre, _vàri, rāns_, 
   {{0x6b440789,0xe61867c2,0xe194009d,0x00000000}},	// [75a0] cóge, _хдп_, эрвэ, --, 
   {{0x46ac00bc,0x6abc11bc,0x00e4030f,0x00000000}},	//   ट्रह, ्युर, ختری, --, 
   {{0x2d9c67c3,0x2eec5d43,0x2564015d,0x2b4c0219}},	//   euwe_, _boef_, _hôl_, kmec_, 
   {{0xc3300075,0x2d9c00fb,0xdb1830d8,0x2eec0129}},	//   _ئەر_, fuwe_, _ostá, _coef_, 
   {{0x2d9c015c,0x2eec0af9,0x444462e4,0x00000000}},	//   guwe_, _doef_, _hz_, --, 
   {{0xa2a4012c,0x66d40139,0x61e01b99,0x00000000}},	//   _छाड्, _yükä, äolu, --, 
   {{0x50400372,0x4444019b,0x2d9c002d,0x6fc400c7}},	//   _берб, _jz_, auwe_, _иарҕ, 
   {{0xe6c82068,0x444467c4,0x2d9c67c5,0x2eb41234}},	//   ियोज, _mz_, buwe_, _исус, 
   {{0x444467c6,0x25640368,0x645805be,0x69cc033f}},	//   _lz_, _nôl_, žtih, तिषी, 
   {{0x395867c7,0x69f0104b,0x2eec01f5,0x444467c8}},	//   örs_, рүшт, _zoef_, _oz_, 
   {{0xdb1867c9,0x4444123b,0x45d401b9,0x00000000}},	//   _está, _nz_, ҳояс, --, 
   {{0x25640109,0x6b4467ca,0x645c03ac,0x69cc1a4e}},	//   _bôl_, tóge, _agpi, तिशी, 
   {{0x444467cb,0x394c009a,0x86240166,0x00000000}},	//   _az_, pmds_, гьре, --, 
   {{0x2bc41cb7,0x1cbc025c,0x6b440789,0x7c28022e}},	//   विचा, _ཇིས_, róge, _kxdr, 
   {{0x444467cc,0x2d9c67cd,0xc8c40451,0xa7c40032}},	//   _cz_, zuwe_, _سوين_, _арыҫ, 
   {{0x444467ce,0x08380302,0x645c067c,0x88e00124}},	//   _dz_, _מעול, _egpi, _ажәе, 
   {{0x444434ae,0x325467cf,0x2eec002d,0x94843a4e}},	// [75b0] _ez_, твар, _roef_, _пынд, 
   {{0x2d9c0223,0x7cf40241,0x00000000,0x00000000}},	//   vuwe_, _kàru, --, --, 
   {{0x2eec0373,0x2d9c009a,0x8af40213,0x44440b84}},	//   _poef_, wuwe_, _şəmk, _gz_, 
   {{0x3ee406bb,0x2d9c67d0,0x695000b8,0x00000000}},	//   лючв, tuwe_, _māmṛ, --, 
   {{0xa2a4228d,0xfe7000ec,0x00000000,0x00000000}},	//   _छात्, صدن_, --, --, 
   {{0x2d9c1283,0x4444010b,0xfe7067d1,0x2eec0373}},	//   ruwe_, _yz_, لدۇ_, _woef_, 
   {{0xed0401ed,0x2d9c67d2,0x6950002b,0x3208035a}},	//   _یورپ, suwe_, _nāmṛ, lzay_, 
   {{0x2d9c01ee,0x31341086,0xdb040ca8,0x00000000}},	//   puwe_, _чеҳр, _òmìn, --, 
   {{0x2b4c054e,0x598067d3,0x32084c71,0x5f4002f2}},	//   rmec_, алыб, nzay_, _ئۆنل, 
   {{0x25640368,0x32080109,0x2d8c0076,0xdb1802fb}},	//   _rôl_, izay_, _ivee_, _vstá, 
   {{0x7cf4004e,0x6950002b,0xe7285acb,0x320802d0}},	//   _pàrv, _cāmṛ, донд_, hzay_, 
   {{0x66d80801,0x7b7400c6,0x25640042,0x320803ac}},	//   фьор_, _إطلا, _pôl_, kzay_, 
   {{0x444467d4,0xdb1802fb,0x6e280327,0xa8c401c6}},	//   _sz_, _ustá, _jxeb, _айлд, 
   {{0x6e280327,0x320803ac,0x00000000,0x00000000}},	//   _mxeb, dzay_, --, --, 
   {{0x44440cf9,0x290467d5,0x23343528,0x25f00490}},	//   _qz_, mhla_, вхар, ुनही_, 
   {{0x444467d6,0x61f4023a,0x2904009a,0x67340064}},	//   _vz_, tyyl, lhla_, _ukyj, 
   {{0x7cf4004e,0x216867d7,0x95c4004e,0x320802d0}},	// [75c0] _kàrt, физи_, _алыб_, gzay_, 
   {{0x444467d8,0x290467d9,0xdb0801c7,0x61f4005b}},	//   _tz_, nhla_, ttfë, ryyl, 
   {{0x444467da,0x7cf467db,0x4aa40a59,0x6fd40006}},	//   _uz_, _màrt, _गाढव, ліцц, 
   {{0x29040327,0xdd90009f,0x6abc194b,0x00000000}},	//   hhla_, لوص_, ्योर, --, 
   {{0x290467dc,0x1d080209,0x6abc00dc,0x3208035a}},	//   khla_, меди_, ्यैर, czay_, 
   {{0xe0440323,0xddc00327,0x00000000,0x00000000}},	//   _анги, mboż, --, --, 
   {{0x8ff80014,0x290467dd,0x6438010f,0x7bdc00d7}},	//   _قرٲر_, dhla_, וײַג, _šrub, 
   {{0x290401af,0x3af800e5,0x00000000,0x00000000}},	//   ehla_, _képi_, --, --, 
   {{0x6e280472,0x7cf401ab,0xdb0401e1,0x00000000}},	//   _gxeb, _sàru, _òmín, --, 
   {{0x9c8801b9,0x290467de,0x4a500137,0xfe4401af}},	//   _آپاق_, ghla_, шкыс, _анғо, 
   {{0x90980375,0xdb8400c7,0x7d180010,0xd0f4011a}},	//   וסיק, _ргеи, mivs, דמית_, 
   {{0x7d1867df,0xd6d800d1,0x7e6000b5,0x7c240b97}},	//   livs, фто_, _jgmp, şirs, 
   {{0x7e60003e,0xceb0008f,0x29041cf8,0x3af801d3}},	//   _mgmp, סיש_, bhla_, _népi_, 
   {{0x290467e0,0x38c8208f,0x7cf401ab,0x6b4401e7}},	//   chla_, _ساتی_, _gàrt, móga, 
   {{0x6b4467e1,0x36d467e2,0x00000000,0x00000000}},	//   lóga, _бойр, --, --, 
   {{0x7d181a48,0x8fc40133,0x320803ac,0x260c000d}},	//   hivs, ێزان, tzay_, _ढेकी_, 
   {{0xdb1842a4,0x7d180623,0x8af406be,0x00000000}},	// [75d0] _istä, kivs, _şəkk, --, 
   {{0x2d980158,0x7cf40c8e,0xc0700055,0x7bc80432}},	//   _åsei_, _xàrt, _kīṭo_, _osdu, 
   {{0x7534003d,0x2d8c00d8,0x6e98030d,0x6b4400e4}},	//   mozz, _svee_, евер_, hóga, 
   {{0xc7880020,0x395c5629,0x753467e3,0x9c80107d}},	//   _መደበኛ_, _livs_, lozz, ščla, 
   {{0x41e40953,0x75340109,0xf1c8033f,0xfe7067e4}},	//   _кіра, oozz, रिओन, آدم_, 
   {{0x753467e5,0x6b540006,0x7e600857,0xe804012c}},	//   nozz, _išgi, _egmp, शनमा_, 
   {{0xbfa846e8,0xdb18007c,0x00000000,0x00000000}},	//   _итте_, _ostä, --, --, 
   {{0x7cf40de2,0xaa4467e6,0x6b4401e7,0x753401d3}},	//   _sàrt, лейл, fóga, hozz, 
   {{0x29040564,0x2d8c014b,0x7cf467e7,0x75345fa1}},	//   thla_, _uvee_, _càrs, kozz, 
   {{0x7cf4004e,0x6f180368,0x3f683535,0x00000000}},	//   _dàrs, liwc, _oğul_, --, 
   {{0x395c0334,0x290467e8,0xaa94009d,0x00000000}},	//   _divs_, rhla_, _биеч, --, 
   {{0x6f180368,0x7cf401ab,0x7aa402bf,0x6b440332}},	//   niwc, _fàrs, _виїз, bóga, 
   {{0x290403a2,0x7cf4004e,0xc9840124,0x29181a96}},	//   phla_, _tàrt, _руеи, ésas_, 
   {{0xdb1802f6,0xddc067e9,0x6f180042,0x7bdc00e5}},	//   _estä, ncoš, hiwc, _áruc, 
   {{0xd54400f3,0x00000000,0x00000000,0x00000000}},	//   упре_, --, --, --, 
   {{0x316800ac,0x2a6c67ea,0x6b800142,0xfa2403d4}},	//   fqaz_, nceb_, _mwlg, _পৰিল_, 
   {{0x26c067eb,0x91e018ec,0x753467ec,0xe1643738}},	// [75e0] meko_, боте, bozz, ادري, 
   {{0x26c067ed,0x75340395,0x00000000,0x00000000}},	//   leko_, cozz, --, --, 
   {{0xdb18049b,0x6f180368,0x348401c0,0x224400d7}},	//   _ystä, fiwc, _өгөг, ťok_, 
   {{0x26c067ee,0xa2e40eff,0xe29801c0,0x5398011a}},	//   neko_, _сомд, _яам_, _איטו, 
   {{0x628400de,0xd36c35aa,0x00000000,0x00000000}},	//   _ieko, _وهی_, --, --, 
   {{0x26c067ef,0x628407dd,0x6b80015d,0x5ba467f0}},	//   heko_, _heko, _bwlg, гриз, 
   {{0x628467f1,0x7d180579,0x58840184,0x395c01e3}},	//   _keko, rivs, һына, _rivs_, 
   {{0x7cf40228,0x26c067f2,0x628467f3,0x6f1800a9}},	//   _càrr, jeko_, _jeko, ciwc, 
   {{0x26c067f4,0x60cc0211,0x588467f5,0xdb182ad7}},	//   deko_, _kabm, лына, _rstä, 
   {{0x628467f6,0x25a00a73,0x26c00083,0x5bc400c6}},	//   _leko, dukl_, eeko_, _متصف, 
   {{0x628467f7,0x75340003,0x59d00316,0x7bc8014b}},	//   _oeko, vozz, तिहर, _usdu, 
   {{0x26c0633d,0x7cf401c3,0x95c867f8,0x4ae001d5}},	//   geko_, _gàrr, нуга_, _гўша, 
   {{0xadf800e1,0x00000000,0x00000000,0x00000000}},	//   ्नयन_, --, --, --, 
   {{0x628406c8,0x60cc047e,0xdb180036,0x89d000e4}},	//   _aeko, _nabm, _optë, _ñapẽ, 
   {{0x753467f9,0x628467fa,0x26c067fb,0xc134063f}},	//   rozz, _beko, beko_, ọọt_, 
   {{0x628467fc,0xb27467fd,0x7cf40137,0x26c067fe}},	//   _ceko, рлаш, _màrq, ceko_, 
   {{0xb114074d,0x417400d1,0x753467ff,0x00000000}},	// [75f0] амаш, مالس, pozz, --, 
   {{0x628401e2,0x10042c0b,0x00000000,0x00000000}},	//   _eeko, ляем, --, --, 
   {{0x62846800,0x60cc014f,0x9974033f,0x6f180042}},	//   _feko, _dabm, nęły_, tiwc, 
   {{0x6284606b,0x2dd40108,0x00000000,0x00000000}},	//   _geko, ижер, --, --, 
   {{0x6f1800a9,0x60cc0393,0x78b80083,0x80d00073}},	//   riwc, _fabm, _obvv, _डोके, 
   {{0x26c0152d,0x62846801,0x6f180368,0x6b700171}},	//   zeko_, _zeko, siwc, _lāge, 
   {{0x26c06802,0x62846803,0x1d0400a7,0x9874001f}},	//   yeko_, _yeko, рещи_, _የአሁኑ_, 
   {{0x26c06804,0xb7fc0729,0x6b70002b,0x7f5801c4}},	//   xeko_, ুপাত_, _nāge, _басс_, 
   {{0x86500134,0x26c006e4,0x60cc047e,0x3ea0007b}},	//   _abɔn, veko_, _yabm, óite_, 
   {{0x26c06805,0xbc680597,0x6b440615,0x25a00a73}},	//   weko_, _ممكن_, cógn, vukl_, 
   {{0x26c06806,0x7cf40137,0xe0d0010f,0x00000000}},	//   teko_, _tàrr, קײט_, --, 
   {{0x6b440c63,0x2d9c0099,0x6b7000b8,0x00000000}},	//   mógo, orwe_, _vāgd, --, 
   {{0x26c06807,0x6b4401f1,0x287400f7,0x00000000}},	//   reko_, lógo, _кыйр, --, 
   {{0x26c01992,0x62846808,0x1cb0081f,0x69d86809}},	//   seko_, _seko, ྐུར_, _irwe, 
   {{0x6284680a,0x26c0680b,0x638400db,0x6264009b}},	//   _peko, peko_, ргба, ивва, 
   {{0xaabc10fa,0x60cc680c,0x69d8680d,0x4424054e}},	//   ्यटक, _sabm, _krwe, ăm_, 
   {{0x6284680e,0x69d80076,0x60cc014f,0x9c8013d5}},	// [7600] _veko, _jrwe, _pabm, áčka, 
   {{0x657400f1,0x62841cf4,0x60cc014f,0x5fd4680f}},	//   _ityh, _weko, _qabm, ицеф, 
   {{0x62846810,0x9e643971,0xe29800c7,0x2d9c04e6}},	//   _teko, авед, _иан_, erwe_, 
   {{0x1cbc025c,0x672408fb,0x21a46811,0x60cc047e}},	//   _ཇིང_, nnkj, _кимм, _wabm, 
   {{0x60cc032a,0x63bc05b1,0x67244098,0x1224084c}},	//   _tabm, _hppn, inkj, _вояй_, 
   {{0x7050168d,0x7cf40137,0xa11403e6,0xa0682377}},	//   _کۆما, _pàrq, _ئوست, _јава_, 
   {{0x69d800a9,0x201c00fd,0x9be40212,0x6b4400d0}},	//   _arwe, _äti_, рілк, gógo, 
   {{0x65740472,0x2918020c,0x1ea800db,0xd00c01d9}},	//   _otyh, èsan_, _جاسي_, _کلہ_, 
   {{0xdca46812,0x38c8034c,0xf8b81d37,0x0c2005a2}},	//   _вази, هادی_, гөй_, ймән, 
   {{0xd90c6813,0xa3e402f8,0x63bc1700,0x27300765}},	//   بیت_, पमा_, _oppn, mány_, 
   {{0x69d809a4,0x30d800c8,0x65746814,0x27306815}},	//   _erwe, אַרע, _atyh, lány_, 
   {{0x193800b5,0x672403cd,0x0a6416a4,0x96f40022}},	//   _ｒｚｒ_, gnkj, _крши_, рҵит_, 
   {{0xceb00302,0x63bc030d,0x96446816,0x69d80165}},	//   חיר_, _appn, рэнд, _grwe, 
   {{0xd90c04fb,0xb0d40490,0x00000000,0x00000000}},	//   _آید_, _डोंग, --, --, 
   {{0x273000dd,0xd7f815ed,0x657401e2,0x439401b9}},	//   hány_, _јул_, _etyh, жасс, 
   {{0xdb1867c1,0x63bc05b1,0xa2d801ad,0x842400d1}},	//   _astú, _dppn, _पोद्, زىقن, 
   {{0x51846817,0x00000000,0x00000000,0x00000000}},	// [7610] руба, --, --, --, 
   {{0x1cb0025c,0x27306818,0x00000000,0x00000000}},	//   ྐུས_, dány_, --, --, 
   {{0xd6302832,0x37b40154,0xb6100150,0xde500023}},	//   _دِکھ, টিকর, _ﺴﻠ_, _ዝሓየለ, 
   {{0xdb186819,0x00000000,0x00000000,0x00000000}},	//   _estú, --, --, --, 
   {{0xd0840b32,0x273028c8,0x2d9c0810,0xd13800d8}},	//   _выби, gány_, urwe_, _ахв_, 
   {{0x2d9c00ca,0x43d40244,0x00000000,0x00000000}},	//   rrwe_, _ازیز, --, --, 
   {{0x7f94681a,0x4ea406ed,0xdca00d1d,0x00000000}},	//   _марх, _врза, чащи, --, 
   {{0x273002f0,0x69d8045a,0x00000000,0x00000000}},	//   bány_, _prwe, --, --, 
   {{0x7bdc05f7,0x28f801c0,0xd99400f1,0x00000000}},	//   _árun, гэнэ_, منيت_, --, 
   {{0x6b7000cd,0x00000000,0x00000000,0x00000000}},	//   _vāgb, --, --, --, 
   {{0x6b4400d7,0x00000000,0x00000000,0x00000000}},	//   lógm, --, --, --, 
   {{0x99940075,0x7980063f,0x00000000,0x00000000}},	//   شھۇر_, _ịwec, --, --, 
   {{0x69d80516,0x63bc003e,0xe298681b,0x67240158}},	//   _urwe, _sppn, ғаз_, rnkj, 
   {{0x6aa80217,0x4aa4032c,0x999401d9,0xe4d82651}},	//   lgef, _गाँव, _اپور_, دوست_, 
   {{0xe298681c,0x69c8681d,0x84540131,0x27300118}},	//   лав_, lwee, زىرچ, zány_, 
   {{0xadf8681e,0x69c8681f,0x62640fdc,0x141400ae}},	//   ्नान_, owee, сваа, حيفة_, 
   {{0x69c86820,0x9c8002d5,0xe1681c36,0x64a46821}},	// [7620] nwee, ščia, اصره_, _лапа, 
   {{0x26d06822,0x27306823,0x6aa82155,0xd00c6824}},	//   _hayo_, vány_, hgef, کلم_, 
   {{0x26d0037a,0x69c86825,0x63bc6826,0x33d402bf}},	//   _kayo_, hwee, _uppn, _діят, 
   {{0x69c86827,0x27303b36,0x26d06828,0xe808033f}},	//   kwee, tány_, _jayo_, हैया_, 
   {{0x26d06829,0x64480e3c,0x92b402dd,0x6b44682a}},	//   _mayo_, šlić, _احپا, rógl, 
   {{0x69c8682b,0x6d5c011c,0x06e405f9,0x27301bbf}},	//   dwee, _èsal, गाँव_, rány_, 
   {{0x8fa00b16,0x6aa8682c,0x69c8017a,0x4fa0682d}},	//   _наре, fgef, ewee, _нирв, 
   {{0x6aa8682e,0xb998682f,0x2138009a,0x69c8017a}},	//   ggef, авих_, loph_, fwee, 
   {{0xdce0098d,0x00000000,0x00000000,0x00000000}},	//   spođ, --, --, --, 
   {{0xa2d806ab,0xd8e46830,0x2d480005,0xb6480cad}},	//   _पोस्, сцип, lúen_, _gbẹ̀, 
   {{0x06e40d0a,0xb6f80075,0x7d080627,0x69c86831}},	//   गांव_, لىدا_, _ilds, awee, 
   {{0x89d46832,0x2d4809c2,0x69c81418,0x1b4801b9}},	//   _گوهر_, núen_, bwee, _ёзди_, 
   {{0xf8b86833,0x26d06834,0x69c80067,0xfee40150}},	//   _көн_, _dayo_, cwee, _ﺍﻗﯟﺍ, 
   {{0x6b7000ef,0x00000000,0x00000000,0x00000000}},	//   _hāga, --, --, --, 
   {{0x26d06835,0x6b540153,0x2a780241,0xa2d801f9}},	//   _fayo_, _išgr, _àgbá_, _पोह्, 
   {{0x26d06836,0x6b700aed,0x00000000,0x00000000}},	//   _gayo_, _jāga, --, --, 
   {{0x7d08127b,0xa3cc00bc,0x569002dd,0x6b7000cd}},	// [7630] _olds, _míří_, _дақт, _māga, 
   {{0x26d06837,0x61440075,0x224003d4,0x5064016c}},	//   _zayo_, قىقە, _dykk_, стаа, 
   {{0x6aa80158,0x69c801a4,0x0574030f,0x00000000}},	//   ygef, zwee, _واید, --, 
   {{0x7d086838,0x6b700882,0x69c86839,0xbea400d4}},	//   _alds, _nāga, ywee, заїк, 
   {{0x2138009a,0x69c85148,0x869c00df,0x00000000}},	//   boph_, xwee, רידז, --, 
   {{0x21b800c8,0x764c009f,0xed58683a,0x2fe400f1}},	//   _דזשא, _mzay, шол_, _وګاټ, 
   {{0x2d48056a,0x6aa8683b,0x69c8683c,0x7bdc01ed}},	//   búen_, tgef, wwee, _árul, 
   {{0x69c8025f,0x7d08449c,0x764c683d,0x6b7000cd}},	//   twee, _elds, _ozay, _cāga, 
   {{0x6aa8683e,0x26d0683f,0x764c0526,0xac9415bf}},	//   rgef, _rayo_, _nzay, _мааш, 
   {{0x26d06840,0x69c86841,0x6aa8097d,0xac180137}},	//   _sayo_, rwee, sgef, _козу_, 
   {{0x69c86842,0x26d06843,0x764c6844,0x6f0817ee}},	//   swee, _payo_, _azay, _klec, 
   {{0x6b706845,0x2ca80198,0x69c801a4,0x00000000}},	//   _gāga, ɗada_, pwee, --, 
   {{0x958011db,0x26d06846,0xa2d86847,0x6f086848}},	//   мляе, _vayo_, _पोष्, _mlec, 
   {{0x2408016c,0x764c6849,0x1cbc025c,0x6f080368}},	//   анги_, _dzay, _ཇིབ_, _llec, 
   {{0x26d0684a,0x6f08684b,0x3af80694,0x21380175}},	//   _tayo_, _olec, _képp_, voph_, 
   {{0xa2280a83,0x3af81bce,0x6f080036,0x33280393}},	//   ажба_, _jépp_, _nlec, gnax_, 
   {{0x3af81bce,0x61e001e4,0xac04000d,0xd75406c2}},	// [7640] _mépp_, ĥolo, ööjõ, _بليت_, 
   {{0xa2d8000b,0x33280354,0x3af81574,0x00000000}},	//   _पोर्, anax_, _lépp_, --, 
   {{0x6f08684c,0x2d481709,0x2138684d,0xdfd000c6}},	//   _blec, túen_, roph_, بيض_, 
   {{0x21385f24,0x6f08684e,0x224000d4,0xdb180158}},	//   soph_, _clec, _tykk_, _ustø, 
   {{0x4444684f,0x32d401c0,0x2d480077,0xa0686850}},	//   _hy_, _эцэс, rúen_, _вага_, 
   {{0x44446851,0x2d481709,0xa3bc02e5,0xcc840063}},	//   _ky_, súen_, _इहा_, обље_, 
   {{0x44446852,0x3af81574,0x00000000,0x00000000}},	//   _jy_, _bépp_, --, --, 
   {{0x44446853,0x6f086854,0x00000000,0x00000000}},	//   _my_, _glec, --, --, 
   {{0x3af80de2,0x44446855,0x6b706856,0x00000000}},	//   _dépp_, _ly_, _vāga, --, 
   {{0x44446857,0x6f080034,0xdca40032,0xdb080ba1}},	//   _oy_, _zlec, _фажи, stfà, 
   {{0x44446858,0xd1dc1b49,0x6b700421,0x33280227}},	//   _ny_, _ሒደት_, _tāga, ynax_, 
   {{0x3af80694,0xa2d86859,0xada80014,0x24980311}},	//   _gépp_, _पोल्, _خطہٕ_, _adpm_, 
   {{0x4444685a,0x00000000,0x00000000,0x00000000}},	//   _ay_, --, --, --, 
   {{0x4444685b,0xbabc00cc,0x00000000,0x00000000}},	//   _by_, _অফিছ, --, --, 
   {{0x4444685c,0x33280369,0x1cbc031c,0x59d01157}},	//   _cy_, tnax_, _ཇིན_, तिकर, 
   {{0x4444685d,0xdb1802d2,0x8b98011a,0xe848009f}},	//   _dy_, _optí, יבלת, _اجهن_, 
   {{0x4444685e,0x764c685f,0xa2d80073,0x6b70002b}},	// [7650] _ey_, _uzay, _पोळ्, _nāgn, 
   {{0xd4981e80,0x44446860,0x6f080936,0x69dc0217}},	//   _три_, _fy_, _slec, åsei, 
   {{0x44446861,0x6f086862,0x06c00154,0x00000000}},	//   _gy_, _plec, োরি, --, 
   {{0x661800c8,0x51842e5d,0xdb4406f6,0x2d480077}},	//   ŝtke, _муга, _سَ_, túeo_, 
   {{0x44446863,0x50a00075,0x6f086864,0x6b7000cd}},	//   _zy_, _يەرل, _vlec, _cāgn, 
   {{0x3af81bce,0x00000000,0x00000000,0x00000000}},	//   _sépp_, --, --, --, 
   {{0x6b4400d0,0xffb40304,0x00000000,0x00000000}},	//   lógi, _ойрэ, --, --, 
   {{0x6f080210,0x00000000,0x00000000,0x00000000}},	//   _ulec, --, --, --, 
   {{0x9ce800e5,0x00000000,0x00000000,0x00000000}},	//   _گولے_, --, --, --, 
   {{0x3af81bce,0xdb1800d0,0x00000000,0x00000000}},	//   _wépp_, _istý, --, --, 
   {{0x6d406865,0xdb241f7b,0x2498009a,0x03d00150}},	//   _ikla, _کونی, _rdpm_, _ءﺍﺯﯨ, 
   {{0x44446866,0x24980165,0x6b440413,0x00000000}},	//   _ry_, _sdpm_, kógi, --, 
   {{0x44446867,0xd7ec0a52,0x6d40025c,0xe7ec00ab}},	//   _sy_, _ەكى_, _kkla, _छपवा_, 
   {{0x44446868,0x00000000,0x00000000,0x00000000}},	//   _py_, --, --, --, 
   {{0x6d40014b,0x9878008f,0x638402d5,0x02c801b9}},	//   _mkla, _פאקט, ягва, оқни_, 
   {{0x44446869,0xd7f80375,0x29045c19,0xa6841513}},	//   _vy_, _להצל, lkla_, _элид, 
   {{0x4444686a,0xa368022e,0xf1d4686b,0x00000000}},	// [7660] _wy_, _prеs, мөрө, --, 
   {{0x2054686c,0xd24c47ea,0x614451e4,0x6b700055}},	//   птер, انك_, чеза, _nāgo, 
   {{0x4444686d,0x09b4015b,0x212405a1,0xd12c10ed}},	//   _uy_, জিটা, đoh_, دمل_, 
   {{0x6d40686e,0x3f8c025c,0x29040254,0xa3140354}},	//   _akla, _ħdud_, hkla_, _хьош, 
   {{0x5de4686f,0x29046870,0x00000000,0x00000000}},	//   яжда, kkla_, --, --, 
   {{0x764009a5,0x6d400004,0x29040114,0x7bdc01d3}},	//   şlyg, _ckla, jkla_, _áruk, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d406871,0x29046872,0x00000000,0x00000000}},	//   _ekla, ekla_, --, --, 
   {{0x6d4003c1,0x6b700421,0xbb5400b5,0x00000000}},	//   _fkla, _fāgo, _abcマ_, --, 
   {{0x29041c06,0x3dc40208,0x7798004e,0x00000000}},	//   gkla_, _ipmw_, окор_, --, 
   {{0x5c480592,0x6b700171,0x00000000,0x00000000}},	//   _الاّ_, _jāgl, --, --, 
   {{0xe7ec00af,0x6d4000bc,0x00000000,0x00000000}},	//   _छपरा_, _zkla, --, --, 
   {{0xcb1004ae,0xceb00a1e,0xa8f403e6,0x6d406873}},	//   _אלף_, עיש_, ستیڤ, _ykla, 
   {{0x2ec80da8,0x38c800dd,0x2904049f,0x00000000}},	//   _रस्त, _ذاتی_, ckla_, --, 
   {{0x88b8011a,0x00000000,0x00000000,0x00000000}},	//   _המוז, --, --, --, 
   {{0xdb0801bf,0x2ae4012d,0x00000000,0x00000000}},	//   stfæ, काएँ_, --, --, 
   {{0xc6d4009f,0x00000000,0x00000000,0x00000000}},	// [7670] _ستيت, --, --, --, 
   {{0x0cd404c5,0x2f8800c7,0x00000000,0x00000000}},	//   _তক্ত, жәан_, --, --, 
   {{0x7bdc01ed,0xb3546874,0x6b700055,0x00000000}},	//   _áruh, _окош, _rāgo, --, 
   {{0x6d406875,0x672c0115,0x3f6803e0,0xdb08007c}},	//   _skla, _ĉajk, _ağus_, ntfä, 
   {{0x3f986876,0x6d4001fa,0xd24401c0,0x29045d1d}},	//   _evru_, _pkla, _хэни, ykla_, 
   {{0x51843461,0x2904031c,0xeb780798,0x00000000}},	//   _муҳа, xkla_, осиј_, --, 
   {{0x6d400122,0x41540640,0xdb08007c,0x403401f0}},	//   _vkla, _чврс, ktfä, _зерс, 
   {{0x2ef4036b,0xbed40640,0xae045f32,0xdb0c0241}},	//   _ўзар, _посј, _قوزى, _ìdìb, 
   {{0x8c640046,0x290402fb,0x6d4000d8,0xdb180332}},	//   _етед, tkla_, _tkla, _astó, 
   {{0xfa281540,0x3d94084c,0xa8041cd0,0x00000000}},	//   _ዲፕሎማ, _чифр, дзол, --, 
   {{0xa6c82830,0x29046877,0xdb08007c,0x00000000}},	//   олна_, rkla_, ftfä, --, 
   {{0x29046878,0x00000000,0x00000000,0x00000000}},	//   skla_, --, --, --, 
   {{0xdb186879,0xe8f400c6,0x00000000,0x00000000}},	//   _estó, _يستخ, --, --, 
   {{0xa3e801b9,0x00000000,0x00000000,0x00000000}},	//   одга_, --, --, --, 
   {{0xdb182508,0xd464687a,0xe2981a71,0x8cbc687b}},	//   _istò, дире_, жаб_, ल्यो, 
   {{0x3f680205,0x3f9c06ea,0xa18800d8,0x00000000}},	//   _oğur_, ávum_, жбаа_, --, 
   {{0xa09800c6,0xc44801b9,0xe80400bc,0x00000000}},	// [7680] قضاء_, تیگن_, शनका_, --, 
   {{0x8cbc31a0,0x3a2000e4,0x6b4400c7,0x00000000}},	//   ल्मो, _ýipe_, mógu, --, 
   {{0x6b44291f,0xdef80026,0x00000000,0x00000000}},	//   lógu, жыл_, --, --, 
   {{0x7e9802da,0x00000000,0x00000000,0x00000000}},	//   سنتر_, --, --, --, 
   {{0x6b4400e4,0x4aa40073,0x00000000,0x00000000}},	//   nógu, _गाजव, --, --, 
   {{0xb0ec0327,0x719000a2,0x00000000,0x00000000}},	//   _ལོརེ, _çekỳ, --, --, 
   {{0x69dc019b,0x0b90009f,0x00000000,0x00000000}},	//   æsen, نجيد, --, --, 
   {{0xdb18010e,0x6b440124,0xdb0801e3,0xddc4003b}},	//   _ustü, kógu, xtfä, _обби, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x98c4687c,0x38780e89,0x8df8011a,0xeccc00eb}},	//   фсил, ùrr_, _והמת, লাউড, 
   {{0xdb0801e6,0x1bf000bc,0xbaa41171,0xb7880166}},	//   ttfä, _अपिल_, _зулқ, чәле_, 
   {{0xdb24687d,0xdb18687e,0x00000000,0x00000000}},	//   _کوچی, _estò, --, --, 
   {{0x6b4401d3,0xdb0826bc,0x69dc03cd,0x6600031c}},	//   gógu, rtfä, åset, _żokr, 
   {{0xdb08687f,0x00000000,0x00000000,0x00000000}},	//   stfä, --, --, --, 
   {{0xd6d86880,0xd90c3b93,0xd7f800d8,0x98bc0356}},	//   _дтп_, _میک_, _фул_, altă_, 
   {{0x35b46881,0x074400c7,0x51846882,0x661800df}},	//   _збир, _ихым, дужа, ŝtka, 
   {{0x41746883,0x26dc016b,0x8cbc0ebb,0x856800d1}},	// [7690] نالس, ɛto_, ल्डो, _ﺳﻮﺩﺍ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x09c800cd,0x00000000,0x00000000,0x00000000}},	//   _ऽन्य, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x317800c8,0xada45e7f,0x6cc4008e,0x6da41341}},	//   _מאָד, халл, ейла, хила, 
   {{0xac746884,0xabd41b6b,0x26dc00b0,0x4ba400cf}},	//   راتش, ециј, ētoi_, дөдү_, 
   {{0xac086885,0xbbb400ec,0x00000000,0x00000000}},	//   янка_, نلوڊ, --, --, 
   {{0x0dc8084c,0x18a00107,0x00000000,0x00000000}},	//   _музи_, қаюм, --, --, 
   {{0xad246886,0x88d000cc,0xdb18005c,0x00000000}},	//   _كىرى, ়াসক, _optæ, --, 
   {{0x2d8c01f2,0x3f681ae4,0xdd106887,0x00000000}},	//   _iwee_, _uğur_, müşs, --, 
   {{0x2d8c013b,0x0bf00c71,0xeab000e5,0x00000000}},	//   _hwee_, _جياڭ, _مٹا_, --, 
   {{0xe5a46888,0x2d8c6889,0xdb08007c,0x00000000}},	//   ними, _kwee_, ttfå, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2d8c2ce9,0xa5080114,0x6b4447f1,0x78b800d7}},	//   _mwee_, чега_, rógu, ľavý, 
   {{0x2d8c00f1,0x6b4400e4,0x6844688a,0x00000000}},	//   _lwee_, sógu, _янка, --, 
   {{0xe2b405f5,0xa2d800bc,0x6b4400c7,0x00000000}},	//   эсгэ, _पोख्, pógu, --, 
   {{0x2d8c00b4,0xa3680139,0x00000000,0x00000000}},	// [76a0] _nwee_, _isеm, --, --, 
   {{0x59142fb5,0x6724688b,0x66040b1a,0x6b700055}},	//   ྲིགས_, likj, mykk, _vāgj, 
   {{0x66040627,0x2d8c688c,0x9fdc0eac,0xd00c00ec}},	//   lykk, _awee_, ভঙ্গ, ٽلن_, 
   {{0x21684834,0x2d8c062c,0x6724688d,0x00000000}},	//   _ними_, _bwee_, nikj, --, 
   {{0x63ac05d6,0x2d9801bf,0x69dc01bf,0x660401f4}},	//   lubn, _æsel_, æsel, nykk, 
   {{0x71700058,0x6294688e,0x61441760,0x00000000}},	//   _ئۇلا, layo, _чега, --, 
   {{0x63ac688f,0x6b7000b8,0xcec00118,0x660401f4}},	//   nubn, _jāgh, íří_, hykk, 
   {{0x62946890,0xdd906891,0x19a86892,0x7e9838b7}},	//   nayo, _مور_, птоп_, _آچار_, 
   {{0x9f340046,0x2d8c062c,0x95ec05b3,0x6b70002b}},	//   _жеңі, _gwee_, _चपेट_, _lāgh, 
   {{0x62946893,0x66045522,0x8cbc1fd2,0x00000000}},	//   hayo, dykk, ल्दो, --, 
   {{0x62946894,0x2d8c04c4,0x69dc1347,0x3cec01bf}},	//   kayo, _zwee_, åser, _indv_, 
   {{0x63ac6895,0x00000000,0x00000000,0x00000000}},	//   dubn, --, --, --, 
   {{0x62946896,0xdb4c04d3,0x05e81d0f,0x8af80375}},	//   dayo, _پێک_, нфри_, _מהאי, 
   {{0xab600209,0x26c4002e,0xd3786897,0x628000e8}},	//   _ýüre, _ñoon_, зча_, ñoon, 
   {{0x63ac1505,0xa8040227,0x6b7000b8,0x00000000}},	//   gubn, rañä, _cāgh, --, 
   {{0x62944511,0xd5b8011c,0xdb08032e,0x042000cc}},	//   gayo, _есо_, fufé, _মুহী_, 
   {{0xcfb4009e,0xdb1800fd,0x68ec01e1,0xdb08032e}},	// [76b0] ীয়ান, _iptä, _úndá, gufé, 
   {{0x33746898,0x62940280,0x6b446899,0x7bc8057b}},	//   _игор, aayo, nógr, _opdu, 
   {{0x6294689a,0x2d8c689b,0x00000000,0x00000000}},	//   bayo, _swee_, --, --, 
   {{0xfe70689c,0x6294689d,0x6b440332,0xc7b0011a}},	//   مده_, cayo, hógr, טבע_, 
   {{0x7bc825ad,0x00000000,0x00000000,0x00000000}},	//   _apdu, --, --, --, 
   {{0x3134262e,0x62640132,0xdca0009d,0xbe88013d}},	//   _регр, _جاپق, ааши, _үсте_, 
   {{0x6604000f,0x7c9402c9,0xc0cc0023,0x6b58466e}},	//   zykk, اشها, በኦም_, мшир_, 
   {{0x2d8c689e,0x6604005b,0xaa440132,0x00000000}},	//   _twee_, yykk, кейл, --, 
   {{0x2eec0048,0x7e6408a4,0x672400cc,0xc94001b9}},	//   _inef_, žipr, vikj, лдиқ, 
   {{0x2eec0477,0x6294689f,0x63ac003e,0x66040108}},	//   _hnef_, zayo, yubn, vykk, 
   {{0xe73865a7,0x629468a0,0x2eec01ab,0x672468a1}},	//   ден_, yayo, _knef_, tikj, 
   {{0x660412ed,0x6b700882,0xca5000d1,0x6294058a}},	//   tykk, _rāgh, ﺋﻪﺕ_, xayo, 
   {{0x2b4c03bd,0x629468a2,0x672468a3,0xdab4413a}},	//   mlec_, vayo, rikj, _شهوت_, 
   {{0x629468a4,0x66042ab7,0x6b440005,0x2b4c68a5}},	//   wayo, rykk, cógr, llec_, 
   {{0x629468a6,0x660468a7,0x672468a8,0x2308131e}},	//   tayo, sykk, pikj, وتري_, 
   {{0x63ac02fb,0x2b4c68a9,0x9834011a,0x6b700055}},	//   rubn, nlec_, _ברצף_, _vāgh, 
   {{0x629468aa,0x65d407d6,0x3d100241,0x63ac68ab}},	// [76c0] rayo, _рўйх, _làwa_, subn, 
   {{0x2eec020b,0x00000000,0x00000000,0x00000000}},	//   _anef_, --, --, --, 
   {{0x629468ac,0xd24c121e,0x3f9c20ef,0xd7e4031c}},	//   payo, منہ_, évu_, རའགྱ, 
   {{0x629468ad,0x4ea068ae,0x2b4c0175,0x57f800df}},	//   qayo, арша, jlec_, ולעו, 
   {{0x4dd0282b,0x2b4c17ee,0xdfd000ec,0x00000000}},	//   لتوس, dlec_, _ھير_, --, 
   {{0xdfd02603,0x6b540006,0x2b4c030a,0x61e468af}},	//   _پير_, _išgy, elec_, _irkl, 
   {{0xdea0034d,0x61e401fa,0x1ea868b0,0xbb440818}},	//   _نیای, _hrkl, _ياري_, лфиқ, 
   {{0x1a6403e6,0x61e416a3,0x2b4c01a6,0xdb080fac}},	//   نیای_, _krkl, glec_, ntfø, 
   {{0x6b4468b1,0xdb1801e3,0x588468b2,0x8cbc07af}},	//   tógr, _ostö, кына, ल्हो, 
   {{0x0d2068b3,0x61e40e3c,0x2b4c0010,0x7bc80332}},	//   _күчү, _mrkl, alec_, _tpdu, 
   {{0x64582200,0xdb080158,0x6b4468b4,0x2b4c68b5}},	//   ýtil, ktfø, rógr, blec_, 
   {{0x16705894,0x61e468b6,0x1cb0031c,0xab6000ee}},	//   шқир, _orkl, ྐུམ_, _ýüpe, 
   {{0xcb640261,0x6b7000b8,0xa2c400bc,0x6b443a6c}},	//   _раце_, _rāgi, ाभन्, pógr, 
   {{0x062468b7,0x7bdc01d3,0x00000000,0x00000000}},	//   рфюм, _árus, --, --, 
   {{0x61e468b8,0x98bc02e2,0x00000000,0x00000000}},	//   _arkl, notč_, --, --, 
   {{0x301468b9,0x61e41a48,0x237c01ed,0x00000000}},	//   ңдар, _brkl, ítja_, --, 
   {{0x42742852,0x74140133,0x325468ba,0x6b7000b8}},	// [76d0] ргус, _ڕودا, увар, _vāgi, 
   {{0x764c68bb,0xd24c021a,0xe7a800dc,0x2b4c05c7}},	//   _iyay, منځ_, _किमप, zlec_, 
   {{0x61e468bc,0x1ee804fb,0x73340131,0x764c002b}},	//   _erkl, کونی_, _مىدا, _hyay, 
   {{0x764c0a49,0x61e401bf,0x98bc0100,0x00000000}},	//   _kyay, _frkl, dotč_, --, 
   {{0x518468bd,0xfe7068be,0x61e40960,0x764c0055}},	//   _шуна, زدن_, _grkl, _jyay, 
   {{0xfe70425b,0x32086326,0x621802e4,0x6f24002b}},	//   مدۇ_, myay_, _טורק, _śucī, 
   {{0x4a70005e,0x7f480075,0x764c0337,0x031803e6}},	//   қықт, رلۇق_, _lyay, _ستێت_, 
   {{0xe9d868bf,0xfbd068c0,0x2ca800ac,0x776c002e}},	//   еки_, تته_, şad_, _niax, 
   {{0x764c0e8a,0x320868c1,0xaa0c012c,0x2b4c68c2}},	//   _nyay, nyay_, िनेछ_, rlec_, 
   {{0x32080050,0x29103656,0xa9a40046,0x3d1001e1}},	//   iyay_, óza_, _ەمشى, _tàwa_, 
   {{0x764c68c3,0x2b4c1497,0x776c045a,0x3208127b}},	//   _ayay, plec_, _biax, hyay_, 
   {{0x764c68c4,0x6a84322e,0x0550001f,0xc95002dd}},	//   _byay, _ёлла, _ማብራሪ, ытқы, 
   {{0x26c43d27,0x764c0796,0x2d9c68c5,0x776c002e}},	//   _ñoom_, _cyay, nswe_, _diax, 
   {{0x69d868c6,0xb8e80729,0x764c0100,0x782407d6}},	//   _iswe, _লো_, _dyay, اعیل, 
   {{0x764c68c7,0x32080050,0x61e405be,0x2d9c00ca}},	//   _eyay, eyay_, _srkl, hswe_, 
   {{0x776c68c8,0x61e468c9,0x26dc00e2,0x61e001bf}},	//   _giax, _prkl, ētos_, æolo, 
   {{0x764c0337,0xdb0868ca,0x320803ac,0x05a807af}},	// [76e0] _gyay, rtfø, gyay_, _कटिब, 
   {{0x61e401a6,0xdb080158,0x00000000,0x00000000}},	//   _vrkl, stfø, --, --, 
   {{0xe29868cb,0xdee451e4,0x94b80302,0x205468cc}},	//   _пан_, ложи, _אמית, утар, 
   {{0xc0f80125,0x5e940150,0x3208058a,0xde940127}},	//   _ገዳም_, اشاء, byay_, اجاب, 
   {{0x8fa00046,0x69d81eef,0x98bc007f,0x320802d0}},	//   _қате, _nswe, wotč_, cyay_, 
   {{0x8cbc146b,0x59140327,0x00000000,0x00000000}},	//   ल्लो, ྲིབས_, --, --, 
   {{0x386001e4,0x00000000,0x00000000,0x00000000}},	//   _ĝiro_, --, --, --, 
   {{0x3a7404a9,0x705003e6,0x58f40327,0x0d8068cd}},	//   шлир, _بۆما, _ྗོངས_, шлән, 
   {{0x391468ce,0x7e6400ee,0x776c01ab,0xcb640640}},	//   имир, ýipd, _riax, ћање_, 
   {{0x764c015c,0x5d100075,0xd90c68cf,0x91b8008f}},	//   _ryay, _دېتا, ثیت_, עמיי, 
   {{0x69d84242,0x2c000107,0xe97800db,0x00000000}},	//   _eswe, _мӯъм, нбөш_, --, 
   {{0xd6d8063b,0x2d4804d4,0x320868d0,0xb50c000d}},	//   хто_, búes_, yyay_, हस्प_, 
   {{0x776c0f71,0xeb540131,0xab6006ba,0x320868d1}},	//   _viax, _ئىنگ, _بۇيى, xyay_, 
   {{0x764c68d2,0xdb180120,0x3d1001e1,0xfbb82314}},	//   _vyay, _estô, _màwo_, _इमाम, 
   {{0x2d9c009a,0x3d100241,0x32080857,0x00000000}},	//   zswe_, _làwo_, wyay_, --, 
   {{0xe7a80073,0x320802d0,0x764c0055,0x534400c0}},	//   _कितप, tyay_, _tyay, ухга, 
   {{0xf0840efb,0x764c68d3,0xd1b82309,0x3d1001e1}},	// [76f0] لداۋ, _uyay, عارا_, _nàwo_, 
   {{0x32082f05,0x38480023,0xd3440133,0xcf981fbe}},	//   ryay_, _ሓንሳብ, _ڕیزه_, ејд_, 
   {{0xc3300014,0x320868d4,0x614400d1,0x00000000}},	//   زٕے_, syay_, جىلە, --, 
   {{0x8e700220,0x320803ac,0x00000000,0x00000000}},	//   сқаш, pyay_, --, --, 
   {{0x320802d1,0x9e9401b9,0x1f240014,0x00000000}},	//   qyay_, شانچ, جِنہ, --, 
   {{0x71240075,0x2d480998,0x6bd4007b,0x00000000}},	//   _ئىسم, vúes_, لتبر, --, 
   {{0xaa0c038e,0x6e9402bf,0xaed401f4,0x00000000}},	//   िन्छ_, _вибу, _ковш, --, 
   {{0x3d1001e1,0x00000000,0x00000000,0x00000000}},	//   _fàwo_, --, --, --, 
   {{0xa36801d5,0xa9a400ee,0x888000e5,0x00000000}},	//   _prеz, шипд, میشن, --, 
   {{0xa92468d5,0x6f186729,0x2d4800e4,0xfbd000f7}},	//   рдол, lhwc, rúes_, تتۇ_, 
   {{0x7bdc0124,0x26c4002e,0x6b7402dd,0xa7a802e8}},	//   _árup, _ñook_, _тлеу, ъкна_, 
   {{0x69d868d6,0xd7b402ab,0x2d4805c7,0x00000000}},	//   _tswe, _अमरच, púes_, --, 
   {{0x69d868d7,0x65740051,0x6b7000b8,0x00000000}},	//   _uswe, _quyh, _vāgu, --, 
   {{0xf990168d,0x7c3868d8,0x5e5400df,0x00000000}},	//   _ربه_, _çarç, שישע_, --, 
   {{0xe2982082,0x232868d9,0xe7380150,0x00000000}},	//   кав_, вови_, _иек_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x64a468da,0x91e017a0,0xe12400c7,0x00000000}},	// [7700] _капа, ооте, амаи, --, 
   {{0xa0a468db,0xba08001f,0x91a405dc,0xe1080108}},	//   ражд, _ገዥ_, _चिरै, ъезд_, 
   {{0x98bc1c52,0x00000000,0x00000000,0x00000000}},	//   notā_, --, --, --, 
   {{0x5398025f,0xa2e468dc,0x1ee801b9,0x59a400bc}},	//   _ביטו, _томд, کوچی_, _खिलर, 
   {{0xdcb02928,0xe0d40166,0x20d4003b,0x00000000}},	//   قىش_, _кювь, _ківс, --, 
   {{0x16d0012c,0x00000000,0x00000000,0x00000000}},	//   _तस्ब, --, --, --, 
   {{0x3d1001e1,0x4fa001af,0x28d80118,0x00000000}},	//   _wàwo_, _мирв, बजनि, --, 
   {{0x6f180368,0x3d100241,0x98bc00de,0x00000000}},	//   chwc, _tàwo_, dotā_, --, 
   {{0x3f681ae4,0x5d841867,0x4970010b,0x00000000}},	//   _oğuz_, _ضلال, олыс, --, 
   {{0x63ac1068,0x391468dd,0xdb080332,0x5fb828fe}},	//   krbn, смор, irfé, _उमाल, 
   {{0xdb1800b5,0xf1dc000d,0x98bc68de,0x00000000}},	//   _optø, _नैनन, gotā_, --, 
   {{0x4ba41e35,0xdb08002f,0x91a4000d,0x00000000}},	//   _төшү_, ntfü, _चिलै, --, 
   {{0x550468df,0xca44004b,0xef10008f,0x588400db}},	//   ачва, _پلوه_, פּט_, _кыйа, 
   {{0x98bc00ef,0x00000000,0x00000000,0x00000000}},	//   botā_, --, --, --, 
   {{0x69dc01bf,0x480400f0,0x00000000,0x00000000}},	//   æsev, _вејн_, --, --, 
   {{0x591403bd,0xb27468e0,0xd340114f,0x00000000}},	//   ྲིམས_, слаш, آفری, --, 
   {{0xb0340b8d,0xcad40375,0xdb080112,0x6b700b13}},	// [7710] әнеш, סומת_, dtfü, _jāgr, 
   {{0x77780218,0xfd500882,0x823468e1,0x00000000}},	//   _kuvx, pekṣ, زرقا, --, 
   {{0xdb080112,0xbdf800f2,0x6f18015d,0x00000000}},	//   ftfü, یرها_, thwc, --, 
   {{0xd34402f2,0x00000000,0x00000000,0x00000000}},	//   _ئیره_, --, --, --, 
   {{0x3f9c022c,0x913000c7,0x6b7000b8,0xa2f4011a}},	//   ávur_, _дҭах, _nāgr, _המרה_, 
   {{0xeb9868e2,0x64580112,0x86500023,0x27300135}},	//   гик_, ütig, _መንእስ, rġni_, 
   {{0xab2868e3,0x6ee001f2,0x4f6804b4,0x98740092}},	//   лока_, _ịbuw, _ашам_, _ከአሁኑ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa92468e4,0xfb2468e5,0x6b70002b,0x00000000}},	//   йдил, تروپ, _cāgr, --, 
   {{0xe8f868e6,0x3170045a,0x692406a6,0x00000000}},	//   уло_, _jizz_, ёмна, --, 
   {{0x66e40364,0x00000000,0x00000000,0x00000000}},	//   бона, --, --, --, 
   {{0x27300fb7,0xfb8404fb,0x49f0004b,0xb9c40014}},	//   kšne_, _بگوی, _وياړ, _ژٲن٘, 
   {{0x7ac868e7,0x27300010,0x00000000,0x00000000}},	//   _خونِ_, jšne_, --, --, 
   {{0xf9900014,0xa878010f,0x00000000,0x00000000}},	//   _آبن_, _גאַר, --, --, 
   {{0x273000d0,0x58f4011a,0x00000000,0x00000000}},	//   ešne_, _למסע_, --, --, 
   {{0xa06801b9,0x317801d3,0x63ac68e8,0x46dc0037}},	//   ҳаза_, _busz_, rrbn, _बसिह, 
   {{0x317068e9,0x21a468ea,0x17180375,0x00000000}},	// [7720] _bizz_, сизм, _תופע, --, 
   {{0xdb08067c,0xa068010a,0xa6e00174,0x31780210}},	//   ntfò, газа_, áðfe, _dusz_, 
   {{0x98bc0356,0x232868eb,0x31700051,0xdb08002f}},	//   lotă_, _бони_, _dizz_, ttfü, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x1d0868ec,0x31700204,0xe22c001f,0x23780477}},	//   леди_, _fizz_, _በመሆና, _hupj_, 
   {{0xa114006c,0x25a0010a,0x51f40451,0x00000000}},	//   _اوست, iskl_, _اسٽر, --, 
   {{0xdee454c9,0x5ca40364,0xdca4023b,0x28bc1a4e}},	//   _лови, _ҳизб, _ҳази, ्भनि, 
   {{0xef90034c,0x99640131,0xd7f808ca,0x6b70002b}},	//   _آیند, әтил, ҳум_, _sāgr, 
   {{0x249800eb,0xfcc40116,0x2b540214,0x00000000}},	//   _oepm_, _дәйм, آیند_, --, 
   {{0xdd940831,0xd7f868ed,0x5cc40014,0x9d440408}},	//   _ваҡы, гум_, _دترِ, _уезд, 
   {{0xfcd40092,0xfbdc0073,0x6b7000b8,0x28d8000d}},	//   ሪንግ_, _मनिम, _vāgr, _बघरि, 
   {{0xdb0868ee,0xdd10005f,0xe7a82ba2,0xa2a800cd}},	//   rtfó, kļūs, _किरप, जृम्, 
   {{0x8cbc07f7,0xceb00375,0xa3dc05d7,0xd94400f3}},	//   ल्को, היר_, _दैब_, _леди, 
   {{0x27e800e4,0xb7d80ef6,0x317868ef,0x94a81e35}},	//   _ņane_, _نوتا_, _rusz_, ытма_, 
   {{0x5c2c0092,0x00000000,0x00000000,0x00000000}},	//   _እንጠይ, --, --, --, 
   {{0x317001f5,0x47340150,0x00000000,0x00000000}},	//   _sizz_, _ىريز, --, --, 
   {{0x31700010,0x5184013d,0x00000000,0x00000000}},	// [7730] _pizz_, суба, --, --, 
   {{0x518468f0,0x4a58011a,0x00000000,0x00000000}},	//   _қума, רדמו, --, --, 
   {{0x06dc015b,0xa6e068f1,0x00000000,0x00000000}},	//   ধারি, áðge, --, --, 
   {{0x317068f2,0x3178012d,0x00000000,0x00000000}},	//   _wizz_, _tusz_, --, --, 
   {{0xa0200724,0x0eb401e0,0x6da468f3,0x6448012d}},	//   _çönk, ауҙы_, цила, ęliś, 
   {{0x212868f4,0xac0868f5,0xace852d1,0x8d840137}},	//   _gmbh_, инла_, рмка_, _ۇشئن, 
   {{0xc0580153,0x00000000,0x00000000,0x00000000}},	//   _гіт_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x20c400cd,0x00000000,0x00000000,0x00000000}},	//   र्वध, --, --, --, 
   {{0xad4000cf,0x692468f6,0x7c240115,0xc82021f3}},	//   _تۉتۉ, імна, ŝira, ззоқ, 
   {{0xdb08068c,0x6bd80345,0x00000000,0x00000000}},	//   rtfò, _خواس_, --, --, 
   {{0xfbd068f7,0x65c4390e,0x00000000,0x00000000}},	//   _ستم_, обма, --, --, 
   {{0xdb2468f8,0x00000000,0x00000000,0x00000000}},	//   _بونی, --, --, --, 
   {{0xdd7800c8,0xdb0802d2,0x00000000,0x00000000}},	//   יטשל, gufæ, --, --, 
   {{0x528402e3,0x7b0806ea,0x00000000,0x00000000}},	//   _ụlọi, _ástø, --, --, 
   {{0xe578084c,0xdb100342,0x98bc0356,0x00000000}},	//   _кзи_, şgör, potă_, --, 
   {{0xe1f868f9,0x626400db,0x00000000,0x00000000}},	// [7740] шга_, زارق, --, --, 
   {{0x798404e6,0x00000000,0x00000000,0x00000000}},	//   _éiwe, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x645c68fa,0x00000000,0x00000000,0x00000000}},	//   _izpi, --, --, --, 
   {{0x21280a2e,0x5dd800d8,0xa3dc00c5,0x57b407b6}},	//   _tmbh_, рфер_, _दैत_, _अम्ह, 
   {{0x2128014b,0x2fd001a6,0xcdcc00f1,0x00000000}},	//   _umbh_, _fpzg_, کښې_, --, 
   {{0x81bc0183,0x98bc00c0,0x00000000,0x00000000}},	//   _আনি_, notą_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdef801af,0x00000000,0x00000000,0x00000000}},	//   _йыҡ_, --, --, --, 
   {{0xa3c800e1,0x645c01c4,0x81bc0eac,0x21380332}},	//   लझा_, _ozpi, _আনা_, nnph_, 
   {{0xbb5400b5,0x69dc5d04,0x628468fb,0xb6f80131}},	//   _ebbは_, æser, _ofko, مىدا_, 
   {{0x68ec0198,0x98bc0153,0x00000000,0x00000000}},	//   _ɗadi, dotą_, --, --, 
   {{0x645c05f5,0x95c868fc,0x68ec007b,0x7d08007c}},	//   _azpi, шуна_, íodó, _kods, 
   {{0x32d407ae,0x628468fd,0x2b4801a6,0xe79401d5}},	//   _ấy_, _afko, čace_, _کاوک, 
   {{0x7d08019b,0x394c0793,0x3980067c,0x335400f7}},	//   _mods, mods_, _hòs_, зүнө_, 
   {{0x394c0793,0x7d0868fe,0x60cc02d0,0x39800100}},	//   lods_, _lods, _abbm, _kòs_, 
   {{0x7d08127b,0x9d9001ec,0x00000000,0x00000000}},	// [7750] _oods, _етiл, --, --, 
   {{0x3980067c,0x394c0793,0x628402d0,0x7d080254}},	//   _mòs_, nods_, _efko, _nods, 
   {{0x9740041a,0xc104664e,0xd9c000eb,0x00000000}},	//   šćuj, بولي, ্টিম, --, 
   {{0xc0cc0023,0xfe7001d5,0xa91c0064,0x00000000}},	//   _ባዓል_, چده_, rpži, --, 
   {{0xfe7068ff,0x7d0848bb,0x3d1000e8,0x394c01b8}},	//   نده_, _bods, _jàww_, kods_, 
   {{0x7d080050,0xbdf81e5a,0xdce00135,0x06a00220}},	//   _cods, ترما_, tpoġ, _ﻋﯩﻠﯩ, 
   {{0xeb98034b,0xae4401d9,0x00000000,0x00000000}},	//   щий_, _کھاو, --, --, 
   {{0x27300fb7,0x3980033b,0xa70400cc,0xbb3c00d1}},	//   kšna_, _bòs_, _উষ্ম_, ﺑﯩﻲ_, 
   {{0x3980180f,0x7d08037e,0x27300010,0x5c7004b4}},	//   _còs_, _fods, jšna_, мләт, 
   {{0x2ba40029,0x7d086900,0x394c0793,0x6f080b21}},	//   pēc_, _gods, gods_, _hoec, 
   {{0x273000d7,0x66e401f4,0x3d100037,0x00000000}},	//   ešna_, пона, _तकते_, --, 
   {{0xe6443339,0x39800699,0x6f080a85,0xe7386901}},	//   земп, _fòs_, _joec, сем_, 
   {{0x645c068f,0x6f086902,0xeac00220,0xa6dc015b}},	//   _szpi, _moec, _жұқп, যালয়, 
   {{0x8cbc0316,0x6f080165,0x64a4009d,0x98bc0210}},	//   ल्चो, _loec, яага, totą_, 
   {{0x690c02d2,0x00000000,0x00000000,0x00000000}},	//   _dúet, --, --, --, 
   {{0x3d100694,0x64c400f1,0x645c0419,0x398001e1}},	//   _fàww_, _کيدل, _vzpi, _yòs_, 
   {{0xdb080205,0x81c400c7,0x00000000,0x00000000}},	// [7760] sufç, ьааҧ, --, --, 
   {{0x0dc8001f,0x16600166,0xab6000a2,0x64580174}},	//   _አሰፋ_, _явым, _ýüfe, ýtis, 
   {{0x7d08022e,0x645c2672,0x54780375,0xd478011a}},	//   _rods, _uzpi, _לטיו, _לאיל, 
   {{0x44446903,0xdb0801e6,0x6f086904,0x7d0809a8}},	//   _ix_, ltfö, _coec, _sods, 
   {{0x7d086905,0x444404ce,0x80b400d1,0xdb08007c}},	//   _pods, _hx_, _يەرش, otfö, 
   {{0xa0686906,0x9bb4025c,0x602001ed,0xdb080fe7}},	//   _гага_, _དཀྱོ, _címé, ntfö, 
   {{0x444404ce,0x7d082481,0x6f086907,0x79800007}},	//   _jx_, _vods, _foec, wqmw, 
   {{0x44446908,0x1ea8021a,0x394c08cd,0xdcc8035c}},	//   _mx_, _داسي_, wods_, _گذره_, 
   {{0x394c29ef,0x7d08047e,0xdb080267,0x00000000}},	//   tods_, _tods, ktfö, --, 
   {{0x44441590,0xed081564,0x39800ba1,0xdca46909}},	//   _ox_, _وآله_, _vòs_, _хажи, 
   {{0x4444690a,0x394c690b,0x9bb40003,0xf8b8004d}},	//   _nx_, rods_, _དཀྲོ, ghĩa_, 
   {{0xd5b4025c,0x394c2045,0x10340375,0x00000000}},	//   _བཀྱག, sods_, לטים_, --, 
   {{0xbbdc690c,0x69d40311,0xdb08690d,0x394c690e}},	//   _मनुक, ăzec, rufä, pods_, 
   {{0x7b1c01e7,0xd7f801f0,0x19ac0ef6,0x00000000}},	//   _féuc, _гуи_, _ﺳﻪﻳﻠ, --, 
   {{0x44445f5c,0xc8c400ec,0x638801a9,0x00000000}},	//   _cx_, _روين_, жруҳ_, --, 
   {{0x083823e4,0x44445e74,0xc7d4011a,0x00000000}},	//   _לעול, _dx_, _זוהי_, --, 
   {{0x4444690f,0xf1dc033f,0xd5b40327,0x948401e0}},	// [7770] _ex_, _नैशन, _བཀྲག, _нынд, 
   {{0xd4980354,0x8638011a,0x877401f0,0x00000000}},	//   _ури_, _מרחב_, _оғӯш, --, 
   {{0x6f086910,0x602001e7,0x1fb4010a,0x00000000}},	//   _poec, _rímé, çсер, --, 
   {{0x6e94005a,0x00000000,0x00000000,0x00000000}},	//   фиду, --, --, --, 
   {{0xa2c02f89,0x0dc80022,0x00000000,0x00000000}},	//   _шәрк, суеи_, --, --, 
   {{0xd5b40003,0xad246911,0x00000000,0x00000000}},	//   _བཀླག, بىتى, --, --, 
   {{0x44446912,0xfe703baf,0x1ae40011,0xac08011c}},	//   _xx_, ندۇ_, কানে_, юнка_, 
   {{0xef6401c6,0x00000000,0x00000000,0x00000000}},	//   _цэгү, --, --, --, 
   {{0xaa4c02d3,0x272001fb,0x201c032e,0xaa440022}},	//   _ምድላዋ, _hóng_, _ýtir_, ьеил, 
   {{0x2d8c6913,0x272002d2,0xe7a86914,0x7c380332}},	//   _itee_, _kóng_, овол_, éarú, 
   {{0x6d400455,0xc5f800cd,0x00000000,0x00000000}},	//   _ijla, ुह्य_, --, --, 
   {{0x444462ff,0x2720001e,0xe5a42d2e,0x00000000}},	//   _rx_, _móng_, мими, --, 
   {{0x44446915,0xdb086916,0x2720004d,0x98bc033f}},	//   _sx_, ttfö, _lóng_, hotę_, 
   {{0x44446917,0x69c86918,0x00000000,0x00000000}},	//   _px_, mtee, --, --, 
   {{0x69c86919,0x272007ae,0x444462e5,0xdb08691a}},	//   ltee, _nóng_, _qx_, rtfö, 
   {{0x69c8691b,0xdb08691c,0x00e43c5b,0x28bc00cd}},	//   otee, stfö, کتری, ्भवि, 
   {{0x26d0685c,0x444404ce,0x2d8c013f,0xa114691d}},	// [7780] _ibyo_, _wx_, _ntee_, وورت, 
   {{0x4444691e,0x272007ae,0x6d4000f2,0x69c8691f}},	//   _tx_, _bóng_, _njla, itee, 
   {{0x44446920,0x69c80664,0x2d8c0ba7,0xf08819b6}},	//   _ux_, htee, _atee_, سئله_, 
   {{0x69c86921,0x6d4000f3,0xbcfc0051,0x27200051}},	//   ktee, _ajla, _chĩn, _dóng_, 
   {{0x62946922,0x69c8002e,0x57d800af,0x21680902}},	//   mbyo, jtee, _बन्ह, _мими_, 
   {{0x27300fb7,0x26d000ca,0x69c800af,0x71706923}},	//   kšno_, _lbyo_, dtee, _مۇقا, 
   {{0x69c86924,0x2d8c6925,0x26d00083,0x27300427}},	//   etee, _etee_, _obyo_, jšno_, 
   {{0x69c86926,0x62940369,0x3d280b28,0x19a86927}},	//   ftee, nbyo, _کتری_, отоп_, 
   {{0x69c86928,0x391400f3,0x00000000,0x00000000}},	//   gtee, емпр, --, --, 
   {{0x26d03a41,0x62940369,0x2b480e04,0xdc680395}},	//   _abyo_, hbyo, čaca_, _дазд_, 
   {{0x69c86929,0x690c0048,0x26d004ba,0xdb08143a}},	//   atee, _púer, _bbyo_, ftfô, 
   {{0x69c8692a,0x62940369,0xd6d800d8,0x00000000}},	//   btee, jbyo, цто_, --, 
   {{0x69c8692b,0x8a0000a7,0xf8b00014,0x965c074d}},	//   ctee, _изце, _یکھ_, ртнă_, 
   {{0x26d02f99,0x38c80133,0x29180200,0x00000000}},	//   _ebyo_, _راتی_, ësat_, --, 
   {{0xd7e402bf,0x272002d2,0xbbdc141f,0x88b8011a}},	//   _ціло, _bónd_, _मनोक, _ומוז, 
   {{0x6294017a,0x00000000,0x00000000,0x00000000}},	//   gbyo, --, --, --, 
   {{0x80c803f4,0xd56461ff,0x27200016,0x9f48011f}},	// [7790] রজন্, _отоп, _sóng_, _orbâ_, 
   {{0x629404ba,0x98bc0210,0x00000000,0x00000000}},	//   abyo, totę_, --, --, 
   {{0x7534692c,0x2d8c692d,0x69c805f5,0x6294007c}},	//   mizz, _stee_, ztee, bbyo, 
   {{0x7534692e,0x69c81ad2,0xb900031c,0x7ed40006}},	//   lizz, ytee, _ཥི_, вішч, 
   {{0x69c8692f,0xd244009d,0x00000000,0x00000000}},	//   xtee, _цэни, --, --, 
   {{0x75346930,0x61e00ba1,0xfde801ec,0x69c86931}},	//   nizz, çole, ьдік_, vtee, 
   {{0x69c82da0,0x3d100037,0x00000000,0x00000000}},	//   wtee, _तकरे_, --, --, 
   {{0x69c86932,0x75346933,0x2d8c1529,0xae040220}},	//   ttee, hizz, _ttee_, _كوزى, 
   {{0x7a840075,0x75346934,0x69c86935,0x888001ed}},	//   خشىم, kizz, utee, نیشن, 
   {{0xa8040124,0x75346936,0x69c86937,0x00000000}},	//   езол, jizz, rtee, --, 
   {{0x75346938,0x69c86939,0x5ee00154,0x00000000}},	//   dizz, stee, ফারে, --, 
   {{0x69c8693a,0x00000000,0x00000000,0x00000000}},	//   ptee, --, --, --, 
   {{0x6b80693b,0x75340268,0x1a98010f,0xe29801f0}},	//   _hulg, fizz, _זינע, ҷаб_, 
   {{0xdebc693c,0x6b80693d,0x7534693e,0x00000000}},	//   _ሱዳን_, _kulg, gizz, --, 
   {{0x6b80693f,0xe298023b,0x98bc01ef,0x00000000}},	//   _julg, заб_, hotě_, --, 
   {{0x26d000ca,0x6b806940,0x629404ce,0xb9cc069d}},	//   _ubyo_, _mulg, ubyo, _ሱቅ_, 
   {{0x75346941,0x62946942,0x73740961,0x3d1000c5}},	// [77a0] bizz, rbyo, тырх, _तकले_, 
   {{0x753400a7,0x6024551b,0x6b8002d0,0x62940072}},	//   cizz, ндза, _oulg, sbyo, 
   {{0xb4006943,0x1ae4015b,0x00000000,0x00000000}},	//   _күрд, কাতে_, --, --, 
   {{0x26c06944,0x3ea000ae,0x00000000,0x00000000}},	//   ngko_, úit_, --, --, 
   {{0x1278008f,0x5ee000cc,0x00000000,0x00000000}},	//   _מאכע, ফালে, --, --, 
   {{0x61e404b9,0x6b806945,0xdb0803b2,0xadf40139}},	//   _iskl, _bulg, lufø, тошә, 
   {{0xa0680209,0x272000d0,0x5fb80073,0x00000000}},	//   _хава_, _zóne_, _उमटल, --, 
   {{0x6b80054e,0x75346946,0x5f04010a,0x00000000}},	//   _dulg, zizz, _язба, --, 
   {{0x75340a49,0x00000000,0x00000000,0x00000000}},	//   yizz, --, --, --, 
   {{0x6b806947,0x98c40107,0xa6e003b2,0x00000000}},	//   _fulg, хсил, áðne, --, 
   {{0x75346948,0x64586949,0x6b800548,0x7b640276}},	//   vizz, ütil, _gulg, _иӂие, 
   {{0x8c180302,0x4ae0036b,0x61e40798,0x5a4401d5}},	//   _מובי, _бўша, _oskl, _пэла, 
   {{0x7534694a,0xfba4694b,0xcb043229,0x00000000}},	//   tizz, _गौतम, _سيون_, --, 
   {{0xd90c01ed,0x6b80694c,0xb42400e5,0x60dc0432}},	//   _چیک_, _yulg, پٹرو, jepm, 
   {{0x75346082,0xd90c694d,0x6b80172e,0xd7f83de2}},	//   rizz, _نیک_, _xulg, _хул_, 
   {{0x7534694e,0x35f40131,0x00000000,0x00000000}},	//   sizz, _апир, --, --, 
   {{0x7534694f,0x8650016b,0xb2746950,0x1be000e1}},	// [77b0] pizz, _adɔf, тлаш, _कैसल_, 
   {{0x98bc012c,0xe22c001f,0xd4986951,0xcfa4010b}},	//   votě_, _በዘመና, _эри_, ешди, 
   {{0x61e46952,0x7b1c6953,0x201c07c5,0xf1980150}},	//   _eskl, _réun, _ütil_, _ﺘﺨﺩﻡ_, 
   {{0x6b806954,0xc87c0356,0x272000d7,0x00000000}},	//   _rulg, ăşim_, _tóne_, --, 
   {{0x6b8000af,0x1ee8350a,0x60dc014f,0x7e8001ec}},	//   _sulg, بونی_, bepm, _ﺩﯞﻻﺕ_, 
   {{0x271c00ce,0x9324014d,0x32900220,0x00000000}},	//   _पत्र_, _آرگن, _ﺑﯩﻼﻱ_, --, 
   {{0x8f44035b,0x1d0400a7,0x6b80022e,0xfca84451}},	//   _зхад, тещи_, _qulg, راوو_, 
   {{0xb4cc084a,0x7c9401ec,0x9af000d1,0xadbc0064}},	//   रभु_, _ەشنا, لكىت, _мабi, 
   {{0xe9686955,0x6b80033f,0x28b8084c,0xa368022e}},	//   маил_, _wulg, мунэ_, _spеk, 
   {{0xdb080221,0x6b8005de,0xa2800240,0xe8f801f4}},	//   erfä, _tulg, ዓትናን_, фло_, 
   {{0x6b800381,0x00000000,0x00000000,0x00000000}},	//   _uulg, --, --, --, 
   {{0x25dc4688,0x00000000,0x00000000,0x00000000}},	//   गबली_, --, --, --, 
   {{0xb4cc6956,0x9aa400fb,0x00000000,0x00000000}},	//   रभू_, _рухһ, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x78bc041e,0x69d80175,0xdb0803b2,0xe2980220}},	//   órve, _hpwe, tufø, _ﺘﻘﻭﻡ_, 
   {{0x93406957,0x9f48011f,0x00000000,0x00000000}},	//   ансе, _orbá_, --, --, 
   {{0x21a46958,0x5bac1d8a,0x60e84a1a,0x56e001ec}},	// [77c0] тизм, _टि्व, ммам_, _тұяғ, 
   {{0x69d802ce,0x7c2400df,0x6b7000cd,0x00000000}},	//   _mpwe, ŝiri, _vāgy, --, 
   {{0x60dc6959,0xdee40fbe,0x232801d5,0x9f500419}},	//   repm, кожи, _жони_, ždíc_, 
   {{0x69d8695a,0x672001ad,0x60dc695b,0x61e40b97}},	//   _opwe, मसिक_, sepm, _tskl, 
   {{0xcf1801d9,0x81bc00fe,0x00000000,0x00000000}},	//   برٕچ_, _আনক_, --, --, 
   {{0x6144695c,0x8d6068eb,0x41a8030d,0x00000000}},	//   _рега, авче, ăвĕн_, --, 
   {{0x69d81d59,0x8fa0695d,0xdd9062ac,0x0ba0695e}},	//   _apwe, _васе, _چور_, ашым, 
   {{0xdd900acb,0x9f4800f7,0xa6e01d1d,0x1ea83cc6}},	//   _نور_, _urbà_, _áðha, _زاري_, 
   {{0x99641996,0xcb641f5a,0x00000000,0x00000000}},	//   ктол, њање_, --, --, 
   {{0xd83805f5,0x3104255c,0xd90c020e,0x7798004e}},	//   дэм_, रायः_, تیت_, нкор_, 
   {{0x69d80086,0xdb080332,0x09005b0f,0x00000000}},	//   _epwe, únór, рчым, --, 
   {{0x6d5c695f,0x7c940023,0x00000000,0x00000000}},	//   _īsai, _ዚበሃል_, --, --, 
   {{0x7ae06960,0x964459e6,0x6f9801ec,0x310400cd}},	//   memt, тэнд, _ﺇﻨﻤﺎ_, रामः_, 
   {{0x7ae06961,0x3ea400de,0x00000000,0x00000000}},	//   lemt, _lemt_, --, --, 
   {{0x78a86962,0xd3786963,0x00000000,0x00000000}},	//   madv, дча_, --, --, 
   {{0x3ea46964,0x7ae06965,0x1ce0025c,0x0854011a}},	//   _nemt_, nemt, _ཧྲལ_, _שבהם_, 
   {{0x614423f6,0x3cec0165,0x518408ca,0x200c1196}},	// [77d0] گىلە, _oadv_, туба, äfin_, 
   {{0x78a86966,0xdbdc0077,0x61e0004e,0x93886967}},	//   nadv, _líña, çola, _осма_, 
   {{0x61444da8,0xeeb8013d,0xc3e401ee,0x00000000}},	//   دىلە, елеш_, _көтһ, --, 
   {{0x63b801f1,0x7ae003cd,0xa36803e3,0x00000000}},	//   átne, jemt, _osеy, --, 
   {{0x78a86968,0x7de400db,0x27200321,0x74140150}},	//   kadv, لسوم, _jóna_, _شوڭا, 
   {{0x63b810bf,0x31340a5b,0x272000ae,0xdca013b5}},	//   štne, _сегр, _móna_, баши, 
   {{0x4ea46969,0xdcac2928,0x78a86365,0x272001e1}},	//   _арза, سىي_, dadv, _lóna_, 
   {{0x3ea4037e,0xb92801fb,0x7ae0009f,0x78a801f5}},	//   _gemt_, _thuở_, gemt, eadv, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x78a8696a,0xb4cc07b7,0x645829ef,0x1ce00327}},	//   gadv, रभो_, ütik, _ཧིར_, 
   {{0xec14179c,0xe738696b,0xc1d02cbc,0x7ae00b6f}},	//   _حواد, еен_, _सङ्ग, bemt, 
   {{0x2ca40c30,0x272002d2,0x00000000,0x00000000}},	//   _held_, _bóna_, --, --, 
   {{0x69d8696c,0x78a82959,0x2ca4696d,0xe7380166}},	//   _upwe, badv, _keld_, _җеп_, 
   {{0x27200228,0x2eec0bed,0x2ca4002d,0x5e5400c8}},	//   _dóna_, _laef_, _jeld_, רישע_, 
   {{0x2ca4696e,0x1ae4015b,0x1ce00327,0xe738074d}},	//   _meld_, কারে_, _ཧིལ_, _пек_, 
   {{0x2eec1509,0x68e0696f,0x2730151c,0x49180316}},	//   _naef_, leld, kšni_, यसको_, 
   {{0x62640cfc,0xdbdc0321,0x3ea401a4,0x64a4010b}},	// [77e0] уваа, _líða, _remt_, _йапа, 
   {{0x68e06970,0x3ea40790,0x201c6971,0x00000000}},	//   neld, _semt_, _ütik_, --, 
   {{0x2eec54ef,0x657c00f1,0x272003f7,0x7ae00a29}},	//   _baef_, _iiph, _zóna_, yemt, 
   {{0x68e06972,0x78a86973,0x657c4c28,0x00000000}},	//   held, zadv, _hiph, --, 
   {{0x6aa86974,0x2eec0036,0x4dd000c6,0x3cec01e4}},	//   daef, _daef_, متوس, _padv_, 
   {{0x68e06975,0x657c0477,0xdbdc06ea,0x2eec0009}},	//   jeld, _jiph, _bíða, _eaef_, 
   {{0x7ae06976,0x2eec08cd,0x68e06977,0x9a8400d1}},	//   temt, _faef_, deld, лупл, 
   {{0x657c6978,0x645c0036,0x6aa86979,0x78a8697a}},	//   _liph, _mypi, gaef, wadv, 
   {{0x68e0697b,0x78a8002b,0x2ca404ef,0xdb08697c}},	//   feld, tadv, _feld_, nsfé, 
   {{0x2ca40b5f,0x7ae0697d,0x657c4b26,0x2138037e}},	//   _geld_, semt, _niph, niph_, 
   {{0x78a8697e,0xdbdc0005,0xb6f80075,0xd7f800c7}},	//   radv, _tíña, نىدا_, хуп_, 
   {{0x657c01e4,0x2c10012c,0x7ae0014f,0x6aa803e0}},	//   _aiph, तहरू_, qemt, caef, 
   {{0x645c0309,0x2ca40204,0x1ce0031c,0x657c50eb}},	//   _aypi, _yeld_, _ཧྲོ_, _biph, 
   {{0x657c697f,0x272006ea,0x37c400d1,0x645c01bf}},	//   _ciph, _vóna_, _кәмб, _bypi, 
   {{0x657c6980,0x645c3f05,0x93400116,0x00000000}},	//   _diph, _cypi, مىسۇ, --, 
   {{0x657c01c3,0x272003f2,0xdb0803b2,0x83840150}},	//   _eiph, _tóna_, mufó, сыре, 
   {{0x21380129,0xdb081427,0xdce000d7,0x00000000}},	// [77f0] fiph_, lufó, dpoľ, --, 
   {{0x657c6981,0x73341e87,0xc2740114,0x9a400051}},	//   _giph, _چىدا, слуј, _đằn, 
   {{0x776c6982,0x1ce0025c,0xdb08022c,0x2ca40af9}},	//   _khax, _ཧྲེ_, nufó, _reld_, 
   {{0x657c4b5d,0xcee81129,0x2ca40a6c,0x68e06983}},	//   _ziph, عران_, _seld_, zeld, 
   {{0xdbdc6984,0x657c6985,0x2eec6986,0x776c01ab}},	//   _síða, _yiph, _vaef_, _mhax, 
   {{0x657c06e4,0x2eec1028,0x68e0010a,0x273028b5}},	//   _xiph, _waef_, xeld, ršni_, 
   {{0x68e06987,0x2ca40e29,0xab280b3b,0xdb0803f2}},	//   veld, _veld_, кока_, jufó, 
   {{0xe9d86988,0x2ca40cfd,0x68e02e6c,0xdbdc2880}},	//   вки_, _weld_, weld, _víða, 
   {{0x6aa86989,0x68e0698a,0xaa44230c,0xa924698b}},	//   raef, teld, репл, идил, 
   {{0xdbdc2880,0x6aa80421,0x68e00af9,0xbdf80035}},	//   _tíða, saef, ueld, _حرفا_, 
   {{0x68e0698c,0x657c07a9,0x764c011f,0x6aa80174}},	//   reld, _riph, _axay, paef, 
   {{0x657c4ec2,0x68e0698d,0x645c698e,0x776c0113}},	//   _siph, seld, _rypi, _chax, 
   {{0x7b742cb0,0xa9a43775,0x776c0050,0x68e0698f}},	//   _اطلا, _тилд, _dhax, peld, 
   {{0xdb0803fa,0x645c0af9,0x657c0477,0x68e0016d}},	//   zufü, _pypi, _qiph, qeld, 
   {{0x23346990,0x32080009,0x657c6991,0x66000153}},	//   ахар, exay_, _viph, _šokd, 
   {{0x657c6992,0x645c0122,0x776c025c,0x673405d6}},	//   _wiph, _vypi, _ghax, _umyj, 
  
   {{0x657c6993,0x645c0034,0x09d00183,0x320802d0}},	// [7800] _tiph, _wypi, ়িকা, gxay_, 
   {{0x201802d3,0x6b04025c,0x910000c7,0x00000000}},	//   typi_, _མོའོ_, опуе, --, 
   {{0x645c0784,0xa34800d1,0x3208058a,0x21380129}},	//   _uypi, _азна_, axay_, riph_, 
   {{0x33280bc9,0xa6e0008c,0x776c6994,0x20180113}},	//   chax_, áðhe, _xhax, rypi_, 
   {{0x1d0800ee,0x320803ac,0xa04815bf,0x00000000}},	//   кеди_, cxay_, ركچە_, --, 
   {{0xd5f4008f,0xdce000d7,0x8d70009a,0x00000000}},	//   יזנט_, spoľ, ياوا, --, 
   {{0xdee44f53,0xd0046995,0x50d80a7c,0x9f7801af}},	//   _кови, _кере_, _שקלא, _асаф_, 
   {{0xdb0806ea,0x00000000,0x00000000,0x00000000}},	//   vufó, --, --, --, 
   {{0x776c0564,0x26c41574,0xd90400d4,0x6abc01e7}},	//   _rhax, _ñooy_, аїно, ósfa, 
   {{0x776c006c,0xb4e40073,0xdb080174,0x00000000}},	//   _shax, _नसे_, tufó, --, 
   {{0x776c094a,0x80d80882,0x5ac800ee,0x00000000}},	//   _phax, न्ये, _алем_, --, 
   {{0x7e60023a,0x3328011f,0x00000000,0x00000000}},	//   _kymp, xhax_, --, --, 
   {{0xb9940597,0x32082a2d,0x7e60007c,0xd94400d8}},	//   _التب, xxay_, _jymp, _кеди, 
   {{0xca68022e,0x7e600042,0xb4c0012c,0x049400b8}},	//   _ilgа, _mymp, ँले_, _kāṭh, 
   {{0x7e606996,0x92a46997,0x1768010b,0x776c01ab}},	//   _lymp, ијал, _ирип_, _thax, 
   {{0x04940055,0x66d400ec,0xc7900244,0x660001ef}},	//   _māṭh, _هيٺئ, _بشوب, _šoke, 
   {{0x7e606998,0x9f8c0037,0x32080009,0x6ed80a8a}},	// [7810] _nymp, _mõõt_, uxay_, फ्फु, 
   {{0x2b480552,0x32086999,0x33280014,0x01d8015b}},	//   čaci_, rxay_, shax_, সিংদ, 
   {{0x93e407d6,0x0574699a,0x3328003a,0xc3300014}},	//   _тўпл, _بايد, phax_, سٕے_, 
   {{0x92680323,0xef180003,0xeb98016c,0x7e600142}},	//   _арга_, _biża_, қии_, _bymp, 
   {{0x7e60020c,0x733400d1,0x518400d8,0xda6401f7}},	//   _cymp, _نىگا, _њума, _ءُ_, 
   {{0x7e600042,0x3338000d,0x69bc01f9,0x00000000}},	//   _dymp, _hmsx_, _शिबी, --, 
   {{0x16a4012d,0x00000000,0x00000000,0x00000000}},	//   _ख़ूब, --, --, --, 
   {{0x9504031c,0x7e600042,0x00000000,0x00000000}},	//   _ཅོའི_, _fymp, --, --, 
   {{0x3d943a61,0x7e60699b,0xef180327,0xa30802dd}},	//   _митр, _gymp, _giża_, _لﺎﺒ_, 
   {{0xada401e0,0x779000e5,0xa9240108,0x00000000}},	//   _ваҡл, ڈیوا, сдол, --, 
   {{0x1ce00135,0x00000000,0x00000000,0x00000000}},	//   _ཧྲི_, --, --, --, 
   {{0x394400f7,0x61f401f4,0x00000000,0x00000000}},	//   йнөг, yvyl, --, --, 
   {{0xa36801a9,0x80d81b51,0x2bac000d,0xb7b400cf}},	//   _opеr, न्डे, _घबडा, бөөч, 
   {{0x395c05be,0xe7380022,0x272000d7,0x692400fb}},	//   _gkvs_, _әеи_, _tóno_, _ымла, 
   {{0x64a4699c,0x232821ca,0x9fb000eb,0xb6440092}},	//   _қана, гови_, _টঙ্গ, _የዕውቀ, 
   {{0x6d5c0008,0xdb085522,0x3eb80171,0x00000000}},	//   _ísaf, urfø, _ērto_, --, 
   {{0xe1f8699d,0xe0d8699e,0xdcf80100,0xdb080158}},	// [7820] ыга_, лва_, _sitč, rrfø, 
   {{0x7e6006a3,0xa0a4241e,0x614400d4,0x2bf86766}},	//   _rymp, сажд, щеза, ्मां_, 
   {{0x3f5c02d2,0x00000000,0x00000000,0x00000000}},	//   díur_, --, --, --, 
   {{0xdcf80100,0x7e6023b5,0x9ea801b9,0xd5ac0244}},	//   _vitč, _pymp, увда_, _تفی_, 
   {{0x62840589,0xdcb00952,0xaabc012c,0x00000000}},	//   _igko, كىش_, ोलनक, --, 
   {{0xef180135,0x049400dc,0x5ba4022e,0xdb2008a5}},	//   _viża_, _pāṭh, бриз, _úrúg, 
   {{0x5574010f,0xfc3c0023,0x00000000,0x00000000}},	//   זעסן_, _ክቕጽል, --, --, 
   {{0x7e60699f,0xfe780117,0x00000000,0x00000000}},	//   _tymp, _кӯл_, --, --, 
   {{0x80d80b98,0xdd9000ae,0x00000000,0x00000000}},	//   न्थे, _روض_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x1ce0025c,0xdb0803b2,0x00000000,0x00000000}},	//   _ཧྲག_, lsfí, --, --, 
   {{0x2bdc69a0,0x6284020c,0x80d80882,0x907800df}},	//   _महता, _ngko, न्ते, טטיי, 
   {{0xdb080077,0x45d4022e,0x00000000,0x00000000}},	//   nsfí, пояс, --, --, 
   {{0x3f98005f,0x80d80412,0x00000000,0x00000000}},	//   _otru_, _नॉले, --, --, 
   {{0x3cf0033f,0xb994009f,0x00000000,0x00000000}},	//   _इसने_, _الڪب, --, --, 
   {{0x1fcc00bd,0xe7943253,0x1ae40154,0x534469a1}},	//   রবাস, _باوک, কাকে_, ёхва, 
   {{0xb1140c17,0xf4842421,0x1164006c,0x26080073}},	// [7830] омаш, _وادی, ملری_, ामणी_, 
   {{0xdb180139,0x63c403b2,0x00000000,0x00000000}},	//   _aqtü, ðunø, --, --, 
   {{0x3f981529,0x80d800cd,0x00000000,0x00000000}},	//   _ctru_, न्धे, --, --, 
   {{0xd34401b9,0x00000000,0x00000000,0x00000000}},	//   _ایره_, --, --, --, 
   {{0x1ce00135,0xe1ec0451,0xdd8c00e5,0x81640133}},	//   _ཧྲང_, _لڳل_, نڈل_, _کۆلۆ, 
   {{0x2d8003fa,0x80d80a5a,0xeb98151e,0x0ca801a9}},	//   öhe_, न्दे, аик_, утди_, 
   {{0x9b9069a2,0x9d50007b,0x00000000,0x00000000}},	//   ولوت, بنوت, --, --, 
   {{0x4ea429a3,0x705808ca,0xfc3c0023,0x00000000}},	//   _ырга, _баҳр_, _ክንጽል, --, 
   {{0x09c004c5,0x49003baf,0x0dc8399f,0xae44431a}},	//   ্বভা, зүлг, _љуби_, _بھاو, 
   {{0x3f980162,0x68441d39,0x00000000,0x00000000}},	//   _ytru_, жноа, --, --, 
   {{0x317001bf,0x49c001d3,0x60d8062d,0x00000000}},	//   _mhzz_, _کےخل, _ötme, --, 
   {{0xdb080356,0x8c34014b,0x00000000,0x00000000}},	//   asfâ, _коҷӣ_, --, --, 
   {{0xdcf800dc,0x3cf0033f,0xa3bc3885,0x00000000}},	//   _hitā, _इसमे_, ुंभ_, --, 
   {{0x63b81d55,0x2b480e04,0x00000000,0x00000000}},	//   átno, čacu_, --, --, 
   {{0xa87800c8,0xdcf800cd,0x6754007b,0x00000000}},	//   _דאַר, _jitā, _وخبر, --, 
   {{0xe29869a3,0x47f00323,0x63b80306,0xdcf8002b}},	//   раа_, _дүүр, štno, _mitā, 
   {{0x3f9801a6,0x00000000,0x00000000,0x00000000}},	// [7840] _stru_, --, --, --, 
   {{0xe04469a4,0x64c4009f,0x00000000,0x00000000}},	//   онзи, _بيدل, --, --, 
   {{0xdfe8013e,0x2d7c00a2,0xefd40023,0x1ea8131e}},	//   рдед_, _eňek_, _ረኣየ_, لاشي_, 
   {{0x9e644834,0x1ce00dd4,0xdb0801e3,0x62f80354}},	//   овед, _ཧིང_, lufö, _темă, 
   {{0xdcf868de,0x00000000,0x00000000,0x00000000}},	//   _aitā, --, --, --, 
   {{0xae700131,0xd65402e4,0xdcf800ef,0x00000000}},	//   رۇلغ, חינת_, _bitā, --, 
   {{0xdcf800da,0xdfd005d9,0xbe840032,0x3f9869a5}},	//   _citā, _تيز_, _еңел, _utru_, 
   {{0xdd9069a6,0xe2a403b2,0x00000000,0x00000000}},	//   _يوز_, áðha_, --, --, 
   {{0x1cd80156,0x6ab8015d,0xf8b80137,0x88c00882}},	//   འབད_, _ddwf, бөй_, _āśra, 
   {{0x3f840ba7,0x38340452,0x00000000,0x00000000}},	//   _himu_, знор, --, --, 
   {{0x3f8469a7,0x98bc0356,0x00000000,0x00000000}},	//   _kimu_, entă_, --, --, 
   {{0x3f840198,0x00000000,0x00000000,0x00000000}},	//   _jimu_, --, --, --, 
   {{0xceb00302,0x3f840ca8,0x00000000,0x00000000}},	//   ויר_, _mimu_, --, --, 
   {{0x3f8469a8,0xdb0869a9,0x00000000,0x00000000}},	//   _limu_, hrfü, --, --, 
   {{0xe8e8004b,0x13f41f13,0x2720002e,0x938869aa}},	//   _درنو_, ुमेह_, _xónk_, рсга_, 
   {{0x3f8469ab,0x249c510c,0x80d828a2,0x926835c9}},	//   _nimu_, ıtma_, न्से, арза_, 
   {{0x948469ac,0x81d401f0,0xefd40023,0x00000000}},	// [7850] _мынд, мотх, _ረኣዮ_, --, 
   {{0xecc81d8a,0x3f840037,0xdb080175,0x25a4010e}},	//   _राइफ, _aimu_, erfü, _çola_, 
   {{0x3f8469ad,0xbe9802e3,0x00000000,0x00000000}},	//   _bimu_, _ịhụr, --, --, 
   {{0x3f84208d,0x5edc0eac,0x00000000,0x00000000}},	//   _cimu_, _নোবে, --, --, 
   {{0x6da469ae,0x80d869af,0x3f8469b0,0xd20801c0}},	//   чила, न्हे, _dimu_, _тэнд_, 
   {{0xdd8c5845,0xb1280050,0x2a680135,0x6ab80042}},	//   دوو_, _آسن_, _ġab_, _sdwf, 
   {{0x3f841bce,0x8f080408,0x637401e1,0x00000000}},	//   _fimu_, _кхаа_, _ẹnip, --, 
   {{0x3f84384e,0xeab0007b,0xdcf819ae,0x00000000}},	//   _gimu_, رعب_, _vitā, --, 
   {{0x7b1c07ea,0xf6e8031c,0x80d829d9,0x00000000}},	//   _réut, _ཧྲེང, न्वे, --, 
   {{0xdcf80171,0x00000000,0x00000000,0x00000000}},	//   _titā, --, --, --, 
   {{0x2d8402e3,0x3f8400e8,0x3fb400d1,0xb0dc00cd}},	//   _iile_, _yimu_, ﭽﻘﺎﻧ, न्यग, 
   {{0x2d8c0069,0x7b1c0077,0xe55469b1,0x272000e4}},	//   _kuee_, _déus, _اﷲ_, _kóni_, 
   {{0x2d8469b2,0x272069b3,0x2b900208,0x00000000}},	//   _kile_, _jóni_, _hác_, --, 
   {{0x69c80085,0x2d8469b4,0xa7b400f3,0x06a00116}},	//   muee, _jile_, _есиј, _ﺋﯩﻨﯩ, 
   {{0x69c869b5,0x2d8469b6,0x27203d64,0xdb08007c}},	//   luee, _mile_, _lóni_, rufö, 
   {{0x2d8469b7,0x2b9001fb,0xc0f00023,0x00000000}},	//   _lile_, _mác_, _ቀቢላ_, --, 
   {{0x26d0685c,0x69c80373,0x2d8469b8,0x2b90004d}},	// [7860] _icyo_, nuee, _oile_, _lác_, 
   {{0x3f8469b9,0x00e40214,0x2d842f41,0xa3bc01f9}},	//   _simu_, بتری, _nile_, ुंद_, 
   {{0x2d8c0418,0xfa140156,0x6ee001f2,0x7520002f}},	//   _auee_, ིདོན_, _ịbaw, ölze, 
   {{0x2d8469ba,0x2d8c016b,0xa11469bb,0x69c869bc}},	//   _aile_, _buee_, _کوست, kuee, 
   {{0x2d841917,0x5dd869bd,0x3f8403b2,0x5e58007b}},	//   _bile_, сфер_, _vimu_, حجاج_, 
   {{0x2b9007ae,0x2d8469be,0x6294003a,0x69c80af9}},	//   _bác_, _cile_, lcyo, duee, 
   {{0x2b90431d,0x3f8469bf,0x2d8469c0,0x6e4406be}},	//   _các_, _timu_, _dile_, _ərbə, 
   {{0x2d8469c1,0xb99810f5,0x7b1c0231,0x93f80302}},	//   _eile_, ових_, _réus, מלצי, 
   {{0x2d8469c2,0x2d8c0363,0xdcf80356,0xbe3400cf}},	//   _file_, _guee_, _cită, _تۉشب, 
   {{0x2d8469c3,0x26d000ca,0xe9702002,0x69bc1df0}},	//   _gile_, _acyo_, نۇند, _शिरी, 
   {{0x7d0869c4,0x69c80270,0x2b9001fb,0x00000000}},	//   _inds, auee, _gác_, --, 
   {{0x2d8469c5,0x69c801a4,0x75d4009a,0x00000000}},	//   _zile_, buee, ويجا, --, 
   {{0x69c869c6,0x2d8469c7,0x98bc00c0,0x00000000}},	//   cuee, _yile_, entą_, --, 
   {{0x2d8469c8,0xa9c401ec,0x05840114,0x497000d4}},	//   _xile_, _ісік, еусм, _зліс, 
   {{0x2b9007ae,0x7bd80254,0x00000000,0x00000000}},	//   _xác_, ntvu, --, --, 
   {{0x86c45f32,0x00000000,0x00000000,0x00000000}},	//   _كيىن, --, --, --, 
   {{0x7d0869c9,0x394c0204,0x381401d9,0x166400cf}},	// [7870] _onds, onds_, _رژھر, _رەسپ_, 
   {{0x394c0493,0x7bd8003b,0x272002d2,0x00000000}},	//   nnds_, ktvu, _róni_, --, 
   {{0x2d8469ca,0x3374255b,0x06b0009e,0xdb0812e8}},	//   _rile_, _огор, _কাতি, msfæ, 
   {{0x2d840cad,0x7d0869cb,0x2b900016,0x7bd801bf}},	//   _sile_, _ands, _rác_, dtvu, 
   {{0x2d8c0204,0x69c801a4,0x3ea01891,0xff50084e}},	//   _quee_, xuee, ñita_, دخل_, 
   {{0x5c6c044e,0x2b903a59,0x644c0219,0x06a00131}},	//   _ትሕዝቶ_, _pác_, šniš, _ﺋﯩﻠﯩ, 
   {{0x2d8469cc,0x672469cd,0x96bc3b16,0x286400b8}},	//   _vile_, ykkj, ्लाउ, _uḍḍī, 
   {{0x7d0869ce,0x2d8469cf,0x69c869d0,0x394c69d1}},	//   _ends, _wile_, tuee, ends_, 
   {{0xedd469d2,0x6f0869d3,0x2d8469d4,0xa2bc00cd}},	//   _زياد, _inec, _tile_, षणत्, 
   {{0x2b9001dc,0x2d840ea3,0x7d080998,0x660056ce}},	//   _tác_, _uile_, _gnds, _šoko, 
   {{0x6f0869d5,0x69c869d6,0xdb0801bf,0x4b040064}},	//   _knec, suee, dsfæ, _нядб, 
   {{0x394c0129,0xfb840024,0xfaa849f4,0x00000000}},	//   ands_, _зычн, _فهمي_, --, 
   {{0x69c869d7,0xdcf80311,0x28f807d9,0x06b000eb}},	//   quee, _uită, _медь_, _কাদি, 
   {{0x240869d8,0x672433b8,0x95800024,0xdb0869d9}},	//   онги_, skkj, кляе, gsfæ, 
   {{0x3cf0068f,0x6f0869da,0xc86469db,0x47e4025c}},	//   _इससे_, _onec, _этди, _འགྲམ, 
   {{0x2b4c69dc,0x1ce00135,0xdee80f7c,0x63a001a6}},	//   nnec_, _ཧྲན_, መትን_, _čond, 
   {{0x2b4c0165,0xaad400bc,0xb8080137,0x14d869dd}},	// [7880] inec_, _धानक, _ويۇم_, म्हण, 
   {{0x2b4c05d5,0xdcf80024,0x9c800f91,0x00000000}},	//   hnec_, _kitą, íčka, --, 
   {{0xdb08044e,0x00000000,0x00000000,0x00000000}},	//   ënës, --, --, --, 
   {{0x3f9c005f,0x257401bf,0x6b8c01e4,0x6ed800bc}},	//   īvu_, fælg_, ĉagl, फ्लु, 
   {{0xb900025c,0x6f08012c,0x4dd0178c,0x00000000}},	//   _སྡ_, _dnec, نتوس, --, 
   {{0xb0dc69de,0x7bd80212,0xa2c429c7,0x25a40327}},	//   न्दग, ttvu, िलक्, _ħoll_, 
   {{0x69c400b0,0x660000c0,0x00000000,0x00000000}},	//   _āhea, _šokl, --, --, 
   {{0x6130005c,0x7bd80fac,0xdee432f7,0x394c025c}},	//   _bælg, rtvu, _تأسي, wnds_, 
   {{0x7bd869df,0x6130022c,0xf8b800f7,0x998000bc}},	//   stvu, _vælf, пөй_, áků_, 
   {{0x7d0869e0,0x394c69e1,0xb8140f5c,0x6f080306}},	//   _unds, unds_, едој, _znec, 
   {{0x36d4013e,0x998000bc,0x6f0803ac,0xd7f800c7}},	//   нонр, šků_, _ynec, цуп_, 
   {{0x61305266,0x00000000,0x00000000,0x00000000}},	//   _fælg, --, --, --, 
   {{0x6130037e,0xaac4007b,0x98bc02e2,0xdb08005c}},	//   _kæld, _أتمن, litč_, tsfæ, 
   {{0xb7880510,0x24640b82,0x257401bf,0xe79401d3}},	//   _нәме_, _ጳዉሎስ_, jæld_, بایک, 
   {{0x1ce00003,0x61e402d5,0x613001a8,0x98bc0100}},	//   _ཧིན_, _apkl, _mæld, nitč_, 
   {{0x98bc00b0,0xdbf0013d,0x0744074d,0x00000000}},	//   kotī_, _eşçe, _ахьм, --, 
   {{0x838411ed,0x249805da,0x349469e2,0x32542bb6}},	// [7890] тыре, _ffpm_, _папр, хвар, 
   {{0x6f080493,0x2574005c,0x0fe00137,0x61300388}},	//   _snec, gæld_, көбү, _næld, 
   {{0xa3d435e8,0x50640364,0x00000000,0x00000000}},	//   _समय_, фтаа, --, --, 
   {{0xdb0869e3,0x64580129,0x00000000,0x00000000}},	//   nsfä, ûtie, --, --, 
   {{0xf48414c3,0x9f48004e,0x6f08004d,0x613002d2}},	//   _تاکی, _arbó_, _vnec, _bæld, 
   {{0xdb08002f,0x00000000,0x00000000,0x00000000}},	//   hsfä, --, --, --, 
   {{0x613069e4,0x27200306,0x25a40135,0x3a20031c}},	//   _sælg, _zónu_, _ħolm_, _żipp_, 
   {{0x6f08289d,0x33280227,0x63b869e5,0x6e9800d8}},	//   _unec, nkax_, átni, _хвар_, 
   {{0x1ce00156,0x6130037e,0x69240816,0xa9243667}},	//   _ཧྲམ_, _fæld, емпа, едпл, 
   {{0x6130019b,0x63b8151c,0x09c000cc,0xbe8801ec}},	//   _vælg, štni, ্বলা, _істе_, 
   {{0x6d4069e6,0x25a00ac5,0x00000000,0x00000000}},	//   _imla, wpkl_, --, --, 
   {{0xe73069e7,0xef180327,0xdb085b00,0x00000000}},	//   اصد_, _biżi_, gsfä, --, 
   {{0x61300627,0xa2bc00cd,0x8cc01546,0x2a0801f4}},	//   _hæle, षणस्, रणपो, _хелп_, 
   {{0x69d8009a,0x6130037e,0xba740814,0x29d80ba1}},	//   _iqwe, _kæle, _شانت, mèa_, 
   {{0x18640d6f,0x257469e8,0x29d80ba1,0xa2e401b9}},	//   _паши_, jæle_, lèa_, новд, 
   {{0xd3841cd6,0x141400c6,0xe2840166,0x00000000}},	//   ейсе_, ريقة_, елби, --, 
   {{0x6460068f,0xf1d463f5,0x29d81497,0x98bc007f}},	// [78a0] _świę, көрө, nèa_, zitč_, 
   {{0x22940248,0x00000000,0x00000000,0x00000000}},	//   _bùkó_, --, --, --, 
   {{0x205469e9,0x3ea009c2,0x14d4008f,0xa0a40116}},	//   хтар, ñito_, _אויל_, _җабд, 
   {{0x272069ea,0x4438010a,0x307400f7,0x98bc0100}},	//   _ións_, mzr_, туус, vitč_, 
   {{0x6130032e,0x257403b2,0x63b00118,0x00000000}},	//   _pæld, pæld_, šeně, --, 
   {{0x29d80ba1,0x98bc69eb,0x33700023,0x628801e4}},	//   dèa_, rotī_, _በብሓደ_, ĝloĝ, 
   {{0x69d80113,0x613069ec,0x272001a8,0x3a240142}},	//   _aqwe, _cæle, _jóns_, wymp_, 
   {{0x6d404903,0x2720004e,0x6130005c,0x6d5c03b2}},	//   _emla, _móns_, _dæle, _ísan, 
   {{0x98bc007f,0x7fe000bc,0x613002d2,0x38c8179e}},	//   sitč_, _नहुँ, _tæld, وادی_, 
   {{0x779869ed,0xe8f8010a,0x00000000,0x00000000}},	//   мкор_, çли_, --, --, 
   {{0x59c01b57,0xdb083468,0x00000000,0x00000000}},	//   _शिवर, tsfä, --, --, 
   {{0x29d8067c,0xd6d8023a,0xebc00116,0xd5140241}},	//   bèa_, что_, _тәшн, _ọ̀o, 
   {{0x6d400cfd,0x69d85693,0x29d80ba1,0xdb0801e3}},	//   _ymla, _gqwe, cèa_, rsfä, 
   {{0xdb0869ee,0x8c400213,0xef18031c,0x8cc000dc}},	//   ssfä, şşen, _viżi_, रणयो, 
   {{0x06b0015b,0xdb08007c,0x00000000,0x00000000}},	//   _কারি, psfä, --, --, 
   {{0x07f469ef,0x2b080034,0x52c8012c,0x00000000}},	//   _أروع_, वाएँ_, िलेस, --, 
   {{0x33280054,0x00000000,0x00000000,0x00000000}},	// [78b0] rkax_, --, --, --, 
   {{0x33280014,0x00000000,0x00000000,0x00000000}},	//   skax_, --, --, --, 
   {{0x853c0302,0xbfa80484,0x53780092,0x00000000}},	//   _מגזי, етче_, _በጥይት_, --, 
   {{0x6d4069f0,0x932400ae,0x00000000,0x00000000}},	//   _smla, _أردن, --, --, 
   {{0x7ed469f1,0x25740158,0x613021e3,0x999000a2}},	//   ازما, sæle_, _sæle, _çyň_, 
   {{0x8d74594c,0xf0e80150,0x6130005c,0x2574005c}},	//   راشا, _تىسى_, _pæle, pæle_, 
   {{0x41540063,0x49600116,0xdca00108,0x00000000}},	//   _сврс, һниң, шащи, --, 
   {{0x7534003e,0x29d8067c,0xca7402dd,0x613006ea}},	//   hhzz, tèa_, нәлі_, _væle, 
   {{0x5c701f0e,0x2adc00e0,0x2bdc07f7,0x00000000}},	//   лләт, क्षु_, _महका, --, 
   {{0x6d40124c,0xa8041faf,0x29d8180f,0x6130032e}},	//   _umla, взол, rèa_, _tæle, 
   {{0xec1469f2,0x7534003e,0x29d80561,0xc0d00023}},	//   _جواد, dhzz, sèa_, _ብትሪ_, 
   {{0x6378025a,0x29d81497,0xca740116,0x66000a87}},	//   mïng, pèa_, _كاشغ, _áokk, 
   {{0x6aa8004b,0x69d8401f,0x00000000,0x00000000}},	//   mbef, _uqwe, --, --, 
   {{0xbb44023a,0x69c80009,0x00000000,0x00000000}},	//   äävä, mree, --, --, 
   {{0x442c00c6,0x69c80549,0xe29801b9,0xd46469f3}},	//   ád_, lree, даб_, вире_, 
   {{0x69c869f4,0x6aa869f5,0x98bc0882,0x6378000f}},	//   oree, nbef, mitā_, iïng, 
   {{0x69c869f6,0x00000000,0x00000000,0x00000000}},	// [78c0] nree, --, --, --, 
   {{0x91e0035b,0x69c869f7,0x98bc00e4,0x00000000}},	//   рофе, iree, totĩ_, --, 
   {{0x69c80460,0xdfd0007b,0xdef8004e,0x61e00003}},	//   hree, شيش_, дыл_, ħolq, 
   {{0x69c869f8,0xd00c0c8b,0x656c01e7,0x98bc035b}},	//   kree, تلم_, llbh, rotĩ_, 
   {{0xdcb069f9,0x98bc0882,0x61300162,0x6aa8005c}},	//   لىش_, hitā_, _vælb, dbef, 
   {{0x69c869fa,0xa3d44de3,0x98bc00c7,0x6d5c032e}},	//   dree, _समा_, potĩ_, _ísal, 
   {{0x6378025a,0x656c0e9e,0x6aa8002f,0x00000000}},	//   gïng, ilbh, fbef, --, 
   {{0x6aa869fb,0x9a841b04,0xac240006,0x00000000}},	//   gbef, купл, ыфік, --, 
   {{0xb9840046,0x69c869fc,0xd8c8084c,0x9e640345}},	//   лтоқ, gree, мынд_, _شارن, 
   {{0x63782776,0x3914384f,0xdb080306,0xba040137}},	//   bïng, умор, nsfú, _ۅستۉ, 
   {{0x69c81986,0x497001c0,0x6aa80217,0xed34009d}},	//   aree, рлэс, bbef, _сэтэ, 
   {{0x69c869fd,0x16bc0034,0x3d1001f9,0x00000000}},	//   bree, ्लेब, ढावे_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x059801ec,0x00000000,0x00000000,0x00000000}},	//   _ﻛﻮﺷﭙ, --, --, --, 
   {{0xb820015b,0xd7f8074d,0x98bc00cd,0x80cc0210}},	//   _ফেরত_, _цул_, citā_, ालैं, 
   {{0x656c0fa3,0x11640517,0x36d401f0,0x00000000}},	//   albh, چلری_, _соир, --, 
   {{0x6378025a,0x116407d6,0xb27400fb,0x883400e2}},	// [78d0] zïng, نلری_, улаш, ģēša, 
   {{0xcb40022e,0xf10400cf,0x644c00e5,0x00000000}},	//   munх, دۉسۉ_, ániá, --, 
   {{0x273000d7,0x28c00116,0x00000000,0x00000000}},	//   ešny_, _ﻣﯘﺳﻠ, --, --, 
   {{0x660069fe,0x69c869ff,0xd9f02c35,0xdb08002d}},	//   _šoki, yree, _अनंत_, rsfû, 
   {{0xd1c801c6,0x00000000,0x00000000,0x00000000}},	//   _юунд_, --, --, --, 
   {{0x69c86a00,0x6378006a,0x00000000,0x00000000}},	//   vree, tïng, --, --, 
   {{0xcc100323,0x69c81bce,0x9ba00075,0x6d5c0321}},	//   рчлө, wree, مەلى, _ísam, 
   {{0x26dc013f,0xd12c00f1,0x00000000,0x00000000}},	//   ɑtow_, _اڅړ_, --, --, 
   {{0xc3340302,0x69c86a01,0x6aa86a02,0xccf40fc0}},	//   יוק_, uree, rbef, _ақл_, 
   {{0x69c86a03,0xe8f80b2c,0xdcf40311,0xb91002e3}},	//   rree, хло_, ăcăm, melụ_, 
   {{0x80d86a04,0x68446a05,0x69c86a06,0x64a40150}},	//   न्टे, унна, sree, ғаба, 
   {{0xe5a45562,0x69c86a07,0x61305be9,0x2574032e}},	//   лими, pree, _mæla, dæla_, 
   {{0x98bc1976,0xb910063f,0x26dc0034,0x00000000}},	//   sitā_, nelụ_, ęto_, --, 
   {{0x98a01ce0,0xdb0c014a,0x18a0010a,0x00000000}},	//   _лише, ödöl, _лашм, --, 
   {{0x63780024,0x00000000,0x00000000,0x00000000}},	//   есар_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9f5c6a08,0x2328013e,0x21a40c17,0x00000000}},	// [78e0] _été_, _ҷони_, уизм, --, 
   {{0x98bc084c,0x00000000,0x00000000,0x00000000}},	//   mită_, --, --, --, 
   {{0x98bc0276,0x25b000a9,0x23286a09,0x91e002dd}},	//   lită_, _hwyl_, _зони_, _қоре, 
   {{0xc3302dfc,0xb9e8001f,0x25b00af9,0x613002d2}},	//   _بەر_, _ኮፒ_, _kwyl_, _dæla, 
   {{0x98bc0276,0xdb0803cd,0x160403ce,0x00000000}},	//   nită_, msfø, शियर_, --, 
   {{0x614414a4,0x61300158,0xdb083619,0x00000000}},	//   _сега, _fæla, lsfø, --, 
   {{0x8fa06a0a,0x98bc054e,0x81e000cc,0x00000000}},	//   _гасе, hită_, থিও_, --, 
   {{0x3cf0006d,0x1ea82834,0xdd90009f,0xdb0805ac}},	//   _इसके_, _ساري_, _هور_, nsfø, 
   {{0xdca46a0b,0x98bc0356,0x61f4015d,0xf8b80124}},	//   _бази, jită_, nwyl, taĩ_, 
   {{0x98bc36a6,0xcc3000c7,0x80d80709,0x00000000}},	//   dită_, рхәы, न्चे, --, 
   {{0x5c546a0c,0x2c74040b,0xdb086a0d,0x8a146a0e}},	//   _стаф, _پیٹھ_, ksfø, نتیس_, 
   {{0x964401c0,0x9a6800c6,0x98bc054e,0x25740174}},	//   гэгд, _كمال_, fită_, væla_, 
   {{0xdb0839c2,0x98bc0356,0x6abc1d0e,0x00000000}},	//   dsfø, gită_, ðsfe, --, 
   {{0xb4c01152,0x25b0002d,0x260805f9,0x61f4015d}},	//   ुले_, _dwyl_, ामजी_, dwyl, 
   {{0x3cec0316,0x80d80316,0xd3781553,0xa3bc0490}},	//   _आउने_, न्छे, еча_, ुंग_, 
   {{0x98bc0276,0xdb08005c,0x61f40142,0xa3d421bd}},	//   bită_, gsfø, fwyl, _समर_, 
   {{0x98bc0276,0x61f46a0f,0xc6d400db,0x25b003cb}},	// [78f0] cită_, gwyl, _اتىت, _gwyl_, 
   {{0x463c008f,0x25740162,0xc618030d,0x00000000}},	//   _רעזע, pæla_, _соьх_, --, 
   {{0x7a4800e2,0x0f240064,0xdb08005c,0x74140345}},	//   lītī, льдм, bsfø, _ئوجا, 
   {{0xc0d00020,0x61300413,0x61f40042,0xbb3c030d}},	//   _ብድር_, _væla, bwyl, _ниiм, 
   {{0x7de40132,0x6d5c0d12,0x61f40142,0xf8d407f7}},	//   مسوم, _ísak, cwyl, _दांय, 
   {{0x85300b45,0xb91001f2,0x6130032e,0x4ea40166}},	//   _kuɗa, relụ_, _hæln, _әрва, 
   {{0x98bc0276,0xab340e92,0xc058109a,0x4ea40f5c}},	//   zită_, ихиј, _біт_, _брза, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x98bc0276,0xbb4402f6,0x00000000,0x00000000}},	//   vită_, äärä, --, --, 
   {{0xe738529e,0x63a000f3,0xb4600213,0x00000000}},	//   вен_, _čono, çülə, --, 
   {{0x98bc0276,0x25b003cb,0xfbd00244,0x61f40042}},	//   tită_, _pwyl_, _رتم_, ywyl, 
   {{0x3ea002d1,0x49c86a10,0x78a403e0,0x00000000}},	//   ñiti_, _чуем_, _şive, --, 
   {{0x98bc084c,0x853003f9,0x89d40014,0x00000000}},	//   rită_, _buɗa, _لوچر_, --, 
   {{0x8880034c,0x853002a8,0x98bc0276,0xdb083c02}},	//   _دیدن, _cuɗa, sită_, tsfø, 
   {{0x66002b57,0x3f9c01ed,0x61f46a0f,0x98bc054e}},	//   _šoku, ívum_, twyl, pită_, 
   {{0xe0d8334a,0xe5785889,0xe1f86a11,0xdb08072b}},	// [7900] ква_, _изи_, ъга_, rsfø, 
   {{0xdb086a12,0x61f46a13,0x28dc08e9,0x00000000}},	//   ssfø, rwyl, _माफि, --, 
   {{0xa2e46a14,0x28dc038e,0xd00c00c6,0xdb084098}},	//   _конд, _मानि, ولك_, psfø, 
   {{0xdee43e0c,0x539806a9,0x23282b97,0x98bc38a5}},	//   роди, _שיכו, _роми_, mitą_, 
   {{0x7ae40784,0x3dc001c7,0xbcc400fb,0x57d00037}},	//   _ñiti, éiw_, йҡал, _थम्ह, 
   {{0xdb780240,0x00000000,0x00000000,0x00000000}},	//   _ብቅዋም_, --, --, --, 
   {{0x673402d0,0x88b80154,0x00000000,0x00000000}},	//   _olyj, ংলাক, --, --, 
   {{0xd00c6a15,0xded41913,0x6144014b,0x00000000}},	//   _تلف_, _خيرخ, _сеҳа, --, 
   {{0x3f986a16,0xdd886a17,0x5334010f,0x89340092}},	//   _huru_, _абад_, ינקן_, _ብዙዎቻ, 
   {{0x3f986a18,0x6734010b,0xa3d400dc,0xb9e40137}},	//   _kuru_, _alyj, _समं_, _ۇتتۇ, 
   {{0xcb640214,0xcba0014b,0x00000000,0x00000000}},	//   طمیه_, _дахй, --, --, 
   {{0x9a846a19,0x3f986a1a,0x853003f9,0x95c8094f}},	//   _кулл, _muru_, _ruɗa, куга_, 
   {{0x3f986a1b,0x291000c6,0x657c0334,0x09e002d5}},	//   _luru_, ánaí_, _bhph, _моцн, 
   {{0x20086a1c,0x3f9800b0,0xd80800f3,0x00000000}},	//   _orbi_, _ouru_, _ахил_, --, 
   {{0x69c40053,0x3f986a1d,0x534405f5,0x89780375}},	//   _āhei, _nuru_, ахаа, _שרוצ, 
   {{0x394c6a1e,0xa3bc02ab,0x00000000,0x00000000}},	//   lids_, ुंज_, --, --, 
   {{0x394c232c,0x20086a1f,0x61306a20,0x776c0327}},	// [7910] oids_, _arbi_, _cælo, _ikax, 
   {{0x3f986a21,0x394c6a22,0x40942dfc,0xef18031c}},	//   _buru_, nids_, ەلەر, _riżq_, 
   {{0x3f986a23,0x78b80455,0x98bc00c0,0x43946a24}},	//   _curu_, _mevv, citą_, _маэс, 
   {{0x3f986a25,0x394c07de,0x671831a0,0x776c031c}},	//   _duru_, hids_, धायक_, _jkax, 
   {{0x394c04ce,0x3f986a26,0x200801c4,0x6130005c}},	//   kids_, _euru_, _erbi_, _kæll, 
   {{0xa3bc09d9,0x78b80083,0x2d9800d8,0x31340798}},	//   ुंच_, _nevv, _ésem_, _ѓевр, 
   {{0xcf886a27,0x394c6a28,0x20080010,0x257402d2}},	//   _асад_, dids_, _grbi_, dæll_, 
   {{0x31341ee3,0x59c018ea,0xbf140166,0xe9d8300e}},	//   _теҳр, _शिखर, _мүхә, гки_, 
   {{0x3f9800b4,0x394c05d5,0xe2a40ad9,0x71300092}},	//   _zuru_, fids_, óðin_, _ቱሪስቶ, 
   {{0x394c6a29,0x776c0054,0x3f986a2a,0xa96800d8}},	//   gids_, _akax, _yuru_, ѓина_, 
   {{0x2910046c,0x78b80477,0x3f9800e8,0xe728009d}},	//   ıza_, _devv, _xuru_, гонд_, 
   {{0xe73843a7,0xaa9400c6,0x394c004c,0x80d0009e}},	//   уем_, _الإث, aids_, স্প্, 
   {{0xa3d805ba,0x69c40069,0x394c01b8,0x2d9c00f1}},	//   डून_, _āhew, bids_, nqwe_, 
   {{0x776c02c4,0x394c6a2b,0x2b4c00e2,0xa5080063}},	//   _ekax, cids_, liec_, ћева_, 
   {{0x15400724,0x613001bf,0x00000000,0x00000000}},	//   черм, _sælo, --, --, 
   {{0x2b4c6a2c,0x3f986a2d,0x6734127b,0x98bc00c0}},	//   niec_, _ruru_, _ulyj, ritą_, 
   {{0x20080bb8,0x6130019b,0x3f986a2e,0x60e86a2f}},	// [7920] _srbi_, _fæll, _suru_, лмам_, 
   {{0x3f986a30,0x613001bf,0x03a80345,0x00000000}},	//   _puru_, _gæll, _نگرو_, --, 
   {{0x3f980213,0x2af81a04,0x74b802dd,0xd00401e0}},	//   _quru_, ्याँ_, _туыс_, йефе_, 
   {{0x1e846a31,0x6ab86a32,0x3f980a73,0x2008003a}},	//   блем, _newf, _vuru_, _vrbi_, 
   {{0x3f986a33,0x2d9c009a,0x2b4c0064,0x00000000}},	//   _wuru_, gqwe_, diec_, --, 
   {{0x3f986a34,0xa0686a35,0x00000000,0x00000000}},	//   _turu_, _бага_, --, --, 
   {{0x200816b8,0x78b86a36,0x5f040395,0x00000000}},	//   _urbi_, _revv, _лзва, --, 
   {{0x705004d3,0x78b86a37,0xef90006c,0xc51801e1}},	//   _تۆما, _sevv, _قیلد, _ṣọ́_, 
   {{0xcb64026a,0x394c1654,0x6f1c00cf,0x98ac00ef}},	//   љање_, tids_, _òsca, _alfā_, 
   {{0xd00c1973,0xce3404ae,0x28dc1fc4,0x00000000}},	//   _تلہ_, _האמת_, _माणि, --, 
   {{0x06b02158,0x394c6a38,0x78b80158,0xa4f4031c}},	//   _কাজি, rids_, _vevv, _བྲེག_, 
   {{0x2b4c033f,0x28dc012c,0xdb080112,0x61306a39}},	//   ciec_, _माथि, nsfü, _sæll, 
   {{0xab6057d4,0x394c6a3a,0xfa546a3b,0x2cbc008e}},	//   _تۇيى, pids_, _براگ, _öydä_, 
   {{0xd7f801f0,0xe4b400db,0xf1c40153,0x00000000}},	//   _буи_, жирө, našų_, --, 
   {{0x57a407d6,0x776c031c,0x61301924,0x00000000}},	//   _ушла, _tkax, _væll, --, 
   {{0x776c2e95,0xe614151c,0x33743981,0x387c01a6}},	//   _ukax, žišč, ігар, _izvr_, 
   {{0x6130037e,0x06b0009e,0xdb080174,0x24780092}},	// [7930] _tæll, _কাচি, lsfó, _በስሜት_, 
   {{0x613002d2,0x2b4c0210,0x00000000,0x00000000}},	//   _hælj, ziec_, --, --, 
   {{0x009401c0,0x6e980946,0x00000000,0x00000000}},	//   чихэ, авер_, --, --, 
   {{0xac7802d3,0xa3cc07af,0x00000000,0x00000000}},	//   _ብሕማም_, _रित_, --, --, 
   {{0xdb0807c5,0x2b4c6a3c,0xacf80116,0xdcf80166}},	//   mpfè, viec_, инду_, _qitğ, 
   {{0x2b4c6a3d,0x32086a3e,0x7df403cc,0x067c010f}},	//   wiec_, mvay_, سقىچ, אנדל, 
   {{0xeab00597,0x32082f65,0x7e600356,0x2c0800dc}},	//   وعة_, lvay_, _exmp, विधं_, 
   {{0x32080c8c,0x00000000,0x00000000,0x00000000}},	//   ovay_, --, --, --, 
   {{0x32080c8c,0x2b4c0419,0x78a40205,0xe8f80835}},	//   nvay_, riec_, _şiva, алп_, 
   {{0x2b4c0210,0x00000000,0x00000000,0x00000000}},	//   siec_, --, --, --, 
   {{0x38541064,0x2b4c0034,0x320803ac,0x200c002f}},	//   зъяс, piec_, hvay_, äfix_, 
   {{0xdb2401d9,0x320803ac,0x00000000,0x00000000}},	//   _وولی, kvay_, --, --, 
   {{0xa4f40327,0x64a46a3f,0x00000000,0x00000000}},	//   _བྲུག_, жага, --, --, 
   {{0x25741cf3,0x3208127b,0xa5086a40,0x38600055}},	//   mælk_, dvay_, шега_, _śire_, 
   {{0xe7b40597,0x320814dc,0x2904004b,0x98a80210}},	//   _بمعد, evay_, mdla_, óbą_, 
   {{0x61300162,0x320802d0,0x73980022,0xbed80210}},	//   _vælm, fvay_, стрс_, _डाइऑ, 
   {{0x91e00209,0xa11419b6,0x32086a41,0xf1a815eb}},	// [7940] моте, يورت, gvay_, ماله_, 
   {{0x29044b26,0xdb08359e,0x00000000,0x00000000}},	//   ndla_, nsfò, --, --, 
   {{0x26006a42,0x320802d0,0xc330075e,0xe61000e5}},	//   शिकी_, avay_, _كەس_, _رشک_, 
   {{0x613001bf,0x320803ac,0xdb080112,0x00000000}},	//   _kælk, bvay_, usfü, --, 
   {{0x32086a43,0xbf10013d,0x00000000,0x00000000}},	//   cvay_, _җүлә, --, --, 
   {{0x6d8c0084,0x61306a44,0x29040010,0xdb08002f}},	//   ṱang, _mælk, jdla_, ssfü, 
   {{0xf1c40153,0x290401e3,0x8cd8134e,0x00000000}},	//   rašų_, ddla_, _नारो, --, 
   {{0x29046a45,0x2ca4032e,0xdb240790,0xc0c400fb}},	//   edla_, _efld_, _öpüy, _фәҡи, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xccfc0882,0x272000d7,0x613002d2,0xdb080162}},	//   āśca_, _ióny_, _sælj, tsfó, 
   {{0x80d02f8b,0xd6b405d9,0x0db8069d,0xdab83346}},	//   স্থ্, يندڙ_, ደገፈ_, _نهضت_, 
   {{0x7bd8046a,0x320814dc,0xdb081427,0x290400d7}},	//   muvu, yvay_, rsfó, adla_, 
   {{0x7bd806e4,0x34946a46,0x55040410,0x3208035a}},	//   luvu, загр, очва, xvay_, 
   {{0xdea00198,0xdb0803b2,0x320802d0,0x00000000}},	//   rkoƙ, psfó, vvay_, --, 
   {{0x32080c8c,0x00000000,0x00000000,0x00000000}},	//   wvay_, --, --, --, 
   {{0x61306a47,0xd5b80395,0x3208127b,0x00000000}},	//   _fælk, _ксо_, tvay_, --, 
   {{0xd0a86a48,0x7bd86a49,0x3208007f,0xc2c415eb}},	// [7950] لطان_, huvu, uvay_, بيقي, 
   {{0x7bd853ff,0xc17800d6,0x3208127b,0xd0a86a4a}},	//   kuvu, оїх_, rvay_, ртад_, 
   {{0x28dc2765,0x320814dc,0xbde40150,0x2ef40108}},	//   _मासि, svay_, _ﺍﻻﻨﻔ, ззер, 
   {{0x7a2400b0,0x7bd86a4b,0x320803ac,0x00000000}},	//   _kōtā, duvu, pvay_, --, 
   {{0x720404d3,0x00000000,0x00000000,0x00000000}},	//   _عوسم, --, --, --, 
   {{0xeb9812ab,0xaffc0408,0x00000000,0x00000000}},	//   бик_, _йогi, --, --, 
   {{0x7bd86a4c,0xcf400150,0x6abc148b,0xdcac215c}},	//   guvu, _قىسۋ, ðsfo, دىى_, 
   {{0x28dc2413,0xdcf80171,0xa3cc09ab,0xc0380092}},	//   _माहि, _bitē, _रिस_, _በሚባለ, 
   {{0x7c382f61,0xdcf8005f,0xca600124,0xe9d000ae}},	//   _čarš, _citē, ьеиқ, رغة_, 
   {{0x7bd86a4d,0x00000000,0x00000000,0x00000000}},	//   buvu, --, --, --, 
   {{0x3ea06a4e,0x7bdc01b8,0x98bc012c,0x27200122}},	//   žite_, _ärup, litě_, _zóny_, 
   {{0x25742242,0x0db8001f,0xa9c000f7,0xfaf000f2}},	//   mæli_, ደገፍ_, _كۅبۉ, _لثه_, 
   {{0xb2f81b4b,0x6b886a4f,0x98bc0118,0xe7ec00c5}},	//   _ཕྲེང_, mmeg, nitě_, _जहवा_, 
   {{0x6b8809a5,0x61300579,0x5378001f,0x220400e4}},	//   lmeg, _vælk, _በብዛት_, hêhá_, 
   {{0xf9906a50,0xe728009d,0x00000000,0x00000000}},	//   _شبه_, _гойд_, --, --, 
   {{0xe29805f5,0x6b8800ee,0x201c0327,0xe61800d8}},	//   саа_, nmeg, _ħti_, _гди_, 
   {{0x61301d1d,0x6b886a51,0x73740022,0x98bc01ef}},	// [7960] _hæli, imeg, фырх, jitě_, 
   {{0x26c06a52,0xa06812c1,0x7bd800ca,0x6b886a53}},	//   lako_, база_, yuvu, hmeg, 
   {{0x6b886a54,0x26c001c6,0x7688022e,0x55a400e5}},	//   kmeg, oako_, mоya, _وجیہ, 
   {{0x656c6a55,0x7bd803b4,0x6b886a56,0x61302833}},	//   lobh, vuvu, jmeg, _mæli, 
   {{0x7bd85b12,0xd24c038b,0x26c001c6,0x6b886a57}},	//   wuvu, _منَ_, iako_, dmeg, 
   {{0x26c06a58,0x768801a9,0xe12400db,0xdcf80171}},	//   hako_, nоya, _эмги, _ritē, 
   {{0x7bd8013c,0xd6c403d4,0x9138010f,0x8cc4007b}},	//   uuvu, ষ্টয, _פעלק, سويق_, 
   {{0x7bd86a59,0xd00c2c10,0x272002fb,0x6b886a5a}},	//   ruvu, _حلف_, _tóny_, gmeg, 
   {{0xa3d409d9,0x26c06a5b,0x656c6a5c,0x7bd86a5d}},	//   _समझ_, dako_, kobh, suvu, 
   {{0xd7f821ca,0x656c6846,0x7bd86a5e,0x6130032e}},	//   бум_, jobh, puvu, _bæli, 
   {{0x26c06a5f,0x28dc6a60,0x61306a61,0x3f840165}},	//   fako_, _मारि, _cæli, _khmu_, 
   {{0x26c06a62,0xa3d40490,0x1ca403e6,0x613002d2}},	//   gako_, _समज_, _بێژی_, _dæli, 
   {{0xaae40214,0xcb0401f7,0x00000000,0x00000000}},	//   _آسمو, _ريون_, --, --, 
   {{0x26c06a63,0x2498030a,0x656c6a64,0x613008a5}},	//   aako_, _cgpm_, gobh, _fæli, 
   {{0x0fd42f04,0x49001b06,0x61303619,0x60dc0427}},	//   _সন্ধ, _سويق, _gæli, dgpm, 
   {{0x26c06a65,0x75d400db,0x92680120,0x62980139}},	//   cako_, _قيبا, брза_, _ştor, 
   {{0xd04403be,0x656c009a,0xbb3c00d1,0x67180b03}},	// [7970] əməs, bobh, ﻟﻼﻫ_, धारक_, 
   {{0x6b886a66,0xd34407d6,0x98bc0118,0x656c6a67}},	//   zmeg, _کیره_, vitě_, cobh, 
   {{0x98a8012d,0x00000000,0x00000000,0x00000000}},	//   óbę_, --, --, --, 
   {{0xe2a8004b,0x1ee803c7,0x00000000,0x00000000}},	//   _واټن_, قومی_, --, --, 
   {{0x28dc0cb4,0x7bc86a68,0x1ee812e9,0x00000000}},	//   _मालि, _avdu, تونی_, --, 
   {{0x26c06a69,0x25dc0574,0x7cc40aaf,0x98bc0118}},	//   zako_, कंती_, ىزىم, ritě_, 
   {{0xbbe80491,0x26c06a6a,0x6b8800ee,0x8f44010a}},	//   كريم_, yako_, tmeg, _ехад, 
   {{0xeeb80801,0xeaf80b7c,0x656c6a6b,0x6b886a6c}},	//   _флаш_, ्येत_, zobh, umeg, 
   {{0x26c06a6d,0x6b886a6e,0xc0d002d3,0x656c6a6f}},	//   vako_, rmeg, _ብድሆ_, yobh, 
   {{0x6b886a70,0x656c009a,0x613001a8,0xdb1801e3}},	//   smeg, xobh, _pæli, _avtä, 
   {{0x26c06a71,0xfbd06a72,0xf1880075,0xd01c00a2}},	//   tako_, _متن_, _ﺑﻮﻟﯘ, _öńde_, 
   {{0x613009e8,0x00000000,0x00000000,0x00000000}},	//   _væli, --, --, --, 
   {{0x26c06a73,0x2d84014b,0x656c6a74,0xdb246a75}},	//   rako_, _khle_, tobh, _تونی, 
   {{0x85300b45,0x64a40261,0x2d9800d8,0x228c00e4}},	//   _kuɗi, ќава, _éseu_, _ẽko_, 
   {{0x26c06a76,0x21280876,0xa2e46a77,0x2d846a78}},	//   pako_, _robh_, мовд, _mhle_, 
   {{0xae1c10b7,0xe7380d1d,0x00000000,0x00000000}},	//   पमान_, _феи_, --, --, 
   {{0x2d846a79,0xe5680150,0xa5086a7a,0x00000000}},	// [7980] _ohle_, _ومبى_, _депа_, --, 
   {{0x2d84014b,0x656c0fec,0x60dc0175,0x3f8400d7}},	//   _nhle_, qobh, ugpm, _shmu_, 
   {{0xe2986a7b,0x23286a7c,0xdb080267,0x00000000}},	//   _ман_, _дони_, msfö, --, 
   {{0xdb0801e6,0x9e64009a,0x00000000,0x00000000}},	//   lsfö, واشن, --, --, 
   {{0x21286a7d,0xb2f80327,0x00000000,0x00000000}},	//   _tobh_, _ཕྲིང_, --, --, 
   {{0x2d84007f,0xdb08049f,0x00000000,0x00000000}},	//   _chle_, nsfö, --, --, 
   {{0x3f8406a3,0x670c0037,0xdb08002f,0xf778031c}},	//   _thmu_, ियाक_, isfö, stħi_, 
   {{0x2d840921,0x63b80030,0x5398011a,0xada800f7}},	//   _ehle_, átny, חיקו, زدۇق_, 
   {{0xdb0801e6,0xdca46a7e,0x00000000,0x00000000}},	//   ksfö, _жази, --, --, 
   {{0x0d802c05,0x2d8401c3,0x3ea001e4,0x63b80419}},	//   _алун, _ghle_, ɾita_, štny, 
   {{0xdb08049f,0x7d080e89,0x2bd45690,0xe52000dc}},	//   dsfö, _iads, _धिया, मानि_, 
   {{0x81c403f4,0x7d086a7f,0xfbb40154,0x35d42cdd}},	//   _এমন_, _hads, _টিপত, номё, 
   {{0xceb00302,0x7d086a80,0x613008ce,0x3a202ca8}},	//   כיר_, _kads, _hælu, _çip_, 
   {{0xdb0801e6,0x7d080798,0xf10c447d,0x2bd400bc}},	//   gsfö, _jads, _सफेद_, _धिमा, 
   {{0x7d086a81,0x67300fac,0x00000000,0x00000000}},	//   _mads, åkjø, --, --, 
   {{0x7998047e,0x613008a5,0x63a001ef,0x257402d2}},	//   _hivw, _mælu, _čont, dælu_, 
   {{0xc0d0044e,0x7d086a82,0x00000000,0x00000000}},	// [7990] _ብስም_, _oads, --, --, 
   {{0x7d082a92,0x79980455,0x645804d4,0x00000000}},	//   _nads, _jivw, útic, --, 
   {{0x79980477,0x7d0800de,0x35a4000d,0xc0d00023}},	//   _mivw, _mūrē, _गंड़, ብሩላ_, 
   {{0x85300198,0xc1740198,0x7d086a83,0x92f000ee}},	//   _ruɗi, ruɗa_, _aads, _шүбх, 
   {{0x7d086a84,0x3f9c022c,0xd13800d8,0x00000000}},	//   _bads, ívur_, _дхв_, --, 
   {{0xeb986a85,0x7d086a86,0x7998014f,0xa214010f}},	//   пик_, _cads, _nivw, _אַלס_, 
   {{0x61300393,0x3ea02a25,0x7d0806be,0x25741427}},	//   _cælu, žita_, _dads, mælt_, 
   {{0x79980109,0x94fc0135,0x7d08127b,0x613008a5}},	//   _aivw, _ཞིའི_, _eads, _dælu, 
   {{0x7d0801e7,0x613006ea,0xc0d00023,0xedd46a87}},	//   _fads, _vælv, ብሩሉ_, _سياد, 
   {{0x7d086a88,0x6f086a89,0x2d846a8a,0x7cd80cdd}},	//   _gads, _haec, _uhle_, _омур_, 
   {{0x66e46a8b,0x79986a8c,0x61300008,0x65c40124}},	//   нона, _divw, _gælu, _oîhá, 
   {{0xdcf80024,0x9bb400d9,0x00000000,0x00000000}},	//   _bitė, _נהנה_, --, --, 
   {{0x6f080483,0xdb08049f,0x9984033f,0x7d0803e0}},	//   _maec, tsfö, _broń_, _yads, 
   {{0x6f0806ee,0x69c8022f,0x00000000,0x00000000}},	//   _laec, msee, --, --, 
   {{0x69c86a8d,0xe7386a8e,0x613005f7,0xd8d40a1e}},	//   lsee, _нек_, _mælt, _טוסט_, 
   {{0x6aa86a8f,0x6f085cf5,0xdb0801e6,0x69c80c90}},	//   ncef, _naec, ssfö, osee, 
   {{0x69c86a90,0xe65c1b49,0xa594524d,0xdb080267}},	// [79a0] nsee, _ወንጌላ, _прощ, psfö, 
   {{0x69c86a91,0x8cd802ab,0x6b980042,0xa6e00162}},	//   isee, _नागो, _liwg, íðfe, 
   {{0x7d086a92,0x6f08015d,0xa00801d3,0x240817b4}},	//   _rads, _baec, ثقال_, _энни_, 
   {{0x69c86a93,0x6f081730,0x63780227,0xdf746a94}},	//   ksee, _caec, kïni, رداب, 
   {{0x6f08039a,0x2574037e,0x6130532a,0x7d086a95}},	//   _daec, bælt_, _bælt, _pads, 
   {{0x6db801e4,0x15ac0131,0x7d080009,0x69c80bfa}},	//   _iʈal, ﻳﺪﯨﻐ, _qads, dsee, 
   {{0x69c86a96,0x6f086a97,0x7d080250,0x51600114}},	//   esee, _faec, _vads, _сврб, 
   {{0x7d086a98,0x6e34025a,0x6130041e,0x9f48023a}},	//   _wads, ôgbï, _vælu, ömän_, 
   {{0x853003f9,0x7d0802b5,0x79980455,0x6b980142}},	//   _huɗu, _pūrē, _pivw, _diwg, 
   {{0x79980477,0x83000327,0x7d08035a,0xd90c187c}},	//   _qivw, _ཝིའུ_, _uads, صیب_, 
   {{0x69c86a99,0xed580010,0x6f08037e,0x5b3400a8}},	//   asee, _cvžu_, _yaec, _пэду, 
   {{0x69c86a9a,0xfbd00014,0x2d9800d8,0x2bd40118}},	//   bsee, _متچ_, _éser_, _धिता, 
   {{0x69c86a9b,0x7998014f,0x7d0800ef,0x869801f4}},	//   csee, _tivw, _tūrē, етёт_, 
   {{0xdb2407d6,0x51c81884,0x613008a5,0x00000000}},	//   _توچی, _ﺗﻪﻛﺸ, _mæls, --, 
   {{0x998002d5,0x63780054,0x85300198,0xc17001f2}},	//   škų_, nïnw, _nuɗu, ọọp_, 
   {{0x645800d0,0x48780375,0x9f5c0248,0x00000000}},	//   útia, _מטוס, _ètè_, --, 
   {{0x6abc03f2,0x00000000,0x00000000,0x00000000}},	// [79b0] ðsfi, --, --, --, 
   {{0x6f080483,0x63780054,0x7bd802f0,0x4fc4466e}},	//   _saec, kïnw, krvu, есда, 
   {{0xb4dc38bf,0x6f08039a,0x5064013e,0xf7780327}},	//   डली_, _paec, хтаа, stħu_, 
   {{0x69c86a9c,0xe5200316,0x61300158,0x00000000}},	//   ysee, माथि_, _sælt, --, 
   {{0x8504168d,0x7bd804cc,0x6f080393,0x257403b2}},	//   _شوێن, ervu, _vaec, pælt_, 
   {{0xec78337c,0x063800c8,0x6b980368,0x69c80010}},	//   мпл_, ענגט_, _siwg, vsee, 
   {{0x6f08213f,0x613069e8,0x69c8011f,0x6fb80006}},	//   _taec, _vælt, wsee, _ігар_, 
   {{0x69c86a9d,0x61300158,0x3328025c,0x3ea001e4}},	//   tsee, _fæls, njax_, ɾito_, 
   {{0x6aa86a9e,0x9c800030,0x19c02fc3,0xaa441468}},	//   rcef, ľčan, абым, тепл, 
   {{0x2ba82017,0xac180137,0x6aa802d0,0xbcb40419}},	//   _चंपा, _оозу_, scef, čším, 
   {{0x69c86a9f,0x68e002d0,0x00000000,0x00000000}},	//   ssee, rgld, --, --, 
   {{0xe5a46aa0,0x69c86aa1,0xe73801af,0x00000000}},	//   кими, psee, фем_, --, 
   {{0x6d40036e,0x33280327,0x69c8058a,0x00000000}},	//   _klla, djax_, qsee, --, 
   {{0x18a06aa2,0xc0c40023,0x00000000,0x00000000}},	//   _кашм, ጸንሐ_, --, --, 
   {{0x33d40212,0x6d406aa3,0x00000000,0x00000000}},	//   літт, _mlla, --, --, 
   {{0xa6c801d9,0xdec40023,0x00000000,0x00000000}},	//   _کوکل_, ጸትን_, --, --, 
   {{0x26d00100,0xa0a46aa4,0x69e401ef,0x2bec00eb}},	// [79c0] _idyo_, вазд, _úseč, ঝিয়ে_, 
   {{0xd1d402d3,0x3328002e,0x00000000,0x00000000}},	//   ርከቡ_, ajax_, --, --, 
   {{0x6130005c,0x8fa00022,0xf7780327,0xe3642852}},	//   _sæls, аахе, luħa_, _акни, 
   {{0x44381368,0xc2946aa5,0x8d703016,0xd00c01f7}},	//   myr_, _میزب, یاوا, غلن_, 
   {{0x26d00280,0x44386aa6,0x6d400240,0xe0d001d9}},	//   _mdyo_, lyr_, _blla, _پٲز_, 
   {{0x62846aa7,0x613006ea,0x28dc2ce6,0x443800ad}},	//   _izko, _væls, _मागि, oyr_, 
   {{0x6d40020c,0x26d002e2,0xd0046aa8,0x44386aa9}},	//   _dlla, _odyo_, _иере_, nyr_, 
   {{0x6d406aaa,0x26d01556,0x661402d0,0x00000000}},	//   _ella, _ndyo_, _oryk, --, 
   {{0x44386aab,0x63780227,0x6d400240,0x29fc01e4}},	//   hyr_, sïnw, _flla, lʈaj_, 
   {{0x44386aac,0x26d00055,0x5fc400e1,0x6d400240}},	//   kyr_, _adyo_, _लबाल, _glla, 
   {{0xdb4c168d,0x66146aad,0x29fc01e4,0xa3cc000d}},	//   _وێت_, _aryk, nʈaj_, _रिग_, 
   {{0x44386aae,0xbb44023a,0x62846aaf,0x6614012d}},	//   dyr_, äädä, _ozko, _bryk, 
   {{0x26d02252,0x09e012c4,0x6d4000ad,0x25dc2cf5}},	//   _ddyo_, _вочн, _ylla, कूली_, 
   {{0xb4dc205d,0xd1d41e38,0x44386ab0,0x66146ab1}},	//   डले_, ርከብ_, fyr_, _dryk, 
   {{0x56f006ba,0x44385364,0x628401c0,0x1c001b57}},	//   _күнс, gyr_, _azko, लबिल_, 
   {{0x66141700,0x15e006ab,0xfcec0092,0xdcf80171}},	//   _fryk, कंदर_, ቀመጠ_, _bitī, 
   {{0x66146ab2,0x79440295,0x44380363,0x33280327}},	// [79d0] _gryk, _eòwe, ayr_, rjax_, 
   {{0x44380731,0x00000000,0x00000000,0x00000000}},	//   byr_, --, --, --, 
   {{0x628401c0,0x00000000,0x00000000,0x00000000}},	//   _ezko, --, --, --, 
   {{0x6d4002d3,0x00000000,0x00000000,0x00000000}},	//   _slla, --, --, --, 
   {{0x926814b7,0x22d802e4,0x6d400023,0xfcec001f}},	//   _црна_, _אחרא, _plla, ቀመጡ_, 
   {{0xfb7400f2,0x00000000,0x00000000,0x00000000}},	//   یپوگ, --, --, --, 
   {{0x6d4002d3,0xeb980114,0x7d0800c0,0x00000000}},	//   _vlla, нђић_, dūrė, --, 
   {{0x613001bf,0x6e94014b,0xbc18003b,0x00000000}},	//   _hælp, _бибу, тіші_, --, 
   {{0x6d4001af,0x7a4800e2,0x1ee86ab3,0xc334011a}},	//   _tlla, jūtī, _سولی_, שופ_, 
   {{0x66f800b0,0x2574037e,0xc27c0375,0x44386ab4}},	//   _mākō, jælp_, ורחי, yyr_, 
   {{0x25b06ab5,0x387c0477,0xd1d40023,0x64c40003}},	//   _styl_, _cyvr_, ርከቦ_, nċiż, 
   {{0x44386ab6,0x00000000,0x00000000,0x00000000}},	//   vyr_, --, --, --, 
   {{0x44380f7b,0x6abc0436,0xb7f0009e,0x2ba80037}},	//   wyr_, ðsfu, টিগত_, _चंडा, 
   {{0x44386ab7,0x39440953,0x6614017a,0x28dc6ab8}},	//   tyr_, _кніг, _vryk, _माटि, 
   {{0x6284006d,0x44381368,0x64c4025c,0xdcf800ef}},	//   _szko, uyr_, jċiż, _sitī, 
   {{0x66146ab9,0x25b00270,0x72b400d4,0x443800e4}},	//   _tryk, _ttyl_, ищує, ryr_, 
   {{0x23641a4c,0x44386aba,0xf1a8030f,0x267800a8}},	// [79e0] ĵoj_, syr_, ناله_, _яскэ_, 
   {{0x44386abb,0x11d400c6,0xdcf800b8,0xa50800d8}},	//   pyr_, اولة_, _vitī, _џена_, 
   {{0xa2e40184,0xcae00034,0xdbbc009e,0x4438036e}},	//   _йонд, _गांड_, _ইম্ফ, qyr_, 
   {{0x7c3802f0,0xdcf800b8,0x7c3c06be,0xfcc40092}},	//   vyvr, _titī, _ürri, _ሸንጎ_, 
   {{0x62846abc,0xdcb06abd,0x53980375,0x6298010f}},	//   _uzko, مىش_, _ריכו, _ŝtof, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x717008c9,0x00000000,0x00000000,0x00000000}},	//   _بۇلا, --, --, --, 
   {{0x66046abe,0x4ce000c7,0x2bd40037,0x00000000}},	//   kwkk, ажәб, _धिरा, --, 
   {{0x9e6461db,0x2bc401f9,0x00000000,0x00000000}},	//   _свад, ळीबा, --, --, 
   {{0x4df8008f,0x47d800cc,0x00000000,0x00000000}},	//   _אפמא, _বনজী, --, --, 
   {{0x64586abf,0x7688022e,0x50d8010f,0x4970009d}},	//   útil, mоyi, עקטא, слэс, 
   {{0xb4dc01ad,0x9a8401b9,0x57b00150,0x00000000}},	//   डल्_, _йулл, _құмт, --, 
   {{0x66e416f0,0xa5c40055,0x00000000,0x00000000}},	//   _कारक_, _niųā, --, --, 
   {{0xd49852f5,0xd4046ac0,0x1dc40825,0x3ce80055}},	//   ерб_, ляби, रीयत, च्चे_, 
   {{0x7a480029,0x98bc0421,0xd7f86ac1,0xb4940114}},	//   sūtī, sitē_, _чул_, ривљ, 
   {{0x66f802b5,0x87d005d3,0x00000000,0x00000000}},	//   _pākō, _اغوا, --, --, 
   {{0x1dc46ac2,0xdb080112,0x116401d5,0x31d400d1}},	// [79f0] रीमत, mpfä, هلری_, شقاز, 
   {{0xa3cc01ad,0x0fe000db,0x00000000,0x00000000}},	//   _रिच_, йөбү, --, --, 
   {{0xe52002c3,0x3ce86ac3,0x00000000,0x00000000}},	//   मारि_, च्छे_, --, --, 
   {{0x7ff40491,0x4ea400ee,0xcae0072a,0x606000d1}},	//   إسلا, уржа, _गाइड_, زۇقل, 
   {{0x6cc457dd,0x4fc4013d,0x00000000,0x00000000}},	//   айла, _әсга, --, --, 
   {{0xabd426e5,0x2008020c,0xad241e87,0x7ee40124}},	//   ациј, _fsbi_, شىبى, ацәе, 
   {{0xc0d002d3,0x2d98020c,0x66e405dc,0x4034030d}},	//   ብኩም_, _èsem_, _कालक_, _лерс, 
   {{0xeb9865a9,0x9b90009a,0x70580117,0x00000000}},	//   ъий_, يلوت, _заҳр_, --, 
   {{0xcce46ac4,0xe9680139,0x00000000,0x00000000}},	//   _مساي, каил_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe7646ac5,0x98bc0024,0xa764010a,0xba2802dd}},	//   ивоп, antį_, икод, _ەسىم_, 
   {{0xdb24004b,0x66e46ac6,0x3a200427,0x00000000}},	//   _پوهی, шома, _šipe_, --, 
   {{0xe5a46ac7,0x80d000bd,0x7a4802b1,0x00000000}},	//   риги, স্ট্, tūtū, --, 
   {{0x290000e4,0xa44401d5,0xfa340066,0x00000000}},	//   _úha_, ангд, _درمد, --, 
   {{0x32183223,0x02c82097,0xa87800c8,0x63786ac8}},	//   _arsy_, лқни_, _באַר, всар_, 
   {{0x20080263,0x2d0002e5,0x93400354,0xe6186ac9}},	//   _rsbi_, लजुल_, онсе, _ади_, 
   {{0xdcf80316,0xe2985260,0xcae00f4a,0x00000000}},	// [7a00] _chtě, таа_, _गाईड_, --, 
   {{0xe3b000e3,0x00000000,0x00000000,0x00000000}},	//   _ورج_, --, --, --, 
   {{0x606409a6,0x00000000,0x00000000,0x00000000}},	//   جهال, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x644c002f,0x9f5c01e1,0x00000000,0x00000000}},	//   lzbi, _ètí_, --, --, 
   {{0xdd0c0790,0x644c16a3,0x8d6040e0,0xbdd00220}},	//   _dışi, ozbi, овче, _ﺒﺸﻜل_, 
   {{0xc10400aa,0x845c001f,0x644c6aca,0xdb684727}},	//   _پوځي, ደሚሆን_, nzbi, крил_, 
   {{0xcfb4025f,0x8fa006ed,0xe81800dc,0x00000000}},	//   _כללי_, _фате, धिना_, --, 
   {{0x99646acb,0xcb640640,0xb9540212,0x9a8401a9}},	//   итол, јање_, йвищ, шукл, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc17402a8,0xdd940032,0x77980117,0x00000000}},	//   guɗi_, _баҡы, лкор_, --, 
   {{0x644c3421,0x6d8c00e4,0x00000000,0x00000000}},	//   dzbi, túag, --, --, 
   {{0xb5480023,0x3ea40f85,0xdb080112,0x00000000}},	//   _ሓለፍት, _mgmt_, rpfä, --, 
   {{0x97a46acc,0x878801c6,0x00000000,0x00000000}},	//   _крил, лөөг_, --, --, 
   {{0x939400c6,0xf7940276,0x3834084c,0xd3786acd}},	//   لجرا, _лакэ, _ынкр, вча_, 
   {{0x7fac03b9,0x938801d5,0xd6d800f3,0x3218013a}},	//   _ağqo, тсга_, _ртк_, _prsy_, 
   {{0xc2c401ec,0xd1b80131,0x98bc0139,0x00000000}},	// [7a10] زيلي, ئارا_, lotı_, --, 
   {{0x867c0375,0xc618010a,0x05dc000d,0x00000000}},	//   _ברחו, _тоьх_, _बितब, --, 
   {{0xc6782163,0xe8186ace,0x74141541,0x644c012d}},	//   _محیط_, धिया_, _اوجا, czbi, 
   {{0xef180327,0x321802f0,0x12a833d2,0x008401ec}},	//   _okże_, _trsy_, _جددى_, _ﺩﺍﺌﻤ_, 
   {{0x32180ffb,0x00000000,0x00000000,0x00000000}},	//   _ursy_, --, --, --, 
   {{0x320814dc,0xace86acf,0xa4400014,0xc1740198}},	//   mway_, умка_, _بێہو, yuɗi_, 
   {{0x32086ad0,0x33b00131,0xdcac04da,0xcf9803f6}},	//   lway_, _ﻳﺎﺯﻣ, رىي_, _аја_, 
   {{0x8d7404d3,0x32080857,0x00000000,0x00000000}},	//   داڵا, oway_, --, --, 
   {{0x32086ad0,0x3568069c,0xdb1803b2,0xec142586}},	//   nway_, ተኛታት_, _avtó, _گواد, 
   {{0x8d746ad1,0x7d5443a7,0x320803ac,0x645800d7}},	//   _ئارا, _двух, iway_, útik, 
   {{0xe7386ad2,0x32086ad0,0xec14208f,0x00000000}},	//   ген_, hway_, _دواد, --, 
   {{0x320814dc,0xc79801ed,0x00000000,0x00000000}},	//   kway_, جھتا_, --, --, 
   {{0xbb7000cf,0xfaf001f7,0x3208035a,0x80c800eb}},	//   _تۇيع, _آثم_, jway_, _লাস্, 
   {{0x32083ff0,0x26dc054e,0x644c002f,0x98bc0166}},	//   dway_, şto_, tzbi, botı_, 
   {{0x32086ad3,0xb95400db,0xd974009f,0x00000000}},	//   eway_, _بئنت, _ائنڊ, --, 
   {{0x3ea005ce,0x644c4baa,0x32080c8c,0xa2540214}},	//   žiti_, rzbi, fway_, مپزش, 
   {{0x32086ad4,0xe6181353,0x644c0827,0x00000000}},	// [7a20] gway_, _сдп_, szbi, --, 
   {{0x29046ad5,0x00e42d20,0x00000000,0x00000000}},	//   nela_, تتری, --, --, 
   {{0x5ea40a2c,0x29046ad6,0x32080c8c,0x443c005c}},	//   ممال, iela_, away_, _æv_, 
   {{0x8bfc000e,0xdee43461,0x657c004d,0x32085337}},	//   ্মান_, соди, _hkph, bway_, 
   {{0x320814dc,0x5e5800c6,0x673403b2,0x31f80327}},	//   cway_, دجاج_, _moyj, _ཕྱྭར_, 
   {{0x29046ad7,0x2eec0175,0x814400e5,0xdb0c0241}},	//   jela_, _ecef_, _بھرم, _ìjúw, 
   {{0xa0a4016c,0x60246ad8,0x00000000,0x00000000}},	//   _ваҳд, _удва, --, --, 
   {{0xd1f0001f,0x4fd40a7c,0x00000000,0x00000000}},	//   _ሃሣብ_, _לולב_, --, --, 
   {{0x29046ad9,0x3b040369,0x00000000,0x00000000}},	//   fela_, remq_, --, --, 
   {{0x29045114,0x79586ada,0x39580192,0x00000000}},	//   gela_, риор_, òrs_, --, 
   {{0xdeb82295,0x2d9400d4,0x3208127b,0xd7c001f9}},	//   _ሲሆን_, _єрус, zway_, वींच, 
   {{0x290400fb,0x32086adb,0x00000000,0x00000000}},	//   aela_, yway_, --, --, 
   {{0x32080c8c,0x00000000,0x00000000,0x00000000}},	//   xway_, --, --, --, 
   {{0x290453ff,0x697400f1,0x32086adc,0xca94011a}},	//   cela_, _وخوړ, vway_, _הדדי_, 
   {{0xb9d8044e,0x32086add,0x53445e0c,0x00000000}},	//   _በለ_, wway_, бхаа, --, 
   {{0x32086ad0,0x87d42df0,0x79440100,0x80c8009e}},	//   tway_, _ابوس_, _kòwo, _লাষ্, 
   {{0x90a4007b,0x32086ade,0xf288009d,0x00000000}},	// [7a30] محام, uway_, рөнд_, --, 
   {{0x32084dbd,0x2b800210,0x00000000,0x00000000}},	//   rway_, róci_, --, --, 
   {{0x32086ad0,0xe4ec49f1,0xb4d40490,0x2bb40055}},	//   sway_, _जाति_, हणी_, _kāce_, 
   {{0x29044ec2,0xc7b000c8,0x32080c8c,0xaf080066}},	//   zela_, לבע_, pway_, شقتم_, 
   {{0x29046adf,0x51842f8d,0x320868d4,0x14bc0073}},	//   yela_, _гува, qway_, ्रपण, 
   {{0xfe706ae0,0x29046ae1,0xff5003e6,0x25dc01ad}},	//   ردن_, xela_, وخۆ_, कूटी_, 
   {{0x81c400eb,0x00000000,0x00000000,0x00000000}},	//   _এমএ_, --, --, --, 
   {{0x2eec0998,0x776c1bce,0x3a200010,0x2b580ba1}},	//   _ucef_, _njax, _šipa_, òsc_, 
   {{0xfe6c064e,0xedd401f7,0x00000000,0x00000000}},	//   _чү_, _ذياد, --, --, 
   {{0x776c6ae2,0x67346ae3,0x00000000,0x00000000}},	//   _ajax, _soyj, --, --, 
   {{0x29046ae4,0x3b6401d9,0x00000000,0x00000000}},	//   rela_, _کُنِ, --, --, 
   {{0x67340455,0x00000000,0x00000000,0x00000000}},	//   _qoyj, --, --, --, 
   {{0x2904398e,0xb4d40073,0x00000000,0x00000000}},	//   pela_, हणू_, --, --, 
   {{0x29046ae5,0x6b6000e2,0x5e9800df,0x00000000}},	//   qela_, rēgu, יברק, --, 
   {{0xdeb80020,0x317801f2,0x23340408,0xd4a000ee}},	//   _ሲሆኑ_, ụọla_, охар, дирй, 
   {{0x2b4c0ba1,0x00000000,0x00000000,0x00000000}},	//   nhec_, --, --, --, 
   {{0x36e81075,0x43940354,0x00000000,0x00000000}},	// [7a40] _ارىپ_, çарс, --, --, 
   {{0x7a406ae6,0x00000000,0x00000000,0x00000000}},	//   _hátú, --, --, --, 
   {{0x60086ae7,0x9ea80120,0x23ac00a2,0x2bb400b8}},	//   рнем_, авеа_, _uýj_, _yāce_, 
   {{0x1e840cfc,0x00000000,0x00000000,0x00000000}},	//   олем, --, --, --, 
   {{0xa0c452c8,0x0ea43c1a,0x00000000,0x00000000}},	//   _ويحو, әкәй_, --, --, 
   {{0x7a400241,0x00000000,0x00000000,0x00000000}},	//   _látú, --, --, --, 
   {{0x61f46282,0x00000000,0x00000000,0x00000000}},	//   ltyl, --, --, --, 
   {{0x3ce003ee,0x7a400174,0x998403e0,0xa6e00413}},	//   şiv_, _nátú, _broş_, íðle, 
   {{0x6f1c21fc,0xf3f80276,0x61f40034,0x14bc6ae8}},	//   _ósca, ăţi_, ntyl, ्रमण, 
   {{0xed3405f5,0x9d4400cf,0x58846ae9,0xd1cc0023}},	//   _нэхэ, _بئرن, жыма, _ኣኣብ_, 
   {{0x9c646aea,0x61f40200,0x00000000,0x00000000}},	//   _بهاو, htyl, --, --, 
   {{0x2b4c55cd,0x61f415c0,0x00000000,0x00000000}},	//   chec_, ktyl, --, --, 
   {{0x94a86aeb,0x95c80063,0x00000000,0x00000000}},	//   итва_, јума_, --, --, 
   {{0xb4d453b7,0xefcc0023,0xdc3803e0,0x05dc37cc}},	//   हणे_, _ኣሃዱ_, lçıp, _बिरब, 
   {{0x2918013b,0xb7d8027d,0x00000000,0x00000000}},	//   ɛsa_, _اوبا_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x75d4038b,0x32546aec,0x61f4010b,0x37dc00cc}},	// [7a50] _عيدا, чвар, gtyl, _বহিৰ, 
   {{0x7bc800a2,0xd01801f0,0x00000000,0x00000000}},	//   _owdu, ифе_, --, --, 
   {{0x05746aed,0x61f403a2,0xcf9816a4,0xc3300050}},	//   _تايد, atyl, ајд_, رٕے_, 
   {{0xfec46aee,0xd3446aef,0xbf5802bf,0x777c00b5}},	//   ِينَ, _بیره_, орії_, nosx, 
   {{0x7bc80cfd,0x61f46af0,0x22506af1,0x6e94084c}},	//   _awdu, ctyl, czyk_, чиду, 
   {{0xfe70007b,0xddc00118,0x00000000,0x00000000}},	//   خدم_, nzoř, --, --, 
   {{0xfe7004a9,0x709407d6,0x26c0068f,0xdca06af2}},	//   ىدۇ_, _хавф, ybko_, наши, 
   {{0x05dc1524,0xfe700133,0x61e00427,0x7e880162}},	//   _बिलब, ردۆ_, šole, ðspæ, 
   {{0xfe086af3,0x7a400332,0x8d840a5b,0xd5d4012d}},	//   _وقفي_, _rátú, _дужд, _बिगड़, 
   {{0x2b4c1762,0xe6b40b98,0xb4d401f9,0x00000000}},	//   shec_, ूर्ज, हणो_, --, 
   {{0x26c001c6,0x3cf808a5,0x00000000,0x00000000}},	//   tbko_, _örva_, --, --, 
   {{0xe4ec000d,0x00000000,0x00000000,0x00000000}},	//   _जाहि_, --, --, --, 
   {{0x64a4010a,0x5b3001d3,0x00000000,0x00000000}},	//   зага, _سٹور, --, --, 
   {{0x98ac0421,0x00000000,0x00000000,0x00000000}},	//   _tofā_, --, --, --, 
   {{0x18646af4,0xe7386af5,0xdb00004e,0x232818b6}},	//   _наши_, _гей_, _bioè, бови_, 
   {{0x61f46af6,0x225002c4,0x26dc0153,0x33380051}},	//   ttyl, tzyk_, ėtos_, _cosx_, 
   {{0x61f401f5,0xe0d86af7,0x00000000,0x00000000}},	// [7a60] utyl, йва_, --, --, 
   {{0x61f46af8,0xb9d8001f,0x98bc0270,0x2250012d}},	//   rtyl, _በወ_, vitī_, rzyk_, 
   {{0x2250068f,0xdb082c95,0x2244238f,0x20540137}},	//   szyk_, ppfø, šok_, чтар, 
   {{0x21a4014b,0x00000000,0x00000000,0x00000000}},	//   _нимм, --, --, --, 
   {{0x3ea004d1,0x539825f9,0xbb44023a,0x00000000}},	//   äit_, _ליטו, äämä, --, 
   {{0xe04407d6,0x3a200427,0x00000000,0x00000000}},	//   _енги, _šipo_, --, --, 
   {{0x69dc0038,0x777c022e,0x1f5401a9,0x00000000}},	//   ásen, yosx, _етаё, --, 
   {{0xc0c401e0,0xf914033f,0x00000000,0x00000000}},	//   _хәҡи, _थोड़ा_, --, --, 
   {{0x05ac033f,0x63a400c0,0x38c83fb8,0x00000000}},	//   _टूलब, _mikn, يادی_, --, 
   {{0x63a433f3,0x62846af9,0x00000000,0x00000000}},	//   _likn, _myko, --, --, 
   {{0x60cc0455,0x00000000,0x00000000,0x00000000}},	//   _mebm, --, --, --, 
   {{0x63a42109,0x00000000,0x00000000,0x00000000}},	//   _nikn, --, --, --, 
   {{0x629800c8,0x5fcc1e61,0x62846afa,0x60cc0ba1}},	//   _ŝton, _हौसल, _nyko, _oebm, 
   {{0xdbd801e1,0x1cc80327,0x5ed00154,0x9f8800a2}},	//   _làíg, _ིབས_, _হাফে, lıän_, 
   {{0x63a41028,0x628400a2,0x33380175,0x09302e0b}},	//   _bikn, _ayko, _posx_, _سروج, 
   {{0x62846afb,0xdb000129,0xdbd80241,0x00000000}},	//   _byko, _bioé, _nàíg, --, 
   {{0xdb00020c,0x63a46afc,0x60cc01e4,0xe79436ba}},	// [7a70] _cioé, _dikn, _bebm, _تاوک, 
   {{0x78b80076,0xd0a86afd,0xbb44005b,0x00000000}},	//   _jfvv, стад_, ääjä, --, 
   {{0x60cc014f,0x2ef46afe,0x7d180175,0x628408a5}},	//   _debm, дзер, ddvs, _eyko, 
   {{0x2bb400e2,0x00000000,0x00000000,0x00000000}},	//   _nāca_, --, --, --, 
   {{0xfd500a28,0x98bc00e4,0x00940139,0x00000000}},	//   lakṣ, aitĩ_, _җитэ, --, 
   {{0x61e0151c,0x91286aff,0x14bc0b7c,0xdbd80248}},	//   šolc, _اسحق_, ्रिण, _tàìg, 
   {{0x59080327,0xeb9800d8,0x6d8c032e,0x00000000}},	//   _ཀྲེས_, оик_, búan, --, 
   {{0x798802d0,0x00000000,0x00000000,0x00000000}},	//   eldw, --, --, --, 
   {{0x14bc0882,0x3c1c01e4,0xae440a81,0xfd500882}},	//   ्राण, _eĉv_, _تھاو, hakṣ, 
   {{0xd99456e8,0x27180051,0xc2140677,0xfd1006c2}},	//   ونيت_, _ỏn_, גהץ_, _مجم_, 
   {{0x66e438ac,0x5ea000db,0x00000000,0x00000000}},	//   мона, _كۅۅل, --, --, 
   {{0xa5b0068f,0xfd500882,0xfaf000f2,0x00000000}},	//   _इंदौ, dakṣ, _مثه_, --, 
   {{0x6b886b00,0x69341586,0xf99004d3,0xe918003b}},	//   mleg, _онду, _ڵبه_, _моді_, 
   {{0x63a46b01,0x07a400c7,0x00000000,0x00000000}},	//   _sikn, ьаҟн, --, --, 
   {{0x62843c6a,0x60cc01e4,0xe7386b02,0x6b886b03}},	//   _syko, _rebm, _мек_, oleg, 
   {{0x6b886b04,0x64a400c7,0x00000000,0x00000000}},	//   nleg, заҳа, --, --, 
   {{0x6f180cfd,0x63a46b05,0x6b886b06,0x75340175}},	// [7a80] ddwc, _vikn, ileg, bjzz, 
   {{0x6b881ebd,0x62846b07,0x69d802ea,0xdcf800ef}},	//   hleg, _vyko, _mvwe, _oktā, 
   {{0x6284006d,0x6b886b08,0xa0084dad,0x63a46b09}},	//   _wyko, kleg, تقال_, _tikn, 
   {{0xdcb00075,0xdb000077,0xddc00034,0x6b88005c}},	//   چىش_, _tioé, czoś, jleg, 
   {{0x6b886b0a,0xdcb01c02,0xdcf80003,0x60cc6b0b}},	//   dleg, نىش_, _jitħ, _tebm, 
   {{0xfd740323,0xdcf8025c,0x23d0033f,0x15e0107c}},	//   эллэ, _mitħ, _तबाद, कूटर_, 
   {{0x6b886b0c,0x212800a3,0x656c007b,0x00000000}},	//   fleg, _inbh_, inbh, --, 
   {{0x6b886b0d,0x00000000,0x00000000,0x00000000}},	//   gleg, --, --, --, 
   {{0x201c2230,0xdcf8031c,0x2bb46991,0x5d6801f4}},	//   _štih_, _nitħ, _vāca_, _диам_, 
   {{0x69d800d2,0xd52801e1,0x3834011c,0x00000000}},	//   _dvwe, _mọ̀b, енор, --, 
   {{0x79886b0e,0x6e2c0115,0x00000000,0x00000000}},	//   rldw, ĥabe, --, --, 
   {{0xb7d8066d,0x6b886b0f,0xfd500882,0xdcf8025c}},	//   _ہوتا_, cleg, vakṣ, _bitħ, 
   {{0x3d2400b0,0xbd0c031c,0x39b8008e,0x00000000}},	//   _tīwē_, _གྲོཊ_, _эллэ_, --, 
   {{0x257001ec,0x00000000,0x00000000,0x00000000}},	//   лқыс, --, --, --, 
   {{0xe7e414cf,0xdb18004a,0xd3a40064,0x6f180042}},	//   _किया_, _atté, драп, ydwc, 
   {{0xc33016a0,0x14bc0882,0x43946b10,0xfd500882}},	//   لەپ_, ्रहण, васс, rakṣ, 
   {{0x69302be7,0xb2745a0e,0x30e401ec,0x00000000}},	// [7a90] _شکیر, хлаш, есең, --, 
   {{0x6b886b11,0xfd500a28,0xddc0068f,0x656c0175}},	//   zleg, pakṣ, szoś, cnbh, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6b8800b5,0x7bd821e3,0x14bc00dc,0x61e00427}},	//   xleg, dsvu, ्रवण, šola, 
   {{0x6b886b12,0x05740344,0x00000000,0x00000000}},	//   vleg, _ساید, --, --, 
   {{0x6b881a56,0x2a686b13,0x00000000,0x00000000}},	//   wleg, _žabo_, --, --, 
   {{0x6b886b14,0x3f840270,0x6d9400a2,0x7bd80158}},	//   tleg, _fkmu_, _aýaý, gsvu, 
   {{0xdb00067c,0x6b880268,0x3ce000fe,0x70580117}},	//   _dioï, uleg, প্লৱ, _даҳр_, 
   {{0x6b886b15,0xda140cf1,0xa968010b,0x00000000}},	//   rleg, तिगत_, зипа_, --, 
   {{0x6b886b16,0x3d94035b,0x9e942ac8,0x9f480793}},	//   sleg, _аиур, _ساقچ, ömön_, 
   {{0x6b886b17,0xef18003d,0xfbd06b18,0x108001ec}},	//   pleg, _każ_, _نتن_, _ﯨﻨﺪﯨ, 
   {{0x48d80316,0x00000000,0x00000000,0x00000000}},	//   _गएको_, --, --, --, 
   {{0xef180135,0xa2cc00dc,0x2bb40055,0x98ac0064}},	//   _maż_, तरस्, _kāco_, _sofą_, 
   {{0x5e54010f,0x0c800092,0x00000000,0x00000000}},	//   גישע_, _ርዕሶች_, --, --, 
   {{0x23286b19,0x59080327,0x33d401ec,0x00000000}},	//   пови_, _ཀྲིས_, кітт, --, 
   {{0xdcf80003,0x00000000,0x00000000,0x00000000}},	//   _titħ, --, --, --, 
   {{0x25680139,0xe12400c7,0x6abc06ea,0x00000000}},	// [7aa0] _наип_, нмаи, ðsfy, --, 
   {{0x26d03bfe,0x52806b1a,0x661400e4,0xdbd80241}},	//   _heyo_, угуб, _isyk, _làág, 
   {{0x26d001af,0x630400d1,0x00000000,0x00000000}},	//   _keyo_, _كودل, --, --, 
   {{0x2d8407ab,0x26d00241,0x35740023,0x00000000}},	//   _akle_, _jeyo_, _ሸቶታት_, --, 
   {{0xef18025c,0x26d0007f,0xdbd801e1,0xc0c00240}},	//   _daż_, _meyo_, _sààg, ትላል_, 
   {{0x26d00163,0x2d840295,0x7bd86b1b,0xddc00de2}},	//   _leyo_, _ckle_, tsvu, lyoŋ, 
   {{0xdee46b1c,0xd0046b1d,0xfff86b1e,0x201c02d2}},	//   _пови, _пере_, _زکات_, _éti_, 
   {{0x2d840365,0x7bd83e04,0x8fa06b1f,0x26d06b20}},	//   _ekle_, rsvu, _басе, _neyo_, 
   {{0x8cc8012d,0x05dc00bc,0xefec0092,0x4c806b21}},	//   _सड़को, _बिगब, ቆየው_, кләв, 
   {{0x0e600276,0x7bd803cd,0x98bc0153,0xdca46830}},	//   _скун, psvu, ritį_, _зази, 
   {{0x661400c7,0x69300244,0x0900013d,0x00000000}},	//   _asyk, شکور, учым, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x26d06b22,0x55046b23,0x964401c0,0x00000000}},	//   _deyo_, нчва, хэнд, --, 
   {{0xd90c034c,0x26d00009,0xe7ec000d,0x00000000}},	//   _اید_, _eeyo_, चूहा_, --, 
   {{0xb4b013f7,0x56f000fb,0x00000000,0x00000000}},	//   _ओली_, _йүнс, --, --, 
   {{0x26d06b24,0xf5380092,0x2fd800f1,0x93400228}},	//   _geyo_, _ያገኘነ, ېواد_, دىرۇ, 
   {{0x7674399b,0x6b5401e7,0x016c0023,0x90e431e4}},	// [7ab0] _шлиф, _fágf, _ተረኽበ_, فسان, 
   {{0xef18031c,0x00000000,0x00000000,0x00000000}},	//   _saż_, --, --, --, 
   {{0x26d00083,0x00000000,0x00000000,0x00000000}},	//   _yeyo_, --, --, --, 
   {{0x2d840306,0x0cb80401,0x00000000,0x00000000}},	//   _skle_, ॉर्म, --, --, 
   {{0x9f600174,0x00000000,0x00000000,0x00000000}},	//   ðvág_, --, --, --, 
   {{0x01c801ed,0xc69408a8,0x7e780419,0x00000000}},	//   _سوفٹ_, נאס_, _ťapá, --, 
   {{0x2ef41b6b,0xef18003d,0x0094013d,0x8cd0000d}},	//   _извр, _taż_, _бирэ, डरबो, 
   {{0x35980092,0xdcb40166,0x00000000,0x00000000}},	//   መረበት_, нгәч_, --, --, 
   {{0x295400a7,0x0dc8013e,0x7bdc1427,0x7fac06be}},	//   вънр, _хуби_, _ærun, _işqa, 
   {{0x26d06b25,0x00000000,0x00000000,0x00000000}},	//   _seyo_, --, --, --, 
   {{0x661401f4,0x00000000,0x00000000,0x00000000}},	//   _ssyk, --, --, --, 
   {{0xdb2410e8,0xe2a406ea,0x5c34010f,0x00000000}},	//   _لومی, íðka_, _ברען_, --, 
   {{0xdb241968,0x00000000,0x00000000,0x00000000}},	//   _جونی, --, --, --, 
   {{0x7dd80597,0x26d00295,0xd04400ac,0xd9400354}},	//   _húsá, _weyo_, şməs, _веши, 
   {{0x7dd800d2,0xfaa40075,0x7b08143a,0x6b5403b2}},	//   _kúsá, _ишән, _åstø, _vágf, 
   {{0xa2540214,0x3a200010,0x835400e5,0x00000000}},	//   نپزش, _šipi_, اھدا, --, 
   {{0xe1f800e6,0xe5780209,0xe8186b26,0x208800d1}},	// [7ac0] ьга_, _ози_, धिका_, _ﺑﯜﮔﯜ, 
   {{0xd5b41533,0x61e0000a,0xe3b00fc6,0x7fac6b27}},	//   _इंतज, šolo, _پرد_, _aşqa, 
   {{0x6b5403b2,0xd00c00c6,0x64a41fbe,0xa2e46b28}},	//   _gágg, يلك_, _јана, _ионд, 
   {{0x7dd801e7,0x5474011a,0x626401c6,0x13b4011a}},	//   _núsá, _יגיע_, _авма, _שהכל_, 
   {{0x3b0003f0,0xdb0c06af,0x5dd8005a,0x00000000}},	//   _ñiqi_, _àdéc, ффер_, --, 
   {{0x2370007c,0xd1b00244,0x00000000,0x00000000}},	//   lnyj_, _ئیلک, --, --, 
   {{0x30746b29,0x98bc0024,0x7dd8032e,0xcd30007b}},	//   _бутс, nktą_, _búsá, شروب, 
   {{0x7dcc025a,0x7b1402ff,0x00000000,0x00000000}},	//   gôsî, удих, --, --, 
   {{0xdef80184,0x9cf400a8,0xd90c0014,0xbd84010a}},	//   _ныҡ_, _ачеш, ٲیب_, _йӳкк, 
   {{0xd90c1b8d,0xb4b00d79,0xe4ec0037,0xfcd800e5}},	//   زیب_, _ओले_, _जागि_, _سائڈ_, 
   {{0xefd40020,0x7f40676c,0xd9b000d1,0x36d46b2a}},	//   _ከባድ_, _komq, _ھەدد, лонр, 
   {{0x5a6405a2,0x00000000,0x00000000,0x00000000}},	//   _икеб, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x73c40cef,0x7f40016d,0x543403e6,0x00000000}},	//   ләме, _lomq, پرسر, --, 
   {{0x61e0000a,0x89340375,0x83f80798,0x00000000}},	//   šoll, _ברגע_, керс_, --, 
   {{0x7f406b2b,0x26dc016b,0x73c401e0,0x00000000}},	//   _nomq, ɔtoo_, _ҡәбе, --, 
   {{0xd4e401d5,0x2bd82efd,0x00000000,0x00000000}},	// [7ad0] _июни, _यौना, --, --, 
   {{0xf484158b,0xa6e00162,0x00000000,0x00000000}},	//   _ماجی, _æðra, --, --, 
   {{0x7f406b2c,0xd4986b2d,0x81d4015b,0x00000000}},	//   _bomq, _юри_, সূল_, --, 
   {{0xe7e46b2e,0x00000000,0x00000000,0x00000000}},	//   _किसा_, --, --, --, 
   {{0x201c05a1,0x5ed000eb,0x00000000,0x00000000}},	//   _štit_, _হাশে, --, --, 
   {{0x32180129,0x00000000,0x00000000,0x00000000}},	//   _issy_, --, --, --, 
   {{0x826403e6,0x40346b2f,0x6c3402c9,0x00000000}},	//   _مهێن, _керс, افعا, --, 
   {{0xe8bc04af,0x00000000,0x00000000,0x00000000}},	//   ोर्च, --, --, --, 
   {{0x6ec80825,0x19c00150,0x00000000,0x00000000}},	//   _ह्यु, ббым, --, --, 
   {{0x7f4001b3,0x00000000,0x00000000,0x00000000}},	//   _zomq, --, --, --, 
   {{0x6d406b30,0x7f40004b,0x00000000,0x00000000}},	//   _iola, _yomq, --, --, 
   {{0x6d406b31,0xe738013e,0xaba81df2,0x00000000}},	//   _hola, хем_, _ﺷﺎﻣﺎ, --, 
   {{0x6d406b32,0x57440212,0xe7e40073,0xa2e401d5}},	//   _kola, узям_, _किवा_, ғозд, 
   {{0x6d406b33,0x394c011c,0x00000000,0x00000000}},	//   _jola, ckds_, --, --, 
   {{0x32180561,0x6d403d97,0xa2e40c54,0x838800e5}},	//   _assy_, _mola, ловд, نصرہ_, 
   {{0x6d406b34,0x2b4c4b16,0x98bc00c0,0x00000000}},	//   _lola, nkec_, rktą_, --, 
   {{0x6d40198f,0x23700158,0x6b540ca8,0x76a8002b}},	// [7ae0] _oola, rnyj_, _kágb, _pīyū, 
   {{0x6d406b35,0x20546b36,0x7f406b37,0xa0a400f7}},	//   _nola, лтер, _somq, газд, 
   {{0x32182a4e,0xdb08007c,0x3cf802d2,0x00000000}},	//   _essy_, mpfö, _örvi_, --, 
   {{0x6d401140,0x7f40014f,0x6b540cad,0x8fa00354}},	//   _aola, _qomq, _lágb, бахе, 
   {{0x6d406b38,0x9e740214,0x44380076,0x9d4400db}},	//   _bola, دهشت, lxr_, ледд, 
   {{0x7f404b2a,0x00000000,0x00000000,0x00000000}},	//   _womq, --, --, --, 
   {{0x7f400211,0x5c040228,0x7c2400b0,0x6d44005b}},	//   _tomq, уяла, āiro, öhaa, 
   {{0x6d4006d5,0x7bdc0008,0x6e380118,0x3218010b}},	//   _eola, _ærum, _šíří_, _yssy_, 
   {{0x6d406b39,0x6b540ca8,0xfe700345,0x00000000}},	//   _fola, _bágb, _بگا_, --, 
   {{0x6d406b3a,0x6b5403b2,0xe2a4032e,0x00000000}},	//   _gola, _ráge, _æðum_, --, 
   {{0x6b540248,0xb8dc3d1d,0x1ae41340,0x77982cdd}},	//   _dágb, _अल_, _боем, ккор_, 
   {{0x6d406b3b,0x27343ed0,0x00000000,0x00000000}},	//   _zola, لىپس, --, --, 
   {{0x6b546b3c,0xf9d4010b,0xb93400d8,0xd4e46b3d}},	//   _fágb, _толэ, _велј, люви, 
   {{0x6d406b3e,0x49e001d9,0x00000000,0x00000000}},	//   _xola, _آوٕ, --, --, 
   {{0x88b800c8,0xdb0c00e4,0x80d80118,0x00000000}},	//   _אזוי, _ÿjóv, यरने, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x43946b3f,0x7fac0139,0x956402e8,0xd5b801e0}},	// [7af0] сатс, _aşqo, _бънд, _ясй_, 
   {{0x7c286b40,0xf778031c,0x00000000,0x00000000}},	//   _ordr, rrħu_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x32180109,0x00000000,0x00000000,0x00000000}},	//   _tssy_, --, --, --, 
   {{0x6d406b41,0x7c286b42,0x5eb03bf0,0x8ca40ce0}},	//   _pola, _ardr, әйәт, टेनो, 
   {{0x6da46b43,0x6d406b44,0xe7e405b3,0xada41fdd}},	//   шила, _qola, _किला_, шалл, 
   {{0x6d406b45,0xeab00597,0x2bb400b8,0xa26400d7}},	//   _vola, يعة_, _kāci_, rlôž, 
   {{0x6d406b46,0x6b5401e1,0x00000000,0x00000000}},	//   _wola, _ságb, --, --, 
   {{0x7c286b47,0x2b4c6b48,0x2bb400ef,0x00000000}},	//   _erdr, rkec_, _māci_, --, 
   {{0x6e280230,0x6d406b49,0x78a401e4,0x2b4c0156}},	//   _ireb, _uola, _ŝiva, skec_, 
   {{0x6e286b4a,0x7f980309,0x6b540174,0xec1435aa}},	//   _hreb, líqa, _vágb, _خواد, 
   {{0x6e28366a,0x00000000,0x00000000,0x00000000}},	//   _kreb, --, --, --, 
   {{0xbb840597,0x6f0800f2,0x80d80c70,0x6b540241}},	//   _الني, _mbec, यरमे, _tágb, 
   {{0x69c86b4b,0x6e28020c,0x61e00427,0xa968011c}},	//   mpee, _mreb, šolk, _шила_, 
   {{0x64a46b4c,0x6f086b4d,0x69c827b2,0x6d8c02d2}},	//   рава, _obec, lpee, búav, 
   {{0x6e286266,0xe2980075,0xc0240023,0x2904031c}},	//   _oreb, ваб_, _ሰላማው, lfla_, 
   {{0xdb086b4e,0xc69000f1,0x00000000,0x00000000}},	// [7b00] ppfö, _رېس_, --, --, 
   {{0xe3b83a5c,0x29040c86,0x7fac03b9,0xf1a816ac}},	//   _ибо_, nfla_, _eşql, هاله_, 
   {{0x6e286b4f,0xdef8013d,0x00000000,0x00000000}},	//   _areb, выл_, --, --, 
   {{0x6e286b50,0x5f044eca,0x6d443b22,0x00000000}},	//   _breb, рзда, öhan, --, 
   {{0x6e286b51,0xde7400db,0x00000000,0x00000000}},	//   _creb, جداع, --, --, 
   {{0x8e440075,0x6e286b52,0x6f086b53,0x6ec41e4a}},	//   شلىك_, _dreb, _ebec, لتۇق, 
   {{0x6e286b54,0xa0683ab8,0x69c8057b,0xe454008f}},	//   _ereb, _рава_, epee, ייַט_, 
   {{0x6e2819f5,0x69c80162,0x5b240108,0x6b5400e5}},	//   _freb, fpee, рька, _rágc, 
   {{0x6e286b55,0x99800316,0x23880024,0x29046b56}},	//   _greb, íků_, mėję_, ffla_, 
   {{0x7d0802d0,0x8d6002e8,0xba0400db,0x23880153}},	//   _ubds, _двуе, _ۇستۉ, lėję_, 
   {{0x69c86b57,0x6e280165,0x9f5c0248,0x00000000}},	//   apee, _zreb, _ètó_, --, 
   {{0x38c8168d,0x48a46b58,0x765c0112,0x80d8012d}},	//   _ڵاتی_, штым_, tzsy, यरडे, 
   {{0xd90c00e5,0x69dc0174,0x6f0000e5,0x00000000}},	//   _ہیک_, áset, lábó, --, 
   {{0x14c404fb,0x00000000,0x00000000,0x00000000}},	//   شهری_, --, --, --, 
   {{0x6b546428,0xd7f8084c,0x71780fc0,0xd90c020e}},	//   _hága, _рул_, ҳбар_, _فیک_, 
   {{0x79880912,0xd5b86b59,0x468801f2,0x3ea000bc}},	//   lodw, _исо_, ọtị_, žity_, 
   {{0x23880024,0x2bb4002b,0x37b800fe,0x00000000}},	// [7b10] dėję_, _vāci_, _আবিৰ, --, 
   {{0x79886b5a,0x6e280240,0x6f0803cb,0x6f0000e5}},	//   nodw, _rreb, _sbec, kábó, 
   {{0x6f0001ed,0x2b800034,0xcfa401b9,0x6b546b5b}},	//   jábó, rócz_, ашди, _lága, 
   {{0x6e2854b0,0x2ef401af,0x79886b5c,0xcee802da}},	//   _preb, сздр, hodw, ئران_, 
   {{0xfe706b5d,0x4a00025c,0xdd8c39b1,0x79886b5e}},	//   وده_, _མདེལ_, کوو_, kodw, 
   {{0x6e282220,0xd7e4215c,0xa5d8010f,0x32146b5f}},	//   _vreb, _ىك_, אַקי, ğayı_, 
   {{0x80dc00e1,0x79880142,0x6e2800a2,0x6f0001d3}},	//   _फ़ते, dodw, _wreb, gábó, 
   {{0x6e286b60,0x6f086b61,0x2b140212,0xada46b62}},	//   _treb, _ubec, ськр, шаһл, 
   {{0x6e280796,0xaa486b63,0x3e1812c4,0x69c8009f}},	//   _ureb, уппа_, _котэ_, upee, 
   {{0x69c8049b,0xbdc80014,0x7d2400db,0x9f5c110e}},	//   rpee, _خدٲے_, _وېنۇ, _ètò_, 
   {{0x69c80e29,0x6c84007b,0xe7a8009d,0x00000000}},	//   spee, _الضم, лвол_, --, 
   {{0x69c86b64,0x6b546b65,0x00000000,0x00000000}},	//   ppee, _fága, --, --, 
   {{0x79881cdf,0x6b8804c9,0x6b5401e1,0xe5a4611f}},	//   bodw, moeg, _gága, йими, 
   {{0x6b886b66,0xf98401d9,0x67c00171,0xe5a401a9}},	//   loeg, _وجوٝ, _vējb, сиги, 
   {{0x6844084c,0xf778031c,0x00000000,0x00000000}},	//   _ынка, ssħa_, --, --, 
   {{0x67540502,0x6b886b67,0xe6186b68,0x00000000}},	//   _دختر, noeg, _бди_, --, 
   {{0x6d8c1d5d,0x6f0001d3,0xc30c03d4,0x97540677}},	// [7b20] núas, zábó, ৱালি_, _ליקו_, 
   {{0x7164470b,0x6d44005b,0x6b880051,0x00000000}},	//   يالك, öhal, hoeg, --, 
   {{0x656c1929,0xd8d800c8,0x6b88005a,0xd24c1c3b}},	//   mibh, רקער, koeg, ونہ_, 
   {{0x656c6b69,0x644c6b6a,0x7988004b,0xd00c3fe2}},	//   libh, mybi, zodw, علن_, 
   {{0x644c6b6b,0x79886b6c,0x656c3e7c,0xbfc800d1}},	//   lybi, yodw, oibh, _چارە_, 
   {{0x93c80014,0x61f46b6d,0x6f0001d3,0x00000000}},	//   _جایہ_, muyl, tábó, --, 
   {{0xdd90040b,0x61f42fbe,0x644c6b6e,0x6b886b6f}},	//   _ہور_, luyl, nybi, foeg, 
   {{0x79886b70,0x6b540077,0x656c6b71,0x26c00010}},	//   wodw, _pága, hibh, jcko_, 
   {{0x656c6b72,0x61f405d1,0x7988013f,0xdd906b73}},	//   kibh, nuyl, todw, _فور_, 
   {{0x26c0068f,0x6b540579,0x644c0006,0xd8386b74}},	//   ecko_, _vága, kybi, гэм_, 
   {{0x61f403f0,0x656c0882,0x798800e8,0x644c0153}},	//   huyl, dibh, rodw, jybi, 
   {{0x79886b75,0x644c0024,0x964401c0,0x61f46b76}},	//   sodw, dybi, бэгд, kuyl, 
   {{0x656c59fc,0x60dc1a87,0xdd0403b9,0xd37800c7}},	//   fibh, kapm, _xöşb, ҳча_, 
   {{0x656c6b77,0x6d5c0006,0xca68022e,0x61f40790}},	//   gibh, _įsak, _yagо, duyl, 
   {{0x60dc0a2e,0x6b5401d3,0x644c6b78,0xd3780aac}},	//   dapm, _mágn, gybi, гча_, 
   {{0x41740131,0x92b4007b,0x656c01ab,0x938801d5}},	//   ۋالس, صحرا, aibh, усга_, 
   {{0x6298010f,0xa4f401d5,0xdb1801f4,0x61f40205}},	// [7b30] _ŝtor, _ژکفر_, _ittä, guyl, 
   {{0x60dc020b,0x656c6b79,0xd24c004b,0x34480117}},	//   gapm, cibh, ونځ_, _кӯби_, 
   {{0x6b88009f,0x644c6b7a,0x6d4401f4,0x00000000}},	//   yoeg, cybi, öham, --, 
   {{0x1ee82be7,0x61f403e0,0x00000000,0x00000000}},	//   لومی_, buyl, --, --, 
   {{0x6b88207e,0x7bc80171,0x61f40205,0x877c00df}},	//   voeg, _atdu, cuyl, נאדי, 
   {{0xdcac0131,0x60dc6b7b,0xd1380117,0x00000000}},	//   ھىي_, capm, _схм_, --, 
   {{0xdca06b7c,0xf074040b,0x6b886b7d,0xa2cc0490}},	//   маши, _بیاں_, toeg, तरच्, 
   {{0x656c0912,0x26dc013f,0x6d8c1709,0x7f580022}},	//   zibh, ɔtow_, túas, _ласс_, 
   {{0x656c2a6c,0x644c6b7e,0x6b885282,0x4424004d}},	//   yibh, zybi, roeg, ̉m_, 
   {{0x6b886b7f,0x00000000,0x00000000,0x00000000}},	//   soeg, --, --, --, 
   {{0xe7386b80,0x656c0882,0x386002a8,0x6b8800c5}},	//   аен_, vibh, _ƙira_, poeg, 
   {{0x61f40bf1,0x644c0006,0x656c00f1,0x00000000}},	//   yuyl, vybi, wibh, --, 
   {{0x86500134,0x656c6b81,0x60dc036b,0x2bb4005f}},	//   _afɔr, tibh, yapm, _vācu_, 
   {{0x644c6b82,0xb4c401e0,0xdb180108,0x48a400fe}},	//   tybi, зирҙ, _että, _গভীৰ, 
   {{0x656c0882,0xa3480801,0x1864430d,0xfa340137}},	//   ribh, азва_, _маши_, _ورۇد, 
   {{0x656c2935,0x6b540587,0x644c373e,0xdb180120}},	//   sibh, _mágo, rybi, _autê, 
   {{0xe0d86b83,0x60dc020b,0x8ed400fe,0x6b5452e1}},	// [7b40] ива_, tapm, _হাংগ, _lágo, 
   {{0xc7b4016b,0xa3b80531,0x61f462c7,0x672403cd}},	//   _hiɑ_, _پادر_, ruyl, ldkj, 
   {{0x61f46b84,0x60dc6b85,0x657c02d0,0x00000000}},	//   suyl, rapm, _ijph, --, 
   {{0x672408fb,0x61f46b86,0x6db8010e,0x60dc6b87}},	//   ndkj, puyl, _oňad, sapm, 
   {{0x61f402d1,0x33b000d1,0x00000000,0x00000000}},	//   quyl, _سەكر, --, --, 
   {{0x6b54056a,0xdd8c01ed,0x60dc6b88,0x71c40107}},	//   _bágo, کوڈ_, qapm, _харҷ, 
   {{0x9f5c025a,0xe818060e,0x79600cad,0xe00c0ebb}},	//   _ëtï_, _फैला_, _láwù, _सहिद_, 
   {{0xe8c4031c,0x00000000,0x00000000,0x00000000}},	//   _གཅུག, --, --, --, 
   {{0x95280135,0x848c00b7,0x7e986b89,0x00000000}},	//   _སྣའི_, _መድህን_, _اچار_, --, 
   {{0x6b541d5d,0x61e402f0,0x673401d3,0xdcec0064}},	//   _fágo, _mvkl, _anyj, _įdėd, 
   {{0xdb186b8a,0x7fac0139,0x7bc8010e,0x6d8c00e4}},	//   _attå, _aşqi, _utdu, púar, 
   {{0xd6d823a4,0xaba4007b,0x00000000,0x00000000}},	//   што_, _فإنه, --, --, 
   {{0x7ae06b8b,0x45d4036b,0xdb18036e,0x67c000de}},	//   mamt, мояс, _lutë, _vēja, 
   {{0x7ae06b8c,0x52d001ad,0x6b541d1d,0x2a6800a2}},	//   lamt, तर्स, _lágl, _ýaba_, 
   {{0x61e411ad,0x7d186b8d,0x629800df,0xdb181e10}},	//   _avkl, ievs, _ŝtop, _ettå, 
   {{0x26140574,0x1af8015b,0xa8001bce,0x27f00419}},	//   _पैकी_, ্যকে_, ññee, ázne_, 
   {{0x776c36ed,0x75f06b8e,0xabe00220,0xf288009d}},	// [7b50] _imax, _qızğ, _ﺍﻹﻤﺎ, сөнд_, 
   {{0x7ae06b8f,0x7d18506e,0x26cc013f,0xed58107d}},	//   hamt, jevs, _ɑfom_, _kuže_, 
   {{0x7ae06b90,0x61e40109,0xb5bc0011,0x6b5401ef}},	//   kamt, _evkl, _অবিচ, _bágl, 
   {{0xed58012c,0x7ae06b91,0xaba801ec,0x00000000}},	//   _muže_, jamt, _ﺷﺎﻋﺎ, --, 
   {{0x7ae0198f,0xed586b92,0x00000000,0x00000000}},	//   damt, _luže_, --, --, 
   {{0xabd41677,0x82e8031c,0xdb180240,0x85f80375}},	//   пциј, _འཇོའ, _futë, קצוע_, 
   {{0x009405f5,0x7ae0198f,0x2720009e,0xaed46b93}},	//   _жирэ, famt, যাতো_, _новш, 
   {{0x7ae06b94,0x5fa00727,0x752401b9,0x6b541a62}},	//   gamt, _كەلم, _lahz, _vágo, 
   {{0x888001d3,0x7e2800c0,0x00000000,0x00000000}},	//   ڈیشن, _міфа_, --, --, 
   {{0x776c00aa,0xdb180561,0x888001d3,0x6f186b95}},	//   _amax, _lutè, ویشن, lewc, 
   {{0x7ae06b96,0xe7280276,0x3d00000d,0x00000000}},	//   bamt, бонд_, _राते_, --, 
   {{0xed58071b,0xfbd0158b,0x6f186b97,0xd1bc0092}},	//   _duže_, _شتم_, newc, ስማት_, 
   {{0x8ca40cf1,0x6724143a,0x00000000,0x00000000}},	//   टेरो, rdkj, --, --, 
   {{0x69d81859,0x776c02c4,0xdb180137,0xba740050}},	//   _iwwe, _emax, _autè, _تامت, 
   {{0x68e06b98,0xdb18067c,0x6b540008,0xf1b45ae4}},	//   mald, _butè, _lágm, _अंजन, 
   {{0x68e06b99,0x69d80472,0x3f78009b,0x7d1800f3}},	//   lald, _kwwe, rčuk_, zevs, 
   {{0x7d186b9a,0x75240109,0x80d86b9b,0x68e0005a}},	// [7b60] yevs, _fahz, यरले, oald, 
   {{0x64a46b9c,0x7ae002a8,0x69d8007f,0x3d0009b2}},	//   _напа, zamt, _mwwe, _राधे_, 
   {{0x73c00184,0x7ae06b9d,0x68e001c4,0x14d4008f}},	//   _аҡса, yamt, iald, _מויל_, 
   {{0x69d80e14,0x7ae000e8,0xaf4800ec,0x00000000}},	//   _owwe, xamt, يشنل_, --, 
   {{0x68e06b9e,0xf3f0001e,0x63bc0455,0xdb1800e8}},	//   kald, ợc_, _hupn, _wutë, 
   {{0x63bc6b9f,0x68e02833,0x61e009a8,0xef9007d6}},	//   _kupn, jald, šols, _ییلد, 
   {{0x7ae06ba0,0x7d186ba1,0x68e06ba2,0xa0a405f5}},	//   tamt, revs, dald, _хавд, 
   {{0x7d1801fa,0x63bc0139,0x19a86ba3,0x00000000}},	//   sevs, _mupn, әтип_, --, 
   {{0x7ae06ba4,0x63bc0477,0x6d8c00e4,0x00000000}},	//   ramt, _lupn, púap, --, 
   {{0x7ae06ba5,0x68e06ba6,0xed5801a6,0xdb180129}},	//   samt, gald, _puže_, _muté, 
   {{0x69d81f21,0x7ae0071b,0x776c0066,0xdb180129}},	//   _ewwe, pamt, _pmax, _luté, 
   {{0x7ae06ba7,0x68e000c5,0x00000000,0x00000000}},	//   qamt, aald, --, --, 
   {{0x68e00323,0xf8b80323,0x63bc06c8,0xc6a4035b}},	//   bald, _мөн_, _aupn, ерри, 
   {{0x68e05410,0x4a5000d6,0xed581050,0x7fac0139}},	//   cald, _якіс, _tuže_, _işqu, 
   {{0xdb1809ff,0xbf1c0490,0x6d4401f4,0x9660030d}},	//   _auté, _नसून_, öhai, ĕкре, 
   {{0x776c0b6f,0xdb1806af,0x00000000,0x00000000}},	//   _umax, _buté, --, --, 
   {{0x63bc003e,0x752405b1,0xfcb80092,0xc3300050}},	// [7b70] _eupn, _tahz, _ሲመጡ_, ھٕے_, 
   {{0x63bc005c,0xd5840133,0xdb1801ef,0x00000000}},	//   _fupn, _رێزه_, _duté, --, 
   {{0xb4d80cf1,0xdb180ba1,0x2e1c02e2,0xc950010f}},	//   ारी_, _tutè, _sňf_, עמע_, 
   {{0x68e001c0,0xdb1806af,0x249c0205,0x00000000}},	//   zald, _futé, ütme_, --, 
   {{0xfde80046,0x63bc4b16,0x68e015b7,0xbfb4592e}},	//   здік_, _zupn, yald, رحمت, 
   {{0x32080c8c,0x51846ba8,0x6f180042,0xe6b8012d}},	//   mtay_, _хума, sewc, _इल्ज, 
   {{0x68e06ba9,0x32086baa,0x00000000,0x00000000}},	//   vald, ltay_, --, --, 
   {{0x395c07c5,0xb4d832c6,0x33286bab,0x32086bac}},	//   _alvs_, ारु_, ndax_, otay_, 
   {{0x68e06bad,0x4ea40b7f,0x848c1954,0x25a8015d}},	//   tald, _хрва, _መድሕን_, ymbl_, 
   {{0x3208035a,0x00000000,0x00000000,0x00000000}},	//   itay_, --, --, --, 
   {{0xfcb8001f,0x7fac008e,0x3ec4143a,0x7dc40150}},	//   _ሲመጣ_, _eşqu, _åstå_, _قتەك, 
   {{0x68e06bae,0x4ae407d6,0xe7386baf,0x9f8802d3}},	//   sald, _хўжа, цем_, _ንባዕሉ_, 
   {{0x68e06bb0,0xb4d8007d,0x63bc014f,0x3328058a}},	//   pald, ारू_, _supn, ddax_, 
   {{0x64a46bb1,0x32080c8c,0x63bc6bb2,0x68e0439e}},	//   дага, dtay_, _pupn, qald, 
   {{0x88e0045e,0xaad00cf1,0x3208035a,0x00000000}},	//   _মাপক, _सभाक, etay_, --, 
   {{0x32086bb3,0xdb186bb4,0x2eec002e,0x63bc014f}},	//   ftay_, _puté, _ndef_, _vupn, 
   {{0x2fcc04b9,0x91e06bb5,0x32080050,0xe2a84b14}},	// [7b80] _čega_, коте, gtay_, زارن_, 
   {{0x63bc62cc,0x661400c7,0xe5786bb6,0x00000000}},	//   _tupn, _ipyk, _фзо_, --, 
   {{0x32086bb7,0x63bc00f3,0xdb18002e,0x6b5401d3}},	//   atay_, _uupn, _wuté, _vágj, 
   {{0x32080a81,0xc0ec36d7,0x2eec0165,0x3d0004fa}},	//   btay_, _ቅድም_, _cdef_, _राहे_, 
   {{0x88e002f5,0x3208127b,0x64480241,0xe81c012d}},	//   _মানক, ctay_, _àfib, यौता_, 
   {{0xdfd00597,0x2eec0175,0x357c02d3,0xa0686bb8}},	//   _ليس_, _edef_, _ኣዴታት_, _дага_, 
   {{0x2b5c0042,0x5574008f,0x91000139,0xfb3400ee}},	//   _blwc_, ועסן_, _шпре, енйэ, 
   {{0x66140022,0xdb00004d,0x9e600092,0x10a000f3}},	//   _opyk, _khoé, ዴራልና_, _рисн, 
   {{0x8bb00597,0x06c80150,0x1be8000d,0x00000000}},	//   خصوص, _ﺒﺘﻘﺩ, _टिकल_, --, 
   {{0x9984107d,0x89d40014,0x6b5402d2,0x49700166}},	//   _broš_, بوٝر_, _lágh, клыс, 
   {{0x66146bb9,0xd0f40302,0x61f46bba,0x320802d0}},	//   _apyk, ומית_, hryl, ztay_, 
   {{0x32086bbb,0x61f42f53,0x27f002f0,0x998400ef}},	//   ytay_, kryl, ázna_, _droš_, 
   {{0xc0ec067d,0x996422e9,0xb7d861be,0x320803ac}},	//   _ቅድሚ_, _откл, _کوبا_, xtay_, 
   {{0xb4d810b7,0xed580219,0xd7f86bbc,0x3208014f}},	//   ारे_, _kuža_, _дуи_, vtay_, 
   {{0x63a401fa,0x661400e4,0x61f4000f,0x93c40051}},	//   _bhkn, _epyk, eryl, _giặ, 
   {{0x32086bbd,0xed581c75,0x00000000,0x00000000}},	//   ttay_, _muža_, --, --, 
   {{0x43946bbe,0x31341d39,0xdb000051,0x33286bbf}},	// [7b90] татс, неар, _choé, rdax_, 
   {{0x32086bc0,0x85740153,0x00000000,0x00000000}},	//   rtay_, _альх, --, --, 
   {{0x32082f05,0x2ef46bc1,0x05741a59,0x2eec067c}},	//   stay_, езер, _جايد, _pdef_, 
   {{0x32086bc2,0x66140588,0xed50210e,0x00000000}},	//   ptay_, _ypyk, گھر_, --, 
   {{0x61f46bc3,0x32086bc4,0xa2f40375,0x00000000}},	//   cryl, qtay_, _אמרה_, --, 
   {{0xed5001d3,0x67c000ef,0x00000000,0x00000000}},	//   دھر_, _sējm, --, --, 
   {{0xefec0023,0x800400cf,0x80b4014b,0x00000000}},	//   _ቅጥዒ_, _ичте, _абрх, --, 
   {{0xdb18006a,0xe9d83804,0xed5805a1,0x2eec004e}},	//   _dutï, пки_, _duža_, _udef_, 
   {{0x1ee822cd,0x7d28023a,0x7fac06be,0x00000000}},	//   _رولی_, össä, _eşqs, --, 
   {{0xb4d8002b,0x6b546bc5,0xfd106bc6,0x00000000}},	//   ारो_, _mági, _نجم_, --, 
   {{0x66146bc7,0x6b541427,0x9f580b1a,0x2af40006}},	//   _spyk, _lági, stpå_, _зялё, 
   {{0x61f409a5,0x6eb4013a,0x00000000,0x00000000}},	//   yryl, ेशपु, --, --, 
   {{0x27200154,0x00000000,0x00000000,0x00000000}},	//   যালো_, --, --, --, 
   {{0x30d000cc,0x95b4013d,0x00000000,0x00000000}},	//   াণুস, ерсә, --, --, 
   {{0xa87800c8,0x23340124,0x99846bc8,0xd7c404af}},	//   _מאַר, нхар, _uroš_, _रूपच, 
   {{0x61f46bc9,0xe508004b,0x63a400b5,0x59d4095f}},	//   tryl, _کيدو_, _qhkn, ढीकर, 
   {{0x661400e4,0xb9cc010f,0x00000000,0x00000000}},	// [7ba0] _upyk, ַזאָ, --, --, 
   {{0x61f46bca,0x63780100,0xabe00220,0x00000000}},	//   rryl, důne, _ﺍﻹﻁﺎ, --, 
   {{0x40b40276,0xa2e4030d,0x00000000,0x00000000}},	//   траӂ, _понд, --, --, 
   {{0x5de406bb,0xed586bcb,0xdb1808fb,0x61f40267}},	//   ежда, _ruža_, _uttø, pryl, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xed5801a6,0xd00c6bcc,0x67c00171,0xdb20032e}},	//   _puža_, _گلف_, _vējj, _þrúg, 
   {{0x10a06bcd,0x4c906bce,0x260006e3,0x00000000}},	//   _бирн, лишс, वंडी_, --, 
   {{0xa3e06bcf,0x9f5800f2,0x9e6400ec,0xa0681188}},	//   नीय_, kupé_, _ٻارن, _даҳа_, 
   {{0xdef801af,0x00000000,0x00000000,0x00000000}},	//   _мыҡ_, --, --, --, 
   {{0xf8b800db,0x00000000,0x00000000,0x00000000}},	//   мөй_, --, --, --, 
   {{0x36d40107,0xa3e008ec,0x00000000,0x00000000}},	//   конр, नीम_, --, --, 
   {{0xb4d80574,0xdb180113,0x9a846bd0,0xc1f00073}},	//   ार्_, _kutí, _пулл, _चिंब_, 
   {{0x28d06bd1,0x95c80276,0x00000000,0x00000000}},	//   _द्वि, яуна_, --, --, 
   {{0x8ca445c7,0x43940c60,0x73c400c7,0x00000000}},	//   टेको, ҳасс, кәме, --, 
   {{0xd83805f5,0x2d98013f,0x7f981892,0xb4d816d1}},	//   _хэл_, _ɔse_, líqu, ारौ_, 
   {{0x6b546bd2,0x57a43b49,0x4394009d,0x00000000}},	//   _pági, _яшла, гасс, --, 
   {{0x9f586bd3,0x7f9809c2,0x6fdc00fe,0xe6a800db}},	// [7bb0] cupé_, níqu, _ডমেই, _ۉنۉۉ_, 
   {{0xd0840022,0xdb180309,0x6b5403b2,0x867c011a}},	//   ныеи, _sutì, _vági, _מרחו, 
   {{0xdb1802fb,0xaa1c00bc,0x70e0012d,0x00000000}},	//   _autí, _भन्छ_, _फ़ील, --, 
   {{0x7ff46bd4,0xd1f0001f,0x212801ab,0xcf24007b}},	//   اسلا, ልከቻ_, _eabh_, عراي, 
   {{0xdb180798,0x212801ab,0x59b0033f,0x00000000}},	//   _cutí, _fabh_, ीदार, --, 
   {{0x212814d0,0xdb180419,0x568c0023,0xac381bbc}},	//   _gabh_, _dutí, _ሓድነቱ_, дчих_, 
   {{0x67c000ef,0x00000000,0x00000000,0x00000000}},	//   _vējk, --, --, --, 
   {{0x7f9809c2,0xaf8c001f,0x6b54032e,0xc60c00eb}},	//   fíqu, ጅቶችና_, _lágv, ষয়টা_, 
   {{0xed5001d9,0x28f8084c,0x9f5800d8,0x7b4400d1}},	//   _پھش_, мэнэ_, xupé_, ائىل, 
   {{0xdb180120,0x3d940022,0x00000000,0x00000000}},	//   _cutâ, _биур, --, --, 
   {{0xed58009b,0x88e00eac,0x38580108,0x00000000}},	//   _hužo_, _মাদক, еряю_, --, 
   {{0xea946bd5,0x32180ea0,0x9f580066,0x085400cf}},	//   _ишлэ, _opsy_, tupé_, _үчкө_, 
   {{0x25b86bd6,0x69246bd7,0xdb180051,0x00000000}},	//   _pipl_, _амла, _xutí, --, 
   {{0x5e5404ac,0xe5a400f7,0x3f780427,0x64bc024a}},	//   דישע_, тиги, nčur_, ्डेश, 
   {{0xf9906bd8,0x79a4147e,0x212800c6,0x1540151e}},	//   _ابن_, _срце, _rabh_, шерм, 
   {{0xe61800f5,0x6db40166,0x00000000,0x00000000}},	//   _жди_, lğağ, --, --, 
   {{0xe6446bd9,0xe298036b,0x31cc0183,0x7ae40037}},	// [7bc0] _репп, фаа_, _লিউশ, _õite, 
   {{0x20546bda,0x8f5001d5,0xe57000ae,0x00000000}},	//   ктер, ینلش, _خطب_, --, 
   {{0xd12c6bdb,0x38600198,0xdb180077,0x6b540022}},	//   تمل_, _ƙiri_, _sutí, _hágu, 
   {{0xed580b4b,0x00000000,0x00000000,0x00000000}},	//   _bužo_, --, --, --, 
   {{0xc0c00020,0x777c056a,0xad640066,0x00000000}},	//   ስላል_, érxi, گانه, --, 
   {{0x6b546bdc,0xa2cc002b,0xc2c400ec,0x00000000}},	//   _mágu, धुर्, _جيڏي, --, 
   {{0x1fb46bdd,0x5f041b10,0x50400c75,0x6b54148b}},	//   _асар, _изва, _керб, _lágu, 
   {{0xd00c1973,0x6d440e03,0x8c400063,0x3f840419}},	//   _گلہ_, öhar, реће, _ujmu_, 
   {{0xef906bde,0xa3e00d41,0xdb180311,0xba18027d}},	//   _ایند, नीत_, _putâ, ريدا_, 
   {{0xad241aa3,0xd00c01d9,0x7f986bdf,0x38400240}},	//   _مرمو, _دلہ_, ríqu, _ንመልእ, 
   {{0x5b24010b,0xd1f00023,0x69b40022,0x00000000}},	//   _аьла, ልከቶ_, ықшс_, --, 
   {{0x6c7401c6,0xda7801af,0x00000000,0x00000000}},	//   _суух, _оял_, --, --, 
   {{0xcb0405d9,0x6db8010b,0x88a000fb,0xd1f00240}},	//   _شيون_, _oňal, лғәһ, ልከተ_, 
   {{0x6b546be0,0xceb004ae,0xd87400c6,0x4870030f}},	//   _dágu, ייר_, _لاعب, ادیس, 
   {{0x57a40124,0x335400f7,0x97a46be1,0x00000000}},	//   _ишиа, гүнө_, _ирил, --, 
   {{0x1cc0025c,0x6db800a2,0x7d0803ac,0x6b5402d2}},	//   _གུའ_, _aňal, _lcds, _fágu, 
   {{0x6b540241,0xb1141fd4,0xc2e401b9,0x04b800e5}},	// [7bd0] _gágu, лмаш, рўси, ٹھیں_, 
   {{0x54e8021a,0xd1f01ee0,0x7c28003a,0x00000000}},	//   _کرکټ_, ልከቱ_, _osdr, --, 
   {{0xa0480c50,0x799803ac,0x00000000,0x00000000}},	//   ىككە_, _mkvw, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7c281762,0xdb0000ae,0x22a4059f,0x25e4012d}},	//   _asdr, _choí, _бурҳ, जीपी_, 
   {{0xac086be2,0x9e9419c5,0x7d0802d0,0x6b5403f2}},	//   енка_, دامچ, _ccds, _lágt, 
   {{0x7c040879,0x96e000bc,0x67c000ef,0x00000000}},	//   لبيك, पराउ, _tēji, --, 
   {{0xdb18004e,0x98bc013d,0x3ea0025c,0x00000000}},	//   _cutà, ditı_, żita_, --, 
   {{0x6f0801c7,0x7c286be3,0xdb186be4,0x35680023}},	//   _icec, _esdr, _attó, ደኛታት_, 
   {{0x6e284b67,0x70e0012d,0x00000000,0x00000000}},	//   _iseb, _फ़ोल, --, --, 
   {{0x66e46be5,0x9ce801ed,0xdcf80064,0x6b5401e1}},	//   лона, _سونے_, _aktė, _ságu, 
   {{0x25640129,0x6db80306,0xe6440946,0xa9c0030d}},	//   _môle_, _mňam, гемп, _гιач, 
   {{0xfa3431f3,0x6e28031c,0x5378001f,0x00000000}},	//   _پرند, _jseb, _አብዮት_, --, 
   {{0x6e280912,0x6b540579,0x98bc0139,0x00000000}},	//   _mseb, _vágu, bitı_, --, 
   {{0x6e28009a,0x6b5400c6,0x395803fa,0x1cc0031c}},	//   _lseb, _fágt, örse_, _གུལ_, 
   {{0x6e284859,0x6f0800ca,0xdb18011f,0x69c80009}},	//   _oseb, _ncec, _kutá, oqee, 
   {{0xd3846be6,0x38340014,0x18b40124,0x6e286be7}},	// [7be0] уйте_, _مى۪ز, _игәы_, _nseb, 
   {{0x29046be8,0x2564045f,0x6f086be9,0x29c8001e}},	//   ngla_, _bôle_, _acec, _múa_, 
   {{0x29c86bea,0x273800ee,0x29040037,0x00000000}},	//   _lúa_, _günä_, igla_, --, 
   {{0x6db801f1,0x69c80548,0x5ea402e9,0x49800092}},	//   _dňam, kqee, همال, _ይጥቀሱ_, 
   {{0x656003a2,0x29c80005,0x6b5408ce,0x00000000}},	//   _ïohs, _núa_, _lágs, --, 
   {{0x24e00183,0x6f080334,0xa0d80014,0xd6f800b5}},	//   _বাঁহ, _ecec, _سِرا_, noを_, 
   {{0x6e281253,0xcd2414b7,0x7d0834a2,0xdb186beb}},	//   _eseb, ужје_, _vcds, _autá, 
   {{0x29c86bec,0x3b541f91,0x0e6010db,0x79f40395}},	//   _búa_, ркир, ркән, азих, 
   {{0xdb1809c2,0x1e846bed,0xde300066,0x00000000}},	//   _cutá, _слам, _دژاگ, --, 
   {{0xd7f86bee,0xd90c6bef,0x29046bf0,0x6b5402d2}},	//   нум_, سیب_, ggla_, _bágs, 
   {{0x69c80429,0x8d580375,0xdb000165,0x6e2801d3}},	//   aqee, _רכבי, _wioñ, _zseb, 
   {{0x48a46bf1,0x70e02871,0x7bd80926,0x69c8011f}},	//   ытым_, _फ़्ल, mpvu, bqee, 
   {{0x27380166,0x6b5401d3,0xa3e00cb2,0x00000000}},	//   _sünä_, _vágt, नीस_, --, 
   {{0x7804016c,0x9f5800c7,0xe58400db,0x8cc41788}},	//   _кӯма, nupâ_, атсү, ाशयो, 
   {{0x36d4008e,0xdb000051,0x00000000,0x00000000}},	//   _койр, _khoà, --, --, 
   {{0x256420ef,0x260000af,0x72d40276,0x4c980375}},	//   _rôle_, वंशी_, роаф, גבלו, 
   {{0xd498016c,0xa3680139,0xd5b800d8,0xf288009d}},	// [7bf0] _ӯро_, _itеl, _псо_, төнд_, 
   {{0xeb206bf2,0x25646bf3,0x6f080ffb,0x6b540c5e}},	//   _मस्त_, _pôle_, _scec, _jágr, 
   {{0x6e282252,0xc914011a,0x00000000,0x00000000}},	//   _sseb, רחבת_, --, --, 
   {{0x08200156,0x6b546bf4,0x256400d0,0xdb000208}},	//   _འགལཝ_, _lágr, _vôle_, _nhoà, 
   {{0x6db46bf5,0x3d006bf6,0x51846bf7,0x4084059f}},	//   айду, _राखे_, _бува, _ғурб, 
   {{0x6e280f72,0x29c80f71,0x6b5409f3,0x2564004a}},	//   _vseb, _rúa_, _nágr, _tôle_, 
   {{0x29c86bf8,0xdd8c04d3,0x826404d3,0x69c80429}},	//   _súa_, بوو_, _نهێن, wqee, 
   {{0x6e286bf9,0x6f0800ca,0x29c804d4,0xdb00004d}},	//   _tseb, _ucec, _púa_, _choà, 
   {{0x6e2853ff,0x69246bfa,0x290407c5,0x29c8004d}},	//   _useb, ампа, tgla_, _qúa_, 
   {{0x29040cf4,0x29c80165,0xef9001d5,0xfc6411ca}},	//   ugla_, _vúa_, _ایچد, ръән, 
   {{0x29046bfb,0x67082017,0x6d406bfc,0x7b080158}},	//   rgla_, _वादक_, _inla, åstå, 
   {{0x29c836ed,0x6b5406ea,0x00000000,0x00000000}},	//   _túa_, _vágs, --, --, 
   {{0x69c8198f,0xa81808f0,0x65c46bfd,0xfce80092}},	//   qqee, رتگر_, рбга, _መንጃ_, 
   {{0x2b4c0010,0x67c000de,0x00000000,0x00000000}},	//   ljec_, _sēju, --, --, 
   {{0x33d401ec,0x9f5800c7,0x00000000,0x00000000}},	//   йітт, nupã_, --, --, 
   {{0xdb000016,0x2b4c549d,0x8e2c01a9,0x00000000}},	//   _khoá, njec_, yagа_, --, 
  
   {{0x6d406bfe,0x12d00150,0x6d0401f9,0x67c000ef}},	// [7c00] _onla, _ﺘﺘﻌﺭ, _रांग_, _vēju, 
   {{0xe4580c75,0x2bb40055,0x00000000,0x00000000}},	//   _ажо_, _vācy_, --, --, 
   {{0x999806c8,0xddc0005f,0xa3e003ce,0x60240798}},	//   _ōpū_, dzoš, नीश_, рдеа, 
   {{0x6d406bff,0x00000000,0x00000000,0x00000000}},	//   _anla, --, --, --, 
   {{0xdb00004d,0x00000000,0x00000000,0x00000000}},	//   _nhoá, --, --, --, 
   {{0x2720045e,0x91e02be9,0x3d00000d,0x00000000}},	//   যাটো_, _форе, ईलें_, --, 
   {{0xdde00054,0xabcc0ed1,0x88e000cc,0x1ec86c00}},	//   _ńuńu, _ﻗﺎﻧﺎ, _মাংক, _алби_, 
   {{0x20380020,0x6d406c01,0x6b54007b,0x00000000}},	//   _የሚታየ, _enla, _ságr, --, 
   {{0xdb0001fb,0x5f9400d1,0x19a800f7,0x4ef8011a}},	//   _choá, _биңт, ктоп_, _שהמו, 
   {{0x26d0007f,0x6d4001ab,0x9f580721,0x20a807f7}},	//   _afyo_, _gnla, lupà_, _कराध, 
   {{0x57a407d6,0x2b4c01a6,0xe8ec00ec,0x00000000}},	//   ишма, bjec_, رڻو_, --, 
   {{0x9ce800e5,0x00000000,0x00000000,0x00000000}},	//   _سوچے_, --, --, --, 
   {{0x7bc86c02,0xaac400c6,0x645806ea,0x6d406c03}},	//   _hudu, _اتمن, øtin, _ynla, 
   {{0xdb1800a2,0x00000000,0x00000000,0x00000000}},	//   _butç, --, --, --, 
   {{0x7bc86c04,0xdcf800da,0xa3e00027,0xf8b00014}},	//   _judu, _aktī, नील_, _ڈکھ_, 
   {{0x7bc86c05,0x88b80375,0xf8b00014,0x311800dc}},	//   _mudu, _במוז, _وکھ_, न्नः_, 
   {{0x7bc86c06,0x00000000,0x00000000,0x00000000}},	// [7c10] _ludu, --, --, --, 
   {{0x7bc80099,0x777c0ba7,0x6b5403b2,0x67c000ef}},	//   _oudu, lisx, _lágp, _tējt, 
   {{0x7bc86c07,0x3d006c08,0x765c6c09,0x6d40022e}},	//   _nudu, _राजे_, lysy, _rnla, 
   {{0xbfa84727,0x035801e0,0x27f05955,0x777c01a9}},	//   атче_, _күсә_, ázni_, nisx, 
   {{0x7bc86c0a,0x765c6c0b,0xf484030f,0x83c003ce}},	//   _audu, nysy, _خاکی, _शूटआ, 
   {{0x200c00f7,0x64586c0c,0xed5828b5,0x00000000}},	//   àfic_, ätig, _kuži_, --, 
   {{0x7bc83391,0x765c6c0d,0x00000000,0x00000000}},	//   _cudu, hysy, --, --, 
   {{0x7bc850f9,0xed580232,0x9f586c0e,0x765c6c0f}},	//   _dudu, _muži_, cupà_, kysy, 
   {{0x5ca40efb,0x256405da,0xf41c00eb,0x765c0432}},	//   _ۇلكە, _lôla_, দটির_, jysy, 
   {{0x7bc86c10,0x6d406c11,0x8d8401d5,0x67080807}},	//   _fudu, _unla, _тубд, _वाहक_, 
   {{0x7bc86c12,0xdb24035c,0x311800dc,0x00000000}},	//   _gudu, _گونی, न्यः_, --, 
   {{0xdb000016,0xc5f8013e,0x765c00a2,0x00000000}},	//   _thoá, ағи_, fysy, --, 
   {{0xdb2404d3,0x7bc800e2,0x765c6c13,0x00000000}},	//   _دونی, _zudu, gysy, --, 
   {{0x7bc86c14,0x64480cad,0x00000000,0x00000000}},	//   _yudu, _àfik, --, --, 
   {{0xa3e0033d,0xe7386c15,0x7bc86c16,0x64a402d5}},	//   नीं_, _бей_, _xudu, сава, 
   {{0xed580552,0xd9100022,0xe29801d5,0xa6e40395}},	//   _duži_, _ддәы, габ_, _ужил, 
   {{0xc0d0001f,0x765c6c17,0xdce801e4,0x672403cd}},	// [7c20] _እስር_, cysy, lofĥ, mekj, 
   {{0x66046c18,0xd6d40ec9,0x636809f3,0xe2980032}},	//   mukk, _پویش_, _sýnd, _ҡан_, 
   {{0x66046c19,0x11f40efb,0x9f5804cc,0xb05000b8}},	//   lukk, لتەگ, tupà_, _piñḍ, 
   {{0xfce8069c,0x7bc86c1a,0x6724143a,0x00000000}},	//   _መንጎ_, _rudu, nekj, --, 
   {{0x66046c1b,0x63b43c98,0x53980375,0x56940023}},	//   nukk, mmyn, _תיכו, _መንነቱ_, 
   {{0x7bc86c1c,0x63b4066a,0x66040194,0xdb18007c}},	//   _pudu, lmyn, iukk, _mutå, 
   {{0x38c86c1d,0x7bc86c1e,0xa0686c1f,0x777c022f}},	//   یادی_, _qudu, _сава_, yisx, 
   {{0x6724044e,0x5b246c20,0x63b46c21,0x106401ec}},	//   jekj, ська, nmyn, _اڭكى_, 
   {{0x66046c22,0x7bc86c23,0x9f340046,0x9f580077}},	//   jukk, _wudu, _кеңі, cupá_, 
   {{0x7bc86c24,0x66046c25,0x63b46c26,0x6eac000d}},	//   _tudu, dukk, hmyn, _जरतु, 
   {{0x63b46c27,0x64581455,0x44380010,0x8d9000f2}},	//   kmyn, øtil, jvr_, _علمش, 
   {{0x765c6c28,0x66046c29,0x67240158,0xd6d8023a}},	//   tysy, fukk, gekj, ыто_, 
   {{0x66046c2a,0x63b46c2b,0x44386c2c,0x00000000}},	//   gukk, dmyn, evr_, --, 
   {{0x271c02b1,0x5ea803d4,0x94740271,0x38c80345}},	//   _rānō_, _ওলাই, مدزا, _ئاشی_, 
   {{0xd7f867b0,0x67246c2d,0x66040108,0x83f8022e}},	//   _сул_, bekj, aukk, йерс_, 
   {{0x63b4008c,0x07f400c6,0x67240327,0x765c6c2e}},	//   gmyn, _اروع_, cekj, pysy, 
   {{0x66045b6b,0x31d400ae,0x00000000,0x00000000}},	// [7c30] cukk, زقاز, --, --, 
   {{0x79881682,0xed581674,0x63b40142,0x636801ef}},	//   nndw, _tuži_, amyn, _rýne, 
   {{0x50a004a9,0x7d1845a7,0x74146c2f,0x83180075}},	//   سەرل, dfvs, _بوجا, شقەر_, 
   {{0xcee86c30,0x64586c31,0x79880007,0x25e404aa}},	//   اران_, ätie, hndw, जीवी_, 
   {{0x6cc46c32,0x00000000,0x00000000,0x00000000}},	//   ойла, --, --, --, 
   {{0xabd41b88,0xad241e4a,0x81d46c33,0x00000000}},	//   оциј, زىبى, _хорх, --, 
   {{0x7058013e,0x7988009a,0x998402fb,0x66046c34}},	//   _тавр_, dndw, _brož_, zukk, 
   {{0x79886c35,0x66046c36,0x6368013a,0x6f641bf4}},	//   endw, yukk, _týne, _بهرم, 
   {{0xc3340375,0x34b40073,0x6604031c,0x00000000}},	//   פוץ_, ंधुद, xukk, --, 
   {{0x7d18074d,0x66040108,0xd9941541,0x00000000}},	//   cfvs, vukk, ينيت_, --, 
   {{0xfd100597,0x1cc0025c,0x1b1c009e,0x672460e2}},	//   _سجل_, _གུག_, ভয়ে_, tekj, 
   {{0xae0c05d7,0x31180882,0x15e8033f,0x394801ec}},	//   _समान_, न्तः_, _जौहर_, _ۇشىپ_, 
   {{0x67246c37,0x63b4022c,0xf1a80b68,0xf3f0001e}},	//   rekj, vmyn, कतान, ận_, 
   {{0x66046c38,0x6b886c39,0x69d86c3a,0x44386c3b}},	//   rukk, lneg, _itwe, tvr_, 
   {{0x68e06c3c,0x63786c3d,0xfd5800a2,0x6b88012d}},	//   mbld, асар_, _ataỳ, oneg, 
   {{0x6b886c3e,0x66046c3f,0x44380051,0x63780118}},	//   nneg, pukk, rvr_, můnk, 
   {{0x63b46c40,0x6b88581c,0x60e86c41,0x66040869}},	// [7c40] rmyn, ineg, имам_, qukk, 
   {{0x6b886c42,0x69d8009f,0x61e40254,0x64a46c43}},	//   hneg, _mtwe, _vwkl, _мапа, 
   {{0x656c00c6,0x1ec80124,0x6b886c44,0x9ff800c6}},	//   mhbh, алеи_, kneg, شراء_, 
   {{0xe2980d4b,0x6b886c45,0xed5804a7,0x00000000}},	//   _вам_, jneg, _mužu_, --, 
   {{0x1cc0038f,0x6b886c39,0x69d86c46,0x798803cb}},	//   _གུང_, dneg, _ntwe, yndw, 
   {{0x96380a1e,0x216800f7,0x6b8801c7,0xf3f0004d}},	//   יגנט, _тиги_, eneg, ợt_, 
   {{0x69d86c47,0x10a06c48,0xdb686c49,0xddcc0210}},	//   _atwe, _жирн, ирил_, ódła, 
   {{0x6b886c4a,0x7d1845a7,0xba540640,0x79886c4b}},	//   gneg, sfvs, звиј, wndw, 
   {{0xdd906c4c,0x1d086c4d,0xed580171,0x8fa0030d}},	//   _قور_, _вези_, _aužu_, _цате, 
   {{0x79886c4e,0xdc3c0122,0x6b88012d,0x5278010f}},	//   undw, líče, aneg, ינפא, 
   {{0x6b886c4f,0x69d814dc,0xd7f83410,0x656c679d}},	//   bneg, _etwe, шуп_, dhbh, 
   {{0xed5805a1,0xdc3c19b3,0x6b886c50,0x00000000}},	//   _dužu_, níče, cneg, --, 
   {{0xa9240010,0x83d401ec,0x00000000,0x00000000}},	//   _bržč, _ﻛﺎﺭﻳ, --, --, 
   {{0x85440276,0x656c01e7,0x00000000,0x00000000}},	//   мэсе, ghbh, --, --, 
   {{0xd34001b9,0x00000000,0x00000000,0x00000000}},	//   وفسی, --, --, --, 
   {{0x98ac007f,0xdd1c012c,0xcebc0118,0xd6d817a0}},	//   _jafč_, jížd, ířka_, _ттк_, 
   {{0xdc3c0306,0xc3980212,0x656c0055,0x00000000}},	// [7c50] díče, ікує_, bhbh, --, 
   {{0x6b886c45,0x656c078c,0x98bc00c0,0x83d00150}},	//   zneg, chbh, nktį_, _ﻛﯟﺭﺳ, 
   {{0x6b886c51,0x85b800db,0x72d4014b,0xc0dc0240}},	//   yneg, _بايس_, _нонф, ቕላላ_, 
   {{0x6b880334,0x1ee8129e,0x00000000,0x00000000}},	//   xneg, مومی_, --, --, 
   {{0x6b880f72,0xa2a06c52,0x0574158b,0x6db80432}},	//   vneg, _कुप्, _راید, _oňat, 
   {{0xdb18025a,0xa3e0068f,0x32080b6f,0x6b880034}},	//   _tutû, नीक_, muay_, wneg, 
   {{0x6b886c53,0x3ea403b2,0x1c0007f7,0xdc3c022a}},	//   tneg, _eymt_, रंगल_, bíče, 
   {{0x6b886c54,0xed5816a3,0xd1cc001f,0x9af000d1}},	//   uneg, _ružu_, _እህት_, ىكىت, 
   {{0x6b886c55,0x98ac007f,0xe9d810fc,0x00000000}},	//   rneg, _dafč_, љко_, --, 
   {{0x6b886c45,0x2eec01f5,0xff080432,0x00000000}},	//   sneg, _heef_, _çärä_, --, 
   {{0xe7386c56,0x6b882bcd,0x2eec0e14,0xa2a01b61}},	//   бен_, pneg, _keef_, _कुन्, 
   {{0x63680209,0xfb38007b,0x320800e4,0x00000000}},	//   _oýna, _وأنت_, kuay_, --, 
   {{0x656c14d0,0x69d80223,0x2ca401bf,0xaa440f06}},	//   thbh, _utwe, _hyld_, _хелл, 
   {{0x2eec6c57,0x26dc008f,0x98ac033b,0x2ca4007c}},	//   _leef_, ŝto_, _zafč_, _kyld_, 
   {{0x98a05777,0xb91001f2,0x6368010b,0x18a00117}},	//   _пише, halụ_, _aýna, _пашм, 
   {{0x2eec6c58,0x2ca4045f,0x57f80375,0xb91002e3}},	//   _neef_, _myld_, _הלקו, kalụ_, 
   {{0x32080588,0xdb1800d2,0xa5086c59,0xe61801af}},	// [7c60] guay_, _putú, _лепа_, _удп_, 
   {{0x636802d2,0x71f80014,0x3ea4007c,0x59cc6c5a}},	//   _dýna, ترِس_, _rymt_, _हंसर, 
   {{0x657c1cea,0x64a46c5b,0x6d0405f9,0xa6ac009e}},	//   _imph, _хана, _राजग_, _গলিট, 
   {{0x673400b5,0xc3300a52,0x3208003e,0x00000000}},	//   _jayj, _جەر_, buay_, --, 
   {{0x6734094a,0x2eec002e,0x32080113,0x88c000eb}},	//   _mayj, _deef_, cuay_, োরিক, 
   {{0x2ca40b21,0xdb200241,0x61f4010e,0x00000000}},	//   _byld_, _ìrúf, msyl, --, 
   {{0xdee46c5c,0x657c04c4,0x00000000,0x00000000}},	//   _нови, _mmph, --, --, 
   {{0x2eec0936,0x8fa0326d,0x67346c5d,0x6db80118}},	//   _geef_, _засе, _nayj, _sňat, 
   {{0x61f46c5e,0x657c6c5f,0xa2a01971,0x1ea806f6}},	//   nsyl, _omph, _कुम्, _طاري_, 
   {{0x49706c60,0x2ca4037e,0x2eec01a4,0xdb1803b2}},	//   ельс, _fyld_, _zeef_, _lutø, 
   {{0x673400a2,0xc5c403d4,0x23bc00dc,0x38780013}},	//   _bayj, ্ঠাপ, ्दाद, àrr_, 
   {{0x61f402f6,0xf3f00208,0x00000000,0x00000000}},	//   ksyl, ậm_, --, --, 
   {{0x8f980bd9,0xd9445e70,0x99840171,0x00000000}},	//   מיטי, _неди, _esoš_, --, 
   {{0xca300063,0x00000000,0x00000000,0x00000000}},	//   _чешћ, --, --, --, 
   {{0x6368148b,0xa2a02bf1,0x00000000,0x00000000}},	//   _sýna, _कुब्, --, --, 
   {{0x657c6c61,0x07a400f3,0x00000000,0x00000000}},	//   _emph, _пајн, --, --, 
   {{0x90e40ef6,0x2eec6c62,0x776c03b9,0x31340107}},	// [7c70] كسان, _reef_, _ilax, меар, 
   {{0x2478001f,0x2eec6c63,0x00000000,0x00000000}},	//   _አትሌት_, _seef_, --, --, 
   {{0x61f403a2,0x6db8010b,0x00000000,0x00000000}},	//   asyl, _oňar, --, --, 
   {{0xb91002e3,0x636808ce,0x00000000,0x00000000}},	//   talụ_, _týna, --, --, 
   {{0x2ca4002d,0xed586c64,0x32086c65,0x657c035a}},	//   _syld_, жол_, quay_, _ymph, 
   {{0x6db800a2,0x776c0327,0x2eec0af9,0x00000000}},	//   _aňar, _llax, _weef_, --, 
   {{0x2eec057b,0x7f4800d1,0xa0200254,0x4ba4004e}},	//   _teef_, غلۇق_, öötm, пөдү_, 
   {{0x4ea46c66,0x7c0400d1,0xa2a0043e,0xcee80066}},	//   _ерза, ربىك, _कुड्, _درآن_, 
   {{0x2ca46c67,0xed040451,0xfe6c01c4,0xbc686c68}},	//   _wyld_, _يورپ, _сү_, يمۇن_, 
   {{0x776c0054,0x673400e4,0x8c34014b,0x00000000}},	//   _alax, _sayj, _нозӣ_, --, 
   {{0x8c6407d6,0xa6f404da,0xe72801c6,0x785400e5}},	//   _этад, үзүш, оонд_, فیوز_, 
   {{0x61f40368,0x776c6c69,0x00000000,0x00000000}},	//   ysyl, _clax, --, --, 
   {{0x66140113,0x69dc02f0,0x00000000,0x00000000}},	//   _qqyk, ísed, --, --, 
   {{0x776c0857,0x67340de2,0x00000000,0x00000000}},	//   _elax, _wayj, --, --, 
   {{0x2794006c,0x1cc00489,0x23346c6a,0xf49401c6}},	//   _ошир, _གུབ_, мхар, ертю, 
   {{0x041000bd,0xba0802d3,0x200c004e,0x00000000}},	//   াবলী_, _ወብ_, àfim_, --, 
   {{0xe1f86c6b,0xa1c401ca,0xa3e01cd2,0x96f8011a}},	// [7c80] юга_, дбад, नीज_, _ולפת, 
   {{0xa2a01db2,0x61f40368,0x37e0015b,0x02c40139}},	//   _कुण्, rsyl, _ভিতর, _җигү, 
   {{0x443c00dd,0x61f46c6c,0xa2e4004e,0x00000000}},	//   _év_, ssyl, _оонд, --, 
   {{0x1e84023a,0x61f44268,0x00000000,0x00000000}},	//   млем, psyl, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x1cc00135,0x9c440212,0x644801e1,0xdef800c7}},	//   _གུད_, дхил, _àfis, сыҧ_, 
   {{0xa2a008ec,0xf00005f5,0x90c06c6d,0xa3e00073}},	//   _कुत्, _бүхи, _абре, नीच_, 
   {{0xd00c275c,0x8c400063,0x00000000,0x00000000}},	//   _خلف_, ђење, --, --, 
   {{0x44f400fe,0x9e646c6e,0x00000000,0x00000000}},	//   _জানক_, _غارن, --, --, 
   {{0x58840024,0x80cc015b,0x00000000,0x00000000}},	//   дыма, িরক্, --, --, 
   {{0x776c6c6f,0x636803b2,0x6b5401d3,0x00000000}},	//   _plax, _nýno, _lágy, --, 
   {{0x95c803b7,0xc62800eb,0x3ea0025c,0x00000000}},	//   жува_, মিনা_, żitu_, --, 
   {{0x893001b9,0x64580108,0x00000000,0x00000000}},	//   رعیا, ätin, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x776c6c70,0x66040108,0x00000000,0x00000000}},	//   _tlax, arkk, --, --, 
   {{0x1cc0025c,0x395c0162,0x00000000,0x00000000}},	//   _གུན_, _hovs_, --, --, 
   {{0x1164036b,0x25a80477,0x14c80166,0x00000000}},	// [7c90] ولری_, blbl_, _мыни_, --, 
   {{0xae0405d7,0x6e3c02d2,0x00000000,0x00000000}},	//   _रिबन_, _ásbi, --, --, 
   {{0xcf981fbe,0xf4846c71,0x00000000,0x00000000}},	//   ојд_, _سادی, --, --, 
   {{0xd3446c72,0x50dc18cc,0x395c01bf,0x00000000}},	//   _تیره_, _प्रष, _lovs_, --, 
   {{0x9130035b,0x644801e1,0x51846c73,0x00000000}},	//   _иҭах, _àfir, _жува, --, 
   {{0x395c1570,0x9e946c74,0xae100073,0x00000000}},	//   _novs_, رانچ, डंबन_, --, 
   {{0xdca06c75,0x9d502a8b,0xd6f804ce,0x5ca01513}},	//   лаши, انىت, joク_, лишб, 
   {{0x6604005b,0x00000000,0x00000000,0x00000000}},	//   yrkk, --, --, --, 
   {{0x395c04cc,0xa3b40034,0x3338022e,0x00000000}},	//   _bovs_, _चीफ_, _masx_, --, 
   {{0xa3b402fe,0x7e7400db,0xe0200248,0x00000000}},	//   _चीन_, _شاقئ, _òṣè, --, 
   {{0xe7386c76,0x2918033f,0x00000000,0x00000000}},	//   пен_, ęsa_, --, --, 
   {{0xe738524d,0x7bdc00e4,0xdcac00f1,0x2fd0036e}},	//   чем_, _ũrug, _اډه_, _muzg_, 
   {{0xdb1800e4,0x9f580093,0xbb18106b,0x8cc40950}},	//   _jutý, tupú_, _آزما_, ाशको, 
   {{0x290000e4,0x20180784,0x25640419,0x395c00de}},	//   _ÿha_, ytpi_, _kôli_, _govs_, 
   {{0x2b5c0327,0x1420041b,0x35c401f0,0xa3e80395}},	//   _kowc_, лдрм, тарҳ, ядва_, 
   {{0x63680122,0x2b586c77,0x46841df2,0x00000000}},	//   _výno, ösch_, _ақма, --, 
   {{0xc0ec0023,0x23700200,0x14ec00cc,0x00000000}},	// [7ca0] _ህድሞ_, rhyj_, _জাৰী_, --, 
   {{0x6b5401ed,0x2fd001d5,0x00000000,0x00000000}},	//   _vágy, _buzg_, --, --, 
   {{0x80a8015b,0xa348010a,0xe3b0007b,0x39585fa7}},	//   কেন্, _езна_, _مرح_, örsi_, 
   {{0x44446c78,0x2b5c0784,0x6e2c0327,0x00000000}},	//   _ir_, _nowc_, ħabn, --, 
   {{0x44446c79,0x9f5c03b2,0x00000000,0x00000000}},	//   _hr_, _ítí_, --, --, 
   {{0x44446c7a,0xdb1802f0,0x61442377,0x63040116}},	//   _kr_, _dutý, _џева, _توڭل, 
   {{0x44446c7b,0x61e000ae,0xdfa80066,0x00000000}},	//   _jr_, íolf, _فطره_, --, 
   {{0x705004d3,0x44440c3e,0x395c354a,0x93c40051}},	//   _خۆما, _mr_, _sovs_, _nhặ, 
   {{0x395c0793,0x1cc0025c,0xdb1800a2,0x00000000}},	//   _povs_, _གུམ_, _gutý, --, 
   {{0x44446c7c,0x271c2b1b,0xae0401af,0x00000000}},	//   _or_, _বোলো_, _шоуҙ, --, 
   {{0x6458023a,0xa2a02677,0x5ac86c7d,0x00000000}},	//   ätil, _कुस्, _елем_, --, 
   {{0x7c2803ac,0x93c40208,0x00000000,0x00000000}},	//   _ipdr, _chặ, --, --, 
   {{0x44446c7e,0x09e000ea,0x00000000,0x00000000}},	//   _ar_, _бочн, --, --, 
   {{0x44446c7f,0x395c017a,0x34940006,0x00000000}},	//   _br_, _uovs_, вагр, --, 
   {{0x97a40fcb,0x67080490,0x7bdc6c80,0x44446c81}},	//   _прил, _वाचक_, _érud, _cr_, 
   {{0x44446c82,0x80a40037,0x6db400a2,0x00000000}},	//   _dr_, _कड़े, mşaş, --, 
   {{0x43946c83,0x00000000,0x00000000,0x00000000}},	// [7cb0] уатс, --, --, --, 
   {{0x7c2827bb,0x98ac0356,0x63a46c84,0xc0ec0023}},	//   _opdr, _gafă_, _ekkn, _ህድማ_, 
   {{0xba080020,0x2fd0022e,0x00000000,0x00000000}},	//   _ወጥ_, _quzg_, --, --, 
   {{0x926807d6,0xa2a00764,0xdb18010e,0x042c0092}},	//   _ерга_, _कुव्, _putý, _ሥልጣን, 
   {{0x7c286c85,0x44444266,0x95800023,0x00000000}},	//   _apdr, _zr_, _ናብተን_, --, 
   {{0x44441649,0xdb180005,0xada40408,0x3208127b}},	//   _yr_, _outó, ъалл, mray_, 
   {{0xeb986c86,0x320814dc,0x6db43535,0x4444045a}},	//   мик_, lray_, vşağ, _xr_, 
   {{0x3208127b,0xdb1800ee,0x09b8041c,0x25640419}},	//   oray_, _tutý, ैद्य, _vôli_, 
   {{0xdb186c87,0x320814dc,0xe8c800dc,0x490000cf}},	//   _autó, nray_, रश्च, гүлг, 
   {{0xfeb804b3,0x7c2c6bdf,0x68440452,0xdb18033f}},	//   _ساقت_, ñorí, вноа, _butó, 
   {{0x66e46c88,0x32080c8c,0x00000000,0x00000000}},	//   кона, hray_, --, --, 
   {{0x6e280521,0x32080c8c,0x6458023a,0x00000000}},	//   _kpeb, kray_, ätim, --, 
   {{0x44446c89,0x320802d0,0x00000000,0x00000000}},	//   _sr_, jray_, --, --, 
   {{0x44446c8a,0x32086c8b,0x6e2802ea,0x2ca8012c}},	//   _pr_, dray_, _mpeb, řadu_, 
   {{0x44445ca2,0x64a46c8c,0xd578044e,0x32086c8d}},	//   _qr_, тава, _ኣእምሮ_, eray_, 
   {{0x32082f05,0x3170002d,0x3c3c00bc,0xf29c02dd}},	//   fray_, _alzz_, lává_, _ﺃﺼﺒﺢ_, 
   {{0x320814dc,0x23d06c8e,0x6e2c1184,0xa2a02ac3}},	// [7cc0] gray_, _दूरद, çabl, _कुश्, 
   {{0x44446c8f,0xa0686c90,0x3c3c00bc,0xe0d800d4}},	//   _tr_, маза_, nává_, єве_, 
   {{0x44446c91,0xa2a029d9,0x32086c92,0xe3b86c93}},	//   _ur_, _कुर्, aray_, _обо_, 
   {{0x320814dc,0xe8081a3e,0xe2846c94,0x91d001ad}},	//   bray_, _विना_, _алми, _भूवै, 
   {{0x320814dc,0x13e4009e,0xd1b001b9,0x3c3c0f57}},	//   cray_, _ফিয়, _چیقک, kává_, 
   {{0xa3b46c95,0x2a68010e,0x41d800cd,0x80cc00eb}},	//   _चीत_, _ýaby_, _भूयस, িরঙ্, 
   {{0x3c3c012c,0xa18401af,0x00000000,0x00000000}},	//   dává_, _зыңл, --, --, 
   {{0xdb1800f7,0x5b2402bf,0x00000000,0x00000000}},	//   _autò, тька, --, --, 
   {{0x2ee80054,0xda7801ee,0x00000000,0x00000000}},	//   ñafe_, ьяк_, --, --, 
   {{0x80a803d4,0x69dc007b,0xdb180332,0x38340138}},	//   কেণ্, ísea, _putó, гнор, 
   {{0x3208035a,0xd0f400df,0x00000000,0x00000000}},	//   zray_, כציק_, --, --, 
   {{0x32080c8c,0x1ae46c96,0xe514012d,0x00000000}},	//   yray_, _родм, द्घि_, --, 
   {{0xa2a03bca,0x32080857,0x981400e5,0x3c3c013a}},	//   _कुल्, xray_, ربھا, bává_, 
   {{0x7bc06c97,0x32086c98,0xd90c114f,0x00000000}},	//   lmmu, vray_, _بید_, --, 
   {{0x32086c99,0x7988055a,0x6670350a,0x7ae400c5}},	//   wray_, midw, لگیر, _õits, 
   {{0x32082f05,0x79880925,0x7bc0014b,0x3f84017a}},	//   tray_, lidw, nmmu, _nmmu_, 
   {{0x320801d9,0xd5b86c9a,0x7bc0045a,0xc2c400ae}},	// [7cd0] uray_, _осо_, immu, ليفي, 
   {{0x7988055a,0x3f846c9b,0x32084dbd,0xdcec0118}},	//   nidw, _ammu_, rray_, ěděl, 
   {{0x32082f05,0x00000000,0x00000000,0x00000000}},	//   sray_, --, --, --, 
   {{0x32086ad0,0x7988055a,0xb9cc001f,0x6e986c9c}},	//   pray_, hidw, _ሰጪ_, нвер_, 
   {{0xfe703092,0x12846c9d,0x7988055a,0x59cc033f}},	//   يده_, _شمسی_, kidw, _हंगर, 
   {{0x3f846c9e,0xf0e857d7,0x7bc00036,0xbdf8007b}},	//   _emmu_, _سىرى_, emmu, ئرنا_, 
   {{0x4fc46c9f,0xa9a405c2,0x79886ca0,0x7bd80007}},	//   _асаа, ғинд, didw, gqvu, 
   {{0xfc306ca1,0x9fa401ee,0xea5800d8,0x00000000}},	//   تحه_, _быуҙ, ерој_, --, 
   {{0x3c3c634d,0xbfa8030d,0x00000000,0x00000000}},	//   tává_, _ртре_, --, --, 
   {{0x7bc00869,0x79886ca2,0x7e6404e6,0x64580108}},	//   ammu, gidw, äipe, ätik, 
   {{0x3c3c2fda,0xf1c801ec,0x00000000,0x00000000}},	//   rává_, _ﺒﺎﻤﺘ, --, --, 
   {{0x3c3c634d,0x2d8400d7,0xbad40153,0x00000000}},	//   sává_, _hmle_, _кішы, --, 
   {{0x79886ca3,0x6b880153,0x49000139,0xf4c400eb}},	//   bidw, mieg, _күпг, ্রোব, 
   {{0x6b886ca4,0x2fcc6ca5,0x395801e6,0xb5440022}},	//   lieg, _lieg_, örst_, аҧьа_, 
   {{0x69c06ca6,0x23286ca7,0xd918010f,0x562402dd}},	//   mmle, нови_, _נוקל, _ұжым_, 
   {{0x69c06ca8,0x0514015b,0xe618022e,0x00000000}},	//   lmle, াজের_, _зди_, --, 
   {{0xe2986ca9,0xe0d06caa,0x00000000,0x00000000}},	// [7ce0] хаа_, مزا_, --, --, 
   {{0x6b8801c0,0x636800a2,0x00000000,0x00000000}},	//   hieg, _mýni, --, --, 
   {{0x6b88006d,0xf3f0001e,0xa6c81bf3,0x2fcc6cab}},	//   kieg, ật_, _توکل_, _bieg_, 
   {{0x2fcc0007,0x2d8405da,0x79880925,0x6b886cac}},	//   _cieg_, _amle_, zidw, jieg, 
   {{0x2fcc0226,0xef20005f,0x79886cad,0x3bd80de2}},	//   _dieg_, daļā_, yidw, _séq_, 
   {{0xa0a46cae,0x00000000,0x00000000,0x00000000}},	//   _багд, --, --, --, 
   {{0x7988003d,0x6b886caf,0x201c00e4,0x7d1c02d2}},	//   vidw, fieg, _ëti_, _örsm, 
   {{0x3f846cb0,0x79880bd7,0x7bc00869,0x6b88025e}},	//   _ummu_, widw, ummu, gieg, 
   {{0xada8167e,0x7988055a,0x3bd800e8,0xb9980640}},	//   ردۇق_, tidw, _wéq_, квих_, 
   {{0x3bd800e8,0x49700026,0x0e60013d,0xad24104c}},	//   _téq_, йлыс, _укун, _نرمو, 
   {{0x79886cb1,0x6b886cb2,0x9f5800b0,0x2fcc030a}},	//   ridw, bieg, kupü_, _yieg_, 
   {{0x79886cb3,0x69c0020c,0x09e00154,0x6b886cb4}},	//   sidw, amle, _মিরা, cieg, 
   {{0x79886cb5,0xc6f800c0,0x00000000,0x00000000}},	//   pidw, ынях_, --, --, 
   {{0x26d00a49,0x15e801ad,0x45d41c90,0x06e400d1}},	//   _egyo_, जीगर_, сорс, _ﺋﯩﺸﻪ, 
   {{0x15b800ee,0xd6d802e8,0x00000000,0x00000000}},	//   дыңы_, _птп_, --, --, 
   {{0x75d4511e,0xd90c6cb6,0x938801b9,0x00000000}},	//   _پيدا, _بیگ_, хсга_, --, 
   {{0x32540364,0x11d46cb7,0x64480077,0xc6a40276}},	// [7cf0] швар, اترد, _áfin, _грэи, 
   {{0x2fcc03fa,0x6b886cb8,0x30e40220,0x00000000}},	//   _sieg_, zieg, рсаң, --, 
   {{0xb0340046,0x05746cb9,0xe8780023,0x00000000}},	//   рнеш, _دايد, _ብፉጹም_, --, 
   {{0xc0d00020,0x69c06cba,0x2fcc0327,0x5c3801f3}},	//   _እድል_, zmle, _qieg_, _ቡልጋር, 
   {{0x6b88005f,0x69c06cbb,0xd72003d4,0x00000000}},	//   vieg, ymle, _বোৱা_, --, 
   {{0x6b886cbc,0x2fcc057b,0x78b80010,0x6368032e}},	//   wieg, _wieg_, _ozvv, _rýni, 
   {{0xfe703955,0x63682242,0x6b886cbd,0x6db80030}},	//   يدۇ_, _sýni, tieg, _kňaz, 
   {{0xab646cbe,0x98a800bc,0x6a84010b,0x69dc0332}},	//   рвил, žbě_, илйа, íseo, 
   {{0x3f9c07ea,0x69945e0c,0xeab80c60,0xdcb4008e}},	//   évue_, ирох, ъйи_, лгәч_, 
   {{0x636801f1,0x6b886cbf,0x6dc000cf,0xe8081b76}},	//   _výni, sieg, _بۅتۅ, _विदा_, 
   {{0x6b886cc0,0x7c846cc1,0x69c048ed,0x65d00150}},	//   pieg, _луце, rmle, _ﻛﻮﭘﻪ, 
   {{0xdb2400f1,0x63686cc2,0x6b88025c,0x69c00205}},	//   _نومی, _týni, qieg, smle, 
   {{0xaa581dde,0xdb240b29,0x00000000,0x00000000}},	//   _шиду_, _خونی, --, --, 
   {{0xf1c801ec,0x7ac401af,0x00000000,0x00000000}},	//   _ﺒﺎﻻﺘ, _усхе, --, --, 
   {{0x442c6320,0x66e4010b,0xe3640063,0x54940006}},	//   ïd_, _койа, акви, авёў_, 
   {{0x7cec006a,0xb0a8000d,0xb8046cc3,0x33d40150}},	//   _kôrâ, _कड़ग, _ابوه, сірт, 
   {{0xd5ac1893,0x7c24054e,0x00000000,0x00000000}},	// [7d00] سفہ_, ăiri, --, --, 
   {{0x05940133,0xa3b40c6f,0xc0d00092,0x00000000}},	//   _دابگ, _चीर_, _እትም_, --, 
   {{0x20546cc4,0x3d0c0248,0xfe4401c6,0x00000000}},	//   штар, _lówà_, өмжү, --, 
   {{0xd004084c,0x44380142,0xa07400c7,0x49800023}},	//   реце_, mwr_, лыҵш, _ክጥቀሱ_, 
   {{0x443800a9,0xddc46cc5,0x7d1c032e,0x00000000}},	//   lwr_, абди, _örsk, --, 
   {{0xcd240212,0x4438058a,0x15e80037,0x00000000}},	//   ижче_, owr_, जीटर_, --, 
   {{0x44380368,0xef9005af,0x00000000,0x00000000}},	//   nwr_, _کیند, --, --, 
   {{0x61e4020b,0x8f64136b,0x44386cc6,0x0e6005a2}},	//   _ktkl, _касб_, iwr_, скән, 
   {{0x7f401730,0x80a804c5,0x443803cb,0xdb2002d2}},	//   _iamq, কেশ্, hwr_, _þríg, 
   {{0xd90c424b,0x9db82d35,0x61e40270,0x99646cc7}},	//   ذیب_, _рыбу_, _mtkl, ртил, 
   {{0xdca40228,0x672405ac,0x7f40024c,0x00000000}},	//   _тажи, ffkj, _kamq, --, 
   {{0x61e42d2b,0x443800a9,0x176800a8,0x7f400381}},	//   _otkl, dwr_, троп_, _jamq, 
   {{0x81dc0183,0x44380142,0x00000000,0x00000000}},	//   ণীত_, ewr_, --, --, 
   {{0x6e2c6cc8,0x7f40047e,0x443803cb,0x638801a9}},	//   çabi, _lamq, fwr_, ҳруҳ_, 
   {{0x61e40029,0xdb1801b8,0x443800a9,0xd3e0036b}},	//   _atkl, _dutö, gwr_, تقزی, 
   {{0x7f401730,0x88740302,0x636800ee,0x00000000}},	//   _namq, _כתוב_, _oýnu, --, 
   {{0x90e40f1b,0xb7f80154,0x44380042,0xe7944973}},	// [7d10] لسان, _অমিত_, awr_, _داوک, 
   {{0x61e0007b,0x4438015d,0x00000000,0x00000000}},	//   íola, bwr_, --, --, 
   {{0x75346cc9,0x7f400921,0x4fc46cca,0x3cfc0810}},	//   mezz, _bamq, асда, davv_, 
   {{0x75346ccb,0xdf5405f5,0x6368022c,0xa2a00c93}},	//   lezz, йнхө, _býnu, _कुक्, 
   {{0x7f406ccc,0x00000000,0x00000000,0x00000000}},	//   _damq, --, --, --, 
   {{0x75346ccd,0x7f4016b8,0x7dc401ec,0x0638008f}},	//   nezz, _eamq, يتوك, ינדט_, 
   {{0x7534026c,0xe8f86b62,0x12c80150,0x00000000}},	//   iezz, ңли_, _ﻓﻭﻀﻭ, --, 
   {{0xd1b80201,0x75346cce,0x7f40011f,0x00000000}},	//   ታዎች_, hezz, _gamq, --, 
   {{0x28f801c0,0x75346ccf,0x1ef8008f,0xcd285368}},	//   лэнэ_, kezz, _תּלמ, _لسان_, 
   {{0x75346cd0,0x4d1400f2,0x44380142,0xe93800d8}},	//   jezz, _خبرآ, ywr_, учиј_, 
   {{0x6d406cd1,0x7f406cd2,0x00000000,0x00000000}},	//   _iala, _yamq, --, --, 
   {{0xa3b40254,0xabcc0873,0x6f180042,0x4e0812eb}},	//   _चीं_, _ﺗﺎﻣﺎ, ngwc, _हटाई_, 
   {{0x75346cd3,0x44380175,0xd87415b4,0x00000000}},	//   fezz, wwr_, لمیت_, --, 
   {{0x6d406cd4,0x69d8020c,0xd75402dd,0x75346cd5}},	//   _jala, _iuwe, _ۇلىت_, gezz, 
   {{0x69d86cd6,0xfa241b4b,0xf3f001fb,0xd1d8001f}},	//   _huwe, _འདོན_, ập_, ሕዛብ_, 
   {{0x6d406cd7,0x69d86cd8,0x02c81f71,0x443800a9}},	//   _lala, _kuwe, иқни_, rwr_, 
   {{0x69d86cd9,0x75346cda,0x6d406cdb,0x7f40047e}},	// [7d20] _juwe, bezz, _oala, _ramq, 
   {{0x69d86cdc,0x7f406cdd,0x753419f5,0x24f46cde}},	//   _muwe, _samq, cezz, _учир, 
   {{0x1e94052f,0x69d86cdf,0x60086aa8,0x636809e8}},	//   әрер, _luwe, унем_, _sýnu, 
   {{0x6d406ce0,0x69d80428,0xa0a4678d,0x7f406ce1}},	//   _aala, _ouwe, _ғабд, _qamq, 
   {{0x69d86ce2,0x61e46afa,0x3cfc0194,0xfa240327}},	//   _nuwe, _utkl, tavv_, _འདེན_, 
   {{0x7f40401f,0xd2b40375,0x00000000,0x00000000}},	//   _wamq, _ללכת_, --, --, 
   {{0x6d406ce3,0x7f406ce4,0x69d80086,0xdc28411c}},	//   _dala, _tamq, _auwe, استه_, 
   {{0x5f9406d5,0x6d406ce5,0x69d86ce6,0xc0d0001f}},	//   _الرئ, _eala, _buwe, _እድሜ_, 
   {{0x386c0368,0x80b80d79,0x75346ce7,0x0e6000c0}},	//   wydr_, _अरुं, yezz, _ектн, 
   {{0x69d86ce8,0xad6400c6,0xdb180120,0x9d740137}},	//   _duwe, _واله, _autô, _دەتا_, 
   {{0x75346ce9,0x69d81dd4,0x22c002b5,0x58846cea}},	//   vezz, _euwe, _hōkī_, сыпа, 
   {{0x69d86ceb,0x22c000b0,0x75340083,0x644801e1}},	//   _fuwe, _kōkī_, wezz, _àfiy, 
   {{0x75346cec,0x6d406ced,0x69d86cee,0x41d800bc}},	//   tezz, _yala, _guwe, _भूलस, 
   {{0x6d406cef,0x22c002b5,0x01cc01ec,0x3e2c0092}},	//   _xala, _mōkī_, _ﺒﺎﻻﻨ, _ሳይደረ, 
   {{0x69d803fa,0x7d080010,0x37c457aa,0x6f180142}},	//   _zuwe, _mdds, _мәмб, ygwc, 
   {{0x69d86cf0,0x75346cf1,0x9f5c0241,0xd1b81954}},	//   _yuwe, sezz, _ìtè_, ታዎት_, 
   {{0x75346cf2,0x69d80175,0x83840124,0x00000000}},	// [7d30] pezz, _xuwe, чыре, --, 
   {{0x764c6cf3,0x63680162,0xaac801f9,0x00000000}},	//   _iray, _sýnt, ाइतक, --, 
   {{0x61444418,0x636800e4,0xb4b81f0d,0x72d46cf4}},	//   تىلە, _pýnt, _خُدا_, _монф, 
   {{0x764c6cf5,0x9ed4052f,0x7d086cf6,0x00000000}},	//   _kray, ҙмәт_, _adds, --, 
   {{0x9ed46cf7,0x6f18009a,0x764c0055,0x92681fbe}},	//   әмәт_, rgwc, _jray, _срна_, 
   {{0x69d86cf8,0x764c022e,0xa2a06cf9,0x69dc0115}},	//   _ruwe, _mray, _कुट्, ŭsek, 
   {{0x6d406cfa,0xfa2408ea,0x69d86cfb,0x211c0490}},	//   _vala, _འདུན_, _suwe, _पातळ_, 
   {{0x69d86cfc,0x764c6cfd,0x7d0802d0,0x2a6c009a}},	//   _puwe, _oray, _edds, tyeb_, 
   {{0x6f086cfe,0x2ca8068f,0xe9d807b5,0x69d80009}},	//   _idec, ład_, јко_, _quwe, 
   {{0x6d406cff,0xa804004e,0xe2380092,0x00000000}},	//   _uala, озол, _የካህና, --, 
   {{0x764c6d00,0x201c01e6,0x69d8002e,0x6f0801ef}},	//   _aray, _ätit_, _wuwe, _kdec, 
   {{0x22c0166a,0x764c6d01,0x7bdc031c,0x00000000}},	//   _hōkū_, _bray, _ħrux, --, 
   {{0x764c6d02,0x41d8000d,0xcaac0248,0x00000000}},	//   _cray, _भंइस, bẹẹg, --, 
   {{0x764c6d03,0xcfbc0183,0x1a98008f,0xa3e8036b}},	//   _dray, ইদিন, _דינע, идга_, 
   {{0x6f086d04,0x764c01d9,0x25a8002f,0x00000000}},	//   _odec, _eray, robl_, --, 
   {{0x764c6d05,0x6f0805b8,0x636802f0,0x00000000}},	//   _fray, _ndec, _rýns, --, 
   {{0x764c6d06,0xed440451,0x63681427,0xa1880022}},	// [7d40] _gray, _ٻھ_, _sýns, абаа_, 
   {{0x80a8000e,0x64580641,0xe10800fb,0x00000000}},	//   _কৃষ্, ätis, режд_, --, 
   {{0x23286d07,0x6458007c,0x00000000,0x00000000}},	//   _кони_, åtid, --, --, 
   {{0xd1e00023,0x00000000,0x00000000,0x00000000}},	//   ዝጊቡ_, --, --, --, 
   {{0x6f0800a9,0x3ea06d08,0xa2a000c5,0x00000000}},	//   _ddec, çit_, _कुच्, --, 
   {{0x6f080365,0x63b46d09,0xbbb46d0a,0x8e4400d1}},	//   _edec, llyn, ुष्क, زلىك_, 
   {{0xd0046d0b,0x6f080295,0xdef80032,0xa0686d0c}},	//   _мере_, _fdec, _ҙың_, _тава_, 
   {{0x63b46d0d,0x00000000,0x00000000,0x00000000}},	//   nlyn, --, --, --, 
   {{0x2ca80ac4,0x81dc015b,0x63b40334,0xfe580214}},	//   ğada_, ণীর_, ilyn, _دیشب_, 
   {{0x6f080034,0x77bc0077,0x63b46d0e,0x2ca86d0f}},	//   _zdec, déxa, hlyn, şada_, 
   {{0x764c00f2,0x6f080142,0x63b46d10,0xa3a800bc}},	//   _sray, _ydec, klyn, खका_, 
   {{0xbcfc035b,0x764c6d11,0xdaa8003b,0x00000000}},	//   _moĩm, _pray, _квед_, --, 
   {{0x61e00597,0x63b40368,0x764c01a9,0xfa240327}},	//   íoll, dlyn, _qray, _འདིན_, 
   {{0xd4986d12,0x332800a3,0xf1c801ec,0x00000000}},	//   арб_, wfax_, _ﺒﺎﻋﺘ, --, 
   {{0xd7f805f5,0x938805f5,0xbcfc0022,0x7d1c007c}},	//   _тул_, асаа_, _noĩm, _örsu, 
   {{0x764c6d13,0x63b46d14,0x03c42626,0x5514000d}},	//   _tray, glyn, дсум, _ताकए_, 
   {{0x764c6d15,0x6f080427,0x439401d5,0x86c400f7}},	// [7d50] _uray, _rdec, фатс, _ۉيۉن, 
   {{0x3d040034,0x3328031c,0x63b4010b,0x00000000}},	//   रणों_, sfax_, alyn, --, 
   {{0x63b40cea,0x920000b8,0x00000000,0x00000000}},	//   blyn, _śādv, --, --, 
   {{0xb8fc0003,0x26100316,0x60600131,0x63b4015d}},	//   _འུ_, _तिमी_, رۇقل, clyn, 
   {{0x7de418fd,0x6f080118,0x00000000,0x00000000}},	//   وسوم, _vdec, --, --, 
   {{0xc8fc03d4,0xaac800bc,0x31a41699,0x6f080210}},	//   ্ভৱত_, ाइसक, _رمزف, _wdec, 
   {{0x270400cc,0x00000000,0x00000000,0x00000000}},	//   ষ্টো_, --, --, --, 
   {{0x6f086a43,0x00000000,0x00000000,0x00000000}},	//   _udec, --, --, --, 
   {{0xdb0c0597,0x92cc00fe,0x1ee80066,0x00000000}},	//   ódál, ৱৰৰ_, _طولی_, --, 
   {{0x8d746d16,0x63b405b1,0x7d080014,0x6ff406be}},	//   _بارا, zlyn, _وٲقف_, _ağcə, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbf880248,0x00000000,0x00000000,0x00000000}},	//   _ààtà, --, --, --, 
   {{0xf1bc0c00,0xd494004d,0x63b40076,0x00000000}},	//   ्गान, ồng_, vlyn, --, 
   {{0x63b46d17,0xe4d812fd,0x61e001e7,0x7d1c6d18}},	//   wlyn, صورت_, íolm, _örst, 
   {{0x09e02158,0x63b406a3,0x77bc0077,0x00000000}},	//   _মিটা, tlyn, séxa, --, 
   {{0x702000cc,0x57f80677,0xa3b4012d,0xe3b84109}},	//   নবাজ_, _פלפו, _चीख_, ёба_, 
   {{0x17180302,0x00000000,0x00000000,0x00000000}},	// [7d60] _הופע, --, --, --, 
   {{0xe2986d19,0x63b46d1a,0xa0a40220,0x00000000}},	//   _ҳам_, slyn, пазд, --, 
   {{0x63b40306,0x443c02e2,0x6604003b,0x00000000}},	//   plyn, _èv_, lskk, --, 
   {{0xe2986d1b,0x00000000,0x00000000,0x00000000}},	//   _гам_, --, --, --, 
   {{0x81f0031c,0x9f5802d2,0x00000000,0x00000000}},	//   _བསྒྲ_, gspá_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x77bc003e,0x00000000,0x00000000,0x00000000}},	//   déxn, --, --, --, 
   {{0x4c100075,0x20186d1c,0x4f840014,0x09e00154}},	//   ربىس, mupi_, _فاقہ, _মিজা, 
   {{0xdd906d1d,0x20186d1e,0x1d08004e,0x5d6800d8}},	//   _كور_, lupi_, _гези_, _лиам_, 
   {{0x9b400133,0x5d8435b6,0x00000000,0x00000000}},	//   بۆچو, _علال, --, --, 
   {{0x20186d1f,0xb6f80131,0xad24009a,0x00000000}},	//   nupi_, يىدا_, _ترقو, --, 
   {{0xeb486d20,0xabcc08b0,0xcb640354,0x9a8401af}},	//   _وشنو_, _ﺗﺎﻳﺎ, _нахе_, _нулл, 
   {{0x20186d21,0x00000000,0x00000000,0x00000000}},	//   hupi_, --, --, --, 
   {{0x79581d56,0x00000000,0x00000000,0x00000000}},	//   _фикр_, --, --, --, 
   {{0x20186d22,0x26100d01,0x94a801b9,0xd3786d23}},	//   jupi_, _तिथी_, ётга_, бча_, 
   {{0x20186d24,0xd6d80276,0x66040139,0x00000000}},	//   dupi_, _утк_, bskk, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [7d70] --, --, --, --, 
   {{0x93246d25,0x20185053,0xd49835a2,0x50c80139}},	//   _کردن, fupi_, _грм_, быем_, 
   {{0x09e000cc,0x20186d26,0x00000000,0x00000000}},	//   _মিছা, gupi_, --, --, 
   {{0x31180490,0x9f5c01e1,0x00000000,0x00000000}},	//   _पाकृ_, _ìtì_, --, --, 
   {{0xa3a8068f,0x7ed40006,0x00000000,0x00000000}},	//   खकर_, нішч, --, --, 
   {{0x21386d27,0x301400f3,0x00000000,0x00000000}},	//   ceph_, _одгр, --, --, 
   {{0x40341d6c,0x20180395,0xdca06d28,0xc8a8000d}},	//   _перс, cupi_, каши, _घुंट, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xea881422,0x00000000,0x00000000,0x00000000}},	//   юбил_, --, --, --, 
   {{0xbe88215b,0xfe706d29,0x2d900205,0x00000000}},	//   _эссе_, _صدق_, _öze_, --, 
   {{0xe7386d2a,0x00000000,0x00000000,0x00000000}},	//   оен_, --, --, --, 
   {{0x06500023,0x70680023,0x00000000,0x00000000}},	//   _ህላውነ, ሰርሓሉ_, --, --, 
   {{0xaa446d2b,0xe7dc07f7,0x00000000,0x00000000}},	//   _целл, _नूरप, --, --, 
   {{0xa3b40c66,0x20180bf1,0x66046d2c,0xfac40032}},	//   _चीज_, yupi_, rskk, _яңыл_, 
   {{0x6fac0073,0x00000000,0x00000000,0x00000000}},	//   टकां, --, --, --, 
   {{0xe3b83334,0x224001e4,0xe1f83ae4,0x3ae0316f}},	//   іба_, _pskk_, жга_, pōpō_, 
   {{0xe2980323,0x00000000,0x00000000,0x00000000}},	// [7d80] цаа_, --, --, --, 
   {{0x20186d2d,0xe47400a8,0x2ca800bc,0xe0d04e77}},	//   tupi_, _жумэ, řady_, نزا_, 
   {{0x657c6d2e,0x61e80219,0xaac800bc,0x64a43de2}},	//   _ilph, _žolč, ाइँक, _цана, 
   {{0x44446114,0x20186d2f,0xd00c006c,0x4f8401d9}},	//   _is_, rupi_, شله_, وانہ, 
   {{0x2018014c,0x644c20e4,0x9f5c0241,0x4ea000d8}},	//   supi_, lvbi, _ìtí_, крша, 
   {{0xa0a40228,0x44446c79,0x20186d30,0x6bc40022}},	//   _жагд, _ks_, pupi_, ҽрыҧ, 
   {{0x4444074d,0x201802d1,0x5f040452,0x00000000}},	//   _js_, qupi_, _озва, --, 
   {{0x200800ca,0x444402c2,0x9f9c004e,0x8c400640}},	//   _ivbi_, _ms_, rçós_, теће, 
   {{0x44446d31,0x657c035a,0xcb6406ed,0xc0c80092}},	//   _ls_, _olph, ќање_, ቼውም_, 
   {{0xf1c80220,0x00000000,0x00000000,0x00000000}},	//   _ﺒﺎﻟﺘ, --, --, --, 
   {{0x44446d32,0xad240fa2,0x387801e7,0x00000000}},	//   _ns_, _سرلو, árr_, --, 
   {{0x68ec008e,0x00000000,0x00000000,0x00000000}},	//   _ğade, --, --, --, 
   {{0x44446114,0x398001ab,0x95540133,0x68ec010e}},	//   _as_, _pòsd_, وخسا, _şade, 
   {{0x44442238,0x45d401b9,0x00000000,0x00000000}},	//   _bs_, кояс, --, --, 
   {{0x44446d33,0x45d42288,0x490000db,0x97a46d34}},	//   _cs_, торс, _شويق, _орил, 
   {{0xb9d80201,0x44446d35,0x657c0c8c,0x25640109}},	//   _አለ_, _ds_, _elph, _môly_, 
   {{0x78b801f4,0x63a40022,0x00000000,0x00000000}},	// [7d90] _hyvv, хырҕ, --, --, 
   {{0x44446d36,0x398002bd,0x98bc0790,0x54f00037}},	//   _fs_, _fòse_, lktı_, _अभिए_, 
   {{0x776c6d37,0x444462e4,0x00000000,0x00000000}},	//   _koax, _gs_, --, --, 
   {{0xdb000085,0x44fc025c,0xabcc02dd,0x00000000}},	//   _ekoú, _དབོར_, _ﺗﺎﻋﺎ, --, 
   {{0x44446d38,0x657c062c,0xdcf83bc1,0xed5810d6}},	//   _zs_, _ylph, _aktı, зол_, 
   {{0x320814dc,0x80a40133,0xc5f400cc,0xe464000d}},	//   msay_, رمۆن, _জিমা_, ööga_, 
   {{0x320814dc,0xabd42424,0x92c42cc5,0x00000000}},	//   lsay_, нциј, _উভয়_, --, 
   {{0x776c06d6,0x256406d9,0xaa4400c7,0x32080abb}},	//   _noax, _dôly_, ееил, osay_, 
   {{0x320814dc,0x8650016b,0xdcf80139,0xfe24030d}},	//   nsay_, _ayɔn, _ektı, _аьхн, 
   {{0x320801d9,0x1cdc025c,0xaa00004b,0x64dc07af}},	//   isay_, _རུར_, پېډي, _मलेश, 
   {{0x32082f05,0x9ce801d3,0x00000000,0x00000000}},	//   hsay_, _رونے_, --, --, 
   {{0x3980180f,0x44441305,0x3208127b,0xa3e40037}},	//   _ròse_, _rs_, ksay_, _पढब_, 
   {{0x44445e69,0x657c0280,0x320803ac,0x00000000}},	//   _ss_, _plph, jsay_, --, 
   {{0x44446d39,0x32082f05,0xd9406d3a,0x7dc4067c}},	//   _ps_, dsay_, _беши, pòse, 
   {{0x44446d3b,0x29046d3c,0x1cdc0003,0x29fc0030}},	//   _qs_, mala_, _རུལ_, lňa_, 
   {{0x38786ab9,0x44446d3d,0x64a40075,0x3208127b}},	//   ørre_, _vs_, _җама, fsay_, 
   {{0x44446d3e,0xd2a46d3f,0x25580276,0xdb0400bc}},	// [7da0] _ws_, екте_, _ернэ_, ámém, 
   {{0x29046d40,0x44446d41,0x27e80063,0xf1a86d42}},	//   nala_, _ts_, _čanj_, واله_, 
   {{0x44444ebd,0x29046d43,0x32085ad6,0x06f42ba2}},	//   _us_, iala_, asay_, _आभाव_, 
   {{0xdee43c55,0x852005f9,0x5ea403cc,0x29fc00d0}},	//   ходи, _बाँट_, ىمال, kňa_, 
   {{0xa2d46d44,0x3208127b,0x29fc0030,0x53bc076e}},	//   _سيست, csay_, jňa_, ्षरश, 
   {{0x29040419,0x29fc01f1,0xd6f8037e,0x98800419}},	//   jala_, dňa_, niを_, víľa_, 
   {{0x316404cc,0xa0a402e8,0x91b4011a,0x00000000}},	//   _òlza_, _чавд, _נפלא_, --, 
   {{0x0e606d45,0x3b5400f7,0xbcfc00c7,0x9f5c0241}},	//   ткән, ткир, _noĩv, _ìtà_, 
   {{0x29046d46,0x4cdc015b,0x8520012d,0xdd880117}},	//   fala_, _নজরু, _बांट_, _ебад_, 
   {{0x29046d47,0xc2fc0154,0x00000000,0x00000000}},	//   gala_, ইলটি_, --, --, 
   {{0x3208035a,0x00000000,0x00000000,0x00000000}},	//   zsay_, --, --, --, 
   {{0x32086d48,0x3980068c,0x29040421,0xcf9000c8}},	//   ysay_, _bòsc_, aala_, ָטש_, 
   {{0x95c81e2d,0x645811c0,0x32086d49,0xeb54215c}},	//   зува_, åtin, xsay_, _جىنگ, 
   {{0x29046d4a,0x1cdc003d,0xceb00bd9,0xbf0c0574}},	//   cala_, _རུས_, ריש_, हणुन_, 
   {{0x32081bb7,0x947403e6,0xd37806b4,0x395c0129}},	//   wsay_, ردسا, пча_, _invs_, 
   {{0x32080c8c,0x628801e4,0x88b8011a,0x00000000}},	//   tsay_, ĝfon, _מזוי, --, 
   {{0xdcf80100,0xaac80316,0xd5b802e8,0x320802d0}},	// [7db0] _altč, ाइएक, _нсо_, usay_, 
   {{0x320814dc,0x46140014,0x869c011a,0xd7c400f1}},	//   rsay_, _حوٝر, _מיחז, _غوښه_, 
   {{0xbf0c2413,0x32082f05,0x4914011a,0x29fc0419}},	//   हणून_, ssay_, תקבל_, zňa_, 
   {{0x29046d4b,0x29fc6d4c,0xd20801c6,0x3208127b}},	//   zala_, yňa_, _нэгд_, psay_, 
   {{0x29046d4d,0xe8d801fb,0x6464054e,0xfde801ec}},	//   yala_, _đọ_, ăriş, едік_, 
   {{0x29fc6d4e,0x51846d4f,0x29046d50,0x6ab8015d}},	//   vňa_, _чума, xala_, _rywf, 
   {{0xdd8c5845,0xcf880a5b,0x00000000,0x00000000}},	//   توو_, _есад_, --, --, 
   {{0x660003e0,0x9f5801e3,0x29fc00d0,0xcc8401e2}},	//   _çokg, tspå_, tňa_, ونږه_, 
   {{0x2dd46d51,0x2eec0115,0xbcfc00e4,0x9f5c01e1}},	//   _ажар, _ifef_, _roĩv, _ìtá_, 
   {{0xc79801ed,0x7dc400cf,0x29fc0f91,0x01cc0220}},	//   کھتا_, ròsc, rňa_, _ﺒﺎﻟﻨ, 
   {{0x29046d52,0xba280344,0x7b640166,0x01e800fe}},	//   rala_, وسیم_, _әтхе, _পিছদ, 
   {{0x29046d53,0x29fc0030,0x7dc4067c,0x60d86d54}},	//   sala_, pňa_, mòsa, _útme, 
   {{0x2b5c00d2,0xfbd05dcd,0x66180034,0x7dc401ab}},	//   _inwc_, _اتل_, ątko, lòsa, 
   {{0x290429e5,0x64a46d55,0xa85400f3,0x00000000}},	//   qala_, вага, _атиј, --, 
   {{0x23285cf0,0x00000000,0x00000000,0x00000000}},	//   мови_, --, --, --, 
   {{0x2b4c00e4,0xe69400ae,0x00000000,0x00000000}},	//   ndec_, _للعد, --, --, 
   {{0x91e06d56,0x59c40034,0x9594001f,0xd1d40092}},	// [7dc0] иоте, _रीडर, ለማችን_, _ክሶች_, 
   {{0x91a4004d,0x161400e1,0xa2d4041c,0xc33015bf}},	//   _địa_, _तितर_, _मृण्, _گەر_, 
   {{0x5f286d57,0x2d9802d2,0xa3e40b26,0xb9d81954}},	//   доем_, _ísey_, _पढि_, _አወ_, 
   {{0x3980068c,0xc33053f0,0xbf0c01bc,0xa2e401a9}},	//   _mòsa_, _دەر_, हणेन_, _шомд, 
   {{0x787800d2,0x67340124,0x2b4c0076,0x9da802e8}},	//   _kúvú, _mbyj, ddec_, мъка_, 
   {{0x61f4005b,0xdfd00451,0x3c0c00bc,0xa3e40210}},	//   mpyl, _چيس_, těv_, _पढा_, 
   {{0xa2d46d58,0x61f46d59,0xdee40124,0xdfa802da}},	//   _मृत्, lpyl, _аоби, _قطره_, 
   {{0x67340175,0x10a00138,0xdb1c03e0,0x68ec0139}},	//   _nbyj, _тисн, _övül, _ğada, 
   {{0x63a4009a,0x68ec2d9a,0x61f401f4,0xc0c401af}},	//   _mjkn, _şada, npyl, _рәҡи, 
   {{0x7dc4067c,0x77bc0407,0x2b4c030a,0xd7e46d5a}},	//   bòsa, méxi, adec_, кімо, 
   {{0x58845eb4,0x00000000,0x00000000,0x00000000}},	//   тыпа, --, --, --, 
   {{0xa3e41533,0x68f46d5b,0x2b4c0798,0x00000000}},	//   _पढ़_, ızda, cdec_, --, 
   {{0x9ad0063f,0x00000000,0x00000000,0x00000000}},	//   sịbe, --, --, --, 
   {{0x55040395,0x00000000,0x00000000,0x00000000}},	//   ъчма, --, --, --, 
   {{0xf3140323,0x98480801,0x00000000,0x00000000}},	//   лдвэ, _цяла_, --, --, 
   {{0x61f4017a,0xd6d80fac,0x00000000,0x00000000}},	//   fpyl, _отп_, --, --, 
   {{0x2eec04d4,0x31340220,0x96440024,0xf15801f0}},	// [7dd0] _rfef_, леар, _рэйд, ниаш_, 
   {{0x2b4c02fb,0x3d1c033f,0xf8e000dc,0x80f4117e}},	//   zdec_, नलों_, _नलोप, ипух, 
   {{0x30140b7e,0x0fe000f7,0x201c12e8,0x00000000}},	//   удер, рөгү, _åtil_, --, 
   {{0x636800a2,0x2c2000fe,0xd34435cf,0x8898123b}},	//   _oýny, _মনলৈ_, _جیره_, ובבי, 
   {{0x61e000c6,0x2b4c0175,0xda64211f,0x8e60010b}},	//   íolt, vdec_, _اُ_, релҗ, 
   {{0x067c0a7c,0x867c011a,0xf1c800be,0x802400db}},	//   ונדל, ורדו, _سوزى_, ارەم, 
   {{0xe8d80016,0x636800a2,0x8f44035b,0xe184013d}},	//   _đỏ_, _aýny, _ихад, _сөте_, 
   {{0x3980068c,0x04dc0375,0x5dc40137,0x00000000}},	//   _ròsa_, וקול, _ەمكە, --, 
   {{0x2b4c6d5c,0x6e18009f,0x00000000,0x00000000}},	//   rdec_, _سياس_, --, --, 
   {{0x5ac46d5d,0x2b4c05b1,0xdcac00f1,0x3ea000ae}},	//   ылым_, sdec_, _کډه_, úite_, 
   {{0x7c846d5e,0x7ac801d3,0xe7286d5f,0x225002f0}},	//   _куце, _یومِ_, нонд_, zvyk_, 
   {{0xddc00118,0x287401e0,0x13bc043e,0x61f401f4}},	//   dvoř, _ҡыйр, ्षोभ, ypyl, 
   {{0xdb4c01d9,0xc5f400eb,0x00000000,0x00000000}},	//   _رَو_, _জিহা_, --, --, 
   {{0x1a9804ac,0x00000000,0x00000000,0x00000000}},	//   _אינע, --, --, --, 
   {{0xa80407d6,0xf9900133,0x23346d60,0xe73812b9}},	//   _ёзил, _ببن_, лхар, _зей_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x211801d9,0xaac8012c,0x24e80150,0x00000000}},	// [7de0] فتاب_, ाइटक, _пмпи_, --, 
   {{0x67240fac,0x61f46d61,0xb63c0220,0x00000000}},	//   lgkj, rpyl, _ﺇﺫ_, --, 
   {{0x61f40a85,0x21a40032,0x200c6d62,0xc0dc0023}},	//   spyl, _ҡимм, éfi_, ሕፋሕ_, 
   {{0x77bc1709,0x61f404ce,0x5f046d63,0x1e840209}},	//   téxi, ppyl, узда, ллем, 
   {{0xb9d8001f,0x63b401ab,0xdcf800de,0x00000000}},	//   _አፈ_, moyn, _altā, --, 
   {{0xae700075,0x3170031c,0x63b403b2,0x00000000}},	//   غۇلغ, _gozz_, loyn, --, 
   {{0x61e40986,0x4c906d64,0x00000000,0x00000000}},	//   _hukl, йишс, --, --, 
   {{0xbb741b88,0x63b403b2,0x78a4002b,0x00000000}},	//   ргиј, noyn, _śivo, --, 
   {{0xe8d801dc,0x3f8437bd,0xef901547,0xcd4000dd}},	//   _đề_, _ilmu_, _بیند, _گھنٹ, 
   {{0xe9701e87,0xf8b800f7,0x38340107,0x63b4062c}},	//   يۇند, көй_, анор, hoyn, 
   {{0x61e40bed,0x7dc400cf,0x38c804f2,0xec5400d1}},	//   _lukl, lòso, کاکی_, _پىنھ, 
   {{0x8c1806a9,0x63b40098,0xb8dc6d65,0x00000000}},	//   _טובי, joyn, _आड_, --, 
   {{0x63b40072,0xd6d86d66,0x7bc001ab,0x588400c7}},	//   doyn, это_, mlmu, _әыла, 
   {{0xceb005e1,0x7bc06d67,0xddc00316,0x00000000}},	//   מיר_, llmu, tvoř, --, 
   {{0x667011fc,0x61e46d68,0x3f840ffb,0x8d5800df}},	//   مگیر, _aukl, _olmu_, עכלי, 
   {{0x7bc00ac5,0x88106d69,0x39800241,0x439421f3}},	//   nlmu, _ابوط, _kòso_, басс, 
   {{0x31701225,0x61e46085,0x92b408de,0x7bc0000d}},	// [7df0] _pozz_, _cukl, احزا, ilmu, 
   {{0x3f846d6a,0x61e46d6b,0x398002e2,0x00000000}},	//   _almu_, _dukl, _mòso_, --, 
   {{0x61e40793,0x63b40429,0x21280208,0x61e001e7}},	//   _eukl, boyn, _dcbh_, íolr, 
   {{0xa3d40e7d,0x61e4031c,0x66000205,0x660c008e}},	//   िगण_, _fukl, _çokc, _änkä, 
   {{0x61e400a2,0x00000000,0x00000000,0x00000000}},	//   _gukl, --, --, --, 
   {{0x3f843386,0xbdf86d6c,0x7bc06d6d,0xac386d6e}},	//   _elmu_, ارنا_, elmu, вчих_, 
   {{0x61e46d6f,0x0578011a,0x6b6401a9,0x00000000}},	//   _zukl, רגום_, икка, --, 
   {{0x61e41ac8,0x60d8045f,0xbbe826c6,0x00000000}},	//   _yukl, _útma, دروم_, --, 
   {{0xa3d43806,0x3d640014,0xc334011a,0xbfa800f3}},	//   िगत_, _گُلٲ, צוץ_, _стре_, 
   {{0xc5f40183,0x7bc0017a,0x8bc402dd,0xa3e400c5}},	//   _জিলা_, almu, _өсед, _पढल_, 
   {{0x2d846d70,0xfd1000c6,0x1cdc025c,0x3b846d71}},	//   _ille_, _رجل_, _རུག_, рлөг, 
   {{0x7bdc5f15,0xeb0810fe,0x9c800030,0x27943ab4}},	//   _érup, _شقتى_, účen, ршор, 
   {{0x2fcc01ab,0xf1c46d72,0x65c401b9,0x63b4022e}},	//   _mheg_, वतान, ибма, voyn, 
   {{0x6b88047e,0x2c5400ef,0x61e40153,0x00000000}},	//   lheg, _kād_, _rukl, --, 
   {{0x61e46d73,0x63b46d74,0x2d846d75,0x9994004b}},	//   _sukl, toyn, _mlle_, _خپور_, 
   {{0x61e46d76,0x6b886d77,0xa02001f4,0x00000000}},	//   _pukl, nheg, öömm, --, 
   {{0x69c06d78,0x63b40579,0x2d84369a,0xe5a402bf}},	// [7e00] olle, royn, _olle_, _випи, 
   {{0x69c06d79,0x61e42220,0x63b403b2,0x00000000}},	//   nlle, _vukl, soyn, --, 
   {{0x69c06d7a,0x2fcc01ab,0x6b886d7b,0x00000000}},	//   ille, _bheg_, kheg, --, 
   {{0x61e46d7c,0x69c02a6e,0xbae004c5,0xe2986d7d}},	//   _tukl, hlle, _যজ্ঞ, _аам_, 
   {{0x1cdc6d7e,0x6b886d7f,0x2fcc6d80,0xa1140137}},	//   _རུང_, dheg, _dheg_, _پوزت, 
   {{0x6d5c016b,0xd6540375,0x6b880124,0x00000000}},	//   _ɔsag, יינת_, eheg, --, 
   {{0x3f9c004a,0xdcf8054e,0xd00435a2,0x9f9c0200}},	//   évus_, _altă, _весе_, nçës_, 
   {{0x2d846d81,0x69c06d82,0x6b886d83,0x3f840ffb}},	//   _elle_, elle, gheg, _ulmu_, 
   {{0x2d84062c,0x9a842cc8,0x7bc00254,0x69c00076}},	//   _flle_, руйл, rlmu, flle, 
   {{0xad2407fc,0x00000000,0x00000000,0x00000000}},	//   _هرمو, --, --, --, 
   {{0xe8d8431d,0x6b886d84,0x7d0802d0,0x2c540055}},	//   _để_, bheg, _ieds, _gād_, 
   {{0x69c06d85,0x6b886d86,0x7d08007c,0x00000000}},	//   alle, cheg, _heds, --, 
   {{0x7d08005c,0xaae400f2,0x2d840847,0x69c00200}},	//   _keds, _اسمو, _ylle_, blle, 
   {{0xdb0000e8,0x489404fb,0x2c540055,0x291000e5}},	//   _ikoñ, ائید_, _yād_, ózat_, 
   {{0x7d086d87,0x3a24039a,0x53e401c6,0x195401ee}},	//   _meds, lump_, рцга, _баҙы_, 
   {{0x7d086d88,0x00000000,0x00000000,0x00000000}},	//   _leds, --, --, --, 
   {{0x6448145e,0xb1143412,0x2fcc0142,0x86c40046}},	// [7e10] _âfin, ймаш, _rheg_, _ويىن, 
   {{0xd4986d89,0x82a40220,0x7dc4007f,0x6b880489}},	//   _арм_, іште, fòsm, zheg, 
   {{0x5064016c,0x98bc007f,0xb03400d8,0x5f880014}},	//   штаа, ketč_, снеш, گٕنہ_, 
   {{0x6b880921,0x1ee80214,0x764c0055,0xa1440171}},	//   xheg, هومی_, _ksay, _apķē, 
   {{0x7d08105c,0x69c06d8a,0x3a2400b5,0xeb9824ae}},	//   _beds, ylle, jump_, ғип_, 
   {{0x3a246d8b,0x764c090c,0x9ba000d1,0x1d0400db}},	//   dump_, _msay, ۋەلى, беши_, 
   {{0xeb986d8c,0x6b886d8d,0x7d080165,0x764c01d5}},	//   лик_, theg, _deds, _lsay, 
   {{0x764c0df9,0x7d086d8e,0x69c0062c,0x33280009}},	//   _osay, _eeds, wlle, ngax_, 
   {{0x69c00228,0x764c6d8f,0x6b886d90,0x3a2401fa}},	//   tlle, _nsay, rheg, gump_, 
   {{0x6f086d91,0xe8f86d92,0x2d8413fd,0x7d740597}},	//   _heec, ыло_, _ulle_, _والط, 
   {{0x69c00cfd,0x6b885bae,0x66e468e3,0x6f0800b5}},	//   rlle, pheg, йона, _keec, 
   {{0x7998014b,0x69c06d93,0x6f086d94,0xa2e4012c}},	//   _emvw, slle, _jeec, _कलेज_, 
   {{0x6f086d95,0x66e46d96,0xaa40005b,0xa14000e2}},	//   _meec, _қопа, örää_, šķie, 
   {{0x6f080225,0x225c02fd,0x5e54010f,0x00000000}},	//   _leec, _čtk_, זישע_, --, 
   {{0x764c6d97,0x98a010e4,0x18a06d98,0x27ec0210}},	//   _esay, _нише, _нашм, ólną_, 
   {{0x6f086d99,0x9f9c0023,0x33280009,0x7c3c01e3}},	//   _neec, rçës_, ggax_, _ärre, 
   {{0xc53801ec,0x00000000,0x00000000,0x00000000}},	// [7e20] _кінә_, --, --, --, 
   {{0xa0686d9a,0x9f9c036e,0x00000000,0x00000000}},	//   лаза_, pçës_, --, --, 
   {{0x6f086d9b,0x55740375,0x7d080f85,0x98bc007f}},	//   _beec, _העין_, _reds, yetč_, 
   {{0x543800c8,0xa1146d9c,0x00000000,0x00000000}},	//   _געטא, _گوست, --, --, 
   {{0x6f08378e,0x7d086d9d,0xb7f80154,0xd3540677}},	//   _deec, _peds, _আয়াত_, _היכי_, 
   {{0x60d8002d,0x00000000,0x00000000,0x00000000}},	//   _útmo, --, --, --, 
   {{0x6b986d9e,0x6f080076,0xfb8801d5,0xbdf80137}},	//   _bmwg, _feec, ириқ_, ارچا_, 
   {{0x7d086d9f,0xdca40058,0x6f080363,0x5ca400d1}},	//   _weds, _һази, _geec, _һизб, 
   {{0x1e846da0,0x5ed40154,0x00000000,0x00000000}},	//   _улам, _ড্রে, --, --, 
   {{0xd90c1f7b,0xdca46da1,0xd7f804a9,0x6f080a40}},	//   ریب_, _лази, лум_, _zeec, 
   {{0x91b8008d,0x6f080083,0x764c6da2,0xc0981954}},	//   רמיי, _yeec, _ssay, _ጋዜጣን_, 
   {{0x764c0113,0x3a246da3,0x7998035a,0x80a00037}},	//   _psay, pump_, _wmvw, _गइने, 
   {{0x8f980302,0xe8d8004d,0x7c3c007c,0x00000000}},	//   ריכי, _đễ_, _ärrb, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x49986da4,0x53b400fb,0x8934011a,0x84640395}},	//   _תשוב, йғор_, _הרוע_, пъте, 
   {{0x764c6da5,0x07a41b6b,0x26100490,0x018803cc}},	//   _tsay, _најн, _तिची_, ەپكى_, 
   {{0x6f086da6,0x6d5c013f,0x00000000,0x00000000}},	// [7e30] _reec, _ɔsab, --, --, 
   {{0x6f080429,0x28d403ce,0x00000000,0x00000000}},	//   _seec, डेवि, --, --, 
   {{0x6f086da7,0x15740014,0x4fc401d5,0x00000000}},	//   _peec, _نٔکھ_, бсда, --, 
   {{0xfa680092,0x00000000,0x00000000,0x00000000}},	//   ዳይኖር_, --, --, --, 
   {{0x6db41220,0xa3d400e1,0xad2403cc,0x6f080072}},	//   ойду, िगर_, قىشى, _veec, 
   {{0xed586da8,0xdb0000fc,0x6f086da9,0xabf42d29}},	//   рок_, _skoð, _weec, очищ, 
   {{0x6f086daa,0xc05801ce,0x7d1801ef,0x00000000}},	//   _teec, _літ_, _řasá, --, 
   {{0xa2bc0950,0x09b007b7,0x00000000,0x00000000}},	//   _वुड्, ुत्य, --, --, 
   {{0x69246dab,0x6e986dac,0x00000000,0x00000000}},	//   омпа, _твар_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x0ca80801,0xef180327,0xad2400f1,0x0a680022}},	//   _стаи_, _kdż_, _هرڅو, _әреи_, 
   {{0xe7080014,0x00000000,0x00000000,0x00000000}},	//   گتھن_, --, --, --, 
   {{0xa968327c,0x7d1800e4,0x00000000,0x00000000}},	//   _вила_, _ñasä, --, --, 
   {{0x53940092,0x9f58033b,0xd94000db,0x00000000}},	//   _መለየት_, nspò_, _жеши, --, 
   {{0x1cdc31d9,0xe7300597,0x2dd402dd,0x00000000}},	//   _རུབ_, _قصة_, _ﺟﻮﻟﻤ, --, 
   {{0x66000023,0xe284005b,0x00000000,0x00000000}},	//   _çoko, олби, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [7e40] --, --, --, --, 
   {{0x60243334,0x66140153,0x78a400b8,0x00000000}},	//   жджа, _ivyk, _śivi, --, 
   {{0xa2e46dad,0x66180034,0x6aa407f7,0xd12c0b73}},	//   _монд, ątku, खपुर, ضمن_, 
   {{0x645c6dae,0xd00c05d9,0x4fa002e8,0x98bc6daf}},	//   _irpi, ئلن_, михв, netā_, 
   {{0x88cc00bd,0x645c01a6,0x00000000,0x00000000}},	//   রশিক, _hrpi, --, --, 
   {{0x1cdc0489,0x224001e4,0x5f880014,0x9f480200}},	//   _རུད_, _ipkk_, دٕچہ_, _kubë_, 
   {{0x39401a4c,0xf1d40323,0xa2bc00dc,0x00000000}},	//   _ĝis_, _хөтө, _वुत्, --, 
   {{0x22400ac5,0x38600558,0x0d8024a5,0x3a7404a9}},	//   _kpkk_, _čir_, злән, злир, 
   {{0xc2140296,0x224005b1,0xb99800d4,0x00000000}},	//   nsɔ_, _jpkk_, йвих_, --, 
   {{0x645c6db0,0x224005b1,0x00000000,0x00000000}},	//   _orpi, _mpkk_, --, --, 
   {{0x1ca40133,0x00000000,0x00000000,0x00000000}},	//   _گێژی_, --, --, --, 
   {{0x9a846db1,0xdb4c04d3,0x78b00055,0x00000000}},	//   _мулл, _شێخ_, _ādvā, --, 
   {{0x8bd404ac,0x645c6db2,0x660005d1,0x98a80205}},	//   _וואו_, _arpi, _çokl, ıbı_, 
   {{0x94a800a7,0x00000000,0x00000000,0x00000000}},	//   атба_, --, --, --, 
   {{0xe8d8001e,0x645c0841,0xd3d801d9,0x98bc00ef}},	//   _đệ_, _crpi, لبرا_, betā_, 
   {{0x1cdc025c,0x645c107d,0x8c180375,0xe81800ec}},	//   _རུན_, _drpi, יולי, _اروڙ_, 
   {{0xb6c405f5,0x645c6db3,0x1dc83af4,0x68ec0432}},	// [7e50] _хөнд, _erpi, ितात, _şadi, 
   {{0x56900046,0x00000000,0x00000000,0x00000000}},	//   _нақт, --, --, --, 
   {{0x66140232,0x7dc4004e,0x6458007c,0x00000000}},	//   _zvyk, còsi, åtit, --, 
   {{0x93241b8f,0x3980067c,0x6614035b,0xed500583}},	//   _بردن, _dòsi_, _yvyk, کھر_, 
   {{0xa8040022,0x51841d39,0x00000000,0x00000000}},	//   _kiñá, _дува, --, --, 
   {{0xfe1c17e6,0xddc00356,0x9f4c007f,0x726c0092}},	//   _निरस_, rvoş, èfò_, _አመታዊ_, 
   {{0x4e140316,0x00000000,0x00000000,0x00000000}},	//   _निकै_, --, --, --, 
   {{0x302800f1,0xf1d800cd,0x00a402f2,0x00000000}},	//   _پيړۍ_, भगवन, _تیمێ, --, 
   {{0x80e00154,0x00000000,0x00000000,0x00000000}},	//   _প্প্, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfc300b73,0x00000000,0x00000000,0x00000000}},	//   _لحن_, --, --, --, 
   {{0xe73844c9,0x7b646db4,0xc5f807d6,0x3878369a}},	//   щем_, _отче, оғи_, ärra_, 
   {{0x98bc6db5,0x07a400c7,0x0ed0000d,0x00000000}},	//   retā_, заҟн, _तरफड, --, 
   {{0x645c01a6,0x7dc4067c,0x66000bbc,0x00000000}},	//   _prpi, tòsi, _çokm, --, 
   {{0x2ed0045e,0x35c40107,0x00000000,0x00000000}},	//   িশিষ, фарҳ, --, --, 
   {{0xe29816c3,0x23640113,0x00000000,0x00000000}},	//   баб_, ñoj_, --, --, 
   {{0xe8d801dc,0x00000000,0x00000000,0x00000000}},	// [7e60] _độ_, --, --, --, 
   {{0x7dc400f7,0x645c6db6,0x00000000,0x00000000}},	//   pòsi, _trpi, --, --, 
   {{0xdef86db7,0x645c6db8,0x98bc0356,0xe3640798}},	//   был_, _urpi, metă_, _екни, 
   {{0x38780579,0x98bc0276,0x44446db9,0x443805d1}},	//   ørri_, letă_, _ip_, mtr_, 
   {{0x44386dba,0x9cc80588,0x44446dbb,0x00000000}},	//   ltr_, әыла_, _hp_, --, 
   {{0x44446dbc,0x98bc0311,0xa0686dbd,0x8e440131}},	//   _kp_, netă_, _лага_, سلىك_, 
   {{0x44446dbe,0x44386dbf,0x00000000,0x00000000}},	//   _jp_, ntr_, --, --, 
   {{0xa3bc0a28,0x44440302,0x00000000,0x00000000}},	//   ेति_, _mp_, --, --, 
   {{0x1cdc0135,0x44446dc0,0x44386dc1,0x1e846dc2}},	//   _རུམ_, _lp_, htr_, _элам, 
   {{0x444427c0,0x44386dc3,0x3d8801d3,0x6e3c008e}},	//   _op_, ktr_, _بحری_, _äsba, 
   {{0xa3bc1fe5,0x44446dc4,0x9f48067c,0x98bc0311}},	//   ेता_, _np_, _aubé_, detă_, 
   {{0x443800fe,0x7e60107d,0x9f8c00e4,0xab080137}},	//   dtr_, _krmp, kýí_, _ۇتۇق_, 
   {{0x44446dc5,0x44380165,0x00000000,0x00000000}},	//   _ap_, etr_, --, --, 
   {{0xd7f86dc6,0x4438030d,0x44446dc7,0x9f482d16}},	//   _луи_, ftr_, _bp_, _dubé_, 
   {{0xd7f84ecc,0x7c380196,0x454800d4,0xe464032e}},	//   _уул_, ntvr, ччям_, _þöll_, 
   {{0x44446dc8,0x6cd401ec,0xd78801e2,0x00000000}},	//   _dp_, _ﺘﻭﺯﻴ, _دختم_, --, 
   {{0x44380368,0x71780261,0x35b43d6b,0x439400ee}},	// [7e70] atr_, обар_, _обир, хатс, 
   {{0x7c3801f5,0x98bc054e,0x44380205,0x622400db}},	//   ktvr, cetă_, btr_, بوكە, 
   {{0x44443046,0x00000000,0x00000000,0x00000000}},	//   _gp_, --, --, --, 
   {{0xca4801ec,0x00000000,0x00000000,0x00000000}},	//   _ﺀﯗﺵ_, --, --, --, 
   {{0x7e6002b9,0x44446dc9,0xd1c80108,0x00000000}},	//   _crmp, _zp_, _гувд_, --, 
   {{0x44446dca,0x91481513,0x6cd40150,0x00000000}},	//   _yp_, _учма_, _ﺘﻭﺭﻴ, --, 
   {{0xeb986dcb,0x444464a2,0x7e6003ac,0x6aa42bf1}},	//   жий_, _xp_, _ermp, खप्र, 
   {{0x7e600334,0x98bc0356,0x00000000,0x00000000}},	//   _frmp, zetă_, --, --, 
   {{0x8e746356,0x7c38017a,0xad240ae5,0x24ac00cc}},	//   _عارض, atvr, _يىرى, _গৰাহ, 
   {{0x44380205,0x00000000,0x00000000,0x00000000}},	//   ytr_, --, --, --, 
   {{0x6d4004f3,0xbd6800f7,0x6fe00073,0x98bc0356}},	//   _ibla, _эрте_, _फळां, vetă_, 
   {{0x44446dcc,0x44380109,0x660003e0,0x00000000}},	//   _rp_, vtr_, _çokk, --, 
   {{0x44441305,0xf55001f2,0x6e38007f,0x6cd401ec}},	//   _sp_, pụ̀_, ntwb, _ﺘﻭﺠﻴ, 
   {{0x44446dcd,0x4438026c,0x6d400ba1,0x9f8c00e4}},	//   _pp_, ttr_, _jbla, výí_, 
   {{0x29041949,0xe7381555,0x444404ce,0x6d406dce}},	//   mbla_, _дей_, _qp_, _mbla, 
   {{0x6d400175,0x44446dcf,0x98bc0356,0x644c0142}},	//   _lbla, _vp_, setă_, rwbi, 
   {{0x44386dd0,0x44442238,0x98bc054e,0x290400df}},	// [7e80] str_, _wp_, petă_, obla_, 
   {{0x7dc400cf,0x2d800131,0x4438045a,0x00000000}},	//   nòst, ﯩﺰﻧﻰ_, ptr_, --, 
   {{0x44440052,0x00000000,0x00000000,0x00000000}},	//   _up_, --, --, --, 
   {{0x6d406dd1,0x5ea416cc,0x00000000,0x00000000}},	//   _abla, ومال, --, --, 
   {{0xb018002e,0xd6f804ce,0x6d40007c,0x98bc0064}},	//   _fee鯵_, xiキ_, _bbla, metą_, 
   {{0x98bc6dd2,0x6d4000a3,0x3c5800a8,0x602400ea}},	//   letą_, _cbla, зикэ_, _одга, 
   {{0xdd9001d9,0x00000000,0x00000000,0x00000000}},	//   _یور_, --, --, --, 
   {{0x6d4000c8,0x98bc6dd3,0x29046dd4,0x7c380d47}},	//   _ebla, netą_, ebla_, rtvr, 
   {{0x7c380196,0x62940097,0xef10010f,0x5278010f}},	//   stvr, nzyo, _תּל_, ַנטא, 
   {{0x4e940014,0x6d4001ab,0xadb41d00,0x7c3802d0}},	//   _تھٔج_, _gbla, _كۇنا_, ptvr, 
   {{0x98bc0006,0x9f5c0ca8,0x00000000,0x00000000}},	//   ketą_, _ìtó_, --, --, 
   {{0x96440323,0x29041e1c,0x6294007f,0x6cd40150}},	//   мэгд, abla_, kzyo, _ﺘﺭﺠﻴ, 
   {{0x29046dd5,0x7bc06dd6,0xdab86dd7,0xa2bc05d7}},	//   bbla_, momu, _بهشت_, _वुल्, 
   {{0x7bc06dd8,0x39800ba1,0x7dc4067c,0x765c0267}},	//   lomu, _còst_, còst, rvsy, 
   {{0x4a086d7e,0xd3786bed,0x08f46dd9,0x6670158b}},	//   _གསོལ_, оча_, _غروب_, نگیر, 
   {{0x72046dda,0x7bc06ddb,0x394c01e6,0x4dec000d}},	//   فورم, nomu, leds_, _चढलई_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [7e90] --, --, --, --, 
   {{0xef18006d,0x394c014a,0x0f0401ad,0xab5c012d}},	//   _może_, neds_, शर्स_, może, 
   {{0xfe706ddc,0x98bc00c0,0xb81c00cc,0x00000000}},	//   یده_, betą_, _তহঁত_, --, 
   {{0x394c6ddd,0x7bc06dde,0x6d406ddf,0x00000000}},	//   heds_, jomu, _sbla, --, 
   {{0x7bc06de0,0x4a080327,0xa3bc6956,0xef18012d}},	//   domu, _གསེལ_, ेतर_, _noże_, 
   {{0xa2c00184,0x3f6404b4,0x00000000,0x00000000}},	//   _сәск, етәб, --, --, 
   {{0x5064006c,0x7bc06de1,0x6d406de2,0x00000000}},	//   _ўтга, fomu, _vbla, --, 
   {{0x7bc06de3,0xef18033f,0x7c840063,0x6b540241}},	//   gomu, _boże_, ђује, _ẹgbi, 
   {{0x7dc4067c,0x0dc80114,0x00000000,0x00000000}},	//   gòss, _дужи_, --, --, 
   {{0x6d401050,0x9f4807c5,0x394c29ef,0xa8040e58}},	//   _ubla, _lubì_, geds_, нзол, 
   {{0x29046de4,0x569001b9,0x7bc04831,0x7dc401ab}},	//   rbla_, қаёт, bomu, ròst, 
   {{0x29040295,0x7dc4068c,0x80dc0f22,0x00000000}},	//   sbla_, bòss, মুক্, --, 
   {{0x394c0793,0x39806de5,0xaa440139,0x7dc4068c}},	//   beds_, _pòst_, _челл, pòst, 
   {{0x394c01b8,0x6b88143a,0x2b4c058a,0x80a000c5}},	//   ceds_, lkeg, leec_, _गइले, 
   {{0x69c06de6,0x6b8801c4,0x98bc0024,0x245400e4}},	//   mole, okeg, tetą_, _ẽmby_, 
   {{0xe1f8265b,0xe6186de7,0x69c06de8,0x6b8812ed}},	//   зга_, _еди_, lole, nkeg, 
   {{0xd24c00dd,0x69c0002e,0xe2986de9,0x98bc00c0}},	// [7ea0] ینہ_, oole, чаа_, retą_, 
   {{0x69c06dea,0x7bc06deb,0x6b886dec,0x76800241}},	//   nole, zomu, hkeg, _àgbọ, 
   {{0x7bc06ded,0x64a46dee,0x6b886def,0xdef83fad}},	//   yomu, _чана, kkeg, пыл_, 
   {{0x657c6df0,0xd00c6df1,0x1ae403d4,0x00000000}},	//   _hoph, صله_, ওঁতে_, --, 
   {{0x69c05249,0x657c6df2,0x2b4c039a,0xe8d8004d}},	//   kole, _koph, deec_, _đờ_, 
   {{0x657c037e,0x6b886df3,0x7bc06df4,0x00000000}},	//   _joph, ekeg, womu, --, 
   {{0x7bc06df5,0x657c6df6,0x3cf000af,0x6b8802d0}},	//   tomu, _moph, _चलीं_, fkeg, 
   {{0x657c6df7,0x69c0015d,0xaa8402f0,0x00000000}},	//   _loph, eole, zvýš, --, 
   {{0x394c6df8,0x22506df9,0x657c6dfa,0x9e640139}},	//   teds_, nwyk_, _ooph, _явад, 
   {{0x69c06dfb,0x657c6dfc,0xd91807d8,0x21f406ea}},	//   gole, _noph, чьи_, _mæh_, 
   {{0x394c6dfd,0x7bc06dfe,0x2b4c058a,0x6b880010}},	//   reds_, pomu, beec_, bkeg, 
   {{0x6b886dff,0x69c00421,0x394c014a,0x61bc16d1}},	//   ckeg, aole, seds_, ्तुष, 
   {{0x8f9813e2,0x657c6bf9,0x394c0793,0x21f4005c}},	//   ליטי, _boph, peds_, _næh_, 
   {{0x69c06e00,0x9f486e01,0xca540bd9,0x657c6e02}},	//   cole, _jubâ_, _ניוז_, _coph, 
   {{0x80a00574,0x657c6e03,0xa3bc00cd,0xd36c0116}},	//   _गेले, _doph, ेतं_, مۇد_, 
   {{0x9f480139,0x657c03ac,0x00000000,0x00000000}},	//   _bubí_, _eoph, --, --, 
   {{0x657c6e04,0x776c009d,0x00000000,0x00000000}},	// [7eb0] _foph, _inax, --, --, 
   {{0x657c123b,0x6b886e05,0x9f48013a,0x00000000}},	//   _goph, zkeg, _dubí_, --, 
   {{0x3fb00046,0x9484010b,0x30e401ec,0x00000000}},	//   ﻳﯟﺍﻧ, _чыпд, тсаң, --, 
   {{0x69c06e06,0x8fc46e07,0x657c6e08,0x3ef8084c}},	//   zole, رزان, _zoph, енцэ_, 
   {{0x69c06e09,0xed586e0a,0x657c6e0b,0xa2806e0c}},	//   yole, дол_, _yoph, _پیلو, 
   {{0x9f580268,0xfeb86e0d,0x4f90001f,0x69c06e0e}},	//   appà_, رانت_, ዛኛዎቹ_, xole, 
   {{0x69c06e0f,0x776c01d5,0x6b886e10,0x3cdc00c5}},	//   vole, _onax, tkeg, गेले_, 
   {{0x69c06e11,0x0fe06e12,0x7f586e13,0xab641422}},	//   wole, _сөзү, _пасс_, твил, 
   {{0x69c06e14,0x6b8812ed,0x41b400aa,0x7f94013e}},	//   tole, rkeg, _شمېر, _сатх, 
   {{0x6b886e15,0x98bc0034,0xb0c40118,0x8d740066}},	//   skeg, letę_, _वडाग, _ثارا, 
   {{0xcc0843f6,0x69c06e16,0xe7286e17,0x657c047e}},	//   _رزان_, role, монд_, _roph, 
   {{0x69c06e18,0x98bc0210,0x00000000,0x00000000}},	//   sole, netę_, --, --, 
   {{0x657c6e19,0xa97800f7,0x4a08031c,0x00000000}},	//   _poph, _ойду_, _གསིལ_, --, 
   {{0xa9a405f5,0x9f480137,0x657c22a9,0x69c00117}},	//   _шилд, _rubí_, _qoph, qole, 
   {{0xb8643229,0x9f480407,0x2334074d,0xc95002dd}},	//   _مايو, _subí_, кхар, _атқы, 
   {{0x657c6e1a,0x7dc4004e,0x9c800306,0x22504e1b}},	//   _woph, hòsp, účin, twyk_, 
   {{0x657c6e1b,0xd6cc0150,0xa2e4084c,0x66640014}},	// [7ec0] _toph, _وقى_, тоад, _شُدٕ, 
   {{0x3cf00034,0x61bc102f,0x2250000f,0x657c03b2}},	//   _चलें_, ्तेष, rwyk_, _uoph, 
   {{0x22506e1c,0x45e400d1,0x205401f0,0xca2c0150}},	//   swyk_, _ﺋﻮﻳﻼ, ътар, _ﺨﻤﺔ_, 
   {{0x1e840032,0x2d800112,0xa3b400c5,0x00000000}},	//   клем, öhen_, _जदि_, --, 
   {{0x8e346e1d,0x717007d2,0x00000000,0x00000000}},	//   نسور_, _گۇلا, --, --, 
   {{0xe0446e1e,0x91003667,0x5698010f,0x0dc402e8}},	//   _инги, _впре, וינצ, кущи_, 
   {{0x80e00eac,0xe8d80208,0xa0a46e1f,0xadb400db}},	//   _প্র্, _đở_, _равд, دۇلا_, 
   {{0x0c806e20,0x6e4403b2,0x00000000,0x00000000}},	//   рышм, ítbý, --, --, 
   {{0x4e080034,0x5de421cb,0x00000000,0x00000000}},	//   सीआई_, _ажаа, --, --, 
   {{0x776c0227,0xce340bd4,0x0e980302,0x6d5c013f}},	//   _snax, _באמת_, _חשמל, _ɔsak, 
   {{0x7d183ca6,0x00000000,0x00000000,0x00000000}},	//   mavs, --, --, --, 
   {{0x7d180820,0x3868004e,0xab5c0210,0x00000000}},	//   lavs, _үздү_, rożc, --, 
   {{0x95c803b7,0xc6a4013e,0xdcf80100,0x07a40953}},	//   дува_, арри, _lotč, раўн, 
   {{0x7d181828,0x61bc08df,0x98bc012d,0x9f8c010b}},	//   navs, ्तोष, zetę_, lýä_, 
   {{0xab5c0327,0x318401ec,0x69d8010f,0xef180210}},	//   loża, қтаң, _אַקו, _loża_, 
   {{0x7d181600,0x9f8c09a5,0x395c6e21,0x06e8009e}},	//   havs, nýä_, _havs_, পড়ি, 
   {{0x7d1804a7,0x80e02cc5,0xef180210,0x00000000}},	// [7ed0] kavs, _প্ল্, _noża_, --, 
   {{0x90e46e22,0x31580aaa,0x2ff80276,0x7d183493}},	//   نسان, علاج_, енжь_, javs, 
   {{0x7d1805a1,0x395c6e23,0x9f8c00a2,0x41e443e1}},	//   davs, _mavs_, kýä_, ріта, 
   {{0x9f4800db,0xb904031c,0xdcf80118,0xef180210}},	//   _cubà_, _ཨཻ_, _dotč, _boża_, 
   {{0x85b80014,0x660005d1,0x9f8c0432,0xae440066}},	//   _سایس_, _çokt, dýä_, اپتو, 
   {{0x395c1429,0xef180135,0xdcf8007f,0x5184014b}},	//   _navs_, _doża_, _fotč, _рума, 
   {{0x6cc40228,0xdca0010b,0x98bc012d,0xa5d8010f}},	//   ыйка, йаши, petę_, ײַסי, 
   {{0xd1b8001f,0xaab0033f,0x9f8c00a2,0x00000000}},	//   ዳዎች_, ुअलक, gýä_, --, 
   {{0xe8d8001e,0x7d180e04,0x2b9001e7,0x6a844009}},	//   _đố_, bavs, _cáca_, улпа, 
   {{0x6f180198,0x395c6e24,0x7d1800e2,0x00000000}},	//   lawc, _cavs_, cavs, --, 
   {{0xe73838eb,0x3cf00232,0x395c01bf,0xa7a8329b}},	//   нен_, ňové_, _davs_, екна_, 
   {{0x6f180034,0x98bc0118,0x00000000,0x00000000}},	//   nawc, letě_, --, --, 
   {{0x395c6e25,0xc6d4009d,0x7bdc0055,0x00000000}},	//   _favs_, рснө, _ūrug, --, 
   {{0x6f180113,0x64a46e26,0x395c1355,0x98bc0118}},	//   hawc, гага, _gavs_, netě_, 
   {{0x74480023,0x18640395,0x00000000,0x00000000}},	//   _ምውጻእ, _бащи_, --, --, 
   {{0x6f180455,0xd1d80023,0x00000000,0x00000000}},	//   jawc, ንዛብ_, --, --, 
   {{0x6f18006d,0x98bc0118,0xe2a800ec,0x00000000}},	// [7ee0] dawc, ketě_, رارن_, --, 
   {{0xdcf82625,0xd6f8037e,0xef18025c,0x00000000}},	//   _potč, bnコ_, _roża_, --, 
   {{0xd1d8001f,0x60086e27,0x8cbc000d,0x00000000}},	//   ንዛቤ_, хнем_, _लँगो, --, 
   {{0x7c3c00c5,0xef18031c,0xd4780a7c,0x6f18012d}},	//   _ärri, _poża_, _נאכל, gawc, 
   {{0x7d186e28,0x63a4022e,0x3ea008c2,0xe28401d5}},	//   tavs, _imkn, àit_, _ёлги, 
   {{0xdeb00220,0x21742bbd,0x000401d5,0x216800d8}},	//   _құлы, _сумр, _نثری, _џиви_, 
   {{0x61ec01e2,0x644801b8,0xdfd00451,0xd114011a}},	//   _iibl, _äfid, _هيس_, _תקלה_, 
   {{0x61ec6e29,0xdee46e2a,0x395c337b,0x9f4800d8}},	//   _hibl, _боби, _savs_, _fubá_, 
   {{0x61ec6e2b,0x0084036b,0x7d180427,0xdb7800fd}},	//   _kibl, _ёлғо, pavs, _үсеш_, 
   {{0x61ec047e,0xc0dc0b82,0x395c022e,0x00000000}},	//   _jibl, ንጋር_, _qavs_, --, 
   {{0x61ec0109,0xab5c012d,0x00000000,0x00000000}},	//   _mibl, możn, --, --, 
   {{0xda640c8b,0x61ec6e2c,0x78640116,0x00000000}},	//   _ماتي, _libl, гкүз, --, 
   {{0x395c00da,0x61ec007b,0x2b1000db,0x9f58005b}},	//   _tavs_, _oibl, _بژىز, mppä_, 
   {{0xbf10069f,0x61ec6e2d,0x00000000,0x00000000}},	//   ारुन_, _nibl, --, --, 
   {{0xf8d8000d,0xc4280108,0x5344009d,0x00000000}},	//   _डरिय, люте_, лхаа, --, 
   {{0x12e4005e,0x61ec0493,0xddc0033f,0xb3540063}},	//   гізг, _aibl, twoś, јкаш, 
   {{0xb2746e2e,0x25a80158,0xb11400d8,0x473400cf}},	// [7ef0] шлаш, bibl_, имаш, _ارىز, 
   {{0x764c6e2f,0x61ec6e30,0x6f180034,0x00000000}},	//   _ipay, _cibl, wawc, --, 
   {{0x61ec6e31,0xbf102c35,0x720401ed,0x2ef40408}},	//   _dibl, ारंभ_, _چہرہ_, азер, 
   {{0x70c40073,0x00000000,0x00000000,0x00000000}},	//   _वडील, --, --, --, 
   {{0x61ec354d,0x6f18033f,0x00000000,0x00000000}},	//   _fibl, rawc, --, --, 
   {{0x32086e32,0x61ec6e33,0x764c6e34,0x6f186e35}},	//   mpay_, _gibl, _mpay, sawc, 
   {{0x320814dc,0x2b5c0472,0xdca0034b,0xbea400d1}},	//   lpay_, _pawc_, жащи, ишәй, 
   {{0xa1f001ec,0x61ec0165,0x7f940022,0x9ba00131}},	//   _اۋەت, _zibl, _ласх, يەلى, 
   {{0x32086e36,0x7f840597,0x764c07ab,0x61ec0117}},	//   npay_, _القن, _npay, _yibl, 
   {{0xa9a405c5,0x75240564,0x61ec002e,0x68446e37}},	//   риод, _ndhz, _xibl, аноа, 
   {{0xe8d801dc,0x764c6e38,0xfbd0021a,0x4a700220}},	//   _đồ_, _apay, _کتل_, рықт, 
   {{0xfc302cee,0xdcf800b0,0x764c0175,0x7c94007b}},	//   _رحم_, _iotā, _bpay, _اشكا, 
   {{0x25a86e39,0xdcf8002b,0x29d401b9,0x320803ac}},	//   ندسي_, _hotā, _кўкс, jpay_, 
   {{0x320814dc,0x1a9808a8,0x27e0003e,0x00000000}},	//   dpay_, _בינע, smkn_, --, 
   {{0x764c6e3a,0x638401c6,0x3208035a,0xab5c0327}},	//   _epay, агва, epay_, nożo, 
   {{0x61ec6e3b,0x25a800a9,0x8c240f22,0x320803ac}},	//   _sibl, sibl_, _মহান_, fpay_, 
   {{0x61ec6e3c,0xdb000124,0x7c3c007c,0x3208035a}},	// [7f00] _pibl, _omoî, _ärrv, gpay_, 
   {{0xa06851e4,0x64586e3d,0x21a46e3e,0xe0441fbe}},	//   каза_, ætis, шизм, инзи, 
   {{0x61ec00ad,0xdcf800e2,0x3208035a,0x9f0400f1}},	//   _vibl, _notā, apay_, لواو, 
   {{0x9e643d63,0x32080998,0x764c0334,0x61ec0142}},	//   ивед, bpay_, _ypay, _wibl, 
   {{0x5de46e3f,0x32080c8c,0x764c05b1,0x00000000}},	//   ажда, cpay_, _xpay, --, 
   {{0xe0d86e40,0xdcf800de,0xa11400f1,0x814400e5}},	//   _авг_, _botā, _خوست, _دھرم, 
   {{0x16d01152,0x28d000e1,0xab5c033f,0x00000000}},	//   _सर्ब, _हरगि, rożn, --, 
   {{0x63b46e41,0xdb0000e4,0xdcf800de,0x7bdc00b8}},	//   nnyn, _emoî, _dotā, _ūrub, 
   {{0xcb646997,0x6f0c0005,0xab5c033f,0x1a7401ec}},	//   рање_, ñace, możl, рұлы_, 
   {{0x3f846e42,0x764c00b8,0x98e4004e,0x00000000}},	//   _homu_, _rpay, июнд, --, 
   {{0x3f84148b,0x764c6e43,0x5b2404d3,0xd0f40375}},	//   _komu_, _spay, _نفال, ימית_, 
   {{0x32080c8c,0xe8500131,0x764c022e,0x3f8400de}},	//   ypay_, سچىد, _ppay, _jomu_, 
   {{0xdb840020,0x3f840a73,0xeb54113e,0x3208035a}},	//   ንኛውም_, _momu_, _دىنگ, xpay_, 
   {{0x3f846e44,0x6800005f,0xf8f40166,0x9e5c0092}},	//   _lomu_, _sēde, _упкэ, _ታክስና_, 
   {{0x93a4036b,0x32086e45,0xc8d00150,0x63b40142}},	//   ашад, wpay_, _وزىع, fnyn, 
   {{0x3f84601a,0x320814dc,0xddcc0030,0x767400f3}},	//   _nomu_, tpay_, ždňa, _глиф, 
   {{0x764c6e46,0x32080c67,0x6800005f,0x67b4004b}},	// [7f10] _upay, upay_, _vēde, _دجوړ, 
   {{0x320814dc,0xdb0000c7,0x91046e47,0x75240200}},	//   rpay_, _omoï, рчад, _udhz, 
   {{0x3f846e48,0x32082f05,0xc1e835c7,0xe5b40131}},	//   _bomu_, spay_, рьте_, _ﭼﯜﻧﻜ, 
   {{0x3f842b1d,0x32080c8c,0xe454008f,0x6fb82309}},	//   _comu_, ppay_, _פירט_, ыгер_, 
   {{0x6458038f,0xdb0000db,0x32080309,0x8e7400fb}},	//   ħtie, _amoï, qpay_, шҡас_, 
   {{0x98a8012d,0x00000000,0x00000000,0x00000000}},	//   żbę_, --, --, --, 
   {{0x3f846e49,0x30e41c82,0x308400c6,0xa3bc0073}},	//   _fomu_, _প্ৰস, _الزف, ेतच_, 
   {{0x3f840bfa,0x1c6800cf,0x6e2c0327,0xab5c6e4a}},	//   _gomu_, اشوۋ_, ġabb, rożo, 
   {{0x9f480793,0x2fcc0165,0x8e540354,0xc03c0092}},	//   _dubä_, _ikeg_, _тĕпл, _ያልተወ, 
   {{0xdcf800e2,0x00000000,0x00000000,0x00000000}},	//   _totā, --, --, --, 
   {{0x3f843a41,0xb17402dd,0x00000000,0x00000000}},	//   _yomu_, ргiз, --, --, 
   {{0x2d846e4b,0xef180210,0x00000000,0x00000000}},	//   _hole_, _jeż_, --, --, 
   {{0x2d846e4c,0xe8d80016,0x274c0023,0x232807a5}},	//   _kole_, _đổ_, _ንዛረበ, ғози_, 
   {{0xfd840075,0x2d846e4d,0xf8a8029e,0x00000000}},	//   ﯨﻐﺎﻥ_, _jole_, ادیه_, --, 
   {{0x2d846e4e,0x23286e4f,0xdcf8084c,0x00000000}},	//   _mole_, лови_, _hotă, --, 
   {{0x2d846e50,0x48c00124,0xe7380117,0x00000000}},	//   _lole_, _гәҭа, _сеи_, --, 
   {{0x3f846e51,0x2d846e52,0x63b46e53,0x00000000}},	// [7f20] _romu_, _oole_, rnyn, --, 
   {{0x3f846e54,0x2d846e55,0x2fcc0165,0xbf100118}},	//   _somu_, _nole_, _akeg_, ार्न_, 
   {{0x3f846e56,0xef180210,0x5c2000eb,0x00000000}},	//   _pomu_, _beż_, _ভঙ্গ_, --, 
   {{0x2d844774,0xe2c84d20,0x5e24007b,0x00000000}},	//   _aole_, _موجو_, معتق, --, 
   {{0x3f840564,0x88cc03d4,0x9da8011c,0x00000000}},	//   _vomu_, ৰশিক, лъка_, --, 
   {{0x3f8404ba,0x2d840d63,0xdee41171,0x00000000}},	//   _womu_, _cole_, _ғози, --, 
   {{0x2d846e57,0x3f846e58,0xef18031c,0x00000000}},	//   _dole_, _tomu_, _feż_, --, 
   {{0x2d840129,0xc03c0092,0x6d440022,0x00000000}},	//   _eole_, _ያልታወ, õhar, --, 
   {{0x2d846e59,0x26d00083,0xb9981363,0xb924001f}},	//   _fole_, _nyyo_, ивих_, ዳዳሪዎ, 
   {{0x2d846e5a,0xdd901f3c,0xdcf80311,0x6d900174}},	//   _gole_, _عوض_, _dotă, rðaæ, 
   {{0x26d0011f,0x645c01f5,0x00000000,0x00000000}},	//   _ayyo_, _nspi, --, --, 
   {{0x2d84262b,0x8704011c,0x00000000,0x00000000}},	//   _zole_, зяре, --, --, 
   {{0x2d84073c,0x27f0009f,0xab5c025c,0x49b40101}},	//   _yole_, _diyn_, kożj, شاید_, 
   {{0x27f00076,0x29d80066,0x2d84002e,0x1db800cd}},	//   _eiyn_, lèan_, _xole_, ेवित, 
   {{0x980401c6,0x480400d8,0x00000000,0x00000000}},	//   _уялд, _лејн_, --, --, 
   {{0x645c01c7,0x27f00363,0x2a780248,0x9f40110e}},	//   _dspi, _giyn_, _ègbá_, _òkè_, 
   {{0x853407d6,0x15f04142,0xef180210,0x00000000}},	// [7f30] _کوپچ, _इंटर_, _reż_, --, 
   {{0x56906e5b,0x2fcc06ea,0xd3440bce,0xab5c0327}},	//   _мақт, _skeg_, _گیره_, gożj, 
   {{0x6614068f,0x2d846e5c,0xef180327,0x4aac00bc}},	//   _zwyk, _role_, _peż_, _जेनव, 
   {{0xdcec012c,0xd3440fa2,0x2d846e5d,0x136801d5}},	//   žděn, _دیره_, _sole_, _ёшни_, 
   {{0x2d846e5e,0x29d80066,0xf28801c0,0xb0f800d8}},	//   _pole_, dèan_, _төвд_, _вегф_, 
   {{0xac086e5f,0x2ea80490,0x00000000,0x00000000}},	//   анка_, _कधीत, --, --, 
   {{0xef18006d,0x2d846e60,0xeae400bd,0x40340372}},	//   _też_, _vole_, _নভেম, _нерс, 
   {{0x2d846e61,0x29d80066,0x6eb0012c,0x00000000}},	//   _wole_, gèan_, _आइपु, --, 
   {{0x2d846e62,0x358c0023,0x2b900208,0xdcb40139}},	//   _tole_, ነኛታት_, _háck_, йгәч_, 
   {{0x27f06e63,0x6dc00137,0xdcf80356,0x3ea000a3}},	//   _siyn_, _تۅتۅ, _votă, ùite_, 
   {{0x799803ac,0x3dc004e6,0x270001e1,0x68000171}},	//   _dlvw, éiwe_, _pєn_, _bēda, 
   {{0xe73825fc,0xcbc40137,0xa3ac4970,0x48780092}},	//   шем_, _ازئي, _औषध_, _ብያለሁ_, 
   {{0x645c00b5,0x799802d0,0x00000000,0x00000000}},	//   _sspi, _flvw, --, --, 
   {{0x290000af,0x24080580,0x00000000,0x00000000}},	//   _üha_, инги_, --, --, 
   {{0xe8d8001e,0xa878008f,0xe3640798,0xe3ac0154}},	//   _đỗ_, _כאַר, окви, ককসব, 
   {{0x7c3c08fb,0x00000000,0x00000000,0x00000000}},	//   _årre, --, --, --, 
   {{0x645c0034,0x65d4007b,0x562400c0,0x66580354}},	// [7f40] _wspi, _ويعط, _джым_, _тапă, 
   {{0xa5080640,0x6b98015d,0x68ec010b,0x25ac032e}},	//   _њена_, _llwg, _şady, _öfl_, 
   {{0x645c6e64,0x00000000,0x00000000,0x00000000}},	//   _uspi, --, --, --, 
   {{0x44446e65,0x44386e66,0x5438010f,0x03d800cc}},	//   _iq_, mur_, _דעטא, _দূৰণ, 
   {{0x44386e67,0x6f0c0077,0x44440f85,0x00000000}},	//   lur_, ñaca, _hq_, --, 
   {{0x44446e68,0x44386e69,0xdb000e78,0x63040150}},	//   _kq_, our_, _bloß, _دوڭل, 
   {{0x44386e6a,0x44440477,0x2b9000d7,0x37d000fe}},	//   nur_, _jq_, _kách_, _সংঘৰ, 
   {{0x444406bb,0x9b686e6b,0x44386e6c,0x00000000}},	//   _mq_, ршка_, iur_, --, 
   {{0x44386e6d,0x9e6436bd,0x2b9001fb,0xd90c036b}},	//   hur_, _بازن, _mách_, پیب_, 
   {{0x44386e67,0x44446e6e,0x2b906e6f,0xfcc400d1}},	//   kur_, _oq_, _lách_, _нәйм, 
   {{0x44446e70,0x680000e2,0x2b900051,0x9b040024}},	//   _nq_, _pēda, _oách_, _дзед, 
   {{0x44386e71,0x2b906e72,0xdcf8033f,0x66000055}},	//   dur_, _nách_, _dotą, _ũoka, 
   {{0x44446e73,0x44386e74,0x7c380989,0xb90000fe}},	//   _aq_, eur_, luvr, _থল_, 
   {{0x44386e75,0x95c86e76,0x9f50006a,0xf8b80139}},	//   fur_, рума_, öyê_, _гөм_, 
   {{0x44386e77,0x44446e78,0x2b90001e,0x76900241}},	//   gur_, _cq_, _bách_, _bóyú, 
   {{0x2b9001dc,0x00000000,0x00000000,0x00000000}},	//   _cách_, --, --, --, 
   {{0x64480793,0x2b90001e,0x11080131,0x44446e79}},	// [7f50] _äfin, _dách_, لغاي_, _eq_, 
   {{0x44386e7a,0x44446e7b,0x7dc402e2,0x3d14012d}},	//   bur_, _fq_, pòsy, डरों_, 
   {{0x769001e1,0x44386e7c,0x4444045a,0x4fc401a9}},	//   _fóyú, cur_, _gq_, осда, 
   {{0x7e600166,0x7c3801a6,0x70580aac,0x9268004e}},	//   _bsmp, duvr, _қабр_, _крга_, 
   {{0x4444037e,0x7c386e7d,0x00000000,0x00000000}},	//   _zq_, euvr, --, --, 
   {{0xed581fbd,0x4444037e,0x82340014,0x51080354}},	//   сок_, _yq_, _کرێا, _тĕкĕ, 
   {{0x44446e7e,0xeb9000c6,0xab5c0327,0x00000000}},	//   _xq_, فظة_, lożi, --, 
   {{0x2b900016,0x7c9c0092,0x00000000,0x00000000}},	//   _xách_, ቃልላል_, --, --, 
   {{0x44386e7f,0xab5c031c,0xe7fc000d,0x6d344031}},	//   zur_, nożi, _ईंहा_, _неаф, 
   {{0x7c3806ea,0x00000000,0x00000000,0x00000000}},	//   ðarø, --, --, --, 
   {{0x6d406e80,0x44386e81,0x7c3805d5,0x6e380477}},	//   _icla, xur_, cuvr, luwb, 
   {{0x44386e82,0x44446e83,0x9f480241,0x00000000}},	//   vur_, _rq_, _subú_, --, 
   {{0x44446e84,0x44380502,0x2b906e85,0xdbc400c5}},	//   _sq_, wur_, _rách_, tööl, 
   {{0x44386e86,0x2b9007ae,0x44446e87,0xef18025c}},	//   tur_, _sách_, _pq_, _dożi_, 
   {{0x44446e88,0x9f4800d2,0xa7b4009b,0xe298035b}},	//   _qq_, _vubú_, _нсиј, әаз_, 
   {{0x44445d94,0x9f440660,0xf7d40952,0x6e38016b}},	//   _vq_, rmoë_, ﯟﺍﻟﺪ, kuwb, 
   {{0x44386e89,0x44440d29,0x2b9001fb,0x6d406e8a}},	// [7f60] sur_, _wq_, _vách_, _ocla, 
   {{0x44446e8b,0x29046e8c,0x6d400175,0xf1a80fb4}},	//   _tq_, ncla_, _ncla, ياله_, 
   {{0x44386e8d,0x44446e8e,0x2b90001e,0x6e380d27}},	//   qur_, _uq_, _tách_, euwb, 
   {{0xd00c6e8f,0xd4780a1e,0xc29401d5,0x7c38014f}},	//   الن_, _האטל, _قیزب, vuvr, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d400d81,0x358c0023,0x7c38107d,0x00000000}},	//   _ccla, _ዓወታት_, tuvr, --, 
   {{0x6e386e90,0x91e000ee,0xfbb00aff,0xb630313e}},	//   auwb, _чоре, _जगदम, _ﺟﯘ_, 
   {{0x6d406e91,0x7bc40006,0x3a740131,0xdc740022}},	//   _ecla, čiuo, длир, _ҭыжь, 
   {{0x7c38014f,0x9cf400d8,0x59640395,0x12e00150}},	//   suvr, _ечеш, пъна, _ﻋﹼﻤﻭ, 
   {{0x0e601621,0x6d4000ae,0x0e98011a,0x00000000}},	//   _якун, _gcla, _השמל, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x48a40962,0xef180327,0x29044230,0xebc000fb}},	//   ятым_, _pożi_, acla_, _үҙән, 
   {{0x6d4002d0,0x645803e0,0x00000000,0x00000000}},	//   _ycla, çtin, --, --, 
   {{0x6d4004fb,0x69b402dd,0x09c400bc,0xd90c6e92}},	//   _xcla, _оқыс_, रकृय, _حید_, 
   {{0x38c86e93,0xe9a80014,0x25dc00e1,0x89d8011a}},	//   _باشی_, _بدنن_, _गठरी_, _החגי, 
   {{0xb4bc05ba,0x60d803b2,0xdb14013d,0x88b8011a}},	//   _अशी_, _útmy, _ücät, _למוז, 
   {{0x95c8016c,0x00000000,0x00000000,0x00000000}},	// [7f70] _гуна_, --, --, --, 
   {{0xab5c025c,0x2b9000e5,0x00000000,0x00000000}},	//   rożi, _váci_, --, --, 
   {{0xe8d80051,0xfbcc08a3,0x00000000,0x00000000}},	//   _đừ_, ावाम, --, --, 
   {{0x6d406e94,0x290444d5,0xab5c0003,0x00000000}},	//   _scla, zcla_, pożi, --, 
   {{0x7c286e95,0x7bc40006,0x926813d6,0x7ff4072d}},	//   _avdr, čiul, _урна_, رسما, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x606000db,0x00000000,0x00000000,0x00000000}},	//   _لۇلل, --, --, --, 
   {{0x680000de,0x00000000,0x00000000,0x00000000}},	//   _sēdo, --, --, --, 
   {{0x7d08037e,0x6f0802d0,0xa9a400ee,0xfeb800db}},	//   _ffds, _ifec, дипд, _فاكت_, 
   {{0x6d406e96,0xfe7001f7,0xad4000db,0xa8040064}},	//   _ucla, _حدف_, _شۉبۉ, мзол, 
   {{0x3c902633,0x29046e97,0x2a68025c,0x1dc80073}},	//   _میوز, rcla_, _ġabu_, ाकरत, 
   {{0x290435f5,0xbc3853f3,0x31ac03e3,0x6e286e98}},	//   scla_, _رسما_, _dözə_, _kveb, 
   {{0x6f08009a,0x2b4c0077,0x07a400c7,0xbad40153}},	//   _mfec, mfec_, даҟн, _пішы, 
   {{0x98b000e2,0x00000000,0x00000000,0x00000000}},	//   ūdām_, --, --, --, 
   {{0xd4641734,0x31ac03e3,0xa80401a9,0x00000000}},	//   мире_, _gözə_, _ўзил, --, 
   {{0xd8d400c8,0x18b000c7,0x32d00241,0x00000000}},	//   _קוקט_, _шәыр, _ẹyan_, --, 
   {{0xc0dc0023,0xa1880798,0x00000000,0x00000000}},	// [7f80] ንዋሕ_, обаа_, --, --, 
   {{0x236405ce,0xe4581d5b,0x680000ef,0x00000000}},	//   žoj_, _джо_, _lēdm, --, 
   {{0x6e286e99,0xdfd000ec,0x66740330,0x00000000}},	//   _aveb, پيش_, _ردکر, --, 
   {{0x9ec404fb,0x1300005b,0x3fac03d4,0x680000de}},	//   وزشه, _изюм, গক্ষ, _rēdl, 
   {{0x5e586e9a,0x7d0802d0,0x4f8401d9,0xde74007b}},	//   تجاج_, _pfds, بالہ, بداع, 
   {{0x20546e9b,0x00000000,0x00000000,0x00000000}},	//   _отбр, --, --, --, 
   {{0x6e280158,0xc0dc0092,0x00000000,0x00000000}},	//   _eveb, ንቋም_, --, --, 
   {{0xdee401d5,0x93f8011a,0x00000000,0x00000000}},	//   _жоби, חלקי, --, --, 
   {{0x6aac0427,0x10400092,0x31ac03e3,0x9e6401a9}},	//   _žafr, _ያልተመ, _sözə_, _ювад, 
   {{0xa7700023,0x00000000,0x00000000,0x00000000}},	//   _ሽማገለ_, --, --, --, 
   {{0x6e280433,0xa3cc012c,0xe9f00124,0x645803e0}},	//   _zveb, शका_, ыҧшы, çtil, 
   {{0x27c000c7,0xbd800092,0x3be801ee,0x00000000}},	//   лӡым, ሪዎችም_, _элеү_, --, 
   {{0xd90c2580,0x79800131,0x00000000,0x00000000}},	//   _پیج_, ﯩﯖﯩﺰ_, --, --, 
   {{0xdcf8033f,0xc6f80024,0xb6f800db,0x00000000}},	//   _potę, ьнях_, تىڭا_, --, 
   {{0x5fcc05d7,0xdaa000d1,0x00000000,0x00000000}},	//   ़वाल, _سەھپ, --, --, 
   {{0x03c4036b,0xd6d8022e,0x9d0800eb,0x00000000}},	//   всум, _мтп_, রণয়ন_, --, 
   {{0xdb0006ed,0x50a00131,0x325400a8,0x91280145}},	// [7f90] _emoç, ھەرل, эвар, قساق_, 
   {{0x6f080311,0x2b4c0165,0x00000000,0x00000000}},	//   _sfec, zfec_, --, --, 
   {{0x6e28003b,0x831800d1,0x33940064,0x00000000}},	//   _sveb, سقەر_, _занё, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf38c02d3,0xd6f8019b,0x00000000,0x00000000}},	//   _ዘለናዮ_, niケ_, --, --, 
   {{0xad24167e,0xf1c80131,0x733400db,0x98ac0790}},	//   رىبى, _روزى_, _تىڭا, _lafı_, 
   {{0xeb986e9c,0x9ba01473,0x98bc0024,0xf0e80150}},	//   зий_, گەنى, metė_, _ءىزى_, 
   {{0x6f0804cc,0xbbe81541,0x09d40073,0xffe4004e}},	//   _ufec, وريم_, डत्य, _аюун, 
   {{0x9ba01823,0x2b4c0489,0x00000000,0x00000000}},	//   دەنى, rfec_, --, --, 
   {{0x8d746e9d,0xe88416a8,0xd6f8105c,0xfd0001ec}},	//   _تارا, егоп, xiゲ_, _күшп, 
   {{0xa770044e,0x2a6c047e,0xdcf00356,0x8c6401a9}},	//   _ሽማግለ_, sveb_, ăgăt, _ютад, 
   {{0x7d040241,0x64580205,0x5ee000cc,0x00000000}},	//   _tìró, çtim, _ফলতে, --, 
   {{0xf6d402bf,0xfcbc0092,0x98bc00c0,0x9f94011a}},	//   віря, ታደግ_, ketė_, גדרה_, 
   {{0xf9100354,0x2bdc06e3,0x00000000,0x00000000}},	//   _вĕри_, मतवा, --, --, 
   {{0x64a46e9e,0x80d4012c,0xa3e800d4,0xf9600133}},	//   хава, _बुढे, здва_, _ئۆپێ, 
   {{0x98ac03e0,0x66e421f3,0x8c400166,0x76641572}},	//   _gafı_, _пойа, _ışla, ätyä, 
   {{0x21180597,0x67240113,0xa13400c6,0x6d540166}},	// [7fa0] كتاب_, makj, فراش, _ızan, 
   {{0x67246e9f,0xdcf801ef,0x00000000,0x00000000}},	//   lakj, _dotě, --, --, 
   {{0xd00c04fb,0x274c02d3,0x98a40114,0x20540276}},	//   ملل_, _ንማሕበ, ćiće_, этар, 
   {{0x67246ea0,0x7bc40024,0x00000000,0x00000000}},	//   nakj, čiuk, --, --, 
   {{0x63b401a9,0x00000000,0x00000000,0x00000000}},	//   miyn, --, --, --, 
   {{0xa11442a3,0x3c58084c,0xb2fc0327,0x443801ab}},	//   _سورت, дикэ_, _ཐོུང_, orr_, 
   {{0xbf440022,0xfbcc0b98,0x717000d1,0x672403b2}},	//   _аҭел, ावलम, _خۇلا, kakj, 
   {{0x9f580ffb,0x44380363,0x2a680327,0x63b46ea1}},	//   appò_, irr_, _ġabr_, niyn, 
   {{0x8fa06ea2,0x6724020b,0x44380036,0x98ac0205}},	//   _сате, dakj, hrr_, _rafı_, 
   {{0x44380083,0x98ac013d,0x63b46ea3,0x2b9001d3}},	//   krr_, _safı_, hiyn, _bács_, 
   {{0x63b46ea4,0x00000000,0x00000000,0x00000000}},	//   kiyn, --, --, --, 
   {{0xdec00092,0x00000000,0x00000000,0x00000000}},	//   _ስራን_, --, --, --, 
   {{0xd6d86ea5,0x63b401a9,0x00000000,0x00000000}},	//   ято_, diyn, --, --, 
   {{0x6abc2268,0xdb4c0345,0x00000000,0x00000000}},	//   úsfe, _ئێک_, --, --, 
   {{0x62940ba7,0x672401a4,0x63b46ea6,0x00000000}},	//   eyyo, bakj, fiyn, --, 
   {{0x7674020a,0x7bc008fb,0x00000000,0x00000000}},	//   _алиф, nnmu, --, --, 
   {{0x44380fa3,0xdcf8012c,0x7bc00158,0xf2c4009d}},	// [7fb0] arr_, _potě, inmu, төни, 
   {{0x05845a42,0x79880007,0x81e403d4,0x7bc0002f}},	//   _буюм, njdw, _পূব_, hnmu, 
   {{0x8144182f,0x62940ba7,0xa3cc033f,0x63b401a9}},	//   انمن, ayyo, शकश_, biyn, 
   {{0x2604006a,0x629400b5,0x73c401ee,0x33940153}},	//   _yôo_, byyo, _рәге, _рамё, 
   {{0x6d9c00a3,0x4aac6ea7,0x7c38017a,0xa3cc6ea8}},	//   _dèan, _जेंव, ervr, शकर_, 
   {{0x200c00f7,0x8d7410fe,0x672401a4,0x7bc0002d}},	//   ífic_, عاشا, zakj, enmu, 
   {{0x2ca8008f,0xdca001a9,0xf00401f0,0x00000000}},	//   ĝado_, иаши, _рӯзи, --, 
   {{0x6f646ea9,0x2ca800df,0xad4000db,0x2b9000e5}},	//   _جهرم, ŝado_, _چۉشۉ, _rács_, 
   {{0x6ae4036b,0x7c38017a,0xc3340a7c,0x2fdc0142}},	//   ъжиз, arvr, אופ_, mlwg_, 
   {{0x645805d1,0x7bc06eaa,0x44386eab,0x2fdc4e18}},	//   çtik, anmu, yrr_, llwg_, 
   {{0xe7386eac,0x67246ead,0x3b8401c0,0x02d80037}},	//   мен_, takj, тлөг, _भुनभ, 
   {{0x6f0c03f0,0xab5c012d,0x9f4c00d7,0x63b4022e}},	//   ñach, rożs, _šnúr_, xiyn, 
   {{0x67246eae,0x7c2405be,0xa4f800dc,0x166000a7}},	//   rakj, ćire, ंश्च_, авям, 
   {{0x6b880209,0x26040120,0x63b40113,0x6aa801c7}},	//   ljeg, _vôo_, wiyn, mzef, 
   {{0x44380dd4,0x69c06eaf,0x63b46eb0,0x672401f5}},	//   urr_, mnle, tiyn, pakj, 
   {{0x6b886eb1,0x2fdc01d4,0xd4640120,0xa2e407a5}},	//   njeg, jlwg_, њите_, вобд, 
   {{0x69c00072,0xe1f807d6,0x6aa86eb2,0x63b46eb3}},	// [7fc0] onle, дга_, nzef, riyn, 
   {{0x69c00645,0xd5ac0597,0x63b40cfd,0x6b88026c}},	//   nnle, _وفي_, siyn, hjeg, 
   {{0x69c06eb4,0x64a4035b,0x657c00c6,0x6b886eb5}},	//   inle, _рана, _inph, kjeg, 
   {{0xd00c0722,0x69c06eb6,0x6b8804ba,0x6aa801c7}},	//   زله_, hnle, jjeg, kzef, 
   {{0xc7b40134,0xdde86eb7,0x644c6eb8,0x69c00083}},	//   _mmɑ_, ورته_, ltbi, knle, 
   {{0x69c001f5,0x00000000,0x00000000,0x00000000}},	//   jnle, --, --, --, 
   {{0x644c6eb9,0x6aa80ea0,0x5f046eba,0x7c3801f5}},	//   ntbi, ezef, _азба, urvr, 
   {{0x6b886ebb,0x69c0058a,0x6aa801c7,0x644c002f}},	//   gjeg, enle, fzef, itbi, 
   {{0x7c380334,0xdde001e0,0x69c06ebc,0x00000000}},	//   srvr, _кәкү, fnle, --, 
   {{0x49706ebd,0x644c3fc6,0x7c2401fa,0x69c06ebe}},	//   альс, ktbi, ćirb, gnle, 
   {{0x6b881727,0x7c38074d,0xa3e00b26,0xcb641547}},	//   bjeg, qrvr, धता_, رمیه_, 
   {{0x69c06ebf,0x644c0112,0x657c6ec0,0x6b880010}},	//   anle, dtbi, _anph, cjeg, 
   {{0xfd580943,0x6f0c25e6,0x644c0208,0xc9d00066}},	//   _siaṱ, ñaci, etbi, طزیب, 
   {{0x644c002f,0x6ed80037,0x00000000,0x00000000}},	//   ftbi, _फुफु, --, --, 
   {{0x57a41c3e,0x644c00b5,0x00000000,0x00000000}},	//   _ашпа, gtbi, --, --, 
   {{0xdcf80327,0x6e2c05be,0x98bc00b0,0x80b80490}},	//   _antċ, šabi, hetī_, ्पने, 
   {{0xb2746ec1,0x71786ec2,0x00000000,0x00000000}},	// [7fd0] ылаш, нбар_, --, --, 
   {{0x764c0309,0x776c0e14,0x427400ee,0x45d4030d}},	//   _iqay, _haax, шгус, _воьс, 
   {{0xdcf800fd,0x6b88349b,0x6aa86ec3,0x680000e2}},	//   _omtı, yjeg, zzef, _pēdi, 
   {{0x776c0694,0x733400db,0x387801f4,0x00000000}},	//   _jaax, _حىحا, ärry_, --, 
   {{0x69c06ec4,0x776c0067,0x6b886ec5,0x657c0076}},	//   ynle, _maax, vjeg, _ynph, 
   {{0x776c6ec6,0x3328292a,0x3208447b,0xfe7001b9}},	//   _laax, laax_, mqay_, غدن_, 
   {{0x65a00109,0x6b886ec7,0x69c0022c,0x32086ec8}},	//   _jôha, tjeg, vnle, lqay_, 
   {{0x160006ab,0x69c00072,0x776c6ec9,0x0fe000fd}},	//   लदार_, wnle, _naax, _төзү, 
   {{0x6b886eca,0x764c022e,0x3208127b,0xaa440014}},	//   rjeg, _nqay, nqay_, ھنگى, 
   {{0x6b886ecb,0xa9a40aaf,0x6aa86ecc,0x69c004e6}},	//   sjeg, امدى, rzef, unle, 
   {{0x68441248,0x6b886ecd,0x776c6ece,0x6aa800dd}},	//   ынна, pjeg, _baax, szef, 
   {{0x776c1bce,0x64a46ecf,0x320802d0,0x00000000}},	//   _caax, қаба, kqay_, --, 
   {{0xfbd00014,0xba740f3e,0x75246ed0,0x776c6ed1}},	//   _بتل_, _پانت, _behz, _daax, 
   {{0x26dc0aed,0x644c5794,0x3208127b,0x00000000}},	//   āto_, ttbi, dqay_, --, 
   {{0x776c0449,0x657c0208,0x33280009,0x63786ed2}},	//   _faax, _vnph, faax_, нсар_, 
   {{0x3878019b,0x644c6ed3,0x776c4091,0x00000000}},	//   ærre_, rtbi, _gaax, --, 
   {{0x644c6ed4,0x61380a31,0xa508011c,0x00000000}},	// [7fe0] stbi, ечер_, _пепа_, --, 
   {{0x657c0076,0x644c1141,0x7524002f,0x00000000}},	//   _unph, ptbi, _gehz, --, 
   {{0x776c102c,0x33285284,0x6800003a,0x23280108}},	//   _yaax, baax_, _fœde, _пони_, 
   {{0x307400f7,0x776c6ed5,0xdb0c03b2,0x1ec800c7}},	//   шуус, _xaax, _ájøv, нлеи_, 
   {{0x29d8068c,0xfd641e4a,0x320803ac,0xe04412b9}},	//   nèas_, индү, cqay_, _әнби, 
   {{0xfc1400ee,0x00000000,0x00000000,0x00000000}},	//   амкэ, --, --, --, 
   {{0xa0a416c3,0x0704012d,0x2fd400db,0x00000000}},	//   _савд, रखाव_, دتەح, --, 
   {{0x8fa03548,0x0ba000fa,0xdd900451,0x1ea800ec}},	//   _ласе, йшым, _ڏور_, _ٻاري_, 
   {{0x776c01d9,0x00000000,0x00000000,0x00000000}},	//   _raax, --, --, --, 
   {{0x776c6ed6,0x99646ed7,0xdb0004e6,0x6abc002d}},	//   _saax, утил, _kloë, úsfa, 
   {{0xad9c012d,0x3208035a,0xe8d80051,0x39800023}},	//   _kuźn, zqay_, _đợ_, _ንወለዲ_, 
   {{0xb8ec1533,0x964405f5,0x776c6ed8,0x32080857}},	//   _रख_, лэгд, _qaax, yqay_, 
   {{0x12bc015b,0x764c022e,0x1a94027d,0xd7600133}},	//   _আর্দ, _qqay, _حجاج, لۆژی, 
   {{0x776c6ed9,0xcad40375,0xad9c012d,0x3328058a}},	//   _waax, _עוגת_, _luźn, waax_, 
   {{0xd3786eda,0x776c6271,0x33280014,0x4d78008f}},	//   нча_, _taax, taax_, ערלע, 
   {{0xb7d85cb5,0x2848008f,0x461401d9,0x32080857}},	//   _جوبا_, _סעפּ, _گوٝر, tqay_, 
   {{0x29d80ba1,0x764c058a,0xd1385622,0x63b8020c}},	// [7ff0] cèas_, _uqay, ехе_, ètna, 
   {{0xdcf80100,0xdb000036,0x32080c8c,0x46140050}},	//   _antč, _bloë, rqay_, _دوٝر, 
   {{0x32086c99,0xc3300014,0xa0b401f0,0x00000000}},	//   sqay_, غٕے_, аҳру_, --, 
   {{0xcf241367,0x21e400e4,0x00000000,0x00000000}},	//   اراي, rôha_, --, --, 
   {{0xad244717,0x32086edb,0xd13800d8,0x00000000}},	//   لىشى, qqay_, _пхв_, --, 
   {{0xed586edc,0x51846edd,0xdcf802bd,0x00000000}},	//   ток_, _сума, _entč, --, 
   {{0x7094059f,0xc0c86c00,0x1db403ce,0x00000000}},	//   _тавф, _буте_, _अगरत, --, 
   {{0x2c30001f,0x00000000,0x00000000,0x00000000}},	//   _አይገኝ, --, --, --, 
   {{0x7c2401fa,0x386000f3,0x00000000,0x00000000}},	//   ćira, _ćira_, --, --, 
   {{0x8d740137,0xca68022e,0x00000000,0x00000000}},	//   _حارا, _degа, --, --, 
   {{0xdd7804ac,0x00000000,0x00000000,0x00000000}},	//   _שטעל, --, --, --, 
   {{0x6e2c01fa,0x00000000,0x00000000,0x00000000}},	//   šabu, --, --, --, 
   {{0xa96800c7,0x7bc40024,0x00000000,0x00000000}},	//   _аила_, čiut, --, --, 
   {{0xdb006ede,0x64a405f5,0x29d8067c,0xd9406edf}},	//   _aloè, аага, rèas_, _деши, 
   {{0x23286ee0,0x00000000,0x00000000,0x00000000}},	//   кови_, --, --, --, 
   {{0x92043d4d,0x29d8180f,0x00000000,0x00000000}},	//   _वंशज_, pèas_, --, --, 
  
   {{0xe0e00154,0xe1240022,0x00000000,0x00000000}},	// [8000] _বলেন, имаи, --, --, 
   {{0x66140022,0x00000000,0x00000000,0x00000000}},	//   _ityk, --, --, --, 
   {{0x5f28005b,0x11d4007b,0x00000000,0x00000000}},	//   воем_, جولة_, --, --, 
   {{0x645c6ee1,0x7c3c0b1a,0x00000000,0x00000000}},	//   _ippi, _årri, --, --, 
   {{0x3ea00491,0x63a40205,0x6ed80037,0x00000000}},	//   áit_, _ilkn, _फुदु, --, 
   {{0xdcb0104b,0x3ea0003d,0x225000a2,0x00000000}},	//   يىش_, ġit_, mtyk_, --, 
   {{0x3ea00316,0x98bc00e4,0x225000a2,0x00000000}},	//   šit_, petĩ_, ltyk_, --, 
   {{0x66140022,0x2018023a,0xdb586ee2,0x7c38031c}},	//   _otyk, mppi_, тюк_, _ċarġ, 
   {{0x22506ee3,0xe8d80016,0x9d446ee4,0xcfb000fe}},	//   ntyk_, _đỡ_, _везд, টকখন, 
   {{0x645c6ee5,0xb984448f,0x98bc00e2,0x2018005b}},	//   _oppi, стиқ, egtā_, oppi_, 
   {{0x661400c7,0xd2e000bc,0x00000000,0x00000000}},	//   _atyk, _खर्ब_, --, --, 
   {{0x22506ee6,0xda6402dd,0xa6b00eac,0x7bc40024}},	//   ktyk_, _ناتي, _টুইট, čius, 
   {{0x645c6ee7,0x5504011c,0x00000000,0x00000000}},	//   _appi, ичва, --, --, 
   {{0x6d9c020c,0x33746ee8,0x00000000,0x00000000}},	//   _rèak, әгар, --, --, 
   {{0xf3140323,0x89340302,0x63a4020b,0x116407d6}},	//   йдвэ, _כרגע_, _blkn, یلری_, 
   {{0xf6986ee9,0x61ec035a,0x645c0332,0x934000f7}},	//   _منبع_, _ahbl, _dppi, تىرۇ, 
   {{0x645c6eea,0x2f0c08de,0x2018020c,0x95e001ec}},	// [8010] _eppi, _lógó_, eppi_, _ويعۇ, 
   {{0x7bdc01e1,0x00000000,0x00000000,0x00000000}},	//   _íruf, --, --, --, 
   {{0x6734032e,0x00000000,0x00000000,0x00000000}},	//   _áfjö, --, --, --, 
   {{0xf36401d5,0xd34430cd,0xa3ac000d,0x00000000}},	//   _ائدی, _خیره_, _कतय_, --, 
   {{0xa2e8016c,0x20186eeb,0x00000000,0x00000000}},	//   _бурҷ_, appi_, --, --, 
   {{0xf19400c7,0x10143267,0xdcf80171,0x00000000}},	//   _уигь, _نبرد, _notē, --, 
   {{0xdca06eec,0x7c6400d1,0xa9686eed,0xf07400e5}},	//   защи, قايل, қина_, _دیاں_, 
   {{0xafc438eb,0x61ec036e,0x31700419,0x00000000}},	//   _ايرى, _zhbl, _hazz_, --, 
   {{0x31700327,0xe6b4000d,0x89a40139,0x9fa401ee}},	//   _kazz_, _उधेड़, ийиң_, _уырҙ, 
   {{0xdcac004b,0xa9680640,0x31706eee,0xddc00118}},	//   _ګډه_, ћина_, _jazz_, ktoř, 
   {{0x66146eef,0x3170031c,0x4a7002dd,0x2f0c02d2}},	//   _styk, _mazz_, сықт, _gógó_, 
   {{0x387801a8,0xa7a80eba,0x22500210,0x7b741063}},	//   ærra_, укма_, ytyk_, _وطنا, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x201802f6,0x31706ef0,0x00000000,0x00000000}},	//   yppi_, _nazz_, --, --, 
   {{0x66146ef1,0xd4a000d1,0x6ed80037,0x23341bbc}},	//   _wtyk, пирй, _फुसु, йхар, 
   {{0x673402d0,0x00000000,0x00000000,0x00000000}},	//   _udyj, --, --, --, 
   {{0x28a40490,0x20c40032,0xb6780092,0x00000000}},	// [8020] खनवि, әйем, ክክለኛ_, --, 
   {{0x3170011c,0xda080ce0,0x9f400cad,0x00000000}},	//   _cazz_, _हंसत_, _òkú_, --, 
   {{0x645c6ef2,0x25b80165,0x22506ef3,0x9f040472}},	//   _uppi, _impl_, styk_, مواو, 
   {{0xfdb01533,0x1e846ef4,0x2018005b,0x00000000}},	//   जफ्फ, йлем, rppi_, --, 
   {{0x80d40073,0x00000000,0x00000000,0x00000000}},	//   _बँके, --, --, --, 
   {{0xdcf83da0,0xb3240327,0xdb0006af,0x00000000}},	//   _antā, _འབོང_, _cloî, --, 
   {{0x38601225,0x7c240fcf,0x20180784,0xdcf80171}},	//   _ćiro_, ćiro, qppi_, _rotē, 
   {{0x20086ef5,0x0ea43c1a,0x6e2c031c,0x00000000}},	//   _iubi_, ркәй_, ġabr, --, 
   {{0x3f8403f9,0xbb4c037e,0x5398008d,0x20080009}},	//   _inmu_, _comが_, טיקו, _hubi_, 
   {{0xfcc4190b,0x00000000,0x00000000,0x00000000}},	//   _мәйм, --, --, --, 
   {{0xea9401e2,0x00000000,0x00000000,0x00000000}},	//   مایښ, --, --, --, 
   {{0x20086ef6,0x9f5c145e,0x2128020b,0x00000000}},	//   _mubi_, _îtä_, _lebh_, --, 
   {{0x20086ef7,0x8c40054e,0x36d40212,0x9b6801ee}},	//   _lubi_, ăşen, іогр, _ашһа_, 
   {{0x7e600109,0x200800e8,0x4bc001c0,0xceb0010f}},	//   _mpmp, _oubi_, _мөөг, ליר_, 
   {{0xe8d807ae,0x20086ef8,0x00000000,0x00000000}},	//   _đủ_, _nubi_, --, --, 
   {{0x25b8031c,0xb4e821bd,0x317003b9,0x34940454}},	//   _empl_, _बरी_, _sazz_, баҳр, 
   {{0x75d4046f,0xddc06ef9,0x43940108,0xd5b86efa}},	// [8030] _ويبا, dvož, чатс, _бсн_, 
   {{0x20086efb,0x3f840198,0x857401af,0x910428e5}},	//   _bubi_, _anmu_, _ельх, счад, 
   {{0x20086efc,0xc1e800f5,0x3cf4012d,0x00000000}},	//   _cubi_, сьте_, ेखों_, --, 
   {{0x20086efd,0xc8d8010f,0x92e400cc,0xcfa85868}},	//   _dubi_, נקאט, _পলী_, دائم_, 
   {{0x317052d5,0xc1e401d3,0xb4e8012c,0x7ff4007b}},	//   _tazz_, _کےلی, _बरु_, أسلا, 
   {{0x321803d1,0x3f840427,0xac386ed2,0x3d1400bc}},	//   _itsy_, _enmu_, ачих_, नुले_, 
   {{0x20080b91,0x6ac02802,0x04fc0183,0x859c008f}},	//   _gubi_, शप्र, ্ৰীৰ_, רשוו, 
   {{0x0c840efb,0xeb986efe,0xdb0000db,0xea580063}},	//   _қызм, рии_, _cloï, арој_, 
   {{0xada4052f,0xbfa864e1,0x6d34013e,0x7bc40153}},	//   _һаҡл, _утре_, _меаф, čiup, 
   {{0xfeb86eff,0xdb000129,0x21280135,0x80d00764}},	//   _طاقت_, _eloï, _xebh_, _दशमे, 
   {{0x20080009,0x395c0208,0x04f400cc,0xada401af}},	//   _xubi_, _dbvs_, _অভ্ৰ_, _лаҡл, 
   {{0xaa586f00,0x9984068f,0x8b644c84,0xdcf800ef}},	//   _виду_, _ktoś_, _دائم, _untā, 
   {{0xb6c401e0,0x00000000,0x00000000,0x00000000}},	//   зияһ, --, --, --, 
   {{0xb324031c,0xd5e40014,0x00000000,0x00000000}},	//   _འབུང_, ٲٹِن_, --, --, 
   {{0x32180170,0x2fcc00d5,0xe88402bf,0x5900031c}},	//   _atsy_, _ojeg_, _єгип, _ཛུགས_, 
   {{0x20086f01,0x2fcc6f02,0x21280327,0x630404f2}},	//   _rubi_, _njeg_, _sebh_, زوئل, 
   {{0x20086f03,0x25b80e4e,0xa1840032,0xe29800f0}},	// [8040] _subi_, _tmpl_, ҙыҡл, јаз_, 
   {{0x2fcc54ba,0xd24c6f04,0x2008000d,0x80b86611}},	//   _ajeg_, ئنل_, _pubi_, ्पले, 
   {{0x32180851,0x2eec00a2,0x20080009,0x38c40022}},	//   _etsy_, _azef_, _qubi_, mérô_, 
   {{0x5ea46aed,0x200807a8,0x2d846f05,0xa3ac37e3}},	//   يمال, _vubi_, _anle_, _कति_, 
   {{0x4f040032,0x2fcc0240,0xddc00153,0x00000000}},	//   әнән_, _djeg_, rvož, --, 
   {{0x20086f06,0x4a24031c,0x21280100,0x00000000}},	//   _tubi_, _རྦེལ_, _uebh_, --, 
   {{0xa3ac0cf1,0x9b68004e,0x00000000,0x00000000}},	//   _कता_, ашпа_, --, --, 
   {{0x3f840198,0xd0040276,0x5b2402d5,0x98bc0024}},	//   _unmu_, _фете_, цька, ngtą_, 
   {{0x91bc1c82,0x3dc00036,0x38c400e4,0x98ac0205}},	//   ্তৰ্, éiws_, kérô_, _ınız_, 
   {{0xad2404fb,0x27f0058a,0x00000000,0x00000000}},	//   _فرمو, _ahyn_, --, --, 
   {{0xb4e83027,0x69300633,0x00000000,0x00000000}},	//   _बरे_, رکور, --, --, 
   {{0xda78084c,0x27f06c13,0xef180210,0x00000000}},	//   _вяк_, _chyn_, _boży_, --, 
   {{0xba1810e0,0xe8d8004d,0xa3ac01ad,0x00000000}},	//   _ايتا_, _đụ_, कसन_, --, 
   {{0x7bc06f07,0xd90c5a9d,0x546c0092,0x00000000}},	//   limu, _جید_, _ትልልቅ_, --, 
   {{0xdb0000e4,0x92e400fe,0x15b80209,0x00000000}},	//   _imoñ, _পলে_, гыңы_, --, 
   {{0x7bc06f08,0x27f000ad,0x36d401c6,0x9f4001e1}},	//   nimu, _ghyn_, _нойр, _ókè_, 
   {{0x79980161,0x00000000,0x00000000,0x00000000}},	// [8050] _kovw, --, --, --, 
   {{0x9f4407e4,0x7bc06f09,0xddc0068f,0x55600220}},	//   mmoù_, himu, rtoś, _تۇسك, 
   {{0x7bc01bb7,0x3dd004c5,0x9f440dd4,0xff1802e3}},	//   kimu, িতাল, lmoù_, _ịtụn, 
   {{0x5c780201,0x7bc06f0a,0x321805da,0x86083c46}},	//   _በርካታ_, jimu, _ttsy_, _دقیق_, 
   {{0x7bc06f0b,0xab5c0034,0x7c280857,0xdb00035b}},	//   dimu, niże, _awdr, _omoñ, 
   {{0xcdd8026a,0xdb0000ae,0xa24400f2,0x00000000}},	//   шње_, _cloí, _ریمل_, --, 
   {{0xdd8c0597,0xeb986f0c,0x7bc00393,0x63a001f4}},	//   اوى_, йик_, fimu, öong, 
   {{0xdb006f0d,0x7a2001f2,0xe0d0010f,0x00000000}},	//   _eloí, _ịtac, _נײן_, --, 
   {{0x27f0017a,0x7c2803ac,0x00000000,0x00000000}},	//   _rhyn_, _ewdr, --, --, 
   {{0x6e284b26,0xa2c00db3,0x0dc80dab,0x27f00208}},	//   _iweb, _रेफ्, _туби_, _shyn_, 
   {{0x7bc06f0e,0x6e286f0f,0x79980455,0xddc06f10}},	//   bimu, _hweb, _dovw, ntoŝ, 
   {{0x6e284084,0x7bc00483,0xdb0000c7,0xb6080419}},	//   _kweb, cimu, _emoñ, kašľ, 
   {{0xfaa8038b,0x49b00075,0x9f440165,0x386c0142}},	//   _وهمي_, _жәну, gmoù_, awdr_, 
   {{0x6e2843c4,0x6b9847e4,0x80d46f11,0xe5a46f12}},	//   _mweb, _howg, _बुझे, чиги, 
   {{0x69c06f13,0x2a6c6f14,0x6e286f15,0x6b98010e}},	//   mile, lweb_, _lweb, _kowg, 
   {{0xfd4c02e3,0x6e286f16,0x00000000,0x00000000}},	//   _belụ, _oweb, --, --, 
   {{0x69c00fa3,0x47f405f5,0x2a6c6f17,0x6e280521}},	// [8060] oile, _нүүр, nweb_, _nweb, 
   {{0x7bc001f0,0x69c06f18,0x6f0803ac,0x6b986f19}},	//   zimu, nile, _agec, _lowg, 
   {{0x2a6c6f1a,0x638400d1,0x7bc06f1b,0xab5c012d}},	//   hweb_, _егна, yimu, soży, 
   {{0x7bc06f1c,0x69c06f1d,0x6e282252,0xab5c033f}},	//   ximu, hile, _bweb, poży, 
   {{0x69c06f1e,0x7bc06f1f,0x6e280175,0x394c05ac}},	//   kile, vimu, _cweb, ygds_, 
   {{0x69c06f20,0x6e28014b,0x9f44017a,0x63ac00e2}},	//   jile, _dweb, oloë_, šinē, 
   {{0x69c06f21,0x6e286f22,0x11840014,0x2a6c00d7}},	//   dile, _eweb, _ژھۅٹ_, eweb_, 
   {{0x6b986f23,0x6e280175,0x7998047e,0x7bc06f24}},	//   _cowg, _fweb, _sovw, uimu, 
   {{0x6e286f25,0x9d442401,0xb4e80574,0x69c02f75}},	//   _gweb, _неад, _बर्_, file, 
   {{0x69c06f26,0x7bc06f27,0x00000000,0x00000000}},	//   gile, simu, --, --, 
   {{0x7bc06f28,0x68ec0115,0x8c140592,0x2a6c013a}},	//   pimu, _ŝadr, _فيلر_, aweb_, 
   {{0x2a6c0428,0x79986f29,0x7bc06f2a,0x6b980432}},	//   bweb_, _wovw, qimu, _gowg, 
   {{0x2a6c1ef9,0xcb0400c6,0x6e28004b,0x8ae002bf}},	//   cweb_, _عيون_, _xweb, _пішл, 
   {{0x69c06f2b,0xf9c41c67,0xceb002e4,0xd5ac01ed}},	//   cile, _تحصی, גיש_, اہد_, 
   {{0x236400c8,0x6b980009,0x01c40154,0x9f440165}},	//   ĵojn_, _yowg, ্তাদ, smoù_, 
   {{0xb9dc0020,0xdecc044e,0x43946584,0xab5c031c}},	//   _ቢሮ_, እልን_, насс, piże, 
   {{0x6448168c,0xc73c0375,0xf8b001d3,0x6e280092}},	// [8070] _åfin, _התחת, _سکھ_, ስቴንሽ, 
   {{0x6e28006f,0x67d00318,0x6abc002d,0x2b4c0010}},	//   _rweb, māja, úsfi, zgec_, 
   {{0x6e28030a,0x80140212,0x2a6c0208,0x00000000}},	//   _sweb, ефіц, zweb_, --, 
   {{0x69c02e11,0x6e2801ab,0xddc001e4,0x00000000}},	//   zile, _pweb, rtoŝ, --, 
   {{0x67d01a14,0xadd80137,0xddc00115,0x00000000}},	//   nāja, омду_, stoŝ, --, 
   {{0x6b9800ee,0x69c0208d,0x7ed46f2c,0x00000000}},	//   _sowg, xile, رزنا, --, 
   {{0xbf880131,0xefe40023,0x2a6c031c,0x00000000}},	//   تئەل_, ምሮይ_, wweb_, --, 
   {{0x2a6c6f2d,0x6e286f2e,0x09b40574,0xa2c04da4}},	//   tweb_, _tweb, ेच्य, _रेड्, 
   {{0x6e28014b,0x2b4c03e0,0x00000000,0x00000000}},	//   _uweb, rgec_, --, --, 
   {{0x67d01c52,0xfe740116,0x6b980009,0x69c00393}},	//   dāja, _чүш_, _wowg, uile, 
   {{0x69c06f2f,0xe3c04ba9,0xef180327,0x00000000}},	//   rile, lmış_, _anżi_, --, 
   {{0x2a6c00d7,0xfe7001d3,0x207800df,0x00000000}},	//   pweb_, _جدہ_, קארא, --, 
   {{0xe3c06f30,0x2a6c0354,0xc8e403e6,0x0ae80220}},	//   nmış_, qweb_, توگۆ_, _اراي_, 
   {{0x69c06f31,0xfaf400fb,0x3ce003e0,0x00000000}},	//   qile, _яҫы_, şive_, --, 
   {{0x26dc0210,0x00000000,0x00000000,0x00000000}},	//   łto_, --, --, --, 
   {{0xe3c003ee,0x9f440ea0,0x67d000e2,0x86e80150}},	//   kmış_, rloë_, bāja, _ﺟو_, 
   {{0xd6c001ed,0x7c24107d,0xa2042a30,0x00000000}},	// [8080] _لمٹی, ćiri, дпад, --, 
   {{0xa0a46f32,0xe16400e3,0xe3c006be,0xd918010f}},	//   мазд, بدري, dmış_, ַונל, 
   {{0xd12c6f33,0x20545eb4,0x00000000,0x00000000}},	//   شمن_, ьтар, --, --, 
   {{0xdfd00f2b,0x85240345,0x00000000,0x00000000}},	//   خيص_, _توگۆ, --, --, 
   {{0xb35401b9,0x44380175,0x00000000,0x00000000}},	//   _سیلا_, lsr_, --, --, 
   {{0x705003e6,0xe0446f34,0x3a206f35,0xa02400a2}},	//   _ڕۆما, _онги, _çipi_, gröý, 
   {{0x91006f36,0x9cfc0154,0x00000000,0x00000000}},	//   _апре, ুর্ন_, --, --, 
   {{0x3a746f37,0x0d8001d2,0x67f400d0,0x443800b5}},	//   елир, елән, nájd, isr_, 
   {{0x3db80156,0x00000000,0x00000000,0x00000000}},	//   ྐྲུན, --, --, --, 
   {{0x67d0005f,0x443805b1,0x9964547c,0x4d600395}},	//   vāja, ksr_, фтил, _икув, 
   {{0xa3ac1b57,0xdcf800e2,0xed3400ec,0xaa6401ec}},	//   कसा_, _motī, _سونھ, _үтік, 
   {{0x67d000da,0x7dd800d2,0x8b200024,0x00000000}},	//   tāja, búsû, _адце, --, 
   {{0x44380af9,0x7c380af9,0x60180055,0xd6d802e8}},	//   esr_, lsvr, _jįmb, юто_, 
   {{0x67d00882,0xde3c0023,0xdcf800e2,0xdee82440}},	//   rāja, _ኣይደለ, _notī, ህልና_, 
   {{0xe3c06f38,0x7c38057b,0x644800d4,0x335400f7}},	//   zmış_, nsvr, _åfil, нүнө_, 
   {{0x67d000da,0xe3c0083c,0x7c380549,0x00000000}},	//   pāja, ymış_, isvr, --, 
   {{0xe3c00213,0xab5c6f39,0xb6c4004e,0x81d800eb}},	// [8090] xmış_, niża, _чөнд, াতন_, 
   {{0x7c3801f5,0x00000000,0x00000000,0x00000000}},	//   ksvr, --, --, --, 
   {{0x7c380d27,0xdcf80171,0x1f380023,0x00000000}},	//   jsvr, _dotī, _ከምዝዝ, --, 
   {{0x75346f3a,0xe3c01d89,0x7ff401d5,0x7c380d47}},	//   lazz, tmış_, نسنا, dsvr, 
   {{0x59dc1092,0x85b86f3b,0x91700022,0x6d540205}},	//   नकार, _رایس_, _иҳац, _özak, 
   {{0x75346f3c,0xe3c00bcc,0x50640046,0x7c380af9}},	//   nazz, rmış_, _отба, fsvr, 
   {{0x7c38017a,0xc0c80114,0x1d04004e,0x00000000}},	//   gsvr, _жуте_, неши_, --, 
   {{0xe3c02fbe,0x75346f3d,0x00000000,0x00000000}},	//   pmış_, hazz, --, --, 
   {{0x75341f21,0x67f4012c,0x7c38017a,0xeab0007b}},	//   kazz, náje, asvr, طعة_, 
   {{0x75340003,0x3ea001c7,0x9f400248,0x00000000}},	//   jazz, äite_, _òkò_, --, 
   {{0x75346f3e,0x39580013,0xfc300411,0x3c906f3f}},	//   dazz, òrsa_, _نحن_, _نیوز, 
   {{0x24840030,0xc6d401c0,0xbb84007b,0xe0d000df}},	//   _čom_, всгө, _للمي, רײט_, 
   {{0xe9f8005e,0x23ac008c,0x75345906,0xcc840133}},	//   _енді_, _nýja_, fazz, _رۆکه_, 
   {{0x75346f40,0x680000e2,0x1a98010f,0xe2980124}},	//   gazz, _jēdz, _מינע, ҟаз_, 
   {{0x2328013e,0x680000de,0x958000c7,0x00000000}},	//   зоби_, _mēdz, ылре, --, 
   {{0xe3540323,0xdad00131,0x44380798,0x67d000e2}},	//   этгэ, _جەۋھ, rsr_, mājo, 
   {{0x4438008e,0x75346f41,0x92280327,0xdcf800de}},	// [80a0] ssr_, bazz, _སྦྱག_, _potī, 
   {{0x753402e8,0x00000000,0x00000000,0x00000000}},	//   cazz, --, --, --, 
   {{0x67d0005f,0x60086f42,0x6458004e,0x10a001b9}},	//   nājo, чнем_, àtid, лифн, 
   {{0x387809f3,0xa3b86f43,0x5f740372,0x656c6f44}},	//   ærri_, _راجر_, عاار, lebh, 
   {{0x420400c7,0x020400c7,0x9f400241,0x00000000}},	//   _аҧаг, _аҷан, _ókí_, --, 
   {{0x8e443ee0,0x7c380373,0x8e800b24,0x00000000}},	//   رلىك_, tsvr, الوه, --, 
   {{0x644c6f45,0x61fc002f,0x00000000,0x00000000}},	//   nubi, mmpl, --, --, 
   {{0x656c6f46,0x67d0005f,0x7c38057b,0xdee401d5}},	//   hebh, dājo, rsvr, _зоби, 
   {{0x644c6f47,0x656c6f48,0xdde000d1,0x75341418}},	//   hubi, kebh, _йәкү, yazz, 
   {{0x3914020a,0x61fc007f,0xb98401b9,0xab5c025c}},	//   ъмор, nmpl, ттиқ, riża, 
   {{0x75346f49,0x61fc4725,0xa2c01f13,0x58843a47}},	//   vazz, impl, _रेस्, хыпа, 
   {{0x644c6f4a,0x2ca03626,0x753413cd,0x00000000}},	//   dubi, ähde_, wazz, --, 
   {{0x7534038f,0x656c6210,0xcb980a1e,0x38600841}},	//   tazz, febh, _מסאט, _ćiru_, 
   {{0xb89400c6,0x656c6f4b,0x644c6f4c,0x67d000de}},	//   _للتع, gebh, fubi, bājo, 
   {{0x75341f21,0x0ea40073,0xc91408c3,0x67d000ef}},	//   razz, _कॅनड, _אחות_, cājo, 
   {{0x61fc44b6,0x75346f4d,0xdbc80037,0x00000000}},	//   empl, sazz, põõs, --, 
   {{0x75346f4e,0x717815ed,0x36d416c3,0x656c6f4f}},	// [80b0] pazz, мбар_, _шоир, bebh, 
   {{0x765c002f,0x67f40022,0x00000000,0x00000000}},	//   mtsy, ráje, --, --, 
   {{0x644c6f50,0xf4846f51,0x4fc4457e,0xf3f8009d}},	//   cubi, _شادی, нсда, _онош_, 
   {{0xb4ac6495,0x67f4012c,0xa3ac0037,0x43940153}},	//   कनी_, páje, _कतए_, _баюс, 
   {{0x1ee803e6,0x33286f52,0x00000000,0x00000000}},	//   وومی_, mbax_, --, --, 
   {{0x765c002f,0x00000000,0x00000000,0x00000000}},	//   itsy, --, --, --, 
   {{0xeb986f53,0xabd42424,0xdf3400d1,0x7ee4035b}},	//   дий_, кциј, ركۈت_, кцәе, 
   {{0x332801d9,0x656c6f54,0x765c1f53,0x67d000e2}},	//   nbax_, zebh, ktsy, vājo, 
   {{0xc334010f,0x67f40118,0x00000000,0x00000000}},	//   נוץ_, hájc, --, --, 
   {{0x765c00b5,0x644c598e,0xecc401ee,0x00000000}},	//   dtsy, yubi, _ишеү, --, 
   {{0x4a700046,0x644c6f55,0x3ce8000d,0x68440395}},	//   тықт, xubi, _चुपे_, ънна, 
   {{0x656c6f56,0x644c6f57,0x765c08fb,0x7aec0419}},	//   webh, vubi, ftsy, _žitň, 
   {{0xfcbc0020,0x61fc6f58,0x644c5b12,0xd5b4004d}},	//   ሳደግ_, ympl, wubi, ắng_, 
   {{0x644c6f59,0x27e005ac,0x64480fac,0xa2c000bc}},	//   tubi, sokn_, _åfik, _रेष्, 
   {{0x6d400173,0xdcf80022,0x765c0582,0x644c0083}},	//   _mdla, _potĩ, atsy, uubi, 
   {{0x644c0134,0xa68443c8,0x656c2747,0x93406f5a}},	//   rubi, _алид, sebh, инсе, 
   {{0x644c555f,0x6d4004b9,0x3ce80034,0x00000000}},	// [80c0] subi, _odla, _चुने_, --, 
   {{0x644c6f5b,0x6d4007a9,0x601800a2,0xab5c0327}},	//   pubi, _ndla, _aįma, kiżo, 
   {{0x61fc0857,0x644c0472,0x33280009,0xc4540133}},	//   rmpl, qubi, bbax_, _حێزب, 
   {{0x6d406f5c,0x9f0400f1,0x61fc03ac,0x00000000}},	//   _adla, نواو, smpl, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x62940218,0x6284025c,0x6d400139,0x61440354}},	//   mxyo, _irko, _cdla, _шега, 
   {{0xfc646f5d,0x00000000,0x00000000,0x00000000}},	//   اختی, --, --, --, 
   {{0x62846f5e,0x8fa06f5f,0x63b403a2,0x6d406f60}},	//   _krko, _касе, nhyn, _edla, 
   {{0xcb641614,0x62840115,0xdcf8010f,0x1a7402dd}},	//   тање_, _jrko, _matĉ, тұлы_, 
   {{0x628438bb,0x0d806f61,0xdca40124,0x00000000}},	//   _mrko, _клун, _иази, --, 
   {{0x1cb813ea,0x2a9402dd,0x779c0092,0x5c54399f}},	//   _غائب_, _ەدىڭ, ገሪቱዋ_, _штаф, 
   {{0x765c1f53,0x62841c42,0x6d40022e,0x07e400d4}},	//   ttsy, _orko, _zdla, ицям, 
   {{0xa2c01098,0x62940218,0x6d400142,0xcb640114}},	//   _रेल्, jxyo, _ydla, _јаче_, 
   {{0x765c6f62,0xa3800037,0x00000000,0x00000000}},	//   rtsy, öõnn, --, --, 
   {{0xd3786f63,0xb4ac6f64,0x81d809bd,0x00000000}},	//   мча_, कने_, াতা_, --, 
   {{0x628405ce,0x77546f65,0x63b46f66,0x3a2000a2}},	//   _brko, _скиф, ghyn, _çips_, 
   {{0x70bc086b,0x63b80ea0,0x63c40432,0xd5b80150}},	// [80d0] ्प्ल, ëtna, _şunç, _жсн_, 
   {{0x64586f67,0x63b40009,0x3ce80037,0x33286f68}},	//   àtic, ahyn, _चुभे_, sbax_, 
   {{0xc1e81064,0xada41ac1,0x67f46f69,0x00000000}},	//   тьте_, ғайл, lája, --, 
   {{0x63b46f6a,0x6800003a,0x6d380241,0xab5c0135}},	//   chyn, _fœdu, _ọ́ṣ, viżo, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfd581682,0xde44004b,0x00000000,0x00000000}},	//   _khaṱ, ایلو_, --, --, 
   {{0x009400fd,0x6c840066,0x00000000,0x00000000}},	//   _кирэ, البم, --, --, 
   {{0x4ea40124,0xf00401f0,0x23c408ec,0x00000000}},	//   _ирза, _сӯзи, रोपद, --, 
   {{0x98ac007f,0xde445533,0x60c001e4,0xcca000db}},	//   _defč_, _مینو_, ĝome, _چڭعى, 
   {{0x6d406f6b,0x8d746f6c,0xaa4402dd,0xab5c025c}},	//   _udla, _جارا, _ەنشى, miżm, 
   {{0xa5d001d9,0x1ae000d1,0xab5c0003,0x00000000}},	//   किसà_, _қошм, liżm, --, 
   {{0xebd802e8,0x5ed80154,0x00000000,0x00000000}},	//   _ядеш_, _বৃটে, --, --, 
   {{0x22a0013f,0x4aa800f7,0xaa446f6d,0xab5c0003}},	//   kɔka_, _تااپ_, _селл, niżm, 
   {{0x6f0c00d0,0xab600166,0x00000000,0x00000000}},	//   ľach, _çübe, --, --, 
   {{0xdecc044e,0x63b46f6e,0x23b40092,0x6aa8427b}},	//   _እዉን_, thyn, _ለለውጥ_, lyef, 
   {{0xa6940b7f,0x62840552,0xe298036b,0xab5c031c}},	//   _број, _prko, наб_, kiżm, 
   {{0xe1f84c2c,0x63b46f6f,0x6aa86f70,0x2eec004e}},	// [80e0] ега_, rhyn, nyef, _nyef_, 
   {{0xfd5806d6,0xe694035b,0x63b400ee,0x7bdc01e4}},	//   _fhaṱ, _аиҩы, shyn, _ƭruk, 
   {{0x64a46f71,0x11d40491,0x657c455b,0x6aa8013f}},	//   _сана, دولة_, _iaph, hyef, 
   {{0xd00c1e95,0xe2986f72,0x657c6f73,0x661402d1}},	//   سله_, _зам_, _haph, _kuyk, 
   {{0x657c6f74,0x87e8025c,0x975404ae,0x62846f75}},	//   _kaph, _ལེནྡ, רינו_, _urko, 
   {{0x657c6f76,0x00000000,0x00000000,0x00000000}},	//   _japh, --, --, --, 
   {{0x213800d2,0x661401f5,0x71c4013e,0x6734035a}},	//   maph_, _luyk, _тарҷ, _oeyj, 
   {{0x657c6f77,0x58846f78,0x21386f79,0xd00400d8}},	//   _laph, ңына, laph_, _бесе_, 
   {{0x6aa8016b,0x8d900014,0x00000000,0x00000000}},	//   gyef, _گٔلت, --, --, 
   {{0x657c6f7a,0x9a84052f,0x8af41669,0x39586f7b}},	//   _naph, _ҡулл, ыныс_, ürs_, 
   {{0x67346f7c,0x00000000,0x00000000,0x00000000}},	//   _beyj, --, --, --, 
   {{0x22500113,0x6aa80083,0x78a8017a,0x00000000}},	//   kuyk_, byef, rydv, --, 
   {{0x673401a8,0xe8f40032,0x79940353,0x57a40150}},	//   _deyj, лһә_, _вилф, _ұшпа, 
   {{0x657c6f7d,0xfd5806d6,0x21380113,0xc3300131}},	//   _caph, _phaṱ, japh_, ۋەپ_, 
   {{0x657c6f7e,0xf3c40588,0x8934011a,0xab5c0327}},	//   _daph, араҟ, _גרוע_, ziżm, 
   {{0xfd5806d6,0x67f401f1,0x68f46f7f,0x657c02d0}},	//   _vhaṱ, pája, üzde, _eaph, 
   {{0x657c5bae,0x213801af,0x72046f80,0x51840108}},	// [80f0] _faph, faph_, لورم, лужа, 
   {{0x657c216b,0xb51800bc,0x2bb000ce,0xdbf00139}},	//   _gaph, _दलिय_, _जत्थ, lğän, 
   {{0x948400ee,0x34946f81,0xab5c025c,0xc0240116}},	//   _сыпд, _танр, wiżm, مىلي, 
   {{0x657c6f82,0x66140309,0xf2c40075,0x6aa8198f}},	//   _zaph, _yuyk, _көзи, yyef, 
   {{0xd9f4069f,0xed586f83,0x4ea4010b,0x00000000}},	//   ुगात_, вол_, ыржа, --, 
   {{0xdcf80ba5,0xab5c0003,0xed5000e5,0x00000000}},	//   _altı, riżm, تھر_, --, 
   {{0xdbf006be,0x6adc013a,0x4ba400db,0x00000000}},	//   bəüz, मथ्र, лөдү_, --, 
   {{0x7d2400d1,0xdefc0327,0x00000000,0x00000000}},	//   لفۇن, ċċra_, --, --, 
   {{0xe9d848f2,0x67340113,0xeab0007b,0x00000000}},	//   кки_, _reyj, تعث_, --, 
   {{0xe81806ab,0x67d000e2,0xa9680063,0xdd38054e}},	//   _नंदा_, māji, њина_, măşi, 
   {{0x657c6f84,0x67346f85,0x66145063,0xe7286f86}},	//   _raph, _peyj, _suyk, конд_, 
   {{0xe7380a8f,0x661402d1,0xfcc800db,0x6fb4012d}},	//   ъем_, _puyk, _сууй_, ंसिं, 
   {{0x657c6f87,0x67d000da,0x7d2400d2,0x66140309}},	//   _paph, nāji, _étsé, _quyk, 
   {{0xc9840640,0xd62419ba,0x69dc00e5,0x00000000}},	//   _људи, роре_, ésed, --, 
   {{0xab5c003d,0x657c4b56,0x888068cf,0xa878010f}},	//   viżj, _vaph, _ایجن, _יאַר, 
   {{0x657c5b36,0x9c1001f2,0x2138009a,0x66146f88}},	//   _waph, kọnd, waph_, _tuyk, 
   {{0xd2a40598,0x657c0a55,0x21386f89,0xa1c445b1}},	// [8100] акте_, _taph, taph_, абад, 
   {{0x657c014b,0x614402bf,0x67d000e2,0x22440024}},	//   _uaph, режа, dāji, šoko_, 
   {{0x21386f8a,0x67f401a2,0x645c0784,0x00000000}},	//   raph_, nájo, _uqpi, --, 
   {{0x1e841cd6,0x213801c3,0x67f400e5,0x00000000}},	//   илем, saph_, zájn, --, 
   {{0x67d0005f,0x1e740120,0xab5c025c,0x00000000}},	//   gāji, рѓес, piżj, --, 
   {{0x9c440d6f,0xc1e400db,0xa3ac0073,0x00000000}},	//   ахил, _اۋئي, कसक_, --, 
   {{0x6e40044e,0x998006c8,0xa0a405f5,0xddc0012d}},	//   _ኣይግባ, ūkū_, _тавд, troł, 
   {{0x644c6f8b,0x67d000de,0x00000000,0x00000000}},	//   irbi, bāji, --, --, 
   {{0xc0e40092,0x67d00171,0x00000000,0x00000000}},	//   ዜውም_, cāji, --, --, 
   {{0x1da80401,0x3e60033b,0x644c0427,0x00000000}},	//   _कवित, mòt_, krbi, --, 
   {{0xdcf8007f,0x3e603c51,0x1d08430d,0x644c01bf}},	//   _katč, lòt_, _режи_, jrbi, 
   {{0x6d540209,0xfce40124,0x644c0175,0x5ac805a2}},	//   _özar, _коҕо, drbi, _илем_, 
   {{0x95c864e1,0xdcf86f8c,0x3e606f8d,0x644c6f8e}},	//   вува_, _matč, nòt_, erbi, 
   {{0x95c826bf,0x67f403df,0xd1bc0092,0x00000000}},	//   тума_, bájo, ዱበት_, --, 
   {{0x43a42d40,0xc8c400ec,0xe4b400db,0x45d4009d}},	//   ﺎﻳﯩﻦ_, _پوين_, бирө, цорс, 
   {{0x3e6002bd,0x00000000,0x00000000,0x00000000}},	//   kòt_, --, --, --, 
   {{0x998c0100,0x3e6002e2,0xd138010b,0x59a800cd}},	// [8110] _pifň_, jòt_, вхе_, _चकार, 
   {{0x3e606f8d,0xdd380356,0x00000000,0x00000000}},	//   dòt_, văşi, --, --, 
   {{0x395c019f,0x932403c7,0x7414085b,0xe10800eb}},	//   _mcvs_, _پرجن, _دوجا, শুসহ_, 
   {{0x67d00029,0x339400c6,0xa2c005b5,0x00000000}},	//   tāji, _الحز, _रेक्, --, 
   {{0x3e602561,0x5194030d,0x00000000,0x00000000}},	//   gòt_, _вăла, --, --, 
   {{0x51846f8f,0xdd380356,0x00000000,0x00000000}},	//   _тума, răşi, --, --, 
   {{0xab5c031c,0xace80006,0x321801ef,0xac9810e0}},	//   liżi, ымка_, _husy_, انعا_, 
   {{0x32180122,0xdd380276,0x3e606f90,0x997c0356}},	//   _kusy_, păşi, bòt_, _păşi_, 
   {{0xe7380184,0xef18031c,0x3e180276,0x3e600ba1}},	//   һен_, _gaża_, _воуэ_, còt_, 
   {{0xdcf80118,0xa4540092,0x644c0042,0xac1800d4}},	//   _zatč, _ዝግጅት, yrbi, _божу_, 
   {{0xe7386f91,0x32186f92,0x00000000,0x00000000}},	//   лен_, _lusy_, --, --, 
   {{0x2c6000e5,0x00000000,0x00000000,0x00000000}},	//   mód_, --, --, --, 
   {{0xa968228e,0x395c00db,0x00000000,0x00000000}},	//   _била_, _fcvs_, --, --, 
   {{0x64a46f93,0xa2c00b68,0xab5c031c,0x00000000}},	//   бага, _रेग्, diżi, --, 
   {{0xa34806bb,0x3e600100,0xe5a400fb,0x00000000}},	//   лзва_, zòt_, _ғини, --, 
   {{0x32100109,0xf1a82094,0x32186f94,0x73940212}},	//   _aizy_, یاله_, _busy_, ошує, 
   {{0x17540302,0x67f40122,0x644c2625,0x2c6001e7}},	// [8120] _הספר_, nájm, srbi, hód_, 
   {{0xef180327,0x3e60067c,0x2c60295c,0xe5780e58}},	//   _raża_, vòt_, kód_, _сзо_, 
   {{0x3210020c,0xdcf8007f,0xe3b04363,0x3e60033b}},	//   _dizy_, _patč, _فرح_, wòt_, 
   {{0x44446f95,0x3e606f96,0x83dc012d,0x6fe800d4}},	//   _iv_, tòt_, _यदिआ, афів_, 
   {{0x44446f97,0x321065f7,0x23ac032e,0x00000000}},	//   _hv_, _fizy_, _nýji_, --, 
   {{0x3f806f98,0xc104010b,0x2c60007b,0x67d000e2}},	//   žiu_, _дүзл, fód_, māju, 
   {{0x44446f99,0xdfd00486,0xad6404fb,0x67d000e2}},	//   _jv_, _فيس_, تانه, lāju, 
   {{0x63a46f9a,0xfc4402d3,0xa0680124,0x44442238}},	//   _jokn, _ከይፈለ, _иаҳа_, _mv_, 
   {{0x44446f9b,0x67d011f9,0x63a400df,0x9d443e1f}},	//   _lv_, nāju, _mokn, _гезд, 
   {{0x44446f9c,0x63a46f9d,0x20046f9e,0x387c00d7}},	//   _ov_, _lokn, lmoi_, _psvr_, 
   {{0x44440f85,0x645800cf,0x63a402d0,0xda6400ec}},	//   _nv_, àtil, _ookn, _ڇاتي, 
   {{0x2004004d,0x589400c7,0x78640139,0x63a400ef}},	//   nmoi_, ашҭу, бкүз, _nokn, 
   {{0x395c04e6,0x67d000e2,0x20040208,0x00000000}},	//   _tcvs_, jāju, imoi_, --, 
   {{0xd8b8156d,0x67d000da,0x682001f2,0x34946f9f}},	//   _مدعا_, dāju, _ịdep, оагр, 
   {{0x32183159,0x63a46fa0,0x534405f5,0x7afc00ac}},	//   _susy_, _bokn, йхаа, ərta, 
   {{0x44446fa1,0x32186fa2,0xcc38010f,0x00000000}},	//   _dv_, _pusy_, טעלט, --, 
   {{0x67d0005f,0x776c6fa3,0x95c82555,0x2c606fa4}},	// [8130] gāju, _ibax, _буна_, zód_, 
   {{0x44446fa5,0xab5c0327,0x00000000,0x00000000}},	//   _fv_, riżi, --, --, 
   {{0x44446fa6,0x63a46fa7,0x2ed000cd,0x00000000}},	//   _gv_, _fokn, तप्त, --, 
   {{0x61ec6fa8,0x776c031c,0x67d000e2,0x2ef403c5}},	//   _ekbl, _jbax, bāju, озер, 
   {{0x2c600034,0x6da46fa9,0x44446faa,0x776c0de2}},	//   wód_, жила, _zv_, _mbax, 
   {{0x44440323,0x2bb056e9,0xfe70082e,0x63a46fab}},	//   _yv_, जस्थ, عدن_, _zokn, 
   {{0x44446fac,0xdca002e8,0x7c6400be,0x00000000}},	//   _xv_, дащи, كايل, --, 
   {{0x2c60068f,0xaba86fad,0x20046fae,0x06e40154}},	//   ród_, рвиз_, cmoi_, নেটি, 
   {{0x2dd4020f,0x00000000,0x00000000,0x00000000}},	//   _джар, --, --, --, 
   {{0x6e286faf,0x776c6e0e,0x684400d4,0x00000000}},	//   _iteb, _abax, оноа, --, 
   {{0x3e240241,0x0984024c,0x00000000,0x00000000}},	//   _iṣọn, _ҳалқ_, --, --, 
   {{0x2a7c0211,0x44446fb0,0x38780200,0x2a340153}},	//   _tswb_, _rv_, çrra_, _дэкр, 
   {{0x63a46fb1,0x888004fb,0x00000000,0x00000000}},	//   _rokn, زیکن, --, --, 
   {{0x44446c8a,0x67d000da,0x776c6fb2,0x63a46fb3}},	//   _pv_, vāju, _ebax, _sokn, 
   {{0x7174044e,0x63a43386,0xa5082c68,0xdcf80055}},	//   _ጽሑፋት_, _pokn, рева_, _katā, 
   {{0x44444e90,0x67d00029,0x6e286fb4,0x23280022}},	//   _vv_, tāju, _oteb, роаи_, 
   {{0x44446fb5,0xdcf86fb6,0x6e2843c4,0x63a40115}},	// [8140] _wv_, _matā, _nteb, _vokn, 
   {{0xe0d06fb7,0x44446fb8,0x3ce005d1,0xdcf8002b}},	//   وزا_, _tv_, şivi_, _latā, 
   {{0x6e286fb9,0x44446fba,0xbb3c01ec,0x9594011a}},	//   _ateb, _uv_, _ﺑﻪﻱ_, _וכיו_, 
   {{0x26c0009d,0xdcf80a2f,0x00000000,0x00000000}},	//   ozko_, _natā, --, --, 
   {{0x5de46fbb,0x26c001c6,0x20040023,0x00000000}},	//   ожда, nzko_, rmoi_, --, 
   {{0x26c001c0,0x225001bf,0xdbdc01e1,0xb46400f2}},	//   izko_, mryk_, _ṣàk, _بدیه, 
   {{0x6e286fbc,0xdcf8002b,0x201c0311,0x22502694}},	//   _eteb, _batā, _îti_, lryk_, 
   {{0xdee46fbd,0x0ea40032,0xab600166,0x00000000}},	//   _доби, скәй_, _çüle, --, 
   {{0x22506fbe,0x2cb806be,0x3ca800fe,0x00000000}},	//   nryk_, _əsdi_, _কেশৱ, --, 
   {{0x3f846fbf,0x19a86fc0,0x81d80154,0xe3dc00cc}},	//   _hamu_, ртип_, াতক_, _ভীমব, 
   {{0x3f845088,0xd7f86fc1,0x7c285243,0x26c001c4}},	//   _kamu_, иум_, _utdr, ezko_, 
   {{0x3f8446a3,0x22500af9,0xdcf800dc,0x6e2802d0}},	//   _jamu_, kryk_, _gatā, _yteb, 
   {{0xcb6400a8,0x00000000,0x00000000,0x00000000}},	//   _фаче_, --, --, --, 
   {{0x225001bf,0x00000000,0x00000000,0x00000000}},	//   dryk_, --, --, --, 
   {{0x2d98016b,0x26c001c6,0x776c025c,0xd8380105}},	//   _ɑse_, azko_, _tbax, _тэл_, 
   {{0x3f846fc2,0x439438e0,0x776c6fc3,0xf3f801f0}},	//   _namu_, масс, _ubax, ёнаш_, 
   {{0x23ac0008,0x91280c50,0x26c0033f,0xae0c473c}},	// [8150] _nýju_, لساق_, czko_, िगमन_, 
   {{0x3f846fc4,0xd1b801f7,0x98bc013d,0x00000000}},	//   _aamu_, جارا_, letı_, --, 
   {{0x6e286fc5,0x3f846fc6,0x201c0098,0x3dd00154}},	//   _steb, _bamu_, _étil_, াকাল, 
   {{0x22506fc7,0x3f84015d,0x6e980395,0x00000000}},	//   bryk_, _camu_, йвер_, --, 
   {{0x3f846fc8,0x7ed40214,0xdcf800cd,0x80dc00cc}},	//   _damu_, وزها, _ratā, _ভৰদ্, 
   {{0x067c0a7c,0xdcf800dc,0xca78022e,0x98a80210}},	//   ינדל, _satā, tbuо, źbę_, 
   {{0x3f846fc9,0xdcf83db2,0x61e06fca,0x98bc0166}},	//   _famu_, _patā, éole, ketı_, 
   {{0xeb986fcb,0x3f846fcc,0x6e280083,0x04dc02e4}},	//   сии_, _gamu_, _tteb, יקול, 
   {{0x6e286fcd,0xab60010e,0x06b000cc,0xdcf8002b}},	//   _uteb, _çüme, _চেনি, _vatā, 
   {{0x3f846fce,0xfeb804fb,0x7e6408c2,0x5ac42a9d}},	//   _zamu_, _بافت_, àipe, ялым_, 
   {{0x63b8005f,0x3f840083,0x8bb4007b,0xdcf86991}},	//   ūtni, _yamu_, _وإصا, _tatā, 
   {{0x2d846fcf,0x6fbc02ab,0x3f841574,0x26c001c4}},	//   _hale_, ्फिं, _xamu_, tzko_, 
   {{0x2d846fd0,0x26c0009d,0xb6c401e0,0xfa8002dd}},	//   _kale_, uzko_, дияһ, _ақым, 
   {{0x2d846fd1,0x64a46fd2,0x3ea0005b,0xab5c025c}},	//   _jale_, пага, äiti_, riżu, 
   {{0x64a43ebf,0x2d846fd3,0x67f4219b,0xa8486fd4}},	//   чава, _male_, háji, _البم_, 
   {{0x22506fd5,0x00000000,0x00000000,0x00000000}},	//   tryk_, --, --, --, 
   {{0x3f846fd6,0xab5c0034,0x2d84054e,0xe0d800fd}},	// [8160] _ramu_, liżs, _oale_, әве_, 
   {{0x3f844437,0x2d846fd7,0x22506fd8,0x00000000}},	//   _samu_, _nale_, rryk_, --, 
   {{0x3f846fd9,0xab5c0034,0xe50800e3,0x20540006}},	//   _pamu_, niżs, _ديدو_, ятар, 
   {{0x2d846fda,0x9e645734,0x3f846fdb,0xd0040556}},	//   _aale_, كاتن, _qamu_, пехе_, 
   {{0x63b41f60,0xd24c0133,0xc2240066,0x00000000}},	//   mkyn, _ینێ_, _آکرو, --, 
   {{0x63b46fdc,0x2d846fdd,0x3f842f99,0x2fcc0086}},	//   lkyn, _cale_, _wamu_, _emeg_, 
   {{0x3f846fde,0x98bc03e0,0x91b801e4,0x00000000}},	//   _tamu_, yetı_, _פמלי, --, 
   {{0x69dc2047,0x63b46fdf,0x2d846fe0,0x50d8011a}},	//   ésen, nkyn, _eale_, _הקלא, 
   {{0x2d846fe1,0x98bc0724,0xef9001d5,0x6fb0012d}},	//   _fale_, vetı_, _جیند, _अकतू, 
   {{0x2d842517,0x00000000,0x00000000,0x00000000}},	//   _gale_, --, --, --, 
   {{0x98bc0598,0x63b46fe2,0xd90c01ed,0xcd800220}},	//   tetı_, kkyn, دیث_, _سۇيۋ, 
   {{0x2d846fe3,0x63b402f0,0x36d46fe4,0x78640139}},	//   _zale_, jkyn, домр, пкүз, 
   {{0x63b40308,0x49b400f2,0x00000000,0x00000000}},	//   dkyn, زاید_, --, --, 
   {{0x2d846fe5,0xca940375,0xe85000db,0x00000000}},	//   _xale_, _מדדי_, رچۉد, --, 
   {{0x33540137,0x7988015d,0x3d0001f9,0x00000000}},	//   мүнө_, mddw, षेचे_, --, 
   {{0x247402d3,0x63b400b5,0x0874008f,0x27e801e4}},	//   _ሽግራት_, gkyn, _זעהט_, _ĉang_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [8170] --, --, --, --, 
   {{0x63b406a3,0x940800ac,0x79886fe6,0x910400db}},	//   akyn, _əmək_, nddw, пчед, 
   {{0x2d846fe7,0x9f4403bd,0x7534030d,0x2fcc010f}},	//   _rale_, lloù_, mbzz, _pmeg_, 
   {{0x2d845c4d,0xd24401c6,0x00000000,0x00000000}},	//   _sale_, _нэги, --, --, 
   {{0x2d846fe8,0xce6823c5,0xa3e86fe9,0xc2e401d5}},	//   _pale_, сред_, यवर_, _зўри, 
   {{0x2d8401e0,0x00000000,0x00000000,0x00000000}},	//   _qale_, --, --, --, 
   {{0x2d846fea,0xac086feb,0x4fc400c7,0xafc401ec}},	//   _vale_, онка_, _есаа, _قيسى, 
   {{0x2d846fec,0x79981937,0xdb0001c4,0x6ab44b53}},	//   _wale_, _anvw, _aloñ, дсох, 
   {{0x2d84493b,0xfe701060,0xdb00030a,0x7b640114}},	//   _tale_, _مدل_, _bloñ, хтје, 
   {{0x27f06fed,0x3ce8068f,0x2d846fee,0xde500023}},	//   _skyn_, _चुके_, _uale_, _ኣይኬግ, 
   {{0x3cf00232,0x9f440489,0x63b401f4,0x00000000}},	//   čové_, eloù_, ykyn, --, 
   {{0xddc02314,0x7bc06fef,0xdb246ff0,0x2fdc13e9}},	//   kroś, chmu, _قومی, nnwg_, 
   {{0xb8f46398,0xdcf80276,0xb950001f,0x9f440165}},	//   _से_, _tată, _ቀበሌዎ, gloù_, 
   {{0x6b886ff1,0x63b403a2,0x5e54008f,0xddc0012d}},	//   ldeg, wkyn, וישע_, droś, 
   {{0x69c06ff2,0x63b403a2,0xa6c800aa,0x04f805d9}},	//   mhle, tkyn, _ژوبل_, سورڊ_, 
   {{0x69c001ee,0x7c3c0023,0x9f440489,0x00000000}},	//   lhle, _çrre, bloù_, --, 
   {{0x6b886ff3,0x0500015b,0x61b401d9,0x00000000}},	// [8180] ideg, ্ডের_, وٕرا, --, 
   {{0x69c06ff4,0x63b46ff5,0x9654008f,0x6b886ff6}},	//   nhle, skyn, _קשיא_, hdeg, 
   {{0x69c00097,0xa5086ff7,0x041800cc,0x6b8803b2}},	//   ihle, _фена_, ধীজী_, kdeg, 
   {{0xe2986ff8,0x23940014,0x6b8801f5,0x69c00327}},	//   _дам_, _تۅرگ_, jdeg, hhle, 
   {{0x79880cfd,0x69c003a2,0x38b40248,0x00000000}},	//   yddw, khle, _kúrú_, --, 
   {{0xfe7016cb,0x6b886ff9,0x69c00118,0x69dc00e5}},	//   ندڙ_, edeg, jhle, ésel, 
   {{0x7bc06ffa,0x69c06ffb,0x6b88017a,0xe81805b3}},	//   thmu, dhle, fdeg, _नंगा_, 
   {{0x69c06ffc,0x6b886ffd,0xd0043004,0x7988015d}},	//   ehle, gdeg, _жесе_, wddw, 
   {{0xad6416cb,0x60cc0006,0xdb000165,0x69c002d2}},	//   _ڳاله, žimė, _ploñ, fhle, 
   {{0x69c06ffe,0x7f406e35,0x7bc06fff,0x79880368}},	//   ghle, _hemq, shmu, uddw, 
   {{0x79880368,0xad6404fb,0x6b88005c,0x00000000}},	//   rddw, _ساله, bdeg, --, 
   {{0x9f440156,0x69c07000,0x167001d5,0x00000000}},	//   tloù_, ahle, вқир, --, 
   {{0x38b401e1,0x69c07001,0x98bc02e2,0x00000000}},	//   _búrú_, bhle, matč_, --, 
   {{0xceb004ac,0x1dc000dc,0x9f440165,0x8af8011a}},	//   דיש_, वोचत, rloù_, _והדי, 
   {{0x38b401e1,0xb4d802e5,0xfa88004d,0x6bd40c75}},	//   _dúrú_, ़पे_, _hừ_, _تتەر, 
   {{0xe80001ad,0x98bc02bd,0xddc01be1,0x00000000}},	//   ोषणा_, natč_, troś, --, 
   {{0x6448008c,0xd1480f87,0xe3c006be,0x00000000}},	// [8190] _æfin, قشان_, dlığ_, --, 
   {{0x765c7002,0x6b887003,0xfa88004d,0x38b414fc}},	//   musy, zdeg, _mừ_, _gúrú_, 
   {{0x765c7004,0x98bc0100,0xfa880208,0x61e0003e}},	//   lusy, katč_, _lừ_, éola, 
   {{0xef180135,0x69c07005,0x00000000,0x00000000}},	//   _każi_, zhle, --, --, 
   {{0x765c7006,0xeb987007,0x69c07008,0xac0800d1}},	//   nusy, җип_, yhle, үнла_, 
   {{0x5e900472,0x00000000,0x00000000,0x00000000}},	//   الوط, --, --, --, 
   {{0x6b88014f,0x69dc7009,0x00000000,0x00000000}},	//   tdeg, ésem, --, --, 
   {{0x6b88700a,0x765c700b,0xef180327,0x33280de2}},	//   udeg, kusy, _oażi_, ncax_, 
   {{0xfa88004d,0x765c0083,0xbbe806c2,0x00000000}},	//   _cừ_, jusy, بروم_, --, 
   {{0x6b88700c,0x69c0700d,0xef18031c,0xfa880051}},	//   sdeg, uhle, _nażi_, _dừ_, 
   {{0x6d40700e,0x7f40047e,0x765c062c,0x6b880477}},	//   _iela, _yemq, eusy, pdeg, 
   {{0x6d40700f,0x69c07010,0xdc34008f,0x6b880477}},	//   _hela, shle, _נאנט_, qdeg, 
   {{0x6d407011,0xe3c04953,0xef18003d,0x765c7012}},	//   _kela, nlış_, _bażi_, gusy, 
   {{0x6d404aa5,0x26dc0356,0x00000000,0x00000000}},	//   _jela, ăto_, --, --, 
   {{0x6d407013,0xddc00115,0xb90800cf,0x00000000}},	//   _mela, jroŝ, _ۉزۉم_, --, 
   {{0x6d402a1f,0x765c7014,0xd8d40a1e,0x58f4011a}},	//   _lela, busy, _רוקט_, _אמצע_, 
   {{0x6d4001ee,0xef180003,0x7f400393,0xd9100124}},	// [81a0] _oela, _fażi_, _remq, _идәы, 
   {{0x6d407015,0xe8880016,0x7f40014b,0x60240006}},	//   _nela, _kẻ_, _semq, еджа, 
   {{0x23280c60,0xd12c0014,0x19b4010f,0x6d540205}},	//   _нони_, صمن_, עפער_, _özay, 
   {{0x6d400bed,0xe88801fb,0xe358010a,0x00000000}},	//   _aela, _mẻ_, _эшош_, --, 
   {{0xe8880016,0xc17401ed,0x67f402f0,0x98bc007f}},	//   _lẻ_, _لگات, lájs, vatč_, 
   {{0xd6f800b5,0xddc001e4,0x7f40014f,0xef180327}},	//   feり_, broŝ, _wemq, _xażi_, 
   {{0x91e000c9,0xdbdc01e1,0x660c009a,0xe888004d}},	//   _соре, _fíìn, imbk, _nẻ_, 
   {{0x6d407016,0x3ea00221,0x00000000,0x00000000}},	//   _eela, äits_, --, --, 
   {{0x6d407017,0x1ea806f6,0x98bc02e2,0x67f40419}},	//   _fela, _عاري_, ratč_, hájs, 
   {{0xdca47018,0xe88801fb,0x99640075,0xfa880051}},	//   _пази, _bẻ_, хтил, _vừ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfa88431d,0x765c7019,0x6d40701a,0x628401c4}},	//   _từ_, tusy, _zela, _osko, 
   {{0x6d40701b,0x9644009d,0xc6e4003b,0xd90c085b}},	//   _yela, ээнд, гірп, _گید_, 
   {{0x6d400694,0x00000000,0x00000000,0x00000000}},	//   _xela, --, --, --, 
   {{0x6284701c,0xd90c190f,0x38c80244,0x00000000}},	//   _asko, _دید_, _تاشی_, --, 
   {{0x765c1c06,0xdcf800de,0xca8001af,0x00000000}},	//   pusy, _antī, _ргәй, --, 
   {{0x63b80165,0xe8880051,0x00000000,0x00000000}},	// [81b0] êtna, _zẻ_, --, --, 
   {{0x764c0b6f,0x6284020b,0xdecc0023,0x00000000}},	//   _ivay, _dsko, ቢኡን_, --, 
   {{0x22a0013f,0xe88801fb,0x60180165,0x386c00b5}},	//   fɔks_, _xẻ_, _sůma, ntdr_, 
   {{0x6d404020,0xad2415bf,0xa6e000cc,0x00000000}},	//   _sela, چىشى, _নৰিয়, --, 
   {{0x439413d7,0x69dc00dd,0x6284009f,0xad243ee0}},	//   _саяс, ések, _gsko, نىشى, 
   {{0x6d40701d,0xed581171,0xd1500092,0x00000000}},	//   _qela, фок_, ሆናቸው, --, 
   {{0x44840092,0x8d7000f1,0xbb3c0ef6,0xa1a401af}},	//   _ያካተተ_, ناډا, _ﺑﻪﻝ_, _рыяһ, 
   {{0xe88807ae,0x6d40701e,0x9b900131,0x764c701f}},	//   _rẻ_, _wela, للىت, _ovay, 
   {{0x6d407020,0xe88807ae,0x764c00cd,0xdcf80153}},	//   _tela, _sẻ_, _nvay, _matę, 
   {{0x6d407021,0x6994011c,0x00000000,0x00000000}},	//   _uela, трих, --, --, 
   {{0x764c7022,0x395800ae,0x00000000,0x00000000}},	//   _avay, órsa_, --, --, 
   {{0xe88807ae,0xc6d401c0,0xdcf8012d,0x00000000}},	//   _vẻ_, гсгө, _natę, --, 
   {{0x5fa402ab,0xae202017,0xa9680229,0x85b4008e}},	//   कॉटल, मदिन_, _жила_, гәнч, 
   {{0x764c0882,0xe888004d,0x00000000,0x00000000}},	//   _dvay, _tẻ_, --, --, 
   {{0xddc000da,0x764c7023,0x15407024,0xd4647025}},	//   ntoš, _evay, ресм, кире_, 
   {{0x7b0803b2,0xe29801d5,0x00000000,0x00000000}},	//   _ístø, маб_, --, --, 
   {{0x2a6c7026,0x61e07027,0x98bc7028,0xa188009d}},	// [81c0] nteb_, éolo, matā_, мбаа_, 
   {{0x64580268,0x62840010,0x38780162,0xd24c0bce}},	//   àtis, _vsko, _ífrá_, زنم_, 
   {{0x764c0433,0x64580077,0x62840210,0x00000000}},	//   _zvay, átid, _wsko, --, 
   {{0x2a6c7029,0x93c40276,0xdef80220,0x27e00098}},	//   kteb_, _plăţ, мыл_, nnkn_, 
   {{0x62844db0,0xddc0702a,0x8e4400d1,0x6458702b}},	//   _usko, etoš, پلىك_, štid, 
   {{0x8d6015ed,0x98bc0882,0xe624004d,0xffa4702c}},	//   авље, hatā_, _đôla_, _өлгү, 
   {{0x98bc702d,0x3ea00276,0x00000000,0x00000000}},	//   katā_, ţit_, --, --, 
   {{0x61fc702e,0xcb640114,0x00000000,0x00000000}},	//   llpl, ваће_, --, --, 
   {{0xd00c0491,0x2a6c0218,0x61fc017a,0x98bc002b}},	//   _ذلك_, gteb_, olpl, datā_, 
   {{0x3ec40205,0x00000000,0x00000000,0x00000000}},	//   ırtı_, --, --, --, 
   {{0x764c0a28,0x06b004c5,0x61fc0af9,0xbb3c00d1}},	//   _svay, _চেলি, ilpl, _ﺑﻪﻙ_, 
   {{0x61fc1196,0x00000000,0x00000000,0x00000000}},	//   hlpl, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x61fc01bf,0xe584009d,0x00000000,0x00000000}},	//   jlpl, лтсү, --, --, 
   {{0xd90c0214,0xf8b80137,0x938801c6,0xc618702f}},	//   _گیگ_, _чөп_, мсаа_, торх_, 
   {{0x764c0882,0x61fc2bb9,0xd404023a,0x03c40024}},	//   _tvay, elpl, тяги, асум, 
   {{0x764c7030,0xd90c17a5,0xd6840117,0x00000000}},	// [81d0] _uvay, _دیگ_, _руйп, --, 
   {{0x61fc04cc,0x98bc0153,0x00000000,0x00000000}},	//   glpl, ngtį_, --, --, 
   {{0xc95025f9,0xaad800e1,0x69dc01ed,0x00000000}},	//   שמע_, _बेनक, ései, --, 
   {{0xb4c0068f,0x61fc7031,0xddc0054e,0xa5c008a5}},	//   ्छी_, alpl, troş, _þóro, 
   {{0x20e8166a,0x4ea40801,0xc1cc01e1,0x6ecc0037}},	//   aʝi_, ържа, _kọ̀ǹ, _देखु, 
   {{0x64587032,0xf0c0010a,0xbd680114,0xfd74004e}},	//   štie, _гιоь, врће_, илчэ, 
   {{0x7c640d1f,0x4084001b,0xabf41422,0x6c7401c4}},	//   لايل, _кутб, лчищ, уулх, 
   {{0xddc07033,0x6dc000db,0xea88011c,0x00000000}},	//   rtoš, _گۅتۅ, ебил_, --, 
   {{0xddc07034,0x98bc0882,0xb4c047d0,0xeb9800fd}},	//   stoš, vatā_, ्छु_, _җил_, 
   {{0x201c00cf,0x7d740271,0xaad80037,0x00000000}},	//   _ètic_, _نامط, _बइठक, --, 
   {{0x2a6c01d4,0x4a7002dd,0xdcf800bc,0x48b003d4}},	//   steb_, уықт, _matě, ুপ্ৰ, 
   {{0x7ae40552,0xb864036b,0x3d2801e1,0xa6c85476}},	//   _žite, گایو, _tìwó_, елма_, 
   {{0x61fc01bf,0x00000000,0x00000000,0x00000000}},	//   ylpl, --, --, --, 
   {{0xa968355d,0xdcf80118,0xa6840150,0x00000000}},	//   _чика_, _natě, _ұлид, --, 
   {{0xa3e80801,0xf8a800c6,0xdb000139,0xa878010f}},	//   едва_, _لديه_, _pooç, _טאַר, 
   {{0xa7647035,0x64580137,0xd4940208,0x78bc03cd}},	//   _скид, àtiq, ừng_, ørve, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [81e0] --, --, --, --, 
   {{0x6d4409f3,0xfe7001d3,0x55e0010a,0x00000000}},	//   ðhal, ےگا_, _гоьб, --, 
   {{0x98bc0276,0x70240014,0x61fc01e3,0x00000000}},	//   mată_, لرنٕ, rlpl, --, 
   {{0x98bc084c,0x7e4800e5,0x00000000,0x00000000}},	//   lată_, نستہ_, --, --, 
   {{0x661c0054,0x644c007c,0xc2b401c6,0x1418011a}},	//   _kipk, lsbi, _төвш, _רוכב, 
   {{0x98bc084c,0x3d942472,0x2dc401d5,0x601801ef}},	//   nată_, рикр, ақун_, _tůmo, 
   {{0x5b247036,0x4438002f,0x98bc054e,0x00000000}},	//   льпа, npr_, iată_, --, 
   {{0xba541614,0x1fa802bf,0xdb4c03e6,0x8bc00209}},	//   авиј, _якби_, سێت_, йсыд, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x98bc0311,0x644c0423,0x443800b5,0x4f9400c7}},	//   jată_, ksbi, kpr_, _ирӡу, 
   {{0x98bc084c,0xdb000254,0x644c01bf,0xc94c01d5}},	//   dată_, _sooä, jsbi, _қў_, 
   {{0x644c6130,0x97a47037,0xf8b800e4,0x00000000}},	//   dsbi, урол, ryĩ_, --, 
   {{0x75d47038,0x644c003a,0x44380165,0x7c3801a4}},	//   ليحا, esbi, epr_, lpvr, 
   {{0x98bc0276,0x28c00034,0x644c0e78,0x443800d8}},	//   gată_, शनशि, fsbi, fpr_, 
   {{0x65b8025a,0xb4c07039,0x661c003e,0x998c0100}},	//   _sähê, ्छे_, _dipk, _pifņ_, 
   {{0x766400f1,0x28c007f7,0x00000000,0x00000000}},	//   _پیسې_, शनरि, --, --, 
   {{0x98bc0311,0x644c01ab,0x00000000,0x00000000}},	// [81f0] bată_, asbi, --, --, 
   {{0x98bc00a8,0x661c110c,0x644c67c4,0x104800d4}},	//   cată_, _gipk, bsbi, еяди_, 
   {{0x44380408,0x614415bf,0xf48402f2,0x6d4403b2}},	//   cpr_, شىنە, _ئاخی, ðham, 
   {{0x645807f5,0xc0580131,0x741400d1,0x661c03e0}},	//   štic, اشلا_, _خوجا, _zipk, 
   {{0x926807fb,0x00000000,0x00000000,0x00000000}},	//   _ярна_, --, --, --, 
   {{0x2b4801a6,0x765c0076,0x6e2c0115,0x600800d7}},	//   _žac_, irsy, ŭabo, výme, 
   {{0x765c002f,0x3b200248,0x00000000,0x00000000}},	//   hrsy, _ẹyọ_, --, --, 
   {{0xeb980364,0x98bc084c,0x91c000fb,0x00000000}},	//   тии_, zată_, _тәғл, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6f080113,0xd1c402d3,0x44380204,0xfe54703a}},	//   _izec, _ጸቢብ_, ypr_, _ایوب_, 
   {{0xe738703b,0x98bc0276,0x765c3a5e,0x18b000c7}},	//   кен_, vată_, ersy, жәыр, 
   {{0xc600044b,0x3bd40064,0x00000000,0x00000000}},	//   ोग्य_, _люіс, --, --, 
   {{0x661c703c,0xaa44703d,0x98bc084c,0xa9a4586a}},	//   _pipk, _телл, tată_, _вилд, 
   {{0x644c703e,0x7d1c007b,0xe8f8030d,0xe4c41d4d}},	//   tsbi, _úrsc, _илл_, айги, 
   {{0x98bc00a8,0x644c0e78,0x64b001ad,0xb4c401e0}},	//   rată_, usbi, ीनेश, бирҙ, 
   {{0x98e40184,0x98bc0276,0x661c01f5,0x00000000}},	//   _әсәһ, sată_, _wipk, --, 
   {{0xe1f807d6,0x661c703f,0x644c26bc,0x255801c0}},	// [8200] вга_, _tipk, ssbi, _ирнэ_, 
   {{0x44387040,0xff680092,0xf1d400db,0x5ea4691d}},	//   ppr_, ተዳድሩ_, бөсө, یمال, 
   {{0x64a47041,0x4438014b,0xa3e802d5,0xc9940092}},	//   _тана, qpr_, _адна_, ውሮፓው_, 
   {{0x44447042,0x23280107,0x00000000,0x00000000}},	//   _iw_, _шоми_, --, --, 
   {{0x2ba828e1,0x2a7c0218,0x6f087043,0x98bc6dd3}},	//   काना, _npwb_, _czec, matą_, 
   {{0x44447044,0x629407a8,0x6f0805b8,0x98bc00c0}},	//   _kw_, mvyo, _dzec, latą_, 
   {{0x6f087045,0xab5c0210,0x00000000,0x00000000}},	//   _ezec, liży, --, --, 
   {{0x44447046,0x765c00ee,0x98bc0153,0x09e00011}},	//   _mw_, yrsy, natą_, _নীলা, 
   {{0x44447047,0x62947048,0xab5c012d,0x00000000}},	//   _lw_, nvyo, niży, --, 
   {{0x44447049,0x4970453f,0xd9b000db,0x00000000}},	//   _ow_, ольс, تەتد, --, 
   {{0x98bc6dd3,0x91b8011a,0x00000000,0x00000000}},	//   katą_, דמיי, --, --, 
   {{0xdb4c04d3,0x22bc0374,0xda78704a,0x387c00d7}},	//   _کێک_, _kākā_, _аяк_, _vpvr_, 
   {{0xa9c401e0,0x765c01f5,0x98bc0064,0x00000000}},	//   рсөк, ursy, datą_, --, 
   {{0x444443c4,0x7c28704b,0x22bc02b5,0x98a000fd}},	//   _bw_, _kudr, _mākā_, şkı_, 
   {{0x4444704c,0x394c05d5,0x534401c0,0xdcf8008e}},	//   _cw_, mads_, ихаа, _kotı, 
   {{0x4444704d,0x394c704e,0x99e400a2,0x2ba800dc}},	//   _dw_, lads_, _diňş, काया, 
   {{0x7c2804ac,0x717805f5,0xff68001f,0xcb10008f}},	// [8210] _ludr, лбар_, ተዳደሩ_, ַלע_, 
   {{0x4444704f,0x6f08006d,0x394c7050,0x7c287051}},	//   _fw_, _rzec, nads_, _oudr, 
   {{0x44447052,0x2ba818ea,0x7c287053,0xed581086}},	//   _gw_, कामा, _nudr, ҳол_, 
   {{0x394c07de,0xdcf8013d,0x22bc00ef,0x00000000}},	//   hads_, _notı, _bākā_, --, 
   {{0x7c287054,0x51847055,0xed587056,0x3ef8084c}},	//   _audr, _кува, гол_, анцэ_, 
   {{0x44447057,0x9fa40032,0x7c281cd0,0x394c05d5}},	//   _yw_, _һыуҙ, _budr, jads_, 
   {{0x44447058,0x394c1570,0x7c287059,0xd0180353}},	//   _xw_, dads_, _cudr, _афа_, 
   {{0xa8840952,0x7c2800b8,0x9fa401ee,0x00000000}},	//   ەلدى, _dudr, _лыуҙ, --, 
   {{0x7c280afe,0x6f080cf4,0x2ba80bae,0xcc840133}},	//   _eudr, _uzec, काबा, _چۆته_, 
   {{0x394c0c86,0x7db4007b,0x00000000,0x00000000}},	//   gads_, _وصلا, --, --, 
   {{0x6e280656,0x7c28705a,0x5df8008f,0x7c34010a}},	//   _hueb, _gudr, _עפענ, _дехх, 
   {{0x4444705b,0x6e2801c7,0xfcc8004e,0x7d1c02d2}},	//   _rw_, _kueb, _тууй_, _úrsa, 
   {{0x6e20705c,0x394c2e13,0xfbd00832,0x4aa80137}},	//   _kilb, bads_, _تتل_, _جااپ_, 
   {{0x4444705d,0x6e28705e,0x6e20705f,0x28b80597}},	//   _pw_, _mueb, _jilb, _مطبخ_, 
   {{0x6e207060,0x44440211,0x6e28009a,0x69c00d47}},	//   _milb, _qw_, _lueb, mkle, 
   {{0x69c07061,0x44447062,0xe4c412d7,0xbae80183}},	//   lkle, _vw_, айҳи, _পৰিছ, 
   {{0x6e282d6d,0x98bc7063,0x6e207064,0x44447065}},	// [8220] _nueb, ratą_, _oilb, _ww_, 
   {{0x44447066,0x69c07067,0x6e207068,0x2b4c0393}},	//   _tw_, nkle, _nilb, haec_, 
   {{0x44443a0e,0xb6200046,0x7c2401e4,0x3e300023}},	//   _uw_, _ﺩﺍ_, ĉirk, _እተካይ, 
   {{0x6e287069,0xa2e405f5,0x7c280882,0x22bc1d77}},	//   _bueb, _гомд, _rudr, _pākā_, 
   {{0x6e20706a,0x69c0706b,0x7c28706c,0x6e280332}},	//   _bilb, kkle, _sudr, _cueb, 
   {{0x6e280221,0x6e20706d,0xdfd00451,0x394c07c5}},	//   _dueb, _cilb, _کير_, xads_, 
   {{0x8d70706e,0x6e20706f,0x394c7070,0x7c287071}},	//   ساوا, _dilb, vads_, _qudr, 
   {{0x9b687072,0x7c287073,0x6e207074,0x6e280036}},	//   ушка_, _vudr, _eilb, _fueb, 
   {{0x394c060a,0x6e20050a,0xd7f87075,0x69c07076}},	//   tads_, _filb, ғун_, fkle, 
   {{0x69c07077,0xd8387078,0x6e207079,0x6f1c0332}},	//   gkle, лэм_, _gilb, _úsca, 
   {{0x394c707a,0xdcf80724,0x9b440244,0x00000000}},	//   rads_, _totı, _هناو, --, 
   {{0x394c707b,0xaad80c2e,0x69dc07ea,0x6e2803f9}},	//   sads_, _बेवक, éser, _yueb, 
   {{0x394c707c,0x6458707d,0xcb0400b2,0x95c82dbf}},	//   pads_, átin, _ٿيون_, гува_, 
   {{0x69c0707e,0x6e200009,0x00000000,0x00000000}},	//   ckle, _xilb, --, --, 
   {{0x6458707f,0xd37807d5,0x2ea40118,0x00000000}},	//   štin, лча_, _खप्त, --, 
   {{0xeda40a28,0xd1b82fd2,0x00000000,0x00000000}},	//   _गच्छ, گارا_, --, --, 
   {{0xf8b000dd,0x780408e9,0xd5e804fb,0x5924031c}},	// [8230] _رکھ_, रतीक_, _معدن_, _རྔོས_, 
   {{0xd1b87080,0x6e2822df,0xc69400df,0x00000000}},	//   دارا_, _rueb, _זאץ_, --, 
   {{0x6e287081,0xd4980063,0x25bc0254,0x00000000}},	//   _sueb, _срп_, ötle_, --, 
   {{0x6e287082,0x6e987083,0x6e207084,0xb4b400c5}},	//   _pueb, ивер_, _silb, झही_, 
   {{0x69c07085,0x7ae45a54,0x6e287086,0x00000000}},	//   ykle, _žitn, _queb, --, 
   {{0x69c001a4,0xdcf8008e,0x9e9400d1,0x00000000}},	//   xkle, _qatğ, غانچ, --, 
   {{0x6e207087,0x2b4c0381,0x69c00790,0x9d7400db}},	//   _vilb, taec_, vkle, تئنچ, 
   {{0x6e207088,0x6e287089,0x8d7404fb,0xd1dc001f}},	//   _wilb, _tueb, _گارا, ናዎች_, 
   {{0x6e20708a,0x69c02c6a,0x4ea401c6,0x98bc6dd3}},	//   _tilb, tkle, _урва, matę_, 
   {{0x8d74708b,0xe9d8399f,0xd1f40092,0xed502b9f}},	//   _دارا, рко_, _ፈቀቅ_, _آپا_, 
   {{0x69c0708c,0xa7a81575,0x2ba808a3,0xdd0c0205}},	//   rkle, акна_, कादा, mışm, 
   {{0xdd0c708d,0x7dc402dd,0xa6e00174,0x443c00c0}},	//   lışm, _وتەك, _íðka, _įv_, 
   {{0x2d98013f,0x69c0057b,0x00000000,0x00000000}},	//   _ɔsen_, pkle, --, --, 
   {{0xdd0c07c4,0x00000000,0x00000000,0x00000000}},	//   nışm, --, --, --, 
   {{0xe7380220,0x3ea00036,0x232800c7,0x4900009d}},	//   _кей_, äitz_, иови_, _хүнг, 
   {{0xe730708e,0x00000000,0x00000000,0x00000000}},	//   _غصب_, --, --, --, 
   {{0xdd0c05d1,0x22500153,0x00000000,0x00000000}},	// [8240] kışm, usyk_, --, --, 
   {{0x2250708f,0xe1640597,0x93c4004d,0x00000000}},	//   rsyk_, تدري, _hoặ, --, 
   {{0x22507090,0xef5402d3,0xe0d800d8,0x00000000}},	//   ssyk_, _ከምዝግ, јве_, --, 
   {{0x22500158,0xaac8012c,0x9878008f,0x00000000}},	//   psyk_, िनाक, ירעק, --, 
   {{0xb3541f70,0xaad81025,0x00000000,0x00000000}},	//   _ریلا_, _बेलक, --, --, 
   {{0xb8fc1efe,0x7ae4009b,0x5698008f,0xd0f00073}},	//   _ལྟ_, _žito, יינצ, _अडचण_, 
   {{0x4e900075,0x98bc0210,0xdfd04c1c,0x00000000}},	//   كشۈر, batę_, _قيس_, --, 
   {{0x69dc020c,0x4c100d2f,0x0e601206,0xff240133}},	//   èsen, وبيس, чкән, _ربری, 
   {{0x7e980edf,0xa3d03d1d,0xdd0c013d,0xf1c000cd}},	//   _دچار_, _वतन_, bışm, _एवमन, 
   {{0x200402d3,0x4d6009a5,0x00000000,0x00000000}},	//   lloi_, _окув, --, --, 
   {{0x09b406d5,0x38c87091,0x5ce4007b,0xda6400ec}},	//   تطيع_, صادی_, _بكال, _ڀاتي, 
   {{0x9aa47092,0x63a4003e,0x657c00b8,0xbb282d40}},	//   _وماو, _nnkn, _abph, ﻣﺪﻯ_, 
   {{0x6458098d,0x20047093,0x657c00b5,0x00000000}},	//   štil, iloi_, _bbph, --, 
   {{0x63a45df4,0x00000000,0x00000000,0x00000000}},	//   _ankn, --, --, --, 
   {{0x667012e1,0x2004005a,0xc49400d4,0x79887094}},	//   وگیر, kloi_, мирщ, medw, 
   {{0x79887095,0xd6d87096,0xdd0c1b0d,0x00000000}},	//   ledw, _вто_, zışm, --, 
   {{0x2004003e,0x6448025c,0xdd0c0205,0x38540092}},	// [8250] dloi_, _ħfie, yışm, _መተባበ, 
   {{0xd1387097,0x79887098,0x41e4109a,0x9104084c}},	//   рха_, nedw, міха, очед, 
   {{0x85347099,0xada4016c,0xdcf800de,0x00000000}},	//   _توپچ, ҷалл, _matē, --, 
   {{0x7988709a,0xffd40691,0x53a00137,0x00000000}},	//   hedw, وغند, _تۅرك, --, 
   {{0x6da41607,0x7988709b,0xcee8709c,0xada4709d}},	//   зила, kedw, جران_, залл, 
   {{0x7988009f,0xa280438b,0xa2b80375,0x00000000}},	//   jedw, _سیمو, _המשט, --, 
   {{0x7d1c09cc,0xdd0c050e,0x798814dc,0xe80c012c}},	//   _úrsl, rışm, dedw, सतमा_, 
   {{0xdc2000b0,0xdecc0092,0x09c000cd,0x00000000}},	//   _pōān, ጥልኝ_, षस्य, --, 
   {{0xe9d84ced,0xdd0c1432,0x00000000,0x00000000}},	//   йки_, pışm, --, --, 
   {{0x7988709e,0x2ba8185b,0xedd400c6,0x66e4010b}},	//   gedw, काहा, _عياد, җога, 
   {{0xbb280ed1,0xdcf80171,0x00000000,0x00000000}},	//   ﻣﻪﻥ_, _datē, --, --, 
   {{0x64584eb7,0xfc6402e8,0x2fd4013d,0x00000000}},	//   átim, _цъфн, _çagı_, --, 
   {{0x7988709f,0x6b8870a0,0x60080419,0x00000000}},	//   bedw, meeg, zýmo, --, 
   {{0x6b8870a1,0x6458098d,0x7988127b,0xba00035b}},	//   leeg, štim, cedw, _иҧыл, 
   {{0xa508537c,0x77900133,0x00000000,0x00000000}},	//   сева_, رییا, --, --, 
   {{0x78bc70a2,0x6b8870a3,0x2408013e,0x942070a4}},	//   ärve, neeg, ёнаи_, емсе, 
   {{0x73740022,0x00000000,0x00000000,0x00000000}},	// [8260] ьырх, --, --, --, 
   {{0x6b880014,0x00000000,0x00000000,0x00000000}},	//   heeg, --, --, --, 
   {{0x200470a5,0x55b80375,0x525821ef,0x26c070a6}},	//   tloi_, _המיו, لسەڭ_, lyko_, 
   {{0x798870a7,0xd7ac0490,0x63a470a8,0x12b800d1}},	//   zedw, टायच, _unkn, ﻧﺒﻪﺭ, 
   {{0x53980375,0x6b88058a,0x20040042,0x656c0332}},	//   _היכו, deeg, rloi_, ogbh, 
   {{0x656c06a3,0x798870a9,0x00000000,0x00000000}},	//   ngbh, xedw, --, --, 
   {{0x20042047,0x61fc70aa,0x79880c8c,0x3c3800c7}},	//   ploi_, mopl, vedw, _oĩve_, 
   {{0x798870ab,0x6b8870ac,0x25b80064,0x7d1c02d2}},	//   wedw, geeg, _lopl_, _úrsm, 
   {{0x79882f05,0xdcf800da,0xbb2c24ae,0x7bdc0064}},	//   tedw, _patē, ﯩﺸﻰ_, _įrud, 
   {{0xdbf003e3,0x00000000,0x00000000,0x00000000}},	//   lşün, --, --, --, 
   {{0x798870ad,0x2ba80a94,0x645804a7,0x76ac013f}},	//   redw, काशा, štij, mɑyɛ, 
   {{0x61fc70ae,0x798870af,0x6b88011f,0x26c00175}},	//   hopl, sedw, ceeg, fyko_, 
   {{0x2ba870b0,0x61fc70b1,0xdb04005b,0x79880857}},	//   कारा, kopl, ömäk, pedw, 
   {{0x997470b2,0x79880107,0x61fc01f5,0x4ac00150}},	//   _худш, qedw, jopl, _سيىق, 
   {{0x99800153,0x897800d9,0x00000000,0x00000000}},	//   ūkų_, _הרוצ, --, --, 
   {{0x61fc0175,0xdefc0135,0x00000000,0x00000000}},	//   eopl, ċċja_, --, --, 
   {{0x91280ed1,0x0ed82017,0x61fc70b3,0x35f41d5b}},	// [8270] مساق_, _मेंड, fopl, _опир, 
   {{0x61fc70b4,0x833405f5,0x6b8870b5,0xc69400df}},	//   gopl, _үнэх, zeeg, _טאפ_, 
   {{0x06380405,0x6b8870b6,0x00000000,0x00000000}},	//   _وسیع_, yeeg, --, --, 
   {{0x046470b7,0x00000000,0x00000000,0x00000000}},	//   _ятьм, --, --, --, 
   {{0x6ff4068f,0x61fc01e4,0x98bc00bc,0x6b8870b8}},	//   jące, bopl, tatě_, veeg, 
   {{0xac3870b9,0x6ce4004b,0xfe7001d5,0x6ff4012d}},	//   очих_, وړان, طده_, dące, 
   {{0x6b8870ba,0x2ba870bb,0xdd8c70bc,0x26c0033f}},	//   teeg, काला, شوي_, zyko_, 
   {{0x7f9470bd,0x8af00724,0x6b88030a,0xea580a5b}},	//   _пасх, нҗеш, ueeg, орој_, 
   {{0x6b8870be,0x8d8470bf,0xc3340302,0xdf840014}},	//   reeg, _нужд, עוץ_, _زُلی, 
   {{0x26c00006,0x6b8870c0,0x606000cf,0xbb480014}},	//   vyko_, seeg, _سۇۇل, _ہلمن_, 
   {{0x69a00490,0x6b8800c5,0x00000000,0x00000000}},	//   _कोणी, peeg, --, --, 
   {{0x66e470c1,0x2fcc525e,0x64581c1e,0x2ba80073}},	//   дома, _jleg_, štik, काळा, 
   {{0x61fc02e2,0x25b801ef,0x69a001f9,0x00000000}},	//   yopl, _popl_, _कोथी, --, 
   {{0x61fc004e,0x26c0005a,0x7c340432,0x395803b2}},	//   xopl, ryko_, _ýerü, órst_, 
   {{0x2fcc70c2,0xd38800d1,0x00000000,0x00000000}},	//   _oleg_, ﺗﻠﯩﻖ_, --, --, 
   {{0x26c000c0,0x00000000,0x00000000,0x00000000}},	//   pyko_, --, --, --, 
   {{0x61fc70c3,0xc33000cf,0x00000000,0x00000000}},	// [8280] topl, _ەەر_, --, --, 
   {{0x2fcc0276,0xe1680fb4,0x8f1c00a2,0xd7040108}},	//   _aleg_, تصره_, _onuт_, _юные_, 
   {{0x61fc70c4,0x2fcc70c5,0x2328299f,0x0ccc00cc}},	//   ropl, _bleg_, _мони_, িপুত, 
   {{0x61fc70c6,0x2fcc020c,0x00000000,0x00000000}},	//   sopl, _cleg_, --, --, 
   {{0x61fc037e,0x2fcc0175,0x00000000,0x00000000}},	//   popl, _dleg_, --, --, 
   {{0x7d1c09f3,0x7d7812fc,0xdca435dd,0xddc000bc}},	//   _úrsk, سمبر_, дшип, stož, 
   {{0x2fcc0204,0xaf0001e1,0x00000000,0x00000000}},	//   _fleg_, _òùng, --, --, 
   {{0x2fcc039a,0x6d44022c,0xdbf00213,0xfa6801a9}},	//   _gleg_, ðhar, qşün, пчоқ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x600800bc,0x0e603594,0x2fcc00a2,0x6ff4012d}},	//   kýmk, _шкун, _zleg_, rące, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x628470c7,0x06e004c5,0x395c002f,0x00000000}},	//   _opko, _যুধি, _wdvs_, --, 
   {{0x49b470c8,0x63b40363,0x8c1808a8,0xa3d009b2}},	//   ساید_, djyn, _וואי, वसन_, 
   {{0x349470c9,0x19f40014,0xc9a40902,0xdefc025c}},	//   нагр, _تِتھ_, _овче_, ċċha_, 
   {{0x628400da,0x7d08037e,0x13a4179e,0x00000000}},	//   _apko, _jyds, ونسی_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7d0828b3,0xe79401e2,0x00000000,0x00000000}},	// [8290] _lyds, _سايک, --, --, 
   {{0x764c70ca,0x2fcc0660,0x79980477,0x90e470cb}},	//   _iway, _sleg_, _javw, وسان, 
   {{0x764c006f,0x2b040316,0xdb0000e8,0x2fcc0489}},	//   _hway, _हुनु_, _mooñ, _pleg_, 
   {{0x764c70cc,0x799870cd,0x2ef407b5,0xddc001e4}},	//   _kway, _lavw, нзер, rsoŝ, 
   {{0x764c70ce,0xdcf80006,0x2fcc0af9,0x00000000}},	//   _jway, _katė, _vleg_, --, 
   {{0x29c80789,0x720400c6,0x799870cf,0x705801ee}},	//   _cúal_, _أوسم, _navw, _нагр_, 
   {{0x32000109,0x7d0803cb,0xdcf80153,0x00000000}},	//   mohy_, _cyds, _matė, --, 
   {{0x764c70d0,0x32000122,0x2fcc6085,0x6ab402e8}},	//   _oway, lohy_, _uleg_, есох, 
   {{0x764c0521,0x7d0803b2,0xfe70009a,0x00000000}},	//   _nway, _eyds, _ندل_, --, 
   {{0xbd440302,0x32000170,0xca380092,0x00000000}},	//   _لنكي, nohy_, _በባቢሎ, --, 
   {{0x764c70d1,0x386c009a,0x6f0801a9,0x7d08015d}},	//   _away, gudr_, _hyec, _gyds, 
   {{0x764c43c4,0x6f080083,0x78bc01e6,0x48780092}},	//   _bway, _kyec, ärva, _እያለሁ_, 
   {{0x0ae80502,0xd87415f6,0xbbe80014,0xddc00064}},	//   _براي_, ومیت_, _ترٕم_, luoš, 
   {{0x764c0100,0x320005da,0x59a40490,0x6b9852bb}},	//   _dway, johy_, _कोपर, _hawg, 
   {{0x764c0921,0x6b9800e8,0x6284037e,0x638400c0}},	//   _eway, _kawg, _spko, нгва, 
   {{0x764c57cb,0x7ae470d2,0x6b98406c,0x6284005a}},	//   _fway, _žiti, _jawg, _ppko, 
   {{0x764c70d3,0x23080592,0x6f080c6a,0x320003d1}},	// [82a0] _gway, ستري_, _nyec, fohy_, 
   {{0x6b9870d4,0x00000000,0x00000000,0x00000000}},	//   _lawg, --, --, --, 
   {{0x6f0870d5,0x764c70d6,0x3c380588,0xddc00327}},	//   _ayec, _zway, _oĩva_, rtoż, 
   {{0x78bc0579,0x69a01524,0x5438008f,0x6b98025c}},	//   ørvi, _कोसी, _מעטא, _nawg, 
   {{0x7d0870d7,0x764c01f0,0x975404ae,0x53a002dd}},	//   _syds, _xway, תינו_, _саяб, 
   {{0x3c3800e4,0x6b98058a,0x3d1c0073,0x00000000}},	//   _aĩva_, _aawg, मधले_, --, 
   {{0x6f0870d8,0x79980455,0x00000000,0x00000000}},	//   _eyec, _ravw, --, --, 
   {{0x799802e2,0x600802f0,0x00000000,0x00000000}},	//   _savw, kými, --, --, 
   {{0x6b9870d9,0x7d080af9,0x7b140395,0x69a000bc}},	//   _dawg, _wyds, ъдих, _कोही, 
   {{0x7d0870da,0x764c70db,0x1670020a,0x7998014f}},	//   _tyds, _rway, ҳқир, _qavw, 
   {{0x764c70dc,0x79980978,0xc2cc01e1,0x00000000}},	//   _sway, _vavw, _ọ̀fú, --, 
   {{0x7dd4026c,0x6b980198,0xb7c470dd,0x32000109}},	//   _bàsg, _gawg, троқ, zohy_, 
   {{0xcf9004ac,0xdb001bce,0xdcf80064,0x00000000}},	//   נטש_, _tooñ, _patė, --, 
   {{0x764c70de,0xceb0008d,0x00000000,0x00000000}},	//   _vway, איש_, --, --, 
   {{0x6b9801d4,0x320005da,0xe8180451,0xc9500375}},	//   _yawg, vohy_, _ڪروڙ_, _עמק_, 
   {{0x439470df,0x7dd401ab,0x764c19e1,0x34940b01}},	//   ласс, _fàsg, _tway, наҳр, 
   {{0x32005fd3,0x764c70e0,0x8c180375,0x3ea4022e}},	// [82b0] tohy_, _uway, לולי, _nrmt_, 
   {{0xe2a4022c,0xa5c002dd,0x45d4030d,0x00000000}},	//   øðan_, _көсе, _боьс, --, 
   {{0x32000851,0xc95000c8,0x3ea40036,0x7ff40330}},	//   rohy_, רמע_, _armt_, گسلا, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x320005da,0xa3e408e9,0x6b9870e1,0x2ebc227c}},	//   pohy_, _भगत_, _rawg, ्नेत, 
   {{0x6b980097,0x31340640,0xbbcc014a,0xa2b407f7}},	//   _sawg, _јевр, äänü, _ईपत्, 
   {{0x64585ef9,0x00000000,0x00000000,0x00000000}},	//   štiv, --, --, --, 
   {{0xddc002d5,0xdca00116,0x99840064,0x6a84014b}},	//   ruoš, раъи, _ruoš_, влиа, 
   {{0x6f08009a,0x222801d9,0xa3d002c3,0x9e946b89}},	//   _uyec, _رٲہی_, वसत_, _لالچ, 
   {{0xddc002d5,0x6b980009,0x8ca00150,0xa6e00174}},	//   puoš, _wawg, _مەتو, _øðin, 
   {{0x6b9870e2,0x00000000,0x00000000,0x00000000}},	//   _tawg, --, --, --, 
   {{0x59a40dad,0xe738023a,0x69a00c22,0x2ebc00cd}},	//   _कोठर, ьем_, _कोरी, ्नॊत, 
   {{0xaad803ce,0x00000000,0x00000000,0x00000000}},	//   _बेचक, --, --, --, 
   {{0x7d0470e3,0x2ba81df0,0x78c401d3,0x00000000}},	//   şise, काका, ítvá, --, 
   {{0xd624024d,0x02bc07d0,0x00000000,0x00000000}},	//   торе_, ोन्न, --, --, 
   {{0x739870e4,0x7c3c00e5,0x00000000,0x00000000}},	//   нтус_, _érre, --, --, 
   {{0x2ebc66eb,0xa20470e5,0x2d8400df,0x96b001af}},	// [82c0] ्नोत, впад, _oble_, _көрє, 
   {{0xa0a470e6,0x61442db7,0xb8080183,0x7ae4010b}},	//   казд, тежа, _ৰূপত_, _ýite, 
   {{0xd12c70e7,0xe0d00597,0xa3485740,0xfd540055}},	//   زمن_, جزء_, _озна_, cagṛ, 
   {{0x2d8470e8,0x3cb4013e,0xddcc0034,0x00000000}},	//   _able_, ғйир, żdża, --, 
   {{0x442070e9,0xc32000bd,0xaf840032,0x7dd400cf}},	//   mmi_, _ফ্রি_, ыҡта_, _làse, 
   {{0x69a0190e,0x0d80009d,0x6ff40210,0x00000000}},	//   _कोली, илчн, rąca, --, 
   {{0x91e070ea,0xca1400d1,0x22400208,0xef9000e5}},	//   _торе, _ﻳﯜﺯ_, _htkk_, _گیند, 
   {{0x442070eb,0x2d8404ac,0xd9c810dc,0x3ea40204}},	//   nmi_, _eble_, िस्ट, _trmt_, 
   {{0x442070ec,0xef9070ed,0x5f040124,0x4a500f15}},	//   imi_, _دیند, _рзаа, акыс, 
   {{0x78bc007c,0xcc300022,0x00000000,0x00000000}},	//   ärvo, ыхәы, --, --, 
   {{0x442070ee,0xdcf80aea,0xa3d0041c,0x00000000}},	//   kmi_, _matī, वसा_, --, 
   {{0x442070ef,0xdcf800e2,0xe72800e5,0x00000000}},	//   jmi_, _latī, کسپو_, --, 
   {{0x442070f0,0x8bd40375,0x645c01e3,0x56f00116}},	//   dmi_, _בואו_, _avpi, рүпс, 
   {{0x442070f1,0x09e01fbe,0xc9d000f7,0x67f4025c}},	//   emi_, _кочн, _ۅزۉب, rġja, 
   {{0x44380472,0x442070f2,0x49900244,0x335400cf}},	//   gqr_, fmi_, _ئیپر, лүнө_, 
   {{0x22400048,0x7d1c00db,0x78bc06ea,0x00000000}},	//   _btkk_, _úrsu, ørvu, --, 
   {{0x958802d3,0x8334011b,0xc7e800cf,0xb6c402dd}},	// [82d0] _ህዝቢን_, рнух, _جىين_, _сөнд, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3c3800dd,0x442070f3,0x645800d0,0x2ebc197e}},	//   _név_, bmi_, átit, ्न्त, 
   {{0x926870f4,0x442070f5,0x6f6438b7,0x00000000}},	//   _орга_, cmi_, اهشم, --, 
   {{0x645804b9,0x290001bf,0x2f88013d,0x00000000}},	//   štit, _øhav_, _җәен_, --, 
   {{0x958802d3,0x3ec4013e,0xdcf800b8,0x765c01f4}},	//   _ህዝባን_, ришҳ, _gatī, issy, 
   {{0x987c013d,0x9e800023,0x1d04004e,0x3c38013a}},	//   _oçıp_, _ሓይልና_, леши_, _cév_, 
   {{0x9588693c,0x9b900075,0x3c380129,0x00000000}},	//   _ህዝብን_, ملىت, _dév_, --, 
   {{0x98bc0270,0x765c01f5,0xdcf8002b,0x5ea001e2}},	//   katē_, jssy, _yatī, _هڅول, 
   {{0x442070f6,0x987c70f7,0x3c3870f8,0x699425ea}},	//   zmi_, _açıp_, _fév_, урих, 
   {{0x442070f9,0xd7ac0490,0xe5a40116,0x00000000}},	//   ymi_, टांच, қиви, --, 
   {{0x25a40510,0x442070fa,0x387800a3,0xe6880145}},	//   _şol_, xmi_, àrra_, ىنجى_, 
   {{0x442070fb,0x765c44b3,0xda9400ec,0x00000000}},	//   vmi_, gssy, _ٽانڊ, --, 
   {{0x5924025c,0x442070fc,0xd9402bbd,0x00000000}},	//   _རྔམས_, wmi_, _леши, --, 
   {{0x765c062c,0xdcf80055,0xf9600345,0x00000000}},	//   assy, _ratī, _بۆپێ, --, 
   {{0x442070fd,0x765c417b,0xdcf81981,0x67b81291}},	//   umi_, bssy, _satī, _سابح_, 
   {{0x442020ac,0xdcf800da,0x2e3802bd,0xe8040073}},	// [82e0] rmi_, _patī, _nèf_, रवठा_, 
   {{0x7dd400cf,0x645870fe,0x00000000,0x00000000}},	//   _màsc, átis, --, --, 
   {{0x442070ff,0x60080030,0xd12c007b,0xdcf8002b}},	//   pmi_, kýmt, أمم_, _vatī, 
   {{0x44446114,0x44201bb7,0x2e380699,0x24980109}},	//   _it_, qmi_, _bèf_, _ispm_, 
   {{0x44447100,0x600c022e,0xdd8400db,0x1fe400f1}},	//   _ht_, _dеmо, гыйп, نکړي_, 
   {{0x444445eb,0xdcf800e4,0x98bc0024,0xa034215c}},	//   _kt_, _hatĩ, lbtą_, _مىست, 
   {{0x44447101,0x9c8400f2,0xc2cc01e1,0x00000000}},	//   _jt_, اشته, _ọ̀bú, --, 
   {{0x765c0731,0x7dd400db,0x249801a6,0x44447102}},	//   yssy, _bàsc, _mspm_, _mt_, 
   {{0x44447103,0x9d447104,0x9ea801c0,0x20047105}},	//   _lt_, _безд, _яваа_, mooi_, 
   {{0x765c168c,0x20040942,0x00000000,0x00000000}},	//   vssy, looi_, --, --, 
   {{0x26e000bd,0x2498009b,0x1c442dbf,0x645806af}},	//   _গুলো_, _nspm_, _снем, âtil, 
   {{0x20045b5e,0x7e60037e,0x00000000,0x00000000}},	//   nooi_, _kvmp, --, --, 
   {{0x44440052,0x98bc7106,0x26dc00df,0x69dc0200}},	//   _at_, tatē_, ŝton_, ësec, 
   {{0x765c7107,0x44447108,0x2004017a,0x629403cb}},	//   rssy, _bt_, hooi_, dwyo, 
   {{0x444402b7,0x20040373,0xc8c455ab,0x5dc801ec}},	//   _ct_, kooi_, _موون_, _ﺒﺠﻤﻴ, 
   {{0x44447109,0x261805f9,0xd90c179e,0x765c03cd}},	//   _dt_, _मीठी_, _ویک_, pssy, 
   {{0x4444710a,0x249800d8,0x00000000,0x00000000}},	// [82f0] _et_, _espm_, --, --, 
   {{0xeff80020,0x44440375,0x00000000,0x00000000}},	//   _ገበያ_, _ft_, --, --, 
   {{0x2e38007f,0x2004017a,0xdb2003b2,0x7e640419}},	//   _sèf_, fooi_, _óræd, šipl, 
   {{0xb4d035e8,0x20040660,0x79440092,0x00000000}},	//   वनी_, gooi_, _የጠቀስ, --, 
   {{0x4444710b,0x408464ab,0xf2c405f5,0xa3d002c3}},	//   _zt_, _қурб, _төви, वसर_, 
   {{0x4444710c,0xada4710d,0x6cc4710e,0x2e38007f}},	//   _yt_, ракл, ийла, _vèf_, 
   {{0xeb98710f,0xabd46fbd,0x7c647110,0x6568000f}},	//   вий_, ициј, مايل, _ôfhe, 
   {{0x7e600109,0x00000000,0x00000000,0x00000000}},	//   _fvmp, --, --, --, 
   {{0x59a405f9,0xffb40276,0x00000000,0x00000000}},	//   _कोहर, _уйтэ, --, --, 
   {{0xe8847111,0x68240064,0xa9c000db,0x7c380174}},	//   агоп, _jųdv, تۅتۉ, ýarø, 
   {{0x6d407112,0xdbdc01a8,0x88240092,0x00000000}},	//   _ifla, _tíðn, ተፈቀደ, --, 
   {{0x2d200490,0x44447113,0x645806af,0x00000000}},	//   मधील_, _rt_, âtim, --, 
   {{0x44447114,0x00000000,0x00000000,0x00000000}},	//   _st_, --, --, --, 
   {{0xe4d87115,0xe5a47116,0xa4444cd0,0xdcf800e4}},	//   پورت_, шиги, ингд, _satĩ, 
   {{0x44447117,0xa5087118,0x63787119,0x29000022}},	//   _qt_, тева_, ксар_, _âha_, 
   {{0x987800df,0x6264003b,0x00000000,0x00000000}},	//   _סאפט, ивба, --, --, 
   {{0x4444711a,0xe618711b,0x6d40711c,0x7f440309}},	// [8300] _wt_, _иди_, _ofla, ñiqm, 
   {{0xe4740276,0x6294015d,0xddc00064,0x65b002f2}},	//   _кумэ, rwyo, kroš, _بیسڕ, 
   {{0x4444711d,0x7dd400a3,0x2a6c00d0,0x20040af9}},	//   _ut_, _nàsa, hreb_, tooi_, 
   {{0x6d40711e,0xddc00029,0x3cec0037,0x23c80210}},	//   _afla, droš, _अइबे_, _रविद, 
   {{0x20041af3,0x6d400332,0x2b4c007c,0x00000000}},	//   rooi_, _bfla, dbec_, --, 
   {{0x2b4c074d,0x7dd408c2,0x20040607,0xe4000220}},	//   ebec_, _bàsa, sooi_, _ءﺗﯩﭙ, 
   {{0xa3a8012d,0x1fb4011c,0x00000000,0x00000000}},	//   _खफा_, _ксар, --, --, 
   {{0x6d40711f,0xdcf801d5,0xdd9000e5,0x6aac01ef}},	//   _efla, _یراش_, _ڈور_, _šafa, 
   {{0x2a6c7120,0xdd907121,0x6d400368,0xfd7801d9}},	//   greb_, _وور_, _ffla, _مشاں_, 
   {{0x4e78025f,0x7c780020,0x696802d3,0x7dd40e89}},	//   _באמצ, ከተለው_, _ተበግሶ_, _fàsa, 
   {{0x8c40014b,0x00000000,0x00000000,0x00000000}},	//   _дехе, --, --, --, 
   {{0xcb040451,0x61e8007f,0x00000000,0x00000000}},	//   _ھيون_, čfly, --, --, 
   {{0x6b8c0428,0x867402bf,0xcb040451,0x6d40035a}},	//   _ñaga, оляє, _پيون_, _yfla, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd3787122,0xb4d07123,0xdbdc08a5,0xa3d007b6}},	//   кча_, वने_, _díön, वसं_, 
   {{0x3bd800e8,0xf2c401c6,0xa5c008a5,0x00000000}},	//   _féqe_, бөги, _þóno, --, 
   {{0xdb08068c,0x8b54010f,0x548c0023,0x00000000}},	// [8310] ïnèr, ייןס_, _ምፍራህ_, --, 
   {{0x9128075e,0xf59400c6,0xd6f8037e,0xd1b87124}},	//   نساق_, _الدج, ndキ_, خارا_, 
   {{0x388c013f,0xd1b804d3,0xed5801ec,0x00000000}},	//   _fɛre_, _یاسا_, қой_, --, 
   {{0x6d4004cc,0x7dd401ab,0x439401fe,0xa3d000cd}},	//   _sfla, _ràsa, _даюс, वसः_, 
   {{0x6d400730,0x7dd400a3,0x27f001d3,0xd1387125}},	//   _pfla, _sàsa, ézni_, _ахб_, 
   {{0x7dc4515c,0x2b900051,0x0458072d,0x8d8407a5}},	//   قتىك, _ạc_, _حجیت_, рудд, 
   {{0x15842e56,0x98bc0024,0xcf98041b,0x00000000}},	//   ﻪﺗﺘﯩ, matė_, _ија_, --, 
   {{0x9ed441fd,0x2a6c7126,0xc4f808a8,0x7c945230}},	//   рмәт_, treb_, יזוי_, تشها, 
   {{0x2b4c7127,0x00000000,0x00000000,0x00000000}},	//   rbec_, --, --, --, 
   {{0x8d740131,0x6d407128,0xddc02a25,0x2a6c031c}},	//   _خارا, _ufla, proš, rreb_, 
   {{0x46e0012c,0x7ccc0171,0x00000000,0x00000000}},	//   _पेजह, _pērš, --, --, 
   {{0xa8840220,0x00000000,0x00000000,0x00000000}},	//   _ۇلتى, --, --, --, 
   {{0xe9a4010b,0x7ccc00e2,0xaa440137,0x661c002f}},	//   _галп, _vērš, _انتى, _phpk, 
   {{0x6018013a,0x15400150,0x00000000,0x00000000}},	//   _důmy, зерм, --, --, 
   {{0xe1f8036b,0x64a40801,0x07a421f3,0x888001d3}},	//   ҳга_, щава, _ҳақн, _بیجن, 
   {{0xe2987129,0xc8c40014,0xe7300035,0x05a8000d}},	//   лаб_, _موڈن_, _عصب_, _छोरब, 
   {{0xe1f8712a,0xa1884530,0x00000000,0x00000000}},	// [8320] гга_, лбаа_, --, --, 
   {{0xdef800fb,0xa6e00162,0x00000000,0x00000000}},	//   һыл_, øðub, --, --, 
   {{0x0028004b,0x00000000,0x00000000,0x00000000}},	//   لګرو_, --, --, --, 
   {{0x4424712b,0x78bc712c,0x5bb40073,0x1b0c0154}},	//   _òm_, ärvi, _आचेव, াইতে_, 
   {{0xd00c712d,0xfe7800d1,0xbb9002dd,0x00000000}},	//   رله_, рүз_, _ﺒﺄﻨﻪ_, --, 
   {{0x3d2c013f,0xe19400a8,0x00000000,0x00000000}},	//   tɛw_, _урмэ, --, --, 
   {{0x29c80005,0xdf481867,0xe0d80816,0xa114009f}},	//   _lúas_, _مؤذن_, _свв_, _طورت, 
   {{0xe8e4038f,0x3d2c013b,0x69dc036e,0x3ce001e4}},	//   _སྟེག, rɛw_, ësen, ŝivo_, 
   {{0x26dc00df,0x00000000,0x00000000,0x00000000}},	//   ŝtoj_, --, --, --, 
   {{0x984847fa,0x00000000,0x00000000,0x00000000}},	//   ляма_, --, --, --, 
   {{0xf8b805f5,0xcd3401d9,0x00000000,0x00000000}},	//   рөл_, _آمت_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb4d00a28,0x657c0055,0x26180073,0xb9e400cf}},	//   वन्_, _bcph, _मीही_, _وتتۇ, 
   {{0x29c80f71,0xd1b802d3,0x6370022e,0x6f0c0ba1}},	//   _dúas_, ሲታት_, _sаnа, üaci, 
   {{0x7e64000a,0x69a0712e,0xd7e40111,0xa2700092}},	//   šiph, _कोटी, _гіпо, _እርከን_, 
   {{0x7bc00399,0x6f0c0210,0x00000000,0x00000000}},	//   njmu, żaci, --, --, 
   {{0x429402d3,0x82f800c6,0x00000000,0x00000000}},	// [8330] _ምርኢት_, مركز_, --, --, 
   {{0x94840150,0x00000000,0x00000000,0x00000000}},	//   _лымд, --, --, --, 
   {{0xcee80502,0x9324712f,0x6568000f,0x5064014b}},	//   گران_, _گردن, _ôfha, стза, 
   {{0x9f4405c7,0x00000000,0x00000000,0x00000000}},	//   onoù_, --, --, --, 
   {{0x9f440ad3,0xcee87130,0x9324042a,0x00000000}},	//   nnoù_, دران_, _دردن, --, 
   {{0xdcf80166,0x00000000,0x00000000,0x00000000}},	//   _antı, --, --, --, 
   {{0x59a40316,0x00000000,0x00000000,0x00000000}},	//   _कोइर, --, --, --, 
   {{0x2bc8010b,0xaa440022,0xfe5404f2,0x4fc44c91}},	//   рлип_, оеил, _کیوب_, _усга, 
   {{0xe9d87131,0xffb40304,0x00000000,0x00000000}},	//   ики_, _эйтэ, --, --, 
   {{0x29c8172e,0x7bc00218,0xa9680640,0x984c03e0}},	//   _rúas_, ajmu, јина_, _ağın_, 
   {{0x29c836ed,0x9f4405c7,0x6fdc0073,0x00000000}},	//   _súas_, enoù_, _मतां, --, 
   {{0x29c804d4,0x00000000,0x00000000,0x00000000}},	//   _púas_, --, --, --, 
   {{0x91f80d2c,0xf40000bd,0x9f4405c7,0x7f440bf1}},	//   ्वाज_, ্ষার_, gnoù_, ñiqi, 
   {{0xb864004b,0x6b883690,0x69a003ba,0x7e6400e4}},	//   _ځايو, lfeg, _कोची, áipi, 
   {{0xd4640276,0xea6400e5,0xd4a001d5,0xf9540354}},	//   жисе_, _اپڈی, мирй, _хĕсм, 
   {{0x29c8172e,0x6b887132,0x3cec00af,0x2aa800d0}},	//   _túas_, nfeg, _अइसे_, _kĺb_, 
   {{0xb3880023,0x970000d1,0x6d900419,0x00000000}},	// [8340] _ምጽዋዕ_, _يېپى, _kľač, --, 
   {{0x21680131,0x69c07133,0x6e20045a,0xd1b80240}},	//   рижи_, njle, _nhlb, ሲታቱ_, 
   {{0xdde81077,0x6aa802d2,0x00000000,0x00000000}},	//   یرته_, hvef, --, --, 
   {{0x6e207134,0x6008005b,0x9ea80120,0x59a43be5}},	//   _ahlb, шнем_, ивеа_, _कोईर, 
   {{0xf4f800e5,0xde940127,0x00000000,0x00000000}},	//   _نویں_, تجاب, --, --, 
   {{0x5bd000dc,0xe048007b,0x9c447135,0x00000000}},	//   तस्व, _نشره_, охил, --, 
   {{0xaff4066d,0xd00c00cf,0x00000000,0x00000000}},	//   _کہنا_, رلۇ_, --, --, 
   {{0xd00402de,0xd24c1973,0xdc280214,0x44fc0154}},	//   _десе_, _سنہ_, جسته_, _ইরাক_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x670c2aa1,0xddc0068f,0x6b880421,0x6e2001ab}},	//   _सड़क_, społ, afeg, _ghlb, 
   {{0x2050069c,0x1d087136,0xc8c40014,0x00000000}},	//   _ዝነበረ, _тежи_, ٲوُن_, --, 
   {{0xc8c40014,0x6e2000d7,0x8d5c0092,0x00000000}},	//   زوُن_, _zhlb, ደናቂው_, --, 
   {{0x1b0c009e,0x9f440165,0x6fe80327,0x95c800d8}},	//   াইহে_, unoù_, _རཏྣའ, аува_, 
   {{0x9f44030a,0x00000000,0x00000000,0x00000000}},	//   rnoù_, --, --, --, 
   {{0xd7f80153,0x6fdc0f4a,0x00000000,0x00000000}},	//   _вуп_, पसमू, --, --, 
   {{0x78bc0254,0x00000000,0x00000000,0x00000000}},	//   ärvu, --, --, --, 
   {{0xb27407d6,0x248c013f,0xd1382bbd,0xd14806c2}},	// [8350] ялаш, _ɔmmɔ_, ахе_, لشان_, 
   {{0x7dd401c3,0x472401d9,0xd0a80124,0xb598009f}},	//   _bàsm, _تر٘ٲ, итед_, _اَدا_, 
   {{0x395c007f,0x98bc002b,0x00000000,0x00000000}},	//   _mevs_, datī_, --, --, 
   {{0x395c05d5,0x6aa801bf,0x42940150,0x00000000}},	//   _levs_, yvef, _ﺗﻴﯩﭙ, --, 
   {{0x05740cbb,0x00000000,0x00000000,0x00000000}},	//   _عاید, --, --, --, 
   {{0x270801dc,0x395c7137,0x7dd401ab,0x72047138}},	//   ờng_, _nevs_, _fàsm, _روزم, 
   {{0x6b8802fa,0xc5f4008d,0x8558011a,0x00000000}},	//   tfeg, ודס_, חשוב_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xab6400db,0x6b887139,0x8d840b01,0x00000000}},	//   _aqüí, rfeg, _мужд, --, 
   {{0xe9d8713a,0x395c003e,0x4dd425f4,0x6e20009a}},	//   ско_, _cevs_, _بترس, _uhlb, 
   {{0x395c579b,0xe7385393,0x6844713b,0xe3c04dd9}},	//   _devs_, йен_, янна, lnış_, 
   {{0x205002d3,0x00000000,0x00000000,0x00000000}},	//   _ዝነብረ, --, --, --, 
   {{0x68e00175,0x00000000,0x00000000,0x00000000}},	//   szld, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x23d40a0e,0x7cfc0166,0x00000000,0x00000000}},	//   пцар, _tөre, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6568002d,0x86f4009f,0x4ad807b7,0x00000000}},	// [8360] _ôfho, _آڻجا, यनिव, --, 
   {{0xe57817a0,0x3cec007d,0x644c713c,0x00000000}},	//   _узо_, _अइले_, ppbi, --, 
   {{0xe3d400f2,0x923000db,0x00000000,0x00000000}},	//   _فتحع, رىمش, --, --, 
   {{0x660c022a,0x69dc0200,0x7d040205,0x00000000}},	//   lobk, ësej, şisk, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x63a43a97,0x9254023b,0xe19401c6,0x00000000}},	//   _hakn, _хаёт_, _эрмэ, --, 
   {{0x63a4713d,0x61ec713e,0x49080f44,0x395c713f}},	//   _kakn, _imbl, _ठुलो_, _revs_, 
   {{0x8fa07140,0x395c00d7,0x4fa0011c,0x00000000}},	//   _пасе, _sevs_, _писв, --, 
   {{0x7f440789,0x3d180037,0x00000000,0x00000000}},	//   ñiqu, _फरके_, --, --, 
   {{0xdca47141,0x63a47142,0x0d800fbe,0x1b0c0154}},	//   _нази, _lakn, _плун, াইলে_, 
   {{0x38c87143,0x660c0050,0x00000000,0x00000000}},	//   زادی_, dobk, --, --, 
   {{0xfd6800c7,0xec34006c,0xd0f4011a,0x4c38011a}},	//   _nosẽ, _قولگ, למית_, _התאב, 
   {{0xda641001,0x61ec7144,0xc6f80b7e,0xdab84fca}},	//   _راشي, _ombl, знях_, _دهشت_, 
   {{0x78bc0267,0x98bc00e4,0x34940024,0x660c6f19}},	//   ärvs, hatĩ_, магр, gobk, 
   {{0x63a47145,0x46a400c7,0x98bc0022,0x9848004e}},	//   _bakn, _ҧшьб, katĩ_, _уяла_, 
   {{0x63a405b1,0xddc00210,0x00000000,0x00000000}},	//   _cakn, groź, --, --, 
   {{0x63a43c0e,0x00000000,0x00000000,0x00000000}},	// [8370] _dakn, --, --, --, 
   {{0xd1381620,0x63a4035a,0x657801ab,0xc0bc0092}},	//   сха_, _eakn, òtht, _ታተመ_, 
   {{0x63a4011f,0xf8dc4196,0x00000000,0x00000000}},	//   _fakn, मनिय, --, --, 
   {{0xc1047146,0x63a40369,0x0874008f,0x6fb8030d}},	//   روني, _gakn, לעבט_, югер_, 
   {{0x6da4006c,0x764c0a73,0xada47147,0x776c0009}},	//   дила, _jtay, далл, _mdax, 
   {{0x764c01c8,0x2d807148,0x63a402f0,0x00000000}},	//   _mtay, ühe_, _zakn, --, 
   {{0x63a47149,0xdca006bb,0xeba400d4,0x00000000}},	//   _yakn, ващи, _åøke_, --, 
   {{0x776c3d27,0x660c01f7,0x764c714a,0x04dc011a}},	//   _ndax, zobk, _otay, מקול, 
   {{0x764c0230,0x61ec0076,0xae046911,0x00000000}},	//   _ntay, _ymbl, _قورى, --, 
   {{0x61ec0175,0x776c06be,0xbca80137,0x00000000}},	//   _xmbl, _adax, زدۉك_, --, 
   {{0x764c714b,0x7a8400f2,0x9ac801d3,0x00000000}},	//   _atay, وشیم, مدیہ_, --, 
   {{0x764c04ba,0x9b0c0521,0xee700023,0x00000000}},	//   _btay, ịhịa_, _ብሰንኩ_, --, 
   {{0x4ab00228,0xfd6800e4,0x1fc8009e,0x63a4714c}},	//   _чөйр, _rosẽ, লোকস, _rakn, 
   {{0x63a42d62,0x3c3800c7,0xc984013e,0xa29800b7}},	//   _sakn, _hũva_, _худи, _ወያኔን_, 
   {{0x63a4714d,0x660c05dd,0x764c714e,0x78480118}},	//   _pakn, robk, _etay, _pěve, 
   {{0x2284714f,0x61ec0175,0x660c02f0,0x676401d9}},	//   tôk_, _smbl, sobk, _کُکل, 
   {{0x63a47150,0x98bc0022,0x6604011c,0x7d040205}},	// [8380] _vakn, vatĩ_, _опиа, ğisi, 
   {{0x63a4020c,0x7d0430a8,0x660c0009,0x00000000}},	//   _wakn, şisi, qobk, --, 
   {{0x63a47151,0x55b8011a,0x98bc00c7,0x3e600248}},	//   _takn, _ומיו, tatĩ_, _ẹ̀kà_, 
   {{0xbb5804ce,0x00000000,0x00000000,0x00000000}},	//   _cのlt, --, --, --, 
   {{0x5398025d,0x764c01d5,0x15e402dd,0x98bc0022}},	//   _ויכו, _xtay, _ﺍﺑﺪﻩ, ratĩ_, 
   {{0x61ec7152,0x7ae400ee,0xd6f8037e,0x00000000}},	//   _umbl, _ýiti, feオ_, --, 
   {{0x61fc007c,0x00000000,0x00000000,0x00000000}},	//   mnpl, --, --, --, 
   {{0xdb580816,0xda6401e2,0x00000000,0x00000000}},	//   цюк_, واخي, --, --, 
   {{0x1ea87153,0x9d441d37,0x61fc7154,0x00000000}},	//   _بازي_, _жезд, onpl, --, 
   {{0x61fc143a,0xa29802d3,0x764c7155,0x00000000}},	//   nnpl, _ወያነን_, _rtay, --, 
   {{0x764c7156,0x52b800cd,0x00000000,0x00000000}},	//   _stay, _ईप्स, --, --, 
   {{0x25b807ab,0xdd900133,0x61fc002f,0xdca401f0}},	//   _anpl_, _سوڵ_, hnpl, _наҷи, 
   {{0x3dcc009a,0x7df40153,0x4a5000c0,0x00000000}},	//   _kodw_, _tęsė, _акіс, --, 
   {{0x7dd40228,0xdbd40139,0x61fc01f5,0x6abc0158}},	//   _bàsi, _bäçl, jnpl, åsfe, 
   {{0x7d1c0158,0x8978011a,0x98bc0064,0x93a43947}},	//   _ørsd, _ורוצ, matį_, мшад, 
   {{0x43947157,0x6aac0b4b,0x764c04ba,0x34940454}},	//   касс, _šafi, _ttay, маҳр, 
   {{0x36d4014b,0x61fc032e,0x00000000,0x00000000}},	// [8390] _чопр, fnpl, --, --, 
   {{0xdbd4007d,0xd6247158,0x00000000,0x00000000}},	//   _hääl, _تعبي, --, --, 
   {{0x15b042c6,0x67f40010,0x00000000,0x00000000}},	//   _كەڭس, lšja, --, --, 
   {{0x61fc7159,0xdbd46775,0x00000000,0x00000000}},	//   anpl, _jääl, --, --, 
   {{0xde4400d1,0x00000000,0x00000000,0x00000000}},	//   ۈرۈۋ, --, --, --, 
   {{0xfe702814,0x91e03507,0x660002d2,0x00000000}},	//   شده_, _गतिज_, _íokt, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x70581171,0x00000000,0x00000000,0x00000000}},	//   _маҳр_, --, --, --, 
   {{0xeab000c6,0x511c000d,0x00000000,0x00000000}},	//   اعب_, _भरुआ_, --, --, 
   {{0x2fcc715a,0xa9a4009d,0x28e800cf,0x1a000150}},	//   _hoeg_, хиод, здоп_, лпым, 
   {{0xbca4038b,0x92f800eb,0x00000000,0x00000000}},	//   _لملي, _আরোপ_, --, --, 
   {{0x2918198e,0x2ca40472,0xe738715b,0xddc0012c}},	//   āsa_, _isld_, яем_, dpoř, 
   {{0x2fcc715c,0x61fc017a,0x784801ef,0xa3ac03ce}},	//   _moeg_, ynpl, _pěvc, ओएस_, 
   {{0x64a4715d,0xda6c1e24,0x00000000,0x00000000}},	//   нага, _اُو_, --, --, 
   {{0xb8f403f4,0x00000000,0x00000000,0x00000000}},	//   _সে_, --, --, --, 
   {{0x61fc045a,0xa684003b,0x00000000,0x00000000}},	//   wnpl, _злид, --, --, 
   {{0x96b001af,0x00000000,0x00000000,0x00000000}},	// [83a0] _йөрє, --, --, --, 
   {{0x3ea4009f,0xe04400db,0x00000000,0x00000000}},	//   _rsmt_, енжи, --, --, 
   {{0x2fcc715e,0x61fc26bc,0x54640153,0x00000000}},	//   _boeg_, rnpl, _паэм_, --, 
   {{0x2250002d,0x245c0118,0xe80400bc,0x83d4000d}},	//   ppyk_, mům_, रवटा_, _धकिआ, 
   {{0x2fcc0007,0x245c0316,0x03040037,0x00000000}},	//   _doeg_, lům_, _रखिह_, --, 
   {{0x27f0020b,0x3d940d97,0x98bc0356,0xa0681a5c}},	//   _lmyn_, тикр, nctă_, _нага_, 
   {{0x2fd0006a,0x2fcc004e,0x245c012c,0x27f00432}},	//   êngê_, _foeg_, nům_, _omyn_, 
   {{0x2d8401ab,0x2240715f,0x00000000,0x00000000}},	//   _ecle_, _kukk_, --, --, 
   {{0xd0047160,0x245c0118,0x00000000,0x00000000}},	//   _чете_, hům_, --, --, 
   {{0x8e940bd9,0x245c012c,0x22400694,0x2ca80034}},	//   _אדמו_, kům_, _mukk_, łada_, 
   {{0x22407161,0xdbd40664,0xdb00067c,0x245c0118}},	//   _lukk_, _pääl, _taoï, jům_, 
   {{0x1ae47162,0x245c00bc,0x92f803d4,0x00000000}},	//   _поем, dům_, _আৰোপ_, --, 
   {{0x22407163,0xdbd4007c,0x00000000,0x00000000}},	//   _nukk_, _vääl, --, --, 
   {{0x2614003a,0x27f0015d,0xddc00118,0x387801ab}},	//   dæos_, _emyn_, hrož, àrrs_, 
   {{0xdbd4049b,0xc8b05706,0xddc009a8,0xdb007164}},	//   _tääl, _مصيب, krož, _maoí, 
   {{0x82347165,0x04c8188d,0x2240143a,0x69dc036e}},	//   ۇرلا, روقي_, _bukk_, ësev, 
   {{0x1b0c00bd,0xdc106656,0x2fcc0042,0x46680006}},	// [83b0] াইকে_, nğın, _roeg_, _прэм_, 
   {{0x22400109,0x5064322e,0x2fcc7166,0xdb000332}},	//   _dukk_, етда, _soeg_, _naoí, 
   {{0x2fcc00c5,0x245c0118,0x00000000,0x00000000}},	//   _poeg_, cům_, --, --, 
   {{0x22401574,0xddc07167,0x7f440113,0xd98c0150}},	//   _fukk_, grož, ñiqp, _ﺒﻤﻔﻬ_, 
   {{0x2fcc225e,0xf8dc00cd,0x00000000,0x00000000}},	//   _voeg_, मनुप, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2fcc7168,0xdb000332,0xddc00427,0x0c904710}},	//   _toeg_, _daoí, brož, ادتگ, 
   {{0xeb987169,0x4034716a,0x2240020b,0xdf700e4a}},	//   фии_, _бесс, _yukk_, _نگهب, 
   {{0x3f9801d9,0x245c0118,0x5ba400cf,0xaa280139}},	//   _سپٕد_, zům_, ткым_, _şiñä_, 
   {{0x3200026c,0x00000000,0x00000000,0x00000000}},	//   nnhy_, --, --, --, 
   {{0x6568045f,0xdb243c73,0x00000000,0x00000000}},	//   _ôfhi, _یومی, --, --, 
   {{0x39400276,0x78bc0267,0x245c0118,0xe6444130}},	//   _şist_, årva, vům_, кемп, 
   {{0x7d04716b,0x79a4013d,0x00000000,0x00000000}},	//   şist, _әрче, --, --, 
   {{0xd940716c,0x68ec0b45,0x245c012c,0x9f44032e}},	//   _кеши, _ƙadd, tům_, hnoð_, 
   {{0xa80406bb,0x2bc4716d,0x224061df,0xdb0008a5}},	//   _изкл, वापा, _sukk_, _hnoð, 
   {{0x245c012c,0x7dd401ab,0x2240716e,0xdb080790}},	//   rům_, _hàst, _pukk_, çiçe, 
   {{0x6144026a,0x6b8c0124,0x245c00bc,0x216801d5}},	// [83c0] веза, _ñagu, sům_, дизи_, 
   {{0xa32009bb,0x3eb80427,0x245c0118,0x00000000}},	//   _मरीज_, _črt_, pům_, --, 
   {{0xa508716f,0x7dd400f7,0x5574011a,0x1f640395}},	//   _цена_, _màst, _בעין_, вкем, 
   {{0x44447170,0x2498009a,0x9e645734,0x22407171}},	//   _iu_, _ippm_, ناتن, _tukk_, 
   {{0x2bc40882,0x224001ab,0x73c001e0,0x2214014b}},	//   वाना, _uukk_, _уҡта, _афвр, 
   {{0x249805b1,0x7dd47172,0x61440063,0x753800ee}},	//   _kppm_, _nàst, _јева, _ýazý, 
   {{0x3dc80032,0x8c60010b,0xddc07173,0xa1146216}},	//   _үҫеп_, атыд, prož, _شورت, 
   {{0x7c80001f,0x00000000,0x00000000,0x00000000}},	//   _የክልል_, --, --, --, 
   {{0x2498020b,0xdb000077,0x00000000,0x00000000}},	//   _lppm_, _taoí, --, --, 
   {{0x7dd400cf,0x4e24014b,0x00000000,0x00000000}},	//   _càst, _аоун_, --, --, 
   {{0x38347174,0xddc0068f,0xd90c7175,0xc300015b}},	//   лнор, zpoś, غیب_, ্ধটি_, 
   {{0x7e60014b,0x16700022,0xe9800124,0x00000000}},	//   _kwmp, ақир, ақән, --, 
   {{0x249804cc,0x7dd40137,0xdb0002d2,0xddc0031c}},	//   _appm_, _fàst, _gnoð, kroż, 
   {{0x7dd4004e,0xceb00375,0x36d401e0,0x09e00114}},	//   _gàst, ביש_, _ҡойр, _вољн, 
   {{0x44447176,0x65780597,0x48a47177,0x5884035b}},	//   _cu_, ótha, _атым_, _рыла, 
   {{0xfa0403d4,0x249805b1,0x4908012c,0x2bc4043e}},	//   _উঠিল_, _dppm_, _ठुटो_, वाया, 
   {{0x44447178,0x7204009a,0xd6d800d4,0xe27400cf}},	// [83d0] _eu_, هورم, _іти_, лктө, 
   {{0x44447179,0x41740131,0xddc00034,0x9f44030a}},	//   _fu_, لامس, groż, mioù_, 
   {{0x4444717a,0x9f4403bd,0x823400c6,0x2bc404e4}},	//   _gu_, lioù_, شركا, वामा, 
   {{0x394c009a,0xffb401c0,0x7e600042,0x2cb802f0}},	//   hcds_, ийхэ, _bwmp, _čsd_, 
   {{0x4444717b,0x9f4403bd,0x7e600368,0xddc0202a}},	//   _zu_, nioù_, _cwmp, broż, 
   {{0x4444717c,0x7e600142,0xaab005dc,0x7cfc0139}},	//   _yu_, _dwmp, जिसक, _tөrl, 
   {{0x9f4403bd,0x4444717d,0xa9a404a9,0xdb0002d2}},	//   hioù_, _xu_, қинд, _snoð, 
   {{0x6a8439f6,0x6f0800cf,0x9f440156,0xddc000df}},	//   глиа, _txec, kioù_, mpoŝ, 
   {{0x7e6000a9,0x9f440165,0x2bc4202e,0x9e940137}},	//   _gwmp, jioù_, वाबा, _مالچ, 
   {{0x9f440489,0xff0402e8,0xfe74717e,0xe8c80120}},	//   dioù_, _тясн, _түш_, егол_, 
   {{0x6d40717f,0x7c847180,0xddc001e4,0x00000000}},	//   _igla, _вуче, npoŝ, --, 
   {{0x7dd40ffb,0x9f4405c7,0x3a2400cf,0x00000000}},	//   _fàss, fioù_, лмөг, --, 
   {{0x9f440165,0xddc000e2,0x370432c0,0x69dc036e}},	//   gioù_, lsoš, ачёв, ëses, 
   {{0x44447181,0xdc540014,0xddc001e4,0xf954030d}},	//   _pu_, _شرۅک, kpoŝ, _вĕрм, 
   {{0x44447182,0x67e4033f,0xbf2007af,0x00000000}},	//   _qu_, _pójd, _बर्न_, --, 
   {{0x44447183,0x9f440165,0x00000000,0x00000000}},	//   _vu_, bioù_, --, --, 
   {{0x6d407184,0x44447185,0xca141c5c,0x53900b82}},	// [83e0] _ogla, _wu_, ﻳﺘﺎ_, _ምጽዋት_, 
   {{0x6d407186,0x2a6c015d,0x00000000,0x00000000}},	//   _ngla, iseb_, --, --, 
   {{0x44447187,0xf1a801b9,0x249804cc,0x7e60015d}},	//   _uu_, ضاله_, _uppm_, _swmp, 
   {{0xd12c7188,0x6d407189,0x2a6c718a,0xa2e41086}},	//   سمن_, _agla, kseb_, _бомд, 
   {{0x4420718b,0x4e900451,0x9f440af9,0x00000000}},	//   mli_, مشور, lhoë_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4420718c,0x718822f7,0x9f4403bd,0x1b0c03d4}},	//   oli_, _шарҳ_, zioù_, াইছে_, 
   {{0x4420718d,0x3a74718e,0x6d40718f,0x7e60015d}},	//   nli_, алир, _egla, _twmp, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9f4403bd,0x39147190,0x79f40107,0x00000000}},	//   vioù_, импр, рзох, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x44207191,0x707802d3,0x6d400b3d,0x37f80276}},	//   jli_, _ብቐሊሉ_, _zgla, темэ_, 
   {{0x6d4000ee,0xcb040451,0x9f44030a,0x4bf80a7c}},	//   _ygla, _ٽيون_, uioù_, _אלאס, 
   {{0x44207192,0x9f4407e4,0xceb0010f,0xa8f40133}},	//   eli_, rioù_, זיש_, اتیڤ, 
   {{0x44207193,0x499004fb,0x9f44030a,0x00000000}},	//   fli_, _ایپر, sioù_, --, 
   {{0x44207194,0xb3547195,0x487000db,0x799803ac}},	//   gli_, ркаш, _ادوس, _hbvw, 
   {{0xb6c47196,0x2bc41276,0x00000000,0x00000000}},	// [83f0] _төнд, वाता, --, --, 
   {{0x273c0208,0xddc0008f,0xf4d80408,0x110800d1}},	//   _ắng_, tpoŝ, _амош_, ىغاي_, 
   {{0x63ac005b,0x8b000118,0x2f8800c7,0x7e7c00de}},	//   önnä, ěřil, кәан_, _ārpa, 
   {{0x6d407197,0xb3840209,0xddc00115,0x2a6c03cb}},	//   _sgla, _өлүл, rpoŝ, yseb_, 
   {{0x6d400280,0x85040424,0x78b80064,0x00000000}},	//   _pgla, _نوین, _lrvv, --, 
   {{0x7dd400f7,0x41e412fa,0x5e54007b,0xb7fc00fe}},	//   _bàsq, _ліса, جلوس_, ীতিত_, 
   {{0x463c10df,0x6d407198,0x00000000,0x00000000}},	//   געגע, _vgla, --, --, 
   {{0x2a6c007d,0x799803ac,0x2bc4012c,0x7c64007b}},	//   tseb_, _abvw, वाधा, حاول, 
   {{0x9f6005ac,0x7d1c01bf,0x00000000,0x00000000}},	//   øvåg_, _ørsn, --, --, 
   {{0x6d401326,0x00000000,0x00000000,0x00000000}},	//   _ugla, --, --, --, 
   {{0x2bc408a3,0xb7c4007f,0xa32000e1,0x297c0023}},	//   वादा, _maãƒ, _मर्ज_, _ጨናፍር_, 
   {{0x44207199,0x3958719a,0x98bc0393,0x3878655d}},	//   xli_, ırsa_, nctę_, árra_, 
   {{0x4420719b,0x7998035a,0x07a40124,0x85b40139}},	//   vli_, _fbvw, ааҟн, бәнч, 
   {{0x4420719c,0x67e40210,0x00000000,0x00000000}},	//   wli_, _bójc, --, --, 
   {{0x64a4719d,0x2934008f,0xf1c8043e,0x00000000}},	//   шава, _דאַן_, रानन, --, 
   {{0x4420719e,0xe7380276,0x232800c2,0x9f440af9}},	//   uli_, _ией_, воби_, rhoë_, 
  
   {{0xade43eaf,0x00000000,0x00000000,0x00000000}},	// [8400] कसान_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4420719f,0x161c28d4,0x2408003b,0x00000000}},	//   pli_, _मीटर_, _анни_, --, 
   {{0x442071a0,0xca140952,0x54341617,0xdef864c2}},	//   qli_, ﺰﺩﺍ_, _پرپر, кыл_, 
   {{0x7e9871a1,0x7cfc0139,0x00000000,0x00000000}},	//   انتر_, _tөrk, --, --, 
   {{0x4dd02928,0x205400fb,0x8d600114,0x00000000}},	//   قتىس, _втар, овље, --, 
   {{0xa03404b3,0xa06801f0,0x622400d1,0x91000150}},	//   _نىست, _шава_, _مىڭل, _дпре, 
   {{0x2d9003ee,0x00000000,0x00000000,0x00000000}},	//   _özen_, --, --, --, 
   {{0xd90c0133,0x00000000,0x00000000,0x00000000}},	//   ژیت_, --, --, --, 
   {{0x2a7801d3,0x27e80327,0x68ec01ef,0x13d0000d}},	//   ásba_, _ċana_, _řada, _सव्भ, 
   {{0x68ec03f9,0x6bd40014,0x00000000,0x00000000}},	//   _ƙada, _گتٕر, --, --, 
   {{0x947401b9,0x2004005b,0x00000000,0x00000000}},	//   یدزا, nnoi_, --, --, 
   {{0x20040093,0xe8f401e0,0xf1c811a6,0x00000000}},	//   inoi_, иһә_, रामन, --, 
   {{0xc8c403e6,0xde500092,0xb0e00248,0x00000000}},	//   _چوون_, _ይደነግ, _òógù, --, 
   {{0xd43400c6,0xb4c002ab,0x644800d8,0x09e00798}},	//   لعرب, ंमे_, _éfil, _фојн, 
   {{0xd7f824ce,0xd6d8020a,0x20040200,0x03c43866}},	//   _шул_, _ато_, jnoi_, осум, 
   {{0xfdf8000d,0x984c0205,0x67e4012d,0x6f0c012d}},	// [8410] ्चास_, _işın_, _wójc, żacz, 
   {{0x798871a2,0x00000000,0x00000000,0x00000000}},	//   ngdw, --, --, --, 
   {{0xcfa4322e,0x80a4007b,0x00000000,0x00000000}},	//   ишди, يمكن, --, --, 
   {{0x667002f2,0x6ff40210,0x00000000,0x00000000}},	//   _بگێر, lącz, --, --, 
   {{0x2bc471a3,0xeb98036b,0x67e403b2,0x4ea43866}},	//   वासा, ҳий_, _jója, рреа, 
   {{0x20040083,0xada454a0,0x6da471a4,0xa2803cc4}},	//   anoi_, сакл, сика, _ریمو, 
   {{0xeb9871a5,0x7d1c01bf,0x7848013a,0x00000000}},	//   гий_, _ørsl, _děvk, --, 
   {{0x6e445d62,0x00000000,0x00000000,0x00000000}},	//   _هنرم, --, --, --, 
   {{0x6f2401d3,0x00000000,0x00000000,0x00000000}},	//   _اڑان, --, --, --, 
   {{0x2bc471a6,0x984c1ea0,0x69240500,0x3c2800c7}},	//   वाहा, _aşın_, ймпа, rûva_, 
   {{0xacb40532,0x12e000cc,0xa8880006,0xe9a801d3}},	//   _دماغ, _যশোদ, ыйна_, ندھن_, 
   {{0x0cb002ab,0xa098010f,0x00000000,0x00000000}},	//   ंटीम, נירט, --, --, 
   {{0x9b8400cf,0x6b8826cf,0x3b840816,0x00000000}},	//   _اچىل_, mgeg, _фліг, --, 
   {{0x2bc454cb,0x6aa80083,0xe968010b,0xa90800ec}},	//   वावा, mwef, _сакл_, _ٽيبل_, 
   {{0x29000022,0x00000000,0x00000000,0x00000000}},	//   _ãha_, --, --, --, 
   {{0x78bc1600,0xa7642b91,0xe284004e,0xd67c022e}},	//   ærve, _укид, йлби, _бeри, 
   {{0x6b880e78,0xe2a86ea9,0x7e7c00de,0x00000000}},	// [8420] igeg, دازن_, _ārpo, --, 
   {{0xd7540ec9,0xd6f800b5,0xe1e800d1,0xdd380356}},	//   _پلیت_, adコ_, دىئو_, năţi, 
   {{0x656c71a7,0x5f4471a8,0x2700016b,0x6aa80e78}},	//   mabh, منال, _hɔn_, hwef, 
   {{0x656c71a9,0x6b880d27,0xdc8802f4,0x6aa871aa}},	//   labh, jgeg, ҳсил_, kwef, 
   {{0x6b88074d,0x200471ab,0xc2040022,0x840801d3}},	//   dgeg, rnoi_, _дҟаи, _előá, 
   {{0x2d900ab7,0x656c71ac,0x244c01f1,0x0ba00588}},	//   _özel_, nabh, _kým_, ҧшым, 
   {{0x61fc71ad,0x7cc80085,0x6b8871ae,0x26f40cf1}},	//   mipl, vɛrs, fgeg, ीपुर_, 
   {{0xdb4c168d,0x6b880d47,0x61fc71af,0xba54026a}},	//   رێت_, ggeg, lipl, овиј, 
   {{0x6ff4006d,0xdd380311,0xaff400e5,0x60dc00a2}},	//   jący, făţi, _بہنا_, lypm, 
   {{0x61fc71b0,0xdd380311,0x6ff4033f,0x6b880455}},	//   nipl, găţi, dący, ageg, 
   {{0x656c0882,0x9b8871b1,0xf1c800cd,0x244c00d7}},	//   dabh, _منال_, रातन, _ným_, 
   {{0x61fc71b2,0x00000000,0x00000000,0x00000000}},	//   hipl, --, --, --, 
   {{0x61fc71b3,0x2bc4081e,0xdb0c005b,0xdbd4013d}},	//   kipl, वारा, äjäh, _mäül, 
   {{0x15e800d6,0xdd380311,0x61fc003e,0x38c80133}},	//   уємо_, căţi, jipl, _نابی_, 
   {{0x6ff4033f,0xabd40150,0xc7e800db,0x60dc00a2}},	//   rącz, _دزەت, _گىين_, jypm, 
   {{0x61fc0b4f,0x244c013a,0x6ff40210,0x00000000}},	//   eipl, _dým_, sącz, --, 
   {{0x661c0270,0x656c124c,0x6ff4012d,0xaab000bc}},	// [8430] _fkpk, babh, cący, जिएक, 
   {{0x61fc0357,0x656c71b4,0x00000000,0x00000000}},	//   gipl, cabh, --, --, 
   {{0x463c04ac,0x3e5402d3,0x1ee8109c,0x61440eff}},	//   _געזע, _ዝተዛረ, یومی_, زىنە, 
   {{0xd5bc005f,0x765c71b5,0x61fc0b4f,0xeeb800db}},	//   žādi_, opsy, aipl, илеш_, 
   {{0xdbd40598,0x765c71b6,0x877c010f,0x61fc415b}},	//   _däül, npsy, ראדי, bipl, 
   {{0x61fc71b7,0x765c017a,0xb0c400f1,0x7dc42374}},	//   cipl, ipsy, _وښاي, كتىك, 
   {{0x6b8871b8,0x2bc46236,0x68100f40,0xdd38054e}},	//   tgeg, वाला, lāde, văţi, 
   {{0x656c2fad,0xdcac0131,0x68ec00bc,0x3c0c00bc}},	//   zabh, ئىي_, _řado, těva_, 
   {{0xdd380262,0x6b8871b9,0x656c71ba,0xd6f800b5}},	//   tăţi, rgeg, yabh, leウ_, 
   {{0x6b8871bb,0x0db82e0b,0x6aa80036,0x3b6401d9}},	//   sgeg, _حارث_, rwef, _ہُمِ, 
   {{0x6aa80770,0x656c71bc,0xdd380311,0x6b880af9}},	//   swef, vabh, răţi, pgeg, 
   {{0x656c0163,0xe73871bd,0x61fc01c6,0x244c02f0}},	//   wabh, иен_, zipl, _rým_, 
   {{0x656c0882,0xbc383fe6,0x5ac80133,0x61fc0205}},	//   tabh, _اسلا_, _ناوێ_, yipl, 
   {{0x1a98008f,0x6ff4012d,0xcaa00023,0xb8645b74}},	//   _כינע, rący, _ፈቲኖም_, _کاوو, 
   {{0x893471be,0x656c71bf,0x270071c0,0x154071c1}},	//   _اعشا, rabh, _wɔn_, дерм, 
   {{0x656c71c2,0x2700013f,0x765c0fac,0xca180150}},	//   sabh, _tɔn_, bpsy, _ﺴﻭﺀ_, 
   {{0xe1f871c3,0x61fc71c4,0x6810005f,0xe5780395}},	// [8440] ага_, tipl, gāde, _кзп_, 
   {{0x244c6b07,0x656c0921,0x00000000,0x00000000}},	//   _tým_, qabh, --, --, 
   {{0x6458012c,0x26180241,0x00000000,0x00000000}},	//   ítid, _ṣowo_, --, --, 
   {{0xd00c71c5,0xa3dc0243,0x67e401e1,0x44240332}},	//   پله_, _तकि_, _mójo, _óm_, 
   {{0xfe7800f7,0x67e401e1,0x81dc0154,0xe800012d}},	//   сүз_, _lójo, তোষ_, _लगना_, 
   {{0xf1d40323,0x61fc3bc8,0x63b471c6,0x7d1c00fe}},	//   _нөхө, qipl, ldyn, _ørsk, 
   {{0x9cc871c7,0x71700b38,0x3bd800e8,0x63b40076}},	//   рыла_, _سۇنا, _séqq_, odyn, 
   {{0x63b471c8,0x24780023,0x3c2800c7,0x1ea801c8}},	//   ndyn, _ክውሰድ_, rûvo_, _پاري_, 
   {{0x629471c9,0xcb641f5a,0x00000000,0x00000000}},	//   ntyo, цање_, --, --, 
   {{0xdca471ca,0x5ca40107,0x63b4015d,0x00000000}},	//   _мази, _мизб, hdyn, --, 
   {{0xf8b805f5,0xba040372,0x2c54002b,0x63b451bc}},	//   сөл_, _ۉستۉ, _pāde_, kdyn, 
   {{0x8e440137,0x765c020c,0x629471cb,0x00000000}},	//   _الەك_, tpsy, ktyo, --, 
   {{0x63b471cc,0x2c5400b8,0x00000000,0x00000000}},	//   ddyn, _vāde_, --, --, 
   {{0xdcf80365,0x78480055,0x7aec1432,0x80bc07f7}},	//   _hatı, _aśve, ıltı, ोमाइ, 
   {{0xdcf80ab7,0x38c8036b,0xaac40137,0x43a800d1}},	//   _katı, _داشی_, _وتۇن, ﺷﻠﯩﺪ, 
   {{0x325471cd,0x765c1f53,0x63b40432,0x00000000}},	//   звар, ppsy, gdyn, --, 
   {{0x86500134,0xdcf80139,0x914800d8,0x717807a5}},	// [8450] _asɔf, _matı, ачеа_, йбар_, 
   {{0x68100318,0xdcf843bc,0x4734027d,0x90e471ce}},	//   rāde, _latı, _غريز, يسان, 
   {{0x764c71cf,0xb4b471d0,0x68100a30,0x63b40334}},	//   _huay, _эйнш, sāde, bdyn, 
   {{0x764c71d1,0x764404ce,0x6e9400ea,0x7ae00419}},	//   _kuay, _hihy, зиду, kymt, 
   {{0x764c0022,0x2d90008e,0x00000000,0x00000000}},	//   _juay, _özek_, --, --, 
   {{0x764c71d2,0x764401f9,0xfe7000ec,0x939401c8}},	//   _muay, _jihy, ئدن_, _اجھا, 
   {{0x459c04ac,0xdcf80bcc,0x9d4000ee,0x313406b4}},	//   יסגע, _batı, нешд, _хевр, 
   {{0x6e9434d8,0xf1c8045b,0xdcf82791,0x2a68031c}},	//   _нибу, रावन, _catı, _ħabb_, 
   {{0xfe6c6610,0x764c003e,0x67e402fb,0x7e74009d}},	//   _шү_, _nuay, _sójo, _огтх, 
   {{0x785400dd,0x320071d3,0x63b471d4,0x00000000}},	//   ڈیوز_, nihy_, zdyn, --, 
   {{0x6c480597,0xdcf871d5,0x785401d3,0x3b8401c6}},	//   _الصف_, _fatı, ویوز_, члөг, 
   {{0x320005da,0xdcf800a2,0x2af40153,0x00000000}},	//   hihy_, _gatı, _нялё, --, 
   {{0x62942f3b,0x00000000,0x00000000,0x00000000}},	//   xtyo, --, --, --, 
   {{0x2ca80034,0x764c0342,0xdcf871d6,0x233400c7}},	//   ładu_, _duay, _zatı, ҧхар, 
   {{0xdcf8494d,0x320005da,0x8ec0009e,0x637871d7}},	//   _yatı, dihy_, ্নিগ, йсар_, 
   {{0xdcf871d8,0x629471d9,0x7c800023,0xa76400cf}},	//   _xatı, ttyo, _ከይበለ_, _экид, 
   {{0x764c71da,0x63b471db,0xb3880023,0x00000000}},	// [8460] _guay, rdyn, _ዝጽዋዕ_, --, 
   {{0x76440369,0x629471dc,0xd00400fb,0x00000000}},	//   _gihy, rtyo, үефе_, --, 
   {{0x629471dd,0xdd902832,0x68e071de,0x00000000}},	//   styo, ہوش_, nyld, --, 
   {{0x69c4041e,0xe29871df,0x764c00e4,0x629404ce}},	//   _óhef, _лам_, _yuay, ptyo, 
   {{0x644471e0,0x68e04ebc,0x7e9800f2,0x00000000}},	//   _iiki, hyld, زنثر_, --, 
   {{0xdcf871e1,0x644471e2,0xa3b80133,0xae9c030d}},	//   _satı, _hiki, _ئاگر_, ăмлă_, 
   {{0x8d7071e3,0x64441bb7,0x10a00116,0xdcf80205}},	//   راوا, _kiki, _пирн, _patı, 
   {{0x644471e4,0xdcf8467d,0x68e000ee,0x00000000}},	//   _jiki, _qatı, dyld, --, 
   {{0x644471e5,0x776c0077,0xff240214,0x24880175}},	//   _miki, _reax, _آبزی, hubm_, 
   {{0x68e0019b,0x5d840150,0x764c0946,0x8af400fb}},	//   fyld, _ءلال, _ruay, яныс_, 
   {{0x644471e6,0x9b44034c,0x68e071e7,0x776c056a}},	//   _oiki, _فناو, gyld, _peax, 
   {{0x76440007,0xb904256a,0xdca401f0,0x00000000}},	//   _sihy, _नथ_, _маҷи, --, 
   {{0x764c71e8,0x95c868d9,0xcf9000df,0x00000000}},	//   _quay, бува_, עטש_, --, 
   {{0x644471e9,0x4a7805e1,0x68e00a85,0xd1e0001f}},	//   _aiki, _פרוב, byld, ኑበት_, 
   {{0x644471ea,0x2c5400da,0xa35801f2,0xd37871eb}},	//   _biki, _kāda_, _ọnụe, йча_, 
   {{0x6444576b,0x671c1533,0x3dc4015b,0x00000000}},	//   _ciki, _युवक_, ্সিল, --, 
   {{0xe800068f,0x32000109,0x877c0375,0xa3dc00af}},	// [8470] _लगता_, tihy_, _האחי, _तकर_, 
   {{0x644471ec,0x681000dc,0xd138010b,0x9f44030a}},	//   _eiki, māda, бхе_, zhoã_, 
   {{0x644471ed,0x320071ee,0x69cc2ce6,0xd49806d4}},	//   _fiki, rihy_, ताती, _урп_, 
   {{0x644471ef,0x320071f0,0x2c54002b,0xd3f800fe}},	//   _giki, sihy_, _nāda_, _আৱৰি_, 
   {{0x68100aed,0x4ea40953,0xdfcc71f1,0x5fac01f9}},	//   nāda, яржа, شيو_, _घसरल, 
   {{0x644471f2,0x425401d9,0x00000000,0x00000000}},	//   _ziki, _سنِر, --, --, 
   {{0x644471f3,0x00000000,0x00000000,0x00000000}},	//   _yiki, --, --, --, 
   {{0x6810198e,0x64440564,0x29fc00d7,0x00000000}},	//   kāda, _xiki, rňam_, --, 
   {{0x4a4000d1,0x68e003cb,0x00000000,0x00000000}},	//   нмиң, wyld, --, --, 
   {{0x68e071f4,0x00000000,0x00000000,0x00000000}},	//   tyld, --, --, --, 
   {{0xa7a80fbe,0x0c8409a5,0x7e7c00ef,0x00000000}},	//   окна_, _хызм, _ārpi, --, 
   {{0x68e00209,0x9d18008f,0x7ae400ef,0x00000000}},	//   ryld, _וועט, _ļitv, --, 
   {{0x64443142,0xe7384f33,0x38600427,0x00000000}},	//   _riki, юем_, _čire_, --, 
   {{0x64a471f5,0x644471f6,0x2bc407d0,0x00000000}},	//   мага, _siki, वाका, --, 
   {{0x644471f7,0x00000000,0x00000000,0x00000000}},	//   _piki, --, --, --, 
   {{0x64440cfe,0x25a80175,0x68100055,0x00000000}},	//   _qiki, sebl_, bāda, --, 
   {{0x644471f8,0xec0801dc,0x0a480020,0xf1c80574}},	// [8480] _viki, yến_, _መሣሪያ, रांन, 
   {{0xe108023a,0xf1d45bc9,0x00000000,0x00000000}},	//   оезд_, нөсө, --, --, 
   {{0xdce803a0,0xe3640276,0x2ca40165,0xe5a400c7}},	//   kafā, _окни, _npld_, _еиҿи, 
   {{0x1ea80be2,0x644471f9,0xd8d4008f,0x3ea40356}},	//   قاتي_, _uiki, וועט_, _ppmt_, 
   {{0x442071fa,0x4e90014d,0x7a34004e,0x2c5400e2}},	//   moi_, نشور, làte, _rāda_, 
   {{0xa06871fb,0x67e4033f,0x0c000014,0x5cc401d5}},	//   _мага_, _bójk, ێووُ, дсиз, 
   {{0x0c7071fc,0x213c08c2,0x2c5400cd,0x00000000}},	//   نديد, _àth_, _pāda_, --, 
   {{0x442071fd,0xdfa40ada,0x5c0471fe,0x2bc46b26}},	//   noi_, _تحسي, ьяла, वागा, 
   {{0x442071ff,0xaa540023,0x2c5400b8,0x291803e0}},	//   ioi_, _ከነረጋ, _vāda_, şsal_, 
   {{0x44207200,0x645c0552,0x68100882,0x784800dc}},	//   hoi_, _otpi, vāda, _aśva, 
   {{0x2c5400da,0x2bc410eb,0xfb180a81,0xdd9401ee}},	//   _tāda_, वाखा, _کراں_, _наҡы, 
   {{0x442002d3,0x657c03ac,0x61ec0175,0xec3401ec}},	//   joi_, _adph, _llbl, _كولگ, 
   {{0x8c407201,0x7c207202,0x645c4a97,0x5ebc00cc}},	//   _реце, momr, _atpi, ্নকে, 
   {{0x7c201dca,0x2a68510c,0x784800b8,0x26180248}},	//   lomr, _çaba_, _eśva, _ṣoro_, 
   {{0x44207203,0x68107204,0x50700150,0xed940023}},	//   foi_, sāda, _ءﺍﻟﻲ_, _ዘኽብር_, 
   {{0x7c207205,0x68100882,0x61ec282c,0x12e40220}},	//   nomr, pāda, _albl, мізг, 
   {{0x61ec014f,0xf8b001d9,0x59d0043e,0x31840139}},	// [8490] _blbl, _شکھ_, तापर, етең, 
   {{0x68ec012c,0x442000b5,0x8574068e,0xf1c809ab}},	//   _řadi, aoi_, _ильх, राइन, 
   {{0x44207206,0x7c20248f,0xc104007b,0x00000000}},	//   boi_, komr, نوكي, --, 
   {{0x44207207,0x7c200e04,0x61ec396d,0xe454010f}},	//   coi_, jomr, _elbl, _רירט_, 
   {{0xed587208,0x7c207209,0x6da40588,0xada4720a}},	//   пол_, domr, еила, еалл, 
   {{0xed58720b,0x68340005,0x00000000,0x00000000}},	//   чок_, máde, --, --, 
   {{0x7c20020b,0x09b4015b,0x101401b9,0x68340f57}},	//   fomr, জামা, _قبرد, láde, 
   {{0x0a480020,0x7c200e38,0x7f84007b,0x5fc40037}},	//   _መሣርያ, gomr, _للفن, _रोपल, 
   {{0xae04005e,0xaa440124,0x00000000,0x00000000}},	//   _كورى, неил, --, --, 
   {{0x4420720c,0xe8f8720d,0xf95c0023,0x49000961}},	//   zoi_, зло_, _ተሓቢኡ_, күлг, 
   {{0x3170720e,0xbc680597,0x4420720f,0x7c207210}},	//   _mezz_, _يمكن_, yoi_, bomr, 
   {{0x44207211,0x7c207212,0x00000000,0x00000000}},	//   xoi_, comr, --, --, 
   {{0x44207213,0x7a3408e7,0x7ac8009f,0x3ce400cc}},	//   voi_, wàte, _يومِ_, _কেপ্_, 
   {{0xe8000cb4,0x31700841,0xbcfc00e4,0x44200175}},	//   _लगवा_, _nezz_, _teĩt, woi_, 
   {{0x7d1c7214,0x05945a76,0xd9400131,0xc6900131}},	//   _ørst, _یادگ, _йеши, _ھېس_, 
   {{0x2bc4278e,0x64a41171,0x00000000,0x00000000}},	//   वाटा, маҳа, --, --, 
   {{0x44207215,0xba040020,0x66e47216,0x68347217}},	// [84a0] roi_, _ጌታ_, _чопа, gáde, 
   {{0x44207218,0x17180302,0x622400cf,0x2c5400b8}},	//   soi_, _מופע, رىال, _nādo_, 
   {{0x44207219,0xb54400c7,0xe7d0009e,0x7c20721a}},	//   poi_, _аҧра_, াসীয, yomr, 
   {{0xa03408c9,0x4420003a,0xf1c81152,0x683401d3}},	//   رىشت, qoi_, राउन, ládb, 
   {{0x7c201455,0xf2c438b4,0xee94721b,0xb35417a5}},	//   vomr, _исён, ندوک, _شیلا_, 
   {{0x7e64054e,0x00000000,0x00000000,0x00000000}},	//   ţipo, --, --, --, 
   {{0x987c0316,0x7c201347,0x7e7c005f,0xa068721c}},	//   _péče_, tomr, _ārpu, _хаба_, 
   {{0x22b00100,0xbea80137,0xeb98010a,0x50400150}},	//   _kņk_, _يۇان_, çик_, _бесб, 
   {{0x7a38721d,0x20040992,0x2bc4041c,0x8b5401f7}},	//   мпир_, mioi_, वाजा, رجيس_, 
   {{0xdc102ed0,0x200401c0,0x5884721e,0x25b80165}},	//   rşın, lioi_, ныма, _napl_, 
   {{0x20040421,0x6810005f,0x7e600175,0x383407a5}},	//   oioi_, rādn, _htmp, кнор, 
   {{0x8c1405d9,0x00000000,0x00000000,0x00000000}},	//   _ٻيهر_, --, --, --, 
   {{0x95c8721f,0x68340077,0xdb000254,0x00000000}},	//   пува_, xáde, _jaoü, --, 
   {{0x200400b0,0x2d9005d1,0x00000000,0x00000000}},	//   hioi_, _özet_, --, --, 
   {{0x200402b1,0x2bc4085c,0x69cc7220,0x00000000}},	//   kioi_, वाचा, तारी, --, 
   {{0x68340005,0x31700327,0x3d180037,0x00000000}},	//   táde, _sezz_, _भखने_, --, 
   {{0x2004036e,0x51a8005b,0x00000000,0x00000000}},	// [84b0] dioi_, зъем_, --, --, 
   {{0x22b00100,0x68347221,0x00000000,0x00000000}},	//   _dņk_, ráde, --, --, 
   {{0xff5000aa,0x68347222,0x2248003b,0x473401d5}},	//   څخه_, sáde, _dibk_, _لریز, 
   {{0x22b002e2,0xff50088c,0x2004004d,0xfe700133}},	//   _fņk_, مخه_, gioi_, ڵده_, 
   {{0x2c54002b,0x00000000,0x00000000,0x00000000}},	//   _pādo_, --, --, --, 
   {{0xada47223,0xdee00dbb,0xfde80046,0xfe707224}},	//   такл, роши, ндік_, صده_, 
   {{0xdd8c6ac4,0x7124313e,0x622400cf,0xe800000d}},	//   زوي_, _شىرم, _شوفە, _लगला_, 
   {{0x3034034b,0xfed800fe,0x00000000,0x00000000}},	//   _ребё, _দেওধ, --, --, 
   {{0x78480055,0xef647225,0x38600e04,0x8b4000c7}},	//   _aśvo, ğıdı_, _čira_, ыдиҵ, 
   {{0x8c0000d1,0xef641432,0x00000000,0x00000000}},	//   _әҗил, şıdı_, --, --, 
   {{0x2fcc05e4,0xa6e403b2,0xdce8054e,0x00000000}},	//   _kneg_, _orðá, rafă, --, 
   {{0xeab07226,0x6810005f,0x66e47227,0x00000000}},	//   _نعت_, rādo, вома, --, 
   {{0x98a0005f,0xb6c40032,0x69d40112,0x3dcc0142}},	//   ākā_, гияһ, özes, _yndw_, 
   {{0x5b10035f,0x69245b7f,0x96600150,0x00000000}},	//   _әмәт, _имла, ркре, --, 
   {{0x2fcc022f,0x89b001a9,0x00000000,0x00000000}},	//   _oneg_, _аёқш, --, --, 
   {{0xe0d05226,0x00000000,0x00000000,0x00000000}},	//   یزا_, --, --, --, 
   {{0xe61803b7,0x2e2800d2,0x2004023a,0x55500014}},	// [84c0] _оди_, lúfu_, vioi_, _چھِر, 
   {{0x2fcc0165,0xa068023a,0x04f00154,0x5f440133}},	//   _aneg_, дажа_, _ঐশীর_, ۆنال, 
   {{0x63847228,0x7e600175,0x60c000b0,0x200401f4}},	//   _игна, _stmp, āomo, tioi_, 
   {{0xe2c800cf,0xdf60035b,0xd8d8010f,0x09bc00eb}},	//   _قوجو_, рҭақ, וקער, েসটা, 
   {{0x2fcc0036,0x1e940276,0x20047229,0x7a3401ab}},	//   _dneg_, трер, rioi_, hàta, 
   {{0x2fcc020b,0x27f00368,0x22480175,0x6084007b}},	//   _eneg_, _llyn_, _uibk_, _لشرك, 
   {{0xd8c00156,0x0c7418a1,0x60240006,0xbb5801c6}},	//   གའབྲ, نصيب_, _адва, найх_, 
   {{0x2fcc0158,0xfa6801a9,0x00000000,0x00000000}},	//   _gneg_, нчоқ_, --, --, 
   {{0x3b2c044e,0xe7d428e0,0x9e7000d1,0xd00400d8}},	//   _ስድራቤ, धानप, _ئۇتت, _рете_, 
   {{0x27f0722a,0x00000000,0x00000000,0x00000000}},	//   _alyn_, --, --, --, 
   {{0x6734007f,0x16c800dc,0x6458722b,0x2b5c0042}},	//   _azyj, ाम्ब, ítil, _ffwc_, 
   {{0x9b0406ed,0x8cac0490,0x2d9005d2,0x00000000}},	//   _изед, ंबरो, _özer_, --, 
   {{0x6734012d,0x645801e4,0x1db409fa,0x00000000}},	//   _czyj, ŭtil, _आघात, --, 
   {{0x27f02e93,0x3494722c,0x98c41188,0x63a4002f}},	//   _elyn_, лагр, _асил, _abkn, 
   {{0xc8b00979,0x48e04c70,0x00000000,0x00000000}},	//   _نصيب, _војв, --, --, 
   {{0x27f00368,0x799802d0,0x3b0402b1,0x1ab41bcf}},	//   _glyn_, _hcvw, pīpī_, _अनाथ, 
   {{0x98bc722d,0x00000000,0x00000000,0x00000000}},	// [84d0] matı_, --, --, --, 
   {{0x35b4722e,0x2fcc722f,0x98bc45a5,0x64480395}},	//   _сбор, _sneg_, latı_, _èfin, 
   {{0x68340e96,0xc05802d5,0x3cec033f,0x74141bf4}},	//   láda, віч_, जनों_, _مودا, 
   {{0x98bc7230,0xb4c02ce6,0x7e7c00de,0x00000000}},	//   natı_, ूमी_, _ārpr, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4e8c044e,0x7e2400d4,0xcdc000c7,0x98bc4dd9}},	//   _ብደረጃ_, адіж, ракқ, hatı_, 
   {{0x86500085,0x98bc1d89,0x68340306,0xd7c00a59}},	//   _nsɔn, katı_, háda, षयाच, 
   {{0xeb987231,0xeab87232,0x2fcc7233,0xc214013f}},	//   хии_, ейи_, _uneg_, nsɔn_, 
   {{0x8650013f,0xeb2801c0,0x98bc7234,0x2f140108}},	//   _asɔn, эжил_, datı_, _сдаё, 
   {{0xf1c8012c,0xa0200254,0x00000000,0x00000000}},	//   राटन, _ööri, --, --, 
   {{0x27f00122,0x98bc1ae9,0x6734033f,0x00000000}},	//   _plyn_, fatı_, _szyj, --, 
   {{0xf64825f9,0x6b64010b,0x27e80003,0xaa580114}},	//   _זצ_, _ёкла, _ċans_, _зиду_, 
   {{0xa9a47235,0x25bc0770,0x09dc015b,0x68340022}},	//   _билд, ôtlo_, যোগা, gáda, 
   {{0x09b40154,0x64580115,0x00000000,0x00000000}},	//   জাহা, ŭtim, --, --, 
   {{0x98bc7236,0x44240208,0x00000000,0x00000000}},	//   batı_, _ưm_, --, --, 
   {{0xe7387237,0x68340518,0x98bc0342,0xa3480395}},	//   _пей_, báda, catı_, езба_, 
   {{0x21a41422,0x00000000,0x00000000,0x00000000}},	// [84e0] лиам, --, --, --, 
   {{0x61446afd,0x00000000,0x00000000,0x00000000}},	//   геза, --, --, --, 
   {{0x98a47238,0x6b9801c4,0xf1c87239,0xa50800f3}},	//   čiće_, _ocwg, राजन, _чена_, 
   {{0xe3b0121a,0x9e642d8d,0xdf740345,0x00000000}},	//   _ارد_, هاتن, اداب, --, 
   {{0x5f04723a,0x201c00ae,0x7e0400c7,0x00000000}},	//   ызда, _ítim_, аҧаз, --, 
   {{0xdcb806bb,0xc1040724,0x999c0270,0x0f20015b}},	//   ещи_, _күзл, totō_, _বৃহঃ_, 
   {{0xa114723b,0x98bc0ba5,0x00000000,0x00000000}},	//   _صورت, yatı_, --, --, 
   {{0x0e60723c,0x3b54723d,0xa0a400c7,0x00000000}},	//   шкән, шкир, _иаҳд, --, 
   {{0x68100882,0xef640790,0x00000000,0x00000000}},	//   mādh, şıcı_, --, --, 
   {{0x2d900166,0x00000000,0x00000000,0x00000000}},	//   _özep_, --, --, --, 
   {{0x98bc723e,0xf8b82be5,0x00000000,0x00000000}},	//   tatı_, төл_, --, --, 
   {{0x59d00316,0x68ec0198,0x68100882,0x3c0c00bc}},	//   ताहर, _ƙadr, nādh, těvu_, 
   {{0x98bc538f,0x6fd401f9,0x00000000,0x00000000}},	//   ratı_, णातू, --, --, 
   {{0x68340122,0x7998009a,0x98bc0db1,0x7bc01780}},	//   ráda, _ucvw, satı_, ldmu, 
   {{0x5884723f,0x68340216,0x7a3400db,0x93a401a9}},	//   _сыла, mádn, làto, лшад, 
   {{0xd1b87240,0x68347241,0x82a4053f,0x7bc0007d}},	//   کارا_, ládn, әште, ndmu, 
   {{0xc79400cf,0x00000000,0x00000000,0x00000000}},	// [84f0] _اشىب, --, --, --, 
   {{0x67e4012d,0x7bc00327,0x53a00137,0xd5b80395}},	//   _wójt, hdmu, _گۅرك, _чси_, 
   {{0x9f440165,0xb5940208,0xb0f8007b,0x00000000}},	//   mhoù_, _hạot, خفاض_, --, 
   {{0x9f4403bd,0xb6300efb,0xd34402f2,0x00000000}},	//   lhoù_, _ﻓﻲ_, _میزه_, --, 
   {{0x12e4177b,0xe378011a,0x7bc0031c,0x7414072d}},	//   _сінг, _שרשר, ddmu, _موگا, 
   {{0x72047242,0x00000000,0x00000000,0x00000000}},	//   _ئوسم, --, --, --, 
   {{0x2c54005f,0x681000dc,0x00000000,0x00000000}},	//   _kādi_, bādh, --, --, 
   {{0x6a847243,0xa0200254,0x681000b8,0x00000000}},	//   алиа, _ööpi, cādh, --, 
   {{0xedd415c9,0x47b0015b,0x00000000,0x00000000}},	//   _پياد, য়ামী, --, --, 
   {{0x683402fb,0x69247244,0x64580162,0xff0401f4}},	//   gádn, импа, ítik, _уясн, 
   {{0x2d842517,0x7c8400f3,0x00000000,0x00000000}},	//   _idle_, _гуче, --, --, 
   {{0x6458010f,0xfd107245,0x7a3401e1,0x00000000}},	//   ŭtik, _عجل_, bàto, --, 
   {{0x68100a54,0xd6f800b5,0xe73006c2,0x00000000}},	//   nādi, deコ_, تصد_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69c00921,0x00000000,0x00000000,0x00000000}},	//   mdle, --, --, --, 
   {{0x69c07246,0x68340518,0xe58400f7,0xd918011a}},	//   ldle, mádo, دۅگۉ_, _שוקל, 
   {{0x2d84014b,0xa20402d5,0x68340765,0xca1400d1}},	// [8500] _odle_, апад, ládo, ﺳﺘﺎ_, 
   {{0x69c02ffc,0x2d8402c4,0x9f440dd4,0xe458030d}},	//   ndle, _ndle_, choù_, _ижо_, 
   {{0x60246345,0x69c00368,0xf3f001fb,0x68347247}},	//   аджа, idle, ệc_, nádo, 
   {{0x2d840107,0xf000010b,0x1ab4000d,0xb354085b}},	//   _adle_, пүси, _अनलथ, _هیفا_, 
   {{0xdd905dd0,0x6810198e,0xa0680124,0x00000000}},	//   قوش_, rādh, хаҵа_, --, 
   {{0xe3b02be7,0x68100882,0x683403da,0x69c04ff4}},	//   _ارگ_, sādh, kádo, jdle, 
   {{0x69c026e7,0x2c540055,0xdebc0240,0x00000000}},	//   ddle, _yādi_, ሰብካ_, --, 
   {{0x9f440ad3,0x3a747248,0x69c07249,0xdee4724a}},	//   zhoù_, блир, edle, _коби, 
   {{0x69c00196,0x5e48724b,0x8bd402dd,0xda64724c}},	//   fdle, _апам_, рмыс_, جابي, 
   {{0x69c001a4,0x957c0023,0x69c40162,0x7a3400a3}},	//   gdle, ዕታትን_, _óhel, ràto, 
   {{0x6834724d,0x2474016b,0xefd40092,0x00000000}},	//   rádn, bɛmɑ_, ያሳዩ_, --, 
   {{0x683402fb,0xefc002d3,0x7ba400cc,0x00000000}},	//   sádn, _ጻዕዳ_, _খোৰো, --, 
   {{0x68340308,0x2c5400ef,0xf8b800db,0x00000000}},	//   pádn, _rādi_, _өөн_, --, 
   {{0x6834724e,0xa2d8227c,0x960800c0,0x1dc400cd}},	//   ládl, नमन्, тэма_, लयित, 
   {{0xd7f8035b,0x2a68031c,0x1ab4000d,0x3354004e}},	//   _ауп_, _ħabi_, _अनुठ, йүнө_, 
   {{0xc5f40198,0x68100882,0xb354724f,0x49c40139}},	//   _ruɓe_, yādi, скаш, _блән_, 
   {{0x1dc4086b,0x73387250,0xfbd800cc,0x00000000}},	// [8510] लयात, узар_, _ততাত, --, 
   {{0xd1487251,0x68100882,0x45d4010a,0x00000000}},	//   نشان_, vādi, _доьс, --, 
   {{0x2c54005f,0x784800cd,0x7ed40014,0x454401e2}},	//   _tādi_, _aśvi, ۪زما, _ورپې, 
   {{0x777c0227,0x1ab405f9,0x3ae002b5,0xbfa81ca9}},	//   nasx, _अनूठ, _kōpā_, итче_, 
   {{0x69c07252,0xf0787253,0xeb980075,0xa4c4010e}},	//   ydle, тиҗә_, қип_, _öňrä, 
   {{0x68100aed,0xc5f403f9,0xee200073,0xea8802a9}},	//   rādi, _tuɓe_, यवेध_, қбол_, 
   {{0x66cc0109,0xefd4001f,0x69c00194,0x39e0000d}},	//   _kôkô, ያሳይ_, vdle, _पकड़ि, 
   {{0xa80400e4,0xd0180276,0x7f940408,0x6a940212}},	//   _moñá, _рфг_, _масх, броє, 
   {{0x8d847254,0x2d840a73,0x2ef47255,0xeab000c6}},	//   _نشان, _tdle_, _узар, سعة_, 
   {{0x2d84401f,0x69c07256,0xe9d87257,0x3ea008c2}},	//   _udle_, udle, уко_, àite_, 
   {{0x69c07258,0x1ca80014,0x6d340101,0x69c4032e}},	//   rdle, _مَلی_, _افاض, _óhem, 
   {{0x68345956,0x00000000,0x00000000,0x00000000}},	//   rádo, --, --, --, 
   {{0xc5f87259,0x68341705,0x59c0000d,0x00000000}},	//   иғи_, sádo, _वोकर, --, 
   {{0x37b4015b,0xe5a40063,0xb90800f2,0x23281171}},	//   টাগর, љиви, ازیم_, ҳоби_, 
   {{0x2bbc725a,0xa8840137,0xd99400db,0xf9600345}},	//   ्यपा, _البى, _انىت_, _تۆپێ, 
   {{0x2328725b,0xb8640345,0xa0a40022,0x00000000}},	//   гоби_, _باوو, ҩаад, --, 
   {{0x9f500118,0xe2c80006,0x00000000,0x00000000}},	// [8520] ícím_, ылад_, --, --, 
   {{0x2ca80034,0x7ae40192,0x3d180037,0x00000000}},	//   łady_, _àite, _भखले_, --, 
   {{0xef640baf,0x2c5400da,0xd24c01d9,0xe4c401d5}},	//   ğını_, _kādu_, رنم_, _уйни, 
   {{0xef642c6f,0x660c725c,0x00000000,0x00000000}},	//   şını_, libk, --, --, 
   {{0x63b4725d,0x2bbc725e,0x09b407b7,0x00000000}},	//   meyn, ्यना, _असूय, --, 
   {{0xac8c044e,0x63b4725f,0x21f40597,0x62947260}},	//   _ነይሮም_, leyn, _اكسس, muyo, 
   {{0xec0807ae,0x62947261,0xdcf80210,0x5fc40037}},	//   yết_, luyo, _odtą, _रोअल, 
   {{0x63b47262,0x30747263,0x660c00ac,0x4fa07264}},	//   neyn, _фурс, hibk, _нисв, 
   {{0x62947265,0x660c0254,0x00000000,0x00000000}},	//   nuyo, kibk, --, --, 
   {{0x777c0054,0x3ae002b5,0x63b40014,0x00000000}},	//   wasx, _rōpā_, heyn, --, 
   {{0x777c0227,0x62947266,0x63b403d9,0x660c058a}},	//   tasx, huyo, keyn, dibk, 
   {{0x62947267,0x63b47268,0x2c7401ed,0x683401ed}},	//   kuyo, jeyn, _بیٹھ_, ládj, 
   {{0x63b47269,0x5b3413d7,0x41c8726a,0x49900d73}},	//   deyn, _اعار, रयास, _کیپر, 
   {{0x62940004,0x66cc0109,0x19f40a81,0xa2ac726b}},	//   duyo, _sôkô, _دِتھ_, ुबन्, 
   {{0xf8b80348,0xdb4c04d3,0x63b4726c,0x25f8023e}},	//   _төп_, _تێک_, feyn, _उतरी_, 
   {{0x2bbc08f8,0x63b40014,0x6294037e,0x21e002dd}},	//   ्यया, geyn, fuyo, _ﺍﻷﺨﺭ, 
   {{0x6294726d,0x8af403be,0x71783531,0x69cc02ab}},	// [8530] guyo, _çəti, ибар_, ताची, 
   {{0xf494044e,0x660c0014,0x84600124,0xa2d800bc}},	//   _ይፍለጥ_, cibk, _ẽteé, _नपर्, 
   {{0x2bbc726e,0x63b40014,0xeb1402ab,0x14c801f4}},	//   ्यमा, beyn, _तख्त_, _сыпи_, 
   {{0x63b44091,0x6294726f,0xaaa800c5,0x00000000}},	//   ceyn, buyo, _कहलक, --, 
   {{0xcf240a2c,0x62940113,0xd16402e8,0x4e880108}},	//   حراي, cuyo, _гъби, ущем_, 
   {{0x2bbc06ff,0x00000000,0x00000000,0x00000000}},	//   ्यभा, --, --, --, 
   {{0x1d040395,0x00000000,0x00000000,0x00000000}},	//   жещи_, --, --, --, 
   {{0xea88084c,0x7a3401c3,0x00000000,0x00000000}},	//   абил_, làth, --, --, 
   {{0x1ee87270,0x2bbc7271,0x2c540171,0x00000000}},	//   _پولی_, ्यबा, _rādu_, --, 
   {{0xbef00150,0xe88408db,0x7a3408c2,0x660c058a}},	//   _سۋىع, огоп, nàth, xibk, 
   {{0x63b401d9,0xbb200131,0x62940790,0x21e001ec}},	//   yeyn, ﺸﻨﻰ_, zuyo, _ﺍﻷﺯﺭ, 
   {{0x63b40014,0x62947272,0xa6c87273,0x7a3401ab}},	//   xeyn, yuyo, алма_, hàth, 
   {{0xe9d87274,0xddc0005f,0x683402fb,0x63b40e2d}},	//   _вкл_, lpoš, ládk, veyn, 
   {{0x63b40050,0xf3f0001e,0x2a6c0218,0x3a240212}},	//   weyn, ện_, mpeb_, _еміг, 
   {{0x5ab40156,0x63b47275,0x2c5400da,0x62947276}},	//   _དགོམ, teyn, _tādu_, wuyo, 
   {{0x62947277,0x660c020c,0xe3b80120,0xe71c0055}},	//   tuyo, sibk, јба_, _ãdįũ, 
   {{0x63b47278,0x2c5400da,0x6834012c,0x7690013d}},	// [8540] reyn, _kāds_, hádk, _cıyğ, 
   {{0x62947279,0x63b4727a,0x09b4015b,0x660c058a}},	//   ruyo, seyn, জাকা, qibk, 
   {{0x63b41529,0xd79004fb,0xddc016a3,0x6294727b}},	//   peyn, _علیخ, jpoš, suyo, 
   {{0xe29811b5,0x1ec80124,0x63b401d9,0x6294727c}},	//   _кам_, илеи_, qeyn, puyo, 
   {{0x2a6c0218,0x50cc0882,0x50c80150,0x13b4011a}},	//   jpeb_, īnāṃ_, _ءﻣﺎﺟ_, _והכל_, 
   {{0x6284727d,0xdfd000b2,0xdc88727e,0x1ab400bc}},	//   _ivko, _ڪير_, асил_, _अनौठ, 
   {{0xf2f80133,0xe7c82802,0x8cb400ae,0x00000000}},	//   _نوێژ_, ियाप, قديس_, --, 
   {{0x7a34727f,0xdfd07280,0x3a740131,0x0d800daf}},	//   màti, _تير_, плир, плән, 
   {{0x7a3400db,0x93f8010f,0x00000000,0x00000000}},	//   làti, ילקי, --, --, 
   {{0x1d08519b,0xab6400e2,0x9d4400d8,0xd84001ef}},	//   _кези_, viļņ, _дезд, _mečů_, 
   {{0x115808a8,0x7a3412d9,0x818001ec,0xa3c801f9}},	//   ידיע, nàti, _ﺨﺩﻤﺔ_, ऊया_, 
   {{0xc5f403f9,0xd8087281,0x683402f0,0x00000000}},	//   _ruɓa_, рхол_, nádh, --, 
   {{0x2d50001f,0x86740212,0x00000000,0x00000000}},	//   _ማሳሰቢ, мляє, --, --, 
   {{0x2bbc00dc,0x38c80345,0x69a0000d,0x00000000}},	//   ्यथा, _هابی_, _खायी, --, 
   {{0xd3787282,0x62840250,0x14087283,0x00000000}},	//   ича_, _avko, ахап_, --, 
   {{0x81a804c5,0x00000000,0x00000000,0x00000000}},	//   _খোল_, --, --, --, 
   {{0x2bbc4697,0x76900139,0xddc00010,0x62900241}},	// [8550] ्यता, _qıyğ, zpoš, _ìjọ, 
   {{0xef6406b9,0x7a34004e,0x473405a2,0x61fc02d0}},	//   ğımı_, fàti, _юныс, ghpl, 
   {{0x60cc004e,0xef642fbe,0xf484158b,0x7a3408c2}},	//   _crbm, şımı_, _عادی, ràth, 
   {{0x09b40882,0x7690013d,0x00000000,0x00000000}},	//   _अस्य, _tıyğ, --, --, 
   {{0x15fc49fc,0x40940131,0xcdc000c7,0x00000000}},	//   _उतार_, كلەر, далқ, --, 
   {{0x61fc7284,0x7a3400db,0xd0980451,0x25dc012d}},	//   chpl, bàti, _پئسا_, खायी_, 
   {{0x69c40008,0x5fc4000d,0x00000000,0x00000000}},	//   _óhei, _रोकल, --, --, 
   {{0x68340308,0x7ff42309,0x6ae41422,0x00000000}},	//   rádk, _قسقا, зжиз, --, 
   {{0x683402fb,0xde44004b,0x2a680003,0xddc00427}},	//   sádk, _ځینو_, _ħabs_, spoš, 
   {{0xa9a40276,0x00000000,0x00000000,0x00000000}},	//   чиод, --, --, --, 
   {{0x66740020,0x2a6c0218,0x2bbc08e6,0x3da401b9}},	//   _ጠቅላላ_, speb_, ्यदा, _юртб, 
   {{0x644800d8,0x21e00150,0x2a6c7285,0x00000000}},	//   _éfix, _ﺍﻷﺤﺭ, ppeb_, --, 
   {{0x68340798,0x00000000,0x00000000,0x00000000}},	//   nádi, --, --, --, 
   {{0x2c5400da,0x57441e76,0xa2d8258d,0xba287286}},	//   _tāds_, язям_, नमस्, _وسوم_, 
   {{0x290003a1,0x6d5400d7,0x81d40154,0x00000000}},	//   _åha_, _úzad, িউম_, --, 
   {{0xa68404a9,0x69a0202e,0x3ac4037e,0x683403b2}},	//   _елид, _खाडी, をpc_, kádi, 
   {{0x2bac05ba,0xe1f8036b,0x57f80375,0xd7f80375}},	// [8560] झ्या, бга_, _ללקו, _להקל, 
   {{0xf1a87092,0x62840175,0x7a3400cf,0x76900139}},	//   قامه_, _vvko, tàti, _qıyş, 
   {{0x657c0393,0x557405d0,0x2bd000bc,0x00000000}},	//   _ieph, _מעין_, _दोभा, --, 
   {{0x657c7287,0xdef87288,0x645c7289,0x61fc728a}},	//   _heph, йыл_, _iupi, shpl, 
   {{0x657c2f95,0x683400ae,0xca200150,0x00000000}},	//   _keph, rádh, _ﺼﻼﺡ_, --, 
   {{0x6734049b,0x2bd00da3,0x7a3400cf,0x358c0023}},	//   _myyj, _दोबा, pàti, _ዕዮታት_, 
   {{0x657c728b,0x9cc8728c,0x645c728d,0x7d04010f}},	//   _meph, сыла_, _jupi, ĝiso, 
   {{0x657c728e,0x645c728f,0xbfa80014,0x00000000}},	//   _leph, _mupi, _گاڑٕ_, --, 
   {{0x61280165,0x657c003a,0xcb640b3e,0x683400d8}},	//   _fǎlú, _oeph, чање_, cádi, 
   {{0x657c7290,0x645c7291,0x00000000,0x00000000}},	//   _neph, _oupi, --, --, 
   {{0xdef81669,0x645c0006,0x499001d3,0x00000000}},	//   _тың_, _nupi, ریٹر, --, 
   {{0x1ae47292,0x1c440137,0x00000000,0x00000000}},	//   _ноем, _энем, --, --, 
   {{0x645c7293,0x657c0912,0xfb1801d9,0xf3f001fb}},	//   _aupi, _beph, _براں_, ệm_, 
   {{0x09e00f5c,0x645c7294,0x657c7295,0xd1dc02d3}},	//   _почн, _bupi, _ceph, ሒታት_, 
   {{0x645c0483,0x657c022f,0x69a004fa,0x00000000}},	//   _cupi, _deph, _खाती, --, 
   {{0x03c4721f,0x657c02d0,0x00000000,0x00000000}},	//   нсум, _eeph, --, --, 
   {{0x325405f5,0xa3bc0037,0x5688009f,0x00000000}},	// [8570] двар, _इसर_, _ائبٽ_, --, 
   {{0x82341a59,0x645c009f,0x657c0036,0x00000000}},	//   ىرلا, _fupi, _geph, --, 
   {{0x645c7296,0xc1e80108,0x33580064,0x00000000}},	//   _gupi, чьте_, _манэ_, --, 
   {{0x657c7297,0x683406ed,0xaf3800c7,0x7a34004e}},	//   _zeph, tádi, озеф_, màtu, 
   {{0x657c7298,0xed5819bb,0xd3940032,0x2bbc193d}},	//   _yeph, оол_, _мәҡә_, ्यसा, 
   {{0xfe707299,0x68341a09,0xa2f40a7c,0xc51400f2}},	//   ادن_, rádi, _חמשה_, _آبیت, 
   {{0x645c004e,0x25dc012d,0x00000000,0x00000000}},	//   _xupi, खाती_, --, --, 
   {{0xeb98729a,0xfd10729b,0x644804cc,0x00000000}},	//   ции_, دجه_, _èfit, --, 
   {{0x7f58729c,0xaa44084c,0x92b80154,0x00000000}},	//   _хаус_, меил, _অপু_, --, 
   {{0x7d18007b,0xe2a40321,0xde440014,0x98ac03e0}},	//   éasú, æðin_, _ہیۆو_, _affı_, 
   {{0x657c729d,0x3d9401c6,0x00000000,0x00000000}},	//   _reph, _чихр, --, --, 
   {{0x657c729e,0xe7385777,0x645c729f,0xaa580117}},	//   _seph, жем_, _rupi, _диду_, 
   {{0xe9a40dd8,0x657c0165,0xa9a472a0,0x645c72a1}},	//   _жалп, _peph, _жилд, _supi, 
   {{0x2bbc72a2,0x657c72a3,0x645c72a4,0x6aa872a5}},	//   ्यवा, _qeph, _pupi, mtef, 
   {{0x645c72a6,0x394801ec,0xd4a000fb,0xd4640117}},	//   _qupi, _ىشىپ_, кирй, дисе_, 
   {{0x657c63f0,0x64580137,0x645c01a6,0x6d400327}},	//   _weph, ítiq, _vupi, _mzla, 
   {{0xa1c472a7,0x9f483535,0x00000000,0x00000000}},	// [8580] мбад, ümün_, --, --, 
   {{0x26d00537,0x645c72a8,0x657c0b6f,0x6d40036b}},	//   _iryo_, _tupi, _ueph, _ozla, 
   {{0x290405d5,0x6aa80036,0xd12c007b,0x11d4007b}},	//   nzla_, htef, لمك_, ظومة_, 
   {{0x6aa803cd,0xa5c400cd,0x00000000,0x00000000}},	//   ktef, ायकौ, --, --, 
   {{0x6d4072a9,0x1ec82f0d,0x6aa805be,0xce600131}},	//   _azla, юлди_, jtef, نگلى, 
   {{0x6aa8005c,0x7d04010f,0x00000000,0x00000000}},	//   dtef, ŝism, --, --, 
   {{0x644872aa,0x629400b5,0x0c400014,0x90c0030d}},	//   _èfis, lryo, چھنَ, _ибре, 
   {{0x26d004ba,0xfb841a4b,0x93f8010f,0x00000000}},	//   _oryo_, ردبی, ַליי, --, 
   {{0x6d4002ea,0x5ea40691,0x6294037e,0x6aa801bf}},	//   _ezla, _زمال, nryo, gtef, 
   {{0x5d840ec9,0x629472ab,0x7e6003ac,0x588401ec}},	//   _آلال, iryo, _iump, мыма, 
   {{0x26d072ac,0x6aa8045f,0x7e600d63,0x64440254}},	//   _aryo_, atef, _hump, _ohki, 
   {{0x7e6072ad,0x21e002dd,0x00000000,0x00000000}},	//   _kump, _ﺍﻷﺴﺭ, --, --, 
   {{0xeb540e8e,0x26d001a4,0x2bbc72ae,0x7e6072af}},	//   _كىمگ, _cryo_, ्यरा, _jump, 
   {{0xc1c80864,0x26d00109,0x7a3400cf,0x6d40010b}},	//   रयोग, _dryo_, tàtu, _yzla, 
   {{0x7e6072b0,0x26d00a49,0x395c0005,0x00000000}},	//   _lump, _eryo_, _igvs_, --, 
   {{0x683400d2,0x7a34521d,0x64443df1,0x316c0118}},	//   fádu, ràtu, _chki, _řez_, 
   {{0x7e6072b1,0xb878001f,0x00000000,0x00000000}},	// [8590] _nump, _የሰጠው_, --, --, 
   {{0xd71802ab,0xd13872b2,0x7a34004e,0x00000000}},	//   नपीठ_, охе_, pàtu, --, 
   {{0x7e600ba1,0x62944f74,0x6fb838be,0x00000000}},	//   _aump, aryo, згер_, --, 
   {{0x629472b3,0xa6e4009e,0x9f440165,0x6aa8143a}},	//   bryo, _পেটট, lkoù_, ytef, 
   {{0x7e6072b4,0xdcf802e2,0xef180327,0x6d400034}},	//   _cump, _detč, _beża_, _szla, 
   {{0xfde80220,0x9f440489,0x3f640075,0x683401d3}},	//   мдік_, nkoù_, нтәб, ládt, 
   {{0x2bbc095f,0x00000000,0x00000000,0x00000000}},	//   ्यला, --, --, --, 
   {{0x7e6001e4,0xc10400ec,0x9cb0009a,0x00000000}},	//   _fump, _شوقي, اميت, --, 
   {{0x1b10015b,0x00000000,0x00000000,0x00000000}},	//   _ডুবে_, --, --, --, 
   {{0x395c02ea,0x6f240276,0x7c34031c,0x00000000}},	//   _cgvs_, ărcă, _ġerż, --, 
   {{0x6d4072b5,0x6aa872b6,0x7e60026c,0x00000000}},	//   _uzla, stef, _zump, --, 
   {{0x8650013f,0x60d801ed,0x8bc401ec,0x62940022}},	//   _nsɔr, _átme, _ісед, yryo, 
   {{0x2904012d,0x00000000,0x00000000,0x00000000}},	//   szla_, --, --, --, 
   {{0x8650013b,0x644472b7,0xa9a401b9,0xe9a4004e}},	//   _asɔr, _shki, _чикд, _чакп, 
   {{0x23d46ed2,0xd54401f4,0x00000000,0x00000000}},	//   нцар, епре_, --, --, 
   {{0x629472b8,0x26d00165,0x00000000,0x00000000}},	//   tryo, _tryo_, --, --, 
   {{0xed94001f,0x629404ce,0xe1f85a5b,0xe688007b}},	// [85a0] _ፌስቡክ_, uryo, пга_, _عندى_, 
   {{0x16740375,0x26c00472,0x98a0033f,0x57440166}},	//   _רגיל_, mwko_, łką_, _язым_, 
   {{0xdcf80100,0xdfd802e8,0x64a4009d,0x00000000}},	//   _petč, зъл_, _яана, --, 
   {{0x7e6072b9,0x1ea8007b,0x644401f4,0x00000000}},	//   _pump, كاتي_, _uhki, --, 
   {{0x442072ba,0x7e604376,0x63a4127b,0xa8580150}},	//   mni_, _qump, _ickn, _كلوﺑ, 
   {{0xfd6800c7,0x3d380276,0x5cc4121c,0x3e180276}},	//   _hasẽ, мплэ_, есиз, ьолэ_, 
   {{0x442072bb,0x7e6072bc,0x61ec011c,0x213c00ae}},	//   oni_, _wump, _iobl, _áth_, 
   {{0x61ec72bd,0x7e6072be,0xc5fc0729,0x87441954}},	//   _hobl, _tump, ঁচটা_, ረመስቀ, 
   {{0x61ec72bf,0x7e60079b,0x63a4045a,0xb4bc72c0}},	//   _kobl, _uump, _mckn, _इन्_, 
   {{0x442072c1,0x61ec72c2,0xec34006c,0x00000000}},	//   hni_, _jobl, _یولگ, --, 
   {{0x442072c3,0x61ec41a0,0x63a472c4,0x69a005c0}},	//   kni_, _mobl, _ockn, _खारी, 
   {{0x61ec014f,0xfd6800e4,0x6c740139,0x00000000}},	//   _lobl, _nasẽ, _руфх, --, 
   {{0x61ec0589,0x8c4072c5,0xc6f8054d,0x00000000}},	//   _oobl, _сеце, енях_, --, 
   {{0x58f8025c,0xded802d3,0x63a472c6,0x80d005d7}},	//   ྒྱུས_, _ኮይነ_, _ackn, सटाइ, 
   {{0x442072c7,0x9f440489,0xdc100356,0x00000000}},	//   fni_, rkoù_, cşăn, --, 
   {{0x49380302,0x61ec01ab,0x3c0c00bc,0x9f440489}},	//   _מגוו, _aobl, těvy_, skoù_, 
   {{0x61ec72c8,0x776c014b,0xb35425f1,0x2848010f}},	// [85b0] _bobl, _ifax, ткаш, _קעפּ, 
   {{0x61ec72c9,0x63a4035a,0x00000000,0x00000000}},	//   _cobl, _eckn, --, --, 
   {{0xded8067d,0x823472ca,0x25dc375c,0x3e480023}},	//   _ኮይኑ_, ارقا, खारी_, _ፖሊካር, 
   {{0x44201505,0x61ec04cc,0xffe412fa,0x00000000}},	//   cni_, _eobl, лючн, --, 
   {{0x6da472cb,0x69a00574,0xada458c9,0x61ec05c7}},	//   вила, _खाली, валл, _fobl, 
   {{0xa2a45c0e,0xf1940166,0xfeb81291,0x00000000}},	//   _चमत्, _шигь, عانت_, --, 
   {{0x2b5c004b,0x26c00083,0x6e040014,0x23640153}},	//   _pgwc_, zwko_, _یِرن, žoje_, 
   {{0x2bbc00dc,0x00000000,0x00000000,0x00000000}},	//   ्येथ, --, --, --, 
   {{0x8e300261,0x61ec72cc,0x81d40154,0x1dd0000d}},	//   кeдo_, _yobl, িউর_, _धोवत, 
   {{0x442072cd,0x2bd002ab,0xddd800e8,0xe8f81c35}},	//   zni_, _दोरा, _nitň, дло_, 
   {{0x442072ce,0xe3c02737,0x00000000,0x00000000}},	//   yni_, lkış_, --, --, 
   {{0x7b080e78,0x442072cf,0xbd7001af,0x00000000}},	//   ßstä, xni_, _кңәш, --, 
   {{0xded8044e,0x25dc72d0,0x7a340109,0x468402dd}},	//   _ኮይና_, खाली_, ràtr, ықпа, 
   {{0x442072d1,0x86500296,0xc9843e4f,0x60c0033f}},	//   wni_, _epɔn, _чуди, łomi, 
   {{0x59a4069f,0x61ec72d2,0x7a34004e,0xa3dc01ad}},	//   _खातर, _robl, pàtr, ढाल_, 
   {{0x442072d3,0x61ec72d4,0xdcf800b8,0x00000000}},	//   uni_, _sobl, _jetā, --, 
   {{0x442072d5,0x61ec72d6,0xdcf800da,0xe61004fb}},	// [85c0] rni_, _pobl, _metā, _نشد_, 
   {{0x68340005,0x61ec014f,0xdcf80171,0xa3bc0210}},	//   cádr, _qobl, _letā, _इसक_, 
   {{0x81d4015b,0x61ec72d7,0x00000000,0x00000000}},	//   িউল_, _vobl, --, --, 
   {{0x442072d8,0xe28472d9,0xdcf800e2,0x63a402d0}},	//   qni_, _илми, _netā, _uckn, 
   {{0xe7a8028a,0x61ec72da,0x8fa00828,0x5f0402e8}},	//   _कानप, _tobl, раче, ъзда, 
   {{0x61ec05a1,0xc1043b49,0xd24c009f,0xca3800d1}},	//   _uobl, _йүзл, _ونَ_, ﻐﯩﺮ_, 
   {{0x205472db,0xefbc0023,0x00000000,0x00000000}},	//   _атар, ሰድዎ_, --, --, 
   {{0xab5c033f,0xdcf8002b,0xe04801d5,0x28d4043e}},	//   jeżd, _cetā, _آشسه_, धिनि, 
   {{0xa3b8012c,0x1ea800ec,0xdcf800de,0x00000000}},	//   _आउन_, _تازي_, _detā, --, 
   {{0x200401af,0x3f84009f,0xdb1c0008,0xa02000c5}},	//   lhoi_, _hemu_, _þvíl, _ööbi, 
   {{0xdcf872dc,0x3f8419a2,0x00000000,0x00000000}},	//   _fetā, _kemu_, --, --, 
   {{0x3f8472dd,0x200472de,0x00000000,0x00000000}},	//   _jemu_, nhoi_, --, --, 
   {{0x3f8472df,0x1ae408ca,0x66701888,0xcb6400f3}},	//   _memu_, _шодм, یگیر, _раче_, 
   {{0x7bc072e0,0x69c405f7,0x59740124,0x00000000}},	//   lemu, _óhep, _рыду, --, 
   {{0x62980618,0x798872e1,0x66b00220,0x093026d4}},	//   _ātoa, madw, _құру, _پروج, 
   {{0x7bc072e2,0x798872e3,0x3f8472e4,0x27f00118}},	//   nemu, ladw, _nemu_, ěnná_, 
   {{0x36d472e5,0x81ac015b,0x200472e6,0x51a8005b}},	// [85d0] _сопр, কজন_, dhoi_, дъем_, 
   {{0x7bc072e7,0xd1b80a2c,0xb80403d4,0x79880368}},	//   hemu, بارا_, _উদিত_, nadw, 
   {{0x7bc072e8,0xd0a801c6,0xab5c012d,0x058401ec}},	//   kemu, ьтад_, leże, _туым, 
   {{0x3f842ce2,0x7bc0603f,0xc5f40198,0x798872e9}},	//   _cemu_, jemu, _ruɓi_, hadw, 
   {{0xc2e40517,0x7bc072ea,0x3f8472eb,0x7988090c}},	//   _кўри, demu, _demu_, kadw, 
   {{0xfe705b2c,0x3dcc00a9,0x798872ec,0x98a0033f}},	//   زده_, _cadw_, jadw, łkę_, 
   {{0xdd8c037b,0x3f842b1d,0x7bc072ed,0xada40131}},	//   سوي_, _femu_, femu, ваһл, 
   {{0x7bc072ee,0x3f8472ef,0x200472f0,0x00000000}},	//   gemu, _gemu_, choi_, --, 
   {{0x5ca4030c,0x79880042,0xdcf824b8,0x00000000}},	//   _ەلمە, fadw, _vetā, --, 
   {{0x798872f1,0x3dcc00a9,0x7bc000b0,0x3f8472f2}},	//   gadw, _gadw_, aemu, _zemu_, 
   {{0x7bc072f3,0xa2c872f4,0x3f8472f5,0x6d440254}},	//   bemu, _सैन्, _yemu_, ühad, 
   {{0x2d8472f6,0xfbd072f7,0x7bc072f8,0x66e43542}},	//   _hele_, _وتن_, cemu, гома, 
   {{0x2d8472f9,0x2fcc0369,0x79880925,0xf408015b}},	//   _kele_, _maeg_, badw, রচার_, 
   {{0x64a472fa,0x966072fb,0x2fcc0007,0x2bbc07b7}},	//   лага, скре, _laeg_, ्यका, 
   {{0x2d8472fc,0x5e5400c8,0x34f400d4,0x00000000}},	//   _mele_, טישע_, аїтт, --, 
   {{0x2d8472fd,0x73980c69,0x6b880421,0x00000000}},	//   _lele_, ктус_, naeg, --, 
   {{0x2d8400fb,0x6b880421,0x69c001f7,0x3f8472fe}},	// [85e0] _oele_, iaeg, oele, _remu_, 
   {{0x2d8472ff,0x3f847300,0x27f05dd8,0xdb0806af}},	//   _nele_, _semu_, _hoyn_, énér, 
   {{0x7bc07301,0x6b887302,0x69c000ec,0x5a1400c8}},	//   yemu, kaeg, iele, נקען_, 
   {{0x2d847303,0x2fcc0194,0xf3f0001e,0x626402dd}},	//   _aele_, _caeg_, ệt_, _ماسق, 
   {{0x7bc07304,0x2fcc0097,0x3f843d0e,0x6b880156}},	//   vemu, _daeg_, _vemu_, daeg, 
   {{0x2d841142,0x69c07305,0x3f840099,0x7bc07306}},	//   _cele_, jele, _wemu_, wemu, 
   {{0x69c07307,0x3f847308,0x7bc0207a,0x2004073c}},	//   dele, _temu_, temu, phoi_, 
   {{0x2d840770,0x61fc7309,0x2fcc0165,0x7988730a}},	//   _eele_, lkpl, _gaeg_, wadw, 
   {{0x69c0730b,0x2d84730c,0x7bc0730d,0xd004730e}},	//   fele, _fele_, remu, _сете_, 
   {{0x7bc0730f,0xdcf8084c,0x2d847310,0x61fc0af9}},	//   semu, _cetă, _gele_, nkpl, 
   {{0x79887311,0x27f0062c,0x6b88003e,0x395842a7}},	//   radw, _boyn_, baeg, ärs_, 
   {{0x69c00032,0x62980618,0x79887312,0xcb640536}},	//   aele, _āton, sadw, _баце_, 
   {{0x69c06336,0x7988017a,0x61fc2147,0x2d841ed9}},	//   bele, padw, kkpl, _yele_, 
   {{0x61fc01a4,0x00000000,0x00000000,0x00000000}},	//   jkpl, --, --, --, 
   {{0xab5c038f,0xca4400c6,0x1cc00327,0xf8a8012d}},	//   reże, _حلوه_, _ཏགས_, _कमिय, 
   {{0x337460a9,0xddc07313,0x27f00067,0x61fc0b4f}},	//   ргар, jpož, _goyn_, ekpl, 
   {{0x7cdc0356,0x41e008a3,0x00000000,0x00000000}},	// [85f0] _hără, नांस, --, --, 
   {{0x50647314,0x91047315,0x6b8801c4,0x91280131}},	//   гтда, лчед, zaeg, ىساق_, 
   {{0x2d8411c1,0x2fcc0393,0x741401e2,0xcee87316}},	//   _rele_, _paeg_, _نودا, کران_, 
   {{0x2d847317,0x057404fb,0x61fc0af9,0x7cdc054e}},	//   _sele_, _پاید, akpl, _mără, 
   {{0x2d847318,0x2fcc0399,0x6b8804c9,0x40940131}},	//   _pele_, _vaeg_, vaeg, للەر, 
   {{0x69c07319,0x2d84731a,0x6b88731b,0xc69c1ee0}},	//   xele, _qele_, waeg, _ፋብሪካ_, 
   {{0x2d84731c,0x0638008f,0x2fcc24a6,0x6810005f}},	//   _vele_, אנגט_, _taeg_, rādz, 
   {{0xd6f4069f,0xdcf80276,0x92e4015b,0xab64731d}},	//   ुनाथ_, _setă, বনী_, швил, 
   {{0x2d84731e,0x6b88030a,0xbbe81cbf,0x27f006ea}},	//   _tele_, raeg, ارىم_, _royn_, 
   {{0x2d84731f,0x6b8800af,0xc77400f7,0x69c07320}},	//   _uele_, saeg, өтмө, uele, 
   {{0x69c07321,0x7cdc0311,0xbb3c0150,0x00000000}},	//   rele, _cără, _ﻓﻌﻼ_, --, 
   {{0x7cdc0356,0x7d04008f,0x6eb80037,0x00000000}},	//   _dără, ĝist, _इहाँ, --, 
   {{0x61fc0b21,0x248401f1,0x29180054,0x27f0062c}},	//   ykpl, _ňom_, ńsa_, _voyn_, 
   {{0x69c07322,0x7cdc054e,0xfbd00133,0xf1d404af}},	//   qele, _fără, _وتۆ_, _डोलन, 
   {{0xdb0000c7,0x00000000,0x00000000,0x00000000}},	//   _mboý, --, --, --, 
   {{0x64a47323,0x656c01e7,0x00000000,0x00000000}},	//   лаҳа, scbh, --, --, 
   {{0xddc008a4,0x826800dd,0x21680256,0xe5780395}},	// [8600] vpož, اشرہ_, визи_, _изп_, 
   {{0x21e00150,0x00000000,0x00000000,0x00000000}},	//   _ﺍﻷﺒﺭ, --, --, --, 
   {{0x61fc7324,0xc0e002d3,0x78480055,0x002800f1}},	//   rkpl, _ሓደራ_, _aśvy, هګرو_, 
   {{0x8e340efc,0xcf940798,0x61fc0162,0x00000000}},	//   یسور_, ајш_, skpl, --, 
   {{0x3ed4007b,0xddc4024c,0x00000000,0x00000000}},	//   إقتر, ибди, --, --, 
   {{0xd0b000ac,0x63b40ea0,0xc2246ea9,0xdde80b24}},	//   hşət, lfyn, _اکرو, ضرته_, 
   {{0x9cc87325,0xe0d00050,0xfce83229,0xddc00003}},	//   тыла_, _بٲز_, افعي_, mpoż, 
   {{0x8fa07326,0x4fa001d5,0x63b40142,0x00000000}},	//   _масе, _мисв, nfyn, --, 
   {{0xddd802b1,0x7cdc0311,0x2bbc0b98,0x7e780166}},	//   _hitō, _sără, ्यजा, _сәет_, 
   {{0x99647327,0x7cdc0276,0x9524031c,0x49d435c7}},	//   штил, _pără, _རྨའི_, адью_, 
   {{0x63b47328,0x2bd000af,0x5ba800db,0x37f80166}},	//   kfyn, _दोका, _акем_, генэ_, 
   {{0xaf3402d3,0x37c401e0,0x00000000,0x00000000}},	//   _እናሃለ, сәкб, --, --, 
   {{0xec34006c,0x63b47329,0xf3f801a9,0x00000000}},	//   _اونگ, dfyn, қнаш_, --, 
   {{0x186415ed,0xd1dc02d3,0x7cdc0356,0x00000000}},	//   _књиг, ዒታት_, _tără, --, 
   {{0xb89400c6,0x63b44e0b,0x5884732a,0xd1b80092}},	//   _البع, ffyn, _тыла, ደንቅ_, 
   {{0xba1800b2,0xab5c0034,0x63b40042,0x90e457ff}},	//   _جيڪا_, leża, gfyn, یسان, 
   {{0xe19401c0,0xa2c81152,0x964400c0,0x00000000}},	// [8610] өлтө, _सैद्, _вэнд, --, 
   {{0xaa880023,0xc73c011a,0x30e40150,0x00000000}},	//   _መዐቀኒ_, _בתחת, йсең, --, 
   {{0x92e411ba,0x63b40175,0x245001d5,0x4fc467ba}},	//   বনে_, bfyn, تچیس, исда, 
   {{0xbb2401ec,0x801400d4,0xd344732b,0x6fe0134e}},	//   _ﹼﻬﻡ_, офіц, _نیزه_, फाइं, 
   {{0x6458732c,0x1de02c35,0x4f080131,0xab7800d1}},	//   ïtie, पांत, ختاپ_, ۇمغا_, 
   {{0x7204732d,0xf1f4013d,0x00000000,0x00000000}},	//   _اوسم, _узгэ, --, --, 
   {{0x93f80574,0xac3801c6,0xfca800ec,0x51080354}},	//   _एकाच_, лчих_, لايو_, _шĕкĕ, 
   {{0x58f80135,0x40340209,0xe9a400c7,0x00000000}},	//   ྒྱབས_, _десс, әанп, --, 
   {{0xa968009b,0xdcf800c0,0xd1d80092,0x00000000}},	//   липа_, _retą, _ኖሮት_, --, 
   {{0xceb401af,0x00000000,0x00000000,0x00000000}},	//   _бәҫ_, --, --, --, 
   {{0x63b403cb,0xd8741bf4,0xbca400ae,0x00000000}},	//   yfyn, یمیت_, _ومكي, --, 
   {{0x6d40732e,0x00000000,0x00000000,0x00000000}},	//   _iyla, --, --, --, 
   {{0xac740345,0x6700012d,0x00000000,0x00000000}},	//   _ئاڕش, रैंक_, --, --, 
   {{0x6d40732f,0xba0800db,0x00000000,0x00000000}},	//   _kyla, _ۅتۉك_, --, --, 
   {{0x6d407330,0x00000000,0x00000000,0x00000000}},	//   _jyla, --, --, --, 
   {{0x6d4000ee,0xe45816ab,0xf3f001fb,0xe57839b7}},	//   _myla, ужб_, ệp_, _өзи_, 
   {{0x63b40cfd,0x28d41d03,0x6d4000a2,0xd83c00d7}},	// [8620] rfyn, धिवि, _lyla, áčej_, 
   {{0xe3b07331,0x6d407332,0x95b00bd6,0x63b401e3}},	//   _کرد_, _oyla, _нөсх, sfyn, 
   {{0x6d407333,0xd5ac00aa,0xf1a800f1,0x00000000}},	//   _nyla, _ښځې_, شاله_, --, 
   {{0xd12c7334,0xddc0003d,0x44d802fd,0x00000000}},	//   رمن_, spoż, _ič_, --, 
   {{0x6d407335,0x44d801fa,0x6454002f,0xddc0025c}},	//   _ayla, _hč_, mmyi, ppoż, 
   {{0x44d802f8,0x71700131,0xdee402a9,0x00000000}},	//   _kč_, _يۇقا, _қози, --, 
   {{0x10a0119e,0x00000000,0x00000000,0x00000000}},	//   _нирн, --, --, --, 
   {{0x6d400cfd,0x3a747336,0x9e6400d8,0x44d80c5e}},	//   _dyla, олир, _гвад, _mč_, 
   {{0x44d80699,0x6d400455,0x5f0400c7,0x93f80375}},	//   _lč_, _eyla, _узаа, טלקי, 
   {{0x44d801ef,0x00000000,0x00000000,0x00000000}},	//   _oč_, --, --, --, 
   {{0x44d87337,0x4dd80375,0x6d407338,0x2be400cd}},	//   _nč_, _תחבו, _gyla, काशं_, 
   {{0x81d404c5,0x6b840137,0xe8ec00ec,0x00000000}},	//   িউট_, _ۇشۇل, ئڻو_, --, 
   {{0xab5c068f,0x50180375,0x2be400dc,0x44d800bc}},	//   leżn, רוכו, कारं_, _ač_, 
   {{0x6d40010e,0x00000000,0x00000000,0x00000000}},	//   _yyla, --, --, --, 
   {{0xd7f804b4,0x6d407339,0x4df8010f,0x00000000}},	//   _буп_, _xyla, נפלא, --, 
   {{0xc4e403ee,0x44d80100,0x80dc01ad,0xcc7400d9}},	//   яƒє_, _dč_, फिने, מעלה_, 
   {{0xa3b8007d,0x53441734,0xef18025c,0x44d80171}},	// [8630] _आउर_, схва, _teżi_, _eč_, 
   {{0x44d80d29,0x60cc0076,0x04b801d3,0xc32800cc}},	//   _fč_, _bsbm, جھیں_, _মৰহি_, 
   {{0x8650013f,0x41741d00,0xe81407f7,0x91480022}},	//   _apɔw, سالس, दोवा_, учаа_, 
   {{0x6d40733a,0x49380a7c,0x957c0092,0x00000000}},	//   _ryla, נגאו, ንዳችን_, --, 
   {{0x6d400209,0xc214016b,0x44d8733b,0x25dc0073}},	//   _syla, mpɔn_, _zč_, खाची_, 
   {{0x6d40733c,0x999c00c0,0x00000000,0x00000000}},	//   _pyla, imtų_, --, --, 
   {{0x5c7030cb,0xe7a80825,0x6d400200,0x4960010b}},	//   үләт, _कालप, _qyla, үниң, 
   {{0x799803ac,0x6d400306,0x606000d1,0x7d0401e4}},	//   _advw, _vyla, _قۇلل, ĝisp, 
   {{0x6d40733d,0xe9a401f4,0x00000000,0x00000000}},	//   _wyla, оапп, --, --, 
   {{0x3ea000c6,0x28d400dc,0x6d400064,0x00000000}},	//   áite_, धिलि, _tyla, --, 
   {{0x6d40733e,0xbdf82309,0x5ca4247f,0xbb8401e2}},	//   _uyla, _ارقا_, _ولكە, _ځلمي, 
   {{0x3ea0341a,0x37740024,0xbb841291,0x00000000}},	//   šite_, зырс, _فلمي, --, 
   {{0x44d80100,0x602c01e4,0x00000000,0x00000000}},	//   _sč_, nĝma, --, --, 
   {{0x44d8733f,0x1f58010f,0x00000000,0x00000000}},	//   _pč_, ידרא, --, --, 
   {{0xa80405d1,0xcfe402dd,0x79a40798,0xbb600092}},	//   _akış, _ﺍﺗﺎﻗ, _хрче, _መሳተፋ, 
   {{0x683401a2,0x44d8012c,0x41ac0037,0x00000000}},	//   hádz, _vč_, _चाहस, --, 
   {{0x44d802bd,0x412801e0,0xd24c0014,0xab5c0210}},	// [8640] _wč_, әнеү_, ھنم_, zeżn, 
   {{0x44d87340,0x7ae400c6,0x2bd00574,0x00000000}},	//   _tč_, _áite, _दोघा, --, 
   {{0xa0c4004b,0x90b002d9,0x44d812fe,0x00000000}},	//   تياو, мәтш, _uč_, --, 
   {{0x1ea81c4e,0xd6d401b9,0x00000000,0x00000000}},	//   لاتي_, _اویش_, --, --, 
   {{0x44207341,0x73c00184,0x00000000,0x00000000}},	//   mii_, _яҡта, --, --, 
   {{0x44207342,0x7bdc005f,0x15e000bc,0x00000000}},	//   lii_, ērum, खाएर_, --, 
   {{0x44207343,0xe7a80aff,0x69dc005f,0x98a03e16}},	//   oii_, _कांप, ēsel, ākī_, 
   {{0x44207344,0x30747345,0x88cc02f5,0x00000000}},	//   nii_, _хурс, িমাক, --, 
   {{0xd24c01d3,0x00000000,0x00000000,0x00000000}},	//   _سچے_, --, --, --, 
   {{0x44207346,0x39140229,0xbec80171,0x00000000}},	//   hii_, змор, grūš, --, 
   {{0xa3c87347,0xe87c0055,0x00000000,0x00000000}},	//   लजा_, _įųãn_, --, --, 
   {{0x44200a4d,0x1ae4034b,0x9a8400f3,0x00000000}},	//   jii_, _моем, _дукл, --, 
   {{0x44207348,0xcf900375,0x89d400e5,0x00000000}},	//   dii_, וטר_, _ڈونر_, --, 
   {{0x799800d2,0x7c20009f,0x9474007b,0xe3c40116}},	//   _udvw, limr, قدرا, үртү, 
   {{0x44207349,0x6e3c02d2,0x93881fce,0x00000000}},	//   fii_, _ísbe, исаа_, --, 
   {{0x4420734a,0x7c20734b,0xb274036b,0xfbbc3c71}},	//   gii_, nimr, злаш, ्जिम, 
   {{0x78a8734c,0x451c00eb,0x00000000,0x00000000}},	// [8650] ludv, _দুদক_, --, --, 
   {{0x4420734d,0xf49402d3,0x82345a57,0x85741572}},	//   aii_, _ክፍለጥ_, ورلا, _ольх, 
   {{0x4420734e,0x683401a2,0x78a872ab,0xfbbc190c}},	//   bii_, vádz, nudv, ्जाम, 
   {{0x4420734f,0x3e7001c3,0x15e0012d,0x00000000}},	//   cii_, _bàt_, खाकर_, --, 
   {{0xb8dc0135,0x78a82acd,0xe7fc00ab,0x7c207350}},	//   _ཅཱ_, hudv, _उकसा_, dimr, 
   {{0x78a8192e,0x21340066,0x00000000,0x00000000}},	//   kudv, édhé_, --, --, 
   {{0xeb987351,0x683400d0,0xfa200154,0x00000000}},	//   бий_, rádz, নকাল_, --, 
   {{0x68340419,0xae1c5572,0x9b9000d1,0x00000000}},	//   sádz, _भगवन_, ىلىت, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x44207352,0xcce47353,0x78a87354,0x3e180262}},	//   zii_, _وساي, fudv, _доуэ_, 
   {{0x44207355,0x8650016b,0x78a87354,0xac180b3b}},	//   yii_, _mpɔt, gudv, _ложу_, 
   {{0x44200a81,0x9c80022a,0xdcf80118,0x00000000}},	//   xii_, áčen, _letě, --, 
   {{0x44207356,0xa9685211,0xf6d400d4,0xe9d801f4}},	//   vii_, _лила_, міря, _гкл_, 
   {{0x44207357,0x9c800f72,0x78a87358,0xdcf80118}},	//   wii_, ščen, budv, _netě, 
   {{0x44207359,0xd940735a,0xd83c09a8,0x6aa8735b}},	//   tii_, _пеши, ščaj_, luef, 
   {{0x4420735c,0x00000000,0x00000000,0x00000000}},	//   uii_, --, --, --, 
   {{0x4420735d,0xa2046215,0xd3842ae3,0xe298735e}},	// [8660] rii_, ппад, яйте_, саз_, 
   {{0x4420735f,0x7c200099,0xd1b001d3,0x9734011a}},	//   sii_, zimr, ٹیفک, _מרפא_, 
   {{0x44207360,0xd00c1a4d,0x6aa80270,0x7c2004ba}},	//   pii_, گلن_, huef, yimr, 
   {{0x44207361,0xaabc5829,0x6aa87362,0x23280117}},	//   qii_, ्बाक, kuef, _гоми_, 
   {{0xf8a80d2b,0x66fc03f3,0xd00c0531,0x2be40037}},	//   _कम्प, ॉनिक_, دلن_, काईं_, 
   {{0xbd68052f,0x2c70007b,0x7c2002d1,0x62940100}},	//   әрҙе_, _bád_, wimr, msyo, 
   {{0x7c2002d1,0x62947363,0x00000000,0x00000000}},	//   timr, lsyo, --, --, 
   {{0x78a87364,0x6aa854bb,0x7ac4004e,0x00000000}},	//   vudv, fuef, дөка, --, 
   {{0x62945f79,0x7c201529,0x6aa8016b,0x78a80af2}},	//   nsyo, rimr, guef, wudv, 
   {{0x2c7001ab,0x200401c4,0x7c2003f0,0x5e28009f}},	//   _fád_, lkoi_, simr, _اثرَ_, 
   {{0x602c01e4,0xab5c0135,0x00000000,0x00000000}},	//   nĝmo, neżj, --, --, 
   {{0x62947365,0x78a87366,0x20040108,0x80c400ce}},	//   ksyo, rudv, nkoi_, _रहने, 
   {{0x78a87367,0x62947368,0x200400b0,0x6aa8003a}},	//   sudv, jsyo, ikoi_, cuef, 
   {{0x2004036e,0x00000000,0x00000000,0x00000000}},	//   hkoi_, --, --, --, 
   {{0x49b823e4,0x2004005b,0x00000000,0x00000000}},	//   _המוס, kkoi_, --, --, 
   {{0x661c03ac,0x2be4033f,0x00000000,0x00000000}},	//   _empk, काएं_, --, --, 
   {{0x95c84b7d,0x62941c06,0x479c011a,0x83347369}},	// [8670] _луна_, gsyo, _היחס, ентх, 
   {{0x6ff80154,0x00000000,0x00000000,0x00000000}},	//   _আগেও_, --, --, --, 
   {{0x7e7c151c,0x62940bc2,0x00000000,0x00000000}},	//   _črpa, asyo, --, --, 
   {{0x2c7040cf,0x3ce0012c,0xf8b80022,0xb90c01e1}},	//   _rád_, किने_, itĩ_, _sumọ_, 
   {{0x6294007f,0x51840329,0x2c700419,0xab5c0327}},	//   csyo, _нува, _sád_, teżm, 
   {{0x6da4736a,0x2c700122,0xdee03129,0x939401d3}},	//   фика, _pád_, тоши, _بجھا, 
   {{0xfe4401c6,0x00000000,0x00000000,0x00000000}},	//   эмшү, --, --, --, 
   {{0x3ea01ebd,0x1b1c00bd,0x7ae42ba4,0x6aa80d12}},	//   šita_, _পড়ে_, _šita, tuef, 
   {{0x3ef80276,0xb90c0ca8,0xca6000c7,0x92b800cc}},	//   _ентэ_, _tumọ_, неиқ, _আছু_, 
   {{0xef180135,0x00000000,0x00000000,0x00000000}},	//   _feżr_, --, --, --, 
   {{0x6aa8736b,0x4ad40014,0x6294007f,0x00000000}},	//   suef, زاکھ_, zsyo, --, 
   {{0x661c003e,0x23640024,0xc5f80243,0x3a380010}},	//   _smpk, žoji_, ुस्य_, črpa_, 
   {{0xd1e402d3,0x59a401ad,0x00000000,0x00000000}},	//   ዙሓት_, _खाचर, --, --, 
   {{0x69240640,0x26d0022e,0xdc540133,0x6294007f}},	//   _омла, _vsyo_, _فرۆک, vsyo, 
   {{0x154001b9,0x96601fbe,0xa5080f06,0xdfdc012d}},	//   верм, ткре, цева_, ółkę_, 
   {{0x6294007f,0xab5c0327,0x5eec01f9,0x00000000}},	//   tsyo, veżj, _आपल्_, --, 
   {{0xe1f8736c,0x62940280,0x1dac0490,0xd6cc06f6}},	// [8680] ога_, usyo, _घालत, _نقي_, 
   {{0x6294736d,0x6e2c004a,0x661c736e,0x3f9800b8}},	//   rsyo, éabl, _umpk, _śru_, 
   {{0x6294736f,0xffa40032,0x2004023a,0x64a40139}},	//   ssyo, елеү, tkoi_, _юана, 
   {{0x62945f8c,0xd00c004b,0xab5c0327,0x58f4010f}},	//   psyo, ټله_, reżj, וצען_, 
   {{0x20047370,0x00000000,0x00000000,0x00000000}},	//   rkoi_, --, --, --, 
   {{0x717004a9,0x2004005a,0x00000000,0x00000000}},	//   _مۇكا, skoi_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4ef80375,0x13d4015b,0xbaa40116,0x00000000}},	//   _והמו, হায়, _ﺋﻪﻧﮕ, --, 
   {{0x1cb00327,0x8af406be,0x2b500210,0x7ec801e1}},	//   _ྟའི_, _çəni, ęzca_, bépò, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdcf80139,0xd90c01d3,0xbbbc1db2,0x00000000}},	//   _ictı, _چیخ_, ्जीक, --, 
   {{0x8a000801,0xaabc00bc,0x00000000,0x00000000}},	//   _изче, ्बरक, --, --, 
   {{0x999c0418,0x387c01a6,0x82240154,0x7e68045a}},	//   nitō_, _utvr_, বকাপ_, _midp, 
   {{0x38b87371,0x999c02b1,0x80c8012c,0x00000000}},	//   mér_, kotū_, रबैं, --, 
   {{0x38b83386,0x32547372,0x776c0077,0xa2c00116}},	// [8690] lér_, евар, _igax, ләрк, 
   {{0x38687373,0x7e680455,0x00000000,0x00000000}},	//   _hiar_, _nidp, --, --, 
   {{0x38687374,0x38b8013a,0x7644378b,0x92dc03d4}},	//   _kiar_, nér_, _ikhy, তহে_, 
   {{0x7e68127b,0xa2c82e05,0x00000000,0x00000000}},	//   _aidp, _सैक्, --, --, 
   {{0x38687375,0x38b800dd,0xb8f00135,0x6b80063f}},	//   _miar_, hér_, _ུར_, _ịgos, 
   {{0x38687376,0xdcf803e0,0x5108010a,0x00000000}},	//   _liar_, _actı, _мĕлĕ, --, 
   {{0xeb9800a8,0x776c014b,0x9d400209,0x38b83e3b}},	//   пий_, _ogax, лешд, jér_, 
   {{0xeb987377,0x776c004b,0x38687378,0x9c8000d0}},	//   чии_, _ngax, _niar_, áčan, 
   {{0x5ac412c4,0x09d000eb,0x00000000,0x00000000}},	//   елым_, ়াসা, --, --, 
   {{0x9c8049ad,0x999c003a,0x38b87379,0xab5c025c}},	//   ščan, bitō_, fér_, neżi, 
   {{0x38682c48,0x38b8737a,0x1cbc0327,0x00000000}},	//   _biar_, gér_, _ཇཱར_, --, 
   {{0x386801c3,0x7644737b,0x2be4033f,0x13d40154}},	//   _ciar_, _akhy, काओं_, হাড়, 
   {{0x3868737c,0xaa580588,0xe9a406a6,0xa9a4022e}},	//   _diar_, _еиду_, _залп, _зилд, 
   {{0x38b8737d,0x246801e4,0xd7ec0150,0x00000000}},	//   bér_, _aŝma_, _ۇكى_, --, 
   {{0x38b8737e,0xf6640724,0x386801ab,0x2ab802bd}},	//   cér_, терү, _fiar_, lèb_, 
   {{0xe73834d8,0x38680076,0x2904737f,0xa5240131}},	//   _ней_, _giar_, myla_, _үмид, 
   {{0xc1e87380,0x2ab80100,0x23740150,0x2904010e}},	// [86a0] وکسل_, nèb_, _ۋاحح, lyla_, 
   {{0x38687381,0xa1341e87,0x1dac012c,0xa3b825da}},	//   _ziar_, ىراش, _घाइत, _کادر_, 
   {{0xa3e8529e,0x38681028,0xe1940323,0x7e68007c}},	//   _една_, _yiar_, _үргэ, _ridp, 
   {{0xa3b87382,0x6e20015d,0x7e680477,0x44242b15}},	//   _आउट_, _amlb, _sidp, _öm_, 
   {{0x6444006c,0x38b85955,0x2ab802e2,0x290415c0}},	//   _ikki, zér_, jèb_, hyla_, 
   {{0x29047383,0x999c00b0,0x7ae44a38,0x3ea00010}},	//   kyla_, rotū_, _šito, šito_, 
   {{0x7e687384,0x38b80306,0x00000000,0x00000000}},	//   _vidp, xér_, --, --, 
   {{0x38b87385,0xbbbc134e,0xab5c031c,0x29044632}},	//   vér_, ्जेक, neżw, dyla_, 
   {{0x7e68049f,0x999c0270,0x38681cf8,0x38b80098}},	//   _tidp, sitō_, _riar_, wér_, 
   {{0x38680ea3,0x38b87386,0xd2b4011a,0x0a480023}},	//   _siar_, tér_, עלית_, _ምብርካ, 
   {{0x64442e6d,0x38687387,0xcd780092,0xcaf000cf}},	//   _okki, _piar_, ዮጵያና_, _ەسىب, 
   {{0x38b87388,0x00000000,0x00000000,0x00000000}},	//   rér_, --, --, --, 
   {{0x38b87389,0x3868020b,0x00000000,0x00000000}},	//   sér_, _viar_, --, --, 
   {{0x6444738a,0x8cd40c5a,0x38b87389,0x2904012c}},	//   _akki, _मनमो, pér_, byla_, 
   {{0x38680649,0x490000cf,0x53e401c0,0xf8a4738b}},	//   _tiar_, _مووق, нцаа, _खटिय, 
   {{0x776c738c,0x83f800f3,0x00000000,0x00000000}},	//   _ugax, несс_, --, --, 
   {{0xab5c0327,0x00000000,0x00000000,0x00000000}},	// [86b0] teżi, --, --, --, 
   {{0xd1c80020,0xba040020,0x64444fd4,0x78a80b4f}},	//   _በታች_, _ጎን_, _ekki, ordv, 
   {{0x64440418,0xc0780212,0x0ca800fe,0xab5c031c}},	//   _fkki, есії_, _খন্ত, reżi, 
   {{0x2ab80100,0xd9e0000d,0x00000000,0x00000000}},	//   yèb_, _कोसत_, --, --, 
   {{0xdfcc4f4e,0xbfb40532,0xc2e401b9,0x2904738d}},	//   زيو_, احمت, _йўри, zyla_, 
   {{0x2ab80d29,0x9f4405c7,0x7bc0002f,0x321c015d}},	//   vèb_, njoù_, efmu, ëwyd_, 
   {{0x70640022,0xeff802d3,0x7bc0738e,0x2904007f}},	//   _ахаҧ, ላሳይ_, ffmu, xyla_, 
   {{0x2d6402a8,0x6ed4738f,0xa3b800bc,0xa02003e3}},	//   rɓe_, _मैथु, _आउछ_, _şövk, 
   {{0x2dd47390,0x5d5002d9,0x6e3c02d2,0x98b000ef}},	//   _ижар, лкәт, _ísbo, _ēdām_, 
   {{0x29043f05,0x3d9401f0,0x00000000,0x00000000}},	//   tyla_, _бифр, --, --, 
   {{0x9f440165,0x7c847391,0xa888074d,0x09d000eb}},	//   djoù_, _буче, ьйна_, ়ালা, 
   {{0x64580006,0x66a000d1,0x2ab80100,0x29047392}},	//   įtik, аңиғ, pèb_, ryla_, 
   {{0x6b887393,0x78a8257c,0x1cbc031c,0x644401f4}},	//   mbeg, ardv, _ཇཱོ_, _rkki, 
   {{0x569007d6,0x2fdc0369,0x6aa805ac,0xeb0c1431}},	//   раёт, hdwg_, mref, िनीत_, 
   {{0x6aa87394,0x7b6400c7,0x4900013d,0x00000000}},	//   lref, _итәе, _сүнг, --, 
   {{0xa6e4152d,0x69c07395,0x6b887396,0x2fdc0007}},	//   _ажил, lfle, nbeg, jdwg_, 
   {{0x76c4036b,0x00000000,0x00000000,0x00000000}},	// [86c0] _یغیل, --, --, --, 
   {{0xc0e80020,0x17540375,0x6b8846e1,0x6aa84738}},	//   _መነሻ_, _בספר_, hbeg, iref, 
   {{0x6aa82ac5,0x6b8801f5,0x69c07397,0xdfd80395}},	//   href, kbeg, ifle, дъл_, 
   {{0x6aa81700,0x6444013c,0x5f28013e,0x69c035c0}},	//   kref, _ukki, моем_, hfle, 
   {{0x6aa800b5,0xdea00345,0x00000000,0x00000000}},	//   jref, شیای, --, --, 
   {{0x6aa87398,0x69c02e22,0xe0d00050,0x7ae0010a}},	//   dref, jfle, _پٲر_, vvmt, 
   {{0x61ec1ed1,0x6aa87399,0x6b88002f,0x9fb801af}},	//   _inbl, eref, fbeg, _оѓає_, 
   {{0x6b88739a,0xa3b4739b,0x06e80183,0xdee40022}},	//   gbeg, च्च_, _পথনি, _иоби, 
   {{0x6aa8739c,0x7bc0002f,0x00000000,0x00000000}},	//   gref, rfmu, --, --, 
   {{0x6b880083,0xd12c00e5,0x00000000,0x00000000}},	//   abeg, _امہ_, --, --, 
   {{0x6b88002d,0x38c83a25,0x00000000,0x00000000}},	//   bbeg, رادی_, --, --, 
   {{0x6aa8739d,0x69c00165,0x00000000,0x00000000}},	//   bref, afle, --, --, 
   {{0xa3b42429,0x61ec739e,0xc6f8739f,0x6aa80175}},	//   च्छ_, _onbl, внях_, cref, 
   {{0x9f440156,0x00000000,0x00000000,0x00000000}},	//   ujoù_, --, --, --, 
   {{0x6e2c73a0,0xca445fab,0x9f440165,0xd7f80137}},	//   éabi, _جلوه_, rjoù_, _жуп_, 
   {{0x83a812d7,0x321002fb,0x12e40220,0x61ec73a1}},	//   ктуб_, _slzy_, кізг, _anbl, 
   {{0x360400c6,0x73380022,0x00000000,0x00000000}},	// [86d0] _موظف, хзар_, --, --, 
   {{0x61ec020b,0x61442dfc,0x6b8873a2,0x28a800dc}},	//   _cnbl, گىمە, zbeg, _किमि, 
   {{0xada43461,0x6aa801e4,0xdcf80171,0x999c01ef}},	//   ҳалл, zref, _metē, hotů_, 
   {{0x614415c3,0x6aa8383d,0x61ec6df3,0x8384023a}},	//   دىمە, yref, _enbl, _выре, 
   {{0x6da473a3,0xcee810e5,0x69c00368,0xada473a4}},	//   гила, بران_, yfle, галл, 
   {{0x7de40075,0xd6f800b5,0x6aa803cd,0x6b8873a5}},	//   لسىم, ngケ_, vref, wbeg, 
   {{0x6b880558,0x50641c13,0x6abc00dc,0x69c001bf}},	//   tbeg, _атаа, ्ब्र, vfle, 
   {{0x6aa873a6,0x8af40cc1,0x249c00d0,0x00000000}},	//   tref, _çəki, átmi_, --, 
   {{0xaa444132,0x69c073a7,0x985c003d,0x61ec002d}},	//   леил, tfle, _eċċ_, _ynbl, 
   {{0x6aa873a8,0xe8f873a9,0xe9d85080,0xbca800cf}},	//   rref, ело_, хко_, ردۉك_, 
   {{0x69c073aa,0x69240354,0xabb473ab,0xed500137}},	//   rfle, умна, _مماث, _اپا_, 
   {{0x6c54010b,0x6d44002f,0x999c013a,0x00000000}},	//   _ёкду, ühau, botů_, --, 
   {{0x69c00730,0x00000000,0x00000000,0x00000000}},	//   pfle, --, --, --, 
   {{0xdbd80166,0xc9843542,0x80c400c5,0xdb04032e}},	//   _eçäs, _руди, _रहले, _ámán, 
   {{0xab5c031c,0xe8f800d4,0x00000000,0x00000000}},	//   reżu, _їли_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa1c473ac,0x66e473ad,0x46a80210,0xe2840a5b}},	// [86e0] лбад, _сопа, _कटिह, улзи, 
   {{0x613873ae,0x00000000,0x00000000,0x00000000}},	//   нчер_, --, --, --, 
   {{0x1fa80124,0x00000000,0x00000000,0x00000000}},	//   екеи_, --, --, --, 
   {{0x25b80784,0x715873af,0xe4a400c7,0x05c0190c}},	//   _hcpl_, трус_, _ирҭо, श्रब, 
   {{0x53980302,0x8fa003d0,0xef90036b,0x63b473b0}},	//   _איכו, саче, زیلد, mgyn, 
   {{0x614473b1,0x63b46c51,0xdec802d3,0x61ec73b2}},	//   _бега, lgyn, _በጃኻ_, _unbl, 
   {{0x9c4473b3,0xdcf800ef,0x00000000,0x00000000}},	//   лхил, _retē, --, --, 
   {{0x63b473b4,0xa06873b5,0x57d001f9,0x00000000}},	//   ngyn, _чаба_, _तसेह, --, 
   {{0x8c400063,0xcec00118,0x80dc0027,0xb00400fb}},	//   љење, ěří_, फिके, _тотһ, 
   {{0x588473b6,0xc0cc0092,0x63b403cb,0x00000000}},	//   лыма, _በባሰ_, hgyn, --, 
   {{0x383473b7,0x1cbc0327,0x11f4010f,0x63b40432}},	//   инор, _ཇཱི_, אזיל_, kgyn, 
   {{0x386c01e6,0x00000000,0x00000000,0x00000000}},	//   öer_, --, --, --, 
   {{0x95c873b8,0x6b9c022c,0xdcf800b0,0x63b4015d}},	//   нува_, ðsge, _tetē, dgyn, 
   {{0x63b40064,0x99740117,0x00000000,0x00000000}},	//   egyn, _судш, --, --, 
   {{0x1cc80489,0x34946c43,0x00000000,0x00000000}},	//   ཊསི_, рабр, --, --, 
   {{0xb4c4033d,0x63b4062c,0x8cd4041c,0x00000000}},	//   _एही_, ggyn, _मनसो, --, 
   {{0x36d400ee,0xe27400f7,0x0c7402d3,0x290c00d0}},	// [86f0] _топр, иктө, _ኣነጺሩ_, čkať_, 
   {{0xcb540375,0xd1380116,0x30e4013d,0x31840150}},	//   רסמה_, нхе_, исең, ртаң, 
   {{0x61441e4a,0xfbac009e,0xd13873b9,0x63b40042}},	//   لىكە, ক্যত, хха_, bgyn, 
   {{0x733400d1,0x504800db,0x00000000,0x00000000}},	//   _نىجا, رجاپ_, --, --, 
   {{0x645807ea,0x7ae436f4,0xb4c4000d,0xc338010a}},	//   îtie, _áith, _एहु_, _чĕ_, 
   {{0xfe702050,0xfde80046,0x867c00c8,0x645800db}},	//   سده_, лдік_, ערוו, ïtiv, 
   {{0x7e740115,0x88c400bc,0x00000000,0x00000000}},	//   _ɾepɾ, _kněž, --, --, 
   {{0xbe8801ec,0x38980023,0x00000000,0x00000000}},	//   _әсте_, _መሰላቱ_, --, --, 
   {{0x1ee800f1,0x00000000,0x00000000,0x00000000}},	//   _ټولی_, --, --, --, 
   {{0x63b400ee,0xb4c4007d,0x00000000,0x00000000}},	//   zgyn, _एहू_, --, --, 
   {{0x63b40510,0xbe64082e,0xacd4013d,0x490001ec}},	//   ygyn, _اهلي, _әбҗә, сүйг, 
   {{0xc5b45bc9,0x00000000,0x00000000,0x00000000}},	//   өргө, --, --, --, 
   {{0xddd801ee,0x1cb0031c,0xe9d802a9,0x7984010e}},	//   _litŝ, _ཟའོ_, _акл_, _şiwe, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2448007b,0x00000000,0x00000000,0x00000000}},	//   نجري_, --, --, --, 
   {{0x3ea005ce,0x63840323,0x7ae473ba,0xa6941d39}},	//   šiti_, ргаа, _šiti, _крој, 
   {{0xd46473bb,0x63b473bc,0x27f00076,0x3ce00270}},	// [8700] рите_, rgyn, _inyn_, āivi_, 
   {{0x260406ed,0xa3e405d7,0x63b46c13,0xc0e80023}},	//   _vôos_, _योर_, sgyn, _መቐለ_, 
   {{0x27f0000f,0xe044020f,0x26dc02b5,0xa068041b}},	//   _knyn_, анжи, ātou_, важа_, 
   {{0xe3b073bd,0x44d80432,0xe2980120,0x525800d1}},	//   _برد_, _iō_, _иам_, ىسەڭ_, 
   {{0x3ea004c4,0x44d8123c,0x26c00010,0x00000000}},	//   éit_, _hō_, ntko_, --, 
   {{0x44d873be,0x7ae40597,0x26c0005b,0x6284365b}},	//   _kō_, _áiti, itko_, _itko, 
   {{0x10a013e7,0x12d404c5,0x44d8003e,0x27f0010b}},	//   _мирн, সমৃদ, _jō_, _onyn_, 
   {{0x44d81243,0x60cc009a,0xd00473bf,0x50400276}},	//   _mō_, _ipbm, _кесе_, _десб, 
   {{0x44d80069,0xd00400cf,0xedf400db,0x00000000}},	//   _lō_, _тете_, _گيلگ, --, 
   {{0xba181cbf,0x27f000a2,0xdca473c0,0xc4c401ec}},	//   ايدا_, _anyn_, _важи, _ﺨﺴﺎﺌ, 
   {{0x44d857af,0x794c010c,0xb4c400c5,0x00000000}},	//   _nō_, _ማንቸስ, _एहे_, --, 
   {{0x628405ce,0x00000000,0x00000000,0x00000000}},	//   _otko, --, --, --, 
   {{0x44d800a2,0x672000a2,0x00000000,0x00000000}},	//   _aō_, _ýojl, --, --, 
   {{0x44d802e2,0x88c400bc,0x9644009d,0x00000000}},	//   _bō_, _sněž, рэмд, --, 
   {{0x628473c1,0x26c073c2,0xd70400db,0x09d00154}},	//   _atko, atko_, _چىعۇ_, ়াখা, 
   {{0x337473c3,0x7998047e,0x00000000,0x00000000}},	//   сгар, _hevw, --, --, 
   {{0x79980085,0x918473c4,0x00000000,0x00000000}},	// [8710] _kevw, لجام, --, --, 
   {{0x75d473c5,0x98d873c6,0x35b473c7,0x44d873c8}},	//   _ايدا, _बनाए, _убор, _fō_, 
   {{0x62840d04,0x50641751,0x799802ea,0x741473c9}},	//   _etko, атда, _mevw, _هودا, 
   {{0x2ef46bb5,0xfbac0729,0x86e401d9,0x28a873ca}},	//   йзер, ক্তত, _آیو, _किसि, 
   {{0x40940075,0x00000000,0x00000000,0x00000000}},	//   ملەر, --, --, --, 
   {{0x79980455,0x309848dc,0x00000000,0x00000000}},	//   _nevw, _محرک_, --, --, 
   {{0xdcf80153,0xb4c400c5,0x00000000,0x00000000}},	//   _metė, _एहो_, --, --, 
   {{0x26c073cb,0x00000000,0x00000000,0x00000000}},	//   ytko_, --, --, --, 
   {{0x666001e1,0xed500014,0x28a8000d,0x2f140108}},	//   _lẹṣa_, _کھش_, _किहि, _удаё, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x799873cc,0x29105955,0xf76873cd,0x00000000}},	//   _devw, áza_, _נק_, --, 
   {{0x44d80374,0xa3e40034,0x06840aac,0x4ad400e5}},	//   _rō_, _यों_, оҳин, _ناتھ_, 
   {{0x395401a2,0x7998007f,0x6a8473ce,0x00000000}},	//   _časť_, _fevw, _улла, --, 
   {{0x44d873cf,0x26c073d0,0x81cc00eb,0x00000000}},	//   _pō_, rtko_, _শোন_, --, 
   {{0x26c0006d,0x8de80327,0x5e54010f,0x00000000}},	//   stko_, _ཡོནལ, מישע_, --, 
   {{0x33f400cf,0x7af0000d,0x395803e0,0x00000000}},	//   очус, _ühtä, ürse_, --, 
   {{0x44d802b1,0x26dc00e2,0xddd806be,0x1a78010f}},	// [8720] _wō_, ātos_, _nitş, ָװעמ, 
   {{0x44d81f4c,0x9c800fb7,0x21680b38,0x217473d1}},	//   _tō_, ščin, гизи_, суар, 
   {{0x99981a4c,0xa50873d2,0x44d80607,0x28dc033f}},	//   רבעט, _сена_, _uō_, _फैमि, 
   {{0x601800e4,0x8fa00354,0x00000000,0x00000000}},	//   _oïme, заце, --, --, 
   {{0x62845794,0xa29800db,0xbf6401d5,0x73c000fb}},	//   _utko, _حئجر_, زگرو, _юҡта, 
   {{0xe3b0012f,0x975808d8,0x975405d0,0x00000000}},	//   _برگ_, נדסט, זינו_, --, 
   {{0x799837b6,0x557400c8,0x9cc873d3,0x00000000}},	//   _revw, זעצן_, уыла_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xda7802d5,0xb4c4000d,0x00000000,0x00000000}},	//   ыяй_, _एह्_, --, --, 
   {{0xdc6c0020,0x4f0400db,0x00000000,0x00000000}},	//   ጠቃላይ_, _унун_, --, --, 
   {{0x1cb0025c,0x9be40212,0xdcf80064,0x00000000}},	//   _ཟའི_, _гілк, _retė, --, 
   {{0x28a873d4,0x3ea002f0,0x7ae473d5,0x00000000}},	//   _किरि, šitu_, _šitu, --, 
   {{0x3ea403b2,0x41d800e1,0x00000000,0x00000000}},	//   _jvmt_, ड़ास, --, --, 
   {{0x09e00a8f,0x6b98025c,0x915c0208,0x3c4401f7}},	//   _ночн, _zewg, _lắp_, _اَچِ, 
   {{0x6b8c0356,0x6b980139,0x00000000,0x00000000}},	//   _îngâ, _yewg, --, --, 
   {{0xddd801d3,0x440400db,0x00000000,0x00000000}},	//   _mitő, пчуб, --, --, 
   {{0x2bd8000d,0x4274498b,0x964401c4,0x00000000}},	// [8730] ढ़ता, згус, _гэнд, --, 
   {{0xf484105d,0xd5b80305,0x00000000,0x00000000}},	//   _واجی, _сси_, --, --, 
   {{0x4a58011a,0x00000000,0x00000000,0x00000000}},	//   נדבו, --, --, --, 
   {{0x70c80406,0x245c0022,0xd34402f2,0x00000000}},	//   _रहील, tïme_, _هیزه_, --, 
   {{0x518473d6,0x00000000,0x00000000,0x00000000}},	//   _губа, --, --, --, 
   {{0x816403e6,0xad2404da,0x6b980327,0x28a82ca5}},	//   _کۆمۆ, يىشى, _sewg, _किलि, 
   {{0xed5856ac,0xfca805d9,0xd6cc00cc,0x00000000}},	//   шок_, مايو_, িটিয, --, 
   {{0xd1cc044e,0x6a840824,0xe0d000c8,0x00000000}},	//   _ኣበባ_, олиа, _קײן_, --, 
   {{0x3ea400ca,0x69bc0034,0x00000000,0x00000000}},	//   _gvmt_, _शादी, --, --, 
   {{0xe8c80da9,0x9ce801d3,0x00000000,0x00000000}},	//   агол_, _ھونے_, --, --, 
   {{0x999c012c,0xac1849f3,0x9ce800e5,0x00000000}},	//   nitř_, _кожу_, _پونے_, --, 
   {{0x4c5473d7,0x6b980334,0x6d4073d8,0x00000000}},	//   _اضطر, _uewg, _ixla, --, 
   {{0x2fcc00ca,0x81e00183,0x00000000,0x00000000}},	//   _mbeg_, থাত_, --, --, 
   {{0xa96873d9,0x2eec0175,0x9e7808a8,0x78c803b2}},	//   _кила_, _mref_, ינשפ, ósvø, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69c4033f,0xaf700240,0x5b1001af,0x00000000}},	//   ़्री, እስትና_, _хмәт, --, 
   {{0xa20473da,0xd38400d4,0xa2280798,0x00000000}},	// [8740] опад, юйте_, ажаа_, --, 
   {{0x2fcc0dd4,0x6d4073db,0xe24400c6,0x915c0208}},	//   _abeg_, _oxla, آخري, _sắp_, 
   {{0x602473dc,0xe0d873dd,0x30a40212,0x308401e1}},	//   оджа, рве_, зрів, _ṣorí_, 
   {{0x2eec73de,0x2d840276,0xd68801ec,0x9e800023}},	//   _bref_, _afle_, _ﺒﻨﻅﺭ_, _ክሰርሓ_, 
   {{0x9fa4052f,0x6d4073df,0xb35445cc,0x00000000}},	//   быҙҙ, _axla, _فیفا_, --, 
   {{0x6ce43eaf,0x2fcc0066,0x2eec00a9,0x645473e0}},	//   किंग_, _ebeg_, _dref_, llyi, 
   {{0x90c031de,0xdcf800de,0x00000000,0x00000000}},	//   _обре, _ietī, --, --, 
   {{0x26d00280,0x2eec0334,0x2d840393,0x00000000}},	//   _opyo_, _fref_, _efle_, --, 
   {{0x8af40cc1,0x2d840295,0x2eec73e1,0x6d4003b9}},	//   _şərh, _ffle_, _gref_, _exla, 
   {{0x7ae405be,0x9e2400d1,0x00000000,0x00000000}},	//   _šits, _بىئو, --, --, 
   {{0x91b80375,0xec340af6,0xdcf800ef,0x00000000}},	//   סמטי, _کونگ, _metī, --, 
   {{0xe8ec05d9,0xba180ccb,0x00000000,0x00000000}},	//   اڻو_, _گيتا_, --, --, 
   {{0x2eec02fa,0xcb400075,0xc5e4009e,0xec68009a}},	//   _xref_, _охши, মানপ, _اصلو_, 
   {{0xdcf800e2,0xceb00a1e,0xba183c97,0x94a8011c}},	//   _netī, ויש_, _ديتا_, итба_, 
   {{0x70c8007d,0x64540036,0x3ce00073,0x4df800df}},	//   _रहेल, flyi, किटे_, ספלא, 
   {{0xb9e81772,0x1cbc031c,0x00000000,0x00000000}},	//   _ሬሳ_, _ཇཱན_, --, --, 
   {{0xd760694d,0x95c873e2,0x00000000,0x00000000}},	// [8750] _تنظی, _куна_, --, --, 
   {{0xdb0000e4,0x2eec0200,0x00000000,0x00000000}},	//   _ndoí, _rref_, --, --, 
   {{0x2eec0175,0x00000000,0x00000000,0x00000000}},	//   _sref_, --, --, --, 
   {{0x2eec3ddd,0x720401d9,0x00000000,0x00000000}},	//   _pref_, _کوسم, --, --, 
   {{0x518473e3,0xfd4c001e,0x387c022e,0x3e60007f}},	//   _мува, _triề, _luvr_, zòte_, 
   {{0x0dc8013e,0x387c0100,0x3198010f,0x7f4800d1}},	//   руди_, _ouvr_, _לבֿנ, ڭلۇق_, 
   {{0xd02001ec,0xbdf802da,0x6b9c0174,0x00000000}},	//   _قوسۋ, غرها_, ðsgo, --, 
   {{0x70940364,0x2eec73e4,0xa8041709,0x69bc0954}},	//   _маҳф, _tref_, _mañá, _शाही, 
   {{0xeab000c6,0x8cd400ab,0x8ca4012d,0x00000000}},	//   رعة_, _मनको, _घटको, --, 
   {{0xa9241b04,0x00000000,0x00000000,0x00000000}},	//   здол, --, --, --, 
   {{0x6d4001b9,0x6b740220,0xf8b800e4,0x574c0092}},	//   _uxla, _елеу, guĩ_, _ማስፈራ, 
   {{0x645402c4,0xfbd03016,0x8a740117,0x00000000}},	//   xlyi, _لته_, _дидӣ_, --, 
   {{0xa3e40807,0x377473e5,0x6a8467ba,0xaa88007b}},	//   _योग_, дырс, _элла, _انتم_, 
   {{0x3e600699,0x59c069af,0xa50873e6,0x00000000}},	//   pòte_, _शायर, бега_, --, 
   {{0x99f80375,0x7ae4007b,0x2934008f,0x64540f85}},	//   _לפספ, _áitr, _מאַן_, tlyi, 
   {{0x601800e4,0xd8c40327,0x2328023b,0x02c801d5}},	//   _oïma, _ཀྱིི, боби_, оқми_, 
   {{0x645473e7,0x934073e8,0xd06000ac,0xb86473e9}},	// [8760] rlyi, енте, _ürək, _تاوو, 
   {{0xe928031c,0xe4740262,0x7ae400e4,0x614416a4}},	//   _སྟོབ_, _нумэ, _âite, пеза, 
   {{0x645473e7,0xa8040077,0x24e873ea,0x00000000}},	//   plyi, _gañá, _умни_, --, 
   {{0x1ea873eb,0x00000000,0x00000000,0x00000000}},	//   ماتي_, --, --, --, 
   {{0x442073ec,0x00000000,0x00000000,0x00000000}},	//   mhi_, --, --, --, 
   {{0x442073ed,0x6d7815bf,0x00000000,0x00000000}},	//   lhi_, يجىڭ_, --, --, 
   {{0x442073ee,0x2c6000d7,0x00000000,0x00000000}},	//   ohi_, zóde_, --, --, 
   {{0x44205de0,0xa0380014,0xeff80023,0xcd30007b}},	//   nhi_, _آرا_, ዋታይ_, عروب, 
   {{0xd24c0014,0xa2b0033f,0x5f940166,0x23cc07b7}},	//   _شنہ_, इंट्, _миңт, ह्यद, 
   {{0x391473ef,0xaa34001f,0xf8b800e4,0x00000000}},	//   дмор, _ይኖረዋ, tuĩ_, --, 
   {{0x69bc1025,0x8da40133,0x00000000,0x00000000}},	//   _शारी, _رشلۆ, --, --, 
   {{0x442073f0,0x6e3c0a87,0x9a84009b,0x00000000}},	//   jhi_, _ísbr, _еукл, --, 
   {{0x0c000014,0xe81c00af,0xe8540092,0x167001a9}},	//   _سووُ, _पतरा_, ለሙያዎ, нқир, 
   {{0x2b080316,0x442073f1,0x00000000,0x00000000}},	//   िहरु_, ehi_, --, --, 
   {{0x44200084,0x00000000,0x00000000,0x00000000}},	//   fhi_, --, --, --, 
   {{0x442073f2,0xe4fc00cd,0x00000000,0x00000000}},	//   ghi_, _उपरि_, --, --, 
   {{0xb27473f3,0x877c010f,0xa2c0010b,0x8c1800d9}},	// [8770] длаш, _פאזי, кәрк, צומי, 
   {{0x442073f4,0x00000000,0x00000000,0x00000000}},	//   ahi_, --, --, --, 
   {{0x77600cc1,0xf4842580,0x00000000,0x00000000}},	//   əlxa, _تاخی, --, --, 
   {{0x301473f5,0x00000000,0x00000000,0x00000000}},	//   ьдер, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x41e402d5,0xd24473f6,0x00000000,0x00000000}},	//   _піса, _хэми, --, --, 
   {{0xe81c05f9,0x1d0400a7,0xeb986141,0x463c010f}},	//   _पतला_, дещи_, оий_, זעגע, 
   {{0x601802b1,0xea8873f7,0x2b1400d4,0x06c800eb}},	//   _tïma, обил_, дьор, ষয়টি, 
   {{0x81e000bd,0xcd280451,0xa5c40055,0x00000000}},	//   থার_, _ڏسان_, _yeųā, --, 
   {{0x442073f8,0xe9d873f9,0x00000000,0x00000000}},	//   zhi_, цко_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x442073fa,0xe6d4009d,0x6b14009b,0x00000000}},	//   xhi_, мцгэ, _омеђ, --, 
   {{0x44201aa1,0x3e600ba1,0xdb4c0014,0x0ae80066}},	//   vhi_, lòta_, _پَو_, _دراي_, 
   {{0x44200325,0xa90800f1,0x00000000,0x00000000}},	//   whi_, _ويشل_, --, --, 
   {{0x442073fb,0x853405a9,0xa3e80006,0xaa8801c8}},	//   thi_, رورچ, одва_, _انڪم_, 
   {{0x442073fc,0xe73800a8,0xe29873fd,0xe4581cb8}},	//   uhi_, _мей_, жаа_, іжа_, 
   {{0x442013a1,0x82c40327,0xf1a800f1,0x6b9c00e5}},	// [8780] rhi_, _ཝཱཎའ, ړانه_, ósgy, 
   {{0xc1d8012d,0xa1340b24,0x00000000,0x00000000}},	//   ड़ेग, وراش, --, --, 
   {{0x44202ffc,0x661c0ac5,0xd5f8011a,0xd24c2b9f}},	//   phi_, _ilpk, _ופיר, جنل_, 
   {{0x442073fe,0x636400b0,0xdef873ff,0x3e60067c}},	//   qhi_, _pōnī, жык_, dòta_, 
   {{0xffa40228,0x8fa03f0f,0xa5c4002b,0xe7c400b8}},	//   _үлгү, таче, _teųā, _वानप, 
   {{0xdc886ee4,0x61440395,0x00000000,0x00000000}},	//   осил_, _жега, --, --, 
   {{0x28dc03f8,0x00000000,0x00000000,0x00000000}},	//   _फैलि, --, --, --, 
   {{0x0d807400,0x44c80e78,0xab5c012d,0x00000000}},	//   нлән, iß_, leży, --, 
   {{0x3a7404a9,0x8fa07401,0xddc8007f,0xd1600023}},	//   нлир, _шате, lofō, _ዝሳተፍ, 
   {{0x3e60067c,0x0e607402,0x7c20005c,0x00000000}},	//   bòta_, _акун, shmr, --, 
   {{0x2600032c,0x00000000,0x00000000,0x00000000}},	//   शानी_, --, --, --, 
   {{0xfe7800a2,0x204c0023,0x00000000,0x00000000}},	//   _hiį_, _ንባህር, --, --, 
   {{0x44c803fa,0x76600055,0x00000000,0x00000000}},	//   eß_, _aśaṃ, --, --, 
   {{0xd4987403,0x7bc020e4,0xdce815b7,0x667002f2}},	//   жра_, lgmu, lafı, ێگیر, 
   {{0x49b8011a,0x00000000,0x00000000,0x00000000}},	//   _ומוס, --, --, --, 
   {{0x7bc0138f,0x661c02d0,0xdce80790,0x00000000}},	//   ngmu, _elpk, nafı, --, 
   {{0x20040200,0xb62c0092,0xfbd01a55,0x479c011a}},	// [8790] djoi_, ደማይቀ, थ्यम, _ויחס, 
   {{0xd1b87404,0xd2580953,0xc2c4152b,0x06b80133}},	//   تارا_, іца_, ئيلي, _کچێک_, 
   {{0xe7c465c5,0x7de800de,0xd13800c7,0x00000000}},	//   _वामप, _mūsē, цха_, --, 
   {{0x3cf40a28,0x61442ba5,0x20040240,0x7de80171}},	//   ्मने_, رىنە, gjoi_, _lūsē, 
   {{0xdce806be,0x00000000,0x00000000,0x00000000}},	//   dafı, --, --, --, 
   {{0xc0cc0201,0x6da417b4,0xada400ee,0xc6940a7c}},	//   _በጣም_, хика, хакл, דאס_, 
   {{0xc0c401af,0x00000000,0x00000000,0x00000000}},	//   _иљти, --, --, --, 
   {{0x8ff87405,0x2900031c,0x7bc0007c,0x00000000}},	//   _برسر_, _ħha_, ggmu, --, 
   {{0x2ef400fd,0xa9a400ee,0x0dc800d8,0x40341c34}},	//   _язар, нипд, _мужи_, _ретс, 
   {{0x7bc001f5,0xe82001ad,0xeab00014,0xbef8007b}},	//   agmu, मसभा_, پٹھ_, _ترفض_, 
   {{0xa8880395,0x00000000,0x00000000,0x00000000}},	//   яйна_, --, --, --, 
   {{0xc0f4044e,0xab5c0034,0x29e8030a,0x7c94072d}},	//   _ግብሪ_, zeży, fïañ_, _ششما, 
   {{0x7d1801f1,0x07a40022,0x00000000,0x00000000}},	//   časť, наҟн, --, --, 
   {{0x6aa808a5,0x00000000,0x00000000,0x00000000}},	//   msef, --, --, --, 
   {{0x15407406,0xa508449b,0x6aa87407,0x69c00489}},	//   герм, чева_, lsef, mgle, 
   {{0x6b887408,0x69c07409,0x229401e1,0x00000000}},	//   nceg, lgle, _nùkò_, --, 
   {{0x6aa8013b,0x69c0740a,0xfbac009e,0x626406ed}},	// [87a0] nsef, ogle, ক্কত, еваа, 
   {{0xc0f41540,0x00000000,0x00000000,0x00000000}},	//   _ግብረ_, --, --, --, 
   {{0x6b880a73,0x2c6000d0,0xaf600023,0x69c0740b}},	//   kceg, zóda_, _ዝሓለፈ, igle, 
   {{0xa2b018ef,0x81e00729,0x6aa80a64,0x5f441e87}},	//   ेंद्, থাই_, ksef, ىنال, 
   {{0x6aa800b5,0x20040108,0xdce815b7,0x00000000}},	//   jsef, rjoi_, vafı, --, 
   {{0x69c0597f,0x9e640131,0x00000000,0x00000000}},	//   jgle, راشن, --, --, 
   {{0x69c008a4,0x7bc004cc,0x6144024c,0x7de800ef}},	//   dgle, tgmu, _чева, _rūsē, 
   {{0x59c01d72,0xdee4470d,0x2c600030,0x00000000}},	//   _शाहर, _поби, tóda_, --, 
   {{0xdce80d9c,0x6aa8691c,0xd00c007b,0x3cdc000d}},	//   rafı, gsef, _الق_, _खनके_, 
   {{0x69c0740c,0x6b88740d,0x38c8020e,0x80c40073}},	//   ggle, aceg, واجی_, ांपे, 
   {{0x3958037e,0x6aa8016b,0x00000000,0x00000000}},	//   ærs_, asef, --, --, 
   {{0x69c0740e,0x6b88002e,0xb8d808a3,0x00000000}},	//   agle, cceg, _चि_, --, 
   {{0x69c00112,0x48140276,0xd90c397a,0xc8c402f2}},	//   bgle, умяс, شیک_, ووین_, 
   {{0xdb0006ed,0xba1804fb,0x29e80165,0x00000000}},	//   _adoç, _زيبا_, rïañ_, --, 
   {{0x7a24007f,0x7ae8004b,0x00000000,0x00000000}},	//   _pòtf, _روژې_, --, --, 
   {{0xb4e02c30,0xb6f40b3e,0x03c401a9,0x00000000}},	//   _धनी_, _азиј, лсум, --, 
   {{0x3868014b,0x3374740f,0x3254059f,0x00000000}},	// [87b0] _ihar_, тгар, ввар, --, 
   {{0x38680327,0xc73c011a,0x00000000,0x00000000}},	//   _hhar_, _מתחת, --, --, 
   {{0xc0f40020,0x38687410,0xcee800f1,0x6aa800e5}},	//   _ግብር_, _khar_, ګران_, zsef, 
   {{0x6e947411,0x38680198,0x6aa8003b,0x409400d1}},	//   виду, _jhar_, ysef, چلەر, 
   {{0xb4e002e5,0xe3c804c5,0x40940075,0x6b8801fa}},	//   _धनु_, _লোকব, نلەر, vceg, 
   {{0xed587412,0xdb040d12,0x00000000,0x00000000}},	//   мол_, ðmýk, --, --, 
   {{0x386801c6,0x50b80327,0x69c00158,0x7d1802f0}},	//   _ohar_, _པའིཚ, vgle, _časá, 
   {{0x2ef47413,0x6aa87414,0x3868003d,0x9ed423c9}},	//   _избр, tsef, _nhar_, хмәт_, 
   {{0x6b881225,0x8c10045e,0x69c00112,0x6dc000cf}},	//   rceg, িফলন_, tgle, _نۅشۅ, 
   {{0x6b8802e8,0x69c07415,0x38687416,0x2df83b7a}},	//   sceg, ugle, _ahar_, _تبرک_, 
   {{0x69c07417,0x386803d5,0x6e20127b,0x3d94151e}},	//   rgle, _bhar_, _illb, _сихр, 
   {{0x69c07418,0x7c84084c,0x6aa80158,0xf64808c3}},	//   sgle, _суфе, psef, _וצ_, 
   {{0x2614007d,0x38687419,0x00000000,0x00000000}},	//   _नकदी_, _dhar_, --, --, 
   {{0x44240142,0x602c0115,0xa2b004af,0x00000000}},	//   _ŷm_, rŝmi, ेंस्, --, 
   {{0x68444fd6,0xc5e4015b,0x084401d9,0x00000000}},	//   _инка, মালপ, _مۆدُ, --, 
   {{0x3868741a,0xd464741b,0x00000000,0x00000000}},	//   _ghar_, висе_, --, --, 
   {{0x24840030,0x6e20741c,0xe2a8009f,0x00000000}},	// [87c0] _čomu_, _ollb, بازن_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2174741d,0x682400d8,0x00000000,0x00000000}},	//   туар, _códg, --, --, 
   {{0x6e20741e,0xeaf005d7,0x942003cc,0x38680327}},	//   _allb, _अछूत_, _نوپۇ, _xhar_, 
   {{0x3ed400c6,0x65a402b5,0x6d4c2d1c,0x65340cd6}},	//   اقتر, pōhē, şaal, _سرگذ, 
   {{0x6294741f,0x2dc40075,0xe7c400cd,0x00000000}},	//   mpyo, лқун_, _वाऽप, --, 
   {{0x10a07420,0x3c58084c,0x2c600174,0x1fa800f3}},	//   _висн, никэ_, ródn_, _окви_, 
   {{0xd50c043b,0xdc286dd7,0x7a24007f,0x6e207421}},	//   nɛ́n, بسته_, _mòte, _ellb, 
   {{0x62947422,0xba54033a,0x8c400114,0x00000000}},	//   npyo, лвиј, јење, --, 
   {{0x81e000fe,0x5884008e,0x00000000,0x00000000}},	//   থাক_, кыма, --, --, 
   {{0x38680280,0x3328036b,0x23e00034,0x91b80375}},	//   _phar_, zzax_, _पसंद, ומיי, 
   {{0xc7f80212,0x00000000,0x00000000,0x00000000}},	//   внює_, --, --, --, 
   {{0x7a24007f,0x95c81d0f,0x00000000,0x00000000}},	//   _pòtd, мува_, --, --, 
   {{0xb8f40597,0x64440fac,0x0b400131,0x89306646}},	//   _مكتب, _ajki, _әнән, اعیا, 
   {{0x38687423,0xddd80421,0x4a7806a9,0x49005756}},	//   _thar_, _aitū, _קרוב, _نووق, 
   {{0xf2c401c6,0x9c8400ef,0x00000000,0x00000000}},	//   лөги, _inčī, --, --, 
   {{0x0cbc0cb4,0x64441c3a,0x2848008f,0x473400ec}},	// [87d0] _एम्म, _djki, _רעפּ, _پريز, 
   {{0x7a24007f,0x52a00c70,0x00000000,0x00000000}},	//   _fòte, _ओबीस, --, --, 
   {{0x76547424,0xe01c0c2e,0xdfcc05d9,0xada47425}},	//   mozy, पसंद_, ڳيو_, қайл, 
   {{0x76547426,0xa2b0012d,0x00000000,0x00000000}},	//   lozy, ेंश्, --, --, 
   {{0xdfcc7427,0x00000000,0x00000000,0x00000000}},	//   سيو_, --, --, --, 
   {{0x51847428,0x7a2402e2,0xfca80451,0x00000000}},	//   _шума, _lòtb, چايو_, --, 
   {{0xb4b0068f,0x81cc015b,0xfca801c8,0x2904025c}},	//   _ऑटो_, _শোক_, نايو_, xxla_, 
   {{0xcb800075,0x321006d9,0x09a80490,0x682402fb}},	//   швиқ, _hozy_, चण्य, _kóde, 
   {{0x32107429,0x00000000,0x00000000,0x00000000}},	//   _kozy_, --, --, --, 
   {{0xf9d402bf,0x6824742a,0x6e2003ac,0x00000000}},	//   ацюю, _móde, _ullb, --, 
   {{0xefd400b7,0x9f88000d,0x9ac800e5,0xedc401e2}},	//   _ከበደ_, _vööd_, ودیہ_, _لېږي_, 
   {{0x32100109,0xd1f0069d,0x00000000,0x00000000}},	//   _lozy_, _ግድብ_, --, --, 
   {{0x9f88007d,0xb510015b,0xe718742b,0x00000000}},	//   _tööd_, _হেলথ_, ريست_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x23d42386,0x490002dd,0x248400ef,0x00000000}},	//   лцар, _түнг, _čoms_, --, 
   {{0x4ab40034,0xc90c02ab,0x7a241497,0x26001d68}},	//   _इटाव, ाहीम_, _vòte, शाही_, 
   {{0xe1f8742c,0x2b580ccc,0x321006d9,0x682404d4}},	// [87e0] нга_, üsch_, _bozy_, _códe, 
   {{0xd50c043b,0x7a24004e,0x2088010b,0x3210742d}},	//   sɛ́n, _tòte, ейжи_, _cozy_, 
   {{0x26c0742e,0x3210742f,0x466400db,0xdfd801d5}},	//   luko_, _dozy_, _مۇڭق, еъл_, 
   {{0xe298160b,0x25a87430,0x02c4013d,0x9ea801d5}},	//   _пам_, labl_, _кимү, евда_, 
   {{0xdd907431,0x645407d6,0x3ea0180f,0x00000000}},	//   موش_, moyi, èit_, --, 
   {{0x64547432,0x62847433,0xdfd07434,0x21740e92}},	//   loyi, _iuko, _گير_, _бубр, 
   {{0x26c07435,0x63a404a4,0xbca400c6,0x61ec0857}},	//   huko_, _kekn, جمعي, _iabl, 
   {{0x61ec7436,0x26c07437,0xdfd0215e,0x81e00eac}},	//   _habl, kuko_, _دير_, থাও_, 
   {{0x61ec7438,0x34e00b7d,0x63a47439,0x3cf400cd}},	//   _kabl, _पन्द, _mekn, ्महे_, 
   {{0x61ec55bb,0x26c0743a,0x6454743b,0x63a4743c}},	//   _jabl, duko_, hoyi, _lekn, 
   {{0x5bc40199,0x61ec743d,0x6454743e,0x25a80165}},	//   _مقال, _mabl, koyi, dabl_, 
   {{0x62840751,0x26c0743f,0x61ec7440,0xb8a40092}},	//   _ouko, fuko_, _labl, _መደገፍ_, 
   {{0xcc5425f9,0x26c07441,0x61ec030a,0x62847442}},	//   _גבאי_, guko_, _oabl, _nuko, 
   {{0x61ec7443,0x63a40369,0xd4e40719,0x25a80100}},	//   _nabl, _aekn, люби, gabl_, 
   {{0x63a47444,0x62847445,0x76547446,0xdb0000c7}},	//   _bekn, _auko, rozy, _ndoú, 
   {{0x682436ed,0x26c07447,0x64544520,0x32100109}},	//   _póde, buko_, goyi, _sozy_, 
   {{0x7654068f,0x62847448,0x26c07449,0x3210289f}},	// [87f0] pozy, _cuko, cuko_, _pozy_, 
   {{0x6284015c,0xa5c00598,0x63a403ac,0x0fe00137}},	//   _duko, _мөсе, _eekn, өөбү, 
   {{0x61ec744a,0x3210012c,0x4f0804fb,0x6284744b}},	//   _dabl, _vozy_, کتاپ_, _euko, 
   {{0x63a4744c,0x2ef4744d,0x62840093,0x61ec0076}},	//   _gekn, изер, _fuko, _eabl, 
   {{0x62840537,0xada401c0,0x999c0153,0x5fa000d1}},	//   _guko, аалл, notų_, زەلم, 
   {{0x61ec744e,0x63a459ae,0x6298007f,0x20cc03b2}},	//   _gabl, _zekn, _ōtog, býi_, 
   {{0x26c0744f,0x999c00bc,0xe7c41025,0x7c840063}},	//   zuko_, entů_, _वालप, буње, 
   {{0x62847450,0x26c0019b,0x25a8007f,0x245c00e4}},	//   _yuko, yuko_, zabl_, tïmi_, 
   {{0x6284011f,0xddd80100,0x261417cb,0xab2822d7}},	//   _xuko, _oktň, _नकली_, топа_, 
   {{0x26c07451,0x8c640220,0x6454401f,0xe8f87452}},	//   vuko_, _өтед, zoyi, вло_, 
   {{0x64543142,0x26c07453,0x25a8007f,0x68440022}},	//   yoyi, wuko_, vabl_, иноа, 
   {{0x26c0152d,0x4a700046,0x3ea00311,0x60d8010e}},	//   tuko_, шықт, ţite_, _ätme, 
   {{0x63a40183,0x260007af,0x64547454,0x388c0118}},	//   _rekn, शाली_, voyi, _věra_, 
   {{0x62847455,0x64547456,0x63a40306,0x00000000}},	//   _ruko, woyi, _sekn, --, 
   {{0x26c07457,0x61ec7458,0x63a46b07,0x638400a7}},	//   suko_, _rabl, _pekn, игва, 
   {{0x26c07459,0x78bc43e5,0x25a8007f,0x999c0153}},	//   puko_, árve, sabl_, botų_, 
  
   {{0x61ec0bed,0x6454745a,0x66e4745b,0xf1d405f5}},	// [8800] _pabl, royi, _топа, өөрө, 
   {{0x61ec745c,0x7a240100,0xf00001c0,0x6454745d}},	//   _qabl, _kòta, үүри, soyi, 
   {{0xe3b8745e,0x55b80302,0x61ec745f,0x62847460}},	//   _ибн_, _במיו, _vabl, _wuko, 
   {{0x62847461,0xfa88001e,0x7a2402e2,0x61ec0334}},	//   _tuko, _lừa_, _mòta, _wabl, 
   {{0x61ec0fa9,0x44207462,0x62842210,0x5de423c5}},	//   _tabl, mki_, _uuko, ижда, 
   {{0x61ec0408,0xf1a804d3,0x3cf40bae,0x2c6000ae}},	//   _uabl, _مافه_, ्मले_, lódh_, 
   {{0x7a241497,0x00000000,0x00000000,0x00000000}},	//   _nòta, --, --, --, 
   {{0xd12c01d9,0xa0681b0a,0x2c6001e7,0x81e800fe}},	//   _کمہ_, _раба_, nódh_, _মচি_, 
   {{0xfa88004d,0xa3cc0073,0x00000000,0x00000000}},	//   _bừa_, _रान_, --, --, 
   {{0x44207463,0x7a2401ab,0x5cd402bf,0xcb640b3e}},	//   hki_, _bòta, _відх, шање_, 
   {{0x44207464,0xfa88001e,0x7a247465,0xa3e4012d}},	//   kki_, _dừa_, _còta, फ़ा_, 
   {{0x44207466,0xabc87467,0xdb5846b2,0x00000000}},	//   jki_, _مذهل_, _июл_, --, 
   {{0x44207468,0x386c00e2,0x73c401e0,0x2c6001e7}},	//   dki_, ķer_, ҙәне, dódh_, 
   {{0x44207469,0x8af80375,0xd5a001b9,0x09e0041b}},	//   eki_, _שהגי, تلسی, _мочн, 
   {{0x4420746a,0x93a4036b,0x947400c6,0xd3a400d1}},	//   fki_, ишад, لدرا, ирап, 
   {{0x4420746b,0x349401b9,0x999c0064,0x4404004e}},	//   gki_, _қамр, potų_, очуб, 
   {{0xdcf80135,0x00000000,0x00000000,0x00000000}},	// [8810] _fetħ, --, --, --, 
   {{0x4420746c,0xeff802d3,0x318402dd,0x53e400c7}},	//   aki_, _ለበዋ_, стаң, ыцҳа, 
   {{0x4420746d,0x2a6803f9,0xe7ec012c,0x61441870}},	//   bki_, _ɗab_, _जसमा_, مىكە, 
   {{0xa3cc09d9,0x2c600332,0xf484072d,0x00000000}},	//   _राय_, códh_, _پاگی, --, 
   {{0xb8f80ad3,0x16180574,0xd2580798,0x00000000}},	//   _ོད_, _नकार_, _ацв_, --, 
   {{0x741400d1,0x51940354,0x344801f0,0x00000000}},	//   _ئوڭا, _тăка, _рӯҳи_, --, 
   {{0xdd8c746e,0xa3cc23ef,0xaaa81a22,0x2c6001ed}},	//   روي_, _राम_, चीनक, lódi_, 
   {{0x7058039b,0xe7c407f7,0x00000000,0x00000000}},	//   _сабр_, _वाइप, --, --, 
   {{0xd00000d1,0x7a2402e2,0xeaf80633,0x00000000}},	//   _лоңқ, _sòta, اربت_, --, 
   {{0x4420746f,0x7a240699,0x998c0421,0x00000000}},	//   zki_, _pòta, _fofō_, --, 
   {{0x44207470,0xfa8807ae,0x6c8400c6,0x81ac009e}},	//   yki_, _vừa_, _الصم, _গাম_, 
   {{0x6a2404fb,0x7a24067c,0x442001c4,0x728c0023}},	//   _گفتم, _vòta, xki_, ዛእታዊ_, 
   {{0x4420341a,0x68247471,0x6fd8107c,0xfbd07472}},	//   vki_, _códa, फ्यू, _آتم_, 
   {{0x4420006d,0x69dc01ed,0x3e6002e2,0x00000000}},	//   wki_, őseb, tòti_, --, 
   {{0x44207473,0xfa34034c,0xd9400209,0x39581196}},	//   tki_, _برند, _неши, ürst_, 
   {{0x44207474,0xdc340598,0x3f800006,0x638401c0}},	//   uki_, _mäğl, žiui_, сгаа, 
   {{0xd4640a70,0x2d847475,0xe2980124,0x68240174}},	// [8820] сите_, _ogle_, уаз_, _góda, 
   {{0x27f001d9,0x2fcc037e,0x2c6001e7,0x00000000}},	//   _hayn_, _aceg_, sódh_, --, 
   {{0x44202e95,0x5a3800c8,0x27f0058a,0xa0683da1}},	//   pki_, נגעה, _kayn_, гажа_, 
   {{0x2d840429,0x8d9c0220,0x44203792,0x232801f0}},	//   _agle_, _ﺍﭘﺎﺕ_, qki_, _боми_, 
   {{0x27f07476,0x00000000,0x00000000,0x00000000}},	//   _mayn_, --, --, --, 
   {{0x20dc01e4,0xe08406f6,0x27f07477,0x7d7800f1}},	//   _aĥiŝ_, _هجري, _layn_, ټمبر_, 
   {{0x644803b2,0x51f400f1,0x4dd0009a,0x00000000}},	//   _ífis, _اسټر, ستوس, --, 
   {{0x1e8458a8,0x27f00009,0x2d847478,0xbab800f3}},	//   _глам, _nayn_, _egle_, агих_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x68247479,0xdca401c6,0x9d4401ec,0x00000000}},	//   _róda, _гажи, _лезд, --, 
   {{0xad2465fb,0x2d9416a4,0x27f0747a,0x6824032e}},	//   _ورمو, _фрус, _bayn_, _sóda, 
   {{0x27f00014,0x9b6800d4,0x2c0800cd,0x00000000}},	//   _cayn_, _йшла_, वाणं_, --, 
   {{0x27f00014,0xec34747b,0xc95401a9,0x00000000}},	//   _dayn_, _بونگ, _қўш_, --, 
   {{0x27f000ad,0xa2040248,0x00000000,0x00000000}},	//   _eayn_, _kọ̀ọ, --, --, 
   {{0x15b8010b,0x00000000,0x00000000,0x00000000}},	//   кыңы_, --, --, --, 
   {{0x6824172e,0x27f04af6,0xa20401e1,0x62880115}},	//   _tóda, _gayn_, _mọ̀ọ, ĉfon, 
   {{0xdb04006a,0x5184129d,0xfd500208,0x00000000}},	// [8830] _âmän, مشاق, gchế, --, 
   {{0x518400c7,0x00000000,0x00000000,0x00000000}},	//   суаа, --, --, --, 
   {{0x68240232,0x7a24007f,0xe8880208,0x51840124}},	//   _módn, _lòto, _lẻn_, ауҵа, 
   {{0x160406ab,0x27f0058a,0xc0581cd0,0x00000000}},	//   शावर_, _xayn_, біч_, --, 
   {{0xa3cc09fd,0x4ea4747c,0x1bf0107c,0xa3e4012d}},	//   _रात_, ёрда, _अफजल_, फ़र_, 
   {{0xfd1001d5,0x836800f1,0xff5001c8,0x6da400f3}},	//   کجه_, _دشپې_, رخن_, цика, 
   {{0xac08747d,0x7c840640,0x27e4002e,0xafc40150}},	//   инка_, пуње, _ñong_, _ويسى, 
   {{0xeab87216,0x92c80154,0xeb9800d8,0x00000000}},	//   айи_, লবী_, јип_, --, 
   {{0x27f0747e,0x81ac03d4,0x00000000,0x00000000}},	//   _rayn_, _গাত_, --, --, 
   {{0x2d900724,0x2d840ac8,0x399002d3,0x27f00009}},	//   _üze_, _ugle_, _ነበርቲ_, _sayn_, 
   {{0x776c009a,0x7ba800cc,0x399401e1,0x00000000}},	//   _azax, _গাৰো, _ẹsè_, --, 
   {{0x7a24068c,0x27f04f40,0xdb2401d3,0xba0801ec}},	//   _fòto, _qayn_, _ڈومی, _ۇتىك_, 
   {{0x27f00076,0xabb400fd,0x00000000,0x00000000}},	//   _vayn_, _гаҗә, --, --, 
   {{0x27f00050,0x9a640014,0x057c0150,0x00000000}},	//   _wayn_, _وۅٹل_, _ﺀانى, --, 
   {{0x7a241f3f,0x27f0062c,0xa978008f,0x00000000}},	//   _mòtl, _tayn_, _דאַכ, --, 
   {{0xa348747f,0xe8880208,0xd54401ec,0x81ac00cc}},	//   азба_, _hẻo_, іпте_, _গাধ_, 
   {{0x9878008f,0xe888004d,0x22580208,0x04fc0154}},	// [8840] _דאקט, _kẻo_, topk_, ীনের_, 
   {{0x68240765,0x00000000,0x00000000,0x00000000}},	//   _kódo, --, --, --, 
   {{0xa5080395,0x00000000,0x00000000,0x00000000}},	//   _тена_, --, --, --, 
   {{0x682400dd,0xa2c02435,0xe8880208,0xd8d8010f}},	//   _módo, _लिप्, _lẻo_, יקער, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdcb806bb,0xa0a44eb6,0x7a24004e,0x3d941086}},	//   ащи_, _магд, _ròto, чикр, 
   {{0x25b87480,0xc0d402d3,0x00000000,0x00000000}},	//   _mdpl_, ረቶም_, --, --, 
   {{0x7a240699,0x83f0013f,0x0c7000f1,0x8c6001ec}},	//   _pòto, koɑm, وديد, мтыд, 
   {{0xa2b0443a,0xa2c01b76,0x9ce800cc,0x00000000}},	//   ेंट्, _लिफ्, কমেন_, --, 
   {{0xa2c00b68,0x6ee40736,0x776c06be,0xa20401e1}},	//   _लिन्, _عسقل, _rzax, _tọ̀ọ, 
   {{0xe88801fb,0xd90c397a,0xc95401d5,0x9ba00116}},	//   _dẻo_, ئیب_, жўя_, _قەغى, 
   {{0x25b801a6,0xfa880051,0x8c14009f,0x00000000}},	//   _adpl_, _hừm_, _ويلر_, --, 
   {{0x24980263,0x6d4c029f,0x47847481,0x682403b2}},	//   _atpm_, şaat, дырб, _tódn, 
   {{0xddd8007f,0x3e60067c,0x00000000,0x00000000}},	//   _oktō, mòts_, --, --, 
   {{0x26c07482,0x999c02b5,0x45d400a7,0x3e600ba1}},	//   arko_, hitū_, ьорс, lòts_, 
   {{0x999c02b5,0x25a40e04,0x75d4004b,0x92b4007b}},	//   kitū_, _đole_, _کيدا, قحطا, 
   {{0x26000254,0x00000000,0x00000000,0x00000000}},	// [8850] शाखी_, --, --, --, 
   {{0x7ae40428,0xe888004d,0xd5b85b6d,0x644801e1}},	//   _âitu, _xẻo_, _тси_, _ìfin, 
   {{0x7a241497,0x92c8015b,0x33940153,0x00000000}},	//   _ròtl, লবে_, _нанё, --, 
   {{0x2c4400e2,0x30140229,0x00000000,0x00000000}},	//   pēdi_, ядер, --, --, 
   {{0x63a004cf,0x999c02b5,0x563c0092,0x00000000}},	//   ñone, gitū_, _ባለንብ, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x999c00b0,0xbd4400e3,0x2c6000d7,0xac38009d}},	//   aitū_, ونهي, zódu_, йчих_, 
   {{0xa2c00316,0x682405ac,0xc1040f13,0xa3cc06b1}},	//   _लिम्, _ródo, _توفي, रलय_, 
   {{0x3e600ba1,0xa3cc1431,0x682400d7,0x00000000}},	//   gòts_, _रास_, _sódo, --, 
   {{0x7a240100,0x0c840022,0x00000000,0x00000000}},	//   _fòtm, _дыдм, --, --, 
   {{0xecf80efc,0x68240332,0xf1dc00dc,0xe8880051}},	//   _دفاغ_, _fódl, न्यन, _vẻo_, 
   {{0x66e402bf,0x3e601497,0xbd44007b,0x6aac025c}},	//   пома, bòts_, _تنمي, _ħaff, 
   {{0x24980092,0x3e600ba1,0xdee80023,0x00000000}},	//   _stpm_, còts_, _ዘተን_, --, 
   {{0x6824172e,0xa3cc1533,0x7a24067c,0xe88801fb}},	//   _tódo, _राह_, _lòtj, _hẻm_, 
   {{0x682400e5,0x92c800eb,0x00000000,0x00000000}},	//   _hódm, লবো_, --, --, 
   {{0x58b80375,0x2c1c03d4,0x00000000,0x00000000}},	//   _המקצ, বোৰে_, --, --, 
   {{0xddd801ee,0x2bdc06e3,0x00000000,0x00000000}},	// [8860] _litš, क्यू_, --, --, 
   {{0x1754025f,0xa3cc2232,0xe3b001e2,0x00000000}},	//   _מספר_, _राव_, _ګرد_, --, 
   {{0xe0d80114,0x30a400d4,0x758001af,0x00000000}},	//   све_, дрів, _аңра, --, 
   {{0x44240016,0x999c00b0,0x1fd42e05,0x00000000}},	//   _ôm_, titū_, ठभेड, --, 
   {{0x1fe401e2,0x5f040121,0x00000000,0x00000000}},	//   يکړي_, язда, --, --, 
   {{0xddd80f8b,0x999c00b0,0x3e60067c,0x00000000}},	//   _bitš, ritū_, vòts_, --, 
   {{0xd24c263d,0xa1146e9a,0xd1b06786,0xa0a400db}},	//   _صنف_, _عورت, _سینک, _хабд, 
   {{0xddd87483,0xa0a41086,0x4ba4004e,0x00000000}},	//   _ditš, _маҳд, пөшү_, --, 
   {{0x06e4000e,0x5ea47484,0x3a7404a9,0x7afc00e2}},	//   মিডি, _رمال, млир, ārto, 
   {{0x3f8002d5,0x3e600ba1,0xd334011a,0x80e000c5}},	//   žius_, ròts_, פריה_, _नहाइ, 
   {{0x60c801ab,0x00000000,0x00000000,0x00000000}},	//   àfmh, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3a3c070d,0x2c0800dc,0x41cc1223,0x682400e5}},	//   _tmvp_, वारं_, ालास, _kódj, 
   {{0x4b780375,0xa2940150,0x00000000,0x00000000}},	//   _האדו, _ﺘﺨﺘﺒ_, --, --, 
   {{0x682401ed,0x89d8011a,0xd90c072d,0x00000000}},	//   _módj, _לחגי, _صیح_, --, 
   {{0x6aac0241,0x2c440171,0x04640150,0x00000000}},	//   _ànfà, bēdu_, етум, --, 
   {{0xd764066d,0xa3dc0037,0x842400d1,0x00000000}},	// [8870] _ڈاکٹ, _दउर_, رىكن, --, 
   {{0x94840137,0x00000000,0x00000000,0x00000000}},	//   _нымд, --, --, --, 
   {{0x7a24007f,0xf434010b,0x9f440165,0x40940212}},	//   _pòtj, _женэ, mdoù_, еріт, 
   {{0x9d700023,0x00000000,0x00000000,0x00000000}},	//   _ብሕጋዊ_, --, --, --, 
   {{0x850401d5,0x26000073,0x9f44030a,0x00000000}},	//   _قوین, शाची_, odoù_, --, 
   {{0x0dc806ed,0x9f4405c7,0x11282218,0x00000000}},	//   суди_, ndoù_, _люби_, --, 
   {{0x2d800112,0x00000000,0x00000000,0x00000000}},	//   ähe_, --, --, --, 
   {{0x7cc415bf,0xe0d000df,0x00000000,0x00000000}},	//   رزىم, _שײן_, --, --, 
   {{0x8d84179e,0xbe9800ae,0x00000000,0x00000000}},	//   _فشان, _فضلا_, --, --, 
   {{0x3d9400d8,0x00000000,0x00000000,0x00000000}},	//   _зифр, --, --, --, 
   {{0x7a2400a3,0x9f440165,0x1dd00846,0xa3cc07f7}},	//   _mòth, ddoù_, _सातत, _राल_, 
   {{0xdb000428,0xfbd00b28,0xf1dc4697,0x9f440156}},	//   _edoñ, _مته_, न्तन, edoù_, 
   {{0xdc340a7c,0xa8040205,0x07a400c7,0x00000000}},	//   _קאנט_, _nmış, маҟн, --, 
   {{0x56907485,0xdb24221d,0x28c41a22,0x00000000}},	//   таёт, _توهی, _विपि, --, 
   {{0xe58400cf,0x00000000,0x00000000,0x00000000}},	//   بۅدۉ_, --, --, --, 
   {{0x9f440dd4,0x2c4400e2,0x23280063,0xa804010a}},	//   adoù_, pēdu_, ооби_, _цзил, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [8880] --, --, --, --, 
   {{0x7ae400e4,0x1dd006e3,0x00000000,0x00000000}},	//   _ãite, _साधत, --, --, 
   {{0xf1dc102f,0x00000000,0x00000000,0x00000000}},	//   न्धन, --, --, --, 
   {{0x28c4194b,0x5f447486,0x00000000,0x00000000}},	//   _विनि, ونال, --, --, 
   {{0x9878008f,0xdd907487,0xe0cc00eb,0x00000000}},	//   קאנט, نوش_, রবেন, --, 
   {{0xf1dc00dc,0x00000000,0x00000000,0x00000000}},	//   न्दन, --, --, --, 
   {{0xa0341b56,0x00000000,0x00000000,0x00000000}},	//   _قىست, --, --, --, 
   {{0x799802d0,0xa3cc000d,0x7b181171,0x00000000}},	//   _sfvw, रलि_, зоир_, --, 
   {{0xcb640063,0x5398011a,0x00000000,0x00000000}},	//   маће_, חיפו, --, --, 
   {{0x3914035b,0x7a2401e1,0x00000000,0x00000000}},	//   емор, _kòti, --, --, 
   {{0xa3cc0574,0x682403b2,0x2bbc5b99,0x00000000}},	//   रला_, _gódk, ोलशा, --, 
   {{0xa73c0092,0x00000000,0x00000000,0x00000000}},	//   _የኦጋዴ, --, --, --, 
   {{0x8be80183,0x68240332,0x59b40073,0x00000000}},	//   কাখন_, _módh, _आजपर, --, 
   {{0x9f440dd4,0xb8f400bd,0x2fdc0369,0xf9d4084c}},	//   udoù_, _হন_, zfwg_, _чокэ, 
   {{0x667038b7,0xc8c402e9,0x9f4405c7,0xa8040139}},	//   دگير, _قوون_, rdoù_, _smış, 
   {{0x660003f9,0x36d4013e,0x7a2401ab,0x49c401ee}},	//   _ɗoki, _зоир, _sòth, _елән_, 
   {{0x8c180375,0x63a00789,0xeb90010f,0x00000000}},	// [8890] קומי, ñona, אָב_, --, 
   {{0x9128005e,0x00000000,0x00000000,0x00000000}},	//   يساق_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb034084c,0x00000000,0x00000000,0x00000000}},	//   энеш, --, --, --, 
   {{0x28c4084a,0xcee8034c,0xee2002dd,0x91f00022}},	//   _विभि, تران_, ледi_, _иҟаш, 
   {{0x7a2402e2,0x999c0118,0x00000000,0x00000000}},	//   _fòti, ditů_, --, --, 
   {{0x7a240137,0x68240332,0x00000000,0x00000000}},	//   _gòti, _fódh, --, --, 
   {{0x09c40073,0x6298032e,0x999c01ef,0x00000000}},	//   लल्य, _óboð, fitů_, --, 
   {{0x6824012d,0x6a840022,0x00000000,0x00000000}},	//   _wódk, нлиа, --, --, 
   {{0xe9d80faa,0xa2c002ab,0x80c401f9,0x00000000}},	//   чко_, _लिस्, ांचे, --, 
   {{0x68440ec6,0x6824003a,0x3078010f,0x00000000}},	//   енна, _hódi, ּאָנ, --, 
   {{0xd8740014,0x999c01ef,0x00000000,0x00000000}},	//   ٹمُت_, bitů_, --, --, 
   {{0x97740166,0xbc380633,0x999c013a,0x00000000}},	//   етрә, _تسلا_, citů_, --, 
   {{0x68240077,0xc1e401ec,0x64980107,0x00000000}},	//   _módi, _ﺍﯕﺪﺍ, зтар_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x81ac0729,0xf1dc085c,0xf9600133,0xe298725b}},	//   _গাই_, न्सन, _خۆپێ, заа_, 
   {{0x28c4068f,0x21a47488,0x682400ae,0x00000000}},	// [88a0] _विडि, еизм, _ródh, --, 
   {{0x7a2402e2,0x5efc000d,0x672403cd,0x7ae4005b}},	//   _dòtw, लिस्_, mykj, _äite, 
   {{0x60247489,0x6724748a,0xe568748b,0xf204033f}},	//   нджа, lykj, _хинд_, राज़_, 
   {{0xdef8748c,0x80e0033f,0x75200112,0x00000000}},	//   зык_, _नहीं, älze, --, 
   {{0x6824748d,0x63b4748e,0x661c748f,0x2c0800c5}},	//   _códi, mayn, _kopk, वाईं_, 
   {{0x63b47490,0x7a247491,0x0ba0010b,0x00000000}},	//   layn, _tòti, ңшым, --, 
   {{0x2294005c,0x3c5800ee,0x00000000,0x00000000}},	//   _hæk_, микэ_, --, --, 
   {{0x63b47492,0x2294005c,0x661c00de,0x00000000}},	//   nayn, _kæk_, _lopk, --, 
   {{0xa3cc012c,0x661c7493,0x682403b2,0x3a540b01}},	//   _राई_, _oopk, _gódi, ккиё, 
   {{0x63b47494,0x6724002d,0x4a5007ee,0x00000000}},	//   hayn, dykj, лкыс, --, 
   {{0x63b47495,0x99647496,0x229469d9,0x9bc400c0}},	//   kayn, этил, _læk_, _зёлк, 
   {{0x63b401d9,0x64480248,0xd4984411,0x00000000}},	//   jayn, _ìfih, ҷра_, --, 
   {{0x661c01af,0x63b40050,0x5a44084c,0x4b88030d}},	//   _bopk, dayn, _пэка, _хιун_, 
   {{0x63b40076,0xd4980eba,0xf67401c6,0x00000000}},	//   eayn, зра_, тггэ, --, 
   {{0x6824007f,0x63b40067,0x661c01e3,0x6fd0000d}},	//   _nódw, fayn, _dopk, _हालं, 
   {{0xd6d84dcd,0x63b47497,0x2c080034,0x22941924}},	//   _ето_, gayn, वाएं_, _bæk_, 
   {{0x07f81375,0x388c01ef,0x00000000,0x00000000}},	// [88b0] _سريع_, _věru_, --, --, 
   {{0x7afc0a28,0x229404ce,0x63b40280,0x68240798}},	//   ārth, _dæk_, aayn, _ródi, 
   {{0x63b47498,0x68247499,0x61440617,0x764800e8}},	//   bayn, _sódi, نىكە, éeyu, 
   {{0x66e4016b,0x6824749a,0x63b40014,0x51840139}},	//   _wɔke, _pódi, cayn, _җуга, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbfa846e8,0xd16400a7,0x661c022e,0x00000000}},	//   _үтте_, _зъби, _xopk, --, 
   {{0x3f640b65,0x28c466eb,0x1b1c04c5,0xc0c80276}},	//   ктәб, _विधि, _বেলে_, _путе_, 
   {{0xbd5400c7,0x00000000,0x00000000,0x00000000}},	//   ыҭхә, --, --, --, 
   {{0x6e9401af,0x2bdc084d,0x00000000,0x00000000}},	//   _ризу, क्षू_, --, --, 
   {{0x63b4749b,0x28c409b4,0xc334011a,0xaa4400db}},	//   zayn, _विदि, טופ_, ئندى, 
   {{0x63b4749c,0x2ed000dc,0x661c35f8,0x00000000}},	//   yayn, _समुत, _ropk, --, 
   {{0x63b40a81,0x661c749d,0x25a85168,0x3ea001e4}},	//   xayn, _sopk, कर्ण, ŭite_, 
   {{0x442c00e2,0x63b400ad,0xadf40037,0xe9a8179e}},	//   _ēd_, vayn, _इसान_, _قدغن_, 
   {{0x06e40183,0x63b4749e,0xaa443129,0xe7ec00bc}},	//   মিলি, wayn, _шелл, _जसका_, 
   {{0x63b42e95,0x67240a85,0x7a24749f,0x62940007}},	//   tayn, sykj, _còtu, wqyo, 
   {{0x2ae419e5,0x18a01d56,0x661c000f,0x00000000}},	//   _कहाँ_, _таъм, _wopk, --, 
   {{0xd46474a0,0xe1f874a1,0x63b474a2,0x638401c0}},	// [88c0] тите_, мга_, rayn, тгаа, 
   {{0x2294019b,0x63b474a3,0x7d08387a,0xa52400c7}},	//   _væk_, sayn, _jérô, _амод, 
   {{0x63b474a4,0x64a474a5,0x00000000,0x00000000}},	//   payn, _шана, --, --, 
   {{0x63b474a6,0xd91800c8,0x2328022e,0x00000000}},	//   qayn, וועל, _жоми_, --, 
   {{0xd00c1af5,0x0b100154,0x06f4134e,0x00000000}},	//   غله_, িনুল_, ेटिव_, --, 
   {{0xdb1c0129,0x00000000,0x00000000,0x00000000}},	//   _àvél, --, --, --, 
   {{0x61443e4f,0x8cb40451,0x216800d8,0x6098009f}},	//   _рева, نديس_, _циви_, _آنرس_, 
   {{0x5f0474a7,0xdfd074a8,0xc7b40134,0x9be402dd}},	//   _изба, _خير_, _neɑ_, тікк, 
   {{0x61fc74a9,0x45180eac,0xdeb001ec,0x00000000}},	//   odpl, ঠনিক_, _тұлы, --, 
   {{0xdca4009d,0x00000000,0x00000000,0x00000000}},	//   _аажи, --, --, --, 
   {{0x49705d99,0xfcc40032,0x644801e1,0x00000000}},	//   ильс, _сәлм, _ìfiw, --, 
   {{0xa3cc3d4d,0x81b800cc,0x066c00d1,0x00000000}},	//   _राग_, ছলি_, ﺰﯨﻘﯩ, --, 
   {{0x68245178,0x27480023,0xea6000e5,0x00000000}},	//   _nódu, _ነቕርበ, _گھٹی, --, 
   {{0x7d080165,0x7a2402e2,0xd5a0006c,0x00000000}},	//   _gérô, _pòtu, شلری, --, 
   {{0xa3cc74aa,0x61fc0fac,0x325401f0,0x57a4030d}},	//   _राख_, ddpl, ҳвар, _ишпа, 
   {{0x78740014,0x61fc29d0,0x091800cc,0x12c80150}},	//   _حُبا, edpl, _ফেকু_, _ﺗﻪﻭﺭ, 
   {{0x337474ab,0x325405f5,0x61fc0d27,0x439474ac}},	// [88d0] угар, гвар, fdpl, раус, 
   {{0x776c209c,0xd4980276,0x7e6800b5,0x61fc01f5}},	//   _iyax, _орм_, _nkdp, gdpl, 
   {{0x99e40209,0x00000000,0x00000000,0x00000000}},	//   _goňş, --, --, --, 
   {{0x61fc017a,0x28c474ad,0xbe0401d3,0x6e9400d1}},	//   adpl, _विसि, یونٹ, гиду, 
   {{0x68240174,0x645806af,0x2d7c00d1,0x00000000}},	//   _gódu, étie, ﻤﯩﻨﻰ_, --, 
   {{0x10880150,0x00000000,0x00000000,0x00000000}},	//   _ﺑﺎﺩﯨ, --, --, --, 
   {{0xa2802ab4,0xde140372,0xddd8007f,0x313400d8}},	//   _ایلو, اقىت_, _oktņ, _севр, 
   {{0x5dc402dd,0x4ea44130,0x00000000,0x00000000}},	//   _ەملە, _аржа, --, --, 
   {{0x28c407b7,0xe3c40086,0x76441600,0xdc3c013d}},	//   _विहि, õñin_, _omhy, _cíın, 
   {{0x2bd40073,0x1ee800f2,0x7f580153,0x00000000}},	//   _धावा, _سومی_, _раус_, --, 
   {{0x776c74ae,0x1ce0025c,0x6e2003ac,0x3d0401f9}},	//   _ayax, _ཧཱར_, _iolb, विणे_, 
   {{0x6e2074af,0x2c080034,0xe73874b0,0xab9402bf}},	//   _holb, वाओं_, еем_, _сиді, 
   {{0x6e2074b1,0x28c42677,0x776c003a,0x9c80022a}},	//   _kolb, _विवि, _cyax, íčen, 
   {{0x386874b2,0x6e200010,0x7ae40254,0x00000000}},	//   _ekar_, _jolb, _äita, --, 
   {{0x776c009a,0x6e2007f5,0xa3e8084c,0xda140014}},	//   _eyax, _molb, ндва_, _حسنک, 
   {{0x6e2074b3,0x3d0401bc,0x00000000,0x00000000}},	//   _lolb, विते_, --, --, 
   {{0x6e20035a,0x00000000,0x00000000,0x00000000}},	// [88e0] _oolb, --, --, --, 
   {{0xf1a83ccb,0x10881c5c,0x6e2074b4,0x61fc01f5}},	//   نامه_, _ﺑﺎﺭﯨ, _nolb, udpl, 
   {{0x61fc74b5,0x19b400c8,0x11d4007b,0x1e8400ee}},	//   rdpl, רפער_, اومة_, ңлем, 
   {{0x6aac1f21,0x36f4025c,0x68240162,0xa534004e}},	//   _ħafn, _བརྩལ_, _gódt, _анүч, 
   {{0x64bc0882,0x644474b6,0x76440042,0x047400cf}},	//   ṇidh, _imki, _ymhy, _مئڭگ, 
   {{0x6e2074b7,0x7a24007f,0x00000000,0x00000000}},	//   _colb, _lòtr, --, --, 
   {{0xc0d40023,0x00000000,0x00000000,0x00000000}},	//   የቶም_, --, --, --, 
   {{0x628c74b8,0x682401ed,0x7a24067c,0x9084009d}},	//   _hibo, _móds, _nòtr, _ббсб_, 
   {{0x2bd433ee,0x6e2074b9,0xdc3c0166,0x00000000}},	//   _धारा, _folb, _qíın, --, 
   {{0x28c40825,0x628c74ba,0xd334011a,0x1a7401ec}},	//   _विशि, _jibo, טרפה_, ыұлы_, 
   {{0x8d9074bb,0x1be40517,0x628c74bc,0x644474bd}},	//   _المش, _бўлг, _mibo, _omki, 
   {{0x628c3d81,0x7d180077,0x7d080857,0xdd94035b}},	//   _libo, mxvs, _irds, _раҧы, 
   {{0xa3cc1889,0x1b4874be,0x33280009,0x6e20010b}},	//   _राज_, _язди_, xyax_, _yolb, 
   {{0x6444009f,0x6e2001a9,0x2cbc013d,0x00000000}},	//   _amki, _xolb, _äydä_, --, 
   {{0x53e405f5,0x7a24007f,0x2c080073,0xf44800e5}},	//   лцаа, _fòtr, वाचं_, نلسٹ_, 
   {{0x386874bf,0x26dc084c,0x66e40134,0x628c74c0}},	//   _ukar_, ător_, _wɔka, _aibo, 
   {{0x776c0921,0x64440036,0x96440139,0x81ac00cc}},	// [88f0] _uyax, _dmki, _бэнд, _গাজ_, 
   {{0x7d0874c1,0x644474c2,0x05dc0073,0x764408a5}},	//   _ords, _emki, _बायब, _umhy, 
   {{0x645874c3,0x6e200af9,0x00000000,0x00000000}},	//   étic, _rolb, --, --, 
   {{0x6e2000ed,0x72d474c4,0x00000000,0x00000000}},	//   _solb, _комф, --, --, 
   {{0x628c74c5,0x6e2074c6,0x7d0874c7,0x035801af}},	//   _fibo, _polb, _ards, _бүтә_, 
   {{0x7d0808ad,0x28c474c8,0x628c74c9,0x518474ca}},	//   _brds, _विलि, _gibo, _буба, 
   {{0x6e200316,0xfca80451,0x682401d3,0x858000d1}},	//   _volb, هايو_, _módr, ﻨﯩﺪﺍ_, 
   {{0x3cec054e,0x4034010a,0xd09401e0,0x3ea0010f}},	//   _dpdv_, _лесс, _ашҡы, ŭita_, 
   {{0x78a4655f,0x9b740372,0x628c74cb,0x7d084431}},	//   _čiva, ۇڭۇز_, _yibo, _erds, 
   {{0x6f0814dc,0x628c06e4,0x80cc0d2c,0x00000000}},	//   _irec, _xibo, _हिमे, --, 
   {{0x7a2402bd,0x7d08002f,0xed503c97,0xec240137}},	//   _pòtr, _grds, _بپا_, _پىشپ, 
   {{0x36f40135,0x2a640280,0x81ac015b,0x7654045a}},	//   _བརྡལ_, solb_, _গাছ_, enzy, 
   {{0x69f80354,0x00000000,0x00000000,0x00000000}},	//   _анлă, --, --, --, 
   {{0x6aa80b34,0xa9a40440,0x6f0874cc,0x64a4009d}},	//   mpef, _тикд, _mrec, иага, 
   {{0x628c74cd,0xd7a40b9c,0xd940013e,0x6aa812ed}},	//   _ribo, _क्वच, _меши, lpef, 
   {{0x6f0874ce,0x628c48b5,0x07b00cad,0x25a40356}},	//   _orec, _sibo, _fẹẹr, _şold_, 
   {{0x07b001e1,0x628c74cf,0x00000000,0x00000000}},	// [8900] _gẹẹr, _pibo, --, --, 
   {{0x46640145,0x322800d4,0x00000000,0x00000000}},	//   _چۇڭق, лієм_, --, --, 
   {{0xe0d86770,0x628c74d0,0x6f0874d1,0xa2c00c4c}},	//   тве_, _vibo, _arec, _लिक्, 
   {{0x6f0874d2,0x628c74d3,0x29040c86,0x644474d4}},	//   _brec, _wibo, ivla_, _umki, 
   {{0x628c74d5,0x6f0874d6,0x645474d7,0xdea074d8}},	//   _tibo, _crec, mnyi, زیای, 
   {{0x6f0874d9,0x7d0000dd,0x7d080175,0x5cc401b9}},	//   _drec, járá, _prds, асиз, 
   {{0xdfd005d9,0x787c01ed,0x645470b6,0x6f0874da}},	//   _ويس_, léve, onyi, _erec, 
   {{0x645474db,0xc0a800f1,0x35a00023,0x5c040f06}},	//   nnyi, _لاړل_, ፍታታት_, ряка, 
   {{0x7a24007f,0x645474dc,0xdcf400fd,0x290405d5}},	//   _bòtp, inyi, ıbız, evla_, 
   {{0x9d443b5f,0x9e6474dd,0x00000000,0x00000000}},	//   _кезд, _ئارن, --, --, 
   {{0x6f080a40,0x2ca474de,0x00000000,0x00000000}},	//   _zrec, _gtld_, --, --, 
   {{0x787c01d3,0x9b6874df,0x00000000,0x00000000}},	//   kéve, _ишла_, --, --, 
   {{0x66e4013f,0xc6f80251,0x787c01d3,0x8c18011a}},	//   _dɔko, анях_, jéve, _שודי, 
   {{0x645474e0,0xcb300395,0x787c00e5,0x6d440419}},	//   enyi, _фешъ, déve, ĺhav, 
   {{0x8a78011a,0x00000000,0x00000000,0x00000000}},	//   _שאות, --, --, --, 
   {{0x645474e1,0x07b00248,0x439401f4,0xba7400d1}},	//   gnyi, _tẹẹr, жатс, _ئاچت, 
   {{0x787c01d3,0xec70010f,0x24680064,0x00000000}},	// [8910] géve, פֿל_, dėmę_, --, 
   {{0x645474e2,0x69dc013f,0x80e00011,0x6f080200}},	//   anyi, ɑses, নবন্, _rrec, 
   {{0x6f080bb8,0x372400f1,0x00000000,0x00000000}},	//   _srec, _خوښې, --, --, 
   {{0x7d0001ed,0x6aa800cc,0x3448014b,0x00000000}},	//   zárá, ypef, _сӯги_, --, 
   {{0x6da4564f,0xff5074e3,0x59c40490,0xada474e4}},	//   била, وخه_, लणार, балл, 
   {{0xed5874e5,0x6f0874e6,0x2ca40077,0xc3200183}},	//   лол_, _vrec, _ptld_, _নেকি_, 
   {{0x6f0800a9,0x7d0001d3,0x7c9474e7,0xe818095f}},	//   _wrec, várá, орыц, धामा_, 
   {{0x6f080262,0x80cc0d41,0x85580375,0x7c640116}},	//   _trec, _हिते, ישוב_, يايل, 
   {{0x6f0874e8,0x7a24033b,0x7d002bb4,0x63a00113}},	//   _urec, _pòtp, tárá, ñoni, 
   {{0xe8f874e9,0x64540369,0x6aa805ac,0xa9f80229}},	//   гло_, znyi, rpef, ухих_, 
   {{0x999c0006,0x3c3800d8,0x2c600419,0x787c00e5}},	//   entų_, _séve_, zódy_, zéve, 
   {{0x6aa81347,0x2bdc3ee1,0x3c3800e4,0x1ce00327}},	//   ppef, क्खू_, _péve_, _ཧྱི_, 
   {{0x645474ea,0x6b7400db,0x00000000,0x00000000}},	//   vnyi, _улду, --, --, 
   {{0x66e4013f,0x3c3801d3,0x46480107,0x787c00e5}},	//   _wɔko, _véve_, рҷон_, véve, 
   {{0x64a474eb,0xc9840276,0x645400e5,0xdb0c0108}},	//   саба, _туди, tnyi, ädöl, 
   {{0x64a474ec,0x645474ed,0x2c600030,0x787c74ee}},	//   _қама, unyi, tódy_, téve, 
   {{0x645474ef,0xa06874f0,0xa1c400fd,0xb9e4010c}},	// [8920] rnyi, қада_, йбад, _ሩት_, 
   {{0x26c04d3c,0xe04474f1,0x787c74f2,0xeae400c5}},	//   msko_, әнди, réve, _कहैत_, 
   {{0xd00c74f3,0x2bf80a28,0x787c00dd,0x00000000}},	//   کلن_, ्यां_, séve, --, 
   {{0x1aec0154,0xa2e401af,0x00000000,0x00000000}},	//   জিতে_, _ломд, --, --, 
   {{0x26c074f4,0xa2c0007d,0x442074f5,0xfe4800c7}},	//   nsko_, _लिट्, mji_, аҟаи_, 
   {{0x216800d1,0x3d0474f6,0x26c074f7,0xf1a802f2}},	//   _биги_, विले_, isko_, _نافه_, 
   {{0x442074f8,0xcb4000c7,0xfbdc0118,0x00000000}},	//   oji_, ҧхьи, _यादम, --, 
   {{0xa068104e,0xdd3003e0,0xe044008e,0x00000000}},	//   _саба_, _eşşe, _унби, --, 
   {{0x9b6874f9,0x26c04d3c,0x442008e7,0xd7f80853}},	//   ышка_, jsko_, iji_, қун_, 
   {{0x44200c95,0x6ecc0037,0x00000000,0x00000000}},	//   hji_, _सितु, --, --, 
   {{0x1ce00327,0x5c0401c6,0x58840150,0x00000000}},	//   _ཧཱི_, _гяла, йыма, --, 
   {{0x442074fa,0x26081682,0x26c01a48,0xb8d000af}},	//   jji_, ṱolo_, fsko_, _ओऽ_, 
   {{0x442074fb,0x95c803b7,0x0c000050,0x26c0007c}},	//   dji_, лува_, _رووُ, gsko_, 
   {{0x442074fc,0x645874fd,0x1aec015b,0xb4940063}},	//   eji_, étin, জিদে_, живљ, 
   {{0x442074fe,0x26c0007c,0x1b1c00eb,0x00000000}},	//   fji_, asko_, _বেচে_, --, 
   {{0x4420044e,0xb4e873c6,0x36d4136b,0x26c019d6}},	//   gji_, _यही_, _доир, bsko_, 
   {{0x249874ff,0x629802b5,0x66740092,0x00000000}},	// [8930] _eupm_, _ōtor, _በጅምላ_, --, 
   {{0x442016cb,0x75d47500,0x25b8010e,0x6a7c007f}},	//   aji_, _بيدا, _gepl_, pèfe, 
   {{0x44207501,0xeb140b02,0xef980150,0x00000000}},	//   bji_, _तप्त_, акеш_, --, 
   {{0x442014cf,0x1b1c0154,0xa2c03541,0x64480241}},	//   cji_, _বেছে_, _लिच्, _ìfip, 
   {{0xe8185572,0xd34400f2,0x00000000,0x00000000}},	//   धाता_, _ایذه_, --, --, 
   {{0x80a44d2d,0x915c0208,0x00000000,0x00000000}},	//   زمۇن, _cặp_, --, --, 
   {{0xfe706e93,0xac380212,0x26080bae,0x00000000}},	//   رده_, ичих_, ायती_, --, 
   {{0x26c07502,0xeb987503,0x6aac0200,0x00000000}},	//   ysko_, шии_, _çafk, --, 
   {{0xdb200241,0x00000000,0x00000000,0x00000000}},	//   _èrìg, --, --, --, 
   {{0x44207504,0x26c07505,0x915c004d,0x2bf800dc}},	//   zji_, vsko_, _gặp_, ्यहं_, 
   {{0x26c01afd,0x44207506,0xad540133,0x00000000}},	//   wsko_, yji_, _بناغ, --, 
   {{0x442000e8,0x00000000,0x00000000,0x00000000}},	//   xji_, --, --, --, 
   {{0x28c46f64,0x44207507,0xc89004d3,0xe5a47508}},	//   _विकि, vji_, _کاتژ, жиги, 
   {{0x442001c8,0x00000000,0x00000000,0x00000000}},	//   wji_, --, --, --, 
   {{0xa2c07509,0xf1dc038e,0x4420750a,0x3c380022}},	//   _लिङ्, न्छन, tji_, _héva_, 
   {{0x442004ce,0x3c3800e4,0x211801b9,0xe8c40073}},	//   uji_, _kéva_, یتاب_, वळीच, 
   {{0x4420750b,0x224805b1,0x25b802f0,0xc17800c0}},	// [8940] rji_, _pmbk_, _tepl_, _šė_, 
   {{0x4420068f,0x787c00e4,0x00000000,0x00000000}},	//   sji_, méva, --, --, 
   {{0x4420750c,0xd5a001b9,0x787c750d,0x00000000}},	//   pji_, _تلپی, léva, --, 
   {{0xa2a01533,0xe3b00127,0x00000000,0x00000000}},	//   _कंप्, _ترد_, --, --, 
   {{0x9e64750e,0xa23405f5,0x5f04750f,0xdb0001ab}},	//   ياتن, _дэвш, юзда, _leoò, 
   {{0x61447510,0x9e7801f3,0x8ca00014,0xc5b800cc}},	//   _дега, _ፖሊሲና_, ڈٕوو, _জাঁপ, 
   {{0x61ec7511,0x5efc00dc,0x16b4098a,0xd7d87512}},	//   _ibbl, लिङ्_, _अब्ब, _भालच, 
   {{0x787c0c63,0x20340214,0xaf340014,0xa0340136}},	//   kéva, _بفرس, _کرِت, _بىرت, 
   {{0xddc80093,0xdee421f3,0x787c00e4,0x7c2002d0}},	//   lifō, _фози, jéva, rjmr, 
   {{0x200401c6,0x5d14085b,0x00000000,0x00000000}},	//   ldoi_, _وباز, --, --, 
   {{0x2d940148,0x63a47513,0xae0000d1,0x00000000}},	//   _хрус, _ofkn, _سۈيى, --, 
   {{0x20047514,0x64580098,0x00000000,0x00000000}},	//   ndoi_, étil, --, --, 
   {{0x44fc1a4c,0x61ec7515,0x7bc07516,0x657c06be}},	//   _aŭ_, _obbl, mamu, _azph, 
   {{0x7bc07517,0x63a40430,0xddd801ed,0x0c9400db}},	//   lamu, _afkn, _kitű, _ادەگ, 
   {{0xf9c800c6,0x6aac0135,0x05dc07af,0x320c06be}},	//   _ђмṡ_, _ħafi, _बारब, _ğey_, 
   {{0x320c4ba9,0x61ec7518,0x7c2400a3,0xb5d00150}},	//   _şey_, _abbl, _òird, _ﭙﺴﯩﺰ, 
   {{0x51a8005e,0x44fc01e4,0x00000000,0x00000000}},	// [8950] لداپ_, _eŭ_, --, --, 
   {{0x7bc07519,0x63a40270,0x61ec0204,0x80cc01f9}},	//   hamu, _efkn, _cbbl, _हिशे, 
   {{0x5064751a,0x6a7c004e,0x9f440156,0x7ee40150}},	//   отда, nèfa, meoù_, _ﺍﻻﻨﻁ, 
   {{0x7bc0751b,0x61ec03ac,0x9f4405c7,0x75d40832}},	//   jamu, _ebbl, leoù_, _بيگا, 
   {{0xb8dc6d7e,0x7bc0751c,0x6da42460,0x4ea4013d}},	//   _ཆས_, damu, пила, цреа, 
   {{0x6da44cf6,0xf1c801ec,0xada4376d,0x7bc0003a}},	//   чика, _دوسى_, чакл, eamu, 
   {{0x7bc00a55,0xf3f8031c,0xd018751d,0x00000000}},	//   famu, _ཕྲོད_, _кфа_, --, 
   {{0x7bc0751e,0x3c380588,0x6e9801af,0x00000000}},	//   gamu, _péva_, _гвар_, --, 
   {{0xfe70751f,0x05dc0316,0xda141098,0xab5c033f}},	//   ردۇ_, _बालब, तांत_, każe, 
   {{0x787c0124,0x3c3800c7,0x7bc03ed2,0xe2a40d12}},	//   véva, _véva_, aamu, áðin_, 
   {{0x7bc07520,0xa9687521,0x9f4405c7,0xf768010f}},	//   bamu, сина_, deoù_, _עק_, 
   {{0xa134010f,0xd7d8037e,0x3c380129,0xb52000cc}},	//   פארק_, moホ_, _téva_, ননাথ_, 
   {{0xf3f8031c,0x2a340064,0x00000000,0x00000000}},	//   _ཕྲེད_, _нэкр, --, --, 
   {{0xe81c00c5,0x80cc00ce,0x787c00c7,0xd9e0000d}},	//   _बचवा_, _हिले, réva, _खायत_, 
   {{0x5e54008f,0x6a7c004e,0x39800092,0x787c00c7}},	//   לישע_, cèfa, _የፓርቲ_, séva, 
   {{0x69c07522,0x787c7523,0x33f4004e,0x00000000}},	//   lale, péva, мчус, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [8960] --, --, --, --, 
   {{0x69c07524,0x7bc07525,0x1780008e,0xe8180a8a}},	//   nale, zamu, _ягым, धावा_, 
   {{0x7bc07526,0xf1a87092,0xf500016c,0xdcf80327}},	//   yamu, تاقه_, _иҷро, _iftħ, 
   {{0x7bc00050,0x6b980770,0x614001e1,0x00000000}},	//   xamu, _ngwg, _aílé, --, 
   {{0x69c07527,0x7bc07528,0x614000bc,0xa11401b9}},	//   kale, vamu, _bílé, _کوزت, 
   {{0x69c07529,0x7bc0752a,0x7ae402f6,0x61ec1f2a}},	//   jale, wamu, _äiti, _ubbl, 
   {{0x7bc0752b,0x69c0752c,0x60244d87,0x44c806be}},	//   tamu, dale, _едва, nğ_, 
   {{0xb0d00574,0x26080943,0x6144013e,0x28c4752d}},	//   _हितग, ṱoho_, _деҳа, _विजि, 
   {{0x7bc0250b,0x69c0752e,0x7998030d,0x44c80477}},	//   ramu, fale, _pgvw, hğ_, 
   {{0x7bc0752f,0x1aec045e,0x6a7c0100,0x00000000}},	//   samu, জিলে_, tèfa, --, 
   {{0x7bc07530,0xd90c7531,0x9f440489,0xdee40107}},	//   pamu, ایب_, veoù_, _фоҷи, 
   {{0x7bc07532,0x69c07533,0x4c980375,0xab5c012d}},	//   qamu, aale, _הבאו, waże, 
   {{0x47341142,0xc93005c7,0x9f440165,0x00000000}},	//   еняс, rbūṭ, teoù_, --, 
   {{0x28c407b7,0x98c400d1,0x00000000,0x00000000}},	//   _विचि, _есил, --, --, 
   {{0x9f4403bd,0xab5c0034,0xc8d007f7,0x00000000}},	//   reoù_, raże, _थियट, --, 
   {{0xab5c068f,0x9f4405c7,0x00000000,0x00000000}},	//   saże, seoù_, --, --, 
   {{0xa8000428,0xdb0401b8,0xe8183507,0xb788151e}},	// [8970] _òñan, _ämän, धारा_, _фәне_, 
   {{0xd5b80022,0xc2740114,0x7ad400bc,0xc1a400d8}},	//   _уси_, елуј, _दिनअ, ејци, 
   {{0x787c59c6,0x61400332,0xfbdc0073,0x32d400d1}},	//   névo, _rílé, _यांम, _ﺟﻪﮬﻪ, 
   {{0x69c07534,0x6140143c,0x00000000,0x00000000}},	//   zale, _sílé, --, --, 
   {{0xe80c0d2b,0xd7d800e1,0x00000000,0x00000000}},	//   ियता_, _भाईच, --, --, 
   {{0x69c07535,0x23880030,0x057402dd,0x787c00e4}},	//   xale, ňujú_, _تاۋد, kévo, 
   {{0x6b980175,0xe81c000d,0x00000000,0x00000000}},	//   _pgwg, _बचला_, --, --, 
   {{0x2ef40212,0x68e4010e,0x00000000,0x00000000}},	//   _озбр, _ähdi, --, --, 
   {{0x2fcc7536,0xaa4400a8,0x98b00055,0x28c4012d}},	//   _ideg_, депл, _āyā_, _विङि, 
   {{0x05dc038e,0x69c03bf3,0x9e9400f7,0x187c0092}},	//   _बाइब, uale, _قالچ, _የሃገር_, 
   {{0x64587537,0x6aac0327,0x88c40118,0x7e647538}},	//   étik, _ħafu, _oběž, éipe, 
   {{0x7a2402e2,0xbca4007b,0xde440150,0xab5c031c}},	//   _mòty, _أمني, _ىرەۋ, rażb, 
   {{0x69c07539,0x260802ab,0xb6c401e0,0x57440006}},	//   pale, ायली_, нияһ, дзям_, 
   {{0x69c0753a,0x6a84036b,0x00000000,0x00000000}},	//   qale, _ўлка, --, --, 
   {{0x6a7c0228,0x388c00b8,0x787c00e4,0xb35c0023}},	//   lèfo, _aśru_, cévo, ቲካዊን_, 
   {{0x58b8011a,0xca7402f2,0xfa900205,0x00000000}},	//   _ומקצ, _باڵغ, şütü_, --, 
   {{0xa20406d4,0x78a400ef,0x00000000,0x00000000}},	// [8980] мпад, _čivi, --, --, 
   {{0x2fcc753b,0x00000000,0x00000000,0x00000000}},	//   _adeg_, --, --, --, 
   {{0x600800e6,0xf1a8753c,0x30a400d4,0x91e02377}},	//   жнем_, ساله_, ерів, тохе, 
   {{0x3ec40022,0x00000000,0x00000000,0x00000000}},	//   еидҳ, --, --, --, 
   {{0x63b40649,0xe7e42208,0x2fcc0368,0x71740023}},	//   mbyn, _काना_, _ddeg_, ጽሕፈት_, 
   {{0x66e4013f,0xddf00220,0x2fcc0009,0x6d0802a0}},	//   _wɔkw, токө, _edeg_, विंग_, 
   {{0x16d81e61,0x910000c7,0x05dc098a,0x91e001f0}},	//   _बम्ब, _ипре, _बाईब, _шоре, 
   {{0x63b403a2,0x3dcc0142,0x408801ee,0x00000000}},	//   nbyn, _wddw_, _эҙем_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb35c02d3,0x8e8000d8,0x787c0022,0x4a5000db}},	//   ቲካዉን_, _агуе, tévo, ккыс, 
   {{0xa8040139,0x00000000,0x00000000,0x00000000}},	//   _olığ, --, --, --, 
   {{0xec68753d,0x98480d30,0x787c753e,0x36d4026b}},	//   _ерік_, іяна_, révo, номр, 
   {{0x5b344352,0x63b40652,0x6ec0193d,0x787c007f}},	//   _تعار, dbyn, रीपु, sévo, 
   {{0xa80400fd,0x00000000,0x00000000,0x00000000}},	//   _alığ, --, --, --, 
   {{0x15b800ee,0x00000000,0x00000000,0x00000000}},	//   йыңы_, --, --, --, 
   {{0xe7e404fa,0xd6f8037e,0x00000000,0x00000000}},	//   _काया_, sbケ_, --, --, 
   {{0x7d1c08a7,0xc1e80050,0x00000000,0x00000000}},	// [8990] _ársf, ژکٲل_, --, --, 
   {{0x7a24007f,0xab5c012d,0x00000000,0x00000000}},	//   _pòty, naża, --, --, 
   {{0x76540113,0xe7e4041c,0x34940114,0x00000000}},	//   mizy, _कामा_, _паор, --, 
   {{0x7654753f,0xab5c0327,0x00000000,0x00000000}},	//   lizy, haża, --, --, 
   {{0x02a400c7,0xa6e40162,0x9f940022,0xab5c7540}},	//   _арсм, miðú, нышә, każa, 
   {{0xb35c044e,0x518400f7,0x76540205,0x00000000}},	//   ቲካውን_, _жуба, nizy, --, 
   {{0xab5c0210,0x00000000,0x00000000,0x00000000}},	//   daża, --, --, --, 
   {{0x2fcc7541,0xc1040592,0x6ab401c6,0x00000000}},	//   _udeg_, _جوفي, нсох, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x5a601df9,0xa9242773,0x3df400f0,0x0378011a}},	//   лкыб, едол, _изус, ותחת_, 
   {{0x29107542,0xfbd00330,0x76547543,0xeff40023}},	//   íza_, _چته_, dizy, _ዉሑድ_, 
   {{0xfbd004d3,0x395800c6,0xcc8402f2,0x00000000}},	//   _نته_, úrsa_, _تۆبه_, --, 
   {{0x76547544,0xe7e4000d,0xab5c0003,0xdcf800ef}},	//   fizy, _काठा_, baża, _iztā, 
   {{0x23340022,0xfa900205,0x00000000,0x00000000}},	//   ҭхар, şürü_, --, --, 
   {{0xa8040d9c,0x6b1c0489,0x63b47545,0x19d01d00}},	//   _alış, ེདམོ_, tbyn, _ﻛﯘﻧﻠ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa69415ed,0x63b400a9,0x9c800232,0xe2840139}},	// [89a0] _прој, rbyn, íčin, елаи, 
   {{0x61447546,0xd5b40037,0x7d1c2507,0xdef80022}},	//   неза, _अभयज, _ársg, ҧыл_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdfd0034c,0x27e07547,0x274406af,0x21740107}},	//   ايش_, ngkn_, _gêné_, _ҷубр, 
   {{0x64547548,0xc204035b,0xe2987549,0x00000000}},	//   miyi, _иҟаи, _хаг_, --, 
   {{0x6454754a,0xdd90754b,0x21740006,0x7c7c0092}},	//   liyi, هوش_, _зубр, ኮኖሚው_, 
   {{0xe7e40073,0xcda400ec,0xe28c022e,0x00000000}},	//   _काढा_, رهيه_, mmа_, --, 
   {{0x6454754c,0xcd000c9e,0xd004010b,0xab5c033f}},	//   niyi, учши, _песе_, waża, 
   {{0xda78373e,0x60dc754d,0xcb04007b,0x9e6400c0}},	//   зян_, lupm, فيين_, _звад, 
   {{0x61fc754e,0x6454754f,0x05dc06b1,0x1d0800f3}},	//   nepl, hiyi, _बागब, _нези_, 
   {{0x76547550,0xab5c068f,0x64547551,0x60dc0477}},	//   vizy, raża, kiyi, nupm, 
   {{0x64540d04,0x7654033f,0x61fc0254,0xab5c0210}},	//   jiyi, wizy, hepl, saża, 
   {{0x64547552,0x61fc03a1,0x787c012c,0x60dc0455}},	//   diyi, kepl, lévk, hupm, 
   {{0x61fc7553,0xdbe00248,0x60dc1538,0xb50c0073}},	//   jepl, _séèf, kupm, हिलय_, 
   {{0x645401d9,0xd90c2099,0x7d1c03b2,0x7654033b}},	//   fiyi, _ایج_, _ársd, rizy, 
   {{0x76542178,0x60dc207a,0x64547554,0x89780375}},	//   sizy, dupm, giyi, _מרוצ, 
   {{0xb2747555,0x2be009ab,0x00000000,0x00000000}},	// [89b0] влаш, फलता, --, --, 
   {{0xd5b8519b,0x3c8c0150,0x999c0064,0x00000000}},	//   _эси_, _ﺗﺎﺑﻰ_, mitų_, --, 
   {{0x64547556,0x3f8401a9,0xcf24004b,0x999c00c0}},	//   biyi, _azmu_, کراي, litų_, 
   {{0x64547557,0xb384004e,0x00000000,0x00000000}},	//   ciyi, _үлүл, --, --, 
   {{0x61fc7558,0x64ac0115,0x22a40124,0xdb8800d1}},	//   bepl, _pĝig, _аусҳ, ﻗﯩﺮﻯ_, 
   {{0xac9c0023,0xdd0000dc,0x00000000,0x00000000}},	//   _ሃዲሞም_, _śrād, --, --, 
   {{0xf0e80046,0xab5c033f,0x961000cc,0x6ecc228d}},	//   _تىزى_, gażn, _সকাম_, _सिकु, 
   {{0xeb987559,0xefe0001f,0x00000000,0x00000000}},	//   мий_, ፐድያ_, --, --, 
   {{0x3d2c013f,0xea88022e,0x00000000,0x00000000}},	//   bɛwo_, мбил_, --, --, 
   {{0x6454755a,0xc3340bd4,0x7c2400a3,0x999c0153}},	//   ziyi, רוץ_, _òirn, ditų_, 
   {{0x999c00c0,0x00000000,0x00000000,0x00000000}},	//   eitų_, --, --, --, 
   {{0x2d840ab7,0x64540067,0x61fc012d,0x00000000}},	//   _izle_, xiyi, zepl, --, 
   {{0x61fc0724,0xb8e8007a,0x6454755b,0x00000000}},	//   yepl, _लौ_, viyi, --, 
   {{0x6454755c,0xb0d03af7,0x00000000,0x00000000}},	//   wiyi, _हिंग, --, --, 
   {{0x64a4755d,0x6454755e,0x61fc755f,0x64987560}},	//   таба, tiyi, vepl, дтар_, 
   {{0x41440220,0x7d1c0162,0x60dc014f,0xe3f800db}},	//   ңдаң, _árse, vupm, بىرت_, 
   {{0x64547561,0xe2980323,0x21a40dbe,0xa68400d1}},	// [89c0] riyi, даа_, визм, _илид, 
   {{0x06b80011,0x60dc7562,0x00000000,0x00000000}},	//   _জিপি, tupm, --, --, 
   {{0x61fc7563,0xa2a017c6,0xe19400c0,0xe28c022e}},	//   repl, _कूर्, траэ, rmа_, 
   {{0xdef87564,0x61fc7565,0x64540cfe,0x60dc014f}},	//   дык_, sepl, qiyi, rupm, 
   {{0x61fc7566,0xab5c033f,0x60dc0455,0xbdd402e8}},	//   pepl, ważn, supm, голщ, 
   {{0x60dc7567,0x2168004e,0xcfa40150,0x00000000}},	//   pupm, _жиги_, _ﺷﯩﻘﺒ, --, 
   {{0x60dc014f,0xd1b00133,0x32640454,0x00000000}},	//   qupm, _ئیمک, _серҳ, --, 
   {{0x06b800bd,0xab5c012d,0x30743a49,0xc1d401ee}},	//   _জিনি, rażn, _буус, _шөғә, 
   {{0x3f840552,0x3a747568,0x0d807569,0xe7e405f9}},	//   _uzmu_, ллир, ллән, कलना_, 
   {{0x44ec00e4,0x00000000,0x00000000,0x00000000}},	//   kÿ_, --, --, --, 
   {{0x787c756a,0x5c04756b,0xdb880150,0x7214010f}},	//   lévi, _аяла, _ﺮﺍﺩﻯ_, אַרב_, 
   {{0x3ea4756c,0xd9b00131,0x00000000,0x00000000}},	//   _kumt_, _ھەجد, --, --, 
   {{0x787c756d,0xa2a00307,0xe1e00073,0x7ad4007b}},	//   névi, _कूल्, _पांघ, _إقتص, 
   {{0x7d080649,0xb8d803d4,0x7ae0756e,0xcf900375}},	//   _ksds, _চি_, mumt, יטר_, 
   {{0x9474756f,0x7ae07570,0x3ea4036e,0x00000000}},	//   ندرا, lumt, _lumt_, --, 
   {{0x04b800dd,0x473403e6,0x7d0803ac,0xab5c0327}},	//   کھیں_, ارێز, _msds, każl, 
   {{0x7ae07571,0x58d00220,0x72187572,0xd5b8361e}},	// [89d0] numt, _соқт, нжар_, _осн_, 
   {{0xd5b47573,0x01cc0154,0x7d087574,0x00000000}},	//   _अभिज, র্ঘদ, _osds, --, 
   {{0x645800f7,0xd5640261,0x3ea402d2,0xf10400db}},	//   ètic, _штип, _aumt_, دۉزۉ_, 
   {{0x64587575,0x38a806af,0xfe780153,0x00000000}},	//   étit, _mûr_, _akį_, --, 
   {{0x60cc00f2,0x7d0806ea,0xeabc015b,0x00000000}},	//   _evbm, _asds, _আম্ম, --, 
   {{0x7ae0089c,0xf2880014,0xace81f39,0xab5c033f}},	//   dumt, _سپزو_, емка_, ważo, 
   {{0x32000170,0xab5c0210,0x00000000,0x00000000}},	//   mehy_, tażo, --, --, 
   {{0x7ae00af2,0x2e380ba1,0x320005da,0x228405da}},	//   fumt, _mèfi_, lehy_, môka_, 
   {{0x7ae02ffc,0xab5c0034,0x6a7c004e,0x5d500075}},	//   gumt, rażo, lèfi, икәт, 
   {{0xaa440aaf,0x6f0817a3,0xab5c0034,0x1db800dc}},	//   اندى, _isec, sażo, _उभयत, 
   {{0x6a7c00cf,0x00000000,0x00000000,0x00000000}},	//   nèfi, --, --, --, 
   {{0x7ae07576,0x68447577,0x00000000,0x00000000}},	//   bumt, унма, --, --, 
   {{0x2ca40428,0x7ae0003a,0x07a400c7,0x00000000}},	//   _huld_, cumt, лаҟн, --, 
   {{0x2ca47578,0x6f08009f,0xa9687579,0xcc9000b8}},	//   _kuld_, _msec, _пила_, _dṛś_, 
   {{0x1540757a,0x2aa80030,0x00000000,0x00000000}},	//   берм, _húb_, --, --, 
   {{0x68e0757b,0x6f08757c,0x60d8049f,0x2328016c}},	//   muld, _osec, _åtmi, ноби_, 
   {{0x63840323,0x32000170,0xe738757d,0xd464084c}},	// [89e0] угаа, fehy_, _чеп_, уите_, 
   {{0xe298035b,0x2ca4757e,0x2328013e,0xa5240166}},	//   хаз_, _ould_, _ҷоми_, _бмод, 
   {{0x3ea4757f,0x6f080c8c,0x64587580,0x7ae0005f}},	//   _sumt_, _asec, étis, zumt, 
   {{0x7ae00117,0x1ec85a52,0x92b000cc,0x00000000}},	//   yumt, елди_, _টিৰ_, --, 
   {{0x68e07581,0x657c7582,0x2ca44f7f,0x32000030}},	//   huld, _hyph, _auld_, behy_, 
   {{0x787c73a0,0x7ae0047e,0xab5c012d,0xdd84004e}},	//   révi, vumt, rażl, лыйп, 
   {{0x6f087583,0x61447584,0x2ca401ab,0x7ae00107}},	//   _esec, _сева, _culd_, wumt, 
   {{0x68e07585,0x2ca405e4,0x7ae07586,0x6ecc00e1}},	//   duld, _duld_, tumt, _सिचु, 
   {{0x38a87587,0xd1ec0020,0x657c0270,0x9f4802f6}},	//   _sûr_, _ሀሳብ_, _lyph, ämän_, 
   {{0x2ca4019b,0x68e07588,0x202400d7,0x00000000}},	//   _fuld_, fuld, štič_, --, 
   {{0x2ca47589,0x68e0758a,0x7ae0758b,0x19f40014}},	//   _guld_, guld, sumt, نِکھ_, 
   {{0x7ae0014f,0xacb00244,0x00000000,0x00000000}},	//   pumt, _بڕوب, --, --, 
   {{0xd90c758c,0x657c0113,0x7ae0758d,0x41c40073}},	//   زیک_, _ayph, qumt, षरास, 
   {{0x68e0716b,0x228400d2,0xd5a001d5,0xab5c0003}},	//   buld, yôka_, صلری, każj, 
   {{0x68e00261,0xb5940d97,0x00000000,0x00000000}},	//   culd, ривш, --, --, 
   {{0x657c2689,0x228405da,0x5a00009d,0x00a800d1}},	//   _dyph, vôka_, _түүв, ﻴﻪﺗﺘ, 
   {{0x38680009,0x95c80063,0x46dc0037,0x00000000}},	// [89f0] _ijar_, _пуна_, _बियह, --, 
   {{0x3868002d,0x249000d0,0x41740133,0x00000000}},	//   _hjar_, amym_, ڕانس, --, 
   {{0x3200758e,0xe8180073,0x00000000,0x00000000}},	//   rehy_, धाचा_, --, --, 
   {{0x8fc4758f,0x22840109,0x776c0327,0x98bc012d}},	//   ازان, rôka_, _kxax, cztą_, 
   {{0x26080574,0x68e04a98,0xe7e4033f,0x00000000}},	//   ायची_, zuld, कलता_, --, 
   {{0xed587590,0x6a7c0699,0xdd8c04d3,0x68e07591}},	//   кол_, pèfi, ژوو_, yuld, 
   {{0x776c0120,0xe7e4228d,0x3eb80219,0x3868010e}},	//   _lxax, _काला_, _črte_, _ojar_, 
   {{0x68e07592,0x8558010f,0x7f4800d1,0xdb0400d7}},	//   vuld, טשוב_, خلۇق_, žmýk, 
   {{0x6f087593,0x7e68010a,0x776c7594,0x5ac47595}},	//   _usec, _fjdp, _nxax, алым_, 
   {{0x38687596,0x68e07597,0x2ca40037,0x2aa800d0}},	//   _ajar_, tuld, _tuld_, _vúb_, 
   {{0xa9687598,0x38680327,0x776c7599,0x00000000}},	//   тина_, _bjar_, _axax, --, 
   {{0xe738759a,0x68e0759b,0x657c017a,0xe7e40073}},	//   вем_, ruld, _ryph, _काळा_, 
   {{0x38680003,0x7c940a11,0x00000000,0x00000000}},	//   _djar_, _اشلا, --, --, 
   {{0x68e0759c,0xbb843a16,0xe9d8011c,0x00000000}},	//   puld, _الهي, _ркк_, --, 
   {{0x776c0077,0x38681427,0x2b4c0083,0x2b900208}},	//   _exax, _fjar_, lzec_, _ạch_, 
   {{0x38680162,0xab5c025c,0x00000000,0x00000000}},	//   _gjar_, vażj, --, --, 
   {{0x64580231,0xa2e4759d,0xd2a4405c,0x2490014b}},	// [8a00] étiq, розд, икте_, rmym_, 
   {{0x657c759e,0x26d043d6,0x2558084c,0x98bc0034}},	//   _typh, _ivyo_, _армэ_, sztą_, 
   {{0x3cf402ab,0xa2a00210,0x00000000,0x00000000}},	//   _आहें_, _कंक्, --, --, 
   {{0x1aec015b,0xa2e4004e,0x58f4010f,0xfa580023}},	//   ড়িতে_, _комд, יצען_, ሎማሰኛ, 
   {{0x644436c5,0xd00c01d9,0x2d8003fa,0xde0409a5}},	//   _ilki, بلن_, ühen_, ипди, 
   {{0x1cb80156,0xa18800c7,0xab5c0327,0x00000000}},	//   _མསད_, _абга_, pażj, --, 
   {{0x9c44759f,0x23a80490,0x628c014f,0x3c5800a8}},	//   ихил, _कलाद, _ihbo, ликэ_, 
   {{0x10a075a0,0x26d000ec,0xd24c00db,0x00000000}},	//   _фитн, _ovyo_, _ىچە_, --, 
   {{0x9b680395,0x00000000,0x00000000,0x00000000}},	//   ъшка_, --, --, --, 
   {{0x5cf40006,0x00000000,0x00000000,0x00000000}},	//   _вяду, --, --, --, 
   {{0x644475a1,0xa3d40b4c,0xd238010f,0x00000000}},	//   _olki, सणा_, דגיל, --, 
   {{0xd9e81b57,0x8d58011a,0xcc3000c7,0x00000000}},	//   ज्जत_, _בכבי, _ҳхәы, --, 
   {{0x95c873b8,0x9a8475a2,0x628c0455,0xa2a01d24}},	//   кува_, _кукл, _ohbo, _कंग्, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc8d02072,0xc0cc0092,0x00000000,0x00000000}},	//   _थिएट, _አጣሪ_, --, --, 
   {{0x386875a3,0x628c01d5,0x35a400fd,0x645800d8}},	//   _ujar_, _ahbo, раңг, étip, 
   {{0xd684030d,0x00000000,0x00000000,0x00000000}},	// [8a10] _вунп, --, --, --, 
   {{0xdb000036,0x64ac0115,0xab78008f,0xc2c4007b}},	//   _agoë, _iĝin, אָעז, تيكي, 
   {{0xdcf875a4,0x6fb875a5,0x7e780139,0x00000000}},	//   _bytč, ггер_, dovp, --, 
   {{0x22842776,0x18a001ec,0x00000000,0x00000000}},	//   bôko_, _ﺍﻟﯟﻯ_, --, --, 
   {{0xb8c808ea,0xdfcc75a6,0xa28075a7,0xab5c033f}},	//   _བང_, ريو_, _کیلو, rażk, 
   {{0xb638037e,0x9f5401ed,0x2b4c054e,0x5194074d}},	//   _ｄｃ_, ágát_, vzec_, _кăла, 
   {{0x32100109,0xc10800ee,0xa5d8010f,0x8d7400db}},	//   _iazy_, _кэте_, אַפי, جاشا, 
   {{0x3210045a,0x00000000,0x00000000,0x00000000}},	//   _hazy_, --, --, --, 
   {{0x93ec0490,0x3210010b,0x7d1c03b2,0xeb980022}},	//   _छानच_, _kazy_, _ársn, ыии_, 
   {{0x2b4c0034,0x70500345,0xaadc0037,0x00000000}},	//   rzec_, _بۆچا, _मिठक, --, 
   {{0x15c80150,0x32d40150,0x00000000,0x00000000}},	//   _ﺑﯘﺯﺩ, _ﺟﻪﮔﻪ, --, --, 
   {{0x32102517,0x3cf801e3,0x00000000,0x00000000}},	//   _lazy_, _ärva_, --, --, 
   {{0x321044f1,0x6720009b,0xbc7000cf,0xdb000051}},	//   _oazy_, _šojb, _تۇيب, _ngoè, 
   {{0x321075a8,0x00000000,0x00000000,0x00000000}},	//   _nazy_, --, --, --, 
   {{0x23d4074d,0xc1e800f2,0x00000000,0x00000000}},	//   йцар, یکسل_, --, --, 
   {{0x998c00c0,0x26d00205,0x10a800d1,0x00000000}},	//   _elfų_, _tvyo_, ﻴﻪﺗﻨ, --, 
   {{0xe1f875a9,0x321075aa,0xab5c0327,0x00000000}},	// [8a20] лга_, _bazy_, fażi, --, 
   {{0x2284006a,0x17540375,0xe7e400e1,0xab5c031c}},	//   rôko_, _לספר_, कलवा_, gażi, 
   {{0xdfd800a7,0xa6a8009e,0x64440205,0x2d800037}},	//   гъл_, _কবিয়, _tlki, ühel_, 
   {{0x321000b5,0xd6cc2ab4,0x64440055,0x00000000}},	//   _eazy_, _تقی_, _ulki, --, 
   {{0xa2a003f3,0xc7b4013f,0x0a58044e,0x7ae401e4}},	//   _कंट्, _mfɑ_, ሎማስያ, _ĥito, 
   {{0x321000ee,0x787c0cde,0x5cc401d5,0x00000000}},	//   _gazy_, névr, бсиз, --, 
   {{0xd1b000e5,0xd00c0133,0x00000000,0x00000000}},	//   _رینک, بلۆ_, --, --, 
   {{0x6db001e4,0x5c040c98,0x7e780455,0x98bc012d}},	//   _aցad, сяка, sovp, cztę_, 
   {{0x7e780010,0x5e6000cf,0x9a2400ae,0x00000000}},	//   povp, _ىچتە, معدن, --, 
   {{0xd90c75ab,0x200475ac,0xdcac00db,0x00000000}},	//   فیت_, leoi_, _كۉت_, --, 
   {{0x5d8475ad,0x61ec01ef,0x527800df,0x00000000}},	//   _الال, _mcbl, רניא, --, 
   {{0x96e80006,0xdb8400c7,0x69c40254,0x00000000}},	//   льга_, _лгеи, _õhen, --, 
   {{0x3c3807ea,0x9b9400c6,0x61ec03ac,0x8858011c}},	//   _févr_, _الشت, _ocbl, сияс_, 
   {{0x63a402d0,0x00000000,0x00000000,0x00000000}},	//   _agkn, --, --, --, 
   {{0x321075ae,0xab5c0327,0xa2a0012d,0x00000000}},	//   _razy_, vażi, _कंज्, --, 
   {{0x321075af,0x57a43cc5,0xab5c031c,0x00000000}},	//   _sazy_, _ушка, ważi, --, 
   {{0x2004005a,0x966875b0,0x439406a4,0x8c18011a}},	// [8a30] deoi_, _مصدق_, затс, נומי, 
   {{0xc2c475b1,0x7ae001e7,0x00000000,0x00000000}},	//   سيمي, irmt, --, --, 
   {{0x321075b2,0x3eb80427,0x301475b3,0xf0e800d1}},	//   _vazy_, _črta_, ждер, شىشى_, 
   {{0x78b80a73,0x321043af,0x61ec030d,0x85b80014}},	//   _mtvv, _wazy_, _ecbl, _پایس_, 
   {{0xc1cc2e56,0x61ec037e,0x3210130d,0x6da426b1}},	//   _ﺗﯘﺭﺍ, _fcbl, _tazy_, оила, 
   {{0x83f0013f,0x98bc012d,0x3204013a,0x00000000}},	//   yiɑk, sztę_, _úly_, --, 
   {{0x9cb0009a,0x1db8033f,0x2ca800df,0xa2a00037}},	//   وموت, _उभरत, ĉado_, _कूट्, 
   {{0xae040014,0xdd1c0419,0xdca00395,0x00000000}},	//   _ڈورى, _míňa, мащи, --, 
   {{0x2aa800d7,0x1be8000d,0x00000000,0x00000000}},	//   _kĺbi_, _टारल_, --, --, 
   {{0x06b803d4,0x2be40073,0x00000000,0x00000000}},	//   _জিলি, _टाकू_, --, --, 
   {{0x61f800dd,0x7bc033b8,0x58d00120,0xfda41d39}},	//   _ötle, bbmu, моќт, _хјум, 
   {{0xdef80092,0x00000000,0x00000000,0x00000000}},	//   ፋጣኝ_, --, --, --, 
   {{0xfbd075b4,0x9f440165,0x9a3c0051,0x00000000}},	//   _ستن_, ffoù_, ứơc_, --, 
   {{0xa4f40135,0xe7e4098b,0xfd6800c7,0xadec0037}},	//   _བྱུག_, _काका_, _resẽ, च्चन_, 
   {{0x1c1c0316,0x888401af,0x00000000,0x00000000}},	//   _मोडल_, _нғол, --, --, 
   {{0x61ec0076,0xfd6800e4,0xe73802e8,0xcd880023}},	//   _scbl, _pesẽ, _веи_, _ቅንዕና_, 
   {{0x69c075b5,0x6ab80175,0x00000000,0x00000000}},	// [8a40] oble, _jtwf, --, --, 
   {{0x69c075b6,0x91e0013e,0x07a40014,0x68e00175}},	//   nble, дофе, _وۅگُ, orld, 
   {{0x69c075b7,0x00000000,0x00000000,0x00000000}},	//   ible, --, --, --, 
   {{0x69c006a3,0x5f443ed0,0xfd6400f7,0x27300139}},	//   hble, ينال, үндү, _gеnä_, 
   {{0x20040363,0x00000000,0x00000000,0x00000000}},	//   reoi_, --, --, --, 
   {{0x217475b8,0xef9007d6,0xbf100166,0xe2a800ec}},	//   _дубр, ریلد, _җүкә, _ماڳن_, 
   {{0xa11475b9,0x69c075ba,0xc344001f,0x44c8236c}},	//   _بوزت, dble, _የመጠቀ, nş_, 
   {{0xa06875bb,0x69c075bc,0x7d1c1d0e,0x00000000}},	//   _таба_, eble, _ársm, --, 
   {{0x9e6431d5,0x533400c8,0x69c001bf,0x00000000}},	//   _двад, ַנטן_, fble, --, 
   {{0x64ac01e4,0x1cb80327,0x69c0002f,0x9e7000d1}},	//   _aĝim, མེད_, gble, _تۇتت, 
   {{0xfb181973,0x23a801f9,0x00000000,0x00000000}},	//   _گراں_, _कलंद, --, --, 
   {{0x69c075bd,0x6ec0738f,0x00000000,0x00000000}},	//   able, रीकु, --, --, 
   {{0x69c047b4,0x66e4013f,0x44c8054e,0xe72c0133}},	//   bble, _kɔky, eş_, ۆڵی_, 
   {{0x46dc75be,0x6d440158,0x386c0042,0xab5c0210}},	//   _बिरह, øhag, ŵer_, gażu, 
   {{0x349475bf,0x9f440156,0x94a801d5,0x00000000}},	//   завр, rfoù_, ртга_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x44c875c0,0x00000000,0x00000000,0x00000000}},	// [8a50] aş_, --, --, --, 
   {{0x2248003e,0x941800c5,0x00000000,0x00000000}},	//   _clbk_, _पोरच_, --, --, 
   {{0xeff0044e,0x3f84022e,0x47340214,0x00000000}},	//   _ፍሉይ_, _aymu_, _فریز, --, 
   {{0x2248005a,0x69c075c1,0x405401d3,0x79640023}},	//   _elbk_, zble, وئنس, _ጌጋታት, 
   {{0xd24475c2,0x3dcc0042,0x3f840142,0xd7d8019b}},	//   _дэви, _bedw_, _cymu_, toリ_, 
   {{0x6ec001bc,0x3f843903,0x7ae40108,0x90d40633}},	//   रीगु, _dymu_, _äity, _وآزا, 
   {{0x6ab803cb,0x69c0005c,0x00000000,0x00000000}},	//   _stwf, vble, --, --, 
   {{0x69c00649,0xffe405f5,0xcf400150,0x1048234c}},	//   wble, _оюун, _قىزۋ, _тяги_, 
   {{0xab644294,0x69c075c3,0x3dcc0042,0xcf24007b}},	//   явил, tble, _fedw_, _برأي, 
   {{0xdb0075c4,0x2fcc75c5,0x69c075c6,0x244c00a2}},	//   _egoï, _heeg_, uble, _iýme_, 
   {{0x69c075c7,0x69c4000d,0xab5c0327,0x00000000}},	//   rble, _õhem, vażu, --, 
   {{0x69c075c8,0x2fcc75c9,0x00000000,0x00000000}},	//   sble, _jeeg_, --, --, 
   {{0x2fcc75ca,0x8b640137,0x69c0107d,0xb6c401e0}},	//   _meeg_, _باام, pble, мияһ, 
   {{0x2fcc75cb,0x2700013f,0x00000000,0x00000000}},	//   _leeg_, _nɔne_, --, --, 
   {{0x2d840204,0x26dc00b0,0xfbd00133,0xfa3401c8}},	//   _jyle_, ōto_, _ستۆ_, _ترند, 
   {{0x2fcc0b89,0x2d8475cc,0xa9c000f7,0xe7e40b03}},	//   _neeg_, _myle_, _تۅگۉ, _काटा_, 
   {{0x27000605,0x3eb80219,0xe4480150,0x2d8475cd}},	// [8a60] _bɔne_, _črto_, _ۇلدى_, _lyle_, 
   {{0x2fcc011c,0x2d8475ce,0x82440092,0x171800df}},	//   _aeeg_, _oyle_, _የየራሳ, _פויע, 
   {{0x764005d1,0xdfd0007b,0x00000000,0x00000000}},	//   ölye, فيض_, --, --, 
   {{0x1be8068f,0x27f00076,0x51640137,0xd8d800df}},	//   _टाइल_, _jcyn_, чүсү_, מקער, 
   {{0x2fcc75cf,0x3dcc0142,0x2aa80419,0x2ff82e0b}},	//   _deeg_, _pedw_, _kĺbu_, تونگ_, 
   {{0x8fa06d66,0x2d8475d0,0x7d1c148b,0x5cc401d5}},	//   хаче, _byle_, _ársk, псиз, 
   {{0x7d7875d1,0x205407d6,0x81440345,0x00000000}},	//   غمبر_, _етар, _تۆان, --, 
   {{0xbab875d2,0x66e4013b,0x2fcc0076,0x2d8475d3}},	//   огих_, _wɔky, _geeg_, _dyle_, 
   {{0xdee4136b,0x2d8475d4,0xe7e4000d,0x00000000}},	//   _хози, _eyle_, _काजा_, --, 
   {{0x2d8475d5,0x2eb43334,0x2fcc0211,0x4df8012c}},	//   _fyle_, _ісус, _zeeg_, ल्दै_, 
   {{0x2d84062c,0x2fcc75d6,0x996475d7,0xcaf002f2}},	//   _gyle_, _yeeg_, ятил, وسیب, 
   {{0x2fcc002e,0x00000000,0x00000000,0x00000000}},	//   _xeeg_, --, --, --, 
   {{0x2d840064,0xec3401f7,0x00000000,0x00000000}},	//   _zyle_, _تونگ, --, --, 
   {{0x7688008c,0x00000000,0x00000000,0x00000000}},	//   mþyk, --, --, --, 
   {{0x46dc000d,0x00000000,0x00000000,0x00000000}},	//   _बिअह, --, --, --, 
   {{0xb2f80135,0x68fc0419,0x9660010a,0x00000000}},	//   _ཕྱུང_, ázdň, ĕксе, --, 
   {{0x7674732e,0x705400d1,0x00000000,0x00000000}},	// [8a70] _олиф, ۈنئا, --, --, 
   {{0x35b4006c,0x2fcc0009,0x00000000,0x00000000}},	//   _юбор, _seeg_, --, --, 
   {{0x2fcc002e,0xd6ac2b1b,0x463c0a7c,0x7d1c0252}},	//   _peeg_, _কবিয, _לעזע, _ársh, 
   {{0x2fcc01d4,0x27000134,0xaadc2aa1,0x00000000}},	//   _qeeg_, _wɔne_, _मिलक, --, 
   {{0x2d840204,0x2fcc0373,0x00000000,0x00000000}},	//   _syle_, _veeg_, --, --, 
   {{0x2fcc75d8,0x2d8475d9,0xc0f80023,0xd254072d}},	//   _weeg_, _pyle_, ለሶም_, _عیاش_, 
   {{0x2fcc0218,0xc35401e1,0x00000000,0x00000000}},	//   _teeg_, _ọ̀rò, --, --, 
   {{0xeab8023b,0x1b1400cc,0xb81c000d,0x00000000}},	//   ойи_, তমনে_, _बोलम_, --, 
   {{0xd5bc00dc,0xadf43252,0x2d8475da,0xfe6c75db}},	//   ्राज, _опаш, _wyle_, _бү_, 
   {{0x4ad400dd,0x2d84068f,0x00000000,0x00000000}},	//   _ہاتھ_, _tyle_, --, --, 
   {{0xfb34009d,0x00000000,0x00000000,0x00000000}},	//   _үнхэ, --, --, --, 
   {{0x25c4215d,0xf648011a,0x46dc000d,0x00000000}},	//   वर्ण, _דצ_, _बिआह, --, 
   {{0xf1dc043e,0x442c0051,0x00000000,0x00000000}},	//   मणान, _đd_, --, --, 
   {{0x6a84053f,0x00000000,0x00000000,0x00000000}},	//   _юлла, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd7fc00a8,0xc1f000c5,0x00000000,0x00000000}},	//   şări_, _चाहब_, --, --, 
   {{0xd5ac066d,0xf8340030,0xd464329b,0x7c240332}},	// [8a80] افہ_, úšťa_, фите_, _óire, 
   {{0x26c00109,0x63b4033f,0x61440107,0x76e800a2}},	//   mpko_, scyn, меза, _ỳagş, 
   {{0x6aac011c,0xe4480132,0x00000000,0x00000000}},	//   _èaff, _ۇلگى_, --, --, 
   {{0x7d1c1f60,0xd6cc75dc,0xdee475dd,0x53a075de}},	//   _ársi, _حقی_, доди, رمەك, 
   {{0xbf644bcf,0xe29875df,0xe82c001f,0x737400c7}},	//   رگرو, _мам_, _እየተነ, _зырх, 
   {{0xdcb82564,0xb2f8025c,0x6f0c0b97,0x00000000}},	//   ощи_, _ཕྱིང_, çaca, --, 
   {{0x716419c5,0x2df83418,0xc0f80023,0xd3200150}},	//   _كافك, سبوک_, ለቶም_, кiзу, 
   {{0x25dc205d,0x5f046ee8,0xfbd005d9,0xdb00004d}},	//   कृती_, _озба, اڪا_, _ngoã, 
   {{0x9e74036b,0x61fc017a,0x7e6401c7,0x3ec40107}},	//   _قهرت, ofpl, éips, _чизҳ, 
   {{0x1c1c01ad,0x00000000,0x00000000,0x00000000}},	//   _मोरल_, --, --, --, 
   {{0x64c000df,0xa9d4030f,0x75f801d3,0x00000000}},	//   nĉiĝ, رژوا_, húzó, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd7880597,0x4c98011a,0x00000000,0x00000000}},	//   تخدم_, _ובאו, --, --, 
   {{0x61fc01a4,0x00000000,0x00000000,0x00000000}},	//   jfpl, --, --, --, 
   {{0x88e000c7,0x00000000,0x00000000,0x00000000}},	//   _ҧжәе, --, --, --, 
   {{0x61fc0b4f,0x57a4024c,0x3a3c00a2,0x53440022}},	//   efpl, _ошпа, _hovp_, мхза, 
   {{0x61fc44dc,0x33740588,0x73c4008e,0xcaa00023}},	// [8a90] ffpl, хгар, _җәбе, _ወዲኦም_, 
   {{0xd14875e0,0x439475e1,0x00000000,0x00000000}},	//   يشان_, таус, --, --, 
   {{0xc0cc0201,0xf1940022,0x00000000,0x00000000}},	//   _አባል_, хижь, --, --, 
   {{0x61fc75e2,0x6734032e,0x00000000,0x00000000}},	//   afpl, _ífjö, --, --, 
   {{0xe45430fb,0xdb0007ae,0x668001d9,0x64580ea0}},	//   _נישט_, _ngoà, _شیہل, ëtie, 
   {{0x40940c50,0x6458005f,0x00000000,0x00000000}},	//   ىلەر, ītie, --, --, 
   {{0x645875e3,0x00000000,0x00000000,0x00000000}},	//   ūtie, --, --, --, 
   {{0xdcac00f7,0x00000000,0x00000000,0x00000000}},	//   حىي_, --, --, --, 
   {{0xd1d40092,0x00000000,0x00000000,0x00000000}},	//   _ርስት_, --, --, --, 
   {{0xcd2875e4,0x1ee875e5,0x302800f1,0x244c01ef}},	//   _وسان_, _رومی_, _بيړۍ_, _mýma_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x66e475e6,0xbb4800ec,0xc77401c4,0x00000000}},	//   нома, _ڪلهن_, втгө, --, 
   {{0xab2859db,0xe6d4009d,0x00000000,0x00000000}},	//   _хола_, эцнэ, --, --, 
   {{0x641401d5,0x00000000,0x00000000,0x00000000}},	//   کورط, --, --, --, 
   {{0x244c00a2,0x888400f1,0x00000000,0x00000000}},	//   _aýma_, _لیدن, --, --, 
   {{0x5b1001af,0x00000000,0x00000000,0x00000000}},	//   _рмәт, --, --, --, 
   {{0x2c00068f,0x7d1c0d12,0x61fc0175,0x00000000}},	// [8aa0] व्यू_, _ársv, tfpl, --, 
   {{0x61fc002f,0x2174004e,0x00000000,0x00000000}},	//   ufpl, нуер, --, --, 
   {{0x61fc049f,0xe12401c0,0xa06826b1,0x00000000}},	//   rfpl, эмжи, пажа_, --, 
   {{0x660c75e7,0x6720025c,0x40340114,0x00000000}},	//   lebk, _ġojj, ђелс, --, 
   {{0x94200153,0x00000000,0x00000000,0x00000000}},	//   _смяе, --, --, --, 
   {{0xdb0001fb,0x4df805d7,0x9fa400fb,0x660c75e8}},	//   _ngoá, ल्लै_, мыҙҙ, nebk, 
   {{0x629c75e9,0xd41003d4,0x9cc856f3,0x718801a9}},	//   mmpo, হাৰি_, чыла_, _жарҳ_, 
   {{0x660c000d,0x10a00354,0x00000000,0x00000000}},	//   hebk, _бисн, --, --, 
   {{0x3a7475ea,0x0d8023c9,0x46dc00c5,0x3a3c0010}},	//   клир, клән, _बिगह, _povp_, 
   {{0xa0100f22,0xf3380023,0xddb8010a,0x00000000}},	//   _সচিব_, _ረኺብና, _хуаш_, --, 
   {{0x629c1e0b,0x5ba80150,0x00000000,0x00000000}},	//   impo, _екем_, --, --, 
   {{0xd7d800b5,0x3d1c0037,0x00000000,0x00000000}},	//   coレ_, पटीं_, --, --, 
   {{0x8704020f,0x57a40276,0x00000000,0x00000000}},	//   ляре, эшоа, --, --, 
   {{0x244c75eb,0x34a8098a,0xcc300588,0x629c01e4}},	//   _rýma_, कद्द, _ахәы, jmpo, 
   {{0xdcf800e2,0x00000000,0x00000000,0x00000000}},	//   _iztē, --, --, --, 
   {{0x629c75ec,0x8b840131,0x7d1c0413,0x00000000}},	//   empo, _تەۋە_, _ársu, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [8ab0] --, --, --, --, 
   {{0x660c003e,0x00000000,0x00000000,0x00000000}},	//   cebk, --, --, --, 
   {{0x6458003a,0x506401a9,0x00000000,0x00000000}},	//   ëtic, нтда, --, --, 
   {{0x6db001e4,0xc0581cd0,0x409400d4,0x00000000}},	//   _eցal, ніч_, гріт, --, 
   {{0x7ff475ed,0xf2a400d1,0x244801c8,0x00000000}},	//   اسما, _җиңп, _آجپي_, --, 
   {{0x51843129,0x2bc80825,0x057402dd,0x02a4014b}},	//   _зуба, रर्थ, _جاۋد, _брсм, 
   {{0xfe702264,0xed58003b,0x00000000,0x00000000}},	//   حدن_, ьок_, --, --, 
   {{0x64ac01e4,0xcf7800c6,0x70944421,0x00000000}},	//   _iĝit, _فإذا_, _рабф, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa92401d5,0x60d80139,0xe9a401ec,0x2d8075ee}},	//   вдол, _äcmä, капп, ühes_, 
   {{0x6994016c,0x3c3806af,0x3eb80427,0x64b40073}},	//   ърих, _lévy_, _črti_, _आंधळ, 
   {{0x26c40790,0x76400108,0x00000000,0x00000000}},	//   _çook_, ölyn, --, --, 
   {{0x629c75ef,0xfc3000f1,0x37740139,0x00000000}},	//   ympo, _دحل_, гырс, --, 
   {{0x63440085,0x1ae01638,0xa96816c3,0x00000000}},	//   lɔng, _тошм, _оила_, --, 
   {{0x7d1c066a,0x660c75f0,0x00000000,0x00000000}},	//   _árst, rebk, --, --, 
   {{0xf9905767,0x232801af,0x6f08035a,0x33f400db}},	//   _ابه_, моби_, _opec, лчус, 
   {{0x934075f1,0x888407d6,0x24780118,0x3c38013a}},	// [8ac0] анте, _لیگن, jďme_, _cévy_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd874066d,0x6344043b,0x6f0803ac,0x16340375}},	//   _سمیت_, kɔng, _apec, _סנטר_, 
   {{0xd12c0736,0xe36400f3,0x00000000,0x00000000}},	//   تمم_, _акми, --, --, 
   {{0x73c00032,0x7e040022,0x81680023,0x00000000}},	//   _ыҡта, лҧаз, _ተኸቲሉ_, --, 
   {{0xe298152d,0xad6404fb,0x97580375,0x6344013f}},	//   _цаг_, گاهه, ודנט, tɔnf, 
   {{0x6f0802d0,0x3d1c012d,0x8d600114,0xb35c0023}},	//   _epec, पटें_, ивље, ሲያውን_, 
   {{0x6f080393,0x645475f2,0xfdd800ec,0xe28c022e}},	//   _fpec, nhyi, _ڳائڻ_, llа_, 
   {{0xda7875f3,0x8fa024b1,0x307475f4,0x2d800730}},	//   дян_, _вате, _сурс, üher_, 
   {{0x5ea43765,0xd90c75f5,0x53980a7c,0x81e40154}},	//   _شمال, قیت_, ויפו, ভ্র_, 
   {{0x63440085,0x3c0401b9,0xa3b00412,0x37f80139}},	//   bɔng, _бўлғ, टखा_, ненэ_, 
   {{0xc0d8069d,0x00000000,0x00000000,0x00000000}},	//   _ርእስ_, --, --, --, 
   {{0x2700016b,0xa3d44244,0x3d1c0248,0x00000000}},	//   _wɔnn_, हरन_, báwá_, --, 
   {{0x06a43306,0xceb00bd9,0x7d1c0321,0x3c38013a}},	//   لصَّ, ייש_, _árss, _révy_, 
   {{0x3eac2759,0x984c068f,0x45d475f6,0x2a7800e5}},	//   _midt_, jęć_, росс, ésbe_, 
   {{0x3eac105c,0x63440085,0x3dd80f22,0xd7e400d4}},	//   _lidt_, kɔnd, _সাফল, _ріко, 
   {{0xb27475f7,0x667025da,0xe73000a2,0x00000000}},	// [8ad0] глаш, شگیر, _käýý, --, 
   {{0x78ac75f8,0x69c40254,0x31340d1d,0x877c00df}},	//   _hiav, _õhet, лезр, _קאזי, 
   {{0x78ac0270,0xe7940344,0x82a40114,0xd5840133}},	//   _kiav, _لایک, рште, _شێره_, 
   {{0x672000f3,0x3eac75f9,0x00000000,0x00000000}},	//   _šoji, _aidt_, --, --, 
   {{0x78ac0170,0x3eac75fa,0xca6801d5,0x00000000}},	//   _miav, _bidt_, _orgа, --, 
   {{0xf1c852c8,0x78ac03a0,0xb1c831f6,0x00000000}},	//   _سورى_, _liav, _سِرن_, --, 
   {{0xef18012d,0x00000000,0x00000000,0x00000000}},	//   _ryżu_, --, --, --, 
   {{0xfd102885,0x63440085,0x78ac03d1,0x2fd85598}},	//   تجه_, bɔnd, _niav, _سوئد_, 
   {{0x6f080558,0x3ef80276,0xfa9005d1,0x2ec400fd}},	//   _upec, _интэ_, ğünü_, _сөем, 
   {{0xe8c8152d,0xfa903361,0x78ac75fb,0x00000000}},	//   нгол_, şünü_, _aiav, --, 
   {{0xc0d81e38,0x6344016b,0x9f480793,0x78ac005c}},	//   _ርእሰ_, mɔne, ämön_, _biav, 
   {{0x78ac75fc,0x9b90141b,0x13a800eb,0xead401c4}},	//   _ciav, ؤلیت, গুয়, _бодь, 
   {{0x78ac75fd,0x7d1c0ad9,0x00000000,0x00000000}},	//   _diav, _ársr, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x78ac0170,0x649875fe,0x29180f40,0x6454020c}},	//   _fiav, етар_, āsas_, thyi, 
   {{0x78ac1570,0xc0d8044e,0x33400092,0x00000000}},	//   _giav, _ርእሱ_, _የመዝሙ, --, 
   {{0x33d4005e,0x6454013f,0x645800cf,0xe29800d8}},	// [8ae0] ріст, rhyi, ètiq, еаа_, 
   {{0x6454685c,0x21a475ff,0xf9900137,0x78ac05c7}},	//   shyi, гизм, _ابۇ_, _ziav, 
   {{0x64540564,0x3eac0135,0x23880064,0xd5f80a7c}},	//   phyi, _ridt_, _sėją_, _אפיר, 
   {{0x661c0cfe,0x78ac18f7,0x63440085,0xa2e4104e}},	//   _hapk, _xiav, tɔnd, _йомд, 
   {{0x661c7600,0xc0d8044e,0xe5700014,0x34440139}},	//   _kapk, _ርእሲ_, _خطک_, _түти_, 
   {{0x661c0010,0x238800c0,0x00000000,0x00000000}},	//   _japk, _vėją_, --, --, 
   {{0x3eac4c2e,0xc360001f,0x661c44ef,0x00000000}},	//   _vidt_, _ለመጠቀ, _mapk, --, 
   {{0x661c02d5,0x00000000,0x00000000,0x00000000}},	//   _lapk, --, --, --, 
   {{0x58847601,0x78ac00a7,0x6344013f,0x3eac0158}},	//   ғына, _riav, bɔne, _tidt_, 
   {{0x44207602,0x78ac7603,0x661c01ed,0xc0d80023}},	//   hdi_, _siav, _napk, _ርእሳ_, 
   {{0x78ac7604,0x44207605,0x5c0402e8,0x00000000}},	//   _piav, kdi_, _бяла, --, 
   {{0x44207606,0x4d7813e2,0x661c002d,0x78ac0194}},	//   jdi_, _ארבע, _aapk, _qiav, 
   {{0x78ac19a2,0x9a84086f,0x661c0064,0x9f580166}},	//   _viav, _йукл, _bapk, _öyäz_, 
   {{0x44207607,0x4ae00050,0x661c036e,0xca6801a9}},	//   edi_, _آول, _capk, _urgа, 
   {{0xd4980b30,0x442001d9,0x78ac7608,0x661c0153}},	//   ера_, fdi_, _tiav, _dapk, 
   {{0x44207609,0x64581d64,0xd7f80902,0x00000000}},	//   gdi_, ūtin, _чук_, --, 
   {{0x58d00046,0x487400f1,0x00000000,0x00000000}},	// [8af0] _тоқт, _ددوس, --, --, 
   {{0x4420760a,0x479c0375,0x661c01a9,0x00000000}},	//   adi_, _איחס, _gapk, --, 
   {{0x4420760b,0xb114760c,0xf484760d,0x34940640}},	//   bdi_, рмеш, _ناحی, _ванр, 
   {{0x4420760e,0xa3d407af,0x661c0205,0x00000000}},	//   cdi_, हरण_, _zapk, --, 
   {{0x7c8802d3,0x661c0166,0x00000000,0x00000000}},	//   _ምህላው_, _yapk, --, --, 
   {{0x6cc4760f,0x0f7001ec,0xc39400fb,0x51940354}},	//   айка, ағұр, _ѳҫтә, _йăла, 
   {{0x8d747610,0xed34256e,0xa2807611,0x00000000}},	//   داشا, рэлэ, _بیلو, --, 
   {{0x7dc403cc,0x213c00a3,0xccf401ec,0xc3600092}},	//   لقۇن, _àtha_, _ұқк_, _ለመጥቀ, 
   {{0xa3d400e1,0xeb980107,0x00000000,0x00000000}},	//   हरत_, ъии_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x44207612,0x00000000,0x00000000,0x00000000}},	//   ydi_, --, --, --, 
   {{0x661c7613,0x395808c2,0x00000000,0x00000000}},	//   _sapk, ùrsa_, --, --, 
   {{0x44207614,0xd1bc044e,0xae1800ab,0x00000000}},	//   vdi_, ድሚት_, _धसान_, --, 
   {{0xa9a47615,0x8650013f,0x8ed4045e,0xe9a47616}},	//   _килд, _atɔr, _সমাগ, _калп, 
   {{0x44207617,0x28745067,0xe5a40cb6,0xd1d40092}},	//   tdi_, _выпр, риви, ርኩት_, 
   {{0x2b084966,0x8a100075,0x00000000,0x00000000}},	//   _वहाँ_, _ئېھت, --, --, 
   {{0x44207618,0x661c7619,0x6264761a,0xe1f81a71}},	// [8b00] rdi_, _tapk, аваа, кга_, 
   {{0x4420761b,0x00000000,0x00000000,0x00000000}},	//   sdi_, --, --, --, 
   {{0x4420761c,0x9e64331c,0x672403cd,0xa3e80798}},	//   pdi_, یاتن, lvkj, _идна_, 
   {{0x4420761d,0x00000000,0x00000000,0x00000000}},	//   qdi_, --, --, --, 
   {{0xdf580075,0x2fc8761e,0xab5c0327,0x47a80154}},	//   خشاش_, ñaga_, bbżi, কুরী, 
   {{0xa114761f,0x24907620,0x9ce47621,0x98bc0064}},	//   _پورت, llym_, ацил, lytą_, 
   {{0xdff40024,0x614401d5,0xa2d82314,0xab5c0210}},	//   _вязь, _тева, _पौत्, maży, 
   {{0xa3d409ab,0xc770001f,0x8c400114,0xfa9003e0}},	//   हरि_, _ጥፋተኛ_, жеће, ğümü_, 
   {{0xfa900790,0x00000000,0x00000000,0x00000000}},	//   şümü_, --, --, --, 
   {{0xba541d39,0x200401f4,0x24900419,0x00000000}},	//   свој, lfoi_, hlym_, --, 
   {{0xa3d42aa1,0xa2d407b6,0x98bc0153,0x00000000}},	//   हरा_, मीत्, kytą_, --, 
   {{0xcb64034d,0x7d1802d0,0x00000000,0x00000000}},	//   امیه_, mwvs, --, --, 
   {{0x98bc0024,0x24900076,0xda780139,0xd90c2e3e}},	//   dytą_, dlym_, _ияк_, سیک_, 
   {{0xd6844ea0,0x4ac000ec,0x6f0c067c,0x74f80116}},	//   румп, _بيوق, çaci, легр_, 
   {{0x249000a9,0x47a804c5,0xd5a007d6,0x625001bf}},	//   flym_, কুলী, زلری, _pæon, 
   {{0x24901368,0x787401d9,0x98bc00c0,0x00000000}},	//   glym_, _دُبا, gytą_, --, 
   {{0x657c4a1d,0x38687622,0x2128007b,0x78b8007c}},	// [8b10] _exph, _imar_, _arbh_, _huvv, 
   {{0x35f43e1e,0x78b803ee,0x51a82dfc,0x00000000}},	//   _упор, _kuvv, نداپ_, --, 
   {{0x38687623,0x78b80158,0x99e400a2,0x394c0076}},	//   _kmar_, _juvv, _gaňş, nyds_, 
   {{0x78b804ba,0x23ac0124,0x50640107,0x00000000}},	//   _muvv, _ẽje_, штза, --, 
   {{0x76440270,0x38680198,0x78b80810,0x3ef800a8}},	//   _kohy, _mmar_, _luvv, инцэ_, 
   {{0x1afc02f5,0x200403d1,0x9f44030a,0xa28001d3}},	//   ্টাই_, afoi_, ngoù_, _ٹیمو, 
   {{0x7644013f,0x78b8016d,0x6da40cb9,0x00000000}},	//   _mohy, _nuvv, щика, --, 
   {{0x9df46b62,0x764400d7,0x6ca80150,0x00000000}},	//   анәт_, _lohy, _ﺷﺎﺷﺴ, --, 
   {{0x764400ad,0xfe6c7624,0x00000000,0x00000000}},	//   _oohy, _жү_, --, --, 
   {{0x78b80477,0x2fdc01d4,0xe738013e,0xaa34005b}},	//   _buvv, lawg_, ҳем_, схищ, 
   {{0x6e200472,0x16f0031c,0x47dc0154,0x64400108}},	//   _ialb, _བཀུམ_, _ভাবী, öoik, 
   {{0xa8546fbd,0x6e207625,0xe7387626,0x78b80810}},	//   стој, _halb, гем_, _duvv, 
   {{0x6e207627,0x764402fb,0xe7380640,0x64580200}},	//   _kalb, _bohy, ћег_, ëtim, 
   {{0x76440369,0x6e207628,0x9f900162,0xe9d84258}},	//   _cohy, _jalb, _møði_, _скк_, 
   {{0x6e207629,0x76440369,0xa3a81944,0xc44807d6}},	//   _malb, _dohy, गेन_, لیدن_, 
   {{0x69c00175,0xab5c0034,0xb8641e5a,0x7864007b}},	//   lcle, waży, _وايو, _وديك, 
   {{0x2fdc762a,0x98bc762b,0xa2e40fbe,0x69c0003a}},	// [8b20] dawg_, rytą_, созд, ocle, 
   {{0x6e201368,0x76440097,0x9f50003e,0x78b8022e}},	//   _nalb, _gohy, _édég_, _yuvv, 
   {{0x7bc0037e,0x00000000,0x00000000,0x00000000}},	//   ycmu, --, --, --, 
   {{0x6e20762c,0xab5c012d,0xd00c0966,0x10a00108}},	//   _aalb, saży, فلم_, пихн, 
   {{0x88380020,0x737400c7,0xf40003d4,0x00000000}},	//   _እየተሰ, _дырх, _লোকৰ_, --, 
   {{0x6444762d,0x6e20762e,0xdde803e6,0x8ff40124}},	//   _hoki, _calb, ارشه_, ахәу_, 
   {{0x6444762f,0x6e207630,0xc0f802d3,0x628c022e}},	//   _koki, _dalb, ወቶም_, _ikbo, 
   {{0x64447631,0x7170278f,0x9f900174,0x78b80455}},	//   _joki, _تۇما, _føði_, _ruvv, 
   {{0x64447632,0x6e200192,0x78b80bdf,0x10a00063}},	//   _moki, _falb, _suvv, _хитн, 
   {{0x64447633,0x6e207634,0xd12c01d9,0x394c05e4}},	//   _loki, _galb, _تمہ_, tyds_, 
   {{0x78b82d64,0x64447635,0x764400e4,0x7878010b}},	//   _quvv, _ooki, _rohy, ийор_, 
   {{0x64447636,0x7ae0074d,0x76440263,0x394c38aa}},	//   _noki, psmt, _sohy, ryds_, 
   {{0xc0f80201,0x764403c6,0x6e200a43,0x00000000}},	//   _ወዲህ_, _pohy, _yalb, --, 
   {{0x69c07637,0x6444037e,0x6e207638,0x19b801af}},	//   ccle, _aoki, _xalb, _судь_, 
   {{0x64447639,0x53e405f5,0x9f440156,0x00000000}},	//   _boki, йцаа, rgoù_, --, 
   {{0x6444037e,0x7644016b,0x2fdc01d4,0x9814763a}},	//   _coki, _wohy, xawg_, _طبعا, 
   {{0x6444763b,0x764400e4,0xd1c8013e,0x00000000}},	// [8b30] _doki, _tohy, гуед_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6fb841b0,0x6444763c,0x1048763d,0x6e20014f}},	//   агер_, _foki, ляди_, _ralb, 
   {{0x6e20763e,0x6444763f,0x628c6fa8,0x741401b9}},	//   _salb, _goki, _ekbo, _بوحا, 
   {{0x69c03ac7,0x93247640,0x6e20013a,0x00000000}},	//   ycle, _ارجن, _palb, --, 
   {{0x64447641,0x2fdc0218,0x637400a2,0x244c08a5}},	//   _zoki, sawg_, _dünĸ, _rými_, 
   {{0x6e207642,0xdbd4022c,0x64447643,0x660805d1}},	//   _valb, tøði, _yoki, _öfke, 
   {{0x6e207644,0x69c003cb,0x644401d5,0x00000000}},	//   _walb, wcle, _xoki, --, 
   {{0x6e207645,0xdbd40579,0x69c04663,0xc0c0001f}},	//   _talb, røði, tcle, ትዌር_, 
   {{0xe9d818b6,0x6e200472,0x6344013f,0x17b40150}},	//   шко_, _ualb, kɔnn, _ﺤﺯﺍﺯ, 
   {{0x69c07646,0x64587647,0x1c0401f9,0xe3c0013d}},	//   rcle, ëtik, व्हल_, lgış_, 
   {{0x69c07648,0x244c00d0,0x64583e16,0xa7a8329b}},	//   scle, _tými_, ītik, икна_, 
   {{0xba7470c8,0x64447649,0x1dc400cd,0x00000000}},	//   _کانت, _roki, रुवत, --, 
   {{0x8aa4764a,0x6444764b,0x35c40364,0xe938764c}},	//   _уред, _soki, зарҳ, _نسبت_, 
   {{0x6444764d,0xd5440063,0xf9100408,0x98bc00c0}},	//   _poki, опре_, _пĕри_, kytę_, 
   {{0x74b8764e,0xdd0000dc,0x5ec800eb,0x00000000}},	//   сурс_, _śrīd, _রিসে, --, 
   {{0x6444764f,0x47a800bd,0x00000000,0x00000000}},	// [8b40] _voki, _ক্রী, --, --, 
   {{0x64442af2,0xe10800c7,0xd7d807ad,0xab5c031c}},	//   _woki, иезд_, xiペ_, qbżu, 
   {{0x64447650,0x2904021a,0xe5a41583,0xa2d808e6}},	//   _toki, ntla_, _фини, _पौर्, 
   {{0x64440210,0x00000000,0x00000000,0x00000000}},	//   _uoki, --, --, --, 
   {{0x9ea87651,0x290400c5,0x9878010f,0xe2a86a3b}},	//   авда_, htla_, סאנט, _ناسن_, 
   {{0x5bd00882,0x628c0175,0x5cc41eca,0xa3a800dc}},	//   सर्व, _ukbo, осиз, गेण_, 
   {{0x8e8002da,0x9638010f,0x00000000,0x00000000}},	//   بلوه, יגסט, --, --, 
   {{0x81bc00eb,0x305400f3,0x00000000,0x00000000}},	//   _ইজি_, _еђут, --, --, 
   {{0x29040e0f,0x00000000,0x00000000,0x00000000}},	//   etla_, --, --, --, 
   {{0xc314015b,0xda487652,0xd1dc0023,0x00000000}},	//   সিপি_, рчил_, _ዕቤት_, --, 
   {{0x91b80302,0xdd1c0306,0xa3a80073,0x9298011a}},	//   ימיי, líže, गेत_, שיית, 
   {{0xded00023,0x37c4013d,0x00000000,0x00000000}},	//   ከለኹ_, чәкб, --, --, 
   {{0x29047653,0x5a44084c,0xdd1c13d5,0xda640d2f}},	//   atla_, _мэка, níže, _واتي, 
   {{0x987802b5,0x98bc012d,0x13d01546,0x00000000}},	//   _kūī_, zytę_, तर्भ, --, 
   {{0x27f40118,0x00000000,0x00000000,0x00000000}},	//   ácné_, --, --, --, 
   {{0xd6d87654,0x23180184,0x00000000,0x00000000}},	//   _кто_, өнсө_, --, --, 
   {{0x8c180375,0x964401c0,0x3c1800bc,0x00000000}},	// [8b50] סומי, _дэнд, _दसैँ_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x30147655,0xe2a40ad9,0x34947656,0xb59401c4}},	//   здер, íðan_, _наор, _хинш, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x80dc0eac,0x98380092,0x643800df,0x94d80037}},	//   মূল্, _እየተቀ, _הערנ, _बबुआ, 
   {{0x5fa00131,0x29047657,0x244c01ef,0xa2b8011a}},	//   رەلم, ytla_, _dýmu_, _למשט, 
   {{0x29047658,0xd30400f1,0x02640133,0x00000000}},	//   xtla_, _دښځو_, _تێلێ, --, 
   {{0xc57c0302,0x4084004e,0x00000000,0x00000000}},	//   ירות, _жууб, --, --, 
   {{0x5ac40500,0x9a480248,0x9ac800e5,0x00000000}},	//   плым_, _àkọ́, یدیہ_, --, 
   {{0xe8f8487f,0x7c34031c,0x00000000,0x00000000}},	//   бло_, _ħerż, --, --, 
   {{0x29047659,0x00000000,0x00000000,0x00000000}},	//   utla_, --, --, --, 
   {{0x06c801b9,0x00000000,0x00000000,0x00000000}},	//   оҳий_, --, --, --, 
   {{0x2904765a,0x29100118,0x00000000,0x00000000}},	//   stla_, ůza_, --, --, 
   {{0xd1180490,0xdbd403b2,0x91d8000d,0x00000000}},	//   नबाण_, _høðu, _पड़लै, --, 
   {{0x64a402d5,0x00000000,0x00000000,0x00000000}},	//   зава, --, --, --, 
   {{0x98a0765b,0xe738005b,0xd4640063,0x11340092}},	//   _пище, _геи_, писе_, _የሚያና, 
   {{0xdbd40162,0x00000000,0x00000000,0x00000000}},	// [8b60] _møðu, --, --, --, 
   {{0x27e00a2e,0x0594765c,0xdbd403b2,0x244c013a}},	//   lakn_, _يادگ, _løðu, _rýmu_, 
   {{0x6578007b,0x6d440f23,0x00000000,0x00000000}},	//   úthd, ähal, --, --, 
   {{0xdd1c00bc,0xa0680640,0x27e004a5,0xd8d4010f}},	//   tíže, љада_, nakn_, פונט_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x27e0003e,0xdd1c00d7,0x00000000,0x00000000}},	//   hakn_, ríže, --, --, 
   {{0x20d8765d,0x710000c7,0x25b80009,0x6458002e}},	//   _دوزخ_, _аҧха, _mgpl_, ëtiw, 
   {{0xd00402bf,0x244c012c,0x6454016b,0x61fc005c}},	//   _несе_, _týmu_, nkyi, lgpl, 
   {{0xdfd4013d,0xcb0400ae,0x00000000,0x00000000}},	//   _моңы, كيين_, --, --, 
   {{0x61fc765e,0x987802b1,0x47dc00cc,0x81b000cc}},	//   ngpl, _tūī_, _ভাষী, _ট্য_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x32cc010e,0x4cb8123b,0xc7c801f4,0x00000000}},	//   lñyş_, _המאג, зыре_, --, 
   {{0x24980020,0x3ce40150,0x56c403c5,0x00000000}},	//   _መሥራት_, _ﺍﻹﺠﻤ, ящна, --, 
   {{0xcb340115,0x00000000,0x00000000,0x00000000}},	//   _מאדי_, --, --, --, 
   {{0x25b80014,0xd7f8004e,0x34940818,0x00000000}},	//   _dgpl_, _луп_, давр, --, 
   {{0x94a801b9,0x00000000,0x00000000,0x00000000}},	//   стга_, --, --, --, 
   {{0x244c02d2,0x00000000,0x00000000,0x00000000}},	// [8b70] _rýmt_, --, --, --, 
   {{0x61fc3402,0xd138010a,0x35b400d4,0x00000000}},	//   ggpl, йхе_, _обпр, --, 
   {{0x705400f2,0x00000000,0x00000000,0x00000000}},	//   وچرا, --, --, --, 
   {{0x3e2c00b7,0x64a0037e,0x733400db,0x6d4401f4}},	//   _ተሽከር, のiph, _قىجا, äham, 
   {{0xdbd406ea,0x00000000,0x00000000,0x00000000}},	//   _røðu, --, --, --, 
   {{0x5fcc0d26,0x12845945,0x7de406ba,0x479c008f}},	//   हुबल, _رمزی_, ىسىم, ציגס, 
   {{0x7058039b,0xde4400f1,0x999c00c0,0x200c0174}},	//   _давр_, بیلو_, iktų_, úkið_, 
   {{0xbd1802bf,0x9f44002e,0x3bf40588,0x00000000}},	//   яції_, ggoó_, нџьт, --, 
   {{0xbf240118,0x00000000,0x00000000,0x00000000}},	//   áště, --, --, --, 
   {{0x1dc40abd,0xf9d400d4,0x00000000,0x00000000}},	//   रुआत, нцюю, --, --, 
   {{0x27e00a2e,0xdbd403b2,0x6454005b,0x00000000}},	//   takn_, _tøðu, ykyi, --, 
   {{0x66e44d9b,0x3c440108,0x00000000,0x00000000}},	//   мома, _пэчв, --, --, 
   {{0x61fc049f,0xf1dc00e1,0x00000000,0x00000000}},	//   ygpl, यरान, --, --, 
   {{0xe5a4765f,0xda0c001e,0x2498001f,0x7c580150}},	//   диги, _hỏng_, _መብራት_, _ولەر_, 
   {{0x27e00a2e,0xba287660,0x645401f4,0x00000000}},	//   pakn_, _رسوم_, tkyi, --, 
   {{0x394801ec,0x61d400cd,0x00000000,0x00000000}},	//   _ءشوپ_, धर्ष, --, --, 
   {{0xda0c001e,0x603c0311,0x7ea4067c,0x64547661}},	// [8b80] _mỏng_, _lămâ, lòpe, rkyi, 
   {{0xda0c01fb,0x645401f4,0x98e401af,0x00000000}},	//   _lỏng_, skyi, _эсәһ, --, 
   {{0xdb1c02d2,0x00000000,0x00000000,0x00000000}},	//   _ávöl, --, --, --, 
   {{0xe3f80214,0x00000000,0x00000000,0x00000000}},	//   _بعدش_, --, --, --, 
   {{0xa3a87662,0x6264247f,0x2d840afa,0xd00c009a}},	//   गेश_, _قاسق, _axle_, ؤله_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xda0c001e,0xa3a8012c,0x90c0688a,0x00000000}},	//   _bỏng_, गेर_, _абсе, --, 
   {{0xa03407d2,0x717000cf,0x00000000,0x00000000}},	//   _تىرت, _حۇما, --, --, 
   {{0x451402f5,0xda0c0051,0xe0e400cc,0x00000000}},	//   াটিক_, _dỏng_, _নহয়ন, --, 
   {{0xdb20068f,0x59080327,0x9e7000cf,0x00000000}},	//   _źród, _ཀྱུས_, _جۇتت, --, 
   {{0x20e800c8,0x39587663,0x00000000,0x00000000}},	//   nĝi_, árs_, --, --, 
   {{0x20e800df,0x6930015e,0xda0c0051,0x00000000}},	//   iĝi_, اکور, _gỏng_, --, 
   {{0xd618129d,0x61ec44ef,0xc6280154,0xae040412}},	//   يتسا_, _odbl, মানা_, _रामन_, 
   {{0x6344013f,0xb42401d3,0xc6a400d8,0x00000000}},	//   mɔnh, کٹرو, врси, --, 
   {{0xe5840228,0x8ab400df,0x6618000d,0x999c00c0}},	//   еттү, _קלוג_, õtka, rktų_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa3a80574,0xd5b82852,0x00000000,0x00000000}},	// [8b90] गेल_, _мсн_, --, --, 
   {{0x6d44005b,0x657800ae,0xb7d80244,0x00000000}},	//   ähak, úthc, _بوکا_, --, 
   {{0x24800170,0x506401c0,0x25d40375,0x00000000}},	//   _fjkm_, мтда, _אותן_, --, 
   {{0x603c084c,0x61ec7664,0x64580023,0xcd2003e6}},	//   _rămâ, _edbl, ëtit, ێژای, 
   {{0xb900031c,0x15e01428,0x603c054e,0xdc380139}},	//   _སས_, _औजार_, _sămâ, _nçıs, 
   {{0x6da40e46,0x603c084c,0x956c02d3,0xada47665}},	//   нила, _pămâ, _ጥሜትን_, налл, 
   {{0xfe701a4d,0xdc386648,0x00000000,0x00000000}},	//   جدن_, _açıs, --, --, 
   {{0xdcf80064,0xa2d4084d,0x63ac0241,0x1af800eb}},	//   _lytė, मीक्, _ùnnù, ্বনে_, 
   {{0x32000076,0x2b5801e7,0x00000000,0x00000000}},	//   oghy_, ásc_, --, --, 
   {{0xfeb8240f,0x603c0356,0x32000afa,0x00000000}},	//   _قالت_, _tămâ, nghy_, --, 
   {{0xccc4036b,0x7e7400db,0xda0c0051,0x00000000}},	//   _ўғил_, _شاكئ, _tỏng_, --, 
   {{0x7ea4067c,0xa3a80118,0x00000000,0x00000000}},	//   ròpe, गेँ_, --, --, 
   {{0x20540115,0x00000000,0x00000000,0x00000000}},	//   גירל_, --, --, --, 
   {{0x68340139,0xa9680556,0x00000000,0x00000000}},	//   _büdä, _нила_, --, --, 
   {{0xa97800c8,0x2cac045a,0x6d440108,0x00000000}},	//   _מאַכ, omed_, ähah, --, 
   {{0x2cac030d,0x0ba00092,0xc3140154,0xe5a40107}},	//   nmed_, _ወታደር_, সিসি_, диҳи, 
   {{0x2cac7666,0xa3a8134e,0xda0400ab,0xd3841214}},	// [8ba0] imed_, गें_, _शामत_, ейте_, 
   {{0x2cac7667,0xdcf800c0,0xe2980022,0x00000000}},	//   hmed_, _gytė, чаз_, --, 
   {{0x2cac00af,0x64587668,0x00000000,0x00000000}},	//   kmed_, ëtis, --, --, 
   {{0x20e800df,0x9f847669,0xf1c8012d,0x00000000}},	//   rĝi_, нгед, ाँउन, --, 
   {{0x2cac007d,0x61ec0175,0xfe980014,0xdbcc0205}},	//   dmed_, _tdbl, وٝصک_, lıçk, 
   {{0x4f842832,0x2cac0204,0x61ec005c,0x9f440165}},	//   رانہ, emed_, _udbl, ugoñ_, 
   {{0xcd900640,0xb3940b82,0xcd24399f,0x81440244}},	//   лашћ, _ሎንዶን_, ежје_, _جۆان, 
   {{0x6b98015d,0xcd300633,0x2cac143a,0xe0440166}},	//   _bywg, اروب, gmed_, _янби, 
   {{0x1e840111,0x3ce0000d,0x00000000,0x00000000}},	//   _злам, _गौरइ_, --, --, 
   {{0x2cac3b08,0x996000d0,0xe9f0035b,0x9d44117e}},	//   amed_, ríža_, аҧшы, _пезд, 
   {{0xdca46ee4,0x2cac766a,0x00000000,0x00000000}},	//   _зажи, bmed_, --, --, 
   {{0x8d58011a,0x3eb80419,0x00000000,0x00000000}},	//   _מכבי, _črty_, --, --, 
   {{0x4784004e,0x00000000,0x00000000,0x00000000}},	//   гырб, --, --, --, 
   {{0x09e000bd,0xcf90008f,0x86240354,0x00000000}},	//   _মাথা, רטש_, льсе, --, 
   {{0x8930766b,0xb59418ac,0xceb000c8,0x9a70001f}},	//   _معيا, тивш, טיש_, _ችለናል_, 
   {{0x59080327,0x4998011a,0x657801e7,0xcd94011a}},	//   _ཀྱགས_, _משוב, útha, גדלת_, 
   {{0x09e00eac,0x00000000,0x00000000,0x00000000}},	// [8bb0] _মাতা, --, --, --, 
   {{0xb9e802d3,0xca300131,0x32000076,0x00000000}},	//   _ኮን_, ﺯﻣﺎ_, ughy_, --, 
   {{0x2cac0142,0x00000000,0x00000000,0x00000000}},	//   ymed_, --, --, --, 
   {{0x2cac0014,0x6fb41291,0x00000000,0x00000000}},	//   xmed_, نماا, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7ed406c2,0x00000000,0x00000000,0x00000000}},	//   ازنا, --, --, --, 
   {{0x2cac766c,0xeff002d3,0x61e80413,0xbe9800ae}},	//   tmed_, _ግጉይ_, ðfle, رضها_, 
   {{0x64ac01e4,0x63a0766d,0x6b9800e4,0xada4766e}},	//   _uŝit, żone, _pywg, наһл, 
   {{0xc62802a6,0x1c40766f,0x2cac7670,0x40847671}},	//   মাতা_, рным, rmed_, _сурб, 
   {{0x2cac5522,0x3ba40022,0x00000000,0x00000000}},	//   smed_, ылыҳ, --, --, 
   {{0xa9687672,0x0ca87673,0x09e0015b,0xefe40023}},	//   фина_, _етди_, _মাদা, _ማዕዶ_, 
   {{0x2eec08a5,0x6b740150,0x00000000,0x00000000}},	//   _kvef_, _илеу, --, --, 
   {{0x7ea4068c,0xb6c401e0,0xab280cb6,0x9b9005af}},	//   lòpa, лияһ, _цола_, _پلوت, 
   {{0xf1b07674,0x00000000,0x00000000,0x00000000}},	//   जधान, --, --, --, 
   {{0x2fcc0142,0x55e00a93,0xc4080014,0x00000000}},	//   _ofeg_, росб, ى۪دٕ_, --, 
   {{0x845400db,0x00000000,0x00000000,0x00000000}},	//   دىرچ, --, --, --, 
   {{0x24907675,0xa22801c6,0xa20400cf,0x00000000}},	// [8bc0] roym_, мжаа_, кпад, --, 
   {{0x26d00526,0x8bfc11ba,0xd2600eba,0x20d41cd0}},	//   _ityo_, ্যটন_, акуй, відс, 
   {{0x60087676,0xd00c00ec,0x00000000,0x00000000}},	//   днем_, ڪلن_, --, --, 
   {{0xd00c7677,0x27f00223,0x7ea400db,0x30a40212}},	//   قلم_, _jdyn_, dòpa, грів, 
   {{0x44207678,0xd00c00ec,0x1ea8007b,0x00000000}},	//   mei_, تلن_, واتي_, --, 
   {{0x44207679,0xefcc069c,0x00e43028,0x2fcc0165}},	//   lei_, _ብዘይ_, _متری, _efeg_, 
   {{0x44200428,0x629c00d5,0x27f00042,0xbd4400be}},	//   oei_, mlpo, _odyn_, انعي, 
   {{0x4420767a,0x20001125,0x0dc4767b,0x26d00a49}},	//   nei_, _øki_, нләй_, _otyo_, 
   {{0x4420767c,0x26d0767d,0x0ba00124,0xa2d40073}},	//   iei_, _ntyo_, ишьм, मीच्, 
   {{0x4420767e,0x27f0722a,0x5fcc0037,0x00000000}},	//   hei_, _adyn_, हुरल, --, 
   {{0x4420767f,0x26d05b70,0x673400e4,0x7ea4004e}},	//   kei_, _atyo_, _aryj, còpa, 
   {{0x635818a6,0x44207680,0x7e78107d,0x36d4013e}},	//   _kānā, jei_, livp, ломр, 
   {{0x7c202a06,0x635800dc,0x27f00368,0xdc800023}},	//   memr, _jānā, _ddyn_, ንየለይ_, 
   {{0x7c2001d3,0x635800cd,0xded00b82,0x00000000}},	//   lemr, _mānā, ከለና_, --, 
   {{0x44207681,0x26d01418,0xd90c01d3,0x18880329}},	//   fei_, _etyo_, _بیج_, _осип_, 
   {{0x44207682,0x629c01f5,0xe80810eb,0x6734036e}},	//   gei_, elpo, _वाया_, _fryj, 
   {{0x63587683,0x7e782d8b,0xf8b001d9,0x00000000}},	// [8bd0] _nānā, kivp, _پکھ_, --, 
   {{0x44207684,0x7c200083,0x7e780477,0x00000000}},	//   aei_, hemr, jivp, --, 
   {{0x44204124,0x6d5c0cc1,0x27f00368,0x77240014}},	//   bei_, _əsas, _ydyn_, _شٹھٕ, 
   {{0x44207685,0x629c106f,0xd7e0085c,0x8b6800e2}},	//   cei_, alpo, परिच, _ņēmē, 
   {{0x1ee80722,0x6358002b,0xdb44143e,0x7c201de4}},	//   فونی_, _cānā, _اَ_, demr, 
   {{0x6744002d,0x635800dc,0xb15c02dd,0x81d40354}},	//   _útjű, _dānā, _енгi, _ворх, 
   {{0xd7e00490,0x2d1c01ad,0xe9d80022,0x00000000}},	//   पराच, पबेल_, ҭки_, --, 
   {{0x2fcc04cc,0x6c3400c6,0xae0403e5,0x7ea4004e}},	//   _ufeg_, افظا, _रावन_, ròpa, 
   {{0x2ef8022c,0x63580055,0x26c403b9,0x26f000bc}},	//   _ísf_, _gānā, _çoox_, _अटेर_, 
   {{0x7d2802f6,0x09e00011,0xa924009d,0x00000000}},	//   ässä, _মাহা, гдол, --, 
   {{0x44207686,0xe2a405f7,0xfd040014,0x00000000}},	//   yei_, íðin_, _نولَ, --, 
   {{0x44207687,0x7c200076,0x6d440108,0xa2a87688}},	//   xei_, cemr, ähau, _जीन्, 
   {{0x44207689,0x38782508,0x629c03cd,0x2a34013d}},	//   vei_, èrra_, ylpo, _бэйр, 
   {{0x4420768a,0xa9a4768b,0x3cf801f9,0x00000000}},	//   wei_, _йилд, ईंचे_, --, 
   {{0x4420768c,0xed78044e,0xe8f4007b,0x00000000}},	//   tei_, _እንበር_, _إستخ, --, 
   {{0x4420768d,0xe5780131,0xd918011a,0x00000000}},	//   uei_, _үзи_, _נופל, --, 
   {{0x26d001b2,0x0514015b,0x88842099,0x6734035a}},	// [8be0] _utyo_, াটের_, _میگن, _uryj, 
   {{0x6144768e,0xe808466d,0x216800f3,0x6d5c03e3}},	//   леза, _वाडा_, низи_, _əsar, 
   {{0x629c768f,0xe3b07690,0x05a84540,0x83f0013f}},	//   rlpo, _گرد_, _गरिब, nkɑk, 
   {{0x1f640598,0x44207691,0x33d40111,0x1fdc000d}},	//   лкем, qei_, _вірт, मरेड, 
   {{0x7e787692,0x91e00183,0xae042982,0x63a400c0}},	//   tivp, _পাৰ্, _राशन_, _uzkn, 
   {{0xded0001f,0xe04401c0,0x63580055,0x2e3400d1}},	//   ከለኛ_, _өнги, _vānā, لبىڭ, 
   {{0x2cc801a2,0xaca8121e,0xd24c0a8e,0xc1d4008e}},	//   _ľudí_, چھنے_, _عنف_, _бөҗә, 
   {{0x63440134,0x635800b8,0x00000000,0x00000000}},	//   bɔnt, _tānā, --, --, 
   {{0x68f403c6,0x7c207693,0x8fa0011c,0xda78011c}},	//   ázdn, remr, _гате, еян_, 
   {{0x39147694,0x37e0015b,0x3a7400f7,0x49d4030d}},	//   амор, _ভাইর, рлор, лдью_, 
   {{0x20040270,0x00000000,0x00000000,0x00000000}},	//   ogoi_, --, --, --, 
   {{0x20047695,0xd8447696,0x7c200455,0x00000000}},	//   ngoi_, ухоп, qemr, --, 
   {{0x70e002ab,0x09e0015b,0x7ea4026c,0x167001d5}},	//   _पब्ल, _মারা, nòpo, йқир, 
   {{0xcf900375,0x3eac02c1,0x6d480034,0x6d4400cc}},	//   מטר_, _jhdt_, ślał, åhag, 
   {{0x6344013f,0x14c40811,0x94a868ba,0x85440166}},	//   kɔns, اهری_, етаа_, бэте, 
   {{0x55c07697,0xf8b802dd,0x3eac0042,0x7ea402e2}},	//   раңғ, _шөп_, _lhdt_, kòpo, 
   {{0x78ac7698,0xc7d808c3,0x00000000,0x00000000}},	// [8bf0] _ihav, _עוזי_, --, --, 
   {{0x0514015b,0x5fb827a6,0x63a00254,0xc398003b}},	//   ায়ের_, ेशनल, üona, укує_, 
   {{0x78ac1399,0xe79428c4,0x00000000,0x00000000}},	//   _khav, _مایک, --, --, 
   {{0x335400f7,0x8978010f,0x5064009f,0x63a07540}},	//   _күбө_, עראצ, دائِ, żona, 
   {{0xee08593c,0x78ac007f,0xa8040139,0xc62800eb}},	//   велл_, _mhav, _unış, মারা_, 
   {{0xacf40640,0xffd40131,0x2cbc0142,0x00000000}},	//   ачиј, لغۇد, _siwd_, --, 
   {{0xada4641f,0x78ac7699,0x6da40107,0x3eac0051}},	//   шакл, _ohav, шика, _dhdt_, 
   {{0xeb98769a,0x78ac769b,0x00000000,0x00000000}},	//   кий_, _nhav, --, --, 
   {{0xeeb8769c,0xd13801a9,0x00000000,0x00000000}},	//   _алаш_, _ўхҳ_, --, --, 
   {{0x78ac769d,0x7ea4068c,0xa3a85c0e,0xca64215c}},	//   _ahav, nòpl, गेट_, الدۇ_, 
   {{0x68442f83,0x78ac18e5,0xa9a4769e,0xe8080c2e}},	//   анна, _bhav, ринд, _वादा_, 
   {{0x78ac769f,0x7c8476a0,0xf56000b7,0x00000000}},	//   _chav, _луче, _ግልጋሎ, --, 
   {{0x78ac76a1,0xe7380640,0x6724002d,0xaa440408}},	//   _dhav, њег_, uwkj, _велл, 
   {{0xe7f00316,0x78ac127b,0xf99002f2,0x00000000}},	//   _आएका_, _ehav, _کبه_, --, 
   {{0xc62800bd,0x649876a2,0xe96802a9,0x29000022}},	//   মালা_, втар_, _шакл_, _êha_, 
   {{0xb1400020,0x78ac76a3,0x1af8015b,0x6384026b}},	//   _የሚያሳ, _ghav, ্বরে_, агба, 
  
   {{0x9f5007b3,0x4df40316,0xe29876a4,0xe3b859db}},	// [8c00] üyü_, ीलाई_, ваа_, тба_, 
   {{0x21281161,0x78ac76a5,0x7ae4008e,0x00000000}},	//   _psbh_, _zhav, _çite, --, 
   {{0x64a41baa,0x6aa0007b,0x88580023,0xa3a80c70}},	//   _вана, illf, _ዝከታተ, गेज_, 
   {{0xdef80716,0x78ac02d3,0x23ac00e4,0xe6d800bc}},	//   вык_, _xhav, _ẽju_, _बझाङ, 
   {{0x20040023,0xd004311b,0xe3b00214,0x00000000}},	//   rgoi_, рече_, _گرگ_, --, 
   {{0xf030001f,0x7ea456eb,0x20040042,0x00000000}},	//   _በዝርዝ, ròpo, sgoi_, --, 
   {{0xd0e40214,0x787c00e4,0x9fc8014b,0x69d40205}},	//   _نکنم_, hũva, _агба_, ızel, 
   {{0xe7f0033f,0xdb040200,0x00000000,0x00000000}},	//   _आएगा_, _çmën, --, --, 
   {{0x0d8046e8,0xf0000323,0x78ac18f7,0x3a7476a6}},	//   йлән, _хүчи, _rhav, йлир, 
   {{0x261401ad,0x00000000,0x00000000,0x00000000}},	//   _पॉली_, --, --, --, 
   {{0x79940139,0xad6400ec,0x00000000,0x00000000}},	//   синф, _ٿاله, --, --, 
   {{0x8c4001f0,0x6aa001e7,0xd0f4011a,0x00000000}},	//   _мехе, allf, סמכת_, --, 
   {{0x7ad476a7,0x78ac1aa1,0xaa6401e0,0x00000000}},	//   _اقتص, _vhav, ртөк, --, 
   {{0x32dc0ca8,0x98c476a8,0x00000000,0x00000000}},	//   _láyò_, _ксил, --, --, 
   {{0x588476a9,0x78ac76aa,0xd4984131,0x00000000}},	//   _выпа, _thav, вра_, --, 
   {{0x78ac07a8,0xd7f8064d,0x4a00031c,0x49b80375}},	//   _uhav, _рук_, _མཐོལ_, _במוס, 
   {{0x733800c7,0xd9b000cf,0x721802dd,0x00000000}},	// [8c10] ызар_, _دەگد, лжар_, --, 
   {{0xdcec00bc,0x6b6000e5,0x00000000,0x00000000}},	//   áděn, lágö, --, --, 
   {{0x32dc0248,0x34944b36,0xb558023b,0xb11404b1}},	//   _báyò_, _ганр, _синф_, смеш, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xda042274,0x23880030,0x6aa00142,0x4394014b}},	//   _शांत_, čujú_, yllf, _маюс, 
   {{0x6ad400fe,0x05740150,0x26181c54,0x00000000}},	//   _দিলো, _داۋد, म्पी_, --, 
   {{0x332804e6,0xed340de7,0x00000000,0x00000000}},	//   lwax_, сэлэ, --, --, 
   {{0x213c0597,0x7ff410fe,0x308400c6,0x00940139}},	//   _átha_, _وسقا, _الرف, _дисэ, 
   {{0x98bc0024,0x2ef400ee,0xfbac012c,0x00000000}},	//   lytė_, _ызар, _चरणम, --, 
   {{0xa9a40209,0xdc9800db,0x00000000,0x00000000}},	//   йипд, ктөш_, --, --, 
   {{0x98bc0024,0x00000000,0x00000000,0x00000000}},	//   nytė_, --, --, --, 
   {{0xed340f31,0x787c00e4,0xbd680798,0xc0c004b2}},	//   _پوچھ, tũva, _труе_, _ስለሺ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa508189d,0x98bc0024,0x7cc40137,0xfa8002dd}},	//   лега_, kytė_, _ازەم, _оқым, 
   {{0xe5a404a9,0xba74007b,0x98bc0064,0x00000000}},	//   сиви, _بانت, jytė_, --, 
   {{0x290476ab,0x232800c2,0xf1bc202e,0x7af0005b}},	//   mula_, лоби_, ्खनन, _ähtä, 
   {{0xe73876ac,0x61e876ad,0xc22400f2,0xc0d80b82}},	// [8c20] _сеп_, ðflo, يکسو, _ይብላ_, 
   {{0x63a00210,0x00000000,0x00000000,0x00000000}},	//   żono, --, --, --, 
   {{0xd6540375,0x98bc00c0,0x00000000,0x00000000}},	//   _היית_, gytė_, --, --, 
   {{0x4424003c,0x29040421,0xff24006c,0xa444009f}},	//   _úm_, iula_, قبتی, _اَحو, 
   {{0x290476ae,0xfe780064,0x00000000,0x00000000}},	//   hula_, _pmį_, --, --, 
   {{0x98bc0064,0x244c013a,0x00000000,0x00000000}},	//   bytė_, _rýmy_, --, --, 
   {{0x290476af,0xc0d8044e,0x91e007a5,0xa0a401d5}},	//   jula_, _ይብሉ_, _хосе, _гавд, 
   {{0x290476b0,0x307405f5,0x3d18000d,0x00000000}},	//   dula_, _дуус, _दहीं_, --, 
   {{0x999c02b5,0x93f80a7c,0x6a6c032e,0x1f6401d5}},	//   retō_, אלפי, _múff, _укам, 
   {{0x290476b1,0x6a6c02d2,0x00000000,0x00000000}},	//   fula_, _lúff, --, --, 
   {{0xc314015b,0xad6402c9,0xed4c00ec,0xdef801ec}},	//   সিটি_, _وامه, _لھي_, _шың_, 
   {{0x244c00bc,0x06c400fe,0x6ca400d4,0xf3300240}},	//   _týmy_, ্ঠনি, _дріж, _ብርቱዓ, 
   {{0x290476b2,0xe80810eb,0x3328003e,0xb6340014}},	//   aula_, _वारा_, xwax_, ۅکھش, 
   {{0x290476b3,0x45d476b4,0xea94004b,0xca9c0023}},	//   bula_, зорс, _واوښ, _ልብኹም_, 
   {{0x6a6c0162,0x787401d9,0x81c003d4,0x00000000}},	//   _búff, _وُتا, ীৰত_, --, 
   {{0x73d876b5,0x81c000bd,0x26183c71,0xc0d80023}},	//   рдар_, ীরা_, म्बी_, _ይብሎ_, 
   {{0x325476b6,0x386876b7,0x7e680113,0xd8900014}},	// [8c30] овар, _ilar_, _oldp, _ؤڈد, 
   {{0x75d405d9,0x6454001f,0x98bc0006,0x1fac00cc}},	//   _ڏيکا, _የገለጹ, tytė_, গশাস, 
   {{0xc0d8069c,0x3494016c,0xd13876b8,0x3328232c}},	//   _ይብል_, _маор, ыха_, swax_, 
   {{0x614476b9,0x6a6c02d2,0x00000000,0x00000000}},	//   تىمە, _gúff, --, --, 
   {{0x290476ba,0x3868022e,0x82940133,0xfd74009d}},	//   zula_, _mlar_, تگێڕ, үлчэ, 
   {{0x386876bb,0xad243ee0,0xed580902,0xc51402f2}},	//   _llar_, قىتى, иол_, _ببیت, 
   {{0x386876bc,0xe8084425,0x290476bd,0x7ae40135}},	//   _olar_, _वाला_, xula_, _ħita, 
   {{0x290476be,0x7e683a26,0x3868022e,0x00000000}},	//   vula_, _eldp, _nlar_, --, 
   {{0xc7b4013f,0x764401f5,0x00000000,0x00000000}},	//   _abɑn_, _onhy, --, --, 
   {{0x38680598,0x00000000,0x00000000,0x00000000}},	//   _alar_, --, --, --, 
   {{0x386876bf,0xbe300137,0x09c001e0,0x9f4800e5}},	//   _blar_, _سۉيب, оҡһо, óköz_, 
   {{0x386876c0,0xe7383eb3,0x764476c1,0xf648011a}},	//   _clar_, аем_, _anhy, _בצ_, 
   {{0x3868022e,0x0df00092,0x00000000,0x00000000}},	//   _dlar_, _ግሩፕ_, --, --, 
   {{0x38680254,0x7ae476c2,0x7d1c002f,0x53bc26e4}},	//   _elar_, _çita, _ärsc, ्शनश, 
   {{0x38680784,0xc448107f,0x29040912,0x1a98010f}},	//   _flar_, میدن_, qula_, _דיסע, 
   {{0x7644013f,0x7cf00332,0x00000000,0x00000000}},	//   _enhy, _hórá, --, --, 
   {{0xd4644170,0x161806ab,0x638401c0,0x2b4c004e}},	// [8c40] ците_, _पॉवर_, цгаа, nxec_, 
   {{0x3868036b,0xb400009d,0x00000000,0x00000000}},	//   _zlar_, _үүрд, --, --, 
   {{0x7cf000c6,0x2d840131,0x386801b9,0x00000000}},	//   _mórá, ﻪﺭﻧﻰ_, _ylar_, --, 
   {{0xa2a8193d,0xa06807b5,0xa3ec012d,0x94200116}},	//   _जीर्, јада_, _ज़िप_, _قوپۇ, 
   {{0x644476c3,0x00000000,0x00000000,0x00000000}},	//   _inki, --, --, --, 
   {{0xdd9076c4,0xc62800eb,0x3cf80118,0x00000000}},	//   ووش_, মাকা_, ैंले_, --, 
   {{0x2610007d,0x68ec0034,0x628c0477,0x61440798}},	//   _तानी_, _ładn, _ijbo, _ќеба, 
   {{0x3a2001e4,0x3b5476c5,0x261800bc,0x00000000}},	//   _ŝip_, зкир, म्ती_, --, 
   {{0x386801b9,0xdcf40205,0x8f64022e,0x00000000}},	//   _rlar_, ğcık, _датб_, --, 
   {{0x6444030d,0x4e0000f7,0x386876c6,0x60dc0fac}},	//   _lnki, _озуб, _slar_, oppm, 
   {{0x644476c7,0x5d84072d,0x386876c8,0xa2b007f7}},	//   _onki, _بلال, _plar_, _अठन्, 
   {{0x9b4442b5,0x386801a9,0x787c00c7,0x00000000}},	//   _وناو, _qlar_, rũvo, --, 
   {{0x60dc0477,0x63a0031c,0x00000000,0x00000000}},	//   hppm, żonj, --, --, 
   {{0x644476c9,0x628c01fa,0x00000000,0x00000000}},	//   _anki, _njbo, --, --, 
   {{0xd7f876ca,0x386801d5,0x73c40166,0x00000000}},	//   _куп_, _tlar_, зәге, --, 
   {{0xd14876cb,0x3868006c,0x88f400d9,0x94200137}},	//   یشان_, _ular_, _וזהו_, بورۇ, 
   {{0x1cd80327,0x00000000,0x00000000,0x00000000}},	// [8c50] _འཕའ_, --, --, --, 
   {{0x644476cc,0xd13876cd,0x00000000,0x00000000}},	//   _enki, ихе_, --, --, 
   {{0x7ea40137,0x628c0009,0xa2803a56,0xe7f0012d}},	//   còpi, _djbo, ریفو, _अजमा_, 
   {{0xdca476ce,0x00c8005e,0x349424a3,0xc95000c8}},	//   _سى_, ілік_, _хамр, ומע_, 
   {{0x786c000f,0xcf240b24,0x00000000,0x00000000}},	//   _gûve, تراي, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x644403b2,0x00000000,0x00000000,0x00000000}},	//   _ynki, --, --, --, 
   {{0x68ec0034,0xbd1800d4,0x00000000,0x00000000}},	//   _łado, юції_, --, --, 
   {{0x4ea46fbd,0xafe41cd1,0xdcac03cc,0xc02400db}},	//   _држа, _моңл, دىي_, _زىلي, 
   {{0xa3e01db2,0x00000000,0x00000000,0x00000000}},	//   _न्न_, --, --, --, 
   {{0xfd100066,0x00000000,0x00000000,0x00000000}},	//   _لجن_, --, --, --, 
   {{0x7d1c010b,0x00000000,0x00000000,0x00000000}},	//   _ärsa, --, --, --, 
   {{0x32100034,0x7cf00162,0x00000000,0x00000000}},	//   _oczy_, _tórá, --, --, 
   {{0x7ea400cf,0x6a6c08ce,0xfd640ca8,0x691c025c}},	//   tòpi, _búfe, _nirọ, tħeġ, 
   {{0x786c002d,0x290076cf,0x154076d0,0x00000000}},	//   _sûve, _íha_, нерм, --, 
   {{0xfd640241,0x58f8008f,0x1cd80327,0x00000000}},	//   _airọ, _פּונ, _འཕལ_, --, 
   {{0x32100139,0x1ad800cc,0x00000000,0x00000000}},	// [8c60] _bczy_, _দিৱা, --, --, 
   {{0x23700210,0x00000000,0x00000000,0x00000000}},	//   rzyj_, --, --, --, 
   {{0x23640bb8,0xae04146b,0x91e00107,0x059400f2}},	//   šoj_, _राजन_, хохе, _زادگ, 
   {{0x644476d1,0x00000000,0x00000000,0x00000000}},	//   _unki, --, --, --, 
   {{0xe81c0825,0x628c020c,0xa3e076d2,0x00000000}},	//   य्या_, _tjbo, _न्य_, --, 
   {{0xdea076d3,0x09e00154,0x90841884,0x660c0051}},	//   ریای, _মাঝা, ينەك_, ngbk, 
   {{0x61ec76d4,0xb7d400b8,0x00000000,0x00000000}},	//   _iebl, _iṣva, --, --, 
   {{0x63a476d5,0x61ec76d6,0x717038eb,0xa0300137}},	//   _kykn, _hebl, _جۇما, _سۉتت, 
   {{0x61ec2045,0x60cc014f,0xd00c76d7,0x09e00eac}},	//   _kebl, _hubm, _حلق_, _মাজা, 
   {{0x629c76d8,0x3eb8067c,0x61ec76d9,0x63a40fac}},	//   nopo, _òrt_, _jebl, _mykn, 
   {{0x61ec76da,0x629c0421,0x60cc014f,0x5bc4007b}},	//   _mebl, iopo, _jubm, _فقال, 
   {{0x629c76db,0x61ec76dc,0x00000000,0x00000000}},	//   hopo, _lebl, --, --, 
   {{0x629c76dd,0x00000000,0x00000000,0x00000000}},	//   kopo, --, --, --, 
   {{0xcad4025f,0x61ec76de,0xdb00003e,0x629c76df}},	//   _צוות_, _nebl, _nyoé, jopo, 
   {{0x629c76e0,0x60cc0455,0x08f476e1,0xf8b804b4}},	//   dopo, _nubm, _فريب_, _мөм_, 
   {{0xb9cc76e2,0x61ec04cc,0xc95401b9,0x98bc00c7}},	//   _ተራ_, _aebl, _хўш_, kytĩ_, 
   {{0x261805ba,0x629c019b,0x7d1803ac,0x00000000}},	// [8c70] म्ही_, fopo, htvs, --, 
   {{0x629c76e3,0x61ec76e4,0x63a476e5,0x01e805ac}},	//   gopo, _cebl, _dykn, _পাউদ, 
   {{0xb4b40831,0x30141c22,0x63a40162,0x65780332}},	//   _ойош, ддер, _eykn, útht, 
   {{0x61ec022f,0x629c0421,0x09e000cc,0xb6280150}},	//   _eebl, aopo, _মাছা, _ﻗﻊ_, 
   {{0x61ec76e6,0x629c76e7,0x00000000,0x00000000}},	//   _febl, bopo, --, --, 
   {{0x61ec09f9,0x6da476e8,0xada476e9,0x3210033f}},	//   _gebl, мила, малл, _uczy_, 
   {{0xfe7001b9,0x00000000,0x00000000,0x00000000}},	//   ددن_, --, --, --, 
   {{0x61ec76ea,0x1d040107,0x82f80244,0xdca00395}},	//   _zebl, феъи_, _برێز_, кащи, 
   {{0x31400020,0x61ec76eb,0xd1dc02d3,0x7ae4008e}},	//   _የሚቀር, _yebl, _ንቤተ_, _çitl, 
   {{0x60c800d2,0x61ec00e8,0x00000000,0x00000000}},	//   _úmmé, _xebl, --, --, 
   {{0xcce405d4,0xc0f4001f,0xac1802bf,0x6f180042}},	//   _رساي, _ልብስ_, _можу_, ltwc, 
   {{0x629c76ec,0x63a0012d,0x00000000,0x00000000}},	//   zopo, żoni, --, --, 
   {{0x6b7407d6,0x629c76ed,0x61a800dc,0xb904000d}},	//   _юлду, yopo, _कर्ष, _पढ़_, 
   {{0xa96876ee,0x6d200073,0x00000000,0x00000000}},	//   _мила_, _महाग_, --, --, 
   {{0x61ec76ef,0xf544009d,0x00000000,0x00000000}},	//   _rebl, ндрү, --, --, 
   {{0x161c084a,0x629c76f0,0x61ec76f1,0x60cc010f}},	//   म्बर_, wopo, _sebl, _rubm, 
   {{0x629c76f2,0x60cc76f3,0x61ec76f4,0x6e2002f0}},	// [8c80] topo, _subm, _pebl, _oblb, 
   {{0x60cc76f5,0xe1f80220,0x7ea4004e,0x91e006ed}},	//   _pubm, іге_, nòpt, вофе, 
   {{0x629c76f6,0x1cd8031c,0x60cc047e,0x6d4405ac}},	//   ropo, _འཕེ_, _qubm, åhal, 
   {{0x29040789,0x63a476f7,0x20e800df,0x261800bc}},	//   irla_, _tykn, rŝi_, म्री_, 
   {{0x6d400af5,0xa51c76f8,0x61ec76f9,0xb7d40055}},	//   _arla, _पहुच_, _tebl, _iṣta, 
   {{0x6d400a2e,0x60cc0198,0x61ec127b,0x00000000}},	//   _brla, _tubm, _uebl, --, 
   {{0xa06876fa,0xa11401d5,0x3f9801d3,0x05a40118}},	//   _дава_, _توزت, _کھاد_, _खुमब, 
   {{0x645476fb,0x2c700162,0x29040010,0xdb200271}},	//   njyi, _nádd_, drla_, نوعی, 
   {{0x6d4076fc,0xc5f400bd,0x29043fa8,0x64540369}},	//   _erla, _জানা_, erla_, ijyi, 
   {{0x6d4001a6,0xf9780a5b,0x00000000,0x00000000}},	//   _frla, збој_, --, --, 
   {{0x6d4076fd,0xedf476fe,0x4970009d,0x00000000}},	//   _grla, _سينگ, влэс, --, 
   {{0xad246ea9,0x6e2002f0,0x00000000,0x00000000}},	//   _سرمو, _zblb, --, --, 
   {{0x7ae0074d,0x29045e49,0x38c8168d,0x6454020c}},	//   qpmt, arla_, _کاتی_, djyi, 
   {{0x7ea40137,0x645401d4,0xb7d40055,0x799400d8}},	//   còpt, ejyi, _aṣta, _пилф, 
   {{0xb3e80c99,0x3e700241,0x7654000f,0x6d40022e}},	//   _འབྱུ, _gàte_, rjzy, _xrla, 
   {{0x29180356,0x6f180142,0x440400db,0x00000000}},	//   ăsat_, ytwc, кчуб, --, 
   {{0x473450d5,0x7ea4067c,0x95c873af,0x657801e7}},	// [8c90] _аныс, nòps, _муна_, úthr, 
   {{0x78bc4f8c,0xb7d40055,0x00000000,0x00000000}},	//   lmsv, _eṣta, --, --, 
   {{0x06c402a6,0x823401d5,0x6ad400fe,0x00000000}},	//   ্ঠশি, ضرلا, _দিছো, --, 
   {{0xb3e876ff,0xdfcc0451,0xc3300014,0x00000000}},	//   _འབྲུ, ٽيو_, دٕے_, --, 
   {{0x78bc2d8b,0x2c70110e,0x92680f5c,0x6a6c01e7}},	//   imsv, _jáde_, _дрва_, _lúfa, 
   {{0x6d407700,0x98bc0064,0x00000000,0x00000000}},	//   _prla, kytį_, --, --, 
   {{0xf0e802dd,0xbd88143e,0xc5f40154,0x6f18015d}},	//   _ءىرى_, ونهن_, _জামা_, stwc, 
   {{0x6b547701,0x7ea40100,0x98bc0064,0x00000000}},	//   етох, wòpt, dytį_, --, 
   {{0x6e200175,0x4aa8000d,0x76880064,0x00000000}},	//   _tblb, _घीउव, ižyb, --, 
   {{0x6d400a2e,0xc5f40f22,0xf8b000dd,0x29047702}},	//   _trla, _জাভা_, یکٹ_, trla_, 
   {{0x6d407703,0x29040192,0x7ea47704,0xbe6400ec}},	//   _urla, urla_, ròpt, _جهلي, 
   {{0xc0d8044e,0x6a6c01f1,0xac187705,0x8ca000cf}},	//   _ክብሪ_, _dúfa, _ходу_, _جەبو, 
   {{0x8b640137,0x00000000,0x00000000,0x00000000}},	//   _تاام, --, --, --, 
   {{0xa3e0515b,0x78bc0430,0x290409a8,0xdd1c0306}},	//   नुन_, amsv, prla_, líše, 
   {{0x39580ac8,0x00000000,0x00000000,0x00000000}},	//   ørst_, --, --, --, 
   {{0x64a47706,0x786c000f,0xe8080073,0x27e400a2}},	//   хаба, _tûva, _वाटा_, _ýon_, 
   {{0x33d47707,0x6a6c0030,0x5ed00131,0x00000000}},	// [8ca0] тіст, _zúfa, ﻟﺪﯗﺭ, --, 
   {{0x6aa00cfd,0x27f00067,0xc0d81ee0,0x00000000}},	//   nolf, _heyn_, _ክብረ_, --, 
   {{0x26d000b2,0x27f07708,0x84c40116,0xbbac012c}},	//   _huyo_, _keyn_, _җәңд, _चर्क, 
   {{0x26d0136f,0x6aa07709,0xd8d800c8,0x27f0062c}},	//   _kuyo_, holf, לקער, _jeyn_, 
   {{0x4420770a,0x27f01c06,0x26d003f9,0x81c800e2}},	//   mfi_, _meyn_, _juyo_, _smēķ, 
   {{0x4420770b,0x26d01418,0x27f0058a,0x1ee801b9}},	//   lfi_, _muyo_, _leyn_, قوچی_, 
   {{0x4420770c,0x26d00ecf,0x5cc4770d,0x2480770e}},	//   ofi_, _luyo_, нсиз, _kmkm_, 
   {{0x52e002a6,0x4420770f,0x26d0007f,0x6b8c7710}},	//   _পিতৃ, nfi_, _ouyo_, _žaga, 
   {{0x9b687711,0x442022a9,0xd014006c,0x3d1c02e5}},	//   яшка_, ifi_, _سقلش_, _महके_, 
   {{0x442002b4,0xa3e001ad,0xc210033f,0x4ef8011a}},	//   hfi_, _न्स_, ालिब_, _מהמו, 
   {{0x79940395,0x44200205,0xda7c0419,0x00000000}},	//   тинф, kfi_, žďom_, --, 
   {{0x26d00280,0x27f0058a,0x44202da4,0x2c707712}},	//   _buyo_, _ceyn_, jfi_, _páde_, 
   {{0x26d0204e,0xc6f8063b,0x27f05148,0x78bc0158}},	//   _cuyo_, ннях_, _deyn_, rmsv, 
   {{0x27f00076,0x44207713,0xaa480092,0x6a6c00d7}},	//   _eeyn_, efi_, _እፈልጋ, _húfn, 
   {{0xe8087714,0x26100ce0,0x657800ae,0x00000000}},	//   _वाचा_, _तारी_, úthp, --, 
   {{0x27f00014,0x44200076,0x00000000,0x00000000}},	//   _geyn_, gfi_, --, --, 
   {{0x768802d5,0x26d0022e,0x00000000,0x00000000}},	// [8cb0] ržyb, _guyo_, --, --, 
   {{0x44207715,0x75d4007b,0x00000000,0x00000000}},	//   afi_, _جيدا, --, --, 
   {{0xc0d80020,0x34940124,0xb1141945,0x00000000}},	//   _ክብር_, _аанр, тмеш, --, 
   {{0x8ce01e4a,0x44200009,0x65540115,0x00000000}},	//   ۇقتۇ, cfi_, _סברא_, --, 
   {{0xe80801ad,0x0464022e,0x5348010a,0x00000000}},	//   _वाघा_, _стэм, _хăлă, --, 
   {{0x316c0118,0xdee80023,0x5194030d,0x00000000}},	//   _řezu_, መሪካ_, _пăла, --, 
   {{0x6aa07716,0x7e740228,0x63a00327,0xed347717}},	//   volf, دانئ, żont, тэлэ, 
   {{0xdd8c0491,0x2fcc020c,0x3cd001ec,0x00000000}},	//   توى_, _ugeg_, _ﻗﺎﺌﻤ, --, 
   {{0x27f07718,0xaed400d6,0x261075be,0x6aa0026c}},	//   _reyn_, _розш, _ताली_, tolf, 
   {{0x27f0003a,0xd7d800b5,0xbf3800d4,0x00000000}},	//   _seyn_, niユ_, _язує_, --, 
   {{0x6aa00048,0x44207719,0x26d0771a,0x1cd8025c}},	//   rolf, yfi_, _suyo_, _འཕག_, 
   {{0x26d00309,0x6aa0771b,0x27f00009,0x7aa40166}},	//   _puyo_, solf, _qeyn_, киөз, 
   {{0xc6c85313,0xfbd045cf,0x247c001f,0x6aa0010f}},	//   нқид_, _اتم_, _የፖሊስ_, polf, 
   {{0x27f00a81,0x2cac771c,0x26d0771d,0xa92402d5}},	//   _weyn_, lled_, _vuyo_, _адкл, 
   {{0xe5a4771e,0x4420771f,0x958000c7,0xa5200209}},	//   тиви, tfi_, алре, шүнҗ, 
   {{0x64bc7720,0x26d07721,0x442022a9,0x27f04831}},	//   ्देश, _tuyo_, ufi_, _ueyn_, 
   {{0x44207722,0x2cac7723,0xd58c02d3,0x3e7001ab}},	// [8cc0] rfi_, iled_, _ዘድልዮ_, _làta_, 
   {{0x2cac0316,0x216848fb,0x6d20000d,0x00000000}},	//   hled_, мизи_, _महंग_, --, 
   {{0xa3e87724,0x44200084,0xd7ec01ec,0x2cac030a}},	//   _одна_, pfi_, _اكۋ_, kled_, 
   {{0x24800263,0xf494010a,0x44201898,0x00000000}},	//   _umkm_, _йăхн, qfi_, --, 
   {{0x2cac0368,0xa348036b,0xe3b00cd2,0x2490033f}},	//   dled_, _ўзга_, _خرد_, mnym_, 
   {{0x2cac7725,0x24907726,0x3e700e89,0xfe0818fd}},	//   eled_, lnym_, _bàta_, رقعي_, 
   {{0x2cac1848,0x38b801ed,0x2490033f,0xa0a401c6}},	//   fled_, lére_, onym_, _аавд, 
   {{0x24907727,0x3e700e89,0xa034113e,0x5e400014}},	//   nnym_, _dàta_, _جىرت, انژٕ, 
   {{0x38b801ed,0xcc3000c6,0x8c400e92,0xdf54004b}},	//   nére_, شريع, рење, _ګرځښ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2cac7728,0x6b8c08a5,0x00000000,0x00000000}},	//   bled_, _þagn, --, --, 
   {{0x2cac7729,0x24900034,0xdb840124,0x38b8772a}},	//   cled_, jnym_, _игеи, kére_, 
   {{0x2490772b,0x38b800dd,0xa3d4772c,0x16700131}},	//   dnym_, jére_, िखन_, иқир, 
   {{0xd7d8037e,0x00000000,0x00000000,0x00000000}},	//   xiユ_, --, --, --, 
   {{0x1ad84251,0xd5ac00e5,0x00000000,0x00000000}},	//   _দিয়া, تہد_, --, --, 
   {{0x5884772d,0x2c7000e4,0x335400db,0x39a40117}},	//   _шыла, _káda_, гүмө_, _ишқв, 
   {{0x38b801ed,0x36d40212,0xd6d801a9,0xb3900240}},	// [8cd0] gére_, _щопр, _ўти_, _ጀራዲን_, 
   {{0xd344004b,0xf1d00154,0x2490012d,0x00000000}},	//   _ییزه_, ির্ভ, anym_, --, 
   {{0x2cac772e,0x2490772f,0x9f44030a,0x1cd80327}},	//   yled_, bnym_, maoù_, _འཕཊ_, 
   {{0x3e7000a3,0x9f440165,0x24907730,0x38b8143c}},	//   _ràta_, laoù_, cnym_, bére_, 
   {{0x27140085,0xc00401ec,0x00000000,0x00000000}},	//   _pɛnɛ_, рпік, --, --, 
   {{0x2cac1590,0x6b8c0010,0x9f440165,0x00000000}},	//   wled_, _žago, naoù_, --, 
   {{0xcfd8015b,0x61e80165,0xd0180305,0x00000000}},	//   দরবন, ñfle, _офа_, --, 
   {{0x2cac7731,0xbd68011c,0x00000000,0x00000000}},	//   uled_, ърче_, --, --, 
   {{0x2cac7732,0xe7bc045e,0xfe6c7733,0x1c407734}},	//   rled_, _আভ্য, _дү_, сным, 
   {{0x2490489d,0x2c7001ef,0x28e800db,0x00000000}},	//   znym_, _dáda_, ндоп_, --, 
   {{0xec147735,0xa968074d,0x9f4405c7,0x38b800e5}},	//   _مواد, хина_, daoù_, zére_, 
   {{0x66e47736,0x7c847737,0x00000000,0x00000000}},	//   лома, _куче, --, --, 
   {{0xc8cc0e49,0xab287738,0x24900030,0xb3d80154}},	//   _संकट, _чола_, vnym_, তরাজ, 
   {{0x38b87739,0x24900034,0x68ec033f,0x9f44030a}},	//   vére_, wnym_, _ładu, gaoù_, 
   {{0x05a405f9,0xc448006c,0x2490489d,0x2c7000bc}},	//   _खुशब, نیدن_, tnym_, _záda_, 
   {{0x38b8773a,0xf99004d3,0x6a7801e1,0xe3b000ae}},	//   tére_, _ببه_, _fùfù, مرء_, 
   {{0x2b58773b,0x4e100316,0xa0a4136b,0x2490773c}},	// [8ce0] äsch_, ठलाई_, қадд, rnym_, 
   {{0x38b8035b,0x62640a2c,0x24900034,0x00000000}},	//   rére_, دارق, snym_, --, 
   {{0x6008773d,0x38b800dd,0xa06800d8,0x24900210}},	//   енем_, sére_, нажа_, pnym_, 
   {{0x38b85ed5,0xd00c00c6,0x7d1c00a2,0x30a400d4}},	//   pére_, كلم_, _ärsi, арів, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xddd80618,0x2c70012c,0x00000000,0x00000000}},	//   _totō, _ráda_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd12c2073,0x00000000,0x00000000,0x00000000}},	//   _عمق_, --, --, --, 
   {{0x3a740058,0x60c0773e,0x0d80767b,0x9a8800a7}},	//   илир, mmom, илән, ещна_, 
   {{0x60c0773f,0x213c01ab,0x5cf40153,0xfbc00303}},	//   lmom, _áths_, _бяду, शेषम, 
   {{0x59d4033f,0x9f44030a,0x98a40427,0xddb8008e}},	//   डखबर, vaoù_, žiča_, _чуаш_, 
   {{0xed4c009f,0x00000000,0x00000000,0x00000000}},	//   _آھو_, --, --, --, 
   {{0x36d47740,0x9f44030a,0x00000000,0x00000000}},	//   рогр, taoù_, --, --, 
   {{0xa3e012eb,0x60c00e78,0xc92003d4,0x00000000}},	//   नुस_, hmom, _বছৰত_, --, 
   {{0xceb00bd9,0x60c001f5,0x9f440156,0x391400d1}},	//   מיש_, kmom, raoù_, _ئوبز, 
   {{0x9f4405c7,0x00000000,0x00000000,0x00000000}},	//   saoù_, --, --, --, 
   {{0xd138001f,0xa008015b,0x60c001e3,0xd2440276}},	// [8cf0] _የላቸው, রভাব_, dmom, лэжи, 
   {{0x65780e89,0xd63000e5,0xb0d8012d,0x00000000}},	//   ùthc, _اِدھ, _बंदग, --, 
   {{0x824402d3,0x6a6c08a5,0xc79400e5,0x0584014b}},	//   _ረቛሒታ, _búfj, _نشیب, _гуям, 
   {{0x60c07741,0xc0580d30,0x2d2000ab,0xc0c800d8}},	//   gmom, ліч_, _महौल_, гуче_, 
   {{0x14d80490,0x00000000,0x00000000,0x00000000}},	//   _मंडण, --, --, --, 
   {{0x60c000c0,0xd13800d8,0x81d4009d,0x00000000}},	//   amom, _пхб_, _горх, --, 
   {{0xed587742,0x6608000f,0xbdf81375,0x4df002dd}},	//   той_, _ôfke, ارها_, аяқт, 
   {{0xb3b80073,0x00000000,0x00000000,0x00000000}},	//   _आराख, --, --, --, 
   {{0xd7c438d2,0x0bf000cf,0x00000000,0x00000000}},	//   रेमच, _ۇياڭ, --, --, 
   {{0xa9247743,0x2bd02017,0x1ee80330,0x6b8c02d2}},	//   адол, _हलका, _شومی_, _þagm, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfbd004d3,0xfd101867,0x3e7001e1,0x00000000}},	//   _فته_, _رجم_, _yàto_, --, 
   {{0xbca4021a,0x37747744,0x00000000,0x00000000}},	//   _امني, бырс, --, --, 
   {{0x07a40124,0x00000000,0x00000000,0x00000000}},	//   иаҟн, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd9180a1e,0x26106407,0x23287745,0x33f400db}},	//   _סופל, _ताकी_, коби_, йчус, 
   {{0x93407746,0xa3e00b7d,0x7ae40724,0x2c7000e4}},	// [8d00] онте, नुष_, _çitt, _ládo_, 
   {{0x38b87747,0x00000000,0x00000000,0x00000000}},	//   méra_, --, --, --, 
   {{0x38b87748,0x00000000,0x00000000,0x00000000}},	//   léra_, --, --, --, 
   {{0x44247749,0xe61043fb,0x6024774a,0x00000000}},	//   _ùm_, _اشک_, рдда, --, 
   {{0xfd6400f7,0x38b80118,0x1ea800ec,0xcf8c0014}},	//   өндү, néra_, پاشي_, ٘ژٕ_, 
   {{0xa3e04196,0x6144774b,0xfd74009d,0xe298774c}},	//   नुर_, _кега, йллэ, _раг_, 
   {{0x2054717e,0x38b8035b,0xcd30007b,0x00000000}},	//   _ктар, héra_, قريب, --, 
   {{0x10a0236b,0xa07400ee,0x38b800c7,0x1e940022}},	//   _дисн, _тыгш, kéra_, ырҵр, 
   {{0x8af4774d,0xda64774e,0xda78011c,0xdce40205}},	//   аныс_, لادي, вян_, ımım, 
   {{0xda480116,0x38b800d7,0x00000000,0x00000000}},	//   тчил_, déra_, --, --, 
   {{0xec341e2f,0x37f80166,0xa3d42802,0x00000000}},	//   _گونگ, ленэ_, िखा_, --, 
   {{0x38b85923,0x49c40166,0x00000000,0x00000000}},	//   féra_, шуым_, --, --, 
   {{0xec34774f,0x2c7001ef,0x00000000,0x00000000}},	//   _دونگ, _mádl_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xddd8033f,0xad580408,0x5fd46611,0x00000000}},	//   _kotł, _урăх_, धशाल, --, 
   {{0x1cd80135,0x4a20025c,0x38b801e4,0x87e4004b}},	//   _འཕན_, _འཁོལ_, béra_, _وګټل, 
   {{0xb274036b,0x2bc8033f,0x00000000,0x00000000}},	// [8d10] блаш, ाइया, --, --, 
   {{0x339401b9,0x00000000,0x00000000,0x00000000}},	//   _ҳамё, --, --, --, 
   {{0x78ac0083,0xe794158b,0x02a401ec,0x00000000}},	//   _kkav, _نایک, ірум, --, 
   {{0x78ac0165,0x2c70013a,0x768800c0,0x00000000}},	//   _jkav, _rádo_, ižym, --, 
   {{0xc8d00574,0x78ac01f7,0x2cbc0142,0xe7f8530e}},	//   _संघट, _mkav, _rhwd_, ्णता_, 
   {{0x720402dd,0x2cbc0042,0xd2440de7,0x00000000}},	//   _دوسم, _shwd_, _тэми, --, 
   {{0x78ac7750,0xc5f40677,0x38b800d7,0x00000000}},	//   _okav, קדק_, zéra_, --, 
   {{0x78ac7751,0x00000000,0x00000000,0x00000000}},	//   _nkav, --, --, --, 
   {{0x69c8000d,0x38b800d7,0x918401af,0x00000000}},	//   हेनी, xéra_, _саңғ_, --, 
   {{0x78ac7752,0x6a6c00d2,0x00000000,0x00000000}},	//   _akav, _kúfi, --, --, 
   {{0xa9a46f0c,0x8d8402dd,0xe9a47753,0x78ac0208}},	//   синд, _туад, санп, _bkav, 
   {{0x3ed402dd,0x38b80306,0xcc840133,0x00000000}},	//   _اقەر, téra_, _خۆبه_, --, 
   {{0x6498013e,0xaa440e4e,0x53a421f2,0x00000000}},	//   ҳтар_, _гелл, _कुलश, --, 
   {{0x78ac7754,0x2d98013f,0x55e03860,0x38b80022}},	//   _ekav, _ɛsen_, зорб, réra_, 
   {{0x38b87755,0x78ac0418,0x6498054a,0xe4d818a2}},	//   séra_, _fkav, гтар_, اورت_, 
   {{0xe73800c7,0x98a03417,0x00000000,0x00000000}},	//   _беи_, _нище, --, --, 
   {{0xe2980323,0x64a47756,0xa204010b,0x00000000}},	// [8d20] гаа_, _ҳана, йпад, --, 
   {{0x7d1c0efa,0x9758010f,0x21a4119e,0x00000000}},	//   _årsg, _עדיט, бизм, --, 
   {{0x602448ec,0x64a47757,0xe12401f4,0x00000000}},	//   йджа, _гана, смеи, --, 
   {{0xd918008f,0x00000000,0x00000000,0x00000000}},	//   טועל, --, --, --, 
   {{0xd0047758,0xa3e000cd,0x00000000,0x00000000}},	//   сече_, नुः_, --, --, 
   {{0x21740835,0x00000000,0x00000000,0x00000000}},	//   _лубр, --, --, --, 
   {{0x61fc7759,0x38b800d5,0x69c80073,0x00000000}},	//   mapl, dérn_, हेमी, --, 
   {{0x61fc775a,0x60c004ba,0x4a200327,0xd194011a}},	//   lapl, ŋomb, _འཁུལ_, _הכלי_, 
   {{0x3b54109a,0xcb04007b,0x5f0400db,0x00000000}},	//   ікор, ميين_, _ызаа, --, 
   {{0x61fc775b,0x527800c8,0xdc280133,0xfa6801d5}},	//   napl, ָנטא, _ڕسته_, рчиқ_, 
   {{0x261043d1,0x00000000,0x00000000,0x00000000}},	//   _ताजी_, --, --, --, 
   {{0x61fc775c,0xe91800dd,0x00000000,0x00000000}},	//   hapl, گریڈ_, --, --, 
   {{0x61fc775d,0x78ac1d04,0x02d801ad,0xd49821f3}},	//   kapl, _vkav, _भूलभ, ҳра_, 
   {{0xcb0446c1,0x00000000,0x00000000,0x00000000}},	//   _ايون_, --, --, --, 
   {{0xd498775e,0x61fc775f,0x98e400cf,0x00000000}},	//   гра_, dapl, _уюлд, --, 
   {{0x38b80231,0xd7f80139,0x161400e1,0x94a801d5}},	//   méro_, _сук_, तलहर_, утга_, 
   {{0x38b80129,0x6a6c032e,0x61fc02d2,0x999c00e5}},	// [8d30] léro_, _súfi, fapl, mető_, 
   {{0x61fc7760,0x999c01d3,0xa2cc01f9,0x649800a2}},	//   gapl, lető_, _तळण्, lįil, 
   {{0x6608000f,0x00000000,0x00000000,0x00000000}},	//   _ôfka, --, --, --, 
   {{0xa3e0000d,0x00000000,0x00000000,0x00000000}},	//   नुआ_, --, --, --, 
   {{0x61fc7761,0x38b86479,0x6aac02d2,0x00000000}},	//   bapl, héro_, _íafg, --, 
   {{0x999c066d,0xace81149,0x40941456,0x00000000}},	//   hető_, амка_, يلەر, --, 
   {{0x6cc47762,0x7ae401e4,0x38b847f1,0xa280104c}},	//   ойка, _ɩite, jéro_, _تیلو, 
   {{0x506472a0,0x38b80129,0x69c807b7,0x00000000}},	//   _утга, déro_, _हृषी, --, 
   {{0xeb987763,0xdcac0131,0x00000000,0x00000000}},	//   рип_, خىي_, --, --, 
   {{0x28dc3042,0xde44004b,0x7ea40100,0xb7d400dc}},	//   _नंदि, _وینو_, kòpy, _iṣya, 
   {{0x5edc0154,0x38b80022,0x3ea012f2,0x00000000}},	//   নীদে, géro_, éite_, --, 
   {{0x61fc0a43,0xb7d40055,0x999c00e5,0x6498010e}},	//   zapl, _kṣya, gető_, gįil, 
   {{0xdd1c01a2,0x3e7001ab,0xae0c00c5,0xa038010f}},	//   _víťa, _bàth_, _सयान_, בערפ, 
   {{0x3e7000a3,0x61fc003a,0x0ac400f5,0x00000000}},	//   _càth_, xapl, _ущем, --, 
   {{0x61fc7764,0xb2f4025c,0x1540033a,0x291001d3}},	//   vapl, _བསུང_, мерм, ázad_, 
   {{0x61fc00fd,0x7d1c03cd,0xa3e87765,0x00000000}},	//   wapl, _årse, рдаа_, --, 
   {{0xe1f87766,0x6b8c09a5,0xe738424c,0x3e7000a3}},	// [8d40] ига_, _ýagd, _теп_, _fàth_, 
   {{0xf1a803e6,0xd6d40214,0x7ae47538,0x00000000}},	//   ڕانه_, _گویش_, _éite, --, 
   {{0x61fc09a5,0x6724449c,0x64c400ae,0x00000000}},	//   rapl, ltkj, _ويخل, --, 
   {{0x61fc7767,0x25e47768,0x00000000,0x00000000}},	//   sapl, जुरी_, --, --, 
   {{0xd00c177a,0x1ec805c2,0xf3900882,0x61fc00b8}},	//   ئله_, алди_, kṣya_, papl, 
   {{0x999c00dd,0x6a6c00d2,0x61fc7769,0x9ce414b3}},	//   zető_, _kúfu, qapl, оцил, 
   {{0xc0d8044e,0xb7d4002b,0x8f9400d1,0x00000000}},	//   _ክብሉ_, _eṣya, йъәт_, --, 
   {{0x9cc8776a,0x6724143a,0x8c400063,0x38b800e4}},	//   шыла_, ktkj, деће, véro_, 
   {{0x6a6c00d2,0xc7b40134,0x999c01ed,0x3e700248}},	//   _lúfu, _nyɑ_, vető_, _làti_, 
   {{0x38b8776b,0xea980055,0x00000000,0x00000000}},	//   téro_, _īṃ_, --, --, 
   {{0x3e7001ab,0x999c01d3,0xe8ec00ec,0x6e4000d1}},	//   _ràth_, tető_, هڻي_, _سۆيم, 
   {{0x7e680455,0x672433b8,0x3fac1884,0x38b80022}},	//   _hodp, ftkj, ﺴﺘﺎﻧ, réro_, 
   {{0xd90c776c,0x7e680115,0x68ec01a6,0x999c01d3}},	//   ریک_, _kodp, _čade, rető_, 
   {{0x25e4012c,0x6a6c03b2,0xca30009b,0x00000000}},	//   जुली_, _búfu, _жешћ, --, 
   {{0x7e68776d,0x2c700332,0x45d4776e,0x00000000}},	//   _modp, _bádh_, дорс, --, 
   {{0xc0d802d3,0x7e68016d,0x6608002d,0x7664004b}},	//   _ክብሎ_, _lodp, _ôfkn, _کیسې_, 
   {{0xb27422ff,0x3e7001ab,0x9f440165,0x7e68035a}},	// [8d50] плаш, _tàth_, kaoñ_, _oodp, 
   {{0x7e6804fb,0x38680489,0x656c01ed,0xe0e40154}},	//   _nodp, _hoar_, ínhá, _পয়েন, 
   {{0xc0d802d3,0x3868776f,0x2fd80597,0x00000000}},	//   _ክብል_, _koar_, مواد_, --, 
   {{0x38687770,0xf4847771,0x6538010f,0x00000000}},	//   _joar_, _راجی, _פערד, --, 
   {{0x76447772,0x38687773,0x7e6803cd,0x5ee40eac}},	//   _kahy, _moar_, _bodp, _নিউই, 
   {{0xad2404a9,0x38680489,0x7e680139,0x76447774}},	//   كىتى, _loar_, _codp, _jahy, 
   {{0xc69404ac,0x764400dc,0x320013d5,0x62980100}},	//   ואס_, _mahy, mahy_, _ňtog, 
   {{0x32001311,0x00cc005e,0xab6428a8,0x7644058a}},	//   lahy_, _ﺑﺎﺳﺘ, звил, _lahy, 
   {{0xa3cc0562,0x3ae01497,0x80d40406,0x7e68005c}},	//   षेप_, _còp_, _बूटे, _fodp, 
   {{0x32001311,0xeb9801b9,0x7e680171,0x76447775}},	//   nahy_, _қил_, _godp, _nahy, 
   {{0x3868232c,0x64400022,0x00000000,0x00000000}},	//   _boar_, ôoik, --, --, 
   {{0x7644013f,0x7e68278a,0x386800ad,0x672408fb}},	//   _aahy, _zodp, _coar_, ttkj, 
   {{0x38680262,0x76447776,0x2cac7777,0x32000109}},	//   _doar_, _bahy, moed_, kahy_, 
   {{0x76441eb2,0x2cac4e06,0x67247778,0x2f3c007f}},	//   _cahy, loed_, rtkj, _mňg_, 
   {{0x3868193f,0x32000170,0x67247779,0x7644777a}},	//   _foar_, dahy_, stkj, _dahy, 
   {{0x6d400a2e,0x3868777b,0x2904777c,0x76440857}},	//   _msla, _goar_, msla_, _eahy, 
   {{0xd4640a70,0x6d40777d,0x320005da,0x6608045f}},	// [8d60] чите_, _lsla, fahy_, _ôfko, 
   {{0x32000170,0x2c7001e1,0x2cac777e,0x764455e3}},	//   gahy_, _dádi_, hoed_, _gahy, 
   {{0x2904777f,0xf6e8031c,0xcd040153,0x00000000}},	//   nsla_, _འཕོང, žėjų_, --, 
   {{0x64a47780,0x76447781,0x613001a8,0x6ce402dd}},	//   _хама, _zahy, _aðlö, _ﺍﺨﺘﻴ, 
   {{0x64440270,0x26c80109,0x249000b5,0x2cac0142}},	//   _iaki, ombo_, miym_, doed_, 
   {{0x29047782,0x3ae001c3,0x7d18022e,0x00000000}},	//   ksla_, _ròp_, tuvs, --, 
   {{0x628c7783,0x3ae004cc,0x22840724,0x2cac005c}},	//   _imbo, _sòp_, _дуңг, foed_, 
   {{0x64447784,0x2cac2e6c,0x29043953,0x3ae002e2}},	//   _jaki, goed_, dsla_, _pòp_, 
   {{0x38687785,0x64447786,0x6d407787,0x8b200640}},	//   _roar_, _maki, _esla, едње, 
   {{0x64447788,0x38687789,0xd00c1c3b,0x24901ba4}},	//   _laki, _soar_, _للہ_, hiym_, 
   {{0x628c0161,0x68ec0030,0x2904778a,0x38680076}},	//   _mmbo, _čadc, gsla_, _poar_, 
   {{0x6444778b,0x764409a5,0x63a00034,0x26c800e4}},	//   _naki, _sahy, żony, embo_, 
   {{0x628c07dd,0x3868778c,0xe4640882,0x7c240986}},	//   _ombo, _voar_, ṃśat, _ñirq, 
   {{0x6444778d,0x38680a40,0x6d400209,0x2c70012c}},	//   _aaki, _woar_, _ysla, _rádi_, 
   {{0x3200778e,0x3868062c,0x764403e0,0x2c70032e}},	//   vahy_, _toar_, _vahy, _sádi_, 
   {{0x628c0875,0x6444778f,0x38c804d3,0x26c804ba}},	//   _ambo, _caki, _باتی_, ambo_, 
   {{0x32007790,0x76447791,0x00000000,0x00000000}},	// [8d70] tahy_, _tahy, --, --, 
   {{0x823415f8,0x64440857,0x16940014,0xdbf00118}},	//   فرما, _eaki, _ژٕکھ_, dříz, 
   {{0x64447792,0x32000588,0x00000000,0x00000000}},	//   _faki, rahy_, --, --, 
   {{0x64447793,0x32007794,0x6fb87795,0x25bc0205}},	//   _gaki, sahy_, огер_, ütle_, 
   {{0x2cac1af3,0x7fd4753d,0xa3e000c5,0x00000000}},	//   voed_, ніші, नुओ_, --, 
   {{0x6d400421,0xed587796,0xb1500882,0x29047797}},	//   _psla, жок_, ṣṭaḥ_, ysla_, 
   {{0x7124167e,0x7d0802d0,0x2cac0037,0x33280327}},	//   _تىزم, _cvds, toed_, ltax_, 
   {{0x14bc11bc,0x5064006c,0x64440598,0x7d0818bb}},	//   ्षिण, _этга, _xaki, _dvds, 
   {{0x1c407798,0x2cac2f50,0x4ea402dd,0x628c7799}},	//   тным, roed_, _ержа, _ymbo, 
   {{0x2904779a,0xbdf86f04,0x316c0118,0x6d4001e7}},	//   tsla_, _فرما_, _řezy_, _tsla, 
   {{0x78080574,0x2cac779b,0x6d4005d1,0x2904202c}},	//   वणूक_, poed_, _usla, usla_, 
   {{0xd1f0069c,0x2904779c,0x7d1c708a,0x6f080010}},	//   _ውድብ_, rsla_, _årsa, _kvec, 
   {{0x6444779d,0xb904779e,0x2904779f,0x00000000}},	//   _raki, _भू_, ssla_, --, 
   {{0x644477a0,0x2eec5e6f,0x332805b1,0x2b4c0010}},	//   _saki, _mtef_, dtax_, mvec_, 
   {{0x644477a1,0x7534009d,0x00000000,0x00000000}},	//   _paki, нэтх, --, --, 
   {{0x6f080124,0x64440286,0xd7ac01f2,0x33280139}},	//   _ovec, _qaki, ụpụr, ftax_, 
   {{0x644477a2,0x2490009f,0x628c0022,0x2b4c0165}},	// [8d80] _vaki, riym_, _pmbo, nvec_, 
   {{0xa3e007f7,0x03680014,0xfe1c0210,0x00000000}},	//   नुज_, _ۂجی_, _नाइस_, --, 
   {{0x6f0877a3,0x3e7000e8,0xe5a477a4,0x05947138}},	//   _avec, _màtt_, _цини, _سادگ, 
   {{0x6444394e,0x64980064,0xd00c009a,0x00000000}},	//   _uaki, _фтор_, للم_, --, 
   {{0x6f0877a5,0x98a405ce,0x442077a6,0x1ea877a7}},	//   _cvec, žića_, mgi_, ياتي_, 
   {{0xa3cc00dc,0x21a477a8,0x00000000,0x00000000}},	//   षेण_, _жигм, --, --, 
   {{0x44200368,0x5cc42ac8,0x6f0877a9,0xf3900055}},	//   ogi_, мсиз, _evec, _iṣam_, 
   {{0x5478008f,0xfb8801b9,0xdbf00118,0x00000000}},	//   ַטיו, зроқ_, příz, --, 
   {{0x8244001f,0xf3900055,0xbf100139,0x629c01f4}},	//   _የማስታ, _kṣam_, _сүлә, onpo, 
   {{0x44200007,0x629c1600,0x38b877aa,0xd8e40220}},	//   hgi_, nnpo, méri_, _ﺍﻟﻭﻟ, 
   {{0x6f0805b8,0x3e7000e8,0xa3cc08e6,0x38b8003e}},	//   _zvec, _dàtt_, षेत_, léri_, 
   {{0x629c002f,0x00000000,0x00000000,0x00000000}},	//   hnpo, --, --, --, 
   {{0x442077ab,0xbb58009d,0x9a8400d8,0xc6f80108}},	//   dgi_, _халх_, _оукл, мнях_, 
   {{0x442077ac,0xddd8038e,0x3e701bce,0x629c77ad}},	//   egi_, _potř, _gàtt_, jnpo, 
   {{0x442077ae,0x08f4299c,0x38b800e4,0x94741bf4}},	//   fgi_, _قريب_, héri_, ودرا, 
   {{0x442077af,0x332877b0,0x00000000,0x00000000}},	//   ggi_, ttax_, --, --, 
   {{0x439477b1,0xdecc02d3,0x3e7000e8,0x32544a0b}},	// [8d90] ватс, ቦምን_, _yàtt_, нвар, 
   {{0x442077b2,0x629c072b,0x81c80eac,0xa3cc5b99}},	//   agi_, gnpo, উশন_, षेध_, 
   {{0x301407dd,0x3328003d,0x2eec77b3,0x44200522}},	//   едер, stax_, _stef_, bgi_, 
   {{0x442002fa,0x629c77b4,0x38b800d7,0x00000000}},	//   cgi_, anpo, féri_, --, 
   {{0xb4bc068f,0xa3b41b37,0x25e4033f,0x38b801d3}},	//   ेगी_, _चुप_, जुकी_, géri_, 
   {{0xb640037e,0x6f8801d9,0x00000000,0x00000000}},	//   _ｃｐ_, _ہنزِ_, --, --, 
   {{0xf1c80046,0xb37800b5,0x8d740092,0xe9d800d1}},	//   _ءوزى_, dでip, _ጠይቋል_, үки_, 
   {{0x7c9402d5,0x6f08007c,0x38b800d7,0xac0800c7}},	//   крыц, _tvec, béri_, чниа_, 
   {{0x6f081050,0x7d1c05ac,0x00940276,0x684c0b82}},	//   _uvec, _årsn, _ритэ, _ሕማማት, 
   {{0x442077b5,0xdb0c0597,0x7d2877b6,0x2b4c02d3}},	//   zgi_, ádál, örsö, rvec_, 
   {{0xa3b42871,0x442077b7,0x252000b7,0x00000000}},	//   _चुन_, ygi_, ስቲትዩ, --, 
   {{0x2c7002fb,0x3078010f,0x629c0427,0xc1dc1cd2}},	//   _pádu_, פאָנ, znpo, _बल्ग, 
   {{0x442077b8,0x4e000cbf,0x629c77b9,0x00000000}},	//   vgi_, _रजाई_, ynpo, --, 
   {{0x4420058a,0xe9d80139,0xa9a41887,0x0eac012d}},	//   wgi_, _экк_, _пилд, टविड, 
   {{0x442077ba,0x2484025c,0x95d40108,0x5fbc00d1}},	//   tgi_, _ċomb_, едёт_, ﺭﻩﭘﺘ, 
   {{0x442077bb,0x77903028,0x629c0072,0xe5a400d1}},	//   ugi_, اییا, wnpo, _җими, 
   {{0x221477bc,0x00000000,0x00000000,0x00000000}},	// [8da0] ефер, --, --, --, 
   {{0x442077bd,0x32dc0cad,0x00000000,0x00000000}},	//   sgi_, _ọdún_, --, --, 
   {{0x629c77be,0x442077bf,0x76880024,0x38b8002e}},	//   rnpo, pgi_, ržyt, wéri_, 
   {{0x38b877c0,0x15400107,0xd7c401f9,0x00000000}},	//   téri_, _сеюм, रेकच, --, 
   {{0x26d801c8,0x1ee400f1,0x00000000,0x00000000}},	//   _kipo_, روغی_, --, --, 
   {{0x26d8047e,0x3d940117,0x38b800d7,0x00000000}},	//   _jipo_, килр, réri_, --, 
   {{0x32cc0064,0x63b00118,0x38b85923,0x00000000}},	//   _ežys_, řeně, séri_, --, 
   {{0xdfd021e7,0xec100116,0x00000000,0x00000000}},	//   _ميز_, لۈمد, --, --, 
   {{0x8fa00697,0x4fa077c1,0x20040607,0x26d800c7}},	//   _бате, _битв, maoi_, _oipo_, 
   {{0xd90c77c2,0xa9b00084,0x26d877c3,0xdb0400d2}},	//   میت_, _ṱuṱu, _nipo_, _émín, 
   {{0x6b8c0209,0x497001c0,0x19f40014,0x24e40150}},	//   _ýagn, глэс, وِکھ_, _ﻋﺎﻻﻣ, 
   {{0x26d80124,0xa3b400c5,0x20043e79,0x00000000}},	//   _aipo_, _चुभ_, naoi_, --, 
   {{0x26d877c4,0xda78011c,0x00000000,0x00000000}},	//   _bipo_, _няк_, --, --, 
   {{0x20040332,0x00000000,0x00000000,0x00000000}},	//   haoi_, --, --, --, 
   {{0x26d877c5,0xd85000f7,0xddd80064,0x00000000}},	//   _dipo_, _бейө, _imtų, --, 
   {{0x79880369,0xb4bc0950,0x3d08012d,0x00000000}},	//   mzdw, ेगे_, _सबने_, --, 
   {{0x481477c6,0x20040109,0x55c001ec,0x2c70013a}},	// [8db0] _смыс, daoi_, таңғ, _kádr_, 
   {{0x78bc1876,0x00000000,0x00000000,0x00000000}},	//   llsv, --, --, --, 
   {{0x82a477c7,0x315802e9,0x02a4010b,0x00000000}},	//   уште, بلاج_, уртм, --, 
   {{0x26d877c8,0x20041140,0x2248005a,0xc07802bf}},	//   _zipo_, gaoi_, _eabk_, нсії_, 
   {{0x26d80241,0x3ef80139,0x00000000,0x00000000}},	//   _yipo_, енчэ_, --, --, 
   {{0x85b80150,0x26d8004d,0x38b800d7,0x947400e5}},	//   _تاۋس_, _xipo_, méru_, _آدھا, 
   {{0x200c022c,0xd1b833d2,0x0dc877c9,0x68ec00c0}},	//   økið_, _راسا_, чуди_, _čado, 
   {{0xdd8c004b,0x00000000,0x00000000,0x00000000}},	//   غوي_, --, --, --, 
   {{0x25f477ca,0x00000000,0x00000000,0x00000000}},	//   ्रमी_, --, --, --, 
   {{0x78bc017a,0x6f18015d,0xdd7001d3,0x28e8004e}},	//   elsv, mrwc, _چھٹک, мдоп_, 
   {{0xa9a477cb,0x26d877cc,0xe9a477cd,0x78bc02d2}},	//   тинд, _ripo_, танп, flsv, 
   {{0x9b9037f4,0x24a402d3,0x38b802f0,0x00000000}},	//   الیت, _ፈጻሚት_, kéru_, --, 
   {{0x6ec40918,0xaa4401a9,0x00000000,0x00000000}},	//   ितपु, _аелл, --, --, 
   {{0x7bdc0882,0x70ac0d0a,0x6b8801c7,0x78bc02d0}},	//   śrut, टकुल, mzeg, alsv, 
   {{0x26d877ce,0xa50877cf,0x6b8877d0,0x6f180142}},	//   _vipo_, ьева_, lzeg, hrwc, 
   {{0x22480ac5,0x26d80f85,0x00000000,0x00000000}},	//   _sabk_, _wipo_, --, --, 
   {{0xe1f01b56,0x6b8877d1,0xe5bc1df2,0x00000000}},	// [8dc0] لسا_, nzeg, ﻠﯩﻜﻜ, --, 
   {{0x6f180368,0x6b8877d2,0x52a4013e,0x4eb00154}},	//   drwc, izeg, ввум_, টগুল, 
   {{0x64a4035b,0xb7d40ca8,0x2d500135,0x00000000}},	//   _аана, _iṣaa, _nġe_, --, 
   {{0x6b8801c7,0x00000000,0x00000000,0x00000000}},	//   kzeg, --, --, --, 
   {{0x20040597,0xd00477d3,0xa3cc0b40,0x38b801d3}},	//   raoi_, тече_, षेश_, mért_, 
   {{0x7d18009b,0x717003cc,0x38b800e5,0x00000000}},	//   trvs, _گۇما, lért_, --, 
   {{0x60240801,0x29100122,0x71c4013e,0x5698008f}},	//   _идва, ázal_, _барҷ, ויסצ, 
   {{0x7d1c77d4,0x69b4033f,0x6b8801c7,0x717000cf}},	//   _årsm, _उड़ी, fzeg, _دۇما, 
   {{0xdee452f7,0xcb0400c6,0x6b8c010b,0x21c801ec}},	//   _рози, نيين_, _ýagl, _ﺒﻭﺠﻭ, 
   {{0xd12c2832,0x61ec77d5,0x9dd000b8,0x00000000}},	//   _دمہ_, _jfbl, _aṇūn, --, 
   {{0x38b877d6,0xc04c0092,0x0ab400ae,0x9c4401a9}},	//   kért_, _በምትገ, خطيب_, _ахлл, 
   {{0xb7d40241,0x00000000,0x00000000,0x00000000}},	//   _aṣaa, --, --, --, 
   {{0x6b88006d,0x61ec0036,0x78bc0158,0x38b800e5}},	//   czeg, _ofbl, rlsv, dért_, 
   {{0xc6a43f07,0x999c02b5,0x38b80030,0x9f44030a}},	//   арси, netū_, véru_, uboù_, 
   {{0x3ce800ab,0x9f440489,0x66180162,0x32100210}},	//   _चूमे_, rboù_, ótka, _rdzy_, 
   {{0x61ec2d02,0x38b801d3,0x6f180142,0x94a801a9}},	//   _afbl, gért_, yrwc, фтга_, 
   {{0x999c0374,0xafe401b9,0xa3b477d7,0x00000000}},	// [8dd0] ketū_, қолл, _चुद_, --, 
   {{0x550477d8,0x25f41b76,0x00000000,0x00000000}},	//   _ичма, ्रणी_, --, --, 
   {{0x6b8877d9,0xc10445d7,0xbff00521,0xa5c000ee}},	//   zzeg, لولي, _ịhọr, _гөте, 
   {{0x7d1c02f6,0x1da4012c,0x6f180042,0x00000000}},	//   _ärsy, गपनत, trwc, --, 
   {{0x7d1c5243,0xd1d80023,0x23880419,0x00000000}},	//   _årsj, ንዚቡ_, ďujú_, --, 
   {{0x6da404a9,0x6b5800d2,0xada477da,0x877c010f}},	//   лила, _lúgô, лалл, ואדי, 
   {{0x6cd800f3,0x10040395,0x00000000,0x00000000}},	//   нфис_, _аязм, --, --, 
   {{0x6b8877db,0xb3941772,0xcc840133,0xa9a401d5}},	//   tzeg, _ፍርድን_, کۆڵه_, ғимд, 
   {{0x8e2407dd,0x6b880165,0x00000000,0x00000000}},	//   _афед, uzeg, --, --, 
   {{0x6b8877dc,0x6b8c010b,0x38b800e5,0x00000000}},	//   rzeg, _ýagm, zért_, --, 
   {{0x6b8877dd,0x692477de,0x00000000,0x00000000}},	//   szeg, ымна, --, --, 
   {{0xd1f0001f,0x6b8801f5,0xb4ac1a04,0xf648011a}},	//   _ውድቅ_, pzeg, गवो_, _מצ_, 
   {{0x9cd40302,0x9660052f,0x8b6400cf,0x7b6401d9}},	//   _עונה_, әксе, _جاام, _ناوٕ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc22404fb,0x38b801d3,0xf664013d,0x00000000}},	//   یکسو, tért_, шерү, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x38b801d3,0xe2c801f4,0x00000000,0x00000000}},	// [8de0] rért_, елад_, --, --, 
   {{0xdee41ee3,0x38b801ed,0x09d40154,0x657800a3}},	//   ҳоди, sért_, _দ্যা, ùths, 
   {{0xed4400b2,0x53a0136b,0xda78008f,0x414420b0}},	//   _بھ_, _ғарб, ענער, рдең, 
   {{0xdee405c5,0x44240450,0xd464013d,0x9f8436e1}},	//   годи, _øm_, _биюе_, лгед, 
   {{0xfe4400f7,0x8fa001ec,0x00000000,0x00000000}},	//   имдү, баце, --, --, 
   {{0x91e077df,0x7d1c0efa,0x00000000,0x00000000}},	//   _горе, _årsk, --, --, 
   {{0x6608000f,0x999c00b0,0x23740eff,0x6b8c00a2}},	//   _ôfku, retū_, _شاڭح, _ýagj, 
   {{0xdb6821fa,0x1158008f,0x20c821e7,0x2224004b}},	//   ерол_, _אדלע, _سبزي_, _جګړي_, 
   {{0x5438008f,0x8c400f5c,0xcb04009d,0x00000000}},	//   געפא, сење, лхэд_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x09d41d4c,0xec3400db,0x00000000,0x00000000}},	//   _দ্বা, _چومگ, --, --, 
   {{0x49c401e0,0x661803b2,0x00000000,0x00000000}},	//   ыуым_, ótkn, --, --, 
   {{0x47842519,0x00000000,0x00000000,0x00000000}},	//   бырб, --, --, --, 
   {{0x999c00e4,0x3ea000ae,0x00000000,0x00000000}},	//   hetũ_, éith_, --, --, 
   {{0x6e340209,0x79a401e0,0x667057fb,0x00000000}},	//   _özbe, _әрҙе, تگير, --, 
   {{0xf3f4030f,0x00000000,0x00000000,0x00000000}},	//   شترک, --, --, --, 
   {{0x73c40b8d,0x73d80116,0x00000000,0x00000000}},	// [8df0] рәне, тдар_, --, --, 
   {{0x36c40166,0x00000000,0x00000000,0x00000000}},	//   _әбүг, --, --, --, 
   {{0x50a00131,0x7d1c03cd,0xddd806be,0xd1c40023}},	//   مەسل, _årsh, _rotş, ኽፋት_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x562400cc,0x7ae40332,0xc4580117,0x00000000}},	//   য়ীক_, _éith, _сиях_, --, 
   {{0xad242928,0xf8d001ad,0x291001d3,0x00000000}},	//   لىتى, सगुप, ázak_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfd4c0016,0x6a8477e0,0xbc480063,0xfe6c01af}},	//   _khiể, илиа, учје_, _еү_, 
   {{0x7f8400c6,0xea580798,0xacf800f3,0x00000000}},	//   _الكن, триј_, _анжу_, --, 
   {{0xbe641e5a,0x06c400cc,0xec146d29,0x00000000}},	//   _دهلي, _এংলি, _نواد, --, 
   {{0x9c8002fb,0x00000000,0x00000000,0x00000000}},	//   účto, --, --, --, 
   {{0x66e45bc5,0x661877e1,0xaa480408,0x08e00150}},	//   рога, ótko, _апла_, _ﺍﻟﻌﺯ, 
   {{0xfd4c0208,0x00000000,0x00000000,0x00000000}},	//   _nhiể, --, --, --, 
   {{0xc44801d5,0x1a98010f,0x25bc06ea,0x00000000}},	//   هیدن_, _ביסע, ætl_, --, 
   {{0x3d084425,0x25f45b99,0x7ae40055,0x00000000}},	//   _सबसे_, ्रही_, _ũiti, --, 
   {{0xa2040298,0x782442c6,0x3d0c01e1,0x58b8011a}},	// [8e00] ипад, _اعىل, _kówá_, _במקצ, 
   {{0x5ea8015b,0xfd4c004d,0xe5780117,0x00000000}},	//   _চীনে, _chiể, _азо_, --, 
   {{0xba0877e2,0x60080212,0x602401a9,0x00000000}},	//   _ጊዜ_, внем_, иджа, --, 
   {{0x3d0c0241,0xd12c00ec,0x24b40244,0x00000000}},	//   _lówá_, ظمن_, _ئۆرگ_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x217477e3,0x975402e4,0x00e40330,0x00000000}},	//   _кубр, יינו_, _هتری, --, 
   {{0x27f00368,0x3f8077e4,0x7c2400e2,0x61fc007c}},	//   _ofyn_, šiu_, _ķirb, mbpl, 
   {{0xa0a4013e,0xb0b8009d,0x3ea000e5,0x00000000}},	//   _табд, _буух_, őit_, --, 
   {{0x60c0136f,0x0dc4329e,0xbab877e5,0x00000000}},	//   mlom, лләй_, лгих_, --, 
   {{0x60c077e6,0xd334011a,0xdb2002d2,0x00000000}},	//   llom, סריה_, _þríd, --, 
   {{0x60c005da,0xca700116,0x1c440108,0x00000000}},	//   olom, تايغ, _внем, --, 
   {{0x5fa80490,0x60c077e7,0x3138001f,0x00000000}},	//   _कशाल, nlom, _አጋጣሚ, --, 
   {{0x07a40953,0x9a84030d,0x07080395,0x00000000}},	//   жаўн, _вуйл, ихри_, --, 
   {{0x60c077e8,0xda6431ed,0x00000000,0x00000000}},	//   hlom, _خاصي, --, --, 
   {{0x60c077e9,0x27f00042,0xe72c03e6,0x5f0400cd}},	//   klom, _ffyn_, وڵی_, सीत्_, 
   {{0x56240729,0x999c0118,0x0d14010f,0x04642f5c}},	//   য়েক_, letů_, יקלט_, отум, 
   {{0x60c077ea,0xc61c0f22,0x08981867,0x3ce800ab}},	// [8e10] dlom, দ্ধা_, _خضوع_, _चूसे_, 
   {{0x2ca805a1,0x60c000d7,0x00000000,0x00000000}},	//   čadi_, elom, --, --, 
   {{0x75d477eb,0x60c002a8,0x46c0012c,0xd5b80120}},	//   _ديدا, flom, _शीटह, _јсп_, 
   {{0x60c077ec,0xa3e000cd,0x409400d4,0x00180006}},	//   glom, दशः_, оріт, аўшы_, 
   {{0xfd4c001e,0x61fc01e3,0x7ff4029c,0x999c01ef}},	//   _thiể, bbpl, آسما, ketů_, 
   {{0x10f401d5,0x60c00254,0x3ce8012d,0x00000000}},	//   _نثرد, alom, _चूहे_, --, 
   {{0x0638010f,0x3d0c01e1,0xaa84010e,0x2d8000d0}},	//   ינגט_, _rówá_, heýç, áhe_, 
   {{0x60c077ed,0xeb2801c0,0xd0840139,0xec480108}},	//   clom, гжил_, _тыги, узил_, 
   {{0x2d801ebd,0x00000000,0x00000000,0x00000000}},	//   šhe_, --, --, --, 
   {{0xa9244942,0xdb0401d3,0x9ad8002b,0x30d400d1}},	//   бдол, émáj, _prāṅ, _ﭘﯩﻼﻧ, 
   {{0x291002fb,0x9f44002e,0xae5401ec,0x7dec010f}},	//   éza_, bboó_, _وﻗﻴﻌ, _סקאַ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x0cd00118,0x00000000,0x00000000,0x00000000}},	//   दगीम, --, --, --, 
   {{0xfd4c00cd,0x00000000,0x00000000,0x00000000}},	//   _ahiṃ, --, --, --, 
   {{0xe8f42010,0x66e41b74,0xfd4c0055,0x00000000}},	//   _استخ, роҳа, _bhiṃ, --, 
   {{0xfa2403bd,0xa804036b,0x2484002e,0x00000000}},	//   _འཐོན_, _узил, óom_, --, 
   {{0x7d1c08fb,0xfd4c0055,0x60c00427,0xe2840022}},	// [8e20] _årsv, _dhiṃ, vlom, блаи, 
   {{0x216877ee,0x3d0800af,0x00000000,0x00000000}},	//   лизи_, _सबले_, --, --, 
   {{0x60c077ef,0x672401a4,0xd6d80375,0xd674011a}},	//   tlom, lukj, _תחיל, _התיק_, 
   {{0x660c77f0,0x1f6428e5,0x60c00b23,0x602401d5}},	//   labk, йкем, ulom, сдда, 
   {{0x60c077f1,0xd6d40214,0x6d4477f2,0x54340244}},	//   rlom, _خویش_, çhan, _ارپر, 
   {{0x60c077f3,0xe29877f4,0x660c44db,0x00000000}},	//   slom, _саг_, nabk, --, 
   {{0x7c880131,0xb90800b8,0x00000000,0x00000000}},	//   ишиң_, bhiṃ_, --, --, 
   {{0x629c77f5,0x660c0014,0xbca400ae,0x00000000}},	//   lipo, habk, تمعي, --, 
   {{0xda640e5a,0x9f84023a,0x5f9400c6,0x660c77f6}},	//   مادي, _угад, _الذئ, kabk, 
   {{0xda4877f7,0x660c77f8,0x67240023,0x00000000}},	//   учил_, jabk, dukj, --, 
   {{0x6e3477f9,0x660c0014,0xed3400c0,0x00000000}},	//   _özba, dabk, _мэцэ, --, 
   {{0x629c42c8,0xede00150,0x00000000,0x00000000}},	//   hipo, _تۋىپ, --, --, 
   {{0x629c77fa,0x00000000,0x00000000,0x00000000}},	//   kipo, --, --, --, 
   {{0x629c77fb,0x8bd402e4,0xcf900375,0x660c44db}},	//   jipo, _הודו_, לטר_, gabk, 
   {{0x629c77fc,0x94a801c0,0x3cfc0073,0x00000000}},	//   dipo, гтаа_, ळीचे_, --, 
   {{0x629c4f82,0x7d1c007c,0xda44009d,0x00000000}},	//   eipo, _årsu, _түүж_, --, 
   {{0x660c77fd,0x78ac77fe,0xb27477ff,0x17d400cc}},	// [8e30] babk, _ijav, олаш, _থ্ৰি, 
   {{0x660c0a81,0x629c7800,0x92680124,0x00000000}},	//   cabk, gipo, ырба_, --, 
   {{0xe7940cbb,0xffb4009d,0x00000000,0x00000000}},	//   _هایک, үйхэ, --, --, 
   {{0xf8c81428,0x629c7801,0x65785b00,0x72440050}},	//   रतिय, aipo, äthe, _ژھال, 
   {{0x629c7802,0x1ee801ed,0xc8dc010f,0x00000000}},	//   bipo, لونی_, אקאט, --, 
   {{0x629c7803,0x395c04cc,0x957c0b82,0x479c010f}},	//   cipo, _orvs_, _ዓመትን_, ניגס, 
   {{0x78ac08f9,0x00000000,0x00000000,0x00000000}},	//   _ojav, --, --, --, 
   {{0xec787804,0x660c05b1,0x25bc00c5,0xfa24031c}},	//   рпи_, zabk, ütli_, _འཐུན_, 
   {{0x395c7805,0x15f86956,0xae4400f2,0x00000000}},	//   _arvs_, ्रार_, _وپرو, --, 
   {{0x78ac7806,0x2fcc0036,0x9f440ad9,0x1e380014}},	//   _ajav, _izeg_, mboð_, _نغمک_, 
   {{0x9f441f60,0xdc5400e5,0x00000000,0x00000000}},	//   lboð_, _ڈرنک, --, --, 
   {{0x660c7807,0x6d407808,0x78ac04cc,0xfd1000c6}},	//   wabk, _ipla, _cjav, _أجل_, 
   {{0x61c42ce6,0x78ac2625,0xcbc4113e,0xe7380640}},	//   _वर्ष, _djav, _ازاي, јег_, 
   {{0x78ac014b,0xac7403e6,0xaa5801c8,0x00000000}},	//   _ejav, _داڕش, _ضلعا_, --, 
   {{0xa5083117,0x7d1c0623,0x660c7809,0x629c780a}},	//   реба_, _årst, rabk, vipo, 
   {{0x6d40780b,0x660c780c,0x9f440162,0x00000000}},	//   _mpla, sabk, kboð_, --, 
   {{0x23281ee3,0xf8a800f1,0x00000000,0x00000000}},	// [8e40] рози_, _ددوه_, --, --, 
   {{0x21a40311,0x78ac0030,0x660c0009,0x6b8c010e}},	//   оизм, _zjav, qabk, _ýagu, 
   {{0x6d400070,0x6d44780d,0xdfe819ba,0x91bc0051}},	//   _npla, çhal, адед_, _đụ_, 
   {{0x10a000a7,0xe4580150,0x9f4402d2,0x71700137}},	//   михн, _тжм_, fboð_, رۇقا, 
   {{0x629c780e,0xdbc4000d,0x00000000,0x00000000}},	//   pipo, lööm, --, --, 
   {{0x629c02d3,0x6d4000ae,0xc61c0154,0xea2401e1}},	//   qipo, _bpla, দ্রা_, _ẹ́gẹ, 
   {{0x6d4007ab,0xc1b8010a,0x00000000,0x00000000}},	//   _cpla, çлăх_, --, --, 
   {{0x8e800588,0x6d400036,0x6454780f,0xe2980818}},	//   згәе, _dpla, ndyi, _саҳ_, 
   {{0x6d407810,0x78ac151c,0x64540810,0xf8b801e0}},	//   _epla, _rjav, idyi, ҙөк_, 
   {{0xd90c7811,0x53981203,0x6d407812,0x6454005b}},	//   نیت_, ייפו, _fpla, hdyi, 
   {{0x6d400998,0xedf411e6,0x76900241,0x15f80d0d}},	//   _gpla, _رينگ, _lóyù, ्रसर_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe3140489,0x645418b0,0x7aa40137,0x50d80a7c}},	//   ྲེསཔ_, ddyi, _ىشتۅ, יקטא, 
   {{0x7d1c7813,0x6d4002d0,0x00000000,0x00000000}},	//   _årss, _ypla, --, --, 
   {{0xd4987814,0x29107815,0x78ac0427,0x00000000}},	//   ара_, ázat_, _tjav, --, 
   {{0xd7f80c04,0x78ac0fec,0x81c0015b,0x00000000}},	//   _тук_, _ujav, ঁধা_, --, 
   {{0x6b8c00ee,0x4de8000d,0x00000000,0x00000000}},	// [8e50] _ýagt, _चललै_, --, --, 
   {{0x78bc7816,0x417403e6,0x64540076,0x00000000}},	//   losv, ژانس, adyi, --, 
   {{0xdb20032e,0x00000000,0x00000000,0x00000000}},	//   _þræd, --, --, --, 
   {{0x92a803f4,0x78bc7817,0x6d4402d1,0xa3b40073}},	//   খতে_, nosv, çham, _चुक_, 
   {{0x161c0dad,0x6d407818,0x00000000,0x00000000}},	//   _बयार_, _spla, --, --, 
   {{0x78bc7819,0x9f44041e,0x6d40615e,0xd25800ee}},	//   hosv, rboð_, _ppla, _тцм_, 
   {{0x66180034,0x3ea0067c,0x70580b00,0xbd8801c8}},	//   ótki, èita_, _лавр_, ينهن_, 
   {{0x6d4009a8,0x00000000,0x00000000,0x00000000}},	//   _vpla, --, --, --, 
   {{0xeb984a4d,0x78bc01b8,0x6e3400ee,0x7ff40214}},	//   сип_, dosv, _özbo, _آسفا, 
   {{0xea880026,0x00000000,0x00000000,0x00000000}},	//   сбол_, --, --, --, 
   {{0x6f080433,0x68ec0165,0x6454005b,0x78bc02d0}},	//   _hwec, _čads, ydyi, fosv, 
   {{0x6f082c6b,0x2ee40112,0x1cc80327,0x00000000}},	//   _kwec, _hilf_, _ཊེར_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3328020b,0xaa4002f6,0xa3b402e5,0x2c70781a}},	//   duax_, ärää_, _चुग_, _rády_, 
   {{0x2ee4781b,0x6f082d2f,0x78bc0810,0x2eec04e6}},	//   _milf_, _lwec, bosv, _luef_, 
   {{0x6454004c,0x2c700306,0xa3e801c6,0xa8046be1}},	//   udyi, _pády_, сдаа_, _эзил, 
   {{0x6454089c,0x6f08063f,0xe7380166,0xaf2c0023}},	// [8e60] rdyi, _nwec, _уеп_, ተባህለ, 
   {{0x2ee403cd,0x33d41cb8,0xb74401c8,0x00000000}},	//   _nilf_, фіст, _آئيو, --, 
   {{0x2734037e,0x61e80427,0xe04400c7,0x23280107}},	//   læn_, žflo, знеи, роҷи_, 
   {{0x6f080161,0x6aa0481f,0xd12c781c,0xa2e455a7}},	//   _bwec, hilf, طمه_, _номд, 
   {{0xd00c781d,0x6f08014b,0x2ee4015d,0x73c00032}},	//   اله_, _cwec, _bilf_, _аҡта, 
   {{0x2168781e,0x78bc0433,0x1ee807d6,0x00000000}},	//   _лиги_, zosv, لوچی_, --, 
   {{0x6f080a40,0x6aa00092,0xc0d41ee0,0x3ebc0427}},	//   _ewec, dilf, ርምር_, rovt_, 
   {{0xcca00952,0xd00c781f,0x399c0030,0x7af8013e}},	//   ىڭنى, _ملف_, násť_, ониё_, 
   {{0x3d0845bf,0x6aa00a40,0x6f080dd4,0x78bc7820}},	//   _सबके_, filf, _gwec, vosv, 
   {{0x6aa07821,0x00000000,0x00000000,0x00000000}},	//   gilf, --, --, --, 
   {{0x78bc7822,0x6f08097d,0x7e687823,0x00000000}},	//   tosv, _zwec, _indp, --, 
   {{0xd90c034c,0x2b4c0175,0x6aa001e7,0x00000000}},	//   پیک_, bwec_, ailf, --, 
   {{0x6aa07824,0x9a847825,0x291009c2,0xdcf800fd}},	//   bilf, _нукл, ázar_, _ixtı, 
   {{0xdb8400fb,0x50380092,0x00000000,0x00000000}},	//   _мѳһи, _በኮሚሽ, --, --, 
   {{0x7e680ac5,0x78bc01d3,0xd5a0006c,0x00000000}},	//   _mndp, posv, رلری, --, 
   {{0x6aac00d2,0x236401e4,0x00000000,0x00000000}},	//   _íafr, ĥojn_, --, --, 
   {{0x386800c6,0x7e68035a,0x00000000,0x00000000}},	// [8e70] _inar_, _ondp, --, --, 
   {{0x6f080433,0x6120063f,0x6d4402d1,0x00000000}},	//   _rwec, _ọlae, çhak, --, 
   {{0x6f0800d4,0x90e400cf,0xb034010a,0x0cd40150}},	//   _swec, سسان, днеш, _ﺟﺎﯞﻗ, 
   {{0x7e68465f,0x720403e6,0x66d001bf,0x00000000}},	//   _andp, سوڵم, ræke, --, 
   {{0x6e947826,0x33280393,0xddc802e2,0x38680166}},	//   миду, quax_, lefň, _mnar_, 
   {{0x7e6802d0,0x00000000,0x00000000,0x00000000}},	//   _cndp, --, --, --, 
   {{0x386801c4,0x8ce01e4a,0x30140e92,0xa28001d3}},	//   _onar_, ىقتۇ, _одвр, _جیلو, 
   {{0x7e686040,0x9d40039b,0x7f480131,0xab1801c6}},	//   _endp, теъд, تلۇق_, оцох_, 
   {{0x6aa07827,0x2ee412e8,0x00000000,0x00000000}},	//   tilf, _tilf_, --, --, 
   {{0x38687828,0x660056c0,0x3ce800e1,0x3e180262}},	//   _anar_, _đoko, _चूके_, _ноуэ_, 
   {{0x38680a2e,0x6fd80574,0x38b87829,0x7d1c1347}},	//   _bnar_, बेरं, léry_, _årsp, 
   {{0xfc30168d,0xe738782a,0x00000000,0x00000000}},	//   _محه_, оем_, --, --, 
   {{0x2cac782b,0x648803b2,0x38b802fb,0x38680427}},	//   mned_, _býin, néry_, _dnar_, 
   {{0x2734782c,0x6aa0208d,0x7f44036e,0xda60005a}},	//   ræn_, qilf, çiqi, _авши, 
   {{0x2cac782d,0x00000000,0x00000000,0x00000000}},	//   oned_, --, --, --, 
   {{0x3868002e,0x2cac782e,0x2728782f,0xd4647830}},	//   _gnar_, nned_, _джип_, мисе_, 
   {{0x2cac0d8b,0x399c0419,0x66d001bf,0xae0c0b27}},	// [8e80] ined_, rásť_, rækb, हरान_, 
   {{0x38b802f0,0x2cac01ef,0x00000000,0x00000000}},	//   déry_, hned_, --, --, 
   {{0x38682a89,0x00000000,0x00000000,0x00000000}},	//   _ynar_, --, --, --, 
   {{0x2a680198,0x6724002d,0x60180d30,0x7df81b87}},	//   _ɗaba_, orkj, іцер_, ुर्ग_, 
   {{0x7e687831,0x20cc0162,0x00000000,0x00000000}},	//   _pndp, býin_, --, --, 
   {{0x2cac7832,0xfe7800a2,0x02c4013d,0xe124009d}},	//   ened_, _kiįi_, _чигү, _омги, 
   {{0x628c03b9,0xd00c0137,0xa0a4022e,0x00000000}},	//   _ilbo, الۇ_, _жавд, --, 
   {{0x2cac7833,0x628c01f1,0x38b87834,0x9e640451}},	//   gned_, _hlbo, béry_, _ڪارن, 
   {{0x628c7835,0x8c400f5c,0x386803b2,0xebc0134b}},	//   _klbo, тење, _rnar_, ләшн, 
   {{0x2cac7836,0x38680579,0x9e640214,0x7e6803ac}},	//   aned_, _snar_, _تارن, _undp, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2004005a,0x594001d3,0x00000000,0x00000000}},	//   nboi_, _یکجہ, --, --, 
   {{0x628c05ac,0xab6007d2,0x7b8801af,0x00000000}},	//   _olbo, _مۇيى, _хәйб_, --, 
   {{0x628c0175,0x95f80d2e,0x2d8001c7,0x00000000}},	//   _nlbo, ्रेट_, äheg_, --, 
   {{0x20041028,0x6724002d,0x38b802fb,0x00000000}},	//   kboi_, arkj, zéry_, --, 
   {{0xddd802b5,0x38687837,0x24900076,0xdef41954}},	//   _aotū, _unar_, ghym_, ፈለን_, 
   {{0xb9d80201,0xd5e831f6,0x628c0122,0x38b802fb}},	// [8e90] _አሉ_, _وعدن_, _blbo, xéry_, 
   {{0x1cbc0003,0xdcec00bc,0x2cac01d3,0x82d801d5}},	//   _གཉའ_, íděn, zned_, ддус_, 
   {{0x2cac0142,0x6cec000d,0xd76400e5,0x00000000}},	//   yned_, _चूंग_, _راکٹ, --, 
   {{0x7d1845a7,0x2eb800dc,0x628c0e21,0x38b8022a}},	//   dsvs, ेत्त, _elbo, téry_, 
   {{0x643800df,0x00000000,0x00000000,0x00000000}},	//   _צעשנ, --, --, --, 
   {{0xed587838,0x72047839,0x2cac783a,0x00000000}},	//   зок_, _سورم, wned_, --, 
   {{0x2004026c,0xd01810a7,0x8d740b24,0x2cac00e5}},	//   bboi_, _мфа_, باشا, tned_, 
   {{0x38b8783b,0x6724783c,0x10145220,0x2cac0204}},	//   péry_, yrkj, _زبرد, uned_, 
   {{0x2cac0c3e,0x91c00116,0xff28007b,0x26c8007c}},	//   rned_, _чаңҗ, _يكفي_, ylbo_, 
   {{0xe7380b8d,0x321001ef,0x00000000,0x00000000}},	//   үен_, _jezy_, --, --, 
   {{0xa9681920,0xccf401d5,0x2d800254,0x00000000}},	//   чина_, _ўқи_, ähed_, --, 
   {{0x2d5000a2,0x32100210,0x00000000,0x00000000}},	//   _iše_, _lezy_, --, --, 
   {{0x26c8009a,0xf414015b,0x920c27a6,0xe7cc0eac}},	//   tlbo_, িলার_, िराज_, রখ্য, 
   {{0x2004084c,0x66d80428,0x00000000,0x00000000}},	//   zboi_, dùkù, --, --, 
   {{0x49b81060,0x224c0cc1,0x1540783d,0xa5082401}},	//   _باشد_, _ölkə_, лерм, яева_, 
   {{0x2d500118,0x792c0092,0xddd800c0,0xe80801ee}},	//   _mše_, _ተሰባስ, _sotū, _энид_, 
   {{0x1cbc025c,0x2490062c,0x6754007b,0x00000000}},	// [8ea0] _གཉལ_, rhym_, _أخبر, --, 
   {{0x72646aee,0x792c0092,0x20040042,0x0cc800cd}},	//   َالْ, _ተሰብስ, wboi_, ातुम, 
   {{0xe5a4783e,0x32100109,0x6b8c012d,0x6f180042}},	//   _чини, _dezy_, _żagl, eswc, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd5ac40ec,0x9f8401c0,0x2004005b,0x2d5001ef}},	//   _نفی_, эгдд, rboi_, _aše_, 
   {{0x628c783f,0x91001de6,0x00000000,0x00000000}},	//   _ulbo, _әпте, --, --, 
   {{0x7cfc00e4,0x9ce4084c,0x77640092,0x00000000}},	//   _oĩre, нцил, _ሊያስተ, --, 
   {{0xd24c0050,0xb0b801c6,0x717000d1,0xfb8801d5}},	//   _پنہ_, _жуух_, _خۇما, дроқ_, 
   {{0xbf100b8d,0x60c07840,0x6ec40131,0xed88004e}},	//   _түлә, moom, رتۇق, зсөк_, 
   {{0x60c07841,0x00000000,0x00000000,0x00000000}},	//   loom, --, --, --, 
   {{0xc1c40150,0x5ea40154,0x00000000,0x00000000}},	//   _ﯨﻨﺪﺍ, খকদে, --, --, 
   {{0x60c07842,0xb9080073,0x6f180139,0x00000000}},	//   noom, _बळ_, _äbcä, --, 
   {{0x61ec127b,0x00000000,0x00000000,0x00000000}},	//   _ogbl, --, --, --, 
   {{0x36d47843,0x60c07844,0x61ec003e,0xb4d8443a}},	//   тогр, hoom, _ngbl, ाष्_, 
   {{0x60c07845,0x321000d0,0x648800a2,0x00000000}},	//   koom, _rezy_, _iýij, --, 
   {{0x60c07846,0x6f180368,0x61740092,0x00000000}},	//   joom, yswc, _ተላላፊ_, --, 
   {{0x60c00a81,0xa8000086,0x61ec0334,0xf69800c6}},	// [8eb0] doom, _ôñan, _bgbl, _ينبع_, 
   {{0x66d02242,0x31840220,0x83f801c6,0xc95000c7}},	//   lækn, ктең, _үеэс_, _ртәы, 
   {{0x60c01418,0x6e340205,0xb4b400c0,0x00000000}},	//   foom, _özbi, _айнш, --, 
   {{0x251804ae,0x60c0427c,0x00000000,0x00000000}},	//   _קורא, goom, --, --, 
   {{0x32100210,0xa0200254,0x00000000,0x00000000}},	//   _tezy_, ööaj, --, --, 
   {{0xddd80100,0x6da46d8c,0x42e4010b,0xada4668d}},	//   _katň, кила, _бцсб, калл, 
   {{0x60c07847,0x81d47848,0x6cd800d8,0xed580108}},	//   boom, _борх, мфис_, фой_, 
   {{0x2d50038e,0x9df405a2,0x00000000,0x00000000}},	//   _vše_, ннәт_, --, --, 
   {{0x66d000b5,0xea94009d,0x00000000,0x00000000}},	//   dækn, вшнэ, --, --, 
   {{0x2d505723,0xa0200209,0x7b4400f1,0xe8f87849}},	//   _tše_, _ýöri, ائيل, мло_, 
   {{0xe9d8224f,0x9e78010f,0x692402e8,0x00000000}},	//   ько_, _קנעפ, ъмна, --, 
   {{0x76440882,0x3da407d8,0xb0b002dd,0x1cc80327}},	//   _abhy, _сруб, лгiл, _ཊེག_, 
   {{0x78b001ef,0x00000000,0x00000000,0x00000000}},	//   _škví, --, --, --, 
   {{0x60c0784a,0x33280327,0x00000000,0x00000000}},	//   zoom, drax_, --, --, 
   {{0x31600354,0x64a4784b,0x76440055,0x60c0784c}},	//   jvhz_, вава, _dbhy, yoom, 
   {{0xa7641086,0x60c00548,0x3328784d,0x764400cd}},	//   _акид, xoom, frax_, _ebhy, 
   {{0xc24401e0,0x60c001f4,0x00000000,0x00000000}},	// [8ec0] лмаҫ, voom, --, --, 
   {{0x60c00a49,0x66e401ec,0xe1080108,0x00000000}},	//   woom, _шопа, дежд_, --, 
   {{0x60c0784e,0x64c4004b,0xb398069d,0x00000000}},	//   toom, _ليدل, _ጊዜውን_, --, 
   {{0x47c80eac,0x1cbc031c,0x9f8400ee,0x00000000}},	//   রেণী, _གཉེ_, кгед, --, 
   {{0x60c0784f,0x33d40220,0x33280117,0x66d03c38}},	//   room, _бірт, crax_, næko, 
   {{0x60c022a9,0x8fa01fbe,0xf1d401c4,0x00000000}},	//   soom, шаче, _өөхө, --, 
   {{0x20547850,0xdfd05024,0x60c07851,0x82480240}},	//   _итар, _چيز_, poom, _ሓምሳታ, 
   {{0xdfd004fb,0x8d80010b,0xa3e40073,0x00000000}},	//   _نيز_, рушд, _पणा_, --, 
   {{0x2d9000fd,0x00000000,0x00000000,0x00000000}},	//   _üzen_, --, --, --, 
   {{0xddc80270,0x3a740137,0x00000000,0x00000000}},	//   lefō, улор, --, --, 
   {{0x66d00008,0x6b9c01e7,0x00000000,0x00000000}},	//   tækn, úsgr, --, --, 
   {{0x386c7852,0x33280009,0x00000000,0x00000000}},	//   ñer_, yrax_, --, --, 
   {{0x66d004ce,0x648800a2,0x00000000,0x00000000}},	//   rækn, _eýik, --, --, 
   {{0x99647853,0x64440009,0x00000000,0x00000000}},	//   _атил, _abki, --, --, 
   {{0x34945a6f,0xddd801ef,0xcad405d0,0x00000000}},	//   гавр, _motů, _שוות_, --, 
   {{0x998c007f,0x00000000,0x00000000,0x00000000}},	//   _jefō_, --, --, --, 
   {{0xd6d87854,0xd7c4004b,0x00000000,0x00000000}},	// [8ed0] _ото_, _ګوښه_, --, --, 
   {{0x33282988,0x00000000,0x00000000,0x00000000}},	//   rrax_, --, --, --, 
   {{0xd1386990,0x33280009,0x00000000,0x00000000}},	//   ьха_, srax_, --, --, 
   {{0x1cc80489,0x66002625,0x55c001e0,0xdfcc00ec}},	//   _ཊེཊ_, _đoki, _бәғз, ڻيو_, 
   {{0xfd64004d,0x79880042,0x0f707855,0x00000000}},	//   _truớ, hydw, шғар, --, 
   {{0x0cc808df,0xad5802e8,0xe0e401e1,0x00000000}},	//   ात्म, ерих_, _òòni_, --, 
   {{0x41e44dba,0xfe700bbf,0xc0d002d3,0x7d1c02d2}},	//   _віта, غده_, ብሮም_, _ærsl, 
   {{0x3dcc03cb,0xd7d000ab,0x7988015d,0xbcfc0051}},	//   _dydw_, _सरंच, dydw, _trĩn, 
   {{0x7c840640,0x00000000,0x00000000,0x00000000}},	//   рује, --, --, --, 
   {{0x290408cd,0x2fcc020c,0x80c40073,0x7f940150}},	//   tpla_, _iyeg_, िकथे, _таух, 
   {{0x79880142,0xaa440c75,0xe9a400c7,0x00000000}},	//   gydw, _ەنتى, уанп, --, 
   {{0x88842c11,0x7c9400f2,0x13c80011,0x00000000}},	//   рғил, _پشما, লেয়, --, 
   {{0xaa4464ca,0x25b80077,0xdb243451,0x80c40073}},	//   _белл, _sxpl_, _مونی, िकते, 
   {{0x29047856,0x2fcc05b1,0xe5a4022e,0x00000000}},	//   ppla_, _myeg_, гиги, --, 
   {{0x6b887857,0x6e340205,0x0720000d,0x85b4008e}},	//   lyeg, _özbu, _बिकव_, рәпч, 
   {{0xa3e87858,0x00000000,0x00000000,0x00000000}},	//   едба_, --, --, --, 
   {{0x6b887859,0x2fcc01d4,0x00000000,0x00000000}},	// [8ee0] nyeg, _nyeg_, --, --, 
   {{0x9798011a,0x26cc01e1,0x00000000,0x00000000}},	//   _נשיק, _ófo_, --, --, 
   {{0x7cfc00c7,0x23640115,0x00000000,0x00000000}},	//   _oĩra, ŭoj_, --, --, 
   {{0x3dcc0368,0x6b881418,0x236401e4,0xdfd80395}},	//   _rydw_, kyeg, ƭoj_, нъл_, 
   {{0x338401b9,0xaf8401e0,0x5cc400d1,0xddd8013a}},	//   _куёв, аҡта_, һсиз, _potů, 
   {{0x02b8043e,0x00000000,0x00000000,0x00000000}},	//   _आदिभ, --, --, --, 
   {{0x5cc4785a,0x4f38001f,0x00000000,0x00000000}},	//   лсиз, _የውይይ, --, --, 
   {{0x27f00280,0x8d440451,0x00000000,0x00000000}},	//   _ngyn_, اليٰ_, --, --, 
   {{0xa2b806ff,0x798800a9,0x9a84785b,0x9ad80055}},	//   ्वप्, wydw, гунл, _asāṅ, 
   {{0xdee4016c,0x7c2400e2,0x61fc01e4,0x3dcc0042}},	//   _сози, _ķiru, ncpl, _tydw_, 
   {{0x5d84785c,0x6b880083,0xf9d4239a,0xff080139}},	//   _حلال, ayeg, ронэ, _şähä_, 
   {{0x1cbc0135,0x6b88785d,0x2d941309,0x2710007f}},	//   _གཉི_, byeg, _трус, fņn_, 
   {{0x6b880526,0x57a4785e,0x48a80276,0xe28c01a9}},	//   cyeg, ушна, утэм_, kkа_, 
   {{0x2d3c0023,0x2fc80254,0x00000000,0x00000000}},	//   _የርእየ, üagi_, --, --, 
   {{0xa2b80b33,0x8ca802ab,0xd7f82bb6,0xcdf4011a}},	//   ्वन्, _जगमो, _пуп_, רמלי_, 
   {{0xa9240030,0x94a801d5,0x6b8c0210,0x00000000}},	//   _dažď, хтга_, _żagi, --, 
   {{0x3374785f,0x9f4001e1,0xf238004e,0x00000000}},	// [8ef0] шгар, _àkè_, кпаш_, --, 
   {{0x720400e5,0x00000000,0x00000000,0x00000000}},	//   شہرہ_, --, --, --, 
   {{0xc10430bf,0x00000000,0x00000000,0x00000000}},	//   مولي, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xabdc0150,0x00000000,0x00000000,0x00000000}},	//   _ﺇﺭﻫﺎ, --, --, --, 
   {{0x6b88019f,0x649c0882,0x057403e6,0xde0017a0}},	//   vyeg, ṣita, _ئاید, опши, 
   {{0x10040153,0x00000000,0x00000000,0x00000000}},	//   _бязм, --, --, --, 
   {{0xac847860,0x2d907861,0xcf2400c6,0x6d440309}},	//   ргил, _üzem_, _مرئي, çhaq, 
   {{0xeb98302a,0xd3e403d4,0x00000000,0x00000000}},	//   тип_, গুৰি_, --, --, 
   {{0x6b8800ca,0xddd801ed,0x00000000,0x00000000}},	//   ryeg, _eltű, --, --, 
   {{0xade047d0,0x7e340046,0x00000000,0x00000000}},	//   गेशन_, _اۋىز_, --, --, 
   {{0x66d0005c,0x87d40014,0x00000000,0x00000000}},	//   rækm, ٝںخا, --, --, 
   {{0xb8fc7862,0x00000000,0x00000000,0x00000000}},	//   _ती_, --, --, --, 
   {{0x66d001bf,0x00000000,0x00000000,0x00000000}},	//   mækk, --, --, --, 
   {{0x2710007f,0xf1a400c5,0x941803e3,0x00000000}},	//   sņn_, _गेलन, liqə_, --, 
   {{0x19b8011a,0x1864014b,0x00000000,0x00000000}},	//   _במצב, _ваъи_, --, --, 
   {{0xd3847863,0xe2c80116,0xa3e8009d,0x00000000}},	// [8f00] айте_, влад_, тдаа_, --, 
   {{0x248008cd,0x9f400241,0x61441422,0x00000000}},	//   _wokm_, _àké_, иеза, --, 
   {{0x66d00ad9,0xa508074d,0x00000000,0x00000000}},	//   hækk, _шена_, --, --, 
   {{0x650001f2,0x1f6408b7,0x44fc0241,0xb9ac010f}},	//   _ọkwụ, икем, _ií_, עבאָ, 
   {{0x44fc7864,0x2d800086,0x03e400cc,0x00000000}},	//   _hí_, ähen_, _ফ্ৰণ, --, 
   {{0x44fc4e53,0x66d0037e,0x6b8c00ee,0x00000000}},	//   _kí_, dækk, _ýagy, --, 
   {{0x44fc7865,0x66d001a8,0x6d4402d1,0x00000000}},	//   _jí_, tækj, çhap, --, 
   {{0x44fc7866,0x94180213,0x10340137,0x7c2400de}},	//   _mí_, fiqə_, _ەبەگ, _ķirs, 
   {{0x44fc7867,0xb7fc032c,0xb0b80107,0x00000000}},	//   _lí_, _एलबम_, _сурх_, --, 
   {{0x44fc7868,0x66d001a8,0xc0d00023,0x00000000}},	//   _oí_, sækj, ብዮም_, --, 
   {{0x44fc7869,0xdde80fb4,0x25500023,0x00000000}},	//   _ní_, _شرطه_, ዝነበሩ, --, 
   {{0x2a6802a8,0x941800ac,0x66d001bf,0x1be401a9}},	//   _ɗabi_, biqə_, bækk, _кўлг, 
   {{0x44fc786a,0x7ac41b15,0x3f400ba1,0x660006be}},	//   _aí_, _гөна, nòu_, _şoka, 
   {{0x44fc786b,0x27fc012c,0x5c30001f,0xe4f000af}},	//   _bí_, ětna_, _በቀጣይ, _आंखि_, 
   {{0x76980241,0xc9d000db,0xc9801188,0xca6843a2}},	//   _nìye, _وزىب, _муъи, _сiбi, 
   {{0x44fc786c,0x316c786d,0x395c01ef,0x00000000}},	//   _dí_, _čez_, _isvs_, --, 
   {{0x1cc8031c,0x73c40ce8,0x964458e5,0x00000000}},	// [8f10] _ཊེན_, сәне, _кэнд, --, 
   {{0x44fc0cad,0xc2740114,0x427417cd,0x00000000}},	//   _fí_, олуј, огус, --, 
   {{0x44fc556d,0xf040001f,0x00000000,0x00000000}},	//   _gí_, _የምርም, --, --, 
   {{0x7654786e,0x769801e1,0x7534786f,0x3a3c0332}},	//   lezy, _dìye, muzz, _lcvp_, 
   {{0x7534003d,0x395c0334,0x035800fb,0xc05800d4}},	//   luzz, _lsvs_, _күтә_, ріх_, 
   {{0x51847870,0x76547871,0xad240ae5,0x66d000b5}},	//   _куба, nezy, مىتى, vækk, 
   {{0x31e403f4,0x75347872,0x44fc01fb,0xf1e40183}},	//   _প্রশ, nuzz, _xí_, _প্ৰভ, 
   {{0x40347873,0xdd8c7874,0x45b80302,0x6ab07875}},	//   _месс, عوي_, יפול_, ीक्र, 
   {{0x00a403e6,0x32007876,0x2d7c00d1,0x7f58014b}},	//   _بینێ, ochy_, _ﻣﯧﻨﻰ_, _катс_, 
   {{0x75347877,0x66d004ce,0x00000000,0x00000000}},	//   kuzz, rækk, --, --, 
   {{0xa2b80c00,0xec147878,0x28e800f7,0x75340083}},	//   ्वत्, _هواد, лдоп_, juzz, 
   {{0x44fc0570,0x75346938,0x6d40014f,0x70a41d68}},	//   _rí_, duzz, _iqla, _खगोल, 
   {{0x44fc7879,0x2cac787a,0xab28787b,0x941800ac}},	//   _sí_, mied_, _сола_, qiqə_, 
   {{0xa6c8787c,0x7534787d,0x2cac787e,0xd5440032}},	//   улга_, fuzz, lied_, әпте_, 
   {{0x7534787f,0xb7e800fe,0x320000d7,0x78c803b2}},	//   guzz, কুলত_, dchy_, úsvø, 
   {{0x44fc7880,0x2cac029d,0x32007881,0xf99035aa}},	//   _ví_, nied_, echy_, _تبه_, 
   {{0xddd827c4,0xd4647882,0x44fc110e,0x1834011a}},	// [8f20] _motš, щите_, _wí_, _האפל_, 
   {{0x44fc7883,0x2cac7884,0x7534003d,0x6d407885}},	//   _tí_, hied_, buzz, _oqla, 
   {{0x75347886,0x44fc7887,0xa0687888,0xddd800b0}},	//   cuzz, _uí_, лажа_, _patō, 
   {{0x26c8136f,0x2cac0649,0x32000076,0x30a40212}},	//   lobo_, jied_, achy_, орів, 
   {{0x2cac7889,0x6454788a,0x6d40788b,0x5438008f}},	//   died_, meyi, _aqla, _געכא, 
   {{0x26c80770,0x6454788c,0x320000b5,0x3f40067c}},	//   nobo_, leyi, cchy_, ròu_, 
   {{0xddd80f8b,0x2cac788d,0x3f40067c,0x00000000}},	//   _botš, fied_, sòu_, --, 
   {{0x26c8014c,0x6454788e,0x2cac788f,0x24900072}},	//   hobo_, neyi, gied_, nkym_, 
   {{0x6d680029,0x7654083a,0x6d400455,0x9e3800c6}},	//   _īpaš, yezy, _eqla, _مساء_, 
   {{0x1cc80156,0x64540028,0x66d00194,0x26c80687}},	//   _ཊེམ_, heyi, bæki, jobo_, 
   {{0x2cac7890,0xdca410f3,0x2f0c01e1,0x6ec400cd}},	//   bied_, _лажи, _tógò_, ाकरु, 
   {{0xddd8000a,0x2cac7891,0x00000000,0x00000000}},	//   _gotš, cied_, --, --, 
   {{0x64547892,0x6d501591,0x26c87893,0x9a8401c6}},	//   deyi, čkaš, fobo_, _гуйл, 
   {{0x7534038f,0x95c87894,0x26c87895,0xa80403b9}},	//   tuzz, губа_, gobo_, _acığ, 
   {{0x76542622,0x74a87896,0x4df800df,0x00000000}},	//   rezy, асаң_, רפלא, --, 
   {{0x75347897,0x1cb4031c,0x6454676c,0x97240212}},	//   ruzz, _ཚམས_, geyi, _льод, 
   {{0x94843e64,0x32000afa,0xbe140154,0x7654007f}},	// [8f30] _ғынд, tchy_, _সাঈদ_, pezy, 
   {{0x26c87898,0x75347899,0x490c012c,0x2cac0156}},	//   cobo_, puzz, थीको_, zied_, 
   {{0x6454789a,0x5064036b,0x3200789b,0x2cac017a}},	//   beyi, йтда, rchy_, yied_, 
   {{0x32000048,0x2ec041ac,0x249013d5,0x4ea40131}},	//   schy_, शक्त, ckym_, әрда, 
   {{0x2cac06f2,0x643800c8,0xddd800f3,0x7ff400c6}},	//   vied_, _דערנ, _rotš, أسما, 
   {{0x2cac789c,0x999c0024,0x66d001a8,0x8ca8033f}},	//   wied_, netų_, tæki, _जगहो, 
   {{0xddd8000a,0x2cac789d,0x00000000,0x00000000}},	//   _potš, tied_, --, --, 
   {{0x26c800f1,0x776c02d0,0x606000d1,0xef1000db}},	//   zobo_, _orax, _يۇلل, _жүдө, 
   {{0x26c80230,0x2cac789e,0xab2827a8,0x999c0153}},	//   yobo_, ried_, шопа_, ketų_, 
   {{0xa92463e3,0x6f08789f,0x4ea414b7,0x645478a0}},	//   одол, _itec, _урба, zeyi, 
   {{0x645478a1,0x776c78a2,0x2cac2517,0x660078a3}},	//   yeyi, _arax, pied_, _şoko, 
   {{0x26c80526,0xabb46b62,0x00000000,0x00000000}},	//   wobo_, _һаҗә, --, --, 
   {{0x776c78a4,0x26c878a5,0x6f08062c,0x78bc78a6}},	//   _crax, tobo_, _jtec, érva, 
   {{0xa96878a7,0xfd4c00b8,0x645478a8,0x999c00c0}},	//   _вика_, _akiṃ, weyi, getų_, 
   {{0x26c878a9,0xa2b801bc,0xd05c0213,0x249000d0}},	//   robo_, ्वस्, şvət, tkym_, 
   {{0x6f080c8c,0x26c87480,0x776c78aa,0x66e40c60}},	//   _otec, sobo_, _frax, соҳа, 
   {{0x645478ab,0x776c78ac,0x26c80077,0xd770001f}},	// [8f40] reyi, _grax, pobo_, ባሰቢያ_, 
   {{0x26c80912,0x75240334,0x249000d0,0xd36c007b}},	//   qobo_, _fvhz, skym_, ضهم_, 
   {{0x6f0878ad,0x645401e2,0xd674011a,0x47b000cc}},	//   _atec, peyi, _ותיק_, _ঘৰচী, 
   {{0xb9cc010f,0x645406be,0x00000000,0x00000000}},	//   נזאָ, qeyi, --, --, 
   {{0x442078ae,0x7d0802d0,0xa2e4004e,0x6f0801ef}},	//   mai_, _stds, _момд, _ctec, 
   {{0xe29878af,0x00000000,0x00000000,0x00000000}},	//   _таг_, --, --, --, 
   {{0x6f08127b,0x44201d50,0x68f80213,0x1cbc0327}},	//   _etec, oai_, _əbdü, _གཉད_, 
   {{0xa2b8081e,0xfbf8015b,0x6f080208,0x9b2400d8}},	//   ्वव्, ঘর্ষ_, _ftec, офол, 
   {{0xda7809a5,0x442078b0,0x6b8c031c,0x20cc03b2}},	//   аян_, iai_, _żagr, býir_, 
   {{0xbb3006ba,0x6b9c01c3,0xc8c80014,0x00000000}},	//   ﺭﺷﻰ_, ùsga, ۪وَن_, --, 
   {{0x442078b1,0x69f00b38,0x41d02122,0x00000000}},	//   kai_, нүшт, _तुमस, --, 
   {{0x442078b2,0x776c78b3,0xb7e80011,0x00000000}},	//   jai_, _prax, _ক্ষত_, --, 
   {{0x442078b4,0x3eac0af9,0x6f0800db,0x999c0024}},	//   dai_, _kmdt_, _xtec, tetų_, 
   {{0x7c2078b5,0x2a0401f2,0x442001ab,0xd5b80672}},	//   lamr, ịaru_, eai_, асб_, 
   {{0x442078b6,0x999c0153,0xd90c0345,0x00000000}},	//   fai_, retų_, _جیج_, --, 
   {{0x442078b7,0x776c78b8,0x7c2078b9,0x00000000}},	//   gai_, _trax, namr, --, 
   {{0xb9c80201,0x1cbc0003,0x78ac78ba,0x7c20009f}},	// [8f50] _ሲል_, _གཉན_, _imav, iamr, 
   {{0x7c200162,0xd25810f3,0x442078bb,0x999c01d3}},	//   hamr, јца_, aai_, letű_, 
   {{0x442078bc,0x6f0878bd,0x7c2078be,0xddc8007f}},	//   bai_, _stec, kamr, lefņ, 
   {{0x7c200054,0x229401bf,0x657833b8,0x8454075e}},	//   jamr, _hækl_, åthe, _قىپچ, 
   {{0xa2b878bf,0x6488010e,0xaed4300e,0xddd80210}},	//   ्वश्, _iýip, подш, _natł, 
   {{0x629c200c,0x66d00008,0x1ee80214,0x5194010a}},	//   chpo, bæku, مونی_, _мăла, 
   {{0xa2b8258d,0x78ac007d,0xa2c000d1,0x8cc43599}},	//   ्वर्, _omav, _чәтк, ावलो, 
   {{0xec7878c0,0x7c2001d3,0x00000000,0x00000000}},	//   спи_, gamr, --, --, 
   {{0x998c007f,0x999c01d3,0x6f08035a,0x00000000}},	//   _jefņ_, detű_, _utec, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x1ee83345,0xad24129d,0x00000000,0x00000000}},	//   _اولی_, _رىشى, --, --, 
   {{0x442078c1,0x29e00120,0x7c2000f3,0x629c0165}},	//   xai_, _açaí_, camr, zhpo, 
   {{0x442078c2,0xd5b401fb,0xeb0800db,0x200803b9}},	//   vai_, ống_, _اقتى_, _əbi_, 
   {{0x442078c3,0x78ac1cea,0x7ac40063,0x25a800f1}},	//   wai_, _emav, _осје, مدزي_, 
   {{0x442078c4,0x64980107,0xddd80210,0x00000000}},	//   tai_, бтар_, _zatł, --, 
   {{0x5924031c,0x442078c5,0x84540e56,0x00000000}},	//   _རྗིས_, uai_, بىرچ, --, 
   {{0x442078c6,0xe29878c7,0x5edc2435,0x232801f0}},	// [8f60] rai_, баа_, गतम्_, сози_, 
   {{0x7c200ac5,0x67242a5b,0xf1a8004b,0x769801e1}},	//   zamr, mskj, ښانه_, _tìya, 
   {{0x672478c8,0xf550063f,0x68f401d5,0x78ac035b}},	//   lskj, nụ́_, _kiyd, _ymav, 
   {{0xe0d078c9,0x442078ca,0x661c0dd4,0x68f401a9}},	//   رزا_, qai_, _hepk, _jiyd, 
   {{0x67241a84,0xa0681fc7,0x68f405d1,0x661c78cb}},	//   nskj, _һава_, _miyd, _kepk, 
   {{0x68f4022e,0x999c01d3,0x661801a9,0x00000000}},	//   _liyd, zetű_, аtki, --, 
   {{0xa1140150,0x00000000,0x00000000,0x00000000}},	//   _ءورت, --, --, --, 
   {{0x5ba401ce,0x22580219,0x6724143a,0x661c78cc}},	//   зроз, lepk_, kskj, _lepk, 
   {{0x8fa078cd,0xcb641f5a,0x7ac4004e,0x00000000}},	//   _зате, зање_, мөка, --, 
   {{0x3a7478ce,0x7c2078cf,0x672478d0,0x1cbc031c}},	//   флор, samr, dskj, _གཉམ_, 
   {{0x5d1404d3,0x7c200098,0xb83400f5,0x00000000}},	//   _رباز, pamr, менщ, --, 
   {{0xf8bc04c5,0x200478d1,0x6dc4036b,0x38c801d3}},	//   ৃষ্ঠ, ncoi_, _غزلل, تاخی_, 
   {{0x68f4322e,0x65000521,0x999c01ed,0x21380472}},	//   _diyd, _ọkpụ, retű_, huph_, 
   {{0xfaa805d9,0x66d001bf,0x661c236c,0x00000000}},	//   _گهڻي_, dæks, _cepk, --, 
   {{0xd49878d2,0x78ac0232,0x661c020b,0x38b800e4}},	//   бра_, _tmav, _depk, hĩri_, 
   {{0x78ac78d3,0x68f403ee,0x661c127b,0x49380a1e}},	//   _umav, _giyd, _eepk, _הגהו, 
   {{0x32280efb,0x78bc01e3,0x17a800fe,0x9580030d}},	// [8f70] قتاۋ_, mnsv, _গুৰি, ĕлте, 
   {{0x76b86bfd,0x2138009a,0x236002d2,0xd5b821b4}},	//   _флор_, fuph_, _dskj_, _гсм_, 
   {{0x78bc78d4,0x66d00008,0x31581291,0x00000000}},	//   onsv, rækt, تلاج_, --, 
   {{0x78bc78d5,0x236002d2,0x66d0005c,0x2ed400cd}},	//   nnsv, _fskj_, bæks, धत्त, 
   {{0xded40023,0x00000000,0x00000000,0x00000000}},	//   ርጽን_, --, --, --, 
   {{0xa28000f1,0x85040345,0x00000000,0x00000000}},	//   _ټیمو, _توێن, --, --, 
   {{0x41bc0156,0xace80d44,0x9b400133,0x00000000}},	//   ཛཝཞཟ, омка_, ۆچوو, --, 
   {{0xeb981c89,0x78bc78d6,0x6724002d,0x69d400e5}},	//   жии_, jnsv, yskj, üzem, 
   {{0x68f401a9,0x00000000,0x00000000,0x00000000}},	//   _riyd, --, --, --, 
   {{0x78bc26bd,0xbfa800ee,0x68f401d5,0x67241f53}},	//   ensv, _этсе_, _siyd, vskj, 
   {{0x661c78d7,0xa9a478d8,0x3b84009d,0x2bd8000d}},	//   _repk, финд, длөг, _ढरका, 
   {{0x67242a5b,0x68f401b9,0x78bc4699,0x18b000c7}},	//   tskj, _qiyd, gnsv, кәыр, 
   {{0x661c00d7,0xe7cc00fe,0x3774008e,0xf774003b}},	//   _pepk, ৰখ্য, нырс, нурю, 
   {{0x672478d9,0x66d03c38,0x6ea0012d,0x00000000}},	//   rskj, væks, कोचु, --, 
   {{0x672455c2,0x154078da,0x23600427,0x68f4022e}},	//   sskj, керм, _sskj_, _tiyd, 
   {{0x67240efa,0x6d440309,0xe73800d8,0xf99078db}},	//   pskj, çhay, _деи_, _حبه_, 
   {{0x661c03ee,0xb86401f7,0x47c80154,0xe3b800c7}},	// [8f80] _tepk, _سايو, রেজী, цба_, 
   {{0x66d05266,0x33d4177b,0x4ecc015b,0xd7d8037e}},	//   ræks, хіст, িগুল, deト_, 
   {{0x64a478dc,0x75d8009d,0x516400db,0x70c800b8}},	//   _жана, _ньюс_, мүрү_, िकूल, 
   {{0xd12c78dd,0x23600139,0x38b800e4,0x00000000}},	//   شمه_, _tskj_, tĩri_, --, 
   {{0x21385684,0x320c05d1,0x1ec801b9,0x156400d1}},	//   suph_, _şeye_, олди_, _ﺷﯧﺌﯩ, 
   {{0xb3540da4,0xaadc3381,0x2004054e,0x38b800e4}},	//   _سیما_, _नीलक, scoi_, rĩri_, 
   {{0x910006ed,0x602410fc,0x78bc03cd,0x4f540092}},	//   _апсе, _одва, ynsv, _ለውይይ, 
   {{0x91e039c1,0x8c400063,0x00000000,0x00000000}},	//   _росе, веће, --, --, 
   {{0xd00c006c,0xfe7801c0,0x72a00137,0x78bc3b97}},	//   _خلق_, _нүд_, _جەەن, vnsv, 
   {{0x78bc78de,0xd3780a7c,0x00000000,0x00000000}},	//   wnsv, קריט, --, --, 
   {{0xd83c02f0,0xd90c4c8b,0xf8b800db,0x00000000}},	//   _áčko_, جیب_, зөп_, --, 
   {{0x7e6878df,0x78bc04e6,0x068000d1,0x00000000}},	//   _hadp, unsv, _ﺯﯦﻤﯩ, --, 
   {{0x6d54145e,0x7e680165,0x78bc007c,0x2d900205}},	//   _âzar, _kadp, rnsv, _üzer_, 
   {{0xd5a001d5,0xf9f800cc,0x00000000,0x00000000}},	//   پلری, _আজকল_, --, --, 
   {{0x9ba00058,0x7e68037e,0x98c46e1e,0x15e80212}},	//   _سەھى, _madp, _осил, юємо_, 
   {{0x7af878e0,0x7e68014f,0xbac003d4,0x65782dba}},	//   _hivt, _ladp, _উঠিছ, åtha, 
   {{0xb27478e1,0x202c001f,0xb82400cc,0x00000000}},	// [8f90] нлаш, _አምላክ, _ভাপত_, --, 
   {{0x38680917,0x7e6878e2,0x55042e36,0x00000000}},	//   _haar_, _nadp, _очма, --, 
   {{0xa5c00598,0xc10478e3,0xb03428cf,0x1dac02ab}},	//   _бөте, نولي, енеш, _झेलत, 
   {{0x386878e4,0x7af801bf,0xf1f401c6,0x70c808a3}},	//   _jaar_, _livt, _үзмэ, िकेल, 
   {{0x386878e5,0x7e6878e6,0x00000000,0x00000000}},	//   _maar_, _badp, --, --, 
   {{0x386878e7,0x00000000,0x00000000,0x00000000}},	//   _laar_, --, --, --, 
   {{0x7cfc00e4,0x5fd01d00,0x1d040395,0x00000000}},	//   _oĩru, _ﭘﻮﭼﺘ, нещи_, --, 
   {{0x386845eb,0x2b1478e8,0xab6478e9,0x7e6803ac}},	//   _naar_, ньор, евил, _eadp, 
   {{0x332878ea,0xca6801ec,0x00000000,0x00000000}},	//   nsax_, _тiлi, --, --, 
   {{0x435802d3,0x7f680150,0x00000000,0x00000000}},	//   _ምክብባ, _ﺒﺤل_, --, --, 
   {{0x386878eb,0xe9d806bb,0x6e2078ec,0x7af878ed}},	//   _baar_, яко_, _ielb, _divt, 
   {{0x6e200323,0x764478ee,0x38680009,0xf648123b}},	//   _helb, _achy, _caar_, _לצ_, 
   {{0x38680917,0x6e2078ef,0x4e0000c5,0x7e6806be}},	//   _daar_, _kelb, _ललाई_, _yadp, 
   {{0x6e2078f0,0xaa4410cf,0x38680076,0x7d101801}},	//   _jelb, _чекл, _eaar_, _èksè, 
   {{0x6498001a,0xba7478f1,0x38680493,0x48c40184}},	//   птар_, _جانت, _faar_, _аҙна, 
   {{0x38680a81,0x63841d0f,0x616c0092,0x7af800de}},	//   _gaar_, нгба, _ሠላማዊ_, _zivt, 
   {{0xe29857bf,0x7b0c010f,0x290403b9,0x00000000}},	// [8fa0] паа_, ַפאַ, lqla_, --, 
   {{0x7cc80118,0x00000000,0x00000000,0x00000000}},	//   měre, --, --, --, 
   {{0x7e68509b,0x5924031c,0x3868002e,0x2904031c}},	//   _radp, ྡེགས_, _yaar_, nqla_, 
   {{0x47c81c82,0x64a478f2,0x38680694,0x3328058a}},	//   ৰেণী, _чама, _xaar_, bsax_, 
   {{0x764400a9,0x6e2078f3,0x7e68017a,0x64440857}},	//   _ychy, _belb, _padp, _icki, 
   {{0x826401d9,0x01e4496b,0xd12c0131,0x626401c6}},	//   _جگرٕ, _айгү, شمۇ_, _явга, 
   {{0x6e203628,0xa0a478f4,0x91e063b1,0x999c02b5}},	//   _delb, _завд, _боре, tatō_, 
   {{0x4d704b15,0x1ea878f5,0xf000013e,0xa2b800dc}},	//   اطور, _کاري_, _кӯши, ्वक्, 
   {{0x628c78f6,0x386878f7,0x10a01679,0x6e2001ed}},	//   _kobo, _raar_, _ситн, _felb, 
   {{0x386878f8,0x6e2078f9,0x628c78fa,0xb99801f4}},	//   _saar_, _gelb, _jobo, двох_, 
   {{0x386878fb,0x628c78fc,0x7af8010f,0x6444127b}},	//   _paar_, _mobo, _vivt, _ocki, 
   {{0x628c78fd,0x38680a81,0x764478fe,0x7af8014f}},	//   _lobo, _qaar_, _schy, _wivt, 
   {{0x38680660,0x628c78ff,0x7af87900,0x00000000}},	//   _vaar_, _oobo, _tivt, --, 
   {{0x38680917,0x628c7901,0xda6402dd,0x6444127b}},	//   _waar_, _nobo, _ساتي, _acki, 
   {{0x9a8c044e,0x41d04103,0xd4985a06,0x38687902}},	//   _ዝለዓለ_, _तुलस, пра_, _taar_, 
   {{0x38687903,0x7cc8012c,0xf7480451,0x6ba4010e}},	//   _uaar_, běre, _قلعي_, _ötgü, 
   {{0x76447904,0x00000000,0x00000000,0x00000000}},	// [8fb0] _tchy, --, --, --, 
   {{0x628c7905,0x64447906,0x76441718,0x3328022e}},	//   _cobo, _ecki, _uchy, rsax_, 
   {{0x628c7907,0xc2c405d9,0xd13800a7,0x66b00220}},	//   _dobo, ديلي, яха_, _тұру, 
   {{0x6e207908,0x6fb8030c,0xb4940063,0x00000000}},	//   _selb, мгер_, _римљ, --, 
   {{0x6e200201,0x439401c0,0x628c39e2,0xdfcc00ec}},	//   _pelb, _баяс, _fobo, ٺيو_, 
   {{0x628c0d62,0xed586522,0x6e207909,0xdfcc00f1}},	//   _gobo, док_, _qelb, غيو_, 
   {{0x6e20790a,0x70640022,0xc2c4007b,0x00000000}},	//   _velb, _ихаҧ, _صيفي, --, 
   {{0x628c790b,0x6e200d47,0x229402d2,0x5064009d}},	//   _zobo, _welb, _ræki_, _ятга, 
   {{0x2ef4790c,0x6e20790d,0x628c790e,0x229408a5}},	//   _азар, _telb, _yobo, _sæki_, 
   {{0x7cc800bc,0xbbe80137,0x00000000,0x00000000}},	//   věre, ةرىم_, --, --, 
   {{0xfd1005d9,0x00000000,0x00000000,0x00000000}},	//   _هجن_, --, --, --, 
   {{0x61f8790f,0x2efc0150,0xddd80118,0x00000000}},	//   _útle, _ءﺳﻮز_, _natř, --, 
   {{0x6158001f,0x00000000,0x00000000,0x00000000}},	//   ጀክቶች, --, --, --, 
   {{0x22940008,0x7bc40064,0x00000000,0x00000000}},	//   _tæki_, _žiug, --, --, 
   {{0x628c7910,0x5690036b,0x00000000,0x00000000}},	//   _robo, шаёт, --, --, 
   {{0x58f8025c,0x00000000,0x00000000,0x00000000}},	//   _དངགས_, --, --, --, 
   {{0x2b4c7911,0x3270001f,0x628c7912,0xa6e401c6}},	// [8fc0] ntec_, _ለማምጣ, _pobo, _ижил, 
   {{0x628c047e,0x2b4c7913,0x27fc00bc,0x61f41e24}},	//   _qobo, itec_, ětnu_, نساء, 
   {{0xe4c4044c,0xfdcc04c5,0x628c29ef,0xe5a44eca}},	//   _айни, _লণ্ড, _vobo, _рини, 
   {{0xe35405f5,0x628c7914,0x2b4c0010,0x64440857}},	//   _итгэ, _wobo, ktec_, _ucki, 
   {{0x628c7915,0xdfd07916,0xf48400d8,0x00000000}},	//   _tobo, جيش_, _суќн, --, 
   {{0xa1147735,0x6f0c7917,0xddd8013a,0x00000000}},	//   _لوست, íaca, _zatř, --, 
   {{0x5cc47918,0x3f800276,0xe044084c,0x00000000}},	//   ксиз, ţiu_, _инви, --, 
   {{0xe174001f,0xb0b801c6,0x59b000cd,0x00000000}},	//   _የሚታዩ_, _зуух_, ुपसर, --, 
   {{0x60c07919,0x9ad800b8,0x2d80791a,0x5e4801d5}},	//   mnom, _apāṅ, äher_, _опам_, 
   {{0x60c0791b,0x9e640046,0x58f80135,0x5be0791c}},	//   lnom, _جارن, _དངངས_, _परीव, 
   {{0x5d8456a7,0xe6bc1715,0x60c0791d,0x1d2400c7}},	//   _جلال, ोवैज, onom, _рмем, 
   {{0x60c01a82,0x2b4c00ad,0x00000000,0x00000000}},	//   nnom, btec_, --, --, 
   {{0x59b00316,0x2b4c00db,0x60c0791e,0xd7c40108}},	//   ुपहर, ctec_, inom, тёно, 
   {{0x60c001b9,0x6b1000ec,0x00000000,0x00000000}},	//   hnom, _اڀيا, --, --, 
   {{0xddd80316,0x60c0791f,0xa2d400cd,0x00000000}},	//   _patř, knom, भवन्, --, 
   {{0xd7f859df,0x60c07920,0x660003e0,0x00000000}},	//   _оуп_, jnom, _şokt, --, 
   {{0x3254084c,0xded40023,0x53440395,0x00000000}},	// [8fd0] лвар, ይሽን_, ъхва, --, 
   {{0x8234182c,0x60c07921,0xc9500022,0x52bc03ba}},	//   لرما, enom, _стәы, ्वेस, 
   {{0xa2b87922,0x30140137,0x60c001d5,0xfa340092}},	//   ्वज्, гдер, fnom, _በአሕዛ, 
   {{0xc95000c8,0xf0e8104b,0xe72c03e6,0xde4400d1}},	//   ימע_, رىشى_, _بڵێ_, ۇرىۋ, 
   {{0xbf640228,0x2b4c0077,0x6e940131,0x00000000}},	//   لدوو, xtec_, лиду, --, 
   {{0x60c07923,0x2378010f,0x00000000,0x00000000}},	//   anom, _אָלמ, --, --, 
   {{0xed587924,0x60c001d5,0x2b4c00d7,0x200c02f0}},	//   хой_, bnom, wtec_, émií_, 
   {{0x628801b8,0xcdc000d1,0x00943f1d,0x00000000}},	//   öfov, лаһқ, _кисэ, --, 
   {{0x7c641e87,0x2b4c00d8,0xa2b807b6,0x0094009d}},	//   شايل, utec_, ्वच्, _титэ, 
   {{0xc33404ae,0x00000000,0x00000000,0x00000000}},	//   בוץ_, --, --, --, 
   {{0x2b4c7925,0x29100240,0xafe401af,0x00000000}},	//   stec_, ëza_, _роҡл, --, 
   {{0xe7387926,0x3da47927,0x93e00490,0xe5a401d5}},	//   нем_, _труб, _खरंच_, қиби, 
   {{0x229401bf,0xfcf001f3,0x00000000,0x00000000}},	//   _kækt_, _ግምጃ_, --, --, 
   {{0x5fb47928,0x60c07929,0x7aa401ec,0x5ba001af}},	//   _आइसल, znom, _киіз, _ыһығ, 
   {{0x64a4792a,0x60c0792b,0xc9840454,0x30f400cd}},	//   гава, ynom, _шуди, ेदाः_, 
   {{0xd464792c,0x66e401b9,0xfde80c70,0x00000000}},	//   лисе_, тоҳа, टेटस_, --, 
   {{0x60c0792d,0x78bc0165,0x00000000,0x00000000}},	// [8fe0] vnom, èrve, --, --, 
   {{0x9a8c0023,0x60c0012d,0x00000000,0x00000000}},	//   _ዝወዓለ_, wnom, --, --, 
   {{0x60c0792e,0x26d802e3,0x762401c6,0xd12c00ae}},	//   tnom, _ikpo_, _өмөз, كمل_, 
   {{0x60c00099,0x6024792f,0x00000000,0x00000000}},	//   unom, удда, --, --, 
   {{0x14d40375,0x5be00118,0x00000000,0x00000000}},	//   _תוכל_, _परेव, --, --, 
   {{0xac940014,0x7cc8013a,0x00000000,0x00000000}},	//   یۆلا_, děra, --, --, 
   {{0x5c040064,0xae7000d1,0x00000000,0x00000000}},	//   ляпа, تۇلغ, --, --, 
   {{0xd7d800b5,0x10a00f5c,0x60c001b9,0x3074004e}},	//   deノ_, _лисн, qnom, _куус, 
   {{0x26d801f2,0x92d40183,0x00000000,0x00000000}},	//   _okpo_, াগৰ_, --, --, 
   {{0x3eb87930,0xad24009a,0x00000000,0x00000000}},	//   _ört_, _چرنو, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x26d802e3,0x1be4036b,0xe8ec05d9,0xd61000f7}},	//   _akpo_, _йўлг, وڻي_, өзмө, 
   {{0x9b940691,0x229402d2,0x629c602c,0xc7c8008e}},	//   _حشاش, _jæks_, kkpo, гыре_, 
   {{0x386c7931,0x629c01f5,0x00000000,0x00000000}},	//   žer_, jkpo, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x26d801f2,0x89307932,0x629c01f5,0x00000000}},	//   _ekpo_, _اعوا, ekpo, --, 
   {{0x26d803a0,0xf3f87933,0x481401f4,0x00000000}},	// [8ff0] _fkpo_, тнаш_, _умыс, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x318401ec,0x2294032e,0x00000000,0x00000000}},	//   штаң, _rækt_, --, --, 
   {{0x6f0c1dec,0x657800b5,0x629c7934,0x395c045a}},	//   íaco, æthe, akpo, _mpvs_, 
   {{0x1ee80133,0x2ef40166,0x00000000,0x00000000}},	//   چونی_, аздр, --, --, 
   {{0x1ee87935,0x53e40588,0x628801b8,0x00000000}},	//   نونی_, _ацҳа, öfot, --, 
   {{0x200c0008,0x41e41fe2,0x6da47936,0x00000000}},	//   ækið_, _гіта, рийа, --, 
   {{0x61f80321,0x45b800df,0x00000000,0x00000000}},	//   _útla, טפול_, --, --, 
   {{0xdcac0075,0xeb04147e,0xc0c8010a,0x00000000}},	//   بىي_, јпоп, _суре_, --, 
   {{0x7d2000e4,0xeab000ae,0x00000000,0x00000000}},	//   ñysé, تعب_, --, --, 
   {{0x7cc8012c,0x6f1803cb,0x00000000,0x00000000}},	//   měrn, lpwc, --, --, 
   {{0xac187937,0xa3e40037,0x00000000,0x00000000}},	//   _роду_, _फरल_, --, --, 
   {{0xb9400092,0xd72400c7,0x00000000,0x00000000}},	//   _ተደርጎ, аҭыҧ_, --, --, 
   {{0xd99404d3,0x00000000,0x00000000,0x00000000}},	//   انێت_, --, --, --, 
   {{0xb82400bd,0x6ecc1fe7,0xd6247938,0x4de000cc}},	//   _ভারত_, _तदनु, росе_, _পলুৱ, 
   {{0x2d740b23,0xf4940816,0x00000000,0x00000000}},	//   _māe_, брую, --, --, 
  
   {{0xd4647939,0xe21400f7,0x6b88004e,0x232801d5}},	// [9000] шите_, لباع, nxeg, този_, 
   {{0x26d8063f,0x2214013e,0x395c00d8,0x528006ed}},	//   _ukpo_, рфар, _ypvs_, огуб, 
   {{0x5be04438,0xa06848b6,0xe0443298,0x00000000}},	//   _पर्व, кажа_, инжи, --, 
   {{0xb9dc0023,0x19540a7c,0x629c007c,0x00000000}},	//   _ኣዚ_, יבעל_, skpo, --, 
   {{0x1fb40798,0x00000000,0x00000000,0x00000000}},	//   јсер, --, --, --, 
   {{0xcee40a0e,0x920000de,0x00000000,0x00000000}},	//   адче_, _šāvi, --, --, 
   {{0x7d782dcd,0xdca406dc,0xe0d801a9,0x9d640139}},	//   امبر_, ишип, _авв_, рүең_, 
   {{0x3b8401e0,0xe7b40118,0xbc64035b,0x00000000}},	//   йһег, ívěš, схкқ, --, 
   {{0x8fa00021,0x1e84793a,0x7cc80118,0xfe78014b}},	//   _дате, _клам, běrn, _бӯй_, 
   {{0x23980024,0x38a806af,0xdee463dd,0x8e4400f7}},	//   mąją_, _mûre_, _този, _ەلەك_, 
   {{0xdca43e1e,0x00000000,0x00000000,0x00000000}},	//   _кажи, --, --, --, 
   {{0x57a407d6,0x2d94793b,0x239c00ef,0x97a4146a}},	//   ашга, _урус, _kājā_, аргл, 
   {{0x23980153,0x4c38010f,0x00000000,0x00000000}},	//   nąją_, _יגאצ, --, --, 
   {{0x0570044e,0x7d08793c,0x239c005f,0x2d3c0023}},	//   _ብግቡእ_, _kuds, _mājā_, _ከርእየ, 
   {{0x7d08007f,0x98c4023a,0x239c0055,0xfbd800cc}},	//   _juds, _вспл, _lājā_, দেশত, 
   {{0x7d08014f,0x3a2c0175,0xd8380024,0x00000000}},	//   _muds, ladp_, _рэк_, --, 
   {{0x78bc793d,0x7d08793e,0x23980153,0x66800014}},	// [9010] misv, _luds, jąją_, زیێل, 
   {{0x7d08793f,0x776c7940,0x78bc7941,0x239800c0}},	//   _ouds, _isax, lisv, dąją_, 
   {{0x3a840ed1,0x2fc41945,0x7cc80118,0x506401a9}},	//   ﺭﺳﯘﻥ_, әрең, věrn, итда, 
   {{0x78bc7942,0xa1480014,0x6288007c,0x00000000}},	//   nisv, اسٕے_, öfor, --, 
   {{0x45240003,0x7d087943,0x8fc41291,0x23980064}},	//   _འཆོར_, _auds, جزان, gąją_, 
   {{0x7d087944,0x6da4036b,0x78bc7945,0xada42cdb}},	//   _buds, йила, hisv, йалл, 
   {{0xfe707946,0x25a402a8,0xdd8c42b5,0x78bc0aab}},	//   بدن_, _ƙoli_, فوو_, kisv, 
   {{0x6b8801c4,0x3f9806be,0x00000000,0x00000000}},	//   txeg, _əruz_, --, --, 
   {{0x78bc7947,0x997000bc,0xe4f8258d,0x00000000}},	//   disv, měře_, ्दति_, --, 
   {{0x7cc800bc,0x27e4031c,0xfe70007b,0x00000000}},	//   běro, _ġon_, _يدل_, --, 
   {{0xf7680d65,0x6f0804cf,0xe8f87948,0x27e4009b}},	//   _רק_, _huec, лло_, _šon_, 
   {{0x6f087949,0x78bc794a,0x6f000332,0xeaa401d9}},	//   _kuec, gisv, _hilc, _گٕتَ, 
   {{0x6f083d35,0x78bc0066,0x00000000,0x00000000}},	//   _juec, èrva, --, --, 
   {{0x6f08794b,0x6f00794c,0x78bc01f4,0x41d003ce}},	//   _muec, _jilc, aisv, _तुझस, 
   {{0x6f00794d,0x776c056a,0x6f08067c,0x38a8004a}},	//   _milc, _esax, _luec, _sûre_, 
   {{0xd1c8001f,0xb8dc03d4,0x92d400eb,0x78bc0055}},	//   ቢነት_, _অৱ_, াগো_, cisv, 
   {{0x6f08794e,0xa3e801c0,0x7cec06af,0x6f000857}},	// [9020] _nuec, удаа_, qûre, _oilc, 
   {{0x6454794f,0x239c0a28,0x2a647950,0x9f400241}},	//   sfyi, _rājā_, nelb_, _áké_, 
   {{0xed4416cb,0x6f08003a,0x00000000,0x00000000}},	//   _تھ_, _auec, --, --, 
   {{0x6f087951,0x7d080738,0x9f8400fd,0x6f0036f4}},	//   _buec, _ruds, йгед, _ailc, 
   {{0x7d0804b9,0xdee47952,0x6f007953,0x6f087954}},	//   _suds, боди, _bilc, _cuec, 
   {{0xf424038f,0x6f087955,0x7d08037e,0x6f000142}},	//   _འབོད_, _duec, _puds, _cilc, 
   {{0x44207956,0x7d087957,0x6f007958,0x6f087959}},	//   obi_, _quds, _dilc, _euec, 
   {{0x4420795a,0x3ebc795b,0x6f0001ab,0x9be40220}},	//   nbi_, sivt_, _eilc, йіпк, 
   {{0x7d080204,0x78bc06ea,0x4420795c,0xcb0401c0}},	//   _wuds, visv, ibi_, йхэд_, 
   {{0x6f000649,0xd918115c,0x4420795d,0x7d08795e}},	//   _gilc, льм_, hbi_, _tuds, 
   {{0x6f080048,0x4420079b,0x78bc795f,0x7d080037}},	//   _zuec, kbi_, tisv, _uuds, 
   {{0xdee4187d,0x442016a3,0x6f08022e,0x00000000}},	//   _тоҷи, jbi_, _yuec, --, 
   {{0x4420341a,0x6f0001d5,0x00480023,0x43b400cd}},	//   dbi_, _yilc, _መኮንና, ूपोऽ, 
   {{0x7bdc046c,0x44207960,0x78bc7961,0x58f80327}},	//   ğrud, ebi_, sisv, _དངམས_, 
   {{0xded4067d,0x67200023,0xc9f000cf,0xca7000f1}},	//   _ይኹን_, _çojn, _ىسىع, _راوغ, 
   {{0x442005bb,0x10d401ec,0x00000000,0x00000000}},	//   gbi_, _ﺘﻌﺎﻨ, --, --, 
   {{0x248c069c,0x776c0009,0xb7880bd6,0x99700118}},	// [9030] _ነገራት_, _usax, _тәне_, věře_, 
   {{0x44207962,0x6f0835c0,0x00000000,0x00000000}},	//   abi_, _ruec, --, --, 
   {{0x44207963,0xa5c001ec,0x614400d1,0x00000000}},	//   bbi_, _жөте, قىلە, --, 
   {{0x6f00058a,0x44200067,0xc3300014,0x1b1c00eb}},	//   _silc, cbi_, بٕے_, _দিনই_, 
   {{0x7c2008a5,0x6f081bb7,0x6f007964,0xddd800fd}},	//   dbmr, _quec, _pilc, _patş, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfe707965,0x31347966,0x6f007967,0x6f080036}},	//   عده_, _фебр, _vilc, _wuec, 
   {{0x320c0e2d,0x6b580139,0x00000000,0x00000000}},	//   _şeyh_, ашор_, --, --, 
   {{0xddd80139,0x00000000,0x00000000,0x00000000}},	//   _tatş, --, --, --, 
   {{0x44207968,0x693c0092,0x00000000,0x00000000}},	//   zbi_, _በተገቢ, --, --, 
   {{0xa8887969,0x4420796a,0xbe8800d8,0x00000000}},	//   айна_, ybi_, _усте_, --, 
   {{0x6aa00010,0x6ed000bc,0x00000000,0x00000000}},	//   sklf, धवकु, --, --, 
   {{0x2cac019b,0xe1e409fa,0x44201fe6,0xe4f800dc}},	//   mhed_, _कर्ण_, vbi_, ्दसि_, 
   {{0x2cac796b,0xf4240003,0xa9a4796c,0x26dc796d}},	//   lhed_, _འབུད_, _милд, ôto_, 
   {{0x4420796e,0xe5a40a5b,0xf1d804af,0xe4d805af}},	//   tbi_, циви, _बुलन, لوست_, 
   {{0x4420796f,0x2cac04ce,0x00000000,0x00000000}},	//   ubi_, nhed_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [9040] --, --, --, --, 
   {{0x44207970,0x78a4003d,0x614468eb,0x31b400cc}},	//   sbi_, _ċivi, жежа, _জুইশ, 
   {{0xa3e47971,0x2cac7972,0xded402d3,0x98bc48dd}},	//   _फरक_, khed_, _ይኹኑ_, lutā_, 
   {{0x44200429,0x2cac01bf,0xd12c431a,0xd00c0014}},	//   qbi_, jhed_, ئمن_, ٖلن_, 
   {{0x2cac005c,0x00000000,0x00000000,0x00000000}},	//   dhed_, --, --, --, 
   {{0xfd3800c6,0x26c8037e,0x2cac031c,0x00000000}},	//   مكتب_, nnbo_, ehed_, --, 
   {{0xa0687973,0x00000000,0x00000000,0x00000000}},	//   _кава_, --, --, --, 
   {{0x61ec05ce,0x2cac32be,0x657c7974,0x9c700055}},	//   _izbl, ghed_, _mrph, _bhāṭ, 
   {{0x320c4a4a,0x0dc40032,0x9e380aaa,0x3af00022}},	//   _şeyi_, йләй_, _نساء_, hàpe_, 
   {{0x23602a1f,0xdce87975,0x3af000e4,0x00000000}},	//   _mpkj_, ınır, kàpe_, --, 
   {{0x38a80086,0xb39002d3,0xc050001f,0x2cac00b8}},	//   _aûra_, _ቀያድን_, _የምትፈ, bhed_, 
   {{0x7cec019f,0x2cac7976,0x25dc02e5,0x9f400cad}},	//   bûra, ched_, _गड़ी_, _àkó_, 
   {{0x657c7977,0x24900076,0x9c700055,0x07a402d5}},	//   _arph, djym_, _ghāṭ, даўн, 
   {{0xda643738,0x00000000,0x00000000,0x00000000}},	//   _ذاتي, --, --, --, 
   {{0xb5942c68,0x00000000,0x00000000,0x00000000}},	//   чивш, --, --, --, 
   {{0xb78801af,0x00000000,0x00000000,0x00000000}},	//   _ләге_, --, --, --, 
   {{0x657c003a,0xdb040036,0x61f802d2,0x00000000}},	// [9050] _erph, _ëmän, _útlj, --, 
   {{0x2aa87978,0x2cac05c7,0x47340166,0x00000000}},	//   _kúba_, zhed_, _юньс, --, 
   {{0x2cac01bf,0x00000000,0x00000000,0x00000000}},	//   yhed_, --, --, --, 
   {{0x86381540,0x673400e4,0x2cac025c,0x00000000}},	//   _እምነት, _yvyj, xhed_, --, 
   {{0x4f687979,0x2aa80332,0x2cac005c,0xca6801ec}},	//   ршем_, _lúba_, vhed_, _тiзi, 
   {{0x313411ac,0x23f8011a,0x2d940108,0x471c011a}},	//   _негр, _להרא, зрис, סווג, 
   {{0x2cac797a,0x8d7400cf,0x104801f4,0x00000000}},	//   thed_, تاشا, _вязи_, --, 
   {{0xd7d800b5,0x00000000,0x00000000,0x00000000}},	//   meテ_, --, --, --, 
   {{0x2cac019b,0xce681be7,0x00000000,0x00000000}},	//   rhed_, _вред_, --, --, 
   {{0x2cac797b,0x8d8402f2,0xb82403d4,0x2490000f}},	//   shed_, _وشان, _ভাগত_, zjym_, 
   {{0xa968797c,0x6eec00d2,0x248c001f,0xfbd0797d}},	//   щина_, cúba, _ነገሥት_, _یته_, 
   {{0x02b802a0,0x00000000,0x00000000,0x00000000}},	//   _इग्न, --, --, --, 
   {{0x377438be,0x81cc03d4,0x7bdc03e0,0x00000000}},	//   мырс, _লৰা_, ğruc, --, 
   {{0xf1bc4668,0x6720036e,0x3af000e4,0x5fdc0037}},	//   ्पान, _çojm, tàpe_, _फँसल, 
   {{0xa9a405f5,0xe9a4010b,0xa5d405f9,0xf988009f}},	//   _хийд, _хайп, _मुखौ, _ونهي_, 
   {{0xf9901d0a,0x7cc80118,0x2484002e,0x00000000}},	//   _جبه_, věrk, ñom_, --, 
   {{0x6304797e,0x2d8001bf,0x34480108,0x8d480023}},	// [9060] سوال, åhej_, ючён_, _ዘይቅዱ, 
   {{0x2cbc0004,0x2168797f,0x00000000,0x00000000}},	//   _lmwd_, йизи_, --, --, 
   {{0xd24c5662,0x657c03ac,0xa008007b,0x00000000}},	//   انم_, _urph, مقال_, --, 
   {{0xd7540bce,0x98bc0356,0xd00c33ae,0x00000000}},	//   _بلیت_, mută_, هلم_, --, 
   {{0x8fa00a89,0x98bc0311,0xf6280150,0xdee400f3}},	//   наце, lută_, _اسۋى_, поди, 
   {{0x6eec5fbb,0x8c400724,0x00000000,0x00000000}},	//   túba, _ışan, --, --, 
   {{0x49080316,0x98bc0276,0x291001e4,0x61ec7980}},	//   _ठूलो_, nută_, ŭzaj_, _uzbl, 
   {{0xc6ec0327,0x6eec7981,0x00000000,0x00000000}},	//   _རེའུ, rúba, --, --, 
   {{0x2be00490,0x60c00a89,0xd90c01d5,0x92bc00fe}},	//   _पडणा, miom, گیب_, ঁকৰ_, 
   {{0x60c07982,0xd1cc0023,0x3914004e,0x00000000}},	//   liom, ኣይቲ_, ммор, --, 
   {{0x80b01d8a,0xd90c7983,0xd5d80a8a,0x00000000}},	//   ंसपे, دیب_, _मुंज, --, 
   {{0x60c07984,0x00000000,0x00000000,0x00000000}},	//   niom, --, --, --, 
   {{0xcb6400d8,0x00000000,0x00000000,0x00000000}},	//   _наце_, --, --, --, 
   {{0x60c07985,0x2be00490,0x87040166,0x9fec00fe}},	//   hiom, _पडता, еясе, _ওলাব_, 
   {{0x60c07986,0x08f801b9,0x1d500023,0x00000000}},	//   kiom, تریب_, _ዘይኣመ, --, 
   {{0x6d44000a,0x636001f2,0x2ea87987,0x60c0009f}},	//   šhag, _ọnag, _कत्त, jiom, 
   {{0x78ac7988,0x60c07989,0xb274798a,0xdecc044e}},	// [9070] _ilav, diom, млаш, ኦምን_, 
   {{0x78ac0745,0x95c80e58,0x00000000,0x00000000}},	//   _hlav, _гума_, --, --, 
   {{0x98bc084c,0xca680408,0x00000000,0x00000000}},	//   cută_, _тiеi, --, --, 
   {{0x38b800e4,0x743400df,0x00000000,0x00000000}},	//   tĩry_, _קאָנ_, --, --, 
   {{0xb4e817ee,0x78ac009b,0xc0bc0092,0x00000000}},	//   यती_, _mlav, ዲሠራ_, --, 
   {{0x78ac798b,0xad2400db,0x9268798c,0x00000000}},	//   _llav, ورعو, _урма_, --, 
   {{0x78ac798d,0x60c0798e,0xa2c01a98,0xed580a89}},	//   _olav, biom, _рәтк, цой_, 
   {{0x60c0798f,0xeeec000d,0x1e100166,0x00000000}},	//   ciom, _चीरऽ_, нмәя, --, 
   {{0x98bc0276,0x0a380092,0x00000000,0x00000000}},	//   zută_, _በአማራ, --, --, 
   {{0x78ac7990,0xb4e80a28,0x25dc000d,0x0a380092}},	//   _alav, यतु_, _गडली_, _በአመራ, 
   {{0x78ac3f3f,0xbe880cab,0x69246b2f,0x68440166}},	//   _blav, _эсте_, ьмна, мнна, 
   {{0x7ae8009a,0x644801ed,0x3078008f,0x00000000}},	//   aldt, őfiz, קאָנ, --, 
   {{0x6d44000a,0x99d0107f,0xeb987991,0x7d040115}},	//   šhad, فقیت, _фил_, ĉist, 
   {{0x78ac7992,0xa5087993,0x60c07994,0x98bc054e}},	//   _elav, жева_, ziom, tută_, 
   {{0x60c0009a,0x64980b01,0x55e07995,0x00000000}},	//   yiom, отар_, ворб, --, 
   {{0x61f87996,0x98bc0311,0xe45801d5,0x00000000}},	//   _útli, rută_, ўжа_, --, 
   {{0x68f4035a,0x98bc0356,0x1bf8010f,0x00000000}},	// [9080] _ihyd, sută_, ַלעב, --, 
   {{0x62641b06,0x78ac0030,0x98bc0311,0x660400cf}},	//   بارق, _zlav, pută_, _оппа, 
   {{0x60c07997,0x5ab4031c,0x21180214,0x6138011c}},	//   tiom, ྒྲིམ, زتاب_, ючар_, 
   {{0xc33007d2,0x00000000,0x00000000,0x00000000}},	//   _مەر_, --, --, --, 
   {{0x3eac0280,0x7ae826ff,0x9ff8007b,0xffa4009d}},	//   _pldt_, yldt, آراء_, элдү, 
   {{0x60c07998,0x2be005f9,0xdcf80010,0xcd300131}},	//   siom, _पड़ा, _vrtč, ھرىب, 
   {{0x20540220,0x68f40210,0x00000000,0x00000000}},	//   _отар, _ohyd, --, --, 
   {{0x5ba402bf,0x2fd801d3,0x68f40042,0xbb74399f}},	//   дроз, éggé_, _nhyd, егиј, 
   {{0xcb640640,0x63b40034,0x539800df,0x00000000}},	//   дање_, nzyn, ַסטא, --, 
   {{0x1ea805d9,0xd6f800b5,0x00000000,0x00000000}},	//   _باري_, tyキ_, --, --, 
   {{0x7ae875fa,0x248c010c,0x00000000,0x00000000}},	//   rldt, _ነገስት_, --, --, 
   {{0xad6405d9,0x68f47999,0x00000000,0x00000000}},	//   _سامه, _chyd, --, --, 
   {{0xe81c0034,0x78ac799a,0x27f00210,0x00000000}},	//   पड़ा_, _vlav, _czyn_, --, 
   {{0x68f4035a,0x63b4012d,0x00000000,0x00000000}},	//   _ehyd, dzyn, --, --, 
   {{0x68f40175,0x00000000,0x00000000,0x00000000}},	//   _fhyd, --, --, --, 
   {{0xb4e81161,0x78ac799b,0x2d8003cd,0x176801f4}},	//   यते_, _ulav, åhei_, _дроп_, 
   {{0x5fdc044b,0x63b400a2,0x0744009d,0x00000000}},	// [9090] _फुलल, gzyn, _ихэм, --, 
   {{0xd2580006,0xc7d8011a,0x00000000,0x00000000}},	//   ўца_, _קוזי_, --, --, 
   {{0xd1381f39,0x00000000,0x00000000,0x00000000}},	//   юха_, --, --, --, 
   {{0x92cc045e,0x92bc015b,0x339406a6,0x27f000a2}},	//   শতে_, ঁকে_, _замё, _yzyn_, 
   {{0x63b4006d,0x7fd402dd,0x6ef408a5,0x00000000}},	//   czyn, кіші, _nýbý, --, 
   {{0xeb98013e,0x4e88005b,0x394c01bf,0x2aa80248}},	//   ҷии_, ющем_, kuds_, _rúbo_, 
   {{0x201000c6,0x394c01e3,0x5f0001ec,0xf1d8000d}},	//   íniú_, juds_, ызша, _बँटन, 
   {{0xeb98799c,0x394c0280,0x0d38069d,0x506401a9}},	//   зии_, duds_, _አይፈል, _ютга, 
   {{0x68f400a9,0x1ee85dcd,0xfe6c799d,0xff5047e7}},	//   _rhyd, _کولی_, _кү_, _نخل_, 
   {{0x94040085,0xe75c0113,0xe7d84668,0x9f400248}},	//   ɔnɔ_, j鯵a_, _युगप, _áká_, 
   {{0xa8c4799e,0xa9a4004e,0x00000000,0x00000000}},	//   ейнд, хинд, --, --, 
   {{0xb4e85347,0x00000000,0x00000000,0x00000000}},	//   यतो_, --, --, --, 
   {{0xf0ac02dd,0x6298033b,0xaa44792b,0x00000000}},	//   рдiң_, _òtog, _зелл, --, 
   {{0x9f5401ed,0x8f48001f,0x68f40165,0xab60010e}},	//   égét_, _ዓይነቶ, _whyd, _şüwe, 
   {{0xc44801d5,0x7ae40022,0x68f40042,0x24f43d89}},	//   ویدن_, _êita, _thyd, ечар, 
   {{0x92bc02f5,0x92cc009e,0x996c0213,0x00000000}},	//   ঁকো_, শতো_, ləş_, --, 
   {{0xe3b876b8,0xd8d400c8,0x27f000ee,0xa804013d}},	// [90a0] чба_, _רופט_, _uzyn_, _язил, 
   {{0x63b4068f,0x996c00ac,0xd12c0133,0x00000000}},	//   rzyn, nəş_, ڵمه_, --, 
   {{0x63b4068f,0xa0a4023a,0x85580214,0x00000000}},	//   szyn, нажд, _تیزر_, --, 
   {{0xd12c06f6,0x11d4007b,0xc32400cc,0x224415b7}},	//   صمه_, رونة_, _পিঠি_, şok_, 
   {{0xdfd07427,0x00000000,0x00000000,0x00000000}},	//   ديش_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x91e0799f,0x00000000,0x00000000,0x00000000}},	//   _сосе, --, --, --, 
   {{0x394c0204,0x2b4c180f,0xda7879a0,0x69d4002d}},	//   wuds_, guec_, пян_, ûzen, 
   {{0x394c79a1,0x6298007f,0x6d4400d7,0x00000000}},	//   tuds_, _òtod, áhac, --, 
   {{0xd2b40302,0xf8b80137,0xdd902372,0x69dc0205}},	//   גלית_, дөп_, _حوض_, şsen, 
   {{0xad240c8b,0x61f879a2,0x7ae401e4,0x394c4836}},	//   _شرمو, _útlu, _ŭitd, ruds_, 
   {{0x1be84965,0xd90c00f2,0xf3340023,0x00000000}},	//   _эдди_, _گیج_, ባብትና, --, 
   {{0xb4e80882,0xcf90010f,0x394c79a3,0xb994007b}},	//   यत्_, אטש_, puds_, _للتب, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x325479a4,0xcb10008f,0xd6300014,0x00000000}},	// [90b0] квар, ָלע_, _یِکھ, --, 
   {{0x50a031f0,0x00000000,0x00000000,0x00000000}},	//   گەرل, --, --, --, 
   {{0x3f8479a5,0x35f42773,0x00000000,0x00000000}},	//   _armu_, _шпор, --, --, 
   {{0x90e479a6,0x50a00328,0x2ea841ac,0x8d800092}},	//   رسان, دەرل, कस्त, ናውቀው_, 
   {{0x73c40598,0x6434008f,0x00000000,0x00000000}},	//   _рәве, _בארא_, --, --, 
   {{0x7bdc4953,0x3f84020c,0xc0dc02d3,0x09d800cc}},	//   ğrul, _drmu_, _ንገለ_, ডেটা, 
   {{0xdd8c00cf,0xa2ac06b1,0x7bdc03e0,0x85040345}},	//   قوو_, ंघर्, şrul, _جوێن, 
   {{0x0cbc02f5,0x00000000,0x00000000,0x00000000}},	//   উক্ত, --, --, --, 
   {{0x7e6401d3,0x00000000,0x00000000,0x00000000}},	//   őipa, --, --, --, 
   {{0xf1d429d9,0x2b4c1c69,0xe8c800dc,0x7e7400cf}},	//   _दशान, ruec_, ाच्च, _مامئ, 
   {{0x98bc762b,0xcd2843b1,0xe81c0073,0x00000000}},	//   lutę_, _رسان_, पडला_, --, 
   {{0xe73879a7,0x2d8479a8,0xa8a000d1,0x00000000}},	//   мем_, _irle_, рғиқ, --, 
   {{0x98bc79a9,0x2d840fcf,0xae141524,0xa038008f}},	//   nutę_, _hrle_, _ढलान_, וערפ, 
   {{0x2d8479aa,0x9d40001f,0x21380455,0x3ce000d7}},	//   _krle_, ረጃችሁ, ysph_, čive_, 
   {{0xca700220,0x00000000,0x00000000,0x00000000}},	//   _ауқы, --, --, --, 
   {{0x81e8009e,0x2d8401a6,0xd4640276,0xde400092}},	//   মেড_, _mrle_, кисе_, _የጎደለ, 
   {{0x78bc0240,0xc44801d5,0x98bc00c0,0x00000000}},	// [90c0] ërve, ویگن_, jutę_, --, 
   {{0x2d8479ab,0x20d400d1,0x98bc00c0,0x00000000}},	//   _orle_, ھتاج, dutę_, --, 
   {{0x41440150,0x00000000,0x00000000,0x00000000}},	//   удең, --, --, --, 
   {{0x251c0521,0x00000000,0x00000000,0x00000000}},	//   _ọnwụ_, --, --, --, 
   {{0x2d845c2f,0xd00479ac,0x213801e4,0x00000000}},	//   _arle_, веце_, ssph_, --, 
   {{0x2d8401a6,0x3d280248,0x00000000,0x00000000}},	//   _brle_, _nìwò_, --, --, 
   {{0x127800c8,0x163400df,0x7bdc03e0,0x00000000}},	//   _קאלע, דנצר_, ğrum, --, 
   {{0x10a079ad,0x98bc00c0,0x9cc80022,0x00000000}},	//   _кисн, butę_, ьыла_, --, 
   {{0x5f0479ae,0x1cb4031c,0x98a000b0,0xfb8479af}},	//   _азаа, ྜིཏ_, ōkī_, ادبی, 
   {{0x9f041077,0x2edc01bc,0xdde80633,0xdb200210}},	//   _شواو, यवृत, _قرضه_, _żród, 
   {{0x2d840e3c,0xddd802b1,0x6da003f9,0x9c640244}},	//   _grle_, _matū, rɓac, _لهاو, 
   {{0x7b845a05,0xd7f879b0,0x9ba001ec,0x8c400006}},	//   _ماتە, дуг_, _نەعى, _веце, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xddd802d5,0x6eec00d2,0x66000115,0xc0d00023}},	//   _natū, gúbh, _ŝoka, _ቦኽሪ_, 
   {{0x98bc033f,0x00000000,0x00000000,0x00000000}},	//   zutę_, --, --, --, 
   {{0x628c79b1,0x97a400c7,0x00000000,0x00000000}},	//   _anbo, _арол, --, --, 
   {{0xc8c8009f,0x841479b2,0x00000000,0x00000000}},	// [90d0] _جوين_, рмух, --, --, 
   {{0xddd800b8,0x6eec00d7,0x83f8011c,0x59c4000d}},	//   _catū, rúbk, теус_, _लधार, 
   {{0x3d1800e8,0x00000000,0x00000000,0x00000000}},	//   _néw_, --, --, --, 
   {{0x628c79b3,0xd3440133,0x06d80154,0x0584030d}},	//   _enbo, _لیره_, _দীপি, _туьм, 
   {{0xb4c058c1,0xb4b40022,0x6f64007b,0x61e003e0}},	//   ्ची_, _аиҟә, اهتم, ğola, 
   {{0x76540399,0x518400c7,0x81e800fe,0x02a4009b}},	//   ngzy, _иуба, মেধ_, _крсм, 
   {{0xcb5400b5,0x2ef402dd,0x00000000,0x00000000}},	//   _sボ_, _ұзар, --, --, 
   {{0x7eb400db,0x8b640116,0x4084004e,0x00000000}},	//   _ràpe, впиң_, _кууб, --, 
   {{0x628c0385,0x81e809bd,0xd05802a8,0xa3d4012c}},	//   _ynbo, মেদ_, _shuɗ, िपय_, 
   {{0x9f540158,0x1b200154,0x00000000,0x00000000}},	//   ågås_, _মিশে_, --, --, 
   {{0x2d840356,0x00000000,0x00000000,0x00000000}},	//   _urle_, --, --, --, 
   {{0xc32400bd,0x684479b4,0x00000000,0x00000000}},	//   _পিসি_, ынма, --, --, 
   {{0x2aa80241,0xa88400f7,0x00000000,0x00000000}},	//   _lúbi_, _ەلبى, --, --, 
   {{0x7eb4004e,0x2f1802e2,0x2cac79b5,0x8aa40354}},	//   _tàpe, _mèg_, lked_, _шред, 
   {{0xb4c0069f,0x2f180066,0x3d18002e,0x2cac26de}},	//   ्चू_, _lèg_, _xéw_, oked_, 
   {{0x2cac79b6,0x3210010b,0xe8e805d9,0x672403cd}},	//   nked_, _agzy_, _ڪرڻو_, ppkj, 
   {{0x2f180699,0x2cac0204,0x15880131,0x6a8801c7}},	// [90e0] _nèg_, iked_, _ﻗﯧﺘﯩ, _gëfä, 
   {{0x68e479b7,0x2900058a,0x2cac0037,0x98bc01ef}},	//   lokd, lmka_, hked_, kutě_, 
   {{0x26c879b8,0x2cac0c48,0x80b0033f,0x628c0175}},	//   mibo_, kked_, ंसले, _vnbo, 
   {{0x26c879b9,0x3d1800e8,0xc45403e6,0x00000000}},	//   libo_, _réw_, _خێرب, --, 
   {{0xe3b079ba,0xddd802b5,0x6454013f,0x290079bb}},	//   _طرح_, _tatū, mgyi, imka_, 
   {{0xa11442b5,0x1b200eac,0x26c80113,0x68e401a4}},	//   _موست, _মিলে_, nibo_, hokd, 
   {{0x68e45063,0x00000000,0x00000000,0x00000000}},	//   kokd, --, --, --, 
   {{0x26c879bc,0x645479bd,0x2cac003e,0x00000000}},	//   hibo_, ngyi, gked_, --, 
   {{0x26c879be,0x61ec0368,0xdc280133,0xdd9002dd}},	//   kibo_, _hybl, وسکه_, рақы, 
   {{0x61ec79bf,0x2cac50eb,0x2b5801ab,0x98bc01ef}},	//   _kybl, aked_, àsca_, butě_, 
   {{0x26c879c0,0x1d240114,0x00000000,0x00000000}},	//   dibo_, _смем, --, --, 
   {{0x2cac79c1,0x61ec2b53,0x64540369,0x37d8015b}},	//   cked_, _mybl, jgyi, _সরবর, 
   {{0x9a8479c2,0x29100077,0x26c801bf,0xcc38010f}},	//   _буйл, ízar_, fibo_, _טעאט, 
   {{0x4b7800c8,0x2900294b,0x61ec05ac,0x81a40092}},	//   _נאוו, amka_, _oybl, ለክታሉ_, 
   {{0x61ec0267,0x12e40220,0x68e479c3,0x00000000}},	//   _nybl, ңізг, bokd, --, 
   {{0x645479c4,0xb4c079c5,0x38c8066d,0x1cd0025c}},	//   ggyi, ्चे_, _جاتی_, _ེམས_, 
   {{0x36d4169c,0x26c82f99,0x386879c6,0x61ec07d6}},	// [90f0] _вопр, bibo_, _ibar_, _aybl, 
   {{0x2f180d29,0x26c879c7,0x09d400bd,0x394c79c8}},	//   _règ_, cibo_, _হরতা, ords_, 
   {{0x3868003d,0x69200421,0x30140354,0x61ec0142}},	//   _kbar_, _vēeg, адер, _cybl, 
   {{0x394c039a,0x61ec015d,0xa5600014,0x8d240131}},	//   irds_, _dybl, _گۯہن, қниң_, 
   {{0x61ec06be,0xfeb82162,0x6438010f,0x8f6400e5}},	//   _eybl, گانت_, _בערנ, التے_, 
   {{0x999c0024,0xada42247,0x00000000,0x00000000}},	//   ngtų_, иалл, --, --, 
   {{0x712404a9,0xfeb800e3,0x38680e89,0x2cac00c5}},	//   _خىزم, دانت_, _obar_, tked_, 
   {{0x38680048,0x26c879c9,0x2cac030a,0xae18134e}},	//   _nbar_, zibo_, uked_, नुजन_, 
   {{0x2cac79ca,0xc04c001f,0x26c879cb,0x394c79cc}},	//   rked_, _አምባገ, yibo_, erds_, 
   {{0x2cac79cd,0x386879ce,0x5fdc0073,0x29000009}},	//   sked_, _abar_, _फुटल, wmka_, 
   {{0xe8f83169,0x38680175,0x6e200175,0x00000000}},	//   кло_, _bbar_, _iflb, --, 
   {{0xb4c013da,0x76440882,0x38680175,0x29000014}},	//   ्चो_, _adhy, _cbar_, umka_, 
   {{0x26c835b7,0x29000cf4,0x78bc0240,0x68e479cf}},	//   tibo_, rmka_, ërva, rokd, 
   {{0x38680295,0x2b4c0219,0x29000009,0x00000000}},	//   _ebar_, mrec_, smka_, --, 
   {{0x26c879d0,0xba7479d1,0x660402e8,0xe5041095}},	//   ribo_, _دانت, рпва, لبري, 
   {{0x26c879d2,0x64a479d3,0x794400ae,0x00000000}},	//   sibo_, шаба, _اخوك, --, 
   {{0xd49401fb,0x26c80784,0x22145211,0xc24401e0}},	// [9100] ờng_, pibo_, афер, ймаҫ, 
   {{0x26c879d4,0x00000000,0x00000000,0x00000000}},	//   qibo_, --, --, --, 
   {{0x776c022e,0x6d441d0e,0x00000000,0x00000000}},	//   _zpax, áhal, --, --, 
   {{0x61ec0306,0x64540175,0xe450431a,0x7bdc03e0}},	//   _vybl, qgyi, _بضد_, şrui, 
   {{0x6d4079d5,0x5f04069a,0x00000000,0x00000000}},	//   _avla, азда, --, --, 
   {{0x442079d6,0x2b4c79d7,0x2aa808a5,0x00000000}},	//   lci_, drec_, _kúbu_, --, 
   {{0x9d540107,0x00000000,0x00000000,0x00000000}},	//   рӯзӣ_, --, --, --, 
   {{0x442079d8,0x7eb401e1,0x0ca400c7,0x00000000}},	//   nci_, _dàpa, итыи_, --, 
   {{0x442079d9,0x42680020,0x6d4079da,0xa3d43105}},	//   ici_, _ሳምንት_, _evla, िपि_, 
   {{0x44200097,0x9d4400a7,0x38680142,0xcb04009d}},	//   hci_, _вежд, _sbar_, ихэд_, 
   {{0x81e803f4,0x442079db,0x64440030,0x2b4c0165}},	//   মের_, kci_, _odki, arec_, 
   {{0x442079dc,0x98c479dd,0x9b6879de,0x9200002b}},	//   jci_, рсол, _ашка_, _śāku, 
   {{0x44205e64,0x94741547,0x6d4002fb,0xac7400f1}},	//   dci_, یدرا, _zvla, _دننګ, 
   {{0x442079df,0x64445138,0xe28c01d5,0xb9c40451}},	//   eci_, _adki, hlаb_, _هڪجه, 
   {{0x38a8006a,0x7ae879e0,0x63a0023a,0xaae443fb}},	//   _sûru_, modt, äonn, _اسنو, 
   {{0x6444010a,0x44202959,0x6eec007b,0x38680438}},	//   _cdki, gci_, lúbt, _ubar_, 
   {{0x437402bf,0x490400cf,0x461401d9,0x158800d1}},	// [9110] жуєт, _بويق, _ژوٝر, _ﺗﯧﺨﯩ, 
   {{0xd94c0020,0x442079e1,0xa2c00116,0x00000000}},	//   _በተደጋ, aci_, пәск, --, 
   {{0x442079e2,0x27fc012d,0x00000000,0x00000000}},	//   bci_, ętne_, --, --, 
   {{0x442079e3,0x33280108,0x6d440162,0x6fb829c6}},	//   cci_, ppax_, áham, лгер_, 
   {{0x6d401b24,0x920000e2,0x81e80154,0xddd8013a}},	//   _svla, _šādi, মেল_, _batů, 
   {{0x7eb400a3,0x2b4c68b5,0x00000000,0x00000000}},	//   _pàpa, vrec_, --, --, 
   {{0xada479e4,0xddd8013a,0x7bc40153,0x00000000}},	//   сайл, _datů, _žiup, --, 
   {{0xec7879e5,0x2b4c79e6,0x38a80129,0xe8c40073}},	//   упи_, trec_, _mûrs_, _लगेच, 
   {{0x9f980e78,0xc0c879e7,0x6fa400cc,0x00000000}},	//   mäße_, _туре_, _খেৰে, --, 
   {{0x442079e8,0x2b4c0228,0x7eb40109,0x7ae879e9}},	//   zci_, rrec_, _tàpa, godt, 
   {{0x2b4c014b,0xfe700014,0x6d440109,0xa9680063}},	//   srec_, _زدل_, âhad, ћима_, 
   {{0xefd00125,0x26dc0030,0xbc180220,0xca68022e}},	//   _ቦርድ_, čtom_, _кіші_, _etgа, 
   {{0xef18006d,0x44200118,0x7ae80d27,0xbb580117}},	//   _już_, vci_, bodt, _вачх_, 
   {{0x6444020b,0x44200198,0xe5a479ea,0x9ba0075e}},	//   _sdki, wci_, биги, _رەپى, 
   {{0x442079eb,0xdbd4002f,0xe96801a9,0xefd00092}},	//   tci_, _käßm, _сайл_, _ቦርዴ_, 
   {{0x442079ec,0xe2a82264,0xeff0001f,0x00000000}},	//   uci_, گارن_, ውልድ_, --, 
   {{0x442079ed,0xe21452c8,0x8d78001f,0x4aa80037}},	// [9120] rci_, مباع, _ኮሚቴው_, _छवाव, 
   {{0x29104ba8,0xe2a879ee,0x22140024,0x00000000}},	//   _hiya_, دارن_, сфар, --, 
   {{0x291079ef,0x9f980e78,0xa6c801d3,0x544000d1}},	//   _kiya_, fäße_, _لوکل_, زنەك, 
   {{0x291079f0,0xe0d80c98,0x644400b5,0x27f0023a}},	//   _jiya_, ыве_, _udki, _kyyn_, 
   {{0x291079f1,0x81e8009e,0x8e4400d1,0xaf8400fb}},	//   _miya_, মেং_, ڭلىك_, оҡта_, 
   {{0x291079f2,0x27f0005b,0x00000000,0x00000000}},	//   _liya_, _myyn_, --, --, 
   {{0x291079f3,0xd1b02832,0x5cc407d6,0x00000000}},	//   _oiya_, _ٹینک, йсиз, --, 
   {{0x291079f4,0x3ce005ce,0x7ae8014f,0xd1b0104c}},	//   _niya_, čivo_, wodt, _عینک, 
   {{0xdca46294,0x5d840050,0x00000000,0x00000000}},	//   _қади, _گلال, --, --, 
   {{0x9e6479f5,0x291079f6,0xeff002d3,0x657c127b}},	//   _دارن, _aiya_, ልፍዎ_, _osph, 
   {{0x291079f7,0x7ae87861,0x27f0010e,0x38c879f8}},	//   _biya_, rodt, _ayyn_, لاحی_, 
   {{0x7ae879f9,0x291079fa,0x00000000,0x00000000}},	//   sodt, _ciya_, --, --, 
   {{0x657c79fb,0x291079fc,0x38a806af,0x6e340241}},	//   _asph, _diya_, _sûrs_, _ògbà, 
   {{0x7ae8014f,0x3ebc0051,0x00000000,0x00000000}},	//   qodt, nhvt_, --, --, 
   {{0x291079fd,0x7eb401e1,0x00000000,0x00000000}},	//   _fiya_, _làpo, --, --, 
   {{0x291079fe,0xefd0001f,0x00000000,0x00000000}},	//   _giya_, _ቦርዱ_, --, --, 
   {{0x657c014b,0x7eb41f40,0x670002e3,0x439479ff}},	// [9130] _esph, _nàpo, ịkar, патс, 
   {{0x2910021a,0x00000000,0x00000000,0x00000000}},	//   _ziya_, --, --, --, 
   {{0xfa540020,0x74140228,0x71787a00,0x29107a01}},	//   _ጉዳተኞ, _وودا, рбер_, _yiya_, 
   {{0x291007a9,0x6fb40a2c,0x00000000,0x00000000}},	//   _xiya_, يماا, --, --, 
   {{0xa2c00248,0xdef00023,0xbee401f9,0x00000000}},	//   _kọ̀m, ልጽን_, गवून_, --, 
   {{0x6b8c1e31,0x867c008f,0x657c7a02,0x31340884}},	//   _šago, ָרהו, _ysph, _мегр, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xef18033f,0x78bc017a,0x2ca800d1,0x00000000}},	//   _tuż_, ërvl, ркип_, --, 
   {{0x29107a03,0xeab828a9,0x490401c0,0x6e98009b}},	//   _riya_, ийи_, үүлг, _квар_, 
   {{0x29107a04,0x8fd0052f,0xddd8002d,0x7eb400e8}},	//   _siya_, _мәҙә, _entű, _jàpl, 
   {{0x29107a05,0xedd400f1,0x27f0005b,0x7b640014}},	//   _piya_, _بياد, _syyn_, _ہاوٕ, 
   {{0x29107a06,0xb90801d9,0x00000000,0x00000000}},	//   _qiya_, ٝزُم_, --, --, 
   {{0xaa44074d,0x00000000,0x00000000,0x00000000}},	//   _делл, --, --, --, 
   {{0x6b887a07,0x29d401a9,0x00000000,0x00000000}},	//   mveg, _мўйс, --, --, 
   {{0x29107a08,0x04180055,0x225c00a2,0x7bdc0b97}},	//   _tiya_, _kūḍa, _ötki_, şrut, 
   {{0x657c019b,0x78bc3262,0xa3d4121d,0x00000000}},	//   _vsph, chsv, िपल_, --, 
   {{0x6b887a09,0xb8644d2d,0x23480075,0xd384016a}},	// [9140] nveg, _رايو, شلاپ_, ойте_, 
   {{0xe68800db,0x33d402bf,0xc3300131,0x69c00076}},	//   _ئندى_, чіст, _ۋەز_, ozle, 
   {{0x64a47a0a,0x69c022f8,0x00000000,0x00000000}},	//   _дана, nzle, --, --, 
   {{0xa0687a0b,0x7eb4067c,0x69c07a0c,0xd5f808a8}},	//   рада_, _pàpo, izle, _כפיר, 
   {{0xdb0c0122,0x5f740137,0xdef00023,0x00000000}},	//   ždém, تاار, ውጽእ_, --, 
   {{0x6b887a0d,0xdb040793,0xb3541079,0x57f8011a}},	//   dveg, ämük, _ریما_, בלנו, 
   {{0x20d40212,0xdcb80d1d,0xcd24119e,0x00000000}},	//   _діас, ищи_, ожје_, --, 
   {{0xa3ac098b,0x041800b8,0x7bc0002f,0x00000000}},	//   _कथा_, _cūḍa, tzmu, --, 
   {{0x320c7a0e,0x92bc03d4,0xcc30009f,0x00000000}},	//   _şeyx_, ুকৰ_, ذريع, --, 
   {{0x0f78010f,0x7bc02016,0xdb2001e1,0xbab8009d}},	//   _דאמב, rzmu, _àríd, сгох_, 
   {{0x999c00b0,0x7e780455,0x79f402e8,0xdee80092}},	//   matū_, mevp, язох, _ህሊና_, 
   {{0x7bdc002f,0x00000000,0x00000000,0x00000000}},	//   ßrus, --, --, --, 
   {{0xd7f87a0f,0x7bdc06b9,0x69c0030a,0xacd8010f}},	//   рун_, ğrus, azle, _פֿעי, 
   {{0x999c04fe,0x96e80108,0x00000000,0x00000000}},	//   natū_, рьма_, --, --, 
   {{0x9ba00131,0x89f402dd,0x3a3c00ef,0x27fc012d}},	//   _رەھى, _وعىز_, _ievp_, ętna_, 
   {{0xb4b40034,0x999c1d76,0xe27400f7,0x0b40010b}},	//   झसे_, hatū_, үктө, _энән, 
   {{0x372403bd,0x999c0053,0xf3f400f2,0x00000000}},	// [9150] _འཕྲལ_, katū_, سترک, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x61442928,0x6b88004c,0x7e780477,0xa694011a}},	//   كىلە, zveg, devp, _זכתה_, 
   {{0xef980228,0x2248005a,0xd3441927,0x6b88035b}},	//   йкеш_, _edbk_, _ویزه_, yveg, 
   {{0xa3d400cd,0x00000000,0x00000000,0x00000000}},	//   िपः_, --, --, --, 
   {{0x660000df,0xc7d8011a,0x0ee8035b,0x00000000}},	//   _ŝoki, חודי_, шьеи_, --, 
   {{0x313400ea,0x31a43fe6,0x00000000,0x00000000}},	//   _хебр, _عمرف, --, --, 
   {{0x6b8809f3,0x3134136b,0x00000000,0x00000000}},	//   tveg, _меҳр, --, --, 
   {{0x8d940092,0x00a40345,0x00000000,0x00000000}},	//   ግራቸው_, _تینێ, --, --, 
   {{0x69c07a10,0x7e780010,0x00000000,0x00000000}},	//   tzle, cevp, --, --, 
   {{0x6b887a11,0x00000000,0x00000000,0x00000000}},	//   sveg, --, --, --, 
   {{0x69c00a40,0xeff002d3,0x00000000,0x00000000}},	//   rzle, _ውሉድ_, --, --, 
   {{0x69c0066d,0xbca4007b,0x61e00205,0x00000000}},	//   szle, _تمني, ğoli, --, 
   {{0xdb1c0798,0x92bc0154,0xd6247a12,0x69240798}},	//   _évál, ুকু_, зоре_, _емка, 
   {{0xddd8000a,0xaa4400d1,0xe5a40305,0xdb0402d2}},	//   _katš, _деһл, чиви, _ímán, 
   {{0xa5c4012d,0x00000000,0x00000000,0x00000000}},	//   jpóź, --, --, --, 
   {{0xddd8000a,0x212801ab,0x58b8011a,0x00000000}},	// [9160] _matš, _stbh_, _למקצ, --, 
   {{0x5280022e,0x00000000,0x00000000,0x00000000}},	//   нгуб, --, --, --, 
   {{0x21680124,0x00000000,0x00000000,0x00000000}},	//   сиеи_, --, --, --, 
   {{0xd12c7a13,0x999c0374,0x44240bbc,0x00000000}},	//   امن_, watū_, _üm_, --, 
   {{0x64a40124,0x999c0374,0xe6100214,0x00000000}},	//   _даҽа, tatū_, _تشک_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xddd8000a,0x20547a14,0x999c02b5,0x6fdc00fe}},	//   _batš, _нтар, ratū_, _বৰদৈ, 
   {{0x5ec401d9,0xfbb800bc,0x6fcc0073,0xa2b001f9}},	//   _کترٲ, इनलम, _देवू, _आकड्, 
   {{0x999c02b5,0x00000000,0x00000000,0x00000000}},	//   patū_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x82fc0135,0x00000000,0x00000000,0x00000000}},	//   _ཐེའུ_, --, --, --, 
   {{0xf8ac0073,0x88940107,0xb8e41a75,0x69dc002f}},	//   _चवीप, хиях, _एत_, ßser, 
   {{0xda640451,0x7cc800bc,0x00000000,0x00000000}},	//   _راتي, věry, --, --, 
   {{0x1d800020,0xe5700241,0x00000000,0x00000000}},	//   ረሰቦች_, _òmìí, --, --, 
   {{0x98bc00b0,0xab600205,0x00000000,0x00000000}},	//   rutē_, _ğüze, --, --, 
   {{0x47e400fb,0xdecc0023,0x00000000,0x00000000}},	// [9170] _зәрҡ, እሎን_, --, --, 
   {{0x970000d1,0x64600055,0x00000000,0x00000000}},	//   _سېزى, _āviũ, --, --, 
   {{0x1fa800fe,0x00000000,0x00000000,0x00000000}},	//   _খেলস, --, --, --, 
   {{0x92bc00bd,0x53a000cf,0x3cf8012d,0x00000000}},	//   ুকে_, _كۅزك, ुषों_, --, 
   {{0xfaf8005f,0xb4e845c7,0x93880329,0x26dc00d0}},	//   klī_, मकी_, _усна_, čtov_, 
   {{0x2d940117,0xdcfc00ef,0x00000000,0x00000000}},	//   дрис, _īvān, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xeb2825f2,0x10140133,0xfaf800ef,0x00000000}},	//   ожил_, _ربرد, elī_, --, 
   {{0xfe6c7a15,0x442c03e3,0x00000000,0x00000000}},	//   _йү_, _əd_, --, --, 
   {{0xeab00597,0xe9d833b6,0xa9247a16,0xfaf800ef}},	//   ئعة_, жко_, мдол, glī_, 
   {{0x1ee82418,0xceb401af,0xcd04022e,0x00000000}},	//   _بولی_, _мәҫ_, _ечди, --, 
   {{0x32cc03e3,0x00000000,0x00000000,0x00000000}},	//   _döyə_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7eb40208,0x00000000,0x00000000,0x00000000}},	//   _càph, --, --, --, 
   {{0x32cc03e3,0x1ae001d5,0x6578025c,0x94d403b9}},	//   _göyə_, _шошм, ħtho, lçə_, 
   {{0xe57001e1,0x00000000,0x00000000,0x00000000}},	//   _òmíí, --, --, --, 
   {{0x248401a2,0x178059b7,0x92bc00fe,0xa6e4117e}},	// [9180] ľom_, _агым, ুকৈ_, _ожил, 
   {{0x3ce004a7,0x00000000,0x00000000,0x00000000}},	//   čivi_, --, --, --, 
   {{0xd6cc0133,0x5698011a,0x00000000,0x00000000}},	//   _ڕقی_, _וייצ, --, --, 
   {{0xdcf800de,0x94d403b9,0x00000000,0x00000000}},	//   _ostā, kçə_, --, --, 
   {{0x78bc02d3,0x737401af,0x00000000,0x00000000}},	//   ërvi, _пырх, --, --, 
   {{0x98bc00de,0x999c00e4,0x00000000,0x00000000}},	//   istā_, satũ_, --, --, 
   {{0x71700075,0xdcf800b8,0x78bc1c52,0xae2400cf}},	//   _مۇلا, _astā, ūrvi, رويۉ, 
   {{0x98bc00da,0x80b800eb,0x00000000,0x00000000}},	//   kstā_, _অদক্, --, --, 
   {{0x60c027cc,0x7eb4004e,0xda7800a7,0x9e6400ee}},	//   mhom, _làpi, оян_, _овад, 
   {{0x60c07a17,0x3f840135,0x80b40490,0xcb04007b}},	//   lhom, _ismu_, _आवडे, ويين_, 
   {{0x69f00b38,0x2714013a,0x98bc0171,0x00000000}},	//   лүшт, _měně_, estā_, --, 
   {{0xa3ac0a28,0xed4c00b2,0x3eac0010,0x6fa40154}},	//   _कथं_, _اھو_, _hodt_, _খেয়ে, 
   {{0xcb0400b2,0xdc2c0055,0x98bc00de,0x00000000}},	//   _ڪيون_, cñāk, gstā_, --, 
   {{0x60c00978,0xfd4c002b,0x81b400cc,0x36d401f4}},	//   hhom, _smiṃ, _জইন_, хогр, 
   {{0x7eb400db,0x3f8400c0,0x999c0118,0x00000000}},	//   _càpi, _lsmu_, matů_, --, 
   {{0x3f8400f3,0xd7f80063,0xb4e87a18,0x60c0014f}},	//   _osmu_, _муп_, मके_, jhom, 
   {{0x60c07a19,0x00000000,0x00000000,0x00000000}},	// [9190] dhom, --, --, --, 
   {{0x78ac03d1,0x52746eb7,0x00000000,0x00000000}},	//   _hoav, بارز, --, --, 
   {{0x78ac0165,0x769400a2,0x84381884,0x60c00327}},	//   _koav, _eýyä, سكەر_, fhom, 
   {{0x78ac0124,0x60c0016d,0xdbc80254,0x00000000}},	//   _joav, ghom, lõõr, --, 
   {{0x78ac4673,0xbf646e07,0x7eb4004e,0x9d4000ee}},	//   _moav, ندوو, _zàpi, ңешд, 
   {{0x60c07a1a,0x78ac7a1b,0xff5042b5,0x69c400c5}},	//   ahom, _loav, شخه_, _üheg, 
   {{0x3f8400da,0x60c07a1c,0xed580334,0xa2c00150}},	//   _esmu_, bhom, чой_, _сәтк, 
   {{0x60c07a1d,0x78ac0109,0xdbc80254,0xaa84010e}},	//   chom, _noav, hõõr, kaýç, 
   {{0x55f8045e,0x6bd40a8e,0x7e88023a,0x98bc0024}},	//   _আলোক_, عتبر, öspä, lutė_, 
   {{0x3eac7a1e,0xfe707a1f,0xd94c001f,0xdcf80139}},	//   _godt_, _ندم_, _በተዘጋ, _trtğ, 
   {{0x98bc02d5,0xa2b07a20,0x78ac021c,0x00000000}},	//   nutė_, _आकस्, _boav, --, 
   {{0x2d847a21,0x7eb40228,0xb4e8038e,0x78ac0076}},	//   _isle_, _ràpi, मको_, _coav, 
   {{0xeb987a22,0xa8c4152d,0x7eb41e7b,0x249c004d}},	//   _хил_, _үйлд, _sàpi, _đtm_, 
   {{0x98bc7a23,0x78ac022e,0x601400a2,0x60c00156}},	//   rstā_, _eoav, _hümü, zhom, 
   {{0x81b4045e,0x60c07a24,0x78ac0162,0x94080213}},	//   _জেন_, yhom, _foav, _incə_, 
   {{0x60c06ae5,0x78ac7a25,0xca6001a9,0x98bc0153}},	//   xhom, _goav, _jinо, dutė_, 
   {{0xa3fc0f22,0xca60022e,0x60c0014f,0x601406be}},	// [91a0] ংখ্য_, _minо, vhom, _mümü, 
   {{0xf1a804d3,0x7eb47a26,0x86b40220,0x60c07a27}},	//   ژانه_, _tàpi, _рәмі, whom, 
   {{0x60c07a28,0x27240016,0x80b407f7,0x69c40254}},	//   thom, _hôn_, _आवदे, _ühed, 
   {{0x601406be,0x247c0240,0x6008011c,0x00000000}},	//   _nümü, _ብጽሒት_, пнем_, --, 
   {{0x60c07a29,0x2d8408fb,0x00000000,0x00000000}},	//   rhom, _asle_, --, --, 
   {{0x60c07a2a,0x27247a2b,0x63b402f6,0x98bc00c0}},	//   shom, _môn_, myyn, butė_, 
   {{0x60c07a2c,0x27247a2d,0x98bc0311,0xca60022e}},	//   phom, _lôn_, nstă_, _binо, 
   {{0xcb1802ab,0x60c07a2e,0x98bc0356,0x10a0030d}},	//   नदंड_, qhom, istă_, _йисн, 
   {{0xdcf8084c,0x78ac0109,0x2d84003a,0x27247a2f}},	//   _astă, _roav, _esle_, _nôn_, 
   {{0x78ac7a30,0x68f400a2,0xda64027d,0x00000000}},	//   _soav, _akyd, راخي, --, 
   {{0x88b00085,0x601401b8,0xad64007b,0xdbc80037}},	//   _viɛn, _fümü, _لانه, võõr, 
   {{0x601443eb,0x27240049,0x6da002a8,0x63b401f4}},	//   _gümü, _bôn_, rɓat, kyyn, 
   {{0xda700014,0x78ac0170,0x2724001e,0x3e8400c0}},	//   _مُش_, _voav, _côn_, pūtė_, 
   {{0x6f1c011c,0x6da002a8,0x2724015d,0x00000000}},	//   _èsce, mɓar, _dôn_, --, 
   {{0x05e87a31,0x292c7a32,0x78ac7a33,0x6abc002d}},	//   ефти_, _ﺩﻩﭖ_, _toav, êsfe, 
   {{0x04643a47,0xca8c02d3,0x27247a34,0xdbc80254}},	//   лтум, _ምኻኖም_, _fôn_, sõõr, 
   {{0x98bc00a8,0x27240208,0x63b401f4,0x78bc0200}},	// [91b0] astă_, _gôn_, gyyn, ërvu, 
   {{0x58d001ec,0x00000000,0x00000000,0x00000000}},	//   _шоқт, --, --, --, 
   {{0xa2b01ab2,0x8d6c02dd,0x00000000,0x00000000}},	//   _आकर्, _ﺴﻴﺎﻕ_, --, --, 
   {{0x5fd07a35,0xa5c8012c,0x98bc0153,0x6534010f}},	//   _देहल, _हेटौ, rutė_, _שארף_, 
   {{0x272401fb,0x7f940022,0x8e7001ec,0x00000000}},	//   _xôn_, лацх, лқаш, --, 
   {{0xbe480131,0x60147a36,0x130401ec,0xca60022e}},	//   ىشىم_, _sümü, _سىزۋ_, _sinо, 
   {{0xada47a37,0x30c80150,0x6da40131,0xc0ec0023}},	//   тайл, _قوسپ_, тийа, ህሮም_, 
   {{0xeb984cc8,0x5fd02802,0x61f803b2,0xcf4000db}},	//   дии_, _देवल, _øtla, _مىرۋ, 
   {{0xc108010b,0xdcf800de,0x00000000,0x00000000}},	//   _чэре_, _artē, --, --, 
   {{0x68f47a38,0x27246cc6,0xd84c0ca8,0x00000000}},	//   _skyd, _rôn_, _wọle_, --, 
   {{0x3b840323,0x27240368,0xdce40618,0x601405d1}},	//   влөг, _sôn_, ūmāl, _tümü, 
   {{0x6e2c0a28,0xeab00583,0x888400d1,0x27240051}},	//   śabd, اٹھ_, уғил, _pôn_, 
   {{0xfd107a39,0x3774008e,0x00000000,0x00000000}},	//   _اجل_, лырс, --, --, 
   {{0xa0480023,0xf9900133,0x27240051,0x5b54011a}},	//   _ናጽነታ, _گبه_, _vôn_, _ישנן_, 
   {{0x24f42069,0xae0407f7,0x8c44008e,0x64a400c7}},	//   вчар, षेचन_, ciğä, ҭаҳа, 
   {{0x27240016,0x98bc0276,0xf9900133,0x63b4005b}},	//   _tôn_, rstă_, _دبه_, tyyn, 
   {{0x14200364,0x94200410,0xa6c800f1,0x232801f0}},	// [91c0] рдум, рмуе, _يوبل_, фози_, 
   {{0xd6cc0879,0x75340175,0x63b401f4,0xe2980124}},	//   _وقي_, bpzz, ryyn, ьаз_, 
   {{0x63b4005b,0x51640139,0xa3ac134e,0x00000000}},	//   syyn, күрү_, _कथक_, --, 
   {{0xd12c583f,0x63b4023a,0x00000000,0x00000000}},	//   زمه_, pyyn, --, --, 
   {{0x5fd000bc,0x656c00ae,0x00000000,0x00000000}},	//   _देशल, ltbh, --, --, 
   {{0xd00c036b,0x00000000,0x00000000,0x00000000}},	//   آله_, --, --, --, 
   {{0x6ee40075,0x61447a3a,0x6024004e,0xe28c01b9}},	//   ھسۇل, _шева, _адба, mdа_, 
   {{0xe28c01d5,0x656c0332,0xefb80092,0x00000000}},	//   ldа_, itbh, ሲኒያ_, --, 
   {{0x393c001f,0x4f8401d9,0xe0640023,0x1e847a3b}},	//   _የተያያ, _لالہ, _ደምዳሚ_, _илам, 
   {{0x6da002a8,0xe28c01d5,0x4f04774c,0x98bc4f7e}},	//   rɓar, ndа_, _анун_, istą_, 
   {{0xdcb05f32,0x3914030d,0x9d4400d8,0x00000000}},	//   _پىش_, лмор, _реед, --, 
   {{0x98bc0006,0xa2d006ff,0xe28c022e,0x00000000}},	//   kstą_, णोत्, hdа_, --, 
   {{0xeb540e8e,0x2bd805dc,0xe28c01a9,0x00000000}},	//   _مىنگ, _बेपा, kdа_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4a7808a8,0x98bc0153,0xe28c01d5,0x00000000}},	//   _חרוב, estą_, ddа_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb7d813c3,0x3868067c,0xb2747a3c,0x92687a3d}},	// [91d0] _سودا_, _icar_, ллаш, дреа_, 
   {{0x78bc7a3e,0x75d47a3f,0xc6f80c9e,0x00000000}},	//   lksv, _ميخا, _иных_, --, 
   {{0xb0340120,0x90e41870,0x95c800d8,0x2bd81414}},	//   гнеш, پسان, _цупа_, _बेना, 
   {{0x78bc01a4,0x41740b8c,0x7e6802d0,0xea14010f}},	//   nksv, شامس, _acdp, אַני_, 
   {{0x78bc0936,0x386805da,0x81b402f5,0x8fc42d4b}},	//   iksv, _mcar_, _জেদ_, خزان, 
   {{0xd1b82544,0xa2d00b02,0x00000000,0x00000000}},	//   _قازا_, णोद्, --, --, 
   {{0x7644016b,0xfe70036b,0x27fc012d,0xad240145}},	//   _mehy, تدن_, ętni_, دىبى, 
   {{0x78bc01a4,0x17000327,0x764400b8,0x25bc01ab}},	//   jksv, _ཚེའམ_, _lehy, ùtli_, 
   {{0x2b1400d6,0x7524020c,0x7eb400cf,0xeb987a40}},	//   льор, _luhz, _càps, хип_, 
   {{0x78bc7a41,0x38687a42,0x76447a43,0x2bd80037}},	//   eksv, _acar_, _nehy, _बइठा, 
   {{0x776c011f,0x0ca8086f,0x6c747a44,0x00000000}},	//   _aqax, _отди_, _булх, --, 
   {{0x98bc3d44,0xe28c01d5,0x00000000,0x00000000}},	//   ystą_, zdа_, --, --, 
   {{0x7644016b,0xcb440124,0xe28c022e,0x46840150}},	//   _behy, _рхеи, ydа_, ақпа, 
   {{0x2b4c004c,0xaa4400f3,0x2bd800c5,0x00000000}},	//   msec_, _секл, _बेया, --, 
   {{0x64984140,0xd940084c,0xba7400d1,0x386800a3}},	//   нтар_, _лещи, _خانت, _fcar_, 
   {{0xa7d42550,0x66c00030,0x78bc7a45,0xb4600213}},	//   _متخص, _dôka, cksv, şünə, 
   {{0xe2987a46,0x2b4c7a47,0x78ac012c,0x2bd87a48}},	// [91e0] наа_, nsec_, žová, _बेमा, 
   {{0x6d4048df,0x76440549,0x47f4013e,0xa6840153}},	//   _owla, _gehy, _бӯҳр, _слод, 
   {{0xe28c01d5,0x00000000,0x00000000,0x00000000}},	//   rdа_, --, --, --, 
   {{0xe0442097,0x33280135,0xdfe80107,0xe28c022e}},	//   унди, bqax_, ндед_, sdа_, 
   {{0x6d407a49,0x7644016b,0xdef8699d,0x00000000}},	//   _awla, _yehy, нык_, --, 
   {{0xd12c0075,0x2b4c01fa,0x7534007f,0x02c40137}},	//   زمۇ_, dsec_, _ègzè, _тигү, 
   {{0x64447a4a,0x628c7a4b,0x6e20045a,0x9f94002f}},	//   _keki, _iabo, _dglb, büßt_, 
   {{0x64440810,0x0fc02d55,0x6d40010a,0x3b546fe4}},	//   _jeki, рйән, _dwla, акир, 
   {{0x628c7a4c,0x6444398e,0x20000d12,0x10a0011c}},	//   _kabo, _meki, _áki_, _уитн, 
   {{0x64447a4d,0xc0d002d3,0x91a800cc,0x00000000}},	//   _leki, እዮም_, _গেটখ, --, 
   {{0x628c4d28,0x6d400cfd,0x38680161,0x6f1c011c}},	//   _mabo, _gwla, _pcar_, _èsca, 
   {{0x628c7a4e,0x2b4c045a,0x00000000,0x00000000}},	//   _labo, bsec_, --, --, 
   {{0x764400e4,0xc8c80050,0x2b4c045a,0xb6a400d1}},	//   _pehy, اوُن_, csec_, қиңл, 
   {{0x78bc007c,0x00000000,0x00000000,0x00000000}},	//   sksv, --, --, --, 
   {{0x64447a4f,0xd4987a50,0x9690179e,0x00000000}},	//   _beki, нра_, لیکش, --, 
   {{0x64447a51,0x628c7a52,0x776c025c,0x76440042}},	//   _ceki, _aabo, _tqax, _wehy, 
   {{0x628c5e35,0x64447a53,0xd2587a54,0x7d000037}},	// [91f0] _babo, _deki, еце_, ilms, 
   {{0x64447a55,0x4734009f,0x7d0001e3,0x00000000}},	//   _eeki, _اريز, hlms, --, 
   {{0x628c7a56,0x64447a57,0x61440075,0x7bdc029f}},	//   _dabo, _feki, لىلە, ğruy, 
   {{0x64447a58,0xb4640228,0x628c02d0,0x34940107}},	//   _geki, _өкүл, _eabo, _тамр, 
   {{0x88b00085,0x628c7a59,0xfde802dd,0x3328031c}},	//   _siɛk, _fabo, ңдік_, qqax_, 
   {{0x628c7a5a,0xed58230c,0x64447a5b,0x00000000}},	//   _gabo, вок_, _zeki, --, 
   {{0x64447a5c,0xde440066,0x00000000,0x00000000}},	//   _yeki, شینو_, --, --, 
   {{0x0ce0045e,0xe28c022e,0x2b4c031c,0x00000000}},	//   মত্ত, noаn_, tsec_, --, 
   {{0x6a847a5d,0xd09401ee,0x00000000,0x00000000}},	//   алпа, _ишҡы, --, --, 
   {{0x2b4c7a5e,0x7d000083,0x628c01c4,0x6ab425ea}},	//   rsec_, alms, _xabo, рсих, 
   {{0xa9680640,0xb0b81d68,0x6d40010e,0x00000000}},	//   њима_, _आवाग, _uwla, --, 
   {{0xebd80faa,0x39580f47,0x98bc0064,0x00000000}},	//   _идеш_, ársa_, ostę_, --, 
   {{0xdcf80006,0x7eb400e8,0x20e801e4,0x00000000}},	//   _artė, _kàpp, nĝia_, --, 
   {{0x64447a5f,0x98a80029,0x2cac7a60,0x7eb41574}},	//   _seki, ībā_, ljed_, _jàpp, 
   {{0x64447a61,0x35c4016c,0x2bd852be,0x95b400c7}},	//   _peki, барҳ, _बेता, артә, 
   {{0x628c7a62,0x6444011f,0x7eb400e8,0x58d00798}},	//   _sabo, _qeki, _làpp, _мојт, 
   {{0x64447a63,0x628c7a64,0x29000270,0xa6c80da9}},	// [9200] _veki, _pabo, mlka_, _алпа_, 
   {{0x29000bf1,0x644409a5,0x628c7a65,0x2cac000d}},	//   llka_, _weki, _qabo, hjed_, 
   {{0x628c7a66,0x29000014,0xe5a47a67,0x602406ed}},	//   _vabo, olka_, _тини, адеа, 
   {{0x2cac003d,0x657c7a68,0x644403a0,0xdfd80801}},	//   jjed_, _ipph, _ueki, къл_, 
   {{0x2cac7a69,0x29007a6a,0x7f9438b4,0xd02001e0}},	//   djed_, ilka_, салх, әмәй, 
   {{0x628c0076,0x98bc00e4,0x2490010b,0x00000000}},	//   _uabo, rutĩ_, ldym_, --, 
   {{0x91e07a6b,0xa1141272,0x5cc40131,0x81b40154}},	//   _доре, _نوست, исиз, _জের_, 
   {{0xcae0015b,0xdb0c01e1,0x249000ee,0x00000000}},	//   _নীলফ, _ójút, ndym_, --, 
   {{0x041800bd,0xcb6400c6,0x24900076,0x2900058a}},	//   ধুরী_, لميه_, idym_, dlka_, 
   {{0x657c7a6c,0x29007a6d,0x6b980042,0x69200171}},	//   _opph, elka_, _drwg, _nēes, 
   {{0xd90c1060,0x5d84007b,0x2490010b,0x00000000}},	//   ویت_, _خلال, kdym_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb0009f0,0x69c4007d,0x7eb4002e,0x24901368}},	//   _groß, _ühen, _yàpp, ddym_, 
   {{0x29000050,0x4b78008f,0x8bd40375,0xe5840137}},	//   alka_, _סאוו, _דודו_, өтсү, 
   {{0x29007a6e,0xfbe80154,0x128400f2,0x7954009f}},	//   blka_, _পরিত, یمری_, _اَبا, 
   {{0x98bc762b,0x093006c2,0x00000000,0x00000000}},	//   ystę_, _بروج, --, --, 
   {{0x81b4015b,0x04f400d3,0x32547a6f,0x2bc8076e}},	// [9210] _জেল_, ізую, йвар, िनया, 
   {{0x657c0175,0x430400d4,0x2bd80037,0x538c0023}},	//   _fpph, оїха, _बइसा, _ዘካይድ_, 
   {{0xdcf80034,0x116401d5,0xe28c01b9,0x962400ef}},	//   _wstę, شلشی_, vlаt_, _viņē, 
   {{0x7eb47a70,0xb48400db,0xfbb81bd6,0x30147a71}},	//   _sàpp, _اددۇ, ेनाम, бдер, 
   {{0x61ec2076,0x2cac0841,0xdcf8012d,0xd244009d}},	//   _exbl, vjed_, _ustę, _вэби, 
   {{0x98bc00c0,0x00000000,0x00000000,0x00000000}},	//   kutį_, --, --, --, 
   {{0x290001d9,0x850404d3,0x41500023,0x906000db}},	//   ylka_, _دوێن, _ኣፍልጦ, _ونسۇ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x1c402ecc,0xfd4802e3,0x6f1c011c,0xce680022}},	//   чным, _kemị, _èsco, _аред_, 
   {{0x24907a72,0x8d740014,0x2cac1711,0xe28c01a9}},	//   zdym_, _ناصا, sjed_, llаr_, 
   {{0x66c00030,0xbb4400d1,0x00000000,0x00000000}},	//   _dôkl, ﭘﻨﻰ_, --, --, 
   {{0x7c847a73,0x2900132e,0xe28c01d5,0x3078010f}},	//   _муче, ulka_, nlаr_, נאָנ, 
   {{0x79880042,0x29000009,0x00000000,0x00000000}},	//   awdw, rlka_, --, --, 
   {{0x6b887a74,0xa96800f3,0xe28c01d5,0x69c40254}},	//   mweg, _бика_, hlаr_, _üheo, 
   {{0x6b881ebd,0x80b803f4,0x68e4074d,0x64a47a75}},	//   lweg, _আগস্, pnkd, бава, 
   {{0x6b88033f,0x26c801d5,0x684403f5,0xfbe800fe}},	//   oweg, shbo_, _униа, _পৰিত, 
   {{0x6b887a76,0x249000ee,0x81b400cc,0xe28c01a9}},	// [9220] nweg, rdym_, _জেং_, dlаr_, 
   {{0x49000316,0x7778013d,0x6d5c00dc,0x00000000}},	//   रतको_, _äwxa, _āsan, --, 
   {{0x657c7a77,0x6b887a78,0x2bd80959,0xe28c022e}},	//   _upph, hweg, _बेसा, flаr_, 
   {{0x6b881616,0x61ec00b8,0x00000000,0x00000000}},	//   kweg, _āhlā, --, --, 
   {{0x42a4052f,0x5fd0007d,0x602400c7,0x00000000}},	//   _һуңғ, _देखल, адҵа, --, 
   {{0x66f82d8f,0x6b880112,0xe0d001d9,0x2f0800e4}},	//   ृतिक_, dweg, _کٲر_, túga_, 
   {{0x171804ac,0x6b8877d0,0xe28c022e,0x9d5401f0}},	//   נוצע, eweg, blаr_, сӯзӣ_, 
   {{0xdfd0038b,0xca6001a9,0x6b8801f5,0x2bd8228d}},	//   _فيز_, _minе, fweg, _बेहा, 
   {{0x60c0041e,0xe8182122,0x6b887a79,0xd0047a7a}},	//   mkom, नेमा_, gweg, _гете_, 
   {{0xd7d8037e,0x2d8c0108,0x00000000,0x00000000}},	//   veム_, äkeä_, --, --, 
   {{0x6dc42df0,0x69c400af,0x645800b0,0x60c0588d}},	//   _وزمل, _ühel, _ētin, okom, 
   {{0x6b887a7b,0x26d87a7c,0x2bd81b90,0x386c04cc}},	//   bweg, _ampo_, _बेवा, üer_, 
   {{0x60c07a7d,0x00000000,0x00000000,0x00000000}},	//   ikom, --, --, --, 
   {{0x2248005a,0x98bc0024,0x167001b9,0x386c6f39}},	//   _nebk_, putį_, чқор, żer_, 
   {{0x60c07a7e,0xe28c022e,0xe9f80051,0x00000000}},	//   kkom, ylаr_, _đầ_, --, 
   {{0x60c07a7f,0x26d83699,0x2248005a,0xd6d80724}},	//   jkom, _empo_, _aebk_, _әти_, 
   {{0x60c011c0,0x36d406ed,0x43740212,0xe28c01a9}},	// [9230] dkom, _моир, зуєт, vlаr_, 
   {{0x80b8000e,0x32544dba,0x60c07a80,0x95c87a81}},	//   _আগষ্, івер, ekom, _бума_, 
   {{0x4820044e,0x7ae800b5,0x6b8801f5,0xe28c01d5}},	//   ተዘይኮ, indt, zweg, tlаr_, 
   {{0x60c0357f,0x21280fa3,0x6b881418,0x00000000}},	//   gkom, _dubh_, yweg, --, 
   {{0x212800a3,0xe28c01b9,0x932401ed,0x00000000}},	//   _eubh_, rlаr_, _درجن, --, 
   {{0x60c07a82,0xad58301d,0x05740aad,0xada47a83}},	//   akom, арих_, _باید, жакл, 
   {{0x60c07a84,0x00000000,0x00000000,0x00000000}},	//   bkom, --, --, --, 
   {{0x6b887a85,0x60c07a86,0x7ae803cd,0xe28c022e}},	//   tweg, ckom, endt, qlаr_, 
   {{0x6b8809b6,0x00000000,0x00000000,0x00000000}},	//   uweg, --, --, --, 
   {{0x79800952,0x6b882238,0x00000000,0x00000000}},	//   ﯨﻤﯩﺰ_, rweg, --, --, 
   {{0x6b887a87,0x9e9400f7,0xd7d8037e,0xfe24074d}},	//   sweg, _باقچ, veメ_, _хьун, 
   {{0x69c4000d,0x03e400cc,0x00000000,0x00000000}},	//   _ühem, _মৰোণ, --, --, 
   {{0x69d80073,0x3cf801d3,0x7d040135,0x00000000}},	//   _फेरी, _írva_, ċist, --, 
   {{0xbb4803e6,0x00000000,0x00000000,0x00000000}},	//   _چلۆن_, --, --, --, 
   {{0x49e001ec,0xdb0403cd,0x00000000,0x00000000}},	//   _رۋحق, ømåk, --, --, 
   {{0xa3e803b7,0x212801ab,0x60c0005a,0xd4a00116}},	//   адба_, _rubh_, xkom, мисй, 
   {{0x29103864,0x21287a88,0x6658030d,0x00000000}},	// [9240] _ihya_, _subh_, _капă, --, 
   {{0x26d80113,0x59dc134e,0x00000000,0x00000000}},	//   _umpo_, _फेडर, --, --, 
   {{0xa6c80050,0xd12c0347,0xa5087a89,0x00000000}},	//   _موکل_, نمل_, _вена_, --, 
   {{0x60c07a8a,0x3d94013e,0xdfd00b73,0x205452c4}},	//   ukom, ҷикр, ويض_, ітер, 
   {{0x2bd87a8b,0x7ae8005c,0x261407af,0x00000000}},	//   _बेला, yndt, फेरी_, --, 
   {{0x60c07a8c,0x61447a8d,0x17980bd9,0x9e6433d2}},	//   skom, _мега, יינב, زاتن, 
   {{0x29100263,0x60c07a8e,0x6084007b,0x0f340023}},	//   _ohya_, pkom, _وشرك, _ይደልየ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf000013e,0xe2080f90,0x0bf001c4,0x00000000}},	//   _пӯши, _वरुण_, мпъю, --, 
   {{0x0e607a8f,0x5ec401d9,0x00000000,0x00000000}},	//   _окун, _بترٲ, --, --, 
   {{0x29100055,0x00000000,0x00000000,0x00000000}},	//   _bhya_, --, --, --, 
   {{0xad640214,0x5d1000d1,0x52b461ef,0x7d040327}},	//   _رامه, _تېبا, _आक्स, ċiss, 
   {{0x70400092,0x00000000,0x00000000,0x00000000}},	//   ርስባቸ, --, --, --, 
   {{0xe20802ab,0x00000000,0x00000000,0x00000000}},	//   _वरूण_, --, --, --, 
   {{0xe7a400a2,0x7bc07a90,0x00000000,0x00000000}},	//   _düñö, lymu, --, --, 
   {{0xd8380209,0x70b8007d,0x00000000,0x00000000}},	//   _тэк_, _आवेल, --, --, 
   {{0x7bc07a91,0xb9e40020,0x94040085,0x6d5c00b8}},	// [9250] nymu, _ኪሜ_, ɛnɛ_, _āsam, 
   {{0x36d405f5,0x8c180375,0x62980174,0x65680332}},	//   _хоор, שומי, _ótol, ómhé, 
   {{0x59c8193d,0xfbd000cc,0x7bc0015d,0x00000000}},	//   ानिर, াপিত, hymu, --, 
   {{0x7bc00006,0xed5801e0,0x301400ee,0xe57000df}},	//   kymu, ҡол_, пдер, _אַש_, 
   {{0xcf880107,0x5348010a,0x7bc0010e,0x56900055}},	//   рсед_, _тăлă, jymu, _śoṇā_, 
   {{0x7bc07a92,0x59c817c6,0x6620010e,0x947400e5}},	//   dymu, ानार, _ýyký, _ادھا, 
   {{0x2c440092,0x06980150,0x10e40395,0x00000000}},	//   _የቀረቡ, _ﺀﯗﻳﯩ, _дюам, --, 
   {{0xd9fc00c5,0x81b400cc,0x00000000,0x00000000}},	//   _उड़त_, _জেক_, --, --, 
   {{0x7bc00142,0x3cf0012d,0x00000000,0x00000000}},	//   gymu, आवजे_, --, --, 
   {{0x69c4007d,0x2910785d,0x9508025c,0xfeb82088}},	//   _ühek, _shya_, _ཁེའི_, _والت_, 
   {{0xf768008f,0xe8f87a93,0x00000000,0x00000000}},	//   _תק_, йло_, --, --, 
   {{0x9de4025c,0x7bc001f5,0x635c0356,0x00000000}},	//   _སྨྲེ, bymu, lănţ, --, 
   {{0x6fbc107c,0x29000055,0x00000000,0x00000000}},	//   ्निं, _ūhas_, --, --, 
   {{0x9bb405d0,0xefdc0023,0xe17c0023,0x6d5c0055}},	//   _מהנה_, _ንኺድ_, _ከጋጥሞ_, _āsaj, 
   {{0x29100564,0x64a47a94,0x00000000,0x00000000}},	//   _thya_, пава, --, --, 
   {{0x6fbc1098,0xd1ec0092,0x69c00064,0xe73800d8}},	//   ्नां, ቂነት_, myle, _леи_, 
   {{0x69c07a95,0x6da00198,0xe2c80139,0xc0bc0023}},	// [9260] lyle, rɓay, блад_, ታታሊ_, 
   {{0xe1f00075,0x6f1c04cc,0xe68801ec,0x179808a8}},	//   ىسا_, _èsch, _اندى_, _פייב, 
   {{0x69c07a96,0x91e07a97,0xe9f8001e,0x7bc0033f}},	//   nyle, нофе, _đẻ_, zymu, 
   {{0xc3dc0150,0x00000000,0x00000000,0x00000000}},	//   _көзi, --, --, --, 
   {{0x69c07a98,0x387c00a2,0x00000000,0x00000000}},	//   hyle, _öwre_, --, --, 
   {{0x975400d9,0x00000000,0x00000000,0x00000000}},	//   לינו_, --, --, --, 
   {{0x22a00166,0x69c4000d,0x05000154,0x00000000}},	//   _eçkä_, _üheh, ্দীর_, --, 
   {{0x7bc00006,0x69c000a2,0x5158011a,0xe0d800d8}},	//   tymu, dyle, _לכלו, _увб_, 
   {{0x69c00076,0xbbb8000d,0x7b144964,0x00000000}},	//   eyle, ेनेक, мдих, --, 
   {{0x69c07a99,0x7bc000c0,0x6b9c01bf,0x7d040003}},	//   fyle, rymu, æsga, ċisq, 
   {{0x7bc07a9a,0x69c000e5,0x00000000,0x00000000}},	//   symu, gyle, --, --, 
   {{0xab5c0034,0x0500015b,0x3ce00205,0x7bc00064}},	//   wyże, ্দুর_, _öiv_, pymu, 
   {{0x8c402e9c,0xd7f87a9b,0x69c00363,0x59c800bc}},	//   _чече, сун_, ayle, ानहर, 
   {{0x69c000a0,0x96e81de1,0x8c180375,0x00000000}},	//   byle, сьма_, _הודי, --, 
   {{0x8b000118,0x8a78011a,0x4a78011a,0x6d5c00b8}},	//   ářej, _האות, _הרוב, _āsak, 
   {{0xb92400c6,0x00000000,0x00000000,0x00000000}},	//   _تفعي, --, --, --, 
   {{0x0fd81431,0x00000000,0x00000000,0x00000000}},	// [9270] _मेंढ, --, --, --, 
   {{0xab6003ee,0x6fbc07b7,0x00000000,0x00000000}},	//   _şüke, ्नसं, --, --, 
   {{0x795402d3,0x22280014,0xdeb80023,0x75140452}},	//   _መደባት, زٲنی_, ታናን_, _омоф, 
   {{0x2ec4449f,0x25bc0724,0xde4400d1,0x40947a9c}},	//   वस्त, ätle_, ۈرىۋ, ершт, 
   {{0x635c0276,0x69c07a9d,0xc104027d,0x00000000}},	//   tănţ, zyle, روهي, --, 
   {{0xc7d80375,0xdec00022,0xdd0000dc,0x00000000}},	//   הודי_, кәхо, _ārād, --, 
   {{0xdd8c7a9e,0x9e9400cf,0x128001af,0x00000000}},	//   لوو_, بانچ, _оҫҡо, --, 
   {{0x645800e2,0x69c00306,0xbd880116,0x00000000}},	//   _ētik, vyle, سخىك_, --, 
   {{0x69c00142,0x00000000,0x00000000,0x00000000}},	//   wyle, --, --, --, 
   {{0xc94001d5,0xfe740798,0x00000000,0x00000000}},	//   ндоқ, _плуќ, --, --, 
   {{0xa8887a9f,0xbe64007b,0x7e7400cf,0x00000000}},	//   ойна_, _أهمي, _سالئ, --, 
   {{0x8c4400ee,0x2d847aa0,0x00000000,0x00000000}},	//   _эҗиз_, _iple_, --, --, 
   {{0xcc085670,0x16180bc0,0x69c00108,0x00000000}},	//   _ازان_, फेसर_, syle, --, 
   {{0x3a2001e4,0x59dc0c4c,0x8ca8012d,0x00000000}},	//   _ŝipe_, _फेवर, झावो, --, 
   {{0xd6247aa1,0xba280345,0xab600205,0x00000000}},	//   доре_, _عسوم_, _şühe, --, 
   {{0xe8f400c6,0x9ad80055,0x7c2401e7,0x00000000}},	//   _تستخ, _ivāṅ, _úirc, --, 
   {{0x27e4007f,0xe9f80051,0xa3e8009d,0x691c0ca8}},	// [9280] _äon_, _đẹ_, цдаа_, _ṣewa, 
   {{0x0500015b,0x00000000,0x00000000,0x00000000}},	//   ্দের_, --, --, --, 
   {{0xe81801ad,0xd24c01c8,0x00000000,0x00000000}},	//   नेरा_, شنن_, --, --, 
   {{0x60080107,0x00000000,0x00000000,0x00000000}},	//   онем_, --, --, --, 
   {{0x2d840100,0x00000000,0x00000000,0x00000000}},	//   _aple_, --, --, --, 
   {{0xe28401af,0x00000000,0x00000000,0x00000000}},	//   _юлги, --, --, --, 
   {{0x8eac04c5,0x03e400cc,0x2d580248,0xaab0190c}},	//   কসংগ, _খৰচী_, _ṣere_, जानक, 
   {{0x99700316,0x8d140338,0x5ce45409,0x00000000}},	//   těže_, وزير_, ьюла, --, 
   {{0x2d847aa2,0x9ad800b8,0xda640fb4,0xfcc4013d}},	//   _eple_, _avāṅ, وادي, _җәйм, 
   {{0x1eb401a9,0x008401af,0x00000000,0x00000000}},	//   _ўсаё, _юлғо, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2bd84614,0x2d947aa3,0x03e400cc,0x00000000}},	//   _बेका, _ярус, _খৰছী_, --, 
   {{0xe8187aa4,0x9ad800b8,0x8cc400db,0x00000000}},	//   नेला_, _evāṅ, _زووق_, --, 
   {{0x7d007aa5,0x98bc3279,0x95c80022,0x00000000}},	//   loms, rttı_, оуба_, --, 
   {{0x8af8011a,0xa6140166,0xe58400db,0x00000000}},	//   _והגי, езрә, нттү, --, 
   {{0xc98000a8,0x046432b1,0x00000000,0x00000000}},	//   _руши, ктум, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [9290] --, --, --, --, 
   {{0x671406bc,0x68ec01e4,0x7d0000d7,0x00000000}},	//   _दीपक_, _ĉadi, homs, --, 
   {{0x76547aa6,0x00000000,0x00000000,0x00000000}},	//   mazy, --, --, --, 
   {{0x7d000030,0x00000000,0x00000000,0x00000000}},	//   joms, --, --, --, 
   {{0x69c4000d,0x00000000,0x00000000,0x00000000}},	//   _ühev, --, --, --, 
   {{0x537c0201,0xb8d0081f,0x2bd805f9,0x1e701955}},	//   _ሥርዓት_, _ནོ_, _बेगा, лғус, 
   {{0x7d007aa7,0xad680395,0x00000000,0x00000000}},	//   foms, чайз_, --, --, 
   {{0x7d0037cf,0xcf7800c6,0x98bc00e2,0x8d980092}},	//   goms, _وإذا_, istē_, _ቀርቧል_, 
   {{0x76547aa8,0xdcf800ef,0x9ad8002b,0x00000000}},	//   kazy, _astē, _svāṅ, --, 
   {{0xeab00491,0xaad8068f,0x3f14084c,0x765402fb}},	//   اعة_, योंक, _адус, jazy, 
   {{0x7d0001b8,0xe28c022e,0x9ce801d3,0x76547aa9}},	//   boms, moаt_, _کونے_, dazy, 
   {{0x1cac0135,0x00000000,0x00000000,0x00000000}},	//   _ཕོར_, --, --, --, 
   {{0xa3dc05d7,0xfcd40092,0xdcf800de,0xeab000d1}},	//   _थें_, _ርምጃ_, _estē, _معث_, 
   {{0x76547aaa,0x2cbc058a,0x7b14067c,0xe28c01a9}},	//   gazy, _howd_, tàue, noаt_, 
   {{0x2cbc7aab,0xa9a421cb,0xe9a404f0,0x00000000}},	//   _kowd_, _чийд, _чайп, --, 
   {{0x050000bd,0x284800db,0x00000000,0x00000000}},	//   ্দ্র_, _эзип_, --, --, 
   {{0x2cbc7aac,0x68e400a2,0x00000000,0x00000000}},	// [92a0] _mowd_, mikd, --, --, 
   {{0x29007aad,0x68e47aae,0x63047aaf,0x7d000944}},	//   loka_, likd, روال, zoms, 
   {{0x7d007ab0,0xefc40023,0x5634010f,0x00000000}},	//   yoms, _ጸሃየ_, _ראטע_, --, 
   {{0x232822f7,0x29007ab1,0x26c805b1,0x656c7ab2}},	//   _номи_, noka_, lkbo_, mubh, 
   {{0x64547ab3,0x656c7ab4,0x7d007ab5,0x8fa0009b}},	//   mayi, lubh, voms, лаце, 
   {{0x64547ab6,0x29007ab7,0x2cbc0158,0x7d007ab8}},	//   layi, hoka_, _aowd_, woms, 
   {{0x29007ab9,0xe9f8001e,0x656c0882,0x68e406be}},	//   koka_, _đế_, nubh, kikd, 
   {{0x64547aba,0x76541529,0xdd8c00dd,0x29007abb}},	//   nayi, zazy, لوڈ_, joka_, 
   {{0x29007abc,0x7d007abd,0x1e847abe,0x656c7abf}},	//   doka_, roms, _плам, hubh, 
   {{0x64547ac0,0x656c6580,0x5398011a,0x6d5c002b}},	//   hayi, kubh, ליפו, _āsav, 
   {{0x29007ac1,0x7d007ac2,0x76547ac3,0xdca4084c}},	//   foka_, poms, vazy, _пажи, 
   {{0x7654382f,0x64547ac4,0x29007ac5,0x2cbc1c1d}},	//   wazy, jayi, goka_, _gowd_, 
   {{0x64547ac6,0x47840ce8,0x00000000,0x00000000}},	//   dayi, лырб, --, --, 
   {{0x29000109,0xdb04023a,0x2bd80073,0x4a7001f7}},	//   aoka_, ämäk, _बेटा, _مُهر, 
   {{0x3eac020b,0x765473bc,0x656c4b7a,0x64547ac7}},	//   _mndt_, razy, gubh, fayi, 
   {{0x64547ac8,0x82343baf,0x29007ac9,0x1cac031c}},	//   gayi, ۇرما, coka_, _ཕོས_, 
   {{0x78ac7aca,0x3eac04ce,0xb2746dc3,0x76547acb}},	// [92b0] _inav, _ondt_, клаш, pazy, 
   {{0x64540399,0x656c7acc,0x81bc04c5,0x78ac0175}},	//   aayi, bubh, েছন_, _hnav, 
   {{0x78ac0493,0x656c7acd,0x999c0024,0x461401d9}},	//   _knav, cubh, matų_, _موٝر, 
   {{0x64547ace,0x78ac0175,0xd6180014,0x999c0064}},	//   cayi, _jnav, _وتھا_, latų_, 
   {{0x78ac7acf,0x00000000,0x00000000,0x00000000}},	//   _mnav, --, --, --, 
   {{0xdb007ad0,0x78ac0175,0x999c0153,0x00000000}},	//   _droë, _lnav, natų_, --, 
   {{0x29007ad1,0x2bd81889,0x78ac00db,0x2bc80864}},	//   yoka_, _बेजा, _onav, िन्थ, 
   {{0x3eac0627,0x78ac1418,0xdb0004e6,0x290001e2}},	//   _endt_, _nnav, _froë, xoka_, 
   {{0xdb000036,0x6e9400c7,0x68e405ac,0x999c0153}},	//   _groë, _ииау, vikd, katų_, 
   {{0x78ac7ad2,0x29007ad3,0x3a200115,0x4994084c}},	//   _anav, woka_, _ŝipa_, еӂия_, 
   {{0x29007ad4,0x68e47ad5,0x656c0117,0x999c0153}},	//   toka_, tikd, xubh, datų_, 
   {{0x6d407ad6,0x7afc0427,0x00000000,0x00000000}},	//   _itla, črta, --, --, 
   {{0x29007ad7,0x2bd80c2e,0x64547ad8,0x68e47ad9}},	//   roka_, _बेचा, vayi, rikd, 
   {{0x64547ada,0x78ac0c86,0x6d40022e,0x80d81f13}},	//   wayi, _enav, _ktla, _मतभे, 
   {{0x64987adb,0xa5081a92,0x78ac0175,0xc77400f7}},	//   мтар_, дева_, _fnav, _өтпө, 
   {{0xdb00020c,0x6d4001af,0x66e4016c,0x78ac7adc}},	//   _aroè, _mtla, хоҳа, _gnav, 
   {{0xe2987add,0x999c00c0,0x00000000,0x00000000}},	// [92c0] маа_, batų_, --, --, 
   {{0x64546580,0x6d407ade,0x69c400af,0xd704034b}},	//   sayi, _otla, _ühes, _иные_, 
   {{0x56e0005e,0x6d407adf,0x64547ae0,0x656c0472}},	//   _тұрғ, _ntla, payi, qubh, 
   {{0x64547ae1,0x50604942,0x5fe40150,0x00000000}},	//   qayi, атша, кілж, --, 
   {{0x6d407ae2,0xe9f8004d,0xdef850c0,0xcf74007b}},	//   _atla, _đẽ_, мык_, نصوص_, 
   {{0xdb007ae3,0x1ee404fb,0x20e801e4,0x00000000}},	//   _groè, ضوعی_, fŝic_, --, 
   {{0x180c05ba,0x8d600063,0x27fc012d,0x8d706e25}},	//   _सर्व_, авје, ętny_, لايا, 
   {{0x1ea80451,0x0ea40bd6,0x5ba436ca,0x8d980092}},	//   _ڪاري_, екәй_, вроз, _ቀርቷል_, 
   {{0xcb6423a4,0x6d407ae4,0xda5804a9,0x629c033f}},	//   вање_, _etla, үрүш_, odpo, 
   {{0x629c7ae5,0x1ea87ae6,0x78ac508f,0x6d40022e}},	//   ndpo, _تاري_, _snav, _ftla, 
   {{0x629c7ae7,0xad647ae8,0x78ac0175,0x1db41b6e}},	//   idpo, _مانه, _pnav, _अपित, 
   {{0x63a47ae9,0x1cb8117d,0x5c041c7c,0xa8040139}},	//   _orkn, _تائب_, _ияла, _ofığ, 
   {{0xb6c47aea,0x0c0001d9,0x8bb0708e,0x48e40006}},	//   гөнд, _پووُ, _نصوص, роўв, 
   {{0x79581ee3,0x78ac0175,0x1db41cba,0x00000000}},	//   _зикр_, _wnav, _अपात, --, 
   {{0x20e8008f,0xd4987814,0x68f400b5,0x63a403ac}},	//   nĝis_, мра_, _fjyd, _arkn, 
   {{0x63a40175,0x7ae8072b,0x799802d0,0x20e8008f}},	//   _brkn, lidt, _isvw, iĝis_, 
   {{0x63a40b3d,0x645802b1,0x629c01f5,0x59c866eb}},	// [92d0] _crkn, _ētit, fdpo, ानकर, 
   {{0x95c87aeb,0xff14037e,0x7ae80455,0xab5c012d}},	//   _жума_, yleで, nidt, zyżo, 
   {{0x63a4002f,0x00000000,0x00000000,0x00000000}},	//   _erkn, --, --, --, 
   {{0x63a401a6,0x629c01f5,0xe8187aec,0x6d400718}},	//   _frkn, adpo, नेका_, _rtla, 
   {{0x6d407aed,0xdb4400aa,0xc32800cf,0x00000000}},	//   _stla, _دَ_, ركۅن_, --, 
   {{0xcdc000c7,0x27e4010e,0x00000000,0x00000000}},	//   иалқ, _ýone_, --, --, 
   {{0x7ae80589,0xf07400dd,0x7db402e8,0x6d5c002b}},	//   didt, _میاں_, исъц, _āsas, 
   {{0x7dc40075,0x6d4002f0,0xec7800d1,0xeb9800c7}},	//   شتىك, _vtla, хпи_, еии_, 
   {{0x7c2401e7,0x7afc19d6,0xeb28009d,0x00000000}},	//   _úirl, črtn, нжил_, --, 
   {{0xeb9800ee,0x7ae802d0,0x7e7400db,0x98bc00c0}},	//   _җик_, gidt, _پاكئ, ostė_, 
   {{0x6d407aee,0xaad86385,0x59c86236,0x7998035a}},	//   _utla, योगक, ानगर, _csvw, 
   {{0x3ddc00eb,0x98bc00c0,0x00000000,0x00000000}},	//   _ঢুকল, istė_, --, --, 
   {{0x6b647aef,0xf8b400c7,0x00000000,0x00000000}},	//   _скла, рҩы_, --, --, 
   {{0x7b140561,0x98bc00c0,0xe8180210,0x00000000}},	//   làun, kstė_, नेगा_, --, 
   {{0x63a401fa,0x00000000,0x00000000,0x00000000}},	//   _srkn, --, --, --, 
   {{0x63a40118,0x645800de,0x00000000,0x00000000}},	//   _prkn, _ētis, --, --, 
   {{0xfe003885,0xf8340419,0x00000000,0x00000000}},	// [92e0] _लुईस_, ášťa_, --, --, 
   {{0x1420005b,0xdb007af0,0xc1dc0150,0x00000000}},	//   сдум, _proé, _ﺃﻁﺭﺍ, --, 
   {{0xa0a44ee6,0xc2240214,0x00000000,0x00000000}},	//   лажд, شکسو, --, --, 
   {{0xa09800c6,0xe284009d,0x00000000,0x00000000}},	//   عضاء_, _өлми, --, --, 
   {{0x44240013,0xa06800d1,0x673400a2,0x63a4002f}},	//   _àm_, _җаза_, _juyj, _urkn, 
   {{0xd00c7af1,0xdd987af2,0xa2e400db,0x33b0515c}},	//   أله_, еши_, _согд, _بەكر, 
   {{0xbdd4005b,0xa0680064,0x00000000,0x00000000}},	//   ройщ, _пава_, --, --, 
   {{0xdb0006af,0x3a20008f,0x20e800df,0x00000000}},	//   _croî, _ŝipo_, rĝis_, --, 
   {{0xda780209,0x673400e8,0x4f8401d9,0x7ae8007c}},	//   нян_, _nuyj, _مالہ, tidt, 
   {{0x7afc151c,0x0fc00137,0x69dc01e4,0x701800d4}},	//   črto, _уйун, ĝsen, _ріст_, 
   {{0x7ae87af3,0xd2b40302,0x38c8030f,0x9d440120}},	//   ridt, אלית_, ناحی_, _сеед, 
   {{0x8df80302,0x00000000,0x00000000,0x00000000}},	//   _אהבת, --, --, --, 
   {{0x81bc03f4,0xefe4044e,0x7ae801e4,0x00000000}},	//   েছি_, _ዝያዳ_, pidt, --, 
   {{0x99d47405,0x98bc0024,0x7ae80455,0x00000000}},	//   _متعا, ystė_, qidt, --, 
   {{0x45d47af4,0x69c400c5,0xc0d0010c,0xb5941049}},	//   борс, _ühep, ጥሮስ_, шивш, 
   {{0x84c406ed,0x2bd00a59,0x65780192,0x00000000}},	//   бљуд, दैवा, àtha, --, 
   {{0x32547af5,0x48741c3e,0x67346c09,0x926800d8}},	// [92f0] ивар, _ادىس, _guyj, ереа_, 
   {{0x322808b0,0x00000000,0x00000000,0x00000000}},	//   نتاۋ_, --, --, --, 
   {{0xb0347af6,0x95c8010a,0x00000000,0x00000000}},	//   анеш, _чупа_, --, --, 
   {{0x98bc0024,0xddd80210,0x00000000,0x00000000}},	//   rstė_, _odtł, --, --, 
   {{0x92681614,0x00000000,0x00000000,0x00000000}},	//   _прва_, --, --, --, 
   {{0xa3dc0490,0x92687af7,0x98bc0064,0x00000000}},	//   _थेट_, _ярма_, pstė_, --, 
   {{0x85040272,0x02180138,0x691401a8,0x00000000}},	//   _خوێن, _борщ_, dáen, --, 
   {{0x81c40150,0x6b6400c7,0xbd540022,0xefb00101}},	//   _دەمۇ, акиа, сҭцә, _ویاگ, 
   {{0x90b000d1,0xaab0190c,0x00000000,0x00000000}},	//   _вәһш, जालक, --, --, 
   {{0xfb88143e,0x7ff47af8,0x00000000,0x00000000}},	//   ائيو_, _اسفا, --, --, 
   {{0xdb000ba1,0xad4000f7,0x6ac405b3,0x67340432}},	//   _eroï, _بۉبۉ, _लकीर, _suyj, 
   {{0xe7387af9,0xaad80b4c,0x6734014f,0x00000000}},	//   кем_, योजक, _puyj, --, 
   {{0x7d0400ec,0xe634009d,0x00000000,0x00000000}},	//   _اِنه, ихвэ, --, --, 
   {{0xaa447afa,0x5f34008f,0x00000000,0x00000000}},	//   _текл, יטשע_, --, --, 
   {{0xe8f807d6,0xe4c41422,0xe8180210,0x00000000}},	//   _илк_, айви, नेजा_, --, 
   {{0x6ac4000d,0x00000000,0x00000000,0x00000000}},	//   _लकुर, --, --, --, 
   {{0x249006ea,0x985400db,0x892400e5,0x00000000}},	// [9300] reym_, _өтөш, _پڑھو, --, 
   {{0x23640024,0xb744009f,0x00000000,0x00000000}},	//   šojo_, _ائيو, --, --, 
   {{0xe50800f1,0x00000000,0x00000000,0x00000000}},	//   _ليدو_, --, --, --, 
   {{0xa0687afb,0x2fdc0175,0x6d5c00b8,0x00000000}},	//   тада_, fzwg_, _āsap, --, 
   {{0xd00c01e2,0xe8180073,0x00000000,0x00000000}},	//   ولم_, नेचा_, --, --, 
   {{0x1cac025c,0x656c12ef,0x00000000,0x00000000}},	//   _ཕོང_, orbh, --, --, 
   {{0x3d886bde,0xd12c0131,0xa0b40114,0x00000000}},	//   احتی_, سمۇ_, _кљај, --, 
   {{0x0ca47afc,0x656c379c,0x0dc47afd,0xdb000ba1}},	//   атьи_, irbh, руши_, _proï, 
   {{0x0c700214,0x00000000,0x00000000,0x00000000}},	//   زديد, --, --, --, 
   {{0x0f780bd9,0x09cc009e,0xb3440200,0x8b200114}},	//   _באמב, াছনা, _hoçë, одње, 
   {{0x95740023,0x9c6400f2,0xfa380092,0x00000000}},	//   _ይፍትን_, _نهاو, _በዓለማ, --, 
   {{0x1be80d08,0xdc340075,0xdb007afe,0x200003b2}},	//   _идеи_, _ئىشخ, _troï, _økis_, 
   {{0xd7f8661e,0x98bc005f,0xbebc00b8,0xb3440200}},	//   тун_, lstī_, _chīg, _moçë, 
   {{0x7e787aff,0x96e800d4,0xdcf800ef,0x00000000}},	//   ngvp, тьма_, _ostī, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x73c40daf,0xc4d80640,0x00000000,0x00000000}},	//   бәге, ађу_, --, --, 
   {{0x656c14d0,0x98bc0276,0xd25858a8,0xdcf800cd}},	// [9310] arbh, aptă_, вце_, _astī, 
   {{0xf6987b00,0x2c18000d,0x00000000,0x00000000}},	//   _свој_, _परसू_, --, --, 
   {{0x61440aaf,0x00000000,0x00000000,0x00000000}},	//   مىلە, --, --, --, 
   {{0x07a40014,0xd3440330,0x00000000,0x00000000}},	//   _امیُ, _نیره_, --, --, 
   {{0x61e001e4,0x83f80064,0x00000000,0x00000000}},	//   ĝola, _веяс_, --, --, 
   {{0x2cc40327,0xed587b01,0x00000000,0x00000000}},	//   _ཀྭཿབ, гок_, --, --, 
   {{0xdb0000ae,0x02040024,0xc15401ee,0x00000000}},	//   _croí, _дзён, _мњѓњ, --, 
   {{0x85f80375,0xb4f800bc,0x00000000,0x00000000}},	//   יצוע_, ्किय_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfe740166,0x6ab400ee,0x00000000,0x00000000}},	//   _дүш_, ссих, --, --, 
   {{0x200006ea,0x00000000,0x00000000,0x00000000}},	//   _økir_, --, --, --, 
   {{0x08c800d1,0x385402e8,0x00000000,0x00000000}},	//   рғип_, жърс, --, --, 
   {{0xaab87b02,0xdc34008f,0x00000000,0x00000000}},	//   _مدثر_, _האנט_, --, --, 
   {{0x28e82abf,0x00000000,0x00000000,0x00000000}},	//   _әдип_, --, --, --, 
   {{0xe9f80051,0xa6c80150,0x00000000,0x00000000}},	//   _đặ_, _ұлпа_, --, --, 
   {{0x656c007b,0x1c1c00af,0xf79002dd,0x00000000}},	//   rrbh, _परमल_, _ﺑﻴﯩﻚ_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [9320] --, --, --, --, 
   {{0x0508015b,0xd7b8011a,0x00000000,0x00000000}},	//   লগের_, _עציר, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x71080212,0x59140327,0x649806a7,0x00000000}},	//   ахів_, _ླེབས_, _стор_, --, 
   {{0x9878008f,0x00000000,0x00000000,0x00000000}},	//   ראנט, --, --, --, 
   {{0xdb0006ed,0xa2d47b03,0x63040131,0x41b401e2}},	//   _proí, _ايست, _چوڭل, _وڅار, 
   {{0x321000ee,0x1d8800ec,0x52d4010f,0xbbc000cd}},	//   _gyzy_, ائتي_, _פולע_, शङ्क, 
   {{0xfb88036b,0x00000000,0x00000000,0x00000000}},	//   ароқ_, --, --, --, 
   {{0x8c4016a4,0x21247b04,0xd12c007b,0x00000000}},	//   чење, mmoh_, _سمك_, --, 
   {{0xd90c2263,0x2124016d,0xd7f806dc,0x98bc0153}},	//   کیب_, lmoh_, ғум_, iptą_, 
   {{0x7e6802d0,0x00000000,0x00000000,0x00000000}},	//   _iddp, --, --, --, 
   {{0x2124016d,0x00000000,0x00000000,0x00000000}},	//   nmoh_, --, --, --, 
   {{0xbb585a09,0xb8d007f7,0x6d440022,0x00000000}},	//   _талх_, _ऐफ_, ãhav, --, 
   {{0xeaf47b05,0x1cac0327,0x21240978,0x00000000}},	//   ीकृत_, _ཕོཌ_, hmoh_, --, 
   {{0x68281ef7,0x00000000,0x00000000,0x00000000}},	//   ተመለስ, --, --, --, 
   {{0x21240978,0xb3980023,0x00000000,0x00000000}},	//   jmoh_, _ዋላውን_, --, --, 
   {{0x38687b06,0x2124047e,0xdbd40139,0x083c00df}},	// [9330] _idar_, dmoh_, _näüm, _געחל, 
   {{0x8c181203,0xe7ec000d,0x00000000,0x00000000}},	//   רומי, _चइता_, --, --, 
   {{0x38680649,0xd7c4004b,0x00c802dd,0x292801e1}},	//   _kdar_, _خوښه_, әлік_, _àtaó_, 
   {{0x7e687b07,0x30147579,0xd4980108,0x00000000}},	//   _addp, одер, _сро_, --, 
   {{0x491825f9,0x4f68014b,0x00000000,0x00000000}},	//   זקאל_, ушем_, --, --, 
   {{0x21240429,0x3ec4013e,0x8d246bcd,0x64400124}},	//   amoh_, зишҳ, әниң_, ñoiv, 
   {{0x386803f9,0x2124047e,0x5108030d,0xffd40116}},	//   _odar_, bmoh_, _йĕкĕ, يغۇد, 
   {{0xacc87b08,0x38681bce,0xddd80100,0x50d41079}},	//   ргиз_, _ndar_, _metň, _ازسر, 
   {{0x7c647b09,0xce687b0a,0xbebc0055,0xddd80118}},	//   سايل, _бред_, _dhīb, _letň, 
   {{0x38687b0b,0xdb007b0c,0x3e380092,0x00000000}},	//   _adar_, _croà, ጠናከር, --, 
   {{0xe8f87b0d,0xbd6800f3,0x00000000,0x00000000}},	//   ило_, _грче_, --, --, 
   {{0x38680158,0x76440009,0x7e680010,0x657801ab}},	//   _cdar_, _afhy, _zddp, àthm, 
   {{0xe73818ac,0x00000000,0x00000000,0x00000000}},	//   рег_, --, --, --, 
   {{0x38680428,0x2b4c004e,0xcc840244,0x00000000}},	//   _edar_, mpec_, _ئۆکه_, --, 
   {{0xca6004a9,0x2b4c0427,0x2124047e,0x5f0800cd}},	//   _деһқ, lpec_, ymoh_, िवत्_, 
   {{0x1cac031c,0x2d800363,0x00000000,0x00000000}},	//   _ཕོབ_, çhey_, --, --, 
   {{0x66340166,0x21240978,0xe3b8035b,0x00000000}},	// [9340] _мэнф, vmoh_, шба_, --, 
   {{0x386802fb,0x2124014f,0x22147b0e,0x98bc0064}},	//   _zdar_, wmoh_, офер, rptą_, 
   {{0xc96c001f,0x91e07b0f,0x2124047e,0x61e001e4}},	//   _በሰፊው_, мофе, tmoh_, ĝolo, 
   {{0x7afc0219,0xbf4400c7,0x1fa80124,0x00000000}},	//   črti, зҭал, икеи_, --, 
   {{0x73740209,0x21247b10,0x9ff8007b,0x64400022}},	//   _нырх, rmoh_, جراء_, ñoiu, 
   {{0x21240978,0x21740117,0x00000000,0x00000000}},	//   smoh_, _мубр, --, --, 
   {{0x1cac0003,0x628c035a,0x2124016d,0x00000000}},	//   _ཕོད_, _ibbo, pmoh_, --, 
   {{0x0e604a4e,0x2124016d,0xa3ac134e,0x00000000}},	//   пкән, qmoh_, किप_, --, 
   {{0x1d8800ec,0x00000000,0x00000000,0x00000000}},	//   ائڪي_, --, --, --, 
   {{0x386805b1,0x60c07b11,0x00000000,0x00000000}},	//   _sdar_, ljom, --, --, 
   {{0x644404e6,0xdb000798,0xaea000d1,0x6d4400c7}},	//   _ofki, _croá, _سەيي, ãhat, 
   {{0x60c07b12,0xfaf800e2,0x26d87b13,0x2370012d}},	//   njom, snī_, _alpo_, kryj_, 
   {{0x628c7b14,0x661c005a,0xa3ac00e1,0x17240327}},	//   _obbo, _azpk, किफ_, _རྫུམ_, 
   {{0xa3ac1b4c,0x64443011,0x60c00108,0xe72c0133}},	//   किन_, _afki, hjom, ێڵی_, 
   {{0xd90c7b15,0x00000000,0x00000000,0x00000000}},	//   _لید_, --, --, --, 
   {{0x628c1e6c,0x38680989,0x38c80133,0x26d80171}},	//   _abbo, _udar_, _چاکی_, _elpo_, 
   {{0x1cac0135,0x43740212,0x33744258,0xdef00257}},	// [9350] _ཕོན_, дуєт, ягар, ፍሽን_, 
   {{0x238c00da,0xf4847b16,0x1fc002f5,0x60c00064}},	//   dējā_, _کادی, ্ছাস, ejom, 
   {{0xb4b400d4,0x00000000,0x00000000,0x00000000}},	//   _ейнш, --, --, --, 
   {{0x628c693e,0xc104004b,0x6fb801a9,0x60c00200}},	//   _ebbo, وولي, йгер_, gjom, 
   {{0xcf981f5a,0x00000000,0x00000000,0x00000000}},	//   рје_, --, --, --, 
   {{0xb8cc025c,0xad587b17,0xada47b18,0x236401e4}},	//   _པལ_, брих_, закл, ɩoj_, 
   {{0xfe7041f5,0x10140210,0x00000000,0x00000000}},	//   ئده_, _तरकश_, --, --, 
   {{0xdd8c7b19,0x238c00ef,0x00000000,0x00000000}},	//   اوي_, bējā_, --, --, 
   {{0xa3ac012c,0x6094001f,0x2b4c0118,0x09d000cd}},	//   किय_, _መምጣት_, upec_, दन्य, 
   {{0xad400372,0xdf7000ec,0xbfb44710,0x00000000}},	//   _كۉتۉ, _سگهب, _تحفت, --, 
   {{0xa968026a,0x2b4c0f85,0xa6e003b2,0x00000000}},	//   љима_, spec_, _íðin, --, 
   {{0xa3ac1df1,0xdb2401d3,0x23640024,0x9ac0031c}},	//   किम_, _ہونی, šoji_, _ċċen, 
   {{0xa098010f,0xdc3800df,0x69a80210,0x00000000}},	//   זירט, _הענר, टिही, --, 
   {{0xdb244c8b,0xfaa80472,0x98bc00c0,0x26f400bc}},	//   _فونی, _وهني_, bstį_, ँचेर_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x98bc0139,0x00000000,0x00000000,0x00000000}},	//   butı_, --, --, --, 
   {{0xe1f80679,0xbb48010f,0x00000000,0x00000000}},	// [9360] әге_, ַנאַ_, --, --, 
   {{0xd36c7b1a,0x00000000,0x00000000,0x00000000}},	//   اهل_, --, --, --, 
   {{0xa5087b1b,0x9638011a,0x644000c7,0x00000000}},	//   _гена_, _לגיט, ñois, --, 
   {{0x55b80375,0x238c00e2,0xdecc0240,0x00000000}},	//   _המטו, tējā_, ጥዎን_, --, 
   {{0x6d447b1c,0x828401a9,0x00000000,0x00000000}},	//   íhan, _оқад, --, --, 
   {{0x9e647b1d,0x628c03ac,0x238c00e2,0x60c015f1}},	//   ساتن, _ubbo, rējā_, sjom, 
   {{0x29100083,0xdb140098,0x9da80395,0x00000000}},	//   _okya_, _écés, съла_, --, 
   {{0x29107b1e,0x238c005f,0x10a000a7,0x118401d9}},	//   _nkya_, pējā_, _писн, _ژھۆٹ_, 
   {{0xfff8168d,0x61380316,0x3ae801d5,0x00000000}},	//   _بکات_, _důle, قبدی_, --, 
   {{0xbd9001ec,0x00000000,0x00000000,0x00000000}},	//   _ақкө, --, --, --, 
   {{0x39582508,0x00000000,0x00000000,0x00000000}},	//   èrs_, --, --, --, 
   {{0x2fd002b5,0x00000000,0x00000000,0x00000000}},	//   ūngū_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x99647b1f,0x29102252,0xe948010e,0xf5600023}},	//   _етил, _ekya_, _öwşü, _ገብረሚ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x5fbc2699,0xc0bc044e,0x7afc09a8,0xdb000240}},	//   ्हाल, ሳሳሊ_, črtu, _broç, 
   {{0xd90c444b,0x43947b20,0x00000000,0x00000000}},	// [9370] _لیگ_, натс, --, --, 
   {{0x51847b21,0x36d401c6,0x644000c7,0x00000000}},	//   зуда, _цоор, ñoir, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2fd8004b,0x0fe00137,0x39ac0118,0x00440023}},	//   يواد_, нөзү, _měs_, _ንበይኖ, 
   {{0x798802d0,0x00000000,0x00000000,0x00000000}},	//   htdw, --, --, --, 
   {{0xd13800c7,0xff5000e3,0xdcac004b,0x877c00df}},	//   _гха_, اخن_, یډن_, מאדי, 
   {{0xada407d6,0x613801ef,0x2c440092,0x00000000}},	//   файл, _půle, _ከቀረቡ, --, 
   {{0x9ed47b22,0xdcac33d2,0x00000000,0x00000000}},	//   змәт_, لىى_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa3ac4d53,0xab5c0034,0x291000cc,0x00000000}},	//   कित_, wyżs, _skya_, --, 
   {{0x6dd47405,0x7bc00175,0x00000000,0x00000000}},	//   _تقاض, axmu, --, --, 
   {{0x39401a48,0xb4f800e1,0x39ac013a,0x00000000}},	//   _čist_, ्कोप_, _děs_, --, 
   {{0xf0ac0150,0x00000000,0x00000000,0x00000000}},	//   удiң_, --, --, --, 
   {{0x6b887b23,0x00000000,0x00000000,0x00000000}},	//   mteg, --, --, --, 
   {{0x6b887b24,0x310c00dc,0xb0dc000d,0x00000000}},	//   lteg, िकाः_, _मतंग, --, 
   {{0xdb007b25,0x4dac00cc,0x00000000,0x00000000}},	//   _proç, _কথাং, --, --, 
   {{0x6b887b26,0x234800d1,0x00000000,0x00000000}},	// [9380] nteg, زلاپ_, --, --, 
   {{0x6b886bd7,0xbebc00b8,0x00000000,0x00000000}},	//   iteg, _ahīn, --, --, 
   {{0xa5240364,0xa87800c8,0x6b887b27,0x22147b28}},	//   _омод, ַאַר, hteg, ффар, 
   {{0xdb007b29,0x00000000,0x00000000,0x00000000}},	//   _troç, --, --, --, 
   {{0xdee40131,0x64547b2a,0x6b887b2b,0xbebc00b8}},	//   моди, mbyi, jteg, _dhīn, 
   {{0x7b1400cf,0x2bb06d58,0x64540fac,0x6b880450}},	//   nàut, जिना, lbyi, dteg, 
   {{0x6b887b2c,0x2f0801d3,0x705003e6,0x2168011c}},	//   eteg, núgy_, _ڕۆنا, _фиби_, 
   {{0x6b887b2d,0xdb6801c4,0x00000000,0x00000000}},	//   fteg, орол_, --, --, 
   {{0x1e8416c3,0x6b880af9,0xe7ec75be,0x958c02d3}},	//   _олам, gteg, _चेला_, _ምፍታሕ_, 
   {{0xdb000036,0x00000000,0x00000000,0x00000000}},	//   _isoë, --, --, --, 
   {{0x6b887b2e,0x00000000,0x00000000,0x00000000}},	//   ateg, --, --, --, 
   {{0xa3dc4103,0x6b887b2f,0x7f404242,0x00000000}},	//   तना_, bteg, _kumq, --, 
   {{0x8c4028bd,0x7f400455,0x69c07b30,0xec340150}},	//   _рече, _jumq, axle, _كومگ, 
   {{0x660000dc,0x00000000,0x00000000,0x00000000}},	//   _śoka, --, --, --, 
   {{0xb8e400bd,0x34947b31,0x8a78011a,0x00000000}},	//   _এত_, навр, _ואות, --, 
   {{0xadf0367a,0x13a401e2,0x00000000,0x00000000}},	//   _अइसन_, ونزی_, --, --, 
   {{0xd2687b32,0x7f400483,0x2bb00034,0xc0440023}},	// [9390] قصان_, _numq, जिया, _ብሓላፍ, 
   {{0x98bc00bc,0xd5b801ec,0xc6f858e5,0x00000000}},	//   yptě_, _дсм_, _оных_, --, 
   {{0x6b8805f5,0x46a8000d,0x518400c7,0xd5840345}},	//   zteg, _छोटह, ьуаа, _تێزه_, 
   {{0x6b887b33,0x712400d1,0x999c00c0,0x6d4400d7}},	//   yteg, رىشم, lbtų_, íham, 
   {{0x752c7b34,0x7f401730,0x2ef4005b,0x6b880009}},	//   mmaz, _cumq, нздр, xteg, 
   {{0x752c7b35,0x7f4016b8,0xe3c40086,0xaaac05f9}},	//   lmaz, _dumq, ùñen_, _झोंक, 
   {{0xdd8c7b36,0xddd80421,0x7f4016b8,0xf23401ed}},	//   موو_, _fetō, _eumq, _سبسک, 
   {{0x752c7b37,0x00000000,0x00000000,0x00000000}},	//   nmaz, --, --, --, 
   {{0xeb987b38,0x7f40011f,0x6b8801c6,0xfb841079}},	//   чип_, _gumq, uteg, نگوی, 
   {{0x5fbc2983,0x1ee801ed,0xaa44129d,0x00000000}},	//   ्हरल, _فوقی_, ةندى, --, 
   {{0x6b887b39,0xa8840222,0x752c7b3a,0x4094215c}},	//   steg, ىلدى, kmaz, _سلەر, 
   {{0x6d407b3b,0x02dc00dc,0x00000000,0x00000000}},	//   _iula, _यत्न, --, --, 
   {{0xbd2c1a4c,0x291c00da,0x752c17a3,0xead40b7e}},	//   _וואָ, ēta_, dmaz, _подь, 
   {{0xe5a47b3c,0x26dc043b,0xa3ac07f7,0x28dc095f}},	//   ниги, óto_, किस_, मसहि, 
   {{0x6d407b3d,0x64540175,0x00000000,0x00000000}},	//   _jula, tbyi, --, --, 
   {{0x6d407b3e,0xdefc031c,0x752c00a2,0x00000000}},	//   _mula, ċċin_, gmaz, --, 
   {{0x6d407b3f,0xa3e801c0,0x6d440306,0x753401c6}},	// [93a0] _lula, чдаа_, íhaj, тэрх, 
   {{0x6d407b40,0x7f40003a,0x752c0083,0x7b140ba1}},	//   _oula, _rumq, amaz, làur, 
   {{0x7f407b41,0xc0bc00b7,0xb54400c7,0x00000000}},	//   _sumq, ዳዳሪ_, _аҧса_, --, 
   {{0x2a640112,0x30a40212,0x7100035b,0x752c0205}},	//   halb_, крів, аҧса, cmaz, 
   {{0x6d407b42,0xdb00004a,0x7f401ffc,0xdc1c25c9}},	//   _aula, _croû, _qumq, _परेड_, 
   {{0x20180a28,0xd00c7b43,0x63a401fa,0x7f40047e}},	//   āpi_, حله_, _iskn, _vumq, 
   {{0x629c7b44,0x7f400117,0xbebc00b0,0x781c05d7}},	//   mepo, _wumq, _whīo, _नर्क_, 
   {{0x7f40003a,0x0fc001e0,0x00000000,0x00000000}},	//   _tumq, тйән, --, --, 
   {{0x9a847b45,0x6f0c0066,0x35700023,0x00000000}},	//   нунл, èncè, ስባታት_, --, 
   {{0x6d407b46,0x2a6405d5,0x00000000,0x00000000}},	//   _fula, galb_, --, --, 
   {{0x5cd402bf,0x752c7b47,0xd83801c6,0xaf4c0023}},	//   _підх, ymaz, зэг_, _ዝተሓወ, 
   {{0x629c7b48,0xff540023,0x995c013a,0x00000000}},	//   hepo, _ዝተሰመ, _téže_, --, 
   {{0x629c7b49,0x6d407b4a,0x3eb8180f,0xb90800dc}},	//   kepo, _zula, _òrts_, _यत_, 
   {{0x629c7b4b,0x6d407b4c,0xdcf80166,0x2a640477}},	//   jepo, _yula, _irtı, calb_, 
   {{0x9ba00075,0x6d407b4d,0x752c7b4e,0xcc3000c7}},	//   _شەھى, _xula, tmaz, _ихәы, 
   {{0xc7b4013f,0x58840510,0x752c0077,0xc9801d5b}},	//   _frɑ_, _чыка, umaz, _суши, 
   {{0x629c0098,0xb4d800dc,0x3ce80037,0x00000000}},	// [93b0] fepo, ऽसौ_, _जतने_, --, 
   {{0x629c7b4f,0xbebc0882,0x614403cc,0x2bb000dc}},	//   gepo, _bhīm, چىلە, जिता, 
   {{0x752c1e0c,0x657801ab,0x614400d1,0xdc6c0092}},	//   pmaz, àtht, نىلە, _በፀሐይ_, 
   {{0x6d407b50,0xbebc00dc,0x1cd80327,0x00000000}},	//   _rula, _dhīm, ོིས_, --, 
   {{0x6d407b51,0x629c7b52,0xfeb802f2,0x00000000}},	//   _sula, bepo, کانت_, --, 
   {{0x6d407b53,0xa3ac367a,0x1ee8168d,0xb8ec031c}},	//   _pula, किर_, وونی_, _ློ_, 
   {{0xdcf87b54,0x6d407b55,0x00000000,0x00000000}},	//   _artı, _qula, --, --, 
   {{0x6d407b56,0x776c06be,0x00000000,0x00000000}},	//   _vula, _ovax, --, --, 
   {{0x6d407b57,0xb5d400fe,0x2a647b58,0xeb28009d}},	//   _wula, _হেমচ, talb_, мжил_, 
   {{0x6d407b59,0x3f1401af,0x7c2400c7,0x00000000}},	//   _tula, _бдус, ызыҧ, --, 
   {{0x6d407b5a,0xec7005d9,0xdcf80166,0x1ee80326}},	//   _uula, _نٿا_, _ertı, _تولی_, 
   {{0x629c7b5b,0x6b747b5c,0x660000b8,0xebd8009b}},	//   zepo, _алду, _śoko, _одеш_, 
   {{0x629c7b5d,0x9cd40375,0x00000000,0x00000000}},	//   yepo, _שונה_, --, --, 
   {{0x2cac7b5e,0x00000000,0x00000000,0x00000000}},	//   lded_, --, --, --, 
   {{0x2cac136c,0xe9a4014b,0x00000000,0x00000000}},	//   oded_, _райп, --, --, 
   {{0xa3ac09d9,0x629c7b5f,0xa8040166,0xe28c01a9}},	//   किल_, wepo, _agış, hnаt_, 
   {{0x93407b60,0x629c7b61,0x2cac7b62,0x29000009}},	// [93c0] инте, tepo, ided_, mnka_, 
   {{0x629c0093,0x2cac05c7,0xd36c7b63,0x29000009}},	//   uepo, hded_, زهم_, lnka_, 
   {{0x290001d9,0x16740375,0x30880023,0xd654025d}},	//   onka_, _בגיל_, _ዘምጽእ_, _שיטת_, 
   {{0x629c7b64,0x29007b65,0xdcf80135,0xdbd000c5}},	//   sepo, nnka_, _istħ, tüüp, 
   {{0x2cac7b66,0x29007b67,0x629c260d,0x717000f7}},	//   dded_, inka_, pepo, _ۇۇلا, 
   {{0x2cac0428,0x29000198,0x00000000,0x00000000}},	//   eded_, hnka_, --, --, 
   {{0xe044024c,0x5bc800cd,0x00000000,0x00000000}},	//   _анби, िह्व, --, --, 
   {{0x2fd0025a,0x2cbc0042,0x2cac0165,0x20e8010f}},	//   ëngë_, _cnwd_, gded_, rŝis_, 
   {{0x2900058a,0xde940345,0xdd9001ec,0x00000000}},	//   dnka_, _لجاب, уақы, --, 
   {{0x79587b68,0x29007b69,0x5dd80276,0xa3a809bb}},	//   ниор_, enka_, _офер_, _खनन_, 
   {{0x776c0055,0x69f0004e,0x00000000,0x00000000}},	//   _svax, йүшт, --, --, 
   {{0x3eac025c,0x2cbc0142,0xdca400f0,0x68ec013a}},	//   _hadt_, _gnwd_, _јади, _ňadr, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2900093c,0xb9b4007b,0x00000000,0x00000000}},	//   anka_, _ممتع, --, --, 
   {{0x94a8009d,0x00000000,0x00000000,0x00000000}},	//   мтаа_, --, --, --, 
   {{0x92ac015b,0xa3dc00dc,0xbebc00b8,0xa3ac2d3b}},	//   _ওকে_, तनं_, _bhīk, किं_, 
   {{0x04640124,0x77c8002e,0x613800bc,0x657801ab}},	// [93d0] ртсм, _dëxë, _půln, àthr, 
   {{0x63a07b6a,0x2cac03bd,0x78ac7b6b,0x4394094c}},	//   çona, zded_, _haav, рафс, 
   {{0x78ac7b6c,0x75d400c6,0x46140050,0x30741513}},	//   _kaav, _إيجا, _نوٝر, гулс, 
   {{0x74147b6d,0x2c7807c5,0x6578007b,0x78ac7b6e}},	//   _موجا, _müdà_, áthe, _jaav, 
   {{0x78ac7b6f,0xaed40845,0xa3dc00cd,0x00000000}},	//   _maav, лодш, तनः_, --, 
   {{0x6e947b70,0x753c1b7a,0x78ac7b71,0x88b0016b}},	//   الغا, _hisz, _laav, _nkɛn, 
   {{0x753c00dd,0x29007b72,0x2cac0165,0x81380228}},	//   _kisz, ynka_, tded_, رسۅز_, 
   {{0x2cac7b73,0x78ac7b74,0x3ae000a3,0x6f640214}},	//   uded_, _naav, _ròpa_, _مهرم, 
   {{0x2cac7b75,0x09c800dc,0x753c1f6f,0x2cb00118}},	//   rded_, ाह्य, _misz, ězd_, 
   {{0x753c7b76,0xeac435dd,0x2cac4fdf,0xfeb80244}},	//   _lisz, убоп, sded_, _لامت_, 
   {{0x78ac0a49,0xd87401d9,0xedd400ae,0x00000000}},	//   _baav, گمُت_, _حياد, --, 
   {{0x29000050,0x78ac0005,0x753c033f,0x00000000}},	//   unka_, _caav, _nisz, --, 
   {{0x78ac7b77,0xeb987b78,0xcbc405af,0x29002149}},	//   _daav, _чил_, _جزاي, rnka_, 
   {{0x753c0036,0x612800d7,0xee4408a5,0x00000000}},	//   _aisz, mýle, _þýdd_, --, 
   {{0x78ac096b,0x2c7807c5,0x660400a7,0x753c1785}},	//   _faav, _güdà_, упва, _bisz, 
   {{0x78ac7b79,0x753c1790,0xd5b4004d,0xe2a87b7a}},	//   _gaav, _cisz, ứng_, کارن_, 
   {{0x753c1f96,0x24900267,0x657801f6,0x00000000}},	// [93e0] _disz, rfym_, áthb, --, 
   {{0x33d402bf,0x78ac1418,0x753c1196,0x00000000}},	//   шіст, _zaav, _eisz, --, 
   {{0x78ac7b7b,0xbebc00b0,0x9340084c,0x753c033f}},	//   _yaav, _whīk, инӂе, _fisz, 
   {{0x74540c04,0x600802d5,0x6aa07b7c,0x673c0200}},	//   _върх, ннем_, helf, _hipj, 
   {{0x6aa07b7d,0x3eac010a,0xc33800c7,0x673c01f5}},	//   kelf, _padt_, _аҕа_, _kipj, 
   {{0xe16447ea,0xdda87b7e,0x3eac0327,0x612801ef}},	//   _مدري, етил_, _qadt_, dýle, 
   {{0x6aa07b7f,0xc0c47b80,0x8d707b81,0x656c01ab}},	//   delf, _вәли, مايا, nsbh, 
   {{0x3cd4316e,0x673c7b82,0x656c03d5,0xbb74033a}},	//   ржис, _lipj, isbh, агиј, 
   {{0xcb6407b5,0x78ac7b83,0xd04000ec,0x00000000}},	//   гање_, _raav, _اھمي, --, 
   {{0x78ac7b84,0x6aa07b85,0x68f400ee,0xad640451}},	//   _saav, gelf, _amyd, _چانه, 
   {{0x7994052f,0x5ac80cef,0x527800c8,0x78ac7b86}},	//   шинф, _үлем_, ענטא, _paav, 
   {{0x27e47b87,0x78ac20ac,0x98c47b88,0x6e24002f}},	//   _żona_, _qaav, усол, ühbe, 
   {{0x78ac7b89,0xed340139,0x55040022,0x00000000}},	//   _vaav, _тэфэ, ҳчаа, --, 
   {{0x78ac7b8a,0x8aa002e8,0x00000000,0x00000000}},	//   _waav, _гръд, --, --, 
   {{0x78ac7b8b,0x49b402dd,0x753c7b8c,0x63a007ea}},	//   _taav, _مايد_, _pisz, çonn, 
   {{0x8544084c,0x2ed00073,0x00000000,0x00000000}},	//   сэре, _तक्त, --, --, 
   {{0x753c066d,0xdcf800ef,0x26180b4c,0x00000000}},	// [93f0] _visz, _aptī, _मुठी_, --, 
   {{0x6578007b,0x35f42d29,0x753c2634,0x5bd000cd}},	//   áthc, _впор, _wisz, _तथैव, 
   {{0x753c066d,0x4394005e,0x70540a2c,0x65ac00c7}},	//   _tisz, _қарс, لناا, rõhá, 
   {{0x6aa00936,0x9f940254,0xc0c80114,0x753c012d}},	//   zelf, büüt_, луче_, _uisz, 
   {{0x93887b8d,0x087800c8,0x8e7006dc,0x80640024}},	//   _ясна_, רעדט_, йқаш, свіж, 
   {{0xd9f40ce0,0x6aa004e6,0xa2c000fd,0x26180ce0}},	//   ुपात_, xelf, _мәхк, _मुडी_, 
   {{0x6cc40dab,0x00000000,0x00000000,0x00000000}},	//   ийка, --, --, --, 
   {{0xeb987b8e,0x6aa001f5,0x61280216,0xbdf87b8f}},	//   вии_, welf, týle, درها_, 
   {{0xa3ac3be5,0x50b400fb,0x00000000,0x00000000}},	//   किए_, _исҡу, --, --, 
   {{0x87e400d1,0x86500023,0x00000000,0x00000000}},	//   ەتسە, ማንነት, --, --, 
   {{0xdeb80bd9,0xa8c401af,0x7ed400db,0x6aa00115}},	//   _שמעל, айнд, _ازقا, relf, 
   {{0x6aa07b90,0xab9400d6,0x661c002d,0x8cc4030d}},	//   self, _виді, _rypk, _сĕмĕ_, 
   {{0x7d047b91,0x661c7b92,0x37747b93,0xf1f8012d}},	//   čist, _sypk, йырс, ्पड़_, 
   {{0x7ae800a3,0x44240327,0x661c7b94,0x00000000}},	//   chdt, _ġm_, _pypk, --, 
   {{0x24f47b95,0xeb1001f9,0x00000000,0x00000000}},	//   ачар, ठकीत_, --, --, 
   {{0x673c0076,0x61380118,0x68f4010b,0x00000000}},	//   _wipj, _půlm, _umyd, --, 
  
   {{0x62647b96,0x673c7b97,0x28200050,0x00000000}},	// [9400] иваа, _tipj, _گژھہ, --, 
   {{0x58f00327,0x9f940254,0x00000000,0x00000000}},	//   _བཏོས_, rüüt_, --, --, 
   {{0x21a47b98,0xa508013d,0xe04400c7,0x00000000}},	//   рием, _аена_, анеи, --, 
   {{0x546400fd,0x2e8000b5,0x357c0092,0xdfd0007b}},	//   _каюм_, _ｈlホ_, _እልባት_, ييض_, 
   {{0x44247b99,0xd12c4cdb,0x7ae80076,0xf08802c9}},	//   _ám_, ذمه_, yhdt, ائمه_, 
   {{0xa2e47b9a,0xdd98504f,0xdb0000a2,0x00000000}},	//   _тогд, вши_, _broý, --, 
   {{0x61382fe5,0x9ce4011c,0x00000000,0x00000000}},	//   _ачар_, ицил, --, --, 
   {{0x3d107b9b,0x25b80204,0xa1140131,0x00000000}},	//   ावें_, _mrpl_, _ئورت, --, 
   {{0xc0c400d1,0x4f8401d9,0x712401d5,0xde741411}},	//   _вәһи, _نالہ, _طرفل, _نداع, 
   {{0x1ea800b2,0x00000000,0x00000000,0x00000000}},	//   _جاري_, --, --, --, 
   {{0x39147b9c,0x7e6802d0,0xeff00092,0xf8b8586f}},	//   ймор, _iedp, ሂደው_, гөп_, 
   {{0x63b40024,0x00000000,0x00000000,0x00000000}},	//   kvyn, --, --, --, 
   {{0xbebc0055,0x5fc4060c,0xbb547b9d,0x00000000}},	//   _dhīv, लमिल, _انتب, --, 
   {{0xa3d8007d,0xcab000ae,0x00000000,0x00000000}},	//   ़हन_, _ومنظ, --, --, 
   {{0xbebc02b1,0xd5a001d5,0x00000000,0x00000000}},	//   _whīw, غلری, --, --, 
   {{0x65780597,0x7e687b9e,0x613801ef,0xd4980395}},	//   átha, _ledp, _důlk, ърг_, 
   {{0xb2740da6,0xe27400f7,0x938802e8,0x59ac3711}},	// [9410] йлаш, өктө, ъсва_, टिकर, 
   {{0x38680c30,0x7e682b96,0xcb540375,0x8b540a7c}},	//   _hear_, _nedp, יסמה_, יימס_, 
   {{0x38680225,0x83645a05,0x518402a9,0x717800f3}},	//   _kear_, مدەل, руза, убер_, 
   {{0x3d10033f,0x00000000,0x00000000,0x00000000}},	//   ावों_, --, --, --, 
   {{0x38687b9f,0x7e687ba0,0x0f5007d6,0xcfa400c7}},	//   _mear_, _bedp, تکزگ, ршеи, 
   {{0x38687ba1,0xddd802e2,0xdb0000ee,0x00000000}},	//   _lear_, _metņ, _proý, --, 
   {{0xd138035b,0xa2447ba2,0x00000000,0x00000000}},	//   _аха_, _ایمل_, --, --, 
   {{0xa9a42544,0x38687ba3,0xab6402e8,0xef6401c4}},	//   ەمدى, _near_, бвил, _гэжү, 
   {{0x7e6804cc,0x764400ad,0x00000000,0x00000000}},	//   _fedp, _oghy, --, --, 
   {{0x58f0038f,0x76440cfd,0xdb007ba4,0x9524031c}},	//   _བཏུས_, _nghy, _groü, _ཡེའི_, 
   {{0xbe647427,0x386826e7,0x75280327,0x59ac0210}},	//   _ذهني, _bear_, ċezj, टिगर, 
   {{0x38687ba5,0x7644062c,0x7e68009a,0xe72c022e}},	//   _cear_, _aghy, _zedp, _shе_, 
   {{0x38687ba6,0xc4482be7,0xaa440408,0x00000000}},	//   _dear_, ییدن_, _лелл, --, 
   {{0xe8f81884,0xdc3400c8,0x38680363,0x613800bc}},	//   _әли_, _פאסט_, _eear_, _půlk, 
   {{0xf5b41def,0x38680c18,0x64982e1d,0x00000000}},	//   остю, _fear_, лтар_, --, 
   {{0xa2d802ab,0x38687ba7,0x63b40024,0xa4440107}},	//   पॉन्, _gear_, tvyn, снад, 
   {{0xe298152d,0x64a40184,0x2fdc01d4,0xb9080116}},	// [9420] лаа_, _һана, jywg_, _әнөз_, 
   {{0x386801c4,0x37f800df,0x00000000,0x00000000}},	//   _zear_, _כּתב, --, --, 
   {{0x38687ba8,0x64a47ba9,0x7e687baa,0x65b80276}},	//   _year_, _лана, _redp, _супр_, 
   {{0x92541621,0xa0687bab,0x64a40022,0x00000000}},	//   _ҳаёт_, уада_, _уама, --, 
   {{0xdef87bac,0x64447bad,0x55500345,0xc00400c7}},	//   лык_, _igki, _وپیر, цҿак, 
   {{0x6e207bae,0x7e68014f,0xe168009a,0x00000000}},	//   _bylb, _qedp, _مصره_, --, 
   {{0x7e685794,0x3d14302b,0x00000000,0x00000000}},	//   _vedp, दवले_, --, --, 
   {{0x3b541ea2,0xb5d400fe,0x4fe47baf,0x6e20036e}},	//   окир, _হেঁচ, рмән_, _dylb, 
   {{0x64443223,0xbebc00dc,0x38687bb0,0xa3ac1431}},	//   _mgki, _bhīt, _rear_, किट_, 
   {{0x38687bb1,0x41dc1b61,0xbebc00b8,0x6e200142}},	//   _sear_, _यथास, _chīt, _fylb, 
   {{0xbebc002b,0x95740023,0x38687bb2,0x76440055}},	//   _dhīt, _ክፍትን_, _pear_, _rghy, 
   {{0xf8b87aea,0xbebc00b8,0x95c801d5,0x00000000}},	//   рөк_, _ehīt, қуга_, --, 
   {{0xd7f87bb3,0xab601a50,0x657800c6,0xb7b8015b}},	//   уун_, _قۇيى, áthn, ুন্ট, 
   {{0x64440d04,0x38687bb4,0x8c180375,0x15a800a7}},	//   _agki, _wear_, _עוגי, лъби_, 
   {{0xcb0406f6,0x588400c7,0x38687bb5,0xd4982095}},	//   _ديون_, _лыпа, _tear_, лра_, 
   {{0x628c035a,0x4df8010f,0x00000000,0x00000000}},	//   _acbo, אפלא, --, --, 
   {{0xdb00030a,0x2848010f,0xd1380131,0x00000000}},	// [9430] _hroñ, _דעפּ, ңхе_, --, 
   {{0x64440d04,0xf69810fc,0xdb000055,0xa2c0008e}},	//   _egki, _твој_, _kroñ, мәск, 
   {{0x9600015b,0xd5b85ce7,0x00000000,0x00000000}},	//   _এরকম_, _ссп_, --, --, 
   {{0x63ac0598,0xf4843135,0x6fb87bb6,0x00000000}},	//   ännä, _بادی, игер_, --, 
   {{0x6e20000f,0x64580356,0x00000000,0x00000000}},	//   _sylb, _ştig, --, --, 
   {{0xdfcc5ac4,0xdd8c3016,0x236401e4,0xde440116}},	//   ئيو_, چوو_, ɨoj_, يرىۋ, 
   {{0xed584e7c,0xdd8c7bb7,0x9d5000f1,0x9e9400d1}},	//   шой_, نوو_, ونوت, تانچ, 
   {{0x009401c0,0xbebc00b8,0xa3e400dc,0x8d8401d5}},	//   _нисэ, _bhīs, यैव_, _ҳудд, 
   {{0x4fc4223e,0x84900023,0x6a840150,0x00000000}},	//   _усва, _ዝኽእላ_, олпа, --, 
   {{0xdb00030a,0xbebc0055,0x9b000006,0x00000000}},	//   _broñ, _dhīs, дзьд, --, 
   {{0xa96815ed,0xdb001f40,0xbbe801b9,0xfb8800db}},	//   јима_, _proò, لریم_, абөк_, 
   {{0x3ea02d2b,0xdb000165,0xbebc0374,0xddd80118}},	//   đite_, _droñ, _whīt, _netř, 
   {{0x7d247bb8,0x610c0115,0x00000000,0x00000000}},	//   _эффе, nĝla, --, --, 
   {{0x65787bb9,0xfc14009d,0x00000000,0x00000000}},	//   átho, _эмчэ, --, --, 
   {{0xdb000156,0x4a7001ec,0x00000000,0x00000000}},	//   _groñ, _дықт, --, --, 
   {{0xe4587bba,0x39587bbb,0xdb00032e,0x6aa80b4c}},	//   ржа_, írse_, _hroð, _कसुर, 
   {{0x628c037e,0xb9c40228,0x5c34010f,0x00000000}},	// [9440] _pcbo, _وقۇي, ַרען_, --, 
   {{0x625802a9,0x77a8009f,0x00000000,0x00000000}},	//   ррар_, _اُٿِ_, --, --, 
   {{0xa3ac0ebb,0x00000000,0x00000000,0x00000000}},	//   किङ_, --, --, --, 
   {{0x9f9400c5,0x71640116,0x00000000,0x00000000}},	//   _tüüp_, سامك, --, --, 
   {{0xbba81d72,0xc0cc0092,0x00000000,0x00000000}},	//   _कनेक, _በአል_, --, --, 
   {{0xe18800ec,0x1ea8007b,0x00000000,0x00000000}},	//   _پئسن_, شاتي_, --, --, 
   {{0xbebc00cd,0xa0680139,0xfcc40166,0x00000000}},	//   _bhīr, _ваба_, зәлм, --, 
   {{0x3074009d,0x00000000,0x00000000,0x00000000}},	//   _нуус, --, --, --, 
   {{0xbebc00dc,0x20007bbc,0x00000000,0x00000000}},	//   _dhīr, _äki_, --, --, 
   {{0x21247bbd,0x3ae0007f,0x58f0025c,0x00000000}},	//   lloh_, _kòpi_, _བཏངས_, --, 
   {{0x39586c57,0xe3c004c5,0x6e2c03f9,0x26180490}},	//   ërs_, োনিব, ƙaba, _मुली_, 
   {{0x21240369,0x5bc400c6,0xbebc0055,0x395800e2}},	//   nloh_, _وقال, _ghīr, īrs_, 
   {{0x2124011f,0xdb00148b,0x00000000,0x00000000}},	//   iloh_, _froð, --, --, 
   {{0x3f5007ae,0x7d007bbe,0x21247bbf,0xdb00030a}},	//   _màu_, lims, hloh_, _troñ, 
   {{0x7ec000d0,0xddd80118,0x3f500051,0x8624003b}},	//   _zápä, _petř, _làu_, дьте, 
   {{0x7d007bc0,0x79887bc1,0xe3d40183,0x7c2400a3}},	//   nims, mudw, _সেইব, _ùirs, 
   {{0x96440323,0x43945d29,0x79887bc2,0x093402da}},	// [9450] _мэнд, матс, ludw, _تروج, 
   {{0x539876e2,0x7d007bc3,0xd2587bc4,0xc74801d9}},	//   _ህይወት_, hims, рца_, _گٔیو_, 
   {{0x7d007bc5,0xdb00005b,0x15a802e8,0x7654012d}},	//   kims, _isoä, _тъпи_, mczy, 
   {{0x76540034,0x2124011f,0x50a010a8,0x3f500208}},	//   lczy, gloh_, بەرل, _bàu_, 
   {{0xad240075,0x1cd80327,0x7d00013a,0x3f500208}},	//   ۋىتى, ོིན_, dims, _càu_, 
   {{0x643804ac,0x3f50002e,0x79887bc6,0x51847bc7}},	//   _לערנ, _dàu_, kudw, _муба, 
   {{0x2124011f,0x7d000076,0x00000000,0x00000000}},	//   bloh_, fims, --, --, 
   {{0x21240429,0xd7c80a59,0x79887bc8,0x7d000064}},	//   cloh_, ामाच, dudw, gims, 
   {{0x3f500208,0x2ef40354,0x00000000,0x00000000}},	//   _gàu_, _езар, --, --, 
   {{0xbebc7bc9,0x7654033f,0x798803cb,0x63a00200}},	//   _whīr, jczy, fudw, çoni, 
   {{0x79880117,0x69247bca,0xfeb800cf,0x7654033f}},	//   gudw, змна, _باقت_, dczy, 
   {{0x684400ee,0x7654033f,0x657801e7,0x70d8000d}},	//   янма, eczy, áthm, _भकोल, 
   {{0xe7380184,0x7c94006c,0xdb000252,0x00000000}},	//   йем_, _آشما, _troð, --, 
   {{0x6b880099,0x21240369,0xe7381d1c,0x79887bcb}},	//   mueg, zloh_, сег_, budw, 
   {{0x6b882f06,0x21240429,0x357c0092,0x161c000d}},	//   lueg, yloh_, _እልቂት_, _मुदर_, 
   {{0x6b880489,0xa90800ec,0x00000000,0x00000000}},	//   oueg, _ديبل_, --, --, 
   {{0x76547bcc,0x6b8819f5,0x638401c0,0x53a07bcd}},	// [9460] bczy, nueg, ягаа, натб, 
   {{0x7d007bce,0x612802f0,0xd7f8011a,0x76540210}},	//   zims, týlo, _להפל, cczy, 
   {{0x6b880789,0x764000c7,0x7d002ca8,0xdce80356}},	//   hueg, _аҭра, yims, nsfă, 
   {{0x29007bcf,0x26d87bd0,0x7d007bd1,0x00000000}},	//   nika_, _hopo_, xims, --, 
   {{0x26d87bd2,0x6b88015b,0x21247bd3,0x290004ba}},	//   _kopo_, jueg, rloh_, iika_, 
   {{0x6b8827be,0x26d800ec,0x5d642119,0xa3e400dc}},	//   dueg, _jopo_, птиз, यैः_, 
   {{0x29007bd4,0x26d87bd5,0x2124003e,0xe28c022e}},	//   kika_, _mopo_, ploh_, mgа_, 
   {{0x29007bd6,0x3f500016,0x76540034,0x26d87bd7}},	//   jika_, _tàu_, zczy, _lopo_, 
   {{0x29007bd8,0x6b887bd9,0x8c5006b6,0x7988014b}},	//   dika_, gueg, رئيا, wudw, 
   {{0x26d87bda,0xeb300372,0xe28c01a9,0xf97800ea}},	//   _nopo_, نۉند, ngа_, обој_, 
   {{0xdca4234c,0x2f1800db,0x1c441797,0x00000000}},	//   _нажи, _بىلگ_, _енем, --, 
   {{0x26d80b23,0x76540034,0x7d007bdb,0x6b887bdc}},	//   _aopo_, wczy, qims, bueg, 
   {{0x26d8020c,0x6b880ffb,0x00000000,0x00000000}},	//   _bopo_, cueg, --, --, 
   {{0xa3c03eaf,0x26d806ed,0x2900023a,0x00000000}},	//   ्मन_, _copo_, aika_, --, 
   {{0x26d80c04,0xcb1004ac,0x29007bdd,0x76541afd}},	//   _dopo_, _אלס_, bika_, rczy, 
   {{0x29000516,0xe81c22e3,0x391401ce,0x25bc0162}},	//   cika_, _युवा_, _імпр, ætla_, 
   {{0x38c80424,0x2bb005f9,0x7654012d,0x00000000}},	// [9470] _هاکی_, ड़िया, pczy, --, 
   {{0x674400d0,0x26d80356,0xc6f80108,0x00000000}},	//   ľujú, _gopo_, _нных_, --, 
   {{0x6b8801c6,0x82340e76,0x67440030,0x41e40006}},	//   zueg, ىرما, žujú, ніца, 
   {{0x93c40356,0x27e40003,0x2c1c0073,0x823400db}},	//   _arăţ, _żoni_, _पडलं_, ررلا, 
   {{0x93c4054e,0x6b88005a,0xe28c01a9,0xbb240150}},	//   _brăţ, xueg, bgа_, _ﺼﻭﻡ_, 
   {{0xad587bde,0xa3d800e1,0xada47bdf,0x87b8010f}},	//   орих_, ़हर_, дакл, פלוס_, 
   {{0xfe707be0,0x29007be1,0x6b8801f2,0x32040108}},	//   اده_, yika_, wueg, _äly_, 
   {{0x29007be2,0xf0e86073,0x6b887be3,0x00000000}},	//   xika_, _بىرى_, tueg, --, 
   {{0x93c40311,0x395c045a,0x3e7801d3,0x00000000}},	//   _frăţ, _atvs_, _sütő_, --, 
   {{0x6b887be4,0x29007be5,0x00000000,0x00000000}},	//   rueg, wika_, --, --, 
   {{0x29007be6,0x6b8804c9,0x26d87be7,0x00000000}},	//   tika_, sueg, _ropo_, --, 
   {{0x26d87be8,0xa3c000cd,0xe28c01a9,0x00000000}},	//   _sopo_, ्मम_, zgа_, --, 
   {{0x395c0254,0x00000000,0x00000000,0x00000000}},	//   _etvs_, --, --, --, 
   {{0x29007be9,0x161c05f9,0xa968074d,0xe5a47bea}},	//   sika_, _मुहर_, _дика_, миги, 
   {{0x29007beb,0x28b81142,0x273400b5,0x35c40107}},	//   pika_, _дупэ_, hæng_, нарҳ, 
   {{0x29004b2a,0xa3e813d6,0x26d80248,0x00000000}},	//   qika_, одба_, _wopo_, --, 
   {{0x26d87bec,0x29100796,0xa8040212,0x7b080413}},	// [9480] _topo_, _ijya_, _ізол, _óstý, 
   {{0x26d8011c,0xdecc0023,0x6f0c00ae,0x9f9800fd}},	//   _uopo_, ኣቱን_, éacl, läçe_, 
   {{0x6454020c,0xe28c01d5,0xc5f80154,0x00000000}},	//   pcyi, rgа_, _আঁকা_, --, 
   {{0x58f0025c,0x323801f7,0x00000000,0x00000000}},	//   _བཏབས_, سينگ_, --, --, 
   {{0x4f546e9a,0xd6d402f2,0xde380023,0x00000000}},	//   وجود_, _روێش_, ትዘንግ, --, 
   {{0xa3c01414,0x613801ef,0x8d707bed,0x00000000}},	//   ्मठ_, _půls, چايا, --, 
   {{0x273404ce,0x8d7000f1,0x9f980139,0x00000000}},	//   mænd_, نايا, käçe_, --, 
   {{0x629c0354,0xfb8807d6,0x29100230,0x357c001f}},	//   lfpo, проқ_, _njya_, _እውቀት_, 
   {{0x9a5000b8,0xd00410de,0x629c01a4,0x8d140116}},	//   _arāḍ, _жете_, ofpo, بزور_, 
   {{0x291001aa,0xddc4026a,0xbcfc00e4,0x2b58021c}},	//   _ajya_, _обзи, _otĩg, ísca_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x80e003f4,0x63a47bee,0x2a680841,0x5c0405a2}},	//   পোর্, _opkn, _đabe_, _ояла, 
   {{0x88b00134,0x2d900724,0x6458013f,0xc7b80006}},	//   _akɛs, _äzer_, _ɑtit, мёр_, 
   {{0xdcf815b7,0x00000000,0x00000000,0x00000000}},	//   _istı, --, --, --, 
   {{0x64580276,0x63a40166,0x9f980139,0x00000000}},	//   _ştia, _apkn, bäçe_, --, 
   {{0x39987bef,0x629c01f5,0x00000000,0x00000000}},	//   més_, efpo, --, --, 
   {{0x39987bf0,0x88b00085,0x490401ec,0x85447bf1}},	// [9490] lés_, _ekɛs, _جويق, тэре, 
   {{0x35b47bf2,0x39487bf3,0x95c87bf4,0x7f48014f}},	//   _збор, _hias_, _дума_, _nidq, 
   {{0x39987bf5,0x39487bf6,0xdbd4005b,0x00000000}},	//   nés_, _kias_, _hääm, --, 
   {{0x30147bf7,0x776c0944,0xdbd40108,0x00000000}},	//   ндер, _kwax, _kääm, --, 
   {{0x399820ef,0x39487bf8,0xdbd405a7,0xc3940184}},	//   hés_, _mias_, _jääm, _иҫтә, 
   {{0x39487bf9,0x39987bfa,0x7f74003b,0x00000000}},	//   _lias_, kés_, туїц, --, 
   {{0xdcf87bfb,0x5e540592,0x80a400eb,0x00000000}},	//   _astı, رليس_, ওয়্, --, 
   {{0x39487bfc,0x39987bfd,0x776c014b,0x2734037e}},	//   _nias_, dés_, _owax, mæne_, 
   {{0x776c02c4,0xdbd401c7,0xe0d0008f,0x00000000}},	//   _nwax, _nääm, _גײן_, --, 
   {{0xa3c04a01,0x29100158,0x39487bfe,0x9a500055}},	//   ्मत_, _sjya_, _aias_, _prāḍ, 
   {{0x776c7bff,0x39987c00,0x39487c01,0x9e940e56}},	//   _awax, gés_, _bias_, _سالچ, 
   {{0x39487c02,0x7b1c0166,0x00000000,0x00000000}},	//   _cias_, _açuğ, --, --, 
   {{0x39487c03,0x3ae01497,0x2cac01d9,0x99840e3c}},	//   _dias_, _còps_, meed_, čiše_, 
   {{0xfbd07c04,0x2cac7c05,0x3948009a,0x39987c06}},	//   _ختم_, leed_, _eias_, bés_, 
   {{0x39980372,0x64a46c8c,0x776c009a,0x39480393}},	//   cés_, нава, _ewax, _fias_, 
   {{0x2cac01d9,0x29100796,0x394800e4,0x00000000}},	//   need_, _ujya_, _gias_, --, 
   {{0x2b98068c,0xc1d800cd,0x00000000,0x00000000}},	// [94a0] nèc_, भङ्ग, --, --, 
   {{0x2cac7c07,0x39480211,0x61280f91,0xdebc0092}},	//   heed_, _zias_, mýli, ቱትን_, 
   {{0x39480211,0x2cac7c08,0x7f480009,0xdbd40432}},	//   _yias_, keed_, _ridq, _täçm, 
   {{0xa3c005f9,0x394801d4,0x2cac7c09,0xe0d87c0a}},	//   ्मद_, _xias_, jeed_, яве_, 
   {{0x3998066d,0x2cac7c0b,0x2734005c,0x5f044df8}},	//   zés_, deed_, pænd_, нзда, 
   {{0x399820ef,0x7bc402d5,0x2b98067c,0x2490010e}},	//   yés_, _šiuo, dèc_, lgym_, 
   {{0x39980de0,0x7f48014f,0x612802f0,0xa068014b}},	//   xés_, _vidq, hýli, _нава_, 
   {{0x2cac0050,0x61447c0c,0x61f00e51,0x3f8401b9}},	//   geed_, _чеба, ıklı, _ағда, 
   {{0x02e42871,0x39487c0d,0xa3c00882,0x2b980ba1}},	//   _गवाह_, _rias_, ्मि_, gèc_, 
   {{0x39987c0e,0x39481570,0x93f80bd9,0xdbd4000d}},	//   tés_, _sias_, פליי, _rääm, 
   {{0x39487c0f,0x6458016b,0x2cac0014,0x61340432}},	//   _pias_, _ɑtir, beed_, _gülý, 
   {{0x39987c10,0x2cac7c11,0xfc647c12,0xa3c0590f}},	//   rés_, ceed_, _شخصی, ्मा_, 
   {{0x39987c13,0x39487c14,0xb90802ab,0x2b98067c}},	//   sés_, _vias_, _मक_, cèc_, 
   {{0x8c407c15,0x39987c16,0xccd0035b,0x98bc0205}},	//   _сече, pés_, _ацәы, rstı_, 
   {{0x39480b89,0x600401b9,0xd4c4113e,0x87e4113e}},	//   _tias_, _hаmd, нсап, _ەتپە, 
   {{0x39480393,0x61280252,0x24900c21,0x6e240112}},	//   _uias_, býli, ggym_, ühbi, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [94b0] --, --, --, --, 
   {{0x24902ffe,0x2cac0165,0x166400d1,0x7b1c0205}},	//   agym_, zeed_, _سەرپ_, _uçuğ, 
   {{0x2cac0d62,0x71240131,0x2b98068c,0x613801ef}},	//   yeed_, پىشم, zèc_, _půlp, 
   {{0x823474bb,0x78bc7c17,0x2cac0014,0x9f440489}},	//   اركا, ndsv, xeed_, mzoù_, 
   {{0x78bc0ae3,0x752c7c18,0x2cac1163,0x9f44030a}},	//   idsv, mlaz, veed_, lzoù_, 
   {{0x2cac7c19,0x2b980ba1,0x00000000,0x00000000}},	//   weed_, vèc_, --, --, 
   {{0x2cac7c1a,0x752c009d,0xa6c801d5,0x00000000}},	//   teed_, olaz, _shаk, --, 
   {{0x78bc7c1b,0x2b98068c,0x61e80b1a,0x752c030a}},	//   jdsv, tèc_, øfle, nlaz, 
   {{0x2cac7c1c,0xc0bc001f,0x752c01f7,0x78bc7c1d}},	//   reed_, ቱንም_, ilaz, ddsv, 
   {{0x752c376b,0x2cac7c1e,0x2b98068c,0x79880143}},	//   hlaz, seed_, rèc_, frdw, 
   {{0x2cac7c1f,0x2b98068c,0xa9687c20,0x00000000}},	//   peed_, sèc_, ьина_, --, 
   {{0x2b98067c,0x61280f91,0x2cac058a,0x00000000}},	//   pèc_, týli, qeed_, --, 
   {{0xca740220,0x9f4405c7,0x798851a0,0x18640063}},	//   _пәні_, ezoù_, ardw, ђари_, 
   {{0x6f0c00c6,0x752c0109,0x00000000,0x00000000}},	//   éach, elaz, --, --, 
   {{0xd6247c21,0x00000000,0x00000000,0x00000000}},	//   воре_, --, --, --, 
   {{0x752c2e10,0x74b801c6,0xdad000d1,0x00000000}},	//   glaz, нуус_, _مەۋھ, --, 
   {{0x69c07c22,0xc5b419bb,0x9f440165,0x27e4007f}},	// [94c0] lvle, _өрнө, azoù_, _æon_, 
   {{0x752c7c23,0x6b887c24,0x2ba800af,0xe2a87c25}},	//   alaz, ireg, _कहना, بارن_, 
   {{0x752c7c26,0x6b881ba6,0x7b1c7c27,0x69c07c28}},	//   blaz, hreg, _uçuş, nvle, 
   {{0x6b887c29,0x5574008f,0x672c28bf,0xa06801b9}},	//   kreg, _בעטן_, llbj, фада_, 
   {{0x4fb0007b,0x6b8801e4,0x9f4c0432,0xd00c4138}},	//   لصور, jreg, _önüp_, يلم_, 
   {{0x6b887c2a,0x57f80302,0x69c00af9,0xf60800f2}},	//   dreg, ולנו, kvle, _آتیه_, 
   {{0x6b881ddb,0x7bc00218,0xddd801d3,0x1fe400f1}},	//   ereg, wvmu, _pető, رکړي_, 
   {{0xa0a44211,0x2a680841,0x0dc47c2b,0x69c001f5}},	//   _шабд, _đaba_, туши_, dvle, 
   {{0x6b887c2c,0x28d409ab,0x69c0017a,0xd11c2c06}},	//   greg, धानि, evle, यकरण_, 
   {{0x752c7c2d,0x00000000,0x00000000,0x00000000}},	//   zlaz, --, --, --, 
   {{0xddd801ed,0x69c0017a,0xeb980023,0x69c402d2}},	//   _tető, gvle, _ገዲፍና_, _áhel, 
   {{0xd838152d,0x7de801e1,0x78bc0373,0x81ac2cc5}},	//   дэг_, _eèsú, udsv, কটপ_, 
   {{0x69c001bf,0xd7f86c00,0xb3700240,0x00000000}},	//   avle, фун_, ባብዕን_, --, 
   {{0x16707c2e,0x798802d0,0x00000000,0x00000000}},	//   шқор, prdw, --, --, 
   {{0x09e00b7f,0x9f4405c7,0x00000000,0x00000000}},	//   _војн, uzoù_, --, --, 
   {{0xc9802649,0x2d50031c,0x752c07de,0x9f440489}},	//   _туши, _eġew_, ulaz, rzoù_, 
   {{0x752c005a,0x38780254,0x00000000,0x00000000}},	// [94d0] rlaz, masr_, --, --, 
   {{0x752c7c2f,0x97000075,0xdb000022,0x6914025c}},	//   slaz, _ئېسى, _opoí, nġen, 
   {{0x752c7c30,0x6e2c0198,0x058401a9,0x75d400ae}},	//   plaz, ƙabi, _куям, _صيحا, 
   {{0x2d9400c2,0x28d43711,0x00000000,0x00000000}},	//   ҳрис, धायि, --, --, 
   {{0x26cc0165,0x733400cf,0x6730032e,0x69c01ed8}},	//   ńjoů_, _مىحا, _ákjó, zvle, 
   {{0x2d947c31,0x7e7800da,0x1e701638,0x74c400fe}},	//   грис, gavp, йғус, _একিউ, 
   {{0x81d4085a,0x6b887c32,0xf0e8247f,0x02640244}},	//   _корх, wreg, _كىسى_, _ئێمێ, 
   {{0x6b88748d,0x9cb00075,0xa9a41955,0xa3b07c33}},	//   treg, ممىت, қимд, _झैँ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6b887c34,0xe9d87c35,0x69c0057b,0x00000000}},	//   rreg, еко_, tvle, --, 
   {{0xe0a80241,0x0dd0010a,0x00000000,0x00000000}},	//   _àṣà, _тăни_, --, --, 
   {{0x6b887c36,0x69c07c37,0x6e240112,0x6128032e}},	//   preg, rvle, ühbu, býlu, 
   {{0x2f28145e,0xfbd0168d,0x69c00660,0x393405f5}},	//   _gîgî_, _وته_, svle, рээс, 
   {{0x2cbc0014,0x69c00549,0x00000000,0x00000000}},	//   _hawd_, pvle, --, --, 
   {{0xa9a47c38,0xe9a4004e,0x00000000,0x00000000}},	//   _сийд, _сайп, --, --, 
   {{0xbebc002b,0x2874013d,0xa3c028d4,0x00000000}},	//   _dhīy, _сыкр, ्मल_, --, 
   {{0x4ab405ba,0x2cbc0009,0xba3c0064,0x00000000}},	// [94e0] _असाव, _mawd_, beįs, --, 
   {{0x2cbc0211,0x7bc40006,0x657c020c,0xd36c00c6}},	//   _lawd_, _šiuk, _tvph, سهم_, 
   {{0xda74010f,0x53a001ec,0xba700150,0x00000000}},	//   רגעט_, _қарб, _ﺳﯘﻳﮕ, --, 
   {{0x2cbc01d4,0xe7d404c5,0x00000000,0x00000000}},	//   _nawd_, হনীয, --, --, 
   {{0xdee47c39,0xe6103125,0x205401e0,0x33d40064}},	//   лоди, _خشک_, _ҡтар, _кірт, 
   {{0xd0900124,0x63b4015d,0xb3540345,0x00000000}},	//   ашәы, mwyn, _ئیلا_, --, 
   {{0x2f28006a,0x63b47c3a,0x7f9c1b49,0x7d1c7c3b}},	//   _sîgî_, lwyn, ለቲካዊ_, _írsk, 
   {{0xdb681d39,0x00000000,0x00000000,0x00000000}},	//   нрол_, --, --, --, 
   {{0x21240263,0x38780175,0x3b54033a,0x63b403cb}},	//   mooh_, vasr_, јкор, nwyn, 
   {{0x2124008b,0x9f440066,0xd00c7c3c,0x63b40af9}},	//   looh_, kyoé_, _علل_, iwyn, 
   {{0x39147c3d,0x63b40368,0x2cbc0142,0x49c4013e}},	//   имор, hwyn, _fawd_, гуям_, 
   {{0x2124011f,0x2cbc045a,0x1e3000ec,0x5bc4072d}},	//   nooh_, _gawd_, _پکڙج, _متتف, 
   {{0x47840fb5,0x00000000,0x00000000,0x00000000}},	//   йырб, --, --, --, 
   {{0x387803f9,0x26040490,0x63b40492,0x2ba800c5}},	//   sasr_, _हेही_, dwyn, _कहता, 
   {{0x2d5027c4,0xbebc0069,0x4a580bd9,0x858834be}},	//   _tšee_, _akīk, _אדוו, лёта_, 
   {{0x62882792,0xa3c00882,0x63b40042,0x69140003}},	//   ófon, ्मं_, fwyn, nġel, 
   {{0xb2746294,0x63b403cb,0x657800ae,0xda44009d}},	// [94f0] илаш, gwyn, áthr, _шүүж_, 
   {{0x4394010b,0x53442902,0x42744eca,0x00000000}},	//   сафс, ухба, йгус, --, 
   {{0xbebc002b,0x00000000,0x00000000,0x00000000}},	//   _ekīk, --, --, --, 
   {{0x9128525b,0x21240548,0x1608072a,0x61e805ac}},	//   رساق_, gooh_, _हेयर_, øfla, 
   {{0xa3c000dc,0x248c00bc,0x606000d1,0x439401af}},	//   ्मः_, íjmů_, تۇقل, _лаяс, 
   {{0x2cbc7c3e,0xff5048c1,0x42c001fb,0x117405af}},	//   _sawd_, سخه_, _ýtưở, _مطرح, 
   {{0x2124058a,0x5108010a,0x41c40153,0x00000000}},	//   booh_, _пĕкĕ, _лёта, --, 
   {{0x25bc0162,0x684800c0,0x00000000,0x00000000}},	//   ætli_, lūdž, --, --, 
   {{0x4034277c,0xfe6c7c3f,0x7c38008e,0x00000000}},	//   _гетс, _нү_, _ğarä, --, 
   {{0x2cbc0042,0xdd8c00db,0x00000000,0x00000000}},	//   _wawd_, سوۋ_, --, --, 
   {{0x2cbc0218,0xa9a47c40,0xbcfc00e4,0x1ee85022}},	//   _tawd_, шинд, _itĩn, _جولی_, 
   {{0x68447c41,0x61f8033d,0x3cd401b9,0x00000000}},	//   инна, _ütle, _гўшт, --, 
   {{0xeab801c0,0x63b4058a,0xeb9801c4,0xfaf800cd}},	//   _айл_, xwyn, _рил_, bhī_, 
   {{0xaa4400ee,0xe7381fbe,0x68480153,0x2954030d}},	//   _келл, тег_, jūdž, _къир, 
   {{0x64987c42,0xa54400c6,0x2124011f,0x28d400dc}},	//   ктар_, لضرو, yooh_, धादि, 
   {{0x63b47c43,0x00000000,0x00000000,0x00000000}},	//   twyn, --, --, --, 
   {{0xe2987c44,0xe3b87c45,0x386c005a,0x6914031c}},	// [9500] каа_, ъба_, ñere_, nġem, 
   {{0xe1f05e3b,0x85583577,0x577800c8,0x63b403cb}},	//   يسا_, _میسر_, _שטיצ, rwyn, 
   {{0xe12405f5,0x2124011f,0x68f47c46,0xf4e400cc}},	//   амжи, tooh_, _klyd, _নগৰব, 
   {{0xa0a47c47,0x63b40142,0x00000000,0x00000000}},	//   радд, pwyn, --, --, 
   {{0x68480024,0x21240ae6,0x1fb4068e,0xdef80022}},	//   būdž, rooh_, рсер, кык_, 
   {{0x68f47c48,0x00000000,0x00000000,0x00000000}},	//   _llyd, --, --, --, 
   {{0x39ac0605,0xc0c40124,0x2124037e,0x68f47c49}},	//   _kɛse_, _гәли, pooh_, _olyd, 
   {{0x3ea00316,0x5ba47c4a,0x1f64011c,0x00000000}},	//   řit_, ароз, _вкам, --, 
   {{0x60c07c4b,0xdf487c4c,0x61fc0112,0x1a7401ec}},	//   mdom, _азад_, lzpl, аұлы_, 
   {{0x60c002d5,0x8f9802e4,0x68f400a2,0x00000000}},	//   ldom, _בימי, _alyd, --, 
   {{0x95242fb5,0x61fc0d16,0x68f47c4d,0x60c000b5}},	//   _རྩའི_, nzpl, _blyd, odom, 
   {{0x68f41c98,0x60c07c4e,0xdc680107,0xbb240150}},	//   _clyd, ndom, _радд_, _ﹼﺭﻩ_, 
   {{0x4bd404fb,0x81ac0eac,0xb6c401e0,0x60c07c4f}},	//   _نبود_, কটি_, бөнд, idom, 
   {{0x60c04562,0xa3c807f7,0x00000000,0x00000000}},	//   hdom, लटन_, --, --, 
   {{0x5bb426e4,0xd4987c50,0x74a87c51,0x68f47c52}},	//   _अनुव, кра_, лсаң_, _flyd, 
   {{0xb4c0007d,0x81ac015b,0x68f47c53,0x00000000}},	//   ंये_, কটা_, _glyd, --, 
   {{0x926473c5,0xa6c801a9,0xd7f80166,0x04c831b1}},	// [9510] لدام, _chаs, _шук_, جوقي_, 
   {{0x83f0013f,0xefd4010c,0x3e4c0165,0xfe780064}},	//   nbɑy, ሪቃዊ_, kɛt_, _neį_, 
   {{0xc3480801,0x60c001e4,0x684800e2,0x00000000}},	//   ряте_, fdom, rūdž, --, 
   {{0x60c000cc,0xdca40aa0,0xc10423bb,0x84840092}},	//   gdom, _عى_, يولي, ምናለን_, 
   {{0x68480006,0x60600131,0xd6b00354,0xcf9800d8}},	//   pūdž, سۇلل, _хlум, тје_, 
   {{0xeb98016c,0x60c07c54,0xdee001f4,0x00000000}},	//   ҳии_, adom, зоши, --, 
   {{0x6458084c,0x28c820f0,0x914801c0,0xab287c55}},	//   _ştii, ियमि, _ачаа_, ғона_, 
   {{0xeb987c56,0x69c408a7,0x4cb400cc,0x00000000}},	//   гии_, _áhei, _আচহু, --, 
   {{0x6f0c007b,0xeb281fce,0x6ef0032e,0x00000000}},	//   éacs, лжил_, gðbæ, --, 
   {{0x68f47c57,0x035800df,0x00000000,0x00000000}},	//   _slyd, ביזש_, --, --, 
   {{0x2ba8007d,0x00000000,0x00000000,0x00000000}},	//   _कहवा, --, --, --, 
   {{0x673c044e,0x2ee4030a,0xa9a4030c,0x8cc4030d}},	//   _shpj, _holf_, _ۇمتى, _тĕмĕ_, 
   {{0x6b647c58,0x2ee40b4f,0xbb7000db,0x00000000}},	//   _укла, _kolf_, _قۇيع, --, 
   {{0x60c07c59,0xfb2404d3,0xa038010f,0x966002e8}},	//   zdom, _وروپ, טערפ, зкре, 
   {{0x20d808a3,0x00000000,0x00000000,0x00000000}},	//   णामध, --, --, --, 
   {{0xe8f4521e,0x68f47c5a,0x60c0002f,0x00000000}},	//   _دستخ, _ulyd, xdom, --, 
   {{0x7cfc066d,0x5c380023,0x00000000,0x00000000}},	// [9520] _férf, _ብትዕቢ, --, --, 
   {{0x61fc3f5b,0x290c012d,0x28d42bf1,0x00000000}},	//   tzpl, ślać_, धावि, --, 
   {{0xe3b004fb,0xe72c0139,0x61fc0165,0x7f680023}},	//   _کرج_, _ikе_, uzpl, _ዝተዋጽ, 
   {{0xd7d8037e,0x409400f2,0x00000000,0x00000000}},	//   faヨ_, زلتر, --, --, 
   {{0xd12c7c5b,0x44247c5c,0xa3e801b9,0x3f080022}},	//   رمه_, _âm_, _ёдга_, аҭап_, 
   {{0x2ee40395,0x33b00131,0x54341291,0x00000000}},	//   _colf_, _تەكر, _درپر, --, 
   {{0xa3c0000b,0x2ee47c5d,0xdce814b2,0xe1f8013d}},	//   ्मक_, _dolf_, žiče, _сгв_, 
   {{0xa114006c,0x7cfc01ed,0x307401c4,0x00000000}},	//   _اورت, _mérg, _муус, --, 
   {{0xda787c5e,0x00000000,0x00000000,0x00000000}},	//   лян_, --, --, --, 
   {{0x2ee47c5f,0x6b9c01ab,0x8e8001a9,0x4db400eb}},	//   _golf_, àsga, _нгуе, _অপরূ, 
   {{0xfcc400d1,0x1a740220,0x39580af9,0x75280003}},	//   _дәпм, _құны_, êrs_, ċezz, 
   {{0x2d500f8b,0x7cfc0008,0x600401a9,0x2ee40139}},	//   _tšea_, _sérf, _jаmo, _zolf_, 
   {{0x2bd8085b,0x00000000,0x00000000,0x00000000}},	//   _ناوک_, --, --, --, 
   {{0xd6d409bd,0x2be40316,0xa6c801d5,0x6e2c002f}},	//   হস্প, टहरू_, _shаr, ßabg, 
   {{0xa6c8022e,0x94a801c6,0x4b34011a,0xdb2000a2}},	//   _chаq, лтаа_, _הרגל_, _örñe, 
   {{0x6004022e,0x00000000,0x00000000,0x00000000}},	//   _nаmo, --, --, --, 
   {{0x28d41524,0x78ac7c60,0x7cfc00e5,0x926800d8}},	// [9530] धारि, _ibav, _térf, греа_, 
   {{0x2fd800f1,0x35b400f3,0xd6b4009f,0x00000000}},	//   یواد_, _дбор, _اندڙ_, --, 
   {{0x7cfc00f8,0x95c80484,0x51840107,0x00000000}},	//   _kérd, _супа_, суза, --, 
   {{0xb0340276,0x2ba844ab,0xf2880014,0xbb240150}},	//   онеш, _कहला, _چھاو_, _ﺼﺭﻑ_, 
   {{0x78ac7c61,0x92e400cc,0x00000000,0x00000000}},	//   _mbav, _বগী_, --, --, 
   {{0x2ee406be,0xdb100241,0x00000000,0x00000000}},	//   _qolf_, _ògèy, --, --, 
   {{0x78ac1326,0xad242dc3,0x38ac022e,0x00000000}},	//   _obav, يىتى, kоr_, --, 
   {{0x78ac00d2,0xab643f51,0x50a00131,0xece87c62}},	//   _nbav, овил, _رەتل, рдил_, 
   {{0xeab87c63,0x4ea40120,0xf8dc00cd,0x00000000}},	//   айп_, _греа, यानय, --, 
   {{0x2fcc0066,0x600401a9,0x7e7400db,0x00000000}},	//   _ireg_, _mаml, _فامئ, --, 
   {{0x6e2c002f,0x00000000,0x00000000,0x00000000}},	//   ßabd, --, --, --, 
   {{0x69141ebd,0xad400137,0x7af800e5,0x00000000}},	//   išeg, _تۉبۉ, _elvt, --, 
   {{0xe7387c64,0x78ac02b9,0x386c7c65,0x7cfc7c66}},	//   ием_, _dbav, ñera_, _sérg, 
   {{0x7cfc24c8,0x78ac7c67,0x00000000,0x00000000}},	//   _pérg, _ebav, --, --, 
   {{0x6914151c,0x38ac022e,0x00000000,0x00000000}},	//   jšeg, bоr_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7cfc00e8,0x53a033b0,0x7b08032e,0x00000000}},	// [9540] _wérg, матб, _ástþ, --, 
   {{0x78ac7c68,0x93400108,0x00000000,0x00000000}},	//   _zbav, днуе, --, --, 
   {{0x5bb47509,0x7cfc7c69,0x2fcc05c7,0xc0e002d3}},	//   _अन्व, _hére, _areg_, ሓዳሪ_, 
   {{0x7cfc00dd,0x2fcc1753,0xa3640956,0x00000000}},	//   _kére, _breg_, _وُجو, --, 
   {{0x2fcc00ad,0x2d8421e3,0xdfa4007b,0x942000d1}},	//   _creg_, _avle_, تحضي, _يوپۇ, 
   {{0x7cfc00dd,0x14180302,0x2fcc00cc,0x6e200076}},	//   _mére, _כוכב, _dreg_, _bxlb, 
   {{0xd12c0075,0x7cfc056a,0x2fcc7c6a,0x6004022e}},	//   رمۇ_, _lére, _ereg_, _tаmo, 
   {{0x2fcc0ba1,0xe0d001d9,0x600401a9,0xddd8002b}},	//   _freg_, _تٲر_, _hаmm, _hetū, 
   {{0x2d5001a6,0x2fcc3046,0x610c0115,0xddd80055}},	//   _išel_, _greg_, lŝlo, _ketū, 
   {{0x78ac0395,0x3f800006,0x7cfc032e,0x3eac0051}},	//   _sbav, šius_, _sérd, _ubdt_, 
   {{0x7cfc7c6b,0xdca403b7,0x38ac022e,0x00000000}},	//   _pérd, _мажи, tоr_, --, 
   {{0x7cfc01ed,0xa3c8000d,0x273400b5,0xf8b87c6c}},	//   _bére, लटा_, bænk_, сөк_, 
   {{0xd8387c6d,0x7cfc06ed,0xab600220,0x38ac022e}},	//   рэн_, _cére, _كۇيى, rоr_, 
   {{0x7cfc7c6e,0xb9840075,0x00000000,0x00000000}},	//   _dére, _етиқ, --, --, 
   {{0x660003f9,0xa8040166,0x6e200175,0x7cfc01d3}},	//   _ƙoka, _azığ, _xxlb, _térd, 
   {{0x78ac7c6f,0x7cfc7c70,0x244c0022,0x69140f03}},	//   _ubav, _hérb, _ẽma_, všeg, 
   {{0x7cfc7c71,0x2bcc1d15,0xfbbc1223,0xd2587c72}},	// [9550] _gére, ़िया, ्टिम, аце_, 
   {{0x69147c73,0x82d800a8,0x439400c7,0x00000000}},	//   tšeg, одус_, ьаус, --, 
   {{0x2fcc7c74,0x82345089,0x00000000,0x00000000}},	//   _sreg_, ورما, --, --, 
   {{0x2fcc7c75,0x6efc0066,0xfbbc227c,0x7cfc0de2}},	//   _preg_, _mèbe, ्टाम, _yére, 
   {{0xddd80421,0x752c05da,0x00000000,0x00000000}},	//   _fetū, moaz, --, --, 
   {{0xdfcc16cb,0xed587c76,0x691409a8,0x752c7c77}},	//   ايو_, бок_, pšeg, loaz, 
   {{0xdd8c7c78,0x395c05d5,0x2fcc0489,0xa2805ce9}},	//   هوو_, _nuvs_, _wreg_, _سینو, 
   {{0x2fcc7c79,0xa3c0424e,0x2d84007f,0x752c7c7a}},	//   _treg_, ्मच_, _vvle_, noaz, 
   {{0x3ec4049b,0x7bc40024,0x823468e7,0x7cfc01d3}},	//   östä_, _šiur, _فرہا, _bérb, 
   {{0x2d507483,0x752c009d,0x7cfc01e7,0x00000000}},	//   _tšeo_, hoaz, _cérb, --, 
   {{0x7cfc7c7b,0x6c540220,0xd7d8019b,0x752c05c7}},	//   _sére, _екеу, faワ_, koaz, 
   {{0x7cfc0cc3,0x752c005a,0x00000000,0x00000000}},	//   _pére, joaz, --, --, 
   {{0x691402fb,0x752c002d,0x38540395,0x92e400cc}},	//   všed, doaz, дърс, _বগৈ_, 
   {{0x6d487c7c,0xf6d40212,0x7cfc01d3,0xa3e401f9}},	//   lmea, міся, _vére, _बॅग_, 
   {{0x6d4801ab,0x49047c3f,0x78c4007c,0x00000000}},	//   omea, _жүнг, ötvä, --, 
   {{0x6d480192,0x752c005a,0x7cfc7c7d,0x00000000}},	//   nmea, goaz, _tére, --, 
   {{0x7cfc0005,0x6d4814d0,0xddd800ef,0x00000000}},	// [9560] _hérc, imea, _petū, --, 
   {{0x6d4800c6,0x69c40162,0xd70401f4,0x00000000}},	//   hmea, _áhes, _нные_, --, 
   {{0x6d480076,0x2178007b,0x1674011a,0xd5ac02f2}},	//   kmea, صحاب_, _מגיל_, _یفی_, 
   {{0x7cfc0f71,0xd00c01b9,0x691400f3,0x27e4033f}},	//   _mérc, گله_, lšeb, _żony_, 
   {{0x6d480254,0x00000000,0x00000000,0x00000000}},	//   dmea, --, --, --, 
   {{0xd00c7c7e,0x672c738e,0xbebc00b8,0x600401a9}},	//   دله_, nobj, _akīr, _hаmk, 
   {{0xcd301b2c,0x6d9002d2,0xa06800d8,0x00000000}},	//   کروب, _róað, _габа_, --, 
   {{0x6d48000f,0x2d500427,0x629c0fac,0x672c014f}},	//   gmea, _ušel_, lgpo, hobj, 
   {{0x629c017a,0x395c7c7f,0x672c0254,0x19c80116}},	//   ogpo, _suvs_, kobj, _ﺑﯧﻴﺠ, 
   {{0x629c06a3,0x395c0589,0x752c7c80,0x6d4801ab}},	//   ngpo, _puvs_, zoaz, amea, 
   {{0x672c0fb7,0x386c7c81,0x2b5c009a,0x1d087136}},	//   dobj, ñero_, _euwc_, _лежи_, 
   {{0xdca47c82,0x6d487c83,0x00000000,0x00000000}},	//   _хади, cmea, --, --, 
   {{0x629c0770,0x9bb4025c,0x752c03d1,0x672c031c}},	//   kgpo, _དགྲོ, voaz, fobj, 
   {{0x17042eac,0x6d54056a,0x395c00de,0xc6e40150}},	//   سفزی_, _ézar, _tuvs_, нісп, 
   {{0x752c7c84,0xaa40001f,0x45d47c85,0xf8dc00cd}},	//   toaz, _የፓርላ, норс, यादय, 
   {{0x2eb809d9,0x6458084c,0xd7f8030d,0x00000000}},	//   _इस्त, _ştir, _гуо_, --, 
   {{0x69c4008c,0x28c80cf1,0x672c0175,0x2824001f}},	// [9570] _áher, ियरि, bobj, ተካከያ, 
   {{0xd2580953,0x752c0109,0x776c7c86,0x629c0efa}},	//   сца_, soaz, _itax, ggpo, 
   {{0x752c0109,0x95840092,0x35a402f2,0x00000000}},	//   poaz, ዝባችን_, _تۆزێ_, --, 
   {{0x30143b5f,0xd498013e,0x00000000,0x00000000}},	//   мдер, _уро_, --, --, 
   {{0x3ce05345,0x92680063,0x00000000,0x00000000}},	//   काने_, _грба_, --, --, 
   {{0xe8d835e8,0x2d50012c,0x934000f7,0xa804008e}},	//   _बच्च, _všem_, _سىزۇ, _uzış, 
   {{0x6d487c87,0xdcf8008e,0x38687c88,0x7bc400c0}},	//   tmea, _aptı, _ofar_, _šiup, 
   {{0x776c01b9,0x6914031c,0xad24215c,0x628800d7}},	//   _otax, nġet, بىبى, ófov, 
   {{0x6d487c89,0x7c647c8a,0x7de8016b,0x776c031c}},	//   rmea, رايل, bɛso, _ntax, 
   {{0x38687c8b,0x6d4803d5,0x672c0334,0x0f18007b}},	//   _afar_, smea, xobj, _اغرب_, 
   {{0x776c0054,0x38680004,0xf8f80051,0x00000000}},	//   _atax, _bfar_, ượt_, --, 
   {{0x38680023,0x672c010a,0x9ce80014,0x7cfc01d3}},	//   _cfar_, wobj, _وولے_, _vérc, 
   {{0x672c7c8c,0x691401af,0xddd80022,0x00000000}},	//   tobj, tšeb, _retũ, --, 
   {{0x2cac7c8d,0xa6c8022e,0xfc3075b0,0x244c00e4}},	//   lfed_, _ekаn, _صحن_, _ẽmo_, 
   {{0x7cfc7c8e,0x64a45aa4,0xd994179e,0xe8e800d8}},	//   _héra, мава, _قنوت_, _ммкд_, 
   {{0x2cac0142,0x7cfc0129,0x69240024,0xa85400f3}},	//   nfed_, _kéra, _імпа, _отпј, 
   {{0x672c1710,0x66e401f4,0x00000000,0x00000000}},	// [9580] pobj, _жопа, --, --, 
   {{0x7cfc034c,0x75280e3c,0x221416ab,0x00000000}},	//   _méra, čeza, мфер, --, 
   {{0x26d80e02,0x7cfc0de2,0x629c01a4,0x5164004e}},	//   _inpo_, _léra, rgpo, дүсү_, 
   {{0x212400d0,0xdfd800a7,0x3868031c,0x26c80162}},	//   čoho_, жък_, _xfar_, ldbo_, 
   {{0x6004022e,0x776c022e,0x2cac0142,0x6914031c}},	//   _kаmi, _xtax, dfed_, lġes, 
   {{0x29000113,0x600401d5,0xef9001d5,0x2cac045a}},	//   hhka_, _jаmi, ایلد, efed_, 
   {{0x7cfc004a,0x2cac7c8f,0x6914031c,0x7d0003ac}},	//   _aéra, ffed_, nġes, thms, 
   {{0x7cfc1bce,0x2cac015d,0x628c01ef,0x00000000}},	//   _béra, gfed_, _hdbo, --, 
   {{0x3b547c90,0xef907c91,0x290001d9,0x7cfc7c92}},	//   нкир, _میند, dhka_, _céra, 
   {{0x7cfc7c93,0x38687c94,0x26c80010,0x2910007f}},	//   _déra, _sfar_, jdbo_, èzan_, 
   {{0x776c03b9,0x00000000,0x00000000,0x00000000}},	//   _stax, --, --, --, 
   {{0x38680023,0x7cfc0129,0x290800e8,0xf1c001ec}},	//   _qfar_, _féra, _ňaar_, _ﺭﺅﻴﺘ, 
   {{0x628c7c95,0x7cfc7c96,0x20047c97,0xd7f800d4}},	//   _odbo, _géra, nzoi_, іум_, 
   {{0xaff800c8,0xa3d0257b,0xbbbc6d65,0x628c0051}},	//   פּרי, विन_, ्टीक, _ndbo, 
   {{0x7cfc020c,0x465800f5,0xa2a04709,0xa2c000cd}},	//   _zéra, дарю_, खलन्, रजन्, 
   {{0x29007c98,0x7ec802b5,0x628c00a9,0x26d87c99}},	//   chka_, _hūpē, _adbo, _enpo_, 
   {{0x78bc7c9a,0x7cfc0077,0x43740212,0xf74801ec}},	// [9590] mesv, _xéra, вуєт, _ىلعي_, 
   {{0x78bc0857,0x439407d6,0x2004004c,0x3ebc003b}},	//   lesv, тафс, dzoi_, jevt_, 
   {{0x6edc0490,0x2cac015d,0x00000000,0x00000000}},	//   पासु, yfed_, --, --, 
   {{0x78bc7c9b,0x628c0280,0x6598010f,0x69cc010b}},	//   nesv, _edbo, _צירק, _äheň, 
   {{0x78bc0158,0x2cac0165,0xaa840432,0x00000000}},	//   iesv, vfed_, niýä, --, 
   {{0x6efc020c,0xb8f00135,0xed587c9c,0x7cfc0124}},	//   _bèba, _ུལ_, пок_, _réra, 
   {{0x7cfc3d70,0x78bc4cab,0x00000000,0x00000000}},	//   _séra, kesv, --, --, 
   {{0x78bc7c9d,0x7cfc7c9e,0xe570010f,0x00000000}},	//   jesv, _péra, אַז_, --, 
   {{0x2cac7c9f,0x40340108,0x00000000,0x00000000}},	//   rfed_, _аетс, --, --, 
   {{0x7cfc7ca0,0xde38001f,0x6e28001f,0x1c404c17}},	//   _véra, ስመዝገ, ትራክሽ, ыным, 
   {{0x7cfc1bce,0xe800033f,0x29007ca1,0xba000022}},	//   _wéra, रैना_, thka_, иҧшл, 
   {{0x7cfc7ca2,0x78bc03ac,0x3ce00574,0xcc840133}},	//   _hérn, gesv, काणे_, _کۆکه_, 
   {{0x6d58598a,0x7cfc01ed,0x9b54004b,0x6efc0100}},	//   _iiwa, _kérn, _ګټور_, _zèba, 
   {{0x29007ca3,0x6d587ca4,0x00000000,0x00000000}},	//   shka_, _hiwa, --, --, 
   {{0x6d587ca5,0x6b887ca6,0x75280e3c,0x7cfc01ed}},	//   _kiwa, lseg, čezn, _mérn, 
   {{0x6d582e95,0x78bc7ca7,0x25a80175,0x74b8009d}},	//   _jiwa, cesv, rtbl_, муус_, 
   {{0x6d587ca8,0xe29800c7,0x3ce00b67,0x00000000}},	// [95a0] _miwa, заз_, काते_, --, 
   {{0x6d587ca9,0x65c4084c,0xd46400fd,0x26d87caa}},	//   _liwa, _збоа, _җире_, _unpo_, 
   {{0xbb440724,0x6d587cab,0x6b880332,0x00000000}},	//   şägä, _oiwa, hseg, --, 
   {{0x6b887cac,0x69c001c7,0xdfa40798,0x00000000}},	//   kseg, iwle, ејко, --, 
   {{0xdef811ca,0x6b88037e,0x628c0334,0x7f4800f1}},	//   зый_, jseg, _tdbo, وستې_, 
   {{0x6d587cad,0xe8000dad,0x6b880254,0x628c0010}},	//   _aiwa, रैया_, dseg, _udbo, 
   {{0x6d587cae,0x6b881140,0x7ec8005f,0x8d70143e}},	//   _biwa, eseg, _rūpē, هايا, 
   {{0x6d587caf,0xe0d001d9,0x6efc033b,0x7c3402dd}},	//   _ciwa, _حٲر_, _vèba, кейх, 
   {{0x6d587cb0,0x6b887cb1,0x248008cd,0xd114008d}},	//   _diwa, gseg, _mekm_, _נקמה_, 
   {{0x29100337,0x6d5802d0,0x5f040354,0x00000000}},	//   _amya_, _eiwa, _язза, --, 
   {{0x6d5818c6,0xf8dc35e0,0x13140302,0xa3d03d1d}},	//   _fiwa, यालय, תחיל_, विड_, 
   {{0x6b887cb2,0x6d587cb3,0x98c40107,0x2d940108}},	//   bseg, _giwa, хсол, _шрус, 
   {{0x7cfc7cb4,0x29c0002b,0x69c00142,0x6b887cb5}},	//   _héro, _eųa_, awle, cseg, 
   {{0x6d587cb6,0x7cfc003e,0xabb40588,0xfde42e05}},	//   _ziwa, _kéro, _рашә, _कपास_, 
   {{0x7cfc006a,0x78bc004c,0x6d587cb7,0x69147cb8}},	//   _jéro, pesv, _yiwa, mšen, 
   {{0x7cfc73a0,0x6d580009,0x78bc0200,0x661800d7}},	//   _méro, _xiwa, qesv, útka, 
   {{0x7cfc0ffb,0x439413c3,0xdebc001f,0xd90c01b9}},	// [95b0] _léro, латс, ሱስን_, _نیگ_, 
   {{0x69144e86,0x35f47cb9,0x338c0023,0x00000000}},	//   nšen, _апор, _ንክልተ_, --, 
   {{0x39487cba,0xa5c07cbb,0x69140770,0x2734782c}},	//   _khas_, _көте, išen, rænt_, 
   {{0x7cfc032e,0xd4980108,0x6b880142,0x00000000}},	//   _sérn, _эро_, yseg, --, 
   {{0xc1047cbc,0x7cfc7cbd,0x69140010,0x6edc190c}},	//   دوني, _aéro, kšen, पालु, 
   {{0x7cfc020c,0xc2e401d5,0x877c00df,0x00000000}},	//   _béro, _йўси, לאדי, --, 
   {{0x69140122,0x6d587cbe,0x7cfc01d3,0x90b001af}},	//   dšen, _piwa, _vérn, _бәлш, 
   {{0x6b887cbf,0x7cfc7cc0,0x3170014b,0x6d580309}},	//   tseg, _déro, _itzz_, _qiwa, 
   {{0x6d587cc1,0x6b887cc2,0x69c00036,0x7cfc00e5}},	//   _viwa, useg, wwle, _térn, 
   {{0x6d587cc3,0x39487cc4,0xa3d000ce,0xc01413f3}},	//   _wiwa, _ahas_, वित_, _смущ, 
   {{0x6b887cc5,0x6d587cc6,0x6f007cc7,0x39487cc8}},	//   sseg, _tiwa, _illc, _bhas_, 
   {{0x39487cc9,0x6b887cca,0xc0cc0023,0x69c07ccb}},	//   _chas_, pseg, _ጣዕሳ_, rwle, 
   {{0x39487ccc,0x75280e3c,0x7cfc7ccd,0x69c00042}},	//   _dhas_, čezl, _zéro, swle, 
   {{0x7cfc020c,0x7c240024,0x248000c0,0x00000000}},	//   _yéro, _žirg, _sekm_, --, 
   {{0x394808c2,0xbcfc00e4,0x6efc007f,0x692400d1}},	//   _fhas_, _itĩr, _lèbo, _имка, 
   {{0x2910009a,0x39487cce,0x00000000,0x00000000}},	//   _umya_, _ghas_, --, --, 
   {{0xa3d02765,0xdce808a4,0x6f00062e,0xe2c80120}},	// [95c0] विध_, žiće, _ollc, млад_, 
   {{0x13007ccf,0x6efc020c,0xdebc0092,0x00000000}},	//   азум, _sèbn, ሱትን_, --, 
   {{0xa5081920,0x7cfc01ed,0xdc740092,0x00000000}},	//   _жена_, _bérl, ረንሣይ_, --, 
   {{0x6f007cd0,0x28a82366,0x53a0215c,0x6384009b}},	//   _allc, _काफि, امەك, _игма, 
   {{0x10a07cd1,0x7cfc7cd2,0x74f00150,0xa29003e6}},	//   ричн, _séro, _اۋقا, _نگاڵ, 
   {{0x7cfc7cd3,0x6444009d,0x00000000,0x00000000}},	//   _péro, _izki, --, --, 
   {{0x91e07cd4,0x00000000,0x00000000,0x00000000}},	//   _коре, --, --, --, 
   {{0x7cfc4e01,0x6f00127b,0xbc54001f,0x614416a4}},	//   _véro, _ellc, _መታወቂ, _реба, 
   {{0x9ea80cfc,0x1e840022,0x7cfc00e8,0x7124036b}},	//   _оваа_, _алзм, _wéro, _صرفل, 
   {{0x25b82d8b,0x7cfc7cd5,0x6914012c,0x8c4007b5}},	//   _oppl_, _téro, ušen, шење, 
   {{0x7cfc7cd6,0x39482d45,0x5cc401a9,0x00000000}},	//   _hérm, _phas_, _аслз, --, 
   {{0xd90c0517,0x7d080241,0x64440427,0x38c83b8c}},	//   تیب_, _dèrù, _ozki, راجی_, 
   {{0x69147cd7,0x7cfc7cd8,0x25b84ebd,0x00000000}},	//   pšen, _jérm, _appl_, --, 
   {{0x8c400945,0x6efc0ba1,0x39141cd1,0xc76801b9}},	//   _тече, _nèbl, _әмир, тиёж_, 
   {{0x39480211,0x6444003e,0xb9080f22,0x80d80316}},	//   _thas_, _azki, _যত_, _नोभे, 
   {{0x9f50025a,0x497002e8,0x00000000,0x00000000}},	//   âyê_, _тлъс, --, --, 
   {{0x17041079,0x00000000,0x00000000,0x00000000}},	// [95d0] _لفظی_, --, --, --, 
   {{0x80d80bc0,0x7cfc01a8,0xc2740114,0x00000000}},	//   _नोबे, _sérl, илуј, --, 
   {{0x14a80574,0x644401c6,0x28a8146b,0xd9e002ab}},	//   _छापण, _ezki, _कामि, गमित_, 
   {{0x69140e04,0xa6c801a9,0x00000000,0x00000000}},	//   jšel, _shаx, --, --, 
   {{0x83840962,0x6efc0100,0x4394030d,0x00000000}},	//   _высе, _fèbl, _каяс, --, 
   {{0x7cfc0077,0x66247cd9,0x3354004e,0x00000000}},	//   _dérm, _çukç, _сүзө_, --, 
   {{0xad580f12,0x7cfc7cda,0xbda4007b,0xcde000c7}},	//   нрих_, _térl, لحيو, шәаҿ, 
   {{0x7cfc0098,0x2bc82374,0x244c00c7,0x691400d7}},	//   _férm, елип_, _ẽmi_, všeo, 
   {{0x4ea47cdb,0x7cfc7cdc,0xfe6c3f6e,0xc0bc001f}},	//   _ареа, _kérj, _мү_, ሱንም_, 
   {{0xbf147cdd,0xdca07cde,0x6f0002d0,0x00000000}},	//   _күчә, _ғаши, _ullc, --, 
   {{0x3ce000cd,0xcd0401a9,0x00000000,0x00000000}},	//   काशे_, _ичди, --, --, 
   {{0x7cfc0de2,0x5df8008f,0x7c240010,0x2198010f}},	//   _yérm, _אפענ, _žire, עברא, 
   {{0x3ce07cdf,0x7cfc0077,0x5c0400ec,0x00000000}},	//   कारे_, _xérm, _ٽڪيٽ_, --, 
   {{0xe5a47ce0,0x9b90021a,0xa3d03806,0xe9a40b81}},	//   лиги, _الوت, विस_, _бакп, 
   {{0xd62447bf,0xdbd8013d,0x6444033f,0x9f48003e}},	//   горе_, _eçär, _szki, émén_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xddd827c4,0x27e40023,0xe3b80953,0x6b6802d3}},	// [95e0] _metš, _çon_, эба_, _ተባህለ_, 
   {{0xddd81ebd,0x64440010,0x54340014,0x03a40107}},	//   _letš, _vzki, ارٲر, лиғо, 
   {{0x69140118,0x7cfc7ce1,0x25b87ce2,0xdd1c013a}},	//   yšel, _sérm, _uppl_, _líšn, 
   {{0xd24c7ce3,0xa0687ce4,0x7cfc1a96,0x30a400d4}},	//   سنن_, хада_, _pérm, ирів, 
   {{0xd12c00c6,0x7cfc01ed,0x4fb000c6,0x69140219}},	//   أمن_, _férj, مصور, jšem, 
   {{0xef9001b9,0x00000000,0x00000000,0x00000000}},	//   زیمد, --, --, --, 
   {{0x3ce00b98,0xa0740588,0xdec801ec,0x00000000}},	//   काले_, _бызш, _ﻓﺄﺼﺒ, --, 
   {{0x7cfc7ce5,0x691400bc,0x5f0400ee,0x7cd80798}},	//   _térm, ušel, _өзба, тмир_, 
   {{0x60c07ce6,0x69140024,0x00000000,0x00000000}},	//   meom, ršel, --, --, 
   {{0x60c07ce7,0x7b14016c,0x610c01e4,0x00000000}},	//   leom, рдох, rŝlu, --, 
   {{0xddd8000a,0x691402d5,0x00000000,0x00000000}},	//   _fetš, pšel, --, --, 
   {{0x60c00489,0x7cfc7bfa,0x61f80037,0xf8b800cf}},	//   neom, _mérk, _ütlu, төк_, 
   {{0xd7f87ce8,0xed4c01d9,0x57a41a6d,0xc7b87ce9}},	//   хун_, _تھو_, ышна, лёр_, 
   {{0x60c00332,0x00000000,0x00000000,0x00000000}},	//   heom, --, --, --, 
   {{0x74a8013d,0x00000000,0x00000000,0x00000000}},	//   ксаң_, --, --, --, 
   {{0x60c005ac,0x1b18015b,0xc98001c6,0x00000000}},	//   jeom, _নীচে_, _ууши, --, 
   {{0x28a84284,0xb4c438d2,0x45d401b9,0xd34001d5}},	// [95f0] _काति, _एसी_, _ғояс, مفری, 
   {{0xd344034c,0xf8b00d62,0xd164013d,0x7cfc00e5}},	//   ایسه_, _اکھ_, гъди, _bérk, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x60c07cea,0x8978010f,0x00000000,0x00000000}},	//   geom, גראצ, --, --, 
   {{0xafe47ceb,0x00000000,0x00000000,0x00000000}},	//   ролл, --, --, --, 
   {{0x2d947cec,0xddd87483,0xa3d011b1,0xdb00056a}},	//   арис, _setš, विर_, _opoñ, 
   {{0x60c00083,0x7cfc01d3,0x2d80007f,0x00000000}},	//   beom, _kérh, èhe_, --, 
   {{0xfd4c0055,0x60c001bf,0x00000000,0x00000000}},	//   _kaiṃ, ceom, --, --, 
   {{0x7cfc00e5,0xebc400c7,0x1fe400f1,0xddd8013a}},	//   _mérh, рӡеи, _نکوي_, _vetš, 
   {{0xe9d80b7b,0x69140427,0x00000000,0x00000000}},	//   вко_, ršem, --, --, 
   {{0xbe642abb,0xaa447ced,0x4ea40124,0xa924030d}},	//   _اهمي, ренл, _арҵа, идол, 
   {{0x6004022e,0x98a8054e,0x00000000,0x00000000}},	//   _kаmp, vocă_, --, --, 
   {{0xa8040598,0x00000000,0x00000000,0x00000000}},	//   _oyış, --, --, --, 
   {{0xbebc002b,0x00000000,0x00000000,0x00000000}},	//   _ajīj, --, --, --, 
   {{0xe9a47cee,0x2d5009a8,0x60c001f7,0x7bdc00b0}},	//   _тайп, _ušes_, yeom, ārue, 
   {{0x0524015b,0xa3d01b51,0xa8040205,0x2874008e}},	//   পত্র_, विल_, _ayış, _тыкр, 
   {{0x7cfc01a8,0x60c01347,0x7afc0790,0x00000000}},	// [9600] _sérk, veom, örtg, --, 
   {{0x2258708e,0x60c00083,0xa69410fc,0xa25868e1}},	//   نجاب_, weom, _триј, نشاء_, 
   {{0x60c02665,0xa1c40026,0xe7fc0118,0x569800d9}},	//   teom, рбед, उनका_, _בייצ, 
   {{0xc0f0001f,0x19b4010f,0x4ddc033f,0xd12c01c8}},	//   _ቀጠሮ_, יפער_, _कपड़े_, ومل_, 
   {{0x88e8000e,0xe3b0537f,0x60c07cef,0xdfd04706}},	//   _পতাক, _برج_, reom, تيش_, 
   {{0x98a8068f,0x7cfc00dd,0x52580e8e,0xe2980c9e}},	//   mocą_, _térk, رسەڭ_, _шаг_, 
   {{0x60c05bae,0x7cfc7cf0,0xa06800c7,0xc0f01ef7}},	//   peom, _héri, _ааба_, _ቀጠር_, 
   {{0x10a006dc,0x69c408a5,0x7cfc7cf1,0x00000000}},	//   _мисн, _áhey, _kéri, --, 
   {{0xda7800ee,0xda740092,0x00000000,0x00000000}},	//   кян_, _የበገና_, --, --, 
   {{0x2fc806af,0xff240214,0x200806be,0x00000000}},	//   çage_, _ابری, _əbil_, --, 
   {{0xf2d800c8,0x7cfc0789,0xebc000c7,0xd1c80092}},	//   אַרל, _léri, _ҕәын, _በዲታ_, 
   {{0x21247cf2,0xb4c40307,0xa3e40f44,0x00000000}},	//   nnoh_, _एसे_, भमा_, --, 
   {{0x8c407b00,0x2124102c,0x394c005f,0x088801d5}},	//   _деце, inoh_, ķes_, шбўй_, 
   {{0x21240649,0x7cfc0008,0x98bc05d1,0x7afc01e3}},	//   hnoh_, _sérh, rptı_, örtd, 
   {{0x7cfc20ef,0xaa5c0092,0xfd4c00b8,0xb994007b}},	//   _aéri, _ለፓርላ, _saiṃ, _البب, 
   {{0x7cfc7cf3,0x3eac01ab,0xfd4c0055,0x00000000}},	//   _béri, _lcdt_, _paiṃ, --, 
   {{0x78ac19a2,0x6e2c03ee,0x00000000,0x00000000}},	// [9610] _icav, ğabi, --, --, 
   {{0x883c0302,0x6e2c0365,0x7cfc4afb,0x00000000}},	//   _בתחו, şabi, _déri, --, 
   {{0xd2587cf4,0xdc74001f,0x6efc007f,0x7cfc00e5}},	//   тца_, ረንሳይ_, _wèbk, _térh, 
   {{0x7cfc7cf5,0xb12409bd,0x50a010a8,0x74147cf6}},	//   _féri, বত্ব_, تەرل, _هوجا, 
   {{0x9268547c,0x753c7cf7,0x7cfc06af,0x28a80b67}},	//   _арба_, _iksz, _géri, _कासि, 
   {{0x733400cf,0x00000000,0x00000000,0x00000000}},	//   _چىڭا, --, --, --, 
   {{0xee380276,0x102800db,0x00000000,0x00000000}},	//   ынк_, رتچۉ_, --, --, 
   {{0xb4c4791c,0x7cfc7cf8,0x00000000,0x00000000}},	//   _एसो_, _yéri, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfe707cf9,0x78ac004e,0xeb0400a8,0xaa440032}},	//   _قدم_, _acav, споп, йепл, 
   {{0x6efc033b,0x5e6401ec,0xedd400f1,0x6dd401e2}},	//   _nèbi, _انمە, _دياد, _دقاض, 
   {{0xfd9829db,0x00000000,0x00000000,0x00000000}},	//   _төшә_, --, --, --, 
   {{0xeb987cfa,0xfd1001f7,0x00000000,0x00000000}},	//   _сил_, _تجل_, --, --, 
   {{0xa6c859b7,0x09cc009e,0xdb8001c6,0x00000000}},	//   ылга_, িমবা, _эгши, --, 
   {{0x7cfc7cfb,0x7afc7cfc,0x78ac007c,0x00000000}},	//   _séri, örte, älvö, --, 
   {{0x7cfc7cfd,0x7b04067c,0x6efc00cf,0x00000000}},	//   _péri, _jòun, _dèbi, --, 
   {{0x212401a6,0xdd1400a2,0xefc80023,0x00000000}},	// [9620] vnoh_, _läşl, _በቒዑ_, --, 
   {{0x7cfc3d24,0x68f47cfe,0x29007cff,0xa6c40137}},	//   _véri, _hoyd, lkka_, _اقدى, 
   {{0x68f403ee,0x6064004b,0x2900005b,0x386c7d00}},	//   _koyd, مهال, okka_, žere_, 
   {{0x3f8408cd,0x7cfc7d01,0x68f4036b,0x29007d02}},	//   _pwmu_, _téri, _joyd, nkka_, 
   {{0x2900049b,0x8fa07d03,0x2fcc0175,0xb68401ec}},	//   ikka_, заче, _cseg_, _اشۋى, 
   {{0x6ed812b7,0x212403a2,0xdd140432,0x68f401a9}},	//   لدىڭ_, snoh_, _bäşl, _loyd, 
   {{0x61445822,0x2fcc0af9,0x93c00311,0x68f40009}},	//   _гева, _eseg_, ţătu, _ooyd, 
   {{0x23280364,0xbb741b6b,0x68f4022c,0x256c03b2}},	//   _роҳи_, огиј, _noyd, _mýl_, 
   {{0x61fc0209,0x7d00010a,0xcb6400ea,0xfe78014b}},	//   lypl, rkms, бање_, _кӯй_, 
   {{0x78ac7d04,0x29007d05,0xdeec0150,0x256c00a2}},	//   _scav, ekka_, _سۋب_, _oýl_, 
   {{0xdd900502,0x9ca8021a,0x68f47d06,0x28a80c93}},	//   _روش_, _مهال_, _boyd, _काशि, 
   {{0xd84002fb,0xdcb002dd,0xdc6801fe,0x00000000}},	//   _ničí_, _ءىش_, _садд_, --, 
   {{0x673c05d5,0x7cfc00e8,0x28a87d07,0x07a40006}},	//   _bkpj, _sérw, _कारि, паўн, 
   {{0xdd140724,0x7cfc5cca,0x29007d08,0x41c8012c}},	//   _yäşl, _cérv, akka_, रबास, 
   {{0x68f40517,0xc0cc0023,0x4ef8011a,0xa2ac00bc}},	//   _foyd, _ጣዕሚ_, נהלו, ुभन्, 
   {{0x68f4010b,0x61fc012d,0x256c013a,0x00000000}},	//   _goyd, dypl, _dýl_, --, 
   {{0x36d43169,0x92647d09,0x6ea80490,0x4918011a}},	// [9630] _допр, مدام, _घालु, _לקהל_, 
   {{0x6efc00db,0x00000000,0x00000000,0x00000000}},	//   _tèbi, --, --, --, 
   {{0x61fc0175,0x68f401a9,0x7cfc032e,0xf48402f2}},	//   gypl, _yoyd, _héru, _واحی, 
   {{0x753c012d,0x68f403b9,0x0f700150,0x00000000}},	//   _uksz, _xoyd, зғар, --, 
   {{0xcf9815ed,0x7cfc39b4,0x7c240153,0xe0140037}},	//   ује_, _jéru, _žirn, _देआद_, 
   {{0xdee001b9,0x4ea40f89,0x256c010e,0x22a401d5}},	//   доши, срда, _yýl_, _мусҳ, 
   {{0xace87d0a,0x28a8197c,0x290000fe,0x61fc0210}},	//   имка_, _कालि, ykka_, cypl, 
   {{0x7dc4425b,0x91c02e47,0x2fcc0190,0xeb98013e}},	//   ستىك, _мәҗл, _tseg_, аии_, 
   {{0xeb987d0b,0x7f1400d1,0xce3010e8,0x00000000}},	//   шип_, تكۈچ, _کواک, --, 
   {{0x69040077,0x68f47d0c,0x4ea400f7,0x691467e9}},	//   _cóen, _soyd, _ырба, nšev, 
   {{0x68f47d0d,0xceb800ac,0x7bdc0374,0xbe0400e5}},	//   _poyd, şəsi_, ārua, _ٹونٹ, 
   {{0x7cfc7d0e,0x68f47d0f,0x29000f12,0x00000000}},	//   _sérv, _qoyd, ukka_, --, 
   {{0x7cfc002e,0x290002f6,0xe6c40150,0x68f47d10}},	//   _céru, rkka_, يتسي, _voyd, 
   {{0x69140427,0x29000946,0x442400ef,0x00000000}},	//   jšev, skka_, _ģm_, --, 
   {{0x96600c9b,0x2ee405b1,0x24f407b5,0x9f600213}},	//   дкре, _mnlf_, очар, şqçi_, 
   {{0xd4647d11,0x61fc0122,0x7cfc5efc,0x18a001d5}},	//   жите_, vypl, _féru, _жаъм, 
   {{0x2ee40050,0xd7ec00c6,0x00000000,0x00000000}},	// [9640] _onlf_, _لكي_, --, --, 
   {{0x61fc127b,0xdecc001f,0xaf88030d,0x00000000}},	//   typl, ጣቱን_, _саiу, --, 
   {{0xdb1c01ed,0x7cfc01ed,0x2b4401ab,0x00000000}},	//   övén, _kért, illc_, --, 
   {{0x61fc010b,0x7cfc7d12,0xd12c01d5,0xb9ac010f}},	//   rypl, _yéru, پمه_, רבאָ, 
   {{0xa3cc3eaf,0x1ec87d13,0x7cfc01ed,0x00000000}},	//   _शनि_, илди_, _mért, --, 
   {{0xdd982a62,0xd00c7d14,0x7c241a48,0xda1800af}},	//   аши_, خله_, _žiro, _फइलत_, 
   {{0x63b47d15,0x3ea00e51,0x6ce4033f,0x1224014b}},	//   ltyn, ğit_, कांग_, _дорй_, 
   {{0x3ea07d16,0x90c07d17,0x00000000,0x00000000}},	//   şit_, _обсе, --, --, 
   {{0xd0043117,0xdeb002dd,0x00000000,0x00000000}},	//   _дете_, _жұлы, --, --, 
   {{0x8af400ac,0xbebc00b8,0x00000000,0x00000000}},	//   _şəri, _ajīv, --, --, 
   {{0x63b41978,0x2b58004e,0x5d687d18,0x00000000}},	//   htyn, ïsca_, _тием_, --, 
   {{0x7cfc5f15,0x63b47d19,0x5c0401c0,0x00000000}},	//   _péru, ktyn, _мяла, --, 
   {{0xc86400d6,0x98487d1a,0x3dbc2baf,0xda18000d}},	//   дтри, ряна_, _আছিল, _फेरत_, 
   {{0x6efc067c,0xdcf80139,0x63b47d1b,0x00000000}},	//   _fèbu, _iqtı, dtyn, --, 
   {{0x7cfc7d1c,0x6fd00490,0x4a780115,0x00000000}},	//   _fért, _दैनं, _דרוב, --, 
   {{0x33747d1d,0x7af8014f,0x7cfc00e8,0x27e400c0}},	//   згар, _hovt, _téru, _šone_, 
   {{0x63b40209,0x3868005a,0x4504031c,0x926800d8}},	// [9650] gtyn, _igar_, ངྒེར_, ареа_, 
   {{0x38680165,0x00000000,0x00000000,0x00000000}},	//   _hgar_, --, --, --, 
   {{0x69140fb7,0x30741f91,0x95c87d1e,0x63b4012d}},	//   ršev, пулс, _тупа_, atyn, 
   {{0x65782942,0x7af80a64,0x7cfc01d3,0x70580139}},	//   íthe, _lovt, _mérs, баер_, 
   {{0x3f40180f,0x63b4003a,0x00000000,0x00000000}},	//   jòus_, ctyn, --, --, 
   {{0x7af80115,0x76440124,0x776c0051,0x00000000}},	//   _novt, _kyhy, _muax, --, 
   {{0xfeb87d1f,0xdcf80139,0x9e7000ec,0x63a00135}},	//   تانت_, _aqtı, رهيت, ġone, 
   {{0xb1280014,0x69145726,0x38687d20,0x76447d21}},	//   _آرن_, nšet, _ngar_, _myhy, 
   {{0x7af87d22,0x7644049b,0x6efc020c,0xe0d0008f}},	//   _bovt, _lyhy, _sèbu, _אײן_, 
   {{0x38687d23,0x7cfc7d24,0x37d0015b,0x2b440076}},	//   _agar_, _sért, ামার, ullc_, 
   {{0x5e6801d9,0x7cfc04d4,0x7afc0267,0x7af800d0}},	//   _أمہ_, _pért, örta, _dovt, 
   {{0x63b402f6,0x691402f0,0x3a7000d1,0x00000000}},	//   ytyn, jšet, нһәр, --, 
   {{0x6a847d25,0x3200037e,0x7cfc7d26,0x00000000}},	//   _елла, hyhy_, _vért, --, 
   {{0x4e1c19e5,0xbb782ad5,0x2cac7d27,0x7af8045a}},	//   _बधाई_, _بلوچ_, lged_, _govt, 
   {{0x386c39ae,0x63b406a3,0x64981058,0x764403cb}},	//   žera_, wtyn, йтар_, _cyhy, 
   {{0x63b4049b,0x2cac79c1,0x7af801f5,0x00000000}},	//   ttyn, nged_, _zovt, --, 
   {{0x776c0798,0x7af80477,0x00000000,0x00000000}},	// [9660] _guax, _yovt, --, --, 
   {{0x7af80070,0x386801d5,0x93400108,0x83a40022}},	//   _xovt, _zgar_, енуе, зыҧҵ, 
   {{0x26c8003a,0x7644015d,0x396403e0,0xd6f8123b}},	//   mebo_, _gyhy, _üssü_, _הפיכ, 
   {{0x26c87d28,0x63b47d29,0x957401c6,0x7c240153}},	//   lebo_, ptyn, _хөрс_, _žirm, 
   {{0x2cac7d2a,0x44247d2b,0x656400aa,0xdef87d2c}},	//   dged_, _äm_, _iikh, йык_, 
   {{0xa1147d2d,0xd12c0075,0x65647d2e,0x9f8800a2}},	//   _کورت, پمۇ_, _hikh, _göýe_, 
   {{0x6444017a,0x656403cd,0x7af80427,0x4e900472}},	//   _hyki, _kikh, _rovt, رشور, 
   {{0x65640054,0x2cac7d2f,0x26c801ee,0x64440ea0}},	//   _jikh, gged_, hebo_, _kyki, 
   {{0x628c0264,0x65647d30,0x7cfc00fc,0x7af801d4}},	//   _kebo, _mikh, _sérs, _povt, 
   {{0x6444022c,0x65647d31,0x69040077,0x7cfc7d32}},	//   _myki, _likh, _dóem, _pérs, 
   {{0x628c27c4,0x6444008c,0x26c87d33,0x00000000}},	//   _mebo, _lyki, debo_, --, 
   {{0x628c0bc8,0x65647d34,0x7cfc7d35,0x2460013f}},	//   _lebo, _nikh, _vérs, kɔm_, 
   {{0xd8384e90,0x7cfc5b84,0x24900280,0x691401f1}},	//   сэн_, _férr, daym_, všet, 
   {{0x628c0e9a,0x656401ee,0x776c010a,0x7cfc7d36}},	//   _nebo, _aikh, _vuax, _gérr, 
   {{0x6914000a,0x65647d37,0x64447d38,0xd49839f1}},	//   tšet, _bikh, _ayki, йра_, 
   {{0xca440ada,0x65647d39,0x73c41cd1,0x76440306}},	//   _عليه_, _cikh, мәге, _vyhy, 
   {{0x65647d3a,0x628c7d3b,0x26c87d3c,0x889c0375}},	// [9670] _dikh, _bebo, bebo_, _הבחי, 
   {{0x26c82935,0x628c7d3d,0x6efc0ba1,0x656402d0}},	//   cebo_, _cebo, _lèbr, _eikh, 
   {{0x628c7d3e,0x65647d3f,0x644405b1,0x3f800276}},	//   _debo, _fikh, _eyki, ţiul_, 
   {{0x32000209,0x628c7d40,0xf48402cb,0xd58400fb}},	//   ryhy_, _eebo, _تادی, _мәғл_, 
   {{0x33580276,0xdf7001b9,0x00000000,0x00000000}},	//   _мамэ_, نگلب, --, --, 
   {{0x628c7d41,0x65644b5d,0x4dc000bd,0xda6400e3}},	//   _gebo, _zikh, ্মসং, _لُ_, 
   {{0xc0f0001f,0x752c0099,0x4ad40b02,0xed5800db}},	//   _ቀበሌ_, onaz, _भोगव, оок_, 
   {{0x48e800bd,0x628c7d42,0x752c7d43,0x78bc0196}},	//   _পত্র, _zebo, nnaz, jfsv, 
   {{0x628c7d44,0x2cac7d45,0x752c0083,0x26c87d46}},	//   _yebo, rged_, inaz, yebo_, 
   {{0x691400f3,0x2cac03cb,0x8ccc000d,0x00000000}},	//   jšer, sged_, _दसवो, --, 
   {{0x6efc7d47,0xd6f800b5,0x26c87d48,0xd7c00327}},	//   _fèbr, ntサ_, vebo_, གསཀྱ, 
   {{0x26c87d49,0x752c01f5,0x00000000,0x00000000}},	//   webo_, jnaz, --, --, 
   {{0x26c87d4a,0x6d487d4b,0x65647d4c,0x3ce07d4d}},	//   tebo_, mlea, _rikh, _óiva_, 
   {{0x6d487d4e,0x65642747,0x6efc7d4f,0x752c7d50}},	//   llea, _sikh, _zèbr, enaz, 
   {{0x26c87d51,0x24901c06,0x6d481140,0xe504027d}},	//   rebo_, taym_, olea, وبري, 
   {{0x628c7d52,0x752c7d53,0x6d487d54,0x26c87d55}},	//   _sebo, gnaz, nlea, sebo_, 
   {{0x6d487d56,0x65647d57,0x628c7d58,0x25a80489}},	// [9680] ilea, _vikh, _pebo, subl_, 
   {{0x65640227,0xe2a81a4d,0x24900589,0x752c0099}},	//   _wikh, تارن_, saym_, anaz, 
   {{0x65647d59,0xd00c7d5a,0x628c004c,0x752c01a9}},	//   _tikh, یلم_, _vebo, bnaz, 
   {{0x628c7d5b,0x64447d5c,0xa0087d5d,0x2c0c00dc}},	//   _webo, _tyki, يقال_, िनां_, 
   {{0x4fb00035,0x716418fd,0x00000000,0x00000000}},	//   نصور, رامك, --, --, 
   {{0x6d480618,0xbebc00b8,0x672c041e,0x00000000}},	//   elea, _ajīr, nnbj, --, 
   {{0x2d7400b0,0x6d48000f,0x672c0321,0xa1140220}},	//   _pāea_, flea, inbj, _قوست, 
   {{0xe0d00014,0xbebc00ef,0x8e4400d1,0xa3b00118}},	//   _جٲر_, _smīd, بلىك_, _टमा_, 
   {{0x93f800df,0x00000000,0x00000000,0x00000000}},	//   ַלטי, --, --, --, 
   {{0x2d7402b5,0x6d487d5e,0x0ea40137,0x00000000}},	//   _wāea_, alea, _окуй_, --, 
   {{0x6d487d5f,0x2d7402b1,0x27e4031c,0x00000000}},	//   blea, _tāea_, _ġona_, --, 
   {{0xd90c5bb8,0xf1d01bbb,0x78bc0112,0xdca47d60}},	//   شیخ_, _सनसन, ufsv, _цади, 
   {{0x657c02d0,0x14dc0b4e,0xd6d801f4,0x00000000}},	//   _atph, _पोषण, отв_, --, 
   {{0xdce001a6,0xdc000118,0x00000000,0x00000000}},	//   _mioč, nčíc, --, --, 
   {{0x693000b0,0x86240108,0x00000000,0x00000000}},	//   māen, вьте, --, --, 
   {{0x657801ed,0x752c7d61,0xdc0001ef,0x00000000}},	//   ítha, unaz, hčíc, --, 
   {{0x752c7d62,0x00000000,0x00000000,0x00000000}},	// [9690] rnaz, --, --, --, 
   {{0x6d4801c0,0x752c02f0,0x00000000,0x00000000}},	//   zlea, snaz, --, --, 
   {{0xda0c35e8,0x752c7d63,0xa5a4000d,0x63a0031c}},	//   ानित_, pnaz, _छियौ, ġona, 
   {{0x61e80158,0x752c022e,0x6d4801bf,0x0fe000cf}},	//   åfla, qnaz, xlea, көзү, 
   {{0x6d487d64,0x24840077,0xd1181b76,0x60940244}},	//   vlea, ñome_, पोषण_, رنوس_, 
   {{0xda0c0a59,0x7cfc032e,0xc0f00092,0x7afc007c}},	//   ानात_, _sérp, _ቀጠለ_, örtl, 
   {{0x6d487d65,0x00000000,0x00000000,0x00000000}},	//   tlea, --, --, --, 
   {{0xfd6401f2,0x4ad40037,0xed34009d,0x00000000}},	//   _ikwụ, _भोजव, ээлэ, --, 
   {{0x6d487d66,0x5fa03ee0,0x00000000,0x00000000}},	//   rlea, _مەنم, --, --, 
   {{0x6d487d67,0x00000000,0x00000000,0x00000000}},	//   slea, --, --, --, 
   {{0x6d487d68,0x69247d69,0x3170058a,0x672c0174}},	//   plea, емна, _juzz_, vnbj, 
   {{0x64580115,0x00000000,0x00000000,0x00000000}},	//   _ŝtim, --, --, --, 
   {{0x2d7400b0,0x393401c0,0x3b840024,0x5f14012d}},	//   _kāeo_, тээс, _аліг, भोक्_, 
   {{0xfd64063f,0x00000000,0x00000000,0x00000000}},	//   _okwụ, --, --, --, 
   {{0xfd6402e3,0x6b8c00a2,0xa3140022,0xf41c00cc}},	//   _nkwụ, _çagb, ҕьаш, _ভুলৰ_, 
   {{0x2744025a,0xe8f800ee,0xdc000118,0x28a810fa}},	//   _bênî_, _хли_, zčíc, _काटि, 
   {{0xfd6444fc,0x53a00417,0x00000000,0x00000000}},	// [96a0] _akwụ, латб, --, --, 
   {{0xdbc4007d,0x31707d6a,0x00000000,0x00000000}},	//   _tööa, _buzz_, --, --, 
   {{0xdc000118,0x657c7d6b,0x1718010f,0x4ca400eb}},	//   včíc, _utph, _זויע, ক্যু, 
   {{0x26d800b2,0x64a401c0,0xdfd800a7,0x00000000}},	//   _hapo_, _яама, зък_, --, 
   {{0x26d87d6c,0xd12c7d6d,0x00000000,0x00000000}},	//   _kapo_, حمن_, --, --, 
   {{0x26d87d6e,0x8d70431a,0x00000000,0x00000000}},	//   _japo_, گاوا, --, --, 
   {{0x26d87d6f,0x91e00209,0x274000bc,0x31700332}},	//   _mapo_, _йоре, méně_, _guzz_, 
   {{0x26d87d70,0x8d7013ea,0x91b80375,0x55d8008f}},	//   _lapo_, داوا, _ממלי, פֿונ, 
   {{0x21240649,0x26d800e4,0xef90397a,0x2cb801ab}},	//   mioh_, _oapo_, _نیند, òsda_, 
   {{0x26d8623c,0x9f50006a,0xd00c007b,0xd7f80075}},	//   _napo_, âyä_, _الك_, җум_, 
   {{0x691401af,0x00000000,0x00000000,0x00000000}},	//   tšep, --, --, --, 
   {{0x69b0068f,0x21240649,0x386c32b8,0x9d183592}},	//   _अमरी, nioh_, øer_, _عزاء_, 
   {{0xb8d80b03,0x26d84c91,0xd970009d,0x00000000}},	//   _चा_, _bapo_, _өвлө, --, 
   {{0x26d87d71,0x00000000,0x00000000,0x00000000}},	//   _capo_, --, --, --, 
   {{0x2744145e,0xd90c04d3,0x26d8299d,0x38c801ed}},	//   _sênî_, _هید_, _dapo_, _ہاکی_, 
   {{0x26d87d72,0x00000000,0x00000000,0x00000000}},	//   _eapo_, --, --, --, 
   {{0x3170017a,0x8d58011a,0x96600354,0x00000000}},	// [96b0] _suzz_, לכלי, ăксе, --, 
   {{0x82d8084c,0x26d87d73,0xd2580114,0x00000000}},	//   ндус_, _gapo_, пце_, --, 
   {{0xd6243229,0x41e40006,0x2c1c0037,0x35a40244}},	//   _سعدي, ліца, _बेईं_, _جۆزێ_, 
   {{0x21247d74,0x26d801c4,0xa6c8022e,0x7afc0267}},	//   gioh_, _zapo_, _ljаl, örtj, 
   {{0x26d800ec,0x3170003e,0x4f68005b,0x00000000}},	//   _yapo_, _wuzz_, чшем_, --, 
   {{0x6da46b80,0xbdf804fb,0xf2c40131,0x128400e5}},	//   вика, کرها_, _шөби, _سمری_, 
   {{0x81c40075,0x436801a9,0x42e40024,0x00000000}},	//   _مەلۇ, _чаён_, _сцяб, --, 
   {{0xf0e801ec,0x705801b9,0x7ed400cf,0x6fd4012d}},	//   _تىرى_, _жабр_, _ۅزما, _मैथू, 
   {{0x88b0013f,0x40340166,0x00000000,0x00000000}},	//   _mmɛt, _бетс, --, --, 
   {{0xe8a801ad,0x27e40153,0xf40403d4,0x37b800fe}},	//   कल्च, _šono_, _ৰখাৰ_, েটাৰ, 
   {{0xfeb82ba5,0x26d87d75,0xfd1000ec,0x00000000}},	//   _سالت_, _rapo_, _ڏجن_, --, 
   {{0xdb247d76,0x26d87d77,0xe6c800dc,0xbd6800d8}},	//   _یونی, _sapo_, ाज्ज, _зрче_, 
   {{0x6d587d78,0x00000000,0x00000000,0x00000000}},	//   _ihwa, --, --, --, 
   {{0x4ad400f8,0x6d587d79,0x657801e7,0xe73801c4}},	//   _ساتھ_, _hhwa, ítho, фег_, 
   {{0x6d587d7a,0x26d8031c,0x35c400c7,0x00000000}},	//   _khwa, _vapo_, ларҳ, --, 
   {{0x26d80451,0xe1f045cc,0x6d5802d0,0x00000000}},	//   _wapo_, یسا_, _jhwa, --, 
   {{0xe3b87d7b,0x26d87d7c,0x29102b24,0xe29821e2}},	// [96c0] ьба_, _tapo_, _ilya_, даз_, 
   {{0x26d87d7d,0x660400f3,0x00000000,0x00000000}},	//   _uapo_, _апоа, --, --, 
   {{0x64a40588,0x6d58127b,0x00000000,0x00000000}},	//   _иана, _ohwa, --, --, 
   {{0x6d587d7e,0x32387d7f,0xdcfc00da,0x606402da}},	//   _nhwa, رينگ_, īvīb, نهال, 
   {{0xdef87d80,0xfe707d81,0x1fb432eb,0x002801e2}},	//   дый_, مگا_, тсер, رګرو_, 
   {{0x6d587d82,0x0d7401b9,0x00000000,0x00000000}},	//   _ahwa, چیلک_, --, --, 
   {{0x29107d83,0x6b8c031c,0xc0c401e0,0xddd80064}},	//   _olya_, _ħaga, _бәли, _retų, 
   {{0x6d587d84,0x88b0013f,0x29100548,0xfb88036b}},	//   _chwa, _mmɛs, _nlya_, нроқ_, 
   {{0x6d587d85,0x1f647ce9,0x00000000,0x00000000}},	//   _dhwa, _акам, --, --, 
   {{0x29100a49,0x6d587d86,0x50180375,0xecb00022}},	//   _alya_, _ehwa, _חומו, аӡәы, 
   {{0x6d58035a,0xabbc0150,0x00000000,0x00000000}},	//   _fhwa, _ﺣﻴﻜﺎ, --, --, 
   {{0x60c07d87,0x6d5802d0,0x00000000,0x00000000}},	//   nfom, _ghwa, --, --, 
   {{0x291028e5,0x52880150,0xc7f800d4,0x00000000}},	//   _dlya_, _ﺗﯘﯕﯩ, вняє_, --, 
   {{0x6b8c09a5,0xc6a4035b,0x291004ba,0x19b800c6}},	//   _çaga, ирси, _elya_, _قطعة_, 
   {{0x291000cc,0xade40037,0x6d5802d0,0xb90800cc}},	//   _flya_, कियन_, _yhwa, _মক_, 
   {{0x6dc001f2,0x0584720a,0x6d5803ac,0x5a00009d}},	//   ịagh, рурм, _xhwa, _бүүв, 
   {{0x394801c6,0x5ea800eb,0x00000000,0x00000000}},	// [96d0] _ikas_, চ্যে, --, --, 
   {{0x92647d88,0x36d47d89,0x60c0009a,0xd05801e4}},	//   ندام, _соор, efom, _pluɾ, 
   {{0x41747d8a,0x39487d8b,0x60c0007c,0x00000000}},	//   لانس, _kkas_, ffom, --, 
   {{0x628803f2,0x00000000,0x00000000,0x00000000}},	//   ðfor, --, --, --, 
   {{0x25180302,0x6d587d8c,0xafc42033,0x527400db}},	//   _נושא, _rhwa, ايتى, _لازز, 
   {{0x4ea46140,0xeaf012eb,0x00000000,0x00000000}},	//   трда, _अचेत_, --, --, 
   {{0x6d587d8d,0x39480793,0xddd801ed,0x00000000}},	//   _phwa, _okas_, _betű, --, 
   {{0x39480211,0x6d58239a,0x00000000,0x00000000}},	//   _nkas_, _qhwa, --, --, 
   {{0x6d5802d0,0xb0342377,0x705800db,0x69d4000d}},	//   _vhwa, _снаш, _чаар_, _बनही, 
   {{0xfe740220,0xd6f8037e,0x6d5802d0,0x39487d8e}},	//   _күш_, ssオ_, _whwa, _akas_, 
   {{0x6d587d8f,0xa2c8073d,0x6f007d90,0x316c7d91}},	//   _thwa, _सॉफ्, _iolc, _kiez_, 
   {{0x6f007d92,0x88b00134,0x6d587d93,0xab9401ec}},	//   _holc, _amɛr, _uhwa, _биді, 
   {{0x316c7d94,0x6f00033f,0xcc080244,0xc0440240}},	//   _miez_, _kolc, _تزان_, _እናተፈ, 
   {{0x316c17ed,0x39487d95,0xa92400d1,0xe4d800f2}},	//   _liez_, _ekas_, _әдил, کورت_, 
   {{0x6fd40d2c,0x6f00036b,0xdb240077,0x7b040ba1}},	//   _मैसू, _molc, _ápáx, _vòut, 
   {{0x6f00022f,0xfbd8033f,0xa68400d1,0x291003e3}},	//   _lolc, _बैडम, _өлид, _ulya_, 
   {{0x6f007d96,0x60c00165,0x8af406be,0xe354009d}},	// [96e0] _oolc, vfom, _şəyi, гтжэ, 
   {{0x221401fc,0xaa2c0023,0x234816a0,0xc0cc0092}},	//   лфер, _ብመስዋ, رلاپ_, _አበራ_, 
   {{0xd24c0597,0x60c01cea,0xd6c01291,0x00000000}},	//   كنك_, tfom, _امپی, --, 
   {{0x19b4008f,0x6f000332,0xe2840139,0x00000000}},	//   טפער_, _aolc, _әлви, --, 
   {{0x316c7d97,0x7b040ba1,0x10a07d98,0xb35401b9}},	//   _diez_, _mòur, сичн, _چیقا_, 
   {{0x6f007d99,0x00000000,0x00000000,0x00000000}},	//   _colc, --, --, --, 
   {{0x6f007d9a,0x316c7d9b,0xdcf8005f,0xae700116}},	//   _dolc, _fiez_, _attā, زۇنغ, 
   {{0x614409a5,0x386c56af,0x7cfc0098,0x7de000d7}},	//   _себа, žeri_, _hérz, _násť, 
   {{0x636002e3,0x3948000d,0x7b8400d1,0x6014003b}},	//   ọnuc, _rkas_, جابە, _сєвє, 
   {{0xca540020,0x6f007d9c,0x397802d3,0x316c0165}},	//   _ቋንቋዎ, _golc, _በሃልቲ_, _ziez_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3f84020b,0xdd940124,0xde340092,0x9848004e}},	//   _ktmu_, _ааҧы, _እሄዳለ, еяга_, 
   {{0x31d02f2e,0x6f0003ee,0x2b440076,0xb8fc07f7}},	//   _सन्ध, _yolc, bolc_, _डस_, 
   {{0x8c180302,0xdb1c01e6,0x65c000d1,0x14080022}},	//   _אודי, övän, ﺭﻧﯩﻠ, ҭхап_, 
   {{0xdce00051,0x9964004e,0xd4c47d9d,0x00000000}},	//   _gioă, _йтил, лсап, --, 
   {{0x39487d9e,0xfd4c0248,0x3f840960,0xe94401d9}},	//   _ukas_, _ailẹ, _otmu_, _پر٘ی, 
   {{0x316c0489,0x17687d9f,0xcb740092,0x73c400fb}},	// [96f0] _riez_, _проп_, _በባሕረ_, шәне, 
   {{0x2aec07f7,0xbebc00ef,0x00000000,0x00000000}},	//   जाएँ_, _smīn, --, --, 
   {{0x316c7da0,0xc1e87da1,0x07380d2f,0x26dc00df}},	//   _piez_, льце_, _حسيب_, ɾto_, 
   {{0x6f007da2,0x5c6c001f,0xd1480214,0x00000000}},	//   _solc, _አጀንዳ_, رشان_, --, 
   {{0x316c6bb4,0xca64001f,0x6f007da3,0x764803e0}},	//   _viez_, ደሆነም_, _polc, şeyd, 
   {{0xc61c0183,0x7bc0002f,0x335400cf,0xdbf800eb}},	//   _দুটা_, dtmu, _түзө_, ইনাস_, 
   {{0x41e404db,0x316c7da4,0x7bc07da5,0x00000000}},	//   _літа, _tiez_, etmu, --, 
   {{0x313401d5,0x690401d3,0x00000000,0x00000000}},	//   _тебр, _lóer, --, --, 
   {{0x6f000a55,0xc1047da6,0x00000000,0x00000000}},	//   _tolc, _اوقي, --, --, 
   {{0x693000b0,0x15f40ce0,0x5f4000ec,0x61e00210}},	//   pāek, ीहार_, _وچول, łole, 
   {{0x2d9400db,0x26dc00d7,0x00000000,0x00000000}},	//   _төлө_, ôtom_, --, --, 
   {{0x2d840166,0x5d7800df,0x00000000,0x00000000}},	//   _itle_, _סאנק, --, --, 
   {{0x7bc00334,0x2fcc0d63,0xdcf800cd,0xf1f8012d}},	//   ctmu, _jpeg_, _uttā, ूहड़_, 
   {{0x6b887da7,0x2fcc3c36,0x8af40213,0x66e401f0}},	//   mpeg, _mpeg_, _şəfi, шога, 
   {{0x26dc0419,0x7de001d3,0x64940a5b,0x6b886d7d}},	//   ľto_, másá, ијах, lpeg, 
   {{0x69c0074d,0x7de000dd,0x74b801c0,0x26dc7da8}},	//   mtle, lásá, луус_, žto_, 
   {{0xfd4c0241,0x6b880022,0x00000000,0x00000000}},	// [9700] _pilẹ, npeg, --, --, 
   {{0x2d8401af,0xf1d401c0,0xe578490c,0x6b8800c7}},	//   _otle_, өөсө, _изо_, ipeg, 
   {{0x2d847318,0x69c07da9,0x216821fa,0x6b5c007f}},	//   _ntle_, ntle, вижи_, mègd, 
   {{0x29e400b0,0x71640b8c,0xb3700023,0x60087daa}},	//   _mēa_, مانك, ኣእያን_, кнем_, 
   {{0x69c07dab,0x2d8408fb,0x7de001d3,0x75200036}},	//   htle, _atle_, kásá, ëlze, 
   {{0xd9b40011,0x76480205,0x00000000,0x00000000}},	//   _জনসম, şeye, --, --, 
   {{0x7de000dd,0x69c00327,0x9f280116,0x00000000}},	//   dásá, jtle, ىقچە_, --, 
   {{0x7bc07dac,0x9cc80953,0x69c032af,0x5fd87dad}},	//   ttmu, тыка_, dtle, _मैथल, 
   {{0x69c07dae,0x2d840205,0x6b8c062d,0x254800c0}},	//   etle, _etle_, _çagl, mėlę_, 
   {{0x69c07daf,0x7bc07db0,0x7b04067c,0x4ca4015b}},	//   ftle, rtmu, _còup, ক্লু, 
   {{0xe18c069c,0x13cc03f4,0x6b8800e4,0x69c0353e}},	//   _ዝነበሩ_, রিয়, apeg, gtle, 
   {{0x25480024,0x6b8801ab,0x2d94030d,0x00000000}},	//   nėlę_, bpeg, _ырус, --, 
   {{0x69c07db1,0xd83805f5,0x9a84036b,0x00000000}},	//   atle, тэн_, _куйл, --, 
   {{0x69c07db2,0x2d840254,0x00000000,0x00000000}},	//   btle, _ytle_, --, --, 
   {{0x69c001a4,0x7afc0008,0x8af8011a,0xe584004e}},	//   ctle, örtu, _בהגי, йттү, 
   {{0x7968068f,0x58846b1a,0x3d1801e1,0x2910036e}},	//   _oświ, _тыка, _féwe_, ëzat_, 
   {{0x2f18067c,0x248001d9,0x98a8054e,0x7338035b}},	// [9710] _hège_, _dfkm_, ancă_, гзар_, 
   {{0x59d87db3,0x8c18011a,0x00000000,0x00000000}},	//   _बनार, דומי, --, --, 
   {{0x248003d1,0x92687db4,0x2fcc030a,0xda0407f7}},	//   _ffkm_, траа_, _speg_, शहित_, 
   {{0x7de000dd,0x386c01a6,0x6b880124,0x14dc01f9}},	//   zásá, žeru_, ypeg, _पोचण, 
   {{0x752c7db5,0x6b5c004a,0xdef8001f,0xc69401ec}},	//   miaz, lège, ፋጠን_, _اشۋع, 
   {{0x2d9404a9,0x752c7db6,0x43947db7,0x9e8002d3}},	//   брис, liaz, _фарс, _ሓቢርና_, 
   {{0x7de001ed,0x69c000b5,0x6b5c0129,0x720400f1}},	//   vásá, xtle, nège, _اوزم, 
   {{0x752c7db8,0x657800c6,0x0d0401d5,0x00000000}},	//   niaz, íthi, рдиқ_, --, 
   {{0x7de0066d,0x6b880618,0xebc4008e,0x00000000}},	//   tásá, upeg, сәен, --, 
   {{0x6b887db9,0xe9d87724,0x752c0356,0xc9102314}},	//   rpeg, гко_, hiaz, ास्म_, 
   {{0x6b887dba,0x752c7dbb,0x7de001d3,0x6e447dbc}},	//   speg, kiaz, rásá, _انضم, 
   {{0xe18c044e,0x69c07dbd,0x7bdc3a2f,0x1e54011a}},	//   _ዝነብሩ_, rtle, ārur, _השער_, 
   {{0x752c7dbe,0x291c02d5,0x6d48150c,0xb848001f}},	//   diaz, ėta_, moea, _መንገዱ, 
   {{0xba282b09,0x6d487dbf,0x69c00bbc,0x569001b9}},	//   اسیم_, loea, ptle, заёт, 
   {{0x490401c0,0x4a7002dd,0x752c054e,0x98a80205}},	//   _дүнг, _лықт, fiaz, amcı_, 
   {{0x752c0c86,0x6d48030a,0xa80403b9,0xd9404316}},	//   giaz, noea, _axış, _нещи, 
   {{0xe4587dc0,0x27e47dc1,0xe2c80139,0xe290007b}},	// [9720] ужа_, _éon_, ллад_, كذا_, 
   {{0x57f802e4,0xd83c00bc,0x693002b1,0xe12400d1}},	//   _עליו, áček_, tāew, әмди, 
   {{0xe610034c,0xd36c7dc2,0x16740375,0x752c7dc3}},	//   _رشد_, رهم_, _לגיל_, biaz, 
   {{0x752c7dc4,0xd83c09a8,0x672c7dc5,0xc8b803e5}},	//   ciaz, šček_, libj, अलिट, 
   {{0x909400d4,0x00000000,0x00000000,0x00000000}},	//   світ_, --, --, --, 
   {{0x44207dc6,0x63b40784,0x2018033f,0xd0040640}},	//   mzi_, muyn, ąpi_, сеље_, 
   {{0x629c7dc7,0x44207dc8,0x63b40438,0xc0cc0092}},	//   mapo, lzi_, luyn, _አጠር_, 
   {{0x71702dfc,0x44207dc9,0x672c01a9,0x4dd01884}},	//   _قۇلا, ozi_, hibj, ستىس, 
   {{0x1ea8774e,0x63b40784,0x660c0306,0x7968033f}},	//   _ماضي_, nuyn, hybk, _uświ, 
   {{0x629c7dca,0x752c7dcb,0xade402ab,0x3eb80162}},	//   napo, ziaz, किशन_, _ørt_, 
   {{0x9e08495f,0x9cc83c1b,0xd1f01ee0,0x6d480393}},	//   _حياك_, _была_, _ግዴታ_, boea, 
   {{0x629c7dcc,0x44207dcd,0x63b40bf1,0x00000000}},	//   hapo, kzi_, kuyn, --, 
   {{0x752c7dce,0x44202f29,0x386c7dcf,0x672c0327}},	//   viaz, jzi_, äer_, fibj, 
   {{0x44207dd0,0x629c0588,0x672c0321,0x6b5c004a}},	//   dzi_, japo, gibj, tège, 
   {{0x44207dd1,0x629c7dd2,0x752c7dd3,0x6b5c0cad}},	//   ezi_, dapo, tiaz, bègb, 
   {{0x44207dd4,0xc0bc0023,0xdff80c22,0x00000000}},	//   fzi_, _ደቂሱ_, ्हाद_, --, 
   {{0x629c7dd5,0x6b5c020c,0x44207dd6,0x9394007b}},	// [9730] fapo, sège, gzi_, إجرا, 
   {{0x629c7dd7,0x6d48009f,0x752c7dd8,0x25ac0342}},	//   gapo, zoea, siaz, üklü_, 
   {{0x44207dd9,0x752c7dda,0xd258084c,0x31d4075e}},	//   azi_, piaz, уца_, تقاز, 
   {{0x1ee853e2,0x44207ddb,0x63b47ddc,0x629c00c7}},	//   یونی_, bzi_, buyn, aapo, 
   {{0x629c7ddd,0x63b47dde,0x753c01f5,0x44207ddf}},	//   bapo, cuyn, _ijsz, czi_, 
   {{0x079c0302,0x61e00210,0x00000000,0x00000000}},	//   נסול, łola, --, --, 
   {{0x7dc410fe,0x6d487de0,0xff505cfc,0x00000000}},	//   كتيك, toea, رخه_, --, 
   {{0x81680e58,0xe6b41a55,0xec780484,0xad240372}},	//   _груб_, _अञ्ज, шпи_, تىبى, 
   {{0x7f941fe2,0x6d4801ab,0x672c022e,0x660c0210}},	//   _натх, roea, yibj, zybk, 
   {{0xaa481064,0xeb2802dd,0xdd8c00f7,0x00000000}},	//   иппа_, ржол_, روۋ_, --, 
   {{0x44207de1,0x1ee8208f,0x693000b0,0x6d487de2}},	//   zzi_, _خولی_, kāet, poea, 
   {{0x7afc01e6,0xeaf8221d,0x63b40309,0x00000000}},	//   örtr, ارکت_, yuyn, --, 
   {{0xeb987de3,0x6844109a,0x3a700166,0x00000000}},	//   _тил_, інга, мһәр, --, 
   {{0x44207de4,0x00000000,0x00000000,0x00000000}},	//   vzi_, --, --, --, 
   {{0xa5087de5,0x629c7de6,0x63600af2,0x64987de7}},	//   аева_, vapo, lông, итар_, 
   {{0x44200323,0x629c7de8,0x27e400c0,0x00000000}},	//   tzi_, wapo, _šonu_, --, 
   {{0x629c7de9,0x66e40a16,0x44207dea,0x00000000}},	// [9740] tapo, _допа, uzi_, --, 
   {{0x44207deb,0x63b40784,0x795c7dec,0xb8640014}},	//   rzi_, ruyn, méwa, _ژایو, 
   {{0x4420066d,0x795c0687,0x63b40113,0x7eb00241}},	//   szi_, léwa, suyn, _lópà, 
   {{0x29000f03,0xa2c80034,0x63b40986,0x00000000}},	//   njka_, _सॉर्, puyn, --, 
   {{0x629c166a,0x795c1060,0x63b47ded,0xb3540d73}},	//   papo, néwa, quyn, _کیلا_, 
   {{0x94080cc1,0xdda81fbd,0x629c7dee,0x24907def}},	//   _necə_, атил_, qapo, lbym_, 
   {{0x5f740451,0x06e400cc,0x00000000,0x00000000}},	//   _ڀائر, মাপি, --, --, 
   {{0x5ba436ca,0x795c6085,0x7124036b,0xc0d4001f}},	//   ороз, kéwa, _فرقل, ረትም_, 
   {{0xa2c87df0,0x795c003e,0xd90c03e6,0x00000000}},	//   स्थ्, jéwa, ێیت_, --, 
   {{0x3d18255a,0x795c065c,0x7b1801c0,0xa2c001ad}},	//   _déwa_, déwa, соор_, _लाफ्, 
   {{0x9ca828ec,0x2490012d,0xa2c0024a,0x588400db}},	//   _نهال_, kbym_, _लान्, жыга, 
   {{0xa2c83af4,0x38c801ed,0x68f4015d,0x00000000}},	//   स्त्, حادی_, _cnyd, --, 
   {{0x06e40f22,0x00000000,0x00000000,0x00000000}},	//   মানি, --, --, --, 
   {{0x940803be,0x68f4035a,0xcb64005b,0x29000009}},	//   _gecə_, _enyd, _даче_, ajka_, 
   {{0xd4987df1,0x34947df2,0x64580115,0x92b40014}},	//   ира_, забр, _ŝtip, ۪حرا, 
   {{0x795c0098,0x68f42c1e,0x3d1801e1,0xddc800e5}},	//   béwa, _gnyd, _yéwa_, ncfű, 
   {{0x6360025a,0x61ec7df3,0x6b5c0ffb,0x9ccc031c}},	// [9750] kônd, _arbl, lèga, _ཉིནས, 
   {{0x61ec1050,0x78bc7df4,0x660c00bc,0xfbbc00fe}},	//   _brbl, lgsv, ínká, _অনাত, 
   {{0x5efc18cc,0x00000000,0x00000000,0x00000000}},	//   लान्_, --, --, --, 
   {{0x6360019f,0x69cc49fc,0x26dc0419,0x00000000}},	//   yông, _तहसी, ôtov_, --, 
   {{0x61ec7df5,0xa6c8022e,0xe4f80375,0x48500092}},	//   _erbl, _ijаr, _הפרש, _መንደሮ, 
   {{0x78bc074d,0x6360006a,0x2d947df6,0x61ec003b}},	//   hgsv, gônd, прис, _frbl, 
   {{0x61ec00f3,0x6b5c0066,0x90d4007b,0x518401f4}},	//   _grbl, jèga, _وآرا, _фуга, 
   {{0xeb987df7,0x693000b0,0x00000000,0x00000000}},	//   бии_, hāer, --, --, 
   {{0x40341c3e,0x301400ee,0xa2c00e49,0xac980137}},	//   _жетс, _эдар, _लाम्, _ۇناا_, 
   {{0x68f47df8,0x0dc817a0,0x636000d8,0x78bc0112}},	//   _snyd, _вуди_, cônd, egsv, 
   {{0x6360145e,0x28747df9,0x29000113,0x2490012d}},	//   sông, зыгр, tjka_, ybym_, 
   {{0xef180034,0x78bc7dfa,0x795c0c6a,0x63600129}},	//   _duże_, ggsv, téwa, mône, 
   {{0x2ee40926,0x63602a59,0xca740220,0x2900022e}},	//   _kalf_, lône, _мәні_, rjka_, 
   {{0x4ad401d9,0x795c00f2,0xe7380107,0x8e280023}},	//   _ذاتھ_, réwa, ёев_, _እንዳኸ, 
   {{0xa9687dfb,0x6aa07dfc,0x7d18007f,0x795c003e}},	//   _лика_, malf, _òbsè, séwa, 
   {{0x638405f5,0xd83c7dfd,0x795c007f,0x34f80108}},	//   згаа, ščak_, péwa, охую_, 
   {{0xd4647dfe,0x61ec4ca5,0x5efc0303,0x00000000}},	// [9760] зите_, _srbl, लाम्_, --, 
   {{0xe2987dff,0xaabc227c,0x00000000,0x00000000}},	//   саж_, ्भिक, --, --, 
   {{0x75803c1f,0x00000000,0x00000000,0x00000000}},	//   _аңса, --, --, --, 
   {{0xd24c1547,0xf1a81ec7,0xd5f8011a,0xbf143f7e}},	//   دنم_, زامه_, _הפטר, तघ्न_, 
   {{0xf8c00b7c,0x7f48004b,0x00000000,0x00000000}},	//   ष्टय, يستې_, --, --, 
   {{0x2ee47e00,0xfe707e01,0x9db4025c,0x9e040017}},	//   _calf_, نگا_, _དཀྱེ, зчил, 
   {{0x657c014f,0x4f840014,0x61ec03ac,0xc0c401ee}},	//   _juph, _ہالہ, _urbl, _жәли, 
   {{0xe9940023,0xe124022e,0xab040055,0x00000000}},	//   _ዘተኮረ_, _эмби, _śṛṇa, --, 
   {{0x6aa07e02,0x657c48b5,0x2ee40042,0xdeb001ec}},	//   falf, _luph, _falf_, _зұлы, 
   {{0x6c38005e,0x6aa03754,0xbebc0055,0x50180375}},	//   تتىڭ_, galf, _amīv, _הומו, 
   {{0x63600129,0x00000000,0x00000000,0x00000000}},	//   cône, --, --, --, 
   {{0x69cc05f9,0x2ee47e03,0x78bc0158,0x6aa00037}},	//   _तहरी, _zalf_, ugsv, aalf, 
   {{0x6aa07e04,0x657c03ac,0x78bc7e05,0x48e402d5}},	//   balf, _auph, rgsv, хоўв, 
   {{0x657c6580,0x6aa07e06,0x2c080316,0xd90c2ab4}},	//   _buph, calf, िहरू_, ئیک_, 
   {{0x657c7545,0x6d4400e4,0x00000000,0x00000000}},	//   _cuph, éhag, --, --, 
   {{0xa2c801bc,0x6d440022,0x00000000,0x00000000}},	//   स्स्, ĩhag, --, --, 
   {{0x78ac7e07,0x33745d80,0x795c6790,0x00000000}},	// [9770] _idav, дгар, léwo, --, 
   {{0xc3540640,0xe7b03cbe,0x2bec00cd,0x00000000}},	//   екуј, _जितप, जितं_, --, 
   {{0xcb1004ac,0x657c00ca,0x2ee4061f,0x2bd800bc}},	//   עלע_, _guph, _ralf_, _भन्थ, 
   {{0x06e404c5,0x07a401d9,0x2ee40ea0,0xdb000129}},	//   মাণি, _تمیُ, _salf_, _ovoï, 
   {{0x41747e08,0x53e47e09,0x00000000,0x00000000}},	//   رامس, _эцна, --, --, 
   {{0x662005d1,0x795c003e,0x14ec00cc,0xc0d40092}},	//   _öykü, kéwo, _টকিঅ_, _የዱር_, 
   {{0x71240075,0x6aa07e0a,0xa2c02e04,0x2ee403e0}},	//   _قىسم, valf, _लात्, _valf_, 
   {{0x78ac7e0b,0x3d18020c,0x636000d8,0x6aa00042}},	//   _ndav, _déwo_, rône, walf, 
   {{0x6aa0074d,0x00000000,0x00000000,0x00000000}},	//   talf, --, --, --, 
   {{0x78ac7e0c,0x63600109,0xab2800d4,0xbf3400d4}},	//   _adav, pône, іона_, _знущ, 
   {{0x6aa07e0d,0xa9687e0e,0x6bd40133,0x00000000}},	//   ralf, жина_, ستکر, --, 
   {{0x657c03f0,0x6aa07e0f,0xbd4400ec,0x00000000}},	//   _ruph, salf, _ٻنهي, --, 
   {{0x657c7e10,0x6aa03ae2,0x76480790,0xf8b40124}},	//   _suph, palf, şeyl, хҩы_, 
   {{0x78ac0793,0x657c014f,0xdc34010f,0xd8740014}},	//   _edav, _puph, _קאסט_, بمُت_, 
   {{0x28c41fe5,0xde2c001f,0x6b5c0ba1,0x5efc00cd}},	//   _वापि, _እንደወ, lègo, लात्_, 
   {{0x657c18f7,0x00000000,0x00000000,0x00000000}},	//   _vuph, --, --, --, 
   {{0x657c0921,0xa2e401b9,0x9f480200,0x00000000}},	// [9780] _wuph, моад, ëmën_, --, 
   {{0x78ac7e11,0x934001f4,0x00000000,0x00000000}},	//   _zdav, внуе, --, --, 
   {{0xa5087e12,0x4acc0a94,0x2f1804cc,0x06e40154}},	//   _дена_, त्यव, _pègn_, মাদি, 
   {{0xa0480b38,0x27f00200,0xffa400db,0xa2d400ec}},	//   ەكچە_, _kryn_, елдү, _ڪيست, 
   {{0xd12c1060,0x10a07e13,0x44240158,0x987800df}},	//   جمن_, тичн, _åm_, קאסט, 
   {{0x6444005a,0xa2d40451,0x27f00042,0x97400092}},	//   _ixki, _تيست, _mryn_, _የቅድስ, 
   {{0x63b4010e,0x00000000,0x00000000,0x00000000}},	//   lryn, --, --, --, 
   {{0xbebc0055,0x00000000,0x00000000,0x00000000}},	//   _amīt, --, --, --, 
   {{0xde2c0020,0x63b47e14,0x10a000d8,0x00000000}},	//   _እንዲወ, nryn, _шитн, --, 
   {{0x93f8008d,0xbb440131,0x00000000,0x00000000}},	//   קליי, ﺘﯩﻢ_, --, --, 
   {{0xc0d4069c,0x27f000a2,0x78ac0208,0x7cf4022e}},	//   _የሱስ_, _aryn_, _pdav, bоrа, 
   {{0x27f07e15,0x795c4542,0xd83c00d0,0x63b4012d}},	//   _bryn_, réwo, áčok_, kryn, 
   {{0xb6c40032,0x27f003cb,0x1ac8010b,0x00000000}},	//   нөнд, _cryn_, _дуйп_, --, 
   {{0x63b47e16,0xccd000c7,0x764815b7,0x00000000}},	//   dryn, _зцәы, şeym, --, 
   {{0xcad4025f,0xef180003,0x63b4017a,0x0994007b}},	//   _חוות_, _juża_, eryn, _قضيب_, 
   {{0x78ac7e17,0x65640589,0x63b400a9,0x27f07e18}},	//   _udav, _chkh, fryn, _fryn_, 
   {{0x63b47e19,0x27f07e1a,0xbebc0171,0x889c011a}},	// [9790] gryn, _gryn_, _klīd, _ובחי, 
   {{0xd2587e1b,0x97200014,0x7cf401a9,0x00000000}},	//   оце_, _شہزو, zоrа, --, 
   {{0x64441529,0x69a001ad,0x28c400af,0xef18025c}},	//   _exki, कीपी, _वामि, _nuża_, 
   {{0x63b400ee,0x33940006,0x1c0c012d,0xc0cc0092}},	//   bryn, _памё, िहाल_, _አበል_, 
   {{0x24b400c8,0x00000000,0x00000000,0x00000000}},	//   _אהרן_, --, --, --, 
   {{0xe7b005f9,0x22280014,0x6b5c007f,0x00000000}},	//   _जिसप, _کٲفی_, vègo, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xef180034,0xde4400f1,0x6b5c007f,0xbebc3da0}},	//   _duża_, رینو_, tègo, _alīd, 
   {{0xdb0000e4,0xbebc00ef,0x00000000,0x00000000}},	//   _evoí, _blīd, --, --, 
   {{0x709002d3,0x00000000,0x00000000,0x00000000}},	//   _ዝበሃሉ_, --, --, --, 
   {{0x3b8400fb,0xac940395,0xbebc00ef,0xcd0401a9}},	//   нлөг, _заеш, _slīg, _очди, 
   {{0x63b40209,0x7e640118,0x00000000,0x00000000}},	//   yryn, řipc, --, --, 
   {{0xe6d401c0,0x385402e8,0x00000000,0x00000000}},	//   нцвэ, върс, --, --, 
   {{0xbb44040d,0x6b640724,0x6444020b,0x65640165}},	//   ﺘﯩﻦ_, _якла, _rxki, _shkh, 
   {{0x63b406a3,0x24f42820,0x6abc4697,0xc0d40023}},	//   wryn, нчар, ्भीर, _የሱሱ_, 
   {{0x63b47e1c,0x27f0002d,0x00000000,0x00000000}},	//   tryn, _tryn_, --, --, 
   {{0xa444539e,0xe3b802e8,0x225c00d7,0xe73800d8}},	// [97a0] хнад, яба_, _štk_, _неи_, 
   {{0x63b40b6a,0x06e400fe,0x497c0023,0x66e400f0}},	//   rryn, মাহি, _ኩነታቱ_, _џона, 
   {{0xe0d84f35,0x56980375,0x6b8c0332,0x217815b0}},	//   зве_, _מייצ, _éagf, سحاب_, 
   {{0x98a80276,0x4acc0b7c,0x63b479ab,0x00000000}},	//   mică_, त्तव, pryn, --, 
   {{0x98a8084c,0xa068377b,0xd47805d0,0x42c80107}},	//   lică_, чада_, _מאכל, _оҳан_, 
   {{0x1ea832e8,0xdce00139,0xdd987e1d,0xdea00066}},	//   ساتي_, _bioğ, пши_, ایای, 
   {{0x98a800a8,0x0084013d,0x6b5c0129,0x00000000}},	//   nică_, _акбү, règl, --, 
   {{0xfb8801b9,0xbebc00de,0x2bc0012d,0x00000000}},	//   мроқ_, _slīd, _शमशा, --, 
   {{0x60c042c9,0x50400209,0x98a8054e,0x00000000}},	//   mgom, _бетб, hică_, --, 
   {{0x9ad001f2,0xef18003d,0x60c07e1e,0x4e0000db}},	//   _bịag, _tuża_, lgom, _өзуб, 
   {{0xddb478db,0x09a80327,0xdad00014,0x00000000}},	//   _سحاب, _བྷྱ_, نٕکھ, --, 
   {{0x60c07e1f,0x28c42efd,0x98a8084c,0xdca47e20}},	//   ngom, _वाणि, dică_, _чади, 
   {{0xd7f87e21,0x60c07e22,0x00000000,0x00000000}},	//   чун_, igom, --, --, 
   {{0x98a8084c,0xd7607e23,0x19a800ee,0xc6e402dd}},	//   fică_, انسی, _етип_, лісп, 
   {{0x60c07e24,0x98a80276,0xd5647e25,0x45d47e26}},	//   kgom, gică_, етап, лорс, 
   {{0x94a8036b,0x4a58011a,0x1b00004e,0x00000000}},	//   ятга_, _מדוו, _рүүн, --, 
   {{0xbb64037e,0x98a80356,0x00000000,0x00000000}},	// [97b0] _iosゲ_, aică_, --, --, 
   {{0xdca40075,0x60c01418,0x98a80356,0x883c011a}},	//   _ھى_, egom, bică_, _מתחו, 
   {{0xa2c0257b,0x98a8054e,0xc2c415eb,0xb5940229}},	//   _लार्, cică_, ايمي, _шинш, 
   {{0x46687e27,0x60c07e28,0x3ec401f0,0x00000000}},	//   _ярым_, ggom, ҳишҳ, --, 
   {{0x5ea800bd,0x3d047e29,0x24c800cc,0xdce00419}},	//   চ্ছে, वाने_, _লোকহ, _choč, 
   {{0x60c00153,0x00000000,0x00000000,0x00000000}},	//   agom, --, --, --, 
   {{0xf1c80150,0x00000000,0x00000000,0x00000000}},	//   _توزى_, --, --, --, 
   {{0x417410e0,0x25bc01ab,0x00000000,0x00000000}},	//   _ماقس, àtli_, --, --, 
   {{0x98a8084c,0xab280395,0x00000000,0x00000000}},	//   zică_, допа_, --, --, 
   {{0xfca801d9,0x8d84014b,0x00000000,0x00000000}},	//   ٘ایو_, _зудд, --, --, 
   {{0x28c47e2a,0x272401fb,0xaa440724,0x98a80356}},	//   _वादि, _hông_, тенл, xică_, 
   {{0x272401fb,0x98a8054e,0x61e801bf,0xac94003b}},	//   _kông_, vică_, æfli, _радш, 
   {{0x99940014,0xa2c0166d,0x00000000,0x00000000}},	//   _یپور_, _लाल्, --, --, 
   {{0x98a800a8,0x2724001e,0x60c015c0,0x00000000}},	//   tică_, _mông_, zgom, --, 
   {{0x64a40953,0x27240016,0x60c07e2b,0xdcf800cd}},	//   кава, _lông_, ygom, _hutā, 
   {{0x98a8084c,0xd04400ac,0x3d042cca,0x00000000}},	//   rică_, şlən, वाये_, --, 
   {{0x27240016,0x98a80311,0x57e4760c,0xc2b401c6}},	// [97c0] _nông_, sică_, _адым_, лөвш, 
   {{0x98a8054e,0xdcf80171,0x22140395,0x00000000}},	//   pică_, _mutā, кфер, --, 
   {{0xb8640014,0xf1a8413a,0x9f882b95,0x60c002d0}},	//   _لایو, فانه_, _köçe_, tgom, 
   {{0x2724001e,0x60c00024,0xdfd802e8,0x00000000}},	//   _bông_, ugom, дък_, --, 
   {{0x2724431d,0x60c022a9,0xb91c01f2,0xdcf80055}},	//   _công_, rgom, _anyụ_, _nutā, 
   {{0xef18068f,0x2724001e,0x0cc003d4,0x80d0015b}},	//   _dużo_, _dông_, ্যোত, _সোশ্, 
   {{0x52d4008f,0x98a8012d,0x57ac0037,0x00000000}},	//   _שולע_, licą_, _झट्ह, --, 
   {{0x6b5c026c,0x80d0015b,0x4acc06ff,0xdcf80171}},	//   lègh, _সোর্, त्सव, _butā, 
   {{0x98a8033f,0xef907e2c,0x2124014f,0x27240051}},	//   nicą_, _هیند, mhoh_, _gông_, 
   {{0x6b5c0268,0x764803e0,0x00000000,0x00000000}},	//   nègh, şeyi, --, --, 
   {{0x3f847e2d,0x3d1800e8,0x5ce46215,0x9cc85cde}},	//   _humu_, _léwi_, _аюла, _жыла_, 
   {{0x3f847e2e,0x21240369,0x49740166,0x00000000}},	//   _kumu_, nhoh_, илэс, --, 
   {{0x3f847e2f,0x272401fb,0xdb4c03e6,0x628c08a5}},	//   _jumu_, _xông_, _وێب_, _ofbo, 
   {{0x3f847e30,0x07a42c1d,0x21240369,0x73c40032}},	//   _mumu_, раён, hhoh_, һәге, 
   {{0x4b7800c8,0x3f847e31,0xd4c47e32,0x996401f0}},	//   _קאוו, _lumu_, ксап, _итил, 
   {{0x73c40cef,0x3f847e33,0x628c7e34,0x21240007}},	//   ләге, _oumu_, _afbo, jhoh_, 
   {{0x39880a85,0x7bc07e35,0x3f847e36,0x2124020b}},	// [97d0] _hûs_, numu, _numu_, dhoh_, 
   {{0x3d18032b,0x2724004d,0x38700327,0x00000000}},	//   _déwi_, _rông_, ħorġ_, --, 
   {{0x8af40cc1,0x27240016,0x7afc0108,0x00000000}},	//   _şəki, _sông_, örty, --, 
   {{0x3f847e37,0x3988045f,0x2124047e,0x00000000}},	//   _bumu_, _mûs_, ghoh_, --, 
   {{0x7bc07e38,0x3f842b1d,0x63000131,0x28c433af}},	//   jumu, _cumu_, _گۈلل, _वासि, 
   {{0x3f847e39,0x6da47e3a,0xf48401d3,0x27240208}},	//   _dumu_, гика, _جاگی, _vông_, 
   {{0xed587e3b,0x41e47e3c,0x3f840421,0xb64404ce}},	//   нок_, _кіта, _eumu_, _ｉｎ_, 
   {{0x7bc07e3d,0x61f800dd,0x2724001e,0x3f847e3e}},	//   fumu, _átla, _tông_, _fumu_, 
   {{0x3f842252,0xa2c81886,0x6b5c068c,0x27240208}},	//   _gumu_, स्क्, lègi, _uông_, 
   {{0x28c4086b,0x9a4801e1,0x00000000,0x00000000}},	//   _वाहि, _ìkọ́, --, --, 
   {{0x7bc00421,0xfeb800cf,0xd9e80d0d,0x00000000}},	//   aumu, _جاقت_, टिगत_, --, 
   {{0x39881400,0x6b5c19f5,0x3f84002e,0xe9f802dd}},	//   _dûs_, zègh, _yumu_, _үнді_, 
   {{0x6d587e3f,0x2d847e40,0x00000000,0x00000000}},	//   _ikwa, _hule_, --, --, 
   {{0x2d847e41,0xc5b400db,0x28c42894,0x00000000}},	//   _kule_, ирбө, _वावि, --, 
   {{0x2d847e42,0xe2980588,0x6d58025c,0x2b88004d}},	//   _jule_, ҵаз_, _kkwa, _húc_, 
   {{0xf4941de1,0x4acc243c,0x63600120,0x8af400ac}},	//   ирую, त्रव, tôno, _şəhi, 
   {{0x69c02935,0x2d847e43,0x6d587e44,0x2fcc0218}},	// [97e0] lule, _lule_, _mkwa, _nqeg_, 
   {{0x29107e45,0x2d8437b6,0x3f847e46,0x2b88004d}},	//   _hoya_, _oule_, _rumu_, _múc_, 
   {{0x2b8801dc,0x29107e47,0x7bc07e48,0x6d587e49}},	//   _lúc_, _koya_, zumu, _okwa, 
   {{0x7bc07e4a,0x29107e4b,0x6d587e4c,0x3f8401f7}},	//   yumu, _joya_, _nkwa, _pumu_, 
   {{0x69c07e4d,0x29107e4e,0x2d847e4f,0x1fb40c69}},	//   hule, _moya_, _aule_, усер, 
   {{0x6d587e50,0x2d847e51,0x69c07e52,0x29107e53}},	//   _akwa, _bule_, kule, _loya_, 
   {{0x2d847e54,0x3f8400ca,0x6d5802d0,0x6144023b}},	//   _cule_, _wumu_, _bkwa, _бева, 
   {{0x69c07e55,0x2d84644f,0x7bc07e56,0x3f847e57}},	//   dule, _dule_, tumu, _tumu_, 
   {{0x3f840ba7,0x2b8801fb,0x6d58035a,0x69c0003e}},	//   _uumu_, _cúc_, _dkwa, eule, 
   {{0x2d847e58,0x69c07e59,0x7b1801c0,0x2ab40150}},	//   _fule_, fule, тоор_, аңшы_, 
   {{0x69c07e5a,0x29107e5b,0x2d847e5c,0x7bc07e5d}},	//   gule, _boya_, _gule_, sumu, 
   {{0xdb000139,0xad241699,0x00000000,0x00000000}},	//   _ovoç, _پرمو, --, --, 
   {{0x69c00421,0x28c40ad7,0x2d8401a6,0x29107e5e}},	//   aule, _वारि, _zule_, _doya_, 
   {{0x69c07e5f,0x2d847e60,0x00000000,0x00000000}},	//   bule, _yule_, --, --, 
   {{0x69c07e61,0x2e340020,0x29100ac5,0x4644001f}},	//   cule, _እንደመ, _foya_, _የትግራ, 
   {{0x34947e62,0x51840aac,0x1dc400dc,0x6618143a}},	//   раар, ҳуда, रूयत, øtka, 
   {{0x2b880016,0x2724002d,0xd7f87e63,0x97a401b9}},	// [97f0] _xúc_, _sône_, _чуй_, _ёрил, 
   {{0x6b5c00f7,0x29107e64,0x38687e65,0x36d42be5}},	//   tègi, _zoya_, _izar_, _тоор, 
   {{0x291000e4,0xcad4011a,0x00000000,0x00000000}},	//   _yoya_, רובת_, --, --, 
   {{0x41740597,0x2d847e66,0x272400d0,0x628805c7}},	//   مانس, _rule_, _vône_, ñfor, 
   {{0x2d847e67,0x7dfc054e,0x2ca800d0,0x00000000}},	//   _sule_, _lăsă, _ľad_, --, 
   {{0x2d847e68,0x6d587e69,0x4ea47e6a,0x69c00472}},	//   _pule_, _skwa, урда, yule, 
   {{0x7dfc0311,0x28c40ad7,0x2b8801fb,0x3d1801e1}},	//   _năsă, _वालि, _súc_, _léwu_, 
   {{0x2d8407a9,0x394801f7,0xf0e8030c,0x38685063}},	//   _vule_, _njas_, _جىرى_, _ozar_, 
   {{0xdcf80029,0x69c07e6b,0x2e340020,0x1aec045e}},	//   _attē, wule, _እንዲመ, জানে_, 
   {{0x69c07e6c,0x2910055a,0x2d847e6d,0x41c40014}},	//   tule, _soya_, _tule_, _خٲہِ, 
   {{0x38687e6e,0xa2c81b76,0x7dfc0276,0x29107e6f}},	//   _azar_, स्ट्, _căsă, _poya_, 
   {{0x6d587e70,0x69c07e71,0x38680327,0x2b88001e}},	//   _ukwa, rule, _bzar_, _túc_, 
   {{0x69c07e72,0x29100564,0x98a87e73,0x7d74009f}},	//   sule, _voya_, nicę_, _االط, 
   {{0x69c07e74,0x38686e2b,0x98a800da,0x9b902bd8}},	//   pule, _dzar_, ējās_, _بلوت, 
   {{0x29107e75,0xe5a47e76,0x38687e77,0x39487e78}},	//   _toya_, риби, _ezar_, _fjas_, 
   {{0x58fc003d,0xd54426b1,0x00000000,0x00000000}},	//   _ཞོགས_, апсе_, --, --, 
  
   {{0xe2c87e79,0xd384311c,0x234800d1,0x838800e5}},	// [9800] клад_, ийте_, پلاپ_, اصرہ_, 
   {{0xe29805f5,0x130000d6,0xe618136b,0xdce001fb}},	//   таж_, озум, _адо_, _khoă, 
   {{0x9c800122,0x9f400248,0x00000000,0x00000000}},	//   áčko, _èké_, --, --, 
   {{0x316c2047,0x68e00de2,0xa2c021b8,0x00000000}},	//   _chez_, _ñodd, _लाक्, --, 
   {{0x9c800219,0xdee4014b,0x6b5c0129,0x6e2c01e4}},	//   ščko, иоди, lègu, ŝabl, 
   {{0xd83c0122,0x53a07e7a,0xbebc00e2,0xbe5c0023}},	//   _účel_, _фарб, _elīn, _ህንጻታ, 
   {{0x20880fc0,0xfe08009a,0x00000000,0x00000000}},	//   _айби_, اقعي_, --, --, 
   {{0x71582119,0x21687e7b,0x7dfc0311,0x9fe40214}},	//   _брус_, _риби_, _răsă, _پسره, 
   {{0xa2a80b27,0x00000000,0x00000000,0x00000000}},	//   टरप्, --, --, --, 
   {{0x7dfc0276,0x3d047e7c,0x3d187e7d,0x00000000}},	//   _păsă, वाहे_, _réwu_, --, 
   {{0x3d184a16,0xb2700055,0x386801d3,0x69a00456}},	//   _séwu_, _kañṭ, _szar_, कीली, 
   {{0xe65002d3,0x25ac0fac,0x61e800cc,0xd91802e8}},	//   _ዘስካሕ, _åfly_, åfly, тьо_, 
   {{0x6ecc1152,0x63600109,0x98487e7e,0xd5400248}},	//   _सामु, gônk, тяна_, _lẹ́n, 
   {{0xa2c0038e,0x3d043027,0x6b8c00ae,0x1db80118}},	//   _लाग्, वावे_, _éaga, _ईटात, 
   {{0x47a80154,0x00000000,0x00000000,0x00000000}},	//   কূলী, --, --, --, 
   {{0x26d80083,0x8a780302,0xf2c401c0,0x97a46c48}},	//   _ebpo_, _באות, өөги, _крол, 
   {{0x39587e7f,0x38681f02,0x3dcc009e,0x7f580166}},	// [9810] moss_, _uzar_, লবিল, kovq, 
   {{0x39587e80,0x97000075,0xd54001e1,0x795c002e}},	//   loss_, _بېسى, _bẹ́n, réwu, 
   {{0x6ecc04fa,0x6d940327,0x3958003e,0x06e400cc}},	//   _साबु, _iġag, ooss_, মাখি, 
   {{0x39585cf5,0x3bd00113,0x00000000,0x00000000}},	//   noss_, kàq_, --, --, 
   {{0x2f1802bf,0x8fe4600f,0xac9800d1,0x629c007c}},	//   лодь_, рцед, ۇنغا_, bbpo, 
   {{0x395801cf,0xd1b81867,0xd54001e1,0xab5c025c}},	//   hoss_, _لارا_, _fẹ́n, kuża, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xece87e81,0x02640244,0x00000000,0x00000000}},	//   удил_, _بێمێ, --, --, 
   {{0x39587e82,0x80cc00bc,0x00000000,0x00000000}},	//   doss_, _हाते, --, --, 
   {{0x6d940327,0x00000000,0x00000000,0x00000000}},	//   _nġag, --, --, --, 
   {{0xd9947e83,0x00000000,0x00000000,0x00000000}},	//   ینیت_, --, --, --, 
   {{0x81bc00cc,0x00000000,0x00000000,0x00000000}},	//   _অহম_, --, --, --, 
   {{0x272406d9,0xed58151c,0x3d041a47,0x2cac7e84}},	//   _aôna_, mož_, वारे_, maed_, 
   {{0x6360019f,0x2cac7e85,0x6a84036b,0xed5802fb}},	//   rônk, laed_, _улка, lož_, 
   {{0xd6240283,0xadf80303,0xabc401af,0x00000000}},	//   боре_, ्मिन_, _таҙҙ, --, 
   {{0x63600261,0x2724003a,0xc4b80eac,0x19b408a8}},	//   môni, _dôna_, ুজ্জ, _הפקר_, 
   {{0xd6c07e86,0x68e40209,0x636006ed,0x6b5c00db}},	// [9820] _کمپی, mekd, lôni, sègu, 
   {{0xadf819e5,0x272406d9,0xed58012c,0x2cac0007}},	//   ्मान_, _fôna_, hož_, haed_, 
   {{0x63607e87,0x2f18067c,0xed587e88,0x61440c9e}},	//   nôni, _lègs_, kož_, бежа, 
   {{0xd00c7e89,0xed6c001f,0x2cac0165,0x7e6400bc}},	//   کله_, ስከበር_, jaed_, řipk, 
   {{0x33b40962,0x2cac0165,0x65740051,0x63a80118}},	//   _мёрт, daed_, mmyh, álně, 
   {{0x26c87e8a,0x3e180276,0x29d003b2,0xd54001e1}},	//   ngbo_, иолэ_, káa_, _tẹ́n, 
   {{0x3d04000b,0xb35400f1,0x68e47e8b,0x00000000}},	//   वाले_, _بیلا_, kekd, --, 
   {{0x68e400ee,0x636000d8,0x65740fac,0x7f58047e}},	//   jekd, dôni, nmyh, sovq, 
   {{0x602405f5,0x8fa07e8c,0x910000f7,0x68e401e4}},	//   _удаа, _нате, _эпте, dekd, 
   {{0x63600261,0xff2404fb,0x7f5801a9,0x8d200014}},	//   fôni, _ببری, qovq, ٲفیٖ, 
   {{0x63600798,0x00000000,0x00000000,0x00000000}},	//   gôni, --, --, --, 
   {{0x63a40c8c,0xd83801c0,0x38c801d5,0x00000000}},	//   _owkn, гэг_, جادی_, --, 
   {{0xdc8c01f2,0xc7b8136b,0x39587e8d,0x69c408fb}},	//   _dịtụ_, йёр_, ross_, _åhen, 
   {{0xccd00022,0x395801c7,0x00000000,0x00000000}},	//   _дцәы, soss_, --, --, 
   {{0x636000d8,0x74a80116,0x68e45063,0xcaf000f2}},	//   côni, исаң_, bekd, _رسوب, 
   {{0x7bc00037,0x68e44dd9,0x26c80241,0x00000000}},	//   ormu, cekd, agbo_, --, 
   {{0x73387e8e,0x33947e8f,0x61ec7e90,0x26c87e91}},	// [9830] азар_, زلاز, _asbl, bgbo_, 
   {{0x6ecc7e92,0x8c180375,0x6b5c1184,0x2cac0165}},	//   _साधु, אומי, lègr, zaed_, 
   {{0x63a40857,0x6d44020c,0x2cac030a,0x7bc0002f}},	//   _ewkn, éhak, yaed_, hrmu, 
   {{0x661800fd,0x799803ac,0x7bc002f0,0x2cac0009}},	//   ätke, _mtvw, krmu, xaed_, 
   {{0x63600120,0x61ec015d,0x9f44030a,0x2cac0165}},	//   zôni, _esbl, lvoù_, vaed_, 
   {{0x439401c0,0x2cac0042,0x00000000,0x00000000}},	//   _харс, waed_, --, --, 
   {{0x7bc07e93,0x2cac0dd6,0xed580118,0xd1ec0092}},	//   ermu, taed_, tož_, ቀቶች_, 
   {{0x752c7e94,0x0d041086,0x71240131,0xefc80092}},	//   nhaz, сдиқ_, _بىرم, በለው_, 
   {{0x2cac7e95,0xed587e96,0x90b015cf,0xeb280902}},	//   raed_, rož_, _дәһш, ижил_, 
   {{0x1c407e97,0x2cac0bed,0x636006ed,0xe9d8026a}},	//   ьным, saed_, tôni, ако_, 
   {{0x752c7e98,0x7bc07e99,0x8e2400fd,0x2cac002d}},	//   khaz, armu, _уфад, paed_, 
   {{0x06e404c5,0x63607e9a,0x6b8c7e9b,0x00000000}},	//   মাছি, rôni, _éago, --, 
   {{0x6d487e9c,0x68e40209,0x63600798,0x799803ac}},	//   mnea, rekd, sôni, _etvw, 
   {{0xf4000c58,0x28c405f9,0xa9a4010b,0x636000d8}},	//   োনাৰ_, _वाकि, _дикд, pôni, 
   {{0x6d487e9d,0xd61800c7,0xe504027d,0x00000000}},	//   onea, ахтә_, يبري, --, 
   {{0x6d483c60,0x752c7e9e,0x9930007b,0x00000000}},	//   nnea, ghaz, _يفوت, --, 
   {{0x6d487e9f,0xe8c405ba,0x00000000,0x00000000}},	// [9840] inea, वलीच, --, --, 
   {{0x6d480fa3,0x752c0810,0x61ec04ce,0x63040fb4}},	//   hnea, ahaz, _psbl, غوال, 
   {{0x752c7ea0,0x6d4800cc,0x69c00175,0xe568014b}},	//   bhaz, knea, nrle, _винд_, 
   {{0x752c6580,0x69c07ea1,0xfe4400f7,0x7a400162}},	//   chaz, irle, үмдү, _hátø, 
   {{0x69c00730,0x48dc0316,0x787003b2,0x6d94025c}},	//   hrle, ग्यो_, _iðví, _nġab, 
   {{0x44200516,0x6b8c0209,0x6d4801c6,0x88b0009e}},	//   myi_, _çagy, enea, কলিক, 
   {{0x442000dd,0xeea80046,0x42a40075,0x9254005b}},	//   lyi_, стік_, _муңғ, _даёт_, 
   {{0x8e4404a9,0x6d4853cc,0x8d7000c6,0x44207ea2}},	//   تلىك_, gnea, وايا, oyi_, 
   {{0x81bc009e,0x69c07ea3,0x00000000,0x00000000}},	//   _অহি_, erle, --, --, 
   {{0x44200086,0x7bc00240,0x6d487ea4,0x69c00432}},	//   iyi_, rrmu, anea, frle, 
   {{0x6b5c7ea5,0x69c403cd,0x752c0076,0x69c000a2}},	//   tègr, _åhel, yhaz, grle, 
   {{0x394c0a16,0x44200134,0x6d487ea6,0x81bc0183}},	//   ões_, kyi_, cnea, _অহা_, 
   {{0x44207ea7,0x752c06d6,0x386c3b3b,0x69c017ce}},	//   jyi_, vhaz, åer_, arle, 
   {{0x44207ea8,0x764001d3,0x00000000,0x00000000}},	//   dyi_, úlyo, --, --, 
   {{0x752c7ea9,0xbebc00b8,0x44201418,0xdce0033f}},	//   thaz, _alīk, eyi_, _choć, 
   {{0x7ae87eaa,0x3eac00b5,0x3ca80183,0x4420007f}},	//   ledt, _ledt_, _গাঁৱ, fyi_, 
   {{0x442000dd,0x7a400162,0x94741ec7,0xd87452d4}},	// [9850] gyi_, _fátø, زدرا, _باغب, 
   {{0x752c7eab,0x741400dd,0x78ac7eac,0xbb440046}},	//   shaz, _ہوجا, _heav, ﺘﯩﻚ_, 
   {{0x752c7ead,0x7c200cfd,0xe794158b,0x44207eae}},	//   phaz, hymr, _وایک, ayi_, 
   {{0x44207eaf,0x7c200627,0x752c0107,0x7ae8014f}},	//   byi_, kymr, qhaz, hedt, 
   {{0x7ae87eb0,0x3eac7eb1,0x88b004c5,0x44207eb2}},	//   kedt, _bedt_, _কামক, cyi_, 
   {{0x78ac7eb3,0xf31405f5,0x68f800da,0x6d483040}},	//   _leav, _эдгэ, ētdi, wnea, 
   {{0x6d484ba3,0xdb0003fa,0x7ae80857,0x00000000}},	//   tnea, _stoß, dedt, --, 
   {{0x78ac7eb4,0xb4e8012c,0x69c00489,0x6d487eb5}},	//   _neav, _यसो_, vrle, unea, 
   {{0x3eac04ce,0xb4e80f44,0x7ae87eb6,0x7c2003cb}},	//   _fedt_, _यसै_, fedt, gymr, 
   {{0x6d484695,0x6b8c00ae,0xe28c022e,0x7ae848d7}},	//   snea, _éagm, hdаn_, gedt, 
   {{0xfbd802f5,0x69c00549,0xe28c022e,0xbea800ec}},	//   তিগত, urle, kdаn_, _ذهنن_, 
   {{0x69c004c4,0x44207eb7,0x9b900b43,0x3cf8007b}},	//   rrle, yyi_, بلیت, _وعند_, 
   {{0x78ac039a,0x7c2003cb,0x7ae802d0,0x4420058a}},	//   _deav, cymr, bedt, xyi_, 
   {{0x442007a8,0xed3401ed,0x7ae803ac,0x70640092}},	//   vyi_, _بوچھ, cedt, ግስታቸ, 
   {{0x78ac7eb8,0x64a47eb9,0xa508423c,0x80cc00bc}},	//   _feav, заба, бева_, _हाले, 
   {{0x78ac7eba,0x44207ebb,0x28c47ebc,0x95807ebd}},	//   _geav, tyi_, _वाटि, елсе, 
   {{0x1aec00bd,0xe73800ee,0x68f4058a,0x44200a49}},	// [9860] জারে_, _геп_, _iayd, uyi_, 
   {{0x68f47ebe,0x44207ebf,0x386c00e4,0x00000000}},	//   _hayd, ryi_, üere_, --, 
   {{0x68f47ec0,0x673c038f,0xf1a81ef1,0x3eac5cb7}},	//   _kayd, _impj, قانه_, _redt_, 
   {{0x44207ec1,0x600801e0,0xf1f800f1,0x7ae87ec2}},	//   pyi_, йнем_, غونډ_, zedt, 
   {{0x68f47ec3,0xd12c7ec4,0x00000000,0x00000000}},	//   _mayd, دمن_, --, --, 
   {{0x63b47ec5,0x68f47ec6,0x3eac0327,0x7ae80175}},	//   msyn, _layd, _qedt_, xedt, 
   {{0x91e0196e,0x63b46ab9,0x7ae82ab7,0x3eac0010}},	//   _поре, lsyn, vedt, _vedt_, 
   {{0x63b40b1d,0xa2a80d0a,0x68f40946,0x7188023b}},	//   osyn, टरव्, _nayd, _фатҳ_, 
   {{0x7ae80c8c,0x5f745220,0x28c4448b,0xdc640023}},	//   tedt, _فائر, _वाजि, _ስድራይ_, 
   {{0x78ac7ec7,0x68f40009,0x63b4002d,0xb4e81fe7}},	//   _seav, _aayd, isyn, _यस्_, 
   {{0x68f40050,0x78ac007d,0x63b47e14,0x7ae87ec8}},	//   _bayd, _peav, hsyn, redt, 
   {{0xae34021a,0xc0cc044e,0x78ac0a73,0x68f41af4}},	//   _غونډ, _ባሕሪ_, _qeav, _cayd, 
   {{0x68f47ec9,0x7ae87eca,0xb6c400f7,0x78ac7ecb}},	//   _dayd, pedt, мөнд, _veav, 
   {{0x78ac7ecc,0x63b47ecd,0x3d04000d,0x00000000}},	//   _weav, dsyn, वाके_, --, 
   {{0x68f412ca,0x78ac7ece,0x2124011f,0x34947ecf}},	//   _fayd, _teav, kkoh_, дабр, 
   {{0x68f47ed0,0x48dc00bc,0x00000000,0x00000000}},	//   _gayd, ग्दो_, --, --, 
   {{0xdcf80029,0x212403a2,0xaac402dd,0x58d00220}},	// [9870] _attī, dkoh_, _ءتۇن, _жоқт, 
   {{0xc0cc0092,0x68f4022e,0x00000000,0x00000000}},	//   _ባሕረ_, _zayd, --, --, 
   {{0x68f47ed1,0xa6c8022e,0x051c03d4,0xab5c0135}},	//   _yayd, _emаs, _নগৰৰ_, fużj, 
   {{0x68f47ed2,0x21240438,0x98bc00bc,0x00000000}},	//   _xayd, gkoh_, ्लिए, --, 
   {{0x43940024,0xb6480046,0x00000000,0x00000000}},	//   _паяс, _ﻋﻠ_, --, --, 
   {{0xdee00117,0x00000000,0x00000000,0x00000000}},	//   воши, --, --, --, 
   {{0x51840323,0xdd8c00e5,0x41c400c0,0x00000000}},	//   _хуга, لڈن_, _пёта, --, 
   {{0x63600af2,0xeb98013e,0x7dc4075e,0x00000000}},	//   sônt, оии_, رتىك, --, 
   {{0x68f47ed3,0xab5c033f,0xce3000f1,0x40340114}},	//   _rayd, erża, _ګواک, _зетс, 
   {{0x68f47ed4,0x9e947ed5,0x00000000,0x00000000}},	//   _sayd, _قامچ, --, --, 
   {{0x68f47ed6,0x1dc4032c,0x00000000,0x00000000}},	//   _payd, रूआत, --, --, 
   {{0x68f47ed7,0x63b40209,0x05140882,0x6fd02d6b}},	//   _qayd, ysyn, maṇḍ, _समां, 
   {{0xfaf80055,0x00000000,0x00000000,0x00000000}},	//   bdī_, --, --, --, 
   {{0x68f40050,0x6b6407d6,0x4ad40a81,0x4298001f}},	//   _wayd, _юкла, _راتھ_, ህንነት_, 
   {{0x63b47e14,0x68f47ed8,0x24f47ed9,0xd84c063f}},	//   wsyn, _tayd, мчар, wọta_, 
   {{0x48c40032,0x00000000,0x00000000,0x00000000}},	//   _яҙма, --, --, --, 
   {{0x80b40050,0xd4641d83,0xe3b81b04,0xd8740228}},	// [9880] _उजबे, дите_, юба_, _ۉمۉت_, 
   {{0x673c035a,0x00000000,0x00000000,0x00000000}},	//   _umpj, --, --, --, 
   {{0xc0cc0020,0x63b47eda,0x7bdc054e,0xbebc0171}},	//   _ባሕር_, ssyn, ărui, _klīv, 
   {{0xf1a87edb,0x63b47edc,0xd84c063f,0x5a14010f}},	//   سامه_, psyn, pọta_, וקען_, 
   {{0xd84c063f,0x2124036e,0x00000000,0x00000000}},	//   lọra_, rkoh_, --, --, 
   {{0xdd985f5d,0x9e0441e4,0x00000000,0x00000000}},	//   оши_, дчил, --, --, 
   {{0x61447edd,0x52800124,0xc0c405a2,0xbebc00de}},	//   _жева, _агрб, _зәли, _olīv, 
   {{0x91e04316,0xb0b8009d,0x00000000,0x00000000}},	//   _шосе, _нуух_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbebc00e2,0xfaf81c52,0xdd9000f2,0x051400cd}},	//   _blīv, rdī_, _شوش_, caṇḍ, 
   {{0x9c2406ed,0x6d446085,0x81e800cc,0x00000000}},	//   _одед, éhat, বিপ_, --, 
   {{0x1bf03eaf,0xed4c01d3,0xc864009d,0x00000000}},	//   _अनिल_, _دھو_, втри, --, 
   {{0xd90c7ede,0x25b80051,0x00000000,0x00000000}},	//   ایک_, _bvpl_, --, --, 
   {{0x61fc7edf,0x29e0025c,0x00000000,0x00000000}},	//   jvpl, għaġ_, --, --, 
   {{0x7af87ee0,0xb4c81b90,0x93240133,0x00000000}},	//   _havt, ईले_, ژران, --, 
   {{0x7af80218,0x058404da,0x33747ee1,0x7e682ab7}},	// [9890] _kavt, турм, егар, _lydp, 
   {{0x81e802a6,0x38687ee2,0x7af80153,0xf1940022}},	//   বিন_, _iyar_, _javt, еижь, 
   {{0x6d9400e4,0xd84c01f2,0x00000000,0x00000000}},	//   _aġan, pọsa_, --, --, 
   {{0x38680b45,0x6b8c011c,0x41740150,0x7af80627}},	//   _kyar_, _èagg, نانس, _lavt, 
   {{0xe638001f,0x66180158,0x85740eed,0x00000000}},	//   _ከትናን, øtkv, _шлюх, --, 
   {{0x7af87ee3,0x92e87ee4,0x00000000,0x00000000}},	//   _navt, _برحق_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdd8c7ee5,0x69c405ac,0xab5c0327,0x00000000}},	//   حوي_, _åhei, mużi, --, 
   {{0x3d0403f3,0x7af87ee6,0x3868020c,0xab5c031c}},	//   वाजे_, _bavt, _nyar_, lużi, 
   {{0x8c9c06ab,0x7af8107d,0x00000000,0x00000000}},	//   _ग्रो, _cavt, --, --, 
   {{0x38687ee7,0xbebc00de,0x00000000,0x00000000}},	//   _ayar_, _plīv, --, --, 
   {{0x386803d4,0xf7680a1e,0x00000000,0x00000000}},	//   _byar_, _הק_, --, --, 
   {{0xebe42002,0x00000000,0x00000000,0x00000000}},	//   _чолп, --, --, --, 
   {{0xe6a800e1,0x386c030a,0x66180419,0x6d6801e4}},	//   करेज, üera_, ätko, ŭsaĵ, 
   {{0x3d040574,0xdb4c01d9,0xa5080e92,0xfb840022}},	//   वाचे_, _دَو_, пева_, _рыцн, 
   {{0x7af87ee8,0x386c012d,0x81e800cc,0x3cf400cd}},	//   _zavt, żera_, বিম_, ्यये_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [98a0] --, --, --, --, 
   {{0x59a47aec,0xdb0c0158,0x48dc024a,0xc5b401af}},	//   कीकर, ådøm, ग्रो_, _ирмө, 
   {{0x3cf469a0,0xe2b401c6,0x11d4007b,0x00000000}},	//   ्यमे_, _үсгэ, فولة_, --, 
   {{0x8c9c7ee9,0x386803f9,0x2b440198,0x61fc007c}},	//   _ग्लो, _yyar_, hilc_, rvpl, 
   {{0xe3b07eea,0x7e6821e3,0xbed40798,0x00000000}},	//   _حرج_, _sydp, волј, --, 
   {{0xab5c031c,0x52c40154,0x00000000,0x00000000}},	//   bużi, র্বৃ, --, --, 
   {{0x628c7eeb,0x1cb8031c,0x02cc090a,0xab5c012d}},	//   _igbo, _མཧཱ_, ालीन, erżo, 
   {{0x7af87eec,0x00000000,0x00000000,0x00000000}},	//   _savt, --, --, --, 
   {{0xc0c40116,0x0e607eed,0x2b907eee,0x3b5421f3}},	//   _зәһи, ккән, لینس, ккир, 
   {{0x7e680660,0x7af80477,0x1a7402dd,0xcb640640}},	//   _tydp, _qavt, нұлы_, нање_, 
   {{0x386850f9,0xd05803f9,0x628c0521,0xd334011a}},	//   _syar_, _bauɗ, _mgbo, גריה_, 
   {{0x38680113,0x48dc05d7,0xf79402d5,0x8cd419cc}},	//   _pyar_, ग्लो_, камэ, _यायो, 
   {{0x628c0cad,0xd0580198,0x8ba001c0,0x00000000}},	//   _ogbo, _dauɗ, _бичж, --, 
   {{0x628c7eef,0x999c00dd,0x656400b5,0xbebc00de}},	//   _ngbo, sztő_, _akkh, _glīt, 
   {{0xb5c80214,0x55047ef0,0x00000000,0x00000000}},	//   ظورم_, нчаа, --, --, 
   {{0x628c7ef1,0xbebc00de,0x00000000,0x00000000}},	//   _agbo, _klīs, --, --, 
   {{0x628c0334,0x386805d1,0x73d87ef2,0xd324009d}},	// [98b0] _bgbo, _uyar_, ьдар_, ньжи, 
   {{0x65640109,0x00000000,0x00000000,0x00000000}},	//   _ekkh, --, --, --, 
   {{0xc2c40c8b,0x644803b9,0x438800f1,0x00000000}},	//   طيني, _əliə, رنمټ_, --, 
   {{0x628c0521,0x00000000,0x00000000,0x00000000}},	//   _egbo, --, --, --, 
   {{0x69c403cd,0xa1100753,0x00000000,0x00000000}},	//   _åhev, شووت, --, --, 
   {{0xecac0154,0x09d400eb,0x00000000,0x00000000}},	//   _গাইড, তবতা, --, --, 
   {{0xed587ef3,0xb2640014,0xd1380354,0x31847ef4}},	//   мок_, _شُرى, _еха_, _атаң, 
   {{0xdbcc0022,0x272400d7,0xbebc0171,0x63a00332}},	//   _eñív, _vôni_, _slīt, íong, 
   {{0xbebc00e2,0xeee40066,0x00000000,0x00000000}},	//   _plīt, _لغای, --, --, 
   {{0xb0d07ef5,0xeab0007b,0x7f940117,0x00000000}},	//   _हाँग, جعة_, _сафх, --, 
   {{0x2b440010,0x00000000,0x00000000,0x00000000}},	//   rilc_, --, --, --, 
   {{0xfeac0570,0xbebc0171,0x00000000,0x00000000}},	//   _iṣẹ_, _flīs, --, --, 
   {{0x2be400c5,0xfd101291,0x00000000,0x00000000}},	//   _कहिं_, _دجل_, --, --, 
   {{0x7bdc0276,0x78a803b2,0x00000000,0x00000000}},	//   ărut, ðevr, --, --, 
   {{0xb0d0424e,0x0a681a71,0xbebc00ef,0x962400de}},	//   _हांग, _эрди_, _klīr, _noņē, 
   {{0x2be43bca,0x27941ee3,0xa8047ef6,0x00000000}},	//   _कहां_, _ишор, _азил, --, 
   {{0x3cf41161,0x2fdc0211,0x8c20015b,0xdce0025c}},	// [98c0] ्यते_, jtwg_, _বেতন_, _skoċ, 
   {{0x6b8c00ae,0x00000000,0x00000000,0x00000000}},	//   _éagu, --, --, --, 
   {{0xe5a47ef7,0xe4c4001b,0x06b800cc,0xe0d82ff5}},	//   _шини, _ийни, _জাপি, две_, 
   {{0x88b000eb,0x00000000,0x00000000,0x00000000}},	//   _কাঁক, --, --, --, 
   {{0xa3b87ef8,0x5ed80183,0xfeac0cad,0x69c403b2}},	//   _تاجر_, _যোগে, _aṣẹ_, _æhef, 
   {{0x628c00b4,0xa2d405d9,0x6d44020c,0x3ce400bc}},	//   _ugbo, _جيست, èhan, झ्ने_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4f04052f,0x2fdc0218,0xe0d00014,0x04900055}},	//   енән_, btwg_, _خٲر_, _cūḍi, 
   {{0x9f847ef9,0x4bb00150,0x00000000,0x00000000}},	//   _агад, айыс, --, --, 
   {{0xd24c01d9,0xc1800521,0x00000000,0x00000000}},	//   _انہ_, _ịghọ, --, --, 
   {{0x39b805f5,0xa3c47efa,0xf8b80e22,0xd2b400d9}},	//   элнэ_, ैंड_, нөп_, כלית_, 
   {{0x3f8c05b1,0x64480213,0x1c446518,0x91b8011a}},	//   _hidu_, şfiy, _инем, ומטי, 
   {{0x7bdc0356,0x00000000,0x00000000,0x00000000}},	//   ărus, --, --, --, 
   {{0xcf9000c8,0x3f8c01a9,0x8be400db,0x00000000}},	//   יטש_, _jidu_, _شىىق_, --, 
   {{0x3f8c7efb,0xb8d80f22,0xcb640063,0x00000000}},	//   _midu_, _চা_, _шаље_, --, 
   {{0x2ba80316,0x1b0001c6,0x3f8c0118,0x157c0150}},	//   चीका, _сүүн, _lidu_, _ﺣﺎﺗﯩ, 
   {{0x8234036b,0x66180158,0x6b8c01e7,0xddd80118}},	// [98d0] یرما, øtkr, _éagt, _vytř, 
   {{0x798c02b5,0xdcf802b5,0x3f8c19f5,0x2fdc0218}},	//   _hiaw, _kutē, _nidu_, vtwg_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3f8c0254,0x6da40116,0xb0340798,0xdcf800ef}},	//   _aidu_, ңила, лнеш, _mutē, 
   {{0x3f8c003d,0x752c0bd7,0x00000000,0x00000000}},	//   _bidu_, mkaz, --, --, 
   {{0x3f8c0399,0xa6c8022e,0x798c0142,0x752c0332}},	//   _cidu_, _llаn, _liaw, lkaz, 
   {{0x798c0a73,0x752c010f,0x3f8c7efc,0x51840588}},	//   _oiaw, okaz, _didu_, _ауаа, 
   {{0x752c7efd,0x798c7efe,0xe03401c0,0x7cb40131}},	//   nkaz, _niaw, _өмсө, ққәт_, 
   {{0x3f8c7eff,0xab6400f3,0x6b640139,0xfa2000eb}},	//   _fidu_, лвил, лкиа, _ফেলল_, 
   {{0x798c0113,0x3f8c7f00,0x717000d1,0x00000000}},	//   _aiaw, _gidu_, _ئۇچا, --, 
   {{0x798c3223,0x752c04ba,0xbe0401d3,0x00000000}},	//   _biaw, kkaz, _پونٹ, --, 
   {{0x798c7f01,0x7bdc054e,0x2ca800a2,0xe0200241}},	//   _ciaw, ărur, _ýad_, _ìṣè, 
   {{0x798c7f02,0x752c0010,0xa52401d5,0x00000000}},	//   _diaw, dkaz, қмад, --, 
   {{0xa038008f,0xea040014,0x00000000,0x00000000}},	//   געשפ, _موتٍ, --, --, 
   {{0xa6e4032e,0x6d4800ad,0x69340137,0x752c7f03}},	//   _auðæ, oiea, _مةةر, fkaz, 
   {{0x798c089c,0x6d4862f1,0x02cc012c,0x845415bf}},	//   _giaw, niea, ाल्न, لىزچ, 
   {{0x6b8c0491,0x6754678a,0x27240042,0x00000000}},	// [98e0] _éags, _مخدر, _bônt_, --, 
   {{0x57f8025f,0x752c0099,0x6d4801c4,0x246800c0}},	//   _טלפו, akaz, hiea, _rėmą_, 
   {{0xdce0013a,0x3f8c7f04,0xb8647f05,0x6d4801c4}},	//   _skoč, _ridu_, _مایو, kiea, 
   {{0x516400f7,0x9f400241,0x00000000,0x00000000}},	//   гүсү_, _èkú_, --, --, 
   {{0x6d487f06,0x3f8c7f07,0x3cf400dc,0x27240142}},	//   diea, _pidu_, ्यसे_, _fônt_, 
   {{0x3e3c02d3,0xefd40023,0x5ba401a9,0x00000000}},	//   _ክንዛረ, ከብዎ_, қриз, --, 
   {{0x3f8c04ac,0xeea8005e,0x5d6400d1,0x6d4801ab}},	//   _vidu_, ттік_, лтиз, fiea, 
   {{0x3f8c020c,0x6d48002f,0xa06800d8,0x00000000}},	//   _widu_, giea, _заба_, --, 
   {{0xdce008a4,0x60087f08,0x00000000,0x00000000}},	//   _ukoč, _янам_, --, --, 
   {{0x798c7f09,0x6d480363,0x629c7f0a,0x102000f1}},	//   _siaw, aiea, ncpo, _دکمپ, 
   {{0x798c7f0b,0x9cc800c7,0x89d00006,0x00000000}},	//   _piaw, _зыла_, біўш, --, 
   {{0x88b0015b,0x602800e2,0x00000000,0x00000000}},	//   _কাউক, _tēmā, --, --, 
   {{0x386c037e,0xd7ac0073,0x180c00cd,0x69cc0153}},	//   æer_, जींच, ामेव_, _įneš, 
   {{0xba181291,0x3c200118,0x00000000,0x00000000}},	//   _ليتا_, यहीँ_, --, --, 
   {{0x752c07d6,0x798c7f0c,0xd90c04fb,0x00000000}},	//   tkaz, _tiaw, _فید_, --, 
   {{0x752c0030,0x948411cf,0x6b8c0332,0x00000000}},	//   ukaz, гызд, _éagr, --, 
   {{0x752c006c,0xc8d42309,0x4954004b,0x93940b73}},	// [98f0] rkaz, _ازىع, _دخوس, اجرا, 
   {{0x752c05d9,0x52ac34ef,0x6d487f0d,0x672c01e3}},	//   skaz, टरेस, ziea, ckbj, 
   {{0x914801d5,0x9f400241,0xd2580022,0x00000000}},	//   нчда_, _èkù_, хца_, --, 
   {{0xbebc00e2,0x63a00332,0x00000000,0x00000000}},	//   _slīp, íonc, --, --, 
   {{0x2ef41f5a,0x00000000,0x00000000,0x00000000}},	//   издр, --, --, --, 
   {{0xa3e81a55,0x00000000,0x00000000,0x00000000}},	//   _महत_, --, --, --, 
   {{0x6d487f0e,0xada47f0f,0xad5802e8,0xee140139}},	//   tiea, шайл, крих_, рьлэ, 
   {{0x66181611,0x6d247f10,0x6b9c03b2,0x00000000}},	//   ätki, рдиз, ísgo, --, 
   {{0xec780801,0x32442de5,0xbca800db,0xa2a801f9}},	//   ъпи_, _сеңг, ددىك_, टरच्, 
   {{0x98a47f11,0x81e800bd,0xbbe86ea9,0x00000000}},	//   _ēnā_, বির_, اريم_, --, 
   {{0x6d487f12,0xb0b81d8a,0xad2400d1,0x6e18009f}},	//   piea, _उजाग, _پىشى, _جياس_, 
   {{0x60400521,0x8d840334,0x00000000,0x00000000}},	//   ọmen, _сузд, --, --, 
   {{0x6d587f13,0x2cac7f14,0xac181171,0x2874008e}},	//   _ijwa, mbed_, _шоду_, рынр, 
   {{0x6d9400e4,0x2cac7f15,0x6d5802d0,0x69947f16}},	//   _aġai, lbed_, _hjwa, _крих, 
   {{0x29540c04,0x6d5803ac,0x00000000,0x00000000}},	//   _въпр, _kjwa, --, --, 
   {{0x2cac7f17,0x00000000,0x00000000,0x00000000}},	//   nbed_, --, --, --, 
   {{0x29107f18,0x26d80004,0xe298274b,0x00000000}},	// [9900] _inya_, _tcpo_, ваз_, --, 
   {{0x29107f19,0x6d5802d0,0xcaa00023,0x77901dd8}},	//   _hnya_, _ljwa, ወትኩም_, _ریفا, 
   {{0xaadc7f1a,0x2910079b,0x6d5801f0,0x2cac257d}},	//   _मानक, _knya_, _ojwa, kbed_, 
   {{0xc7b4013f,0x81e8015b,0xdfa4147e,0x6d58491b}},	//   _kwɑ_, বিল_, ајко, _njwa, 
   {{0xdef8169c,0x29000014,0x9f8401c0,0x1aec015b}},	//   вый_, idka_, агдд, ড়াতে_, 
   {{0xd00c7f1b,0x6d587f1c,0x63a40857,0xcee400d8}},	//   بله_, _ajwa, _itkn, идче_, 
   {{0x29107f1d,0x3cf4012c,0x00000000,0x00000000}},	//   _onya_, ्यले_, --, --, 
   {{0xa3e87f1e,0x29107f1f,0x61ec7f20,0x9c087f21}},	//   _महा_, _nnya_, _ipbl, вхоз_, 
   {{0x8cd406ab,0xefe87f22,0x6d5803ac,0xfb8801b9}},	//   _यारो, _معلو_, _djwa, лроқ_, 
   {{0x29107f23,0x6d5801f0,0x29000050,0x9b24252c}},	//   _anya_, _ejwa, edka_, рфил, 
   {{0x2cac7f24,0xba14015b,0x20045f12,0x00000000}},	//   bbed_, ান্ড_, lvoi_, --, 
   {{0x38c861f4,0x57a416c3,0x5fb805f9,0x63a403ac}},	//   دادی_, ишга, _उबाल, _otkn, 
   {{0x20047f25,0x2910020b,0xc7b8039b,0x25a4009b}},	//   nvoi_, _dnya_, иёр_, _čola_, 
   {{0x29107f26,0x29007f27,0xaadc1098,0xfb34084c}},	//   _enya_, adka_, _मायक, _ынлэ, 
   {{0x63a40162,0x29000009,0x46440092,0x00000000}},	//   _atkn, bdka_, _ከትግራ, --, 
   {{0xef180034,0x63a40139,0x349401c6,0x29000009}},	//   _duży_, _btkn, саар, cdka_, 
   {{0x78bc7f28,0x44980a8f,0x4a00031c,0xa6c8022e}},	// [9910] masv, рвую_, _མནོལ_, _lmаy, 
   {{0x39480421,0x78bc7f29,0x63a000c6,0xd5b8036b}},	//   _hmas_, lasv, íona, _исм_, 
   {{0x79980455,0x518425a2,0x02a46bce,0x6d440214}},	//   _juvw, ауда, юртм, èhak, 
   {{0x78bc7f2a,0x799802ea,0x2910020b,0x30147f2b}},	//   nasv, _muvw, _xnya_, йдер, 
   {{0x00c80046,0xf4841888,0x00000000,0x00000000}},	//   рлік_, _دادی, --, --, 
   {{0x78bc7f2c,0x39487f2d,0x7998007f,0xa280072d}},	//   hasv, _lmas_, _ouvw, _کیمو, 
   {{0x78bc7f2e,0x2cac7f2f,0x290001d9,0xf15800a7}},	//   kasv, tbed_, ydka_, _бивш_, 
   {{0x8d240058,0x78bc7f30,0x067c0375,0x3948022e}},	//   рниң_, jasv, כנול, _nmas_, 
   {{0x403425f2,0x2cac7f31,0x7bc07f32,0x78bc4811}},	//   _детс, rbed_, gsmu, dasv, 
   {{0x39487f33,0x7998014f,0x2cac7f34,0x1c400a89}},	//   _amas_, _buvw, sbed_, яным, 
   {{0x291006df,0xaa487c58,0x6d582959,0xacb400aa}},	//   _pnya_, упна_, _tjwa, _هماغ, 
   {{0x6f007f35,0x6d580117,0x6d940030,0x9e740375}},	//   _halc, _ujwa, _všad, _הגעה_, 
   {{0x6c840597,0x29007f36,0x3fbc00d1,0x00000000}},	//   _الشم, rdka_, ﻧﻴﺎﻧ, --, 
   {{0x39487f37,0x6360019f,0x6f007f38,0x7b640050}},	//   _emas_, bôny, _jalc, _واوٕ, 
   {{0xe5a47f39,0x29103223,0x2b88002d,0x34a405db}},	//   сиби, _tnya_, _rźch_, _ụdị_, 
   {{0x29107f3a,0x6f00004e,0xe5a42c11,0x20040124}},	//   _unya_, _lalc, _қими, yvoi_, 
   {{0x69c0334b,0x6f00035a,0x2b100037,0x2168010b}},	// [9920] lsle, _oalc, ़ाऊँ_, ңизи_, 
   {{0x7c240013,0x6754004b,0x69c00076,0x48b00154}},	//   _àire, _دخبر, osle, _কায়র, 
   {{0x69c07f3b,0x20540cef,0xc0cc001f,0x394801a9}},	//   nsle, әтер, _ባሕል_, _ymas_, 
   {{0x69c01016,0x6d940010,0x7bc00108,0x63a40051}},	//   isle, _ošab, ysmu, _ttkn, 
   {{0x74f00150,0x5f04444e,0x63a40210,0xa878010f}},	//   _زۋلا, йзда, _utkn, װאַר, 
   {{0x20047f3c,0x6f007f3d,0x69c07f3e,0x53a04169}},	//   rvoi_, _calc, ksle, _харб, 
   {{0x6f007f3f,0xc0c41f0e,0xa0a47f40,0x78bc00dc}},	//   _dalc, _дәли, _габд, yasv, 
   {{0x69c011aa,0x00000000,0x00000000,0x00000000}},	//   dsle, --, --, --, 
   {{0x78bc7f41,0x6f007f42,0x79980978,0x491c2e37}},	//   vasv, _falc, _suvw, यानो_, 
   {{0x6f000a55,0x799823ee,0x69c07f43,0x78bc05e4}},	//   _galc, _puvw, fsle, wasv, 
   {{0x7bc07f44,0x69c07f45,0x78bc7f46,0x7998047e}},	//   ssmu, gsle, tasv, _quvw, 
   {{0xdce00115,0x7bc02dba,0x7998014f,0x6f004e96}},	//   _bioĥ, psmu, _vuvw, _zalc, 
   {{0x78bc7f47,0x69c00af9,0xad6456e6,0x5fcc0073}},	//   rasv, asle, _باله, हंटल, 
   {{0x78bc7f48,0x69c023fc,0xb5940edb,0xdcf800c0}},	//   sasv, bsle, живш, _putė, 
   {{0x80d84ff1,0x9574034c,0x69c00553,0x63a0007b}},	//   डलाइ, مدرض, csle, íonn, 
   {{0x39487f49,0x00000000,0x00000000,0x00000000}},	//   _umas_, --, --, --, 
   {{0x04c80066,0x00000000,0x00000000,0x00000000}},	// [9930] صولي_, --, --, --, 
   {{0x70d00c2e,0xd6d86147,0xa3e807f7,0x2b100210}},	//   हल्ल, _сти_, _महर_, ़ाएँ_, 
   {{0x6f000455,0x34947f4a,0xd9a00150,0xb86400f1}},	//   _ralc, _манр, _ﺍﻟﺪﻩ_, _داډو, 
   {{0x6f007f4b,0xdd841046,0x61440131,0x491c0b98}},	//   _salc, _زو_, يىلە, यायो_, 
   {{0xf1c407f7,0x6d9401ef,0x00000000,0x00000000}},	//   _लटकन, _ošac, --, --, 
   {{0x69c07f4c,0x2fc80f8b,0xc7d80302,0x92e41c82}},	//   ysle, šago_, מודי_, _মোৰ_, 
   {{0xf48404d3,0xa2040241,0x3134084c,0x720401d5}},	//   _داگی, _bọ́ọ, _девр, _بوزم, 
   {{0x6f007f4d,0x00000000,0x00000000,0x00000000}},	//   _walc, --, --, --, 
   {{0x69c06dc7,0xeb980640,0xd9a00150,0xaadc3cc3}},	//   wsle, јио_, _ﺍﻟﻨﻬ_, _मादक, 
   {{0xeb7800d8,0x00000000,0x00000000,0x00000000}},	//   јсиј_, --, --, --, 
   {{0x06b80eac,0x69c07f4e,0x00000000,0x00000000}},	//   _জালি, usle, --, --, 
   {{0x69c07f4f,0xa3e80d54,0xa9687f50,0xa3a80574}},	//   rsle, _महल_, рима_, _गझल_, 
   {{0xe7687f51,0x9ce80014,0x81e800eb,0x00000000}},	//   لحسن_, _خونے_, বিএ_, --, 
   {{0xfbd00272,0x69c000ed,0x3958007f,0x9f98010f}},	//   _سته_, psle, anss_, יסשפ, 
   {{0xdaa002dd,0x7a840132,0xd6240120,0x9b8400ec}},	//   _تەپپ, _ىشىم, ооре_, _بچيل_, 
   {{0xb3b80ed9,0x00000000,0x00000000,0x00000000}},	//   _བསྡུ, --, --, --, 
   {{0xa3482386,0x00000000,0x00000000,0x00000000}},	// [9940] азаа_, --, --, --, 
   {{0x7cf002d2,0x63a001e4,0xb38c0051,0xb4b80210}},	//   _kóræ, ŭono, _đểph, _घड़ी_, 
   {{0xe1f82dfa,0x11d400c6,0x5b38010f,0x7c3c01e4}},	//   рге_, قولة_, סגעק, ĝrri, 
   {{0x60080209,0xc0cc02d3,0x00000000,0x00000000}},	//   инем_, _ባዕላ_, --, --, 
   {{0xe2987f52,0x649c0427,0xd12c00f1,0x10a00395}},	//   _ваг_, ršič, خمن_, фичн, 
   {{0x6574127b,0x73f8008f,0xddd800ef,0x00000000}},	//   llyh, _פּרו, _uztū, --, 
   {{0xa3e8000d,0x00000000,0x00000000,0x00000000}},	//   _महँ_, --, --, --, 
   {{0x657439ed,0x00000000,0x00000000,0x00000000}},	//   nlyh, --, --, --, 
   {{0x81bc7f53,0x00000000,0x00000000,0x00000000}},	//   _আমি_, --, --, --, 
   {{0xc0cc069c,0xb3b80003,0x9a8802e8,0x6574127b}},	//   _ባዕሉ_, _བསྣུ, ищна_, hlyh, 
   {{0x13b000bd,0xd0040262,0xdcf800e2,0x5ca40166}},	//   টওয়, _леӂе_, _jutī, _диеб, 
   {{0xc0e802d3,0xdcf80171,0x00000000,0x00000000}},	//   _መሓሪ_, _mutī, --, --, 
   {{0x6574035a,0x9f400cad,0x00000000,0x00000000}},	//   dlyh, _èkó_, --, --, 
   {{0x6d944fe7,0xcc7400d9,0x00000000,0x00000000}},	//   _iġar, _ועדה_, --, --, 
   {{0xda640214,0x46dc2cf5,0x00000000,0x00000000}},	//   _باشي, _बारह, --, --, 
   {{0x0584026b,0x00000000,0x00000000,0x00000000}},	//   дуум, --, --, --, 
   {{0x6d94031c,0x7338003b,0x4974003b,0x00000000}},	// [9950] _jġar, бзар_, _ільс, --, 
   {{0x8c180375,0x6d94025c,0xbebc0171,0x00000000}},	//   בומי, _mġar, _elīz, --, 
   {{0x877c008f,0xbebc00e2,0x657403ac,0x802400d1}},	//   _דאזי, _flīz, blyh, ېرىم, 
   {{0x1ce4025c,0x33947f54,0x09ac0183,0x51844166}},	//   ྫུས_, _намё, _কিমা, цуза, 
   {{0x251806a9,0x6d940327,0xb4c83166,0xa02000a2}},	//   _הורא, _nġar, ैली_, _çöli, 
   {{0xe3b000c8,0xb8dc0327,0x224401e4,0x00000000}},	//   _אױך_, _ཇབ_, ŝoka_, --, 
   {{0x09ac00bd,0x00000000,0x00000000,0x00000000}},	//   _কিভা, --, --, --, 
   {{0xd08400c7,0xbdf80214,0x92b0015b,0xf0e800cf}},	//   _дызи, ترها_, _টায়_, _دىرى_, 
   {{0x4ea40276,0xaed4084c,0xe8f80032,0x4ee40024}},	//   _дреа, _ноаш, ҡло_, _міжз, 
   {{0xce6800a8,0x09ac00fe,0xe9d81318,0xaa440114}},	//   _кред_, _কিবা, бко_, зеол, 
   {{0x657401f4,0xce300244,0x00000000,0x00000000}},	//   ylyh, _تواک, --, --, 
   {{0xaf840023,0x5fd06d65,0x00000000,0x00000000}},	//   _ዝሃበና_, _सिमल, --, --, 
   {{0x2c0804fb,0x5d780677,0x6aac0166,0x00000000}},	//   _دعای_, _פאנק, _ğaff, --, 
   {{0xaa4455b6,0xdbc4000d,0x00000000,0x00000000}},	//   _нелл, tööj, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe93800f2,0xdcf800de,0x00000000,0x00000000}},	//   _دستت_, _rutī, --, --, 
   {{0xe568020a,0x386c05d5,0x65740142,0xdcf8002b}},	// [9960] _ҳинд_, üert_, rlyh, _sutī, 
   {{0x13007f55,0x2cbc045a,0x00000000,0x00000000}},	//   нзум, _lewd_, --, --, 
   {{0x64a47f56,0x569802e4,0x3c801884,0x657401f4}},	//   _нана, _לייצ, ﻧﯩﺴﻰ_, plyh, 
   {{0x46dc05f9,0x00000000,0x00000000,0x00000000}},	//   _बाँह, --, --, --, 
   {{0xe47459e6,0xa0680395,0x00000000,0x00000000}},	//   _хунэ, щада_, --, --, 
   {{0x290c0134,0x44200003,0x98780a7c,0x00000000}},	//   _ɔfaa_, mxi_, זאנט, --, 
   {{0xa3c4012c,0x44204879,0x23d800cd,0xe2982cdd}},	//   ैंक_, lxi_, यंवद, _ваҳ_, 
   {{0x4dd00d1f,0xa0a4009d,0x00000000,0x00000000}},	//   رتىس, _хаад, --, --, 
   {{0x44207f57,0x60c07f58,0x46dc00e1,0xa2dc00fe}},	//   nxi_, maom, _बांह, ড়ীখ, 
   {{0x442000f7,0x60c07f59,0xa6300023,0x00000000}},	//   ixi_, laom, _ጽግዕተ, --, 
   {{0xaadc7e2a,0x6d940024,0xc8780213,0xcf9005d0}},	//   _मारक, _išan, əği_, _נטע_, 
   {{0x60c07f5a,0x44200227,0xe16c01ec,0x00000000}},	//   naom, kxi_, ктiң_, --, 
   {{0xfaf80421,0xb788054a,0xd7f8010b,0x6d94013a}},	//   peī_, және_, щун_, _kšan, 
   {{0x60c00109,0x44200077,0x36d4003b,0x00000000}},	//   haom, dxi_, ьогр, --, 
   {{0x60c005b8,0xdb4c04d3,0x25b8015d,0x442000e8}},	//   kaom, _لێک_, _cwpl_, exi_, 
   {{0xb4c8038e,0x60c000c5,0x4a58011a,0x00000000}},	//   ैले_, jaom, _לדוו, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [9970] --, --, --, --, 
   {{0x09ac2158,0xfbd437e3,0x21fc00bc,0x883c0375}},	//   _কিতা, _दिनम, _bůh_, _לתחו, 
   {{0x25b80042,0x44207f5b,0x00000000,0x00000000}},	//   _gwpl_, axi_, --, --, 
   {{0x70540f1b,0x60c00170,0xd84c01f2,0xb0540799}},	//   وناا, gaom, pọda_, وپات, 
   {{0xaadc0a8a,0x4420003a,0xafe40150,0x00000000}},	//   _मालक, cxi_, фолл, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x60c07851,0x00000000,0x00000000,0x00000000}},	//   baom, --, --, --, 
   {{0xa280004b,0x100402d5,0x8ca000db,0x00000000}},	//   _شینو, _нязм, رەتو, --, 
   {{0x6f643629,0xdd8c1622,0x00000000,0x00000000}},	//   _قهرم, جوي_, --, --, 
   {{0xd84c02e3,0x00000000,0x00000000,0x00000000}},	//   kọba_, --, --, --, 
   {{0xd6e000bd,0x753c7f5c,0xe8f85211,0x7c2401c3}},	//   য়ায, _olsz, олн_, _àirn, 
   {{0x4420102c,0x00000000,0x00000000,0x00000000}},	//   yxi_, --, --, --, 
   {{0x44207f5d,0xbbe804fb,0x989400d1,0x393401c6}},	//   xxi_, _فروم_, дурә, хээс, 
   {{0xca60022e,0x60c00083,0x753c01d3,0x491c0037}},	//   _innо, zaom, _alsz, याहो_, 
   {{0x60c07f5e,0x55e07f5f,0xa5087f60,0xfb241e24}},	//   yaom, корб, оева_, _سروپ, 
   {{0x442005f5,0xe3b81679,0x81bc0154,0xe5781cd0}},	//   txi_, жба_, _আমল_, іза_, 
   {{0x60c07f61,0x321000a2,0xa764009b,0x44200051}},	// [9980] vaom, _arzy_, _окид, uxi_, 
   {{0x60c00451,0x753c01ed,0x44207f62,0x3210012c}},	//   waom, _elsz, rxi_, _brzy_, 
   {{0xf1a4005e,0x60c07f63,0x32100009,0x1718008f}},	//   ерін, taom, _crzy_, _וויע, 
   {{0x44202e95,0xe0d000cf,0x224401e4,0x00000000}},	//   pxi_, ئزا_, ŝoko_, --, 
   {{0x8fa07f64,0xc0e8001f,0x39580c6a,0xe3b01888}},	//   ваче, _መናር_, érsi_, _جرج_, 
   {{0xdda80a15,0x9f880036,0x00000000,0x00000000}},	//   отил_, höön_, --, --, 
   {{0x9f88005b,0x326401f0,0x00000000,0x00000000}},	//   köön_, _зерҳ, --, --, 
   {{0xa1147f65,0xdc8c01f2,0xa0685550,0x5ba40107}},	//   _تورت, _dịnụ_, _даба_, мроз, 
   {{0x21240455,0x6d9400c0,0x5574010f,0x00000000}},	//   mjoh_, _išal, ועקן_, --, 
   {{0x1b3c069c,0x8f2800dd,0xcb640b3e,0x1a740150}},	//   _ፖሎቲካ, _وآلہ_, мање_, мұлы_, 
   {{0xda482077,0x52d40115,0x00000000,0x00000000}},	//   ючил_, וויע_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6fc0070f,0x6aac2b24,0x00000000,0x00000000}},	//   रीपू, _şafe, --, --, 
   {{0xd84c01f2,0x00000000,0x00000000,0x00000000}},	//   tọba_, --, --, --, 
   {{0x9964036b,0x49b40fb4,0x6d940419,0x00000000}},	//   _отил, _قايد_, _ošal, --, 
   {{0xd6b400b2,0xab5c0034,0xd7f87f66,0x661803cd}},	//   _ڪندڙ_, duży, _дуо_, åtka, 
   {{0x21240cf4,0x491c0cf1,0x977c030d,0xada002d2}},	// [9990] djoh_, यारो_, _вунă_, _þúve, 
   {{0x3210006d,0xd84c063f,0xd37802d5,0x00000000}},	//   _przy_, pọba_, іча_, --, 
   {{0xd2587f67,0xdcf80064,0x51a82309,0x00000000}},	//   цца_, _nutį, زداپ_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf4087f68,0xb3b80003,0xd0002d31,0x2fc8007b}},	//   _عيسى_, _བསྲུ, толқ, éag_, 
   {{0xaadc06bc,0x32100034,0x83a801f0,0xc0e80023}},	//   _माइक, _trzy_, _ютюб_, _መዓር_, 
   {{0x3d100c2e,0x7dc47f69,0xa6c8022e,0x00000000}},	//   _दोहे_, نتيك, _zlаs, --, 
   {{0xf10400cf,0xb38c0051,0x00000000,0x00000000}},	//   _سۉتۉ_, _độph, --, --, 
   {{0x301401c0,0x7c2401ab,0x00000000,0x00000000}},	//   _ядар, _àirl, --, --, 
   {{0x18a0005e,0xe9d87f6a,0x40840124,0xb3b8025c}},	//   ғарм, пко_, _русб, _བསླུ, 
   {{0x9f88049b,0x270c0c58,0x00000000,0x00000000}},	//   töön_, _সকলো_, --, --, 
   {{0x684406bd,0x00000000,0x00000000,0x00000000}},	//   енма, --, --, --, 
   {{0x2d8c7f6b,0xab5c0210,0x00000000,0x00000000}},	//   mmee_, zuży, --, --, 
   {{0x61380137,0x2d8c198f,0xb3ac0154,0xe7380556}},	//   _aïll, lmee_, _চিংড়, чег_, 
   {{0xa3e022e3,0x2d8c208d,0x9f8801f4,0x00000000}},	//   नून_, omee_, pöön_, --, 
   {{0x9f400270,0x7e7c05ac,0x6d9407f5,0xa6c8022e}},	//   _īkí_, _ørpe, _ošam, _plаs, 
   {{0xd4643252,0x2d8c0076,0x63840798,0x4ad04433}},	// [99a0] еите_, imee_, егаа, _दयाव, 
   {{0xd83c04bf,0x2d8c05b1,0xe72c0139,0x39a400fd}},	//   íček_, hmee_, _kiеm_, _яшәв, 
   {{0xaadc0d1a,0x6d940064,0x00000000,0x00000000}},	//   _माईक, _pšal, --, --, 
   {{0xa0a4016c,0x492000b7,0x00000000,0x00000000}},	//   хадд, _ቴሌቪዥ, --, --, 
   {{0xb7c4007f,0x1fb40117,0x03a8009f,0x00000000}},	//   _etãƒ, хсер, _آگرو_, --, 
   {{0x9e047f6c,0xdb00010e,0xa6c8022e,0x21240455}},	//   ечил, _itoç, _zlаr, sjoh_, 
   {{0x61440a93,0x00000000,0x00000000,0x00000000}},	//   _зева, --, --, --, 
   {{0xd0207f6d,0xa0c406f6,0x1278010f,0x00000000}},	//   тмәй, _سيئو, _זאלע, --, 
   {{0x3ec400c7,0x09ac009e,0x00000000,0x00000000}},	//   _аизҳ, _কিষা, --, --, 
   {{0x8fa00364,0x2d8c7f6e,0x7c2401ab,0x7afc022e}},	//   _сафе, amee_, _àirm, еrta, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xed4c01c8,0x00000000,0x00000000,0x00000000}},	//   _وھي_, --, --, --, 
   {{0xa6c8022e,0x486402e8,0x858c0220,0x00000000}},	//   _rlаr, гърб, _ﻓﻬﺫﺍ_, --, 
   {{0xa3e82871,0x8c1806a9,0xa6c8022e,0xf5e800ec}},	//   _महज_, _מודי, _slаr, وڙجي_, 
   {{0xc6687f6f,0xd5a001d5,0x00000000,0x00000000}},	//   еште_, الری, --, --, 
   {{0x4a780375,0x8a78011a,0xb81400f3,0x69d401f9}},	//   _מרוב, _מאות, _адиј, _भिती, 
   {{0x78ac0022,0x34942be5,0x981400ae,0x00000000}},	// [99b0] _ifav, таар, _أبعا, --, 
   {{0x2d8c014b,0x92e400eb,0x00000000,0x00000000}},	//   zmee_, _মোড়_, --, --, 
   {{0xcad40375,0x2d8c5f8b,0xa6c8022e,0x3218007b}},	//   תובת_, ymee_, _tlаr, بياد_, 
   {{0xb50400f7,0xa6c801d5,0xe28c01d5,0xb03400d8}},	//   _جۉرۅ_, _ulаr, ndаy_, кнеш, 
   {{0x166401d9,0xb4cc05c0,0xcf981f5a,0x00000000}},	//   _زاگَ, रणी_, чје_, --, 
   {{0x3eac7f70,0xd2580395,0xf7cc02dd,0x00000000}},	//   _cfdt_, _ецб_, _ﺑﻪﻟﻪ, --, 
   {{0x78ac00e4,0x7e5402e8,0xfec802f2,0xee080395}},	//   _ofav, лтъц, ربوو_, фейл_, 
   {{0xfe703c19,0x2d987f71,0x2d8c062c,0xdd8c0472}},	//   حده_, öse_, umee_, يوو_, 
   {{0x2d8c7890,0x6b4c00a2,0xfca805d9,0x5bc022fd}},	//   rmee_, _aºga, رايو_, айыб, 
   {{0xc6bc1d4c,0x78ac7f72,0xdbcc00e4,0x2d8c0af9}},	//   _অঞ্চ, _afav, _añóv, smee_, 
   {{0xa9687136,0x386803e3,0xbbe82927,0x6bd402f2}},	//   дина_, _axar_, وریم_, رتکر, 
   {{0x6298000f,0x2fcc03cd,0xbdf80cd2,0x7db4007b}},	//   _útoe, _kveg_, _سرما_, _إصلا, 
   {{0x386800e8,0x00000000,0x00000000,0x00000000}},	//   _cxar_, --, --, --, 
   {{0x78ac007f,0xdbcc00e4,0xf1d001ad,0x85b40131}},	//   _efav, _eñóv, _हिंन, ләмч, 
   {{0xf66418bc,0x6fc001f9,0x00000000,0x00000000}},	//   герү, रीतू, --, --, 
   {{0x4a700150,0x00000000,0x00000000,0x00000000}},	//   _иықт, --, --, --, 
   {{0x6d947f73,0x00000000,0x00000000,0x00000000}},	// [99c0] _ašak, --, --, --, 
   {{0xfbd4068f,0x93407f74,0xdee0001f,0xe738026a}},	//   _दिसम, ануе, ኑትን_, _цео_, 
   {{0xb6d804ac,0x2fcc7f75,0xbebc00b0,0xe644010a}},	//   _אַרט, _aveg_, _moīt, _ренп, 
   {{0xa3e04614,0x64a47f76,0x78ac0789,0x00000000}},	//   नंद_, _шама, _xfav, --, 
   {{0x44242b93,0x716400ae,0x00000000,0x00000000}},	//   _çm_, دالك, --, --, 
   {{0xe2845211,0xb2c4020c,0x00000000,0x00000000}},	//   _алги, _مغفو, --, --, 
   {{0x68f42f53,0x63b4007c,0x5d6400f3,0x00000000}},	//   _obyd, lpyn, ктиз, --, 
   {{0xd7d0000d,0x6aac0139,0x00000000,0x00000000}},	//   _तिलच, _ğafa, --, --, 
   {{0x63b47e14,0x6aac7f77,0x5f04035b,0xbb7410fc}},	//   npyn, _şafa, _изаа, лгиј, 
   {{0x78ac7f78,0x68f40a05,0xd17400c7,0x3074010b}},	//   _sfav, _abyd, _зыӡы, _сусс, 
   {{0x78ac0208,0x39940023,0x98a40219,0xb6c400fb}},	//   _pfav, _መቃለሲ_, šiča_, һөнд, 
   {{0x0e5400d9,0xd7f80fdc,0xcba00022,0xfcc401af}},	//   _בשבט_, муг_, ықәҿ, _сәкм, 
   {{0x7d007f79,0x1b28007b,0xb6c47f7a,0x8c40009b}},	//   mems, _يأتي_, лөнд, _кеце, 
   {{0x7d007f7b,0x00000000,0x00000000,0x00000000}},	//   lems, --, --, --, 
   {{0xa2c400cd,0x00000000,0x00000000,0x00000000}},	//   िरन्, --, --, --, 
   {{0xb4cc53c3,0x3868009d,0x63b40af9,0x7f58047e}},	//   रणे_, _txar_, fpyn, hivq, 
   {{0x39587f7c,0x7a3802d2,0x6ab000e5,0x00000000}},	// [99d0] miss_, _fútú, _éjfé, --, 
   {{0x39587f7d,0x7d007f7e,0xd2580114,0x68f401ef}},	//   liss_, hems, мце_, _zbyd, 
   {{0x63b403a2,0x61440e8e,0x7d007f7f,0x02a40a93}},	//   apyn, گىنە, kems, ррум, 
   {{0x39587f80,0x06d809bd,0xdce00135,0x7d007f81}},	//   niss_, দ্দি, _djoċ, jems, 
   {{0x63a00597,0x00c00150,0x6144215c,0x00000000}},	//   íont, _ﺯﻩﺗﺘ, دىنە, --, 
   {{0xda64038b,0x6d940024,0x3958002f,0x00000000}},	//   _هُ_, _išai, hiss_, --, 
   {{0x3958005c,0x6d9400e2,0x7d00366f,0x9104024c}},	//   kiss_, _ušak, fems, _ичад, 
   {{0xac0800c7,0x6448012d,0xcc800116,0x00000000}},	//   ениа_, źliś, _ﮬﻪﺭﮔ, --, 
   {{0xeb987f82,0x2fd820ad,0xc0e00020,0x7f580455}},	//   нии_, _سواد_, ኑንም_, bivq, 
   {{0x5c8401e0,0x629801ef,0x00000000,0x00000000}},	//   ыйым_, _útoc, --, --, 
   {{0x7d00014b,0x39580135,0x00000000,0x00000000}},	//   bems, fiss_, --, --, 
   {{0xd6e004c5,0xd9940133,0xccb00139,0x3a3803b2}},	//   য়োপ, ێنیت_, _тәкь, ørpa_, 
   {{0x39580ba1,0xa400033f,0xed580118,0x37c414d4}},	//   èrsa_, _रैंप_, miž_, ағым_, 
   {{0xc0e8044e,0xed580010,0x00000000,0x00000000}},	//   _መዓስ_, liž_, --, --, 
   {{0x2d9c7f83,0x39587f84,0x05a40037,0x24f40408}},	//   _kiwe_, biss_, _खूशब, лчар, 
   {{0x2cac7f85,0x2d9c00ec,0x3958202c,0x23080633}},	//   nced_, _jiwe_, ciss_, کتري_, 
   {{0x29007f86,0x2cac0204,0x2d9c0432,0xd1e80092}},	// [99e0] meka_, iced_, _miwe_, _መባቻ_, 
   {{0xca740201,0x7d001758,0x491c038e,0x2d9c7f87}},	//   _ቢሆንም_, zems, याको_, _liwe_, 
   {{0xe0d80d84,0x248401f1,0x7d007f88,0x26c87f89}},	//   еве_, ťom_, yems, mabo_, 
   {{0x29001827,0x26c87f8a,0x2d9c7f8b,0x9fc834d8}},	//   neka_, labo_, _niwe_, егда_, 
   {{0x7d000212,0x7f58047e,0x5cc464b6,0xed582438}},	//   vems, tivq, ңсиз, diž_, 
   {{0x26c81df8,0x1ea8035d,0x29007f8c,0x65747f8d}},	//   nabo_, راتي_, heka_, loyh, 
   {{0x2d9c1446,0x7d0014dc,0x63a403f0,0xdd9833d2}},	//   _biwe_, tems, _hukn, нши_, 
   {{0x29007f8e,0x2d9c1446,0x26c87f8f,0xae087f90}},	//   jeka_, _ciwe_, habo_, विजन_, 
   {{0x29007f91,0x26c87f92,0x63a47f93,0x7d007f94}},	//   deka_, kabo_, _jukn, rems, 
   {{0x7d003917,0x3b547f95,0x63a403f9,0x39582ad7}},	//   sems, ркор, _mukn, wiss_, 
   {{0xb3b80867,0x2d9c27be,0x26c87f96,0x63a47f97}},	//   _བསྐུ, _fiwe_, dabo_, _lukn, 
   {{0x29007f98,0x2d9c0083,0xd7e4177b,0x26c80083}},	//   geka_, _giwe_, ліго, eabo_, 
   {{0xd8380323,0x63a40280,0xf3d40327,0x15e4000d}},	//   хэн_, _nukn, ུངབཅ, _ओमहर_, 
   {{0x26c8633d,0x2d9c7f99,0xd3a40131,0xc6e402dd}},	//   gabo_, _ziwe_, ғрап, йісп, 
   {{0x2900124c,0x2d9c1459,0x63a40008,0xa3e002ab}},	//   beka_, _yiwe_, _aukn, नूस_, 
   {{0x1b000323,0x290001bd,0x27e00083,0xf8a801b9}},	//   _түүн, ceka_, bukn_, _جگده_, 
   {{0x36d47f9a,0xb35425c4,0x798c7f9b,0x61ec0009}},	// [99f0] _копр, акаш, _ihaw, _aqbl, 
   {{0x798c0117,0x26c87f9c,0x63a47f9d,0xf9fc0327}},	//   _hhaw, cabo_, _dukn, _ྐྱོན_, 
   {{0x798c7f9e,0x3254147e,0x67200d0b,0x6d440af9}},	//   _khaw, јвер, मारक_, ëhak, 
   {{0x30147f9f,0x63a40548,0x3f8c022e,0xf8b402a0}},	//   идер, _fukn, _ahdu_, ंडिय, 
   {{0x798c02b9,0x752c7fa0,0xb3b8025c,0x2d9c063f}},	//   _mhaw, mjaz, _བསྒུ, _riwe_, 
   {{0x290015d3,0x2d9c7fa1,0x98a80006,0x2cac00f1}},	//   zeka_, _siwe_, ėjęs_, wced_, 
   {{0x29007fa2,0xed58031d,0xddc012b4,0xdcf803ee}},	//   yeka_, tiž_, общи, _attı, 
   {{0x26c87fa3,0x29007fa4,0xf9fc031c,0x63a47fa5}},	//   zabo_, xeka_, _ྐྱེན_, _yukn, 
   {{0x26c8046a,0x29007fa6,0xd84c063f,0x2d9c7fa7}},	//   yabo_, veka_, fọma_, _viwe_, 
   {{0x290000b2,0x798c0526,0x2d9c5975,0x26c87fa8}},	//   weka_, _ahaw, _wiwe_, xabo_, 
   {{0x29007fa9,0x26c8014a,0x69247faa,0x798c0810}},	//   teka_, vabo_, амна, _bhaw, 
   {{0x798c7fab,0x26c87fac,0x2bdc0574,0x752c02f0}},	//   _chaw, wabo_, _मिपा, jjaz, 
   {{0x29007fad,0x798c7fae,0x6d480ea3,0x752c7faf}},	//   reka_, _dhaw, mhea, djaz, 
   {{0x6d487fb0,0x798c0921,0x1ae00cef,0x63a45906}},	//   lhea, _ehaw, _дошм, _rukn, 
   {{0x26c87fb1,0x63a4762b,0x29007fb2,0xddd800c7}},	//   rabo_, _sukn, peka_, _pytũ, 
   {{0x6d487fb3,0x9660005e,0x26c87fb4,0x63a42375}},	//   nhea, ікте, sabo_, _pukn, 
   {{0x78a82aac,0x7af800e4,0x26c800b5,0x779053b6}},	// [9a00] ževc, _ybvt, pabo_, تییا, 
   {{0x6d48030d,0x6d940006,0x2214014b,0x2bdc070f}},	//   hhea, _išau, ифер, _मिना, 
   {{0x6d4806d6,0xa2047fb5,0x6b80015d,0x65740022}},	//   khea, рпед, illg, poyh, 
   {{0x6b04031c,0x61440640,0x491c01ad,0x752c7fb6}},	//   _མིའོ_, једа, याटो_, cjaz, 
   {{0x6d480571,0x5f047fb7,0x6d8401d3,0x9f44002f}},	//   dhea, изда, tóan, groß_, 
   {{0x06d8015b,0x6d4801ab,0x20040175,0x1ea800f1}},	//   দ্রি, ehea, rwoi_, ډاګي_, 
   {{0x6d487fb8,0xbebc0055,0xa3e052f2,0x69d400bc}},	//   fhea, _anīc, नूर_, ázel, 
   {{0x6d487fb9,0x2d980228,0xd24c0014,0x8d7001e2}},	//   ghea, гөчө_, _کنہ_, يايا, 
   {{0xdee47fba,0x29d0003d,0xd0040eff,0x798c7fbb}},	//   _вози, eġa_, _кете_, _rhaw, 
   {{0x798c7fbc,0x752c7fbd,0xdb4c04d3,0x6d4800d8}},	//   _shaw, zjaz, بێت_, ahea, 
   {{0x6d487fbe,0x798c7fbf,0x00000000,0x00000000}},	//   bhea, _phaw, --, --, 
   {{0x6d480571,0x798c7fc0,0xdc2802e9,0x6b800332}},	//   chea, _qhaw, _لسته_, allg, 
   {{0x58847fc1,0x798c0084,0xad24021a,0x386c482b}},	//   рына, _vhaw, _درلو, çer_, 
   {{0x798c0325,0x386c025c,0x0a540066,0x00000000}},	//   _whaw, ħer_, اشیع_, --, 
   {{0x798c0190,0xd90c3faa,0x752c7fc2,0xb4e4000d}},	//   _thaw, _قید_, tjaz, _नाॆ_, 
   {{0x798c0453,0x73c401e0,0x4a98011a,0x00000000}},	//   _uhaw, йәге, _ביוג, --, 
   {{0xd6d80261,0x752c0135,0xa50815bf,0x00000000}},	// [9a10] _итн_, rjaz, دىقە_, --, 
   {{0xec7004ac,0x7ae87fc3,0x6d48030a,0x55040022}},	//   פֿן_, ngdt, zhea, ычҳа, 
   {{0x6d487fc4,0x00000000,0x00000000,0x00000000}},	//   yhea, --, --, --, 
   {{0x6d480354,0x69c402a4,0xd1dc0023,0x00000000}},	//   xhea, _çhee, _ዓቃቢ_, --, 
   {{0x6b8000a9,0x6d48010a,0xe0cc01d9,0x10040d1d}},	//   yllg, vhea, رٲو_, ряем, 
   {{0x6da4220f,0x24847fc5,0xada4013d,0x00000000}},	//   бика, _چھےٚ_, бакл, --, 
   {{0x6d487fc6,0x48e80490,0x6d9402f0,0x81d4014b}},	//   thea, _झालो_, _ošat, _морх, 
   {{0xb3b8025c,0x6d480798,0x00000000,0x00000000}},	//   _བསྙུ, uhea, --, --, 
   {{0x07f40489,0x32440046,0x8ac404a9,0x1f240014}},	//   _བདེཝ_, _теңг, ақла_, _گِلہ, 
   {{0x2bdc00e1,0x00000000,0x00000000,0x00000000}},	//   _मिठा, --, --, --, 
   {{0xd1dc02d3,0x1f2401d9,0x00000000,0x00000000}},	//   _ዓቃብ_, _دِلہ, --, --, 
   {{0x8d847fc7,0xa3e005d7,0x606000cf,0x29d0003d}},	//   _тузд, नूँ_, _بۇۇل, rġa_, 
   {{0x6d587fc8,0x7d7400c6,0x5ec8015b,0x5d100014}},	//   _imwa, _بالط, _রাতে, _رِوا, 
   {{0x6d5803ac,0xd1dc0092,0x00000000,0x00000000}},	//   _hmwa, _ዓቃቤ_, --, --, 
   {{0x78a80f72,0x6d58035a,0xa2c400dc,0x3c3c01d3}},	//   ževa, _kmwa, िरस्, _távú_, 
   {{0xa8c4036b,0x6d940064,0xe2980022,0x00000000}},	//   _уйид, _išas, ҳаз_, --, 
   {{0xa3e02208,0x69c400ad,0x6d587fc9,0xdc24008e}},	// [9a20] नूं_, _çheb, _mmwa, _möğa, 
   {{0x29107fca,0xe2987fcb,0xd24c034c,0xe6447fcc}},	//   _haya_, газ_, کنم_, _геоп, 
   {{0x29107fcd,0xf1a87fce,0x6d580c8a,0x6d8401d3}},	//   _kaya_, لانه_, _omwa, tóal, 
   {{0x6d587fcf,0x7c2401e7,0xda78010f,0xc0e80023}},	//   _nmwa, _áirg, אנער, _መዓላ_, 
   {{0x8ff40491,0xdef8748c,0x69d4012c,0x00000000}},	//   مرور_, гый_, ázej, --, 
   {{0x6d587fd0,0x29107fd1,0xf67400d1,0x8504009f}},	//   _amwa, _laya_, ﺸﯩﮕﻪ_, _اوڏن, 
   {{0x88e002a6,0x6d5802d0,0x5f880014,0x91e001a9}},	//   য্যক, _bmwa, نٕچہ_, _норе, 
   {{0x29107fd2,0x6d580857,0x49184da4,0x7d1c00e2}},	//   _naya_, _cmwa, _बोलो_, ērso, 
   {{0x313001d9,0x6d58035a,0x00000000,0x00000000}},	//   _تہنز, _dmwa, --, --, 
   {{0x29107fd3,0x6d5808e7,0xd7f84fd6,0x09ac00fe}},	//   _aaya_, _emwa, қум_, _কিজা, 
   {{0x29107fd4,0x7c2402d5,0x6d58035a,0x6d940010}},	//   _baya_, _šird, _fmwa, _pšat, 
   {{0x29100ac5,0x6d58035a,0x25a00bb3,0xa3c801f9}},	//   _caya_, _gmwa, _nikl_, ोळा_, 
   {{0x29104437,0x25e400c5,0xd6d800d8,0x00000000}},	//   _daya_, जूसी_, лтв_, --, 
   {{0x6d5802d0,0x2bdc7fd5,0x00000000,0x00000000}},	//   _zmwa, _मिता, --, --, 
   {{0x6d947fd6,0x29107fd7,0x6d580368,0x00000000}},	//   _tšat, _faya_, _ymwa, --, 
   {{0x29107fd8,0x7c2400a3,0x6d5802d0,0x142800d4}},	//   _gaya_, _àirs, _xmwa, лізо_, 
   {{0x39480280,0x2d80013f,0x7c2401e7,0xd7f833be}},	// [9a30] _ilas_, _ɔhe_, _áird, _суй_, 
   {{0x39487fd9,0x69c400ad,0xd7740150,0x3d100073}},	//   _hlas_, _çhec, _داعع, _दोघे_, 
   {{0x39487fda,0x29107fdb,0x51847fdc,0x66ec25c9}},	//   _klas_, _yaya_, буда, _जातक_, 
   {{0x0ce00eac,0x81a40124,0x29101898,0x55c001af}},	//   _মস্ত, _ẽtép, _xaya_, _мәғз, 
   {{0xb4e41b57,0x6d587fdd,0x6618003b,0x7d1c00e2}},	//   नली_, _rmwa, åtkv, ērsl, 
   {{0x439400a7,0x6d5803ac,0xc1e401d3,0x00000000}},	//   _наяс, _smwa, تےہی, --, 
   {{0x6d580c8c,0x39487fde,0xe1ec00ec,0x5194010a}},	//   _pmwa, _olas_, _لڳن_, _лăка, 
   {{0x6d940024,0x3fc80014,0x8d240131,0x00000000}},	//   _ašar, _گدٲی_, сниң_, --, 
   {{0x6d587fdf,0xcee87fe0,0xaed40276,0x705821cb}},	//   _vmwa, _مران_, _моаш, _таар_, 
   {{0x29107020,0x39487fe1,0x9b907fe2,0x0dc87fe3}},	//   _saya_, _alas_, وليت, _буди_, 
   {{0x29107fe4,0xdc240139,0x98b001ef,0x00000000}},	//   _paya_, _töğa, _úděl_, --, 
   {{0x7c245166,0x6d58633d,0x78a808ad,0x39487fe5}},	//   _šire, _umwa, ževn, _clas_, 
   {{0x29107fe6,0x9d7400db,0xab280354,0x00000000}},	//   _vaya_, _بئلچ, _вола_, --, 
   {{0x39487fe7,0xe5a403fb,0x25a0022e,0xaa447fe8}},	//   _elas_, живи, _sikl_, _мелл, 
   {{0x29107fe9,0x39487fea,0xe69401b9,0xb4e400c5}},	//   _taya_, _flas_, زلرد, नलू_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x5ec8015b,0x93c80583,0xe2c800d4,0x00000000}},	// [9a40] _রাসে, لالہ_, илад_, --, 
   {{0x7c240597,0xc3302002,0x27e0037e,0x62643f0f}},	//   _áire, رەز_, mrkn_, овза, 
   {{0x64a47feb,0x316c01fa,0x7dd001e7,0x00000000}},	//   _мана, _bjez_, _mósá, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x25e40034,0xa0686ef4,0x6b4c032e,0x00000000}},	//   जूरी_, шада_, _gúgg, --, 
   {{0xfe780228,0x661c0311,0x5ec800eb,0x00000000}},	//   бүз_, _krpk, _রাহে, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x910007b5,0xae700131,0xbebc00b8,0x21687fec}},	//   _опсе, رۇنغ, _gnīn, _тиби_, 
   {{0x60c07fed,0xddcc033f,0xdb680f06,0x26d801ef}},	//   mbom, ódło, ирол_, _odpo_, 
   {{0xba541614,0x60c07fee,0x9a84036b,0xdee401b9}},	//   звој, lbom, жумл, _фожи, 
   {{0x39487fef,0xa3c80073,0x8f98011a,0x670c07f7}},	//   _plas_, ळीत_, _כימי, ाजनक_, 
   {{0x60c07ff0,0x81bc045e,0x00000000,0x00000000}},	//   nbom, _ইটা_, --, --, 
   {{0xd7f87ff1,0x817c0023,0x78a80841,0x6db000ef}},	//   шун_, _ክኣትዉ_, ževo, _jāan, 
   {{0x628c00a4,0x60c0002f,0xd7c401f0,0x8b2000d8}},	//   _ozbo, hbom, йёҳо, _одче, 
   {{0x39480032,0x661c63e0,0x26d87ff2,0x60c00fac}},	//   _tlas_, _crpk, _ddpo_, kbom, 
   {{0xb4e47ff3,0x39487ff4,0x6aac0dde,0x00000000}},	//   नले_, _ulas_, _ğafi, --, 
   {{0x25b80175,0x628c7ff5,0xb4b40032,0x60c001e4}},	// [9a50] _etpl_, _azbo, жиғә, dbom, 
   {{0x2bdc03f8,0x60c0017a,0x82f800f2,0xdc3c01ef}},	//   _मिसा, ebom, قرمز_, jíčc, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdd847ff6,0x60c07ff7,0x6da40022,0x00000000}},	//   _سو_, gbom, ҿика, --, 
   {{0x6b4c067c,0x628c0165,0xd1b87ff8,0x20d000db}},	//   _húge, _ezbo, _چارا_, رقوس, 
   {{0xd1b87ff9,0x6da47ffa,0x6b4c00d2,0x60c00083}},	//   _نارا_, пика, _kúge, abom, 
   {{0x16fc03bd,0x5ec8015b,0xf41c03d4,0x41d800bc}},	//   _ཞིནམ_, _রাশে, _নথিৰ_, _डिएस, 
   {{0xf3f8031c,0xf8b40073,0x00000000,0x00000000}},	//   _ཕྱོད_, ंडोप, --, --, 
   {{0xdd8c7ffb,0x00000000,0x00000000,0x00000000}},	//   دوي_, --, --, --, 
   {{0x78a800f3,0x7c240427,0x00000000,0x00000000}},	//   ževl, _širc, --, --, 
   {{0xdd8c179e,0x00000000,0x00000000,0x00000000}},	//   ضوی_, --, --, --, 
   {{0xa9687ffc,0xbe640592,0x3a380267,0x6b4c0162}},	//   сима_, _تهمي, ärpa_, _súgd, 
   {{0x661c38bb,0xcc0845cf,0x00000000,0x00000000}},	//   _srpk, _خزان_, --, --, 
   {{0xe6c40037,0xdc9800df,0x00000000,0x00000000}},	//   वरेज, _פיסל, --, --, 
   {{0x65c406bb,0x60c00024,0x26d80139,0x00000000}},	//   ябва, ybom, _vdpo_, --, 
   {{0xbebc0055,0x60c002f0,0xe8c801a9,0x00000000}},	//   _anīl, xbom, _угил_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [9a60] --, --, --, --, 
   {{0x62980122,0x59c007d0,0x661c02f0,0x00000000}},	//   _útok, वीकर, _trpk, --, 
   {{0xa5087ffd,0x236407f5,0x6b4c01e1,0xe57800f3}},	//   _лена_, đoj_, _kúgb, _гзн_, 
   {{0xfaf800e2,0x60c07ffe,0x628c01ef,0x00000000}},	//   lnīt_, ubom, _vzbo, --, 
   {{0x98a4071b,0x628c033f,0x39581e4c,0x00000000}},	//   šića_, _wzbo, èrsi_, --, 
   {{0x60c07fff,0x6b4c01e1,0x10a00395,0x00000000}},	//   sbom, _lúgb, хичн, --, 
   {{0x628c0432,0xf40403d4,0x7d7806c2,0x00000000}},	//   _uzbo, ৰমণৰ_, يمتر_, --, 
   {{0x9cb00e26,0xe7bc28b8,0x2bdc01ad,0x00000000}},	//   رۅتت, ्ठाप, _मिशा, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xff24034c,0xe6c412eb,0x2b5400f2,0x3f980ca8}},	//   _تبری, वरोज, ویند_, _òru_, 
   {{0xed340451,0x9a24007b,0x09e000d8,0x00000000}},	//   _ڪونھ, سعدن, ноќн, --, 
   {{0xd83801c6,0x00000000,0x00000000,0x00000000}},	//   бэг_, --, --, --, 
   {{0x69c40731,0x00000000,0x00000000,0x00000000}},	//   _çhen, --, --, --, 
   {{0x7bc00ffb,0xc60400cc,0x1d840244,0x00000000}},	//   mpmu, _উপজা_, _بدڕێ, --, 
   {{0x8af8025f,0xa3c80073,0xa2d000cc,0x00000000}},	//   _להגי, ळीस_, ালাও, --, 
   {{0x2bd000bc,0x25fc02db,0x00000000,0x00000000}},	//   _दौडा, _लहरी_, --, --, 
   {{0x73383db7,0xa5c000e4,0x00000000,0x00000000}},	// [9a70] озар_, ñóra, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x5184004e,0x00000000,0x00000000,0x00000000}},	//   пуда, --, --, --, 
   {{0x6b4c0af2,0xf0e83baf,0x2bdc0263,0x26082982}},	//   _kúgc, زىتى_, _मिला, ाबरी_, 
   {{0x80d40137,0x64900241,0x948401ee,0x00000000}},	//   رموچ, _ọmọ́, _хынд, --, 
   {{0xdb0004cf,0xa3e005d7,0x00000000,0x00000000}},	//   _otoñ, _धित_, --, --, 
   {{0xed580aec,0x9f4403bd,0x7f84004e,0x7c24025c}},	//   жой_, ntoù_, jòqu, _ġira, 
   {{0x7c243421,0x7de40d1f,0x78a80427,0x71240136}},	//   _šira, رسىم, ževj, _تىرم, 
   {{0x2bdc05ba,0x2ef48000,0x6db00421,0x96bc2c30}},	//   _मिळा, _озар, _tāao, ्राउ, 
   {{0xe9d84afa,0xaa44036b,0x9f4405c7,0x25fc0037}},	//   око_, деол, ktoù_, _लहली_, 
   {{0x7bc001f5,0xdb000208,0x00000000,0x00000000}},	//   apmu, _quoá, --, --, 
   {{0xe6c40882,0x6aac013d,0x00000000,0x00000000}},	//   वर्ज, _ğafu, --, --, 
   {{0x8804004b,0xef800023,0x00000000,0x00000000}},	//   رېدو, _ክሃድሙ_, --, --, 
   {{0xab2803f6,0xaa4801af,0x00000000,0x00000000}},	//   _фока_, _мпла_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x198406bb,0x6f000175,0x24840135,0x00000000}},	//   _общи_, _lblc, żomm_, --, 
   {{0x69c08001,0x39580200,0x00000000,0x00000000}},	// [9a80] lple, ërse_, --, --, 
   {{0x69c0005c,0x178000c7,0x00000000,0x00000000}},	//   ople, _игым, --, --, 
   {{0x69c060d7,0xe4c47075,0x00000000,0x00000000}},	//   nple, _ойни, --, --, 
   {{0x9c800308,0x69c08002,0xa878010f,0x59c000bc}},	//   íčko, iple, ֿאַר, वीटर, 
   {{0xa03400cf,0xf4840024,0x00000000,0x00000000}},	//   بىشت, _зуён, --, --, 
   {{0x69c02b92,0xf3f8031c,0x670c17ee,0xefbc0092}},	//   kple, _ཕྱིད_, ाजिक_, ደሪያ_, 
   {{0x53a42ecf,0x69c077ad,0x4dd00592,0x77680129}},	//   _कूटश, jple, نتيس, éexi, 
   {{0x69c08003,0xa2c48004,0x4fe40131,0x999c00c7}},	//   dple, िरक्, чмән_, pytũ_, 
   {{0xa2a08005,0x69c08006,0x64540083,0xa0a4009d}},	//   _कृत्, eple, nzyi, _цаад, 
   {{0x69c0017a,0xe82066c0,0x7bc001e4,0xa3d4000d}},	//   fple, मिना_, rpmu, _सबन_, 
   {{0x69c08007,0x69c41368,0x0c7001d5,0xcf90010f}},	//   gple, _çhel, فدید, _סטע_, 
   {{0x1c448008,0x6aac4dd9,0x7bc00254,0x00000000}},	//   _онем, _şaft, ppmu, --, 
   {{0xd83801c6,0x00000000,0x00000000,0x00000000}},	//   цэн_, --, --, --, 
   {{0x64540099,0x0b400798,0x00000000,0x00000000}},	//   dzyi, _инчн, --, --, 
   {{0xd9f04614,0xbebc00cd,0xdb4c03e6,0xdc3c013a}},	//   _अमित_, _anīk, _مێک_, _míčo, 
   {{0x9f440489,0x1888009b,0x00000000,0x00000000}},	//   rtoù_, _мспп_, --, --, 
   {{0x9f440489,0x78ac00af,0xa3c801f9,0x00000000}},	// [9a90] stoù_, _igav, ळील_, --, 
   {{0x8c180375,0x6b4c8009,0x9f44030a,0x92640326}},	//   חומי, _kúga, ptoù_, ودام, 
   {{0xa6e003f2,0xada0032e,0x00000000,0x00000000}},	//   _óðal, _þúge, --, --, 
   {{0x714000db,0x90840240,0xa698011a,0x00000000}},	//   دۉرۅ, _ንሓይሊ_, _משתפ, --, 
   {{0x6b4c7978,0x69c00427,0x7c240427,0xe820098a}},	//   _lúga, zple, _širn, मिया_, 
   {{0x69c0800a,0x799c2ad7,0x291c4974,0x753c00e5}},	//   yple, hmsw, ētai_, _hosz, 
   {{0x753c800b,0xb64004ce,0x6b4c0162,0x69c0800c}},	//   _kosz, _ｃｓ_, _núga, xple, 
   {{0x78ac800d,0x69c001e4,0xe8200b98,0xdb0001a8}},	//   _ngav, vple, मिमा_, _stoð, 
   {{0x753c800e,0xebc40022,0x00000000,0x00000000}},	//   _mosz, хӡеи, --, --, 
   {{0x69c0800f,0x753c0112,0xfeb80346,0x6b4c02d2}},	//   tple, _losz, _قامت_, _búga, 
   {{0x2fcc0165,0x6e200175,0x69c08010,0x7c248011}},	//   _hweg_, _urlb, uple, _áirn, 
   {{0x4abc146b,0x753c1790,0x69c40363,0x6c740107}},	//   _श्रव, _nosz, _çhem, _пулх, 
   {{0x69c08012,0x291c0316,0x6d48000f,0x00000000}},	//   sple, ěta_, mkea, --, 
   {{0x78ac0472,0x6d480c4e,0x69c00c30,0x799c29d0}},	//   _egav, lkea, pple, amsw, 
   {{0xd6240276,0x6b8001d5,0x64540369,0x7afc067c}},	//   норе_, molg, wzyi, òrte, 
   {{0x6d488013,0xe3b88014,0x6d84030a,0x6b800946}},	//   nkea, зба_, cóat, lolg, 
   {{0x753c0034,0xa2a0190c,0x27e417ba,0x6d488015}},	// [9aa0] _dosz, केन्, _íon_, ikea, 
   {{0x6d4833eb,0x64a4010b,0x78ac036e,0xe290007b}},	//   hkea, _җага, _zgav, هذا_, 
   {{0x6d488016,0x61448017,0xf1d40cab,0x753c01d3}},	//   kkea, нежа, көтө, _fosz, 
   {{0x753c8018,0x673c0455,0x6b808019,0x00000000}},	//   _gosz, _hopj, holg, --, 
   {{0x14d4025f,0x673c801a,0xe044801b,0x6d48045f}},	//   _אוכל_, _kopj, энди, dkea, 
   {{0x7c24801c,0x44203090,0x8fa05e8c,0x6b800ffb}},	//   _širo, mvi_, гаче, jolg, 
   {{0x2fcc0221,0x673c01f5,0x6b806ec5,0xdfd0004b}},	//   _eweg_, _mopj, dolg, _څير_, 
   {{0x78a80989,0xdfd000b2,0x44203110,0x39ac00bc}},	//   ževi, _مير_, ovi_, _měst_, 
   {{0x6b80801d,0x4420801e,0x6b4c801f,0xcd3038eb}},	//   folg, nvi_, _súga, ارىب, 
   {{0x6b808020,0x673c01f5,0x6d48017a,0x6aac8021}},	//   golg, _nopj, akea, _şafr, 
   {{0x44208022,0x00000000,0x00000000,0x00000000}},	//   hvi_, --, --, --, 
   {{0x442005ce,0x6d488023,0xdbe08024,0x00000000}},	//   kvi_, ckea, _léég, --, 
   {{0x673c01ee,0xb6c40228,0x6b808025,0x753c8026}},	//   _bopj, көнд, bolg, _rosz, 
   {{0x44204255,0x6b800395,0xd5b88027,0x9f44017a}},	//   dvi_, colg, зса_, droë_, 
   {{0x753c3ec0,0x44208028,0x78ac0c86,0x673c8029}},	//   _posz, evi_, _tgav, _dopj, 
   {{0x78ac7ab0,0x23b402d2,0x44200010,0x00000000}},	//   _ugav, _bæj_, fvi_, --, 
   {{0x97a403a6,0x442008a7,0xc2140150,0x37c400d1}},	// [9ab0] _прол, gvi_, _ءﺟﯘﺯ, _шәнб, 
   {{0x35b416c3,0x673c00a2,0x6d48005a,0x00000000}},	//   _ибор, _gopj, zkea, --, 
   {{0x4420802a,0x16bc802b,0x6d4803cd,0xf5980108}},	//   avi_, ्रीब, ykea, _овощ_, 
   {{0x6b8001ed,0x4420006f,0x518400c6,0x91841291}},	//   zolg, bvi_, رشاق, رجام, 
   {{0xdbe001e1,0x44200393,0x12e400d4,0x6b804d2f}},	//   _féég, cvi_, _півг, yolg, 
   {{0xe82007b7,0x6d840162,0x00000000,0x00000000}},	//   मिता_, jóar, --, --, 
   {{0x6b80802c,0x7ed404fb,0x5ec8015b,0x6d4841a2}},	//   volg, ازها, _রাখে, tkea, 
   {{0x23c40014,0x6b80002d,0x6db000e2,0xac980116}},	//   _سٕہہ, wolg, _jāai, ونغا_, 
   {{0x6d48802d,0xeb98802e,0x6b80802f,0xec78010a}},	//   rkea, мии_, tolg, ьпи_, 
   {{0x6d488030,0xf1a800f1,0x40840064,0x00000000}},	//   skea, _راځه_, _сусб, --, 
   {{0x2bd009fd,0x442005b8,0x490401c0,0x2bdc0764}},	//   _दौरा, zvi_, гүйг, _मिका, 
   {{0x44208031,0x6b808032,0x673c0477,0xda600395}},	//   yvi_, solg, _sopj, рвюи, 
   {{0x3958069c,0x2d8c8033,0x44200381,0x673c01f5}},	//   ërsa_, mlee_, xvi_, _popj, 
   {{0x2d8c8034,0x44202b1d,0x9c10063f,0x6a848035}},	//   llee_, vvi_, _kọnf, _илла, 
   {{0x2d8c0a55,0xe72c0139,0x966000f3,0x78000150}},	//   olee_, _kiеz_, акре, _қүра, 
   {{0x44208036,0xa2a0590f,0x6b4c0af2,0x2d8c0363}},	//   tvi_, _कृष्, _kúgo, nlee_, 
   {{0xd4646145,0x2d8c8037,0x673c8038,0xe7380eff}},	// [9ac0] вите_, ilee_, _topj, _жеп_, 
   {{0x44208039,0x2d8c803a,0x87980014,0x232800d4}},	//   rvi_, hlee_, _سێزر_, ьози_, 
   {{0x2d8c803b,0x29003284,0x221408ca,0x80e8104e}},	//   klee_, ofka_, ъфар, егең_, 
   {{0x91e0035b,0x80cc06ab,0xa2c400dc,0x1be0000d}},	//   роце, ारें, िरङ्, _खिलल_, 
   {{0xf1a8803c,0x10100137,0x2d8c0363,0x29000009}},	//   رامه_, لبود, dlee_, ifka_, 
   {{0xd00c803d,0x9e04803e,0x2d8c803f,0x6ed800d1}},	//   تله_, вчил, elee_, ىدىڭ_, 
   {{0x21688040,0x399800dd,0xa3b4068f,0x15040c58}},	//   _живи_, lése_, _चूत_, ৱাৰী_, 
   {{0xa3d405d7,0x2d8c8041,0xa1141411,0x2bdc01ad}},	//   _सबा_, glee_, _جورت, _मिखा, 
   {{0x61fc6eb8,0x399801d3,0x10a040c5,0x8bd00006}},	//   ltpl, nése_, _витн, ажыц, 
   {{0x7b1805f5,0x9b248042,0x2d8c0a55,0x9a50002b}},	//   хоор_, тфил, alee_, _atāḍ, 
   {{0x61fc8043,0x2d8c0072,0xd8c801ec,0x00000000}},	//   ntpl, blee_, _ﺒﻘﻭﻟ, --, 
   {{0xdcb004a9,0x61fc28dc,0x00000000,0x00000000}},	//   _ئىش_, itpl, --, --, 
   {{0xc8648044,0x61fc7154,0x00000000,0x00000000}},	//   атри, htpl, --, --, 
   {{0x399801ed,0x29000067,0x00000000,0x00000000}},	//   dése_, afka_, --, --, 
   {{0x7a080134,0x98c414b7,0x64580393,0x4b34011a}},	//   _bɛte, _испл, _ętia, _ברגל_, 
   {{0x05740a2c,0x61fc03fa,0x7c24025c,0xd8440024}},	//   لاقد, dtpl, _ġirj, _ахоп, 
   {{0x7c240219,0x44b40415,0x1b340023,0x33740354}},	// [9ad0] _širj, рбус, _ኤረትራ, ггар, 
   {{0x2d8c05b1,0x8144036b,0x4498023a,0x00000000}},	//   zlee_, ینلن, твую_, --, 
   {{0x2d8c8045,0x61fc005c,0x00000000,0x00000000}},	//   ylee_, gtpl, --, --, 
   {{0x2d8c3d20,0x00000000,0x00000000,0x00000000}},	//   xlee_, --, --, --, 
   {{0xb4c04c21,0x5ec800eb,0x00000000,0x00000000}},	//   ुरी_, _রাজে, --, --, 
   {{0x2d8c002e,0x00000000,0x00000000,0x00000000}},	//   wlee_, --, --, --, 
   {{0x81d48046,0x61fc8047,0x6b4c0162,0x2d8c8048}},	//   _восх, ctpl, _dúgl, tlee_, 
   {{0x2ee803be,0x8d2404a9,0x2d8c198f,0xdcf827ac}},	//   şaf_, тниң_, ulee_, _butı, 
   {{0x2d8c8049,0x00000000,0x00000000,0x00000000}},	//   rlee_, --, --, --, 
   {{0x2d8c062c,0x9ba015c3,0x16bc1152,0x6b4c02d2}},	//   slee_, مەنى, ्रोब, _gúgl, 
   {{0x399800dd,0xc7b4013f,0x2d8c039a,0xa96855cc}},	//   zése_, _suɑ_, plee_, еина_, 
   {{0x2d8c0009,0x2900058a,0x15a400d1,0x00000000}},	//   qlee_, ufka_, _ﺋﺎﻻﮬ, --, 
   {{0x2bdc0c2e,0xbf700124,0xfc3002f2,0x8c3401f0}},	//   _मिटा, _ықәы, _وحه_, _шодӣ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa508804a,0x7a08013f,0x49040447,0x9af000db}},	//   нева_, _pɛte, _күнг, _اكىت, 
   {{0x291c0029,0x3998066d,0x6a84804b,0x29d05106}},	//   ētas_, tése_, _илһа, mša_, 
   {{0x7d040641,0x29d03493,0xb8643cc6,0x00000000}},	// [9ae0] _öise, lša_, _پايو, --, 
   {{0x7c24804c,0x61fc0250,0x3998804d,0x00000000}},	//   _širk, ttpl, rése_, --, 
   {{0xdb08804e,0x29d00f03,0xe29801c0,0x60e8804f}},	//   _difè, nša_, хаж_, емем_, 
   {{0x6db00171,0x29d0139f,0x399800e5,0x00000000}},	//   _jāau, iša_, pése_, --, 
   {{0x65642784,0xe3b08050,0x40348051,0x61fc8052}},	//   _imkh, _درج_, релс, stpl, 
   {{0x9c10063f,0x61fc02c1,0xd54001e1,0xb3542099}},	//   _dọlf, ptpl, _ké̟n, _پیما_, 
   {{0x29d01edd,0x63ac0472,0xdda81a92,0xdcf80166}},	//   jša_, _iibn, нтил_, _sutı, 
   {{0x645803e3,0x00000000,0x00000000,0x00000000}},	//   _ətin, --, --, --, 
   {{0x9c1002e3,0x9b6856e2,0x628c0165,0x3b546a7c}},	//   _gọlf, ешна_, _hybo, икир, 
   {{0x93f805e1,0x307409a5,0xd24c01d9,0x63ac0003}},	//   עליי, _тусс, _بنہ_, _jibn, 
   {{0x65648053,0x628c01b8,0xa3b405f9,0x63ac0003}},	//   _omkh, _jybo, _चूस_, _mibn, 
   {{0x63ac0100,0x628c00b5,0xdcf800fd,0xfcc401af}},	//   _libn, _mybo, _tutı, _тәкм, 
   {{0x37c401e0,0x00000000,0x00000000,0x00000000}},	//   шәйб, --, --, --, 
   {{0x656453ff,0xbb500ed1,0x29d009a8,0x63ac0135}},	//   _amkh, ﺎﺭﻯ_, bša_, _nibn, 
   {{0x628c11c0,0x9f44030a,0x00000000,0x00000000}},	//   _nybo, ntoñ_, --, --, 
   {{0xb4c08054,0x63ac05b1,0x6804016b,0xf8d800ab}},	//   ुरे_, _aibn, _wɔda, _भजिय, 
   {{0x4aa48055,0x628c02d0,0xdb0800ae,0xd3246135}},	// [9af0] _икән_, _aybo, _aifé, льжи, 
   {{0x65648056,0x2b981e4f,0x628c01e3,0x95c88057}},	//   _emkh, pèce_, _bybo, _пума_, 
   {{0x63ac01d9,0x6db0005f,0xc2c400c6,0x00000000}},	//   _dibn, _jāat, صيني, --, 
   {{0xdb08003e,0xdd8400c6,0x47b80154,0x6b4c02d2}},	//   _difé, _ذو_, _অবতী, _rúgm, 
   {{0x628c8058,0x20000139,0x00000000,0x00000000}},	//   _eybo, _äkil_, --, --, 
   {{0xd3440066,0xbf00024a,0x00000000,0x00000000}},	//   _حیطه_, ल्लभ_, --, --, 
   {{0xe28c01b9,0xbebc00ef,0x00000000,0x00000000}},	//   lgаn_, _anīs, --, --, 
   {{0x29d007f5,0x63ac009a,0xf19000d1,0xe1ec009f}},	//   vša_, _zibn, ﯘﺭﻏﯘ, _آڳل_, 
   {{0x1c402b41,0x32008059,0xe28c01d5,0x00000000}},	//   жным, lthy_, ngаn_, --, 
   {{0x29d05723,0x3200805a,0xab64130f,0x63ac058a}},	//   tša_, othy_, рвол, _xibn, 
   {{0x5efc068f,0x29d0805b,0x6dc00137,0xe28c01a9}},	//   _शॉट्_, uša_, _بۅبۅ, hgаn_, 
   {{0xfe70805c,0xa968805d,0x29d07710,0xe8201b77}},	//   _عدل_, тима_, rša_, मिला_, 
   {{0x385402e8,0xb4c009b2,0x00000000,0x00000000}},	//   бърс, ुरै_, --, --, 
   {{0x29d00f8b,0xcfd402a6,0x442c805e,0xfbd003e6}},	//   pša_, _সমান, _čd_, _رته_, 
   {{0x63ac0219,0x2d9c0165,0x7c240135,0x29d401a9}},	//   _ribn, _khwe_, _ġiri, _тўлс, 
   {{0x2c08068f,0x63ac805f,0x628c05d6,0xda78011a}},	//   _वहां_, _sibn, _rybo, _שנקר, 
   {{0x66e4355b,0x628c8060,0x9420117e,0x00000000}},	// [9b00] _копа, _sybo, омте, --, 
   {{0x63ac0548,0xa2e4034b,0xe64800c7,0xca6001a9}},	//   _qibn, рожд, _апод_, _yanа, 
   {{0x6db00421,0x63ac0218,0xa3b48061,0x00000000}},	//   _māas, _vibn, _चूर_, --, 
   {{0x65648062,0x2d9c013f,0x628c0122,0x69c41368}},	//   _umkh, _nhwe_, _vybo, _çheu, 
   {{0x628c8063,0x44248064,0x63ac8065,0x657401e2}},	//   _wybo, _ém_, _tibn, mnyh, 
   {{0x7c240597,0x2d9c016b,0xbebc00b8,0x65740728}},	//   _áiri, _ahwe_, _anīr, lnyh, 
   {{0x91e08066,0x39980066,0x628c014f,0x6574005b}},	//   _море, hésa_, _uybo, onyh, 
   {{0x2d9c0368,0x65748067,0x6b4c0332,0x9f440165}},	//   _chwe_, nnyh, _húgh, rtoñ_, 
   {{0x2d9c020c,0xa3c80490,0x1fa80107,0x89d401d9}},	//   _dhwe_, ळीच_, _акаи_, یوٝر_, 
   {{0x3b540a70,0x2d9c013f,0xd00c0597,0xda2402bf}},	//   скор, _ehwe_, _تلك_, аємо, 
   {{0x7a08013f,0xf8b88068,0xd2b4011a,0x6574007c}},	//   _bɛta, лөп_, ילית_, knyh, 
   {{0xed58012c,0xb4d4032c,0x1be800d1,0xec680150}},	//   chž_, _सजे_, _адди_, _өрік_, 
   {{0xdca48069,0x6574369d,0x6ad400eb,0x00000000}},	//   _тади, dnyh, _দারো, --, 
   {{0xb4c0228a,0xccd00022,0xcb6400f3,0xda64806a}},	//   ुर्_, _лцәы, _каче_, _پاتي, 
   {{0xf9c4806b,0xcb0400db,0xd5640064,0x00000000}},	//   _احتی, _ئيىن_, атап, --, 
   {{0xb2740032,0x657401bf,0xe28c01d5,0x00000000}},	//   ҡлаш, gnyh, tgаn_, --, 
   {{0x798c806c,0x6578806d,0xe7ec0c2e,0x962400da}},	// [9b10] _ikaw, étha, _जिया_, _saņē, 
   {{0x798c0113,0x962400e2,0xfaf80374,0xe28c01a9}},	//   _hkaw, _paņē, ngī_, rgаn_, 
   {{0x32000204,0x877c008f,0xaa8400ee,0x798c0135}},	//   uthy_, _באזי, meýä, _kkaw, 
   {{0xaa8409a5,0xee380184,0x65740212,0xd58403e6}},	//   leýä, ғни_, cnyh, _ئێره_, 
   {{0xba081b49,0x798c806e,0xc1040f2b,0x00000000}},	//   _ገጹ_, _mkaw, توني, --, 
   {{0x2d9c806f,0xd2440209,0x4394010b,0x83840024}},	//   _shwe_, _кэби, _маяс, _дысе, 
   {{0x798c8070,0xdce00306,0x5194010a,0x645806be}},	//   _okaw, _emoč, _кăка, _ətim, 
   {{0x798c8071,0x9f440008,0x00000000,0x00000000}},	//   _nkaw, stoð_, --, --, 
   {{0x7ff4282b,0xe8f801e0,0x00000000,0x00000000}},	//   _وسكا, ңло_, --, --, 
   {{0x798c8072,0x6b4c00d2,0x00000000,0x00000000}},	//   _akaw, _kúgi, --, --, 
   {{0x6e948073,0x2d9c00fb,0xdce00427,0x76400108}},	//   _الاا, _thwe_, _zmoč, älyl, 
   {{0x2d9c0810,0x00000000,0x00000000,0x00000000}},	//   _uhwe_, --, --, --, 
   {{0x798c020c,0x7c240024,0x3078010f,0xbebc0171}},	//   _dkaw, _širv, ראָנ, _knīp, 
   {{0x798c0428,0x6804016b,0xa098010f,0xfbd08074}},	//   _ekaw, _wɔdo, טירט, _آتن_, 
   {{0xe9d80517,0x39988075,0x6b4c08a5,0xa9a401d5}},	//   _ёки_, sésa_, _núgi, _ликд, 
   {{0xe8f82bbd,0x00000000,0x00000000,0x00000000}},	//   _сли_, --, --, --, 
   {{0x29c80943,0x65741506,0xb90800db,0xe7301291}},	// [9b20] _ṱahe_, rnyh, _ئزىم_, _فصد_, 
   {{0x65748076,0x69c41368,0xb9f40092,0x00000000}},	//   snyh, _çhes, _ሞቶ_, --, 
   {{0x26d806c8,0xd12c29f2,0xdce0107d,0x6574005c}},	//   _iepo_, کمن_, _smoč, pnyh, 
   {{0xbebc0055,0x24f401ce,0x9fe4007b,0x75c4110e}},	//   _anīp, _учор, مسته, _únfẹ, 
   {{0x26d86489,0x347401ee,0xf484014b,0x00000000}},	//   _kepo_, _дѳрѳ, _дуён, --, 
   {{0xe2a88077,0x26d801e1,0xfe706e92,0x80d4000d}},	//   _مازن_, _jepo_, وگا_, _ढ़के, 
   {{0xdee43461,0x00000000,0x00000000,0x00000000}},	//   _ҳози, --, --, --, 
   {{0x26d88078,0xba000882,0x2b98067c,0x1b1000eb}},	//   _lepo_, māḥ_, vèca_, ়াছে_, 
   {{0xdc28177a,0xba000882,0xc2140046,0xdce007f5}},	//   اسبه_, lāḥ_, _ءﺗﯘﺯ, _umoč, 
   {{0xd00c8079,0x26d8807a,0x60c0807b,0xb4d41fe5}},	//   _سلم_, _nepo_, lcom, _सज्_, 
   {{0xba000882,0x60c0011c,0x798c003e,0x00000000}},	//   nāḥ_, ocom, _pkaw, --, 
   {{0xd7f82405,0xdc2804d3,0xad2400f7,0x6c6801d3}},	//   луг_, _مسته_, _ورنو, الیہ_, 
   {{0x58844478,0xba000882,0x661c01e4,0x26d801a6}},	//   сына, hāḥ_, _aspk, _bepo_, 
   {{0xba000a28,0x26d83d62,0xf9d4010b,0x25b801bf}},	//   kāḥ_, _cepo_, _докэ, _bupl_, 
   {{0x26d8807c,0xba000882,0x60c001f5,0xef1000df}},	//   _depo_, jāḥ_, kcom, וּן_, 
   {{0x798c807d,0x9484807e,0x26d80248,0x6aac01e4}},	//   _ukaw, бызд, _eepo_, _ŝafg, 
   {{0xb4b81533,0x60c0030d,0x661c05b1,0x26d8807f}},	// [9b30] _चली_, dcom, _espk, _fepo_, 
   {{0x60c001f5,0xd2587858,0x6b4c0789,0x00000000}},	//   ecom, лце_, _púgi, --, 
   {{0x60c00204,0x00000000,0x00000000,0x00000000}},	//   fcom, --, --, --, 
   {{0x60c08080,0x70540f1b,0x26d8005a,0x8e7401e0}},	//   gcom, يناا, _zepo_, ҡҡас_, 
   {{0xded00020,0x69d401d3,0xd3240108,0xafe4009d}},	//   ረጉን_, ázez, _льви, цолл, 
   {{0x60c00ffb,0x6b4c0174,0x42540014,0xb4b80037}},	//   acom, _húgv, _کنِر, _चलु_, 
   {{0xf1d402ab,0x60c08081,0x6b4c0162,0xba0000b8}},	//   डीशन, bcom, _kúgv, cāḥ_, 
   {{0x60c08082,0xbebc00b8,0x00000000,0x00000000}},	//   ccom, _paīc, --, --, 
   {{0xdcac021a,0x7a08013f,0x6b4c03b2,0xdd8c2dd0}},	//   نډه_, _bɛto, _múgv, خوي_, 
   {{0x6b4c0174,0x7e6401e4,0x92b800fe,0x00000000}},	//   _lúgv, ŝipa, ঘৰৰ_, --, 
   {{0xdf840014,0xb4b80037,0xa9a48083,0xf1b800bc}},	//   _بُلی, _चलू_, жинд, इदिन, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x26d88084,0x6d588085,0x393401c6,0x385402e8}},	//   _pepo_, _ilwa, чээс, пърс, 
   {{0xba000a28,0x6d580184,0x60c03efd,0x00000000}},	//   yāḥ_, _hlwa, zcom, --, 
   {{0x6b4c0579,0x6d588086,0x65782056,0x65c40395}},	//   _búgv, _klwa, étho, юбва, 
   {{0xba000882,0x26d80099,0x9f440077,0x24c88087}},	//   vāḥ_, _wepo_, iroá_, ргап_, 
   {{0x26d8020c,0x6b4c0174,0xaf94001f,0x6d58127b}},	// [9b40] _tepo_, _dúgv, ግሥትና_, _mlwa, 
   {{0x60c08088,0xba001161,0xe298497c,0x2b580a40}},	//   wcom, tāḥ_, ааз_, ësch_, 
   {{0xe82012eb,0x6d585a26,0x46d0038e,0xa3d405f9}},	//   मिका_, _olwa, _त्यह, _सबक_, 
   {{0xf1a81416,0x60c057cf,0xba000a28,0x262801b8}},	//   مانه_, ucom, rāḥ_, _iĝo_, 
   {{0x6db000b0,0x39580023,0xfe780032,0x60c08089}},	//   _rāap, ërsi_, әүе_, rcom, 
   {{0x6d58808a,0x60c0808b,0x6b4c808c,0x236802d2}},	//   _alwa, scom, _kúgu, _umbj_, 
   {{0xc7b4013f,0x6d58035a,0x6b4c02d2,0xa2a000cd}},	//   _nsɑm_, _blwa, _júgu, _कृच्, 
   {{0x6d58808d,0x6b4c02d2,0x00000000,0x00000000}},	//   _clwa, _múgu, --, --, 
   {{0x6d5803ac,0x17280327,0xfb8801d5,0xf8b801e0}},	//   _dlwa, _སྣའམ_, йроқ_, ҙөй_, 
   {{0x158008b0,0x20040023,0x6b4c0022,0x10a0084c}},	//   ﯩﻜﺘﯩ, mtoi_, _oúgu, _циун, 
   {{0x20040240,0x6d5803ac,0x09e006ed,0xdb0c01e1}},	//   ltoi_, _flwa, моќн, _òjís, 
   {{0xb4b809d9,0x2124808e,0x6d58808f,0x00000000}},	//   _चले_, ndoh_, _glwa, --, 
   {{0x20048090,0x6b4c8091,0x262800c8,0x6ec02802}},	//   ntoi_, _aúgu, _aĝo_, रुकु, 
   {{0x6aac01e4,0x6b4c0174,0x6d5802d0,0x00000000}},	//   _ŝafe, _súgv, _zlwa, --, 
   {{0x21240369,0x3e4c013f,0x7f48047e,0x20048092}},	//   kdoh_, bɛte_, _modq, htoi_, 
   {{0x7f48014f,0x20040023,0x94a805d9,0x6d58035a}},	//   _lodq, ktoi_, لاءِ_, _xlwa, 
   {{0xd7f88093,0x26280115,0x94a88094,0x2124011f}},	// [9b50] _туй_, _eĝo_, ртва_, ddoh_, 
   {{0x7f480455,0x00000000,0x00000000,0x00000000}},	//   _nodq, --, --, --, 
   {{0xb1140006,0x3948003e,0x6b4c0162,0x518473f6}},	//   змеш, _koas_, _túgv, оуда, 
   {{0x21240649,0x200402d3,0x3948033b,0x25a0003a}},	//   gdoh_, ftoi_, _joas_, _ghkl_, 
   {{0x39480077,0xc954008f,0xd01801f0,0x490000dc}},	//   _moas_, ומף_, рфе_, ष्टो_, 
   {{0x39488095,0x09a80073,0x6d5803ac,0x8f0801d5}},	//   _loas_, _गळ्य, _slwa, рхда_, 
   {{0x20048096,0x6d588097,0xd1380408,0x00000000}},	//   atoi_, _plwa, _кха_, --, 
   {{0x3948000f,0xb4b88098,0x6fb8010a,0xcee808f0}},	//   _noas_, _चलो_, _ггар_, _چران_, 
   {{0xc1040597,0x2004003a,0xb4b80037,0x613001a9}},	//   _توقي, ctoi_, _चलै_, mаlа, 
   {{0x0f800014,0x6dc00228,0x613001d5,0x00000000}},	//   _تیتُ, _كۅتۅ, lаlа, --, 
   {{0x39488099,0x6d582d32,0xdb0800d8,0xce68809a}},	//   _boas_, _tlwa, _sifã, _трад_, 
   {{0x39480f71,0x6d580928,0x9f44030a,0x613001a9}},	//   _coas_, _ulwa, duoù_, nаlа, 
   {{0xab28055f,0x39482508,0x9cd405d0,0x00000000}},	//   _гола_, _doas_, _זונה_, --, 
   {{0x3948003a,0x6b4c00e4,0x613001a9,0xf42000eb}},	//   _eoas_, _púgu, hаlа, নমার_, 
   {{0x394801bf,0xe5a4809b,0xe69401b9,0x613001a9}},	//   _foas_, зиви, سلرد, kаlа, 
   {{0x21240399,0x613001d5,0x200401f4,0xb5b00150}},	//   xdoh_, jаlа, ytoi_, _ﺳﺎﻧﻌ, 
   {{0x29c007ae,0x93c80583,0x9f440165,0x613001a9}},	// [9b60] _hóa_, مالہ_, auoù_, dаlа, 
   {{0x316c07c5,0x29c000c7,0x6b4c01e7,0xa3140022}},	//   _amez_, _kóa_, _iúgs, џьаш, 
   {{0x709c02d3,0x2d8c0418,0x39480098,0x69c0809c}},	//   _ዝሓለፉ_, koee_, _yoas_, nqle, 
   {{0x69c00007,0x200402f6,0xeaf82ce1,0x7f480477}},	//   iqle, ttoi_, ्भुत_, _sodq, 
   {{0x29c0809d,0x00000000,0x00000000,0x00000000}},	//   _lóa_, --, --, --, 
   {{0x2004809e,0x7f480009,0x6b4c02d2,0xa34801a9}},	//   rtoi_, _qodq, _múgs, _узга_, 
   {{0x53a00228,0x20042edd,0x29c0809f,0x613001a9}},	//   _чарб, stoi_, _nóa_, bаlа, 
   {{0xcb040323,0x20040240,0x7e6400df,0x37bc0154}},	//   үхэд_, ptoi_, ŝipo, _অবসর, 
   {{0x39480489,0xdef000c7,0x1f6400fb,0xeaf880a0}},	//   _roas_, _зҿлы, _екам, ्भूत_, 
   {{0x394880a1,0xdb0800d8,0x7b840131,0xdee480a2}},	//   _soas_, _bifá, بابە, _хожи, 
   {{0xad6405d9,0x2d8c003a,0x29c00208,0x894c01e1}},	//   _ڪاله, boee_, _cóa_, _àjọ̀, 
   {{0x984800a7,0x00000000,0x00000000,0x00000000}},	//   бяга_, --, --, --, 
   {{0x7d040986,0x83f0013f,0x3948030a,0x1a6480a3}},	//   _ñisq, nyɑd, _voas_, تیژی_, 
   {{0x29c002d2,0x613001a9,0xe7ec0b4c,0xbd8801f7}},	//   _fóa_, zаlа, _जिरा_, _انچن_, 
   {{0x394800c5,0xb5941553,0x6e20010a,0x29c080a4}},	//   _toas_, дивш, _xslb, _góa_, 
   {{0x9cf8015b,0x629806ea,0x8a78011a,0x73d8190b}},	//   _আসুন_, _útoy, _לאות, ждар_, 
   {{0x04c815f2,0x0574007b,0xe51c0037,0x00000000}},	// [9b70] سولي_, رافد, _पसरि_, --, 
   {{0x2d8c009f,0x43740212,0xd6d80da9,0x9f400241}},	//   zoee_, нуєт, _ути_, _ìkè_, 
   {{0x29c00016,0x613001d5,0x32184e77,0xcad4011a}},	//   _xóa_, tаlа, تياد_, פואת_, 
   {{0x6b4c03b2,0xd6c001d3,0x0cb803ce,0x48dc00fe}},	//   _júgr, _تمھی, _उलेम, _ভাৱৰ, 
   {{0x5fa00075,0x1728031c,0x6e2001ab,0x613001a9}},	//   ھەمم, _སྣོམ_, _sslb, rаlа, 
   {{0xdd8c80a5,0xdfcc2abb,0xfe7001b9,0x4df807f7}},	//   یوو_, جيو_, گده_, _एमआई_, 
   {{0xc1040451,0x00000000,0x00000000,0x00000000}},	//   _ڳولي, --, --, --, 
   {{0xfe7080a6,0xe7ec09fd,0x30142424,0x613001a9}},	//   دده_, _जिला_, _одбр, qаlа, 
   {{0xc1047ae6,0x69c00007,0x29c002d2,0x00000000}},	//   _سولي, wqle, _sóa_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2b980036,0x6b4c08a5,0x00000000,0x00000000}},	//   lèck_, _búgr, --, --, 
   {{0x7d040986,0xa2a021bd,0x00000000,0x00000000}},	//   _ñisp, केट्, --, --, 
   {{0x2000010e,0xc2cc0241,0x00000000,0x00000000}},	//   _äkit_, _ẹ̀gú, --, --, 
   {{0xb90409bb,0x0ba405a2,0x29c00051,0x00000000}},	//   _पड़_, _эшем, _tóa_, --, 
   {{0xd62480a7,0x7b446a3b,0x9b9000f2,0x00000000}},	//   море_, _سئول, _جلوت, --, 
   {{0x99f405d0,0xe5a401f4,0x00000000,0x00000000}},	//   _חזקה_, фиби, --, --, 
   {{0x29100796,0x2fcc01d4,0x3998003e,0x00000000}},	// [9b80] _ibya_, _nteg_, désh_, --, 
   {{0xdcd8085c,0x00000000,0x00000000,0x00000000}},	//   _यज्ञ, --, --, --, 
   {{0xe29801c0,0x61440006,0x97540375,0x9f400241}},	//   цаж_, межа, _חייו_, _ìké_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x29100124,0x64c400cf,0x10440395,0x00000000}},	//   _mbya_, _ىيگل, дящи_, --, 
   {{0x442080a8,0x20ec01fb,0x9cf8015b,0x65940022}},	//   mwi_, ội_, _আসেন_, _хаҭу, 
   {{0x442080a9,0x2b980100,0x7c900023,0x3d9400f3}},	//   lwi_, mèch_, _ምትላል_, никр, 
   {{0x442080aa,0xa0a40e76,0x00000000,0x00000000}},	//   owi_, _жабд, --, --, 
   {{0x442080ab,0xbf100348,0xdb8802d3,0x00000000}},	//   nwi_, _бүлә, _ምእዛዝ_, --, 
   {{0x29104c27,0x44200053,0x6aac00df,0x6b4c007b}},	//   _abya_, iwi_, _ŝafa, _súgr, 
   {{0x442027cc,0x399800dd,0xc6140eac,0xa2a00073}},	//   hwi_, lési_, ায়তা_, केच्, 
   {{0xed8802dd,0x3da801af,0x00000000,0x00000000}},	//   _есік_, _эйеү_, --, --, 
   {{0x17285078,0x442080ac,0x96e800c7,0xda6400ec}},	//   _སྣུམ_, jwi_, жьба_, _ڪاشي, 
   {{0x442080ad,0x9f440589,0x29102f99,0x00000000}},	//   dwi_, broå_, _ebya_, --, 
   {{0x88b0013f,0xda645734,0x399806fd,0x2b9802e2}},	//   _abɛd, _تاشي, hési_, dèch_, 
   {{0x2910145e,0x3ce400d8,0x4420007f,0x399880ae}},	//   _gbya_, namv_, fwi_, kési_, 
   {{0x97a40323,0x442080af,0x92e81884,0x00000000}},	// [9b90] _орол, gwi_, قراق_, --, 
   {{0x3ce402c4,0x399801ed,0x8c400790,0x00000000}},	//   hamv_, dési_, _üşen, --, 
   {{0x2fcc7813,0x442080b0,0x728400e5,0x00000000}},	//   _steg_, awi_, رائے, --, 
   {{0x765409a5,0x02a40e48,0x39980098,0x442080b1}},	//   myzy, трум, fési_, bwi_, 
   {{0x44200009,0x00000000,0x00000000,0x00000000}},	//   cwi_, --, --, --, 
   {{0x9404043b,0x66200209,0xb900031c,0x13a40133}},	//   ́nɛ_, _çyký, _ཧབ_, _کۆڕی_, 
   {{0xdb0801b8,0x94a80014,0xed5880b2,0x910401d5}},	//   _mifä, _داگِ_, зой_, _очад, 
   {{0xeab80107,0x00000000,0x00000000,0x00000000}},	//   ӯйи_, --, --, --, 
   {{0x2fcc80b3,0x657806af,0xbebc0055,0x2fd800ae}},	//   _uteg_, éthi, _maīj, _رواد_, 
   {{0x9f440589,0xf1b809a8,0xfbc80154,0x80a4012d}},	//   troå_, _hiš_, _শিখত, _औरते, 
   {{0x442080b4,0xa3e40918,0xf1b805a1,0x00000000}},	//   zwi_, _यौन_, _kiš_, --, 
   {{0x4420016d,0xad2404da,0xcc10004e,0x00000000}},	//   ywi_, _سىتى, _ачкө, --, 
   {{0x7c6480b5,0xf1b880b6,0x4420031c,0xa154011a}},	//   _لاول, _miš_, xwi_, גברה_, 
   {{0x44200842,0x6a84010b,0x5ba001af,0x00000000}},	//   vwi_, _плла, _йһығ, --, 
   {{0x69947b0d,0x399800dd,0x59c42e1e,0x442080b7}},	//   _прих, zési_, _रूपर, wwi_, 
   {{0x442080b8,0xf1b80989,0x00000000,0x00000000}},	//   twi_, _niš_, --, --, 
   {{0x2484172e,0x7a08016b,0x68e405bc,0x442022d0}},	// [9ba0] çom_, _bɛtw, makd, uwi_, 
   {{0x442080b9,0x68e4485b,0xf1b80064,0x14200006}},	//   rwi_, lakd, _aiš_, ыдум, 
   {{0x442080ba,0x7654033f,0x2b98007f,0x76400108}},	//   swi_, cyzy, rèch_, älyt, 
   {{0x290080bb,0x399800dd,0x68e480bc,0x6804013f}},	//   ngka_, tési_, nakd, _wɔdu, 
   {{0x7d04005b,0x657480bd,0x2b9802e2,0x44200978}},	//   _öisi, miyh, pèch_, qwi_, 
   {{0x80d02ce1,0x6454009a,0x657480be,0x39983980}},	//   _ड्रे, myyi, liyh, rési_, 
   {{0xf1b80e04,0xdbd800e8,0x39983e3b,0x68e4022e}},	//   _fiš_, _ràñe, sési_, kakd, 
   {{0x68e4322e,0x5f04013e,0x2168010b,0x7774022e}},	//   jakd, _ӯзба, _эиби_, zizx, 
   {{0x9f84063b,0xb03400aa,0x6454009a,0x68e40432}},	//   _згад, _ټولګ, nyyi, dakd, 
   {{0x3b54797f,0xff241dd8,0x00000000,0x00000000}},	//   ткор, _جبری, --, --, 
   {{0x61fc80bf,0x657401f4,0x0d940124,0x00000000}},	//   nupl, kiyh, ьтәы_, --, 
   {{0xdbd800e8,0x64580213,0x00000000,0x00000000}},	//   _wàñe, _ətir, --, --, 
   {{0x88b0016b,0x61fc014f,0xb7880352,0x00000000}},	//   _abɛb, hupl, дәне_, --, 
   {{0x61fc04b9,0x00000000,0x00000000,0x00000000}},	//   kupl, --, --, --, 
   {{0x16740020,0x6454198f,0x61fc80c0,0x77740083}},	//   _አድራሻ_, eyyi, jupl, rizx, 
   {{0xb7c41621,0x8ca412eb,0x68e403e0,0x765480c1}},	//   _ироқ, _चरमो, cakd, ryzy, 
   {{0x947404d3,0xf1b80064,0x00000000,0x00000000}},	// [9bb0] ردرا, _riš_, --, --, 
   {{0xd6d81c22,0x799c3a60,0xd34480c2,0x764080c3}},	//   _эти_, llsw, ریزه_, älys, 
   {{0xd36c3baf,0x61fc03b2,0x799c80c4,0xf1b85752}},	//   لۇڭ_, gupl, olsw, _piš_, 
   {{0xcfc80150,0x00000000,0x00000000,0x00000000}},	//   _ﻗﻮﺭﺗ, --, --, --, 
   {{0xb4dc46c7,0x753c80c5,0xf1b801a6,0x61fc035a}},	//   डरी_, _insz, _viš_, aupl, 
   {{0x61fc014f,0x2cbc0142,0x799c002f,0xa3f4011a}},	//   bupl, _sgwd_, hlsw, _במשק_, 
   {{0x61fc80c6,0x518400c7,0x999c0064,0x00000000}},	//   cupl, _зуаа, nytų_, --, 
   {{0x6aac00df,0x712401ec,0x00000000,0x00000000}},	//   _ŝafo, _جىرم, --, --, 
   {{0x7a08013f,0x3e4c016b,0x68e480c7,0x752c009d}},	//   _mɛtu, bɛto_, vakd, idaz, 
   {{0x799c0730,0x999c0024,0x9f440165,0xeac40395}},	//   elsw, kytų_, kroù_, ъбоп, 
   {{0x68e47ab4,0x753c0d27,0xa9a438ca,0x645806be}},	//   takd, _onsz, киод, _ətiq, 
   {{0x999c0024,0x9f440165,0xaad000cd,0x00000000}},	//   dytų_, droù_, _द्रक, --, 
   {{0x68e480c8,0x752c80c9,0x1cb8031c,0x9f4405c7}},	//   rakd, ddaz, _ཙུག_, eroù_, 
   {{0x61fc1529,0x68e422d0,0x9f440489,0x799c0857}},	//   yupl, sakd, froù_, alsw, 
   {{0x7a08013f,0xa594399b,0x660400a7,0x7afc003a}},	//   _bɛtu, вращ, ъпва, órte, 
   {{0x6d4880ca,0x752c0198,0x64a4014b,0x61fc014f}},	//   njea, gdaz, ваба, vupl, 
   {{0xe3b823b3,0x9f440489,0x65740108,0x232801f0}},	// [9bc0] дба_, aroù_, riyh, моаи_, 
   {{0x7e6400df,0x57f8010f,0x65740108,0x00000000}},	//   ŝipi, _קליו, siyh, --, 
   {{0xe1f01e87,0x2cb000bc,0x6d20012c,0xa2041075}},	//   شسا_, ězdy_, _मसंग_, тпед, 
   {{0xb294026a,0x752c0076,0x672c005c,0xe4584130}},	//   ујућ, cdaz, ldbj, _жжм_, 
   {{0x61fc80cb,0x6aac0115,0x6d4801ab,0x00000000}},	//   supl, _ŝafl, djea, --, 
   {{0x399800dd,0xe3b00f84,0x61fc80cc,0x672c005c}},	//   lést_, _خرج_, pupl, ndbj, 
   {{0x91e080cd,0x1cb80003,0xe298009d,0xdda800db}},	//   _восе, _ཙུང_, _цав_, мтил_, 
   {{0x399880ce,0x69c40076,0xdfd000ec,0x00000000}},	//   nést_, _çhey, _نير_, --, 
   {{0xd8400306,0x8ca45edd,0x2d5002d2,0x00000000}},	//   _mlčí_, _चरणो, _páer_, --, 
   {{0xda787724,0xcb640e92,0x1a7401ec,0x00000000}},	//   дям_, кање_, кұлы_, --, 
   {{0x752c04ce,0xe8ec00ec,0x00000000,0x00000000}},	//   ydaz, ڳڻي_, --, --, 
   {{0x9cb001d9,0x9f440165,0x58840e3b,0x00000000}},	//   _پۅخت, vroù_, выга, --, 
   {{0x588480cf,0x399801ed,0x61ec0175,0x799c04ce}},	//   тына, dést_, _lvbl, rlsw, 
   {{0x7a08013f,0x4c900220,0x3880001f,0x999c0024}},	//   _bɛtt, _тиіс, _የዕለቱ_, tytų_, 
   {{0x7ae880d0,0xa6c8022e,0xcb640114,0x00000000}},	//   madt, _rnаt, _јаје_, --, 
   {{0x7ae880d1,0x8ab40302,0x6f0c05a1,0x752c04cc}},	//   ladt, _בלוג_, đaci, udaz, 
   {{0x733880d2,0xd4040c9e,0xb6a400d1,0xd6d8011c}},	// [9bd0] нзар_, ъяви, тиңл, _отн_, 
   {{0x7ae880d3,0x6d48000f,0x9f4405c7,0x999c0064}},	//   nadt, zjea, proù_, pytų_, 
   {{0x644001f4,0x00000000,0x00000000,0x00000000}},	//   äoir, --, --, --, 
   {{0x7ae880d4,0xf8c000e1,0x00000000,0x00000000}},	//   hadt, _एलोप, --, --, 
   {{0x7ae880d5,0x0f703e64,0x0fe000f7,0xdb0802f0}},	//   kadt, ағар, рөбү, _difú, 
   {{0xf5b00150,0xdee00aac,0x7ae880d6,0x00000000}},	//   _ءﺷﻮﭘ, боши, jadt, --, 
   {{0x7ae8539f,0x83f0013f,0x6d480129,0x00000000}},	//   dadt, nyɑn, tjea, --, 
   {{0xde1400c6,0x518480d7,0x00000000,0x00000000}},	//   اقيت_, _руга, --, --, 
   {{0x9e901772,0x7ae80332,0x1ad80154,0xaed421fe}},	//   _ልዕልና_, fadt, _দাড়া, _бозш, 
   {{0x399800dd,0xe9e801f1,0xcae0015b,0x7ae880d8}},	//   zést_, hnúť_, _মাহফ, gadt, 
   {{0x1ee8034c,0xe9e80030,0x00000000,0x00000000}},	//   _سونی_, knúť_, --, --, 
   {{0x2ee40165,0x9e900023,0x00000000,0x00000000}},	//   _helf_, _ልዕሌና_, --, --, 
   {{0xe9e801f1,0x3998012c,0x2ee4030a,0x7ae880d9}},	//   dnúť_, vést_, _kelf_, badt, 
   {{0x5bf02832,0x0b8801a9,0xf8b400c7,0x2734075e}},	//   _آوا, _ўсди_, шҩы_, دىسس, 
   {{0x399800dd,0xee4400ee,0x0a6801d5,0x00000000}},	//   tést_, _öýde_, _юрди_, --, 
   {{0x320002f0,0x7d041b99,0x3a38005c,0xaa500023}},	//   duhy_, _öist, ærpe_, _ዝመሓላ, 
   {{0xd4644156,0x399801d3,0xd8400c5e,0x00000000}},	// [9be0] гите_, rést_, _vlčí_, --, 
   {{0x61ec003a,0x399801d3,0xe644009b,0x00000000}},	//   _pvbl, sést_, _беоп, --, 
   {{0x2b98067c,0x399801d3,0xe9e800d7,0xf1a81046}},	//   lècs_, pést_, bnúť_, چانه_, 
   {{0xf1a86702,0xd058013f,0xd5f80677,0x00000000}},	//   نانه_, _aduɑ, _אפטר, --, 
   {{0x7a08013f,0x442435b2,0x101000be,0x25b06e25}},	//   _yɛts, _èm_, مبود, mmyl_, 
   {{0x7a080085,0x9e04801b,0x61ec011c,0x2ee40368}},	//   _mɛtr, гчил, _tvbl, _celf_, 
   {{0xab780201,0x2ee480da,0x7ae80037,0x00000000}},	//   _ብለዋል_, _delf_, vadt, --, 
   {{0x2174100b,0x8e340271,0x7d541422,0x00000000}},	//   _сугр, اسور_, рвих, --, 
   {{0x7ae880db,0x5474010f,0x00000000,0x00000000}},	//   tadt, ָגיע_, --, --, 
   {{0x6fdc45bf,0x5018008d,0x5884054a,0x2ee480dc}},	//   _नौटं, _אומו, ғыма, _gelf_, 
   {{0x7ae81bbf,0x05b42232,0xe9e80419,0x00000000}},	//   radt, ंगाब, ynúť_, --, 
   {{0x2ee40460,0x7a08016b,0xd2b4011a,0xf8b82519}},	//   _zelf_, _bɛtr, טלית_, көп_, 
   {{0x8d9080dd,0xdb840092,0x49740816,0x9bd40064}},	//   _النش, ኖረውም_, сляс, _сцеш, 
   {{0x7ae80455,0x00000000,0x00000000,0x00000000}},	//   qadt, --, --, --, 
   {{0xda6480de,0xe9e80030,0x2b980ba1,0x00000000}},	//   _حاشي, tnúť_, rèct_, --, 
   {{0xb4d480df,0x0574006c,0x82280327,0x74540092}},	//   ржащ, ماقد, _ཤནྟི_, _የመፍጠ, 
   {{0x337480e0,0x2b980ba1,0x27e4025c,0xe3c401c6}},	// [9bf0] агар, pèct_, _ħong_, архү, 
   {{0xe9e800d0,0x00000000,0x00000000,0x00000000}},	//   snúť_, --, --, --, 
   {{0xe9e80030,0x67b8011a,0xd63001f7,0x00000000}},	//   pnúť_, _שמתק, _اِجھ, --, 
   {{0x2ee40302,0x320002fb,0xca940375,0xb0340120}},	//   _self_, ruhy_, נדאי_, инеш, 
   {{0x2ee44e13,0x7d040113,0x00c802dd,0x09b8010f}},	//   _pelf_, _ñisy, улік_, אפאט_, 
   {{0xb0d406ab,0x00000000,0x00000000,0x00000000}},	//   _ड्रग, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2ee480e1,0x8d240075,0x27e400a2,0xed3404b4}},	//   _welf_, униң_, _çong_, рэкэ, 
   {{0x6fb880e2,0x2ee480e3,0x506480e4,0x6b64014b}},	//   _агар_, _telf_, _ства, икиа, 
   {{0xce681377,0x51840b01,0x0dc80117,0x00000000}},	//   _пред_, _руҳа, _зуди_, --, 
   {{0xa9681515,0xce3039b1,0x7c6401d5,0xbdf880e5}},	//   вина_, _دواک, لایل, _مرنا_, 
   {{0xac940166,0x00000000,0x00000000,0x00000000}},	//   _каеш, --, --, --, 
   {{0xebe480e6,0x00000000,0x00000000,0x00000000}},	//   _толп, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe9a480e7,0xf6640137,0x00000000,0x00000000}},	//   _какп, берү, --, --, 
   {{0x7a08016b,0xdce00022,0x9f4400a2,0x00000000}},	//   _tɛtr, _omoĝ, droý_, --, 
  
   {{0x6aac01e4,0x25b0017a,0x00000000,0x00000000}},	// [9c00] _ŝafh, rmyl_, --, --, 
   {{0x716400d1,0x93400022,0x00000000,0x00000000}},	//   ەھكە, онуе, --, --, 
   {{0xe5a480e8,0xdce000e4,0x00000000,0x00000000}},	//   _вини, _amoĝ, --, --, 
   {{0x5f000154,0x5a14010f,0xc1b40166,0x00000000}},	//   _এসইও_, יקען_, сәгы, --, 
   {{0x33d480e9,0x74f001ec,0x403409ac,0x00000000}},	//   _гіст, _رۋلا, селс, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69c0044b,0x5d640cdd,0xa2d480ea,0x00000000}},	//   _रंगी, итиз, मुण्, --, 
   {{0x2370033f,0x628c02d0,0x2f040124,0xb5b002dd}},	//   żają_, _ixbo, ажәҳ, _ﺳﺎﻟﻌ, 
   {{0x661c0ac5,0x8d7080eb,0x0ea41945,0x8c400f14}},	//   _lppk, تاوا, лкәй_, жење, 
   {{0x661c168c,0x61fc6f23,0x68f4010e,0x217408ca}},	//   _oppk, orpl, _adyd, _суҳр, 
   {{0xc0d0069c,0xad6400b2,0x65640158,0x0ecc134e}},	//   _ጥራሕ_, _ڏانه, _olkh, _स्टड, 
   {{0xa2d40882,0x3b84010b,0x1ee81dd8,0x00000000}},	//   मुत्, рлүг, _سوچی_, --, 
   {{0x68f40cfd,0x61fc0e78,0xb6c401e0,0x661c80ec}},	//   _ddyd, hrpl, йөнд, _appk, 
   {{0x656480ed,0x00000000,0x00000000,0x00000000}},	//   _alkh, --, --, --, 
   {{0x65640477,0x88c800bc,0x61fc01bf,0x671480ee}},	//   _blkh, _svěž, jrpl, द्धक_, 
   {{0x81c40d42,0x661c0a2e,0xc4d80114,0x80dc00eb}},	//   _এবং_, _dppk, иђу_, মৃত্, 
   {{0x628c006c,0x61fc80ef,0x661c005a,0x53e40150}},	// [9c10] _axbo, erpl, _eppk, рцба, 
   {{0xdb080597,0x6aac010f,0xd25802d5,0x889c02e4}},	//   _bhfé, _ŝafi, кце_, _בבחי, 
   {{0x6fb802dd,0x00000000,0x00000000,0x00000000}},	//   ңгер_, --, --, --, 
   {{0xdd84758c,0xc1980212,0x8bfc00eb,0x00000000}},	//   _رو_, атії_, ্বতন_, --, 
   {{0x628c0048,0x61fc6df9,0xdca402dd,0x00000000}},	//   _exbo, arpl, _ءى_, --, 
   {{0xa2d40882,0xb8d8025c,0xf1c800c6,0xdee04258}},	//   मुद्, _མཛ_, _موسى_, поши, 
   {{0x4a200f50,0xeb981f71,0x61fc05ce,0x31a422ad}},	//   _འགེལ_, ғин_, crpl, _همسف, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xeb9880f0,0x1c402b41,0x00000000,0x00000000}},	//   лии_, зным, --, --, 
   {{0x80dc02f5,0xab641188,0x00000000,0x00000000}},	//   মৃদ্, свол, --, --, 
   {{0x0dc8013e,0xed3480f1,0xfe083229,0x8d84014b}},	//   _рузи_, _гэлэ, _نقلي_, _кудд, 
   {{0x3b844ecc,0x45640023,0xdc5457fb,0x00000000}},	//   йлөг, _መፈንጠ, _گرمک, --, 
   {{0x2d9c80f2,0xa2bc80f3,0xa3e400bc,0x7c8400f3}},	//   _ikwe_, _वृन्, _यौं_, _муље, 
   {{0x848402d3,0xe7380063,0x6b6480f4,0x61fc007c}},	//   _ዑስማን_, ћев_, _ыкла, yrpl, 
   {{0xba285706,0xbebc00b0,0x66e42e56,0x49b40131}},	//   _نسيم_, _haīr, _қона, _мәму, 
   {{0xfa880032,0x00000000,0x00000000,0x00000000}},	//   _әсәй_, --, --, --, 
   {{0x2d9c01c8,0x628c058a,0x00000000,0x00000000}},	// [9c20] _mkwe_, _sxbo, --, --, 
   {{0x61fc0010,0xc1b02c2e,0x00000000,0x00000000}},	//   trpl, जग्ग, --, --, 
   {{0xe1f880f5,0xb9c080f6,0x661c80f7,0x61fc257d}},	//   уге_, _üçün, _uppk, urpl, 
   {{0x2d9c325e,0x41340092,0x00000000,0x00000000}},	//   _nkwe_, _ኮሙኒኬ, --, --, 
   {{0xd12c3ae3,0x7d781888,0xd24c00f1,0x98700023}},	//   عمه_, یمتر_, وچې_, _ኣስሚዑ_, 
   {{0x2d9c80f8,0xe29801c0,0xdce00166,0x00000000}},	//   _akwe_, _баг_, _bmoğ, --, 
   {{0xfa040156,0x00000000,0x00000000,0x00000000}},	//   _མའེན_, --, --, --, 
   {{0x5bb02894,0x7bf801d5,0xa114591a,0xd5d8010f}},	//   ीद्व, анир_, _دورت, אַזש, 
   {{0x4a200ed9,0xfb88036b,0x69c0012d,0x547800df}},	//   _འགུལ_, ироқ_, _रंजी, ָטיו, 
   {{0x2d9c0521,0x262801e4,0xdce0107d,0x200480f9}},	//   _ekwe_, _oŝo_, _iloč, muoi_, 
   {{0x5ea40eff,0x262801e4,0x6f1405d1,0xda64007b}},	//   _امال, _nŝo_, _özca, صادي, 
   {{0xd90c51a4,0x9a8425f8,0x2124030a,0x9db801ec}},	//   ریخ_, _қулл, neoh_, _сызу_, 
   {{0x200400b0,0x9c58210e,0x7ac40166,0x00000000}},	//   nuoi_, _حجاز_, _мөна, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x20040069,0x4b780a1e,0x00000000,0x00000000}},	//   huoi_, _תאוו, --, --, 
   {{0xdb08014a,0x20b80d2c,0xf4d880fa,0x98c480fb}},	//   _lifü, ेशाध, рмаш_, _ускл, 
   {{0x798c80fc,0x69c001ad,0xb9d80023,0x00000000}},	// [9c30] _ijaw, _रूटी, _በሊ_, --, 
   {{0x78ac0223,0x20040198,0xd684014b,0x00000000}},	//   _izav, duoi_, _гумп, --, 
   {{0x68ec008e,0x00000000,0x00000000,0x00000000}},	//   _öndä, --, --, --, 
   {{0x466880fd,0xdce080fe,0xc104007b,0x27f00139}},	//   _ырым_, _bloč, كومي, _ännä_, 
   {{0x798c0175,0x7af80030,0x20040208,0x46d000bc}},	//   _mjaw, _odvt, guoi_, तुकह, 
   {{0x78ac80ff,0x7afc01e7,0x00000000,0x00000000}},	//   _mzav, órtl, --, --, 
   {{0xdb088100,0x2d9000e5,0x41e400c0,0x00000000}},	//   _lifó, _ízek_, _ніта, --, 
   {{0xed58187d,0xa28020d3,0x798c8101,0x78ac0219}},	//   рои_, _تیمو, _njaw, _ozav, 
   {{0x78ac0223,0x3a3c0175,0x20040208,0xfca800ec}},	//   _nzav, _arvp_, cuoi_, ٽايو_, 
   {{0x798c8102,0xa554001f,0x6a8400a8,0xdc800023}},	//   _ajaw, _የወንጀ, жлоа, _ዕድመይ_, 
   {{0xdce004b9,0x78ac8103,0x7c3c01ab,0x00000000}},	//   _zloč, _azav, ārra, --, 
   {{0xac188104,0x2d9c8105,0x00000000,0x00000000}},	//   _воду_, _ukwe_, --, --, 
   {{0x798c8106,0xe7300f1c,0x00000000,0x00000000}},	//   _djaw, وصآ_, --, --, 
   {{0x78ac3dd0,0xdb0856eb,0x9514025c,0xe738026a}},	//   _dzav, _difó, ྲུའི_, шег_, 
   {{0x94040085,0x78ac3926,0x2a08010a,0xf6640166}},	//   ́nɔ_, _ezav, _тейп_, перү, 
   {{0xb0a8353b,0x9f4402d2,0x00000000,0x00000000}},	//   _औरंग, hroð_, --, --, 
   {{0xfd640521,0x2d508107,0xe7308108,0xb90800cf}},	// [9c40] _anwụ, _báez_, _قصد_, _ازىم_, 
   {{0xaac8433a,0x798c033f,0x04fc0154,0x00000000}},	//   रशिक, _zjaw, ুজের_, --, 
   {{0x24940024,0xa2d48109,0x1718010f,0x4394030d}},	//   _žemę_, मुष्, _דויע, çатс, 
   {{0xdce0041a,0x37dc0183,0x20040051,0xa2d8578b}},	//   _ploč, _বিতৰ, tuoi_, _प्र्, 
   {{0xa034049e,0xdb0801b8,0xf1a85230,0x320000a2}},	//   تىشت, _pifü, حاله_, arhy_, 
   {{0x88b0016b,0xe2a8810a,0xdce002fb,0x00000000}},	//   _abɛk, _نازن_, _vloč, --, 
   {{0x38ac01a9,0x00000000,0x00000000,0x00000000}},	//   rоri_, --, --, --, 
   {{0x68401540,0x98a80276,0xdfd000f1,0xa2d4810b}},	//   ክርስት, ndcă_, _ييز_, मुर्, 
   {{0xa2bc810c,0x20040129,0xee4400a2,0x545400df}},	//   _वृत्, quoi_, _öýne_, ַסטן_, 
   {{0xdc280133,0x00000000,0x00000000,0x00000000}},	//   _ۆسته_, --, --, --, 
   {{0x78ac00dd,0xdb08810d,0x00000000,0x00000000}},	//   _szav, _sifó, --, --, 
   {{0xdc2800f1,0x00000000,0x00000000,0x00000000}},	//   _نسته_, --, --, --, 
   {{0x6aac00df,0xd90c1e4b,0x645801e1,0x00000000}},	//   _ŝaft, _یید_, _ńtin, --, 
   {{0x3f9c08ad,0x37dc00cc,0x00000000,0x00000000}},	//   novu_, _বিদৰ, --, --, 
   {{0x95c8810e,0xa8040139,0xfaf80055,0x00000000}},	//   руга_, _arığ, bhīr_, --, 
   {{0x3f9c1505,0x32000232,0xdb083eba,0x2d5004d4}},	//   hovu_, vrhy_, _tifó, _sáez_, 
   {{0x78ac031d,0x799c0770,0x2d503eba,0x3dcc0142}},	// [9c50] _uzav, mosw, _páez_, _ludw_, 
   {{0x92641f7a,0x799c810f,0x3f9c8110,0x572000cf}},	//   يدام, losw, jovu_, _تۉسك, 
   {{0xa2bc449f,0x88b0013f,0x30880032,0x00000000}},	//   _वृद्, _abɛh, әшеү_, --, 
   {{0x41744354,0x799c2378,0x81c800d4,0x00000000}},	//   وانس, nosw, ігів_, --, 
   {{0xf48401d3,0x00000000,0x00000000,0x00000000}},	//   _راحی, --, --, --, 
   {{0xdfcc8111,0x799c8112,0xdb0800c6,0x2c0005f9}},	//   ديو_, hosw, _bhfí, _शिबू_, 
   {{0x59c41889,0x799c8113,0xed580212,0x57c400dc}},	//   _रंगर, kosw, йок_, लदुह, 
   {{0x41e80798,0xa908012d,0x00000000,0x00000000}},	//   _ффрм_, _वाइफ_, --, --, 
   {{0x9c2000c9,0x3f9c8114,0xa8040139,0xf26801af}},	//   едыд, bovu_, _krış, _тиңл_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x799c8115,0xa9a48116,0x2fcc030a,0xaa440440}},	//   fosw, зинд, _hueg_, ченл, 
   {{0xbea88117,0x50c83e8c,0x2fc400ad,0x60600228}},	//   _بهمن_, िशिष, _hilg_, _تۇۇل, 
   {{0x6d588118,0x2fc4013d,0xa8040139,0x00000000}},	//   _iowa, _kilg_, _orış, --, 
   {{0x2fc48119,0x6d58811a,0xc5f801e0,0x00000000}},	//   _jilg_, _howa, оғо_, --, 
   {{0x6d58811b,0x799c073c,0x2fcc0007,0xd6cc00c6}},	//   _kowa, bosw, _lueg_, اقف_, 
   {{0x3f9c811c,0x6d5806a3,0xe8e8036b,0xa804013d}},	//   zovu_, _jowa, _умид_, _arış, 
   {{0x29100796,0x6d58811d,0xa2bc0b9a,0x3f9c592c}},	// [9c60] _icya_, _mowa, वेन्, yovu_, 
   {{0x6d58811e,0xe2982f09,0x6b80811f,0xa6c8022e}},	//   _lowa, баз_, nilg, _lnаz, 
   {{0x6d585ad0,0xe124010b,0x3f9c02f0,0xa2cc043e}},	//   _oowa, змеи, vovu_, तशब्, 
   {{0x6b80036b,0xdb0801a8,0x23680208,0x00000000}},	//   hilg, _lifð, _wlbj_, --, 
   {{0xdef82cc8,0xd0042838,0x2fc40205,0x6b808120}},	//   бый_, зече_, _bilg_, kilg, 
   {{0x799c0099,0x33b4005b,0xf69800d1,0xa06801e0}},	//   zosw, _жёст, ﺘﯩﮕﻪ_, _һаба_, 
   {{0x3f9c8121,0x2cc00cc1,0x2fc40c67,0x6d580d68}},	//   rovu_, ərdə_, _dilg_, _bowa, 
   {{0x6d588122,0x3f9c1050,0x6b800491,0x7d788123}},	//   _cowa, sovu_, eilg, تمبر_, 
   {{0x6d588124,0x69d400bc,0x4cd016ac,0xbc780395}},	//   _dowa, ízen, رغيز, юбих_, 
   {{0x2fc48125,0x3f9c014b,0x6d5802d0,0x6b8001d5}},	//   _gilg_, qovu_, _eowa, gilg, 
   {{0x6d588126,0x799c8127,0x399800e5,0x00000000}},	//   _fowa, tosw, mész_, --, 
   {{0x2910070d,0x6d588128,0x5d740740,0xace800cf}},	//   _ccya_, _gowa, _عطاء, _ۇرۇل_, 
   {{0x6b808129,0xa5280135,0x998000bc,0x799c03ac}},	//   bilg, _སྒེག_, ňků_, rosw, 
   {{0x6d58812a,0x799c0810,0x399801d3,0x4bf80677}},	//   _zowa, sosw, nész_, _פלוס, 
   {{0x799c812b,0x6d58812c,0x795801c4,0x00000000}},	//   posw, _yowa, _микр_, --, 
   {{0x799c0784,0xd5a001b9,0x94a84710,0xd4980120}},	//   qosw, ءلری, ماءِ_, брз_, 
   {{0x39480227,0x426c069d,0x399801d3,0x89340a11}},	// [9c70] _inas_, ተርኔት_, kész_, _سعيا, 
   {{0x2fcc062c,0x6e2c033f,0x256c00d7,0xa2bc00cd}},	//   _rueg_, łabi, _rýle_, वेभ्, 
   {{0x35b4812d,0x39483e04,0xe8f80166,0xd684030d}},	//   _обор, _knas_, _унөч_, _хупп, 
   {{0x6b8007d6,0x2fc40327,0x00000000,0x00000000}},	//   zilg, _silg_, --, --, 
   {{0x3948083a,0x6d58812e,0x6b8001b9,0xc338010a}},	//   _mnas_, _rowa, yilg, _лĕ_, 
   {{0x6d58812f,0x2fc401d5,0x00000000,0x00000000}},	//   _sowa, _qilg_, --, --, 
   {{0x6d588130,0x39480793,0x6b808131,0xcee8021f}},	//   _powa, _onas_, vilg, _ۇران_, 
   {{0x61f81bb0,0x6d5802d1,0x2fc401f5,0xee44010e}},	//   _ætla, _qowa, _wilg_, _öýme_, 
   {{0x6b80006c,0x6d588132,0x2fc48133,0xb0340408}},	//   tilg, _vowa, _tilg_, _юнаш, 
   {{0x7c64113e,0x6d588134,0x00000000,0x00000000}},	//   عايل, _wowa, --, --, 
   {{0x6b80006c,0x6d588135,0xa2cc00cd,0x00000000}},	//   rilg, _towa, तशत्, --, 
   {{0x6b808136,0x3948054e,0xf7680375,0xfd1002f2}},	//   silg, _cnas_, _דק_, _مجه_, 
   {{0x6cc407d6,0x6b80018f,0x426c1772,0x2d8c8137}},	//   _ўйла, pilg, ተርነት_, mnee_, 
   {{0x39488138,0x6b808139,0x3ea00311,0x2d8c1aed}},	//   _enas_, qilg, şite_, lnee_, 
   {{0x637004ce,0xa5280003,0x7c24006a,0x2d8c813a}},	//   _hæng, _སྒུག_, _âirr, onee_, 
   {{0x2d8c813b,0x3948813c,0xe96804b4,0x637000b5}},	//   nnee_, _gnas_, _фаил_, _kæng, 
   {{0xe738189c,0x2d8c813d,0xd6cc00dd,0xe35401c6}},	// [9c80] _деп_, inee_, اقہ_, мтжэ, 
   {{0x39481326,0x637004ce,0x316c0100,0x2d8c813e}},	//   _znas_, _mæng, _alez_, hnee_, 
   {{0x6370105c,0xa2bc813f,0x316c05c7,0x2d8c022f}},	//   _læng, _वृश्, _blez_, knee_, 
   {{0x737400c7,0x00000000,0x00000000,0x00000000}},	//   _ҧырх, --, --, --, 
   {{0x2d8c0449,0x53ac1546,0x00000000,0x00000000}},	//   dnee_, _जीवश, --, --, 
   {{0x6d5c01e6,0x2d8c8140,0x316c8141,0x62641f0d}},	//   ösan, enee_, _elez_, _قازق, 
   {{0x2d8c198f,0x21688142,0x399801d3,0x53a00022}},	//   fnee_, _диви_, rész_, _рарб, 
   {{0x2d8c8143,0x316c05d5,0x60240640,0x00e41176}},	//   gnee_, _glez_, _одба, _ستری, 
   {{0x657806af,0x39484219,0x00000000,0x00000000}},	//   éthy, _rnas_, --, --, 
   {{0x2d8c8144,0xdb08007b,0x4f040510,0x1f54036b}},	//   anee_, _bhfá, _онун_, _ўтаё, 
   {{0x2d8c8145,0x3948123b,0x00000000,0x00000000}},	//   bnee_, _pnas_, --, --, 
   {{0x637004ce,0x200400b0,0x2d8c058a,0x61e80174}},	//   _fæng, oroi_, cnee_, áfly, 
   {{0x200403a2,0x6370037e,0xa2bc17c6,0x00000000}},	//   nroi_, _gæng, वेत्, --, 
   {{0x26d80ba1,0x00000000,0x00000000,0x00000000}},	//   _cfpo_, --, --, --, 
   {{0x6370037e,0xe85001b9,0xe77800d1,0x00000000}},	//   _mænd, نچید, чарә_, --, 
   {{0x39488146,0x73d88147,0x7470001f,0x200459b6}},	//   _unas_, здар_, _ለመፍጠ, kroi_, 
   {{0x36d48148,0x34940323,0x2028001f,0xc7e804b3}},	// [9c90] _попр, хаар, ደነበረ, _قىين_, 
   {{0x20048149,0x2c000882,0x2d8c0198,0x316c00f3}},	//   droi_, _शिसू_, znee_, _slez_, 
   {{0x2d8c814a,0x66b00150,0x00000000,0x00000000}},	//   ynee_, _бұру, --, --, 
   {{0x2004814b,0x00000000,0x00000000,0x00000000}},	//   froi_, --, --, --, 
   {{0x752c00a8,0x63700008,0x316c05c7,0xdc38013d}},	//   meaz, _bænd, _vlez_, _oçır, 
   {{0x752c814c,0x2d8c814d,0xee440432,0xb4bc0118}},	//   leaz, wnee_, _öýke_, ेखी_, 
   {{0xada40724,0xa2bc0a94,0x82a4084c,0x02a40ce8}},	//   накл, वेद्, _аште, _артм, 
   {{0x752c00a8,0x69d40122,0x2004005a,0xdc386b27}},	//   neaz, ízem, broi_, _açır, 
   {{0xa2d411bc,0x2d8c814e,0x2b3800a8,0x1d20010b}},	//   मुक्, rnee_, пянэ_, умым, 
   {{0x752c0276,0x637062b4,0x9f44030a,0x2d8c814f}},	//   heaz, _væng, ksoù_, snee_, 
   {{0xdd8c8150,0x752c000f,0x2d8c017a,0x00000000}},	//   شوی_, keaz, pnee_, --, 
   {{0x752c084c,0x2d8c0ba7,0x637001bf,0x00000000}},	//   jeaz, qnee_, _tæng, --, 
   {{0x752c0276,0x7eb408a5,0x00000000,0x00000000}},	//   deaz, _týpí, --, --, 
   {{0x20780a7c,0x00000000,0x00000000,0x00000000}},	//   לארא, --, --, --, 
   {{0xa9688151,0x88b0013f,0x256c00a2,0x752c0311}},	//   _ника_, _abɛt, _aýla_, feaz, 
   {{0x28e80510,0xe5a48152,0xe4c40137,0x20040200}},	//   _эдип_, хиби, ейби, yroi_, 
   {{0x637000b5,0x18b001af,0x00000000,0x00000000}},	// [9ca0] _læne, _бәрр, --, --, 
   {{0xe2984eab,0x00000000,0x00000000,0x00000000}},	//   паз_, --, --, --, 
   {{0x752c0851,0xa2d48153,0x63701d1d,0xf1c40051}},	//   beaz, मुग्, _rænd, _thợ_, 
   {{0x672c1ebd,0x20048154,0x256c032e,0x64c40064}},	//   lebj, troi_, _fýla_, _ačiū, 
   {{0x403447bf,0x660c013a,0x00000000,0x00000000}},	//   телс, lubk, --, --, 
   {{0xa2d41a2a,0x20048155,0x672c005c,0x904001e2}},	//   मुख्, rroi_, nebj, انوه, 
   {{0x660c0280,0x63700008,0xd1dc0023,0x8e34007b}},	//   nubk, _vænd, _ዕጥቂ_, فسير_, 
   {{0x20040240,0x256c00a2,0xe0d8009b,0x00000000}},	//   proi_, _yýla_, _хва_, --, 
   {{0x637004ce,0x660c8156,0xd0048157,0x672c01bf}},	//   _tænd, hubk, _пете_, kebj, 
   {{0x752c00a8,0x5438008f,0x637000b5,0x660c8158}},	//   zeaz, לעפא, _uænd, kubk, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x752c0276,0x660c0014,0x4a000022,0x00000000}},	//   xeaz, dubk, ыџьа, --, 
   {{0x38c83577,0x752c084c,0x96e80cc9,0xf7340023}},	//   بادی_, veaz, зьба_, _ብምፍላ, 
   {{0x672c0623,0x752c31a9,0x61ec035a,0xcc74011a}},	//   gebj, weaz, _owbl, _אגדת_, 
   {{0x752c8159,0x3eb401ef,0x00000000,0x00000000}},	//   teaz, _úctě_, --, --, 
   {{0x5eb000fe,0x00000000,0x00000000,0x00000000}},	//   _চলাই, --, --, --, 
   {{0x752c0262,0xa2bc2232,0xdb18002e,0x9f44030a}},	// [9cb0] reaz, वेस्, emté, ssoù_, 
   {{0xc4c46aee,0x752c00a8,0xb4b00037,0x00000000}},	//   اتِو, seaz, _ओरी_, --, 
   {{0x752c00b4,0x61ec0368,0x5184815a,0x358c0023}},	//   peaz, _cwbl, нуда, _ዘጥፍኡ_, 
   {{0x02a48087,0x00000000,0x00000000,0x00000000}},	//   урум, --, --, --, 
   {{0x94842a20,0xe794815b,0xc428815c,0x61ec03ac}},	//   _чынд, _سایک, _пюре_, _ewbl, 
   {{0x637000b5,0xc308009e,0xb4bc0073,0x00000000}},	//   _pæne, র্বি_, आधी_, --, 
   {{0xed584fd5,0x43942636,0x61ec0368,0x00000000}},	//   дой_, _сарс, _gwbl, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6ac8012a,0x5eb000d1,0x00000000,0x00000000}},	//   रश्र, лйәт, --, --, 
   {{0xab64815d,0x3ea00311,0xe9d81436,0xaa44014b}},	//   твол, şita_, мко_, веол, 
   {{0x6f0003ac,0x672c03cd,0xe8f80137,0x00000000}},	//   _idlc, vebj, үнүч_, --, 
   {{0x672c27c4,0xa9682bbd,0x6e2c0210,0x00000000}},	//   webj, фима_, łabs, --, 
   {{0x6b741cd1,0x76440142,0x5d78010f,0x672c353e}},	//   _илду, _arhy, _קאנק, tebj, 
   {{0x660c815e,0x00000000,0x00000000,0x00000000}},	//   tubk, --, --, --, 
   {{0x672c03cd,0x00000000,0x00000000,0x00000000}},	//   rebj, --, --, --, 
   {{0xa9a40323,0x6844815f,0xa9240116,0x660c058a}},	//   _шийд, _аниа, _рдил, rubk, 
   {{0x83480131,0x660c0009,0x00000000,0x00000000}},	// [9cc0] нжаң_, subk, --, --, 
   {{0x737400c7,0x00000000,0x00000000,0x00000000}},	//   лыхх, --, --, --, 
   {{0x76440055,0x00000000,0x00000000,0x00000000}},	//   _grhy, --, --, --, 
   {{0xd24c8160,0xa2bc00dc,0x216800c7,0x00000000}},	//   تنم_, वेष्, ьиеи_, --, 
   {{0xddcc012d,0xaf4800e5,0xe4740153,0x00000000}},	//   żdżo, کشنل_, _рунэ, --, 
   {{0x920400e2,0xfe780352,0xe0d000eb,0x00000000}},	//   _stāš, нүз_, ারেন, --, 
   {{0xa2bc193d,0x3240001f,0xfdc821f3,0x00000000}},	//   वेश्, _የሚኖሩ, нтиқ_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd1b002f2,0x16ac07af,0x00000000,0x00000000}},	//   _ئینک, _टर्ब, --, --, 
   {{0x1ea81fbb,0x6444009b,0xa2d40882,0x3b542766}},	//   _قاضي_, _mrki, मुच्, укор, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x64448161,0x394c04d4,0x996400f7,0xaea000cf}},	//   _orki, ñes_, ттол, _دەىي, 
   {{0xb4b0000d,0x9f400cad,0x00000000,0x00000000}},	//   _ओरे_, _ìkó_, --, --, 
   {{0x87040724,0xc3080eac,0x386c0135,0x00000000}},	//   иясе, র্তি_, ġer_, --, 
   {{0xccdc037e,0x386c01ef,0x00000000,0x00000000}},	//   _mm目_, šer_, --, --, 
   {{0x64440e3c,0x39148162,0xb2740116,0xda44009d}},	//   _brki, _смир, ңлаш, _зүүж_, 
   {{0x3eac01bf,0x83f800d8,0x37dc00cc,0x00000000}},	// [9cd0] _lydt_, кетс_, _বিকৰ, --, 
   {{0x78ac2939,0x64440841,0x842400d1,0x764003cd}},	//   _iyav, _drki, شىمن, ålys, 
   {{0x64448163,0xa2bc02ab,0x3eac00b5,0x78ac00cd}},	//   _erki, वेल्, _nydt_, _hyav, 
   {{0xc1047a3f,0x644401fa,0x78ac0a49,0x00000000}},	//   لومي, _frki, _kyav, --, 
   {{0x753c009a,0xdce0041a,0x644400f3,0xd4980261}},	//   _iasz, _zloć, _grki, _црн_, 
   {{0x753c00f8,0xa2bc61b8,0xb8e4031c,0xc34800fd}},	//   _hasz, _वृक्, _ཏཻ_, _иясе_, 
   {{0x753c295f,0x78ac04ba,0x0ad001d3,0xd2540244}},	//   _kasz, _lyav, یحدگ, _جیاش_, 
   {{0x64440579,0xad24004b,0x78ac8164,0x753c0210}},	//   _yrki, ارغو, _oyav, _jasz, 
   {{0xcfa87c04,0x40348165,0x753c3ec0,0x78ac8166}},	//   _قائم_, _кетс, _masz, _nyav, 
   {{0x753c5909,0xcb8021f3,0x27e4036e,0xce6801f0}},	//   _lasz, рвоқ, _çoni_, _оред_, 
   {{0x78ac8167,0xce303016,0x6a845dc0,0x6574035b}},	//   _ayav, _خواک, улна, yhyh, 
   {{0x753c14cf,0x78ac8168,0x8c4400d1,0x9f400ca8}},	//   _nasz, _byav, _аҗиз_, _ìkò_, 
   {{0x291c0034,0xa2a80490,0x888404fb,0x78ac8169}},	//   ęta_, _जुन्, شیدن, _cyav, 
   {{0xdce00841,0x95c4023b,0x78ac00b8,0x64a4242d}},	//   _ploć, ғлуб_, _dyav, ҳаба, 
   {{0x46a40c2e,0x78ac816a,0x753c58a5,0xdb2001d3}},	//   _खुशह, _eyav, _basz, _óráb, 
   {{0x64a40209,0x4adc08a3,0x6d5c01f4,0x00000000}},	//   габа, पुरव, ösah, --, 
   {{0xe3b8816b,0x78ac0399,0xa4440220,0x68f40175}},	// [9ce0] еба_, _gyav, ынад, _ieyd, 
   {{0x68f403be,0x64a40032,0x644401a6,0x637009e8}},	//   _heyd, _ҡана, _vrki, _bæna, 
   {{0x6144816c,0x68f401d9,0x7ddc00e4,0x1718008f}},	//   лежа, _keyd, _oĩsa, _אויע, 
   {{0x673c816d,0x3eac045f,0x68f40455,0x27f00af9}},	//   _hapj, _rydt_, _jeyd, _kwyn_, 
   {{0x68f4816e,0x6444816f,0x673c8170,0xd0d40212}},	//   _meyd, _urki, _kapj, удії_, 
   {{0x27f00cfd,0x8fa08171,0xdce000e4,0x753c033f}},	//   _mwyn_, баче, _imoĩ, _zasz, 
   {{0x09cc35e8,0x673c7a41,0x27f00042,0x91e00166}},	//   _संगठ, _mapj, _lwyn_, _госе, 
   {{0x44208172,0x61fc8173,0x9f9400af,0xdfd05298}},	//   oti_, mspl, lüüs_, _هير_, 
   {{0x61fc8174,0xdee4016c,0xfaf802b5,0x261c015d}},	//   lspl, _бози, taī_, hïo_, 
   {{0x673c00dd,0x78ac01b2,0xda780b2c,0x9f940037}},	//   _napj, _ryav, еям_, nüüs_, 
   {{0x44208175,0x68f48176,0xa2a80316,0x2eb401d9}},	//   hti_, _beyd, _जुम्, _پێٹھ_, 
   {{0xddb405d3,0x61fc8177,0xc1cc1c5c,0x68f48178}},	//   _صحاب, ispl, _ﺑﺎﺯﺍ, _ceyd, 
   {{0x753c8179,0x68f4006c,0x4420817a,0x58843e25}},	//   _rasz, _deyd, jti_, уына, 
   {{0x61fc817b,0x4420817c,0x78ac817d,0x27f00368}},	//   kspl, dti_, _vyav, _dwyn_, 
   {{0x68f4817e,0x27f0817f,0x753c8180,0x61fc6864}},	//   _feyd, _ewyn_, _pasz, jspl, 
   {{0x44208181,0x61fc1455,0x27f0015d,0x637003b2}},	//   fti_, dspl, _fwyn_, _ræna, 
   {{0x44208182,0x78ac0163,0x27f000a9,0x61fc0115}},	// [9cf0] gti_, _uyav, _gwyn_, espl, 
   {{0x2d8000dd,0x753c0034,0xc1cc0952,0xc308015b}},	//   éhez_, _wasz, _ﺑﺎﺭﺍ, র্সি_, 
   {{0x44208183,0xdce00588,0x2460013f,0xdb080332}},	//   ati_, _emoĩ, rɔma_, _bhfú, 
   {{0x44208184,0x673c8185,0x51a82a8b,0x68f48186}},	//   bti_, _zapj, رداپ_, _xeyd, 
   {{0x44208187,0x61fc0254,0x673c00a2,0xe4f8011a}},	//   cti_, aspl, _yapj, _בפרש, 
   {{0x63700579,0xa0640398,0x60600131,0x61fc7e42}},	//   _tæna, раша_, غۇلل, bspl, 
   {{0xff046156,0xa24401ed,0x60d40153,0x61fc03ac}},	//   сячн, _پینل_, žyma, cspl, 
   {{0x51848188,0xd1b801d9,0xe184008e,0xbe4800f1}},	//   _суга, _سازا_, _көче_, اشوم_, 
   {{0xeb988189,0x68f4818a,0xcdcc00f1,0x6c74009d}},	//   кии_, _reyd, _کښت_, руйх, 
   {{0x27f0015d,0xdfa00137,0x69c401d3,0xcd440092}},	//   _rwyn_, _وڭوي, _éhez, ናችኋለ, 
   {{0x4420818b,0x68f4818c,0x673c0477,0x27f00042}},	//   zti_, _peyd, _rapj, _swyn_, 
   {{0x4420818d,0x6844818e,0x68f411a9,0xa9a4818f}},	//   yti_, анма, _qeyd, римд, 
   {{0x44208190,0x68f40139,0x61fc8191,0x00000000}},	//   xti_, _veyd, zspl, --, 
   {{0x68f40a81,0x44208192,0xaa44030d,0x00000000}},	//   _weyd, vti_, _векл, --, 
   {{0x24f4764a,0x44208193,0x9660262e,0x25a88194}},	//   ичар, wti_, окре, ندري_, 
   {{0x44208195,0x27f00142,0x261c0142,0x61f88196}},	//   tti_, _twyn_, rïo_, _ætli, 
   {{0x638405f5,0x691c09a8,0xd464721f,0x6fa40073}},	// [9d00] агаа, _všeč, аите_, खकां, 
   {{0x37dc0183,0x261c03cb,0xd7f8011a,0x00000000}},	//   _বিচৰ, pïo_, _שהיל, --, 
   {{0x4aa8069f,0x995800e8,0xd24c00c6,0x224400b0}},	//   _घुमव, _bëň_, ونك_, āoko_, 
   {{0x61fc8197,0xf1a88198,0xe04400c7,0x00000000}},	//   rspl, هانه_, инеи, --, 
   {{0x44208199,0x61fc1730,0xd12c819a,0x74b80117}},	//   qti_, sspl, ظمه_, _бурс_, 
   {{0x9e04819b,0x00000000,0x00000000,0x00000000}},	//   ачил, --, --, --, 
   {{0xdd98819c,0x9f4400d5,0x2cb00213,0xb3540066}},	//   кши_, npoé_, əzdi_, _دیلا_, 
   {{0x21745950,0xd24c00e5,0x00000000,0x00000000}},	//   _тугр, _کچے_, --, --, 
   {{0xa2a800bc,0x00000000,0x00000000,0x00000000}},	//   _जुत्, --, --, --, 
   {{0x81c40521,0xff2400f1,0x81cc00cc,0x65600108}},	//   _ịchọ_, _دبری, _শৌচ_, öohj, 
   {{0xddc400b8,0x00000000,0x00000000,0x00000000}},	//   _aṃśe_, --, --, --, 
   {{0xcc84096d,0x2124031c,0x9f4400a2,0x00000000}},	//   انیه_, nfoh_, msoñ_, --, 
   {{0xc864524d,0x6f0c01e7,0x48140395,0x00000000}},	//   отри, _íocó, омяс, --, 
   {{0x6d5c0847,0x00000000,0x00000000,0x00000000}},	//   ösav, --, --, --, 
   {{0xb9e40228,0xc668084c,0x00000000,0x00000000}},	//   _اتتۇ, аште_, --, --, 
   {{0x94a801f7,0x00000000,0x00000000,0x00000000}},	//   ناءِ_, --, --, --, 
   {{0x7af80218,0xf9f804c5,0xd838084c,0x3374136b}},	// [9d10] _kevt, _অমিল_, _рэй_, бгар, 
   {{0x7af8819d,0x34941b74,0xddcc01f1,0x00000000}},	//   _jevt, _ҳамр, ždňo, --, 
   {{0xa2c07853,0x00000000,0x00000000,0x00000000}},	//   зәтк, --, --, --, 
   {{0x6370819e,0x92d4015b,0x307400d1,0x103001b9}},	//   _fæno, সরে_, йулс, قبتگ, 
   {{0xae18033f,0x00000000,0x00000000,0x00000000}},	//   नूनन_, --, --, --, 
   {{0x7af8819f,0x712400d1,0x643800df,0x00000000}},	//   _nevt, _گىرم, _געשנ, --, 
   {{0xdd8c00aa,0xd1380022,0xc0c00023,0x41e40153}},	//   کوي_, _иха_, _ስዉር_, _міта, 
   {{0x06980375,0x1fe40154,0x9fe405ac,0x00000000}},	//   ידום_, _নিরস, _নিৰগ, --, 
   {{0x3200010e,0x00000000,0x00000000,0x00000000}},	//   lshy_, --, --, --, 
   {{0x4ea481a0,0x6b5481a1,0xa2bc1b61,0x4e88005b}},	//   _креа, стих, वेक्, _ищем_, 
   {{0xa96881a2,0x7af80477,0x7c644973,0x00000000}},	//   гина_, _devt, مایل, --, 
   {{0x598008db,0x3200045a,0xf768011a,0x00000000}},	//   злюб, ishy_, _אק_, --, 
   {{0xab2881a3,0x9cd800c8,0x2198010f,0x6d5c01f4}},	//   _бола_, _עקספ, רברא, ösau, 
   {{0x2d8c81a4,0x6a2400f2,0x00000000,0x00000000}},	//   liee_, _هفتم, --, --, 
   {{0xeac403d4,0x00000000,0x00000000,0x00000000}},	//   _শ্ৰম, --, --, --, 
   {{0x2d8c81a5,0xeaf805d9,0xdb1801a8,0x7e7c0790}},	//   niee_, _شرڪت_, mmtá, _ürpe, 
   {{0x32000204,0x7af80477,0x69c4002f,0x00000000}},	// [9d20] eshy_, _yevt, mmke, --, 
   {{0x69c4045f,0x256c00d7,0xdb0c0174,0xd5e400fe}},	//   lmke, _mýli_, ádøm, _ফিৰঙ, 
   {{0xe5a481a6,0x2d8c0270,0x69c4257c,0x5af8010f}},	//   _гини, kiee_, omke, רלעצ, 
   {{0x716481a7,0xa5740014,0x387c03e0,0x2e2002d2}},	//   يانك, _چُھت, _özrü_, dóf_, 
   {{0x2d8c0af9,0x32000076,0x20880166,0x00000000}},	//   diee_, ashy_, ыйди_, --, 
   {{0x656401af,0x72d40014,0x8fa00835,0x00000000}},	//   _hokh, _وُٕچ, паче, --, 
   {{0x656481a8,0x63ac05b1,0x2d8c81a9,0x7afc022e}},	//   _kokh, _ikbn, fiee_, аrtn, 
   {{0x656481aa,0x256c0bcd,0x7af86a37,0x7cd8024c}},	//   _jokh, _býli_, _sevt, шмир_, 
   {{0x656481ab,0x20541614,0x8c400120,0x5ba400d4}},	//   _mokh, _утвр, зење, йроз, 
   {{0x656481ac,0xd24c01d9,0x69c4002d,0x2d8c0076}},	//   _lokh, _تنہ_, emke, aiee_, 
   {{0x7af80158,0x2d8c009f,0x656481ad,0xbda400db}},	//   _vevt, biee_, _ookh, _وڭبو, 
   {{0x656481ae,0x61f80008,0xbebc00ef,0xd2b4011a}},	//   _nokh, _ætlu, _acīg, מלית_, 
   {{0xf3f4031c,0x7af80010,0x98a8054e,0x272000fe}},	//   _བསེད_, _tevt, decă_, য়নো_, 
   {{0x69c4002d,0xbb480451,0x8c180a7c,0x00000000}},	//   amke, _ضلعن_, _עווי, --, 
   {{0x656481af,0x1368013e,0x478800d4,0x0c800092}},	//   _bokh, қшаи_, ссям_, ርጋለች_, 
   {{0x64480421,0x65640051,0x14c80022,0xb7d8210e}},	//   āfin, _cokh, гызи_, _پودا_, 
   {{0x656481b0,0x34943cdf,0x981447e7,0x058400d1}},	// [9d30] _dokh, цаар, _ابعا, чурм, 
   {{0xc04c0023,0x65b80022,0x80ac012d,0x00000000}},	//   _ሞራላው, rïha, _जड़े, --, 
   {{0x656401d3,0xf2380150,0x00000000,0x00000000}},	//   _fokh, рпеш_, --, --, 
   {{0x3200010b,0x91b4036b,0x3d142c35,0x656481b1}},	//   rshy_, ёҳат_, _धागे_, _gokh, 
   {{0x6e2081b2,0x3200037e,0xdcec0118,0xdb181d0e}},	//   _sqlb, sshy_, žděl, mmtæ, 
   {{0x65640925,0x2d8c013f,0xc20815bf,0xdd8c0050}},	//   _zokh, wiee_, شقۇن_, ێوو_, 
   {{0x656481b3,0x69c40589,0x1fe4015b,0x2d8c0076}},	//   _yokh, ymke, _নিঃস, tiee_, 
   {{0xac080588,0x27e40098,0x2e2001a8,0x00000000}},	//   аниа_, _éong_, róf_, --, 
   {{0x1c402b41,0x2d8c81b4,0xbbe80bce,0xc10400e3}},	//   дным, riee_, یریم_, _رولي, 
   {{0x2d8c016b,0xc0240150,0xae180412,0x00000000}},	//   siee_, _ءىلي, नंदन_, --, 
   {{0xeab00597,0x6fe000bd,0x6e9401d3,0x2d8c017a}},	//   بعة_, _নিয়ে, _بلاا, piee_, 
   {{0x3a9834d8,0x6dc00137,0x69c40c6a,0x0dc881b5}},	//   стью_, _تۅبۅ, umke, _сузи_, 
   {{0x2d9c00ca,0x69c4010f,0xa13800df,0x3da801f7}},	//   _ijwe_, rmke, בערח, _اُنَ_, 
   {{0x656481b6,0x8bc40305,0x442400b8,0x00000000}},	//   _sokh, _усед, _īm_, --, 
   {{0x6564055a,0x998400d0,0x98a8054e,0x44240064}},	//   _pokh, žiša_, tecă_, _ūm_, 
   {{0x4a700220,0x7c24054e,0x62f403d4,0x24083594}},	//   _мықт, _ţiri, _চাইট_, инби_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [9d40] --, --, --, --, 
   {{0x656449e1,0x47f401f0,0x3ea00205,0x00000000}},	//   _wokh, _мӯҳр, şiti_, --, 
   {{0xe0d881b7,0x656481b8,0x3f980139,0x00000000}},	//   аве_, _tokh, _ıru_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x442404c4,0xa2a844ab,0xe04400d1,0x9fc80114}},	//   _ëm_, _जुर्, юнди, агда_, 
   {{0xdce0456f,0x20200023,0xbf0400cd,0x00000000}},	//   _bloğ, _ዳይረክ, रणेन_, --, 
   {{0x6370005c,0x00000000,0x00000000,0x00000000}},	//   _lænk, --, --, --, 
   {{0x7bf80116,0xa0683edd,0xa0a481b9,0x00000000}},	//   бнир_, _каба_, _дабд, --, 
   {{0xe8140cb4,0x244c001f,0xdce006be,0x00000000}},	//   _तमगा_, _ሃላፊነ, _eloğ, --, 
   {{0x6d5c3167,0x28ac012d,0x00000000,0x00000000}},	//   ösar, _घड़ि, --, --, 
   {{0xa2bc4d21,0xda640451,0x3eb801d3,0xbdf8211f}},	//   वेच्, زادي, _árt_, _چرچا_, 
   {{0x6370037e,0x9cc82eca,0xf8b801e0,0x00000000}},	//   _bænk, _кыла_, йөп_, --, 
   {{0x36d4005b,0x23a82c2e,0xd7f80063,0xed34009d}},	//   зогр, कवाद, јум_, _хэхэ, 
   {{0x7d0081ba,0x167001a9,0x00000000,0x00000000}},	//   lams, дқор, --, --, 
   {{0xd5645b0f,0x8624005b,0xa2a82982,0xdd2400ef}},	//   отап, мьте, _जुल्, _mūžz, 
   {{0x7bc80009,0x6600012d,0x1dc800cd,0x00000000}},	//   lmdu, _łokc, ागित, --, 
   {{0x798c81bb,0x386c01c7,0x92e807d6,0x00000000}},	// [9d50] _imaw, äerd_, لراق_, --, 
   {{0x7bc8020c,0xdbd4005b,0x970000d1,0x00000000}},	//   nmdu, mään, _زېرى, --, 
   {{0x7d0081bc,0xd258074d,0xdbd40821,0x1dc807b7}},	//   kams, шца_, lään, ागात, 
   {{0xf55881bd,0x88b0016b,0x7bc881be,0x7d00110c}},	//   _الحب_, _abɛy, hmdu, jams, 
   {{0x798c0bd7,0xdbd4005b,0xa5c0010b,0x00000000}},	//   _mmaw, nään, _чөре, --, 
   {{0xd7a81524,0x718401d9,0x03f80114,0x339800ec}},	//   चकिच, _کٔرن, _фнрј_, _اچرج_, 
   {{0x798c81bf,0xee3822f7,0x7d0003cb,0xdbd40108}},	//   _omaw, ёни_, fams, hään, 
   {{0x7d0081c0,0xdbd46775,0x417407d2,0x256c032e}},	//   gams, kään, _قاقس, _fýlu_, 
   {{0xdbd400af,0x272000fe,0x637002d2,0x0094008e}},	//   jään, য়তো_, _bænh, _житэ, 
   {{0x20200020,0x798c81c1,0x3f14026a,0xd1bc0092}},	//   _ዳይሬክ, _amaw, _одус, ቴዎች_, 
   {{0x6370037e,0x7d0081c2,0x2d9c0100,0xc3080154}},	//   _sænk, bams, _tjwe_, র্কি_, 
   {{0xac183c1b,0xdb080597,0xfd64063f,0xad241a50}},	//   _году_, _bhfó, _mawụ, _ءىشى, 
   {{0xdce0009b,0x02b8584e,0x00000000,0x00000000}},	//   _glođ, _अर्न, --, --, 
   {{0x6498052f,0x798c81c3,0x00000000,0x00000000}},	//   ҡтар_, _emaw, --, --, 
   {{0xfbd03251,0x10840ed1,0x28ac0073,0x00000000}},	//   _شته_, ﺪﺍﺭﯨ, _घडवि, --, 
   {{0x6370019b,0xa8040e46,0x38c40171,0xe8f800f3}},	//   _tænk, _езил, _būrī_, _ули_, 
   {{0x82e80135,0x00000000,0x00000000,0x00000000}},	// [9d60] _ཧྥུའ, --, --, --, 
   {{0x290081c4,0x04fc00bd,0x69d481c5,0xb86400aa}},	//   laka_, ইলের_, _hiye, _ځایو, 
   {{0xdce009a8,0xa6c80ccb,0xd6d8011a,0x00000000}},	//   _sooč, _دودل_, _לחיל, --, 
   {{0x290081c6,0x69d481c7,0xdce0031c,0x637002d2}},	//   naka_, _jiye, _omoġ, _mæni, 
   {{0x69d481c8,0x7d0081c9,0xfbe002f5,0x29000109}},	//   _miye, vams, _মৌনত, iaka_, 
   {{0x6ed80046,0x7d0061b5,0x2d80036e,0x00000000}},	//   يدىڭ_, wams, ëhen_, --, 
   {{0x7d0081ca,0xdce000e4,0x00000000,0x00000000}},	//   tams, _amoġ, --, --, 
   {{0x290081cb,0x69d481cc,0xbebc0055,0xd298011a}},	//   jaka_, _niye, _acīc, _השלט, 
   {{0x5ea481cd,0x7d0081ce,0xf15002f2,0x00000000}},	//   _کمال, rams, _جێند, --, 
   {{0x7d0081cf,0xd9b4043e,0x69d40ca8,0x3f8c81d0}},	//   sams, ृष्ट, _aiye, _umdu_, 
   {{0x29006580,0x7d0081d1,0x34b81408,0x00000000}},	//   faka_, pams, _आर्द, --, 
   {{0x644800da,0x2900731f,0xdc28034c,0xdbd481d2}},	//   āfij, gaka_, _هسته_, tään, 
   {{0x69d481d3,0x200481d4,0x24e000eb,0x00000000}},	//   _diye, nsoi_, বরাহ, --, 
   {{0x69d40086,0x290000e4,0x3f9c03b2,0x798c0210}},	//   _eiye, aaka_, nnvu_, _wmaw, 
   {{0x290081d5,0x69d481d6,0x68ec145e,0xdbd416ca}},	//   baka_, _fiye, êndâ, rään, 
   {{0x69d481d7,0x798c81d8,0x2900601a,0x95c82ecb}},	//   _giye, _umaw, caka_, суга_, 
   {{0x3f9c0083,0xdbd4005b,0x55c00116,0x00000000}},	// [9d70] knvu_, pään, даңғ, --, 
   {{0x69d481d9,0xd2580953,0x4814013d,0x00000000}},	//   _ziye, йце_, _ямьс, --, 
   {{0x799c0c8c,0xd36c0145,0x00000000,0x00000000}},	//   onsw, نۇڭ_, --, --, 
   {{0x69d40c11,0xd34400aa,0x3f9c0083,0x799c002f}},	//   _xiye, _ډیره_, envu_, nnsw, 
   {{0xb4d80833,0x752c6ae5,0x799c33d5,0x00000000}},	//   ाशी_, mfaz, insw, --, 
   {{0x290081da,0x00000000,0x00000000,0x00000000}},	//   zaka_, --, --, --, 
   {{0x6da40588,0xee3800d6,0xada481db,0xf19401f4}},	//   мика, іни_, макл, _живь, 
   {{0x29000c11,0x3f9c0083,0x799c01a4,0x0c6400d1}},	//   xaka_, anvu_, jnsw, ззиқ_, 
   {{0x290081dc,0x69d4003e,0xe50c04af,0x00000000}},	//   vaka_, _riye, िणति_, --, 
   {{0x2900580c,0x752c0369,0x6370003a,0x3af41f42}},	//   waka_, hfaz, _pæni, няюс, 
   {{0x290081dd,0x69d481de,0x2fc40076,0xa9a481df}},	//   taka_, _piye, _ihlg_, динд, 
   {{0x799c035a,0x637002d2,0x00000000,0x00000000}},	//   gnsw, _væni, --, --, 
   {{0x290081e0,0x6d480072,0x69d481e1,0xc308015b}},	//   raka_, mdea, _viye, র্টি_, 
   {{0x290081e2,0x6d480323,0x799c81e3,0x69d401b2}},	//   saka_, ldea, answ, _wiye, 
   {{0x752c0395,0xa96881e4,0x69d481e5,0x38c40374}},	//   ffaz, _мика_, _tiye, _rūrū_, 
   {{0x6d4881e6,0x290000fb,0x60d40006,0x81e40154}},	//   ndea, qaka_, žymi, পীড_, 
   {{0x6d4850c2,0x6d5881e7,0x26dc01e4,0x232801a9}},	// [9d80] idea, _mnwa, ɾton_, жози_, 
   {{0x6d4881e8,0x6574011c,0x6d58035a,0x61a481e9}},	//   hdea, skyh, _lnwa, गक्ष, 
   {{0xa6c80cd2,0x6d585337,0x02c4009d,0x069400e5}},	//   _گوگل_, _onwa, хижү, _سادھ, 
   {{0x6d5881ea,0x200481eb,0xb86400cf,0x00000000}},	//   _nnwa, tsoi_, _زاۋو, --, 
   {{0x25a00332,0x12f400d1,0x00000000,0x00000000}},	//   _ijkl_, ستەھ, --, --, 
   {{0x6d582f05,0x200403a2,0xd1b001d5,0xc3080154}},	//   _anwa, rsoi_, _ییلک, র্জি_, 
   {{0x20040395,0x6d5803ac,0x6d4800e2,0x9e640214}},	//   ssoi_, _bnwa, fdea, باشن, 
   {{0x6d4881ec,0x2fc481ed,0x6d5803ac,0xfcc4070e}},	//   gdea, _ehlg_, _cnwa, нәлм, 
   {{0x6d5803ac,0xdee401b9,0xdb1803b2,0x00000000}},	//   _dnwa, _жози, mmtú, --, 
   {{0x6d5881ee,0x6d4881ef,0x799c81f0,0x00000000}},	//   _enwa, adea, wnsw, --, 
   {{0x6d480369,0x6d580857,0x80b0009e,0x5fa000d1}},	//   bdea, _fnwa, জেশ্, _كەچم, 
   {{0x7f48047e,0x6da00421,0x799c01c7,0x752c0175}},	//   _hadq, lēan, unsw, xfaz, 
   {{0x58840184,0x799c02d0,0x6370032e,0x7c34030d}},	//   фына, rnsw, _hænu, _челх, 
   {{0x61ec03ac,0x6d5802d0,0x637002d2,0x8c400114}},	//   _otbl, _znwa, _kænu, _реље, 
   {{0x7f4881f1,0xfc48004d,0x67380037,0x00000000}},	//   _madq, _hử_, õtja, --, 
   {{0x7bd83209,0x7f48014f,0xb4d8041c,0x6d5802d0}},	//   _hivu, _ladq, ाशे_, _xnwa, 
   {{0x7bd881f2,0xb35481f3,0x752c01c4,0xd404030d}},	// [9d90] _kivu, нкаш, rfaz, ьяви, 
   {{0x752c81f4,0xdce00327,0x7bd8047e,0x61ec0175}},	//   sfaz, _fmoħ, _jivu, _btbl, 
   {{0x6d4881f5,0x394881f6,0x51840364,0x7bd8556c}},	//   ydea, _kaas_, муда, _mivu, 
   {{0x76444c99,0x394800e8,0x7f480014,0xdbd40108}},	//   _ishy, _jaas_, _aadq, _hääj, 
   {{0x394881f7,0x7f480009,0x7fe805af,0x6d5802d0}},	//   _maas_, _badq, وروف_, _rnwa, 
   {{0x7bd881f8,0x394881f9,0x63700008,0x6d5802d0}},	//   _nivu, _laas_, _bænu, _snwa, 
   {{0x6d4881fa,0x7f48058a,0x39480254,0x6d5802d0}},	//   tdea, _dadq, _oaas_, _pnwa, 
   {{0x764400ca,0xad240075,0x7f48035a,0x00000000}},	//   _mshy, رىخى, _eadq, --, 
   {{0x7bd881fb,0xfc480016,0x9ed481fc,0xeb9881fd}},	//   _bivu, _cử_, ммәт_, зип_, 
   {{0x6d480e89,0x764401a9,0xfc480051,0xea8800d8}},	//   sdea, _oshy, _dử_, збол_, 
   {{0x7bd881fe,0x764401aa,0x39482813,0x1ee82a60}},	//   _divu, _nshy, _baas_, _رونی_, 
   {{0x6d5881ff,0xfd1004d3,0x39488200,0x606000cf}},	//   _unwa, _نجه_, _caas_, _جۇۇل, 
   {{0x76448201,0x6f000086,0x39488202,0x6370005c}},	//   _ashy, _kelc, _daas_, _kænt, 
   {{0x7bd81418,0x6f008203,0x00000000,0x00000000}},	//   _givu, _jelc, --, --, 
   {{0x39488204,0xfb240014,0xe69401d5,0xfcf80092}},	//   _faas_, _شروپ, رلرد, _ወስጥ_, 
   {{0xe8f88205,0x316c0165,0x63700162,0xb9040154}},	//   _эли_, _noez_, _lænt, _পড়_, 
   {{0x66e462bd,0xfc4807ae,0x7bd88206,0x76440731}},	// [9da0] _попа, _xử_, _yivu, _eshy, 
   {{0x7bd806e4,0x2d800240,0x399800e4,0x6f0015c0}},	//   _xivu, ëhej_, rũse_, _nelc, 
   {{0xe1f08207,0x08e401ec,0x00000000,0x00000000}},	//   اسئ_, _ﺍﯞﻩﺯ, --, --, 
   {{0x39480014,0x7f48058a,0x072000c5,0xa878010f}},	//   _xaas_, _sadq, _बाँव_, ּאַר, 
   {{0x6f0011ce,0xf1d48208,0x834400c7,0xe0d001e4}},	//   _belc, төрө, _иҭаз, reϲo_, 
   {{0x6f008209,0x7f48820a,0x7644820b,0x00000000}},	//   _celc, _qadq, _yshy, --, 
   {{0xfc4801dc,0x53a0820c,0x7bd8820d,0x6f00820e}},	//   _sử_, _сарб, _rivu, _delc, 
   {{0x7bd8820f,0x6f008210,0x63700413,0x7d54011c}},	//   _sivu, _eelc, _vænu, твих, 
   {{0x10a08211,0x7f4807d6,0x7bd80194,0x6f008212}},	//   _битн, _tadq, _pivu, _felc, 
   {{0xcc305cb5,0x64448213,0x637003b2,0x7f4803ac}},	//   اريع, _mski, _tænu, _uadq, 
   {{0x7bd88214,0x39488215,0x6370032e,0x25b08216}},	//   _vivu, _paas_, _hæns, koyl_, 
   {{0xfc4801dc,0x6444014b,0x39480067,0x7bd88217}},	//   _tử_, _oski, _qaas_, _wivu, 
   {{0xb90819e5,0x39488218,0x7bd88219,0x6f000036}},	//   _बल_, _vaas_, _tivu, _yelc, 
   {{0x3948821a,0xc30803d4,0xa02c0092,0xcb6454d9}},	//   _waas_, ৰ্তি_, _ሰውነታ, _паче_, 
   {{0x3948821b,0xb59465cb,0x6444821c,0xccd00124}},	//   _taas_, вивш, _aski, _ицәы, 
   {{0x94841411,0x499400f2,0x00000000,0x00000000}},	//   нызд, _میپر, --, --, 
   {{0xa5080075,0xc7e81e4a,0x6370005c,0x00000000}},	// [9db0] بىقە_, _كىين_, _næns, --, 
   {{0x889c0302,0x316c0789,0x04c82984,0x333800f2}},	//   _מבחי, _soez_, رولي_, بزرگ_, 
   {{0x7644821d,0x316c0139,0x00000000,0x00000000}},	//   _ushy, _poez_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x64440198,0x6f00821e,0x00e40212,0x00000000}},	//   _gski, _pelc, ужін, --, 
   {{0x7ff4821f,0x6f00014f,0x5f880014,0x00000000}},	//   اسنا, _qelc, وٕنہ_, --, 
   {{0x637009cc,0x00000000,0x00000000,0x00000000}},	//   _vænt, --, --, --, 
   {{0x6f005e65,0x8d240116,0x64440108,0x00000000}},	//   _welc, хниң_, _yski, --, 
   {{0x6f008220,0x637003b2,0xe570010f,0x00000000}},	//   _telc, _tænt, יַז_, --, 
   {{0x5f3400c7,0x6f0003ac,0x25b001a9,0x00000000}},	//   _идуӡ, _uelc, zoyl_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x853003f9,0x00000000,0x00000000,0x00000000}},	//   kiɗa, --, --, --, 
   {{0x26dc01e4,0x88c8013a,0xab2833ea,0x00000000}},	//   ɾtoj_, _otěž, _жола_, --, 
   {{0x1ae08221,0xc5f80032,0x64440162,0x0ba4013d}},	//   _кошм, нғо_, _rski, _яшем, 
   {{0xd6248222,0x644400d8,0xaa4401f4,0x9b400345}},	//   коре_, _sski, _рейл, _ئۆپو, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x29108223,0xa3d40490,0xa2e40a93,0x63a01e54}},	// [9dc0] _idya_, _हळद_, возд, éono, 
   {{0x27f0003a,0x00000000,0x00000000,0x00000000}},	//   _ityn_, --, --, --, 
   {{0xe5a40022,0x63700008,0xd12c00ec,0x614401ec}},	//   _аини, _sæns, ڪمن_, кежа, 
   {{0x64448224,0x8f500f1c,0xa3e80f5c,0x00000000}},	//   _tski, یننش, _одма_, --, 
   {{0xd12c8225,0x64448226,0x40340046,0x2910020c}},	//   تمن_, _uski, уелс, _mdya_, 
   {{0x44208227,0x38bc00c6,0xdde8015e,0x637008a5}},	//   mui_, lárú_, وربه_, _væns, 
   {{0x44208228,0x3d942ec9,0x1798010f,0x9f800051}},	//   lui_, ликр, ויסב, _vưà_, 
   {{0x29108229,0x4420822a,0x3ea00276,0x637003b2}},	//   _ndya_, oui_, ăit_, _tæns, 
   {{0x4420822b,0xdb180036,0x50400026,0xddc801d3}},	//   nui_, llté, _кетб, ínűs, 
   {{0x442004fe,0x2910822c,0xec3401d9,0x00000000}},	//   iui_, _adya_, دوٝگ, --, 
   {{0x9a84822d,0x1d240124,0x53180a1e,0x27f073b0}},	//   тупл, _амем, וויצ, _atyn_, 
   {{0xd83801c0,0x386c0108,0x00000000,0x00000000}},	//   мэг_, äero_, --, --, 
   {{0x4420822e,0x96e8822f,0x00000000,0x00000000}},	//   jui_, дьба_, --, --, 
   {{0x29100432,0xd76001ed,0x9b680024,0x00000000}},	//   _edya_, جنسی, _ішла_, --, 
   {{0x7c200066,0x09e00798,0x00000000,0x00000000}},	//   lumr, _којн, --, --, 
   {{0x44208230,0x88c8012c,0x78747a13,0x75ac0073}},	//   fui_, _stěž, _مُبا, चवेळ, 
   {{0x44208231,0x7c208232,0xa000015b,0x45d48233}},	// [9dd0] gui_, numr, _উৎসব_, ротс, 
   {{0x9f988234,0xbebc00e2,0x2848010f,0x00000000}},	//   _jään_, _acīm, _טעפּ, --, 
   {{0xd1640724,0xc8b48235,0x4420003a,0xd8e40150}},	//   къди, _مصیب, aui_, _ﺍﯞﻩﻟ, 
   {{0x44208236,0x661802fb,0xf0e80131,0xdd842e0b}},	//   bui_, átke, رىتى_, _طو_, 
   {{0x44208237,0x94848238,0x290c0134,0x00000000}},	//   cui_, _рынд, _ɛfa_, --, 
   {{0x9f980108,0x63180011,0x00000000,0x00000000}},	//   _nään_, ন্বয়_, --, --, 
   {{0x43948239,0xa8040124,0x22a4014b,0x00000000}},	//   _тарс, _kuñá, _бутҳ, --, 
   {{0x32080408,0x00000000,0x00000000,0x00000000}},	//   ăхĕн_, --, --, --, 
   {{0x7c20209c,0x00000000,0x00000000,0x00000000}},	//   gumr, --, --, --, 
   {{0xc0c8823a,0x5ba4823b,0x27f00076,0x00000000}},	//   _русе_, лкым_, _rtyn_, --, 
   {{0x4420823c,0xed3405f5,0xadf46582,0x7d28007c}},	//   zui_, _бэлэ, _спеш, ärsö, 
   {{0x3a980139,0xa9681188,0x442004ce,0xbdf8823d}},	//   ттью_, хима_, yui_, _شرما_, 
   {{0x7c64823e,0x44200393,0xbd88010f,0x597400f2}},	//   _ناول, xui_, _בעאַ_, ادپز, 
   {{0x4420823f,0x64a402dd,0xfba801e0,0xdc980677}},	//   vui_, қаза, _үтәй_, _אינל, 
   {{0x44208240,0x2a140153,0x00000000,0x00000000}},	//   wui_, _сьлё, --, --, 
   {{0x2cbc0175,0x4e1800bc,0x6ed400cd,0x00000000}},	//   _kywd_, _यिनै_, येयु, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [9de0] --, --, --, --, 
   {{0x63045fc4,0xeae0015b,0x70dc1025,0x00000000}},	//   اوال, _মজুম, यशैल, --, 
   {{0x44208241,0xa5088242,0x31e40736,0x955c0092}},	//   sui_, _пена_, لسنّ, ደሮችን_, 
   {{0x44208243,0x11d4007b,0x00000000,0x00000000}},	//   pui_, هولة_, --, --, 
   {{0x44208244,0x6448005f,0x74f801c6,0xe4d8009a}},	//   qui_, āfis, _шээс_, _سوست_, 
   {{0xd8d4008f,0xe2981bbc,0xa348013d,0xe7b400cd}},	//   אונט_, _заг_, _язга_, ृतिप, 
   {{0x95680020,0x69c402b5,0x4f840014,0x7e4800e5}},	//   _አለብን_, _īhen, دانہ, ئستہ_, 
   {{0x9f98005b,0x00000000,0x00000000,0x00000000}},	//   _sään_, --, --, --, 
   {{0xd1b00502,0x9f98023a,0xffc402dd,0x212401a9}},	//   _اینک, _pään_, _көкп, mgoh_, 
   {{0xff24669d,0x7c208245,0xd24c00dd,0x2124022e}},	//   _خبری, rumr, _بچے_, lgoh_, 
   {{0xee2800c6,0x7c208246,0x00000000,0x00000000}},	//   _لأنه_, sumr, --, --, 
   {{0x21248247,0x996405f5,0x98480006,0x7c20014f}},	//   ngoh_, утол, няга_, pumr, 
   {{0x7c2000aa,0x0c740214,0x9f9801f4,0x00000000}},	//   qumr, _مصوب_, _tään_, --, 
   {{0x394c39a4,0xdb2001e1,0x00000000,0x00000000}},	//   žes_, _ìràd, --, --, 
   {{0x36d40107,0x00000000,0x00000000,0x00000000}},	//   ровр, --, --, --, 
   {{0xbebc0055,0x38780419,0x00000000,0x00000000}},	//   _acīk, pysr_, --, --, 
   {{0xe8d00014,0x00000000,0x00000000,0x00000000}},	// [9df0] _وۅپھ, --, --, --, 
   {{0xa57400b7,0xf3144889,0xdec0010c,0x00000000}},	//   _ጊዮርጊ, рджэ, ስርን_, --, 
   {{0xd6d802bf,0x70dc07b7,0x00000000,0x00000000}},	//   _яти_, यश्ल, --, --, 
   {{0xc1048248,0x313402bf,0x9f440156,0x110400cf}},	//   مومي, редр, mpoù_, اباپ, 
   {{0xada40030,0x00000000,0x00000000,0x00000000}},	//   nkúš, --, --, --, 
   {{0x83840a89,0x66000210,0x00000000,0x00000000}},	//   _лысе, _łoki, --, --, 
   {{0xd138030d,0x00000000,0x00000000,0x00000000}},	//   _пха_, --, --, --, 
   {{0xed588249,0x463c008f,0xdd8c00e5,0x00000000}},	//   тои_, געהע, وڈن_, --, 
   {{0x78ac18f7,0xdd8c824a,0xcf2400ae,0x00000000}},	//   _nxav, بوي_, _مراي, --, 
   {{0xcb840131,0x6eac0210,0x00000000,0x00000000}},	//   امدۇ_, _जशपु, --, --, 
   {{0x78ac02c4,0x5ac4824b,0xdbc401c0,0x5fdc0ce0}},	//   _axav, ильм_, ргэд_, _फूटल, 
   {{0x69944929,0xa368022e,0x00000000,0x00000000}},	//   ррох, jmеn, --, --, 
   {{0x6b64824c,0xc8d002ab,0x4cd00154,0x00000000}},	//   _вкла, सेंट, _ধ্রু, --, 
   {{0x29e40421,0x21240007,0xeb9801c6,0x2244012d}},	//   _lēai_, zgoh_, _шил_, łoki_, 
   {{0x212401a9,0x09e000cc,0x00000000,0x00000000}},	//   ygoh_, _কৌৰৱ_, --, --, 
   {{0x64a4824d,0x00000000,0x00000000,0x00000000}},	//   ааба, --, --, --, 
   {{0xe3b80fc0,0x19b8011a,0x00000000,0x00000000}},	// [9e00] вба_, _במקב, --, --, 
   {{0xd7900472,0x1878011a,0x9878011a,0x00000000}},	//   _وليخ, _סטיב, _סריק, --, 
   {{0x171800c8,0xe21400cf,0x212401a9,0x00000000}},	//   _בויע, شباع, tgoh_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf1a8824e,0x212401d5,0x00000000,0x00000000}},	//   داله_, rgoh_, --, --, 
   {{0x8fa000a8,0xa6d80154,0x00000000,0x00000000}},	//   оаче, _ব্যয়, --, --, 
   {{0xe298824f,0xdda80798,0x00000000,0x00000000}},	//   _рав_, ктил_, --, --, 
   {{0x2d780882,0x91e08250,0x60940014,0x00000000}},	//   ṇena_, _фоте, _پۆتس_, --, 
   {{0x06c4009e,0x5ba4014b,0x6044010a,0x718801f0}},	//   ্ডটি, ироз, _тĕпх, _сатҳ_, 
   {{0xda7800a7,0xb9f00208,0x1a740150,0x00000000}},	//   вям_, cđộ_, иұлы_, --, 
   {{0x3f9c8251,0x247c02b5,0xa8540032,0x1e94084c}},	//   mivu_, _hāmā_, ҙерә, _трар, 
   {{0x3f9c8252,0x2d800023,0x37f8084c,0x247c002b}},	//   livu_, ëhet_, лемэ_, _kāmā_, 
   {{0x8d900050,0x3988002d,0xdb188253,0xed4c00ec}},	//   _بٔنت, _rûsd_, lltí, _سھي_, 
   {{0x247c8254,0x3f9c026c,0xbb180014,0xda641541}},	//   _māmā_, nivu_, _صٲبا_, _نابي, 
   {{0xada401f1,0xd5b81429,0x79580354,0x00000000}},	//   skúš, вса_, _бийр_, --, 
   {{0x3988000f,0x95c800fd,0x661802f0,0xdb180332}},	//   _bûse_, туга_, átka, iltí, 
   {{0x799c8255,0x3f9c03b4,0x78ac02c4,0x60380aed}},	// [9e10] misw, kivu_, _uxav, nāmā, 
   {{0x799c5107,0x8c180302,0x1cd80327,0x66180010}},	//   lisw, כומי, _འཔན_, štka, 
   {{0x999c02b1,0x3f9c8256,0x00000000,0x00000000}},	//   hutō_, divu_, --, --, 
   {{0x799c0163,0x41745734,0x00000000,0x00000000}},	//   nisw, يانس, --, --, 
   {{0x799c0810,0xdf5401c6,0x00000000,0x00000000}},	//   iisw, өнцө, --, --, 
   {{0x799c8257,0xa0640354,0x60380a2f,0x00000000}},	//   hisw, саша_, dāmā, --, 
   {{0x799c2747,0x6fcc01a2,0x256c00a2,0x4ea401d5}},	//   kisw, júce, _aýly_, шрда, 
   {{0x51848258,0x6fcc8259,0xaa4408c9,0x799c825a}},	//   _туга, dúce, ەندى, jisw, 
   {{0x799c825b,0xec78825c,0x00000000,0x00000000}},	//   disw, упп_, --, --, 
   {{0x3f9c026c,0xd1b0006c,0xec6800d1,0xeab00d62}},	//   civu_, _ایچک, врүк_, ۪ٹھ_, 
   {{0xe9d8156b,0x799c3feb,0x2ca801fa,0x63a00129}},	//   лко_, fisw, _žadd_, éoni, 
   {{0x799c825d,0xa9a4825e,0xe9a42080,0x81e400cc}},	//   gisw, симд, самп, পীক_, 
   {{0xe5780022,0x603800ef,0x00000000,0x00000000}},	//   қза_, cāmā, --, --, 
   {{0x291c825f,0x7de41d37,0x6da000b0,0xdac40116}},	//   şta_, _اسەم, tēaw, _گېپى_, 
   {{0x799c8260,0x64540070,0x569001d5,0x00000000}},	//   bisw, wvyi, паёт, --, 
   {{0x799c8261,0xe6880046,0x53740092,0x00000000}},	//   cisw, _ەندى_, _በማየት_, --, 
   {{0xd4648262,0xe4583748,0x3f9c8263,0x00000000}},	// [9e20] бите_, ыжа_, yivu_, --, 
   {{0x64a40aa5,0xa68403f6,0x247c0055,0xe4e401ec}},	//   _ҳама, _глод, _rāmā_, ріңн, 
   {{0x62583c1f,0x3f9c8264,0xdb98008f,0x649c003d}},	//   ырар_, vivu_, נסער, _sħiħ, 
   {{0x60380882,0x2568040e,0x00000000,0x00000000}},	//   yāmā, _самп_, --, --, 
   {{0x3f9c8265,0x4424001e,0x2b44030a,0x20108266}},	//   tivu_, _êm_, kelc_, éyi_, 
   {{0x799c124c,0x44208267,0x7f5801f0,0x9e0401d5}},	//   zisw, mri_, ракс_, бчил, 
   {{0x3f9c8268,0x44208269,0x2b440165,0x201800b0}},	//   rivu_, lri_, delc_, ōpi_, 
   {{0x4420826a,0x3f9c826b,0x799c826c,0x6fcc0419}},	//   ori_, sivu_, xisw, vúce, 
   {{0x799c0433,0x3f9c01a6,0x717000db,0x9fc801c6}},	//   visw, pivu_, _تۇنا, _бгаа_, 
   {{0x4420826d,0x799c826e,0x2d800240,0x2b440165}},	//   iri_, wisw, ëher_, gelc_, 
   {{0x4420826f,0x799c8270,0x8aa08271,0x2ca800d0}},	//   hri_, tisw, зряд, _ľade_, 
   {{0x6fcc00d0,0x9cc801af,0x00000000,0x00000000}},	//   rúce, _йыла_, --, --, 
   {{0x44208272,0x799c8273,0x8c402f59,0xcc3058c5}},	//   jri_, risw, _неце, _فروع, 
   {{0x7c200010,0xdb1c01f4,0x00000000,0x00000000}},	//   mrmr, äväa, --, --, 
   {{0x799c8274,0xd37801b9,0x4b3400d9,0x00000000}},	//   pisw, қча_, _לרגל_, --, 
   {{0xdb08022c,0x799c2c60,0x00000000,0x00000000}},	//   _akfø, qisw, --, --, 
   {{0x44208275,0x3254001f,0x33748276,0xd838084c}},	// [9e30] gri_, _የሚመጣ, огар, _сэй_, 
   {{0x7c200332,0x00000000,0x00000000,0x00000000}},	//   irmr, --, --, --, 
   {{0xf1940124,0xa2c0013d,0x00000000,0x00000000}},	//   оижь, дәтк, --, --, 
   {{0xc3300014,0x714000f7,0x00000000,0x00000000}},	//   ٕ٘ے_, بۉرۅ, --, --, 
   {{0x44208277,0xd0180a93,0x19e40046,0x00000000}},	//   cri_, уфе_, _ﺍﻟﻔﻠ, --, 
   {{0xfe708278,0xadec1889,0x5344010a,0x00000000}},	//   کده_, _चंदन_, _ухма, --, 
   {{0x877c27af,0xd04406be,0x00000000,0x00000000}},	//   ראוי, _ələb, --, --, 
   {{0x86400023,0x7e6c0356,0x2d988279,0x00000000}},	//   _ርግኣት, _şopâ, òse_, --, 
   {{0x506445c9,0x81d401c0,0xcfe000fe,0x00000000}},	//   _утва, _хотх, নীজন, --, 
   {{0xeb98827a,0xf3f000fe,0xaa440116,0x3f14014b}},	//   рио_, _চিঞৰ_, ەنگى, _ндус, 
   {{0x4420827b,0x753c068f,0x705004d3,0x7c20002d}},	//   zri_, _obsz, _رۆژا, armr, 
   {{0x4420827c,0x7afc0baa,0x77640051,0x00000000}},	//   yri_, ırta, _anhx, --, 
   {{0x44207ed7,0xfd10827d,0x00000000,0x00000000}},	//   xri_, _سجن_, --, --, 
   {{0x4420827e,0x66180313,0x753c01d3,0x2d8c0076}},	//   vri_, átko, _absz, lhee_, 
   {{0x4420827f,0xdb1800e4,0x00000000,0x00000000}},	//   wri_, kotê, --, --, 
   {{0x44208280,0x2d8c8281,0x00000000,0x00000000}},	//   tri_, nhee_, --, --, 
   {{0x44208282,0x2d8c0076,0x70980023,0x290015c0}},	// [9e40] uri_, ihee_, ሓላሊፉ_, mbka_, 
   {{0x44208283,0xe7388284,0x69c48285,0x04fc015b}},	//   rri_, _тео_, llke, েলের_, 
   {{0x44208286,0xf8a804d3,0x2d8c00e8,0x2900058a}},	//   sri_, _ندیه_, khee_, obka_, 
   {{0x44208287,0x29000009,0x00000000,0x00000000}},	//   pri_, nbka_, --, --, 
   {{0x65641cea,0x2d8c22a9,0x44208288,0x29000067}},	//   _inkh, dhee_, qri_, ibka_, 
   {{0x69c4002f,0x18580a7c,0x00000000,0x00000000}},	//   hlke, יכנע, --, --, 
   {{0x68f40042,0x00000000,0x00000000,0x00000000}},	//   _ofyd, --, --, --, 
   {{0x61fc0ea0,0x2d8c8289,0x00e4158b,0xd02000d1}},	//   mppl, ghee_, _رتری, чмәй, 
   {{0x9b6807d5,0x8c4006ed,0x10a0828a,0x29000009}},	//   ашна_, дење, _житн, dbka_, 
   {{0x2d8c0449,0x61fc168c,0x2900058a,0x61e80115}},	//   ahee_, oppl, ebka_, ŭflu, 
   {{0x6564192e,0xdb180240,0xaad400bc,0x5ea402c9}},	//   _onkh, lotë, डेलक, _بمال, 
   {{0x2d8c828b,0x6564058a,0x9c6402f2,0xca940150}},	//   chee_, _nnkh, _وهاو, _ﺘﺒﻌﺩ_, 
   {{0xd8c8084c,0x46c00037,0x2db8009f,0x00000000}},	//   рынд_, _शुबह, _اَنگ_, --, 
   {{0x6564828c,0x29000014,0x69c4058a,0x5fc8012c}},	//   _ankh, abka_, alke, ितिल, 
   {{0x68f40368,0x69c401ef,0x00000000,0x00000000}},	//   _ffyd, blke, --, --, 
   {{0x29000067,0xb8141f5a,0x00000000,0x00000000}},	//   cbka_, _едиј, --, --, 
   {{0x5fc86d58,0x24900432,0x00000000,0x00000000}},	// [9e50] िताल, gzym_, --, --, 
   {{0xd258828d,0x6564828e,0xed581710,0xe7d054cb}},	//   ице_, _enkh, može_, _दीपप, 
   {{0xed5808a4,0x914801d5,0x00000000,0x00000000}},	//   lože_, ичда_, --, --, 
   {{0x5560005e,0xd5840345,0x00000000,0x00000000}},	//   _تۇرك, _بێره_, --, --, 
   {{0x61fc0f49,0xd344828f,0x24900034,0x47940214}},	//   appl, _ویره_, czym_, _رجیس, 
   {{0xd3405929,0x00000000,0x00000000,0x00000000}},	//   _تفسی, --, --, --, 
   {{0xdb180798,0x69c48290,0xed5802fb,0x29008291}},	//   potê, ylke, hože_, ybka_, 
   {{0x2d8c0069,0xed582a69,0xdb18036e,0x70980240}},	//   uhee_, kože_, botë, ሓላልፉ_, 
   {{0x1c408292,0x752c0268,0xc058187f,0x459c010f}},	//   еным, igaz, _міф_, יסהע, 
   {{0x2d8c4ddb,0xdb183040,0xab280114,0x00000000}},	//   shee_, notè, љона_, --, 
   {{0x2d8c198f,0x8b680171,0x00000000,0x00000000}},	//   phee_, _ķēdē, --, --, 
   {{0x290000bc,0x69c40098,0x5edc00fe,0x0dc80c54}},	//   ubka_, ulke, নুহে, _тузи_, 
   {{0x2d9c8293,0x385400a7,0x752c8294,0x6d480363}},	//   _imwe_, мърс, dgaz, meea, 
   {{0x752c8295,0x6d480731,0x3ce000c7,0x00000000}},	//   egaz, leea, _úiva_, --, 
   {{0xdb188296,0x35800092,0x00000000,0x00000000}},	//   zotë, _የገቡት_, --, --, 
   {{0x752c8297,0x6d4800ad,0xed588298,0x291c0024}},	//   ggaz, neea, bože_, ėtas_, 
   {{0x2d9c2f99,0xd4641515,0x386c0221,0x18b000d1}},	// [9e60] _mmwe_, пите_, äert_, _зәрр, 
   {{0x752c8299,0x6d480076,0xe7d00137,0x24900210}},	//   agaz, heea, _سۅزگ, rzym_, 
   {{0x2490006d,0x2d9c1813,0x248400d0,0x61fc829a}},	//   szym_, _omwe_, šom_, uppl, 
   {{0x6564829b,0x61fc01f5,0x6d4800ad,0xb6440150}},	//   _unkh, rppl, jeea, _ﺎﺫ_, 
   {{0xd6cc03e6,0x6d4800ad,0x74f00150,0x00000000}},	//   _لقی_, deea, _شۋلا, --, 
   {{0x2d9c0bd5,0x9e043663,0xa06804a2,0xdb18829c}},	//   _amwe_, пчил, _қаза_, cotè, 
   {{0xdd98829d,0x28dc17c6,0x6d481b5a,0xdb0c0118}},	//   йши_, _नृसि, feea, ádím, 
   {{0x2ca80024,0x6d480083,0xdb180306,0x7bf8009b}},	//   _žada_, geea, moté, онир_, 
   {{0xd004829e,0xdb1806af,0x0c400014,0x20c81541}},	//   _нете_, loté, ٹھنَ, _طبري_, 
   {{0x5edc03f4,0x2d9c829f,0x63bc05d6,0x61ec82a0}},	//   নুষে, _emwe_, nopn, _kubl, 
   {{0x61ec1574,0xdb1882a1,0x6d4804ba,0x672c0175}},	//   _jubl, noté, beea, dgbj, 
   {{0xed5803c6,0x63bc0e96,0x61ec82a2,0x9f44002e}},	//   tože_, hopn, _mubl, ppoó_, 
   {{0xc8645660,0x61ec82a3,0x23bc00dc,0x63bc1dbb}},	//   нтри, _lubl, ्ताद, kopn, 
   {{0x36d482a4,0x61ec82a5,0xdb180098,0xed580e04}},	//   догр, _oubl, koté, rože_, 
   {{0x61ec82a6,0x8b380375,0xc6680640,0x752c82a7}},	//   _nubl, _התוצ, пште_, tgaz, 
   {{0x960001c0,0x7bc882a8,0xdb1882a9,0x6fcc00d7}},	//   мүүж, lldu, doté, júcn, 
   {{0x3f8c82aa,0x798c82ab,0x752c82ac,0x6fcc01f1}},	// [9e70] _oldu_, _ilaw, rgaz, dúcn, 
   {{0x798c82ad,0x61ec82ae,0x63bc0158,0x6d480472}},	//   _hlaw, _bubl, gopn, zeea, 
   {{0x61ec82af,0x798c82b0,0x7bc882b1,0xdb1882b2}},	//   _cubl, _klaw, ildu, rotè, 
   {{0xdd8482b3,0xdb1882b4,0x7644009a,0x3f8c0162}},	//   _شو_, lltä, _iphy, _aldu_, 
   {{0x798c3bd7,0x53a00e26,0x61ec02d0,0xdb1800cf}},	//   _mlaw, _كۅرك, _eubl, potè, 
   {{0x798c82b5,0x61ec003a,0xdb180036,0x6d480af9}},	//   _llaw, _fubl, boté, weea, 
   {{0x798c82b6,0x61ec2111,0x6440004a,0x6d4800ad}},	//   _olaw, _gubl, çoiv, teea, 
   {{0x320082b7,0x3f8c01c4,0x7bc882b8,0xe46805d1}},	//   mphy_, _eldu_, eldu, ıköğ, 
   {{0x32001c06,0x61ec0010,0x6d4826de,0xed580219}},	//   lphy_, _zubl, reea, tožb_, 
   {{0x6d4820a2,0x61ec0548,0x764403ac,0xd1bc0092}},	//   seea, _yubl, _ophy, ሴዎች_, 
   {{0x3a140598,0x798c82b9,0x32000218,0x9d500424}},	//   ньяс, _blaw, nphy_, رنیت, 
   {{0x2d9c0537,0x798c82b9,0xa96815ed,0x7bc8022c}},	//   _umwe_, _claw, цима_, aldu, 
   {{0x798c82ba,0x764482bb,0x6b7400ee,0xd6f801ad}},	//   _dlaw, _aphy, _олду, ्रंथ_, 
   {{0x798c82bc,0x00000000,0x00000000,0x00000000}},	//   _elaw, --, --, --, 
   {{0xaad027c6,0xb17c00d7,0xf664009d,0x00000000}},	//   _हरिक, _niťo, нерү, --, 
   {{0xed5800f3,0x798c82bd,0xdb1802f0,0x00000000}},	//   ndž_, _glaw, voté, --, 
   {{0x63bc151c,0x6fcc01f1,0x764482be,0x61ec82bf}},	// [9e80] topn, júco, _ephy, _subl, 
   {{0x6fcc0030,0xaad0033f,0x386c003b,0x66e400db}},	//   dúco, _हराक, åere_, _оопа, 
   {{0x61ec7a56,0x798c03ac,0x00000000,0x00000000}},	//   _qubl, _ylaw, --, --, 
   {{0x88b0043b,0xdb1800d2,0xed5800f3,0x63bc82c0}},	//   _ndɛk, jotî, jdž_, sopn, 
   {{0x7bc82242,0x63bc0770,0x44242959,0x3580023b}},	//   yldu, popn, _ím_, _ёқуб, 
   {{0xdb180232,0x61ec82c1,0xe29882c2,0xffb401c6}},	//   poté, _tubl, _даг_, эйлэ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69d4013b,0x7afc5775,0x7bc80175,0x2bf800cc}},	//   _nhye, ırtm, wldu, _ইয়েই_, 
   {{0x717000db,0xdb1801f4,0x00000000,0x00000000}},	//   _حۇنا, yltä, --, --, 
   {{0x69d4013b,0x798c82c3,0x7bc80213,0x3b540818}},	//   _ahye, _slaw, uldu, хкор, 
   {{0x798c82c4,0x69d400b8,0x00000000,0x00000000}},	//   _plaw, _bhye, --, --, 
   {{0x69d4033b,0x64440b4f,0x99640b01,0x00000000}},	//   _chye, _opki, фтол, --, 
   {{0x69d400cd,0x5fe001f9,0x69c40055,0x980482c5}},	//   _dhye, _पळाल, _īhet, ьянд, 
   {{0xed580427,0x65740022,0x00000000,0x00000000}},	//   moža_, ejyh, --, --, 
   {{0x52bc04fa,0x386c0311,0x798c015d,0x64440064}},	//   _्रेस, ţer_, _tlaw, _apki, 
   {{0x9484472d,0x798c82c6,0x69d40076,0x45d4030d}},	//   мызд, _ulaw, _ghye, восс, 
   {{0xb7d40241,0xed5801a6,0x00000000,0x00000000}},	// [9e90] _aṣen, noža_, --, --, 
   {{0xb17c00d0,0xdedc0023,0x437400d4,0x00000000}},	//   _piťo, ቕርን_, куєт, --, 
   {{0xe7280135,0x6444022e,0x00000000,0x00000000}},	//   _སྐྲན_, _epki, --, --, 
   {{0xc1040220,0x316801c4,0xed5882c7,0x00000000}},	//   نومي, ñaz_, koža_, --, 
   {{0x5064007b,0xc1e400fb,0x00000000,0x00000000}},	//   بطاق, төрҙ, --, --, 
   {{0x6fcc00d0,0xda1c0073,0x2ca80064,0x00000000}},	//   rúco, _भिंत_, _žado_, --, 
   {{0xee38090b,0x23bc2cbb,0x00000000,0x00000000}},	//   їни_, ्तरद, --, --, 
   {{0xdb4400c6,0x506400a7,0xec7882c8,0x00000000}},	//   _םَ_, _отза, зпи_, --, 
   {{0xed5817a3,0xf4bc009e,0x35800092,0xdb180022}},	//   rdž_, _অণুব, _የወተት_, rotî, 
   {{0x69d482c9,0x00000000,0x00000000,0x00000000}},	//   _shye, --, --, --, 
   {{0xd1bc0023,0xdb0c0118,0xdb1800c7,0x4b3000f2}},	//   _ድሙቕ_, ádám, potî, _یکدس, 
   {{0xadb40139,0x00000000,0x00000000,0x00000000}},	//   _ябеш, --, --, --, 
   {{0x6d580649,0x00000000,0x00000000,0x00000000}},	//   _iawa, --, --, --, 
   {{0x6d5882ca,0x5c78008f,0xa098010f,0x7c84003b}},	//   _hawa, _מאנה, לירט, _шухе, 
   {{0x6d5882cb,0x69d402d3,0x00000000,0x00000000}},	//   _kawa, _thye, --, --, 
   {{0xc9d401d3,0x00000000,0x00000000,0x00000000}},	//   _جمعک, --, --, --, 
   {{0x291002c4,0xd7000107,0x00000000,0x00000000}},	// [9ea0] _ieya_, ъҷӯи, --, --, 
   {{0x29100055,0xba940432,0x00000000,0x00000000}},	//   _heya_, _öçür, --, --, 
   {{0x29100481,0xe5680022,0x6d58035a,0xe6441fbe}},	//   _keya_, _еинд_, _oawa, _џемп, 
   {{0xfe702fb6,0x64400129,0x00000000,0x00000000}},	//   یگا_, çois, --, --, 
   {{0x291082cc,0x95b00139,0x91007e7e,0x61e000d7}},	//   _meya_, _сөрх, упче, ňolo, 
   {{0x291082cd,0x9f940276,0x51500022,0x00000000}},	//   _leya_, эшеш, втәу, --, 
   {{0x6d5882ce,0xdea002f2,0x00000000,0x00000000}},	//   _bawa, دیای, --, --, 
   {{0x6d5882cf,0x291082d0,0xe298013e,0xd6a00150}},	//   _cawa, _neya_, _даҳ_, _ﺎﺒﻴﺭ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x1e940faa,0xed580427,0x6d5803ac,0xd434010f}},	//   _прер, roža_, _eawa, עריק_, 
   {{0x0c7010e5,0x291082d1,0x7c2400df,0x0ea4000d}},	//   ندید, _beya_, _ĥiru, _केपड, 
   {{0x6d5882d2,0x2910011f,0xdb183b32,0x00000000}},	//   _gawa, _ceya_, motí, --, 
   {{0x291082d3,0x27f00076,0x7dcc002d,0xdb1802f0}},	//   _deya_, _cuyn_, hûsk, lotí, 
   {{0x6d5882d4,0xd90c0cb8,0x29100241,0x27f00432}},	//   _zawa, جیک_, _eeya_, _duyn_, 
   {{0xdb180372,0x6d5882d5,0x29100432,0xabb40022}},	//   notí, _yawa, _feya_, _шашә, 
   {{0x6d582f2a,0x29100548,0xdec0069d,0x00000000}},	//   _xawa, _geya_, ድርና_, --, 
   {{0x932482d6,0x7dcc045f,0xe9880240,0x00000000}},	// [9eb0] فران, tûsj, _ዝረኣየ_, --, 
   {{0xdb180419,0xb5f40108,0x00000000,0x00000000}},	//   kotí, _изощ, --, --, 
   {{0x291082d7,0xa2d40a59,0x36d4004e,0x00000000}},	//   _yeya_, _भरण्, _шоор, --, 
   {{0x857401af,0x83840022,0x28dc3f7e,0xdb18013a}},	//   _блюх, _ҩыре, नेवि, dotí, 
   {{0x6d5882d8,0x00000000,0x00000000,0x00000000}},	//   _rawa, --, --, --, 
   {{0x6d5882d9,0xa06482da,0xdb180306,0x00000000}},	//   _sawa, таша_, fotí, --, 
   {{0xcc8403e6,0xcee801d9,0x00000000,0x00000000}},	//   کۆشه_, _ہران_, --, --, 
   {{0x6d58749c,0xd1b80014,0xf4c40349,0x13a403e6}},	//   _qawa, _رازا_, ্শীব, _تۆڕی_, 
   {{0x6d580433,0xeb9809a5,0x40c800ec,0x00000000}},	//   _vawa, дип_, _ٻولَ_, --, 
   {{0x6d5882db,0x291082dc,0x00d83c97,0x8ee00154}},	//   _wawa, _seya_, _سبقت_, নুষগ, 
   {{0x6d5882dd,0x316c0960,0x7dcc00d2,0x8d44009d}},	//   _tawa, _knez_, kûsh, _зүйг_, 
   {{0xa9a46d3a,0xcd280046,0x6d5802d0,0xe9a482de}},	//   тимд, _ءسان_, _uawa, тамп, 
   {{0x2910079d,0x3ea00115,0x00000000,0x00000000}},	//   _veya_, ĝite_, --, --, 
   {{0x3ea00115,0x00000000,0x00000000,0x00000000}},	//   ŝite_, --, --, --, 
   {{0x2910043b,0x316c009d,0x3d08000d,0x00000000}},	//   _teya_, _onez_, _सभमे_, --, 
   {{0x7d04000d,0x27f00051,0x00000000,0x00000000}},	//   _õist, _tuyn_, --, --, 
   {{0x28dc03f3,0xa3e801c6,0xdb1800d7,0x00000000}},	// [9ec0] नेशि, ддаа_, zotí, --, 
   {{0x316c05c7,0x78ac00bc,0xa2d42314,0xb3b40154}},	//   _anez_, šová, _भरद्, _জীবজ, 
   {{0x41280032,0xdb1800d8,0xd24c00c6,0x6fcc0332}},	//   енеү_, lotã, ينك_, múch, 
   {{0x6fcc007b,0xb7d40241,0x00000000,0x00000000}},	//   lúch, _iṣan, --, --, 
   {{0xd00c009f,0x00000000,0x00000000,0x00000000}},	//   قلن_, --, --, --, 
   {{0x316c0dd4,0x02c482df,0x0dd0001f,0x6d9482e0}},	//   _enez_, _бигү, _ያለፈ_, _láad, 
   {{0x53a082e1,0x61385b7f,0x4f840014,0x00000000}},	//   _тарб, _очар_, خانہ, --, 
   {{0x6fcc007b,0xdb1803cd,0x25b000ad,0x9f980108}},	//   húch, lltø, nnyl_, _näön_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x200402b4,0xd0040276,0x1e840022,0x9a8400ee}},	//   mpoi_, _рефе_, _илзм, вумл, 
   {{0xdee482e2,0x2b887bb9,0x6fcc82e3,0x00000000}},	//   _рожи, _múch_, dúch, --, 
   {{0x7f940de2,0x760802bd,0xb17c00d7,0x00000000}},	//   _dàqe, _lèzò, _riťk, --, 
   {{0x200403a2,0xb7d40241,0x6d940ca8,0x0b5401b9}},	//   npoi_, _aṣan, _dáad, رشیب_, 
   {{0x6fcc0419,0x00000000,0x00000000,0x00000000}},	//   vúck, --, --, --, 
   {{0x2bb00574,0x00000000,0x00000000,0x00000000}},	//   ीकरा, --, --, --, 
   {{0x499400e5,0x00000000,0x00000000,0x00000000}},	//   _نیپر, --, --, --, 
   {{0xb4d4023a,0xdb180798,0x6fcc00d7,0x00000000}},	// [9ed0] ужащ, cotã, búch, --, 
   {{0x6fcc0789,0x7f94002e,0x00000000,0x00000000}},	//   cúch, _yàqe, --, --, 
   {{0x2b8800ae,0x00000000,0x00000000,0x00000000}},	//   _dúch_, --, --, --, 
   {{0xdb1805da,0x00000000,0x00000000,0x00000000}},	//   hotà, --, --, --, 
   {{0x6fcc82e4,0xdb1800e4,0x65980a7c,0xfbb4095f}},	//   lúci, kotà, _נישק, ुवाम, 
   {{0xee3882e5,0x73c401ec,0x00000000,0x00000000}},	//   енк_, _сәбе, --, --, 
   {{0xd1b82dfc,0xada482e6,0x20040374,0xd138074d}},	//   _قارا_, лакл, apoi_, _оха_, 
   {{0xa28019d4,0x64680254,0x00000000,0x00000000}},	//   _دیمو, _õpiü, --, --, 
   {{0x6d9401ed,0x00000000,0x00000000,0x00000000}},	//   _ráad, --, --, --, 
   {{0x6fcc0030,0x00000000,0x00000000,0x00000000}},	//   kúci, --, --, --, 
   {{0x6fcc01a2,0xdd8c82e7,0x00000000,0x00000000}},	//   júci, زوی_, --, --, 
   {{0x6fcc0030,0x3dc404ce,0xa3d819cc,0x00000000}},	//   dúci, comw_, _डीन_, --, 
   {{0xdb1800db,0x2d8c0009,0x9d18011a,0x6fcc82e8}},	//   botà, mkee_, _נוסט, túch, 
   {{0x2d8c82e9,0xdb180798,0xa14000e2,0x38040107}},	//   lkee_, rotã, ēķin, рорҳ, 
   {{0x2d8c82ea,0x6fcc007b,0x00000000,0x00000000}},	//   okee_, rúch, --, --, 
   {{0x2d8c82eb,0x6fc40490,0x6fcc007b,0xdb180306}},	//   nkee_, ाकडू, súch, motá, 
   {{0x69c482ec,0xdb1829e8,0x6fcc00d7,0x00000000}},	// [9ee0] moke, lotá, púch, --, 
   {{0x69c47d52,0xe29882ed,0x6fcc82ee,0x2d8c01f4}},	//   loke, наз_, búci, hkee_, 
   {{0x2d8c82ef,0x25b00076,0xe5a482f0,0x5754011a}},	//   kkee_, pnyl_, _бини, _גביע_, 
   {{0x69c482f1,0x00000000,0x00000000,0x00000000}},	//   noke, --, --, --, 
   {{0xdef882f2,0x2b88002d,0x69c4005a,0x80cc015b}},	//   ный_, _túch_, ioke, ়েন্, 
   {{0x69c482f3,0xdb1801ed,0x2d8c058a,0x00000000}},	//   hoke, kotá, ekee_, --, 
   {{0x69c482f4,0x2d8c0009,0x00000000,0x00000000}},	//   koke, fkee_, --, --, 
   {{0x69c482f5,0x2004005b,0xdb1846dc,0x9c080022}},	//   joke, ppoi_, dotá, нхоз_, 
   {{0x61e007d6,0x69c482f6,0x811000af,0x7cd80c60}},	//   mmol, doke, ारीख_, ъмир_, 
   {{0x2d8c0ba7,0x54540677,0x00000000,0x00000000}},	//   akee_, נסין_, --, --, 
   {{0x69c482f7,0x61e00770,0xdb180113,0x2d8c058a}},	//   foke, omol, gotá, bkee_, 
   {{0x61e082f8,0x2d8c00ad,0x69c482f9,0x00000000}},	//   nmol, ckee_, goke, --, 
   {{0xdb1882fa,0x61e001f4,0x00000000,0x00000000}},	//   potà, imol, --, --, 
   {{0xdb1800e4,0x6fcc82fb,0x291c016b,0x61e082fc}},	//   botá, túci, ɔtam_, hmol, 
   {{0x69c482fd,0x61e07c46,0xc0d40092,0x00000000}},	//   boke, kmol, _ይዘህ_, --, 
   {{0x69c482fe,0x6fcc00d0,0x2ca80064,0x00000000}},	//   coke, rúci, _žadi_, --, 
   {{0x39480789,0x45d40107,0x6fcc00d7,0x00000000}},	// [9ef0] _ibas_, сотс, súci, --, 
   {{0x386802a8,0x61e001a4,0x73c40032,0x7e6882ff}},	//   _irar_, emol, рәме, _ordp, 
   {{0x32542db2,0xc8b48300,0x51848301,0xc34800fd}},	//   рвер, _نصیب, луда, ыяте_, 
   {{0xf434084c,0x61e00115,0xf0e80131,0x25f000ab}},	//   _кемэ, gmol, پىتى_, ंआरी_, 
   {{0x653404ac,0x39488302,0x94846ad2,0x7e6802d0}},	//   _דארף_, _mbas_, _сынд, _ardp, 
   {{0x61e08303,0x69c4006f,0x38680327,0x39480171}},	//   amol, zoke, _mrar_, _lbas_, 
   {{0xed582075,0x2d948304,0xfce8001f,0x4ea48305}},	//   вой_, ирис, ዘጋጀ_, ырда, 
   {{0x2d8c8306,0x38684168,0x69c400f1,0xda1c0073}},	//   ukee_, _orar_, xoke, _भिजत_, 
   {{0x2d8c8307,0x0578010c,0xa3d801ad,0x3ea0008f}},	//   rkee_, _አገባብ_, _डीड_, ĝita_, 
   {{0x2d8c8308,0x39488309,0x69c4830a,0x3ea0008f}},	//   skee_, _abas_, woke, ŝita_, 
   {{0x69c4830b,0xe9d8830c,0x3868830d,0xaa44830e}},	//   toke, кко_, _arar_, шенл, 
   {{0x394801ab,0xfce8001f,0x4ea40022,0x606000db}},	//   _cbas_, ዘጋጁ_, _ирҵа, _دۇۇل, 
   {{0x69c4830f,0x39480618,0xdd8c04d3,0x28b80276}},	//   roke, _dbas_, _زوو_, тунэ_, 
   {{0xdb188310,0x38688311,0x69c48312,0xab281bc4}},	//   potá, _drar_, soke, _рока_, 
   {{0x66e449f3,0x61e08313,0x69c48314,0x386801e4}},	//   рова, ymol, poke, _erar_, 
   {{0x38688315,0x7f9400e8,0x39480241,0xa8040166}},	//   _frar_, _màqa, _gbas_, _aqış, 
   {{0x7f940de2,0x18b005a2,0x3d080037,0x00000000}},	// [9f00] _làqa, _дәрр, _सभसे_, --, 
   {{0x64540042,0x00000000,0x00000000,0x00000000}},	//   rwyi, --, --, --, 
   {{0xf3c88316,0xbebc002b,0x923000d1,0x0b840240}},	//   ابقه_, _adīn, قىلش, _ዝወደይ_, 
   {{0x61444d0b,0x29d0011f,0x563400df,0x00000000}},	//   реда, dáak_, _דאטע_, --, 
   {{0x61e0003d,0x20548317,0xa804008e,0x00000000}},	//   rmol, ртер, _uqığ, --, 
   {{0x61e08318,0x44208319,0x7f9400e8,0xfce80092}},	//   smol, msi_, _bàqa, ዘጋጃ_, 
   {{0xfdc82f0d,0x217428e5,0x7e4801d3,0x386c0036}},	//   лтиқ_, _куар, استہ_, äerz_, 
   {{0x7f940de2,0xfce80092,0x9c4403c5,0x00000000}},	//   _dàqa, ዘጋጅ_, ахол, --, 
   {{0xdfe8013e,0x629c0036,0xadb400cf,0x69f0009d}},	//   _адад_, lzpo, حۇنا_, үүшт, 
   {{0x44201988,0x23c42982,0x39480327,0xdb680835}},	//   isi_, वविद, _sbas_, трил_, 
   {{0x4420831a,0x6e20010a,0x39480334,0x629c2ad7}},	//   hsi_, _gvlb, _pbas_, nzpo, 
   {{0x4420831b,0x998000bc,0x1d0821fa,0xdb18002f}},	//   ksi_, čků_, _реди_, lltü, 
   {{0x3868031c,0xb78805a2,0x79c40116,0x8c40831c}},	//   _qrar_, гәне_, ийүз, _меце, 
   {{0x8c180bd9,0x0c000014,0x7f9400e8,0x3868036e}},	//   _יודי, _بووُ, _yàqa, _vrar_, 
   {{0x4420831d,0x7f9400e8,0x00000000,0x00000000}},	//   esi_, _xàqa, --, --, 
   {{0x442000b2,0x39141789,0x394822d0,0x386807de}},	//   fsi_, _умир, _ubas_, _trar_, 
   {{0x4420831e,0x3868831f,0x62880217,0xf4d80107}},	// [9f10] gsi_, _urar_, øfon, умаш_, 
   {{0x84240952,0x92e8267c,0xc39800d4,0x00000000}},	//   زىمن, نراق_, акує_, --, 
   {{0x44208320,0x3988000f,0x59b86c52,0xdb188321}},	//   asi_, _fûst_, _उदार, lltó, 
   {{0x7bc80770,0x44208322,0xdb188323,0xd5b80114}},	//   hodu, bsi_, lotä, _јсо_, 
   {{0x7bc88324,0x44208325,0xdfcc8326,0x7f9400e8}},	//   kodu, csi_, کيو_, _sàqa, 
   {{0x4524025c,0x7c200010,0x00000000,0x00000000}},	//   _འཇོར_, dsmr, --, --, 
   {{0xed5815ad,0xf2e40eac,0x629c8327,0x00000000}},	//   loži_, _প্রণ, czpo, --, 
   {{0xc6b8011a,0x00000000,0x00000000,0x00000000}},	//   יהוי_, --, --, --, 
   {{0x2bc800d1,0x7bc80142,0x00000000,0x00000000}},	//   ллип_, fodu, --, --, 
   {{0x7bc88328,0xd1bc001f,0x7f941bce,0x25dc00c5}},	//   godu, ዴዎች_, _tàqa, _कीनी_, 
   {{0x44208329,0xdb0401d3,0x2ca800d0,0x4ea406ed}},	//   zsi_, émák, _ľadu_, _траа, 
   {{0x2cbc0218,0x2ca800c0,0xac180117,0x35bc012d}},	//   _txwd_, _žadu_, _боду_, ्कफ़, 
   {{0x7bc8832a,0x4420832b,0x6ce40014,0x3988002d}},	//   bodu, xsi_, _آشن, _rûst_, 
   {{0x64980046,0x7bc80072,0xa7d8007b,0x00000000}},	//   ңтар_, codu, اوسط_, --, 
   {{0xdb1800c6,0x7dcc002d,0xa5942077,0xe968832c}},	//   altó, pûst, бращ, _байл_, 
   {{0x4420832d,0xb7d40882,0x64a40d34,0x629c0118}},	//   tsi_, rṣab, баба, vzpo, 
   {{0x4420832e,0xe3b800c7,0xb8dc00fe,0x00000000}},	// [9f20] usi_, гба_, _অৰ_, --, 
   {{0x4420832f,0x629c17da,0xc3300137,0x00000000}},	//   rsi_, tzpo, بەس_, --, 
   {{0xe1f066a3,0x216805c5,0xdef802dd,0x29d80241}},	//   سسا_, лижи_, қыл_, _ṣaya_, 
   {{0xf1a410f5,0x29006c50,0x629c002f,0x5180004e}},	//   орін, ncka_, rzpo, зуша, 
   {{0x44208330,0xc3300075,0x7164129d,0x7bc88331}},	//   qsi_, _يەر_, تالك, yodu, 
   {{0x8b040b45,0xd8d400c8,0x66f82e1e,0x6384074d}},	//   _haƙƙ, זונט_, ्डिक_, _угга, 
   {{0xe2988332,0x7bc800ac,0x8e4400ae,0x00000000}},	//   _сав_, vodu, ملوك_, --, 
   {{0x7124182c,0x7bc88333,0x232808ca,0xdfd000f1}},	//   _ورقل, wodu, _шоҳи_, _ځير_, 
   {{0x91e08334,0x61fc074d,0x5574008f,0x0ea40166}},	//   _хоте, lqpl, מעקן_, икәй_, 
   {{0x2900068f,0x6d4c1bce,0x7c200334,0x5398010f}},	//   ecka_, _ñaan, rsmr, ָסטא, 
   {{0x1e94084c,0x34d4121d,0xd378010f,0xdb1801f4}},	//   _урар, _दर्द, אריט, votä, 
   {{0x7bc88335,0xd8380323,0x6d94032e,0xaca801d3}},	//   sodu, лэг_, _háan, اپیے_, 
   {{0xb90039de,0xdb1801e3,0xa9a000db,0x00000000}},	//   _थर_, totä, بۅيى, --, 
   {{0x68f48336,0x45240327,0x3f9c0208,0xd4980209}},	//   _egyd, _འཇུར_, nhvu_, ңра_, 
   {{0x7f940de2,0xd5b8300e,0x6288143a,0x8b000210}},	//   _làqo, гса_, øfol, łęcz, 
   {{0x95c80372,0xc0dc0023,0xed580010,0x00000000}},	//   ууга_, _ሕጉስ_, toži_, --, 
   {{0x49b845d7,0x5fb82793,0xa3d80037,0xf8bc0037}},	// [9f30] _داود_, ेवाल, _डीह_, _ऊखिय, 
   {{0xed580427,0x24840108,0x00000000,0x00000000}},	//   roži_, äoma_, --, --, 
   {{0x72b800c6,0x6728002d,0xe6c80139,0x92680022}},	//   جهاز_, _ôfja, _ırçı, ыраа_, 
   {{0x61448337,0xded00150,0x00000000,0x00000000}},	//   قىمە, _ﺘﺭﺘﺒ, --, --, 
   {{0x4acc0abd,0x80cc0154,0x00000000,0x00000000}},	//   _सुनव, ়েস্, --, --, 
   {{0x7f9400e8,0x13a48338,0x65e400d1,0x00000000}},	//   _dàqo, _طنزی_, _ﺋﺎﯕﻠ, --, 
   {{0x2900049f,0xdee00276,0xada48339,0x24980092}},	//   ycka_, моши, жайл, _ለመሐድ_, 
   {{0xf0740014,0x518401c6,0x00000000,0x00000000}},	//   _ویاں_, _ууга, --, --, 
   {{0x6d9401a8,0x9e980240,0x00000000,0x00000000}},	//   _fáan, _ገይርና_, --, --, 
   {{0xaba800c2,0x5f4000cf,0x3f9c833a,0x2618134e}},	//   рвоз_, _قچىل, chvu_, _बबली_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6844833b,0x7f9400e8,0x88840131,0x799c02d0}},	//   онма, _yàqo, зғил, ghsw, 
   {{0x6d480175,0x00000000,0x00000000,0x00000000}},	//   mfea, --, --, --, 
   {{0x6d48833c,0xe7380063,0x29000fac,0x7a300022}},	//   lfea, јев_, scka_, ẽtah, 
   {{0xb8d00642,0x7b6401d9,0xf1c800dc,0x28a85b82}},	//   _टे_, _راوٕ, िकान, _चेरि, 
   {{0x6d48833d,0x799c833e,0x6b8c00a2,0x2bdc07b7}},	//   nfea, chsw, _įagy, _नीता, 
   {{0xd464833f,0x6d481552,0x638400d8,0x00000000}},	// [9f40] оите_, ifea, огаа, --, 
   {{0x6d48007b,0xed580427,0x2328014b,0x00000000}},	//   hfea, možu_, рожи_, --, 
   {{0x7f94002e,0x8b0403f9,0x66e48340,0x6d48000f}},	//   _dàql, _taƙƙ, _фона, kfea, 
   {{0x6ecc07f7,0x51f4003b,0x00000000,0x00000000}},	//   दअनु, інію_, --, --, 
   {{0xe0548341,0x6d488342,0xdf60035b,0x628801f4}},	//   تخاب, dfea, мҭақ, äfob, 
   {{0x9e040ff1,0x6d480010,0x66f808f2,0x00000000}},	//   очил, efea, ंशिक_, --, 
   {{0xdd988343,0x9e6433d2,0x00000000,0x00000000}},	//   иши_, تاشن, --, --, 
   {{0xed586c3c,0x1278008f,0x6d4800ae,0x00000000}},	//   kožu_, _דאלע, gfea, --, 
   {{0x8e440131,0x7f94002e,0x4f8401d9,0x80d800ec}},	//   ملۈك_, _yàql, _ڈالہ, _اڀار_, 
   {{0x4f842832,0xdee4337e,0x6d9408a5,0xde748344}},	//   _والہ, _дози, _háal, _وداع, 
   {{0x9d448345,0xe8c4025c,0x8aa08346,0xe06003e6}},	//   _межд, _གཙུག, дряд, _رێژی, 
   {{0xb7d40241,0x6d48007b,0x19a8113e,0x18700b01}},	//   _iṣin, cfea, ртоп_, дҳия, 
   {{0x386c068c,0x72780092,0x00000000,0x00000000}},	//   íer_, _አጸደቀ_, --, --, 
   {{0x81c02b1b,0xa3d802a0,0x799c03ac,0x2ca800ee}},	//   ঁতি_, _डील_, shsw, _ýada_, 
   {{0x99d43dca,0x3b640014,0x9a840408,0x8aa002e8}},	//   _وتعا, _وُچِ, _фулл, _оръд, 
   {{0xbebc0055,0x39148347,0x1644009d,0x00000000}},	//   _adīk, _эмир, бүүк_, --, 
   {{0x39588348,0x5fc8047f,0xd83801c0,0x00000000}},	// [9f50] mess_, ाकाल, _тэй_, --, 
   {{0x39588349,0xa36801a9,0x926800d8,0x00000000}},	//   less_, llеj, иреа_, --, 
   {{0x7f58834a,0x867400c0,0x00000000,0x00000000}},	//   devq, _жыўц, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d9401e1,0x90e42099,0x7f94002e,0xd0a80f5c}},	//   _dáal, آسان, _tàql, јтед_, 
   {{0x395835e9,0x23f80302,0x6d480334,0x00000000}},	//   hess_, _להשא, wfea, --, 
   {{0xc7b40302,0x6d48834b,0xcdc000c7,0x00000000}},	//   ובס_, tfea, макқ, --, 
   {{0xac8439f4,0xd1b001b9,0x3958834c,0x2d9800e4}},	//   згил, _کیچک, jess_, óse_, 
   {{0x39580c86,0x6d48834d,0xb7d40241,0x3b1c0175}},	//   dess_, rfea, _eṣin, _bevq_, 
   {{0xeb980640,0x3958003e,0x6d48834e,0x3fc800f2}},	//   сио_, eess_, sfea, _وگوی_, 
   {{0xa968834f,0x39588350,0x6d48045f,0x5b2000f1}},	//   бина_, fess_, pfea, رځول, 
   {{0x39588351,0x59804f13,0x00000000,0x00000000}},	//   gess_, елюб, --, --, 
   {{0xed580010,0x00000000,0x00000000,0x00000000}},	//   mež_, --, --, --, 
   {{0xed5854ff,0x37740220,0xca7401ec,0x00000000}},	//   lež_, мысс, _дәмі_, --, 
   {{0xa5940801,0x26dc494c,0x39588352,0xf664008e}},	//   пращ, åto_, bess_, мерү, 
   {{0x39588353,0xe4048354,0xa6c8022e,0xa7e000e2}},	//   cess_, ззап, _ldаg, _šķēl, 
   {{0xe8c40135,0xe7388355,0x4acc02c3,0x00000000}},	// [9f60] _གཙིག, _леп_, _सुतव, --, 
   {{0xb7f801ad,0x66e40107,0x00000000,0x00000000}},	//   ंदरम_, _нопа, --, --, 
   {{0x7f58074d,0xf8a87878,0xa36801a9,0xd6f8011a}},	//   vevq, _هدیه_, llеk, _לפיכ, 
   {{0xed580841,0xbf1401ad,0x15e07c33,0xd8b00066}},	//   jež_, डर्न_, _कीपर_, _آمیخ, 
   {{0x65640652,0xed588356,0xaf4800ec,0x44240248}},	//   _iakh, dež_, ڪشنل_, _ìm_, 
   {{0x8fa033e2,0x39588357,0x65648358,0x6d9401e1}},	//   наче, zess_, _hakh, _dáam, 
   {{0x6564136f,0x63ac0327,0x53980375,0x6d9401e1}},	//   _kakh, _imbn, _פילו, _táal, 
   {{0x65640bc9,0x6d940421,0x4e3000f4,0xd2a4004e}},	//   _jakh, _fáam, رعىز, _эксе_, 
   {{0x39588359,0x63ac020c,0x8c4006ed,0x2490005c}},	//   vess_, _kmbn, еење, nyym_, 
   {{0x6564124c,0x3958835a,0x0ea400e1,0x3d0800af}},	//   _lakh, wess_, _केकड, _सभके_, 
   {{0x3958038f,0x63ac02d0,0x4a200166,0x03940241}},	//   tess_, _mmbn, ньяб, _ńfọb, 
   {{0x6564835b,0xd2b4011a,0x00000000,0x00000000}},	//   _nakh, ללית_, --, --, 
   {{0x3958835c,0x00000000,0x00000000,0x00000000}},	//   ress_, --, --, --, 
   {{0xcb64835d,0x656401d9,0xc4c4009e,0x47840150}},	//   _наче_, _aakh, ্ধাঙ, нысб, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x63ac02d0,0x65640055,0xcad40375,0x291802dd}},	//   _ambn, _cakh, _מוות_, _ﺷﻪﭖ_, 
   {{0x656401d9,0x7a08012c,0xf8e00037,0x2920012d}},	// [9f70] _dakh, _děte, _नरिय, óraś_, 
   {{0x889c0375,0x656402d0,0x25b00076,0x44b421f3}},	//   _לבחי, _eakh, aiyl_, хбус, 
   {{0xdb180023,0x48740330,0x33200327,0x00000000}},	//   entë, _قدیس, rahx_, --, 
   {{0xc2c4835e,0xda640014,0x00000000,0x00000000}},	//   ريني, _یُ_, --, --, 
   {{0x0f70016c,0xdb182b96,0x5ea80154,0xed580010}},	//   нғар, botø, _চুলে, vež_, 
   {{0x6564835f,0x35a00092,0xc3480024,0x00000000}},	//   _zakh, _ግሽበት_, _нясе_, --, 
   {{0x6564124c,0xed581a48,0x12844eb9,0x00000000}},	//   _yakh, tež_, _عمری_, --, 
   {{0x9624005f,0x7f94002e,0x9d5000d1,0xac08035b}},	//   _ieņē, _yàqk, ننىت, ониа_, 
   {{0x1c400c9e,0x29d00174,0xa7380118,0x40343e4f}},	//   вным, káar_, áčká, _петс, 
   {{0x53bc00dc,0x00000000,0x00000000,0x00000000}},	//   ्विश, --, --, --, 
   {{0x52d88360,0xed581f48,0x0dc80b16,0xdf5400f1}},	//   _भरोस, pež_, _луди_, _زرلښ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x65646e7a,0x2d9c0117,0x53bc01bc,0xab280354}},	//   _rakh, _ilwe_, ्वाश, _дола_, 
   {{0x66e48361,0x65648362,0xdce0000d,0xfd58010e}},	//   дога, _sakh, _परतछ, klaỳ, 
   {{0x65640925,0x73cc01f2,0x96240171,0x00000000}},	//   _pakh, ụọta, _neņē, --, 
   {{0xdb187ea5,0x556003cc,0x693401ef,0x00000000}},	//   entè, نۇپك, _břež, --, 
   {{0x65648363,0x26dc0793,0xbb440150,0x7a08013a}},	// [9f80] _vakh, ütob_, _ﺘﻴﻥ_, _věte, 
   {{0x65644b26,0xbef00248,0x00000000,0x00000000}},	//   _wakh, _iṣẹ́, --, --, 
   {{0x65648364,0x2d9c8365,0xe72c0166,0xe5a45a52}},	//   _takh, _olwe_, _idе_, _жини, 
   {{0xe0d8682f,0xdb180165,0x00000000,0x00000000}},	//   ове_, antè, --, --, 
   {{0x9fc80b32,0x745402e8,0x00000000,0x00000000}},	//   огда_, _пърх, --, --, 
   {{0x2d9c8366,0x2bdc8367,0x63ac03ac,0xdb8000d1}},	//   _alwe_, _नीला, _umbn, _ﺩﯦﺪﻯ_, 
   {{0x1ea819bc,0xa3d800e1,0x1718010f,0x261001f9}},	//   غاتي_, _डीए_, קוקע, धीची_, 
   {{0x66180030,0xc0c4010b,0xd59800df,0x00000000}},	//   átky, _пәли, ַביל, --, 
   {{0x244c0020,0xca60022e,0xdb5800cf,0x00000000}},	//   _ኃላፊነ, _senа, оюн_, --, 
   {{0x2d9c8368,0x5478008f,0x661802f0,0x00000000}},	//   _elwe_, קטיו, štky, --, 
   {{0xa3e411b1,0xd3340302,0x4c1000f2,0xe4ec00cd}},	//   _पठन_, וריה_, _یبوس, चेति_, 
   {{0xdb180129,0x49740138,0xd7f80120,0x7aa400cf}},	//   inté, влюс, жув_, диүз, 
   {{0x3f8c8369,0xc32400bd,0x0c2000c7,0x1b20015b}},	//   _kodu_, _পানি_, _амчн, _মাঠে_, 
   {{0xd90c608c,0x36d4836a,0x3f8c836b,0x00000000}},	//   دیک_, еогр, _jodu_, --, 
   {{0x3f8c836c,0xdce00558,0x956401d5,0x00000000}},	//   _modu_, _maoč, мъад, --, 
   {{0x28a83c71,0x6934012c,0xc9d800d1,0x3f8c836d}},	//   _चेकि, _přež, ﯟﺍﻟﻐ, _lodu_, 
   {{0xdb18836e,0x3374836f,0xa5080075,0x81e400fe}},	// [9f90] enté, нгар, سىلە_, নদা_, 
   {{0xdce02ce2,0x3f8c19f5,0x7f94002e,0xb9d8001f}},	//   _naoč, _nodu_, _fàqi, _አሊ_, 
   {{0xc7b40134,0x798c00b0,0x07440022,0x660806be}},	//   _kwɑn_, _koaw, _рхым, _çfkp, 
   {{0x003402d3,0xdd848370,0x55600150,0x42e401af}},	//   _ኣይኮና, _صو_, _جۇرك, тцуб, 
   {{0x1ca80003,0xa5c04445,0x3f8c0122,0x00000000}},	//   ྔགས_, _сөре, _bodu_, --, 
   {{0x3f8c0ffb,0x28b0258d,0x6d9401e1,0x00000000}},	//   _codu_, ीपति, _táak, --, 
   {{0x3f8c597b,0xdce00171,0x74e000eb,0x00000000}},	//   _dodu_, _kloķ, _ভলিউ, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x61441b16,0x69c41d1d,0x00000000,0x00000000}},	//   _سىلە, _íhei, --, --, 
   {{0x3f8c8371,0x0a300201,0x1ee8004b,0x271c0118}},	//   _godu_, _በተለያ, _کومی_, _बजेर_, 
   {{0xa9688372,0xe7381de6,0xdb20179e,0x37b400fe}},	//   пина_, үем_, دوپی, ংকাৰ, 
   {{0x2d9c293d,0xa968026a,0xdce000d0,0x3f8c00ef}},	//   _ulwe_, чима_, _zaoč, _zodu_, 
   {{0x4acc1fbc,0x9d18008f,0x22a401e1,0xdb181155}},	//   _सुरव, _זונט, _kíké_, lotý, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x798c00ad,0xda6c0451,0x66000841,0xdce000e2}},	//   _foaw, _هُو_, _čoks, _bloķ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x1b2000fe,0x2804033f,0x287400cf,0x21c801ec}},	// [9fa0] _মাতে_, ówną_, _чыйр, _ﻓﺂﺨﺭ, 
   {{0x798c009a,0x22a401e1,0x9340005b,0xdb1800c7}},	//   _zoaw, _níké_, лнуе, kotý, 
   {{0x3f8c8373,0xa2e48374,0x6d4c0694,0x56e002dd}},	//   _rodu_, хожд, _ñaaw, _бұрғ, 
   {{0xf1a88375,0x3f8c8376,0x69d4037e,0xdb180306}},	//   وانه_, _sodu_, _jkye, dotý, 
   {{0xc4482094,0xfaf8005f,0xa6c000eb,0x00000000}},	//   _زیان_, ldīt_, _এরিয়, --, 
   {{0x3f8c03b9,0x00000000,0x00000000,0x00000000}},	//   _qodu_, --, --, --, 
   {{0x69d48377,0x81c800e5,0x00000000,0x00000000}},	//   _okye, _قطرہ_, --, --, 
   {{0x69d40605,0x3f8c013f,0xc0d00092,0x00000000}},	//   _nkye, _wodu_, ብሯል_, --, 
   {{0x8d7000e3,0xbebc00de,0x00000000,0x00000000}},	//   طايا, _adīt, --, --, 
   {{0x69d40605,0x8c5000c6,0xdb1800c7,0x9e70129d}},	//   _akye, ائيا, botý, _مۇتت, 
   {{0x798c06c8,0x69d40083,0x533400c8,0xdb1801b8}},	//   _poaw, _bkye, ענטן_, motü, 
   {{0xdb1801b8,0xba240137,0x50600022,0x00000000}},	//   lotü, ндүк, _рҕәҕ, --, 
   {{0xc4c400cc,0xbebc00de,0xca440345,0x00000000}},	//   ্ধুজ, _edīt, ولیه_, --, 
   {{0x69d48378,0xdb18000d,0x00000000,0x00000000}},	//   _ekye, notü, --, --, 
   {{0x36d41b88,0x798c8379,0x00000000,0x00000000}},	//   товр, _toaw, --, --, 
   {{0x45d40a93,0x00000000,0x00000000,0x00000000}},	//   госс, --, --, --, 
   {{0xf3f803b7,0x89d80050,0x00000000,0x00000000}},	// [9fb0] днаш_, _سوٝر_, --, --, 
   {{0x23680789,0xf11800e1,0xcb10010f,0x00000000}},	//   _cabj_, दर्द_, ָלף_, --, 
   {{0x236801bf,0xdb185f0b,0x75d4009a,0xc7d80677}},	//   _dabj_, lotó, _ليدا, _אוזי_, 
   {{0x7f9400f7,0x8234837a,0x3134837b,0xb4b401c0}},	//   _màqu, ارلا, тедр, _аймш, 
   {{0xdb18837c,0x7f940de2,0x0fe001c6,0x95700092}},	//   notó, _làqu, гөжү, _ከሙታን_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6da402f4,0xada42708,0xee3800d4,0x5f9000d8}},	//   кика, какл, єни_, ријт, 
   {{0xdb181f6f,0xdd8c00c6,0xed58013e,0xa28000e5}},	//   kotó, قوى_, фои_, _خیمو, 
   {{0xdd8c837d,0xc32403d4,0x9c20010b,0x6ab80dba}},	//   توي_, _পাতি_, адыд, उप्र, 
   {{0x69d41088,0xedc4004b,0x4ea400f3,0x09bc07b6}},	//   _skye, رېږي_, _преа, ोक्य, 
   {{0x3af47fb5,0xae0402dd,0xa9a45a92,0x7a080118}},	//   ляюс, _شوشى, винд, _pěta, 
   {{0x6994303d,0xdb1801d3,0x2cd4014b,0x7c3403b2}},	//   трох, fotó, _июлр, ýfrí, 
   {{0x6b64837e,0x00000000,0x00000000,0x00000000}},	//   _акла, --, --, --, 
   {{0x4acc29c8,0x37c414d4,0xeab83e38,0x00000000}},	//   _सुअव, лғым_, _ойл_, --, 
   {{0x92000882,0x7d10003e,0xfaf800e2,0xfbd016ac}},	//   _śānt, _éksé, udīt_, _اتن_, 
   {{0xdb180210,0x00000000,0x00000000,0x00000000}},	//   botó, --, --, --, 
   {{0xdb1804d4,0x2328013e,0x00000000,0x00000000}},	// [9fc0] cotó, дози_, --, --, 
   {{0x26d813fd,0xe298837f,0x22b88380,0x93c81893}},	//   _typo_, маз_, وداع_, والہ_, 
   {{0xe2840801,0x17980375,0xdb1829ef,0x97340375}},	//   ължи, _חייב, votü, _בריא_, 
   {{0x94402832,0x55500050,0x5440215c,0x00000000}},	//   _چھلن, _پھِر, انەك, --, 
   {{0xd0040c04,0x21248381,0x1b2000bd,0x95b001c0}},	//   вече_, raoh_, _মাসে_, _төрх, 
   {{0xdef88382,0x4fd00212,0x00000000,0x00000000}},	//   мый_, ажіт, --, --, 
   {{0xbebc00b8,0x84c400d1,0x7374010b,0x3ce00010}},	//   _adīr, _рәңд, _сыях, _šiv_, 
   {{0x4f040598,0xfe7801c6,0x83a40124,0xfcc48383}},	//   ннән_, _үүд_, _рыҭҵ, ләлм, 
   {{0x7f940de2,0x7c941867,0xa3e40dba,0x00000000}},	//   _sàqu, الخص, _पठा_, --, 
   {{0x5fb4007d,0x1b200011,0x9eb40108,0xdd9001c8}},	//   _अगिल, _মাহে_, _ищеш, _ھوش_, 
   {{0xdd908384,0xdb0803b2,0x2fc80129,0x2ca003b9}},	//   _پوش_, _umfí, éage_, _əhdi_, 
   {{0xdb1803b2,0x00000000,0x00000000,0x00000000}},	//   totó, --, --, --, 
   {{0x8c406799,0xed4c0451,0x19f40050,0x7c340884}},	//   _вече, _رھي_, _یِتھ_, _селх, 
   {{0xc7c48385,0xdb188386,0xccc00139,0x00000000}},	//   асси, rotó, _әбәй, --, 
   {{0xdb183702,0xb9080f22,0x999c00b0,0x5a440064}},	//   botò, _বল_, nutū_, _рэла, 
   {{0xdb188387,0x49c80daf,0x6d4c1bce,0x95c8011c}},	//   cotò, _үлән_, _ñaat, фуга_, 
   {{0x39480267,0xb3548388,0x058435e3,0x799c02d0}},	// [9fd0] _icas_, лкаш, шурм, mksw, 
   {{0x38688389,0x999c02b5,0x28b00404,0x13bc00cd}},	//   _isar_, kutū_, ीपरि, ्वेभ, 
   {{0x720400dd,0x5184001b,0x799c03ac,0x00000000}},	//   اہرہ_, куда, oksw, --, 
   {{0x38680198,0x3d1c012d,0x00000000,0x00000000}},	//   _ksar_, नरों_, --, --, 
   {{0x62882d75,0x65540a7c,0x5344010a,0x00000000}},	//   øfor, _גברא_, _ихва, --, 
   {{0x7204838a,0x889c0375,0x53a435a7,0x7888036e}},	//   _موسم, ובדי, _गतिश, _zëvë, 
   {{0x28d80cb3,0x59d0813f,0xdb1803b2,0x3948013a}},	//   _युनि, सवार, gntí, _ocas_, 
   {{0x394801d4,0x7bd8838b,0x799c0d27,0x5e54007b}},	//   _ncas_, _akvu, jksw, اليس_, 
   {{0x5eb004a9,0x50b417c6,0x4ba00116,0x9ed411ca}},	//   ийәт, _अधिष, илиң, кмәт_, 
   {{0xcee85035,0x3948838c,0x799c01f5,0x3dd8025c}},	//   _قران_, _acas_, eksw, _ġewż_, 
   {{0x3868838d,0x316c030a,0xfb840066,0x2bd40118}},	//   _asar_, _kaez_, شگوی, ठकबा, 
   {{0x394806af,0xf76805d0,0x00000000,0x00000000}},	//   _ccas_, _מק_, --, --, 
   {{0x316c0dd4,0x386801e4,0xdb18004e,0xbebc00cd}},	//   _maez_, _csar_, rotò, _udīr, 
   {{0x3948838e,0xaa44838f,0x316c05c7,0xdc38011a}},	//   _ecas_, _бекл, _laez_, _נעצר, 
   {{0x38688390,0x2ca800d7,0xdb4c009f,0x58200150}},	//   _esar_, _ľady_, _رَي_, _қмэб, 
   {{0xdb0800d2,0x799c581c,0x39480332,0xe2980022}},	//   _imfá, cksw, _gcas_, ҭаа_, 
   {{0x87e800ee,0xb4248391,0xa3e80120,0xe8f808da}},	// [9fe0] _илиң_, لعلو, едаа_, _яли_, 
   {{0x6e20035a,0x05140154,0xc33000d1,0x00000000}},	//   _owlb, িণের_, غەز_, --, 
   {{0x316c0007,0xdb9800c8,0x69c40162,0xe0d00116}},	//   _baez_, עסער, _íhes, ڭزا_, 
   {{0x316c0399,0xe1240853,0x6f0002d0,0x64a48392}},	//   _caez_, умди, _aglc, _бама, 
   {{0x316c0369,0xdfd80801,0x76a8002e,0x00000000}},	//   _daez_, нък_, _tëyé, --, 
   {{0x999c8393,0xfe780139,0x00000000,0x00000000}},	//   tutū_, күз_, --, --, 
   {{0x9338044e,0x316c05b1,0x799c002d,0x6d9403b2}},	//   _ኣምባሳ, _faez_, yksw, _náas, 
   {{0x8e440131,0x3f9c8394,0xdc8800d8,0x00000000}},	//   چلۈك_, skvu_, есол_, --, 
   {{0x5b242ecc,0x1e848395,0xd12c592e,0x519000c6}},	//   льна, _әлем, _رمل_, _القذ, 
   {{0x8d80013e,0x00000000,0x00000000,0x00000000}},	//   _ҳушд, --, --, --, 
   {{0xdee4442d,0xd35408a8,0x8f980375,0x6d9401e1}},	//   _сожи, ניטי_, _ריבי, _páat, 
   {{0x88b0016b,0x6d9401e1,0x00000000,0x00000000}},	//   _mfɛf, _dáas, --, --, 
   {{0x799c8396,0xdd940124,0x3868025c,0x5ea800cc}},	//   rksw, _иаҧы, _qsar_, _চুচে, 
   {{0x6d4c3d27,0xd4980588,0xb8fc8397,0x6d94022c}},	//   _ñaar, ҭра_, _तँ_, _fáas, 
   {{0x394805b1,0xabcc00d1,0x00000000,0x00000000}},	//   _tcas_, _ﮔﯘﻧﺎ, --, --, 
   {{0x39488398,0x75142c31,0x454800db,0x00000000}},	//   _ucas_, рмаф, лчум_, --, 
   {{0x38688399,0x316c0399,0xfd4c0241,0x7f940de2}},	// [9ff0] _usar_, _raez_, _balẹ, _làqq, 
   {{0x44f47257,0x69c402d2,0x00000000,0x00000000}},	//   спус, _íher, --, --, 
   {{0xa3e4000d,0x00000000,0x00000000,0x00000000}},	//   _पठर_, --, --, --, 
   {{0xd5641920,0xae6803e6,0x6d940ca8,0xeac000cc}},	//   _стоп, ێڕان_, _láar, _উৰুম, 
   {{0xc32400bd,0xceb000f7,0x316c030a,0x522400fd}},	//   _পারি_, өшкө, _vaez_, _әфга, 
   {{0xb81c05d7,0x73c4839a,0xf3f00248,0x5348030d}},	//   बीएम_, _тәбе, _ọ̀_, _чăкă, 
   {{0x7f9400e8,0x9f94147e,0x00000000,0x00000000}},	//   _càqq, рвју_, --, --, 
   {{0x7f9400e8,0x6f0002d0,0x301400d4,0x82d800f3}},	//   _dàqq, _wglc, _вдар, _сдсс_, 
   {{0x7a08012c,0xdb1800d8,0x2bc80075,0xece8466e}},	//   _dětm, mitê, клип_, ъдил_, 
   {{0xdb1870da,0xeb98026a,0xd1c40023,0x00000000}},	//   litê, тио_, _ጸበባ_, --, 
   {{0x4acc5096,0xdd8c17b9,0xfe780064,0xbbe8007b}},	//   _सुखव, سوی_, _grį_, دريم_, 
   {{0xddd8012c,0x1ee8249f,0xdb18839b,0xf1c42cbb}},	//   _ostř, _شونی_, nitê, लचिन, 
   {{0x6d58015c,0x2d8c01f7,0x00000000,0x00000000}},	//   _ibwa, mjee_, --, --, 
   {{0x2d8c839c,0x2bdc3ee1,0x6d5802d0,0x7f940de2}},	//   ljee_, _नीचा, _hbwa, _yàqq, 
   {{0xb8fc1161,0xaa44839d,0xc32404c5,0x8c400032}},	//   _तु_, _тейл, _পালি_, _теҙе, 
   {{0x2d8c839e,0xd5e80051,0x00000000,0x00000000}},	//   njee_, _địc, --, --, 
  
   {{0x6d58839f,0x9f5c011f,0x69c40472,0x2cac3f65}},	// [a000] _mbwa, _ditê_, mnke, nzed_, 
   {{0x2cac0204,0xdb1800c6,0x69c4003e,0x6d5803ac}},	//   ized_, ontá, lnke, _lbwa, 
   {{0x6d582f99,0x7afc05be,0x69c483a0,0xd24c0014}},	//   _obwa, žrtv, onke, ِنم_, 
   {{0x69c483a1,0x6d5802d0,0x2d8c83a2,0xa50883a3}},	//   nnke, _nbwa, jjee_, _шема_, 
   {{0x2d8c062c,0x69c483a4,0xfd4c01e1,0x00000000}},	//   djee_, inke, _talẹ, --, 
   {{0x6d5883a5,0x2cac0165,0x9e640d2f,0x3e3400ae}},	//   _abwa, dzed_, لابن, مفتر, 
   {{0x6d580857,0x69c40083,0x8e8000f2,0x2fc800ae}},	//   _bbwa, knke, قلوه, éaga_, 
   {{0x6d5802d0,0x69c483a6,0x00000000,0x00000000}},	//   _cbwa, jnke, --, --, 
   {{0x61e083a7,0xdb1883a8,0x6d580857,0xd1b001d3}},	//   mlol, entá, _dbwa, _بینک, 
   {{0x291005d9,0xbbd00316,0x6d5883a9,0x2d8c0e14}},	//   _afya_, सकेक, _ebwa, ajee_, 
   {{0x6aac02a8,0x2d8c0810,0xdb1883aa,0x6d5803ac}},	//   _ƙafa, bjee_, kotö, _fbwa, 
   {{0x61e083ab,0xdd9003e6,0x6d580857,0x9200002b}},	//   nlol, _گوڵ_, _gbwa, _śākt, 
   {{0x61e00607,0xdb1883ac,0xd8c8084c,0x29d0011f}},	//   ilol, dotö, тынд_, náay_, 
   {{0x61e083ad,0x69c45604,0x7ac40166,0x00000000}},	//   hlol, anke, _гөма, --, 
   {{0x6d5805b1,0x61e083ae,0xd9b00050,0xdb1883af}},	//   _ybwa, klol, _ؤتھ, fotö, 
   {{0xdb1883b0,0x61e001e4,0x8af80677,0x00000000}},	//   gotö, jlol, _בלוז, --, 
   {{0x61e083b1,0x16640131,0xdb180240,0xccf0010f}},	// [a010] dlol, _ھەرپ_, jitë, ַכע_, 
   {{0x9f5c069c,0xdb1802d3,0xddd8012c,0xed5801a6}},	//   _ditë_, ditë, _vstř, miže_, 
   {{0xed5883b2,0x32543591,0xd2440276,0x2cac045a}},	//   liže_, свер, рэзи, zzed_, 
   {{0x61e083b3,0x2cac020b,0x88040014,0x51840120}},	//   glol, yzed_, _دِیو, јужа, 
   {{0xed58009b,0x4174215c,0x752c04ba,0x94844c34}},	//   niže_, تالس, maaz, _тынд, 
   {{0x111c069c,0x752c83b4,0xdb1800d8,0x6d5803ac}},	//   ስትያና, laaz, sitê, _sbwa, 
   {{0xed5883b5,0x61e0083c,0x69c483b6,0xdb1883b7}},	//   гой_, blol, ynke, mitè, 
   {{0x752c83b8,0xdb1883b9,0x61e00421,0x9f5c02e2}},	//   naaz, litè, clol, _litè_, 
   {{0x2d8c83ba,0x2cac05c7,0x6d5803ac,0xdb180200}},	//   rjee_, uzed_, _vbwa, citë, 
   {{0xed5805ce,0x752c0109,0xdb18004e,0x2cac83bb}},	//   diže_, haaz, nitè, rzed_, 
   {{0xeab805f5,0x752c83bc,0x2cac01ed,0x6d58035a}},	//   уйн_, kaaz, szed_, _tbwa, 
   {{0x6d580537,0x752c0083,0xfe700214,0xdb1802e2}},	//   _ubwa, jaaz, _زدم_, hitè, 
   {{0xdd8c83bd,0x69c483be,0x752c04ba,0x6d48002d}},	//   _سوو_, rnke, daaz, mgea, 
   {{0x6d4883bf,0xab2883c0,0xaa8400a2,0xa3e4000d}},	//   lgea, _сока_, guýç, _पठइ_, 
   {{0x66e483c1,0x78c011a9,0xdb1883c2,0x4acc0490}},	//   сова, _əvvə, zitë, _सुचव, 
   {{0x6d4883c3,0xdb080036,0x752c83c4,0xa924005b}},	//   ngea, _emfä, gaaz, _удил, 
   {{0x6d487ea1,0x61e00109,0xdb1883c5,0x46440014}},	// [a020] igea, vlol, fitè, _ژھرِ, 
   {{0x6d484266,0xdb18036e,0x1c08000d,0x9f5c036e}},	//   hgea, vitë, _हंसल_, _vitë_, 
   {{0x61e083c6,0x752c0a49,0x672c0165,0x6d48005c}},	//   tlol, baaz, mabj, kgea, 
   {{0x61440a70,0x9f5c19f5,0xdb180240,0x61e083c7}},	//   седа, _zitè_, titë, ulol, 
   {{0x61e01c06,0x6d4883c8,0x8e4483c9,0x7a080118}},	//   rlol, dgea, ەلىك_, _pětk, 
   {{0xdb1883ca,0x9f5c0cd9,0x29d0011f,0x33d402bf}},	//   ritë, _kité_, ráay_, _діст, 
   {{0x6d4883cb,0x8e340fb4,0xdb1883cc,0x00000000}},	//   fgea, مسير_, sitë, --, 
   {{0xdb1883cd,0x61e001b9,0x7170215c,0xeea801ec}},	//   mité, qlol, _يۇلا, штік_, 
   {{0xdb1883ce,0xd18000ee,0x629c83cf,0x9f5c013a}},	//   lité, _элтй, lypo, _lité_, 
   {{0x6d4883d0,0x752c83d1,0xdb0801e3,0xdb681422}},	//   agea, zaaz, _omfå, урил_, 
   {{0xdb1883d2,0x6d480332,0x00000000,0x00000000}},	//   nité, bgea, --, --, 
   {{0x394c83d3,0x1d081377,0x9f5c007f,0x6d4800b5}},	//   ües_, _седи_, _sitè_, cgea, 
   {{0x63bc2dba,0x1ee80efc,0x752c000f,0xdb18007f}},	//   kipn, _شوچی_, vaaz, yitè, 
   {{0x48a82cfe,0x752c2dff,0x629c01f4,0x672c02d2}},	//   стюм_, waaz, kypo, gabj, 
   {{0x9f5c83d4,0x629c20e5,0x7bc80921,0x752c1418}},	//   _cité_, jypo, mndu, taaz, 
   {{0x9f5c05da,0xdb1883d5,0x629c045a,0x92e80145}},	//   _dité_, dité, dypo, ۇراق_, 
   {{0x672c00ca,0xddd846e4,0xc23c01ec,0x752c83d6}},	// [a030] babj, _artū, _ءﺟﯘﻧ, raaz, 
   {{0xdb180a40,0x9f5c00db,0x842406ba,0x7bc883d7}},	//   fité, _fité_, سىمن, nndu, 
   {{0x752c83d8,0xdb18020c,0x6d48002d,0xf1b8035b}},	//   paaz, ritè, ygea, аӡа_, 
   {{0x7bc883d9,0xdb1835a5,0x91281411,0x00000000}},	//   hndu, sitè, اساق_, --, 
   {{0x7bc8020c,0xdb1883da,0x6d4804cc,0x7a08013a}},	//   kndu, pitè, vgea, _děti, 
   {{0xd9cc00bd,0x65a80122,0x629c83db,0xdb1883dc}},	//   রতিম, _výhe, bypo, bité, 
   {{0xdb1883dd,0x6d4883de,0x629c2315,0x629803e0}},	//   cité, tgea, cypo, _ütop, 
   {{0x7bc883df,0x6d48003a,0x00000000,0x00000000}},	//   endu, ugea, --, --, 
   {{0x6d4883e0,0x6aac0198,0x7bc801a8,0x00000000}},	//   rgea, _ƙafo, fndu, --, 
   {{0x6d4883e1,0x7bc80007,0x00000000,0x00000000}},	//   sgea, gndu, --, --, 
   {{0x6d4883e2,0x4ea422cb,0x9f4801e1,0x00000000}},	//   pgea, _ураа, _òbá_, --, 
   {{0x7bc80022,0x54f807f7,0xe9d8010b,0xdd0c03e0}},	//   andu, ्शाए_, ркм_, mışk, 
   {{0xcce404b3,0x629c068f,0xdd0c0baa,0xa2e483e3}},	//   _اساي, zypo, lışk, _कर्ज_, 
   {{0x7c240724,0xdb1801e3,0x9c60009f,0x00000000}},	//   _çira, gntä, _آڇيو, --, 
   {{0x672c83e4,0xdb180036,0x629c0076,0x65b80022}},	//   rabj, xité, xypo, ауар_, 
   {{0xdb1883e5,0x672c009a,0x629c0306,0x00000000}},	//   vité, sabj, vypo, --, 
   {{0xe3b000aa,0xe73883e6,0x9f5c00f2,0x3948021f}},	// [a040] ورئ_, _кеп_, _wité_, _اشىپ_, 
   {{0xdb1883e7,0x21200fc8,0x629c83e8,0xe5183507}},	//   tité, मर्श_, typo, _फ्रि_, 
   {{0x63bc83e9,0x7a0800bc,0x00000000,0x00000000}},	//   ripn, _pěti, --, --, 
   {{0xdb1883ea,0xd87483eb,0x518083ec,0xdd0c0139}},	//   rité, _امیت_, душа, dışk, 
   {{0x7bc883ed,0x629c0588,0xdb1883ee,0x00000000}},	//   yndu, sypo, sité, --, 
   {{0x2d9883ef,0x8fa0562a,0x63bc0023,0xdb180332}},	//   ösen_, маче, qipn, pité, 
   {{0x7bc8022c,0x216883f0,0xe2983edb,0xe16400f1}},	//   vndu, _киви_, _тав_, _ودري, 
   {{0xdc1c00bd,0x65740124,0x5f7400dd,0x81d40183}},	//   _দিবস_, ndyh, _ڈائر, _হওক_, 
   {{0xdb1802f6,0x645483f1,0x5f744028,0x00000000}},	//   yntä, ntyi, _وائر, --, 
   {{0xa3e8190c,0xda7883f2,0x6454004c,0x3b5483f3}},	//   मति_, аям_, ityi, чкор, 
   {{0x645483f4,0x7bc801a8,0xcf90011a,0x00000000}},	//   htyi, rndu, _קטע_, --, 
   {{0x0e140345,0x00000000,0x00000000,0x00000000}},	//   _بکوژ_, --, --, --, 
   {{0xa3e81788,0xfc146bd5,0x00000000,0x00000000}},	//   मता_, _эмлэ, --, --, 
   {{0xed58107d,0xcb64041b,0x7de40244,0x201401e1}},	//   miža_, _маче_, _بسڕم, _ọọru, 
   {{0xb5c800c6,0xed5807f5,0xdb18007c,0xfaa801e2}},	//   موسم_, liža_, rntä, _دهغي_, 
   {{0x923c044e,0x383400d1,0x49b8007b,0x0574009a}},	//   _ኣፍሪቃ, _енир, _وايد_, واقد, 
   {{0x20f40055,0xcd940375,0x482400f7,0x764001d3}},	// [a050] _dṛkṣ, קדמת_, _قىيق, ályb, 
   {{0x97a466b4,0x8c18011a,0xdedc0023,0x00000000}},	//   _фрил, יומי, ዕርን_, --, 
   {{0xf67401c0,0x00000000,0x00000000,0x00000000}},	//   _эгнэ, --, --, --, 
   {{0x6618295a,0x61446911,0x00000000,0x00000000}},	//   ítke, كىمە, --, --, 
   {{0x0f70036b,0xb6c800e5,0x00000000,0x00000000}},	//   мғар, _خاکے_, --, --, 
   {{0x1b2000bd,0xed580010,0xc3483cc5,0xe4f8011a}},	//   _মাঝে_, diža_, _мясе_, _לפרש, 
   {{0x6da401d5,0xada483f5,0x00000000,0x00000000}},	//   зийа, зайл, --, --, 
   {{0x0d34001f,0xd1b802f2,0x00000000,0x00000000}},	//   _ኮምፒው, _ئاسا_, --, --, 
   {{0x1b200183,0x00000000,0x00000000,0x00000000}},	//   _মাজে_, --, --, --, 
   {{0x95080156,0x2000007f,0xdd0c0790,0x5f4000db}},	//   _ཀུའི_, _ékip_, pışk, _كچىل, 
   {{0xe9d883f6,0x0dc802bf,0xd1d80023,0x7c240166}},	//   йко_, _куди_, _ዕሙቕ_, _çirn, 
   {{0x6454023a,0xed58310a,0x00000000,0x00000000}},	//   ytyi, biža_, --, --, 
   {{0x98b80166,0x00000000,0x00000000,0x00000000}},	//   _baqı_, --, --, --, 
   {{0x291c010f,0x18640798,0x00000000,0x00000000}},	//   ŝta_, џари_, --, --, 
   {{0x5690036b,0x65a800a2,0x442c0100,0x20f400b8}},	//   наёт, _aýha, _ňd_, _pṛkṣ, 
   {{0x645483f7,0xa9240510,0x1a98008f,0x6aa002d0}},	//   ttyi, _эдил, _ליצע, mylf, 
   {{0x02c453c3,0x20f40882,0xe568151e,0xa444024c}},	// [a060] वप्न, _vṛkṣ, _һинд_, янад, 
   {{0xdb08000f,0x645483f8,0x7a0800bc,0x54c01620}},	//   _alfê, rtyi, _větv, хбуб, 
   {{0x66e483f9,0x179800c8,0x6454023a,0xdb18000f}},	//   _хона, _הייב, styi, entû, 
   {{0xd24c83fa,0x645483fb,0xc0dc0023,0x2d98002f}},	//   طنه_, ptyi, _ዕሉል_, ösel_, 
   {{0xd12c83fc,0x6604013c,0x95c40801,0xc5f807f7}},	//   امه_, _iikk, _хляб_, ंगीय_, 
   {{0x442083fd,0x660483fe,0x9f4c04cc,0x98b8008e}},	//   mpi_, _hikk, umfà_, _xaqı_, 
   {{0x442083ff,0x66048400,0x97540375,0xdd700014}},	//   lpi_, _kikk, פיקו_, ٹھاک, 
   {{0x66048401,0x44208402,0xe1940323,0xdb0800d2}},	//   _jikk, opi_, _эргэ, _umfú, 
   {{0x44201bb7,0x9be40006,0xdb08036b,0x00000000}},	//   npi_, зінк, یزگه_, --, 
   {{0x44208403,0xdf14074d,0x3d080d79,0x7a388404}},	//   ipi_, _хьаь, _हलके_, опор_, 
   {{0x4420003e,0xfe3c037e,0xa6c8022e,0x66040108}},	//   hpi_, mはok_, _zdаv, _oikk, 
   {{0xdb188405,0x44200986,0x19a868eb,0x00000000}},	//   mití, kpi_, стоп_, --, 
   {{0xdb188406,0x44208407,0x588402d5,0x9f5c01ef}},	//   lití, jpi_, чына, _lití_, 
   {{0x44208408,0x2bd80014,0x660401f4,0xcc38011a}},	//   dpi_, _واوک_, _aikk, _פעוט, 
   {{0x66048409,0x9a84840a,0xdb180030,0x7d040332}},	//   _bikk, _хулл, nití, _úisb, 
   {{0x6604066d,0xb7d800e5,0x00000000,0x00000000}},	//   _cikk, _ڈوبا_, --, --, 
   {{0x6604840b,0x93243009,0x4420079b,0x9f5c035b}},	// [a070] _dikk, كران, gpi_, _mitâ_, 
   {{0x9f5c840c,0x6604840d,0xdb1800d8,0x8c180375}},	//   _bití_, _eikk, litâ, צובי, 
   {{0x35f43967,0x4420840e,0x9f5c0332,0xa2c00131}},	//   _опор, api_, _cití_, вәтк, 
   {{0x88b0016b,0x4420840f,0x660404ba,0x9f5c01e1}},	//   _mfɛn, bpi_, _gikk, _dití_, 
   {{0x92000882,0xf7400023,0x9f5c0332,0x44200356}},	//   _śāst, _ንምድን, _eití_, cpi_, 
   {{0xdb188410,0x660404ba,0x21ec00e4,0x00000000}},	//   antú, _zikk, rýha_, --, 
   {{0x6604002e,0xdb180419,0x8e0000d1,0x00000000}},	//   _yikk, gití, ىكتۇ, --, 
   {{0x66040548,0x7db40006,0x00000000,0x00000000}},	//   _xikk, есьц, --, --, 
   {{0x2cb800a3,0x7c248411,0xb9100241,0x00000000}},	//   àsd_, _çirl, balẹ_, --, 
   {{0xdb180306,0x2bb8007b,0x6aa0007c,0x00000000}},	//   bití, تابة_, tylf, --, 
   {{0x9f5c0421,0x44208412,0x753c0034,0xdb188413}},	//   _fitâ_, zpi_, _odsz, cití, 
   {{0x44201bb7,0x1ee80214,0x59801422,0xcfe40244}},	//   ypi_, _بومی_, влюб, _بفڕه_, 
   {{0x66048414,0x3a200010,0x44200113,0x6aa00042}},	//   _rikk, _čipe_, xpi_, sylf, 
   {{0x66047eb1,0x753c00a2,0xdb8001c0,0xeab0007b}},	//   _sikk, _adsz, _агши, _لعب_, 
   {{0x66048415,0x7a08038e,0x44200bf1,0x203c0023}},	//   _pikk, _děts, wpi_, _ኣይትረ, 
   {{0xdb188416,0x442002d1,0x92dc03d4,0x00000000}},	//   citâ, tpi_, দেৱ_, --, 
   {{0xdb181a58,0x44208417,0x2ec800cd,0x00000000}},	// [a080] zití, upi_, िपुत, --, 
   {{0x66048418,0x9f5c8419,0xdb1800e4,0x00000000}},	//   _wikk, _mitã_, mitã, --, 
   {{0x6604841a,0x4420841b,0xa50800d8,0xe5080137}},	//   _tikk, spi_, _мена_, _ويدو_, 
   {{0x4420841c,0x64a4841d,0xa06807d6,0x661c05da}},	//   ppi_, _жама, жада_, _itpk, 
   {{0xdb180798,0x442003f0,0xe7d000cd,0xf1d4009d}},	//   nitã, qpi_, _सदाप, хөрө, 
   {{0x76c401d5,0x5e840334,0xdb0806ea,0xdb1816f6}},	//   _آغیل, дуиз, _umfø, tití, 
   {{0xd12c0075,0x8fc000b8,0x00000000,0x00000000}},	//   امۇ_, _ṛjīṣ, --, --, 
   {{0xdb18841e,0xdbc4013d,0xe0d8009b,0x00000000}},	//   rití, _köçn, _двб_, --, 
   {{0x21244c8f,0x9f5c003a,0x9b68074d,0xdb18841f}},	//   mboh_, _vitâ_, ошна_, vitâ, 
   {{0x7c240724,0xdb188420,0x00000000,0x00000000}},	//   _çirm, nntø, --, --, 
   {{0xa3b41094,0x6d940241,0xdb187dfa,0x21ec0118}},	//   _जतन_, _láay, intø, nýho_, 
   {{0xba2400db,0x00000000,0x00000000,0x00000000}},	//   мдүк, --, --, --, 
   {{0x21ec01ef,0x50d800df,0x00000000,0x00000000}},	//   hýho_, ַקלא, --, --, 
   {{0x203c0023,0x44ec009e,0x5bc400ae,0x00000000}},	//   _ኣይተረ, _কলংক_, _تتصف, --, 
   {{0x9f5c8421,0xdb180109,0x00000000,0x00000000}},	//   _mità_, mità, --, --, 
   {{0xdb188422,0x21240007,0x63ac0334,0xcb040150}},	//   lità, jboh_, _albn, _تيىن_, 
   {{0x94a804db,0x4a08025c,0xd37802bf,0x63ac0306}},	// [a090] цтва_, _གཤོལ_, жче_, _blbn, 
   {{0x08f82781,0xdb188423,0x00000000,0x00000000}},	//   _غريب_, nità, --, --, 
   {{0xc2c4007b,0x00000000,0x00000000,0x00000000}},	//   نيكي, --, --, --, 
   {{0x34944358,0xdb1806d9,0x6d4c002e,0xd5840345}},	//   _замр, hità, _ñaax, _تێره_, 
   {{0x25180a1e,0xf40801ec,0x1c0801ad,0xdb0800e5}},	//   _מורא, _ءيسى_, _हंगल_, _elfé, 
   {{0x9f5c0c95,0xa3e81361,0xb4bc01ad,0x29d0025c}},	//   _cità_, मतः_, ेपी_, jġan_, 
   {{0x21240548,0xdb1826b7,0xdee00fac,0x00000000}},	//   bboh_, dità, лоши, --, 
   {{0x9f5c0589,0xa2c00150,0x00000000,0x00000000}},	//   _pitã_, _сәук, --, --, 
   {{0x6fb80166,0x00000000,0x00000000,0x00000000}},	//   _егар_, --, --, --, 
   {{0x9f5c0589,0x00000000,0x00000000,0x00000000}},	//   _vitã_, --, --, --, 
   {{0x18a05856,0x6d5c0037,0x96d8000d,0x00000000}},	//   қарм, õsas, _मँगउ, --, 
   {{0x9f5c00d8,0x6d5c08c2,0x6c140395,0xdb1800e4}},	//   _titã_, òsad, _зддф, titã, 
   {{0x42800092,0x38540395,0xc90000eb,0x321015c0}},	//   ኩልነት_, кърс, ূর্ত_, _luzy_, 
   {{0x2d9c8424,0xdb182508,0x32100109,0x21240007}},	//   _howe_, cità, _ouzy_, zboh_, 
   {{0x2d9c8425,0x96d40184,0x7a08012c,0x25b08426}},	//   _kowe_, естә, _větr, thyl_, 
   {{0x65a803c6,0xdb188427,0x2d9c020c,0x55e0005b}},	//   _výho, mitá, _jowe_, госб, 
   {{0xd4640f43,0xdb188428,0x638405f5,0x2d9c8429}},	// [a0a0] ните_, litá, нгаа, _mowe_, 
   {{0x2d9c842a,0x67f00008,0x00000000,0x00000000}},	//   _lowe_, bæja, --, --, 
   {{0xdb181d91,0x69c4023a,0xe5a47de7,0x25b0842b}},	//   nitá, oike, _зини, phyl_, 
   {{0x69c42747,0x2d9c842c,0x3210842d,0x1ec800d1}},	//   nike, _nowe_, _duzy_, үлди_, 
   {{0x33b00131,0x614400ee,0xd6cc3267,0x00000000}},	//   _ھەمر, _җеза, _نقی_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9e04842e,0x2d9c8424,0xc7b4016b,0x32107d19}},	//   нчил, _bowe_, _ntɑm_, _guzy_, 
   {{0x7c240bfc,0x69c4842f,0x2d9c0204,0x247002e2}},	//   _çirk, jike, _cowe_, _kņm_, 
   {{0x2d9c8430,0x61e08431,0x3dc400ca,0x9f5c004e}},	//   _dowe_, mool, rimw_, _tità_, 
   {{0x61e08432,0x9f58023a,0x69c400ad,0x6d5c0254}},	//   lool, öpä_, eike, õsar, 
   {{0x69c48433,0xdb188434,0x3f8c8435,0x2d9c00e8}},	//   fike, rità, _indu_, _fowe_, 
   {{0x69c48436,0x83100003,0xdb18004e,0x00000000}},	//   gike, _ཏུའུ_, sità, --, 
   {{0x65a8012c,0x61e00083,0xdb188437,0xc8640b96}},	//   _výhl, iool, pità, лтри, 
   {{0x8c181a4c,0xdb188438,0x36d48439,0x2d9c01e2}},	//   _צווי, bitá, вогр, _zowe_, 
   {{0x61e0843a,0x2d9c843b,0xdb18843c,0x98a8054e}},	//   kool, _yowe_, citá, facă_, 
   {{0x61e004ba,0xd5a0036b,0xde500023,0x00000000}},	//   jool, دلری, _ዘይደለ, --, 
   {{0x798c843d,0x3210843e,0x3f8c01c4,0x61e0843f}},	// [a0b0] _inaw, _suzy_, _ondu_, dool, 
   {{0x3f8c1682,0x38688440,0x28d82c97,0x7e680175}},	//   _nndu_, _ipar_, _युटि, _opdp, 
   {{0x32543f51,0x9f480086,0x61e08441,0x0edc06e3}},	//   твер, _òbù_, fool, _पुंड, 
   {{0x3f8c0124,0x24700100,0x61e08442,0xc0d00092}},	//   _andu_, _fņm_, gool, _ሥራም_, 
   {{0xa5c08443,0x2d9c8444,0x798c00ec,0xdca403cc}},	//   _төре, _rowe_, _mnaw, _ئى_, 
   {{0x69c48445,0xdb188446,0x2d9c8447,0x9f5c0093}},	//   zike, litæ, _sowe_, _pitá_, 
   {{0x69c48448,0x798c6004,0xa2800344,0xdb180077}},	//   yike, _onaw, _پینو, xitá, 
   {{0x61e08449,0x798c7f1f,0xdb18844a,0x69c4005a}},	//   cool, _nnaw, nitæ, xike, 
   {{0x69c4844b,0x3a200010,0xefdc0023,0x00000000}},	//   vike, _čipa_, _ዕጹው_, --, 
   {{0x798c844c,0x2d9c844d,0x69c4844e,0x6d5c01ab}},	//   _anaw, _wowe_, wike, òsab, 
   {{0x69c4844f,0x38688450,0x2d9c8451,0x798c0042}},	//   tike, _apar_, _towe_, _bnaw, 
   {{0xdb188452,0xdb080561,0x0d480150,0x798c015d}},	//   ritá, _amfó, _ءشاي_, _cnaw, 
   {{0x69c46fe8,0x98a88453,0x00000000,0x00000000}},	//   rike, vacă_, --, --, 
   {{0x69c48454,0x798c8455,0x66181d55,0x44240153}},	//   sike, _enaw, ítko, _įm_, 
   {{0x66e48456,0x2c182f8b,0x69c48457,0x38680428}},	//   това, _দিয়ে_, pike, _epar_, 
   {{0x69c41cdf,0x317c0007,0x798c4d43,0x6e200076}},	//   qike, jdwz_, _gnaw, _mtlb, 
   {{0xe8f80c04,0x88b0013f,0x69d48458,0x61e08459}},	// [a0c0] _юли_, _mfɛk, _ijye, vool, 
   {{0x61e0845a,0x3ce00022,0xdc2c0055,0x9c8000d0}},	//   wool, _ÿive_, _jñāv, účil, 
   {{0x61e0845b,0x06bc02f5,0xf1a800f1,0x00000000}},	//   tool, _আঁকি, کاله_, --, 
   {{0xe5a455da,0xe4c400d1,0x8bf40011,0xc2f40154}},	//   _рими, _айми, ঘদিন_, _জলদি_, 
   {{0xe3bc0597,0x2054845c,0x61e0845d,0xdfd80801}},	//   _мαи_, ттер, rool, мък_, 
   {{0x61e0845e,0xa3b40316,0x66f44721,0x7c24496e}},	//   sool, _जति_, _इराक_, _çiri, 
   {{0x61e0845f,0x71700075,0x8fa00640,0x00000000}},	//   pool, _گۇنا, раје, --, 
   {{0x69d40230,0x2b4803f9,0x61e08460,0x27f80051}},	//   _njye, _ɓace_, qool, _lhpn_, 
   {{0xcd302dc3,0xa3b41d8a,0x91000120,0xabf400ec}},	//   جرىب, _जता_, _впте, گزيڪ, 
   {{0x69d48461,0x798c8462,0x00000000,0x00000000}},	//   _ajye, _snaw, --, --, 
   {{0x386800b5,0xde000055,0x798c015d,0x66180413}},	//   _spar_, _aṃśa_, _pnaw, ítkl, 
   {{0x3868045a,0xa3b4000d,0xdb1806be,0x764000d7}},	//   _ppar_, _जतऽ_, kitç, álym, 
   {{0x26d805d5,0xa3e00307,0x9f5c0381,0x00000000}},	//   _axpo_, दवा_, _vitæ_, --, 
   {{0x798c03cb,0xdb180166,0x3e7c01ef,0x00000000}},	//   _wnaw, ditç, cátá_, --, 
   {{0x7bc88463,0xda780801,0x798c062c,0x6288005c}},	//   midu, _цял_, _tnaw, åfol, 
   {{0x798c8464,0x7bc88465,0x6dbc0882,0x94a805d9}},	//   _unaw, lidu, ṇava, واءِ_, 
   {{0x9f5c0724,0x38680798,0x7bc801fb,0x26d88466}},	// [a0d0] _kitä_, _upar_, oidu, _expo_, 
   {{0xf3145fd0,0x00000000,0x00000000,0x00000000}},	//   уджэ, --, --, --, 
   {{0x9f5c0664,0x75d47427,0xd2588467,0x976002d3}},	//   _mitä_, _ميدا, ьца_, _ልምዓት, 
   {{0x7bc88468,0xdb188469,0x00000000,0x00000000}},	//   hidu, litä, --, --, 
   {{0x7bc8846a,0x9564001f,0x629828ed,0xdfcc00f1}},	//   kidu, _ድሬዳዋ_, _àton, ګيو_, 
   {{0xdb18846b,0x7bc8846c,0xed5801a6,0x3fe40212}},	//   nitä, jidu, miži_, ажів, 
   {{0x6e94846d,0x7bc8846e,0xdfcc0592,0x00000000}},	//   العا, didu, ثيو_, --, 
   {{0xed580364,0xec78846f,0xfe70006c,0xec980063}},	//   хои_, епи_, تده_, етој_, 
   {{0x7bc865b4,0xdb188470,0x32440150,0x00000000}},	//   fidu, kitä, _шеңг, --, 
   {{0x7bc88471,0x9f5c00fd,0x00000000,0x00000000}},	//   gidu, _citä_, --, --, 
   {{0xa9a4765f,0xdb188472,0xdb080798,0x8d748473}},	//   гинд, entó, _alfâ, _لاشا, 
   {{0xba280244,0x00000000,0x00000000,0x00000000}},	//   کسیم_, --, --, --, 
   {{0x7bc88474,0x6d588475,0xed585160,0x9f5c0108}},	//   bidu, _icwa, jiži_, _fitä_, 
   {{0x7bc88476,0xdb180793,0x96600daf,0x6d5803ac}},	//   cidu, gitä, әкте, _hcwa, 
   {{0x6d5802d0,0xdb188477,0xe96883f5,0x00000000}},	//   _kcwa, antó, _зайл_, --, 
   {{0x69d400ca,0xf5b41b04,0x3eb80254,0xa9c000cf}},	//   _ujye, асую, _ürte_, _چۅگۉ, 
   {{0x81cc015b,0xa8040166,0x6d58035a,0x248401e7}},	// [a0e0] রকম_, _avış, _mcwa, íom_, 
   {{0x26d80175,0x6d5803ac,0xdb180139,0x00000000}},	//   _txpo_, _lcwa, citä, --, 
   {{0x6d588478,0x98a80210,0x667400f2,0xdb1803e0}},	//   _ocwa, racą_, _صددر, sitç, 
   {{0x6d588479,0x7bc8847a,0x22440030,0xa134847b}},	//   _ncwa, zidu, čok_, اراش, 
   {{0x26181533,0x7bc851b9,0x9fc8036b,0xa6c40eac}},	//   _मंडी_, yidu, нгда_, _এডিট, 
   {{0x7bc8847c,0x6d58847d,0x5150035b,0xd0040166}},	//   xidu, _acwa, атәу, гече_, 
   {{0x1ea80a12,0x2910016b,0x6d58035a,0x934000a8}},	//   عاتي_, _ogya_, _bcwa, _ынре, 
   {{0x9f5c0664,0x7bc8847e,0xdb1803fa,0x6d58035a}},	//   _sitä_, widu, zitä, _ccwa, 
   {{0x6d580857,0x4ec00116,0x9f5c01f4,0x9ce40124}},	//   _dcwa, ийәв, _pitä_, ыцкл, 
   {{0x2910013b,0x83f0016b,0x6d58847f,0x8bd40220}},	//   _agya_, suɑf, _ecwa, лмыс_, 
   {{0x7bc88480,0xdb188481,0x6d5803ac,0x00000000}},	//   ridu, vitä, _fcwa, --, 
   {{0x6d588482,0x76400024,0x2d980108,0x29d00327}},	//   _gcwa, šlyk, öset_, nġah_, 
   {{0x7bc88483,0xd83805f5,0x8c400209,0xdb181577}},	//   pidu, ээн_, _гече, titä, 
   {{0x29100a49,0x0d940588,0xdb2007d6,0xdb180162}},	//   _egya_, _атәы_, _اوغی, rntó, 
   {{0xdb188484,0x6d5802d0,0x5a44013d,0x93a401ec}},	//   ritä, _ycwa, _сэла, қшад, 
   {{0x29100083,0xca4400c6,0xdb188485,0x6d5803ac}},	//   _ggya_, _إليه_, sitä, _xcwa, 
   {{0x34948486,0xdb188487,0xdce002fb,0xb3e801d3}},	// [a0f0] шаар, pitä, _oboč, نٹرل_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb2748488,0xd6840108,0x8cc800dc,0x52241188}},	//   рлеш, _супп, _तेनो, уфза, 
   {{0x61440d1f,0x55600150,0x11e811dc,0x00000000}},	//   لىمە, _دۇرك, رعاي_, --, 
   {{0x658001d9,0x6d58035a,0x75d400ec,0x00000000}},	//   _بیقٕ, _rcwa, _ميگا, --, 
   {{0x752c8489,0x3d08012c,0x6d58035a,0x00000000}},	//   lbaz, ाइने_, _scwa, --, 
   {{0x6d58127b,0x764001d3,0x4eb000eb,0x00000000}},	//   _pcwa, ályh, টপ্ল, --, 
   {{0xada4848a,0x752c848b,0x201400d0,0x6d5802d0}},	//   раил, nbaz, údií_, _qcwa, 
   {{0xdb0800db,0x70580228,0x6d5802d0,0x00000000}},	//   _alfà, _шаар_, _vcwa, --, 
   {{0x78bc00e2,0x9ba01183,0x6d5802d0,0x65a80419}},	//   dzsv, يەنى, _wcwa, _výhi, 
   {{0xaa4800a7,0x2d981196,0x6d5803ac,0xc0480092}},	//   ъпна_, öses_, _tcwa, _አልተፈ, 
   {{0x6d581cdf,0x1ba00023,0x8c34014b,0xa9c000cf}},	//   _ucwa, _ዝገለጸ_, _бодӣ_, تۅبۉ, 
   {{0x6dbc0882,0xf0ac02dd,0x752c06be,0x00000000}},	//   ṇasa, здiң_, dbaz, --, 
   {{0x752c0337,0xfc30848c,0x2618443a,0x3ce000e4}},	//   ebaz, _رحه_, _मंदी_, _ÿiva_, 
   {{0xe9d801a9,0x00000000,0x00000000,0x00000000}},	//   _икк_, --, --, --, 
   {{0xe9680184,0xe5a4848d,0x752c010a,0xe524848e}},	//   _раил_, шиби, gbaz, рдап, 
   {{0xb424848f,0x18a01b74,0x3d080034,0xa3e801c6}},	// [a100] معلو, _маъм, ाइये_, вдаа_, 
   {{0x752c0083,0xd464549f,0xe6180139,0x626424cd}},	//   abaz, рифе_, _идо_, ивза, 
   {{0x752c8490,0xed580960,0x68f80213,0xe27802e8}},	//   bbaz, ližu_, ətda, ъщаш_, 
   {{0x629800cf,0x013801d3,0x00000000,0x00000000}},	//   _àtom, اغاں_, --, --, 
   {{0x9fa40184,0xdcec005f,0x00000000,0x00000000}},	//   ғыҙҙ, ādīj, --, --, 
   {{0xa3c82f36,0x62740451,0x386c4e99,0x00000000}},	//   _ऋषि_, _پهرئ, çeri_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x91e06145,0x83f0013f,0x1278010f,0x00000000}},	//   _досе, suɑd, _באלע, --, 
   {{0x60088491,0x00000000,0x00000000,0x00000000}},	//   _анам_, --, --, --, 
   {{0xed5808a4,0x2d988492,0xfe7801f0,0x00000000}},	//   dižu_, öser_, _бӯи_, --, 
   {{0xdee4006c,0xd35408a8,0x29d0025c,0xadb400db}},	//   _тожи, סיטי_, nġaw_, рбөш, 
   {{0x752c0a40,0xdb080267,0xc5f001f9,0x00000000}},	//   xbaz, _omfö, चतोय_, --, 
   {{0xa3b40b7c,0x95740214,0x57a402e8,0x5bd0030d}},	//   जसा_, یدرض, ашва, _дιаб, 
   {{0x23680139,0x15f80073,0x78bc01d3,0xd7e44f32}},	//   _nbbj_, ्षभर_, rzsv, рімо, 
   {{0x752c8493,0xb5945716,0x8aa002e8,0x00000000}},	//   tbaz, бивш, _мръд, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x752c8494,0x65a806ea,0x81cc015b,0xf458007b}},	// [a110] rbaz, _nýhu, রকা_, طلاع_, 
   {{0x752c8495,0x00000000,0x00000000,0x00000000}},	//   sbaz, --, --, --, 
   {{0x9f5c0093,0xd6d80114,0x00000000,0x00000000}},	//   _fitú_, _шти_, --, --, 
   {{0x76548496,0xf594275c,0xd76001ed,0x22280014}},	//   muzy, _الحج, _انھی, اٲنی_, 
   {{0x7654033f,0xd1b83b93,0x25f48497,0x00000000}},	//   luzy, _یارا_, ्षरी_, --, 
   {{0xd9cc03d4,0x48d400fe,0x203c0023,0xf3f00248}},	//   ৰতিম, _সৰুৰ, _ኣይመር, _ọ́_, 
   {{0xb63800b5,0x98a8033f,0x7c3c0092,0x87b8010f}},	//   _ｄｄ_, racę_, _በሁለቱ, שלוס_, 
   {{0xaa440032,0xaf5c0092,0x00000000,0x00000000}},	//   ҙемл, _ሰዎችና_, --, --, 
   {{0xb4f42356,0xdb180ffb,0x00000000,0x00000000}},	//   _आरोप_, litù, --, --, 
   {{0xe4f803f8,0x76548498,0xf8c40037,0x00000000}},	//   ्धति_, kuzy, _लेइय, --, 
   {{0x23b40008,0x00000000,0x00000000,0x00000000}},	//   _jæja_, --, --, --, 
   {{0xe61805c2,0x794c013f,0x23b4032e,0x9f4801e1}},	//   ғда_, _yεwɔ, _mæja_, _òbò_, 
   {{0x76540007,0xd8740014,0xa178010f,0x00000000}},	//   euzy, ٕمُت_, נטשט, --, 
   {{0xdca08499,0xdbc4010b,0xfc30009f,0x00000000}},	//   _хаши, _köýn, _آحن_, --, 
   {{0x38ac01e7,0x7c240200,0x76540432,0x2cac00e5}},	//   _pórú_, _çirr, guzy, lyed_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe9d000b2,0xe314849a,0x2cac3e3b,0xdb1803b2}},	// [a120] _وٺڻ_, مباب, nyed_, vitú, 
   {{0xe298035b,0xe6441c90,0x23b4032e,0xa2e4849b}},	//   лаз_, _леоп, _bæja_, бозд, 
   {{0xdb18172e,0x76540007,0x5b38008f,0x3a200010}},	//   titú, cuzy, רגעק, _čipk_, 
   {{0x7c2401e7,0x29d00327,0x00000000,0x00000000}},	//   _éirg, rġaw_, --, --, 
   {{0x6574014f,0xdb180413,0x9f84009d,0xdb20008e}},	//   meyh, ritú, йгдд, _ürçe, 
   {{0xdef8849c,0x65740abb,0xdb180ffb,0x83f0013f}},	//   лый_, leyh, bitù, suɑb, 
   {{0x6454849d,0x23b402d2,0x5e840107,0xfe78008e}},	//   luyi, _gæja_, сулз, рүе_, 
   {{0x6574849e,0x25b00076,0x00000000,0x00000000}},	//   neyh, nkyl_, --, --, 
   {{0xe0d8026a,0x64545a25,0xe04400a8,0x2cac01d3}},	//   _сва_, nuyi, _ынаи, gyed_, 
   {{0x6dbc0882,0x8c240154,0x65740108,0x00000000}},	//   ṇapa, _মিশন_, heyh, --, 
   {{0x6574849f,0x1398008f,0x27e80010,0x00000000}},	//   keyh, אביע, dobn_, --, 
   {{0x657400c7,0x00000000,0x00000000,0x00000000}},	//   jeyh, --, --, --, 
   {{0xf8b84d4c,0x5c0401ce,0xed580427,0x657401f4}},	//   рөй_, _ляка, rižt_, deyh, 
   {{0x76541529,0x057400d1,0x6e4000fd,0x7c240166}},	//   tuzy, ۋاقد, _äybä, _çirq, 
   {{0xdb1884a0,0xc0dc0092,0x9a2484a1,0xf21c00c5}},	//   ditø, _ንጉሠ_, _اعتن, _बूढ़_, 
   {{0x645484a2,0x15f804af,0xdb1802d2,0x00000000}},	//   fuyi, ्षधर_, gntö, --, 
   {{0x39482d1e,0x64543926,0x7d0408c2,0x00000000}},	// [a130] _idas_, guyi, _ùisd, --, 
   {{0x2618068f,0xdb180268,0xd01c0154,0xb7880bd6}},	//   _मूवी_, titù, নীড়_, _тәме_, 
   {{0x64540810,0x00000000,0x00000000,0x00000000}},	//   auyi, --, --, --, 
   {{0x64542935,0xffb4009d,0xc0dc0092,0x823445cc}},	//   buyi, үйцэ, _ንጉሡ_, سرما, 
   {{0x948401af,0x00000000,0x00000000,0x00000000}},	//   _уынд, --, --, --, 
   {{0xb4b40358,0x400805d9,0xc2c414a5,0x8c240eac}},	//   जनी_, مينٽ_, _کيفي, _মিলন_, 
   {{0x82a484a3,0x39480100,0x2cac0142,0xdcec0055}},	//   _еште, _odas_, wyed_, _ājāt, 
   {{0x394884a4,0xec4884a5,0xd1c80107,0x29d0031c}},	//   _ndas_, азил_, _сугд_, nġat_, 
   {{0xdb1804e6,0x00000000,0x00000000,0x00000000}},	//   chtë, --, --, --, 
   {{0x394884a6,0x4fc40588,0x7f58014b,0x999c0064}},	//   _adas_, _усба, _гафс_, kutų_, 
   {{0xe9d83169,0xdb18005b,0x6454022e,0x00000000}},	//   ико_, yntö, zuyi, --, 
   {{0x39480789,0xa88884a7,0x7cf000c7,0xe81c0073}},	//   _cdas_, айма_, _ẽren, _यंदा_, 
   {{0xeb9884a8,0x3078008f,0x7c640244,0x7644007c}},	//   _вил_, באָנ, _فاول, _avhy, 
   {{0xd7ec3306,0xab2884a9,0x394884aa,0x645484ab}},	//   َكَ_, _тока_, _edas_, vuyi, 
   {{0x645484ac,0x316c19b2,0x569001b9,0xdb180158}},	//   wuyi, _obez_, маёт, vitø, 
   {{0xc0dc0020,0x64540a49,0xd7d8037e,0xe3b00133}},	//   _ንጉሥ_, tuyi, rtチ_, ژرا_, 
   {{0x657484ad,0x25b00363,0xdb1803b2,0x999c00c0}},	// [a140] reyh, rkyl_, titø, autų_, 
   {{0x7c240597,0x64541418,0x25b084ae,0x657403ac}},	//   _éire, ruyi, skyl_, seyh, 
   {{0xe5a40116,0xdb180579,0x6454014b,0xd36c007b}},	//   _дини, ritø, suyi, ئهم_, 
   {{0x216884af,0xdb1884b0,0x64540083,0xe1f400dc}},	//   риди_, thtë, puyi, ेषेण_, 
   {{0xd4a00131,0x7f94035b,0x4034009b,0xe3b01291}},	//   _жияй, залх, челс, _قرآ_, 
   {{0xdb18007f,0x22284fca,0xfe7800db,0x00000000}},	//   chtè, _نثري_, йүз_, --, 
   {{0x1798025f,0xdb18044e,0x442084b1,0x29d0031c}},	//   ייסב, shtë, lqi_, nġas_, 
   {{0x44200194,0x9c444409,0x628c84b2,0x3ea01710}},	//   oqi_, охол, _irbo, ćit_, 
   {{0x442084b3,0x628c0306,0xdd9002dd,0x9f4c0332}},	//   nqi_, _hrbo, зақы, llfí_, 
   {{0x628c0122,0x39481418,0x60c084b4,0x44200009}},	//   _krbo, _sdas_, mzom, iqi_, 
   {{0x261800af,0x1e842bb6,0x68100118,0x442001d5}},	//   _मूली_, _флем, _mědě, hqi_, 
   {{0x60c00165,0x00000000,0x00000000,0x00000000}},	//   ozom, --, --, --, 
   {{0x60c084b5,0x1d080395,0x00000000,0x00000000}},	//   nzom, _теди_, --, --, 
   {{0xb7e80729,0xcb64026a,0x60c084b6,0x628c002e}},	//   পষ্ট, _даље_, izom, _orbo, 
   {{0x60c00165,0xb5940edb,0x44200003,0x95c80124}},	//   hzom, пивш, eqi_, ауаа_, 
   {{0x44200548,0x81b00c58,0x999c0153,0xaa5800e5}},	//   fqi_, টোত_, rutų_, _الٹا_, 
   {{0xb4b484b7,0x44200944,0xd7f8030d,0x2be084b8}},	// [a150] जने_, gqi_, _вун_, _पदमा, 
   {{0x60c0268a,0x195401d9,0x628c0427,0x82500023}},	//   dzom, _آکھ_, _brbo, _ኣውሮጳ, 
   {{0x65a804bf,0x3c20007f,0x67440030,0x44200009}},	//   _výhr, _lòv_, šujú, aqi_, 
   {{0x44200429,0x2be00d2e,0x00000000,0x00000000}},	//   bqi_, _पदभा, --, --, 
   {{0x628c84b9,0xd498033a,0x6598011a,0xd1500092}},	//   _erbo, _трн_, _הירק, _የኮርፖ, 
   {{0x13a40133,0x29d0031c,0x67f002d2,0x00000000}},	//   _گۆڕی_, nġar_, bæju, --, 
   {{0x31341fbd,0x88b00085,0x628c1050,0x753c01ed}},	//   _невр, _ngɛn, _grbo, _kesz, 
   {{0x753c006d,0x50c800db,0x00000000,0x00000000}},	//   _jesz, _кызм_, --, --, 
   {{0x2bc80209,0x60c04a43,0x753c84ba,0xab9802c9}},	//   йлип_, czom, _mesz, مخدر_, 
   {{0x753c84bb,0x00000000,0x00000000,0x00000000}},	//   _lesz, --, --, --, 
   {{0x8d8484bc,0x9b405f6b,0x9f480241,0x00000000}},	//   _мудд, رچوو, _óbá_, --, 
   {{0x442084bd,0xbf7000c7,0x202402d2,0xe0a801e1}},	//   yqi_, _зқәы, _ópið_, _ìṣà, 
   {{0xb4b42d3b,0xdb1800d0,0x2a64002f,0xacf8004e}},	//   जनो_, litý, stlb_, _унду_, 
   {{0x78a800af,0x64a40588,0x3b840212,0x28200014}},	//   äeva, ҟаза, _оліг, ٘ژھہ, 
   {{0x753c066d,0xaa5802de,0xdb180306,0x442002d1}},	//   _besz, _العا_, nitý, wqi_, 
   {{0x442084be,0x7afc84bf,0x2bb8000d,0x00000000}},	//   tqi_, ürte, इसवा, --, 
   {{0x753c8180,0x44200009,0xe3b8022e,0xa348009d}},	// [a160] _desz, uqi_, бба_, йзаа_, 
   {{0x442084c0,0xa2e43546,0x753c02d0,0x9a800023}},	//   rqi_, позд, _eesz, _ይካኣል_, 
   {{0xe2140f1b,0x753c00dd,0xe6881b06,0xdb1884c1}},	//   سباع, _fesz, _انجى_, uhté, 
   {{0xe1f084c2,0x628c0331,0xdef80184,0xe8e8031c}},	//   رسا_, _vrbo, ҙыл_, _རྙོག, 
   {{0x442084c3,0x673c0432,0x661c00d7,0x10440395}},	//   qqi_, _kepj, _hupk, пящи_, 
   {{0x60c00c09,0x68f402f6,0x628c84c4,0x753c84c5}},	//   rzom, _myyd, _trbo, _zesz, 
   {{0x628c00c8,0x62980cf4,0x68f401f4,0x60c000e5}},	//   _urbo, _štof, _lyyd, szom, 
   {{0x661c01fa,0x3c2002bd,0xe3bc0eac,0x5cc40107}},	//   _mupk, _pòv_, _আদিব, зсоз, 
   {{0x661c05a1,0x9f5c008e,0x00000000,0x00000000}},	//   _lupk, _kitü_, --, --, 
   {{0xdb180306,0x673c0064,0xa71c0154,0x00000000}},	//   bitý, _nepj, থরুম_, --, 
   {{0x68f402d0,0x8af40024,0x00000000,0x00000000}},	//   _ayyd, знэс_, --, --, 
   {{0x629807ea,0x4ef8008d,0x6bd00014,0xdb180037}},	//   _àtou, _פלאג, ى۪ۆر, litü, 
   {{0x753c295f,0x3a20627e,0x57480023,0x00000000}},	//   _resz, _čipu_, _ንምፍራ, --, 
   {{0x661c0491,0x673c00ef,0xdb18000d,0x00000000}},	//   _bupk, _cepj, nitü, --, 
   {{0x24800ac5,0xb4b400dc,0x1c00012d,0x753c06d8}},	//   _askm_, जन्_, _रीयल_, _pesz, 
   {{0x673c02d0,0xdb180254,0xe694032e,0x29d0031c}},	//   _eepj, hitü, _víðá, sġar_, 
   {{0x753c066d,0x673c01af,0x6d5c01c3,0xdb180254}},	// [a170] _vesz, _fepj, òsai, kitü, 
   {{0x9f5c84c6,0x661c01bf,0x753c033f,0x23b402d2}},	//   _mitó_, _fupk, _wesz, _hæjj_, 
   {{0x753c066d,0xdb1884c7,0x661c02f0,0x00000000}},	//   _tesz, litó, _gupk, --, 
   {{0xdb1802fb,0x00000000,0x00000000,0x00000000}},	//   vitý, --, --, --, 
   {{0x29d0110c,0x62880158,0x661c0210,0x00000000}},	//   kšan_, åfor, _zupk, --, 
   {{0xdd8c040b,0x29d00219,0xdb180a8c,0x60d40113}},	//   یڈن_, jšan_, gitü, úyma, 
   {{0xada484c8,0xdee019ba,0x00000000,0x00000000}},	//   дайл, коши, --, --, 
   {{0x62982375,0x7f480131,0x7c2400b8,0x6c34009a}},	//   _štog, قلۇق_, _ũira, وفعا, 
   {{0x9f5c0407,0xdb1802f0,0x161c0037,0x00000000}},	//   _citó_, sitý, _मूसर_, --, 
   {{0x765484c9,0xdb1807ca,0x4fc4010b,0x68f401f4}},	//   krzy, ditó, _эсба, _ryyd, 
   {{0x76540034,0xceb80063,0x68f41b99,0x41c400cd}},	//   jrzy, _уља_, _syyd, लोकस, 
   {{0x68f402f6,0x8c44010b,0x673c84ca,0xac1801f0}},	//   _pyyd, _еҗиз_, _sepj, _доду_, 
   {{0x76541afd,0x00000000,0x00000000,0x00000000}},	//   erzy, --, --, --, 
   {{0x7c240022,0xeb984965,0x673c036e,0x7ae400b8}},	//   _éira, _фик_, _qepj, _śite, 
   {{0xe9d000c6,0xc0dc010c,0x7654012d,0x00000000}},	//   _لغة_, _ንጉሰ_, grzy, --, 
   {{0x68f4023a,0x2124011f,0x5ee000eb,0x00000000}},	//   _tyyd, xcoh_, _ফরমে, --, 
   {{0xd46484cb,0x63840323,0x673c0789,0x261803e5}},	// [a180] мите_, мгаа, _tepj, _मंकी_, 
   {{0x67200d0a,0xdb1800db,0x7654396d,0xe8b8000d}},	//   _मलिक_, litò, brzy, उनीच, 
   {{0xdb1804cc,0x9798123b,0x00000000,0x00000000}},	//   vitü, _ושיק, --, --, 
   {{0xdb18004e,0xd24c083b,0xc0dc0092,0x00000000}},	//   nitò, شنه_, _ንጉሱ_, --, 
   {{0x21240076,0x80d40154,0x00000000,0x00000000}},	//   rcoh_, _তরঙ্, --, --, 
   {{0x2124011f,0x34840032,0x29d004a7,0x00000000}},	//   scoh_, _яҡуп_, kšao_, --, 
   {{0x9e0484cc,0xd1d40092,0xdb1884cd,0x00000000}},	//   мчил, ክሮች_, ritü, --, 
   {{0x9f5c00cf,0xdb1884ce,0x30bc00cc,0x4f2004b4}},	//   _pitó_, yitó, _আখৰস, ндәб, 
   {{0xa0684c64,0x1f6400ee,0x9f5c007f,0xf1bc0034}},	//   _фаза_, _окам, _ditò_, ्फरन, 
   {{0x5f4404fb,0xfdd805d9,0xdbc40037,0x200801e1}},	//   _آنال, _کائڻ_, _löön, _òbi_, 
   {{0x8aa002bf,0x68f800ac,0x4ccc00cc,0x8fa084cf}},	//   вряд, ətdi, _হুদু, _шафе, 
   {{0x2b4802a8,0x8d9000c6,0x81b0015b,0x00000000}},	//   _ɓaci_, _للمش, টোর_, --, 
   {{0xc86484d0,0xdcb000cf,0xa368022e,0x48640395}},	//   ктри, _جىش_, nnеs, кърб, 
   {{0x7654068f,0xdb1884d1,0x00000000,0x00000000}},	//   trzy, ritó, --, --, 
   {{0xdb1865fa,0x6454058a,0x99d4007b,0x9a84030d}},	//   sitó, eryi, _يتعا, _цулл, 
   {{0x69d401ed,0x8a040063,0xdb184e05,0x00000000}},	//   ézet, _изје, pitó, --, 
   {{0x6454020c,0xa368022e,0xf7940024,0x5ee000cc}},	// [a190] gryi, riеn, _запэ, _ফৰমে, 
   {{0x76540034,0x660400c5,0x37c40116,0x98140035}},	//   przy, _ehkk, _чәмб, _تبعا, 
   {{0xdbc43110,0x00000000,0x00000000,0x00000000}},	//   _föön, --, --, --, 
   {{0x29d00427,0x720484d2,0xe4e80037,0x00000000}},	//   jšal_, روشم, _झुकि_, --, 
   {{0x534411ed,0xd46800c6,0x442401af,0x00000000}},	//   _охва, _بحجم_, _аєса, --, 
   {{0x3868031c,0x3e6806af,0x53440139,0x80d400fe}},	//   _mqar_, fût_, _юхма, _তৰঙ্, 
   {{0xa368022e,0x00000000,0x00000000,0x00000000}},	//   rnеt, --, --, --, 
   {{0x386884d3,0xac840137,0xdb180ba1,0x9e700b24}},	//   _oqar_, егил, xitò, اهيت, 
   {{0x705400db,0x34dc0b02,0x8f8001b9,0x00000000}},	//   _سناا, _यशोद, _ақлл, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x386884d4,0x9f5c026c,0xdb1884d5,0x7d0401ab}},	//   _aqar_, _titò_, chtí, _ùisn, 
   {{0x3ce01326,0x29d005a1,0xa9a401c6,0x6fcc012d}},	//   _žive_, ršao_, химд, dźci, 
   {{0x6e2084d6,0xdb18004e,0x7cc400f2,0x00000000}},	//   _hulb, ritò, _لزوم, --, 
   {{0x6e2084d7,0x29d001fa,0xdbc40037,0x6454007f}},	//   _kulb, pšao_, _söön, vryi, 
   {{0x6e200267,0xdb1856ec,0xf66464c2,0xdbc40037}},	//   _julb, pitò, керү, _pöön, 
   {{0x64a484d8,0x6e20332e,0x38680135,0x64543c36}},	//   наба, _mulb, _fqar_, tryi, 
   {{0xe40484d9,0xe45884da,0x396400c7,0xdbc4000d}},	// [a1a0] езап, яжа_, _рныҳ, _vöön, 
   {{0x645484db,0xa68484dc,0x9f4c036e,0x7b08010e}},	//   rryi, _злод, rofë_, _üstý, 
   {{0xdbc40037,0x141400ae,0x00000000,0x00000000}},	//   _töön, ريمة_, --, --, 
   {{0xe04484dd,0xa06884de,0x6454020c,0xdb080200}},	//   енди, зада_, pryi, _sofë, 
   {{0x442426cd,0x2b440165,0x29d00427,0xf1a84e77}},	//   _îm_, kalc_, jšam_, باله_, 
   {{0x8fa084df,0xd00c0592,0x29c00162,0x6e200fb2}},	//   лаче, ملن_, _jóab_, _bulb, 
   {{0x5398025f,0x6e2084e0,0x6d4402b1,0x7e680334}},	//   _צילו, _culb, _ēhar, _qqdp, 
   {{0x6e2084e1,0x71582e5d,0x4e90027d,0x10a000fb}},	//   _dulb, _орус_, اشور, тиән, 
   {{0x6e20002e,0x63ac05ce,0x29d00e3c,0xcc8400ae}},	//   _eulb, _kobn, ršal_, فنيه_, 
   {{0xbf1030cb,0x6e2084e2,0x63ac00b5,0x386801a9}},	//   _күлә, _fulb, _jobn, _rqar_, 
   {{0x6e2084e3,0x63ac037e,0x65640857,0xd00c007b}},	//   _gulb, _mobn, _ockh, _الل_, 
   {{0x63ac84e4,0x588484e5,0xe87c02d3,0x3e4c00bc}},	//   _lobn, ныга, _ዕላምኡ_, mět_, 
   {{0x63ac02d0,0xc0dc0023,0x00000000,0x00000000}},	//   _oobn, _ንጉሆ_, --, --, 
   {{0x2b44010a,0x8c180375,0x6564035a,0x63ac0455}},	//   calc_, _זוגי, _ackh, _nobn, 
   {{0xd5b884e6,0x3e4c00bc,0x23b402d2,0x00000000}},	//   пса_, nět_, _gæji_, --, 
   {{0x68e000c0,0x00000000,0x00000000,0x00000000}},	//   _žode, --, --, --, 
   {{0x63ac84e7,0xd3780f15,0xd7f80452,0x8cc0012d}},	// [a1b0] _bobn, зче_, _нуо_, ाईयो, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd25884e8,0x81bc00fe,0x63ac84e9,0x8c2400fe}},	//   яца_, েচন_, _dobn, _মিছন_, 
   {{0x3e4c038e,0x2b440dd4,0x30340108,0xa56000cf}},	//   dět_, zalc_, ведё, _ەگەن, 
   {{0xc394052f,0x6e201b5a,0x2b4402c4,0xdfcc0451}},	//   _өҫтә, _sulb, yalc_, ڪيو_, 
   {{0x6e2084ea,0x63ac84eb,0xdb080100,0x00000000}},	//   _pulb, _gobn, _tofè, --, 
   {{0xdfcc00aa,0x6e20014f,0x81b000eb,0x00000000}},	//   تيو_, _qulb, টোই_, --, 
   {{0xc6940bd9,0x63ac151c,0xe1940166,0xddc80100}},	//   ראק_, _zobn, _илсө, nsfň, 
   {{0x1c4084ec,0x301484ed,0x2b440427,0x7c240332}},	//   аным, _адар, talc_, _éirl, 
   {{0x6e2084ee,0x29d000e2,0x3e4c0118,0xe87c0023}},	//   _tulb, ršam_, bět_, _ዕላማኡ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x0c9001b9,0x2b44030a,0x29d00427,0x6d340798}},	//   _مدتگ, salc_, mšak_, _редф, 
   {{0x2d9c84ef,0x00000000,0x00000000,0x00000000}},	//   _inwe_, --, --, --, 
   {{0x2d8c84f0,0x66e41188,0xca600150,0x00000000}},	//   ldee_, вога, _бекқ, --, 
   {{0x83f0013f,0x2d8c84f1,0x20500023,0x00000000}},	//   suɑk, odee_, _ኣይትጨ, --, 
   {{0x2d8c84f2,0x63ac1109,0xe8f80117,0x00000000}},	//   ndee_, _sobn, _олй_, --, 
   {{0xa80484f3,0x2d9c009a,0x63ac6b0b,0x2d8c84f4}},	// [a1c0] _изил, _mnwe_, _pobn, idee_, 
   {{0xd6cc01d3,0x2d8c343b,0x464c0092,0x00000000}},	//   حقہ_, hdee_, _ንግግራ, --, 
   {{0x200002d5,0x69c403a2,0x2d9c05db,0x614400d8}},	//   _ūkio_, ohke, _onwe_, вееа, 
   {{0x3e4c00bc,0x656402d0,0x64a40022,0x42c80022}},	//   vět_, _uckh, _ҟаҳа, _ҧҳан_, 
   {{0x2d8c84f5,0x63ac84f6,0xf1a800c6,0x69c4003e}},	//   ddee_, _tobn, عامه_, ihke, 
   {{0xdb1884f7,0x2d9c004c,0x237c002d,0x9f8800c5}},	//   mitö, _anwe_, _útj_, _lööb_, 
   {{0xdb1884f8,0xe1241173,0x221484f9,0x29d039ae}},	//   litö, _амби, _афар, ršaj_, 
   {{0x2d8c0a55,0xd65400d9,0x00000000,0x00000000}},	//   gdee_, דיקת_, --, --, 
   {{0xdb1884fa,0x69c40067,0x29d00010,0x00000000}},	//   nitö, dhke, pšaj_, --, 
   {{0x2d9c00b4,0x61e084fb,0x69c40098,0x2d8c84fc}},	//   _enwe_, lnol, ehke, adee_, 
   {{0x5ea469d2,0x2d8c198f,0x0ba084fd,0x61e0009a}},	//   _جمال, bdee_, ршым, onol, 
   {{0x61e084fe,0x3f8c84ff,0x69c401c7,0xdb188500}},	//   nnol, _hadu_, ghke, kitö, 
   {{0x3f8c8501,0xdca4013e,0x35b4020a,0x61e08502}},	//   _kadu_, _шади, қбар, inol, 
   {{0x3f8c8503,0x69c4003e,0xdb188504,0x58840022}},	//   _jadu_, ahke, ditö, ныҳа, 
   {{0x8c1825f9,0xf1b80fb7,0x645802b5,0xda043a4e}},	//   _קווי, _hiše_, _ātia, _ичип, 
   {{0x69c48505,0xdb188506,0xf1b81b24,0x3f8c8507}},	//   chke, chtá, _kiše_, _ladu_, 
   {{0x33748508,0xdb18000d,0x8544013d,0x00000000}},	// [a1d0] лгар, gitö, рэсе, --, 
   {{0x798c0751,0x61e00077,0xf1b804a7,0x2d8c01f2}},	//   _haaw, enol, _miše_, zdee_, 
   {{0x32548509,0x798c850a,0x2d8c850b,0x847802d3}},	//   увер, _kaaw, ydee_, _ኣዋርሕ_, 
   {{0x798c2db1,0x3f8c2bd7,0x29d00427,0xdb18850c}},	//   _jaaw, _aadu_, však_, bitö, 
   {{0x798c850d,0x3f8c850e,0xdca400c6,0x752c009a}},	//   _maaw, _badu_, _اى_, mcaz, 
   {{0x3f8c850f,0x61e08510,0x60940736,0x798c0067}},	//   _cadu_, anol, انوس_, _laaw, 
   {{0x3f8c8511,0xf1b805be,0xdd8c00aa,0x69c4023a}},	//   _dadu_, _aiše_, ړوي_, yhke, 
   {{0x752c8512,0x3f8c0428,0x798c8513,0xf1b80841}},	//   ncaz, _eadu_, _naaw, _biše_, 
   {{0x53b407f8,0x2d8c47a2,0x3f8c0198,0x752c026c}},	//   _आकाश, rdee_, _fadu_, icaz, 
   {{0x3f8c8514,0x09dc05ba,0xf1b807f5,0x9f8800c5}},	//   _gadu_, मच्य, _diše_, _sööb_, 
   {{0x752c021a,0x798c2252,0x2628010f,0x06d8015b}},	//   kcaz, _baaw, _aĝon_, _দুনি, 
   {{0x798c0050,0x2d9c268a,0x2d8c0014,0x69c40c6a}},	//   _caaw, _unwe_, qdee_, uhke, 
   {{0x798c8515,0x3f8c03f9,0x6d488516,0xdd8c4319}},	//   _daaw, _yadu_, maea, _روو_, 
   {{0x69c48517,0x6d488518,0x8d7404d3,0x752c026c}},	//   shke, laea, _ساڵا, ecaz, 
   {{0x6b808519,0x798c851a,0xfbd014d1,0x4574010b}},	//   melg, _faaw, _بتن_, ңңүр, 
   {{0x61e0851b,0x798c851c,0x752c014b,0xdb180821}},	//   xnol, _gaaw, gcaz, titö, 
   {{0x69d40796,0x9f5c004d,0xee48035b,0x7bc800fe}},	// [a1e0] _imye, _kitô_, hẽ_, ৰকৰো, 
   {{0x6d48851d,0x798c851e,0xdb1825c6,0x6b80851f}},	//   haea, _zaaw, ritö, nelg, 
   {{0xdb188520,0x798c0a49,0x6d488521,0x29d00153}},	//   sitö, _yaaw, kaea, ešai_, 
   {{0x3f8c8522,0x752c8523,0x6b808524,0x602405f5}},	//   _sadu_, ccaz, helg, гдда, 
   {{0x20548525,0x61e08526,0x27e40798,0x6d488527}},	//   утер, rnol, _íons_, daea, 
   {{0x61e08528,0xf1b80010,0x78a80037,0xaf540124}},	//   snol, _riše_, äevi, аншә, 
   {{0x69d4035b,0x3f8c8529,0xf1b801a6,0xef9007d6}},	//   _omye, _vadu_, _siše_, تیلد, 
   {{0xf1d400f7,0x3f8c852a,0x6d480042,0xbdb40063}},	//   _көчө, _wadu_, gaea, рбиј, 
   {{0xbebc0421,0x3f8c852b,0x798c0a4d,0x814400aa}},	//   _afīt, _tadu_, _raaw, _منځن, 
   {{0xf1b804b9,0xef907be0,0x6b80852c,0x69d40022}},	//   _više_, _ویند, gelg, _amye, 
   {{0x798c852d,0x6d5c01e7,0x00000000,0x00000000}},	//   _paaw, ósac, --, --, 
   {{0x798c852e,0x64580421,0x201c852f,0x6d480393}},	//   _qaaw, _ātin, _hiti_, caea, 
   {{0x201c8530,0x798c04ba,0x00000000,0x00000000}},	//   _kiti_, _vaaw, --, --, 
   {{0x201c01af,0x798c8531,0x69d48532,0x00000000}},	//   _jiti_, _waaw, _emye, --, 
   {{0x201c8533,0xdb081aac,0x798c8534,0xdb187171}},	//   _miti_, _kofí, _taaw, kkté, 
   {{0x201c8535,0x7bc80477,0x45d4030d,0x2cc803e3}},	//   _liti_, lhdu, босс, _ötdü_, 
   {{0x752c8536,0xdb0801e1,0xdb18000d,0x880400ec}},	// [a1f0] rcaz, _mofí, ritõ, _ڏِيو, 
   {{0x7bc88537,0x36d48538,0x92e81473,0x752c8539}},	//   nhdu, _воор, ىراق_, scaz, 
   {{0x7bc8005b,0x00000000,0x00000000,0x00000000}},	//   ihdu, --, --, --, 
   {{0x201c853a,0x6b80853b,0x4734136e,0x29c0032e}},	//   _aiti_, zelg, _پریز, _lóan_, 
   {{0x201c0b91,0x6d484218,0x27f8020c,0x62983ea9}},	//   _biti_, vaea, _ykpn_, _áton, 
   {{0x201c853c,0x550400c7,0x29d075e3,0x6b80007c}},	//   _citi_, _ачҳа, ršai_, xelg, 
   {{0x74d83806,0x201c853d,0x6b800ee1,0x6d48853e}},	//   _नेतृ, _diti_, velg, taea, 
   {{0x7c981b49,0x201c853f,0xec788540,0x6b800280}},	//   _ጀነራል_, _eiti_, впи_, welg, 
   {{0x201c8541,0x6b808542,0x6d488543,0xee4800c7}},	//   _fiti_, telg, raea, sẽ_, 
   {{0x201c8544,0xd1d8001f,0x6d4854b2,0x7bc88545}},	//   _giti_, ኔዎች_, saea, ghdu, 
   {{0x8d748546,0x6b800ed6,0x7e9c0311,0xdb0800d8}},	//   _ماشا, relg, _căpă, _fofí, 
   {{0x6b80060a,0xad240075,0x201c8547,0x00000000}},	//   selg, _ئىشى, _ziti_, --, 
   {{0x6b808548,0x201c8549,0x6fd800ce,0xa80436da}},	//   pelg, _yiti_, _भगां, измл, 
   {{0x7bc8854a,0x201c030d,0x29d00427,0x7d080212}},	//   chdu, _xiti_, jšav_, _сніг_, 
   {{0x320c0165,0x00000000,0x00000000,0x00000000}},	//   _ohey_, --, --, --, 
   {{0x69d40912,0x966000a7,0x00000000,0x00000000}},	//   _umye, юксе, --, --, 
   {{0x9f5c049b,0x6fc40574,0x2328854b,0xe738013d}},	// [a200] _yhtä_, वसां, вози_, _иеп_, 
   {{0xe298115c,0x2334035b,0x320c0067,0xe64400d8}},	//   каз_, рхар, _ahey_, _кеоп, 
   {{0x201c854c,0xdb18002f,0xe0e000eb,0x00000000}},	//   _riti_, chtä, _বরেন, --, 
   {{0x201c854d,0x7bc802d3,0x320c0076,0x2fc42caa}},	//   _siti_, zhdu, _chey_, _allg_, 
   {{0x201c854e,0x25a0854f,0x9f84009d,0x00000000}},	//   _piti_, _inkl_, игдд, --, 
   {{0x7c240597,0x3ce00f03,0xdb088550,0xdef84ad0}},	//   _éiri, _živo_, _sofí, кый_, 
   {{0x201c8551,0x7e9804fb,0x614458e5,0x28c40118}},	//   _viti_, انبر_, _веба, रैति, 
   {{0x201c8552,0x320c062c,0xdce88553,0xd1b0072d}},	//   _witi_, _ghey_, šiče, _ویلک, 
   {{0x201c8554,0x7e9c054e,0x04f400cc,0x4dd000cf}},	//   _titi_, _săpă, _অণুৰ_, تتوس, 
   {{0x64580b23,0x201c0276,0x7e9c054e,0x8f500214}},	//   _ātil, _uiti_, _păpă, _ونقش, 
   {{0xf1b80fb7,0x00000000,0x00000000,0x00000000}},	//   _hiša_, --, --, --, 
   {{0xf1b80989,0x88d80154,0x00000000,0x00000000}},	//   _kiša_, _সড়ক, --, --, 
   {{0xedf40832,0x29c00208,0xddc80100,0x26dc01d3}},	//   _اينگ, _tóan_, nsfō, úton_, 
   {{0xc7c48555,0xf1b80960,0x25a00165,0xdd8c01ed}},	//   осси, _miša_, _ankl_, _روڈ_, 
   {{0x7bd88556,0x5a440139,0x4b500244,0x9c6001c8}},	//   _imvu, _тэла, _بێپر, _اهڙو, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x06d80729,0xf1b88557,0xf8b88558,0x98040064}},	// [a210] _দুদি, _niša_, _сөн_, _вянд, 
   {{0x320c1368,0x394800af,0x2bd800cd,0x00000000}},	//   _shey_, _heas_, योपा, --, 
   {{0xf1b80b4b,0x39480b21,0x7de800bc,0xb27413d6}},	//   _aiša_, _keas_, věsn, слеш, 
   {{0xee381f71,0x39480076,0x00000000,0x00000000}},	//   қни_, _jeas_, --, --, 
   {{0x39488559,0x7bd801e2,0x7f480009,0x7de800bc}},	//   _meas_, _omvu, _bedq, těsn, 
   {{0x3948379c,0xa1a40032,0x2ca8025c,0x320c045a}},	//   _leas_, _һыуһ, _ħad_, _whey_, 
   {{0x320c0052,0x262800df,0x7d0c016b,0xee380640}},	//   _they_, _aĝoj_, ɑnsɑ, ћни_, 
   {{0x7bd8855a,0x6fd81a2a,0x3948855b,0x2bd820f0}},	//   _amvu, _भगवं, _neas_, योना, 
   {{0xeb9822bf,0x9ed400d1,0x4034466e,0x00000000}},	//   гип_, имәт_, _метс, --, 
   {{0x39480077,0x78bc02f6,0x9524031c,0x9b8414fb}},	//   _aeas_, dysv, _འུའི_, مچىل_, 
   {{0x3948855c,0x262801e4,0x29d001a6,0xfeb800f2}},	//   _beas_, _eĝoj_, kšat_, _پالت_, 
   {{0x3948084c,0x29d00010,0x00000000,0x00000000}},	//   _ceas_, jšat_, --, --, 
   {{0x39480fa3,0xec3400c8,0x6f00000f,0x2ca800a2}},	//   _deas_, _פאַר_, _hylc, _çad_, 
   {{0xdc3400c8,0x3948855d,0xaab80814,0x84800240}},	//   _האסט_, _eeas_, _مدبر_, _ሕርሻን_, 
   {{0x76440369,0x39487868,0xe5a403fb,0x00000000}},	//   _cwhy, _feas_, биви, --, 
   {{0x6f000076,0xa524855e,0x78bc01bf,0x00000000}},	//   _mylc, смад, bysv, --, 
   {{0xb8fc02f5,0xa3e805f5,0x1420855f,0x65747f7f}},	// [a220] _তু_, гдаа_, здум, rfyh, 
   {{0xd8d400c8,0x29d00024,0x3948030a,0xdb1801bf}},	//   _לופט_, ršau_, _zeas_, shtå, 
   {{0x39480489,0xdb080309,0x23280107,0x00000000}},	//   _yeas_, _kofá, воҷи_, --, 
   {{0x62984221,0x7f480327,0x7afc55ac,0x29d05106}},	//   _átom, _sedq, ürti, mšas_, 
   {{0xdb080077,0xdfd80801,0x6614010e,0x7f480455}},	//   _mofá, лък_, mmyk, _pedq, 
   {{0xf1b805ce,0x6f00015d,0x66145873,0xdc880107}},	//   _viša_, _bylc, lmyk, ҳсол_, 
   {{0x6f0000a9,0x29d0005f,0x7de8013a,0x00000000}},	//   _cylc, nšas_, běsl, --, 
   {{0x628c3089,0xc0c40a43,0x5698010f,0x9a940092}},	//   _isbo, _мәли, ריקצ, _ሌላኛው_, 
   {{0x394803bd,0xdb08004e,0x50402be9,0x7f4806be}},	//   _reas_, _sofà, _нетб, _tedq, 
   {{0x39483371,0xdee48560,0xdb18002d,0x46c802ab}},	//   _seas_, _лози, chtû, रनाह, 
   {{0x39488561,0x93f800c8,0x6f000368,0x62980010}},	//   _peas_, רליי, _gylc, _štoj, 
   {{0xdb080113,0x64440784,0x78bc023a,0xecd860c7}},	//   _cofá, _owki, tysv, _बेवफ, 
   {{0x39482b76,0x76440399,0xa3f8629c,0x29d00153}},	//   _veas_, _swhy, ्ताप_, ešas_, 
   {{0x628c8562,0xcc5425f9,0x2a648563,0x7bd88564}},	//   _osbo, _פסוק_, bulb_, _umvu, 
   {{0x64444f6b,0x2a6400b5,0xdb0801d3,0x39488565}},	//   _awki, culb_, _alfö, _teas_, 
   {{0x9484516c,0x38c803e6,0xaae4007b,0xdb1800d7}},	//   йызд, _ناخی_, _بسهو, nktí, 
   {{0x93248566,0x628c036b,0x73d88567,0xb4b4033f}},	// [a230] مران, _asbo, адар_, ड़ने_, 
   {{0xb4b40184,0x3358084c,0x3a200306,0xca700244}},	//   биғә, ражэ_, _čipy_, _بچیک, 
   {{0xdb0801e3,0x29d00010,0x5fbc0b4c,0x00000000}},	//   _elfö, mšar_, ्सनल, --, 
   {{0xd1488568,0xdd8400f1,0xdb1800d7,0x00000000}},	//   اشان_, _غو_, jktí, --, 
   {{0x628c8569,0x69a80073,0x817401e2,0x00000000}},	//   _esbo, टाती, سپوڅ, --, 
   {{0xee38856a,0x6f00010e,0x5348010a,0x19cc0150}},	//   анк_, _pylc, _сăкă, _ﻗﻠﻴﻠ, 
   {{0x7ff4007b,0x00000000,0x00000000,0x00000000}},	//   أسنا, --, --, --, 
   {{0xab9c0092,0xe0a801e1,0x00000000,0x00000000}},	//   _ገበያው_, _ìs̟à, --, --, 
   {{0xdb180597,0x2bc8856b,0xf1b8151c,0x6f00002d}},	//   chtú, илип_, _hišo_, _wylc, 
   {{0xdb081dec,0xdb1843ed,0x00000000,0x00000000}},	//   _sofá, aktí, --, --, 
   {{0xdd8c17b9,0x66146c0f,0xbdc801c0,0xa2c00248}},	//   روی_, ymyk, ргөж_, _nọ́m, 
   {{0xa9683dc8,0x9f480241,0x26dc00d7,0x00000000}},	//   шима_, _óbò_, útom_, --, 
   {{0x6d58856c,0xa178008f,0x00000000,0x00000000}},	//   _idwa, סטשט, --, --, 
   {{0xaa44856d,0xa6c80786,0x61b41546,0x6d58035a}},	//   _декл, алга_, _अक्ष, _hdwa, 
   {{0x644402c4,0xf1b80427,0x6d5803ac,0xc5f801e0}},	//   _swki, _nišo_, _kdwa, йғо_, 
   {{0x29d0005f,0xdb08005c,0x6d5802d0,0x2bb81025}},	//   ršas_, _bofæ, _jdwa, ेसवा, 
   {{0xb8d0045e,0x66145443,0x2d44001f,0x6d58035a}},	// [a240] _য়ে_, rmyk, _ማጠናከ, _mdwa, 
   {{0x66142188,0xe7380640,0x6d58035a,0x7ae400b8}},	//   smyk, _њен_, _ldwa, _śiti, 
   {{0x6d58856e,0xc1a401ec,0x00000000,0x00000000}},	//   _odwa, зылқ, --, --, 
   {{0x6d58856f,0x6b28031c,0xda78008f,0x00000000}},	//   _ndwa, _ལུའོ_, ינער, --, 
   {{0xecd802ab,0x104400a7,0xbebc00ef,0x2a500092}},	//   _बेलफ, оящи_, _egīl, _መደብሮ, 
   {{0x645802b5,0x73740022,0xd00c00ec,0x628c01ef}},	//   _ātih, _нысх, نلن_, _tsbo, 
   {{0x628c113c,0x6d58035a,0xeff00092,0xdea0129e}},	//   _usbo, _bdwa, _ውጊያ_, بیای, 
   {{0x6d580857,0x00000000,0x00000000,0x00000000}},	//   _cdwa, --, --, --, 
   {{0x6d582252,0xe0d88570,0x20000064,0xdb180419}},	//   _ddwa, _тва_, _ūkiu_, rktí, 
   {{0xc0c401ee,0x00000000,0x00000000,0x00000000}},	//   _мәһи, --, --, --, 
   {{0x6d5803ac,0x00000000,0x00000000,0x00000000}},	//   _fdwa, --, --, --, 
   {{0x6d5802d0,0x00000000,0x00000000,0x00000000}},	//   _gdwa, --, --, --, 
   {{0xd90c18b2,0xdef801e0,0xd7a401f9,0xedf8009f}},	//   کیک_, _сыҡ_, खालच, _اِنڊ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa3ac23ef,0xe9440014,0xbaa40b01,0xf7e402dd}},	//   कान_, _کر٘ی, _хулқ, _ﺍﺳﻜﻪ, 
   {{0x6d5803ac,0xf1b800d7,0xee7c02dd,0x00000000}},	//   _xdwa, _rišo_, _ﺤﺴﻴﻥ_, --, 
   {{0x92e403f4,0x80c40073,0xdecc0023,0x4bc001c6}},	// [a250] _পরে_, वनों, _እዋእ_, _хөөг, 
   {{0x58d01870,0x0a400092,0x4734009d,0x00000000}},	//   _ноқт, _የተሠራ, _оньс, --, 
   {{0xb6bc030d,0x00000000,0x00000000,0x00000000}},	//   _синi, --, --, --, 
   {{0x41b402dd,0x7654002f,0x00000000,0x00000000}},	//   мсіт, mszy, --, --, 
   {{0x7654033f,0x6d580857,0xc0c80063,0xc31c00cc}},	//   lszy, _rdwa, жује_, দুলি_, 
   {{0x6d58035a,0x00000000,0x00000000,0x00000000}},	//   _sdwa, --, --, --, 
   {{0xed5807a2,0x116400f1,0x76548571,0x6d58035a}},	//   бой_, _ولسی_, nszy, _pdwa, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6cb80139,0x00000000,0x00000000,0x00000000}},	//   сыйр_, --, --, --, 
   {{0xa3ac3711,0xf1b801fa,0x26dc00d0,0x6d5803ac}},	//   काय_, _hoš_, útok_, _wdwa, 
   {{0x76540034,0xf1b82a0d,0x6d58035a,0xeb9801a9}},	//   jszy, _koš_, _tdwa, _ҳил_, 
   {{0xf1b804b9,0x9f5c02bd,0x7654033f,0x6d586258}},	//   _još_, _aktè_, dszy, _udwa, 
   {{0xa3ac02db,0xf1b88572,0xfd7411e6,0xab280454}},	//   काम_, _moš_, _آدمخ, _лола_, 
   {{0xf1b8098d,0x9d180302,0x0dbc0092,0x00000000}},	//   _loš_, _פוסט, _ድምፀ_, --, 
   {{0x7afc0205,0x00000000,0x00000000,0x00000000}},	//   ürtt, --, --, --, 
   {{0x25a40022,0xb0bc1fbc,0xf1b80010,0x2e3003b2}},	//   ñol_, ्नाग, _noš_, _máf_, 
   {{0x69c40194,0x00000000,0x00000000,0x00000000}},	// [a260] mkke, --, --, --, 
   {{0x18740375,0x92e40c58,0x672001e4,0xa7640a89}},	//   _צעיר_, _পৰে_, _ĝojf, _экод, 
   {{0xf1b80fb7,0xe5a401a9,0x00000000,0x00000000}},	//   _boš_, _еини, --, --, 
   {{0x69c40f24,0x21680a42,0x59ac107c,0xd12c02c9}},	//   nkke, сиди_, टायर, همم_, 
   {{0x69c48573,0xabb80150,0x00000000,0x00000000}},	//   ikke, _ﺸﺠﺎﻋ, --, --, 
   {{0x64548574,0x7b3800e4,0x9878010f,0x00000000}},	//   msyi, iĝuí, מאנט, --, 
   {{0x09cc05ba,0x20000024,0x64540083,0xdb08007c}},	//   ासाठ, _ūkis_, lsyi, _kofå, 
   {{0x2bd8791c,0x3cd40150,0x00000000,0x00000000}},	//   योसा, _ﺘﻁﺭﺤ, --, --, 
   {{0x64548575,0x7654012d,0x00000000,0x00000000}},	//   nsyi, zszy, --, --, 
   {{0x7654033f,0x3fc81079,0x69c4072d,0x00000000}},	//   yszy, _بدری_, ekke, --, 
   {{0x60c08576,0x0c702eac,0xbb44001f,0x09a800bc}},	//   lyom, ودید, _የአይሁ, गांठ, 
   {{0x394c04d4,0x64548577,0x00000000,0x00000000}},	//   úes_, ksyi, --, --, 
   {{0x60c08578,0x2bd8068f,0x76540034,0x88e0015b}},	//   nyom, योहा, wszy, _যুবক, 
   {{0x61e08579,0x7654012d,0x5fbc28df,0x956c0023}},	//   hiol, tszy, ्सिल, ብዓትን_, 
   {{0x0dbc0020,0x61e0857a,0x4b7804ae,0x60c0009f}},	//   _ድምፅ_, kiol, _האוו, hyom, 
   {{0x24780020,0x76540034,0x69c4813e,0x60c0857b}},	//   _አካላት_, rszy, ckke, kyom, 
   {{0xd7f80209,0xf90412e9,0xf1b8310a,0x5fbc0709}},	// [a270] _гун_, _تأثی, _roš_, ्साल, 
   {{0x76540034,0xf1b80306,0x4394857c,0x60c0857d}},	//   pszy, _soš_, наус, dyom, 
   {{0x84240ae5,0x61e003cd,0x6454020c,0xf1b80427}},	//   رىمن, fiol, asyi, _poš_, 
   {{0x61e004c9,0x68e00024,0x35a40345,0x00000000}},	//   giol, _žodi, _تۆرێ_, --, 
   {{0x60c000dd,0xf1b88256,0x999c0064,0x6598011a}},	//   gyom, _hišk_, lstų_, _וירק, 
   {{0xa3ac0490,0x8b0400bc,0xd340036b,0x93881246}},	//   काण_, _jiří, _سفری, _усма_, 
   {{0x69c4708a,0xbb3c0020,0x62984473,0xff504fe0}},	//   ykke, ረድተዋ, _štov, اخه_, 
   {{0x61e0857e,0x60c0046a,0x999c00c0,0x00000000}},	//   ciol, byom, istų_, --, 
   {{0xc10400b2,0x3a3c0427,0x3ea002b5,0x00000000}},	//   _ٻولي, _atvp_, āita_, --, 
   {{0x999c0024,0xebc400c7,0x00000000,0x00000000}},	//   kstų_, ьӡеи, --, --, 
   {{0xa3ac2274,0xbfa801ee,0x00000000,0x00000000}},	//   कात_, _этте_, --, --, 
   {{0xb32c0327,0x64540df4,0x00000000,0x00000000}},	//   _ཧུའང_, ysyi, --, --, 
   {{0x69c402f6,0x6c8401b9,0xe7380556,0x09d000cc}},	//   rkke, _آلتم, жег_, াচলা, 
   {{0x8b00012c,0x69c40165,0x7de80118,0x4ab001af}},	//   ářsk, skke, věsi, _зөмр, 
   {{0x25a8038b,0x66e414b3,0xd14001f3,0x00000000}},	//   يدري_, фова, ከታተል, --, 
   {{0xc0d0001f,0x6454857f,0x64a48580,0x60c001a9}},	//   _እራሱ_, tsyi, маба, yyom, 
   {{0xbb440092,0xe8f80064,0x2bb00709,0xe45879b2}},	// [a280] _የአባላ, _флп_, जापा, южа_, 
   {{0xc0c4044e,0x64548581,0x60c08582,0x291006d9}},	//   _ጸኒሑ_, rsyi, vyom, _izya_, 
   {{0x61e08583,0x754801ed,0xe1f005a9,0x64548584}},	//   tiol, észü, پسا_, ssyi, 
   {{0x64548585,0x60c08586,0x00000000,0x00000000}},	//   psyi, tyom, --, --, 
   {{0xc44803e6,0x20548587,0xc28002dd,0x00000000}},	//   _ریان_, фтер, _ءﺳﯘﻳ, --, 
   {{0x8fa01ea2,0x7624016c,0xd8d4010f,0x626400ee}},	//   каче, _омӯз, וונט_, _овга, 
   {{0x1fc003d4,0x262800df,0xb35403ff,0x61e01ca6}},	//   ্চলস, _iĝos_, _سینا_, piol, 
   {{0x74700020,0x68f406af,0x5f740451,0x5cc468dd}},	//   _ድርጅቱ_, _oxyd, _ڊائر, дсоз, 
   {{0x91e04ea0,0x629c0450,0x00000000,0x00000000}},	//   _роте, lvpo, --, --, 
   {{0xdfa416cb,0xda78016c,0xbf1001ee,0x00000000}},	//   _تحري, оям_, _йүлә, --, 
   {{0x9c1001f2,0x291000a2,0xde740132,0x53980a7c}},	//   họgb, _azya_, _زداع, קסטא, 
   {{0x3ce00552,0xceb0008f,0xc0c40023,0x9cc80eed}},	//   _živu_, _שיף_, _ጸኒሓ_, _мыла_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xda640220,0xf8b00014,0x7de402f2,0x00000000}},	//   _قابي, ٖکھ_, _تسڕم, --, 
   {{0xd5b84d16,0x999c0153,0x00000000,0x00000000}},	//   оса_, ustų_, --, --, 
   {{0x999c0024,0xa8040205,0x662000a2,0x94a801c8}},	//   rstų_, _atığ, _įyký, ياءِ_, 
   {{0x67200115,0x00000000,0x00000000,0x00000000}},	// [a290] _ĝoje, --, --, --, 
   {{0x3a280c6a,0x7bc8000f,0xe8140db3,0x2bb000cd}},	//   _hiap_, nkdu, _दीपा_, जाया, 
   {{0xf1b8151c,0x3a288588,0x97000131,0x332c06be}},	//   _hiši_, _kiap_, _شېرى, _şexs_, 
   {{0xf1b8041a,0x28c4012d,0x00000000,0x00000000}},	//   _kiši_, रैकि, --, --, 
   {{0xa6c8022e,0x6538010f,0x2bb01bcf,0x26dc0419}},	//   _egаd, _מערד, जामा, útov_, 
   {{0xf1b80427,0x7bc801f5,0x00000000,0x00000000}},	//   _miši_, jkdu, --, --, 
   {{0xed588589,0xa2807611,0x7e7c0254,0xeb28009d}},	//   пой_, _میلو, _ärpl, үжил_, 
   {{0x518401c6,0x2bb800bc,0xed580107,0x2bb008a3}},	//   _юуга, ेस्थ, чои_, जाभा, 
   {{0xd1740032,0x622400db,0x74700092,0xadbc0150}},	//   _ныҡы, _سوكە, _ድርጊቱ_, _қадi, 
   {{0x4f64143e,0x70bc858a,0x00000000,0x00000000}},	//   _زائف, ्नील, --, --, 
   {{0x2bb0068f,0x3a2803b9,0xdb180112,0x00000000}},	//   जाबा, _biap_, chtü, --, 
   {{0xeab00050,0x9ca40137,0x00000000,0x00000000}},	//   ٖٹھ_, بۇۇل_, --, --, 
   {{0x3a2800e8,0x00000000,0x00000000,0x00000000}},	//   _diap_, --, --, --, 
   {{0x7bc806f2,0xf1b80219,0x2c78033b,0xa804008e}},	//   ckdu, _diši_, mèd_, _otış, 
   {{0xa3ac2366,0x5690006c,0x3a2805da,0x2c78007f}},	//   कास_, лаёт, _fiap_, lèd_, 
   {{0x3a280051,0x25580276,0x2bb800bc,0x8bdc000d}},	//   _giap_, яргэ_, ेसका, _फगुअ, 
   {{0x7de80316,0xa804858b,0x06d82b1b,0x95800137}},	// [a2a0] měst, _atış, _দুখি, ылте, 
   {{0xdce805ce,0xdb1800c6,0x0a40001f,0xd24c0133}},	//   šiće, chtó, _የተሰራ, ڵنه_, 
   {{0xe3bc00c6,0xdb18007c,0x66e428f3,0x4e0c01f9}},	//   _ғαн_, cktä, _чона, ाताई_, 
   {{0x629801a6,0x2c78007f,0xa3ac1414,0x00000000}},	//   _štos, kèd_, काह_, --, 
   {{0x71701e87,0xd0340212,0xdd9800c7,0x00000000}},	//   شۇلا, езії_, ҧши_, --, 
   {{0x601400e4,0x00000000,0x00000000,0x00000000}},	//   kâme, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd84c01f2,0xa3ac0c66,0x2490033f,0x1278010f}},	//   _bọlb_, काव_, owym_, _מאלע, 
   {{0x2c7800f2,0x6064009f,0xa0680408,0x00000000}},	//   gèd_, _سهال, _хаза_, --, 
   {{0xff0800c6,0x3a2850f9,0x5474010f,0x00000000}},	//   _ɱǟʂя, _siap_, עגיע_, --, 
   {{0x7c2404cc,0x1fbc858c,0x5ef8000d,0xb4ac08ec}},	//   _èirm, ्सीड, _ऊँट्_, _कप्_, 
   {{0xf1b8858d,0x66ec00e5,0x00000000,0x00000000}},	//   _piši_, zőké, --, --, 
   {{0x8c40858e,0xbd6801e0,0x00000000,0x00000000}},	//   _бече, _ерҙе_, --, --, 
   {{0xf1b80989,0xc7b8858f,0x8cc40150,0x59ac00bc}},	//   _viši_, нёс_, _سوىق_, टाहर, 
   {{0x3a288590,0x7de8013a,0x9a840354,0x00000000}},	//   _tiap_, běst, _чулл, --, 
   {{0x83a40020,0x497400a7,0x4a5000a7,0x95c88591}},	//   _ለማወቅ_, _блъс, _скъс, чуга_, 
   {{0x66ec01d3,0x33746206,0x80a0012d,0x00000000}},	// [a2b0] tőké, кгар, _गज़ले, --, 
   {{0x799c03ac,0x667004fb,0x59ac0073,0x00000000}},	//   ldsw, دگیر, टावर, --, 
   {{0xc0d0010c,0x62980427,0x29c00162,0xb274010b}},	//   _እያሱ_, _štor, _tóat_, тлеш, 
   {{0x614404a2,0x799c8592,0x66ec01d3,0xe8000bae}},	//   نىمە, ndsw, sőké, लकथा_, 
   {{0x799c0b4f,0x70bc012c,0xc174009a,0x00000000}},	//   idsw, ्नेल, ادمت, --, 
   {{0xb4ac6956,0x00000000,0x00000000,0x00000000}},	//   कमी_, --, --, --, 
   {{0xa3ac8593,0x8ea000f7,0x00000000,0x00000000}},	//   कार_, البۇ, --, --, 
   {{0x6014019f,0xdb084bc7,0x799c01f5,0x2c78007f}},	//   gâmb, _infè, jdsw, tèd_, 
   {{0xc8e003f3,0x7de800bc,0xbbe800f1,0x629802d2}},	//   _पेंट, věst, کريم_, _átor, 
   {{0x799c017a,0x2c7802e2,0x60140124,0x00000000}},	//   edsw, rèd_, tâme, --, 
   {{0xa9688594,0x6da48595,0x2c781801,0x00000000}},	//   мина_, _җиһа, sèd_, --, 
   {{0x60140120,0x2c78020c,0x1ee80244,0x00000000}},	//   râme, pèd_, _تومی_, --, 
   {{0xfd44013d,0x00000000,0x00000000,0x00000000}},	//   _сэхн, --, --, --, 
   {{0x6a848596,0x6d488597,0x799c0076,0xebe41367}},	//   _алка, lbea, adsw, _шолп, 
   {{0x7de800bc,0x00000000,0x00000000,0x00000000}},	//   pěst, --, --, --, 
   {{0x6d488598,0xf1b8041a,0x0cb00154,0x24900210}},	//   nbea, _kišu_, টনীত, twym_, 
   {{0xa3ac3eaf,0xdb08033b,0xa5248599,0x18b03ad0}},	// [a2c0] काल_, _anfè, тмад, _кәрр, 
   {{0xf1b816a3,0x6d4801ab,0x00000000,0x00000000}},	//   _mišu_, hbea, --, --, 
   {{0x6d48037e,0xe61877a8,0x338400d8,0x00000000}},	//   kbea, _одо_, ѓуѕв, --, 
   {{0xa068859a,0x00000000,0x00000000,0x00000000}},	//   дада_, --, --, --, 
   {{0xf1b8187e,0xdb080100,0x00000000,0x00000000}},	//   _nišu_, _enfè, --, --, 
   {{0x6d480381,0xe28404a9,0xa3ac0490,0x823403e6}},	//   ebea, _илги, काळ_, _موسڵ, 
   {{0xf1b801fa,0x53980375,0x63ac0135,0x81b00f22}},	//   _aišu_, _קילו, _inbn, য়োগ_, 
   {{0x6d48859b,0x5bc8859c,0xefcc0092,0xf1b800de}},	//   gbea, िस्व, _እዛው_, _bišu_, 
   {{0xdb08859d,0x8c4006ed,0xa5c0012d,0x6014859e}},	//   _infé, аење, łówc, râmb, 
   {{0xf1b80fcf,0x5ba4859f,0x008401b9,0x601485a0}},	//   _dišu_, триз, _илғо, sâmb, 
   {{0x36b402dd,0x29c00413,0xe68c0023,0x601400e4}},	//   _ءﻭﺳﯩ, _róar_, ዝነበሮ_, pâmb, 
   {{0x6d485732,0x799c0373,0xa3ac0dba,0x19a84a1a}},	//   cbea, udsw, काँ_, фтоп_, 
   {{0x799c127b,0x98485ce1,0xb8140055,0xdb1843ed}},	//   rdsw, ьяна_, _aṭan, nktú, 
   {{0xe8140037,0xdb1800e4,0xbb4400d1,0x9f4c032e}},	//   _दीदा_, iktú, ﭘﯩﻖ_, fnfé_, 
   {{0x8c180375,0xddd40129,0x799c03ac,0x2eb4010a}},	//   _חוגי, _écœu, pdsw, _усăс, 
   {{0x59640801,0x98c485a1,0xa2a400dc,0x349400f3}},	//   _ръка, _асол, छिन्, лабр, 
   {{0x629885a2,0xa3ac00dc,0xb4ac02ab,0xbb181884}},	// [a2d0] _štop, कां_, कमे_, _ﺳﺎﻥ_, 
   {{0x932404fb,0x03d400d4,0x68e00432,0xf1b8013a}},	//   نران, ажую, _ýoda, _lišt_, 
   {{0x6d4885a3,0x63ac0fac,0x439485a4,0x00000000}},	//   ybea, _dnbn, рахс, --, 
   {{0x3958202c,0xf1b828b5,0x6d480356,0xc1180014}},	//   nass_, _ništ_, xbea, ھہٕچ_, 
   {{0x07f82172,0x741402f2,0xf07401d3,0x00000000}},	//   _سریع_, _موحا, طیاں_, --, 
   {{0xa3ac0882,0x395885a5,0x6d480c21,0xe8140ad7}},	//   काः_, hass_, wbea, णतया_, 
   {{0x2bb0069f,0x6d4885a6,0x395812ce,0x629802d2}},	//   जासा, tbea, kass_, _átop, 
   {{0xf1b80989,0x395804cc,0x00000000,0x00000000}},	//   _pišu_, jass_, --, --, 
   {{0x395885a7,0xf738001f,0x1c4039b0,0x6cc485a8}},	//   dass_, ያንዳን, бным, уйпа, 
   {{0x6d480192,0x09cc0882,0xf1b8041a,0xeb9801c6}},	//   sbea, ास्य, _višu_, хио_, 
   {{0x2bd83f55,0x5ac401c0,0x3958002f,0x6d5c85a9}},	//   योगा, глэм_, fass_, ósas, 
   {{0x395885aa,0x00000000,0x00000000,0x00000000}},	//   gass_, --, --, --, 
   {{0x2d9c0069,0xed5885ab,0x00000000,0x00000000}},	//   _iawe_, maž_, --, --, 
   {{0x2d9c85ac,0x66e485ad,0xed5885ae,0x3958037e}},	//   _hawe_, гога, laž_, aass_, 
   {{0x2d9c85af,0x395870d8,0xa9a40137,0xe9a485b0}},	//   _kawe_, bass_, _бийд, _байп, 
   {{0x29540801,0x395885b1,0xed5885b2,0x2d9c0241}},	//   _съкр, cass_, naž_, _jawe_, 
   {{0xdecc067d,0xd464311b,0x63840323,0x2d9c85b3}},	// [a2e0] _እዋን_, лите_, лгаа, _mawe_, 
   {{0x2d9c0751,0xa3ac1b90,0x00000000,0x00000000}},	//   _lawe_, काइ_, --, --, 
   {{0x85b400c7,0xed5801ef,0x00000000,0x00000000}},	//   _кәач, kaž_, --, --, 
   {{0x2d9c85b4,0x722802bf,0xed580219,0x00000000}},	//   _nawe_, вців_, jaž_, --, 
   {{0x9e040116,0x00000000,0x00000000,0x00000000}},	//   һчил, --, --, --, 
   {{0x2d9c0241,0xc0d00020,0xdb18002d,0x657485b5}},	//   _aawe_, _እያለ_, rktú, lgyh, 
   {{0x9e040323,0x2d9c39aa,0xfe7800fd,0x7c2401ab}},	//   лчил, _bawe_, түе_, _èiri, 
   {{0x2d9c85b6,0xdcb802e8,0x395800e8,0x657400c7}},	//   _cawe_, ещо_, xass_, ngyh, 
   {{0x5f7400f7,0x2d9c1446,0xa3ac0401,0x395885b7}},	//   _ماار, _dawe_, काऊ_, vass_, 
   {{0x3b546833,0x6d5c041e,0x39580036,0x5478010f}},	//   шкор, ósar, wass_, עטיו, 
   {{0xc0d00020,0x2d9c85b8,0xad6408f0,0xdb180450}},	//   _እያሉ_, _fawe_, _چاهه, nktø, 
   {{0x2d9c85b9,0x497401f4,0x00000000,0x00000000}},	//   _gawe_, блюс, --, --, 
   {{0xc8640166,0x39587086,0xf8b809a0,0x8aa00022}},	//   йтри, rass_, төй_, _ҳрыд, 
   {{0x2d9c01b2,0xdb180240,0xcec00210,0x00000000}},	//   _zawe_, njtë, _więź_, --, 
   {{0x2d9c85ba,0xb4ac0a28,0x395885bb,0xa3ac1524}},	//   _yawe_, कम्_, pass_, काई_, 
   {{0x857401c6,0x3958031c,0x960400f2,0x00000000}},	//   йлсх, qass_, ابآم, --, 
   {{0xdb0829ef,0x9f4c0418,0x5884030c,0xb35485bc}},	// [a2f0] _lofü, nofó_, _сыйа, икаш, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd36c04da,0x69a872d0,0x2bd801ad,0x00000000}},	//   يۇڭ_, _जोडी, योटा, --, 
   {{0x76440161,0x439485bd,0xa3ac27a6,0x00000000}},	//   _ithy, _қасс, काउ_, --, 
   {{0x1ccc1b35,0x2d9c85be,0xdecc02d3,0xdb180112}},	//   ུགས_, _rawe_, _እዋኑ_, chtö, 
   {{0x7644044e,0x2d9c009f,0x00000000,0x00000000}},	//   _kthy, _sawe_, --, --, 
   {{0xdb180194,0x2d9c3545,0xa6c801a9,0x5fa024ae}},	//   cktø, _pawe_, _lgаn, تەلم, 
   {{0x720438b5,0x6014054e,0xdb18036e,0xdbf0013d}},	//   _ئورم, râma, ajtë, hğäl, 
   {{0xed583421,0x2bb05b67,0x5c0400ec,0x6bb4003b}},	//   raž_, जाला, ڌڪوٽ_, аснє, 
   {{0x2d9c85bf,0x764430f5,0xab2885c0,0xa3ac1d8a}},	//   _wawe_, _othy, копа_, काए_, 
   {{0x764402c4,0x2d9c85c1,0xed5800f3,0x672000df}},	//   _nthy, _tawe_, paž_, _ĝojo, 
   {{0xfe7085c2,0x2bd805dc,0xdeb8011a,0xdb1801f4}},	//   _ردم_, योजा, _במעל, yhtö, 
   {{0xc2ec00bd,0x7644008c,0xbe0401d3,0x00000000}},	//   _করছি_, _athy, _اونٹ, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x65c40801,0xca700811,0x00000000,0x00000000}},	//   абва, _انعک, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69d4066d,0x764485c3,0x3ea004fe,0xd62485c4}},	// [a300] _ilye, _ethy, āiti_, роте_, 
   {{0x69a810f7,0x00000000,0x00000000,0x00000000}},	//   _जोती, --, --, --, 
   {{0xc0bc0092,0x9fe400f2,0x00000000,0x00000000}},	//   ዳዲስ_, یسته, --, --, 
   {{0xdb187a1e,0xe5a485c5,0xad9c012d,0x2168361e}},	//   rktø, _тими, woźn, тиди_, 
   {{0x602485c6,0xbb44001f,0xdb1803cd,0x7afc002f}},	//   адда, _የጠቅላ, sktø, ürtz, 
   {{0x644485c7,0x33d40953,0xa2a400cd,0x00000000}},	//   _itki, _ліст, छिद्, --, 
   {{0x21740116,0x69d485c8,0xad9c0210,0x00000000}},	//   _вузр, _olye, roźn, --, 
   {{0xa3ac069f,0x64400356,0x00000000,0x00000000}},	//   काक_, ţoiu, --, --, 
   {{0x8d700228,0xdb080e78,0xaee40032,0x50400209}},	//   زايا, _wofü, ибәһ, _метб, 
   {{0x88b0013b,0x69d485c9,0xdee485ca,0xa6c801a9}},	//   _kyɛf, _alye, _кози, _rgаn, 
   {{0x69d4007c,0x9f4c0332,0xcdcc01af,0x00000000}},	//   _blye, nnfí_, _дњ_, --, 
   {{0x64441591,0x76440055,0x9f4c01e7,0x00000000}},	//   _otki, _rthy, infí_, --, 
   {{0x588485cb,0x68e0010e,0x00000000,0x00000000}},	//   шына, _ýodl, --, --, 
   {{0x628c27c0,0x69d485cc,0x2bac0073,0x00000000}},	//   _opbo, _elye, _झोपा, --, 
   {{0x644485cd,0x201c0083,0x596402e8,0x00000000}},	//   _atki, _mhti_, _къпа, --, 
   {{0x69d4017a,0x4548520c,0x00000000,0x00000000}},	//   _glye, ичум_, --, --, 
   {{0x3da804c5,0xb6a400d1,0xb17c00d7,0x75d400db}},	// [a310] _ওকাল, шиңл, _smťo, _ۇيدا, 
   {{0xdb0806ed,0x77980a5b,0x534485ce,0x92a40114}},	//   _infâ, _скор_, рхаа, ијел, 
   {{0x64440ab7,0x764401e6,0xdd8401ed,0x75d401d5}},	//   _etki, _uthy, _ٹو_, _هيدا, 
   {{0xdd840228,0x201c3110,0x00000000,0x00000000}},	//   _عو_, _ahti_, --, --, 
   {{0x92d40154,0xbb1802dd,0xb11485cf,0x00000000}},	//   াপে_, _ﺳﺎﻱ_, িশ্ব_, --, 
   {{0xdb08021c,0x201c0129,0x00000000,0x00000000}},	//   _anfí, _chti_, --, --, 
   {{0xeb9805c2,0x00000000,0x00000000,0x00000000}},	//   қин_, --, --, --, 
   {{0xe6b80882,0x201c005b,0x00000000,0x00000000}},	//   _उपसङ, _ehti_, --, --, 
   {{0x1c400108,0x00000000,0x00000000,0x00000000}},	//   пным, --, --, --, 
   {{0x63a00198,0xeb980063,0x320c045a,0x261c0142}},	//   ɓons, ћин_, _hkey_, pïog_, 
   {{0x8d7485d0,0x69d40204,0x7ed41ec7,0xdb08067c}},	//   _ناشا, _plye, _وزما, _sofò, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa6c8022e,0x6d58035a,0x764003b2,0x4c0000f1}},	//   _egаl, _iewa, ílyn, _وېبل, 
   {{0x6d580490,0x00000000,0x00000000,0x00000000}},	//   _hewa, --, --, --, 
   {{0x6d5885d1,0x644485d2,0x2fc40076,0x00000000}},	//   _kewa, _stki, _molg_, --, 
   {{0x6d580770,0xf5b40212,0x23280107,0x59ac0073}},	//   _jewa, осую, ҳози_, _जोपर, 
   {{0x6d5885d3,0x7d0403cd,0x00000000,0x00000000}},	// [a320] _mewa, _øist, --, --, 
   {{0xf1a885d4,0x6d5885d5,0x320c85d6,0x2910102c}},	//   یانه_, _lewa, _akey_, _iyya_, 
   {{0x63040736,0x6d5865ef,0x00000000,0x00000000}},	//   حوال, _oewa, --, --, 
   {{0x201c85d7,0x6d5885d8,0xe0d802e8,0x00000000}},	//   _shti_, _newa, лве_, --, 
   {{0x2fc485d9,0x644485da,0x628c0100,0xc60403ce}},	//   _bolg_, _utki, _wpbo, लवीय_, 
   {{0x6d58166a,0x2fc414c5,0xa3ac07f7,0x29100254}},	//   _aewa, _colg_, काओ_, _myya_, 
   {{0x6d5885db,0x2fc409a8,0x628c02d0,0xd1300092}},	//   _bewa, _dolg_, _upbo, ጠታቸው, 
   {{0x6d583142,0x25a00306,0x00000000,0x00000000}},	//   _cewa, _jakl_, --, --, 
   {{0x6d5885dc,0xdb583943,0x00000000,0x00000000}},	//   _dewa, люн_, --, --, 
   {{0x6d580857,0x201c0254,0x0a400092,0x00000000}},	//   _eewa, _uhti_, _የተመራ, --, 
   {{0x291085dd,0xca44030f,0x5ea400f1,0x5d6802e8}},	//   _ayya_, یلیه_, _دمال, _бием_, 
   {{0x6d5885de,0xec3400ec,0x25a001ef,0x00000000}},	//   _gewa, _ڀونگ, _nakl_, --, 
   {{0x2fc4036b,0x00000000,0x00000000,0x00000000}},	//   _yolg_, --, --, --, 
   {{0x6d5885df,0x00000000,0x00000000,0x00000000}},	//   _zewa, --, --, --, 
   {{0x29100083,0xd56485e0,0xd90c109c,0xdb1885e1}},	//   _eyya_, йтап, بیک_, nktü, 
   {{0xdb080137,0xca4485e2,0x6d5885e3,0x00000000}},	//   _infà, _اليه_, _xewa, --, 
   {{0x798c85e4,0xf8b829db,0x89d801d9,0x291000a2}},	// [a330] _ibaw, _төн_, _طوٝر_, _gyya_, 
   {{0x78ac01b2,0x320c0175,0x25a00254,0xd6840dab}},	//   _irav, _skey_, _eakl_, _лумп, 
   {{0x78ac0122,0x320c010a,0x00000000,0x00000000}},	//   _hrav, _pkey_, --, --, 
   {{0x3f8c85e5,0xb1140f1a,0xca7800df,0x00000000}},	//   _abdu_, омеш, רנאט, --, 
   {{0x798c85e6,0x2ed02cbc,0x6d5885e7,0x3eac06af}},	//   _mbaw, तन्त, _rewa, _ardt_, 
   {{0xdb182957,0x2fc401a9,0xae98007b,0x00000000}},	//   nktó, _qolg_, لضبط_, --, 
   {{0x2fc47890,0x6d5885e8,0x798c85e9,0x67200115}},	//   _volg_, _pewa, _obaw, _ĝojk, 
   {{0x78ac85ea,0x0af005f5,0x7bd80381,0x320c009a}},	//   _orav, үүдэ, _alvu, _ukey_, 
   {{0x6d580099,0xa3ac0073,0x2fc400ae,0xdb180413}},	//   _vewa, काच_, _tolg_, kktó, 
   {{0x6d580502,0x798c85eb,0x9f4c0589,0x6e9400fd}},	//   _wewa, _abaw, rnfã_, _мизу, 
   {{0x78ac85ec,0x6d5885ed,0x798c0083,0x79680952}},	//   _arav, _tewa, _bbaw, ﻳﻤﯩﺰ_, 
   {{0x69a86859,0xdb18033f,0x7bd8669e,0x00000000}},	//   _जोशी, ektó, _elvu, --, 
   {{0x394c85ee,0xdb08067c,0x25a00115,0x78ac0e21}},	//   ñesa_, _enfà, _rakl_, _crav, 
   {{0x78ac85ef,0xab281f91,0x798c3c2d,0xec240150}},	//   _drav, _кола_, _ebaw, _بىتپ, 
   {{0x78ac85f0,0xca6400db,0xae1c012d,0x00000000}},	//   _erav, _البۇ_, _पठान_, --, 
   {{0x78ac85f1,0x798c413b,0x93c800e5,0x7c341d1d}},	//   _frav, _gbaw, یالہ_, _ófrá, 
   {{0x7bd80076,0xa3e885f2,0x80f400eb,0x00000000}},	// [a340] _ylvu, адаа_, _জর্জ_, --, 
   {{0xf84401c6,0x798c012d,0x3d0c00c5,0x1414007b}},	//   _хүрд_, _zbaw, _डँसे_, قيقة_, 
   {{0xe29885f3,0x78ac151c,0x00000000,0x00000000}},	//   рае_, _zrav, --, --, 
   {{0xa1885a5b,0x7ddc01d3,0x00000000,0x00000000}},	//   рбда_, _kése, --, --, 
   {{0x80b4012d,0x66140432,0x00000000,0x00000000}},	//   ंमें, mlyk, --, --, 
   {{0x661485f4,0xa2e485f5,0x7ddc85f6,0x9f4c0ffb}},	//   llyk, _догд, _mése, unfà_, 
   {{0x61441ee3,0x7ddc068c,0xce4406ed,0x4f8401d9}},	//   _мева, _lése, озје_, تانہ, 
   {{0x85480006,0x661400ee,0xdb1884bf,0x9da802e8}},	//   brėž, nlyk, rktü, ръка_, 
   {{0x66140108,0x00000000,0x00000000,0x00000000}},	//   ilyk, --, --, --, 
   {{0x0b74001f,0x6614010e,0x3a74011c,0x00000000}},	//   _በአየር_, hlyk, плор, --, 
   {{0x66140209,0x78ac7754,0x7bd001e4,0x8ae000d4}},	//   klyk, _srav, _ĉiuĵ, діял, 
   {{0x98486f63,0x7e780455,0x00000000,0x00000000}},	//   ияга_, muvp, --, --, 
   {{0x7ddc067c,0x661485f7,0x78ac06be,0x959800e5}},	//   _cése, dlyk, _qrav, یئرز_, 
   {{0x7ddc85f8,0xdb0800e4,0x78ac85f9,0x7bd80158}},	//   _dése, _enfá, _vrav, _ulvu, 
   {{0x6614369d,0xdb080c86,0x7c2885fa,0x79587d60}},	//   flyk, _unfà, mmdr, _лийр_, 
   {{0x78ac85fb,0xd9fc13f5,0x2b481050,0x661485fc}},	//   _trav, _उदित_, _đaci_, glyk, 
   {{0x78ac85fd,0x73d8004e,0x00000000,0x00000000}},	// [a350] _urav, бдар_, --, --, 
   {{0x04c867b3,0x4394329e,0x80f400fe,0x00000000}},	//   غولي_, маус, _জৰ্জ_, --, 
   {{0x661485fe,0xf1a8109c,0x9f4c0100,0x00000000}},	//   blyk, یاچه_, mifè_, --, 
   {{0x7ddc85ff,0xeef000c5,0x00000000,0x00000000}},	//   _lésb, _अइबऽ_, --, --, 
   {{0x224801c4,0x6720010f,0xed5800fb,0x00000000}},	//   _etbk_, _ĝoji, ҙоп_, --, 
   {{0xbfc4109a,0xe454010f,0x5348030d,0x00000000}},	//   мбік, _מישט_, _тăкă, --, 
   {{0xfbd000eb,0x00000000,0x00000000,0x00000000}},	//   াফাত, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2bb800c6,0x962400e2,0x00000000,0x00000000}},	//   مادة_, _izņē, --, --, 
   {{0x7ddc2047,0x9c208600,0x7f580353,0xf41c00fe}},	//   _rése, ндыд, _маус_, _ভূতৰ_, 
   {{0x66140209,0xa9a48601,0x00000000,0x00000000}},	//   ylyk, пинд, --, --, 
   {{0xa9a400f7,0x8c34014b,0x00000000,0x00000000}},	//   чимд, _додӣ_, --, --, 
   {{0x6e280627,0x7ddc08a5,0x39348602,0x2ca800ae}},	//   mmeb, _fésb, дэрс, _éad_, 
   {{0x6e2848a1,0x7ddc180f,0xdca02ec9,0x3fc800d1}},	//   lmeb, _vése, _чаши, ﯨﻐﺎﻧ, 
   {{0x66140209,0x6e281418,0xdb08005c,0xfb2400cf}},	//   tlyk, omeb, _anfæ, _ۉرۉپ, 
   {{0xe61800c2,0x317c0097,0x6e288603,0x661420e4}},	//   ёда_, jgwz_, nmeb, ulyk, 
   {{0x66148604,0x7ddc01c7,0x00000000,0x00000000}},	// [a360] rlyk, _hésc, --, --, 
   {{0x6298025a,0x66148605,0x6e284431,0xd01000cc}},	//   _âtok, slyk, hmeb, িগড়_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x236802fa,0xd24c8606,0x7ddc04e6,0x68e00024}},	//   _wdbj_, انن_, _mésc, _žody, 
   {{0x6e2800af,0x60148607,0x7ddc0036,0x651400db}},	//   dmeb, lâmi, _lésc, _روسئ, 
   {{0xd0040353,0xd00c01f7,0x4fd001ec,0x00000000}},	//   пече_, هلن_, нжіт, --, 
   {{0x601406ed,0x00000000,0x00000000,0x00000000}},	//   nâmi, --, --, --, 
   {{0x0fc0010b,0x00000000,0x00000000,0x00000000}},	//   дйән, --, --, --, 
   {{0x7ddc0c6a,0x60d400cc,0xe0d88608,0x00000000}},	//   _pésb, øymd, _ува_, --, 
   {{0x6fdc0ba1,0x6e28037e,0x00000000,0x00000000}},	//   _pèce, ameb, --, --, 
   {{0x200c0270,0xbb180150,0x00000000,0x00000000}},	//   mofi_, _ﺳﺎﻗ_, --, --, 
   {{0x200c8609,0x60140798,0x7ddc0129,0xeef00037}},	//   lofi_, dâmi, _désc, _अइतऽ_, 
   {{0x050000bd,0xdef801af,0x00000000,0x00000000}},	//   ্ধুর_, _тыҡ_, --, --, 
   {{0xd7f8860a,0x4c980375,0x317c0007,0xd5a0036b}},	//   сум_, _לבדו, zgwz_, کلری, 
   {{0x870407d8,0x7ddc0036,0x00000000,0x00000000}},	//   еяте, _gésc, --, --, 
   {{0x200c860b,0x9f4c007f,0x00000000,0x00000000}},	//   hofi_, sifè_, --, --, 
   {{0x3948860c,0x200c860d,0x2bb0070f,0x00000000}},	// [a370] _ifas_, kofi_, जाचा, --, 
   {{0x3868860e,0x6e280356,0x00000000,0x00000000}},	//   _ivar_, zmeb, --, --, 
   {{0x386805a4,0x200c02d2,0x00000000,0x00000000}},	//   _hvar_, dofi_, --, --, 
   {{0x3868860f,0x41e40953,0xdb080267,0x00000000}},	//   _kvar_, ніча, _infä, --, 
   {{0x200c8610,0xc0c8026a,0xf0e800d1,0x94a800d8}},	//   fofi_, зује_, غىتى_, _утна_, 
   {{0x200c8611,0xb4d80307,0x2eb404b0,0x94202374}},	//   gofi_, ़नी_, дсис, _سوزۇ, 
   {{0x39480270,0xbf6404d3,0xbf880a11,0xfc5c1954}},	//   _ofas_, ردوو, سئول_, _ግብጻው, 
   {{0x962411f9,0x6fdc026c,0x7e683129,0x38680356}},	//   _uzņē, _bècc, _dvdp, _ovar_, 
   {{0xeb740276,0x09780137,0x09cc00cc,0xe6b80037}},	//   мынэ, үрмө_, _লগলা, _उप्ज, 
   {{0x39488612,0x7ddc0077,0x6e284101,0xeb983e9f}},	//   _afas_, _pésc, smeb, цио_, 
   {{0x38688613,0xdcec00e2,0xfe703fe2,0x1ccc0327}},	//   _avar_, ādāj, _مدن_, ུགཔ_, 
   {{0x6600010f,0x2bfc00fe,0x2ca800ef,0x00000000}},	//   _ĉoko, ঁতেই_, _šadu_, --, 
   {{0xdb080730,0x2d8c000f,0x38680332,0x00000000}},	//   _anfä, mfee_, _cvar_, --, 
   {{0x3948007f,0x7ddc0036,0x2d8c116e,0x60141ca9}},	//   _efas_, _tésc, lfee_, tâmi, 
   {{0x16a4529e,0x38680354,0x39480421,0x2cac8614}},	//   мври_, _evar_, _ffas_, lved_, 
   {{0x200c8615,0x60140261,0x7ddc8616,0xe61801ce}},	//   zofi_, râmi, _késa, іда_, 
   {{0x672001e4,0xdb0801e3,0x2cac8617,0x00000000}},	// [a380] _ĝoju, _enfä, nved_, --, 
   {{0x316c0165,0x25a40f03,0x7ddc0129,0x261c0165}},	//   _adez_, žol_, _mésa, cïon_, 
   {{0x7ddc020c,0xdecc02d3,0x629c3a65,0x386805d5}},	//   _lésa, ኣተን_, uwpo, _zvar_, 
   {{0x2cac8618,0x629c003a,0x00000000,0x00000000}},	//   kved_, rwpo, --, --, 
   {{0x200c8619,0xd5980375,0xdb08007c,0x00000000}},	//   tofi_, _ובכל, _infå, --, 
   {{0x7d080200,0x68e0010e,0x2bac09ab,0x00000000}},	//   hërë, _ýodu, _झोला, --, 
   {{0xa2d44d49,0x316c04d4,0x2d8c2517,0x2cac861a}},	//   _غيرت, _fdez_, ffee_, eved_, 
   {{0x7ddc861b,0x38c40de2,0x232807a5,0x00000000}},	//   _bésa, _jërë_, _гоҳи_, --, 
   {{0x3dc40cf9,0x61e0861c,0x4438861d,0xa1840184}},	//   rjmw_, mhol, _kir_, _ныҡл, 
   {{0x61e0861e,0x5f74861f,0x7ddc8620,0x44388621}},	//   lhol, _زائر, _désa, _jir_, 
   {{0x44388622,0x39480194,0xe9080327,0x67e000d0}},	//   _mir_, _pfas_, _གཙུབ_, _môjd, 
   {{0x3f9c601a,0x44388623,0x61e010f5,0x2b5003ee}},	//   levu_, _lir_, nhol, ızca_, 
   {{0x44380192,0xdcf804fb,0x61e0009a,0x00000000}},	//   _oir_, _براش_, ihol, --, 
   {{0x44388624,0x61e08625,0x6fdc020c,0x3f9c8626}},	//   _nir_, hhol, _kèca, nevu_, 
   {{0x38c4069c,0xb59465cb,0x7d080240,0x8aa041e5}},	//   _bërë_, нивш, bërë, _арыд, 
   {{0x7d04025a,0x44388627,0x3868245b,0x7c38047e}},	//   _gïrï, _air_, _tvar_, _hivr, 
   {{0x44383630,0x61e0019b,0xd7e400d6,0xb4d8068f}},	// [a390] _bir_, dhol, _жіно, ़ने_, 
   {{0x3f9c3ad4,0x61e08628,0x799c8629,0x4438862a}},	//   jevu_, ehol, lesw, _cir_, 
   {{0x4438862b,0x61e00084,0xdb083f5b,0x3f9c862c}},	//   _dir_, fhol, _unfä, devu_, 
   {{0x7c38862d,0x44381675,0x799c862e,0x61e05f03}},	//   _livr, _eir_, nesw, ghol, 
   {{0x44387ea3,0x60c0020c,0x2cac0165,0xeef0000d}},	//   _fir_, gxom, xved_, _अइहऽ_, 
   {{0x4438862f,0x61e01b9f,0x3f9c7851,0x7ddc0129}},	//   _gir_, ahol, gevu_, _résa, 
   {{0x61e02747,0x7ddc8630,0x799c8631,0x7ae401ef}},	//   bhol, _sésa, kesw, _řitn, 
   {{0x61e08632,0x6fdc00f7,0x44388633,0x7ddc8634}},	//   chol, _dèca, _zir_, _pésa, 
   {{0x799c8635,0x44388636,0x3f9c5617,0x7c3803b2}},	//   desw, _yir_, bevu_, _bivr, 
   {{0x2cac8637,0x2d8c8638,0x1d208639,0x44380067}},	//   rved_, sfee_, ымым, _xir_, 
   {{0x7c38863a,0x291c033f,0x24540241,0x91f0023e}},	//   _divr, ętam_, _kùmò_, _आगाज_, 
   {{0x799c0c8c,0x69c401d4,0x7ddc4a16,0xaab40220}},	//   gesw, ujke, _tésa, _үйді, 
   {{0x7c38013d,0x38c40240,0xa2d401f9,0xd94000d8}},	//   _fivr, _rërë_, _मॅन्, ѓери, 
   {{0x7c38863b,0x6d48863c,0x38c40023,0x69c4863d}},	//   _givr, lcea, _sërë_, sjke, 
   {{0x4438863e,0x66e4863f,0x61e08640,0x6d48011c}},	//   _rir_, хова, yhol, ocea, 
   {{0x61e08641,0x3f9c00d2,0x44380c18,0x7c3805c7}},	//   xhol, zevu_, _sir_, _zivr, 
   {{0x61e00084,0x44388642,0x6d48327f,0x67e001f1}},	// [a3a0] vhol, _pir_, icea, _pôjd, 
   {{0x753c083a,0x61340036,0xa2e40026,0x44380169}},	//   _egsz, _lülü, нозд, _qir_, 
   {{0x44386852,0x38c402d3,0x61e08643,0x45440022}},	//   _vir_, _tërë_, thol, _аҕба, 
   {{0x44388644,0xe2148645,0x518000cf,0x3f9c8646}},	//   _wir_, رباع, гуша, wevu_, 
   {{0x61e01455,0x3f9c8647,0xbb600092,0x00000000}},	//   rhol, tevu_, _ለጠቅላ, --, 
   {{0x442c0699,0x6fdc067c,0x44388648,0x61e08649}},	//   _òd_, _pèca, _uir_, shol, 
   {{0x61e016ec,0x3f9c864a,0x61340166,0x673c003b}},	//   phol, revu_, _bülü, _mgpj, 
   {{0x291c068f,0x61e00f3f,0x3f9c864b,0x7c3805d1}},	//   ętaj_, qhol, sevu_, _sivr, 
   {{0x98a871e1,0x799c0c8c,0x91e016ab,0x6e380142}},	//   yacı_, vesw, _соте, _diwb, 
   {{0x799c53ff,0xd24c0137,0x00000000,0x00000000}},	//   wesw, _ئچە_, --, --, 
   {{0x7c38864c,0x799c864d,0x4f84040b,0x98a80790}},	//   _vivr, tesw, _سالہ, vacı_, 
   {{0x6134864e,0x6e380042,0x6d480332,0x6014054e}},	//   _gülü, _giwb, ccea, râmu, 
   {{0x799c2cdf,0x7c38030a,0x441000e1,0x106c00d1}},	//   resw, _tivr, ़काऊ_, ﭽﯩﺪﯨ, 
   {{0xb8c814cf,0x613401b8,0x799c864f,0x00000000}},	//   _गई_, _zülü, sesw, --, 
   {{0x98a81b0d,0x5018011a,0x799c8650,0xdb0401f4}},	//   racı_, פולו, pesw, ämäh, 
   {{0x7ddc8651,0x799c009a,0x13f80073,0xc734009f}},	//   _méso, qesw, ्व्ह_, افِظ, 
   {{0x3a282fd9,0x7ddc0098,0x98a80205,0x00000000}},	// [a3b0] _ihap_, _léso, pacı_, --, 
   {{0x7bc80399,0x8b04013a,0x930400d8,0x00000000}},	//   njdu, _uhří, нџел, --, 
   {{0x3a2806a3,0xfe10012c,0x7ae80158,0x2c5c0100}},	//   _khap_, ावास_, nzdt, zňd_, 
   {{0xcb1000c8,0x02a401ec,0x35a402f2,0x00000000}},	//   אלע_, ырум, _جۆرێ_, --, 
   {{0x3a2801c3,0x6e38015d,0x94a875e1,0xfbb000cd}},	//   _mhap_, _riwb, _этна_, जयाम, 
   {{0x3a28020c,0x60d405ac,0x61340342,0x20d000d1}},	//   _lhap_, øyma, _sülü, شقىس, 
   {{0xada428e5,0x6d48005a,0x7d1c0213,0xa2800c62}},	//   вайл, tcea, ərsi, _نیلو, 
   {{0x7ddc8652,0x3a28001e,0x2c5c0100,0x00000000}},	//   _déso, _nhap_, tňd_, --, 
   {{0x6d488653,0xb0340124,0x6144129d,0xdbdc01e1}},	//   rcea, _анаш, _شىلە, _tíìl, 
   {{0x6d488654,0xe5000f4c,0x7ddc00e8,0x00000000}},	//   scea, लपति_, _féso, --, 
   {{0x6e38015d,0x6d480356,0x7e7400db,0x6014054e}},	//   _tiwb, pcea, _مانئ, râmt, 
   {{0x3a288655,0x1f240014,0x00000000,0x00000000}},	//   _chap_, _شِنہ, --, --, 
   {{0xd84000d7,0x84f0000d,0x00000000,0x00000000}},	//   _rečí_, _घेंट_, --, --, 
   {{0xeb98449b,0xe7380107,0x00000000,0x00000000}},	//   _цик_, ҷеҳ_, --, --, 
   {{0x96608656,0xb8c85b29,0x00000000,0x00000000}},	//   икре, _गै_, --, --, 
   {{0x3a28016d,0xa96800f2,0x00000000,0x00000000}},	//   _ghap_, _کمکم_, --, --, 
   {{0xd464529e,0x15403f3a,0x00000000,0x00000000}},	// [a3c0] ките_, реум, --, --, 
   {{0xe7380139,0x616c0023,0x987800d9,0x00000000}},	//   _оеп_, _ሽበራዊ_, _קריק, --, 
   {{0x66e45f5d,0xa184013d,0x00000000,0x00000000}},	//   _рона, вылл, --, --, 
   {{0x7ddc8657,0xd24c8658,0xc5cc0154,0x7f580175}},	//   _réso, زنه_, রোজপ, wbvq, 
   {{0x7ddc002e,0x271800cc,0x00000000,0x00000000}},	//   _séso, _দলটো_, --, --, 
   {{0x64540223,0xbebc00ef,0x7f4801e2,0x00000000}},	//   mpyi, _dzīn, رستې_, --, 
   {{0x6fdc0228,0x9e048659,0x3d94074d,0xa6c801d5}},	//   _tècn, кчил, гийр, _zgаr, 
   {{0x5f144802,0xd6d0010f,0x00000000,0x00000000}},	//   _पुण्_, שׂה_, --, --, 
   {{0x3a280280,0x9be40111,0x10a00395,0x00000000}},	//   _rhap_, вінк, _китн, --, 
   {{0x9f5c007f,0x7bc80399,0x3b540166,0x6f0c003e}},	//   _ektò_, ujdu, ыкор, éncé, 
   {{0xd00c004b,0x3a2801fb,0xd3780a1e,0x8aa01318}},	//   _بلل_, _phap_, וריט, аряд, 
   {{0x67200115,0x1da4000d,0xdde80472,0x00000000}},	//   _ĝojp, _खसित, _غرضه_, --, 
   {{0xc86430c4,0x386c865a,0xb7880bd6,0xe85001b9}},	//   итри, éer_, нәне_, یچید, 
   {{0x48140276,0x6d5c06ea,0x00000000,0x00000000}},	//   имяс, ðsav, --, --, 
   {{0x3a28865b,0x15a8013e,0x00000000,0x00000000}},	//   _thap_, мъаи_, --, --, 
   {{0xb27401e0,0x00000000,0x00000000,0x00000000}},	//   ҫлаш, --, --, --, 
   {{0xdb084e9b,0x9804865c,0x3358084c,0x00000000}},	// [a3d0] _anfø, _аянд, еазэ_, --, 
   {{0x6fdc00f7,0xc3540640,0x00000000,0x00000000}},	//   _rèco, икуј, --, --, 
   {{0x59d40254,0x36d40209,0xa2c00131,0xf1b8035b}},	//   _डकार, _сонр, бәтк, нӡа_, 
   {{0x8af8011a,0x999c00c0,0x00000000,0x00000000}},	//   והבי, mptų_, --, --, 
   {{0x534404a9,0xdfcc004b,0x999c00c0,0x00000000}},	//   _ахба, ړيو_, lptų_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb0800e8,0x7644865d,0xbbdc00bc,0x41240139}},	//   _dafë, _juhy, यसैक, лфәб, 
   {{0x7644865e,0x7db44077,0xa1a401af,0x999c00c0}},	//   _muhy, асьц, _йыуһ, iptų_, 
   {{0x0cb00f22,0x7644009f,0xa9a400d1,0x3d1801f9}},	//   য়ন্ত, _luhy, ۇمدى, _पडणे_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x160004af,0x7644005a,0x4034010b,0x3fb81374}},	//   रचार_, _nuhy, _тефс, _جھنگ_, 
   {{0x66e400c2,0x7afc43e9,0x60140120,0x35980092}},	//   қоба, úrta, lâmp, ሆኑበት_, 
   {{0xfd4402d5,0x7764036e,0xc8240022,0x69d80171}},	//   _тэхн, _behx, измқ, _ābeļ, 
   {{0x291c0061,0x6148002e,0x3d180073,0x6a8400d8}},	//   āta_, _këló, _पडते_, _блка, 
   {{0x65b8865f,0x77640327,0x59ac0ce0,0x8120000d}},	//   нуар_, _dehx, _जोकर, _बर्ख_, 
   {{0x64a48660,0x764400b8,0x00000000,0x00000000}},	//   лаба, _duhy, --, --, 
   {{0xe3b88661,0xe3b001d9,0x637801ec,0x00000000}},	// [a3e0] нба_, ٝرا_, есер_, --, 
   {{0x64540393,0xe28c01a9,0xd04403e3,0x00000000}},	//   rpyi, ttа_, _ömər, --, 
   {{0xdb088662,0xc3303256,0x1bf4008f,0x57400276}},	//   _cafè, زەر_, נצער_, _ынэб, 
   {{0x96f80677,0x64542a6a,0xbebc0171,0xe28c022e}},	//   _טלית, ppyi, _dzīl, rtа_, 
   {{0xe2840184,0x65640007,0x71242928,0x100c0d0d}},	//   _әлби, _iekh, ۇرۇل, िवंश_, 
   {{0x65640280,0x40341b9f,0x62642309,0x66140784}},	//   _hekh, шелс, _مارق, loyk, 
   {{0x65642ebc,0x63ac0280,0xa2e48663,0x7ddc020c}},	//   _kekh, _iabn, _совд, _wésm, 
   {{0x64448664,0x63ac8665,0xbbdc07b7,0xb91402e3}},	//   _kuki, _habn, यस्क, godị_, 
   {{0x60083117,0x65648666,0x63ac0218,0x64448667}},	//   _знам_, _mekh, _kabn, _juki, 
   {{0x644443c4,0x5ba48668,0xda788669,0x656456fc}},	//   _muki, уриз, ням_, _lekh, 
   {{0xd00c866a,0x6444866b,0x6614866c,0x5d84866d}},	//   _علم_, _luki, koyk, _ملال, 
   {{0x6444866e,0x63ac1008,0xdb081bce,0xd3340375}},	//   _ouki, _labn, _jafé, טריה_, 
   {{0x5c5455c3,0x6444866f,0x66140784,0x76440051}},	//   _стеф, _nuki, doyk, _suhy, 
   {{0x628c022e,0x59d40210,0x00000000,0x00000000}},	//   _oqbo, _डकवर, --, --, 
   {{0xd5b88670,0x65648671,0x64448672,0x9a70009f}},	//   нса_, _bekh, _auki, _انبڙ, 
   {{0x6564003e,0xdb08068c,0x93242002,0x66140784}},	//   _cekh, _rafè, ۇران, goyk, 
   {{0xd3788673,0x64448674,0x55048675,0x63ac0427}},	// [a3f0] ече_, _cuki, учва, _babn, 
   {{0x644423db,0xd24405f5,0x63ac0548,0x92688676}},	//   _duki, гэди, _cabn, ерда_, 
   {{0x63ac0211,0x65648677,0x644401c6,0x66140124}},	//   _dabn, _fekh, _euki, boyk, 
   {{0x64448678,0x7ddc0098,0x65648679,0x8af8008f}},	//   _fuki, _désk, _gekh, עלאז, 
   {{0x6444015c,0x6014084c,0xdb08002e,0xc0f8001f}},	//   _guki, tâmp, _dafé, _ገደማ_, 
   {{0x3d181533,0x65646e0e,0x63ac867a,0xc05800f1}},	//   _पड़े_, _zekh, _gabn, اشنا_, 
   {{0x656415d3,0x6444867b,0x8b6400d1,0xa368022e}},	//   _yekh, _zuki, ңпиң_, rkеt, 
   {{0x6444105c,0x75cc01d3,0x00000000,0x00000000}},	//   _yuki, _főző, --, --, 
   {{0x63ac102c,0x64440009,0x4ea400d1,0xc0bc0092}},	//   _yabn, _xuki, _әрза, _ሱፐር_, 
   {{0xabd4147e,0xab6401d5,0x7ee40124,0x00000000}},	//   рциј, швол, рцәе, --, 
   {{0x628c867c,0x00000000,0x00000000,0x00000000}},	//   _xqbo, --, --, --, 
   {{0xdcf406fe,0x6d5c030a,0xacf801ec,0x00000000}},	//   افیت_, ñsad, _инеу_, --, 
   {{0x6564867d,0x3ea00356,0x6c78010f,0xd9d0215c}},	//   _rekh, ăite_, _סאַפ, تەيگ, 
   {{0x6444867e,0x0684059f,0xadb800ec,0xf3f400fe}},	//   _ruki, бҳон, _سهڻا_, _অৱসৰ_, 
   {{0x6444867f,0x656405b1,0x63ac0014,0x47a8015b}},	//   _suki, _pekh, _rabn, খালী, 
   {{0x64448680,0x63ac8681,0x496404a9,0xd5e001a9}},	//   _puki, _sabn, _униң, ожси, 
  
   {{0x7ddc8682,0x63ac014f,0xdb080de2,0x64b0033f}},	// [a400] _désh, _pabn, _rafé, ीमेश, 
   {{0x644419a2,0x63ac0a4d,0x65648683,0x6fdc01c7}},	//   _vuki, _qabn, _wekh, _dèck, 
   {{0x65648684,0x644400f2,0xe5788685,0x630400c6}},	//   _tekh, _wuki, _изн_, جوال, 
   {{0x64448686,0xfc480016,0xe0d815ed,0x66140309}},	//   _tuki, _lửa_, кве_, qoyk, 
   {{0x64440280,0x63ac0548,0x68e00327,0x00000000}},	//   _uuki, _tabn, _żodj, --, 
   {{0xfc480016,0x2490012d,0x00000000,0x00000000}},	//   _nửa_, mtym_, --, --, 
   {{0x7ddc20ef,0x53980375,0x6fdc004a,0xdea000f1}},	//   _hési, _שילו, _mèch, تیای, 
   {{0x6fdc004a,0x5f7400db,0xd0b006be,0x7ddc00e5}},	//   _lèch, _چاار, hşər, _kési, 
   {{0x5f148687,0x5f748688,0x24900076,0xfc480208}},	//   _पुर्_, _ناار, ntym_, _bửa_, 
   {{0xfc4807ae,0xa03000f7,0x24908689,0x6d5c0174}},	//   _cửa_, _بۉتت, itym_, ðsar, 
   {{0x290c013f,0x7ddc868a,0x5018011a,0xdd880153}},	//   _ɛfae_, _lési, _יומו, _абед_, 
   {{0x9964868b,0x8d80010b,0xdb080205,0xcc84030f}},	//   штол, _душд, _infü, دنیه_, 
   {{0x6fdc02e2,0x25b0062c,0xc8c80014,0x9be8009b}},	//   _bèch, ddyl_, لوَن_, _имдб_, 
   {{0xd7f8868c,0x24900f91,0xbb300046,0x36d44627}},	//   тум_, dtym_, _ﺫﻟﻙ_, богр, 
   {{0x3604868d,0x66c801e1,0x13a440ec,0x964401c6}},	//   موسف, _kàṣà_, ینری_, рэгд, 
   {{0x8b38011a,0x9f4c0166,0x00000000,0x00000000}},	//   _בתוצ, lifä_, --, --, 
   {{0x798c01e2,0x5b0001d9,0x33743ab4,0x06140212}},	// [a410] _icaw, _دِژم, йгар, ідую, 
   {{0x7ddc0231,0x78ac868e,0x6fdc02e2,0xd684868f}},	//   _dési, _isav, _gèch, _кумп, 
   {{0xdb083b95,0x25b00076,0x249000d7,0x5f1402c3}},	//   _infó, bdyl_, atym_, _पुल्_, 
   {{0xc2448690,0x7ddc02d2,0xc2c4007b,0x00000000}},	//   інік, _fési, تيمي, --, 
   {{0xdb08245f,0x7ddc3ae2,0xdce0009b,0xc10400c6}},	//   _anfü, _gési, _beoč, يومي, 
   {{0xf3e40050,0x218400c7,0x80a400f2,0x74140116}},	//   _آسُ, атәҳ, تمهن, _چوڭا, 
   {{0xfc48001e,0x83f843be,0x3eac0051,0x00000000}},	//   _rửa_, _терс_, _csdt_, --, 
   {{0xfc4807ae,0x798c0070,0x3f8c009a,0x78ac8691}},	//   _sửa_, _ncaw, _ecdu_, _osav, 
   {{0x9f4c0139,0x00000000,0x00000000,0x00000000}},	//   fifä_, --, --, --, 
   {{0xebe400d8,0x00000000,0x00000000,0x00000000}},	//   сооп, --, --, --, 
   {{0x78ac8692,0xc05402d3,0xfc480051,0x3b840092}},	//   _asav, _ዝተቓለ, _vửa_, ራቢዎች_, 
   {{0xdb08068c,0x6fdc5725,0xed58009d,0x7db4007b}},	//   _anfó, _sèch, _ёол_, _وصنا, 
   {{0xeb984170,0x78ac01ed,0xd7c00490,0x6fdc0129}},	//   _бил_, _csav, शांच, _pèch, 
   {{0x7ddc5f6a,0x798c01e2,0xab288693,0x00000000}},	//   _rési, _ecaw, _йола_, --, 
   {{0x78ac0921,0xfd640521,0x24080107,0x00000000}},	//   _esav, _ngwụ, ҳнаи_, --, 
   {{0x7ddc8694,0xdb080100,0x6fdc00cf,0xab8000db}},	//   _pési, _enfó, _dèci, _بۇگۉ, 
   {{0xfd6401f2,0xe7e4009e,0xd624023a,0xe5a400d1}},	// [a420] _agwụ, _নদীয, соте_, _һини, 
   {{0x69d48695,0x7ddc8696,0xdb082561,0x2490033f}},	//   _hoye, _vési, _infò, rtym_, 
   {{0x69d43d81,0xc6900131,0x24908697,0x9bf8008f}},	//   _koye, _تېز_, stym_, נהעט, 
   {{0x69d48698,0x3d184fed,0x3eac0334,0x67e00419}},	//   _joye, _पडले_, _rsdt_, _môjm, 
   {{0x69d48699,0xbb44001f,0x00000000,0x00000000}},	//   _moye, _ከጠቅላ, --, --, 
   {{0x69d4869a,0x1b1000cc,0x00000000,0x00000000}},	//   _loye, ডেটে_, --, --, 
   {{0x7ddc00db,0x69d4378b,0x91b400fe,0x00000000}},	//   _mésv, _ooye, _অকৰ্, --, 
   {{0x69d4869b,0x7ddc0158,0xd654011a,0x00000000}},	//   _noye, _lésv, זיקת_, --, 
   {{0xdce005be,0x61e0869c,0x8d70869d,0x9f4c0789}},	//   _teoč, mkol, سايا, unfó_, 
   {{0x3a74869e,0x02dc00dc,0x00000000,0x00000000}},	//   олор, _यथाभ, --, --, 
   {{0x69d4869f,0x61e02255,0xdb08033b,0x78ac1418}},	//   _boye, okol, _anfò, _ssav, 
   {{0x61e086a0,0x201c003e,0x0dc486a1,0xa6cc00eb}},	//   nkol, _hkti_, _гуши_, রনাট, 
   {{0x69d486a2,0x16b0194b,0x61e086a3,0x00000000}},	//   _doye, ुम्ब, ikol, --, 
   {{0xb8d04108,0x61e086a4,0x9f500066,0xdb0886a5}},	//   _ऐन_, hkol, ècèk_, _hafí, 
   {{0x61e086a6,0xdb0886a7,0x69d486a8,0x798c007f}},	//   kkol, _enfò, _foye, _tcaw, 
   {{0x69d486a9,0x78ac86aa,0x61e086ab,0xe72c01d5}},	//   _goye, _tsav, jkol, _zbеk_, 
   {{0x78ac86ac,0x61e005d6,0xd7f8084c,0xf3f807d5}},	// [a430] _usav, dkol, _бун_, анаш_, 
   {{0x61e02df3,0x69d4055a,0xc5381d0f,0x337401ec}},	//   ekol, _zoye, спух_, ігер, 
   {{0x69d40bd7,0xc0540023,0x00000000,0x00000000}},	//   _yoye, _ዝተማል, --, --, 
   {{0x61e086ad,0x201c86ae,0xc05402d3,0x00000000}},	//   gkol, _akti_, _ዝተመል, --, 
   {{0x201c003e,0x7ddc86af,0x2ba813f7,0x506401b9}},	//   _bkti_, _jésu, _कसला, ётда, 
   {{0x61e086b0,0xae780395,0x00000000,0x00000000}},	//   akol, асих_, --, --, 
   {{0x7ddc020c,0x61e086b1,0x00000000,0x00000000}},	//   _lésu, bkol, --, --, 
   {{0x61e086b2,0xec7886b3,0x201c01d5,0x00000000}},	//   ckol, апи_, _ekti_, --, 
   {{0x69d40bc9,0xafe40184,0x320c0124,0x00000000}},	//   _roye, _һоҡл, _ijey_, --, 
   {{0x69d486b4,0x2b38084c,0x00000000,0x00000000}},	//   _soye, иянэ_, --, --, 
   {{0x69d486b5,0xa9a414b3,0x00000000,0x00000000}},	//   _poye, оинд, --, --, 
   {{0x5ed003f4,0x27f886b6,0x7ddc86b7,0x69d40009}},	//   _থেকে, _smpn_, _bésu, _qoye, 
   {{0x69d486b8,0x320c014b,0x2d9c0099,0xdd8c1af5}},	//   _voye, _mjey_, _ibwe_, _شوو_, 
   {{0x69d4055a,0x61e086b9,0x7ddc14a9,0x60d405ac}},	//   _woye, zkol, _désu, øymi, 
   {{0x69d40296,0x66e4531d,0x320c00c7,0xd7d800b5}},	//   _toye, цова, _ojey_, gsパ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2d9c86ba,0x7ddc0066,0xb9e401ec,0x61e001e4}},	// [a440] _mbwe_, _gésu, _ءسىى, vkol, 
   {{0xe29886bb,0x320c6479,0xca700023,0x53c457bf}},	//   иаз_, _ajey_, _ኾይኖም_, огум_, 
   {{0x2d9c1418,0x862401d5,0x61e086bc,0x00000000}},	//   _obwe_, _فکرل, tkol, --, 
   {{0x7ddc86bd,0x614400d8,0x00000000,0x00000000}},	//   _yésu, цеда, --, --, 
   {{0x61e086be,0x42940020,0xb3742002,0xc2cc0150}},	//   rkol, _ማግኘት_, زدەش, _ءﺳﯘﺗ, 
   {{0x2d9c04ba,0x320c0022,0x1ea886bf,0xdb0886c0}},	//   _abwe_, _ejey_, لابي_, _safí, 
   {{0x290c013f,0x21740107,0x65340e4a,0xb3543224}},	//   _ɛfaa_, _муар, _درگذ, _رینا_, 
   {{0x934010f5,0x7ddc86c1,0x2cbc015d,0x3f800356}},	//   _інте, _nést, _brwd_, şiu_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7ddc2047,0x81ac0154,0x00000000,0x00000000}},	//   _résu, _কচি_, --, --, 
   {{0x3eb801ed,0x7ddc020c,0x00000000,0x00000000}},	//   _ért_, _sésu, --, --, 
   {{0xec3401ed,0xab78001f,0x2cbc015d,0x683006ea}},	//   _ہونگ, ያሳየው_, _frwd_, hædd, 
   {{0x7ddc86c2,0xdd1401d5,0x00000000,0x00000000}},	//   _dést, _بوشخ, --, --, 
   {{0xbebc11f9,0x69d4002d,0x00000000,0x00000000}},	//   _dzīv, êzer, --, --, 
   {{0x7ddc86c3,0xd1dc0020,0x67e00030,0x19f40014}},	//   _fést, ናቀቀ_, _môjh, _وِتھ_, 
   {{0x7bd80c58,0x6fdc004e,0x7ddc0036,0xd5a001b9}},	//   _hovu, _hèct, _iéss, بلری, 
   {{0x7bd886c4,0x94a8026a,0x394886c5,0x683008a5}},	// [a450] _kovu, штва_, _igas_, fædd, 
   {{0x320c022c,0x7bd80327,0x7ddc48f9,0x00000000}},	//   _sjey_, _jovu, _késs, --, 
   {{0x7afc0597,0x7bd802ce,0x7ddc0798,0x00000000}},	//   úrth, _movu, _jéss, --, 
   {{0x7bd886c6,0x386866dd,0xdb0805da,0xc05c02d3}},	//   _lovu, _kwar_, _mafà, _ልኡላው, 
   {{0x4dd02baf,0xa6e00008,0x050800fe,0xfbbc00cd}},	//   তসমূ, öðva, _শৰীৰ_, ्ञाम, 
   {{0xa2a41533,0x7bd886c7,0x6fdc004e,0xa6c8022e}},	//   _टैक्, _novu, _nèct, _rgаz, 
   {{0xdfcc0447,0x394886c8,0x079c00df,0x00000000}},	//   ايى_, _ogas_, יסגל, --, 
   {{0x3948016d,0x320c00e4,0xee380640,0xdd8c007b}},	//   _ngas_, _ujey_, љни_, هوى_, 
   {{0x386807ab,0x321c0034,0x6fdc0268,0x7bd8003a}},	//   _nwar_, mowy_, _sècu, _bovu, 
   {{0x7bd886c9,0x394886ca,0x6fdc0268,0x321c0034}},	//   _covu, _agas_, _pècu, lowy_, 
   {{0x7bd886cb,0x316c86cc,0x386886cd,0x7ddc86ce}},	//   _dovu, _keez_, _awar_, _pést, 
   {{0x2d9c0796,0x38680bc2,0x321c05ff,0x2bfc00fe}},	//   _ubwe_, _bwar_, nowy_, ুতেই_, 
   {{0x7ddc86cf,0xab64030d,0x0ca81063,0x00000000}},	//   _vést, _евлл, _خطاي_, --, 
   {{0x38681f21,0xdb0805da,0x7ddc00db,0x6830037e}},	//   _dwar_, _fafà, _féss, kæde, 
   {{0x7ddc86d0,0x321c0034,0x2d8c0076,0x66d42ac2}},	//   _tést, kowy_, ogee_, dükç, 
   {{0x2d8c86d1,0x7bd8055a,0x38680135,0xd1dc001f}},	//   ngee_, _zovu, _fwar_, ናቀቅ_, 
   {{0x321c86d2,0x7bd886d3,0x67e00109,0x7ddc003e}},	// [a460] dowy_, _yovu, _lôji, _késr, 
   {{0x7ddc00e8,0x142000f0,0x7bd8022e,0x00000000}},	//   _yéss, едум, _xovu, --, 
   {{0x386886d4,0x683086d5,0xe29886d6,0x2cac0036}},	//   _zwar_, rædd, сае_, hwed_, 
   {{0x321c033f,0xa5080a5b,0xdef80124,0x00000000}},	//   gowy_, _гема_, ҩык_, --, 
   {{0x55b80375,0x2d8c86d7,0x90500006,0xa2ec013d}},	//   _המכו, dgee_, евіц, bíğí_, 
   {{0xdb0804f3,0x2d8c4cbd,0x00000000,0x00000000}},	//   _infö, egee_, --, --, 
   {{0x316c005a,0x321c033f,0x195000b5,0x7bd803b2}},	//   _feez_, bowy_, _ｎｅｏ_, _rovu, 
   {{0x2d8c86d8,0x7bd8036b,0x6fdc067c,0x9da802e8}},	//   ggee_, _sovu, _sèct, съка_, 
   {{0x7bd886d9,0xdb0805da,0xadb400cf,0x00000000}},	//   _povu, _safà, بۇنا_, --, 
   {{0x7ddc06ed,0x7bd886da,0x2d8c062c,0x8d7001d9}},	//   _péss, _qovu, agee_, ٘ایا, 
   {{0x386886db,0xc4c808dd,0xdbf000a2,0x00000000}},	//   _swar_, रमुख, mşül, --, 
   {{0x7bd886dc,0xbebc0171,0xeb3400db,0x00000000}},	//   _wovu, _dzīt, بىپد, --, 
   {{0x7bd886dd,0x394800d8,0x7ddc00e8,0x66d41432}},	//   _tovu, _vgas_, _wéss, yükç, 
   {{0x386815f5,0x8c4086de,0x321c86df,0xca440214}},	//   _vwar_, _зече, zowy_, _کليه_, 
   {{0x3948020c,0xdb080267,0xb4d400dc,0xb5940d97}},	//   _tgas_, _anfö, िङ्_, мивш, 
   {{0x39480009,0xfe780064,0x683001bf,0x00000000}},	//   _ugas_, _mvį_, væde, --, 
   {{0x73d886e0,0x38680b45,0x316c0204,0x7ddc020c}},	// [a470] одар_, _uwar_, _reez_, _yésr, 
   {{0x321c033f,0x799c13ee,0x6830005c,0x00000000}},	//   wowy_, lfsw, tæde, --, 
   {{0x321c068f,0x78bc01bf,0x2d8c0009,0x7c2838a6}},	//   towy_, lvsv, ygee_, ildr, 
   {{0x683086e1,0x2cac00a9,0x7c280112,0x41b400d8}},	//   ræde, ywed_, hldr, есшт, 
   {{0x321c86e2,0x799c6eb8,0x6830005c,0x00000000}},	//   rowy_, ifsw, sæde, --, 
   {{0x321c0034,0x04440153,0x00000000,0x00000000}},	//   sowy_, _пеўн, --, --, 
   {{0x321c033f,0x2d8c0ea0,0xee386fe4,0x69dc0037}},	//   powy_, tgee_, онк_, _पवली, 
   {{0x7bdc86e3,0x799c0d27,0x1950019b,0x7c280b4f}},	//   örun, jfsw, _ｎｅｔ_, eldr, 
   {{0x2d8c86e4,0x60d405ac,0x00000000,0x00000000}},	//   rgee_, øymt, --, --, 
   {{0x7c280c86,0xdb0800d8,0x2cac017a,0x2d8c0af9}},	//   gldr, _safá, rwed_, sgee_, 
   {{0x799c3262,0xeeb80f4e,0xbebc00de,0x5a600139}},	//   ffsw, _флеш_, _dzīs, ккэб, 
   {{0xdb08102c,0x7c2808ce,0x00000000,0x00000000}},	//   _qafá, aldr, --, --, 
   {{0xcd281d1f,0x6d582f05,0x6e282d75,0xa174010f}},	//   _اسان_, _ifwa, mleb, וערד_, 
   {{0x6e280385,0xa6c886e5,0x645800b0,0x6d580857}},	//   lleb, олга_, _ōtio, _hfwa, 
   {{0x1950037e,0x6e2804ba,0x291c012d,0x15a800d1}},	//   _ｎｅｗ_, oleb, łta_, ﺷﻠﯩﻐ, 
   {{0xdb0800c6,0x6e2886e6,0x24e80b7b,0xf5b47a9c}},	//   _uafá, nleb, омби_, нсую, 
   {{0x6d58035a,0xa44401f4,0x00000000,0x00000000}},	// [a480] _mfwa, днад, --, --, 
   {{0x6e2886e7,0xa2e401b9,0x6d58035a,0xd8840014}},	//   hleb, мозд, _lfwa, _کھێن_, 
   {{0x6d583ff0,0x6e2886e8,0xe7386e1f,0x00000000}},	//   _ofwa, kleb, _фен_, --, 
   {{0x6d5803ac,0x6e2801bf,0x00000000,0x00000000}},	//   _nfwa, jleb, --, --, 
   {{0x6e2886e9,0x3c3000e4,0x00000000,0x00000000}},	//   dleb, hàva_, --, --, 
   {{0x2d800374,0x9f5c0200,0x6e2886ea,0x3c3000e4}},	//   _ēhea_, _imtë_, eleb, kàva_, 
   {{0x6d5803ac,0x799c017a,0x00000000,0x00000000}},	//   _bfwa, yfsw, --, --, 
   {{0x7ddc2b76,0x6d58035a,0x60d40158,0x0fc000ee}},	//   _césp, _cfwa, øyms, ейән, 
   {{0x6d5803ac,0x8e1002e8,0xa3d00b98,0x00000000}},	//   _dfwa, ъдъц, वाप_, --, 
   {{0x6e2804ba,0x6d5803ac,0x5ba4020f,0x8bc00138}},	//   aleb, _efwa, фриз, всюд, 
   {{0x6e2886eb,0x7c280109,0x6d5803ac,0xfb840101}},	//   bleb, rldr, _ffwa, ودگی, 
   {{0x6e280334,0x799c86ec,0x6d5803ac,0x00000000}},	//   cleb, ufsw, _gfwa, --, 
   {{0x200c86ed,0x09e40006,0x00000000,0x00000000}},	//   onfi_, тоўн, --, --, 
   {{0x78bc86ee,0xdad00014,0x200c0100,0xdb0803b9}},	//   rvsv, _لٕتھ, nnfi_, _nafç, 
   {{0xa3d002fe,0xa3c00210,0x00000000,0x00000000}},	//   वान_, _ऍफ़_, --, --, 
   {{0x4a040124,0x4b8401e0,0x6d5803ac,0x00000000}},	//   _аџьа, _ейән_, _xfwa, --, 
   {{0x25a02a1f,0xdb08007f,0x4bc0004e,0x947400f2}},	// [a490] _dbkl_, _enfô, _чөөг, بدزا, 
   {{0x39580998,0x92e82002,0x00000000,0x00000000}},	//   lcss_, يراق_, --, --, 
   {{0x290c013f,0x972001ed,0x59e00073,0x00000000}},	//   _ɛfam_, _شہرو, _पवार, --, 
   {{0x823427a1,0x6e28002f,0x00000000,0x00000000}},	//   پرما, xleb, --, --, 
   {{0x6e280267,0x7ddc00d5,0x3c3005da,0x2d1c0073}},	//   vleb, _résp, zàva_, _पडेल_, 
   {{0x6d58035a,0xbf640014,0xb6380150,0x2eb404c2}},	//   _sfwa, پدوو, _ﺘﻜ_, есис, 
   {{0xfc4801dc,0x6e2886ef,0x7ddc020c,0x6d5802d0}},	//   _gửi_, tleb, _pésp, _pfwa, 
   {{0x24840006,0xfc4c001f,0x6e2886f0,0x00000000}},	//   šome_, _አነጋግ, uleb, --, 
   {{0x6e2886f1,0x7ddc86f2,0x81c40131,0x30140953}},	//   rleb, _vésp, _جەنۇ, _здар, 
   {{0xa3d0041c,0x35d005f9,0xeb980640,0x6e286eb8}},	//   वाय_, हाड़, чио_, sleb, 
   {{0x0ccc000e,0x6e2886f3,0xfe7086f4,0x7e780175}},	//   িনেত, pleb, _ندن_, csvp, 
   {{0xc06802d3,0x6d5802d0,0x2ebc043e,0xce043346}},	//   _ዝተበገ, _ufwa, ्मीत, _غذاي, 
   {{0xf1b886f5,0xbb2800d1,0x3c3000e4,0x00000000}},	//   _maš_, ﻣﻨﻰ_, sàva_, --, 
   {{0xf1b800f3,0xfbd04fe0,0x6fac03d4,0x3c3000e4}},	//   _laš_, _پته_, চাকৈ, pàva_, 
   {{0xe5a486f6,0x48fc000d,0x00000000,0x00000000}},	//   ниви, _लइको_, --, --, 
   {{0xb92002e3,0xe618003b,0x00000000,0x00000000}},	//   ụrịt, їда_, --, --, 
   {{0xe364084c,0x200c0142,0xe50416cc,0x00000000}},	// [a4a0] екзи, ynfi_, ربري, --, 
   {{0xd918011a,0x4dd800cc,0x00000000,0x00000000}},	//   _מופל, _বগোৱ, --, --, 
   {{0xf1b804b9,0xa3d00c2e,0x68e40209,0xe728013e}},	//   _baš_, वाब_, lykd, _хонд_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf1b81a48,0x04440124,0x65740c89,0x00000000}},	//   _daš_, _аҵан, mayh, --, 
   {{0x657486f7,0x64540369,0x9878008f,0x90c00114}},	//   layh, mqyi, לאנט, убље, 
   {{0x443809f0,0x216886f8,0x3f9802d2,0x00000000}},	//   _ihr_, _ниви_, _örum_, --, 
   {{0x657486f9,0xe2a40008,0x24540158,0x443886fa}},	//   nayh, öðum_, _kæm_, _hhr_, 
   {{0x44380af2,0x64540369,0x77740175,0x4dd00725}},	//   _khr_, nqyi, yazx, اتىس, 
   {{0xf0000075,0xf1b801a6,0x3958009a,0x44380162}},	//   _күчи, _zaš_, wcss_, _jhr_, 
   {{0x1cb00156,0x443886fb,0x2ebc1fe7,0x0ba001ec}},	//   _ཞནམ_, _mhr_, ्मृत, ушым, 
   {{0xac740020,0xdde8034c,0xa3d01fca,0x65740108}},	//   _በሁሉም_, _عرضه_, वाड_, jayh, 
   {{0x291c2706,0xb78886fc,0x443886fd,0x24540413}},	//   ştan_, мәне_, _ohr_, _næm_, 
   {{0x443886fe,0xb90800dc,0x00000000,0x00000000}},	//   _nhr_, _यथ_, --, --, 
   {{0xb5c80133,0x8aa00153,0x00000000,0x00000000}},	//   ووسم_, _брыд, --, --, 
   {{0xd2d80490,0x2adc00bc,0x48fc01f9,0x00000000}},	//   _मॅगझ, खहरु_, _लेको_, --, 
   {{0x443800cd,0x0b4001af,0x39140395,0xa3d001f9}},	// [a4b0] _bhr_, _инән, _шмир, वाढ_, 
   {{0x4394678d,0x24540fac,0xd7640046,0x67e000d0}},	//   лаус, _dæm_, _سەرى_, _dôjs, 
   {{0x443886ff,0x9f4c0093,0x8c180375,0x91bc033f}},	//   _dhr_, hifó_, לומי, _एफआई, 
   {{0x45d435dd,0x44388700,0x499c010f,0x6d5c0205}},	//   _боюс, _ehr_, ִשוב, ısak, 
   {{0xed5805ce,0x7c3800af,0x4438107d,0x63ac03cd}},	//   ndže_, _ohvr, _fhr_, ønnå, 
   {{0x44380055,0x97380092,0xa3d008f2,0x00000000}},	//   _ghr_, _በስድስ, वाण_, --, 
   {{0xf1b80e04,0x2ebc00dc,0x00000000,0x00000000}},	//   _taš_, ्मेत, --, --, 
   {{0xf1c86788,0xf0e80aaf,0x4ea401ec,0xfaf800ef}},	//   _تورى_, _قىزى_, _үржа, dzī_, 
   {{0xdcac1c02,0x0ccc0154,0x8b04013a,0x00000000}},	//   قىي_, িন্ত, _okří, --, 
   {{0x7c3801a6,0x44380175,0x68e40024,0x00000000}},	//   _chvr, _xhr_, vykd, --, 
   {{0xa3d005ba,0x0dc8147e,0x9e946bcc,0x657400e4}},	//   वात_, _нуди_, _لانچ, yayh, 
   {{0xa6e00174,0x00000000,0x00000000,0x00000000}},	//   _øðil, --, --, --, 
   {{0xeb980323,0x9f4c04cc,0x48fc012d,0x657401f4}},	//   _жил_, mifò_, _लेखो_, vayh, 
   {{0xfc48004d,0x657402d0,0x60d401f4,0x00000000}},	//   _bửu_, wayh, äymi, --, 
   {{0xa5948701,0x68e40212,0xfc4801fb,0x2a3400c7}},	//   кращ, sykd, _cửu_, _иэир, 
   {{0x64a48702,0x47f44530,0xa8c4014b,0x68e45d1d}},	//   каба, түүр, _айид, pykd, 
   {{0xe3b88703,0x443801c3,0x65740588,0xd6240108}},	// [a4c0] мба_, _phr_, rayh, тоте_, 
   {{0x7a1801e4,0xa6e400db,0x00000000,0x00000000}},	//   rĉte, _ажол, --, --, 
   {{0x2ebc3711,0x00000000,0x00000000,0x00000000}},	//   ्मोत, --, --, --, 
   {{0x5ea804c5,0x65740113,0x8b04013a,0x00000000}},	//   কিমে, qayh, _zkří, --, 
   {{0xa3d00c4c,0x753401c0,0x4438045a,0x20b800c7}},	//   वाद_, _бэрх, _thr_, ьыжь_, 
   {{0x443809f0,0x23781de7,0xe11002e3,0x442c0332}},	//   _uhr_, _زمرد_, wụsị, _ód_, 
   {{0xe630001f,0x00000000,0x00000000,0x00000000}},	//   _በእናን, --, --, --, 
   {{0x53180375,0x6e3803cb,0x91e00902,0x5cc40107}},	//   _חולצ, _chwb, _косе, всоз, 
   {{0xe0440124,0xaca801d3,0x00000000,0x00000000}},	//   _анаи, ٹھنے_, --, --, 
   {{0x629c0100,0x8fa0233a,0xdb1800e5,0x5ea800eb}},	//   otpo, _вафе, ldté, কিবে, 
   {{0xd00c1f84,0x7ec820ef,0x60c08704,0x291c054e}},	//   _ظلم_, _dépô, lvom, ştal_, 
   {{0x8b04012c,0x629c0549,0x4ef8008f,0xc9d401d3}},	//   _skří, itpo, _קלאג, لمپک, 
   {{0xcdf40375,0xfc48004d,0x38c80214,0x629c000d}},	//   _במאי_, _sửu_, راحی_, htpo, 
   {{0x629c03cd,0x8bc00395,0x00000000,0x00000000}},	//   ktpo, _всъд, --, --, 
   {{0xd5b88705,0x00000000,0x00000000,0x00000000}},	//   мса_, --, --, --, 
   {{0xfde0015b,0x60c08706,0x629c0112,0x00000000}},	//   _বগুড, kvom, dtpo, --, 
   {{0x7ae80fac,0xdb0800d0,0x629c0051,0x850400f1}},	// [a4d0] lydt, _nafú, etpo, ټولن, 
   {{0x21645026,0x629c6144,0x36d400f7,0x60c009a8}},	//   қиши_, ftpo, _боор, dvom, 
   {{0xdd841d1f,0x629c01bf,0x9f4c0332,0x00000000}},	//   _ٿو_, gtpo, ghfí_, --, 
   {{0xf7548707,0x24840024,0xcb100a7c,0x4ac000cd}},	//   _جنگج, šoma_, בלע_, षितव, 
   {{0xdb08006a,0x66188708,0x41748709,0x6e380042}},	//   _pafû, étke, شانس, _rhwb, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xed58870a,0x3a28870b,0xada4870c,0x9f5c01ed}},	//   ной_, _okap_, гайл, _ajtó_, 
   {{0x60c002ce,0x518401c0,0xf3f40183,0x00000000}},	//   bvom, _шуга, _আদিৰ_, --, 
   {{0xec48870d,0x3034022e,0x00000000,0x00000000}},	//   нзил_, _беаё, --, --, 
   {{0x3a28870e,0x9f4c007f,0xc10400d1,0x00000000}},	//   _akap_, sifò_, _ئوكي, --, 
   {{0xaa44870f,0xdb0800d7,0x8bd00171,0x00000000}},	//   леол, _zafú, _ķēdī, --, 
   {{0x3a2805b1,0xe8f80c17,0x00000000,0x00000000}},	//   _ckap_, елм_, --, --, 
   {{0xddc00210,0xe58800d1,0x00000000,0x00000000}},	//   _fioł, _ﺑﯚﻟﯜ, --, --, 
   {{0xeb98008e,0xdb1801d3,0x00000000,0x00000000}},	//   _чик_, zdté, --, --, 
   {{0xd7544739,0xfb244336,0x60c00433,0x9b9000cf}},	//   الفت_, _پروپ, zvom, _الىت, 
   {{0xddc00034,0x00000000,0x00000000,0x00000000}},	//   _zioł, --, --, --, 
   {{0x20cc022c,0x7d04032e,0xc89401ee,0x00000000}},	// [a4e0] iðið_, _þist, _туйө, --, 
   {{0x629c1f53,0x37740139,0x154000d8,0x00000000}},	//   ttpo, _кыюс, сеум, --, 
   {{0x236404ac,0x66e48710,0x179800c8,0x6304004b}},	//   ĝoj_, _сона, _אייב, دوال, 
   {{0xa3d012eb,0x236400c8,0xd24c22eb,0xa1b8007b}},	//   वाह_, ŝoj_, سنه_, عطاء_, 
   {{0xf1d40184,0x9ac00327,0xa11400f7,0x7170075e}},	//   шөрө, ċċik, دوشت, زۇلا, 
   {{0xc44839b1,0x25b08711,0x629c002f,0xe29800f3}},	//   _شیان_, leyl_, ptpo, _паг_, 
   {{0x644c8712,0x60c0006f,0x00000000,0x00000000}},	//   _iibi, svom, --, --, 
   {{0xc0c4767b,0x644c8713,0xa3d03a37,0x25b00204}},	//   _вәки, _hibi, वाव_, neyl_, 
   {{0x7ddc00f8,0xc2800220,0x7ae80ea0,0x59c000dc}},	//   _kész, _ءﺗﯘﻳ, wydt, षयसर, 
   {{0x644c8714,0x3a282147,0xddc48715,0x25b00205}},	//   _jibi, _skap_, _әбди, heyl_, 
   {{0x9e640b74,0x7ddc01d3,0x6830365a,0x00000000}},	//   _свед, _mész, rædl, --, 
   {{0x644c8716,0x62f40154,0x00000000,0x00000000}},	//   _libi, _আশায়_, --, --, 
   {{0x6aa8013f,0x644c8717,0x00000000,0x00000000}},	//   _ɛmfɑ, _oibi, --, --, 
   {{0x644c8718,0x59c0012c,0xc7b80108,0x00000000}},	//   _nibi, षयहर, лёс_, --, 
   {{0xd90c760d,0x9a8401c6,0xec180bd6,0xe7f4012d}},	//   تیک_, _сулл, _шешә_, ीफ़ा_, 
   {{0x644c8719,0x35b40120,0x00000000,0x00000000}},	//   _aibi, јбар, --, --, 
   {{0x7b040024,0x3494871a,0x1da401bc,0x938800d8}},	// [a4f0] žutė, разр, क्यत, есеа_, 
   {{0x644c871b,0x78ac871c,0x37c400d1,0xdedc0023}},	//   _cibi, _ipav, _тәмб, ሓኒና_, 
   {{0x644c871d,0x25b00009,0xf1940022,0x20cc0162}},	//   _dibi, beyl_, иижь, yðið_, 
   {{0x88b0016b,0x644c0086,0x25b001d9,0x34946777}},	//   _ayɛy, _eibi, ceyl_, _камр, 
   {{0xed5805be,0xa3d02e37,0x7ddc01d3,0xc3300050}},	//   jdža_, वाश_, _fész, قٕے_, 
   {{0x644c871e,0x78ac0223,0x0878008f,0xb4d017ee}},	//   _gibi, _mpav, רעגט_, वमी_, 
   {{0x78ac0055,0xd1640395,0x40840454,0x00000000}},	//   _lpav, _бъзи, _қутб, --, 
   {{0x644c871f,0x78ac8720,0x2d988721,0xfec803e6}},	//   _zibi, _opav, üse_, ابوو_, 
   {{0x20cc1f60,0x82348722,0x7f480075,0x644c8723}},	//   rðið_, _طرفا, نلۇق_, _yibi, 
   {{0x22a80069,0x644c378b,0x00000000,0x00000000}},	//   aʝku_, _xibi, --, --, 
   {{0x78ac8724,0xa9680408,0x8fd004a9,0xd59800b5}},	//   _apav, кина_, _вәқә, _chに_, 
   {{0xbe20063f,0x59806be2,0xdb200236,0x26dc0419}},	//   ịdrọ, олюб, توپی, ätom_, 
   {{0xdbdc022c,0x8c644130,0x00000000,0x00000000}},	//   _tíðl, _стед, --, --, 
   {{0x18648725,0x20540375,0xc5b40137,0x8b000118}},	//   рари_, יישל_, өрбө, ířsk, 
   {{0x7ddc00f8,0x78ac0356,0xec7000ec,0x00000000}},	//   _rész, _epav, _اٿڻ_, --, 
   {{0xf65400f5,0x63640419,0x00000000,0x00000000}},	//   стрю, _očné, --, --, 
   {{0xa3d002ab,0x644c500a,0xa5080063,0xe4040153}},	// [a500] वाल_, _pibi, њеза_, азап, 
   {{0x24840f8b,0x644c8726,0x187800c8,0x4cd80154}},	//   šomo_, _qibi, _שטיב, মৈথু, 
   {{0xe2988727,0x644c8728,0xc3304da8,0x7ddc01d3}},	//   тае_, _vibi, سەر_, _vész, 
   {{0x644c8729,0xa06828c1,0x78ac00e4,0xd874072d}},	//   _wibi, вада_, _ypav, _حمیت_, 
   {{0xe044872a,0xd12c872b,0x7ddc01ed,0x31680077}},	//   анди, ومم_, _tész, ñaza_, 
   {{0x7a3c872c,0xa3b80316,0x62642309,0x00000000}},	//   méte, _अघि_, _نارق, --, 
   {{0x4444872d,0x7a3c872e,0x8a04022e,0xb354872f}},	//   mm_, léte, _e稚ib, _ایما_, 
   {{0x661432cb,0x9da800a7,0xdb1001e1,0xed4c00ec}},	//   nnyk, тъка_, _àgéy, ڙھو_, 
   {{0xd12c121e,0x44448730,0x1fb4769a,0xa3b802c3}},	//   _ہمہ_, om_, _всер, _अघा_, 
   {{0x44445281,0x8c4006ed,0xed588731,0x2bcc000d}},	//   nm_, оење, rdža_, ़ागा, 
   {{0x44448732,0x00000000,0x00000000,0x00000000}},	//   im_, --, --, --, 
   {{0x44448733,0xa3d0007d,0x7a3c00d2,0x7d08005f}},	//   hm_, वाँ_, kéte, tīrī, 
   {{0x9d4401f4,0x00000000,0x00000000,0x00000000}},	//   _тедд, --, --, --, 
   {{0x44448734,0x8c4000a8,0x7a3c74fd,0x7d0800b0}},	//   jm_, _дече, déte, rīrī, 
   {{0x7c288735,0x44448736,0xe5840137,0xdb0808a5}},	//   modr, dm_, өттү, _hafþ, 
   {{0x7c2819a2,0xb998026a,0x596400a7,0xe28c022e}},	//   lodr, _свих_, _тъка, drа_, 
   {{0x44448737,0xa3d08738,0x2d800134,0xd3788739}},	// [a510] fm_, वां_, _ɛhe_, вче_, 
   {{0x7c28873a,0x1da406ff,0x9268036b,0x49f40327}},	//   nodr, क्तत, врда_, _བཞོལ_, 
   {{0x7a1800df,0x00000000,0x00000000,0x00000000}},	//   nĉto, --, --, --, 
   {{0x4444873b,0x7c280109,0x5184873c,0x94a801a9}},	//   am_, hodr, ружа, _итга_, 
   {{0x7c28044e,0x7a3c2b76,0x444400ad,0x00000000}},	//   kodr, céte, bm_, --, 
   {{0xa3d00882,0x2898008f,0xb17c00d7,0x60b000db}},	//   वाः_, ריװא, _doťa, سمىئ, 
   {{0x660c00d2,0x7c2839e4,0x8eb00c75,0x00000000}},	//   _ínkû, dodr, تەات, --, 
   {{0xd084034b,0x7f1415bf,0x00000000,0x00000000}},	//   _выжи, تكىچ, --, --, 
   {{0x7c28873d,0x649c03e0,0xbae40154,0x2bb800ae}},	//   fodr, _içiç, _ফেলছ, هادة_, 
   {{0x7c280481,0x317c0007,0x26dc00d0,0xa1f000db}},	//   godr, lawz_, ätok_, _وۋەت, 
   {{0x6d5c030a,0x5f4000db,0xbef4007b,0x00000000}},	//   ñsas, _ىچىل, _وأمت, --, 
   {{0x4444873e,0x683001bf,0x00000000,0x00000000}},	//   zm_, pædk, --, --, 
   {{0x4444873f,0x6e280077,0xed5805be,0x68448740}},	//   ym_, moeb, ldžo_, йнма, 
   {{0x7a3c00dd,0xfd100014,0x7c282e27,0x66e40abe}},	//   véte, _تجم_, codr, бога, 
   {{0x44448741,0xaa9400c6,0xed580301,0xaa441de6}},	//   vm_, _العث, ndžo_, _лекл, 
   {{0x44440e37,0x7a3c01ed,0xe28c022e,0x00000000}},	//   wm_, téte, vrа_, --, 
   {{0x63840323,0x44448742,0x317c0007,0x66148743}},	// [a520] йгаа, tm_, dawz_, rnyk, 
   {{0x44448744,0x6e2800fb,0x64a44701,0x7a3c8745}},	//   um_, hoeb, _һама, réte, 
   {{0x96600276,0x6e280083,0x216800c7,0x7a3c00e5}},	//   _нкэе, koeb, гиеи_, séte, 
   {{0x2d9c00d2,0x64a48746,0x7a3c7ca0,0xb17c0030}},	//   _ncwe_, _лама, péte, _poťa, 
   {{0x6e28017a,0xd6cc0154,0x7c284b5e,0x222400f1}},	//   doeb, রহণয, yodr, لګړي_, 
   {{0x23288747,0x44440194,0xa06800fb,0x00000000}},	//   _боги_, qm_, _ҡаба_, --, 
   {{0x7c280109,0x9e048748,0x00000000,0x00000000}},	//   vodr, йчил, --, --, 
   {{0x5ea82baf,0x7c2800a9,0x3d9407d8,0x6e28017a}},	//   কিলে, wodr, циир, goeb, 
   {{0x7c282f4a,0x22448749,0x9bc4034b,0xcc840691}},	//   todr, mmok_, бёнк, منيه_, 
   {{0xe8080014,0x2cbc0ecf,0xace8010a,0x00000000}},	//   होमा_, _dswd_, ăмпа_, --, 
   {{0x6e2806d9,0xfe7801f0,0x00000000,0x00000000}},	//   boeb, _тӯл_, --, --, 
   {{0x200c874a,0x224405b1,0x7c28874b,0x6dc401b9}},	//   lifi_, nmok_, sodr, _وزنل, 
   {{0x7a3c01d3,0x00000000,0x00000000,0x00000000}},	//   tétb, --, --, --, 
   {{0xd59800b5,0x200c874c,0xd7f800db,0x8cb40b67}},	//   _chの_, nifi_, уум_, ्टरो, 
   {{0xb4d00a28,0x4b7825f9,0xa3d012eb,0x2244874d}},	//   वम्_, _גאוו, वाई_, kmok_, 
   {{0xdb08006a,0x200c874e,0x924c01f3,0x00000000}},	//   _mafü, hifi_, ንቅስቃ, --, 
   {{0x22440548,0x200c0109,0x0a1401d9,0x645800b0}},	// [a530] dmok_, kifi_, _روٝح, _ōtir, 
   {{0x200c0e14,0xb994072d,0x00000000,0x00000000}},	//   jifi_, _الکب, --, --, 
   {{0x316809c2,0x200c010f,0x6e2877f6,0x05c41223}},	//   ñazo_, difi_, yoeb, _लोकब, 
   {{0x22444cd3,0x34941ee3,0x38680327,0x00000000}},	//   gmok_, _қаҳр, _ktar_, --, 
   {{0x200c874f,0xd59804ce,0xf8c839a1,0x518407a5}},	//   fifi_, _yhの_, िटिय, _қува, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6e288750,0x51840364,0x62980793,0xf1b801a6}},	//   toeb, _гуза, _ätop, _ajše_, 
   {{0xfe6c0323,0xdb080639,0xee3807fa,0x68308751}},	//   _үү_, _dafü, јни_, rædi, 
   {{0x38688752,0x200c00fb,0x6e288753,0x301400d8}},	//   _ntar_, bifi_, roeb, _ддар, 
   {{0x2d8006c8,0x6e28017a,0xa3d02e05,0x683012e8}},	//   _ēheu_, soeb, वाए_, pædi, 
   {{0xaa44010b,0x9cac01ec,0x00000000,0x00000000}},	//   женл, _ﺳﻴﻼﻋ, --, --, 
   {{0x4c8000d1,0x6c7407d5,0xf76808c3,0x00000000}},	//   _еғиз, _дукх, _יק_, --, 
   {{0x91bc01fb,0xac18117e,0x984c0213,0xad242374}},	//   _chủ_, _коду_, _ağıl_, _بىشى, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x38688754,0x65c40801,0xa9a43298,0x9cb40327}},	//   _etar_, обва, _дийд, _དགོས, 
   {{0x200c1ec9,0xe5686bd7,0x66e4059f,0x25680022}},	//   zifi_, риад_, боҳа, раап_, 
   {{0x69d48755,0x24080107,0x200c02e2,0x00000000}},	// [a540] _inye, анаи_, yifi_, --, 
   {{0x69c48756,0x7a3c8757,0xdd0000dc,0x00000000}},	//   ldke, méta, _śrīb, --, 
   {{0x7a3c8758,0x29000010,0x69c40009,0x00000000}},	//   léta, lzka_, odke, --, 
   {{0x6b8c0198,0xdb088759,0x69c4875a,0xdb1801d3}},	//   _ɓaga, _rafü, ndke, ndtá, 
   {{0x65640270,0x7a3c07ea,0x69d4875b,0x602412d7}},	//   _ifkh, néta, _mnye, одда, 
   {{0x2244005a,0xa1840022,0xcfd00114,0x00000000}},	//   smok_, сыҧл, дошћ, --, 
   {{0x69d4875c,0x200c875d,0x7a3c020c,0xdb08875e}},	//   _onye, rifi_, héta, _lafò, 
   {{0x7a3c875f,0xa3d00d2c,0x69d48760,0x00000000}},	//   kéta, वाक_, _nnye, --, 
   {{0x1da4194b,0x5fb41867,0x61e08761,0x3cf4012d}},	//   क्षत, _ومرط, mjol, इनें_, 
   {{0x69d48762,0x29008763,0x7a3c003e,0x3868022e}},	//   _anye, dzka_, déta, _rtar_, 
   {{0x38688764,0x61e00789,0xe7dc078a,0x7d0000d7}},	//   _star_, ojol, मानप, szms, 
   {{0x7a3c00e8,0x91bc0208,0x00000000,0x00000000}},	//   féta, _phủ_, --, --, 
   {{0x7a3c20ef,0x3868025c,0x00000000,0x00000000}},	//   géta, _qtar_, --, --, 
   {{0x69d405db,0x61e08765,0x3868003a,0x3f9c8766}},	//   _enye, hjol, _vtar_, ngvu_, 
   {{0x61e00e38,0xdb20036b,0xca700131,0x29008767}},	//   kjol, _توغی, _قايغ, azka_, 
   {{0x69d4007f,0x91bc01fb,0x7a3c8768,0x61e08769}},	//   _gnye, _thủ_, béta, jjol, 
   {{0x2900068f,0x6aac01fa,0x3868876a,0x61e0016d}},	// [a550] czka_, _ćafi, _utar_, djol, 
   {{0xa3d02144,0x799c002f,0xc9540115,0x00000000}},	//   वाग_, lgsw, _קמץ_, --, 
   {{0x61e00158,0x67b80375,0xb6340066,0x00000000}},	//   fjol, _המתק, _فکرش, --, 
   {{0x799c876b,0x2490876c,0xc8c84bf3,0x00000000}},	//   ngsw, brym_, _اوین_, --, 
   {{0x2ab0025a,0x3cf4033f,0x00000000,0x00000000}},	//   _kôbö_, इनों_, --, --, 
   {{0x7204876d,0x683001bf,0x61e00108,0x5348030d}},	//   _کورم, sædv, ajol, _кăлă, 
   {{0xfd4c07ae,0x6e940597,0xdb18037e,0xeb9801e0}},	//   _triể, ألعا, ldtæ, ҙин_, 
   {{0x6ef008a5,0x61e0012d,0x6830005c,0x7058009d}},	//   _aðbú, cjol, lædt, _гаар_, 
   {{0x320c0113,0xdb18037e,0x09e402f5,0xd7c8041c}},	//   _imey_, ndtæ, মসমা, ायाच, 
   {{0x1c40876e,0x69d40af9,0xeafc037e,0x799c002f}},	//   нным, _snye, t船_, egsw, 
   {{0xab283afa,0x7a3c065c,0x00000000,0x00000000}},	//   сона_, wéta, --, --, 
   {{0x24841ebd,0xfe7004fb,0xdb08007f,0x1ee800f2}},	//   šomi_, _شدم_, _pafò, _دومی_, 
   {{0x2fc4089c,0xbcc00184,0x69c4017a,0xfcc00032}},	//   _kalg_, _аҡыл, rdke, _аҙым, 
   {{0x66e4876f,0x6d58035a,0x2fc40037,0x61e0012d}},	//   пога, _hgwa, _jalg_, zjol, 
   {{0x6d588770,0x29008771,0x6b808772,0x5b780375}},	//   _kgwa, szka_, malg, _הרצא, 
   {{0x6b802e12,0x7a3c4dff,0x69d48773,0x63ac05b1}},	//   lalg, péta, _unye, _sbbn, 
   {{0xdb0800fc,0xd5ac0597,0x27f80263,0x6d588774}},	// [a560] _hafð, طفل_, _tlpn_, _mgwa, 
   {{0x24900731,0x6b808775,0x17c400c7,0x2fc4022e}},	//   rrym_, nalg, _егьи_, _nalg_, 
   {{0x61e001af,0x6d582252,0xdbd403b2,0x782401f7}},	//   tjol, _ogwa, _møðs, _تعيل, 
   {{0x6d588776,0x61e04a31,0x3208187f,0x26dc00d7}},	//   _ngwa, ujol, охін_, ätou_, 
   {{0x6b808777,0x61e08778,0x25a002e2,0x2fc41175}},	//   kalg, rjol, _ickl_, _balg_, 
   {{0x6d588779,0x4ad85cea,0x2fc400a3,0x6b8000c5}},	//   _agwa, यमाव, _calg_, jalg, 
   {{0x6b80877a,0x2fc4022e,0x799c017a,0x00000000}},	//   dalg, _dalg_, ygsw, --, 
   {{0x6d5803ac,0xa0a4014b,0x00000000,0x00000000}},	//   _cgwa, _набд, --, --, 
   {{0x6d5803ac,0xa3c00950,0x00000000,0x00000000}},	//   _dgwa, ्यप_, --, --, 
   {{0x6d58877b,0xa3d04728,0x6b80877c,0x2fc40af9}},	//   _egwa, वाट_, galg, _galg_, 
   {{0x3f8c877d,0x6d5802d0,0xde7400db,0x79941606}},	//   _iddu_, _fgwa, _رداع, минф, 
   {{0x6d582252,0x7ce400b0,0x5ce400db,0x00000000}},	//   _ggwa, _pōrā, _ىكال, --, 
   {{0x6b80877e,0xdbd406ea,0x78bc01f5,0x00000000}},	//   balg, _føðs, uwsv, --, 
   {{0x6b800857,0x7a3c003e,0x1dd800dc,0xec3400db}},	//   calg, cétn, भावत, _قونگ, 
   {{0xa3c02d8f,0x7bd8877f,0x9b3401c0,0x00000000}},	//   ्यन_, _invu, _хүнс_, --, 
   {{0x07088780,0xd1c00023,0x5958074d,0x00000000}},	//   سيقي_, ኻታት_, _ушкă, --, 
   {{0x1cb81efe,0x3f8c0e14,0x798c8781,0xc8c409bb}},	// [a570] _ཆགས_, _oddu_, _idaw, _लैपट, 
   {{0xe94401d9,0x7bc80e20,0x99580724,0x36d400db}},	//   _تر٘ی, nddu, _yäşi_, _жоор, 
   {{0x7a3c00d7,0x00000000,0x00000000,0x00000000}},	//   néto, --, --, --, 
   {{0x2fc43570,0x3f8c8782,0x798c025c,0x6b80022e}},	//   _salg_, _addu_, _jdaw, zalg, 
   {{0xf4844bf3,0xd0a80364,0xdb18049f,0x798c0135}},	//   _تاجی, стед_, ldtä, _mdaw, 
   {{0x7a3c020c,0x6d5803cb,0x6b80343b,0x00000000}},	//   kéto, _sgwa, xalg, --, 
   {{0x6b808783,0x2fc48784,0xae440372,0x798c8785}},	//   valg, _valg_, وپتو, _odaw, 
   {{0x3f8c2b1d,0x7bd88786,0x2fc40549,0x63000131}},	//   _eddu_, _anvu, _walg_, _جۈمل, 
   {{0xa3d00b9c,0xed588787,0xf10400cf,0x6d5803ac}},	//   वाच_, ndži_, _تۉشۉ_, _vgwa, 
   {{0x798c8788,0xa3c00825,0x4f640cd2,0xac0800d4}},	//   _adaw, ्यय_, _رائف, інна_, 
   {{0x6b808789,0x7a3c0232,0x6d58035a,0x00000000}},	//   ralg, rétn, _tgwa, --, 
   {{0x7bd8878a,0x7bc8878b,0x6d58878c,0xac7400db}},	//   _envu, addu, _ugwa, _قاتش, 
   {{0xa3c0878d,0x6b8000c5,0x1dd8878e,0x798c878f}},	//   ्यम_, palg, भारत, _ddaw, 
   {{0xfd104fb6,0x798c03ac,0x1bc801d9,0x7a3c8790}},	//   _حجم_, _edaw, _وُنی_, létl, 
   {{0x798c031c,0x1fa800fe,0x7a3c0129,0xe5a400d1}},	//   _fdaw, _গোঁস, céto, миви, 
   {{0x7dd401a9,0x00000000,0x00000000,0x00000000}},	//   nоsа, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [a580] --, --, --, --, 
   {{0x798c012d,0x154001ec,0x00000000,0x00000000}},	//   _zdaw, теум, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe808772c,0xa3d00118,0x00000000,0x00000000}},	//   होरा_, वाङ_, --, --, 
   {{0x7bc88791,0x55b8011a,0x65740588,0xb9ac010f}},	//   yddu, _ומכו, mbyh, מבאָ, 
   {{0x9e641063,0x00000000,0x00000000,0x00000000}},	//   وابن, --, --, --, 
   {{0x53a022e6,0xdb0802d2,0x91e40150,0xffa400db}},	//   _шарб, _hafö, _ﺍﻗﯩﻼ, _үлбү, 
   {{0x386c054e,0xdde80fb4,0xdb1801bf,0x00000000}},	//   ţeri_, ترته_, ndtå, --, 
   {{0xdb0829ef,0xbd181bbc,0x00000000,0x00000000}},	//   _jafö, яжих_, --, --, 
   {{0xdb080793,0x3f8c3fb4,0x00000000,0x00000000}},	//   _mafö, _uddu_, --, --, 
   {{0x7bc88792,0xdb180240,0xddc4234c,0x5d6800d8}},	//   rddu, metë, _обжи, _дием_, 
   {{0xdb180240,0x7a3c8793,0xe6c806be,0x00000000}},	//   letë, réto, _şişə, --, 
   {{0xd90c2163,0x386c1a7c,0x16d421b8,0x6fa40154}},	//   شید_, ëer_, डम्ब, _গোয়ে, 
   {{0xdb180240,0xe808302b,0x37f80139,0x00000000}},	//   netë, होला_, чегэ_, --, 
   {{0xdb1800d2,0x321c0142,0x00000000,0x00000000}},	//   zetê, ynwy_, --, --, 
   {{0x798c8794,0x4d7800c8,0xdb080e78,0x6574017a}},	//   _udaw, ַרבע, _bafö, gbyh, 
   {{0xd3a400a8,0xb95402bf,0xdb180240,0xd8440212}},	// [a590] дреп, _явищ, ketë, _охоп, 
   {{0xdb1802d3,0x481405f5,0x439400a8,0xed5882c7}},	//   jetë, _амьс, каус, rdži_, 
   {{0x6fdc05ba,0xddd800b0,0xdb1802d3,0xed581aff}},	//   पासू, _autō, detë, leže_, 
   {{0xdbd801e1,0x00000000,0x00000000,0x00000000}},	//   _lààb, --, --, --, 
   {{0x764c8460,0xdb180240,0x2b140037,0xee3800c7}},	//   mmay, fetë, _फेनु_, ҟни_, 
   {{0x764c129f,0xdb4405d4,0xdb180200,0x00000000}},	//   lmay, _مَ_, getë, --, 
   {{0x82a40e26,0xd1b800b2,0x764c0067,0x02a4030d}},	//   _иште, _وارا_, omay, _иртм, 
   {{0x764c8795,0xada43c5e,0xec7843d7,0x3134274b}},	//   nmay, хаил, ппи_, _зебр, 
   {{0xed581711,0xdb181762,0x00000000,0x00000000}},	//   ježe_, letè, --, --, 
   {{0x3ec40664,0x764c8796,0xed580219,0x7a3c01d3}},	//   ästä_, hmay, deže_, sétl, 
   {{0xa9a44c13,0xa3c00b9c,0x764c8797,0xdbd801e1}},	//   ىمدى, ्यत_, kmay, _dààb, 
   {{0x764c6eb0,0x00000000,0x00000000,0x00000000}},	//   jmay, --, --, --, 
   {{0x39348798,0xdb180066,0x764c0363,0xbd88009f}},	//   вэрс, hetè, dmay, _آنهن_, 
   {{0x291c0276,0x764c0098,0xdca02bbd,0x5fe00829}},	//   ăta_, emay, _саши, पायल, 
   {{0x1da41fe5,0x244406af,0x00000000,0x00000000}},	//   क्कत, nôme_, --, --, 
   {{0xdb188799,0x764c879a,0x21fc00c7,0xa3b0012c}},	//   zetë, gmay, _oïha_, झ्न_, 
   {{0xa444879b,0xd8dc0156,0x6574879c,0xeac8879d}},	// [a5a0] енад, ོདཞི, rbyh, _hẹ_, 
   {{0x764c01d9,0x657400d7,0x00000000,0x00000000}},	//   amay, sbyh, --, --, 
   {{0xeac80570,0x1bf4008f,0xdb180240,0x764c0067}},	//   _jẹ_, עצער_, vetë, bmay, 
   {{0xeac807ae,0x2444002d,0x764c0009,0x00000000}},	//   _mẹ_, dôme_, cmay, --, 
   {{0xdb18044e,0x66140309,0xeac8879e,0xd6d401d5}},	//   tetë, miyk, _lẹ_, _قویش_, 
   {{0x6614879f,0xd12c87a0,0x33d401ec,0x16840345}},	//   liyk, حمه_, _иіст, _تایێ, 
   {{0xdb1802d3,0xdb200158,0xd434011a,0x94200a5b}},	//   retë, _årøe, _נטלי_, _смре, 
   {{0x63bc87a1,0x629c87a2,0x66140309,0x7cd800fb}},	//   lepn, mupo, niyk, дмир_, 
   {{0xdb181a74,0x00000000,0x00000000,0x00000000}},	//   meté, --, --, --, 
   {{0x764c87a3,0xeac80ca8,0xdb1887a4,0x60c000ec}},	//   zmay, _bẹ_, leté, mwom, 
   {{0xed58310a,0x661403f0,0xdeb00220,0x60c004ba}},	//   veže_, kiyk, _сұйы, lwom, 
   {{0xdb1800dd,0x764c03be,0xeac801e1,0x63bc01f5}},	//   neté, xmay, _dẹ_, hepn, 
   {{0xa3c038db,0x60c00354,0x629c87a5,0xed5807f5}},	//   ्या_, nwom, hupo, teže_, 
   {{0xdb1887a6,0xeac8110e,0xdb080798,0x764c062c}},	//   heté, _fẹ_, _bafô, wmay, 
   {{0x764c87a7,0xa8541cd1,0xed580427,0x8d5000fd}},	//   tmay, терә, reže_, _итәч, 
   {{0x764c87a8,0xd90c87a9,0xed580219,0xdb1887aa}},	//   umay, _هیج_, seže_, jeté, 
   {{0xed580306,0x7afc0162,0xdc100139,0x00000000}},	// [a5b0] peže_, ørtf, lğıl, --, 
   {{0xdd8487ab,0x93244418,0x629c0421,0x63bc003e}},	//   _ھو_, ىران, fupo, gepn, 
   {{0x764c2fbe,0xdd8487ac,0x90e487ad,0x60c00083}},	//   pmay, _پو_, کسان, ewom, 
   {{0x764c87ae,0xdb1887af,0x41e40006,0x24440022}},	//   qmay, geté, ліча, vôme_, 
   {{0x60c00083,0xdb18067c,0x91bc004d,0x45d401d5}},	//   gwom, setè, _chú_, _сояс, 
   {{0x629c00f1,0x244406af,0x63bc0010,0x8f280092}},	//   bupo, tôme_, cepn, _ዴስክቶ, 
   {{0x629c87b0,0xdb1800e5,0x91bc0051,0xdb940150}},	//   cupo, beté, _thù_, _ﻛﯘﺯﻯ_, 
   {{0xeac80570,0xed582075,0x244406af,0xbb6800b5}},	//   _rẹ_, мой_, rôme_, _newス_, 
   {{0x7a3c00a0,0x7de408b0,0xeac80241,0xdba00023}},	//   méth, اسىم, _sẹ_, _ጉዳዮም_, 
   {{0xff1800b5,0x7a3c2d59,0xab6401b9,0xeac80248}},	//   _webの, léth, ъвол, _pẹ_, 
   {{0xcd28021a,0x661400ca,0x1c400276,0x00000000}},	//   _کسان_, yiyk, рнэм, --, 
   {{0x6600031c,0x63bc05d7,0xfeb801f7,0x00000000}},	//   _ċoko, zepn, _سامت_, --, 
   {{0x629c00b5,0x63bc834a,0xeac80241,0x00000000}},	//   zupo, yepn, _wẹ_, --, 
   {{0xdb18066d,0x909802d3,0xe8544028,0x66140784}},	//   zeté, _ወግዓዊ_, ئنسد, wiyk, 
   {{0x661487b1,0x2cac87b2,0xdb1887b3,0x60c001a4}},	//   tiyk, lted_, yeté, zwom, 
   {{0x2cac87b4,0x629c87b5,0x60c00210,0x00000000}},	//   oted_, vupo, ywom, --, 
   {{0x2cac87b6,0xe45887b7,0xdb18804d,0x66143d07}},	// [a5c0] nted_, джа_, veté, riyk, 
   {{0x629c87b8,0x661487b9,0x2cac87ba,0xc5b400db}},	//   tupo, siyk, ited_, _өрмө, 
   {{0x63bc0c6a,0x630400aa,0x2cac00af,0xdb18804d}},	//   repn, خوال, hted_, teté, 
   {{0x629c87bb,0x63bc7f01,0x95802401,0x661402d1}},	//   rupo, sepn, _клюе, qiyk, 
   {{0xdb1887bc,0x629c286b,0x2cac87bd,0xe0481547}},	//   reté, supo, jted_, وشته_, 
   {{0xdb1887be,0x60c00c21,0xd12c0131,0x91000063}},	//   seté, rwom, ڭمۇ_, рпље, 
   {{0x60c004ce,0xd50c0085,0x4438017a,0xdb18804d}},	//   swom, mɛ́l, _ikr_, peté, 
   {{0xa1100131,0x2cac0c18,0x60c0037e,0x91bc004d}},	//   _پۈتت, fted_, pwom, _thú_, 
   {{0x443860ab,0xdb1801bf,0x9c44030d,0xa3c4012d}},	//   _kkr_, ldtø, кхол, _ऎसा_, 
   {{0x443887bf,0x6ebc3347,0x3d1800c5,0x00000000}},	//   _jkr_, _वैकु, _बइठे_, --, 
   {{0x2cac87c0,0x443887c1,0xdb1887c2,0x4ae401f4}},	//   ated_, _mkr_, ndtø, вьям_, 
   {{0x2cac7db2,0x443887c3,0x00000000,0x00000000}},	//   bted_, _lkr_, --, --, 
   {{0x2cac87c4,0xd83805f5,0x443887c5,0xdcf887c6}},	//   cted_, дэв_, _okr_, _تراش_, 
   {{0x4438016b,0x628c03b2,0x383401c4,0x00000000}},	//   _nkr_, _ovbo, унгр, --, 
   {{0xb59487c7,0x7a3c07ea,0x25b06f66,0x956402e8}},	//   ливш, héti, ffyl_, възд, 
   {{0x4438036e,0x09e4009b,0x00000000,0x00000000}},	//   _akr_, _воћн, --, --, 
   {{0x73d887c8,0x443800c8,0x628c87c9,0x7a3c00d8}},	// [a5d0] ндар_, _bkr_, _avbo, jéti, 
   {{0xd50c0085,0x46ac05f9,0x84240075,0xed580010}},	//   gɛ́l, _चहचह, لىقن, neža_, 
   {{0x8934703a,0x1dd01a4e,0x316c01c4,0x4438365a}},	//   _معیا, थयात, _pfez_, _dkr_, 
   {{0x2cac87ca,0x7a3c3822,0x443826bb,0x00000000}},	//   yted_, féti, _ekr_, --, 
   {{0x7a3c87cb,0xf484732b,0xc1e401e0,0xc0a8007b}},	//   géti, _حاجی, шөрҙ, ناول_, 
   {{0x13a42172,0x765c5e03,0xed581710,0xf08402dd}},	//   _جنسی_, _hisy, ježa_, _ەداۋ, 
   {{0x765c0083,0xed5884c4,0x2cac0204,0x2d9401e0}},	//   _kisy, deža_, wted_, гөлө_, 
   {{0x2cac6e5e,0x78ac0454,0xacc8004e,0x443801ef}},	//   tted_, _oqav, егиз_, _zkr_, 
   {{0x765c87cc,0x2cac87cd,0x7a3c87ce,0x2ef487cf}},	//   _misy, uted_, céti, _өзар, 
   {{0x2cac0c18,0x765c1529,0x753c0034,0x2bc80108}},	//   rted_, _lisy, _mysz, хлоп_, 
   {{0x2cac87d0,0x9e9487d1,0x78ac014b,0x765c87d2}},	//   sted_, _مانچ, _aqav, _oisy, 
   {{0x765c3cac,0x2cac26e7,0x00000000,0x00000000}},	//   _nisy, pted_, --, --, 
   {{0xed5800e2,0x00000000,0x00000000,0x00000000}},	//   beža_, --, --, --, 
   {{0x9d1804ac,0x765c87d3,0xab283e1e,0x3d2800b0}},	//   _אונט, _aisy, _пола_, _wïwï_, 
   {{0x765c87d4,0x78ac014b,0x4438030d,0x2c6803b2}},	//   _bisy, _eqav, _rkr_, _húd_, 
   {{0x765c020c,0x443887d5,0x7afc0627,0x7a3c002e}},	//   _cisy, _skr_, ørte, yéti, 
   {{0x765c87d6,0x44380092,0xb8c80c58,0x7a3c0005}},	// [a5e0] _disy, _pkr_, _গৈ_, xéti, 
   {{0x753c012d,0x44380200,0x00000000,0x00000000}},	//   _dysz, _qkr_, --, --, 
   {{0x6aa087d7,0x765c500a,0xa804035b,0xe5a41cd6}},	//   nulf, _fisy, _азҿл, _йини, 
   {{0x7a3c5599,0x765c0589,0x44380327,0xdb1803cd}},	//   téti, _gisy, _wkr_, rdtø, 
   {{0x443887d8,0x6aa003fa,0x71700137,0x00000000}},	//   _tkr_, hulf, تۇقا, --, 
   {{0x7a3c4056,0x44386ea9,0x10440395,0x628806ea}},	//   réti, _ukr_, лящи_, áfos, 
   {{0x753c003e,0xf8e087d9,0xed5887da,0xfe7002f2}},	//   _zysz, _पप्प, veža_, زگا_, 
   {{0x7a3c5725,0x3df4084c,0x2480037e,0x2c680162}},	//   péti, рзис, _kwkm_, _búd_, 
   {{0xe0d887db,0xed5805ce,0x91e00139,0x673c0200}},	//   _ява_, teža_, _уоте, _lypj, 
   {{0x6aa087dc,0x358402d3,0xfc14030d,0x00000000}},	//   fulf, ራቤታት_, рмоэ, --, 
   {{0xd43400c8,0xed5801fa,0x5398010f,0xdb1800e4}},	//   רטיי_, reža_, עסטא, retï, 
   {{0x5fe03874,0x297c044e,0x78ac022e,0xb9841171}},	//   पावल, _ጨንፈር_, _pqav, штоқ, 
   {{0x765c07ab,0xdb1809c2,0xed58238f,0x00000000}},	//   _risy, metí, peža_, --, 
   {{0xdb183aa7,0x765c87dd,0xb8ec2e05,0x96e8109a}},	//   letí, _sisy, _रन_, ньба_, 
   {{0xf3f8084c,0x6aa00393,0x765c87de,0x36d40a5b}},	//   _îţi_, culf, _pisy, јобр, 
   {{0xd1e4044e,0xd4e487df,0x753c033f,0x00000000}},	//   ማታት_, люзи, _pysz, --, 
   {{0xa3c01161,0x26144ca3,0x765c1123,0x25f400af}},	// [a5f0] ्यं_, _नगरी_, _visy, _एकरी_, 
   {{0x765c0280,0x33940108,0x4874009a,0x00000000}},	//   _wisy, ражё, _اديس, --, 
   {{0x753c006d,0x765c0585,0xdb1887e0,0x673c010b}},	//   _wysz, _tisy, letâ, _gypj, 
   {{0x9f480086,0x24440109,0x765c007f,0x6d5c00e2}},	//   _ôbù_, rôma_, _uisy, žsai, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb4c013b4,0xa3c00a28,0xcdcc004b,0x93e401b9}},	//   ंबी_, ्यः_, ړښت_, _сўмл, 
   {{0x1cb80489,0x2c6887e1,0x850404d3,0x7a3c0129}},	//   _ཆགཔ_, _súd_, _نوێن, létu, 
   {{0x5f9000d1,0x6aa001f5,0x66000327,0x394800c0}},	//   биәт, vulf, _ċokk, _ozas_, 
   {{0x5c8473bf,0x2d940032,0x00000000,0x00000000}},	//   айым_, гөһө_, --, --, 
   {{0x3a28010b,0xdb080036,0x6aa00200,0x8f08030d}},	//   _ajap_, _obfä, tulf, _пхеа_, 
   {{0x7ff40e76,0x394887e2,0xafe40032,0xffe410d9}},	//   _اسقا, _azas_, _йоҡл, _уютн, 
   {{0x09e439db,0xa9a487e3,0x6da40640,0x3ce00010}},	//   মস্থ, шимд, _ђила, _šive_, 
   {{0x3948006d,0x2b14007d,0x684410cf,0xdb080e78}},	//   _czas_, _फेरु_, инма, _abfä, 
   {{0xbd4416cb,0x68e0038f,0x3a2800a2,0x8d740133}},	//   _انهي, _ġodd, _ejap_, _شاڵا, 
   {{0xe73887e4,0x7d0800b0,0x1dd80073,0x2cb8031c}},	//   тев_, rūrū, _मोडत, ħsdu_, 
   {{0xdb1887e5,0xb4c010eb,0xa9086ea9,0x673c01ef}},	//   betâ, ंबू_, _ليبل_, _vypj, 
   {{0xd4644170,0x638487e6,0x393401c4,0xe8f8010a}},	// [a600] иите_, игаа, _гээс, ĕлӳ_, 
   {{0xd6a400f2,0x3d18000d,0x00000000,0x00000000}},	//   دگیم_, _बइसे_, --, --, 
   {{0x66e487e7,0x179802e4,0x00000000,0x00000000}},	//   _тона, _בייב, --, --, 
   {{0xe48801c0,0xdb1800d8,0xc4480133,0xe28c022e}},	//   _иймд_, letã, _ڵیان_, rsа_, 
   {{0x52803b5f,0x5fe00316,0x6604023a,0xdb1801d3}},	//   ملەك, पालल, _ilkk, vetí, 
   {{0xd00c87e8,0x26d80427,0xd0340212,0xa34800db}},	//   ولن_, _krpo_, азії_, _азга_, 
   {{0x9e0487e9,0x644c0327,0x625801af,0xe51887ea}},	//   ичил, _ihbi, _арар_, _नेति_, 
   {{0x291c0e2d,0x97540375,0x7e4800e5,0x7c8c0092}},	//   ştay_, סיקו_, دستہ_, _መነሻው_, 
   {{0xa06800c9,0x00000000,0x00000000,0x00000000}},	//   _раза_, --, --, --, 
   {{0x7a3c026c,0x629c20ac,0x26d858e5,0x66040327}},	//   hétt, orpo, _orpo_, _llkk, 
   {{0x8aa029c3,0xdb184e72,0xe7c887eb,0xed5800de}},	//   оряд, petí, ाजनप, bežo_, 
   {{0x39480789,0x13cc015b,0x5ebc02f5,0xc9840305}},	//   _pzas_, রায়, ্মদে, жури, 
   {{0xb78830cb,0x644c013f,0x7e681477,0x0508015b}},	//   ләне_, _ohbi, _hudp, লপুর_, 
   {{0x7e680af2,0xdb180356,0x66040108,0x00000000}},	//   _kudp, retâ, _alkk, --, 
   {{0xc66807fa,0xdb180e78,0x7a3c020c,0x9a840408}},	//   иште_, ndtü, wétu, _тулл, 
   {{0x3a280165,0x68e001a6,0xd5a007d6,0xdb180022}},	//   _ujap_, _šode, تلری, petâ, 
   {{0x394800c8,0x629c013c,0x7e680115,0xdb18004e}},	// [a610] _uzas_, erpo, _ludp, letà, 
   {{0x644c01ab,0x7e6887ec,0x38680076,0x9f5c03b2}},	//   _chbi, _oudp, _iuar_, _altí_, 
   {{0x7e6800df,0xdb1867c1,0x63b40022,0xd6e800f5}},	//   _nudp, netà, сахӡ, _рфпл_, 
   {{0x386887ed,0x644c01c4,0xf1e087ee,0x7a3c87ef}},	//   _kuar_, _ehbi, फाइन, pétu, 
   {{0x629c0eda,0x70183334,0xade405d7,0x644c01ab}},	//   arpo, лікт_, कासन_, _fhbi, 
   {{0x7e68020c,0x386887f0,0xdb1887f1,0x3a3800d0}},	//   _budp, _muar_, ndtó, hosp_, 
   {{0xb8f807e4,0x386887f2,0x7f483baf,0x3a38037e}},	//   _ོན_, _luar_, ۇلۇق_, kosp_, 
   {{0x38680076,0x644c036e,0x7db40006,0xf3e800eb}},	//   _ouar_, _zhbi, осьц, _গতির_, 
   {{0x386887f3,0x2cbc0208,0x00000000,0x00000000}},	//   _nuar_, _qpwd_, --, --, 
   {{0x321c033f,0x7ff487f4,0x5fac3d1d,0x3e680022}},	//   liwy_, _وسلا, _घायल, ышән_, 
   {{0x3a701cd1,0x00000000,0x00000000,0x00000000}},	//   үһәр, --, --, --, 
   {{0xa3dc05ba,0xf7680375,0x00000000,0x00000000}},	//   _दोन_, _טק_, --, --, 
   {{0x2d8c01e0,0x386887f5,0xb4c001ad,0x30f800dc}},	//   maee_, _cuar_, ंबो_, ्निः_, 
   {{0x18641b74,0x2d8c87f6,0x38680023,0x64980032}},	//   сари_, laee_, _duar_, ҫтар_, 
   {{0x7a3c7c7b,0x386800ad,0xdb1800e4,0x1b1800cc}},	//   tétt, _euar_, retã, _নুঠে_, 
   {{0x386887f7,0x2d8c0381,0x7d0c137e,0x30f800cd}},	//   _fuar_, naee_, _ölsü, ्नाः_, 
   {{0x69c487f8,0x7a3c87f9,0xe3b887fa,0x386887fb}},	// [a620] meke, rétt, лба_, _guar_, 
   {{0x2d8c0093,0x629c1440,0xa06801b9,0xdb181bbf}},	//   haee_, trpo, ҳада_, letá, 
   {{0x386887fc,0x64a4013e,0x629c257c,0x26d80108}},	//   _zuar_, раҷа, urpo, _urpo_, 
   {{0x69c487fd,0xdb1824b0,0x7a3c87fe,0xa06826f7}},	//   neke, netá, létr, гада_, 
   {{0x10a087ff,0x7e687040,0x69c4005a,0x2d8c003a}},	//   зичн, _sudp, ieke, daee_, 
   {{0x69c48800,0x7a3c8801,0x7e681c06,0x2ff40145}},	//   heke, nétr, _pudp, قتىڭ, 
   {{0x69c48802,0x44448803,0xdb180518,0x2490062c}},	//   keke, ml_, ketá, lsym_, 
   {{0xa3c0069f,0x69c48804,0xdfd0021a,0x71700f78}},	//   ्यक_, jeke, _ډير_, _قۇما, 
   {{0x69c48805,0x44448806,0x24900142,0xadb40137}},	//   deke, ol_, nsym_, تۇنا_, 
   {{0xda788807,0x44448808,0xdca41621,0x3868003e}},	//   лям_, nl_, _ҳади, _ruar_, 
   {{0x44448809,0x5f44880a,0x63ac020c,0xdb180789}},	//   il_, _انال, _mcbn, fetá, 
   {{0x69c4880b,0x4444880c,0xdca4880d,0x3860880e}},	//   geke, hl_, _гади, _sihr_, 
   {{0x38684a1f,0x4444880f,0x9d5400db,0xade4007d}},	//   _quar_, kl_, _انشت, कारन_, 
   {{0x44448810,0x7a3c3e3b,0x321c033f,0x00000000}},	//   jl_, gétr, ziwy_, --, 
   {{0xd5b88811,0x69c453ff,0x38680a40,0x44448812}},	//   лса_, beke, _wuar_, dl_, 
   {{0x38688813,0xe72c013d,0x2abc00b5,0x926801a9}},	//   _tuar_, _idеl_, でban_, ҳрда_, 
   {{0x44448814,0x6fa80574,0x7c288815,0xd378023a}},	// [a630] fl_, _घालू, ondr, гче_, 
   {{0x44441675,0x7c288816,0xc0d4001f,0xdeb40150}},	//   gl_, nndr, _የሰራ_, _ﺤﺴﺎﺒ, 
   {{0x7c288817,0x00000000,0x00000000,0x00000000}},	//   indr, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdca48818,0x44448819,0x09e0031c,0x3d18000d}},	//   _تى_, bl_, སྐྲ_, _बेले_, 
   {{0x69c4881a,0x4444881b,0x7c280d27,0x5348030d}},	//   zeke, cl_, jndr, _йăлă, 
   {{0x69c42959,0x1dd80c2e,0x2d8c881c,0xdb18366f}},	//   yeke, _मोहत, taee_, letæ, 
   {{0x7c28881d,0x69c401f0,0x31340353,0x75f000e5}},	//   endr, xeke, _дебр, _fűző, 
   {{0x69c4881e,0x21140073,0xdb18353e,0x7c288524}},	//   veke, _देऊळ_, netæ, fndr, 
   {{0x69c4881f,0xeab80354,0x2d8c003a,0x1c402f6a}},	//   weke, айо_, saee_, мным, 
   {{0x69c48820,0x5fac0574,0x00000000,0x00000000}},	//   teke, _घातल, --, --, 
   {{0x7c288821,0x21fc00b0,0x69c40ea0,0x2ab002f0}},	//   andr, _pïhi_, ueke, ráb_, 
   {{0x6e288822,0xdb188823,0x44448824,0xbc7001ec}},	//   mneb, retá, yl_, _كۇيب, 
   {{0x44448825,0x9a50001f,0x3ce00022,0xdb18005c}},	//   xl_, መለከቱ, _áiva_, detæ, 
   {{0x444404ce,0xdb188826,0x69c48827,0x6e280083}},	//   vl_, petá, peke, oneb, 
   {{0xe5788828,0x69c40921,0x444428fd,0x7a3c0264}},	//   рза_, qeke, wl_, sétr, 
   {{0x6e288829,0x4444882a,0xdb1801bf,0x00000000}},	// [a640] ineb, tl_, getæ, --, 
   {{0x6e28002f,0x7afc007c,0x00000000,0x00000000}},	//   hneb, ärtg, --, --, 
   {{0x4444882b,0xc2cc0150,0x6e280158,0x216800c7}},	//   rl_, _ءﺑﯘﺗ, kneb, аиеи_, 
   {{0xe0d8882c,0x4444882d,0xdb1800b5,0x6e2802f0}},	//   иве_, sl_, betæ, jneb, 
   {{0x7c281347,0x69d802b5,0x00000000,0x00000000}},	//   yndr, ēteh, --, --, 
   {{0x7d000248,0x2018180f,0xe2a800ec,0x00000000}},	//   _lárú, òpi_, _پاسن_, --, 
   {{0xff8800fb,0x2bec00cd,0x00000000,0x00000000}},	//   _һөйл_, जानं_, --, --, 
   {{0xdcb80801,0x6e280ef9,0x6aa0010a,0xdde8027d}},	//   ащо_, gneb, drlf, شربه_, 
   {{0x7c280109,0x00000000,0x00000000,0x00000000}},	//   tndr, --, --, --, 
   {{0x2244882e,0x7c28882f,0x6e28017a,0x28dc4466}},	//   llok_, undr, aneb, मिनि, 
   {{0x7c288830,0xfd6401af,0xc0bc0240,0x00000000}},	//   rndr, _енеү, _ተዃሉ_, --, 
   {{0x3f8c8831,0x5ce400c6,0xd2b4011a,0xb9340798}},	//   _hedu_, _وكال, חלטת_, земј, 
   {{0x3f8c00b4,0x7d000241,0x6d5c00e2,0x394c0450}},	//   _kedu_, _dárú, žsar, åes_, 
   {{0x39440029,0xd1f40020,0x16700046,0xd8383e4e}},	//   āls_, _ጉዳት_, мқор, рэм_, 
   {{0x22448832,0x7bc88833,0x3f8c8834,0x4b78008f}},	//   klok_, medu, _medu_, _דאוו, 
   {{0x7bc88835,0x22448836,0x80bc4ff1,0x4b8400d1}},	//   ledu, jlok_, ोबाइ, _лйән_, 
   {{0x22442fd9,0x7d0003ac,0xdde000dc,0x00000000}},	// [a650] dlok_, nyms, _śuśr, --, 
   {{0xd3788837,0x798c8838,0x7bc88839,0xdb1800b5}},	//   рча_, _heaw, nedu, retæ, 
   {{0x798c166a,0x6e280368,0x7bc8009a,0x38c0007c}},	//   _keaw, yneb, iedu, _fårö_, 
   {{0x7bc8883a,0x1dd805d7,0xf1582dbf,0x2244883b}},	//   hedu, _मोलत, биеш_, glok_, 
   {{0x3f8c883c,0x798c0810,0xdb18883d,0x6e280627}},	//   _bedu_, _meaw, letä, vneb, 
   {{0x798c02c4,0x2244079b,0x3f8c011c,0x7bc8883e}},	//   _leaw, alok_, _cedu_, jedu, 
   {{0xb8cc0003,0x7bc8883f,0x3f8c8840,0xdb1816ca}},	//   _པའ_, dedu, _dedu_, netä, 
   {{0xed588841,0x798c0099,0x3f8c0248,0x22440429}},	//   leži_, _neaw, _eedu_, clok_, 
   {{0x6e280ac8,0x41c40014,0xdb180f23,0x7bc80165}},	//   rneb, _زٲلِ, hetä, fedu, 
   {{0x7bc88842,0xdb188843,0x3f8c8844,0xed580010}},	//   gedu, ketä, _gedu_, neži_, 
   {{0xf8a825f9,0x7df401b9,0x00000000,0x00000000}},	//   _תש_, سقیچ, --, --, 
   {{0xdeb80302,0xdb1802f6,0x3f8c0810,0x321406b9}},	//   _למעל, detä, _zedu_, _çayı_, 
   {{0x798c8845,0x3f8c05b8,0xdb180274,0xec780815}},	//   _deaw, _yedu_, yetç, _упл_, 
   {{0xed584473,0x7bc88846,0x7028031c,0x6b6401d5}},	//   ježi_, cedu, _སམྦུ_, _экка, 
   {{0x26dc1709,0xed588847,0x22440548,0x00000000}},	//   íto_, deži_, ylok_, --, 
   {{0x7afc8848,0x22440327,0x05200240,0xfaf006c2}},	//   ärte, xlok_, _ተመልኪ, _جثه_, 
   {{0x26dc008f,0x00000000,0x00000000,0x00000000}},	// [a660] ŭto_, --, --, --, 
   {{0x69d48849,0x29003c30,0xdb18002f,0x624800a2}},	//   _haye, myka_, betä, aýol, 
   {{0x3f8c884a,0x69d4884b,0xe6443e1e,0xdb180365}},	//   _redu_, _kaye, _неоп, retç, 
   {{0x3f8c63ce,0x23700029,0x7bc8884c,0x69d4884d}},	//   _sedu_, _šajā_, zedu, _jaye, 
   {{0x69d4884e,0x200c25a9,0x3f8c884f,0x2900072d}},	//   _maye, thfi_, _pedu_, nyka_, 
   {{0x69d48850,0x7bc802b9,0xc138001f,0x22442507}},	//   _laye, xedu, _እናውቃ, slok_, 
   {{0x3f8c05b8,0x22448851,0x7bc88852,0xdb18012b}},	//   _vedu_, plok_, vedu, ldtö, 
   {{0x69d48853,0x3f8c05b8,0x7bc80428,0xfcc40116}},	//   _naye, _wedu_, wedu, дәкм, 
   {{0x8d708854,0x7bc88855,0x10a021d7,0xa0a4030d}},	//   رايا, tedu, _питн, _хазд, 
   {{0x798c8856,0x69d48857,0x7bc801f5,0x9e700150}},	//   _seaw, _aaye, uedu, _كۇتت, 
   {{0x69d48858,0xba1810fe,0x201c0024,0xf1a4010a}},	//   _baye, قيدا_, _imti_, _арĕн, 
   {{0xa3dc0dba,0xdb188859,0x00000000,0x00000000}},	//   _दोस_, jetå, --, --, 
   {{0x69d4885a,0x5c0406bb,0x7bc8885b,0x386c0af9}},	//   _daye, _няка, pedu, êer_, 
   {{0xdb18049b,0xc864885c,0xad240271,0x00000000}},	//   tetä, етси, _ترمو, --, 
   {{0x69d4885d,0xed58885e,0xddc0013a,0x1be0012d}},	//   _faye, veži_, _shoř, _कोयल_, 
   {{0x69d4885f,0x9f5c013d,0xdb188860,0x00000000}},	//   _gaye, _iltä_, getå, --, 
   {{0xed5816a3,0x80cc0316,0xdb183110,0xf3f88861}},	// [a670] teži_, _दैले, setä, онаш_, 
   {{0x69d48862,0xb4bc0406,0x00000000,0x00000000}},	//   _zaye, _आही_, --, --, 
   {{0xed581a48,0x67b8011a,0xd3448863,0x00000000}},	//   reži_, _ומתק, سیره_, --, 
   {{0x69d40067,0xcb100a7c,0xc2c4007b,0xf8b0353b}},	//   _xaye, עלף_, عيني, _जमाय, 
   {{0xed5802f0,0x7afc0fac,0xddc001ef,0x6ad8000d}},	//   peži_, ørtj, _uhoř, _बछ्र, 
   {{0x28dc18cc,0x00000000,0x00000000,0x00000000}},	//   मिति, --, --, --, 
   {{0x29008864,0x69cc05f9,0x82a400d8,0xdfcc1541}},	//   zyka_, _तसली, _пште, شيي_, 
   {{0x201c1509,0xec783f67,0x00000000,0x00000000}},	//   _emti_, опи_, --, --, 
   {{0xdcac0075,0x69d48865,0x320c058a,0xa9a40131}},	//   لىي_, _raye, _iley_, ۈمدى, 
   {{0xca5401ec,0x00000000,0x00000000,0x00000000}},	//   _ﻋﺭﺽ_, --, --, --, 
   {{0x69d48866,0xa9a48867,0x27f80204,0xd59800b5}},	//   _paye, минд, _ropn_, _cmか_, 
   {{0x2900006d,0xfe705496,0x69d48868,0xa020032e}},	//   tyka_, _صدم_, _qaye, _óöru, 
   {{0x69d48869,0xeb98886a,0xbc7400db,0x00000000}},	//   _vaye, _дил_, _كەيش_, --, 
   {{0x69d4886b,0x2900886c,0x06840c60,0xca100171}},	//   _waye, ryka_, нҳон, _ņūdž, 
   {{0x69d4886d,0x1ca80003,0xdce00421,0xaad0007d}},	//   _taye, _བའོ_, _igoā, _तनिक, 
   {{0x69d4037e,0x29000022,0xe7dc012d,0x00000000}},	//   _uaye, pyka_, _फोरप, --, 
   {{0xa9c000cf,0x00000000,0x00000000,0x00000000}},	// [a680] _كۅگۉ, --, --, --, 
   {{0xdb18002d,0x9f5c01f4,0x00000000,0x00000000}},	//   jetû, _yltä_, --, --, 
   {{0x320c886e,0x00000000,0x00000000,0x00000000}},	//   _bley_, --, --, --, 
   {{0x320c039a,0xed580427,0x72280212,0xfd580432}},	//   _cley_, ležu_, пців_, gdaỳ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd12c4876,0x320c0fac,0x33d4886f,0x00000000}},	//   جمه_, _eley_, _піст, --, 
   {{0xd0780023,0x00000000,0x00000000,0x00000000}},	//   _ይደልዩ_, --, --, --, 
   {{0x3ea00316,0x3cd48870,0x320c0204,0x1dac0073}},	//   čit_, ежис, _gley_, _टाळत, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xed588185,0x95f8033f,0x5b2400f5,0x00000000}},	//   ježu_, _एक्ट_, дьма, --, 
   {{0xed5809a8,0x9f041a4b,0x00000000,0x00000000}},	//   dežu_, _تواو, --, --, 
   {{0x2d980789,0x00000000,0x00000000,0x00000000}},	//   óset_, --, --, --, 
   {{0xb4bc2d6c,0x58840124,0x00000000,0x00000000}},	//   _आहे_, ьына, --, --, 
   {{0xec34215c,0x00000000,0x00000000,0x00000000}},	//   _كونگ, --, --, --, 
   {{0x50180375,0x00000000,0x00000000,0x00000000}},	//   קולו, --, --, --, 
   {{0x99640c17,0xf1b800d0,0x00000000,0x00000000}},	//   _отпл, _omša_, --, --, 
   {{0xd7f809a0,0xed5800e2,0x00000000,0x00000000}},	// [a690] _дун_, bežu_, --, --, 
   {{0x93244973,0x76b8084c,0x7bd800e5,0x36d401c6}},	//   وران, _елор_, _javu, _зоор, 
   {{0x08f88871,0x7bd88872,0x320c1afe,0xfbd800cc}},	//   _فریب_, _mavu, _pley_, তাপত, 
   {{0x7bd81675,0xf1581d0f,0x00000000,0x00000000}},	//   _lavu, пиеш_, --, --, 
   {{0xdca48873,0x68400a81,0xdb080112,0x6d1c0037}},	//   _حى_, _شێہل, _abfü, _बेंग_, 
   {{0x7bd88874,0xdc100139,0x00000000,0x00000000}},	//   _navu, kşıl, --, --, 
   {{0x72040132,0x00000000,0x00000000,0x00000000}},	//   _كوسم, --, --, --, 
   {{0x7bd8062c,0xddd80115,0x00000000,0x00000000}},	//   _aavu, _tutŝ, --, --, 
   {{0x7bd88875,0x39488876,0x316c0139,0x00000000}},	//   _bavu, _nyas_, _igez_, --, 
   {{0x7bd823e0,0xcee88863,0xc60800eb,0x00000000}},	//   _cavu, _وران_, রোপা_, --, 
   {{0x7bd88877,0x752802f0,0xd9e80d79,0xdc1000a2}},	//   _davu, _žezl, टांत_, gşıl, 
   {{0x7afc049f,0x9b940150,0x00000000,0x00000000}},	//   ärta, _ﻛﯘﭘﻰ_, --, --, 
   {{0x7bd88878,0xcd280014,0xed5805ce,0x9af001ec}},	//   _favu, _بسان_, težu_, _ەكىت, 
   {{0x7bd88879,0x3948089c,0x3d180034,0xa3dc0210}},	//   _gavu, _dyas_, _बेटे_, _दों_, 
   {{0xed580841,0x2cac887a,0xa62c0092,0xad2400f1}},	//   režu_, lued_, _ተለይተ, _ترڅو, 
   {{0x7bd8887b,0x316c009a,0xed5816a3,0x2cac0156}},	//   _zavu, _ngez_, sežu_, oued_, 
   {{0x7bd8887c,0x3948003a,0x2cac0c30,0xed580010}},	// [a6a0] _yavu, _gyas_, nued_, pežu_, 
   {{0x80c8009e,0xe2984cb2,0x00000000,0x00000000}},	//   লিম্, заж_, --, --, 
   {{0x2cac04c4,0x3e7800c7,0x38b80022,0x00000000}},	//   hued_, _oĩta_, pýrã_, --, 
   {{0xe1f808e2,0x63bc0175,0x7afc003b,0x00000000}},	//   яге_, sfpn, ørti, --, 
   {{0x39480218,0xdb180036,0x40b40276,0x6024887d}},	//   _xyas_, rfté, треӂ, ндда, 
   {{0x316c0165,0x2cac0076,0xe29877a8,0x25b000a2}},	//   _egez_, dued_, _наг_, lgyl_, 
   {{0x7bd8887e,0xdc10887f,0x645c8880,0xa02400a2}},	//   _ravu, xşıl, mmpi, _aköý, 
   {{0x7bd88881,0xdb1800b5,0x2cac05ac,0x645c0af9}},	//   _savu, metø, fued_, lmpi, 
   {{0x645c2430,0x2cac0f85,0xdb185522,0xdb0c01e1}},	//   ompi, gued_, letø, _àdún, 
   {{0x7bd8014f,0x645c8882,0x00000000,0x00000000}},	//   _qavu, nmpi, --, --, 
   {{0x7bd88883,0x8c501b06,0x645c8884,0x5f04010b}},	//   _vavu, دئيا, impi, _язжа, 
   {{0xdc101ae6,0x3948007f,0x2cac0036,0x00000000}},	//   rşıl, _pyas_, bued_, --, 
   {{0x7bd88885,0x3d181715,0x8df8011a,0x00000000}},	//   _tavu, _बेचे_, _מהאת, --, 
   {{0x39480810,0xdb182c95,0x645c01f5,0x628c035a}},	//   _vyas_, ketø, jmpi, _owbo, 
   {{0x2c0c0073,0x7aa4000d,0x00000000,0x00000000}},	//   ाघरं_, _खटिअ, --, --, 
   {{0x45d402bf,0xdb1820e4,0x3948414b,0x645c8886}},	//   лосс, detø, _tyas_, empi, 
   {{0x73d88887,0x628c8888,0x1dc00c00,0x82bc025c}},	// [a6b0] мдар_, _awbo, व्यत, _པཱུའ, 
   {{0xd68407b5,0xd7f8014b,0xddd801ef,0x00000000}},	//   _пумп, _хуи_, _ottů, --, 
   {{0xdb1804ce,0x78bc683b,0x522401a9,0x00000000}},	//   getø, ltsv, нфда, --, 
   {{0x645c8889,0x2cac0165,0xa368022e,0x00000000}},	//   ampi, yued_, ydеv, --, 
   {{0x78bc014a,0x764c1258,0xd3a40261,0x628c0857}},	//   ntsv, mlay, _првп, _ewbo, 
   {{0x764c888a,0x78bc888b,0xa3dc0037,0xdb18005c}},	//   llay, itsv, _दोऊ_, betø, 
   {{0x853003f9,0x877c0a1e,0x628c03cb,0xe2740f15}},	//   maɗa, לאגי, _gwbo, _аксө, 
   {{0x78bc03cd,0xd24400ee,0x2cac030a,0xdb0c0248}},	//   ktsv, _чэги, tued_, _àdùn, 
   {{0x4ec0015b,0x764c888c,0x7afc0112,0x823400f2}},	//   ্মেল, ilay, ärtn, _صرفا, 
   {{0x764c888d,0x2cac7731,0x6b64004e,0x5fac0118}},	//   hlay, rued_, ккпа, _घाएल, 
   {{0x764c0ab7,0x2cac888e,0x78bc0036,0x69c000e4}},	//   klay, sued_, etsv, _ñoek, 
   {{0x78bc11ad,0x2ee4009a,0x853003f9,0x764c010a}},	//   ftsv, _irlf_, haɗa, jlay, 
   {{0x764c888f,0x2cac232c,0x6124022e,0x78bc005c}},	//   dlay, qued_, _gаld, gtsv, 
   {{0xdca08890,0x764c8891,0x00000000,0x00000000}},	//   _таши, elay, --, --, 
   {{0x78bc8892,0xccb400b5,0x764c8893,0x00000000}},	//   atsv, _hホ_, flay, --, 
   {{0x764c8894,0xaa440510,0x3ce00427,0xdb1812e8}},	//   glay, _шейл, _šivi_, vetø, 
   {{0x6fe00490,0x966004b3,0x3a3800e4,0x00000000}},	// [a6c0] पयां, ркте, érpe_, --, 
   {{0x764c8895,0xccb4037e,0xdb18143a,0x645c8896}},	//   alay, _mホ_, tetø, umpi, 
   {{0x764c8897,0xe7388898,0x645c6a95,0x00000000}},	//   blay, _цен_, rmpi, --, 
   {{0x764c01d9,0xdb181fcd,0xaaa8012c,0x25d40150}},	//   clay, retø, _किनक, _جۇرگ_, 
   {{0x853003f9,0xf1b80010,0x645c009a,0x00000000}},	//   baɗa, _emšo_, pmpi, --, 
   {{0xdb1801bf,0x9374014b,0x1dd801f9,0x00000000}},	//   petø, _абёт_, _मोजत, --, 
   {{0x1ca80003,0x6710012c,0x8f5015bf,0x00000000}},	//   _བའང_, ठनिक_, ۇنۇش, --, 
   {{0x7cd88899,0x4fe40166,0xe298014b,0x00000000}},	//   емир_, емән_, _наҳ_, --, 
   {{0x1fb4889a,0x9f5c0240,0x00000000,0x00000000}},	//   _асер, _kotë_, --, --, 
   {{0x7afc01e6,0x1dac0490,0x5f04020a,0xc5b8009e}},	//   ärto, _टाकत, _изза, ঁজিপ, 
   {{0x4444889b,0x3d2400b0,0xdeb001ec,0x8c400798}},	//   io_, wīwī_, _тұйы, реќе, 
   {{0x4444889c,0x764c03be,0x78bc0efa,0x9f5c036e}},	//   ho_, xlay, ttsv, _lotë_, 
   {{0x3e78889d,0x764c889e,0x984800a7,0xfcc401af}},	//   _hét_, vlay, дява_, _сәйм, 
   {{0x4444889f,0x3e78066d,0x764c88a0,0x9f5c0023}},	//   jo_, _két_, wlay, _notë_, 
   {{0x7c2888a1,0x764c88a2,0x78bc88a3,0x87040d1d}},	//   midr, tlay, stsv, аяте, 
   {{0x444488a4,0x7afc022c,0x3e7888a5,0x85300198}},	//   eo_, ørtu, _mét_, waɗa, 
   {{0x444488a6,0x764c88a7,0x9f5c044e,0x3e7888a8}},	// [a6d0] fo_, rlay, _botë_, _lét_, 
   {{0x7c2888a9,0xdb0c032e,0x00000000,0x00000000}},	//   nidr, _þjós, --, --, 
   {{0x764c88aa,0x3e780016,0x9f5c0200,0x00000000}},	//   play, _nét_, _dotë_, --, 
   {{0x444488ab,0x68e00029,0x764c88ac,0x249c00c0}},	//   ao_, _šodi, qlay, _žymų_, 
   {{0x7c280286,0x94841ac1,0x45d40139,0x00000000}},	//   kidr, _шынд, _тояс, --, 
   {{0x9f5c0240,0x3e7888ad,0x12840811,0xb4c0012d}},	//   _gotë_, _bét_, _لمسی_, ूबी_, 
   {{0x3e780098,0xb8e4031c,0x7afc0267,0xd084035b}},	//   _cét_, _ཌཱ_, ärtl, хыҵи, 
   {{0x3e7888ae,0x9f5c88af,0x00000000,0x00000000}},	//   _dét_, _motè_, --, --, 
   {{0x2ef40598,0xc10488b0,0xeb987b38,0x9f5c02e2}},	//   _әзер, _پولي, нип_, _lotè_, 
   {{0x4ea4313f,0xabd41614,0x3e78007f,0x7c2888b1}},	//   _арда, уциј, _fét_, gidr, 
   {{0x3e7888b2,0x9f5c0100,0xf1b80010,0x8f44035b}},	//   _gét_, _notè_, _kcš_, _рхад, 
   {{0x4cf40014,0x6a140330,0x2d880051,0x27e42057}},	//   _لبتھ_, ابدر, _ýae_, _şon_, 
   {{0x7c281654,0xe5a40853,0x2ca80332,0x6248010e}},	//   bidr, ғизи, _íad_, mýot, 
   {{0x444488b3,0x6e2888b4,0x7c2888b5,0xe85401d5}},	//   xo_, lieb, cidr, انسد, 
   {{0x3e780016,0xe5a488b6,0x00000000,0x00000000}},	//   _xét_, ливи, --, --, 
   {{0x6e2888b7,0x9f5c07c9,0x248001a6,0xe738013d}},	//   nieb, _dotè_, _ptkm_, _җем_, 
   {{0xe4581b10,0xa3e805f5,0x598088b8,0x00000000}},	// [a6e0] ежа_, ндаа_, _улыб, --, 
   {{0x78a817a3,0x6e283262,0x00000000,0x00000000}},	//   ševc, hieb, --, --, 
   {{0x6e280cf9,0x33d40220,0x9f5c0023,0x737401e0}},	//   kieb, шітт, _votë_, рыух, 
   {{0x3e7888b9,0x7e78074d,0x80c80eac,0x6e280ea0}},	//   _rét_, vqvp, লিস্, jieb, 
   {{0x444488ba,0x6e2888bb,0x222400aa,0x8cd002ab}},	//   po_, dieb, نګړي_, _बैलो, 
   {{0x444488bc,0x3e7888bd,0x2328014b,0x00000000}},	//   qo_, _pét_, _зоги_, --, 
   {{0x9f5c88be,0x6d5c88bf,0x6e280112,0x00000000}},	//   _koté_, ýsan, fieb, --, 
   {{0x629c88c0,0x9f5c002e,0x7c280e78,0x3e78004d}},	//   mspo, _joté_, widr, _vét_, 
   {{0x7c2888c1,0x24700100,0x3e78002e,0x00000000}},	//   tidr, _fņme_, _wét_, --, 
   {{0xd12c14e9,0x224488c2,0x610800da,0x629c01a6}},	//   _عمل_, look_, _vēlā, ospo, 
   {{0x7c2888c3,0x629c88c4,0x23c472ae,0xdb1803b2}},	//   ridr, nspo, र्यद, betý, 
   {{0x22442db4,0x6e281730,0x9f5c88c5,0x7c286179}},	//   nook_, cieb, _noté_, sidr, 
   {{0x7c280ffb,0xb7880daf,0xdb1888c6,0x9be400d4}},	//   pidr, кәне_, letü, _бійк, 
   {{0xc8501540,0x224488c7,0xd7f888c8,0x9f5c011c}},	//   _ማእከላ, hook_, хум_, _potè_, 
   {{0x224488c9,0xd180001f,0x2bd80073,0xcb0401c8}},	//   kook_, _ይጠቅሙ_, _बघता, _ميون_, 
   {{0x629c88ca,0x9f5c88cb,0x4438022e,0x224488cc}},	//   dspo, _coté_, _ajr_, jook_, 
   {{0x26d834fe,0x9f5c88cd,0x4438387a,0xdb1801ed}},	// [a6f0] _espo_, _doté_, _bjr_, hetü, 
   {{0x44380263,0xba00001f,0x629c88ce,0x6e2815c0}},	//   _cjr_, _ውሀ_, fspo, zieb, 
   {{0x629c88cf,0xdb180077,0x44380175,0x00000000}},	//   gspo, metó, _djr_, --, 
   {{0xdb1888d0,0x224400e8,0x68ec0432,0x00000000}},	//   detü, gook_, _ündä, --, 
   {{0x6e280998,0xdb1800e4,0x7afc007c,0xc0a80066}},	//   vieb, vetý, ärtj, هاول_, 
   {{0x6e280112,0x1294027d,0xdc0c107c,0x1fa40114}},	//   wieb, _مشرح, िसोड_, акши_, 
   {{0x6e2888d1,0x43681ee3,0x629c009b,0x0580002b}},	//   tieb, _баён_, cspo, _pīḍy, 
   {{0x224404ce,0x0f280023,0xc2c4007b,0x00000000}},	//   cook_, _እንርከ, _ديفي, --, 
   {{0x6e2888d2,0xad240075,0xdd1c0118,0x752800a2}},	//   rieb, شىدى, _píšo, _ýezd, 
   {{0x6e2888d3,0xdb1888d4,0x1be403cf,0x6cbc00d1}},	//   sieb, jetó, адьи_, _ﻣﻪﺧﺴ, 
   {{0x6e2888d5,0x6e040014,0xdb180210,0x00000000}},	//   pieb, _پِشن, detó, --, 
   {{0xaa4488d6,0xdce400e2,0x92b000fe,0x624800a2}},	//   ремл, šmāj, _জৈৱ_, lýor, 
   {{0x2d8c88d7,0x629c88d8,0x7afc88d9,0x00000000}},	//   mbee_, zspo, ørtr, --, 
   {{0x6d5888da,0x765c003e,0x629c88db,0x2d8c88dc}},	//   _izwa, _ahsy, yspo, lbee_, 
   {{0x629c0036,0x9f5c012c,0xa5940801,0x2d8c88dd}},	//   xspo, _poté_, иращ, obee_, 
   {{0x78a80f72,0x64a4118f,0x629c04ce,0x2cac0072}},	//   ševa, иаба, vspo, ored_, 
   {{0x629c88de,0x9f5c004a,0x2d8c208d,0x3ce80034}},	// [a700] wspo, _voté_, ibee_, जिये_, 
   {{0x2cac3371,0x224488df,0x6d5888e0,0x9f5c00e8}},	//   ired_, wook_, _mzwa, _woté_, 
   {{0x9340035b,0x2cac03cb,0x629c3f8a,0x00000000}},	//   онфе, hred_, uspo, --, 
   {{0x6d5888e1,0x2cac88e2,0x44380098,0x00000000}},	//   _ozwa, kred_, _wjr_, --, 
   {{0x224488e3,0xe0d00f84,0x443806af,0x629c0f5a}},	//   rook_, تزا_, _tjr_, sspo, 
   {{0xa2e4169c,0x224488e4,0x2cac88e5,0x7afc369a}},	//   _когд, sook_, dred_, ärtk, 
   {{0x2cac0787,0x6d58043b,0xe29849b3,0x224488e6}},	//   ered_, _azwa, _шав_, pook_, 
   {{0x1ca80489,0xdb1888e7,0x2d8c037e,0x9e640b8c}},	//   _བའད_, retü, gbee_, جاتن, 
   {{0xdfd00bbd,0x6d580034,0x61e088e8,0xdb1888e9}},	//   _وير_, _czwa, mdol, setü, 
   {{0x60c088ea,0x2d8c88eb,0x61e088ec,0x69c4002d}},	//   mtom, abee_, ldol, efke, 
   {{0x60c088ed,0x6d5888ee,0x3f9c0451,0x2d8c88ef}},	//   ltom, _ezwa, mavu_, bbee_, 
   {{0x9524038f,0x3f9c88f0,0x60c000c0,0x00000000}},	//   _ལྟའི_, lavu_, otom, --, 
   {{0x61e088f1,0x6d5802d0,0xa3e488f2,0xdb180210}},	//   idol, _gzwa, भया_, tetó, 
   {{0x61e00664,0x3f9c5766,0x1dc006ff,0xbb840597}},	//   hdol, navu_, व्रत, _الغي, 
   {{0x765c0286,0xdb1888f3,0x07081ee3,0x8aa000c7}},	//   _phsy, retó, ахти_, _дрыд, 
   {{0x3f9c829f,0xdb180077,0x61e00419,0x6ea8000d}},	//   havu_, setó, jdol, _टिसु, 
   {{0x3f9c88f4,0x799c88f5,0x61e088f6,0x47cc045e}},	// [a710] kavu_, masw, ddol, ায়ী, 
   {{0x3f9c0419,0x799c88f7,0x61e088f8,0x97b456e0}},	//   javu_, lasw, edol, _өсүш, 
   {{0x3a2808cd,0x3f9c19a2,0xdce00419,0x60c000d7}},	//   _kmap_, davu_, _neoľ, etom, 
   {{0x799c88f9,0x61e088fa,0x60c00023,0xaaa80034}},	//   nasw, gdol, ftom, _किसक, 
   {{0x60c088fb,0xddc0068f,0x41740330,0x2cac0165}},	//   gtom, _okoł, زانس, xred_, 
   {{0x799c88fc,0x3f9c88fd,0x2cac0489,0x2d8c039a}},	//   hasw, gavu_, vred_, wbee_, 
   {{0x60c001e1,0x799c88fe,0x61e088ff,0xada47e3a}},	//   atom, kasw, bdol, байл, 
   {{0x2cac8900,0x799c003e,0xd1b81d37,0x8e04010b}},	//   tred_, jasw, _جاسا_, рмиң_, 
   {{0x60c08901,0x2d8c8902,0x65b001a9,0x51840107}},	//   ctom, rbee_, _mаhа, _буҷа, 
   {{0x3f9c8903,0x3a288904,0x2cac8905,0xa968036b}},	//   cavu_, _amap_, rred_, ғига_, 
   {{0x2cac04a7,0x799c00ca,0xd940010b,0x2c1c00cd}},	//   sred_, fasw, җери, योगं_, 
   {{0x6d5802d0,0x00000000,0x00000000,0x00000000}},	//   _tzwa, --, --, --, 
   {{0x81bc1c82,0x6c840597,0x78a876e0,0x6d5801f0}},	//   _অসম_, _التم, ševn, _uzwa, 
   {{0x61e01d43,0xeb988906,0xaf600b82,0x7b08000f}},	//   zdol, _сик_, _ትሕትና_, êstú, 
   {{0x61e08907,0x60c002fb,0x3a280334,0xe7381d0f}},	//   ydol, ztom, _fmap_, уев_, 
   {{0x3a280085,0x3f9c2625,0x60c00064,0x29180035}},	//   _gmap_, zavu_, ytom, _مقعد_, 
   {{0x2bbc189a,0x3f9c19a2,0x61e001b9,0xe3900023}},	// [a720] ्भपा, yavu_, vdol, _ዝቀረበ_, 
   {{0xd6cc01ed,0x60c08908,0x61e08909,0x3a2800d7}},	//   بقہ_, vtom, wdol, _zmap_, 
   {{0xb864890a,0xe644890b,0x6aa002c4,0xe3581cc9}},	//   _بايو, _генп, nslf, ушаш_, 
   {{0x60c0890c,0x7afc890d,0x3f9c0a49,0x00000000}},	//   ttom, ärti, wavu_, --, 
   {{0xd24c890e,0xa878008f,0x99b8011a,0x00000000}},	//   رنه_, נאַר, רזנט, --, 
   {{0x6604890f,0x60c08910,0x61e00af9,0x8fa00063}},	//   _hokk, rtom, sdol, паље, 
   {{0x66048911,0x60c08912,0x799c8913,0x8fa00063}},	//   _kokk, stom, yasw, чаје, 
   {{0x66041574,0x60c08914,0x21687de7,0x5334008f}},	//   _jokk, ptom, _биби_, _האלב_, 
   {{0x66048915,0x6ab02158,0x3f9c770e,0x91008916}},	//   _mokk, _জনগো, pavu_, _епте, 
   {{0x799c8917,0x705004d3,0x3a28037e,0x30740798}},	//   wasw, _قۆنا, _smap_, _футс, 
   {{0x799c8918,0x798800e8,0x93f8011a,0x660438e1}},	//   tasw, ñewo, אליי, _ookk, 
   {{0x660400fc,0x9e644303,0xaaa88919,0xc984891a}},	//   _nokk, _увед, _किरक, зури, 
   {{0x9f5c004e,0x78a80327,0x00000000,0x00000000}},	//   _motí_, ġevo, --, --, 
   {{0x799c27be,0x25600421,0x78a80e04,0x00000000}},	//   sasw, _mōlī_, ševo, --, 
   {{0x660424c0,0x799c05d9,0xdb1c02f6,0x41c800cd}},	//   _bokk, pasw, ävän, रभास, 
   {{0x6604019b,0x644c891b,0x3a280113,0x9f5c004e}},	//   _cokk, _akbi, _umap_, _notí_, 
   {{0x6604891c,0x878801c0,0x443c1eca,0x00000000}},	// [a730] _dokk, шөөг_, еv_, --, 
   {{0x36d47bb3,0x93a8007b,0x21e001ec,0x00000000}},	//   _доор, طائف_, _ﺍﻵﺨﺭ, --, 
   {{0x6604891d,0x9f5c00db,0xa2c0891e,0xb2d4027d}},	//   _fokk, _botí_, мәтк, تياغ, 
   {{0x6604891f,0x644c0066,0x75d406f6,0xcb1000df}},	//   _gokk, _ekbi, _بيحا, הלע_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xaaa80d2c,0x889c08a8,0x7bc801f5,0x66048920}},	//   _किलक, נבוי, jfdu, _zokk, 
   {{0x66048921,0x43948922,0x6e4401e2,0x9f5c0216}},	//   _yokk, _хасс, ينتم, _fotí_, 
   {{0x660400fd,0xac848923,0x6b800175,0x00000000}},	//   _xokk, огил, wclg, --, 
   {{0x00940276,0x644c00b5,0xb03400c7,0x23c41a55}},	//   _нитэ, _ykbi, _днаш, र्वद, 
   {{0xeb980640,0x932c0023,0x00000000,0x00000000}},	//   шио_, _ተኸታታ, --, --, 
   {{0x78a8098d,0x4ea40228,0xd9e000fe,0xd1f40092}},	//   ševl, _ыраа, যানম, _ፋንታ_, 
   {{0xdd1c00bc,0xba3c0024,0x00000000,0x00000000}},	//   _síťo, drįs, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x66048924,0x7e64025c,0x00000000,0x00000000}},	//   _sokk, ċipe, --, --, 
   {{0x66048925,0xba3c0024,0x46480107,0x00000000}},	//   _pokk, grįs, йҷон_, --, 
   {{0x3a388926,0x6604011f,0x00000000,0x00000000}},	//   cnsp_, _qokk, --, --, 
   {{0xe404487f,0x66042301,0x25640014,0xa02008a5}},	// [a740] озап, _vokk, زارُ, _óögu, 
   {{0x66048927,0x4cd003d4,0x85300198,0x00000000}},	//   _wokk, তিপু, naɗi, --, 
   {{0x66048928,0xc3303ee0,0x23c48929,0x9f5c01ef}},	//   _tokk, رەر_, र्षद, _potí_, 
   {{0xf1b80419,0x60e84627,0x00000000,0x00000000}},	//   _omšu_, имем_, --, --, 
   {{0xe044892a,0x10a0892b,0x764000dd,0xc45404d3}},	//   онди, дичн, élye, _فێرب, 
   {{0x28b0007d,0xdb180f23,0x716418fd,0xaaa80825}},	//   _जिनि, metö, سانك, _किंक, 
   {{0xdb18892c,0xdef80228,0xc0d4001f,0x21a40166}},	//   letö, рыл_, _የደም_, _дәлү_, 
   {{0x6144892d,0x321c033f,0x00000000,0x00000000}},	//   _деба, chwy_, --, --, 
   {{0x717015c3,0xf1d401c0,0xdb186c3f,0x00000000}},	//   _كۇما, _хөхө, netö, --, 
   {{0x9b68721f,0x8c40026a,0xddc00034,0xddd8002b}},	//   ишна_, мење, _skoń, _kutū, 
   {{0xae3400f1,0x3b540395,0x00000000,0x00000000}},	//   _کونډ, якор, --, --, 
   {{0x9f5c003a,0x00000000,0x00000000,0x00000000}},	//   _totâ_, --, --, --, 
   {{0x5c040064,0x00000000,0x00000000,0x00000000}},	//   _мяка, --, --, --, 
   {{0xdb180793,0xb17c00d7,0x98480395,0xf11400df}},	//   detö, _maťa, ряма_, פֿרי_, 
   {{0xddd800c0,0x00000000,0x00000000,0x00000000}},	//   _nutū, --, --, --, 
   {{0x7afc007d,0xddc0033f,0xdee8001f,0x00000000}},	//   ärtu, _ukoń, _ሆነን_, --, 
   {{0xd378892e,0xb4e402e5,0xdb180793,0xb17c00d0}},	// [a750] аче_, पटे_, getö, _naťa, 
   {{0x764001d3,0xb7d801e2,0x248401e7,0x00000000}},	//   élyb, _اودا_, íoma_, --, 
   {{0x4cd000bd,0x9f5c04cc,0x321c0368,0x00000000}},	//   তিযু, _notà_, thwy_, --, 
   {{0xb17c01ef,0x00000000,0x00000000,0x00000000}},	//   _baťa, --, --, --, 
   {{0xf07401d3,0x321c0142,0xdb18000d,0x32500240}},	//   سیاں_, rhwy_, metõ, _ንኣርባ, 
   {{0xdb1800c5,0x764c0363,0xf1c802dd,0x2244892f}},	//   letõ, loay, _گورى_, čoka_, 
   {{0x82a414b7,0x160c0da3,0xada48930,0x02a401d5}},	//   _оште, _सवार_, пайл, _ортм, 
   {{0x9f5c05d5,0x764c0363,0xd9e00154,0xd5c800cd}},	//   _dotà_, noay, যাডম, ाभिज, 
   {{0x9f5c0589,0xcfa800cf,0x00000000,0x00000000}},	//   _potã_, _ناام_, --, --, 
   {{0x41740150,0x2bbc1d68,0xdb18000d,0x10140345}},	//   _زاقس, ्भधा, hetõ, _ببرد, 
   {{0x85300b45,0xb17c0030,0xdb1801b8,0x764c8931}},	//   raɗi, _zaťa, zetö, koay, 
   {{0x764c00e4,0x00000000,0x00000000,0x00000000}},	//   joay, --, --, --, 
   {{0xdb1801b8,0x6d5c04cc,0xaa440124,0xb4e402c3}},	//   xetö, üsad, _ҭелл, पटो_, 
   {{0x2d9c00ca,0x7c94034c,0x1d040075,0x6a8401b9}},	//   _hewe_, _آشنا, _хеши_, _елка, 
   {{0x4e1c0c2e,0x2d9c01e1,0x764c00ad,0xe3b001d3}},	//   _बताई_, _kewe_, foay, ہرا_, 
   {{0x2d9c5975,0xba2805d4,0xdb1800c5,0x764c062c}},	//   _jewe_, _وسيم_, tetö, goay, 
   {{0x2d9c063f,0x23480131,0xc5d00183,0x9f5c01ef}},	// [a760] _mewe_, ڭلاپ_, ৱালপ, _motá_, 
   {{0x2d9c8932,0x63782e9c,0xdb188933,0x21200208}},	//   _lewe_, ссар_, retö, _ýkhi_, 
   {{0xe2c83d71,0x2d9c0175,0x764c8934,0xdb18000d}},	//   след_, _oewe_, boay, betõ, 
   {{0x2d9c8935,0xdb1800c5,0xd12c02f2,0xe61000ae}},	//   _newe_, petö, گمه_, _أشد_, 
   {{0x4dc00154,0x661403b2,0xc8dc012d,0x00000000}},	//   ্যাং, mkyk, यबिट, --, 
   {{0xddd802b5,0x661403b2,0x54640117,0x00000000}},	//   _tutū, lkyk, _наям_, --, 
   {{0x2d9c8936,0x00000000,0x00000000,0x00000000}},	//   _bewe_, --, --, --, 
   {{0x91e08937,0x2d9c0073,0x9f5c07de,0x66148938}},	//   _посе, _cewe_, _votà_, nkyk, 
   {{0x2d9c8939,0xdde801d5,0x62980139,0x00000000}},	//   _dewe_, لرکه_, _çtob, --, 
   {{0xdee41ee3,0xe04458e5,0x00000000,0x00000000}},	//   _нози, _энзи, --, --, 
   {{0x764c00b5,0x661400d7,0x00000000,0x00000000}},	//   yoay, kkyk, --, --, 
   {{0x2d9c0223,0xdb18893a,0xd334011a,0x00000000}},	//   _gewe_, ngté, לריה_, --, 
   {{0xd7f80212,0x764c0076,0x09e402d5,0x00000000}},	//   був_, voay, хоўн, --, 
   {{0x7afc893b,0x764c04ba,0x7bdc000d,0xdee80092}},	//   ärts, woay, õrud, _ሆነና_, 
   {{0x2d9c0796,0x6124022e,0x63bc0175,0x764c893c}},	//   _yewe_, _bаlk, dgpn, toay, 
   {{0x661403b2,0x1b00004e,0x8b38011a,0x00000000}},	//   gkyk, _жүүн, _לתוצ, --, 
   {{0xd8b8893d,0x3b3402d3,0x8a180150,0x764c893e}},	// [a770] _ادعا_, _ብመጀመ, _ءتىس_, roay, 
   {{0xd378893f,0xe72c04d3,0xdb1800c5,0x764c0083}},	//   сча_, اڵی_, setõ, soay, 
   {{0x13640451,0x764c062c,0xdd8400f1,0xd658030d}},	//   سائٽ, poay, _ټو_, _дlад, 
   {{0x31340276,0x6614035a,0xc8c80133,0xf1b8013a}},	//   меер, ckyk, _بوین_, _olše_, 
   {{0xfbb42b1b,0xf0e8104b,0xafe4443f,0x2d9c0112}},	//   জ্যত, تىشى_, долл, _rewe_, 
   {{0x2d9c0660,0x4734035c,0x00000000,0x00000000}},	//   _sewe_, _آریز, --, --, 
   {{0x4dc0009e,0x00000000,0x00000000,0x00000000}},	//   ্যসং, --, --, --, 
   {{0xa2d820f0,0x00000000,0x00000000,0x00000000}},	//   नबर्, --, --, --, 
   {{0x9f5c0407,0x6ea80b4c,0x00000000,0x00000000}},	//   _votá_, _टिकु, --, --, 
   {{0x2d9c8940,0x7e64003d,0x1e640055,0x00000000}},	//   _wewe_, ċipa, _vṛṣo, --, 
   {{0xaa448941,0x2d9c8942,0x64a0054e,0xc6080154}},	//   денл, _tewe_, mţiţ, রোটা_, 
   {{0xcbc400aa,0x2d9c0221,0xb17c00d7,0xddc0013a}},	//   _کېدو_, _uewe_, _maťo, _okoř, 
   {{0x3ea038bb,0xbf70035b,0xad24075e,0xb17c01ef}},	//   ćite_, _иқәы, _تىشى, _laťo, 
   {{0xdb180798,0x64a00356,0x00000000,0x00000000}},	//   tetô, nţiţ, --, --, 
   {{0x66148943,0x00000000,0x00000000,0x00000000}},	//   tkyk, --, --, --, 
   {{0x2bbc00dc,0x7afc12e8,0x00000000,0x00000000}},	//   ्भवा, årte, --, --, 
   {{0x24080364,0x66146069,0x00000000,0x00000000}},	// [a780] онаи_, rkyk, --, --, 
   {{0x6614023a,0xb17c0306,0x00000000,0x00000000}},	//   skyk, _baťo, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe1f8346d,0x22440010,0xc6080154,0x00000000}},	//   юге_, čoko_, রোজা_, --, 
   {{0xf7300092,0x74b8004e,0xe048027d,0x00000000}},	//   _አስደን, _нурс_, يشته_, --, 
   {{0x3c2002e2,0xd0040640,0x612401d5,0x232863dd}},	//   _kòve_, деље_, _jаli, _доги_, 
   {{0x3c20067c,0xc334008f,0xfe78013d,0x00000000}},	//   _jòve_, _װוּ_, чүе_, --, 
   {{0x78a80bb8,0x628c6aca,0x3c20007f,0x00000000}},	//   ševi, _itbo, _mòve_, --, 
   {{0x8d708944,0x80c800eb,0x00000000,0x00000000}},	//   پايا, লিঙ্, --, --, 
   {{0xa3dc02e5,0x612401a9,0x00000000,0x00000000}},	//   ढ़ि_, _nаli, --, --, 
   {{0xd9e004c5,0x93b4011a,0x00000000,0x00000000}},	//   যাসম, וליו_, --, --, 
   {{0xdee4014b,0x00000000,0x00000000,0x00000000}},	//   _ноҷи, --, --, --, 
   {{0x4f9c0201,0xa3dc0c2e,0xb4bc6653,0x8cb40c4f}},	//   _ግንባታ_, ढ़ा_, _इमे_, _قدوس_, 
   {{0xdce02804,0x628c022e,0x00000000,0x00000000}},	//   _ugođ, _otbo, --, --, 
   {{0xddc000bc,0xc6a4004e,0x00000000,0x00000000}},	//   _skoř, крти, --, --, 
   {{0x27e801ab,0x29180165,0x46682461,0x69cc0073}},	//   adbn_, ñfañ_, друм_, ध्दी, 
   {{0x201c036b,0x628c8945,0x63ac0166,0x00000000}},	// [a790] _olti_, _atbo, _bdbn, --, 
   {{0x78bc8946,0x74542b9f,0x00000000,0x00000000}},	//   musv, رپائ, --, --, 
   {{0x78bc7941,0x00000000,0x00000000,0x00000000}},	//   lusv, --, --, --, 
   {{0x201c8947,0x13dc0150,0x78bc0c8c,0x349400c0}},	//   _alti_, _زﻳﺎﻧ, ousv, _памр, 
   {{0x628c0334,0x3d18033f,0xddc01462,0xddd801ef}},	//   _etbo, धनों_, _biož, _autů, 
   {{0x85741c26,0x6498025f,0xc9180375,0x6fb4072d}},	//   _шлях, _מישה, וחדת_, رمعا, 
   {{0x78bc12ed,0xf1d000f7,0x64a00356,0xddc000ef}},	//   husv, _бөлө, rţiţ, _diož, 
   {{0x78bc0433,0x201c032e,0x00000000,0x00000000}},	//   kusv, _elti_, --, --, 
   {{0xdcac2928,0xb11802e3,0x324402dd,0x78bc8948}},	//   مىي_, ọọgụ_, _жеңг, jusv, 
   {{0x78bc4610,0x1c400108,0x00000000,0x00000000}},	//   dusv, лным, --, --, 
   {{0x7afc2771,0x00000000,0x00000000,0x00000000}},	//   ärtp, --, --, --, 
   {{0xd1d00020,0x68200109,0x8d74021f,0x320c0f85}},	//   _ረቂቅ_, _môde, _قاشا, _joey_, 
   {{0x2490010a,0x78bc8949,0x158002dd,0xba00035b}},	//   xpym_, gusv, _ﯨﺴﺘﯩ, рҧыл, 
   {{0x66e4829d,0x6d580309,0xab2808ca,0x9c700055}},	//   нога, _iywa, _нола_, _trāṭ, 
   {{0x28b0012c,0x6d58010b,0x00000000,0x00000000}},	//   _जिवि, _hywa, --, --, 
   {{0x78bc0381,0xf5b4187f,0xe2980124,0x00000000}},	//   busv, ксую, ҧаз_, --, 
   {{0x81e80729,0xd544894a,0x630400aa,0xd624894b}},	// [a7a0] বাম_, епте_, کوال, хоте_, 
   {{0x628c0165,0x291c0115,0x66e4010a,0x00000000}},	//   _ptbo, ŝtas_, _зооа, --, 
   {{0x23c47220,0xe5a423be,0xb40014fb,0x9798011a}},	//   र्गद, _пини, шүрд, _משיק, 
   {{0x1a9800c8,0x6d5803ac,0xd36c00ae,0x00000000}},	//   פינע, _oywa, حهم_, --, 
   {{0x6d581ebd,0x21686191,0x00000000,0x00000000}},	//   _nywa, чиди_, --, --, 
   {{0x25a002d2,0xcf6400d1,0xb37400db,0x00000000}},	//   _hekl_, ﺷﯘﺭﯗ, ردەش, --, 
   {{0x6d580c8c,0x248001b9,0xe7d018ea,0xe29800db}},	//   _aywa, _hukm_, द्यप, _хаб_, 
   {{0x6d58033f,0x00000000,0x00000000,0x00000000}},	//   _bywa, --, --, --, 
   {{0x59a4006d,0x6d58894c,0xa03400db,0x00000000}},	//   _ख़बर, _cywa, _كىرت, --, 
   {{0x320c894d,0x201c894e,0x6d58733d,0x78bc0037}},	//   _zoey_, _ulti_, _dywa, vusv, 
   {{0x6d5802d0,0xb4bc0764,0x00000000,0x00000000}},	//   _eywa, _इम्_, --, --, 
   {{0x78bc1059,0xcc8401d5,0xda64007b,0x4784190b}},	//   tusv, بنیه_, عادي, ғырб, 
   {{0x4974894f,0x6d580042,0x69a0012d,0x00000000}},	//   ллюс, _gywa, _ख़री, --, 
   {{0x78bc8950,0x20080086,0xad24004b,0x87e406a6}},	//   rusv, _òbid_, _جرمو, люсе, 
   {{0x2fd02e11,0x25a0002f,0x2d98030a,0x78bc0857}},	//   _özge_, _bekl_, ñseg_, susv, 
   {{0xd1e4044e,0xdb180ad9,0x9c600451,0xbd9800b5}},	//   ኛታት_, ngtí, _جهڙو, rとwh, 
   {{0x1cdc0156,0x7988002e,0xddc00210,0x00000000}},	// [a7b0] _སགས_, ñewu, _skoś, --, 
   {{0x78ac8951,0x00000000,0x00000000,0x00000000}},	//   _ivav, --, --, --, 
   {{0x08f85457,0x320c067c,0x78ac00b5,0x00000000}},	//   _قریب_, _poey_, _hvav, --, 
   {{0x798c031c,0x6c700055,0x00000000,0x00000000}},	//   _jfaw, _mānṛ, --, --, 
   {{0x91bc01f2,0x798c8952,0x72040014,0x59d0043e}},	//   _ahụ_, _mfaw, _یوسم, ध्यर, 
   {{0x78ac00f1,0x073804fb,0xd44801c0,0x6d58033f}},	//   _mvav, _آسیب_, _хямд_, _rywa, 
   {{0x5fa00131,0x6d580af9,0xb1c800c7,0x6c70002b}},	//   شەنم, _sywa, _отаҧ_, _nānṛ, 
   {{0x3f8c009a,0x78ac8953,0xb17c0419,0x00000000}},	//   _efdu_, _ovav, _maťk, --, 
   {{0x2ee40067,0xeb9814fb,0x78ac0055,0x26fc012d}},	//   _wslf_, мип_, _nvav, _उप्र_, 
   {{0x798c172c,0xea880b3e,0x00000000,0x00000000}},	//   _afaw, мбол_, --, --, 
   {{0xab288954,0x78ac8955,0x394804cc,0x7c642a8b}},	//   фона_, _avav, _axas_, دايل, 
   {{0x8d840801,0x6d588956,0x9e9400db,0x2d9805c7}},	//   _чужд, _tywa, _شامچ, ñsed_, 
   {{0x6d588957,0xfe708958,0x25a08256,0x00000000}},	//   _uywa, _ادل_, _rekl_, --, 
   {{0x798c03ac,0xd1580023,0x00000000,0x00000000}},	//   _efaw, ግስታው, --, --, 
   {{0x78ac8959,0x798c015d,0x613003e0,0xe5a400d8}},	//   _evav, _ffaw, _kılç, киви, 
   {{0x66e40107,0x00000000,0x00000000,0x00000000}},	//   ноҳа, --, --, --, 
   {{0x69d4895a,0xa3e801c0,0x64a4895b,0x59a4033f}},	// [a7c0] _ibye, мдаа_, таза, _ख़तर, 
   {{0xe2980323,0x3c2000e4,0x14200a89,0x00000000}},	//   даж_, _kòva_, адум, --, 
   {{0xa764063b,0x78ac0e8a,0x68f402d2,0xb17c00d7}},	//   _шкод, _zvav, _hryd, _gaťk, 
   {{0x26d8895c,0x3eb800b5,0xd12c004b,0x64a40124}},	//   _ippo_, _årti_, ښمن_, _иама, 
   {{0x69d4895d,0x6124022e,0xb17c00d7,0x7a700092}},	//   _mbye, _nаlt, _zaťk, _አቡጊዳ_, 
   {{0x90504077,0xd00c05d9,0x91bc004d,0xca3401ec}},	//   авіц, يلن_, _phụ_, _ﺭﺃﺱ_, 
   {{0x69d4895e,0x3c202508,0x6d5c895f,0x00000000}},	//   _obye, _nòva_, üsan, --, 
   {{0x645c8960,0x6cec2232,0x817401d9,0x68f402d0}},	//   llpi, जिंग_, _منزچ, _oryd, 
   {{0x81e88961,0x248406d5,0x6b8c00ee,0x6d5c00e4}},	//   বাদ_, íomh_, _şaga, ýsap, 
   {{0x69d48962,0x91bc0051,0x9a84009d,0x00000000}},	//   _abye, _thụ_, кумл, --, 
   {{0x0c700597,0x78ac8963,0x9f5c03a0,0x26d88964}},	//   جديد, _svav, _lotú_, _nppo_, 
   {{0x68f48965,0xd1d00023,0x00000000,0x00000000}},	//   _bryd, _ረቂቕ_, --, --, 
   {{0x26d88966,0x68f40042,0xd90c21f4,0x17940023}},	//   _appo_, _cryd, زید_, _ጉዕዞኡ_, 
   {{0x69d42f99,0x68f40368,0xb17c00d7,0x6c700055}},	//   _ebye, _dryd, _paťk, _tānṛ, 
   {{0xe7d0012a,0x68f4015d,0x798c0327,0x6288004e}},	//   द्धप, _eryd, _tfaw, ífol, 
   {{0x798c8967,0xd4980063,0x78ac8968,0xeb740064}},	//   _ufaw, држ_, _tvav, _сычэ, 
   {{0x26d808e5,0x68f4037e,0x78ac00aa,0x00000000}},	// [a7d0] _eppo_, _gryd, _uvav, --, 
   {{0x78a88969,0x5dbc00fe,0xb17c013a,0x00000000}},	//   ševs, _আসোঁ, _taťk, --, 
   {{0xa53c0023,0x7e64025c,0x786802d2,0x00000000}},	//   _ተዘርጊ, ċipj, gþve, --, 
   {{0x41b4117e,0x355406c2,0x00000000,0x00000000}},	//   асшт, _منجز, --, --, 
   {{0xd5642bbd,0xd0a8013e,0x41e4753d,0xd47401af}},	//   _штоп, фтед_, ріха, _аҙаш_, 
   {{0x4394010a,0x00000000,0x00000000,0x00000000}},	//   _варс, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xece86799,0x877c010f,0xace80124,0x53cc00cd}},	//   едил_, ואוי, емиа_, स्रश, 
   {{0xacf45aa3,0x3a380175,0xc15401af,0x02640244}},	//   اسبت, disp_, _књѕњ, _ئێنێ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa9a4896a,0xc4d044af,0xdd8c004b,0x00000000}},	//   линд, _सङ्ख, غوی_, --, 
   {{0x68f40cfd,0xa68401d5,0x00000000,0x00000000}},	//   _pryd, ғлад, --, --, 
   {{0xbd28007b,0xac18009b,0x00000000,0x00000000}},	//   _لأول_, _поду_, --, --, 
   {{0x68f40151,0xc61c0882,0x3a38017a,0x3e68045f}},	//   _vryd, नस्य_, aisp_, rûte_, 
   {{0x1864896b,0xa3a81533,0x2cac00af,0x3b640014}},	//   уари_, _गजब_, lsed_, _پُٹِ, 
   {{0x2d8c896c,0x69d40585,0x68f400a9,0xe968010b}},	//   ncee_, _ubye, _tryd, _пайл_, 
   {{0xa4441f10,0x2cac896d,0x68f403cd,0x96603740}},	// [a7e0] гнад, nsed_, _uryd, скте, 
   {{0x2cac896e,0x232839c8,0x69c401f5,0x53c45a52}},	//   ised_, нози_, lgke, лгум_, 
   {{0xe738896f,0xe2988970,0x26d801f4,0xa6c8009d}},	//   _чен_, хае_, _uppo_, _ялна_, 
   {{0x69c45d69,0x2cac00af,0xdc00015b,0xa50806ed}},	//   ngke, ksed_, এসএস_, _зема_, 
   {{0x69c403fa,0x3e4c012c,0xa13400db,0x50d08971}},	//   igke, něte_, دراش, مزور, 
   {{0xd0040aa8,0x2cac0037,0x7d0408c2,0x00000000}},	//   лече_, dsed_, _àisi, --, 
   {{0x44448972,0x94201d1c,0x812402f5,0x2cac0076}},	//   mn_, _умре, বপেজ_, esed_, 
   {{0x44448973,0x9ce401c0,0x00e4032f,0x00000000}},	//   ln_, гцол, _پتری, --, 
   {{0x44448974,0x61e000e3,0x2cac00c5,0xa3dc02e5}},	//   on_, meol, gsed_, ढ़ऊ_, 
   {{0x61e08975,0xddd80f8b,0x60c08976,0x69c404e6}},	//   leol, _dutš, muom, egke, 
   {{0x2cac8977,0x60c02077,0x5018011a,0x612800e5}},	//   ased_, luom, _רובו, _fölé, 
   {{0x44448978,0x61e08979,0xdca4897a,0xdbc401b8}},	//   hn_, neol, _бади, löük, 
   {{0x4444897b,0x60c0897c,0x8d14143e,0x3a3803b2}},	//   kn_, nuom, _مزور_, risp_, 
   {{0x4444897d,0x8c4051e4,0x682000d7,0x00000000}},	//   jn_, _лече, _pôda, --, 
   {{0x7bd80099,0x0c400014,0x7aa40137,0x60c00108}},	//   _ibvu, _دپوَ, _ئشتۅ, huom, 
   {{0x60c0897e,0xb59400a6,0x61e00356,0xf48400e5}},	//   kuom, риаш, jeol, لائی, 
   {{0x61e0897f,0x44448980,0x60c0023a,0xf3f80154}},	// [a7f0] deol, fn_, juom, _আকবর_, 
   {{0x44448981,0x85743334,0x058412d7,0xc0d402d3}},	//   gn_, слух, _ҳурм, _ከሰላ_, 
   {{0x2d8c04c4,0x03180014,0x00000000,0x00000000}},	//   ycee_, ُتمت_, --, --, 
   {{0x05848982,0xb81000c7,0x42740214,0x00000000}},	//   _гурм, _уҧҳә, مانآ, --, 
   {{0x44448983,0x7bd8004c,0x321c045f,0x30e48984}},	//   bn_, _obvu, rkwy_, рсең, 
   {{0x2cac00af,0x2eb48985,0x60600131,0x321c012d}},	//   vsed_, асис, قۇقل, skwy_, 
   {{0x2cac039a,0x752c005a,0x78bc0112,0x7c2801c3}},	//   wsed_, lzaz, hrsv, dhdr, 
   {{0xed588986,0x7bd8006f,0x2cac00af,0x61e08987}},	//   кой_, _abvu, tsed_, ceol, 
   {{0x2d8c8988,0xac8403b7,0x2cac0254,0x8fc40133}},	//   rcee_, јгол, used_, _مزان, 
   {{0x2cac8989,0x799c0e78,0x752c0165,0x7c28898a}},	//   rsed_, ebsw, izaz, ghdr, 
   {{0x7f8474bb,0x81e80d42,0x2cac898b,0x78bc898c}},	//   _المن, বার_, ssed_, ersv, 
   {{0x7bd8004c,0x4444898d,0x3e4c012c,0x409400db}},	//   _ebvu, zn_, těte_, _ئلەر, 
   {{0x4444898e,0x9f5c003a,0x6e280117,0x5fd8033f}},	//   yn_, _antè_, mheb, _मॉडल, 
   {{0xef340201,0x7c280013,0x752c898f,0x6e28257c}},	//   _እንዳል, chdr, dzaz, lheb, 
   {{0x44448990,0x66e4016c,0x28b0007d,0x78bc257c}},	//   vn_, шова, _जिकि, arsv, 
   {{0xe8f88991,0x44448992,0x61e08993,0x6e288994}},	//   _али_, wn_, xeol, nheb, 
  
   {{0x44448995,0xe3b08996,0x558405f5,0x9f5c02e2}},	// [a800] tn_, قرا_, рбум_, _entè_, 
   {{0x44448997,0x63940a0e,0x1d940092,0x7e64031c}},	//   un_, ршаф, መንቶች_, ċipi, 
   {{0x6e288998,0x61e08999,0x2a8400ef,0xa2e4005b}},	//   kheb, teol, _bēbi_, роед, 
   {{0xe7d02311,0x6e2801af,0x4444899a,0xd24c4278}},	//   द्रप, jheb, sn_, ونل_, 
   {{0x6e28899b,0x81e8015b,0xb9ec02d3,0xae0800af}},	//   dheb, বাল_, _ንዑ_, वानन_, 
   {{0x61e0899c,0x60c002d5,0xe29403b7,0x58f4011a}},	//   seol, ruom, _враќ, ימנע_, 
   {{0x60c05067,0x6e28899d,0x61e0899e,0x3ef8010b}},	//   suom, fheb, peol, унйэ_, 
   {{0x6e28899f,0xa3dc0307,0x78bc03cd,0x60c001f4}},	//   gheb, ढ़क_, yrsv, puom, 
   {{0x394c006d,0x7c2889a0,0x443889a1,0xfb8401d3}},	//   żesz_, thdr, _kmr_, یدگی, 
   {{0x44380072,0x22440e79,0xcd30007b,0x00000000}},	//   _jmr_, lnok_, غريب, --, 
   {{0x752c6f40,0x6e2889a2,0x7bd800e4,0xe1a40150}},	//   zzaz, bheb, _vbvu, _ەﻛﺸﻪ, 
   {{0x224489a3,0x6e2855fd,0xdb20032e,0xd354011a}},	//   nnok_, cheb, _þríb, שיטי_, 
   {{0x7c940491,0x6fcc1d8a,0x394c89a4,0x78bc4f99}},	//   _التص, _सामू, çes_, ursv, 
   {{0xd83889a5,0x7bd80810,0x443889a6,0x78bc007c}},	//   тэм_, _ubvu, _nmr_, rrsv, 
   {{0xcb040451,0x22440356,0x6c6800e5,0x00000000}},	//   _نيون_, knok_, _حلوہ_, --, 
   {{0x4b7805e1,0x224401d3,0x752c01c6,0x7bc80d12}},	//   _באוו, jnok_, tzaz, lgdu, 
   {{0x73d889a7,0x752c005a,0x9848004e,0xfecc00cc}},	// [a810] лдар_, uzaz, _аяна_, লবিধ, 
   {{0x7bc889a8,0x6e2889a9,0x224401f1,0x752c005a}},	//   ngdu, zheb, enok_, rzaz, 
   {{0x6670598b,0xd3780598,0x3d1c0248,0x00000000}},	//   تگیر, тча_, _yáwú_, --, 
   {{0x6e2800aa,0x443889aa,0x22442c95,0x00000000}},	//   xheb, _emr_, gnok_, --, 
   {{0x81e804c5,0x85440166,0x0118035b,0x84e40024}},	//   বাং_, _дэре, аҭтә_, _доўж, 
   {{0x2244005a,0x7c380064,0x00000000,0x00000000}},	//   anok_, _nmvr, --, --, 
   {{0x31680030,0xdb1801e3,0xa3a8000d,0x00000000}},	//   ťaz_, ngtä, _गड़ि_, --, 
   {{0xddc01ebd,0x22440789,0x765c037e,0xad6801c4}},	//   _phoš, cnok_, _jksy, лайз_, 
   {{0x6e2889ab,0x8fd00184,0x00940276,0x301489ac}},	//   rheb, _ғәҙә, _митэ, _лдар, 
   {{0x9f5c0548,0x4438010a,0x80c003d4,0x7bc8007c}},	//   _intî_, _xmr_, _শৈক্, ggdu, 
   {{0x6e2889ad,0x765c89ae,0xf3f8015b,0xdf8401d3}},	//   pheb, _oksy, _আকার_, _اُمی, 
   {{0x6e280472,0x68200030,0x00000000,0x00000000}},	//   qheb, _pôdo, --, --, 
   {{0xe618006c,0x00000000,0x00000000,0x00000000}},	//   қда_, --, --, --, 
   {{0x765c159f,0xa6c889af,0xe738009d,0xbd44009f}},	//   _aksy, ллга_, гег_, _بنهي, 
   {{0xdb08037e,0xa664007b,0xe9a489b0,0xdb1801e3}},	//   _adfæ, مطرو, _лайп, ggtä, 
   {{0x7afc21e3,0x00000000,0x00000000,0x00000000}},	//   ærte, --, --, --, 
   {{0x443889b1,0x7d0400a3,0x00000000,0x00000000}},	// [a820] _pmr_, _àist, --, --, 
   {{0x4ad889b2,0x765c005b,0xa3b8007b,0xa2e4004e}},	//   _बहाव, _eksy, طائر_, йозд, 
   {{0x224489b3,0xfbac00fe,0x44380162,0x06900ef6}},	//   tnok_, _খামত, _vmr_, _ﻛﺎﻣﯩ, 
   {{0x44381aed,0xa2e402dd,0x2ff800e5,0x00000000}},	//   _wmr_, _қобд, یونگ_, --, 
   {{0xf1a819f1,0x443889b4,0x224401d3,0x7bc80174}},	//   شانه_, _tmr_, rnok_, ygdu, 
   {{0x81e82158,0x443889b5,0xe8b402e5,0xaf34001f}},	//   বাই_, _umr_, _अटैच, _እንላለ, 
   {{0x53a073b3,0x9420004e,0x00000000,0x00000000}},	//   _хасб, _эмре, --, --, 
   {{0x71c4016c,0x9ce400e5,0xdb18007c,0x00000000}},	//   _масҷ, موعے_, ngtå, --, 
   {{0x7f38001f,0x53cc02ab,0xdd0403b9,0xdb040ca8}},	//   _እንዲች, स्कश, _döşa, _àmúl, 
   {{0x20d00311,0x3fc86e92,0xfb8889b6,0x00000000}},	//   mâi_, _خدری_, шриқ_, --, 
   {{0x5f7400c6,0xb3ac0154,0x5e6000cf,0x7bc889b7}},	//   _طائر, _চামড়, _ىچبە, rgdu, 
   {{0x5d840491,0x9cc81e76,0xd37808a8,0x7e700345}},	//   _الإل, _быка_, טריט, _تۆبڵ, 
   {{0x20d00042,0xea98002b,0x00000000,0x00000000}},	//   nâi_, _āṅ_, --, --, 
   {{0x96e85884,0x37f80304,0x00000000,0x00000000}},	//   льба_, шегэ_, --, --, 
   {{0x50180302,0x20d00042,0x8bd4011a,0x00000000}},	//   נולו, hâi_, _לוגו_, --, 
   {{0x20d00124,0x86980108,0xf5980395,0x00000000}},	//   kâi_, стёт_, рващ_, --, 
   {{0x3a280280,0x38c802f2,0xd7e4187f,0x00000000}},	// [a830] _ilap_, _ئابی_, _ліно, --, 
   {{0x3ce01533,0xb4e82ce1,0x97a489b8,0xb4b866eb}},	//   _कहने_, _मनी_, _урил, _घटी_, 
   {{0x9f5c0085,0x30c400cc,0x00000000,0x00000000}},	//   _motó_, _এনেস, --, --, 
   {{0x9f5c1132,0x00000000,0x00000000,0x00000000}},	//   _lotó_, --, --, --, 
   {{0x61440075,0xdb08005c,0xca7c010f,0x00000000}},	//   يىمە, _udfæ, אנאט, --, 
   {{0x3a2889b9,0xd5bc005f,0x41744144,0x9f5c0407}},	//   _llap_, žādu_, سانس, _notó_, 
   {{0xb4e82e1e,0xf1d00137,0xf3180354,0x00000000}},	//   _मनु_, _жөлө, _товш_, --, 
   {{0x823489ba,0xa280036b,0x0d340023,0x237c01d3}},	//   _فرقا, _قیلو, _እትፈል, _útja_, 
   {{0x9f5c0137,0xdcac104b,0x1df401d5,0x00000000}},	//   _botó_, نىي_, تکلب_, --, 
   {{0x2ca8003d,0x9f5c00cf,0x3a2889bb,0xaba808ca}},	//   _ħadd_, _cotó_, _alap_, швоз_, 
   {{0x7d040003,0xbfb4007b,0x800407ee,0x00000000}},	//   _ġise, _رحلت, _эчте, --, 
   {{0x3a2889bc,0x7d7400e5,0xe8f80835,0x00000000}},	//   _clap_, _کامط, алм_, --, 
   {{0xa3a81b77,0x9f5c01ed,0x6ec017ee,0xa3e83885}},	//   _गजल_, _fotó_, रंकु, _मसल_, 
   {{0xeb980348,0x3a2889bd,0x307800c8,0x68440816}},	//   _тик_, _elap_, יאָנ, інва, 
   {{0x3a283b08,0x98a8005f,0xd84001ef,0x442400ef}},	//   _flap_, ājās_, _syčí_, _ēm_, 
   {{0x442c0042,0x5ac80244,0xa524004e,0x00000000}},	//   _ŷd_, _ئاوێ_, омбд, --, 
   {{0x3ea0098d,0xa708015b,0x09b000eb,0xe3a8005a}},	// [a840] ćiti_, রনেম_, _কাপা, икад_, 
   {{0x7d0400c6,0xa6e47863,0x37c003d4,0x9c8000d7}},	//   _áise, _джол, শ্বৰ, _účta, 
   {{0x316c030a,0x00000000,0x00000000,0x00000000}},	//   _azez_, --, --, --, 
   {{0xdb08045f,0x20d089be,0x2d98030a,0xd840022a}},	//   _befê, tâi_, ñsel_, _tyčí_, 
   {{0x9f5c011c,0x660401f4,0x00000000,0x00000000}},	//   _notò_, _inkk, --, --, 
   {{0xd12c42b5,0x19ac0131,0x33d489bf,0xdbc40037}},	//   خمه_, _ﻳﯩﻠﻠ, _ніст, löök, 
   {{0x316c005a,0x73f8008f,0x6ec00073,0x2a7002f0}},	//   _ezez_, _פּשו, रंगु, _ohyb_, 
   {{0x629c89c0,0x2a700042,0xd02000d1,0x00000000}},	//   mppo, _nhyb_, змәй, --, 
   {{0x629c02f6,0x9f5c89c1,0x6008014b,0x00000000}},	//   lppo, _potó_, _кнам_, --, 
   {{0xa0682a8b,0x629c89c2,0xdee489c3,0x3a282517}},	//   _таза_, oppo, _мози, _slap_, 
   {{0x60c0143a,0x9f5c0407,0x3a28007f,0x5f4457be}},	//   lrom, _votó_, _plap_, _بنال, 
   {{0x0dc434da,0x9f5c5490,0x629c0869,0x2a7019b3}},	//   _души_, _fotò_, ippo, _chyb_, 
   {{0x9f5c89c4,0x60c089c5,0xc98489c6,0xb4e82de3}},	//   _totó_, nrom, дури, _मने_, 
   {{0x6604023a,0x60c0021c,0xa3a8000d,0x0bf00064}},	//   _ankk, irom, _गड़ल_, _опію, 
   {{0x60c089c7,0x3a2801d3,0x6fcc2cbb,0x5a7001f0}},	//   hrom, _tlap_, _सासू, _оғох, 
   {{0x60c003c6,0x349407dd,0x7a2c0225,0x3a2822d0}},	//   krom, заар, _bûte, _ulap_, 
   {{0x6b8c00ac,0x60c0110c,0x938800d8,0x00000000}},	// [a850] _şagi, jrom, асеа_, --, 
   {{0x60c089c8,0x932489c9,0x66040108,0x00000000}},	//   drom, يران, _enkk, --, 
   {{0x60c000c7,0x00000000,0x00000000,0x00000000}},	//   erom, --, --, --, 
   {{0x60c089ca,0x7a2c002d,0x717800b1,0xcb100a1e}},	//   from, _fûte, ббер_, ולע_, 
   {{0x629c20ac,0xdb0801c7,0x01080372,0xae082cfd}},	//   appo, _befë, قتوو_, वासन_, 
   {{0xd3e02c6c,0x81e80154,0x00000000,0x00000000}},	//   _تقسی, বাগ_, --, --, 
   {{0x60c089cb,0xb8fc0135,0x007800d1,0x349401a9}},	//   arom, _ལད_, _ﺧﻮﺗﯘ, _фаҳр, 
   {{0x15cc0150,0x00000000,0x00000000,0x00000000}},	//   _ﯗﻧﺪﻩ, --, --, --, 
   {{0x60c089cc,0xb4e800dc,0x00000000,0x00000000}},	//   crom, _मनो_, --, --, 
   {{0x7ff40220,0xdb080221,0x5fd0466d,0x00000000}},	//   _يسلا, _gefë, _सायल, --, 
   {{0xd1f4044e,0xab647036,0xd598037e,0x09b00154}},	//   _ጋንታ_, явол, _cmに_, _কাবা, 
   {{0x9f5c02e8,0xed3401c0,0xbdf85712,0x1fc40154}},	//   _totò_, _нэлэ, _ورنا_, _এসএস, 
   {{0xdb08033b,0x00000000,0x00000000,0x00000000}},	//   _lefè, --, --, --, 
   {{0x3ce0068f,0x7a2c000f,0xeab0007b,0x00000000}},	//   _कहते_, _rûte, _كعب_, --, 
   {{0x09b0015b,0xe5a489cd,0xea9489ce,0xd59800b5}},	//   _কাঠা, зиби, _эшлэ, _kmと_, 
   {{0x60c00158,0x64bc0356,0xdb1c007c,0xdb3400d9}},	//   yrom, hăiţ, åvån, _מנצח_, 
   {{0xc3300075,0xd598037e,0xd83c0427,0x60c0022e}},	// [a860] ھەر_, _mmと_, ščah_, xrom, 
   {{0xc3301823,0xe12401c6,0xdbc40037,0xe8700116}},	//   پەر_, үмжи, söök, _سۆزگ, 
   {{0x629c20ac,0xb78000d1,0x60c00356,0x23340124}},	//   uppo, _ағри, wrom, чхар, 
   {{0x26c8234f,0xdb0889cf,0x6604014b,0x6fc80412}},	//   mubo_, _defè, _unkk, _राउं, 
   {{0xa06889d0,0x26c889d1,0x518089d2,0x60c089d3}},	//   бада_, lubo_, нуша, urom, 
   {{0x25b00067,0x00000000,0x00000000,0x00000000}},	//   layl_, --, --, --, 
   {{0x60c089d4,0x645c89d5,0x26c889d6,0x6264027a}},	//   srom, mopi, nubo_, _فارق, 
   {{0x60c089d7,0x9f5c0c67,0x63ac0158,0xd598037e}},	//   prom, _antã_, _hebn, _cmと_, 
   {{0x628c89d8,0x26c842c9,0x63ac007c,0xd12c0014}},	//   _hubo, hubo_, _kebn, _یمہ_, 
   {{0x645c89d9,0x26c889da,0x92dc0c58,0x65640fac}},	//   nopi, kubo_, তিৰ_, _mykh, 
   {{0x628c89db,0x26c800d2,0xb4e827c6,0xdb0800e5}},	//   _jubo, jubo_, _मन्_, _kefé, 
   {{0x645c89dc,0x63ac89dd,0xb5f00241,0x00000000}},	//   hopi, _lebn, _ojúọ, --, 
   {{0x645c89de,0x62984056,0x6d5c04cc,0x00000000}},	//   kopi, _étof, üsat, --, 
   {{0xb8f489df,0x645c89e0,0x63ac5732,0x628c0942}},	//   _हम_, jopi, _nebn, _oubo, 
   {{0x26c831fa,0x628c89e1,0xd5b889e2,0x25b0058a}},	//   gubo_, _nubo, йса_, fayl_, 
   {{0xdb0889e3,0xee48004d,0x89d80050,0x56080154}},	//   _refè, hẽn_, _ٹوٝر_, রস্ক_, 
   {{0x628c0129,0x645c01f4,0xb42400e5,0x00000000}},	// [a870] _aubo, fopi, وٹرو, --, 
   {{0x628c89e4,0x26c889e5,0x6a500270,0x97a40276}},	//   _bubo, bubo_, māfa, _эрил, 
   {{0x26c802e8,0x628c7917,0x926889e6,0x6a500421}},	//   cubo_, _cubo, брда_, lāfa, 
   {{0x628c04b9,0x25b001d9,0x00000000,0x00000000}},	//   _dubo, cayl_, --, --, 
   {{0x645c89e7,0xdb0889e8,0x628c89e9,0x544000d1}},	//   bopi, _defé, _eubo, _كۆرك, 
   {{0x628c037e,0xf4080150,0x6f4400f1,0x764c308e}},	//   _fubo, _بيسى_, وږان, lnay, 
   {{0x628c19a0,0x764c01d9,0xaf34001f,0x81e80011}},	//   _gubo, onay, _እንመለ, বাজ_, 
   {{0x720407d6,0x5f900184,0x63ac0e3c,0x712413d7}},	//   _تورم, ниәт, _zebn, _قىزم, 
   {{0x9f5c2508,0x764c89ea,0x628c89eb,0x6290005f}},	//   _entà_, inay, _zubo, ējoš, 
   {{0x628c07d6,0x764c89ec,0x00000000,0x00000000}},	//   _yubo, hnay, --, --, 
   {{0x764c0548,0xec68010b,0x26c8058a,0x00000000}},	//   knay, йрүк_, xubo_, --, 
   {{0xa96889ed,0x645c89ee,0xb0d0012a,0xcf2c510c}},	//   жима_, zopi, _समाग, ışım_, 
   {{0x645c89ef,0x764c01d9,0x6a500618,0x888401d5}},	//   yopi, dnay, gāfa, нғил, 
   {{0xaac489f0,0x66e489f1,0x26c889f2,0x645c02c4}},	//   _विपक, мога, tubo_, xopi, 
   {{0x186489f3,0x25b00280,0x6564000f,0x764c0009}},	//   фари_, tayl_, _sykh, fnay, 
   {{0x628c89f4,0x764c89f5,0x645c89f6,0x6aa00165}},	//   _rubo, gnay, wopi, mplf, 
   {{0x628c0bb8,0x26c889f7,0xdb0889f8,0x154089f9}},	// [a880] _subo, subo_, _refé, ветм, 
   {{0x764c01d9,0x628c0793,0x80c401ad,0x25b089fa}},	//   anay, _pubo, _रिबे, sayl_, 
   {{0x26c815fa,0x764c3011,0x6304009a,0x63ac022e}},	//   qubo_, bnay, بوال, _vebn, 
   {{0x63ac89fb,0x25a40882,0x764c0014,0x6dc0063f}},	//   _webn, ṛṣṭa, cnay, ịaji, 
   {{0x645c89fc,0x63ac89fd,0x628c0784,0x6f0003ac}},	//   popi, _tebn, _wubo, _arlc, 
   {{0x645c0784,0xe3b00553,0x66140108,0x00000000}},	//   qopi, _جرح_, ljyk, --, 
   {{0x628c1c06,0x6f0001ab,0xd598037e,0xdb080248}},	//   _uubo, _crlc, _mmの_, _tefé, 
   {{0x682000d2,0x224005d5,0x4e7402eb,0xbd180108}},	//   _gôdv, _ökk_, وحيد_, зжих_, 
   {{0x86480092,0x00000000,0x00000000,0x00000000}},	//   _የጥናት, --, --, --, 
   {{0x9f5c03b2,0x7b1410d9,0x5f7400f7,0x7afc01bf}},	//   _entá_, едох, _قاار, ærto, 
   {{0x764c89fe,0x62980798,0x00000000,0x00000000}},	//   ynay, _étod, --, --, 
   {{0x7a2c002d,0x6a500b23,0xdca401d5,0x764c058a}},	//   _bûta, tāfa, _жади, xnay, 
   {{0x7e6089ff,0x7bdc0037,0xcd3001e2,0x6d9c0248}},	//   momp, õrus, _لروب, _ṣagb, 
   {{0x7e608a00,0xd598037e,0xed4c0050,0x661400e4}},	//   lomp, _cmの_, _چھی_, ejyk, 
   {{0x167002dd,0x764c8a01,0x00000000,0x00000000}},	//   кқор, tnay, --, --, 
   {{0x7e601311,0xf1b80122,0x66140023,0x1b0001c6}},	//   nomp, _koše_, gjyk, _зүүн, 
   {{0x44448a02,0x764c8a03,0x798c8a04,0x57a401a9}},	// [a890] fi_, rnay, _igaw, _ошна, 
   {{0x7e608a05,0x3f8c003e,0x764c8a06,0x78ac8a07}},	//   homp, _ngdu_, snay, _iwav, 
   {{0xf1b804b9,0x798c009a,0x78ac05b8,0xa2c00075}},	//   _loše_, _kgaw, _hwav, ләтк, 
   {{0x44448a08,0x32081bb7,0x78ac8a09,0x3e6800d2}},	//   ai_, ñay_, _kwav, bûti_, 
   {{0x44448a0a,0x0ef4068f,0x798c00ec,0x7e608943}},	//   bi_, ंट्स_, _mgaw, domp, 
   {{0x78ac8a0b,0x69d401ad,0x7c28007c,0xefb000e5}},	//   _mwav, _भाभी, jkdr, ایاگ, 
   {{0x78ac8a0c,0x798c037e,0x7e6006d9,0x00000000}},	//   _lwav, _ogaw, fomp, --, 
   {{0x798c8a0d,0xae0802ab,0x7e608a0e,0x78ac401f}},	//   _ngaw, वाइन_, gomp, _owav, 
   {{0x78ac0943,0xac848a0f,0xc10400f1,0xaa440014}},	//   _nwav, нгил, _ټولي, ہندى, 
   {{0x798c8a10,0x2ee4300b,0x38ac01fa,0xd9c400cc}},	//   _agaw, _tplf_, džr_, ষ্মম, 
   {{0x7e608a11,0x6f000076,0x9c800419,0x00000000}},	//   bomp, _urlc, áčal, --, 
   {{0x78ac8a12,0x7e608a13,0x00000000,0x00000000}},	//   _bwav, comp, --, --, 
   {{0x9c8009a8,0xa368022e,0xaa44013d,0x6aa002d0}},	//   ščal, nfеr, _җепл, splf, 
   {{0x7c288a14,0x6e284c2e,0x798c8a15,0x3ce000e4}},	//   ckdr, lkeb, _egaw, _äiva_, 
   {{0x4444013a,0x2edc12eb,0x78ac0b6f,0xaa44188c}},	//   vi_, _महोत, _ewav, _пекл, 
   {{0x44448a16,0x798c0083,0x66e402a9,0x00000000}},	//   wi_, _ggaw, моҳа, --, 
   {{0x69d401aa,0x78ac8a17,0x6a501140,0xf66400f7}},	// [a8a0] _icye, _gwav, lāfo, тетү, 
   {{0x44448a18,0x68f4014b,0x7e608a19,0x394c056a}},	//   ui_, _isyd, zomp, úese_, 
   {{0x78ac1aa1,0xa68405c1,0x6e280e38,0x7e608a1a}},	//   _zwav, _плод, kkeb, yomp, 
   {{0x3ce0033d,0x7e60009a,0xdb0400bc,0x64a43d89}},	//   _कहले_, xomp, áméh, _пама, 
   {{0x44448a1b,0xa0688a1c,0x563400c8,0xf1d00950}},	//   pi_, пада_, _טאטע_, _हारन, 
   {{0x44448a1d,0xf1b801fa,0x3e4c012c,0x7e608a1e}},	//   qi_, _roše_, měti_, womp, 
   {{0x7e608a1f,0xdb0804ce,0x27f80311,0xf1b801ef}},	//   tomp, _udfø, _mapn_, _soše_, 
   {{0x5fd00490,0xfbac0154,0x00000000,0x00000000}},	//   _सावल, _খাইত, --, --, 
   {{0x7e608a20,0x02e00316,0xa0c411e6,0x6d5c00e4}},	//   romp, _नहुन, _سياو, üsap, 
   {{0x7e608a21,0x69d40223,0x78ac8a22,0x87e8025c}},	//   somp, _acye, _rwav, _སིཊཡ, 
   {{0x78ac02c4,0x7c2801a4,0x101401d3,0x8fa08a23}},	//   _swav, rkdr, _سکوں_, _сахе, 
   {{0x201c8a24,0x22448a25,0x6e284bc1,0xf1b807f5}},	//   _hoti_, niok_, ckeb, _toše_, 
   {{0x201c8a26,0xda9005f5,0x21247dec,0x999000e5}},	//   _koti_, _өглө, nyoh_, édők_, 
   {{0xf9f000bd,0x201c8a27,0xd7f84d58,0x3e4c01ef}},	//   টাইল_, _joti_, чум_, děti_, 
   {{0x201c8a28,0x68f48a29,0x09b000bd,0x2244009d}},	//   _moti_, _esyd, _কারা, kiok_, 
   {{0x201c8a2a,0x798c35f9,0x78ac8a2b,0x27f80005}},	//   _loti_, _ugaw, _twav, _eapn_, 
   {{0x78ac8a2c,0x201c022f,0x224401c4,0xb17c00d0}},	// [a8b0] _uwav, _ooti_, diok_, _obťa, 
   {{0xd3784afa,0xb4e0098b,0xd9b02f7c,0x6e28030a}},	//   пче_, _दही_, _جەڭد, zkeb, 
   {{0xd6d801ee,0x00000000,0x00000000,0x00000000}},	//   _этп_, --, --, --, 
   {{0x9264280e,0x201c0618,0x22442710,0x05a8000d}},	//   ردام, _aoti_, giok_, _छ्पब, 
   {{0x201c8a2d,0x2488004e,0x00000000,0x00000000}},	//   _boti_, _fibm_, --, --, 
   {{0x201c19f5,0xafe48a2e,0xabd801ec,0xddc00064}},	//   _coti_, токл, _ﺃﺫﻫﺎ, _chož, 
   {{0x201c8a2f,0xb3640014,0x2244005a,0xa368022e}},	//   _doti_, _شُر٘, biok_, sfеr, 
   {{0x22442c2b,0xee3806ed,0x518401c6,0x714000cf}},	//   ciok_, ќни_, _зуза, _پۉتۅ, 
   {{0x320c0050,0x69a00b9c,0xec788a30,0xdb08056a}},	//   _iney_, _क्षी, мпи_, _defí, 
   {{0x6e280ac8,0x7ff43e43,0x201c8a31,0x4f6400db}},	//   skeb, _مسما, _goti_, _كااف, 
   {{0xa9a48a32,0x98a400b0,0xd9bc012d,0xdb0401e1}},	//   кинд, _ānā_, ्लूट, _òmìm, 
   {{0x201c8a33,0x68f4007c,0xaa44010b,0x8d7433d2}},	//   _zoti_, _psyd, темл, _كاشا, 
   {{0x201c055a,0x9f5c02f6,0xdd140419,0x6c5401af}},	//   _yoti_, _entä_, _päťm, _иткє, 
   {{0x69a01cb7,0x6d588a34,0x9f5c0421,0x20080428}},	//   _क्री, _ixwa, _totô_, _òbit_, 
   {{0x320c8a35,0x6d5802d0,0x00000000,0x00000000}},	//   _oney_, _hxwa, --, --, 
   {{0x21240429,0x3e4c0118,0xd5ac0014,0x69d43b21}},	//   yyoh_, těti_, ٲفل_, _ucye, 
   {{0xdb080428,0x2244005a,0xdcec00cd,0xf77001e2}},	// [a8c0] _gefâ, viok_, _ādīn, لاې_, 
   {{0x23288a36,0x320c090e,0x6d5803ac,0x00000000}},	//   мози_, _aney_, _mxwa, --, 
   {{0x65c40022,0x2244005a,0x6d5802d0,0x7d040135}},	//   _ибна, tiok_, _lxwa, _ġism, 
   {{0x201c8a37,0x722802bf,0x6d583cf7,0x00000000}},	//   _soti_, нців_, _oxwa, --, 
   {{0x201c8a38,0xdb081709,0x22448a39,0xa6dc00eb}},	//   _poti_, _refí, riok_, ডিওট, 
   {{0x716401ec,0x22440086,0xd0040fca,0x00000000}},	//   دامك, siok_, кече_, --, 
   {{0x62641d18,0x201c8a3a,0x6d588a3b,0x224408cd}},	//   _авва, _voti_, _axwa, piok_, 
   {{0x201c8a3c,0x69a08a3d,0x6d5802d0,0x3df400d8}},	//   _woti_, _क्ली, _bxwa, узис, 
   {{0x201c8a3e,0x428800d1,0x00000000,0x00000000}},	//   _toti_, ﺭﯛﻣﭽ, --, --, 
   {{0x61e08a3f,0x26c809a8,0x6d5803ac,0x201c0393}},	//   lfol, krbo_, _dxwa, _uoti_, 
   {{0x61e0052f,0x6ec45821,0x6d583020,0x29008a40}},	//   ofol, _متنق, _exwa, evka_, 
   {{0xd90c8a41,0x61e08a42,0x6d5802d0,0x2d980489}},	//   قیب_, nfol, _fxwa, ñset_, 
   {{0x61e041ec,0x2f8400fb,0x00000000,0x00000000}},	//   ifol, _иҙән_, --, --, 
   {{0xc7c40588,0xf1b800f3,0x8c402eca,0x00000000}},	//   исси, _moša_, _кече, --, 
   {{0xf1b8098d,0x61e08a43,0x80cc09bb,0x6d5802d0}},	//   _loša_, kfol, _समझे, _zxwa, 
   {{0x61e08a44,0x2e30032e,0x00000000,0x00000000}},	//   jfol, _káfa_, --, --, 
   {{0x25a428f2,0x49b805d9,0xf1b80010,0x26c801e4}},	// [a8d0] ñola_, _شايد_, _noša_, arbo_, 
   {{0x61e08a45,0x84340212,0x80cc0073,0x645000b8}},	//   efol, анує, _समजे, _ākiñ, 
   {{0xdca4313e,0xd764215c,0x00000000,0x00000000}},	//   _گى_, _شەرى_, --, --, 
   {{0x61e012ed,0x2c788a46,0x31344c87,0x00000000}},	//   gfol, mède_, леер, --, 
   {{0xdca48a47,0x320000bc,0x78bc0efa,0x2c788a48}},	//   _دى_, ěhy_, nssv, lède_, 
   {{0x4fc48a49,0x61e00421,0xf1b8107d,0x6d5803ac}},	//   тсда, afol, _doša_, _rxwa, 
   {{0x78bc074d,0x8384023a,0xb8d40327,0x9f4c007f}},	//   hssv, _выте, _ཝས_, nefè_, 
   {{0xc69400c8,0xd1b80736,0x78bc7c1d,0x24e40154}},	//   סאפ_, _زارا_, kssv, নিরহ, 
   {{0xf1b836dd,0x315402d5,0x705841b9,0x00000000}},	//   _goša_, _сваё, _заар_, --, 
   {{0xcee802dd,0x316c009a,0x6e943993,0xcec4010b}},	//   _يران_, _iyez_, _бижу, _ащди, 
   {{0xab28136b,0xeab80e3b,0xee480022,0x7f948a4a}},	//   хона_, эйн_, hẽi_, _тахх, 
   {{0x8bf0015b,0xa140005f,0x2d980790,0x6d58035a}},	//   জাইন_, _šķid, ıses_, _txwa, 
   {{0xfd108a4b,0xf8b407dd,0x6d5801f0,0xaac400dc}},	//   _وجه_, аҩы_, _uxwa, _विवक, 
   {{0x7b448a4c,0x00000000,0x00000000,0x00000000}},	//   ائیل, --, --, --, 
   {{0xdb080086,0x61e08a4d,0x26c88a4e,0x00000000}},	//   _gefà, yfol, urbo_, --, 
   {{0x80c48a4f,0x316c0129,0x61e00076,0xdb04032e}},	//   _रिले, _oyez_, xfol, _ámál, 
   {{0x316c0007,0x61e00158,0x7d04031c,0x8af403e3}},	// [a8e0] _nyez_, vfol, _ġisk, _şəhv, 
   {{0x5fd01524,0x246800f7,0x2c780241,0x00000000}},	//   _साइल, رماپ_, bède_, --, 
   {{0x61e08a50,0x2c78004a,0x316c004a,0x21184c9a}},	//   tfol, cède_, _ayez_, کتاب_, 
   {{0x7afc8a51,0x326400d4,0x00000000,0x00000000}},	//   ærti, атів, --, --, 
   {{0x7a2c002d,0x94e41037,0x60241d4d,0x00000000}},	//   _bûtj, _مکلف_, лдда, --, 
   {{0x442c0086,0xf1b8009b,0x2e3002d2,0x00000000}},	//   _ôd_, _voša_, _ráfa_, --, 
   {{0x316c009f,0x61e0036e,0x1ea815f2,0x6fd4003b}},	//   _eyez_, pfol, راثي_, річц, 
   {{0x727800d8,0x2e30032e,0x3d100118,0x00000000}},	//   _асус_, _páfa_, तमले_, --, 
   {{0x62808a52,0xd83c151c,0x00000000,0x00000000}},	//   mmoo, ščih_, --, --, 
   {{0x628001d9,0x11440276,0x2d980489,0x9984031c}},	//   lmoo, _спуй_, ñser_, ġiża_, 
   {{0x62808a53,0x35a400e1,0x3ce00037,0x00000000}},	//   omoo, गुड़, _कहके_, --, 
   {{0xaac41d03,0xd35400d9,0x00000000,0x00000000}},	//   _विरक, ריטי_, --, --, 
   {{0xd90c8a54,0x62808a55,0x78bc0194,0xd7c4023b}},	//   سید_, imoo, ussv, лёво, 
   {{0x62808a56,0xee480124,0x38c802f2,0x00000000}},	//   hmoo, vẽi_, _یاخی_, --, 
   {{0xae088a57,0x6c68121e,0xa3c869de,0x2c100037}},	//   वाचन_, _جلوہ_, ोलन_, तारू_, 
   {{0xadf8084a,0x62800218,0x69d801d3,0x00000000}},	//   ्ययन_, jmoo, őter, --, 
   {{0xd3a40184,0x62800548,0x73d80137,0x00000000}},	// [a8f0] греп, dmoo, кдар_, --, 
   {{0x62808a58,0x2c780561,0xee4800e4,0x04c80f17}},	//   emoo, pède_, rẽi_, اولي_, 
   {{0x316c1529,0x62800549,0x506401b9,0x03580166}},	//   _syez_, fmoo, қтда, гүрә_, 
   {{0x316c1529,0x62800050,0x43940818,0xd26800be}},	//   _pyez_, gmoo, _ҳарс, رصان_, 
   {{0x62984aee,0xc2e401b9,0xefc80023,0xdb04032e}},	//   _éton, _қўри, _ጽሩይ_, _ámæl, 
   {{0x92b48a59,0x439405f5,0xbb64037e,0x3a38020c}},	//   _محرا, _гарс, _masケ_, hhsp_, 
   {{0xc7d8008d,0xbfb80a8e,0xab1001e1,0x2f880022}},	//   אווי_, اطها_, _lóòó_, тәан_, 
   {{0x62800067,0x00000000,0x00000000,0x00000000}},	//   cmoo, --, --, --, 
   {{0x316c009a,0xc0c8030d,0x00000000,0x00000000}},	//   _uyez_, _бухе_, --, --, 
   {{0x614404a9,0x201801f4,0x00000000,0x00000000}},	//   _ئىكە, öpit_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa2d41f5e,0x00000000,0x00000000,0x00000000}},	//   मंत्, --, --, --, 
   {{0x6d980118,0x00000000,0x00000000,0x00000000}},	//   rťač, --, --, --, 
   {{0x5d38025d,0x7e640010,0xa6c801a9,0x00000000}},	//   _בתנא, čipe, клга_, --, 
   {{0x62808a5a,0x7d04025c,0xa9a47577,0x00000000}},	//   ymoo, _ġisi, _кийд, --, 
   {{0x6a747d3d,0xdb08005c,0x62800009,0xc61400cc}},	//   máfo, _befæ, xmoo, সস্থ_, 
   {{0xa4448a5b,0x64c48a5c,0x00000000,0x00000000}},	// [a900] анад, شيال, --, --, 
   {{0x628001ab,0xa2e40026,0x00000000,0x00000000}},	//   wmoo, иозд, --, --, 
   {{0xd24c212c,0x7a2c000f,0x2bdc298e,0x62808a5d}},	//   ژنم_, _bûth, _माना, tmoo, 
   {{0x62808a5e,0x6a5072dc,0xf1b81710,0x00000000}},	//   umoo, fāfi, _došo_, --, 
   {{0xc1780166,0x00000000,0x00000000,0x00000000}},	//   уҗа_, --, --, --, 
   {{0x62808a5f,0x7d04007b,0x00000000,0x00000000}},	//   smoo, _áisi, --, --, 
   {{0xdef81367,0xe0d00014,0x0f200022,0xd04000db}},	//   тыл_, _ژٲر_, жьым, تپوي, 
   {{0x2fc40005,0x81e400bd,0xa23401c6,0x00000000}},	//   _edlg_, _ভোর_, _тэгш, --, 
   {{0x10a0154e,0x59a409b4,0xe0d80229,0x21740114}},	//   _митн, _क्षर, _шва_, _ђубр, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb188a60,0x5bb41b51,0x97c400f2,0x00000000}},	//   matë, _आजीव, یتآم, --, 
   {{0xdb18036e,0x9f5c0200,0x00000000,0x00000000}},	//   latë, _latë_, --, --, 
   {{0x98480801,0xa2d417c6,0xec3400ec,0x9d188a61}},	//   вява_, मूत्, _ڏونگ, _جزاء_, 
   {{0xdb185993,0x2bdc2d93,0x9f5c02d3,0xad240214}},	//   natë, _माया, _natë_, _درمو, 
   {{0x87041413,0xdb1800d2,0xa734104e,0x8af406be}},	//   ояте, zatê, бдрә, _şəvv, 
   {{0xd59804ce,0x9f5c00d8,0x2c780ba1,0x7afc05ac}},	//   _mmで_, _patê_, mèda_, ærtu, 
   {{0xdb1802d3,0xf48400dd,0xd7e402bf,0xadf80034}},	// [a910] katë, مائی, _кіно, ्यतन_, 
   {{0x81e4009e,0x93a48a62,0xdb18036e,0x00000000}},	//   _ভোল_, ршад, jatë, --, 
   {{0xed5804b9,0x9f5c02d3,0xdb1802d3,0x2c78067c}},	//   maže_, _datë_, datë, nèda_, 
   {{0xed5808a4,0xb1148a63,0x00000000,0x00000000}},	//   laže_, ймеш, --, --, 
   {{0x7758044e,0x764c003e,0x81c80212,0x83cc0ef6}},	//   _ወትሃደ, miay, ргів_, _ﻗﯘﺭﺳ, 
   {{0xdb188a64,0x73c400c6,0x764c8a65,0xfccc0092}},	//   gatë, _ديسم, liay, _በሥጋ_, 
   {{0x752c8a66,0xd59804ce,0xda0401f9,0x00000000}},	//   lyaz, _cmで_, षयात_, --, 
   {{0x764c8a67,0xdb188a68,0x31340353,0x551800bc}},	//   niay, patê, _лебр, _नपाए_, 
   {{0xeb987d0b,0x9f5c0699,0xdb188a69,0xf1b80064}},	//   лип_, _latè_, latè, _ieš_, 
   {{0x6a743a6c,0x4ee400d6,0x290c01ef,0x00000000}},	//   táfo, _відз, _čfa_, --, 
   {{0x9f5c020c,0x6b640a93,0x764c37bf,0x1ee81fe4}},	//   _natè_, скна, kiay, _مولی_, 
   {{0x764c5f3a,0x1f240014,0xf1b85a54,0x752c0337}},	//   jiay, _دِمہ, _ješ_, kyaz, 
   {{0x3de0009e,0x764c4e7e,0x5e6401ec,0x00000000}},	//   _মোকল, diay, _اننە, --, 
   {{0xf1b81591,0x752c7d39,0xdb085df7,0xdb18020c}},	//   _leš_, dyaz, _befä, katè, 
   {{0x752c0083,0xe5a400d1,0x9f5c0200,0x00000000}},	//   eyaz, йиви, _ratë_, --, 
   {{0x9f5c007f,0xf1b88a6a,0xe9d88a6b,0xdb180023}},	//   _datè_, _neš_, _ски_, zatë, 
   {{0xa3e805f5,0xe3b000c6,0xe458010b,0xdb18002e}},	// [a920] лдаа_, كرا_, гжа_, yatë, 
   {{0x8ccc068f,0x7a2c002d,0xfccc0092,0xa7b4033a}},	//   _दिनो, _rûti, _በእጅ_, _усиј, 
   {{0xdb088a6c,0xb9e0067d,0xadf81025,0x764c53d5}},	//   _gefä, _እታ_, ्यान_, biay, 
   {{0x752c8a6d,0xf1b80841,0x764c8a6e,0x5b5400df}},	//   byaz, _ceš_, ciay, זשען_, 
   {{0x9c80151c,0x752c00ca,0xdb180023,0xc3c400c7}},	//   ščil, cyaz, tatë, _мҩал, 
   {{0x33d410f5,0x9f5c3386,0xdb18007f,0xdb08013d}},	//   _міст, _haté_, batè, _yefä, 
   {{0xdb1802d3,0x3de003d4,0x9f5c0098,0x2c1002e5}},	//   ratë, _মোগল, _katé_, ़ाईं_, 
   {{0x91e08a6f,0x934000db,0xdb180200,0x00000000}},	//   _носе, _энсе, satë, --, 
   {{0x9f5c03a0,0xbd4400c6,0xdb188a70,0xad9c0210}},	//   _maté_, تنظي, patë, wdźc, 
   {{0x60c08a71,0xdb180023,0x44380072,0xa3c80254}},	//   msom, qatë, _jlr_, ोलि_, 
   {{0x9f048a72,0xddc00010,0x8d7000d1,0x752c03e0}},	//   _دواو, _ekoš, ياۋا, zyaz, 
   {{0x60c08a73,0x9f5c8a74,0x1e848a75,0xdb1802f0}},	//   osom, _naté_, _улем, naté, 
   {{0x60c08a76,0x63bc8a77,0xa3c87ff3,0x9f5c0214}},	//   nsom, kapn, ोला_, _satè_, 
   {{0x60c00dda,0x9f5c011c,0x63bc003e,0xdb188a78}},	//   isom, _patè_, japn, haté, 
   {{0x63bc50f9,0xcb0400b2,0x9f5c01e1,0x2bdc4a18}},	//   dapn, _هيون_, _baté_, _माता, 
   {{0x443801ab,0x60c08a79,0xed58231e,0x752c8a7a}},	//   _alr_, ksom, saže_, tyaz, 
   {{0x44388a7b,0x9f5c8a7c,0xf1b80010,0x60c0005c}},	// [a930] _blr_, _daté_, _reš_, jsom, 
   {{0x63bc4460,0x60c08a7d,0x44388a7e,0xdb08014a}},	//   gapn, dsom, _clr_, _tefä, 
   {{0xd3788a7f,0x9f5c00e8,0x60c0058a,0xf1b809a8}},	//   уча_, _faté_, esom, _peš_, 
   {{0xb9e0069c,0x9f5c7dc1,0xdb1887ef,0x443817e2}},	//   _እኳ_, _gaté_, gaté, _elr_, 
   {{0x60c08a80,0xf1b87e96,0xd1482f84,0x8b04013a}},	//   gsom, _veš_, دشان_, _koří, 
   {{0xdb180502,0xcfdc2b1b,0x63bc00d5,0x00000000}},	//   patè, _যোজন, capn, --, 
   {{0x60c01418,0xf1b87edf,0xdb181155,0x8b0401ef}},	//   asom, _jošk_, baté, _moří, 
   {{0x7c380c86,0xdb18154f,0x60c001bf,0xf1b800ef}},	//   _alvr, caté, bsom, _mošk_, 
   {{0xed588a81,0x7dc410fe,0xad240075,0x60c08a82}},	//   роп_, ستيك, زىدى, csom, 
   {{0xc1000116,0x0fe00209,0x00000000,0x00000000}},	//   _чүшл, _хөдү, --, --, 
   {{0x4084023b,0x2ca80003,0x6e98014b,0x00000000}},	//   _хутб, _ħadu_, _твер_, --, 
   {{0x63bc02f0,0x7ed4029e,0xde4400ec,0x00000000}},	//   zapn, _رزما, _وڌيو_, --, 
   {{0x63bc3223,0xcd287677,0x9f5c004a,0xbf700022}},	//   yapn, _حسان_, _raté_, _оқәы, 
   {{0x6e380218,0xdb1801ed,0x9f5c0214,0x2cac26e7}},	//   _hlwb, zaté, _saté_, mped_, 
   {{0x2cac8a83,0x44381263,0x00000000,0x00000000}},	//   lped_, _rlr_, --, --, 
   {{0x2cac232c,0x60c0003b,0xb0c81b87,0x41d807f7}},	//   oped_, ysom, _रिंग, _डाइस, 
   {{0xe3b87736,0x44382d26,0x63bc8a84,0x3d0c00ab}},	// [a940] иба_, _plr_, tapn, ़िये_, 
   {{0x2aec35e8,0xa3b81d93,0x6b8c010e,0x78a80332}},	//   _जहाँ_, شائر_, _şagy, íeve, 
   {{0x60c004cc,0xf1a804d3,0xdb182056,0xf1b81710}},	//   wsom, ڵانه_, taté, _gošk_, 
   {{0xe4d85175,0x63bc8a85,0x61f4022e,0x00000000}},	//   _پوست_, sapn, еyla, --, 
   {{0x2088006c,0xdb188a86,0x44381590,0xdb08002d}},	//   айди_, raté, _tlr_, _befû, 
   {{0x60c08a87,0x443807c5,0xdb180077,0xe2a831f6}},	//   rsom, _ulr_, saté, _نارن_, 
   {{0xdb183386,0x2cac0b1d,0x62a02b57,0xdec80092}},	//   paté, eped_, útoč, _በቅኝ_, 
   {{0x69d408e9,0xfe7000db,0x6e380142,0x5cc47938}},	//   _भागी, رگا_, _clwb, осоз, 
   {{0xa2d42bf1,0x80c406ab,0x7d5400a7,0x9c700055}},	//   मूर्, _रिटे, явих, _apāṭ, 
   {{0x2ca80135,0xd12c0092,0x00000000,0x00000000}},	//   _ħadt_, ኤያቸው, --, --, 
   {{0xa3e019e5,0xda7863ee,0xba1800e3,0x53980677}},	//   _धान_, иям_, ميدا_, יסיא, 
   {{0x5d684445,0x29a400c7,0x00000000,0x00000000}},	//   _кием_, зырҳ, --, --, 
   {{0x8b04012c,0xdcf86bcc,0x00000000,0x00000000}},	//   _poří, _خراش_, --, --, 
   {{0xe8ec00b2,0x5e640137,0x25b00076,0x00000000}},	//   اڻي_, _انچە, ebyl_, --, 
   {{0x0708013e,0xed588a88,0x5018011a,0x8b04013a}},	//   охти_, maža_, סולו, _voří, 
   {{0xed585a11,0x8b380375,0x00000000,0x00000000}},	//   laža_, _כתוצ, --, --, 
   {{0x9f4c0109,0x00000000,0x00000000,0x00000000}},	// [a950] hefà_, --, --, --, 
   {{0xf1b805be,0xed580f03,0x80c4098a,0x25b0062c}},	//   _tošk_, naža_, _रिजे, abyl_, 
   {{0x3a2801b8,0x2bdc07b7,0x25b01368,0xa2d4590f}},	//   _koap_, _मासा, bbyl_, मूल्, 
   {{0x34948a89,0x2cac06f2,0xf1b88a8a,0x00000000}},	//   _намр, yped_, _koši_, --, 
   {{0xed5800f3,0xdb1800b0,0x00000000,0x00000000}},	//   kaža_, katï, --, --, 
   {{0x35e00307,0x20d00131,0x23e00c70,0x3a288a8b}},	//   _फाड़, رقىس, _पायद, _loap_, 
   {{0x539c044e,0xf1b805ce,0x2cac0204,0x7e640010}},	//   _ውሑዳት_, _loši_, wped_, čipn, 
   {{0xa8040598,0x7a2c002d,0x2bdc0b8f,0x2cac143a}},	//   _kiñä, _mûts, _माहा, tped_, 
   {{0xf1b8000a,0x32440046,0x5f900184,0xdb04006a}},	//   _noši_, _деңг, миәт, _âmêl, 
   {{0xed58040d,0x09d40490,0x2cac8a8c,0x606000d1}},	//   _қол_, थल्य, rped_, _كۇنل, 
   {{0xad2426a2,0x2cac8a8d,0x6a500171,0x00000000}},	//   زىگى, sped_, dāfr, --, 
   {{0x2cac771c,0x2b58054e,0x00000000,0x00000000}},	//   pped_, ăsc_, --, --, 
   {{0xdc540014,0x00000000,0x00000000,0x00000000}},	//   _کرنک, --, --, --, 
   {{0x7a2c002d,0x60100139,0xeb988a8e,0x00000000}},	//   _bûts, _iñmä, _уик_, --, 
   {{0x4e1c00e1,0x3a28007c,0x00000000,0x00000000}},	//   _मचाई_, _foap_, --, --, 
   {{0x62987c71,0x3a280156,0xa8c40116,0xf5440023}},	//   _étoi, _goap_, _ейид, _መመኽነ, 
   {{0xa804008e,0x25b0062c,0x00000000,0x00000000}},	// [a960] _ciñä, rbyl_, --, --, 
   {{0xdb088a8f,0x7a2c00d2,0xe7388a90,0x00000000}},	//   _refú, _fûts, _гео_, --, 
   {{0x179825f9,0xb86426c0,0x97980375,0xe5a433cc}},	//   _לייב, _تايو, _לשיק, _нини, 
   {{0xd36c8a91,0x2934010f,0x11d400ae,0x1a9800df}},	//   دهم_, ּאַן_, كومة_, צינע, 
   {{0xe57005c6,0x6f0003ac,0xa5740014,0x66040129}},	//   _سطح_, _aslc, _رُست, _iakk, 
   {{0x66048a92,0xdb08032e,0x24b000cc,0x00000000}},	//   _hakk, _vefú, _চিপহ, --, 
   {{0x66048a93,0x9f5c8a94,0x6f000109,0xed5880b6}},	//   _kakk, _antò_, _cslc, važa_, 
   {{0x22580491,0x21a47db4,0x7e64009b,0xe8d401ec}},	//   _الرد_, _хиам, čipo, _ءﻯ_, 
   {{0x66048a95,0x644c02c4,0xe62801fb,0x69d40490}},	//   _makk, _kmbi, _độ_, _भाजी, 
   {{0x66048a96,0xf1b805be,0x3a285ff1,0x9138011a}},	//   _lakk, _roši_, _soap_, _העמק, 
   {{0x2bdc05c0,0xdb1800e4,0x00000000,0x00000000}},	//   _मारा, ratï, --, --, 
   {{0x66048400,0x0e980302,0xed588a97,0x00000000}},	//   _nakk, _השאל, saža_, --, 
   {{0x58847798,0x9f5c0228,0x644c8a98,0xed580e3c}},	//   зыва, _matí_, _ombi, paža_, 
   {{0xdb188a99,0x6604360c,0x9f5c8a9a,0xaac4085c}},	//   latí, _aakk, _latí_, _विचक, 
   {{0x66048a9b,0x9f5c00c7,0xd7f80bd6,0x6d9c0241}},	//   _bakk, _hatâ_, _һун_, _ṣaib, 
   {{0x660481f1,0xdb188a9c,0x9ba00131,0x2e30032e}},	//   _cakk, natí, _تەھى, _páfi_, 
   {{0x7ae8074d,0xd7f8030d,0x8cbc00bc,0xa804013d}},	// [a970] ltdt, _лун_, लीपो, _qiñä, 
   {{0x78ac8a9d,0x9f5c8a9e,0xb7d856a7,0xdb08332e}},	//   _itav, _patì_, _بودا_, _befø, 
   {{0x66040a4d,0xa2c03941,0x9f5c0166,0xdb188a9f}},	//   _fakk, кәтк, _batí_, katí, 
   {{0x644c8aa0,0x66048aa1,0x9f5c004e,0xdb188aa2}},	//   _embi, _gakk, _catí_, jatí, 
   {{0x2bdc2894,0xdb1819cd,0x69a01c15,0x9f4c005c}},	//   _माला, datí, कुटी, nefæ_, 
   {{0x6a745178,0x66048aa3,0x78ac009f,0x8cbc5d4f}},	//   ráfi, _zakk, _mtav, लीफो, 
   {{0x66048aa4,0xa0640022,0x00000000,0x00000000}},	//   _yakk, ьаша_, --, --, 
   {{0x78ac8aa5,0x2d9839c2,0xdb188aa6,0x8d2404a9}},	//   _otav, øse_, gatí, зниң_, 
   {{0x78ac8aa7,0x518405f5,0x2bb800c6,0x644c0042}},	//   _ntav, _хува, يادة_, _ymbi, 
   {{0x9f4c0418,0x9cb0036b,0xcf2400f7,0xc32400eb}},	//   sefá_, کمیت, _ىراي, _যেটি_, 
   {{0x78ac8aa8,0xdb1865fa,0x81e40eac,0x260c00af}},	//   _atav, batí, _ভোট_, _डफली_, 
   {{0x386000b0,0x78ac00b5,0xdb180798,0x00000000}},	//   _ajhr_, _btav, catí, --, 
   {{0x66048aa9,0xed580064,0x00000000,0x00000000}},	//   _rakk, mažo_, --, --, 
   {{0x66048aaa,0xed580219,0x7764002f,0xb8940395}},	//   _sakk, lažo_, _bxhx, ерсъ, 
   {{0xe738034b,0xe5a48aab,0x78ac01d5,0xa6940798}},	//   цев_, диби, _etav, драј, 
   {{0x644c0a2e,0x66040429,0x9f5c0124,0xed588aac}},	//   _smbi, _qakk, _hatã_, nažo_, 
   {{0x66040a71,0x64a401b9,0x00000000,0x00000000}},	// [a980] _vakk, фаза, --, --, 
   {{0x66048aad,0x29108aae,0xdb1800bc,0x644000b0}},	//   _wakk, _irya_, zatí, īoio, 
   {{0x66048aaf,0xf1b805ce,0x9f5c00cf,0xdbc80241}},	//   _takk, _lošu_, _patí_, _kòòf, 
   {{0xd00c8ab0,0x81e404c5,0x78ac00e4,0x291001e3}},	//   یلن_, _ভোজ_, _ytav, _krya_, 
   {{0x10a08ab1,0xdb185f5b,0xa068084c,0xf1b88ab2}},	//   вичн, vatí, оада_, _nošu_, 
   {{0x644c8ab3,0x710007dd,0x67240150,0xc44805af}},	//   _umbi, ыҧуа, _ءﯨﻠﯩ, _عیان_, 
   {{0xdb188ab4,0x626413ef,0x670c000d,0x2e30032e}},	//   tatí, _قارق, ाटिक_, _láfu_, 
   {{0x2910003e,0xdb180022,0xc0c40ce8,0xed580153}},	//   _orya_, hatã, _зәки, gažo_, 
   {{0xdb188ab5,0x29100083,0x217401c0,0x3c5800ee}},	//   ratí, _nrya_, _цувр, зипэ_, 
   {{0x06d41c82,0x3eac01fb,0x645c143a,0xf1b80171}},	//   _হৈছি, _ttdt_, nnpi, _došu_, 
   {{0x29108ab6,0xdb182b76,0xd00c866a,0xa3d40cb4}},	//   _arya_, patí, _خلل_, _ियन_, 
   {{0x62984056,0xdb18054e,0xd04803b9,0x00000000}},	//   _étou, tatâ, dugə, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x59d80490,0x68f00451,0xdc5401d3,0x00000000}},	//   _भाकर, اڻيء, _کرچک, --, 
   {{0x764002d5,0x29100a49,0xf1b801ef,0x00000000}},	//   ūlym, _erya_, _košt_, --, 
   {{0xda648ab7,0x29100217,0x9f5c00a3,0xf1b8310a}},	//   _تاتي, _frya_, _matà_, _jošt_, 
   {{0x78ac8ab8,0x6a740008,0xdb188ab9,0x2e3008a5}},	// [a990] _utav, gáfu, latà, _gáfu_, 
   {{0xd3788aba,0x7c80001f,0x00000000,0x00000000}},	//   оче_, _የባህል_, --, --, 
   {{0x92688abb,0x7d0001d4,0xdb1800db,0x00000000}},	//   орда_, hwms, natà, --, 
   {{0x8ccc033f,0x645c0332,0x00000000,0x00000000}},	//   _दिलो, anpi, --, --, 
   {{0xdb1805da,0x25d40375,0xed580010,0x00000000}},	//   hatà, _אורן_, važo_, --, 
   {{0xe8202e1e,0xf07401ed,0x3e4c00bc,0x00000000}},	//   माया_, ریاں_, měty_, --, 
   {{0x9f5c4a2e,0x6da400ee,0xada48abc,0xb3740023}},	//   _catà_, нийа, найл, ራዉያን_, 
   {{0x9f5c1703,0x2c788abd,0xeb98013e,0x00000000}},	//   _datà_, mèdi_, ӯии_, --, 
   {{0xb1140166,0xe82035e0,0xed5887da,0xa3d407f7}},	//   _ямаш, मामा_, ražo_, _ियम_, 
   {{0xed588abe,0xf1b800f3,0x2614012d,0x10140244}},	//   sažo_, _vošu_, _पोनी_, _تبرد, 
   {{0x62980798,0xdb1807c5,0xca780150,0xed5800c0}},	//   _étot, gatà, _ﺼﻌﻭﺩ_, pažo_, 
   {{0xade804fb,0xa9687656,0xda0400bc,0xfd1000ec}},	//   _رفتم_, зима_, षयगत_, _ھجن_, 
   {{0x2d9c05db,0x00000000,0x00000000,0x00000000}},	//   _igwe_, --, --, --, 
   {{0xdb18004e,0xf1b800ef,0xebe400db,0x00000000}},	//   batà, _košs_, _чокп, --, 
   {{0xdb188abf,0x2c78020c,0x00000000,0x00000000}},	//   catà, jèdi_, --, --, 
   {{0xd6240640,0xa3e00037,0x1a9800df,0x00000000}},	//   носе_, _धाह_, _ציפע, --, 
   {{0x29101419,0x9f5c8ac0,0xdb188ac1,0x96600276}},	// [a9a0] _urya_, _matá_, patã, укте, 
   {{0x69c48ac2,0xdb1800dd,0x645c0b4f,0x00000000}},	//   lake, latá, unpi, --, 
   {{0xe1f813d7,0x645c8ac3,0x279447b3,0x2d9c02e3}},	//   зге_, rnpi, _яшир, _ogwe_, 
   {{0x69c48ac4,0x2d9c8ac5,0xdb188ac6,0x722800d4}},	//   nake, _ngwe_, natá, мців_, 
   {{0xf1b802fb,0xdd982f16,0x26c801e3,0xb8640101}},	//   _rošt_, үши_, lsbo_, _سایو, 
   {{0x69c48ac7,0x2d9c8ac8,0xd03402bf,0xdb182942}},	//   hake, _agwe_, нзії_, hatá, 
   {{0x44448ac9,0x69c41060,0xf1b802f0,0x26c8376e}},	//   mh_, kake, _pošt_, nsbo_, 
   {{0x44448aca,0x9f5c8acb,0x69c48acc,0x7e4801ed}},	//   lh_, _catá_, jake, بستہ_, 
   {{0x44448acd,0x69c48ac2,0x40a8066d,0xd25425f9}},	//   oh_, dake, _آخری_, _נשמה_, 
   {{0x44448ace,0x39500085,0x61e08acf,0x9f4c0793}},	//   nh_, _ínsɔ_, lgol, tefä_, 
   {{0x44448ad0,0x69c4136f,0x1ea875a6,0x61e02c9b}},	//   ih_, fake, _راضي_, ogol, 
   {{0xdb188ad1,0x2d9c2f99,0x2eb48ad2,0x26c88ad3}},	//   gatá, _ggwe_, _рсфс, dsbo_, 
   {{0x44448ad4,0x76400153,0xfd040117,0x00000000}},	//   kh_, ūlyk, _рӯйп, --, 
   {{0x44448ad5,0x36d4009b,0x9138010f,0xed340166}},	//   jh_, когр, לעכק, _шэхэ, 
   {{0x44448ad6,0x69c48ad7,0x61e08ad8,0xfa6807d6}},	//   dh_, bake, kgol, _очиқ_, 
   {{0x44448ad9,0x69c48ada,0xdb1867ca,0x39148035}},	//   eh_, cake, catá, _амир, 
   {{0x61e08adb,0xdb0801b8,0x44440072,0xf48401d3}},	// [a9b0] dgol, _lefü, fh_, نائی, 
   {{0x44448adc,0x61e08add,0x6b8c0022,0x2c78033b}},	//   gh_, egol, _ângá, tèdi_, 
   {{0xa3e0033d,0x23e01b6e,0xdb0801b8,0x61e00042}},	//   _धार_, _पारद, _nefü, fgol, 
   {{0x44448ade,0x61e08adf,0x3134084c,0x2c78007f}},	//   ah_, ggol, кеер, rèdi_, 
   {{0x44443c76,0xafe48ae0,0x05848ae1,0x30e439fb}},	//   bh_, волл, _бурм, тсең, 
   {{0x69c48ae2,0xdb0803fa,0x60600075,0xdb188ae3}},	//   zake, _befü, لۇقل, zatá, 
   {{0xe820375c,0x69c48ae4,0xa3d4000d,0x00000000}},	//   माता_, yake, _ियत_, --, 
   {{0x2900068f,0x69c48ae5,0xdd8c00f1,0x61e00210}},	//   ywka_, xake, ښوي_, cgol, 
   {{0xd59800b5,0xdb188ae6,0x00000000,0x00000000}},	//   _mlは_, vatá, --, --, 
   {{0x69c48ae7,0x0b900023,0x00000000,0x00000000}},	//   wake, _መሓውር_, --, --, 
   {{0xdb18066d,0xdb080639,0x6a742b76,0x9f5c323d}},	//   tatá, _gefü, dáfr, _tatá_, 
   {{0x44440ad3,0x2d9c01f7,0x9d500133,0xdb180174}},	//   zh_, _ugwe_, انیت, katæ, 
   {{0x444401a9,0xdb0803b2,0x6e2805ac,0xdb188ae8}},	//   yh_, _befó, mjeb, ratá, 
   {{0x69c48ae9,0x61e08aea,0x6d4403be,0x9f5c003a}},	//   sake, zgol, _əhal, _datæ_, 
   {{0x69c48aeb,0x6d48054e,0xdb1801d3,0x15681884}},	//   pake, lzea, patá, ﺳﯩﺘﯩ, 
   {{0xadf88a4f,0x05ac0490,0x69c4014b,0x96600945}},	//   ्यटन_, टुंब, qake, аксе, 
   {{0x44448aec,0x6d488aed,0x26c80332,0xdb1802d2}},	// [a9c0] th_, nzea, ssbo_, gatæ, 
   {{0x44448aee,0x6e28002d,0x6d485c71,0x7e6401a6}},	//   uh_, hjeb, izea, čipi, 
   {{0x44448aef,0xdb0c145e,0x6e280158,0x61e01d17}},	//   rh_, _âdôn, kjeb, tgol, 
   {{0x44448af0,0xdb088af1,0xe4c400ee,0xd24c1c4e}},	//   sh_, _refü, _ийми, ينل_, 
   {{0x91e010ae,0x6e288af2,0x00000000,0x00000000}},	//   роче, djeb, --, --, 
   {{0x6d480084,0x61e00368,0x2bdc0073,0xa11401d5}},	//   dzea, sgol, _मागा, _یوزت, 
   {{0xd2a40276,0x6e28002d,0x9f5c8af3,0x61e00205}},	//   _аксе_, fjeb, _matç_, pgol, 
   {{0x6ed8005e,0xdb187236,0x61e00421,0xad9c033f}},	//   ردىڭ_, latç, qgol, jeźd, 
   {{0xa0a48af4,0xa3d452be,0x25e805dc,0x0a280154}},	//   _разд, _िया_, _छानी_, মসাং_, 
   {{0xdb1803ee,0xbab801c0,0x2244017a,0x8a1801d9}},	//   natç, нгох_, lhok_, ۆتُس_, 
   {{0x201c8af5,0xdb088af6,0x00000000,0x00000000}},	//   _inti_, _refó, --, --, 
   {{0x22448af7,0xdb180209,0x63ac0175,0x2f5400d4}},	//   nhok_, hatç, _lfbn, _стус, 
   {{0x23e00406,0x596402e8,0xdb188af8,0x00000000}},	//   _पांद, тъна, katç, --, 
   {{0xc8648af9,0xdb088afa,0xfda40022,0x22440327}},	//   атси, _defò, _рыҧҟ, hhok_, 
   {{0x7bc88afb,0x6a740077,0xc6a48afc,0xdb18036e}},	//   madu, ráfr, ирти, datç, 
   {{0x20d0073d,0xdb180174,0x00000000,0x00000000}},	//   _सिंध, tatæ, --, --, 
   {{0x201c1c06,0x224404fb,0x188801e0,0x970000d1}},	// [a9d0] _onti_, dhok_, _осоп_, _ھېرى, 
   {{0x7bc88afd,0x201c3223,0x626c01e4,0xd3440753}},	//   nadu, _nnti_, nĝof, پیره_, 
   {{0x63e40075,0x6d480789,0x7bc86729,0x814400e5}},	//   ايمە, zzea, iadu, ینمن, 
   {{0x7bc88afe,0x201c8aff,0x25e800e1,0xddc000d0}},	//   hadu, _anti_, _छायी_, _akož, 
   {{0x7bc88b00,0x201c009f,0xdb188b01,0xddc001ef}},	//   kadu, _bnti_, latä, _umoř, 
   {{0x7bc88b02,0xdb181432,0x660001e4,0x491400cd}},	//   jadu, catç, ĵoke, दितो_, 
   {{0x6d488b03,0xdfcc004b,0xed588b04,0x6e28282c}},	//   wzea, سيي_, maži_, tjeb, 
   {{0x201c0605,0x6d480323,0x22440ac5,0x60d402d5}},	//   _enti_, tzea, chok_, šyma, 
   {{0x6e28207a,0xde4400f1,0xdb180641,0x00000000}},	//   rjeb, دینو_, hatä, --, 
   {{0x7bc88b05,0x6e2824d1,0x201c020b,0x1c408b06}},	//   gadu, sjeb, _gnti_, йным, 
   {{0xcee84732,0xdb0802e2,0xd174013d,0xdb180254}},	//   _زران_, _sefò, _чыңы, jatä, 
   {{0x2fc478d0,0x8c4000ac,0xcdc88b07,0xfeb82e0b}},	//   _helg_, _əşya, _آذان_, _شامت_, 
   {{0xfe708b08,0x7bc88b09,0xdb1862c7,0x00000000}},	//   _بدل_, badu, yatç, --, 
   {{0x7aec01ed,0x18a08b0a,0x2bdc134e,0x98a00f7e}},	//   öltö, сарм, _खाटू_, сире, 
   {{0xdb1801b8,0x00000000,0x00000000,0x00000000}},	//   gatä, --, --, --, 
   {{0x9f4c06af,0xdb080241,0xf5b400d4,0xe8202e2a}},	//   uffé_, _tefò, исую, माहा_, 
   {{0xdb0800fc,0x24880109,0xe56801c0,0x00000000}},	// [a9e0] _hefð, _phbm_, хиад_, --, 
   {{0xdb180254,0x86e400f1,0xa0a40b01,0x00000000}},	//   batä, _پړسو, ҳадд, --, 
   {{0xdb185fea,0x224404fb,0xef0400f1,0x00000000}},	//   ratç, thok_, _بڼ_, --, 
   {{0x53a00fab,0x7bc88b0b,0x2fc4056a,0xdb18062d}},	//   _ҳарб, zadu, _aelg_, satç, 
   {{0x7bc88b0c,0x83c857aa,0x22440af9,0x00000000}},	//   yadu, _ағза_, rhok_, --, 
   {{0x2408006c,0x53a08b0d,0xdb188b0e,0x7bc8005a}},	//   _янги_, _гарб, latå, xadu, 
   {{0x7bc88b0f,0x2fc40af9,0x224400d8,0xd4648b10}},	//   vadu, _delg_, phok_, _сире_, 
   {{0x7bc80bf1,0x3cd48b11,0x00000000,0x00000000}},	//   wadu, ажис, --, --, 
   {{0x7bc88b12,0x9bc40a89,0x6598010f,0x2fc48b13}},	//   tadu, лёнк, עיִק, _felg_, 
   {{0x201c8b14,0xcb1c06ab,0xf1b801fa,0xdb180054}},	//   _unti_, यमंड_, _inša_, yatä, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3d2801d5,0xdb180847,0x2fc40139,0x00000000}},	//   _لتتی_, vatä, _zelg_, --, 
   {{0x7bc88b15,0xdd9069bb,0xd7f88b16,0x00000000}},	//   padu, _اوش_, нув_, --, 
   {{0xdb1883fd,0xb8fc584e,0xd800074d,0x7bc88b17}},	//   tatä, _डि_, сăк_, qadu, 
   {{0xdb0808a5,0x9b3401c6,0x501800d9,0x00000000}},	//   _gefð, _сүнс_, עולו, --, 
   {{0x35b48b18,0x626c01e4,0xdb1833fe,0x23e00118}},	//   рбар, nĝod, gatå, _पाउद, 
   {{0xe8204802,0xf59800a7,0x20c436c7,0xdb180254}},	// [a9f0] माशा_, тващ_, रीमध, satä, 
   {{0xb4d402e5,0x2bdc00bc,0x00000000,0x00000000}},	//   _सटी_, _माछा, --, --, 
   {{0xed588b19,0x1be01b57,0x2fc40166,0xf1b800ef}},	//   raži_, _खाईल_, _relg_, _anša_, 
   {{0x2fc48b1a,0xd5b80212,0xed580427,0xb1140108}},	//   _selg_, _ясо_, saži_, имеш, 
   {{0x91bc063f,0x25e84d53,0x00000000,0x00000000}},	//   _ajụ_, _छाती_, --, --, 
   {{0x4fc48b1b,0x00000000,0x00000000,0x00000000}},	//   усда, --, --, --, 
   {{0x2fc48b1c,0x00000000,0x00000000,0x00000000}},	//   _velg_, --, --, --, 
   {{0xa2a07220,0x3c8800d1,0x00000000,0x00000000}},	//   गदर्, ﺮﯨﺸﻰ_, --, --, 
   {{0x2d980598,0x68e001e4,0x9d500240,0x00000000}},	//   äse_, _ĥodo, _ክትፍጽ, --, 
   {{0xeb981719,0xcc8404d3,0x00000000,0x00000000}},	//   кип_, دۆته_, --, --, 
   {{0xea888b1d,0x8d680092,0x7bdc0332,0x00000000}},	//   кбол_, ችላቸው_, órua, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfe708b1e,0xe82043d1,0x8d84005b,0x00000000}},	//   _عدم_, माला_, _сужд, --, 
   {{0xdb18003a,0x00000000,0x00000000,0x00000000}},	//   natû, --, --, --, 
   {{0x44240208,0x00000000,0x00000000,0x00000000}},	//   _đm_, --, --, --, 
   {{0x66e407d6,0x295400a7,0x834801ec,0x00000000}},	//   лоҳа, _въор, ңжаң_, --, 
   {{0x69d4409c,0xdb18025a,0xa5243ae4,0x6ab400c5}},	// [aa00] _idye, katû, шмад, _अझुर, 
   {{0x142044ec,0x261401f9,0x00000000,0x00000000}},	//   одум, _पोरी_, --, --, 
   {{0xe2988b1f,0x234800d1,0x26cc0241,0x00000000}},	//   важ_, خلاپ_, _ìfo_, --, 
   {{0xed580989,0x3c8808b0,0xd12c03e6,0x11d4007b}},	//   lažu_, ﺮﯨﺴﻰ_, ژمن_, لومة_, 
   {{0x05945662,0x69d40bd7,0x55b80375,0x98bc025c}},	//   _دادگ, _mdye, _במכו, ħuħ_, 
   {{0x76400006,0x90500006,0x6ab40037,0x3ed400ae}},	//   ūlyt, овіц, _अझूर, مقتر, 
   {{0xe7ec09d9,0x69d402ce,0xbdd40108,0x00000000}},	//   _जाना_, _odye, бойщ, --, 
   {{0x69d48b20,0x91e00166,0xef902c04,0x00000000}},	//   _ndye, _мосе, سیند, --, 
   {{0xed580552,0x62800430,0x60088b21,0xc5a803d4}},	//   kažu_, mloo, _инам_, _ওজাপ, 
   {{0x62808b22,0x69d48b23,0x0fc000d1,0xdb186abf}},	//   lloo, _adye, _мйун, matú, 
   {{0x62808b24,0x3a7400f7,0xdb1801f6,0x9f048b25}},	//   oloo, йлор, latú, _خواو, 
   {{0x62801adb,0x9a34010b,0x00000000,0x00000000}},	//   nloo, рҗих_, --, --, 
   {{0xb6c431ee,0xdd1442a3,0x62808b26,0xa3e40b02}},	//   өөнд, _خوشخ, iloo, फला_, 
   {{0x62808b27,0x69d4079b,0x25bc0051,0x21800150}},	//   hloo, _edye, _đtla_, _ﺩﻭﻟﻴ_, 
   {{0x62808b28,0xfb3400a8,0x00000000,0x00000000}},	//   kloo, _ынкэ, --, --, 
   {{0xdb180588,0x93247b15,0x81dc0f22,0x27f8009d}},	//   katú, یران, ত্ত_, _ebpn_, 
   {{0x62800942,0x26140490,0x58840c98,0x0a588b29}},	// [aa10] dloo, _पोळी_, _вына, _خشوع_, 
   {{0xd7f8013e,0xe7ec39a7,0x62801dd0,0xdb1800d0}},	//   _руи_, _जाया_, eloo, datú, 
   {{0x62808b2a,0x7640002d,0xfdf8000d,0x00000000}},	//   floo, ëlys, ्जास_, --, 
   {{0x62808b2b,0xdcec0118,0xdb18032e,0x00000000}},	//   gloo, áděl, fatú, --, 
   {{0xd14805bd,0xe7ec032c,0xdb083262,0xdd8401ec}},	//   خشان_, _जामा_, _gefö, _ءو_, 
   {{0x6280625d,0x32a400d1,0xb9d80092,0x00000000}},	//   aloo, _гуаң, _ጠጋ_, --, 
   {{0x62808b2c,0x2d900131,0xaef800db,0x00000000}},	//   bloo, ﻟﯩﻨﻰ_, ارتئ_, --, 
   {{0x62801e0b,0x6f0c012d,0xdb1801e1,0xd24401c4}},	//   cloo, łaco, batú, _тэги, 
   {{0xec782472,0xdb1800e4,0x00000000,0x00000000}},	//   лпи_, catú, --, --, 
   {{0x30840597,0x00000000,0x00000000,0x00000000}},	//   _الطف, --, --, --, 
   {{0xa9a4519b,0xed5839ae,0xad240137,0x00000000}},	//   йинд, važu_, _گىشى, --, 
   {{0x3b848b2d,0xdef4011a,0x00000000,0x00000000}},	//   өлөг, _למעט_, --, --, 
   {{0x7e7400cf,0xed5816a3,0xbf0000d0,0xe9a42bcb}},	//   _بالئ, tažu_, číšn, _қапп, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x62808b2e,0xfbd007d6,0x7c3c8b2f,0x2cac016d}},	//   yloo, _آته_, örre, lqed_, 
   {{0x99841ebd,0xed5839ae,0xdb34011a,0x62800009}},	//   šiša_, sažu_, _לנצח_, xloo, 
   {{0xa4448b30,0x62800b4f,0x00000000,0x00000000}},	// [aa20] бнад, vloo, --, --, 
   {{0x23281789,0x62808b31,0xf4d40220,0x53c4004e}},	//   лози_, wloo, _ﺟﻪﺗﻜ, йгум_, 
   {{0xe7380440,0x62808b32,0x56e002dd,0x228c00e4}},	//   _сен_, tloo, _нұрғ, hýke_, 
   {{0xd36c2a1a,0xd12c8b33,0xdb0829ef,0x62808b34}},	//   رهن_, کمه_, _tefö, uloo, 
   {{0x62808b35,0xe5e000f1,0x00000000,0x00000000}},	//   rloo, _وګړي, --, --, 
   {{0x62808b36,0xdb188b37,0x74dc012a,0xb4c400fb}},	//   sloo, ratú, _पितृ, _фирҙ, 
   {{0x62808b38,0x09e0045e,0xdef86f78,0xb9d80092}},	//   ploo, য্যা, уыл_, _ጠፋ_, 
   {{0x645c8b39,0x25b0009a,0x01080451,0xbcb402e8}},	//   lipi, ncyl_, _نڪتو_, обищ, 
   {{0x68e400bf,0x611c0311,0x217406ed,0x00000000}},	//   jukd, _bălţ, _ѓубр, --, 
   {{0x68e4003e,0x00000000,0x00000000,0x00000000}},	//   dukd, --, --, --, 
   {{0x54780302,0x41cc00bc,0x00000000,0x00000000}},	//   רטיו, ारपस, --, --, 
   {{0x645c38d7,0x2cac0477,0x00000000,0x00000000}},	//   hipi, bqed_, --, --, 
   {{0x645c8b3a,0xd61000f7,0xdef801af,0x00000000}},	//   kipi, үзгө, _шыҡ_, --, 
   {{0x645c8b3b,0x4d7800c8,0xdb18005c,0xe7ec01f9}},	//   jipi, _ערגע, katø, _जाणा_, 
   {{0x645c8b3c,0x1038010f,0x41a809fa,0x00000000}},	//   dipi, נגלע, गशास, --, 
   {{0x68e40280,0x8cbc012c,0x3f8c02fb,0x2d8c0210}},	//   bukd, लीको, _mzdu_, śleń_, 
   {{0xa6e003f2,0x98040153,0x00000000,0x00000000}},	// [aa30] óðra, _лянд, --, --, 
   {{0x645c8b3d,0x798c2d6f,0x88a40133,0x78bc000d}},	//   gipi, _izaw, _ریفۆ, mpsv, 
   {{0xe7ec4425,0x9f5c00a3,0xdb187e78,0x938801c6}},	//   _जाता_, _tatù_, gatø, усаа_, 
   {{0x645c004c,0x78bc0373,0x16e400f1,0x00000000}},	//   aipi, opsv, _پېړۍ_, --, 
   {{0x7bd805a1,0x83cc1c5c,0x645c8b3e,0x00000000}},	//   _odvu, _ﺗﯘﺭﺳ, bipi, --, 
   {{0x645c8b3f,0x764c8b40,0x798c01f7,0x06f40214}},	//   cipi, lhay, _mzaw, _بسیج, 
   {{0xd1b800c6,0x8fc400cf,0xaf0400d4,0x00000000}},	//   _ماذا_, _ۇزان, іпил, --, 
   {{0xee388b41,0x798c8b42,0x7bd8030a,0x7008009e}},	//   рни_, _ozaw, _advu, লাইজ_, 
   {{0x798c2dd1,0xd59800b5,0x752c014b,0xec480ce1}},	//   _nzaw, _dlで_, nxaz, изил_, 
   {{0x764c003e,0xac388b43,0x00000000,0x00000000}},	//   hhay, рчих_, --, --, 
   {{0x764c2747,0x798c0198,0x78bc27bb,0xde7401d3}},	//   khay, _azaw, epsv, _ڈیوڈ_, 
   {{0x7bd82959,0x645c8b44,0x68e4089c,0xbebc00ef}},	//   _edvu, zipi, tukd, _brīf, 
   {{0x764c8b45,0xe7ec007d,0x645c8967,0x6f00035a}},	//   dhay, _जादा_, yipi, _hplc, 
   {{0xbd8816cb,0x798c6009,0xeb988b46,0x4268001f}},	//   _انهن_, _dzaw, _кил_, ታማነት_, 
   {{0x798c8b47,0x68e48b48,0x1864030d,0x645c8b49}},	//   _ezaw, sukd, цари_, vipi, 
   {{0x764c8b4a,0xdb181fcd,0x66000115,0x645c0042}},	//   ghay, vatø, ĵoko, wipi, 
   {{0x645c15fd,0xe4588b4b,0x25b00477,0xad9c0210}},	// [aa40] tipi, ажа_, rcyl_, zeźn, 
   {{0x764c0014,0x37e00154,0x54d40014,0xc3680092}},	//   ahay, ম্বর, زِمس_, _ተሸክሞ_, 
   {{0x764c8b4c,0x63048b4d,0x648000c7,0x04fc00eb}},	//   bhay, توال, kôiv, ীমের_, 
   {{0x764c8b4e,0xdb180a64,0xb35403e6,0xbebc0055}},	//   chay, ratø, سیقا_, _hrīg, 
   {{0x645c8b4f,0xbebc0171,0x66140064,0x00000000}},	//   pipi, _krīg, mdyk, --, 
   {{0x44f48b50,0x6d4400ac,0x66145127,0x645c02d1}},	//   mä_, _əhat, ldyk, qipi, 
   {{0x44f48b51,0x44444375,0xd24c00f1,0xe2980064}},	//   lä_, mk_, رچې_, _вав_, 
   {{0x44388b52,0x66148b53,0xe2a4066a,0x44447ba7}},	//   _hor_, ndyk, óðum_, lk_, 
   {{0x44f48b54,0x44388b55,0x44448b56,0x00000000}},	//   nä_, _kor_, ok_, --, 
   {{0x44388b57,0x6614023a,0x3b542c25,0x715800a8}},	//   _jor_, hdyk, зкор, _урсс_, 
   {{0x9ce8015b,0x764c8b58,0xad9c033f,0x3f8c02f0}},	//   কবেন_, yhay, leźl, _uzdu_, 
   {{0x44388b59,0x81dc0d42,0x44f48b5a,0xdca48b5b}},	//   _lor_, ত্র_, kä_, _дади, 
   {{0x44388b5c,0x44448b5d,0x44f40664,0x7e6060e7}},	//   _oor_, kk_, jä_, mimp, 
   {{0x44443a0e,0x44f48b5e,0x44380c30,0x78bc8b5f}},	//   jk_, dä_, _nor_, rpsv, 
   {{0x764c4fae,0xa6e0022c,0x9054011a,0xa4740166}},	//   thay, óðpa, קבלו_, _şeşä_, 
   {{0x7e608b60,0x44448b61,0x44f48b62,0x7c3801e6}},	//   nimp, ek_, fä_, _hovr, 
   {{0x44388b63,0xd7f88b64,0x7c3800c8,0x7ae88b65}},	// [aa50] _bor_, _кун_, _kovr, ludt, 
   {{0x764c8b66,0x44388b67,0x7ae8009a,0xda6c0451}},	//   shay, _cor_, oudt, _سُڌ_, 
   {{0x44388b68,0x7e608b69,0x764c8b6a,0x78ac8b6b}},	//   _dor_, kimp, phay, _huav, 
   {{0x444403b3,0x7c388b6c,0x44380086,0x78ac20d6}},	//   ak_, _lovr, _eor_, _kuav, 
   {{0x44386114,0x44440522,0x058405f5,0x78ac00e4}},	//   _for_, bk_, _журм, _juav, 
   {{0x78ac18f7,0x44388b6d,0x7c3800ac,0x78a40842}},	//   _muav, _gor_, _novr, _jihv, 
   {{0x78ac0421,0x88b0013f,0x7e600109,0x00000000}},	//   _luav, _prɛk, fimp, --, 
   {{0x44388b6e,0xe68c03be,0x78a48b6f,0x7ae80477}},	//   _zor_, _məşğ, _lihv, dudt, 
   {{0x44388b70,0xad240075,0x7c38017a,0xe80c012c}},	//   _yor_, سىدى, _bovr, ाजमा_, 
   {{0xcf248b71,0x7c388b72,0xbebc00da,0x44388b73}},	//   _وراي, _covr, _brīd, _xor_, 
   {{0x7c388b74,0x765c03d4,0x7ae80004,0x7e608b75}},	//   _dovr, _omsy, gudt, bimp, 
   {{0x7e608a67,0x78ac0158,0x44f400fd,0x9f5c00d8}},	//   cimp, _buav, yä_, _obtê_, 
   {{0x78a4047e,0x7c380076,0xdb1803b2,0xbd6800f3}},	//   _bihv, _fovr, matý, _мрље_, 
   {{0x44f4049b,0x78ac23e0,0x7c380493,0xe7388b76}},	//   vä_, _duav, _govr, бег_, 
   {{0x44385e9c,0xaa448b77,0xbebc005f,0x44448b78}},	//   _ror_, _некл, _grīd, vk_, 
   {{0x44f4426d,0x44388b79,0x78ac8b7a,0xdb180306}},	//   tä_, _sor_, _fuav, natý, 
   {{0x78ac8b7b,0x6e388b7c,0x66148b7d,0xa0200790}},	// [aa60] _guav, _mowb, rdyk, _şömi, 
   {{0x44f48b7e,0x44448b7f,0x7e60401f,0x44388b80}},	//   rä_, uk_, zimp, _qor_, 
   {{0x44388b81,0x44f48b82,0xdb1802f0,0xd24c0014}},	//   _vor_, sä_, katý, گنن_, 
   {{0x44f48b83,0x44388b84,0x78ac0211,0x2910007f}},	//   pä_, _wor_, _yuav, _ksya_, 
   {{0x7e608b85,0xf1a88b86,0x44448b87,0x64a48b88}},	//   vimp, زانه_, pk_, _хага, 
   {{0x443804cc,0x7e605c5d,0x44440175,0x232801f4}},	//   _uor_, wimp, qk_, _логи_, 
   {{0x765401ed,0x765c8b89,0x00000000,0x00000000}},	//   _ügyé, _ymsy, --, --, 
   {{0x7ae88b8a,0x6b540327,0xc0bc0092,0x00000000}},	//   vudt, _mżgħ, ተቻለ_, --, 
   {{0x7e608b8b,0x7c388b8c,0x29100a1d,0x6e3c0112}},	//   rimp, _povr, _nsya_, ösba, 
   {{0x7e608b8d,0xdb1800c7,0x7c38427b,0x00000000}},	//   simp, aatý, _qovr, --, 
   {{0x29108b8e,0x5c84044e,0x7e608b8f,0x9f500724}},	//   _asya_, _ርእይቶ_, pimp, ädän_, 
   {{0x78ac8b90,0x7e600227,0xdb188b91,0x7ae81600}},	//   _puav, qimp, matü, rudt, 
   {{0x7c38151c,0x78ac0381,0x78a4005b,0x9d98007b}},	//   _tovr, _quav, _pihv, _انشئ_, 
   {{0xb9047f1a,0x78ac8b92,0xfc646646,0x00000000}},	//   _पट_, _vuav, _تخصی, --, 
   {{0x29108b93,0xbebc0055,0x41cc041c,0x87040108}},	//   _esya_, _hrīb, ारास, няте, 
   {{0x78ac8b94,0x9f5c00e5,0x00000000,0x00000000}},	//   _tuav, _ható_, --, --, 
   {{0x3a282af2,0x59c08b95,0x78a40254,0x9f5c659a}},	// [aa70] _inap_, _व्यर, _tihv, _kató_, 
   {{0xdb188b96,0xb4cc098a,0x04c80592,0x6f0c033f}},	//   katü, _रबी_, سومي_, łaci, 
   {{0x752805ce,0x3a282d02,0xd1b83b5f,0x9f5c86c1}},	//   _šezd, _knap_, ماشا_, _mató_, 
   {{0xdb188b97,0x22440066,0x228c00d0,0x765c8b98}},	//   lató, gkok_, týka_, _umsy, 
   {{0xe8200490,0xdb1802f0,0xc0c80063,0x26140c22}},	//   माचा_, vatý, пује_, _पोटी_, 
   {{0xdb188b99,0x41745d95,0xfaf80f40,0x6e380076}},	//   nató, رانس, ktī_, _sowb, 
   {{0x3a2800ca,0x9f5c05da,0xdb188b9a,0x00000000}},	//   _onap_, _tatý_, gatü, --, 
   {{0x9f8800e4,0xdb188b9b,0xada48b9c,0xa2c00166}},	//   _añói_, ható, майл, _рәфк, 
   {{0xd7bc0be7,0xe7ec367a,0xdb188b9d,0x7f480116}},	//   ्राच, _जाला_, kató, يلۇق_, 
   {{0xc1046884,0x9f5c011f,0x6e38054e,0x3a280205}},	//   _سومي, _cató_, _wowb, _anap_, 
   {{0x6e388b9e,0x2ef4010b,0xdb188b9f,0x00000000}},	//   _towb, _цзер, dató, --, 
   {{0x3a2808c2,0x9f8800e4,0xe8f80a5b,0x00000000}},	//   _cnap_, _eñói_, олм_, --, 
   {{0xdb088ba0,0xac18026b,0xbebc0171,0x00000000}},	//   _affä, _моду_, _grīb, --, 
   {{0xdb188ba1,0x6b645afd,0x3a288ba2,0x2244005a}},	//   gató, _окла, _enap_, zkok_, 
   {{0x2910070d,0x98a08ba3,0x18a08ba4,0x69d8013f}},	//   _wsya_, тире, тарм, ɔten, 
   {{0x88b0013f,0x29100109,0x9f5c007f,0x3eb801ed}},	//   _asɛe, _tsya_, _katò_, _érte_, 
   {{0x69c408cd,0x2910014b,0xdb188ba5,0x00000000}},	// [aa80] mbke, _usya_, bató, --, 
   {{0xdb188ba6,0x9f5c00db,0x25e80037,0x00000000}},	//   cató, _xató_, _छाकी_, --, 
   {{0x65c475d2,0xdb18642b,0x47d400cc,0x224401d3}},	//   _обна, latò, _তাপী, tkok_, 
   {{0xd24c004b,0xdb180254,0x00000000,0x00000000}},	//   ټنه_, vatü, --, --, 
   {{0x224403c0,0xdb188ba7,0xa2a817cb,0x00000000}},	//   rkok_, natò, _जंक्, --, 
   {{0x22448ba8,0x25e4012c,0x7f946d5f,0x3dc40477}},	//   skok_, टलकी_, налх, wbmw_, 
   {{0x644c8ba9,0xaa840419,0x2be001f9,0x00000000}},	//   _ilbi, _zmýš, पणना, --, 
   {{0xdb188baa,0x644c00d7,0xbebc00ef,0x00000000}},	//   zató, _hlbi, _prīb, --, 
   {{0x626c01e4,0x9be401ca,0xdb180254,0x00000000}},	//   nĝom, мінк, satü, --, 
   {{0x3dc40ffb,0x3a288bab,0x69c402f0,0xdd9001ec}},	//   sbmw_, _snap_, ebke, нақы, 
   {{0x9f5c0137,0x60c0822d,0xdb0c0793,0xdb188bac}},	//   _obté_, lpom, _ädün, vató, 
   {{0x60c00034,0xfaf80b13,0xd90c0517,0x60d40024}},	//   opom, rtī_, لیب_, šymu, 
   {{0x644c8bad,0xdb188bae,0x588400c9,0xad6405d9}},	//   _olbi, tató, дыва, _ٻانه, 
   {{0x60c00099,0xd7e400db,0x6fc0024a,0x00000000}},	//   ipom, بوسۇ_, रुपू, --, 
   {{0xdb188baf,0x349407dd,0xaa84013a,0x00000000}},	//   rató, ҵаар, _smýš, --, 
   {{0x644c8bb0,0xb8f404c5,0xb9040183,0xdb188bb1}},	//   _albi, _হম_, _নহ_, batò, 
   {{0xdb188bb2,0x60c08bb3,0xe28c022e,0x644c01ef}},	// [aa90] catò, jpom, rtаl_, _blbi, 
   {{0xdeb8001f,0x4cc00154,0x60c00427,0x00000000}},	//   ተኛና_, _শিমু, dpom, --, 
   {{0xdb080036,0x60c001f5,0x978000f2,0x00000000}},	//   _uffä, epom, _شیره, --, 
   {{0x644c8bb4,0xd7bc8bb5,0x60c001a4,0x626c010f}},	//   _elbi, ्रवच, fpom, lĝoj, 
   {{0x6dc001f2,0x00000000,0x00000000,0x00000000}},	//   ịakw, --, --, --, 
   {{0x3af801ed,0x417400c6,0x626c010f,0x00000000}},	//   kép_, خامس, nĝoj, --, 
   {{0x626c01e4,0x00000000,0x00000000,0x00000000}},	//   iĝoj, --, --, --, 
   {{0x43948bb6,0x8d2400d1,0x52c80073,0xc1740133}},	//   _расс, дниң_, ाठीस, ردۆت, 
   {{0x11647f05,0x5184009d,0x00000000,0x00000000}},	//   _غلطی_, _цува, --, --, 
   {{0x6298011c,0xeac4004e,0x00000000,0x00000000}},	//   _ètor, нбоп, --, --, 
   {{0x291c0aed,0x3af800dd,0x18b00588,0x403411f4}},	//   ātam_, gép_, қәыр, _шефс, 
   {{0x26dc1315,0x38600332,0x69c4003e,0x00000000}},	//   átom_, _amhr_, ubke, --, 
   {{0xbebc0171,0x00000000,0x00000000,0x00000000}},	//   _trīc, --, --, --, 
   {{0x26dc0989,0xdb1856ed,0x6d5c03b2,0x9cd4011a}},	//   štom_, ratò, úsau, _טונה_, 
   {{0x97740184,0xe7380e58,0x3af80c6a,0xa6940114}},	//   еттә, чев_, cép_, ерај, 
   {{0x39a403c1,0xdb180561,0xfd4801e1,0x00000000}},	//   _sīsū_, patò, _nimọ, --, 
   {{0xe8f8030d,0x00000000,0x00000000,0x00000000}},	// [aaa0] _элп_, --, --, --, 
   {{0x4ad08bb7,0x7d040036,0xe5a400ee,0x64a40408}},	//   _दबाव, _äise, _җиги, хаза, 
   {{0x64e00490,0xb86400ec,0x1618012d,0x00000000}},	//   _पिवळ, _جايو, _पोकर_, --, 
   {{0x60c00fcf,0xdb08004a,0x5edc00eb,0x228c00d7}},	//   tpom, _affû, _মহলে, rýko_, 
   {{0x51808bb8,0x60c00810,0x3af801ed,0x228c00e4}},	//   луша, upom, zép_, sýko_, 
   {{0x60c08bb9,0x10a02461,0x74b406e3,0x00000000}},	//   rpom, гичн, _अंतः, --, 
   {{0x7e9825f4,0x42a40116,0x626c0115,0x48bc00eb}},	//   ونتر_, _җуңғ, nĝok, _অটোর, 
   {{0xe0d00050,0x2d90000f,0x25a40010,0x5cc401f0}},	//   _مٲر_, ęzen_, žolu_, нсоз, 
   {{0x4ea052d9,0x63ac1180,0x00000000,0x00000000}},	//   ырша, _kgbn, --, --, 
   {{0x3af88bba,0x00000000,0x00000000,0x00000000}},	//   tép_, --, --, --, 
   {{0x26dc8bbb,0xefec0023,0xcd3000db,0x00000000}},	//   štoj_, _ቀንዩ_, _ەرىب, --, 
   {{0x3af88bbc,0x200c0184,0xfd640032,0xb5f001e1}},	//   rép_, lefi_, _инеү, _olúọ, 
   {{0x3af800d5,0x6d5c03b2,0x00000000,0x00000000}},	//   sép_, úsat, --, --, 
   {{0x99640352,0x00000000,0x00000000,0x00000000}},	//   _үтил, --, --, --, 
   {{0x7d0404e6,0x626c0115,0x8c1805d0,0x06880116}},	//   _äisb, rĝoj, _זווי, ﯩﻜﯩﮕ, 
   {{0x63ac063f,0xb3cc009e,0x161807f7,0x00000000}},	//   _agbn, _লাইজ, _पोखर_, --, 
   {{0xf44801e2,0x00000000,0x00000000,0x00000000}},	// [aab0] وټرو_, --, --, --, 
   {{0x200c0198,0x00000000,0x00000000,0x00000000}},	//   jefi_, --, --, --, 
   {{0xf6986997,0x97a48bbd,0x57bc1d27,0x200c3a43}},	//   _овој_, _ярил, ्रीह, defi_, 
   {{0x1af003d4,0xf07400e5,0xc2c4009a,0x00000000}},	//   _জনাই_, ھیاں_, ايني, --, 
   {{0xf07400e5,0x00000000,0x00000000,0x00000000}},	//   پیاں_, --, --, --, 
   {{0x614003c5,0x00000000,0x00000000,0x00000000}},	//   реша, --, --, --, 
   {{0x53480354,0x00000000,0x00000000,0x00000000}},	//   _хăйă, --, --, --, 
   {{0x57bc6352,0x6fc00037,0x00000000,0x00000000}},	//   ्रुह, _र्रू, --, --, 
   {{0x30146d45,0x200c016b,0x7ae8002d,0x321c0042}},	//   _идар, befi_, erdt, mdwy_, 
   {{0x26dc01ed,0xad9c033f,0xbebc00ef,0x00000000}},	//   átok_, zeźw, _irīn, --, 
   {{0xbebc0055,0x59c00073,0x00000000,0x00000000}},	//   _hrīn, _व्हर, --, --, 
   {{0xa9688bbe,0x7bc80ba7,0x3f640063,0x8e54010a}},	//   дима_, abdu, _стуб, _чĕмл, 
   {{0xefe8001f,0x7ae855ad,0x88840075,0x7bc80327}},	//   _መሄድ_, ardt, лғил, bbdu, 
   {{0x66e40cfc,0x1d040861,0xa80402e8,0x7bdc1427}},	//   кога, _реши_, ъзгл, órut, 
   {{0x88b0013f,0x3da401af,0x00000000,0x00000000}},	//   _prɛs, _ирәб, --, --, 
   {{0xa9248bbf,0x200c043b,0x7d0404e6,0x44248bc0}},	//   _адил, zefi_, _äisc, _şm_, 
   {{0x7bdc06ea,0x00000000,0x00000000,0x00000000}},	// [aac0] ðrug, --, --, --, 
   {{0xdb18007c,0x2ed00d2e,0x00000000,0x00000000}},	//   bbtä, _सबूत, --, --, 
   {{0xc2e402dd,0xe1f800db,0x00000000,0x00000000}},	//   _ءﺑﯘﻟ, дге_, --, --, 
   {{0xbebc005f,0xed5801a6,0x216800c7,0x00000000}},	//   _brīn, kzž_, миеи_, --, 
   {{0x200c01ee,0xdfd0007b,0x00000000,0x00000000}},	//   tefi_, ليش_, --, --, 
   {{0xdb188bc1,0x321c03cb,0xbddc0150,0x00000000}},	//   matö, adwy_, _ﺘﻨﻘل_, --, 
   {{0x200c00a9,0xdb188bc2,0xe28401b9,0x3958003e}},	//   refi_, latö, _алви, zzss_, 
   {{0xc6900020,0xe124023a,0xbd184db0,0x20180113}},	//   _መሥሪያ_, _имби, ежих_, žpi_, 
   {{0xdb188bc3,0xbebc00de,0x00000000,0x00000000}},	//   natö, _grīn, --, --, 
   {{0xe7ec0574,0x5158008d,0x44d0030a,0x7b14009d}},	//   _जागा_, _חכמו, iń_, гдох, 
   {{0x626c00df,0xa184013d,0xdb180641,0x6d5c03f2}},	//   rŝof, _чыңл, hatö, úsar, 
   {{0x7bc8014b,0x00000000,0x00000000,0x00000000}},	//   sbdu, --, --, --, 
   {{0xdb188bc4,0x7bc80332,0x7bdc0162,0x00000000}},	//   jatö, pbdu, órus, --, 
   {{0x9b248bc5,0xb6c400f7,0x7bc8031c,0xdb1808a5}},	//   _афил, лөмд, qbdu, datö, 
   {{0x44d0006d,0x386c1727,0x16708bc6,0x38140014}},	//   eń_, đer_, иқор, نژھر, 
   {{0x13c800dc,0xf1b81b5c,0x4ae001b9,0xc1cc043e}},	//   िर्भ, _kaše_, _тўша, ारोग, 
   {{0xf1b81505,0xdb0800b5,0xefe80092,0xdb18032e}},	// [aad0] _jaše_, _affø, _መሄዱ_, gatö, 
   {{0x798c8bc7,0x6b8c00c7,0x3f8c0205,0xed5800a2}},	//   _iyaw, _ãngá, _oydu_, gažy_, 
   {{0xd3a41ed2,0x44d0030a,0xa2c00075,0xdb18007c}},	//   трап, ań_, йәтк, bbtå, 
   {{0x798c8bc8,0xdb180793,0x717802dd,0x550401d5}},	//   _kyaw, batö, нбер_, _ичга, 
   {{0xc7b80552,0xafe48bc9,0x764c8bca,0x321c0042}},	//   žđe_, голл, mkay, rdwy_, 
   {{0x764c8bcb,0xdb180254,0x00000000,0x00000000}},	//   lkay, latõ, --, --, 
   {{0x88b00134,0x798c7294,0x764c00b5,0x291c8bcc}},	//   _nsɛn, _lyaw, okay, ātai_, 
   {{0x764c8bcd,0x798c04ba,0x325401f0,0xdb180254}},	//   nkay, _oyaw, _ёвар, natõ, 
   {{0x798c8bce,0xac845a42,0x88b00134,0xa2802be7}},	//   _nyaw, лгил, _asɛn, _اینو, 
   {{0x764c03f0,0xdb180254,0x5dc40228,0x00000000}},	//   hkay, hatõ, _ەمنە, --, 
   {{0x798c8bcf,0x764c8bd0,0x15e00490,0xdc3c013d}},	//   _ayaw, kkay, गणार_, _cíıl, 
   {{0x798c8bd1,0xd59804ce,0x764c8bd2,0x00000000}},	//   _byaw, _noは_, jkay, --, 
   {{0x798c01aa,0x88b0043b,0x764c8bd3,0x3f8c0064}},	//   _cyaw, _esɛn, dkay, _zydu_, 
   {{0x798c0369,0x764c01d9,0xdb188bd4,0x5fc40404}},	//   _dyaw, ekay, vatö, रुपल, 
   {{0x798c0a49,0x49b40116,0x6d488bd5,0x764c8bd6}},	//   _eyaw, _вәгу, lyea, fkay, 
   {{0x764c8bd7,0x1c340022,0x9c340131,0xe8f803a6}},	//   gkay, _азәы_, _апәт_, _зли_, 
   {{0x798c0297,0xe3b08bd8,0x69d40784,0xa5248bd9}},	// [aae0] _gyaw, مرا_, _ieye, ымад, 
   {{0xc1cc5ce0,0xdb188bda,0x69d4083c,0x9f5c0109}},	//   ार्ग, ratö, _heye, _katô_, 
   {{0x69d48bdb,0x377400c9,0x764c0067,0x7c3c002f}},	//   _keye, _выяс, bkay, örri, 
   {{0x69d48bdc,0xe6105085,0x245402d2,0xdb180037}},	//   _jeye, _اشد_, _sæmd_, patö, 
   {{0x69d48bdd,0x91e07096,0x798c0211,0xdb0c0793}},	//   _meye, соче, _xyaw, _ädön, 
   {{0x69d48bde,0x5cc41955,0xcfcc0154,0x00000000}},	//   _leye, қсиз, _রাউন, --, 
   {{0xf1b8009b,0xe2940261,0x04c801e2,0x00000000}},	//   _saše_, _браќ, _سوځي_, --, 
   {{0xf1b88bdf,0x79880e5e,0x45440092,0x00000000}},	//   _paše_, żewi, _የመንበ, --, 
   {{0x9a8401b9,0x245402d2,0x8e340137,0x6d5c0174}},	//   ғунл, _tæmd_, اسىر_, úsap, 
   {{0xf1b88be0,0x798c01b2,0xdb18006a,0xbebc002b}},	//   _vaše_, _ryaw, katô, _hrīm, 
   {{0x798c8be1,0x3f8c05d1,0x91d42b1b,0x764c8be2}},	//   _syaw, _uydu_, _হাতখ, ykay, 
   {{0x201c8be3,0xcc3002dd,0x00000000,0x00000000}},	//   _hati_, _ۇرىع, --, --, 
   {{0x201c8be4,0x69d48be5,0xdb188be6,0x9f4c01e7}},	//   _kati_, _deye, icté, igfí_, 
   {{0x798c5b9f,0xd8388be7,0x69d4037e,0x4668136b}},	//   _vyaw, хэм_, _eeye, ҳрум_, 
   {{0x9484005e,0x69d409b6,0x9f5c0109,0x764c8be8}},	//   ңызд, _feye, _gatô_, tkay, 
   {{0x201c4e53,0x69d48be9,0xc0e8001f,0x764c8bea}},	//   _lati_, _geye, መለስ_, ukay, 
   {{0x201c04fe,0x798c2ffc,0xc9f404b3,0xb17c00d0}},	// [aaf0] _oati_, _uyaw, _اسىع, _odťa, 
   {{0x764c8beb,0xd3788bec,0x76b8084c,0xdb180254}},	//   skay, нче_, _илор_, satõ, 
   {{0x69d48bed,0x764c0227,0xdb180798,0x386c002e}},	//   _yeye, pkay, patõ, éeru_, 
   {{0xc8c88bee,0x201c8bef,0x764c0227,0x6d480175}},	//   _جوین_, _aati_, qkay, yyea, 
   {{0x26dc0030,0x3f800356,0xf8b411d7,0x00000000}},	//   átov_, şiul_, ंदिय, --, 
   {{0xd2d48bf0,0x201c8bf1,0x760c063f,0xa6e001a8}},	//   _مغرب, _cati_, _ịrịọ, óðga, 
   {{0x6d480334,0x26dc00d7,0x00000000,0x00000000}},	//   wyea, štov_, --, --, 
   {{0xddc0068f,0x6d488bf2,0xf0e800d1,0x6e44447e}},	//   _iloś, tyea, _لىرى_, реиз, 
   {{0xed588bf3,0x201c8bf4,0xec7800f7,0x1f700166}},	//   топ_, _fati_, кпи_, йләя, 
   {{0x201c8bf5,0x69d48bf6,0x6d48045a,0x7bdc00e4}},	//   _gati_, _seye, ryea, órup, 
   {{0xcee88bf7,0x69d48bf8,0x6d480175,0x00000000}},	//   _سران_, _peye, syea, --, 
   {{0x201c8bf9,0x69d4208d,0x00000000,0x00000000}},	//   _zati_, _qeye, --, --, 
   {{0x201c8bfa,0x7d00010a,0x69d4007f,0x6d4801a9}},	//   _yati_, ctms, _veye, qyea, 
   {{0x6c7800c8,0x31d002e3,0x7d1c00e2,0x201c01d5}},	//   _שאַפ, ịrịọ_, ārst, _xati_, 
   {{0xefec001f,0x69d40a49,0x068408ca,0x00000000}},	//   _ቀንድ_, _teye, йҳон, --, 
   {{0x626c0115,0x7d0c0332,0xdb180142,0xa9c00137}},	//   nĝot, _íosá, ratô, _گۅڭۉ, 
   {{0x2488020b,0xd544084c,0x7ae400a3,0x00000000}},	// [ab00] _pkbm_, апте_, _āiti, --, 
   {{0x93c801ed,0x386c01c7,0x00000000,0x00000000}},	//   نامہ_, éert_, --, --, 
   {{0x201c8bfb,0xa6c800c6,0xe28480f1,0xbebc31ff}},	//   _rati_, _جوجل_, алжи, _prīm, 
   {{0xe80c00bc,0xc0e80092,0x20c400c7,0x29008bfc}},	//   ाजका_, መለሱ_, аскг, otka_, 
   {{0x29008bfd,0xe3e000c7,0xad9c0210,0x6d4401e1}},	//   ntka_, _мҩақ, zeźr, _ńhan, 
   {{0x201c8bfe,0x26dc0122,0xd12c0133,0x00000000}},	//   _qati_, štou_, بمه_, --, 
   {{0x201c8bff,0x88b0013b,0x54648c00,0xd4648c01}},	//   _vati_, _nsɛm, _тарм_, _тире_, 
   {{0x201c1813,0xe2988c02,0x61440902,0x11f41411}},	//   _wati_, _раб_, _кеба, _ەتەگ, 
   {{0x201c8c03,0x88b0013b,0xdc2801d5,0xac900023}},	//   _tati_, _asɛm, نسده_, _ምእራም_, 
   {{0x7b1805f5,0x201c8c04,0xdee401b9,0x9c4440f8}},	//   гоор_, _uati_, _вожи, рхил, 
   {{0x29000419,0x7d000175,0x5dc400cf,0x00000000}},	//   etka_, stms, _ەمچە, --, 
   {{0xf1b88c05,0x76b801b9,0x29000009,0xa0a401f0}},	//   _kaša_, ғлар_, ftka_, _саҷд, 
   {{0xf1b80010,0x00000000,0x00000000,0x00000000}},	//   _jaša_, --, --, --, 
   {{0x58840953,0xf1b87edf,0xec1801ee,0xd77433d2}},	//   рыма, _maša_, _бешә_, لازع, 
   {{0x80d82871,0x29008c06,0x626c01e4,0x7bd85106}},	//   _नौसे, atka_, nĝos, _ievu, 
   {{0x7bd88c07,0x35b40588,0x89d801d9,0x00000000}},	//   _hevu, сбар, _پوٝر_, --, 
   {{0xf1b88c08,0x7bd80286,0xc7b80552,0x7ebc00c7}},	// [ab10] _naša_, _kevu, žđa_, _oĩpo, 
   {{0x843402bf,0x0574036b,0x00000000,0x00000000}},	//   онує, زاقد, --, --, 
   {{0xbebc005f,0xafc40046,0xa7c40032,0x00000000}},	//   _drīk, ەيتى, _урыҫ, --, 
   {{0x7bd88c09,0x00000000,0x00000000,0x00000000}},	//   _levu, --, --, --, 
   {{0xbebc00ef,0x2adc0037,0x00000000,0x00000000}},	//   _frīk, _कौनु_, --, --, 
   {{0x7bd88c0a,0x32d804fb,0x187c001f,0xf1b80219}},	//   _nevu, _مدرک_, _የቅጥር_, _daša_, 
   {{0xd0040032,0xee0801ee,0x00000000,0x00000000}},	//   геҙе_, гейл_, --, --, 
   {{0xefec069c,0x7bd816b8,0x29002149,0x72048c0b}},	//   _ቀንዲ_, _aevu, ytka_, _دورم, 
   {{0x7bd88c0c,0x0eb40184,0x626c01e4,0xedd40150}},	//   _bevu, ыуҙы_, rĝot, _ۇياد, 
   {{0x50a00131,0x29000427,0x2d9000de,0x4f6800fb}},	//   _بەتل, vtka_, āze_, _ишем_, 
   {{0x7bd88c0d,0x6f943adf,0x58f00327,0x95040327}},	//   _devu, _الاض, _བཀུས_, _ཅཱའི_, 
   {{0x7afc8c0e,0x9f94011a,0x28f80139,0x2f001d01}},	//   àrta, _הדעה_, лэгэ_, móg_, 
   {{0x6cc48c0f,0x2f008c10,0x3178008f,0x290005d7}},	//   _уйла, lóg_, ראָד, utka_, 
   {{0xeb98768b,0x7bd88c11,0x29008c12,0x9d40010b}},	//   _йил_, _gevu, rtka_, _хешд, 
   {{0xaa448c13,0x2f008c14,0x8c4001af,0xdc340677}},	//   _гейл, nóg_, _геҙе, _לאסט_, 
   {{0xa3c80073,0x00000000,0x00000000,0x00000000}},	//   ळुन_, --, --, --, 
   {{0x7bd80488,0x291c0f40,0x2f0001e7,0xa6e00bcd}},	// [ab20] _yevu, ātas_, hóg_, óðba, 
   {{0xf1b80e04,0xb3e80b61,0x92c000cc,0xe738009b}},	//   _raša_, لعمل_, _এয়ে_, _бео_, 
   {{0xf1b814a6,0xe2988c15,0xe12401c0,0x00000000}},	//   _saša_, гаж_, өмжи, --, 
   {{0xf1b88c16,0x26dc0024,0x2f00007b,0x245401a8}},	//   _paša_, štos_, dóg_, _dæma_, 
   {{0xcfcc03f4,0x09c4009e,0x0a380092,0x6614022e}},	//   _রাজন, ্ণপা, _እየሰራ, meyk, 
   {{0xf1b88c17,0x66148c18,0x2f000332,0x00000000}},	//   _vaša_, leyk, fóg_, --, 
   {{0x7bd88c19,0x2f008c1a,0xdf0801a9,0x00000000}},	//   _revu, góg_, уэлл_, --, 
   {{0x7bd88c1b,0x20d88c1c,0x66148c1d,0x00000000}},	//   _sevu, _مورخ_, neyk, --, 
   {{0x7bd800f3,0xc1740133,0x00000000,0x00000000}},	//   _pevu, _بگات, --, --, 
   {{0xf1b005d9,0x661403b2,0x2f008477,0x00000000}},	//   _آءِ_, heyk, bóg_, --, 
   {{0x7bd88c1e,0x7eb00022,0x8d7001d5,0x2f000332}},	//   _vevu, _ẽpua, قایا, cóg_, 
   {{0x7bd80083,0xfa6801d5,0x8f9800df,0x00000000}},	//   _wevu, рчоқ_, _גיבי, --, 
   {{0xd90c0502,0x7bd88c1f,0x661403e0,0x9a740092}},	//   رید_, _tevu, deyk, ከለኛው_, 
   {{0xb8d00073,0x51c807d2,0x420400cd,0x37d800eb}},	//   _ओळ_, _ﺗﯩﻠﺸ, रभुः_, _তাহর, 
   {{0x2c640014,0xdb0c01e1,0x00000000,0x00000000}},	//   _بدنُ, _àjàs, --, --, 
   {{0x629800b0,0xda7802e8,0x66140162,0x245402d2}},	//   _ūton, _щял_, geyk, _ræma_, 
   {{0x73d864b6,0x26dc0765,0x58840209,0x245403b2}},	// [ab30] идар_, átor_, _гына, _sæma_, 
   {{0xf8b402ab,0xd7f81eb8,0xbebc0055,0x00000000}},	//   ंदीप, _суи_, _trīh, --, 
   {{0x59c0012c,0x26dc00f3,0x018800d1,0x661403e0}},	//   वुअर, štor_, ەپنى_, beyk, 
   {{0xd58404d3,0x66140309,0x8af8008f,0x50640116}},	//   _هێزه_, ceyk, רלאז, әтда, 
   {{0xdd840050,0x6f00045a,0x712415bf,0x00000000}},	//   _آو_, _sqlc, تىشم, --, 
   {{0xb9fc0092,0x2454032e,0x2f0000ae,0xc2c400db}},	//   _ፀጋ_, _tæma_, tóg_, زيۇي, 
   {{0xee388c20,0xdcec00b8,0x00000000,0x00000000}},	//   инк_, _ādān, --, --, 
   {{0xece88c21,0x2f008c22,0xace80124,0x7bdc148b}},	//   адил_, róg_, амиа_, ðrun, 
   {{0xdc8802d3,0xb2b80150,0x622400db,0x63b000df}},	//   _ምእላይ_, _اﻗﭙﺎ, _بوقە, ĝenŝ, 
   {{0xf1b80427,0x2f000332,0x3ea00003,0x66140205}},	//   _kašo_, póg_, ċita_, zeyk, 
   {{0x2fc412ed,0x66140113,0x6e9400f3,0x00000000}},	//   _iflg_, yeyk, _дижу, --, 
   {{0xf1b80b3d,0x626c0115,0x4c0000f1,0x6d34014b}},	//   _mašo_, nĝop, _کېدل, _мееф, 
   {{0xbd9002d3,0x320c00e8,0x98a402b5,0xf1b80153}},	//   _ምስቶም_, _mbey_, _ōnā_, _lašo_, 
   {{0x2d9c016c,0xa6c872a0,0x66140784,0x5d78010f}},	//   _izwe_, илга_, weyk, _דאנק, 
   {{0xa7a88c23,0x320c8c24,0xf1b80fb7,0x66148c25}},	//   рква_, _obey_, _našo_, teyk, 
   {{0xe618033a,0x24e800db,0x630400e5,0x37dc00cc}},	//   јда_, имби_, ےوال, _বাণৰ, 
   {{0x66140050,0xa4448c26,0xef04004b,0xe7380276}},	// [ab40] reyk, онад, _ګڼ_, _ӂен_, 
   {{0x29100124,0x66145c6b,0x958000a8,0x37dc00cc}},	//   _ipya_, seyk, флуе, _বাথৰ, 
   {{0xe7388c27,0xdb042776,0xbebc00b8,0x00000000}},	//   _тен_, _âmôl, _hrīv, --, 
   {{0x29100a73,0x661402d1,0xbebc00ef,0x6a9000d1}},	//   _kpya_, qeyk, _krīv, ﯜﺭﯛﺵ_, 
   {{0x64a48c28,0x37dc0183,0x40340139,0xd24c01d9}},	//   _мама, _বাতৰ, зелс, خنن_, 
   {{0x291000b2,0x00000000,0x00000000,0x00000000}},	//   _mpya_, --, --, --, 
   {{0xddc00356,0x878c0b82,0x5fc400bc,0x91c800fe}},	//   _cloş, _መድሃኔ_, रुषल, _ৱাৰ্, 
   {{0xb35401b9,0x7d043f50,0x00000000,0x00000000}},	//   _عینا_, _äisk, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4cc0015b,0x795001e1,0xb5cc01ec,0xcc841095}},	//   _শিখু, _lówú, _ﺑﯩﻠﻌ, ينيه_, 
   {{0x2d9c0107,0x29100309,0x3f9801d3,0x39b8009d}},	//   _ezwe_, _apya_, _áru_, йлнэ_, 
   {{0xbebc0029,0xf1b00c2e,0x00000000,0x00000000}},	//   _brīv, ुँचन, --, --, 
   {{0xddc00276,0xd1dc0023,0x00000000,0x00000000}},	//   _emoţ, _ነናብ_, --, --, 
   {{0xd7f88c29,0x166c0248,0x00000000,0x00000000}},	//   шум_, _ọ̀ún_, --, --, 
   {{0x29108c2a,0x88948c2b,0x00000000,0x00000000}},	//   _epya_, фирх, --, --, 
   {{0x88b0016b,0xf1b80006,0x00000000,0x00000000}},	//   _apɛd, _rašo_, --, --, 
   {{0xf1b80219,0xbebc1981,0x00000000,0x00000000}},	// [ab50] _sašo_, _grīv, --, --, 
   {{0xf1b88c2c,0xc4f82688,0xdb0c0241,0x00000000}},	//   _pašo_, تعفا_, _òjór, --, 
   {{0x92e80a11,0x8c1802e4,0x6f0c033f,0x626c01e4}},	//   شراق_, שובי, łacz, rŝon, 
   {{0xf1b8151c,0x9550001f,0x78688c2d,0x6738007c}},	//   _vašo_, መልክተ, džvi, åtje, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x44b406bb,0x37d8015b,0x645c002f,0x60200108}},	//   _обяс, _তাঁর, chpi, едша, 
   {{0x09c404c5,0xef181086,0x001802d5,0x43940064}},	//   ্ণতা, ёми_, іўшы_, _жарс, 
   {{0xee388c2e,0x3e840201,0x64b40bc9,0x6dc00137}},	//   сни_, _ይቅርታ_, _uņic, رۅتۅ, 
   {{0xc0c8005b,0xd7d80073,0xc6940a7c,0x00000000}},	//   _духе_, भराच, ואק_, --, 
   {{0xeb980510,0xfe70315b,0x00000000,0x00000000}},	//   йип_, _یدن_, --, --, 
   {{0xf98830fb,0xea888c2f,0x7c648c30,0xbebc0171}},	//   _ער_, йбол_, بايل, _esīb, 
   {{0xae04005e,0xb3d002f5,0xc0ec0023,0x94080073}},	//   _ءوشى, াণিজ, ቀሙሉ_, स्तच_, 
   {{0x2d9c01f0,0x9f50014a,0x7e0000c7,0x4c8001d5}},	//   _uzwe_, ädön_, _рҧыз, _оғиз, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2bd005ba,0x186414b7,0xa098010f,0x00000000}},	//   _द्या, чари_, מישט, --, 
   {{0xaa44035b,0x00000000,0x00000000,0x00000000}},	//   _хеил, --, --, --, 
   {{0x29100451,0x958004f0,0xbebc0055,0x645c045a}},	// [ab60] _upya_, елте, _hrīt, thpi, 
   {{0x69c40066,0xe7d001d9,0xbebc1a14,0x00000000}},	//   lcke, _سۅرگ, _krīt, --, 
   {{0xdc9800c8,0x00000000,0x00000000,0x00000000}},	//   ציעל, --, --, --, 
   {{0x69c48c31,0x645c8c32,0x21a400d8,0xa508010a}},	//   ncke, shpi, пием, _лема_, 
   {{0x68e412bf,0x69c4014b,0xb8640633,0x00000000}},	//   nskd, icke, _رایو, --, 
   {{0xa2e401c0,0x00000000,0x00000000,0x00000000}},	//   _ногд, --, --, --, 
   {{0x44440226,0xe2988c33,0x4438045a,0x91000139}},	//   mj_, _гав_, _inr_, _үпсе, 
   {{0x44448c34,0x2bd01d8a,0x69c48c35,0x00000000}},	//   lj_, _द्बा, jcke, --, 
   {{0x44448c36,0x443832ff,0x61e08c37,0x1fb48c38}},	//   oj_, _knr_, maol, _есер, 
   {{0x44448c39,0x61e08c3a,0x44388c3b,0x3b548c3c}},	//   nj_, laol, _jnr_, дкор, 
   {{0x44448c3d,0x44388c3e,0x1f54036b,0x8ae00006}},	//   ij_, _mnr_, _этаё, ніял, 
   {{0x61e08c3f,0x44388c40,0x9d4421fa,0xee28007b}},	//   naol, _lnr_, _неед, _وأنه_, 
   {{0x44440ac5,0xbd541c93,0x60c00309,0xcc3000e5}},	//   kj_, _تراژ, nqom, ذریع, 
   {{0x44448c41,0x61e08c42,0x8c4002e8,0x69c48c43}},	//   jj_, haol, _пече, acke, 
   {{0x44448c44,0x61e08c45,0x7c388c46,0xdb0802d2}},	//   dj_, kaol, _invr, _affö, 
   {{0x44448c47,0x44380c86,0x61e000af,0x69c419f5}},	//   ej_, _anr_, jaol, ccke, 
   {{0x44388c48,0x61e08c49,0x38c80e60,0x44441427}},	// [ab70] _bnr_, daol, _بابی_, fj_, 
   {{0x44388c4a,0x7c288c4b,0x236400c8,0xd4988c4c}},	//   _cnr_, nddr, ĝojn_, ёра_, 
   {{0x44388c4d,0x20c008ce,0x05840107,0x2364010f}},	//   _dnr_, _aði_, _ҷурм, ŝojn_, 
   {{0x44448c4e,0x61e00770,0x44380129,0x00000000}},	//   aj_, gaol, _enr_, --, 
   {{0x4438070d,0x44440354,0x60c00921,0x7c381a7c}},	//   _fnr_, bj_, gqom, _onvr, 
   {{0x44388c4f,0xe9f401ec,0x444415c0,0x00000000}},	//   _gnr_, _رﺎ_, cj_, --, 
   {{0x69c404f3,0x752c8c50,0xef1802bf,0x8b0401ef}},	//   ycke, lvaz, іми_, _maří, 
   {{0x7c281af3,0x7c388c51,0x116404fb,0xd2447c3f}},	//   eddr, _anvr, _فلزی_, _ээги, 
   {{0x63a00198,0x752c02f0,0x2b480210,0x00000000}},	//   ƙonc, nvaz, _łac_, --, 
   {{0xbebc0882,0x8b0400bc,0x6ab48c52,0x00000000}},	//   _prīt, _naří, _siyf, --, 
   {{0x8d8411fc,0x4ea4036b,0x4ba40137,0x00000000}},	//   _کشان, _ерда, чөдү_, --, 
   {{0x9e946073,0x7c38030a,0x69c4002d,0x9f480fac}},	//   _قانچ, _envr, ucke, ømål_, 
   {{0x752c08ad,0xbebc00ef,0xb60401d3,0x8c34014b}},	//   jvaz, _frīs, zzáé, _нодӣ_, 
   {{0x6e288c53,0x61e08c54,0x765c0432,0x68e405ac}},	//   ldeb, zaol, _alsy, rskd, 
   {{0x61e03b85,0x6ab4022f,0x66e40212,0x66040395}},	//   yaol, _tiyf, ьова, мпва, 
   {{0x44448c55,0x44388c56,0x39a40421,0x60c00113}},	//   wj_, _snr_, _sūsū_, yqom, 
   {{0xe3b08c57,0xfbc4012c,0x6e288c58,0x00000000}},	// [ab80] چرا_, लुकम, ideb, --, 
   {{0x44448c59,0xa3b800c6,0xe3b08c5a,0x765c01e3}},	//   uj_, زائر_, نرا_, _elsy, 
   {{0xf2c40046,0x6e280209,0x44448c5b,0x4438062c}},	//   есін, kdeb, rj_, _vnr_, 
   {{0x8b040316,0x444421e3,0x752c0433,0x00000000}},	//   _zaří, sj_, bvaz, --, 
   {{0x61e08c5c,0x51808c5d,0x6e288c5e,0x91e063e6}},	//   raol, куша, ddeb, точе, 
   {{0xf1a844e7,0x64a40323,0x61e08c5f,0x44380230}},	//   سانه_, _цага, saol, _unr_, 
   {{0x61e08c60,0x2d980112,0x9084007b,0x2bd00aff}},	//   paol, üsen_, بنوك_, _द्धा, 
   {{0x6e288c61,0x65a400b0,0xef9001d5,0x0fc00209}},	//   gdeb, _tōhī, دیمد, нйән, 
   {{0x7c38009d,0x93b00165,0x4ea002e8,0x16d8134e}},	//   _pnvr, _waʃt, ърша, _बब्ब, 
   {{0x6e380083,0x602402bf,0x6e280393,0x00000000}},	//   _enwb, _ідеа, adeb, --, 
   {{0x93f402e4,0x752c0433,0x7c288c62,0xdc9800db}},	//   וציא_, zvaz, rddr, йтүш_, 
   {{0x22440e4f,0x200c01f4,0x00000000,0x00000000}},	//   njok_, lffi_, --, --, 
   {{0xc0d4001f,0xbebc005f,0x8b0400bc,0x00000000}},	//   _ጭማሪ_, _trīs, _paří, --, 
   {{0x7c380204,0x752c0cf4,0xd6d80120,0x00000000}},	//   _unvr, vvaz, жта_, --, 
   {{0xbb5801c0,0x8b040118,0x626c01e4,0x00000000}},	//   _хайх_, _vaří, rŝoj, --, 
   {{0x6258006a,0xfe1406ab,0x32d40241,0xd91802e8}},	//   _sïon, _थॉमस_, _lúyò_, _дьо_, 
   {{0x7ae800cc,0x0ef8012d,0xd1dc0023,0x00000000}},	// [ab90] lsdt, _एम्स_, _ነናቱ_, --, 
   {{0xd4982626,0x986400e5,0x00000000,0x00000000}},	//   іра_, _کیڑے_, --, --, 
   {{0x3a280151,0x7ae800cc,0x97a401a9,0x00000000}},	//   _kaap_, nsdt, _юрил, --, 
   {{0x3a288c63,0xa6e00162,0xf1b8013a,0x00000000}},	//   _jaap_, _óðam, _kaši_, --, 
   {{0x3a288c64,0x65a402b5,0x1cc8031c,0x6e2805ac}},	//   _maap_, _pōhū, ླམས_, vdeb, 
   {{0x7ae80158,0xf1b80427,0x8234179e,0xccc40220}},	//   ksdt, _maši_, _یرقا, _ﺩﺍﺨل_, 
   {{0x2eb48c65,0x6e288c66,0xf1b800ef,0x00000000}},	//   нсис, tdeb, _laši_, --, 
   {{0x6d248c67,0x200c8c68,0x7ae80158,0xc1d400c7}},	//   едиз, affi_, dsdt, _аҩцә, 
   {{0xefbc001f,0x7dc400d1,0x00000000,0x00000000}},	//   ሰራው_, ختىك, --, --, 
   {{0xf1b81109,0xc01480df,0x6e283c02,0x321c012d}},	//   _naši_, _имущ, sdeb, lewy_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x321c0076,0xa6e01427,0x00000000,0x00000000}},	//   newy_, óðma, --, --, 
   {{0x644801b8,0x282c02d3,0x682c0023,0x00000000}},	//   öfik, _ብምክያ, _ብምርድ, --, 
   {{0x7ae80158,0x9d74010f,0x69dc03ce,0x00000000}},	//   bsdt, _אײנס_, परही, --, 
   {{0x6a9400d6,0xa30c00e1,0x28200014,0x25a00210}},	//   _приє, _सहेज_, نژھہ, _szkl_, 
   {{0xe9d80372,0x80e004c5,0x3a2834b6,0xe9a469aa}},	//   _эки_, _নমস্, _gaap_, _пайп, 
   {{0xdbe001e1,0xa6c8022e,0xb8140183,0x00000000}},	// [aba0] _béèd, _grаn, ায়ত_, --, 
   {{0xf1b885a2,0x245401a8,0xd8d4010f,0x00000000}},	//   _gaši_, _kæmi_, _רויט_, --, 
   {{0x64a42e47,0x3a2806be,0xc33000d1,0x00000000}},	//   _җава, _yaap_, جەز_, --, 
   {{0x321c0ea0,0x77900345,0xd1c400d8,0x00000000}},	//   gewy_, _ئیفا, елце_, --, 
   {{0x6604035a,0x2244003e,0xda74010f,0x00000000}},	//   _ickk, rjok_, עגנט_, --, 
   {{0x5574008f,0x2244143a,0x00000000,0x00000000}},	//   _װעלן_, sjok_, --, --, 
   {{0x53a04286,0xd0402374,0x2454032e,0x200c01f4}},	//   _барб, اپىي, _næmi_, rffi_, 
   {{0xc34402d3,0x7ae805ac,0x00000000,0x00000000}},	//   _የሩሳሌ, vsdt, --, --, 
   {{0x644c8c69,0x3a280549,0x5c040dce,0x00000000}},	//   _kobi, _raap_, няна, --, 
   {{0x644c8c6a,0x7ae805ac,0xc2b800f1,0x3a2800ef}},	//   _jobi, tsdt, _راځئ_, _saap_, 
   {{0x1c440220,0x1ed88c6b,0x3a2800e8,0x6604035a}},	//   _үнем, _رباب_, _paap_, _ockk, 
   {{0x644c1aac,0x2454008c,0x0ba08c6c,0xf1b800f3}},	//   _lobi, _dæmi_, ышым, _saši_, 
   {{0x2bd06526,0xf1b8005f,0x644c0548,0xc9848c6d}},	//   _द्वा, _paši_, _oobi, гури, 
   {{0x644c8c6e,0x660402d0,0x1fdc012c,0xdd8c01d3}},	//   _nobi, _ackk, _नजोड, _پوڈ_, 
   {{0xf1b88c6f,0x3a28002d,0xd6c0065f,0x00000000}},	//   _vaši_, _taap_, امری, --, 
   {{0x3a288c70,0x4b340375,0xf8b00014,0xa6c8022e}},	//   _uaap_, _טרול_, _چکس_, _trаn, 
   {{0x349405f5,0x35b40b01,0xd7e400d4,0xeaa8010f}},	// [abb0] ваар, тбар, _піно, _קױפֿ, 
   {{0x644c8c71,0x44988c72,0x386c257d,0x37c40032}},	//   _cobi, евую_, ëerd_, _шәмб, 
   {{0xa2c001e0,0xade000c5,0xae20012d,0x00000000}},	//   иәтк, _गजलन_, _मसलन_, --, 
   {{0x644c0295,0x71788c73,0xdbe00248,0x63a00198}},	//   _eobi, мбер_, _dééd, ƙonn, 
   {{0x00c80220,0x92680022,0x913000c7,0x00000000}},	//   елік_, _ҵраа_, ыҭах, --, 
   {{0x644c7082,0xa1540063,0x00000000,0x00000000}},	//   _gobi, ђају_, --, --, 
   {{0xf1a800f2,0x00000000,0x00000000,0x00000000}},	//   ساچه_, --, --, --, 
   {{0x644c8c74,0x43940354,0xa2bc27c6,0x00000000}},	//   _zobi, _сасс, षदर्, --, 
   {{0x51848c75,0x644c8c76,0x2d9800b5,0x245402d2}},	//   _чува, _yobi, æse_, _sæmi_, 
   {{0x78680010,0x7f500092,0x00000000,0x00000000}},	//   zžvr, ንያዎች, --, --, 
   {{0xdae400f1,0x00000000,0x00000000,0x00000000}},	//   نځيو_, --, --, --, 
   {{0x2bd01a2a,0x8fc00124,0x63b8148b,0x80d81be1}},	//   _द्रा, _раҧҵ, _útne, नीके, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfaf800da,0xeaf8866a,0x9c1001e1,0x00000000}},	//   brī_, _قربت_, _họng, --, 
   {{0x644c8c77,0x1fe439db,0x00000000,0x00000000}},	//   _robi, _নামস, --, --, 
   {{0x644c8c78,0xdbe007ea,0x8b9001d5,0x00000000}},	//   _sobi, _rééd, _ирқч, --, 
   {{0x644c8c79,0xa9680276,0xdbe0002e,0xf1b88c7a}},	// [abc0] _pobi, _ципа_, _sééd, _kašu_, 
   {{0x443c0dd4,0x644c036b,0xf1b816a3,0x626c00df}},	//   ñv_, _qobi, _jašu_, nŝov, 
   {{0x644c0483,0xf1b80e3c,0x920000ef,0x00000000}},	//   _vobi, _mašu_, _čārt, --, 
   {{0x644c8c7b,0x38600099,0xf1b800de,0x00000000}},	//   _wobi, _zlhr_, _lašu_, --, 
   {{0xa0688c7c,0x6264006c,0x399c00e5,0x00000000}},	//   мада_, _یارق, mású_, --, 
   {{0xc7b80fcf,0x10a00902,0x399c01d3,0x00000000}},	//   žđu_, аичн, lású_, --, 
   {{0xe0d00014,0xe2b400c0,0xa2e40408,0x00000000}},	//   _چٲر_, _асаэ, _шовд, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa3d435e8,0x6280198f,0xf1d401c0,0x6008023b}},	//   _सभा_, mnoo, _сөхө, _онам_, 
   {{0x62808c7d,0x8c400120,0xf1a88c7e,0xad1400ec}},	//   lnoo, иење, _ساقه_, اسيڪ, 
   {{0x8650013f,0x62808c7f,0xe7e4012d,0x00000000}},	//   mmɔf, onoo, करना_, --, 
   {{0x62808c80,0x6f7804ac,0x05b40034,0xb6c400fb}},	//   nnoo, _אָנג, ूखाब, ҫөнд, 
   {{0x94000c2e,0xd8740597,0x8f200113,0x62800548}},	//   _लालच_, ناسب, _t茜cn, inoo, 
   {{0x7d008c81,0x5c544cc1,0x0d8001e0,0x245408a5}},	//   mums, _штеф, _әлән, _kæmu_, 
   {{0x62808c82,0x8c180302,0xb3440200,0x27880139}},	//   knoo, _חווי, _muçë, ертү_, 
   {{0xeff4001f,0x932403e6,0xb594023a,0x00000000}},	//   ለመደ_, ێران, гибш, --, 
   {{0x7d008c83,0x55040801,0x26dc0356,0x00000000}},	// [abd0] nums, ъчва, âtor_, --, 
   {{0xd3788c84,0x39580158,0x62800ea0,0x6d5c0e89}},	//   мче_, myss_, enoo, ùsai, 
   {{0x7d00198f,0xbebc0055,0x399c00e5,0xafe40150}},	//   hums, _asīm, bású_, қойл, 
   {{0x7d008c85,0x62808c86,0xcb10008f,0x00000000}},	//   kums, gnoo, ילע_, --, 
   {{0x7d008c87,0x8544084c,0x307402ec,0x395884d6}},	//   jums, _кэре, лукс, nyss_, 
   {{0x62808c88,0x7d008c89,0x00000000,0x00000000}},	//   anoo, dums, --, --, 
   {{0x62808c8a,0x2f8800c7,0x6a6400e5,0x00000000}},	//   bnoo, хәан_, _hófe, --, 
   {{0x9f5c0548,0xf1b800f3,0xc0d4001f,0x3958143a}},	//   _abtó_, _sašu_, _ያህሉ_, kyss_, 
   {{0x7d008c8b,0xf1b800da,0x5fc400bc,0xec540139}},	//   gums, _pašu_, रुङल, гънэ, 
   {{0x3958286e,0x399c01d3,0xcf24007b,0x00000000}},	//   dyss_, zású_, _لرؤي, --, 
   {{0xf1b88c8c,0x626c00df,0x3b8400fb,0x00000000}},	//   _vašu_, rŝov, ҫлөг, --, 
   {{0x7d008c8d,0x7f58136b,0x1864036b,0x37dc03d4}},	//   bums, _шахс_, қаси_, _বাগৰ, 
   {{0x7d008c8e,0x9400033f,0x7d040036,0x6d5c0158}},	//   cums, _लांच_, _äisp, øsad, 
   {{0x80d801ad,0x6c78010f,0xebe4004e,0x00000000}},	//   नीटे, _ראַפ, _сокп, --, 
   {{0x91e0007d,0x399c01ed,0x628060b7,0xf1b801a6}},	//   खराज_, tású_, ynoo, _zašt_, 
   {{0xe4d800db,0x4904104e,0xd6248c8f,0x62800009}},	//   فورت_, _күмг, лосе_, xnoo, 
   {{0xc224221d,0x00000000,0x00000000,0x00000000}},	// [abe0] یکرو, --, --, --, 
   {{0x245402d2,0x00000000,0x00000000,0x00000000}},	//   _næmt_, --, --, --, 
   {{0xe1f846fd,0x29008c90,0xfd640241,0xb17c01f1}},	//   еге_, luka_, _burọ, _reťa, 
   {{0xc0d40201,0xe2840588,0xe6448c91,0x62800099}},	//   _ያህል_, ылеи, _семп, unoo, 
   {{0x628022a9,0xd6cc02f2,0x7d00022e,0xb17c01ef}},	//   rnoo, _وقی_, xums, _peťa, 
   {{0x62808c92,0xed580118,0x1b1800eb,0xf8d800cc}},	//   snoo, dyž_, ধিতে_, _তিমথ, 
   {{0xe8144466,0x7d003302,0x245408a5,0x628016ca}},	//   द्या_, wums, _dæmt_, pnoo, 
   {{0xe2a81698,0x3f988c93,0x7d008c94,0xae700131}},	//   _سازن_, _ørum_, tums, يۇلغ, 
   {{0x29008c95,0x127804ac,0xa0a48c96,0x9be40024}},	//   juka_, _נאמע, _баад, лінк, 
   {{0x7d008c97,0x7b148c98,0x8d14007b,0x525c0055}},	//   rums, адох, ازير_, _ṣāṭk, 
   {{0xe3200489,0x645c0357,0x28bc03ce,0x93f8010f}},	//   _ོགསཔ_, ikpi, _एंजि, עלטי, 
   {{0x29008c99,0xfaf800e2,0x5334008f,0x645c000d}},	//   fuka_, dzīt_, אנטן_, hkpi, 
   {{0xf1b801fa,0x29008c9a,0xcfd402f5,0x7d000ba7}},	//   _hašr_, guka_, _সযতন, qums, 
   {{0x36d48c9b,0x27e803f9,0x39588c9c,0xdc281176}},	//   иогр, gabn_, ryss_, _سسته_, 
   {{0x2124003e,0x1a7402dd,0x7eb000c7,0x2900035b}},	//   hwoh_, _бұны_, _ẽpya, auka_, 
   {{0x8f98011a,0x00000000,0x00000000,0x00000000}},	//   גילי, --, --, --, 
   {{0x29008c9d,0x27e80198,0x00000000,0x00000000}},	// [abf0] cuka_, babn_, --, --, 
   {{0xa5080075,0xc1dc0150,0x00000000,0x00000000}},	//   ئىلە_, _ﺇﺸﺭﺍ, --, --, 
   {{0xd1488c9e,0x977c030d,0x00000000,0x00000000}},	//   کشان_, _хупă_, --, --, 
   {{0x6ed00171,0x68ec0139,0x37dc00cc,0x00000000}},	//   _jābe, _ändä, _বাটৰ, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x008400d6,0x626c0115,0xe2a402d2,0x00000000}},	//   бліо, fŝos, _óðni_, --, 
   {{0x29008c9f,0xe7e40574,0xa064311c,0x72440014}},	//   zuka_, करता_, раща_, _پھال, 
   {{0xee388ca0,0x29008ca1,0x764c8ca2,0x43840597}},	//   тни_, yuka_, njay, _الفق, 
   {{0x3f8c009a,0x7db402d5,0x2900005a,0x82888ca3}},	//   _exdu_, йсьц, xuka_, _ссрб_, 
   {{0x764c8ca4,0x3f640cef,0xdbe001e7,0xc58801ec}},	//   hjay, ртәб, _féíd, _ﺭﺃﻴﻨ_, 
   {{0x29008ca5,0x798c0429,0x6ed000ef,0xeb980114}},	//   wuka_, _axaw, _bābe, ђим_, 
   {{0x7bdc0162,0xfaf80171,0x00000000,0x00000000}},	//   ðrur, ezīs_, --, --, 
   {{0x290004ba,0x764c8ca6,0x0bb4004e,0x37dc05ac}},	//   uuka_, djay, _өткө_, _বাজৰ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x66e48ca7,0x7c948ca8,0x798c02d0,0x6d48005a}},	//   роба, _اشنا, _exaw, lxea, 
   {{0x29008ca9,0x7afc8caa,0xfaf800e2,0x764c7dec}},	//   puka_, árte, rzīt_, gjay, 
  
   {{0x8d78044e,0x63a00198,0x29006ae5,0x6d486d50}},	// [ac00] _እትብል_, ƙonk, quka_, nxea, 
   {{0xa3b800cf,0x6ed00171,0x61dc0303,0x00000000}},	//   ناار_, _zābe, मर्ष, --, 
   {{0x645c3c36,0xb864131e,0xa1c400db,0x764c0055}},	//   rkpi, _دايو, абед, bjay, 
   {{0xe5781188,0x645c8504,0x6658010a,0x00000000}},	//   _азм_, skpi, _рамă, --, 
   {{0xb17c01f1,0xcfcc0183,0x60248cab,0x00000000}},	//   _deťo, _ৰাজন, идда, --, 
   {{0x212403a2,0x626c01e4,0x99880118,0x24500133}},	//   rwoh_, tŝos, zdců_, _گۆڕس, 
   {{0xe29805f5,0xab6003e0,0x00000000,0x00000000}},	//   _аав_, çüld, --, --, 
   {{0x4e90009a,0x00000000,0x00000000,0x00000000}},	//   يشير, --, --, --, 
   {{0xbebc005f,0x00000000,0x00000000,0x00000000}},	//   _krīz, --, --, --, 
   {{0xa0a439af,0x00000000,0x00000000,0x00000000}},	//   _тазд, --, --, --, 
   {{0xbab805f5,0xd434008d,0x8c5000f7,0xcdcc00f3}},	//   лгох_, בריק_, تئيا, _мњ_, 
   {{0x255c166a,0xddc00306,0xeac80051,0x0dc40117}},	//   _kālā_, _hmož, _sẹc_, _куши_, 
   {{0xdd908cac,0x255c0055,0x0c7007d6,0x00000000}},	//   _بوش_, _jālā_, صدید, --, 
   {{0x61188cad,0x255c00cd,0x00000000,0x00000000}},	//   mālā, _mālā_, --, --, 
   {{0xe814041c,0x255c8cae,0x7af401d9,0x36d48caf}},	//   द्धा_, _lālā_, _آبش, собр, 
   {{0x798c0b89,0x7e60009a,0x59ac00bc,0x8f18011a}},	//   _txaw, nkmp, _घरपर, כולת, 
   {{0x764c8cb0,0x611800da,0xbebc0171,0xda6400ec}},	// [ac10] rjay, nālā, _brīz, _ماکي, 
   {{0xe8143174,0x3354004e,0x00000000,0x00000000}},	//   द्दा_, бүгө_, --, --, 
   {{0xbebc005f,0x78b40175,0x6a6402d2,0x318405a2}},	//   _drīz, mmzv, _hófa, әтең, 
   {{0x61180a30,0x255c00cd,0xa3080014,0x644801f4}},	//   kālā, _bālā_, ارٕے_, öfir, 
   {{0x058409a5,0x823416ac,0x00000000,0x00000000}},	//   _дурм, ترلا, --, --, 
   {{0x255c0069,0x2c680241,0xbebc0171,0xa92002d2}},	//   _dālā_, _kúde_, _grīz, _áþen, 
   {{0xdfcc8cb1,0x6a643b7b,0xbebc0055,0xa2803a56}},	//   ريي_, _lófa, _hrīy, _کینو, 
   {{0x6d4805f5,0xbebc0055,0x2f3400dc,0x00000000}},	//   txea, _krīy, _vāg_, --, 
   {{0x7c80001f,0xbef402fb,0x245401bf,0x00000000}},	//   _ይኖራል_, _číňa, _kæmp_, --, 
   {{0xbebc002b,0xe00c8cb2,0xf20c0037,0xdd8c01d3}},	//   _apīd, _सायद_, _हाड़_, رڈن_, 
   {{0x201003be,0x69a8000d,0xd17401af,0x00000000}},	//   əyi_, _घरही, _сыңы, --, 
   {{0xddc009a8,0xbd9801f2,0x61183da0,0x00000000}},	//   _zmož, ịpụt, bālā, --, 
   {{0xbebc0171,0xfe7000ae,0x61180055,0x00000000}},	//   _spīg, _تدل_, cālā, --, 
   {{0x7eac000f,0x4acc0490,0x00000000,0x00000000}},	//   rûpe, _संपव, --, --, 
   {{0xefc82295,0x00000000,0x00000000,0x00000000}},	//   _አንድ_, --, --, --, 
   {{0xfd64004d,0xf4f0031c,0x00000000,0x00000000}},	//   _nguờ, _བྷངྒ_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [ac20] --, --, --, --, 
   {{0xefc8001f,0xe6100214,0x962400e2,0xd5ac1291}},	//   _አንዴ_, _کشد_, _apņē, رفل_, 
   {{0xefbc4be7,0xc5f400bd,0xb17c01f1,0xb6080171}},	//   ደራዊ_, ঙ্গা_, _deťm, _bišķ, 
   {{0xdb98008f,0x1718008f,0x255c0055,0x21680124}},	//   אסער, _גוטע, _pālā_, лиеи_, 
   {{0x26c00a73,0xef640aba,0x78c00213,0xa0a45090}},	//   _iiko_, çını_, _üzvü, бадд, 
   {{0x26c08cb3,0x63b88cb4,0xf1a81ec7,0x2328234c}},	//   _hiko_, _útno, جامه_, _йоги_, 
   {{0x26c08cb5,0x54b00304,0xb22c0171,0x101000db}},	//   _kiko_, _хәтф, _šļūk, سبود, 
   {{0x26c023e0,0xe2988cb6,0xdee401b9,0x61181a14}},	//   _jiko_, _саб_, _ҳожи, tālā, 
   {{0x26c08cb7,0xefc8001f,0x00000000,0x00000000}},	//   _miko_, _አንዷ_, --, --, 
   {{0xddc0278a,0x26c08cb8,0x61180f40,0xbebc00e2}},	//   _umož, _liko_, rālā, _spīd, 
   {{0x26c007dd,0x6a6401a8,0x00000000,0x00000000}},	//   _oiko_, _sófa, --, --, 
   {{0x26c08cb9,0x39b801c0,0x1b1803d4,0xa0a40107}},	//   _niko_, илнэ_, ধিলে_, _таҷд, 
   {{0x2c680030,0xd7f801b9,0x5ef800cc,0x00000000}},	//   _súde_, лув_, _আহিও_, --, 
   {{0x26c08cba,0x5884026f,0xec3401d9,0x00000000}},	//   _aiko_, сыма, _وونگ, --, 
   {{0x26c000b4,0xeac80016,0x00000000,0x00000000}},	//   _biko_, _hẹn_, --, --, 
   {{0x6a648cbb,0x26c0793c,0xbebc00cd,0x6ed000de}},	//   _tófa, _ciko_, _prīy, _jāba, 
   {{0x26c01bce,0x25a0033f,0xa5c0010b,0xb7d81f0d}},	// [ac30] _diko_, _cykl_, дөре, _پوجا_, 
   {{0x26c01e0b,0x27e4004d,0x7d0008c2,0x13680022}},	//   _eiko_, _đong_, irms, лшеи_, 
   {{0xefc80201,0x00000000,0x00000000,0x00000000}},	//   _አንዱ_, --, --, --, 
   {{0x26c000ca,0xd9f802ab,0x1ae800fe,0x92683004}},	//   _giko_, ्लित_, _কমাই_, ырза_, 
   {{0x88b00134,0x4acc687b,0xc33001d9,0xe81400cd}},	//   _asɛy, _संभव, وٕے_, द्वा_, 
   {{0x26c08cbc,0x00000000,0x00000000,0x00000000}},	//   _ziko_, --, --, --, 
   {{0x26c08cbd,0xa3d4012d,0x00000000,0x00000000}},	//   _yiko_, सडर_, --, --, 
   {{0x26c002c4,0x6ed00055,0xeac80208,0x1284104c}},	//   _xiko_, _cāba, _bẹn_, _امری_, 
   {{0x2fc4020c,0x68e0025c,0x900835b6,0x00000000}},	//   _tglg_, _ħodo, _مزاق_, --, 
   {{0xc10431ed,0xec781ee3,0x61440075,0x10140014}},	//   _رومي, рпо_, _بىكە, _دبرد, 
   {{0x2dd48cbe,0xa6c8022e,0xaa488cbf,0xc05800cf}},	//   _джер, _jrаt, апна_, _اشقا_, 
   {{0x753c066d,0xa9a48cc0,0x6fe0015b,0x2d98004e}},	//   _orsz, жимд, _নায়ে, üses_, 
   {{0x26c08cc1,0x3d940022,0x27fc0210,0x00000000}},	//   _riko_, _еицр, ótno_, --, 
   {{0x26c08cc2,0x6ed000e2,0x8d9c0023,0x00000000}},	//   _siko_, _zāba, _ምስታፍ_, --, 
   {{0x26c08cc3,0x18a08cc4,0x98a00117,0x2a340024}},	//   _piko_, фарм, фире, _дэпр, 
   {{0xeac80ca8,0x00000000,0x00000000,0x00000000}},	//   _yẹn_, --, --, --, 
   {{0xa5080266,0x26c001c8,0xeac8001e,0xa3e8009d}},	// [ac40] реза_, _viko_, _kẹo_, идаа_, 
   {{0x26c07439,0x142000db,0x00000000,0x00000000}},	//   _wiko_, мдум, --, --, 
   {{0x26c08cc5,0xeac80016,0xe29801c0,0x6a6401d3}},	//   _tiko_, _mẹo_, ааж_, _jófo, 
   {{0xe8148cc6,0x290001d9,0xa3d400af,0xa5088cc7}},	//   द्रा_, orka_, _सभक_, _кема_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x29000014,0x6ed00055,0x00000000,0x00000000}},	//   irka_, _sāba, --, --, 
   {{0x7d040036,0x53a03004,0x6d5c143a,0x00000000}},	//   _äisz, _жарб, øsan, --, 
   {{0x63ac01fa,0x672001fa,0xef907983,0x7d541985}},	//   _izbn, _ćojl, ریند, звих, 
   {{0xddc0068f,0x9f5c011f,0xc344001f,0xbebc00b8}},	//   _umoż, _abtô_, _የሚጠቀ, _apīc, 
   {{0x61e01654,0xeac801fb,0x2900022f,0xbebc00b8}},	//   lbol, _vẹn_, drka_, _asīt, 
   {{0x29008cc8,0x2d9805c7,0xd90c036b,0xeac80051}},	//   erka_, üser_, چیب_, _dẹo_, 
   {{0x61e08cc9,0x29000198,0x5ce48cca,0xd90c8ccb}},	//   nbol, frka_, _дюка, نیب_, 
   {{0x61e08ccc,0x7cd801d5,0x49741cd0,0x00000000}},	//   ibol, _اوتز_, дляс, --, 
   {{0x6a6408a5,0x394800c7,0x23a80073,0xda580116}},	//   _hófl, азҭо_, _करंद, урүш_, 
   {{0x61e08ccd,0x29008cce,0x7c288ccf,0xddc004ba}},	//   kbol, arka_, medr, _onoŋ, 
   {{0x5a440166,0x00000000,0x00000000,0x00000000}},	//   _фэка, --, --, --, 
   {{0x61e0019b,0x37c40154,0xf3f88cd0,0x3914004e}},	// [ac50] dbol, ্রবর, йнаш_, _эмпр, 
   {{0x7c288cd1,0x93a4656c,0x61e08cd2,0xd7f80117}},	//   nedr, ошед, ebol, _туи_, 
   {{0x8650016b,0x7c2804cc,0x75d400db,0x00000000}},	//   mmɔn, iedr, _ىيدا, --, 
   {{0x42c80046,0x201c0067,0x325401d5,0xef644283}},	//   ігін_, _abti_, явер, çımı_, 
   {{0xdd8406d5,0x7c288cd3,0x2ca40267,0x25d4011a}},	//   _أو_, kedr, ylld_, _מורן_, 
   {{0x61e08cd4,0x94201e87,0x752c8cd5,0xa4f4031c}},	//   abol, _توسۇ, mwaz, _བྷིག_, 
   {{0x61e08cd6,0x752c8cd7,0x9f4c0100,0xf3f000fe}},	//   bbol, lwaz, nafè_, _চাপৰ_, 
   {{0x29008cd8,0x201c0327,0xeac801fb,0xece8013e}},	//   yrka_, _ebti_, _sẹo_, бдил_, 
   {{0x7c282df2,0xec781cd6,0x1d20005b,0x70587d60}},	//   fedr, йпи_, емым, _лаар_, 
   {{0x7c288cd9,0x2c688cda,0xeb04014b,0x00000000}},	//   gedr, _búda_, ппоп, --, 
   {{0xeb984490,0x752c5693,0x29000014,0xeac8004d}},	//   син_, hwaz, wrka_, _vẹo_, 
   {{0x752c8cdb,0x00000000,0x00000000,0x00000000}},	//   kwaz, --, --, --, 
   {{0x752c8cdc,0x7c2827bb,0x29000050,0x27f80198}},	//   jwaz, bedr, urka_, _pdpn_, 
   {{0xe6c41216,0x7c287635,0x6e2801d9,0x752c8cdd}},	//   كتري, cedr, leeb, dwaz, 
   {{0xa7a88cde,0x61e02d1c,0xe7380104,0x29000427}},	//   сква_, ybol, щев_, srka_, 
   {{0x88b0013f,0x6e288cdf,0x00000000,0x00000000}},	//   _apɛt, neeb, --, --, 
   {{0x752c8ce0,0x61e08ce1,0x64c48ce2,0x630400f1}},	// [ac60] gwaz, vbol, سيال, ړوال, 
   {{0x6e28022f,0x673c1710,0xeac80051,0x64a400c7}},	//   heeb, _trpj, _lẹm_, чаза, 
   {{0x248405ce,0xe7380724,0x752c0083,0x6e2804ba}},	//   đom_, _уен_, awaz, keeb, 
   {{0x752c8ce3,0x7c288ce4,0x2ab000dd,0x80a4033f}},	//   bwaz, zedr, lább_, _चीजे, 
   {{0x752c0117,0x6e288ce5,0x40348ce6,0xf7e80220}},	//   cwaz, deeb, делс, _ارۋى_, 
   {{0x9f4c004e,0x7e880118,0x20548ce7,0x7c2803ac}},	//   lafé_, měpi, ятер, xedr, 
   {{0x7c288ce8,0x6e288ce9,0xfa2c0327,0x63ac022e}},	//   vedr, feeb, _ཧྲའན_, _uzbn, 
   {{0x61e0036b,0x8e440131,0x9f4c8cea,0x7cd81302}},	//   qbol, كلىك_, nafé_, омир_, 
   {{0x7c288ceb,0x2ab000dd,0x62806583,0x63a00198}},	//   tedr, kább_, mioo, ƙons, 
   {{0x62808cec,0x7afc01d3,0x00000000,0x00000000}},	//   lioo, árto, --, --, 
   {{0x6e288ced,0x752c8cee,0x3f980022,0x9f4c03cd}},	//   beeb, zwaz, _âru_, kafé_, 
   {{0x7c288cef,0xaf480597,0x6e280009,0x9f4c00e8}},	//   sedr, _بشكل_, ceeb, jafé_, 
   {{0x984800a7,0x9e640133,0x00000000,0x00000000}},	//   бява_, _واڵن, --, --, 
   {{0x752c1529,0x9f4c0100,0x2ab000e5,0x00000000}},	//   vwaz, tafè_, gább_, --, 
   {{0x8c500214,0x8c18011a,0x6280005b,0xc7b80108}},	//   _سئوا, _הווי, kioo, зёт_, 
   {{0x752c8cf0,0x00000000,0x00000000,0x00000000}},	//   twaz, --, --, --, 
   {{0x752c009f,0x62808cf1,0xd8280111,0x74341171}},	// [ac70] uwaz, dioo, _лінк_, мнаф, 
   {{0x752c8cf2,0x6e288cf3,0x9f4c007f,0x00000000}},	//   rwaz, zeeb, pafè_, --, 
   {{0x752c8cf4,0x12c48cf5,0x6e280083,0x62800254}},	//   swaz, ستاپ, yeeb, fioo, 
   {{0x752c8cf6,0x628000af,0x9f4c01f5,0x00000000}},	//   pwaz, gioo, café_, --, 
   {{0x6e28193f,0x752c009a,0x021800e5,0x00000000}},	//   veeb, qwaz, سٹوں_, --, 
   {{0x6e282f99,0x6d5c143a,0x6140030d,0x00000000}},	//   weeb, øsam, теша, --, 
   {{0x9ed40831,0x7bdc0724,0x662401ed,0xc7d80375}},	//   үмәт_, ırul, _ütkö, לוגי_, 
   {{0x6d8c06d6,0x7bd8257c,0x00000000,0x00000000}},	//   ṱamb, _afvu, --, --, 
   {{0x6e288cf7,0x30140719,0x00d800f2,0x4acc0037}},	//   reeb, _одар, _فبلت_, _संहव, 
   {{0x6e286732,0xab648cf8,0xc05800c0,0x00000000}},	//   seeb, двол, _ніх_, --, 
   {{0x2ab0066d,0x6e280083,0x3af40108,0x00000000}},	//   vább_, peeb, няяс, --, 
   {{0x6e280009,0x37c40154,0x00000000,0x00000000}},	//   qeeb, ্রার, --, --, 
   {{0xed588cf9,0xf9c4005b,0x2ab000e5,0x18780023}},	//   _фол_, ещён, tább_, _ኣእጋር_, 
   {{0xf0ac0150,0x00000000,0x00000000,0x00000000}},	//   лдiң_, --, --, --, 
   {{0xb8d4033d,0x62800076,0x00000000,0x00000000}},	//   _छी_, yioo, --, --, 
   {{0xaab853a2,0x00000000,0x00000000,0x00000000}},	//   _بدتر_, --, --, --, 
   {{0xddc01224,0x9f4c020c,0x273400c7,0x62800108}},	// [ac80] _kloš, rafé_, _ẽndy_, vioo, 
   {{0xa2e4023a,0xe72801c0,0x00000000,0x00000000}},	//   дожд, _доод_, --, --, 
   {{0x62808cfa,0x00000000,0x00000000,0x00000000}},	//   tioo, --, --, --, 
   {{0xbebc0055,0x00000000,0x00000000,0x00000000}},	//   _apīn, --, --, --, 
   {{0x62808cfb,0xddc000f3,0x00000000,0x00000000}},	//   rioo, _ološ, --, --, 
   {{0x6280033d,0x2ff4515c,0x3ce00790,0x95b001af}},	//   sioo, ىتىڭ, _çivi_, _рөсх, 
   {{0x44388cfc,0x2214013e,0x62800108,0x00000000}},	//   _iar_, _офар, pioo, --, 
   {{0x44387a1e,0x6ab40142,0x7afc00e5,0xe108014b}},	//   _har_, _nhyf, ártm, _мебд_, 
   {{0x44388cfd,0x5c048cfe,0x4dd00131,0xddc0276e}},	//   _kar_, мяна, ختىس, _bloš, 
   {{0x3b548cff,0x51580375,0x44381c2e,0xbf1004b4}},	//   екор, _וכמו, _jar_, _бүкә, 
   {{0x44387d6a,0x4ae40b87,0x00000000,0x00000000}},	//   _mar_, мьям_, --, --, 
   {{0x44388d00,0x6ab40cfd,0xda78109a,0x6d4c00ae}},	//   _lar_, _chyf, іян_, ónaí, 
   {{0x8d70168d,0x44388d01,0x394c8d02,0xf1c000b8}},	//   _لاوا, _oar_, ães_, _kṣaḥ_, 
   {{0x399401f2,0x394c00e2,0x00000000,0x00000000}},	//   ụso_, ģes_, --, --, 
   {{0x321c03cb,0xf77000e5,0xdb4c0244,0x90780115}},	//   yfwy_, ھاڑ_, _ئێج_, קטלי, 
   {{0x44381574,0x8aa40588,0x00000000,0x00000000}},	//   _aar_, _ирыд, --, --, 
   {{0x7c388d03,0x44380375,0x00000000,0x00000000}},	// [ac90] _kavr, _bar_, --, --, 
   {{0x44388d04,0xe614151c,0x7c388d05,0x2ab000e5}},	//   _car_, čišč, _javr, mába_, 
   {{0xfa2c031c,0x2ab001d3,0xf3f000fe,0x81e000cc}},	//   _ཧྲོན_, lába_, _চাদৰ_, _দয়_, 
   {{0x44380c18,0x550401b9,0x6d5c03cd,0x67b8011a}},	//   _ear_, _очга, øsak, _ממתק, 
   {{0x44380c3e,0x912853f0,0x765c03ac,0x50a01456}},	//   _far_, تساق_, _iosy, نەرل, 
   {{0x44388d06,0x7c388d07,0x00000000,0x00000000}},	//   _gar_, _navr, --, --, 
   {{0x88b002ea,0xef6405f5,0x765c007f,0x27fc0210}},	//   _mpɛp, ээдү, _kosy, ótni_, 
   {{0xed580364,0x765c002d,0x7c385867,0xf1c0002b}},	//   зои_, _josy, _aavr, _eṣaḥ_, 
   {{0xad2404a9,0x44388d08,0xddc0389c,0x765c37b6}},	//   رىدى, _yar_, _ploš, _mosy, 
   {{0x5f0401d9,0x765c8d09,0x44388d0a,0x7c388d0b}},	//   संख्_, _losy, _xar_, _cavr, 
   {{0x7c388d0c,0x09c82677,0x6a84721f,0x40840672}},	//   _davr, रख्य, елна, _рутб, 
   {{0xdb1c012c,0x765c8d0d,0x9b400133,0x00000000}},	//   áván, _nosy, اچوو, --, 
   {{0xddc0000a,0x7c388d0e,0x2ab001d3,0x0c7c0023}},	//   _tloš, _favr, gába_, _ትገልጽ_, 
   {{0x260c0943,0xddc07313,0x2c740241,0x1b1c015b}},	//   _ḽo_, _uloš, _dùdù_, _বছরে_, 
   {{0x765c020c,0x6e388d0f,0xd5b401fb,0x44388d10}},	//   _bosy, _kawb, ếng_, _rar_, 
   {{0x7c3808ad,0x44388d11,0xe3b01b16,0xe8f88d12}},	//   _zavr, _sar_, ۇرا_, _ели_, 
   {{0x765c8d13,0x7c3803ee,0x26dc8d14,0x6e388d15}},	// [aca0] _dosy, _yavr, ūto_, _mawb, 
   {{0x44388d16,0x6e3800e8,0xe3b042ed,0x00000000}},	//   _qar_, _lawb, هرا_, --, 
   {{0xded4044e,0x00000000,0x00000000,0x00000000}},	//   _ካብኡ_, --, --, --, 
   {{0xe1f08d17,0xdebc0201,0x44388d18,0x6e380218}},	//   اسا_, ቶችን_, _war_, _nawb, 
   {{0xd0d402bf,0xe2a801d9,0xd12c01d9,0x00000000}},	//   едії_, _ہارن_, ٝمن_, --, 
   {{0x64a40510,0x442c007b,0x44380df4,0x6ed00055}},	//   _чага, _úd_, _uar_, _kābh, 
   {{0x6e388d19,0x7c3803b2,0xe2a88d1a,0x00000000}},	//   _bawb, _ravr, _فارن_, --, 
   {{0x7c3804b9,0x6ed000b8,0x2ab001d3,0x9ce40479}},	//   _savr, _mābh, yába_, нцол, 
   {{0x6e380100,0x9f4c0093,0x69c08d1b,0x7c380327}},	//   _dawb, mafí_, रेमी, _pavr, 
   {{0x9f4c0418,0x70380014,0x6d5c005b,0x7c3803e3}},	//   lafí_, _ٲسٕس_, äsaa, _qavr, 
   {{0x141800c8,0x7c388d1c,0x6ed00882,0x2ab000d2}},	//   הויב, _vavr, _nābh, wába_, 
   {{0x7c388d1d,0x2ab06293,0x00000000,0x00000000}},	//   _wavr, tába_, --, --, 
   {{0x765c8d1e,0x7c388d1f,0x984800a7,0xc8200023}},	//   _rosy, _tavr, пява_, _ስምምዕ, 
   {{0x765c5f71,0x2ab05f5b,0xb7881b15,0x6ed0002b}},	//   _sosy, rába_, дәме_, _bābh, 
   {{0x36d48c5d,0x5a440276,0x6ed000dc,0x4aac00c5}},	//   тобр, _зэпа, _cābh, _टीकव, 
   {{0x3138001f,0x69d80118,0x00000000,0x00000000}},	//   _በግብር, ětec, --, --, 
   {{0x765c00c0,0xd1f00092,0x97c0010a,0x00000000}},	// [acb0] _vosy, _ፍራቻ_, ăйсе, --, 
   {{0x850436b4,0xf3f000fe,0xbebc0171,0x94a801f7}},	//   اولن, _চাহৰ_, _spīl, ساءِ_, 
   {{0x72188d20,0x04c818a1,0xbebc0055,0x7afc621e}},	//   джер_, رومي_, _apīm, árth, 
   {{0x0f7014d4,0x00000000,0x00000000,0x00000000}},	//   ңғар, --, --, --, 
   {{0x321805d1,0x30740166,0x00000000,0x00000000}},	//   _ösym_, кукс, --, --, 
   {{0x6e388d21,0x1ae4015b,0xc0c80063,0x6ed0002b}},	//   _sawb, _কিনে_, нује_, _yābh, 
   {{0x20188d22,0x6e380455,0x7ff40214,0x00000000}},	//   òpia_, _pawb, اسها, --, 
   {{0x02a40276,0x6e440139,0x6e38014f,0xada454f2}},	//   _брум, теиз, _qawb, кайл, 
   {{0xb03400a6,0xa2c00139,0x00000000,0x00000000}},	//   _инаш, _тәфк, --, --, 
   {{0xc1b84e76,0x00000000,0x00000000,0x00000000}},	//   _ساقط_, --, --, --, 
   {{0xad241066,0x6e388d23,0x4f68030d,0x00000000}},	//   رىگى, _tawb, _эшам_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7ae40118,0x6ed000cd,0x00000000,0x00000000}},	//   _čite, _sābh, --, --, 
   {{0x3ea03466,0x00000000,0x00000000,0x00000000}},	//   čite_, --, --, --, 
   {{0x6ab403f6,0x6ed000ef,0x3774004e,0x00000000}},	//   _исих, _bābi, гытс, --, 
   {{0xd6240c5c,0x6ed0002b,0x00000000,0x00000000}},	//   косе_, _vābh, --, --, 
   {{0x1da00020,0xfa2c0135,0x65c463d7,0x6b8c0055}},	// [acc0] _ውጤቶች_, _ཧྲིན_, тбаа, _śagh, 
   {{0xdebc0020,0x69c00316,0x386c0d27,0xa7640124}},	//   ቶችና_, रेणी, ëert_, _акод, 
   {{0x66e421fe,0x291c0356,0xcfd400eb,0x00000000}},	//   _шона, ătau_, হরান, --, 
   {{0x779004f2,0x00000000,0x00000000,0x00000000}},	//   _ایفا, --, --, --, 
   {{0x9f4c004e,0x00000000,0x00000000,0x00000000}},	//   rafí_, --, --, --, 
   {{0xd12c8d24,0x00000000,0x00000000,0x00000000}},	//   تمه_, --, --, --, 
   {{0x644c8d25,0xac9002d3,0x6a6401a8,0x6d5c3b22}},	//   _inbi, _ዝብሎም_, _hófu, äsan, 
   {{0xd0200116,0x00000000,0x00000000,0x00000000}},	//   гмәй, --, --, --, 
   {{0x8cf00006,0x00000000,0x00000000,0x00000000}},	//   азыц, --, --, --, 
   {{0xdd900220,0xe28c022e,0x6a6402d2,0x00000000}},	//   лақы, ksаk_, _mófu, --, 
   {{0x2ff8006c,0xdb4c04d3,0x6a6421f1,0x6e4403b2}},	//   _سونگ_, ڵێک_, _lófu, ítbó, 
   {{0x2d640943,0x644c0175,0xd1f40092,0xd1d00092}},	//   ḓea_, _lnbi, _ላንተ_, _ካንተ_, 
   {{0x5884656c,0x644c8d26,0x0d5033ae,0x00000000}},	//   выва, _onbi, _نخود, --, 
   {{0x588434b1,0xd774489b,0x1ddc00cd,0xc5b000cc}},	//   тыма, نازع, फुरत, _কলংপ, 
   {{0x25ac0213,0x6d5c05ac,0xf3f000fe,0x00000000}},	//   əfli_, øsav, _চালৰ_, --, 
   {{0x644c8d27,0x00000000,0x00000000,0x00000000}},	//   _anbi, --, --, --, 
   {{0x349405f5,0x45d40032,0x5a900214,0xb7c40154}},	// [acd0] гаар, роус, _میگذ, ্রেট, 
   {{0x291c0276,0xd6d80395,0x38340108,0x00000000}},	//   ătat_, _отм_, _снор, --, 
   {{0x3ea48d28,0x00000000,0x00000000,0x00000000}},	//   komt_, --, --, --, 
   {{0x644c8d29,0x1cb0031c,0x3e7801d3,0x00000000}},	//   _enbi, _དེའ_, _hétf_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x644c033b,0xd7a40073,0x846402e8,0x00000000}},	//   _gnbi, _गडाच, _късе, --, 
   {{0x28d806bc,0x3860022c,0xeac801fb,0x00000000}},	//   _यूनि, _mohr_, _kẹt_, --, 
   {{0x43948d2a,0xf2c40075,0x8d2400d1,0x82342586}},	//   _тасс, _сөзи, вниң_, _پرفا, 
   {{0xacc8006c,0x2d988d2b,0x8b0400bc,0xeac80208}},	//   нгиз_, çse_, _obří, _mẹt_, 
   {{0xef642523,0xeac80051,0xa92002d2,0x212801e2}},	//   çısı_, _lẹt_, _áþin, _سيمی_, 
   {{0xb2f00006,0x9e9400ec,0xeac48d2c,0x00000000}},	//   абiл, _ڍانچ, лбоп, --, 
   {{0xd940010b,0xeac80051,0x7d280254,0x00000000}},	//   әери, _nẹt_, ärsõ, --, 
   {{0x38608d2d,0x9f4c0270,0x28f801c0,0x9dd404ae}},	//   _bohr_, mafá_, ээнэ_, _עוסק_, 
   {{0x1cb01f21,0xeb988d2e,0xe7382140,0xbebc00b8}},	//   _དེར_, _пил_, нег_, _apīh, 
   {{0x2ca40784,0xdc98008d,0xaa440510,0x69d8016b}},	//   mold_, _איסל, _бейл, ɛten, 
   {{0xe5a48d2f,0x9f4c0270,0x00000000,0x00000000}},	//   гиби, nafá_, --, --, 
   {{0xeac80208,0xa96828e8,0xbebc0171,0x85b40166}},	// [ace0] _dẹt_, _чипа_, _spīk, рәнч, 
   {{0x2c6803b2,0x00000000,0x00000000,0x00000000}},	//   _búdi_, --, --, --, 
   {{0x1bf4008f,0x1cb00327,0x00000000,0x00000000}},	//   רצער_, _དེལ_, --, --, 
   {{0x2ca48d30,0x6ed000ef,0x6a64032e,0x00000000}},	//   hold_, _jābu, _tófu, --, 
   {{0x6a640008,0x2ca48d31,0x6d5c0108,0x518000db}},	//   _hófs, kold_, äsal, йуша, 
   {{0x644c8d32,0xa2d410fe,0x2ca42d75,0x10a08d33}},	//   _unbi, _ميست, jold_, бичн, 
   {{0x3ea42611,0x2ca465c8,0x4acc000d,0x00000000}},	//   tomt_, dold_, _संगव, --, 
   {{0x399401f2,0xeac80208,0xd12c00d1,0x6ed00055}},	//   ụsi_, _xẹt_, تمۇ_, _nābu, 
   {{0xf1d405f5,0x3e7804cc,0xdde835cd,0x63ac0306}},	//   _төхө, _létg_, ورکه_, _hybn, 
   {{0x2ca48d34,0x3ea417c1,0x9f480356,0xcf54013d}},	//   gold_, somt_, ămân_, трәч_, 
   {{0x38608d35,0x8d70015e,0x69c019cc,0x00000000}},	//   _rohr_, لایا, रेसी, --, 
   {{0x3ea40a73,0xbb2c1884,0x8f98011a,0x00000000}},	//   qomt_, ﻧﺠﻰ_, _איבי, --, 
   {{0x2ca48d36,0x6d5c0fac,0xeac80051,0x8aa40006}},	//   bold_, øsat, _rẹt_, срэд, 
   {{0xb8fc0a28,0x31c024ae,0x16040073,0x7b84215c}},	//   _तं_, ﺭﺩﯨﻜ, षणभर_, _پاتە, 
   {{0x6aa48d37,0xa8541b15,0x26dc00df,0x00000000}},	//   bokf, шерә, ŭton_, --, 
   {{0x386001c7,0x291c054e,0xbebc00ef,0x1b0000cf}},	//   _wohr_, ătar_, _asīz, _күүн, 
   {{0x58840184,0x26080307,0x63ac01d5,0xeac8004d}},	// [acf0] _бына, िलजी_, _aybn, _vẹt_, 
   {{0x1cb01b4b,0x39488d38,0xb7d80133,0xdcec0153}},	//   _དེས_, _iras_, _جودا_, ždėm, 
   {{0x394805c7,0xeac80208,0x6a6402d2,0x27e400a2}},	//   _hras_, _tẹt_, _tóft, _şong_, 
   {{0x39488d39,0x03c41171,0x00000000,0x00000000}},	//   _kras_, ссум, --, --, 
   {{0x91040120,0x95640395,0xe6840150,0x00000000}},	//   учед, _сънд, _тәрк_, --, 
   {{0x21648d3a,0x040c009e,0x62880129,0x6a6402d2}},	//   риши_, স্বী_, éfor, _jófr, 
   {{0x21dc063f,0x39480165,0x25a40327,0x00000000}},	//   _ịhe_, _lras_, żolt_, --, 
   {{0x39488d3b,0x2ca401f5,0x00000000,0x00000000}},	//   _oras_, wold_, --, --, 
   {{0x7ae41326,0x39480211,0x9b3c0882,0xa2808d3c}},	//   _čita, _nras_, māṇā, _بینو, 
   {{0x3ea005a1,0xac840228,0x7ee400c7,0x00000000}},	//   čita_, ргол, шцәе, --, 
   {{0x39488d3d,0x00000000,0x00000000,0x00000000}},	//   _aras_, --, --, --, 
   {{0x39488d3e,0xa96815ed,0x6f0003ac,0x2ca48d3f}},	//   _bras_, вима_, _ivlc, sold_, 
   {{0x2ca48d40,0x39480483,0x3e7804cc,0x8ce010de}},	//   pold_, _cras_, _sétg_, _اقتۇ, 
   {{0x39488d41,0x3e7804cc,0x5d78008f,0x6aa40158}},	//   _dras_, _pétg_, _באנק, sokf, 
   {{0xb8fc8d42,0x39488d43,0xcc840133,0x00000000}},	//   _तू_, _eras_, _لۆکه_, --, 
   {{0x63ac8d44,0x39482c1e,0x00000000,0x00000000}},	//   _rybn, _fras_, --, --, 
   {{0x39488d45,0x00000000,0x00000000,0x00000000}},	// [ad00] _gras_, --, --, --, 
   {{0x9b400101,0x00000000,0x00000000,0x00000000}},	//   _اچیو, --, --, --, 
   {{0xe1f8292c,0x5dcc01ec,0x00000000,0x00000000}},	//   вге_, _ﻗﻭﻤﻴ, --, --, 
   {{0xd36c00c6,0xf1a80214,0xe5a406a7,0x00000000}},	//   بهم_, گامه_, _вими, --, 
   {{0xc1040166,0x00000000,0x00000000,0x00000000}},	//   сүзл, --, --, --, 
   {{0x201800af,0x59ac0b26,0xf1a88d46,0x00000000}},	//   üpi_, _घरघर, دامه_, --, 
   {{0xa2c40b98,0x9b3c00b8,0x00000000,0x00000000}},	//   िषद्, bāṇā, --, --, 
   {{0x8e440075,0xbd1801c6,0x59c409b2,0x00000000}},	//   للىك_, гжих_, रेडर, --, 
   {{0xc0c40b65,0x8234004b,0x69d800bc,0xc1e400fb}},	//   _ләки, _پرځا, ětel, _көҙҙ, 
   {{0x39480200,0x00000000,0x00000000,0x00000000}},	//   _rras_, --, --, --, 
   {{0x26dc56eb,0x6d5c3a26,0xa18400fb,0x93f8011a}},	//   ítol_, øsar, _сыңл, כליי, 
   {{0x39488d47,0x1bf00abd,0x5f3c001f,0x03c8010e}},	//   _pras_, _आजकल_, _በርሳቸ, _şaỳa, 
   {{0x6e2c009d,0x1be401d5,0xd7f801d5,0xbdb401f7}},	//   _ñaba, _кўйг, кув_, _اجاڙ, 
   {{0x39488d48,0xad640a12,0x2c6800d7,0x00000000}},	//   _vras_, _دامه, _búdu_, --, 
   {{0xda782e9a,0x9b3c0882,0x00000000,0x00000000}},	//   _аяп_, yāṇā, --, --, 
   {{0x39488d49,0x00000000,0x00000000,0x00000000}},	//   _tras_, --, --, --, 
   {{0x39488d4a,0x6ed000e2,0xea9401e2,0x00000000}},	// [ad10] _uras_, _jābr, _داوښ, --, 
   {{0xeac801fb,0x53e47765,0x947400ae,0x00000000}},	//   _hẹp_, рцаа, جدرا, --, 
   {{0xeac801fb,0x00000000,0x00000000,0x00000000}},	//   _kẹp_, --, --, --, 
   {{0x7178014b,0x92680395,0x00000000,0x00000000}},	//   лбер_, ърза_, --, --, 
   {{0x9b3c0882,0x95c80640,0x4ad02ba2,0xc24402d5}},	//   rāṇā, _јуна_, _संघव, ўнік, 
   {{0xdfcc05d9,0x00000000,0x00000000,0x00000000}},	//   ڙيو_, --, --, --, 
   {{0x43948d4b,0xb8d8025c,0x59c400cd,0x00000000}},	//   _дарс, _མཚ_, रेतर, --, 
   {{0xee388d4c,0x518407d6,0xff5042b5,0xeb981b1c}},	//   уни_, _куза, بخه_, ғим_, 
   {{0x6ed000cd,0x6bd400f2,0x324401ec,0x2ca800db}},	//   _cābr, یتگر, _кеңг, лкип_, 
   {{0x101449bf,0xac388d4d,0xae1800bc,0x3f6400d1}},	//   _خبرد, учих_, _धावन_, стәб, 
   {{0x7c640e3e,0x6fb48d4e,0x3e78002e,0xeac8004d}},	//   تايل, _اماا, _séte_, _bẹp_, 
   {{0x753c01d3,0x26dc5923,0x00000000,0x00000000}},	//   _ossz, ítom_, --, --, 
   {{0x6db48d4f,0x2c6801f1,0xeac801fb,0x7eac000f}},	//   _уйду, _súdu_, _dẹp_, rûpt, 
   {{0xfb8801d3,0x7c8400f3,0x00000000,0x00000000}},	//   ائیو_, _мује, --, --, 
   {{0x66e48d50,0x753c01ed,0x00000000,0x00000000}},	//   соба, _assz, --, --, 
   {{0x66e48d51,0x3e780129,0xb67800d4,0x00000000}},	//   _қома, _téte_, ащує_, --, 
   {{0xe09c063f,0x69d401ed,0x00000000,0x00000000}},	// [ad20] họọ_, _igye, --, --, 
   {{0xe09c0521,0xe2840131,0x23d400f3,0x00000000}},	//   kọọ_, әлди, сцар, --, 
   {{0x29008d52,0x1bf8008f,0xd24c0214,0x29e001e1}},	//   lska_, רלעב, کنن_, _kєa_, 
   {{0x673c8d53,0x29000014,0xeac80208,0xd7b8011a}},	//   _ispj, oska_, _xẹp_, _תצטר, 
   {{0xa0688d54,0x26d806c8,0xbd24031c,0x00000000}},	//   лада_, _hupo_, _འདེཊ_, --, 
   {{0xd00c20ad,0x29000050,0x10a0871a,0x26d88d55}},	//   فله_, iska_, пичн, _kupo_, 
   {{0x44448d56,0x69d446a6,0x26d80115,0x68f40368}},	//   md_, _ogye, _jupo_, _lwyd, 
   {{0x22940491,0x3ea00bb8,0x26d88d57,0x69d4013f}},	//   _الرس, čito_, _mupo_, _ngye, 
   {{0x26d88d58,0x61e08d59,0x44448d5a,0x68f40368}},	//   _lupo_, mcol, od_, _nwyd, 
   {{0x290008ad,0x61e08d5b,0x69d40134,0xe0482be7}},	//   dska_, lcol, _agye, _حشره_, 
   {{0x44448d5c,0x814004d3,0x29008d5d,0x68f40368}},	//   id_, _رۆژن, eska_, _awyd, 
   {{0x44448d5e,0x6d8800dd,0x68f40368,0xd9180212}},	//   hd_, امیہ_, _bwyd, льг_, 
   {{0x0c700502,0xaea00075,0xdca48d5f,0x68f40142}},	//   زدید, _تەيي, _лади, _cwyd, 
   {{0x69d48d60,0x44440460,0x8c408d61,0x26d801e1}},	//   _egye, jd_, _нече, _bupo_, 
   {{0x44441649,0x26d88d62,0x290001d9,0x4bf80a1e}},	//   dd_, _cupo_, aska_, _גלוס, 
   {{0x44448d63,0xdbd42045,0x29002b5d,0x68f40368}},	//   ed_, _läük, bska_, _fwyd, 
   {{0x44440936,0x61e00354,0x68f400a9,0x290001ed}},	// [ad30] fd_, dcol, _gwyd, cska_, 
   {{0x44448d64,0x80dc068f,0xd3788d65,0xb9d81772}},	//   gd_, _पढ़े, лче_, _በላ_, 
   {{0x75d4554b,0x81b803f9,0x7c2801c7,0x47dc00eb}},	//   _ويدا, ɓɓiy, ifdr, ভরশী, 
   {{0x44448d66,0x61e08d67,0x201c22df,0x7ae4041a}},	//   ad_, gcol, _acti_, _čitl, 
   {{0x44448d68,0x248805da,0x26d804cc,0x81cc00cc}},	//   bd_, _fmbm_, _zupo_, _শ্ব_, 
   {{0x26d80451,0xe09c063f,0x82340092,0xb4d4134e}},	//   _yupo_, tọọ_, _በዮርዳ, हदी_, 
   {{0x290003da,0x61e08d69,0xf2348d6a,0xa1f000d1}},	//   zska_, bcol, _وبرک, سۋەت, 
   {{0x29008d6b,0x61e03003,0x7c280373,0xe09c063f}},	//   yska_, ccol, efdr, rọọ_, 
   {{0xec78085f,0x705800db,0x00000000,0x00000000}},	//   ипи_, _каар_, --, --, 
   {{0xaadc02ab,0xbebc00e2,0x68f403cb,0xeb0400f3}},	//   _नंदक, _spīt, _rwyd, опоп, 
   {{0x68f40f7b,0x2900068f,0xab288d6c,0x6e2c002e}},	//   _swyd, wska_, шона_, _ñabo, 
   {{0x290005ce,0x26d88d6d,0xfd500055,0x69244eca}},	//   tska_, _rupo_, _likṣ, омма, 
   {{0x44448d6e,0xddc08d6f,0x26d88d70,0x29006607}},	//   yd_, _zlož, _supo_, uska_, 
   {{0x26d80cad,0x6ff800c8,0x3ce00124,0x6e28002f}},	//   _pupo_, יפֿג, _éiva_, lfeb, 
   {{0x61e08d71,0xe7388d72,0x44440b34,0x6d488d73}},	//   ycol, шев_, vd_, lvea, 
   {{0xfd50002b,0x44448d74,0x6e2801c4,0x3e7801e1}},	//   _aikṣ, wd_, nfeb, _kéta_, 
   {{0x44448d75,0x6d480165,0x1fc400bc,0x61e00175}},	// [ad40] td_, nvea, _लण्ड, vcol, 
   {{0x3e788d76,0x44448d77,0x26d800ec,0x61e0010a}},	//   _méta_, ud_, _tupo_, wcol, 
   {{0x673c036f,0x201c7233,0x26d8079b,0x61e08d78}},	//   _uspj, _rcti_, _uupo_, tcol, 
   {{0x44448d79,0xa69416a4,0xa3d4033f,0x72280212}},	//   sd_, _фрој, _हलक_, йців_, 
   {{0x61e08d7a,0xddc08d7b,0x444400b5,0xa508026a}},	//   rcol, _slož, pd_, _њега_, 
   {{0x1df000e1,0x26c0005a,0xf41000eb,0x444403b9}},	//   घर्ष_, _hhko_, স্বর_, qd_, 
   {{0x62200116,0x00000000,0x00000000,0x00000000}},	//   _يۈئە, --, --, --, 
   {{0xddc04ea1,0x1cb008ea,0x3e788d7c,0x2168010b}},	//   _vlož, _དེང_, _béta_, _киби_, 
   {{0x22440354,0x3eb8005f,0x91008d7d,0x00000000}},	//   mdok_, ērt_, _опте, --, 
   {{0x22448d7e,0x26c001c4,0x7c280112,0x00000000}},	//   ldok_, _lhko_, ufdr, --, 
   {{0xddc00e8b,0x7c280142,0x65600108,0x00000000}},	//   _ulož, rfdr, äohj, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x21248d7f,0x394c8d80,0x7c280112,0x27e40432}},	//   ntoh_, íes_, pfdr, _şona_, 
   {{0x8c400063,0x22440327,0x00000000,0x00000000}},	//   _жеље, hdok_, --, --, 
   {{0x2244359a,0x9f4c180f,0x6d5c0108,0x5a440006}},	//   kdok_, ïnèt_, äsav, _дэпа, 
   {{0xcb101203,0x26c00c5e,0x76b801d5,0x00000000}},	//   _חלק_, _chko_, ёлар_, --, 
   {{0x95c80a83,0x22448d81,0x3a3800d8,0x59c40bae}},	// [ad50] рува_, ddok_, mesp_, रेशर, 
   {{0x7af80211,0x26c001c4,0xf3f000cc,0x093401c8}},	//   _kwvt, _ehko_, _চাঙৰ_, _آريج, 
   {{0x25a03714,0x6d48004c,0x572000db,0xfd5000dc}},	//   _exkl_, zvea, _تۉزك, _vikṣ, 
   {{0x3a388d82,0x6d480158,0x47341a4b,0xd1d801f3}},	//   nesp_, yvea, _کریز, _ፖርቲ_, 
   {{0xd1388d83,0xdbd4013d,0xafe401d5,0x30740108}},	//   рхе_, _läñk, полл, зуйс, 
   {{0x7bd88d84,0xe04002bf,0x75380ac1,0x224400d0}},	//   _ngvu, енши, ğazı, adok_, 
   {{0xdee000a7,0x6e28003e,0x3e781079,0x00000000}},	//   нощи, tfeb, _séta_, --, 
   {{0x3e7800f2,0xbebc0171,0x629802d2,0x00000000}},	//   _péta_, _spīr, _ítop, --, 
   {{0x30148d85,0x6d488d86,0x3a3800d8,0x6e280fac}},	//   _ндар, uvea, desp_, rfeb, 
   {{0x6d485dae,0x3e7800e4,0x6e28007c,0x00000000}},	//   rvea, _véta_, sfeb, --, 
   {{0x3a3800d8,0x6d480254,0x0e4401c4,0x00000000}},	//   fesp_, svea, _мэдм, --, 
   {{0xa9a489e6,0x321c0129,0x00000000,0x00000000}},	//   зимд, ngwy_, --, --, 
   {{0x5ed000bd,0xfe702d74,0x00000000,0x00000000}},	//   _সবচে, _جدل_, --, --, 
   {{0xfca80014,0x26c002d3,0xe7b802dd,0x6d5c0108}},	//   _واوو_, _shko_, _ﺤﻭﺍﻟ, äsau, 
   {{0x18a08d87,0x3a3800d8,0x9bf8011a,0x97c0022e}},	//   харм, besp_, _ההצט, ейре, 
   {{0xe9a40826,0x2124011f,0x638000ae,0x00000000}},	//   _найп, ytoh_, _líné, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [ad60] --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x516400f7,0x7ae40841,0xd5ac00e5,0x00000000}},	//   үүсү_, _čitk, نفہ_, --, 
   {{0x21240429,0xe1240137,0x91e08d88,0x00000000}},	//   ttoh_, змди, еоце, --, 
   {{0x4cd8015b,0x22448d89,0x00000000,0x00000000}},	//   _মৌসু, rdok_, --, --, 
   {{0x55b80375,0xe208033f,0x74f002dd,0x00000000}},	//   _למכו, dróż_, _شۋما, --, 
   {{0x53a0136b,0xcfd00063,0xd3840354,0x22140153}},	//   _зарб, ношћ, _ейре_, _нфар, 
   {{0x13980375,0x539802e4,0xe28407ee,0x00000000}},	//   _הבלע, _הילו, _элби, --, 
   {{0x638001e7,0x00000000,0x00000000,0x00000000}},	//   _fíné, --, --, --, 
   {{0x1ab408f8,0x63800332,0xbec400dc,0x00000000}},	//   ृष्ठ, _gíné, _śūdr, --, 
   {{0xefd00092,0x00000000,0x00000000,0x00000000}},	//   ጧቸው_, --, --, --, 
   {{0xdb200419,0xd90c0066,0x00000000,0x00000000}},	//   _šrób, هیب_, --, --, 
   {{0x6d5c0108,0x00000000,0x00000000,0x00000000}},	//   äsat, --, --, --, 
   {{0x3a3800d8,0xdbd4013d,0x38c8158f,0x00000000}},	//   sesp_, _täñk, تاجی_, --, 
   {{0x3a380798,0x7b840150,0x6e340cad,0x4bd400ae}},	//   pesp_, _تاشە, _ìgbà, _عبود_, 
   {{0x8aa402d5,0x63b83168,0xba540063,0x00000000}},	//   _прыд, _útny, _цвиј, --, 
   {{0xf48400dd,0x3e78012c,0xd838009d,0x00000000}},	// [ad70] وائی, _léto_, _лэн_, --, 
   {{0x49b80c8b,0x00000000,0x00000000,0x00000000}},	//   _عايد_, --, --, --, 
   {{0x43940a5b,0xf4680023,0x00000000,0x00000000}},	//   нафс, _ተዛረብ_, --, --, 
   {{0x95c80064,0x00000000,0x00000000,0x00000000}},	//   _гуга_, --, --, --, 
   {{0x8ae002dd,0x26dc00d7,0x00000000,0x00000000}},	//   _ﺍﻟﻤﺅ, ítov_, --, --, 
   {{0xf31401c0,0x2f5411f7,0x69c00b4c,0x128400f2}},	//   _одгэ, дтис, रेटी, _کمری_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xece83f1c,0x00000000,0x00000000,0x00000000}},	//   одил_, --, --, --, 
   {{0x320c00d7,0x51940408,0x00000000,0x00000000}},	//   _idey_, _хăпа, --, --, 
   {{0xeb980640,0xc0f8001f,0xc104007b,0x00000000}},	//   жио_, _ሊኖሩ_, _أولي, --, 
   {{0x3e78003e,0x7f58023b,0xf1e04697,0x00000000}},	//   _géto_, _нафс_, _फलान, --, 
   {{0xdd8c8d8a,0x4ea4030d,0x00000000,0x00000000}},	//   اوی_, _эрза, --, --, 
   {{0xda1c8d8b,0x91cc03d4,0x00000000,0x00000000}},	//   _भारत_, হুৰ্, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xaa880014,0xdca001c0,0x69c0012c,0x320c0067}},	//   _ونتم_, _шаши, रेजी, _odey_, 
   {{0x320c1bce,0x6304004b,0x340c0055,0x00000000}},	//   _ndey_, ېوال, _āgaḥ_, --, 
   {{0xc5a80451,0xa4440229,0x00000000,0x00000000}},	// [ad80] ڪڏھن_, мнад, --, --, 
   {{0xe738026a,0x320c0009,0x00000000,0x00000000}},	//   _део_, _adey_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc0f8001f,0x44e40205,0xb3ac00fe,0x00000000}},	//   _ሊኖር_, _iö_, কেইজ, --, 
   {{0x44e48d8c,0x00000000,0x00000000,0x00000000}},	//   _hö_, --, --, --, 
   {{0xb9008d8d,0x44e429ef,0x3e78004a,0x91c8033f}},	//   _སྤ_, _kö_, _véto_, तेहै, 
   {{0x9f5c044e,0x62808d8e,0x1cb00003,0x2018068c}},	//   _ketë_, mhoo, _དེད_, òpis_, 
   {{0x9f5c069c,0x3e78038e,0x44e4420d,0x62808d8f}},	//   _jetë_, _této_, _mö_, lhoo, 
   {{0x44e48d90,0xe0e40f22,0x6d5c4ab3,0x3f980022}},	//   _lö_, _নিয়ন, äsar, _ãru_, 
   {{0x44e40112,0xeea80150,0x00000000,0x00000000}},	//   _oö_, _етік_, --, --, 
   {{0x44e48d91,0x984800a7,0x9138010f,0x62800254}},	//   _nö_, оява_, ֿעלק, ihoo, 
   {{0x9f5c036e,0xc30400fe,0x00000000,0x00000000}},	//   _netë_, _উমনি_, --, --, 
   {{0x62808d92,0xc7b88d93,0x8cc400cf,0x44e4032e}},	//   khoo, дёт_, _تووق_, _aö_, 
   {{0x44e48021,0x0b54106b,0x628001f5,0x4a040124}},	//   _bö_, _آشوب_, jhoo, _иџьа, 
   {{0x62808d94,0x320c0009,0x98c45a6f,0x69c0013d}},	// [ad90] dhoo, _rdey_, _осол, _бөрб, 
   {{0x44e48d95,0x62800549,0x00000000,0x00000000}},	//   _dö_, ehoo, --, --, 
   {{0x290c1140,0x1cb0025c,0x92e80131,0x6280017a}},	//   _āfai_, _དེན_, زراق_, fhoo, 
   {{0x44e48d96,0xc0f0001f,0x62800363,0x00000000}},	//   _fö_, _ግማሽ_, ghoo, --, 
   {{0x44e48d97,0x9f5c0240,0x00000000,0x00000000}},	//   _gö_, _fetë_, --, --, 
   {{0x9f5c01e1,0x6280815e,0x61500214,0x942000cf}},	//   _ketè_, ahoo, انوئ, _جوسۇ, 
   {{0x9f5c0100,0x44e4013d,0x00000000,0x00000000}},	//   _jetè_, _zö_, --, --, 
   {{0x62808d98,0x320c014b,0x9f5c007f,0x44e4023a}},	//   choo, _udey_, _metè_, _yö_, 
   {{0xdc388d99,0x8650013f,0x62240150,0x44e40139}},	//   _açıq, boɔf, _سولە, _xö_, 
   {{0xab644631,0xcc840133,0x00000000,0x00000000}},	//   евол, بۆته_, --, --, 
   {{0x5c040451,0x8f440354,0x00000000,0x00000000}},	//   رڪوٽ_, _юхад, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xed588d9a,0x7e7400cf,0x97280023,0xbd8800cf}},	//   _хол_, _جالئ, _ድልየት, _ۉنۅن_, 
   {{0xf1b80122,0x6cc401e0,0xa41c1bbb,0x35b80210}},	//   _myš_, _яйла, _पाइप_, _आरज़, 
   {{0x62801caa,0x44e401e3,0x9f5c0240,0x17c40798}},	//   yhoo, _sö_, _retë_, егри_, 
   {{0x9f5c007f,0x44e42045,0x628001e2,0xaa44084c}},	//   _detè_, _pö_, xhoo, _чеил, 
   {{0x25a400db,0x9f5c036e,0x5a98011a,0x6280000d}},	// [ada0] çol_, _petë_, _משקא, vhoo, 
   {{0xe7280801,0x9f5c0023,0x628001a4,0x26dc056a}},	//   _еоод_, _qetë_, whoo, ítos_, 
   {{0xe2988525,0x62801c1d,0x9f5c8d9b,0xc050004b}},	//   паж_, thoo, _vetë_, یږئ_, 
   {{0x44e48d9c,0x236404b9,0x21a417b4,0x59c40d79}},	//   _tö_, ćoj_, нием, रेकर, 
   {{0x62808d9d,0x9f5c0023,0xa8000055,0x00000000}},	//   rhoo, _tetë_, _āñja, --, 
   {{0x62808d9e,0x40347546,0x65740334,0x27fc022e}},	//   shoo, текс, myyh, аtni_, 
   {{0x62808d9f,0xcfe4007b,0xdef864c2,0x525866a3}},	//   phoo, رفيه_, чыл_, تسەڭ_, 
   {{0x62648da0,0x9f5c8da1,0x5d640114,0xe2a801c8}},	//   _явба, _jeté_, етоз, _رازن_, 
   {{0xa0a48602,0xc0500092,0x00000000,0x00000000}},	//   _заад, ቀበለው, --, --, 
   {{0x9f5c8da2,0xdd9001ec,0x00000000,0x00000000}},	//   _leté_, кақы, --, --, 
   {{0x60d8009a,0xb51c0d0d,0x00000000,0x00000000}},	//   _iitm, _पम्प_, --, --, 
   {{0x1cb00489,0x657401f4,0x00000000,0x00000000}},	//   _དེམ_, kyyh, --, --, 
   {{0x7ae417a3,0x8d700244,0x60d8008e,0x9f5c8da3}},	//   _čitu, _ماوا, _kitm, _setè_, 
   {{0x3ea01050,0xdc287b16,0x60d80135,0x9f5c007f}},	//   čitu_, _رسته_, _jitm, _petè_, 
   {{0x60d88da4,0x00000000,0x00000000,0x00000000}},	//   _mitm, --, --, --, 
   {{0xda6425aa,0x97340023,0xb8e401a9,0x00000000}},	//   _سابي, _ኣካይድ, _исоқ, --, 
   {{0x848c1e38,0x9f5c00db,0x386c017a,0x00000000}},	// [adb0] _መከራን_, _deté_, êers_, --, 
   {{0x60d88da5,0xad9c0034,0x38c85ce9,0x00000000}},	//   _nitm, kaźn, _تابی_, --, 
   {{0xad9c033f,0xd3a406a6,0x00000000,0x00000000}},	//   jaźn, храп, --, --, 
   {{0x71980330,0x7afc01d3,0x80241870,0xb5c400db}},	//   وناز_, árty, ۇرىم, _үйүл, 
   {{0x765c8da6,0x60d88da7,0x764c6164,0x85741cb8}},	//   _insy, _bitm, mday, _блях, 
   {{0x752c01c8,0x60d800fd,0x20780139,0x00000000}},	//   mtaz, _citm, мичө_, --, 
   {{0x752c8da8,0xb4bc45bf,0x60d801a4,0xad240131}},	//   ltaz, आती_, _ditm, ھىدى, 
   {{0xf1d08da9,0xad240075,0xed58016c,0x752c009f}},	//   _көлө, پىدى, дои_, otaz, 
   {{0xddc02625,0x1fb0009e,0x90b08daa,0x764c0067}},	//   _pooš, টেলস, _йәкш, iday, 
   {{0x764c0429,0x60d83b13,0x6ab48dab,0x752c8dac}},	//   hday, _gitm, _skyf, itaz, 
   {{0x764c8dad,0x765c78ec,0xae040150,0x752c0200}},	//   kday, _onsy, _ٴوتى, htaz, 
   {{0x752c8dae,0x60d801a4,0x28d8033f,0x9fa401ee}},	//   ktaz, _zitm, _यूजि, _рыуҙ, 
   {{0x764c8daf,0x9f5c004e,0x60d88db0,0x752c8db1}},	//   dday, _reté_, _yitm, jtaz, 
   {{0x765c8db2,0x764c0067,0xeb9800f0,0x657401f4}},	//   _ansy, eday, _оил_, vyyh, 
   {{0x66e415ed,0x9f5c020c,0x70dc00ab,0x764c02d0}},	//   тоба, _peté_, मदुल, fday, 
   {{0x764c8db3,0x765c0334,0x00000000,0x00000000}},	//   gday, _cnsy, --, --, 
   {{0x6e2c0086,0xa8c40116,0xa47801d9,0x55e000f3}},	// [adc0] _ñabu, _ийид, وٝرا_, роуб, 
   {{0x765c8db4,0x764c8db5,0xd918010f,0x95c40672}},	//   _ensy, aday, _קויל, тлуб_, 
   {{0x93400104,0x28740022,0x18780375,0x764c002b}},	//   инфе, _зыҽр, _חטיב, bday, 
   {{0x60d80175,0xdebc001f,0x764c0067,0x65740108}},	//   _sitm, ሶችን_, cday, pyyh, 
   {{0x60d88db6,0x752c07c5,0xf7b806ba,0x00000000}},	//   _pitm, ctaz, ﺸﯩﻠﻪ, --, 
   {{0xf1a88db7,0xd00c8db8,0x60d82b9e,0x64a40153}},	//   رانه_, قله_, _qitm, _рага, 
   {{0xdec88db9,0x60d88dba,0x3e7802d2,0xe2988dbb}},	//   муил_, _vitm, _héti_, _жав_, 
   {{0x60d805e4,0xad9c0034,0x4fe435e3,0xa11400f1}},	//   _witm, raźn, нмән_, _لورت, 
   {{0x60d88dbc,0x5cc40b75,0xe04400c7,0x0fc0010b}},	//   _titm, ксоз, _инаи, лйән, 
   {{0x60d82595,0x3e780de2,0x764c6164,0x00000000}},	//   _uitm, _méti_, zday, --, 
   {{0x752c009d,0x3e783bed,0x00000000,0x00000000}},	//   ztaz, _léti_, --, --, 
   {{0x3ea08dbd,0x764c8dbe,0x6bc400c7,0x00000000}},	//   _ñit_, xday, ырыҧ, --, 
   {{0x3e780098,0x7c34074d,0x752c01a9,0x764c8dbf}},	//   _néti_, _белх, xtaz, vday, 
   {{0x06bc00cc,0x764c058a,0x00000000,0x00000000}},	//   _আংগি, wday, --, --, 
   {{0x0bc023f6,0x6b8c0198,0x59c407f7,0x00000000}},	//   _ﺭﺍﻳﻮ, _ƙage, रेजर, --, 
   {{0x752c8dc0,0x0bb40302,0xa3d400ce,0x764c0009}},	//   ttaz, _שלהם_, ाइन_, uday, 
   {{0xd7f873da,0x3a2803e0,0xd4e417b4,0x00000000}},	// [add0] _оун_, _icap_, тюби, --, 
   {{0x752c8dc1,0x764c127b,0x3948220c,0x3ae8002d}},	//   rtaz, sday, _isas_, _kûp_, 
   {{0x752c8dc2,0x97a400d8,0xf3c400c7,0x00000000}},	//   staz, _шрил, ураҟ, --, 
   {{0x752c8dc3,0x6570044e,0xf67800c8,0x79680036}},	//   ptaz, ëdhë, _נאָמ, _gëwë, 
   {{0x27e400a2,0x00000000,0x00000000,0x00000000}},	//   _şoni_, --, --, --, 
   {{0x61f40724,0x78b405b8,0x34948dc4,0x2d800055}},	//   ıyla, nozv, _сагр, _āhe_, 
   {{0xaf3407d2,0x39480064,0xb4c02bf1,0x00000000}},	//   ارتت, _lsas_, ुषी_, --, 
   {{0x3948007d,0xda1c2983,0x3e780129,0x9f4c007f}},	//   _osas_, _भागत_, _yéti_, tafò_, 
   {{0x78b408a4,0xaa4400d1,0x00000000,0x00000000}},	//   kozv, ۇندى, --, --, 
   {{0x3a280a2e,0x00000000,0x00000000,0x00000000}},	//   _acap_, --, --, --, 
   {{0x39488dc5,0xd1f00023,0x00000000,0x00000000}},	//   _asas_, _ግራት_, --, --, 
   {{0x3a2802ce,0x39480789,0x6a848dc6,0xb4c000dc}},	//   _ccap_, _bsas_, улма, ुषु_, 
   {{0x78b400f3,0x888400d1,0x394801ef,0x00000000}},	//   fozv, иғил, _csas_, --, 
   {{0x0ca807d6,0x6b841ba4,0x68448dc7,0x78b48dc8}},	//   _ўтди_, _مشعل, ынга, gozv, 
   {{0x39488dc9,0xbebc00b8,0xdbd0010b,0x7c3400e5}},	//   _esas_, _apīy, _küýz, égrő, 
   {{0xe6c48dca,0x6f000142,0x672c007c,0xfb240345}},	//   اتسي, _mwlc, rtbj, _ئروپ, 
   {{0xe9d88dcb,0xe4587116,0x78b40099,0x4a7401d9}},	// [ade0] _яки_, нжа_, bozv, _مُژر, 
   {{0x672c03b2,0xdebc0092,0x00000000,0x00000000}},	//   ptbj, ሶችና_, --, --, 
   {{0x64a40032,0xe738033a,0x00000000,0x00000000}},	//   _ҡама, _џем_, --, --, 
   {{0xa3d400af,0x9798008f,0x3e7801e1,0x256800d8}},	//   ाइब_, _טשיק, _téti_, _замп_, 
   {{0x6f0002d0,0x9e040131,0x00000000,0x00000000}},	//   _awlc, ңчил, --, --, 
   {{0x66048dcc,0x63f801d9,0xad9c0034,0x6f0003cb}},	//   _hekk, _سفرس_, raźl, _bwlc, 
   {{0x66048dcd,0x4438198f,0x2ee407de,0xd8d400c8}},	//   _kekk, _ibr_, _culf_, נוצט_, 
   {{0x66040694,0x3ae8045f,0xd1800f25,0x78b40433}},	//   _jekk, _rûp_, рләй, zozv, 
   {{0x5c048dce,0x3ae8002d,0xc1e40032,0xd24c007b}},	//   ляна, _sûp_, _йөҙҙ, _عنك_, 
   {{0x66048dcf,0x644c8dd0,0xdee403a6,0x3a288dd1}},	//   _lekk, _jabi, _божи, _scap_, 
   {{0x443800a3,0x78b40e8a,0x30748dd2,0x2a700076}},	//   _mbr_, vozv, _тутс, _boyb_, 
   {{0x644c8dd3,0x66043d27,0x39488d5e,0x4438020b}},	//   _labi, _nekk, _psas_, _lbr_, 
   {{0xc9848899,0xa3d411b1,0x44388dd4,0x9f5c0407}},	//   бури, ाइड_, _obr_, _metí_, 
   {{0x44385941,0x6604005a,0x9f5c02fb,0x9f940037}},	//   _nbr_, _aekk, _letí_, küür_, 
   {{0xdb081477,0x9f5c0124,0x00000000,0x00000000}},	//   _nyfø, _hetâ_, --, --, 
   {{0x644c8dd5,0x44388dd6,0x3a282ec3,0x65ac0084}},	//   _aabi, _abr_, _ucap_, _ṱhan, 
   {{0x78b48dc8,0x4438037e,0x39488dd7,0x97000131}},	// [adf0] pozv, _bbr_, _usas_, _گېزى, 
   {{0x14740228,0x45b84566,0x85b800d8,0x45d41422}},	//   دارج, угую_, улус_, соус, 
   {{0x644c8dd8,0x66048dd9,0x44380153,0x3e78032e}},	//   _dabi, _fekk, _dbr_, _hétu_, 
   {{0x66048dda,0x44388ddb,0x644c0428,0x3e780248}},	//   _gekk, _ebr_, _eabi, _kétu_, 
   {{0x9f5c01f1,0x78780ffb,0x3e780098,0x443806be}},	//   _detí_, _dìvv, _jétu_, _fbr_, 
   {{0x44388ddc,0x66040337,0xe034004e,0x00000000}},	//   _gbr_, _zekk, имчө, --, 
   {{0x66048ddd,0x9f5c01e1,0x2ee401a9,0x3e7801a8}},	//   _yekk, _fetí_, _qulf_, _létu_, 
   {{0x644c8dde,0x8d2400d1,0x3494023b,0xf2c4013d}},	//   _zabi, гниң_, _саҳр, _төзи, 
   {{0x644c8875,0xada48ddf,0xac748de0,0x645806ed}},	//   _yabi, рапл, لادش, _ótic, 
   {{0x644c8de1,0x00000000,0x00000000,0x00000000}},	//   _xabi, --, --, --, 
   {{0x1f240014,0x00000000,0x00000000,0x00000000}},	//   _نِلہ, --, --, --, 
   {{0xa3d400c5,0x80cc00fe,0x5ef800df,0x00000000}},	//   ाइत_, াদণ্, _יפעד, --, 
   {{0x66048de2,0x7ed41291,0x00000000,0x00000000}},	//   _rekk, _ازلا, --, --, 
   {{0xad6416cb,0x6d588de3,0x66048de4,0x2d8c00ca}},	//   _ماڻه, _irwa, _sekk, mzee_, 
   {{0x66048de5,0x18648152,0x6d58035a,0xdc980a7c}},	//   _pekk, шари_, _hrwa, _ביסל, 
   {{0x644c8de6,0x6d5864d3,0x44388de7,0x9f5c0124}},	//   _sabi, _krwa, _sbr_, _hetã_, 
   {{0x644c8de8,0x6604168c,0x2d8c3b4d,0x6d580857}},	// [ae00] _pabi, _vekk, nzee_, _jrwa, 
   {{0x644c8de9,0x66048dea,0x29101446,0x6d580c8c}},	//   _qabi, _wekk, _ivya_, _mrwa, 
   {{0x66048deb,0x644c8dec,0x1ccc0327,0xe314007b}},	//   _tekk, _vabi, _ྱེལ_, شباب, 
   {{0x6d586ad0,0x44380354,0x673c0003,0x2d8c1190}},	//   _orwa, _wbr_, _ippj, kzee_, 
   {{0x644c8ded,0xe0448dee,0xa0688def,0x20180120}},	//   _tabi, инди, када_, ópio_, 
   {{0x2d8c1682,0x644c01f0,0x3e788df0,0x9f5c035b}},	//   dzee_, _uabi, _létt_, _retâ_, 
   {{0x53a081f3,0x6d588df1,0xc0e002d3,0xa2d48074}},	//   _дарб, _arwa, _ዓዶም_, _نيست, 
   {{0x6d58035a,0x68f40267,0x673c0139,0x02c801d5}},	//   _brwa, _otyd, _mppj, _ёқди_, 
   {{0x444403bd,0x6d58035a,0xe0d88df2,0xa0140066}},	//   oe_, _crwa, _ава_, _نذاش, 
   {{0x6d588df3,0x9f4c05d5,0x673c143a,0x45440092}},	//   _drwa, dafö_, _oppj, _የካንሠ, 
   {{0x44448df4,0x6d588df5,0x6b8c0198,0x8d708df6}},	//   ie_, _erwa, _ƙaga, مایا, 
   {{0x44448df7,0x1ed88df8,0xd008015b,0x6d58035a}},	//   he_, _شباب_, _রায়_, _frwa, 
   {{0xdca48df9,0x673c004e,0x81e8015b,0x6d588dfa}},	//   _кади, _appj, _মজা_, _grwa, 
   {{0x9f5c0790,0x57a43d76,0x97a401d5,0x00000000}},	//   _odtü_, ашба, арбл, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9f5c8dfb,0x3e7800e8,0x6d5803ac,0xb4c016ae}},	//   _metà_, _gétt_, _yrwa, ुष्_, 
   {{0x44448dfc,0xdb0c0129,0x00000000,0x00000000}},	// [ae10] fe_, _œdèm, --, --, 
   {{0x7c288dfd,0xd3788dfe,0x1ccc0327,0x00000000}},	//   ngdr, кче_, _ྱེས_, --, 
   {{0x11f46e0c,0x9268036b,0x09b88dff,0x00000000}},	//   لواک_, крда_, _مطیع_, --, 
   {{0x44448e00,0x4b34025f,0x95c80166,0xd6d80166}},	//   ae_, שראל_, _ауга_, _штп_, 
   {{0xdbd000a2,0x00000000,0x00000000,0x00000000}},	//   _müñz, --, --, --, 
   {{0x83f80276,0x6d588e01,0x6d5c03cd,0x216407a5}},	//   _верс_, _rrwa, åsam, сиши_, 
   {{0x3e7800db,0x9f5c035b,0x6d58035a,0xc20800cf}},	//   _néts_, _retã_, _srwa, اقۇن_, 
   {{0x2d8c8e02,0xb64804ce,0x6728143a,0x6d586a43}},	//   tzee_, _ｊｐ_, _åfje, _prwa, 
   {{0x3e7800fc,0xd1b88e03,0xe80800bc,0x00000000}},	//   _rétt_, _شارا_, वरमा_, --, 
   {{0x6da43ba6,0x2d8c8e04,0xa968023b,0xada402a9}},	//   _қила, rzee_, қига_, _қалл, 
   {{0x3a2c01c0,0x8d7c001f,0xeb988e05,0x68f48e06}},	//   мep_, ኖራቸው_, уин_, _styd, 
   {{0x6d588e07,0x00000000,0x00000000,0x00000000}},	//   _trwa, --, --, --, 
   {{0x6d580516,0x6e2840e9,0x9f5c0588,0x6c74009d}},	//   _urwa, mgeb, _tetã_, _гуйх, 
   {{0x44448e08,0x6e281aa2,0x65ac06d6,0x9f5c00e4}},	//   xe_, lgeb, _ṱhon, _hetá_, 
   {{0x6d488e09,0xe73800ee,0x7c9404fb,0x6e281418}},	//   lwea, ыев_, _بشنا, ogeb, 
   {{0x6e282238,0x6d480295,0x7d2403b2,0xa3d412eb}},	//   ngeb, owea, _útsí, ाइस_, 
   {{0xe4e81129,0x6e280112,0x68f40857,0x00000000}},	// [ae20] اعره_, igeb, _utyd, --, 
   {{0x44448e0a,0x9f5c8e0b,0x6e2817da,0xa3e88e0c}},	//   ue_, _letá_, hgeb, уджа_, 
   {{0x18740302,0x6e288e0d,0xe1f85080,0xe8b40073}},	//   _העיר_, kgeb, гге_, ृतीच, 
   {{0x2c200574,0x6e280d27,0x6d48000f,0xa184010b}},	//   _माझं_, jgeb, kwea, йылл, 
   {{0x44448e0e,0xd24c036b,0x7e9804fb,0x00000000}},	//   pe_, عنه_, ینتر_, --, 
   {{0x44448e0f,0x6d480066,0x6e280d47,0x23088e10}},	//   qe_, dwea, egeb, _متري_, 
   {{0x6e288e11,0x92380118,0x00000000,0x00000000}},	//   fgeb, ířít, --, --, 
   {{0x8e440075,0xbcf4011c,0xd1c4030d,0x00000000}},	//   ملىك_, опищ, _ӳлте_, --, 
   {{0xa3d400e1,0x22448e12,0x2bd401f9,0xd59800df}},	//   ाइव_, meok_, डेसा, ָביל, 
   {{0x62808e13,0x22448e14,0x6e280175,0x7b1401c4}},	//   lkoo, leok_, ageb, одох, 
   {{0xa1840b65,0x200c8e15,0x7c2801a4,0x6e2801f5}},	//   _тыңл, mafi_, rgdr, bgeb, 
   {{0x62808e16,0x200c8e17,0x6d4831a9,0x05b807f7}},	//   nkoo, lafi_, bwea, _आडंब, 
   {{0xc9848e18,0x3f580051,0x00000000,0x00000000}},	//   пури, _hĩu_, --, --, 
   {{0x200c04c9,0x62808e19,0x00000000,0x00000000}},	//   nafi_, hkoo, --, --, 
   {{0x62808e1a,0x200c0618,0x889405f5,0x2244005a}},	//   kkoo, iafi_, чирх, keok_, 
   {{0x200c8e1b,0x62808e1c,0x97a401ec,0x00000000}},	//   hafi_, jkoo, арұл, --, 
   {{0x628081f6,0x200c8e1d,0x22448e1e,0x6ef4031c}},	// [ae30] dkoo, kafi_, deok_, _iġbe, 
   {{0x6e288e1f,0x22440a73,0x628056df,0x50f0013e}},	//   zgeb, eeok_, ekoo, ҷҷат, 
   {{0x62802790,0x6e280158,0x00000000,0x00000000}},	//   fkoo, ygeb, --, --, 
   {{0x62808e20,0xd5b88e21,0x478800cf,0x6d5c01e3}},	//   gkoo, _бсг_, _ысым_, åsak, 
   {{0x200c8e22,0xafe42360,0x00000000,0x00000000}},	//   fafi_, оолл, --, --, 
   {{0xa3d4032c,0x200c8e23,0x62808e24,0x47340214}},	//   ाइश_, gafi_, akoo, _بریز, 
   {{0x6e288e25,0x628001d9,0x2244005a,0x630000d1}},	//   tgeb, bkoo, beok_, _يۈكل, 
   {{0x200c0270,0xc51404d3,0x6e28002f,0xdee00395}},	//   aafi_, _ببێت, ugeb, мощи, 
   {{0x6e288e26,0x6b8c0198,0x200c014b,0x30140026}},	//   rgeb, _ƙago, bafi_, _мдар, 
   {{0x6e288e27,0x00000000,0x00000000,0x00000000}},	//   sgeb, --, --, --, 
   {{0x6e288e28,0x00000000,0x00000000,0x00000000}},	//   pgeb, --, --, --, 
   {{0xc4d000bc,0x00000000,0x00000000,0x00000000}},	//   _तीनओ, --, --, --, 
   {{0x3eb800dd,0x80cc00eb,0x00000000,0x00000000}},	//   _írta_, াদর্, --, --, 
   {{0x66e48e29,0xd7fc0356,0x2bd001ad,0x00c8030d}},	//   жова, _ţărm_, _हरपा, _элĕк_, 
   {{0x62801e82,0x00000000,0x00000000,0x00000000}},	//   ykoo, --, --, --, 
   {{0x200c8e2a,0xe9a4030d,0x00000000,0x00000000}},	//   zafi_, _майп, --, --, 
   {{0x200c03f9,0x240801f0,0x22440254,0x00000000}},	// [ae40] yafi_, инаи_, veok_, --, 
   {{0xa3d409fd,0x394c0724,0xe3583849,0x200c0067}},	//   ाइल_, çese_, ишеш_, xafi_, 
   {{0xfed4040d,0x200c8e2b,0x06c4009e,0x62808e2c}},	//   _ﺟﺎﯞﺍ, vafi_, ্দবি, tkoo, 
   {{0x200c8e2d,0xa1c412e7,0x62808e2e,0x2bd007f7}},	//   wafi_, обед, ukoo, _हरना, 
   {{0x62808e2f,0x2244005a,0xc8f800cc,0x3228003b}},	//   rkoo, reok_, _অটুত_, сієм_, 
   {{0x62808e30,0x200c8e31,0x20400133,0x00000000}},	//   skoo, uafi_, بکرێ, --, 
   {{0x62808e32,0x00000000,0x00000000,0x00000000}},	//   pkoo, --, --, --, 
   {{0x626413ef,0x200c009f,0xfd74010b,0x00000000}},	//   _باسق, safi_, злиэ, --, 
   {{0x200c01e4,0x00000000,0x00000000,0x00000000}},	//   pafi_, --, --, --, 
   {{0x200c0083,0x40a88e33,0x3f580051,0x00000000}},	//   qafi_, _اخری_, _tĩu_, --, 
   {{0x99c403d4,0x5454010f,0x2bd40b4c,0x00000000}},	//   _এলেক, קסטן_, डेला, --, 
   {{0x316800d0,0x00000000,0x00000000,0x00000000}},	//   ťaze_, --, --, --, 
   {{0x6aac05d1,0xa3d400bc,0x00000000,0x00000000}},	//   _şofö, ाइँ_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc7c40640,0x2bd002ab,0x96e80474,0x37c400c6}},	//   дсти, _हरया, рьга_, سيرف, 
   {{0xd9e0069f,0x46688e34,0x39148e35,0x07e4109a}},	//   _गणपत_, орум_, _емир, ьцям, 
   {{0xd83800ee,0xd7e4187f,0x20c800cd,0x00000000}},	// [ae50] _кэн_, _міно, िताध, --, 
   {{0x28d00950,0x9f5c023a,0x64580d12,0x04c8027d}},	//   _दीपि, _ketä_, _ótil, قوقي_, 
   {{0xb7d88e36,0x38c80e60,0x960400c6,0x27480023}},	//   _دودا_, _پاکی_, _وبحم, _ብፍልጠ, 
   {{0xd624007b,0x00000000,0x00000000,0x00000000}},	//   _بعدي, --, --, --, 
   {{0x59d08e37,0x410402d5,0x91300588,0x00000000}},	//   _सरफर, дзів, ьҭах, --, 
   {{0xa024081f,0x3dd0015b,0xf8bc02c3,0x00000000}},	//   _རྐྱང_, াখাল, ोतिय, --, 
   {{0x386c0af9,0x00000000,0x00000000,0x00000000}},	//   êery_, --, --, --, 
   {{0x31348e38,0xb62c00b5,0x12840345,0x00000000}},	//   _небр, _ｕｖ_, _بمری_, --, 
   {{0xb60800e2,0x00000000,0x00000000,0x00000000}},	//   _ikšķ, --, --, --, 
   {{0x320c8e39,0x9f5c008e,0x3d1c0a8a,0x00000000}},	//   _heey_, _betä_, _मिरे_, --, 
   {{0x320c0009,0xa2b004af,0x447c010f,0x70b80bae}},	//   _keey_, _अदम्, ינזע, ेतील, 
   {{0xf41000fe,0x00000000,0x00000000,0x00000000}},	//   ালিৰ_, --, --, --, 
   {{0x320c058a,0x00000000,0x00000000,0x00000000}},	//   _meey_, --, --, --, 
   {{0x320c058a,0x00000000,0x00000000,0x00000000}},	//   _leey_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4ad82832,0x320c002e,0x20d00311,0xc0c00b82}},	//   _باتھ_, _neey_, mâie_, _ስዊስ_, 
   {{0x28b8010b,0xe44c06be,0x00000000,0x00000000}},	// [ae60] _гунэ_, loжi_, --, --, 
   {{0xe3b03b5f,0xa84800c6,0x00000000,0x00000000}},	//   ىرا_, _الدم_, --, --, 
   {{0x64580cfc,0x9a80044e,0x320c8e3a,0x9878011a}},	//   _ótim, _ይከኣል_, _beey_, _האיט, 
   {{0x3d1c09fd,0xdebc001f,0x48c40124,0xe80800af}},	//   _मिले_, ዶችን_, _хәҭа, वरवा_, 
   {{0x26c08e3b,0x6b80002d,0xc42801ec,0x91008e3c}},	//   _ikko_, hylg, _وتسە_, епче, 
   {{0x21681607,0x91e00d4b,0x101000d1,0x229400e5}},	//   _қизи_, хоче, ىبىد, _کلرس, 
   {{0x10100f87,0x320c002e,0xe36429e7,0x00000000}},	//   ربود, _feey_, _экви, --, 
   {{0x320c3d20,0x9f5c00c7,0xe29800c7,0x6b806873}},	//   _geey_, _retä_, _уаб_, dylg, 
   {{0xa6c8022e,0x9f5c005b,0x00000000,0x00000000}},	//   _rqаl, _setä_, --, --, 
   {{0x6b803d28,0x2fc452fd,0xd6e403d4,0x9f5c0108}},	//   fylg, _fylg_, গীয়া_, _petä_, 
   {{0x320c8e3d,0x00000000,0x00000000,0x00000000}},	//   _yeey_, --, --, --, 
   {{0x5e941291,0x00000000,0x00000000,0x00000000}},	//   _عشاء, --, --, --, 
   {{0x8e8000e4,0x00000000,0x00000000,0x00000000}},	//   _áĝar, --, --, --, 
   {{0x26c08e3e,0x6b800ad9,0x9f5c00c7,0xdb680902}},	//   _akko_, bylg, _tetä_, _грил_, 
   {{0x4c380375,0x00000000,0x00000000,0x00000000}},	//   _התוב, --, --, --, 
   {{0x26c00a40,0xd9180395,0x00000000,0x00000000}},	//   _ckko_, _льо_, --, --, 
   {{0x95c873b8,0x00000000,0x00000000,0x00000000}},	// [ae70] сува_, --, --, --, 
   {{0x26c005ac,0x057403e6,0x320c0de2,0xdbd40108}},	//   _ekko_, راقد, _seey_, pääo, 
   {{0x320c0de2,0x00000000,0x00000000,0x00000000}},	//   _peey_, --, --, --, 
   {{0xba080023,0x766400f1,0x00000000,0x00000000}},	//   _ለኸ_, _تیرې_, --, --, 
   {{0x85440276,0xd1382bbd,0x307400f5,0x00000000}},	//   _пэре, схе_, дуйс, --, 
   {{0x320c8e3f,0xa0640117,0x00000000,0x00000000}},	//   _weey_, даша_, --, --, 
   {{0x320c1bce,0x9008021f,0x00000000,0x00000000}},	//   _teey_, _ۇزاق_, --, --, 
   {{0xc68c0092,0x69cc0210,0x00000000,0x00000000}},	//   _ማረሚያ_, _सरली, --, --, 
   {{0x7d040166,0x00000000,0x00000000,0x00000000}},	//   _çisl, --, --, --, 
   {{0x61442e51,0x00000000,0x00000000,0x00000000}},	//   _تىكە, --, --, --, 
   {{0xa3d437f3,0x2ab0031c,0xcf880139,0xaa4800d8}},	//   ाइए_, eġba_, _усад_, опна_, 
   {{0xedd4286d,0xa9a41638,0x20d00356,0xb8240154}},	//   _قياد, димд, râie_, ম্মত_, 
   {{0xcdc840ec,0x78700022,0x00000000,0x00000000}},	//   _اذان_, _ẽvak, --, --, 
   {{0x3c580166,0x9f400241,0x00000000,0x00000000}},	//   _ничэ_, _ńké_, --, --, 
   {{0xeb98084c,0x9bf8011a,0x35800092,0x00000000}},	//   _фий_, _והצט, ረግበት_, --, 
   {{0x7afc8e40,0xf65400d3,0x00000000,0x00000000}},	//   írte, нтую, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [ae80] --, --, --, --, 
   {{0x6fac0490,0x6728143a,0xdebc0092,0x2900012d}},	//   टपां, _åfjo, ዶችና_, mpka_, 
   {{0x93c0084c,0xb0600139,0x66040798,0x234800d1}},	//   _ţări, _çäyg, _опна, تلاپ_, 
   {{0x26c0005b,0x00000000,0x00000000,0x00000000}},	//   _ukko_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8c9c0073,0x00000000,0x00000000,0x00000000}},	//   गोमो, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x53980375,0x316800d0,0xd84001ef,0xe24400ae}},	//   _וילו, ťaza_, _krčí_, _تخسي, 
   {{0xa3d40034,0xfce002d3,0x00000000,0x00000000}},	//   ाइक_, _ሓረግ_, --, --, 
   {{0xddc001e4,0x6ef40327,0x21248e41,0x00000000}},	//   _gaoŝ, _iġbn, mroh_, --, 
   {{0x201c00d8,0xdbd40139,0x29000419,0x6fd400c0}},	//   _idti_, _mäçk, epka_, _зіцц, 
   {{0x60c8004e,0x00000000,0x00000000,0x00000000}},	//   llfm, --, --, --, 
   {{0x212406a3,0xdb0801e6,0x22bc0521,0x00000000}},	//   nroh_, _nyfö, ọkwa_, --, 
   {{0x3ea4376e,0x7c34074d,0x8cb00139,0x00000000}},	//   limt_, _чекх, _үсәч, --, 
   {{0xcc308e42,0x21240098,0x00000000,0x00000000}},	//   _شروع, hroh_, --, --, 
   {{0x3ea4000f,0x21240c6a,0xcf54011a,0x00000000}},	//   nimt_, kroh_, ובלת_, --, 
   {{0xb4d4016a,0x98040364,0x35b41ee3,0xd49805f5}},	// [ae90] ежащ, _оянд, хбар, орж_, 
   {{0x45d42f23,0x33540137,0x93a48e43,0x00000000}},	//   тоус, нүгө_, мшед, --, 
   {{0xd6d8022e,0x00000000,0x00000000,0x00000000}},	//   _мтм_, --, --, --, 
   {{0x201c25b9,0xd840013a,0xd5840133,0x00000000}},	//   _adti_, _frčí_, _قێزه_, --, 
   {{0xf7e401b9,0x764c04ba,0xdbd4005b,0x823401d5}},	//   _تآکی, meay, _hääk, ضرنا, 
   {{0x2f548e38,0xdbd41b99,0x764c0363,0x00000000}},	//   етис, _kääk, leay, --, 
   {{0xdbd40d77,0x212403a2,0x752c8e44,0xa5600150}},	//   _jääk, aroh_, luaz, _لگەن, 
   {{0x862c02d3,0xb64004ce,0x764c0076,0xdbd40108}},	//   _ድኽነት, _ｍｇ_, neay, _määk, 
   {{0xdbd40664,0x752c8e45,0x00000000,0x00000000}},	//   _lääk, nuaz, --, --, 
   {{0xeb980640,0x764c062c,0x00000000,0x00000000}},	//   зио_, heay, --, --, 
   {{0x6ef4031c,0x17f800dc,0x764c8e46,0x2054010f}},	//   _iġbo, ्रैव_, keay, _ריעל_, 
   {{0xbd8816cb,0x752c8e47,0x6d5c0158,0x91d000bc}},	//   _ڪنهن_, kuaz, åsas, _तराई, 
   {{0xb91402e3,0x2bd00ce0,0x29000009,0xad68009d}},	//   madị_, _हरवा, upka_, _халз_, 
   {{0xbd8800b2,0xe00000af,0xb91402e3,0xeb988e48}},	//   _تنهن_, रुपद_, ladị_, _нил_, 
   {{0x2ca42833,0x9f4c0332,0x00000000,0x00000000}},	//   mild_, ocfá_, --, --, 
   {{0xdc700588,0x2124011f,0x764c0731,0x2ca40076}},	//   _агәы, yroh_, geay, lild_, 
   {{0x752c00c7,0x85b40166,0x00000000,0x00000000}},	// [aea0] guaz, тәнч, --, --, 
   {{0x64c48e49,0x66ec01e4,0x6aa401e4,0x2ca401bf}},	//   ريال, _aŝke, likf, nild_, 
   {{0x764c8e4a,0x00000000,0x00000000,0x00000000}},	//   beay, --, --, --, 
   {{0x6aa48e4b,0xd84002f0,0x00000000,0x00000000}},	//   nikf, _trčí_, --, --, 
   {{0x2ca48e4c,0x66140bf1,0x752c1a44,0x606404a9}},	//   kild_, mayk, cuaz, нҗаң_, 
   {{0x59d00d01,0x66148e4d,0x2ca40a85,0x21248e4e}},	//   _सरसर, layk, jild_, rroh_, 
   {{0xb3542444,0x271c00e1,0x672c025c,0xb90c0022}},	//   _لیلا_, _बटोर_, nubj, ãhẽ_, 
   {{0x66141bb7,0x7d0406be,0x00000000,0x00000000}},	//   nayk, _çisk, --, --, 
   {{0x1ccc0135,0x6aa401e4,0x81c400c7,0x0fc05290}},	//   _ྱེད_, dikf, _рааҧ, кйән, 
   {{0x672c8e4f,0xdce000df,0x661450d4,0x3ea48e50}},	//   kubj, _kroĉ, hayk, simt_, 
   {{0xa3d42db8,0x8d701416,0x661403f0,0x6aa47b7d}},	//   ाइट_, نایا, kayk, fikf, 
   {{0xdbd4007d,0x66140113,0x98a401a6,0x672c00d8}},	//   _rääk, jayk, _điđe_, dubj, 
   {{0xdd908e51,0x2ca48e52,0xf8b80228,0x0dc42b97}},	//   _حوش_, bild_, дөн_, _пуши_, 
   {{0xdbd402f6,0xdce001e4,0xfcc4151e,0x752c022e}},	//   _pääk, _oroĉ, _шәйм, vuaz, 
   {{0x764c0789,0x9f480139,0x00000000,0x00000000}},	//   teay, _übä_, --, --, 
   {{0x752c8e53,0xb98401b9,0x66148e54,0xdbd401f4}},	//   tuaz, _атоқ, gayk, _vääk, 
   {{0x58848e55,0xd7f800cf,0x764c00ad,0x9f4001e1}},	// [aeb0] _зына, _нун_, reay, _ńkì_, 
   {{0x752c3633,0x39480113,0x661400e4,0xdbd41057}},	//   ruaz, _ipas_, aayk, _tääk, 
   {{0x1ccc031c,0x17dc0183,0x66140bfa,0xe7ac00cc}},	//   _ྱེན_, _ব্ৰি, bayk, _গৰীয, 
   {{0x66140009,0xa3d42356,0x2bd400bc,0x00000000}},	//   cayk, ाइज_, डेटा, --, 
   {{0x82348e56,0x752c5bd9,0x69d8033f,0xdd848e57}},	//   ارما, quaz, ęteg, _ئو_, 
   {{0x602069a4,0x6aa400df,0x20d0054e,0x00000000}},	//   адша, zikf, tâia_, --, 
   {{0x39480ac5,0x2ca401bf,0x73c431b1,0xdb0c01e1}},	//   _lpas_, vild_, _شيرم, _èdèn, 
   {{0x2ca45b5e,0x3948023a,0xa3bc00e1,0x00000000}},	//   wild_, _opas_, ँअर_, --, 
   {{0x39480211,0x2ca40582,0x6aa405ac,0x5d3000ec}},	//   _npas_, tild_, vikf, لفيئ, 
   {{0x2ca40175,0x3e7800d7,0xac8401c6,0x61e41155}},	//   uild_, _méty_, тгол, _úkla, 
   {{0xcf248e58,0x6aa48e59,0xeb988e5a,0x39488e5b}},	//   _سراي, tikf, фин_, _apas_, 
   {{0xfeb80491,0x39488e5c,0x1ee807d6,0x2ca48e5d}},	//   _كانت_, _bpas_, _قولی_, sild_, 
   {{0x39480129,0xed5801c0,0x2ca43a52,0x6aa402d0}},	//   _cpas_, _цол_, pild_, rikf, 
   {{0x6aa48e5e,0xa8a001b9,0x66141181,0x8e2c022e}},	//   sikf, рғоқ, wayk, _zigа_, 
   {{0x6b8c0198,0x661402d1,0x6600005a,0xe6c406c2}},	//   _ƙagu, tayk, ñoko, نتري, 
   {{0xfbd071c5,0xaa440588,0x2550007f,0x00000000}},	//   _اته_, _реил, _pņl_, --, 
   {{0x66148e5f,0xa8040801,0xe50405d9,0xe9d801a9}},	// [aec0] rayk, _изпл, ئبري, _юки_, 
   {{0x66148e60,0x00000000,0x00000000,0x00000000}},	//   sayk, --, --, --, 
   {{0xddc0098d,0x66140986,0x25500100,0x672c8e61}},	//   _mnoš, payk, _wņl_, qubj, 
   {{0xd36c0597,0x66140986,0x6d2005d7,0xe80800bc}},	//   تهم_, qayk, _मिंग_, वरका_, 
   {{0xc4345ce9,0x00000000,0x00000000,0x00000000}},	//   _مکات, --, --, --, 
   {{0xddc027c4,0x65c00046,0x7d040205,0x3580024c}},	//   _nnoš, _бұға, _çisi, _уқуб, 
   {{0x4438054e,0x8e4400d1,0x00000000,0x00000000}},	//   _icr_, چلىك_, --, --, 
   {{0x44388e62,0x645c4b55,0x7d7800c6,0x8e440131}},	//   _hcr_, ldpi, فمبر_, نلىك_, 
   {{0xd1c41142,0x5c04010b,0x7e04007f,0x91e00a5b}},	//   _алте_, кяна, včsč, _воте, 
   {{0x645c8e63,0x5f0401c6,0x65640051,0x00000000}},	//   ndpi, _азжа, _mrkh, --, 
   {{0x5fb443d1,0x60d80175,0x645c002f,0x39483046}},	//   _अखिल, _ihtm, idpi, _spas_, 
   {{0x44388e64,0x39488e65,0xf8bc0b7c,0x8650013f}},	//   _lcr_, _ppas_, ोत्प, nnɔd, 
   {{0x81e403f4,0x8d708e66,0x3d1c00e1,0x44380f85}},	//   পুর_, _ناوا, _मिटे_, _ocr_, 
   {{0x44388e67,0x60d8030d,0x3948031c,0x7b841df2}},	//   _ncr_, _jhtm, _vpas_, _مابە, 
   {{0x6cd800c8,0x69d400a2,0x60d802d0,0x8cc400db}},	//   _אַקצ, _ezye, _mhtm, _جووق_, 
   {{0x44388e68,0x38ac05be,0x39480142,0x00000000}},	//   _acr_, džre_, _tpas_, --, 
   {{0x44388e69,0x645c0d27,0x39488e6a,0xf4d80408}},	// [aed0] _bcr_, fdpi, _upas_, емаш_, 
   {{0x44388e6b,0x7aec8e6c,0x147452a4,0x73c48e6d}},	//   _ccr_, _hiat, خارج, гәбе, 
   {{0x7aec0924,0xd34400f1,0x212800b8,0x00000000}},	//   _kiat, خیزه_, _ābha_, --, 
   {{0x7aec0327,0x94200131,0x60d8000d,0xe3c400e8}},	//   _jiat, _ھوزۇ, _ahtm, ññal_, 
   {{0x7aec8e6e,0x44388e6f,0x765c0649,0x7c388e70}},	//   _miat, _fcr_, _iasy, _ocvr, 
   {{0x4438070d,0x7aec8e71,0x765c8e72,0xf40810fe}},	//   _gcr_, _liat, _hasy, _سيرى_, 
   {{0x765c8e73,0x60d83c36,0x81e40eac,0x339401a9}},	//   _kasy, _dhtm, পুল_, _савё, 
   {{0x765c07dd,0x60d803d0,0xddc00841,0x518400c7}},	//   _jasy, _ehtm, _snoš, _иуза, 
   {{0x765c8e74,0x7bdc1427,0x00000000,0x00000000}},	//   _masy, ýrun, --, --, 
   {{0x765c8e75,0x7aec00c5,0xcfa40124,0xf41000fe}},	//   _lasy, _aiat, _ишеи, ালকৰ_, 
   {{0xf98800d9,0x00000000,0x00000000,0x00000000}},	//   _צר_, --, --, --, 
   {{0x765c60d7,0x7aec7876,0x60d80334,0x9f5c01ef}},	//   _nasy, _ciat, _zhtm, _jetý_, 
   {{0x7aec8e76,0xa68401b9,0x00000000,0x00000000}},	//   _diat, қлад, --, --, 
   {{0x6d586ad0,0x60d88e77,0x66ec01e4,0xddc01050}},	//   _iswa, _xhtm, _aŝka, _unoš, 
   {{0x7aec8e78,0x765c0209,0x64a43f6e,0x6d5802d0}},	//   _fiat, _basy, ңаба, _hswa, 
   {{0x7aec8e79,0x44388e7a,0x369407d8,0x765c8e7b}},	//   _giat, _scr_, ашус, _casy, 
   {{0x765c8e7c,0x44388e7d,0x6d5803ac,0xf954030d}},	// [aee0] _dasy, _pcr_, _jswa, _кĕтм, 
   {{0x765c8e7e,0xd36c16cb,0x6d588e7f,0x7aec0ffb}},	//   _easy, ڻهن_, _mswa, _ziat, 
   {{0x765c8e80,0x6d5803ac,0x68f40208,0x990001e4}},	//   _fasy, _lswa, _huyd, ĝĉev, 
   {{0xdce0038f,0x60d80408,0x765c8e81,0x68f48e82}},	//   _proċ, _shtm, _gasy, _kuyd, 
   {{0x60d8030d,0x6d588e83,0x4438045a,0x656402d0}},	//   _phtm, _nswa, _tcr_, _urkh, 
   {{0x765c0585,0x443830de,0x64a4341e,0xd00c00c6}},	//   _zasy, _ucr_, _сага, كله_, 
   {{0x6d588e84,0x765c0a28,0x68f4002e,0xe2988e85}},	//   _aswa, _yasy, _luyd, _зав_, 
   {{0x44448e86,0xa1148e87,0x6d5803ac,0x7c3802f0}},	//   lf_, _مورت, _bswa, _scvr, 
   {{0x7aec8e88,0x6d5870a9,0x44440773,0x00000000}},	//   _riat, _cswa, of_, --, 
   {{0x44448e89,0x6d5833d5,0xd12c0345,0x5190007b}},	//   nf_, _dswa, _رمم_, _الكذ, 
   {{0x44448e8a,0x7aec8e8b,0x29100986,0x5474008f}},	//   if_, _piat, _awya_, אגיע_, 
   {{0x6d58035a,0x68f4236c,0x44440432,0x41b81546}},	//   _fswa, _buyd, hf_, _अशास, 
   {{0x7aec8e8c,0x765c8e8d,0xa8008e8e,0x98480801}},	//   _viat, _rasy, ğınd, нява_, 
   {{0x44440460,0xa8004952,0xed4c16cb,0x765c8e8f}},	//   jf_, şınd, _آھي_, _sasy, 
   {{0x7aec8e90,0x44440334,0xbb5823be,0xd4980124}},	//   _tiat, df_, _райх_, ҕра_, 
   {{0x7bd804b9,0x44448e91,0x9f5c0023,0x6d588e92}},	//   _izvu, ef_, _aftë_, _yswa, 
   {{0x25f40cb4,0x68f400a2,0x765c6341,0x955400f1}},	// [aef0] ौड़ी_, _guyd, _vasy, دخزا, 
   {{0x765c8e93,0x78a426b8,0xdce007f5,0x9f5c8e94}},	//   _wasy, _umhv, _oroč, _betü_, 
   {{0x765c1161,0xfa7802d3,0x68f401f5,0x36d406ed}},	//   _tasy, _ብማዕረ_, _zuyd, _вонр, 
   {{0x44448e95,0x9f5c004e,0x20640014,0x00000000}},	//   af_, _letó_, یٖنہ, --, 
   {{0x44448e96,0xe8080073,0x394c036e,0x00000000}},	//   bf_, वरचा_, çesh_, --, 
   {{0x752c02fb,0x22bc01f2,0x63b0020c,0xc0c80063}},	//   mraz, ọkpa_, èdné, лује_, 
   {{0x752c011f,0x6d588e97,0x8f6401d3,0x40788e98}},	//   lraz, _sswa, البے_, الىڭ_, 
   {{0x752c8e99,0xdfcc00db,0xdce00010,0x6d580857}},	//   oraz, بيى_, _droč, _pswa, 
   {{0x7bd80099,0xe7f8012c,0xc0c002d3,0x6d586143}},	//   _azvu, ्डमा_, ስሎም_, _qswa, 
   {{0x68f40113,0x752c8e9a,0x4034010b,0x6d580857}},	//   _ruyd, iraz, _гефс, _vswa, 
   {{0x752c0316,0xbc30001f,0x68f4014f,0x6d5802d0}},	//   hraz, _ተጠያቂ, _suyd, _wswa, 
   {{0x6d588e9b,0x68f40c67,0x7bd8004c,0x752c8e9c}},	//   _tswa, _puyd, _dzvu, kraz, 
   {{0x6d588e9d,0x68f48e9e,0x44448e9f,0x7e7400cf}},	//   _uswa, _quyd, yf_, _دالئ, 
   {{0xfd1004d3,0x4444010a,0xebe40108,0x00000000}},	//   _رجه_, xf_, _колп, --, 
   {{0x752c0323,0xeb98483d,0xe6140261,0x649001a8}},	//   eraz, _шик_, ифаќ, _bæin, 
   {{0xfb248ea0,0x752c8ea1,0x44448ea2,0x68f48ea3}},	//   _اروپ, fraz, wf_, _tuyd, 
   {{0x752c8ea4,0x7d040724,0x99d00220,0x41a4000d}},	// [af00] graz, _çist, _وقىت, _खेंस, 
   {{0x44448ea5,0x9f5c007f,0x00000000,0x00000000}},	//   uf_, _metò_, --, --, 
   {{0x44448ea6,0x752c8ea7,0x00000000,0x00000000}},	//   rf_, araz, --, --, 
   {{0x752c8ea8,0xd7b8025f,0x444429ef,0xe2440597}},	//   braz, _יציר, sf_, شخصي, 
   {{0x752c8ea9,0x44448eaa,0xdce01710,0xdd0000e2}},	//   craz, pf_, _sroč, ērīg, 
   {{0xdce01326,0x88b0016b,0xc0e002d3,0x394c8eab}},	//   _proč, _hwɛb, _ናቶም_, çesi_, 
   {{0xd9d01b76,0x7de000e4,0x04c800ec,0x00000000}},	//   _सर्ट, kâsé, _لوڏي_, --, 
   {{0xdce00fb7,0x64a40fc0,0xce6401c4,0x00000000}},	//   _vroč, _саҳа, арьд_, --, 
   {{0x9f5c00cf,0x60e83bd4,0xbebc002b,0xfaf800e2}},	//   _petó_, _амам_, _avīc, rvīm_, 
   {{0xdce008a4,0xd12c2f84,0x0fa40073,0xdd9001ec}},	//   _troč, _آمل_, _केवढ, йақы, 
   {{0xa8008eac,0x799c0007,0xdce00010,0x752c8ead}},	//   ğıld, wzsw, _uroč, zraz, 
   {{0x38ac05be,0xa8000d9c,0x752c8eae,0x9d440354}},	//   džra_, şıld, yraz, _ведд, 
   {{0x0e9802e4,0xc984084c,0xdb4c0133,0x394c8eaf}},	//   _בשאל, оури, سێک_, ïes_, 
   {{0xda0425fe,0x752c8eb0,0x8c400063,0x00000000}},	//   _व्रत_, vraz, _деље, --, 
   {{0x7bd84dd9,0x0b54009f,0x00000000,0x00000000}},	//   _uzvu, _نشيب_, --, --, 
   {{0x35f48eb1,0x31680419,0x03b000fe,0x4b780a7c}},	//   спар, ťazi_, _কৰ্ণ, _יאוו, 
   {{0x752c8eb2,0x63e48337,0x95c873b8,0x34948eb3}},	// [af10] uraz, ەيلە, тува_, баар, 
   {{0x752c588c,0x7af80218,0x449842cd,0x26d004ba}},	//   rraz, _kuvt, авую_, alyo_, 
   {{0xb9e0067d,0x93241129,0xa8540302,0x87e4247f}},	//   _ኩሉ_, شران, _היתה_, _وتپە, 
   {{0x7af8014f,0xe194009d,0x00000000,0x00000000}},	//   _muvt, өлхө, --, --, 
   {{0x752c03e3,0x00000000,0x00000000,0x00000000}},	//   qraz, --, --, --, 
   {{0x38600639,0x77f40da3,0x41740116,0x00000000}},	//   _jahr_, _आलोक_, تامس, --, 
   {{0xb3e403f4,0x33940597,0x3860022e,0xd258011c}},	//   _প্রজ, _الأز, _mahr_, _ица_, 
   {{0x34941ee3,0x02a48eb4,0x8d240131,0x38608eb5}},	//   _таҳр, _друм, аниң_, _lahr_, 
   {{0x51848eb6,0x6da45a41,0x59d000e1,0xada48eb7}},	//   _тува, сипа, _सरगर, сапл, 
   {{0xec781606,0x38608eb8,0x321c1327,0xc0c8014b}},	//   упо_, _nahr_, lawy_, _кухе_, 
   {{0xeac4004e,0xf4b400cc,0x00000000,0x00000000}},	//   йбоп, _জীৱব, --, --, 
   {{0xdb1c0316,0x7af80455,0xa800029f,0xa3c8000d}},	//   íván, _duvt, ğımd, _ऊडस_, 
   {{0xa8008eb9,0x7de000e4,0x00000000,0x00000000}},	//   şımd, râsé, --, --, 
   {{0xe7388eba,0xdd8c00c6,0x29d401b9,0x2d8c002e}},	//   лег_, _سوى_, _қўйс, myee_, 
   {{0x98a01586,0x321c033f,0x2d8c0009,0xa6940114}},	//   чире, kawy_, lyee_, брај, 
   {{0x321c0034,0x672c0158,0x69940108,0x060800fb}},	//   jawy_, rrbj, _грох, рмаҫ_, 
   {{0x386067c4,0x2d8c8ebb,0xe7380166,0xa96800f3}},	// [af20] _fahr_, nyee_, _өеп_, _сипа_, 
   {{0x38608ebc,0xe5a40116,0x7af80455,0x2d8c5dd8}},	//   _gahr_, _ңини, _yuvt, iyee_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2d8c016b,0x386002f0,0x00000000,0x00000000}},	//   kyee_, _zahr_, --, --, 
   {{0xa6c800e5,0xb6c401af,0x00000000,0x00000000}},	//   _لوگل_, _фияһ, --, --, 
   {{0x1eb401e0,0x2ef802f0,0x2ff400d1,0x00000000}},	//   өклө_, _čsfr_, يتىڭ, --, 
   {{0x321c8ebd,0xa2d4143e,0x2d8c058a,0xe0d001d9}},	//   bawy_, _هيست, eyee_, _ہٲر_, 
   {{0x93b40375,0xa22400f2,0x00000000,0x00000000}},	//   _הללו_, _درسه, --, --, 
   {{0xdce002b5,0x2d8c0134,0x41dc00af,0x7af8047e}},	//   _aroā, gyee_, _बरिस, _suvt, 
   {{0x7af80455,0x30741188,0x00000000,0x00000000}},	//   _puvt, _мухс, --, --, 
   {{0x2d8c8ebe,0xdfa400c6,0x5478008f,0xaca801ed}},	//   ayee_, _احذي, אטיו, جھنے_, 
   {{0x3860017a,0x7af80455,0x2d8c0009,0x00000000}},	//   _sahr_, _vuvt, byee_, --, 
   {{0x9cc8010b,0x7af8014f,0x5ce40064,0x00000000}},	//   _йыка_, _wuvt, _люка, --, 
   {{0x98a80311,0x321c0034,0x3860022e,0xe8f801e0}},	//   ducă_, zawy_, _qahr_, рлѳ_, 
   {{0x48a86c48,0x2ab0025c,0x818c0150,0x164800cf}},	//   стям_, eġbu_, _ﺒﻐﻴﺔ_, лчап_, 
   {{0x386003fa,0xd9a802f5,0xa3bc007d,0x00000000}},	//   _wahr_, _গুণম, ुअन_, --, 
   {{0x3a288ebf,0x7d0400a3,0x386001a9,0x44f42a3b}},	// [af30] _idap_, _éisd, _tahr_, зпус, 
   {{0x66d80227,0xb78801af,0x00000000,0x00000000}},	//   rïka, _кәбе_, --, --, 
   {{0x321c0034,0xb7d8208f,0x00000000,0x00000000}},	//   tawy_, _خودا_, --, --, 
   {{0x95c80228,0xdc8c02d3,0x899002d3,0x2d8c8ec0}},	//   _буга_, _ዝገበረ_, _ዝኸኣለ_, yyee_, 
   {{0x321c0034,0x00000000,0x00000000,0x00000000}},	//   rawy_, --, --, --, 
   {{0x8650013f,0x3a28045a,0xf0e800d1,0xc0cc0092}},	//   nnɔn, _ldap_, جىتى_, _ቢቻል_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3a28002e,0x31340117,0xae8800db,0x00000000}},	//   _ndap_, _мебр, рбиз_, --, 
   {{0xa2808ec1,0xf8c80073,0x00000000,0x00000000}},	//   _تینو, ळवाय, --, --, 
   {{0x316c0129,0x2d8c0009,0x40840117,0x2ca801f4}},	//   _irez_, ryee_, _нухб, ркоп_, 
   {{0x316c0165,0x2d8c0de2,0xeab80395,0x4ec400c0}},	//   _hrez_, syee_, ийо_, _лёдз, 
   {{0x316c8ec2,0x28d00034,0xe8b0012c,0x00000000}},	//   _krez_, _दीजि, ँच्च, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3804013e,0x00000000,0x00000000,0x00000000}},	//   зорҳ, --, --, --, 
   {{0x7c648ec3,0xaa448ec4,0x2a0800ee,0x3774005b}},	//   _راول, _дейл, _кейп_, пытс, 
   {{0x316c0276,0xe8f800f3,0xdb0c0248,0x00000000}},	//   _orez_, _кли_, _èdán, --, 
   {{0xda780375,0x00000000,0x00000000,0x00000000}},	// [af40] _כנקר, --, --, --, 
   {{0xe3b07427,0x61e400bc,0x7d048ec5,0x00000000}},	//   ورا_, _úkli, _éise, --, 
   {{0xe1f88ec6,0x63a001e4,0xe8c401f9,0x00000000}},	//   аге_, ĝono, लकीच, --, 
   {{0x316c0f72,0xaac8694b,0x7bdc0327,0xe29800f0}},	//   _brez_, रविक, żrug, јад_, 
   {{0x60c88ec7,0x316c0356,0x5180005b,0xa0340725}},	//   tofm, _crez_, дуща, قىشت, 
   {{0x20188ec8,0x316c8ec9,0x00000000,0x00000000}},	//   úpi_, _drez_, --, --, 
   {{0x316c083a,0x644c8eca,0x60c800d7,0xbebc0171}},	//   _erez_, _ibbi, rofm, _dvīn, 
   {{0x60c8025c,0xe2a802f2,0x00000000,0x00000000}},	//   sofm, _ئاسن_, --, --, 
   {{0x316c030a,0x6280000d,0x60240395,0x00000000}},	//   _grez_, mjoo, _мдаа, --, 
   {{0x6280049b,0x66040270,0x3a28002d,0x9b688ecb}},	//   ljoo, _lfkk, _sdap_, ашма_, 
   {{0x644c020c,0x628004ba,0x6d5c8ecc,0x00000000}},	//   _mbbi, ojoo, æsar, --, 
   {{0x62808ecd,0x644c01bf,0x00000000,0x00000000}},	//   njoo, _lbbi, --, --, 
   {{0x644c8ece,0x6ef40006,0xa2b0227c,0x8d6012e7}},	//   _obbi, _išba, _आगन्, _овце, 
   {{0x38540023,0xd8380166,0x00000000,0x00000000}},	//   _ምዝራብ, шэм_, --, --, 
   {{0x01d00154,0x00000000,0x00000000,0x00000000}},	//   িধিদ, --, --, --, 
   {{0x644c8ecf,0x3d00007f,0x62800694,0x20000166}},	//   _abbi, _kòw_, jjoo, _şkil_, 
   {{0x55040801,0x62808ed0,0xa2cc00dc,0x58848ed1}},	// [af50] ючва, djoo, तवन्, _дына, 
   {{0x316c0589,0x644c01fa,0xc954008d,0x62800009}},	//   _rrez_, _cbbi, _חמץ_, ejoo, 
   {{0x32548ed2,0xd7640075,0x36d45abb,0xd37802d5}},	//   звер, _بەزى_, _ноор, шча_, 
   {{0x316c00df,0x644c8ed3,0x71780724,0x62800009}},	//   _prez_, _ebbi, йбер_, gjoo, 
   {{0x543400aa,0xcad8011a,0x00000000,0x00000000}},	//   _ورسر, קודת_, --, --, 
   {{0x80a802bf,0x62808ed4,0x10488ed5,0x00a401d9}},	//   овів_, ajoo, ряди_, وٝنُ, 
   {{0x62800014,0x316c05c7,0x00000000,0x00000000}},	//   bjoo, _wrez_, --, --, 
   {{0x316c1529,0x3d00007f,0x52740244,0x00000000}},	//   _trez_, _bòw_, _باسز, --, 
   {{0xf1b817a3,0x7d00009a,0x316c8ed6,0xf26801af}},	//   _beše_, gqms, _urez_, _киңл_, 
   {{0xcc8403e6,0xc6800240,0x00000000,0x00000000}},	//   تۆته_, _ሓዊስካ_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe3c400e8,0xf3ec0154,0x00000000,0x00000000}},	//   ññil_, _ওভার_, --, --, 
   {{0x0dc81fbe,0x00000000,0x00000000,0x00000000}},	//   _тужи_, --, --, --, 
   {{0x50c800cd,0x00000000,0x00000000,0x00000000}},	//   िविष, --, --, --, 
   {{0x66e48ed7,0x62801bce,0xa6940798,0x317800e5}},	//   зова, yjoo, прај, _ászf_, 
   {{0x7d04092e,0x644c0083,0x6280058a,0xe81c0037}},	//   _éisc, _sbbi, xjoo, _बजवा_, 
   {{0xe3b830cb,0xe3f8592e,0x9a380375,0x00000000}},	// [af60] әбе_, معاش_, _התפק, --, 
   {{0x1dcc05f9,0x69d4102c,0x00000000,0x00000000}},	//   _हँसत, _iyye, --, --, 
   {{0x62801bce,0xd7f8011a,0x00000000,0x00000000}},	//   tjoo, _להיל, --, --, 
   {{0x236400c8,0x254c00e2,0x0cc40b6d,0x00000000}},	//   ĉoj_, tēlā_, रकुम, --, 
   {{0x62808ed8,0xa068004e,0x00000000,0x00000000}},	//   rjoo, йада_, --, --, 
   {{0x10a08ed9,0x644c8eda,0x628000c5,0x65c001ec}},	//   ничн, _ubbi, sjoo, _жұға, 
   {{0xf1b83341,0xe2848ab1,0x00000000,0x00000000}},	//   _reše_, _елви, --, --, 
   {{0x61448edb,0x00000000,0x00000000,0x00000000}},	//   _неба, --, --, --, 
   {{0x63440092,0x00000000,0x00000000,0x00000000}},	//   _ያልጠበ, --, --, --, 
   {{0x21240369,0xa4d002dd,0x74300023,0x3b300092}},	//   msoh_, мшiл, _ኣምጺእ, _በተገኘ, 
   {{0x201c8edc,0x00000000,0x00000000,0x00000000}},	//   _ieti_, --, --, --, 
   {{0x201c8edd,0x2ab027c4,0x3d8826a8,0x62840248}},	//   _heti_, tšba_, _وحشی_, _òkod, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x201c2b10,0xd5b80032,0x9f4001e1,0x00000000}},	//   _jeti_, ҡса_, _ńkù_, --, 
   {{0x201c8ede,0x69d40bc1,0x36d48edf,0x00000000}},	//   _meti_, _eyye, довр, --, 
   {{0x201c8ee0,0xddc04ea1,0xda647ae6,0x95c83cc5}},	//   _leti_, _množ, _رابي, буза_, 
   {{0xd8c8084c,0xcebc0118,0x98040153,0x00000000}},	// [af70] _гынд_, ířil_, _нянд, --, 
   {{0x201c8ee1,0xd37802e8,0x56940092,0x00000000}},	//   _neti_, йче_, _መገኘቱ_, --, 
   {{0x9f480cad,0x00000000,0x00000000,0x00000000}},	//   _àbè_, --, --, --, 
   {{0x201c0037,0x00000000,0x00000000,0x00000000}},	//   _aeti_, --, --, --, 
   {{0x201c05f5,0x21240369,0x00000000,0x00000000}},	//   _beti_, gsoh_, --, --, 
   {{0x802404a9,0x201c0882,0x764c8ee2,0x00000000}},	//   ىرىم, _ceti_, lfay, --, 
   {{0x201c0038,0x764c0067,0x261001f9,0x00000000}},	//   _deti_, ofay, तरची_, --, 
   {{0x2d94319b,0x201c0ba7,0xee3810fc,0xa1f000d1}},	//   дрос, _eeti_, цни_, رۋەت, 
   {{0x201c8ee3,0x764c0fec,0xa2b000cd,0xc2e401a9}},	//   _feti_, ifay, _आगत्, _чўри, 
   {{0x201c008c,0x00000000,0x00000000,0x00000000}},	//   _geti_, --, --, --, 
   {{0xc02400db,0x4034030d,0x00000000,0x00000000}},	//   _سىني, _чехс, --, --, 
   {{0xe28c022e,0x00000000,0x00000000,0x00000000}},	//   qqаt_, --, --, --, 
   {{0x14bc0882,0x00000000,0x00000000,0x00000000}},	//   ्वाण, --, --, --, 
   {{0x764c8ee4,0x7e980220,0x1de008a3,0x00000000}},	//   efay, _ونەر_, _परतत, --, 
   {{0x6d4835b8,0x764c011f,0x24887636,0x7470001f}},	//   ltea, ffay, _robm_, _ለማፋጠ, 
   {{0x61f40024,0x6d488ee5,0x66e40b01,0xabc401af}},	//   žyli, otea, фоба, _наҙҙ, 
   {{0xa8c4036b,0x21240548,0x6ac81788,0xd54400db}},	// [af80] _ойид, xsoh_, रवीर, мпте_, 
   {{0x6d480fa3,0x27f80048,0x764c0014,0x00000000}},	//   itea, _ugpn_, afay, --, 
   {{0x6d488ee6,0x00000000,0x00000000,0x00000000}},	//   htea, --, --, --, 
   {{0x6d480b21,0x9f4801e1,0xc69400df,0x00000000}},	//   ktea, _àbé_, _נאָ_, --, 
   {{0x20c800c6,0xb9f802d3,0xa0a402a9,0x21588ee7}},	//   يبتي_, _መዚ_, мадд, تجاع_, 
   {{0xd00c8ee8,0x6d480597,0x66140153,0x201c06be}},	//   لله_, dtea, lbyk, _qeti_, 
   {{0x201c8ee9,0x3b700020,0xe2988eea,0x212401c7}},	//   _veti_, _ስራዎች_, _дав_, ssoh_, 
   {{0x201c8eeb,0x6d4836f4,0xf1a804fb,0xe3c400e8}},	//   _weti_, ftea, _کافه_, ññul_, 
   {{0x201c8eec,0x63ac0006,0x6d4800c6,0x6ef40153}},	//   _teti_, žinė, gtea, _išbl, 
   {{0x7b140692,0x3eb800e5,0x00000000,0x00000000}},	//   ндох, őrt_, --, --, 
   {{0x6d488eed,0x764c03ee,0xd00c00db,0x00000000}},	//   atea, yfay, _ئلم_, --, 
   {{0x6d488eee,0x52c00150,0x00000000,0x00000000}},	//   btea, _ﯨﺸﯟﺩ, --, --, 
   {{0xdd908eef,0x6d488ef0,0x1de00882,0x00000000}},	//   _جوش_, ctea, _परित, --, 
   {{0xfc646241,0xddc0012d,0x00000000,0x00000000}},	//   _سختی, _mnoż, --, --, 
   {{0xf1b88ef1,0xd68800a7,0x00000000,0x00000000}},	//   _meša_, ощад_, --, --, 
   {{0xf1b80e3c,0xdce0110c,0x661405e4,0x1de0739b}},	//   _leša_, _broć, gbyk, _परात, 
   {{0xd7f88ef2,0x764c350e,0x8ad41370,0x98a80210}},	// [af90] _мун_, rfay, _جتوئ, zucę_, 
   {{0x764c8ef3,0xf1b833fc,0x00000000,0x00000000}},	//   sfay, _neša_, --, --, 
   {{0x5fac069f,0x6d4805f5,0x764c0223,0x98a80356}},	//   _झेलल, ztea, pfay, arcă_, 
   {{0x6d488ef4,0x38ac05be,0x776401d5,0xda1c7ef5}},	//   ytea, džri_, _ishx, परित_, 
   {{0x6448004e,0x37a400fe,0x00000000,0x00000000}},	//   òfic, _খুচৰ, --, --, 
   {{0x65600240,0x6d480254,0x00000000,0x00000000}},	//   çohe, vtea, --, --, 
   {{0xf1b801a6,0x6d4801f5,0xda1c0073,0xefb000e5}},	//   _deša_, wtea, परात_, دیاگ, 
   {{0x6d488ef5,0x39480194,0x78b40433,0xe514012d}},	//   ttea, _oqas_, hizv, दीकि_, 
   {{0x2d988ef6,0x7bd800e4,0xf7d408b0,0x78b4004c}},	//   áse_, _ayvu, ﺘﯩﻤﻪ, kizv, 
   {{0x6d488ef7,0x7764036b,0x78b401a6,0x00000000}},	//   rtea, _oshx, jizv, --, 
   {{0xaa448ef8,0x6d488ef9,0x78b48efa,0x00000000}},	//   ىندى, stea, dizv, --, 
   {{0x9ce800f8,0x67200210,0x00000000,0x00000000}},	//   _ہونے_, _łojo, --, --, 
   {{0x7c648efb,0x6f00003a,0x78b40810,0x776401d5}},	//   رایل, _hulc, fizv, _ashx, 
   {{0x6f0000dd,0xf8b40022,0x00000000,0x00000000}},	//   _kulc, кҩы_, --, --, 
   {{0x7bd80006,0xc5f80f4a,0xc1dc610a,0xeb9801c0}},	//   _gyvu, ंख्य_, _बर्ग, _хий_, 
   {{0x6f008efc,0xdce0098d,0x00000000,0x00000000}},	//   _mulc, _proć, --, --, 
   {{0x65c405f5,0x6f00014f,0x3964035b,0xbebc00b8}},	// [afa0] хбаа, _lulc, _аныҳ, _dvīh, 
   {{0xa3bc06ab,0xdb040209,0xfaf80165,0x1de01a04}},	//   ुअल_, ümçi, nwīn_, _परसत, 
   {{0xdd2400c0,0x00000000,0x00000000,0x00000000}},	//   _mūšy, --, --, --, 
   {{0x66d80227,0x225000ee,0x26c08efd,0xa1c48efe}},	//   kïki, ýyk_, _ujko_, нбед, 
   {{0x26d08eff,0xf1b80010,0xe7f800bc,0x91e000f3}},	//   moyo_, _peša_, ्डका_, гоце, 
   {{0x6f0022a9,0x3f48025a,0x23284d15,0x26d08f00}},	//   _bulc, tûu_, _ноги_, loyo_, 
   {{0x645c8f01,0xf1b81050,0x6f008f02,0xcfd00114}},	//   mepi, _veša_, _culc, лошћ, 
   {{0x6f008f03,0x645c05f9,0x26d08f04,0xddc0013a}},	//   _dulc, lepi, noyo_, _zboř, 
   {{0xf1b80010,0x00000000,0x00000000,0x00000000}},	//   _teša_, --, --, --, 
   {{0x645c8f05,0x26d08f06,0x6f0088ff,0xffd401ee}},	//   nepi, hoyo_, _fulc, _иҫлә_, 
   {{0x26d00296,0x6f0001a9,0x78b48f07,0x00000000}},	//   koyo_, _gulc, vizv, --, 
   {{0x6ee48f08,0x645c8f09,0x78b40099,0x26d08f0a}},	//   tóbe, hepi, wizv, joyo_, 
   {{0x78b4006f,0x26d00214,0x00000000,0x00000000}},	//   tizv, doyo_, --, --, 
   {{0x645c8f0b,0x3b548f0c,0xc86401c0,0x7bd80064}},	//   jepi, _аккр, лтси, _tyvu, 
   {{0x645c8f0d,0x78b48f0e,0x65648f0f,0x8c4000f3}},	//   depi, rizv, _askh, _сеје, 
   {{0x26d00bd7,0x44b4136b,0x78b48f10,0x8aa40139}},	//   goyo_, ҳбус, sizv, _брьд, 
   {{0x35f40209,0xa8001ae4,0x78b40810,0x645c010f}},	// [afb0] тпар, ğırd, pizv, fepi, 
   {{0x1cbc1efe,0xa8001ae4,0xf8b8009d,0x00000000}},	//   _ཁམས_, şırd, _цөм_, --, 
   {{0x229c025a,0x19f40014,0x6584016b,0x26d08f11}},	//   _sïka_, _تِکھ_, kɔhw, boyo_, 
   {{0x92640133,0x00000000,0x00000000,0x00000000}},	//   عدام, --, --, --, 
   {{0x6f008f12,0x2aa000e8,0x645c8f13,0x00000000}},	//   _sulc, _yóbb_, bepi, --, 
   {{0x6f008f14,0x645c8f15,0x2f548f16,0xf1b800f3}},	//   _pulc, cepi, втис, _fešn_, 
   {{0x6f008f17,0xdd240024,0x9f480241,0x00000000}},	//   _qulc, _rūšy, _àbì_, --, 
   {{0x6564009a,0x51848f18,0x00000000,0x00000000}},	//   _yskh, _пуза, --, --, 
   {{0x6da404a9,0xada48f19,0x6ee401ed,0x7d043a35}},	//   типа, тапл, tóbb, _éisl, 
   {{0xeb988f1a,0x6f007126,0x66d80054,0x6ac84668}},	//   дио_, _tulc, rïki, रव्र, 
   {{0x26d08f1b,0x7bdc6f88,0x00000000,0x00000000}},	//   yoyo_, ýrup, --, --, 
   {{0xeff40201,0x645c8f1c,0xbe640592,0x63280023}},	//   ገኘው_, zepi, _مهمي, _ስነጥበ, 
   {{0x645c01f7,0x00000000,0x00000000,0x00000000}},	//   yepi, --, --, --, 
   {{0x26d02f99,0xf1b81710,0x6d580857,0x05780092}},	//   woyo_, _lešo_, _ipwa, አግባብ_, 
   {{0x26d08f1d,0x645c8f1e,0x6d580857,0x7c3c8f1f}},	//   toyo_, vepi, _hpwa, órre, 
   {{0x645c18a6,0x38ac05be,0x4ad801d9,0x6d5802d0}},	//   wepi, džru_, _ثاتھ_, _kpwa, 
   {{0x26d04a08,0x645c8f20,0xa4440640,0x6d58035a}},	// [afc0] royo_, tepi, кнад, _jpwa, 
   {{0x29108f21,0x6d588f22,0x320c058a,0x94c8004b}},	//   _itya_, _mpwa, _afey_, والې_, 
   {{0x645c8f23,0x26d0108f,0x6d58035a,0xe618361e}},	//   repi, poyo_, _lpwa, _одн_, 
   {{0x65648f24,0xf1a81afc,0xeba40fac,0x80a401f9}},	//   _tskh, کامه_, åøyd_, कसभे, 
   {{0x656430d7,0x2498003e,0x6d58035a,0x40340835}},	//   _uskh, pkpm_, _npwa, гелс, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x44440354,0xb17c01a2,0x6d588f25,0x40880032}},	//   mg_, _vzťa, _apwa, _үҙем_, 
   {{0x44448f26,0x1ea8774e,0x29100a49,0x6d588f27}},	//   lg_, باتي_, _otya_, _bpwa, 
   {{0x44448f28,0x6d58009f,0x29108f29,0xdd84008e}},	//   og_, _cpwa, _ntya_, тыйп, 
   {{0x6d5803ac,0x7b1801c0,0x1fb4008e,0xf1b0009f}},	//   _dpwa, ноор_, _исер, _اءِ_, 
   {{0x29108f2a,0x6d580857,0x6598002b,0xaea000db}},	//   _atya_, _epwa, _hāhā, _گەيي, 
   {{0x6d58035a,0x1ec801b9,0x444403cd,0xc0c00023}},	//   _fpwa, _ўлди_, hg_, ድዎም_, 
   {{0x7e608f2b,0x6d58127b,0x9848011c,0xceb000df}},	//   memp, _gpwa, мява_, _דיף_, 
   {{0x7e608f2c,0x44440936,0x659800dc,0x00000000}},	//   lemp, jg_, _māhā, --, 
   {{0x87048f2d,0x7c288f2e,0x29108f2f,0x6ee401ed}},	//   ияте, madr, _etya_, lóba, 
   {{0x7c28704d,0xd90c17a5,0x00000000,0x00000000}},	//   ladr, _ویج_, --, --, 
   {{0xf1b800f3,0xe81c00af,0x6d580857,0x659800b8}},	// [afd0] _rešo_, _बड़का_, _xpwa, _nāhā, 
   {{0x44448f30,0x7e608f31,0x841409a5,0xdce002f0}},	//   gg_, hemp, имух, _osoč, 
   {{0x7e608f32,0x3cfc011c,0xf7948f33,0xf1b80419}},	//   kemp, _mivv_, _санэ, _pešo_, 
   {{0x44448f34,0x1de08f35,0x7e608f36,0x7c288f37}},	//   ag_, _परंत, jemp, hadr, 
   {{0xdd848f38,0x7c288f39,0xc1040979,0x44448f3a}},	//   _او_, kadr, لوني, bg_, 
   {{0x705404a9,0x7c2801f1,0x44440334,0x7e600472}},	//   انغا, jadr, cg_, eemp, 
   {{0x7c288f3b,0x52248f3c,0x752c495a,0x7e600112}},	//   dadr, _афза, lsaz, femp, 
   {{0x9f508f3d,0x6d580857,0x7c288f3e,0x8fc40133}},	//   ádán_, _ppwa, eadr, _یزان, 
   {{0x752c8f3f,0xf0440811,0x6d5802d0,0x7c288f40}},	//   nsaz, _معای, _qpwa, fadr, 
   {{0x7c288f41,0xac848f42,0x752c006f,0x6d5803ac}},	//   gadr, угол, isaz, _vpwa, 
   {{0xeb988f43,0x752c0007,0x7e60014b,0x8f4400c7}},	//   хин_, hsaz, bemp, _шхад, 
   {{0x44448f44,0xfe708bee,0x7e608075,0x6d5802d0}},	//   zg_, _ودن_, cemp, _tpwa, 
   {{0x7c288f45,0x44448f46,0x6d585337,0xed588f47}},	//   badr, yg_, _upwa, _чол_, 
   {{0xbd881d1f,0x7c288f48,0x6e288f49,0xab2800d8}},	//   _جنهن_, cadr, laeb, _зока_, 
   {{0x951c031c,0x44440477,0xa6c80395,0x00000000}},	//   ེེའི_, vg_, елва_, --, 
   {{0x44440457,0x2aa001e1,0x6e28003a,0x00000000}},	//   wg_, _fóba_, naeb, --, 
   {{0x44441675,0xe50432e8,0x29105e6f,0x24e8013e}},	// [afe0] tg_, ابري, _utya_, емаи_, 
   {{0x44440190,0x7e608f4a,0x6e28003a,0x00000000}},	//   ug_, zemp, haeb, --, 
   {{0x7e608f4b,0xe2988f4c,0x6e2821c6,0xbebc0171}},	//   yemp, наж_, kaeb, _kvīt, 
   {{0x44440876,0x7e605b00,0x68fc0455,0xddc000f3}},	//   sg_, xemp, _hipd, _laoš, 
   {{0x44440334,0x7c288f4d,0x7e608f4e,0xc43443fb}},	//   pg_, yadr, vemp, _نکات, 
   {{0xddc00e3c,0xe2848f4f,0x7e608f50,0x9f68010b}},	//   _naoš, _өлги, wemp, ериз_, 
   {{0x7c288f51,0xdef800c7,0x672c01bf,0xc2948f52}},	//   vadr, ныи_, nsbj, _پیشب, 
   {{0x68fc8f53,0x6ee401d3,0x02c40166,0x93408f54}},	//   _lipd, tóba, _тибү, _ынсе, 
   {{0x91e08f55,0x7c288f56,0x00000000,0x00000000}},	//   _готе, tadr, --, --, 
   {{0x7e600ac7,0x3b548f57,0xbebc00b8,0x224401ed}},	//   semp, акор, _avīt, lgok_, 
   {{0x6e2827be,0x7e600925,0xd00c0014,0x3f980d12}},	//   baeb, pemp, _رلن_, _æru_, 
   {{0x7c280591,0x22448f58,0x7e600309,0x672c01bf}},	//   sadr, ngok_, qemp, dsbj, 
   {{0x8d708f59,0x7c288f5a,0xbebc0055,0xaca400e5}},	//   _هاوا, padr, _dvīt, _چھپے_, 
   {{0x644800db,0x672c08a5,0x00000000,0x00000000}},	//   òfil, fsbj, --, --, 
   {{0x68fc8f5b,0x81b8015b,0xcb6400f3,0x17041bf4}},	//   _dipd, _ঘুম_, _баје_, افری_, 
   {{0xddc00960,0x752c8f5c,0x4b7808a8,0x00000000}},	//   _zaoš, tsaz, _טאוו, --, 
   {{0x7aec4700,0xf5580214,0x1b380092,0x00000000}},	// [aff0] _ihat, ضلاب_, _በተቃራ, --, 
   {{0x68fc089c,0x752c8f5d,0xa9240171,0x73c40022}},	//   _gipd, rsaz, _dižā, аӡба, 
   {{0x7aec8f5e,0x752c8f5f,0x200c0004,0xb4b41889}},	//   _khat, ssaz, dcfi_, _जगी_, 
   {{0x25dc0037,0x62840241,0x00000000,0x00000000}},	//   _खरची_, _òkol, --, --, 
   {{0x7aec0192,0x66d80054,0x8b0401ef,0x6ee40419}},	//   _mhat, rïkt, _keří, fóbn, 
   {{0x60d8030d,0x2edc0b7c,0x224401c4,0x94846518}},	//   _cktm, मत्त, agok_, _сымд, 
   {{0x7aec1311,0xb4e00764,0x04c83090,0x4394030d}},	//   _ohat, दती_, _صوفي_, _ларс, 
   {{0x7aec8f60,0xed588f61,0xd41400c7,0xbe18010b}},	//   _nhat, вои_, _шьҭы, лцьц_, 
   {{0x6e284d11,0x26dc016b,0xb7d40248,0x02640133}},	//   raeb, _ɔto_, _oṣoo, _دێنێ, 
   {{0x6e28000a,0xcca42002,0xc1b81d4a,0xcdc08f62}},	//   saeb, اندۇ_, _слух_, _қалқ, 
   {{0x7aec0192,0x6a8447bf,0xf98805d0,0x7c3c0332}},	//   _bhat, ална, _קר_, órra, 
   {{0x7aec1948,0x9fa40184,0x6ab40117,0x78a48f63}},	//   _chat, _тыуҙ, рсох, _alhv, 
   {{0x7aec8f64,0xad240131,0x68fc0455,0x00000000}},	//   _dhat, _ئىتى, _pipd, --, 
   {{0xfbd03bd6,0x68fc014f,0x7aec06be,0xdd100345}},	//   _کته_, _qipd, _ehat, _بووخ, 
   {{0x7aec8f65,0xdc38008f,0x1cb8011a,0xbebc0171}},	//   _fhat, _סעקר, _במסע, _tvīt, 
   {{0x7aec8f66,0x65c40107,0x672c01bf,0xdb2000e5}},	//   _ghat, абба, rsbj, _بوٹی, 
  
   {{0x68fc8f67,0xe9d81f5a,0x00000000,0x00000000}},	// [b000] _tipd, _јкп_, --, --, 
   {{0x6ef400c0,0x7aec01ef,0xa3b81f0d,0x00000000}},	//   _išbu, _zhat, پائر_, --, 
   {{0x7aec8f68,0xa2040006,0x66e460a9,0xa6c8009d}},	//   _yhat, апед, _вона, _ална_, 
   {{0x5b54008f,0x00000000,0x00000000,0x00000000}},	//   ישען_, --, --, --, 
   {{0x22448f69,0x27f40118,0xe2a80050,0xc178010b}},	//   rgok_, ženě_, _یارن_, ыҗа_, 
   {{0x64a48f6a,0x2610134e,0xd0d40212,0x7d040332}},	//   _тага, धुरी_, адії_, _éisi, 
   {{0x7f9401c0,0x2d9805ac,0x8fa00063,0x6ee400d7}},	//   сайх, øsen_, жаје, róbn, 
   {{0xbebc00b8,0x81b800cc,0xa1141c43,0x73f8010f}},	//   _avīr, _ঘুণ_, _نورت, _תּשו, 
   {{0x4fe45a9a,0x7aec8f6b,0x5cc401f0,0xbebc0171}},	//   лмән_, _rhat, исоз, _svīs, 
   {{0x2fd08f6c,0x00000000,0x00000000,0x00000000}},	//   éngé_, --, --, --, 
   {{0x7aec8f6d,0xb47804ac,0x9e647724,0xdce02737}},	//   _phat, אָרי, _введ, _eroğ, 
   {{0xd90c8f6e,0x7aec8f6f,0x8b040118,0x00000000}},	//   ویب_, _qhat, _seří, --, 
   {{0x7aec0dc9,0x657402fb,0x3f9c00d0,0x29a400c7}},	//   _vhat, jvyh, lyvu_, бырҳ, 
   {{0x7aec8f70,0xb4b402c3,0x0c3400ae,0xdc280066}},	//   _what, _जगे_, _نكهة_, _شسته_, 
   {{0x7aec8f71,0xd6d88f72,0xf1b80010,0x3d0c0210}},	//   _that, вта_, _pešk_, _डंडे_, 
   {{0x26100316,0x673800d2,0x2010013f,0x7aec8f73}},	//   धुली_, átja, ɛyie_, _uhat, 
   {{0x38c803ff,0x00000000,0x00000000,0x00000000}},	// [b010] _مادی_, --, --, --, 
   {{0x673809a8,0x04c8004b,0x3a280e21,0xb4e02314}},	//   štja, ټومي_, _heap_, दते_, 
   {{0x3a280b21,0x65740022,0x799c0142,0xb9f00023}},	//   _keap_, avyh, lysw, _ነሩ_, 
   {{0x42d81fe2,0xf0e81e87,0xef1801b9,0x00000000}},	//   афія_, گىتى_, қми_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x41748f74,0x3a2824b6,0xf0e800d1,0xb64001ec}},	//   غانس, _leap_, دىتى_, _ﺍﻙ_, 
   {{0x3d0c0c2e,0x2eb40e46,0xdce00139,0x799c015d}},	//   _डूबे_, йсис, _sroğ, hysw, 
   {{0xdce00baa,0x3a280076,0x92b400db,0x6ee44579}},	//   _proğ, _neap_, _ئحسا, róbo, 
   {{0xc05800ec,0x00000000,0x00000000,0x00000000}},	//   _چشما_, --, --, --, 
   {{0x7dc404a9,0x40840019,0xdce0107d,0x81f41c3b}},	//   تتىك, _мухб, _brođ, _ظہور_, 
   {{0x60d8008f,0x00000000,0x00000000,0x00000000}},	//   _עקענ, --, --, --, 
   {{0x3a283e7c,0xe8b000dc,0x81c800fe,0x00000000}},	//   _ceap_, ुच्च, _উৰি_, --, 
   {{0x3a2800a3,0x799c0142,0xb80000fe,0xbab000db}},	//   _deap_, gysw, ্ৰমত_, بۅيب, 
   {{0x2aa001e1,0x98a800ef,0x00000000,0x00000000}},	//   _tóbo_, ducē_, --, --, 
   {{0x6498005e,0xbb8401f7,0x81c800cc,0x00000000}},	//   қтар_, _ولهي, _উৰা_, --, 
   {{0x799c002d,0x316c8f75,0x00000000,0x00000000}},	//   bysw, _osez_, --, --, 
   {{0xe5788f76,0xe4588f77,0x28b800a8,0x1dc800cd}},	// [b020] ыза_, лжа_, _бунэ_, ापयत, 
   {{0x2a700014,0x240800ee,0x00000000,0x00000000}},	//   _hayb_, унжи_, --, --, 
   {{0x3a2805b1,0xa6c807d6,0x316c8f78,0xb40000d1}},	//   _yeap_, _مودل_, _asez_, дүрд, 
   {{0x63ac2220,0x2a700100,0xa2280395,0x00000000}},	//   _đinđ, _jayb_, ужда_, --, 
   {{0x61388f79,0x75340166,0x00000000,0x00000000}},	//   учер_, _мэрх, --, --, 
   {{0x94048f7a,0xa878008f,0x64a40798,0x00000000}},	//   _герб_, ראַר, _ѓава, --, 
   {{0x44388f7b,0x20548f7c,0xbf640014,0x799c012d}},	//   _idr_, _ҳтер, تۯاو, zysw, 
   {{0x44388f7d,0xed4c0050,0x64a41086,0x539802e4}},	//   _hdr_, چھو_, _таҳа, _גילו, 
   {{0x7c3c2b76,0xbebc00cd,0x44380205,0x3a28045a}},	//   órro, _dvīp, _kdr_, _reap_, 
   {{0xdce0098d,0x3a288f7e,0x44388f7f,0xd12c00c6}},	//   _prođ, _seap_, _jdr_, _أمل_, 
   {{0x44388f80,0xf1b88f81,0xf0b001d9,0x644c0009}},	//   _mdr_, _reši_, _زیٹھ, _mcbi, 
   {{0xf1b800e2,0x799c02d0,0x00000000,0x00000000}},	//   _seši_, tysw, --, --, 
   {{0x58842ecc,0xd83801c0,0x7c34030d,0xf1b80419}},	//   быва, лэв_, _делх, _peši_, 
   {{0x2d9802f6,0x44388f82,0x9cf40640,0xcb0400ec}},	//   äsee_, _ndr_, _учеш, _ڏيون_, 
   {{0xdce005a1,0x7c380175,0x0c7000c6,0xabb40124}},	//   _urođ, _idvr, _ردود, _машә, 
   {{0x44388f83,0xb4e000dc,0x2a700205,0x69d8002f}},	//   _adr_, दत्_, _gayb_, ßtec, 
   {{0x44380649,0xca380302,0xf1b8009b,0x00000000}},	// [b030] _bdr_, _הנחה_, _teši_, --, 
   {{0x44388f84,0xc6a80092,0x891800f1,0x316c00ef}},	//   _cdr_, _መገለጫ_, _اغيز_, _rsez_, 
   {{0x44388f85,0xd3788f86,0x932401ed,0x7c3800d7}},	//   _ddr_, ыча_, صران, _mdvr, 
   {{0x4438037e,0x644c0165,0x92c400cc,0x656c0108}},	//   _edr_, _ecbi, উত্_, änhä, 
   {{0x765c0334,0xd138034b,0x00000000,0x00000000}},	//   _ibsy, ухе_, --, --, 
   {{0x44388f87,0x00c8187f,0x00000000,0x00000000}},	//   _gdr_, блік_, --, --, 
   {{0xa2b000dc,0x81cc00fe,0x00000000,0x00000000}},	//   _आगच्, ৱেল_, --, --, 
   {{0x88b0013f,0x7c380165,0x44380427,0x8d2400d1}},	//   _ntɛn, _advr, _zdr_, бниң_, 
   {{0xa2d44a01,0xb8000154,0x5184009d,0x00000000}},	//   यकर्, ্রিত_, _уува, --, 
   {{0x403455c3,0x88b0016b,0x2ba41d8a,0x00000000}},	//   _неус, _atɛn, खनला, --, 
   {{0x2d9800c5,0x765c15c0,0xa8000205,0x00000000}},	//   äseb_, _obsy, şızd, --, 
   {{0x2a700050,0x00000000,0x00000000,0x00000000}},	//   _qayb_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x765c003a,0x00000000,0x00000000,0x00000000}},	//   _absy, --, --, --, 
   {{0x44385d31,0x2b44009a,0xf1b800de,0xfcf8010f}},	//   _rdr_, qulc_, _iešu_, _פּױל, 
   {{0x44384818,0x7d048f88,0xa9080014,0x00000000}},	//   _sdr_, _èisc, _پٲدٕ_, --, 
   {{0xa9685882,0x44388f89,0x7d048f8a,0x643400c6}},	// [b040] _типа_, _pdr_, _éist, قراء, 
   {{0x25dc0574,0xe7641639,0x637800d8,0x18a0010a}},	//   _कुणी_, _двоп, исер_, _жаьм, 
   {{0x4438002f,0xf1a401ec,0x6658010a,0x00000000}},	//   _vdr_, үрін, _канă, --, 
   {{0x44380e78,0xa184010b,0x81b80154,0xf2c40150}},	//   _wdr_, жыкл, _ঘুষ_, псін, 
   {{0xa0688f8b,0x44381f97,0x00000000,0x00000000}},	//   иада_, _tdr_, --, --, 
   {{0xdfd02781,0x10a04f5c,0xf1b80064,0x6ee401e7}},	//   ويش_, мичн, _nešu_, lóbh, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdef80eff,0x6144016c,0x6ee400d2,0x00000000}},	//   шыл_, _меба, nóbh, --, 
   {{0x25b074a9,0x6e38015d,0x00000000,0x00000000}},	//   nzyl_, _ddwb, --, --, 
   {{0xa8000205,0x00000000,0x00000000,0x00000000}},	//   şıyd, --, --, --, 
   {{0xdee48f8c,0x6ee4036b,0x98ac0064,0x6c3001e2}},	//   _дожи, _کسلل, _ūgį_, رځوا, 
   {{0x2d8c011f,0x00000000,0x00000000,0x00000000}},	//   bxee_, --, --, --, 
   {{0xa6c8022e,0x00000000,0x00000000,0x00000000}},	//   _vvаl, --, --, --, 
   {{0x1c0c2ba2,0x80a8009e,0x00000000,0x00000000}},	//   _सलिल_, কচক্, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69d80276,0x00000000,0x00000000,0x00000000}},	//   ştea, --, --, --, 
   {{0x7d048f8d,0x1dc800dc,0xe164001f,0x2618012d}},	// [b050] _éiss, ापित, ደነበሩ_, बड़ी_, 
   {{0xd3788f8e,0x44f402bf,0x81c000eb,0x00000000}},	//   иче_, дпус, ঁথা_, --, 
   {{0x92685950,0x00000000,0x00000000,0x00000000}},	//   ирда_, --, --, --, 
   {{0x1dc869a0,0x2d8c208d,0x6ee4033f,0x765c0857}},	//   ापात, yxee_, róbk, _ubsy, 
   {{0xf1b8107d,0x2d8c198f,0x25b00210,0x764c427b}},	//   _nešt_, xxee_, czyl_, mgay, 
   {{0x6ee41709,0x764c8f8f,0x82a40022,0x00000000}},	//   móbi, lgay, зшәе, --, 
   {{0xf1b80010,0xbf6800c6,0x764c0014,0x3ea40332}},	//   _rešu_, قصيم_, ogay, fkmt_, 
   {{0x9f5c0429,0x81cc03d4,0xf1b800e2,0x00000000}},	//   _aftó_, ৱেই_, _sešu_, --, 
   {{0x764c0009,0x317800e5,0x00000000,0x00000000}},	//   igay, _ész_, --, --, 
   {{0x2ca81fbd,0x82e80135,0x5ab4025c,0x764c8f90}},	//   скоп_, _འཚོའ, _བཏུམ, hgay, 
   {{0xf1b83341,0x00000000,0x00000000,0x00000000}},	//   _vešu_, --, --, --, 
   {{0x88b00085,0xa9688f91,0x3f643cc5,0x2ef404b4}},	//   _etɛl, бима_, _ютуб, _эзер, 
   {{0x2d8c208d,0x6dc000db,0x6d18030d,0xec780395}},	//   qxee_, _سۅدۅ, _уклă, _гпл_, 
   {{0x764c8f92,0x96d40588,0x2874035b,0x5d780115}},	//   egay, ҧстә, чымр, _לאנק, 
   {{0x6d488f93,0x7c9401e2,0x00000000,0x00000000}},	//   luea, _تشنا, --, --, 
   {{0x82e80135,0x764c8f94,0xa3cc00bc,0x2f1002f0}},	//   _འཚེའ, ggay, tíží_, _mág_, 
   {{0x6d488f95,0x2ca40076,0x2f100aab,0x00000000}},	// [b060] nuea, okld_, _lág_, --, 
   {{0x764c0067,0xe7382b2e,0x6d4801ab,0x25a4031c}},	//   agay, _лео_, iuea, ġol_, 
   {{0x764c8f96,0x228400f7,0x6d488f97,0x00000000}},	//   bgay, зулг, huea, --, 
   {{0x764c0589,0x6d482ec1,0x5b38008f,0x00000000}},	//   cgay, kuea, מגעק, --, 
   {{0x9e040075,0xf1a80451,0x2bdc0073,0x6614007c}},	//   үчил, ياهه_, _नुसा, mcyk, 
   {{0x2f1002d2,0x6d4801ab,0x710800d4,0x00000000}},	//   _bág_, duea, іхів_, --, 
   {{0x88b0013f,0xb17c0030,0xaa8401ef,0x00000000}},	//   _ntɛm, _vyťa, _zbýš, --, 
   {{0xbd18020f,0x00000000,0x00000000,0x00000000}},	//   ожих_, --, --, --, 
   {{0x6d480a90,0x7cf4004e,0xa114009f,0x61448f98}},	//   guea, nàrg, _روضت, _хеза, 
   {{0x2f1000c6,0xd00c00c6,0xf1b800f3,0x764c5431}},	//   _fág_, _ملك_, _vešt_, zgay, 
   {{0x6d480076,0x764c89fa,0x69d8002f,0x01a8009f}},	//   auea, ygay, ßten, _اُڃي_, 
   {{0xdc000306,0x4dcc01ec,0x00000000,0x00000000}},	//   _učím, _ﯗﻟﯩﻨ, --, --, 
   {{0xc9848f99,0x69d8084c,0x7cf40268,0x764c0790}},	//   нури, şten, jàrg, vgay, 
   {{0xb924063f,0x2bdc0316,0x764c058a,0xad2414af}},	//   _zipụ_, _नुवा, wgay, _آرنو, 
   {{0x6d94031c,0x26f801ad,0x764c8f9a,0x45580023}},	//   _eżaġ, ्दूर_, tgay, _ዝርከበ, 
   {{0x70a805d7,0x6614007c,0x00000000,0x00000000}},	//   _कत्ल, gcyk, --, --, 
   {{0x764c8209,0x09e400fe,0x45d40395,0x00000000}},	// [b070] rgay, নেবা, еотс, --, 
   {{0x6ee41dec,0x764c011f,0x14080022,0x00000000}},	//   róbi, sgay, схап_, --, 
   {{0x32545e3e,0x98a8084c,0x764c01a9,0x12e400d4}},	//   двер, ască_, pgay, підг, 
   {{0xdb04020c,0x00000000,0x00000000,0x00000000}},	//   èmèh, --, --, --, 
   {{0x39580109,0x00000000,0x00000000,0x00000000}},	//   ntss_, --, --, --, 
   {{0x2f108f9b,0xafe41638,0x942003cc,0x6448004e}},	//   _pág_, молл, _سورۇ, òfit, 
   {{0xb4d805ba,0x6aa48f9c,0xf314009d,0x083c00df}},	//   ावी_, ykkf, _цдбэ, מעגל, 
   {{0x6d48863c,0x7c2401a6,0x8d240131,0xa2805ce9}},	//   tuea, _đira, пниң_, _لیمو, 
   {{0x33200076,0xa28048ca,0x00000000,0x00000000}},	//   lphx_, _جینو, --, --, 
   {{0x61e48f9d,0x6d4801ab,0x00000000,0x00000000}},	//   _økla, ruea, --, --, 
   {{0xaa448f9e,0xeb988f9f,0x6d4801ab,0xae18011c}},	//   менл, цин_, suea, _джеф_, 
   {{0x6d480421,0xe5f00139,0x00000000,0x00000000}},	//   puea, _çeçä, --, --, 
   {{0x6d488fa0,0xad64009f,0x00000000,0x00000000}},	//   quea, _آٿتو, --, --, 
   {{0xab28022e,0x00000000,0x00000000,0x00000000}},	//   _дока_, --, --, --, 
   {{0x66e48fa1,0x00000000,0x00000000,0x00000000}},	//   дова, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x66148fa2,0x77900133,0xe570007b,0x00000000}},	// [b080] rcyk, نییا, خطأ_, --, 
   {{0x6dc4025c,0x7cf4004e,0x66141654,0x00000000}},	//   _iċaħ, càrd, scyk, --, 
   {{0xca2c0131,0x6614005c,0x00000000,0x00000000}},	//   _ﺧﻪﺕ_, pcyk, --, --, 
   {{0xe5a48fa3,0xa1c42f89,0x00000000,0x00000000}},	//   _жими, мбед, --, --, 
   {{0x6dc40327,0x00000000,0x00000000,0x00000000}},	//   _jċaħ, --, --, --, 
   {{0xb9f80020,0x6dc4031c,0x7528036e,0x2250012d}},	//   _ሙያ_, _mċaħ, _çeza, żyk_, 
   {{0x2d988fa4,0x7cf4004e,0xd0040114,0x00000000}},	//   äsen_, nàre, меље_, --, 
   {{0x645c8fa5,0x69d40798,0x626402dd,0x00000000}},	//   lfpi, _oxye, _تاسق, --, 
   {{0xc0c4010b,0x00000000,0x00000000,0x00000000}},	//   _пәки, --, --, --, 
   {{0x645c003a,0xe08416a2,0x00000000,0x00000000}},	//   nfpi, _تجري, --, --, 
   {{0x69d88fa6,0x8c9c012d,0xad5400e5,0x1e940117}},	//   ştel, _ओवरो, وریڈ, _ордр, 
   {{0x1d0835f4,0x452400fe,0x00000000,0x00000000}},	//   _деди_, _পিনক_, --, --, 
   {{0x25dc007d,0x0c7003e6,0x4ef8011a,0x00000000}},	//   _कुली_, ردید, _והאו, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69d4039a,0x7cf4004e,0xc7c400d4,0xdb0401e7}},	//   _exye, gàre, всти, úmói, 
   {{0xbebc005f,0x8f980375,0x00000000,0x00000000}},	//   _avīz, חילי, --, --, 
   {{0x497402de,0x672001fa,0xbebc002b,0x00000000}},	// [b090] _алыс, _čoje, _itīd, --, 
   {{0xb4d88fa7,0x7afc8fa8,0x24880327,0x7cf4004e}},	//   ावे_, lmst, _cnbm_, bàre, 
   {{0xca485175,0x656405b1,0x2ca80198,0x7afc257c}},	//   _علیه_, _epkh, _ɓad_, omst, 
   {{0xd6240491,0xd9f00574,0x03fc0055,0xc2b801e2}},	//   _تعدي, _घरात_, _jāṃb, وانئ_, 
   {{0x7afc0158,0xf07401d3,0x918433d2,0x00000000}},	//   imst, ٹیاں_, بجام, --, 
   {{0x3b080869,0x7afc002f,0x98a800ef,0x00000000}},	//   _liaq_, hmst, ducī_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xee381b10,0x2d9418ac,0xeb980131,0x67cc00e5}},	//   чни_, ерос, җим_, lőjé, 
   {{0x98ec1533,0x00000000,0x00000000,0x00000000}},	//   छताछ_, --, --, --, 
   {{0x81d48fa9,0x7afc8c63,0x00000000,0x00000000}},	//   _роух, emst, --, --, 
   {{0x3b0805b1,0x09c817c6,0x00000000,0x00000000}},	//   _biaq_, रप्य, --, --, 
   {{0x8d740075,0xeab08faa,0xfb24034c,0x8fd004a9}},	//   _ياشا, اعد_, کریپ, _пәқә, 
   {{0x98b80139,0xbebc00e2,0x9b9000db,0x00000000}},	//   _asqı_, _stīg, _ەلىت, --, 
   {{0x26f81428,0x7afc8fab,0x6d58667f,0x37c00c58}},	//   ्द्र_, amst, _iqwa, _শুধৰ, 
   {{0x6d5803ac,0xb4d8007a,0x05d80a8a,0x00000000}},	//   _hqwa, ावै_, _भुजब, --, 
   {{0xd7048fac,0x7cf4004e,0x54c002a9,0xca64035b}},	//   енсе_, ràre, ҳбуб, _реиқ, 
   {{0x15406584,0x2d58007f,0xe9a41b94,0x26f8012d}},	// [b0a0] летм, nèe_, _чапп, ्दौर_, 
   {{0x96240171,0xeaf800ec,0x00000000,0x00000000}},	//   _atņē, _برڪت_, --, --, 
   {{0x7b080fb9,0x2910006f,0x645c003a,0x00000000}},	//   _üstü, _huya_, rfpi, --, 
   {{0x29105749,0xa5088fad,0x6d580b6f,0x17180bd9}},	//   _kuya_, _нема_, _oqwa, _מוטע, 
   {{0x291023db,0x6d580921,0x00000000,0x00000000}},	//   _juya_, _nqwa, --, --, 
   {{0x29101aa1,0xd00c8fae,0x80bc02ab,0x00000000}},	//   _muya_, مله_, ्चें, --, 
   {{0x6d588faf,0x232806cb,0x29108fb0,0x03a801d9}},	//   _aqwa, _хоби_, _luya_, _تۯاو_, 
   {{0x23280364,0x29102281,0x320c0076,0xb16400fb}},	//   _моҳи_, _ouya_, _ggey_, хнәһ, 
   {{0x26c00270,0x3df401d5,0x4e9000cf,0x00000000}},	//   _mmko_, ъзис, اشىر, --, 
   {{0x7b1801c6,0x03fc00b8,0x4cb40108,0xec78010a}},	//   моор_, _sāṃb, елью_, çпи_, 
   {{0xd00c8fb1,0x2910006f,0x6d588fb2,0x9a700451}},	//   _الم_, _auya_, _eqwa, هندڙ, 
   {{0x29108fb3,0x7afc8fb4,0x67cc01d3,0xd334011a}},	//   _buya_, umst, zőjé, ערכה_, 
   {{0x29108fb5,0xdca48fb6,0xdd2000e8,0x2d9808fb}},	//   _cuya_, _пади, _méŋg, øset_, 
   {{0x26c08fb7,0x291003b9,0x00000000,0x00000000}},	//   _amko_, _duya_, --, --, 
   {{0x7c2805b1,0x67cc01d3,0xbebc002b,0x03fc0055}},	//   mbdr, vőjé, _svīy, _tāṃb, 
   {{0x29100af2,0xb4d800cd,0x147401c8,0x00000000}},	//   _fuya_, ाव्_, کارج, --, 
   {{0xd34459c7,0x29108fb8,0x67cc01d3,0x6d5802d0}},	// [b0b0] کیزه_, _guya_, tőjé, _xqwa, 
   {{0x26c00b4b,0x6458007c,0xdce0013a,0x00000000}},	//   _emko_, _ötil, _opoč, --, 
   {{0x26c0005a,0xe51800d7,0x00000000,0x00000000}},	//   _fmko_, _vášň, --, --, 
   {{0x291000b5,0x00000000,0x00000000,0x00000000}},	//   _yuya_, --, --, --, 
   {{0x66c08fb9,0x64485178,0x00000000,0x00000000}},	//   _тәрж, ófic, --, --, 
   {{0xa0648fba,0x21a08fbb,0x00000000,0x00000000}},	//   ваша_, ришм, --, --, 
   {{0x6d58035a,0x7e6002d0,0x3f480432,0x00000000}},	//   _sqwa, ffmp, _ỳurt_, --, 
   {{0xa3e40490,0xa2c000d1,0x6d5802d0,0x00000000}},	//   _पडत_, _кәчк, _pqwa, --, 
   {{0x0d0407a5,0x00000000,0x00000000,0x00000000}},	//   ндиқ_, --, --, --, 
   {{0xcfa801d3,0x2fc404b4,0x69d80790,0x29102ca8}},	//   _ٹائم_, _ирең, ştek, _ruya_, 
   {{0x29108fbc,0x26c40de2,0x4ea400d8,0xab28117e}},	//   _suya_, _ňoom_, _прда, ьона_, 
   {{0x9f9408a8,0x2d980450,0xe9a4119e,0xa9a40139}},	//   _בדעה_, øses_, вамп, вимд, 
   {{0x6e288a67,0x6d5800f1,0xdce00118,0x29108fbd}},	//   mbeb, _uqwa, _zpoč, _quya_, 
   {{0xdca08fbe,0x2eec8fbf,0x6d488fc0,0x291018f7}},	//   _ваши, llef_, mrea, _vuya_, 
   {{0x291023db,0xe7388fc1,0xeb980276,0x6e2801f7}},	//   _wuya_, ьев_, _ций_, obeb, 
   {{0x29108fc2,0x6e288fc3,0xf1d05096,0xe69401d5}},	//   _tuya_, nbeb, तपान, خلرد, 
   {{0x6d488fc4,0x6e28009f,0x6b800175,0x7cf40e89}},	// [b0c0] nrea, ibeb, lvlg, làra, 
   {{0x6d483c60,0x14208fc5,0x2eec0327,0x00000000}},	//   irea, идум, hlef_, --, 
   {{0xaac40c2e,0x7cf400a3,0xe29801f0,0x00000000}},	//   _लगाक, nàra, маж_, --, 
   {{0xc4c40f22,0x65c40064,0x673800e5,0x00000000}},	//   ্তেজ, _абма, átju, --, 
   {{0xdce06875,0x6d480960,0x6e280e78,0x7cf401ab}},	//   _spoč, jrea, dbeb, hàra, 
   {{0x6e280381,0x2eec01c7,0x6ef40064,0x3af800e4}},	//   ebeb, elef_, _išby, mépe_, 
   {{0x6d488fc6,0x54780375,0x33d402dd,0x91f0013d}},	//   erea, _קטלו, _бітт, лчәч, 
   {{0x6d488fc7,0x6e288fc8,0x26d08fc9,0xbebc0171}},	//   frea, gbeb, nnyo_, _stīb, 
   {{0x6d488fca,0x2054035b,0x6ee401a2,0x9f5c0548}},	//   grea, _атер, tóbr, _aftô_, 
   {{0x21240020,0x9ff88fcb,0xa3e423ef,0x00000000}},	//   mpoh_, _قراء_, _पडा_, --, 
   {{0x6d488fcc,0x201c208d,0x3e78001f,0x26d0020b}},	//   area, _ifti_, _ጠቀሜታ_, knyo_, 
   {{0x2eec033b,0x4ea007b5,0xddc400c7,0x67140037}},	//   clef_, _врша, _ибеи, _दूधक_, 
   {{0x6d488fcd,0x21240477,0x3af800c7,0x7c240166}},	//   crea, npoh_, jépe_, _ğirf, 
   {{0x26d002e3,0xa3b01bf9,0x7cf4004e,0x3c580276}},	//   enyo_, टना_, bàra, _чикэ_, 
   {{0x21248fce,0x00000000,0x00000000,0x00000000}},	//   hpoh_, --, --, --, 
   {{0xa3e41533,0xba540640,0x5a4402d5,0x3ae800f2}},	//   _पड़_, _свиј, _рэка, _ثبتی_, 
   {{0xf8b805f5,0x21240455,0x89c801e1,0x3a380254}},	// [b0d0] _зөв_, jpoh_, _tópẹ, masp_, 
   {{0xe2940220,0xd3a4415e,0x26d08fcf,0x3a380175}},	//   ғаш_, креп, anyo_, lasp_, 
   {{0x6d488fd0,0x970000d1,0x00000000,0x00000000}},	//   zrea, _نېسى, --, --, 
   {{0x6d488fd1,0x201c8fd2,0x88d8009e,0x715800f3}},	//   yrea, _afti_, _দীপক, еркс_, 
   {{0xc2c405e6,0x3a380109,0x26cc016b,0x7cf40109}},	//   جيني, iasp_, ɑfo_, zàra, 
   {{0x6d4803bd,0x2d943ba6,0x69d803fa,0x2f5400d4}},	//   vrea, ғрис, ßtei, гтис, 
   {{0x2eec8fd3,0x60940efb,0x439414ec,0xd2588fd4}},	//   tlef_, انىس_, _карс, _оца_, 
   {{0x6d488fd5,0x201c1427,0x92680166,0x00000000}},	//   trea, _efti_, _юрга_, --, 
   {{0x6e288fd6,0x6d488fd7,0x2eec03f9,0x1e808fd8}},	//   rbeb, urea, rlef_, слым, 
   {{0x50a00131,0x6d483077,0x2eec0158,0x7cf401ab}},	//   _خەتل, rrea, slef_, tàra, 
   {{0x6d4823bd,0xc0c80063,0xfe700133,0x6e280205}},	//   srea, _руте_, _ژده_, pbeb, 
   {{0x5f40004b,0x00000000,0x00000000,0x00000000}},	//   _اچول, --, --, --, 
   {{0xeab80323,0x201c0334,0x6d5c01c3,0x9f480cad}},	//   _үйл_, _yfti_, àsad, _àbò_, 
   {{0x7cf400a3,0x3af8035b,0x00000000,0x00000000}},	//   pàra, vépe_, --, --, 
   {{0x9cd80375,0x7c240432,0x00000000,0x00000000}},	//   _אקספ, _şirg, --, --, 
   {{0xfbd00b28,0xc060001f,0x39e401f2,0x18b00116}},	//   _بته_, _መጽሐፍ, ụzị_, _һәср, 
   {{0x598002d5,0x822c0023,0xa2e401a9,0x00000000}},	// [b0e0] _глыб, ስትሪታ, қодд, --, 
   {{0x26d001ee,0x3af8035b,0x00000000,0x00000000}},	//   snyo_, répe_, --, --, 
   {{0xbb0c0205,0xfe14000d,0x00000000,0x00000000}},	//   _üçüz, _डललस_, --, --, 
   {{0x5b54010f,0x3af8035b,0x00000000,0x00000000}},	//   טשען_, pépe_, --, --, 
   {{0x25580276,0xa0a45124,0x18480023,0x00000000}},	//   _ярнэ_, ладд, _ንምእማ, --, 
   {{0x40c801f7,0x3a380419,0x00000000,0x00000000}},	//   ضوعَ_, zasp_, --, --, 
   {{0x2124047e,0xb35400e5,0x53a00354,0xb4c401ee}},	//   spoh_, _نیلا_, _ларб, _тирҙ, 
   {{0xb3a80086,0x00000000,0x00000000,0x00000000}},	//   _òñañ, --, --, --, 
   {{0xe0542ad9,0x3cb40137,0xfd1406ed,0x0fc00116}},	//   _مخاب, ийир, јмоќ, ийән, 
   {{0x5b248fd9,0x201c05b1,0x2fd0020c,0x00000000}},	//   льма, _ufti_, èngé_, --, 
   {{0xdd90712f,0x9f58023a,0x9e648fda,0x00000000}},	//   _گوش_, äpä_, _ماشن, --, 
   {{0xc0dc0240,0x00000000,0x00000000,0x00000000}},	//   ሕዎም_, --, --, --, 
   {{0x3a388fdb,0xdd908fdc,0x9ff400fe,0xf8b8009d}},	//   rasp_, _دوش_, _চলিব_, вөн_, 
   {{0x3a388fdd,0xfb8801a9,0x00000000,0x00000000}},	//   sasp_, _ариқ_, --, --, 
   {{0x8c180302,0xb8dc0574,0xc06002d3,0xf4848fde}},	//   _אווי, _आत_, _መጽሓፍ, یائی, 
   {{0x9ff400cc,0x391401f0,0x00000000,0x00000000}},	//   _চলাব_, _кмир, --, --, 
   {{0x6d441d77,0xd8380153,0x7434014b,0x00000000}},	// [b0f0] _āhak, _пэн_, инаф, --, 
   {{0x2eb00118,0x00000000,0x00000000,0x00000000}},	//   _जत्त, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x116430c0,0x66800014,0x95c88fdf,0x00000000}},	//   التی_, _بیقل, _чуна_, --, 
   {{0xc1040691,0x60c8003a,0xddc00356,0x628403b2}},	//   موني, gifm, _scoş, _ókon, 
   {{0x2eb40c69,0x93f001ec,0x712405a9,0x00000000}},	//   исис, _اۋاش, _چىرم, --, 
   {{0xa3b00034,0xed440884,0xde4400f2,0x00000000}},	//   टनर_, анип, لیمو_, --, 
   {{0xc6940677,0x66d80064,0x00000000,0x00000000}},	//   מאק_, nįka, --, --, 
   {{0xab648fe0,0x1ee8036b,0x212800f2,0x00000000}},	//   авол, _یولی_, _شيمی_, --, 
   {{0xc1043c4b,0xbebc00b8,0x442406be,0x3eb000e5}},	//   _اولي, _itīn, _əm_, áltó_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xed588fe1,0xec788fe2,0x7c24010e,0x00000000}},	//   _рол_, _апл_, _şire, --, 
   {{0xa3e42983,0x6d4400b0,0x6fa80073,0xdd8c009f}},	//   _पडल_, _āhah, _कथां, _آوو_, 
   {{0x7c64007b,0x888465fd,0x00000000,0x00000000}},	//   _طاول, لیکن, --, --, 
   {{0x7cf408c2,0x00000000,0x00000000,0x00000000}},	//   hàrl, --, --, --, 
   {{0x958077a8,0xe9d800f3,0x15e00037,0xe578008e}},	// [b100] олте, _шки_, _कुआर_, ъза_, 
   {{0xe3b08fe3,0xa88400db,0x394c0077,0xe7a8022e}},	//   يرا_, _ئلدى, áese_, _авол_, 
   {{0x316c01c4,0x6ab40267,0x3af80098,0x00000000}},	//   _apez_, _klyf, lépa_, --, 
   {{0xbebc00cd,0x2efc0142,0x00000000,0x00000000}},	//   _atīn, _nhwf_, --, --, 
   {{0xa0341823,0x60c80784,0xc8440023,0x27001d94}},	//   لىشت, tifm, _ንምንዋ, लगीर_, 
   {{0x6ab40cfd,0x00000000,0x00000000,0x00000000}},	//   _llyf, --, --, --, 
   {{0x44388fe4,0x6ab405e4,0x316c01c4,0x60c8022e}},	//   _ier_, _olyf, _epez_, rifm, 
   {{0x63600521,0x60c80e14,0x00000000,0x00000000}},	//   _ọnwe, sifm, --, --, 
   {{0x44388fe5,0x62800009,0x00000000,0x00000000}},	//   _ker_, mdoo, --, --, 
   {{0x443804b9,0x62808fe6,0x5c048fe7,0x3b54016c}},	//   _jer_, ldoo, ияна, бкор, 
   {{0x44388fe8,0x3cfc03d1,0xef0c004b,0x628059bf}},	//   _mer_, _vhvv_, _ګڼو_, odoo, 
   {{0x44388fe9,0x62808fea,0x6ab4015d,0xa3dc00c5}},	//   _ler_, ndoo, _clyf, _तखन_, 
   {{0x44380385,0x62808feb,0x3be80137,0x00000000}},	//   _oer_, idoo, _өлдү_, --, 
   {{0x44388fec,0x64488fed,0x6ab40042,0x8cf002d5}},	//   _ner_, ófil, _elyf, _дзіц, 
   {{0x6ab48fee,0x62808fef,0xe8000490,0xfd540055}},	//   _flyf, kdoo, ळेला_, _rugṇ, 
   {{0x44388ff0,0x7c380489,0x0bb40375,0x6ab42c1a}},	//   _aer_, _hevr, _כלום_, _glyf, 
   {{0x44388ff1,0x7aec8ff2,0x6280474c,0x7c3803bd}},	// [b110] _ber_, _ikat, ddoo, _kevr, 
   {{0x44388ff3,0x7c382aef,0x62808ff4,0x98543baf}},	//   _cer_, _jevr, edoo, _өтүш, 
   {{0x44388ff5,0xdd8455c1,0x7c380af4,0x62808ff6}},	//   _der_, _کو_, _mevr, fdoo, 
   {{0x7c3803bd,0x44388ff7,0x78a4014f,0x7aec025c}},	//   _levr, _eer_, _hohv, _jkat, 
   {{0x44388ff8,0x7aec8ff9,0x78a4007d,0x85440276}},	//   _fer_, _mkat, _kohv, _мэре, 
   {{0x44388ffa,0xed58187d,0x9de00134,0x78a4047e}},	//   _ger_, ҳои_, _ɔbɔɔ_, _johv, 
   {{0x7aec8ffb,0x62801db9,0xefcc001f,0xc05802bf}},	//   _okat, bdoo, _እዚያ_, річ_, 
   {{0x44388ffc,0x62800050,0x7aec8ffd,0xed584411}},	//   _zer_, cdoo, _nkat, гои_, 
   {{0x44388ffe,0x7c380e29,0x00000000,0x00000000}},	//   _yer_, _bevr, --, --, 
   {{0x7aec8fff,0x44380429,0x78a49000,0x7c389001}},	//   _akat, _xer_, _nohv, _cevr, 
   {{0x7c389002,0x765c0363,0xebe401b9,0x2efc015d}},	//   _devr, _ocsy, сонп, _thwf_, 
   {{0xf8a804ae,0x3af800c7,0x9f480241,0x00000000}},	//   _אש_, tépa_, _ábá_, --, 
   {{0x7aec0036,0x5ac43da1,0x78a40419,0x68fc9003}},	//   _dkat, слям_, _bohv, _phpd, 
   {{0x7c389004,0x78a40175,0x27f8012d,0xcc840244}},	//   _gevr, _cohv, _pzpn_, _ئۆده_, 
   {{0x78a405ce,0x44389005,0x7aec9006,0x628074ae}},	//   _dohv, _rer_, _fkat, ydoo, 
   {{0x628001d9,0x765c010a,0x672c010f,0x7c389007}},	//   xdoo, _ccsy, _ĉijĝ, _zevr, 
   {{0x7c389008,0x00000000,0x00000000,0x00000000}},	// [b120] _yevr, --, --, --, 
   {{0x9f5c00a2,0x44380240,0x628008aa,0x69d89009}},	//   _agtý_, _qer_, wdoo, ştes, 
   {{0x62806e16,0x66e4900a,0x7aec00b5,0xca6401a9}},	//   tdoo, _гона, _ykat, _munо, 
   {{0x4438900b,0xc69000aa,0x6280022f,0x46bc17ee}},	//   _wer_, _تېر_, udoo, _ईतिह, 
   {{0x6280900c,0x628408ce,0x00000000,0x00000000}},	//   rdoo, _ókom, --, --, 
   {{0xdb18066d,0x6280900d,0xdf745821,0x7ebc01d3}},	//   szté, sdoo, مدعب, _képg, 
   {{0x7c3805c7,0x00000000,0x00000000,0x00000000}},	//   _revr, --, --, --, 
   {{0x7c38900e,0x62800014,0x00000000,0x00000000}},	//   _sevr, qdoo, --, --, 
   {{0x6e380649,0x1d8801c8,0x6e3c0413,0x00000000}},	//   _dewb, ائبي_, ðsba, --, 
   {{0x504017a0,0xbebc002b,0x00000000,0x00000000}},	//   _неуб, _itīm, --, --, 
   {{0x7c382d8b,0x11840014,0x5e8407a5,0x00000000}},	//   _vevr, _پھۆٹ_, _гулз, --, 
   {{0xda64900f,0x78a40978,0x6d4400cd,0x00000000}},	//   حادي, _sohv, _āhav, --, 
   {{0x7c3808f7,0x7aec0a73,0x98480801,0x2d982c4f}},	//   _tevr, _vkat, лява_, äset_, 
   {{0xd90c9010,0x78a4014f,0x00000000,0x00000000}},	//   ژیک_, _qohv, --, --, 
   {{0xd6d84720,0x7aec9011,0x81c003d4,0x5018011a}},	//   гта_, _tkat, ুথি_, רולו, 
   {{0x7aec1269,0x00000000,0x00000000,0x00000000}},	//   _ukat, --, --, --, 
   {{0x69d89012,0x06a40131,0x38c8030f,0x78a426bb}},	// [b130] şter, ﺎﺳﻠﯩ, _نادی_, _tohv, 
   {{0x3f8c152d,0x798c9013,0x719800f2,0xbebc00ef}},	//   _ordu_, _iraw, یناز_, _stīl, 
   {{0x50a004a9,0x721800f5,0x00000000,0x00000000}},	//   ۋەرل, ажер_, --, --, 
   {{0x798c9014,0xd498004e,0x705400ec,0x00000000}},	//   _kraw, _өрг_, ڪچرا, --, 
   {{0x798c031c,0x6e38016d,0x3f8c0129,0x15a802e8}},	//   _jraw, _rewb, _ardu_, _съни_, 
   {{0x3f8c05a1,0x752c9015,0x6e38014b,0x493c0bd9}},	//   _brdu_, mpaz, _sewb, נגוו, 
   {{0x798c0de2,0x752c9016,0x67200427,0xd244586a}},	//   _lraw, lpaz, _čojk, _гэзи, 
   {{0x7c240598,0x6d2468eb,0xd6cc00a2,0x00000000}},	//   _ğira, одиз, niт_, --, 
   {{0x798c0070,0x3f8c01c4,0x7c246cba,0x6c7401af}},	//   _nraw, _erdu_, _şira, оунх, 
   {{0x6e38009a,0x752c9017,0x6cc40006,0xacc80022}},	//   _wewb, ipaz, ійна, ргоз_, 
   {{0x798c9018,0x0d940046,0xf98804ae,0xc3b003b2}},	//   _araw, ртқы_, _שר_, _óítø, 
   {{0x798c9019,0x2d9800c5,0x752c0477,0x9b8400d1}},	//   _braw, äses_, kpaz, زچىل_, 
   {{0x798c901a,0xada4901b,0xe8f801fe,0x00000000}},	//   _craw, _фалл, илм_, --, 
   {{0x798c901c,0xd9400120,0x752c0419,0x00000000}},	//   _draw, ќери, dpaz, --, 
   {{0x628c016b,0xe7380107,0x798c901d,0x752c0171}},	//   _ɔbob, реб_, _eraw, epaz, 
   {{0x7e6403f0,0x798c901e,0x386c107d,0x00000000}},	//   _ñipt, _fraw, đera_, --, 
   {{0x798c901f,0x09e4015b,0x284800d4,0x00000000}},	// [b140] _graw, নেজা, _кзпп_, --, 
   {{0xa44401ec,0x3e4c0153,0x00000000,0x00000000}},	//   інед, mėtų_, --, --, 
   {{0x3e4c02d5,0x1414007b,0x00000000,0x00000000}},	//   lėtų_, زينة_, --, --, 
   {{0x7ebc066d,0xded8001f,0xd12c004b,0x00000000}},	//   _képe, ኖችን_, ږمه_, --, 
   {{0xd00c03e6,0x3e4c0153,0xd24c0d2f,0x0094004e}},	//   ۆله_, nėtų_, ئنه_, зилэ, 
   {{0x7ebc003e,0xd00c0633,0x00000000,0x00000000}},	//   _mépe, چله_, --, --, 
   {{0xd00c9020,0x7ebc01d3,0x6d5c01ab,0x00000000}},	//   نله_, _lépe, àsan, --, 
   {{0x7cf435fb,0x3e4c0006,0x00000000,0x00000000}},	//   màri, kėtų_, --, --, 
   {{0x7cf467c1,0x7ebc01ed,0x00000000,0x00000000}},	//   làri, _népe, --, --, 
   {{0x3b549021,0x3e4c0024,0x6d44002b,0x00000000}},	//   пкор, dėtų_, _āhat, --, 
   {{0x7cf49022,0x2d989023,0x798c00f2,0x3f8c9024}},	//   nàri, äser_, _sraw, _urdu_, 
   {{0x798c9025,0x7f580455,0x3ea00254,0x1ac800c7}},	//   _praw, muvq, _õit_, руоп_, 
   {{0xdb4c04d3,0xc9849026,0x2bb40051,0x3e4c0064}},	//   رێک_, мури, ác_, gėtų_, 
   {{0x7ebc9027,0x5f0400c7,0x00000000,0x00000000}},	//   _dépe, _узҵа, --, --, 
   {{0x9a8455d9,0x8bc00801,0x69d875c0,0x56a40798}},	//   _дупл, _осъд, ştep, ојаз, 
   {{0x798c9028,0x7cf48d22,0x2b500118,0x3e4c00c0}},	//   _traw, dàri, ázce_, bėtų_, 
   {{0x7ebc01ed,0x798c9029,0x00000000,0x00000000}},	// [b150] _gépe, _uraw, --, --, 
   {{0x449845b3,0x752c0789,0x7cf400db,0x41480092}},	//   овую_, rpaz, fàri, _ናይጄሪ, 
   {{0x3958902a,0x7cf467c1,0x93240345,0xa878011a}},	//   luss_, gàri, زران, _האתר, 
   {{0x752c07de,0x00000000,0x00000000,0x00000000}},	//   ppaz, --, --, --, 
   {{0x3958902b,0xbebc0055,0x8afc010f,0x00000000}},	//   nuss_, _itīh, בלאז, --, 
   {{0x00c80024,0x7c241cce,0x6150215c,0x00000000}},	//   олік_, _şirn, رنىئ, --, 
   {{0x395803fa,0x7cf44b84,0x6e3c0162,0x52740f2b}},	//   huss_, càri, ðsbo, _وارز, 
   {{0x7d080b4f,0x8d2400d1,0x9e600395,0x00000000}},	//   emds, ониң_, евъд, --, 
   {{0x386000a9,0xfec803e6,0xc0dc0023,0xd1b80133}},	//   _ochr_, تبوو_, ዕሎም_, _ئازا_, 
   {{0xdce0003d,0x7ebc20ef,0x38600100,0xd6c000cc}},	//   _proġ, _répe, _nchr_, ্কিয, 
   {{0xe820012d,0x00000000,0x00000000,0x00000000}},	//   _मलबा_, --, --, --, 
   {{0x7d08000f,0xfe700133,0xad4000cf,0x00000000}},	//   amds, _لده_, _كۉبۉ, --, 
   {{0x1ee807d6,0xfd48063f,0x3958902c,0x2f0000d7}},	//   _اونی_, _momọ, guss_, góge_, 
   {{0x3e4c02d5,0x6f08902d,0xbdf8902e,0xed5800bc}},	//   rėtų_, lmec, _برما_, muž_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3860902f,0x6f089030,0x39589031,0xe618036b}},	//   _echr_, nmec, buss_, сда_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [b160] --, --, --, --, 
   {{0x7cf49022,0x6f080730,0x2eec08c8,0x672c03b2}},	//   tàri, hmec, hoef_, ppbj, 
   {{0x6f089032,0x00000000,0x00000000,0x00000000}},	//   kmec, --, --, --, 
   {{0x7cf49022,0xa1849033,0x6f089034,0x66e4059f}},	//   ràri, зыкл, jmec, _хома, 
   {{0x29089035,0x26d09036,0xb6c401e0,0x7cf400cf}},	//   omba_, miyo_, _цияһ, sàri, 
   {{0xed5804a7,0x290802e2,0x68ec0455,0x7f580477}},	//   duž_, nmba_, nobd, tuvq, 
   {{0x29089037,0x98780a7c,0x7c2427ac,0x00000000}},	//   imba_, מאסט, _şiro, --, 
   {{0x6d54006d,0x26d09038,0x6f089039,0x395813bb}},	//   ązan, niyo_, gmec, yuss_, 
   {{0xed581710,0x7f58014f,0xe194009d,0x00000000}},	//   guž_, suvq, _эрвэ, --, 
   {{0x26d0903a,0x645c903b,0xdb1800dd,0x271c02e3}},	//   hiyo_, ngpi, sztí, ọnye_, 
   {{0x26d0903c,0x7f58014f,0x25640142,0xfd500124}},	//   kiyo_, quvq, hôl_, nyhẽ, 
   {{0x26d0903d,0x3958005f,0x38600036,0x290800e8}},	//   jiyo_, tuss_, _schr_, emba_, 
   {{0x26d0903e,0x00000000,0x00000000,0x00000000}},	//   diyo_, --, --, --, 
   {{0x3958903f,0xed340323,0x628c016b,0x29080109}},	//   russ_, _цэцэ, _ɔboa, gmba_, 
   {{0x26d0544d,0x00000000,0x00000000,0x00000000}},	//   fiyo_, --, --, --, 
   {{0x26d01d3c,0x39580fac,0x996401a9,0x00000000}},	//   giyo_, puss_, _етол, --, 
   {{0x3a28010a,0x7bdc0321,0x68ec022e,0x00000000}},	// [b170] _ifap_, úruf, bobd, --, 
   {{0x1cd80135,0x394804cc,0xca64022e,0x44f49040}},	//   _ཡམས_, _ivas_, _hunа, епус, 
   {{0x26d001d9,0x6d9c01e4,0x00000000,0x00000000}},	//   biyo_, nɨar, --, --, 
   {{0x26d036ba,0x39489041,0x7c244560,0x00000000}},	//   ciyo_, _kvas_, _şirl, --, 
   {{0xc0f402d3,0x6f080205,0x00000000,0x00000000}},	//   _ጌሮም_, vmec, --, --, 
   {{0x41749042,0xa6c801a9,0x09b000cc,0x00000000}},	//   عانس, _etаd, _চেডা, --, 
   {{0xd3442e3e,0x6f089043,0x00000000,0x00000000}},	//   _ریشه_, tmec, --, --, 
   {{0x394804d4,0x6f0801bf,0x00000000,0x00000000}},	//   _ovas_, umec, --, --, 
   {{0x6f089044,0x2eec9045,0x29080083,0x68ec022e}},	//   rmec, roef_, ymba_, yobd, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x26d09046,0x39489047,0x3a28017a,0xca64022e}},	//   yiyo_, _avas_, _bfap_, _bunа, 
   {{0x26d001d9,0xff18037e,0xadb41d39,0x00000000}},	//   xiyo_, _usbの, _обеш, --, 
   {{0x68ec01b9,0x26d09048,0x00000000,0x00000000}},	//   tobd, viyo_, --, --, 
   {{0x29089049,0x26d0904a,0x3a280194,0x00000000}},	//   umba_, wiyo_, _efap_, --, 
   {{0x7ebc904b,0x26d0904c,0x68ec022e,0x290800e4}},	//   _hépa, tiyo_, robd, rmba_, 
   {{0x68ec01b9,0x7ebc1079,0xbc4006be,0x00000000}},	//   sobd, _képa, _üçrə, --, 
   {{0x26d00067,0x8a140075,0xddc0012d,0x59800132}},	// [b180] riyo_, _سېست, _zdoł, _алыб, 
   {{0x26d0904d,0xa50816a4,0x68ec022e,0x25640042}},	//   siyo_, цеза_, qobd, rôl_, 
   {{0x26d004ce,0xbebc00b8,0x69c4002f,0x228400f3}},	//   piyo_, _itīv, lzke, дулг, 
   {{0xe1f80283,0xdb1801ed,0x3dc4003e,0x26d08891}},	//   оге_, nztá, yzmw_, qiyo_, 
   {{0x7ebc904e,0x69c4904f,0xd0400213,0x7c2445d8}},	//   _népa, nzke, linə, _şirm, 
   {{0x15400063,0x6d440055,0x20180162,0x6d540210}},	//   _јерм, _āhap, øpi_, ązal, 
   {{0x644c02d0,0x7de80200,0xe8000073,0xd8d40a7c}},	//   _idbi, kësë, ळेचा_, ווסט_, 
   {{0xd020446e,0x00000000,0x00000000,0x00000000}},	//   нмәй, --, --, --, 
   {{0x44449050,0x39a4002e,0x7ebc06af,0x2d8c017a}},	//   oa_, _mësë_, _cépa, gvee_, 
   {{0x7ebc2047,0x9b680032,0x1fb40212,0x91e000c7}},	//   _dépa, ошма_, _осер, _роуе, 
   {{0x44449051,0x628c016b,0x69c4005a,0x80d40154}},	//   ia_, _ɔbon, ezke, দকদ্, 
   {{0xbebc00cd,0x39a4036e,0xd04003e3,0xc0dc0023}},	//   _atīv, _nësë_, dinə, ዕዎም_, 
   {{0x9848084c,0x6d9c0115,0x00000000,0x00000000}},	//   жяба_, sɨar, --, --, 
   {{0x2f0001e7,0xd04006be,0x00000000,0x00000000}},	//   móga_, finə, --, --, 
   {{0x2f009052,0x00000000,0x00000000,0x00000000}},	//   lóga_, --, --, --, 
   {{0x44449053,0x7d180140,0x7a380354,0x00000000}},	//   ea_, _hivs, _эпир_, --, 
   {{0x39489054,0x34943a49,0x2f000332,0x8624013d}},	// [b190] _uvas_, наар, nóga_, тьсе, 
   {{0x14740a2c,0xd04003b9,0x00000000,0x00000000}},	//   بارج, binə, --, --, 
   {{0x325428a8,0xb7d80bbf,0x7cf401c3,0x2f0048cb}},	//   евер, _روحا_, làrs, hóga_, 
   {{0x95c839be,0x644c9055,0xf54001d9,0x0b440092}},	//   _дуга_, _edbi, _مہرێ, _መደበኛ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7ebc9056,0xc104835e,0x8650013f,0x64480005}},	//   _répa, نوني, nkɔn, ófit, 
   {{0x7ebc20ef,0x8414014b,0xc348014b,0x00000000}},	//   _sépa, _амрх, _ояте_, --, 
   {{0xa2809057,0x2d8c9058,0x2f000332,0x59dc00cd}},	//   _میمو, tvee_, fóga_, नपार, 
   {{0x7d181225,0xcdc00220,0x2f001315,0x705864cb}},	//   _bivs, тапқ, góga_, _наар_, 
   {{0x2d8c9059,0xd0400213,0x50b81bf4,0x34dc0037}},	//   rvee_, yinə, _بدرد_, _मदोद, 
   {{0xeb98905a,0x7d18905b,0x4ea4905c,0x2d8c000d}},	//   чин_, _divs, _орда, svee_, 
   {{0x7ebc0077,0x7d18003a,0x753c033f,0x2f000332}},	//   _tépa, _eivs, _owsz, bóga_, 
   {{0x6e28676c,0x7cf400cf,0x69c4905d,0x2f000332}},	//   mceb, tàrt, uzke, cóga_, 
   {{0x4444905e,0xdb18066d,0x6d48905f,0x23c40248}},	//   xa_, sztá, msea, _jíjé_, 
   {{0x6d483e7c,0x69c401ed,0x67200cf4,0xa2c00864}},	//   lsea, szke, _čojs, लसम्, 
   {{0x6e289060,0xf6544a2d,0xe5a4405c,0x7ebc01d3}},	//   nceb, ктую, ниби, _lépn, 
   {{0x6d489061,0x6f18014f,0xbebc00cd,0xe7f00037}},	// [b1a0] nsea, _miwc, _itīt, _आँवा_, 
   {{0x6d480ea3,0x6e280369,0x00000000,0x00000000}},	//   isea, hceb, --, --, 
   {{0x7c243bc2,0x6d480afe,0x00000000,0x00000000}},	//   _şirk, hsea, --, --, 
   {{0x29189062,0xe5a49063,0x6d4825a3,0x6f1803cb}},	//   _hipa_, _зими, ksea, _niwc, 
   {{0x29189064,0x64480005,0x644c0175,0x6d48005c}},	//   _kipa_, ófis, _tdbi, jsea, 
   {{0x44449065,0x10a00b46,0x6d489066,0x291802c4}},	//   qa_, личн, dsea, _jipa_, 
   {{0x2918020b,0x2d981f53,0xe9ac00b5,0xfdb807f7}},	//   _mipa_, åsen_, _lｺ_, इन्फ, 
   {{0x8e449067,0x29189068,0x6e280912,0x7d189069}},	//   ىلىك_, _lipa_, gceb, _sivs, 
   {{0x6d48906a,0x291802ce,0x91e0906b,0x00000000}},	//   gsea, _oipa_, _боте, --, 
   {{0x2918906c,0x22441c06,0xbebc00dc,0x2f0000ae}},	//   _nipa_, laok_, _atīt, róga_, 
   {{0x9f9406b3,0x7d1800df,0x5454008f,0x6d4802d0}},	//   _яшаш, _vivs, עסטן_, asea, 
   {{0x6d48906d,0x2918906e,0x34dc906f,0x6e28009a}},	//   bsea, _aipa_, _मद्द, cceb, 
   {{0x29189070,0x6d489071,0xcb6425da,0xdde804fb}},	//   _bipa_, csea, ومیه_, _عرصه_, 
   {{0x7ebc0098,0x09b0015b,0x22440c6a,0xbebc0055}},	//   _képo, _চেহা, haok_, _etīt, 
   {{0x29189072,0x6f18009a,0x497402dd,0x36d40798}},	//   _dipa_, _yiwc, _ұлыс, вовр, 
   {{0x7cf400db,0x7bc80369,0x2124011f,0x3ae87611}},	//   càrr, mzdu, kqoh_, _تبتی_, 
   {{0x24880998,0x29189073,0x383400d8,0x6e3c0162}},	// [b1b0] _babm_, _fipa_, _инпр, ðsbi, 
   {{0x7afc9074,0x29180048,0x6d5c0e89,0x00000000}},	//   llst, _gipa_, àsai, --, 
   {{0x7cf41c69,0x7afc0b4f,0xf31401c6,0x6d480175}},	//   nàrq, olst, вджэ, zsea, 
   {{0x6d489075,0x29180063,0x201c00a2,0x6e2800e4}},	//   ysea, _zipa_, _agti_, xceb, 
   {{0x6f180113,0xc2c400c6,0x42240212,0x66b00150}},	//   _riwc, ديني, удів, _тұту, 
   {{0x7afc3fb9,0x6d48030d,0x00000000,0x00000000}},	//   hlst, vsea, --, --, 
   {{0x6d489076,0x6f18014f,0x60d4033b,0xb4dc0073}},	//   wsea, _piwc, èyma, तची_, 
   {{0x7ebc0231,0x7afc9077,0xfbb8045e,0x6d489078}},	//   _dépo, jlst, ুপাত, tsea, 
   {{0x6e289079,0xb1140124,0x201c0175,0xd13801c6}},	//   rceb, _амаш, _fgti_, _ххб_, 
   {{0x6d48907a,0x6e28214d,0xbebc002b,0x628400e5}},	//   rsea, sceb, _stīt, _ókor, 
   {{0xa3b82871,0x2918907b,0x7cf400db,0x26dc0066}},	//   आईए_, _ripa_, tàrr, étok_, 
   {{0x2918907c,0x3b080842,0x6d48907d,0x7afc0ac8}},	//   _sipa_, _chaq_, psea, glst, 
   {{0x3b0801d9,0x2f000af2,0x072c0131,0x39580175}},	//   _dhaq_, lógo_, _ﻧﯩﯔ_, grss_, 
   {{0x7afc907e,0x29180784,0x7ebc002e,0xec7800d4}},	//   alst, _qipa_, _lépl, _цпк_, 
   {{0x98a0907f,0x18a09080,0x291881ec,0x24880010}},	//   шире, шарм, _vipa_, _rabm_, 
   {{0x3b08014f,0x61f4012d,0x00000000,0x00000000}},	//   _ghaq_, żyli, --, --, 
   {{0x7c248af8,0x00000000,0x00000000,0x00000000}},	// [b1c0] _şiri, --, --, --, 
   {{0xfaf8005f,0x19b4011a,0x00000000,0x00000000}},	//   stīt_, _ספיר_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7ebc2047,0x33f40137,0x2558084c,0x28cc0118}},	//   _répo, учус, _оргэ_, होरि, 
   {{0x7ebc0231,0x26c00548,0xa0a40510,0x07a40022}},	//   _dépl, _ilko_, кадд, _раҟн, 
   {{0xed580122,0x2124020b,0x7ebc0036,0x50f00006}},	//   drž_, rqoh_, _pépo, азіт, 
   {{0x54649081,0xd4649082,0x22440098,0x00000000}},	//   _шарм_, _шире_, paok_, --, 
   {{0x7bc80122,0x91bc2765,0xbebc00b8,0xdb0c01b8}},	//   vzdu, वनशै, _atīr, ädük, 
   {{0xe0440276,0x7afc01bf,0x00000000,0x00000000}},	//   _анзи, vlst, --, --, 
   {{0x7bc8005a,0xa3b4000d,0x00000000,0x00000000}},	//   tzdu, _जथा_, --, --, 
   {{0x09b000cc,0x26c001f4,0x7c4800b8,0x7b14009d}},	//   _চেলা, _olko_, _āprī, лдох, 
   {{0x7bc8005a,0xed5800bc,0x7cf400db,0x7ebc00e5}},	//   rzdu, brž_, ràrq, _képm, 
   {{0x394c9083,0xdd9066a5,0x7afc9084,0x00000000}},	//   ées_, _خوش_, rlst, --, 
   {{0x26c09085,0x00000000,0x00000000,0x00000000}},	//   _alko_, --, --, --, 
   {{0x3b080784,0xb8e40137,0x7c24010e,0x8b9000f3}},	//   _thaq_, _ۅزدۉ, _şirw, _врњч, 
   {{0x21e001ec,0x00000000,0x00000000,0x00000000}},	//   _ﻋﺒﺎﺭ, --, --, --, 
   {{0x7ebc9086,0xcb140375,0xfaf800de,0x5be00846}},	// [b1d0] _répl, _דלק_, stīs_, _पशुव, 
   {{0x3af80de2,0xb4dc0073,0x97800066,0x00000000}},	//   répu_, तचे_, _پیره, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x823400f2,0xa0640022,0x00000000,0x00000000}},	//   لرها, ҳаша_, --, --, 
   {{0xc6a400a8,0x16044982,0x8588014b,0x00000000}},	//   _трэи, _शरिर_, _иёра_, --, 
   {{0xa0649087,0xafe401d5,0x00000000,0x00000000}},	//   гаша_, лолл, --, --, 
   {{0x838400a8,0x5684001f,0x81d400eb,0x00000000}},	//   _кыте, ሮጀክቱ_, _সুদ_, --, 
   {{0xbebc0055,0x2d8800db,0x00000000,0x00000000}},	//   _stīr, ейип_, --, --, 
   {{0x506400c7,0x9d5000f1,0x90640798,0xa2802a9f}},	//   _атеа, منيت, _ањел, _دینو, 
   {{0xaba89088,0x900831b1,0xa9a401d5,0x00000000}},	//   евоз_, _قزاق_, ҳимд, --, 
   {{0xaa4400ee,0xc5e400cc,0x00000000,0x00000000}},	//   ленл, _মৰাপ, --, --, 
   {{0x7ebc01d3,0xa9a46bce,0xa020032e,0x00000000}},	//   _lépj, гимд, _þöru, --, 
   {{0xbebc02b1,0xfeb80137,0xbab000db,0x00000000}},	//   _kuīn, _جالت_, تۅيب, --, 
   {{0x7b1000e4,0x7c2400ac,0x9d500b24,0x7cc40228}},	//   _añuĝ, _şirv, _انوت, _ۅزۉم, 
   {{0xeb989089,0x00000000,0x00000000,0x00000000}},	//   _чий_, --, --, --, 
   {{0xa6a800ae,0x00000000,0x00000000,0x00000000}},	//   رازق_, --, --, --, 
   {{0xe8f80798,0x9c8000c0,0x660400d8,0x00000000}},	// [b1e0] _пли_, _ščia, упаа, --, 
   {{0x59800139,0xe12407a5,0x00000000,0x00000000}},	//   _ульб, ҳмди, --, --, 
   {{0xfaf800da,0x8650908a,0x9cd40375,0xe1f01e4a}},	//   brīd_, nkɔk, נועה_, ڭسا_, 
   {{0x26c0005b,0xa1c400cf,0x326400d4,0x00000000}},	//   _ulko_, лбед, итів, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xffb405f5,0x442c01b8,0x7ebc01d3,0x2b58012d}},	//   ийлэ, _üd_, _gépj, ńscy_, 
   {{0x26c400e8,0xa2e4030d,0xa3b80210,0x00000000}},	//   _ňooy_, _бовд, आईओ_, --, 
   {{0x7d540b75,0x72787136,0x539802e4,0xef9001b9}},	//   авих, _исус_, _אילו, غیند, 
   {{0x60e80124,0x9c840214,0x9a840853,0x00000000}},	//   _змам_, هشده, қунл, --, 
   {{0xbb7410fc,0x7ebc01d3,0x62800254,0xd00c57fb}},	//   агој, _képk, leoo, _کلم_, 
   {{0x35840023,0xe044014b,0x00000000,0x00000000}},	//   ርተታት_, _анҷи, --, --, 
   {{0xa6c801a9,0x596402e8,0x1ccc0327,0x5f040818}},	//   _stаn, лъга, ུྃཿ_, _ёзда, 
   {{0x7c24054e,0x4974011c,0x00000000,0x00000000}},	//   _şiru, бляс, --, --, 
   {{0x466800d1,0xc8644c91,0x7c340354,0x00000000}},	//   һрум_, йтси, _текх, --, 
   {{0x9cb00014,0xc6a4497a,0x6e340cad,0xeb8801af}},	//   _نۅکت, әрси, _àgbá, _арыҫ_, 
   {{0x6d5c08a7,0xd6d801c0,0x1b3c0092,0x41c406ff}},	//   ásag, хтг_, ካባቢያ, वनास, 
   {{0x6280908b,0x984802e8,0x95c802e8,0xe788013a}},	// [b1f0] deoo, _пяна_, хува_, _míří, 
   {{0x44b48af9,0x00000000,0x00000000,0x00000000}},	//   ббус, --, --, --, 
   {{0x62800270,0xdb100055,0x00000000,0x00000000}},	//   feoo, _ṣṭak, --, --, 
   {{0x62800549,0x00000000,0x00000000,0x00000000}},	//   geoo, --, --, --, 
   {{0xdd84908c,0xc2440006,0x45d401d5,0x318401ec}},	//   _بو_, снік, _гояс, ртең, 
   {{0x2f5406a7,0x92c40183,0xdb44475d,0xbebc0171}},	//   атис, ৈকে_, _وَ_, _stīp, 
   {{0x62800196,0x30c801ed,0x7ebc00e5,0x7fd80395}},	//   beoo, _یورپ_, _gépk, лфът_, 
   {{0xc8500023,0x3134030d,0x00000000,0x00000000}},	//   _ክዝንጋ, _веар, --, --, 
   {{0xa2c005dc,0x7bdc0ad9,0xa2800014,0xc178009f}},	//   लसर्, úrun, _گیۆو, _مصلا_, 
   {{0xeb98026a,0x7ebc01d3,0xc17400f1,0x2bc006b1}},	//   вио_, _léph, _ددفت, शनला, 
   {{0xdb200008,0xc0c800a8,0x7f5802a9,0xedc400f1}},	//   ærðf, _суте_, _бахс_, دېږي_, 
   {{0x7ebc908d,0x00000000,0x00000000,0x00000000}},	//   _néph, --, --, --, 
   {{0xddc0038e,0x60cc0166,0x9f4801e1,0x6d5c908e}},	//   _zbož, _änmü, _ábò_, ásad, 
   {{0x291c908f,0x21b8008f,0x271c2e04,0x00000000}},	//   öta_, דזשא, भद्र_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7ebc006a,0xa6840798,0x00000000,0x00000000}},	//   _céph, јлад, --, --, 
   {{0xa4449090,0xe618510d,0x4ad800dd,0x7ebc9091}},	// [b200] инад, тда_, _لاکھ_, _déph, 
   {{0x7ae40115,0x3af8002e,0xd8b40327,0x394c0327}},	//   _ĉiti, lépp_, པྲདྲ, ġest_, 
   {{0xe73807d5,0x62809092,0xa354009a,0x00000000}},	//   _шен_, teoo, شخاص, --, 
   {{0x7ebc01d3,0x00000000,0x00000000,0x00000000}},	//   _géph, --, --, --, 
   {{0x62809093,0x40349094,0x26dc02f0,0x7534014b}},	//   reoo, белс, étou_, _гэсх, 
   {{0x240805f5,0x7ebc6ede,0xe4b80022,0x62800108}},	//   _анги_, _zéph, _рымш_, seoo, 
   {{0xe3f80150,0x3af801d3,0x201801f4,0x00000000}},	//   _شىرت_, képp_, äpi_, --, 
   {{0x3f9831ac,0x00000000,0x00000000,0x00000000}},	//   _árum_, --, --, --, 
   {{0xa0a400f7,0x9cc89095,0x81d4015b,0x81c400c7}},	//   _каад, вына_, _সুর_, _уааҧ, 
   {{0x00e43345,0x9e6435e6,0x6e3c03f2,0x557400df}},	//   _اتری, _چاشن, ðsbr, סעין_, 
   {{0x7ebc9096,0x9e645d62,0x7b1819bb,0x9be4155b}},	//   _lépi, _ناشن, лоор_, ріпк, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf8b89097,0x76b89098,0xdb180036,0x9d500244}},	//   гөн_, қлар_, lytë, _بۆخت, 
   {{0xe7f003f8,0xaf340137,0x38bc0241,0x7ebc0129}},	//   _आँखा_, _ئرەت, _kìri_, _séph, 
   {{0xc7b89099,0x00000000,0x00000000,0x00000000}},	//   аёт_, --, --, --, 
   {{0x05900023,0x8c1800d9,0xcf54011a,0x46a400cf}},	//   _ብጭቡጥ_, _בווי, יבלת_, ошуб, 
   {{0xceb803b9,0x00000000,0x00000000,0x00000000}},	// [b210] _şəkk_, --, --, --, 
   {{0x7ebc07ea,0xd040013f,0xe72c0133,0x4de000fe}},	//   _dépi, yinɑ, بڵی_, _পৰুৱ, 
   {{0x9f5c044e,0x92e8909a,0xb9f40023,0x00000000}},	//   _dytë_, پراق_, _ማል_, --, 
   {{0x75d4909b,0x436800d4,0x0324003b,0xa7c400fb}},	//   _هيجا, раїн_, ідін, _ырыҫ, 
   {{0x764c909c,0x95c80415,0x798c031c,0xb27401a9}},	//   maay, _руна_, _jsaw, _қлаш, 
   {{0x764c909d,0x802403cc,0x798c909e,0x00000000}},	//   laay, يرىم, _msaw, --, 
   {{0x7bdc0008,0xc8800213,0x73c400c7,0x752c06be}},	//   úrul, əşdi_, _уӡаа, lqaz, 
   {{0x764c909f,0xf1d00323,0x798c90a0,0xae881fce}},	//   naay, _нөлө, _osaw, убиз_, 
   {{0x798c90a1,0x752c014b,0x2d9890a2,0xc1d40139}},	//   _nsaw, nqaz, íse_, _мөшә, 
   {{0x764c0050,0xddc00311,0xdb180200,0x7de400d1}},	//   haay, _scoţ, bytë, تسىم, 
   {{0x798c90a3,0x764c90a4,0xddc0033f,0xe7e402dd}},	//   _asaw, kaay, _zboż, _ﺍﻣﺎﻟ, 
   {{0x764c0de2,0x9ca400db,0xb63c0092,0x00000000}},	//   jaay, _ۇشىۇ, _ሬፑብሊ, --, 
   {{0xed5890a5,0x764c90a6,0x6bd46e9a,0x2ba80cb4}},	//   _сол_, daay, شتگر, _छपवा, 
   {{0x6c348f74,0x6cc400f7,0x7ebc06af,0x7e440022}},	//   _افغا, _ыйла, _répi, _лхәе, 
   {{0x798c90a7,0x764c2252,0xaa440137,0xdc34008f}},	//   _esaw, faay, _лейл, _פאקט_, 
   {{0x9f5c02d3,0x764c338f,0x752c00ac,0x7ebc90a8}},	//   _sytë_, gaay, fqaz, _pépi, 
   {{0xae0c00af,0xed580419,0x00000000,0x00000000}},	// [b220] ाइटन_, byže_, --, --, 
   {{0xa88413d7,0x6ab403b2,0x598090a9,0xdb0c023a}},	//   _الدى, _hoyf, _эльб, ädök, 
   {{0xe2980323,0x764c90aa,0xa2e490ab,0x5f0800dc}},	//   лаж_, baay, божд, ातम्_, 
   {{0x6ab490ac,0x764c01d9,0x3f8c0175,0xa978010f}},	//   _joyf, caay, _rsdu_, ָאַכ, 
   {{0x7ebc00dd,0x272c0142,0x91e003f6,0x05c4012d}},	//   _képv, _hýn_, поце, लैशब, 
   {{0xdb180200,0x3f9800e5,0x00000000,0x00000000}},	//   tytë, _áruk_, --, --, 
   {{0x52800131,0x4f54007b,0x00000000,0x00000000}},	//   زلۈك, مجيد_, --, --, 
   {{0x7eb890ad,0xe12400d8,0xdb180200,0xd35400d9}},	//   ргис_, _гмаи, rytë, _לילי_, 
   {{0xa1c400f7,0xe2a40321,0x3d9428a8,0x7c240166}},	//   _убад, úðum_, ципр, _şirq, 
   {{0x3b5425ff,0x764c90ae,0xda0c0073,0x00000000}},	//   окор, zaay, _सरबत_, --, 
   {{0x798c90af,0x3f8c047e,0x8d700050,0xaf4801e2}},	//   _ssaw, _usdu_, _ہاوا, _نشنل_, 
   {{0x1be407d6,0x764c292a,0x6d5c01e7,0x00000000}},	//   _қўлг, xaay, ásac, --, 
   {{0x272c00a2,0x764c0a49,0xf2bc009e,0x49746a10}},	//   _aýn_, vaay, _আগমণ, пляс, 
   {{0x764c90b0,0x8308031c,0x5ba490b1,0xd90c90b2}},	//   waay, _ཇེའུ_, _гриз, عید_, 
   {{0x764c90b3,0x58840184,0x9f500139,0x00000000}},	//   taay, _һына, _ädäb_, --, 
   {{0x798c90b4,0x63bc33b8,0x752c01b9,0x00000000}},	//   _tsaw, dypn, tqaz, --, 
   {{0x798c90b5,0x764c90b6,0x7aec035b,0x58844640}},	// [b230] _usaw, raay, _ijat, _лына, 
   {{0x764c2f99,0x00000000,0x00000000,0x00000000}},	//   saay, --, --, --, 
   {{0x764c90b7,0x7aec90b8,0x14080022,0x73d800ea}},	//   paay, _kjat, ухап_, јдер_, 
   {{0x60d890b9,0x764c0014,0x7aec00b8,0x91300022}},	//   _amtm, qaay, _jjat, зҭах, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x50640aac,0x7e640171,0x4244008e,0x948401af}},	//   стда, _ķipa, охәб, _уымд, 
   {{0x7aec00c7,0xdb1800e4,0xc0c80114,0xdc380092}},	//   _ojat, pytè, ључе_, _የአሁኑ, 
   {{0x7aec90ba,0xdb1800e4,0x2f340055,0xcb8400d1}},	//   _njat, byté, _nāge_, ەمدۇ_, 
   {{0xed588bb8,0xc10405d9,0xad2400d1,0xd1c8009d}},	//   шоп_, _کولي, غىدى, _сувд_, 
   {{0x7aec90bb,0x2f0006ea,0xebe4004e,0x00000000}},	//   _ajat, jógv_, жооп, --, 
   {{0x6a843252,0x4fc401c6,0x00000000,0x00000000}},	//   олна, _усаа, --, --, 
   {{0x8650013f,0x78a40208,0x644800e5,0x00000000}},	//   nkɔt, _anhv, ófiz, --, 
   {{0x7aec90bc,0x7b28002b,0x272c0321,0x63bc0210}},	//   _djat, _aśud, _sýn_, zypn, 
   {{0x7ebc90bd,0xeb981c96,0x7aec90be,0x9f5c01ef}},	//   _dépu, _вик_, _ejat, _syté_, 
   {{0x29e0013f,0xec142c11,0x6dc000db,0x26b40395}},	//   _wɔa_, _بوغد, _رۅگۅ, ощар, 
   {{0x7aec069c,0x78a48784,0x63bc02f0,0x47f401c6}},	//   _gjat, _enhv, vypn, жүүр, 
   {{0x7c380098,0x393401c6,0x2bc004aa,0x20bc0073}},	// [b240] _ébré, _нээс, शनका, ्समध, 
   {{0x7ebc003e,0x2d9c0083,0x63bc90bf,0x4aa8012d}},	//   _hépt, _mrwe_, typn, गावव, 
   {{0x9f5c011f,0x2f0001f1,0x9878008f,0x7ebc01d3}},	//   _aytî_, lógu_, _דריק, _képt, 
   {{0xe5a41f91,0x256890c0,0xa88401ec,0x7aec031c}},	//   _дими, _камп_, _الگى, _xjat, 
   {{0x208890c1,0xdb1800e4,0x00000000,0x00000000}},	//   ийди_, kytî, --, --, 
   {{0x657401e2,0x7ebc01d3,0xdb1802f0,0xd0d400d4}},	//   mtyh, _lépt, ryté, одії_, 
   {{0x2d9c0099,0x2d983c38,0x63bc0240,0x8fa00114}},	//   _arwe_, æsen_, qypn, даје, 
   {{0x95e401d9,0xbdb40063,0xdb180124,0x7ebc4e79}},	//   _اکہِ_, збиј, pyté, _népt, 
   {{0x6574870e,0x4f040184,0xa06821ae,0x4fe4446e}},	//   ntyh, өнән_, _ваза_, ймән_, 
   {{0x7ebc90c2,0xdb4c168d,0x24940023,0xc1e401af}},	//   _répu, نێت_, _ዘማሪት_, _мөҙҙ, 
   {{0x7aec90c3,0x2d9c0ea0,0x7ebc06af,0x3f980306}},	//   _pjat, _erwe_, _sépu, _éru_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfd3800c6,0x7aec0162,0x2d9801e3,0x00000000}},	//   _اكتب_, _vjat, åset_, --, 
   {{0x26dc0ba1,0xdb18002f,0xa2d800b8,0xe778035b}},	//   èton_, lztü, पोत्, әатә_, 
   {{0xd6d890c4,0x7aec90c5,0xcb640640,0x6574009a}},	//   ата_, _tjat, _даје_, etyh, 
   {{0x7aec90c6,0xd5ac00e5,0x00000000,0x00000000}},	//   _ujat, نہج_, --, --, 
   {{0xbb3c001f,0x38c890c7,0xdb14033f,0x6574010e}},	// [b250] _የተቃዋ, _هادی_, ńców, gtyh, 
   {{0x7afc90c8,0x394813a4,0x7ebc00e5,0xbc4006be}},	//   lost, _iwas_, _képs, _üçdə, 
   {{0x19f40014,0x7afc017a,0x65740022,0x00000000}},	//   _دِکھ_, oost, atyh, --, 
   {{0x87980014,0x394890c9,0x8c18011a,0x00000000}},	//   _بێٲر_, _kwas_, בובי, --, 
   {{0xdec401f3,0xa2500101,0x00000000,0x00000000}},	//   ሽኑን_, رپوش, --, --, 
   {{0x3dd00729,0x3948007f,0xef1811ca,0xbebc002b}},	//   াপাল, _mwas_, әми_, _itīy, 
   {{0x60204ea5,0x7ebc00dd,0x12e402bf,0x96bc90ca}},	//   ндша, _néps, _діаг, _एकाउ, 
   {{0x7afc90cb,0x518490cc,0xee380801,0x8234009f}},	//   jost, _муза, щни_, _يرقا, 
   {{0x7ebc90cd,0x324420f3,0x00000000,0x00000000}},	//   _répt, _меңг, --, --, 
   {{0x7ebc90ce,0x1cbc0327,0x13dc0154,0x958c0023}},	//   _sépt, ཇིཊ_, _বুয়, _ዘካትዕ_, 
   {{0x7afc90cf,0x7ebc90d0,0x7b2800cd,0x31bc009e}},	//   fost, _pépt, _aśub, _অধিশ, 
   {{0x7afc90d1,0xddc8000a,0x8fd000d1,0x2d980fac}},	//   gost, šiše, _нәқә, åses_, 
   {{0x2d9c0223,0x6da407d5,0xada490d2,0x2d9000e2}},	//   _urwe_, _хила, _халл, āzes_, 
   {{0x201003be,0x3a2890d3,0x2d8c2543,0x6b541d39}},	//   əyib_, _egap_, mwee_, _етих, 
   {{0xbebc0055,0x2d8c90d4,0xe7380120,0x00000000}},	//   _atīy, lwee_, себ_, --, 
   {{0xf1bc0b9c,0x00000000,0x00000000,0x00000000}},	//   ्नान, --, --, --, 
   {{0x28f805f5,0x2d8c0521,0x7ebc01ed,0x3948015d}},	// [b260] _гэнэ_, nwee_, _képr, _gwas_, 
   {{0xd1d0069d,0xe5780139,0x550090d5,0x00000000}},	//   ያነት_, _һзм_, епуб, --, 
   {{0x7ebc4056,0x2d8c0134,0xb40000ee,0x65744e2d}},	//   _mépr, hwee_, вүрд, styh, 
   {{0x7ebc5fe6,0x2d8c0472,0x65740076,0x77900244}},	//   _lépr, kwee_, ptyh, _جیفا, 
   {{0xd24c1416,0x00000000,0x00000000,0x00000000}},	//   انه_, --, --, --, 
   {{0x7afc90d6,0x2d8c0af9,0xd7540244,0x7ebc00e5}},	//   zost, dwee_, _بلێت_, _népr, 
   {{0xd00c095e,0x7afc90d7,0x443890d8,0x6d5c00c6}},	//   هله_, yost, _ifr_, ásan, 
   {{0x444409f0,0x644c3942,0x443806af,0x7afc005a}},	//   lb_, _hebi, _hfr_, xost, 
   {{0x644c90d9,0x44440b89,0x7afc90da,0x672416a6}},	//   _kebi, ob_, vost, _mikj, 
   {{0x444490db,0x644c90dc,0xdb1800dd,0x44381f53}},	//   nb_, _jebi, sztü, _jfr_, 
   {{0x7afc90dd,0x444490de,0x644c90df,0x66045d16}},	//   tost, ib_, _mebi, _lykk, 
   {{0x644c90e0,0x672409a8,0x443890e1,0x7b28002b}},	//   _lebi, _nikj, _lfr_, _aśuc, 
   {{0x0e980302,0x444400b5,0x644c0109,0x39480327}},	//   _לשאל, kb_, _oebi, _qwas_, 
   {{0x644c90e2,0x443805ac,0x4444031c,0x7ebc00e5}},	//   _nebi, _nfr_, jb_, _gépr, 
   {{0x444490e3,0xf8b00345,0x00000000,0x00000000}},	//   db_, _یکس_, --, --, 
   {{0x444490e4,0xa8040227,0x3948039a,0x644c002d}},	//   eb_, _sañä, _twas_, _aebi, 
   {{0xdb181b7a,0x66040194,0x349405f5,0x6724003d}},	// [b270] sztó, _cykk, маар, _dikj, 
   {{0x66047a1e,0x9f5c0429,0x444490e5,0x67240158}},	//   _dykk, _aytí_, gb_, _eikj, 
   {{0x932490e6,0x4438070d,0x2d8c0036,0x67240200}},	//   سران, _dfr_, zwee_, _fikj, 
   {{0x44440e37,0x66c80232,0x644c90e7,0x3cf00490}},	//   ab_, _týka, _eebi, ीकडे_, 
   {{0x444490e8,0x644c90e9,0xf0d401c6,0x05840107}},	//   bb_, _febi, мждэ, _пурм, 
   {{0x644c90ea,0x444490eb,0x443890ec,0x21a001b9}},	//   _gebi, cb_, _gfr_, тишм, 
   {{0x7ebc90ed,0x73c421e7,0x2d8c0290,0x90b001e0}},	//   _répr, _غيرم, wwee_, _үҙеш, 
   {{0x644c90ee,0x7c380f49,0x72a401d9,0x2d8c05e4}},	//   _zebi, _afvr, _تٕرن, twee_, 
   {{0x644c90ef,0x70583de2,0x82a40166,0xdb0401e1}},	//   _yebi, _маар_, _яшре, _òmùj, 
   {{0x2d8c0a40,0x5184013e,0x00000000,0x00000000}},	//   rwee_, _муҷа, --, --, 
   {{0x2d8c90f0,0x765c012d,0x00000000,0x00000000}},	//   swee_, _odsy, --, --, 
   {{0xfe7090f1,0x2f3400ef,0xdb1801ef,0x00000000}},	//   _مده_, _gāga_, bytí, --, 
   {{0x6f0804c4,0x4444058a,0x672490f2,0xfb7401d3}},	//   mlec, yb_, _rikj, وپیگ, 
   {{0x6f0890f3,0x660490f4,0x765c0731,0x6724007f}},	//   llec, _rykk, _adsy, _sikj, 
   {{0x67241509,0x66041a82,0xe6c426c0,0x444409a8}},	//   _pikj, _sykk, وتري, vb_, 
   {{0x644c90f5,0x6f0804c4,0x444490f6,0x2eec90f7}},	//   _sebi, nlec, wb_, nnef_, 
   {{0x644c90f8,0x44380327,0x7bdc09f3,0x672400cc}},	// [b280] _pebi, _pfr_, úruv, _vikj, 
   {{0x44440190,0x6f085651,0x6d5890f9,0xd464084c}},	//   ub_, hlec, _mvwa, дифе_, 
   {{0x6f0890fa,0x644c0730,0x44442278,0x67245613}},	//   klec, _vebi, rb_, _tikj, 
   {{0x660490fb,0x4444019b,0x7ebc90fc,0x66e43159}},	//   _tykk, sb_, _népp, _цома, 
   {{0x644c90fd,0x6f0890fe,0x4444083a,0x4438011c}},	//   _tebi, dlec, pb_, _tfr_, 
   {{0x443890ff,0x644c0023,0x1fa49100,0x3f9c009b}},	//   _ufr_, _uebi, дриг, tvvu_, 
   {{0x6d589101,0x7ebc00e8,0x6f086e16,0xdef89102}},	//   _avwa, _bépp, flec, жып_, 
   {{0x26d0020b,0x9f5c00c7,0x6f087ea3,0x2eec0267}},	//   nhyo_, _pytâ_, glec, gnef_, 
   {{0xb8e0025c,0x6d58035a,0x00000000,0x00000000}},	//   _གྭ_, _cvwa, --, --, 
   {{0xa2d80da3,0x6f089103,0x22449104,0xd24c9105}},	//   पोर्, alec, lbok_, _منہ_, 
   {{0x6f089106,0x7d0804f3,0x6d58035a,0xde4401b9}},	//   blec, rlds, _evwa, _قیغو_, 
   {{0x22449107,0x6f089108,0xddc41064,0x4ea09109}},	//   nbok_, clec, _обеи, _арша, 
   {{0xace82ab4,0x22440af9,0x25b00175,0x673c0064}},	//   _کرنل_, ibok_, jxyl_, _atpj, 
   {{0x3f9801f6,0x66c80419,0x2244910a,0x00000000}},	//   _árus_, _býko, hbok_, --, 
   {{0x224401e3,0x7ebc00e8,0xebc0013d,0x78b40175}},	//   kbok_, _yépp, _бәян, rjzv, 
   {{0x29080789,0x00000000,0x00000000,0x00000000}},	//   alba_, --, --, --, 
   {{0x2244910b,0x6d5803ac,0x95c800d8,0x00000000}},	// [b290] dbok_, _xvwa, цува_, --, 
   {{0x6f08910c,0x26d00067,0x24980175,0xa6c801a9}},	//   zlec, ahyo_, gdpm_, _stаt, 
   {{0x26d00882,0x6f08910d,0x00000000,0x00000000}},	//   bhyo_, ylec, --, --, 
   {{0xb810035b,0x765c00b5,0xd2580006,0x00000000}},	//   _аҧҳә, _udsy, іце_, --, 
   {{0xcad80302,0x6f08910e,0x5bc801bc,0xa5f001c0}},	//   וואת_, vlec, ानुव, _бүтц, 
   {{0x3cf805f9,0x6d5c007b,0x6d5802d0,0xaf940120}},	//   ँवों_, ásam, _rvwa, ешиј, 
   {{0x6f08910f,0xd2580022,0x6d5803ac,0x22449110}},	//   tlec, _мца_, _svwa, bbok_, 
   {{0x66c80174,0x6d580857,0x95840092,0xc1c80150}},	//   _nýkl, _pvwa, _ምርትን_, _ﺒﻐﺩﺍ, 
   {{0x6f08092e,0xd24c021a,0x6da49111,0x9f5c0124}},	//   rlec, _منځ_, хипа, _pytã_, 
   {{0x6f089112,0x00000000,0x00000000,0x00000000}},	//   slec, --, --, --, 
   {{0x6f089113,0x1ee8006c,0x6d5803ac,0x25b00175}},	//   plec, _کونی_, _wvwa, zxyl_, 
   {{0x6d58127b,0x00000000,0x00000000,0x00000000}},	//   _tvwa, --, --, --, 
   {{0xfd5001f2,0xa3e400e1,0x66c80306,0xccf4504c}},	//   _medị, _बेन_, _sýko, _оқи_, 
   {{0xa80477a4,0xe694036b,0x6c78010f,0xd6740150}},	//   езгл, کلرد, _זאַפ, _ﺠﺫﻭﺭ_, 
   {{0x9cd4025f,0x598002dd,0x38040107,0x248c06be}},	//   _רוצה_, _ұлыб, ворҳ, _ölmə_, 
   {{0x66c8278a,0xba00063f,0xa6c801a9,0x25a00108}},	//   _výko, ụsịt, _rtаs, _prkl_, 
   {{0x6e3c0174,0x00000000,0x00000000,0x00000000}},	// [b2a0] ðsby, --, --, --, 
   {{0x26d09114,0x69c4003b,0xa5080276,0x2f34002b}},	//   shyo_, myke, чеза_, _nāgo_, 
   {{0x69c49115,0x224403a2,0x24989116,0xdb1801d3}},	//   lyke, tbok_, rdpm_, lytá, 
   {{0x25b00175,0xa3e400af,0x00000000,0x00000000}},	//   pxyl_, _बइठ_, --, --, 
   {{0x27f000da,0x22449117,0x326402bf,0x69c401d3}},	//   šanā_, rbok_, ттєв, nyke, 
   {{0x2244229b,0xdd30033f,0x00000000,0x00000000}},	//   sbok_, ręży, --, --, 
   {{0xb92402e3,0x00000000,0x00000000,0x00000000}},	//   _akpụ_, --, --, --, 
   {{0xa3e40050,0x69c40ea0,0x00000000,0x00000000}},	//   _बेय_, kyke, --, --, 
   {{0xbd1805f5,0xf1500050,0x6144022e,0x69c40f12}},	//   мжих_, _نێند, _чеза, jyke, 
   {{0x201003be,0x800800e5,0x66c801a8,0x6ea800bc}},	//   əyin_, _قرضہ_, _sýkl, काउँ, 
   {{0x5bc8687b,0xbf10104e,0x1f640798,0x00000000}},	//   ानेव, _күкә, _чкем, --, 
   {{0xc0dc0023,0x95840092,0xebc0013d,0x00000000}},	//   ንዎም_, _ምርቱን_, рәшн, --, 
   {{0x66c80122,0x69c401ed,0x0e040276,0xc9840276}},	//   _výkl, gyke, _пэши_, лури, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb90805ba,0x69c4003e,0xdd9001ee,0x00000000}},	//   _मग_, ayke, _раҙы, --, 
   {{0x59000d46,0x69c4002d,0x00000000,0x00000000}},	//   _ཚེམས_, byke, --, --, 
   {{0x69c49118,0x0c201945,0xd83801c0,0x66c800a2}},	// [b2b0] cyke, _имән, _нэн_, _gýkm, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x66c808ce,0x2f34002b,0x00000000,0x00000000}},	//   _mýkj, _rāgo_, --, --, 
   {{0xd6d83bb3,0x6d5c00e5,0x00000000,0x00000000}},	//   _хто_, ásak, --, --, 
   {{0xcb140a1e,0xa8f40133,0x1c00000d,0x00000000}},	//   אלף_, _ستیڤ, _रुसल_, --, 
   {{0xafe42e26,0x66c8032e,0xc104009f,0x9f5c01ef}},	//   колл, _nýkj, هوني, _sytá_, 
   {{0x9f5c00e4,0x69c49119,0xedc800bc,0x44f40a5b}},	//   _pytá_, zyke, िन्छ, _спрс, 
   {{0xf1c8313e,0xde4400f1,0x16bc000d,0x7fe8911a}},	//   _قوزى_, نیمو_, _एकोब, عروف_, 
   {{0xdd8c911b,0x8d2404a9,0xcdc002dd,0x91dc00cc}},	//   قوي_, нниң_, уапқ, _ফুৰ্, 
   {{0xa3e42356,0x00000000,0x00000000,0x00000000}},	//   _बेड_, --, --, --, 
   {{0x69c46df9,0x6b6402e8,0xa2a40073,0xaa440ce8}},	//   wyke, ъкна, _घोड्, кенл, 
   {{0x69c4911c,0x6e182761,0x3d1001e1,0x00000000}},	//   tyke, _قياس_, bàwo_, --, 
   {{0x69c40c6a,0x7bdc03f2,0x00000000,0x00000000}},	//   uyke, úrur, --, --, 
   {{0xd940911d,0x69c41f53,0x7c2401e4,0xdb1802f0}},	//   рери, ryke, _ŝire, rytá, 
   {{0x66e4453f,0x69c400d4,0x7e8803cd,0x47c800f1}},	//   вова, syke, _åspø, راسۍ_, 
   {{0xe3b019d2,0x9660911e,0xdb1800c7,0x00000000}},	//   یرا_, иксе, pytá, --, 
   {{0x59b01ee2,0xe8f8911f,0x68440276,0xe5788b10}},	// [b2c0] _көрс, _оли_, _инпа, ьза_, 
   {{0x2d68001f,0x1954011a,0x00000000,0x00000000}},	//   _ተነስቶ_, _שביל_, --, --, 
   {{0xdb18002f,0xe2b4009d,0x00000000,0x00000000}},	//   rztö, ксдэ, --, --, 
   {{0x61449120,0x2168013e,0xe2a8007b,0x962400d1}},	//   веда, диди_, باطن_, ركەك_, 
   {{0x29180649,0xa03407a7,0x00000000,0x00000000}},	//   _khpa_, نىشت, --, --, 
   {{0x31a4004b,0x20c002d2,0x91e00108,0x00000000}},	//   الوې, _aðir_, шоче, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe8180c2e,0x6f1803cb,0x00000000,0x00000000}},	//   _धरना_, _chwc, --, --, 
   {{0xaca800dd,0x62809121,0x5bc800dc,0x1278008f}},	//   کھنے_, mfoo, ान्व, _קאמע, 
   {{0x62809122,0xdc88036b,0xaf04004e,0x00000000}},	//   lfoo, фсил_, кчөк, --, 
   {{0x81f4015b,0x69d8008f,0x00000000,0x00000000}},	//   _জরিপ_, ŝtel, --, --, 
   {{0x62809123,0x7e989124,0x1ee8036b,0x4cac015b}},	//   nfoo, _سنتر_, _کوچی_, টসগু, 
   {{0x291801c3,0x62809125,0x00000000,0x00000000}},	//   _bhpa_, ifoo, --, --, 
   {{0x62800334,0x5ba49126,0xc8649127,0x628488e9}},	//   hfoo, _ариз, итси, _ökof, 
   {{0xf8b001d9,0x36d49128,0xda0c1d34,0x00000000}},	//   لکھ_, говр, _सरकत_, --, 
   {{0x8f98008f,0xa3d49129,0xb5940d99,0x00000000}},	//   וילי, िनन_, либш, --, 
   {{0x6280912a,0x00000000,0x00000000,0x00000000}},	// [b2d0] dfoo, --, --, --, 
   {{0x3860912b,0x6d5c6d6c,0x00000000,0x00000000}},	//   _udhr_, ásai, --, --, 
   {{0xf31405f5,0x62800548,0xdb1800a2,0xa3e4912c}},	//   гджэ, ffoo, gytç, _बेद_, 
   {{0x97000075,0x6d5c00e2,0x6280912d,0x644803b2}},	//   _ئېرى, šsai, gfoo, ðfir, 
   {{0xcca00115,0x00000000,0x00000000,0x00000000}},	//   _linց, --, --, --, 
   {{0x92e000bd,0xaf98912e,0x41040212,0x28c401ad}},	//   নকে_, етих_, азів, रॉपि, 
   {{0x6fb408de,0xca302d40,0x00000000,0x00000000}},	//   امعا, ﺭﻻﺭ_, --, --, 
   {{0x6280020c,0x02a4912f,0x2d949130,0x41740e56}},	//   cfoo, _крум, грос, _چالس, 
   {{0x201000ac,0xb1cc01f2,0xf0e8129d,0xc2e401d5}},	//   əyim_, ọọkụ_, _كىرى_, _тўри, 
   {{0x332c025c,0x320c0067,0xc09400cf,0x06cc00eb}},	//   _hiex_, _iyey_, _ۅجۅت, রোপি, 
   {{0xa3d4242e,0xa2d801ad,0x7f949131,0x60600137}},	//   िनय_, पोक्, _вахх, _چۇۇل, 
   {{0xcf249132,0xa968026a,0x28c402ab,0xfee401b9}},	//   _شراي, нима_, रॉनि, _кўчм, 
   {{0x7bc80548,0x332c0327,0xdb1801f4,0x00000000}},	//   aydu, _miex_, dytä, --, 
   {{0x7bc80142,0xb6080171,0x00000000,0x00000000}},	//   bydu, _mošķ, --, --, 
   {{0x6280010a,0xac089133,0x7bc80034,0x00000000}},	//   yfoo, _янка_, cydu, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x25a400c6,0x7a8400cf,0x62800175,0xe9a4419d}},	// [b2e0] íol_, _ئشىم, vfoo, _сапп, 
   {{0x628000b5,0x66c809e8,0x394c054e,0x00000000}},	//   wfoo, _mýki, ţesc_, --, 
   {{0x332c3aaf,0x320c0050,0x66e4024c,0x92e000fe}},	//   _biex_, _ayey_, _бона, নকৈ_, 
   {{0xe1f89134,0x236407f5,0x00000000,0x00000000}},	//   нге_, čoj_, --, --, 
   {{0x26c002b9,0x7bc81d01,0x21740798,0x00000000}},	//   _ioko_, zydu, ѓудр, --, 
   {{0x26c09135,0x62809136,0xa5080640,0xa6c801a9}},	//   _hoko_, sfoo, _чега_, _muаm, 
   {{0x26c09137,0x332c031c,0x320c0009,0x62800175}},	//   _koko_, _fiex_, _eyey_, pfoo, 
   {{0x26c09138,0x332c0327,0x7bc80153,0x3f140798}},	//   _joko_, _giex_, vydu, јдис, 
   {{0x26c02173,0x7ebc00dd,0x69d8008f,0x00000000}},	//   _moko_, _képz, ŝtej, --, 
   {{0x26c09139,0x66c803b2,0x9f5c00c7,0xddf002dd}},	//   _loko_, _dýki, _pytä_, _қолө, 
   {{0xfaf8005f,0xbc4006be,0x00000000,0x00000000}},	//   krīt_, _üçmə, --, --, 
   {{0x26c00c58,0xda6400c6,0x7bc8913a,0x332c0135}},	//   _noko_, دادي, rydu, _xiex_, 
   {{0xa3e407af,0x7bc800b5,0xf8a8315b,0x2d98005c}},	//   _बेस_, sydu, نگده_, æset_, 
   {{0xa2a402ab,0x7ebc00e5,0x00000000,0x00000000}},	//   _घोस्, _népz, --, --, 
   {{0x26c0913b,0x6d5c00d0,0xdb18005b,0xa368022e}},	//   _boko_, ásav, tytä, lyеf, 
   {{0x26c00333,0xc6000154,0xcb6400f3,0x00000000}},	//   _coko_, ্ধনা_, _саће_, --, 
   {{0x26c0913c,0x35b4913d,0x98e4011c,0x00000000}},	// [b2f0] _doko_, шбар, _бюнд, --, 
   {{0x3f8c022f,0xdb18023a,0x798c913e,0x00000000}},	//   _opdu_, sytä, _ipaw, --, 
   {{0x26c00170,0xd3a40c75,0xfaf800de,0x00000000}},	//   _foko_, ырап, brīt_, --, 
   {{0x26c00099,0x92b00154,0x66d400ec,0x823400f2}},	//   _goko_, টস্_, _نيپئ, مرها, 
   {{0xb9d0693c,0x3f8c0589,0xb464913f,0x8544084c}},	//   _ስነ_, _apdu_, _نگاه, _гэсе, 
   {{0x764c9140,0x798c9141,0x26c09142,0x2364005f}},	//   lbay, _mpaw, _zoko_, ņoja_, 
   {{0x26c09143,0x201000ac,0x66c801a8,0xbf6416ac}},	//   _yoko_, əyik_, _sýki, مديو, 
   {{0x764c9144,0xaec49145,0x798c137f,0x26c002b9}},	//   nbay, рбил, _opaw, _xoko_, 
   {{0x798c0070,0x764c0014,0x7c2400df,0x0d0401a9}},	//   _npaw, ibay, _ĝira, лдиқ_, 
   {{0xfc440020,0x7c2400df,0x63a0033f,0x00000000}},	//   _የአገል, _ŝira, łone, --, 
   {{0x798c9146,0x764c9147,0x00000000,0x00000000}},	//   _apaw, kbay, --, --, 
   {{0x2d98005c,0x00000000,0x00000000,0x00000000}},	//   æses_, --, --, --, 
   {{0x26c09148,0x764c0014,0x62840254,0x0eb401ee}},	//   _roko_, dbay, _ökoe, _ауҙы_, 
   {{0x6d489149,0x26c0914a,0x7c940801,0x764c914b}},	//   mpea, _soko_, _гръц, ebay, 
   {{0x26c0914c,0x6d48914d,0xeb98084c,0x798c02d0}},	//   _poko_, lpea, _рий_, _epaw, 
   {{0x764c4511,0xdce00135,0x29540354,0x00000000}},	//   gbay, _ipoġ, _къор, --, 
   {{0x26c007a9,0x6d48914e,0x7afc2539,0xa50800d8}},	// [b300] _voko_, npea, érte, веаа_, 
   {{0x26c0914f,0x6d4807f0,0x764c8442,0x00000000}},	//   _woko_, ipea, abay, --, 
   {{0x26c0638a,0xdce00135,0x764c9150,0x232801d5}},	//   _toko_, _jpoġ, bbay, вожи_, 
   {{0x926467b7,0xdce0031c,0x764c058a,0x93400212}},	//   арша_, _mpoġ, cbay, інче, 
   {{0xa3e4033d,0xe1241e37,0x91e002e8,0x00000000}},	//   _बेर_, амди, ооце, --, 
   {{0x6d48000d,0x2444030d,0x00000000,0x00000000}},	//   dpea, _тĕкс, --, --, 
   {{0x6d5c025a,0x6d480175,0xdce0031c,0x2f0000d0}},	//   âsan, epea, _npoġ, lógy_, 
   {{0x6d4400b0,0x77600077,0x53980375,0x00000000}},	//   _ōhaa, álxi, _בילו, --, 
   {{0x91e09151,0x716400ae,0x00000000,0x00000000}},	//   _мәшһ, _هالك, --, --, 
   {{0x5cc49152,0x6284002f,0x00000000,0x00000000}},	//   рсиз, _ökob, --, --, 
   {{0x764c9153,0x2d98037e,0xa3d41971,0x6d489154}},	//   ybay, æser_, िनि_, apea, 
   {{0x70440166,0xd840022a,0xef2400a2,0xeef40024}},	//   _күәм_, _ovčí_, _ýüpe_, _лячэ, 
   {{0x7c340408,0xe8ec00ec,0x6d5c00d7,0x00000000}},	//   _лелх, کڻي_, ásat, --, 
   {{0x386c0639,0xa3d436c7,0x00000000,0x00000000}},	//   ßer_, िना_, --, --, 
   {{0x386c0ab7,0x7d0800b5,0x66c80ad9,0x00000000}},	//   ğer_, mods, _lýku, --, 
   {{0x386c9155,0x764c079b,0x73d89156,0x7d0812e8}},	//   şer_, ubay, ңдар_, lods, 
   {{0x798c9157,0x764c9158,0x05741066,0xb8cc009e}},	// [b310] _upaw, rbay, قالد, _কক_, 
   {{0xb8940597,0x26dc0421,0x764c9159,0xd3a46ff7}},	//   _الدع, ītoa_, sbay, иреп, 
   {{0x6d485594,0x06cc0154,0xd7f80798,0x80a4000d}},	//   zpea, রোধি, _шуи_, _गोें, 
   {{0x6d48915a,0x7d08127b,0x764c0548,0xb15c01ec}},	//   ypea, hods, qbay, ендi, 
   {{0x7d08915b,0xa3080014,0x70480107,0x00000000}},	//   kods, درٕے_, гӯем_, --, 
   {{0xbc4006be,0x6f6400ae,0x00000000,0x00000000}},	//   _üçhə, مهتم, --, --, 
   {{0x73d802e8,0x00000000,0x00000000,0x00000000}},	//   _сдвр_, --, --, --, 
   {{0xb8d8915c,0x2ca8915d,0x66c80a87,0x6d48915e}},	//   _ཚོ_, _şad_, _fýku, tpea, 
   {{0x5064915f,0x6d484056,0x417400c6,0x7d0801bf}},	//   _نطاق, upea, _واكس, fods, 
   {{0x2ba411f9,0x6d489160,0x7d089161,0xdce0031c}},	//   _pēc_, rpea, gods, _ppoġ, 
   {{0xeb040212,0xc104007b,0xeb280137,0x09d000cd}},	//   йпоп, _بولي, лжол_, हन्य, 
   {{0xc6000729,0x09e00011,0x6d5c9162,0x2d98003d}},	//   ্ধতা_, _যুগা, ásas, ħseb_, 
   {{0xfe70034c,0x63a00607,0x7d0805ac,0x6f080334}},	//   _زدن_, āoni, bods, moec, 
   {{0x2d9c01af,0x7d080014,0xbbe89163,0x2eec9164}},	//   _iswe_, cods, اریم_, lief_, 
   {{0xdc1003be,0xa3e40037,0x00000000,0x00000000}},	//   _işğa, _बें_, --, --, 
   {{0x2eec05b1,0x6f08003a,0xfbd09165,0x00000000}},	//   nief_, noec, _تته_, --, 
   {{0xe6189166,0x39340137,0x00000000,0x00000000}},	// [b320] уда_, _мээс, --, --, 
   {{0x2eec9167,0x66c81d0e,0x00000000,0x00000000}},	//   hief_, _rýku, --, --, 
   {{0x29089168,0xb7802310,0x1d14008f,0x5c5800df}},	//   moba_, _оғри, צקער_, רדעק, 
   {{0x29083d81,0x68ec9169,0x6f08000f,0x923c0023}},	//   loba_, libd, joec, _ክበርሃ, 
   {{0x6d440374,0x2eec23f3,0x00000000,0x00000000}},	//   _ōhan, dief_, --, --, 
   {{0x2908916a,0x66c80122,0x15400fcb,0xdbf0010e}},	//   noba_, _výku, _херм, _aşýa, 
   {{0x645c2af2,0x2d9c02e2,0x6f08002d,0xc0dc001f}},	//   mapi, _aswe_, foec, ፕሎማ_, 
   {{0x645c916b,0x2908916c,0x26d004ce,0x2eec05e4}},	//   lapi, hoba_, nkyo_, gief_, 
   {{0x7cd82095,0x2908916d,0x7d08916e,0x9cc8916f}},	//   имир_, koba_, tods, гына_, 
   {{0x29089170,0x645c9171,0x02c4036b,0x68ec022e}},	//   joba_, napi, _уйғо, jibd, 
   {{0xdee49172,0x9be40046,0x68ec0280,0x29089173}},	//   _ложи, сіпк, dibd, doba_, 
   {{0x645c9174,0xf8d02435,0xbebc0171,0x7d0800e5}},	//   hapi, हस्प, _luīz, sods, 
   {{0x290805be,0x7d089175,0x00000000,0x00000000}},	//   foba_, pods, --, --, 
   {{0x29089176,0x645c9177,0xdce001e4,0x26d01418}},	//   goba_, japi, _ovoĉ, ekyo_, 
   {{0x645c9178,0xb9000406,0x5c14030d,0xd6880395}},	//   dapi, _दत_, _уьду, лщад_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x29089179,0x645c0109,0x09e40063,0x37e00154}},	// [b330] boba_, fapi, _ноћн, _মুখর, 
   {{0x2908917a,0x68ec00ac,0x8648001f,0x26d01418}},	//   coba_, cibd, ያስከት, akyo_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6f080005,0x39480055,0x756401d3,0x4b78010f}},	//   xoec, _ktas_, _ویزہ_, רטאג, 
   {{0x645c917b,0x26cc013b,0x95c807d5,0x200c06be}},	//   bapi, ɔfo_, _суна_, _əliş_, 
   {{0x394800d8,0x00000000,0x00000000,0x00000000}},	//   _mtas_, --, --, --, 
   {{0x2eec1aa7,0xdb18005c,0x6f0801ab,0x00000000}},	//   tief_, bytø, toec, --, 
   {{0xee38917c,0x2908917d,0x3948917e,0xef181fbe}},	//   шни_, zoba_, _otas_, јми_, 
   {{0x6da40b14,0x2eec1aa7,0x2908016c,0x7f48917f}},	//   ципа, rief_, yoba_, _etdq, 
   {{0xce30021a,0x2eec0936,0xab644f13,0xe454008f}},	//   _ځواک, sief_, овол, ֿירט_, 
   {{0x394827ed,0xeab89180,0x5924025c,0x66c8032e}},	//   _atas_, айн_, _རྫེས_, _mýkr, 
   {{0x645c52ed,0x29080516,0x2d9c9181,0x6e9400fb}},	//   zapi, woba_, _tswe_, _фиду, 
   {{0x29089182,0x645c0986,0x394801e2,0xed589183}},	//   toba_, yapi, _ctas_, _тол_, 
   {{0xad242e56,0x00000000,0x00000000,0x00000000}},	//   _بىتى, --, --, --, 
   {{0x39489184,0x68ec07d6,0xdb0806af,0xfb2400f2}},	//   _etas_, ribd, _orfè, تریپ, 
   {{0x645c9185,0x657401f4,0x00000000,0x00000000}},	//   wapi, tuyh, --, --, 
   {{0x645c9186,0xe4589187,0x2908063f,0x24e80107}},	// [b340] tapi, ижа_, poba_, амаи_, 
   {{0x29080107,0x26d00083,0xa3d401ad,0xeaf800ec}},	//   qoba_, skyo_, िनल_, _حرڪت_, 
   {{0x645c228f,0x6ab49188,0xe7380114,0xa3e800d8}},	//   rapi, _knyf, _њем_, јдеа_, 
   {{0x673800e5,0xe578009b,0x00000000,0x00000000}},	//   ítju, _кзм_, --, --, 
   {{0x645c9189,0x03a801d9,0x00000000,0x00000000}},	//   papi, _گۯاو_, --, --, 
   {{0xd4c4004b,0x7c24008f,0x645c918a,0x00000000}},	//   _وژلو_, _ŝirm, qapi, --, 
   {{0x4444918b,0x03a80050,0xdfa4007b,0xe2982ff5}},	//   mc_, _دۯاو_, تحشي, _кав_, 
   {{0x4444918c,0x6ab402c4,0xa2d4004b,0x00e4918d}},	//   lc_, _nnyf, _بيرت, _کتری, 
   {{0x4444918e,0x6d5c0022,0x3df401f4,0x00000000}},	//   oc_, ásap, язис, --, 
   {{0x4f840014,0x39480332,0x4438045a,0x205401ee}},	//   _ژانہ, _rtas_, _jgr_, _фтар, 
   {{0x4444918f,0x44389190,0x39489191,0x61e09192}},	//   ic_, _mgr_, _stas_, lzol, 
   {{0x394804d4,0x4438007c,0x5398010f,0x00000000}},	//   _ptas_, _lgr_, בסטא, --, 
   {{0x7e606ea0,0x4438067c,0x5924025c,0xdca448f2}},	//   mamp, _ogr_, _རྫུས_, _мади, 
   {{0x44440010,0x2ca4020c,0x28c401ad,0x00000000}},	//   jc_, cdld_, रॉलि, --, 
   {{0x444406a3,0x3cf800c5,0x61e0022e,0xdb58011c}},	//   dc_, ुवीं_, hzol, _тюл_, 
   {{0x44449193,0xcb0805d9,0x00000000,0x00000000}},	//   ec_, _ويون_, --, --, 
   {{0x39489194,0xf3f8506f,0x44380334,0x60d801d5}},	// [b350] _utas_, әнеш_, _bgr_, _oltm, 
   {{0x61e0289c,0x63ac01ab,0x7aec02fb,0xa3d400dc}},	//   dzol, _brbn, _hmat, िनं_, 
   {{0x7e609195,0x78a45bef,0x27e402a8,0x44389196}},	//   kamp, _iahv, _ƙone_, _dgr_, 
   {{0x44449197,0x7e609198,0x63ac0c5e,0xfa200092}},	//   ac_, jamp, _drbn, _ተንታኞ, 
   {{0x7aec9199,0x78a4919a,0x4444919b,0x201c009d}},	//   _mmat, _kahv, bc_, _azti_, 
   {{0x4438049f,0x6284919c,0x765c919d,0x2f540334}},	//   _ggr_, _ökon, _hesy, птис, 
   {{0x765c919e,0x7e600851,0x78a4016d,0xd34016e0}},	//   _kesy, famp, _mahv, _آفری, 
   {{0x78a4919f,0x7e6091a0,0x753491a1,0xed5891a2}},	//   _lahv, gamp, _hizz, бои_, 
   {{0x765c91a3,0x753491a4,0x201c009d,0xece81a71}},	//   _mesy, _kizz, _ezti_, йдил_, 
   {{0x78a491a5,0x7aec476b,0x765c91a6,0x753c7b8c}},	//   _nahv, _amat, _lesy, _musz, 
   {{0x7534109f,0x753c91a7,0x7e6091a8,0xeb983129}},	//   _mizz, _lusz, bamp, щин_, 
   {{0x753491a9,0x7aec0077,0x319c033b,0x765c702b}},	//   _lizz, _cmat, _kňz_, _nesy, 
   {{0x7aec91aa,0x78a400cd,0x44440784,0xdb0c00e5}},	//   _dmat, _bahv, yc_, ójáv, 
   {{0x7aec91ab,0x753491ac,0x765c0ac5,0x6d5891ad}},	//   _emat, _nizz, _aesy, _iwwa, 
   {{0x61e091ae,0x753c91af,0x765c91b0,0x444491b1}},	//   zzol, _ausz, _besy, vc_, 
   {{0x443891b2,0x7aec009a,0xa3e4098a,0x753c91b3}},	//   _sgr_, _gmat, _बेग_, _busz, 
   {{0x765c91b4,0x443891b5,0xa3dc0316,0x753491b6}},	// [b360] _desy, _pgr_, दैन_, _bizz, 
   {{0x444491b7,0x7e6091b8,0x753c0034,0x765c02d0}},	//   uc_, zamp, _dusz, _eesy, 
   {{0x444491b9,0x753491ba,0x7aec0cfd,0x765c0092}},	//   rc_, _dizz, _ymat, _fesy, 
   {{0xd7b80d65,0x78a40552,0x444491bb,0x7e6000f7}},	//   _הצטר, _zahv, sc_, xamp, 
   {{0x444491bc,0x753491bd,0x7e605943,0x78a491be}},	//   pc_, _fizz, vamp, _yahv, 
   {{0x765c2622,0x753491bf,0x443891c0,0x7e6091c1}},	//   _zesy, _gizz, _ugr_, wamp, 
   {{0x61e000dd,0x673c0054,0x6d5891c2,0x442c0129}},	//   szol, _jupj, _awwa, _àd_, 
   {{0x753404ba,0x673c014f,0x6d58035a,0xb35401d5}},	//   _zizz, _mupj, _bwwa, _آینا_, 
   {{0xa06891c3,0x25a00158,0x6d5803ac,0x2a60003e}},	//   _газа_, _jskl_, _cwwa, dakb_, 
   {{0x7aec1326,0xe1080139,0x60d802d0,0x00000000}},	//   _smat, _уезд_, _ultm, --, 
   {{0x78a4033d,0x7e6091c4,0x7aec91c5,0x6d586282}},	//   _rahv, pamp, _pmat, _ewwa, 
   {{0x7e6091c6,0x6d58035a,0xa6c801a9,0x78a4262a}},	//   qamp, _fwwa, _muаs, _sahv, 
   {{0x765c91c7,0x7c38005a,0x1d0891c8,0x78a416ca}},	//   _resy, _tgvr, _леди_, _pahv, 
   {{0x765c91c9,0x3d1409fd,0x201003be,0x753c2957}},	//   _sesy, _नीचे_, əyir_, _rusz, 
   {{0x753491ca,0x78a40d77,0xd6d891cb,0x673c5880}},	//   _rizz, _vahv, бта_, _cupj, 
   {{0x75340225,0x753c58ad,0x4b78011a,0x00000000}},	//   _sizz, _pusz, _האהו, --, 
   {{0x78a40842,0x753491cc,0x765c0100,0x7afc01e3}},	// [b370] _tahv, _pizz, _vesy, mnst, 
   {{0xda0404fb,0x6d4402b5,0xd7f8013e,0x7534022e}},	//   _ويژه_, _ōhak, _гум_, _qizz, 
   {{0x7afc91cd,0x753491ce,0x25a00158,0xb4ac0118}},	//   onst, _vizz, _eskl_, _कफी_, 
   {{0x753c91cf,0x7afc91d0,0x628491d1,0x319c007f}},	//   _tusz, nnst, _ökol, _pňz_, 
   {{0x7afc91d2,0x753491d3,0x673c0010,0x83341291}},	//   inst, _tizz, _zupj, ررمض, 
   {{0x7afc91d4,0xef240209,0xfbdc3347,0x6d586e99}},	//   hnst, _ýüze_, मनाम, _rwwa, 
   {{0x4394398c,0xdce002f0,0x6d5802d0,0xaf200023}},	//   _парс, _cvoč, _swwa, _ትህልወ, 
   {{0x7afc91d5,0xdce000f3,0x691001bf,0x224400e5}},	//   jnst, _dvoč, næer, ccok_, 
   {{0x7afc0113,0xec7801d5,0xa2c0008e,0xa2a428fe}},	//   dnst, опп_, _шәфк, _घोट्, 
   {{0xdb1802fb,0xd1cc0092,0x00000000,0x00000000}},	//   rytý, ባባቂ_, --, --, 
   {{0xbed801d5,0x7afc08a5,0x00000000,0x00000000}},	//   زهیچ_, fnst, --, --, 
   {{0x7afc91d6,0x673c005f,0x2dd407d8,0xcc8403e6}},	//   gnst, _rupj, _ожер, _کۆده_, 
   {{0xdce0151c,0x1ee84716,0x673c0024,0xd8740014}},	//   _zvoč, _بونی_, _supj, ڈمُت_, 
   {{0x7afc91d7,0xe73891d8,0x673c01f5,0xd8740050}},	//   anst, жев_, _pupj, ومُت_, 
   {{0xfca80014,0x00000000,0x00000000,0x00000000}},	//   _راوو_, --, --, --, 
   {{0x22440548,0xcfac009e,0xe69401d5,0xaae0190c}},	//   xcok_, _কথান, بلرد, _पतिक, 
   {{0x7c2401e4,0xe7b85b29,0x00000000,0x00000000}},	// [b380] _ĝiri, _उपकप, --, --, 
   {{0x7c2400df,0x673c036e,0xd99400e5,0xe8f8011c}},	//   _ŝiri, _tupj, _کنیت_, _фло_, 
   {{0x33d40953,0x66e4792b,0xaae00b67,0xdb180210}},	//   ніцт, _жона, _पताक, cytó, 
   {{0xb424072d,0x00000000,0x00000000,0x00000000}},	//   رعلو, --, --, --, 
   {{0xddc00030,0x62840ef5,0xdce00064,0x224491d9}},	//   _odoš, _ökom, _svoč, rcok_, 
   {{0x2244009d,0x65740142,0x2d98031c,0x0564030d}},	//   scok_, mryh, ħsel_, ăвĕн, 
   {{0x7afc91da,0x53a0035b,0xa3e402fe,0xd04000d1}},	//   ynst, _иарб, _बेच_, خپىي, 
   {{0xb9f4001f,0x62641eeb,0x6cd40150,0x00000000}},	//   _ዛፍ_, _زارق, _ﺘﺠﺭﻴ, --, 
   {{0x717004a9,0x7afc022c,0xdb18033f,0x65740108}},	//   _مۇنا, vnst, zytó, nryh, 
   {{0x7afc91db,0x657401ab,0x00000000,0x00000000}},	//   wnst, iryh, --, --, 
   {{0xc0cc001f,0xbbb807f7,0xdfa4007b,0xd90c07d6}},	//   ባናል_, इमेक, _تحذي, ییب_, 
   {{0x7afc91dc,0x00000000,0x00000000,0x00000000}},	//   unst, --, --, --, 
   {{0xc98491dd,0x58842e70,0x499401d3,0xdde005a2}},	//   кури, мыва, نیٹر, _шәкү, 
   {{0xed4c05d9,0x6f0c00d7,0x00000000,0x00000000}},	//   _اھي_, čace, --, --, 
   {{0x27e402a8,0x55f8015b,0x0ba03947,0x00000000}},	//   _ƙona_, _আরেক_, _ашым, --, 
   {{0x6d440093,0xdb18012d,0x65740200,0x00000000}},	//   _ōhai, rytó, fryh, --, 
   {{0xdbdc0077,0xd83891de,0x657402d0,0x00000000}},	// [b390] míña, _мэн_, gryh, --, 
   {{0x73c491df,0x00000000,0x00000000,0x00000000}},	//   нәбе, --, --, --, 
   {{0xb27491e0,0x38600036,0x691000b5,0xa854011a}},	//   елеш, _iehr_, pæer, _איתה_, 
   {{0x932400f2,0x00000000,0x00000000,0x00000000}},	//   ذران, --, --, --, 
   {{0x3860002f,0xb9ec0023,0x00000000,0x00000000}},	//   _kehr_, _ቕነ_, --, --, 
   {{0x2d982093,0x00000000,0x00000000,0x00000000}},	//   çsem_, --, --, --, 
   {{0x386091e1,0xbf6400b2,0x00000000,0x00000000}},	//   _mehr_, نديو, --, --, 
   {{0x38600112,0xed580107,0x43944684,0x91d801ec}},	//   _lehr_, пои_, _шасс, _мәлi, 
   {{0x8d2404a9,0x26dc0200,0xf42000cc,0x00000000}},	//   мниң_, ëtoi_, _বলিৰ_, --, 
   {{0x707802dd,0xfc60001f,0x3cf40419,0xd7dc0709}},	//   _ءماز_, _ለአገል, _ľavú_, ननाच, 
   {{0x92b002f5,0xa6e00008,0x68e00042,0x2bb8007b}},	//   য়সী_, úðka, _ïodi, سادة_, 
   {{0xfe7091e2,0xdd8c591c,0x9cb00137,0xfe540024}},	//   _نده_, جوی_, _ەموت, _акцэ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdca091e3,0x657405e4,0x5ca01945,0xec2402dd}},	//   _баши, vryh, _бишб, _كىشپ, 
   {{0x7a2801a9,0x657401f4,0x00000000,0x00000000}},	//   lоtl, wryh, --, --, 
   {{0x63a00034,0xcb5c002e,0xdb4c01f7,0x00000000}},	//   łonk, g茜en_, _اَي_, --, 
   {{0xa52404f0,0xe5780a8d,0x59b0013d,0xe29801f0}},	// [b3a0] емад, яза_, _йөрс, ҷае_, 
   {{0xbb441c5c,0xe634009d,0xdb0401f4,0x00000000}},	//   _ﭘﻪﻥ_, _үхмэ, ämöi, --, 
   {{0x6574023a,0xe29891e4,0x6284000d,0x7a28022e}},	//   sryh, зае_, _ökok, hоtl, 
   {{0xe31491e5,0x66e440f8,0x00000000,0x00000000}},	//   رباب, _чома, --, --, 
   {{0xfd4801e1,0xb6c401ee,0x00000000,0x00000000}},	//   _damọ, _рияһ, --, --, 
   {{0x64a405f5,0xfff82a60,0x1fa401a9,0xd0d400d4}},	//   _яага, وکات_, ериг, ндії_, 
   {{0xdef86ad2,0xfd480241,0x2ef801e4,0xe29406ed}},	//   зып_, _famọ, _ĉsfr_, _праќ, 
   {{0x8fa006ed,0x9e6491e6,0xae7000d1,0x00000000}},	//   ѓање, رابن, لۇمغ, --, 
   {{0x5698025f,0x62801529,0x7ce40ba1,0x3d0c012c}},	//   ליקצ, mgoo, _jòrg, ठकले_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdeb00220,0x5f7400cf,0xdbdc0077,0xd12c08f4}},	//   _бұйы, _ساار, tíña, _امل_, 
   {{0x386009f0,0x628091e7,0x6fcc012c,0x00000000}},	//   _sehr_, ngoo, तहरू, --, 
   {{0x4dd091e8,0x628091e9,0x3860007c,0x00000000}},	//   _متوس, igoo, _pehr_, --, 
   {{0x1ee80345,0x00000000,0x00000000,0x00000000}},	//   _بوچی_, --, --, --, 
   {{0x628001a4,0x24780023,0x07a401d5,0xab60000d}},	//   kgoo, _ኣምራት_, лаён, üüte, 
   {{0x75e801a9,0x38600112,0x9a84013d,0x00000000}},	//   _hоzi, _wehr_, _чукл, --, 
   {{0x95c891ea,0x38600ac5,0x628091eb,0x69c000f7}},	// [b3b0] чува_, _tehr_, dgoo, _көрб, 
   {{0x62803a73,0x061484dc,0x00000000,0x00000000}},	//   egoo, удую, --, --, 
   {{0x7ce401c3,0xd7f891ec,0xfd480241,0xd3787a9c}},	//   _iòrd, _хуп_, _pamọ, яча_, 
   {{0x628091ed,0x75e8022e,0x27fc00d0,0x00000000}},	//   ggoo, _lоzi, útne_, --, 
   {{0x7ce40561,0xc24402dd,0x6d5c00e2,0x45d4490c}},	//   _gòrg, унік, šsaz, _бояс, 
   {{0x7ce4068c,0xf07401ed,0x628091ee,0xf0e800d1}},	//   _jòrd, ئیاں_, agoo, بىتى_, 
   {{0x606000d1,0x5ea80154,0xa3bc00cd,0xf3140064}},	//   شۇنل, কানে, ेहः_, _адвэ, 
   {{0x75740020,0x6280037e,0x00000000,0x00000000}},	//   _እርስዎ_, cgoo, --, --, 
   {{0x90b00150,0x00000000,0x00000000,0x00000000}},	//   _бәйш, --, --, --, 
   {{0x316c07e4,0xdbdc09cc,0x7ce400cf,0x7ae4031c}},	//   _ivez_, tíða, _nòrd, _ċita, 
   {{0x06cc0154,0x00000000,0x00000000,0x00000000}},	//   রোটি, --, --, --, 
   {{0xa9680640,0xcfe00213,0xdbdc0bcd,0xab840124}},	//   мима_, ışıq_, ríða, нуҭк, 
   {{0x7ce491ef,0xdbdc0436,0x7a28022e,0x00000000}},	//   _bòrd, síða, qоtl, --, 
   {{0x7ce491f0,0x2d8c0a55,0x63a0033f,0x55f805ac}},	//   _còrd, mtee_, łoni, _আৰ্ক_, 
   {{0x2d8c8902,0x628091f1,0x37740166,0x3d2400c0}},	//   ltee_, ygoo, лытс, _сьцв, 
   {{0xc5f40198,0x2d8c208d,0x00000000,0x00000000}},	//   zaɓu_, otee_, --, --, 
   {{0xa92491f2,0xe61801b9,0x00000000,0x00000000}},	// [b3c0] _идил, фда_, --, --, 
   {{0x628091f3,0x7ce408c2,0x2d8c6d94,0x00000000}},	//   wgoo, _gòrd, itee_, --, 
   {{0x316c0231,0x2d8c91f4,0x18740302,0x628091f5}},	//   _avez_, htee_, _בעיר_, tgoo, 
   {{0xe1f834b1,0x2d8c91f6,0x7790331c,0x00000000}},	//   мге_, ktee_, _دیفا, --, 
   {{0x628091f7,0x6dc001e4,0x7afc91f8,0x00000000}},	//   rgoo, sʈaʈ, érti, --, 
   {{0xdce001f1,0x2d8c00af,0x7ce4007f,0xd4140124}},	//   _spoľ, dtee_, _kòre, хьӡы, 
   {{0xfe780184,0x2334035b,0x316c91f9,0x644c0009}},	//   еүе_, _ахар, _evez_, _ifbi, 
   {{0xeb6402d3,0x2d8c198f,0xd59800b5,0xdef8035b}},	//   _መሰጋገ, ftee_, _mgの_, ьыл_, 
   {{0x316c0369,0xd0208fb9,0x6144236b,0xf15004d3}},	//   _gvez_, лмәй, _реза, _هێند, 
   {{0xfba80276,0xf8d00118,0x00000000,0x00000000}},	//   еӂий_, _सकेप, --, --, 
   {{0x2d8c3431,0x547804ae,0x316c0427,0x5ea80154}},	//   atee_, וטיו, _zvez_, কাবে, 
   {{0x2d8c5f39,0x00000000,0x00000000,0x00000000}},	//   btee_, --, --, --, 
   {{0x2d8c91fa,0x644c0036,0x8f34011a,0x00000000}},	//   ctee_, _ofbi, _סאדו_, --, 
   {{0xdce400e2,0xb92400ae,0x00000000,0x00000000}},	//   ēmēj, افسي, --, --, 
   {{0xec180166,0x7bdc005c,0x6578002b,0x00000000}},	//   _пешә_, ørud, _ātha, --, 
   {{0x644c75fa,0xa3b42072,0x00000000,0x00000000}},	//   _afbi, जिन_, --, --, 
   {{0x34943bfd,0x5fa40037,0x9f8c0037,0x00000000}},	// [b3d0] лаар, _कईऽल, mõõt_, --, 
   {{0x798c031c,0x00000000,0x00000000,0x00000000}},	//   _iqaw, --, --, --, 
   {{0x316c00f3,0x08f807c0,0x938801c6,0x5dd402dd}},	//   _svez_, _جريب_, ьсаа_, _ﺘﻐﻴﻴ, 
   {{0x2d8c91fb,0x02f00790,0x00000000,0x00000000}},	//   ytee_, _üçlü_, --, --, 
   {{0x644c01fa,0x66780375,0x798c0327,0x320891fc}},	//   _ffbi, _אטרק, _jqaw, çay_, 
   {{0x89dc0302,0x3d0c033f,0xa1540063,0x764c4457}},	//   וחדי, सकों_, ћају_, lcay, 
   {{0xd34404fb,0x2ab800a2,0x4cc800fe,0x92a4033a}},	//   _شیشه_, _jübä_, িসমু, _ијал, 
   {{0x764c91fd,0xf1c80046,0x8284113e,0x00000000}},	//   ncay, _كوزى_, _ەجەل, --, 
   {{0x798c0218,0x2d9891fe,0x316c1710,0x2d8c0076}},	//   _nqaw, ïse_, _uvez_, utee_, 
   {{0x2d8c91ff,0x058802d3,0x91bc0208,0xe8d001f9}},	//   rtee_, _ዚግባእ_, _ngủ_, _हवेच, 
   {{0x2d8c9200,0x00000000,0x00000000,0x00000000}},	//   stee_, --, --, --, 
   {{0xaf200154,0x2d8c0076,0x7ed40064,0xf8a8011a}},	//   _পূরণ_, ptee_, _вішч, _מש_, 
   {{0x764c1f75,0x66e407a5,0x00000000,0x00000000}},	//   dcay, ҳова, --, --, 
   {{0xd9400262,0xa3b49201,0x764c058a,0x00000000}},	//   сери, जिम_, ecay, --, 
   {{0x66e40577,0xdb180108,0x00000000,0x00000000}},	//   гова, vytö, --, --, 
   {{0x6b809202,0xe5a49203,0x764c009a,0x7bdc03b2}},	//   mulg, либи, gcay, ørue, 
   {{0xdb18005b,0x1a98008f,0xd704005b,0xc894004e}},	// [b3e0] tytö, _טיקע, унте_, _кунө, 
   {{0x7ce40086,0x201801b8,0x764c0067,0x25b00076}},	//   _tòre, üpik_, acay, rvyl_, 
   {{0x291801f2,0x764c058a,0x3774004e,0x5ea80154}},	//   _ikpa_, bcay, _кыяс, কাতে, 
   {{0x6264322e,0xf1c4004d,0x26dc00e2,0xc1540023}},	//   увда, _trợ_, ītos_, _ዝተወሃ, 
   {{0x6b809204,0x83a409ab,0x00000000,0x00000000}},	//   hulg, _गैरआ, --, --, 
   {{0xe04803b6,0x7ce400a3,0x779001ed,0x883c0092}},	//   رشته_, _mòrc, _دیہا, _በቤተሰ, 
   {{0x24880522,0x291805db,0xd3700133,0x6b800037}},	//   _icbm_, _mkpa_, _هێلک, julg, 
   {{0x7d18005b,0x6b800d63,0xdb1c0174,0xbed400d8}},	//   _skvs, dulg, _ávøk, роиј, 
   {{0xa2049205,0xf1a828c4,0x6d4400b0,0x00000000}},	//   _спад, _لاله_, _ōhar, --, 
   {{0x764c9206,0x291802e3,0x6b809207,0x66c802fb}},	//   zcay, _nkpa_, fulg, _výky, 
   {{0xf1b801f1,0x6b809208,0x213c01ab,0x764c0009}},	//   _vyše_, gulg, _iith_, ycay, 
   {{0x29189209,0x213c01ab,0xd434010f,0x00000000}},	//   _akpa_, _hith_, טריק_, --, 
   {{0x6af000aa,0x7ce401ab,0xf8b00050,0x5ea800eb}},	//   تګور, _còrc, ۅکھ_, কাদে, 
   {{0x6b80920a,0x7ce401ab,0x4ac402dd,0x5ba435ce}},	//   bulg, _dòrc, _ۇيىق, _бриз, 
   {{0x213c920b,0xc7c40276,0xf8b00014,0xb8dc01f9}},	//   _mith_, бсти, مکھ_, _इफ_, 
   {{0x213c920c,0x7ce40ba1,0x3a740116,0x798c031c}},	//   _lith_, _fòrc, _тлир, _tqaw, 
   {{0x29180093,0x4a54013d,0x201c0064,0x588401af}},	// [b3f0] _fkpa_, _укыс, _lyti_, _йына, 
   {{0x764c920d,0xe8140574,0x495400aa,0x213c920e}},	//   scay, _दुवा_, _اخيس, _nith_, 
   {{0x537802d3,0xf3140006,0x201c032e,0x06cc03d4}},	//   _ኣውያት_, аджэ, _nyti_, ৰোধি, 
   {{0x9264920f,0x98b0084c,0x213c9210,0x24880165}},	//   ادام, _fixă_, _aith_, _ecbm_, 
   {{0x213c50c2,0x201c9211,0x6b8001c4,0x01d80011}},	//   _bith_, _ayti_, zulg, _দেবদ, 
   {{0x6ae037f3,0x3a28005a,0x201c03b2,0x213c00ae}},	//   _पत्र, _mzap_, _byti_, _cith_, 
   {{0xafe49212,0x213c01c3,0x6b800077,0xbf100073}},	//   ройл, _dith_, xulg, ावून_, 
   {{0x6b800120,0x213c0493,0x201c0023,0x3a280129}},	//   vulg, _eith_, _dyti_, _ozap_, 
   {{0x51844c70,0x201c01e1,0x8fd001e0,0x00000000}},	//   _љуба, _eyti_, шәҡә, --, 
   {{0x201c036e,0x5fa4043e,0x00000000,0x00000000}},	//   _fyti_, _कैवल, --, --, 
   {{0xfd500882,0x3a2875d4,0xd17401ec,0xfd4c0208}},	//   _mokṣ, _azap_, _шыңы, _khiễ, 
   {{0x7ce456eb,0xf1b804a7,0x62849213,0x00000000}},	//   _pòrc, _krš_, _ökot, --, 
   {{0x692401fe,0x69c40a59,0x8d740133,0xd1780023}},	//   имма, ामधी, _ڤاڵا, _ብሰፊሕ_, 
   {{0x271c0cb3,0x9d5000c6,0x6b800037,0x5d78010f}},	//   पत्र_, _بنوت, pulg, _יאנק, 
   {{0x18649214,0xb91c0248,0x00000000,0x00000000}},	//   раси_, _yiyẹ_, --, --, 
   {{0xfd4c0016,0xd7042bbd,0x872801e2,0x00000000}},	//   _nhiễ, ансе_, اغسې_, --, 
  
   {{0xd5449215,0xe9a49216,0x7a840150,0x35c4013e}},	// [b400] ипте_, _тапп, _اشىم, батҳ, 
   {{0xdb089217,0x00000000,0x00000000,0x00000000}},	//   _erfä, --, --, --, 
   {{0x213c0597,0xf1b801fa,0x626403cc,0x9c10063f}},	//   _rith_, _arš_, لاشق, họnc, 
   {{0x213c9218,0xa69414b7,0x332c01d5,0x7ce40013}},	//   _sith_, _трој, _chex_, _mòra, 
   {{0x332c0a81,0x213c0493,0x26c00115,0x00000000}},	//   _dhex_, _pith_, _inko_, --, 
   {{0x201c00c7,0xfd500055,0xa878008f,0xa3b40412}},	//   _pyti_, _gokṣ, דאַר, जिद_, 
   {{0xa3b8033d,0x2d9c02e2,0x4f649219,0x213c01c7}},	//   _अछि_, _apwe_, ашым_, _vith_, 
   {{0x213c3d99,0x332c0327,0x7b1c04d4,0x2328828a}},	//   _with_, _ghex_, néut, _роби_, 
   {{0x26c00093,0xa0c4004b,0x91e0921a,0xbd1801c6}},	//   _mnko_, _پياو, _доте, лжих_, 
   {{0x568c02d3,0xa3b81d7d,0x4cb4005b,0x201c0064}},	//   _ነጻነቱ_, _अछा_, алью_, _tyti_, 
   {{0x26c00664,0x7ce40e89,0x6284921b,0xdee41d4a}},	//   _onko_, _còra, _ökos, _кожи, 
   {{0x7ce408e7,0xdd9801f0,0x00000000,0x00000000}},	//   _dòra, _ашк_, --, --, 
   {{0x3ea4921c,0x5334010f,0xfdd800ec,0x00000000}},	//   memt_, ינטן_, _ڄاڻڻ_, --, 
   {{0x26c00699,0x7ce4921d,0x5884921e,0x3ea4921f}},	//   _anko_, _fòra, шыма, lemt_, 
   {{0xbb843dca,0x7ce401c3,0x57b0044b,0x00000000}},	//   _العي, _gòra, ुमेह, --, 
   {{0x22b4016b,0x00000000,0x00000000,0x00000000}},	//   bɛkɔ_, --, --, --, 
   {{0x7afc33eb,0xb9940597,0x09e40063,0x3a280432}},	// [b410] mist, _الخب, _моћн, _uzap_, 
   {{0x26c09220,0x394805d5,0xa6c8022e,0x00000000}},	//   _enko_, _iuas_, _muаy, --, 
   {{0x394801d4,0xb8b40046,0x7afc02f6,0x39409221}},	//   _huas_, _көңі, oist, _iihs_, 
   {{0x39489222,0x7b1c09ff,0x3ea4143a,0x62f000c7}},	//   _kuas_, céut, jemt_, пҧст, 
   {{0x39489223,0x59a402ab,0x3ea401f5,0x955401ed}},	//   _juas_, गबिर, demt_, _ضیاء_, 
   {{0xd77807db,0x39480070,0x7f48014f,0x92d4015b}},	//   _ኤርትራ_, _muas_, _budq, াফে_, 
   {{0x7afc9224,0x39489225,0xdfcc188d,0xc07802bf}},	//   kist, _luas_, فيو_, рсії_, 
   {{0xf1b801fa,0xeb986294,0xd59800b5,0x00000000}},	//   _trš_, қим_, _kgだ_, --, 
   {{0x39480013,0xee389226,0x7ce4004e,0x00000000}},	//   _nuas_, ыни_, _sòra, --, 
   {{0x50d85843,0x7afc9227,0x6b84001f,0xbde401ec}},	//   _भविष, eist, _በተረፈ_, _ﺍﻷﻗل_, 
   {{0x39489228,0xaa440184,0x7f8400c6,0xeb980640}},	//   _auas_, йенл, _ولكن, ћим_, 
   {{0x7afc9229,0x3948207a,0x7b1c0077,0xdd7000e5}},	//   gist, _buas_, déus, _کھٹک, 
   {{0x3948922a,0x7afc0ba1,0x7ce40248,0x5ea80154}},	//   _cuas_, èrta, _wòra, কাশে, 
   {{0x3948922b,0x7afc922c,0x7ce408c2,0x7f48014f}},	//   _duas_, aist, _tòra, _yudq, 
   {{0x7afc922d,0x2ca45122,0x5ea803f4,0x3ae8000f}},	//   bist, meld_, কারে, _sûpe_, 
   {{0x394883bf,0x5b780a1e,0xea88005b,0x2ca403b2}},	//   _fuas_, _ערפא, _сбил_, leld_, 
   {{0x9fa009f3,0x2b9002fb,0x00000000,0x00000000}},	// [b420] _líða_, lác_, --, --, 
   {{0xa81800c6,0x2ca401a4,0x00000000,0x00000000}},	//   _متجر_, neld_, --, --, 
   {{0x7b1c2b76,0xd8d4010f,0x9fa002d2,0x00000000}},	//   péut, _הויט_, _níða_, --, 
   {{0x2ca4922e,0x394801d4,0xb24401e0,0x26c0922f}},	//   held_, _yuas_, ҙмәһ, _unko_, 
   {{0x2ca49230,0x39480070,0x7f489231,0x67340072}},	//   keld_, _xuas_, _sudq, mmyj, 
   {{0x9fa01f60,0xdb081f40,0x2ca408fb,0xdee00023}},	//   _bíða_, _esfè, jeld_, ምዑን_, 
   {{0x7afc9232,0x7ce4067c,0x3ea403cd,0x2ca401f5}},	//   yist, _bòrn, temt_, deld_, 
   {{0x7afc9233,0x63ac9234,0x7ce40c8e,0xa024010e}},	//   xist, _isbn, _còrn, _agöý, 
   {{0x2ca49235,0x3ea42ab7,0x7ce408c2,0x5ea8015b}},	//   feld_, remt_, _dòrn, কালে, 
   {{0x39489236,0x2ca49237,0x7ce401c3,0x673401f4}},	//   _ruas_, geld_, _eòrn, hmyj, 
   {{0x39489238,0x63ac003e,0xd7c80150,0x74c80bca}},	//   _suas_, _jsbn, _ءﻭﺗﯟ_, रातः, 
   {{0x39480190,0x7afc01f4,0xec1400f2,0xb90c0241}},	//   _puas_, uist, توپد, bamọ_, 
   {{0x39489239,0x2ca4923a,0x00000000,0x00000000}},	//   _quas_, beld_, --, --, 
   {{0x3948923b,0x3b180309,0x2b9001e7,0x673400c0}},	//   _vuas_, sosq_, bác_, emyj, 
   {{0x656402d0,0x6aa4022e,0x2b900208,0x7d081141}},	//   _awkh, bekf, các_, mnds, 
   {{0x3948923c,0x7afc923d,0xc3241df2,0x95c82e26}},	//   _tuas_, qist, _سە_, луза_, 
   {{0x355406c2,0x00000000,0x00000000,0x00000000}},	// [b430] زناز, --, --, --, 
   {{0x7ce4067c,0x7d08923e,0x00000000,0x00000000}},	//   _mòro, nnds, --, --, 
   {{0xdd8416cb,0x78b40354,0x7d085363,0x69cc0276}},	//   _ڪو_, mdzv, inds, ăieş, 
   {{0x63ac0a2e,0x2ca42e10,0x9fa0041e,0xe7a4033f}},	//   _dsbn, zeld_, _ríða_, खबरप, 
   {{0xdd84923f,0x9fa01bb0,0x05849240,0x63ac0175}},	//   _تو_, _síða_, _нурм, _esbn, 
   {{0xa3b41533,0xa02802d3,0x63ac0139,0x7ce401ab}},	//   जिश_, _ትሕዝቶ, _fsbn, _sòrn, 
   {{0x2ca42c01,0xdb082cd7,0x7ce401ab,0x0878010f}},	//   veld_, _esfé, _pòrn, מעגט_, 
   {{0x2ca49241,0xa3b41e61,0x9fa009f3,0x7d089242}},	//   weld_, जिर_, _víða_, ends, 
   {{0x2ca40896,0xace800c7,0xef180135,0xece8011c}},	//   teld_, имиа_, roż_, идил_, 
   {{0x463c008f,0x84940240,0x00000000,0x00000000}},	//   נעזע, _ፍታሕን_, --, --, 
   {{0xeb989243,0x2ca4292b,0x7ce45c99,0x7ff40137}},	//   шин_, reld_, _eòro, _ىسما, 
   {{0x2ca49244,0x7ce40ba1,0xbe649245,0x92b40183}},	//   seld_, _fòro, _فهمي, _চকু_, 
   {{0xcdc09246,0x2ca47a41,0x984c0166,0x6f089247}},	//   _халқ, peld_, _ağım_, mnec, 
   {{0x6d582f05,0x6f089248,0x18641575,0x6aa401c7}},	//   _itwa, lnec, жари_, sekf, 
   {{0x6f08010f,0x6d58035a,0xe7180633,0x00000000}},	//   onec, _htwa, ليست_, --, 
   {{0x6f089249,0x2eec0373,0x6d5802d0,0x4ad801d9}},	//   nnec, nhef_, _ktwa, _چاکھ_, 
   {{0xda6c037e,0x6d5802d0,0x6f0803ac,0xab54009f}},	// [b440] _koяn_, _jtwa, inec, _ائڪش, 
   {{0x6d58924a,0x6f089217,0xa3b4924b,0x01e4009d}},	//   _mtwa, hnec, जिल_, үйжү, 
   {{0x6f08924c,0x6d58035a,0x11d000d1,0x00000000}},	//   knec, _ltwa, ېتىد, --, 
   {{0x6d58924d,0xe298924e,0xdb98008f,0x6f080115}},	//   _otwa, рад_, יסער, jnec, 
   {{0x290804fb,0x6f08924f,0x6d589250,0x7ce400a3}},	//   onba_, dnec, _ntwa, _bòrl, 
   {{0xd12c0014,0x99b8008f,0x2908037e,0x7de001e1}},	//   نمن_, יזנט, nnba_, _lású, 
   {{0x6d589251,0x7ce401ab,0x63ac0066,0x2d8002b1}},	//   _atwa, _dòrl, _usbn, _āhea_, 
   {{0x6d5803ac,0x8e441b56,0xdd980408,0x00000000}},	//   _btwa, يلىك_, ашо_, --, 
   {{0xb8fc081f,0x7ce400a3,0x6d58035a,0x2908037e}},	//   _རྭ_, _fòrl, _ctwa, knba_, 
   {{0x7d089252,0x6d58035a,0x6f0801e4,0x00000000}},	//   unds, _dtwa, anec, --, 
   {{0x6d589253,0x6f080393,0x7afc0066,0x7de002d2}},	//   _etwa, bnec, èrto, _bású, 
   {{0x2eec9254,0x6d58035a,0x2908058a,0x9d44010a}},	//   chef_, _ftwa, enba_, _дедд, 
   {{0x26d00083,0x6d58035a,0x290800b5,0x09e40006}},	//   djyo_, _gtwa, fnba_, доўн, 
   {{0x76b8035b,0x78b40810,0xad640214,0x00000000}},	//   әлар_, udzv, _راهه, --, 
   {{0xd66807b5,0x00000000,0x00000000,0x00000000}},	//   ијал_, --, --, --, 
   {{0x290801d9,0x9fac00fd,0xa3dc00bc,0x00000000}},	//   anba_, _eşçe_, दैछ_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [b450] --, --, --, --, 
   {{0x6f0c181f,0x854400c0,0x6f0800d7,0xa6e006ea}},	//   čaci, _šėry, znec, øðra, 
   {{0x7ce41497,0x6f080937,0x00000000,0x00000000}},	//   _nòrm, ynec, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x95c89255,0x88340092,0x00000000,0x00000000}},	//   _туна_, _በስተደ, --, --, 
   {{0x7ce4067c,0xe794527d,0x6d5803ac,0x00000000}},	//   _bòrm, _بایک, _rtwa, --, 
   {{0x6d589256,0xe12005f5,0x2eec0af9,0x7bdc0162}},	//   _stwa, эмши, thef_, ørul, 
   {{0x59c84c3d,0x6d580857,0x32540006,0x0438002b}},	//   ामार, _ptwa, _хвар, _nāṃn, 
   {{0x6f089257,0x29080014,0x7ce401ab,0x2eec0ea0}},	//   rnec, ynba_, _tòrl, rhef_, 
   {{0x7ce49258,0x6f089259,0x8fc4925a,0x7de0007b}},	//   _fòrm, snec, _وزان, _sású, 
   {{0xf988008f,0xc3300050,0x6d580857,0x00000000}},	//   _תר_, _سٕے_, _wtwa, --, 
   {{0xbfb469f2,0xfeb81375,0x7ce4007f,0x290804ba}},	//   _زحمت, _وانت_, _jòrj, wnba_, 
   {{0x6d58925b,0x9b90925c,0x00000000,0x00000000}},	//   _utwa, ولیت, --, --, 
   {{0x2908058a,0xcc840133,0x00000000,0x00000000}},	//   unba_, _بۆده_, --, --, 
   {{0x6fbc752d,0x6a84010b,0x2908925d,0x00000000}},	//   ्मिं, _елйа, rnba_, --, 
   {{0xe6481a5c,0x61400241,0xe69401d5,0x26c41574}},	//   спад_, _kílì, ثلرد, ñoo_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [b460] --, --, --, --, 
   {{0x6ab4016b,0x6fbc925e,0x00000000,0x00000000}},	//   _hayf, ्मां, --, --, 
   {{0x6ab4036b,0xf3640212,0x00000000,0x00000000}},	//   _kayf, дтін, --, --, 
   {{0xddc0013a,0xd24c4e77,0xd9940244,0x00000000}},	//   _leoš, هنم_, _بنیت_, --, 
   {{0x6ab4925f,0x00000000,0x00000000,0x00000000}},	//   _mayf, --, --, --, 
   {{0x90c00114,0x9f68022e,0x00000000,0x00000000}},	//   ебље, бриз_, --, --, 
   {{0x53a00276,0xd464151e,0x23280117,0x64482ca8}},	//   _парб, _хисе_, _гови_, ğliğ, 
   {{0x7ce4067c,0x64600034,0x644805d1,0xcf8c0014}},	//   _gòrj, świę, şliğ, اژٕ_, 
   {{0xe2a4022c,0xa23401c0,0x00000000,0x00000000}},	//   øðum_, _хэвш, --, --, 
   {{0x3b542c1d,0x61e09260,0x0438002b,0x160019cc}},	//   мкор, myol, _sāṃn, _रेफर_, 
   {{0x61e00337,0x6ab400b5,0xeff802d3,0x712407d6}},	//   lyol, _bayf, ዋተይ_, _آرقل, 
   {{0x7774010a,0x68fc03ac,0x60d89261,0x61e00083}},	//   vszx, _ampd, _hotm, oyol, 
   {{0x61e09262,0x6ab401f5,0x5ce40395,0x00000000}},	//   nyol, _dayf, _нюка, --, 
   {{0x60d8014f,0x832c031c,0x39449263,0x05000154}},	//   _jotm, _ཧེའུ_, öls_, ্তুর_, 
   {{0xb8f41533,0x3870014b,0x60d89264,0x61e09265}},	//   _सच_, razr_, _motm, hyol, 
   {{0x60d89266,0x61e09267,0x6ab43f1d,0x00000000}},	//   _lotm, kyol, _gayf, --, 
   {{0xcb4402af,0x7aec9268,0x60d80549,0x4a7c0375}},	// [b470] _яхши, _ilat, _ootm, _הרחב, 
   {{0x7aec9269,0x61e0926a,0x6ab4022e,0xfbb02c2e}},	//   _hlat, dyol, _zayf, _जनाम, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x629c00dd,0x6fbc1d03,0xd0440213,0x6ab4022e}},	//   őpon, ्मसं, ələl, _xayf, 
   {{0x60d8047e,0xdeb80b82,0xd5b80108,0x00000000}},	//   _botm, ታንን_, _усн_, --, 
   {{0x7aec926b,0xf484150e,0x00000000,0x00000000}},	//   _llat, _تاحی, --, --, 
   {{0x60d803d1,0x7aec926c,0xdb0800db,0x4174129d}},	//   _dotm, _olat, _asfí, _ۋاكس, 
   {{0x7aec020c,0x86900023,0x92681999,0x00000000}},	//   _nlat, _ዝኽተሎ_, _ырга_, --, 
   {{0xdd8c926d,0x00000000,0x00000000,0x00000000}},	//   لوي_, --, --, --, 
   {{0x6ab4079d,0x60d80083,0xdd8c04fb,0x2d940150}},	//   _sayf, _gotm, گوی_, _ﻛﻪﻧﻰ_, 
   {{0xa3b4068f,0xdb0804d4,0x249c0205,0x00000000}},	//   जिए_, _esfí, _ötme_, --, 
   {{0x7aec926e,0xdd8c926f,0x60d89270,0x9e9400d1}},	//   _clat, دوی_, _zotm, _يانچ, 
   {{0xe814069f,0x80b4068f,0x7aec068f,0x7ae4003d}},	//   _दुजा_, _इसमे, _dlat, _ċitt, 
   {{0x7aec9271,0x6ab4005c,0xdd8c02f2,0xccf40150}},	//   _elat, _wayf, _ئوو_, _хқо_, 
   {{0x6ab41ae4,0xec14036b,0x61e0926a,0x18b00124}},	//   _tayf, _توغد, zyol, тәыр, 
   {{0x61e09272,0x47f401c6,0xdbcc0205,0xcc840133}},	//   yyol, дүүр, _sıçt, _بۆگه_, 
   {{0xe5786ebd,0x68fc0113,0x442c0dfe,0xd6242bbd}},	// [b480] юза_, _tmpd, _šd_, доте_, 
   {{0x7aec9273,0x61e09274,0x68fc03ac,0xeea002dd}},	//   _zlat, vyol, _umpd, _ﺃﻤﻴﻥ_, 
   {{0x7aec5063,0x657402f0,0x00000000,0x00000000}},	//   _ylat, ssyh, --, --, 
   {{0x60d89275,0x0500015b,0xfbb006b1,0x4254029e}},	//   _sotm, ্তের_, _जनसम, رنتر, 
   {{0x36940166,0x3f9800b8,0x00000000,0x00000000}},	//   _яшэс, _ūru_, --, --, 
   {{0xb9f40020,0x61e04918,0x60d81ffc,0x8534006c}},	//   _ኛው_, ryol, _qotm, _سوزچ, 
   {{0xe2a800b2,0xc0c40724,0x61e09276,0x00000000}},	//   _وارن_, _җәли, syol, --, 
   {{0x3f8002d5,0x61e00bd7,0x60d8047e,0xfe701dd8}},	//   čiu_, pyol, _wotm, اگا_, 
   {{0xa3b46b9b,0xa1149277,0x60d89278,0x00000000}},	//   जिक_, _قورت, _totm, --, 
   {{0x7ce402e2,0xe0546676,0xe6800023,0x00000000}},	//   _kòri, _غیبت_, _ንጽበዮ_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7aec05ce,0x7ce400db,0x8d9000ae,0x00000000}},	//   _vlat, _lòri, _للنش, --, 
   {{0x4fc00075,0x7aec9279,0x4cb4003b,0x00000000}},	//   _سەۋە, _wlat, _олію_, --, 
   {{0x7aec927a,0x7ce400db,0x1cac031c,0xf8b001d9}},	//   _tlat, _nòri, _ཕྲར_, نکھ_, 
   {{0x7aec00af,0x8b0800bc,0x00000000,0x00000000}},	//   _ulat, _vyří, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [b490] --, --, --, --, 
   {{0x7ce41f40,0x6134045f,0xcd940375,0xd9c80210}},	//   _bòri, nâld, ודמת_, ामीट, 
   {{0x3a28003e,0x7bdc0174,0x00000000,0x00000000}},	//   _hyap_, øruh, --, --, 
   {{0x6134334b,0x1cac0135,0x7ce4927b,0x00000000}},	//   hâld, _ཕྲལ_, _dòri, --, 
   {{0x7ce408e7,0xdd84927c,0xb50400db,0x00000000}},	//   _eòri, _حو_, _كۉرۅ_, --, 
   {{0xb10c04c5,0x6ea00864,0xd000035b,0x00000000}},	//   ষত্ব_, क्नु, колқ, --, 
   {{0xf1b80122,0x00000000,0x00000000,0x00000000}},	//   _myši_, --, --, --, 
   {{0x680c01d3,0x00000000,0x00000000,0x00000000}},	//   lődé, --, --, --, 
   {{0x3a28004e,0x6134000f,0xb640037e,0xed440354}},	//   _nyap_, fâld, _ｍｙ_, ннип, 
   {{0xdb08927d,0x316c0165,0x8fe400f3,0x00000000}},	//   _erfü, _iwez_, _оцед, --, 
   {{0xab281fbd,0x316c0dd4,0x3a2800a2,0x7ae4031c}},	//   зона_, _hwez_, _ayap_, _ċitr, 
   {{0xc4dc1f14,0x952c0327,0x00000000,0x00000000}},	//   _मक्ख, _ཨེའི_, --, --, 
   {{0xada40724,0x6da4927e,0xeab00050,0x00000000}},	//   _чалл, _чила, نٹھ_, --, 
   {{0xc9000183,0x00000000,0x00000000,0x00000000}},	//   ৃত্ত_, --, --, --, 
   {{0x2d8c0418,0x17c4927f,0xe73801df,0x3774013d}},	//   luee_, нгри_, зев_, кытс, 
   {{0xdc600023,0xdb1800e4,0xdc3800df,0x00000000}},	//   _ደበሳይ_, yvté, _צעקר, --, 
   {{0xd5ac1893,0x7ce400db,0x6ea01d68,0x2d8c9280}},	// [b4a0] یفہ_, _sòri, क्यु, nuee_, 
   {{0x050000bd,0x2a70058a,0x00000000,0x00000000}},	//   ্ত্র_, _heyb_, --, --, 
   {{0x66e49281,0xe28400c7,0x1cac0327,0x00000000}},	//   _зона, елеи, _ཕྲས_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x67243fae,0x0b240327,0xd12c0133,0x00000000}},	//   _ikkj, _ལེནྜ_, ڕمه_, --, 
   {{0xdfd8016c,0xdee80092,0x00000000,0x00000000}},	//   зъи_, ሄዱን_, --, --, 
   {{0x644c0cad,0x2d8c062c,0x75f400e5,0x00000000}},	//   _igbi, euee_, _tüzé, --, 
   {{0x62649282,0x53980302,0x5d640d97,0x6134045f}},	//   _سارق, _מילו, нтоз, wâld, 
   {{0x316c0489,0xdce0110c,0x0b7c0023,0x25b003cb}},	//   _gwez_, _svođ, _ኖርወይ_, nwyl_, 
   {{0x55941a4c,0xdbdc0248,0x6064007b,0x4a8000dc}},	//   עדיע_, _fíìm, _أهال, _āhuḥ_, 
   {{0x644c01f2,0xdb081a06,0x6134045f,0x2d8c00ad}},	//   _mgbi, _asfá, râld, auee_, 
   {{0x680c01d3,0x00000000,0x00000000,0x00000000}},	//   ződé, --, --, --, 
   {{0x2d8c0076,0x644c0248,0x0ba00150,0x00000000}},	//   cuee_, _ogbi, _ұшым, --, 
   {{0x644c9283,0xed8801ec,0x00000000,0x00000000}},	//   _ngbi, _ісік_, --, --, 
   {{0xdce00989,0x8cb80677,0x00000000,0x00000000}},	//   _uvođ, _זצוק, --, --, 
   {{0x644c9284,0xd59800b5,0x2bdc012c,0xd5140248}},	//   _agbi, _kgへ_, खहरू_, _ọ̀k, 
   {{0x34940588,0x644c0327,0x3a2803e0,0xba18009f}},	// [b4b0] каар, _bgbi, _uyap_, _زيدا_, 
   {{0x799c0218,0x1cac031c,0x67249285,0xda7000d1}},	//   mtsw, _ཕིས_, _ekkj, _جۇڭخ, 
   {{0x799c9286,0x07a40014,0xa7380150,0x38341608}},	//   ltsw, _یمیُ, _ﺣﯟﺍﯓ_, _шнор, 
   {{0xf67804ac,0x799c9287,0x644c0ca8,0x93240150}},	//   _קאָמ, otsw, _egbi, رران, 
   {{0x799c9288,0xb9ec02d3,0x823400f2,0x00000000}},	//   ntsw, _ሕነ_, هرها, --, 
   {{0x799c4431,0xa1540063,0x64b000cf,0x00000000}},	//   itsw, њају_, _ۅڭۅر, --, 
   {{0x026403e6,0x1cac031c,0xdfcc1913,0xbf6401c8}},	//   _ڕێنێ, _ཕྲེ_, قيو_, هديو, 
   {{0x2d8c9289,0xad58928a,0xaec409a0,0x00000000}},	//   tuee_, мрох_, тбил, --, 
   {{0x7bdc928b,0x799c0211,0x31c001d9,0x2d8c0270}},	//   ärun, jtsw, _خۅشہ, uuee_, 
   {{0x952c03bd,0x82340491,0x7ce401e1,0xbda4009f}},	//   _ཨེསི_, _إرفا, _oòru, احيو, 
   {{0x799c928c,0xdbdc0241,0x4ee402bf,0x3f9c0306}},	//   etsw, _fíím, _підз, ctvu_, 
   {{0x2a700050,0x799c928d,0x2d8c013f,0x49b400c7}},	//   _qeyb_, ftsw, puee_, гәоу, 
   {{0x2d8c928e,0x8fc00022,0x00000000,0x00000000}},	//   quee_, _шаҧҵ, --, --, 
   {{0x765c928f,0xe6c81a55,0x888400f2,0xa7a800db}},	//   _afsy, ाञ्ज, دیدن, мкга_, 
   {{0xa6940640,0x799c017a,0x6ea012eb,0x00000000}},	//   крај, atsw, क्थु, --, 
   {{0x799c9290,0x7ce401ab,0xbb280ed1,0x9af000cf}},	//   btsw, _dòru, ﻣﯩﻦ_, _ۅكۉت, 
   {{0x799c0c8c,0x7afc0023,0x7a4800de,0x6498155b}},	// [b4c0] ctsw, ërte, _cītī, дтер_, 
   {{0x7ce40228,0x25b00591,0x6ea000dc,0x00000000}},	//   _fòru, rwyl_, क्तु, --, 
   {{0xe2989291,0x25b00368,0x377401ee,0x38040117}},	//   дае_, swyl_, _йыяс, _боэҳ, 
   {{0x7ce40ba1,0xa1849292,0x141400c6,0x00000000}},	//   _hòrt, выкл, خيمة_, --, 
   {{0xa3b4012c,0x3ea0002e,0x00000000,0x00000000}},	//   जिङ_, _ñiti_, --, --, 
   {{0x1fa4267c,0x00000000,0x00000000,0x00000000}},	//   вриг, --, --, --, 
   {{0x7ce4180f,0xdef80209,0x00000000,0x00000000}},	//   _mòrt, дып_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x1cac0003,0xaad40864,0xa0b401fe,0x00000000}},	//   _ཕྲུ_, धानक, _аҳлу_, --, 
   {{0x5cc49293,0x799c0218,0x7bdc005b,0x00000000}},	//   тсиз, vtsw, äruo, --, 
   {{0x200800fd,0x4e1400f2,0x00000000,0x00000000}},	//   _äbi_, فتید_, --, --, 
   {{0x799c9294,0x7ce462a3,0x3f58003e,0xc8c80014}},	//   ttsw, _aòrt, _iéu_, ۆوُن_, 
   {{0x1db406ff,0x799c478b,0x61340356,0xaae44e10}},	//   _अनित, utsw, câlc, اسپو, 
   {{0x799c127b,0xdb080008,0x6d7400a2,0xb7880bd6}},	//   rtsw, _erfð, _çalỳ, нәме_, 
   {{0x2d800053,0x799c0c8c,0x7ce401c3,0xdb1803b2}},	//   _āhei_, stsw, _dòrt, lvtí, 
   {{0xcb080150,0x799c035a,0x1db49295,0x9a8400c0}},	//   _ليىن_, ptsw, _अनात, _рукл, 
   {{0x7ce4180f,0x5b000075,0x05740a11,0x7d080076}},	// [b4d0] _fòrt, _مېھم, لالد, oids, 
   {{0x7d0801fa,0x04f416ab,0x44f40024,0x7ce401e1}},	//   nids, азую, апус, _tòru, 
   {{0x6ef49296,0x84240131,0x59c81be1,0x478400db}},	//   _hábe, لىكن, ामकर, _кыяб, 
   {{0xd584168d,0x7d089297,0xaad46ace,0x6ef47448}},	//   _لێره_, hids, धायक, _kábe, 
   {{0x7d0802d0,0x81f80014,0x00000000,0x00000000}},	//   kids, نہٲر_, --, --, 
   {{0xded402d3,0xf0740f31,0x7ce401ab,0x82340736}},	//   ርዳእ_, ایاں_, _mòrs, جرما, 
   {{0x3f5806ed,0x5344497c,0xd34001ed,0xfd640208}},	//   _céu_, _ахаа, _نفسی, _truờ, 
   {{0x3f5800f7,0xa2c80490,0x00000000,0x00000000}},	//   _déu_, _सोप्, --, --, 
   {{0x7d080009,0x6ef40419,0x3134014b,0x00000000}},	//   fids, _nábe, _беар, --, 
   {{0x3f5800cf,0x7d080b4f,0x40940c75,0xdbf000fd}},	//   _féu_, gids, _ەلەر, kşäm, 
   {{0x6e940b24,0x00000000,0x00000000,0x00000000}},	//   _ملاا, --, --, --, 
   {{0x6a849298,0x940403be,0x6ef49299,0xa3b405f9}},	//   ылма, ünə_, _bábe, ड़ित_, 
   {{0x6f08068f,0x7ce4929a,0xa2c806e3,0xccf40150}},	//   miec, _còrs, _सोफ्, _ақп_, 
   {{0x6f0800da,0xf1b805be,0xdb080139,0xa2c80490}},	//   liec, _msš_, _asfä, _सोन्, 
   {{0x5d100a81,0xdc9804ae,0x9d1802e4,0x7bdc8ebc}},	//   _دِوا, _ניקל, _אוסט, ørut, 
   {{0x6f08929b,0x6d40036b,0x1cd400c7,0x7ce401ab}},	//   niec, lmla, _адәы_, _fòrs, 
   {{0x7ce4067c,0x5a60010b,0xe6180982,0x6d40017a}},	// [b4e0] _tòrt, _укыб, хда_, omla, 
   {{0xa3f407e6,0x620403b9,0x18a00408,0x00000000}},	//   ляеш, _üslə, _лаьм, --, 
   {{0x2908929c,0x6f08929d,0x6ef401f1,0x228400f7}},	//   miba_, kiec, _zábe, гулг, 
   {{0x2908929e,0x3f580120,0x6d40929f,0x6ef400e5}},	//   liba_, _réu_, hmla, _lább, 
   {{0x3f58008c,0x6f0892a0,0x6d4001d5,0x98a401e4}},	//   _séu_, diec, kmla, ŝiĥa_, 
   {{0x290808e7,0x6ea04438,0x00000000,0x00000000}},	//   niba_, क्सु, --, --, 
   {{0x6d5c92a1,0x6d408ef1,0x6f08068c,0xdfa400c6}},	//   ísan, dmla, fiec, احتي, 
   {{0x81ac0c58,0x290892a2,0x3f580798,0x44380010}},	//   গিব_, hiba_, _véu_, _izr_, 
   {{0x290892a3,0x2168013e,0x44380205,0x1278010f}},	//   kiba_, _чизи_, _hzr_, _ראמע, 
   {{0x614401a9,0x290892a4,0x00000000,0x00000000}},	//   _сеза, jiba_, --, --, 
   {{0x6f0892a5,0x290892a6,0x7d081654,0x6ef4056a}},	//   biec, diba_, rids, _sábe, 
   {{0x7d082165,0x7ce492a7,0x6f0892a8,0x6d4003e0}},	//   sids, _còrr, ciec, amla, 
   {{0x7d0892a9,0x58846feb,0xdbdc0241,0xcb08009d}},	//   pids, лыва, _díám, ухэд_, 
   {{0x290892aa,0x6d4000f3,0x6ef402f0,0x7d080009}},	//   giba_, cmla, _vábe, qids, 
   {{0x94840220,0xcc74011a,0x00000000,0x00000000}},	//   ғызд, _גגות_, --, --, 
   {{0x7ce4067c,0x6ef402d2,0x00000000,0x00000000}},	//   _gòrr, _tábe, --, --, 
   {{0x443892ab,0x45d40a5b,0xf8a401af,0x00000000}},	// [b4f0] _azr_, ботс, _кѳнү, --, 
   {{0x2908102c,0xdb080036,0x6f08033f,0x875c00c7}},	//   ciba_, _opfë, ziec, _ẽreí, 
   {{0x325492ac,0x00000000,0x00000000,0x00000000}},	//   авер, --, --, --, 
   {{0xd6d892ad,0x44380589,0x6d40036b,0x12840424}},	//   _что_, _dzr_, zmla, امشی_, 
   {{0x4438014b,0x6d4009a5,0xe194009d,0x00000000}},	//   _ezr_, ymla, илцө, --, 
   {{0x6f0892ae,0x43840131,0xf1b80010,0x00000000}},	//   wiec, شلۇق, _vsš_, --, 
   {{0x6f080029,0x8d2400d1,0x6d4001d5,0x6e9492af}},	//   tiec, һниң_, vmla, للغا, 
   {{0x6ef4003a,0x6b6000ef,0x2ee4009d,0x00000000}},	//   _sább, _jēge, ржиг, --, 
   {{0xee3892b0,0x6ea00882,0x290892b1,0x1cac031c}},	//   ъни_, क्षु, yiba_, _ཕྲང_, 
   {{0x6f0800a9,0x7ce4068c,0x3134267c,0x71400137}},	//   siec, _sòrr, _тезр, _بۉتۅ, 
   {{0x6f0892b2,0x6d4092b3,0x2fd84e10,0x7ce4067c}},	//   piec, rmla, _جواد_, _pòrr, 
   {{0x6d40036b,0x29081ab4,0x1f580375,0x6f080175}},	//   smla, wiba_, _סדנא, qiec, 
   {{0x290892b4,0x0d6402f6,0x7c380165,0x7afc036e}},	//   tiba_, _съем, _ezvr, ërta, 
   {{0x1cac025c,0xbf6400cf,0x6ea0085c,0x2d8c0076}},	//   _ཕིག_, _ئدەو, क्रु, mree_, 
   {{0x7ce400a3,0x66e40107,0x00000000,0x00000000}},	//   _tòrr, аова, --, --, 
   {{0x81ac04c5,0x273c002d,0xa6c802e8,0x00000000}},	//   গিত_, iïng_, ълба_, --, 
   {{0x443800f3,0xe8f879e4,0x2d8c062c,0xe9d892b5}},	// [b500] _szr_, _алп_, nree_, _ркп_, 
   {{0x2d8c92b6,0x290801b3,0x9a380375,0x44380790}},	//   iree_, qiba_, _בתפק, _pzr_, 
   {{0x2d8c92b7,0xaad80210,0x00000000,0x00000000}},	//   hree_, _बचाक, --, --, 
   {{0x2d8c92b8,0xe5783da1,0x21682d57,0x225003cd}},	//   kree_, _изм_, види_, øyk_, 
   {{0x6d8c0084,0x6d5c92b9,0xd1b40c4f,0x00000000}},	//   _ṱang, ísal, لاوا_, --, 
   {{0x443892ba,0x90940212,0xa2a402db,0xd46400f3}},	//   _tzr_, ивіт_, _टॉर्, _вире_, 
   {{0x44387885,0x4fb0007b,0x2d8c343b,0x00000000}},	//   _uzr_, قصير, eree_, --, 
   {{0x2d8c92bb,0x1cac0135,0x63ac0175,0x9754011a}},	//   free_, _ཕིང_, _ipbn, סיפו_, 
   {{0xf1a848c1,0x29180113,0x2d8c92bc,0x6ed81411}},	//   _ماله_, _ojpa_, gree_, ادىڭ_, 
   {{0x7ce40ba1,0xa2c807b6,0x9ce4084c,0xbcf40108}},	//   _còrp, _सोत्, рцил, спощ, 
   {{0x2d8c92bd,0x1724031c,0x9e74027d,0x9a7000ec}},	//   aree_, _རྩའམ_, _نهضت, يندڙ, 
   {{0x2d8c92be,0x7ce40192,0x7c3809a8,0xd00c027d}},	//   bree_, _eòrp, _vzvr, _تلم_, 
   {{0x4ef80bd9,0x2d8c0afa,0xc98401a9,0x00000000}},	//   _בלאג, cree_, жуси, --, 
   {{0x201c0139,0x00000000,0x00000000,0x00000000}},	//   _kxti_, --, --, --, 
   {{0x7c380989,0xad240372,0x9a8492bf,0x36d40117}},	//   _uzvr, _ارنو, _купл, бовр, 
   {{0x3a7405f5,0xdb0801c7,0x95c80166,0x5018011a}},	//   _улир, _opfé, куза_, דולו, 
   {{0x3b080869,0xa2c8012c,0x9644009d,0x00000000}},	// [b510] _imaq_, _सोध्, рэвд, --, 
   {{0x6ef400d2,0x3ab400fb,0x00000000,0x00000000}},	//   _mába, _тәүт, --, --, 
   {{0x6134084c,0x65640204,0x3b080066,0x78b492c0}},	//   tâln, _etkh, _kmaq_, mezv, 
   {{0x6fc492c1,0x1db492c2,0x2d8c0363,0x00000000}},	//   विसं, _अनंत, yree_, --, 
   {{0x058420e5,0x6ef492c3,0x3b080194,0x313428e8}},	//   _мурм, _nába, _mmaq_, бедр, 
   {{0x78b4006f,0x6d5c92c4,0x92d4015b,0x2d8c062c}},	//   nezv, ísam, িসে_, vree_, 
   {{0x213c00a3,0x920000e2,0x2d8c526b,0xf318030d}},	//   _dhth_, _šādu, wree_, _бовш_, 
   {{0x2d8c92c5,0x2d9492c6,0xdb1800b5,0x116400f1}},	//   tree_, брос, lvtæ, _نلری_, 
   {{0x6ef404d4,0x201c003a,0xfbe40154,0x2d8c0363}},	//   _cába, _exti_, _ফেলত, uree_, 
   {{0x2d8c92c7,0xdfa400b2,0x6ef40005,0xa3ac0037}},	//   rree_, _ڇڏيو_, _dába, _कहम_, 
   {{0x7ff492c8,0x0cb407f7,0x78b492c9,0x2d8c0810}},	//   _وسما, _असीम, dezv, sree_, 
   {{0xa9687f50,0xb60800de,0xff0801f4,0x0c5c0240}},	//   лима_, _kašķ, äätä_, _ተዓጽዩ_, 
   {{0x6ef40077,0x78a892ca,0x2d8c022f,0x00000000}},	//   _gába, đevn, qree_, --, 
   {{0xeb986833,0x6d5803ac,0xac9802cb,0x984c0205}},	//   _бик_, _iuwa, _صنعا_, _aşım_, 
   {{0x6d5892cb,0x6ef403c6,0x186401b9,0x00000000}},	//   _huwa, _zába, саси_, --, 
   {{0x6d58615a,0x7b640014,0x6ef40083,0xa3ac00af}},	//   _kuwa, _باوٕ, _yába, _कहब_, 
   {{0x6d5892cc,0x232802a9,0xb60800de,0x00000000}},	// [b520] _juwa, қоди_, _našķ, --, 
   {{0x6d5892cd,0x200003b9,0xdb0401e1,0xe4540798}},	//   _muwa, _əkib_, _ìmòl, стаќ, 
   {{0x6d5892ce,0xa908004b,0xdc340139,0x00000000}},	//   _luwa, _ليکل_, _mäğk, --, 
   {{0xe5a444e4,0xe1f892cf,0x6d5808e7,0xc29401d5}},	//   _лими, лге_, _ouwa, تیرب, 
   {{0x26c004b9,0x6d5892d0,0x758002dd,0x1a98010f}},	//   _iako_, _nuwa, _оңта, רינע, 
   {{0xa508529e,0x26c092d1,0x217401d5,0xdfa4007b}},	//   _сега_, _hako_, _ҳужр, محبي, 
   {{0x6ef4748d,0x6d5892d2,0xdb1c00d7,0x908400db}},	//   _sába, _auwa, _švík, حنىك_, 
   {{0x26c092d3,0x6d5892d4,0x23280e92,0x6ab0033f}},	//   _jako_, _buwa, _соби_, ज़ोर, 
   {{0x26c092d5,0x6d5892d6,0xdee4039b,0x78b48dc8}},	//   _mako_, _cuwa, _қоди, yezv, 
   {{0x26c092d7,0x6d5892d8,0xdcb83cc5,0x1ec801ec}},	//   _lako_, _duwa, ущи_, _әлди_, 
   {{0x78b492d9,0x7afc02d3,0x50540014,0x6d5892da}},	//   vezv, ërto, _أمس_, _euwa, 
   {{0x26c07d49,0x6ef4011f,0x6d5892db,0x78b4006f}},	//   _nako_, _tába, _fuwa, wezv, 
   {{0x6d5892dc,0x78b492dd,0xdb1c0174,0x00000000}},	//   _guwa, tezv, _ávík, --, 
   {{0x26c092de,0x78a801a6,0xf868007b,0x78b4030a}},	//   _aako_, đevo, شمري_, uezv, 
   {{0x6d5892df,0x78b492e0,0x8af006be,0x80b000bc}},	//   _zuwa, rezv, _biəd, _आउने, 
   {{0x6d58094a,0x78b40099,0xcb643cc6,0x26c00200}},	//   _yuwa, sezv, _اميه_, _cako_, 
   {{0x26c092e1,0x6d580548,0xaad41fd2,0x630c0154}},	// [b530] _dako_, _xuwa, धारक, িকায়_, 
   {{0x26c092e2,0xd7f82d08,0x89dc0375,0x00000000}},	//   _eako_, _бум_, _תחזי, --, 
   {{0x26c092e3,0xb60800e2,0x46c41fc4,0xa2c800bc}},	//   _fako_, _sašķ, _लोकह, _सोह्, 
   {{0x26c092e4,0x6d5c00d2,0x964401c6,0x6b6000de}},	//   _gako_, ísak, _гэгд, _jēga, 
   {{0xfa20001f,0x08f80214,0x00000000,0x00000000}},	//   _ደንበኞ, _ضریب_, --, --, 
   {{0x6d5892e5,0x26c092e6,0x0cb401ad,0xca3c0150}},	//   _ruwa, _zako_, _असेम, _ﺒﺎﺴ_, 
   {{0x17244933,0x26c092e7,0x43947510,0xf2c40cef}},	//   _རྩོམ_, _yako_, _нарс, _мөди, 
   {{0xa3ac033d,0x6d5892e8,0xb2743e4f,0x2d8800d1}},	//   _कहत_, _puwa, _флаш, айип_, 
   {{0x6d5892e9,0x00000000,0x00000000,0x00000000}},	//   _quwa, --, --, --, 
   {{0x3940009a,0xff08023a,0x7afc002f,0xc10401c8}},	//   _nhhs_, äärä_, ehst, _فوقي, 
   {{0xd0180395,0x00000000,0x00000000,0x00000000}},	//   _сфа_, --, --, --, 
   {{0x6d5892ea,0x7afc92eb,0xab2892ec,0x955c02d3}},	//   _tuwa, ghst, рома_, ዳእታን_, 
   {{0x26c092ed,0x6ef401ed,0xeb98084c,0x6d5802d0}},	//   _rako_, _hábo, _ӂий_, _uuwa, 
   {{0x26c092ee,0x00000000,0x00000000,0x00000000}},	//   _sako_, --, --, --, 
   {{0x7cc40214,0x7afc00a3,0xeb98005a,0x18a0035b}},	//   _رزوم, bhst, _тий_, ьарм, 
   {{0x7afc92ef,0xe69407d6,0x00000000,0x00000000}},	//   chst, تلرد, --, --, 
   {{0x26c092f0,0x6d5c0ab9,0x6ef400e5,0x00000000}},	// [b540] _vako_, ísah, _lábo, --, 
   {{0x26c092f1,0x15400150,0x00000000,0x00000000}},	//   _wako_, деум, --, --, 
   {{0x6ef492f2,0xe73892f3,0xe3b892f4,0x394c0ea0}},	//   _nábo, _вен_, рбе_, ïese_, 
   {{0x1cac003d,0x26c01132,0x7d000248,0xded4010c}},	//   _ཕྲན_, _uako_, _kárù, ርታን_, 
   {{0xdce008a4,0xc5f8052f,0x91e0020f,0x673400a2}},	//   _stoč, _уға_, моце, mlyj, 
   {{0x6ef492f5,0x81ac0729,0x6734448d,0x7d000ca8}},	//   _bábo, গিল_, llyj, _márù, 
   {{0xaac839d7,0xa3ac00af,0x53a0084c,0xdb180158}},	//   ियाक, _कहि_, _оарб, lvtå, 
   {{0xdda81271,0x7bc8031c,0x67340432,0x00000000}},	//   атол_, vvdu, nlyj, --, 
   {{0xe0d86ff7,0x673401f4,0x60b4007b,0x716400ae}},	//   _ква_, ilyj, _ومرئ, _فالك, 
   {{0xa3ac14cf,0x6ef40789,0xdb0c01e1,0x00000000}},	//   _कहा_, _hábl, _íjús, --, 
   {{0x7afc92f6,0x28dc2977,0x7d000241,0xdce005ce}},	//   thst, मानि, _aárù, _utoč, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6ef492f7,0x32b80327,0x78a0067c,0x5884121c}},	//   _zábo, _ཛྲསྐ, òlvo, жыба, 
   {{0xd90c4f6f,0x7afc03ac,0x00000000,0x00000000}},	//   ئید_, shst, --, --, 
   {{0x98380020,0x36d47f55,0x6ea092f8,0x386c0115}},	//   _በትምህ, повр, क्कु, ĝer_, 
   {{0x8b240640,0xa2c8257b,0x7bdc005b,0x3a74074d}},	//   _одје, _सोल्, äruu, _элир, 
   {{0xb90000fe,0xd498009d,0x00000000,0x00000000}},	// [b550] _দত_, ирж_, --, --, 
   {{0x44b46c00,0x67340064,0x98a00171,0x00000000}},	//   мбус, alyj, bojā_, --, 
   {{0x1cac0135,0x04c8088c,0x00000000,0x00000000}},	//   _ཕིན_, تولي_, --, --, 
   {{0x0cb4739b,0x248806d9,0x85300198,0x6ef400c6}},	//   _अस्म, _edbm_, ruɗa, _cábl, 
   {{0xc2c43592,0x672802d2,0x46c40037,0x00000000}},	//   بيني, _ífja, _लोटह, --, 
   {{0xc1040472,0x00000000,0x00000000,0x00000000}},	//   ووني, --, --, --, 
   {{0x3cf001f9,0x00000000,0x00000000,0x00000000}},	//   ेसने_, --, --, --, 
   {{0x2d9431df,0xd1b892f9,0xff080108,0x00000000}},	//   прос, _پارا_, ääpä_, --, 
   {{0x709401f0,0x00000000,0x00000000,0x00000000}},	//   _нааф, --, --, --, 
   {{0xeb98026a,0x6ef40306,0x00000000,0x00000000}},	//   био_, _zábl, --, --, 
   {{0xc1041e95,0xa3b4000d,0x8e540408,0xa3dc1bbb}},	//   _تولي, ड़िए_, _мĕнл, तमय_, 
   {{0x273c0bc9,0x28dc726b,0xdd8c84d2,0x6ea000cd}},	//   kïna_, माभि, خوی_, क्खु, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x18640364,0x291c92fa,0xdca01d5b,0x9ac00135}},	//   зари_, õta_, _заши, _ċċel, 
   {{0x6ef400e5,0x7bdc007c,0x00000000,0x00000000}},	//   _lábm, ärut, --, --, 
   {{0x9f5401ed,0x98a000e2,0xdaa000db,0x00000000}},	//   ógép_, rojā_, _كەپپ, --, 
   {{0x28b800a8,0x00000000,0x00000000,0x00000000}},	// [b560] _лунэ_, --, --, --, 
   {{0x6ef401ef,0x00000000,0x00000000,0x00000000}},	//   _sábl, --, --, --, 
   {{0x6ebc3cbe,0x00000000,0x00000000,0x00000000}},	//   ्याँ, --, --, --, 
   {{0xe29892fb,0xd36c3738,0x73940212,0x00000000}},	//   сад_, اهن_, ьшує, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd12c11e6,0x00940276,0x00000000,0x00000000}},	//   همن_, фикэ, --, --, 
   {{0x6ef4374c,0x15400139,0x00000000,0x00000000}},	//   _tábl, _черм, --, --, 
   {{0x9db40003,0x6ef4032e,0xe1f800f3,0x27fc00d7}},	//   _དགྱེ, _hábj, _лгб_, útny_, 
   {{0x205492fc,0x9cc892fd,0xe1f892fe,0xa6e400cc}},	//   _етер, бына_, _уга_, নসপট, 
   {{0xb3081f21,0x00000000,0x00000000,0x00000000}},	//   _གཏོང_, --, --, --, 
   {{0xe8b8025c,0x508400f1,0x00000000,0x00000000}},	//   _བྲེག, _رالې, --, --, 
   {{0x23bc0316,0x628092ff,0xd00c00c6,0x00000000}},	//   _můj_, naoo, _حلم_, --, 
   {{0xc8c800af,0x62800421,0x7ed400db,0x00000000}},	//   िएंट, iaoo, _ىزچا, --, 
   {{0x7bdc007d,0x62800009,0x200003e3,0xadb4009f}},	//   ärus, haoo, _əkin_, _آڇيا_, 
   {{0x9b68173e,0x62805318,0x6d5c1897,0xa8540ce8}},	//   _ушла_, kaoo, ísav, дерә, 
   {{0x70b858c1,0x8c1804ae,0x8c34011a,0x00000000}},	//   _इस्ल, _לווי, _מטוס_, --, 
   {{0x5c640023,0x95c80395,0xaac80118,0x00000000}},	// [b570] _ተሓድሶ_, щува_, ियरक, --, 
   {{0x28dc1a47,0xa9b4009f,0x00000000,0x00000000}},	//   माणि, _آشيڪ, --, --, 
   {{0xccf000c8,0x273c0054,0x62800421,0xcfa80150}},	//   עכע_, sïna_, faoo, _ﺴﻴﺎﻗ, 
   {{0xa3ac1533,0x7afc0023,0x6280011f,0x28dc012c}},	//   _कहर_, ërth, gaoo, माथि, 
   {{0xdd849300,0x2d900034,0x6ef402d2,0x95c8009d}},	//   _جو_, ązek_, _fábj, _ууна_, 
   {{0xc2441ed2,0x6b600171,0xf0e80116,0x00000000}},	//   хнік, _bēgl, تىتى_, --, 
   {{0xa1f00131,0x6b6000ef,0x00000000,0x00000000}},	//   ىۋېت, _rēgo, --, --, 
   {{0x92a800cc,0x00000000,0x00000000,0x00000000}},	//   _কোৰ_, --, --, --, 
   {{0xd24401c0,0x7124215c,0x00000000,0x00000000}},	//   _хэви, _قىرم, --, --, 
   {{0x7ce40100,0x61f42dba,0x00000000,0x00000000}},	//   _kòry, øyle, --, --, 
   {{0xeab89301,0x009401c0,0x00000000,0x00000000}},	//   ойн_, _чихэ, --, --, 
   {{0x3e6002b1,0x00000000,0x00000000,0x00000000}},	//   tōtō_, --, --, --, 
   {{0xb4bc256a,0xae041df2,0x6bd4009f,0xc60c000d}},	//   _आसू_, _توشى, ستگر, _सेंठ_, 
   {{0xa3ac033d,0xad24167e,0x28dc00cd,0xfe240354}},	//   _कहल_, _تىتى, माधि, _яьхн, 
   {{0xfd5400cd,0x00000000,0x00000000,0x00000000}},	//   _nigṛ, --, --, --, 
   {{0x98b000e2,0x628000e8,0x00000000,0x00000000}},	//   īcās_, xaoo, --, --, 
   {{0x24e80364,0xdb080077,0xa9240fc0,0x28dc63d3}},	// [b580] омаи_, _esfó, _одил, मादि, 
   {{0x6ef400d0,0xb3080327,0x00000000,0x00000000}},	//   _bábk, _གཏུང_, --, --, 
   {{0xf364005e,0x316c01c6,0xa2e400f3,0x66580354}},	//   етін, _atez_, можд, _манă, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7afc044e,0x6280058a,0xca3c02dd,0x00000000}},	//   ërti, raoo, _ﺒﺎﺏ_, --, 
   {{0x6ef400c6,0xdb1804e6,0x00000000,0x00000000}},	//   _hábh, rwté, --, --, 
   {{0xcc900150,0x00000000,0x00000000,0x00000000}},	//   _ﻛﯘﺯﮔ, --, --, --, 
   {{0x78a804b9,0xd24c01e2,0x00000000,0x00000000}},	//   đevi, اچې_, --, --, 
   {{0x44389302,0x7ce40100,0x3d0001e1,0x00000000}},	//   _hyr_, _zòry, _lòwe_, --, 
   {{0x44389303,0x61e00921,0xdb1821e3,0x00000000}},	//   _kyr_, mxol, lvtø, --, 
   {{0x60d802d0,0x8d7007d6,0xd4940375,0x61e0022e}},	//   _intm, _یاوا, וכית_, lxol, 
   {{0x443802a4,0xdde89304,0x8d700131,0x6ef401e7}},	//   _myr_, _ورشه_, راۋا, _nábh, 
   {{0x81ac1c82,0x3f9c9305,0x44389306,0x61e09307}},	//   গিক_, luvu_, _lyr_, nxol, 
   {{0xa3dc038e,0x61e00077,0x44380731,0x38349308}},	//   तमा_, ixol, _oyr_, енгр, 
   {{0x6ef40332,0x81b40154,0x88580022,0x8bc001af}},	//   _bábh, জটি_, дирс_, _асыд, 
   {{0xdb08180f,0x1dd08109,0x00000000,0x00000000}},	//   _esfò, तिपत, --, --, 
   {{0x60d8225e,0x44381368,0x7aec003a,0x996401b9}},	// [b590] _ontm, _ayr_, _ioat, _ўтил, 
   {{0x7aec9309,0x4438930a,0x3f9c2f99,0x799c930b}},	//   _hoat, _byr_, kuvu_, musw, 
   {{0x7aec930c,0x799c930d,0x4438930e,0x78a40100}},	//   _koat, lusw, _cyr_, _ichv, 
   {{0x443828b3,0x7aec05f5,0x3f9c930f,0x7ce40100}},	//   _dyr_, _joat, duvu_, _vòry, 
   {{0x7aec9310,0x799c9311,0x7d080006,0x61e04b2a}},	//   _moat, nusw, _kūrė, gxol, 
   {{0x7aec1311,0x3f9c009f,0x1cc8031c,0xc0c80063}},	//   _loat, fuvu_, ྲབས_, дуће_, 
   {{0x6ef49312,0x3f9c1446,0x2f549313,0x799c9314}},	//   _hábi, guvu_, нтис, husw, 
   {{0x7aec9315,0xb308081f,0x60d89316,0x6ef40241}},	//   _noat, _གཏིང_, _entm, _kábi, 
   {{0xdd8c9317,0x26dc013f,0x78a4014f,0x7a4800de}},	//   موي_, _ɑto_, _ochv, _jūtī, 
   {{0x7aec0618,0x7c38017a,0xeb980640,0x7d0800e4}},	//   _aoat, _byvr, пио_, vérõ, 
   {{0x6ef49318,0x3f9c0286,0x28dc278e,0x7aec9319}},	//   _lábi, cuvu_, मासि, _boat, 
   {{0x78a403ac,0x7aec931a,0x257401e1,0x6d5c0162}},	//   _achv, _coat, _jùlò_, ísas, 
   {{0xaeb80156,0x799c931b,0x7aec0072,0x2bb0007d}},	//   _དྲགོ, gusw, _doat, _जहवा, 
   {{0x6ef40597,0xdd8c00f1,0x65c800e4,0x3d0001e1}},	//   _sábh, _اوو_, hêhá, _pòwe_, 
   {{0x7aec931c,0xfc640801,0x6ef401e7,0x799c002f}},	//   _foat, _ръчн, _pábh, ausw, 
   {{0x7aec931d,0x78a40455,0xdbd800e8,0x799c51b0}},	//   _goat, _echv, _gàñc, busw, 
   {{0x4438931e,0x799c03ac,0x00000000,0x00000000}},	// [b5a0] _syr_, cusw, --, --, 
   {{0x2ebc53c3,0x4438931f,0x64c4470b,0x4aac185b}},	//   ्युत, _pyr_, عيال, ट्रव, 
   {{0x6ef40597,0x7b0801b8,0x44380076,0xa5f8022e}},	//   _tábh, _ästü, _qyr_, _o想ga, 
   {{0x6ef49320,0x3f9c311e,0x44380024,0xf2c402dd}},	//   _fábi, vuvu_, _vyr_, ксін, 
   {{0x75340354,0x443803cb,0x6ef4013a,0x00000000}},	//   _fkzz, _wyr_, _gábi, --, 
   {{0x44389321,0x3f9c9322,0x61e09323,0x00000000}},	//   _tyr_, tuvu_, rxol, --, 
   {{0xb86c0092,0xbe84024c,0x9fcc00eb,0x00000000}},	//   ሻንጉል_, вқеи, িঙ্গ, --, 
   {{0x799c9324,0xd84002f0,0x00000000,0x00000000}},	//   yusw, _hučí_, --, --, 
   {{0xe1f807d6,0x7aec9325,0x9cc83f6e,0x799c014b}},	//   _эга_, _roat, пына_, xusw, 
   {{0x7aec9326,0x799c2a73,0x00000000,0x00000000}},	//   _soat, vusw, --, --, 
   {{0x7aec1142,0x799c9327,0x645803f2,0x6d5c0bcd}},	//   _poat, wusw, _útid, ísar, 
   {{0x78a40232,0x7c380122,0x799c9328,0x1418008f}},	//   _schv, _vyvr, tusw, לויב, 
   {{0x7aec1311,0xdc1006b9,0x61340194,0xace800ec}},	//   _voat, rşım, sâlu, _ڪرنل_, 
   {{0x7aec0134,0x1ca8025c,0x799c9329,0x00000000}},	//   _woat, _བཡི_, rusw, --, 
   {{0x7aec932a,0x7a4800da,0x6ef40120,0x9138008f}},	//   _toat, _sūtī, _sábi, פעלק, 
   {{0x799c02d0,0x36d40395,0x7a480171,0x00000000}},	//   pusw, ъобр, _pūtī, --, 
   {{0x7afc02d3,0x7d080064,0x65c800e4,0x00000000}},	// [b5b0] ërtu, _tūrė, vêhá, --, 
   {{0x798c7acd,0xa3e00034,0x78a402fb,0x6ef455c8}},	//   _ivaw, _गपशप_, _uchv, _vábi, 
   {{0x80a42f2e,0x28dc78bf,0x478401ee,0x00000000}},	//   च्छे, मारि, _йыяб, --, 
   {{0x91bc2871,0x8234932b,0x6ef40ca8,0x00000000}},	//   _एनआई, گرما, _tábi, --, 
   {{0x3f8c01fa,0x00000000,0x00000000,0x00000000}},	//   _avdu_, --, --, --, 
   {{0x8234932c,0x6e380368,0x61f42d8b,0x349400d8}},	//   درما, _rywb, øyla, _шагр, 
   {{0xafe4932d,0xbfa80063,0xa3ac000d,0x00000000}},	//   тойл, етње_, _कहए_, --, 
   {{0x2ebc0882,0x798c02d0,0x201800d0,0x00000000}},	//   ्येत, _ovaw, úpia_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7c240882,0x48ac00fe,0xe7f40118,0x00000000}},	//   _śira, _চফ্ৰ, ीनमा_, --, 
   {{0xab28932e,0xc0bc044e,0x798c0810,0xdb080221}},	//   дона_, ቲኦም_, _avaw, _opfä, 
   {{0x6458932f,0xf1b80010,0xd5b00073,0x37b80154}},	//   _útie, _kpš_, ुबाज, ুমার, 
   {{0x6da49330,0x28dc7f1e,0x1ee800f2,0xada49331}},	//   _рила, मालि, _تونی_, _ралл, 
   {{0xabd41d39,0xeb9800db,0x00000000,0x00000000}},	//   _ациј, _жик_, --, --, 
   {{0x186407d6,0xe7389332,0x798c02d0,0x77740175}},	//   таси_, дев_, _evaw, gpzx, 
   {{0xf1e01a2a,0x00000000,0x00000000,0x00000000}},	//   पमान, --, --, --, 
   {{0xe8101e61,0x96609333,0x7a4802b5,0x6ab4010a}},	// [b5c0] _डेरा_, ркуе, _pūtū, _ibyf, 
   {{0x69d40223,0x80c005d7,0xdedc0023,0x7c3802d2}},	//   _irye, _एसें, _ዕዮን_, _íbré, 
   {{0x798c0433,0x33d4109a,0xf84401c6,0xb400009d}},	//   _zvaw, ліцт, _бүрд_, бүрд, 
   {{0x69d4067d,0x2ebc00dc,0x6ef4299d,0xd36c5dc6}},	//   _krye, ्योत, _kábu, زهه_, 
   {{0x7a489334,0x42540451,0x41b4009f,0x2ebc00cd}},	//   _tūtū, ھنڪر, امتر, ्यैत, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6574023a,0x626401c6,0xe354004e,0x6ef462d5}},	//   lpyh, _авба, _атаэ, _lábu, 
   {{0x69d49335,0x6ab40175,0xa2c892c1,0x2bd400cd}},	//   _orye, _nbyf, _सोच्, धिना, 
   {{0xa06802de,0x64580252,0x3cf0012c,0x77740175}},	//   _жаза_, _útib, ेसले_, zpzx, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69d4159f,0x853003f9,0x3b540117,0x00000000}},	//   _arye, guɗi, лкор, --, 
   {{0x69d403cd,0x00000000,0x00000000,0x00000000}},	//   _brye, --, --, --, 
   {{0x69d49336,0x1278010f,0x00000000,0x00000000}},	//   _crye, ואכע, --, --, 
   {{0x853003f9,0x3dc400b5,0x69d49337,0xd5bc00e2}},	//   buɗi, mwmw_, _drye, šāku_, 
   {{0x69d49338,0x65740072,0x7b1800f3,0x81d80154}},	//   _erye, epyh, _покр_, াহি_, 
   {{0x69d49339,0x672434fe,0x6ef42cd7,0x3ae8036b}},	//   _frye, _cjkj, _fábu, _سببی_, 
   {{0x69d4933a,0x798c02d0,0x00000000,0x00000000}},	// [b5d0] _grye, _uvaw, --, --, 
   {{0x7afc933b,0x73c40daf,0x81d80011,0xa3dc00cd}},	//   lkst, ләбе, াহা_, तमं_, 
   {{0x2bd4068f,0xaaa80da5,0xc270063f,0xf1b802f0}},	//   धिया, _कामक, _ịdọr, _spš_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8b5c0198,0x6fd400cd,0x00000000,0x00000000}},	//   ɓɓuɓ, भिभू, --, --, 
   {{0xa5d800c8,0x2bd426e4,0x05940354,0x6ef400e5}},	//   _אַלי, धिमा, _тăшм, _lábt, 
   {{0x7afc933c,0x386001c3,0xa3dc00dc,0xac8400d1}},	//   kkst, _mghr_, तमः_, ңгил, 
   {{0x349480e2,0x7afc432f,0xaec40124,0xe7f41b76}},	//   _шаҳр, jkst, убил, ीनता_, 
   {{0xed58016c,0x51841246,0x8d240131,0xee380cdd}},	//   нои_, _шува, книң_, эни_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x386000ca,0x69d40076,0xf3f400fe,0x00000000}},	//   _aghr_, _prye, _আধাৰ_, --, 
   {{0xef18025c,0xaaa81bd6,0x00000000,0x00000000}},	//   miż_, _काठक, --, --, 
   {{0xef180e5e,0x2d8c933d,0x7afc933e,0x69d40ea0}},	//   liż_, msee_, akst, _vrye, 
   {{0x2d8c933f,0xa524013e,0xfd100345,0x3cf800e5}},	//   lsee_, ҳмад, _بجن_, örve_, 
   {{0xef18003d,0x6ef40120,0x69d40023,0x2d8c00ad}},	//   niż_, _tábu, _trye, osee_, 
   {{0x2d8c9340,0x69d40309,0x984c001f,0x27fc0010}},	// [b5e0] nsee_, _urye, _በድርጅ, štn_, 
   {{0x2d8c9341,0x776401ab,0xa3b800e5,0x00000000}},	//   isee_, _fuhx, ٹائر_, --, 
   {{0x65740b6f,0x1d14008f,0x23d40276,0x2d8c002f}},	//   spyh, נקער_, ыцар, hsee_, 
   {{0x2d8c9342,0x66e49343,0x20000374,0x5c34008f}},	//   ksee_, _сома, _āki_, ארען_, 
   {{0x69c402c4,0xef180135,0x80c82cc5,0x6ef400e5}},	//   nwke, diż_, লাস্, _lábs, 
   {{0x2d8c6081,0x65640649,0x6734014f,0x1fa4022e}},	//   dsee_, _iukh, loyj, григ, 
   {{0x65640784,0xe2982401,0x7afc9344,0x2d8c6d94}},	//   _hukh, _пав_, ykst, esee_, 
   {{0xa2d486bf,0xef180135,0x2d8c002f,0x7c2400cd}},	//   _حيرت, giż_, fsee_, _śiro, 
   {{0x2d8c9345,0x8d703016,0x00000000,0x00000000}},	//   gsee_, یایا, --, --, 
   {{0x65649346,0xfd1400d8,0x00000000,0x00000000}},	//   _mukh, рмоќ, --, --, 
   {{0x5ea400dd,0x2d8c814f,0xfe1400ab,0xef180327}},	//   _ممال, asee_, _तेरस_, biż_, 
   {{0x2d8c0ba7,0x386000b5,0x7afc00e2,0x00000000}},	//   bsee_, _sghr_, ukst, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x1ee8036b,0x00000000,0x00000000,0x00000000}},	//   _توچی_, --, --, --, 
   {{0x65640161,0x6b600171,0xb6a40116,0x7b8400d1}},	//   _aukh, _bēgu, һиңл, _ئاتە, 
   {{0xc87845a5,0x0b909347,0xc3240ef6,0x6ef402d2}},	//   ığa_, _اجود, _رە_, _hábr, 
   {{0xd4989348,0x05749349,0xb6a400d1,0x65640051}},	// [b5f0] ере_, مالد, лиңл, _cukh, 
   {{0x6564934a,0x236400c8,0x3f9c0fcf,0x93886141}},	//   _dukh, ĉojn_, krvu_, есда_, 
   {{0x20180030,0x799c04cc,0x67343bfb,0xd7f806b4}},	//   úpil_, lrsw, boyj, _чуп_, 
   {{0x2d8c934b,0x65640007,0x0fe447b3,0x2bd429d9}},	//   ysee_, _fukh, ғлиқ_, धिता, 
   {{0x15a807d6,0xef18038f,0xc8c8168d,0xd49803b7}},	//   _яъни_, viż_, _شوێن_, _прв_, 
   {{0x2164301f,0x6ef400d0,0xaf9406ed,0x7bd80254}},	//   шиши_, _nábr, ашиј, _orvu, 
   {{0x6564025a,0x799c0112,0x606000d1,0xef180135}},	//   _zukh, hrsw, زۇنل, tiż_, 
   {{0x2d8c934c,0x80c804c5,0x645803b2,0xa2c00139}},	//   tsee_, লাষ্, _útia, _мәчк, 
   {{0x7bd8033d,0x8338023a,0x3f9c000d,0x90a4007b}},	//   _arvu, _счёт_, arvu_, _محام, 
   {{0x2d8c934d,0x00000000,0x00000000,0x00000000}},	//   rsee_, --, --, --, 
   {{0xeb9834ac,0x799c0373,0x00000000,0x00000000}},	//   ъин_, ersw, --, --, 
   {{0x81d800bd,0xde1417a5,0xa968934e,0x2d8c75d9}},	//   াহর_, اقیت_, кима_, psee_, 
   {{0xfe70030f,0x6f080810,0x69c4282c,0x2c1400c5}},	//   _ردن_, mhec, uwke, _फेरू_, 
   {{0x6f0806ed,0x6564934f,0x2eec16a3,0xa80402e8}},	//   lhec, _rukh, ljef_, азгл, 
   {{0x65640a28,0xfb249350,0x6d409351,0xe718129e}},	//   _sukh, _گروپ, mlla, نيست_, 
   {{0x6f080cfc,0x6ef40122,0x98a40421,0x78a0067c}},	//   nhec, _zábr, āiāa_, òlvr, 
   {{0x6d409352,0x673403b2,0xfb242732,0x00000000}},	// [b600] olla, royj, _دروپ, --, 
   {{0x6d4082b5,0x656406e4,0xa8a42374,0xded40023}},	//   nlla, _vukh, _өрүк, ይታና_, 
   {{0x6d409353,0x6564014b,0x78a0056a,0xd7fc0356}},	//   illa, _wukh, ólve, ţări_, 
   {{0x65649354,0xe2989355,0xe5a49356,0x6d403deb}},	//   _tukh, тад_, _кими, hlla, 
   {{0x6d409357,0x6f0801ab,0x984c0092,0x00000000}},	//   klla, dhec, _በስተጀ, --, 
   {{0x3f9c9358,0x6d401181,0xded40023,0x29080051}},	//   trvu_, jlla, ይዳን_, nhba_, 
   {{0x80c8015b,0x6d4002d0,0x33d400d4,0x00000000}},	//   লাল্, dlla, _літт, --, 
   {{0x6d409359,0x6f083c57,0xf1500014,0xf1a802f2}},	//   ella, ghec, _ہێند, _ڕامه_, 
   {{0x25b00072,0xa0a4026a,0x29080561,0x216802e8}},	//   ntyl_, _вазд, khba_, _ризи_, 
   {{0x61448db9,0x4f840050,0x20c81913,0x6d400200}},	//   _теза, _چانہ, _جبري_, glla, 
   {{0x6f08935a,0x25b00076,0x29080009,0xdb4c0133}},	//   bhec, htyl_, dhba_, وێت_, 
   {{0x6f08935b,0x6d40935c,0x71800022,0x8fa0009b}},	//   chec, alla, _ьқәе, _фаце, 
   {{0x799c05e4,0x26d01418,0x6d40036e,0xfcc401af}},	//   ursw, ddyo_, blla, _ләнм, 
   {{0xcd30208f,0x8238001f,0x6d400113,0x2908935d}},	//   _وروب, _እናስታ, clla, ghba_, 
   {{0xdb0804ce,0x5fc404fa,0x9f4c00b5,0x7bd800c0}},	//   _opfø, लबिल, ryfæ_, _urvu, 
   {{0x4824185e,0x73c40032,0x59a41cd2,0x00000000}},	//   زىقق, ҙәге, कंदर, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [b610] --, --, --, --, 
   {{0x5fc40316,0x26d00067,0x2908014f,0xb4d0043e}},	//   लबाल, adyo_, chba_, वये_, 
   {{0x7a400ca8,0x00000000,0x00000000,0x00000000}},	//   bátú, --, --, --, 
   {{0x970004a9,0x25b0002d,0xd6d8004e,0x00000000}},	//   _بېرى, btyl_, _рто_, --, 
   {{0x6d40935e,0x6458935f,0x25b0062c,0x00000000}},	//   ylla, _útin, ctyl_, --, 
   {{0x6d400227,0x80a80212,0x87d40ed8,0x45d400d8}},	//   xlla, ивів_, _اغیا, _ќорс, 
   {{0xa154026a,0x6d40036e,0x28dc000d,0x00000000}},	//   љају_, vlla, _फोफि, --, 
   {{0x6d403d07,0x2ee4005b,0x00000000,0x00000000}},	//   wlla, сжиг, --, --, 
   {{0x6d409360,0x00000000,0x00000000,0x00000000}},	//   tlla, --, --, --, 
   {{0x6d409361,0x6f089362,0x2eec03a1,0xa5d800c8}},	//   ulla, shec, sjef_, אַטי, 
   {{0x6f089363,0x6d409364,0x2bec015b,0x00000000}},	//   phec, rlla, _ছেড়ে_, --, 
   {{0x6d409365,0x76340882,0x7ed401f7,0x4e04012c}},	//   slla, ṣayā, _وزنا, ाईदै_, 
   {{0x6d409366,0x7bc80142,0x00000000,0x00000000}},	//   plla, awdu, --, --, 
   {{0x6c8400c6,0x6d400986,0xe6b001bc,0x7d080006}},	//   _الثم, qlla, ुज्ज, _кніг_, 
   {{0x2908031c,0x00000000,0x00000000,0x00000000}},	//   rhba_, --, --, --, 
   {{0x25b000ad,0xb6780212,0x6a84009d,0xe5a4004e}},	//   ttyl_, ищує_, _улиа, йиби, 
   {{0x2bd40825,0xae1c0037,0x00000000,0x00000000}},	// [b620] धिवा, _बेमन_, --, --, 
   {{0x2168013e,0x25b00ba1,0x18b001af,0x00000000}},	//   ҳиди_, rtyl_, _нәср, --, 
   {{0x29189367,0x25b09368,0xe5a4013e,0x0ea410eb}},	//   _impa_, styl_, риҷи, _गांड, 
   {{0x216800ee,0x25b0005b,0xded40240,0x00000000}},	//   гиди_, ptyl_, ይዳና_, --, 
   {{0xdce00b91,0x614414a4,0x9f5800bc,0x91b4007b}},	//   _suoč, беда, ápí_, مطور_, 
   {{0x291805b1,0x5464013e,0xd62400d8,0x86c4009f}},	//   _jmpa_, _гарм_, _ѓоре_, _ايڏن, 
   {{0x53a09369,0x6f180fac,0x00000000,0x00000000}},	//   _нарб, _bmwc, --, --, 
   {{0xb614004b,0x7d980818,0xf1a801fd,0x00000000}},	//   _اړېک, авис_, _چاله_, --, 
   {{0xf1a811fc,0xa204936a,0x2918936b,0x00000000}},	//   _ناله_, _упад, _ompa_, --, 
   {{0x56680023,0x00000000,0x00000000,0x00000000}},	//   ዳስነቱ_, --, --, --, 
   {{0xa0a4014b,0x9dd40066,0x00000000,0x00000000}},	//   _ваҷд, _گزاش, --, --, 
   {{0x2918936c,0xdb0858ae,0x24880165,0x28dc07f7}},	//   _ampa_, ازده_, _lebm_, _फोबि, 
   {{0xaaa82899,0xc9841955,0x7d380023,0x3c94024c}},	//   _कारक, зуси, _ብፖለቲ, _дилё, 
   {{0x3c58008e,0x00000000,0x00000000,0x00000000}},	//   _килэ_, --, --, --, 
   {{0x28dc6b9b,0x2918009a,0x2368020c,0x00000000}},	//   माजि, _dmpa_, _nubj_, --, 
   {{0x29180831,0x5018011a,0xf8ac00cd,0x2bd4012a}},	//   _empa_, אולו, ञ्जय, धिरा, 
   {{0x49c80276,0x3b08936d,0xb92800db,0x00000000}},	// [b630] _луэм_, _ilaq_, _ۅزگۅ_, --, 
   {{0xe2d801b9,0x200006be,0x00000000,0x00000000}},	//   یانچ_, _əkir_, --, --, 
   {{0x6458936e,0x00000000,0x00000000,0x00000000}},	//   _útil, --, --, --, 
   {{0xe8101d72,0x6b6000ef,0x0ea407af,0x00000000}},	//   _डेटा_, _jēgp, _गाइड, --, 
   {{0x6f18009a,0x00000000,0x00000000,0x00000000}},	//   _rmwc, --, --, --, 
   {{0xaf98936f,0x518401b9,0x00000000,0x00000000}},	//   атих_, _ҳужа, --, --, 
   {{0xaaa81562,0xcdcc004b,0x3b080213,0x00000000}},	//   _कालक, ځښت_, _olaq_, --, 
   {{0x2d949370,0x51849371,0xdfcc009f,0xdd8c00f1}},	//   орос, _гужа, ئيي_, چوي_, 
   {{0xdd8c9372,0x213c0270,0x00000000,0x00000000}},	//   نوي_, _fkth_, --, --, 
   {{0x3b089373,0xfd5000cd,0x2bd4190c,0x00000000}},	//   _alaq_, _kakṣ, धिला, --, 
   {{0xddc00034,0xfd500055,0x7d380023,0xcac000eb}},	//   _czoł, _jakṣ, _ብፖሎቲ, োসফ, 
   {{0xbdf8130e,0xab740092,0xfd50002b,0xa3d80d2e}},	//   _گرما_, _በኃይል_, _makṣ, ़ित_, 
   {{0xa968006c,0xfd500a28,0x00000000,0x00000000}},	//   рига_, _lakṣ, --, --, 
   {{0x3b080784,0x61f4010e,0x00000000,0x00000000}},	//   _elaq_, _ýalń, --, --, 
   {{0xd9400262,0x24880194,0x8d7404d3,0xfd5000dc}},	//   фери, _rebm_, _ئاڵا, _nakṣ, 
   {{0xd70430c7,0x00000000,0x00000000,0x00000000}},	//   онсе_, --, --, --, 
   {{0x23680334,0x3cf00073,0x00000000,0x00000000}},	// [b640] _subj_, ेसचे_, --, --, 
   {{0x29189374,0xaaa87ef5,0x7c240055,0x00000000}},	//   _umpa_, _काँक, _śiri, --, 
   {{0xba282e6b,0xfd500882,0x80d4530e,0xd36c009f}},	//   _نسیم_, _cakṣ, _योगे, نهل_, 
   {{0xfd500882,0x6458041e,0x00000000,0x00000000}},	//   _dakṣ, _útim, --, --, 
   {{0x3b4c001f,0x00000000,0x00000000,0x00000000}},	//   _ማኔጅመ, --, --, --, 
   {{0xa508010a,0xa878010f,0x1c1800c5,0x00000000}},	//   _тега_, באַר, _फइलल_, --, 
   {{0x04c8021a,0x28b01dbd,0xaaa82e1e,0xc8200092}},	//   _پوځي_, _जानि, _कांक, ደሚሆን, 
   {{0x644c49ad,0xe1f89375,0xc10405d9,0x232801fe}},	//   _izbi, _кгб_, توڻي, _тоби_, 
   {{0x24183c1f,0x4cd004c5,0x00000000,0x00000000}},	//   _соңы_, তানু, --, --, 
   {{0xfd500882,0x00000000,0x00000000,0x00000000}},	//   _yakṣ, --, --, --, 
   {{0x628019a0,0x1ea800f2,0x00000000,0x00000000}},	//   oboo, _ناشي_, --, --, 
   {{0x62809376,0x53980375,0x7c300055,0x00000000}},	//   nboo, סיכו, _ādrā, --, 
   {{0xad240583,0x81d804c5,0x62800d47,0x1c180037}},	//   _کرنو, াহক_, iboo, _फेरल_, 
   {{0x644c1326,0xd7740228,0x62804266,0x80c80154}},	//   _ozbi, قارع, hboo, লাক্, 
   {{0x62809377,0x401c00cc,0x00000000,0x00000000}},	//   kboo, _পুতৌ_, --, --, 
   {{0xfd500882,0x628001f5,0xd5b800d1,0x3ce81d34}},	//   _rakṣ, jboo, исз_, जावे_, 
   {{0x644c03f9,0x62809378,0x95c803b7,0xfd5000b8}},	// [b650] _azbi, dboo, шува_, _sakṣ, 
   {{0xfd500882,0xdb180254,0x28b0000d,0x6d94010e}},	//   _pakṣ, rvtõ, _जायि, lýaý, 
   {{0x62800b4f,0xdeb80092,0xc4ac0709,0x00000000}},	//   fboo, ዳንና_, _चारओ, --, 
   {{0x62809379,0xfd500882,0x67d8010f,0x00000000}},	//   gboo, _vakṣ, _פֿיג, --, 
   {{0x28b001ad,0x2280022e,0x00000000,0x00000000}},	//   _जामि, _dаk_, --, --, 
   {{0x6280937a,0x9394007b,0xfd5000cd,0x69d80210}},	//   aboo, _وجزا, _takṣ, łteg, 
   {{0x6280937b,0xdce003e0,0x5348030d,0x00000000}},	//   bboo, _stoğ, _кăкă, --, 
   {{0x6294937c,0x6b8c033f,0x628026c2,0x61e401ef}},	//   óyot, _łago, cboo, _škle, 
   {{0x792c0023,0x00000000,0x00000000,0x00000000}},	//   ተኛታት, --, --, --, 
   {{0x4cd00011,0xc10400db,0x00000000,0x00000000}},	//   তাভু, _قوقي, --, --, 
   {{0xcee8937d,0xd01801fc,0x28c801ad,0x1f240014}},	//   _پران_, _тфа_, ाजसि, _کِنہ, 
   {{0x316c0036,0x00000000,0x00000000,0x00000000}},	//   _kuez_, --, --, --, 
   {{0x316c937e,0x00000000,0x00000000,0x00000000}},	//   _juez_, --, --, --, 
   {{0xfd4800c0,0xdbd80248,0x00000000,0x00000000}},	//   _дзік_, bààg, --, --, 
   {{0x6280937f,0x3ce801b0,0x316c01e4,0x3164002f}},	//   yboo, जारे_, _luez_, _milz_, 
   {{0x628002fa,0xea8877f7,0xd598037e,0x9bf80375}},	//   xboo, _убил_, _byだ_, _להצט, 
   {{0x64a400c7,0xf65000dd,0x316c00eb,0x6280003e}},	// [b660] заза, ہئے_, _nuez_, vboo, 
   {{0x62809380,0xbb2c0131,0x00000000,0x00000000}},	//   wboo, ﯩﭽﻪ_, --, --, 
   {{0xe7389381,0xae1c10eb,0xe1f00bce,0x00000000}},	//   _ген_, _बेसन_, کسا_, --, 
   {{0xcfc02f8b,0x316c05c7,0xa6c8030d,0x00000000}},	//   ্মান, _buez_, _улма_, --, 
   {{0x62809382,0x644c0210,0x00000000,0x00000000}},	//   rboo, _wzbi, --, --, 
   {{0x628009c8,0x6d7c0092,0x00000000,0x00000000}},	//   sboo, _የሐዋሳ_, --, --, 
   {{0x62804b5a,0xdfd800a7,0xdea0258c,0x644c0210}},	//   pboo, съл_, فیای, _uzbi, 
   {{0x53980375,0xada400d0,0x9e70075e,0x00000000}},	//   _לילו, zpúš, رۇتت, --, 
   {{0x21a449d2,0xa0a49383,0x316c4a85,0x31640112}},	//   _хизм, _наад, _guez_, _filz_, 
   {{0x26dc013f,0xe0440b16,0x716400db,0x505401d9}},	//   _ɔtoa_, _ензи, _قالك, _کٔمس_, 
   {{0x4bb0010b,0x10a0009d,0x00000000,0x00000000}},	//   нйэс, _чихн, --, --, 
   {{0x60c80036,0x00000000,0x00000000,0x00000000}},	//   lefm, --, --, --, 
   {{0x2cd80014,0x58841075,0x1afc00eb,0x00000000}},	//   _ڈُنگ_, зыба, উফলে_, --, 
   {{0xd90c0502,0x28b00073,0xd5b800c7,0x00000000}},	//   اید_, _जाणि, ҩса_, --, 
   {{0x6458148b,0x4cb8011a,0xdbd80241,0x00000000}},	//   _útih, _המוג, bàág, --, 
   {{0x60c805d5,0xa3c06b9b,0xada400d7,0x00000000}},	//   hefm, ्बन_, spúš, --, 
   {{0xe6980014,0x6b5400ae,0x00000000,0x00000000}},	// [b670] زمٕژ_, fágf, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x28b026e4,0x97000131,0x00000000,0x00000000}},	//   _जाति, _كېسى, --, --, 
   {{0x26e40156,0x27fc00fd,0x2d980118,0x00000000}},	//   _ཤོགཔ, ätne_, ásek_, --, 
   {{0x31640ade,0x96449384,0x00000000,0x00000000}},	//   _pilz_, _хэнд, --, --, 
   {{0x316c030a,0xff08005b,0x16e400f1,0x7ff400f2}},	//   _vuez_, äänä_, _بېړۍ_, کسها, 
   {{0xdfcc099f,0x0878008f,0xdbe800e5,0x00000000}},	//   ليو_, לעגט_, _főét, --, 
   {{0xa3d805f9,0xe3b000c8,0x316c06af,0xa070013d}},	//   ़िर_, _שױן_, _tuez_, нгәч, 
   {{0x51849385,0xed3405f5,0x7bdc041e,0x6b5401d3}},	//   _хуба, дэнэ, ærun, lágg, 
   {{0x6ea8044b,0x3d180118,0x00000000,0x00000000}},	//   _टाकु, योले_, --, --, 
   {{0x4ee40024,0x00000000,0x00000000,0x00000000}},	//   _нідз, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdce001f1,0xa3c01f13,0x291c180f,0x00000000}},	//   _zvoľ, ्बम_, òta_, --, 
   {{0x18649386,0x80c8015b,0x7bdc0158,0x7c8404c2}},	//   дари_, লাচ্, årut, _чуче, 
   {{0xeab06640,0x00000000,0x00000000,0x00000000}},	//   _شعب_, --, --, --, 
   {{0x2bd49387,0x35c40107,0x00000000,0x00000000}},	// [b680] धिका, натҳ, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbd940023,0xe8c801f9,0x00000000,0x00000000}},	//   ዚኣቶም_, ाजीच, --, --, 
   {{0x1bf4010f,0x00000000,0x00000000,0x00000000}},	//   וצער_, --, --, --, 
   {{0x2fc4020b,0x00000000,0x00000000,0x00000000}},	//   _aplg_, --, --, --, 
   {{0x26c0005a,0x69d800b0,0x00000000,0x00000000}},	//   _hbko_, āteh, --, --, 
   {{0x99849388,0x00000000,0x00000000,0x00000000}},	//   _ānō_, --, --, --, 
   {{0xdd989389,0x61f405ac,0x0f2000c7,0x1418011a}},	//   ошо_, øyls, кьым, _וולב, 
   {{0xd1b06b5d,0x00000000,0x00000000,0x00000000}},	//   _لینک, --, --, --, 
   {{0x39b801c0,0x60b000db,0x5cc401d5,0x00000000}},	//   үлнэ_, _شۅبئ, фсиз, --, 
   {{0xedb401d3,0x00000000,0x00000000,0x00000000}},	//   وجیک, --, --, --, 
   {{0xdce00030,0xd52801e1,0xeef400c0,0x00000000}},	//   _uvoľ, _kọ̀n, _пячэ, --, 
   {{0x6ef403c6,0x4cd0036b,0xe8c80073,0x00000000}},	//   _náby, رغیز, ाजूच, --, 
   {{0x7bdc0158,0x66140210,0x8d1400ae,0x00000000}},	//   årus, dzyk, _يزور_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7f40401f,0x6ef403b2,0x8b98011a,0x00000000}},	//   nomq, _báby, _ובהת, --, 
   {{0x0574938a,0x6448002f,0x00000000,0x00000000}},	// [b690] نالد, üfin, --, --, 
   {{0xd4080f1b,0x88c4068f,0x798c938b,0x26c0009d}},	//   يتام_, ęści, _iwaw, _ebko_, 
   {{0x7f400921,0x798c004c,0x00000000,0x00000000}},	//   komq, _hwaw, --, --, 
   {{0x798c19f8,0x92e800d1,0x03c408ca,0xff080108}},	//   _kwaw, غراق_, ъсум, äälä_, 
   {{0x2fc405b1,0x6614033f,0x6b5401d3,0xb1a801e1}},	//   _splg_, czyk, ságg, _ṣọkọ_, 
   {{0x798c938c,0x00000000,0x00000000,0x00000000}},	//   _mwaw, --, --, --, 
   {{0x798c938d,0xa0644e73,0x6b54938e,0xa92002d2}},	//   _lwaw, наша_, láge, _íþen, 
   {{0x25a427c4,0x798c938f,0x26dc0134,0xd1b800c6}},	//   šole_, _owaw, _ɔtoo_, _واذا_, 
   {{0x2d98066d,0x712423f6,0x2bd001ad,0x32540452}},	//   ése_, _كىرم, _तनहा, _чвар, 
   {{0x398c00de,0x2d9800e4,0x00000000,0x00000000}},	//   džs_, ĩse_, --, --, 
   {{0x798c18a6,0x7f40014f,0xeff00023,0x00000000}},	//   _awaw, bomq, ሃሃዲ_, --, 
   {{0x28b052f2,0x798c9390,0xa3c035e8,0xa9a43663}},	//   _जाहि, _bwaw, ्बत_, нимд, 
   {{0x645809f3,0x9e949391,0x6f08022e,0x00000000}},	//   _útiv, _سانچ, mkec, --, 
   {{0x68449392,0x6f0825a6,0xcc840244,0x00000000}},	//   енга, lkec, _تۆده_, --, 
   {{0x6d409393,0x00000000,0x00000000,0x00000000}},	//   mola, --, --, --, 
   {{0x6d409394,0x6f089395,0xfbd004d3,0x798c031c}},	//   lola, nkec, _خته_, _fwaw, 
   {{0xddc01ebd,0xe618407e,0x798c9396,0xa5080798}},	// [b6a0] _kgoš, чда_, _gwaw, пеаа_, 
   {{0x69d49397,0x6614033f,0x9a38011a,0x9b800244}},	//   _isye, rzyk, _מתפק, _جڤین, 
   {{0x798c06d6,0x1b001c82,0x6614068f,0x7f40014b}},	//   _zwaw, _লগতে_, szyk, yomq, 
   {{0xe7389398,0xe2900597,0x6b549399,0x68fc014f}},	//   _хем_, اذا_, lágb, _hopd, 
   {{0x68fc939a,0x91e0003b,0xddc000ef,0xff0801f4}},	//   _kopd, лоце, _ogoš, äämä_, 
   {{0x6d40939b,0x7f400b6f,0xb9fc02d3,0x3f8c0142}},	//   jola, womq, _ቅዲ_, _pwdu_, 
   {{0x6d40939c,0x68fc014f,0x2574939d,0xd5280241}},	//   dola, _mopd, _hæl_, _wọ̀n, 
   {{0x6d5c939e,0x6e2c0cf4,0x443801ab,0x2efc0009}},	//   ïsan, _žaba, _ixr_, _cowf_, 
   {{0x6d40939f,0x69d407ab,0xe2a41873,0x68fc017a}},	//   fola, _nsye, æðum_, _oopd, 
   {{0x798c66af,0x7f400921,0x44380139,0x00000000}},	//   _rwaw, somq, _kxr_, --, 
   {{0x69d493a0,0x798c93a1,0xdee40dbb,0x60d8030a}},	//   _asye, _swaw, _пожи, _iatm, 
   {{0x60d893a2,0x2efc0493,0x6f0804e6,0x645803b2}},	//   _hatm, _gowf_, ckec, _útiu, 
   {{0x6d4093a3,0x60d893a4,0x2f100241,0x506000c7}},	//   bola, _katm, _fágb_, _иҕәҕ, 
   {{0xa3c0216a,0x60d893a5,0xfd38007b,0xe1ec01ec}},	//   ्बा_, _jatm, _تكتب_, ргi_, 
   {{0x60d893a6,0x68fc047e,0x443800d8,0xfb3400ee}},	//   _matm, _dopd, _nxr_, _инкэ, 
   {{0x60d893a7,0x798c93a8,0xddc009a8,0x44b40131}},	//   _latm, _twaw, _zgoš, һбус, 
   {{0x7aec93a9,0x68fc000f,0xa2b40316,0x798c2e6e}},	// [b6b0] _inat, _fopd, ैभन्, _uwaw, 
   {{0x6b5403df,0x60d893aa,0x68fc010e,0x7aec93ab}},	//   ráge, _natm, _gopd, _hnat, 
   {{0x7aec008c,0x913000c7,0x00000000,0x00000000}},	//   _knat, ҳҭах, --, --, 
   {{0x6d4093ac,0x60d8002b,0x2574143a,0x00000000}},	//   zola, _aatm, _fæl_, --, 
   {{0x7aec93ad,0x60d893ae,0x68fc01a9,0x6b5400e5}},	//   _mnat, _batm, _yopd, lágc, 
   {{0xeafc47d0,0x1cc80003,0x4438020b,0x60d893af}},	//   _उक्त_, ིབས_, _fxr_, _catm, 
   {{0x6d4093b0,0x7aec93b1,0x60d800a2,0x2f5800d8}},	//   vola, _onat, _datm, мшиќ_, 
   {{0x6d402df3,0x7aec93b2,0x60d8127b,0x6b5401ed}},	//   wola, _nnat, _eatm, zágb, 
   {{0x6d4093b3,0x6f082831,0x60d893b4,0xed58016c}},	//   tola, rkec, _fatm, мои_, 
   {{0x7aec93b5,0x270c3bca,0x60d805e4,0xad240131}},	//   _anat, _सत्र_, _gatm, ئىدى, 
   {{0x6d4093b6,0xa3d80034,0x6f08003e,0x443801a9}},	//   rola, ़िए_, pkec, _xxr_, 
   {{0x6d4093b7,0x7aec01c3,0x60d893b8,0x68fc4cae}},	//   sola, _cnat, _zatm, _sopd, 
   {{0x68fc93b9,0x60d893ba,0x7aec93bb,0x00000000}},	//   _popd, _yatm, _dnat, --, 
   {{0x6d4093bc,0xddc0107d,0x05e005d7,0x60d8022e}},	//   qola, _ugoš, निसब, _xatm, 
   {{0x257409e8,0xd82032b1,0x6b5493bd,0x00000000}},	//   _sæl_, адри, _итих, --, 
   {{0x69d401b8,0x6b5401ed,0x257401bf,0x7aec93be}},	//   _tsye, ságb, _pæl_, _gnat, 
   {{0x68fc93bf,0xd62493c0,0xad9c033f,0x4f900092}},	// [b6c0] _topd, воте_, zyźn, _ሚደቅሳ_, 
   {{0x7aec04b9,0x25741125,0x68fc01bf,0x00000000}},	//   _znat, _væl_, _uopd, --, 
   {{0xc33004a9,0x60d81801,0x44380113,0x7aec93c1}},	//   مەس_, _ratm, _qxr_, _ynat, 
   {{0x60d80fcd,0xaf980023,0x85940101,0x00000000}},	//   _satm, ዉኣትና_, _میرص, --, 
   {{0x60d893c2,0x6e2c0010,0x91b40214,0xd1b4029c}},	//   _patm, _žabn, نطور_, ناوا_, 
   {{0x64a493c3,0x60d893c4,0xdb08007c,0x74c000cd}},	//   _шага, _qatm, _upfö, र्दृ, 
   {{0xd00c7b19,0x2d9c0100,0xa114036b,0x74f001ec}},	//   يله_, _avwe_, _یورت, _دۋلا, 
   {{0x92e40798,0x00000000,0x00000000,0x00000000}},	//   _идсб_, --, --, --, 
   {{0x60d87bfb,0x7aec93c5,0x7d2801d3,0xa3d8000d}},	//   _tatm, _rnat, فزدہ_, ़िक_, 
   {{0x61e093c6,0x6458041e,0x3074009d,0x00000000}},	//   mvol, _útis, _буцс, --, 
   {{0x61e01214,0x3d1893c7,0x2fa40736,0x00000000}},	//   lvol, योगे_, _مصنّ, --, 
   {{0x4f8401d9,0xdcb000d1,0x5398011a,0x00000000}},	//   _شامہ, _چىش_, ויטו, --, 
   {{0x61e093c8,0xf8b893c9,0xceb00375,0x88c4033f}},	//   nvol, нөн_, _כיף_, ęśni, 
   {{0x7aec0142,0xd8800066,0x00000000,0x00000000}},	//   _wnat, شهری, --, --, 
   {{0xd6d8728c,0x7aec01ab,0x2ba80b67,0x00000000}},	//   мта_, _tnat, _किया, --, 
   {{0x7aec93ca,0x61e003d4,0x47344f73,0x4784104e}},	//   _unat, kvol, ансс, рырб, 
   {{0x5ebc00fe,0x74a801ec,0x00000000,0x00000000}},	// [b6d0] ্যপে, есең_, --, --, 
   {{0x61e02e31,0x2ba893cb,0x98540116,0xd4e4014b}},	//   dvol, _किमा, _үтүш, ъюби, 
   {{0xdd840d62,0xdb183ae2,0x61e093cc,0x2f102507}},	//   _گو_, etté, evol, _lága_, 
   {{0xf678008f,0x25a40427,0x61e0002f,0x778400fb}},	//   _ראָמ, šola_, fvol, _илүз, 
   {{0xdd8493cd,0x61e093ce,0x00000000,0x00000000}},	//   _دو_, gvol, --, --, 
   {{0x78b40007,0x63a40022,0xada401ec,0x2cf000bc}},	//   ngzv, _әырҕ, ңайл, _अचेल_, 
   {{0xb4c023ef,0x5f900640,0x439493cf,0x61e001ef}},	//   ्जी_, бијт, _васс, avol, 
   {{0xa3c02982,0x61e0003a,0x2f101d1d,0x00000000}},	//   ्बर_, bvol, _bága_, --, 
   {{0xd1b866a3,0xf2344c8b,0x6458659a,0x00000000}},	//   _تازا_, _صبرک, _útir, --, 
   {{0x799c03ac,0x00000000,0x00000000,0x00000000}},	//   dssw, --, --, --, 
   {{0x799c0036,0xa804013d,0xab28337e,0xab64022e}},	//   essw, _meñä, еона_, лвол, 
   {{0xdd8c93d0,0x2f1001e1,0x4f6400db,0xb4c0024a}},	//   _کوو_, _fága_, _شااف, ्जु_, 
   {{0xada493d1,0x799c03ac,0x8d7493d2,0x00000000}},	//   _салл, gssw, _شاشا, --, 
   {{0xeb9824a9,0x97c001e0,0xee3000ec,0x00000000}},	//   _зик_, әйте, _پٽڻ_, --, 
   {{0xab2834d8,0xb8640b24,0x00000000,0x00000000}},	//   _пока_, لافو, --, --, 
   {{0x186401d5,0xfc300345,0x00000000,0x00000000}},	//   уаси_, _بحه_, --, --, 
   {{0x3ce80073,0xb4c093d3,0xdb0c00e5,0x00000000}},	// [b6e0] जाचे_, ्जू_, _íjás, --, 
   {{0xa3c037bb,0x35c40107,0x9660005b,0x00000000}},	//   ्बल_, рафҳ, скуе, --, 
   {{0x6e2c110c,0xa80400a2,0xa2e40395,0x00000000}},	//   _žabl, _deñä, ложд, --, 
   {{0x61e028e5,0xe5a400d1,0x0524015b,0x82846148}},	//   tvol, _йими, বকের_, рқад, 
   {{0xd50c0085,0x26d093d4,0x53a004da,0x660401d5}},	//   sɛ́m, meyo_, لمەك, _ёпга, 
   {{0x26d093d5,0x61e093d6,0x10a00640,0xdfd80107}},	//   leyo_, rvol, биљн, еъи_, 
   {{0x61e093d7,0x656c004b,0x442c014a,0x2f1002f0}},	//   svol, _iibh, _äd_, _sága_, 
   {{0x26d093d8,0x64a493d9,0x61e01af3,0x656c01ab}},	//   neyo_, _шаҳа, pvol, _hibh, 
   {{0xa0b47611,0x656c009a,0x74c000dc,0x61e001a9}},	//   _محاص, _kibh, र्वृ, qvol, 
   {{0x2f10022c,0xa068702f,0x6b54089f,0x00000000}},	//   _vága_, _заза_, vága, --, 
   {{0x656c93da,0x26d0055a,0x88c40034,0x672403cd}},	//   _mibh, keyo_, ęśli, _omkj, 
   {{0x656c3917,0x26d093db,0x799c02d0,0x2f1001ef}},	//   _libh, jeyo_, tssw, _tága_, 
   {{0x26d093dc,0x644c93dd,0x78b40334,0x799c0036}},	//   deyo_, _lybi, tgzv, ussw, 
   {{0x656c93de,0x7bd893df,0xd7f8329c,0x644c03e0}},	//   _nibh, _tsvu, нуб_, _oybi, 
   {{0x644c93e0,0x6b5400e5,0xace81f0d,0x69d80037}},	//   _nybi, sága, _جرنل_, _पैठी, 
   {{0x656c14d0,0x2ba835e8,0x6b5493e1,0x26d093e2}},	//   _aibh, _किता, pága, geyo_, 
   {{0x644c93e3,0x656c00dc,0x35f493e4,0x349400c7}},	// [b6f0] _aybi, _bibh, шпар, иаар, 
   {{0xb4c00d2c,0x656c0369,0xd7f8022e,0xa3c000dc}},	//   ्जे_, _cibh, _зум_, ्बं_, 
   {{0x644c93e5,0x26d0406d,0x656c93e6,0xa8780375}},	//   _cybi, beyo_, _dibh, _באתר, 
   {{0x656c3e7c,0x644c015d,0x26d00009,0x046493e7}},	//   _eibh, _dybi, ceyo_, стум, 
   {{0x656c0810,0x644c06be,0x00000000,0x00000000}},	//   _fibh, _eybi, --, --, 
   {{0x656c93e8,0x939406c2,0x00000000,0x00000000}},	//   _gibh, _مجرا, --, --, 
   {{0x6724002d,0xa1540640,0xc0780212,0x645803b2}},	//   _ymkj, јају_, усії_, _útip, 
   {{0x656c0912,0xada400c7,0x7fe8009a,0x00000000}},	//   _zibh, ааил, اروف_, --, 
   {{0x656c4b26,0x7afc00f3,0x9e6002e8,0x00000000}},	//   _yibh, djst, овъд, --, 
   {{0x656c01d4,0x26d093e9,0xec7800a7,0x6d2402a9}},	//   _xibh, zeyo_, ъпо_, рдоз, 
   {{0x26d093ea,0xd5b40034,0xcfa800db,0xeeb800d8}},	//   yeyo_, इंडज, _ساام_, _алеш_, 
   {{0x78a400dc,0xab28468b,0xfe7002f2,0xacf451ae}},	//   _adhv, тома_, _فده_, اسکت, 
   {{0x26d000ca,0x00000000,0x00000000,0x00000000}},	//   veyo_, --, --, --, 
   {{0x26d093eb,0x2ae4000d,0xb4c02435,0x00000000}},	//   weyo_, _जोरु_, ्जो_, --, 
   {{0xa6941b88,0x656c93ec,0x6adc00fe,0x26d093ed}},	//   ирај, _ribh, যাবো, teyo_, 
   {{0x644c93ee,0x69947927,0xfd680432,0xf1c4012d}},	//   _rybi, _крох, _orsỳ, लझान, 
   {{0xa52493ef,0x644c93f0,0x6b5400dd,0x6e2c0427}},	// [b700] амад, _sybi, lágo, _žabj, 
   {{0x26d093f1,0x656c047e,0xa96801ec,0xe808009d}},	//   seyo_, _qibh, _шипа_, _анод_, 
   {{0x656c0a28,0x26d093f2,0xe2980953,0xe7384964}},	//   _vibh, peyo_, вае_, _аен_, 
   {{0x66e493f3,0x644c02fb,0x98a000e2,0x656c014f}},	//   _тома, _vybi, mijā_, _wibh, 
   {{0x644c006d,0x98a000da,0x656c93f4,0xd24c93f5}},	//   _wybi, lijā_, _tibh, ونم_, 
   {{0x1fa4006c,0x656c0192,0x644c03cb,0x6af40327}},	//   ариг, _uibh, _tybi, _བོའོ_, 
   {{0x98a000da,0x53a0016c,0x3fc801ed,0xdfd802e8}},	//   nijā_, _марб, ادتی_, тъл_, 
   {{0x673493f6,0x261405b3,0x6adc00eb,0xbed8011c}},	//   nnyj, पैथी_, যাডো, удих_, 
   {{0xe0d893f7,0xe0d001d9,0xd24c01d9,0x425493f8}},	//   _ива_, _وٲر_, _ہنہ_, _اچار, 
   {{0xcd303306,0x28b0012c,0x5fac0073,0x00000000}},	//   ْرَب, _जागि, _टिपल, --, 
   {{0xe044010b,0xeed40014,0x78a40055,0xa068004e}},	//   _тнжи, _گٍنگ, _rdhv, _ража_, 
   {{0x9b2493f9,0x98a0005f,0x4cd0015b,0x6b5401d3}},	//   рфол, dijā_, তাগু, ságn, 
   {{0xdd8c0f31,0x5ebc0eac,0x00000000,0x00000000}},	//   _کوڈ_, ্যদে, --, --, 
   {{0xb78829db,0x69d8010e,0x98a00171,0x00000000}},	//   ләме_, _ŧbeý, fijā_, --, 
   {{0x6b540077,0x7760001f,0x8d580115,0x00000000}},	//   cágo, _ገለልተ, _שכוי, --, 
   {{0xa3c01715,0x9a8493fa,0x7bdc0162,0x00000000}},	//   ्बई_, _тукл, æruu, --, 
   {{0xd49856a1,0x00000000,0x00000000,0x00000000}},	// [b710] вре_, --, --, --, 
   {{0x44f405c1,0x6e2c02fb,0x78a401bf,0x98a00171}},	//   опус, _žabk, _udhv, bijā_, 
   {{0xdeb80020,0x98a000da,0xd7f893fb,0x04840165}},	//   ዲሆን_, cijā_, _руп_, _jēṭh, 
   {{0x2ba822e3,0xdb1803b2,0x6b98010f,0x00000000}},	//   _किसा, kttí, רשײד, --, 
   {{0x6b5400dd,0xc2c4007b,0x8b580677,0x00000000}},	//   zágo, تيني, ביאס_, --, 
   {{0x1c0405f9,0xc10493fc,0xe7fc1c54,0x80a400f2}},	//   शहाल_, يوني, _उपमा_, قمهن, 
   {{0x865002ea,0xba00001f,0x6b5404d4,0x321c0210}},	//   ngɔn, _ልጁ_, xágo, szwy_, 
   {{0x6b5400e5,0xe040117e,0x98a00064,0x60600116}},	//   vágo, янщи, kojį_, سۇنل, 
   {{0x98a000e2,0x97280023,0x2ba800c5,0x41e40024}},	//   zijā_, _ተገዳስ, _किहा, _міфа, 
   {{0x6b545b84,0x00000000,0x00000000,0x00000000}},	//   tágo, --, --, --, 
   {{0x705493fd,0xdedc02d3,0xb05493fe,0x67340108}},	//   _اناا, ሓንካ_, _اپات, ynyj, 
   {{0x2b140801,0x6b5401ed,0x37dc0154,0x00000000}},	//   сьор, rágo, ডমার, --, 
   {{0x6b5400dd,0xeeb80022,0x9e74025d,0x00000000}},	//   ságo, _алҵш_, _הגנה_, --, 
   {{0xbdf81b2c,0x5fac00bc,0x00000000,0x00000000}},	//   _خرما_, _टिमल, --, --, 
   {{0x67340477,0x7bdc0162,0x6b5431b7,0x00000000}},	//   tnyj, ærut, lágm, --, 
   {{0x98a000da,0x00000000,0x00000000,0x00000000}},	//   rijā_, --, --, --, 
   {{0x7c240198,0x98a0005f,0x67340076,0x24c807ee}},	// [b720] _ƙirg, sijā_, rnyj, лгап_, 
   {{0x8b600198,0x55000276,0x00000000,0x00000000}},	//   ɓɓaɓ, ппуб, --, --, 
   {{0x4adc007d,0x64a4036b,0xe72893ff,0x1874011a}},	//   _बसाव, _қава, _бонд_, _לעיר_, 
   {{0x734800d6,0xe29800c7,0xfff80345,0x00000000}},	//   ачів_, уад_, یکات_, --, 
   {{0xd12c00f1,0x00000000,0x00000000,0x00000000}},	//   ډمن_, --, --, --, 
   {{0xf1a832cc,0x00000000,0x00000000,0x00000000}},	//   شاهه_, --, --, --, 
   {{0xdeb80020,0x3ef80276,0xa2e40395,0x00000000}},	//   ዲሆኑ_, инкэ_, _ловд, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x62809400,0xdde85767,0xbb4c0220,0x00000000}},	//   mcoo, اربه_, _ﺃﻭﻻ_, --, 
   {{0x2364008f,0x62806257,0x216800ee,0xd24c007b}},	//   lmoj_, lcoo, _сизи_, _أنك_, 
   {{0xdec80026,0x236401e4,0xdb182131,0x6a700162}},	//   _булл_, omoj_, sttí, yðfø, 
   {{0x2ba89401,0x62809402,0xdde807d6,0x8fa00006}},	//   _किरा, ncoo, _مرته_, _хаце, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbb6800b5,0x23640240,0x2da00118,0x9b340166}},	//   _datは_, hmoj_, íseň_, рхүш, 
   {{0x907800d9,0xc69000f1,0x00000000,0x00000000}},	//   רטלי, کېټ_, --, --, 
   {{0x6e2c0010,0x236400df,0x00000000,0x00000000}},	//   _žabi, jmoj_, --, --, 
   {{0x23640fcf,0x6a7003b2,0x00000000,0x00000000}},	// [b730] dmoj_, rðfø, --, --, 
   {{0x236401e4,0x00000000,0x00000000,0x00000000}},	//   emoj_, --, --, --, 
   {{0x62800175,0x932400ec,0xd1b80023,0x3ce0012d}},	//   fcoo, ٽران, ተወት_, _कसने_, 
   {{0x32549403,0x35680020,0xa3a804fa,0x1aa80183}},	//   овер, ታወቁት_, _गटर_, গ্ৰা, 
   {{0x865002ea,0x41e400db,0xb854001f,0x00000000}},	//   ngɔl, كسوف, _መስጠቱ, --, 
   {{0xc2440953,0x00c802dd,0x23640115,0xc0e80133}},	//   чнік, йлік_, amoj_, یفۆن_, 
   {{0x62800067,0x5348030d,0x00000000,0x00000000}},	//   bcoo, _йăкă, --, --, 
   {{0x62800de2,0x7d1803cd,0xe8b461ef,0x23640200}},	//   ccoo, _alvs, _अञ्च, cmoj_, 
   {{0x8d240058,0xa6e001a8,0x3134010a,0x00000000}},	//   йниң_, öðin, _деар, --, 
   {{0xd6bc02f5,0xdd8c2756,0x71400137,0x00000000}},	//   উজিয, کوی_, _تۉتۅ, --, 
   {{0x6144185e,0xeb98026a,0x0d280023,0x2fd83346}},	//   _بىلە, јим_, _ብወገኖ, _خواد_, 
   {{0xdd040139,0x00000000,0x00000000,0x00000000}},	//   _töşn, --, --, --, 
   {{0x7dc4007b,0x6b5401d3,0x7bdc1427,0x00000000}},	//   _فتوك, lágk, ærur, --, 
   {{0x2d8c6e43,0x20500240,0x00000000,0x00000000}},	//   mpee_, _ምንባረ, --, --, 
   {{0x6280037e,0x00000000,0x00000000,0x00000000}},	//   ycoo, --, --, --, 
   {{0xc0f0044e,0x62800548,0x00000000,0x00000000}},	//   _ቁዱስ_, xcoo, --, --, 
   {{0x6378007f,0x6f180142,0x68280092,0x4db400cc}},	// [b740] _kůng, _mlwc, ደሚመስ, _অনুৱ, 
   {{0x2d8c06af,0x6f1803cb,0x00000000,0x00000000}},	//   ipee_, _llwc, --, --, 
   {{0x6280030d,0x236400df,0x6b5400e5,0x00000000}},	//   tcoo, tmoj_, vágj, --, 
   {{0x69c401f5,0x628001f5,0x00000000,0x00000000}},	//   otke, ucoo, --, --, 
   {{0x69c4066d,0x236404ac,0x62809404,0xbb4c0150}},	//   ntke, rmoj_, rcoo, _ﺃﺭﻴ_, 
   {{0x62809405,0x69c49406,0x2364008f,0x00000000}},	//   scoo, itke, smoj_, --, 
   {{0x6f180368,0x69c40254,0x00000000,0x00000000}},	//   _blwc, htke, --, --, 
   {{0x98a00024,0x69c403b2,0x291800ef,0x00000000}},	//   miją_, ktke, _llpa_, --, 
   {{0xf1a80cbb,0x98a00024,0xa0a4004e,0x00000000}},	//   _هاله_, liją_, _маад, --, 
   {{0x6b5401ed,0x69c4002f,0x00000000,0x00000000}},	//   lágh, dtke, --, --, 
   {{0x98a00006,0x6f180042,0x69c40208,0x00000000}},	//   niją_, _flwc, etke, --, 
   {{0x25b00306,0x6f180042,0x60c8005c,0xa3d007af}},	//   kryl_, _glwc, lffm, _वहन_, 
   {{0x88e40154,0xfd6400db,0xc984735a,0x98a00064}},	//   মানক, _ендү, дуси, hiją_, 
   {{0x25b000ad,0x6d5c068c,0xdc280811,0x7d18007c}},	//   dryl_, ïsat, _پسته_, _ulvs, 
   {{0x4688063f,0x1a740220,0x8eb001ec,0x69c400d5}},	//   _ọtị_, _мұны_, _ءمۇش, atke, 
   {{0x29189407,0x98a00024,0x5018011a,0x00000000}},	//   _elpa_, diją_, בולו, --, 
   {{0xadec7a48,0xd8c81142,0x69c401f5,0x85b80014}},	// [b750] जियन_, _кынд_, ctke, قالس_, 
   {{0x98a00024,0x00000000,0x00000000,0x00000000}},	//   fiją_, --, --, --, 
   {{0x1368036b,0x98a00024,0x88040014,0x6adc0154}},	//   ашди_, giją_, _ہِیو, যারো, 
   {{0xf1a002dd,0x00000000,0x00000000,0x00000000}},	//   ейдi_, --, --, --, 
   {{0x8234034c,0x00000000,0x00000000,0x00000000}},	//   ورها, --, --, --, 
   {{0x88440092,0xd6d40154,0x98a04632,0x00000000}},	//   _የስብሰ, হাওয, biją_, --, 
   {{0x98a00953,0x72440d83,0x20300023,0x00000000}},	//   ciją_, _کھال, _ክንረክ, --, 
   {{0xdfcc8117,0x6b5401d3,0x69c49408,0xdbe800e5}},	//   ايي_, rágk, ytke, _főút, 
   {{0xdd8c0fb4,0x2d8c5109,0x69c400a3,0x2ae4000d}},	//   هوي_, upee_, xtke, _जोगु_, 
   {{0x417421ef,0x80b49409,0x00000000,0x00000000}},	//   _قالس, _обух, --, --, 
   {{0x8f800517,0xcd24001f,0xe570008f,0x2f1003b2}},	//   _ўқил, _ትገኛለ, ײַז_, _lági_, 
   {{0xaa446dc6,0x2d8c940a,0x69c4032e,0x25a40010}},	//   земл, ppee_, ttke, šoli_, 
   {{0x98a00024,0x69c4940b,0x606000cf,0x00000000}},	//   ziją_, utke, _قۇۇل, --, 
   {{0xa968006c,0x69c46971,0xec780108,0xdce800ef}},	//   сига_, rtke, _упк_, _tifā, 
   {{0xd9400209,0xdb1801bf,0x18b0035b,0x00000000}},	//   хери, dttæ, хәыр, --, 
   {{0xaa44940c,0x2f1003b2,0x00000000,0x00000000}},	//   _нейл, _bági_, --, --, 
   {{0x7b640014,0x2b8001fb,0x25a40129,0xdb188ecc}},	// [b760] _تاوٕ, _hóc_, éol_, fttæ, 
   {{0xd5ac940d,0x25b01263,0x6b540120,0x98a00024}},	//   افل_, rryl_, dági, tiją_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe1f81914,0x98a002d5,0x2b80940e,0x6b541ada}},	//   йге_, riją_, _móc_, fági, 
   {{0x8ec00729,0x98a00006,0xa6e00008,0x2b80004d}},	//   ্যাগ, siją_, öðun, _lóc_, 
   {{0x98a00024,0x332c0254,0x3ea00427,0x6b5400e5}},	//   piją_, _emex_, _žit_, ságh, 
   {{0x2b8001fb,0x629401a9,0x00000000,0x00000000}},	//   _nóc_, аyot, --, --, 
   {{0x54380302,0x00000000,0x00000000,0x00000000}},	//   _העלא, --, --, --, 
   {{0xe1241677,0x00000000,0x00000000,0x00000000}},	//   _емаи, --, --, --, 
   {{0x2b8001fb,0xc0bc0023,0xa0a401ee,0x0d2000db}},	//   _bóc_, ዲቦም_, _хажд, нүчү, 
   {{0x92dc0c58,0x2b80001e,0x26c0940f,0x3b080200}},	//   তাৰ_, _cóc_, _ocko_, _poaq_, 
   {{0x2b800208,0x1f64004e,0x00000000,0x00000000}},	//   _dóc_, _экем, --, --, 
   {{0x8af006be,0xd1b80023,0xdc3c013d,0x00000000}},	//   _ahəs, _ደቒቕ_, bíğa, --, 
   {{0x02c800c5,0x2bd8033f,0x80c403ce,0xdc3c0166}},	//   रभुन, यौहा, _राफे, cíğa, 
   {{0x2b800016,0xb9040c6f,0x00000000,0x00000000}},	//   _góc_, _नस_, --, --, 
   {{0x36300092,0x00000000,0x00000000,0x00000000}},	//   _በመግዛ, --, --, --, 
   {{0x1be82a05,0xb82403d4,0x588401ee,0x45d45e0c}},	// [b770] टिवल_, _মুখত_, _нына, нотс, 
   {{0x798c9410,0x2f10022c,0x7bc80af9,0xd83801c6}},	//   _itaw, _vági_, otdu, _гэм_, 
   {{0x7bc80048,0xedd80316,0x2b80004d,0x00000000}},	//   ntdu, _भन्छ, _xóc_, --, 
   {{0x6b5406ed,0x22908b07,0x00000000,0x00000000}},	//   tági, پلوس, --, --, 
   {{0x798c031c,0x00000000,0x00000000,0x00000000}},	//   _jtaw, --, --, --, 
   {{0xdb18049b,0x798c4180,0x6b540789,0x6ff401c6}},	//   lttä, _mtaw, rági, дчих, 
   {{0xa064398c,0x6b5400e5,0x59dc000d,0x00000000}},	//   маша_, sági, _पैसर, --, 
   {{0xdb1802f6,0x6b549411,0x798c9412,0x8e04010b}},	//   nttä, pági, _otaw, змиң_, 
   {{0x798c0e37,0x2b809413,0x2d989414,0xdb18005b}},	//   _ntaw, _sóc_, èse_, ittä, 
   {{0x7bc87e42,0x2b800051,0x00000000,0x00000000}},	//   ftdu, _póc_, --, --, 
   {{0x798c9415,0xd0189416,0x7c2402a8,0x417400db}},	//   _ataw, _уфа_, _ƙira, _ساكس, 
   {{0x2b8001fb,0xcf24007b,0xa9a41887,0xdb0c0241}},	//   _vóc_, _عراي, мимд, _ìjìs, 
   {{0x80c49417,0x2bdc07f7,0x98a00064,0x9d5000cf}},	//   _रामे, _फैरा, liję_, رچۇت, 
   {{0x2b8007ae,0x798c0165,0xeb985c74,0x00000000}},	//   _tóc_, _dtaw, _дик_, --, 
   {{0x798c020c,0x7b980014,0xdb18007c,0x98a00064}},	//   _etaw, _ٹھپس_, fttä, niję_, 
   {{0x186412d7,0x22500210,0x00000000,0x00000000}},	//   фаси_, żyki_, --, --, 
   {{0x3ea0000d,0x64a400c0,0x99e000cf,0x00000000}},	// [b780] _õite_, даза, _ажыд, --, 
   {{0x643401c8,0xbc8c0240,0x00000000,0x00000000}},	//   وراء, _ዘበንና_, --, --, 
   {{0xe76400d8,0xa764014b,0x00000000,0x00000000}},	//   _овоп, _окод, --, --, 
   {{0x98a00064,0x00000000,0x00000000,0x00000000}},	//   diję_, --, --, --, 
   {{0xc448034d,0x3f8c0175,0x91e0011c,0x00000000}},	//   _کیان_, _stdu_, коце, --, 
   {{0x50d00131,0x00000000,0x00000000,0x00000000}},	//   نزىر, --, --, --, 
   {{0x2bdc9418,0x2488072b,0x2f1009e8,0x0e340092}},	//   _फैला, _ifbm_, _lágu_, _እስከም, 
   {{0xef90104a,0x00000000,0x00000000,0x00000000}},	//   ایند, --, --, --, 
   {{0x6b8c01a6,0x6b5400c7,0x629403e0,0x00000000}},	//   _čaga, nágu, ıyod, --, 
   {{0x9ff800c6,0xa3d03d1d,0x7bc8007c,0x00000000}},	//   _وراء_, _वहा_, ttdu, --, 
   {{0xdb18426d,0x798c068f,0x69d49419,0x7d7804fb}},	//   yttä, _staw, _apye, _کمتر_, 
   {{0x7bc8941a,0xf1980150,0xef68007b,0xdb18713c}},	//   rtdu, _ءﻣﻮر, _فإنه_, kttå, 
   {{0x5884941b,0xdb180023,0x6b540022,0x00000000}},	//   дыба, lutë, jágu, --, 
   {{0x3ea4941c,0x6e2c010b,0x49740153,0x00000000}},	//   lamt_, _ýaba, кляс, --, 
   {{0x36d422e9,0x9be402bf,0xdb180023,0x00000000}},	//   новр, _цілк, nutë, --, 
   {{0x3ea403fa,0x798c031c,0x00000000,0x00000000}},	//   namt_, _ttaw, --, --, 
   {{0x798c941d,0x996401ee,0x3ea404cc,0xdb18941e}},	// [b790] _utaw, _отол, iamt_, rttä, 
   {{0xd7f80334,0xdb18343a,0x00000000,0x00000000}},	//   _дум_, sttä, --, --, 
   {{0x3ea40093,0x37b8031c,0x6b540022,0xdb180200}},	//   kamt_, _བའིད, aágu, jutë, 
   {{0x69d40022,0x27fc0158,0x6f8801ec,0x00000000}},	//   _ypye, åtne_, _ﻗﺎﻨﺎ_, --, 
   {{0x0584035b,0x776c0548,0x5570941f,0x1d2c02d3}},	//   _аусм, mmax, _аҳат, _ብገንዘ, 
   {{0x2f1005f7,0xdb180240,0x776c9420,0x6b5400e5}},	//   _lágt_, futë, lmax, lágt, 
   {{0xdfcc2834,0x92c40815,0x409400d4,0x8f6400e5}},	//   ميو_, _ощад, тріт, ولتے_, 
   {{0x72041216,0x26140574,0x776c0e14,0x2d9400fd}},	//   _كوزم, पैकी_, nmax, нрос, 
   {{0xee389421,0x98a00006,0x00000000,0x00000000}},	//   яни_, siję_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xed5801fa,0x2f1008a5,0x80c403ce,0xac389422}},	//   juže_, _bágt_, _राते, ячих_, 
   {{0xed5808a4,0xc02401ec,0x6b540022,0x00000000}},	//   duže_, _جىمي, yágu, --, 
   {{0x776c9423,0x6b540120,0x88e4015b,0x00000000}},	//   dmax, xágu, মাসক, --, 
   {{0x291c9424,0x6b54022c,0x00000000,0x00000000}},	//   óta_, vágu, --, --, 
   {{0x9d1800c8,0x7c84288b,0x2ca49425,0xdff000e1}},	//   _מוסט, _руче, mald_, _आज़ाद_, 
   {{0x6b540124,0xeab0007b,0x00000000,0x00000000}},	//   tágu, _صعب_, --, --, 
   {{0x37749426,0xd738001f,0xdc700022,0x574000d8}},	// [b7a0] тырс, _የእምነ, _игәы, унтб, 
   {{0x2ca49427,0x6b540022,0xfba801ee,0x00000000}},	//   nald_, rágu, _этәй_, --, 
   {{0xdb180561,0xdc3c013d,0xddc00166,0x78006566}},	//   futè, _míğm, _oyoş, _күра, 
   {{0x2ca49428,0x6b549429,0x00000000,0x00000000}},	//   hald_, págu, --, --, 
   {{0x2ca41fcd,0x3ce04540,0x6b5401d3,0x00000000}},	//   kald_, _कसले_, lágs, --, 
   {{0x2ca4942a,0xdb180023,0x4034004e,0x661401f4}},	//   jald_, tutë, келс, myyk, 
   {{0xe2980aa5,0x1540942b,0xdb180ba1,0x2ca400cf}},	//   _нав_, _серм, butè, dald_, 
   {{0xdb180ba1,0x63bc014f,0x3ea4002f,0x00000000}},	//   cutè, mupn, uamt_, --, 
   {{0x3ea4942c,0x2ca4942d,0x6aa405b1,0x20180309}},	//   ramt_, fald_, dakf, špi_, 
   {{0x3ea4942e,0x61e0942f,0x4dd00a2c,0xdb180023}},	//   samt_, mwol, اتيس, putë, 
   {{0xb0500014,0x9f4c004e,0x60180354,0x00000000}},	//   _پھوت, ïnós_, _эцар_, --, 
   {{0xd00c3c5b,0x61e004ba,0x6614005b,0x3dd800fe}},	//   _دلم_, owol, kyyk, তিবল, 
   {{0x2ca49430,0xf8b800f7,0xdb1802fb,0x28d000dc}},	//   bald_, мөн_, nuté, द्भि, 
   {{0x63bc02fb,0x6e3c2268,0x2ca40356,0x00000000}},	//   kupn, úsbe, cald_, --, 
   {{0x63bc07b9,0x6aa401e4,0x61e01196,0xa8540116}},	//   jupn, bakf, hwol, верә, 
   {{0x63bc33cb,0x61e09431,0xdb189432,0x7d0801e3}},	//   dupn, kwol, kuté, ljds, 
   {{0x63b801e3,0x6b5400e5,0x00000000,0x00000000}},	// [b7b0] _åtnj, rágt, --, --, 
   {{0x2edc06ab,0x776c9433,0x61e001f5,0x2f100306}},	//   _मस्त, smax, dwol, _jágr_, 
   {{0x61e09434,0xa5080116,0x00000000,0x00000000}},	//   ewol, بىلە_, --, --, 
   {{0x61e0017a,0x6b5401d3,0x256400d7,0x00000000}},	//   fwol, lágr, vôle_, --, 
   {{0xdd8415fa,0x61e004ba,0xa6c80154,0x88e40154}},	//   _خو_, gwol, _লোকট, মারক, 
   {{0x7bd89435,0x2f1008a5,0x00000000,0x00000000}},	//   _opvu, _nágr_, --, --, 
   {{0x7c280960,0x2ca49436,0x63bc020b,0x61e00083}},	//   jzdr, vald_, cupn, awol, 
   {{0x25649437,0x61e09438,0xdb189439,0x00000000}},	//   rôle_, bwol, rttû, --, 
   {{0x2ca4943a,0x6aa401e4,0x222400f1,0x00000000}},	//   tald_, vakf, _لګوي_, --, 
   {{0x25640a85,0x2f10943b,0x00000000,0x00000000}},	//   pôle_, _págs_, --, --, 
   {{0xbfb4943c,0x9c200022,0xeb98943d,0x00000000}},	//   _محنت, иҧшҵ, ьин_, --, 
   {{0x2b140801,0x6db40116,0x2f1006ea,0xd9d800fe}},	//   тьор, _айду, _vágs_, দিনম, 
   {{0x6f080841,0x2ca4003a,0x63bc0010,0x6aa4943e}},	//   mjec, pald_, zupn, rakf, 
   {{0xdd8c0272,0x6f08943f,0x6aa406ea,0xee3000ec}},	//   _بوو_, ljec, sakf, _ٽٽڻ_, 
   {{0x6e289440,0x61e0068f,0x98a09441,0x7524003e}},	//   lzeb, zwol, рисе, dhhz, 
   {{0x81e804c5,0x2eec05b1,0x63bc014f,0x6d409442}},	//   যমত_, ndef_, vupn, lnla, 
   {{0xe5a422d7,0xe5780d30,0x6e2801c7,0xaa440022}},	// [b7c0] тизи, дза_, nzeb, _шеил, 
   {{0x63bc04bf,0x6f080268,0x00000000,0x00000000}},	//   tupn, hjec, --, --, 
   {{0x6d409443,0x68fc0395,0x2eec07ab,0xe3b024e0}},	//   inla, _inpd, kdef_, شرا_, 
   {{0x61e09444,0x63bc0438,0x80c405f9,0x6f0822a9}},	//   twol, rupn, _राहे, jjec, 
   {{0x6f08171e,0x2eec0368,0x63bc0c6a,0x6d4001d5}},	//   djec, ddef_, supn, knla, 
   {{0x61e000a9,0x6d409445,0x6adc04c5,0x6e284084}},	//   rwol, jnla, যাটো, dzeb, 
   {{0xe2840598,0x7f580022,0x61e003fa,0x6e281418}},	//   _алби, накс_, swol, ezeb, 
   {{0xdb189446,0x6d409447,0xd4640276,0x54640fc0}},	//   puté, enla, _рисе_, _расм_, 
   {{0xcf749448,0x68fc03ac,0x5d640902,0xd1c4010a}},	//   خصوص_, _onpd, ктоз, _илте_, 
   {{0x6d409449,0xb0c86bf2,0x7c28002f,0x00000000}},	//   gnla, _रायग, tzdr, --, 
   {{0x6f08944a,0x8d7001f7,0x00000000,0x00000000}},	//   bjec, جايا, --, --, 
   {{0x5f740228,0x7c28944b,0x9e7000d1,0x7994014b}},	//   _شاار, rzdr, _پۇخت, лимф, 
   {{0xb0c86611,0x6e28033f,0xfcc401af,0x00000000}},	//   _रामग, czeb, _йәнм, --, 
   {{0x0c000014,0x2dd801ec,0xb4e00037,0x00000000}},	//   _چووُ, _ﺃﺴﻠﺤ, _दसे_, --, 
   {{0x28d04ead,0x6b54944c,0x69d80276,0x81d8015b}},	//   द्धि, rágr, ătea, ়টি_, 
   {{0x27fc01e6,0x6b5401d3,0xcc7401e4,0x00000000}},	//   åtna_, ságr, _בעוה_, --, 
   {{0x7aec944d,0xed5832fe,0x1be81b76,0xb4d40395}},	// [b7d0] _iaat, luža_, टिकल_, лжащ, 
   {{0x7aec944e,0xe294944f,0x28d07e92,0x81d80011}},	//   _haat, қаш_, द्दि, ়টা_, 
   {{0xdb0c01a8,0x6e289450,0xdb18072b,0x80bc012d}},	//   _þjór, zzeb, fttø, ईलैं, 
   {{0x7aec9451,0x7c240198,0x78a4014f,0x8af006be}},	//   _jaat, _ƙirj, _hehv, _lkən, 
   {{0x7aec9452,0x6f082a6d,0x6d409453,0x78a400af}},	//   _maat, vjec, ynla, _kehv, 
   {{0x7aec9454,0xac6402d3,0xa0a00209,0x00000000}},	//   _laat, _ታዕሊም_, башд, --, 
   {{0x6f089455,0x765c6f88,0x94200131,0x78a45ead}},	//   tjec, _hysy, _ئوزۇ, _mehv, 
   {{0x6e289456,0x765c0664,0x7aec9457,0x6d40062e}},	//   tzeb, _kysy, _naat, wnla, 
   {{0x6d409458,0x2eec0175,0x00000000,0x00000000}},	//   tnla, rdef_, --, --, 
   {{0x6e289459,0x6f081711,0xeb98945a,0x765c0100}},	//   rzeb, sjec, нио_, _mysy, 
   {{0x7aec945b,0x6d40945c,0x6e98945d,0x6e28945e}},	//   _baat, rnla, _звер_, szeb, 
   {{0x7aec945f,0x2eec0327,0x00000000,0x00000000}},	//   _caat, qdef_, --, --, 
   {{0x7aec9460,0x765c00b5,0x186408ca,0x00000000}},	//   _daat, _nysy, ғати_, --, 
   {{0x92dc00bd,0x25640109,0xd9780166,0x5e5400df}},	//   তায়_, kôla_, ерсә_, _גינע_, 
   {{0x7aec9461,0x765c033b,0x00000000,0x00000000}},	//   _faat, _aysy, --, --, 
   {{0x7aec9462,0x777c0077,0xd7f4001e,0x765c9463}},	//   _gaat, _cisx, ững_, _bysy, 
   {{0x765c0f7b,0x777c0077,0x63ac0175,0x8d7c001f}},	// [b7e0] _cysy, _disx, _svbn, _የሲቪል_, 
   {{0x7aec9464,0x765c0042,0x78a4002f,0x00000000}},	//   _zaat, _dysy, _gehv, --, 
   {{0x765c0022,0x06b00eac,0xa3149465,0x7aec1574}},	//   _eysy, ঙ্গি, льдш, _yaat, 
   {{0x765c9466,0x7aec1bce,0xf2c40150,0x00000000}},	//   _fysy, _xaat, исін, --, 
   {{0x765c602a,0x7c240198,0x1a98008f,0x636800c7}},	//   _gysy, _ƙirk, גינע, výnd, 
   {{0x9e0400d1,0xdb18005c,0x00000000,0x00000000}},	//   ғчил, sttø, --, --, 
   {{0xd5441d9d,0x8fa0041b,0x25640208,0x23280b3b}},	//   _спре_, баје, côla_, _зови_, 
   {{0x35a807c1,0xbdb41f5a,0x00000000,0x00000000}},	//   _चौड़, абиј, --, --, 
   {{0x9cc82cd0,0x7aec9467,0xe0d801f4,0x693400ef}},	//   нына_, _raat, _пва_, eņem, 
   {{0x7aec9468,0x6e3c002d,0xc31c00cc,0x00000000}},	//   _saat, úsba, _দআটি_, --, 
   {{0x78a400af,0xc1b000fb,0x00000000,0x00000000}},	//   _rehv, _уҙҙы, --, --, 
   {{0x7aec0a81,0x78a403b9,0x69d80356,0x00000000}},	//   _qaat, _sehv, ăten, --, 
   {{0x7aec9469,0xaac40a59,0xddb80484,0x00000000}},	//   _vaat, _वारक, _чуеш_, --, 
   {{0x78a4014f,0x765c12c1,0x6b5400e5,0x00000000}},	//   _qehv, _rysy, ságp, --, 
   {{0x7aec946a,0x38c804d3,0xc7b8946b,0xdd8c01d9}},	//   _taat, _یادی_, лёт_, _بوڈ_, 
   {{0x765c946c,0xbb58946d,0xd35c0131,0xda04014b}},	//   _pysy, _шайх_, ﯘﺭﯗﭖ_, _бчоп, 
   {{0xdb180122,0x4ca4015b,0x78a4946e,0xa6140124}},	// [b7f0] nutí, _খাতু, _tehv, азтә, 
   {{0x765c02fb,0x98c4003b,0x00000000,0x00000000}},	//   _vysy, _ссил, --, --, 
   {{0x765c068f,0x45d40131,0xa908022e,0xdb180306}},	//   _wysy, _қорс, _shоg, hutí, 
   {{0x92e80597,0x14c438db,0xdb18946f,0x67ec00e4}},	//   عراق_, _लावण, kutí, sõjá, 
   {{0x28d00882,0x6934005f,0x439402a9,0xc6181b0a}},	//   द्वि, zņem, _ҳасс, _боях_, 
   {{0xdb1800d8,0x00000000,0x00000000,0x00000000}},	//   dutí, --, --, --, 
   {{0xc918011a,0x00000000,0x00000000,0x00000000}},	//   רחות_, --, --, --, 
   {{0xd3409470,0x51840153,0xdb18032e,0x00000000}},	//   _افری, _бужа, futí, --, 
   {{0x2bdc0034,0xc1040451,0x766003e0,0xdb1808ce}},	//   _फैजा, _گولي, _özyı, gutí, 
   {{0xf9fc0154,0x7c940092,0x00000000,0x00000000}},	//   ুনাল_, _የበልግ_, --, --, 
   {{0xab289471,0xc104007b,0x5d640166,0x00000000}},	//   вона_, _دولي, риэм_, --, 
   {{0x693400e2,0x00000000,0x00000000,0x00000000}},	//   rņem, --, --, --, 
   {{0x6da42708,0xada49472,0x80241075,0x39e80024}},	//   _тила, _талл, _پرەم, льён_, 
   {{0xa968006c,0x95841b49,0x18a001b9,0x98a0081b}},	//   тига_, ማኖትን_, жарм, жире, 
   {{0xbd6814b7,0xd9402b97,0xe7380798,0x18b000c7}},	//   _срце_, цери, вев_, цәыр, 
   {{0x2d58067c,0x44240a2f,0xcc8402f2,0x00000000}},	//   pèes_, _ām_, _جۆگه_, --, 
  
   {{0xdb180356,0x59b000fb,0x7d1c007c,0x00000000}},	// [b800] butâ, _мөрс, örsg, --, 
   {{0x59dc012d,0x55000f06,0x00000000,0x00000000}},	//   _पैटर, опуб, --, --, 
   {{0x7c240198,0xe284035b,0x00000000,0x00000000}},	//   _ƙiri, алеи, --, --, 
   {{0x28d008dd,0x828402dd,0x00000000,0x00000000}},	//   द्रि, сқад, --, --, 
   {{0x009401c6,0xa2280395,0xd12c00e5,0x00000000}},	//   билэ, ъжда_, ڈمن_, --, 
   {{0xd12c4336,0xdfd8013e,0xe5240166,0xdb180162}},	//   ومن_, въи_, _тдгп, vutí, 
   {{0xa2e456b4,0x63789473,0xdde804fb,0x442c005c}},	//   _ковд, _асар_, چرخه_, _åd_, 
   {{0x644c011f,0x2bd800ab,0xd0040063,0x00000000}},	//   _ixbi, यौछा, реће_, --, 
   {{0xb35417a5,0xb1440014,0x00000000,0x00000000}},	//   _اینا_, _گیوم_, --, --, 
   {{0x20542ff2,0xdb189474,0xa06800c7,0xefb000e5}},	//   _ктер, rutí, _ҟаҵа_, _کیٹگ, 
   {{0x3f9800e4,0xd12c0736,0x3b545fad,0x1ec80395}},	//   _ïru_, _تمل_, йкор, _алеи_, 
   {{0x2564006a,0xed5814b2,0x1038011a,0x539800df}},	//   kôlo_, vrže_, _בגבע, כסטא, 
   {{0x27f8089c,0x6ab400a9,0xb6c401e0,0x00000000}},	//   _arpn_, _ddyf, ҙөнд, --, 
   {{0x67240332,0xdb1801e7,0x0d503dbb,0x7c780092}},	//   _alkj, irté, _وخود, ከትለው_, 
   {{0xd77402de,0x56a4033a,0x78ac0055,0x00000000}},	//   لارع, ијаз, _ānvī, --, 
   {{0x0b90007b,0x00000000,0x00000000,0x00000000}},	//   _بجود, --, --, --, 
   {{0x87540212,0xdb18054e,0xf4d80b00,0xa2d800bc}},	// [b810] ікує, putâ, лмаш_, नभन्, 
   {{0x67249475,0x4498023a,0x00000000,0x00000000}},	//   _elkj, ивую_, --, --, 
   {{0x656c01ab,0x6ab400b5,0x717801ec,0x00000000}},	//   _dhbh, _ydyf, ңбер_, --, 
   {{0x2564025a,0x57200137,0xb2740395,0x83840124}},	//   bôlo_, _بۉرك, блеш, цыфе, 
   {{0x644c045a,0x69a812eb,0x00000000,0x00000000}},	//   _exbi, जीपी, --, --, 
   {{0x1ae0015b,0x93949476,0x00000000,0x00000000}},	//   যায়া, _نجرا, --, --, 
   {{0xed589477,0xdb189478,0x63bc07f5,0xd3789479}},	//   ғон_, arté, crpn, _ача_, 
   {{0xaf041768,0x3860713c,0xada4004e,0x00000000}},	//   спил, _myhr_, баил, --, 
   {{0x8d240559,0xed58016c,0xd1b808c9,0x28a80950}},	//   иниң_, лои_, _جازا_, करमि, 
   {{0x2a64031c,0x00000000,0x00000000,0x00000000}},	//   _ġob_, --, --, --, 
   {{0x644c0076,0xfeb80451,0x2a640427,0xf8b00954}},	//   _xxbi, _چاهت_, _šob_, _जयजय, 
   {{0xeab80724,0xdd8c721b,0xa038008f,0xbef4007b}},	//   ыйм_, بوی_, _געעפ, _وأنت, 
   {{0xfe7042b5,0xac94001f,0xfd1000ec,0x8ccc01f9}},	//   _قده_, መስልም_, _ڪجن_, _दापो, 
   {{0xfd48063f,0x00000000,0x00000000,0x00000000}},	//   _memọ, --, --, --, 
   {{0xdb181e7b,0x7d1c947a,0x636800d7,0x00000000}},	//   butà, örse, hýna, --, 
   {{0xa6841d4a,0xe7680736,0x3860005c,0xa9680b01}},	//   слад, احسن_, _dyhr_, тиҳа_, 
   {{0xa3c80574,0x2d8c947b,0x649802dd,0x00000000}},	// [b820] ळून_, nqee_, гтер_, --, 
   {{0x69c4947c,0xdb1802fb,0x63bc16a3,0x64a40798}},	//   muke, vrté, trpn, сажа, 
   {{0xe738947d,0xe3b8947e,0xdb1801ed,0xe2980006}},	//   _бен_, убе_, lutá, гае_, 
   {{0xb9e007db,0xd04001e4,0x02b4095f,0xa184013d}},	//   _እቲ_, menɨ, ुलेन, быкл, 
   {{0x6e3c002d,0x612401a8,0xdb180118,0x00000000}},	//   úsbl, _aðla, nutá, --, 
   {{0xdd98013e,0x1fa43eeb,0x25b00076,0xdb0c032e}},	//   қши_, бриг, msyl_, _þjör, 
   {{0x69c4947f,0xdef89480,0xf0340092,0x00000000}},	//   huke, гып_, _እንለም, --, 
   {{0x80c43d1d,0x934000ee,0xdb180518,0x70e0012d}},	//   _राके, _енсе, kutá, फ़ॉल, 
   {{0x69c49481,0x25b000ad,0x92a0012d,0xdb189482}},	//   juke, nsyl_, ółen, jutá, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x60640517,0x5ea43e45,0x69c4003e,0xdb1800db}},	//   _اهال, _همال, euke, tutà, 
   {{0x25b0002d,0x7d1c0267,0xdb1801d3,0x9b240395}},	//   ksyl_, örsb, futá, сфол, 
   {{0x69c49483,0x00000000,0x00000000,0x00000000}},	//   guke, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x0d380d65,0x69c49484,0x69a801ad,0x321c012d}},	//   _תגוב, auke, जीबी, zywy_, 
   {{0x69c49485,0xdb1806ed,0x938801d5,0x00000000}},	//   buke, butá, ҳсда_, --, 
   {{0xb5041533,0xe77803a5,0x69c4192e,0xdb183822}},	// [b830] रालय_, ратә_, cuke, cutá, 
   {{0xf4841968,0x80c4076e,0x799c03ac,0x00000000}},	//   زائی, _रागे, mpsw, --, 
   {{0xd7f85bc5,0x25b00fac,0xf1c400cc,0xe5180037}},	//   _суп_, asyl_, _এনেভ, _धवरि_, 
   {{0x321c033f,0xc2c400c6,0x8ccc466d,0x70e0012d}},	//   tywy_, كيمي, _दाभो, फ़्ल, 
   {{0x80c473ca,0x00000000,0x00000000,0x00000000}},	//   _राखे, --, --, --, 
   {{0xdfcc0451,0xaf94033a,0x00000000,0x00000000}},	//   چيو_, ошиј, --, --, 
   {{0xdfcc9486,0x69c418f7,0x3d0c0034,0x00000000}},	//   نيو_, zuke, ़ाने_, --, 
   {{0x69c49487,0x20300023,0x00000000,0x00000000}},	//   yuke, _ክንምክ, --, --, 
   {{0xace80114,0x6e2c025c,0x83380108,0x724400e5}},	//   ампа_, _żabb, _учёт_, _بھال, 
   {{0x69c49488,0x2d8c0ba7,0x02441359,0x00000000}},	//   vuke, rqee_, _عَلَ, --, 
   {{0x69c49489,0x799c0430,0x6fdc02a0,0x00000000}},	//   wuke, epsw, _महिं, --, 
   {{0x69c4948a,0xdb1802fb,0xd04001e4,0xb0c80118}},	//   tuke, tutá, venɨ, _राँग, 
   {{0x2d8c948b,0x00000000,0x00000000,0x00000000}},	//   qqee_, --, --, --, 
   {{0x69c4948c,0xa80407d8,0xdb1803b2,0x6fdc4e6d}},	//   ruke, озгл, jutæ, _महां, 
   {{0x69c44a7d,0xddc016a3,0x00000000,0x00000000}},	//   suke, _izoš, --, --, 
   {{0x69c4948d,0xaa441555,0x291c00af,0xdb18070b}},	//   puke, _мейл, ötab_, putá, 
   {{0xb0c80490,0x69c40173,0xc6040d2c,0x60c80175}},	// [b840] _रांग, quke, रमेय_, ygfm, 
   {{0x6498948e,0x02b4012c,0x25b0000f,0xdb1802d2}},	//   ртар_, ुल्न, rsyl_, gutæ, 
   {{0x2bb40a30,0x386c0198,0x25b000ad,0xa68400db}},	//   nāc_, ƙera_, ssyl_, _млнд, 
   {{0xe1f8948f,0x25b01141,0xb80801c8,0x00000000}},	//   иге_, psyl_, _ايٽم_, --, 
   {{0xa3e400e1,0x00000000,0x00000000,0x00000000}},	//   _भनक_, --, --, --, 
   {{0xa03403cc,0x00000000,0x00000000,0x00000000}},	//   يىشت, --, --, --, 
   {{0xa4a40086,0xa2d80034,0x34b00014,0xa5040116}},	//   _enòù, नभद्, _سۅنز, _ляңл, 
   {{0xdef89490,0x88d0009e,0x8bec00fe,0x00000000}},	//   рык_, াজিক, টমান_, --, 
   {{0x20d4109a,0x23640115,0x00000000,0x00000000}},	//   _міжс, mloj_, --, --, 
   {{0x20c8021a,0x236402d3,0xa3cc02ab,0x00000000}},	//   _خبري_, lloj_, _शमा_, --, 
   {{0x9b689491,0x23640115,0xdde800f1,0x2f1000e5}},	//   ишма_, oloj_, _چرته_, _lágy_, 
   {{0xf1b00034,0x09e40eac,0x2364007f,0x3ea0010e}},	//   ुंचन, মিনা, nloj_, _ýit_, 
   {{0x3f8c23db,0x236401e4,0x7f40014f,0x00000000}},	//   _hudu_, iloj_, mimq, --, 
   {{0x3f8c9492,0x21dc0069,0x799c000f,0x97a49493}},	//   _kudu_, māhā_, rpsw, жрал, 
   {{0x23649494,0x3f8c9495,0xf8b00050,0x00000000}},	//   kloj_, _judu_, وکھ_, --, 
   {{0x7d189496,0x3f8c9497,0x2364010f,0xc3249498}},	//   _hovs, _mudu_, jloj_, _شە_, 
   {{0x3f8c9499,0x58845aba,0x7d18949a,0x236401e4}},	// [b850] _ludu_, _мына, _kovs, dloj_, 
   {{0xd498949b,0xf1d007f7,0x7d1800d7,0xdb1800ae}},	//   рра_, _समबन, _jovs, irtí, 
   {{0x80c43174,0x798c949c,0x3f8c0268,0x21dc3191}},	//   _राजे, _huaw, _nudu_, hāhā_, 
   {{0x798407a8,0x7d18949d,0x798c949e,0x97000131}},	//   _hihw, _lovs, _kuaw, _تېرى, 
   {{0x7bc8949f,0x798401f7,0x3f8c94a0,0xa27401ec}},	//   hudu, _kihw, _audu_, зұту_, 
   {{0x7bc894a1,0x3f8c801c,0x7d1894a2,0x79840455}},	//   kudu, _budu_, _novs, _jihw, 
   {{0x236400c8,0x73c40598,0x798c0069,0x43840131}},	//   bloj_, _хәзе, _luaw, سلۇق, 
   {{0x7bc894a3,0x3f8c94a4,0x7984014f,0x23640115}},	//   dudu, _dudu_, _lihw, cloj_, 
   {{0x2d98044e,0x798c0428,0x8ccc01f9,0x00000000}},	//   ëse_, _nuaw, _दादो, --, 
   {{0x3f8c94a5,0x7bc80912,0x7984047e,0xdb18000d}},	//   _fudu_, fudu, _nihw, hutä, 
   {{0x3f8c0c09,0x798c00ec,0x7bc894a6,0x7d1c553f}},	//   _gudu_, _auaw, gudu, örsa, 
   {{0x79840810,0x35680020,0x37d0015b,0x81b4010b}},	//   _aihw, ዳለበት_, াবার, _эңәр_, 
   {{0x798494a7,0x7ed456e1,0x7bc80129,0xdb180254}},	//   _bihw, _آزما, audu, dutä, 
   {{0xfe700502,0x7984019f,0x14c40574,0x6f1894a8}},	//   _شدن_, _cihw, _लागण, _howc, 
   {{0xab988ec3,0x7bc894a9,0xc6040b7c,0xed5800f3}},	//   _اختر_, cudu, रम्य_, juži_, 
   {{0x6d4094aa,0xed5808a4,0x798c01c7,0x8c3401c0}},	//   lila, duži_, _fuaw, _гүүр_, 
   {{0xa52494ab,0x9f4c067c,0x6d40062c,0x00000000}},	// [b860] пмад, ïnés_, oila, --, 
   {{0x6d4094ac,0x79840223,0x272c01a8,0xe8c8023a}},	//   nila, _gihw, _sýnd_, _угол_, 
   {{0x29180069,0x3d0c05f9,0x29d4003a,0x9f6002f0}},	//   _iopa_, ़ाते_, læa_, _špíz_, 
   {{0x6d4094ad,0x291894ae,0x6f18011c,0x3f8c94af}},	//   hila, _hopa_, _nowc, _rudu_, 
   {{0x291894b0,0x6d4094b1,0x798407a8,0x200006c8}},	//   _kopa_, kila, _yihw, _ōki_, 
   {{0x6d400a55,0x2918049b,0x3f8c08e7,0x236404a7}},	//   jila, _jopa_, _pudu_, sloj_, 
   {{0x6d4094b2,0xc44810e5,0x236494b3,0x29180789}},	//   dila, _بیان_, ploj_, _mopa_, 
   {{0x291894b4,0x7bc894b5,0x6f18304b,0x6d401a7c}},	//   _lopa_, vudu, _cowc, eila, 
   {{0x7d18389c,0x2918166a,0x3f8c94b6,0x7f4094b7}},	//   _povs, _oopa_, _wudu_, rimq, 
   {{0x6d4094b8,0x7bc8032b,0x3f8c02a8,0x798c02b1}},	//   gila, tudu, _tudu_, _ruaw, 
   {{0xd12c94b9,0x1e8494ba,0x6db44ba9,0xdee44afa}},	//   _حمل_, _елем, _aşağ, _ножи, 
   {{0x798c02b1,0x6d400076,0x7f40047e,0xdb18000d}},	//   _puaw, aila, qimq, httö, 
   {{0x291894bb,0x79840810,0x7d1894bc,0x7bc894bd}},	//   _bopa_, _pihw, _tovs, sudu, 
   {{0x7bc894be,0x79840477,0x00000000,0x00000000}},	//   pudu, _qihw, --, --, 
   {{0xaac400a5,0x36d494bf,0x00000000,0x00000000}},	//   _वाचक, мовр, --, --, 
   {{0x798c0053,0x8f9825f9,0x798407a8,0xdb18005b}},	//   _tuaw, מילי, _wihw, ettö, 
   {{0x9f5c02d3,0x79840099,0xc8ec0183,0x00000000}},	// [b870] _artë_, _tihw, _ওচৰত_, --, 
   {{0xed580e3c,0x291894c0,0xdb18000d,0x00000000}},	//   tuži_, _gopa_, sutä, --, 
   {{0x3b08036e,0x039400d4,0xdb18000d,0x738801e1}},	//   _knaq_, ерія, putä, _ṣebí, 
   {{0x291894c1,0xed58892f,0x69a8278e,0x9580010a}},	//   _zopa_, ruži_, जीवी, ĕлхе, 
   {{0x6d4094c2,0x6f1894c3,0x291894c4,0xd4980b3e}},	//   yila, _rowc, _yopa_, _грб_, 
   {{0x6d4094c5,0x291894c6,0x3cf8033f,0xafe46ac9}},	//   xila, _xopa_, ्ञों_, докл, 
   {{0x213c02d3,0xa11000ae,0x00000000,0x00000000}},	//   _dmth_, ضويت, --, --, 
   {{0x6d4094c7,0xb14c01e1,0x00000000,0x00000000}},	//   wila, _ẹ̀ṣé, --, --, 
   {{0xee381618,0x64500356,0x00000000,0x00000000}},	//   юни_, ăjiţ, --, --, 
   {{0x3b0894c8,0x6d400618,0x6f181174,0x00000000}},	//   _anaq_, uila, _wowc, --, 
   {{0x6d4094c9,0x291894ca,0x332c04c4,0xac3802bf}},	//   rila, _ropa_, _klex_, ючих_, 
   {{0xf1d01b61,0x8ccc012d,0x74dc00cd,0xe9d800d8}},	//   _समान, _दावो, न्तः, окм_, 
   {{0x6d4094cb,0x291894cc,0xdb180664,0x60600150}},	//   pila, _popa_, yttö, _كۇۇل, 
   {{0x6d4094cd,0xc03c02d3,0xdb080267,0x2bc400dc}},	//   qila, _ክንቃለ, _avfä, _विपा, 
   {{0x29180810,0x332c000d,0xdd7001d3,0x00000000}},	//   _vopa_, _olex_, _جھٹک, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6db400ac,0x00000000,0x00000000,0x00000000}},	// [b880] _uşağ, --, --, --, 
   {{0xdb18019f,0x332c94ce,0xe4c8009f,0x00000000}},	//   kutû, _alex_, تبرن_, --, 
   {{0xdb186c3f,0xe8a80073,0x23d400c7,0x00000000}},	//   rttö, करीच, ьцар, --, 
   {{0x2bc40aa2,0x00000000,0x00000000,0x00000000}},	//   _विना, --, --, --, 
   {{0xd00c59c7,0x2d9c00ca,0xb3840592,0xfd5800a2}},	//   یله_, _ntwe_, رجمه, gtaỳ, 
   {{0x332c194f,0xa57401d5,0x69c4003e,0xd24c0338}},	//   _elex_, _آُست, irke, جنه_, 
   {{0xe29894cf,0xd4640139,0x9f5c0240,0x332c94d0}},	//   _мав_, _жире_, _urtë_, _flex_, 
   {{0x2008031c,0x3df411f4,0x13000395,0x00000000}},	//   _ġbid_, езис, _изсм, --, 
   {{0xc62009bd,0x4e9000d1,0x7d1c007c,0xebc00022}},	//   _নেতা_, خشىر, örso, ҳәын, 
   {{0x32240150,0x00000000,0x00000000,0x00000000}},	//   _سۋىپ_, --, --, --, 
   {{0x69c494d1,0x332c005b,0x8ccc150d,0x00000000}},	//   erke, _ylex_, _दारो, --, 
   {{0x9e0894d2,0x90700451,0x1ee80214,0xdb1803b2}},	//   _وياك_, _شهنش, _گوچی_, lutú, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8d5000fd,0xc8c801d9,0x00000000,0x00000000}},	//   _үтәч, ووُن_, --, --, 
   {{0x69c494d3,0x2bc41d7d,0x10640131,0x2bac07f7}},	//   arke, _विया, ﺴﯩﺪﯨ, झीदा, 
   {{0x3b080113,0x3d0c00af,0xcb440022,0x4b5403e6}},	//   _unaq_, ़ावे_, _ахьи, _لێپر, 
   {{0x478494d4,0xdb1894d5,0x00000000,0x00000000}},	// [b890] тырб, kutú, --, --, 
   {{0x2bc47688,0xdb1803b2,0x00000000,0x00000000}},	//   _विमा, jutú, --, --, 
   {{0x78b40433,0x87480092,0xdb1802d2,0x00000000}},	//   mazv, _የጥምቀ, dutú, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2bc40d79,0x332c8023,0xa5c00139,0x00000000}},	//   _विभा, _vlex_, _бөхе, --, 
   {{0x70c805ba,0x7d1c691c,0x78b40433,0x6ff494d6}},	//   रलेल, örsl, nazv, ечих, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69c494d7,0x78b4006f,0xf1d000db,0xda0c0d79}},	//   yrke, hazv, _бөкө, ामात_, 
   {{0x2ca40998,0x78b405b8,0x51844c91,0x00000000}},	//   tbld_, kazv, _жужа, --, 
   {{0xdb180306,0x3bd80de2,0x5fc40456,0x00000000}},	//   vrtá, féq_, रंखल, --, 
   {{0x69b0007d,0x78b40099,0x2a70033f,0x00000000}},	//   _अबही, dazv, _szyb_, --, 
   {{0x4e000107,0x272c0432,0x00000000,0x00000000}},	//   _аҷиб, _oýna_, --, --, 
   {{0x69c43386,0x2d9c0223,0x78b40099,0x2eec198f}},	//   urke, _utwe_, fazv, meef_, 
   {{0x2eec94d8,0x78b4004c,0xfa8001ec,0x12e00150}},	//   leef_, gazv, шқым, _ﺍﻤﻴﺭ, 
   {{0x272c010b,0x3d0c012d,0xab28014b,0x64a400c7}},	//   _aýna_, ़ारे_, _нока_, ҵаза, 
   {{0x2eec5bce,0x63740432,0xe6d401c6,0x1864024c}},	//   neef_, _müný, эцгэ, хаси_, 
   {{0x78b40810,0xfd4c002b,0x69d80311,0x09e400cc}},	// [b8a0] bazv, _aliṅ, ătes, মিহা, 
   {{0x2eec94d9,0xdb180086,0x396400c7,0x272c02d2}},	//   heef_, dutù, _иныҳ, _dýna_, 
   {{0x5f1000dc,0xb0c83337,0x53a00107,0x00000000}},	//   थाम्_, _राजग, гахб, --, 
   {{0xa908022e,0x00000000,0x00000000,0x00000000}},	//   _riоy, --, --, --, 
   {{0x2eec0ba7,0x61440452,0x216800d8,0xdb1803b2}},	//   deef_, неда, пиди_, tutú, 
   {{0x68ec0142,0x00000000,0x00000000,0x00000000}},	//   nebd, --, --, --, 
   {{0x50b40491,0x2eec208d,0x7f58130f,0x2d980077}},	//   ردود_, feef_, макс_, ísen_, 
   {{0x637409a5,0x26d094da,0x20d023ef,0xe29894db}},	//   _düný, ngyo_, _सावध, _хаа_, 
   {{0x4ca402f5,0xdb1800d2,0x657c4afb,0x78b48dc8}},	//   _খাজু, putú, omph, yazv, 
   {{0xdb1803b2,0x00000000,0x00000000,0x00000000}},	//   lutø, --, --, --, 
   {{0x2eec94dc,0x63ac020b,0x78b4006f,0x8d707b1d}},	//   beef_, _jwbn, vazv, دايا, 
   {{0x78b4006f,0x7ae800df,0x00000000,0x00000000}},	//   wazv, ĵeto, --, --, 
   {{0x78b4004c,0x6124032e,0x00000000,0x00000000}},	//   tazv, _aðli, --, --, 
   {{0x26d07bcb,0x272c032e,0xade4000d,0x00000000}},	//   egyo_, _rýna_, _कहतन_, --, 
   {{0x78b494dd,0x272c1873,0xb8e800af,0xdb1803b2}},	//   razv, _sýna_, _लए_, kutø, 
   {{0x78b40433,0x26d004ba,0x2bc484b8,0xcb6800f3}},	//   sazv, ggyo_, _विता, _паје_, 
   {{0x6124008c,0x7afc94de,0x86241b04,0x78b4004c}},	// [b8b0] _eðli, mdst, льфе, pazv, 
   {{0x5dcc0952,0x00000000,0x00000000,0x00000000}},	//   _ﻛﻪﻟﺴ, --, --, --, 
   {{0x77540022,0x2eec0ba7,0x00000000,0x00000000}},	//   _акнф, yeef_, --, --, 
   {{0x31647edf,0x7bc894df,0x272c94e0,0x7d1c007c}},	//   _sklz_, irdu, _týna_, örsj, 
   {{0x7afc70c7,0xb9d802d3,0x776c014b,0x7bc80e78}},	//   idst, _ኽኣ_, mlax, hrdu, 
   {{0x720401d5,0x2eec0af9,0x00000000,0x00000000}},	//   _یوزم, weef_, --, --, 
   {{0x2bc405f9,0x62940ab7,0xdb181512,0x2eec94e1}},	//   _विधा, ıyor, butø, teef_, 
   {{0x7afc94e2,0xc7b40375,0x0294007b,0x9f480241}},	//   jdst, אבק_, _مؤكد, _èbì_, 
   {{0x2eec94e3,0x7afc94e4,0x30c80451,0xdef80023}},	//   reef_, ddst, _يورپ_, ሊስካ_, 
   {{0x7afc94e5,0x2bc48004,0x7de40691,0x518494e6}},	//   edst, _विदा, اسيم, _чуба, 
   {{0x7afc5d94,0x00000000,0x00000000,0x00000000}},	//   fdst, --, --, --, 
   {{0x68ec02d0,0x2eec0e14,0xdb18002d,0x67f000e4}},	//   webd, qeef_, lstê, _ẽjoy, 
   {{0xfeb827e3,0x7bc894e7,0xcdc08f62,0x657c94e8}},	//   _سانت_, ardu, _салқ, ymph, 
   {{0x7afc94e9,0x636801a8,0xdb1894ea,0xa36801d5}},	//   adst, rýni, nstê, ltеt, 
   {{0x186494eb,0x636809f3,0x776c0005,0x68ec020c}},	//   вари_, sýni, flax, rebd, 
   {{0xed580bb8,0x7c846ff7,0x00000000,0x00000000}},	//   drži_, _суче, --, --, 
   {{0xa68494ec,0x35c4013e,0x377402dd,0x850850e5}},	// [b8c0] тлад, латҳ, уырс, ндаң_, 
   {{0x657c1730,0xdb18000f,0xc4cc1fd2,0x3e6c0332}},	//   umph, jstê, ालेख, lótú_, 
   {{0xf650066d,0xdb180b21,0x657c01f5,0xe73801f4}},	//   لئے_, dstê, rmph, _жен_, 
   {{0x24984f3b,0x776c1709,0x00000000,0x00000000}},	//   scpm_, clax, --, --, 
   {{0x657c01af,0x26c094ed,0x15401142,0x7d1c691c}},	//   pmph, _idko_, _ӂерм, örsk, 
   {{0xdb18168c,0x430400d1,0xbaa40131,0x660494ee}},	//   sutø, _әҗда, _ﺋﯩﻠﮕ, _irkk, 
   {{0xe36494ef,0x7afc94f0,0xdea094f1,0xbec80166}},	//   _акви, ydst, لیای, еңез_, 
   {{0xd004026a,0xdd984411,0x00000000,0x00000000}},	//   ђење_, мшо_, --, --, 
   {{0xe0d823a4,0x9cc894f2,0x629c012c,0x6264129d}},	//   _ова_, мына_, ěpod, _شارق, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x776c94f3,0x6e3c002d,0x7bc80129,0xdb18007c}},	//   ylax, úsbr, urdu, yrtä, 
   {{0x7afc75fa,0x6604005b,0x7bc88db1,0x00000000}},	//   udst, _orkk, rrdu, --, 
   {{0x7afc94f4,0xdb180036,0x3a2c00e4,0x00000000}},	//   rdst, lstë, áep_, --, 
   {{0x39500c86,0xc03c0023,0x7afc03b2,0x00000000}},	//   unzs_, _ክንሓል, sdst, --, 
   {{0xa8540184,0xd7600ec9,0x660402f6,0xdb1894f5}},	//   герә, لنسی, _arkk, nstë, 
   {{0xdb18036e,0x00000000,0x00000000,0x00000000}},	//   istë, --, --, --, 
   {{0xdb1801e6,0x7c2803cb,0x20d03042,0x776c058a}},	// [b8d0] rrtä, lydr, _सांध, rlax, 
   {{0xdb0808fb,0x776c94f6,0xb4cc0490,0x6e2c0210}},	//   _avfø, slax, ळले_, _żabk, 
   {{0x66041073,0x00000000,0x00000000,0x00000000}},	//   _erkk, --, --, --, 
   {{0xc2c40597,0x2bc408a3,0x673400e4,0x00000000}},	//   ليمي, _विसा, chyj, --, 
   {{0xdb18002d,0x988001ef,0x95c8009d,0x00000000}},	//   tstê, _míči_, _юуна_, --, 
   {{0x307409fe,0xf1d494f7,0x021801ed,0xed580e04}},	//   луйс, डंबन, ئٹوں_, prži_, 
   {{0x62840122,0xa06494f8,0xdb1894f9,0x00000000}},	//   _úkon, лаша_, rstê, --, 
   {{0x3cfc5133,0xc03c0023,0x7c280076,0xdc5c0023}},	//   _aavv_, _ክንምል, dydr, _ዳሕራይ_, 
   {{0x2bc412ec,0x3254447e,0x00000000,0x00000000}},	//   _विहा, _свар, --, --, 
   {{0xacf41fbe,0x7c280042,0xa9a43d09,0x00000000}},	//   учиј, fydr, һимд, --, 
   {{0x7c280042,0xc1040472,0x67340124,0x00000000}},	//   gydr, _خولي, yhyj, --, 
   {{0xa9a494fa,0xe9a494fb,0xdca000d1,0xf988025d}},	//   лимд, ламп, _һаши, _זר_, 
   {{0x2bc4072a,0xdb18180f,0x6124032e,0xbcfc00c7}},	//   _विवा, istè, _eðlu, moĩn, 
   {{0x7c2894fc,0x6e280198,0xfe702f84,0xdca036da}},	//   bydr, myeb, _بدم_, _лаши, 
   {{0xc04402d3,0x98a01cd6,0x6e2894fd,0x673402d0}},	//   _እንተፈ, сисе, lyeb, thyj, 
   {{0x6f1c94fe,0x00000000,0x00000000,0x00000000}},	//   ösch, --, --, --, 
   {{0x6e285088,0xa3b40cb4,0xe57894ff,0xdb180122}},	// [b8e0] nyeb, चीन_, еза_, nutý, 
   {{0x9f5c0004,0xdb183bd2,0x6ab403b9,0x2dd01884}},	//   _krtã_, ystë, _heyf, _ﻛﻪﻟﻤ, 
   {{0x6ab42c6f,0x68fc03a2,0xe3b006f6,0x232800f3}},	//   _keyf, _iapd, صرا_, ножи_, 
   {{0xe738169c,0xe2989500,0x68fc0652,0x6e289501}},	//   _чем_, хад_, _hapd, kyeb, 
   {{0x68fc00df,0xdb1800e4,0x660401f4,0x7c280210}},	//   _kapd, jutý, _urkk, zydr, 
   {{0x6ab4008c,0x6e289502,0x3fc406dc,0xdb1804e6}},	//   _leyf, dyeb, ариғ, tstë, 
   {{0x2bc44d21,0x68fc0334,0xd24c0372,0x9fe42bd8}},	//   _विषा, _mapd, ينۅ_, استه, 
   {{0xcfe40597,0xdb180a40,0x68fc9503,0x7c2802fb}},	//   افيه_, rstë, _lapd, vydr, 
   {{0x7c280368,0x6e289504,0xa0a49505,0xdb1801c7}},	//   wydr, gyeb, _базд, sstë, 
   {{0x2bc49506,0x68fc06a3,0x23640457,0xd1e802d3}},	//   _विशा, _napd, looj_, ዘብቲ_, 
   {{0x3b544880,0x6e280083,0x60d827ac,0xdb1801c7}},	//   икор, ayeb, _ictm, lsté, 
   {{0x2bc49507,0x6ab40332,0x6e289508,0x54540a7c}},	//   _विरा, _ceyf, byeb, רסטן_, 
   {{0x6e280223,0x27f80334,0x68fc0432,0x6ab408a5}},	//   cyeb, _aspn_, _bapd, _deyf, 
   {{0x68fc8d22,0x23640070,0xf9880451,0x3944180f}},	//   _capd, hooj_, ئنسي_, òls_, 
   {{0xb8fc084a,0xdb681422,0x00000000,0x00000000}},	//   _डा_, _прил_, --, --, 
   {{0x6ab40009,0xdb1c0e03,0x6e2c0210,0x00000000}},	//   _geyf, öväl, _żabi, --, 
   {{0x6d5c06af,0x68fc045a,0xa92400de,0x093400ec}},	// [b8f0] ésag, _fapd, _bažā, _گريج, 
   {{0x45d4188c,0x68fc3298,0x44b49509,0xdb18000d}},	//   софс, _gapd, йбус, hutü, 
   {{0xa9240029,0xdb18950a,0x787415f8,0x00000000}},	//   _dažā, esté, _خُدا, --, 
   {{0xade4007d,0x60d80175,0x35d40107,0x00000000}},	//   _कहलन_, _actm, _комё, --, 
   {{0xd5ac00f8,0x6284012c,0x34940166,0x68fc950b}},	//   _رہا_, _úkol, _вагр, _yapd, 
   {{0x2bc493d3,0x9f5c00cf,0xc0c8026a,0x7eac01ec}},	//   _विला, _artà_, гуће_, _ﺴﺘﻭﻁ, 
   {{0x60dc0699,0x636800e4,0x5348030d,0x00000000}},	//   òpma, týnt, _пăкă, --, 
   {{0x6e28004b,0xdb180332,0x00000000,0x00000000}},	//   tyeb, artú, --, --, 
   {{0xed584170,0xd1b001d5,0x6ab402d2,0x00000000}},	//   кои_, _چیچک, _reyf, --, 
   {{0xd16406bb,0xed4400d6,0x6e280a49,0xa3c801f9}},	//   _съби, рноп, ryeb, ळंच_, 
   {{0x68fc0455,0xdb180254,0x00000000,0x00000000}},	//   _rapd, butü, --, --, 
   {{0x6b648000,0x753400b5,0x6a843252,0xdb1800d8}},	//   ркма, _llzz, илна, dutó, 
   {{0x68fc02e2,0x00000000,0x00000000,0x00000000}},	//   _papd, --, --, --, 
   {{0x68fc014f,0x23640115,0xdb18950c,0xccf401ec}},	//   _qapd, zooj_, futó, _сқо_, 
   {{0x193c044e,0x68fc0810,0x23640218,0xdb1801ed}},	//   _ኣእምሮ, _vapd, yooj_, gutó, 
   {{0x7d1c691c,0xab780101,0x68fc0051,0xdb1802f0}},	//   örsv, _جمعا_, _wapd, ysté, 
   {{0x68fc950d,0xe56801c6,0x00000000,0x00000000}},	// [b900] _tapd, виад_, --, --, 
   {{0xdb18012d,0xda78011a,0x00000000,0x00000000}},	//   butó, _בנפר, --, --, 
   {{0x66e4950e,0xdb1800d8,0xc32801e1,0x00000000}},	//   _кона, cutó, _àíkà, --, 
   {{0xa2040124,0x765c00b5,0xf3c8950f,0xdb1801c7}},	//   ипед, _fxsy, ابله_, tsté, 
   {{0xe1f007a7,0x2364010f,0x1a98010f,0x2a5c04b2}},	//   تسا_, rooj_, דינע, _ወንበሮ, 
   {{0xdb189510,0x23640218,0x69cc012c,0xd0d40212}},	//   rsté, sooj_, _तिनी, идії_, 
   {{0xc0c47400,0xa31400c7,0x00000000,0x00000000}},	//   _ғәли, _кьаш, --, --, 
   {{0xe508043e,0x8f040408,0x00000000,0x00000000}},	//   _होति_, ахьа_, --, --, 
   {{0xa1880124,0x00000000,0x00000000,0x00000000}},	//   _абаа_, --, --, --, 
   {{0x61e09511,0xdb18000d,0x00e40633,0x00000000}},	//   mtol, sutü, _دتری, --, 
   {{0x611401e1,0x712400cf,0x1dc00073,0xf8b801e0}},	//   _e̟lé, _ارقل, _शिकत, һөн_, 
   {{0x61e000ec,0xbcfc00c7,0x00000000,0x00000000}},	//   otol, moĩm, --, --, 
   {{0x61e09512,0xf8b801c6,0xa3b4044b,0x4bc000db}},	//   ntol, лөн_, चीत_, бөөг, 
   {{0x3f840198,0x61e09513,0xba48013a,0x00000000}},	//   lmmu_, itol, jlůž, --, 
   {{0xd6d89514,0x61e05943,0x1768010b,0x7d1c01e3}},	//   кта_, htol, врап_, örsu, 
   {{0xd5a0036b,0xe3cc00fe,0x00000000,0x00000000}},	//   قلری, ৰবাব, --, --, 
   {{0x753400c6,0x86989515,0xfdf825c9,0x4b7c00df}},	// [b910] _plzz, ркус_, ्टिस_, _באהו, 
   {{0x61e09516,0xdb1856eb,0x399c01e1,0x00000000}},	//   dtol, cutò, _iìs_, --, 
   {{0x61e09517,0x49149518,0xf1c8000d,0x00000000}},	//   etol, दारो_, _रिहन, --, 
   {{0x69cc0316,0x61e09519,0xc87805d1,0x291c0037}},	//   _तिमी, ftol, üğe_, ötav_, 
   {{0x61e0951a,0x42c801ec,0xd498030d,0x00000000}},	//   gtol, ргін_, _арб_, --, 
   {{0x7534020b,0x61f400ee,0x21f000d1,0xd3a41fbe}},	//   _ulzz, çyla, سكىس, _врап, 
   {{0x6ac0009e,0x61e00083,0x00000000,0x00000000}},	//   ষ্টো, atol, --, --, 
   {{0x27a8010f,0x733801a9,0x3cb401ec,0xbf64951b}},	//   נספּ, _ёзар_, _ﺼﺩﺍﻤ, يديو, 
   {{0xab28020a,0x690c0254,0x399c0248,0x00000000}},	//   ҳона_, _jõeä, _nìs_, --, 
   {{0x8234951c,0x7d280022,0x9f5c01ef,0x00000000}},	//   _برفا, иныҳ_, _vrtá_, --, 
   {{0xab282a65,0x00000000,0x00000000,0x00000000}},	//   гона_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x799c0369,0x00000000,0x00000000,0x00000000}},	//   gqsw, --, --, --, 
   {{0x7d1c04f3,0x98a000ee,0xa96801a9,0x00000000}},	//   örst, зире, уига_, --, 
   {{0xd940951d,0x2d840204,0xf1d0951e,0x66d0022e}},	//   чери, mmle_, _समझन, _bаkа, 
   {{0xa90801a9,0x2d8403e0,0xfc300244,0x00000000}},	//   _chоr, lmle_, _تحه_, --, 
   {{0x61e00175,0x00000000,0x00000000,0x00000000}},	// [b920] xtol, --, --, --, 
   {{0xba4800bc,0xe8f8009b,0xf1e001ec,0x69c801ec}},	//   ulůž, _сло_, _ﺍﻻﻫﺘ, _ﺑﻪﻳﺰ, 
   {{0xb4000137,0x2d8401ab,0x61e001ab,0xf1e00220}},	//   мүрд, imle_, wtol, _ﺍﻻﻨﺘ, 
   {{0x61e0951f,0x59ac4aa7,0xe2840022,0x27b000fb}},	//   ttol, जीकर, блеи, _мәғс, 
   {{0x61e003c1,0xd36c9520,0xdb1c0fac,0x00000000}},	//   utol, رهه_, _åvåk, --, 
   {{0x67249521,0x20d400d4,0x00000000,0x00000000}},	//   _hokj, сідс, --, --, 
   {{0x6724020c,0x442c01bf,0x00000000,0x00000000}},	//   _kokj, _æd_, --, --, 
   {{0x61e09522,0x3f84020b,0x00000000,0x00000000}},	//   ptol, ummu_, --, --, 
   {{0x425401d9,0x1718008f,0xa1c40209,0x61e0031c}},	//   _بچار, רופע, _ыбад, qtol, 
   {{0x6724002d,0x71702a8b,0xd5f80a7c,0x399c0248}},	//   _lokj, _قۇنا, נפיר, _rìs_, 
   {{0x799c0007,0x2a7003cb,0x399c01e1,0xdd980139}},	//   wqsw, _ayyb_, _sìs_, _өшл_, 
   {{0x272c0051,0xeef40024,0x00000000,0x00000000}},	//   _uýnh_, _мячэ, --, --, 
   {{0xde7400db,0x7d1c3167,0x00000000,0x00000000}},	//   _اداع, örss, --, --, 
   {{0xd7f89523,0x59ac07f7,0x7c340354,0xcdf4011a}},	//   луб_, जीगर, _мелх, _למדי_, 
   {{0xdb18041e,0x704802d3,0x69cc4668,0xfc644117}},	//   lstí, _እንተጸ, _तिथी, _بخشی, 
   {{0x35b40022,0x09e400cc,0x00000000,0x00000000}},	//   жбар, মিজা, --, --, 
   {{0x7aec9524,0x9f5c008e,0x00000000,0x00000000}},	// [b930] _ibat, _irtä_, --, --, 
   {{0xdb180597,0x74a89525,0x21e001ec,0x272c0092}},	//   istí, рсаң_, _ﺍﺴﺘﺭ, ደሌለበ, 
   {{0x57f0038f,0x6724002d,0xf3f800a7,0xdba002dd}},	//   _བགྲོ_, _fokj, рнеш_, _ﺍﻟﺪﻯ_, 
   {{0x67246d6d,0x7aec0135,0xdb18000f,0x52cc0131}},	//   _gokj, _jbat, lstâ, _ﺗﯚﯞﻩ, 
   {{0x7aec9526,0x69d80210,0x00000000,0x00000000}},	//   _mbat, ąteg, --, --, 
   {{0xdb189527,0xe79404d3,0x93949528,0x3494013e}},	//   nstâ, _دایک, _هجرا, _фавр, 
   {{0xbcfc00e4,0x272c0252,0x00000000,0x00000000}},	//   moĩh, _sýni_, --, --, 
   {{0xdb1801a8,0xf1d000db,0x7aec9529,0x7648032e}},	//   fstí, _жөкө, _nbat, _þeys, 
   {{0x2d98006a,0xc2c400ec,0xdb182507,0x00000000}},	//   êse_, _ريلي, gstí, --, 
   {{0x7aec6f2e,0x320c0109,0x2d90952a,0x00000000}},	//   _abat, _irey_, öze_, --, 
   {{0x7aec03b2,0x2d84952b,0x76400213,0x00000000}},	//   _bbat, rmle_, _əlya, --, 
   {{0xf8a80d65,0x7aec07ab,0x8234040b,0x320c0100}},	//   _יש_, _cbat, _برہا, _krey_, 
   {{0x2bc410fa,0x6724952c,0x6a8464b6,0xdb184dda}},	//   _विका, _rokj, юлма, fstâ, 
   {{0xbe80052f,0x7aec952d,0x9f5c010e,0x6724952e}},	//   _яңыл, _ebat, _ertä_, _sokj, 
   {{0x6724020b,0x00000000,0x00000000,0x00000000}},	//   _pokj, --, --, --, 
   {{0x7aec952f,0x7a30035b,0x00000000,0x00000000}},	//   _gbat, _ẽtej, --, --, 
   {{0xa5249530,0xe6181751,0xdb1806ed,0x291c2771}},	// [b940] омад, шда_, bstâ, ötas_, 
   {{0x2bec09d9,0x7aec044e,0x999401b9,0x94c800f1}},	//   _जहां_, _zbat, _گپیر_, لامې_, 
   {{0x320c05b1,0x00000000,0x00000000,0x00000000}},	//   _arey_, --, --, --, 
   {{0xdcb40da5,0x320c9531,0x624401d5,0x386c0e78}},	//   _आज्ञ, _brey_, _fаol, ßere_, 
   {{0xa1884cd0,0x386c236c,0x00000000,0x00000000}},	//   абда_, ğere_, --, --, 
   {{0x1fa49532,0x320c9533,0xdb180162,0x386c03e0}},	//   ориг, _drey_, vstí, şere_, 
   {{0x320c0014,0xa2d412fc,0x00000000,0x00000000}},	//   _erey_, _ويست, --, --, 
   {{0x320c9534,0x2ff41870,0xdb189535,0x00000000}},	//   _frey_, ستىڭ, lutö, --, 
   {{0x320c9536,0x6e2c031c,0xfcc40131,0x03a40454}},	//   _grey_, _żabr, пәйм, _фиғо, 
   {{0xdb189537,0xb3d001ad,0x20180309,0x00000000}},	//   rstí, _हिमख, äpis_, --, 
   {{0x7aec004e,0xdee4228c,0xf8b801e0,0x6d5c003e}},	//   _pbat, _можи, ҙөп_, ésaa, 
   {{0x7aec0327,0xa0740124,0xdb180254,0x93f8011a}},	//   _qbat, _лыҵш, hutö, בלטי, 
   {{0xda7809a5,0x8650013f,0x7aec037e,0xdb189538}},	//   рян_, nbɔd, _vbat, kutö, 
   {{0x7aec0042,0x00000000,0x00000000,0x00000000}},	//   _wbat, --, --, --, 
   {{0xdb189539,0x7aec0135,0x889407a5,0x9b741063}},	//   dutö, _tbat, дирх, _واعص, 
   {{0x4c38025f,0x291c01e3,0x2cb00205,0x00000000}},	//   _כתוב, ötar_, ızde_, --, 
   {{0xd498953a,0xdb180137,0xf594141b,0xe7780124}},	// [b950] аре_, mstà, سلاج, сатә_, 
   {{0x44f4084c,0x25a400c6,0x94a801c0,0xdb1875ee}},	//   мпус, íola_, ртаа_, hrtü, 
   {{0xf48401ed,0xd7f832ea,0x938801a9,0x00000000}},	//   سائی, _туп_, асда_, --, 
   {{0x320c953b,0xdb1856ed,0x7a400129,0x964401c6}},	//   _prey_, nstà, _gâté, _дэгд, 
   {{0xdb1801e3,0x320c06be,0x00000000,0x00000000}},	//   butö, _qrey_, --, --, 
   {{0xa2801b12,0x320c062c,0xdb180306,0x272c08ce}},	//   ریلو, _vrey_, vrtý, _dýnu_, 
   {{0xc9540bd9,0xdfcc00b2,0xdb18953c,0x00000000}},	//   ומס_, هيو_, kstà, --, 
   {{0x60600075,0x2ca800bc,0x63a40022,0x320c0f85}},	//   رۇنل, _řad_, _хырҕ, _trey_, 
   {{0xc16c0116,0x67380af9,0x719800f2,0xc8580092}},	//   _аҗ_, ëtji, _طناز_, _የድንጋ, 
   {{0x7d1c01e3,0xe80c0118,0x00000000,0x00000000}},	//   örsp, ाटमा_, --, --, 
   {{0x71702002,0x8144036b,0xdb18000d,0x00000000}},	//   _قۇچا, _تنلن, hutõ, --, 
   {{0x2d9874c3,0x6434010f,0x6dc000f7,0x16180709}},	//   íses_, פארא_, _كۅبۅ, नमार_, 
   {{0x7e000588,0xae040220,0x5e98011a,0x7eac0150}},	//   _аҧыз, _ءوتى, _הבנק, _ﺴﺘﻀﻁ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb18953d,0xb9240521,0xfd1005d9,0x7b04023a}},	//   bstà, _hapụ_, _ججن_, öttä, 
   {{0x2d9c136f,0xeab8036b,0x00000000,0x00000000}},	//   _kuwe_, _уйи_, --, --, 
   {{0x9660953e,0x9ad001f2,0x2018063f,0x2d9c0248}},	// [b960] екте, _dịde, ̣pi_, _juwe_, 
   {{0x6498953f,0x2d9c9540,0x69c49541,0xb92401f2}},	//   стар_, _muwe_, mske, _mapụ_, 
   {{0xdb189542,0xa3b49543,0x2d9c9544,0x6b9401d5}},	//   rutö, चीं_, _luwe_, _kiyg, 
   {{0x2d9c24d1,0x4914012c,0xd24c0214,0x73480212}},	//   _ouwe_, दाको_, گنه_, очів_, 
   {{0x69c49545,0x2d9c9546,0xbcfc0124,0xdb189547}},	//   nske, _nuwe_, moĩv, nstá, 
   {{0xd24c9548,0x9f5c0030,0xe9f40150,0x69c41f39}},	//   دنه_, _isté_, _ءﺍ_, iske, 
   {{0x2d9c9549,0xaabc954a,0x00000000,0x00000000}},	//   _auwe_, ्णाक, --, --, 
   {{0x44440097,0xdef8954b,0x2d9c01ee,0x69c4954c}},	//   mz_, сык_, _buwe_, kske, 
   {{0x4444954d,0x69c438a2,0x9f5c0c6a,0xc8dc0034}},	//   lz_, jske, _jsté_, _बांट, 
   {{0x4444954e,0x2d9c034c,0x69c4954f,0x7c34376d}},	//   oz_, _duwe_, dske, деох, 
   {{0x44440207,0x06d40183,0x2d9c0158,0x6b94010e}},	//   nz_, হ্যি, _euwe_, _biyg, 
   {{0x44449550,0xdee49551,0x2d9c01e0,0xaf0402bf}},	//   iz_, _ходи, _fuwe_, _очік, 
   {{0x2d9c0066,0x69c49552,0x444405b1,0xceb0008f}},	//   _guwe_, gske, hz_, _טיף_, 
   {{0x2bc410eb,0x25f0007d,0x97a40116,0x67340153}},	//   _विचा, ुबनी_, зрал, ekyj, 
   {{0xc8640e26,0x776c0077,0x69c49553,0xb8f400dc}},	//   етти, toax, aske, _हय_, 
   {{0x44441201,0x69c48c05,0x2d9c030a,0xdb080267}},	//   dz_, bske, _yuwe_, _avfö, 
   {{0x44449554,0x69c401ed,0x69d8033f,0xb9840131}},	// [b970] ez_, cske, ątec, _отоқ, 
   {{0xd4989555,0x272c066a,0x44449556,0x7d0803b2}},	//   сра_, _sýnt_, fz_, ndds, 
   {{0x9f5c204e,0xd85000db,0xa50800db,0x00000000}},	//   _esté_, _ченө, تىلە_, --, 
   {{0x9f5c03b2,0xbcfc0022,0xd6d80114,0x2bc41788}},	//   _ertú_, moĩu, _уто_, _विघा, 
   {{0x44449557,0xecdc07f7,0x9f480248,0x292802d2}},	//   az_, _मालफ, _èbù_, _útað_, 
   {{0x2d9c27bb,0x2ba400ef,0x00000000,0x00000000}},	//   _ruwe_, _lēca_, --, --, 
   {{0x4444068f,0x64e00490,0x2d9c9558,0xe9f401ec}},	//   cz_, _पातळ, _suwe_, _ءﺎ_, 
   {{0xee38334a,0xdb189559,0x69c4955a,0x00000000}},	//   жни_, ystá, yske, --, 
   {{0x7e5400a8,0xedc4004b,0x798402d0,0xfe5401d3}},	//   етэц, ړېږي_, _ohhw, ٹیوب_, 
   {{0x2d9c1682,0x69c4955b,0xdb18955c,0x2bc8955d}},	//   _vuwe_, vske, nstæ, олоп_, 
   {{0x6144278f,0x2d9c1418,0x3cf80254,0x7de4032f}},	//   _تىلە, _wuwe_, õrva_, وسیم, 
   {{0x2d9c00ec,0x69c4955e,0x2b140801,0x798402d0}},	//   _tuwe_, tske, фьор, _ahhw, 
   {{0x6f08955f,0x2d9c009f,0x44449560,0xdd640451}},	//   mdec, _uuwe_, zz_, _ڪڍيو_, 
   {{0x69c49561,0xdb189562,0x68f8022e,0x00000000}},	//   rske, rstá, еtda, --, 
   {{0x69c49563,0x9f5c011c,0x98a00408,0x66e49564}},	//   sske, _artù_, тисе, мова, 
   {{0x6f089565,0x69c49566,0x8d7404d3,0x44449567}},	//   ndec, pske, _باڵا, vz_, 
   {{0x44440226,0xdb18008c,0xaa44652e,0x6d4003a2}},	// [b980] wz_, fstæ, _цепл, ohla, 
   {{0x6d409568,0xc3306788,0xdb1856a9,0x6f080112}},	//   nhla, گەر_, gstæ, hdec, 
   {{0x44440207,0xd91804ac,0x9f48002e,0xa2e4005b}},	//   uz_, _וויל, ëmël_, доед, 
   {{0x44441a5d,0xc3302033,0xe29801c0,0x6d4001ab}},	//   rz_, دەر_, цад_, hhla, 
   {{0x44449569,0x6d40956a,0x7d08049f,0x291806df}},	//   sz_, khla, ydds, _knpa_, 
   {{0x44440408,0x6f08956b,0x2908956c,0xf7c40244}},	//   pz_, edec, ndba_, _تزیپ, 
   {{0x2b0c2007,0x6d400afe,0x6f080086,0x54340050}},	//   ियाँ_, dhla, fdec, _قرٲر, 
   {{0x6f08004e,0x851c02e5,0x7d080042,0x6d400419}},	//   gdec, नावट_, wdds, ehla, 
   {{0xa0a4516c,0x25b00af9,0x2918005b,0xf1a802f2}},	//   _жазд, npyl_, _onpa_, _فاله_, 
   {{0x6d40956d,0x6f180142,0x6f08033f,0x29080010}},	//   ghla, _enwc, adec, jdba_, 
   {{0xd00c01d9,0x6f08956e,0x29080009,0x00000000}},	//   _پلن_, bdec, ddba_, --, 
   {{0x7c441591,0x29181709,0x2cb0956f,0x6d409570}},	//   _đurđ, _anpa_, ızda_, ahla, 
   {{0x6d404695,0x1d080108,0xa2a40037,0x25a4007b}},	//   bhla, _меди_, _छलन्, íoll_, 
   {{0x6d409571,0x00000000,0x00000000,0x00000000}},	//   chla, --, --, --, 
   {{0x5c0406bb,0x099400d8,0x00000000,0x00000000}},	//   _цяла, тарџ, --, --, 
   {{0x399401e1,0x29189572,0x29080009,0x00000000}},	//   _bùsì_, _enpa_, adba_, --, 
   {{0xdef8010c,0xdedc0023,0x7bc801e3,0x224401d3}},	// [b990] ሊስና_, ናሕና_, lsdu, jzok_, 
   {{0x428c0020,0x6f0805d6,0x57a401b9,0x7bc801c3}},	//   ንድነት_, zdec, _ошма, osdu, 
   {{0xdb189573,0xfe0801fb,0x7afc00d8,0x6f08013a}},	//   rstæ, _lữ_, oest, ydec, 
   {{0x6d400122,0x7bc8010a,0xdb189574,0x6f080393}},	//   zhla, isdu, sstæ, xdec, 
   {{0xfe0801dc,0x7afc00a8,0xdb189575,0x63ac035a}},	//   _nữ_, iest, mstä, _etbn, 
   {{0xdb189576,0x6f080798,0x6f180042,0xf0e8568c}},	//   lstä, wdec, _snwc, سىبى_, 
   {{0x6f08101d,0x6d400218,0x00000000,0x00000000}},	//   tdec, vhla, --, --, 
   {{0xdb189577,0x7afc0f85,0x6d400369,0x6e940131}},	//   nstä, jest, whla, ىلغا, 
   {{0x6f089578,0x6d409579,0xdb18005b,0xfe080208}},	//   rdec, thla, istä, _cữ_, 
   {{0x1e80957a,0xfe080016,0xdb185df7,0x7afc16ca}},	//   ылым, _dữ_, hstä, eest, 
   {{0xc5b40ed9,0x3b0801d9,0x6d40957b,0xdb1801e6}},	//   _བསྐྲ, _baaq_, rhla, kstä, 
   {{0x6d405c81,0xac7c0201,0xd9b400eb,0x9c8000d7}},	//   shla, _የዓለም_, _জমজম, áčam, 
   {{0xdb18049f,0x386c03fa,0x3b080067,0xdd1003e6}},	//   dstä, ßern_, _daaq_, _ڕووخ, 
   {{0x9c8009a8,0x7bc800d8,0xad240046,0xdb18005b}},	//   ščam, bsdu, _سىبى, estä, 
   {{0xdb180ade,0x20080162,0x29080010,0xfe080051}},	//   fstä, _ábit_, rdba_, _zữ_, 
   {{0xdb185b00,0x00000000,0x00000000,0x00000000}},	//   gstä, --, --, --, 
   {{0x69944834,0x29180a2e,0x63ac00fb,0xe6480c69}},	// [b9a0] _прох, _tnpa_, _stbn, чпад_, 
   {{0xec0801dc,0x25b0957c,0x00000000,0x00000000}},	//   _kế_, rpyl_, --, --, 
   {{0xe3b07cbc,0xdb1808c6,0x3b080009,0x00000000}},	//   ارئ_, bstä, _yaaq_, --, 
   {{0x213c01ab,0x224401c4,0xdce80135,0x25b00076}},	//   _slth_, tzok_, _tifħ, ppyl_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7afc957d,0x26c0035b,0x59d04fed,0x059c0150}},	//   zest, _heko_, _तिसर, _ﭘﯘﺷﭙ, 
   {{0x26c0957e,0x224400dd,0x7afc957f,0xfe080208}},	//   _keko_, szok_, yest, _sữ_, 
   {{0x7afc0f71,0x26c0035b,0x3f141608,0x00000000}},	//   xest, _jeko_, тдис, --, 
   {{0x26c0004b,0xdb187c52,0x25a00309,0x73740124}},	//   _meko_, nstå, _jukl_, _рырх, 
   {{0x26c09580,0x7afc9581,0x3b089582,0xec0801fb}},	//   _leko_, west, _saaq_, _bế_, 
   {{0x7afc9583,0xdb1802f6,0x59d00456,0x1ea8009f}},	//   test, ystä, _तिहर, _فاشي_, 
   {{0x7afc9584,0x3b089585,0xec08001e,0x6b4403b2}},	//   uest, _qaaq_, _dế_, _lógf, 
   {{0x7afc9586,0xdb189587,0x99640108,0x00000000}},	//   rest, vstä, етвл, --, 
   {{0x7afc9588,0x26c09589,0xdb183e04,0xadf40131}},	//   sest, _aeko_, dstå, _рошә, 
   {{0x26c0958a,0xd90c5c81,0xdb183714,0x3b08013c}},	//   _beko_, لیک_, tstä, _taaq_, 
   {{0x26c0958b,0x00000000,0x00000000,0x00000000}},	//   _ceko_, --, --, --, 
   {{0xdb18958c,0x80e007f7,0x45d4958d,0xa908022e}},	// [b9b0] rstä, नलाइ, лотс, _zkоm, 
   {{0xdb1841b7,0x3834958e,0x26c0009d,0x38c8958f}},	//   sstä, _анор, _eeko_, _کاکی_, 
   {{0x3940067c,0x26c09590,0xec08001e,0xdb180267}},	//   _ilhs_, _feko_, _xế_, pstä, 
   {{0xd6d85402,0x26c09591,0x2b18012d,0x95c8005a}},	//   _это_, _geko_, धाएँ_, _нуга_, 
   {{0x6d5c0098,0x00000000,0x00000000,0x00000000}},	//   ésak, --, --, --, 
   {{0x26c004a7,0x58d00183,0x20080003,0x6ff4009d}},	//   _zeko_, দ্ৰী, _ġbir_, вчих, 
   {{0x26c00099,0x83f81925,0xc9180375,0xa0640354}},	//   _yeko_, _перс_, תחות_, каша_, 
   {{0x92b40014,0x8e0400ee,0xec080051,0x26c00051}},	//   _سحرا, емиң_, _rế_, _xeko_, 
   {{0x5f740597,0xd9e0033f,0xe0540014,0xb2748726}},	//   خميس_, कूमत_, _ییٖت_, _рлаш, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6b44002e,0x00000000,0x00000000,0x00000000}},	//   _jógg, --, --, --, 
   {{0xa9a49592,0xec08004d,0xdb180158,0xe9a46179}},	//   кимд, _vế_, ystå, камп, 
   {{0x26c00588,0xad2400aa,0x6b44022c,0x39400051}},	//   _reko_, _لرغو, _lógg, _blhs_, 
   {{0x26c09593,0xec0801dc,0xdca09594,0x48d000bd}},	//   _seko_, _tế_, _каши, িভ্র, 
   {{0x6b64036b,0x26c09595,0x69cc0490,0x25a002f0}},	//   _икка, _peko_, _तिकी, _sukl_, 
   {{0xdb189596,0x8d74001f,0x00000000,0x00000000}},	//   tstå, _አባባል_, --, --, 
   {{0x26c09597,0x64a4014b,0xea8801af,0x00000000}},	// [b9c0] _veko_, ваза, _юбил_, --, 
   {{0x26c09598,0xf1e00220,0x00000000,0x00000000}},	//   _weko_, _ﺍﻻﻋﺘ, --, --, 
   {{0x26c09599,0xa7640022,0x23280890,0x25ac0010}},	//   _teko_, _акнд, можи_, _žolč_, 
   {{0xdb184e97,0x00000000,0x00000000,0x00000000}},	//   pstå, --, --, --, 
   {{0x9fe40214,0x6b4400ae,0x91e000f3,0x00000000}},	//   چسبه, _tógf, иоце, --, 
   {{0xd12c0486,0x27f8020b,0x64a40f14,0x00000000}},	//   يمن_, _kppn_, _јава, --, 
   {{0xa87800c8,0xb1940022,0x00000000,0x00000000}},	//   ואַר, ылшә, --, --, 
   {{0x657c959a,0xfbe0045e,0x00000000,0x00000000}},	//   llph, _বনলত, --, --, 
   {{0xbcfc00e4,0xc0cc0092,0x657c02d0,0xe0d00345}},	//   foĩp, _በጦር_, olph, _نزا_, 
   {{0x2054959b,0x27f80010,0x23c402e5,0x3cb4010b}},	//   _итер, _oppn_, _लबाद, ыйор, 
   {{0xa3b40490,0x10a00276,0x7514010f,0x657c0332}},	//   चीच_, _тихн, אַרע_, ilph, 
   {{0xd83c09a8,0x671013f5,0x98a41432,0x4ea00120}},	//   ščki_, _ढोलक_, _ını_, _крша, 
   {{0x9f5c959c,0x00000000,0x00000000,0x00000000}},	//   _istà_, --, --, --, 
   {{0x27f8003e,0x8c502ab4,0xd90c00f2,0x00000000}},	//   _bppn_, ائیا, آید_, --, 
   {{0xd77400cf,0x36d4959d,0x819801ec,0x00000000}},	//   نارع, ловр, _ﺘﺎﻤﺔ_, --, 
   {{0xe1d002a0,0x00000000,0x00000000,0x00000000}},	//   _सिंघ, --, --, --, 
   {{0x80b400c5,0x62740115,0xe7280014,0xdb1803b2}},	// [b9d0] ुराइ, nĝoĉ, رسٲو_, kstú, 
   {{0x44b4959e,0xe69801d9,0x349401c4,0x00000000}},	//   ибус, رمٕژ_, газр, --, 
   {{0x6d5c7d4f,0x82b0063f,0x093400c6,0xf31401c0}},	//   ésai, _ịnọg, _خريج, лджэ, 
   {{0xba78037e,0x657c01ab,0x8af003b9,0x00000000}},	//   _aはip, alph, _iməc, --, 
   {{0x96443f1b,0x20d02374,0x313400f0,0x00000000}},	//   _рэнд, ڭقىس, ледр, --, 
   {{0x73c44990,0xdb180174,0xc2440024,0x00000000}},	//   _бәде, gstú, шнік, --, 
   {{0x5ebc015b,0x160801f9,0x6fb4009a,0xc0c80166}},	//   োলনে, हटकर_, دمعا, туче_, 
   {{0x6744069c,0xaf0489ed,0x889c0115,0x00000000}},	//   _መወዳእ, упил, ובוי, --, 
   {{0x6b441bce,0x90b00116,0xed3401c6,0x09b800cc}},	//   _jóge, _кәйш, гэнэ, _জিভা, 
   {{0x9f5c0372,0x51840251,0x6d240c69,0x50c400bc}},	//   _està_, _руба, удоз, _रजिष, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xab281a5c,0xeab83de2,0xa098010f,0xeb0c05c0}},	//   хома_, эйм_, _װינט, ियेत_, 
   {{0xcdc06e5b,0xdd8c1fe4,0x657c959f,0xa14000da}},	//   _талқ, توی_, ylph, _šķie, 
   {{0x61e403cd,0x9f5c00d0,0x1d04014b,0x6ea800e5}},	//   _åkle, _istá_, _беши_, _غنڈہ_, 
   {{0x18642bd4,0x229806be,0x65cc0116,0x00000000}},	//   гари_, _kükü_, _ﺗﻪﭘﻪ, --, 
   {{0x7c3c95a0,0x27341c02,0x7c84009b,0x00000000}},	//   ørre, دىرس, _туче, --, 
   {{0xa68495a1,0x88f40220,0x93c801d3,0x00000000}},	// [b9e0] улад, _кінә, ہانہ_, --, 
   {{0x64c400f7,0x00000000,0x00000000,0x00000000}},	//   ايال, --, --, --, 
   {{0x66e495a2,0xe738114b,0x217401f0,0xdb180419}},	//   _йона, _зен_, қудр, vstú, 
   {{0x6b44032e,0x00000000,0x00000000,0x00000000}},	//   _fóge, --, --, --, 
   {{0x51f00b6c,0x6b440241,0x00000000,0x00000000}},	//   مسور, _kógb, --, --, 
   {{0xd4a000ee,0xf1e002dd,0x00000000,0x00000000}},	//   _гирй, _ﺍﻻﻗﺘ, --, --, 
   {{0x2fc495a3,0x9f5c011f,0xdea03c5b,0xdfd802e8}},	//   арың, _astá_, میای, хъл_, 
   {{0xa6d4015b,0x6b4495a4,0x57f808d8,0xbf340395}},	//   ড্রয়, _lógb, תלקו, рнищ, 
   {{0xdb181924,0x00000000,0x00000000,0x00000000}},	//   mstø, --, --, --, 
   {{0x61e095a5,0x21744a03,0x634c01e4,0x2e340022}},	//   muol, _субр, rŝnu, рҧшы_, 
   {{0x9f5c74c3,0x61e0166a,0x5190007b,0x4cc00154}},	//   _está_, luol, _اللذ, _শাশু, 
   {{0xdb183bb4,0x5438010f,0x8c600108,0x00000000}},	//   nstø, געטא, стьд, --, 
   {{0xf8b80372,0x61e002d5,0xd3540375,0xdb180158}},	//   көн_, nuol, ריכי_, istø, 
   {{0x02d00073,0x00000000,0x00000000,0x00000000}},	//   हणुन, --, --, --, 
   {{0x61e002f6,0x6b440241,0xdb1895a6,0xfb8800d1}},	//   huol, _dógb, kstø, _ириқ_, 
   {{0x61e095a7,0x8c1804ae,0xc0500023,0x00000000}},	//   kuol, _טווי, _ክንሕግ, --, 
   {{0xdb183b97,0xba181541,0xed4c00e5,0x00000000}},	// [b9f0] dstø, _شيدا_, _رھی_, --, 
   {{0x28c407f7,0x61e095a8,0x00000000,0x00000000}},	//   वरणि, duol, --, --, 
   {{0x02d00490,0x9f5c003a,0x61e00393,0xdb1803b2}},	//   हणून, _istæ_, euol, fstø, 
   {{0x61e095a9,0xdb1895aa,0xc2c40451,0x439406a6}},	//   fuol, gstø, ميمي, бахс, 
   {{0x61e06de4,0x00000000,0x00000000,0x00000000}},	//   guol, --, --, --, 
   {{0x50d412a4,0x9b54063f,0xb4f800df,0x00000000}},	//   ازشر, ụghị, _בפֿי, --, 
   {{0xdb1800b5,0x33940153,0x00000000,0x00000000}},	//   bstø, _вавё, --, --, 
   {{0xef1895ab,0x61e095ac,0xcb140490,0x00000000}},	//   тми_, buol, _तोंड_, --, 
   {{0x90e495ad,0x764c0928,0x32541ed2,0xed4400d1}},	//   _مسان, nzay, _твар, инип, 
   {{0xc59001ec,0x00000000,0x00000000,0x00000000}},	//   _ﺒﺎﻟﻨ_, --, --, --, 
   {{0xab644c6b,0x7e2801d5,0x50640798,0x6b4402d2}},	//   ивол, نسیف_, _стаа, _rógb, 
   {{0xc2100014,0x41b400db,0x5e5401d3,0x6b5401c4}},	//   _بٔے_, _ئمەر, الیس_, ртох, 
   {{0xa9a405f5,0x00000000,0x00000000,0x00000000}},	//   ригд, --, --, --, 
   {{0x684495ae,0x764c0bd7,0xed580510,0xf1e002dd}},	//   анга, dzay, _шол_, _ﺍﻻﻟﺘ, 
   {{0xdd8c95af,0x6c7800c8,0x6d5c0129,0xdb1803cd}},	//   _توو_, _באַפ, ésau, ystø, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb18022c,0x6e286e0e,0x61e00306,0x28c4000d}},	// [ba00] vstø, nxeb, xuol, वरदि, 
   {{0x58fc0327,0x00000000,0x00000000,0x00000000}},	//   _ཞིགས_, --, --, --, 
   {{0xdb1895b0,0x61e001f2,0x00000000,0x00000000}},	//   tstø, wuol, --, --, 
   {{0x1bf400c8,0x61e095b1,0xe73895b2,0x64e00490}},	//   יצער_, tuol, _рем_, _पाकळ, 
   {{0x64a495b3,0xf0780116,0xe80c013a,0x00000000}},	//   _вага, һишә_, ाटका_, --, 
   {{0xdb180feb,0x61e093fb,0x00000000,0x00000000}},	//   sstø, ruol, --, --, 
   {{0x403402d5,0x61e0129c,0x7f587e32,0x60c802d2}},	//   сейс, suol, лакс_, rafm, 
   {{0xdef87564,0x61e095b4,0xb24401e0,0x66140024}},	//   тык_, puol, рмәһ, ovyk, 
   {{0x236495b5,0x61e0011c,0x386c03ee,0x4b2400fe}},	//   mnoj_, quol, ğeri_, _পতংগ_, 
   {{0x23641326,0xa0740139,0x386c0bbc,0x00000000}},	//   lnoj_, _кыеш, şeri_, --, 
   {{0x20541952,0x764c95b6,0x2364008f,0x00000000}},	//   _ттар, zzay, onoj_, --, 
   {{0x23640115,0xba18009f,0x6e2806be,0x00000000}},	//   nnoj_, هيجا_, bxeb, --, 
   {{0xffc400d1,0x9a840131,0x8f98011a,0x00000000}},	//   _төһп, рунл, _סידי, --, 
   {{0xf98895b7,0xa2d400dc,0xd7f81f0f,0x7c3c01ab}},	//   انسي_, मृत्, куб_, ùrrs, 
   {{0x62840fac,0x9bc40108,0x00000000,0x00000000}},	//   _økof, _тёлк, --, --, 
   {{0x236495b8,0x764c005a,0x2ca8008e,0xde500023}},	//   jnoj_, tzay, _ğadi_, _ክትነግ, 
   {{0x23641326,0x7aec95b9,0x9fe0009e,0x9f5c00fd}},	// [ba10] dnoj_, _icat, _মনোগ, _istä_, 
   {{0x764c95ba,0x7aec0165,0x4a7c0375,0x236495bb}},	//   rzay, _hcat, _ברחב, enoj_, 
   {{0x6b440124,0x661400e4,0x04c816ac,0x80e00456}},	//   _hóga, avyk, شوني_, नलैं, 
   {{0xd34416e6,0x2364008f,0xa3e40cb4,0x66140308}},	//   جیره_, gnoj_, पढ़_, bvyk, 
   {{0x6b4495bc,0x6e2895bd,0x7aec0332,0x00000000}},	//   _jóga, xxeb, _mcat, --, 
   {{0x3494035b,0x2364010f,0x3d10012d,0xe294119e}},	//   _гагр, anoj_, ़यों_, љаш_, 
   {{0x6b440579,0x236405ce,0x7aec0c8c,0x272c010e}},	//   _lóga, bnoj_, _ocat, _aýny_, 
   {{0x753400f8,0x236408ad,0xd5400241,0x93400e56}},	//   _hozz, cnoj_, _fẹ́l, _بىرۇ, 
   {{0x7534036e,0x6b4402d2,0x313400d8,0x00000000}},	//   _kozz, _nóga, _леар, --, 
   {{0x320c208d,0x61e42b27,0x415495be,0xed445169}},	//   _isey_, _åkla, _двус, сноп, 
   {{0x753495bf,0xeb9895c0,0x7aec0354,0xcf241371}},	//   _mozz, лио_, _bcat, _پراي, 
   {{0x78a40477,0x75344f1b,0x7aec00f3,0xbbe8030f}},	//   _aghv, _lozz, _ccat, گریم_, 
   {{0xe73812d7,0x7aec0334,0x6b44007b,0x6d5c95c1}},	//   қеа_, _dcat, _cóga, ésas, 
   {{0x753495c2,0xdec80020,0x236405ce,0x7aec95c3}},	//   _nozz, _በሆነ_, znoj_, _ecat, 
   {{0x6d40003c,0x7aec010a,0xa78495c4,0x78a40175}},	//   mkla, _fcat, مشرو, _dghv, 
   {{0x6d4095c5,0x7aec00c6,0x6b44007b,0x8c3401c6}},	//   lkla, _gcat, _fóga, _бүүр_, 
   {{0x23641326,0xe61895c6,0x753495c7,0xd62495c8}},	// [ba20] vnoj_, ыда_, _bozz, боте_, 
   {{0x6d4095c9,0x753491ae,0x6b780055,0x00000000}},	//   nkla, _cozz, _ṃgha, --, 
   {{0x236404b9,0x75341a44,0x6d4095ca,0xdec8001f}},	//   tnoj_, _dozz, ikla, _በሆኑ_, 
   {{0xdef81772,0x6d407dcd,0xa2e408ca,0x00000000}},	//   ዊትን_, hkla, содд, --, 
   {{0xa2a82ecf,0x6d4095cb,0x6b440005,0xe8e4025c}},	//   टशब्, kkla, _xóga, _སྐོག, 
   {{0x23640bb8,0x65c00046,0x753495cc,0x35c402f4}},	//   snoj_, _мұға, _gozz, _фарҳ, 
   {{0x9cc8052f,0x320c95cd,0x6d4095ce,0x236405ce}},	//   һына_, _esey_, dkla, pnoj_, 
   {{0x6d400399,0x7534011c,0x543800c8,0xbdb410fc}},	//   ekla, _zozz, _געלא, обиј, 
   {{0x6d4095cf,0x7534045a,0xdd980124,0x00000000}},	//   fkla, _yozz, лшо_, --, 
   {{0xe16436e9,0x9ad001f2,0x7aec95d0,0x6b440124}},	//   _ادري, _tịke, _scat, _róga, 
   {{0xdef895d1,0x21f00129,0xf8a801d5,0x00000000}},	//   _был_, lâh_, یگده_, --, 
   {{0x6b440332,0x6d4095d2,0x6ec400db,0x6e2c01ef}},	//   _póga, akla, _ۇتۇق, _šibř, 
   {{0x09e402d5,0x80ac0ebb,0x5e94007b,0x3b8400db}},	//   поўн, _चलाइ, _الشط, йлүг, 
   {{0x6d4095d3,0x3f84003d,0xd90c130e,0xdb180e78}},	//   ckla, llmu_, ریج_, lstü, 
   {{0x753495d4,0x1d78001f,0x7aec062c,0xb8d00fe3}},	//   _rozz, _አባቶች_, _tcat, _ओल_, 
   {{0x7aec0921,0x6b4400c6,0x75343eb9,0xdb18791a}},	//   _ucat, _tóga, _sozz, nstü, 
   {{0x753495d5,0xf1b81225,0x3f8495d6,0x54a400c6}},	// [ba30] _pozz, _krše_, ilmu_, محاف, 
   {{0x98c42e3f,0x78a4014f,0xdb180112,0x86982b2e}},	//   _усил, _ughv, hstü, скус_, 
   {{0xdb1895d7,0x00000000,0x00000000,0x00000000}},	//   kstü, --, --, --, 
   {{0x6d4095d8,0xdb1809f3,0x753495d9,0x660c95da}},	//   zkla, mstó, _wozz, änkä, 
   {{0x6d4009a5,0x753495db,0xdb1895dc,0x00000000}},	//   ykla, _tozz, lstó, --, 
   {{0xdb1895dd,0x3f8419f5,0x550455da,0x386c0356}},	//   vstý, elmu_, _учма, şeru_, 
   {{0x6d40049f,0xa6a8015b,0x00000000,0x00000000}},	//   vkla, _ছড়িয়, --, --, 
   {{0x320c02d1,0x6d40039a,0x3cfc01f5,0xd6d80154}},	//   _tsey_, wkla, _abvv_, ড্রয, 
   {{0xdb18068c,0x4394141c,0xc0cc0092,0x00000000}},	//   mptè, _хатс, _በቦሌ_, --, 
   {{0x09b80c58,0xed5895de,0x3f84022f,0xdb1895df}},	//   _জিলা, роо_, almu_, rstý, 
   {{0xdb1895e0,0xbe480d73,0x00000000,0x00000000}},	//   sstý, لشیم_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe8e40156,0xed3401af,0x7cf00022,0x00000000}},	//   _སྐུག, _мэкэ, ẽrak, --, 
   {{0x2dd80014,0xe7f4000d,0x6d4002d0,0x00000000}},	//   _مُچھ_, ँझला_, qkla, --, 
   {{0xe73895e1,0x98a095e2,0x18a095e3,0xae1000af}},	//   аев_, дире, дарм, ़िकन_, 
   {{0x44240208,0x65c40120,0x00000000,0x00000000}},	//   _ăm_, жбаа, --, --, 
   {{0x2d8495e4,0xdb1800ae,0x00000000,0x00000000}},	// [ba40] olle_, astó, --, --, 
   {{0x2d8495e5,0x69d45975,0xe8f83a61,0x00000000}},	//   nlle_, _ivye, _тло_, --, 
   {{0x2d8495e6,0x6b4495e7,0x386c03fa,0x1cb00327}},	//   ille_, _jógo, ßert_, _ྐུལ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x672495e8,0xd00c03e6,0x386c0356,0x2d080401}},	//   _inkj, ێله_, şert_, _वसूल_, 
   {{0x32080724,0xe47400a8,0xdef80092,0xdfd80107}},	//   çaya_, _дубэ, ዊድን_, аъи_, 
   {{0xaad813b4,0xd4642786,0xdb1895e9,0x9f5c00d0}},	//   _भयंक, _дире_, istò, _istú_, 
   {{0x6d5c3040,0x00000000,0x00000000,0x00000000}},	//   èsan, --, --, --, 
   {{0xdb180639,0x712400d1,0x907c0150,0x00000000}},	//   rstü, غرۇل, _ﺨﻼﺼﺔ_, --, 
   {{0xdb1895ea,0x614400cf,0x717002dd,0x00000000}},	//   mpté, _بئرق, _كۇنا, --, 
   {{0x60640e63,0xf1b808ad,0x8e34036b,0x62840158}},	//   _بهال, _vrše_, مسیر_, _økob, 
   {{0x2d8495eb,0x201c02f6,0x9f5c95ec,0x61e039ed}},	//   alle_, _irti_, _opté_, orol, 
   {{0x5398008f,0x201c0010,0x9e7414d1,0xf1b80010}},	//   יסטא, _hrti_, _بهشت, _trše_, 
   {{0x61e00005,0x69d400b8,0x6b4401e7,0xdb08036e}},	//   irol, _dvye, _hógl, _kufë, 
   {{0x7d080857,0x61e03d3c,0x8dc40327,0x00000000}},	//   meds, hrol, _གསོལ, --, 
   {{0x35b495ed,0x7d0895ee,0x6b4400e8,0xdb18148b}},	//   збар, leds, _jógl, rstó, 
   {{0x95c80116,0xa36801a9,0xbb4400fb,0x94a800d8}},	// [ba50] руба_, tsеn, _меҫк, атеа_, 
   {{0x7d0895ef,0xbef81a22,0x672400fe,0xef18033f}},	//   neds, ्जुन_, _enkj, może_, 
   {{0x61e000db,0xf3f82d1f,0xfbd800fe,0x00000000}},	//   erol, снеш_, _তহঁত, --, 
   {{0x7d08105c,0x61e095f0,0xdb0801e6,0x4bf8008f}},	//   heds, frol, _utfä, שלאס, 
   {{0x201c95f1,0x60d80076,0x7d0895f2,0xd2580e92}},	//   _arti_, _bdtm, keds, јце_, 
   {{0x2b9001f1,0x201c020b,0x7d080841,0x00000000}},	//   máce_, _brti_, jeds, --, 
   {{0xa0a0086f,0x201c0841,0x349401c6,0x7d087a02}},	//   нашд, _crti_, _хавр, deds, 
   {{0x61e095f3,0x15ec00c5,0xcdcc004b,0x00000000}},	//   brol, _चमार_, نښت_, --, 
   {{0x201c001f,0x7bdc95f4,0x2d840137,0xb62c00b5}},	//   _erti_, árun, tlle_, _ｒｂ_, 
   {{0x2d8495f5,0x82a402dd,0xed5801c6,0x7d0802d0}},	//   ulle_, _іште, ёон_, geds, 
   {{0x2d840f71,0x6b44026c,0xfe703bd6,0x00000000}},	//   rlle_, _fógl, _یده_, --, 
   {{0x2d841709,0xe6a809ab,0x8af006be,0x68340166}},	//   slle_, _कलेज, _imək, hüdç, 
   {{0x7d088c4b,0xc0ec02d3,0x6f080014,0x14c807b6}},	//   beds, ቀመሉ_, meec, िराण, 
   {{0x6f0895f6,0x7d08035a,0x3cf400d7,0x00000000}},	//   leec, ceds, ľavý_, --, 
   {{0xeb9895f7,0xdd8c00db,0x61e00115,0x00000000}},	//   _лик_, _حوو_, zrol, --, 
   {{0x1864036b,0x3864007b,0xdb1806af,0x7c3c088f}},	//   часи_, úlra_, ypté, ärre, 
   {{0xd6240556,0x28e800f3,0x00000000,0x00000000}},	// [ba60] поте_, _лдпп_, --, --, 
   {{0x6f080b21,0xdb08068c,0x64940114,0x00000000}},	//   heec, _aufè, пјех, --, 
   {{0x290804ce,0x69b010eb,0x61e00b6a,0x794c0241}},	//   meba_, _इंडी, wrol, _àgbẹ, 
   {{0x290895f8,0x7d0895f9,0xe5a495fa,0x61e05337}},	//   leba_, zeds, _ними, trol, 
   {{0x7d087cf7,0x6f08513e,0xe5a4327c,0x6b440162}},	//   yeds, deec, _хиги, _nógm, 
   {{0x26d095fb,0x61e095fc,0x7d08010a,0x201c0427}},	//   layo_, rrol, xeds, _prti_, 
   {{0x657c95fd,0x7d0895fe,0x6f0895ff,0xdef89600}},	//   moph, veds, feec, бып_, 
   {{0x657c9601,0x61e00fcf,0x29089602,0x7d0869d0}},	//   loph, prol, heba_, weds, 
   {{0x29089603,0x7d080c8c,0x63ac9604,0x60d8010a}},	//   keba_, teds, _hubn, _tdtm, 
   {{0x657c9605,0x29089606,0xa0689607,0xdb08036e}},	//   noph, jeba_, _лаза_, _tufë, 
   {{0x26d08cdb,0x201c9608,0x6f089609,0x2908960a}},	//   kayo_, _urti_, beec, deba_, 
   {{0x657c960b,0x7d08960c,0x26d0960d,0x6f08011f}},	//   hoph, seds, jayo_, ceec, 
   {{0x657c4b26,0x7d08960e,0x290801f0,0xf1b828b5}},	//   koph, peds, feba_, _krša_, 
   {{0x657c014b,0x2908960f,0x6e3c007c,0xef180210}},	//   joph, geba_, äsbe, roże_, 
   {{0xcd302eac,0x3e88009f,0x00000000,0x00000000}},	//   _سروب, _اَڇَ_, --, --, 
   {{0xd7f80184,0x26d09610,0x7bd8025c,0x657c0113}},	//   _һум_, gayo_, _ivvu, eoph, 
   {{0x29085554,0x63ac003e,0x1ac041ac,0x657c0393}},	// [ba70] beba_, _aubn, _व्यथ, foph, 
   {{0xd4989611,0x29089612,0x7afc9613,0x657c9614}},	//   бре_, ceba_, lfst, goph, 
   {{0x26d016cb,0x7afc0ea0,0x938801b9,0x00000000}},	//   bayo_, ofst, бсда_, --, 
   {{0xf1b805be,0x26d0737b,0x63ac02fd,0x7afc002f}},	//   _arša_, cayo_, _dubn, nfst, 
   {{0xbef845bf,0xa28023cf,0x7afc02c1,0x556002dd}},	//   ्जैन_, نیفو, ifst, _كۇرك, 
   {{0x657c9615,0x7bd81418,0xdca49616,0x6f089617}},	//   coph, _ovvu, _لى_, weec, 
   {{0x63ac3a73,0x7bdc01ed,0x6f08002d,0xaf9410fc}},	//   _gubn, árul, teec, мшиј, 
   {{0x2908068f,0x7afc0cf9,0x776c01a9,0xc2080116}},	//   zeba_, jfst, nnax, تقۇن_, 
   {{0x6f089618,0x63ac245b,0x7bd81418,0x29083d81}},	//   reec, _zubn, _avvu, yeba_, 
   {{0x26d08b6a,0x7afc1af3,0x6f0888c7,0xed5802bf}},	//   zayo_, efst, seec, іон_, 
   {{0xeb989619,0x63ac961a,0x7afc961b,0x29080333}},	//   жин_, _xubn, ffst, veba_, 
   {{0x657c961c,0x26d06fc3,0x290848b5,0xe8c400cd}},	//   zoph, xayo_, weba_, वर्च, 
   {{0x657c961d,0x2908961e,0x7bd80337,0x776c031c}},	//   yoph, teba_, _evvu, dnax, 
   {{0x26d07e6b,0x7afc508f,0xebe400f7,0x1d04004e}},	//   wayo_, afst, _жокп, _жеши_, 
   {{0x2908961f,0x26d09620,0x00000000,0x00000000}},	//   reba_, tayo_, --, --, 
   {{0x29089621,0x63ac0841,0x657c01b3,0x6a84010b}},	//   seba_, _rubn, woph, _олйа, 
   {{0x63ac9622,0x24f43580,0x29089623,0x699401c0}},	// [ba80] _subn, дчер, peba_, _орох, 
   {{0x26d08cdb,0x290801e0,0xe968036b,0x972c0023}},	//   sayo_, qeba_, _фаол_, _ተጻወት, 
   {{0xe7389624,0x26d09625,0x25e804fa,0xd24c3c5b}},	//   _ден_, payo_, _चमकी_, ینم_, 
   {{0x26d09626,0x84f002a0,0x5c3400df,0xe64401fe}},	//   qayo_, _चावट_, ורען_, _жемп, 
   {{0x754800f8,0xd0400213,0x51f05cfc,0x00000000}},	//   ászó, manə, نسور, --, 
   {{0x657c9627,0x518013f3,0x63ac058a,0xf1a80451}},	//   qoph, куща, _tubn, ساهه_, 
   {{0xdb189628,0x7afc0ea0,0x6b9401e3,0x41e000cd}},	//   mstö, yfst, _ohyg, _निवस, 
   {{0xdea0034d,0x44449629,0xdb18962a,0x00000000}},	//   نیای, my_, lstö, --, 
   {{0xf1b80010,0xe0d8003b,0xdb18000d,0xd2500133}},	//   _trša_, _мва_, ostö, _لکوژ, 
   {{0x44444458,0xdb18962b,0xe2a40008,0xf1b80427}},	//   oy_, nstö, áðum_, _urša_, 
   {{0x4444962c,0xdb1802f6,0x60600075,0x8c400261}},	//   ny_, istö, _جۇغل, веќе, 
   {{0x4444962d,0x66040270,0x7afc962e,0x6b9400a2}},	//   iy_, _opkk, ufst, _chyg, 
   {{0x4444962f,0x527800c8,0x8fa00261,0xdb181876}},	//   hy_, ַנלא, _раце, kstö, 
   {{0x44449630,0x61f40209,0x6b4401e7,0x673400e4}},	//   ky_, çyly, _lógh, ejyj, 
   {{0x44449631,0x7afc17da,0xef180327,0xdb189632}},	//   jy_, pfst, loża_, dstö, 
   {{0x7d189633,0xd04003e3,0x00000000,0x00000000}},	//   _havs, ganə, --, --, 
   {{0x44448e3d,0xdb18264d,0x7d189634,0x776c0009}},	// [ba90] ey_, fstö, _kavs, rnax, 
   {{0x776c0054,0x2b900030,0xdb189632,0x00000000}},	//   snax, máca_, gstö, --, 
   {{0x44449635,0x36d4049b,0x7d18036b,0x6b4403b2}},	//   gy_, _понр, _mavs, _bógh, 
   {{0x33280bc9,0x7d182ab7,0xc2c40592,0x38c8429e}},	//   ñax_, _lavs, نيمي, _باکی_, 
   {{0x44449636,0x7d18049f,0x6d5c0066,0xdb18002f}},	//   ay_, _oavs, èsak, bstö, 
   {{0x44449637,0x7d189638,0x41e03347,0x6b440332}},	//   by_, _navs, _निरस, _eógh, 
   {{0x628439c2,0x44449639,0x798438f3,0x606c00b7}},	//   _økon, cy_, _mkhw, _ድንገት_, 
   {{0xee38963a,0xb3740b82,0x80e000eb,0x00000000}},	//   зни_, ራዊያን_, প্ল্, --, 
   {{0x79846ca0,0x6b940042,0xde14104c,0xada42083}},	//   _okhw, _rhyg, فقيت_, наил, 
   {{0x3158963b,0x79840bd7,0x9f5c0030,0x7d180332}},	//   _علاج_, _nkhw, _istý_, _cavs, 
   {{0x7d180076,0x6b64963c,0xd04000ac,0x1c4001c6}},	//   _davs, екна, yanə, гнэм, 
   {{0x950c0135,0x7c3c01e6,0x00000000,0x00000000}},	//   _ཌིའི_, ärra, --, --, 
   {{0x7d1851fa,0x6b4401e1,0xdb180108,0x00000000}},	//   _favs, _jógi, ystö, --, 
   {{0x6f180399,0x7d180174,0x6b4402d2,0x6b700055}},	//   _hawc, _gavs, _mógi, cāgn, 
   {{0x6b44963d,0x279447fa,0xdca000d1,0x4444963e}},	//   _lógi, ешар, _йаши, xy_, 
   {{0x44440ceb,0x79840e4d,0x6b941fcd,0x6f18014f}},	//   vy_, _ekhw, _uhyg, _jawc, 
   {{0x4444963f,0xe9681945,0xdb183705,0x6b7000e2}},	// [baa0] wy_, _наил_, tstö, lāgo, 
   {{0x64989640,0x6f180477,0x61e44606,0xd0400213}},	//   птер_, _lawc, _åkli, sanə, 
   {{0xdb189641,0x44449642,0x97400552,0x29180356}},	//   rstö, uy_, šćav, _iapa_, 
   {{0x29189643,0xdb189644,0x7c3c9645,0xf4944d56}},	//   _hapa_, sstö, ørri, трую, 
   {{0x44449646,0x29189647,0xa2280dab,0xe2989648}},	//   sy_, _kapa_, яжда_, чад_, 
   {{0x44449649,0x2918964a,0x00000000,0x00000000}},	//   py_, _japa_, --, --, 
   {{0x7d18036b,0xa2e40801,0xc44803e6,0x4034964b}},	//   _ravs, _повд, _تیان_, тейс, 
   {{0x2918964c,0xdb08964d,0x53a000c7,0x7d18964e}},	//   _lapa_, _utfø, _басб, _savs, 
   {{0x0e4001c0,0x2364008f,0x6f18012d,0x8fa00114}},	//   гээм, mioj_, _dawc, ћање, 
   {{0x2918964f,0xf1a89650,0x236400c8,0xd24c00c6}},	//   _napa_, _قاله_, lioj_, _انك_, 
   {{0x6f189651,0x224400dd,0xdb18002d,0x7d1803b2}},	//   _fawc, lyok_, kstô, _vavs, 
   {{0x29180972,0x236400c8,0x213c01e4,0xdb1803b2}},	//   _aapa_, nioj_, _hoth_, pptí, 
   {{0x7d189652,0x29189653,0x224400dd,0x3ea008c2}},	//   _tavs, _bapa_, nyok_, _àit_, 
   {{0x29189654,0xc98400ee,0x2b909655,0x79940440}},	//   _capa_, гуси, ráca_, тигф, 
   {{0x213c1590,0x29189656,0x23649657,0x36d4490c}},	//   _moth_, _dapa_, kioj_, ковр, 
   {{0x29180093,0x22440280,0x213c9658,0x478810f3}},	//   _eapa_, kyok_, _loth_, есум_, 
   {{0x291801e0,0x2364008f,0x25a80489,0xd3780724}},	// [bab0] _fapa_, dioj_, _bibl_, үче_, 
   {{0xc6a49659,0x2918965a,0x22449335,0xd4988df2}},	//   урси, _gapa_, dyok_, пре_, 
   {{0x33180212,0x2364010f,0x5ed40154,0x02cc0a59}},	//   діля_, fioj_, _ধানে, ारंभ, 
   {{0x2364008f,0x11640ec9,0x00000000,0x00000000}},	//   gioj_, کلتی_, --, --, 
   {{0x2244066d,0x628439c2,0x213c965b,0x08f8965c}},	//   gyok_, _økol, _both_, _غریب_, 
   {{0x6f180399,0x213c01ab,0x19ac0075,0x291800db}},	//   _sawc, _coth_, _ﻳﻮﻟﻠ, _xapa_, 
   {{0x6f18965d,0x213c32a7,0x236400df,0x00000000}},	//   _pawc, _doth_, bioj_, --, 
   {{0x236404ac,0x2244020b,0x6f18014f,0x600402e8}},	//   cioj_, byok_, _qawc, тнъм_, 
   {{0xb11464e1,0xed580137,0xa0940150,0x7c3c01e3}},	//   _имаш, доп_, _ﺘﻭﹼﺕ_, ärrn, 
   {{0x6b440579,0xed44201d,0x00000000,0x00000000}},	//   _jógv, тноп, --, --, 
   {{0x2ef45e89,0x2918965e,0x15f002ab,0x1b18015b}},	//   _азер, _rapa_, इंडर_, ধানে_, 
   {{0x2918965f,0xac7c001f,0xaca0001f,0x6b440174}},	//   _sapa_, _ከዓለም_, _ለዓለም_, _lógv, 
   {{0x9f5c1497,0x1f240014,0xe80817ee,0x00000000}},	//   _estó_, _جِنہ, _हैजा_, --, 
   {{0x6b441125,0x29189660,0x2364008f,0x5e54010f}},	//   _nógv, _qapa_, zioj_, _בינע_, 
   {{0x29189661,0xfd100014,0x25a80156,0x5d78008f}},	//   _vapa_, _دجن_, _ribl_, _קאצק, 
   {{0x29189662,0x22440548,0x7c2400de,0x00000000}},	//   _wapa_, yyok_, _ņirg, --, 
   {{0xdcf800da,0x6b440162,0x0ba40022,0x236401e4}},	// [bac0] lotā, _bógv, _иыҩҭ, vioj_, 
   {{0x332c1529,0x29189663,0xe9a41c34,0x00000000}},	//   _anex_, _uapa_, _шапп, --, 
   {{0x66e49664,0x213c6040,0xba283765,0xdcf8005f}},	//   _иона, _roth_, _قسیم_, notā, 
   {{0x332c0589,0xe68801ec,0x69c4000f,0xa2e40137}},	//   _cnex_, _يندى_, opke, тодд, 
   {{0x236400c8,0x142001ec,0x8af00213,0x00000000}},	//   rioj_, _ءﻣﺎﺳ, _iləd, --, 
   {{0x2b9000d2,0xdcf8005f,0x332c010e,0x62840fac}},	//   káco_, kotā, _enex_, _økom, 
   {{0xdb08068c,0x2244020c,0xdcf800e2,0x2364010f}},	//   _sufí, syok_, jotā, pioj_, 
   {{0xc22448ef,0xdcf8005f,0x3f142e63,0x22440066}},	//   _مکتو, dotā, удис, pyok_, 
   {{0x69c4002d,0x6b440241,0x7374104e,0x8af006be}},	//   jpke, _jógu, _сырх, _lməs, 
   {{0x5698010f,0xa09815b0,0xe0449665,0x00000000}},	//   ויפצ, _قضاء_, _инзи, --, 
   {{0xdef80dd8,0xa0a40801,0x69c49666,0x6b449667}},	//   _жыл_, _ражд, epke, _lógu, 
   {{0xe5000f4c,0x5de47afa,0x0fe073b5,0xa3e807af}},	//   र्ति_, _ажда, _төшү, _मिन_, 
   {{0x3f840333,0x6b4402d2,0x7c2400ef,0x00000000}},	//   momu_, _nógu, _ņird, --, 
   {{0x3f849668,0x3dc80154,0xdcf80171,0x00000000}},	//   lomu_, _শিপল, botā, --, 
   {{0x6b440579,0x69c400d5,0xcd940375,0x6e2c00d8}},	//   _rógv, apke, _שדות_, _àabr, 
   {{0xb5c85fc4,0x6b440241,0x7c3c06ea,0x00000000}},	//   فورم_, _bógu, ørru, --, 
   {{0x98e49669,0x80d80154,0xd5a0006c,0x00000000}},	// [bad0] _июнд, _ঠান্, للری, --, 
   {{0xeaa800c8,0x3f84966a,0x8af000ac,0x39141f99}},	//   _אױפֿ, homu_, _eləd, _смор, 
   {{0x311c00dc,0x82340214,0xb6c4004e,0x48e8000d}},	//   _योगः_, یرها, _бөзд, _जयतो_, 
   {{0x6b4401e1,0x32543aeb,0x33740c75,0x3f84966b}},	//   _fógu, лвер, ыгер, jomu_, 
   {{0x3f84966c,0x6b440174,0x72040633,0x00000000}},	//   domu_, _tógv, اوتم, --, 
   {{0x85440139,0xe68401af,0x00000000,0x00000000}},	//   _кэсе, _сәск_, --, --, 
   {{0x3f8413c4,0x61403580,0xd3a40713,0x93a4966d}},	//   fomu_, сеща, _арап, _ашад, 
   {{0xa44004d3,0x6b44002e,0x3f84966e,0xdcf800e2}},	//   _دێمو, _jógt, gomu_, votā, 
   {{0x26dc013b,0xb0341de6,0x00000000,0x00000000}},	//   _ɛto_, _әнеш, --, --, 
   {{0xdcf80029,0x6b44089f,0xee480306,0x3d1801f9}},	//   totā, _lógt, jvýš_, _बघणे_, 
   {{0x3f84966f,0x00000000,0x00000000,0x00000000}},	//   bomu_, --, --, --, 
   {{0x3f849670,0xdcf8005f,0x150c0011,0xadd4009b}},	//   comu_, rotā, সায়ী_, _бодљ, 
   {{0xad24212d,0x69c400ec,0x66e40107,0xf4080154}},	//   _مرغو, upke, ғоза, রটির_, 
   {{0x1cb00003,0xa88820c2,0x69c4000f,0xa96801b9}},	//   _ཐུར_, ейга_, rpke, хига_, 
   {{0x2d849671,0x66e49672,0x31b802e2,0xd94000a7}},	//   mole_, лова, _lèz_, щери, 
   {{0x2d849673,0x64a49674,0x6b440022,0xa8c400d1}},	//   lole_, ҳаза, _pógu, _өйид, 
   {{0x6b849675,0x69c80270,0x2d840270,0x18a00c60}},	// [bae0] mokg, _ōfef, oole_, _қаюм, 
   {{0x6b849676,0x2d849677,0x64a49678,0xdb080798}},	//   lokg, nole_, газа, _tufã, 
   {{0x2d84011c,0x1cb00135,0x3f840bd7,0x00000000}},	//   iole_, _ཐུལ_, yomu_, --, 
   {{0x2d849679,0x6b8427c4,0x31b802e2,0x62843c02}},	//   hole_, nokg, _bèz_, _økok, 
   {{0x61442b39,0x2168967a,0x00000000,0x00000000}},	//   леда, ниди_, --, --, 
   {{0x6b84073c,0x2d84967b,0x3f841418,0x3ff4007b}},	//   hokg, jole_, womu_, لكتر, 
   {{0x6b840770,0x3f84967c,0x6614002d,0x84540131}},	//   kokg, tomu_, lwyk, _ئىزچ, 
   {{0x2d840076,0x3dc800eb,0x00000000,0x00000000}},	//   eole_, _শিবল, --, --, 
   {{0x2d84192e,0x63a0967d,0xa3e802a0,0x6b4403b2}},	//   fole_, mmon, _मिड_, _lógs, 
   {{0x2d84967e,0x21a4376d,0xd6f8037e,0xd5f8010f}},	//   gole_, _сизм, _chオ_, עפיר, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x63a000b5,0x6b84073c,0x5e24115a,0x39400036}},	//   nmon, gokg, _معتق, _sohs_, 
   {{0x2d84967f,0x63a09680,0xbdd40a8f,0x8d700345}},	//   bole_, imon, _толщ, شایا, 
   {{0x2d849681,0x63a09682,0x26c41bce,0x66140210}},	//   cole_, hmon, ñoon_, dwyk, 
   {{0x63a09683,0x6b8427be,0x9be49684,0xc7c42901}},	//   kmon, bokg, _сілк, йсти, 
   {{0x63a00399,0x6614017a,0x9964013d,0x00000000}},	//   jmon, fwyk, _әтил, --, 
   {{0x63a09685,0x74f800d8,0x00000000,0x00000000}},	// [baf0] dmon, кеар_, --, --, 
   {{0x63a09686,0x3a280395,0x1cb0025c,0x31b80100}},	//   emon, _irap_, _ཐུས_, _rèz_, 
   {{0x3a280280,0x74a89687,0x63a08ec7,0x6b4400c6}},	//   _hrap_, тсаң_, fmon, _tógt, 
   {{0x3a289688,0x31b89689,0x63a001ed,0x970000d1}},	//   _krap_, _pèz_, gmon, _دېرى, 
   {{0xf1b817a3,0x2d84968a,0x3b08968b,0xe50000dc}},	//   _krši_, yole_, _mbaq_, र्हि_, 
   {{0x63a0968c,0x3a280129,0xe29400ea,0x00000000}},	//   amon, _mrap_, јаш_, --, 
   {{0x2d84968d,0x2f54968e,0x28b400dc,0x00d821e7}},	//   vole_, итис, ंशति, ابهت_, 
   {{0x2d84968f,0x6b440077,0xa3e80406,0x31b802e2}},	//   wole_, _lógr, _मित_, _tèz_, 
   {{0x2d849690,0xe5000da5,0x00000000,0x00000000}},	//   tole_, र्वि_, --, --, 
   {{0x2d84003a,0x6b4400e5,0x00000000,0x00000000}},	//   uole_, _nógr, --, --, 
   {{0x3a2837be,0x6b8427be,0x66140034,0xfbcc0050}},	//   _arap_, tokg, zwyk, ى۪و_, 
   {{0xf1b80064,0x7f940354,0x205400df,0x00000000}},	//   _arši_, _лахх, _דיעל_, --, 
   {{0x3a289691,0x6b849692,0xde4401ed,0x6d5c033b}},	//   _crap_, rokg, _نیٹو_, èsas, 
   {{0x3a288fd1,0x63a09693,0xa36801a9,0x00000000}},	//   _drap_, zmon, nsеr, --, 
   {{0x3a289694,0x6b8427be,0x98640022,0x00000000}},	//   _erap_, pokg, аирб_, --, 
   {{0x70d0038e,0x3a289695,0x63a04eca,0x291c0153}},	//   हरुल, _frap_, xmon, žta_, 
   {{0x6b440491,0x3a289696,0xe6189697,0x8af000ac}},	// [bb00] _fógr, _grap_, ъда_, _eləc, 
   {{0x63a04d0e,0x6614002d,0xe450007b,0x94c800f1}},	//   wmon, rwyk, يضا_, نامې_, 
   {{0x63a000c8,0xaab80abd,0xe50002e5,0x320c0076}},	//   tmon, _इलाक, र्षि_, _apey_, 
   {{0x63a09698,0x00000000,0x00000000,0x00000000}},	//   umon, --, --, --, 
   {{0x70d0038e,0x2484012d,0x00000000,0x00000000}},	//   हरूल, łom_, --, --, 
   {{0x63a09699,0x2934008f,0x63b8003e,0x7c3c0267}},	//   smon, שאַן_, _étno, ärrk, 
   {{0x2018011c,0x63a00af9,0x2fc40175,0x320c0790}},	//   ìpi_, pmon, _ctlg_, _epey_, 
   {{0x9c80278a,0x6e2c2625,0x63a0022e,0xbdd403c5}},	//   _účin, _šaba, qmon, боищ, 
   {{0x2b90969a,0x9cc8969b,0x91cc012d,0xdd9801f0}},	//   mách_, кына_, सीआई, кшо_, 
   {{0x5164969c,0x2b900122,0x516000a7,0x3a280200}},	//   _күчү_, lách_, _двуб, _rrap_, 
   {{0x81e80183,0x8cb405b3,0x5158011a,0x00000000}},	//   _বহি_, ोड़ो, _שכבו, --, 
   {{0x2b90969d,0x3a2802d3,0x320c002d,0x1e844538}},	//   nách_, _prap_, _ypey_, _клем, 
   {{0xda78969e,0x8e34969f,0x6f0c00e4,0x00000000}},	//   тян_, _نسور_, _ñaca, --, 
   {{0x2b900122,0xa7a002d3,0x3a280240,0x81e800fe}},	//   hách_, _ገለገለ_, _vrap_, _বহা_, 
   {{0x3a2896a0,0xf1b80989,0x2b900232,0xc7b82c1d}},	//   _wrap_, _vrši_, kách_, иёт_, 
   {{0x3a2896a1,0x2b9002f0,0xcc54011a,0x9ad80055}},	//   _trap_, jách_, _כבוי_, bhāṅ, 
   {{0x2b900122,0xd4c400d1,0xf6980261,0xf1b80427}},	// [bb10] dách_, لغاي, увај_, _trši_, 
   {{0x58840006,0x00000000,0x00000000,0x00000000}},	//   _выма, --, --, --, 
   {{0x320c96a2,0xdb1811ab,0x2b9001e7,0x00000000}},	//   _spey_, pptä, fách_, --, 
   {{0x6b700421,0x2b900306,0xf5e800ec,0x2bb8000d}},	//   tāgi, gách_, _مڙئي_, _ईंसा, 
   {{0x645c01c4,0x776c067c,0x95c896a3,0x8f6401d3}},	//   azpi, miax, _шуна_, یلتے_, 
   {{0x45d496a4,0xdfcc00aa,0xf4340262,0x823496a5}},	//   _форс, ډيو_, _легэ, ترما, 
   {{0xd3442a60,0x2b900122,0x9420129d,0xef18031c}},	//   _پیشه_, bách_, _بوزۇ, lożi_, 
   {{0xef1896a6,0x3cfc017a,0xa368022e,0x00000000}},	//   уми_, _acvv_, ssеr, --, 
   {{0x764c96a7,0x90e400e3,0x325400c0,0xef18031c}},	//   nyay, _نسان, _увар, nożi_, 
   {{0x2b900030,0x764c058a,0x6448324c,0x00000000}},	//   máci_, iyay, äfig, --, 
   {{0x764c96a8,0x2b9002fb,0xf1b80010,0x3084007b}},	//   hyay, láci_, _huš_, _الضف, 
   {{0xa3e81025,0x764c96a9,0x41b438eb,0x6b540117}},	//   _मिस_, kyay, _امەر, стох, 
   {{0x764c1423,0xa9a447ca,0x2d981497,0x00000000}},	//   jyay, йимд, ïses_, --, 
   {{0x764c96aa,0x9f48007f,0x2b900306,0x00000000}},	//   dyay, _òmòn_, zách_, --, 
   {{0xe57802a9,0x764c0067,0x00000000,0x00000000}},	//   ҳза_, eyay, --, --, 
   {{0x2efc017a,0x764c03e0,0x2b900419,0x00000000}},	//   _jcwf_, fyay, káci_, --, 
   {{0x2b9096ab,0x764c96ac,0xf1b80841,0x5ac40daf}},	// [bb20] vách_, gyay, _kršu_, _улым_, 
   {{0x2b900306,0x9a38011a,0x645c002f,0x00000000}},	//   dáci_, _עתיק, tzpi, --, 
   {{0xe2c81679,0x2b900232,0xe3b000dd,0x23280861}},	//   глед_, tách_, سرا_, ложи_, 
   {{0x764c0796,0xe73896ad,0xf1b80331,0x6e2c0327}},	//   byay, _сем_, _buš_, _ġabn, 
   {{0x2b900122,0x764c1423,0x645c06d8,0x00000000}},	//   rách_, cyay, szpi, --, 
   {{0x64a496ae,0xdb0803fa,0x2b9002fb,0xc43403e6}},	//   _гага, _zufä, sách_, _وکات, 
   {{0x2b900122,0x22506b6a,0x7bc40153,0x00000000}},	//   pách_, šyk_, _čiuo, --, 
   {{0xf1b80841,0x2b900f91,0x33d400d4,0xc56401f7}},	//   _fuš_, báci_, _фірт, _اُڀي, 
   {{0xdda801c6,0x53a001a9,0x00000000,0x00000000}},	//   лтол_, _хатб, --, --, 
   {{0x61e096af,0x00000000,0x00000000,0x00000000}},	//   msol, --, --, --, 
   {{0x61e096b0,0x69b01533,0x9740041a,0x69d40857}},	//   lsol, _इंजी, šćiv, _awye, 
   {{0x60d896b1,0x61e096b2,0x69d40042,0x764c96b3}},	//   _hetm, osol, _bwye, yyay, 
   {{0x60d8036b,0x5398008f,0xde9496b4,0x0c000014}},	//   _ketm, טיטו, _اجاب, _ہووُ, 
   {{0x764c68d2,0x61e096b5,0x383496b6,0x6ab401ed}},	//   vyay, isol, онгр, _egyf, 
   {{0x60d895bb,0x776c0077,0x2b9002f0,0xbb58030d}},	//   _metm, tiax, záci_, _вайх_, 
   {{0x764c0a28,0x60d8014f,0xc7b896b7,0x201c4c8f}},	//   tyay, _letm, сёр_, _msti_, 
   {{0x34c80efb,0x7d0801a4,0x7c280fac,0xf4d82083}},	// [bb30] لداۋ_, ofds, lvdr, имаш_, 
   {{0x60d896b8,0x764c96b9,0x201c96ba,0x2b902195}},	//   _netm, ryay, _osti_, váci_, 
   {{0xd49896bb,0x61e096bc,0x764c96bd,0x22bc02e3}},	//   ура_, esol, syay, _ịka_, 
   {{0x391401d5,0x7bc40153,0x2b9000d7,0x30900240}},	//   _اوگز, _čiul, táci_, _ምሕጻብ_, 
   {{0x201c96be,0x61e096bf,0x60d85476,0x764c02d1}},	//   _asti_, gsol, _betm, qyay, 
   {{0x60d80077,0x6e2c96c0,0x2b900306,0xd3d81291}},	//   _cetm, _šabo, ráci_, _مبرا_, 
   {{0x61e096c1,0x75340ffb,0x60d896c2,0x2b9002f0}},	//   asol, _inzz, _detm, sáci_, 
   {{0xf1b81109,0x61e06257,0x60d8127b,0xd258010b}},	//   _tuš_, bsol, _eetm, _йцз_, 
   {{0x201c96c3,0x6584002d,0xd16400a7,0x61e001ed}},	//   _esti_, _úthô, _лъжи, csol, 
   {{0x60d803be,0x752402b9,0xbc8401fb,0x225003cd}},	//   _getm, ndhz, ườn, øyke_, 
   {{0x69d4017a,0x26c400e8,0x7bdc0124,0x00000000}},	//   _swye, ñook_, árup, --, 
   {{0x60d801a4,0x7ff48e10,0x2e2400ae,0x00000000}},	//   _zetm, _رسما, _وفضف, --, 
   {{0x60d896c4,0x62840b1a,0x6f080472,0x7c280267}},	//   _yetm, _økot, mfec, avdr, 
   {{0xa3e8534e,0x00000000,0x00000000,0x00000000}},	//   _मिल_, --, --, --, 
   {{0x6e2896c5,0xdd8c96c6,0x96c405db,0x7524003e}},	//   lveb, _جوو_, _ụfọd, ddhz, 
   {{0xa6c805f5,0x6f0896c7,0xbbe80214,0x98a03cc5}},	//   рлаа_, nfec, _اروم_, фисе, 
   {{0x7c3c0267,0x00000000,0x00000000,0x00000000}},	// [bb40] ärrv, --, --, --, 
   {{0x6d4096c8,0x81e803d4,0xd6cc01ed,0x24080f5c}},	//   njla, _বহল_, فقہ_, инзи_, 
   {{0x60d896c9,0xe2c816ac,0x61e0025c,0x00000000}},	//   _retm, لواو_, wsol, --, 
   {{0x60d84f07,0x61e096ca,0xd498074d,0xa22800d8}},	//   _setm, tsol, ăра_, ижеа_, 
   {{0xe21496cb,0x26d096cc,0xe5a43129,0x61e010d9}},	//   تباع, mbyo_, _мими, usol, 
   {{0xdb08049f,0x61e096cd,0x6f080483,0xe4d896ce}},	//   _utfö, rsol, efec, _خوست_, 
   {{0x6f0896cf,0x60d8044e,0xd8d4008f,0x6e28127b}},	//   ffec, _vetm, קוקט_, eveb, 
   {{0xc0e0069c,0x26d000ca,0x60d80b4f,0x00000000}},	//   _ሓድሽ_, nbyo_, _wetm, --, 
   {{0x60d896d0,0x3f987106,0x201c0142,0x00000000}},	//   _tetm, ēru_, _wsti_, --, 
   {{0xa06896d1,0xdb1805ac,0x7bf80114,0xa0a40408}},	//   _каза_, lptø, бнор_, _дазд, 
   {{0x2d480048,0x9ee804d3,0x201c96d2,0x712000cf}},	//   _púer_, _نفال_, _usti_, _سۉيم, 
   {{0x628448a1,0x2908058a,0xffa401af,0x00000000}},	//   _økos, efba_, _элеү, --, 
   {{0x4f840050,0xde7496d3,0xca240120,0xfcc401af}},	//   _بالہ, _بداع, мфри, _нәнм, 
   {{0x26d01418,0xdcb02374,0x00000000,0x00000000}},	//   ebyo_, _قىش_, --, --, 
   {{0x36d496d4,0xa2a8041c,0x176804b3,0x00000000}},	//   зобр, जेत्, арап_, --, 
   {{0x76b896d5,0xc614015b,0x7c3c007c,0xcb68009b}},	//   слар_, সিনা_, ärru, _маје_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [bb50] --, --, --, --, 
   {{0xd7f80262,0x7afc8605,0x26d096d6,0x4974013d}},	//   _кум_, lgst, abyo_, _олыс, 
   {{0xf8b0034c,0x49743334,0x7afc057b,0x6e280433}},	//   _سکس_, _ілюс, ogst, zveb, 
   {{0x1cd8003d,0x7afc96d7,0x00000000,0x00000000}},	//   _འབའ_, ngst, --, --, 
   {{0xbcfc0022,0x7afc96d8,0xe708009f,0xfcc80092}},	//   chĩg, igst, _اتپن_, _በመጡ_, 
   {{0x21f00ae5,0xd5a001b9,0x00000000,0x00000000}},	//   ركىس, _آلسی, --, --, 
   {{0x7afc00b5,0x1cb00327,0x6d4001a9,0xf45800ae}},	//   kgst, _ཐུཊ_, vjla, _الأع_, 
   {{0x2b9000bc,0xf1c402d2,0x00000000,0x00000000}},	//   náct_, _þáog_, --, --, 
   {{0x6f080e1e,0x3254792b,0x00000000,0x00000000}},	//   rfec, _эвар, --, --, 
   {{0x6f0896d9,0x7afc26c5,0x6d400399,0xed5896da}},	//   sfec, egst, ujla, соо_, 
   {{0xeb2c02d3,0x01640014,0x62840158,0xab2896db}},	//   _ሽማግለ, _تُلَ, _økor, бона_, 
   {{0xe45400c8,0x7afc2ff9,0x8e34004b,0x00000000}},	//   פירט_, ggst, _وياړ_, --, 
   {{0x3e840200,0xedc801c8,0x00000000,0x00000000}},	//   rëtë_, _اِتي_, --, --, 
   {{0x1cd8003d,0x7afc2a28,0x61300166,0x1d7c0092}},	//   _འབར_, agst, _iñlä, _እሴቶች_, 
   {{0xe7381d0f,0xfcc80092,0xbaac00eb,0x7c3c007c}},	//   бев_, _በመጣ_, কুলছ, ärrt, 
   {{0xdcac0150,0xef180327,0xd820009d,0xdbc40254}},	//   _حىى_, neż_, эдси, tööh, 
   {{0x26d0089c,0xe4d400c6,0x00000000,0x00000000}},	// [bb60] rbyo_, كتاب, --, --, 
   {{0xdcf80118,0x00000000,0x00000000,0x00000000}},	//   dotě, --, --, --, 
   {{0x1cd831d9,0xfa080327,0x7bc40064,0xb400004e}},	//   _འབལ_, _ཇཱོན_, _čiuk, күрд, 
   {{0x9f4c043b,0x00000000,0x00000000,0x00000000}},	//   kufá_, --, --, --, 
   {{0x0cd800af,0x2b9001d3,0xd24c0014,0x00000000}},	//   _मजूम, lács_, ُنم_, --, 
   {{0x672401f5,0x00940166,0x1a9800df,0x00000000}},	//   _hakj, милэ, זינע, --, 
   {{0x8af000ac,0x23281a92,0x7afc96dc,0x656c96dd}},	//   _aləm, _лови_, ygst, _imbh, 
   {{0x67240227,0x54780375,0x91b800cc,0x00000000}},	//   _jakj, _הטלו, _উবৰ্, --, 
   {{0x672496de,0x3b18026c,0x8d70004b,0x9f480241}},	//   _makj, vesq_, کايا, _íbí_, 
   {{0x672496df,0x2b9001d3,0x5f7400e5,0x00000000}},	//   _lakj, kács_, _کائر, --, 
   {{0xbae000bd,0x8af000ac,0xd00c96e0,0x205401b9}},	//   _ভাবছ, _eləm, _ملل_, _этар, 
   {{0x7afc005f,0x5474010f,0x00000000,0x00000000}},	//   ugst, לגיע_, --, --, 
   {{0x656c379d,0x9da80395,0x00000000,0x00000000}},	//   _ombh, _лъка_, --, --, 
   {{0xd90c107f,0x3c58084c,0x672401bf,0x7c3c0267}},	//   چیک_, _милэ_, _aakj, ärrs, 
   {{0xd90c0502,0x672496e1,0x00000000,0x00000000}},	//   نیک_, _bakj, --, --, 
   {{0x656c96e2,0x7b840150,0x00000000,0x00000000}},	//   _ambh, _تاتە, --, --, 
   {{0x59b496e3,0x7aec96e4,0x6724020c,0x35b4551b}},	// [bb70] _इंटर, _idat, _dakj, дбар, 
   {{0xb4c80574,0x89dc011a,0xe5e8010b,0x4a5c011a}},	//   ैरे_, _החזי, _ölýä, _לדחו, 
   {{0x6724002d,0xdb080158,0x645896e5,0xbcfc0022}},	//   _fakj, _bufø, _ütil, chĩe, 
   {{0x656c2dee,0xa2d001e2,0x8c18011a,0x00000000}},	//   _embh, پيوت, מובי, --, 
   {{0x913000c7,0x00000000,0x00000000,0x00000000}},	//   нҭах, --, --, --, 
   {{0x672496e6,0x656c7421,0x00000000,0x00000000}},	//   _zakj, _gmbh, --, --, 
   {{0x7aec96e7,0x67240ac5,0xef180210,0x00000000}},	//   _odat, _yakj, też_, --, 
   {{0x4394009d,0x00000000,0x00000000,0x00000000}},	//   _засс, --, --, --, 
   {{0x71780022,0xada42ced,0x795801e1,0xef180327}},	//   _дбар_, маил, _nìwo, reż_, 
   {{0x7aec96e8,0x6ecc96e9,0x62240150,0x0c640454}},	//   _adat, _ध्रु, _زومە, ззоқ_, 
   {{0xcfa4010b,0x5928031c,0xe5000118,0x00000000}},	//   _ешди, _སྣེས_, र्टि_, --, 
   {{0x7aec010a,0x2b9001d3,0x00000000,0x00000000}},	//   _cdat, vács_, --, --, 
   {{0x7aec0cfd,0xe8b400dc,0x672400e5,0x00000000}},	//   _ddat, ंश्च, _rakj, --, 
   {{0x25ec1533,0xa06009a5,0x7aec96ea,0x672404fb}},	//   ेंसी_, _öňün, _edat, _sakj, 
   {{0x672496eb,0x7aec13be,0x49a40220,0xbbe896ec}},	//   _pakj, _fdat, дыңғ, _فريم_, 
   {{0x1cd80135,0x9f540205,0x00000000,0x00000000}},	//   _འབོ_, şgör_, --, --, 
   {{0xa52496ed,0x672496ee,0xe9680e92,0x00000000}},	// [bb80] ммад, _vakj, _маил_, --, 
   {{0x3f800006,0x7aec02fb,0x649800f3,0x00000000}},	//   čiui_, _zdat, отер_, --, 
   {{0x1cb01f21,0x25ec000d,0x00000000,0x00000000}},	//   _ཐུབ_, ेंही_, --, --, 
   {{0x65c496ef,0x6f0c02d1,0x42a400d1,0x00000000}},	//   _обма, _ñach, нулғ, --, 
   {{0xa3dc09d9,0xd36c0451,0x93400801,0x8b080024}},	//   _दौर_, جهن_, ънце, _gręž, 
   {{0x656c2a6c,0xe70801d9,0x1cd8031c,0x53a000d1}},	//   _umbh, _اتھن_, _འབེ_, ىمەك, 
   {{0x442c5eb5,0xdee8001f,0x7f946b2f,0xf04400e5}},	//   _éd_, _መስክ_, накх, فٹوی, 
   {{0x2ff466a3,0x00000000,0x00000000,0x00000000}},	//   رتىڭ, --, --, --, 
   {{0xd24c034c,0xfe7003e6,0xa2a81fd2,0x8af003b9}},	//   _پنل_, دگا_, जेश्, _iləh, 
   {{0x657c00c6,0x1cb0025c,0x20540114,0x00000000}},	//   nnph, _ཐུད_, _отер, --, 
   {{0xcf8c0261,0x6d9c067c,0x657c02d0,0x6e3c007c}},	//   _ај_, pèan, inph, äsbr, 
   {{0x608c0240,0x00000000,0x00000000,0x00000000}},	//   _ምሕጓስ_, --, --, --, 
   {{0x310400dc,0x4ea001ee,0x4bc096f0,0x00000000}},	//   _रामः_, _ирша, нөөг, --, 
   {{0x9f4c007b,0x00000000,0x00000000,0x00000000}},	//   irfí_, --, --, --, 
   {{0x3f58020c,0xa3e802ab,0x7aec0175,0x6e2c031c}},	//   _léum_, _मिग_, _tdat, _ġabi, 
   {{0x6e2c3421,0xb4c800dc,0xcb0802dd,0x657c0208}},	//   _šabi, ैर्_, _قيىن_, enph, 
   {{0xb8f404c5,0xbcfc035b,0x00000000,0x00000000}},	// [bb90] _হয_, chĩc, --, --, 
   {{0xd498024d,0x15f005ba,0xd83801c6,0xab600037}},	//   оре_, ेंबर_, _дэм_, _üüra, 
   {{0xf48450b5,0xdb180306,0x938801d5,0x81e805ac}},	//   رائی, zptý, осда_, _বহগ_, 
   {{0x1cb0081f,0x57200137,0xdb1896f1,0xdd840133}},	//   _ཐུན_, _جۉرك, mptó, _ڕو_, 
   {{0xeb9000c8,0xa2a81cd2,0x00000000,0x00000000}},	//   אָג_, जेल्, --, --, 
   {{0x9f5c3eba,0x00000000,0x00000000,0x00000000}},	//   _optó_, --, --, --, 
   {{0x44b400c7,0xf28801d9,0x5348030d,0x00000000}},	//   _абрс, _کھاو_, _мăкă, --, 
   {{0x1cd80003,0x50cc08df,0x5f9000d8,0x00000000}},	//   _འབུ_, _स्रष, лијт, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xad2404a9,0x653800c8,0x00000000,0x00000000}},	//   رىجى, ִערד, --, --, 
   {{0xab2896f2,0x15f0033f,0x00000000,0x00000000}},	//   пона_, ेंडर_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x657c0076,0xbb400022,0x9f88000d,0x00000000}},	//   ynph, рҵык, tööl_, --, 
   {{0x92b80154,0x7bc40064,0x32c00432,0x00000000}},	//   _আজো_, _čiuv, _ỳyl_, --, 
   {{0x6d9c067c,0xe73817a0,0x6c78010f,0x00000000}},	//   nèam, пев_, _מאַפ, --, 
   {{0xa90800f1,0x9f880254,0x00000000,0x00000000}},	//   _کيدل_, sööl_, --, --, 
   {{0x24f496f3,0xa6840dab,0x00000000,0x00000000}},	// [bba0] ечер, хлад, --, --, 
   {{0xe8f8010a,0x00000000,0x00000000,0x00000000}},	//   _эло_, --, --, --, 
   {{0x66e496f4,0xdb180ba1,0x657c002f,0x3f5801a8}},	//   _пона, mptò, rnph, _séum_, 
   {{0x0eb80073,0x070800ec,0x00000000,0x00000000}},	//   _उलगड, _کيڏي_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d9c004e,0x00000000,0x00000000,0x00000000}},	//   fèam, --, --, --, 
   {{0xf4940cd7,0xd01475e1,0xa3e8121d,0xd4a0022e}},	//   _артю, ефы_, _मिट_, _бирй, 
   {{0x444496f5,0xe2c80305,0x8ff400d1,0xfe780166}},	//   mx_, _хлад_, ررىر_, мүе_, 
   {{0x444496f6,0xbb6804ce,0xbad80150,0x9f0000f1}},	//   lx_, _netは_, _ﺃﺸﺨﺎ, نوژو, 
   {{0x444496f7,0x1278010f,0x2ff400cf,0x00000000}},	//   ox_, _זאמע, رتۉڭ, --, 
   {{0x444496f8,0x30040014,0x00000000,0x00000000}},	//   nx_, _لبنُ, --, --, 
   {{0x444496f9,0xdee401b9,0xa368022e,0x545400df}},	//   ix_, _чоди, tsеy, גסטן_, 
   {{0x1cb031d9,0x4444025c,0xfd64009d,0x00000000}},	//   _ཐུམ_, hx_, _индү, --, 
   {{0x444496fa,0xd90c1079,0x1cd8031c,0x00000000}},	//   kx_, حید_, _འབི_, --, 
   {{0x97a496fb,0x00000000,0x00000000,0x00000000}},	//   ерал, --, --, --, 
   {{0x444496fc,0x6d5c0200,0x4c98011a,0x00000000}},	//   dx_, ësav, _משוע, --, 
   {{0x444496fd,0x1ae40154,0xe77800c7,0x00000000}},	// [bbb0] ex_, _কাপে_, фатә_, --, 
   {{0x444496fe,0x4a7c0375,0xfba418cc,0xcbb80117}},	//   fx_, _מרחב, _गीतम, _оғӯш_, 
   {{0x932401d3,0x85040472,0x00000000,0x00000000}},	//   ٹران, اومن, --, --, 
   {{0x932496ff,0x325417a0,0xdb080205,0x00000000}},	//   عران, квер, _nufü, --, 
   {{0x44449700,0x00000000,0x00000000,0x00000000}},	//   ax_, --, --, --, 
   {{0x1ae400cc,0x44440135,0x6d9c007f,0x00000000}},	//   _কাফে_, bx_, tèam, --, 
   {{0x1ae40154,0xb4cc10eb,0xe2a403b2,0x00000000}},	//   _কানে_, रडी_, _áðni_, --, 
   {{0xee386bed,0x34e0012d,0x00000000,0x00000000}},	//   дни_, _फ़ुद, --, --, 
   {{0xa2c00139,0x00000000,0x00000000,0x00000000}},	//   _тәхк, --, --, --, 
   {{0xbb68037e,0xdd8c157c,0x823437ba,0x22a40107}},	//   _netク_, يوي_, _حرفا, _русҳ, 
   {{0xa6200020,0x68e80b21,0x6d9c0066,0x6e2c031c}},	//   ስተዳደ, _ôfdi, lèak, _ġabu, 
   {{0xed5001d9,0x9e7000f2,0x7bc400c0,0x00000000}},	//   اپھ_, اهیت, _čiut, --, 
   {{0x873c0092,0x102401f7,0x00000000,0x00000000}},	//   _አለማቀ, _آڻڻي_, --, --, 
   {{0x1cd803bd,0xdb089701,0x4444036b,0xbdf8143e}},	//   _འབག_, _bufó, yx_, _سرها_, 
   {{0x66e49702,0x44449703,0xd9403edd,0xe0e400fe}},	//   кова, xx_, шери, _নামভ, 
   {{0xd5c000af,0xd04001e4,0x8d740133,0x18b00124}},	//   _वंशज, ranɨ, _تاڵا, шәыр, 
   {{0xaa44152a,0x44449704,0xdb0800d7,0x386c00df}},	// [bbc0] _репл, wx_, _eufó, ĝera_, 
   {{0x44449705,0x6d9c0066,0x59280327,0xd83c0118}},	//   tx_, dèak, _སལགས_, íčci_, 
   {{0x44449706,0x64989707,0x79880036,0x3fe0000d}},	//   ux_, фтар_, éewe, _गौंआ_, 
   {{0x44449708,0xd36c0592,0xd4640114,0x00000000}},	//   rx_, يهل_, њице_, --, 
   {{0x21689709,0x4444970a,0xf1d4009d,0x00000000}},	//   миди_, sx_, гөхө, --, 
   {{0x64a40124,0x644803cd,0xc0e00023,0x00000000}},	//   _аага, øfis, _ሓትም_, --, 
   {{0x7164215c,0x3ea00010,0x7a480200,0x44440135}},	//   دانك, _šit_, _këtë, qx_, 
   {{0x1cd8031c,0xdef8010b,0xb24401e0,0x00000000}},	//   _འབང_, фык_, тмәһ, --, 
   {{0x13d404c5,0x23640218,0x68e8002d,0xc2f80154}},	//   _হিয়, mhoj_, _ôfdw, _ইউপি_, 
   {{0x6e3c03cd,0x00000000,0x00000000,0x00000000}},	//   åsba, --, --, --, 
   {{0x1be00456,0xe8a8013d,0x00000000,0x00000000}},	//   _कौशल_, _ırğı, --, --, 
   {{0x3f800953,0x30747bb3,0x23640369,0x7a48002e}},	//   čius_, _суус, nhoj_, _nëtë, 
   {{0x3ea00491,0x9a843773,0xedf40451,0xd334011a}},	//   _áit_, тунл, _مينگ, דרכה_, 
   {{0x2244005a,0x0c706e0d,0x00000000,0x00000000}},	//   ixok_, ادید, --, --, 
   {{0x5ba40022,0x236401e4,0x00000000,0x00000000}},	//   _ириз, khoj_, --, --, 
   {{0xba54970b,0xdb0800cf,0x47880fc0,0x2364010f}},	//   _منبع, _eufò, всум_, jhoj_, 
   {{0x798401af,0xc7b89493,0x2364970c,0xc6e402dd}},	// [bbd0] _tjhw, тёр_, dhoj_, рісп, 
   {{0x3a28970d,0xb4cc0073,0x65780092,0x00000000}},	//   _isap_, रडे_, _በረቂቅ_, --, 
   {{0xd498970e,0x7994970f,0x72d421d7,0x00000000}},	//   фра_, mozw, гоеф, --, 
   {{0x79940944,0x7a4800e8,0x23649710,0x970000d1}},	//   lozw, _gëtë, ghoj_, _خېرى, 
   {{0xf07401ed,0x942000d1,0x926400ae,0x00000000}},	//   گیاں_, _ھورۇ, خدام, --, 
   {{0x34949711,0x79949712,0x4a5c0375,0x942000db}},	//   _багр, nozw, ודדו, _پورۇ, 
   {{0x3a280a40,0xf07401ed,0x3b0803e3,0x00000000}},	//   _lsap_, دیاں_, _ocaq_, --, 
   {{0x79949713,0x23640115,0x7a48002e,0x00000000}},	//   hozw, choj_, _xëtë, --, 
   {{0x79949714,0x00000000,0x00000000,0x00000000}},	//   kozw, --, --, --, 
   {{0x332c0369,0x7994009a,0x7bc40153,0xec480798}},	//   _haex_, jozw, _čiur, езол_, 
   {{0xbdc801c0,0x3a280f85,0x7994012d,0x3f9400b8}},	//   нгөж_, _asap_, dozw, _ūcuś_, 
   {{0xa2a80807,0x8df4014b,0xcee800f2,0x7f941188}},	//   जेक्, _амдӣ_, _آران_, _кахх, 
   {{0x332c0007,0x7994014b,0x3a287cb5,0x00000000}},	//   _maex_, fozw, _csap_, --, 
   {{0x79949715,0xd99403e6,0x23640007,0x8af000ac}},	//   gozw, ێنێت_, zhoj_, _alət, 
   {{0x3a280810,0xe87800f2,0x00000000,0x00000000}},	//   _esap_, رمرغ_, --, --, 
   {{0x332c0369,0x2fc40076,0xeb0402e8,0x00000000}},	//   _naex_, _mulg_, _спип, --, 
   {{0x79949716,0x35c40107,0xe61800c0,0xb46400f2}},	// [bbe0] bozw, иатҳ, эда_, یدمه, 
   {{0x8af003b9,0x5a60004e,0x00000000,0x00000000}},	//   _elət, _ыкыб, --, --, 
   {{0x2fc40254,0xe354009d,0xf8440132,0x00000000}},	//   _nulg_, лтдэ, _күрд_, --, 
   {{0x2244009d,0x8af006be,0x60640116,0xa82001d3}},	//   txok_, _iləs, ңҗаң_, _پکڑن, 
   {{0x5b7800c8,0x6fcc0ae5,0xa2c401bc,0x00000000}},	//   ערנא, _ﻗﺎﺭﺷ, िशब्, --, 
   {{0xe4d89717,0x23649718,0x2fc401d5,0x2934008f}},	//   _سورت_, shoj_, _bulg_, ראַן_, 
   {{0x332c0007,0x68e8002d,0x03080022,0x96680241}},	//   _faex_, _ôfdu, _аҭел_, _ò̟ré, 
   {{0x64a40022,0x44389719,0x79940117,0xe298971a}},	//   _ааҳа, _irr_, zozw, _заб_, 
   {{0x7994971b,0x200c0165,0x5ce40006,0x73980114}},	//   yozw, stfi_, люна, _ртрс_, 
   {{0x7994009a,0x2fc40356,0x5de401ec,0x4e140066}},	//   xozw, _fulg_, _ұжда, اتيد_, 
   {{0xa0a4971c,0x5594008f,0x9f04027d,0x00000000}},	//   _сажд, רדיע_, _مواو, --, 
   {{0x4438003e,0x26c00214,0x4fa00801,0x8fa0030d}},	//   _mrr_, _ngko_, _лихв, _лахе, 
   {{0x79940b12,0x5f0407dd,0x629c0034,0x5964013d}},	//   tozw, _азҵа, ępow, гъва, 
   {{0x4438971d,0xceb00bd9,0x2fc401a9,0x00000000}},	//   _orr_, _פיס_, _yulg_, --, 
   {{0x7994971e,0x44380fac,0x386c010f,0x8c40009b}},	//   rozw, _nrr_, ĝero_, _геје, 
   {{0x799454da,0xdcf800e2,0x00000000,0x00000000}},	//   sozw, potē, --, --, 
   {{0x76b8971f,0x3a288b14,0x25ec0034,0x8af00213}},	// [bbf0] тлар_, _usap_, ेंगी_, _eləs, 
   {{0x3f8403f9,0x7994009a,0x39140798,0x00000000}},	//   hnmu_, qozw, _тмор, --, 
   {{0x44389720,0x73c40b8d,0x8af003b9,0x672c0108}},	//   _crr_, рәге, _ilər, önjä, 
   {{0xf314009d,0xc34800d4,0x9f480cad,0xd6d8011c}},	//   рддэ, ляче_, _ìbè_, _ято_, 
   {{0x324446e8,0x394001a4,0x44389721,0x2fc40254}},	//   релг, _knhs_, _err_, _sulg_, 
   {{0x443804cc,0x2fc40789,0x6ff49722,0xb42401d3}},	//   _frr_, _pulg_, ачих, _پٹرو, 
   {{0xa154026a,0xf8b400e1,0x5928025c,0xdfcc314c}},	//   рају_, ंधिय, _སྣབས_, ويو_, 
   {{0x34941ee3,0x7d1803ac,0x2fc4003a,0x7bc40153}},	//   _баҳр, _abvs, _vulg_, _čiup, 
   {{0x443802b9,0x7c3805c7,0x7820012d,0x00000000}},	//   _zrr_, _arvr, मबुक_, --, 
   {{0x3f84207a,0xed5896da,0x0c740023,0x44380142}},	//   anmu_, тоо_, _ኣንጻሩ_, _yrr_, 
   {{0xbcfc00c7,0xdd8c00f1,0x00000000,0x00000000}},	//   chĩm, ړوی_, --, --, 
   {{0x7ed40064,0x00000000,0x00000000,0x00000000}},	//   _лішч, --, --, --, 
   {{0x8d740139,0xfd4c0055,0x2c2400eb,0x00000000}},	//   _бәну_, _laiṅ, যমেই_, --, 
   {{0x3940007f,0xac740046,0xa2a80034,0xac3801c4}},	//   _cnhs_, _پاتش, जेट्, _ачих_, 
   {{0x78c401ef,0x00000000,0x00000000,0x00000000}},	//   _štvá, --, --, --, 
   {{0x92e40154,0xeb987d60,0x9b900244,0x6924035b}},	//   পলু_, _ший_, _ولوت, ымҳа, 
  
   {{0xa36801a9,0xc33000d1,0x00000000,0x00000000}},	// [bc00] spеk, ۋەس_, --, --, 
   {{0x1cd80ed9,0x44387dcd,0x69d49723,0x2d849724}},	//   _འབབ_, _prr_, _itye, nnle_, 
   {{0x44380407,0x2d84090e,0x7a8410e8,0x00000000}},	//   _qrr_, inle_, _نشیم, --, 
   {{0x25fc9725,0x8af006be,0x96940107,0x00000000}},	//   _लिपी_, _zlər, урӣш, --, 
   {{0xe124167e,0xdb189726,0xc7b4016b,0x44380477}},	//   имди, mptô, mmɑ_, _wrr_, 
   {{0x4438151c,0xdcf80356,0xc0e800e5,0x00000000}},	//   _trr_, intă, اہان_, --, 
   {{0x44389727,0x00000000,0x00000000,0x00000000}},	//   _urr_, --, --, --, 
   {{0x69d49728,0xe81c05f9,0xa6e0022c,0x291800ef}},	//   _otye, _पहना_, áðha, _lbpa_, 
   {{0x1cd876ff,0x63a09729,0x6e380042,0xdcf801e4}},	//   _འབད_, mlon, _crwb, litĉ, 
   {{0x63a0972a,0x21a4972b,0x61b001ec,0x6e380042}},	//   llon, _тизм, _بەتا, _drwb, 
   {{0x63a08ad8,0x69d4972c,0xdcf8054e,0x8af003b9}},	//   olon, _atye, entă, _rlər, 
   {{0x63a0138f,0x2d840014,0xd00c0345,0x00000000}},	//   nlon, anle_, _زله_, --, 
   {{0x63a0123c,0x6e380142,0xa2a823e9,0x00000000}},	//   ilon, _grwb, जेच्, --, 
   {{0x63a0972d,0xdb080267,0x00000000,0x00000000}},	//   hlon, _nufö, --, --, 
   {{0x69d47aaf,0x1be401b9,0xad240ee8,0x00000000}},	//   _etye, _тўлг, _درنو, --, 
   {{0x5018025f,0xdb1c02d3,0xefe00023,0xef240139}},	//   כולו, _miqë, _ዓብዪ_, _çüte_, 
   {{0x63a0972e,0xd84000bc,0x0708038b,0xc8c80014}},	// [bc10] dlon, dičů_, شيلي_, اوہن_, 
   {{0x05740372,0x3cec01fa,0x63a0972f,0x7d086e95}},	//   يالد, nadv_, elon, ngds, 
   {{0x1cd8031c,0xef180327,0xf314009d,0x98480395}},	//   _འབན_, liże_, йджэ, _ряпа_, 
   {{0x63a09730,0x27fc0030,0x68e8000f,0x7c3c005b}},	//   glon, átne_, _ôfdr, ärry, 
   {{0x201c4ff3,0x96449731,0x2d840142,0x3fd00150}},	//   _apti_, _тэнд, ynle_, _ﻗﺎﺭﻧ, 
   {{0x27fc54b0,0xdcf80064,0xdb800116,0x00000000}},	//   štne_, motė, ﺧﺎﺭﻯ_, --, 
   {{0x63a09732,0x629403ee,0xd84000bc,0x53440408}},	//   blon, üyor, bičů_, _кхаа, 
   {{0x43949733,0x9f4c033b,0x00000000,0x00000000}},	//   _дасс, nsfè_, --, --, 
   {{0x7d0845a7,0xdb08014a,0x2d945e0c,0xdcf80064}},	//   fgds, _yufö, йрос, notė, 
   {{0x51849734,0x1ae400fe,0xdc800023,0x51c80ef6}},	//   _туба, _কাষে_, _ዓቕመይ_, _ﻗﻮﻳﺸ, 
   {{0x69d403a2,0x3f580120,0xd6f800b5,0x2d840042}},	//   _stye, _céus_, _ckカ_, rnle_, 
   {{0x29180ac5,0x3f5800cf,0x6e380042,0xdcf80064}},	//   _sbpa_, _déus_, _trwb, kotė, 
   {{0x244c025a,0x1f2401d9,0x7fb400db,0x68449735}},	//   _kömë_, _دِنہ, _بۇير_, әнба, 
   {{0x63a09736,0x6e288f29,0x6b8400b5,0x6cc400cf}},	//   zlon, mweb, snkg, _уйка, 
   {{0x18649737,0x3f58003e,0x6e289738,0x78a80118}},	//   бари_, _géus_, lweb, řevn, 
   {{0x7c3c037e,0x69d401a9,0x63a00051,0x00000000}},	//   ærre, _ttye, xlon, --, 
   {{0x6e289739,0xe5c853f3,0x69d400f1,0x63a0792d}},	// [bc20] nweb, اظره_, _utye, vlon, 
   {{0x3f58020c,0x6e280466,0x00000000,0x00000000}},	//   _yéus_, iweb, --, --, 
   {{0x63a0973a,0x6e28973b,0x2908063f,0xdd78008f}},	//   tlon, hweb, mgba_, נטעל, 
   {{0x68ec973c,0x6e28973d,0xd24c1da4,0x63a0973e}},	//   labd, kweb, کنه_, ulon, 
   {{0x63a0973f,0x6f08035a,0x7d0801e6,0xc178010b}},	//   rlon, dgec, ygds, аҗа_, 
   {{0x29089740,0x63a09741,0x6e289742,0xd59800b5}},	//   ngba_, slon, dweb, _jpが_, 
   {{0x63a09743,0x657c9744,0xefe002d3,0x00000000}},	//   plon, miph, _ዓብይ_, --, 
   {{0x657c2747,0x2908006a,0x3f580120,0xb35404fb}},	//   liph, hgba_, _réus_, _ویلا_, 
   {{0x93409745,0x68ec05b1,0x1ae4015b,0x3cec00cc}},	//   _энте, kabd, _কালে_, tadv_, 
   {{0x657c9746,0x68ec05b1,0xd654011a,0x00000000}},	//   niph, jabd, ציית_, --, 
   {{0x071817ee,0x6e280083,0x7c2801f5,0x26d00009}},	//   दभाव_, aweb, uwdr, kcyo_, 
   {{0x657c9747,0x6e289748,0x1cd8031c,0x5d10004b}},	//   hiph, bweb, _འབམ_, _کېدا, 
   {{0x6e286580,0xfcc424ae,0xdbe00077,0x657c9749}},	//   cweb, _мәнм, _véñe, kiph, 
   {{0x657c0472,0x68ec0009,0x645c0108,0xa2a800cc}},	//   jiph, gabd, kypi, _ওলাও, 
   {{0x657c974a,0xdbe0056a,0x115800c8,0x00000000}},	//   diph, _téñe, נדלע, --, 
   {{0x290801e1,0x00000000,0x00000000,0x00000000}},	//   agba_, --, --, --, 
   {{0x657c974b,0xdaa00eff,0x68ec01b9,0xa3bc000d}},	// [bc30] fiph, _رەسپ, babd, ुआन_, 
   {{0x657c974c,0x89d801d9,0x26d00009,0x68ec7caa}},	//   giph, _دوٝر_, acyo_, cabd, 
   {{0xb7181d1b,0x75240112,0xc9d404f2,0x94a8009d}},	//   _конф_, rehz, _وزیب, утаа_, 
   {{0x75d400f1,0x92e81896,0x26d0037e,0xc9b000d1}},	//   _ويجا, اراق_, ccyo_, ﺰﯨﻠﻐ, 
   {{0xf0e83955,0x657c974d,0x6e2800aa,0x00000000}},	//   لىشى_, biph, xweb, --, 
   {{0x657c974e,0x764c974f,0x645c9750,0x61409751}},	//   ciph, mxay, bypi, деша, 
   {{0xb4e4242e,0x6d4400e4,0x06a000d1,0x764c01a9}},	//   नरी_, _òhai, ﺋﯩﻠﯩ, lxay, 
   {{0x6e283699,0x7fe83fe2,0x00000000,0x00000000}},	//   tweb, حروف_, --, --, 
   {{0x6f089752,0x764c0946,0x68ec9753,0xdef80023}},	//   rgec, nxay, yabd, ጊስካ_, 
   {{0x6e289754,0xf04401b9,0x6f080036,0x2eec0332}},	//   rweb, _وعای, sgec, saef_, 
   {{0x6e289755,0x68ec9756,0x506401c0,0x00000000}},	//   sweb, vabd, _утаа, --, 
   {{0xeab89757,0x657c1253,0x6e289758,0x68ec0367}},	//   ийн_, ziph, pweb, wabd, 
   {{0x657c124c,0x645c033f,0x68ec0213,0x6e280472}},	//   yiph, zypi, tabd, qweb, 
   {{0xb328025c,0x657c9759,0x1d04288a,0x6844975a}},	//   _ལིའང_, xiph, _деши_, онга, 
   {{0x68ec975b,0x994c0209,0x764c058a,0xa6c802e8}},	//   rabd, _müň_, exay, илва_, 
   {{0x68ec07f3,0x657c975c,0x645c02f0,0x26d00009}},	//   sabd, wiph, vypi, ucyo_, 
   {{0x63b8975d,0x24e8023b,0x657c975e,0x3774010b}},	// [bc40] _ètni, имаи_, tiph, чырс, 
   {{0x645c975f,0x499401d3,0x68ec0327,0xe504007b}},	//   typi, _ریزر, qabd, تبري, 
   {{0x776c9760,0x93c81893,0x764c058a,0xd24c03e6}},	//   bhax, لانہ_, axay, ێنم_, 
   {{0x657c2747,0xe7381c22,0xe6449761,0x776c0bc9}},	//   siph, _тем_, _демп, chax, 
   {{0x645c9762,0xffb4009d,0x00000000,0x00000000}},	//   sypi, үйлэ, --, --, 
   {{0x66147778,0x673404ce,0x4034411a,0x78b00162}},	//   mtyk, ldyj, зекс, _íhvø, 
   {{0xdb0c0232,0x1594215c,0x6614010e,0x00000000}},	//   ždéh, _بەلگ_, ltyk, --, 
   {{0x6734035b,0x00000000,0x00000000,0x00000000}},	//   ndyj, --, --, --, 
   {{0x661402d5,0x26c400e8,0x7bd800d7,0x9f480248}},	//   ntyk, ñooy_, _stvu, _ìbí_, 
   {{0x66140953,0x994c010e,0xd1b00014,0x00000000}},	//   ityk, _güň_, _ہیۆک, --, 
   {{0x66140108,0x00000000,0x00000000,0x00000000}},	//   htyk, --, --, --, 
   {{0x66149763,0x776c011f,0x764c011f,0x7ca40092}},	//   ktyk, xhax, yxay, _ማዕረግ_, 
   {{0xd6f8037e,0xdcf80f40,0x64580248,0x67340210}},	//   _chソ_, notī, _àtif, ddyj, 
   {{0xebb800b8,0x00000000,0x00000000,0x00000000}},	//   _āḥ_, --, --, --, 
   {{0x7e609764,0x628c013f,0x7bd803cd,0xef186f39}},	//   lymp, _ɛboa, _utvu, liża_, 
   {{0x27fc1d55,0x170400e5,0xd70400db,0x00000000}},	//   átna_, تفری_, تىرۇ_, --, 
   {{0xef189765,0xa6e008a7,0x776c0564,0xdcf8007f}},	// [bc50] niża_, óðan, rhax, hitč, 
   {{0x776c94f6,0x7aec9766,0x27fc10bf,0x764c0067}},	//   shax, _heat, štna_, rxay, 
   {{0x49b89767,0x7aec9768,0x776c02b9,0x04c80691}},	//   _بايد_, _keat, phax, زوني_, 
   {{0x7aec007f,0x7e60023a,0x8c1802e4,0xd76410e0}},	//   _jeat, kymp, שואי, _بەرى_, 
   {{0x200018a6,0x7aec9769,0xd5b8011c,0xdcf800ef}},	//   _ākia_, _meat, _всв_, gotī, 
   {{0x26dc013f,0x7aec976a,0xef18025c,0xf1140073}},	//   _ɑtom_, _leat, diża_, णभेद_, 
   {{0xe04016ab,0x83f80fbe,0x00000000,0x00000000}},	//   енщи, _мерс_, --, --, 
   {{0xd3402172,0x7aec976b,0x934000cf,0xb8dc0327}},	//   _تفری, _neat, _تىرۇ, _ཆཻ_, 
   {{0x75346934,0xef18025c,0x7e60007c,0x00000000}},	//   _kazz, giża_, gymp, --, 
   {{0x7aec0093,0x82348971,0x00000000,0x00000000}},	//   _aeat, _غرقا, --, --, 
   {{0x7534976c,0x7aec93be,0xd1300092,0x00000000}},	//   _mazz, _beat, _በሽታው, --, 
   {{0x7aec976d,0x6614976e,0x00000000,0x00000000}},	//   _ceat, ytyk, --, --, 
   {{0x273400d1,0x6e440395,0x00000000,0x00000000}},	//   ۋىسس, _хелз, --, --, 
   {{0x7534038f,0x291c976f,0xb4e477d7,0x5e54010f}},	//   _nazz, ýta_, नरो_, _מינע_, 
   {{0x7aec9770,0x18649771,0xdca000ea,0x91d40154}},	//   _feat, пари_, _паши, ডওয়্, 
   {{0x7aec37a8,0x97c0274b,0xe9d81cd6,0x6ae400ee}},	//   _geat, ейсе, _лки_, _эжиз, 
   {{0x75349772,0x69242773,0x673400c0,0x00000000}},	// [bc60] _bazz, _емпа, rdyj, --, 
   {{0x75349773,0x66149774,0x7aec01c4,0x15f001ad}},	//   _cazz, rtyk, _zeat, ेंजर_, 
   {{0x66149775,0x75349776,0x7aec0363,0xa4080154}},	//   styk, _dazz, _yeat, রব্য_, 
   {{0x753402d0,0x66140210,0x00000000,0x00000000}},	//   _eazz, ptyk, --, --, 
   {{0x75349777,0xe63405f5,0x91e00b7e,0x00000000}},	//   _fazz, _эхнэ, еоче, --, 
   {{0x75349778,0xdcf89779,0xd12c009f,0xef18031c}},	//   _gazz, rotī, ُمن_, viża_, 
   {{0x442c977a,0x7c240cf4,0x7e600142,0xa2e401d5}},	//   _èd_, _ćiro, wymp, _новд, 
   {{0x753423db,0xe35405f5,0xef180135,0x7e6001f4}},	//   _zazz, _этгэ, tiża_, tymp, 
   {{0x7aec977b,0x9cc8977c,0xb51858fc,0x75340337}},	//   _reat, йына_, न्वय_, _yazz, 
   {{0x20540ba0,0x63ac0006,0x7aec977d,0x7bf80137}},	//   _нтер, šinė, _seat, онор_, 
   {{0x7aec977e,0xde940014,0xe7bc0574,0x645801e1}},	//   _peat, _کجاب, ्दाप, _àtid, 
   {{0x236400c8,0xef180135,0x9f480ca8,0x00000000}},	//   nkoj_, piża_, _ìbà_, --, 
   {{0xda640150,0x09e40953,0x7aec977f,0x00000000}},	//   ساحي, ноўн, _veat, --, 
   {{0x7aec74da,0xdcb000db,0x23640200,0xccd00051}},	//   _weat, _كىش_, hkoj_, _sẻvớ, 
   {{0x75347897,0x36d49780,0x7b1801fe,0x00000000}},	//   _razz, добр, _дойр_, --, 
   {{0x23649781,0xe81c375c,0x75340083,0xb4e42314}},	//   jkoj_, _पहरा_, _sazz, नर्_, 
   {{0x75349782,0x38c89783,0x4b7c0375,0x00000000}},	// [bc70] _pazz, _وادی_, _לאהו, --, 
   {{0x7534022e,0x00000000,0x00000000,0x00000000}},	//   _qazz, --, --, --, 
   {{0xdee800b7,0x58840408,0xd9dc00cc,0x00000000}},	//   መሩን_, _хыпа, _ভটিম, --, 
   {{0x75342d3a,0x23640218,0x25b803cb,0x00000000}},	//   _wazz, gkoj_, ampl_, --, 
   {{0x75349784,0x45d49785,0x21f000d1,0x6d4408a5}},	//   _tazz, _пояс, پكىس, _óhag, 
   {{0x236401e4,0xa1540063,0x3718009f,0x00000000}},	//   akoj_, даљу_, _ارھھ_, --, 
   {{0xd7480092,0x81c400db,0x00000000,0x00000000}},	//   _መኪናዎ, رەمۇ, --, --, 
   {{0x23640b91,0xac880023,0xa368022e,0x00000000}},	//   ckoj_, _ዓቕሞም_, spеr, --, 
   {{0x0de8001f,0x5108010a,0x41e400c0,0xb11400f3}},	//   _መጥፎ_, _лĕпĕ, _зіха, _омаш, 
   {{0xe81c068f,0x90b00131,0x1e800229,0xe7c80116}},	//   _पहला_, _пәйш, тльм, ﺒﻪﺭﻟ, 
   {{0x80a40037,0x00000000,0x00000000,0x00000000}},	//   _चुपे, --, --, --, 
   {{0x020c002e,0x81e000fe,0x00000000,0x00000000}},	//   _ñëëw_, _থিত_, --, --, 
   {{0xa2f4011a,0x9f480ca8,0x00000000,0x00000000}},	//   ומרה_, _ìbá_, --, --, 
   {{0xf6e8025c,0x27fc02fb,0xbbe817a5,0x9f480241}},	//   _འབུང, átno_, _کروم_, _íbò_, 
   {{0xe7389786,0x23640240,0xb89402e8,0x0ca801d5}},	//   оев_, ykoj_, ертъ, _утди_, 
   {{0xdcf80882,0xdca0010b,0x27fc0219,0xab600205}},	//   mitā, _шащи, štno_, çüde, 
   {{0xdcf89787,0x80a40034,0xbcfc00e4,0x05440022}},	// [bc80] litā, _चुने, chĩs, ндаҟ, 
   {{0x59809788,0xa90800ec,0x00000000,0x00000000}},	//   _альб, _بيدل_, --, --, 
   {{0x236407f5,0xefe002d3,0xdcf80318,0xdc7c069d}},	//   tkoj_, _ዓብዱ_, nitā, _ካንሰር_, 
   {{0xf36410da,0xdcf80124,0x71800022,0x00000000}},	//   нтін, rotĩ, ҳқуе, --, 
   {{0x23649789,0xdcf80a28,0xa02000a2,0x24f400f3}},	//   rkoj_, hitā, _çözu, _очвр, 
   {{0xc1040691,0x5900031c,0xbae000d1,0x98a000e2}},	//   روعي, ཛུགས_, _ﺋﯩﺠﺎ, lejā_, 
   {{0xdb1c0113,0x656c00ae,0x64a4010a,0x00000000}},	//   _siqí, _ilbh, _цава, --, 
   {{0xdcf8198e,0x93407083,0xe298651e,0x5478011a}},	//   ditā, _инсе, _даб_, _וטלו, 
   {{0xbfd001e0,0x645801e1,0x3f9802d2,0x33b40108}},	//   _өҙлө, _àtib, _írum_, _чёрт, 
   {{0x91e0010b,0x00000000,0x00000000,0x00000000}},	//   _рофе, --, --, --, 
   {{0xdcf81a5a,0x11840014,0x00000000,0x00000000}},	//   gitā, _کھۆٹ_, --, --, 
   {{0x61e0978a,0x00000000,0x00000000,0x00000000}},	//   opol, --, --, --, 
   {{0x61e0978b,0x7bdc0306,0x98a000ef,0x00000000}},	//   npol, írub, dejā_, --, 
   {{0x3f84978c,0xd90c397a,0xabb000d1,0x00000000}},	//   limu_, جید_, _ﭼﯩﻘﺎ, --, 
   {{0xdcf8198e,0x21d00ed1,0x00000000,0x00000000}},	//   citā, ﻟﺪﺍﺭ, --, --, 
   {{0x3f84978d,0x656c0107,0x61e0978e,0x0ba40124}},	//   nimu_, _albh, kpol, _ишым, 
   {{0x35b4978f,0x98e42a20,0x60d803fa,0xd5a007d6}},	// [bc90] ебар, _оюнд, _oftm, نلری, 
   {{0x2464693c,0x3f8400b2,0x80a4000d,0x48c000fe}},	//   _ጳውሎስ_, himu_, _चुभे, ্ৰেৰ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x14dc9790,0x61e09791,0x3f849792,0x00000000}},	//   _प्रण, fpol, jimu_, --, 
   {{0x3f849793,0xdcf800e2,0xe7bc02c3,0x61e0072d}},	//   dimu_, zitā, ्दरप, gpol, 
   {{0x8544010a,0x00000000,0x00000000,0x00000000}},	//   _иэсе, --, --, --, 
   {{0xa0a09794,0x61e09795,0x3f847dcd,0x8af00213}},	//   лашд, apol, fimu_, _eləy, 
   {{0xdcf80061,0x61e00072,0x3f842c9b,0x3494022e}},	//   vitā, bpol, gimu_, _жаҳр, 
   {{0xb8140011,0xee3800d4,0x00000000,0x00000000}},	//   াবিত_, їно_, --, --, 
   {{0x3f840093,0x645800cf,0x98a0005f,0xc18401d9}},	//   aimu_, _àtic, zejā_, _لگى۪, 
   {{0x1ae400bd,0x3f8404ba,0x966801e1,0x00000000}},	//   _কাজে_, bimu_, _ò̟fé, --, 
   {{0xdcf84114,0x6fb8765f,0x3f849796,0x25840241}},	//   ritā, _эгер_, cimu_, _kílè_, 
   {{0xdd8c105d,0x862c0240,0x00000000,0x00000000}},	//   _گوو_, ስተንት, --, --, 
   {{0xdcf80061,0xa9689797,0x3178008f,0x7e7400f7}},	//   pitā, чига_, לאָד, _جامئ, 
   {{0x2d846adf,0xdd8c9798,0x61e0151c,0xd820009d}},	//   mile_, _دوو_, zpol, лдри, 
   {{0x2d844a7d,0x61e09799,0xb394001f,0x5d5000c7}},	//   lile_, ypol, ሌቪዥን_, _акәт, 
   {{0x61e001c4,0xe568979a,0x2d8403d5,0x25840cad}},	// [bca0] xpol, пиад_, oile_, _nílè_, 
   {{0x3f84979b,0xdcf8054e,0x61e00158,0xc94400c7}},	//   zimu_, mită, vpol, _рдоқ, 
   {{0xdcf800a8,0x7c248bbb,0x3f84071a,0xd5ac007b}},	//   lită, _ćirk, yimu_, حفل_, 
   {{0x2d840f3f,0x25840248,0xdd0c00a2,0x6b84002f}},	//   hile_, _bílè_, _oñşu, nikg, 
   {{0x2d84979c,0xdcf80276,0x8b08012c,0x3f84979d}},	//   kile_, nită, _zpří, vimu_, 
   {{0x1ae403f4,0x61e0979e,0xe5a4979f,0x656c01c3}},	//   _কাছে_, rpol, _чиги, _ulbh, 
   {{0xdcf8054e,0x00000000,0x00000000,0x00000000}},	//   hită, --, --, --, 
   {{0x2d8400c5,0x502000c6,0x26ec012d,0x8fa00114}},	//   eile_, افيك, _ज़ोर_, лаје, 
   {{0x3f8497a0,0x63a097a1,0x2d8497a2,0x6b844d11}},	//   rimu_, moon, file_, dikg, 
   {{0x2d8497a3,0x3f8497a4,0x63a097a5,0xdcf8054e}},	//   gile_, simu_, loon, dită, 
   {{0x3f8497a6,0x00000000,0x00000000,0x00000000}},	//   pimu_, --, --, --, 
   {{0x63a097a7,0x6b8497a8,0x200c97a9,0x7b8400d1}},	//   noon, gikg, mufi_, ئادە, 
   {{0x2d8497aa,0x200c97ab,0x63a00083,0x8b08013a}},	//   bile_, lufi_, ioon, _spří, 
   {{0x63a097ac,0xce34011a,0x00000000,0x00000000}},	//   hoon, _נאות_, --, --, 
   {{0xb8e897ad,0x7c3497ae,0x200c002e,0x56f000db}},	//   _ऋण_, _рейх, nufi_, лүнс, 
   {{0x63a01b57,0x200c0618,0x2cb005d1,0xcb08075e}},	//   joon, iufi_, üzde_, _كيىن_, 
   {{0xdcf80276,0xf48401ed,0xb998026a,0x6448007c}},	// [bcb0] cită, ھائی, _ових_, åfin, 
   {{0x200c0296,0x3a2897af,0xcc3000c7,0xf8b8004e}},	//   kufi_, _ipap_, _рхәы, _жөб_, 
   {{0x63a097b0,0x98c40116,0x8b0800bc,0x644800d0}},	//   foon, _ясил, _upří, ťfin, 
   {{0x63a097b1,0xdbf00166,0xf2080116,0x00000000}},	//   goon, _iğän, дидa_, --, 
   {{0x2d8497b2,0xdca42002,0x39340023,0x00000000}},	//   yile_, _چى_, _ብምዕራ, --, 
   {{0xdca41b56,0x2d8497b3,0x200c0e14,0x3a28007f}},	//   _نى_, xile_, fufi_, _mpap_, 
   {{0x4174188a,0x200c01aa,0x63a0528c,0xf3c4035b}},	//   دانس, gufi_, boon, _араҟ, 
   {{0x2d8406e4,0x63a097b4,0xc01c001e,0x3a280200}},	//   wile_, coon, _hước_, _opap_, 
   {{0x63a40124,0x321897b5,0x00000000,0x00000000}},	//   _рырҕ, _زياد_, --, --, 
   {{0xdcf8084c,0x200c022f,0xd6f8019b,0x00000000}},	//   vită, bufi_, _thシ_, --, 
   {{0x2d8497b6,0xeb9897b7,0x6b8497b8,0x3a2897b9}},	//   rile_, дин_, tikg, _apap_, 
   {{0xdcf80311,0x408400db,0x00000000,0x00000000}},	//   tită, _сууб, --, --, 
   {{0x2d8497ba,0x6b844d11,0xeaf00c2e,0x3ce00205}},	//   pile_, rikg, _अजीत_, _şive_, 
   {{0xc01c01dc,0x63a097bb,0xdcf8084c,0x2d8497bc}},	//   _nước_, zoon, rită, qile_, 
   {{0x0ca89794,0x63a097bd,0xdcf8054e,0x3ec400fd}},	//   _этди_, yoon, sită, _исәб, 
   {{0xd7000440,0x63a00067,0x291c02e2,0xca744c9a}},	//   изси, xoon, òtab_, _منعک, 
   {{0x7c240bb8,0xc01c07ae,0xe61897be,0x63a097bf}},	// [bcc0] _ćiri, _bước_, ьда_, voon, 
   {{0x63a097c0,0x9c1027dd,0xc01c001e,0xd1d002d3}},	//   woon, _mọnd, _cước_, ረኻት_, 
   {{0x63a097c1,0xe87004a9,0x9f4c0023,0x64400618}},	//   toon, _ئۆزگ, ënës_, āoio, 
   {{0x93400408,0xe7080050,0x228400cf,0xc8e802f2}},	//   инхе, _کتھن_, кулг, _توگۆ_, 
   {{0x200c0e14,0x2b1809ab,0xc1e400db,0x00000000}},	//   wufi_, _भानु_, اۋئي, --, 
   {{0x63a097c2,0x200c0418,0x8ff40131,0x240897c3}},	//   soon, tufi_, ھرىر_, _онги_, 
   {{0x63a097c4,0xf1a80451,0x233400c7,0x00000000}},	//   poon, راهه_, _ихар, --, 
   {{0x200c97c5,0x63a00548,0x00000000,0x00000000}},	//   rufi_, qoon, --, --, 
   {{0xa1c497c6,0x44380ac5,0xd2a400a8,0x00000000}},	//   _абад, _hsr_, _акте_, --, 
   {{0xc01c01fb,0x6b940432,0xd24c007b,0x98a0012d}},	//   _xước_, _ajyg, _بنك_, leją_, 
   {{0x4508015b,0xd00c007b,0x00000000,0x00000000}},	//   র্থক_, _ولك_, --, --, 
   {{0x44388d34,0xdb0c03ee,0x257400b5,0x93f80375}},	//   _msr_, _ödül, _hæld_, ולטי, 
   {{0x6d4c00c6,0x257402d2,0x00000000,0x00000000}},	//   ánaí, _kæld_, --, --, 
   {{0x44380b4b,0x9c4497c7,0x00000000,0x00000000}},	//   _osr_, _ахил, --, --, 
   {{0x97a497c8,0xc86497c9,0xc01c01fb,0x2574032e}},	//   врал, атти, _rước_, _mæld_, 
   {{0x25fc1d15,0x7c380165,0x6b940240,0xc01c0051}},	//   _लिखी_, _isvr, _gjyg, _sước_, 
   {{0x44385e8a,0xc7c800c9,0x45d47696,0xa3bc00e1}},	// [bcd0] _asr_, тыре_, иотс, ुआई_, 
   {{0xf4d0015b,0x7bcc0363,0x00000000,0x00000000}},	//   ির্ব, _hiau, --, --, 
   {{0x7bcc97ca,0xd9b0313e,0x97c4007b,0x00000000}},	//   _kiau, _مەڭد, _لتحم, --, 
   {{0xb274010b,0x00000000,0x00000000,0x00000000}},	//   ллеш, --, --, --, 
   {{0xc01c01fb,0x38c80133,0x4438045a,0x64580248}},	//   _tước_, _تاکی_, _esr_, _àtin, 
   {{0x7bcc97cb,0x7c380b91,0x443897cc,0x7038084c}},	//   _liau, _osvr, _fsr_, ечис_, 
   {{0xc95425f9,0x705473c5,0xe4b40372,0x257497cd}},	//   ימס_, انعا, _бирө, _sælg_, 
   {{0xee380e91,0xb4c00c2e,0x776c0227,0x7bcc97ce}},	//   ени_, ुशी_, nkax, _niau, 
   {{0xa6e009cc,0x44380334,0xef180003,0xb3d801f9}},	//   óðin, _zsr_, niżi_, _बंडख, 
   {{0x257404ce,0x7bcc0ffb,0x27fc151c,0x80a40037}},	//   _vælg_, _aiau, štni_, _चुवे, 
   {{0x7bcc97cf,0x41740131,0x602806be,0x7d1c0e89}},	//   _biau, _ئاقس, _cəmd, òrsa, 
   {{0x7bcc97d0,0x2bb800c6,0xbbe897d1,0xdb1c013d}},	//   _ciau, عادة_, کریم_, _niqä, 
   {{0x257400b5,0x7e000022,0xad240137,0xef180327}},	//   _hæle_, _дҧыз, _مىشى, jiżi_, 
   {{0x7bcc97d2,0x2574005c,0xef18025c,0x602803b9}},	//   _eiau, _kæle_, diżi_, _qəmg, 
   {{0x7bcc97d3,0x27a00220,0x21c40150,0x00000000}},	//   _fiau, йқоң, _ﺨﺎﺴﺭ, --, 
   {{0x7bcc97d4,0x25740158,0xef18031c,0xa6c80120}},	//   _giau, _mæle_, fiżi_, елба_, 
   {{0xa52497d5,0x443897d6,0xaa880832,0x7a840ccb}},	// [bce0] лмад, _ssr_, _سندم_, _پشيم, 
   {{0x776c0227,0x6498404b,0x7bcc0024,0x224801ef}},	//   akax, нтер_, _ziau, _čbk_, 
   {{0x649897d7,0x03a843bb,0xe4044f33,0x69d497d8}},	//   хтар_, نگرو_, узеп, _huye, 
   {{0x69d497d9,0xe2980953,0x44380270,0x7c3c2142}},	//   _kuye, нае_, _vsr_, ærri, 
   {{0xa18497da,0x69d403f9,0x27f40118,0x00000000}},	//   лыкл, _juye, šeně_, --, 
   {{0x64a497db,0x443897dc,0x69d497dd,0x00000000}},	//   _бага, _tsr_, _muye, --, 
   {{0x257400b5,0x69d497de,0x2d200092,0x00000000}},	//   _væld_, _luye, ዲጠናከ, --, 
   {{0x768801a9,0xf1a81550,0x69d402d0,0x70500133}},	//   _fоyd, _یاله_, _ouye, تۆما, 
   {{0x444497df,0x69d40076,0x7bcc0024,0x6f1c067c}},	//   lv_, _nuye, _riau, òsca, 
   {{0x44440190,0x7bcc97e0,0x2574143a,0x7cd808ca}},	//   ov_, _siau, _fæle_, ъмор_, 
   {{0x444497e1,0x69d40198,0x7bcc97e2,0x213c3a45}},	//   nv_, _auye, _piau, _iath_, 
   {{0x444497e3,0x69d497e4,0x30740137,0x776c058a}},	//   iv_, _buye, _туус, xkax, 
   {{0x291800a3,0x69d40789,0x444400af,0x7bcc180f}},	//   _bcpa_, _cuye, hv_, _viau, 
   {{0x69d497e5,0xc98497e6,0xef180003,0x00000000}},	//   _duye, буси, viżi_, --, 
   {{0x444497e7,0x69d40c6a,0x213c97e8,0x8cd8011a}},	//   jv_, _euye, _math_, _אחות, 
   {{0x69d497e9,0x44440324,0x7bcc0421,0x213c97ea}},	//   _fuye, dv_, _uiau, _lath_, 
   {{0x444497eb,0xa3d80c2e,0x776c0054,0xd508004b}},	// [bcf0] ev_, _डूब_, rkax, فغان_, 
   {{0x213c97ec,0x776c01d9,0x798459fc,0xd4981064}},	//   _nath_, skax, _umhw, нре_, 
   {{0x3d1c76f8,0xd49897ed,0x444462a2,0x1b0803d4}},	//   _माने_, хра_, gv_, ষ্ণই_, 
   {{0xb5181094,0x69d40175,0x572000cf,0x0fe40131}},	//   न्जय_, _yuye, _دۉرك, қлиқ_, 
   {{0x44440190,0x257405ac,0x69d4004d,0x213c97ee}},	//   av_, _sæle_, _xuye, _bath_, 
   {{0x213c97ef,0x79940810,0x2574005c,0xc8a40037}},	//   _cath_, nnzw, _pæle_, _खुँट, 
   {{0x12e40046,0x213c327f,0x7994006f,0xccf40116}},	//   _бізг, _dath_, inzw, ққй_, 
   {{0x6f6497f0,0x7994002f,0x00000000,0x00000000}},	//   рвиз, hnzw, --, --, 
   {{0x213c97f1,0x2d9497f2,0x79940810,0x7bdc0115}},	//   _fath_, ирос, knzw, ŭrul, 
   {{0x69d497f3,0x213c97f4,0x79940810,0x308801ee}},	//   _ruye, _gath_, jnzw, _ишеү_, 
   {{0x69d497f5,0xdcf800e2,0x994c00a2,0x7648010e}},	//   _suye, entē, _müń_, _šeyl, 
   {{0x69d497f6,0x6e380218,0x5c3001d5,0x291800d7}},	//   _puye, _tswb, تکهز, _scpa_, 
   {{0x7ed497f7,0x7ae897f8,0x69d4001e,0x213c01b3}},	//   _ازما, ñeta, _quye, _yath_, 
   {{0x69d406e4,0x29f000e2,0xfe701359,0xed58033a}},	//   _vuye, rņa_, _عدن_, _јок_, 
   {{0x6d400028,0x9d18008d,0xb53002d3,0x00000000}},	//   mdla, _יוסט, _ጽሑፋት, --, 
   {{0xa6e439a5,0x69d4001e,0x7994004c,0x602803b9}},	//   ржал, _tuye, anzw, _həmc, 
   {{0x44440b89,0x63782776,0xa6c801c6,0x6d4003ac}},	// [bd00] wv_, _hïng, тлаа_, odla, 
   {{0xd6240414,0x29180129,0x00000000,0x00000000}},	//   рофе_, _ucpa_, --, --, 
   {{0x444497f9,0x213c97fa,0x6d4097fb,0xaa881e24}},	//   uv_, _rath_, idla, _سنگم_, 
   {{0x444497fc,0x6d40020b,0x213c078c,0x27fc827c}},	//   rv_, hdla, _sath_, átnu_, 
   {{0x6378145e,0x16000316,0x444497fd,0x213c97fe}},	//   _lïng, _लिएर_, sv_, _path_, 
   {{0xd24c43f6,0x213c020b,0xa50897ff,0x6d4001f5}},	//   بنه_, _qath_, _шега_, jdla, 
   {{0x213c068c,0x6d409800,0x00000000,0x00000000}},	//   _vath_, ddla, --, --, 
   {{0x6d409801,0x213c004b,0xab600e51,0xfe7800fd}},	//   edla, _wath_, çüle, лүе_, 
   {{0x213c068c,0xe2a80014,0x602800ac,0x81e0009e}},	//   _tath_, _شارن_, _qəmb, _থিক_, 
   {{0x6378025a,0x5d643a61,0xe2a40321,0x213c01c3}},	//   _bïng, ртиз, íðum_, _uath_, 
   {{0xdcb800a7,0xaf3401d9,0x22440153,0x9f0405af}},	//   ъщи_, _گونژ, lvok_, _نواو, 
   {{0x6d409802,0xdb6873ea,0x291c0100,0x602806be}},	//   adla, трол_, òtan_, _təmb, 
   {{0xaf340014,0xdd9808ca,0x00000000,0x00000000}},	//   _دونژ, _ишк_, --, --, 
   {{0x7994004c,0x22440200,0x00000000,0x00000000}},	//   unzw, ivok_, --, --, 
   {{0x6378006a,0x6b940174,0x00000000,0x00000000}},	//   _gïng, óggá, --, --, 
   {{0x36d49803,0x00000000,0x00000000,0x00000000}},	//   соар, --, --, --, 
   {{0x76b89804,0x7bd804f3,0x452002f5,0x54e49805}},	// [bd10] улар_, _huvu, নজনক_, لساق, 
   {{0x7bd89806,0x7afc9807,0x39149808,0x00000000}},	//   _kuvu, last, _умор, --, 
   {{0x7bd80477,0x7afc9809,0xf8b00066,0x00000000}},	//   _juvu, oast, _رکس_, --, 
   {{0x7bd8980a,0x3254759d,0x73c40daf,0x2c0800bc}},	//   _muvu, йвер, сәге, _विसं_, 
   {{0x7bd8980b,0x6d40980c,0x7afc05ac,0x32447f21}},	//   _luvu, ydla, iast, селг, 
   {{0x7afc980d,0x3e6000b0,0xdb1c06af,0x00000000}},	//   hast, _mōtā_, _piqû, --, 
   {{0x7bd8980e,0x6d400218,0x2ef803b2,0x00000000}},	//   _nuvu, vdla, ðsfo_, --, 
   {{0xad240075,0xc898011a,0xa28000f1,0x00000000}},	//   ڭىدى, יכוז_, _ډیمو, --, 
   {{0x7afc980f,0xb2749810,0xb8c8025c,0x200c0194}},	//   dast, _улаш, _བཙ_, arfi_, 
   {{0x7bd89811,0x2eec011c,0x257408a5,0xdd380356}},	//   _buvu, sbef_, _kæla_, răşu, 
   {{0x6d409812,0xb0541f0d,0x6d4408a5,0x00000000}},	//   rdla, _دھشت, _óham, --, 
   {{0x7afc9813,0x3d1c032c,0xe45400c8,0x31649814}},	//   gast, _माथे_, צירט_, _holz_, 
   {{0x394001b9,0x4ea40798,0xfb840066,0x00000000}},	//   _bahs_, _тржа, تگوی, --, 
   {{0x7afc00af,0x602803e3,0xef240139,0x00000000}},	//   aast, _həma, _çübe_, --, 
   {{0x3d1c539d,0xec140fb4,0x7bd89815,0x22440219}},	//   _माते_, _اوعد, _guvu, zvok_, 
   {{0xea5823a4,0x31640180,0x224400d7,0x00000000}},	//   _број_, _lolz_, yvok_, --, 
   {{0xfd100150,0x67340010,0xe4d4007b,0x7bd80064}},	// [bd20] _ءجۇ_, _čajč, متاب, _zuvu, 
   {{0x2574032e,0x7bd8022e,0x602806be,0x00000000}},	//   _bæla_, _yuvu, _ləma, --, 
   {{0xd8d404ac,0x684402ac,0x2408035b,0x00000000}},	//   _לויט_, _унна, унеи_, --, 
   {{0xc3300c50,0x257408a5,0x00000000,0x00000000}},	//   بەر_, _dæla_, --, --, 
   {{0x21689816,0x31649584,0xc0e00b82,0xbb48010f}},	//   лиди_, _bolz_, _ናስር_, ינאַ_, 
   {{0x661402d1,0x257408a5,0xa5741a90,0x1f9401e0}},	//   muyk, _fæla_, _اُست, өйлө_, 
   {{0x7afc9817,0x3164030a,0x25dc01ad,0x66140438}},	//   yast, _dolz_, _कंडी_, luyk, 
   {{0x7bd89818,0x67349819,0x2d9801d3,0x602803b9}},	//   _ruvu, neyj, ésen_, _cəma, 
   {{0x7afc981a,0x7bd8981b,0x66140784,0xe298009d}},	//   vast, _suvu, nuyk, _саа_, 
   {{0x7afc981c,0x71640597,0x7bd8005b,0x0ee40037}},	//   wast, _والك, _puvu, _ट्ीस_, 
   {{0x7afc981d,0xf1b80113,0x7bd801b9,0x66140309}},	//   tast, _uqša_, _quvu, huyk, 
   {{0x7bd8981e,0xd00c4a91,0x66140bf1,0xfb8801d5}},	//   _vuvu, _سله_, kuyk, рроқ_, 
   {{0x3940045a,0x8d7002f2,0x6734981f,0x00000000}},	//   _pahs_, زایا, deyj, --, 
   {{0x7bd89820,0xc9842f8d,0x7afc9821,0x60280213}},	//   _tuvu, пуси, sast, _zəma, 
   {{0x7bd80108,0x6734032e,0x00000000,0x00000000}},	//   _uuvu, feyj, --, --, 
   {{0x628c016b,0x3e6002b5,0x7afc9822,0x673402d0}},	//   _ɛbor, _tōtā_, qast, geyj, 
   {{0x070827e3,0x25749823,0x661400e4,0x2b900118}},	// [bd30] صيلي_, _sæla_, guyk, ušce_, 
   {{0x257401a8,0xe51c1546,0x00000000,0x00000000}},	//   _pæla_, _पाणि_, --, --, 
   {{0x534401c0,0x3b080334,0x00000000,0x00000000}},	//   йхда, _kdaq_, --, --, 
   {{0xdfc42a14,0x8c1804ae,0x66149824,0x31640427}},	//   _زي_, רואי, buyk, _solz_, 
   {{0x31649825,0x16002ce6,0x38c800f2,0x0744761e}},	//   _polz_, _लिटर_, _حاکی_, _эхэм, 
   {{0x60280213,0x2574032e,0x00000000,0x00000000}},	//   _səma, _tæla_, --, --, 
   {{0x316405c7,0x802400c6,0x21a0010b,0x9fb403e3}},	//   _volz_, كريم, ьишм, bəüz_, 
   {{0x3b08045d,0x31640221,0xc0e80131,0x7ae800e8}},	//   _ndaq_, _wolz_, لفۇن_, ñetl, 
   {{0x332c9826,0x316405c7,0x51849827,0x00000000}},	//   _ibex_, _tolz_, _лужа, --, 
   {{0x6c0400f3,0x463c010f,0x80a41fd2,0x00000000}},	//   озоз, רעזע, _चुके, --, 
   {{0x60280213,0x00000000,0x00000000,0x00000000}},	//   _təma, --, --, --, 
   {{0x661402d1,0x00000000,0x00000000,0x00000000}},	//   yuyk, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc0d01e38,0x888401b9,0x60280213,0x291c9828}},	//   _ብሩህ_, зғол, _məmn, üta_, 
   {{0x332c003a,0x385402e8,0x186410ea,0xa9c000d1}},	//   _obex_, пътс, оари_, ﻣﭙﯩﻴ, 
   {{0xe9d80116,0x661402d1,0xbae00131,0x291c0327}},	//   _кки_, tuyk, _ﺋﯩﺒﺎ, żta_, 
   {{0x67349829,0xa9a40150,0x8af003b9,0x7b640114}},	// [bd40] reyj, _ومبى, _enəc, _хтје, 
   {{0xa5080212,0x66140113,0x00000000,0x00000000}},	//   режа_, ruyk, --, --, 
   {{0xe7280276,0x3d1c08e6,0x66140309,0x47d400fe}},	//   _конд_, _मासे_, suyk, ধীজী, 
   {{0x2328982a,0x661403f0,0x00000000,0x00000000}},	//   роди_, puyk, --, --, 
   {{0xe2980aa5,0xc448168d,0x661402d1,0x00000000}},	//   шад_, _گیان_, quyk, --, 
   {{0x2d98982b,0x00000000,0x00000000,0x00000000}},	//   ésel_, --, --, --, 
   {{0x657c0491,0xc4480424,0x00000000,0x00000000}},	//   mhph, _دیان_, --, --, 
   {{0x644c982c,0x66040083,0x3d1c01ad,0x9e0400db}},	//   _irbi, _kvkk, _माहे_, очол, 
   {{0xdd98982d,0x657c02d0,0xc5e80154,0x00000000}},	//   ишо_, ohph, _পিঁপ, --, 
   {{0x657c01fb,0x00000000,0x00000000,0x00000000}},	//   nhph, --, --, --, 
   {{0x2d8c02d3,0x62800036,0x00000000,0x00000000}},	//   _ንእሽቶ_, lzoo, --, --, 
   {{0x9e6479d1,0xdec84a0b,0x644c0051,0x00000000}},	//   _واشن, _кулл_, _mrbi, --, 
   {{0x62801ce9,0x4ea00153,0x09e40006,0x539800d9}},	//   nzoo, _орша, моўн, שיכו, 
   {{0x62800099,0x644c982e,0x3b080477,0x64580241}},	//   izoo, _orbi, _wdaq_, _àtiw, 
   {{0xb4b8982f,0x8d7002f2,0xb8e400cf,0x9f480241}},	//   _चरे_, _زاوا, _ۉزدۉ, _ìbó_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x25740381,0x64480008,0x00000000,0x00000000}},	// [bd50] _cælo_, æfin, --, --, 
   {{0x644c9830,0x7d1c00a3,0x6280007c,0x00000000}},	//   _brbi, òrsh, dzoo, --, 
   {{0x80d004c5,0x3cfc017a,0x62800083,0x9178004d}},	//   সুত্, _mevv_, ezoo, hệ_, 
   {{0x332c00d8,0xca489831,0x43940408,0x00000000}},	//   _qbex_, _الیه_, махс, --, 
   {{0x644c9832,0x41e49833,0x62809834,0xdb200428}},	//   _erbi, وسوف, gzoo, ùrùg, 
   {{0x216400c2,0x657c9835,0xc2440953,0x75a400c7}},	//   зиши_, chph, ьнік, _хымҧ, 
   {{0x2d9801ed,0x9420075e,0x00000000,0x00000000}},	//   ésem_, _توزۇ, --, --, 
   {{0x628001bf,0x00000000,0x00000000,0x00000000}},	//   bzoo, --, --, --, 
   {{0x2d8800ee,0x602803b9,0x59a82ca5,0xb274030d}},	//   ййип_, _həml, चकार, _элаш, 
   {{0xac849836,0x00000000,0x00000000,0x00000000}},	//   згол, --, --, --, 
   {{0x3d1c1533,0x99840790,0x9c206135,0x00000000}},	//   _मारे_, _şişe_, ндэд, --, 
   {{0xeb989837,0x602803e3,0x7c940022,0x7f58014b}},	//   сим_, _məml, ьрыц, _махс_, 
   {{0x80d00eac,0x00000000,0x00000000,0x00000000}},	//   _স্প্, --, --, --, 
   {{0x9ce400e5,0x9f480ca8,0xbb2400d1,0x00000000}},	//   _ٹوٹے_, _ìbò_, ﻼﻧﻰ_, --, 
   {{0x602803e3,0x50c8043e,0x00000000,0x00000000}},	//   _nəml, ाधिष, --, --, 
   {{0xab6400d6,0x6280208d,0xb75802bf,0xbbe800f2}},	//   _хвил, yzoo, ошує_, _بروم_, 
   {{0x644c56c0,0xdce8002d,0x657c9838,0xe5780a42}},	// [bd60] _srbi, _alfę, thph, бза_, 
   {{0x628001d4,0x644c0010,0x64a49839,0x15400395}},	//   vzoo, _prbi, паза, неум, 
   {{0x6378067c,0x60280213,0x66e401f0,0x68441513}},	//   _aïna, _cəml, _нона, _энна, 
   {{0x93c81973,0xe3b0983a,0x68fc0209,0x62800d27}},	//   مانہ_, ررا_, _hepd, tzoo, 
   {{0x7688022e,0x3d1c5219,0x68fc010e,0x657c035a}},	//   _jоyl, _माले_, _kepd, phph, 
   {{0x27f801a4,0x1eb400f7,0x644c0427,0x64480158}},	//   _kwpn_, үккө_, _trbi, åfis, 
   {{0x644c983b,0x628001d4,0x27f805b1,0xe3640fcb}},	//   _urbi, szoo, _jwpn_, _екви, 
   {{0x628001f5,0x00000000,0x00000000,0x00000000}},	//   pzoo, --, --, --, 
   {{0xdda8009d,0x00000000,0x00000000,0x00000000}},	//   йтол_, --, --, --, 
   {{0x61e001e2,0x68fc00a2,0x602803e3,0x3d8800f2}},	//   mqol, _nepd, _həmm, تحبی_, 
   {{0x7124036b,0x61e00009,0xa92400de,0x00000000}},	//   _ترقل, lqol, _mežā, --, 
   {{0x257401a8,0xd90c00f2,0x00000000,0x00000000}},	//   _sæll_, گید_, --, --, 
   {{0x602803be,0x68fc0477,0x61e0983c,0xad640451}},	//   _məmm, _bepd, nqol, _ڪانه, 
   {{0xd90c6aa5,0x68fc983d,0x00000000,0x00000000}},	//   دید_, _cepd, --, --, 
   {{0x68fc983e,0xad647ae8,0x00000000,0x00000000}},	//   _depd, _تانه, --, --, 
   {{0x61e0011f,0x68fc0857,0x00000000,0x00000000}},	//   kqol, _eepd, --, --, 
   {{0x80d0009e,0xb8e400db,0xe7780022,0x00000000}},	// [bd70] _স্ম্, _ۉزگۉ, цатә_, --, 
   {{0x68fc010e,0x7c28017a,0x00000000,0x00000000}},	//   _gepd, otdr, --, --, 
   {{0xf8c00bc0,0x602803e3,0x00000000,0x00000000}},	//   _एरिय, _qəml, --, --, 
   {{0x68fc0472,0x7c280b4f,0x33740024,0x04c800ae}},	//   _zepd, itdr, ьгер, سوني_, 
   {{0x2d98066d,0x68fc0b6f,0x61e0379d,0x7c2802d0}},	//   ések_, _yepd, gqol, htdr, 
   {{0x764c983f,0x7c28007c,0xc23800cf,0x00000000}},	//   mvay, ktdr, سقىچ_, --, 
   {{0x17280867,0x764c9840,0xa06402e8,0xddc00171}},	//   _སྡོམ_, lvay, даща_, _kroņ, 
   {{0x64580e04,0xd244010b,0x08580375,0x61e0022e}},	//   _štig, _нэзи, לבום_, bqol, 
   {{0x69d80115,0xb500000d,0x00000000,0x00000000}},	//   ĉtek, _लजाय_, --, --, 
   {{0x7c289841,0xb608005f,0xebe403f6,0x00000000}},	//   ftdr, _izšķ, мооп, --, 
   {{0xd7bc0574,0x645806af,0x68fc0356,0xc104724c}},	//   ्षाच, _àtit, _repd, _سوني, 
   {{0x6b549842,0x68fc9843,0x8af006be,0xc0d00023}},	//   фтох, _sepd, _enən, _ብኩሉ_, 
   {{0x1728031c,0x68fc0477,0x6e443169,0xe51c5b82}},	//   _སྡེམ_, _pepd, _целз, _पालि_, 
   {{0x9e941e87,0x764c0882,0xed58084c,0x6e284ff4}},	//   _تامچ, dvay, _фок_, mteb, 
   {{0x66e49844,0xddc000ef,0x00000000,0x00000000}},	//   доба, _broņ, --, --, 
   {{0x635c0276,0xdb1c004e,0x68fc014f,0x1bf80375}},	//   _mănâ, _xiqü, _wepd, _ולקב, 
   {{0xb8d49845,0x6e289846,0x68fc31c5,0x764c1eca}},	// [bd80] _छु_, nteb, _tepd, gvay, 
   {{0xf1e02aa1,0x6e289847,0xc0d01954,0x00000000}},	//   _पढ़न, iteb, ብርህ_, --, 
   {{0x6e2801c7,0x649800fb,0x00000000,0x00000000}},	//   hteb, цтар_, --, --, 
   {{0x6e289848,0x00000000,0x00000000,0x00000000}},	//   kteb, --, --, --, 
   {{0x91e09849,0x6e2825a6,0x7ae8984a,0xf644030d}},	//   воче, jteb, ñeti, _пхён, 
   {{0xc1a80574,0x2574037e,0x6614984b,0x26c001c4}},	//   गवेग, _mælk_, mryk, _izko_, 
   {{0x6e28984c,0x66140af9,0x61e0022e,0x403400c0}},	//   eteb, lryk, sqol, хейс, 
   {{0x602800ac,0x61e0022e,0x2b180037,0x00000000}},	//   _həmk, pqol, _भागु_, --, 
   {{0xc68c0020,0x6614984d,0x6e28984e,0x61e00ba7}},	//   _መመሪያ_, nryk, gteb, qqol, 
   {{0x236405ce,0x3eb8005f,0xdb0c00d8,0x7c285794}},	//   ljoj_, ārt_, cocê, ttdr, 
   {{0x6e28002d,0xe06800c6,0x764c006f,0x3c580276}},	//   ateb, _بإذن_, zvay, чинэ_, 
   {{0x26c00427,0x66140108,0x00000000,0x00000000}},	//   _ozko_, kryk, --, --, 
   {{0x4f8401d9,0xb06000c5,0x6e28984f,0x25dc00ab}},	//   _تالہ, _äärd, cteb, _कूली_, 
   {{0x66149850,0x23640455,0xea6000e5,0x81e000cc}},	//   dryk, hjoj_, اھٹی, _দবা_, 
   {{0x80d009bd,0x5ba4523a,0x1728031c,0x2d980134}},	//   _স্ত্, _ориз, _སྡུམ_, ɑse_, 
   {{0xf8b001d9,0xa26400d7,0x661460e2,0x00000000}},	//   َکھ_, _zmôž, fryk, --, 
   {{0x98bc03be,0x9c1001f2,0x23649851,0xc6e402dd}},	// [bd90] ırıb_, _tọsd, djoj_, тісп, 
   {{0xd5b83334,0x764c00dc,0x23640115,0x602806be}},	//   іса_, rvay, ejoj_, _cəmk, 
   {{0x79949852,0x6e289853,0x26c0005a,0xa2c00032}},	//   mizw, zteb, _ezko_, ғәтк, 
   {{0x79949854,0x23640023,0x6e2808fb,0x66149855}},	//   lizw, gjoj_, yteb, bryk, 
   {{0x6fc400eb,0x8574074d,0x0cb89856,0x00000000}},	//   nóce, алăх, _उर्म, --, 
   {{0x79949857,0xf1f401c0,0x645800d0,0x6b54013d}},	//   nizw, _үзвэ, _štie, _kügä, 
   {{0x25a48a7c,0x673402bf,0xf1e0000d,0x00000000}},	//   éole_, _ågjø, _पढवन, --, 
   {{0x79940230,0x03c40022,0x4e1000bc,0x00000000}},	//   hizw, _асум, _दिदै_, --, 
   {{0x79949858,0x6e28010a,0x32540139,0x645801e1}},	//   kizw, uteb, _явар, _àtir, 
   {{0xdcf800e2,0xed446a7a,0x02640133,0xe8dc4709}},	//   ditē, хноп, _جێهێ, _मलेच, 
   {{0x6e28193f,0x7994009a,0x00000000,0x00000000}},	//   steb, dizw, --, --, 
   {{0x6a84008e,0xdb0c00db,0x4f6400db,0x6e289859}},	//   елма, nocè, _تائف, pteb, 
   {{0x0db8044e,0x2fcc6115,0xba180055,0x00000000}},	//   _ደገፍ_, mmeg_, _ũårā, --, 
   {{0x7994985a,0x2fcc0165,0xc0d00023,0x9d4001a9}},	//   gizw, lmeg_, ብርሉ_, _бешд, 
   {{0x7c64985b,0x18a0985c,0x98a0013e,0x5d78010f}},	//   _لايل, гарм, гире, _מאסק, 
   {{0x66142759,0x321c010e,0xdcf800de,0xdc3400df}},	//   tryk, kuwy_, bitē, _נאפט_, 
   {{0xe618985d,0x79940944,0x7dec00c8,0x65c40261}},	// [bda0] яда_, bizw, ַקאַ, ебаа, 
   {{0x6614985e,0x7994014b,0x257408a5,0x5ac400b1}},	//   rryk, cizw, _kæli_, _ялым_, 
   {{0x2fcc0369,0x69cc985f,0x6614017a,0xd6cc01d3}},	//   kmeg_, mmbe, sryk, لقہ_, 
   {{0x25740008,0xdb0c020c,0x66149860,0x69cc9861}},	//   _mæli_, gocè, pryk, lmbe, 
   {{0x69cc9862,0x602803e3,0x00000000,0x00000000}},	//   ombe, _təmk, --, --, 
   {{0x60280cc1,0x69cc9863,0x2fcc030a,0x994c0205}},	//   _həmi, nmbe, emeg_, _müş_, 
   {{0x69cc9864,0x64a42312,0x602803e3,0x638428f6}},	//   imbe, _чава, _kəmi, _згва, 
   {{0x79949865,0x69cc9866,0x656c9867,0x2fcc0369}},	//   zizw, hmbe, _hobh, gmeg_, 
   {{0x79949868,0x656c9869,0x4438022f,0x69cc02d1}},	//   yizw, _kobh, _hpr_, kmbe, 
   {{0x44380490,0x656c0433,0x69cc986a,0x257402d2}},	//   _kpr_, _jobh, jmbe, _bæli_, 
   {{0x25740381,0xbfa80276,0x672402d0,0x69cc01ab}},	//   _cæli_, _оӂие_, _ockj, dmbe, 
   {{0x69cc986b,0x1e843eae,0x656c986c,0x443825a9}},	//   embe, _плем, _lobh, _mpr_, 
   {{0xdb0c986d,0xcb0805f5,0x799457fc,0x656c0472}},	//   nocé, эхэд_, tizw, _oobh, 
   {{0x67240857,0x656c986e,0x69cc003e,0x994c5397}},	//   _ackj, _nobh, gmbe, _düş_, 
   {{0x7994986f,0x25740fac,0xd8740271,0xb78c0023}},	//   rizw, _gæli_, راسب, _መለክዒ_, 
   {{0x79949870,0x60280cc1,0x656c0e89,0x69cc9871}},	//   sizw, _cəmi, _aobh, ambe, 
   {{0x7aec9872,0x44389873,0x656c9874,0x36d40262}},	// [bdb0] _ifat, _apr_, _bobh, тоар, 
   {{0x44380a2e,0x656c9875,0x6b540724,0x79940107}},	//   _bpr_, _cobh, _tügä, qizw, 
   {{0x656c9876,0xdb0c067c,0x4438045a,0x9264552d}},	//   _dobh, tocè, _cpr_, کدام, 
   {{0x44389877,0x656c9878,0xb2d40131,0x602800ac}},	//   _dpr_, _eobh, نياغ, _gəmi, 
   {{0x7aec9879,0x656c01e7,0x4438045a,0x49b84c9a}},	//   _mfat, _fobh, _epr_, _زاید_, 
   {{0x44384c99,0x3d1c205d,0x7c3827bb,0x656c987a}},	//   _fpr_, _मागे_, _opvr, _gobh, 
   {{0x4438987b,0x2fcc0072,0x7aec987c,0xa1540640}},	//   _gpr_, tmeg_, _ofat, тају_, 
   {{0x7aec0223,0x656c987d,0x69cc0399,0xd344315b}},	//   _nfat, _zobh, zmbe, _سیته_, 
   {{0x45440020,0x656c004b,0xdb0c987e,0x066c0023}},	//   _የማኅበ, _yobh, cocé, _ተራኺቡ_, 
   {{0x6458987f,0x2fcc1e9b,0xd7740020,0x6224030c}},	//   _átic, smeg_, _የገበያ_, _جوكە, 
   {{0x0fcc1682,0x705004d3,0xc5e804c5,0x44380175}},	//   _ṱhuṱ, _ڕۆژا, _পিছপ, _xpr_, 
   {{0x1ee8404a,0xddc0448b,0x7ff400c6,0x09bc9880}},	//   _قومی_, _kroś, _إسلا, ोग्य, 
   {{0x7aec00d8,0x3e840374,0x602806be,0x00000000}},	//   _dfat, tūtū_, _rəmi, --, 
   {{0x7aec9881,0x69cc9882,0xbbe813f9,0x602800ac}},	//   _efat, umbe, بریم_, _səmi, 
   {{0xbbe80597,0x7aec0368,0x656c9883,0x2d849884}},	//   _كريم_, _ffat, _robh, mhle_, 
   {{0x656c9885,0x44389886,0x6d200c2e,0x602803b9}},	//   _sobh, _rpr_, _माँग_, _qəmi, 
   {{0x44389887,0xa5246590,0x69cc009a,0x442c0165}},	// [bdc0] _spr_, кмад, pmbe, _ūd_, 
   {{0x2d849888,0x44389889,0xe4d40a2c,0x362401d9}},	//   nhle_, _ppr_, نتاب, اوٕہ, 
   {{0x602800ac,0x15401422,0x656c0055,0xbdb40220}},	//   _təmi, рехм, _vobh, _ﺴﺒﻴل_, 
   {{0x656c004b,0x66e4988a,0x44380010,0xe298988b}},	//   _wobh, _шома, _vpr_, мае_, 
   {{0x6d2009d9,0x2d84012c,0x656c988c,0xa1883da1}},	//   _मांग_, khle_, _tobh, мбда_, 
   {{0xe4c46240,0xe5a400d8,0x00000000,0x00000000}},	//   _айги, _риги, --, --, 
   {{0xdef81982,0xb4c40184,0x3f8406a3,0x23d40124}},	//   мып_, _бирҙ, thmu_, _ацар, 
   {{0x2d84009a,0x27fc0030,0x00000000,0x00000000}},	//   ehle_, átny_, --, --, 
   {{0x63a0988d,0x4444988e,0x81c40124,0x8ed411e6}},	//   mnon, lw_, _бааҧ, پذير_, 
   {{0x4444988f,0x7aec9890,0xfcc49891,0x2d8401ab}},	//   ow_, _sfat, ләйм, ghle_, 
   {{0x63a09892,0x44449893,0x60640849,0x7aec0139}},	//   onon, nw_, _جهال, _pfat, 
   {{0x44449894,0x2d8400d0,0x9e645868,0x00000000}},	//   iw_, ahle_, _لاتن, --, 
   {{0x7f400393,0x2d8401c3,0x63a09895,0x6f1c0784}},	//   memq, bhle_, inon, ósce, 
   {{0x2d84031d,0x44449896,0x7f4016b8,0x4bc428fc}},	//   chle_, kw_, lemq, лөөг, 
   {{0x63a09897,0x6fc425e6,0x44440113,0x7c38005a}},	//   knon, lóca, jw_, _upvr, 
   {{0x7aec9898,0x7d089899,0x7f401730,0x44440368}},	//   _ufat, lads, nemq, dw_, 
   {{0x4444989a,0x63a0989b,0x8704005b,0x9a840166}},	// [bdd0] ew_, dnon, рясе, _шукл, 
   {{0x7d08989c,0x63a027be,0x04f429e4,0x64580030}},	//   nads, enon, изую, _štia, 
   {{0x44442e87,0xf3f80395,0xf7940153,0x00000000}},	//   gw_, хнеш_, _банэ, --, 
   {{0x63a0989d,0x3d1c05ba,0x7d08989e,0xddc00034}},	//   gnon, _माझे_, hads, _proś, 
   {{0x7f401730,0x602800ac,0xd17001e0,0x4444061d}},	//   demq, _məmu, ғыҙы, aw_, 
   {{0x63a0989f,0xdca400c6,0x44440a49,0xdcf800c0}},	//   anon, _هى_, bw_, mitė, 
   {{0x7d0801e4,0x534498a0,0x00000000,0x00000000}},	//   dads, _ихаа, --, --, 
   {{0x320c0579,0x3ea08841,0x63a00066,0x7f400381}},	//   _tvey_, _žita_, cnon, gemq, 
   {{0xd200113e,0xaf340150,0x2d8498a1,0x2d9400cf}},	//   _түлк, _ەرتت, thle_, лөкө_, 
   {{0xfe743955,0x14b401f9,0x1fb400db,0x00000000}},	//   рүш_, _अडाण, ксөр, --, 
   {{0xab281032,0x7f4098a2,0xf1d401ec,0xd6740150}},	//   нона_, bemq, _ﺟﻮﻳﻘ, _ﺼﻐﻴﺭ_, 
   {{0xdcf80006,0x2d848ff6,0x94f0025c,0x7f4016b8}},	//   kitė, shle_, _བཅའི_, cemq, 
   {{0x7d081893,0x44440472,0x2d9801d3,0x9fa001e1}},	//   bads, zw_, éses_, _míìn_, 
   {{0x7d082453,0x63a00369,0x444403cb,0x6f08002f}},	//   cads, znon, yw_, laec, 
   {{0xe73898a3,0x257405f7,0xeb9898a4,0x63a098a5}},	//   нев_, _mælt_, _пик_, ynon, 
   {{0x6f0898a6,0x2b8000e4,0xa8840202,0x1cb80375}},	//   naec, _fóca_, _ەلدى, _אמצע, 
   {{0x444498a7,0xe5e406f6,0x63a0004d,0x4560001f}},	// [bde0] ww_, اثري, vnon, _ለማክበ, 
   {{0x6d4098a8,0x499403e6,0xa3e80cc9,0x257402d2}},	//   nela, _ئیسر, еджа_, _nælt_, 
   {{0x444498a9,0x290898aa,0x69dc98ab,0xb924063f}},	//   uw_, maba_, _iipe, _lepụ_, 
   {{0x6d4098ac,0x444498ad,0x63a098ae,0x46440014}},	//   hela, rw_, unon, _پھرِ, 
   {{0x69dc98af,0x444498b0,0x257498b1,0x7f4098b2}},	//   _kipe, sw_, _bælt_, vemq, 
   {{0x290898b3,0x63a098b4,0x69dc98b5,0xddc0008f}},	//   naba_, snon, _jipe, _broŝ, 
   {{0x6d4098b6,0x69dc98b7,0x63a00b21,0x44448c41}},	//   dela, _mipe, pnon, qw_, 
   {{0x290898b8,0x69dc98b9,0xddc001e4,0x6f080077}},	//   haba_, _lipe, _droŝ, gaec, 
   {{0x29083dd4,0x6d4098ba,0x7f4098bb,0x7d084cab}},	//   kaba_, fela, remq, tads, 
   {{0x7f4098bc,0x290898bd,0x3d9498be,0x6b9498bf}},	//   semq, jaba_, риор, _amyg, 
   {{0x290898c0,0xddc000df,0x7f400393,0x00000000}},	//   daba_, _groŝ, pemq, --, 
   {{0x7d080640,0xdee498c1,0x69dc98c2,0x6d4000fb}},	//   sads, _соди, _aipe, aela, 
   {{0x22441509,0x4f840014,0x29080109,0x7d0898c3}},	//   nwok_, _حالہ, faba_, pads, 
   {{0x69dc04b9,0x9fa002d2,0x00000000,0x00000000}},	//   _cipe, _míín_, --, --, 
   {{0xdb0c3822,0x6458107d,0x4d78008f,0xb8fc4ead}},	//   locí, _štin, _ארגע, _तः_, 
   {{0x4c101a73,0x602800ac,0x69dc007b,0x68ec00a3}},	//   _ابوس, _həms, _eipe, acbd, 
   {{0xdb0c98c4,0x69dc03d1,0x7bcc009d,0xb6c498c5}},	// [bdf0] nocí, _fipe, _ihau, рөнд, 
   {{0x29082cd7,0x7afc98c6,0x22441028,0xd6f800b5}},	//   caba_, lbst, dwok_, _cmを_, 
   {{0x7bcc98c7,0xf8b806ab,0x7afc002f,0x00000000}},	//   _khau, _इडिय, obst, --, 
   {{0x6d4098c8,0x69dc98c9,0x6ff000de,0x2574032e}},	//   zela, _zipe, _jāce, _sælt_, 
   {{0x6d4098ca,0xc8c80014,0xf0e81c02,0xd598037e}},	//   yela, _لوین_, نىشى_, _jpに_, 
   {{0x6d4098cb,0x69dc02b9,0x6ff00171,0x0584010a}},	//   xela, _xipe, _lāce, _лусм, 
   {{0x7bcc02b5,0x92600014,0xe0cc0014,0x6f08015d}},	//   _ohau, _گۯشم, ٘ٲو_, taec, 
   {{0xee3898cc,0x6d4098cd,0x290898ce,0x7bcc98cf}},	//   вни_, wela, zaba_, _nhau, 
   {{0x6d4098d0,0x6f080393,0xdb0c0077,0x01640014}},	//   tela, raec, gocí, _گُلَ, 
   {{0x290898d1,0x6b9498d2,0xddc001e4,0x7afc0e78}},	//   xaba_, _smyg, _troŝ, ebst, 
   {{0x69dc98d3,0x290898d4,0xb92402e3,0x7bcc00dc}},	//   _ripe, vaba_, _wepụ_, _bhau, 
   {{0x69dc98d5,0x7bcc98d6,0xeb9898d7,0x29081629}},	//   _sipe, _chau, тим_, waba_, 
   {{0x69dc98d8,0x7bcc98d9,0x776c01a9,0xae040116}},	//   _pipe, _dhau, djax, _ئوتى, 
   {{0x69dc0140,0xff5003e6,0x321c030a,0x7bcc98da}},	//   _qipe, _وخۆ_, irwy_, _ehau, 
   {{0x279498db,0xe7b4036b,0x7db441ff,0x7afc3bdc}},	//   ашар, لمسد, _اصنا, bbst, 
   {{0x29083dd4,0x7bcc0363,0x69dc98dc,0x377401e0}},	//   saba_, _ghau, _wipe, быус, 
   {{0xaa447724,0x290898dd,0xfb240046,0x25a40077}},	// [be00] _тепл, paba_, _ارىپ, éolo_, 
   {{0x290898de,0x69dc98df,0x321c015d,0x24f4030d}},	//   qaba_, _uipe, drwy_, рчар, 
   {{0xf980024c,0xa7a80354,0x6ff000b8,0x00000000}},	//   _эҳро, _акна_, _yāce, --, 
   {{0x22441028,0x5c34008f,0x321c0042,0xd4640063}},	//   twok_, ירען_, frwy_, јице_, 
   {{0x425400c6,0x9b14010f,0x216898e0,0x00000000}},	//   إنتر, בֿוד_, киди_, --, 
   {{0xdb0c0077,0xd1c40484,0x00000000,0x00000000}},	//   vocí, алче_, --, --, 
   {{0xd4646b58,0x106800d1,0xe3b80a0e,0x00000000}},	//   _кире_, _ﻳﯧﺮﯨ, _абв_, --, 
   {{0xddc09009,0x2d980036,0x5f7498e1,0x8ff406c2}},	//   _broş, èsen_, شاعر, جرور_, 
   {{0x7bcc01d4,0x425400f1,0x6ff000ef,0x6f1c01e7}},	//   _rhau, _دچار, _rāce, ósca, 
   {{0xd24c1f6d,0x93c40311,0xdcf81c52,0x00000000}},	//   _زنم_, rlăţ, mitī, --, 
   {{0xfe18098b,0x7bcc0070,0xdb0c054e,0x9f4c01e7}},	//   _दिवस_, _phau, vocâ, apfá_, 
   {{0x7bcc01d4,0xc978001f,0xdb0c02f0,0x25a800ef}},	//   _qhau, _ያለፈው_, pocí, _ljbl_, 
   {{0x798401d4,0x602803be,0x7afc98e2,0x6ee4036b}},	//   _plhw, _təms, rbst, _اسمل, 
   {{0x7bcc4f7f,0xc9840d1d,0x00000000,0x00000000}},	//   _whau, оуси, --, --, 
   {{0xbb58152d,0x7bcc0b89,0x324c0092,0x00000000}},	//   _байх_, _thau, _በውስጣ, --, 
   {{0x7bcc98e3,0x386c56af,0x99480139,0x00000000}},	//   _uhau, ćer_, bışu_, --, 
   {{0x79845bae,0x63e40075,0x00000000,0x00000000}},	// [be10] _tlhw, ەيمە, --, --, 
   {{0x69f00323,0x398c0241,0x00000000,0x00000000}},	//   _хүрт, _dósù_, --, --, 
   {{0x743498e4,0x7a3c0267,0x534401c6,0x645898e5}},	//   снеф, _fåtö, ихда, _átil, 
   {{0x97801550,0x6cd8008f,0x37c00183,0x00000000}},	//   _بیره, אַנצ, _শংকৰ, --, 
   {{0x92680801,0x38c802f2,0x00000000,0x00000000}},	//   ържа_, _جاکی_, --, --, 
   {{0x63a0003e,0x6ff00055,0x80f80395,0x0244009f}},	//   ōonp, _nācc, ахът_, تَهَ, 
   {{0x02a40598,0x1b1c015b,0x602806be,0xa110007b}},	//   йрәм, য্যে_, _səmr, سويت, 
   {{0xddc098e6,0x201800d0,0x6fc4012d,0x00000000}},	//   _proş, ápia_, róco, --, 
   {{0x332c04d4,0x518447c5,0xcdcc00f1,0x64480327}},	//   _icex_, _кужа, وښت_, ħfie, 
   {{0x417414ef,0x6ff00a88,0xaa8000a2,0x00000000}},	//   _والس, _cācc, _žýon, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x602806be,0x7094014b,0xbdc8009d,0x00000000}},	//   _təmr, _каҷф, лгөж_, --, 
   {{0x8d7416e6,0x00000000,0x00000000,0x00000000}},	//   _پاشا, --, --, --, 
   {{0x64580d0f,0x00000000,0x00000000,0x00000000}},	//   _štim, --, --, --, 
   {{0xdca01d83,0xdcf800da,0xdb0c004e,0x7cc402dd}},	//   _наши, zitī, bocà, _وزىم, 
   {{0xdb0c00d8,0x98a00354,0x00000000,0x00000000}},	//   rocã, чисе, --, --, 
   {{0xefe002d3,0xa6c801c6,0xf1b800cd,0x00000000}},	// [be20] _ናብዚ_, улаа_, ेतान, --, 
   {{0xe9440efc,0xa9240798,0x00000000,0x00000000}},	//   _اندپ, _удол, --, --, 
   {{0xdb0c98e7,0x6d8c00a2,0x16141066,0xe35401c6}},	//   locá, _aºak, لسەڭ, йтдэ, 
   {{0x228400db,0x00000000,0x00000000,0x00000000}},	//   йулг, --, --, --, 
   {{0x9340234c,0xdb0c0332,0x52700114,0x00000000}},	//   янце, nocá, зују, --, 
   {{0x2d9800db,0xefe00023,0x00000000,0x00000000}},	//   èsel_, _ናብዛ_, --, --, 
   {{0xa878008f,0x8454075e,0xdde802f2,0x7170568c}},	//   טאַר, _بىزچ, گربه_, بۇلا, 
   {{0x644c98e8,0xd598037e,0xdcf81d76,0xbdf4399f}},	//   _isbi, _jpの_, pitī, опиј, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x644c01fa,0x5d640063,0x25b80165,0x27e0007c}},	//   _ksbi, стиз, nopl_, _likn_, 
   {{0x228400d1,0xdb0c004e,0x9f042824,0x00000000}},	//   _туңг, tocà, _هواو, --, 
   {{0xe6300023,0xe7b800eb,0x291c1427,0x00000000}},	//   _ኣጋንን, ংগুয, ótan_, --, 
   {{0x26c01730,0xd9181b04,0x6ff00055,0x6e000116}},	//   _nyko_, льв_, _tācc, _قېين, 
   {{0x644c0b4b,0x44c801e1,0x00000000,0x00000000}},	//   _osbi, _o̟_, --, --, 
   {{0x644c05be,0x6ff000b8,0x0d500133,0xc86400db}},	//   _nsbi, _kāca, _رخود, птти, 
   {{0x27e003f9,0x26c008a5,0x645801e1,0xdb0c0108}},	//   _cikn_, _byko_, _àtiy, äjäv, 
   {{0xdb0c0077,0x25b803d1,0x644c017a,0xf59802e8}},	// [be30] cocá, fopl_, _asbi, аващ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x644c0109,0xf8dc01ad,0xc9f400f2,0x00000000}},	//   _csbi, _मणिय, _وسیع, --, 
   {{0xb7d800d1,0x6ff0002b,0x437400db,0xb78801af}},	//   _خوجا_, _nāca, зушт, _тәге_, 
   {{0x66040083,0x44c80241,0xa354004b,0x201803b2}},	//   _gwkk, _e̟_, ترلږ, ápin_, 
   {{0x644c01fa,0x6ff45a6f,0x7d1c0d12,0x00000000}},	//   _fsbi, очих, órsl, --, 
   {{0xfbc8085c,0x83f801a9,0x00000000,0x00000000}},	//   रताम, _гесс_, --, --, 
   {{0x7d18030d,0xdfcc05d9,0x6ff0002b,0xd2d4074d}},	//   _advs, نڊن_, _cāca, _дiая, 
   {{0xd598019b,0x2d8864b6,0x0be00150,0x72a402f2}},	//   _jpは_, ийип_, _ﺍﻟﺘﺫ, _بڕان, 
   {{0xdb0c003a,0x644c0042,0x00000000,0x00000000}},	//   vocá, _ysbi, --, --, 
   {{0x2ef498e9,0xd0a801af,0xa5d8010f,0x00000000}},	//   _дзер, _стад_, יַטי, --, 
   {{0xdb0c021c,0x765c010b,0xe454010f,0x7e6401ef}},	//   tocá, _orsy, קירט_, _šipe, 
   {{0xb88c001f,0x4ea4010b,0x7c2401ab,0x00000000}},	//   ዘጋጀው_, _уржа, _āire, --, 
   {{0x80d000bd,0xdb0c09c2,0xa88898ea,0xedf400f2}},	//   _স্ট্, rocá, айга_, _هيچگ, 
   {{0x765c044e,0x6c7401a9,0x6ff000cd,0x6e3c025c}},	//   _arsy, _фулх, _yāca, ħsbu, 
   {{0x8af006be,0x26c00153,0x00000000,0x00000000}},	//   _enər, _pyko_, --, --, 
   {{0x7f440986,0xd6f8037e,0x00000000,0x00000000}},	// [be40] _ñiqe, _kmオ_, --, --, 
   {{0x644c05be,0x26c00006,0x64580162,0x00000000}},	//   _psbi, _vyko_, _átik, --, 
   {{0xe73802de,0x765c0363,0xd6f8037e,0xf65001ed}},	//   _кен_, _ersy, _mmオ_, وئے_, 
   {{0x26c03f05,0xa63c0023,0x00000000,0x00000000}},	//   _tyko_, ይተወሰ, --, --, 
   {{0x6ff00055,0x51f00244,0x00000000,0x00000000}},	//   _rāca, وسور, --, --, 
   {{0x20180120,0x6f180129,0x6fc40332,0x6ff00055}},	//   ápio_, _adwc, lóch, _sāca, 
   {{0x644c0784,0xf1a898eb,0x6ff0002b,0xdea00014}},	//   _usbi, حانه_, _pāca, ڈیای, 
   {{0x93f80bd4,0xdfd800a7,0xd18000d1,0x6fc401e7}},	//   _כללי, шъл_, зләй, nóch, 
   {{0xe2980cfc,0x4fb06e9a,0x7d180407,0x6ff00882}},	//   _таа_, بصور, _pdvs, _vāca, 
   {{0xd6f8037e,0x00000000,0x00000000,0x00000000}},	//   _cmオ_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x291800ca,0x92bc00fe,0x00000000,0x00000000}},	//   _adpa_, ুখৰ_, --, --, 
   {{0xed8898ec,0x8ae402dd,0xb5f001e1,0x6fc400ae}},	//   рсөк_, дірл, _osúọ, dóch, 
   {{0x27f80a2e,0x28b47dad,0x8d601d0f,0x00000000}},	//   _btpn_, _आँखि, _овче, --, 
   {{0x6d8c02d2,0xa3a80073,0x00000000,0x00000000}},	//   _dúad, गचा_, --, --, 
   {{0x765c089c,0x7c2898ed,0x2b80002d,0x2a640219}},	//   _prsy, mudr, _nóch_, _šobe_, 
   {{0x24680201,0x3f840073,0x7c2898ee,0x33540372}},	// [be50] _ተቋማት_, ikmu_, ludr, үүгө_, 
   {{0x38341789,0x45d498ef,0x00000000,0x00000000}},	//   _енор, доус, --, --, 
   {{0x20180306,0x3f84031c,0x00000000,0x00000000}},	//   ápil_, kkmu_, --, --, 
   {{0xdfc498f0,0x97a498f1,0xd6f804ce,0xe8d404ae}},	//   _سي_, _фрол, _mmカ_, _מותר_, 
   {{0x291805b1,0x020402d5,0x201816a3,0x765c98f2}},	//   _ydpa_, дзін, špil_, _ursy, 
   {{0x764c98f3,0x7c2823e0,0x82346f04,0x6fc45923}},	//   mway, kudr, ظرنا, móci, 
   {{0x764c98f4,0xd3a40262,0x7c280064,0x00000000}},	//   lway, _драп, judr, --, 
   {{0x7e0001f2,0x764c058a,0x3494024c,0x00000000}},	//   _ịsac, oway, _даҳр, --, 
   {{0x764c98f5,0xada498f6,0xdfcc004b,0x4560001f}},	//   nway, запл, ديي_, _ለማኅበ, 
   {{0x764c0198,0xd1b825ba,0x7e640331,0x62240c75}},	//   iway, _ئارا_, _šipc, _رومە, 
   {{0xed5802f4,0x7c2898f7,0xc09400cf,0x00000000}},	//   _ҳол_, gudr, _ۉجۅت, --, 
   {{0x09b40d2c,0xe7f00073,0x00000000,0x00000000}},	//   ंक्य, _आंबा_, --, --, 
   {{0xed5898f8,0x764c98f9,0xc0ec001f,0x7c280064}},	//   _гол_, jway, ጀመሩ_, audr, 
   {{0x28244be7,0x6e2898fa,0x7c280481,0x764c98fb}},	//   _ዴሞክራ, mueb, budr, dway, 
   {{0x764c0548,0x7c2819a2,0x6e2898fc,0x6ff000de}},	//   eway, cudr, lueb, _māco, 
   {{0x764c98fd,0x00000000,0x00000000,0x00000000}},	//   fway, --, --, --, 
   {{0x6fc498fe,0x10680131,0x6e2898ff,0x2ef803b2}},	// [be60] góci, _ﻳﯧﺰﯨ, nueb, ðsfy_, 
   {{0x1a980677,0x65c400c7,0x00000000,0x00000000}},	//   _ליפע, чбза, --, --, 
   {{0xc8c006ab,0x6e2804e6,0x764c2fb2,0x1414007b}},	//   _एडिट, hueb, away, كيلة_, 
   {{0x764c2252,0x232800c2,0xa5080131,0x2d849900}},	//   bway, соди_, شىچە_, hkle_, 
   {{0x764c2959,0x6fc47917,0x7d1c9901,0x2d8405ac}},	//   cway, cóci, órsk, kkle_, 
   {{0x6e280393,0xdc3c054e,0x66147738,0x00000000}},	//   dueb, nţăt, msyk, --, 
   {{0x2d840fac,0x661472b6,0x96dc0150,0x00000000}},	//   dkle_, lsyk, гiзу_, --, 
   {{0x7c289902,0x910012b9,0xd0040114,0x00000000}},	//   vudr, _үпте, чеће_, --, 
   {{0x6e289903,0x661400d4,0x7c28014b,0xc0ec001f}},	//   gueb, nsyk, wudr, ጀመር_, 
   {{0x7c280286,0xb81c00e1,0x6614002d,0x2d840098}},	//   tudr, _फिलम_, isyk, gkle_, 
   {{0x764c9904,0x62809905,0x00000000,0x00000000}},	//   zway, lyoo, --, --, 
   {{0x764c9906,0x6e289907,0x66149908,0x2d840076}},	//   yway, bueb, ksyk, akle_, 
   {{0x764c9909,0x6280990a,0x7c28990b,0x5e58007b}},	//   xway, nyoo, sudr, _دجاج_, 
   {{0x6280300b,0x2d84771c,0x661433b8,0x764c02e2}},	//   iyoo, ckle_, dsyk, vway, 
   {{0x63a0990c,0x8d70990d,0x6b8c145e,0xa8543c1a}},	//   kion, _ساوا, ângâ, мерә, 
   {{0x764c60d7,0x63a0990e,0xc7c4119e,0x6e340241}},	//   tway, jion, есуи, _ìgbá, 
   {{0x63a00263,0xbbc81b6e,0x661405ac,0x9a8401c4}},	// [be70] dion, रतीक, gsyk, _хуйл, 
   {{0x6fc40034,0x764c990f,0x62800067,0x7d1c9910}},	//   róci, rway, dyoo, órsh, 
   {{0x764c9911,0x63a09912,0x37c4035b,0x62800009}},	//   sway, fion, _жәаб, eyoo, 
   {{0x764c54c4,0x62800009,0x6aa002f0,0x00000000}},	//   pway, fyoo, _žofi, --, 
   {{0x2d840034,0x386004e6,0x764c9913,0x755000c7}},	//   ykle_, _hrhr_, qway, _иҭаӡ, 
   {{0x63a00810,0x38600036,0x216400ee,0x61400024}},	//   aion, _krhr_, диши_, веша, 
   {{0x63a0068f,0x64581505,0x5064036b,0x62809914}},	//   bion, _štiv, ятда, ayoo, 
   {{0x7e649915,0xeda400dc,0x62809916,0x6e2816b8}},	//   _šipa, गच्छ, byoo, tueb, 
   {{0x90e49917,0x62800009,0x926801a9,0x00000000}},	//   _فسان, cyoo, _урва_, --, 
   {{0x6e289918,0xac849919,0x00000000,0x00000000}},	//   rueb, дгол, --, --, 
   {{0xfd54002b,0x2d84991a,0x00000000,0x00000000}},	//   _jagṛ, rkle_, --, --, 
   {{0x6e280789,0x6614991b,0xa6e00174,0x00000000}},	//   pueb, ysyk, íðka, --, 
   {{0x6e28991c,0xe9280327,0x00000000,0x00000000}},	//   queb, _སྐུབ_, --, --, 
   {{0x63a0991d,0xefc80092,0x00000000,0x00000000}},	//   zion, ጠፊያ_, --, --, 
   {{0x579402d3,0x63a0991e,0x46e047b8,0x00000000}},	//   _መለኽቲ_, yion, पेनह, --, 
   {{0x6280991f,0x27e4006a,0x398c0023,0xab6400f3}},	//   yyoo, öon_, _ሓወልቲ_, _цвил, 
   {{0xe61802f6,0x66142401,0x6280058a,0x00000000}},	// [be80] юда_, usyk, xyoo, --, 
   {{0x66149920,0x63a09921,0x62800451,0xe3b09922}},	//   rsyk, wion, vyoo, ھرا_, 
   {{0x63a09923,0x66140209,0xe3b09924,0x7d1c041e}},	//   tion, ssyk, پرا_, órsi, 
   {{0xe2c8600f,0x62800083,0x63a0003a,0x00000000}},	//   олед_, tyoo, uion, --, 
   {{0x6fc40120,0x22149925,0xb9cc0092,0x00000000}},	//   nócu, ффер, _ታች_, --, 
   {{0x14b40490,0x62809926,0x00000000,0x00000000}},	//   _अडचण, ryoo, --, --, 
   {{0x63a09927,0x6e2c01e4,0x23349928,0x602803e3}},	//   pion, _ĥaba, _охар, _həmz, 
   {{0x4024013d,0x63a006be,0x00000000,0x00000000}},	//   _үзаң, qion, --, --, 
   {{0x45600020,0x7ae81050,0xef9001d5,0xf3f80356}},	//   _ለማንበ, žetk, دیند, _ăţi_, 
   {{0xe1644c1c,0x00000000,0x00000000,0x00000000}},	//   _تدري, --, --, --, 
   {{0xe04402bf,0x4438037e,0x20540024,0x00000000}},	//   _інди, _jqr_, _ютар, --, 
   {{0x2a640427,0xaae400e5,0x1e8400d8,0x00000000}},	//   _šoba_, کسپو, _олем, --, 
   {{0xda78084c,0x645c0254,0x00000000,0x00000000}},	//   цян_, hvpi, --, --, 
   {{0xf8b800db,0x00000000,0x00000000,0x00000000}},	//   зөм_, --, --, --, 
   {{0xdc3c00e2,0xcd301ec7,0x333c0175,0x00000000}},	//   rģēt, _شروب, yfwx_, --, 
   {{0x8c180115,0x00000000,0x00000000,0x00000000}},	//   _ווהי, --, --, --, 
   {{0x7aec9929,0x7bdc0267,0x4a5400f7,0x3c3800e5}},	// [be90] _igat, mmsu, _акыс, lév_, 
   {{0xca48034c,0x00000000,0x00000000,0x00000000}},	//   _کلیه_, --, --, --, 
   {{0x7aec2f42,0x3c3801ed,0x7bdc198f,0x49b8027d}},	//   _kgat, név_, omsu, _تايد_, 
   {{0x4308992a,0xd7644c2d,0x443803b9,0xd344992b}},	//   ِينَ_, _تەرى_, _dqr_, بیره_, 
   {{0x645804b9,0x7aec0522,0x7bdc2d8b,0xf07401ed}},	//   _štit, _mgat, imsu, کیاں_, 
   {{0x60280213,0x00000000,0x00000000,0x00000000}},	//   _həmy, --, --, --, 
   {{0x7aec992c,0x7c380175,0x33940a89,0x602806be}},	//   _ogat, _nqvr, _завё, _zəmz, 
   {{0x7aec992d,0xef182766,0x00000000,0x00000000}},	//   _ngat, чми_, --, --, 
   {{0xbf140166,0x00000000,0x00000000,0x00000000}},	//   түчә, --, --, --, 
   {{0x7aec992e,0x777c0211,0x7f440113,0x7058992f}},	//   _agat, _losx, _ñiqn, _назр_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7aec7acb,0x09c801f9,0x00000000,0x00000000}},	//   _cgat, ळत्य, --, --, 
   {{0xd094052f,0x6e4406ed,0x645c0427,0x00000000}},	//   _эшҡы, _челз, zvpi, --, 
   {{0x7aec9930,0x291c145e,0x7bdc208d,0xed589931}},	//   _egat, ûta_, amsu, _хок_, 
   {{0x18649932,0x2e38007f,0x00000000,0x00000000}},	//   нари_, lèf_, --, --, 
   {{0x9f449933,0x7d1c1427,0x00000000,0x00000000}},	//   _cioè_, órsv, --, --, 
   {{0x3ea00008,0x44380334,0xeadc0183,0x2e3802e2}},	// [bea0] _þitt_, _sqr_, _ভ্ৰম, nèf_, 
   {{0x66e40209,0x20180113,0xd6d401d5,0x7aec022e}},	//   _җога, špii_, رولش_, _zgat, 
   {{0x44380798,0x7aec0022,0x64980cab,0x00000000}},	//   _qqr_, _ygat, чтар_, --, 
   {{0xd67c00d1,0x00000000,0x00000000,0x00000000}},	//   ﻧﺒﻪﺭ_, --, --, --, 
   {{0x51f40816,0xd24c01d9,0x779002f2,0x00000000}},	//   енію_, ٝنن_, _ئیقا, --, 
   {{0x64a49934,0x7e6405be,0x00000000,0x00000000}},	//   _зага, _šipo, --, --, 
   {{0x201801d3,0x00000000,0x00000000,0x00000000}},	//   épi_, --, --, --, 
   {{0xae207f90,0xdef89935,0x5438010f,0xdecc01f3}},	//   _मिशन_, чык_, _מעלא, _ባራክ_, 
   {{0x7aec036b,0x626401c0,0x290401fb,0x7eb801af}},	//   _rgat, _яваа, _đoan_, ьгис_, 
   {{0x7aec0e89,0x00000000,0x00000000,0x00000000}},	//   _sgat, --, --, --, 
   {{0x6fc49936,0x00000000,0x00000000,0x00000000}},	//   tóct, --, --, --, 
   {{0x7e700133,0x00000000,0x00000000,0x00000000}},	//   _نۆبڵ, --, --, --, 
   {{0xda6452c8,0x7bdc613e,0x1ec80228,0x26dc01e4}},	//   راحي, rmsu, _элди_, _ŝton_, 
   {{0x09e40953,0xd7f80022,0x3d2804f2,0x00000000}},	//   лоўн, зуа_, _آتشی_, --, 
   {{0x7aec9937,0x8d580302,0x6fc430d9,0x00000000}},	//   _tgat, _זכוי, mócr, --, 
   {{0x7aec015c,0x9554168d,0x36d4894b,0x6bc40124}},	//   _ugat, کخرا, вобр, _ирыҧ, 
   {{0x9f440395,0x8aa406a6,0xd598037e,0x777c0166}},	// [beb0] _cioé_, _брэд, _jpで_, _vosx, 
   {{0x7c289938,0x74a8013d,0x00000000,0x00000000}},	//   ordr, мсең_, --, --, 
   {{0x26e003f4,0x64580fb7,0x74340daf,0x5fb03ee1}},	//   গুলো_, _štir, тнеф, ुकाल, 
   {{0xae2016f0,0x00000000,0x00000000,0x00000000}},	//   _मिलन_, --, --, --, 
   {{0x2bb4005f,0xdb0c036e,0xe7a400d1,0x7c28002f}},	//   nāca_, encë, _شۇكى_, hrdr, 
   {{0xe12001c0,0xdee00092,0xd5b800d8,0x00000000}},	//   амши, ዑካን_, _хсм_, --, 
   {{0x81741e4a,0x6fc410d8,0x6d8c02d2,0x6ff000cd}},	//   انىچ, dócr, _búan, _kāci, 
   {{0x6d8c0789,0x883c0375,0x6ff00171,0xe0d000eb}},	//   _cúan, פתחו, _jāci, াশূন, 
   {{0xf2880014,0xdb0c0023,0xf1d010de,0x6ff01981}},	//   _تھاو_, ancë, _көкө, _māci, 
   {{0x2a640010,0x6ff000de,0x6fc400e5,0x00000000}},	//   _šobo_, _lāci, tócs, --, 
   {{0xab28016c,0xd6f800b5,0x9008103c,0x30140022}},	//   мона_, _mmア_, _رزاق_, _рдер, 
   {{0x6ff0005f,0x00000000,0x00000000,0x00000000}},	//   _nāci, --, --, --, 
   {{0x2fcc9939,0x6f08993a,0x2d987ea5,0x7c280fac}},	//   mleg_, mbec, èses_, ardr, 
   {{0x2fcc993b,0x7d1c993c,0x6e28020c,0x6cc401d5}},	//   lleg_, órst, mreb, _ийла, 
   {{0x7c64993d,0x6f080232,0xe7380798,0xeb980353}},	//   _مايل, obec, мев_, _оик_, 
   {{0x2fcc993e,0xeaf8152f,0x6f083b52,0x6ff00055}},	//   nleg_, _غربت_, nbec, _cāci, 
   {{0xb8c80da0,0x2fcc01c7,0x6d4001ab,0xa92001a8}},	// [bec0] _खे_, ileg_, ofla, _óþol, 
   {{0x6f08993f,0x7994002f,0x00000000,0x00000000}},	//   hbec, chzw, --, --, 
   {{0x2fcc9940,0x68fc04cc,0x6e2800d0,0x5eb00183}},	//   kleg_, _ifpd, hreb, _চৰাই, 
   {{0x69cc9941,0xdc2c0882,0x6d40127b,0x6e289942}},	//   llbe, _jñāt, hfla, kreb, 
   {{0x2fcc0183,0x6f089943,0x69cc0ea0,0xb3e84f90}},	//   dleg_, dbec, olbe, رعمل_, 
   {{0xd24c9798,0x2fcc8d2d,0x1a98008f,0x6d402e22}},	//   تنه_, eleg_, וינע, jfla, 
   {{0x656c0876,0x6d40127b,0x6e28736b,0xa2cc0c2e}},	//   _inbh, dfla, ereb, _तरक्, 
   {{0x2fcc0183,0x69cc3468,0x64a4036b,0x6e289944}},	//   gleg_, hlbe, _заҳа, freb, 
   {{0x6e280d0f,0x6d409945,0x7f4402d1,0x8e1002d5}},	//   greb, ffla, _ñiqm, адыц, 
   {{0x2bb40882,0x6d409946,0x20c80451,0x69cc005c}},	//   vāca_, gfla, _قبضي_, jlbe, 
   {{0x6f089947,0x6e289948,0x6fc404d4,0x2fcc9949}},	//   bbec, areb, rócr, bleg_, 
   {{0x6e28994a,0x68fc03ac,0x6d40994b,0x7c280158}},	//   breb, _afpd, afla, rrdr, 
   {{0x6fc47d3d,0x6e28994c,0x6aa000f3,0x6d40003a}},	//   pócr, creb, _žofr, bfla, 
   {{0x7c34994d,0x6ff01c52,0x7c280175,0xdb0c00ae}},	//   _бекх, _sāci, prdr, incé, 
   {{0x35b41d18,0x9f5c00e8,0x7c3c01ab,0x8c500137}},	//   ҳбар, _atté_, àrrd, _نئيا, 
   {{0x656c01e7,0x349401ec,0x27fc00d7,0x00000000}},	//   _anbh, ңаар, ítna_, --, 
   {{0x6458994e,0x6ff000da,0x76b8994f,0x3b1800e8}},	// [bed0] _štip, _vāci, хлар_, masq_, 
   {{0xd40407d8,0x2fcc00ee,0xb8e8015b,0x6f080010}},	//   вяди, zleg_, _ঋণ_, zbec, 
   {{0x6ec8038e,0xdb0c06af,0x2fcc2f50,0x00000000}},	//   _हुनु, encé, yleg_, --, 
   {{0x6e289950,0x04649951,0x2fcc01bf,0x6f08002f}},	//   yreb, штум, xleg_, xbec, 
   {{0x6a44013f,0x2fcc03d4,0x6d409952,0x201c0219}},	//   _kɔfa, vleg_, yfla, _avti_, 
   {{0x6e289953,0x6d40003b,0xb5c8007b,0xc104027d}},	//   vreb, xfla, _أوسم_, لوهي, 
   {{0x14c40e83,0x2fcc9954,0x3494026a,0x6e2800ee}},	//   _شهری_, tleg_, _савр, wreb, 
   {{0x6e289955,0x2fcc05c7,0xad2415bf,0x00000000}},	//   treb, uleg_, گىدى, --, 
   {{0x2fcc0c58,0x6d409956,0x69cc002f,0x6f087ea3}},	//   rleg_, tfla, ylbe, rbec, 
   {{0x2fcc6b16,0x6f089957,0xed5801c0,0xec784558}},	//   sleg_, sbec, хоо_, епо_, 
   {{0xb4b00034,0x2d980006,0x2fcc9958,0x20180118}},	//   _ओशो_, ėse_, pleg_, ápit_, 
   {{0x6d409959,0x7ff4995a,0x6e28995b,0x7dd401ab}},	//   sfla, _ئسلا, preb, ràsa, 
   {{0xfe70995c,0x186400c2,0x6e2806be,0x00000000}},	//   _وده_, қати_, qreb, --, 
   {{0x29080ffb,0x6d8c02d2,0xef18012d,0x920400ef}},	//   ubba_, _kúam, laż_, cmāš, 
   {{0x69cc4a7f,0x00000000,0x00000000,0x00000000}},	//   rlbe, --, --, --, 
   {{0x7c3c00f7,0xada40116,0xc70402dd,0x6da4008e}},	//   àrre, _шаһл, ржақ, _шиһа, 
   {{0xe56801c6,0xd62404b0,0x377418bc,0x00000000}},	// [bee0] ниад_, лоте_, шырс, --, 
   {{0x1a9804ac,0x7e640bb3,0x6600063f,0x2498017a}},	//   _נייע, _šipk, ̣okw, tzpm_, 
   {{0xef18006d,0xc3e4004b,0x1d14008f,0x00000000}},	//   każ_, لګرو, רקער_, --, 
   {{0xc3301cbf,0xe3140132,0xef180034,0x4ad80490}},	//   تەر_, اباب, jaż_, _ठराव, 
   {{0xef18068f,0xd8b00214,0x00000000,0x00000000}},	//   daż_, _نمیخ, --, --, 
   {{0x9e041f71,0xe5a467ba,0x05b82c2e,0x00000000}},	//   қчил, _сиги, _आदिब, --, 
   {{0x7f580d1d,0xb0600139,0x00000000,0x00000000}},	//   вайс_, _şärg, --, --, 
   {{0x201c0263,0x2d98995d,0x673400ee,0x3ce00115}},	//   _vvti_, ësen_, ngyj, _ŝivo_, 
   {{0x35d805f9,0xc0d00092,0x00000000,0x00000000}},	//   _बीड़, _ሥዩም_, --, --, 
   {{0xd6540302,0x5c04995e,0xd09000c7,0x6f1c00ae}},	//   ניית_, ляма, ршәы, óscr, 
   {{0xdbdc03b2,0xd24c01d9,0x00000000,0x00000000}},	//   _bíðj, _ونہ_, --, --, 
   {{0xd00c168d,0xfb8801a9,0xc1b000fb,0x00000000}},	//   _رله_, троқ_, _ыҙҙы, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x5ec800fe,0x7afc0051,0xa2901954,0x00000000}},	//   াইদে, scst, ቁርናን_, --, 
   {{0x395005d5,0x56f0004e,0x00000000,0x00000000}},	//   rezs_, йүнс, --, --, 
   {{0x6a44013f,0x291c0321,0x395005d5,0x00000000}},	//   _wɔfa, ótar_, sezs_, --, 
   {{0xeb180451,0x02a4000d,0x751400d8,0x00000000}},	// [bef0] _شريڪ_, _खेलभ, имаф, --, 
   {{0xef180210,0x00000000,0x00000000,0x00000000}},	//   zaż_, --, --, --, 
   {{0xca280150,0xdd8400f1,0x00000000,0x00000000}},	//   _ﱢﺭﺕ_, _ېو_, --, --, 
   {{0x04c8038b,0xdfc45857,0x00000000,0x00000000}},	//   دومي_, _ذي_, --, --, 
   {{0x30c01870,0x00000000,0x00000000,0x00000000}},	//   ﺭﺯﻩﻧ, --, --, --, 
   {{0xef18068f,0x321c0142,0x00000000,0x00000000}},	//   waż_, rswy_, --, --, 
   {{0x32640014,0x82a40022,0xef18202a,0x00000000}},	//   انڈہ, ишәе, taż_, --, 
   {{0x72040d1f,0x82f80597,0x4394995f,0x934000db}},	//   _نورم, _مركز_, _ласс, _دىرۇ, 
   {{0x92b4293c,0xef18033f,0xc0e80131,0xdcf80139}},	//   _صحرا, raż_, نفۇن_, entı, 
   {{0xada46169,0xef18033f,0x6da40262,0xfe740116}},	//   раол, saż_, риоа, сүш_, 
   {{0x8e7000d1,0xe7e401f9,0x00000000,0x00000000}},	//   руқч, _कळला_, --, --, 
   {{0xace8004b,0x6d8c21f1,0x81cc0154,0x7f740064}},	//   _یرغل_, _kúak, রগণ_, _гушц, 
   {{0x61ec03ee,0x6ff000ef,0xf8b400c7,0x00000000}},	//   _ünlü, _vācu, ҩҩы_, --, 
   {{0xa804119e,0x00000000,0x00000000,0x00000000}},	//   изгл, --, --, --, 
   {{0xd6f800b5,0x00000000,0x00000000,0x00000000}},	//   _mmウ_, --, --, --, 
   {{0xed300014,0x6a840353,0x60d000a2,0x00000000}},	//   _اڈکھ, _влиа, _ýemş, --, 
   {{0x24f49960,0xe9d809a5,0x6bc002e3,0x3b0c0309}},	// [bf00] ачер, _ики_, ọasụ, ñeqe_, 
   {{0xa5080114,0x85b40139,0x00000000,0x00000000}},	//   тежа_, сәмч, --, --, 
   {{0x6a44013f,0x630400aa,0x1414007b,0x24800092}},	//   _kɔfo, لوال, ليلة_, _የጸሎት_, 
   {{0x23289961,0x626406ed,0xe6180107,0x9fac013a}},	//   тоди_, ивеа, _идм_, _pří_, 
   {{0x7f441bb7,0x06e400bd,0x00000000,0x00000000}},	//   _ñiqi, _ফ্রি, --, --, 
   {{0x6b9400a9,0xd6f8037e,0x00000000,0x00000000}},	//   _llyg, _cmウ_, --, --, 
   {{0xd0149962,0x6b940368,0xb35403e6,0x442c9963}},	//   афы_, _olyg, _گینا_, _íd_, 
   {{0x6604020c,0x9fac012c,0xa2041468,0x6b9400a2}},	//   _ktkk, _tří_, _впад, _nlyg, 
   {{0xb35400dd,0x644c010a,0x5398025d,0x65c400b8}},	//   _دینا_, _hpbi, _סימו, _gįhõ, 
   {{0xddc0068f,0x3d9400c7,0xa0a400db,0x00000000}},	//   _społ, сиор, _казд, --, 
   {{0x6b949964,0xd12c00c6,0xdde801b9,0xcf8c0a5b}},	//   _blyg, _زمن_, _یرته_, _дј_, 
   {{0xd00c0066,0x91bc0051,0x00000000,0x00000000}},	//   _آلن_, _trụ_, --, --, 
   {{0x5da4004b,0xdee4009b,0x4ea0009b,0x00000000}},	//   _نږدې_, _тоди, _мрша, --, 
   {{0xe3bc029f,0xdb0c9965,0x00000000,0x00000000}},	//   ğıya_, tocó, --, --, 
   {{0x6b949966,0x9f5c011f,0x7bc4010f,0x57a49967}},	//   _flyg, _ittâ_, _ĉiuf, ашаа, 
   {{0x81cc0154,0x00000000,0x00000000,0x00000000}},	//   রগি_, --, --, --, 
   {{0x7d189968,0x7bcc9969,0x644c00ef,0x00000000}},	// [bf10] _kevs, _ikau, _apbi, --, 
   {{0x7bcc0165,0x6ec800af,0x7d180171,0xdb0c01e7}},	//   _hkau, _हँसु, _jevs, incí, 
   {{0x7d1803ee,0x7f440784,0x53e42fc3,0x97c4007b}},	//   _mevs, _ñiqw, ацда, _نتحم, 
   {{0x79840455,0xd6d801c0,0x660001e4,0xc348008e}},	//   _hohw, _атг_, ŭoka, ияче_, 
   {{0xd6d82dbd,0x644c01fa,0x79840099,0x7bcc009f}},	//   _што_, _epbi, _kohw, _mkau, 
   {{0x79840842,0x644c00b5,0x765c037e,0x7d182e31}},	//   _johw, _fpbi, _issy, _nevs, 
   {{0xf4e41c82,0x7bcc996a,0x7984996b,0xed580aac}},	//   _প্ৰব, _okau, _mohw, қон_, 
   {{0x7bcc0190,0xee38996c,0x00000000,0x00000000}},	//   _nkau, гни_, --, --, 
   {{0x6b9400a2,0x00000000,0x00000000,0x00000000}},	//   _rlyg, --, --, --, 
   {{0x7bcc996d,0x7984996e,0x00000000,0x00000000}},	//   _akau, _nohw, --, --, 
   {{0x34c40034,0x6b94996f,0xe2a408a5,0x35b400cc}},	//   _वडोद, _plyg, _æðri_, _জীৱহ, 
   {{0x69dc069c,0xf98825f9,0x765c03ac,0x7c3c08c2}},	//   _shpe, _אר_, _ossy, àrra, 
   {{0xeab0066d,0x79849970,0x69dc9971,0xdb0c9972}},	//   سٹس_, _bohw, _phpe, tocò, 
   {{0x7bcc0428,0x7ed47092,0x7d1806ea,0x8d745821}},	//   _ekau, _بزما, _gevs, _خاصا, 
   {{0x765c9973,0x7bcc03a0,0x261801ad,0x97749974}},	//   _assy, _fkau, मीनी_, әтсә, 
   {{0x6b9402d0,0x7d189975,0xe768297d,0x00000000}},	//   _ulyg, _zevs, دحسن_, --, 
   {{0xa5249976,0x29d4003a,0x7d180139,0xe9a401fe}},	// [bf20] ймад, læam_, _yevs, _гапп, 
   {{0x79840810,0x6f1800f1,0x64989977,0x7d180166}},	//   _gohw, _lewc, лтер_, _xevs, 
   {{0x765c9978,0x29189979,0x00000000,0x00000000}},	//   _essy, _iepa_, --, --, 
   {{0xe298997a,0x7984014b,0x2d980240,0x9cd8010f}},	//   лае_, _zohw, ësej_, אַדז, 
   {{0x2918997b,0x47c8004b,0x657801ab,0x7984997c}},	//   _kepa_, _ماڼۍ_, _òtho, _yohw, 
   {{0x2918010e,0x00000000,0x00000000,0x00000000}},	//   _jepa_, --, --, --, 
   {{0x6f180472,0xf1a876d3,0x29180803,0x7d18997d}},	//   _bewc, جانه_, _mepa_, _revs, 
   {{0x4444997e,0x2918997f,0x6f180368,0x7d189980}},	//   mt_, _lepa_, _cewc, _sevs, 
   {{0x7d180219,0x6f180368,0xf3f4031c,0x7bcc02d2}},	//   _pevs, _dewc, _བཤོད_, _rkau, 
   {{0x7bcc9981,0x44449982,0x29189983,0xfcf80023}},	//   _skau, ot_, _nepa_, _ፊልጲ_, 
   {{0x7d186a12,0x6aa4015b,0x606416ac,0x7984002f}},	//   _vevs, _গুলো, _دهال, _rohw, 
   {{0x444417ce,0x29180109,0xc978001f,0x7e6449b0}},	//   it_, _aepa_, _ካለፈው_, _šipu, 
   {{0x44449984,0x29180099,0x9e7405d9,0x7984047e}},	//   ht_, _bepa_, _دهشت, _pohw, 
   {{0x96ec025c,0x6f18009a,0x3c9408ca,0x6edc01f9}},	//   _ཨུཏྤ, _zewc, _милё, _परतु, 
   {{0x44449985,0x29189986,0x6f0c084c,0xf8b84d4c}},	//   jt_, _depa_, _încâ, рөп_, 
   {{0x79840134,0x7bcc9987,0x291801e1,0x2bc801bc}},	//   _wohw, _ukau, _eepa_, रवणा, 
   {{0x29189988,0xa3bc190e,0x00000000,0x00000000}},	// [bf30] _fepa_, ीकन_, --, --, 
   {{0x44449989,0x00000000,0x00000000,0x00000000}},	//   ft_, --, --, --, 
   {{0x4444998a,0xad2c0023,0xdef40023,0x00000000}},	//   gt_, _ተበጊሶ, ለላን_, --, 
   {{0x25a80477,0x291801b8,0x2d780240,0xcc3800df}},	//   _embl_, _zepa_, _ክወስዶ_, רעאט, 
   {{0x44441905,0x29180099,0x765c03ac,0x973000f1}},	//   at_, _yepa_, _ussy, _وکړا, 
   {{0x4444998b,0x6f1801e2,0x29180798,0xaadc202e}},	//   bt_, _sewc, _xepa_, नेटक, 
   {{0xaf98998c,0x339400c0,0x00000000,0x00000000}},	//   итих_, _давё, --, --, 
   {{0x93948b1e,0x6fb415b0,0x523802c9,0x00000000}},	//   _اجسا, تمعا, _مسطح_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6f18009a,0x82a40daf,0x0c900023,0x80c4000d}},	//   _wewc, _эшсе, _ይመርጽ_, _लुकइ, 
   {{0x7e640063,0xef6401c0,0x8d8401b9,0x6f180142}},	//   _šipt, _мэдү, _қудд, _tewc, 
   {{0xeff4001f,0xddc00356,0x4fc40022,0xa098010f}},	//   ለኛው_, _proţ, _усза, _דיעט, 
   {{0x444422d9,0x6fc4998d,0x00000000,0x00000000}},	//   zt_, kócz, --, --, 
   {{0xa968006c,0x4444998e,0xddc000e4,0x2918998f}},	//   шига_, yt_, _apoņ, _qepa_, 
   {{0xec1402dd,0x44449990,0x6c78008f,0xeb9801c6}},	//   _بوعد, xt_, _כאַפ, _вий_, 
   {{0x444417c0,0x7f4402d1,0x2918010b,0x8d740133}},	//   vt_, _ñiqt, _wepa_, _خاڵا, 
   {{0x44449991,0xf3f40156,0x29189992,0xe8140cb4}},	// [bf40] wt_, _བཤུད_, _tepa_, _तबका_, 
   {{0x224000af,0xdb0c00d2,0x00000000,0x00000000}},	//   _äkki_, mncá, --, --, 
   {{0xe4589993,0x00000000,0x00000000,0x00000000}},	//   рже_, --, --, --, 
   {{0x06c404c5,0xa348036b,0x00000000,0x00000000}},	//   ্ধবি, рзда_, --, --, 
   {{0xdb0c0798,0xc0bc0092,0x48f40118,0x00000000}},	//   ficê, ታደስ_, ौँको_, --, 
   {{0x64a4134c,0xddc00e04,0xdd0000e2,0x3ea0010b}},	//   _дага, _oroš, ārīg, _ýiti_, 
   {{0x44449994,0x4ccc00cc,0x00000000,0x00000000}},	//   qt_, হেতু, --, --, 
   {{0xc22419bc,0xe3b801c6,0x00000000,0x00000000}},	//   _فکتو, _тбб_, --, --, 
   {{0xe3bc0259,0x7dd4004e,0xa8000213,0x67cc0153}},	//   ğıda_, làsi, ğıye, mėję, 
   {{0x2364008f,0xad2c02d3,0xc03c001f,0x67cc0153}},	//   ldoj_, _ተበግሶ, ከተለው, lėję, 
   {{0x22449995,0x7dd4004e,0x00000000,0x00000000}},	//   ltok_, nàsi, --, --, 
   {{0x23649996,0xddc00029,0xd9e04d21,0x200c18f7}},	//   ndoj_, _droš, पष्ट, mpfi_, 
   {{0xdb0c0023,0x236400df,0x00000000,0x00000000}},	//   licë, idoj_, --, --, 
   {{0xdbd40139,0x00000000,0x00000000,0x00000000}},	//   käçl, --, --, --, 
   {{0xd7f89997,0x7f440784,0xdb0c0023,0xddc00427}},	//   руг_, _ñiqs, nicë, _groš, 
   {{0x22442af2,0xd1ec044e,0x23640115,0x96ec0327}},	//   ktok_, _ሂወት_, jdoj_, _ཨུདྤ, 
   {{0xd5080058,0x67cc0024,0xe21001ec,0x00000000}},	// [bf50] لغان_, dėję, _етiп_, --, 
   {{0x22449998,0x7dd4004e,0x236401e4,0xdb0c036e}},	//   dtok_, fàsi, edoj_, kicë, 
   {{0x394003fa,0xd6f800b5,0x22449999,0x00000000}},	//   _ichs_, _mmズ_, etok_, --, 
   {{0x2244011f,0x81d4009e,0x317801d3,0x67cc00c0}},	//   ftok_, _সংগ_, _ősz_, gėję, 
   {{0x2244999a,0xd258999b,0xf678010f,0x00000000}},	//   gtok_, рце_, _האָמ, --, 
   {{0x23640115,0xdb0c0240,0xdbd401f4,0x00000000}},	//   adoj_, ficë, lääl, --, 
   {{0x765807b3,0x7dd4004e,0x22440030,0x7c3c08c2}},	//   şayı, càsi, atok_, àrrl, 
   {{0x39400066,0x2008031c,0xc0580633,0x00000000}},	//   _lchs_, _ħbit_, تشها_, --, 
   {{0x28d0534e,0x39400086,0x7e64107d,0x313400c0}},	//   _दुनि, _ochs_, _šipr, _неар, 
   {{0xddc00b9b,0xdbd405a7,0x637001a9,0x00000000}},	//   _proš, hääl, lаnа, --, 
   {{0x2ef464e1,0x2bc80137,0xdbd401f4,0x00000000}},	//   _езер, йлоп_, kääl, --, 
   {{0x3940324c,0x3164030a,0xdbd401f4,0xbe3000db}},	//   _achs_, _halz_, jääl, رۉۉب, 
   {{0x38600a2e,0x316403bd,0xcee800cf,0xa3bc2122}},	//   _ashr_, _kalz_, _ئران_, ीकत_, 
   {{0x2fcc999c,0xfe5401d5,0xa3e000c5,0x00000000}},	//   loeg_, _کییب_, _नीन_, --, 
   {{0x224400dd,0xddc0999d,0xdbd40036,0x6c74009d}},	//   ztok_, _uroš, fääl, _хулх, 
   {{0x2fcc7890,0xab980502,0x2244999e,0x39400036}},	//   noeg_, _دختر_, ytok_, _echs_, 
   {{0x39501aac,0x3a380076,0x399c0241,0x00000000}},	// [bf60] ́nsɔ_, cusp_, _sìse_, --, 
   {{0x2fcc05c7,0x00000000,0x00000000,0x00000000}},	//   hoeg_, --, --, --, 
   {{0x2244014b,0xd6f8037e,0xdb0c004e,0x2fcc030a}},	//   wtok_, _mlオ_, ficè, koeg_, 
   {{0x69cc999f,0x224499a0,0xdb0c0023,0xd1ec02d3}},	//   lobe, ttok_, vicë, _ሂወቱ_, 
   {{0x236404ac,0x316405d5,0x2fcc715a,0x1888001f}},	//   rdoj_, _balz_, doeg_, ነጋገር_, 
   {{0x224499a1,0x31640165,0x255800a8,0xdb0c036e}},	//   rtok_, _calz_, _урмэ_, ticë, 
   {{0x224499a2,0x55e099a3,0x716400db,0x233400c7}},	//   stok_, _чорб, بانك, _нхар, 
   {{0xc9180d01,0x224451ca,0xe29899a4,0x2fcc05c7}},	//   थरुम_, ptok_, _лаб_, goeg_, 
   {{0x69cc99a5,0x316431d9,0xd6f800b5,0xa3e00210}},	//   kobe, _falz_, _cmス_, _नीय_, 
   {{0x69cc99a6,0x3cf8022c,0x316405c7,0xad24141d}},	//   jobe, ørv_, _galz_, ورپو, 
   {{0xdb0c0077,0x2fcc5e52,0xf8c80036,0x61e8002f}},	//   licé, boeg_, itéë_, mmfl, 
   {{0xa3e005f9,0xc1740198,0x6d8c01a8,0x0c880023}},	//   _नीम_, ɓɗa_, _búas, ህልላኽ_, 
   {{0xdbd4023a,0xc91825c9,0x00000000,0x00000000}},	//   vääl, थरूम_, --, --, 
   {{0x23dc09d9,0x69cc2f99,0xceb0008f,0xe3e000eb}},	//   _फीसद, gobe, _אינ_, যদিব, 
   {{0xa3bc99a7,0x3a380227,0x61e80332,0xdbd40108}},	//   ीका_, susp_, imfl, tääl, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69cc99a8,0xd6d84d15,0xd7f812d7,0xddc0012c}},	// [bf70] bobe, ств_, руҳ_, _spoř, 
   {{0x69cc99a9,0x3a28009d,0x2fcc05c7,0xdbd40108}},	//   cobe, _ivap_, zoeg_, sääl, 
   {{0xdbd40f23,0xf8b00014,0x85880b7e,0xdb0c004e}},	//   pääl, _شکس_, чёта_, ticè, 
   {{0x245c0316,0x31641a80,0xd6f8037e,0x3f84031c}},	//   _dům_, _salz_, _mlカ_, jjmu_, 
   {{0x2fcc0151,0x41742be7,0xc0c0001f,0x020402dd}},	//   voeg_, کانس, _ስላለ_, езін, 
   {{0x74f80474,0x1aa80c58,0x2fcc030a,0x307460a7}},	//   _февр_, _গুৱা, woeg_, дуис, 
   {{0xdbcc0139,0x8c44013d,0xf07400e5,0x00000000}},	//   _gıçs, _maşí, بیاں_, --, 
   {{0x3164002f,0xd3440133,0xc0bc0023,0x00000000}},	//   _walz_, _ریته_, ታተሎ_, --, 
   {{0x69cc1d5c,0x2fcc99aa,0x31640120,0x332c0fac}},	//   yobe, roeg_, _talz_, _idex_, 
   {{0xed5801c0,0x7bc401e4,0xd5bc00dc,0x69cc005a}},	//   цоо_, _ĉiua, ्विज, xobe, 
   {{0x69cc0cf4,0x3a280166,0x2fcc99ab,0x7c94084c}},	//   vobe, _avap_, poeg_, еряц, 
   {{0x7f4403f0,0x69cc04ba,0x629c0115,0xefd80023}},	//   _ñiqp, wobe, ĝpov, ዮዽያ_, 
   {{0xd5bc4f3c,0x37c40154,0x7ed400c0,0x00000000}},	//   ्वाज, ্ষার, _пішч, --, 
   {{0x9f5c99ac,0x291c99ad,0xb0600139,0xaf740092}},	//   _että_, úta_, _şäyg, ያዎችና_, 
   {{0x69cc99ae,0xbbe80ec9,0x186499af,0x00000000}},	//   robe, تریم_, мари_, --, 
   {{0xe61899b0,0x69cc99b1,0x00000000,0x00000000}},	//   жда_, sobe, --, --, 
   {{0x69cc0851,0x5a6000f7,0x7ec8036e,0x61e8007c}},	// [bf80] pobe, _акыб, mëpë, ymfl, 
   {{0x332c0048,0x69cc99b2,0xe6dc033f,0x4ad80014}},	//   _adex_, qobe, _मरीज, _واکھ_, 
   {{0xddc00055,0x7dd400db,0x00000000,0x00000000}},	//   _apoś, màst, --, --, 
   {{0x7dd4004e,0xdb0c067c,0x2a7001bf,0x645c0142}},	//   làst, ticé, _kryb_, rwpi, 
   {{0x80b000c5,0xa18450c0,0x00000000,0x00000000}},	//   _अइहे, дыйл, --, --, 
   {{0x5bb80b9a,0x782401d5,0x7dd41c69,0x3f58004d}},	//   _उद्व, _تعیل, nàst, _ẩu_, 
   {{0x154099b3,0x7ec80200,0x00000000,0x00000000}},	//   _шерм, këpë, --, --, 
   {{0x88c00154,0x00000000,0x00000000,0x00000000}},	//   _ইরাক, --, --, --, 
   {{0x63a099b4,0x3df40f5c,0x75f0008e,0xe24400ae}},	//   mhon, нзис, bızğ, _تخزي, 
   {{0x63a099b5,0xaad00034,0xc1780064,0x22500200}},	//   lhon, _सड़क, _unė_, çyku_, 
   {{0x63a00184,0x62800009,0x43440092,0xdb1c036e}},	//   ohon, lxoo, _የምትባ, _ujqë, 
   {{0x6ec899b6,0x718000c7,0x9e6400d1,0x00000000}},	//   _हुकु, _ақәе, _ياشن, --, 
   {{0x63a099b7,0xefd8010c,0x9f5c0200,0x00000000}},	//   ihon, ዮጽያ_, _lutë_, --, 
   {{0xc3240075,0x63a099b8,0x2d980240,0x00000000}},	//   _ھە_, hhon, ëset_, --, 
   {{0x63a02ffc,0xc3240ed1,0x00000000,0x00000000}},	//   khon, _پە_, --, --, 
   {{0x7c2899b9,0x3dc004c5,0x7b8400db,0x63a0022e}},	//   msdr, _উঠিল, _سابە, jhon, 
   {{0x63a099ba,0xdcf80139,0x00000000,0x00000000}},	// [bf90] dhon, litı, --, --, 
   {{0xd9e011b1,0x320c1529,0x63a080ef,0x9f5c0023}},	//   _गठित_, _rtey_, ehon, _butë_, 
   {{0x63a00943,0x320c0493,0x7c2899bb,0x3dc0009e}},	//   fhon, _stey_, nsdr, _উঠাল, 
   {{0x63a099bc,0x7c280142,0x00000000,0x00000000}},	//   ghon, isdr, --, --, 
   {{0x3cfc0083,0x042000fe,0x27080051,0x00000000}},	//   _ogvv_, মূলী_, _ờng_, --, 
   {{0x80240131,0x9f5c0200,0xdbd40108,0x7c2899bd}},	//   ھرىم, _futë_, _hääh, ksdr, 
   {{0x9f440dd4,0x5fa00952,0x7bc40115,0x6280058a}},	//   _hioù_, گەنم, _ĉiun, axoo, 
   {{0x63a099be,0xdbd416b5,0x7c282611,0x5d940150}},	//   chon, _jääh, dsdr, _ﺘﺠﺭﺅ_, 
   {{0xa3bc0574,0x7c280b4f,0xddc0012d,0x00000000}},	//   ीकर_, esdr, _upoś, --, 
   {{0x41741ec7,0xac8470e4,0x90e40133,0xfe7404da}},	//   _لامس, егол, _قسان, түш_, 
   {{0xe5701a4c,0x7c2812e8,0x801402d5,0x7dd4004e}},	//   אַר_, gsdr, _афіц, vàst, 
   {{0xcf2404fb,0x00000000,0x00000000,0x00000000}},	//   _آراي, --, --, --, 
   {{0x6f080af2,0x7b800220,0x3d1000dc,0x7dd400cf}},	//   mcec, рғыд, _द्वे_, tàst, 
   {{0x63a00ad3,0x6e282747,0x7c28005c,0x00000000}},	//   zhon, mseb, bsdr, --, 
   {{0xeb9899bf,0x9f5c0100,0x6e2899c0,0xdbd40036}},	//   _ник_, _butè_, lseb, _bääh, 
   {{0x6d4099c1,0x6f0899c2,0x9f4405c7,0x63a099c3}},	//   lgla, ncec, _bioù_, xhon, 
   {{0x6e2899c4,0x63a00084,0x97c02d30,0x7dd400db}},	// [bfa0] nseb, vhon, уйте, càss, 
   {{0x6d4099c5,0x64a40364,0x154099c6,0x02dc00e1}},	//   ngla, наза, леум, _बरौन, 
   {{0x63a099c7,0x6d4099c8,0x6844008e,0x00000000}},	//   thon, igla, _янна, --, 
   {{0x248404b9,0x6e2899c9,0x63a099ca,0x7c3c0ba1}},	//   ćom_, kseb, uhon, àrri, 
   {{0x6e28037e,0x45240f22,0x62800009,0xd8740101}},	//   jseb, _পাঠক_, uxoo, _قمیت_, 
   {{0x6e28151c,0x20640640,0x62800014,0xa088611f}},	//   dseb, еђив, rxoo, зсиз_, 
   {{0x63a099cb,0x6d4003ac,0x64a40a5b,0xf3ec0117}},	//   phon, dgla, _џаба, _вӣ_, 
   {{0x6e280158,0x7bc400df,0x6d400153,0x63a001a9}},	//   fseb, _ĉiuo, egla, qhon, 
   {{0x6d403677,0x6e2899cc,0x00000000,0x00000000}},	//   fgla, gseb, --, --, 
   {{0x7c2899cd,0x3d9499ce,0x9cc87177,0xa06899cf}},	//   tsdr, тиор, зыма_, _наза_, 
   {{0x7c285cf5,0xdcb80801,0xd1940375,0x6e2802d0}},	//   usdr, ящи_, _רכבי_, aseb, 
   {{0x7c2899d0,0x6e282ad1,0x6d4099d1,0x2d980036}},	//   rsdr, bseb, agla, ëser_, 
   {{0x61f899d2,0x4e9099d3,0x7c28319f,0x6d4001e4}},	//   _kitl, _مشور, ssdr, bgla, 
   {{0xdb0c06ed,0x61f899d4,0x588400f7,0x39440793}},	//   micí, _jitl, ныба, üls_, 
   {{0xb90810f7,0xdb0c99d5,0x61f899d6,0xdbd402f6}},	//   _बर_, licí, _mitl, _pääh, 
   {{0x61f899d7,0x201c0421,0x2600007d,0x9f5c0129}},	//   _litl, _mwti_, _वंशी_, _buté_, 
   {{0x391481a0,0xdb0c99d8,0xb6c4941b,0x6ff00055}},	// [bfb0] _импр, nicí, төнд, _cācy, 
   {{0x7bdc99d9,0x28d005d7,0x61f899da,0x9f440156}},	//   llsu, _दुवि, _nitl, _vioù_, 
   {{0xe3bc05f3,0xcebc0118,0x38c83c5a,0xdbd40108}},	//   ğına_, ěřil_, _زادی_, _tääh, 
   {{0xe3bc1ae6,0x04c899db,0x6e2800a9,0x61f801ab}},	//   şına_, روني_, yseb, _aitl, 
   {{0x61f899dc,0x6d4099dd,0x60d899de,0x7bc40115}},	//   _bitl, ygla, _aytm, _ĉiul, 
   {{0x61f80232,0xdb0c0122,0x201c0142,0xa2b0002b}},	//   _citl, dicí, _bwti_, _अधर्, 
   {{0x61f899df,0xa06406bb,0x764c99e0,0x6e28010a}},	//   _ditl, ваща_, ltay, wseb, 
   {{0x6e280bc8,0x776c99e1,0x61f800c6,0x6d4099e2}},	//   tseb, ndax, _eitl, wgla, 
   {{0x61f81a7f,0x7ae80209,0x6f0899e3,0x6e2814dc}},	//   _fitl, ýetl, rcec, useb, 
   {{0x6e284020,0x6d4099e4,0x61f899e5,0x51840032}},	//   rseb, ugla, _gitl, _яуба, 
   {{0x6e2899e6,0xebe499e7,0xd6f8037e,0xdb0c054e}},	//   sseb, кооп, _kmコ_, dicâ, 
   {{0x764c99e8,0x6d4099e9,0x7bdc04cc,0x28d017e6}},	//   ktay, sgla, glsu, _दुषि, 
   {{0x764c03f0,0xdb0c8416,0x61f8016d,0x6d4017b5}},	//   jtay, ficâ, _yitl, pgla, 
   {{0x61f818f7,0x7bdc00af,0x7dd4004e,0xed5806a6}},	//   _xitl, alsu, bàsq, _цок_, 
   {{0xd8208a75,0x764c0076,0xe7b401d5,0x00000000}},	//   идри, etay, نمسد, --, 
   {{0x764c99ea,0x9f5c0ffb,0x66e4136b,0x97c002e8}},	//   ftay, _puté_, воба, айсе, 
   {{0x764c99eb,0x687802d3,0x28d00c93,0x9f440200}},	// [bfc0] gtay, _ኣዘዝቲ_, _दुरि, _shoë_, 
   {{0x6ff00882,0xdb0c0356,0x00000000,0x00000000}},	//   _vācy, cicâ, --, --, 
   {{0x764c99ec,0x61f899ed,0x9f5c0de2,0xdb0c0118}},	//   atay, _ritl, _wuté_, zicí, 
   {{0x61c8085c,0xd6f804ce,0x764c0014,0x61f899ee}},	//   ाक्ष, _cmコ_, btay, _sitl, 
   {{0x61f899ef,0x425499f0,0x7f9c0de2,0xdb0c00d8}},	//   _pitl, انتر, _séqo, licã, 
   {{0xd12c99f1,0xa3e01715,0xd1700075,0xdb0c012c}},	//   قمه_, _नीर_, لدىغ, vicí, 
   {{0x61f899f2,0x9f5c006a,0x7bdc019f,0x35c400c2}},	//   _vitl, _dutî_, îruk, _сарҳ, 
   {{0x61f8047e,0x25e409bb,0xdb0c61f8,0x9f440208}},	//   _witl, _जीती_, ticí, _khoé_, 
   {{0x61f899f3,0x60d8045f,0x00000000,0x00000000}},	//   _titl, _wytm, --, --, 
   {{0x61f83441,0x2ca8012c,0x66140022,0xdb0c7bb9}},	//   _uitl, _řada_, ipyk, ricí, 
   {{0xbb940815,0x00000000,0x00000000,0x00000000}},	//   ганщ, --, --, --, 
   {{0x764c99f4,0xd6f8037e,0x11f40137,0x00000000}},	//   ytay, _mmゲ_, _كتەگ, --, 
   {{0x764c0227,0x80d402f5,0xdb0c0356,0x4e180210}},	//   xtay, ধেশ্, ticâ, पीआई_, 
   {{0x7dd4067c,0x6db800d0,0x00000000,0x00000000}},	//   càsp, rňac, --, --, 
   {{0x60e400bc,0xa854151e,0x764c0113,0x3a380175}},	//   _úsmě, лерә, wtay, srsp_, 
   {{0x764c99f5,0xa3e043d1,0xbd8801b9,0xff1c00b5}},	//   ttay, _नील_, _آچکن_, fのih_, 
   {{0x8bb419d2,0x6a44013b,0x764c0198,0x47843abf}},	// [bfd0] _خصوص, _wɔfr, utay, шырб, 
   {{0x764c99f6,0x9f9800c5,0x851400d4,0x00000000}},	//   rtay, _hääl_, имує, --, 
   {{0x764c99f7,0x7bc400c8,0x66140124,0x00000000}},	//   stay, _ĉiuj, apyk, --, 
   {{0x764c99f8,0xdb0c004e,0x9f980037,0xd76410e0}},	//   ptay, nicà, _jääl_, _جەرى_, 
   {{0x764c1181,0x22280014,0x00000000,0x00000000}},	//   qtay, فٲنی_, --, --, 
   {{0x644899f9,0x00000000,0x00000000,0x00000000}},	//   àfic, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9f5c24ba,0xdcf800de,0x00000000,0x00000000}},	//   _dutï_, aktī, --, --, 
   {{0x439499fa,0xcdcc00f1,0x823415b4,0x00000000}},	//   _татс, يښت_, _پرقا, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb0c2b1d,0xd6f8037e,0x3014023a,0xcfa401d5}},	//   ficà, _mmケ_, _сдер, _ишди, 
   {{0xe454010f,0x5c0400ec,0x66140124,0x53d000cd}},	//   נירט_, دڪوٽ_, ypyk, तविश, 
   {{0xff040801,0xbe840133,0x5f400228,0x8e240124}},	//   _тяхн, _نجوو, _اچىل, _рфед, 
   {{0x64580139,0x00000000,0x00000000,0x00000000}},	//   _ätig, --, --, --, 
   {{0x98a099fb,0x18a099fc,0x7c3c01ab,0x0ca801d5}},	//   бире, барм, àrrt, _ютди_, 
   {{0xdb0c0798,0xa3e00764,0x00000000,0x00000000}},	//   ricã, _नीं_, --, --, 
   {{0xe57809ac,0xa6e499fd,0x4424007f,0xdb0c00d8}},	// [bfe0] нза_, ужал, _ňm_, sicã, 
   {{0xd6f8037e,0xe3bc029f,0x66140024,0x00000000}},	//   _cmケ_, ğıma_, rpyk, --, 
   {{0xdb0c7917,0xe3bc050e,0x43b40588,0x66148943}},	//   licá, şıma_, аӡар, spyk, 
   {{0xa22899fe,0x661499ff,0x7bc400df,0x1414007b}},	//   ежда_, ppyk, _ĉiuk, اينة_, 
   {{0xc5f83419,0xdb0c04d4,0x828412d7,0x27f000ad}},	//   _аға_, nicá, шқад, mmyn_, 
   {{0x20681586,0x67243c56,0x27f000ad,0x00000000}},	//   ешип_, _hekj, lmyn_, --, 
   {{0x66049a00,0xdd380311,0x6ab09856,0xd24c00d1}},	//   _hukk, _lăţi, ीपुर, قچە_, 
   {{0x656c9a01,0x6724003e,0xe2a805d9,0xb35404fb}},	//   _habh, _jekj, _ٻارن_, _نیما_, 
   {{0x66049a02,0x244c0232,0x656c9a03,0x27f0062c}},	//   _jukk, lým_, _kabh, imyn_, 
   {{0x66049a04,0x656c9a05,0xdb0c9a06,0x67240174}},	//   _mukk, _jabh, dicá, _lekj, 
   {{0x244c076f,0x660400ed,0x656c0a68,0x5f449a07}},	//   ným_, _lukk, _mabh, _منال, 
   {{0x656c9a08,0xdb0c1ded,0x6724151c,0x6ab09a09}},	//   _labh, ficá, _nekj, ीपूर, 
   {{0x66049a0a,0x244c0122,0x4fc00131,0x27f00af9}},	//   _nukk, hým_, _ھەۋە, dmyn_, 
   {{0x244c278a,0x656c9a0b,0xdb0c05d5,0x27f00076}},	//   kým_, _nabh, sicà, emyn_, 
   {{0xef1000c6,0xddc0151c,0x67249a0c,0x25b8009f}},	//   _טּْ_, _krož, _bekj, dipl_, 
   {{0x6604102c,0x244c02fb,0x656c0009,0xb7c4009e}},	//   _bukk, dým_, _aabh, ্ষ্ট, 
   {{0x35b49a0d,0x67249445,0x9f5c9a0e,0x644c013d}},	// [bff0] абар, _dekj, _kutâ_, _aqbi, 
   {{0x656c9a0f,0x66049a10,0x27f0062c,0xfaf80024}},	//   _cabh, _dukk, amyn_, žūs_, 
   {{0x656c9a11,0xddc0151c,0x67240fac,0x66040108}},	//   _dabh, _orož, _fekj, _eukk, 
   {{0x93249a12,0x66049a13,0x656c1552,0x6724002d}},	//   اران, _fukk, _eabh, _gekj, 
   {{0x66041418,0x9204005f,0x656c9a14,0x78a000cc}},	//   _gukk, klāš, _fabh, ølvf, 
   {{0x656c0ea3,0x672405be,0x244c02fb,0x3d0000e1}},	//   _gabh, _zekj, bým_, ोडों_, 
   {{0x34947a8d,0xddc002fb,0x660404fd,0x823457d4}},	//   _тавр, _brož, _zukk, _ۇرلا, 
   {{0x656c0944,0x66049a15,0x83f801af,0x00000000}},	//   _zabh, _yukk, _бесс_, --, 
   {{0x66040429,0xddc03f99,0xbf8800d1,0x00000000}},	//   _xukk, _drož, ائىل_, --, 
   {{0x463c008f,0x2d94322c,0xed58033a,0x41e40153}},	//   געזע, ррис, њон_, _ліха, 
   {{0xa17800c8,0x65680b21,0xc1042984,0xe7f800bc}},	//   _שטעט, ôfhi, _اومي, ्दमा_, 
   {{0x765c4240,0xddc002d5,0xdb0c65fa,0xdd38054e}},	//   _opsy, _grož, ticá, _păţi, 
   {{0x7ff4902e,0x67249a16,0x27f00076,0xbcfc0124}},	//   _اسلا, _rekj, vmyn_, teĩc, 
   {{0xdb0c9a17,0x672406d1,0x5e5400c8,0x1d040117}},	//   ricá, _sekj, _כינע_, _кеши_, 
   {{0x656c9a18,0xc0340092,0xaad000bc,0xa7b41d39}},	//   _rabh, _አይታወ, _सडकक, асај, 
   {{0x66049a19,0x244c8ea8,0x656c9a1a,0xdb0c00d8}},	//   _pukk, vým_, _sabh, picá, 
  
   {{0xa5249a1b,0x27f09a1c,0xa6849a1d,0x656c9a1e}},	// [c000] имад, rmyn_, шлад, _pabh, 
   {{0x6498113e,0x244c0232,0x1a980bd9,0x656c014f}},	//   ктер_, tým_, _סייע, _qabh, 
   {{0x67240008,0x64c40150,0xe7389a1f,0x656c7ab2}},	//   _tekj, جيال, _иен_, _vabh, 
   {{0x66049a20,0xe6449a21,0x656c2a6c,0x244c04bf}},	//   _tukk, _кемп, _wabh, rým_, 
   {{0x656c50c2,0xf1a89a22,0x66049a23,0x98a0005f}},	//   _tabh, گانه_, _uukk, majā_, 
   {{0xfe0807ae,0x7ae80209,0x98a0005f,0xe5a400f7}},	//   _nữa_, ýeti, lajā_, _тиги, 
   {{0xf1a85d35,0x1fa40019,0xddc09a24,0x6db802fb}},	//   دانه_, ириг, _prož, tňan, 
   {{0x98a0005f,0x6264198a,0xdef846e5,0x00000000}},	//   najā_, _پارق, кып_, --, 
   {{0xe1f89a25,0x84c4052f,0xfe08001e,0x61449a26}},	//   _ага_, _тәҡд, _bữa_, _веза, 
   {{0x194c00b5,0xfe080051,0x78a801e4,0x6db80419}},	//   _ｃａｄ_, _cữa_, ŝevi, sňan, 
   {{0x98a0005f,0x06c400eb,0x42a401ee,0x00000000}},	//   kajā_, ্ধটি, _туңғ, --, 
   {{0x44449a27,0x9ff800c6,0xb0b801c0,0xdb0801b9}},	//   iu_, _شراء_, _суух_, کزگه_, 
   {{0x98a000b8,0xbe140472,0x00000000,0x00000000}},	//   dajā_, _اوتع, --, --, 
   {{0x1cb800c6,0xfcc40022,0x98c401b9,0x6e3c01d3}},	//   _لاعب_, _гәмм, асбл, ásbe, 
   {{0xa3d49a28,0xad640451,0xddc0033f,0x06b400eb}},	//   हवा_, _دانه, _mroż, _ঝুলি, 
   {{0x98a0005f,0x4c100066,0x00000000,0x00000000}},	//   gajā_, _ببوس, --, --, 
   {{0x9f5c026c,0x0a941086,0x00000000,0x00000000}},	// [c010] _mutà_, _маъю, --, --, 
   {{0xdee802d3,0xdce8009b,0xd4989a29,0xcc3000c7}},	//   _ጅግና_, _lafč, кре_, _ухәы, 
   {{0x44449a2a,0x78a005ac,0x7874132f,0x98a000de}},	//   gu_, ølvd, _اُجا, bajā_, 
   {{0xdfc4099f,0x9f5c19f5,0x98a00171,0x00000000}},	//   _ري_, _nutà_, cajā_, --, 
   {{0x44449a2b,0x399c026c,0x91b401b9,0xc2440006}},	//   au_, _aìsi_, аҳат_, жнік, 
   {{0xdca406d5,0x9f5c3b7b,0xcad8011a,0x48741bf4}},	//   _فى_, _ottó_, בודת_, _ادیس, 
   {{0x9f5c004e,0xddc0033f,0xa3e000af,0xfe080208}},	//   _butà_, _droż, _नीक_, _rữa_, 
   {{0xfe080016,0xddc0031c,0x73c4030c,0x720430cd}},	//   _sữa_, _eroż, _ايرم, _هورم, 
   {{0xc8e40034,0x25ec000d,0xeb9808ca,0xee380114}},	//   _गर्म_, _अठमी_, ҳин_, ћно_, 
   {{0x98a000de,0xddc0012d,0x00000000,0x00000000}},	//   zajā_, _groż, --, --, 
   {{0x6ab09a2c,0x41740d1f,0xfe08004d,0x00000000}},	//   ीप्र, _باقس, _vữa_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xed58152d,0x44449a2d,0x98a01c52,0x1ab001a9}},	//   _бол_, zu_, vajā_, збўя, 
   {{0x44449a2e,0x9f4001f4,0x1c00000d,0x00000000}},	//   yu_, ökö_, _रूकल_, --, 
   {{0x44449a2f,0xe7389a30,0x18a0128d,0x98a09a31}},	//   xu_, лев_, парм, tajā_, 
   {{0x9f5c011f,0x4524009e,0x7ee400db,0xad400228}},	//   _kutá_, _পাইক_, _اكۇن, _بۉگۉ, 
   {{0x44449a32,0x98a00f40,0x00000000,0x00000000}},	// [c020] wu_, rajā_, --, --, 
   {{0x6b949a33,0xe968014b,0x00000000,0x00000000}},	//   _hoyg, _саол_, --, --, 
   {{0x44449a34,0xe1f89a35,0x69dc00b4,0x7ae8005f}},	//   uu_, ңге_, _ikpe, ļete, 
   {{0x6b94036b,0x78a09a36,0x6db80419,0x7348003b}},	//   _joyg, ølve, dňam, ичів_, 
   {{0x44449a37,0x454400aa,0xddc0025c,0x6b940162}},	//   su_, _ورسې, _proż, _moyg, 
   {{0x44449a38,0xa97800c8,0xd6f800b5,0x6b94022e}},	//   pu_, ראַכ, _cmサ_, _loyg, 
   {{0x9f5c01f1,0x69dc0521,0x7028010b,0x55b8011a}},	//   _autá_, _mkpe, ахың_, _עמלו, 
   {{0x6b940455,0x00000000,0x00000000,0x00000000}},	//   _noyg, --, --, --, 
   {{0x63a09a39,0x6284151c,0x9f5c08e5,0xddc000f3}},	//   mkon, _škof, _vutà_, _asoš, 
   {{0x22440280,0x69dc02e3,0x236400df,0x9f5c02f0}},	//   muok_, _nkpe, leoj_, _dutá_, 
   {{0xd12c2264,0xcb043323,0x63a09a3a,0x6b949a3b}},	//   _سمن_, रखंड_, okon, _boyg, 
   {{0x63a09a3c,0xd90c14c3,0x69dc585b,0x236400df}},	//   nkon, کید_, _akpe, neoj_, 
   {{0x63a09a3d,0xddc000da,0xada00589,0x6b94022c}},	//   ikon, _esoš, ãºch, _doyg, 
   {{0x6ee49a3e,0xf98831ed,0x63a09a3f,0x83080327}},	//   _بسمل, جنسي_, hkon, _ཆུའུ_, 
   {{0x63a09a40,0x97a49a41,0x8d709a42,0xdb0c0598}},	//   kkon, брал, _راوا, ticä, 
   {{0x69dc00b4,0xaad8242e,0x6b949a43,0x22443f1b}},	//   _ekpe, _युवक, _goyg, kuok_, 
   {{0x69dc0418,0x78a003d4,0x7bcc9a44,0x236400df}},	// [c030] _fkpe, ølvb, _ijau, deoj_, 
   {{0x7aec152d,0xec08001e,0x22440024,0x49740500}},	//   _izat, _mến_, duok_, _ельс, 
   {{0x23640115,0x6b9401a9,0xf79400c0,0x8d58011a}},	//   feoj_, _yoyg, _данэ, רכבי, 
   {{0x63a09a45,0x85c40075,0x756401ed,0x33580276}},	//   gkon, يغەم, _ڈیرہ_, радэ_, 
   {{0xc8c804fb,0xec0801fb,0x95c82c25,0x00000000}},	//   _نوین_, _nến_, _бува_, --, 
   {{0x7aec0161,0x63a026bb,0x7bcc0171,0x6db800d7}},	//   _mzat, akon, _ljau, tňam, 
   {{0x236400df,0x0fe0004e,0x00000000,0x00000000}},	//   beoj_, пөдү, --, --, 
   {{0x63a09a46,0x22441c06,0xec08001e,0x7bcc0066}},	//   ckon, buok_, _bến_, _njau, 
   {{0x7aec887b,0xa3e00574,0x6db80419,0x313401f0}},	//   _nzat, _नीट_, sňam, _меар, 
   {{0x6b940afb,0x40a89a47,0x7bcc005b,0xec080208}},	//   _soyg, ръән_, _ajau, _dến_, 
   {{0x7aec9a48,0x6b9401b9,0x6b645211,0x7bcc0153}},	//   _azat, _poyg, окна, _bjau, 
   {{0xf9881203,0x79846b5a,0x7d1c1d89,0x7f9c06af}},	//   _בר_, _anhw, ırsa, _béqu, 
   {{0x7bc4008f,0x7fe80212,0x7aec012d,0x62840241}},	//   _ĉiut, _уєфа_, _czat, _àkot, 
   {{0xddc0000a,0x7aec9a49,0xfd940023,0x2364010f}},	//   _tsoš, _dzat, _ይፈልጦ_, zeoj_, 
   {{0x63a06b07,0x27949a4a,0xfd44009d,0x00000000}},	//   ykon, ошар, _хэчн, --, 
   {{0x2244089c,0xec08001e,0x9f44001e,0x7f9c0100}},	//   yuok_, _yến_, _khoá_, _féqu, 
   {{0x63a09a4b,0xf1a81cd2,0xb0600139,0x6db800d7}},	// [c040] vkon, कसान, _şälg, vňaj, 
   {{0x5584004e,0x00000000,0x00000000,0x00000000}},	//   обум_, --, --, --, 
   {{0x99840311,0x6db800d0,0x236401e4,0x00000000}},	//   şiţa_, tňaj, teoj_, --, 
   {{0x7bcc005a,0x22440e3b,0x35c800c7,0x626400d1}},	//   _xjau, tuok_, агӡо_, قاتق, 
   {{0x63a09a4c,0x7f9c004e,0x236400df,0x6db80419}},	//   rkon, _xéqu, reoj_, rňaj, 
   {{0x22444f73,0x236400df,0xd1c424fc,0x00000000}},	//   ruok_, seoj_, олче_, --, 
   {{0x62849a4d,0x63a09a4e,0xec08004d,0x2244005a}},	//   _škod, pkon, _sến_, suok_, 
   {{0xe2980953,0x20009a4f,0x212c045f,0xa3e01414}},	//   _каб_, öki_, safh_, _नीच_, 
   {{0x9f440051,0x98a0012d,0x00000000,0x00000000}},	//   _choá_, mają_, --, --, 
   {{0xdd9856ff,0x161c23ef,0x7bcc045f,0x6e3c01ed}},	//   рши_, मीटर_, _sjau, ásba, 
   {{0x7f9c9a50,0x7aec514a,0x7bcc0006,0xa0c412ea}},	//   _séqu, _szat, _pjau, _بياو, 
   {{0xdef80228,0x7bc4010f,0x9a849a51,0x7f9c0129}},	//   _кыл_, _ĉius, оугл, _péqu, 
   {{0x93f8010f,0x98a40427,0x00000000,0x00000000}},	//   ילטי, čiča_, --, --, 
   {{0x7aec0306,0xc9849a52,0xd5f001ec,0x981401e2}},	//   _vzat, муси, гiнг, قبرا, 
   {{0x98a00034,0x7aec0327,0xa3d89a53,0xdc280244}},	//   kają_, _wzat, ठका_, _ئسته_, 
   {{0x7bcc9a54,0x8bc40220,0x98a0033f,0xbcfc00e4}},	//   _ujau, _осыд, jają_, neĩm, 
   {{0x7aec9a55,0x7bdc9a56,0x98a0068f,0x41bc085c}},	// [c050] _uzat, mosu, dają_, ्चास, 
   {{0x386005b1,0x58849a57,0x4ac82144,0xd1cc0092}},	//   _tphr_, _дыма, रपरव, ባበት_, 
   {{0x13689a58,0x331800d3,0x94a800ec,0x00000000}},	//   ишди_, біля_, جاءِ_, --, 
   {{0x7bdc9a59,0x37240135,0x98a00034,0xe91800e5}},	//   nosu, _འབྲལ_, gają_, _پریڈ_, 
   {{0x38c89a5a,0x167000d1,0x787400bc,0x64580166}},	//   _خاکی_, _юқар, bývá, _ätin, 
   {{0x59d84f71,0x3a280051,0x00000000,0x00000000}},	//   णविर, _mwap_, --, --, 
   {{0x7bdc9a5b,0x417401d5,0xd1cc0023,0x98a0012d}},	//   kosu, بانس, እኽቱ_, bają_, 
   {{0x3b080455,0x98a0033f,0x7bdc036e,0x2848010f}},	//   _ngaq_, cają_, josu, צעפּ, 
   {{0xed589a5c,0x116400f1,0xa2a010eb,0x7bdc9a5d}},	//   боп_, _ولری_, _कॅप्, dosu, 
   {{0xdc100ac1,0x0c900023,0x00000000,0x00000000}},	//   _aşın, _ክመርጽ_, --, --, 
   {{0x320c02fa,0xed580046,0x3a280784,0x7bdc9a5e}},	//   _huey_, _ғой_, _awap_, fosu, 
   {{0xd1cc069c,0x7bdc9a5f,0x332c0694,0x320c05b1}},	//   እኽቲ_, gosu, _jeex_, _kuey_, 
   {{0xa90801a9,0x3a98023a,0x320401ef,0xbea801f7}},	//   _faоl, отрю_, _kily_, _وهمن_, 
   {{0xa9a401c0,0x98a0033f,0x332c058a,0x9f5c0139}},	//   чигд, zają_, _leex_, _putç_, 
   {{0x7bdc9a60,0xdce80421,0xa2a00073,0x8f5c01f3}},	//   bosu, _tafā, _कॅन्, _ቆሮንቶ, 
   {{0x7bdc9a61,0x332c1574,0x78a008fb,0x68f00432}},	//   cosu, _neex_, ølva, _ıkdı, 
   {{0x9660021f,0x32049a62,0x9bc801e2,0x00000000}},	// [c060] нкте, _oily_, _ددوې_, --, 
   {{0x98a00034,0xd5e00276,0x00000000,0x00000000}},	//   wają_, ежуи, --, --, 
   {{0x99980302,0x98a0033f,0xdbd401f4,0x00000000}},	//   _הביט, tają_, räöl, --, 
   {{0x320c9a63,0x9a5404fb,0xec08004d,0x452400cc}},	//   _buey_, _بلیط_, _nếm_, _পাওক_, 
   {{0x62849a64,0x521002bf,0x98a00034,0xdb0c0077}},	//   _škob, едіт, rają_, ticú, 
   {{0x7bdc9a65,0x98a03f05,0xb64402dd,0x4f64035b}},	//   zosu, sają_, _ﺎﺩ_, ҧшым_, 
   {{0x7bdc9a66,0x332c9a67,0x3204013a,0xbcfc0124}},	//   yosu, _feex_, _dily_, teĩm, 
   {{0x27e00ac5,0x7bdc003a,0x82640137,0x00000000}},	//   _jkkn_, xosu, _يۇان, --, 
   {{0x7bdc098d,0x9f040d83,0x32040165,0x04c801e2}},	//   vosu, _ہواو, _fily_, _اوځي_, 
   {{0x3a28007f,0xe3e40345,0x6e340241,0x00000000}},	//   _rwap_, _بکڕن_, _ńgbà, --, 
   {{0x4438017a,0x44449a68,0x3a289a69,0x332c1bce}},	//   _jvr_, nr_, _swap_, _yeex_, 
   {{0x44449a6a,0x44389a6b,0xc5c4045e,0x332c1574}},	//   ir_, _mvr_, ্তিপ, _xeex_, 
   {{0x44449a6c,0x291c0790,0x3ae801b9,0x320400a2}},	//   hr_, ıtan_, تبدی_, _yily_, 
   {{0x7bdc0c69,0x44449a6d,0x44380175,0x8eb09498}},	//   sosu, kr_, _ovr_, _سەپت, 
   {{0x7bdc9a6e,0x44449a6f,0x44380477,0xec0801fb}},	//   posu, jr_, _nvr_, _yếm_, 
   {{0x44449a70,0x7bdc9a71,0x200405da,0xd7f8005b}},	//   dr_, qosu, _jioi_, суг_, 
   {{0x44389a72,0x20040093,0x3a280066,0xd5089a73}},	// [c070] _avr_, _mioi_, _uwap_, مغان_, 
   {{0x39149a74,0x44389a75,0x44449a76,0x332c1bce}},	//   _юмор, _bvr_, fr_, _seex_, 
   {{0x443804ce,0x44449a77,0x20049a78,0x6458008e}},	//   _cvr_, gr_, _oioi_, _ätil, 
   {{0x32040030,0x44380f85,0x6e2c010e,0x00000000}},	//   _sily_, _dvr_, _çabg, --, 
   {{0xd2584dba,0x320c0204,0x78a001e6,0x3204219b}},	//   сце_, _quey_, älvf, _pily_, 
   {{0x444414ea,0x20040b23,0x44380161,0x332c1bce}},	//   br_, _aioi_, _fvr_, _weex_, 
   {{0x32040122,0x200401c4,0x91280150,0x82a40022}},	//   _vily_, _bioi_, _ۇساق_, _ҧшуе, 
   {{0x320406f2,0x00000000,0x00000000,0x00000000}},	//   _wily_, --, --, --, 
   {{0xc2c400c6,0x320406d9,0xa3d82c35,0x7bc40115}},	//   _كيفي, _tily_, ठकर_, _ĉiup, 
   {{0x2018004e,0x00000000,0x00000000,0x00000000}},	//   ípic_, --, --, --, 
   {{0xff5015fa,0x1b1c0154,0xbcfc0022,0x00000000}},	//   _څخه_, _ভয়ে_, neĩh, --, 
   {{0xff5000aa,0x2004001e,0x7e640356,0x00000000}},	//   _مخه_, _gioi_, _ţipe, --, 
   {{0xcee89a79,0x2fcc0156,0x2d900036,0xdcf800d7}},	//   _اران_, mneg_, özes_, chtľ, 
   {{0x444402a4,0x6cc49a7a,0x2ca8012c,0x2b500472}},	//   yr_, _ойла, _řadu_, _wcyc_, 
   {{0x2a70070d,0xeb9800a8,0x2fcc0165,0x444401a9}},	//   _wsyb_, _мик_, oneg_, xr_, 
   {{0x2fcc9a7b,0x44449a7c,0x2700016b,0x25e401ad}},	//   nneg_, vr_, tɔn_, _जीजी_, 
   {{0x44449a7d,0xa6c801c0,0x2fcc0165,0xf1dc00cd}},	// [c080] wr_, цлаа_, ineg_, यवान, 
   {{0x44449a7e,0x2700013f,0x44384266,0xd1cc0092}},	//   tr_, rɔn_, _pvr_, ባበቅ_, 
   {{0x2fcc0ea0,0x69cc6b56,0x00000000,0x00000000}},	//   kneg_, mnbe, --, --, 
   {{0x44449a7f,0x2918010a,0x27001958,0x00000000}},	//   rr_, _hfpa_, pɔn_, --, 
   {{0xd99404d3,0x69cc332e,0x12142bd8,0x98a0033f}},	//   _رنێت_, onbe, وتوث_, daję_, 
   {{0x44389a80,0x69cc0ce2,0x44449a81,0x2fcc2f50}},	//   _tvr_, nnbe, pr_, eneg_, 
   {{0x2004316f,0x7f9c002e,0x15400114,0x00000000}},	//   _pioi_, _séqq, _јесм, --, 
   {{0x69cc9a82,0x2fcc05c7,0xd18001e0,0xad5000d1}},	//   hnbe, gneg_, еләй, ۇچىغ, 
   {{0x6a50016b,0x20040356,0x00000000,0x00000000}},	//   _fɛfɛ, _vioi_, --, --, 
   {{0x69cc9a83,0xc0bc010c,0x224400f3,0xb7d40ca8}},	//   jnbe, ሳሰል_, mrok_, _iṣel, 
   {{0x6f180142,0x22441155,0x6e2c025c,0xfc400092}},	//   _ffwc, lrok_, _ħabe, _ተደጋግ, 
   {{0x69cc9a84,0x201c8928,0x61e89a85,0x29189a86}},	//   enbe, _itti_, llfl, _afpa_, 
   {{0x8d709a87,0x224400e4,0xbf700150,0x69cc02d2}},	//   رایا, nrok_, _аққы, fnbe, 
   {{0x69cc0174,0xd8741272,0x3c0c0055,0x7d0400df}},	//   gnbe, وازب, _aśve_, _ĝisf, 
   {{0x22440d27,0x6f180042,0x00000000,0x00000000}},	//   hrok_, _yfwc, --, --, 
   {{0x22440518,0x3b0402b1,0x5fdc1fe5,0x291803b2}},	//   krok_, _pīpī_, मविल, _efpa_, 
   {{0x9f5c0085,0x3ea43e04,0x76b89a88,0x00000000}},	// [c090] _butú_, nymt_, члар_, --, 
   {{0x2fcc03bd,0x201c9a89,0x22449a8a,0x6e2c0240}},	//   zneg_, _otti_, drok_, _çabe, 
   {{0x201c013f,0xb7d40248,0x224400d0,0x78a00267}},	//   _ntti_, _aṣel, erok_, älvd, 
   {{0x63e40131,0x61e8002f,0x00000000,0x00000000}},	//   ىيلە, elfl, --, --, 
   {{0x201c9a8b,0x22440687,0xf904109c,0x2fcc0165}},	//   _atti_, grok_, _تأکی, vneg_, 
   {{0x776c0943,0x61e80158,0xd75801f7,0x00000000}},	//   leax, glfl, _اجھا_, --, 
   {{0x201c004e,0x213c004d,0x2fcc020c,0xfe080051}},	//   _ctti_, _ddth_, tneg_, _gữi_, 
   {{0x6e2c0003,0x2fcc05c7,0x61e801bf,0x92680798}},	//   _ħabb, uneg_, alfl, _мрза_, 
   {{0x201c9a8c,0x69cc9a8d,0xa0203110,0x2244003e}},	//   _etti_, ynbe, ööri, crok_, 
   {{0x2fcc9a8e,0x213c0051,0xaad8190c,0x00000000}},	//   sneg_, _gdth_, _युगक, --, 
   {{0x764c9a8f,0xada49a90,0x78a000cc,0x2fcc030a}},	//   huay, _җайл, ølvl, pneg_, 
   {{0x7f840491,0x764c0113,0x00000000,0x00000000}},	//   _للمن, kuay, --, --, 
   {{0x8ea401d3,0x764c9a91,0xf41400eb,0x00000000}},	//   _تصان, juay, াঠির_, --, 
   {{0xcdc00220,0x69cc01f5,0x00000000,0x00000000}},	//   _шалқ, unbe, --, --, 
   {{0x69cc9a92,0x7d0401e4,0x1d780092,0x224401a9}},	//   rnbe, _ĝisg, _ጠበቆች_, zrok_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x764c0588,0x65b001bf,0x00000000,0x00000000}},	// [c0a0] guay, _læhe, --, --, 
   {{0xe9380150,0x291800d8,0x21f000c7,0xe8f81d5b}},	//   _ةسةت_, _ufpa_, kâha_, _нлп_, 
   {{0xe3c4010b,0xa87c030d,0xe4d40137,0x00000000}},	//   _öñki_, _улнă_, رتئب, --, 
   {{0x22449a93,0x764c003e,0x78a001e3,0x00000000}},	//   trok_, buay, älve, --, 
   {{0x22440af9,0xc178010b,0x9f5c01e1,0x00000000}},	//   urok_, мҗа_, _tutú_, --, 
   {{0x201c1529,0x528002dd,0x2ca48605,0x224401c6}},	//   _ptti_, الوك, kyld_, rrok_, 
   {{0x2328713a,0x2244003e,0xd4649a94,0x386c01e4}},	//   _нови_, srok_, _пире_, ʈer_, 
   {{0x22449a95,0x6734950b,0xd5f002dd,0x00000000}},	//   prok_, nayj, гiзг, --, 
   {{0xbcfc00e4,0x3d94003b,0x00000000,0x00000000}},	//   neĩv, випр, --, --, 
   {{0x2ca4037e,0x3ea4007c,0x00000000,0x00000000}},	//   fyld_, rymt_, --, --, 
   {{0x201c198f,0xffd40032,0x1ed86a72,0x9ce40262}},	//   _utti_, _иҫкә_, _کباب_, эцил, 
   {{0x7d04008f,0x78a000cc,0x9f500241,0x00000000}},	//   _ĝisd, ølvm, _òyà_, --, 
   {{0x69d8012c,0x9ad002e3,0x6734010e,0x00000000}},	//   čten, jịta, dayj, --, 
   {{0x2ca40b21,0x7c9400c6,0x00000000,0x00000000}},	//   byld_, _للتص, --, --, 
   {{0xa8543c1a,0x00000000,0x00000000,0x00000000}},	//   керә, --, --, --, 
   {{0x20500023,0x00000000,0x00000000,0x00000000}},	//   _ዘይተረ, --, --, --, 
   {{0x78a001e6,0xc0bc00b7,0x2bc401ad,0x9a84004e}},	// [c0b0] älvb, ዳደሩ_, _लगता, _чуйл, 
   {{0x776c0165,0x00000000,0x00000000,0x00000000}},	//   seax, --, --, --, 
   {{0xd4089a96,0x776c0077,0x673403e3,0xf74c0240}},	//   ستام_, peax, bayj, _ዝጽውዕ, 
   {{0x79880198,0x9f5c0241,0x00000000,0x00000000}},	//   ɓewa, _tutù_, --, --, 
   {{0xdb0c5fd9,0xfe0807ae,0x764c9a97,0x491800bc}},	//   licó, _hữu_, quay, बुको_, 
   {{0x75a40022,0x216484cf,0x4a7c0677,0x00000000}},	//   _рымҧ, виши_, פרוב, --, 
   {{0xdb0c0077,0x6aa4000f,0x30749a98,0x987c013a}},	//   nicó, zykf, тулс, _méďa_, 
   {{0xd1b89a99,0xc6240eac,0x7e640356,0x6da400a8}},	//   _کارا_, _পিতা_, _ţipa, ӂиоа, 
   {{0xf1b8000a,0x78a00158,0x8e0400d1,0xfe080051}},	//   _etša_, ølvj, нмиң_, _lữu_, 
   {{0xac849a9a,0x00000000,0x00000000,0x00000000}},	//   вгол, --, --, --, 
   {{0x8e7000d1,0xeb380131,0xfe080051,0x5f740066}},	//   туқч, үзүш_, _nữu_, رمیس_, 
   {{0xdb0c0077,0x39401196,0x00000000,0x00000000}},	//   dicó, _adhs_, --, --, 
   {{0xed5813d7,0xc0bc0125,0x7c2416a3,0x2ca401bf}},	//   _жол_, ዳደር_, _čire, syld_, 
   {{0x2afc0882,0x2eac0cf1,0x6aa401bf,0x5a300108}},	//   रेषु_, टनीत, rykf, рнёт, 
   {{0xfe08004d,0x66140175,0xa2ec2c2e,0x00000000}},	//   _cữu_, wqyk, _जर्ज_, --, 
   {{0x6a849a9b,0xbcfc0588,0x57401188,0x00000000}},	//   _алиа, teĩv, инсб, --, 
   {{0xe5789a9c,0x69249a9d,0x67349a9e,0x6e3c0332}},	// [c0c0] мза_, _импа, rayj, ásbh, 
   {{0x9ad002e3,0xdb0c033f,0x78a0007c,0x00000000}},	//   rịta, bicó, älvc, --, 
   {{0x27400092,0x00000000,0x00000000,0x00000000}},	//   ጭበረበ, --, --, --, 
   {{0xdb0c0137,0x63045e79,0xa6f400d1,0xe7184754}},	//   licò, نوال, _үзүш, _زيست_, 
   {{0x92549a9f,0xa1149aa0,0x00000000,0x00000000}},	//   نشور_, نوشت, --, --, 
   {{0x201806ed,0xb7d40248,0xa08801d5,0x00000000}},	//   ípio_, _iṣal, дсиз_, --, 
   {{0x9f44030a,0x6e2c025c,0xe3580166,0x7e9801d9}},	//   _zhoù_, _ħaba, _ошаш_, کچار_, 
   {{0x53a01b74,0xe2849aa1,0xd384004e,0x03ec00cc}},	//   _касб, _илби, _ийсе_, _জংকী_, 
   {{0x53a000c2,0xe2a80531,0xe19401c0,0x33280005}},	//   _татб, _غارن_, _иржэ, ñaxe_, 
   {{0x657c9aa2,0x60240276,0x3c0c002b,0x6280679c}},	//   ndph, _аджа, _aśva_, mvoo, 
   {{0x645c9aa3,0x62809aa4,0xdb0c0005,0x20542c12}},	//   ntpi, lvoo, xicó, _штар, 
   {{0x5ba49aa5,0xe8140037,0x00000000,0x00000000}},	//   троз, _दूधा_, --, --, 
   {{0xec0801dc,0x62809aa6,0x3c3800bc,0xa06800c7}},	//   _nếu_, nvoo, _bývá_, _хаҵа_, 
   {{0x0a043306,0x6e2c0e51,0x645c8504,0x628001f4}},	//   لذَّ, _çaba, ktpi, ivoo, 
   {{0x62849aa7,0xb7d40241,0x62800076,0x00000000}},	//   _škol, _aṣal, hvoo, --, 
   {{0xdb0c9aa8,0x62809aa9,0x9bc40108,0xb6c4009d}},	//   ricó, kvoo, _шёлк, гөгд, 
   {{0x62800936,0x61f800af,0x992800cf,0xdb0c9aaa}},	// [c0d0] jvoo, _ohtl, _оюна_, sicó, 
   {{0xdc40012c,0x7aec3243,0x62809aab,0x39740108}},	//   _léče, _iyat, dvoo, _слоё, 
   {{0x7aec9aac,0x62806357,0x5470084c,0xddc000d7}},	//   _hyat, evoo, рвеӂ, _osož, 
   {{0x09d804c5,0x7aec9aad,0x62800549,0x657c0175}},	//   _দীপা, _kyat, fvoo, adph, 
   {{0xe8ec0801,0x6280744c,0x60d802d0,0x645c01f5}},	//   _ycлo_, gvoo, _axtm, atpi, 
   {{0xec0807ae,0x7aec9aae,0x61f8002f,0x95c80064}},	//   _hết_, _myat, _chtl, _цума_, 
   {{0xec0801dc,0x7534011c,0x7aec0a49,0x78a000cc}},	//   _kết_, _iezz, _lyat, ølvh, 
   {{0xec080016,0x7aec9aaf,0x75340432,0x35d4014b}},	//   _yếu_, _oyat, _hezz, _роҳё, 
   {{0xf1c825aa,0x60d80175,0x777c6140,0x75349ab0}},	//   _كورى_, _extm, _masx, _kezz, 
   {{0xdb0c004e,0xec080208,0x00000000,0x00000000}},	//   xicò, _lết_, --, --, 
   {{0x75349ab1,0x7aec9ab2,0xc10400c6,0xdee010cf}},	//   _mezz, _ayat, _نوكي, _қоши, 
   {{0x7aec9ab3,0xeb989ab4,0xeab89ab5,0xec080208}},	//   _byat, хим_, ейм_, _nết_, 
   {{0x7aec01aa,0xdb0c9ab6,0x80a800cc,0x6e44014b}},	//   _cyat, ticò, _কেপ্, _селз, 
   {{0xed589ab7,0x75349ab8,0x2bc405f9,0x66e40aac}},	//   _чок_, _nezz, _लगवा, ҳоба, 
   {{0x18645c81,0x7aec57d2,0x1d040131,0x62800810}},	//   лари_, _eyat, _йеши_, zvoo, 
   {{0x7aec009f,0x8ac80116,0x66e49ab9,0xdb0c00cf}},	//   _fyat, _ақма_, гоба, sicò, 
   {{0x75349aba,0x7aec9abb,0xa6849abc,0x09cc009e}},	// [c0e0] _bezz, _gyat, ылад, লকবা, 
   {{0x3ea00013,0x9ad001f2,0x645c0254,0x62809abd}},	//   _àite_, pịra, ttpi, vvoo, 
   {{0xe738005e,0x628001f5,0x64c49abe,0x24f40354}},	//   _пен_, wvoo, ديال, учар, 
   {{0x64480137,0x645c3a52,0x62800373,0xd24c004b}},	//   àfiq, rtpi, tvoo, ړنه_, 
   {{0x645c9abf,0x75340165,0x3688024c,0x00000000}},	//   stpi, _fezz, _исён_, --, 
   {{0x62807890,0x91e00a8f,0x5a14008f,0x9f5c02f0}},	//   rvoo, боче, אקסן_, _dutý_, 
   {{0x98a49ac0,0x62809ac1,0xf1a89ac2,0x35c4016c}},	//   čića_, svoo, خانه_, _тарҳ, 
   {{0xc0d0001f,0x75340083,0x78a09ac3,0x61f80334}},	//   _እኩል_, _zezz, ølvi, _whtl, 
   {{0x600c02e2,0xd0040063,0xfe70030f,0x660c0064}},	//   fòmè, ћење_, تگا_, _kibk, 
   {{0x7aec015c,0x61b00202,0x660c025c,0x60d89ac4}},	//   _ryat, _دەتا, _jibk, _txtm, 
   {{0x7aec9ac5,0x660c031c,0x60d80175,0x7bf80818}},	//   _syat, _mibk, _uxtm, кнор_, 
   {{0x7aec9ac6,0x00000000,0x00000000,0x00000000}},	//   _pyat, --, --, --, 
   {{0x628401a6,0xec080208,0xfe780107,0xbcfc00c7}},	//   _škoj, _rết_, _рӯй_, teĩs, 
   {{0x7aec9ac7,0x660c031c,0x00000000,0x00000000}},	//   _vyat, _nibk, --, --, 
   {{0xb7c407dd,0xf8b80184,0x7aec9ac8,0x69b405f9}},	//   арақ, төп_, _wyat, _उतरी, 
   {{0x75349ac9,0x7c286c97,0x7aec9aca,0xc0440023}},	//   _sezz, mpdr, _tyat, _ከይሰል, 
   {{0x75349acb,0xec08001e,0x80a804c5,0x7aec9acc}},	// [c0f0] _pezz, _vết_, _কেম্, _uyat, 
   {{0xd6f8037e,0x7c28005c,0x00000000,0x00000000}},	//   _blゲ_, opdr, --, --, 
   {{0x660c01af,0x75349acd,0x588462eb,0xec080016}},	//   _dibk, _vezz, _сыпа, _tết_, 
   {{0xb6c40f78,0x7534002d,0xf1ec033f,0x00000000}},	//   _көзд, _wezz, _चीज़_, --, 
   {{0x753404cc,0x00000000,0x00000000,0x00000000}},	//   _tezz, --, --, --, 
   {{0x64489ace,0xef30001f,0x764c9acf,0x660c2b5d}},	//   áfic, _በኢኮኖ, mray, _gibk, 
   {{0xe87802d3,0x764c03ac,0x41980c75,0x2bc400c5}},	//   _ብፍጹም_, lray, امىڭ_, _लगला, 
   {{0x660c0010,0x764c0067,0x20d000f7,0x98a4013a}},	//   _zibk, oray, تقىس, _žně_, 
   {{0x764c9ad0,0x9f5c00dd,0x3c0c00b8,0x7d0401e4}},	//   nray, _autó_, _aśvo_, _ĝisa, 
   {{0x5e540edf,0x660c0135,0x37d800cc,0x00000000}},	//   گلیس_, _xibk, _ভীমৰ, --, 
   {{0xab2874e9,0x764c9ad1,0x00000000,0x00000000}},	//   кона_, hray, --, --, 
   {{0x6a849ad2,0x764c9ad3,0xe45400c8,0xbcfc0022}},	//   алма, kray, סירט_, teĩr, 
   {{0x764c0113,0x39400023,0x00000000,0x00000000}},	//   jray, _ንምዝካ, --, --, 
   {{0x764c9ad4,0x9f5c01d3,0x9ed40166,0x00000000}},	//   dray, _futó_, _әмәт_, --, 
   {{0x764c9ad5,0x660c01bf,0xdd8c00f1,0x7c64007b}},	//   eray, _ribk, _زوي_, _هايل, 
   {{0x764c9ad6,0x3ea001ab,0x00000000,0x00000000}},	//   fray, _àitc_, --, --, 
   {{0x65c49ad7,0x16a49ad8,0xb8ec9ad9,0x00000000}},	// [c100] абаа, авти_, _शे_, --, 
   {{0x9a3805d0,0x00000000,0x00000000,0x00000000}},	//   _שתיק, --, --, --, 
   {{0x764c01d9,0xe8f89ada,0x248400b0,0xdb0c0332}},	//   aray, _шло_, āomo_, mhcá, 
   {{0x764c9adb,0xa6c89adc,0xf3640220,0xd8d800d9}},	//   bray, _алма_, йтін, _יקיר, 
   {{0x3328094a,0x764c9add,0x14840046,0x660c031c}},	//   ñaxa_, cray, _ءﻣﺎﺟ, _tibk, 
   {{0x27f09ade,0x52800131,0x00000000,0x00000000}},	//   llyn_, زلىك, --, --, 
   {{0x64a49adf,0x40341064,0xd24c15bf,0x63780798}},	//   _тава, щейс, كچە_, _исар_, 
   {{0x27f09ae0,0xd12c0131,0x310400dc,0x5478011a}},	//   nlyn_, كمۇ_, षेधः_, _בטלו, 
   {{0x27f09ae1,0xddc002fb,0x23640115,0x00000000}},	//   ilyn_, _apoš, mfoj_, --, 
   {{0x23640115,0x27f07c8d,0x645800fd,0x80a800fe}},	//   lfoj_, hlyn_, _ätis, _কেণ্, 
   {{0x6e2800d8,0x27f09ae2,0xdb0c01e7,0x91b8011a}},	//   apeb, klyn_, dhcá, _שמבי, 
   {{0x764c0986,0xaca801d9,0x81a80154,0x00000000}},	//   yray, اپَے_, খোশ_, --, 
   {{0x680c01e4,0xddc09ae3,0x27f03c75,0xd1d80023}},	//   _aŝdo, _epoš, dlyn_, _ሕማቅ_, 
   {{0x26181533,0x394c0730,0x7c281f53,0x27f000ad}},	//   _बढ़ी_, ßes_, ppdr, elyn_, 
   {{0x0c7475a6,0x6de40014,0x764c9ae4,0xd90c0214}},	//   _نصيب_, _اسنٕ, wray, بید_, 
   {{0x764c9ae5,0x27f00368,0x4c980a1e,0xe7780116}},	//   tray, glyn_, _ישוע, ласә_, 
   {{0x764c9ae6,0x35b40117,0xc0440023,0x00000000}},	// [c110] uray, ббар, _ከይህል, --, 
   {{0xd50804a9,0x764c9ae7,0x27f0062c,0xa6e003b2}},	//   نغان_, rray, alyn_, ýðan, 
   {{0x764c9ae8,0xb7d80145,0x27f00042,0x22ac00ef}},	//   sray, _مودا_, blyn_, _lēkā_, 
   {{0x764c9ae9,0x27f003cb,0x78a00158,0x36d4008e}},	//   pray, clyn_, ølvu, _гомр, 
   {{0x59b80c5a,0x09340150,0x9f4800bc,0x764c544b}},	//   _उतार, _ارۋج, ámým_, qray, 
   {{0x7d0400df,0xe2949aea,0x34940024,0x21a008ca}},	//   _ĝisn, саш_, _лагр, зишм, 
   {{0x65b00217,0xdfcc00f1,0xd3781188,0x00000000}},	//   _mæhl, کيي_, _ича_, --, 
   {{0xec0801fb,0xae7801c0,0x09a41c15,0x52749aeb}},	//   _nếp_, гсох_, _ऐक्य, _پارز, 
   {{0xddc0151c,0x64580793,0x333c0327,0x20540166}},	//   _spoš, _ätir, mawx_, атөр, 
   {{0x333c9aec,0x6e289aed,0xbcfc0022,0x00000000}},	//   lawx_, rpeb, teĩp, --, 
   {{0xec080016,0x27f00363,0x31b80129,0xc0581cb8}},	//   _bếp_, ylyn_, _cèze_, _віч_, 
   {{0x333c031c,0x00000000,0x00000000,0x00000000}},	//   nawx_, --, --, --, 
   {{0x2fcc9aee,0x27f00363,0x2ef40063,0xfe70007b}},	//   mieg_, vlyn_, _уздр, _يده_, 
   {{0x2fcc9aef,0x49c801e0,0x27f00363,0xdb0401d3}},	//   lieg_, рһон_, wlyn_, émái, 
   {{0xddc0151c,0x65b01445,0x6ff8008f,0x9d7400db}},	//   _upoš, _dæhl, ָפּג, _دئنچ, 
   {{0x4914012c,0x2fcc0489,0x18640063,0x333c031c}},	//   _दलको_, nieg_, љати_, jawx_, 
   {{0x27f09af0,0x09c400c7,0x04f40154,0xc0dc1954}},	// [c120] rlyn_, _маиҟ, _জলের_, _ሕዋስ_, 
   {{0x8b08068f,0x27f01829,0x2fcc05c7,0x49940345}},	//   _cięż, slyn_, hieg_, _بیسر, 
   {{0x69cc9af1,0xa8840150,0x2fcc05c7,0x27f075d9}},	//   mibe, _الجى, kieg_, plyn_, 
   {{0xec0807ae,0xd36c007b,0xe244004b,0x2fcc031c}},	//   _xếp_, فهم_, مختي, jieg_, 
   {{0x2fcc715a,0x236401e4,0x00000000,0x00000000}},	//   dieg_, rfoj_, --, --, 
   {{0x91e09af2,0x248801ab,0x00000000,0x00000000}},	//   поче, _trbm_, --, --, 
   {{0xe4d856e1,0x7d0400df,0x2fcc0165,0x7c2401ef}},	//   _صورت_, _ĝiso, fieg_, _čiro, 
   {{0x69cc9af3,0x333c0007,0x9f400109,0x2fcc9af4}},	//   hibe, cawx_, ôkà_, gieg_, 
   {{0xfa240003,0x205002d3,0xdb0c00d8,0xfdb80229}},	//   _འཕེན_, _ዘይምር, nicô, илищ_, 
   {{0x69cc20ee,0xec0801fb,0xe16401e2,0x00000000}},	//   jibe, _sếp_, _ددري, --, 
   {{0x69cc9af5,0x2fcc9af6,0x61e8067c,0xd598010f}},	//   dibe, bieg_, mofl, אביל, 
   {{0xdef81f3b,0x5f749af7,0xdfd036e9,0x9e6404d3}},	//   _йыл_, _دائر, _عيش_, _هاتن, 
   {{0x7e680356,0x99d400ae,0xf1dc00cd,0x00000000}},	//   împă, متسا, यवचन, --, 
   {{0x69cc9af8,0x3d943461,0x61e89af9,0x8b080316}},	//   gibe, _фикр, nofl, _stří, 
   {{0xd768070e,0x00000000,0x00000000,0x00000000}},	//   лшад_, --, --, --, 
   {{0xba189afa,0x69cc017a,0x65b003cd,0xdb200267}},	//   _پيدا_, aibe, _wæhl, öräd, 
   {{0x61e803b2,0x00000000,0x00000000,0x00000000}},	// [c130] kofl, --, --, --, 
   {{0x69cc9afb,0x78a00183,0x61e801a6,0x2fcc05c7}},	//   cibe, ølvs, jofl, zieg_, 
   {{0x2fcc0369,0x333c025c,0x00000000,0x00000000}},	//   yieg_, tawx_, --, --, 
   {{0x7d0401e4,0xd764129d,0xd5a00271,0x8b0801ef}},	//   _ĝisl, _دەرى_, _کلسی, _utří, 
   {{0x2fcc0165,0x3f840135,0x333c025c,0xc2440024}},	//   vieg_, ddmu_, rawx_, знік, 
   {{0xdca49afc,0x3a280100,0xe9f401ec,0x61e801e4}},	//   _قى_, _mtap_, _اﺬ_, gofl, 
   {{0x2fcc9afd,0xf07401d3,0xa1540114,0x00000000}},	//   tieg_, تیاں_, цају_, --, 
   {{0x69cc37ea,0xef189afe,0x333c0327,0x92c400cc}},	//   zibe, шми_, qawx_, _উডী_, 
   {{0x2fcc9aff,0x69cc9b00,0x628432fe,0xaec44627}},	//   rieg_, yibe, _škov, юбил, 
   {{0x69cc9b01,0x2fcc9b02,0xace80b3b,0x00000000}},	//   xibe, sieg_, импа_, --, 
   {{0xf1b827c4,0x69cc9b03,0x3a289b04,0x2fcc9b05}},	//   _ntši_, vibe, _atap_, pieg_, 
   {{0x3a280649,0x69cc9b06,0xbe0400e5,0x00000000}},	//   _btap_, wibe, _ہونٹ, --, 
   {{0xd1d8044e,0x7ed400c0,0x00000000,0x00000000}},	//   _ሕማቕ_, _нішч, --, --, 
   {{0xbe0400e5,0x3ce0002b,0x00000000,0x00000000}},	//   _فونٹ, _śive_, --, --, 
   {{0x69cc9b07,0x3a289b08,0xa7a80861,0x426800b7}},	//   ribe, _etap_, аква_, _ሳይንስ_, 
   {{0x4424025c,0xdb0c0129,0x7a300022,0x61e803e0}},	//   _ċm_, ticô, ẽtav, zofl, 
   {{0x69cc9b09,0x78a000cc,0x00000000,0x00000000}},	// [c140] pibe, ølvr, --, --, 
   {{0x69cc0912,0x2ca8012c,0x2d84975e,0x24f49b0a}},	//   qibe, _řady_, ndle_, очер, 
   {{0x6b940953,0x64989b0b,0x61e80115,0x2d840009}},	//   _knyg, штар_, vofl, idle_, 
   {{0x6658030d,0xa024032e,0x00000000,0x00000000}},	//   _камă, hlöð, --, --, 
   {{0x7d0400df,0x569000c0,0x00000000,0x00000000}},	//   _ĝism, _жаўт, --, --, 
   {{0xb8646646,0x00000000,0x00000000,0x00000000}},	//   _بایو, --, --, --, 
   {{0x61e89b0c,0x2d840573,0xc5f40198,0x23d40022}},	//   rofl, ddle_, guɓe_, _дцар, 
   {{0x44449b0d,0x61e8427b,0x2d849b0e,0x00000000}},	//   ms_, sofl, edle_, --, 
   {{0xdef89b0f,0x5f90036b,0x44380142,0x80a803d4}},	//   шык_, зиқт, _hwr_, _কেশ্, 
   {{0x63a09b10,0x78a004f3,0x6b940432,0x127800df}},	//   ljon, älvk, _anyg, _דאמע, 
   {{0x3a28398e,0x6b840175,0xe814107c,0xca480046}},	//   _stap_, fdkg, _दंगा_, _ﺇﺫﺍ_, 
   {{0x69dc15ad,0x4f840014,0xe59c02dd,0x00000000}},	//   _ajpe, _وانہ, _ﺍﻷﺴﺭ_, --, 
   {{0x44449b11,0xd00c0345,0x63a077b9,0x7f4016b8}},	//   hs_, _شله_, ijon, mamq, 
   {{0x44449b12,0x63a09b13,0x44389b14,0x7f400381}},	//   ks_, hjon, _owr_, lamq, 
   {{0x44449b15,0x97a49b16,0x6e2c003d,0xd90c9b17}},	//   js_, орал, _ħabi, ضیح_, 
   {{0x656c00b8,0x7f409b18,0x63a00165,0xfd240244}},	//   _abbh, namq, jjon, _بوژێ, 
   {{0x44449b19,0x44389b1a,0x7bcc9b1b,0x3a280004}},	// [c150] es_, _awr_, _imau, _utap_, 
   {{0x95546e1d,0xdcf805d1,0xf1b80306,0x1dd8043e}},	//   تخرا, lktı, _kuše_, यचित, 
   {{0x44449b1c,0x443803cb,0x63a01798,0x69d80118}},	//   gs_, _cwr_, fjon, čtet, 
   {{0x7ea402b5,0x63a09b1d,0x44380368,0x656c01ab}},	//   _kōpā, gjon, _dwr_, _ebbh, 
   {{0x44449b1e,0x7984001f,0x7f409b1f,0x44383fd6}},	//   as_, _kahw, damq, _ewr_, 
   {{0x44449b20,0x79849b21,0x81c80212,0x63a00108}},	//   bs_, _jahw, огів_, ajon, 
   {{0x62849b22,0x63a09b23,0x79849b24,0xb7d401e1}},	//   _škot, bjon, _mahw, _aṣil, 
   {{0x63a0068f,0xee389b25,0x7bcc3495,0x7984047e}},	//   cjon, бни_, _nmau, _lahw, 
   {{0xd1489b26,0x798402d0,0x00000000,0x00000000}},	//   _نشان_, _oahw, --, --, 
   {{0x7bcc9b27,0x6b949b28,0x7984006f,0x7bdc003a}},	//   _amau, _snyg, _nahw, érun, 
   {{0x75240730,0x7f40003a,0x2d849b29,0xc31000cc}},	//   ichz, bamq, rdle_, হুদি_, 
   {{0x7bcc07ab,0x7f400393,0x00000000,0x00000000}},	//   _cmau, camq, --, --, 
   {{0x798405ba,0x44449b2a,0xdd8c04d3,0xeab001ed}},	//   _bahw, zs_, _ڕوو_, رٹس_, 
   {{0x63a0038f,0x7bcc9b2b,0x44449b2c,0xec7805c1}},	//   zjon, _emau, ys_, _гпк_, 
   {{0x44449b2d,0x79849b2e,0x63a001b9,0xf1b82625}},	//   xs_, _dahw, yjon, _guše_, 
   {{0x7d18010a,0xbb6800b5,0x00000000,0x00000000}},	//   _zgvs, _txtは_, --, --, 
   {{0x4444873b,0x44380112,0x63a00156,0xf6640139}},	// [c160] ws_, _swr_, vjon, метү, 
   {{0x79840223,0x63a00455,0x00000000,0x00000000}},	//   _gahw, wjon, --, --, 
   {{0x2918409c,0x63a000db,0x6d400194,0x7f40014b}},	//   _igpa_, tjon, iala, yamq, 
   {{0x6d409b2f,0x7f40003a,0x63a00165,0x00000000}},	//   hala, xamq, ujon, --, 
   {{0x44449b30,0x63a09b31,0x7f400393,0x06840b01}},	//   ss_, rjon, vamq, _юҳан, 
   {{0x63a03a70,0x6d409b32,0xe29802dd,0x44384159}},	//   sjon, jala, _қаз_, _twr_, 
   {{0x6d409b33,0x4444031c,0x7f4016b8,0x63a09b34}},	//   dala, qs_, tamq, pjon, 
   {{0xdef89b35,0x6d400363,0x78a00267,0x63a0022e}},	//   йып_, eala, älvi, qjon, 
   {{0x7f401730,0xf490001f,0x80cc0b67,0x00000000}},	//   ramq, _የሚሰጥ_, _थेरे, --, 
   {{0xf1a89b36,0xf1b816a3,0x7bcc9b37,0x7f409b38}},	//   _واله_, _puše_, _smau, samq, 
   {{0x79849b39,0x213c01c3,0x7f40003a,0x91800145}},	//   _rahw, _ieth_, pamq, _سۇيۇ, 
   {{0x79849b3a,0x670400b0,0x6d409b3b,0x201c0356}},	//   _sahw, _kōkī, aala, _iuti_, 
   {{0x6284145e,0x201c9b3c,0x22449b3d,0x7984006f}},	//   _âkod, _huti_, nsok_, _pahw, 
   {{0x6d409b3e,0x201c9b3f,0xd6d8052f,0x29180ac5}},	//   cala, _kuti_, ҡта_, _cgpa_, 
   {{0x213c57cf,0x88940323,0x201c0054,0xdc28036b}},	//   _meth_, нирх, _juti_, _استه_, 
   {{0x201c9b40,0x213c0013,0x22449b41,0x7984016b}},	//   _muti_, _leth_, ksok_, _wahw, 
   {{0x25a89b42,0x7bdc0158,0x7984047e,0xcb0800db}},	// [c170] _bobl_, mnsu, _tahw, _ىيىن_, 
   {{0x201c9b43,0x213c039a,0xd4989b44,0x75240112}},	//   _outi_, _neth_, йре_, uchz, 
   {{0x201c9b45,0x7bdc9b46,0x75241a80,0x224400d7}},	//   _nuti_, onsu, rchz, esok_, 
   {{0x96440323,0x7bdc9b47,0x213c00a9,0x22c000b0}},	//   _нэгд, nnsu, _aeth_, kōkī_, 
   {{0x6d409b48,0x213c0cfd,0x201c9b49,0x62849b4a}},	//   yala, _beth_, _auti_, _škor, 
   {{0x6d409b4b,0x25a8022e,0x7bdc17da,0x04c800f1}},	//   xala, _gobl_, hnsu, _کوفي_, 
   {{0x213c9b4c,0x201c9b4d,0xafe49b4e,0x00000000}},	//   _deth_, _cuti_, мокл, --, 
   {{0x201c9b4f,0x6d409b50,0x776c011f,0x2eb406a6}},	//   _duti_, wala, nfax, дсос, 
   {{0x201c0296,0x26dc016b,0x224401ed,0x2ee40276}},	//   _euti_, _ɛtoo_, csok_, ьжиг, 
   {{0x213c0393,0x6d400618,0x77f80034,0x81d40022}},	//   _geth_, uala, ंतुक_, _зоух, 
   {{0x201c9b51,0xded80023,0x32040419,0x00000000}},	//   _guti_, ኮይኑ_, _ihly_, --, 
   {{0x67040db6,0xb7d40055,0xeb980114,0xaa4401ec}},	//   _hōkū, _kṣul, цим_, мемл, 
   {{0x201c07ab,0x213c0165,0x00000000,0x00000000}},	//   _zuti_, _yeth_, --, --, 
   {{0x6d409b52,0x7bdc3d52,0xfde80220,0x00000000}},	//   qala, ansu, _едік_, --, 
   {{0x7bdc0175,0x776c031c,0x00000000,0x00000000}},	//   bnsu, ffax, --, --, 
   {{0x22440419,0x00000000,0x00000000,0x00000000}},	//   ysok_, --, --, --, 
   {{0x25a89a8e,0x3b040374,0xe9a40220,0x320401e3}},	// [c180] _pobl_, _pūpū_, _жапп, _ohly_, 
   {{0x6e2c247e,0xe4d402f2,0x00000000,0x00000000}},	//   _çabu, وتاب, --, --, 
   {{0x23480075,0x99980375,0x213c0240,0xba28065f}},	//   قلاپ_, _וביט, _reth_, _وسیم_, 
   {{0x201c94a7,0x32049b53,0x670400b0,0x22449b54}},	//   _ruti_, _ahly_, _pōkī, tsok_, 
   {{0x201c9b55,0x213c9b56,0x22441c06,0x25a801fa}},	//   _suti_, _peth_, usok_, _tobl_, 
   {{0xd12c9b57,0x201c9b58,0x213c0200,0xd17000d1}},	//   لمه_, _puti_, _qeth_, ندىغ, 
   {{0x232800d6,0x213c0076,0x201c6064,0x22449b59}},	//   _мови_, _veth_, _quti_, ssok_, 
   {{0x201c9b5a,0xd7b8010f,0x224400c0,0x00000000}},	//   _vuti_, ַציר, psok_, --, 
   {{0x452c031c,0x201c9b5b,0x213c08c2,0x7e640171}},	//   _ཧྥོར_, _wuti_, _teth_, _ģips, 
   {{0x201c9b5c,0x92301075,0x6e2c0135,0x00000000}},	//   _tuti_, _شىمش, _ħabt, --, 
   {{0x201c9b5d,0x00000000,0x00000000,0x00000000}},	//   _uuti_, --, --, --, 
   {{0x9f04004b,0x508400db,0x7bdc9b5e,0x7b8400d1}},	//   _قواو, _زامې, unsu, راجە, 
   {{0x7bdc000f,0x3ea00724,0x3328005a,0x9da802e8}},	//   rnsu, _çit_, ñaxi_, _мъка_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x20049b5f,0xa3bc000d,0x4d74011a,0x9f500241}},	//   _khoi_, इसा_, _חתול_, _òyó_, 
   {{0x50880055,0xf1b8139f,0x00000000,0x00000000}},	//   _jñāṃ_, _muša_, --, --, 
   {{0xdc000030,0xd5640212,0xcb0800db,0xb59401f0}},	// [c190] nčín, дтеп, _ۉيۉن_, ниаш, 
   {{0x8af811ca,0xf16c0150,0x00000000,0x00000000}},	//   _юныс_, _ﺴﻤﺎﺡ_, --, --, 
   {{0x645808fb,0x673401f5,0xf1b80219,0x6284560e}},	//   _åtil, bbyj, _nuša_, _škop, 
   {{0x20049b60,0x78a001e3,0x437401a9,0x00000000}},	//   _nhoi_, älvu, вушт, --, 
   {{0x9ad0063f,0x00000000,0x00000000,0x00000000}},	//   sịfa, --, --, --, 
   {{0xf1b81ebd,0x20049b61,0x6638010f,0x229016ac}},	//   _buša_, _ahoi_, _מעשׂ, الوس, 
   {{0x20040652,0xa5c00166,0x92bc0154,0xcdcc00f1}},	//   _bhoi_, _сөте, ঁপে_, یښت_, 
   {{0xc9189b62,0xee389b63,0x28d402ab,0x00000000}},	//   וחות_, пни_, _डेफि, --, 
   {{0x3d0c0490,0x38c400e8,0xde44004b,0x6e2c025c}},	//   डेसे_, _yëré_, فینو_, _ħabs, 
   {{0xd1b80533,0xacc800c7,0x320400d7,0xed50132f}},	//   _بارا_, згоз_, _uhly_, اھش_, 
   {{0xf1b80114,0x614400cf,0x6b6401c6,0xa3e4013a}},	//   _guša_, _سىنە, нкна, _पदम_, 
   {{0xdc0002f0,0x1ee8104c,0x00000000,0x00000000}},	//   bčín, _کوهی_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7d040115,0xed040220,0x39400171,0xd8400118}},	//   _ĝisv, _كوشپ, _cehs_, zečů_, 
   {{0xa2d41b76,0x26f89b64,0x6c74030d,0x00000000}},	//   _मेन्, ्ध्र_, _чулх, --, 
   {{0xd59800b5,0xd6f800b5,0x20040200,0x00000000}},	//   _hwと_, _inオ_, _xhoi_, --, 
   {{0x59b005f5,0xa6c82386,0x66040798,0x00000000}},	// [c1a0] _өөрс, члаа_, епаа, --, 
   {{0x39400036,0x273c004d,0x00000000,0x00000000}},	//   _gehs_, ắn_, --, --, 
   {{0x19b405e1,0x00c00ed1,0x7dc400db,0x78a001e3}},	//   _נפטר_, ﺭﺍﺗﺘ, _fòsf, älvt, 
   {{0xd8d400c8,0x28d4000d,0xe3f41291,0x00000000}},	//   _טויט_, _डेयि, رثاب, --, 
   {{0x20040cfd,0xf1b880b6,0x857400dd,0x9ad001f2}},	//   _rhoi_, _suša_, _لگائ, rịga, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x20049b65,0x657c0944,0xc5ec2c97,0x55e09b66}},	//   _phoi_, meph, जकीय_, _сорб, 
   {{0x645c9b67,0x657c9b68,0xd12c00d1,0x6e2c031c}},	//   mupi, leph, لمۇ_, _ħabr, 
   {{0x645c9b69,0xe19400c0,0x00000000,0x00000000}},	//   lupi, _пржэ, --, --, 
   {{0x62800430,0xa0a443a2,0x00000000,0x00000000}},	//   mwoo, _пазд, --, --, 
   {{0x62809b6a,0x645c9b6b,0x2004001e,0x394007c5}},	//   lwoo, nupi, _thoi_, _rehs_, 
   {{0x657c9b6c,0x62809b6d,0x50600020,0x600864c2}},	//   heph, owoo, _ፌዴሬሽ, _энем_, 
   {{0x62809b6e,0x657c9b6f,0xd6d800eb,0x28d419cc}},	//   nwoo, keph, _দর্প, _डेबि, 
   {{0xc9849b70,0x3c580276,0x00000000,0x00000000}},	//   луси, _жикэ_, --, --, 
   {{0x657c9b71,0x645c9b72,0x8d600640,0x6280045a}},	//   deph, jupi, _свје, hwoo, 
   {{0x62809b73,0x645c9b74,0x39400036,0x27f00009}},	//   kwoo, dupi, _wehs_, goyn_, 
   {{0x628001a4,0x00000000,0x00000000,0x00000000}},	// [c1b0] jwoo, --, --, --, 
   {{0x645c055a,0x78a001e6,0x657c5b12,0x62809b75}},	//   fupi, älvs, geph, dwoo, 
   {{0x645c9b76,0x628000e8,0x672000de,0xddc00b9b}},	//   gupi, ewoo, žoja, _opož, 
   {{0x62800cf9,0xccf0010f,0x00000000,0x00000000}},	//   fwoo, אכע_, --, --, 
   {{0x62809546,0x657c9b77,0x712400d1,0xf2680139}},	//   gwoo, beph, نىشم, филл_, 
   {{0x82349b78,0xe29407d5,0xf1c810fe,0x0a581ee0}},	//   ارنا, таш_, بوتى_, _ፋብሪካ, 
   {{0x62800449,0x0f380092,0x69a00073,0x00000000}},	//   awoo, _ያበረከ, खाती, --, 
   {{0x889c00c8,0x1ab00825,0x802405af,0xb4bc1b97}},	//   לבוי, ुनाथ, دروم, इनी_, 
   {{0xada40598,0x62800014,0xaf0400a7,0x00000000}},	//   вапл, cwoo, ъпил, --, 
   {{0x7dc401ab,0x65b0003b,0x3f9800b0,0x00000000}},	//   _nòsd, _hæhr, ērua_, --, 
   {{0xcee89b79,0x27f00198,0x27440024,0x3d0c0118}},	//   _کران_, yoyn_, lūnų_, डेले_, 
   {{0x7d040115,0x657c9b7a,0xeeb80139,0xab2800d4}},	//   _ĝist, zeph, _олеш_, ьома_, 
   {{0x657c1449,0x5ba001e0,0xb4bc00bc,0x43b80116}},	//   yeph, рһығ, इनु_, ﯦﺰﯨﺪ, 
   {{0xddc000bc,0x645c03f0,0x3e88008e,0x291c9b7b}},	//   _zpož, yupi, _чишү_, øta_, 
   {{0x18649b7c,0x645c005a,0x657c6605,0xaba8007b}},	//   кари_, xupi, veph, _يهتم_, 
   {{0x657c136f,0x645c0108,0xeb9866b4,0xe6c40066}},	//   weph, vupi, _ции_, پتري, 
   {{0xe6188811,0x62809b7d,0x657c03ac,0x7dc4007f}},	// [c1c0] дда_, xwoo, teph, _fòsd, 
   {{0x645c9b7e,0x28b80276,0x27f00100,0xc77400cf}},	//   tupi, _жумэ_, soyn_, _өтмө, 
   {{0x657c000a,0x62809b7f,0x00000000,0x00000000}},	//   reph, wwoo, --, --, 
   {{0x62809b80,0x93c81973,0x7dc401ab,0xe3b89b81}},	//   twoo, وانہ_, _iòse, ьбе_, 
   {{0x657c9b82,0x27440006,0x13280023,0xc2244d66}},	//   peph, gūnų_, _ብናጽነ, اکرو, 
   {{0x657c0831,0xf1b86767,0x332c0036,0xddc000e2}},	//   qeph, _dušo_, _efex_, _spož, 
   {{0x62800373,0x645c02d1,0xc0340114,0x00000000}},	//   swoo, qupi, ћниј, --, 
   {{0x62800042,0xfff8397a,0x291c05d1,0x27440064}},	//   pwoo, رکات_, ıtay_, būnų_, 
   {{0xd0040063,0x9e04004e,0xd354123b,0x00000000}},	//   њење_, кчол, _שימי_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x23b4033d,0xa3e40243,0x7d0401e4,0x1f64004e}},	//   _अकाद, _पदा_, _ĝiss, _акем, 
   {{0x30d800df,0x00000000,0x00000000,0x00000000}},	//   _אַנע, --, --, --, 
   {{0x99d49b83,0x5e600137,0x7dc400a3,0xd7601a4b}},	//   نتسا, _ئچبە, _pòsd, ینسی, 
   {{0x18700107,0x00000000,0x00000000,0x00000000}},	//   аҳоя, --, --, --, 
   {{0x8a189b84,0x7dc4067c,0xf868007b,0xdd9000fb}},	//   торс_, _còse, عمري_, _баҙы, 
   {{0x7dc4007f,0x00000000,0x00000000,0x00000000}},	//   _dòse, --, --, --, 
   {{0x644c1511,0xfc3c0092,0xf598011c,0x00000000}},	// [c1d0] _avbi, _የሰጠው, нващ_, --, 
   {{0x7dc40100,0x27440006,0x9ad001f2,0x6a980a1e}},	//   _fòse, vūnų_, pịba, _נשתנ, 
   {{0x7e6007b4,0xb4bc0316,0x161c02ab,0xf1b80010}},	//   hump, इने_, _बढकर_, _sušo_, 
   {{0xf1b81ebd,0x21641086,0xb6c4008e,0xdfc491e8}},	//   _pušo_, ҳиши_, _йөзд, _طي_, 
   {{0x7e609b85,0x8284282b,0x59a4146c,0xb6c400ee}},	//   jump, لجول, खापर, _сөвд, 
   {{0x7e609b86,0x764c9b87,0xbf9401d3,0x21641a71}},	//   dump, msay, یگنڈ, гиши_, 
   {{0x30740323,0x45d49b88,0x764c9b89,0x6ff405f5}},	//   уулс, _торс, lsay, лчих, 
   {{0xae880228,0x09e0041c,0x764c0009,0xf1b80064}},	//   ебиз_, _नद्य, osay, _tušo_, 
   {{0x7e608b14,0x31342038,0x00000000,0x00000000}},	//   gump, _безр, --, --, 
   {{0xc2e407d6,0x764c9b8a,0x41749b8b,0x00000000}},	//   _тўси, isay, _نامس, --, 
   {{0x764c0455,0xb03400d8,0x3d0807b7,0x00000000}},	//   hsay, _снеш, _हरणे_, --, 
   {{0x7e6001f0,0x764c9b8c,0x00000000,0x00000000}},	//   bump, ksay, --, --, 
   {{0x7e609b8d,0x764c0113,0xed5858e5,0x7e640108}},	//   cump, jsay, _зол_, _äipp, 
   {{0x7c6401d5,0x764c7d85,0x7dc400cf,0x00000000}},	//   دایل, dsay, _ۅتۉك, --, 
   {{0xbca800c6,0xfca80832,0x61380139,0x49041e4a}},	//   _لديك_, _لايو_, _hälâ, рүнг, 
   {{0xab646bed,0xd8840014,0x7c640244,0x00000000}},	//   _свил, چھێن_, _ئاول, --, 
   {{0x764c7004,0x27e400c8,0xd7e40798,0x00000000}},	// [c1e0] gsay, ĵon_, умте_, --, 
   {{0x64a49b8e,0x00000000,0x00000000,0x00000000}},	//   лаза, --, --, --, 
   {{0x5a140375,0xb9080183,0x764c058a,0xdb0c0332}},	//   _תקין_, _বৰ_, asay, bhcó, 
   {{0x23289b8f,0x764c9b90,0x7e600bc9,0xddc00034}},	//   ходи_, bsay, yump, _spoż, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x644c01fa,0x7e6000b5,0xa08806d3,0x64480413}},	//   _tvbi, vump, есиз_, áfis, 
   {{0x403407d8,0x3fc404a9,0x7e609b91,0x82340345}},	//   шейс, ириғ, wump, ارچا, 
   {{0x7e609b92,0xa8e001fb,0x00000000,0x00000000}},	//   tump, _đồn, --, --, 
   {{0x6e28004b,0x00000000,0x00000000,0x00000000}},	//   gqeb, --, --, --, 
   {{0xdcf80cf4,0x23640115,0x41b81fc4,0x00000000}},	//   setč, lgoj_, _अविस, --, 
   {{0x7e609b93,0x61f8005a,0x84e401ad,0xd12c02f2}},	//   sump, _iktl, कपिट_, _رمن_, 
   {{0x764c9b94,0x23649b95,0x7dc4067c,0x5ba41fbe}},	//   ysay, ngoj_, _bòsc, уроз, 
   {{0x8f9825f9,0x764c0213,0x23640115,0x7e60014f}},	//   _רידי, xsay, igoj_, qump, 
   {{0x58849b96,0x0c700066,0x00000000,0x00000000}},	//   лыба, جدید, --, --, 
   {{0x4df8025f,0xd808023a,0x764c0bf1,0xa2d4024a}},	//   _רפוא, ехал_, wsay, _मेस्, 
   {{0x764c3142,0x2a600810,0x68fc003b,0x0e6001af}},	//   tsay, bukb_, _dypd, _ткән, 
   {{0xb4bc0316,0x8af003b9,0x00000000,0x00000000}},	// [c1f0] इन्_, _edəb, --, --, 
   {{0x28d4072a,0x236401e4,0x7aec0139,0x18700092}},	//   _डेवि, egoj_, _ixat, _ሽግግር_, 
   {{0x24880472,0x764c9b97,0xa0200037,0x00000000}},	//   _csbm_, ssay, ööli, --, 
   {{0x61f89b98,0x764c9b99,0xe8d4011a,0x00000000}},	//   _aktl, psay, _כותר_, --, 
   {{0x764c5435,0xa3e401f9,0x00000000,0x00000000}},	//   qsay, _पदर_, --, --, 
   {{0x95c89b9a,0x30540063,0x229000d1,0x00000000}},	//   _чума_, ађит, زلىس, --, 
   {{0xd6c4015b,0xe0400138,0x61380139,0x606000d1}},	//   _এশিয, онщи, _sälâ, قۇلل, 
   {{0x61f8036b,0xa2440608,0xd3e001d5,0x3b08008e}},	//   _ektl, _چینل_, _اقری, _ozaq_, 
   {{0xdfcc027d,0x10a001b9,0x6fe000de,0x72181367}},	//   بيي_, риқн, nēci, _ажар_, 
   {{0xf1d807b7,0x53e40022,0x00000000,0x00000000}},	//   _भगिन, _рцҳа, --, --, 
   {{0x7aec9b9b,0x3b080139,0x6bd4007b,0x00000000}},	//   _axat, _azaq_, لتحر, --, 
   {{0x7dc4068c,0x68fc0158,0xee200150,0x00000000}},	//   _pòsc, _rypd, _дедi_, --, 
   {{0x6da49b9c,0x9e9401ed,0xada49b9d,0x7c940022}},	//   _вила, _پانچ, _валл, _ҳрыц, 
   {{0x23640399,0xec782c90,0xd9409b9e,0x00000000}},	//   zgoj_, _апк_, жери, --, 
   {{0x7aec0261,0x7c940153,0x95e800eb,0x00000000}},	//   _exat, _грыц, কতাম_, --, 
   {{0x47240220,0x7dc400a3,0x186424cd,0xc31000fe}},	//   спаң, _iòsa, јати_, হুটি_, 
   {{0x7aec014b,0xf1c41a2a,0x7ec800b0,0xd62400ea}},	// [c200] _gxat, वसान, pūpū, иоте_, 
   {{0x8af00cc1,0x7dc40100,0x99d001ec,0x3ea048f4}},	//   _edəc, _kòsa, _وقيت, _áite_, 
   {{0xd24c00f1,0x00000000,0x00000000,0x00000000}},	//   ېنه_, --, --, --, 
   {{0x7aec07d6,0x62642002,0x7dc400a3,0x34f806a6}},	//   _yxat, لاتق, _mòsa, ухую_, 
   {{0x23649b9f,0x6fa82c35,0xc1780075,0xc4480133}},	//   rgoj_, कानं, лҗа_, _ڕیان_, 
   {{0x6284025a,0x51f43334,0x91e01ea2,0x5f1412eb}},	//   _âkom, анію_, ооче, _पृष्_, 
   {{0x23280022,0x7dc408c2,0x9fc400d4,0x00000000}},	//   _аоби_, _nòsa, ищил, --, 
   {{0xe2981ca9,0x6e2c00b8,0x00000000,0x00000000}},	//   _иаб_, _ũaba, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x645c0194,0x72a000db,0xd5a00116,0x7c94007b}},	//   orpi, _رەىن, лaйи, ملخص, 
   {{0x7dc400a3,0x5c0401ee,0xbb9400f5,0x55b8011a}},	//   _còsa, ияма, банщ, דמיו, 
   {{0x98a0033f,0x1ea801f7,0x645c0332,0x8fa003f6}},	//   ncją_, _لاتي_, irpi, _махе, 
   {{0x3f849ba0,0x7dc401c3,0x3e346640,0xfe78014b}},	//   memu_, _eòsa, _افتر, _сӯй_, 
   {{0x3f849ba1,0x645c7313,0x8d9001d9,0x00000000}},	//   lemu_, krpi, _ؤنت, --, 
   {{0x981400c6,0x98a0033f,0xa3e400dc,0x645c005c}},	//   لبرا, kcją_, _पदं_, jrpi, 
   {{0x6aa09ba2,0x7aec01c6,0xf1b80010,0x36d4741b}},	//   _šofe, _txat, _pušk_, бобр, 
   {{0x3b0800ac,0x7aec009d,0xa2d405c0,0x645c9ba3}},	// [c210] _uzaq_, _uxat, _मेल्, erpi, 
   {{0x3f8400b2,0x7bdc9ba4,0x057466a3,0x628403b2}},	//   hemu_, lisu, قامد, _ákoy, 
   {{0x3f849ba5,0x3a280098,0x99d401d9,0xb89400ae}},	//   kemu_, _huap_, _متھا, _الجع, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3f849ba6,0x645c9ba7,0x2bb805f9,0x7bdc0194}},	//   demu_, arpi, _उकसा, iisu, 
   {{0x42b804a9,0x7bdc9ba8,0x61409ba9,0x98a00210}},	//   شنىڭ_, hisu, пеша, acją_, 
   {{0x3a280a2e,0x41749baa,0x3f843e6e,0x645c63e0}},	//   _luap_, تانس, femu_, crpi, 
   {{0xf1d80a28,0xf3e401d9,0x3f849bab,0x7bdc9bac}},	//   _भगवन, _آرُ, gemu_, jisu, 
   {{0xef181c31,0xc208036b,0xef100137,0x60c406be}},	//   ыми_, _چققن_, чүдө, _əkmi, 
   {{0x7dc49bad,0xf1f401af,0x00000000,0x00000000}},	//   _pòsa, _уззэ, --, --, 
   {{0x3f8401a6,0x7bdc9bae,0xc0c80024,0x00000000}},	//   bemu_, fisu, _куце_, --, 
   {{0x7bdc0af5,0x3f849baf,0x3a280407,0x3014023a}},	//   gisu, cemu_, _buap_, _удер, 
   {{0xdf841973,0x3a280263,0x37cc015b,0x9f4801e1}},	//   _دُنی, _cuap_, রচার, _ámáa_, 
   {{0xfe709767,0x3a20062c,0x00000000,0x00000000}},	//   _زده_, _cihp_, --, --, 
   {{0x2d849bb0,0xdd8c00aa,0xeb989bb1,0x7bdc9bb2}},	//   mele_, _سوي_, _бий_, bisu, 
   {{0x7bdc16b8,0xfee800fe,0x00000000,0x00000000}},	//   cisu, _পৰিধ, --, --, 
   {{0x2c7001ed,0xe5783576,0x00000000,0x00000000}},	// [c220] lád_, лза_, --, --, 
   {{0x2d849bb3,0x3f849bb4,0x6b848f49,0x645c9bb5}},	//   nele_, zemu_, lekg, trpi, 
   {{0xe4586719,0xf1b807f5,0x2d840311,0x3f849bb6}},	//   уже_, _guši_, iele_, yemu_, 
   {{0x2d849bb7,0x3f8402b9,0xdcf80311,0xddc000bc}},	//   hele_, xemu_, letă, _dvoř, 
   {{0x3f849bb8,0xaab86b9b,0x1cb0031c,0xdec402dd}},	//   vemu_, ॉनिक, ྟའོ_, _ﺨﻁﺎﺒ, 
   {{0x3f849bb9,0x2d849bba,0x6b849bbb,0x7bdc9bbc}},	//   wemu_, jele_, hekg, zisu, 
   {{0x2d849bbd,0x3f849bbe,0x7dc4642b,0x7bdc9bbf}},	//   dele_, temu_, _bòsn, yisu, 
   {{0x44389bc0,0x7bdc9bc1,0x3f840618,0x2d840b4f}},	//   _itr_, xisu, uemu_, eele_, 
   {{0x3f849bc2,0x4438003e,0xef90036b,0xd36c642c}},	//   remu_, _htr_, بیند, _سهل_, 
   {{0x2d849bc3,0x7bdc9bc4,0x44380109,0x3f849bc5}},	//   gele_, wisu, _ktr_, semu_, 
   {{0x7bdc9bc6,0x3a2806df,0x44380204,0x3f8408e5}},	//   tisu, _suap_, _jtr_, pemu_, 
   {{0xf1b80552,0x7bdc9bc7,0xefd40092,0x00000000}},	//   _ruši_, uisu, ርቀው_, --, 
   {{0x44389bc8,0x5f049bc9,0xdcf80356,0x00000000}},	//   _ltr_, _узда, fetă, --, 
   {{0x7bdc9bca,0xf1b8041a,0xd83c00d0,0xdcf8054e}},	//   sisu, _puši_, účov_, getă, 
   {{0xaab41547,0xd5b89bcb,0x44389bcc,0x6b8400a2}},	//   مگیر_, қса_, _ntr_, bekg, 
   {{0x7bdc0eda,0x3a28003e,0x59a4012c,0xc0580023}},	//   qisu, _tuap_, खाहर, _ከይተገ, 
   {{0x35b4562a,0x79589bcd,0x7dc401e1,0xa3bc060c}},	// [c230] обар, _кипр_, _jòso, ेसन_, 
   {{0x443801ee,0xf1b80427,0xdcf8054e,0xf8b8004e}},	//   _btr_, _tuši_, cetă, _көб_, 
   {{0xd4989bce,0x9f88030a,0x84640395,0x9808007b}},	//   ыра_, _eùé_, зъче, _متحف_, 
   {{0x7c3801bf,0x00000000,0x00000000,0x00000000}},	//   _mtvr, --, --, --, 
   {{0x2d849bcf,0x44381e24,0x79940099,0x75280356}},	//   yele_, _etr_, odzw, _şezu, 
   {{0x799407a9,0x7c385f24,0x2d849bd0,0xddc0012c}},	//   ndzw, _otvr, xele_, _tvoř, 
   {{0x2d849bd1,0x79940099,0x636c01e1,0x3ea0031c}},	//   vele_, idzw, _kóǹ, _ġita_, 
   {{0x2d846adf,0x9ad0063f,0x3ea00153,0x00000000}},	//   wele_, tịla, _šita_, --, 
   {{0x7c380175,0x92b42824,0x6e8805a2,0x443806be}},	//   _atvr, _احزا, рәев_, _ztr_, 
   {{0xec789bd2,0x7bdc020c,0xed582377,0xc69400df}},	//   апо_, èrun, јон_, לאפ_, 
   {{0x2d849bd3,0x6b8400fb,0x6cc40212,0x7c38013a}},	//   rele_, tekg, ійма, _ctvr, 
   {{0x7994006f,0x2c709bd4,0x7bdc035b,0x00000000}},	//   edzw, rád_, érup, --, 
   {{0x2d849bd5,0x6b840032,0x8af003be,0xff505263}},	//   pele_, rekg, _edən, _سخن_, 
   {{0xfeb82d4b,0x2fcc0165,0x6b840036,0x2c7026f6}},	//   _دامت_, lheg_, sekg, pád_, 
   {{0x6d409bd6,0x291c9bd7,0xdcf8054e,0x00000000}},	//   mbla, äta_, retă, --, 
   {{0x4438060a,0x7be40598,0x98a00034,0x7994004c}},	//   _rtr_, ıtuç, ncję_, adzw, 
   {{0x6d400e89,0x44389bd8,0xdcf80356,0x7c3801ef}},	// [c240] obla, _str_, petă, _ztvr, 
   {{0x649840c5,0x4438045a,0x25640014,0xf7700050}},	//   итер_, _ptr_, تارُ, ٘اے_, 
   {{0x2c540882,0x98a00034,0xeab001d9,0x2fcc030a}},	//   nād_, kcję_, _رٹھ_, kheg_, 
   {{0x291c0024,0xc3300014,0x95e40014,0xf1b80171}},	//   žtas_, رٕت_, ٕکہِ_, _mušu_, 
   {{0x6d409bd9,0xf454002e,0x248401f1,0xa188036b}},	//   kbla, _fee鯵, ňom_, ибда_, 
   {{0x1a9804ac,0x69cc0007,0xa3e44eae,0x6d4007f5}},	//   יינע, nhbe, _पदक_, jbla, 
   {{0x6d400c8c,0x7f580c69,0x00000000,0x00000000}},	//   dbla, байс_, --, --, 
   {{0x6d400154,0x79940810,0xdef801ec,0x64a41171}},	//   ebla, zdzw, иып_, _лаҳа, 
   {{0x6d409bda,0x3f98012c,0x44249bdb,0x7c3839e4}},	//   fbla, ěru_, _iim_, _stvr, 
   {{0xb91001f2,0x44249bdc,0x98a00210,0xecd40154}},	//   _chaị_, _him_, ację_, _সুইড, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d402d1e,0x44249bdd,0x2fcc9bde,0xfde80137}},	//   abla, _jim_, cheg_, рдүк_, 
   {{0x44249bdf,0x6d409be0,0x9ad002e3,0x2ff801b9}},	//   _mim_, bbla, mịka, _اونگ_, 
   {{0x44249be1,0x69cc9be2,0xf1b801a6,0x79940433}},	//   _lim_, ghbe, _fušu_, udzw, 
   {{0x7c3804b9,0x61e89be3,0x7c5800c6,0x2d980134}},	//   _utvr, infl, _البر_, ɛse_, 
   {{0x44249be4,0x61e803fa,0x9a8401b9,0x00000000}},	//   _nim_, hnfl, _дуол, --, 
   {{0x6b8000e8,0x36d4084c,0xcb080046,0xf1b800ef}},	// [c250] _ñoga, чоар, _ويىن_, _zušu_, 
   {{0x69cc9be5,0xd4989be6,0x44249be7,0x61e801f5}},	//   chbe, ире_, _aim_, jnfl, 
   {{0x1cb0031c,0x98a0033f,0x37f811ca,0x93882c11}},	//   ྟའི_, ycję_, _генэ_, исда_, 
   {{0x44249be8,0xb9d402d3,0xb9e4001f,0x14c80022}},	//   _cim_, _ኸም_, _ካሬ_, лыҵи_, 
   {{0x44249be9,0x6d409bea,0x9ad001f2,0x7dc4007f}},	//   _dim_, ybla, dịka, _pòsl, 
   {{0x44241509,0xb5c89beb,0xdca49bec,0x2c540882}},	//   _eim_, _اوسم_, _كى_, yād_, 
   {{0x44249bed,0x7dc400db,0x6d400175,0x64580fac}},	//   _fim_, _còsm, vbla, _åtip, 
   {{0x44249bee,0x776c1cdf,0xa2d41f13,0x73340131}},	//   _gim_, ngax, _मेक्, _رىئا, 
   {{0x72049bef,0xee38026a,0x1e801e76,0xf1b8110c}},	//   _فورم, љно_, елым, _sušu_, 
   {{0x6d409bf0,0xf1b800de,0x00000000,0x00000000}},	//   ubla, _pušu_, --, --, 
   {{0x44240190,0xab289bf1,0xf0442263,0x41748818}},	//   _yim_, йона_, _رعای, _تاقس, 
   {{0x6d409bf2,0x44245825,0x30140209,0x00000000}},	//   sbla, _xim_, _эдер, --, 
   {{0x5f880014,0xc0e002d3,0xef18025c,0xaac4012d}},	//   _دٕنہ_, ሓደር_, keżi_, रैंक, 
   {{0xf1b89bf3,0xad2400db,0x5e54010f,0x3f6401ee}},	//   _gušt_, _عىبى, _זיסע_, _етәб, 
   {{0x18a09bf4,0xe73800d1,0x98a0859f,0x6844022e}},	//   нарм, йев_, нире, янва, 
   {{0x69cc6064,0xad4000f7,0x776c058a,0x00000000}},	//   shbe, _تۉگۉ, ggax, --, 
   {{0x6b940009,0x61e8045f,0x00000000,0x00000000}},	// [c260] _iayg, ynfl, --, --, 
   {{0x44249bf5,0x1a9800c8,0xddc001e4,0x6b940067}},	//   _sim_, _פייע, _ovoŝ, _hayg, 
   {{0x4424016d,0x6b949bf6,0x69dc0d63,0x02c400dc}},	//   _pim_, _kayg, _impe, वन्न, 
   {{0x4424047e,0x78a0005c,0x61e80042,0x60dc03e3}},	//   _qim_, ælve, wnfl, _üzmə, 
   {{0x44240190,0x6b949bf7,0xdd140030,0x69dc0165}},	//   _vim_, _mayg, mäťo, _kmpe, 
   {{0x44249bf8,0xc0dc02d3,0x6b940014,0x3ea01ebf}},	//   _wim_, _ዕላል_, _layg, _šito_, 
   {{0x44246dcf,0x6b940076,0x9ad001f2,0x546401f0}},	//   _tim_, _oayg, tịka, _нарм_, 
   {{0x442416b8,0x6720005f,0x67340034,0x8af003e3}},	//   _uim_, žoju, ncyj, _adəm, 
   {{0x69dc9bf9,0xa5280003,0xa908022e,0x00000000}},	//   _ompe, _སྔོག_, _xbоr, --, 
   {{0xdda866b4,0x9ad0063f,0x61b000db,0xa0300137}},	//   стил_, sịka, _سەبا, _كۉتت, 
   {{0x6734068f,0x6b949bfa,0x00000000,0x00000000}},	//   kcyj, _bayg, --, --, 
   {{0x69dc9bfb,0xaf480372,0x6b949bfc,0x00000000}},	//   _ampe, _ۇشۇل_, _cayg, --, 
   {{0x6b949bfd,0xcfb4011a,0xd00c9bfe,0x00000000}},	//   _dayg, _מלאי_, _صله_, --, 
   {{0x832c0003,0xa340001f,0x00000000,0x00000000}},	//   _སུའུ_, _ይጠበቃ, --, --, 
   {{0xa3bc00c5,0x7dc4007f,0x00000000,0x00000000}},	//   ेसा_, _lòsk, --, --, 
   {{0xbdf800f7,0x6b940432,0xcb44030d,0x00000000}},	//   _ارچا_, _gayg, _пхьи, --, 
   {{0x7bcc0cfe,0x395005d5,0x776c0009,0xef18025c}},	// [c270] _ilau, pazs_, rgax, teżi_, 
   {{0x7bcc9bff,0x69dc020c,0x6734033f,0x0c040014}},	//   _hlau, _gmpe, acyj, _ٲویُ, 
   {{0x7bcc9c00,0x6b9403ee,0x97c40592,0xb814009b}},	//   _klau, _yayg, _فتحم, _одој, 
   {{0xdfc49c01,0x6b940009,0x28d4547d,0x1768004e}},	//   _شي_, _xayg, _डेटि, _уроп_, 
   {{0x7bcc009a,0x69dc000f,0xfe0c05f9,0x00000000}},	//   _mlau, _ympe, हतास_, --, 
   {{0x7bcc9c02,0x4ae0000d,0x00000000,0x00000000}},	//   _llau, _पइसव, --, --, 
   {{0x7bcc9c03,0x84640801,0x92bc04c5,0xd14801ec}},	//   _olau, _пъте, ুপে_, _ۇشان_, 
   {{0xee389c04,0x43949c05,0x00000000,0x00000000}},	//   они_, _пасс, --, --, 
   {{0x205464c2,0x60e403e3,0x518401af,0xdcf800c0}},	//   птөр, _əsmə, _нужа, metę, 
   {{0xa2b0006d,0x7bcc9c06,0x6b940365,0xde1400c6}},	//   _आपत्, _alau, _sayg, وقيت_, 
   {{0x417407a7,0x6b9401b9,0xad240131,0x6734033f}},	//   _سالس, _payg, بىدى, ycyj, 
   {{0x69dc020b,0x7bcc9c07,0x6b94022e,0xbad800cc}},	//   _smpe, _clau, _qayg, _ধুইছ, 
   {{0x6284145e,0x6db404da,0x4f081c3e,0xdd140419}},	//   _âkot, _ойду, _اتاپ_, väťo, 
   {{0x7bcc9c08,0x6b94058a,0x2ec807b6,0x00000000}},	//   _elau, _wayg, िनीत, --, 
   {{0x7bcc9c09,0xabf41830,0x27944c34,0xe7f801ad}},	//   _flau, _очищ, мшар, ंवला_, 
   {{0x7bcc9c0a,0xa6c89c0b,0x00000000,0x00000000}},	//   _glau, олба_, --, --, 
   {{0xa528031c,0x67349c0c,0x00000000,0x00000000}},	// [c280] _སྔུག_, rcyj, --, --, 
   {{0x69dc9c0d,0x55841fce,0x00000000,0x00000000}},	//   _umpe, мбум_, --, --, 
   {{0xe728013e,0xdd1400d0,0x6734033f,0x00000000}},	//   _монд_, päťo, pcyj, --, 
   {{0x3ce000af,0x8af006be,0x00000000,0x00000000}},	//   _ओइसे_, _ndək, --, --, 
   {{0xe61801ee,0x6e2c00ae,0xe1f8009d,0x00000000}},	//   _мдм_, _éabh, огд_, --, 
   {{0x23700210,0x00000000,0x00000000,0x00000000}},	//   żyj_, --, --, --, 
   {{0xb9f81e38,0xf3ec0117,0x00000000,0x00000000}},	//   _መዝ_, _бӣ_, --, --, 
   {{0x78a00158,0x00000000,0x00000000,0x00000000}},	//   ålvi, --, --, --, 
   {{0x7bcc0333,0xe19401c0,0x33b001ec,0xd29800c0}},	//   _rlau, _оржэ, _حەنر, _нiбы, 
   {{0xdbc40598,0x7bcc9c0e,0x8af006be,0x00000000}},	//   _köçl, _slau, _edək, --, 
   {{0x7bcc9c0f,0xd12c3b07,0xbb5c00b5,0xa2c800dc}},	//   _plau, _ضمن_, _rayセ_, तैर्, 
   {{0x6284025a,0x8650013f,0x0fc000d1,0x5454010f}},	//   _âkos, nyɔs, _җйән, וסטן_, 
   {{0x501800c8,0x75f80ffb,0x5f1804af,0x7bcc0208}},	//   _וואו, rìzz, मेश्_, _vlau, 
   {{0x7bcc0a2e,0xc9843d6c,0xedf401ec,0x6e3c01e7}},	//   _wlau, куси, _كينگ, ísbe, 
   {{0x9f880241,0x5f180073,0x8d140137,0x8d700244}},	//   _kùà_, मेर्_, _ۉزۉر_, _شاوا, 
   {{0x7bcc7b3b,0x5b24010a,0x00000000,0x00000000}},	//   _ulau, _оьпа, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [c290] --, --, --, --, 
   {{0xc6a402e8,0xf594007b,0x00000000,0x00000000}},	//   ърси, علاج, --, --, 
   {{0x69f09c10,0x38c8029e,0x00000000,0x00000000}},	//   _сүрт, _رادی_, --, --, 
   {{0x7dc4067c,0x00000000,0x00000000,0x00000000}},	//   _dòsi, --, --, --, 
   {{0xfccc02d3,0x95c816a4,0x07a40006,0x00000000}},	//   _ኣዋጅ_, _дува_, _раўн, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3de40729,0xdbc49c11,0xd35c030d,0x00000000}},	//   নকাল, _göçl, _гiач, --, 
   {{0xb4bc1b0c,0x919c000d,0x3b0803b9,0xef18012d}},	//   ेनी_, _गोरै, _oyaq_, zeżu_, 
   {{0x2ec80d0d,0x3b080007,0xa3bc52be,0xa80000e4}},	//   िनेत, _nyaq_, ेसर_, _õñem, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xeb989c12,0x3b089c13,0x41ac9c14,0xadb4104e}},	//   пин_, _ayaq_, चारस, _үбеш, 
   {{0xcc00000e,0xeb989c15,0xdcf80118,0xbfa81436}},	//   ৃদ্ধ_, чим_, letě, _отче_, 
   {{0xcee84732,0x5ac49c16,0x4ae00490,0x41a406e3}},	//   _بران_, елям_, _पेशव, _गोडस, 
   {{0x387c0023,0x933c0092,0x00000000,0x00000000}},	//   _ኣካላቱ_, _ይጠቀሳ, --, --, 
   {{0x1d04016c,0x7c940124,0xdca002e8,0x00000000}},	//   _пеши_, _арыц, _бащи, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3b080007,0xe7089c17,0x320400a2,0x00000000}},	// [c2a0] _gyaq_, سترن_, _okly_, --, 
   {{0x24f49c18,0x7dc49c19,0xddc00210,0x00000000}},	//   нчер, _pòsi, _zwoł, --, 
   {{0xe1f8052f,0x290c01ed,0xe73804b3,0x764803e3}},	//   үге_, _áfa_, _нен_, _çeyn, 
   {{0xc0dc069c,0x78ac012c,0x96601cd1,0x32040432}},	//   _ዕላማ_, ňová, _әкре, _akly_, 
   {{0x93402502,0x00000000,0x00000000,0x00000000}},	//   унче, --, --, --, 
   {{0xd12c3669,0x00000000,0x00000000,0x00000000}},	//   ممه_, --, --, --, 
   {{0xe3b800f3,0x00000000,0x00000000,0x00000000}},	//   _ебв_, --, --, --, 
   {{0x644c03a2,0x44449c1a,0x00000000,0x00000000}},	//   _iwbi, mp_, --, --, 
   {{0x44449c1b,0x644c0076,0x00000000,0x00000000}},	//   lp_, _hwbi, --, --, 
   {{0x644c0083,0x44449c1c,0x6fa8033f,0xd674011a}},	//   _kwbi, op_, काउं, עתיק_, 
   {{0x44442171,0x4e749c1d,0x00000000,0x00000000}},	//   np_, وحید_, --, --, 
   {{0x44449c1e,0x00000000,0x00000000,0x00000000}},	//   ip_, --, --, --, 
   {{0x44440408,0x200406c8,0x6284014a,0xd95c0023}},	//   hp_, _ikoi_, _äkod, _ንምውጋ, 
   {{0xdb4c0133,0xdb0c0332,0x80a40709,0xd90c029e}},	//   جێک_, _ídío, किपे, ییک_, 
   {{0x44444f98,0xa6dc02f5,0x25f47220,0x933c0092}},	//   jp_, _ভুলট, ्वनी_, _ይጠቅሳ, 
   {{0x44449c1f,0xc1740198,0x00000000,0x00000000}},	//   dp_, ɗɗe_, --, --, 
   {{0xf5900020,0x44448b61,0xd56406ed,0x00000000}},	// [c2b0] _የማውጫ_, ep_, етеп, --, 
   {{0x38349c20,0x9a8c02d3,0x00000000,0x00000000}},	//   _инор, _ዝላዓለ_, --, --, 
   {{0xb4bc9c21,0x200400b0,0x89dc02e4,0x80e00011}},	//   ेने_, _okoi_, _מחזי, _পুস্, 
   {{0x43749c22,0x766400f1,0x3204013a,0x00000000}},	//   гушт, _لیرې_, _skly_, --, 
   {{0x44449c23,0x644c035a,0xd95c0023,0x00000000}},	//   ap_, _ewbi, _ንምዕጋ, --, 
   {{0x20049c24,0x4444004c,0x81c800d4,0xd75800e5}},	//   _akoi_, bp_, нгів_, _بجھا_, 
   {{0x44449c25,0x2ec80882,0xa5c0026f,0xf8d0000d}},	//   cp_, िन्त, _төте, सनिय, 
   {{0x5ee0015b,0x57bc0118,0x00000000,0x00000000}},	//   _পড়ে, _एकोह, --, --, 
   {{0xd2b8027d,0x026403e6,0x61100150,0x00000000}},	//   _عارض_, _مێنێ, лдәу, --, 
   {{0x30e40166,0xfcec0092,0x614400db,0xd138009d}},	//   _исең, _ቅርጽ_, _لىكە, _хха_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xcbd00154,0xebe40150,0x7d1c03b2,0x00000000}},	//   াচ্ছ, томп, ýrsa, --, 
   {{0x8fc0035b,0xbe6400ae,0x00000000,0x00000000}},	//   _иаҧҵ, _مهني, --, --, 
   {{0x27e0562c,0x62840793,0xc0f8001f,0x44449c26}},	//   _smkn_, _äkoe, ገራሉ_, yp_, 
   {{0x6e2c011c,0x44449c27,0xeb980276,0xdd8c00c6}},	//   _èabb, xp_, _жий_, _ذوي_, 
   {{0xa2b02413,0x3ea001fa,0x37740032,0x44440427}},	//   _आपल्, _šiti_, лыус, vp_, 
   {{0x78a4019b,0x44449c28,0x7bdc0023,0xd8200116}},	// [c2c0] _erhv, wp_, ërue, рдти, 
   {{0xf48001e0,0x80a407f7,0x00000000,0x00000000}},	//   әҫти, किमे, --, --, 
   {{0x44449c29,0xfcec02d3,0x00000000,0x00000000}},	//   up_, _ቅርጺ_, --, --, 
   {{0xc5b40323,0x44440e2b,0x7dc400db,0x00000000}},	//   _өргө, rp_, _hòst, --, 
   {{0xf1a803e6,0x7dc4007f,0x27f0062c,0xd3700133}},	//   کانه_, _kòst, mnyn_, شێلک, 
   {{0x44449c2a,0x15409c2b,0x80e00f22,0x27f00076}},	//   pp_, _верм, _পুষ্, lnyn_, 
   {{0x7dc41497,0xbf101cd1,0xd24c104b,0x20040129}},	//   _mòst, әүлә, مچە_, _pkoi_, 
   {{0x28b808ec,0x27f09c2c,0xd12c0131,0xfcec0023}},	//   _उपनि, nnyn_, ممۇ_, _ቅርጻ_, 
   {{0x8fa014b7,0x626400cf,0x27f00363,0x35f4010a}},	//   рање, _جازق, inyn_, _рпӳр, 
   {{0x22449c2d,0x7dc42508,0xc0f80020,0xe0449c2e}},	//   mpok_, _nòst, ገራል_, _анжи, 
   {{0x1da405ba,0x22449c2f,0x628429ef,0x80e0015b}},	//   _कोणत, lpok_, _äkob, _পুর্, 
   {{0xefd40092,0x3ea401d3,0xefc00023,0xe99000de}},	//   ይቀው_, _مشتہ, ትታው_, _īkšķ, 
   {{0x7dc44079,0x3ea005ac,0x00000000,0x00000000}},	//   _bòst, _éit_, --, --, 
   {{0x7dc41497,0x3c58084c,0x27f00363,0xdb1c0240}},	//   _còst, _зикэ_, enyn_, _hoqë, 
   {{0xd90c034c,0x2ac000fd,0x27f00142,0xaab40345}},	//   تید_, _һәрв, fnyn_, نگیر_, 
   {{0x22441c04,0x27f0062c,0x00000000,0x00000000}},	//   kpok_, gnyn_, --, --, 
   {{0xa3b4103a,0x7c2c9c30,0x47349a41,0x798402d0}},	// [c2d0] जान_, _iiar, рнус, _tbhw, 
   {{0x7c2c9c31,0x68ec0597,0x363805f5,0x27f01368}},	//   _hiar, ándá, _үзнэ_, anyn_, 
   {{0x7c2c02a4,0x224400d7,0x86240108,0x00000000}},	//   _kiar, epok_, рьте, --, 
   {{0x7c2c1368,0x97a40022,0x6fd40118,0x7198136e}},	//   _jiar, _ррол, _káce, کچرز_, 
   {{0x7c2c1311,0x52b001e0,0x00000000,0x00000000}},	//   _miar, шҡас, --, --, 
   {{0x7c2c9c32,0x7dc4067c,0x80dc009e,0xe29401e0}},	//   _liar, _mòss, যপন্, уаш_, 
   {{0x7c2c01c0,0x31680ac1,0xd3789c33,0xafe41eca}},	//   _oiar, ğaz_, _оча_, локл, 
   {{0x7c2c9c34,0xc0c80640,0x61fc0427,0xc91800d9}},	//   _niar, ђује_, čpla, כחות_, 
   {{0xed589c35,0xada49c36,0xc2c406c5,0x00000000}},	//   ноп_, гапл, _پيلي, --, 
   {{0x2d949c37,0x7c2c01c6,0x5064086f,0xaa4401e0}},	//   урис, _aiar, _атда, һемл, 
   {{0x7c2c9c38,0x27f07620,0x25f40b02,0xa3c8000d}},	//   _biar, ynyn_, ्वती_, _लकम_, 
   {{0x7c2c9c39,0xaa449c3a,0x28b80118,0xa3b411a6}},	//   _ciar, лемл, _उपबि, जाय_, 
   {{0x7dc49c3b,0xe378008f,0x00000000,0x00000000}},	//   _còss, ערשר, --, --, 
   {{0x2fcc0165,0x27f00363,0x00000000,0x00000000}},	//   lkeg_, wnyn_, --, --, 
   {{0x7c2c1311,0xd9409c3c,0xa3b41533,0x3a280724}},	//   _fiar, сеси, जाम_, терү_, 
   {{0x7c2c9c3d,0x6fd406ed,0x7dc45c17,0xeb9806ed}},	//   _giar, _fáce, _fòss, _чии_, 
   {{0xe6180faa,0x6e2c021c,0x2fcc030a,0x27f00363}},	// [c2e0] еда_, _éabs, ikeg_, rnyn_, 
   {{0x7c2c9c3e,0xa3e416da,0xae18007d,0x25ac030a}},	//   _ziar, योन_, _नीमन_, ñfl_, 
   {{0xdd5400c8,0x7c2c0731,0x93c801d9,0x00000000}},	//   רבעט_, _yiar, کالہ_, --, 
   {{0x7c2c02b9,0x69cc05e4,0xd04403e3,0x00000000}},	//   _xiar, lkbe, _öləc, --, 
   {{0xa3b431a0,0xa184008e,0x00000000,0x00000000}},	//   जाब_, гыйл, --, --, 
   {{0x69cc9c3f,0xe434009a,0x2fcc030a,0x00000000}},	//   nkbe, _مفسد, ekeg_, --, 
   {{0xdb1c0200,0x00000000,0x00000000,0x00000000}},	//   _poqë, --, --, --, 
   {{0xaa8403c6,0xe2980fac,0x705400e5,0x00000000}},	//   _zvýš, _паб_, جنٹا, --, 
   {{0x7c2c9c40,0x614436da,0x9340084c,0xad2440ec}},	//   _riar, _беза, _ынте, یرپو, 
   {{0x7c2c9c41,0xf1a804d3,0x645c0280,0x69cc01a4}},	//   _siar, _لامه_, ospi, jkbe, 
   {{0x7c2c9c42,0x00000000,0x00000000,0x00000000}},	//   _piar, --, --, --, 
   {{0x61e89c43,0x2fcc0221,0x7c2c013c,0xa3b80f44}},	//   lifl, ckeg_, _qiar, आउट_, 
   {{0x645c1196,0x00000000,0x00000000,0x00000000}},	//   hspi, --, --, --, 
   {{0x7c2c0034,0x61e803e3,0x00000000,0x00000000}},	//   _wiar, nifl, --, --, 
   {{0x7c2c9c44,0x645c9c45,0x645802d2,0xa85400b1}},	//   _tiar, jspi, _ætih, иерә, 
   {{0x645c9c46,0x69cc0373,0x7c2c9c47,0x6fd401ef}},	//   dspi, akbe, _uiar, _táce, 
   {{0x645c9c48,0x9a849c49,0x00000000,0x00000000}},	// [c2f0] espi, _суйл, --, --, 
   {{0x69cc9c4a,0x645c67c4,0x8af003e3,0x00000000}},	//   ckbe, fspi, _edəs, --, 
   {{0x61e8022e,0xcaf402f2,0x00000000,0x00000000}},	//   difl, _نسیب, --, --, 
   {{0x13a42be7,0xd40807d2,0x6fd400e4,0x5c440092}},	//   طنتی_, رتام_, _mácc, _የደደቢ, 
   {{0x49b89c4b,0x12849c4c,0x03784028,0x61e805d1}},	//   _شاید_, امتی_, احمت_, fifl, 
   {{0x2fcc0165,0x00000000,0x00000000,0x00000000}},	//   wkeg_, --, --, --, 
   {{0x7d1c008c,0x052800cf,0x6aa0000d,0x515001a9}},	//   ýrsl, _боёк_, _ओछ्र, атқу, 
   {{0x2fcc030a,0x00000000,0x00000000,0x00000000}},	//   ukeg_, --, --, --, 
   {{0x69cc0b21,0x2fcc0489,0xef189c4d,0x00000000}},	//   ykbe, rkeg_, ъми_, --, 
   {{0x7dc4068c,0xac846cc1,0x61e80113,0xd9dc0034}},	//   _bòsq, агол, cifl, नफोट, 
   {{0x6fd40077,0x2fcc0165,0x27e40115,0x00000000}},	//   _cácc, pkeg_, ϲon_, --, 
   {{0xfce00023,0x00000000,0x00000000,0x00000000}},	//   _ነጺጋ_, --, --, --, 
   {{0xbf3406fe,0x7bdc02d3,0xa3b413e0,0x8af006be}},	//   _ارمغ, ërua, जात_, _adər, 
   {{0x68444301,0x645c01f4,0xa9a401c0,0x68580023}},	//   инга, yspi, шигд, _ገብረድ, 
   {{0x69cc5d43,0xfca800c6,0x645c0112,0xf7840116}},	//   rkbe, _مايو_, xspi, өврү, 
   {{0x69cc9c4e,0x645c9c4f,0x6ed47039,0x00000000}},	//   skbe, vspi, मैथु, --, 
   {{0x8af003be,0xe9d8040e,0x61e803ee,0xd6cc1375}},	// [c300] _edər, _акп_, yifl, وقف_, 
   {{0x2d84503b,0xe8c80120,0x61e80327,0xfce00240}},	//   nfle_, _агол_, xifl, _ነጺጉ_, 
   {{0x2d840112,0xc0f80092,0x00000000,0x00000000}},	//   ifle_, ገራሚ_, --, --, 
   {{0xe3b004a9,0xd4641f5a,0x63848c96,0x53406191}},	//   غرا_, рице_, ргда, охша, 
   {{0x645c9c50,0x61e89c51,0x00000000,0x00000000}},	//   sspi, tifl, --, --, 
   {{0x40349c52,0x64a49c53,0x20640063,0xa08801b9}},	//   бекс, _кага, ађив, всиз_, 
   {{0xa3b4150d,0x00000000,0x00000000,0x00000000}},	//   जाद_, --, --, --, 
   {{0x61e89c54,0x44381fe1,0xb2440032,0x62641a73}},	//   sifl, _iur_, шмәһ, _ناطق, 
   {{0x2d849c55,0x44389c56,0x63a09c57,0x9f8801e1}},	//   ffle_, _hur_, mdon, _kùú_, 
   {{0x44389c58,0x628058b6,0x7dc4067c,0x1278008f}},	//   _kur_, mtoo, _pòsq, _באמע, 
   {{0x44389c59,0x62809c5a,0x29180421,0x81bc005f}},	//   _jur_, ltoo, _nzpa_, _diēt, 
   {{0x62809c5b,0x9f880248,0x00000000,0x00000000}},	//   otoo, _lùú_, --, --, 
   {{0x62809c5c,0x44389c5d,0x2918005a,0x63a09c5e}},	//   ntoo, _lur_, _azpa_, idon, 
   {{0x44380d65,0x63a09c5f,0x62809c60,0x76480790}},	//   _our_, hdon, itoo, _çeyi, 
   {{0x44389c61,0x62809c62,0xbc440137,0x81c8009e}},	//   _nur_, htoo, _ارتۉ, _উষা_, 
   {{0x62809c63,0x63a000dd,0xddc00083,0x00000000}},	//   ktoo, jdon, _otoŋ, --, 
   {{0x63a09c64,0x9f8801e1,0x68fc0334,0xc7b821f3}},	// [c310] ddon, _bùú_, _expd, шёр_, 
   {{0x63a09c65,0x44389c66,0x62809c67,0xb99400c6}},	//   edon, _bur_, dtoo, _الدب, 
   {{0x44389c68,0x79949c69,0xd49806bb,0x63a09c6a}},	//   _cur_, mezw, ъра_, fdon, 
   {{0x44389c6b,0x63a09c6c,0x79949c6d,0x7c382b1d}},	//   _dur_, gdon, lezw, _muvr, 
   {{0x7c389c6e,0x62800014,0x6fd404d4,0x2d8403cb}},	//   _luvr, gtoo, _náca, yfle_, 
   {{0x79940dc9,0x7c389c6f,0x51849c70,0x44380e21}},	//   nezw, _ouvr, руда, _fur_, 
   {{0x4438387b,0x62809c71,0x62849c72,0x25f42886}},	//   _gur_, atoo, _äkon, ्वरी_, 
   {{0x63a09c73,0x79949c74,0x62809c75,0x3ce0000d}},	//   cdon, hezw, btoo, _ओइजे_, 
   {{0x44389c76,0x79949c77,0x628001f5,0x6fd400ae}},	//   _zur_, kezw, ctoo, _cáca, 
   {{0x629c0b23,0x44384b5e,0xb8a40023,0x2d8440e8}},	//   āpot, _yur_, _ቅልጡፍ_, ufle_, 
   {{0x7c3807de,0xada4016c,0x44383d20,0x6bd4007b}},	//   _cuvr, _ҳалл, _xur_, متحر, 
   {{0x7c381570,0xc5f40263,0x00000000,0x00000000}},	//   _duvr, _आद्य_, --, --, 
   {{0xae440372,0x79949c78,0x7c3805c7,0x6da40b01}},	//   _اپتو, fezw, _euvr, _гила, 
   {{0x63a09c79,0x79949c7a,0xed581fbd,0xd9402083}},	//   zdon, gezw, _сок_, зери, 
   {{0x63a007d6,0x6d400c8c,0x4524025c,0x6924013e}},	//   ydon, mcla, _འཛེར_, ёмба, 
   {{0x44380842,0x62804843,0x6d400857,0x66e400c2}},	//   _rur_, ytoo, lcla, боба, 
   {{0x44389c7b,0x62809c7c,0x7c381529,0x79940107}},	// [c320] _sur_, xtoo, _zuvr, bezw, 
   {{0x7c380649,0x79940b6f,0x63a00649,0x62800070}},	//   _yuvr, cezw, wdon, vtoo, 
   {{0xb8ec03f4,0x63a09c7d,0x6d40022f,0x974000f3}},	//   _শে_, tdon, icla, _šćek, 
   {{0x62809c7e,0x44389c7f,0x6d409c80,0x626414fb}},	//   ttoo, _vur_, hcla, ماتق, 
   {{0x44380c3a,0x62809c81,0x7f400175,0xb35403ff}},	//   _wur_, utoo, vcmq, زیلا_, 
   {{0x63a09c82,0xa5080f4d,0x62809c83,0x7d1c02f0}},	//   sdon, _бега_, rtoo, ýrsk, 
   {{0x44389b80,0x6d400c8c,0x660c0204,0x6fd404d4}},	//   _uur_, dcla, _ikbk, _sáca, 
   {{0x79949c84,0x6d409c85,0x23289c86,0x628001f5}},	//   zezw, ecla, _боби_, ptoo, 
   {{0x7c389c87,0x7994743b,0xd0040640,0x62800009}},	//   _suvr, yezw, љење_, qtoo, 
   {{0xdd981e51,0x6d400334,0x6e3801f5,0xfdc801d5}},	//   уши_, gcla, _duwb, ртиқ_, 
   {{0x79949c88,0xc0c40139,0x00000000,0x00000000}},	//   vezw, _фәли, --, --, 
   {{0x6d4000a3,0x79949c89,0x9f4400e4,0x1ea800f1}},	//   acla, wezw, _omoé_, _ماتي_, 
   {{0x79949818,0x1f145821,0x6d409c8a,0x93580023}},	//   tezw, _اباج, bcla, ቅስቃሳ, 
   {{0x6d400857,0x6ec4012c,0x7c380171,0x00000000}},	//   ccla, िहरु, _tuvr, --, 
   {{0x79942001,0x981401d9,0xd7f89c8b,0xcd307092}},	//   rezw, مبرا, гуа_, _عروب, 
   {{0x36d49c8c,0x58840184,0x79940107,0x28b808df}},	//   ообр, _һыма, sezw, _उपरि, 
   {{0x76b89c8d,0x163800c6,0x98a07975,0x4524031c}},	// [c330] шлар_, اسرة_, rajı_, _འཛུར_, 
   {{0x98a02fbe,0xf96003e6,0x75e806be,0xa3ac0153}},	//   sajı_, _زۆرێ, _közə, _rūšį_, 
   {{0x73380153,0xa5082374,0x00000000,0x00000000}},	//   азер_, لىكە_, --, --, 
   {{0xedb42007,0x6d4004cf,0x601c00e4,0xd6d400eb}},	//   _अच्छ, zcla, hëmb, _সখীপ, 
   {{0x601c02d3,0x6d40127b,0x62840793,0x92e801d5}},	//   këmb, ycla, _äkol, دراق_, 
   {{0x4a5c0a1e,0x6e3801f5,0xd5b887e6,0x6d4003ac}},	//   נדוו, _ruwb, _ссм_, xcla, 
   {{0xf1c801e1,0x764c9c8e,0x7bdc9c8f,0x6458031c}},	//   _aláì_, lpay, khsu, _ħtig, 
   {{0xf40800db,0x629c02b1,0xefc81d0f,0x00000000}},	//   _ئيرى_, āpor, рлил_, --, 
   {{0xa3b42122,0x764c9c90,0x6d407a02,0xee381b88}},	//   जार_, npay, tcla, јно_, 
   {{0xed580228,0x764c0098,0x6d409c91,0x15f800bc}},	//   шоо_, ipay, ucla, ्विर_, 
   {{0x6d409c92,0x764c0205,0x00000000,0x00000000}},	//   rcla, hpay, --, --, 
   {{0x6d409c93,0xab286d56,0x6a843be2,0x09780228}},	//   scla, иона_, олма, өргө_, 
   {{0x15f83885,0xdd140724,0x6d409c94,0xb80003d4}},	//   ्वार_, _täşk, pcla, ্ষাত_, 
   {{0x7bdc0798,0xfe705cfc,0x6fd401ef,0x601c0200}},	//   ahsu, _سده_, _káco, rëme, 
   {{0x75e80cc1,0x7c641f7a,0x764c02fa,0xa3b807f7}},	//   _gözə, _فايل, epay, _अचल_, 
   {{0x248c0023,0xea5800f0,0x00000000,0x00000000}},	//   _ነፋሪት_, _крој_, --, --, 
   {{0x80e004c5,0x764c18e0,0x9f44035b,0xa9a4010b}},	// [c340] _পুঞ্, gpay, _omoî_, _дипд, 
   {{0xe4d4009a,0x00000000,0x00000000,0x00000000}},	//   يتاب, --, --, --, 
   {{0x23480075,0xa3b42c30,0x245404fb,0x00000000}},	//   للاپ_, जाल_, زنشس, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4420005f,0xa2289c95,0x764c0334,0xd12c0133}},	//   ķi_, ажда_, cpay, ۆمه_, 
   {{0xd12c2b09,0x62840793,0xc58800e5,0x00000000}},	//   چمه_, _äkom, _دھرم_, --, 
   {{0xd46405cc,0xd12c9c96,0x45240327,0x644800ae}},	//   _мире_, نمه_, _འཛིར_, ífid, 
   {{0xef18068f,0x05949c97,0x00000000,0x00000000}},	//   leży_, _باڭگ, --, --, 
   {{0x601c0240,0x75e806be,0x00000000,0x00000000}},	//   tëmb, _sözə, --, --, 
   {{0x3ba80020,0x2370012d,0xa0680354,0x645802d2}},	//   _ዊኪዎች_, łają_, _важа_, _ætis, 
   {{0x601c0023,0x212800a3,0x7bdc003a,0x00000000}},	//   rëmb, _àbh_, thsu, --, 
   {{0x601c5ed4,0xefc002d3,0x7bdc00d8,0x764c9c98}},	//   sëmb, ስታይ_, uhsu, ypay, 
   {{0x764c123b,0xc0c41de6,0x3a2001ef,0x00000000}},	//   xpay, _фәһи, _phhp_, --, 
   {{0x8e440e5a,0x81cc015b,0x7bdc00a3,0xad9c01af}},	//   _بلوك_, শোর_, shsu, _башk, 
   {{0xd838152d,0x68e00198,0x764c0309,0xbb58010a}},	//   рэг_, _ƙoda, wpay, _лайх_, 
   {{0x764c9c99,0x272c00e4,0xcb680114,0x00000000}},	//   tpay, _ẽna_, _даће_, --, 
   {{0x764c9c9a,0xd54802dd,0x27fc9c9b,0x00000000}},	// [c350] upay, لجام_, étna_, --, 
   {{0x764c9c9c,0xdce803ee,0x9f4400c7,0xca7403e6}},	//   rpay, _hafı, _omoï_, _کچێک, 
   {{0x764c0986,0xa3b400cd,0x84640395,0xd404020f}},	//   spay, जां_, дъче, ояди, 
   {{0xa3e41524,0xdbc400a2,0xa3b800cd,0x61e40064}},	//   योल_, _köñl, _अचः_, _įkla, 
   {{0x9f4400e4,0x764c0309,0x64580003,0x00000000}},	//   _amoï_, qpay, _ħtie, --, 
   {{0xdce80790,0x6fd400e5,0x00000000,0x00000000}},	//   _lafı, _páco, --, --, 
   {{0xdcf80024,0x93940553,0x00000000,0x00000000}},	//   metė, _وجرا, --, --, 
   {{0xa3b400dc,0xa3b00490,0xaec49c9d,0xdce80139}},	//   जाः_, _झोप_, збил, _nafı, 
   {{0x51849c9e,0x00000000,0x00000000,0x00000000}},	//   _мужа, --, --, --, 
   {{0x6fd402fb,0xdcf80153,0x00000000,0x00000000}},	//   _zácl, netė, --, --, 
   {{0x614400cf,0x00000000,0x00000000,0x00000000}},	//   _رىنە, --, --, --, 
   {{0x31bc045e,0xef180210,0xbfc4003b,0x00000000}},	//   _অতিশ, zeży_, _обєк, --, 
   {{0x7d180030,0xdcf80024,0xdcf400e5,0x00000000}},	//   _časť, ketė, قفیت_, --, 
   {{0x3ea00086,0xada49c9f,0x6da402dd,0x601c0200}},	//   _âita_, _хакл, _хика, mëma, 
   {{0x291c3953,0xa3e405f9,0x00000000,0x00000000}},	//   åta_, योँ_, --, --, 
   {{0x7d1c9ca0,0xe7380120,0xdce803e0,0x291c01e4}},	//   ürse, сеа_, _gafı, ĥta_, 
   {{0x601c0240,0xdcf800c0,0x66e40022,0x6a84030d}},	// [c360] nëma, fetė, чоаа, _элпа, 
   {{0x499400dd,0xf5e400d4,0x00000000,0x00000000}},	//   _تیسر, мієм, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa3e414cf,0x93409ca1,0x00000000,0x00000000}},	//   यों_, енце, --, --, 
   {{0x6fd4012c,0x27f09ca2,0xefe80023,0x00000000}},	//   _václ, miyn_, ቅኑዕ_, --, 
   {{0xd24c0075,0x27f06e63,0x91e03cc5,0x6e2c01ab}},	//   چچە_, liyn_, ноче, _èabh, 
   {{0xd24c3955,0x764805d1,0x00000000,0x00000000}},	//   نچە_, _çeyr, --, --, 
   {{0x27f00784,0x9cc80032,0x657c0175,0xa3e8033a}},	//   niyn_, ҡына_, lgph, _удба_, 
   {{0x44240639,0xd12c04a9,0xa3e40a28,0xe2b405f5}},	//   _ihm_, نمۇ_, योः_, _эсвэ, 
   {{0x657c0652,0xa0a40364,0x44240c6a,0xdce89ca3}},	//   ngph, _назд, _hhm_, _safı, 
   {{0xdbc402d2,0xa3b40f4a,0x00000000,0x00000000}},	//   _böðl, जाऊ_, --, --, 
   {{0xd6f8037e,0x00000000,0x00000000,0x00000000}},	//   _gnシ_, --, --, --, 
   {{0x2ab00109,0x601c0023,0xdbc408a5,0x00000000}},	//   _rôbô_, cëma, _döðl, --, 
   {{0x246c02d3,0xbb440150,0x00000000,0x00000000}},	//   _ኣውጺኡ_, _ﺘﻨﻬ_, --, --, 
   {{0x44244266,0x17689ca4,0x00000000,0x00000000}},	//   _ohm_, йрап_, --, --, 
   {{0x44249ca5,0x00000000,0x00000000,0x00000000}},	//   _nhm_, --, --, --, 
   {{0xa3b400af,0xb4b400dc,0x00000000,0x00000000}},	// [c370] जाई_, जम्_, --, --, 
   {{0x061409fe,0x44249ca6,0xc6a4121c,0x78a001bf}},	//   едую, _ahm_, эрси, ælvs, 
   {{0xf8d01533,0x6b080135,0x44249ca7,0xdcf80153}},	//   _हथिय, _གཙོོ_, _bhm_, retė, 
   {{0x442400b5,0xdcf80153,0xf98800ec,0x850400be}},	//   _chm_, setė, _انھي_, رونن, 
   {{0xdcf80024,0x46a402d5,0x00000000,0x00000000}},	//   petė, _заўв, --, --, 
   {{0x64489ca8,0x44249ca9,0xe2940107,0x31ac00e5}},	//   ífic, _ehm_, фаш_, köző_, 
   {{0x6e2c011c,0x69bc0490,0x4424045a,0x00000000}},	//   _èabi, शाती, _fhm_, --, 
   {{0x442403b2,0x601c036e,0x00000000,0x00000000}},	//   _ghm_, tëma, --, --, 
   {{0x720451d1,0xa280034c,0x81bc00b0,0xdd1400a2}},	//   _قورم, _لینو, _whēa, läňo, 
   {{0x601c00e8,0x2d946b2a,0xdbc4032e,0x00000000}},	//   rëma, фрис, _söðl, --, 
   {{0xeb989caa,0x601c02d3,0x2c440171,0x00000000}},	//   оин_, sëma, _bēda_, --, 
   {{0xc0240ef6,0xa3b4000d,0x00000000,0x00000000}},	//   _كىلي, जाए_, --, --, 
   {{0xbdf8066d,0x935802d3,0x7dc4007f,0x9ce00150}},	//   _کرنا_, ቅስቓሳ, _lòsy, _ﺇﻁﻼﻋ, 
   {{0x8d8464ab,0x2fdc031c,0xae041d00,0xba000022}},	//   _худд, _hlwg_, _توتى, лҧыл, 
   {{0xd9400cdd,0xa7a80798,0xe3ac0154,0x6fd401ef}},	//   теси, оква_, _ককসব, _náck, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x44240b4b,0x291c000d,0x00000000,0x00000000}},	// [c380] _rhm_, ütab_, --, --, 
   {{0x44240073,0x61e40153,0x27f00142,0x4da800cc}},	//   _shm_, _įklo, siyn_, _চকুৱ, 
   {{0xe7388f62,0x44249cab,0x69dc011c,0xa3e89cac}},	//   _мен_, _phm_, _ilpe, оджа_, 
   {{0xd36c0491,0xe2986408,0xe3b80153,0x00000000}},	//   لهم_, жад_, юбе_, --, 
   {{0xda78010f,0x00ac00d1,0x00000000,0x00000000}},	//   ַנקר, _ﺳﯧﺴﺘ, --, --, 
   {{0x9f4403fa,0x4424045a,0xb8649cad,0xb0a810eb}},	//   _bloß_, _whm_, _تایو, किंग, 
   {{0x44249cae,0xe364026a,0x00000000,0x00000000}},	//   _thm_, _окви, --, --, 
   {{0x44440097,0x6fd4022a,0x644c01ef,0x710000c7}},	//   mq_, _jách, _itbi, ыҧха, 
   {{0xceb80cc1,0x69dc2b92,0xe2449caf,0x44441444}},	//   _şərh_, _olpe, _آخري, lq_, 
   {{0x44440af5,0xddc00034,0x69dc0327,0xa3b400c5}},	//   oq_, _stoł, _nlpe, जाक_, 
   {{0x44440207,0xd5740375,0x2c440171,0x2ff800f2}},	//   nq_, ותיה_, _pēda_, _کونگ_, 
   {{0x69dc9cb0,0x44440226,0x644c9cb1,0x6fd4219b}},	//   _alpe, iq_, _mtbi, _nách, 
   {{0xdde8021a,0x8f040116,0x9cf800b8,0x44449cb2}},	//   _ورته_, _охша_, _dvāḥ, hq_, 
   {{0xca2407d6,0xd59800b5,0xdcf800b0,0x444400b5}},	//   вфси, _auの_, netī, kq_, 
   {{0xd6f8015b,0x874c01f2,0x97a401c0,0xd90c0f1c}},	//   _আরো_, _ọdịg, мрал, شیح_, 
   {{0x69dc9cb3,0xdc28034c,0x656c00dc,0x6fd40051}},	//   _elpe, _بسته_, _adbh, _cách, 
   {{0x644c11f9,0x44449cb4,0x7d1800ca,0x35b432ce}},	// [c390] _atbi, eq_, _hyvs, нбар, 
   {{0x7bcc0069,0x7dc402bd,0x601c036e,0xef10000d}},	//   _hoau, _pòsy, këmo, _डँसऽ_, 
   {{0x79842f05,0x33749cb5,0xd9b01411,0x291c00d7}},	//   _ichw, егер, _كەڭد, ýtat_, 
   {{0xb5c801d9,0x78a40064,0x00000000,0x00000000}},	//   _کوسم_, _ishv, --, --, 
   {{0x44449cb6,0x7bcc5632,0xc6a4004e,0x69dc023a}},	//   aq_, _moau, _ирри, _ylpe, 
   {{0x6fd402fb,0x81bc02b1,0x7bcc00ad,0x00000000}},	//   _zách, _whēn, _loau, --, 
   {{0x44445731,0x13e40efb,0x798401f7,0x1c0c13f5}},	//   cq_, _قوسۋ_, _mchw, सवाल_, 
   {{0x8af006be,0x42780092,0x00000000,0x00000000}},	//   _edəy, _አልኩት_, --, --, 
   {{0x79840107,0x00000000,0x00000000,0x00000000}},	//   _ochw, --, --, --, 
   {{0x7bcc1140,0x79849cb7,0xec789cb8,0x6fd424b0}},	//   _aoau, _nchw, ппо_, _máci, 
   {{0x4174005e,0x6f7401ee,0x00000000,0x00000000}},	//   _جاقس, _зѳлф, --, --, 
   {{0x79849cb9,0x765c02d0,0x7d1c0205,0x00000000}},	//   _achw, _owsy, ürsa, --, 
   {{0x7bcc0165,0xdfa40451,0x6fd49cba,0x44448e96}},	//   _doau, _سڏيو_, _rách, zq_, 
   {{0xad241b56,0x26dc0618,0x798403ac,0x2be00cb4}},	//   _كىشى, _āto_, _cchw, _पतवा, 
   {{0x7bcc0076,0x6fd42b57,0x7d189cbb,0xa804011c}},	//   _foau, _pách, _gyvs, езвл, 
   {{0x79849cbc,0x7bcc062c,0xad4000f7,0x0cc800bc}},	//   _echw, _goau, _جۉگۉ, ाहीम, 
   {{0xd7049cbd,0x44440097,0x78a4022e,0x644c0076}},	// [c3a0] енте_, wq_, _eshv, _stbi, 
   {{0x44449cbe,0xf0a401fb,0xa50816a4,0x69dc9cbf}},	//   tq_, _đàng_, пеза_, _ulpe, 
   {{0x44440207,0x6fd40407,0xdbc40254,0x59b00139}},	//   uq_, _tách, _vööl, _сөяс, 
   {{0x6fd49cc0,0x44449cc1,0x62649cc2,0xa95800e5}},	//   _fáci, rq_, евда, _بجکر_, 
   {{0xa3e437f3,0x79840cfd,0xdbc4007d,0x44441e0b}},	//   योग_, _ychw, _tööl, sq_, 
   {{0x59c002ab,0xa0a42f5c,0x05980101,0x656c00cd}},	//   शायर, ешил, _تمسک_, _udbh, 
   {{0x644c04f3,0xf1a89cc3,0xdcf800b0,0x67f80118}},	//   _utbi, بانه_, retī, půjd, 
   {{0x601c00e8,0x25a802d2,0x29180108,0x00000000}},	//   rëmo, _habl_, _mypa_, --, 
   {{0x291806a3,0x25a88bbb,0x7bcc0363,0x23640115}},	//   _lypa_, _kabl_, _roau, maoj_, 
   {{0x7bcc08cd,0x2364010f,0x21680395,0x00000000}},	//   _soau, laoj_, _хижи_, --, 
   {{0x7bcc02b1,0x29180267,0x6e3c0162,0x00000000}},	//   _poau, _nypa_, ísbr, --, 
   {{0x79849cc4,0x236401e4,0x3074004e,0x7d180c5e}},	//   _schw, naoj_, _шуус, _vyvs, 
   {{0x291802d1,0x25a80156,0xcc843bdb,0x2be000e1}},	//   _aypa_, _oabl_, ونیه_, _पतरा, 
   {{0x6fd4021c,0x7d18005c,0x8d80014b,0x00000000}},	//   _ráci, _tyvs, _буъд, --, 
   {{0x4e140375,0x23640115,0x00000000,0x00000000}},	//   _רחוב_, kaoj_, --, --, 
   {{0x291801ab,0x22440548,0x23640115,0x601c04e6}},	//   _dypa_, kqok_, jaoj_, këmm, 
   {{0x79840100,0x64482eb1,0x2ac00166,0x00000000}},	// [c3b0] _tchw, ífin, _кәрв, --, 
   {{0x79840034,0x8afc011a,0xd83801c4,0x00000000}},	//   _uchw, _מהחי, _нэм_, --, 
   {{0x69f00aaf,0x25a89cc5,0x29180200,0x741401d3}},	//   _түрт, _dabl_, _gypa_, نڈرا, 
   {{0xe8d40d65,0x25a8009f,0x6fd424c8,0xa85402e4}},	//   _יותר_, _eabl_, _táci, _שירה_, 
   {{0x25a8070d,0xa3b405f9,0x601c00e8,0x021800e5}},	//   _fabl_, जाज_, rëml, کٹوں_, 
   {{0x4b3800c8,0x00000000,0x00000000,0x00000000}},	//   ׂראל_, --, --, --, 
   {{0x60600131,0xafe41b0a,0x00000000,0x00000000}},	//   لۇلل, кокл, --, --, 
   {{0xdee80023,0xbcfc0022,0x00000000,0x00000000}},	//   _ህልኽ_, taĩn, --, --, 
   {{0xd1380276,0x9e607aa6,0xed583d09,0xdfcc009f}},	//   _ехе_, авыд, моп_, تيي_, 
   {{0x6fd40306,0x00000000,0x00000000,0x00000000}},	//   _nácv, --, --, --, 
   {{0x3b08013d,0x1f2401d9,0xb3d40073,0xccf40150}},	//   _axaq_, _یِمہ, _दवाख, эқк_, 
   {{0x29180098,0x00000000,0x00000000,0x00000000}},	//   _rypa_, --, --, --, 
   {{0x6da407dd,0x7f185eb4,0x00000000,0x00000000}},	//   _аила, _пішу_, --, --, 
   {{0xae18000d,0xec78022e,0x00000000,0x00000000}},	//   _नीचन_, _жпк_, --, --, 
   {{0x7c840063,0xec4801d5,0x00000000,0x00000000}},	//   _буње, _ўзил_, --, --, 
   {{0x9d1800d9,0x9f480205,0x00000000,0x00000000}},	//   _קוקט, şköy_, --, --, 
   {{0x81bc00e2,0x236400df,0xb744072d,0x00000000}},	// [c3c0] _shēm, vaoj_, ائفو, --, 
   {{0x29189cc6,0xdcf800de,0xaa7402f0,0x4bc401af}},	//   _typa_, lgtā, nčíš_, _рөүг, 
   {{0xd5ac007b,0x236401e4,0x9ac800e5,0x00000000}},	//   تفل_, taoj_, _فدیہ_, --, 
   {{0x213c01ab,0x601c04e6,0x6ab4032e,0x57440108}},	//   _sgth_, tëmm, _kryf, _изюм_, 
   {{0x25a89cc7,0x22b8007b,0x23640115,0x6fc410eb}},	//   _tabl_, بداع_, raoj_, वानं, 
   {{0x601c04e6,0xa5087abe,0xa3e40d2e,0x521000d4}},	//   rëmm, _жега_, योज_, адіт, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x27e005b1,0x6ab402d0,0x00000000,0x00000000}},	//   _jlkn_, _oryf, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdcf800e2,0x7d1c002f,0x00000000,0x00000000}},	//   egtā, ürso, --, --, 
   {{0xdfd09cc8,0x11d4007b,0x5fa000d1,0xfc3400d8}},	//   _پيش_, _جولة_, _نەغم, лноќ, 
   {{0x6fd40789,0x6ab439ea,0x545400df,0x00000000}},	//   _bácu, _bryf, כסטן_, --, 
   {{0x6ab40368,0x1b1800cc,0x59640139,0x291c0205}},	//   _cryf, নেনে_, къва, ütan_, 
   {{0x6ab40af9,0x00000000,0x00000000,0x00000000}},	//   _dryf, --, --, --, 
   {{0x98149cc9,0xd83802d5,0xd5a007d6,0x8c4001af}},	//   نبرا, дэа_, یلری, _кеје, 
   {{0x3f8485e8,0x7bdc00e2,0xa3b027a6,0x00000000}},	//   ngmu_, īrus, _झोल_, --, 
   {{0x6ab49cca,0x64480115,0x601c0200,0x00000000}},	// [c3d0] _gryf, ŭfil, tëmj, --, 
   {{0x0574525b,0x98bc00fd,0x7bdc20fe,0x00000000}},	//   لامد, şuı_, lksu, --, 
   {{0x601c02d3,0x7bdc16ca,0x6fc4000d,0x958000c0}},	//   rëmj, oksu, वामं, _žąsi, 
   {{0x7bdc26bb,0x80b800dc,0x67f80118,0x8c400139}},	//   nksu, ्मने, růjc, _öşem, 
   {{0xefc0010c,0xd16000d1,0xa06402dd,0x69d80ef5}},	//   ስታዊ_, анлқ, ңаша_, öteg, 
   {{0x6fd49ccb,0x2004023a,0x14740956,0x7bdc000d}},	//   _láct, _ajoi_, _لارج, hksu, 
   {{0x4dc81c82,0xada404a9,0x7bdc9ccc,0x93a400c7}},	//   িসমূ, қанл, kksu, _ишад, 
   {{0x7bdc9ccd,0xd1b800ec,0x6fd4013a,0x00000000}},	//   jksu, _ڪارا_, _náct, --, 
   {{0x32789cce,0x0cc800dc,0x00000000,0x00000000}},	//   _سماج_, ाह्म, --, --, 
   {{0xd1b89ccf,0x2b9c004d,0x15f800ce,0x00000000}},	//   _تارا_, _ắc_, ्वटर_, --, 
   {{0x5c7400c7,0x00000000,0x00000000,0x00000000}},	//   гәыр_, --, --, --, 
   {{0x61e40024,0x6ab4015d,0x00000000,0x00000000}},	//   _įkli, _pryf, --, --, 
   {{0x31640998,0x3af4010b,0x00000000,0x00000000}},	//   _kelz_, аярс, --, --, 
   {{0x6fd40120,0x7bdc9cd0,0x31640477,0x6ab40ea0}},	//   _vácu, aksu, _jelz_, _vryf, 
   {{0x27e02a1f,0x27942d31,0xdd8c04fb,0x6fd404d4}},	//   _plkn_, лшар, _روي_, _fáct, 
   {{0x6b9405ac,0xdc6401d5,0x399c00e4,0x00000000}},	//   _ubyg, _саъд_, tâsâ_, --, 
   {{0x2d849cd1,0x6ab402d0,0xaa440212,0x00000000}},	// [c3e0] ogle_, _uryf, _щепл, --, 
   {{0x2d844c5f,0xe9a4026a,0xda58025d,0x49b4013d}},	//   ngle_, _саоп, _רכיל, _тәму, 
   {{0x81bc0374,0xdce88bbb,0x2d840067,0x4ad801d3}},	//   _whēk, ćiće, igle_, _ساکھ_, 
   {{0xe2a801d9,0x6b8427be,0x66e40107,0x601c0de2}},	//   فاتن_, ngkg, _бома, rëmk, 
   {{0x31640165,0x3afc0165,0x00000000,0x00000000}},	//   _belz_, _xɬp_, --, --, 
   {{0x47f40107,0x00000000,0x00000000,0x00000000}},	//   _сӯҳр, --, --, --, 
   {{0xa508084c,0x7bdc03cd,0xbcfc00e4,0x00000000}},	//   _чева_, yksu, taĩm, --, 
   {{0x2d84058a,0x50b40472,0x00000000,0x00000000}},	//   egle_, ادود_, --, --, 
   {{0x63a09cd2,0xa2740220,0x81ac009e,0x2174004e}},	//   meon, _сұлу_, গাব_, _буер, 
   {{0x21180597,0x3df49cd3,0x6fd401d3,0x64580135}},	//   _كتاب_, рзос, _bács, _ħtij, 
   {{0xe0d805f5,0x6fd400e4,0x62840fac,0x3c949cd4}},	//   _явж_, _páct, _åkob, шинё, 
   {{0x63a09cd5,0x62800270,0x602401d5,0x70500244}},	//   neon, ouoo, _ёдда, _بچوا, 
   {{0x8ae402dd,0x00000000,0x00000000,0x00000000}},	//   бірл, --, --, --, 
   {{0x63a09cd6,0x7bdc000d,0x00000000,0x00000000}},	//   heon, sksu, --, --, 
   {{0x6fd44a34,0x63a08943,0xe9e400d0,0xc7c40116}},	//   _táct, keon, _ľúto_, әсси, 
   {{0x63a0037e,0x62800254,0x59c000bc,0x00000000}},	//   jeon, kuoo, शाहर, --, 
   {{0x7c2c9cd7,0x6fc40574,0x3940010e,0xcb6800f3}},	// [c3f0] _ihar, वातं, _tghs_, _сање_, 
   {{0xd5080058,0x7c2c00a3,0x628013ab,0x49c83be4}},	//   ىغان_, _hhar, duoo, _буюм_, 
   {{0x7c2c9cd8,0xd4980006,0x63a000e4,0x69d8000d}},	//   _khar, эра_, feon, ötee, 
   {{0x6fd40998,0x7c2c9cd9,0x63a09cda,0x00000000}},	//   _lácr, _jhar, geon, --, 
   {{0x7c2c9cdb,0x316404c4,0x00000000,0x00000000}},	//   _mhar, _pelz_, --, --, 
   {{0x2be000ce,0x7c2c00ad,0x95e02309,0xa5c0013d}},	//   _पत्थ, _lhar, _ايسۇ, _мөхе, 
   {{0x7c2c9cdc,0x34480364,0x63a09cdd,0x00000000}},	//   _ohar, _рӯзи_, beon, --, 
   {{0x7c2c9cde,0x3164017a,0x6fd401d3,0x3e700051}},	//   _nhar, _welz_, _rács, _môtơ_, 
   {{0x1b1804c5,0xf23809ac,0x91849cdf,0xe81412eb}},	//   নেতে_, _апаш_, _مجام, थकता_, 
   {{0x7c2c0551,0x2bdc16ae,0x2d849ce0,0x7bdc003a}},	//   _ahar, मस्थ, ugle_, êrun, 
   {{0x7c2c9ce1,0xcee800aa,0x80b800cd,0x00000000}},	//   _bhar, _ګران_, ्मणे, --, 
   {{0x7f849ce2,0x6e949ce3,0x60dc143a,0x7bdc0022}},	//   _هلمن, _виду, øpme, ërup, 
   {{0x7c2c1161,0xaa4410f5,0x2d94052f,0x2fcc01bf}},	//   _dhar, регл, _көнө_, mjeg_, 
   {{0x7c2c9ce4,0x2fcc04b9,0xbd8800b2,0x63a00165}},	//   _ehar, ljeg_, _منهن_, zeon, 
   {{0x7c2c4695,0x63a09ce5,0x291c01a8,0xac080a5b}},	//   _fhar, yeon, æta_, _инка_, 
   {{0x7c2c9ce6,0x2fcc0989,0x644800df,0x601c0200}},	//   _ghar, njeg_, ŭfik, tëmi, 
  
   {{0xe6189ce7,0x63a00522,0xe7381fbe,0x7b640114}},	// [c400] вда_, veon, теа_, _утје, 
   {{0x7c2c9ce8,0x6e200208,0x5ed80154,0x63a00067}},	//   _zhar, nllb, _বইমে, weon, 
   {{0x638401c6,0x6e200332,0xa87c0408,0x00000000}},	//   игжа, illb, _юлнă_, --, 
   {{0x2fcc025c,0x7c2c9ce9,0x8344035b,0x62800254}},	//   jjeg_, _xhar, сҭаз, tuoo, 
   {{0x63a000c6,0x148402dd,0xdec002d3,0x00000000}},	//   reon, _ءﻣﺎﻟ, ስባን_, --, 
   {{0x11d00075,0x69cc0369,0x5ab4008f,0x6280037e}},	//   قتىد, njbe, ילנע_, ruoo, 
   {{0xcfac045e,0x6d5405d1,0x63a09cea,0xd4640114}},	//   কানন, ızal, peon, _висе_, 
   {{0x9878008f,0xc034026a,0x2fcc0098,0xe3b01291}},	//   דאקט, љниј, gjeg_, _برآ_, 
   {{0x7c2c9ceb,0xdce803e0,0xd0040114,0xc4540345}},	//   _rhar, _ınız, јење_, _ئێڵب, 
   {{0x7c2c9cec,0xf1a810c4,0x80b8185d,0xd1b02099}},	//   _shar, _مامه_, ्मदे, _وینک, 
   {{0x27009ced,0x7c2c9cee,0x42500014,0x32400023}},	//   लपुर_, _phar, _بۆڈر, _ክተሓባ, 
   {{0x7c2c0986,0x6e209cef,0x00000000,0x00000000}},	//   _qhar, allb, --, --, 
   {{0x7c2c0084,0x7e549cf0,0xda780354,0x00000000}},	//   _vhar, _انتص, ъян_, --, 
   {{0x7c2c1f4c,0x00000000,0x00000000,0x00000000}},	//   _whar, --, --, --, 
   {{0x7c2c9cf1,0x81bc02b5,0x2b500042,0x7c340408}},	//   _thar, _whēw, _ffyc_, _лекх, 
   {{0x7c2c9cf2,0xdd8c05d9,0x7ac40166,0x0d38011a}},	//   _uhar, _روڊ_, _лөга, _בגוב, 
   {{0x76b89cf3,0x9a849cf4,0xf5980395,0x00000000}},	// [c410] ылар_, _туйл, лващ_, --, 
   {{0xef10008f,0x2fcc16a3,0x5884004e,0x2c4400de}},	//   פּן_, zjeg_, _кыма, _sēdi_, 
   {{0xf8b013e1,0xb4e00574,0x94841c3e,0x5ed800cc}},	//   _عکس_, धने_, рызд, _বেমে, 
   {{0x74142158,0xd838008e,0x00000000,0x00000000}},	//   িষ্ট_, _шэп_, --, --, 
   {{0x776c0009,0x6fc41223,0x00000000,0x00000000}},	//   maax, वासं, --, --, 
   {{0x776c9cf5,0x764c03be,0x61e89cf6,0x21642c31}},	//   laax, mqay, ghfl, биши_, 
   {{0x764c02d1,0x6ff401c6,0x6a7c02d2,0x00000000}},	//   lqay, йчих, _kæfð, --, 
   {{0x776c0067,0xd34402f2,0x00000000,0x00000000}},	//   naax, _ئیشه_, --, --, 
   {{0x764c9cf7,0x5ed800cc,0x802400d1,0x00000000}},	//   nqay, _বেবে, غرىم, --, 
   {{0x61e8002f,0x67e800ee,0x764c058a,0x850400e5}},	//   chfl, _iýje, iqay, _اوہن, 
   {{0x6600003e,0xa3ac0d2e,0x776c058a,0x00000000}},	//   éoki, _कसम_, kaax, --, 
   {{0x764c009a,0x702000fe,0x2a64031c,0x00000000}},	//   kqay, _পংকজ_, _ħobb_, --, 
   {{0xdfcc07c0,0xc6000011,0x7f500150,0x00000000}},	//   _سيو_, ্ততা_, _ﺼﺎل_, --, 
   {{0x764c0009,0x6fd40118,0x00000000,0x00000000}},	//   dqay, _zácp, --, --, 
   {{0x3cd401b9,0x977401e0,0x776c058a,0x00000000}},	//   _мўът, өттә, faax, --, 
   {{0xab6406dc,0x776c0548,0x99d40150,0x27e40de2}},	//   _увил, gaax, _ۇتپا, óon_, 
   {{0x99841ebd,0x6f1c9cf8,0x764c209c,0xe9d89cf9}},	// [c420] šišo_, üsch, gqay, _бкп_, 
   {{0x1b18009e,0x00000000,0x00000000,0x00000000}},	//   নেহে_, --, --, --, 
   {{0x776c01d9,0x67e8010e,0x764c0009,0xdec00023}},	//   baax, _aýje, aqay, ስባና_, 
   {{0x64a40046,0xb0bc3c71,0xd4640114,0xa08801a9}},	//   _қаба, ्मनग, сице_, ҳсиз_, 
   {{0xe2940261,0x67e802f0,0xabdc0150,0x64a400c7}},	//   среќ, _výjd, _ﺇﺠﻤﺎ, раҵа, 
   {{0x53a00124,0x1a98010f,0xa08801a9,0x2be0000d}},	//   _ҭарб, ריסע, гсиз_, _पतझा, 
   {{0x67e800a2,0x00000000,0x00000000,0x00000000}},	//   _eýje, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x601c0200,0x00000000,0x00000000,0x00000000}},	//   dëmt, --, --, --, 
   {{0xd6f8037e,0x2d9801ed,0x29f0005f,0xe0d00132}},	//   _bbオ_, ősen_, iņas_, _ىزا_, 
   {{0xc1780064,0x764c571b,0x22900139,0x00000000}},	//   _idė_, zqay, lâk_, --, 
   {{0x776c0429,0x601c036e,0x764c0946,0x00000000}},	//   xaax, tëmu, yqay, --, 
   {{0x1ed89cfa,0x81bc00b0,0x8ae401ec,0x80b81cba}},	//   _حباب_, _whēu, пірл, ्मवे, 
   {{0x776c0014,0x69c80100,0x39440158,0x601c0de2}},	//   waax, _òfel, øls_, rëmu, 
   {{0x0694044e,0x05dc033f,0x776c9cfb,0x764c007f}},	//   _ዝርከቡ_, _मक़ब, taax, wqay, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x34e01d27,0x9f4401f5,0x776c0067,0x764c0009}},	// [c430] पन्द, _aloë_, raax, uqay, 
   {{0x99649cfc,0xc8f80183,0x764c3fc7,0x776c058a}},	//   _утил, _আঁৰত_, rqay, saax, 
   {{0x764c0bf1,0xd8b400ec,0x00000000,0x00000000}},	//   sqay, _انجڻ_, --, --, 
   {{0x798803f9,0x61f89cfd,0x776c0067,0x00000000}},	//   ɗewa, _amtl, qaax, --, 
   {{0x764c7b10,0x00000000,0x00000000,0x00000000}},	//   qqay, --, --, --, 
   {{0x51841c65,0xd4e49cfe,0x95c89cff,0x5eec012c}},	//   суда, _люби, _сума_, ेछन्_, 
   {{0x628408fb,0x09e00327,0x00000000,0x00000000}},	//   _åkon, སྒྲ_, --, --, 
   {{0x43940117,0x60dc08fb,0x601c0200,0xcca40116}},	//   _насс, øpma, dëms, ەندۇ_, 
   {{0x600402d5,0x00000000,0x00000000,0x00000000}},	//   ўным_, --, --, --, 
   {{0xfe740131,0x00000000,0x00000000,0x00000000}},	//   чүш_, --, --, --, 
   {{0xad240075,0x00000000,0x00000000,0x00000000}},	//   تىدى, --, --, --, 
   {{0xeab89d00,0x81bc0374,0x2bd801f9,0x00000000}},	//   айм_, _whēt, _ढवळा, --, 
   {{0xcf249d01,0x81ac00bd,0x92e40011,0x601c002e}},	//   _اراي, গার_, _পশু_, rëmt, 
   {{0x5f400e56,0x7c6402f2,0x00000000,0x00000000}},	//   _تچىل, _کاول, --, --, 
   {{0xd9409d02,0x2c4400de,0x1b1800eb,0x00000000}},	//   дери, _pēdu_, নেলে_, --, 
   {{0xac1c030d,0x00000000,0x00000000,0x00000000}},	//   _шайĕ_, --, --, --, 
   {{0xa93401ec,0xa6c8009d,0x1f3400df,0x00000000}},	// [c440] сеңш, шлаа_, ַרער_, --, 
   {{0x3ea000c7,0x78540153,0x00000000,0x00000000}},	//   _ãite_, _sąve, --, --, 
   {{0xdd7804ac,0x00000000,0x00000000,0x00000000}},	//   שטעל, --, --, --, 
   {{0x86b402dd,0x00000000,0x00000000,0x00000000}},	//   _нәзі, --, --, --, 
   {{0x77909d03,0xdc3400c8,0x386c0e04,0x4254007b}},	//   _سیلا, קאנט_, ćere_, أنتر, 
   {{0x91e09d04,0x80b808f2,0x51f412fa,0xef1c0037}},	//   моче, ्मले, онію_, _पड़ऽ_, 
   {{0x80c40210,0x00000000,0x00000000,0x00000000}},	//   वमें, --, --, --, 
   {{0x645c02f6,0x7e98007b,0x00000000,0x00000000}},	//   mppi, منبر_, --, --, 
   {{0x645c005b,0xdee4007b,0x00000000,0x00000000}},	//   lppi, تأثي, --, --, 
   {{0x61f8014b,0x645c9d05,0x62800009,0x188c02d3}},	//   _umtl, oppi, mroo, _ዝፍጠር_, 
   {{0xa3ac0574,0xc0c49151,0x7e040137,0x00000000}},	//   _कसा_, _хәли, _ۉستۅ, --, 
   {{0x69d89d06,0x1ea800ec,0x645c9d07,0x601c036e}},	//   öten, _ناتي_, ippi, rëms, 
   {{0x62809d08,0xfe54010b,0xb78800fb,0x00000000}},	//   nroo, _эклэ, ҙәне_, --, 
   {{0x62800009,0x42d800cc,0x00000000,0x00000000}},	//   iroo, _দেৱশ, --, --, 
   {{0x62809d09,0x9f445f5e,0x17680131,0xd7f80124}},	//   hroo, _aloé_, ирап_, ауа_, 
   {{0x62809d0a,0xa6d42158,0x3a740354,0x0d8001ee}},	//   kroo, _সেইট, _елир, _елән, 
   {{0x9f440129,0x6280058a,0xdcf8031c,0x00000000}},	// [c450] _cloé_, jroo, fetħ, --, 
   {{0x62809c1c,0x81ac015b,0x2a640200,0xc1b400cd}},	//   droo, গাঁ_, _çoba_, ंयोग, 
   {{0x62809d0b,0xb7b800cc,0x00000000,0x00000000}},	//   eroo, _ইকীয়, --, --, 
   {{0x62800221,0x04c8088c,0x59c01bd6,0x00000000}},	//   froo, تومي_, शाकर, --, 
   {{0x62809d0c,0xa7540302,0x3448016c,0x59dc0b4e}},	//   groo, _משרד_, рӯҳи_, _नकार, 
   {{0x42b80058,0x216408a0,0x64480268,0x8ca802ab}},	//   زنىڭ_, пиши_, ìfic, _जनलो, 
   {{0x62809d0d,0xafe43b8f,0x00000000,0x00000000}},	//   aroo, зойл, --, --, 
   {{0xf40800cf,0xefc809ed,0x1ac8095f,0x6fc43885}},	//   _ايرى_, слил_, ामाथ, वाइं, 
   {{0xc6000154,0x2bb000bc,0x00000000,0x00000000}},	//   ্তরা_, _जसबा, --, --, 
   {{0x2718001e,0x81bc02b1,0x5ed80154,0x00000000}},	//   ỏng_, _whēr, _বেহে, --, 
   {{0xeaf4000d,0x00000000,0x00000000,0x00000000}},	//   ीप्त_, --, --, --, 
   {{0xeb989d0e,0xade804fb,0x00000000,0x00000000}},	//   щим_, _گفتم_, --, --, 
   {{0x67e8008c,0xad2415c3,0x00000000,0x00000000}},	//   _nýja, تىگى, --, --, 
   {{0x645c02f6,0x67200327,0x00000000,0x00000000}},	//   yppi, żojk, --, --, 
   {{0xdca09d0f,0x18641f71,0x1984013e,0x67e800a2}},	//   _защи, заси_, ябри_, _aýja, 
   {{0x62809d10,0x00000000,0x00000000,0x00000000}},	//   yroo, --, --, --, 
   {{0xa6841c3e,0xe5789d11,0x62809d12,0x9f480118}},	// [c460] ялад, йза_, xroo, ímém_, 
   {{0xe57801f0,0x62809d13,0xb0bc00b8,0x00000000}},	//   ёзе_, vroo, ्माग, --, 
   {{0xc600009e,0x657000b8,0x645c0108,0x234800d1}},	//   ্তলা_, _ādhī, uppi, ملاپ_, 
   {{0x62809d14,0xfd4c0084,0xe3b04130,0x645c9d15}},	//   troo, _dziṅ, عرا_, rppi, 
   {{0xd36c00b2,0x62809d16,0x00000000,0x00000000}},	//   اهه_, uroo, --, --, 
   {{0x62809d17,0xd1700075,0x24480347,0x52800d1f}},	//   rroo, ىدىغ, _هجري_, رلىك, 
   {{0xd12c5872,0x62809d18,0xd1709d19,0x00000000}},	//   همه_, sroo, ردوغ, --, 
   {{0x644c00a8,0x656c3058,0x62809d1a,0x6724002d}},	//   _iubi, _hebh, proo, _kykj, 
   {{0x644c9d1b,0x656c9d1c,0x626402dd,0x6280058a}},	//   _hubi, _kebh, _ءارق, qroo, 
   {{0x644c3dd4,0x67240c58,0xd24c0532,0x656c0066}},	//   _kubi, _mykj, _صنم_, _jebh, 
   {{0x67240b21,0x515802e4,0xeb300092,0x4e900066}},	//   _lykj, _הכבו, _በሕገወ, وشیر, 
   {{0x644c3182,0x656c48b5,0x661c4bc9,0x00000000}},	//   _mubi, _lebh, hopk, --, 
   {{0x644c9d1d,0x661c9d1e,0x7b18003b,0x00000000}},	//   _lubi, kopk, іогр_, --, 
   {{0x656c2c6b,0x644c9d1f,0x00000000,0x00000000}},	//   _nebh, _oubi, --, --, 
   {{0xda64004b,0x00000000,0x00000000,0x00000000}},	//   _کابي, --, --, --, 
   {{0xd8380323,0x6724143a,0xda787c3f,0xfc140006}},	//   сэг_, _bykj, _ляо_, _імпэ, 
   {{0x95486073,0x644c16b0,0x672400a2,0x4b7c011a}},	// [c470] مشاق_, _aubi, _cykj, _האחו, 
   {{0x9964006c,0x644c9d20,0x6724000f,0x67e800d0}},	//   _этил, _bubi, _dykj, _výja, 
   {{0x644c9d21,0x672402d0,0x383400db,0x00000000}},	//   _cubi, _eykj, _онор, --, 
   {{0x656c009a,0xed70010c,0xb4ac02c3,0xdee80092}},	//   _eebh, ቸስተር_, _कनी_, _ህግን_, 
   {{0x656c0921,0xa3ac1414,0xd5b80114,0x00000000}},	//   _febh, _कसर_, _лсв_, --, 
   {{0x656c9d22,0x644c003a,0x765c03ac,0xcb14008f}},	//   _gebh, _fubi, _itsy, עלס_, 
   {{0x644c04b9,0x5ed80183,0x80246241,0x2d9801d3}},	//   _gubi, _বেলে, کروم, ősek_, 
   {{0x656c0928,0x73c412ea,0xaec42e8d,0x00000000}},	//   _zebh, _تيرم, дбил, --, 
   {{0x644c9d23,0xddc00010,0x7e643c7a,0x717820c8}},	//   _zubi, _dvož, _çipl, _мбар_, 
   {{0x644c9d24,0x2d909d25,0xee380006,0x6c740166}},	//   _yubi, üze_, ўно_, мумх, 
   {{0x644c9d26,0xab7400f7,0x4fc49d27,0x69d826bb}},	//   _xubi, үгүш, _нсда, ötem, 
   {{0xddc09d28,0xcfa8115a,0x765c0083,0x00000000}},	//   _gvož, _دائم_, _otsy, --, 
   {{0x4ea40276,0xa3ac012d,0x00000000,0x00000000}},	//   _хреа, क़त_, --, --, 
   {{0x78540153,0xceb411ca,0xc9d401d3,0x6da4011c}},	//   _sąva, _дәү_, رمزک, _цика, 
   {{0x67240225,0x656c9d29,0xeb989d2a,0x765c010b}},	//   _sykj, _rebh, _дий_, _atsy, 
   {{0x644c9d2b,0x656c1929,0x6724002d,0x61d82ce6}},	//   _rubi, _sebh, _pykj, _बक्ष, 
   {{0x386c071b,0x656c006f,0x00000000,0x00000000}},	// [c480] ćera_, _pebh, --, --, 
   {{0xe5789d2c,0x291c0037,0x00000000,0x00000000}},	//   ізе_, ütas_, --, --, 
   {{0x656c9a1e,0x6724002d,0x644c0009,0xa9c00372}},	//   _vebh, _wykj, _qubi, _كۅڭۉ, 
   {{0x644c0564,0x64480137,0x672406ea,0x66e49d2d}},	//   _vubi, ífiq, _tykj, _жома, 
   {{0xd24c0075,0x644c016b,0x92540214,0x656c9d2e}},	//   ۇچە_, _wubi, وشور_, _tebh, 
   {{0x656c0472,0x20c402e8,0xa11402f2,0x00000000}},	//   _uebh, дсиг, ووشت, --, 
   {{0x15409d2f,0x00000000,0x00000000,0x00000000}},	//   _аерм, --, --, --, 
   {{0xd7bc00e8,0xc7b4013f,0x26c00427,0x00000000}},	//   _j胃pp_, koɑm_, _krko_, --, 
   {{0x8fa00b3e,0x2364010f,0xdeb00150,0x00000000}},	//   тање, mboj_, тұлы, --, 
   {{0x44240aa6,0x236401e4,0x3cd40395,0x00000000}},	//   _hkm_, lboj_, ежос, --, 
   {{0x44249d30,0xee941a4b,0xcf8c00f3,0x00000000}},	//   _kkm_, ودیک, _иј_, --, 
   {{0x9e642928,0x44249d31,0xa2c00b8f,0xddc009a8}},	//   _قاتن, _jkm_, लिप्, _uvož, 
   {{0x44249d32,0xbae452c8,0x4f840a81,0x1e940022}},	//   _mkm_, ركسي, _زانہ, _црер, 
   {{0x442401f4,0x3d94010a,0x00000000,0x00000000}},	//   _lkm_, _чикр, --, --, 
   {{0x26c09d33,0xa3ac1098,0xb4ac00c5,0x442401f4}},	//   _arko_, _कसं_, _कने_, _okm_, 
   {{0x27f09d34,0x2364655f,0x26c00841,0x44240129}},	//   ghyn_, jboj_, _brko_, _nkm_, 
   {{0x98ac0baf,0x26c00e3c,0x80c01d8a,0x9a8c01af}},	// [c490] ınız_, _crko_, विडे, _туйh, 
   {{0x6eb005f9,0xa2c09d35,0x49740139,0xdee80092}},	//   _अनसु, लिन्, _ильс, _ህግና_, 
   {{0x44249d36,0x26c00254,0xd76402dd,0x00000000}},	//   _bkm_, _erko_, _يەسى_, --, 
   {{0x27f09d37,0xdce800f3,0x00000000,0x00000000}},	//   chyn_, _nefč, --, --, 
   {{0x81d811ba,0x44249d38,0x765c332c,0xd2580024}},	//   াসন_, _dkm_, _utsy, цце_, 
   {{0xa90801a9,0x9f44007b,0xe294074d,0x442403e0}},	//   _idоr, _cloí_, хаш_, _ekm_, 
   {{0x442405da,0xe1200116,0x00000000,0x00000000}},	//   _fkm_, лмши, --, --, 
   {{0x6734022c,0x442401bf,0x04c8007b,0x00000000}},	//   _ígjø, _gkm_, _توفي_, --, 
   {{0xdce8007f,0x72040ed1,0x1e8000ee,0x69d833b4}},	//   _defč, _كورم, глым, ötek, 
   {{0x442401a6,0x10480108,0x35bc00fe,0xd20001af}},	//   _zkm_, _дяди_, _আকুহ, _шүлк, 
   {{0x7fb401b9,0x44240205,0x27f001f4,0x69cc0116}},	//   رلیچ, _ykm_, yhyn_, _ﮔﯜﻟﺰ, 
   {{0x30149d39,0x64589d3a,0x9f940022,0xbe0400e5}},	//   _ядер, _étie, _зышә, _یونٹ, 
   {{0x18a02cc8,0x00000000,0x00000000,0x00000000}},	//   һарм, --, --, --, 
   {{0x6d540790,0xe7b40066,0x00000000,0x00000000}},	//   ızas, کمرد, --, --, 
   {{0x6e2063e0,0xdd8c007b,0x98a0030d,0x27f003cb}},	//   molb, _اوى_, лире, thyn_, 
   {{0x2364002e,0x6bd40244,0xa2c01fc4,0x80c0084d}},	//   xboj_, _ستبر, लिम्, विते, 
   {{0x65c40323,0x8c3805f5,0x6fa025c9,0x6e200175}},	// [c4a0] нбаа, _нүүр_, क्यू, oolb, 
   {{0x6e2000a9,0x27f01368,0x00000000,0x00000000}},	//   nolb, shyn_, --, --, 
   {{0x69dc009a,0x74680212,0x25b80332,0xf7f400f1}},	//   _iope, дрів_, rdpl_, رسېد, 
   {{0xe2989d3b,0xd36c4630,0x69dc9d3c,0x44240036}},	//   зад_, مهم_, _hope, _qkm_, 
   {{0x69dc9d3d,0xd3209d3e,0x2364008f,0x26c0009d}},	//   _kope, льши, rboj_, _urko_, 
   {{0x69dc9d3f,0x95b40116,0xa2c00bc0,0x70bc0ad7}},	//   _jope, _прсә, लिब्, ्मूल, 
   {{0x69dc9d40,0xe4d86e9a,0x672000da,0x44249d41}},	//   _mope, _عورت_, ļoju, _tkm_, 
   {{0x69dc9d42,0x44249d43,0xe2980b87,0x1b180011}},	//   _lope, _ukm_, _наб_, নেটে_, 
   {{0x69dc9d44,0x2fdc039a,0x6e200477,0x11440116}},	//   _oope, _dowg_, folb, мпәй_, 
   {{0x69dc9d45,0x6e20951a,0x61449d46,0x1278010f}},	//   _nope, golb, _зеза, _מאמע, 
   {{0xd00c026b,0xf1a8015e,0x00000000,0x00000000}},	//   _бф_, _زاله_, --, --, 
   {{0x69dc9d47,0xcfac00bd,0x78540024,0x61e80fac}},	//   _aope, কাউন, _sąvo, lkfl, 
   {{0x69dc9d48,0x2bb004fa,0xb4ac687b,0x6e209d49}},	//   _bope, _जसरा, _कन्_, bolb, 
   {{0x69dc9d4a,0x61e828dc,0x6e200076,0x06e40154}},	//   _cope, nkfl, colb, _নেভি, 
   {{0x386c05be,0x394401e3,0x00000000,0x00000000}},	//   ćero_, äls_, --, --, 
   {{0x69dc035a,0x0828084c,0x00000000,0x00000000}},	//   _eope, ецуи_, --, --, 
   {{0x69dc02fa,0x61e803cd,0xe7780022,0x00000000}},	// [c4b0] _fope, kkfl, ьатә_, --, 
   {{0x98489d4b,0xfd50063f,0x69dc9d4c,0x7bcc02d2}},	//   _няма_, _rudị, _gope, _hnau, 
   {{0xd6f800b5,0x47e00154,0xd4040131,0x00000000}},	//   _ccを_, _নগরী, няди, --, 
   {{0x69dc9d4d,0x61e801f5,0x00000000,0x00000000}},	//   _zope, ekfl, --, --, 
   {{0x69dc9d4e,0x7bcc01f7,0x00000000,0x00000000}},	//   _yope, _mnau, --, --, 
   {{0x1e18068f,0x69dc02c4,0xdb1c0166,0xe3c4008e}},	//   नकोष_, _xope, _inqä, ерәү, 
   {{0x70bc19e5,0xd3a404db,0x7bcc0093,0x2bb0012c}},	//   ्मेल, _прап, _onau, _जसला, 
   {{0x7bcc01f7,0x73c40022,0x00000000,0x00000000}},	//   _nnau, _шәзе, --, --, 
   {{0xee389d4f,0xef189d50,0x20540c75,0x6e200003}},	//   мни_, ьми_, нтөр, tolb, 
   {{0x64585fd9,0x7bcc9d51,0x61e80112,0xa6e00321}},	//   _étic, _anau, ckfl, úðin, 
   {{0xa8044ba9,0xfd00004e,0x00000000,0x00000000}},	//   lmış, йүшп, --, --, 
   {{0x6e209d52,0xaaac00bc,0x1b1800eb,0x00000000}},	//   solb, टबलक, নেছে_, --, 
   {{0x69dc9d53,0xa8044ba9,0x7ee40014,0x38600332}},	//   _pope, nmış, _مسؤ, _athr_, 
   {{0x7bcc9d54,0x69dc72a3,0xa2c06766,0x6e2001d5}},	//   _enau, _qope, लित्, qolb, 
   {{0xdb1c0227,0x6578025a,0x9f440270,0x69dc0099}},	//   _anqä, _ôthi, _iloá_, _vope, 
   {{0x7bcc1529,0x69dc9d55,0x6ab40109,0xa80405d1}},	//   _gnau, _wope, _tsyf, kmış, 
   {{0x81d800fe,0x00000000,0x00000000,0x00000000}},	// [c4c0] াসত_, --, --, --, 
   {{0x69dc04cc,0xa80406be,0x96a4013d,0x00000000}},	//   _uope, dmış, ъкуб_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd4640063,0x2284010b,0x81ac0154,0x00000000}},	//   тице_, вукг, গাছ_, --, 
   {{0x8004063f,0x92b0007b,0x69c4012d,0x69c801e1}},	//   ịakọ_, لحوا, ायपी, _òfes, 
   {{0xa3ac05f9,0xa0a401c0,0x64a40124,0x53300063}},	//   _कसक_, вшил, _иага, јешт, 
   {{0x6f1802d0,0x91e00063,0x33b000db,0xd54401af}},	//   _axwc, роје, _گەنر, _апре_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2bd40b9c,0x4cdc0154,0x27fc02f0,0x06e40011}},	//   धाना, _ফেলু, étny_, _নেতি, 
   {{0x63a09d56,0x7bcc0363,0xa28001d3,0xe8001100}},	//   lfon, _snau, _میچو, रोता_, 
   {{0x614407d6,0x63a001e4,0x00000000,0x00000000}},	//   _режа, ofon, --, --, 
   {{0x1e842386,0x00000000,0x00000000,0x00000000}},	//   _алдм, --, --, --, 
   {{0xdd90402b,0x80c09d57,0x63a00421,0x00000000}},	//   _نوش_, विवे, ifon, --, 
   {{0x63a0010a,0xdb0c0200,0xdb080248,0x00000000}},	//   hfon, lecë, _àníy, --, 
   {{0xa8049d58,0x63a00007,0xdb4c0014,0xdec00023}},	//   zmış, kfon, _وێد_, ድኣኒ_, 
   {{0x7bcc9d59,0xc864234c,0x81d8015b,0x00000000}},	//   _unau, ртри, াসি_, --, 
   {{0x63a09d5a,0xa8040213,0xc674007b,0xe8000c6f}},	// [c4d0] dfon, xmış, لطلب, रोधा_, 
   {{0xd508282f,0x63a09d5b,0x2b5c00bc,0xca7400d1}},	//   وغان_, efon, ětce_, _ئايغ, 
   {{0x81d8015b,0x38600042,0xd4989d5c,0x00000000}},	//   াসা_, _uthr_, ьра_, --, 
   {{0xa80445a5,0x63a05008,0xe80001ad,0xdec00023}},	//   tmış, gfon, रोदा_, ድኣና_, 
   {{0xfba408df,0x00000000,0x00000000,0x00000000}},	//   ग्यम, --, --, --, 
   {{0xa8049d5d,0x63a09d5e,0x79940399,0x51849d5f}},	//   rmış, afon, ngzw, туда, 
   {{0x63a00066,0x8edc00cc,0xa8042ca8,0x00000000}},	//   bfon, _বেংগ, smış, --, 
   {{0x942004a9,0xa8040259,0x6458003a,0x33440014}},	//   _ئورۇ, pmış, _étia, _منزِ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x80c00882,0x2bd480a0,0x00000000,0x00000000}},	//   विशे, धाभा, --, --, 
   {{0xeb989d60,0xac089d61,0x00000000,0x00000000}},	//   нин_, енна_, --, --, 
   {{0x7ff418a2,0x3ec805d5,0x32040419,0xbec800ef}},	//   _پسما, üttà_, _hmly_, _slūž, 
   {{0x6da45c81,0xcc8403e6,0xcee89d62,0x2d9401af}},	//   _била, رۆکه_, _تران_, _йөнө_, 
   {{0x6c049d63,0x3c3801d3,0x7ae8003b,0x7ed402f2}},	//   _әзиз, véve_, øeta, _خزما, 
   {{0x63a09d64,0x2c44005f,0xb4ac000d,0x3a140166}},	//   yfon, _mēdz_, कबो_, рьяс, 
   {{0x68449d65,0xfd1004d3,0xeb98033a,0x5ed800cc}},	//   унба, _بجه_, _џип_, _বেটে, 
   {{0xe7080345,0x37740150,0x00000000,0x00000000}},	// [c4e0] رترن_, рысс, --, --, 
   {{0x63a002fa,0xa2c00d2c,0x00000000,0x00000000}},	//   wfon, लिस्, --, --, 
   {{0xdecc693c,0x63a09d66,0x35c805f9,0xa3e89d67}},	//   _እውን_, tfon, राज़, нджа_, 
   {{0x248401a2,0xa3b80137,0x63a0037e,0x32040051}},	//   čom_, عاار_, ufon, _amly_, 
   {{0xc69404ac,0xc2040124,0x67e8032e,0x00000000}},	//   _דאָ_, аҟаи, _nýji, --, 
   {{0x80c0041c,0xdcf80419,0x323801d5,0x850401af}},	//   विले, vetľ, نينگ_, _күзз, 
   {{0xee0803f4,0xe4580212,0xf3ec014b,0xd3780150}},	//   রকাশ_, _їжа_, _дӣ_, _бiры, 
   {{0x64a40124,0xc0340640,0x00000000,0x00000000}},	//   _иаҳа, јниј, --, --, 
   {{0x3df4252f,0x64409d68,0x629c0311,0x6aac01ad}},	//   изис, mmoi, ăpos, टबोर, 
   {{0xfdc80019,0xdd980364,0x644002f6,0x81d8015b}},	//   ттиқ_, хши_, lmoi, াসহ_, 
   {{0xd00c9d69,0xab6005d1,0x9cc8010b,0x03fc0055}},	//   _کلن_, ğünd, хыпа_, _śiṣm, 
   {{0xab609d6a,0x64409d6b,0x92d40c58,0x6284003b}},	//   şünd, nmoi, ানৰ_, _åkos, 
   {{0xa2b800e1,0x64400076,0x00000000,0x00000000}},	//   _शैम्, imoi, --, --, 
   {{0x7b840372,0xe80000af,0x4a540f14,0x8e809d6c}},	//   داگە, रोसा_, скрс, _الوه, 
   {{0x27e003cd,0xdce80356,0xb80805af,0xc864004e}},	//   _bokn_, _defă, نيسم_, йтти, 
   {{0xb8dc9d6d,0xd7e40372,0x7ac404b3,0xc6a40131}},	//   _इन_, دورۇ_, _көга, әрти, 
   {{0x36d41b2e,0x7b18136b,0x644006af,0x2a700142}},	// [c4f0] шоар, _шоир_, dmoi, _gwyb_, 
   {{0xd1cc0020,0x69d829a8,0xd1d40023,0x7e640205}},	//   ጣበት_, ötet, ሬታት_, _çipu, 
   {{0x38c83821,0xe8000034,0xdb0c0077,0x20040022}},	//   _شادی_, रोहा_, decé, _omoi_, 
   {{0x64400221,0x7afc01f5,0x43740137,0x73c418c7}},	//   gmoi, ozst, бушт, шәге, 
   {{0xa2c00b7c,0x776c0548,0x64589d6e,0x7afc0ade}},	//   लिष्, mbax, _étin, nzst, 
   {{0x14749d6f,0x200431e5,0x947469d2,0x776c0009}},	//   _مارج, _amoi_, _مدرا, lbax, 
   {{0xa1540063,0x6ff43633,0x69c405c0,0x00000000}},	//   шају_, ичих, ायती, --, 
   {{0xafe49d70,0x776c0014,0xdb0c067c,0x798402d0}},	//   роил, nbax, pecè, _ldhw, 
   {{0x026403e6,0x6fa0043e,0x5fa000d1,0x92e000cc}},	//   _هێنێ, क्षू, تەنم, _ফেৰ_, 
   {{0x67e8012c,0x61441e4a,0x5ed803d4,0x7afc00de}},	//   _výji, _چىكە, _বেঙে, dzst, 
   {{0xcdc00fc0,0xdce8054e,0xff5000f1,0x0244009f}},	//   _ҳалқ, _refă, _ځخه_, _اَلَ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x776c9d71,0x27e00162,0x63a401e3,0xfba4043e}},	//   dbax, _rokn_, _ökne, ग्धम, 
   {{0xfe700272,0x27e000fe,0xee089130,0x00000000}},	//   _رده_, _sokn_, _шелл_, --, 
   {{0x7afc05c7,0x776c0009,0x6440062c,0xac38009d}},	//   azst, fbax, ymoi, _ичих_, 
   {{0x64409d72,0xa7649d73,0x377401e0,0x38040107}},	//   xmoi, ркад, йыус, босҳ, 
   {{0x9774013d,0x69d801e3,0x00000000,0x00000000}},	// [c500] ртсә, ötes, --, --, 
   {{0x64a400c7,0x28e80276,0x79840175,0x3c38035b}},	//   иаза, _адоп_, _gdhw, méva_, 
   {{0x27e00109,0x776c0429,0x29300131,0x601c00e2}},	//   _tokn_, bbax, ﺭﯛﭖ_, līme, 
   {{0x776c0067,0x234800d1,0x644001f4,0x00000000}},	//   cbax, نلاپ_, umoi, --, 
   {{0x7c3c0d47,0x3c3800c7,0x00000000,0x00000000}},	//   ïrri, néva_, --, --, 
   {{0x64401e0b,0x64589d74,0xe6180276,0x00000000}},	//   smoi, _étio, _рдг_, --, 
   {{0xc3c41cd1,0xdb0c9d75,0x25a800d8,0x40a83321}},	//   _гөлл, recé, _ibbl_, اختی_, 
   {{0x7afc9d76,0xc7b4013f,0x6fa000e1,0x3c380124}},	//   yzst, neɑ_, क्लू, kéva_, 
   {{0x386c16a3,0xdcf80115,0x3c3800c7,0x224801f0}},	//   ćeri_, matĉ, jéva_, _апаи_, 
   {{0xbdf400ea,0xab6003e0,0x00000000,0x00000000}},	//   спој, şüld, --, --, 
   {{0x6ed8237e,0x776c01a9,0xa09801af,0x00000000}},	//   _ەدىڭ_, ybax, _штаф_, --, 
   {{0x7afc03fa,0x776c058a,0x00000000,0x00000000}},	//   tzst, xbax, --, --, 
   {{0x8fa00276,0xd00c00f1,0x9ce4015b,0x7afc35ca}},	//   _фаче, _غله_, খছেন_, uzst, 
   {{0xd6f8037e,0x7afc9d77,0x25a803cd,0x00000000}},	//   _fcオ_, rzst, _nbbl_, --, 
   {{0xfc641968,0x776c9d78,0xd84001ef,0x00000000}},	//   _اختی, tbax, hačů_, --, 
   {{0x25a80cad,0xe80002ab,0x69d89d79,0x775400d8}},	//   _abbl_, रोला_, öter, скаф, 
   {{0x67e8008c,0xd6f804ce,0xa3d8033f,0x776c2009}},	// [c510] _nýju, _icカ_, ़ान_, rbax, 
   {{0x954810fe,0x6f0c01a6,0xd9380116,0xd8400118}},	//   نشاق_, _žack, _үчүш_, dačů_, 
   {{0xc7b4013f,0x7c2c9d7a,0x64580098,0x0f340023}},	//   beɑ_, _kkar, _étil, _ብድሕረ, 
   {{0xdcf800fd,0xef180210,0x00000000,0x00000000}},	//   netı, laże_, --, --, 
   {{0x7c2c9d7b,0x00000000,0x00000000,0x00000000}},	//   _mkar, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x92d46569,0x7c2c9d7c,0x601c005f,0x2bc8043e}},	//   ানে_, _okar, zīme, ियमा, 
   {{0x43949d7d,0x7c2c0c11,0xc9180bd4,0x0fe404a9}},	//   _масс, _nkar, יחות_, рлиқ_, 
   {{0x9184168d,0xed589d7e,0x628433b8,0xada43e1f}},	//   _نجام, лоп_, _åkop, бапл, 
   {{0x3c3807dd,0xd1b89d7f,0x9100004b,0x7644003e}},	//   véva_, _جارا_, _وژغو, nmhy, 
   {{0xec4801c6,0xdb1c036e,0xef18012d,0xca3002dd}},	//   лзол_, _faqë, daże_, _ﺩﺍﺨ_, 
   {{0x7c2c1529,0x6e940276,0xa3d800c5,0x3c380588}},	//   _ckar, _гиду, ़ाय_, téva_, 
   {{0xad242928,0x3afc06af,0x7f8c00df,0x00000000}},	//   شىڭى, _râpé_, _ינאַ, --, 
   {{0x7c2c9d80,0xfe700014,0xdee09d81,0x2a140a89}},	//   _ekar, _آدن_, _хоши, сьмё, 
   {{0x7c2c0270,0x291c9d82,0x6c84004b,0xa3d805f9}},	//   _fkar, çta_, _البم, ़ाम_, 
   {{0xfe5401d5,0xeb980c69,0x99800118,0x3c380124}},	//   _دییب_, _сии_, bojů_, péva_, 
   {{0xe6189d83,0xaea005d1,0x060800fb,0xa6c80022}},	// [c520] гда_, _çığl, амаҫ_, ылаа_, 
   {{0xfd581682,0xd6cc007b,0xd84000bc,0xd44c0150}},	//   fhaṱ, عقل_, vačů_, _ﺑﺎﺭﯨ_, 
   {{0x92d42aab,0x7c2c9d84,0x00000000,0x00000000}},	//   ানো_, _ykar, --, --, 
   {{0x86b40220,0x64589d85,0xd8400118,0x00000000}},	//   _мәзі, _étim, tačů_, --, 
   {{0xa1840304,0xb6c401af,0x00000000,0x00000000}},	//   быйл, _дияһ, --, --, 
   {{0x3ea0049b,0x27f000ee,0xe5ac01e1,0x00000000}},	//   _äiti_, lkyn_, _àlàà, --, 
   {{0xdb1c0023,0xdcf80205,0x00000000,0x00000000}},	//   _paqë, yetı, --, --, 
   {{0x9cc89d86,0x68f8045f,0x27f09d87,0xdd3003e0}},	//   ңына_, útdy, nkyn_, _aşşa, 
   {{0xdcf80724,0x216800ee,0xf1a8030f,0x00000000}},	//   vetı, _бизи_, _چامه_, --, 
   {{0xf1a8083b,0x62802430,0xdec801e0,0xbb3c02dd}},	//   _نامه_, msoo, _ҡулл_, _ﺑﻮﻻ_, 
   {{0x62809d88,0xdcf80724,0x11d400c6,0x7c2c01d5}},	//   lsoo, tetı, _دولة_, _pkar, 
   {{0x657c9d89,0x62800b23,0x68ec0450,0xca3002dd}},	//   haph, osoo, dybd, _ﺩﺍﺭ_, 
   {{0x657c4e15,0x7c2c0a73,0x614002f0,0x4e140214}},	//   kaph, _vkar, bílé, شتید_, 
   {{0x62809d8a,0x9980012c,0x657c0472,0xb7c403d4}},	//   isoo, rojů_, japh, _একেট, 
   {{0x657c0bd7,0x28c40107,0x62800067,0xef18012d}},	//   daph, оштҳ, hsoo, raże_, 
   {{0x7c2c9d8b,0x62809d8c,0xdb0c283a,0x998000bc}},	//   _ukar, ksoo, lecí, pojů_, 
   {{0x657c9d8d,0x44c847af,0x2bd40aa2,0x78c40153}},	// [c530] faph, _ağ_, धारा, _žuvė, 
   {{0x657c136f,0xdb0c2b76,0x62809d8e,0x94741d10}},	//   gaph, necí, dsoo, مدصا, 
   {{0x948402de,0x62809d8f,0xfbdc07f7,0x3c3800e4}},	//   сызд, esoo, यापम, névo_, 
   {{0x62800408,0x43749d90,0xdb0c0120,0x2eec022f}},	//   fsoo, пушт, mecâ, yyef_, 
   {{0x657c2747,0x62809d91,0x93240150,0x386c01a6}},	//   baph, gsoo, حران, ćeru_, 
   {{0x657c2747,0xa2b806ab,0x67440030,0x2164013e}},	//   caph, _एनर्, ňujú, оиши_, 
   {{0x61409d92,0x73c4005e,0x91bc063f,0x80c047d0}},	//   меша, _мәде, _atụ_, विगे, 
   {{0x62807361,0x5e600241,0xae8828ed,0x00000000}},	//   bsoo, _sọọj, абиз_, --, 
   {{0xdb0c09c2,0xfbdc3f79,0x63a4007c,0x5194010a}},	//   fecí, यानम, _ökna, _лăпа, 
   {{0xac849d93,0xb7c403d4,0xc0d40023,0x00000000}},	//   огол, _একোট, ራሃም_, --, 
   {{0x62240220,0x3c380022,0x27f001f4,0x2bd4276a}},	//   _بولە, gévo_, ykyn_, धाला, 
   {{0x657c9d94,0xdb0c0356,0x00000000,0x00000000}},	//   zaph, decâ, --, --, 
   {{0xce68418d,0xa3d82ba2,0x8af003b9,0x2b380262}},	//   _сред_, ़ात_, _afər, рянэ_, 
   {{0x0dc815ed,0x657c0194,0x00000000,0x00000000}},	//   _људи_, xaph, --, --, 
   {{0x27f00108,0x1d040117,0x00000000,0x00000000}},	//   tkyn_, _меши_, --, --, 
   {{0x6ecc0316,0x62800429,0x657c9d95,0x68ec0381}},	//   तिपु, ysoo, waph, rybd, 
   {{0x27f09d96,0x6280058a,0xa68401d5,0x00000000}},	// [c540] rkyn_, xsoo, юлад, --, 
   {{0x27f01368,0x64589d97,0x93c801d3,0x00000000}},	//   skyn_, _étik, یانہ_, --, 
   {{0x78ac012c,0x1aec015b,0x2ca40175,0x62800175}},	//   čová, _চেপে_, ntld_, wsoo, 
   {{0x7174693c,0x657c9d98,0x62809d99,0xd36c9d9a}},	//   _ጽሕፈት_, saph, tsoo, نهم_, 
   {{0x62800194,0x00000000,0x00000000,0x00000000}},	//   usoo, --, --, --, 
   {{0x62809d9b,0x657c0928,0xa088036b,0xded402d3}},	//   rsoo, qaph, асиз_, _ይኾኑ_, 
   {{0xdb0c0077,0xa3d8033f,0xd1b402c9,0x00000000}},	//   vecí, ़ाद_, زاوا_, --, 
   {{0xbb3c1d00,0x3c380124,0x00000000,0x00000000}},	//   _ﺑﻮﻱ_, vévo_, --, --, 
   {{0xdef89d9c,0x3f140801,0xdb0c04d4,0x5fa43ec5}},	//   рый_, ядис, tecí, क्षल, 
   {{0x61449d9d,0x3c380124,0x00000000,0x00000000}},	//   _деза, tévo_, --, --, 
   {{0xdb0c09ff,0x61f803ac,0x00000000,0x00000000}},	//   recí, _iltl, --, --, 
   {{0x5f289d9e,0x5c040006,0x2bb0012d,0x9c089d9f}},	//   _коем_, іяна, ज़गा, рхоз_, 
   {{0xbb300131,0x3c3800e4,0x00000000,0x00000000}},	//   ﺪﯨﻢ_, sévo_, --, --, 
   {{0xdb1c00db,0x628c005f,0x3c3800e4,0x00000000}},	//   _inqü, _ābol, pévo_, --, 
   {{0xd8080500,0x00000000,0x00000000,0x00000000}},	//   ахал_, --, --, --, 
   {{0x3e600699,0xd774007b,0x32480023,0x6c68009f}},	//   _kòt_, تاسع, _ምዃንኩ, _اليہ_, 
   {{0x35f411cc,0xda6486bf,0xd9a8004e,0x00000000}},	// [c550] ппар, _بابي, _кънд_, --, 
   {{0x3e60068c,0xdb0c00db,0x82c80327,0x00000000}},	//   _mòt_, mecà, _གླེའ, --, 
   {{0x3e6011c1,0xdfc400b2,0x0c040014,0x7ae800f1}},	//   _lòt_, _ٻي_, _رویُ, _خوښې_, 
   {{0x61f89da0,0xdb1c0bc9,0x04c8004b,0x6ecc08df}},	//   _altl, _jaqï, غوني_, तिमु, 
   {{0x3e600699,0xa2c01fd2,0xef180327,0x38b40248}},	//   _nòt_, लिग्, każa_, búrò_, 
   {{0x068401d9,0x95c80408,0xfbdc00bc,0x00000000}},	//   _زلفُ, _тума_, याडम, --, 
   {{0x65800014,0x765c010e,0x00000000,0x00000000}},	//   _سینٕ, _husy, --, --, 
   {{0x765c9da1,0x3e609da2,0x61f80477,0x2ee407d8}},	//   _kusy, _bòt_, _eltl, зжиг, 
   {{0x3e600100,0x80248ee7,0x75340432,0x777c9da3}},	//   _còt_, بروم, _hyzz, _mesx, 
   {{0x765c9da4,0x3e60204d,0xddc803ee,0x777c0166}},	//   _musy, _dòt_, ğişe, _lesx, 
   {{0x76540007,0xdb1c180f,0x624801d9,0x753400a2}},	//   _mizy, _enqü, _آلہ_, _jyzz, 
   {{0xe6702c6f,0x7654662e,0x3e60033b,0x765c9da5}},	//   _ölçü, _lizy, _fòt_, _ousy, 
   {{0x3e60067c,0x765c0ac5,0xef180327,0xd09401ee}},	//   _gòt_, _nusy, baża_, _ышҡы, 
   {{0x7e28007b,0x00000000,0x00000000,0x00000000}},	//   _وسوف_, --, --, --, 
   {{0xac985a16,0x3e60033b,0x765c0153,0xd940442d}},	//   _انعا_, _zòt_, _ausy, еери, 
   {{0x765c9da6,0x9ba01c62,0x7a40013a,0x00000000}},	//   _busy, _كەپى, _pátý, --, 
   {{0xbb3004a9,0x76540399,0xdb9823e4,0x777c9307}},	// [c560] ﺪﯨﻦ_, _bizy, _הספר, _desx, 
   {{0x2c601dee,0x76540007,0x240804a9,0x765c9bdb}},	//   _kód_, _cizy, әнди_, _dusy, 
   {{0x6fbc0be7,0xd1d01540,0x765432a9,0xdb0c09c2}},	//   ्यां, ያናት_, _dizy, mecá, 
   {{0x2c609cba,0x82c8031c,0x7b0005d1,0x77902a77}},	//   _mód_, _གླུའ, _öztü, _لیفا, 
   {{0x765c0223,0x76549da7,0xfbdc1221,0x2c609da8}},	//   _gusy, _fizy, यातम, _lód_, 
   {{0x76540007,0x26c09da9,0x3e600428,0x00000000}},	//   _gizy, _isko_, _ròt_, --, 
   {{0xf1a89daa,0x777c0070,0x3e6002bd,0x75340432}},	//   تانه_, _yesx, _sòt_, _gyzz, 
   {{0x3e609dab,0x7654007f,0xef18012d,0x00000000}},	//   _pòt_, _zizy, waża_, --, 
   {{0x6140318e,0xdb1c0548,0xdef00023,0xdb0c02f0}},	//   _bílí, _raqï, ልቲኡ_, kecá, 
   {{0xf4080003,0x3e6002bd,0xa3d82871,0x41c000bc}},	//   _གཏོད_, _vòt_, ़ाव_, _एसिस, 
   {{0x2c600597,0x3b840372,0xdc3c012c,0xdb0c0077}},	//   _cód_, үлүг, síčn, decá, 
   {{0x236404ac,0x26c00115,0xdb0c00cf,0xe0440166}},	//   ncoj_, _osko_, tecà, _энеи, 
   {{0xa2c001ad,0x25b80158,0x61400332,0x6d6403b2}},	//   लिट्, kepl_, _fílí, ætað, 
   {{0x765c9dac,0x2c6001e7,0x5eb00154,0x00000000}},	//   _rusy, _fód_, জিদে, --, 
   {{0x26c00323,0xd90c034c,0x765c02d1,0x23640007}},	//   _asko_, ایج_, _susy, kcoj_, 
   {{0x76549dad,0xd1c002d3,0xfb34010b,0x984802e8}},	//   _sizy, _ጻድቕ_, _онйэ, сяга_, 
   {{0x765c0ac5,0x983c0092,0x2bc800cd,0x00000000}},	// [c570] _qusy, _በእልቅ, ियरा, --, 
   {{0x23640115,0x00000000,0x00000000,0x00000000}},	//   ecoj_, --, --, --, 
   {{0x76549dae,0x1dac0882,0x26c00821,0x34b81063}},	//   _vizy, ज्यत, _esko_, تهاج_, 
   {{0x76540034,0xb328025c,0x7338014b,0x765c0055}},	//   _wizy, _སྙུང_, озер_, _tusy, 
   {{0x3870070d,0x6fbc725a,0x76540139,0x765c0108}},	//   lpzr_, ्यसं, _tizy, _uusy, 
   {{0x42b80131,0x236401e4,0xa2c005d7,0x690000a2}},	//   سنىڭ_, acoj_, लिज्, _öydü, 
   {{0xa2500066,0x00000000,0x00000000,0x00000000}},	//   خپوش, --, --, --, 
   {{0xb4e84108,0x2c609daf,0xe9f40150,0x61409db0}},	//   यही_, _ród_, _تﺮ_, _sílí, 
   {{0xa3d8068f,0xdb1c0139,0xbf64216b,0xfba000d1}},	//   ़ार_, _baqí, رديو, _ﺋﯚﺯﯛ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xcf2400f1,0x5e5400f1,0x00000000,0x00000000}},	//   _کراي, ګلیس_, --, --, 
   {{0x2ef49db1,0x00000000,0x00000000,0x00000000}},	//   _озер, --, --, --, 
   {{0x6140022c,0xa9689db2,0xada401b9,0x6da45348}},	//   _tílí, жига_, _жалл, _жила, 
   {{0x7c64598b,0x7d2800dd,0x2bd800e1,0x6cf8030d}},	//   بایل, épsé, _बचका, _мелĕ, 
   {{0xd9fc10f7,0x18a00209,0x18649db3,0x98a019c7}},	//   _उतरत_, карм, даси_, кире, 
   {{0x660c208d,0xdb1c0139,0x00000000,0x00000000}},	//   _smbk, _zaqí, --, --, 
   {{0xdb0c0120,0xdcf89db4,0x65c42360,0x00000000}},	// [c580] pecá, matā, мбаа, --, 
   {{0x2bd400cd,0xdb1c0139,0x00000000,0x00000000}},	//   धाका, _xaqí, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdcf89db5,0x2498020c,0x00000000,0x00000000}},	//   natā, rupm_, --, --, 
   {{0x26c09db6,0xa22800a7,0x05000154,0x2364008f}},	//   _usko_, ожда_, ্থের_, rcoj_, 
   {{0xdcf80882,0xddc00219,0x660c0037,0xa5080354}},	//   hatā, _otoš, _umbk, _дега_, 
   {{0xdcf89db7,0xa2c016d1,0x00000000,0x00000000}},	//   katā, लिङ्, --, --, 
   {{0x15409db8,0x23289db9,0x8fa00063,0x00000000}},	//   _ресм, _доби_, ваће, --, 
   {{0xfbdc412f,0xdcf800cd,0x00000000,0x00000000}},	//   यासम, datā, --, --, 
   {{0xb328038f,0xdb0c315a,0xb8d0031c,0x00000000}},	//   _སྙིང_, lecç, _ནྱ_, --, 
   {{0x559425f9,0x91e09dba,0xf1c400d1,0xfc14013d}},	//   ודיע_, _шофе, _سۈيى_, емнэ, 
   {{0xdcf80882,0xdb0c00d8,0xdb1c00fd,0x00000000}},	//   gatā, necç, _waqí, --, 
   {{0x3f849dbb,0x2df80517,0x7538033f,0xae6401ec}},	//   mamu_, زبیک_, ęwzi, _كەين_, 
   {{0x3f849dbc,0x00000000,0x00000000,0x00000000}},	//   lamu_, --, --, --, 
   {{0xf8b800f7,0xdcf80171,0x00000000,0x00000000}},	//   чөп_, batā, --, --, 
   {{0x3f849dbd,0x1cac025c,0xdb0c0798,0xdcf8002b}},	//   namu_, _ཕྱར_, jecç, catā, 
   {{0xa5080dd4,0x00000000,0x00000000,0x00000000}},	// [c590] _གཟུག_, --, --, --, 
   {{0x3f849dbe,0x05741df2,0x00000000,0x00000000}},	//   hamu_, نامد, --, --, 
   {{0xdb0c06ed,0x00000000,0x00000000,0x00000000}},	//   fecç, --, --, --, 
   {{0x3f849dbf,0x00000000,0x00000000,0x00000000}},	//   jamu_, --, --, --, 
   {{0x3f849dc0,0xf07401ed,0x1cac0327,0x00000000}},	//   damu_, ڑیاں_, _ཕྱལ_, --, 
   {{0x9fac009e,0x21a0010b,0x6ecc2e35,0xa2d0009f}},	//   কযোগ, гишм, तिसु, ايوت, 
   {{0xdcf80882,0x93a449a4,0x3f840a55,0x465847f9}},	//   yatā, _ошад, famu_, _царю_, 
   {{0xa2b8242e,0x3f849dc1,0xaec479a7,0x386001a9}},	//   _शैक्, gamu_, ебил, _muhr_, 
   {{0xef189dc2,0xb8d05078,0xf1d00184,0xdcf80a28}},	//   ями_, _ནཱ_, _бөйө, vatā, 
   {{0x64580137,0x20549dc3,0x00000000,0x00000000}},	//   _ètic, мтөр, --, --, 
   {{0x69c801a8,0x3860002f,0x00000000,0x00000000}},	//   _ófei, _nuhr_, --, --, 
   {{0x3f849dc4,0xe93c031c,0x00000000,0x00000000}},	//   camu_, ħażż, --, --, 
   {{0x4438013f,0xdcf80882,0xbec402dd,0xfa800150}},	//   _ɔr_, ratā, _аңыз_, ақым, 
   {{0x6da43bbd,0xada40ede,0x00000000,0x00000000}},	//   _чика, _чакл, --, --, 
   {{0x2d849dc5,0x7d44001f,0x659401d9,0x5fa401ef}},	//   male_, _የፓርቲ, ہجار, क्कल, 
   {{0x66e49dc6,0x3cf89dc7,0xb4e80210,0x00000000}},	//   ноба, _تعهد_, यहै_, --, 
   {{0x6b849dc8,0x38540801,0x5d500116,0x6a84010b}},	// [c5a0] makg, търс, _икәт, _ялпа, 
   {{0x3f849dc9,0x6b849675,0x38600e78,0x66e401f0}},	//   zamu_, lakg, _fuhr_, _ҷома, 
   {{0xe3b89dca,0xdb0c06ed,0x3f849dcb,0x2d84000d}},	//   збе_, tecç, yamu_, iale_, 
   {{0x2d849dcc,0x6b845bae,0x3f8402c4,0xdcf8054e}},	//   hale_, nakg, xamu_, lată, 
   {{0xdb0c0120,0x3f849dcd,0x66e400d8,0x00000000}},	//   recç, vamu_, _џога, --, 
   {{0x2d849dce,0x3f849dcf,0x6b848f49,0x64a469e2}},	//   jale_, wamu_, hakg, _пага, 
   {{0x2d849dd0,0x15409dd1,0x3f849dd2,0x6b8427be}},	//   dale_, _берм, tamu_, kakg, 
   {{0xa5080107,0xef90036b,0x2d840254,0x00000000}},	//   _деҳа_, لیمد, eale_, --, 
   {{0x2d847eb8,0x63a00579,0x442401f7,0x81c40124}},	//   fale_, mgon, _ijm_, _иааҧ, 
   {{0x2d849dd3,0x63a09dd4,0x00000000,0x00000000}},	//   gale_, lgon, --, --, 
   {{0x716425aa,0x3f849dd5,0xfcc49dd6,0xf1a803e6}},	//   _شالك, pamu_, тәлм, _تاقه_, 
   {{0x38609dd7,0x6b849dd8,0x92b00183,0x3f840ba7}},	//   _ruhr_, gakg, টিৰ_, qamu_, 
   {{0x2d849dd9,0x63a09dda,0x4f8401d9,0x3860002b}},	//   bale_, igon, _سانہ, _suhr_, 
   {{0x63a00399,0xdc8800d1,0xfaa40124,0x6ecc00cd}},	//   hgon, _есил_, наҭо, तिरु, 
   {{0x6b849ddb,0x63a099df,0x6fd401f9,0x00000000}},	//   bakg, kgon, _मोडू, --, 
   {{0x7c340c82,0xab601922,0x44240162,0xd7f8026b}},	//   _шейх, şürd, _njm_, чуг_, 
   {{0xa3d809d9,0x63a09ddc,0xd51401e1,0x52bc00bc}},	// [c5b0] ़ाई_, dgon, _ọ̀h, _एनेस, 
   {{0x63a09ddd,0x1cac025c,0x05680a5b,0x00000000}},	//   egon, _ཕྱོ_, ејци_, --, 
   {{0xb7d8066d,0xd4989dde,0x00000000,0x00000000}},	//   _ہوگا_, яра_, --, --, 
   {{0x63a09ddf,0x2d849de0,0x9f44208d,0x2a640327}},	//   ggon, zale_, _mooâ_, _ħobz_, 
   {{0x2d847e64,0x7c3c009a,0x69c401f9,0x872801a9}},	//   yale_, ilsr, ायची, _зўра_, 
   {{0x2d841bce,0x63a09de1,0x44240174,0xb59401c0}},	//   xale_, agon, _ejm_, _шигш, 
   {{0x2d849de2,0x6b84014b,0x720401d5,0xefdc0023}},	//   vale_, yakg, _یورم, ሕዳዊ_, 
   {{0x2d849de3,0x00000000,0x00000000,0x00000000}},	//   wale_, --, --, --, 
   {{0x32549de4,0x1e800e26,0xde440acb,0xa2800244}},	//   _авар, алым, چینو_, _نینو, 
   {{0x6b849de5,0x6458004a,0xc2908dff,0x2d84000d}},	//   wakg, _étir, _ایوب, uale_, 
   {{0xeb989de6,0xfbdc1098,0x2bb800c6,0x1aec0349}},	//   мин_, यांम, واحة_, _চেলে_, 
   {{0x88c02aab,0x3c3800d2,0x2d849de7,0xa3d8012d}},	//   _উপলক, kévu_, sale_, ़ाए_, 
   {{0x2d849de8,0x6b849de9,0xdcf8054e,0x00000000}},	//   pale_, rakg, tată, --, 
   {{0x2d849dea,0x6b849deb,0xaa440801,0x2fcc0793}},	//   qale_, sakg, тегл, ldeg_, 
   {{0x6b840770,0x6f080a40,0x2ba808a3,0x63a09dec}},	//   pakg, lzec, _कापा, ygon, 
   {{0x2fcc9ded,0x63a00097,0x6f080115,0xd82001d5}},	//   ndeg_, xgon, ozec, адси, 
   {{0x96600372,0x2fcc0a40,0x6f089dee,0x5ac49def}},	// [c5c0] икте, ideg_, nzec, _алым_, 
   {{0x44249df0,0x2fcc0221,0x63a00399,0x6f08054e}},	//   _sjm_, hdeg_, wgon, izec, 
   {{0x69dc9df1,0x63a09df2,0x746802bf,0x69cc9df3}},	//   _inpe, tgon, ерів_, mdbe, 
   {{0xe2989df4,0x69cc2bab,0x63a09df5,0xa684024c}},	//   дад_, ldbe, ugon, _илмд, 
   {{0x2ba84fed,0x2fcc9df6,0x69cc1eff,0x00000000}},	//   _काना, ddeg_, odbe, --, 
   {{0x26d01446,0x63a09df7,0x2fcc0036,0x6f089df8}},	//   mvyo_, sgon, edeg_, dzec, 
   {{0xee080c58,0x1cac031c,0x26d00100,0x69cc9df9}},	//   ৰকাশ_, _ཕཱེ_, lvyo_, idbe, 
   {{0x2fcc9dfa,0x63a0014b,0x2294007b,0x00000000}},	//   gdeg_, qgon, _للرس, --, 
   {{0x3f984ba9,0x645807ea,0xa1c49dfb,0xa8043235}},	//   ğru_, _étiq, _ибад, mlığ, 
   {{0xa8044956,0x1cac0135,0xa3d81d15,0x69dc00b5}},	//   llığ, _ཕྱུ_, ़ाक_, _nnpe, 
   {{0xf1a89dfc,0xd5980302,0x6f089dfd,0x00000000}},	//   _ساله_, וביל, azec, --, 
   {{0x69cc9dfe,0xa8044947,0x69dc9dff,0x66f89e00}},	//   edbe, nlığ, _anpe, _kākā, 
   {{0xd00c0531,0x6f089e01,0x7c3c9e02,0xda789e03}},	//   _بلن_, czec, rlsr, ьян_, 
   {{0x4f209e04,0x66f802b5,0x69cc42be,0xa8041cce}},	//   _әдәб, _mākā, gdbe, hlığ, 
   {{0xc8649e05,0xcd3029c6,0xa80403ee,0x97a49e06}},	//   итти, _پروب, klığ, крал, 
   {{0xbdc004a9,0x69dc9e07,0x69cc0549,0x2ba807d0}},	//   _ئەھۋ, _enpe, adbe, _काया, 
   {{0x35b40323,0xa80403be,0x66f800cd,0xed780092}},	// [c5d0] лбар, dlığ, _nākā, _የአባይ_, 
   {{0x7bcc00ad,0x7cf802d2,0x2fcc030a,0x4b380677}},	//   _haau, _gúrú, zdeg_, _ברחל_, 
   {{0x2908068f,0x2ba853c3,0x7bcc7433,0x26d017fa}},	//   czba_, _कामा, _kaau, avyo_, 
   {{0x7bcc00ef,0xca300150,0xd7f80408,0x00000000}},	//   _jaau, _ﺩﺍﺕ_, _цуо_, --, 
   {{0x86e4036b,0xc6e49e08,0x66f800cd,0xdee4007b}},	//   _кўрд, _кірп, _cākā, _اً_, 
   {{0x7bcc9e09,0x8afc011a,0x3328025c,0x00000000}},	//   _laau, והדי, ħax_, --, 
   {{0x7984016b,0x7bcc0093,0xa80406be,0x3518010f}},	//   _mehw, _oaau, blığ, _װוּנ, 
   {{0xb4c00412,0x7bcc123c,0x6f089e0a,0xae7801c0}},	//   ्टी_, _naau, tzec, нсох_, 
   {{0x2fcc9e0b,0x66e4013f,0x69cc017a,0x00000000}},	//   rdeg_, bɔku, ydbe, --, 
   {{0x79849e0c,0x41c011b1,0x6f080034,0x7e5400a8}},	//   _nehw, _एसएस, rzec, итэц, 
   {{0x6f08297b,0x65b801bf,0x66f800ef,0x00000000}},	//   szec, _høhæ, _zākā, --, 
   {{0x7d1c00c6,0x2d9851bb,0xf3f8054e,0x3cf80174}},	//   úrsa, şse_, _fiţe_, ørva_, 
   {{0x79849e0d,0xa8040259,0x7bcc9e0e,0x6ef80241}},	//   _behw, nlış, _daau, _dùbú, 
   {{0x5e900597,0xa80445a5,0x69cc0072,0x290801f4}},	//   _الوط, zlığ, udbe, tzba_, 
   {{0x7bcc9e0f,0x69cc9e10,0x7984004c,0xa804247e}},	//   _faau, rdbe, _dehw, ylığ, 
   {{0x1cac1efe,0x7bcc00ad,0x29089e11,0x64a401ec}},	//   _ཕྱི_, _gaau, rzba_, ғада, 
   {{0xef18031c,0xa9680902,0xe7a800cd,0xe9d8009b}},	// [c5e0] fażi_, _пипа_, ङ्गप, _зкп_, 
   {{0xfdfc06bc,0xa50808bf,0xb4c01889,0x69dc030a}},	//   एसएस_, неза_, ्टू_, _unpe, 
   {{0xa80445a5,0x7bcc9e12,0x66f80318,0x5df8008f}},	//   tlığ, _yaau, _sākā, עפענ, 
   {{0x7c2404ac,0x66f81d86,0x3774798c,0x638401c6}},	//   _ĉirk, _pākā, _вырс, угда, 
   {{0xa8040bfc,0x7c3c145e,0x7984004c,0xc7b4016b}},	//   rlığ, îrri, _yehw, mfɑ_, 
   {{0xa0a401c6,0xb194013d,0x66f800b8,0x7ae8000d}},	//   гшил, алшә, _vākā, äeti, 
   {{0x2ba80490,0x91e00063,0xa80403e0,0x00000000}},	//   _काढा, соје, plığ, --, 
   {{0xa80443bc,0x64480548,0xd8d4010f,0x200003f2}},	//   qlığ, îfid, רוקט_, óki_, 
   {{0xc330049e,0x7bcc0363,0x141800df,0x00000000}},	//   _بەش_, _raau, _נומב, --, 
   {{0x7bcc9e13,0x6f1c007b,0x3cb40395,0x00000000}},	//   _saau, úsca, айор, --, 
   {{0x7bcc4ffc,0x79849e14,0x20180129,0x00000000}},	//   _paau, _rehw, épis_, --, 
   {{0x79849e15,0xdcf801a6,0xe04401d5,0x3c6400db}},	//   _sehw, hatć, _ёнди, лкүг, 
   {{0xd00c24e0,0xdd90913f,0x79840099,0x7bcc004c}},	//   _عله_, _هوش_, _pehw, _vaau, 
   {{0x7bcc5553,0x79840455,0xf8d001f9,0x00000000}},	//   _waau, _qehw, हिलय, --, 
   {{0x7bcc9e16,0x4df8010f,0xe7700241,0x00000000}},	//   _taau, _אפגא, _ọlọn, --, 
   {{0x213c34fe,0x79849e17,0x7bcc00d8,0x00000000}},	//   _myth_, _wehw, _uaau, --, 
   {{0xbb300ed1,0x5eb002f5,0x9a249e18,0x776c0077}},	// [c5f0] ﺪﯨﻖ_, জিকে, _معدن, rcax, 
   {{0x7d0403f9,0x39141d0f,0x00000000,0x00000000}},	//   _ƙish, _вмор, --, --, 
   {{0xb4c072c0,0x213c03cb,0x92e801b9,0xdb1c0139}},	//   ्टे_, _nyth_, کراق_, _waqä, 
   {{0xd9e0130b,0x743400fb,0xe3d4009d,0x84640240}},	//   खावत_, шнеф, ийхө, _ትኣምን_, 
   {{0xc7d800a7,0x00000000,0x00000000,0x00000000}},	//   _смях_, --, --, --, 
   {{0x51849bb1,0x213c0368,0x506001ec,0x00000000}},	//   ууда, _byth_, бекұ, --, 
   {{0x85440276,0xd1b4004b,0x78540064,0x00000000}},	//   _гэте, ناډا_, _sąvy, --, 
   {{0x2eb40c69,0xb2749e19,0x245c013a,0x00000000}},	//   асос, _влаш, _tůma_, --, 
   {{0x61ec01bf,0xdd1c00d7,0xdce800b8,0xdcf80153}},	//   ænlø, líňa, _ānāy, matę, 
   {{0xed589e1a,0x213c03cb,0x1cac0327,0x00000000}},	//   коп_, _fyth_, _ཕྱང_, --, 
   {{0x313400ee,0x00000000,0x00000000,0x00000000}},	//   _тежр, --, --, --, 
   {{0xfbdc1fe7,0x00000000,0x00000000,0x00000000}},	//   यागम, --, --, --, 
   {{0xaa4410d9,0x5ac454fa,0x00000000,0x00000000}},	//   иемл, алям_, --, --, 
   {{0x9f5000d2,0x00000000,0x00000000,0x00000000}},	//   _ôyá_, --, --, --, 
   {{0x1d046ac5,0x5fd84540,0xb4c04a18,0x00000000}},	//   _вещи_, _मोडल, ्टो_, --, 
   {{0x601c02b5,0xb4c000bc,0x00000000,0x00000000}},	//   pūme, ्टै_, --, --, 
   {{0x320404cc,0xddc801e4,0x601c00b8,0x00000000}},	// [c600] _olly_, _lifŝ, cīmu, --, 
   {{0xe8f8084c,0x69949e1b,0x7c2401e4,0x6b940162}},	//   _ало_, _трих, _ĉiri, _hdyg, 
   {{0xf1a800dc,0x99980375,0x00000000,0x00000000}},	//   च्छन, _בביט, --, --, 
   {{0xb36002d3,0x00000000,0x00000000,0x00000000}},	//   _ስቓይን_, --, --, --, 
   {{0x64580ffb,0x213c0368,0x779003e6,0x00000000}},	//   _ètim, _syth_, _ریلا, --, 
   {{0x25a802fa,0x409404fb,0x7e640022,0x5210003b}},	//   _ucbl_, ملتر, _éipi, одіт, 
   {{0x55b80375,0x6b9402d0,0x7f943f3a,0x00000000}},	//   _שמלו, _odyg, байх, --, 
   {{0x44c89e1c,0x32049e1d,0x00000000,0x00000000}},	//   _iş_, _elly_, --, --, 
   {{0x5398025f,0x225c0109,0x213c0368,0xe80c0034}},	//   _שימו, _titk_, _wyth_, _सतना_, 
   {{0x64400664,0x6b949e1e,0x32640014,0xef18033f}},	//   lloi, _adyg, _انٕہ, jażu_, 
   {{0x64400108,0x00000000,0x00000000,0x00000000}},	//   oloi, --, --, --, 
   {{0x64400007,0x44c803e3,0x00000000,0x00000000}},	//   nloi, _mş_, --, --, 
   {{0x545410df,0x200403c1,0x644004c9,0x320405da}},	//   יסטן_, _iloi_, iloi, _ylly_, 
   {{0x44c89e1f,0x64409e20,0x195401ec,0xdd8c00f1}},	//   _oş_, hloi, ғағы_, _کوډ_, 
   {{0x200406a3,0x7c9400c6,0x644001c4,0xf86806c7}},	//   _kloi_, _البص, kloi, امري_, 
   {{0x98486af7,0xca3001ec,0x0d8000fb,0x00000000}},	//   тяга_, _ﺩﺍﺙ_, _ллән, --, 
   {{0x44c89e21,0x6440031c,0xd5647de7,0xb4c007d0}},	// [c610] _aş_, dloi, атеп, ्ट्_, 
   {{0x7afc02f6,0x60d801d5,0x20049e22,0x64400332}},	//   myst, _ortm, _lloi_, eloi, 
   {{0x5eb00183,0x3ea40158,0x6440002f,0x00000000}},	//   জিটে, humt_, floi, --, 
   {{0x3ea40099,0x644002e2,0x44240212,0xb4c000dc}},	//   kumt_, gloi, оєча, ्टौ_, 
   {{0x7afc519a,0x44c80598,0x93249e23,0xc2c89e24}},	//   nyst, _eş_, جران, لبول_, 
   {{0x94740133,0x3ea49e25,0x644001f4,0x00000000}},	//   _ندرا, dumt_, aloi, --, 
   {{0xc19802bf,0x7d1c0bcd,0x7afc9e26,0xee38134b}},	//   ртії_, úrsl, hyst, һни_, 
   {{0x7afc9e27,0x5fa00131,0xafe4016c,0x64409e28}},	//   kyst, كەمم, соил, cloi, 
   {{0xee380b96,0x8e0400d1,0x60d8138a,0x7afc0108}},	//   лни_, имиң_, _ertm, jyst, 
   {{0x3204003e,0x41e402d5,0x44c820b2,0x9f4c0332}},	//   _ully_, _міха, _yş_, ínár_, 
   {{0xdd8c03e6,0x7afc0067,0x2d800254,0x00000000}},	//   ژوی_, eyst, _õhem_, --, 
   {{0xffd4004b,0x2004015d,0x7afc9e29,0x00000000}},	//   _وغند, _gloi_, fyst, --, 
   {{0x7afc9e2a,0xcee801d9,0x433802d3,0x2ba807f7}},	//   gyst, _جران_, _እናተባ, कलबा, 
   {{0x2ba827a6,0x00000000,0x00000000,0x00000000}},	//   _कावा, --, --, --, 
   {{0x64409e2b,0x7c9400c7,0x7afc1368,0xef18033f}},	//   yloi, _дрыц, ayst, rażu_, 
   {{0x7afc6d4c,0xa7649e2c,0x2ca49e2d,0x6c3445cc}},	//   byst, скад, muld_, _دفعا, 
   {{0x7afc9e2e,0x64400076,0x44c820b2,0x2ca401bf}},	// [c620] cyst, vloi, _sş_, luld_, 
   {{0x44c800a2,0x00000000,0x00000000,0x00000000}},	//   _pş_, --, --, --, 
   {{0x64409e2f,0x64581ef4,0x6aa4017a,0x4a740150}},	//   tloi, _ètik, lukf, _уықт, 
   {{0x601c02b5,0x64409e30,0x00000000,0x00000000}},	//   kūma, uloi, --, --, 
   {{0x2ca49e31,0x64409e32,0x44c800a2,0x6f1c0332}},	//   huld_, rloi, _wş_, úscl, 
   {{0x644003a2,0xe04804fb,0x80dc009e,0xb86412ea}},	//   sloi, گشته_, বহস্, _دایو, 
   {{0x7afc14cf,0x64409e33,0x20040276,0x44c806be}},	//   zyst, ploi, _ploi_, _uş_, 
   {{0x661c9e34,0x2ca49e35,0x64400007,0x23b4004b}},	//   lipk, duld_, qloi, _دمرس, 
   {{0x7afc6a86,0x00000000,0x00000000,0x00000000}},	//   xyst, --, --, --, 
   {{0x7afc11db,0x661c0bc9,0x2ca404ce,0xa068030d}},	//   vyst, nipk, fuld_, _бажа_, 
   {{0x7afc9e36,0x2ca40728,0xdd8401e0,0x291c00d7}},	//   wyst, guld_, _һыйп, útal_, 
   {{0x7afc9e37,0x61e80427,0x661c9e38,0x00000000}},	//   tyst, šolč, hipk, --, 
   {{0x661c9e39,0x6ee400c6,0x2ba83381,0x8fa09e3a}},	//   kipk, _وسهل, _कारा, _хаче, 
   {{0x7afc9e3b,0x00000000,0x00000000,0x00000000}},	//   ryst, --, --, --, 
   {{0x661c0263,0x378800c7,0x00000000,0x00000000}},	//   dipk, ираҟ_, --, --, 
   {{0x96e8005b,0x7afc01f4,0x00000000,0x00000000}},	//   льза_, pyst, --, --, 
   {{0xb5f41214,0xceb000df,0x00000000,0x00000000}},	// [c630] озащ, ּיע_, --, --, 
   {{0x7c2c9e3c,0xd5649e3d,0x19a801ee,0x5fd8000d}},	//   _hjar, стап, _стип_, _मोसल, 
   {{0x7c2c9e3e,0x05740046,0xddc00427,0x78a00174}},	//   _kjar, سالد, _otož, álvd, 
   {{0x57a40276,0xdd8400f1,0x00000000,0x00000000}},	//   _ушоа, _ښو_, --, --, 
   {{0x7c2c01f7,0x00000000,0x00000000,0x00000000}},	//   _mjar, --, --, --, 
   {{0x5924025c,0xdb0c04d4,0x7c2c0200,0x65b00413}},	//   _རྨོས_, lecó, _ljar, rðhó, 
   {{0x2ba89e3f,0x7c2c9e40,0x5fd838d2,0x72a40014}},	//   _काला, _ojar, _मोहल, _ژٕرن, 
   {{0x7c2c1574,0x2ca40cf9,0x0fe40e46,0x764411ad}},	//   _njar, vuld_, слиқ_, llhy, 
   {{0xdcfc00cd,0x99800064,0x2ee4003b,0x00000000}},	//   _āvāh, nojų_, іжог, --, 
   {{0x7f8400e5,0x2ca434c5,0x00000000,0x00000000}},	//   _ہلمن, tuld_, --, --, 
   {{0x7c2c0321,0x1cac0156,0x244c0022,0x9104024c}},	//   _bjar, _ཕྱད_, sýme_, _учад, 
   {{0x2ba80574,0x7c2c0055,0x601c0374,0xc37c0055}},	//   _काळा, _cjar, pūma, _kṣañ, 
   {{0x7c2c9e41,0x2ca401bf,0x64380115,0x00000000}},	//   _djar, suld_, שערנ, --, 
   {{0xed589e42,0x7c2c9e43,0x00000000,0x00000000}},	//   _кол_, _ejar, --, --, 
   {{0xdd8c15fa,0x7c2c2242,0x7d600092,0x00000000}},	//   _شوي_, _fjar, _ለፓርቲ, --, 
   {{0x7c2c9e44,0xeb98014b,0x00000000,0x00000000}},	//   _gjar, _тии_, --, --, 
   {{0xe6189e45,0x661c9e46,0x81d00183,0xadec07f7}},	// [c640] ада_, tipk, ষাত_, जापन_, 
   {{0x7c2c044e,0x00000000,0x00000000,0x00000000}},	//   _zjar, --, --, --, 
   {{0xf8c802ea,0x64c40c8b,0x24c80026,0xee7c0150}},	//   rnéé_, تيال, ргеп_, _ﺤﻨﻴﻥ_, 
   {{0x66e44712,0x661c094a,0x6304021a,0xdb0c00e4}},	//   _дома, sipk, يوال, cecó, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xddc0242a,0x1dac00dc,0x27f00731,0x26c0036e}},	//   _stož, ज्ञत, ljyn_, _ipko_, 
   {{0x15409e47,0xdb0c00cf,0xe474084c,0x96dc01ec}},	//   _жерм, necò, _фугэ, кiзу_, 
   {{0x8ca019e5,0xd24c3955,0xdfd80801,0x0fe000db}},	//   _कमजो, ىچە_, рък_, дөшү, 
   {{0xd12c0058,0xddc00427,0x00000000,0x00000000}},	//   ىمۇ_, _vtož, --, --, 
   {{0xf1a843f6,0x7c2c143a,0x2adc00bc,0xdb0c01e1}},	//   _هامه_, _sjar, खिनु_, _ìjér, 
   {{0x1d2801b9,0xcf8c1d39,0x00000000,0x00000000}},	//   рўпо_, _ој_, --, --, 
   {{0xdde80dc3,0x00000000,0x00000000,0x00000000}},	//   ارکه_, --, --, --, 
   {{0x7d040198,0x317801ed,0x27f00363,0xdb4c0133}},	//   _ƙiss, _őszi_, djyn_, کێک_, 
   {{0x99800024,0x22bc00e2,0x00000000,0x00000000}},	//   vojų_, mākā_, --, --, 
   {{0x22bc005f,0x7c2c9e48,0x3c580276,0x2240002e}},	//   lākā_, _tjar, _ликэ_, _ëkku_, 
   {{0x7c2c9e49,0x998002d5,0xd6f800b5,0x00000000}},	//   _ujar, tojų_, _ccタ_, --, 
   {{0x78a0022c,0x22bc005f,0x2ac000d1,0x76440455}},	// [c650] álvb, nākā_, _пәрв, tlhy, 
   {{0x49c8013e,0x49744166,0xe6bc0413,0x99800153}},	//   _дуюм_, _ольс, _ólýð, rojų_, 
   {{0x05ac07f7,0xd8b401c8,0x00000000,0x00000000}},	//   _चारब, _بنجڻ_, --, --, 
   {{0x7c3c9e4a,0x22bc0374,0x970000d1,0x601c0171}},	//   nosr, kākā_, _قېزى, dūmo, 
   {{0x95c80114,0x2eec025c,0x92b42ed7,0x12c400db}},	//   _кува_, xxef_, تحضا, تتاپ, 
   {{0xe2949e4b,0x7c3c0419,0x22bc0171,0x00000000}},	//   чаш_, hosr, dākā_, --, 
   {{0x4dd004c5,0x44b400d8,0x00000000,0x00000000}},	//   তামূ, _обрс, --, --, 
   {{0xd3e00403,0xc7b4013f,0xcee03272,0x33740022}},	//   _تقری, yiɑm_, дбиқ, _хгар, 
   {{0x22bc00e2,0x7c3c94ee,0xdc8c0023,0x00000000}},	//   gākā_, dosr, _መሰለይ_, --, 
   {{0x90e40133,0xf3f8054e,0x41742309,0x00000000}},	//   _وسان, _hoţ_, _قامس, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x22bc005f,0x3cf80267,0xdce80171,0x00000000}},	//   bākā_, ärva_, _zefī, --, 
   {{0x22bc005f,0x05ac5b82,0x244c0118,0xcf242372}},	//   cākā_, _चालब, nýma_, _براي, 
   {{0x1cac031c,0xbd8800db,0x00000000,0x00000000}},	//   _ཕྱམ_, _ۇنۇن_, --, --, 
   {{0x9ac0031c,0x6e20007c,0xded40023,0x200001e3}},	//   _ċċem, milb, _ክኾኖ_, ökig_, 
   {{0x27e49e4c,0x26c0009d,0x00000000,0x00000000}},	//   ñon_, _ppko_, --, --, 
   {{0x6fbc80f3,0x27f01368,0x6e200332,0x27e40205}},	// [c660] व्यू, rjyn_, oilb, ıon_, 
   {{0x6e209e4d,0x3d0001f9,0x00000000,0x00000000}},	//   nilb, शनचे_, --, --, 
   {{0xf3f800a2,0x2ab4005c,0x00000000,0x00000000}},	//   _boţ_, læb_, --, --, 
   {{0x6e209e4e,0x5924025c,0x3cf8022c,0xf78800d8}},	//   hilb, _རྨིས_, ørvi_, _voçê_, 
   {{0x26c005b1,0x994841b5,0x2ab400b5,0x00000000}},	//   _upko_, _köşk_, næb_, --, 
   {{0xded4044e,0x6e209e4f,0xa088036b,0x00000000}},	//   _ክኾኑ_, jilb, бсиз_, --, 
   {{0xddc00006,0x6e20047e,0xd1b40330,0xf494010a}},	//   _nuoš, dilb, ساوا_, _ортю, 
   {{0x22bc005f,0x00000000,0x00000000,0x00000000}},	//   tākā_, --, --, --, 
   {{0x6e209e50,0xdef808e2,0x600c2b1d,0x28cc9e51}},	//   filb, сый_, _nùme, _हैसि, 
   {{0x6e209e52,0x1c1c01ad,0x22bc00de,0xddc00210}},	//   gilb, मोनल_, rākā_, _utoż, 
   {{0x1f6400ee,0x3c58084c,0x7c3c04b1,0x00000000}},	//   _екем, жинэ_, tosr, --, 
   {{0x61f89e53,0x22bc3a2f,0x00000000,0x00000000}},	//   _hotl, pākā_, --, --, 
   {{0x7c3c01d3,0x00000000,0x00000000,0x00000000}},	//   rosr, --, --, --, 
   {{0x61f89e54,0x7c3c03cd,0xd8b80014,0xfbb400cc}},	//   _jotl, sosr, ٝدرا_, _জোখত, 
   {{0x61f89e55,0x39449e56,0xac540451,0x386c00df}},	//   _motl, æls_, _ڪروڙ, ĉero_, 
   {{0xb8e44c21,0x61f89e57,0xded40023,0x00000000}},	//   _एह_, _lotl, _ክኾና_, --, 
   {{0xf8b00050,0x61f89e58,0xd6f8037e,0x00000000}},	// [c670] رکھ_, _ootl, _idカ_, --, 
   {{0x61f89e59,0xf3f80311,0x45d49e5a,0x1be800af}},	//   _notl, _soţ_, ноус, टावल_, 
   {{0x73d81367,0x00000000,0x00000000,0x00000000}},	//   ждер_, --, --, --, 
   {{0xbeec0073,0x6e202bcc,0x244c00c7,0x00000000}},	//   _जपून_, zilb, týma_, --, 
   {{0x61f89e5b,0x5fd800e1,0x6e20002e,0x4374003b}},	//   _botl, _मोइल, yilb, хуєт, 
   {{0x61f89e5c,0x6fd40a8a,0x00000000,0x00000000}},	//   _cotl, _मोजू, --, --, 
   {{0x61f80842,0x3ea40036,0xd3440133,0x244c00e4}},	//   _dotl, ermt_, _کیشه_, sýma_, 
   {{0xdc740020,0xddc002d5,0xf40800c6,0xd1b80014}},	//   _አሰራር_, _ruoš, _بيرى_, _گارا_, 
   {{0xef189e5d,0x7c2401e4,0x61f811ad,0xa920032e}},	//   юми_, _ĉirp, _fotl, _íþvo, 
   {{0x61f89e5e,0xc2c48326,0xddc00006,0x6fa80490}},	//   _gotl, _سيمي, _puoš, _टाकू, 
   {{0x3f840a2e,0x23700006,0x8234007b,0x0c4400c7}},	//   bbmu_, žyje_, _أرقا, нҭко, 
   {{0x6e209e5f,0xeab80137,0x61f801b9,0x9ac00327}},	//   silb, ойм_, _zotl, ċċni, 
   {{0x61f89e60,0x81d000bd,0x00000000,0x00000000}},	//   _yotl, ষার_, --, --, 
   {{0xe8b8025c,0x8884054a,0x2ba89e61,0xae0000e1}},	//   _བྱུག, нғол, _काका, _लकिन_, 
   {{0xd9400d08,0x2d849e62,0xd7dc0490,0x00000000}},	//   вери, mble_, _पोहच, --, 
   {{0x78a00579,0xafe00fac,0x66e40117,0x114c0023}},	//   álva, _åøde, моба, _ቅንዕና, 
   {{0x2d849e63,0xdb98011a,0xe9d800f3,0x28cc00ce}},	// [c680] oble_, _וספר, _дкп_, _हैरि, 
   {{0x2d845062,0x2ca40334,0x00000000,0x00000000}},	//   nble_, orld_, --, --, 
   {{0x61f89e64,0x2d849e65,0xdedc02d3,0xc690004b}},	//   _rotl, ible_, ዕባና_, _څېر_, 
   {{0x61f89e5b,0x845403cc,0x2d840076,0x41280137}},	//   _sotl, رىشچ, hble_, үндү_, 
   {{0x61f89e66,0x73c00831,0x6658010a,0xa02402d2}},	//   _potl, ыҡта, _мамă, hjöð, 
   {{0x273c01e1,0x2d84009b,0x61f89e67,0x91e049c4}},	//   _ẹnì_, jble_, _qotl, коче, 
   {{0x61f89e68,0x81bc00ef,0x00000000,0x00000000}},	//   _votl, _bjēr, --, --, 
   {{0x2d849e69,0x660c0419,0x5fac0073,0x8dc40150}},	//   eble_, _hlbk, _टाळल, _ﺒﻤﻨﺄ, 
   {{0xb35c0201,0x61f89e6a,0x3d9400f3,0x2d8401bf}},	//   ታቸውን_, _totl, нипр, fble_, 
   {{0x62809e6b,0xd6f804ce,0xa02402d2,0x00000000}},	//   mpoo, _sdカ_, fjöð, --, 
   {{0x71640f1b,0xa3d00d2c,0xae1c02e5,0x62809e6c}},	//   _كامك, _वसा_, योधन_, lpoo, 
   {{0x628004c9,0x2d849e6d,0x69d800d0,0x00000000}},	//   opoo, able_, ôten, --, 
   {{0x628094f0,0x2d847156,0x00000000,0x00000000}},	//   npoo, bble_, --, --, 
   {{0x62800270,0x00000000,0x00000000,0x00000000}},	//   ipoo, --, --, --, 
   {{0xa3dc0882,0x690400d7,0x00000000,0x00000000}},	//   तया_, _čudá, --, --, 
   {{0x7a2805be,0x62809e6e,0x660c0200,0x00000000}},	//   džte, kpoo, _albk, --, 
   {{0x2fc80086,0x7a280153,0xc864011c,0x00000000}},	// [c690] _ñage_, ežte, ттри, --, 
   {{0xd5080075,0xf674009d,0x00000000,0x00000000}},	//   يغان_, _үгнэ, --, --, 
   {{0x79949e6f,0x62809e70,0xf7940153,0x00000000}},	//   mazw, epoo, _панэ, --, 
   {{0x79949e71,0xe730010e,0x00000000,0x00000000}},	//   lazw, läýý, --, --, 
   {{0x66e4013f,0xfbc000dc,0xf678010f,0x00000000}},	//   kɔky, ष्यम, _מאָמ, --, 
   {{0x79941ab4,0x00000000,0x00000000,0x00000000}},	//   nazw, --, --, --, 
   {{0x216464ab,0xc8d801ad,0x61400120,0x6280000d}},	//   ниши_, डिएट, леша, apoo, 
   {{0x79949e72,0x130402dd,0x00000000,0x00000000}},	//   hazw, _قىزۋ_, --, --, 
   {{0x79949e73,0xdcf802b5,0x4394009d,0x00000000}},	//   kazw, katē, _шатс, --, 
   {{0x273c431d,0xac849e74,0x799400ec,0xeab805f5}},	//   ững_, нгол, jazw, үйн_, 
   {{0x79940117,0x417400db,0x2700016b,0x6da4013e}},	//   dazw, _شالس, mɔne_, _ҷила, 
   {{0xf3f80356,0x00000000,0x00000000,0x00000000}},	//   _biţi_, --, --, --, 
   {{0xada44493,0xa968036b,0x79942d2f,0x2fcc030a}},	//   _залл, зига_, fazw, meeg_, 
   {{0x79949e75,0x2fcc9e76,0x6f1c617f,0x2700016b}},	//   gazw, leeg_, úscu, nɔne_, 
   {{0x2dd80a81,0xa85410fc,0xaa440139,0x00000000}},	//   _وُچھ_, етај, _җенл, --, 
   {{0x2fcc9e77,0x6280493a,0xf3f80311,0x00000000}},	//   neeg_, ypoo, _fiţi_, --, 
   {{0x7994015c,0xd6cc00dd,0xab649e78,0x660c0334}},	// [c6a0] bazw, یقہ_, _явил, _plbk, 
   {{0xfbc02f2e,0x799400ca,0xd6f8019b,0x2fcc0067}},	//   ष्ठम, cazw, _pcゲ_, heeg_, 
   {{0x25a40bcc,0xbd80001f,0x600c00a3,0x2fcc030a}},	//   ğol_, _የአቅም_, _lùma, keeg_, 
   {{0x69cc9e79,0x24840030,0x5fac01ad,0x62809e7a}},	//   lebe, ďom_, _टाइल, tpoo, 
   {{0x2fcc9e7b,0x4908012c,0x47440124,0xd24c0133}},	//   deeg_, सनको_, _рҭаг, ڕنه_, 
   {{0xa0889e7c,0x26d00142,0x3a200051,0x1a9800df}},	//   псиз_, mwyo_, _xmhp_, לינע, 
   {{0x62809e7d,0x69cc03cd,0x5194179e,0x26d003cb}},	//   spoo, iebe, رخود_, lwyo_, 
   {{0x69cc9e7e,0x62800694,0x81d004c5,0x00000000}},	//   hebe, ppoo, ষাই_, --, 
   {{0x69cc9e7f,0x600c00a3,0x79949e80,0x645800db}},	//   kebe, _cùma, yazw, _ètiq, 
   {{0x64409e81,0x727800d3,0x91bc00bc,0x00000000}},	//   looi, _ісус_, ल्दै, --, 
   {{0x26d00368,0x7994014b,0x93400276,0x2fcc0165}},	//   hwyo_, vazw, _анӂе, beeg_, 
   {{0x1be837f3,0x69cc0083,0x79947c18,0xf3f80356}},	//   टाइल_, eebe, wazw, _piţi_, 
   {{0x69cc9e82,0x79949e83,0xdcf8005f,0x8af003b9}},	//   febe, tazw, tatē, _azəb, 
   {{0x69cc9e84,0x26d00368,0xdb0c3847,0x64409e85}},	//   gebe, dwyo_, ngcé, hooi, 
   {{0x79940796,0x64409e86,0xdcf8005f,0x8dd8011a}},	//   razw, kooi, ratē, _זקוק, 
   {{0x79940912,0xf6bc031c,0x9b680139,0x00000000}},	//   sazw, _ཕྱུང, _эшка_, --, 
   {{0x69cc9e87,0x4c549e88,0xd6f804ce,0x79946c35}},	// [c6b0] bebe, _حضور, _pcケ_, pazw, 
   {{0x69cc0cfc,0x2fcc9e77,0xccd00124,0xd1f00023}},	//   cebe, zeeg_, _рцәы, ሌታት_, 
   {{0x6440017a,0x7bdc062c,0x00000000,0x00000000}},	//   fooi, odsu, --, --, 
   {{0xf1d80d0d,0x64409e89,0x2fcc01d4,0x00000000}},	//   _योजन, gooi, xeeg_, --, 
   {{0x7bdc71ad,0x2fcc030a,0x00000000,0x00000000}},	//   idsu, veeg_, --, --, 
   {{0x2fcc0151,0x00000000,0x00000000,0x00000000}},	//   weeg_, --, --, --, 
   {{0x2fcc9e8a,0x64409e8b,0x600c00a3,0x349401c4}},	//   teeg_, booi, _sùma, _шавр, 
   {{0x69cc9e8c,0x64409e8d,0x7bdc00b5,0xafe44cf6}},	//   zebe, cooi, jdsu, тоил, 
   {{0x2fcc9e8e,0xbd80001f,0xb52032ed,0x69cc9e8f}},	//   reeg_, _የአቋም_, _मधुप_, yebe, 
   {{0x2fcc0190,0x69cc9e90,0x7bdc0b4f,0xec781eed}},	//   seeg_, xebe, edsu, мпо_, 
   {{0x2a7003a2,0x26d0014b,0xefdc00b7,0x2fcc0165}},	//   _suyb_, zwyo_, ንሳይ_, peeg_, 
   {{0xab28242f,0xd6f800b5,0x7bdc002d,0x7dc40150}},	//   дома_, _ndク_, gdsu, _ەتيك, 
   {{0xcdc00220,0x7c3000d7,0x00000000,0x00000000}},	//   _балқ, _škrí, --, --, 
   {{0x46e00316,0x7bdc9e91,0x6cc49e92,0x6da40395}},	//   निसह, adsu, _айка, _рика, 
   {{0x3f6429db,0xac3801c0,0xd7d8037e,0x291c0e89}},	//   _итәб, _очих_, _xiデ_, àta_, 
   {{0xf7e80372,0x6ec400bc,0x00000000,0x00000000}},	//   ىرقى_, _वहाँ, --, --, 
   {{0xa7641887,0x69cc21e3,0x644000ad,0x24980175}},	// [c6c0] ткад, pebe, vooi, wspm_, 
   {{0x958000c7,0x69cc9e93,0x0c7c001f,0x64400363}},	//   илуе, qebe, _የተነሣ_, wooi, 
   {{0x777c0334,0x64409280,0xe3b80063,0x00000000}},	//   _ffsx, tooi, дбе_, --, 
   {{0x64400093,0x00000000,0x00000000,0x00000000}},	//   uooi, --, --, --, 
   {{0x64408df4,0x93406be6,0xf3f8054e,0x56900064}},	//   rooi, анце, _niţu_, _каўт, 
   {{0xe4c40228,0x64400618,0x5fd801f9,0x00000000}},	//   _ийги, sooi, _मोजल, --, 
   {{0x23d400c7,0x64a40798,0x00000000,0x00000000}},	//   _ицар, _јаба, --, --, 
   {{0x69a02e3b,0x059408b0,0xa13401b9,0xbed80395}},	//   कृती, _جاڭگ, _یراش, едих_, 
   {{0x44240af5,0xb2c49e94,0x626405f5,0x2ff40228}},	//   _imm_, _مغلو, _аваа, اتىڭ, 
   {{0x5fac0574,0xed4c05d9,0x5318011a,0x91e000d8}},	//   _टाकल, ڻھو_, _חומצ, _коуе, 
   {{0x44249e95,0xdc640023,0xa07400c7,0x93c4054e}},	//   _kmm_, ተገብረ_, _рызш, sfăţ, 
   {{0xefdc044e,0x44249e96,0x4fa0030d,0x5fa40037}},	//   ንታይ_, _jmm_, _вицв, _गयिल, 
   {{0x2fc808e7,0x7bdc9e97,0x7a280006,0x00000000}},	//   _ñaga_, rdsu, ežta, --, 
   {{0x81d002a6,0x44249e98,0x3d945211,0xf988007b}},	//   ষাক_, _lmm_, _сикр, عنزي_, 
   {{0x44240003,0xef18068f,0xb4d09e99,0x00000000}},	//   _omm_, daży_, _वने_, --, 
   {{0x36d44f53,0x5dc801ec,0x99640150,0x00000000}},	//   лобр, _ﺒﻤﻠﻴ, етұл, --, 
   {{0x7d089e9a,0x291c9e9b,0x00000000,0x00000000}},	// [c6d0] lyds, útar_, --, --, 
   {{0x44249e9c,0xf5949e9d,0x28cc00af,0x9f441bce}},	//   _amm_, الاج, _हैकि, _jooñ_, 
   {{0x44249e9e,0xc320009e,0xa2c001e0,0xa3dc07b7}},	//   _bmm_, _ফুলি_, ҙәтк, तयं_, 
   {{0xa2c000d1,0x00000000,0x00000000,0x00000000}},	//   әәтк, --, --, --, 
   {{0x44240334,0x8c1c08a8,0x629400c7,0x71a4009d}},	//   _dmm_, וואי, áyop, галз, 
   {{0x20009e9f,0xc2440024,0xddc80171,0x46e09ea0}},	//   ökin_, анік, _difū, निरह, 
   {{0x442405da,0x7cc80134,0xac9402d3,0x764400c7}},	//   _fmm_, _yɛre, _መሰሎም_, mohy, 
   {{0x4424031c,0x21380af2,0xa3dc00dc,0xfe4401d3}},	//   _gmm_, ûpha_, तयः_, یکوی, 
   {{0x6e440063,0x3254014b,0x9e0c04af,0x00000000}},	//   леиз, _бвар, िसंघ_, --, 
   {{0xadec4ff1,0xdcf80153,0xfe7414fb,0x7a280118}},	//   जाइन_, natė, шүш_, yžta, 
   {{0x44240205,0x00000000,0x00000000,0x00000000}},	//   _ymm_, --, --, --, 
   {{0x6e94016c,0x8c04010b,0x764400d7,0x00000000}},	//   _биду, рҗил, hohy, --, 
   {{0x7644013f,0xf3e400cc,0xdcf80064,0x00000000}},	//   kohy, _ককাৰ_, katė, --, 
   {{0x3d2c016b,0xdcf80153,0x00000000,0x00000000}},	//   _fɛw_, jatė, --, --, 
   {{0x2fdc0190,0xfbc800cc,0x5ac401ec,0xdcf800c0}},	//   _kawg_, ষয়ত, _ұлым_, datė, 
   {{0xd6d001ec,0xef180210,0x00000000,0x00000000}},	//   зiрг, waży_, --, --, 
   {{0x6f089ea1,0x65c460a1,0xdc38010f,0x158802dd}},	// [c6e0] nyec, лбаа, _רעפר, _ﺗﯘﺑﯩ, 
   {{0x6b949ea2,0x44240332,0x244c02f0,0x00000000}},	//   _heyg, _smm_, mými_, --, 
   {{0x6b949ea3,0x69dc028c,0x244c0122,0xba2800e3}},	//   _keyg, _iape, lými_, _جسيم_, 
   {{0x69dc9ea4,0x442405da,0x29080006,0x3cf89ea5}},	//   _hape, _qmm_, myba_, ärvi_, 
   {{0x69dc9ea6,0x244c0e96,0x141400c6,0x6b940067}},	//   _kape, nými_, دينة_, _meyg, 
   {{0x6b941125,0x69dc9ea7,0x44240085,0x6f080205}},	//   _leyg, _jape, _wmm_, dyec, 
   {{0x69dc9ea8,0x2fdc01d4,0x244c1d55,0x442403e0}},	//   _mape, _bawg_, hými_, _tmm_, 
   {{0x69dc9ea9,0x244c0232,0x3d2c013f,0x25b00356}},	//   _lape, kými_, _rɛw_, şală_, 
   {{0x9dbc1b4b,0x69dc00e4,0x2fdc045a,0x539800d9}},	//   _མཁྱེ, _oape, _dawg_, _רימו, 
   {{0x29080006,0x7d089eaa,0x244c02fb,0x13006e1e}},	//   kyba_, tyds, dými_, _узум, 
   {{0x6b949eab,0x29080024,0x657c42a1,0xda9001c6}},	//   _beyg, jyba_, icph, өгнө, 
   {{0x60d89eac,0x29080006,0x601c00b0,0x600c01e1}},	//   _istm, dyba_, tūmu, _kùmm, 
   {{0x34d00b98,0x69dc9ead,0x6f0800ca,0xf4000c58}},	//   _सन्द, _bape, cyec, লোকৰ_, 
   {{0x9dbc0003,0x2fdc0218,0x6b940009,0xefdc0023}},	//   _མཁྲེ, _zawg_, _eeyg, ንዳይ_, 
   {{0x69dc9eae,0x2fdc0457,0xbb30005e,0x6b94022e}},	//   _dape, _yawg_, ﻨﺎﻥ_, _feyg, 
   {{0x249002d3,0x3a743246,0x69dc4c3e,0x81fc031c}},	//   _ምሁራት_, _клир, _eape, དྡྷི_, 
   {{0x76440c6a,0x69dc9eaf,0x473400c6,0xb6c401e0}},	// [c6f0] tohy, _fape, مركز, шөнд, 
   {{0x69dc9eb0,0x60d89eb1,0xd49800c0,0x85b81188}},	//   _gape, _ostm, ерд_, ллус_, 
   {{0x93249eb2,0x76441c42,0x16d405f5,0x0b5801d5}},	//   گران, rohy, _өгнө_, _لشیب_, 
   {{0x69dc9eb3,0xd7645f32,0xd7f80063,0x45d401ec}},	//   _zape, _مەزى_, _чуо_, _қосс, 
   {{0x69dc9eb4,0x2fdc0218,0x93249eb5,0x2700016b}},	//   _yape, _rawg_, دران, pɔna_, 
   {{0x69dc09a0,0x46680024,0x00000000,0x00000000}},	//   _xape, _брсм_, --, --, 
   {{0x2fdc0457,0x9f9006ea,0xc55801af,0x78a00174}},	//   _pawg_, tøði_, _бирє_, álvh, 
   {{0x2fdc0218,0xc2902fc0,0x92b4007b,0x300401d5}},	//   _qawg_, _کیوب, _محطا, рзиг, 
   {{0xee389eb6,0x9f900579,0x60d8035a,0xe2d81e2f}},	//   кни_, røði_, _estm, _لالچ_, 
   {{0x244c03c6,0xa6e00579,0x60d8039a,0xee24487f}},	//   vými_, øðin, _fstm, рмоп, 
   {{0x2fdc0070,0x6b9403ee,0x2fc80428,0xad58013e}},	//   _tawg_, _peyg, _ñago_, ърих_, 
   {{0x69dc9eb7,0x244c0122,0x6b643252,0x6b940009}},	//   _sape, tými_, икна, _qeyg, 
   {{0x6b94022e,0xef1c000d,0x00000000,0x00000000}},	//   _veyg, _बेचऽ_, --, --, 
   {{0xacf420d3,0x244c9eb8,0x29080006,0x69dc014f}},	//   _نسبت, rými_, tyba_, _qape, 
   {{0x69dc9eb9,0x98a09eba,0x6b9401a8,0x27949ebb}},	//   _vape, жисе, _teyg, ишар, 
   {{0x29080006,0xd9401e80,0x81bc00ef,0x2bb8007b}},	//   ryba_, цеси, _amēl, _شابة_, 
   {{0x18649ebc,0xd7049ebd,0x69dc17ce,0xe9a4030d}},	// [c700] рати_, анте_, _tape, _капп, 
   {{0xe5a49ebe,0xa92411ed,0x7b4400db,0x29080153}},	//   рижи, _вдол, _دئىل, pyba_, 
   {{0xd8740014,0xa5c40055,0xdd0c08a9,0x1be80037}},	//   _پمُت_, _niųņ, _mışt, _जोडल_, 
   {{0xdd0c0139,0x9878010f,0x00000000,0x00000000}},	//   _lışt, _שאכט, --, --, 
   {{0x60d805b1,0xdc34008f,0x62649ebf,0x00000000}},	//   _sstm, סאנט_, авда, --, 
   {{0x5bd022e3,0xd17004a9,0xa0a49ec0,0x78700022}},	//   _तस्व, يدىغ, ашил, ẽvet, 
   {{0xd12c168d,0xd4a001af,0xe3b800f3,0x00000000}},	//   ومه_, _мирй, _ибв_, --, 
   {{0x78a0022c,0xe28400c7,0xa5c400b8,0x00000000}},	//   álvi, _влаи, _diųņ, --, 
   {{0xdef89ec1,0x00000000,0x00000000,0x00000000}},	//   тый_, --, --, --, 
   {{0x9e049ec2,0xdd0c0139,0xed4c00ec,0xa28000f2}},	//   рчил, _cışt, ڙھي_, _هیچو, 
   {{0x60d80c8c,0xd24c088c,0x61449ec3,0xdcf80318}},	//   _ustm, _غنم_, _тежа, matī, 
   {{0xfcc410db,0xdcf81a14,0x00000000,0x00000000}},	//   _һәмм, latī, --, --, 
   {{0xdd840166,0x00000000,0x00000000,0x00000000}},	//   _кыйп, --, --, --, 
   {{0x985002d3,0xdce8025c,0x5a4401dd,0xe1ec02dd}},	//   _መብራህ, _nefħ, рэма, згi_, 
   {{0x6e3c01ed,0x00000000,0x00000000,0x00000000}},	//   ésbe, --, --, --, 
   {{0x81bc00ef,0x00000000,0x00000000,0x00000000}},	//   _smēl, --, --, --, 
   {{0xdcf89ec4,0x7fd400bc,0x00000000,0x00000000}},	// [c710] katī, _दसैँ, --, --, 
   {{0xb8dc11ba,0x00000000,0x00000000,0x00000000}},	//   _ইন_, --, --, --, 
   {{0xdcf800cd,0x00000000,0x00000000,0x00000000}},	//   datī, --, --, --, 
   {{0xb9e04be7,0x225c01c4,0x78b40433,0xddc00153}},	//   _እሱ_, _ahtk_, muzv, _nuož, 
   {{0x6d4401bf,0xb39c01ec,0x533000c7,0x00000000}},	//   _øhav, _үлгi, цҵат, --, 
   {{0x422402bf,0xdcf80318,0x00000000,0x00000000}},	//   одів, gatī, --, --, 
   {{0xdd0c0166,0xddc000c0,0x1e80035b,0x00000000}},	//   _rışt, _buož, ҿлым, --, 
   {{0x89380375,0x00000000,0x00000000,0x00000000}},	//   ירוע_, --, --, --, 
   {{0x2a600241,0x1e801f39,0x00000000,0x00000000}},	//   _lẹṣe_, плым, --, --, 
   {{0x78b405b8,0xdd0c0139,0xa5c400b8,0xf2340066}},	//   kuzv, _qışt, _tiųņ, _ابرک, 
   {{0x78b405be,0xa5d8010f,0x00000000,0x00000000}},	//   juzv, אַכי, --, --, 
   {{0x78b40810,0x32049ec5,0xca8401a9,0x00000000}},	//   duzv, _holy_, оҳий, --, 
   {{0x4e04012c,0x3204022a,0xdd0c013d,0x00000000}},	//   ाउदै_, _koly_, _tışt, --, 
   {{0x32049ec6,0xed580075,0xaa5821ea,0x7d1001ed}},	//   _joly_, _йол_, السا_, öksé, 
   {{0x5a300108,0x32049ec7,0x02d419cc,0x00000000}},	//   чнёт, _moly_, _धन्न, --, 
   {{0x32049ec8,0x600c0192,0x00000000,0x00000000}},	//   _loly_, _cùmh, --, --, 
   {{0x7c94001f,0x600c01c3,0x2700013f,0xdbd403b2}},	// [c720] ቀጥለው_, _dùmh, rɔno_, møðu, 
   {{0xe9d8009b,0xdbd40162,0xe8f800f3,0x00000000}},	//   _ско_, løðu, _бло_, --, 
   {{0xdcf80a54,0xf49002d3,0xa3e80395,0x00000000}},	//   vatī, _ዝቐርብ_, лджа_, --, 
   {{0x5f1800cd,0x203c0240,0x00000000,0x00000000}},	//   यनम्_, _ኣጣሚር, --, --, 
   {{0x320403d1,0xdcf8005f,0xddc00024,0x78a006ea}},	//   _boly_, tatī, _ruož, álvv, 
   {{0xa6e00579,0x27e00198,0x5690039b,0xd24c00d1}},	//   øðun, _hakn_, _хаёт, ۈچە_, 
   {{0x32049ec9,0xdcf80061,0x20c800e3,0x21a401d5}},	//   _doly_, ratī, ابتي_, _ҳизм, 
   {{0x90944116,0xdbd40162,0xd0140108,0x3f14117e}},	//   حضور_, jøðu, йфы_, ждис, 
   {{0x3204002d,0xc22404fb,0xdcf80318,0x00000000}},	//   _foly_, _وکتو, patī, --, 
   {{0xa5241b4b,0x130400a8,0xfd60010e,0x3204010b}},	//   _རྟོག_, _унуй_, _gazỳ, _goly_, 
   {{0xcc8411fc,0x00000000,0x00000000,0x00000000}},	//   ینیه_, --, --, --, 
   {{0x32040109,0x26c0022e,0x78b40419,0x00000000}},	//   _zoly_, _oqko_, vuzv, --, 
   {{0x3204010b,0xf3480240,0x00000000,0x00000000}},	//   _yoly_, _እናተጓ, --, --, 
   {{0x20049eca,0x78b40099,0x80dc012c,0xf9881e5a}},	//   _hooi_, tuzv, _मनाइ, شنري_, 
   {{0x9c843c4b,0x27e0003e,0x20042e6c,0x97a46e9c}},	//   _اشته, _bakn_, _kooi_, йрал, 
   {{0xb9007db3,0xfc64619c,0x78b40099,0x98480137}},	//   _धन_, _بختی, ruzv, уяга_, 
   {{0x2004292b,0x81b02158,0xd6d40f22,0xf5980395}},	// [c730] _mooi_, ট্য_, সম্প, иващ_, 
   {{0x7aec9ecb,0x20049ecc,0x78d4030d,0x3bcc01a9}},	//   _irat, _looi_, _джох, lоq_, 
   {{0x7aec9ecd,0x4d7800c8,0x32049ece,0xf4d8013d}},	//   _hrat, ארבע, _roly_, рмеш_, 
   {{0x7aec9ecf,0x78a00579,0x4cb800c8,0x200405e4}},	//   _krat, álvu, רמאג, _nooi_, 
   {{0x7bcc0399,0xc04c02d3,0x320425a5,0x9f9006ea}},	//   _mbau, _ምህላው, _poly_, _røðu_, 
   {{0x7aec6dd7,0x00000000,0x00000000,0x00000000}},	//   _mrat, --, --, --, 
   {{0x320403d1,0x20041324,0xc0a83c19,0x798403ac}},	//   _voly_, _booi_, مايل_, _mfhw, 
   {{0x7aec9ed0,0x600c0086,0xc9180375,0xdfcc33d2}},	//   _orat, _mùmw, מחות_, نيى_, 
   {{0x7aec9ed1,0x2004017a,0xdbd40162,0x00000000}},	//   _nrat, _dooi_, vøðu, --, 
   {{0x7bcc1028,0xacc80022,0x00000000,0x00000000}},	//   _abau, агоз_, --, --, 
   {{0xed589ed2,0xdbd40579,0x2004057b,0x00000000}},	//   рон_, tøðu, _fooi_, --, 
   {{0x7aec9ed3,0x20049ed4,0xae1c9ed5,0xc32003d4}},	//   _brat, _gooi_, योजन_, _ফুটি_, 
   {{0x6da49ed6,0xada49ed7,0x7aec0e21,0xdbd406ea}},	//   _дила, _далл, _crat, røðu, 
   {{0x2d80007d,0x7aec9ed8,0x7bcc0428,0x20040d27}},	//   _ühe_, _drat, _ebau, _zooi_, 
   {{0x7aec9ed9,0xa968623a,0x7c6419bc,0xed340014}},	//   _erat, рива_, تایل, _گوژھ, 
   {{0x1128001f,0x00000000,0x00000000,0x00000000}},	//   _እንድና, --, --, --, 
   {{0x27e00158,0x69d805da,0xdcf800c7,0x660400d8}},	// [c740] _vakn_, ôtes, vatĩ, опаа, 
   {{0xa524025c,0x00000000,0x00000000,0x00000000}},	//   _རྟུག_, --, --, --, 
   {{0x290c01a8,0x7aec00d7,0x78a006ea,0xfbc000cd}},	//   _æfa_, _zrat, álvt, ष्कम, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x20040151,0x00000000,0x00000000,0x00000000}},	//   _rooi_, --, --, --, 
   {{0x24900201,0xaab009d9,0x2004017a,0xe4d850d8}},	//   ምህርት_, _जिनक, _sooi_, _پورت_, 
   {{0x20040093,0x090c02f5,0xa5080276,0xdcf800e4}},	//   _pooi_, _হেতু_, _тева_, patĩ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7afc04ce,0x00000000,0x00000000,0x00000000}},	//   xxst, --, --, --, 
   {{0x7aec0a55,0x200405b1,0x00000000,0x00000000}},	//   _rrat, _wooi_, --, --, 
   {{0x7aec0e89,0x20049eda,0xb1f80014,0x7afc0175}},	//   _srat, _tooi_, _دِلچ_, wxst, 
   {{0x7aec9edb,0x600c0295,0x60d4012d,0xa5c85b14}},	//   _prat, _rùmw, łyms, स्तौ, 
   {{0x7aec0003,0x8ae402dd,0x25a800d7,0x99d400d1}},	//   _qrat, мірл, _odbl_, يتسا, 
   {{0x600c0428,0xda649edc,0x00000000,0x00000000}},	//   _pùmw, تاجي, --, --, 
   {{0x7aec3d19,0x00000000,0x00000000,0x00000000}},	//   _wrat, --, --, --, 
   {{0x2ee801fa,0x7bcc068c,0x00000000,0x00000000}},	//   _šafi_, _ubau, --, --, 
   {{0x7aec9edd,0xda648b4d,0x00000000,0x00000000}},	// [c750] _urat, _واخي, --, --, 
   {{0x78a00579,0x7c2c0165,0xec2401d9,0x45d4011c}},	//   álvs, _hmar, _وى۪پ, моус, 
   {{0x7c2c8d68,0x00000000,0x00000000,0x00000000}},	//   _kmar, --, --, --, 
   {{0x7c2c004e,0xdcf80432,0x00000000,0x00000000}},	//   _jmar, hatį, --, --, 
   {{0x38689ede,0x7c2c9edf,0x25a801fa,0x7a280024}},	//   mmar_, _mmar, _fdbl_, ežti, 
   {{0x38689ee0,0x00000000,0x00000000,0x00000000}},	//   lmar_, --, --, --, 
   {{0x7c2c9ee1,0x386800a3,0x34940108,0x00000000}},	//   _omar, omar_, _хабр, --, 
   {{0x34941ee3,0x7c2c067c,0xaf043f72,0xaf480092}},	//   _маҳр, _nmar, зпил, _አሳልፈ, 
   {{0x38689ee2,0xb8fc0135,0x11280092,0x6834013d}},	//   imar_, _རར_, _እንዲና, lüdä, 
   {{0x8c0803f4,0x38689ee3,0xed580032,0x00000000}},	//   _লগইন_, hmar_, йоп_, --, 
   {{0x61ec004e,0x00000000,0x00000000,0x00000000}},	//   _óbla, --, --, --, 
   {{0x7c2c1529,0xed582e56,0x3868009b,0xafc40150}},	//   _cmar, _қой_, jmar_, _ريتى, 
   {{0xad240aaf,0x38689ee4,0xcdc002dd,0x00000000}},	//   زىڭى, dmar_, _жалқ, --, 
   {{0x7c2c9ee5,0x7e6802fa,0x8d900014,0xceb450cb}},	//   _emar, cmdp, _کٔژت, _ләү_, 
   {{0xfe7013e1,0x38680998,0x64b80358,0xeb980dab}},	//   _شده_, fmar_, _उमेश, _лий_, 
   {{0x7c2c9ee6,0x2d840af2,0x9cc4031c,0xa6846c73}},	//   _gmar, lcle_, _ཀྱིས, злад, 
   {{0xe6189ee7,0x09e40154,0x57400108,0x78a00174}},	// [c760] бда_, মাবা, ентб, álvr, 
   {{0x2d849ee8,0x7c2c0034,0x68340793,0x38689ee9}},	//   ncle_, _zmar, füdä, amar_, 
   {{0x7c2c9eea,0x224003b2,0x18a00006,0x2d840332}},	//   _ymar, _íkki_, _паэм, icle_, 
   {{0x7c2c9eeb,0xe4509eec,0xe2a801d9,0x38680077}},	//   _xmar, رضا_, ماتن_, cmar_, 
   {{0xfbc02f2e,0x6aa4007c,0x00000000,0x00000000}},	//   ष्टम, nskf, --, --, 
   {{0x64a49eed,0x24880129,0x23c40014,0x68340139}},	//   _нага, _ttbm_, تٕچہ, büdä, 
   {{0x15400107,0x00000000,0x00000000,0x00000000}},	//   _зерм, --, --, --, 
   {{0xdfd80801,0xef9001b9,0x00000000,0x00000000}},	//   сък_, نیمد, --, --, 
   {{0x63a09eee,0x5464013e,0x00000000,0x00000000}},	//   maon, _хатм_, --, --, 
   {{0x63a09eef,0x386803b9,0xfd140798,0x00000000}},	//   laon, zmar_, дмоќ, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x296002d3,0x2d840204,0x38680009,0x00000000}},	//   _ተስፋይ_, acle_, xmar_, --, 
   {{0x62805dd4,0x0ba4084c,0x7a280064,0x00000000}},	//   nqoo, эшэм, ižtv, --, 
   {{0x63a09ef0,0x6b84030d,0x8f540023,0xdde801e2}},	//   haon, ackg, _ምስኣቶ, _چرګه_, 
   {{0x63a09ef1,0x38689ef2,0xee2800c6,0x44b401ec}},	//   kaon, tmar_, _بأنه_, _ﯨﺰدە, 
   {{0x7c2c9ef3,0x63a09ef4,0x38689ef5,0x00000000}},	//   _umar, jaon, umar_, --, 
   {{0x63a0055a,0x394c0210,0x8aa400c0,0x00000000}},	// [c770] daon, łes_, _прэд, --, 
   {{0x62800548,0xaab02e3b,0x00000000,0x00000000}},	//   dqoo, _जितक, --, --, 
   {{0x7c3c0c8c,0x63a09ef6,0xf8e002e5,0x3868003a}},	//   onsr, faon, _पनिय, pmar_, 
   {{0x7c3c449c,0x2d840789,0x00000000,0x00000000}},	//   nnsr, zcle_, --, --, 
   {{0x2d849ef7,0x4374425b,0x7c3c0857,0x27e40115}},	//   ycle_, нушт, insr, ɾon_, 
   {{0x7c3c03cd,0x00000000,0x00000000,0x00000000}},	//   hnsr, --, --, --, 
   {{0x63a09ef8,0x95544336,0xefdc0023,0x62800009}},	//   baon, _رخسا, ንዳዊ_, aqoo, 
   {{0xef1807d6,0x63a09ef9,0x6aa4002d,0x00000000}},	//   жми_, caon, yskf, --, 
   {{0x2d840175,0xd1c80107,0x00000000,0x00000000}},	//   tcle_, _гуед_, --, --, 
   {{0x910413cf,0x00000000,0x00000000,0x00000000}},	//   _нчед, --, --, --, 
   {{0xcee89efa,0x62245f32,0x2bb8007b,0x417400db}},	//   _گران_, _تولە, ياحة_, _كامس, 
   {{0x2d849efb,0xbb44001f,0xdf840014,0x7c3c7664}},	//   scle_, _ያስችላ, _قُمی, gnsr, 
   {{0xcee80133,0x2fcc030a,0x7f9400c7,0xa48c0240}},	//   _دران_, mfeg_, _чачх, _ዝጐደሎ_, 
   {{0x6aa46525,0xce683529,0x63a002ce,0x9f440165}},	//   rskf, _уред_, zaon, _nnoù_, 
   {{0x63a09efc,0xbb3008b0,0x43580b82,0xebe4004e}},	//   yaon, ﻨﺎﻕ_, ግስተኣ, _жойп, 
   {{0xfd101063,0x00000000,0x00000000,0x00000000}},	//   _حجه_, --, --, --, 
   {{0x63a09efd,0xe5a49efe,0xab6401d5,0x7a280064}},	// [c780] vaon, дизи, _ювил, ežtu, 
   {{0x63a07de8,0xd6cc029e,0x00000000,0x00000000}},	//   waon, شقم_, --, --, 
   {{0x63a09eff,0x9f4001a2,0xf4840220,0xa9689f00}},	//   taon, ľké_, еуін, _фина_, 
   {{0x69cc5b5e,0x9f400122,0xe3b01b45,0x62800548}},	//   lfbe, žké_, ئرا_, tqoo, 
   {{0x98149f01,0x00000000,0x00000000,0x00000000}},	//   _آبپا, --, --, --, 
   {{0x62809f02,0x2fcc0036,0xa5f8022e,0x6e200419}},	//   rqoo, efeg_, _o想in, jhlb, 
   {{0x63a09f03,0x7c3c383d,0x2fcc9df6,0xf664004e}},	//   paon, ynsr, ffeg_, _черү, 
   {{0xd1803941,0x6e2000d7,0x64a41171,0x00000000}},	//   нләй, ehlb, _наҳа, --, 
   {{0xa1c49f04,0x62809f05,0x7c3c03b2,0x53a001ee}},	//   _обад, qqoo, vnsr, _шатб, 
   {{0x06d80eac,0x69cc01f5,0x6e200327,0x00000000}},	//   সিপি, jfbe, ghlb, --, 
   {{0x61f8021a,0x7c3c03f2,0xa2d81546,0x20000254}},	//   _intl, tnsr, पौर्, ökis_, 
   {{0x69cc01a4,0xfff82fc0,0x7c3c01c7,0x2cb002f0}},	//   efbe, _رکعت_, unsr, ázda_, 
   {{0x7c3c0857,0x69cc0112,0xdb0c01ed,0x7524003e}},	//   rnsr, ffbe, _üdül, zzhz, 
   {{0x81b00eac,0x13e40011,0x81bc00fe,0x00000000}},	//   ট্র_, ফায়, ইজক_, --, 
   {{0x61f80472,0x981404d3,0xc1dc012c,0x1abc00cc}},	//   _mntl, وبرا, _यसैग, ইবো, 
   {{0x7e780477,0xda640451,0x00000000,0x00000000}},	//   _hivp, _ڪابي, --, --, 
   {{0x76b89f06,0x61f82595,0x2700013f,0x35f4039b}},	// [c790] ялар_, _ontl, kɔnu_, нпар, 
   {{0x7bdc9f07,0xda649f08,0x7e780477,0x61f801a9}},	//   lesu, _تابي, _jivp, _nntl, 
   {{0x73d87655,0x9964466e,0x2bc400cd,0x7528013a}},	//   здер_, _ютил, _वामा, _řezb, 
   {{0x61f89f09,0x7e780158,0x00000000,0x00000000}},	//   _antl, _livp, --, --, 
   {{0x49b8036b,0x16702b8d,0xf31401c6,0x00000000}},	//   _عاید_, _ақар, эддэ, --, 
   {{0xaab0006d,0x7bdc9f0a,0x2bc401ad,0x00000000}},	//   _जिसक, hesu, _वाभा, --, 
   {{0x387800f3,0x00000000,0x00000000,0x00000000}},	//   _kisr_, --, --, --, 
   {{0x61f89f0b,0x7bdc9f0c,0x38780327,0x04640117}},	//   _entl, jesu, _jisr_, _атум, 
   {{0x7bdc9f0d,0x387801b9,0x8af003e3,0x2fcc0036}},	//   desu, _misr_, _ayən, rfeg_, 
   {{0x7e78007f,0x7c78001f,0x1f600022,0x00000000}},	//   _civp, _ከተማው_, ыкым, --, 
   {{0x7bdc9f0e,0x81bc00da,0x60c8039a,0x823400c6}},	//   fesu, _slēg, ctfm, _شركا, 
   {{0x7bdc9f0f,0x38780223,0x777c02d0,0x00000000}},	//   gesu, _nisr_, _ngsx, --, 
   {{0x81bc02b5,0x7de4035c,0xe5e8008e,0x27fc0051}},	//   _imēr, رسیم, _ülçä, _đtn_, 
   {{0x3dc80451,0x69cc0112,0xee2401e1,0x00000000}},	//   _يونٽ_, ufbe, bẹṣe, --, 
   {{0x7bdc9f10,0x3b04145e,0x69cc178a,0x683801ef}},	//   besu, _pëpë_, rfbe, hůde, 
   {{0x7bdc9f11,0xa5c0033f,0xe69401d5,0x273c0092}},	//   cesu, _लाहौ, فلرد, _ተመርጠ, 
   {{0xe618086f,0x69cc0112,0x6374010b,0x00000000}},	// [c7a0] пда_, pfbe, _münü, --, 
   {{0x6038031c,0x00000000,0x00000000,0x00000000}},	//   rċmi, --, --, --, 
   {{0xa2f80490,0xbb440092,0x00000000,0x00000000}},	//   ्ह्ज_, _ያስተላ, --, --, 
   {{0x2a78070d,0x06d800eb,0x00000000,0x00000000}},	//   _hipb_, সিবি, --, --, 
   {{0xba280424,0xa184008e,0x00000000,0x00000000}},	//   _رسیم_, ныйл, --, --, 
   {{0x7bdc9f12,0x60e4228e,0xc17400db,0x61e89f13}},	//   zesu, ециз, نگات, udfl, 
   {{0x35c416c3,0x61e8007c,0x2bc40073,0x00000000}},	//   _шарҳ, rdfl, _वाढा, --, 
   {{0x7bdc0a73,0x81bc005f,0x69d8013f,0xbed40120}},	//   xesu, _slēd, εten, воиј, 
   {{0x7bdc9f14,0xb35c0020,0x660c9f15,0x637403e0}},	//   vesu, ሳቸውን_, _kobk, _dünü, 
   {{0x660c00b5,0x7bdc9f16,0x2d90002d,0x61f89f17}},	//   _jobk, wesu, űzen_, _untl, 
   {{0x660c02ea,0x7bdc9f18,0x7e7800df,0xc0c401ee}},	//   _mobk, tesu, _vivp, _рәли, 
   {{0x63749f19,0x660c9f1a,0x7e780455,0xc5d40154}},	//   _günü, _lobk, _wivp, _হোমপ, 
   {{0x1ea8004b,0x7e780477,0xdce801a6,0x06d80154}},	//   _راشي_, _tivp, čiđe, সিডি, 
   {{0x660c005a,0x4ef8025d,0xe8e80014,0x80d40037}},	//   _nobk, _מהדו, ڈرٲو_, _दहाइ, 
   {{0x7bdc9f1b,0x63740205,0xa3c00b02,0xb7c400c7}},	//   pesu, _yünü, ्भा_, крақ, 
   {{0x36d422c3,0x7bdc0023,0x46ac000d,0x00000000}},	//   кобр, qesu, _चिखह, --, 
   {{0x2bc437cc,0x7d1c9f1c,0x660c9f1d,0xc8647b0a}},	// [c7b0] _वाता, ørsf, _bobk, утри, 
   {{0x163800c6,0xf8d40ce8,0x875400d4,0x00000000}},	//   أسرة_, _иңгә_, укує, --, 
   {{0x442002dd,0x955401e2,0x00000000,0x00000000}},	//   гi_, رخطا, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x028802dd,0x81bc00fe,0x00000000,0x00000000}},	//   ейік_, েজন_, --, --, 
   {{0x42b80058,0x51849f1e,0x660c0009,0x81bc00e2}},	//   رنىڭ_, худа, _gobk, _smēr, 
   {{0x62848851,0x8af00213,0x45d4117e,0x00000000}},	//   _ékon, _ayəl, _щорс, --, 
   {{0x660c0219,0x00000000,0x00000000,0x00000000}},	//   _zobk, --, --, --, 
   {{0xb2749f1f,0xa3e40490,0xbf88009f,0xc7d8011a}},	//   _алаш, _बघत_, رئيل_, תוחי_, 
   {{0x273c07ae,0x7c24031c,0x00000000,0x00000000}},	//   ắng_, _ċira, --, --, 
   {{0x2bc40a59,0x64480129,0x00000000,0x00000000}},	//   _वादा, éfig, --, --, 
   {{0x2a78007f,0x65786d54,0x00000000,0x00000000}},	//   _sipb_, _úthe, --, --, 
   {{0x8af09f20,0x68380118,0x1c401d0b,0xab5c0150}},	//   _azər, hůdc, рням, _ﺍﺭﺗﯟ_, 
   {{0x0dc8016c,0xa96807d6,0x00000000,0x00000000}},	//   _худи_, дига_, --, --, 
   {{0x5e549f21,0x660c0064,0x00000000,0x00000000}},	//   _جلوس_, _robk, --, --, 
   {{0x18642b20,0x00000000,0x00000000,0x00000000}},	//   васи_, --, --, --, 
   {{0x7c64007b,0x17801171,0x00000000,0x00000000}},	// [c7c0] _حاول, ргум, --, --, 
   {{0x752800bc,0x7d1c0fac,0x3ea00139,0x377401ec}},	//   _řeza, ørsg, _çite_, уысс, 
   {{0x68449f22,0x660c01d5,0xe874007b,0x00000000}},	//   _анна, _vobk, _لاحظ, --, 
   {{0x442000e5,0x00000000,0x00000000,0x00000000}},	//   ói_, --, --, --, 
   {{0x660c002d,0x7c3c24c8,0x5394177b,0x00000000}},	//   _tobk, érri, твія_, --, 
   {{0x51f000d1,0x00000000,0x00000000,0x00000000}},	//   لسىر, --, --, --, 
   {{0x64a40364,0x63840117,0x60440166,0x9f400419}},	//   _шава, _агба, кхиз, ľkí_, 
   {{0xaab00490,0x3e2002d3,0x154000ee,0x40340120}},	//   _जिंक, _ስለዘየ, _тесм, ѓепс, 
   {{0x93105e75,0x00000000,0x00000000,0x00000000}},	//   _پولش, --, --, --, 
   {{0xa3c09f23,0x64400419,0x00000000,0x00000000}},	//   ्भव_, lnoi, --, --, 
   {{0xa3e40574,0x55b80375,0x00000000,0x00000000}},	//   _बघा_, ומיו, --, --, 
   {{0x6440049b,0x4f9000f3,0x00000000,0x00000000}},	//   nnoi, _крљу, --, --, 
   {{0x64409f24,0xf1c80d2e,0xc0c400d1,0x00000000}},	//   inoi, _रामन, _рәһи, --, 
   {{0xf8b8955d,0xcd300133,0x644001f4,0x00000000}},	//   нөм_, اریب, hnoi, --, 
   {{0xa3c02ce6,0x7d1c5522,0x00000000,0x00000000}},	//   ंला_, ørsd, --, --, 
   {{0xb6c401c0,0x6f0c0129,0x00000000,0x00000000}},	//   лөгд, _àacc, --, --, 
   {{0x60d81529,0x163800c6,0x00000000,0x00000000}},	// [c7d0] _lptm, وسطة_, --, --, 
   {{0xcfe800bd,0x644002d0,0x85b807b5,0x8b580375}},	//   কায়_, enoi, клус_, _ביחס_, 
   {{0x8af006be,0x49c80150,0x00000000,0x00000000}},	//   _uzər, _руым_, --, --, 
   {{0x64409f25,0xe83c0092,0x00000000,0x00000000}},	//   gnoi, _የብዙዎ, --, --, 
   {{0x1dc03eaf,0x59a4038e,0x62840e47,0x67440030}},	//   _शांत, _औजार, _ékol, čujú, 
   {{0x64400433,0x7dec15c0,0x00000000,0x00000000}},	//   anoi, जयोग_, --, --, 
   {{0xc0a8007b,0x00000000,0x00000000,0x00000000}},	//   نايل_, --, --, --, 
   {{0xefc8059f,0x00000000,0x00000000,0x00000000}},	//   хлил_, --, --, --, 
   {{0xa3c00118,0x00000000,0x00000000,0x00000000}},	//   ्भर_, --, --, --, 
   {{0x5de007dd,0x20540228,0x2bc40aa2,0x00000000}},	//   бжьа, ктөр, _वाहा, --, 
   {{0x6cc40953,0x69d80254,0x00000000,0x00000000}},	//   ыйна, õtem, --, --, 
   {{0xeb98084c,0x3c380022,0x00000000,0x00000000}},	//   эим_, tũva_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xada497da,0xd7d8037e,0xcfb8009e,0xad2458c5}},	//   _сакл, _fiル_, _অঘটন, _مرعو, 
   {{0x291c9f26,0x752800bc,0x64400076,0x3c380022}},	//   áta_, _řezn, ynoi, sũva_, 
   {{0x7d1c708a,0x66e49f27,0x313402d3,0x06d80154}},	//   ørse, лоба, _እንትር, সিসি, 
   {{0x291c04b9,0x7c3c0ba1,0x64400010,0x81bc00fe}},	// [c7e0] šta_, èrre, vnoi, েজত_, 
   {{0xe7d000cf,0x7d28010e,0x9b901d0a,0x1a98010f}},	//   _گۅرگ, _össü, _پلیت, _רייע, 
   {{0xe3b89f28,0x644030e8,0x24f40153,0x00000000}},	//   ебе_, tnoi, ычар, --, 
   {{0x64400433,0x30f80882,0x234816a0,0x60d80175}},	//   unoi, ्मनः_, ىلاپ_, _rptm, 
   {{0x64409f29,0x81bc0618,0x00000000,0x00000000}},	//   rnoi, _alēa, --, --, 
   {{0x5ebc00fe,0x64409f2a,0xdb2000e5,0x00000000}},	//   ্বমে, snoi, írég, --, 
   {{0x244c00d0,0x00000000,0x00000000,0x00000000}},	//   zýmy_, --, --, --, 
   {{0x64400369,0x73c00166,0x00000000,0x00000000}},	//   qnoi, _дәше, --, --, 
   {{0x44249f2b,0xd6f800b5,0x4e90035c,0x80a40037}},	//   _ilm_, _hdゲ_, یشیر, _गौरइ, 
   {{0x44249f2c,0x00000000,0x00000000,0x00000000}},	//   _hlm_, --, --, --, 
   {{0xd6540302,0xdde00166,0x00000000,0x00000000}},	//   ריית_, _һәнү, --, --, 
   {{0x5f280f06,0x00000000,0x00000000,0x00000000}},	//   _поем_, --, --, --, 
   {{0x2bc49f2d,0x7d1c0450,0x69d400cd,0x2ff80066}},	//   _वारा, ørsb, म्भी, _جونگ_, 
   {{0x3d9406dc,0xdde8004b,0xda2400d4,0xfcc401af}},	//   _тикр, _سرته_, уємо, _кәмм, 
   {{0x7cc8043b,0x313402d3,0x2e2803b2,0xd7f800c0}},	//   _vɛrs, _እንተር, _búff_, нуа_, 
   {{0x44240b0e,0xb8ec0764,0xd83801c0,0x69d435e0}},	//   _nlm_, _रम_, хэг_, म्बी, 
   {{0xd5b89f2e,0x00000000,0x00000000,0x00000000}},	// [c7f0] есе_, --, --, --, 
   {{0x44249f2f,0x94a801b9,0x00000000,0x00000000}},	//   _alm_, етда_, --, --, 
   {{0x44249f30,0xef18012d,0xa3c000cd,0x20c408dd}},	//   _blm_, zyż_, ्भं_, रूमध, 
   {{0x44240005,0xb39002d3,0xdd840d23,0x00000000}},	//   _clm_, _ዝበዝሕ_, _ژو_, --, 
   {{0x44249f31,0x9f4401e7,0xf1a83bd6,0x7c240327}},	//   _dlm_, _baoí_, ناغه_, _ċirl, 
   {{0x442403be,0x998000c0,0x00000000,0x00000000}},	//   _elm_, mijų_, --, --, 
   {{0x44249f32,0x99800153,0x2bc4134e,0x40940006}},	//   _flm_, lijų_, _वाला, брыт, 
   {{0x657809e8,0xa3c000dc,0x73c41541,0xb4c04f76}},	//   _útha, ्भः_, _خيرم, ंढी_, 
   {{0x60044734,0xf1d00184,0x99800024,0xb134001f}},	//   рным_, _дөйө, nijų_, _እንዲሳ, 
   {{0x7644143a,0x12900023,0x622400db,0xef18012d}},	//   nnhy, _ዝሰዓበ_, _پومە, ryż_, 
   {{0x9f4001f1,0x76440158,0x00000000,0x00000000}},	//   ľká_, inhy, --, --, 
   {{0x9f4002fb,0x44240208,0x00000000,0x00000000}},	//   žká_, _xlm_, --, --, 
   {{0xe45400df,0x53d406ff,0x00000000,0x00000000}},	//   שירט_, ण्यश, --, --, 
   {{0x69249f33,0x99800006,0x8d849f34,0x6dc000cf}},	//   амга, dijų_, _судд, _بۅدۅ, 
   {{0x2e2802d2,0xb6840145,0xec48011c,0x00000000}},	//   _púff_, ەشمى, _изкл_, --, 
   {{0xdc540014,0x99800024,0xd820022e,0x00000000}},	//   _پر٘ک, fijų_, одси, --, 
  
   {{0x99800006,0x6f080077,0x81b0015b,0xd1b80092}},	// [c800] gijų_, nxec, ট্ট_, ተሉት_, 
   {{0x630400aa,0x7ae870f7,0x44240790,0x24f4010a}},	//   یوال, çete, _slm_, ичер, 
   {{0x855800f2,0x80d4000d,0x00000000,0x00000000}},	//   ایزر_, _दहें, --, --, 
   {{0xe2980aa5,0xa11401b9,0x746800d4,0x00000000}},	//   вад_, یوشت, грів_, --, 
   {{0x998002d5,0x442401a6,0xb6c401af,0x00000000}},	//   cijų_, _vlm_, _лияһ, --, 
   {{0x44240076,0x27f01368,0x81bc00ef,0x00000000}},	//   _wlm_, ldyn_, _elēn, --, 
   {{0x44249f35,0x69cc0243,0x27f00076,0x00000000}},	//   _tlm_, _तानी, odyn_, --, 
   {{0x44249f36,0xdfd806bb,0xdb080365,0x691c0135}},	//   _ulm_, тък_, _çiçe, _iħeġ, 
   {{0x27f00363,0xdd981fce,0xd478011a,0x8fa00114}},	//   idyn_, кшн_, _יאלל, цање, 
   {{0x20d410f5,0x3eb8151c,0x394c0274,0x27f09f37}},	//   _відс, črt_, şesi_, hdyn_, 
   {{0xd7d804ce,0x691c025c,0x30f800dc,0x99800153}},	//   _chホ_, _jħeġ, ्मणः_, zijų_, 
   {{0x6f08056a,0xd12c9f38,0x691c025c,0x52801411}},	//   bxec, _غمن_, _mħeġ, _الەك, 
   {{0x27f09f39,0x76440368,0x4fd4011a,0x3c3800c7}},	//   ddyn_, ynhy, _כואב_, sũvo_, 
   {{0x68280162,0x27f00076,0x4ef8011a,0x00000000}},	//   _lýdd, edyn_, _שהגו, --, 
   {{0x58849f3a,0x9cc80588,0xd8742aaf,0x26d00083}},	//   рыга, _рыла_, لارب, etyo_, 
   {{0x99800153,0x30f800cd,0x27f000ee,0x00000000}},	//   tijų_, ्मतः_, gdyn_, --, 
   {{0x271c9f3b,0x7c3c9f3c,0x35b42f89,0x7bcc0165}},	// [c810] _nānā_, misr, йбар, _icau, 
   {{0x7aec9f3d,0x998002d5,0x85b8182c,0x7c3c9f3e}},	//   _isat, rijų_, لامس_, lisr, 
   {{0x81bc6845,0x99800006,0x26d00083,0x7984035a}},	//   _alēo, sijų_, atyo_, _ighw, 
   {{0xc484005e,0x7aec440e,0x7c3c9f3f,0xd3441fb8}},	//   ілік, _ksat, nisr, لیزه_, 
   {{0x7bcc1681,0xc2e800db,0x55c001ec,0x00000000}},	//   _mcau, لعوم_, _қаңғ, --, 
   {{0x7aec02ce,0x7c3c9f40,0x271c0055,0x21a001b9}},	//   _msat, hisr, _dānā_, пишм, 
   {{0x691c031c,0x3d2005f9,0x7c3c148b,0x0f1c1d68}},	//   _għeġ, मनों_, kisr, यन्स_, 
   {{0x7aec9f41,0x7bcc0457,0xd14800e5,0x83840024}},	//   _osat, _ncau, _یشان_, _дыфе, 
   {{0x7aec9f42,0x43940276,0x7fe89f43,0x7984047e}},	//   _nsat, _фаус, شريف_, _oghw, 
   {{0x7bcc1c1d,0x79849f44,0x6f080077,0x682800a2}},	//   _acau, _nghw, rxec, _iýde, 
   {{0x30840491,0x7aec9f45,0x27f09f46,0x5c8400ee}},	//   _الصف, _asat, ydyn_, ййэм_, 
   {{0x7aec031c,0x7bcc0042,0x7c3c9f47,0x7d1c3c02}},	//   _bsat, _ccau, gisr, ørsa, 
   {{0x7aec066d,0x405400cf,0x7c3c180f,0x00000000}},	//   _csat, _بئلس, èrra, --, 
   {{0x7bcc14dc,0x7aec025c,0x7c3c9a14,0x682801ef}},	//   _ecau, _dsat, aisr, _mýde, 
   {{0x7aec9f48,0x7c3c007c,0xb4c0012d,0x00000000}},	//   _esat, bisr, ंढो_, --, 
   {{0x81bc3495,0xd9409f49,0x6dc000cf,0x26d0037e}},	//   _alēl, чеси, _بۅگۅ, ttyo_, 
   {{0x27f09f4a,0x18649f4b,0x09d004c5,0x00000000}},	// [c820] rdyn_, сати_, াজবা, --, 
   {{0x26d09f4c,0xa5089f4d,0x30f800dc,0x21d401ec}},	//   rtyo_, леза_, ्माः_, _ﺜﻤﺎﺭ, 
   {{0x26d000b8,0x682800a2,0x78a839ae,0x271c00ef}},	//   styo_, _aýde, ćevc, _sānā_, 
   {{0xd6f8019b,0x7aec9f4e,0x7c240003,0x271c00b8}},	//   _ndシ_, _ysat, _ċirk, _pānā_, 
   {{0x2bd81a2a,0x0508015b,0xf1c807f7,0x00000000}},	//   य्या, লনের_, _राशन, --, 
   {{0x59d8190c,0x65789f4f,0x78a40334,0x691c0135}},	//   म्पर, _útho, _ywhv, _tħeġ, 
   {{0x7c3c00ca,0x68280174,0x00000000,0x00000000}},	//   yisr, _týdd, --, --, 
   {{0x2f840184,0x1ee401ed,0x6e0c0241,0x7c3c002f}},	//   ҙҙән_, موعی_, _ránṣ, xisr, 
   {{0x25a801b8,0x3dac03d4,0x20000b97,0x00000000}},	//   _kebl_, _খাবল, ıki_, --, 
   {{0x7aec006c,0x7bcc9f50,0x9e049f51,0x81c801ed}},	//   _rsat, _scau, счил, _خطرہ_, 
   {{0xdd900d83,0x25a8009b,0x7c3c9f52,0x7aec0a49}},	//   _ہوش_, _mebl_, tisr, _ssat, 
   {{0x7aec020c,0x00000000,0x00000000,0x00000000}},	//   _psat, --, --, --, 
   {{0x7c3c9f53,0x38a40142,0x48c800eb,0x00000000}},	//   risr, wŷr_, শবোর, --, 
   {{0x7c3c51c2,0x6a70007f,0x2ea401d3,0xceb0010f}},	//   sisr, hæff, _بھٹی_, _זיס_, 
   {{0xf8b80032,0x0c7401d5,0x00000000,0x00000000}},	//   шөп_, تدید, --, --, 
   {{0x77989f54,0x24cc0154,0x17f8007b,0x81dc00cc}},	//   ркар_, রবাহ, درسة_, _তোম_, 
   {{0x7aec9f55,0x69d49f56,0x7d1c01e3,0x00000000}},	// [c830] _usat, म्ही, ärsf, --, 
   {{0x64489f57,0x8cbc07f7,0x25a80042,0x79849f58}},	//   éfin, लूको, _cebl_, _ughw, 
   {{0x65780008,0x54a400c6,0x27f0005b,0x04b4003b}},	//   _úthl, صحاف, önnä_, зсія, 
   {{0x69d8000d,0x00000000,0x00000000,0x00000000}},	//   õtev, --, --, --, 
   {{0x70e0257b,0xd6f8037e,0x00000000,0x00000000}},	//   पब्ल, _rdシ_, --, --, 
   {{0x682800bc,0x25a80142,0x43740212,0xc2440024}},	//   _výde, _gebl_, чуєт, пнік, 
   {{0x6ab410eb,0x09e40eac,0xe0cc0014,0xddd800d7}},	//   _अट्र, মাচা, نٲو_, motň, 
   {{0x68280316,0x2eb49f59,0xe0d40006,0xc0a8007b}},	//   _týde, осос, івы_, حاول_, 
   {{0x91c84028,0x7d1c353e,0x225c00e2,0x6aa0031c}},	//   _مذاق_, ørsn, _fktk_, _ħofo, 
   {{0x236006ea,0xed5801af,0xeff40023,0x05cc00bc}},	//   _økja_, иоп_, _ጉንዲ_, ालयब, 
   {{0xac08074d,0xec4817a0,0x00000000,0x00000000}},	//   анна_, изол_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3cfc01f4,0x5ac40064,0xdfcc678e,0x00000000}},	//   _ervv_, олям_, _شيو_, --, 
   {{0x5ebc03f4,0xb0dc0aa2,0x2bc42450,0xceb401af}},	//   ্বশে, _महाग, _वाका, _кәү_, 
   {{0x8af00213,0xeb980fac,0x00000000,0x00000000}},	//   _ayət, _кий_, --, --, 
   {{0x59d844af,0x5ebc015b,0x4ba400ee,0xac74484d}},	//   म्बर, ্বরে, _элиң, _باتش, 
   {{0x32049f5a,0x78a8110c,0x24880175,0x00000000}},	// [c840] _only_, ćeva, _subm_, --, 
   {{0x55e0055f,0xe9d8009b,0x7d1c007c,0x00000000}},	//   моуб, _тко_, ärsg, --, 
   {{0x24e80022,0x00000000,0x00000000,0x00000000}},	//   рмеи_, --, --, --, 
   {{0x32049f5b,0x9cd8008f,0x00000000,0x00000000}},	//   _anly_, יקעפ, --, --, 
   {{0x68380118,0xddd800d0,0x6a709f5c,0x00000000}},	//   hůdk, botň, ræff, --, 
   {{0x5ba4012d,0x00000000,0x00000000,0x00000000}},	//   _ख़्व, --, --, --, 
   {{0x16f40327,0x00000000,0x00000000,0x00000000}},	//   _ཕནོམ_, --, --, --, 
   {{0x920000af,0x225c037e,0x78440024,0x8af003b9}},	//   लाउज_, _wktk_, tėvi, _yyət, 
   {{0xb35c001f,0x00000000,0x00000000,0x00000000}},	//   ዳቸውን_, --, --, --, 
   {{0x63a09f5d,0x69d806ab,0x82a402dd,0x7d1c0b1a}},	//   lbon, _पॉली, _мағж, ørso, 
   {{0x92300952,0x63a00337,0x7a3001e1,0xf1a80345}},	//   _تىلش, obon, _lótù, _داقه_, 
   {{0xe0e40ba1,0x9be4003b,0x00000000,0x00000000}},	//   _çòqu_, ціок, --, --, 
   {{0x20040053,0x63a00793,0x02c80118,0x291c0162}},	//   _inoi_, ibon, _रमोन, øtan_, 
   {{0xda180073,0x76a001e1,0x8af003e3,0x63a0022e}},	//   _नकळत_, _láyò, _ayəs, hbon, 
   {{0x63a09f5e,0x69dc020b,0x7d1c01e3,0x35dc0210}},	//   kbon, _dbpe, ärsd, न्फ़, 
   {{0x63a0010f,0xd6d80276,0x64480129,0x00000000}},	//   jbon, итз_, éfil, --, 
   {{0xd7749f5f,0x2e28032e,0x00000000,0x00000000}},	// [c850] زارع, _húfa_, --, --, 
   {{0x63a09f60,0xd56401f0,0x69d8000d,0x00000000}},	//   ebon, отеп, õtet, --, 
   {{0x200400b0,0x8398063f,0x63a0022e,0x00000000}},	//   _onoi_, _ịhụg, fbon, --, 
   {{0x63a09f61,0x58000075,0xe67800e2,0x448802dd}},	//   gbon, _تۈرك, āršā, ібін_, 
   {{0x23b09f62,0x437400f7,0xc6f884da,0x64681155}},	//   رموس, мушт, _днях_, _špió, 
   {{0x20049f63,0x63a09f64,0xf678008f,0xd2580006}},	//   _anoi_, abon, _לאָמ, шце_, 
   {{0x7d1c9f65,0x63a01486,0xb2640014,0xa280104c}},	//   ørsl, bbon, _ہُرى, ریمو, 
   {{0x2004015d,0x03c407b5,0xf44801d3,0x63a00208}},	//   _cnoi_, _осум, _الرٹ_, cbon, 
   {{0xee389f66,0x28a0000d,0x318401af,0x2c700419}},	//   йни_, _ओढ़नि, _етең, náde_, 
   {{0xd08400c7,0x50a00116,0x00000000,0x00000000}},	//   _дыди, _قەتل, --, --, 
   {{0xed589f67,0x80a40597,0x41c401d9,0xdb0c0ba1}},	//   сон_, _يمكن, _زٲنِ, lacè, 
   {{0xf0f81533,0x30f801ed,0x20040042,0x682800a2}},	//   ्मीद_, _پوچھ_, _gnoi_, _oýda, 
   {{0xda0403f3,0x6da407dd,0x6a7000b5,0xdb0c068c}},	//   शांत_, _еила, hæfe, nacè, 
   {{0x63a09f68,0x28941fbe,0x00000000,0x00000000}},	//   zbon, зјас, --, --, 
   {{0x68280209,0x63a001a9,0xa96818a4,0xdcfc0356}},	//   _aýda, ybon, сива_, ăvăl, 
   {{0x2bc40574,0x2fcc9f69,0x63a00369,0x7d1c9f6a}},	//   _वाटा, ngeg_, xbon, ärse, 
   {{0x0cd89f6b,0x97c007a5,0x2c7000d7,0x69d8000d}},	// [c860] _बहुम, эйте, gáde_, õtes, 
   {{0x63a09f6c,0xdb0c067c,0x35c40107,0x6a7003b2}},	//   wbon, dacè, дафҳ, fæfe, 
   {{0x626404a9,0x63a07328,0xf9800b01,0x8ec00011}},	//   ۋاتق, tbon, _аҳро, ্বিগ, 
   {{0x1ca85078,0x9f4001f1,0x63a00d27,0xdb0c00db}},	//   _བསལ_, ľkú_, ubon, facè, 
   {{0x6f0c0129,0x77909f6d,0x9f400419,0x00000000}},	//   _àach, _شیلا, žkú_, --, 
   {{0x69cc9f6e,0xa50800d8,0x00000000,0x00000000}},	//   ngbe, _лега_, --, --, 
   {{0x64a49f6f,0x69cc017a,0x00000000,0x00000000}},	//   _хаба, igbe, --, --, 
   {{0x64a43461,0x7d1c1a84,0x6ebc4900,0x232840c4}},	//   _маҳа, ørsm, _शिशु, _лоби_, 
   {{0x64409f70,0xdb0c036e,0xb3d00bae,0x00000000}},	//   mioi, racë, _हातख, --, 
   {{0x64409f71,0xe5f40724,0xd7340375,0xae7000d1}},	//   lioi, _ütäç, פטית_, نۇنغ, 
   {{0xdb0c09ff,0x64400618,0x61e801bf,0x06d80154}},	//   macé, oioi, mefl, সিটি, 
   {{0xdb0c004a,0x69cc0549,0x6440023a,0x00000000}},	//   lacé, egbe, nioi, --, 
   {{0x60c89f72,0x7b840131,0x05cc0034,0x62844a16}},	//   lufm, بادە, ालाब, _ékos, 
   {{0x69cc9f73,0xdb0c9f74,0x64409f75,0x0ba40022}},	//   ggbe, nacé, hioi, _ҧшым, 
   {{0x69cc3eaf,0x78a80989,0x2bc400a5,0x6440023a}},	//   _तारी, ćevo, _वाचा, kioi, 
   {{0xdc280502,0x69cc0af9,0x9e640133,0x69d8000d}},	//   _دسته_, agbe, _باڵن, õter, 
   {{0x7c2c9f76,0x35f49f77,0x60c805b1,0x64409f78}},	// [c870] _ilar, мпар, hufm, dioi, 
   {{0x68280232,0x7bdc9f79,0x61e80158,0x2c7002f0}},	//   _výda, lfsu, jefl, ráde_, 
   {{0xb8349f7a,0x7afc9f7b,0x61e803ee,0xd7d8037e}},	//   _женщ, lvst, defl, _whパ_, 
   {{0x05749f7c,0x64409f7d,0xe094037e,0xdb0c0ba1}},	//   رالد, gioi, dゲ_, tacè, 
   {{0x38689f7e,0x7c2c0214,0xdb0c246d,0x2bc40073}},	//   mlar_, _mlar, facé, _वाघा, 
   {{0x7c2c6f63,0xdd8403af,0xf0e84acd,0x61e89f7f}},	//   _llar, _لو_, قىتى_, gefl, 
   {{0x7c2c9e1c,0xc0d402d3,0xf0f80307,0x2c54005f}},	//   _olar, _ኩቡር_, ्मेद_, lāde_, 
   {{0x64409f80,0x7bdc0d27,0x7c2c6064,0x682806ea}},	//   cioi, jfsu, _nlar, _lýdn, 
   {{0xdb0c004e,0x69cc27a6,0xd130004b,0xc42800ee}},	//   bacé, _ताली, _ګواښ, _эюре_, 
   {{0x7c2c9f81,0x3868006c,0x61e801f5,0xdb0c0129}},	//   _alar, hlar_, cefl, cacé, 
   {{0x38689f82,0x7c2c9f83,0x31c806ab,0x7bdc002f}},	//   klar_, _blar, रलीध, ffsu, 
   {{0x38689f84,0x00000000,0x00000000,0x00000000}},	//   jlar_, --, --, --, 
   {{0xad2417de,0xfe7004d3,0x7c2c022e,0xb0dc9e51}},	//   سىڭى, _ڵده_, _dlar, _महँग, 
   {{0x6440011c,0xdee000a8,0x0dd4004b,0x7d1c002f}},	//   zioi, _роши, _راتګ_, ärsc, 
   {{0x38689f85,0x291c9f86,0x7afc08fb,0xddc8054e}},	//   flar_, âta_, avst, şiţe, 
   {{0x38689f87,0x65789f88,0x7c2c0afa,0x61e80036}},	//   glar_, _úthi, _glar, zefl, 
   {{0x6440049b,0x1ca80135,0x2c5400da,0x194802d3}},	// [c880] vioi, _བསོ_, gāde_, _ዘድልዮ, 
   {{0x7c2c07d6,0xb0dc44ab,0x5f1803d4,0x64a48f0c}},	//   _zlar, _महंग, _তেঁও_, дажа, 
   {{0x38689f89,0x61e80b00,0x64409f8a,0x7c2c9f8b}},	//   blar_, vefl, tioi, _ylar, 
   {{0x38689f8c,0x7c2c01c4,0xd87c0046,0x00000000}},	//   clar_, _xlar, _ﺣﺎﻳﯟ, --, 
   {{0x61e89f8d,0x644002f6,0xdb0c0129,0x9c8000d7}},	//   tefl, rioi, tacé, ôčik, 
   {{0x20ec038e,0x644002f6,0xa18400fd,0x00000000}},	//   _při_, sioi, мыйл, --, 
   {{0x64409f8e,0x1ca80135,0x7f9401c0,0xdb0c0129}},	//   pioi, _བསེ_, найх, racé, 
   {{0x3e7008c2,0x00000000,0x00000000,0x00000000}},	//   dàta_, --, --, --, 
   {{0x7c2c01b9,0xdb0c0129,0xc31c0154,0x7cf80139}},	//   _rlar, pacé, _দেরি_, _xärƅ, 
   {{0x38689f8f,0x20ec0316,0x7c2c9f90,0x81dc015b}},	//   zlar_, _tři_, _slar, _তোর_, 
   {{0x38689f91,0x7e680175,0x7c2c69a1,0xa0680064}},	//   ylar_, rldp, _plar, _дажа_, 
   {{0xd00c1416,0x5a3c001f,0x7c2c6064,0xfb3400ee}},	//   _پله_, _ባለመቻ, _qlar, енмэ, 
   {{0x38689f92,0x3ea003a2,0x68280432,0x4e140214}},	//   vlar_, _ïit_, _aýdo, ستید_, 
   {{0x386826f8,0x7afc1924,0x9ff005d9,0x69d80254}},	//   wlar_, rvst, _سيڪڙ, õtep, 
   {{0x38689f93,0x7c2c9f94,0x9f4400ae,0x52d800bc}},	//   tlar_, _tlar, _naoú_, _मङ्स, 
   {{0x7c2c0517,0xd83801c0,0x386800fd,0x00000000}},	//   _ular, цэг_, ular_, --, 
   {{0x68289f95,0xdcf89f96,0x50180375,0x8c440063}},	// [c890] _týdn, matı, קומו, _шеће, 
   {{0x386856c3,0xdcf81ae6,0x2c54005f,0x2c700122}},	//   slar_, latı, rāde_, máda_, 
   {{0x38689f97,0x2c7003f7,0x439c0521,0x0a5800e3}},	//   plar_, láda_, _ịrụ_, _تشيع_, 
   {{0x38689f98,0xdcf80c07,0x59d8012c,0xb35401ec}},	//   qlar_, natı, म्रर, нкеш, 
   {{0x92e818a5,0x2c7002fb,0x682800bc,0x67340210}},	//   تراق_, náda_, _mýdl, czyj, 
   {{0xef180364,0xdcf81cce,0x33280327,0x00000000}},	//   ҷми_, hatı, ġax_, --, 
   {{0xdcf847af,0xd4989f99,0x2c700022,0x764401f4}},	//   katı, _фрг_, háda_, mihy, 
   {{0x2c701705,0x76449f9a,0x62841f5d,0x5348030d}},	//   káda_, lihy, _èkon, _мăйă, 
   {{0x1ca8081f,0x32541fe2,0xdcf82c78,0x3374004e}},	//   _བསུ_, _звар, datı, _чгар, 
   {{0x764401f4,0x42741608,0x00000000,0x00000000}},	//   nihy, _агус, --, --, 
   {{0xcf2405d9,0xdcf89f96,0x13e0015b,0x81bc00e2}},	//   _ڪراي, fatı, _নোয়, _plēv, 
   {{0x7d1c007c,0x6e94014b,0xdcf89f9b,0x00000000}},	//   ärsa, _зиду, gatı, --, 
   {{0x2c7002fb,0x7644005b,0xcf249f9c,0x657808ce}},	//   gáda_, kihy, _تراي, _úthv, 
   {{0xcdc00022,0xa9c000cf,0x2ca80210,0x00000000}},	//   _ракқ, دۅدۉ, _ładu_, --, 
   {{0xdcf800ac,0x764464f4,0x6a70032e,0x00000000}},	//   batı, dihy, gæfa, --, 
   {{0x2e340248,0xdcf81432,0x682802f0,0x2c7000d7}},	//   _fùfù_, catı, _výdo, báda_, 
   {{0x5ac42401,0x81bc00de,0xe7389f9d,0x00000000}},	// [c8a0] _злым_, _klēt, чеа_, --, 
   {{0xcd40044e,0x6734033f,0xdb34011a,0x80a001f9}},	//   _ብመንፈ, rzyj, _נניח_, _गझले, 
   {{0xf1c8060c,0x9f440165,0x6734012d,0xa96806b4}},	//   _राजन, _daoù_, szyj, _хина_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x66e4025a,0xf3f800a2,0x7c3c004e,0x645801e7}},	//   _dïkö, _daţ_, èrri, _ítim, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdcf8956f,0xf3ec016c,0xe3a892b5,0xd1b40345}},	//   yatı, _кӣ_, _нквд_, راوا_, 
   {{0x81bc0421,0x717000db,0x3dac00eb,0x00000000}},	//   _alēt, جۇما, _খাইল, --, 
   {{0x9f440165,0xbf10008e,0x00000000,0x00000000}},	//   _yaoù_, рүлә, --, --, 
   {{0x752c006a,0x00000000,0x00000000,0x00000000}},	//   _ânzî, --, --, --, 
   {{0x61f8009a,0x2d800118,0x21740139,0x7c34009d}},	//   _iatl, _úhel_, _чуар, венх, 
   {{0x61f89f9e,0x602406af,0x65781427,0x00000000}},	//   _hatl, _démê, _úthu, --, 
   {{0xdcf812ca,0x8f98010f,0xcf90010f,0xbed400d8}},	//   ratı, _זידי, _עטס_, _ролј, 
   {{0x61f827cc,0x2c700308,0xdcf89f9f,0x3e7000a3}},	//   _jatl, ráda_, satı, màto_, 
   {{0xa3c0189a,0x61f89fa0,0xdcf803ee,0x4e140f87}},	//   ूला_, _matl, patı, _ستود_, 
   {{0xb90814cf,0x61f89fa1,0x6e2c03a2,0xdb0c00bc}},	//   _यह_, _latl, _ïabr, lací, 
   {{0x0c749fa2,0x76449fa3,0x3a7410fc,0xf3f80356}},	// [c8b0] _حدود, tihy, _илир, _raţ_, 
   {{0x61f899ef,0x7a640137,0x86c40b24,0x19a80137}},	//   _natl, _جئبە, ايلن, _этип_, 
   {{0x76449fa4,0x73d89fa5,0x00000000,0x00000000}},	//   rihy, ддер_, --, --, 
   {{0x61f80d04,0xdb0c02f0,0x76440108,0x97800066}},	//   _aatl, hací, sihy, _میزه, 
   {{0x61f89fa6,0xdb0c00bc,0x76440108,0x00000000}},	//   _batl, kací, pihy, --, 
   {{0x61f89fa7,0x81bc00ef,0xdb0c0419,0x7ae8031c}},	//   _catl, _noēd, jací, ħeth, 
   {{0xeff4044e,0x61f8016d,0x9f4001a2,0x260c1715}},	//   _ጉዕዞ_, _datl, ľký_, ठारी_, 
   {{0x61f80857,0x2c5400e2,0x9f400216,0x00000000}},	//   _eatl, kāda_, žký_, --, 
   {{0x61f89fa8,0x7d1c01e3,0x00000000,0x00000000}},	//   _fatl, ärsn, --, --, 
   {{0x61f800ee,0xdb0c9fa9,0x00000000,0x00000000}},	//   _gatl, gací, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x61f89faa,0xd6f804ce,0xeb98005b,0x23700210}},	//   _zatl, _cfカ_, ьим_, żyje_, 
   {{0xdad00075,0xdb0c9fab,0x61f89fac,0x00000000}},	//   لەيھ, bací, _yatl, --, 
   {{0x61f856f6,0xdb0c04d4,0x1f34011a,0xa1340432}},	//   _xatl, cací, _ברנר_, _öňür, 
   {{0x1ca80d46,0x4df00046,0x5d1001d9,0x81bc00ef}},	//   _བསག_, _аяқт, _نِوا, _klēr, 
   {{0xdca0013e,0x28742123,0x2c7000e4,0xa6e40154}},	//   _таъи, тыгр, mádo_, নিসট, 
   {{0x18649fad,0x7c3c0023,0xdb2001d3,0x7d1c5f03}},	// [c8c0] тати_, ërre, _نوٹی, ørsv, 
   {{0x95c4337c,0xa9249fae,0xe5a49faf,0x69240117}},	//   клуб_, _адол, тижи, _амоа, 
   {{0x61f80978,0xa7a80b32,0x00000000,0x00000000}},	//   _ratl, _окна_, --, --, 
   {{0x61f8016d,0xa4a40086,0x9d18008f,0xdb0c0216}},	//   _satl, _aròù, וועט, zací, 
   {{0x61f89fb0,0xe8e0032c,0xd24c00aa,0x07a40022}},	//   _patl, _पहुच, ښنه_, _иаҟн, 
   {{0x61f80842,0x2c700306,0x20d800e4,0xc22400f2}},	//   _qatl, kádo_, tëi_, دکرو, 
   {{0xd12c9fb1,0xdb0c0aa4,0x61f80978,0x50b4004b}},	//   يمه_, vací, _vatl, نديد_, 
   {{0x1ee49fb2,0x61f89e15,0x81bc00de,0x00000000}},	//   نوعی_, _watl, _plēs, --, 
   {{0x61f89fb3,0x09b803f4,0x78a80989,0x1ca80003}},	//   _tatl, _জানা, ćevi, _བསང_, 
   {{0x9e049fb4,0xb8e4031c,0x7d1c007c,0xd090035b}},	//   тчил, _ཌྷ_, ärso, ышәы, 
   {{0xc0c49fb5,0xdb0c02fb,0x2c7000e4,0x00000000}},	//   _сәли, rací, gádo_, --, 
   {{0x2474013f,0xdb0c1155,0xe1d00118,0x00000000}},	//   _bɛmɑ_, sací, _साँघ, --, 
   {{0xfd640228,0xdb0c0306,0x00000000,0x00000000}},	//   _өндү, pací, --, --, 
   {{0x2c5400da,0x2c700118,0x5a440006,0xfcc401ee}},	//   rāda_, ládl_, тэма, _йәмм, 
   {{0x6d44219b,0x387800d7,0x00000000,0x00000000}},	//   _žhav, _phsr_, --, --, 
   {{0xdb2001ed,0x7d1c0158,0x8d50008e,0x00000000}},	//   _نوعی, ørsu, _әтәч, --, 
   {{0x8af8004e,0xcc5800df,0xda6415f2,0x00000000}},	// [c8d0] _аныс_, _שבחי_, _لادي, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdfc41d1f,0x00000000,0x00000000,0x00000000}},	//   _ٿي_, --, --, --, 
   {{0xdb0c06ed,0x42b80131,0x588400db,0x09b800eb}},	//   cacã, ھنىڭ_, _шыпа, _জাযা, 
   {{0x42b80075,0xb4b40724,0x216400d1,0x6aa00200}},	//   پنىڭ_, тиҗә, һиши_, _çoft, 
   {{0xaec40fc0,0x6498010e,0x0594010a,0x00000000}},	//   қбол, _iįin, _кăшм, --, 
   {{0x21649fb6,0x09b803f4,0x668007d6,0xafe460a1}},	//   лиши_, _জামা, _ایلل, гойл, 
   {{0xe8d402dd,0x00000000,0x00000000,0x00000000}},	//   _مﻮ_, --, --, --, 
   {{0xca200131,0x2e2808a5,0xb2744839,0x6fa800f1}},	//   ﺸﻼﺭ_, _húfi_, _блаш, ونډې_, 
   {{0xcdcc00aa,0x00000000,0x00000000,0x00000000}},	//   زښت_, --, --, --, 
   {{0xac8405f5,0x77700882,0xd7c00490,0x81dc00fe}},	//   лгол, ṃbhā, षणाच, _তোক_, 
   {{0x2c7000e4,0x00000000,0x00000000,0x00000000}},	//   rádo_, --, --, --, 
   {{0xe454008f,0x81bc00de,0x1c406156,0x2a34009d}},	//   רירט_, _klēp, сням, гэвр, 
   {{0xed589fb7,0x1864036b,0x6828010b,0xa968941f}},	//   _пол_, ҳаси_, _iýdi, еига_, 
   {{0x7d1c1455,0xda6c0014,0x49d802f2,0x00000000}},	//   ørst, سُف_, _یادگ_, --, 
   {{0x18649fb8,0x2b146a7a,0x00000000,0x00000000}},	//   гаси_, _бьор, --, --, 
   {{0xdb0c0120,0x660c005a,0x00000000,0x00000000}},	// [c8e0] racã, _pnbk, --, --, 
   {{0xe8f81357,0x00000000,0x00000000,0x00000000}},	//   _зло_, --, --, --, 
   {{0xe0bc009e,0x682800d0,0x00000000,0x00000000}},	//   _আহ্ন, _lýdi, --, --, 
   {{0x442008d2,0xc5f0004b,0x00000000,0x00000000}},	//   ði_, _ژړا_, --, --, 
   {{0x27f09fb9,0x00000000,0x00000000,0x00000000}},	//   meyn_, --, --, --, 
   {{0x27f047a9,0x26d09fba,0x51f09fbb,0x00000000}},	//   leyn_, muyo_, مسىر, --, 
   {{0x26d09fbc,0xa0889fbd,0x682800a2,0x6448003e}},	//   luyo_, нсиз_, _aýdi, éfis, 
   {{0xba00069f,0x27f09fbe,0xdb0c01e7,0x02c80818}},	//   _ऊफ्फ_, neyn_, hacá, _ақди_, 
   {{0x26d02412,0x21a49fbf,0x27f00363,0xd12c0131}},	//   nuyo_, _бизм, ieyn_, يمۇ_, 
   {{0x27f001d9,0x25b80165,0xa0c401f7,0xbe2401a9}},	//   heyn_, napl_, _ميئو, рчиқ, 
   {{0x26d00bd7,0x51900aaa,0x6828010e,0x27f060b7}},	//   huyo_, _المذ, _eýdi, keyn_, 
   {{0x26d09fc0,0xf0b000dd,0x6aa0031c,0x27f00009}},	//   kuyo_, _بیٹھ, _ħofr, jeyn_, 
   {{0x8ac407d6,0x27f09fc1,0xc0c40131,0xc5cc0154}},	//   йёрл, deyn_, _сәһи, র্যপ, 
   {{0x27f0062c,0x25b80165,0x7d1c0ac8,0x8e340150}},	//   eeyn_, japl_, ørss, _مسىر_, 
   {{0xdb4c168d,0x4fc00075,0x25b805c7,0xdb0c004e}},	//   تێک_, _ئەۋە, dapl_, sacà, 
   {{0x27f047a9,0xfce401ee,0x00000000,0x00000000}},	//   geyn_, _боҫо, --, --, 
   {{0x35b49fc2,0x26d09fc3,0xcb0807c0,0x2ac00166}},	// [c8f0] ибар, guyo_, _ميين_, _мәрв, 
   {{0x3b089fc4,0x00000000,0x00000000,0x00000000}},	//   _iraq_, --, --, --, 
   {{0x27f00067,0xa3c000cd,0xf4d80304,0x00000000}},	//   beyn_, ूलं_, тмеш_, --, 
   {{0x7aec00b4,0x81bc005f,0x26d09fc5,0x656c9fc6}},	//   _kpat, _slēp, buyo_, _dybh, 
   {{0x26d00789,0x7aec0327,0x87e40150,0x81bc00ef}},	//   cuyo_, _jpat, _اتپە, _plēp, 
   {{0xe2949fc7,0x23249fc8,0xc5cc0154,0x00000000}},	//   шаш_, роши_, র্বপ, --, 
   {{0x3b08089c,0x7aec002b,0xc0a800ec,0x49080550}},	//   _lraq_, _lpat, هايل_, हियो_, 
   {{0xaec49fc9,0x7aec9fca,0x01089fcb,0x3e7008c2}},	//   абил, _opat, اتوو_, làth_, 
   {{0xb3a847af,0xe8e000e1,0xd20000db,0xa4400244}},	//   ğıdı, _पह्च, _гүлк, _بێنو, 
   {{0xb3a806b9,0xdb0c0077,0x3e7008c2,0x00000000}},	//   şıdı, xacá, nàth_, --, 
   {{0xed589fcc,0x26d0037e,0x3b08290f,0x27f0058a}},	//   тон_, zuyo_, _araq_, yeyn_, 
   {{0x9f44004e,0x7aec9fcd,0x682803b2,0x27f00067}},	//   _oboè_, _bpat, _týdi, xeyn_, 
   {{0xbfd000c6,0x7aec0354,0x7c3c0240,0x8ea000cf}},	//   _ѕαѕк, _cpat, ërra, _التۇ, 
   {{0x27f00050,0xada41621,0x26d09fce,0x6da401a9}},	//   weyn_, _такл, vuyo_, _тика, 
   {{0x7aec9fcf,0x27f09fd0,0xdb0c0650,0x26d002ce}},	//   _epat, teyn_, racá, wuyo_, 
   {{0x26d09fd1,0x7aec003a,0xdb0c9fd2,0x27f00363}},	//   tuyo_, _fpat, sacá, ueyn_, 
   {{0x78a420e4,0x27f09fd3,0x25b80113,0x00000000}},	// [c900] _ethv, reyn_, tapl_, --, 
   {{0x09e403f4,0x26d09fd4,0x27f09fd5,0x00000000}},	//   _ফোরা, ruyo_, seyn_, --, 
   {{0x26d09fd6,0x20ec00ac,0x1ca8031c,0xe3b8010b}},	//   suyo_, _zəif_, _བསབ_, вбе_, 
   {{0x7aec02d5,0x26d0409c,0x27f001d9,0x25b80165}},	//   _ypat, puyo_, qeyn_, sapl_, 
   {{0x93409fd7,0x58f00003,0x7aec01f5,0xdb1c0158}},	//   онце, _བགོས_, _xpat, øvøl, 
   {{0x20c4006c,0xd04000ac,0x7d1c0267,0xf8a80244}},	//   асиг, munə, ärsk, _جدیه_, 
   {{0x2934010f,0x5a1400df,0x00000000,0x00000000}},	//   יאַן_, יקסן_, --, --, 
   {{0x630400ec,0x00000000,0x00000000,0x00000000}},	//   _پوئل, --, --, --, 
   {{0xe2982e70,0x442400c8,0xf1a804d3,0xd00407fa}},	//   _раз_, _iom_, _ڕانه_, рење_, 
   {{0x44249fd8,0x626404a9,0x614401a9,0x00000000}},	//   _hom_, _ئارق, _кеза, --, 
   {{0x44249fd9,0x7aec9fda,0x5594008f,0xc5cc00eb}},	//   _kom_, _spat, ידיע_, র্থপ, 
   {{0x44249fdb,0x9c4405f5,0x7aec020b,0x1ec80075}},	//   _jom_, рхол, _ppat, _алди_, 
   {{0xa3cc00e1,0x44240375,0xdb589842,0x00000000}},	//   _शयन_, _mom_, тюн_, --, 
   {{0x44249fdc,0x3e343c46,0x00000000,0x00000000}},	//   _lom_, _دفتر, --, --, 
   {{0x44249fdd,0xb7c49fde,0x7aec0210,0x00000000}},	//   _oom_, йрақ, _wpat, --, 
   {{0x7aec9fdf,0x682800a2,0x8c4400d8,0x107c00d1}},	//   _tpat, _oýdu, _меје, ﺯﯨﺪﯨ, 
   {{0x7aec9fe0,0x3b080bc9,0xd5b8023a,0xdb0c0798}},	// [c910] _upat, _uraq_, все_, dacç, 
   {{0x44245280,0x7e6802d0,0x291401e7,0x0614117e}},	//   _aom_, nodp, ócaí_, одую, 
   {{0x44249fe1,0x78a80e3c,0x78a40fac,0xb7d817a5}},	//   _bom_, ćevs, _uthv, _یوگا_, 
   {{0x682803b2,0x1ca80327,0x00000000,0x00000000}},	//   _býdu, _བསན_, --, --, 
   {{0x38689fe2,0x82a40120,0x91b408ca,0x15fc0456}},	//   moar_, ошје, иҳат_, _उसपर_, 
   {{0x4424019f,0xc2441fe2,0x38689fe3,0x6aa000d8}},	//   _eom_, онік, loar_, _éofe, 
   {{0x44249fe4,0xdb0c01b8,0x3868062c,0x40940150}},	//   _fom_, lacä, ooar_, орыт, 
   {{0x38689fe5,0x44249fe6,0x49081a2a,0xd34435cd}},	//   noar_, _gom_, हितो_, _پیته_, 
   {{0x60040aec,0xde3402d3,0x00000000,0x00000000}},	//   сным_, _ስለዝፈ, --, --, 
   {{0x44249fe7,0x3868000f,0x7e680171,0x00000000}},	//   _zom_, hoar_, godp, --, 
   {{0x44240070,0x38680a85,0x2c7000dd,0x9f44030a}},	//   _yom_, koar_, ládi_, _daoñ_, 
   {{0x44249fe8,0x38689fe9,0x6f94007b,0xd04000ec}},	//   _xom_, joar_, _الإض, _گھڻي, 
   {{0x38689fea,0xe9dc00a2,0x00000000,0x00000000}},	//   doar_, liºi_, --, --, 
   {{0xa2d81cc3,0x09b809bd,0xff501b2c,0x00000000}},	//   _नमस्, _জাহা, _تخم_, --, 
   {{0x38689feb,0x108802dd,0xeab003c7,0x00000000}},	//   foar_, _ﺗﯟﺩﯨ, _کعب_, --, 
   {{0x5eec0882,0x1cb40375,0x38689fec,0x4ab40166}},	//   _अहम्_, _פלפל_, goar_, _мөгр, 
   {{0x6f1c9fed,0xaa440209,0x2bac6847,0x00000000}},	// [c920] äsch, _гепл, _झ्या, --, 
   {{0xe2980aa5,0xdb2010e5,0x66e401e0,0x00000000}},	//   ҳад_, _روپی, _һома, --, 
   {{0x44240b89,0xdce856c0,0x38689fee,0x2a680fac}},	//   _pom_, čiće, boar_, mobb_, 
   {{0x66e45e3e,0x746800d6,0x68fc009a,0x44249fef}},	//   _лома, арів_, _ispd, _qom_, 
   {{0x44249ff0,0x68fc0649,0xdb0c0798,0x7e68014f}},	//   _vom_, _hspd, racç, yodp, 
   {{0x4424013b,0x69dc051f,0x6ab40042,0x92a801d3}},	//   _wom_, _jcpe, _mwyf, ائنہ_, 
   {{0x44249ff1,0x6b94003a,0x6ab403cb,0x6a7002d2}},	//   _tom_, _ogyg, _lwyf, gæfi, 
   {{0x50b400c6,0x2a680327,0xc644009f,0x00000000}},	//   حدود_, hobb_, _اَڀي, --, 
   {{0x63a09ff2,0x41e07a48,0x24849ff3,0x6ab40042}},	//   mcon, _नापस, mmom_, _nwyf, 
   {{0x2a686afa,0x63a09ff4,0xa3c047c6,0x38682560}},	//   jobb_, lcon, ूलक_, zoar_, 
   {{0x7c3c02d3,0x63a00051,0x248400d7,0x00000000}},	//   ërro, ocon, omom_, --, 
   {{0x69dc0055,0x7e6801ed,0x613001a8,0x55740115}},	//   _acpe, sodp, aðlö, מעין_, 
   {{0x1ca86d7e,0x7e680232,0xdf740372,0x68fc9ff5}},	//   _བསམ_, podp, _اداب, _aspd, 
   {{0x63a00334,0x6ab403cb,0x7e68014f,0x00000000}},	//   hcon, _dwyf, qodp, --, 
   {{0x63a09ff6,0xd90c54db,0xd87403e6,0x00000000}},	//   kcon, ریح_, مارب, --, 
   {{0x24845edb,0x6ab4015d,0x8c5400db,0x310800dc}},	//   jmom_, _fwyf, _ىئيا, वितः_, 
   {{0x38680295,0x63a09ff7,0xdb1c02f6,0x6fe4015b}},	// [c930] roar_, dcon, äväl, _খোঁজ_, 
   {{0x38680b21,0x00000000,0x00000000,0x00000000}},	//   soar_, --, --, --, 
   {{0x38689ff8,0x0b581079,0x6d5c0790,0xf7940024}},	//   poar_, _نشیب_, şsav, _манэ, 
   {{0x63a09ff9,0x33743ce7,0x248401fa,0x35dc012d}},	//   gcon, огер, gmom_, न्ज़, 
   {{0x395c0125,0x494c0023,0x00000000,0x00000000}},	//   ተዋጽኦ_, _ነስተብ, --, --, 
   {{0x63a09ffa,0x248401f1,0x2c7059f3,0x2d980118}},	//   acon, amom_, rádi_, ěsek_, 
   {{0x2bbc2d93,0xf3f40244,0x310800cd,0x00000000}},	//   ्णमा, _وترک, विधः_, --, 
   {{0x63a09773,0x54340014,0x89d8013f,0x00000000}},	//   ccon, _ارسر, forכ_, --, 
   {{0xee380da6,0x32540006,0x260c01f9,0x00000000}},	//   ини_, _двар, ठाची_, --, 
   {{0xa6e0008c,0x7d084a1f,0x9268026a,0x82340372}},	//   æðin, fvds, _срба_, _ىرلا, 
   {{0x09b80154,0x2c541a14,0xbff803d4,0xbbc40073}},	//   _জালা, lādi_, _আচৰণ_, वणूक, 
   {{0x6e94014b,0x00000000,0x00000000,0x00000000}},	//   _диду, --, --, --, 
   {{0x41e003ba,0x2c540a30,0xa9a401c6,0x996000d0}},	//   _नामस, nādi_, жигд, _ríši_, 
   {{0x63a00077,0x6f089ffb,0x00000000,0x00000000}},	//   zcon, mvec, --, --, 
   {{0x63a09ffc,0xec781468,0x9960013a,0x3da8009f}},	//   ycon, _кпк_, _píši_, _اُٺَ_, 
   {{0x63a09ffd,0x6ab40660,0xe7a88cca,0xa7a89ffe}},	//   xcon, _twyf, рвал_, ркаа_, 
   {{0x6d404cf1,0x63a09fff,0x2c54005f,0xe6480006}},	// [c940] lzla, vcon, jādi_, апад_, 
   {{0x63a0a000,0x6f0801e4,0x00000000,0x00000000}},	//   wcon, ivec, --, --, 
   {{0x6d400399,0x63a0a001,0x6f0803e0,0xdb2000e4}},	//   nzla, tcon, hvec, ïrög, 
   {{0x6d402630,0x63a0067c,0x6f080115,0x3e70002e}},	//   izla, ucon, kvec, làtt_, 
   {{0x6f082ce2,0x2c54005f,0x6264a002,0x41280137}},	//   jvec, gādi_, овда, өндү_, 
   {{0x24841225,0x63a0a003,0xa0a4a004,0x2c700306}},	//   smom_, scon, ошил, mádu_, 
   {{0x63a0a005,0x2c7002fb,0x26d00083,0x24840112}},	//   pcon, ládu_, lryo_, pmom_, 
   {{0x6d4005b1,0x23289255,0x26d0058a,0x643400d1}},	//   dzla, _коби_, oryo_, _بىرئ, 
   {{0x1ea80bbd,0x31681ae4,0x7c3c0240,0x2ca800d0}},	//   جابي_, ğaza_, ërrm, _čada_, 
   {{0x2000151c,0x6d40022e,0xdd980408,0x00000000}},	//   žki_, fzla, шши_, --, 
   {{0x26d0003e,0x6f08054e,0x61e8015d,0x7c3c02d0}},	//   hryo_, avec, mffl, thsr, 
   {{0x6f080393,0x2c7002f0,0x00000000,0x00000000}},	//   bvec, kádu_, --, --, 
   {{0xd00c75e4,0xf8b8a006,0xf08801d5,0x2ff800f2}},	//   _جلن_, өөн_, _ائله_, _دونگ_, 
   {{0xdd9067d1,0xe1ec0220,0x26d000b5,0x61e80142}},	//   _قوش_, егi_, dryo_, nffl, 
   {{0x7c340117,0x00000000,0x00000000,0x00000000}},	//   _некх, --, --, --, 
   {{0x7c588eef,0x7a3801e1,0xdc288198,0x2c540882}},	//   _دلبر_, _dìta, _خسته_, yādi_, 
   {{0x7d1c11ad,0x2c7002fb,0xd7642309,0x00000000}},	// [c950] årsf, gádu_, زەسى_, --, 
   {{0x7afc0042,0x7bdc32ba,0x00000000,0x00000000}},	//   mwst, lgsu, --, --, 
   {{0x6f080433,0x68280122,0x7afc0142,0x09e40011}},	//   zvec, _výdr, lwst, _ফোকা, 
   {{0x7bdca007,0x2c54005f,0x4908772c,0x26d0253c}},	//   ngsu, tādi_, हिरो_, bryo_, 
   {{0x02a40116,0xe61400cf,0x00000000,0x00000000}},	//   үрәм, تكەگ, --, --, 
   {{0x2c540318,0xddd800bc,0x7afc0036,0x96080006}},	//   rādi_, potř, iwst, _тэма_, 
   {{0x2c541c52,0x90e000c7,0x00000000,0x00000000}},	//   sādi_, ьӡаҧ, --, --, 
   {{0x6f08049f,0x895c00d9,0x6d40035a,0x73c401af}},	//   tvec, ידות, vzla, _хәже, 
   {{0x6d400369,0x733802ac,0x00000000,0x00000000}},	//   wzla, _узар_, --, --, 
   {{0xee380e91,0x6d40a008,0x31d40150,0xb62c037e}},	//   сно_, tzla, _ءقاز, _ｒｃ_, 
   {{0xeb98a009,0x320405da,0x8f94010a,0x00000000}},	//   йин_, _ialy_, _мěнл, --, 
   {{0x3204a00a,0x6d40a00b,0x6a7000b5,0x7bdc143a}},	//   _haly_, rzla, hæft, ggsu, 
   {{0x3204a00c,0x6d401f6f,0x2078010f,0x6a7001bf}},	//   _kaly_, szla, _פאנא, kæft, 
   {{0x320405da,0x49080073,0x08c800fb,0x00000000}},	//   _jaly_, हिलो_, оғоп_, --, 
   {{0x3204a00d,0x4c84016c,0x7d1c42a7,0x00000000}},	//   _maly_, _оғоз, ärst, --, 
   {{0x26d01446,0x32040129,0x109002dd,0xfca80345}},	//   tryo_, _laly_, _ﺟﺎﺯﯨ, _باوو_, 
   {{0xee700020,0x26d00009,0x95380092,0xe9d8117e}},	// [c960] _ስብሰባ_, uryo_, _በሚከተ, _лкп_, 
   {{0xd6cc314e,0x3204a00e,0x2c7002f0,0x7f7800d1}},	//   اقل_, _naly_, rádu_, ﻧﯩﯟﯦ, 
   {{0xb3a871e1,0x32fc010e,0x99980375,0x2c700306}},	//   ğını, _aňy_, _לביט, sádu_, 
   {{0xb3a871e1,0x2c7002f0,0x00000000,0x00000000}},	//   şını, pádu_, --, --, 
   {{0x3204a00f,0xeb5c2440,0xd4644b1f,0x00000000}},	//   _baly_, _ወንጀለ, чице_, --, 
   {{0xa6e00321,0x3204012d,0x59ac0037,0x56900006}},	//   æðun, _caly_, जुपर, _паўт, 
   {{0x23d40276,0x3204045a,0x61e8a010,0x00000000}},	//   _нцар, _daly_, rffl, --, 
   {{0x3f14a011,0xdb0c00d0,0xe2988602,0x1558011a}},	//   ддис, racú, _гаа_, _הכלב, 
   {{0x32040851,0x8e380023,0x2c5400e2,0xbef808df}},	//   _faly_, _ስለዝጸ, nādu_, ्टेन_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe0d0a012,0x61383500,0x628801c7,0x723401e2}},	//   _سزا_, _учар_, mmfo, _زړور_, 
   {{0x2c54005f,0x4f8401d9,0x32040432,0xc5f800eb}},	//   kādu_, _کامہ, _zaly_, ঘাটা_, 
   {{0x7afc0cf9,0x32040209,0x7bdc8860,0xab0401ec}},	//   uwst, _yaly_, rgsu, мірқ, 
   {{0x7afc01c7,0x7d1c01e3,0x00000000,0x00000000}},	//   rwst, ärss, --, --, 
   {{0x7d1c713c,0x00000000,0x00000000,0x00000000}},	//   årsd, --, --, --, 
   {{0x940875be,0x76b8344a,0x00000000,0x00000000}},	//   _सोंच_, жлар_, --, --, 
   {{0x20040069,0x7bcca013,0xfe780153,0x00000000}},	// [c970] _maoi_, _idau, olį_, --, 
   {{0x200400ae,0x00000000,0x00000000,0x00000000}},	//   _laoi_, --, --, --, 
   {{0x6a70005c,0x38c80133,0x14c800c7,0xfe780064}},	//   ræft, _باخی_, сызи_, ilį_, 
   {{0x62880151,0x200437a8,0x572000db,0xb3540166}},	//   emfo, _naoi_, _كۉزك, мкеш, 
   {{0x32040109,0xfe780006,0x15a800a7,0xc2c4007b}},	//   _paly_, klį_, _гъби_, فيني, 
   {{0xd4981363,0x947400f1,0xc8c80244,0x00000000}},	//   _гра_, _ځدرا, _بوێن_, --, 
   {{0x0cd4045e,0x94743c46,0x20040332,0x5184a014}},	//   _তন্ত, _فدرا, _baoi_, чуда, 
   {{0x7bcc0226,0x3204a015,0x6288017a,0x200400ae}},	//   _ndau, _waly_, amfo, _caoi_, 
   {{0xef180212,0x00000000,0x00000000,0x00000000}},	//   імо_, --, --, --, 
   {{0x7bcca016,0xd24400db,0xfe7800c0,0x82380024}},	//   _adau, _ээби, glį_, _езус_, 
   {{0x200406d5,0xd9e011ba,0x28280882,0x41c401d9}},	//   _faoi_, য়াম, ṇaiḥ_, _سٲنِ, 
   {{0x20041140,0x00000000,0x00000000,0x00000000}},	//   _gaoi_, --, --, --, 
   {{0xf1d000e1,0x1c406c20,0x8d74190f,0x7bcc0142}},	//   _सयान, тням, _کاشا, _ddau, 
   {{0x7bcc0333,0x00000000,0x00000000,0x00000000}},	//   _edau, --, --, --, 
   {{0x20040354,0x6f0ca017,0xe7c40150,0x00000000}},	//   _yaoi_, _šach, _ﺩﻩﺭﻟ, --, 
   {{0x7d1c0158,0x38740114,0x00000000,0x00000000}},	//   årse, ећут, --, --, 
   {{0xb3a89d58,0xdebc02d3,0x59ac18cc,0x69d800db}},	// [c980] ğılı, _ሰብን_, _ज्वर, òtes, 
   {{0xb3a80aba,0xd6f800b5,0x2c54005f,0x1660013e}},	//   şılı, _kgオ_, rādu_, ввум, 
   {{0xa2d800cc,0x00000000,0x00000000,0x00000000}},	//   _ধনেখ, --, --, --, 
   {{0x25f8a018,0x425405af,0x69a801f9,0x00000000}},	//   _उसकी_, کنتر, जुरी, --, 
   {{0x7c3c02d3,0x76900139,0x00000000,0x00000000}},	//   ërri, fıyğ, --, --, 
   {{0x2004a019,0x6288a01a,0x386ca01b,0x51f0515c}},	//   _saoi_, umfo, čere_, نسىر, 
   {{0x2c0c006d,0x200400b0,0x01e40137,0x63b403b2}},	//   ियां_, _paoi_, _үйбү, ðyns, 
   {{0x717000db,0x00000000,0x00000000,0x00000000}},	//   دۇما, --, --, --, 
   {{0x64400597,0x7bcc067c,0x6d540077,0x00000000}},	//   mhoi, _rdau, úzan, --, 
   {{0x9e6406f6,0x528000c7,0x6440a01c,0x2c5400e2}},	//   بابن, _агуб, lhoi, kāds_, 
   {{0x923000db,0x20040332,0xb03401e2,0x00000000}},	//   _جىلش, _taoi_, _ګونګ, --, 
   {{0x6440a01d,0x09b80154,0x00000000,0x00000000}},	//   nhoi, _জাগা, --, --, 
   {{0x8ae40046,0x644069f7,0xd9e004c5,0xbf100116}},	//   кірл, ihoi, য়সম, _сүпә, 
   {{0x6440a01e,0xdb1c036e,0xd5f001ec,0x69a80118}},	//   hhoi, _heqë, йiнг, जुली, 
   {{0xa3dc0490,0x6440a01f,0xdb1c0240,0x4dd8011a}},	//   ढला_, khoi, _keqë, _וחוו, 
   {{0x7bcc7d39,0x7a3801e1,0x00000000,0x00000000}},	//   _udau, _tìto, --, --, 
   {{0xfca80014,0x7c2c005a,0x644003d5,0xdb1c036e}},	// [c990] _باڈو_, _ioar, dhoi, _meqë, 
   {{0x7c2ca020,0xb3a807c4,0x45d40305,0x00000000}},	//   _hoar, ğımı, коус, --, 
   {{0x38c8006c,0x7c2c0225,0xb3a82c6f,0x2be41a2a}},	//   _عادی_, _koar, şımı, _कामं_, 
   {{0x7c2c1368,0x64400363,0x00000000,0x00000000}},	//   _joar, ghoi, --, --, 
   {{0xdd84021a,0x7c2ca021,0xc6a4a022,0x8704013d}},	//   _څو_, _moar, _арси, _ияре, 
   {{0xdd840dc3,0xe3d40228,0x7c2ca023,0xf0e80131}},	//   _مو_, _үйрө, _loar, كىتى_, 
   {{0x248404ba,0x63a80118,0x644012ef,0x908400e5}},	//   ŋoma_, émní, bhoi, ومتے_, 
   {{0x7c2c0225,0x6440a024,0x3494a025,0x2ca80327}},	//   _noar, choi, _чабр, _ċad_, 
   {{0x291c413b,0xd3440424,0x7338074d,0x00000000}},	//   ̣ta_, _تیشه_, _эзар_, --, 
   {{0x7c2ca026,0x6d240c17,0x9f80010b,0x00000000}},	//   _aoar, едоз, ыгыд, --, 
   {{0x7c2ca027,0xc10421ec,0xb29401fb,0x7d1c01e3}},	//   _boar, _لولي, _đềmớ, ärsp, 
   {{0x8fc40efc,0x644806af,0x4e0c012c,0x7c2c26de}},	//   _آزان, éfix, _थोरै_, _coar, 
   {{0x7c2ca028,0xef180798,0x00000000,0x00000000}},	//   _doar, _хмл_, --, --, 
   {{0x7d1c0158,0x64400165,0xdee0725b,0x00000000}},	//   årsc, zhoi, _соши, --, 
   {{0x7c2ca029,0xdebc02d3,0x6f7c00d1,0x291c00e4}},	//   _foar, _ሰብና_, ﻧﯩﻐﺎ_, ãta_, 
   {{0x7b04a02a,0x7c2ca02b,0xd7d8037e,0x644001e2}},	//   ättä, _goar, _phメ_, xhoi, 
   {{0x7c3c145e,0x00000000,0x00000000,0x00000000}},	// [c9a0] êrre, --, --, --, 
   {{0xe9d8a02c,0x7c2ca02d,0x23483769,0x00000000}},	//   _эко_, _zoar, ۋلاپ_, --, 
   {{0x6440a02e,0x61fc03be,0x290c020c,0x7c2ca02f}},	//   thoi, _özlə, _éfa_, _yoar, 
   {{0x64400108,0x00000000,0x00000000,0x00000000}},	//   uhoi, --, --, --, 
   {{0xc6a80014,0x9204005f,0x64401978,0xa5080131}},	//   _آگرٕ_, zgāš, rhoi, غىچە_, 
   {{0x6440a030,0x6734023a,0x93400262,0x80a40401}},	//   shoi, myyj, ынче, _चंदे, 
   {{0x96601734,0x6440a031,0x00000000,0x00000000}},	//   _скре, phoi, --, --, 
   {{0x93400166,0xdef40092,0x00000000,0x00000000}},	//   _өнсе, _ፈለክ_, --, --, 
   {{0x7c2ca032,0xcee4026a,0x93f8011a,0xf484014b}},	//   _roar, едње_, _צלמי, _руён, 
   {{0x7c2ca033,0xf1a803e6,0x3d94011c,0x00000000}},	//   _soar, _قامه_, кипр, --, 
   {{0x7c2ca034,0x6298a035,0x00000000,0x00000000}},	//   _poar, _iito, --, --, 
   {{0x6298a036,0x00000000,0x00000000,0x00000000}},	//   _hito, --, --, --, 
   {{0x7c2c0851,0xfe44004e,0xc0e80023,0x00000000}},	//   _voar, _имдү, ሚዶም_, --, 
   {{0x6298a037,0x7c2ca038,0x2aa400d7,0xfd74256e}},	//   _jito, _woar, _dôb_, _иллэ, 
   {{0x6298a039,0x7c2ca03a,0x6e3401d3,0x1278010f}},	//   _mito, _toar, özbe, פאלע, 
   {{0xb78824ce,0x6298a03b,0x07e4084c,0x20ec06be}},	//   дәге_, _lito, лцум, _nəim_, 
   {{0x1ccc0156,0x7c3c0023,0x2ac03ad0,0xf8b0a03c}},	// [c9b0] ུངམ_, ërru, _вәсв, _چکر_, 
   {{0x6298a03d,0xdfc405d9,0x9564010b,0x88a40133}},	//   _nito, _ھي_, нъед, _ڕیفۆ, 
   {{0xdfc416ef,0x93248d3c,0x00000000,0x00000000}},	//   _پي_, کران, --, --, 
   {{0x13a40502,0x6298a03e,0x2c18033f,0x00000000}},	//   رنتی_, _aito, धाएं_, --, 
   {{0x6298a03f,0x43741e87,0x00000000,0x00000000}},	//   _bito, лушт, --, --, 
   {{0x68ec025a,0x00000000,0x00000000,0x00000000}},	//   _ândû, --, --, --, 
   {{0x62989988,0x2164a040,0x15b801ec,0x026402f2}},	//   _dito, киши_, _мыңы_, دێلێ, 
   {{0x62980158,0xef18a041,0x00000000,0x00000000}},	//   _eito, дми_, --, --, 
   {{0x6298a042,0x600445b3,0x80241473,0x3374118f}},	//   _fito, тным_, ارىم, _ргар, 
   {{0x6298a043,0x912800cf,0x02d800ec,0x00000000}},	//   _gito, _ىساق_, _سگهڙ_, --, 
   {{0xc30800fe,0xd1380354,0x8ca0215c,0x00000000}},	//   লমণি_, _эха_, دەبو, --, 
   {{0x6298a044,0x7d1c1f53,0x00000000,0x00000000}},	//   _zito, årsa, --, --, 
   {{0x6298a045,0x3ea401ec,0x3af4a046,0x00000000}},	//   _yito, _биіг, лярс, --, 
   {{0x6298a047,0x00000000,0x00000000,0x00000000}},	//   _xito, --, --, --, 
   {{0xfe7000e3,0x00000000,0x00000000,0x00000000}},	//   _ادن_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2eec4606,0x6a840395,0x00000000,0x00000000}},	// [c9c0] ntef_, _илиа, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x62983073,0xc838001f,0x39340166,0x3d140243}},	//   _rito, _የፈረን, _бэяс, धिये_, 
   {{0xe87003e6,0xe738113e,0xf4840150,0x00000000}},	//   _ئۆرگ, _жем_, гуін, --, 
   {{0x648800e4,0x8c2400cc,0x00000000,0x00000000}},	//   hýig, _পতান_, --, --, 
   {{0x5330a048,0x6298a049,0x27f04f82,0xe568009d}},	//   решт, _qito, lfyn_, _жигд_, 
   {{0x6298a04a,0x2574034c,0xa0883df5,0x2eec0e14}},	//   _vito, _شهرس, мсиз_, etef_, 
   {{0x6298a04b,0x27f00142,0x00000000,0x00000000}},	//   _wito, nfyn_, --, --, 
   {{0x6298a04c,0xa2040075,0xd18050e5,0xc2b40166}},	//   _tito, _ипад, лләй, _сөеш, 
   {{0x6298a04d,0x9f480241,0x00000000,0x00000000}},	//   _uito, _àmín_, --, --, 
   {{0x27f0017a,0x7c3400c0,0x00000000,0x00000000}},	//   kfyn_, генх, --, --, 
   {{0xa3e8069f,0xdb0c068c,0xe81007f7,0xffc441e5}},	//   _माफ_, dacò, _ढोला_, _сөкп, 
   {{0xa3e81889,0x27f000b5,0x11f40150,0x4fd4025d}},	//   _मान_, dfyn_, _ستەگ, _יואב_, 
   {{0x4f8401d9,0x3a740798,0x00000000,0x00000000}},	//   _شانہ, улгр, --, --, 
   {{0x8d70a04e,0x27f000a9,0x3c58084c,0x47cc00fe}},	//   _پاوا, ffyn_, _пикэ_, িলনী, 
   {{0x99e002a6,0x27f0017a,0x5884a04f,0xb6c801d3}},	//   য়েক, gfyn_, тыга, فائے_, 
   {{0xc6a405c5,0x473487c7,0x6f0c0005,0xc7c400d4}},	// [c9d0] архи, антс, _áact, рсси, 
   {{0x3b08a050,0x7c3ca051,0x98c4036b,0x7aeca052}},	//   _isaq_, lksr, _исмл, _iqat, 
   {{0x73d8a053,0x97800214,0xa3dc0073,0xb4d402e8}},	//   едер_, _چیزه, ढलं_, ужещ, 
   {{0xccf004ac,0x36d40bd6,0xd344a054,0x8d580375}},	//   יכע_, _йомр, نیزه_, וכבי, 
   {{0xc30400f7,0x7aec025c,0xe720010e,0x07080139}},	//   لبوو, _jqat, _köýý, _ихри_, 
   {{0x7aeca055,0x00000000,0x00000000,0x00000000}},	//   _mqat, --, --, --, 
   {{0x6828a056,0x78a4a057,0x41e402bf,0x307400f3}},	//   _aýdy, _juhv, річа, луис, 
   {{0xa3e80b03,0x7aeca058,0x7c3c0d27,0x2eec022f}},	//   _माय_, _oqat, jksr, ttef_, 
   {{0x7aec025c,0x6da417a0,0x43940b00,0x2eec0165}},	//   _nqat, липа, _ватс, utef_, 
   {{0x7c3c0d27,0x2eeca059,0xde94002b,0x648800e4}},	//   eksr, rtef_, _prāṅ_, týig, 
   {{0x5e303306,0x7aec1454,0x78a40455,0xa3e800cd}},	//   صَّا, _aqat, _nuhv, _माम_, 
   {{0x99e000fe,0x09dc07b6,0x64880022,0x00000000}},	//   য়োক, बल्य, rýig, --, 
   {{0xcf242e67,0xdba00150,0x648800e4,0xa8d800f1}},	//   _جراي, _ﺍﯞﻻﯞ, sýig, کوزئ_, 
   {{0x78a40369,0xd1b8044e,0x00000000,0x00000000}},	//   _buhv, _ደንበ_, --, --, 
   {{0x7aeca05a,0xa2c8a05b,0x27f0005c,0x8cc4010a}},	//   _eqat, _सौन्, tfyn_, _шĕвĕ_, 
   {{0x7c3ca05c,0x78a4047e,0x2c180034,0xebe401b9}},	//   cksr, _duhv, धाओं_, _соип, 
   {{0x27f0a05d,0xdb0c068c,0x18640116,0x068401a9}},	// [c9e0] rfyn_, sacò, уати_, иҳмн, 
   {{0xa3b40073,0xdb98011a,0x2bbc2bf1,0xe5c400f7}},	//   चुन_, _אספר, ्णका, اقاپ, 
   {{0xd1b80092,0x00000000,0x00000000,0x00000000}},	//   _ደንቡ_, --, --, --, 
   {{0x59040107,0x00000000,0x00000000,0x00000000}},	//   _сеюм_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x26c00332,0xa184008e,0x00000000,0x00000000}},	//   _iwko_, лыйл, --, --, 
   {{0x747c0131,0x2934010f,0x71740092,0x00000000}},	//   ﺭﯨﭙﯩ, טאַן_, _ሽንፈት_, --, 
   {{0x660c01d9,0x403400c7,0xc0340f14,0x2a7800c0}},	//   _habk, реис, рниј, _lkpb_, 
   {{0xdef80228,0x660c925d,0xdbc400a2,0x00000000}},	//   хый_, _kabk, göýi, --, 
   {{0x9e04a05e,0x660c0014,0x682800d7,0x4cd800cc}},	//   учил, _jabk, _výdy, _বনজু, 
   {{0x3b080194,0x7aec0113,0xc0c40d52,0x1674011a}},	//   _ssaq_, _sqat, _тәли, רגיל_, 
   {{0x660ca05f,0x7aec013c,0x3c58084c,0xe720010b}},	//   _labk, _pqat, тимэ_, _söýý, 
   {{0x7c3c7421,0x78a401fa,0xa2c817c6,0x8eb057fb}},	//   rksr, _suhv, _सौम्, _همنش, 
   {{0x85040316,0x78a4696f,0x3d94010a,0x00000000}},	//   रबाट_, _puhv, _килр, --, 
   {{0xd1b80020,0xb7c40124,0x00000000,0x00000000}},	//   _ደንብ_, ирақ, --, --, 
   {{0x36d409fe,0x7aec025c,0x00000000,0x00000000}},	//   иобр, _tqat, --, --, 
   {{0x660ca060,0x7aeca061,0x3b08a062,0xf9d40276}},	// [c9f0] _babk, _uqat, _usaq_, _копэ, 
   {{0x660c058a,0xc90400fe,0x05740133,0x00000000}},	//   _cabk, _উপৰত_, ڕاند, --, 
   {{0x660c01d9,0xc6680261,0x49740276,0x44200150}},	//   _dabk, уште_, _глэс, бi_, 
   {{0xc4289cb8,0x00000000,0x00000000,0x00000000}},	//   люче_, --, --, --, 
   {{0x660c0211,0xbb240150,0x977c0408,0x00000000}},	//   _fabk, _ﹼﻠﻪ_, _хунă_, --, 
   {{0xc8a400af,0xa3e800af,0xf4b401b9,0x2fc80010}},	//   _खूँट, _माथ_, _نشرگ, _žag_, 
   {{0x2be400dc,0xfbb40b4c,0x7d1c0250,0x00000000}},	//   _कालं_, ंडाम, årsl, --, 
   {{0xc0a8314e,0x660ca063,0xddd80306,0x00000000}},	//   داول_, _zabk, litň, --, 
   {{0x534431d5,0x7d180267,0xa3e8a064,0x3cfc00d7}},	//   _схва, _arvs, _मात_, _apvv_, 
   {{0xee3867b5,0x660c0009,0x00000000,0x00000000}},	//   тно_, _xabk, --, --, 
   {{0x8234a065,0xc8a400e1,0xa8042737,0x648800e4}},	//   _ارقا, _खूंट, lkış, sýie, 
   {{0xe184008e,0x2ef40108,0x00000000,0x00000000}},	//   _төче_, _вздр, --, --, 
   {{0x6a84a066,0x7d1802d0,0xd9b403d4,0x81e800eb}},	//   илма, _ervs, _জয়ম, _বসত_, 
   {{0x7f840486,0xa96801b9,0x6f180142,0x0dc82b39}},	//   _الهن, вига_, _irwc, _чуди_, 
   {{0x660c0210,0xbb3c0150,0x00000000,0x00000000}},	//   _rabk, _ﻓﻀﻼ_, --, --, 
   {{0x660c011f,0xeb98004e,0x2c7000d7,0x00000000}},	//   _sabk, _иий_, hádz_, --, 
   {{0x66e427f0,0xab280276,0xe69407d6,0x78a800df}},	// [ca00] роза, _ропа_, للرد, ĉeva, 
   {{0x7d1c95aa,0x660c0067,0x2bb409fa,0x00000000}},	//   ærsg, _qabk, ूरवा, --, 
   {{0xd6f800b5,0x4ca40eac,0x18a0013d,0x18b018c7}},	//   _cgア_, _কৌতু, _маэм, _мәтр, 
   {{0x29180113,0x660c058a,0x4420a067,0xbb2401ec}},	//   _irpa_, _wabk, ñi_, _ﹼﺠﻪ_, 
   {{0x660c0b45,0x2918a068,0xe5a431dc,0x73c001e0}},	//   _tabk, _hrpa_, _виги, яҡта, 
   {{0xd24ca069,0x09d800bd,0xc1040131,0x6d5c15b7}},	//   ونن_, দ্রা, йүзл, şsay, 
   {{0xa3e80801,0x40340220,0xb9ec0023,0xe7a80b02}},	//   _идва_, йекс, _ንዓ_, _कलाप, 
   {{0x7d1c713c,0x00000000,0x00000000,0x00000000}},	//   årsm, --, --, --, 
   {{0xb3a86648,0x104400a7,0x00000000,0x00000000}},	//   ğıtı, рящи_, --, --, 
   {{0x68fc1a84,0x69d85e45,0x2c700122,0x2918a06a}},	//   _oppd, ótel, mády_, _orpa_, 
   {{0x2c7002fb,0xa2c808ec,0x291c007c,0x00000000}},	//   lády_, _सौत्, åtal_, --, 
   {{0x7a380048,0x81e800eb,0x00000000,0x00000000}},	//   _lìtt, _বসি_, --, --, 
   {{0x2918a06b,0x68fca06c,0x2c7002fb,0x00000000}},	//   _arpa_, _appd, nády_, --, 
   {{0x29180263,0x0a68a06d,0xf8b80137,0x00000000}},	//   _brpa_, арси_, лөм_, --, 
   {{0x26dc0607,0x7d1c03cd,0x81e80154,0x00000000}},	//   _ātoa_, ærsd, _বসা_, --, 
   {{0x2c700306,0x00000000,0x00000000,0x00000000}},	//   kády_, --, --, --, 
   {{0xcf9000c8,0x7b180276,0x291803b2,0x89a80050}},	// [ca10] ַטע_, _сопр_, _erpa_, _چھِہ_, 
   {{0xaae401d3,0xccd000c7,0x85b803c5,0x68140210}},	//   _اسٹو, _уцәы, илус_, _pędó, 
   {{0x04c805e6,0xda640150,0xd4040131,0xe81000bc}},	//   لولي_, _ماگي, ияди, _ढोका_, 
   {{0xa914008f,0x3dcc015d,0x7d1c01f4,0x00000000}},	//   _פֿיס_, hadw_, ärsy, --, 
   {{0x8728006c,0x2c700122,0x7d1c713c,0x00000000}},	//   _кўра_, gády_, årsj, --, 
   {{0x7a380268,0xb2b40116,0xf6440451,0x2324041b}},	//   _tìtu, иңғу_, _انسٽ, соши_, 
   {{0xd498a06e,0x69b8a06f,0x45d4014b,0xe7ec1bd6}},	//   _ара_, ्रती, _фосс, ङ्का_, 
   {{0xdfcc1183,0xaec401a9,0x4e0c012d,0x00000000}},	//   ىيى_, ббил, _थोड़े_, --, 
   {{0x8fd001e0,0x64880022,0xb3a815b7,0x00000000}},	//   бәҙә, sýic, şısı, --, 
   {{0x52740075,0x3dcc0142,0x648800c7,0xa14000ef}},	//   _ئارز, gadw_, pýic, _šķeb, 
   {{0x6ab462f1,0xada400d1,0xfe542a77,0x6da40166}},	//   _styf, _һалл, تیوب_, _һила, 
   {{0x6f1803cb,0x00000000,0x00000000,0x00000000}},	//   _trwc, --, --, --, 
   {{0x2fcc715a,0xa3e80456,0xada400ee,0x6da400a7}},	//   maeg_, _मास_, _лалл, _лила, 
   {{0x3dcc02fa,0x29180e3c,0x2fcc0399,0x60280022}},	//   cadw_, _prpa_, laeg_, _ахәҳ_, 
   {{0xd940a070,0x6f0804c4,0x2fcc0254,0x3a28008e}},	//   пери, lwec, oaeg_, шерү_, 
   {{0x2fcc0dd4,0x7f8400db,0x20ec06be,0x7d1c12e8}},	//   naeg_, _الۇن, _iəit_, ærse, 
   {{0x64480023,0x6f08416d,0xe7ec227c,0x2fcc000d}},	// [ca20] ëfim, nwec, ङ्गा_, iaeg_, 
   {{0xa3e8068f,0x291816a3,0x00000000,0x00000000}},	//   _माह_, _trpa_, --, --, 
   {{0x68fc0628,0xeaf82b3c,0x69cca071,0x7a38026c}},	//   _uppd, _شرکت_, mabe, _vìtt, 
   {{0x69cca072,0x6f08a073,0x2fcc0165,0x00000000}},	//   labe, kwec, jaeg_, --, 
   {{0xb3a40032,0x2fcc0165,0x00000000,0x00000000}},	//   әләһ, daeg_, --, --, 
   {{0x69cca074,0x7d1ca075,0x6f080161,0xdb0c0798}},	//   nabe, årsk, dwec, cacõ, 
   {{0xb3a807b3,0x2c7002fb,0x1a98008f,0xd83c0427}},	//   ğırı, sády_, ניצע, ščev_, 
   {{0xbed80640,0xb3a85531,0x2c700306,0x6f08002f}},	//   адих_, şırı, pády_, fwec, 
   {{0x69cca076,0x26d0a077,0x44240356,0xd0040f5c}},	//   kabe, nsyo_, _inm_, сење_, 
   {{0xdee41d56,0x6440a078,0xe298a079,0xef2404d3}},	//   _ҳоди, lkoi, _саз_, تژمێ, 
   {{0x44247202,0xdd98034b,0x10a000c7,0x2fcc05c7}},	//   _knm_, ыши_, _еихн, baeg_, 
   {{0xdee402d7,0x6440a07a,0x44242a9a,0x69cc062c}},	//   _годи, nkoi, _jnm_, eabe, 
   {{0x6f080944,0x7d080369,0x6440a07b,0xbda40137}},	//   cwec, swds, ikoi, _وڭدو, 
   {{0x61e8a07c,0x6440005b,0x00000000,0x00000000}},	//   ngfl, hkoi, --, --, 
   {{0xd7f80124,0x644002f6,0x7c34030d,0xdbc4032e}},	//   луа_, kkoi, _мекх, böði, 
   {{0x4424a07d,0x7ac400fd,0x6b80063f,0x7e680165}},	//   _nnm_, _мөга, ịgas, lndp, 
   {{0xb7881de6,0x00000000,0x00000000,0x00000000}},	// [ca30] рәне_, --, --, --, 
   {{0x94a800ee,0x0ab8007b,0x00000000,0x00000000}},	//   гтда_, _اطيب_, --, --, 
   {{0x4424a07e,0x6f083f5b,0xdb0c00d8,0x26d00009}},	//   _bnm_, zwec, racõ, asyo_, 
   {{0x6f080204,0x98c00032,0x44240790,0x3ce00dba}},	//   ywec, _мөғж, _cnm_, _किने_, 
   {{0xa3e823ef,0x2fcca07f,0x59bc00cd,0x00000000}},	//   _मार_, vaeg_, ्रपर, --, 
   {{0x3868a080,0x442412ba,0xf0e80131,0x2fcc05c7}},	//   lnar_, _enm_, لىتى_, waeg_, 
   {{0xd24c0d73,0x2fcca081,0x00000000,0x00000000}},	//   ونچ_, taeg_, --, --, 
   {{0x3868a082,0x6f08a083,0x644000ad,0x6ed401c6}},	//   nnar_, twec, ckoi, оцох, 
   {{0x3868041e,0x2fcc0dd4,0x11e800ae,0x00000000}},	//   inar_, raeg_, _معاي_, --, 
   {{0x6f081a80,0x2fcca084,0x386805d5,0xf1240214}},	//   rwec, saeg_, hnar_, _وظای, 
   {{0x3868a085,0x69cca086,0xdbc40008,0x6f080e78}},	//   knar_, vabe, töði, swec, 
   {{0x69cca087,0x44240158,0x3868a088,0x648800e4}},	//   wabe, _xnm_, jnar_, hýin, 
   {{0x69cca089,0xe04010f5,0x92a803d4,0x00000000}},	//   tabe, _інши, কীৰ_, --, 
   {{0x29d40691,0x6d540077,0x6440009d,0xed580345}},	//   غيزس, úzas, zkoi, _پشتت_, 
   {{0x3ce00034,0x38680008,0xa3e8230e,0xa7a800a7}},	//   _किये_, fnar_, _माल_, иква_, 
   {{0x69cca08a,0x69b80ad7,0x6ae44965,0x00000000}},	//   sabe, ्रही, _джиз, --, 
   {{0x442406d9,0x644005be,0xbbe80132,0x26d000b5}},	// [ca40] _rnm_, vkoi, _ارىم_, usyo_, 
   {{0x44240050,0x26d0a08b,0xe7ec012c,0x386845c0}},	//   _snm_, rsyo_, ङ्जा_, anar_, 
   {{0x6440023a,0xa3e83da1,0x3868a08c,0x6fc801f9}},	//   tkoi, иджа_, bnar_, ररां, 
   {{0x9c806b07,0x44240395,0x26d01c06,0x69b80882}},	//   _účto, _qnm_, psyo_, ्रवी, 
   {{0xe298152d,0x64400664,0x4424a08d,0xbc0c010f}},	//   аад_, rkoi, _vnm_, טהאָ, 
   {{0x6440a08e,0x00000000,0x00000000,0x00000000}},	//   skoi, --, --, --, 
   {{0x44240bd7,0x61e80158,0x20ec0213,0xa2c8095f}},	//   _tnm_, rgfl, _rəis_, _सौर्, 
   {{0x75200077,0x71700137,0x00000000,0x00000000}},	//   _álza, رۇنا, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa3e81533,0x2484a08f,0x386c08a4,0xdd98260d}},	//   _माँ_, llom_, čeri_, ишн_, 
   {{0xb310038f,0x3868a090,0xffa401ee,0x00000000}},	//   _ྋགོང_, ynar_, _елеү, --, 
   {{0xbbb41d68,0x00000000,0x00000000,0x00000000}},	//   ंडेक, --, --, --, 
   {{0x38681125,0x248401f1,0x00000000,0x00000000}},	//   vnar_, ilom_, --, --, 
   {{0xd90c01fd,0x24840419,0x00000000,0x00000000}},	//   نیخ_, hlom_, --, --, 
   {{0xa3e8a091,0x248408a4,0x3868a092,0x6e1403e6}},	//   _मां_, klom_, tnar_, _رسوڕ, 
   {{0x2484009b,0x3868a093,0x50d80a7c,0xd7e40228}},	//   jlom_, unar_, יקלא, تورۇ_, 
   {{0x3868a094,0x248401f1,0x7bcc00de,0x00000000}},	// [ca50] rnar_, dlom_, _ieau, --, 
   {{0xd5b8a095,0x7bcc6d9e,0x38685f87,0xddd80374}},	//   рса_, _heau, snar_, kitō, 
   {{0xd498a096,0x7bcca097,0x3868a098,0x97c4007b}},	//   ард_, _keau, pnar_, _وتحم, 
   {{0x248408ad,0x96080154,0x00000000,0x00000000}},	//   glom_, রাইম_, --, --, 
   {{0x7bcca099,0x00000000,0x00000000,0x00000000}},	//   _meau, --, --, --, 
   {{0x7bcca09a,0x24840010,0xe4640254,0x891800f1}},	//   _leau, alom_, _ööni_, _اغیز_, 
   {{0x21a0a09b,0xe120005b,0x00000000,0x00000000}},	//   нишм, емщи, --, --, 
   {{0x94200b38,0x76440158,0x4adc02c3,0x934000f7}},	//   _تورۇ, lkhy, _बिलव, _قىزۇ, 
   {{0xd7d8037e,0x00000000,0x00000000,0x00000000}},	//   _cmド_, --, --, --, 
   {{0x7bcc0093,0x76440649,0xdf7001d5,0x926800d8}},	//   _aeau, nkhy, رگنب, _трба_, 
   {{0x7bcca09c,0x7984009a,0x7c2800e2,0xec78751d}},	//   _beau, _nyhw, ķern, йпо_, 
   {{0x7bcca09d,0x801400d6,0x7d1c0b1a,0x00000000}},	//   _ceau, _офіц, ærsa, --, 
   {{0x7ff49b26,0x7bcca09e,0xd5c81a55,0x405400db}},	//   _آسما, _deau, िराज, _تئلس, 
   {{0xdb0c0491,0xdeb8011a,0x24845049,0xaa440108}},	//   ódái, _המסל, zlom_, чегл, 
   {{0x660811a9,0x7bcca09f,0x8d74a0a0,0x291ca0a1}},	//   _ölkə, _feau, _باشا, íta_, 
   {{0x7bcc0d27,0x6d40a0a2,0xa3e875be,0x6dc00137}},	//   _geau, myla, _माइ_, _تۅگۅ, 
   {{0x6d40a0a3,0x248400d0,0x7d1c99c0,0xa6e40064}},	// [ca60] lyla, vlom_, årsv, яжал, 
   {{0xa5940b32,0x7bcc0472,0xdb1c0139,0x6d4000ad}},	//   прещ, _zeau, _deqä, oyla, 
   {{0x6d40a0a4,0x7bcca0a5,0x24843858,0x9a38011a}},	//   nyla, _yeau, tlom_, _התיק, 
   {{0x6d40062c,0x39442ab7,0x76440055,0x00000000}},	//   iyla, ølse_, akhy, --, 
   {{0x6d40a0a6,0x7c3c017a,0x00000000,0x00000000}},	//   hyla, êrri, --, --, 
   {{0x6d40a0a7,0x11d00075,0x80d009bd,0x2484181f}},	//   kyla, ىتىد, সংস্, slom_, 
   {{0x403480df,0x6d4009a5,0x845400db,0x00000000}},	//   дейс, jyla, _قىسچ, --, 
   {{0x6d4009a5,0x44d802e2,0x00000000,0x00000000}},	//   dyla, mč_, --, --, 
   {{0x7bcca0a8,0xddd80418,0x957c02d3,0x6d4000ad}},	//   _reau, sitō, _ንሳተን_, eyla, 
   {{0x7bcca0a9,0xa13400db,0x00000000,0x00000000}},	//   _seau, _ىراش, --, --, 
   {{0x7bcca0aa,0x6d40a0ab,0x44d8a0ac,0xdf745dc6}},	//   _peau, gyla, nč_, _کداب, 
   {{0x648800e4,0x00000000,0x00000000,0x00000000}},	//   kýim, --, --, --, 
   {{0xa3e8033d,0x25a804e6,0x7bcc06af,0x6d400076}},	//   _माई_, _ogbl_, _veau, ayla, 
   {{0xdd900e5a,0x6d40a0ad,0x7bcc0472,0x8f980375}},	//   _كوش_, byla, _weau, _הידי, 
   {{0x6d40a0ae,0x7bcca0af,0x44d8033b,0x4adc0037}},	//   cyla, _teau, jč_, _बिअव, 
   {{0xb9044a01,0xb8f4134e,0x00000000,0x00000000}},	//   _नि_, _हब_, --, --, 
   {{0x59bc0825,0x25a80e78,0x9ba000db,0x81bc0171}},	// [ca70] ्रदर, _bgbl_, _سەسى, _anēm, 
   {{0x06141d82,0x44d802e2,0xa3e80709,0x00000000}},	//   ндую, fč_, _माउ_, --, 
   {{0x04b40d30,0x00000000,0x00000000,0x00000000}},	//   есія, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d400209,0x14fc0150,0x44d800d0,0x00000000}},	//   zyla, _ءﺳﺎﻧ, ač_, --, 
   {{0x77400020,0xc24402d5,0x59bc0303,0x46a40024}},	//   _የመሳሰ, ннік, ्रिर, _паўв, 
   {{0x6d40a0b0,0x00000000,0x00000000,0x00000000}},	//   xyla, --, --, --, 
   {{0x6d40a0b1,0xa3e80dba,0x00000000,0x00000000}},	//   vyla, _माए_, --, --, 
   {{0x59bc1788,0x7d1c01bf,0x00000000,0x00000000}},	//   ्रार, ærsn, --, --, 
   {{0x6d40a0b2,0xed4448a9,0x31d40066,0x00000000}},	//   tyla, дноп, _آقاز, --, 
   {{0xac08a0b3,0xefec0092,0x00000000,0x00000000}},	//   онна_, ቁመው_, --, --, 
   {{0x6d40a0b4,0x00000000,0x00000000,0x00000000}},	//   ryla, --, --, --, 
   {{0x6d40a0b5,0x44d8007f,0x00000000,0x00000000}},	//   syla, zč_, --, --, 
   {{0x6d4000ee,0x44d8033b,0x00000000,0x00000000}},	//   pyla, yč_, --, --, 
   {{0xad246e0c,0xed58084c,0x81bc00ef,0x7d1c0efa}},	//   _زرغو, _фой_, _poēz, årst, 
   {{0xac7402e9,0x44d8a0b6,0x7e7c0010,0x00000000}},	//   _تاتش, vč_, črpe, --, 
   {{0x1864a0b7,0xd7ec00c6,0xb8d402fe,0x44d802e2}},	// [ca80] фати_, شكل_, _छू_, wč_, 
   {{0xc1ac0034,0xb6840131,0x44d8033b,0x00000000}},	//   _चलेग, ىشلى, tč_, --, 
   {{0x24f40588,0x44d800f3,0x00000000,0x00000000}},	//   ьчар, uč_, --, --, 
   {{0x234816a0,0x3ce009bb,0x9f48002e,0x00000000}},	//   يلاپ_, _किसे_, ëmëm_, --, 
   {{0xd12c8c9e,0x17c402bf,0x44d802e2,0x2604000d}},	//   یمه_, _ігри_, sč_, _सउपी_, 
   {{0xd36c05d9,0x934006bb,0x44d80100,0x4ad007b7}},	//   جهه_, ънче, pč_, तीयव, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3f1473f9,0x71080212,0x87440092,0x00000000}},	//   едис, яхів_, _የመስቀ, --, 
   {{0x69dc09a8,0x2fdc0042,0xdef802d5,0x648800e4}},	//   _odpe, _ddwg_, цый_, hýik, 
   {{0x7d1c0b1a,0x5f9001d5,0x00000000,0x00000000}},	//   ærso, ниқт, --, --, 
   {{0x62880309,0xa0a41214,0x00000000,0x00000000}},	//   mlfo, _жажд, --, --, 
   {{0x6288a0b8,0x69dca0b9,0x5f28199c,0x38c40248}},	//   llfo, _adpe, _моем_, _lèrò_, 
   {{0x62880af9,0xbe6800db,0x386c00a2,0x00000000}},	//   olfo, _ىشتۅ_, _ıer_, --, 
   {{0x7d1c05ac,0xd8b80244,0x00000000,0x00000000}},	//   årss, قدرا_, --, --, 
   {{0xd83c01f1,0x62880175,0x99d001d9,0x00000000}},	//   áčov_, ilfo, ى۪کا, --, 
   {{0x76b8a0ba,0xa3e80316,0x59bc0404,0x6288002f}},	//   злар_, _माग_, ्रहर, hlfo, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [ca90] --, --, --, --, 
   {{0x3914187f,0x99280f06,0x00000000,0x00000000}},	//   _змор, _дюма_, --, --, 
   {{0xdfc400b2,0x38c40248,0x756400e5,0x00000000}},	//   _ٽي_, _dèrò_, ریرہ_, --, 
   {{0x59bc146b,0x3374a0bb,0x38b4007c,0xb7c40b01}},	//   ्रवर, нгер, _iår_, _яроқ, 
   {{0x38b451dc,0x932469f1,0x6e2c0198,0x437463dd}},	//   _hår_, بران, _ɗabb, кушт, 
   {{0x38b40623,0x62880158,0x648800e4,0x02e04433}},	//   _kår_, glfo, hýih, _निरभ, 
   {{0x7d1c0008,0x147410de,0x9474a0bc,0x00000000}},	//   ærsl, _قارج, _قدرا, --, 
   {{0x38b4049f,0x62880158,0xc59400d8,0x026402f2}},	//   _mår_, alfo, _рисј, _یێنێ, 
   {{0xb8f00135,0x38b4795b,0x00000000,0x00000000}},	//   _ུས_, _lår_, --, --, 
   {{0xed5841b9,0x00000000,0x00000000,0x00000000}},	//   зоо_, --, --, --, 
   {{0x38b47a1e,0xa3b4000d,0x2068004b,0x81d40107}},	//   _når_, चुक_, _کلنۍ_, _рохх, 
   {{0x9f500882,0xddd8013a,0x00000000,0x00000000}},	//   ṇāni_, botů, --, --, 
   {{0x28d000c5,0x9c800419,0x00000000,0x00000000}},	//   _तबहि, áčaj, --, --, 
   {{0x38b401e3,0xed581188,0x64880022,0x00000000}},	//   _bår_, _нол_, týik, --, 
   {{0x9c80151c,0x4f94001f,0x4adc012d,0xf9902e0b}},	//   ščaj, _ቅስቀሳ_, _बिकव, لبِ_, 
   {{0x22a401e1,0x966000c7,0x00000000,0x00000000}},	//   _kíkì_, ҳкуе, --, --, 
   {{0x69d87917,0x38c401e1,0x628802d0,0xd5c819cc}},	// [caa0] ótes, _pèrò_, ylfo, िरंज, 
   {{0x38b439c3,0x69dc037e,0x2290013c,0x5b780375}},	//   _får_, _udpe, kâka_, _מרפא, 
   {{0x38b439c3,0x00000000,0x00000000,0x00000000}},	//   _går_, --, --, --, 
   {{0xa3e806b1,0x00000000,0x00000000,0x00000000}},	//   _माओ_, --, --, --, 
   {{0xa2c801bc,0x68eca0bd,0xc5f801d5,0x27f0010e}},	//   _सौख्, lubd, _оға_, mgyn_, 
   {{0xb4240e3f,0x3ce0033f,0x27f0a0be,0x00000000}},	//   _یعقو, _किले_, lgyn_, --, 
   {{0xa0a4a0bf,0x27f00076,0x68eca0c0,0x00000000}},	//   ншил, ogyn_, nubd, --, 
   {{0x27f0a0c1,0x64a4a0c2,0x10640131,0xd4a0014b}},	//   ngyn_, _чаба, ىڭنى_, _бисй, 
   {{0x68ec1c06,0xe1f0a0c3,0x27f00363,0xd180035f}},	//   hubd, _مسا_, igyn_, кләй, 
   {{0xdb100205,0x52d4011a,0x00000000,0x00000000}},	//   ıgüz, _נובע_, --, --, 
   {{0xd00c7c25,0xd654011a,0x27f00432,0x00000000}},	//   _گلن_, גיית_, kgyn_, --, 
   {{0x38b4a0c4,0x00000000,0x00000000,0x00000000}},	//   _rår_, --, --, --, 
   {{0xd00c01d9,0xbf100075,0x3d289057,0x64880022}},	//   _دلن_, _түпә, ستگی_, rýih, 
   {{0x27f00076,0xa3e85d9c,0x8fa00063,0x00000000}},	//   egyn_, _माझ_, _саче, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x38b41121,0x92a80f22,0x27f000ad,0xb5cc00cc}},	//   _vår_, কীয়_, ggyn_, _লাইচ, 
   {{0x291ca0c5,0x35f4a0c6,0x00000000,0x00000000}},	// [cab0] åtar_, кпар, --, --, 
   {{0x3b0802fa,0x7c2c0295,0x27f00363,0x38b48ce1}},	//   _ipaq_, _hnar, agyn_, _tår_, 
   {{0x7c2ca0c7,0x38b40158,0xf3f810ea,0x00000000}},	//   _knar, _uår_, днеш_, --, 
   {{0x7afc7890,0x64700c60,0xdd8403e6,0x85740022}},	//   otst, аҳсу, _ۆو_, ылхх, 
   {{0x7afc035a,0xdd84a0c8,0x2290006a,0x7c2ca0c9}},	//   ntst, _چو_, wâka_, _mnar, 
   {{0xdd84a0ca,0x2290025a,0x7afc2d1d,0x7c2c0139}},	//   _نو_, tâka_, itst, _lnar, 
   {{0x7c2ca0cb,0x7afc5282,0x271002e2,0xc59403f6}},	//   _onar, htst, _zņn_, _бирј, 
   {{0x7afc11ad,0x7c2ca0cc,0xd7d800b5,0x34941a5c}},	//   ktst, _nnar, _mmハ_, _рабр, 
   {{0x152c0150,0x7afc508f,0xd200329e,0xc61400eb}},	//   _ءﺷﺎﺷ, jtst, _бүлк, সারা_, 
   {{0x6da4a0cd,0x066c02d3,0x7afc5522,0x7c2ca0ce}},	//   кипа, _ተረኺቡ_, dtst, _anar, 
   {{0x3b0802d1,0x7d1c78d0,0xc1047427,0x00000000}},	//   _apaq_, årsp, _مولي, --, 
   {{0x7c2c01ab,0x7e7c0219,0x00000000,0x00000000}},	//   _cnar, črpa, --, --, 
   {{0xad241473,0x7afc074d,0xa3e828f5,0x7c2ca0cf}},	//   رىڭى, gtst, _माघ_, _dnar, 
   {{0xdee0a0d0,0x25b80076,0x3a14010a,0x00000000}},	//   _тоши, xcpl_, льсс, --, 
   {{0x7afc8c63,0xd7d800b5,0x648800c7,0x7bd000e4}},	//   atst, _cmハ_, mýiv, ãkué, 
   {{0x7c2ca0d1,0xb3a847af,0x68eca0d2,0xa2d007f7}},	//   _gnar, şıyı, rubd, _डबल्, 
   {{0xe618710e,0x98a03804,0x7afc1071,0xa68410f6}},	// [cac0] мда_, рите, ctst, влад, 
   {{0x27f00368,0x660016a3,0x7c2c00de,0x00000000}},	//   sgyn_, đoko, _znar, --, 
   {{0x64a4063b,0x7c2c01a9,0x25b800e2,0xb68400d1}},	//   важа, _ynar, rcpl_, اشقى, 
   {{0xb60800da,0x648800c7,0x3204045a,0x00000000}},	//   _atšķ, hýiv, _ably_, --, 
   {{0xd36ca0d3,0x64880022,0x00000000,0x00000000}},	//   يهم_, kýiv, --, --, 
   {{0x26c03879,0xa18400fd,0x7d1c5522,0x00000000}},	//   _itko_, кыйл, ærsk, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x44fca0d4,0xe474084c,0x25f0134e,0x7f94a0d5}},	//   mí_, _ругэ, ुभवी_, лайх, 
   {{0xdde8a0d6,0x44fca0d7,0x7afca0d8,0xd00414b7}},	//   ورده_, lí_, xtst, тење_, 
   {{0x44fc0332,0x00000000,0x00000000,0x00000000}},	//   oí_, --, --, --, 
   {{0x44fca0d9,0x6b94010e,0xd00c01f4,0x00000000}},	//   ní_, _azyg, _кф_, --, 
   {{0x7afc174e,0x6724a0da,0x1f6402dd,0x00000000}},	//   ttst, _orkj, _икем, --, 
   {{0x20040286,0x7afc8fee,0x44fca0db,0x610806be}},	//   _iboi_, utst, hí_, _bəlg, 
   {{0x7afca0dc,0x44fca0dd,0xd9bc2ef1,0x6d4c00e4}},	//   rtst, kí_, ्रेट, ñoañ, 
   {{0x44fc038e,0x26c0a0de,0x6724000f,0x4a4406a6}},	//   jí_, _atko_, _arkj, шнёв, 
   {{0x27e00204,0x7afca0df,0x43cc00cd,0x00000000}},	//   _cdkn_, ptst, ारोऽ, --, 
   {{0x7d18009b,0x2004a0e0,0xf6980640,0xa3e402a0}},	// [cad0] _hsvs, _mboi_, евај_, पणन_, 
   {{0x44fca0e1,0x7e680477,0xf8b000f2,0x00000000}},	//   fí_, nidp, _هکر_, --, 
   {{0x672468b6,0x44fca0e2,0x634800e2,0x7874009f}},	//   _erkj, gí_, _lēnā, _مُدا, 
   {{0x6b9400ee,0x62980e03,0x78a801e4,0xb3540166}},	//   _yzyg, _ahto, ĉevs, лкеш, 
   {{0x44fca0e3,0x3868a0e4,0x629801a6,0x4adc00c5}},	//   aí_, miar_, _bhto, _बिछव, 
   {{0x3868a0e5,0x20040077,0x44fc635f,0xe6a40166}},	//   liar_, _aboi_, bí_, _бусү, 
   {{0x44fca0e6,0xf1d00184,0x56380092,0x623000d8}},	//   cí_, _һөйө, _በማዳበ, сеју, 
   {{0xef180f04,0x3868a0e7,0x6298023a,0x6724a0e8}},	//   еми_, niar_, _ehto, _yrkj, 
   {{0xd5a40825,0x7e7c0427,0x648800c7,0x00000000}},	//   _कृतज, črpn, týiv, --, 
   {{0x386803a2,0x62980076,0x260425c9,0x9c800427}},	//   hiar_, _ghto, स्पी_, ščlj, 
   {{0x3868a0e9,0x518400c7,0x610806be,0xe7f400bc}},	//   kiar_, _руаа, _cəld, इलमा_, 
   {{0x7d180356,0x2fc8010b,0x648800e4,0x00000000}},	//   _dsvs, _ýag_, sýiv, --, 
   {{0x3868a0ea,0x44fc031d,0x64880022,0x00000000}},	//   diar_, zí_, pýiv, --, 
   {{0x6a84a0eb,0xd00c01d9,0x31e4015b,0x7e68a0ec}},	//   улга, _دلچ_, প্রশ, cidp, 
   {{0x44fca0ed,0x610803be,0x49040137,0xd978035b}},	//   xí_, _gəld, шүнг, ертә_, 
   {{0xddd8000a,0x3868a0ee,0x44fc031d,0x70d00316}},	//   motš, giar_, ví_, _सबैल, 
   {{0xddd8000a,0x44fc0429,0x6b9400a2,0x00000000}},	// [cae0] lotš, wí_, _uzyg, --, 
   {{0x44fc0745,0xe5a40228,0xf3f80356,0x00000000}},	//   tí_, гизи, _acţ_, --, 
   {{0x44fca0ef,0x3868a0f0,0xa968009b,0xa3e80120}},	//   uí_, biar_, _чина_, едеа_, 
   {{0x44fca0f1,0x29185d55,0x6298044e,0xe7380a43}},	//   rí_, _ispa_, _shto, _зем_, 
   {{0x44fca0f2,0x6f1803ac,0x610803e3,0x00000000}},	//   sí_, _nswc, _məle, --, 
   {{0xddd8000a,0x44fca0f3,0x5b78008f,0x40e400d1}},	//   kotš, pí_, ערסא, асиғ, 
   {{0x7e68a0f4,0x29180334,0x1540a0f5,0xf66407ee}},	//   vidp, _jspa_, _лерм, _терү, 
   {{0x29181529,0x634800b0,0xd104007b,0x00000000}},	//   _mspa_, _pēnā, اقيه_, --, 
   {{0x61f400c6,0x6298010a,0x24840de2,0x91d003d4}},	//   _مساء, _thto, moom_, _সাৰ্, 
   {{0x2484a0f6,0x3868a0f7,0x2918a0f8,0x515000c7}},	//   loom_, ziar_, _ospa_, ртәу, 
   {{0x2174a0f9,0x1278008f,0x61f8035a,0x3c58084c}},	//   _суар, _טאמע, _ictl, винэ_, 
   {{0x2484a0fa,0x634800b0,0x3868056a,0x5574010f}},	//   noom_, _tēnā, xiar_, רעטן_, 
   {{0x3868a0fb,0x2918a0fc,0x5438008f,0xf81400f2}},	//   viar_, _aspa_, געכא, یسرگ, 
   {{0xddd827c4,0x38682e9b,0x24840218,0x28b40cf1}},	//   botš, wiar_, hoom_, _आंशि, 
   {{0x3868a0fd,0x2484a0fe,0x00000000,0x00000000}},	//   tiar_, koom_, --, --, 
   {{0x248400e8,0x6ab40175,0x61080213,0x00000000}},	//   joom_, _fuyf, _kəlb, --, 
   {{0x3868a0ff,0x2484a100,0x0c740133,0x00000000}},	// [caf0] riar_, doom_, _ددود, --, 
   {{0x3868a101,0x8cc807f7,0x6f1c003a,0x00000000}},	//   siar_, थीको, æsci, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2484a102,0x59bc0b7c,0x04c85230,0x00000000}},	//   goom_, ्रकर, اوني_, --, 
   {{0xc5fc1c82,0xc3040133,0x610806be,0x00000000}},	//   ীয়া_, مبوو, _nəlb, --, 
   {{0x61f80c67,0xd2580006,0x044c0241,0x00000000}},	//   _cctl, эце_, _àènà_, --, 
   {{0x2484a103,0x668007d6,0x3d140456,0x00000000}},	//   boom_, _بیلل, _फैले_, --, 
   {{0x7e780356,0x6364022e,0xc0c80063,0x2ee43dad}},	//   _ajvp, _qаnc, ћује_, ажиг, 
   {{0x257c145e,0x610803e3,0x43940e4e,0x00000000}},	//   pälë_, _cəlb, _гатс, --, 
   {{0x61f80076,0x10a001d5,0x648800e4,0x00000000}},	//   _gctl, шиқн, sýit, --, 
   {{0xace802e8,0x648800e4,0x00000000,0x00000000}},	//   ъмна_, mýir, --, --, 
   {{0x2918070d,0x64580024,0x81680108,0x5eec01f9}},	//   _rspa_, _įtik, _сруб_, _आमच्_, 
   {{0x01d804c5,0x6438008f,0x2fcca104,0x00000000}},	//   _সাতদ, דערנ, mbeg_, --, 
   {{0xddd80f8b,0xe18c044e,0x6da407d6,0xada4a105}},	//   potš, _ምንባሩ_, _кила, _калл, 
   {{0x68440801,0x9e940131,0xa3c837f3,0x7df400cf}},	//   анва, _ئانچ, ोरम_, _اقىچ, 
   {{0xeb280323,0x7ae80989,0x66e418a4,0x24840694}},	//   _ажил_, šeta, иоба, xoom_, 
   {{0x29180798,0x06080032,0x248400f3,0xe7a8a106}},	// [cb00] _wspa_, лмаҫ_, voom_, твал_, 
   {{0x9ad80a1e,0xd5e801fb,0xdb980375,0x248400e8}},	//   _שחיט, _địn, _בספר, woom_, 
   {{0x2484a107,0x2eec010a,0x29180309,0x69cca108}},	//   toom_, href_, _uspa_, mbbe, 
   {{0xe48006b9,0x260410eb,0x765401ef,0x00000000}},	//   _öpüş, _सॉरी_, _elzy, --, 
   {{0x2484a109,0xd24c04d3,0x9f40a10a,0xdb1001d3}},	//   room_, ژنه_, ükü_, űgöz, 
   {{0x2eec00a9,0x79500014,0x2484a10b,0x6ce403ce}},	//   dref_, _بێہا, soom_, _किंग_, 
   {{0xdb1ca10c,0x69cc2a6e,0x2484002e,0xe3b8a10d}},	//   _seqü, ibbe, poom_, _абб_, 
   {{0xc034026a,0x3fb4015b,0x2fcc0098,0x2484002e}},	//   сниј, ঘর্ষ, gbeg_, qoom_, 
   {{0x610803be,0x2eec0129,0x648803b2,0x260401ad}},	//   _qəlb, gref_, býir, स्थी_, 
   {{0x62700034,0x7e540212,0x00000000,0x00000000}},	//   dłog, своє, --, --, 
   {{0xc0c402dd,0x0e300212,0x00000000,0x00000000}},	//   _уәли, інюю, --, --, 
   {{0x26041d34,0x60c8a10e,0xf8b801e0,0x00000000}},	//   स्ती_, mpfm, ҫөн_, --, 
   {{0x7c3c0175,0xcb4400f3,0xa18401af,0x00000000}},	//   rjsr, охри, _сыҡл, --, 
   {{0x6dc0063f,0x9a8401a9,0xc0f80092,0x00000000}},	//   ịaru, румл, ጋጃል_, --, 
   {{0xd7f8035b,0xa3e40490,0x1be401b9,0xd54001e1}},	//   куа_, पणा_, _кўпг, _mẹ́m, 
   {{0x085402bf,0x69cc1368,0x7d1c0158,0x7bc0012d}},	//   овсю, abbe, ærsu, ślub, 
   {{0x7bdca10f,0x57a40801,0xda78a110,0xda641359}},	// [cb10] masu, ршва, _аян_, _نادي, 
   {{0x7bdca111,0x2fcc0369,0x07080066,0x00000000}},	//   lasu, zbeg_, شيمي_, --, 
   {{0x3a20007c,0x15a80107,0x00000000,0x00000000}},	//   _iahp_, тъаи_, --, --, 
   {{0x6270012d,0x49740f06,0x43f800d4,0x00000000}},	//   hłod, _флюс, ихія_, --, 
   {{0x848002d3,0x7bdc000d,0xd5b85b66,0x648800e4}},	//   _ንኣምን_, iasu, _асб_, týir, 
   {{0x438400d1,0x00000000,0x00000000,0x00000000}},	//   ڭلۇق, --, --, --, 
   {{0x7bdca112,0x21645026,0xb7c40589,0x3494a113}},	//   kasu, йиши_, _inãª, _гавр, 
   {{0x7bdca114,0x2eeca115,0x2fcc030a,0x3e940092}},	//   jasu, tref_, ubeg_, _ምሥረታ_, 
   {{0xb8d8003d,0x2fcc0489,0x7bdca116,0x25fc00c5}},	//   _ངང_, rbeg_, dasu, _लामी_, 
   {{0xee38a117,0xab2800fb,0x00000000,0x00000000}},	//   уно_, ңона_, --, --, 
   {{0x7bdca118,0x2eeca119,0xac840212,0xeea800db}},	//   fasu, sref_, йгол, ктүк_, 
   {{0x7bdca11a,0xdfcc00b2,0x61440075,0x2eec014b}},	//   gasu, _ٻيو_, _دىمە, pref_, 
   {{0xee080166,0xeec4516c,0x6fa403d4,0xa3c80037}},	//   _белл_, _ايتپ, _গ্ৰে, ोरत_, 
   {{0xa96807d6,0x7bdc0869,0x610800ac,0x69cca11b}},	//   гига_, aasu, _həla, ubbe, 
   {{0x7d1c008c,0xd7d8037e,0x67f001d5,0x61080213}},	//   ærst, _mmテ_, _bаjа, _kəla, 
   {{0x7bdca11c,0x385873c7,0x394401e6,0x186412d7}},	//   casu, арую_, älsa_, баси_, 
   {{0x66e4016c,0xe69401b9,0x610803e3,0xab281797}},	// [cb20] соза, ملرد, _məla, _сопа_, 
   {{0xaa8400a2,0x00000000,0x00000000,0x00000000}},	//   _doýç, --, --, --, 
   {{0x25fc7db3,0x6924447e,0x00000000,0x00000000}},	//   _लाठी_, _умна, --, --, 
   {{0xfd500241,0x00000000,0x00000000,0x00000000}},	//   _aidọ, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7bdca11d,0xe5a4a11e,0xd6cc2088,0x291c0327}},	//   zasu, _гиги, _سقف_, ħtaf_, 
   {{0x7bdca11f,0x293400c8,0xa088a120,0x61080213}},	//   yasu, מאַן_, лсиз_, _bəla, 
   {{0x61080213,0x7bdca121,0x00000000,0x00000000}},	//   _cəla, xasu, --, --, 
   {{0x7bdca122,0x9340a123,0xada00004,0xe298a124}},	//   vasu, _енте, åºni, _баа_, 
   {{0x7bdca125,0x9cc878da,0x160821bd,0x00000000}},	//   wasu, лыма_, स्पर_, --, 
   {{0x7bdc152d,0xe0d00b28,0x61080213,0x00000000}},	//   tasu, _رزا_, _fəla, --, 
   {{0x6288a126,0x7158495c,0xdef81e76,0xa3c80037}},	//   lofo, _трус_, _бык_, ोरि_, 
   {{0x6270012d,0x00000000,0x00000000,0x00000000}},	//   płod, --, --, --, 
   {{0x6288a127,0x7bdca128,0x7ae801fa,0xbe640451}},	//   nofo, sasu, šeto, _گهڻي, 
   {{0x7bdca129,0x62880618,0x6d901d0e,0x91b8011a}},	//   pasu, iofo, rðaú, רמלי, 
   {{0x6288a12a,0x9e940131,0x4cf40375,0x7bdca12b}},	//   hofo, _ئاچچ, _הזהב_, qasu, 
   {{0x6288a12c,0x9a840209,0x38800092,0xfe780064}},	// [cb30] kofo, _гунл, _የእርሱ_, onį_, 
   {{0x628801e4,0x75c80150,0x00000000,0x00000000}},	//   jofo, ртаң_, --, --, 
   {{0x6288a12d,0x04c816ef,0xe69801d9,0x969400c7}},	//   dofo, مولي_, جمٕژ_, арҧш, 
   {{0xaa84010e,0x22280014,0x386c0139,0x81bc00ef}},	//   _toýç, یٲنی_, _öer_, _snēp, 
   {{0x6288a12e,0xf1b80124,0x64880022,0xfe780064}},	//   fofo, аӡе_, rýip, knį_, 
   {{0x610800ac,0x628801e4,0x648800c7,0x00000000}},	//   _səla, gofo, sýip, --, 
   {{0x45d4a12f,0xd498894b,0x614002e8,0xa1540063}},	//   _хосс, _бра_, деща, жају_, 
   {{0x257c006a,0xaec4a130,0xfe780153,0x6270012d}},	//   _wälï_, обил, enį_, głob, 
   {{0x260472a2,0x17a803d4,0xa44002f2,0x00000000}},	//   स्वी_, গুৰি, _تێنو, --, 
   {{0x6288a131,0x332ca132,0x386c02fb,0x3ea802f2}},	//   cofo, _irex_, čery_, مێنێ_, 
   {{0x7ae8a133,0x71740345,0xf1a4012c,0x61080213}},	//   šetl, _بهاا, गेशन, _təla, 
   {{0x618c02d3,0x00000000,0x00000000,0x00000000}},	//   ህጉራዊ_, --, --, --, 
   {{0xcf24a134,0x7e7405d9,0xddd80115,0x7d1c03cd}},	//   _دراي, _کانئ, litŝ, ærsr, 
   {{0x2bf800cc,0x4ea4a135,0x00000000,0x00000000}},	//   ইজেই_, _уреа, --, --, 
   {{0x28b8084c,0x6cf8010a,0x5a58010a,0x00000000}},	//   ругэ_, _тейĕ, ăрмĕ, --, 
   {{0x628800df,0x00000000,0x00000000,0x00000000}},	//   zofo, --, --, --, 
   {{0x65b81a92,0x25fc0406,0x6288002e,0xbd900023}},	// [cb40] ауер_, _लादी_, yofo, _ማሕተም_, 
   {{0x62880c86,0x636401a9,0x2a6c002f,0xa59402e8}},	//   xofo, _sаno, _öfb_, орещ, 
   {{0xe3b8093d,0x62880115,0x00000000,0x00000000}},	//   абе_, vofo, --, --, 
   {{0x6364022e,0x6288a136,0x00000000,0x00000000}},	//   _fаnl, wofo, --, --, 
   {{0xe284a137,0x00000000,0x00000000,0x00000000}},	//   олди, --, --, --, 
   {{0x20c4085e,0x00000000,0x00000000,0x00000000}},	//   осиг, --, --, --, 
   {{0x12d4000e,0x00000000,0x00000000,0x00000000}},	//   _সমৃদ, --, --, --, 
   {{0x6288a138,0xe2c8a139,0x44d8003a,0x26041a4e}},	//   sofo, _влад_, mō_, स्री_, 
   {{0x4424a13a,0x332c0381,0xfbc00dba,0x00000000}},	//   _iam_, _grex_, _एलबम, --, 
   {{0x4424a13b,0xf7cc04a9,0xa1346aed,0x6440223e}},	//   _ham_, _ﺑﯩﻠﻪ, _وراش, ljoi, 
   {{0x4424a13c,0x81e0009e,0x44d802b1,0x55b80375}},	//   _kam_, _থাপ_, nō_, ימיו, 
   {{0x6440a13d,0xfe780006,0x44d80418,0xe7200432}},	//   njoi, snį_, iō_, _göçý, 
   {{0x4424a13e,0x9e6401d9,0x5f740372,0x8af803be}},	//   _mam_, _واتن, _باار, _şərt, 
   {{0x4424a13f,0x6440049b,0x53980a1e,0x00000000}},	//   _lam_, hjoi, ייכו, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x44d80c6a,0x3dbc03d4,0x00000000,0x00000000}},	//   dō_, _আজিল, --, --, 
   {{0xd5b8a140,0x81e004c5,0x9a840fc0,0x64400076}},	// [cb50] асе_, _থান_, _муол, djoi, 
   {{0x4424a141,0xba1810e0,0x260401ad,0x1528005b}},	//   _aam_, _ايدا_, स्ली_, ицеп_, 
   {{0x4424a142,0x94a81751,0x9c800219,0xa3e4043e}},	//   _bam_, атда_, ščuj, पणं_, 
   {{0x4424a143,0x660c009d,0x332c003a,0x636401a9}},	//   _cam_, _ebbk, _prex_, _tаnl, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4424a144,0xf0e80131,0x660c005a,0xc2440006}},	//   _eam_, مىتى_, _gbbk, мнік, 
   {{0x4424a145,0xf558007b,0x62700210,0xafe400db}},	//   _fam_, _الأب_, włoc, пойл, 
   {{0x660001d3,0x54340d17,0x6270012d,0x00000000}},	//   őokt, _برسر, tłoc, --, 
   {{0x610803be,0xfd4c0208,0x2d98012d,0xed500014}},	//   _həll, _triễ, ęsem_, کھش_, 
   {{0x4424a146,0x27e40208,0x610803e3,0xbe3000c7}},	//   _zam_, ưong_, _kəll, ҵҕәы, 
   {{0x44240b89,0xc1080153,0x00000000,0x00000000}},	//   _yam_, _мэце_, --, --, 
   {{0x44241105,0x160806ab,0x3cdc033f,0x39980023}},	//   _xam_, स्तर_, _खबरे_, _መስራቲ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9ce400e5,0x00000000,0x00000000,0x00000000}},	//   _کوٹے_, --, --, --, 
   {{0xed340323,0xfbac02f5,0x00000000,0x00000000}},	//   _хэлэ, কুলত, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4424a147,0xd6f800b5,0xa764022e,0x00000000}},	// [cb60] _ram_, _ogサ_, чкад, --, 
   {{0x4424a148,0x610800ac,0x44d88393,0x8ca0033f}},	//   _sam_, _bəll, tō_, _गीतो, 
   {{0x4424a149,0x69dc0225,0x44d80421,0x5a3400c7}},	//   _pam_, _iepe, uō_, _хьыӡ, 
   {{0x69dca14a,0x746800d6,0x4424a14b,0xd7d800b5}},	//   _hepe, орів_, _qam_, _mmホ_, 
   {{0x4424a14c,0x6440426d,0x69dca14d,0xe298a14e}},	//   _vam_, rjoi, _kepe, бад_, 
   {{0x4424a14f,0x44d804fe,0x69dca150,0x644014e0}},	//   _wam_, pō_, _jepe, sjoi, 
   {{0x69dca151,0x62840174,0x206800ee,0x00000000}},	//   _mepe, _íkom, йшип_, --, 
   {{0x69dca152,0x4424a153,0xb3e80736,0x00000000}},	//   _lepe, _uam_, _وعقل_, --, 
   {{0x835400e5,0x229401e2,0x00000000,0x00000000}},	//   _تھاا, _فلرس, --, --, 
   {{0x69dca154,0x7ae807f5,0x5f900116,0x5f4400db}},	//   _nepe, šetk, миқт, _ۉنال, 
   {{0xfbe0015b,0xcfd8015b,0x61080213,0xa06814b3}},	//   _ভাবত, _ধারন, _kəlm, _лажа_, 
   {{0x69dc0b2e,0x5f4400db,0x55740677,0xf3640408}},	//   _aepe, _ىنال, לעין_, _итĕн, 
   {{0x69dca155,0x8fa0a156,0x5a280023,0x00000000}},	//   _bepe, _заце, _ብምርኻ, --, 
   {{0x69dca157,0x0084010b,0x2fdc0135,0xda78a158}},	//   _cepe, _элҗо, _zewg_, сям_, 
   {{0x636401a9,0xcd9000f3,0x00000000,0x00000000}},	//   _bаnk, _пашћ, --, --, 
   {{0xfbc001ad,0x69dc81ad,0xcd9400df,0xdef40023}},	//   _एलिम, _eepe, _מדות_, _ገለን_, 
   {{0x69dca159,0x61080213,0x01d80154,0x00000000}},	// [cb70] _fepe, _səll, _সাঈদ, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8c20015b,0xd3780ede,0x9324004b,0x1cb80327}},	//   ধারন_, әче_, ګران, _ཆངས_, 
   {{0x69dca15a,0x7984009a,0x3374030c,0x38800024}},	//   _zepe, _ixhw, мгер, bėra_, 
   {{0x69dca15b,0xdc240154,0x473400c0,0x95c8026b}},	//   _yepe, যাপস_, _зняс, _губа_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x94f4031c,0xe80800cd,0x6ed43be5,0x69d803b2}},	//   _པའིི_, ह्वा_, _मौजु, ðtei, 
   {{0x610803be,0x7984009a,0x9ce8031c,0x00000000}},	//   _gəlm, _mxhw, _རྗེས, --, 
   {{0x8fc00124,0x60040a89,0x00000000,0x00000000}},	//   _ҟалҵ, фным_, --, --, 
   {{0x4274a15c,0xece8a15d,0x439400d8,0x00000000}},	//   _згус, одол_, _чаус, --, 
   {{0x69dc1e58,0x5194010a,0x00000000,0x00000000}},	//   _repe, _хăна, --, --, 
   {{0x69dca15e,0x00000000,0x00000000,0x00000000}},	//   _sepe, --, --, --, 
   {{0x7984009a,0x25fc46c7,0x7ff400c6,0x00000000}},	//   _axhw, _लाली_, _أسما, --, 
   {{0xed58a15f,0xeab000dd,0xfa800220,0xdeb80375}},	//   _мол_, ئٹس_, лқым, _ומסל, 
   {{0x942000ac,0x69dca160,0xad680b01,0x62700210}},	//   şvət_, _vepe, _файз_, kłon, 
   {{0x98a00364,0x69dca161,0x18a001f0,0x00000000}},	//   висе, _wepe, васм, --, 
   {{0x69dca162,0x6a60000f,0xa6c8103c,0xe648a163}},	// [cb80] _tepe, _rôff, زوال_, опад_, 
   {{0x6f080005,0x69dc0607,0x610806be,0x920000b8}},	//   itec, _uepe, _səlm, _ũānt, 
   {{0x6f08a164,0x6d400369,0x9a380375,0x00000000}},	//   htec, nxla, _ותיק, --, 
   {{0x6f08a165,0xe738a166,0x3e740241,0xa50c0073}},	//   ktec, _дем_, _kùtè_, _सहीच_, 
   {{0x6f08a167,0x290801ed,0xc5f80116,0x00000000}},	//   jtec, ltba_, _нға_, --, 
   {{0x26d06129,0x5330a168,0x23cc3347,0x78a8025c}},	//   mpyo_, тешт, _ह्रद, ċeve, 
   {{0x6f0813ee,0x6270012d,0x290801d3,0xd1d00023}},	//   etec, błon, ntba_, ረኺቡ_, 
   {{0x200000af,0x00000000,0x00000000,0x00000000}},	//   üki_, --, --, --, 
   {{0x8c140eac,0xa204470d,0x6f081c97,0x00000000}},	//   িযান_, _опад, gtec, --, 
   {{0x3f980029,0x20000034,0xc2240fa2,0x3cd40166}},	//   āru_, żki_, _سکتو, нжос, 
   {{0x6f08a169,0x1b1003d4,0x5bb400cd,0x60246cf4}},	//   atec, িয়াই_, ःश्व, _оджа, 
   {{0x30a400d4,0x00000000,0x00000000,0x00000000}},	//   _зрів, --, --, --, 
   {{0x6f081028,0x2364010f,0xa18c01af,0x00000000}},	//   ctec, nzoj_, _сыҡh, --, 
   {{0x8f980375,0x00000000,0x00000000,0x00000000}},	//   _וידי, --, --, --, 
   {{0x8c1402f5,0x28d80118,0x00000000,0x00000000}},	//   িয়ন_, यीलि, --, --, 
   {{0x1bf0000d,0xcc88009b,0x00000000,0x00000000}},	//   _अयिल_, _обје_, --, --, 
   {{0x610803be,0x6364022e,0x57dc00e1,0x158002dd}},	// [cb90] _bəlk, _fаni, _फजीह, _ﯨﻨﺘﯩ, 
   {{0x7afca16a,0x236400df,0x00000000,0x00000000}},	//   must, dzoj_, --, --, 
   {{0x7afca16b,0x79840472,0xf8b8009d,0xca7400d1}},	//   lust, _uxhw, _хөг_, _جايغ, 
   {{0x8c1c04ac,0x36d4277c,0x6f08a16c,0x7afca16d}},	//   ַווי, _помр, ytec, oust, 
   {{0x7afca16e,0x78ac20ac,0xd7d8037e,0x0b94001f}},	//   nust, mmav, _mmボ_, _መንደር_, 
   {{0x78aca16f,0x62700034,0x6d4001a9,0x00000000}},	//   lmav, słon, yxla, --, 
   {{0x7afc007d,0x6f0801f5,0x6270033f,0x7bc00118}},	//   hust, wtec, płon, ěluj, 
   {{0x3b08013c,0x942000f7,0x610803e3,0x2c600419}},	//   _oqaq_, _جورۇ, _məlh, _kóde_, 
   {{0x2604a170,0x1284024e,0x7afca171,0x6f08026c}},	//   स्की_, _قمری_, just, utec, 
   {{0x6f08a172,0x78aca173,0x7afca174,0x2c6000d0}},	//   rtec, hmav, dust, _móde_, 
   {{0x6f0812eb,0x6fb8005e,0xd70800bd,0x6d400369}},	//   stec, _егер_, রিয়া_, uxla, 
   {{0x6d40a175,0x7afca176,0x6f08a177,0x78ac02f0}},	//   rxla, fust, ptec, jmav, 
   {{0x200803be,0xb60800ef,0xe45400df,0x00000000}},	//   əbi_, _kušķ, גירט_, --, 
   {{0x3e6002bd,0x78ac0022,0x5ba001e0,0xadbc010a}},	//   _pòte_, emav, ыһығ, _ункă_, 
   {{0x6a60002d,0x7afca178,0xed58a179,0x7c4801bf}},	//   _rôfd, aust, _хой_, æsrø, 
   {{0x3e60180f,0x245c00c7,0x7c94035b,0x78ac0200}},	//   _vòte_, _oïma_, _ирыц, gmav, 
   {{0x7afca17a,0x1864a17b,0xa5d800c6,0x636401a9}},	// [cba0] cust, хати_, كبار_, _tаni, 
   {{0x78ac3d3a,0xa924a17c,0xe4c400ee,0x28b80276}},	//   amav, _здол, ейжи, _нумэ_, 
   {{0x78ac0175,0xe5a401c6,0x97380092,0x00000000}},	//   bmav, хижи, _አዘውት, --, 
   {{0x638400d8,0xf988009f,0x00000000,0x00000000}},	//   нгеа, _آنٽي_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x672469a5,0x26c0005a,0x236401e4,0x610803b9}},	//   _iskj, _iuko_, rzoj_, _həli, 
   {{0x26c000b2,0x7afca17d,0xe4d802dd,0x225c004d}},	//   _huko_, zust, _ءورت_, _vltk_, 
   {{0x26c0633d,0x661ca17e,0x40340139,0x73c0a17f}},	//   _kuko_, lepk, теис, _кәше, 
   {{0xb3800201,0x7afc1709,0x26c00bfa,0x52c4015b}},	//   ናቸውን_, xust, _juko_, রীবৃ, 
   {{0x3eb8a180,0x7afc102e,0x26c0a181,0x9e0409a5}},	//   ört_, vust, _muko_, хчил, 
   {{0x7afc2ad4,0x26c0a182,0x78ac0124,0x3b08025c}},	//   wust, _luko_, ymav, _sqaq_, 
   {{0x7afc2053,0x26c0009f,0x5b24023a,0xc9700092}},	//   tust, _ouko_, ньга, _አስፋው_, 
   {{0x26c0a183,0x291c1918,0x661ca184,0x7afc05c7}},	//   _nuko_, çtan_, kepk, uust, 
   {{0x7afca185,0x27e001c4,0x661c01a6,0x2c6001e1}},	//   rust, _aekn_, jepk, _róde_, 
   {{0x7afca186,0x6724a187,0x26c0a188,0x78ac00cd}},	//   sust, _askj, _auko_, tmav, 
   {{0x26c0a189,0xbca4951b,0x610800ac,0x00000000}},	//   _buko_, _جمعي, _cəli, --, 
   {{0x78aca18a,0x26c0a18b,0x76b8a18c,0x7afc00ac}},	// [cbb0] rmav, _cuko_, длар_, qust, 
   {{0x7aeca18d,0x26c0a18e,0x4b7c0375,0x661c00d5}},	//   _ivat, _duko_, _מאחו, gepk, 
   {{0x7aeca18f,0xa3cc063f,0xb89400c6,0x67240162}},	//   _hvat, _ịbịa_, _للدع, _eskj, 
   {{0x61080cc1,0x26c0a190,0x7aeca191,0x51400131}},	//   _gəli, _fuko_, _kvat, ғдиғ, 
   {{0x26c000ca,0x7bcc01f7,0x42c802dd,0xb60800e2}},	//   _guko_, _mfau, егін_, _pušķ, 
   {{0xcb140a7c,0x610803e3,0xf1a800f1,0x00000000}},	//   רלס_, _zəli, واغه_, --, 
   {{0xddd80118,0x911001d5,0x316801e4,0x0584004e}},	//   entů, استچ, ĝazo_, _бутм, 
   {{0x26c01283,0x7aeca192,0x610800ac,0x00000000}},	//   _yuko_, _ovat, _xəli, --, 
   {{0xef1800d6,0xf1d00032,0x7aec0055,0xcdc001ec}},	//   ємо_, _көйө, _nvat, лапқ, 
   {{0xed5895de,0x7bcca193,0xddd80064,0xee38011c}},	//   доо_, _afau, dotų, фно_, 
   {{0x7aec17ce,0xe7f400bc,0x26045c0e,0x00000000}},	//   _avat, ेलमा_, स्टी_, --, 
   {{0x7bcc003a,0x00000000,0x00000000,0x00000000}},	//   _cfau, --, --, --, 
   {{0x27e0a194,0xcfe400eb,0x00000000,0x00000000}},	//   _rekn_, ফলদন, --, --, 
   {{0x26c0a195,0x7bcc127b,0x61080213,0x7aeca196}},	//   _ruko_, _efau, _səli, _dvat, 
   {{0xfbe003f4,0x26c02e72,0x7aeca197,0x7bcc22df}},	//   _ভারত, _suko_, _evat, _ffau, 
   {{0xac7400db,0xe69401b9,0xbd68005b,0x6c740166}},	//   _جاتش, چلرد, _ярче_, _шулх, 
   {{0x66e4a198,0x661ca199,0x7aeca19a,0x61080213}},	// [cbc0] тоза, tepk, _gvat, _vəli, 
   {{0x9660a19b,0x7ae8038f,0x7cc80118,0x00000000}},	//   акуе, ġett, _měrn, --, 
   {{0x7aec0e8a,0x661ca19c,0x610803be,0x27e0a19d}},	//   _zvat, repk, _təli, _tekn_, 
   {{0x661c083a,0x26c0a19e,0x4a740046,0x2918013c}},	//   sepk, _tuko_, _шықт, _ippa_, 
   {{0xe4ec000d,0x00000000,0x00000000,0x00000000}},	//   _चटकि_, --, --, --, 
   {{0xd24c05d9,0x47f40107,0x00000000,0x00000000}},	//   ينن_, _шӯҳр, --, --, 
   {{0x3e60a19f,0x1540a1a0,0x00000000,0x00000000}},	//   _nòta_, _керм, --, --, 
   {{0xbbc01d8a,0x64a4a1a1,0x00000000,0x00000000}},	//   _एलेक, _раба, --, --, 
   {{0x291801ee,0x7eb805f5,0xe1f003e6,0x104402e8}},	//   _lppa_, нгис_, _نسا_, тящи_, 
   {{0x29180574,0xd6f8037e,0x7aec16a3,0x8fa0399f}},	//   _oppa_, _byオ_, _rvat, шање, 
   {{0x7aeca1a2,0xdce40069,0x3e6000a3,0xe044a1a3}},	//   _svat, _āmēn, _còta_, _инжи, 
   {{0xdef800db,0x7004007b,0xa2c400cd,0x00000000}},	//   _жык_, _مذهل, ादप्, --, 
   {{0x2918a1a4,0x8eb00075,0x2d9005d5,0xcff4011a}},	//   _appa_, _ھەپت, üzer_, _יצאה_, 
   {{0x25fc1b77,0x796801c7,0x8fa02b2e,0x62700210}},	//   _लागी_, _nëwé, _таче, dłok, 
   {{0xe664001f,0x4d240166,0xf4dc00cc,0xe4fc000d}},	//   _መረጋጋ, _аюым_, _ডম্ব, _उमगि_, 
   {{0x29180100,0xd7d800b5,0xc864084c,0x7bcca1a5}},	//   _dppa_, _cmバ_, атуи, _ufau, 
   {{0x29180327,0x7aeca1a6,0xc3240220,0x6364022e}},	// [cbd0] _eppa_, _uvat, _بە_, _mаns, 
   {{0x7c2ca1a7,0x07081987,0xa2c400cd,0x00000000}},	//   _haar, ئيلي_, ादन्, --, 
   {{0x0b940214,0x04c800f1,0xf3f83efd,0x69d8002e}},	//   _مجید, نولي_, енеш_, ñtee, 
   {{0x7c2ca1a8,0x57a40209,0x2c60002e,0x97a40022}},	//   _jaar, _ашга, _kóda_, _аргл, 
   {{0x610800ac,0xdd8400b2,0x00000000,0x00000000}},	//   _məlu, _ڇو_, --, --, 
   {{0xdd84a1a9,0x7c2ca1aa,0x2c600232,0x79680de2}},	//   _هو_, _laar, _móda_, _gëwé, 
   {{0x78bc01d3,0xc1e8008e,0x00000000,0x00000000}},	//   _kisv, тьче_, --, --, 
   {{0x3494a1ab,0x8504014d,0xc0c80063,0xc9b00116}},	//   _сабр, _خوفن, њује_, ﻳﯘﻟﻐ, 
   {{0xdd2c012c,0x7338013d,0x9394009f,0xaf3406c2}},	//   měře, _язар_, _شجرا, اربت, 
   {{0x7cc800bc,0xaf340137,0x00000000,0x00000000}},	//   _věrn, _ۅرتت, --, --, 
   {{0x7c2ca1ac,0xed58a1ad,0x610803b9,0x63700139}},	//   _baar, хон_, _bəlu, _tınç, 
   {{0x7c2ca1ae,0x3e600ba1,0x78bca1af,0xad2400d1}},	//   _caar, _vòta_, _nisv, پىڭى, 
   {{0x7c2ca1b0,0xb1100008,0x80b00eff,0x7ee40022}},	//   _daar, óðfé, _بەيش, _ҩцәе, 
   {{0x78bc004c,0x7c2c0076,0x0d70152f,0x610806be}},	//   _aisv, _eaar, _پختگ, _vəlv, 
   {{0x7c2ca1b1,0x6e20a1b2,0xfe70a1b3,0xa968a1b4}},	//   _faar, melb, _بدن_, хива_, 
   {{0x7c2ca1b5,0x68443d58,0xb920063f,0x2fcc00d5}},	//   _gaar, ынба, lesị_, nceg_, 
   {{0x78bca1b6,0x7ae801f1,0x2c600174,0xe634009d}},	// [cbe0] _disv, šetr, _góda_, лхжэ, 
   {{0x29180ac5,0x6e20a1b7,0xe9d8a1b8,0x2eec022f}},	//   _tppa_, nelb, _яко_, isef_, 
   {{0xd7d8037e,0x7c2ca1b9,0x29181d0e,0xa2a000dc}},	//   _cmビ_, _yaar, _uppa_, गतस्, 
   {{0xd5aca1ba,0x7c2ca1bb,0x6e20a1bc,0x81e00154}},	//   سفن_, _xaar, helb, _থাই_, 
   {{0x6abc0d27,0x4e000316,0x00000000,0x00000000}},	//   _kipf, ललाई_, --, --, 
   {{0x52100212,0x2fcc0142,0x00000000,0x00000000}},	//   йдіт, eceg_, --, --, 
   {{0x6e20a1bd,0x9660a1be,0x6abc4214,0xc45403e6}},	//   delb, _укре, _mipf, _پێشب, 
   {{0x6abc00df,0x0fe0004e,0xe3dc00eb,0xd538011a}},	//   _lipf, бөшү, _ডাকব, _אתלט, 
   {{0xd4640a16,0x1608a1bf,0x6e20178a,0x7c2ca1c0}},	//   _сите_, स्कर_, felb, _raar, 
   {{0x7c2ca1c1,0x6abc00ca,0x5318010f,0x7e74a1c2}},	//   _saar, _nipf, _אומצ, ргох, 
   {{0x6298007c,0x7cc80118,0x2c6000d7,0x00000000}},	//   _ikto, _věro, _sóda_, --, 
   {{0x7c2ca1c3,0xdee405f5,0x6abc004c,0x61e8a1c4}},	//   _qaar, _боди, _aipf, lafl, 
   {{0x6e20a1c5,0x78bca1c6,0x7c2ca1c7,0x6abc01b2}},	//   belb, _risv, _vaar, _bipf, 
   {{0x7c2ca1c8,0x6abc07a8,0x61e8a1c9,0x00000000}},	//   _waar, _cipf, nafl, --, 
   {{0x7c2ca1ca,0x6298037e,0x6720036e,0x00000000}},	//   _taar, _mkto, çojn, --, 
   {{0x20c80016,0x61e803e0,0x78a80135,0x00000000}},	//   _mùi_, hafl, ċevo, --, 
   {{0x78bca1cb,0x20c801fb,0x61e808ce,0xdd2c00bc}},	// [cbf0] _visv, _lùi_, kafl, věře, 
   {{0x6abca1cc,0xd7d8019b,0x68ec003e,0x7bdca1cd}},	//   _gipf, _cmヒ_, bsbd, lbsu, 
   {{0x78bca1ce,0x2eec01ed,0x61e8a1cf,0x2ab8011a}},	//   _tisv, zsef_, dafl, _שמתא, 
   {{0x6abca1d0,0x7afca1d1,0x6e20a1d2,0x62700210}},	//   _zipf, orst, zelb, ołow, 
   {{0x38684ba3,0x6abca1d3,0x2fcc01fa,0x7afc0076}},	//   mhar_, _yipf, vceg_, nrst, 
   {{0x3868a1d4,0x6abc18f7,0x7afca1d5,0x20c8001e}},	//   lhar_, _xipf, irst, _bùi_, 
   {{0x7afc0730,0x6e20a1d6,0x20c801fb,0x21640116}},	//   hrst, velb, _cùi_, ииши_, 
   {{0x3868a1d7,0xb9200521,0xef1802a9,0x7afc00d7}},	//   nhar_, wesị_, вми_, krst, 
   {{0x6e20a1d8,0x629803c1,0x7bdca1d9,0x7afc00b5}},	//   telb, _fkto, dbsu, jrst, 
   {{0x6270068f,0x7bdc002f,0x3868a1da,0x7cc8013a}},	//   dłow, ebsu, hhar_, _těrl, 
   {{0x2eec0491,0x3868a1db,0x6da436da,0x6abc07a9}},	//   ssef_, khar_, рина, _ripf, 
   {{0x6e205475,0x3e60068c,0xc33001d9,0x6abc020c}},	//   selb, _fòto_, _بٕے_, _sipf, 
   {{0x3868a1dc,0x6e20a1dd,0x9d504667,0x610800ac}},	//   dhar_, pelb, منیت, _fəls, 
   {{0x4ea4006c,0x61080213,0x6e20047e,0xad2400db}},	//   _ёрда, _təlt, qelb, _نىتى, 
   {{0x7afca1de,0xfe704111,0x69cc01d3,0x6270012d}},	//   arst, _عده_, rcbe, ałow, 
   {{0x3868a1df,0x6abca1e0,0x00000000,0x00000000}},	//   ghar_, _wipf, --, --, 
  
   {{0x6abca1e1,0x7c040132,0x61e80205,0xdc980115}},	// [cc00] _tipf, _ابىك, yafl, _שיפל, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x38680ea3,0xa524a1e2,0x2c6000c7,0xa9681def}},	//   bhar_, рмед, _jódo_, _рина_, 
   {{0x1d1404ac,0x20c8001e,0xa40400cc,0x00000000}},	//   יקער_, _rùi_, োয্য_, --, 
   {{0x61e8a1e3,0x20c8004d,0xc3c40116,0x2c6001e1}},	//   tafl, _sùi_, _һөлл, _lódo_, 
   {{0xe4d8135f,0xd2a40835,0x00000000,0x00000000}},	//   _لوست_, акче_, --, --, 
   {{0x61e8a1e4,0xa088a1e5,0xa2d400f1,0x6270012d}},	//   rafl, ксиз_, _چيرت, złow, 
   {{0x61e8a1e6,0x14d40bd4,0x7afca1e7,0x20c8004d}},	//   safl, _כולל_, yrst, _vùi_, 
   {{0x63b40209,0x61f40592,0xd18001e0,0x6364022e}},	//   ýynd, _نساء, йләй, _tаnq, 
   {{0x7afc4d3c,0x38680354,0xe0d86f34,0xe194084c}},	//   vrst, zhar_, _авж_, _креэ, 
   {{0x2484a1e8,0x16080c5a,0x21747119,0xdda8059f}},	//   onom_, स्टर_, _туар, ътил_, 
   {{0x2484a1e9,0x7afca1ea,0x6270012d,0x00000000}},	//   nnom_, trst, tłow, --, 
   {{0x248422d0,0x7afca1eb,0x3ed400c6,0x3868a1ec}},	//   inom_, urst, _اقتر, vhar_, 
   {{0xda789dc2,0x386801d9,0xfd3800c6,0x7afc1876}},	//   тям_, whar_, _مكتب_, rrst, 
   {{0x3868a1ed,0x6270068f,0x7afc02fb,0xddd800b0}},	//   thar_, słow, srst, hitū, 
   {{0x1ac800c7,0x621400dc,0x6270012d,0x00000000}},	//   _иуоп_, प्तौ_, płow, --, 
   {{0x3868a1ee,0x5be000bc,0x00000000,0x00000000}},	// [cc10] rhar_, परीव, --, --, 
   {{0x3868a1ef,0x7980063f,0x6ec80037,0x776c0946}},	//   shar_, _ịwul, _हंसु, rzax, 
   {{0x3868a1f0,0xd5b874ac,0x24840e3c,0x673400e4}},	//   phar_, тса_, fnom_, avyj, 
   {{0x2484a1f1,0xb8240137,0x1600012d,0x00000000}},	//   gnom_, _ابدۇ, _लाकर_, --, 
   {{0x47840022,0x8c38008f,0xcc780375,0x47340153}},	//   _дырб, יטאס_, סעדה_, _дняс, 
   {{0x24840134,0x89342be7,0x95c8781e,0x00000000}},	//   anom_, _اعیا, _шума_, --, 
   {{0x5184016c,0x248439ab,0x00000000,0x00000000}},	//   шуда, bnom_, --, --, 
   {{0x2eb40116,0x00000000,0x00000000,0x00000000}},	//   әсис, --, --, --, 
   {{0x76543c17,0x00000000,0x00000000,0x00000000}},	//   _kozy, --, --, --, 
   {{0x765402bd,0xb648105c,0xfbe000cc,0x686c01e1}},	//   _jozy, _ｊｒ_, _ভাগত, _mímọ, 
   {{0xedc400f1,0x31581e24,0x00000000,0x00000000}},	//   لېږي_, _حلاج_, --, --, 
   {{0x816835dd,0xada45f0f,0x00000000,0x00000000}},	//   _труб_, _қайл, --, --, 
   {{0xc5e8015b,0x00000000,0x00000000,0x00000000}},	//   _পাসপ, --, --, --, 
   {{0x248407f5,0xef9003e6,0x6720036e,0x00000000}},	//   znom_, _ویژد, çojm, --, 
   {{0x291ca1f2,0x24849e11,0x00000000,0x00000000}},	//   ïta_, ynom_, --, --, 
   {{0x610803b9,0x09a8a1f3,0x00000000,0x00000000}},	//   _xəlq, _गरीय, --, --, 
   {{0xe618a1f4,0x2484a1f5,0x7654a1f6,0xe7a8a1f7}},	// [cc20] лда_, vnom_, _bozy, увал_, 
   {{0x7654a1f8,0xa2c400cd,0x00000000,0x00000000}},	//   _cozy, ादस्, --, --, 
   {{0x3ea000e4,0xd61800c7,0x00000000,0x00000000}},	//   _êite_, ыхтә_, --, --, 
   {{0x24847bad,0x6d4406af,0x00000000,0x00000000}},	//   unom_, _àhau, --, --, 
   {{0x64a40fc0,0x76f40139,0x6d4408a5,0x00000000}},	//   _ҳава, _мярх, _áhaf, --, 
   {{0xf2c40220,0x765400a2,0xa1840139,0x00000000}},	//   ісін, _gozy, йыйл, --, 
   {{0x64a4a1f9,0xc5e4a1fa,0x96600139,0x2a780064}},	//   _гава, गरीय_, _экре, _mmpb_, 
   {{0x245c00e4,0xd1b0030f,0x9cc800fb,0x00000000}},	//   _oïmi_, سینک, ҫына_, --, 
   {{0x765401d5,0x81bc00de,0x00000000,0x00000000}},	//   _yozy, _paēs, --, --, 
   {{0x5754011a,0x76540166,0x00000000,0x00000000}},	//   צביע_, _xozy, --, --, 
   {{0xe0d830ba,0x77280092,0xa008007b,0x610803b9}},	//   _све_, ስተሳሰ, _مقال_, _təlq, 
   {{0x8cb801d9,0x132c0092,0x00000000,0x00000000}},	//   ٝدُس_, _በልጅነ, --, --, 
   {{0x50180375,0x8ae40024,0x2a780064,0x2c08043e}},	//   _תודו, зісл, _bmpb_, _वारं_, 
   {{0x60c0a1fb,0x6fa4007b,0x9a84a1fc,0x09e40107}},	//   _hiom, _بإمك, сумл, зоён, 
   {{0x7654a1fd,0x60c0a1fe,0x4e14011a,0x00000000}},	//   _rozy, _kiom, _החוב_, --, 
   {{0x660c005a,0x60c001f7,0xb6c801d3,0x00000000}},	//   _acbk, _jiom, لائے_, --, 
   {{0x9ba004a9,0x7654068f,0x60c0a1ff,0x4544001f}},	// [cc30] _رەسى, _pozy, _miom, _የሚከበ, 
   {{0x2a78070d,0x60c0a200,0x00000000,0x00000000}},	//   _gmpb_, _liom, --, --, 
   {{0xa6e00162,0x00000000,0x00000000,0x00000000}},	//   óðro, --, --, --, 
   {{0x60c0a201,0x5edc02f5,0x672c005b,0x1bf8a202}},	//   _niom, _মিনে, änjä, ्लिल_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x60c0a203,0x332c0139,0x6d4402d2,0x62700210}},	//   _aiom, _vsex_, _áhag, dłos, 
   {{0x60c0a204,0xd34400f2,0x610806be,0x7168009d}},	//   _biom, _گیشه_, _qəlp, райг_, 
   {{0x60c0a205,0x332c0166,0x28bc00cd,0xa2c400cd}},	//   _ciom, _tsex_, ्दयि, ादश्, 
   {{0x60c0a206,0x62700034,0x5344a207,0x00000000}},	//   _diom, głos, _ухва, --, 
   {{0xa2c4090a,0x00000000,0x00000000,0x00000000}},	//   ादर्, --, --, --, 
   {{0x60c00170,0xf3f80276,0x00000000,0x00000000}},	//   _fiom, _alţi_, --, --, 
   {{0x320803f9,0x60c0a208,0x409402dd,0x1ee80133}},	//   ɗaya_, _giom, _еріт, _چونی_, 
   {{0x7d040421,0x6270012d,0xffd400f1,0x00000000}},	//   _āise, płot, _رغند, --, 
   {{0x0dc8a209,0x60c01d01,0xdc240154,0x9b84075e}},	//   _суди_, _ziom, যাগস_, تچىل_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x60c0014a,0x3858858f,0xa6e401a9,0x00000000}},	//   _xiom, брую_, жжал, --, 
   {{0xab281638,0xa5d82088,0xf7d40131,0x1864a20a}},	// [cc40] _топа_, لبار_, _ﭘﻪﻗﻪ, цати_, 
   {{0x3e600ba1,0x9f44030a,0x6a84084c,0xeab0007b}},	//   _còth_, _cdoù_, _флоа, _تعب_, 
   {{0x24080209,0xe5780120,0x24f402e8,0x00000000}},	//   инжи_, јзе_, ючар, --, 
   {{0xa5d81d7d,0x9f44030a,0x1414007b,0x00000000}},	//   _प्रौ, _edoù_, قيمة_, --, 
   {{0xd12c03e6,0x48f4012c,0xa2280395,0x00000000}},	//   ێمه_, ौंको_, ижда_, --, 
   {{0x60c0a20b,0xc5f001e2,0x00000000,0x00000000}},	//   _siom, _سړئ_, --, --, 
   {{0x60c0a20c,0x20680075,0x6270012d,0x00000000}},	//   _piom, ишип_, włos, --, 
   {{0xd014084c,0x00000000,0x00000000,0x00000000}},	//   офь_, --, --, --, 
   {{0x25a81408,0x8fa00063,0x00000000,0x00000000}},	//   _करुण, маће, --, --, 
   {{0x626400f7,0x2cb0058a,0x5be0085c,0x752c010e}},	//   _بارق, _ahyd_, पर्व, _çozý, 
   {{0xa068a20d,0x60c04ba3,0x7c34a20e,0xa0a40024}},	//   _кажа_, _tiom, пенх, _дажд, 
   {{0x9b6807d6,0x2cb0015d,0x60d8035a,0x715801f0}},	//   ашга_, _chyd_, _ittm, _урус_, 
   {{0x2c600332,0xffa4004e,0x8ccc000d,0x386c0171}},	//   _módh_, _элдү, _ठूठो, _ķer_, 
   {{0x9c1002e3,0x6288a20f,0x7cc80055,0x9fe00154}},	//   _nọve, nnfo, _aśre, _যায়গ, 
   {{0x6288a210,0xf8b80184,0x00000000,0x00000000}},	//   info, йөм_, --, --, 
   {{0x81ac0154,0x62880112,0xdd9001ee,0x7d085b4b}},	//   _গলা_, hnfo, _наҙы, muds, 
   {{0x3880001f,0xa3dc000d,0x62880158,0x7d0800b5}},	// [cc50] _ከእርሱ_, _द्ध_, knfo, luds, 
   {{0x213c06f2,0x00000000,0x00000000,0x00000000}},	//   _orth_, --, --, --, 
   {{0x7d08a211,0x73881945,0x5fc874f6,0x668001d5}},	//   nuds, әрең_, ाखाल, ریفل, 
   {{0x61f80077,0x846402e8,0x00000000,0x00000000}},	//   _adtl, мъче, --, --, 
   {{0x4c3c04ac,0x9324034c,0x60d8a212,0xd3780261}},	//   יגאצ, تران, _attm, јче_, 
   {{0x7d08037e,0x6288072b,0x981400e5,0xddd801ef}},	//   kuds, gnfo, _ابھا, ditů, 
   {{0x8234a213,0x00000000,0x00000000,0x00000000}},	//   برنا, --, --, --, 
   {{0x628800f3,0x7d083d54,0x00000000,0x00000000}},	//   anfo, duds, --, --, 
   {{0x213c0165,0x60d80fac,0x7058023b,0x09a8012c}},	//   _erth_, _ettm, _қадр_, _गर्य, 
   {{0x3134855f,0x00000000,0x00000000,0x00000000}},	//   _незр, --, --, --, 
   {{0x60d80083,0xd7d8037e,0x9980013a,0x00000000}},	//   _gttm, _cmル_, dejů_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xddd801ef,0x00000000,0x00000000,0x00000000}},	//   citů, --, --, --, 
   {{0x955c02d3,0xbe8000c7,0x6f08a214,0x00000000}},	//   ሰርትን_, _ақьи, muec, --, 
   {{0xd9401685,0x6f08a215,0x3ea00022,0xdb1c0118}},	//   нери, luec, _êita_, ěvák, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3e600699,0x6f08a216,0x62882f50,0x00000000}},	// [cc60] _sòti_, nuec, ynfo, --, 
   {{0x3e6000b0,0x00000000,0x00000000,0x00000000}},	//   _pòti_, --, --, --, 
   {{0xa9a455d2,0x68440024,0x62882b96,0xf204012d}},	//   _хинд, _енна, vnfo, _राज़_, 
   {{0x3e60067c,0x2908a217,0xe3b800ee,0x628855fd}},	//   _vòti_, muba_, ббе_, wnfo, 
   {{0x2908a218,0x27f00050,0x2c1c00dc,0xf1dc00bc}},	//   luba_, mayn_, य्यं_, नुभन, 
   {{0x6f0804c4,0x27f0a219,0x628809c2,0xdb2006af}},	//   duec, layn_, unfo, érég, 
   {{0x2908a21a,0x6288a21b,0x51f0036b,0x00d002dd}},	//   nuba_, rnfo, رسور, _ﻗﺎﺷﻘ, 
   {{0x7d08a21c,0x27f00050,0xe2c81377,0x6364022e}},	//   vuds, nayn_, _глад_, _mаnz, 
   {{0x213c0f7b,0x29085755,0x2c600162,0x2d90045f}},	//   _wrth_, huba_, _gódi_, ûzen_, 
   {{0x2908a21d,0x27f00050,0x528001ce,0x7d082611}},	//   kuba_, hayn_, _згуб, tuds, 
   {{0x29089b91,0x27f00067,0x60240139,0x3c940108}},	//   juba_, kayn_, _нджа, динё, 
   {{0x7d0804ce,0x2908a21e,0x6f08003a,0x27f0a21f}},	//   ruds, duba_, buec, jayn_, 
   {{0x27f001d9,0x6f089e69,0x7d0800b5,0x7f580276}},	//   dayn_, cuec, suds, _фалс_, 
   {{0x7d0800b5,0x2908a220,0x1b0c00cc,0x00000000}},	//   puds, fuba_, িবলে_, --, 
   {{0x2908a221,0x8bec015b,0x3c5800a8,0x27f00067}},	//   guba_, _কারন_, _микэ_, fayn_, 
   {{0x27f0a222,0x00000000,0x00000000,0x00000000}},	//   gayn_, --, --, --, 
   {{0xcc340597,0xc32402f5,0xe7ec0034,0x41cc01bc}},	// [cc70] _سريع, পিডি_, _ज़रा_, ाशास, 
   {{0x2908a223,0x95c8035b,0x291c025c,0x00000000}},	//   buba_, суаа_, ħtar_, --, 
   {{0x2908a224,0x27f00014,0x6f080036,0x47840166}},	//   cuba_, bayn_, zuec, _җыяб, 
   {{0x27f00014,0x6b8067e9,0x8d9c0092,0x00000000}},	//   cayn_, _žogi, _ማዕቀፍ_, --, 
   {{0x8c1c011a,0x00000000,0x00000000,0x00000000}},	//   מואי, --, --, --, 
   {{0x3f981b0d,0x20000321,0x78a80135,0xb594009d}},	//   ğrul_, ókin_, ċevu, _жигш, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x527450c9,0x1d900023,0x15e80073,0x00000000}},	//   _کارز, _ያዕቤጽ_, टरवर_, --, 
   {{0x29082da1,0xd20000ee,0xe7ec0210,0x00000000}},	//   zuba_, _зүлк, जरता_, --, 
   {{0x6f08a225,0x27f0a226,0x2908a227,0xda1c00e1}},	//   ruec, zayn_, yuba_, म्मत_, 
   {{0x90e40502,0x2908a228,0xed58a229,0x27f00067}},	//   _رسان, xuba_, цон_, yayn_, 
   {{0x27f00014,0x29086a4d,0x00000000,0x00000000}},	//   xayn_, vuba_, --, --, 
   {{0x6f08a22a,0x25a8a22b,0x2908192e,0x00000000}},	//   quec, _कर्ण, wuba_, --, 
   {{0x2908a22c,0x27f0a22d,0xceb81f5a,0x00000000}},	//   tuba_, wayn_, _уље_, --, 
   {{0x27f0a22e,0x00000000,0x00000000,0x00000000}},	//   tayn_, --, --, --, 
   {{0x2908a22f,0x7c940006,0x7c840114,0x00000000}},	//   ruba_, _прыц, _пуње, --, 
   {{0x98a0a230,0x27f001d9,0x2908a231,0xf990004b}},	// [cc80] тите, rayn_, suba_, نبې_, 
   {{0x27f0a232,0xa5080212,0x00000000,0x00000000}},	//   sayn_, жежа_, --, --, 
   {{0x2908a233,0xd36c411c,0x00000000,0x00000000}},	//   quba_, یهم_, --, --, 
   {{0x27f001d9,0xe3a801c6,0x7ae8054e,0x25bc0419}},	//   qayn_, окед_, ţete, _útlm_, 
   {{0xd87401d9,0x93c800dd,0x23b8007b,0x00000000}},	//   _آمُت_, زانہ_, آداب_, --, 
   {{0x91a80131,0xa3dc0950,0xe7d816ae,0x00000000}},	//   ﺷﻘﯩﻼ, _द्र_, युरप, --, 
   {{0x6f0c01e4,0xa0200790,0x00000000,0x00000000}},	//   _ĥaca, _çökt, --, --, 
   {{0x2c600122,0xb73403b2,0xd5e80208,0x80b400db}},	//   _kódu_, _íøðr, _đỉn, رەشش, 
   {{0x73c00184,0x2c6002f0,0xe1f80153,0x2d9803e0}},	//   _йәше, _jódu_, _мга_, şsel_, 
   {{0xe2441d57,0x7cc800cd,0x2c60219b,0x7cf4032e}},	//   _تخري, _aśra, _módu_, _nýrá, 
   {{0x7870713c,0x4a2c0327,0x20540395,0xb1f400f1}},	//   _håve, _སྲེལ_, _отдр, _سينګ, 
   {{0x7870248f,0x69a0000d,0x00000000,0x00000000}},	//   _kåve, _गड़ी, --, --, 
   {{0x7cf40579,0xcf9400d8,0x139800df,0x00000000}},	//   _býrá, _ојш_, ַבלע, --, 
   {{0xb0601059,0x00000000,0x00000000,0x00000000}},	//   _ääre, --, --, --, 
   {{0x78702dba,0xc984a234,0xaf4800cf,0x98c4030d}},	//   _låve, вути, _وشۇل_, дсал, 
   {{0x9ba000d1,0x00000000,0x00000000,0x00000000}},	//   _ۋەھى, --, --, --, 
   {{0x9c1001f2,0x7bcca235,0x7870143a,0x00000000}},	// [cc90] _fọre, _igau, _nåve, --, 
   {{0xb8f42158,0x7aeca236,0xb90411ba,0x34b800cd}},	//   _হব_, _iwat, _নি_, ेद्द, 
   {{0x7bcca237,0x7aeca238,0x25dc05f9,0x63b40022}},	//   _kgau, _hwat, गड़ी_, ҭахӡ, 
   {{0xd5dc11bc,0xba04001f,0x97c4007b,0x81ac00cc}},	//   _प्रज, _ጎራ_, _يتحم, _গলং_, 
   {{0x38680c09,0x7bcc0418,0x2c600162,0xc7c40b01}},	//   mkar_, _mgau, _gódu_, _асри, 
   {{0x7aeca239,0x3868a23a,0x787000cc,0x3e600ba1}},	//   _mwat, lkar_, _dåve, _mòts_, 
   {{0x7aeca23b,0x64c89543,0x7bcc0607,0x3e60067c}},	//   _lwat, िदृश, _ogau, _lòts_, 
   {{0x7bcca23c,0x3868a23d,0x7aec7e70,0x2f548040}},	//   _ngau, nkar_, _owat, етос, 
   {{0x3868a23e,0x787000fe,0x7aec0521,0xaec4a23f}},	//   ikar_, _gåve, _nwat, нбил, 
   {{0x3868a240,0x52c8190c,0xd1480244,0x5edc00eb}},	//   hkar_, ादीस, _وشان_, _মিশে, 
   {{0x7aeca241,0x3868a242,0x8264009f,0x00000000}},	//   _awat, kkar_, _جهلن, --, 
   {{0xeb985296,0x7aec44c8,0x3e600ba1,0x386801e6}},	//   зим_, _bwat, _bòts_, jkar_, 
   {{0x3868a243,0x00000000,0x00000000,0x00000000}},	//   dkar_, --, --, --, 
   {{0x7aec43a5,0x7bcca244,0x38680af9,0x00000000}},	//   _dwat, _egau, ekar_, --, 
   {{0x7aeca245,0x386801f5,0x68680023,0x2f1802e2}},	//   _ewat, fkar_, _ደለይቲ_, lèg_, 
   {{0xddc80100,0x3868a246,0xeb9805f5,0x7aec007f}},	//   _anfň, gkar_, _ний_, _fwat, 
   {{0x7aeca247,0x3e600ba1,0xa6c86e0c,0x2f18033b}},	// [cca0] _gwat, _gòts_, سوال_, nèg_, 
   {{0xdb9823e4,0x38680198,0x85b400d1,0x00000000}},	//   _מספר, akar_, вәбч, --, 
   {{0x7870a248,0xd7d8037e,0x64c82435,0x386803e3}},	//   _såve, _kmレ_, िदेश, bkar_, 
   {{0x386804f3,0x66e46145,0x7870a249,0xddc8033b}},	//   ckar_, _пома, _påve, _enfň, 
   {{0xd7d8037e,0x93401f42,0x52d40212,0xe8bc0829}},	//   _mmレ_, лнце, емію_, ्दीच, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x40340064,0x20c4a24a,0x00000000,0x00000000}},	//   вейс, нсиг, --, --, 
   {{0xddd80f8b,0x26c80014,0x2f18007f,0xb24401e0}},	//   ditš, _hibo_, fèg_, емәһ, 
   {{0x63043f0b,0x26c8a24b,0x2054053f,0x44242238}},	//   _سوال, _kibo_, _үтер, _ibm_, 
   {{0xdbf80714,0x7aeca24c,0x2484a24d,0xe0cc00bd}},	//   ्ल्ड_, _rwat, liom_, _রবীন, 
   {{0x8140168d,0x3868a24e,0xbec80064,0x00000000}},	//   _ڕۆژن, ykar_, _neūž, --, 
   {{0x26c8a24f,0x3e60180f,0x7aec02e2,0x2484a250}},	//   _libo_, _pòts_, _pwat, niom_, 
   {{0x291802d1,0x44249910,0x3868a251,0xf1dc00dc}},	//   _aqpa_, _mbm_, vkar_, नुवन, 
   {{0x26c8a252,0x7aec8cf6,0x3e60067c,0x7bcc0098}},	//   _nibo_, _vwat, _vòts_, _wgau, 
   {{0x3868a253,0x6a60002d,0x7bcc07de,0x3d2801d5}},	//   tkar_, _rôft, _tgau, _آتتی_, 
   {{0x26c800f3,0x38680014,0x7bcca254,0x3e60004e}},	//   _aibo_, ukar_, _ugau, _tòts_, 
   {{0x3868a255,0x26c8a256,0x7aeca257,0x2484a258}},	// [ccb0] rkar_, _bibo_, _uwat, diom_, 
   {{0x26c8a259,0x7c3c2ab7,0xc7c4a25a,0x95e802ab}},	//   _cibo_, ldsr, усси, टरेट_, 
   {{0x4424a25b,0x26c8a25c,0x3868a25d,0x00000000}},	//   _bbm_, _dibo_, pkar_, --, 
   {{0x442401f7,0x2484a25e,0x2ab4005c,0xb6f40114}},	//   _cbm_, giom_, ræbe_, _измј, 
   {{0x4424a25f,0x7c3ca260,0x78ac0139,0x2ab4005c}},	//   _dbm_, idsr, mlav, sæbe_, 
   {{0xe360a261,0x26c80280,0x7cc80034,0xd7d804ce}},	//   ркши, _gibo_, _ośro, _mmロ_, 
   {{0x78ac011c,0x24840b4b,0xa2c0a262,0x00000000}},	//   olav, biom_, рәтк, --, 
   {{0x7c3c037e,0x78ac05d5,0x3eac01f5,0x26c8022e}},	//   jdsr, nlav, eldt_, _zibo_, 
   {{0x3ddc002d,0x78aca263,0x26c8013e,0xe4c80014}},	//   _bfvw_, ilav, _yibo_, _زبٲن_, 
   {{0x7c3c0a85,0x78aca264,0xed44a265,0x318401af}},	//   edsr, hlav, вноп, _итең, 
   {{0x78aca266,0x3014a267,0xc290a268,0xfd5000dc}},	//   klav, _адер, _دیوب, _kukṣ, 
   {{0x28d00d2c,0x7c9c001f,0xc05800d4,0x00000000}},	//   _दूषि, _ሊኖረው_, _піч_, --, 
   {{0x78aca269,0x207800c8,0xd7d800b5,0x7ff4007b}},	//   dlav, _קאנא, _cmロ_, _إسما, 
   {{0x2484a26a,0x6f08a26b,0x7c3c02d0,0x00000000}},	//   ziom_, mrec, adsr, --, 
   {{0x78aca26c,0x9d5000aa,0x6f08a26d,0x26c8a26e}},	//   flav, _ننوت, lrec, _ribo_, 
   {{0x26c8a26f,0x6d40017a,0x2484a270,0x00000000}},	//   _sibo_, mvla, xiom_, --, 
   {{0x26c808cd,0x6f08a271,0xa6c805f5,0x4424a272}},	// [ccc0] _pibo_, nrec, длаа_, _rbm_, 
   {{0x6d40248d,0x78aca273,0xaab85085,0x610806be}},	//   ovla, alav, _تدبر_, _təlx, 
   {{0x26c8a274,0x6f08097d,0x6d400b4f,0x78aca275}},	//   _vibo_, hrec, nvla, blav, 
   {{0x6d401570,0x78aca276,0xfd5000b8,0xa2e402a9}},	//   ivla, clav, _cukṣ, водд, 
   {{0x26c8a277,0x2484a278,0x3eac2142,0x2c18256a}},	//   _tibo_, riom_, yldt_, _भानू_, 
   {{0x6f08a279,0x5b7800c8,0x442405b1,0xe50406f6}},	//   drec, ורנא, _wbm_, _لبري, 
   {{0x44240261,0x6f08a27a,0x7870168c,0x6d4001f5}},	//   _tbm_, erec, _håva, jvla, 
   {{0x6f08a27b,0x6d4016a3,0xc0340114,0xc10400ec}},	//   frec, dvla, униј, نوڻي, 
   {{0x6f08a27c,0x22143849,0x6d40a27d,0x1418123b}},	//   grec, _афер, evla, _קומב, 
   {{0xa80407c4,0x2908151c,0x78aca27e,0x5f900075}},	//   ldığ, krba_, zlav, лиқт, 
   {{0x6f0800a8,0x78700158,0x78aca27f,0x6d400549}},	//   arec, _låva, ylav, gvla, 
   {{0x6f08a280,0x9ff87677,0xa80407c4,0x69dca281}},	//   brec, _آراء_, ndığ, _afpe, 
   {{0x6f08a282,0x7c3c74c1,0x6d402d1e,0x2908058a}},	//   crec, rdsr, avla, erba_, 
   {{0xc60800bd,0x6d400010,0x00000000,0x00000000}},	//   র্তা_, bvla, --, --, 
   {{0xd7f8a283,0x20fc0135,0x00000000,0x00000000}},	//   дуз_, nċi_, --, --, 
   {{0x68fc0208,0x7b180818,0x00000000,0x00000000}},	//   _dvpd, _зоир_, --, --, 
   {{0x78aca284,0xcc8800c6,0x76b8a285,0xcb0801c6}},	// [ccd0] rlav, _جنيه_, елар_, _ихэд_, 
   {{0x78aca286,0xd5643b5f,0xfaf80006,0x78700267}},	//   slav, ктеп, šūs_, _dåva, 
   {{0x6f080e04,0x764001a8,0x20fc0135,0xb4cc11a6}},	//   zrec, _ólym, jċi_, रदे_, 
   {{0x6f08a287,0x78700fac,0x7afc035a,0x00000000}},	//   yrec, _fåva, osst, --, 
   {{0xd5bc005f,0x88580116,0x787001e3,0x6f080334}},	//   _šādi_, _рияс_, _gåva, xrec, 
   {{0x7afc5475,0x6f08a288,0xf678008f,0x6d40007c}},	//   isst, vrec, _טאָמ, yvla, 
   {{0x68e00034,0x7afc035a,0xd4c4010a,0x00000000}},	//   _łodz, hsst, _асап, --, 
   {{0x7afc62ee,0xa3cc1a2a,0xa5600014,0x00000000}},	//   ksst, रशः_, _دۯمن, --, 
   {{0x7afc13e8,0x14fc0150,0x6d4001f5,0x6f08382c}},	//   jsst, _ءﺗﺎﻧ, wvla, urec, 
   {{0xee38a289,0x6d40057b,0xd7d8037e,0xa80405d1}},	//   хно_, tvla, _mlパ_, mdış, 
   {{0x6f08a28a,0x7afc127b,0xd138074d,0x6d400100}},	//   srec, esst, _юха_, uvla, 
   {{0x6d40a28b,0x6f08a28c,0x7afca28d,0x7fd40220}},	//   rvla, prec, fsst, _кіші, 
   {{0x30140022,0x69dc0175,0xff500133,0x6dc000cf}},	//   _адҵр, _pfpe, _وخه_, _گۅدۅ, 
   {{0xa8044a4a,0x6d400373,0x00000000,0x00000000}},	//   zdığ, pvla, --, --, 
   {{0xa8043535,0x7afc017a,0x6dc000cf,0x00000000}},	//   ydığ, asst, _دۅدۅ, --, 
   {{0x7afca28e,0x7bdca28f,0xa8040213,0x2908025c}},	//   bsst, ccsu, xdığ, rrba_, 
   {{0x290805be,0x64a4a290,0x7afc0857,0xa8840c75}},	// [cce0] srba_, қада, csst, _ەلجى, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa80400ac,0x63b000c7,0x00000000,0x00000000}},	//   tdığ, әалӡ, --, --, 
   {{0x32d8007f,0x06e800fe,0x00000000,0x00000000}},	//   _bèy_, _পিঠি, --, --, 
   {{0xa8044a4a,0x8284036b,0x57f80375,0x48c401ee}},	//   rdığ, ақад, _אלכו, _бәҡа, 
   {{0x32d802e2,0xe5a4a291,0x42540244,0x68e00210}},	//   _dèy_, _биги, شنبر, _łody, 
   {{0x46d8000d,0x61e8a292,0xa8040213,0x00000000}},	//   _भूतह, rbfl, pdığ, --, 
   {{0x64a4a0c6,0x36f4003d,0x7afca293,0x32d802bd}},	//   _саба, _བསྩལ_, ysst, _fèy_, 
   {{0xe1f00244,0xd1800131,0x7f9400d1,0xe2987765}},	//   _هسا_, иләй, рапх, _заа_, 
   {{0xe0440075,0xf08801d5,0xd734011a,0x00000000}},	//   _әнди, _یئنه_, נטית_, --, 
   {{0x6288a294,0xd24c0050,0xa1941677,0x7afc045a}},	//   mifo, _رۆٹ_, _сјај, wsst, 
   {{0x6288a295,0x00000000,0x00000000,0x00000000}},	//   lifo, --, --, --, 
   {{0x7afca296,0x00000000,0x00000000,0x00000000}},	//   usst, --, --, --, 
   {{0x6288a297,0x7afca298,0x4c940150,0x00000000}},	//   nifo, rsst, _қиыс, --, 
   {{0xd5e8004d,0x6b80010e,0x5cc401a9,0xc0d40092}},	//   _đìn, _ýogn, _йсиз, _የዶሃ_, 
   {{0x6288a299,0xda142d3b,0x383400d8,0x00000000}},	//   hifo, _तावत_, јнар, --, 
   {{0x35f4a29a,0x6288a29b,0x4c1401ec,0x9a84010b}},	// [ccf0] ипар, kifo, _ابىس, _бунл, 
   {{0x32d80699,0x0708088c,0x00000000,0x00000000}},	//   _rèy_, ايلي_, --, --, 
   {{0xceb01a4c,0x32d8007f,0x00000000,0x00000000}},	//   ציע_, _sèy_, --, --, 
   {{0xf48401ed,0x62880ea0,0x14c80022,0xa8040205}},	//   جائی, eifo, хызи_, tdış, 
   {{0x73c40598,0x733400d1,0x00000000,0x00000000}},	//   рәве, شىغا, --, --, 
   {{0x45d4a29c,0x15a800a7,0x62882fda,0x32d8007f}},	//   _горс, _зъби_, gifo, _vèy_, 
   {{0x93e401a9,0xc8c802f2,0x00000000,0x00000000}},	//   _бўзл, _جوێن_, --, --, 
   {{0x34941ee3,0xf8b42a05,0xaf041d0d,0x62882437}},	//   _табр, ंतिय, апил, aifo, 
   {{0x3254a29d,0xfba40574,0x628801fb,0x00000000}},	//   _квар, _गुलम, bifo, --, 
   {{0x6288a29e,0xddc80100,0x016401d9,0xc21c20f0}},	//   cifo, _enfō, _گُمَ, _नायब_, 
   {{0xb03434d8,0xc2c4188d,0x32040076,0xc1043592}},	//   _внеш, _ايلي, _idly_, _هولي, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd7d800b5,0xf1d807f7,0xeab005af,0x00000000}},	//   _llビ_, _ढलान, قعآ_, --, 
   {{0x7b8002dd,0x00000000,0x00000000,0x00000000}},	//   яғыд, --, --, --, 
   {{0x8d7402f2,0x19842377,0x66180139,0x291ca29f}},	//   _حاشا, абри_, _ötki, îta_, 
   {{0x6288a2a0,0xd5e80051,0x00000000,0x00000000}},	//   zifo, _đín, --, --, 
   {{0xe6189794,0xa684a2a1,0xcc8800aa,0x4ab4010b}},	// [cd00] кда_, алад, _لنډه_, _гөвр, 
   {{0x63a402bf,0xaa4400f7,0x628801ef,0xb8d400d1}},	//   _økni, _ئندى, xifo, شتېش, 
   {{0x78700267,0x332c4c28,0x15400395,0x64a4009d}},	//   _gåvo, _apex_, жехм, аажа, 
   {{0xf98000c2,0x3204a2a2,0x628801e2,0x19b4123b}},	//   _эҳсо, _adly_, wifo, _כפיר_, 
   {{0x6288a2a3,0x23346c00,0xa6e003b2,0x00000000}},	//   tifo, рхер, óðdo, --, 
   {{0x11d00131,0x7790030f,0x00000000,0x00000000}},	//   يتىد, _عیلا, --, --, 
   {{0x6288a2a4,0xbb4c02dd,0x6ef400b8,0x00000000}},	//   rifo, _ﺍﻷﻤ_, _āsiṣ, --, 
   {{0x6288a2a5,0xfff80424,0xd464a2a6,0xa348020f}},	//   sifo, اکات_, _кисе_, _изба_, 
   {{0x6288026c,0x64400007,0xe2c80022,0xd46406ed}},	//   pifo, mdoi, _алад_, _тите_, 
   {{0x6440a2a7,0xd3340375,0xddc801d3,0x628806be}},	//   ldoi, _דרמה_, _sofő, qifo, 
   {{0x644001f4,0x00000000,0x00000000,0x00000000}},	//   odoi, --, --, --, 
   {{0x8d141968,0xc0f80092,0xd00400d8,0x00000000}},	//   گزیر_, ወከል_, _веце_, --, 
   {{0x6440a2a8,0x9e64a2a9,0x9d1400eb,0x00000000}},	//   idoi, _پاشن, ়বেন_, --, 
   {{0x6440a2aa,0x4ef80302,0xdd9001ec,0x00000000}},	//   hdoi, _יהדו, _қақы, --, 
   {{0x2d90002d,0xdcb80108,0xe7780022,0x00000000}},	//   ûzet_, _ищи_, ҳатә_, --, 
   {{0x9be401ec,0xdb6800c0,0x00000000,0x00000000}},	//   _тікк, _арол_, --, --, 
   {{0xcc3400b2,0x6440062c,0x629800a2,0x78bc02d0}},	// [cd10] _ذريع, ddoi, _ojto, _vhsv, 
   {{0x7a382b97,0x644001f4,0xcfc80150,0x00000000}},	//   _спор_, edoi, _ﻗﺭﻴﺒ, --, 
   {{0x20040083,0x7cc80055,0x00000000,0x00000000}},	//   _odoi_, _aśri, --, --, 
   {{0x293404ac,0x200410e1,0x36040214,0x644002d0}},	//   _פארן_, _ndoi_, _گوسف, gdoi, 
   {{0x934000f7,0x00000000,0x00000000,0x00000000}},	//   تىشۇ, --, --, --, 
   {{0x96440323,0x20040ac5,0x64400077,0xef183edf}},	//   _тэмд, _adoi_, adoi, ҳми_, 
   {{0x1b2000cc,0x28bc11a0,0x00000000,0x00000000}},	//   মিটে_, ्दचि, --, --, 
   {{0x96d80316,0xef181a51,0xf9940051,0x00000000}},	//   _बढाउ, гми_, _đầm_, --, 
   {{0x3374a2ab,0x20040142,0x776c022e,0x920400ef}},	//   _угар, _ddoi_, nyax, ecāš, 
   {{0xa6e00436,0x2004a2ac,0x59c408dd,0x00000000}},	//   áðin, _edoi_, लधार, --, 
   {{0xada4a2ad,0x6da44df9,0x63bc033f,0xbf640ed8}},	//   санл, сина, ępne, مدیو, 
   {{0x9f440165,0x06e8015b,0xeeb800fd,0x7d1c08c2}},	//   _leoù_, _পিসি, _өлеш_, àrsa, 
   {{0xd7a40406,0xafc40150,0x00000000,0x00000000}},	//   _कुलच, _ايشى, --, --, 
   {{0x776c0564,0x5edc009e,0x00000000,0x00000000}},	//   dyax, _মিচে, --, --, 
   {{0x6b4c0109,0x644000ad,0x244c022e,0x00000000}},	//   _bôgô, ydoi, kаmа_, --, 
   {{0xe738a2ae,0x64400007,0x00000000,0x00000000}},	//   леб_, xdoi, --, --, 
   {{0x399c006a,0x78700158,0x6440022e,0x00000000}},	// [cd20] _pâsï_, _gåvm, vdoi, --, 
   {{0xe5a4004e,0xaa2c0108,0x00000000,0x00000000}},	//   бизи, älää_, --, --, 
   {{0x9f440165,0xd6cc00c6,0xa5c4033f,0x58d006ed}},	//   _deoù_, رقم_, _opóź, _ноќт, 
   {{0xdbd40e78,0xd36c0451,0x00000000,0x00000000}},	//   _mäßi, ڙهن_, --, --, 
   {{0x6440a2af,0x60e001ec,0x00000000,0x00000000}},	//   rdoi, _ﺍﻨﺘﺸ, --, --, 
   {{0x644000d8,0x40e40131,0x93400395,0x00000000}},	//   sdoi, осиғ, янче, --, 
   {{0xdfd802e8,0x41340092,0x2bf800cd,0x00000000}},	//   лъп_, _ኮሚኒኬ, ्णां_, --, 
   {{0xc0d40020,0x92e400cc,0x00000000,0x00000000}},	//   ጨረሻ_, _ভিৰ_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x61f802d0,0x00000000,0x00000000,0x00000000}},	//   _ietl, --, --, --, 
   {{0x61f8a2b0,0x00000000,0x00000000,0x00000000}},	//   _hetl, --, --, --, 
   {{0x61f84d11,0x60d8047e,0x776c0009,0x2bac0073}},	//   _ketl, _hutm, xyax, _घडणा, 
   {{0x60d801b9,0x02a800cd,0x00000000,0x00000000}},	//   _kutm, गविभ, --, --, 
   {{0x61f8a2b1,0x9f440489,0x52c400fe,0x00000000}},	//   _metl, _reoù_, ৰীকৃ, --, 
   {{0x61f81917,0x60d8a2b2,0x00000000,0x00000000}},	//   _letl, _mutm, --, --, 
   {{0xdeb8044e,0x60d8016d,0x3c2c022e,0x00000000}},	// [cd30] _ሰሙን_, _lutm, mоv_, --, 
   {{0x61f8193f,0x7c2c1d0e,0xb59402e8,0xc0d40092}},	//   _netl, _hbar, оизш, ጨረስ_, 
   {{0x60d8a2b3,0x7c2c031c,0x73d80334,0xddd800e5}},	//   _nutm, _kbar, адер_, nktő, 
   {{0x61f80a87,0x3c2c022e,0xc6e800cc,0x00000000}},	//   _aetl, nоv_, _পিৰচ, --, 
   {{0x7c2ca2b4,0x61f8a2b5,0x60d805d5,0x4734084c}},	//   _mbar, _betl, _autm, _еняс, 
   {{0x60d80b4b,0x7c2ca2b6,0x95c81fbe,0xa5c4012d}},	//   _butm, _lbar, _буба_, _spóź, 
   {{0x61f8a2b7,0x668007d6,0x61b00133,0x2c181bbb}},	//   _detl, _تیلل, وڕما, _भालू_, 
   {{0x61f81af3,0x7c2c010a,0xc324009e,0xb6180220}},	//   _eetl, _nbar, পিজি_, _ﹼﻪ_, 
   {{0x61f818c6,0xc0c80063,0xbf140166,0x00000000}},	//   _fetl, љује_, зүчә, --, 
   {{0x7c2c633d,0x764400dc,0x61f8a2b8,0x60d80200}},	//   _abar, ndhy, _getl, _futm, 
   {{0x7c2c01ab,0x60d8061f,0x7644058a,0x00000000}},	//   _bbar, _gutm, idhy, --, 
   {{0x61f803cd,0x76880213,0xedc400f1,0xe0cc00d4}},	//   _zetl, _döyə, مېږي_, _ів_, 
   {{0x765402e2,0xae206b9b,0x6438008f,0xeab8a2b9}},	//   _onzy, _मापन_, בערנ, ийм_, 
   {{0x7c2ca2ba,0x9c10063f,0x60d8a2bb,0x61f80166}},	//   _ebar, _nọfe, _yutm, _xetl, 
   {{0xd940a2bc,0x76440882,0x7cc800cd,0x6844a2bd}},	//   мери, ddhy, _aśru, онва, 
   {{0x7c2ca2be,0x281404fb,0x00000000,0x00000000}},	//   _gbar, تورس, --, --, 
   {{0xaa44084c,0x060801e0,0x88c8013a,0x00000000}},	// [cd40] _депл, ймаҫ_, jběž, --, 
   {{0x7c2ca2bf,0x7ae800d8,0x88c80118,0x00000000}},	//   _zbar, íete, dběž, --, 
   {{0x61f80978,0x7c2c0209,0x26dc013a,0x00000000}},	//   _retl, _ybar, _čtou_, --, 
   {{0x61f8a2c0,0x60d8000f,0x7644058a,0x6d4402d2}},	//   _setl, _rutm, adhy, _áhau, 
   {{0x60d8a2c1,0x57440153,0x764400cd,0x00000000}},	//   _sutm, _дзям_, bdhy, --, 
   {{0xa6e00008,0x61f8016d,0x78a80219,0xe4e84029}},	//   áðun, _qetl, čeve, _نعره_, 
   {{0x61f80978,0x60d8014f,0x27f00076,0xe568009d}},	//   _vetl, _qutm, obyn_, _тивд_, 
   {{0x61f8a2c2,0x60d80477,0x27f0007c,0x541800db}},	//   _wetl, _vutm, nbyn_, _ەرەڭ_, 
   {{0x63042ad5,0x7c2c0004,0x61f8a2c3,0x2d90002d}},	//   _ذوال, _rbar, _tetl, úzen_, 
   {{0x60d8a2c4,0x7c2ca2c5,0x01cc0154,0x00000000}},	//   _tutm, _sbar, রুষদ, --, 
   {{0x7c2c01e4,0xf2700050,0x7eb4004e,0xd1780014}},	//   _pbar, _سێٹھ, nàpi, _پشٕچ_, 
   {{0x9c1001f2,0x2c6002fb,0xdde800f1,0xdc8818cd}},	//   _mọge, _kódy_, درکه_, рсол_, 
   {{0x60c0a2c6,0x27f00649,0x8ae402bf,0x291ca2c7}},	//   _ihom, dbyn_, дісл, àtan_, 
   {{0x60c00477,0x2c6002fb,0xf0a40248,0x00000000}},	//   _hhom, _módy_, _ààre_, --, 
   {{0x60c0a2c8,0x787003cd,0x7c2c01ab,0x3eac03cd}},	//   _khom, _håvi, _tbar, modt_, 
   {{0xda1445bf,0x9c100248,0x27f001f4,0x00000000}},	//   _ताकत_, _sọfe, gbyn_, --, 
   {{0xd5e80c78,0xb6c800dd,0x60c0a2c9,0x59a42c35}},	// [cd50] لعان_, مائے_, _mhom, _गडकर, 
   {{0x60c00363,0x27f0062c,0x00000000,0x00000000}},	//   _lhom, abyn_, --, --, 
   {{0x7644a2ca,0x27f0a2cb,0xf3f8054e,0xc4f8007b}},	//   rdhy, bbyn_, _hoţi_, قعنا_, 
   {{0x60c00605,0x7b100139,0x36d401f0,0x00000000}},	//   _nhom, _tıuğ, _номр, --, 
   {{0xa8580375,0x78aca2cc,0x00000000,0x00000000}},	//   _הדרכ, moav, --, --, 
   {{0x60c0013b,0x6d4400e4,0x78ac0165,0xcec0013a}},	//   _ahom, _âhag, loav, _keřů_, 
   {{0xd43400ae,0x00000000,0x00000000,0x00000000}},	//   _وعرب, --, --, --, 
   {{0x60c0a2cd,0x78aca2ce,0x6f641420,0x499c011a}},	//   _chom, noav, звиз, ישוב, 
   {{0x60c0a2cf,0xb8fc003d,0x9c1001f2,0x43940e76}},	//   _dhom, _ཤང_, _mọde, _жатс, 
   {{0x527404d3,0x60c0a2d0,0x3eac93ce,0x78aca2d1}},	//   _بارز, _ehom, godt_, hoav, 
   {{0x60c0a2d2,0x78ac17ad,0xe80c00bc,0x00000000}},	//   _fhom, koav, िणमा_, --, 
   {{0x78ac0124,0x60c00978,0xc0c8084c,0x00000000}},	//   joav, _ghom, _дуче_, --, 
   {{0x9e9401d9,0x78ac06d9,0x3940022e,0x00000000}},	//   _کانچ, doav, _ashs_, --, 
   {{0xa96844f0,0x80b4009e,0xef180135,0x00000000}},	//   бига_, ুদণ্, muż_, --, 
   {{0x78ac01f5,0x0dc80212,0x39400051,0xef180135}},	//   foav, _туди_, _cshs_, luż_, 
   {{0x1cb8038f,0x60c0009a,0x3858023a,0x78aca2d3}},	//   _མེར_, _xhom, орую_, goav, 
   {{0x27f00cfd,0x6014a2d4,0x1864a2d5,0xb81c012c}},	// [cd60] rbyn_, lümü, чати_, _फारम_, 
   {{0xe5a4144d,0x27f008c5,0x671c0073,0x00000000}},	//   пизи, sbyn_, यंबक_, --, 
   {{0x60140259,0xe4d4a2d6,0x78ac0109,0x6aac0810}},	//   nümü, ستاب, boav, mobf, 
   {{0x7eb400f7,0x78a80e04,0xef180327,0x1aec0154}},	//   ràpi, čevc, kuż_, _জিতে_, 
   {{0x60c0a2d7,0x1cb8025c,0x4420005f,0xaa8400a2}},	//   _rhom, _མེལ_, ļi_, _gaýç, 
   {{0x44201f21,0x60c01bb9,0x7870005c,0x63b4033f}},	//   żi_, _shom, _råvi, żyno, 
   {{0x60c00032,0x78703be7,0xa088a2d8,0x2934008f}},	//   _phom, _såvi, йсиз_, לאַן_, 
   {{0x7870a2d9,0x60c001e0,0x3944022c,0x845400db}},	//   _påvi, _qhom, ælsi_, _تىرچ, 
   {{0x60c01682,0xe7bc0303,0x00000000,0x00000000}},	//   _vhom, ्धिप, --, --, 
   {{0x60c014e0,0x78ac0798,0xf3f8054e,0xef3c037e}},	//   _whom, zoav, _roţi_, bb弾_, 
   {{0x60c0a2da,0x9cc800f7,0xd00c4965,0xf3f8054e}},	//   _thom, йыма_, _пф_, _soţi_, 
   {{0xf3f8084c,0x60c00453,0xd7d800b5,0xef18003d}},	//   _poţi_, _uhom, _ioデ_, buż_, 
   {{0xfbac0eac,0x78aca2db,0x3dc40131,0x3e840064}},	//   _গণহত, voav, яйүг, _pūtė_, 
   {{0x601405d1,0x78ac0083,0x1c1c000d,0x00000000}},	//   bümü, woav, _भावल_, --, 
   {{0x78aca2dc,0x60141432,0x00000000,0x00000000}},	//   toav, cümü, --, --, 
   {{0xf3f8084c,0x7b181b74,0x3a20045a,0x27240042}},	//   _toţi_, _доир_, _wchp_, fôn_, 
   {{0x78ac003b,0x051c03d4,0xf8b00014,0x779800d8}},	// [cd70] roav, নবোৰ_, ٹکھ_, цкар_, 
   {{0x78ac0851,0x394001c8,0x6aac01bf,0x4b7c011a}},	//   soav, _tshs_, cobf, _לאחו, 
   {{0x7aec022e,0x78aca2dd,0x00000000,0x00000000}},	//   _htat, poav, --, --, 
   {{0x1cb8003d,0x7aec0165,0x54cc0131,0x28e40150}},	//   _མེས_, _ktat, _ﺑﺎﺷﻼ, _ﻋﺎﺠﻠ, 
   {{0x601406b9,0x324409fc,0x00000000,0x00000000}},	//   zümü, делг, --, --, 
   {{0x7aec01f7,0x6014029f,0x00000000,0x00000000}},	//   _mtat, yümü, --, --, 
   {{0x61401e28,0xa1540640,0xdbc80139,0xb4940063}},	//   веща, дају_, _mеñy, _живљ, 
   {{0x7aeca2de,0xd9bc0154,0xef18031c,0x00000000}},	//   _otat, _আলাম, tuż_, --, 
   {{0x7aeca2df,0xaec450ae,0x9ee400f1,0x00000000}},	//   _ntat, мбил, وځول_, --, 
   {{0x2cb000b5,0x60143361,0xee38a2e0,0xef180135}},	//   _skyd_, tümü, цно_, ruż_, 
   {{0xa2a82356,0x98bc0034,0xf8ac0073,0x00000000}},	//   टवर्, ्षाए, चवाय, --, 
   {{0x6014029f,0x00000000,0x00000000,0x00000000}},	//   rümü, --, --, --, 
   {{0x7aec00b8,0x60140205,0x1c1c000d,0x00000000}},	//   _ctat, sümü, _भारल_, --, 
   {{0x9980031c,0x25400240,0x00000000,0x00000000}},	//   bejż_, _የጋጥሞ, --, --, 
   {{0xdd8c05d9,0x9e3000f0,0x00000000,0x00000000}},	//   _پوي_, _рејч, --, --, 
   {{0x7aec0393,0xeb980262,0x00000000,0x00000000}},	//   _ftat, _мий_, --, --, 
   {{0x3b080207,0x041400fe,0x2d840327,0x66e401f0}},	// [cd80] _gvaq_, ণ্ডী_, lzle_, фоза, 
   {{0x78a80fb7,0x2d840076,0x00000000,0x00000000}},	//   čeva, ozle_, --, --, 
   {{0xddc802e2,0xf65001ed,0xa80000e4,0x2b5000d7}},	//   _enfņ, ھئے_, _áñom, _hryc_, 
   {{0xd24c3253,0xe3b875b8,0x2d84a2e1,0x66e40137}},	//   ینن_, обе_, izle_, _оома, 
   {{0x7aec036b,0x63bc0034,0x935400d8,0x00000000}},	//   _xtat, ępno, дрју_, --, 
   {{0xe5a40228,0xc608015b,0x6b80010e,0x00000000}},	//   _жиги, র্জা_, _ýogu, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00d000d1,0x2d840210,0x00000000,0x00000000}},	//   _ﺗﺎﺷﻘ, dzle_, --, --, 
   {{0xe2980323,0x3f841050,0x44fc01e4,0x00000000}},	//   _даа_, uzmu_, lŭ_, --, 
   {{0x442407ae,0xf1a800e1,0x9ce40150,0x6f9c02dd}},	//   _hcm_, _चुकन, _ﺍﻟﻭﻋ, _ﻁﺒﻌﺎ_, 
   {{0xe0cc03d4,0xb46c00d7,0x00000000,0x00000000}},	//   _ৰবীন, žúšk, --, --, 
   {{0xdef802d5,0xc60800eb,0x00000000,0x00000000}},	//   _дык_, র্চা_, --, --, 
   {{0x4424a2e2,0xdf748e33,0x7aec025c,0x5f7400f7}},	//   _mcm_, _تداب, _qtat, _تاار, 
   {{0x44240051,0x00000000,0x00000000,0x00000000}},	//   _lcm_, --, --, --, 
   {{0x4424070d,0x99800024,0x00000000,0x00000000}},	//   _ocm_, vejų_, --, --, 
   {{0x8858a2e3,0x7aec0051,0xc60800fe,0x00000000}},	//   мисс_, _ttat, ৰ্মা_, --, 
   {{0x7aeca2e4,0x7c3ca2e5,0x44fc01e4,0x00000000}},	// [cd90] _utat, mesr, eŭ_, --, 
   {{0xd5b8a2e6,0x7c3c9108,0x4424a2e7,0xfe780153}},	//   осе_, lesr, _acm_, nkį_, 
   {{0x68480023,0x94a801b9,0x00000000,0x00000000}},	//   _መጻምድ, отда_, --, --, 
   {{0x4424a2e8,0x7c3ca2e9,0x7d0801ab,0x981400e5}},	//   _ccm_, nesr, isds, _کبھا, 
   {{0x660c0175,0x44fc00df,0x59d029d9,0x00000000}},	//   _fdbk, aŭ_, _धृतर, --, 
   {{0x4424a2ea,0x7c3c808f,0x22440114,0x00000000}},	//   _ecm_, hesr, епши_, --, 
   {{0x4424a2eb,0x7d080194,0x7c3ca2ec,0xe7e401ad}},	//   _fcm_, jsds, kesr, _कलमा_, 
   {{0x4094100e,0x543400aa,0x74f812d7,0x44240332}},	//   крыт, _ترسر, _меҳр_, _gcm_, 
   {{0x7c3c7421,0x00000000,0x00000000,0x00000000}},	//   desr, --, --, --, 
   {{0x44240077,0x2d84002f,0x00000000,0x00000000}},	//   _zcm_, tzle_, --, --, 
   {{0x5064a2ed,0xed580fab,0x2fd8a2ee,0x69d8a2ef}},	//   _отда, чон_, _فواد_, žtek, 
   {{0x7c3ca2f0,0x00d001ec,0x2b5001ef,0x00000000}},	//   gesr, _ﺗﺎﺳﻘ, _pryc_, --, 
   {{0x258401e1,0x7fa8036e,0x160c01f9,0x2d84a2f1}},	//   _kílé_, rëqë, ाणार_, szle_, 
   {{0x6da404a9,0xada4074d,0xa96801b9,0xbb4c0150}},	//   _пила, _палл, пига_, _ﺍﻷﻗ_, 
   {{0x36f4003d,0x3d64a2f2,0x6f08a2f3,0xa9683dc8}},	//   _བསྔལ_, _لطيف, lsec, чива_, 
   {{0x1864a2f4,0x7c3c127b,0xdb0c01ed,0x25840cad}},	//   наси_, cesr, őjár, _lílé_, 
   {{0x6f08a2f5,0x4424a2f6,0x98a0399f,0x7c2400c7}},	// [cda0] nsec, _rcm_, уите, _рзыҧ, 
   {{0x6f080334,0x25840cad,0x63b4012d,0x00000000}},	//   isec, _nílé_, żynk, --, 
   {{0x3944a2f7,0x44240f85,0x6d40015d,0x00000000}},	//   _иҷро_, _pcm_, nwla, --, 
   {{0x442406af,0x6f08010f,0x19d000d1,0x6b8000ee}},	//   _qcm_, ksec, _ﻛﯜﻧﻠ, _ýogs, 
   {{0x2584012c,0x6f08005c,0xfe780024,0x00000000}},	//   _bílé_, jsec, ykį_, --, 
   {{0x93c80d83,0xa508a2f8,0xc69400c8,0xdfd80107}},	//   سانہ_, _нега_, _יאָ_, ӯъи_, 
   {{0xc0d40020,0xe5a400a8,0x50b4004b,0x6f080f85}},	//   _ጭምር_, _чиви, کدود_, esec, 
   {{0xbf3400a7,0x6f080175,0x41c401b9,0x29080009}},	//   внищ, fsec, нёқа, isba_, 
   {{0x53a03edb,0x69dc02d0,0x6f08010a,0x7c3c0857}},	//   _батб, _ogpe, gsec, vesr, 
   {{0x6460a2f9,0x69dc003e,0x7c3c017a,0x4ac000cd}},	//   štič, _ngpe, wesr, _शीलव, 
   {{0x36f40867,0x7c3ca2fa,0x6d4000a9,0xfe7800c0}},	//   _བསྐལ_, tesr, gwla, rkį_, 
   {{0x49fc2fb5,0x69dc01ab,0xdee4a2fb,0x99840135}},	//   _དབུལ_, _agpe, _зоди, ċiża_, 
   {{0x7c3ca2fc,0xd7d8037e,0x6f080334,0x1ec800db}},	//   resr, _eoホ_, csec, _елди_, 
   {{0x7c3ca2fd,0xc6080183,0x00000000,0x00000000}},	//   sesr, ৰ্তা_, --, --, 
   {{0x98c4a2fe,0x6144001f,0x6d400042,0x7c3c7c9a}},	//   есал, ረሰቦች, cwla, pesr, 
   {{0x0e60035b,0x7c34a2ff,0x56f0004e,0x00000000}},	//   _акән, _реих, лүмс, --, 
   {{0x29080009,0xb7880352,0x00000000,0x00000000}},	// [cdb0] asba_, фәне_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2ab4005c,0x81bc00ef,0xc6a401a9,0x8c4403e0}},	//   ræbt_, _scēn, урти, şşek, 
   {{0xd76442c6,0x337400ee,0x846402e8,0x25840cad}},	//   _كەزى_, кгер, лъче, _sílé_, 
   {{0x38683c37,0xd24c01d3,0x6f08a300,0xae20000d}},	//   mjar_, ینچ_, xsec, _मालन_, 
   {{0x1cb849a6,0x38682c03,0x715801f0,0x00000000}},	//   _མེཀ_, ljar_, дрис_, --, 
   {{0x6f08a301,0x00000000,0x00000000,0x00000000}},	//   wsec, --, --, --, 
   {{0x438400d1,0x895c08c3,0x00000000,0x00000000}},	//   خلۇق, לדות, --, --, 
   {{0x3a3000b5,0x386804e6,0x00000000,0x00000000}},	//   kfzp_, ijar_, --, --, 
   {{0xece805f5,0x439402dd,0xd2000166,0x29080009}},	//   мдол_, _саус, _сүкк, ysba_, 
   {{0x6da4a302,0xada40075,0x3868a303,0xceb40032}},	//   тина, танл, kjar_, мәҫ_, 
   {{0x3868a304,0x6f0803ac,0x20c800b8,0x00000000}},	//   jjar_, psec, _tṛṇo, --, 
   {{0xdb080570,0xddc8007f,0x386801e3,0x00000000}},	//   _ènìy, _lafň, djar_, --, 
   {{0xa9a405f5,0x386835f5,0x6d400100,0xfa800150}},	//   вигд, ejar_, pwla, йқым, 
   {{0xad6801c0,0x386808a5,0x00000000,0x00000000}},	//   _цайз_, fjar_, --, --, 
   {{0x3868a305,0x1cb80135,0x63b40034,0xbdc001ec}},	//   gjar_, _མེག_, żyni, _دەپۋ, 
   {{0xb8e809d9,0x4cc800bd,0x974802d3,0x2908031c}},	// [cdc0] _ली_, _রংপু, _ዘካየድ, ssba_, 
   {{0x386800d8,0xaa8801f7,0x00000000,0x00000000}},	//   ajar_, _آندم_, --, --, 
   {{0xa5242b95,0x3ba4001f,0xc4dc00bc,0x00000000}},	//   тмед, _ወንዶች_, यदेख, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xaae000dc,0xdc2c00cd,0x00000000,0x00000000}},	//   पदिक, _jñās, --, --, 
   {{0x65c42b61,0x86b401ec,0x00000000,0x00000000}},	//   _абга, _сәбі, --, --, 
   {{0x1a9800c8,0x95b400c7,0x35c40fc0,0x00940276}},	//   ויסע, _артә, _барҳ, ликэ, 
   {{0x61e802d0,0x2000041e,0x00000000,0x00000000}},	//   scfl, úki_, --, --, 
   {{0xa2e410f5,0x47d4015b,0x2484a306,0x00000000}},	//   _розд, ধুরী, mhom_, --, 
   {{0xb060049b,0x2484a307,0x33b40024,0x1cb8031c}},	//   _ääne, lhom_, _сёст, _མེང_, 
   {{0x386801a8,0xffd401e0,0x00000000,0x00000000}},	//   yjar_, _өҫкә_, --, --, 
   {{0x2484013b,0x38680009,0x00000000,0x00000000}},	//   nhom_, xjar_, --, --, 
   {{0x6e140133,0x0f1000d4,0x38680327,0x00000000}},	//   _ڵسوڕ, _вмію, vjar_, --, 
   {{0x38680227,0x4f840050,0x2484047e,0xdb080241}},	//   wjar_, _جامہ, hhom_, _èníy, 
   {{0x3868a308,0xd7e400d3,0x225ca309,0x2484a30a}},	//   tjar_, візо, _mntk_, khom_, 
   {{0x2484a30b,0x00000000,0x00000000,0x00000000}},	//   jhom_, --, --, --, 
   {{0x3868a30c,0x248499d4,0x2364002e,0xc864a30d}},	// [cdd0] rjar_, dhom_, jxoj_, штри, 
   {{0xd0480cc1,0x386800fe,0x974802d3,0x2484025c}},	//   _digə, sjar_, _ዘካይድ, ehom_, 
   {{0xdc40012c,0x2484025c,0x3868a30e,0xd5b83eeb}},	//   _léčb, fhom_, pjar_, фса_, 
   {{0x26c80d27,0x24840978,0xf4846c71,0x00000000}},	//   _ehbo_, ghom_, دائی, --, 
   {{0xf2c4009d,0x87040024,0x00000000,0x00000000}},	//   гөжи, _вясе, --, --, 
   {{0x1fb804c5,0x71a401c6,0xe58400db,0x712401c8}},	//   ুশাস, лалз, _өтсү, هرعل, 
   {{0xd7d800b5,0x2484a30f,0xf3f4552d,0x00000000}},	//   _mlロ_, bhom_, _متذک, --, 
   {{0x248404bf,0x36f4025c,0x1c1c00af,0x225c0254}},	//   chom_, _བསྙལ_, _भागल_, _entk_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x82341410,0x00000000,0x00000000,0x00000000}},	//   _نرما, --, --, --, 
   {{0x78a809a8,0x1c1c0037,0x00000000,0x00000000}},	//   čevj, _भाखल_, --, --, 
   {{0x320400dd,0x2280032e,0x00d402dd,0x00000000}},	//   _hely_, _iðka_, _ﺟﺎﺳﺘ, --, 
   {{0x32041311,0xbf6442b5,0x7ff41eeb,0xe76002d2}},	//   _kely_, _ندوو, _ئسما, _sæþó, 
   {{0x6064035b,0x32048067,0x24840327,0x66c000d7}},	//   _ахәҷ, _jely_, zhom_, vôko, 
   {{0x63bc068f,0x320400dd,0x9c1002e3,0xed58a310}},	//   ępni, _mely_, _kọle, _чой_, 
   {{0x32040054,0xab280022,0x3da40075,0x24840b6b}},	//   _lely_, _зоиа_, _әрәб, xhom_, 
   {{0xe7a873f6,0x2484047e,0x00000000,0x00000000}},	// [cde0] хвал_, vhom_, --, --, 
   {{0x7c6401ec,0xe7e4000d,0x24840003,0x00000000}},	//   _ماۋل, _कलवा_, whom_, --, 
   {{0x2484a311,0x295406bb,0x64ac00df,0xd6cc007b}},	//   thom_, _съпр, nĝig, أقل_, 
   {{0x32040109,0x23640218,0x00000000,0x00000000}},	//   _aely_, txoj_, --, --, 
   {{0xe2980aa5,0x2484a312,0x320405e4,0xf0a401e1}},	//   над_, rhom_, _bely_, _ààye_, 
   {{0x851c069f,0x55e0a313,0x2484a314,0x32042b57}},	//   _पटपट_, _горб, shom_, _cely_, 
   {{0x2484014f,0x00000000,0x00000000,0x00000000}},	//   phom_, --, --, --, 
   {{0x3f14a315,0xd0406073,0x0edc01ad,0x2484a30b}},	//   адис, مپىي, नदंड, qhom_, 
   {{0x27e00805,0x644000c6,0x00000000,0x00000000}},	//   _mgkn_, meoi, --, --, 
   {{0x225c207a,0x3204a316,0x6440a317,0xae7000d1}},	//   _untk_, _gely_, leoi, يۇنغ, 
   {{0x6d44145e,0x2d8000af,0x1278010f,0x56b40a7c}},	//   _âhal, _ühel_, _ראבע, רפין_, 
   {{0x64400597,0x5b24a318,0xa6a800cc,0x04000248}},	//   neoi, льга, কতিয়, _éèdì_, 
   {{0x4c944493,0x602400c7,0xdfd0084e,0x64400076}},	//   сияс, _адҵа, _ايش_, ieoi, 
   {{0x20040325,0x644000c6,0x00000000,0x00000000}},	//   _heoi_, heoi, --, --, 
   {{0x2004062c,0x64400076,0x5dd003d4,0xc8640131}},	//   _keoi_, keoi, _দ্ৰু, әтси, 
   {{0x5c0400a7,0x47c00eac,0xf8680472,0x00000000}},	//   _сяка, ্শনী, خمري_, --, 
   {{0x64400491,0x57a4a319,0xb6c801d3,0x00000000}},	// [cdf0] deoi, ушва, نائے_, --, 
   {{0x2004562f,0xf730001f,0xad5001d5,0x00000000}},	//   _leoi_, _አካውን, _اچیغ, --, 
   {{0x86e4036b,0x6440a31a,0x3204a31b,0x00000000}},	//   _қўяд, feoi, _rely_, --, 
   {{0x6440a31c,0xd84428f6,0x00000000,0x00000000}},	//   geoi, _схоп, --, --, 
   {{0xd5ac00f8,0x00000000,0x00000000,0x00000000}},	//   _کہا_, --, --, --, 
   {{0x3114a31d,0x8e24022e,0x35f402e8,0x00000000}},	//   афис, _sinо_, _ъпгр, --, 
   {{0x32040109,0x7168009d,0x00000000,0x00000000}},	//   _vely_, тайг_, --, --, 
   {{0xccf41fa9,0x6440007b,0x2ca80115,0x320403cb}},	//   ққи_, ceoi, _ĉado_, _wely_, 
   {{0xc45003e6,0x01e400eb,0x00000000,0x00000000}},	//   _رێوب, _নজরদ, --, --, 
   {{0x9c1001f2,0xed58009d,0x00000000,0x00000000}},	//   _dọme, воо_, --, --, 
   {{0x20040607,0xdbdc08a5,0x00000000,0x00000000}},	//   _feoi_, _síðk, --, --, 
   {{0xae2000e1,0x64ac00df,0xcdc00150,0x00000000}},	//   _माकन_, rĝig, _қайқ, --, 
   {{0x9c10063f,0x00000000,0x00000000,0x00000000}},	//   _gọme, --, --, --, 
   {{0xdbdc022c,0xb060010e,0x00000000,0x00000000}},	//   _víðk, _ţähe, --, --, 
   {{0xad240116,0x00000000,0x00000000,0x00000000}},	//   _ئىبى, --, --, --, 
   {{0x4268044e,0x7d1c17b6,0xefdc02d3,0xdbdc08a5}},	//   ዳምነት_, árse, _ሓመድ_, _tíðk, 
   {{0x57e40364,0xe610005e,0xa764a31e,0xade8033f}},	// [ce00] рдум_, قشا_, шкад, _ऐलान_, 
   {{0xa5d8034d,0xdd38054e,0xcfd400eb,0x00000000}},	//   نبار_, năşt, _সভান, --, 
   {{0x64400597,0x00000000,0x00000000,0x00000000}},	//   teoi, --, --, --, 
   {{0x58d006ed,0x64400076,0x00000000,0x00000000}},	//   _моќт, ueoi, --, --, 
   {{0x64400597,0x9c10063f,0x59000327,0x00000000}},	//   reoi, _bọje, _མཆོས_, --, 
   {{0x644000c6,0x00000000,0x00000000,0x00000000}},	//   seoi, --, --, --, 
   {{0x2004005a,0xa5080117,0xfe7800fb,0x6440a31f}},	//   _peoi_, _шева_, һүд_, peoi, 
   {{0x2004003a,0xdb20002e,0xdfd80395,0x00000000}},	//   _qeoi_, ërëg, къп_, --, 
   {{0x25c400dc,0xae20012d,0x7eb800db,0x00000000}},	//   _वरुण, _माखन_, лгис_, --, 
   {{0xd734011a,0x9e70215c,0x00000000,0x00000000}},	//   סטית_, تۇتت, --, --, 
   {{0x32240150,0x7cd80329,0x95880240,0x00000000}},	//   _اۋىپ_, лмор_, _መኸተን_, --, 
   {{0x2f840184,0xd12ca320,0x00000000,0x00000000}},	//   рҙән_, _زمه_, --, --, 
   {{0xd00c566c,0x6c6000e4,0x7d1c0162,0x00000000}},	//   _آله_, _ẽhám, ársb, --, 
   {{0x8af003be,0x58b8014d,0x62880051,0x00000000}},	//   _irəl, چارج_, nhfo, --, 
   {{0xd8b8a321,0x44ec0083,0x81b8015b,0x00000000}},	//   ندرا_, _nÿ_, ঘের_, --, 
   {{0x4dd8011a,0x28e401ec,0x00000000,0x00000000}},	//   _בחוו, _ﻋﺎﺌﻠ, --, --, 
   {{0x96e80212,0xc3246911,0x2bdc00cd,0x00000000}},	// [ce10] тьба_, _تە_, _नृपा, --, 
   {{0x7c2c04fb,0x00000000,0x00000000,0x00000000}},	//   _hcar, --, --, --, 
   {{0x9c1001f2,0xf3f81cc9,0x19a80261,0x4ab40ce0}},	//   _nọke, гнеш_, _штип_, ंकरव, 
   {{0xdd8455b4,0x00000000,0x00000000,0x00000000}},	//   _ہو_, --, --, --, 
   {{0x1cb82b88,0x7c2ca322,0xa8000005,0xdd8400f1}},	//   _མེན_, _mcar, óñen, _ځو_, 
   {{0xdd844c8b,0x495400aa,0x630000d1,0x00000000}},	//   _فو_, _اخیس, سۈمل, --, 
   {{0x7c2c2d26,0x76440109,0x98746656,0x942000db}},	//   _ocar, mehy, lçı_, _ووسۇ, 
   {{0x0fe405c2,0x7c2c067c,0x1db809bb,0x7644a323}},	//   шлиқ_, _ncar, _उड़त, lehy, 
   {{0x98742523,0x154001ec,0xb2747de7,0x00000000}},	//   nçı_, _ءﺗﺎﺳ, _ллаш, --, 
   {{0x7c2ca324,0x6288a325,0x32c800d2,0x427400c6}},	//   _acar, chfo, búya_, _والآ, 
   {{0xdd38054e,0x2d941f5a,0x987415b7,0x00000000}},	//   răşt, српс, hçı_, --, 
   {{0x98741b07,0xed5801e0,0x28e80131,0x00000000}},	//   kçı_, _ҡол_, ғдап_, --, 
   {{0x7644a326,0x1c400153,0x00000000,0x00000000}},	//   kehy, чням, --, --, 
   {{0xeab801c6,0x7d1c01e7,0x98746b27,0x00000000}},	//   уйг_, ársc, dçı_, --, 
   {{0x7644a327,0x7e7c03fa,0x7c2c01ab,0x6eec0030}},	//   dehy, örpe, _fcar, _kĺbo, 
   {{0x7c2c007b,0xf8240213,0x98740790,0x00000000}},	//   _gcar, şünə_, fçı_, --, 
   {{0xa684a328,0xcc8800f1,0xa88401ec,0x2b140408}},	// [ce20] блад, _منډه_, _ۇلدى, _уьйр, 
   {{0x78bca329,0x76440158,0xaa4411dc,0x9c8401ef}},	//   _eksv, gehy, _اندى, _vyčů, 
   {{0xa3d85612,0x64a402bf,0x00000000,0x00000000}},	//   डेन_, бажа, --, --, 
   {{0xd5aca32a,0x2408030d,0xd36c6a3b,0x987403b9}},	//   رفن_, унди_, کهه_, bçı_, 
   {{0x7c3809a5,0x628864ad,0x7644016b,0x00000000}},	//   _öwre, thfo, behy, --, 
   {{0x32c80085,0xb6c401af,0x00000000,0x00000000}},	//   túya_, _мияһ, --, --, 
   {{0x41b4a32b,0x75240165,0x00000000,0x00000000}},	//   غمبر, cuhz, --, --, 
   {{0x6288013f,0xf1a800ec,0x95980092,0x80a4007b}},	//   shfo, جاهه_, ላካችን_, تمعن, 
   {{0x638405f5,0x27f0062c,0x00000000,0x00000000}},	//   _угаа, icyn_, --, --, 
   {{0x8dc00150,0x00000000,0x00000000,0x00000000}},	//   _ﺭﺍﺒﻁ, --, --, --, 
   {{0x7c2c0072,0x657c003a,0x635c0356,0x00000000}},	//   _pcar, nyph, _dănţ, --, 
   {{0xdfd075a6,0xd0040798,0x00000000,0x00000000}},	//   _فيض_, _геце_, --, --, 
   {{0x7c2ca32c,0xf0940014,0x7644013b,0x00000000}},	//   _vcar, _بُنگ, yehy, --, 
   {{0xa3d845bf,0x00000000,0x00000000,0x00000000}},	//   डेय_, --, --, --, 
   {{0x7c2c01ab,0x7e9801d3,0x764401bf,0x00000000}},	//   _tcar, _مچھر_, vehy, --, 
   {{0xc4c455c1,0x98742c70,0x7c2ca32d,0xd874007b}},	//   _سے_, tçı_, _ucar, حاسب, 
   {{0xdd2c00bc,0xa3d801ad,0x76440fac,0xf698399f}},	// [ce30] něže, डेम_, tehy, авај_, 
   {{0x7afca32e,0x98746b8e,0x7bcc005f,0x6dc400db}},	//   mpst, rçı_, _izau, _ازۇل, 
   {{0x59002fb5,0x76440134,0x657c03ac,0x7414009f}},	//   _མཆིས_, rehy, gyph, قواا, 
   {{0x6298a32f,0x7afc0af4,0x84240952,0xccf000c8}},	//   _amto, opst, كىمن, לכע_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd9f81f13,0x96900a98,0x7afc017a,0xc6a4022e}},	//   ्रित_, _عیاش, ipst, _ерси, 
   {{0x657ca330,0x776c0ba7,0xb14402bf,0x00000000}},	//   cyph, lxax, інил, --, 
   {{0xef189dc2,0xdb0400d7,0xab6003e0,0x00000000}},	//   ами_, _žmýk, çükb, --, 
   {{0xae880372,0xd9f80490,0x776ca331,0x7afc0582}},	//   ибиз_, ्रात_, nxax, jpst, 
   {{0xfe740145,0xae7802e8,0x2c2400eb,0x00000000}},	//   зүш_, рсих_, _বসেই_, --, 
   {{0x7bcc02ce,0x1d200209,0x2d94003b,0x3ba40092}},	//   _azau, ммэм, юрис, _ወንዞች_, 
   {{0xc3300014,0x7d1c01ed,0x776c0472,0x500000ee}},	//   _تٕے_, ársa, kxax, _эҗиз, 
   {{0x25c41276,0x829403e6,0x8fc4a332,0x9f940124}},	//   _वर्ण, _بگۆڕ, _ازان, _мышә, 
   {{0x7bcc006f,0x39400055,0x2bdc00cd,0x27f00042}},	//   _dzau, _bphs_, _नृणा, wcyn_, 
   {{0xdd8c01d9,0x7bcc05f5,0x7afc257c,0x657c83fb}},	//   _لوو_, _ezau, apst, xyph, 
   {{0x3eb80219,0xa3d80f4a,0x00000000,0x00000000}},	//   črte_, डेड_, --, --, 
   {{0x27f03deb,0xfca88863,0x00000000,0x00000000}},	// [ce40] rcyn_, _داوو_, --, --, 
   {{0x657ca333,0x4ab401c6,0xe66400fb,0xe5a40114}},	//   typh, _хөмр, әтҡо, оизи, 
   {{0xa968048a,0xa884113e,0x27f023b5,0xa3e800d8}},	//   _тина_, _ۇلگى, pcyn_, адеа_, 
   {{0x62980263,0xaa4411dc,0x13e401e0,0xefe80023}},	//   _smto, _انگى, ҙмәй_, ሙራዊ_, 
   {{0x22480209,0x13e401e0,0xc60800fe,0x00000000}},	//   ипди_, әмәй_, ৰ্গা_, --, 
   {{0x657c02d0,0xd2a408da,0x673400c0,0x00000000}},	//   pyph, окче_, mtyj, --, 
   {{0xa0886fc0,0x67340962,0xe5780640,0xdde801b9}},	//   исиз_, ltyj, _тзв_, یرده_, 
   {{0x50d00c8b,0x7afca334,0xdd2c0118,0x00000000}},	//   وزير, ypst, těže, --, 
   {{0x25dc1fbc,0xdef8a335,0x6734a336,0x00000000}},	//   _कृती_, шый_, ntyj, --, 
   {{0x6298014b,0x6144016c,0x67340006,0x9e640131}},	//   _umto, _меза, ityj, زاخن, 
   {{0xd00ca337,0x6734023a,0x3c580276,0x7bcc01d3}},	//   _оф_, htyj, бинэ_, _szau, 
   {{0xdee4a338,0x673400c0,0x00000000,0x00000000}},	//   _доди, ktyj, --, --, 
   {{0x7afc01a8,0xe508043e,0x776c0051,0x00000000}},	//   upst, हीति_, xxax, --, 
   {{0x99700118,0x00000000,0x00000000,0x00000000}},	//   _věže_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7e7800a2,0x00000000,0x00000000,0x00000000}},	//   _hovp, --, --, --, 
   {{0x7bcc2672,0x8af006be,0xdeb801f3,0x00000000}},	// [ce50] _uzau, _asəf, _ደሙን_, --, 
   {{0x7aec0421,0xaad01a4e,0x05741056,0x00000000}},	//   _iuat, _दीपक, ژاند, --, 
   {{0x7ae4014b,0x7aeca339,0x7bc00112,0x628400c0}},	//   _iiht, _huat, ßluf, _įkop, 
   {{0x7aec07dd,0x7e781347,0x78a8a33a,0xe0c40050}},	//   _kuat, _lovp, čevs, _سٲ_, 
   {{0x7aec01c4,0x2bdc012c,0x7ae40641,0xa280028e}},	//   _juat, नेपा, _kiht, کیلو, 
   {{0x7aeca33b,0x7ae4047e,0x7e78047e,0x9738001f}},	//   _muat, _jiht, _novp, _ሥርዓት, 
   {{0x7aec976d,0x7ae40109,0xeff002d3,0x7654003a}},	//   _luat, _miht, _ፍልይ_, _iazy, 
   {{0x7ae4033d,0x7aeca33c,0x765400ee,0xaf040e46}},	//   _liht, _ouat, _hazy, ппил, 
   {{0x60042ecc,0x7654a33d,0x7aec01e7,0x5348010a}},	//   чным_, _kazy, _nuat, _тăпă, 
   {{0x765403c6,0x6eec0030,0x7ae4014f,0x64ac00df}},	//   _jazy, _hĺbk, _niht, nĝin, 
   {{0x7aeca33e,0x3b080784,0x25dc02ab,0x64ac008f}},	//   _auat, _awaq_, केपी_, iĝin, 
   {{0x7aeca33f,0x7654005c,0x6734a340,0xe0cc00d4}},	//   _buat, _lazy, ytyj, _їв_, 
   {{0x7aeca341,0x7ae4a342,0x00000000,0x00000000}},	//   _cuat, _biht, --, --, 
   {{0x7aec19a2,0x76540034,0x7d28022c,0x40940e56}},	//   _duat, _nazy, ðssø, _ىلەر, 
   {{0x7ae4110c,0x00000000,0x00000000,0x00000000}},	//   _diht, --, --, --, 
   {{0x7aeca343,0x6734049b,0x6c04010b,0x00000000}},	//   _fuat, ttyj, _эзиз, --, 
   {{0x7aeca344,0x7654a345,0xa684a346,0x673401f5}},	// [ce60] _guat, _bazy, плад, utyj, 
   {{0x76540007,0x8cc40034,0x6734a347,0x7ae40e04}},	//   _cazy, रतको, rtyj, _giht, 
   {{0x7654a348,0xa44407d8,0x67340c98,0x64a4a349}},	//   _dazy, знед, styj, пажа, 
   {{0x66e4a34a,0xe738586a,0xef18012d,0x7aec013d}},	//   _нома, _лем_, zyża_, _yuat, 
   {{0x7ae4014b,0x2a780f03,0x7654010e,0x66e400f3}},	//   _yiht, _kopb_, _fazy, _хога, 
   {{0xc448168d,0x765400ee,0x00000000,0x00000000}},	//   _ژیان_, _gazy, --, --, 
   {{0x15401c60,0xa3d805f9,0x35c4022e,0x00000000}},	//   _перм, डे़_, _жарҳ, --, 
   {{0x7e78a34b,0x660ca34c,0x00000000,0x00000000}},	//   _sovp, _hebk, --, --, 
   {{0x7e78a34d,0x76540209,0x2bdc2052,0x68e4a34e}},	//   _povp, _yazy, नेमा, _mikd, 
   {{0x660c0029,0x2484a34f,0x7aeca350,0x88c40729}},	//   _jebk, lkom_, _ruat, ্দিক, 
   {{0x7aec15a5,0xef180210,0x00000000,0x00000000}},	//   _suat, ryża_, --, --, 
   {{0x68e403c6,0x7ae4a351,0x7aec077f,0x660ca352}},	//   _nikd, _siht, _puat, _lebk, 
   {{0x2a7800db,0x7ae4a353,0x248401f5,0xcfe416ac}},	//   _bopb_, _piht, ikom_, _عفوه_, 
   {{0x1cdc0156,0x7aec19a2,0x34a80c2e,0x7ae4014f}},	//   _སངམ_, _vuat, _कद्द, _qiht, 
   {{0x7ae4a354,0x291ca355,0x60c06941,0x7aec020c}},	//   _viht, štan_, _kkom, _wuat, 
   {{0x7aeca356,0x24840989,0xdd8c00dd,0x660c01c4}},	//   _tuat, jkom_, _لوڈ_, _aebk, 
   {{0xd5e80aa0,0x7ae400af,0x2484a357,0x60c0a358}},	// [ce70] معان_, _tiht, dkom_, _mkom, 
   {{0x2484a359,0x7c3c002f,0x0708009a,0x00000000}},	//   ekom_, lfsr, سيمي_, --, 
   {{0x60c0a35a,0x68e400d8,0xa3d801ad,0x64ac01e4}},	//   _okom, _fikd, डेस_, rĝin, 
   {{0x60c0a35b,0x68e40369,0x76541529,0x248405e4}},	//   _nkom, _gikd, _wazy, gkom_, 
   {{0x78aca35c,0x7654a35d,0xa858011a,0x00000000}},	//   mnav, _tazy, _ודרכ, --, 
   {{0x60c0a35e,0x78aca35f,0x6d440022,0x9644004e}},	//   _akom, lnav, _ãhag, _ээмд, 
   {{0x78aca360,0x2484a361,0x79940175,0x68e4010e}},	//   onav, bkom_, nzzw, _yikd, 
   {{0x78ac2de2,0x60c007ab,0x2484a1f5,0x7c3c0d27}},	//   nnav, _ckom, ckom_, jfsr, 
   {{0x60c001c7,0x78aca362,0x66c00109,0xe8d40150}},	//   _dkom, inav, môkr, _قﻮ_, 
   {{0x60c01aac,0x00000000,0x00000000,0x00000000}},	//   _ekom, --, --, --, 
   {{0x78aca363,0x7c3c0112,0xace84f55,0x301400f0}},	//   knav, ffsr, юмна_, _ждер, 
   {{0x78ac43d8,0x3eb809a8,0xc05802bf,0x427000c7}},	//   jnav, črta_, _ніч_, _аҳәс, 
   {{0x68e4a364,0x6e88007b,0x26d8a365,0x00000000}},	//   _rikd, _ونصف_, ympo_, --, 
   {{0x6da42c1d,0x78ac8e7a,0x2484a366,0x60c0a367}},	//   _оила, enav, zkom_, _zkom, 
   {{0xb9b406bb,0x1ae0112a,0x68e4a368,0x2484a369}},	//   естъ, торм, _pikd, ykom_, 
   {{0x78aca36a,0x186407d6,0x291c0552,0x25dca36b}},	//   gnav, маси_, štao_, _कृषी_, 
   {{0x2484a36c,0xa6e401ce,0x9cd4011a,0x00000000}},	// [ce80] vkom_, джал, _קופה_, --, 
   {{0x248415f1,0x2d8000af,0x78aca36d,0xdbcc1b0d}},	//   wkom_, _ühes_, anav, _sıçr, 
   {{0x78aca36e,0xdbcc008e,0x68e4a36f,0x660c03e3}},	//   bnav, _pıçr, _tikd, _vebk, 
   {{0x78ac0334,0xf48401ec,0xaad0000d,0x00000000}},	//   cnav, нуін, _दीतक, --, 
   {{0x2484a370,0x2918070d,0x26d8009a,0x3eac01bf}},	//   rkom_, _hvpa_, pmpo_, yndt_, 
   {{0x60c0a371,0xa508a372,0xdb94011a,0xc694010f}},	//   _skom, _мега_, ודנט_, _טאָ_, 
   {{0x64a4a373,0x7c3c017a,0xd5e07577,0x95d4005b}},	//   _жава, yfsr, _ажри, _ждёт_, 
   {{0x66e40aa5,0x3cfc00cf,0x23280835,0x2484031c}},	//   _хоҳа, _rtvv_, _моби_, qkom_, 
   {{0x3cfc01f5,0x291800c0,0x00000000,0x00000000}},	//   _stvv_, _lvpa_, --, --, 
   {{0x626410a8,0x60c00210,0x00000000,0x00000000}},	//   _تارق, _wkom, --, --, 
   {{0xdd9800d1,0xa3d8012c,0x3eaca374,0x61f8035a}},	//   юши_, डेर_, rndt_, _iftl, 
   {{0x60c0a375,0x5f4452c8,0x671c02ab,0x78aca376}},	//   _ukom, _ينال, _पिंक_, xnav, 
   {{0x78ac0fb7,0x68fc0139,0x7c3c01a8,0x291c3493}},	//   vnav, _atpd, rfsr, štal_, 
   {{0xefe80092,0x59640107,0x79940112,0x00000000}},	//   ሙያው_, мъба, tzzw, --, 
   {{0x78aca377,0x8d70a378,0x3f847a90,0x00000000}},	//   tnav, _لايا, lymu_, --, 
   {{0x7bc03535,0x68fc0139,0x79940175,0x00000000}},	//   ğlub, _dtpd, rzzw, --, 
   {{0x77980139,0x3f84a379,0xca780023,0x61f802d0}},	// [ce90] чкар_, nymu_, _ኣለኩም_, _oftl, 
   {{0x3ce80211,0x6d5c0085,0x80d001ad,0xc69c0092}},	//   _hiav_, ́sam, _डीसे, ጋገሪያ_, 
   {{0x3ce801d4,0x78aca37a,0xab6000c5,0x00000000}},	//   _kiav_, pnav, _üürn, --, 
   {{0x3f840024,0x972000e5,0x98a00055,0x00000000}},	//   kymu_, _لہرو, bujā_, --, 
   {{0xa3d81af8,0x8c4400a2,0x13ec0037,0x3244004e}},	//   डेल_, _üşem, _छलीह_, еелг, 
   {{0x3f84a37b,0xd5b802e8,0x04640166,0x00000000}},	//   dymu_, _дсб_, етәм, --, 
   {{0x34945938,0x85b801d9,0xe6bc726b,0x00000000}},	//   _завр, _قافس_, ्तरङ, --, 
   {{0x3ce80218,0x74140075,0x61f80c8c,0xdef00023}},	//   _niav_, _سوئا, _eftl, _ፍሽኽ_, 
   {{0x2ee4444e,0x00000000,0x00000000,0x00000000}},	//   нжиг, --, --, --, 
   {{0xee381f5c,0xd930001f,0x00000000,0x00000000}},	//   чно_, _ይልቁን, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3ce80211,0xe57000df,0x53d00210,0x00000000}},	//   _ciav_, אַש_, _तराश, --, 
   {{0xdfcc16cb,0x3ce801d4,0x68fc562c,0xb814009e}},	//   _ٿيو_, _diav_, _stpd, িলাত_, 
   {{0x291c05ce,0x00000000,0x00000000,0x00000000}},	//   štam_, --, --, --, 
   {{0xd9409398,0x5e5401c8,0x1dc4000d,0x00000000}},	//   лери, _سليس_, _रुपत, --, 
   {{0xb4b8012c,0x00000000,0x00000000,0x00000000}},	//   घको_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [cea0] --, --, --, --, 
   {{0x66e45850,0x68fc05d5,0x00000000,0x00000000}},	//   хоза, _ttpd, --, --, 
   {{0x1a981a4c,0x2d8406af,0xa9a401b9,0x6b84a37c}},	//   _זייע, nyle_, _чинд, lykg, 
   {{0x3ce80211,0x00000000,0x00000000,0x00000000}},	//   _xiav_, --, --, --, 
   {{0xa3d846c7,0x61f80175,0x7768a37d,0xa6a83fe6}},	//   डें_, _pftl, _àexp, _فاسق_, 
   {{0x6264a37e,0x7d1c0ab9,0x2d84a37f,0x601800e4}},	//   عاشق, ársk, kyle_, kämí, 
   {{0x5634010f,0x6498a2b6,0x60e400d8,0x00000000}},	//   _ראלע_, _етар_, нциз, --, 
   {{0x3f840024,0xb5940244,0x00000000,0x00000000}},	//   tymu_, _جێما_, --, --, 
   {{0x7f949a35,0xe2980022,0x3ce80208,0x00000000}},	//   тапх, _еаа_, _riav_, --, 
   {{0x3ce80211,0xaf540451,0xe194004e,0x53a0013d}},	//   _siav_, ئريڪ, _преэ, _сауб, 
   {{0x291c0bb8,0x3ce80457,0x2d8414e0,0x3f84a380}},	//   štaj_, _piav_, gyle_, symu_, 
   {{0x6288008f,0x1fb000cc,0x00000000,0x00000000}},	//   lkfo, _চৰণস, --, --, 
   {{0x3ce801d4,0x2d840076,0xd0040137,0xc98407a5}},	//   _viav_, ayle_, _чече_, қури, 
   {{0x2d84a381,0x6288a382,0x00000000,0x00000000}},	//   byle_, nkfo, --, --, 
   {{0x3ce80457,0x20ec01ef,0x00000000,0x00000000}},	//   _tiav_, _hřib_, --, --, 
   {{0xd87402f2,0x2bdc1546,0x00000000,0x00000000}},	//   رازب, नेहा, --, --, 
   {{0x628808fb,0x50d8010f,0x00000000,0x00000000}},	// [ceb0] kkfo, לקלא, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7994035b,0x4420a1a1,0x87041884,0x7d1c5e4f}},	//   _ринф, лi_, نبەل, ársh, 
   {{0x2bdc4928,0x6288017a,0xd4c40116,0xf4840330}},	//   नेवा, ekfo, رغاي, خائی, 
   {{0x443401d5,0x8c1c011a,0x04c801f7,0xd340179e}},	//   اءمس, לואי, روهي_, افتی, 
   {{0x0708009f,0x81cc03d4,0xdbdc01e1,0x22840022}},	//   _سيفي_, ৰখন_, _ríìk, кәхо_, 
   {{0x45d4a383,0xd498a384,0x6b84002d,0x00000000}},	//   _борс, _ера_, zykg, --, 
   {{0x62880212,0x657800a3,0xd5b801ec,0x00000000}},	//   akfo, _àtha, _дсұ_, --, 
   {{0xf2380798,0x00000000,0x00000000,0x00000000}},	//   _опаш_, --, --, --, 
   {{0x0d0401b9,0x1e800022,0x00000000,0x00000000}},	//   ндоқ_, илым, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x291c05a1,0x15e007f7,0x2d840076,0xdbdc0241}},	//   štak_, केयर_, ryle_, _tíìk, 
   {{0xfd4801ec,0x00000000,0x00000000,0x00000000}},	//   _үзік_, --, --, --, 
   {{0x2d84a385,0x00000000,0x00000000,0x00000000}},	//   pyle_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd8202f0d,0xab64a386,0x00000000,0x00000000}},	//   идси, _авил, --, --, 
   {{0xeab8036b,0xbc780030,0xeb98156c,0x628801bf}},	// [cec0] _ойи_, úšťa, _цип_, ykfo, 
   {{0xe6bc0f4c,0xa5084f5c,0x9b14011a,0x00000000}},	//   ्तेज, дежа_, _שחיה_, --, 
   {{0xa97400f3,0x00000000,0x00000000,0x00000000}},	//   _рупј, --, --, --, 
   {{0x232801f0,0xc1b40124,0x00000000,0x00000000}},	//   доди_, қәзы, --, --, 
   {{0xe3b0a387,0xe298a388,0x00000000,0x00000000}},	//   جرا_, мад_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6288a389,0xe5a41f91,0x25dc08a3,0x00000000}},	//   rkfo, _риви, केशी_, --, 
   {{0xbf3400d4,0x00000000,0x00000000,0x00000000}},	//   гнищ, --, --, --, 
   {{0xa3d44e8f,0xaab005d7,0x6440020c,0x25dc012c}},	//   _हरि_, ँचाक, mfoi, केरी_, 
   {{0xd33402e4,0x5398011a,0x98a0012d,0x00000000}},	//   _ברמה_, _חימו, mują_, --, 
   {{0xe3740032,0xbd4400d1,0x98a0012d,0x75f801d3}},	//   _ялҡы, اھتى, lują_, _húzó, 
   {{0xd0801de1,0xa3d417cb,0x00000000,0x00000000}},	//   _выши, _हरा_, --, --, 
   {{0x64400421,0x98a0033f,0x2bdc00bc,0x00000000}},	//   ifoi, nują_, नेला, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x63bc0034,0xc9840a5b,0x00000000,0x00000000}},	//   ępny, аути, --, --, 
   {{0x98a00034,0x5158011a,0x9cc8013d,0x00000000}},	//   kują_, וכלו, _юыла_, --, 
   {{0xded0069c,0x2ba800bc,0xd6100139,0x00000000}},	// [ced0] _የለን_, _चेपा, изаө, --, 
   {{0xba5426e5,0x6440a38a,0x7bcc0286,0x98a0033f}},	//   _свој, efoi, _iyau, dują_, 
   {{0x5bd0012c,0x6440a38b,0xa2c41a55,0x95d00408}},	//   _सरुव, ffoi, िवन्, рăна_, 
   {{0xba08a38c,0x7bcc3142,0x84240873,0xd4040108}},	//   _ጋር_, _kyau, لىمن, тяжи, 
   {{0x4c9c008d,0x6d5c0f40,0x7bcc0055,0x98a0033f}},	//   ובאו, āsai, _jyau, gują_, 
   {{0x7bcca38d,0x7158010b,0x68ec000f,0xd68400f3}},	//   _myau, ерис_, _ûndú, _румп, 
   {{0x21a001b9,0xd5ac01d3,0x00000000,0x00000000}},	//   йишм, _بہا_, --, --, 
   {{0x301800c6,0x98a0012d,0x0f30036b,0x00000000}},	//   رتبة_, bują_, لکتد, --, 
   {{0x7bcca38e,0xaec4a38f,0x98a0033f,0x2848010f}},	//   _nyau, лбил, cują_, געפּ, 
   {{0x82d80262,0xd20014ca,0x291c0024,0x439414d4}},	//   _адус_, _түкк, štai_, _таус, 
   {{0x7bcca390,0x15c401ec,0x00000000,0x00000000}},	//   _ayau, _ﯨﻨﺪﻩ, --, --, 
   {{0x4c84472b,0x7bcc0007,0xeb983596,0xab2816c3}},	//   рғиз, _byau, еим_, нома_, 
   {{0xe454008f,0x6e440816,0x00000000,0x00000000}},	//   נישט_, _белз, --, --, 
   {{0x0d700214,0x7bcc00cd,0x279401ec,0x00000000}},	//   _نخبگ, _dyau, ңшар, --, 
   {{0x291ca391,0x98a00034,0x6a8401ec,0x00000000}},	//   éta_, zują_, _ұлпа, --, 
   {{0x48c400bd,0x18a000db,0x291c0022,0xdbd4010b}},	//   ্দ্র, басм, ĩta_, läým, 
   {{0x7bcc0097,0xca7802d3,0x5ef4010f,0x291c00e4}},	// [cee0] _gyau, _ኣለኹም_, ָזעף_, ũta_, 
   {{0xa6c8a392,0x00000000,0x00000000,0x00000000}},	//   روال_, --, --, --, 
   {{0x98a0033f,0x9a38011a,0xa52401f0,0x49940244}},	//   wują_, _אתיק, умед, _ئیزر, 
   {{0xe3b80aa5,0xa8541614,0x98a00034,0x00000000}},	//   нбе_, _стој, tują_, --, 
   {{0x6440a393,0x7bcc0070,0x37740228,0xdbdc0248}},	//   rfoi, _xyau, _кырс, _kíák, 
   {{0x6440a394,0x98a0033f,0x657801ab,0xf3f80356}},	//   sfoi, rują_, _àtho, _raţe_, 
   {{0xc4480424,0x98a0033f,0x764000a2,0xdbd400a2}},	//   _لیان_, sują_, _ölya, däým, 
   {{0x98a0012d,0x717000db,0x00000000,0x00000000}},	//   pują_, تۇما, --, --, 
   {{0x4424a395,0xcb2000ab,0x7c38010e,0x00000000}},	//   _idm_, _बिगड_, _öwri, --, 
   {{0xa2e4a396,0xd1bc001f,0xd00c0050,0xdbd400a2}},	//   _созд, ድሞች_, _ہلم_, gäým, 
   {{0x7bcc0a2e,0x59140135,0x3cb400ee,0x212802d2}},	//   _syau, ླེབས_, ийор, _íbh_, 
   {{0xd00ca397,0xfbcc00bd,0x7bcc0055,0x00000000}},	//   _فلم_, রেফত, _pyau, --, 
   {{0x225c0254,0x00000000,0x00000000,0x00000000}},	//   _katk_, --, --, --, 
   {{0x8f981a4c,0x7bcc0161,0x2eb000dc,0x00000000}},	//   _אידי, _vyau, ीकृत, --, 
   {{0x225c000d,0x00000000,0x00000000,0x00000000}},	//   _matk_, --, --, --, 
   {{0xd8380323,0xfb8801b9,0x00000000,0x00000000}},	//   ээг_, _ароқ_, --, --, 
   {{0xcc3400cf,0xa3d4000d,0x7bcca398,0x00000000}},	// [cef0] _ارىع, _हरष_, _uyau, --, 
   {{0xd5b8a399,0x77e40073,0x00000000,0x00000000}},	//   нсе_, _कणीक_, --, --, 
   {{0xc48402dd,0xd5b80408,0x00000000,0x00000000}},	//   әлік, хса_, --, --, 
   {{0x442463ce,0x29780bd9,0x58d003d4,0x25ac0419}},	//   _cdm_, _סטרא, _দূৰী, úfla_, 
   {{0x5bd0177c,0x225c020c,0x4424a39a,0xb4d407f7}},	//   _सरोव, _batk_, _ddm_, _हठी_, 
   {{0x44240048,0x8afc00c8,0x95c88456,0x273c0165}},	//   _edm_, עהוי, _зуба_, sãnã_, 
   {{0x442404ce,0x225c022e,0xe29400a7,0x8234007b}},	//   _fdm_, _datk_, ращ_, إرها, 
   {{0x44241730,0x708405a9,0x82340372,0x4094004e}},	//   _gdm_, ргиз, _ۇرما, йрыт, 
   {{0x35a400d1,0xb4b00073,0x51d00150,0x2eb400f5}},	//   _саңг, टची_, _ﯞﯨﻨﺸ, исос, 
   {{0xf2347f22,0xed442826,0x8234a39b,0x00000000}},	//   _خبرک, аноп, _هرما, --, 
   {{0x442406be,0x00000000,0x00000000,0x00000000}},	//   _ydm_, --, --, --, 
   {{0x6b6402ec,0xedc400f1,0xb6540092,0x00000000}},	//   акма, هېږي_, _የማኔጅ, --, 
   {{0x0a4802d3,0x8e60010b,0xc3780408,0xe45400df}},	//   _ምምልካ, _гелҗ, _уйăх_, בירט_, 
   {{0x6f08a39c,0xa3d865d9,0x5ac401f4,0x98a00210}},	//   mpec, डेट_, илям_, muję_, 
   {{0x7d1ca39d,0xad4000db,0x98a0012d,0x00000000}},	//   árst, _بۉجۉ, luję_, --, 
   {{0xa804a39e,0x6d4001e6,0x2b14084c,0xe7b401d5}},	//   рзал, mtla, _кьор, لمزد, 
   {{0x44240334,0x98a0033f,0x64ac0115,0x6f08a39f}},	// [cf00] _rdm_, nuję_, iĝit, npec, 
   {{0xaa447dfb,0x4424a3a0,0x6d40a3a1,0x2b400076}},	//   _теол, _sdm_, otla, mtkc_, 
   {{0x6d40a3a2,0x4424a3a3,0x2ba8089a,0xa9081b45}},	//   ntla, _pdm_, _चेता, _جيجل_, 
   {{0x6d4000e8,0x3eb80219,0xd1d402d3,0x98a0033f}},	//   itla, črti_, ርክት_, kuję_, 
   {{0x6d40a3a4,0x4424a3a5,0x78a0017a,0x8bf800cc}},	//   htla, _vdm_, ëlve, _অজান_, 
   {{0x6d40a3a6,0xd36c0486,0xf1a80451,0x98a0012d}},	//   ktla, بهه_, گاهه_, duję_, 
   {{0x5bd0a3a7,0x442405da,0x91000798,0xda7400df}},	//   _सर्व, _tdm_, опје, יגסט_, 
   {{0x4424a3a8,0x6f08003a,0xd5d801ad,0x3f142766}},	//   _udm_, fpec, _भरतज, бдис, 
   {{0x6d400034,0xa2c40b98,0x98a00210,0xbf100139}},	//   etla, िवद्, guję_, чүлә, 
   {{0x7e98a3a9,0x99840030,0x15e00073,0x00000000}},	//   اندر_, _čiže_, केवर_, --, 
   {{0x6d40a3aa,0x2364a3ab,0xd5f4010f,0x00000000}},	//   gtla, lvoj_, יזיט_, --, 
   {{0x98a0033f,0xa2d85347,0x00000000,0x00000000}},	//   buję_, _पीत्, --, --, 
   {{0x6d40a3ac,0xa3d80073,0x98a0012d,0xcf745207}},	//   atla, डेच_, cuję_, _نصوص_, 
   {{0x290801bf,0xe2980208,0xdb1c0241,0x00000000}},	//   fpba_, như_, _àwíf, --, 
   {{0xd7f80364,0x76b8036b,0x3eac7e42,0x64ac0115}},	//   вуз_, ҳлар_, midt_, nĝis, 
   {{0x889409fe,0x3eaca3ad,0x3a2c00fd,0x00000000}},	//   оисх, lidt_, şep_, --, 
   {{0xd1d402d3,0x76b8a3ae,0x37c400fb,0xcb6800f0}},	// [cf10] ርክቶ_, глар_, сәнб, _вање_, 
   {{0xd5e82ba5,0x37c400fb,0x869800d8,0x00000000}},	//   نعان_, _ғәбб, акус_, --, 
   {{0x6f0802fb,0x2bd882e7,0xbdf80eac,0x3eac01ab}},	//   zpec, _لایک_, _আজাদ_, iidt_, 
   {{0x6f0849dc,0x3374004e,0xb4c000af,0xb4b00073}},	//   ypec, йгер, ँवे_, टचे_, 
   {{0x78aca3af,0x291c63e0,0x6d400306,0x287401af}},	//   miav, štat_, ztla, _уҡты_, 
   {{0x6d40a3b0,0x78aca3b1,0x984c05d1,0x42c81cb8}},	//   ytla, liav, _işık_, агін_, 
   {{0xb5e403f4,0xf5940597,0x6d4086da,0x236401e4}},	//   _প্রচ, _الأج, xtla, avoj_, 
   {{0x78aca3b2,0xf3f8084c,0x98a0012d,0xef180210}},	//   niav, _faţa_, tuję_, zyżu_, 
   {{0x683001a9,0x43947863,0xc0f00023,0x64ac010f}},	//   _mаdа, _датс, _ሃገራ_, rĝit, 
   {{0x78aca3b3,0x6f08a3b4,0xc0f0044e,0xed5805f5}},	//   hiav, rpec, _ሃገረ_, гоо_, 
   {{0xc2c4027d,0x2d9000bc,0x78aca3b5,0x98a0012d}},	//   _بيلي, áze_, kiav, suję_, 
   {{0x6f080221,0xc18c00c8,0x2b380276,0x78ac022e}},	//   ppec, _שטאָ, лягэ_, jiav, 
   {{0x78aca3b6,0xe454008f,0x7d1c43e9,0x00000000}},	//   diav, זירט_, ársr, --, 
   {{0x6d40a3b7,0x2bdc2983,0x00000000,0x00000000}},	//   ptla, नेगा, --, --, 
   {{0xc0f0044e,0x6d402dbe,0x984c03ee,0x78ac05da}},	//   _ሃገሩ_, qtla, _aşık_, fiav, 
   {{0x78aca3b8,0x98a01de1,0xb4c0000d,0x7c84009b}},	//   giav, писе, ँवो_, _муње, 
   {{0xdbd4010b,0x18640212,0xdc3400df,0xdc980115}},	// [cf20] _käýi, щати_, _האפט_, _תיפל, 
   {{0x78ac0618,0xa5d80345,0x00000000,0x00000000}},	//   aiav, هبار_, --, --, 
   {{0x78ac0064,0x764000c7,0x00000000,0x00000000}},	//   biav, ьҭра, --, --, 
   {{0x78ac4f3b,0x291c0953,0xa90801a9,0x236400df}},	//   ciav, štas_, _prоf, tvoj_, 
   {{0x8284036b,0x00000000,0x00000000,0x00000000}},	//   оқад, --, --, --, 
   {{0x2364008f,0xe69408de,0x00000000,0x00000000}},	//   rvoj_, _السد, --, --, 
   {{0x661c0357,0x3eac1477,0x72280212,0x23640010}},	//   mapk, vidt_, рців_, svoj_, 
   {{0x661c0cfe,0x403401af,0x64ac00df,0xc0340114}},	//   lapk, цеис, rĝis, цниј, 
   {{0x9cc84d50,0x83dc0037,0xe3b8011c,0xe1f00066}},	//   ғына_, _बरिआ, _сба_, _فسا_, 
   {{0x661c0bc9,0x78aca3b9,0x7bc02ba3,0x238c00de}},	//   napk, ziav, şluk, _vējā_, 
   {{0xc0f0067d,0x3eaca3ba,0xdfd00066,0xc0cc0092}},	//   _ሃገር_, ridt_, _کيش_, _ኣገር_, 
   {{0x661c0cfe,0xd12c4fe0,0x7e980214,0x4f840014}},	//   hapk, _سمه_, انگر_, _گامہ, 
   {{0x661ca3bb,0x78aca3bc,0xd90c01d3,0x00000000}},	//   kapk, viav, کیج_, --, 
   {{0x661c74bf,0x78ac02c4,0x4f8401d9,0x6fdc0073}},	//   japk, wiav, _دامہ, _परतू, 
   {{0x78ac1311,0x661c207a,0x00000000,0x00000000}},	//   tiav, dapk, --, --, 
   {{0xb7140801,0x3eb80219,0x6830022e,0x8d800107}},	//   ждащ, črtu_, _qаdа, _хушд, 
   {{0x78aca3bd,0x291ca3be,0x5884329e,0x673400c7}},	// [cf30] riav, átar_, _ғына, guyj, 
   {{0x78aca3bf,0x661c00ee,0x00000000,0x00000000}},	//   siav, gapk, --, --, 
   {{0x291c80b6,0x78aca3c0,0xf3f8a3c1,0x3554007b}},	//   štar_, piav, анеш_, تناز, 
   {{0x7d042e31,0xf8dc0037,0x69d80254,0x00000000}},	//   _čisl, _मठिय, ütee, --, 
   {{0x78bc01a4,0xdfc40f2b,0x661c010e,0x00000000}},	//   _ijsv, _آي_, bapk, --, 
   {{0x661c8590,0xe294a3c2,0xddd800c0,0x00000000}},	//   capk, жаш_, nktų, --, 
   {{0x3494a3c3,0xc8c803e6,0xa280129e,0xb4940640}},	//   _давр, _خوێن_, بیلو, _дивљ, 
   {{0xaf0476a0,0x3b08a3c4,0xc2082374,0x00000000}},	//   опил, _otaq_, لقۇن_, --, 
   {{0xb4d479c5,0x00000000,0x00000000,0x00000000}},	//   हती_, --, --, --, 
   {{0x6d24a3c5,0x6df802a9,0x00000000,0x00000000}},	//   одоз, шхис_, --, --, 
   {{0xa2c4a3c6,0x3b08a3c7,0xf10400db,0xc10400e3}},	//   िवर्, _ataq_, _بۉبۉ_, _فولي, 
   {{0x50d400f2,0x25dc0118,0x7e7c007c,0x00000000}},	//   _ازطر, केटी_, örpr, --, 
   {{0x661c0054,0x00000000,0x00000000,0x00000000}},	//   yapk, --, --, --, 
   {{0x40940150,0x98a400df,0x00000000,0x00000000}},	//   _ولەر, ĝiĝo_, --, --, 
   {{0xddc058f0,0x1984a3c8,0xe8180640,0x6aac01e4}},	//   _обши, обри_, ицај_, ribf, 
   {{0x20d80036,0x3bf40022,0x00000000,0x00000000}},	//   hëin_, _нџьт, --, --, 
   {{0xe6182d2e,0xe73829e4,0x661ca3c9,0x78a0017a}},	// [cf40] ида_, рез_, tapk, ëlva, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x661c50f9,0x1fc42982,0x00000000,0x00000000}},	//   rapk, _लड्ड, --, --, 
   {{0xe738a3ca,0x69dca3cb,0xd24c04d3,0x661ca3cc}},	//   _кем_, _izpe, ێنن_, sapk, 
   {{0x66e4a3cd,0x785000bc,0x3b080135,0xa69406ed}},	//   _мома, _děvč, _xtaq_, _дрвј, 
   {{0xe5a40faa,0x661c0054,0x00000000,0x00000000}},	//   _диги, qapk, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x656c01c3,0x7bc00356,0x00000000,0x00000000}},	//   _irbh, şlui, --, --, 
   {{0x2ba8012c,0xdfd80395,0x00000000,0x00000000}},	//   _चेला, шък_, --, --, 
   {{0x63a0a3ce,0xd9d802f5,0xcee40640,0x52a40eed}},	//   mzon, _দলসম, одње_, _двум_, 
   {{0x25dc0073,0x629894ee,0xd5f8010f,0x00000000}},	//   केची_, _ilto, יפיר, --, 
   {{0x63a003d1,0x00000000,0x00000000,0x00000000}},	//   ozon, --, --, --, 
   {{0x63a0a3cf,0x69dc01c0,0x00000000,0x00000000}},	//   nzon, _azpe, --, --, 
   {{0x63a0004c,0x19540032,0x656c01ab,0x00000000}},	//   izon, ҙағы_, _orbh, --, 
   {{0x6724168c,0xd8740451,0x3d941ebb,0xc1a80bae}},	//   _avkj, يارب, _хийр, _औधोग, 
   {{0x63a001f5,0x3d943d09,0xb78805a2,0x00000000}},	//   kzon, _миһр, бәге_, --, 
   {{0x63a00936,0x6298a3d0,0x656ca3d1,0x3b0803f0}},	// [cf50] jzon, _olto, _arbh, _utaq_, 
   {{0x63a0a3d2,0x7c3ca3d3,0x7a3814a3,0x00000000}},	//   dzon, lgsr, _упор_, --, 
   {{0x63a0a3d4,0x656c0477,0xa50803cc,0x64ac01e4}},	//   ezon, _crbh, مىلە_, rŝin, 
   {{0x970004a9,0xb4d4a3d5,0x6298a3d6,0x63a001e4}},	//   _يېزى, हते_, _alto, fzon, 
   {{0x6298022f,0x656c02d0,0xc30403e6,0x00000000}},	//   _blto, _erbh, وبوو, --, 
   {{0x20040618,0x62600108,0x00000000,0x00000000}},	//   _afoi_, евша, --, --, 
   {{0x63a005da,0x45d40826,0x656c01ab,0xe58400db}},	//   azon, _жорс, _grbh, _еттү, 
   {{0x63a0a3d7,0xf8bc012c,0xd4980063,0x75e4013d}},	//   bzon, ्किय, _трг_, _дәҗҗ, 
   {{0x63a0006d,0x53a000db,0xeea40150,0x00000000}},	//   czon, _تۅشك, _ﻏﻀﻭﻥ_, --, 
   {{0x8d240032,0x479c0375,0xae7800ee,0x7c3c002f}},	//   оноң_, ייחס, ссих_, egsr, 
   {{0x2004015d,0xfbc802e4,0xf8bc1a55,0x00000000}},	//   _ffoi_, _עת_, ्काय, --, 
   {{0x7c3ca3d8,0xec981d39,0x00000000,0x00000000}},	//   ggsr, стој_, --, --, 
   {{0x81b002f5,0x69dca3d9,0x5ff8011a,0x00000000}},	//   _টুপ_, _szpe, _ההנה, --, 
   {{0xed58010b,0x1dc4012d,0x721800cc,0x00000000}},	//   _гок_, _रुकत, _ঠাঁচ_, --, 
   {{0x63a0a3da,0xdd8c0272,0x6e20a3db,0xaca00092}},	//   zzon, _موو_, malb, ገለግሉ_, 
   {{0x6e20a3dc,0xb4d41fbc,0x69dc10bf,0x63a00d2e}},	//   lalb, हतो_, _vzpe, yzon, 
   {{0x18a00b00,0x63a0607b,0x00000000,0x00000000}},	// [cf60] хатм, xzon, --, --, 
   {{0x6e20a3dd,0x96600022,0x6bd44ea7,0x00000000}},	//   nalb, нкуе, _وتکر, --, 
   {{0x69dc0171,0x499412fd,0x00000000,0x00000000}},	//   _uzpe, _غیرر, --, --, 
   {{0x6e20a3de,0x63a0a3df,0x7d1c054e,0x18b00150}},	//   halb, tzon, ârsi, _зәур, 
   {{0x6e2002d5,0xb9200521,0x656c0175,0xc29400f2}},	//   kalb, kasị_, _wrbh, ویرب, 
   {{0x63a0a3e0,0x6e20a3e1,0xf654023a,0xaabc2886}},	//   rzon, jalb, _отсю, ोविक, 
   {{0x63a0a3e2,0x81d400bd,0x6e20a3e3,0xa97800c8}},	//   szon, সেন_, dalb, מאַכ, 
   {{0x63a0a3e4,0x68fc014f,0x55b80375,0x95800354}},	//   pzon, _mupd, _המלו, _ялсе, 
   {{0xd0041b88,0x68fc047e,0x6e200142,0xaabc0b98}},	//   чење_, _lupd, falb, ोवाक, 
   {{0x6e20a3e5,0xb92002e3,0x6298a3e6,0x9e6400c6}},	//   galb, gasị_, _ulto, ساخن, 
   {{0x68fc0477,0x2ef800db,0x8af006be,0x00000000}},	//   _nupd, ísfr_, _urəy, --, 
   {{0xd1940302,0xeeb800db,0x00000000,0x00000000}},	//   _מכבי_, йлөш_, --, --, 
   {{0x9f40a3e7,0x29180113,0x6e20a3e8,0xb920063f}},	//   äkä_, _awpa_, balb, basị_, 
   {{0x6e200857,0xbea805d9,0x93500092,0x00000000}},	//   calb, _گهڻن_, _መግባታ, --, 
   {{0xb89401ed,0x78a0017a,0x52d4010f,0x00000000}},	//   وارڈ, ëlvo, פולע_, --, 
   {{0x68fc0455,0x81bc00ef,0xc86400c7,0x00000000}},	//   _dupd, _ieēd, нтуи, --, 
   {{0x7c2ca3e9,0x64ac01e4,0x00000000,0x00000000}},	// [cf70] _idar, rŝil, --, --, 
   {{0x79581d0f,0xd6d8a3ea,0x4bd83092,0xb4d408df}},	//   _диор_, ёта_, _عبيد_, हत्_, 
   {{0x7c2c009a,0xe9f00124,0x37f8008e,0xf90400f2}},	//   _kdar, _аҧры, _менэ_, _تأخی, 
   {{0xfbe0012c,0x73d800f3,0x7c2ca3eb,0x00000000}},	//   _नराम, одер_, _jdar, --, 
   {{0x3868a3ec,0x3878a3ed,0x81d40154,0x00000000}},	//   mdar_, _insr_, সেম_, --, 
   {{0x3868a3ee,0x6e200077,0x00000000,0x00000000}},	//   ldar_, xalb, --, --, 
   {{0x6e20a3ef,0x7c2c143c,0x776c1709,0x7ae401ab}},	//   valb, _odar, lvax, _mhht, 
   {{0x7c2ca3f0,0x6e200009,0xb9200521,0x00000000}},	//   _ndar, walb, wasị_, --, 
   {{0x6e20a3f1,0x3868a3f2,0x2ee401c0,0xb9d80092}},	//   talb, idar_, мжиг, _በግ_, 
   {{0x38680e89,0x00000000,0x00000000,0x00000000}},	//   hdar_, --, --, --, 
   {{0x6da41173,0x6e201061,0x3868a3f3,0x776c01a9}},	//   фина, ralb, kdar_, hvax, 
   {{0x7c2c005a,0xb92001f2,0x68fc0477,0x38680200}},	//   _cdar, sasị_, _rupd, jdar_, 
   {{0x3868a3f4,0x7c2c0cfd,0xdfcc00b2,0xfeb804d3}},	//   ddar_, _ddar, _پيو_, _کانت_, 
   {{0x7c2c09a5,0x5fe00073,0x6e200009,0x00000000}},	//   _edar, _परतल, qalb, --, 
   {{0xd9404cbe,0xec140131,0x68fc0455,0xdb2001d3}},	//   кери, _قوغد, _qupd, _یوٹی, 
   {{0x3868022c,0x6da40daf,0x68fc014f,0x00000000}},	//   gdar_, _ниһа, _vupd, --, 
   {{0x7c641b56,0x38780334,0xe69407d6,0x00000000}},	// [cf80] _سايل, _dnsr_, ولرد, --, 
   {{0x7c2ca3f5,0x3868a3f6,0xe5d816a4,0x68fc01a9}},	//   _zdar, adar_, офеј_, _tupd, 
   {{0x68fc0280,0xf60800f1,0x74440240,0x00000000}},	//   _uupd, ستله_, _ዘምጽእ, --, 
   {{0x7c2c00d7,0xacd400d1,0x00000000,0x00000000}},	//   _xdar, ﯜﺭﯛﺷ, --, --, 
   {{0x7e6844b3,0x161400db,0x00000000,0x00000000}},	//   yddp, سسەڭ, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xded002d3,0x26d80165,0x6734035a,0xd5446e27}},	//   _ከለኻ_, mlpo_, lryj, _опре_, 
   {{0x30e4a3f7,0x55e0a3f8,0x00000000,0x00000000}},	//   нсың, _росб, --, --, 
   {{0xc0f80023,0xdd2c013a,0x00000000,0x00000000}},	//   _ወዶም_, děše, --, --, 
   {{0x24840b91,0x7c2c05d5,0x3868a3f9,0x931000db}},	//   ljom_, _sdar, zdar_, _شومش, 
   {{0x6008a3fa,0x00000000,0x00000000,0x00000000}},	//   _днем_, --, --, --, 
   {{0x6fc806ab,0x67342320,0x61080393,0x68e400b5}},	//   _हुकू, kryj, _cęle, _nhkd, 
   {{0x3868a30c,0x60c0009a,0xded002d3,0x2a78020b}},	//   vdar_, _ijom, _ከለኹ_, _bnpb_, 
   {{0x1cb00156,0xda782626,0xd91800c7,0x7e4800e5}},	//   དོང_, цям_, жьа_, _رستہ_, 
   {{0x38680fe8,0x480c063f,0x00000000,0x00000000}},	//   tdar_, _ọzịz, --, --, 
   {{0xdd8c066d,0x68e400b5,0x3868a3fb,0x67340200}},	//   _موڈ_, _chkd, udar_, fryj, 
   {{0x3868a3fc,0xda6451d1,0x60c000ec,0x2484110c}},	// [cf90] rdar_, _قادي, _mjom, djom_, 
   {{0x76d40491,0x3868a3fd,0xd6d83334,0x60c00158}},	//   رياض, sdar_, іта_, _ljom, 
   {{0x3868a3fe,0xd5080075,0x60c002d0,0x6734127b}},	//   pdar_, زغان_, _ojom, aryj, 
   {{0xf4140c58,0x2c7804cc,0x3868a3ff,0x00000000}},	//   _ডাঙৰ_, müdà_, qdar_, --, 
   {{0x2c7804cc,0xc1d400d1,0x977c0408,0xd05803b9}},	//   lüdà_, _ﭘﺎﺭﺍ, _тунă_, cmuə, 
   {{0x95c8a400,0x24640024,0x60c0078f,0xb1442377}},	//   _дуба_, _rūmų_, _ajom, енкл, 
   {{0xae1c01d9,0x60c00327,0x44f400cf,0x00000000}},	//   फरसन_, _bjom, رسۅز, --, 
   {{0x6f647327,0x2484012d,0xef1801d5,0x00000000}},	//   евиз, cjom_, пми_, --, 
   {{0xb900081f,0x60c000f3,0xdd2c00bc,0x69d407d0}},	//   _སེ_, _djom, věše, _मुनी, 
   {{0x60c00099,0x52742162,0xf1040137,0xed34009d}},	//   _ejom, _تارز, _كۉتۉ_, нэмэ, 
   {{0xa6e009cc,0xdd2c00bc,0x00000000,0x00000000}},	//   íðin, těše, --, --, 
   {{0x67340209,0x1ee801ed,0x60c00200,0x657800e5}},	//   yryj, _ہونی_, _gjom, _áthe, 
   {{0xf3f80356,0x5c040451,0xaa500023,0xb14c0162}},	//   _baţi_, رڪيٽ_, _ምምልላ, óðfí, 
   {{0x1ee8158b,0x69d8000d,0x00000000,0x00000000}},	//   _فونی_, üteo, --, --, 
   {{0xf3f80276,0x999c1b0d,0xcc1400db,0x00000000}},	//   _daţi_, ğuş_, _ичпө, --, 
   {{0xd5b4004d,0xebe40117,0x00000000,0x00000000}},	//   _ứng_, _пойп, --, --, 
   {{0x17c40212,0xa6e4a401,0xe7a830c7,0xa7a800d8}},	// [cfa0] егти_, ежал, чвал_, чкаа_, 
   {{0xe5a418ec,0x6734a402,0x28f859e6,0xe618003b}},	//   низи, rryj, _нэмэ_, їде_, 
   {{0xe4580b32,0x8fc800fb,0x2484a403,0x00000000}},	//   зже_, hир_, tjom_, --, 
   {{0xe4d48ce2,0xa344004e,0x442000c7,0x00000000}},	//   رتاب, еэкл, úi_, --, 
   {{0x779003e6,0x60c005ac,0x7d1c00e5,0xd7f8011a}},	//   _پیلا, _rjom, ársz, _מהכל, 
   {{0x2164a404,0x60c0032e,0x00000000,0x00000000}},	//   етиг, _sjom, --, --, 
   {{0x55e0a405,0x64a4a406,0xe1940b83,0x71000124}},	//   _борб, _зава, эрдэ, аҧха, 
   {{0xe2a8a407,0x91b4007b,0x40a86646,0x00000000}},	//   _کارن_, عطور_, بختی_, --, 
   {{0x22b40034,0x7994033f,0x2418013d,0x00000000}},	//   ałka_, zyzw, _моңы_, --, 
   {{0x22b4012d,0x216800d8,0x72e4014b,0x00000000}},	//   błka_, _низи_, _абуҷ, --, 
   {{0x5fe005ba,0x1e840cef,0x60c00af9,0x69d80037}},	//   _परवल, _үлем, _tjom, ütel, 
   {{0x6440a408,0x2c7804cc,0x00000000,0x00000000}},	//   ngoi, vüdà_, --, --, 
   {{0xc314015b,0xd71003d4,0x907400df,0xcc2801c4}},	//   _সিডি_, িওৱা_, _רעדא_, эцэд_, 
   {{0x9e6400aa,0x64400076,0x9a8401a9,0xdc1008a9}},	//   _ساتن, hgoi, хумл, rşık, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8e800022,0xf8bc0bae,0x4dd8011a,0x00000000}},	//   _агәе, ्केप, _מחוו, --, 
   {{0x36d4084c,0x6d4400e4,0x00000000,0x00000000}},	// [cfb0] воар, _ãhar, --, --, 
   {{0x3a7400db,0x00000000,0x00000000,0x00000000}},	//   _рлор, --, --, --, 
   {{0xceb010df,0x3ce80070,0x2cb00076,0x644002d0}},	//   ניע_, _khav_, _ymyd_, fgoi, 
   {{0x644000ad,0x00000000,0x00000000,0x00000000}},	//   ggoi, --, --, --, 
   {{0xd1d40020,0x290c0240,0x87e40395,0x00000000}},	//   ይይት_, _çfar_, _бюре, --, 
   {{0x1db0095f,0x56f00166,0xf4d000eb,0x00000000}},	//   ुपात, _сүзс, িষেব, --, 
   {{0xa154026a,0x6fc806ab,0xc0cc02d3,0x81d4015b}},	//   вају_, _हुजू, _ኣለም_, সেস_, 
   {{0x47a800cc,0x45d4004e,0x00000000,0x00000000}},	//   _কুটী, _сосс, --, --, 
   {{0xc62403f4,0x00000000,0x00000000,0x00000000}},	//   _পাতা_, --, --, --, 
   {{0x8ea01e4a,0x00000000,0x00000000,0x00000000}},	//   الدۇ, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7d04a409,0x3ce8a40a,0xf8bc2894,0x69d8a40b}},	//   _čist, _chav_, ्कोप, ütem, 
   {{0xdd8c07d6,0x70dc0892,0x00000000,0x00000000}},	//   موی_, मतील, --, --, 
   {{0x63a4013d,0x6abc012d,0x00000000,0x00000000}},	//   _ükne, ोवेर, --, --, 
   {{0x6da4a40c,0xada416c3,0x291c180f,0x377401ec}},	//   _шика, _шакл, èta_, қытс, 
   {{0xd6c00154,0xd9400063,0x00000000,0x00000000}},	//   ্গোপ, јети, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [cfc0] --, --, --, --, 
   {{0xa594030d,0x87e40132,0x00000000,0x00000000}},	//   крещ, _ەتسە, --, --, 
   {{0x332c04ce,0x6440a40d,0xa9a45e0c,0xa8c40395}},	//   _avex_, tgoi, _ринд, _айнд, 
   {{0xe3b8a40e,0x6fc00490,0x47c400fe,0x00000000}},	//   мбе_, शपां, _শৰণী, --, 
   {{0x93408d61,0x77680077,0x37740032,0xa6a80150}},	//   инце, _áexp, _йырс, _قاسق_, 
   {{0x644000a3,0x02dc07b7,0x76f40064,0x00000000}},	//   sgoi, यतेन, _бясх, --, 
   {{0xe4c82264,0xa6e008a7,0x20c44eca,0x00000000}},	//   _قبرن_, íðun, ксиг, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x1ccc3ae9,0x4424a40f,0x7ea4004e,0xd1d4001f}},	//   ྱོལ_, _iem_, _lòpe, ይይቱ_, 
   {{0x4424a410,0x33d402d5,0x3ce8007f,0x6264021f}},	//   _hem_, _сіст, _shav_, _جارق, 
   {{0x4424a411,0x3ce801d4,0xe0440124,0x00000000}},	//   _kem_, _phav_, _анеи, --, 
   {{0x80e003f4,0x4424a412,0xd12ca413,0x62880fac}},	//   _পূর্, _jem_, _ذمه_, ljfo, 
   {{0x4424a414,0xd004a415,0x2d8400e8,0x8fa00064}},	//   _mem_, _рече_, axle_, _каце, 
   {{0x4424a416,0x7f4016b8,0xdd900032,0x0f5402e4}},	//   _lem_, mumq, _ҡаҙы, _סיום_, 
   {{0x81d403f4,0x3ce80218,0x7f4016b8,0x4ef8008f}},	//   সের_, _thav_, lumq, _קלוג, 
   {{0x4424a417,0xf1b4007d,0x00000000,0x00000000}},	//   _nem_, _अइसन, --, --, 
   {{0x7f4016b8,0x80cc02f5,0xe7ec0ce0,0xc3080154}},	// [cfd0] numq, াতপ্, चेला_, রীতি_, 
   {{0xed4c55b4,0xd5b822f9,0x6f0c00d8,0x7f400393}},	//   _بھی_, мсе_, _éace, iumq, 
   {{0x44240cfc,0x79941ee3,0x7f40003a,0x00000000}},	//   _bem_, _синф, humq, --, 
   {{0x4424a418,0x7f400921,0x70e0000d,0x00000000}},	//   _cem_, kumq, _पठेल, --, 
   {{0x4424a419,0x473402d5,0x8364007b,0x4784004e}},	//   _dem_, _княс, لدول, _кырб, 
   {{0x4424a41a,0x7f4016b8,0x00000000,0x00000000}},	//   _eem_, dumq, --, --, 
   {{0x7f40003a,0x2bd8503c,0xd2f410e8,0x222801e2}},	//   eumq, _युना, _یکتا_, رزوی_, 
   {{0x65780aaa,0x1ccc025c,0xdcf80024,0x44242238}},	//   _átha, ྱོས_, mytė, _gem_, 
   {{0x81d439db,0x7f40a41b,0x332c6d37,0x1cb00327}},	//   সেল_, gumq, _uvex_, དོན_, 
   {{0x4424a41c,0x76440097,0x2aa4145e,0x69d80254}},	//   _zem_, nghy, _kôbe_, ütek, 
   {{0x4424a41d,0x7644062c,0x836402dd,0xdcf80153}},	//   _yem_, ighy, _مدەل, nytė, 
   {{0x4424431d,0x7f400393,0x7644062c,0x2d840076}},	//   _xem_, bumq, hghy, rxle_, 
   {{0x7f400483,0x00000000,0x00000000,0x00000000}},	//   cumq, --, --, --, 
   {{0xa968006c,0xdcf80153,0x18640131,0x00000000}},	//   нига_, kytė, һаси_, --, 
   {{0xed3401c0,0xdcf800c0,0xd37800c0,0x00000000}},	//   _сэлэ, jytė, _нiчы, --, 
   {{0x6d40a41e,0x1864a41f,0x76440363,0xc31400eb}},	//   mula, ласи_, eghy, _সিসি_, 
   {{0x4424a420,0xeb98a421,0x39640023,0x628c01e1}},	// [cfe0] _rem_, _чип_, _ትውልዲ_, _òbog, 
   {{0x4424a422,0x76440072,0x27e400df,0xdd00000d}},	//   _sem_, gghy, ĥon_, _रूँध_, 
   {{0x6d40a423,0x4424a424,0xe8f8119e,0xdcf80064}},	//   nula, _pem_, _пло_, gytė, 
   {{0xb8e804c5,0x4424047e,0x76440731,0x02dc00cd}},	//   _লী_, _qem_, aghy, यत्न, 
   {{0x4424a425,0x6d40a426,0x7f400393,0x6f08014f}},	//   _vem_, hula, xumq, jqec, 
   {{0x4424a427,0x93c801ed,0xb354158f,0x7f40a428}},	//   _wem_, رانہ_, شیما_, vumq, 
   {{0x4424a429,0x6d40a42a,0x69dc0117,0x7f40379d}},	//   _tem_, jula, _jype, wumq, 
   {{0x7f401730,0x44240327,0x69dc0ac5,0x5180a42b}},	//   tumq, _uem_, _mype, суша, 
   {{0x69d40c2e,0xef0c004b,0x7f40003a,0x69dc036e}},	//   _मुसी, وڼو_, uumq, _lype, 
   {{0x6d40a42c,0x7f400483,0x35d800c5,0x00000000}},	//   fula, rumq, _बुड़, --, 
   {{0x6d40a42d,0x7f40a42e,0x00000000,0x00000000}},	//   gula, sumq, --, --, 
   {{0x7f400393,0x6f08014f,0x00000000,0x00000000}},	//   pumq, bqec, --, --, 
   {{0x6d40a42f,0x764400ad,0x7f40014f,0x2ea400e5}},	//   aula, yghy, qumq, _چھپی_, 
   {{0xb0600209,0x6d40a430,0xedb400dd,0x69dc0142}},	//   _çäre, bula, اجیک, _bype, 
   {{0x69dca431,0x35d8a432,0xc9840d44,0x32fc010b}},	//   _cype, _बुढ़, бути, _oňyn_, 
   {{0x69dc0212,0xc4c401d3,0x381401d5,0xcd3006c2}},	//   _dype, _رے_, рмаё, _اروب, 
   {{0x29080009,0xded00023,0xdb0c01f4,0x00000000}},	// [cff0] aqba_, _ከለን_, öjät, --, 
   {{0x65ac1682,0xba5414b7,0xdcf80024,0x550401c0}},	//   _ṱhal, _твој, tytė, гчда, 
   {{0x69dc0204,0x35b40a5b,0x00000000,0x00000000}},	//   _gype, јбер, --, --, 
   {{0xb4c0007d,0x337407d5,0x00000000,0x00000000}},	//   ुवे_, игер, --, --, 
   {{0x69dc0d16,0xd7d8037e,0x59d803e5,0xc6240154}},	//   _zype, _inワ_, _मँडर, _পারা_, 
   {{0x6d407bc0,0x05d007f7,0xdcf80153,0xd68400ea}},	//   yula, _तुकब, pytė, _сумп, 
   {{0x6d40a433,0x53440166,0x3950007c,0xf3c81bf4}},	//   xula, _әхба, ntzs_, ربچه_, 
   {{0x6d40a434,0x27e4068f,0x2f54a435,0x307400cf}},	//   vula, żone_, атос, рукс, 
   {{0x6d40a436,0xa908022e,0x64ac0115,0xef180395}},	//   wula, _prоk, rŝit, ъмп_, 
   {{0x81d40011,0x3134010a,0xaf04004e,0x00000000}},	//   সেই_, _вежр, лчүк, --, 
   {{0x6d401c06,0x51940408,0xc0f80092,0x00000000}},	//   uula, _сăна, ገረም_, --, 
   {{0x6d4005d1,0xeb98a437,0x69dc03cd,0xa1a400fb}},	//   rula, вим_, _rype, _тыуһ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69dc0124,0xee38a438,0x64ac0115,0x8af003b9}},	//   _pype, _рнк_, nŝir, _ipək, 
   {{0x6d40a439,0x7bcca43a,0xc6240154,0x69dc002f}},	//   qula, _exau, _পালা_, _qype, 
   {{0x69dc02fb,0xb4c04196,0x7bd00438,0xeb600092}},	//   _vype, ुवो_, ékué, _ድጋፍና_, 
  
   {{0x98a021ca,0x69dc0034,0xd70400a8,0x18641363}},	// [d000] ците, _wype, инте_, шати_, 
   {{0xa9a400db,0x00000000,0x00000000,0x00000000}},	//   _ەمگى, --, --, --, 
   {{0xbbe8036b,0xa424074d,0x2908031c,0x9a38011a}},	//   _لریم_, аьлл, qqba_, _בתיק, 
   {{0x261460d3,0x18b002dd,0x64a4041b,0x9f940037}},	//   _प्री_, _дәур, јада, tüüp_, 
   {{0xe8e00490,0x00000000,0x00000000,0x00000000}},	//   पतीच, --, --, --, 
   {{0x9f500241,0x0b980092,0x00000000,0x00000000}},	//   _àyé_, ህርዳር_, --, --, 
   {{0xc448a43b,0xa0a401b9,0x20000427,0x403404b3}},	//   _میان_, ишил, žkim_, бейс, 
   {{0x2000022c,0xb24401e0,0x00000000,0x00000000}},	//   øki_, амәһ, --, --, 
   {{0x73c01cd1,0x33d400d4,0xe28400f3,0x00000000}},	//   _нәше, _ліфт, _клаи, --, 
   {{0x9e041f71,0xa2e465a7,0x1d8800ec,0x00000000}},	//   шчил, _тозд, نئجي_, --, 
   {{0xa0a4169c,0x69d40574,0xd00ca43c,0x00000000}},	//   _кажд, _मुली, _мф_, --, 
   {{0x80e0045e,0x628c01e1,0x00000000,0x00000000}},	//   _পংক্, _òbob, --, --, 
   {{0xdfd01ff7,0x00000000,0x00000000,0x00000000}},	//   _بيش_, --, --, --, 
   {{0xdd90a43d,0x63580a28,0x8f9802e4,0x00000000}},	//   _ووش_, mānā, _בידי, --, 
   {{0xded002d3,0x49c8005b,0xa5c400b8,0x00000000}},	//   _ከለና_, алён_, _yaųņ, --, 
   {{0x7bcc0190,0x48a89cb8,0x69d40073,0xd13801f3}},	//   _txau, атум_, _मुळी, _አይበል, 
   {{0x63580882,0xd77400db,0x00000000,0x00000000}},	// [d010] nānā, جازع, --, --, 
   {{0xc7c402bf,0x89d80014,0xb6c42c12,0x41b80263}},	//   істи, _چوٝر_, сөмд, ेपास, 
   {{0x63580a28,0x89d801d9,0x596402e8,0x00000000}},	//   hānā, _نوٝر_, _тъпа, --, 
   {{0x6358a43e,0x00000000,0x00000000,0x00000000}},	//   kānā, --, --, --, 
   {{0xd7f815ed,0x63580882,0xd6d80a0e,0x69d80254}},	//   _јун_, jānā, _атв_, ütev, 
   {{0x63580882,0xd5140532,0xc618030d,0x00000000}},	//   dānā, _نظرب, _ворх_, --, 
   {{0x2aa40109,0x64ac00df,0x00000000,0x00000000}},	//   _jôba_, rŝir, --, --, 
   {{0x7ea401ab,0xed5802a9,0x64ac00df,0x00000000}},	//   _ròpa, қом_, sŝir, --, 
   {{0x600407d8,0x64ac0115,0x35a40139,0x00000000}},	//   щным_, mŝip, _таңг, --, 
   {{0x64ac010f,0xdfcc00ec,0xd1382cdd,0x00000000}},	//   lŝip, رڊن_, _ахд_, --, 
   {{0x64ac01e4,0x3074a43f,0xed580063,0x61c000dc}},	//   oŝip, _гулс, ћом_, षपृष, 
   {{0x64ac0115,0xe20408a5,0x635800ef,0x00000000}},	//   nŝip, _þóru_, bānā, --, 
   {{0xc0ac010f,0x6358002b,0x00000000,0x00000000}},	//   _ביאָ, cānā, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x64ac01e4,0x7de402dd,0x8d743c5a,0xed58a440}},	//   kŝip, _وسىم, _خاشا, _сой_, 
   {{0x13dc0c58,0xa8880137,0x26186d65,0xe8e805af}},	//   বেয়, ыйба_, मुनी_, ارسو_, 
   {{0x32040209,0x64ac01e4,0xe7080345,0xaa440798}},	// [d020] _ogly_, dŝip, اترن_, _лепл, 
   {{0x78a00af9,0xe7ec012d,0x00000000,0x00000000}},	//   ëlvr, चेगा_, --, --, 
   {{0xd704084c,0xdb1c0241,0x00000000,0x00000000}},	//   инӂе_, _àwòf, --, --, 
   {{0x1ccc0003,0x63580882,0xc4d40150,0xe73801ee}},	//   ྱོག_, yānā, _ﺘﻌﺒﺌ, _йем_, 
   {{0xe298a441,0xa2e4036b,0x68f40076,0x00000000}},	//   лад_, бодд, mmyd, --, 
   {{0x2900a442,0x63580a28,0x5330084c,0x68f4a443}},	//   _hika_, vānā, чешт, lmyd, 
   {{0x2900a444,0x26d80bd7,0x04884eac,0x35c4039b}},	//   _kika_, mopo_, _вәли_, _дарҳ, 
   {{0x2900a445,0x26d8a446,0x63580882,0x3f14a447}},	//   _jika_, lopo_, tānā, одис, 
   {{0x63045085,0x74b80902,0x00000000,0x00000000}},	//   _طوال, _турс_, --, --, 
   {{0x2900a448,0x26d8a449,0x3eb80ba1,0x68f40432}},	//   _lika_, nopo_, òrt_, hmyd, 
   {{0xe0d41830,0x06c402f5,0x32240150,0xabe401ec}},	//   _людь, ্তপি, _بۋىپ_, _ﺍﺭﺍﻋ, 
   {{0x26d8a44a,0x2fc80219,0xdc8801e0,0x00000000}},	//   hopo_, _žage_, усол_, --, 
   {{0x26d8a44b,0x5f740137,0x6d44143a,0x3b080139}},	//   kopo_, _داار, _åhan, _quaq_, 
   {{0x2900a44c,0x1be407d6,0x1f240014,0x2d500022}},	//   _aika_, _қўйг, _نِچہ, báe_, 
   {{0x27e00280,0xc984a44d,0x8e4400db,0xcd30a44e}},	//   _aykn_, пути, _الىك_, _فريب, 
   {{0x290023db,0x2bd8a44f,0x7ea402e2,0xd7f800f7}},	//   _cika_, _युवा, _kòpo, гуз_, 
   {{0x2900a450,0x22b40034,0x656c078c,0x64ac01e4}},	// [d030] _dika_, ałki_, _asbh, vŝip, 
   {{0x29000086,0x26d8a451,0x8f98011a,0x3eac0051}},	//   _eika_, gopo_, אימי, nhdt_, 
   {{0x2900a452,0x2bd823cf,0x20000219,0x64ac0115}},	//   _fika_, _مایک_, žkih_, tŝip, 
   {{0x2900a453,0x27e40034,0x2004a454,0x8504004b}},	//   _gika_, żona_, _ngoi_, سوهن, 
   {{0x26d84d11,0x64ac010f,0x27ec0cad,0x00000000}},	//   bopo_, rŝip, _ọjọ́_, --, 
   {{0x2900180e,0x26d8a455,0x31140835,0x00000000}},	//   _zika_, copo_, офис, --, 
   {{0xa2d00491,0xa280a268,0x7d1803e0,0x29000248}},	//   بيوت, ظیمو, _ntvs, _yika_, 
   {{0x78aca456,0x290002b9,0x54340fa2,0x00000000}},	//   nhav, _xika_, _درسر, --, 
   {{0xfa0003f4,0xd1380020,0xb4d425c9,0xe80807f7}},	//   ্রিল_, _አይችል, सकी_, वशता_, 
   {{0x7d1801e4,0x78aca457,0x200401c4,0x3204a458}},	//   _btvs, hhav, _egoi_, _ugly_, 
   {{0xed580364,0x78aca459,0xfd440006,0x68f446f4}},	//   шон_, khav, пэўн, ymyd, 
   {{0x26d80451,0x78ac01d4,0x6f0c0798,0xc0c800f3}},	//   zopo_, jhav, _éaco, _луче_, 
   {{0x78aca45a,0x2900a45b,0x26d80451,0x7d180254}},	//   dhav, _rika_, yopo_, _etvs, 
   {{0x2900a45c,0xada4a45d,0x26d802b9,0x81d400eb}},	//   _sika_, _малл, xopo_, সেও_, 
   {{0x2900a45e,0xa9682be9,0x00000000,0x00000000}},	//   _pika_, шива_, --, --, 
   {{0x78aca45f,0x29000548,0xeb9800f3,0x00000000}},	//   ghav, _qika_, _вии_, --, 
   {{0x2900a460,0x26d8a461,0x68f45de2,0x6be40014}},	// [d040] _vika_, topo_, rmyd, _گژھہ_, 
   {{0x2900357f,0x6d40a462,0x81d400eb,0x65c40395}},	//   _wika_, orla, সেট_, обза, 
   {{0x2900a463,0x26d8a464,0x78ac0a28,0x787000e4}},	//   _tika_, ropo_, bhav, _ẽvei, 
   {{0x26d8a465,0x6d40a466,0x5c34010f,0xf98801f7}},	//   sopo_, irla, ַרצן_, _انٽي_, 
   {{0x26d80751,0x6d40a467,0x00000000,0x00000000}},	//   popo_, hrla, --, --, 
   {{0x6d4007d6,0x213800d2,0xa88400db,0x20040142}},	//   krla, ápho_, _الڭى, _sgoi_, 
   {{0x64a4a468,0x4034a469,0xd1380020,0x00000000}},	//   _дава, пейс, _አይቻል, --, 
   {{0xd5aca46a,0x6d40a46b,0x7d18a46c,0xc0340063}},	//   _شفق_, drla, _rtvs, чниј, 
   {{0x6d40a46d,0x50d000d1,0x7eb8004e,0x00000000}},	//   erla, بزور, йгис_, --, 
   {{0xfa000183,0xbdb4399f,0x6d400946,0x9f500241}},	//   ্ৰিল_, збој, frla, _àyí_, 
   {{0x78aca46e,0x81d4015b,0x6d4400cc,0x6d40022e}},	//   yhav, সেজ_, _åhal, grla, 
   {{0x78aca46f,0x6b8000da,0x225c0158,0x00000000}},	//   xhav, _šoga, _hbtk_, --, 
   {{0x4c94a470,0x6d40a471,0x78ac0943,0xeea8054a}},	//   фияс, arla, vhav, ртөк_, 
   {{0x6d405a5b,0x00000000,0x00000000,0x00000000}},	//   brla, --, --, --, 
   {{0x78aca472,0x59d80c4c,0xe1ec02dd,0x7e68035a}},	//   thav, _मुशर, нгi_, medp, 
   {{0xa3a8068f,0x7e680857,0x8d14179e,0x00000000}},	//   खना_, ledp, _بزور_, --, 
   {{0x69d8a473,0xd7f8036b,0x00000000,0x00000000}},	// [d050] üter, рув_, --, --, 
   {{0x7c2ca474,0x7e680c8c,0xc69000f1,0x00000000}},	//   _hear, nedp, نېټ_, --, 
   {{0x7c2ca475,0x78aca476,0xbb500150,0x00000000}},	//   _kear, phav, _ﺎﺤﻥ_, --, 
   {{0xb4d4068f,0x7c2ca477,0x78ac0784,0x81bc00a2}},	//   सके_, _jear, qhav, _geēi, 
   {{0xdfc40491,0x3868a478,0x7ea4068c,0x733400d1}},	//   _أي_, mear_, _pòpl, سىغا, 
   {{0x3868a479,0xdd84a47a,0x7c2c69d1,0x6d40a47b}},	//   lear_, _كو_, _lear, yrla, 
   {{0x7e680c8c,0x776c0009,0x6d4001b9,0x942000d1}},	//   dedp, lwax, xrla, _يوسۇ, 
   {{0x3868a47c,0x6d40a47d,0x7c2c9427,0x00000000}},	//   near_, vrla, _near, --, 
   {{0x92680276,0x776c058a,0x7e6802d0,0x22b40210}},	//   _вреа_, nwax, fedp, ełku_, 
   {{0x3868a47e,0x7c2c00b0,0x6d40a47f,0xee38082d}},	//   hear_, _aear, trla, щно_, 
   {{0x6d40a480,0x7c2ca481,0x776c0472,0x3868307c}},	//   urla, _bear, hwax, kear_, 
   {{0x7c2c387b,0xc104a482,0x6d40a483,0xd7d8037e}},	//   _cear, _قولي, rrla, _inユ_, 
   {{0x7c2ca484,0xdd8ca485,0x3868a486,0x8fc404d3}},	//   _dear, نوی_, dear_, _بزان, 
   {{0x7c2c0363,0x38680076,0x7e68127b,0xe81c00cd}},	//   _eear, eear_, cedp, युना_, 
   {{0x3868a487,0xada4a488,0x9f4002f6,0xda6005f5}},	//   fear_, _хайл, äkö_, эври, 
   {{0x7c2ca489,0x3868a48a,0xb4d48a57,0xf41003d4}},	//   _gear, gear_, सको_, াৰতৰ_, 
   {{0xe738a48b,0x00000000,0x00000000,0x00000000}},	// [d060] сез_, --, --, --, 
   {{0x7c2ca48c,0x27e4012d,0xd7ec007b,0x65f80166}},	//   _zear, żono_, اكك_, бэер_, 
   {{0x6abca48d,0x7c2ca48e,0x776c0009,0x00000000}},	//   _impf, _year, awax, --, 
   {{0x3868a48f,0x6abc525e,0x7e68a490,0x2a6801ed}},	//   cear_, _hmpf, zedp, lebb_, 
   {{0x638401c0,0xa2e40d1d,0xdc34010f,0x61340432}},	//   ягда, подд, פאסט_, külý, 
   {{0x3f8002d5,0x7e6802d0,0x2a68a491,0x00000000}},	//   _šiuo_, xedp, nebb_, --, 
   {{0x7e68a492,0x6134010e,0x00000000,0x00000000}},	//   vedp, dülý, --, --, 
   {{0x25aca493,0x2fc80219,0x225000c0,0x00000000}},	//   ıklı_, _žaga_, _šaką_, --, 
   {{0x7e680c8c,0xe298a229,0x00000000,0x00000000}},	//   tedp, _лаа_, --, --, 
   {{0x7c2ca494,0x63a0a495,0x386801c6,0x613400a2}},	//   _sear, myon, zear_, gülý, 
   {{0x7c2ca496,0x63a0a497,0x3868a498,0x7e68127b}},	//   _pear, lyon, year_, redp, 
   {{0x6298a499,0x6abca49a,0x7e680c8c,0x3868056a}},	//   _hoto, _ampf, sedp, xear_, 
   {{0x6298a49b,0x7c2ca49c,0xd00c00c6,0xdef864c2}},	//   _koto, _vear, _إله_, _лык_, 
   {{0x6298a49d,0x63a00086,0x7c2c69d1,0x2a6801d3}},	//   _joto, iyon, _wear, gebb_, 
   {{0x1ccc0ed9,0x38680491,0x63a076b7,0x7c2c9427}},	//   ྱོད_, tear_, hyon, _tear, 
   {{0x6298a49e,0x6abc0f2a,0x63a0a49f,0xaa6402d3}},	//   _loto, _empf, kyon, _ምዝርጋ, 
   {{0x4c3c025f,0x3868a4a0,0x63a0a4a1,0x4cbc011a}},	// [d070] _התחב, rear_, jyon, _לזהו, 
   {{0x3868a4a2,0x63a006e4,0xcb1400c8,0xdbd4023a}},	//   sear_, dyon, _אלץ_, rääm, 
   {{0x3868a4a3,0xaab40014,0xdbd4023a,0x63a00337}},	//   pear_, _آگُر_, sääm, eyon, 
   {{0x6298a4a4,0x63a0a4a5,0x293408a8,0xdbd4005b}},	//   _aoto, fyon, _קארן_, pääm, 
   {{0x63a0a4a6,0x00000000,0x00000000,0x00000000}},	//   gyon, --, --, --, 
   {{0xd05403be,0x7124a4a7,0x95d0010a,0x00000000}},	//   əcəy, ورعل, _пăла_, --, 
   {{0x63a0a4a8,0x320001f4,0x00000000,0x00000000}},	//   ayon, ähy_, --, --, 
   {{0xef18a4a9,0x17280dd4,0x92bc2f8b,0x63a0a4aa}},	//   оми_, _སྦོམ_, ীতে_, byon, 
   {{0x6298918b,0x63a0a4ab,0x32540364,0x33740598}},	//   _foto, cyon, _овар, _югар, 
   {{0x6b80107d,0xada401d5,0x00000000,0x00000000}},	//   _šogo, даол, --, --, 
   {{0xb7d40055,0x2a6801d3,0x2be800cc,0xd138010a}},	//   _iṣum, vebb_, _গলেই_, _ыха_, 
   {{0x6298a4ac,0xbc180220,0xc6240154,0x00000000}},	//   _zoto, зірі_, _পাছা_, --, 
   {{0x2a68a4ad,0x6298a4ae,0xb7d40055,0xfe780064}},	//   tebb_, _yoto, _kṣum, bdį_, 
   {{0xad240075,0xdd8c04d3,0xfe08216b,0xae0415bf}},	//   _قىتى, _چوو_, _فقهي_, _قوشى, 
   {{0x63a0a4af,0xdd8ca4b0,0xd97800c7,0xac1c010a}},	//   zyon, _نوو_, ортә_, _кайĕ_, 
   {{0x2a68066d,0x63a0a4b1,0x00000000,0x00000000}},	//   sebb_, yyon, --, --, 
   {{0x4438003e,0x63a00076,0x00000000,0x00000000}},	// [d080] _ěr_, xyon, --, --, 
   {{0xe5a497e6,0x63a000ec,0x6abc00ca,0x44380034}},	//   мизи, vyon, _umpf, _śr_, 
   {{0x1ccc0dd4,0x63a0007f,0x67340108,0x947000f1}},	//   ྱོཝ_, wyon, ssyj, ږدوا, 
   {{0x63a0033b,0x7ea4007f,0xfe780153,0xa3e800d8}},	//   tyon, _pòpk, zdį_, одеа_, 
   {{0x6f0c007b,0xaa640023,0x785400e5,0xaad09ea0}},	//   _éach, _ምምስጋ, _سیلز_, _सदाक, 
   {{0x63a0a4b2,0x6298a4b3,0x00000000,0x00000000}},	//   ryon, _qoto, --, --, 
   {{0x63a0a4b4,0x62981d62,0x81bc00de,0x91e00114}},	//   syon, _voto, _neēt, коље, 
   {{0x6298a4b5,0x5180a4b6,0x63a0a4b7,0x7980005c}},	//   _woto, туша, pyon, ålwi, 
   {{0x6298a4b8,0x2000a4b9,0xdef8a4ba,0x3038129e}},	//   _toto, äki_, жын_, ستيک_, 
   {{0x7e980597,0x6298003a,0x21680107,0xe2a8009f}},	//   سنجر_, _uoto, _мизи_, _بارن_, 
   {{0xfe780024,0xdbd40139,0x00000000,0x00000000}},	//   rdį_, _käçi, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xda780212,0x386c06be,0xb7c80154,0x00000000}},	//   ояв_, _ömrə_, _শর্ট, --, 
   {{0xe7e01533,0xeff002d3,0x00000000,0x00000000}},	//   _खड़ा_, _ግፍዒ_, --, --, 
   {{0x81bc00ef,0x00000000,0x00000000,0x00000000}},	//   _ieēs, --, --, --, 
   {{0xdbd400a2,0x9174010f,0x7dc401a9,0x00000000}},	//   _näçi, ועלף_, _оёқд, --, 
   {{0xcc340be2,0x8cdc033f,0xb788013d,0x00000000}},	// [d090] _شريع, नवरो, чәне_, --, 
   {{0x975c1e38,0x1ccc025c,0xf484a4bb,0x00000000}},	//   _ህይወት, ྱོམ_, کائی, --, 
   {{0x69f00323,0x7ae406df,0x7ea466e5,0x00000000}},	//   _бүрт, _ikht, _còpi, --, 
   {{0x7e7820e4,0x84241884,0xf3f80902,0xa23400c7}},	//   _lavp, نىمن, пнеш_, ҕьшә, 
   {{0xf0e80131,0x00000000,0x00000000,0x00000000}},	//   ۋىتى_, --, --, --, 
   {{0x7e78a4bc,0x0cbc190e,0x2fc80427,0x81bc0171}},	//   _navp, _उष्म, _žago_, _neēs, 
   {{0x06c404c5,0x3878a4bd,0x22901a02,0x00000000}},	//   ্তশি, _kasr_, الىس, --, 
   {{0x9dd80134,0xef1000cf,0x00000000,0x00000000}},	//   _ɔkɔɔ_, гүдө, --, --, 
   {{0x7ae4014b,0x7e78014f,0x06c4015b,0x00000000}},	//   _okht, _bavp, ্তরি, --, 
   {{0x6d24013e,0x2bd87fd5,0xbec400b8,0x00000000}},	//   ндоз, _युगा, _śūrp, --, 
   {{0x6cc40953,0x6da457a8,0x181c00dc,0xada40408}},	//   ейна, хина, _बभूव_, ханл, 
   {{0x3878a4be,0x7ae40656,0x8f801955,0xac0850cb}},	//   _nasr_, _akht, _ақил, янма_, 
   {{0x7654068f,0x7f94035b,0x25e40073,0x00000000}},	//   _oczy, _иацх, _जुनी_, --, 
   {{0xd7d800b5,0xb7c800fe,0x00000000,0x00000000}},	//   _abハ_, _শৰ্ট, --, --, 
   {{0x291ca4bf,0xccf802dd,0xa2b000cd,0x00000000}},	//   ëta_, _оқо_, _अतस्, --, 
   {{0x291c4114,0x38780009,0x7e780010,0x8c6400c7}},	//   īta_, _casr_, _zavp, _реиҵ, 
   {{0x2b440597,0x291ca4c0,0xa68401b9,0x2600000d}},	// [d0a0] _íoc_, ūta_, нлад, वेनी_, 
   {{0x9bb4011a,0x59d8134e,0x00000000,0x00000000}},	//   _נהיה_, _मुकर, --, --, 
   {{0x64a4a4c1,0xa444a4c2,0xa5249111,0xba0400c7}},	//   нажа, енед, хмед, _аҭра_, 
   {{0x6844a4c3,0xd918011a,0x00000000,0x00000000}},	//   _янма, _מוטל, --, --, 
   {{0x2a78007f,0x81bc00e2,0xa5c40210,0x4aa401f9}},	//   _kapb_, _neēr, dnóż, _ऐकाव, 
   {{0x7ea400cf,0x04f00154,0x02bc043e,0x64a4035b}},	//   _tòpi, টদের_, ्चेन, ьаҵа, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7e7805c7,0x00000000,0x00000000,0x00000000}},	//   _savp, --, --, --, 
   {{0xa3443fff,0xb35416f5,0x638401c0,0x7e7801ef}},	//   _سپاه, _لینا_, _ягаа, _pavp, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa00800c6,0x7e78047e,0x00000000,0x00000000}},	//   _فقال_, _vavp, --, --, 
   {{0x7e78014f,0xddc801ef,0x00000000,0x00000000}},	//   _wavp, _nafť, --, --, 
   {{0x60c0a4c4,0x3b8c0092,0x00000000,0x00000000}},	//   _imom, _ዕጩዎች_, --, --, 
   {{0xda78084c,0xd090035b,0x8f18011a,0x5ef80354}},	//   чям_, _ашәы, _צוות, _эхер_, 
   {{0xc3246886,0x59d8150d,0x8aa40138,0xdbd40108}},	//   _گە_, _मुखर, уряд, _sääi, 
   {{0x38781eca,0xdbd401f4,0x00000000,0x00000000}},	//   _qasr_, _pääi, --, --, 
   {{0xc3248337,0x60c0806e,0x7bf800fb,0x35d80210}},	// [d0b0] _دە_, _mmom, _юнир_, _बुज़, 
   {{0x7ae40a2e,0x629c3f41,0xb6c40137,0x3914023b}},	//   _ukht, öpol, төмд, _имор, 
   {{0x387801a2,0x60c007dd,0x451800d4,0xd5641f39}},	//   _tasr_, _omom, еція_, этап, 
   {{0x54e41e87,0x7654012d,0x497400d4,0x850400ae}},	//   رساق, _wczy, _слюс, هولن, 
   {{0x6d442b96,0xd3240124,0x00000000,0x00000000}},	//   _åhav, хьеи, --, --, 
   {{0x60c0a4c5,0x76540034,0xcb140a1e,0x35f400f5}},	//   _amom, _uczy, אלס_, _апгр, 
   {{0x8234314e,0xa2b0043e,0x00000000,0x00000000}},	//   ارها, _अतर्, --, --, 
   {{0xb7f408e9,0xafe40137,0xd4986135,0xd404010a}},	//   _आराम_, койл, _эрг_, _зязи, 
   {{0xb274a4c6,0x65780332,0xb4dc23e9,0x00000000}},	//   _илаш, _áthr, डवी_, --, 
   {{0x38b48fa2,0x25e406ab,0x60c0a4c7,0x7984009a}},	//   _hård_, _जुडी_, _emom, _orhw, 
   {{0xc0f40092,0x00000000,0x00000000,0x00000000}},	//   ጉሙም_, --, --, --, 
   {{0x65780142,0x27e40327,0x7d1c00e5,0x00000000}},	//   _âthe, żoni_, írsa, --, 
   {{0x79840488,0x1c4006a6,0x38b4007c,0x684800ef}},	//   _arhw, шням, _mård_, _jūdž, 
   {{0xa96807d6,0x2e6800d8,0x00000000,0x00000000}},	//   мига_, _цикп_, --, --, 
   {{0x6cd8a4c8,0x2a780204,0xd8840014,0xacf400f3}},	//   _офис_, _vapb_, چھُن_, _ичиј, 
   {{0x186447b3,0x00000000,0x00000000,0x00000000}},	//   каси_, --, --, --, 
   {{0x7c280077,0xa804a4c9,0x00000000,0x00000000}},	// [d0c0] ñere, тзал, --, --, 
   {{0x6f0c00d8,0x7cd801e4,0xeaf8a4ca,0xa8500022}},	//   _éacu, rĉre, _تربت_, ыҵҭә, 
   {{0xe458a4cb,0xe8f80184,0x38b408fb,0x68e400b5}},	//   дже_, _оло_, _bård_, _tkkd, 
   {{0xf48402dd,0xe81c0073,0x00000000,0x00000000}},	//   луін, युशा_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd36c009f,0x00000000,0x00000000,0x00000000}},	//   تهه_, --, --, --, 
   {{0x60c000e4,0x2448007b,0x00000000,0x00000000}},	//   _pmom, _يجري_, --, --, 
   {{0x38b43be7,0x2600190e,0x00000000,0x00000000}},	//   _gård_, वेणी_, --, --, 
   {{0xbb5000b5,0x68480064,0x00000000,0x00000000}},	//   _manペ_, _gūdž, --, --, 
   {{0xe1240323,0xfd4c0084,0xd35405d0,0x63040066}},	//   _амжи, _zwiṅ, _בימי_, _شوال, 
   {{0x7c3406bd,0x3c580276,0x1cc40327,0xa114029e}},	//   ленх, нинэ_, _ྋཏཱ_, _شوشت, 
   {{0x213c03a2,0x60c00b45,0x38b4119a,0x2cb00042}},	//   _ivth_, _umom, _kåre_, _clyd_, 
   {{0xdb4c0133,0x59d80b03,0x00000000,0x00000000}},	//   ڕێک_, _मुजर, --, --, 
   {{0x7ea4a4cc,0xc0c404a9,0x8d7000d1,0x00000000}},	//   _còpt, _шәһи, _چايا, --, 
   {{0x8d7000ec,0x00000000,0x00000000,0x00000000}},	//   _نايا, --, --, --, 
   {{0x6f0c0395,0x2cb00042,0xcfb40790,0xe81ca4cd}},	//   _èacc, _glyd_, _öğüt_, युला_, 
   {{0x7d0c2811,0x36d40262,0x32fc00a2,0xd7e400d4}},	// [d0d0] _iias, гоар, _oňyp_, тіво, 
   {{0x7d0ca4ce,0x684800c0,0x00000000,0x00000000}},	//   _hias, _rūdž, --, --, 
   {{0x7d0ca4cf,0xceb000c8,0x798400f1,0x6a84013d}},	//   _kias, סיע_, _urhw, _сөям_, 
   {{0x73d8a4d0,0x7d0c1368,0x32fc010e,0x38b40fac}},	//   ндер_, _jias, _aňyp_, _båre_, 
   {{0x7d0ca4d1,0x38b4049f,0x3244a4d2,0x78ac0419}},	//   _mias, _vård_, гелг, mkav, 
   {{0x78aca4d3,0xc6a40022,0x56f03740,0x38b4007c}},	//   lkav, _крси, _түзс, _dåre_, 
   {{0x26007db3,0x550401c0,0x7d0c01c4,0x78ac005b}},	//   वेदी_, _ачаа, _oias, okav, 
   {{0x7d0c0170,0x78aca4d4,0xaf9800a7,0xd1f00b82}},	//   _nias, nkav, етох_, ልክቱ_, 
   {{0xc0cc044e,0x55c00032,0xc0e002d3,0x92640137}},	//   _ኢኹም_, _саңғ, _ሓኪም_, _لدام, 
   {{0x78ac8234,0xd2000e8e,0x7d0ca4d5,0x42542309}},	//   hkav, _күлк, _aias, _ەنەر, 
   {{0x78aca4d6,0x3ce801fb,0x00000000,0x00000000}},	//   kkav, _bkav_, --, --, 
   {{0x7d0ca4d7,0x78ac04a7,0xc33001d9,0xa3c80034}},	//   _cias, jkav, _دٕے_, _ऊधम_, 
   {{0x28c401ad,0x00000000,0x00000000,0x00000000}},	//   रोफि, --, --, --, 
   {{0x78ac1b99,0x00000000,0x00000000,0x00000000}},	//   ekav, --, --, --, 
   {{0x7d0ca4d8,0x7c280077,0x78ac0200,0xd940004e}},	//   _fias, ñerc, fkav, йери, 
   {{0x7d0ca4d9,0x2cb0003b,0xc824322f,0x00000000}},	//   _gias, _ulyd_, рзақ, --, 
   {{0xe61001ec,0x26880137,0x9cb001e2,0x00000000}},	// [d0e0] مشا_, нбап_, _دميت, --, 
   {{0x78aca4da,0x2ee4030a,0xdb94010f,0x00000000}},	//   akav, nolf_, _עדיט_, --, 
   {{0x38b400ed,0x7d0ca4db,0xe9a4a4dc,0xda5805d0}},	//   _såre_, _yias, _санп, _אכיל, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x43941a11,0x00e4035c,0x2ee4017a,0x7cd801e4}},	//   ралс, یتبی, kolf_, nĉra, 
   {{0x38b41a82,0x00000000,0x00000000,0x00000000}},	//   _våre_, --, --, --, 
   {{0xe1641b45,0x722800d4,0xb6c401af,0x00000000}},	//   ادتي, тців_, _тирһ, --, 
   {{0x38b45522,0x7f8433d2,0x00000000,0x00000000}},	//   _tåre_, للعن, --, --, 
   {{0x7d0ca4dd,0x7cfc0798,0x46a8060c,0x5438010f}},	//   _rias, lérg, _गवाह, _רעמא, 
   {{0x2ee46463,0x7d0ca4de,0x33d41ed7,0x3ce8a4df}},	//   golf_, _sias, _тіст, _skav_, 
   {{0x7cfc07a8,0x7d0ca4e0,0xdd100432,0x78ac00e4}},	//   nérg, _pias, _düşy, ykav, 
   {{0xd12c168d,0x7d0c0140,0x4e9002dd,0xe0d80064}},	//   _رمه_, _qias, _ۇشىر, _яве_, 
   {{0x69d806af,0x6d4c0153,0xdde81bf4,0x00000000}},	//   ûten, _įnaš, برکه_, --, 
   {{0x272c2776,0x7d0c013b,0x78ac01a4,0xd0048f8c}},	//   zönî_, _wias, wkav, _сече_, 
   {{0x7d0c1dd4,0x78ac16ca,0x291c00df,0x18881075}},	//   _tias, tkav, ŭtan_, нсап_, 
   {{0x2fc80010,0x21cc06be,0x78ac00c7,0x00000000}},	//   _žagi_, _məh_, ukav, --, 
   {{0xddd800e5,0x00000000,0x00000000,0x00000000}},	// [d0f0] mető, --, --, --, 
   {{0x78aca1ea,0xddd801d3,0x6aac0010,0xba18007b}},	//   skav, lető, ckbf, _جيدا_, 
   {{0x78ac005f,0x00000000,0x00000000,0x00000000}},	//   pkav, --, --, --, 
   {{0xd7e420c8,0x00000000,0x00000000,0x00000000}},	//   _біго, --, --, --, 
   {{0xa85406a9,0xe7a40075,0x7cfc0798,0x249402cb}},	//   _דירה_, _پۇلى_, pérf, شنود_, 
   {{0xddd8066d,0x21cc03b9,0xf2689a94,0x00000000}},	//   hető, _bəh_, тикл_, --, 
   {{0x03c40116,0x21cc06be,0xd5a00101,0xd3440133}},	//   исәм, _cəh_, _الزی, _ڕیشه_, 
   {{0x65780042,0x606000d1,0xc20800d1,0x6f1c01e7}},	//   _âtha, قۇمل, چقۇن_, ísco, 
   {{0x60600131,0x4f340014,0x00000000,0x00000000}},	//   تۇنل, ھتکھ_, --, --, 
   {{0xaf50001f,0xf1d001e0,0x60040eed,0xa28001e2}},	//   _ባደረገ, _мөйө, шным_, _وینو, 
   {{0x2ee40158,0xed580063,0x7cfc01d3,0x00000000}},	//   rolf_, њом_, kérd, --, 
   {{0x16041f14,0xa0c000ec,0xddd800e5,0xe7f800bc}},	//   वेयर_, _وڊيو, gető, ्धमा_, 
   {{0x7c28a4e1,0x6e780354,0x0f240108,0x00000000}},	//   ñera, _айлă, _сьем, --, 
   {{0xf1a808f2,0x69241171,0x00000000,0x00000000}},	//   _कथान, имга, --, --, 
   {{0x7e7400cf,0xd94009a5,0xed342ec5,0x00000000}},	//   _دانئ, жеси, _тэлэ, --, 
   {{0x7cfc01d3,0x28f80166,0x00000000,0x00000000}},	//   gérd, тэгэ_, --, --, 
   {{0xe738a4e2,0xa2d413f7,0x0978009d,0x00000000}},	// [d100] тез_, _बदल्, _өрнө_, --, 
   {{0xdb20072b,0xe8e801ec,0x00000000,0x00000000}},	//   øråd, хмұд_, --, --, 
   {{0xa5082081,0x1a9800df,0x00000000,0x00000000}},	//   вежа_, _סיטע, --, --, 
   {{0x23285267,0x20d802b1,0x1c0000e1,0x21cc03b9}},	//   води_, kīia_, रेवल_, _rəh_, 
   {{0x93740491,0xe298a4e3,0x21cc0213,0x0a440023}},	//   لصور_, кад_, _səh_, _ንምሕያ, 
   {{0xddd800dd,0x7cfc01ed,0x00000000,0x00000000}},	//   zető, mére, --, --, 
   {{0xe5a4a4e4,0x7cfca4e5,0x38b40158,0x15408f8c}},	//   _тиви, lére, _håra_, _мерм, 
   {{0x656ca4e6,0x38b400fe,0x807809ac,0x10a00063}},	//   _ipbh, _kåra_, убис_, жићн, 
   {{0x7cfca4e7,0xddd801ed,0x2600257b,0x00000000}},	//   nére, vető, वेरी_, --, 
   {{0x38b40158,0xd24c0014,0x61443d89,0x7cfc01d3}},	//   _måra_, _ٲنن_, _вежа, zérd, 
   {{0x7cfca4e8,0x38b405ac,0x69d8002d,0xd6540375}},	//   hére, _låra_, ûtel, סיטת_, 
   {{0x557404ac,0x9fa4052f,0x5cc4a4e9,0x8af006be}},	//   בעטן_, _ҡыҙҙ, рсоз, _ipəy, 
   {{0x69dc005a,0xc0c4004b,0xdf742101,0xbbd0a4ea}},	//   _axpe, _پېښه_, _خداب, सपेक, 
   {{0x7cfca4eb,0x628c03b2,0x99d400ae,0x00000000}},	//   dére, _óbod, لتزا, --, 
   {{0x98c4a4ec,0x69dc003a,0x00000000,0x00000000}},	//   асал, _cxpe, --, --, 
   {{0x7cfc0231,0x38b40158,0x4fc00131,0x7c3400c7}},	//   fére, _båra_, _دەۋە, _уеих, 
   {{0x7d180218,0x7c3c0098,0xd6240046,0x28c41788}},	// [d110] _huvs, masr, لعاي, रोधि, 
   {{0x7c3ca4ed,0xd344029e,0x00000000,0x00000000}},	//   lasr, ییزه_, --, --, 
   {{0x26000959,0x99800064,0x46680798,0x00000000}},	//   वेली_, rajų_, јрум_, --, 
   {{0x7cfc7ca0,0x9a70009f,0x00000000,0x00000000}},	//   bére, _انگڙ, --, --, 
   {{0x61f8a4ee,0x6efc020c,0x7cfc0129,0x044802dd}},	//   _aztl, lèbe, cére, рпік_, 
   {{0x7c3c0a28,0x1dd4084d,0x00000000,0x00000000}},	//   hasr, डपात, --, --, 
   {{0x45d4083f,0xee3800d1,0x00000000,0x00000000}},	//   _дорс, ңни_, --, --, 
   {{0x26000574,0x6d5c0165,0x7cfc00e5,0x00000000}},	//   वेळी_, ńsak, hérb, --, 
   {{0x15400150,0xdde001a6,0x7c3c0042,0xd2580120}},	//   _ءﺗﺎﻳ, _čušp, dasr, _аце_, 
   {{0xeb982c1d,0xe7f807af,0x7c280005,0x7cfc003e}},	//   ҳим_, ्धता_, ñern, jérb, 
   {{0x7cfc29e8,0x00000000,0x00000000,0x00000000}},	//   zére, --, --, --, 
   {{0xc0c8a4ef,0xe2a4008c,0xeb98a4f0,0x2fdc0218}},	//   _куче_, _öðru_, гим_, _txwg_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xed580006,0x5c7400d1,0x7cfca4f1,0xee380064}},	//   _бок_, _ғәюр_, vére, _снк_, 
   {{0x38b448bb,0x5e540eff,0x6f18015d,0x7c3c00ef}},	//   _såra_, _الىس_, _huwc, basr, 
   {{0x7cfca4f2,0x6d400623,0x7c3c24c2,0x00000000}},	//   tére, msla, casr, --, 
   {{0x6d40a4f3,0x98a0223a,0x4ab40209,0x6b640137}},	// [d120] lsla, чите, _дөвр, _укпа, 
   {{0x38b40628,0x7cfc0c63,0x6d40a4f4,0x7d18022e}},	//   _våra_, rére, osla, _yuvs, 
   {{0x6d40a4f5,0x7cfca4f6,0xbbe82c26,0xb0600139}},	//   nsla, sére, _مریم_, _ğänd, 
   {{0x7cfca4f7,0xa414015b,0xf4e800d3,0xe3b80114}},	//   mérc, ার্য_, афій_, лбе_, 
   {{0x6d40a4f8,0x02c8013e,0xb80037f3,0x6724143a}},	//   hsla, ақаи_, लेआम_, _utkj, 
   {{0x2918a4f9,0x6d40a4fa,0xc448328a,0x7d1ca4fb}},	//   _kupa_, ksla, _چیان_, írsk, 
   {{0x2918a4fc,0xdef80184,0x26c80124,0xc4480133}},	//   _jupa_, ҫып_, _imbo_, _نیان_, 
   {{0x6f18a4fd,0x61f802f0,0x00000000,0x00000000}},	//   _buwc, _vztl, --, --, 
   {{0x2918a4fe,0x6d40a4ff,0x7c3c084c,0x4424a500}},	//   _lupa_, esla, vasr, _ifm_, 
   {{0x6d40074d,0x29180660,0xd36c314e,0x7c3c7460}},	//   fsla, _oupa_, _سهم_, wasr, 
   {{0x7c2809ff,0x7c3c00cd,0x7cfc65fa,0xdce83858}},	//   ñero, tasr, vérb, žiča, 
   {{0x6f18015d,0x6b80031c,0x00000000,0x00000000}},	//   _fuwc, _ġogr, --, --, 
   {{0x442403d1,0x7c3ca501,0x2918a502,0x26c8035b}},	//   _mfm_, rasr, _aupa_, _ombo_, 
   {{0x7c3ca503,0x6d40a504,0x28c4257b,0x4424002f}},	//   sasr, bsla, रोसि, _lfm_, 
   {{0x2918a505,0x4424a506,0x7c3ca507,0x6d400857}},	//   _cupa_, _ofm_, pasr, csla, 
   {{0x29180262,0x26c8a508,0x4424a509,0xbb1801d9}},	//   _dupa_, _ambo_, _nfm_, _پٲدا_, 
   {{0x29180327,0xa90801a9,0x7798a50a,0x7e6801f5}},	// [d130] _eupa_, _asоs, шкар_, ofdp, 
   {{0xd5b82cd0,0x2918a50b,0x7cfc04d4,0x4424045a}},	//   лсе_, _fupa_, bérc, _afm_, 
   {{0x28c407d0,0x4424a50c,0x49c801f0,0xf9600133}},	//   रोहि, _bfm_, _гуям_, _تۆزێ, 
   {{0x44240408,0x59cc05d7,0xf8b801c0,0x26c8045a}},	//   _cfm_, _हेयर, _төг_, _embo_, 
   {{0x3868a50d,0x2918a50e,0xd6d839c1,0xa41403d4}},	//   mfar_, _zupa_, _бтв_, াৰ্য_, 
   {{0x3868a50f,0x2918a510,0x00000000,0x00000000}},	//   lfar_, _yupa_, --, --, 
   {{0x6d4007d6,0x38680e9e,0x2918004e,0x59cc65c5}},	//   xsla, ofar_, _xupa_, _हेमर, 
   {{0x3868a511,0x38b40158,0x7c28056a,0x1b1c0154}},	//   nfar_, _måro_, ñerl, _ভবনে_, 
   {{0x6d40a512,0xef180063,0x503400db,0xb4d40073}},	//   wsla, јмо_, _ۇياڭ_, िची_, 
   {{0x82341a57,0xee381d83,0x6d40a513,0xed44a514}},	//   _فرما, шно_, tsla, оноп, 
   {{0x6da41075,0x4424014b,0x6d4038e1,0x386803b2}},	//   цина, _yfm_, usla, kfar_, 
   {{0x29187cd8,0xac08a0b3,0x25bc00c5,0xb4e8012c}},	//   _rupa_, инна_, _ütle_, टकिय_, 
   {{0x2918a515,0x386800c6,0x6efc026c,0x00000000}},	//   _supa_, dfar_, rèbb, --, 
   {{0x29180ca8,0x6d40a516,0x823802d3,0x5f900066}},	//   _pupa_, psla, _ጥቕስታ, _آلوئ, 
   {{0xed58a517,0x6d40a518,0x291802d1,0xbe840345}},	//   _той_, qsla, _qupa_, _رجوو, 
   {{0x3868a519,0xbdf801f7,0x00000000,0x00000000}},	//   gfar_, _ارها_, --, --, 
   {{0xc42810a8,0xa6c805f5,0x38b42d75,0x2918013f}},	// [d140] ەتتە_, алаа_, _tårn_, _wupa_, 
   {{0x2918a51a,0x7cfca51b,0x386805d5,0x00000000}},	//   _tupa_, méra, afar_, --, 
   {{0x442400ca,0x7cfca51c,0x26c824d1,0x2918020b}},	//   _pfm_, léra, _vmbo_, _uupa_, 
   {{0x3868a51d,0x00000000,0x00000000,0x00000000}},	//   cfar_, --, --, --, 
   {{0x7cfc2047,0x290001f4,0x68f4010e,0x00000000}},	//   néra, _ihka_, mlyd, --, 
   {{0x68f4a51e,0x26c800ec,0xa8000784,0x00000000}},	//   llyd, _umbo_, ññun, --, 
   {{0x7cfc035b,0x44240077,0x1a98008f,0x68f403cb}},	//   héra, _tfm_, ייסע, olyd, 
   {{0x4424a51f,0x7cfc0098,0x9f680107,0x39440d12}},	//   _ufm_, kéra, ароз_, álsi_, 
   {{0x2484a520,0x629c0664,0x1ea8a521,0x7c280077}},	//   mdom_, öpos, لادي_, ñerm, 
   {{0x2364a522,0x24840493,0x7cfca523,0x3eb8a524}},	//   mtoj_, ldom_, déra, órt_, 
   {{0x29000280,0x2364008f,0x68f43c8f,0x69c81bbb}},	//   _ohka_, ltoj_, klyd, _हेली, 
   {{0xdfa47427,0x7cfc06af,0x29000af9,0x3868017a}},	//   _وحشي, féra, _nhka_, xfar_, 
   {{0x236430fb,0x2484a525,0xfbc4205d,0x7cfc07ea}},	//   ntoj_, idom_, _लेखम, géra, 
   {{0x23640115,0x2fc8010e,0x00000000,0x00000000}},	//   itoj_, _ýaga_, --, --, 
   {{0x5fa004a9,0x248411ad,0xca140801,0x236401b9}},	//   _رەھم, kdom_, ддръ, htoj_, 
   {{0x236404ac,0x7cfca526,0x290016a6,0xd7f800c7}},	//   ktoj_, béra, _chka_, ауз_, 
   {{0x2364a527,0x76b8a528,0x2484a529,0x7cfc2056}},	// [d150] jtoj_, блар_, ddom_, céra, 
   {{0x3868a52a,0x236401bf,0x290001f4,0x6ecc012d}},	//   sfar_, dtoj_, _ehka_, धोपु, 
   {{0x3868a52b,0x23640115,0x68f40857,0x954800d1}},	//   pfar_, etoj_, blyd, ششاق_, 
   {{0x24842d75,0x68f491fa,0xbcec00b5,0xa978008f}},	//   gdom_, clyd, _ｃｏm_, _פארכ, 
   {{0xd3780a31,0x61f40213,0x00000000,0x00000000}},	//   рче_, əyli, --, --, 
   {{0x2484014a,0x684401ed,0x00000000,0x00000000}},	//   adom_, _védő, --, --, 
   {{0x236400df,0xd4987621,0x24840175,0x947407fc}},	//   atoj_, _кра_, bdom_, _ودرا, 
   {{0x2f541925,0x92d800fe,0xdef40092,0x89dc011a}},	//   птос, ঠতে_, _ወገኔ_, יחוי, 
   {{0x7cfc0005,0xd11801ad,0x00000000,0x00000000}},	//   xéra, _पूरण_, --, --, 
   {{0x92b4a012,0x260000af,0xed589aa1,0x32540120}},	//   _بحرا, वेकी_, боо_, _ѕвер, 
   {{0xc2c47ae6,0x7cfc0687,0x68f40042,0x301401af}},	//   _تيلي, wéra, ylyd, _едер, 
   {{0x4174a52c,0x7cfc004a,0x00000000,0x00000000}},	//   _تاكس, téra, --, --, 
   {{0x68f45522,0xef200210,0x00000000,0x00000000}},	//   vlyd, óżą_, --, --, 
   {{0xd7d800b5,0x752807f5,0x248482c7,0x29000240}},	//   _fbペ_, _čezn, zdom_, _shka_, 
   {{0x7cfca52d,0x9f500241,0x00000000,0x00000000}},	//   séra, _àyò_, --, --, 
   {{0x7cfca52e,0x65c000d2,0x2b900109,0xe8f8a52f}},	//   péra, _líhé, _côcô_, ёла_, 
   {{0x68f4a530,0x24840fcf,0x290004cc,0x2364022e}},	// [d160] rlyd, vdom_, _vhka_, xtoj_, 
   {{0xaa84010b,0x68f4a531,0x00000000,0x00000000}},	//   _diýä, slyd, --, --, 
   {{0x68f45991,0x25680139,0x00000000,0x00000000}},	//   plyd, саеп_, --, --, 
   {{0xeab000dd,0x6a140214,0x68b80d62,0x2900005b}},	//   _آٹھ_, _وبگر, _چُھس_, _uhka_, 
   {{0x2484a532,0x1fd8000d,0x00000000,0x00000000}},	//   rdom_, _बखेड, --, --, 
   {{0x236404ac,0x46c01715,0xc7780023,0x00000000}},	//   rtoj_, _एतिह, ይኰይኑ_, --, 
   {{0x23641a4c,0x6284013f,0x7cfc0098,0xd1a00451}},	//   stoj_, _ɔkoh, dérn, فٽوي, 
   {{0x2364a533,0xb424a534,0x225009a5,0x6efc0100}},	//   ptoj_, _يعقو, şyk_, vèba, 
   {{0x6440a535,0xe3b88f3a,0x257c0118,0x221400d8}},	//   maoi, _уба_, _hůl_, _ефер, 
   {{0x64400e9e,0xc1a40124,0x257c01ef,0x00000000}},	//   laoi, _ҭыҧқ, _kůl_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6440a536,0x00000000,0x00000000,0x00000000}},	//   naoi, --, --, --, 
   {{0x5f040600,0xdb0c0036,0x99d001e4,0x00000000}},	//   _езда, lycé, maʈi, --, 
   {{0x6440a537,0x0fc002e8,0x9e64009a,0x6fa800bc}},	//   haoi, _яйчн, _راتن, टहरू, 
   {{0x6440a538,0x8d60009b,0x09940798,0x00000000}},	//   kaoi, _звје, нарџ, --, 
   {{0xc5c42158,0x7cfc20ef,0x4dd8011a,0x5c040064}},	//   ্থাপ, méro, _לחוו, _няпа, 
   {{0x644007f0,0x7cfc87aa,0xd7f8036b,0x00000000}},	// [d170] daoi, léro, сув_, --, 
   {{0x3cf802c4,0x00000000,0x00000000,0x00000000}},	//   llsv_, --, --, --, 
   {{0xf5784116,0x6440a539,0x7cfc73a0,0xf59433d2}},	//   تماع_, faoi, néro, بلاج, 
   {{0xdd84a53a,0x6440a53b,0xe91801ed,0x04b40d30}},	//   _یو_, gaoi, _گریڈ_, нсія, 
   {{0x7cfca53c,0xc32400d4,0x00000000,0x00000000}},	//   héro, емік, --, --, 
   {{0xe294a53d,0x64400b23,0x7cfc02f0,0x00000000}},	//   даш_, aaoi, kéro, --, 
   {{0xf0e843e8,0xd4c40798,0x00000000,0x00000000}},	//   يىتى_, _есап, --, --, 
   {{0x7cfca53e,0x64407ea6,0x628c02ea,0x94a801c0}},	//   déro, caoi, _óbon, _утга_, 
   {{0xaf041c7b,0x7cfca53f,0x00000000,0x00000000}},	//   мпил, térn, --, --, 
   {{0x332c0048,0x9ae402a8,0x7cfc00d0,0x00000000}},	//   _itex_, ƙiƙa_, féro, --, 
   {{0x78bca540,0xbf64a541,0x7db40006,0x7cfc753e}},	//   _olsv, ودیو, есяц, géro, 
   {{0x4174a542,0xdfcc2756,0x7ea4007f,0x3ebc0174}},	//   _سامس, ايی_, _mòpy, _elvt_, 
   {{0xdd8c15f6,0x403400cf,0x00000000,0x00000000}},	//   هوی_, _чечс, --, --, 
   {{0xd7d800b5,0x7cfc0098,0x6440056a,0x409400db}},	//   _pcノ_, béro, zaoi, _يلەر, 
   {{0x7cfc14ac,0xdee0036b,0x6d5401ed,0x1984084c}},	//   céro, _шоши, ázad, мбри_, 
   {{0xe8f8242f,0xe73838cb,0x600401a9,0x7bd00254}},	//   іла_, жеа_, kаml, õhuü, 
   {{0xa684a543,0x257c00bc,0x6ae401b9,0x7c840063}},	// [d180] млад, _sůl_, _ожиз, _чује, 
   {{0xe6100046,0x257c012c,0xfbc40451,0x1c000037}},	//   نشا_, _půl_, _سيپٽ, रेओल_, 
   {{0x1a980302,0x64a400ee,0x6440a544,0x00000000}},	//   _וייע, мажа, taoi, --, 
   {{0x69d8004a,0x38b401bf,0xb3280051,0x9f40036e}},	//   ûteu, _nårh_, _ảrập_, çkë_, 
   {{0xb7d40a28,0x6440327f,0x7c2804d4,0x5ef000dc}},	//   kṣya, raoi, ñeri, ुतम्_, 
   {{0x64400b23,0x6efc02e2,0x94900139,0x00000000}},	//   saoi, dèbo, ешәч, --, 
   {{0x7cfc1709,0x64400421,0x9660034f,0x00000000}},	//   xéro, paoi, _шкре, --, 
   {{0x7cfca545,0x5dd40150,0x00000000,0x00000000}},	//   véro, _ﺘﺒﻨﻴ, --, --, 
   {{0x3f143085,0xc7b4016b,0x626400d8,0x00000000}},	//   ндис, nyɑ_, _оваа, --, 
   {{0x7cfca546,0x63a001d5,0x13000305,0x00000000}},	//   téro, mxon, _азум, --, 
   {{0x63a001b9,0x7cfc01ed,0x6288007c,0x52d400d9}},	//   lxon, bérl, mdfo, _קובע_, 
   {{0xd12c01b9,0x00000000,0x00000000,0x00000000}},	//   _ضمه_, --, --, --, 
   {{0x63a0036b,0x6298003e,0xdfa400c6,0x8fa000c7}},	//   nxon, _knto, _تحضي, _иаце, 
   {{0x63a00281,0x7cfca547,0x00000000,0x00000000}},	//   ixon, péro, --, --, 
   {{0x63a0036b,0x9ce41734,0x6288013a,0x3d9401c6}},	//   hxon, _оцил, idfo, _чийр, 
   {{0xaa6402d3,0x6abc127b,0x63a001d5,0x00000000}},	//   _ዝዝርጋ, _elpf, kxon, --, 
   {{0x6298a548,0x76b896d5,0x63a0036b,0x4c3c011a}},	// [d190] _onto, плар_, jxon, _ותחב, 
   {{0x6298020b,0x63a001b9,0x7cfc01ed,0x628801f5}},	//   _nnto, dxon, zérl, jdfo, 
   {{0x62880cfd,0x2b5c0210,0x00000000,0x00000000}},	//   ddfo, ątce_, --, --, 
   {{0x62880036,0x7984a549,0xf48401d5,0x38c86e92}},	//   edfo, _ishw, عاای, _راجی_, 
   {{0x28740184,0x63a00472,0xd7e402bf,0x628801f5}},	//   _яҡты_, gxon, _ціно, fdfo, 
   {{0x6298020c,0x7cfc5b84,0x2aa400d7,0xe3c4009d}},	//   _cnto, dérm, _bôby_, эрхү, 
   {{0x3114a54a,0x28c407f7,0x66c002dd,0x7644a54b}},	//   нфис, रोकि, _сәтж, mahy, 
   {{0x63a007d6,0x7644a54c,0xef840261,0xa1540114}},	//   bxon, lahy, елип, хаћу_, 
   {{0xb2741679,0xa14400ef,0x6004022e,0x6e2c0166}},	//   _плаш, _alķī, qаml, _ğabb, 
   {{0x7cfc01ed,0xb64004ce,0x798402d0,0xed5800cf}},	//   sérl, _ｃｔ_, _oshw, поо_, 
   {{0x2d902b57,0xb0345b97,0x00000000,0x00000000}},	//   íze_, _знеш, --, --, 
   {{0xb0600139,0x00000000,0x00000000,0x00000000}},	//   _ğäwd, --, --, --, 
   {{0x7984a54d,0x6298a54e,0x2bb800c6,0x2d9000df}},	//   _ashw, _ynto, ساحة_, ŭze_, 
   {{0xad240075,0xae04005e,0x00000000,0x00000000}},	//   _كىتى, _كوشى, --, --, 
   {{0x2f3c02e2,0x63a001d5,0xdd8c020c,0x7644002b}},	//   lňg_, zxon, _هوو_, dahy, 
   {{0x63a001b9,0x798402d0,0x7cfc01ed,0x2204032e}},	//   yxon, _dshw, hérj, _híhí_, 
   {{0x27e4a54f,0x7984a550,0x9b90027d,0x628803cb}},	// [d1a0] çon_, _eshw, _مليت, ydfo, 
   {{0x291ca551,0x7c280077,0x764400b5,0x966000c0}},	//   ítas_, ñerv, gahy, лкуе, 
   {{0xe8f81d4a,0x00000000,0x00000000,0x00000000}},	//   _нло_, --, --, --, 
   {{0x63a08a0f,0x98a00139,0x291c01e4,0x00000000}},	//   txon, _биюе, ŭtas_, --, 
   {{0x7644a552,0x00000000,0x00000000,0x00000000}},	//   bahy, --, --, --, 
   {{0x63a0006c,0x81d4035b,0x7644020b,0x9f480098}},	//   rxon, колх, cahy, _émén_, 
   {{0x63a001a9,0x62980051,0xa978010f,0x0f200022}},	//   sxon, _vnto, לאַכ, қьым, 
   {{0xe5040633,0x7cfca553,0x00000000,0x00000000}},	//   _سبزي, térm, --, --, 
   {{0x63a0036b,0xd2500133,0xdecc0b82,0xa074008e}},	//   qxon, _ڵکوژ, _ብሎክ_, _җыеш, 
   {{0x3d9400d8,0xbf10008e,0x00000000,0x00000000}},	//   виор, шүлә, --, --, 
   {{0x7ec800c0,0x6f1c0332,0x04c80055,0x00000000}},	//   _rūpė, íscr, _śaṣp, --, 
   {{0x27e40034,0xa0680588,0x798402d0,0x7cfc1e0b}},	//   żony_, _хада_, _rshw, pérm, 
   {{0x4fb0a554,0x7cfc0c6a,0x798402d0,0x764400e4}},	//   _مصور, lérk, _sshw, yahy, 
   {{0x8f980bd9,0xfd740276,0xe3e0015b,0xbed40120}},	//   _מידי, _алкэ, _বরাব, _шолј, 
   {{0x98b009a8,0x5ed40154,0x00000000,0x00000000}},	//   žeče_, ঠকদে, --, --, 
   {{0x76440a2e,0xc4c41893,0xdb680120,0x8df8011a}},	//   wahy, _طے_, _ерол_, _מהות, 
   {{0x7644a555,0x69d8a556,0x7c2ca557,0xb6c801d3}},	// [d1b0] tahy, ûter, _ifar, وائے_, 
   {{0x7984a558,0x6f0c04cc,0x7cfc02f0,0xf8b00050}},	//   _tshw, _èact, kérk, اکھ_, 
   {{0x7644a559,0x7984a55a,0x00000000,0x00000000}},	//   rahy, _ushw, --, --, 
   {{0x73d80fb5,0x7c2c0327,0x00000000,0x00000000}},	//   мдер_, _jfar, --, --, 
   {{0x4518a55b,0x7c2c36df,0x80a479c5,0xd7f8a55c}},	//   رآمد_, _mfar, काने, _хун_, 
   {{0x213c0042,0x776c16b8,0x23b00131,0xd70400db}},	//   _bwth_, mtax, شمىس, _سىزۇ_, 
   {{0x7cfc01ed,0x61f80142,0x00000000,0x00000000}},	//   gérk, _cytl, --, --, 
   {{0x23d0243c,0x7c2c01e1,0x2bf001f9,0x00000000}},	//   _देवद, _nfar, _घडलं_, --, 
   {{0x776ca55d,0x28c41152,0xa73801ef,0x00000000}},	//   ntax, रोटि, _účtá, --, 
   {{0x7cfc0098,0x00000000,0x00000000,0x00000000}},	//   bérk, --, --, --, 
   {{0x213c01ab,0x61f8010e,0x7d1c03b2,0x776c427b}},	//   _gwth_, _gytl, írsp, htax, 
   {{0x7c2ca55e,0x6618a55f,0x00000000,0x00000000}},	//   _cfar, _útke, --, --, 
   {{0x7c2c01c7,0x2b380276,0x220402d2,0x00000000}},	//   _dfar, ьянэ_, _tíhí_, --, 
   {{0x2d94a560,0xed580e26,0x7c2ca561,0xc004003b}},	//   _арис, _жок_, _efar, _спік, 
   {{0xd9405728,0x9e94a562,0x776c009a,0x7c2c03cb}},	//   иери, _جانچ, etax, _ffar, 
   {{0x7c280005,0x776c008e,0x00000000,0x00000000}},	//   ñert, ftax, --, --, 
   {{0x18640107,0x00000000,0x00000000,0x00000000}},	// [d1c0] ъати_, --, --, --, 
   {{0xa5d82354,0x7c2c022e,0x00000000,0x00000000}},	//   وبار_, _zfar, --, --, 
   {{0x80a401bc,0x6b9401a8,0x7ae801c7,0x00000000}},	//   कामे, _hryg, éete, --, 
   {{0x6b94a563,0x94c800f1,0xf60807d6,0x213c002f}},	//   _kryg, وانې_, رتله_, _rwth_, 
   {{0xdb0c0118,0x23d0098a,0xddd800e4,0x5450003b}},	//   zycí, _देशद, retũ, рвіт, 
   {{0x16145841,0x66e44a1d,0xd24c006c,0x61f8a564}},	//   رسەڭ, _рога, قنه_, _pytl, 
   {{0x213c0175,0x3ea00208,0x673401f4,0x00000000}},	//   _qwth_, _đit_, lpyj, --, 
   {{0x61f80313,0x6b94068f,0x6004022e,0x00000000}},	//   _vytl, _oryg, lаmi, --, 
   {{0x9f44145e,0x7cfc0306,0x6e2ca565,0xb354a566}},	//   _nzoô_, sérk, _şaba, _مینا_, 
   {{0x7cfc6bd3,0x7c2ca567,0x38b4049f,0x61f801ab}},	//   méri, _sfar, _hårt_, _tytl, 
   {{0x7cfca568,0x7c2ca569,0x6b943cf7,0xc1780153}},	//   léri, _pfar, _aryg, _upė_, 
   {{0x776ca56a,0x7c2c0240,0xe0d81608,0x160406e3}},	//   ytax, _qfar, _юве_, वेटर_, 
   {{0x6b9400ad,0x69d8a56b,0x6c9c00e4,0x6004022e}},	//   _cryg, úten, _ẽhái, kаmi, 
   {{0x60c0a56c,0x6b94a56d,0x4dd00b28,0xb7c40116}},	//   _hlom, _dryg, اتیس, ңрақ, 
   {{0x60c0a56e,0x7c281709,0x7cfc004a,0x7c2c031c}},	//   _klom, ñers, héri, _tfar, 
   {{0x6b9404ce,0x7c2ca56f,0x6ea400c7,0xd90c1888}},	//   _fryg, _ufar, _агәҕ, تیج_, 
   {{0x60c0090c,0xe77800c7,0x6b94a570,0x00000000}},	// [d1d0] _mlom, натә_, _gryg, --, 
   {{0x776ca571,0x60c0a572,0x7cfca573,0xd6d80212}},	//   rtax, _llom, déri, єта_, 
   {{0x776ca574,0x60c0a575,0x7af429f5,0x62e8015b}},	//   stax, _olom, mozt, য়গায়_, 
   {{0x776c0054,0x8dd8011a,0x00000000,0x00000000}},	//   ptax, וקבק, --, --, 
   {{0x7cfca576,0x776c0227,0x630000d1,0x00000000}},	//   géri, qtax, ڭۈلل, --, 
   {{0x36d4a577,0x00000000,0x00000000,0x00000000}},	//   _согр, --, --, --, 
   {{0x60c000ed,0x05846bce,0x00000000,0x00000000}},	//   _blom, _кутм, --, --, 
   {{0x60c0707c,0x7af401d3,0x409401c4,0x00000000}},	//   _clom, hozt, арьт, --, 
   {{0x60c001f0,0x7af400dd,0x7cfc057f,0xef18a18c}},	//   _dlom, kozt, céri, нми_, 
   {{0x60c0a578,0xed347717,0x6004190b,0x09d800cc}},	//   _elom, лэмэ, ыным_, _দুফা, 
   {{0x30748258,0x32040c5e,0x09d800cc,0x00000000}},	//   _булс, _uzly_, _দুনা, --, 
   {{0x60c0a579,0xbca4004b,0x6b94005c,0xa92401ec}},	//   _glom, لمپي, _pryg, ғдал, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6a84a57a,0x60c0389e,0x6b940660,0x7af4a57b}},	//   ылга, _zlom, _vryg, gozt, 
   {{0x60c00af2,0xb9b400a7,0x7cfc01d3,0x2008012d}},	//   _ylom, астъ, zéri, ębie_, 
   {{0x6b94148b,0xdc640364,0x5d300451,0xe5a40075}},	//   _tryg, _баъд_, _افيئ, һизи, 
   {{0xa804a57c,0xaa4401af,0x61640240,0xdd140166}},	// [d1e0] узал, _йепл, _ዘይትጽ, läşl, 
   {{0xe5a434da,0xa9a44ea0,0x38b4143a,0x67340153}},	//   лизи, _биод, _sårt_, rpyj, 
   {{0xe458a57d,0x66e40032,0x91d000c5,0x00000000}},	//   еже_, _ҡома, _भेलै, --, 
   {{0x7cfca57e,0xa3483e1e,0x6734005b,0x236800d8}},	//   téri, езда_, ppyj, ејко_, 
   {{0x38b41121,0x60c001ab,0x00000000,0x00000000}},	//   _vårt_, _rlom, --, --, 
   {{0x7cfca57f,0x68f4a580,0x1fa401d5,0xdd140166}},	//   réri, loyd, ғриг, käşl, 
   {{0x26d81c06,0xc1a401ec,0x27f40118,0x63840139}},	//   mipo_, рылқ, řeně_, _әгза, 
   {{0x26d8a581,0x7cfc0231,0x66e400c2,0x7af4005a}},	//   lipo_, péri, _роҳа, zozt, 
   {{0x09d804c5,0x6d544dab,0x60c00219,0xd24c515c}},	//   _দুমা, ázan, _vlom, زچە_, 
   {{0x67242ebc,0x26d8a582,0x02b8a583,0x68f4014f}},	//   _mukj, nipo_, _अविभ, hoyd, 
   {{0xd6d802e4,0x6064004b,0x6724000d,0x80a441ac}},	//   תחיל, _مهال, _lukj, कादे, 
   {{0x60c06e1e,0x2cb00076,0x09d802f5,0x26d8a584}},	//   _ulom, _coyd_, _দুভা, hipo_, 
   {{0x5f347323,0x26d8a585,0x7af4a586,0xda782d29}},	//   _схеф, kipo_, tozt, няв_, 
   {{0xfe780364,0x3d9402bf,0x00000000,0x00000000}},	//   _рӯи_, _викр, --, --, 
   {{0x7af41ac7,0x67245d2e,0x2cb0062c,0x68f401a9}},	//   rozt, _aukj, _foyd_, foyd, 
   {{0x4fc004a9,0x3834a587,0x6724010b,0x5ba40114}},	//   _خەۋە, рнар, _bukj, _броз, 
   {{0x7d0ca588,0x67240010,0xb8dca589,0x7c3c0175}},	// [d1f0] _ihas, _cukj, _अव_, mbsr, 
   {{0x26d80421,0x67240023,0x48146c49,0x39b81572}},	//   gipo_, _dukj, смус, _алоэ_, 
   {{0x7d0c138f,0x00000000,0x00000000,0x00000000}},	//   _khas, --, --, --, 
   {{0xf8c800c5,0x7864010b,0x00000000,0x00000000}},	//   _रतिय, _өкүз, --, --, 
   {{0x04c87cbc,0x26d84d11,0x7d0ca58a,0x3ce803b2}},	//   دوني_, bipo_, _mhas, _mjav_, 
   {{0x26d8a58b,0x7d0ca58c,0x6d441368,0x7cfc003e}},	//   cipo_, _lhas, _çhag, méru, 
   {{0x7d0c0588,0x387805b1,0x6468005b,0x714000db}},	//   _ohas, _kbsr_, äpiö, زۉشۅ, 
   {{0x78ac4d3c,0x7d0c05b8,0x75340327,0x6618a58d}},	//   njav, _nhas, _itzz, _útka, 
   {{0x55c0a58e,0x2cb00363,0x926400e3,0x00000000}},	//   _таңғ, _royd_, _مدام, --, 
   {{0x7d0ca58f,0x78aca590,0x2eb48d05,0xdd140724}},	//   _ahas, hjav, рсис, täşl, 
   {{0x7d0ca591,0x78aca592,0x3f980374,0x82a40063}},	//   _bhas, kjav, ārua_, _уште, 
   {{0x7d0ca593,0x26d8a594,0x78aca595,0xab28a596}},	//   _chas, zipo_, jjav, кома_, 
   {{0x7d0c61bb,0x78ac009b,0x76540034,0x2cb0062c}},	//   _dhas, djav, _odzy, _voyd_, 
   {{0x78aca597,0x7cfc4e01,0x67240439,0x2fcc030a}},	//   ejav, déru, _rukj, mzeg_, 
   {{0x7d0ca598,0x6724020b,0x68f401b9,0xae100412}},	//   _fhas, _sukj, toyd, डेशन_, 
   {{0x7d0ca599,0x6724a59a,0x78aca59b,0x7cfc0419}},	//   _ghas, _pukj, gjav, féru, 
   {{0x2fcca59c,0x29100c67,0x68f4a59d,0xe98c0023}},	// [d200] nzeg_, rmya_, royd, _ብውሽጢ_, 
   {{0xfd4c07ae,0x7d0c02fb,0xeaf8007b,0x68f4022e}},	//   _nhiệ, _zhas, _جربت_, soyd, 
   {{0x26d8a59e,0x777c00b5,0x68f40076,0xa9a4a59f}},	//   ripo_, _epsx, poyd, _тинд, 
   {{0xc690021a,0x26d8a5a0,0x7cfca5a1,0x67240054}},	//   _ډېر_, sipo_, sérv, _tukj, 
   {{0x26d8a5a2,0xe284a5a3,0xd464084c,0x69cc0112}},	//   pipo_, илди, риче_, lzbe, 
   {{0xfd4c0208,0x2b5000dc,0x26d8036e,0x7cfc00e5}},	//   _chiệ, _mvyc_, qipo_, lért, 
   {{0x20c41f71,0x6d540765,0x69cc9d77,0x55e08efe}},	//   исиг, ázal, nzbe, _дорб, 
   {{0x2fcc0036,0x7cfc00e5,0x00000000,0x00000000}},	//   fzeg_, nért, --, --, 
   {{0x2328a5a4,0x3ce80427,0x7d0c045b,0x4424045a}},	//   _рози_, _rjav_, _rhas, _igm_, 
   {{0x7d0ca5a5,0xd0041614,0x21740798,0xa80406be}},	//   _shas, шење_, _вудр, mbığ, 
   {{0x4424037e,0x7cfc01ed,0x7d0ca5a6,0xb8d8031c}},	//   _kgm_, kért, _phas, _ཙྭ_, 
   {{0x7d0c02d1,0x10a00bd6,0x21180214,0x6f0001e7}},	//   _qhas, _михн, _شتاب_, allc, 
   {{0x4c94a5a7,0x7d0c0084,0xdee46a27,0xd0d000b2}},	//   цияс, _vhas, _коди, _بينظ, 
   {{0x7d0ca5a8,0xd0044623,0x7cd8a5a9,0x80a4a5aa}},	//   _whas, _тече_, _әмир_, कावे, 
   {{0x7d0ca5ab,0x78aca5ac,0x20c800a3,0x4ae8008e}},	//   _thas, tjav, _cùig_, рьям_, 
   {{0x7d0ca5ad,0x7cfca5ae,0x78ac0153,0xcd30a5af}},	//   _uhas, gért, ujav, _بروب, 
   {{0x78aca5b0,0x4ba815bf,0xd7f801d5,0x00000000}},	// [d210] rjav, _көрү_, тув_, --, 
   {{0xed4c00f8,0xd5b8a5b1,0x4424045a,0x7e6801e3}},	//   _تھی_, ксе_, _agm_, ngdp, 
   {{0x44241f97,0xb9940597,0x0568041b,0x94a801d5}},	//   _bgm_, _الجب, ијци_, ктда_, 
   {{0x7cfca5b2,0x00000000,0x00000000,0x00000000}},	//   mérs, --, --, --, 
   {{0x44240998,0x6618002d,0xfd4c004d,0x97a400d8}},	//   _dgm_, _útkn, _phiệ, _трнл, 
   {{0x6b5c08a5,0x1da4a5b3,0x00000000,0x00000000}},	//   _hægð, गमात, --, --, 
   {{0x4424299d,0x9f50145e,0x81bc00e2,0x386801ab}},	//   _fgm_, _âyê_, _sfēr, ogar_, 
   {{0x3868394a,0x2fcc0a40,0xa8040139,0x00000000}},	//   ngar_, tzeg_, bbığ, --, 
   {{0xfd4c07ae,0x3868a5b4,0x2fcc05c7,0x92680120}},	//   _thiệ, igar_, uzeg_, _ареа_, 
   {{0x2abc2776,0xafe404a9,0x2fcc9bde,0x7cfc02f0}},	//   _mäbê_, _қолл, rzeg_, kérs, 
   {{0x7cfc01ed,0x2fcc01ed,0x2008012d,0x705854e7}},	//   yért, szeg_, ębia_, _баер_, 
   {{0x20c801ab,0xfd4c0055,0xb114a5b5,0x6b5c032e}},	//   _cùid_, _jhiṇ, _умеш, _nægð, 
   {{0x80a43ee1,0x3868a5b6,0xbfa801d9,0x00000000}},	//   कारे, dgar_, _ناوٕ_, --, 
   {{0xa968a5b7,0x69cc03fa,0x386805d5,0xcdc000c7}},	//   лига_, tzbe, egar_, _малқ, 
   {{0x7c280e04,0x69cc67c4,0x9f9c0166,0x7cfc01d3}},	//   žera, uzbe, _eçär_, tért, 
   {{0x3868a5b8,0x977446e8,0x69cca5b9,0xbfe803d4}},	//   ggar_, әттә, rzbe, _পৰিঘ, 
   {{0xddd8000a,0xeb980139,0x81bc02b5,0x69cc01ed}},	// [d220] metš, _сип_, _ngēn, szbe, 
   {{0x2abc025a,0xddd85723,0x3868007b,0x2328013e}},	//   _däbê_, letš, agar_, ҳоди_, 
   {{0x44249d2b,0x7cfca5ba,0xfd4c0055,0x386801d5}},	//   _pgm_, cérs, _bhiṇ, bgar_, 
   {{0xddd87483,0x2328a5bb,0xdd14008e,0x6b5c032e}},	//   netš, годи_, _mäşh, _gægð, 
   {{0x340800d1,0x937400ae,0x00000000,0x00000000}},	//   ۇزۇپ_, مصور_, --, --, 
   {{0xd6245205,0x6618a5bc,0x4424020b,0xe5a4a5bd}},	//   _горе_, _útko, _wgm_, _лиги, 
   {{0xddd81ebd,0x80a4726a,0x1a98008f,0x00000000}},	//   ketš, काले, טיסע, --, 
   {{0x9f50006a,0x44245552,0x94240327,0x00000000}},	//   _âyë_, _ugm_, _སུརྱ_, --, 
   {{0xd014008e,0x92c400cc,0x00000000,0x00000000}},	//   йфь_, _উদৰ_, --, --, 
   {{0x66f87e29,0x3868a5be,0x2484110c,0xbed8009d}},	//   ्तिक_, zgar_, leom_, рдох_, 
   {{0xddd81ebd,0x50980a28,0xd24c165e,0x3868a5bf}},	//   fetš, ṣāṃ_, _سنن_, ygar_, 
   {{0xddd80f8b,0x20080213,0xd12c00c6,0x2484a5c0}},	//   getš, əbin_, _أمن_, neom_, 
   {{0x66f8069f,0x2364010f,0xdef8004e,0x38680162}},	//   ्ताक_, nuoj_, _йык_, vgar_, 
   {{0x7cfc0122,0x3e18a5c1,0x2a68037e,0xce3001d3}},	//   térs, _колэ_, ggbb_, _ٹوٹک, 
   {{0xddd81ebd,0x38681570,0xaab40832,0x9a8400d1}},	//   betš, tgar_, تگير_, _һунл, 
   {{0x2484009b,0x386828bf,0x5edc0154,0x00000000}},	//   jeom_, ugar_, _নীচে, --, 
   {{0x3868a5c2,0xb8d006ab,0x7cfc0ab9,0x236400df}},	// [d230] rgar_, _टच_, sérs, juoj_, 
   {{0x6efca5c3,0x3868a5c4,0xdb0803e6,0x2364010f}},	//   lèbr, sgar_, _حزبه_, duoj_, 
   {{0x66182268,0x6f1c0ffb,0x1cb40327,0x00000000}},	//   _útkl, ìsci, _ཛྭོ_, --, 
   {{0x6efca5c5,0x20c80e89,0x24840841,0x00000000}},	//   nèbr, _lùib_, geom_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7158a5c6,0xc348005b,0x7124009a,0x6d5400e5}},	//   арис_, сяце_, يرعل, ázak, 
   {{0xddd827c4,0x00000000,0x00000000,0x00000000}},	//   yetš, --, --, --, 
   {{0xf8c805d7,0x2f54119e,0x2364010f,0x69d8a5c7}},	//   रसिय, отос, buoj_, útei, 
   {{0xcef400c6,0xb4c4012d,0x00000000,0x00000000}},	//   _ẋẍẋ_, एसी_, --, --, 
   {{0xddd8000a,0xb4c8228d,0xcd400092,0x00000000}},	//   wetš, _ऋतु_, _የተከለ, --, 
   {{0xddd8000a,0xb0340801,0xb800009e,0x82a48d87}},	//   tetš, _днеш, ্শিত_, _эште, 
   {{0x7c2816a3,0xeb984964,0x417402dd,0x6efc7d4f}},	//   žern, аим_, _ءالس, gèbr, 
   {{0xddd87483,0x443800ac,0x7cfc74f2,0x2d9400fb}},	//   retš, _ər_, térr, сөһө_, 
   {{0xddd8a5c8,0x81cc00bd,0xee3821c1,0x63b4143a}},	//   setš, রপর_, _тнк_, øyni, 
   {{0xddd8000a,0x236401e4,0xad68009d,0xb4c80a8a}},	//   petš, zuoj_, _тайз_, _ऋतू_, 
   {{0x98a0a5c9,0x48e80154,0xa9680c60,0x18a00f89}},	//   мисе, পত্র, лиҳа_, масм, 
   {{0x9d18011a,0x24845160,0x19e00150,0xa9c000cf}},	// [d240] _דוקט, veom_, _ﺍﺣﭙﺎ, سۅڭۉ, 
   {{0x2364010f,0x00000000,0x00000000,0x00000000}},	//   vuoj_, --, --, --, 
   {{0x4ad80014,0xa424074d,0x09d800eb,0x00000000}},	//   _ناگھ_, оьлл, _দুরা, --, 
   {{0x2364010f,0x01e409a0,0xd464009b,0xdd7800df}},	//   tuoj_, үйдү, жице_, יטעל, 
   {{0x24840e04,0x25640014,0x7b0802d2,0x00000000}},	//   reom_, _ژارُ, _ástó, --, 
   {{0x2364010f,0x62641896,0x00000000,0x00000000}},	//   ruoj_, زاتق, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x75340323,0x236401e4,0xd46400f3,0x9100004e}},	//   _хэрх, puoj_, _мисе_, мчыд, 
   {{0x6440a5ca,0x2000008c,0xe2e4a5cb,0xa2582d4b}},	//   mboi, æki_, _джап, _نشاء_, 
   {{0x244001d5,0xc3c400d1,0xd26000f7,0x00000000}},	//   _hаm_, _мөһл, _окуй, --, 
   {{0x6440073c,0x2440022e,0x00000000,0x00000000}},	//   oboi, _kаm_, --, --, 
   {{0x6440005a,0x2440022e,0x71642374,0x90c001f0}},	//   nboi, _jаm_, _رامك, _обхе, 
   {{0xbf380014,0xd004026a,0x7c2801a6,0x09d80154}},	//   _آتش_, _деце_, žero, _দুলা, 
   {{0x1ea82966,0x00000000,0x00000000,0x00000000}},	//   _خاصي_, --, --, --, 
   {{0x0994399f,0xee940133,0x38c40150,0x00000000}},	//   марџ, _ردوک, пшаң, --, 
   {{0x26c8a5cc,0x34b8a5cd,0xddc80100,0x1158008f}},	//   _albo_, _आवेद, _refň, ידלע, 
   {{0x26c800d7,0x00000000,0x00000000,0x00000000}},	// [d250] _blbo_, --, --, --, 
   {{0x50180375,0x07082abb,0x00000000,0x00000000}},	//   שומו, قيقي_, --, --, 
   {{0xba180150,0x63b4023a,0x1dc800cd,0xf59400ae}},	//   _ديدا_, äynn, ानित, ثلاج, 
   {{0x26c80115,0x00000000,0x00000000,0x00000000}},	//   _elbo_, --, --, --, 
   {{0x167001d5,0x4c9c0677,0x245002f2,0x07a40024}},	//   _оқар, יבאו, رنوس, _жаўн, 
   {{0x1dc80a94,0x67b80375,0x644001c3,0xd5b80395}},	//   ानात, _המשק, aboi, _ксб_, 
   {{0xca7c0bd9,0x98bc0d2e,0x00000000,0x00000000}},	//   ינגט, _एकाए, --, --, 
   {{0x0464004e,0x3d040210,0x00000000,0x00000000}},	//   _отум, रतों_, --, --, 
   {{0xb7d40882,0x3eb801a9,0x00000000,0x00000000}},	//   kṣma, аrt_, --, --, 
   {{0xf19402bf,0x82341d0a,0x00000000,0x00000000}},	//   _низь, _قرما, --, --, 
   {{0x6da4a5ce,0x7cfc5178,0xed580063,0xada4a5cf}},	//   чина, térp, љом_, чанл, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa2d03c20,0x60b0431a,0x00000000,0x00000000}},	//   भोक्, _سموئ, --, --, 
   {{0x6440084c,0x00000000,0x00000000,0x00000000}},	//   zboi, --, --, --, 
   {{0x7d10066d,0xab640166,0xab280818,0x00000000}},	//   üksé, _biüç, роҳа_, --, 
   {{0x64400007,0xec4801a9,0x00000000,0x00000000}},	//   xboi, _узил_, --, --, 
   {{0x1c680150,0xab640166,0x32040051,0x66e001e1}},	// [d260] _اشىۋ_, _diüç, _lyly_, _níkè, 
   {{0x64400042,0x00000000,0x00000000,0x00000000}},	//   wboi, --, --, --, 
   {{0xe3b03584,0x00000000,0x00000000,0x00000000}},	//   کرا_, --, --, --, 
   {{0xa888300e,0x7dec010f,0x00000000,0x00000000}},	//   _уйма_, סקאַ, --, --, 
   {{0x2900033d,0x9340a5d0,0xfa4801ec,0x5efc00dc}},	//   _ikka_, енче, _اشۋى_, रकम्_, 
   {{0x32040316,0x00000000,0x00000000,0x00000000}},	//   _byly_, --, --, --, 
   {{0xb9080016,0x3d0c05ac,0xa2d01bd6,0xa50800f3}},	//   _nghỉ_, _সংস্_, भोग्, _гева_, 
   {{0x6b64013f,0xc10400c6,0x1558011a,0x00000000}},	//   _wɔgy, بوعي, _לכלב, --, 
   {{0xdd1c00bc,0x1ea8a5d1,0x00000000,0x00000000}},	//   tížn, مادي_, --, --, 
   {{0x2ba40034,0x29000064,0x00000000,0x00000000}},	//   खमैथ, _lkka_, --, --, 
   {{0x4ab0146b,0x29000327,0x320400a2,0xd2380375}},	//   ञानव, _okka_, _gyly_, _הגבל, 
   {{0x32240150,0x26f80b98,0x00000000,0x00000000}},	//   _تۋىپ_, ्तुर_, --, --, 
   {{0x6d440309,0x8fa00024,0x5040004e,0x00000000}},	//   _çhan, _паце, _чечб, --, 
   {{0x6288a5d2,0x2900a5d3,0x645c013f,0x20040009}},	//   nefo, _akka_, ɔpie, _iyoi_, 
   {{0xc9841363,0x57b80131,0x628803cd,0x4e780375}},	//   нути, ﻧﺒﯩﺮ, iefo, _האוצ, 
   {{0x6288a5d4,0xd7f80228,0x9f5001e1,0x00000000}},	//   hefo, буз_, _áyó_, --, 
   {{0x76b8a5d5,0x00000000,0x00000000,0x00000000}},	// [d270] олар_, --, --, --, 
   {{0x92c4045e,0x2900a5d6,0x6288653a,0xe7bc7aec}},	//   _উদ্_, _ekka_, jefo, _एअरप, 
   {{0x6288a5d7,0x3914a5d8,0xba18009f,0x6fd8000d}},	//   defo, _омор, _گيگا_, _बेईं, 
   {{0x386c037e,0xb68801d9,0x3834187f,0x00000000}},	//   _øer_, _ژھال_, _інгр, --, 
   {{0x62880770,0xd378a5d9,0x332c05d5,0x85043229}},	//   fefo, сче_, _quex_, روهن, 
   {{0x6288a3d3,0x92685a5b,0x798402d0,0x00000000}},	//   gefo, срда_, _kphw, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7984a5da,0x21240789,0x7c280f03,0x00000000}},	//   _mphw, _cioh_, žerj, --, 
   {{0x66d001bf,0xdecc0092,0x00000000,0x00000000}},	//   _dækf, _ብሎኝ_, --, --, 
   {{0x79840161,0x32040108,0xe8a8000d,0x00000000}},	//   _ophw, _tyly_, _चच्च, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xafa0a5db,0x00000000,0x00000000,0x00000000}},	//   _ақиқ, --, --, --, 
   {{0x79840161,0x900800db,0xe454010f,0x6e2c010e}},	//   _aphw, _ازاق_, וירט_, _şabu, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x20c801ab,0xacf40063,0x9f5001e1,0xb060013d}},	//   _mùin_, _очиј, _áyò_, _şäyd, 
   {{0x6ea001ad,0x62887392,0x00000000,0x00000000}},	//   _कोतु, zefo, --, --, 
   {{0x8c2400d1,0x00000000,0x00000000,0x00000000}},	// [d280] _язиҗ, --, --, --, 
   {{0x6d40a5dc,0x00000000,0x00000000,0x00000000}},	//   opla, --, --, --, 
   {{0x6d40a5dd,0x6844a5de,0xdb0c01e1,0x00000000}},	//   npla, _онна, _òdáj, --, 
   {{0x628802e3,0x6d40017a,0x00000000,0x00000000}},	//   wefo, ipla, --, --, 
   {{0x6288a5df,0x00000000,0x00000000,0x00000000}},	//   tefo, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x20c808c2,0x2124003e,0x40340064,0xb0a82d81}},	//   _dùin_, _pioh_, нейс, कांग, 
   {{0x6d40a5e0,0x6288a5e1,0x66d001bf,0x3ea025a8}},	//   dpla, sefo, _bækg, _şit_, 
   {{0x7c28a5e2,0x9e6400f1,0xd0040063,0x00000000}},	//   žerk, وادن, меће_, --, 
   {{0x6d400cf0,0x20c801ab,0xdbc4000d,0xa28001d3}},	//   fpla, _gùin_, _kööm, _شیعو, 
   {{0x6d4400ad,0x00000000,0x00000000,0x00000000}},	//   _çhal, --, --, --, 
   {{0x7cc40116,0x00000000,0x00000000,0x00000000}},	//   _ﯮﺭﯗﻧ, --, --, --, 
   {{0x6d40a5e3,0xdbc40037,0x2364010f,0xfbc400ec}},	//   apla, _lööm, nroj_, ريسٽ, 
   {{0x6d40005c,0xb7c40588,0x236401e4,0xdde8009a}},	//   bpla, ҭрақ, iroj_, _ورثه_, 
   {{0x6d5400dd,0x6d400857,0x4ef8011a,0x00000000}},	//   ázat, cpla, _והגו, --, 
   {{0x8d80016c,0x290c00e8,0xf8c807f7,0xa3cc17c6}},	//   _рушд, _ëfal_, रसेप, शना_, 
   {{0xd7d804ce,0x236400df,0x756401d3,0x00000000}},	// [d290] _pcパ_, jroj_, کیزہ_, --, 
   {{0x7c2ca5e4,0x7d1ca5e5,0x2364010f,0x65d800b8}},	//   _hgar, lmss, droj_, _śāṅk, 
   {{0x7c2ca5e6,0x32080198,0x20c801c3,0x236401e4}},	//   _kgar, ƙayi_, _rùin_, eroj_, 
   {{0x3ebc03cd,0x236401e4,0x00000000,0x00000000}},	//   _lovt_, froj_, --, --, 
   {{0x6d401156,0x73340075,0xb9d8001f,0x7d1c0158}},	//   zpla, رىغا, _አል_, imss, 
   {{0x6d40a5e7,0xc6a4a5e8,0x78bca5e9,0x828424ae}},	//   ypla, _ирси, _hosv, نجىل, 
   {{0x7c2ca5ea,0x78bca5eb,0x236401e4,0xa4400133}},	//   _ogar, _kosv, aroj_, _ڕێنو, 
   {{0x7c2ca5ec,0x2364a5ed,0x6d404bc1,0x78bca5ee}},	//   _ngar, broj_, vpla, _josv, 
   {{0x6d40a5ef,0x20c80e89,0x78bca5f0,0xdb0400d0}},	//   wpla, _iùil_, _mosv, _šmýk, 
   {{0x7c2ca5f1,0x1dc80574,0x7528a5f2,0x78bc047e}},	//   _agar, ानंत, _hiez, _losv, 
   {{0x7528a5f3,0x6da4a5f4,0x776c030a,0x3ebc007c}},	//   _kiez, رمحم, huax, _dovt_, 
   {{0x78bca5f5,0x6d407ea3,0x6d44062c,0xeaf81fc4}},	//   _nosv, rpla, _çham, ृत्त_, 
   {{0x7528a5f6,0x00d8034c,0x7c2c0334,0x09c800cd}},	//   _miez, _تبلت_, _dgar, रन्य, 
   {{0x6d40a5f7,0x7c2ca5f8,0x7528a5f9,0x950c031c}},	//   ppla, _egar, _liez, _ཏེའི_, 
   {{0x6f00a5fa,0x78bca5fb,0xada41513,0x3a28008e}},	//   molc, _bosv, _чайл, дерү_, 
   {{0x26f8257b,0x7528a5fc,0x7c2c025c,0x6f001290}},	//   ्त्र_, _niez, _ggar, lolc, 
   {{0x78bca5fd,0xdbc400af,0x7c8400f3,0x00000000}},	// [d2a0] _dosv, _sööm, _рује, --, 
   {{0x7c2c006c,0xce44001f,0xdb78010f,0x2364010f}},	//   _zgar, _የአጠቃ, _צװיש, vroj_, 
   {{0x7528005f,0x7c2c0124,0xdb200158,0x7d280bbc}},	//   _biez, _ygar, åråd, _üssü, 
   {{0x2364a5fe,0xe45006a0,0x20c808c2,0x6abc7a45}},	//   troj_, اضا_, _cùil_, _hopf, 
   {{0x4394a5ff,0x7528a600,0x6abc0730,0x73c00184}},	//   талс, _diez, _kopf, аҡта, 
   {{0x23640023,0xe4d803e6,0xdbc400c5,0x213c004d}},	//   rroj_, _کورت_, _tööm, _ptth_, 
   {{0x6f000395,0x7528a601,0x78bc014f,0x6064010b}},	//   dolc, _fiez, _yosv, еҗең_, 
   {{0x2364a602,0x6abc03b2,0x7de000d0,0xf1a8009f}},	//   proj_, _lopf, násť, باهه_, 
   {{0x6f000b21,0xe284009b,0x00000000,0x00000000}},	//   folc, _плаи, --, --, 
   {{0x7c2ca603,0x6abc014b,0x7528a604,0x81c40124}},	//   _sgar, _nopf, _ziez, _иазҧ, 
   {{0xe04400c7,0x273401bf,0xc1b40022,0x7c2c00a2}},	//   _знеи, _læn_, _шәды, _pgar, 
   {{0xbebc005f,0x25ac0158,0x6054007b,0xfde80137}},	//   kmīg, øfly_, _أنشط, здүк_, 
   {{0x6298a605,0x7d1ca606,0x78bca607,0x6f00a608}},	//   _kato, rmss, _rosv, bolc, 
   {{0x6298a609,0x6b94037e,0xd00c8fae,0x78bc014f}},	//   _jato, _dsyg, _اله_, _sosv, 
   {{0x6298a60a,0x3a240628,0x7c2c07de,0x6abc007c}},	//   _mato, älp_, _tgar, _dopf, 
   {{0x62989461,0x7c2ca60b,0xb78809a5,0x776c0005}},	//   _lato, _ugar, мәге_, tuax, 
   {{0x62980421,0x7528543f,0x78bca60c,0x7520007f}},	// [d2b0] _oato, _riez, _vosv, _èlzi, 
   {{0x78bc0810,0x75280072,0x20c80192,0xbcfc00e4}},	//   _wosv, _siez, _sùil_, guĩv, 
   {{0x7528a60d,0x6c68066d,0x78bc0810,0xd7d8037e}},	//   _piez, _علیہ_, _tosv, _idネ_, 
   {{0x69f042c6,0x6298a60e,0x6f000427,0x78bc0064}},	//   _түст, _aato, zolc, _uosv, 
   {{0xdfc41d1f,0x6abc02c4,0x752809d8,0x66d001bf}},	//   _ئي_, _yopf, _viez, _dækb, 
   {{0x7528a60f,0x09d80183,0x626068dd,0x7cfc00e5}},	//   _wiez, _দুটা, авша, gérz, 
   {{0x692c01ee,0x00000000,0x00000000,0x00000000}},	//   _tŝee, --, --, --, 
   {{0x6298a610,0x3940045a,0x00000000,0x00000000}},	//   _eato, _mths_, --, --, 
   {{0x6298a611,0xef1848f2,0x6f00a612,0x00000000}},	//   _fato, мми_, tolc, --, 
   {{0x6298a613,0xa3cc02ab,0x6d4403f0,0xa3b40037}},	//   _gato, शनर_, _çhak, _छपत_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6f00a614,0x6b940194,0x6ea002ab,0x00000000}},	//   solc, _psyg, _कोरु, --, 
   {{0x6f00a615,0x3940a616,0x7e6c0129,0x00000000}},	//   polc, _aths_, éopâ, --, 
   {{0x6298a617,0xeab001ed,0xc61c00cc,0x6a8402e8}},	//   _xato, جٹس_, দুটা_, ълга, 
   {{0x6abc0810,0x00000000,0x00000000,0x00000000}},	//   _vopf, --, --, --, 
   {{0x2734037e,0x6abc0810,0x9d40013e,0x65780112}},	//   _pæn_, _wopf, _теъд, _äthi, 
   {{0x6abc7e80,0x3940068c,0x6b9402d0,0xe7380120}},	// [d2c0] _topf, _eths_, _usyg, фез_, 
   {{0xb8c8367a,0xf1d00882,0x20c800a3,0x6abc005c}},	//   _गो_, तनान, _rùim_, _uopf, 
   {{0x6298a618,0xbebc005f,0x20c800a3,0x42a40131}},	//   _rato, smīg, _sùim_, ғулғ, 
   {{0x6298a619,0xa3cc2c97,0x5908031c,0x273403b2}},	//   _sato, शनल_, _ཁེགས_, _tæn_, 
   {{0x93900597,0x82842bcb,0xdcfc0171,0x7cfc00e5}},	//   لجوا, лқад, _švīk, térz, 
   {{0x62982d64,0x66d001bf,0x93c801d3,0x394001f4}},	//   _qato, _dækc, بامہ_, _yths_, 
   {{0x6298a61a,0x81bc02b5,0x394000a3,0x00000000}},	//   _vato, _ngēt, _xths_, --, 
   {{0x629800b2,0x2374a61b,0x7cfc0036,0xe2a800ec}},	//   _wato, _لائح, béry, _ڪارن_, 
   {{0xdef8a61c,0x7cfc0005,0x6298a61d,0xe40801d5}},	//   дын_, mérx, _tato, _آغزه_, 
   {{0xe2a82264,0x6298a61e,0x00000000,0x00000000}},	//   _تارن_, _uato, --, --, 
   {{0x716452c8,0x63a0a61f,0x657c0036,0x05380023}},	//   _مانك, lvon, ntph, _ብባህሪ, 
   {{0x61f80789,0x7cfc0005,0x261802e5,0x657c0076}},	//   _ixtl, nérx, _भरनी_, itph, 
   {{0x3f9800da,0x63a0a620,0x00000000,0x00000000}},	//   ārus_, nvon, --, --, 
   {{0x99d442b5,0x63a0a621,0x8d70691d,0x00000000}},	//   نتزا, ivon, دایا, --, 
   {{0xcbd00150,0x63a0300e,0xa3d0000d,0x1880010b}},	//   _ﮔﻮﭼﻴ, hvon, हैत_, ңңүн, 
   {{0x8d7004d3,0xa3b00316,0x63a0a622,0x00000000}},	//   _ئاوا, टमा_, kvon, --, 
   {{0x81b81c82,0xebc03052,0x657c045a,0x25480064}},	// [d2d0] ঙনি_, _ләрн, etph, _lėlę_, 
   {{0x63a0003c,0x657c037e,0xe76402dd,0x00000000}},	//   dvon, ftph, _ﺷﻪﺷﯟ, --, 
   {{0x628c02ea,0x1ba801d3,0x00000000,0x00000000}},	//   _óboy, _راکٹ_, --, --, 
   {{0xe7dc0316,0x7c282230,0xade400c5,0xa3cc00dc}},	//   _नेकप, žeru, _ओइसन_, शनं_, 
   {{0x2f18004a,0x387801a6,0x63a000e5,0x14dc41ac}},	//   lège_, _icsr_, gvon, पोषण, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x63a09871,0x2f182a78,0x00000000,0x00000000}},	//   avon, nège_, --, --, 
   {{0x63a038ed,0xd34000f2,0x00000000,0x00000000}},	//   bvon, _نفری, --, --, 
   {{0x7534025a,0x7654002d,0x61f8a623,0x43940139}},	//   _huzz, _kezy, _extl, _катс, 
   {{0x0ccc0882,0x75341418,0xe7a800c5,0x7654012d}},	//   ास्म, _kuzz, _tööõ, _jezy, 
   {{0xace8a624,0x25480064,0x753401f4,0x6d2421ee}},	//   емна_, _gėlę_, _juzz, лдоз, 
   {{0x2f1806af,0x765403e0,0x00000000,0x00000000}},	//   dège_, _lezy, --, --, 
   {{0x7534a625,0x5a5c02d3,0x66d0005c,0x00000000}},	//   _luzz, _ንምምጻ, _læka, --, 
   {{0x2d941b88,0x7de40236,0x9cb06431,0xcac80107}},	//   _брис, اسیم, _ۇمىت, тҳое_, 
   {{0x387801ee,0x753486ed,0x657c01ab,0x00000000}},	//   _bcsr_, _nuzz, xtph, --, 
   {{0x63a0036b,0x2d500010,0x00000000,0x00000000}},	//   yvon, mše_, --, --, 
   {{0x9d180302,0x76540100,0xa684a626,0x98a058d5}},	// [d2e0] _אוקט, _bezy, ллад, щите, 
   {{0x7534a627,0x657c02d0,0x63a0022e,0xe6c40066}},	//   _buzz, ttph, vvon, دتري, 
   {{0x7654a628,0x64a4a629,0x75348421,0x2d500427}},	//   _dezy, лажа, _cuzz, nše_, 
   {{0x2d503421,0x779000e5,0x753400e5,0x63a0a62a}},	//   iše_, _ڈیفا, _duzz, tvon, 
   {{0x657c0c67,0x81bc02b5,0x63a0a62b,0x545002bf}},	//   stph, _ngēr, uvon, світ, 
   {{0x2d5004b9,0x7534a62c,0x0514015b,0x6d440309}},	//   kše_, _fuzz, িদের_, _çhaw, 
   {{0x2d500f72,0x7534a62d,0x63a005b8,0x326400d4}},	//   jše_, _guzz, svon, ртів, 
   {{0xc0340114,0xc11400d8,0x00000000,0x00000000}},	//   шниј, јмиј, --, --, 
   {{0xb35425cb,0x1ee80120,0x03541de6,0xa8e00051}},	//   _نینا_, еќно_, _түлә_, _đốn, 
   {{0x672c02fa,0x61f8010a,0xb9d800b7,0x17940a7c}},	//   _jibj, _txtl, _አፍ_, נדיל_, 
   {{0x1fb40046,0x672c0135,0x3d00a62e,0x00000000}},	//   _әсер, _mibj, रवले_, --, 
   {{0x672ca62f,0x00000000,0x00000000,0x00000000}},	//   _libj, --, --, --, 
   {{0x3eb80267,0xdee43cc5,0xefc00092,0xa8040205}},	//   örts_, _йоди, ስቲው_, ncığ, 
   {{0x60c04774,0x2d50151c,0x2f18a630,0x7b1844e4}},	//   _hoom, bše_, tège_, тогр_, 
   {{0x7654a631,0x60c0a632,0x00000000,0x00000000}},	//   _rezy, _koom, --, --, 
   {{0x75340395,0x76541529,0x00000000,0x00000000}},	//   _ruzz, _sezy, --, --, 
   {{0x60c0a633,0x7534011c,0xb8840092,0x4ba8008e}},	// [d2f0] _moom, _suzz, _አጻጻፍ_, _йөрү_, 
   {{0x60c0a634,0x7c28a635,0x45f41682,0x75c80032}},	//   _loom, žers, _ḽoṱh, ктең_, 
   {{0x672c000a,0x69f029db,0xbd8801ec,0x76540064}},	//   _dibj, _дүрт, _ﯨﻠﻪﮔ, _vezy, 
   {{0x60c0a636,0xd508a637,0x660c005c,0xf8b0a638}},	//   _noom, رغان_, _dybk, _بکس_, 
   {{0x0584a639,0xa8580375,0x7654a63a,0x7bdc002f}},	//   _қурм, _בדרכ, _tezy, nzsu, 
   {{0x60c00421,0x75341418,0x8b5808a8,0xf2a400cf}},	//   _aoom, _tuzz, ניוס_, рикп, 
   {{0x42b8345f,0x3494a63b,0x425400d4,0x00000000}},	//   انىڭ_, _кавр, стіт, --, 
   {{0x2d5005a1,0x6820a63c,0x13640451,0x26181431}},	//   vše_, ọdeb, _مائٽ, _भरती_, 
   {{0x60c01574,0xaac40c66,0xddd80122,0x63b402f6}},	//   _doom, रॉडक, latň, äynt, 
   {{0x66d026b8,0x2d505723,0xbf88082e,0xee380fc0}},	//   _lækn, tše_, ائيل_, ъно_, 
   {{0x60c0a63d,0x2d50a63e,0x62240150,0xb194013d}},	//   _foom, uše_, _نوكە, _әлҗә, 
   {{0x2a78070d,0x2d500dfe,0x60c0a63f,0x7af405d5}},	//   _scpb_, rše_, _goom, enzt, 
   {{0xc1045dcd,0x5ca0a640,0x00000000,0x00000000}},	//   _اوني, цияб, --, --, 
   {{0x6da4a641,0xff5039b1,0xada4a642,0xa9685a5b}},	//   _вика, _رخه_, _вакл, кига_, 
   {{0x672c09a8,0xa8541b88,0x60c0a643,0xe694036b}},	//   _ribj, итај, _yoom, یلرد, 
   {{0x776c1709,0x672c007f,0xdd8c0592,0x60c0058a}},	//   frax, _sibj, _آوي_, _xoom, 
   {{0x66d0037e,0xa6e4a644,0x776c021c,0x00000000}},	// [d300] _dækn, ажал, grax, --, 
   {{0x3d180e47,0x6f1c01a4,0x66e400c7,0xab28011c}},	//   méwa_, ïsch, шоза, _шопа_, 
   {{0xa90800aa,0x3d18003e,0xe45800d4,0xd5ac007b}},	//   _ليدل_, léwa_, вже_, وفك_, 
   {{0xc3302dfc,0x776ca645,0x05140154,0x394401e7}},	//   كەر_, brax, িদ্র_, ílse_, 
   {{0x2910a646,0x60c0a647,0x672c0327,0x00000000}},	//   mlya_, _room, _tibj, --, 
   {{0x60c0a648,0x2910a649,0x216407d6,0xe5a400d1}},	//   _soom, llya_, атиг, _киги, 
   {{0x6498a64a,0x3d180066,0x60c0a64b,0x291004ba}},	//   _итар_, héwa_, _poom, olya_, 
   {{0x66e41d56,0x68f4a64c,0x60c00014,0x2cb00076}},	//   _соҳа, nnyd, _qoom, _nnyd_, 
   {{0x68f400a9,0x24848e70,0x1ea800c6,0xe29800c7}},	//   inyd, mfom_, نادي_, _иаа_, 
   {{0x248401fa,0x3d188851,0x68f49689,0x60c0a64d}},	//   lfom_, déwa_, hnyd, _woom, 
   {{0x60c0a64e,0x7bdc0007,0x6064a64f,0x00000000}},	//   _toom, wzsu, _نهال, --, 
   {{0x7bdca650,0xa0342928,0x776c058a,0xcfe40345}},	//   tzsu, _ئىشت, yrax, افیه_, 
   {{0x2910089c,0x7bdc0369,0x248401e2,0xef0c004b}},	//   dlya_, uzsu, ifom_, _ګڼي_, 
   {{0xfe78016c,0x68f4015d,0x00000000,0x00000000}},	//   _сӯи_, enyd, --, --, 
   {{0x68f40f7b,0x39440151,0x00000000,0x00000000}},	//   fnyd, ëls_, --, --, 
   {{0x776ca651,0x2f18067c,0x3834030d,0x69d800a3}},	//   trax, mèga_, снар, ùtea, 
   {{0x7d0c152d,0x9a8407d6,0x2f18067c,0xc86402e8}},	// [d310] _ikas, _кунл, lèga_, ютри, 
   {{0x776ca652,0xba9802bf,0x248400f1,0x29101418}},	//   rrax, _своє_, efom_, alya_, 
   {{0x66d0008c,0x2910a653,0x7d0c031c,0x25a80311}},	//   _tækn, blya_, _kkas, _crbl_, 
   {{0x73d8a654,0x66d0037e,0x776ca655,0x093401d3}},	//   лдер_, _hækl, prax, _گریج, 
   {{0x7d0ca656,0x32443edd,0x53b40aac,0x88a40244}},	//   _mkas, белг, шғар_, _بیقۆ, 
   {{0x248401b8,0x66d00158,0x7d0c01b9,0x2eb42802}},	//   afom_, _jækl, _lkas, _अचेत, 
   {{0x7d0ca657,0xd498a658,0x3ce8000d,0x359c0092}},	//   _okas, _ира_, _omav_, _ቂርቆስ_, 
   {{0x7d0ca659,0x93e4036b,0x09f802e4,0xaf98009d}},	//   _nkas, _кўзл, ימום_, гтох_, 
   {{0x92640272,0xc0c80640,0x20c801ab,0xf3181078}},	//   _ندام, рује_, _nùiu_, _боаш_, 
   {{0x7d0ca65a,0x2eb4301f,0x52740014,0x2cb000b5}},	//   _akas, ссис, _خارز, _snyd_, 
   {{0x68f40cfd,0xd6f804ce,0xb05400f2,0x7d0c0051}},	//   ynyd, _psオ_, _هپات, _bkas, 
   {{0x32d8007f,0x3014004e,0x00000000,0x00000000}},	//   _dèye_, _лдер, --, --, 
   {{0x7d0c020b,0x66d001a8,0x00000000,0x00000000}},	//   _dkas, _bækl, --, --, 
   {{0x7d0ca65b,0xdfcc0150,0xece80116,0x68f4015d}},	//   _ekas, _سيى_, _әдил_, wnyd, 
   {{0x7d0ca65c,0x68440724,0x3d1806fd,0x29100455}},	//   _fkas, йнва, séwa_, tlya_, 
   {{0x68f40368,0xec780cb6,0xeb98013d,0xac1c0408}},	//   unyd, _спи_, _бии_, _пайĕ_, 
   {{0x2fcc05ea,0xe7a8034b,0x68f40042,0xbbe800ec}},	// [d320] nyeg_, ывал_, rnyd, _پريم_, 
   {{0x68f40ea0,0x6d44a65d,0xf9c8037e,0x97bc01ec}},	//   snyd, _çhas, d用fm_, кiту_, 
   {{0x1a9800c8,0x2fcc0165,0xa9a402e8,0x2484a65e}},	//   _גייע, hyeg_, _уинд, tfom_, 
   {{0xe3c40c58,0x69cca65f,0x2fcc44a1,0x044800d1}},	//   _শেষব, mybe, kyeg_, рҗап_, 
   {{0xa3d00c2e,0x69cca660,0x64a40d52,0x77c801b9}},	//   हैं_, lybe, _һава, _куёв_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69cca661,0xdc34013d,0x00000000,0x00000000}},	//   nybe, _näği, --, --, 
   {{0x854401f2,0x00000000,0x00000000,0x00000000}},	//   _ịgwọ_, --, --, --, 
   {{0xa92402fb,0x2fcc002e,0x69cca662,0xb188009d}},	//   mažď, gyeg_, hybe, гсөж_, 
   {{0x21740209,0x232800ee,0x69cc374d,0x7d0ca663}},	//   _гудр, _сози_, kybe, _skas, 
   {{0x69cc002d,0x7d0c01a9,0xbe14007b,0xfe780153}},	//   jybe, _pkas, تودع, rgį_, 
   {{0x69cca664,0xe12400c7,0x00000000,0x00000000}},	//   dybe, _умеи, --, --, 
   {{0x69cc0798,0x2f181497,0x5c040108,0x00000000}},	//   eybe, sèga_, сяна, --, 
   {{0x6fc4012c,0x66d001bf,0x9a84010b,0xc1043cc6}},	//   िहरू, _bækm, щумл, _اوچي, 
   {{0x7d0ca665,0x69cca666,0x00000000,0x00000000}},	//   _tkas, gybe, --, --, 
   {{0x64400369,0x66d0005c,0x8d4401f7,0x00000000}},	//   jcoi, _dækm, _اليٰ_, --, 
   {{0xd6f800b5,0x2494001f,0x6d44062c,0xb78818c7}},	// [d330] _usカ_, _መምራት_, _çhar, шәне_, 
   {{0x69cca667,0x66d0032e,0xf8a800dc,0x00000000}},	//   bybe, _hækj, _चोरय, --, 
   {{0x69cca668,0x3f8403a2,0x2fcc030a,0x95640395}},	//   cybe, htmu_, zyeg_, създ, 
   {{0x7648373d,0x3f8404ba,0xa030001f,0xd6c012ea}},	//   _şeyd, ktmu_, _አጀንዳ, _کمسی, 
   {{0xdb240327,0xded401f3,0x00000000,0x00000000}},	//   _རྫོཌ_, ርሱን_, --, --, 
   {{0x66d0a669,0x635406be,0x00000000,0x00000000}},	//   _lækj, dənı, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2d8002b1,0x6440a66a,0x854404b4,0x511c0cad}},	//   _ähei_, ccoi, _хэре, _ẹgbẹ_, 
   {{0x69cca66b,0xd344006c,0xdc34013d,0x00000000}},	//   zybe, _ایته_, _säği, --, 
   {{0xc484010a,0x00000000,0x00000000,0x00000000}},	//   _ӗлĕк, --, --, --, 
   {{0x3f84511d,0xed58026a,0x20c808c2,0x81440fb4}},	//   atmu_, јом_, _cùis_, _فنلن, 
   {{0xad240075,0x69cca66c,0x41741bf4,0x1128009d}},	//   تىجى, vybe, _رامس, _сюзи_, 
   {{0xdc340166,0x69cc0142,0x00000000,0x00000000}},	//   _wäği, wybe, --, --, 
   {{0x69cca66d,0x7d0401e4,0x8e74001f,0x26180073}},	//   tybe, _ĉise, _በበኩሉ_, _भरली_, 
   {{0xde000640,0xd940119e,0x00000000,0x00000000}},	//   _опши, деси, --, --, 
   {{0x69cca66e,0x00000000,0x00000000,0x00000000}},	//   rybe, --, --, --, 
   {{0xeb980831,0x69cc00ee,0xf7483bee,0xe7b800ef}},	// [d340] _тип_, sybe, مجله_, _īrēš, 
   {{0x9b904e5d,0x00000000,0x00000000,0x00000000}},	//   _کلیت, --, --, --, 
   {{0x66d0a66f,0xde2402d3,0x2d84a670,0x9b00010a}},	//   _hækk, _ሱዳናው, ntle_, _цзэд, 
   {{0x2d84030d,0x66d001bf,0x00000000,0x00000000}},	//   itle_, _kækk, --, --, 
   {{0xe3b0a671,0x6b840770,0xe29801c0,0x2d8434db}},	//   برا_, ntkg, иад_, htle_, 
   {{0x6440a672,0xded4069d,0xb35400f2,0x48f40118}},	//   scoi, ርቱን_, سیما_, ्कको_, 
   {{0x66d0a673,0x00000000,0x00000000,0x00000000}},	//   _lækk, --, --, --, 
   {{0x20c800a3,0x3f84a674,0x00000000,0x00000000}},	//   _rùis_, ttmu_, --, --, 
   {{0x20c801ab,0xd7d8037e,0x66d00321,0x32080342}},	//   _bùir_, _edテ_, _rækj, ğaya_, 
   {{0x66d0008c,0x32080c3c,0x53980375,0x20400092}},	//   _sækj, şaya_, _דימו, _የጀመር, 
   {{0x255002d3,0xe0440022,0x72a00131,0x6288015d}},	//   _ዝነበሩ, _днеи, _سەين, mffo, 
   {{0x66d000b5,0x62880368,0x60080117,0x00000000}},	//   _bækk, lffo, _кнем_, --, 
   {{0x2d8401e0,0xd12ca675,0xba48013a,0x00000000}},	//   atle_, _شمه_, hrůž, --, 
   {{0x66d004ce,0xdde800aa,0x2d840afa,0x628803cb}},	//   _dækk, _پرته_, btle_, nffo, 
   {{0x66d001a8,0x6d4400ad,0xa2b0012c,0x98c44a1a}},	//   _tækj, _çhap, _आफन्, осал, 
   {{0x66d0066a,0xddd800b0,0x628803cb,0x81bc00ef}},	//   _fækk, natō, hffo, _izēd, 
   {{0x14a83174,0x66d001bf,0x36d400a8,0x00000000}},	// [d350] _घोषण, _gækk, поар, --, 
   {{0x3f40067c,0xcc240014,0x62880d27,0x16480137}},	//   _mòu_, _تر٘ٹ, jffo, рчап_, 
   {{0xddd8a676,0xd5b8a677,0x6288015d,0x6a98011a}},	//   katō, шса_, dffo, _השתנ, 
   {{0x291c8d22,0x7984401f,0xd06402d3,0x628801f5}},	//   ïtat_, _iqhw, _ተጀሚሩ_, effo, 
   {{0x97000075,0x3f401497,0x00000000,0x00000000}},	//   _قېرى, _nòu_, --, --, 
   {{0x92b4014d,0x7158a678,0x00000000,0x00000000}},	//   تحصا, брис_, --, --, 
   {{0xa1540063,0xc644009f,0x76440432,0x00000000}},	//   пају_, _آَفي, mchy, --, 
   {{0x7984009a,0x76449d37,0xbebc00e2,0xded001ec}},	//   _mqhw, lchy, smīl, _ﺘﺠﺭﺒ, 
   {{0x73d81d16,0xf3f80356,0xa2a4141f,0x2f88013d}},	//   _удар_, _beţe_, _टोक्, сәен_, 
   {{0x66d0019b,0x7644a679,0x2d84a67a,0x3f40067c}},	//   _rækk, nchy, ttle_, _dòu_, 
   {{0xb0340262,0x66d000b5,0x518407a5,0x614400d1}},	//   _енеш, _sækk, _фуза, _فىلە, 
   {{0xeb988a2e,0x2d0402ab,0xd48c0220,0x25500023}},	//   бим_, रवेल_, ерi_, _ዝነብሩ, 
   {{0x79840b6f,0x2d842517,0x20c801c3,0xf3f8054e}},	//   _aqhw, stle_, _tùir_, _feţe_, 
   {{0x66d0037e,0x7fb422cd,0xab2801a9,0x764401ef}},	//   _vækk, _آلوچ, сога_, jchy, 
   {{0x764402f0,0x00000000,0x00000000,0x00000000}},	//   dchy, --, --, --, 
   {{0x6d400369,0x66d0005c,0x7644a67b,0xc0d41954}},	//   mqla, _tækk, echy, ርፑል_, 
   {{0x798401f0,0x6d40a67c,0x6288015d,0x00000000}},	// [d360] _eqhw, lqla, yffo, --, 
   {{0xfbc401b9,0x96600120,0x764400a2,0x00000000}},	//   _ўғри_, екфе, gchy, --, 
   {{0x6d40a67d,0x291c067c,0x9a380375,0x1a9800df}},	//   nqla, ïtas_, _לתיק, _פיטע, 
   {{0xefd400b7,0x144802d3,0x19b80375,0x00000000}},	//   ይሁድ_, _ዝበልኩ, _המטב, --, 
   {{0xb780052f,0x068402f4,0x2814a67e,0x2d40004d}},	//   _иғти, _оҳан, _روسس, _lóe_, 
   {{0x6288a67f,0xd04806be,0x7644002b,0x626453f0}},	//   uffo, _ilgə, cchy, ساتق, 
   {{0x62880cfd,0x3f400ba1,0xdc3c0419,0x00000000}},	//   rffo, _sòu_, víľo, --, 
   {{0x40344d16,0x3f40180f,0xd1700131,0x26c80f85}},	//   мейс, _pòu_, ردىغ, _hobo_, 
   {{0x26c8a680,0x200003be,0xddd800b0,0x6288002f}},	//   _kobo_, çki_, ratō, pffo, 
   {{0x26c8a681,0x3f40180f,0x21a4a682,0x66d002d2}},	//   _jobo_, _vòu_, _низм, _bæki, 
   {{0x6d400399,0x2364a683,0x225c00ef,0x7e980ed8}},	//   gqla, lsoj_, _ietk_, منکر_, 
   {{0x98a80276,0x764402fb,0x225c00c5,0xed4c1370}},	//   _mică_, zchy, _hetk_, جھو_, 
   {{0x3f40067c,0x213c0036,0x6d400009,0x98a8054e}},	//   _uòu_, _huth_, aqla, _lică_, 
   {{0x213c0472,0x5d640116,0x8f9802e4,0x4fd000d4}},	//   _kuth_, _етиз, _לידי, _яжіт, 
   {{0x84800023,0x23640477,0x81bc00ef,0xc0d00092}},	//   _ሓጎስን_, hsoj_, _uzēd, ሥጢር_, 
   {{0x2364a684,0x213c0ffb,0x6618002d,0x00000000}},	//   ksoj_, _muth_, _útky, --, 
   {{0x26c8a685,0x213ca686,0x76441368,0x236401e4}},	// [d370] _bobo_, _luth_, tchy, jsoj_, 
   {{0x26c8a687,0xb99800d6,0xd5b8a688,0x4824568c}},	//   _cobo_, _двох_, йсе_, رىلق, 
   {{0x94a8006c,0x7644a689,0x79840117,0x26c8a68a}},	//   йтда_, rchy, _uqhw, _dobo_, 
   {{0x7644a68b,0x98a80356,0xb34c0023,0x00000000}},	//   schy, _dică_, _ዝተገደ, --, 
   {{0x26c8a68c,0x80c007b6,0xa9d00150,0x6d40022e}},	//   _fobo_, वाने, _ﮔﺎﯕﻴ, zqla, 
   {{0x26c8a68d,0x213c01c3,0xe82002ab,0x67b800d9}},	//   _gobo_, _buth_, _मरता_, _ומשק, 
   {{0x98a8054e,0xa19000d8,0x71a4a68e,0xba080092}},	//   _gică_, вајч, файз, _ላክ_, 
   {{0xb464a68f,0x213c01ab,0x26c8009a,0x2ed400dc}},	//   _آگاه, _duth_, _zobo_, धस्त, 
   {{0x26c8a690,0x66d001a8,0x98a8054e,0x00000000}},	//   _yobo_, _sæki, _zică_, --, 
   {{0x213c014b,0xed441fbe,0x6d4001d5,0xceb806be}},	//   _futh_, мноп, tqla, _şəbi_, 
   {{0x213c14d0,0xb4f8010f,0x00000000,0x00000000}},	//   _guth_, ַפֿי, --, --, 
   {{0x6d4001b9,0x00000000,0x00000000,0x00000000}},	//   rqla, --, --, --, 
   {{0xb91c0241,0x6d40013f,0xac08109a,0x00000000}},	//   _fuyẹ_, sqla, інга_, --, 
   {{0xed5815ed,0x66d0008c,0xd7d800b5,0xcee40014}},	//   _док_, _tæki, _ccロ_, _ژرژن_, 
   {{0xa6c8022e,0x27240051,0x6d4003e3,0x00000000}},	//   lmаg, lông_, qqla, --, 
   {{0x26c8a691,0xad2400f7,0x98a80356,0x91ac03d4}},	//   _sobo_, _تىبى, _rică_, _কথাখ, 
   {{0x26c8172e,0xeb043dc8,0x386c0171,0x00000000}},	// [d380] _pobo_, _опип, _ķert_, --, 
   {{0x26c80921,0x23640e3c,0x7c640150,0x98a8054e}},	//   _qobo_, vsoj_, _قاۋل, _pică_, 
   {{0xa924a692,0x225c000d,0x27240208,0x23640455}},	//   _одол, _retk_, hông_, wsoj_, 
   {{0x26c80d29,0xd7d8037e,0x213ca693,0x23640200}},	//   _wobo_, _dcモ_, _ruth_, tsoj_, 
   {{0x26c8a694,0x225c22da,0x44200158,0x5b78010f}},	//   _tobo_, _petk_, åi_, ַרקא, 
   {{0xd24ca695,0x2364008f,0x246c01fb,0xf79401d9}},	//   لنه_, rsoj_, ộm_, _سۆمب_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xba08a38c,0x23640115,0xd8d800df,0x00000000}},	//   _ላይ_, psoj_, ַקיר, --, 
   {{0xe2901375,0x94e4872f,0x00000000,0x00000000}},	//   _لذا_, _تکلف_, --, --, 
   {{0x6e2c0115,0x00000000,0x00000000,0x00000000}},	//   _ŝaba, --, --, --, 
   {{0x63000075,0x6b940006,0x3eb85775,0x7db401d5}},	//   _كۈچل, _apyg, ırt_, رمحص, 
   {{0x13540023,0x00000000,0x00000000,0x00000000}},	//   _ዝተጠቐ, --, --, --, 
   {{0x800801ed,0xc5f800e2,0xdfd0007b,0xa2c0085c}},	//   _عرصہ_, _žēl_, _جيش_, लाप्, 
   {{0x2900a696,0x00000000,0x00000000,0x00000000}},	//   _ajka_, --, --, --, 
   {{0xa2d40a28,0x212403a2,0x6b9400c7,0xcc9400d1}},	//   _भवन्, _khoh_, _epyg, _ﻛﯚﺭﮔ, 
   {{0xd7f800c7,0x26cc01b8,0x00000000,0x00000000}},	//   оуз_, öfon_, --, --, 
   {{0x212401ab,0x66d0032e,0xd9b01c3e,0x00000000}},	// [d390] _mhoh_, _læku, رەڭد, --, 
   {{0x2124194f,0x7c2c0003,0x00000000,0x00000000}},	//   _lhoh_, ħorġ, --, --, 
   {{0xa2c04a18,0x996401a9,0x00000000,0x00000000}},	//   लान्, _ўтол, --, --, 
   {{0x8504004b,0x6b9400e4,0x00000000,0x00000000}},	//   پوهن, _ypyg, --, --, 
   {{0x66d001bf,0x00000000,0x00000000,0x00000000}},	//   _rækv, --, --, --, 
   {{0x21240076,0x66d00008,0x39400083,0x7af4005a}},	//   _ahoh_, _bæku, _kuhs_, nizt, 
   {{0xee380209,0xd29000c7,0x59dc1fe7,0x00000000}},	//   үни_, ерқь, ननिर, --, 
   {{0xdbc4a697,0x21240842,0x2f540209,0x7af4005a}},	//   _göçm, _choh_, нтос, hizt, 
   {{0x2f180ba1,0x649c0241,0x00000000,0x00000000}},	//   lègi_, _ṣigi, --, --, 
   {{0x32780150,0x00000000,0x00000000,0x00000000}},	//   _ءماج_, --, --, --, 
   {{0x6b940153,0x00000000,0x00000000,0x00000000}},	//   _spyg, --, --, --, 
   {{0xeb98a698,0x2124014f,0xb0a401d9,0x27240129}},	//   пим_, _ghoh_, _سٍتى, mône_, 
   {{0xaed4a699,0x27240129,0xbcc001e0,0x00000000}},	//   _подш, lône_, рҡыл, --, 
   {{0x7af48440,0x58f8031c,0xa9a401c6,0x7b0800d7}},	//   gizt, _དམུས_, нигд, jľud, 
   {{0x682800dd,0x29000098,0xdce80790,0x7b0800d7}},	//   ködé, _pjka_, _çiğd, dľud, 
   {{0x66d00158,0x98a0a69a,0xf5380419,0x00000000}},	//   _lækt, лисе, _niť_, --, 
   {{0x66740722,0x7c640228,0xaa4417a0,0x3934a69b}},	// [d3a0] فدار, _شايل, _пепл, тэрс, 
   {{0xa9a4014b,0x00000000,0x00000000,0x00000000}},	//   _зиод, --, --, --, 
   {{0xaa84010e,0x69d803cd,0xf5380419,0xda58011a}},	//   _ekýä, øted, _biť_, _מכיל, 
   {{0xe73895c8,0x2900821e,0xe3640209,0x98a800c0}},	//   _нем_, _ujka_, екди, _picą_, 
   {{0xc330192c,0x2910a69c,0xc1c81944,0x68f4a69d}},	//   لەر_, moya_, िङ्ग, miyd, 
   {{0x21249d34,0xd3205aa2,0x68f4a69e,0xa6c801b9}},	//   _shoh_, льщи, liyd, _элга_, 
   {{0x66d0005c,0x2910037e,0xa2c0276a,0x00000000}},	//   _dækt, ooya_, लाब्, --, 
   {{0x2910a69f,0x657ca6a0,0xbf6430d3,0x68f493e3}},	//   noya_, muph, نگتو, niyd, 
   {{0x657c4ec2,0x057800c7,0x00000000,0x00000000}},	//   luph, _хәҷы_, --, --, 
   {{0x63a0a6a1,0x4424a6a2,0x61b0113e,0x68f401d5}},	//   mwon, _izm_, _مەتا, hiyd, 
   {{0x2910a6a3,0x20d400d6,0x21240652,0x63a0a6a4}},	//   koya_, _підс, _thoh_, lwon, 
   {{0x2124017a,0x32240150,0xf1a803e6,0x4e9007d6}},	//   _uhoh_, _جۋىپ_, _زامه_, پشیر, 
   {{0x63a0a6a5,0x657c0912,0x68f4a6a6,0xf08801f7}},	//   nwon, huph, diyd, _آئمه_, 
   {{0x657c2935,0x4424020b,0xdb208f52,0x20fc0327}},	//   kuph, _mzm_, اوسی, kċik_, 
   {{0x4424070d,0x29100efc,0x99d4075e,0x63a004e6}},	//   _lzm_, foya_, رتسا, hwon, 
   {{0x2910a6a7,0x5ba402bf,0x657c00d2,0xd7e40845}},	//   goya_, _зроз, duph, нізо, 
   {{0x63a00d27,0x7af401c4,0x38340e4e,0xf5380419}},	// [d3b0] jwon, pizt, тнар, _riť_, 
   {{0x7d1ca6a8,0x63a0a6a9,0x657c4242,0x8f98011a}},	//   llss, dwon, fuph, הימי, 
   {{0x2910a6aa,0x63a00196,0x66d00008,0x657c090c}},	//   boya_, ewon, _rækt, guph, 
   {{0x0574a6ab,0x29100286,0x63a001f5,0x66d0032e}},	//   االد, coya_, fwon, _sækt, 
   {{0xd6f8019b,0x63a004ba,0x78aca6ac,0x00000000}},	//   _qrコ_, gwon, mdav, --, 
   {{0xe294a6ad,0x78aca6ae,0x70740020,0x657c2747}},	//   ваш_, ldav, _በቀላሉ_, buph, 
   {{0x657c1ae8,0x44240165,0x63a0a6af,0x78ac8f1e}},	//   cuph, _ezm_, awon, odav, 
   {{0x63a039a2,0xa52401e0,0x34940117,0x8464011c}},	//   bwon, _аяуһ, _шабр, _бъфе, 
   {{0x7528a6b0,0x78aca6b1,0xf3900241,0x2724000f}},	//   _ihez, idav, _iṣow_, sône_, 
   {{0x02443306,0x59b00b9a,0x2910a6b2,0x78ac01a9}},	//   _مَكَ, ुमार, zoya_, hdav, 
   {{0x4174a6b3,0x7528a6b4,0x2910a6b5,0xed581def}},	//   _مانس, _khez, yoya_, ьон_, 
   {{0x76483630,0xe82000c5,0xdce80171,0xc0c811eb}},	//   _şeyl, _मरला_, _ķiģe, _пуче_, 
   {{0x75280810,0x657c0117,0x78aca6b6,0x888402dd}},	//   _mhez, zuph, ddav, ңғол, 
   {{0x66d004ce,0x657c0564,0x2910a6b7,0x7d1c02d0}},	//   _lækr, yuph, woya_, alss, 
   {{0x2910a6b8,0x63a0a6b9,0x6da400d1,0xa2c000cd}},	//   toya_, zwon, _рийа, लात्, 
   {{0xd7d800b5,0x66d003b2,0x63a0017a,0x78aca6ba}},	//   _scメ_, _nækr, ywon, gdav, 
   {{0xa684a6bb,0x2910a6bc,0x657ca6bd,0x98a0a6be}},	// [d3c0] клад, roya_, wuph, шите, 
   {{0x7528a6bf,0x657ca6c0,0x5b7806a9,0x2910a6c1}},	//   _ahez, tuph, _קריא, soya_, 
   {{0x64a4a6c2,0x75280099,0x63a00d27,0x78ac00dc}},	//   кажа, _bhez, wwon, bdav, 
   {{0x7528a6c3,0x63a0a6c4,0x657ca6c5,0x68f401a9}},	//   _chez, twon, ruph, qiyd, 
   {{0x657ca6c6,0xd464a6c7,0x6e2c008f,0xccf40134}},	//   suph, тиче_, _ŝabl, _mmɛ_, 
   {{0x66d0019b,0x63a0a6c8,0x657c0b6f,0xa2c077d7}},	//   _væks, rwon, puph, लाध्, 
   {{0x63a00c11,0x41b4a6c9,0x657c01b3,0xb73000e5}},	//   swon, امبر, quph, _اہلب, 
   {{0x63a00cf9,0x7528a6ca,0x442405b1,0x6d4403f0}},	//   pwon, _ghez, _tzm_, _çhay, 
   {{0x3f14569f,0x1af803d4,0x7d1c01bf,0x442403e0}},	//   лдис, ৃততে_, vlss, _uzm_, 
   {{0x78aca6cb,0x80c06211,0x52800eff,0x00000000}},	//   zdav, वाहे, _ەلەك, --, 
   {{0xd12c30c7,0x78ac0024,0x00000000,0x00000000}},	//   _вх_, ydav, --, --, 
   {{0x6abc365d,0x67d8005f,0x7528036e,0x00000000}},	//   _anpf, _kājā, _xhez, --, 
   {{0x7d1ca6cc,0x1ec807d6,0x78ac04a7,0x61e8002f}},	//   rlss, _олди_, vdav, lzfl, 
   {{0x67d800da,0x80c0a6cd,0x40e80345,0x00000000}},	//   _mājā, वावे, _توڤێ_, --, 
   {{0xdde81ec7,0x7b0400e2,0x61e80112,0x3d94a6ce}},	//   _ترشه_, _ērtā, nzfl, _сийр, 
   {{0x7e68047e,0xef180135,0x00000000,0x00000000}},	//   ladp, muża_, --, --, 
   {{0x76b8a6cf,0x78aca6d0,0x67d80055,0xef18025c}},	// [d3d0] нлар_, rdav, _nājā, luża_, 
   {{0x78ac0024,0x3d18003e,0x75280200,0x3cf80254}},	//   sdav, réwu_, _shez, lisv_, 
   {{0x75280928,0x78aca6d1,0x3d18003e,0xbebc00e2}},	//   _phez, pdav, séwu_, mlīd, 
   {{0x3cf801a6,0x73c40166,0x00000000,0x00000000}},	//   nisv_, ләзе, --, --, 
   {{0x3868a6d2,0x67d80055,0x841400c7,0x21640131}},	//   maar_, _cājā, амцх, ңиши_, 
   {{0x3868a6d3,0x2f541e37,0xbebc00e2,0xef18025c}},	//   laar_, қтис, nlīd, kuża_, 
   {{0x34940131,0x7e68a6d4,0xef180135,0x00000000}},	//   _йавр, dadp, juża_, --, 
   {{0x3868a6d5,0x7528a6d6,0x27240109,0x4dc800cc}},	//   naar_, _uhez, môna_, ানমূ, 
   {{0x776c0f71,0x32d801e1,0xbebc00e2,0xac840116}},	//   nsax, _lèyi_, klīd, ңгол, 
   {{0x3868a6d7,0xed584ecc,0xb9040327,0x00000000}},	//   haar_, ноо_, _ཨཾ_, --, 
   {{0x3868a6d8,0x27240109,0x9d500cbe,0x00000000}},	//   kaar_, nôna_, ینیت, --, 
   {{0x3868a6d9,0x67d80055,0x00000000,0x00000000}},	//   jaar_, _yājā, --, --, 
   {{0x3868a6da,0x2bb800c6,0x3cf80ba1,0x80c007d0}},	//   daar_, راحة_, èrva_, वारे, 
   {{0x776c1ed1,0xbebc00de,0x00000000,0x00000000}},	//   dsax, glīd, --, --, 
   {{0x3868a6db,0xed580798,0xfeb80066,0xdd8c0345}},	//   faar_, _џои_, _جانت_, _فوو_, 
   {{0x3868a6dc,0xbebc1a14,0x9d5001f7,0x00000000}},	//   gaar_, smīt, _انيت, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [d3e0] --, --, --, --, 
   {{0x67d80882,0x272405da,0x4ab401c0,0x6fd000cc}},	//   _rājā, fôna_, _төмр, _তেৱে, 
   {{0x3868a6dd,0xa2c023ef,0x66d001bf,0xbebc00e2}},	//   baar_, लास्, _dækp, slīg, 
   {{0x3868011f,0x59800845,0x2a6831b7,0x81bc0171}},	//   caar_, _улюб, labb_, _dzēl, 
   {{0xbb340150,0xd5ac00f1,0x00000000,0x00000000}},	//   _ﯗﻻﻥ_, يځې_, --, --, 
   {{0xe5a4a6de,0x37cc015b,0x61e817da,0xa5643346}},	//   _йиги, _রেকর, tzfl, _مدرن, 
   {{0xd6244773,0x7e68a6df,0x40e40075,0xe2980166}},	//   _боре_, vadp, исиғ, _җае_, 
   {{0x2a6804ba,0x91b4a6e0,0x61e8002f,0x00000000}},	//   habb_, اطور_, rzfl, --, 
   {{0x7e680158,0xe29800d8,0x2a68a6e1,0x00000000}},	//   tadp, _паа_, kabb_, --, 
   {{0x6144a6e2,0x53980302,0x2a6800dd,0x6fb400c5}},	//   _бежа, _אימו, jabb_, _अछरं, 
   {{0x38688531,0x7e68a6e3,0x764806be,0x3d9401f0}},	//   yaar_, radp, _şeyk, шинр, 
   {{0x2484a6e4,0xd00c021a,0x7e68409c,0x776ca6e5}},	//   ngom_, _کله_, sadp, ysax, 
   {{0x38689ed4,0x7e68079b,0xd7d800b5,0xbebc00e2}},	//   vaar_, padp, _ndバ_, tlīd, 
   {{0x3868a6d8,0x1ea8004b,0x32d802e2,0x2a6801d3}},	//   waar_, _ساتي_, _pèyi_, gabb_, 
   {{0x644c013f,0x39447197,0xca480338,0x00000000}},	//   _ɑbir, êls_, الفه_, --, 
   {{0x1b00a6e6,0xbebc00e2,0x00000000,0x00000000}},	//   рүүн, slīd, --, --, 
   {{0x3868a6e7,0x25a8a6e8,0x98143c97,0x24845522}},	// [d3f0] raar_, _asbl_, ابزا, dgom_, 
   {{0x3868a6e9,0x776ca6ea,0x27240109,0x00000000}},	//   saar_, rsax, tôna_, --, 
   {{0x3868a6eb,0x070805d9,0x35f400f0,0x00000000}},	//   paar_, ديلي_, јпер, --, 
   {{0x24840429,0x27240109,0x34941774,0x3868a6ec}},	//   ggom_, rôna_, радр, qaar_, 
   {{0x3cfc1533,0xd7f85981,0x712453d7,0xca740131}},	//   _लगने_, _чун_, یرعل, _ئاۋغ, 
   {{0x23b004a9,0x3f98054e,0x8af006be,0xa2c06a60}},	//   زمىس, ărul_, _itəc, लाष्, 
   {{0xd4984077,0x45d4010a,0x00000000,0x00000000}},	//   _пра_, _лорс, --, --, 
   {{0x2a6801ed,0x6fb400c6,0x76480790,0x00000000}},	//   zabb_, لمعا, _şeyh, --, 
   {{0x73382feb,0xa2c000cd,0x00000000,0x00000000}},	//   _азар_, लाश्, --, --, 
   {{0x877c008f,0xd00001ec,0x00000000,0x00000000}},	//   גאזי, _қолқ, --, --, 
   {{0x6cc4a6ed,0x6f9c01ec,0x2a6800e5,0x0244009f}},	//   айна, _ﺃﻴﻬﺎ_, vabb_, _اَمَ, 
   {{0x7ae403ac,0xbebc00de,0x00000000,0x00000000}},	//   _alht, glīb, --, --, 
   {{0x1d040107,0x00000000,0x00000000,0x00000000}},	//   реяи_, --, --, --, 
   {{0xd84c063f,0xab28a6ee,0xde90009b,0x00000000}},	//   _kọwa_, тога_, _даљњ, --, 
   {{0x6844a6ef,0x2a6801d3,0x2d8000c7,0x00000000}},	//   инва, rabb_, _êhe_, --, 
   {{0x2a6800dd,0x00000000,0x00000000,0x00000000}},	//   sabb_, --, --, --, 
  
   {{0x9f50025a,0xeb2801c0,0x4cf801d9,0x9d1805d0}},	// [d400] _âyô_, _ижил_, _لبکھ_, _שופט, 
   {{0xe9d81b10,0x7d0401e4,0x248401f5,0x00000000}},	//   _ако_, _ĉisi, wgom_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x98a00166,0x6ad46f11,0x2798009d,0x00000000}},	//   _диюе, _ठकुर, _итгэ_, --, 
   {{0x86780139,0x24843df9,0x68e40205,0x00000000}},	//   _бөер_, rgom_, _ilkd, --, 
   {{0x66e418ec,0x6b8001e4,0x48f000bc,0x26dc0051}},	//   _тога, _ĥogl, ीचको_, _ôto_, 
   {{0x64a4a6f0,0x32640212,0x25a80fac,0x248400d7}},	//   _кава, стів, _usbl_, pgom_, 
   {{0xdcf800b0,0xd0400131,0x30e420b0,0x91b40395}},	//   kutā, يپىي, йсың, ргът_, 
   {{0x764806b9,0x3cfc0037,0x00000000,0x00000000}},	//   _şeyi, _लगबे_, --, --, 
   {{0x657c00ca,0xe2a800db,0xa008036b,0x00000000}},	//   orph, _جارن_, _یقال_, --, 
   {{0x657c03a2,0x9310005e,0x629802d0,0x00000000}},	//   nrph, _بولش, _ibto, --, 
   {{0xf8d0009e,0xdd0c0205,0xd080005b,0x657c0332}},	//   _িষ্ঠ, _dışs, _дыши, irph, 
   {{0xd54001e1,0x69d808fb,0x657c002f,0x00000000}},	//   _kẹ́j, øten, hrph, --, 
   {{0x3f84a6f1,0xd5400241,0x9a8401a9,0x00000000}},	//   mumu_, _jẹ́j, шумл, --, 
   {{0x3f84a6f2,0x60c000df,0x094800db,0x00000000}},	//   lumu_, _knom, ичти_, --, 
   {{0xb7889c3a,0xd54001e1,0xdd8c01d3,0x00000000}},	//   ләге_, _lẹ́j, _فوڈ_, --, 
   {{0x7ae40770,0x6298151c,0x3f84a6f3,0x657c78ec}},	// [d410] _tlht, _obto, numu_, erph, 
   {{0x07080451,0x8f540375,0x00000000,0x00000000}},	//   ليقي_, יסמא_, --, --, 
   {{0x3f84a6f4,0x7bdc3e33,0xceb800ac,0x00000000}},	//   humu_, lysu, _şəki_, --, 
   {{0x3f84a6f5,0x451810f5,0x2724025a,0x62980429}},	//   kumu_, ація_, bôno_, _abto, 
   {{0x3f8411f9,0x7bdca6f6,0x03a80372,0x61fc02fb}},	//   jumu_, nysu, لدوو_, úpln, 
   {{0x3f84a6f7,0x62980076,0x69d8a6f8,0x00000000}},	//   dumu_, _cbto, äteg, --, 
   {{0xc2c81b06,0xddd800bc,0x9484005b,0x00000000}},	//   شبول_, patř, _вызд, --, 
   {{0x60c01529,0x3f84a6f9,0x629803ac,0xa6c8022e}},	//   _cnom, fumu_, _ebto, hmаl, 
   {{0xef18a6fa,0x3f84a6fb,0x4cb00011,0x7bdc01f4}},	//   лми_, gumu_, টামু, jysu, 
   {{0x4524031c,0x63e400cf,0x4dc80154,0x00000000}},	//   _འཚོར_, _ايكە, ানসূ, --, 
   {{0x6da46575,0x7bdc208d,0x00000000,0x00000000}},	//   щина, eysu, --, --, 
   {{0x3f84a6fc,0x60c0a6fd,0xace80408,0x00000000}},	//   bumu_, _gnom, умма_, --, 
   {{0xdd8c04d3,0xe0cc0014,0xf3f8054e,0x7bdc0142}},	//   ووی_, _سٲو_, _beţi_, gysu, 
   {{0x60c001d5,0x7cfc00c7,0x78700162,0x6da4a6fe}},	//   _znom, rũra, yðví, _гика, 
   {{0x60c002d0,0xb9b40395,0x00000000,0x00000000}},	//   _ynom, остъ, --, --, 
   {{0xdcf800da,0x684401c0,0x3858023a,0x7bdc036e}},	//   putā, снаа, ирую_, bysu, 
   {{0x2d844a7d,0x3cfc0034,0x7bdc00f2,0x660c058a}},	// [d420] lule_, _लगते_, cysu, _sxbk, 
   {{0x2cb0058a,0xe5a4004e,0x00000000,0x00000000}},	//   _hayd_, йизи, --, --, 
   {{0xe578a6ff,0x2cb0350e,0x6b84a700,0xa9080b24}},	//   узе_, _kayd_, lukg, _ميدل_, 
   {{0xfd500241,0x6298037e,0x787001a8,0x3f84a701}},	//   _aadọ, _sbto, rðví, yumu_, 
   {{0x2d84a702,0xd9180302,0x7bc00618,0x2cb01368}},	//   hule_, _תוכל, ālug, _mayd_, 
   {{0x2d84a703,0x3f84a704,0x60c091bf,0x2cb00009}},	//   kule_, vumu_, _snom, _layd_, 
   {{0xdef84ef9,0x3f8404ba,0xe4740166,0x60c0010e}},	//   ғып_, wumu_, _гузэ, _pnom, 
   {{0x6b840117,0x13e4a705,0x2cb0090e,0x224c00e2}},	//   kukg, рмәй_, _nayd_, _šokā_, 
   {{0x9ec40214,0x1fa401d5,0x1ea8a706,0x20fc025c}},	//   مزده, ёриг, هادي_, wċis_, 
   {{0x3f84a707,0xd84c02e3,0xd36c0597,0x2d84a708}},	//   rumu_, _họta_, _أهل_, fule_, 
   {{0x3f843d81,0x2cb0058a,0x1718008f,0x7cd802c9}},	//   sumu_, _bayd_, רויע, لودز_, 
   {{0x60c0a709,0x628817b8,0x3f84a70a,0x1a540137}},	//   _unom, lgfo, pumu_, өзмө_, 
   {{0x6b840c6a,0x60242b2d,0x2d84002e,0x6f6008b0}},	//   gukg, _удда, aule_, _قۇيم, 
   {{0xd84c01f2,0x38b401f2,0x50180375,0x7d0401e4}},	//   _lọta_, _ụr_, _עוגו, _ĉisu, 
   {{0xd6d8a70b,0x2d84a70c,0x13c011ba,0xf3f80276}},	//   қта_, cule_, ্নয়, _veţi_, 
   {{0x6b840117,0x7bdc00e4,0xb80c00eb,0xb8083f6c}},	//   bukg, pysu, _শরবত_, ليزم_, 
   {{0x7d0ca70d,0x6bd800dd,0x9f500139,0x00000000}},	// [d430] _ijas, _نوٹس_, _äyä_, --, 
   {{0x3ce8a70e,0x7c2ca70f,0x45240327,0xba9800d4}},	//   _hlav_, _izar, _འཚུར_, _твоє_, 
   {{0xd84c27dd,0xd5b8732a,0xdcf80276,0x96940124}},	//   _bọta_, ыса_, cută, ирҧш, 
   {{0x2cb00067,0x386c032e,0x69d80821,0x00000000}},	//   _xayd_, _þer_, ätee, --, 
   {{0xd378a710,0x2d84a711,0x7d0c01f7,0x00000000}},	//   уче_, zule_, _mjas, --, 
   {{0x92680372,0x62887944,0x7c2c009f,0x7d0c01a9}},	//   урда_, ggfo, _mzar, _ljas, 
   {{0x7d0ca712,0x3ce803a1,0x2d84009a,0x799401c7}},	//   _ojas, _olav_, xule_, ntzw, 
   {{0x2d84a713,0x614051f2,0x7c2c036b,0x7d0ca714}},	//   vule_, меща, _ozar, _njas, 
   {{0x2d84016e,0x7c2ca715,0x62980bcd,0xb274084c}},	//   wule_, _nzar, úboð, _млаш, 
   {{0x2d84a716,0x7d0ca717,0x518405f5,0x2cb00072}},	//   tule_, _ajas, _гуда, _sayd_, 
   {{0x707818a2,0x7c2ca718,0x7d0c0055,0x00000000}},	//   _نماز_, _azar, _bjas, --, 
   {{0x2cb007d6,0x7d0c04cc,0x3ce807de,0x69d803cd}},	//   _qayd_, _cjas, _clav_, øtem, 
   {{0x7c2ca719,0x00000000,0x00000000,0x00000000}},	//   _czar, --, --, --, 
   {{0x7c2c0433,0x3ce800c5,0x2cb00009,0x6b84a71a}},	//   _dzar, _elav_, _wayd_, rukg, 
   {{0x3ce802fa,0x7c2c0323,0x2d841cdf,0x7d0c0162}},	//   _flav_, _ezar, qule_, _fjas, 
   {{0xa92400d6,0x7d0c044e,0x61ec0d16,0x3ce8a71b}},	//   ідал, _gjas, _üble, _glav_, 
   {{0x6674a71c,0x6ecca71d,0x62886130,0x7dc400db}},	// [d440] قدار, तापु, ygfo, _وقۇن, 
   {{0xa9a4871a,0x7d0c0010,0xcd54001f,0x7b0800d0}},	//   _диод, _zjas, _የተነገ, hľuj, 
   {{0x7bc00421,0xbebc00e2,0x3f980356,0x1a9800df}},	//   ālue, klīn, ărui_, _דייע, 
   {{0xe3b8053f,0x764847af,0xdef40023,0x7c2c00ee}},	//   ибе_, _şeyt, _ዋዛን_, _yzar, 
   {{0x7b080419,0x872801e2,0xbebc00de,0x00000000}},	//   dľuj, _هغسې_, dlīn, --, 
   {{0x2d7400b0,0xf1a40037,0x00000000,0x00000000}},	//   kāe_, _खनखन, --, --, 
   {{0x6ecc1788,0xc0c41b15,0x628894fc,0xb0c421bd}},	//   तानु, зәли, rgfo, वांग, 
   {{0xd84c01e1,0x4524031c,0xa5080a5b,0x00000000}},	//   _họra_, _འཚིར_, _теба_, --, 
   {{0x7d0c0010,0xe2c80958,0x8fa01d39,0x00000000}},	//   _rjas, _клад_, дање, --, 
   {{0x23280c04,0x3ce8a71e,0x7cec004a,0x2a7801ab}},	//   _този_, _slav_, _mûre, _ndpb_, 
   {{0x7c2ca71f,0x3ce8a720,0x2fcc0548,0x442400ad}},	//   _szar, _plav_, axeg_, _hym_, 
   {{0x44240030,0x69cc0477,0x25ac03cd,0xa2c01fe7}},	//   _kym_, dxbe, åfly_, लाक्, 
   {{0x6e2c01e4,0x7f5800c7,0xb7500241,0x00000000}},	//   _ŝabt, _уалс_, _osùọ, --, 
   {{0x27f0012d,0x9d080154,0x442407f7,0x625c0248}},	//   dzyn_, রতেন_, _mym_, _ṣoju, 
   {{0x442403a2,0x7d0ca721,0x7d780c4f,0x8af003e3}},	//   _lym_, _tjas, _امبر_, _itəl, 
   {{0x7c2ca722,0x7d0c7f88,0x5ba4026b,0xdb6801a9}},	//   _tzar, _ujas, _дроз, _крол_, 
   {{0x7d1ca723,0x4424a724,0x7c2ca725,0xcd540020}},	// [d450] moss, _nym_, _uzar, _የተናገ, 
   {{0xd5b8a726,0x6ecc2802,0x00000000,0x00000000}},	//   исе_, तायु, --, --, 
   {{0x44240731,0x764803ee,0xdb0803e6,0x94a801b9}},	//   _aym_, _şeys, _مزگه_, итда_, 
   {{0x4424a727,0x7d1c579d,0x8548003b,0x00000000}},	//   _bym_, noss, ізів_, --, 
   {{0x27f0a728,0x4424a729,0x6ecc11bc,0xf434013d}},	//   czyn_, _cym_, तामु, чедэ, 
   {{0x6d0044ab,0x4424a72a,0x7d1ca72b,0x6eec0413}},	//   _लगभग_, _dym_, hoss, _kúbe, 
   {{0x7d1ca72c,0x4424a72d,0x7b080030,0x81a8007b}},	//   koss, _eym_, tľuj, قطيف_, 
   {{0x7d1ca72e,0xef180135,0x00000000,0x00000000}},	//   joss, mużi_, --, --, 
   {{0x6d0010f7,0x7d1ca72f,0x4424011a,0xbebc00e2}},	//   _लगबग_, doss, _gym_, rlīn, 
   {{0x69d80b34,0x7b080419,0x00000000,0x00000000}},	//   øtek, sľuj, --, --, 
   {{0x7d1ca730,0xbebc00e2,0x442400a2,0xef18031c}},	//   foss, plīn, _zym_, nużi_, 
   {{0x2a78070d,0xf084005e,0x6eec2815,0xd6c00154}},	//   _sdpb_, _ءداۋ, _súbd, োসিয, 
   {{0xd7a800af,0x00000000,0x00000000,0x00000000}},	//   _घैलच, --, --, --, 
   {{0xa968036b,0xef18025c,0x00000000,0x00000000}},	//   йига_, kużi_, --, --, 
   {{0xf1bc0a28,0x6f00a731,0x7cec07ea,0x6f9c0220}},	//   ्मिन, milc, _sûre, _ﺃﻴﻀﺎ_, 
   {{0x7d1c0548,0xd6f8037e,0x6f000219,0xef180327}},	//   coss, _psタ_, lilc, dużi_, 
   {{0x2bc40037,0x6f0001e7,0xa6e4004e,0x00000000}},	// [d460] _लपटा, oilc, пжал, --, 
   {{0xf1bc0bca,0x27f0a732,0x4424a733,0x6f000427}},	//   ्मान, rzyn_, _rym_, nilc, 
   {{0x4424a734,0x499481cd,0x27f0a735,0x7ae001d3}},	//   _sym_, _تیزر, szyn_, ölte, 
   {{0x7cec0428,0x8544063f,0x6f00a736,0x19540a1e}},	//   _tûre, _ịgbọ_, hilc, _מבטל_, 
   {{0x6f000c09,0x23281a92,0xd8d4008f,0x00000000}},	//   kilc, боди_, _זוכט_, --, 
   {{0x7d1ca737,0xef18025c,0x00000000,0x00000000}},	//   zoss, bużi_, --, --, 
   {{0x6f00a738,0x3cfc00af,0x5270141b,0x7d1c01d3}},	//   dilc, _लगले_, راوز, yoss, 
   {{0x44243f8e,0x63041968,0xf1a80ccb,0x00000000}},	//   _tym_, _کوئل, تاهه_, --, 
   {{0xa3e80323,0x7d1c29a8,0x442404ba,0x6d54682a}},	//   _удаа_, voss, _uym_, ízan, 
   {{0x7d1c0a40,0xd24c00c6,0x6f0007c5,0x2008054e}},	//   woss, _منك_, gilc, ăbi_, 
   {{0x7d1ca739,0x9e04036b,0xd12c03e6,0x6eec02d2}},	//   toss, ячил, _ڵمه_, _búbb, 
   {{0x239c005f,0xc10400f1,0x00000000,0x00000000}},	//   pājā_, _کوچي, --, --, 
   {{0xa0380014,0x6eeca73a,0x00000000,0x00000000}},	//   _آشا_, _súbe, --, --, 
   {{0x7d1ca73b,0x6f000113,0xb19803b2,0x212402f2}},	//   soss, cilc, óðgá, _ببڕێ, 
   {{0x3a24105c,0xe8580521,0x0e980375,0x7d1c2b8a}},	//   ælp_, _ọnụn, _השול, poss, 
   {{0x7d1c011f,0x6eec02d2,0x69d801f4,0xd90c0066}},	//   qoss, _gúbb, ätea, ایح_, 
   {{0x7b14084c,0x00000000,0x00000000,0x00000000}},	// [d470] _одих, --, --, --, 
   {{0x3f84020c,0x6d440022,0x7b080419,0x7e7c01e7}},	//   irmu_, _éhar, džug, órph, 
   {{0x5fac0034,0x057424e0,0x921802ab,0xd6f8037e}},	//   _जैसल, فاند, _पुंज_, _upキ_, 
   {{0x2ea837e3,0x3f8402f0,0xda6405af,0xef180135}},	//   _कस्त, krmu_, _باکي, rużi_, 
   {{0x970000d1,0x4c9c00df,0x00000000,0x00000000}},	//   _كېرى, מבאו, --, --, 
   {{0x5394001f,0x189402d3,0x7158516a,0x82a40114}},	//   _መግዛት_, _ውሽጠይ_, орис_, ешће, 
   {{0x6f00a73c,0x3f840083,0xd34407d6,0xa2c0a73d}},	//   vilc, ermu_, _کیته_, लाज्, 
   {{0xb9240248,0xd1d0001f,0x6f00a73e,0x69d80fac}},	//   _aipẹ_, ያኒቱ_, wilc, øtei, 
   {{0x6f00a73f,0x3c440055,0xb4e8a740,0x620403e3}},	//   tilc, _jīvī_, यसी_, _əslə, 
   {{0x600445b3,0x9e7c022e,0x057400e5,0x00000000}},	//   ьным_, lotª_, _زاہد, --, 
   {{0x6f0009a8,0x81bc005f,0x7cf00124,0x518401a9}},	//   rilc, _dzēs, _ẽram, _хуза, 
   {{0xeb9809fe,0x6f00151c,0x6218008f,0x00000000}},	//   оим_, silc, _וועק, --, 
   {{0x6f000427,0xa2c00490,0x3c4400b8,0x7c280210}},	//   pilc, लाच्, _nīvī_, żern, 
   {{0x3f98084c,0x6f00022f,0x00000000,0x00000000}},	//   ărut_, qilc, --, --, 
   {{0x7b0805be,0xcdc001d5,0x00000000,0x00000000}},	//   džud, _чайқ, --, --, 
   {{0xa968036b,0x200c01a6,0x98a00408,0x0fcc00fe}},	//   йиҳа_, šmiš_, кисе, িনীধ, 
   {{0x3cf80023,0xa69400ea,0xcfdc00eb,0xdcf80064}},	// [d480] ërve_, дреј, _বেতন, jutę, 
   {{0x7b080024,0x9b000064,0xaa8800f2,0x00000000}},	//   gžud, _азьд, _بندم_, --, 
   {{0x38b400c7,0xd84c0241,0x00000000,0x00000000}},	//   _ẽrei_, _tọpa_, --, --, 
   {{0x2d843c60,0xd464026a,0x9dd4008f,0x42080137}},	//   irle_, дице_, וועק_, үмдү_, 
   {{0xe738a741,0x2d84002f,0x939005af,0x8ca000b8}},	//   _мем_, hrle_, نجوا, ग्यो, 
   {{0x2490033f,0x00000000,0x00000000,0x00000000}},	//   żym_, --, --, --, 
   {{0x69c80077,0x69180165,0xdb0c01c7,0x56b4123b}},	//   _áfed, dïez, ädéi, _קפלן_, 
   {{0x910000cf,0x2d8401ef,0x00000000,0x00000000}},	//   кчыд, drle_, --, --, 
   {{0x2d84a742,0xefc80023,0x78a800c7,0xb9240ca8}},	//   erle_, ሽጣዊ_, _ñeve, _pipẹ_, 
   {{0x81bc00da,0x3f840327,0x00000000,0x00000000}},	//   _dzēr, rrmu_, --, --, 
   {{0x2d840072,0x00000000,0x00000000,0x00000000}},	//   grle_, --, --, --, 
   {{0x923002dd,0x5574010f,0x00000000,0x00000000}},	//   _شىنش, ועטן_, --, --, 
   {{0x69d80724,0x2d84a743,0x5ed8015b,0x09dc00cc}},	//   äten, arle_, যোগে, _ডেলা, 
   {{0x1ea8a744,0x5924025c,0x7c28012d,0x81bc00ef}},	//   _ذاتي_, _ཡེངས_, żero, _uzēs, 
   {{0x3914529e,0xc0dc001f,0xdb0c0cad,0x00000000}},	//   емвр, ንጀል_, _ìdíl, --, 
   {{0x26c801f5,0x3eaca745,0x0fc000d1,0xd7e400d4}},	//   _anbo_, ledt_, _чйән, мізо, 
   {{0x81d402f5,0xebc000d1,0x0c747286,0xdcfc00c0}},	// [d490] হনি_, _йәрн, _شديد, _švėk, 
   {{0xd5e8021f,0x6eeca746,0x96048b29,0x6fb000cd}},	//   يعان_, _kúba, وبام, _अनसू, 
   {{0x5a200014,0x00000000,0x00000000,0x00000000}},	//   _شہرٕ, --, --, --, 
   {{0xd7f87180,0xb4e800dc,0xb7d800e5,0x00000000}},	//   _дуг_, यसे_, _فوجا_, --, 
   {{0xd83873f6,0x6eec01e7,0x00000000,0x00000000}},	//   _фэн_, _lúba, --, --, 
   {{0x78aca747,0x2d841368,0x00000000,0x00000000}},	//   leav, yrle_, --, --, 
   {{0xd1b802dd,0x8af00213,0x8ca0012d,0xa2d09fbb}},	//   تاشا_, _stək, ग्डो, ايىت, 
   {{0x78aca748,0xfa0c01fb,0x00000000,0x00000000}},	//   neav, _đầu_, --, --, 
   {{0x78ac0158,0x3eac005c,0x2d840042,0x3eb8022e}},	//   ieav, fedt_, wrle_, оrt_, 
   {{0x78ac005c,0x00000000,0x00000000,0x00000000}},	//   heav, --, --, --, 
   {{0x6eeca749,0x78ac0c4e,0xa6c8022e,0x6dc000db}},	//   _cúba, keav, mmаt, اۅبۅ, 
   {{0x6eec007b,0xe0cc01a9,0x00000000,0x00000000}},	//   _dúba, _ёв_, --, --, 
   {{0x5184016c,0x6ab8000f,0x3eac003b,0x78ac6460}},	//   _хуҷа, ôtfo, bedt_, deav, 
   {{0x7ff4a55b,0x2d840010,0x69d80108,0x00000000}},	//   _جسما, prle_, äteo, --, 
   {{0x2eb801d9,0xc0980023,0x00000000,0x00000000}},	//   _وَچھ_, _ዉሽጥን_, --, --, 
   {{0x78aca74a,0x9c6800a2,0x6844a74b,0xb4e80864}},	//   geav, _boэu, енба, यसो_, 
   {{0x5eb0015b,0xb4e8012c,0x00000000,0x00000000}},	// [d4a0] জারে, यसै_, --, --, 
   {{0xd8200276,0x00000000,0x00000000,0x00000000}},	//   удуи, --, --, --, 
   {{0xe4a49e2c,0x78aca74c,0xa49401e4,0xe9a400d8}},	//   ерло, beav, liϲi, _џамп, 
   {{0x78ac52f0,0x61ec0327,0x00000000,0x00000000}},	//   ceav, _żblo, --, --, 
   {{0x474407dd,0x2900a74d,0x3eac00e5,0x00000000}},	//   _аҭаг, _imka_, yedt_, --, 
   {{0xd24ca74e,0xc1a80150,0x00000000,0x00000000}},	//   منه_, _ﺴﻴﺭﺍ, --, --, 
   {{0x9f400085,0x3eac77e6,0xbebc00e2,0xe504007b}},	//   ákí_, vedt_, slīk, _كبري, 
   {{0x673ca74f,0x15400b3e,0x6eec8cda,0x90940395}},	//   lmpj, _бесм, _rúba, евът_, 
   {{0x3eaca750,0x673c01f5,0xe2907cf6,0x1af40154}},	//   tedt_, ompj, _مذا_, ঁচতে_, 
   {{0x629c004e,0xa6c8022e,0x20fc0327,0x00000000}},	//   òpod, mmаs, nċiz_, --, 
   {{0x69d836be,0x3eac26ff,0x9c100521,0xd24ca751}},	//   ätel, redt_, họta, _انم_, 
   {{0x9c100521,0x71640137,0xf1f801e2,0x00000000}},	//   kọta, _شامك, _غونډ_, --, 
   {{0xdee4a752,0x3074a753,0x92b00c58,0x78ac4606}},	//   _поди, _рухс, টাৰ_, veav, 
   {{0x290001c8,0x673c01f5,0x2be0023e,0x00000000}},	//   _amka_, jmpj, _पथरा, --, 
   {{0x78ac1057,0x29000009,0xc984377e,0x5d10a754}},	//   teav, _bmka_, лути, _مېدا, 
   {{0x673c0d27,0xed4c01d3,0xa6c801a9,0x00000000}},	//   empj, _گھی_, zmаt, --, 
   {{0x76b843ee,0xab6051bb,0x2b50010e,0xdd9002dd}},	// [d4b0] млар_, şüre, _guyc_, _рақы, 
   {{0x29000472,0x78aca755,0xb4e800cd,0x00000000}},	//   _emka_, seav, यस्_, --, 
   {{0x69d803cd,0xd5483918,0x04c80ee8,0x78ac01f4}},	//   øtet, سجام_, کوني_, peav, 
   {{0x78ac0286,0x673c01a4,0x77680dde,0x00000000}},	//   qeav, ampj, _çexo, --, 
   {{0x3868080b,0x98a80034,0xdee80092,0xd6d800f3}},	//   mbar_, _chcą_, ሆኑና_, _етв_, 
   {{0x21240280,0x3868a756,0x724400d1,0xddd80064}},	//   _akoh_, lbar_, نھال, ngtų, 
   {{0xa6c801a9,0x00000000,0x00000000,0x00000000}},	//   rmаt, --, --, --, 
   {{0x3868a757,0x9f500122,0x40782b62,0x00000000}},	//   nbar_, ždým_, ىلىڭ_, --, 
   {{0x67480209,0x3868a758,0xb914063f,0x1304005e}},	//   _üpjü, ibar_, wadọ_, _كىرۋ_, 
   {{0x3868a759,0x3278035c,0xb8fc031c,0xed583a49}},	//   hbar_, _آماج_, _ྡོ_, моо_, 
   {{0xee385d99,0xefd40020,0xa2ac298e,0x6dbc0055}},	//   ьно_, _ክፍያ_, ंजर्, _ṇabh, 
   {{0x6aac0472,0x386801e4,0xc178007b,0xdedc0092}},	//   webf, jbar_, _أصلا_, ንበኛ_, 
   {{0x2ef4055f,0xde143e58,0x3868005c,0x00000000}},	//   _издр, فقیت_, dbar_, --, 
   {{0xe8c82cbc,0x29002a1f,0x38680109,0x9b540fc0}},	//   ाञ्च, _smka_, ebar_, тиёт_, 
   {{0x38680ade,0xa020010b,0x00000000,0x00000000}},	//   fbar_, _ýörs, --, --, 
   {{0x6eec00d2,0xad2407d2,0x8c8801e0,0x00000000}},	//   _kúbo, _جىبى, _яҙма_, --, 
   {{0x68446d5f,0x7768a75a,0x00000000,0x00000000}},	// [d4c0] тнаа, _çexl, --, --, 
   {{0x3868011f,0x9660034b,0x69d8143a,0x98a4a75b}},	//   abar_, икуе, øtes, ēnā_, 
   {{0x3868a75c,0x6eec00d2,0x673c0d27,0x59b0013d}},	//   bbar_, _lúbo, rmpj, _көтс, 
   {{0xf5080075,0x2900014b,0xc6d401c0,0x195400d9}},	//   ىزنى_, _umka_, _өсгө, _שבכל_, 
   {{0x29105088,0xc3302e51,0x00000000,0x00000000}},	//   mnya_, مەر_, --, --, 
   {{0x2910a75d,0x68f4a75e,0x2124a75f,0xe73801c6}},	//   lnya_, lhyd, _skoh_, _цег_, 
   {{0x2910a760,0x3184010b,0x68f402d0,0x64988abc}},	//   onya_, гтың, ohyd, _отар_, 
   {{0x2910a761,0x64a4016c,0x403454be,0x68f47b7c}},	//   nnya_, _шаба, лейс, nhyd, 
   {{0x291033cb,0x9c1001f2,0xd5300131,0x9ec40214}},	//   inya_, họra, _ئېنگ, نزده, 
   {{0x29105088,0x2364008f,0x3868a762,0x7c280210}},	//   hnya_, mpoj_, zbar_, żerk, 
   {{0x2910a763,0xfdd0015b,0x2364010f,0x3264014b}},	//   knya_, ান্ড, lpoj_, _сехҳ, 
   {{0x6eec0077,0x2910a764,0xf1a802f2,0x236401e4}},	//   _fúbo, jnya_, _سامه_, opoj_, 
   {{0x291015a5,0x38680408,0x5fb4a765,0x68f40142}},	//   dnya_, vbar_, _अनिल, dhyd, 
   {{0xd00ca766,0x2910a767,0x38680072,0x00000000}},	//   _بله_, enya_, wbar_, --, 
   {{0x3868a768,0x29102831,0x6eec00d7,0xceb0011a}},	//   tbar_, fnya_, _zúbo, _כיס_, 
   {{0x2910a769,0x3ebc0579,0x8d80036b,0xc8640022}},	//   gnya_, _havt_, _тушд, итуи, 
   {{0x3834a76a,0x69d808fb,0x00000000,0x00000000}},	// [d4d0] унар, øter, --, --, 
   {{0x3868a76b,0x2910a76c,0x7c2ca76d,0x8f9800d9}},	//   sbar_, anya_, _iyar, וימי, 
   {{0x291033cb,0x3868a76e,0x7c2c002b,0xbebc0171}},	//   bnya_, pbar_, _hyar, blīv, 
   {{0x3ebca76f,0x2910a770,0x7c2ca771,0x09dc03d4}},	//   _lavt_, cnya_, _kyar, _ডেকা, 
   {{0xc4840046,0x7c2c00b5,0x78bc02d0,0x568001d3}},	//   рлік, _jyar, _iasv, _نگاہ, 
   {{0xe294a772,0x7c2c030d,0xf8d00574,0xc3240d30}},	//   гаш_, _myar, हावय, амік, 
   {{0x78bc077e,0x45d4a773,0x6eeca774,0xd4983609}},	//   _kasv, _корс, _súbo, _ора_, 
   {{0x7c2ca775,0x6eec004e,0x78bc005a,0xada4036b}},	//   _oyar, _púbo, _jasv, қамл, 
   {{0x7c2ca776,0x78bca777,0xc0c80063,0x660001e4}},	//   _nyar, _masv, тује_, ĝoke, 
   {{0x51840efb,0x78bca778,0x29102948,0x41749717}},	//   _ауда, _lasv, znya_, _چانس, 
   {{0x7c2ca779,0x29100263,0x3ebc0009,0x645c033f}},	//   _ayar, ynya_, _davt_, śpie, 
   {{0x7c2ca77a,0x78bc0f72,0x2910a77b,0x3078010f}},	//   _byar, _nasv, xnya_, _װאַנ, 
   {{0x7c2c01aa,0x8edc015b,0x7f94014b,0x9f401155}},	//   _cyar, যোগগ, _вачх, šká_, 
   {{0x2910a77c,0x7c2ca77d,0x78bca77e,0x48c000fe}},	//   wnya_, _dyar, _aasv, _একেৰ, 
   {{0x2910a763,0x75285552,0x7c2c0083,0x68f4a77f}},	//   tnya_, _okez, _eyar, thyd, 
   {{0x7528556c,0x9ed40116,0x291004ba,0x80b800cd}},	//   _nkez, _амәт_, unya_, ्यये, 
   {{0x29105088,0x7c2ca780,0x68f40368,0xd7d8037e}},	// [d4e0] rnya_, _gyar, rhyd, _adモ_, 
   {{0x29105088,0x7528a781,0x68f4004a,0x00000000}},	//   snya_, _akez, shyd, --, 
   {{0x29104237,0x1a9800c8,0x80b8a782,0xd940084c}},	//   pnya_, _אייע, ्यमे, реӂи, 
   {{0x6abca783,0x29100a2e,0x78bc0b4f,0x7c2c0198}},	//   _hapf, qnya_, _gasv, _yyar, 
   {{0x6abc66b3,0xa2e4a784,0x73c001e0,0x528000d1}},	//   _kapf, лодд, оҡта, ڭلىك, 
   {{0x78bc0dfe,0x752801e4,0xa6445712,0x41840131}},	//   _zasv, _ekez, _مخزن, атиғ, 
   {{0x34f00a28,0x6abca785,0x78bc1cee,0x236401e4}},	//   ṇaḥ_, _mapf, _yasv, spoj_, 
   {{0xd6240798,0x657c002f,0x7c28031c,0x00000000}},	//   _сосе_, msph, żeri, --, 
   {{0x98a80034,0xbebc00e2,0x657c035a,0x8cd8a786}},	//   _chcę_, klīt, lsph, यानो, 
   {{0x7c2c0516,0x9798008f,0x87800131,0x7e74013e}},	//   _ryar, עשיק, _ﺧﻪﻟﻖ_, шгох, 
   {{0x7c2c2831,0x657c7906,0x6298a787,0x22140006}},	//   _syar, nsph, _icto, _сфар, 
   {{0xfcc4053f,0x7c2ca788,0xbebc00ef,0x00000000}},	//   рәкм, _pyar, elīt, --, 
   {{0x6abc015c,0x78bca789,0x3ebc020c,0xbed406ed}},	//   _bapf, _rasv, _tavt_, _волј, 
   {{0x78bc1326,0xbebc0029,0x7c2c43d6,0x6abca78a}},	//   _sasv, glīt, _vyar, _capf, 
   {{0x78bca78b,0x1af402f5,0x69d803cd,0x00000000}},	//   _pasv, ঁচলে_, øtep, --, 
   {{0x657c03ac,0x7c2ca78c,0x00000000,0x00000000}},	//   dsph, _tyar, --, --, 
   {{0x7c2ca78d,0x6298a78e,0x78bca78f,0xe7780588}},	// [d4f0] _uyar, _octo, _vasv, катә_, 
   {{0x6abc0223,0x78bc1ce9,0x9a2400c6,0x00000000}},	//   _gapf, _wasv, _معجن, --, 
   {{0x78bca790,0xa1440171,0xf8b01913,0x2a74011a}},	//   _tasv, _kaķī, _وکر_, _דעתך_, 
   {{0x62985337,0x8cd806ff,0x6abc1d60,0xf79402d5}},	//   _acto, यायो, _zapf, _камэ, 
   {{0x6abca791,0x13a45194,0xd7e40d30,0xb4e407f7}},	//   _yapf, انتی_, _сіно, _पकी_, 
   {{0x7cec002d,0x6298a792,0x657c50eb,0x61e802d0}},	//   _bûrk, _ccto, bsph, fyfl, 
   {{0xb9d00b82,0x657c035a,0x61e80142,0x8cd81408}},	//   _ስኒ_, csph, gyfl, यामो, 
   {{0x6298a793,0xef845c74,0x69d8005b,0x6ebc000d}},	//   _ecto, алип, ätei, _वोजु, 
   {{0xef18a794,0xe0d4a795,0xb398a796,0xbf64a797}},	//   кми_, рвы_, _шкаф_, یدیو, 
   {{0xaf04a798,0x61e8002d,0xc2b800db,0x733400d1}},	//   рпол, byfl, _مامئ_, _ئىئا, 
   {{0x6abc006f,0xada4a799,0x00000000,0x00000000}},	//   _rapf, шанл, --, --, 
   {{0xe1600066,0x00000000,0x00000000,0x00000000}},	//   _بگوي, --, --, --, 
   {{0x6abc006f,0x80c803d4,0x4054009f,0x00000000}},	//   _papf, িউশ্, _ائمس, --, 
   {{0xdfcc00b2,0xa3d428f0,0x00000000,0x00000000}},	//   _آيو_, िमत_, --, --, 
   {{0x6abca79a,0x657c02d0,0x00000000,0x00000000}},	//   _vapf, xsph, --, --, 
   {{0x6abca79b,0x6578003a,0xb4c000dc,0xfd5400b8}},	//   _wapf, _æthi, ्ञो_, _nugṛ, 
   {{0x6abca79c,0x80b801bc,0xe78400d1,0x97c0026b}},	// [d500] _tapf, ्यते, شلاپ, ойте, 
   {{0x657ca79d,0x98a800e2,0xa1440171,0x00000000}},	//   tsph, ījās_, _zaķī, --, 
   {{0xa968074d,0xe3b000ec,0xa8880354,0x00000000}},	//   _шина_, ڪرا_, _ийна_, --, 
   {{0x61ec0730,0x657c7421,0xa52400ee,0xe89c0023}},	//   _übli, rsph, шмед, _ውሽጦም_, 
   {{0xe3b08958,0x657ca79e,0x82847d9d,0xddc803b9}},	//   ترا_, ssph, йқад, _offş, 
   {{0xd2a400ee,0x25640014,0x7790a79f,0x657c035a}},	//   икче_, _نارُ, _ریما, psph, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x1fa4188c,0x55b80375,0x61e8a7a0,0x00000000}},	//   арог, _במלו, ryfl, --, 
   {{0xdef8a7a1,0x6eec0af2,0x76480213,0x61e89da5}},	//   вын_, _kúbh, _şeyx, syfl, 
   {{0x8544063f,0x62980419,0x61e802d0,0x00000000}},	//   _ịghọ_, _ucto, pyfl, --, 
   {{0x6eec00d0,0x72a000db,0x80b8a7a2,0xddd84a97}},	//   _zúbk, _رەين, ्यदे, matū, 
   {{0xa068a7a3,0x63a004c9,0x6eec00d2,0x60080184}},	//   _рада_, oton, _lúbh, _инем_, 
   {{0xeef405d9,0x8fa000c0,0x00000000,0x00000000}},	//   _ڏينھ, _маце, --, --, 
   {{0x63a0a7a4,0x7cec4a31,0x776843bc,0x7b080024}},	//   iton, _mûri, _çexi, ržuo, 
   {{0x4e3002dd,0x69c8032e,0x00000000,0x00000000}},	//   _وعىز, _áfel, --, --, 
   {{0x63a0a7a5,0xa3d43d1d,0x7e78014f,0x00000000}},	//   kton, िमा_, _hevp, --, 
   {{0xddd80053,0xfb8412a7,0x63a0a7a6,0x490800c5}},	// [d510] katū, _ادبی, jton, _सगरो_, 
   {{0x63a07bc3,0x8cd800bc,0x7e7800ef,0xfd5400b8}},	//   dton, याथो, _jevp, _sugṛ, 
   {{0xdfc4a7a7,0x05740aaf,0x7e78014f,0x63a0a7a8}},	//   _کي_, قاند, _mevp, eton, 
   {{0x7ae4a7a9,0x7cec0086,0x386c0209,0x7994016c}},	//   _hoht, _bûri, _ýer_, muzw, 
   {{0x7ae49469,0x63a01089,0xd7f8a7aa,0x7994379d}},	//   _koht, gton, _рун_, luzw, 
   {{0x7ae40664,0x7e78a7ab,0x613c01c7,0x387803b9}},	//   _joht, _nevp, hëld, _hesr_, 
   {{0x63a0a7ac,0x799407a8,0x7ae4016d,0x47340014}},	//   aton, nuzw, _moht, _گرێز, 
   {{0x6ea8038e,0x4dac00cc,0x7ae4005b,0x63a0014f}},	//   ज्नु, টিমূ, _loht, bton, 
   {{0x63a0a7ad,0x799419d9,0x3de4015b,0xaf0400cf}},	//   cton, huzw, _ফেলল, йпил, 
   {{0x7994a7ae,0x6eec00d2,0x7ae4a7af,0xb8d80135}},	//   kuzw, _kúbi, _noht, _ཚི_, 
   {{0x7e783733,0xf1d001c0,0x6eec1ada,0xdcf800e2}},	//   _devp, _хөлө, _júbi, jutē, 
   {{0x79940107,0x705893cf,0xa6c801d5,0x00000000}},	//   duzw, _садр_, jlаn, --, 
   {{0x7ae4a7b0,0x6f644706,0xa6c8022e,0x6eec0419}},	//   _boht, _اهتم, dlаn, _lúbi, 
   {{0xc60002a6,0x79949b06,0x6d54a7b1,0x6438010f}},	//   ্থতা_, fuzw, ízas, טערנ, 
   {{0x63a000dd,0x79940230,0x7ae40010,0xcee40014}},	//   zton, guzw, _doht, _مرژن_, 
   {{0x63a0a7b2,0x76540209,0x387848fc,0x92b00154}},	//   yton, _agzy, _cesr_, টায়_, 
   {{0x6d44a7b3,0xa6841982,0x63a07da5,0x7c2807c5}},	// [d520] mmka, йлад, xton, üert, 
   {{0x7994a7b4,0x6d44a7b5,0x63a00010,0xdcf800ef}},	//   buzw, lmka, vton, butē, 
   {{0x3878011c,0x79940453,0x7b440137,0x6d44017a}},	//   _fesr_, cuzw, _بئيل, omka, 
   {{0x6eeca7b6,0x6d44007f,0x7654012d,0x00000000}},	//   _dúbi, nmka, _egzy, --, 
   {{0x80b8a782,0xddd802b1,0x836401d5,0x24080276}},	//   ्यसे, tatū, تگزل, ынди_, 
   {{0xfbd400eb,0x00000000,0x00000000,0x00000000}},	//   সৈকত, --, --, --, 
   {{0x63a001b9,0xddd85c07,0x68e4020c,0x7e7801e4}},	//   ston, ratū, _kokd, _revp, 
   {{0x63a0a7b7,0x68e40171,0x6514009f,0x00000000}},	//   pton, _jokd, _اورئ, --, 
   {{0x79940a07,0xddd804fe,0xa2e417a0,0x00000000}},	//   zuzw, patū, _лоад, --, 
   {{0x79940526,0x7e78047e,0xdb1c03e3,0x1fb4009d}},	//   yuzw, _qevp, _irqç, асүр, 
   {{0x6eec0077,0x7ae425c6,0x101001d5,0x7e78007c}},	//   _xúbi, _roht, قبید, _vevp, 
   {{0x7994a7b8,0xdd0400ac,0x7ae4014f,0x00000000}},	//   vuzw, _döşl, _soht, --, 
   {{0x7ae41978,0x799401f0,0x60c002d0,0x613c0036}},	//   _poht, wuzw, _iaom, gële, 
   {{0x60c0a7b9,0x6d44a7ba,0x2a7800e4,0x7994a7bb}},	//   _haom, amka, _cepb_, tuzw, 
   {{0x60c0a7bc,0xb6c801ed,0x68e4713c,0xd9180124}},	//   _kaom, یائے_, _bokd, гьа_, 
   {{0x79947f8b,0x6eec004e,0x7ae4014f,0xb0bc00cd}},	//   ruzw, _rúbi, _woht, ्ययग, 
   {{0x60c0a7bd,0x7ae401a2,0x6eec7d3d,0x19541669}},	// [d530] _maom, _toht, _súbi, рағы_, 
   {{0x7bcc05f5,0x60c0a7be,0x629c00cf,0x7c28012d}},	//   _irau, _laom, òpol, żers, 
   {{0x7bcc0008,0x69d8023a,0x68e48ecc,0x8af003b9}},	//   _hrau, ätet, _fokd, _muəl, 
   {{0x7bcca7bf,0x68e40432,0xa6c801a9,0x33d40150}},	//   _krau, _gokd, qlаn, жікт, 
   {{0x03a80372,0x31a0033f,0x93a4005b,0x65c000e4}},	//   مدوو_, wóz_, сшед, tãhá, 
   {{0x4b7c0a7c,0x776c056a,0xa2740063,0x00000000}},	//   נאוו, mpax, обљу_, --, 
   {{0x6aa809f0,0x60c0a7c0,0x9484010b,0x59240327}},	//   _öffe, _baom, _гызд, _རྩོས_, 
   {{0x6f64a7c1,0x60c037a8,0x7bcca09e,0x613c0af9}},	//   овиз, _caom, _orau, eëlb, 
   {{0x7bcc0190,0x60c00109,0x7b080122,0x8cd892c2}},	//   _nrau, _daom, ržuj, यासो, 
   {{0x776c056a,0xfe740166,0x00000000,0x00000000}},	//   ipax, пүш_, --, --, 
   {{0x7bcca7c2,0x60c0a343,0xf1580598,0xd84c0241}},	//   _arau, _faom, _тиеш_, _jọba_, 
   {{0x7bcca7c3,0x6d44058a,0x71400228,0x00000000}},	//   _brau, umka, _تۉبۅ, --, 
   {{0x00940323,0x7bcca7c4,0x5924025c,0x68e400e2}},	//   _хичэ, _crau, _རྩེས_, _rokd, 
   {{0x7bcca7c5,0x613c002e,0x2d940353,0x68e400a2}},	//   _drau, rële, _дрис, _sokd, 
   {{0x7bcc092e,0x60c0a7c6,0x68e401a9,0xb19801a8}},	//   _erau, _yaom, _pokd, óðhá, 
   {{0x7bcca7c7,0x6fcc190c,0x00000000,0x00000000}},	//   _frau, तिपू, --, --, 
   {{0x7bcc2af2,0xa6e40108,0x00000000,0x00000000}},	// [d540] _grau, ожал, --, --, 
   {{0xa6840046,0x69d8a7c8,0xe610a7c9,0x0df002d3}},	//   ілед, ätes, وشا_, ልጡፍ_, 
   {{0xe4580414,0xdcf800e2,0x68e4022e,0x66000115}},	//   аже_, lstā, _tokd, ĝoko, 
   {{0xa3d401ad,0x7ae001d3,0x2368041b,0x660001e4}},	//   िमल_, öltv, ајко_, ŝoko, 
   {{0x4420a7ca,0x60c0a7cb,0xd24c03e6,0xa3484758}},	//   çi_, _raom, ۆنه_, азда_, 
   {{0x60c0a7cc,0x2164036b,0xdcf8005f,0x6eec032e}},	//   _saom, отиг, istā, _kúbu, 
   {{0xd24c803c,0x60c0a7cd,0xa6c8022e,0x80b81810}},	//   ننه_, _paom, nlаm, ्यले, 
   {{0xdcf8005f,0x75800014,0xd4c400f1,0x00000000}},	//   kstā, _سیٖم, _وژنو_, --, 
   {{0xe298a7ce,0x60c0a7cf,0x00000000,0x00000000}},	//   _ваз_, _vaom, --, --, 
   {{0xd24c04a9,0x60c0a7d0,0x944001d9,0xeff00092}},	//   رچە_, _waom, _کھۅن, _ውግያ_, 
   {{0x9e0418ac,0x60c0a7d1,0xaadc190c,0x7bcc0006}},	//   ючил, _taom, मानक, _srau, 
   {{0x9b68006c,0xc0c4a7d2,0x00000000,0x00000000}},	//   ишга_, _хәки, --, --, 
   {{0xdcf800da,0xa3e800dc,0x7bdc0007,0x6f600220}},	//   gstā, महि_, uxsu, _كۇيم, 
   {{0x6eec0248,0x7bcc0076,0x00000000,0x00000000}},	//   _búbu, _vrau, --, --, 
   {{0x8d701e4a,0x8ae4177b,0x79840334,0x776c0113}},	//   _قايا, фіял, _qvhw, wpax, 
   {{0x7bcca7d3,0x9a700451,0x01bc00cc,0xd84c0241}},	//   _trau, _ڪندڙ, _অপাদ, _rọba_, 
   {{0x69d8a7d4,0x7d0ca7d5,0x37545f32,0xbb4c04ce}},	// [d550] äter, _imas, سپاس, _comチ_, 
   {{0x3f84a7d6,0xd6f800b5,0xb6c40137,0xd66800d8}},	//   ismu_, _sqア_, чөмд, рјал_, 
   {{0x776c0054,0x2ab80375,0x7d0c022e,0x67a00092}},	//   spax, _המתא, _kmas, _ውይይቱ_, 
   {{0x7d0c4e3d,0x776c002e,0xa3d400cd,0x3f8400c0}},	//   _jmas, ppax, िमं_, ksmu_, 
   {{0x7d0ca7d7,0x836405af,0x00000000,0x00000000}},	//   _mmas, ودول, --, --, 
   {{0x3948a7d8,0x7d0c07d6,0x3b100175,0xd84c01e1}},	//   lmas_, _lmas, nizq_, _tọba_, 
   {{0x7d0ca7d9,0xd49803b7,0x3f84005f,0xdcf8005f}},	//   _omas, _врз_, esmu_, zstā, 
   {{0x3948a7da,0x7d0c022e,0x6eec00ae,0xc88000a2}},	//   nmas_, _nmas, _lúbt, _üşti_, 
   {{0x3948005f,0xdcf80006,0x737400ec,0x01080137}},	//   imas_, lutė, _رٿائ, تتوو_, 
   {{0xb8fc0867,0x3948a7db,0xd3440133,0x6004a7dc}},	//   _ཡོ_, hmas_, _بیته_, яным_, 
   {{0xdcf802d5,0x8cd813da,0x09c004c5,0x1e80009d}},	//   nutė, यालो, _উপভা, элэм, 
   {{0x7d0c00a3,0xdcf8005f,0xf428031c,0x394801e4}},	//   _cmas, tstā, _སྙོད_, jmas_, 
   {{0x2fc8007b,0x2bb8007b,0x3948a7dd,0xfe7002f2}},	//   _éag_, حاجة_, dmas_, _ڤده_, 
   {{0x7d0ca7de,0xdcf8a7df,0x7a20063f,0x613c036e}},	//   _emas, rstā, _ịtal, mëla, 
   {{0xa9681d3e,0x9e78011a,0xff500133,0xdb0c00e5}},	//   сиба_, _הנצפ, _شخه_, óját, 
   {{0xdcf846e4,0x7d0c0254,0xa6c8022e,0xec780cb6}},	//   dutė, _gmas, rlаm, _упи_, 
   {{0x6d54a7e0,0xe61826f8,0x69d805ac,0xb4e4033f}},	// [d560] _iiya, әде_, åteb, _पकड़_, 
   {{0xaa44a7e1,0xf608021a,0xf4280003,0x39480006}},	//   _непл, ښتنه_, _སྙེད_, amas_, 
   {{0x6d54a7e2,0xb0bc243c,0x2d842d8b,0x3948a7e3}},	//   _kiya, ्याग, nsle_, bmas_, 
   {{0x6d54a7e4,0x39480561,0x7d0c0327,0x2d841cf8}},	//   _jiya, cmas_, _xmas, isle_, 
   {{0x59240ed9,0x6d54a7e5,0xc3304d2d,0x613c002e}},	//   _རྩིས_, _miya, نەر_, jëla, 
   {{0x2910a7e6,0x6d54a7e7,0x050c015b,0x27f001f4}},	//   liya_, _liya, ষকের_, myyn_, 
   {{0x6d540428,0xdcf80276,0x27f002f6,0xc1b80212}},	//   _oiya, nstă, lyyn_, ілих_, 
   {{0x2910a7e8,0x68f47aa6,0x04f805d9,0x2d840158}},	//   niya_, nkyd, _بورڊ_, dsle_, 
   {{0x7d0ca7e9,0x613c002e,0x00000000,0x00000000}},	//   _rmas, gëla, --, --, 
   {{0x2910a7ea,0x6d54a7eb,0x3948a7ec,0x442400db}},	//   hiya_, _aiya, zmas_, _ixm_, 
   {{0x6d54a7ed,0x2910a7ee,0x3948a7ef,0x3f840135}},	//   _biya, kiya_, ymas_, ssmu_, 
   {{0x6d54a7f0,0x2910a7f1,0xd6f804ce,0xa0a4a7f2}},	//   _ciya, jiya_, _jpゲ_, _хадд, 
   {{0x6d54a7f3,0x2910a7f4,0x9db4031c,0x7d0ca7ab}},	//   _diya, diya_, ནསྤེ, _vmas, 
   {{0x6d540086,0x4e9002dd,0x291ca7f5,0x3db400fe}},	//   _eiya, _كشىر, étan_, টিবল, 
   {{0x6d54a7f6,0x29103142,0xca2468d9,0x7d0c01a9}},	//   _fiya, fiya_, ефти, _tmas, 
   {{0x2910a7f7,0x3948a7f8,0x6d54a7f9,0xce340375}},	//   giya_, umas_, _giya, _מאות_, 
   {{0xb8e40412,0x7cec002d,0xade401ed,0xd83801c6}},	// [d570] _एस_, _wûrs, _فہیم_, сэв_, 
   {{0xbbc811b1,0x4b7c0375,0xaadc143b,0x473400f3}},	//   िटीक, _האזו, माणक, енус, 
   {{0x2910a7fa,0x7d1ca7fb,0x6d54a7fc,0x39481eca}},	//   biya_, onss, _yiya, pmas_, 
   {{0x7d1ca7fd,0x2910a7fe,0x741402e9,0xdcf80024}},	//   nnss, ciya_, وواا, rutė, 
   {{0x7d1c0008,0xdcf80024,0x613c002e,0x8cd4134e}},	//   inss, sutė, xëla, _बोफो, 
   {{0x2d8401f1,0x7d1ca7ff,0x78ac00df,0x6eec0332}},	//   ysle_, hnss, lfav, _lúbr, 
   {{0x82840f1b,0x74f80d6f,0x4424022e,0xa2ac012d}},	//   رجول, _девр_, _exm_, ूज़्, 
   {{0x78ac04cc,0x7d1c01f5,0x0fe40075,0x00000000}},	//   nfav, jnss, злиқ_, --, 
   {{0x6d54a800,0x6f1ca801,0x78ac009a,0xd6f800b5}},	//   _riya, ésco, ifav, _upコ_, 
   {{0x7d1c38e1,0x01bc00eb,0x00000000,0x00000000}},	//   enss, _অপরদ, --, --, 
   {{0x6d54a802,0x11287724,0x3218129e,0x613c00e8}},	//   _piya, _люди_, _بياد_, sëla, 
   {{0x2910a803,0x6d54a804,0x2d84a805,0x6eec04d4}},	//   xiya_, _qiya, rsle_, _cúbr, 
   {{0x6d54016d,0x78ac030d,0x2910a806,0x6eec0030}},	//   _viya, dfav, viya_, _dúbr, 
   {{0x2910a807,0x6d54a808,0x2fcc05ac,0x27f0005b}},	//   wiya_, _wiya, mveg_, vyyn_, 
   {{0x6d54a809,0x78aca80a,0x2fcca669,0x5924031c}},	//   _tiya, ffav, lveg_, _རྩངས_, 
   {{0xd7d800b5,0xd94049f3,0x27f00108,0x00000000}},	//   _kgト_, веси, tyyn_, --, 
   {{0x2910a80b,0x2fcc0489,0xfca8352e,0xe7682d4b}},	// [d580] riya_, nveg_, _رايو_, تحزن_, 
   {{0x2910a80c,0x68f4a80d,0x27f001f4,0x00000000}},	//   siya_, skyd, ryyn_, --, 
   {{0x2910a80e,0x569002bf,0xe99001ec,0x27f00108}},	//   piya_, таєт, _جۇزگ, syyn_, 
   {{0xa02000a2,0xa3e877ca,0x2910a80f,0x00000000}},	//   _ýögs, महल_, qiya_, --, 
   {{0x69cc08cb,0xa3b80137,0x9f50012c,0x439469d8}},	//   lvbe, تاار_, ždém_, халс, 
   {{0x442404cc,0x2fcc05ac,0x20c8035b,0x00000000}},	//   _vxm_, dveg_, _ỹi_, --, 
   {{0xbebc00da,0x81e40eac,0x7d1c143a,0x64a40022}},	//   lnīg, _পেজ_, ynss, _ҭаҳа, 
   {{0x656c02d0,0x93c80014,0xd84c01e1,0x66800066}},	//   _itbh, _ژالہ_, _mọna_, _سیچل, 
   {{0x6eec09a9,0x2fcc017a,0xd84c0248,0x7d1c1924}},	//   _rúbr, gveg_, _lọna_, vnss, 
   {{0xf4280327,0x6f000175,0x7d1c02d0,0x7b080064}},	//   _སྙིད_, ghlc, wnss, nžut, 
   {{0xd12ca810,0x3afc0241,0xbe380395,0x00000000}},	//   _ах_, _nìpa_, язох_, --, 
   {{0x656c00b5,0x8d70004b,0x7d1c04e6,0x291c0129}},	//   _mtbh, کایا, unss, étal_, 
   {{0x7d1c3720,0x92b00183,0x201800ae,0x00000000}},	//   rnss, য়াৰ_, _بتاع_, --, 
   {{0xa3b400e1,0x73f8008f,0xbebc00ef,0x00000000}},	//   _जहन_, פּרו, dnīg, --, 
   {{0x98c47041,0xc98421fa,0xbebc00e2,0x00000000}},	//   мсал, кути, enīg, --, 
   {{0x6aa80639,0x7f58014f,0x00000000,0x00000000}},	//   _öffn, _hivq, --, --, 
   {{0x78aca811,0xcd341ec7,0x96d805f9,0x36d447f9}},	// [d590] rfav, _جروب, नालॉ, ноар, 
   {{0x613c2568,0x00000000,0x00000000,0x00000000}},	//   këlo, --, --, --, 
   {{0x78ac006f,0x613c002e,0x2cb00142,0xc6a402e8}},	//   pfav, jëlo, _ybyd_, ърти, 
   {{0xa3e800cd,0x65680332,0x00000000,0x00000000}},	//   महं_, ífha, --, --, 
   {{0xefdc02d3,0xc7c4014b,0x00000000,0x00000000}},	//   _ኔርዎ_, _исри, --, --, 
   {{0x3958a812,0x3244547c,0x7f58014f,0x1cdc031c}},	//   _hiss_, нелг, _nivq, _ལོའ_, 
   {{0x39582517,0x613c0023,0xb4940063,0x00000000}},	//   _kiss_, gëlo, _пивљ, --, 
   {{0x3958003e,0xa1540063,0x2fcc0156,0xe274004e}},	//   _jiss_, нају_, tveg_, _үктө, 
   {{0xbea000c6,0x3958a813,0x613ca814,0x00000000}},	//   _нзᴚз_, _miss_, mëll, --, 
   {{0x3958a815,0xaec401c0,0x2fcca816,0x69cc01d3}},	//   _liss_, хбол, rveg_, yvbe, 
   {{0x2fcca817,0xee38a818,0x3cec022e,0x00000000}},	//   sveg_, яно_, аev_, --, 
   {{0x3958a819,0x61441b56,0xcfb40154,0x00000000}},	//   _niss_, _كىلە, জিবন, --, 
   {{0xc0e81291,0xd84c0241,0x7b8001ec,0x4084014b}},	//   _تفنن_, _sọna_, ағыд, _рухб, 
   {{0x39580204,0x613c0221,0x00000000,0x00000000}},	//   _aiss_, hëll, --, --, 
   {{0x39581f21,0x613c0023,0x00000000,0x00000000}},	//   _biss_, këll, --, --, 
   {{0x1cdc08ea,0x3958a81a,0xdca001f0,0x00000000}},	//   _ལོར_, _ciss_, _баъи, --, 
   {{0x993054f6,0x613c01c7,0x7f58014f,0xa694a81b}},	// [d5a0] افقت, dëll, _yivq, ереј, 
   {{0xddd81ebd,0xf1c407ae,0xebec00b5,0xe7380108}},	//   latš, _đáng_, _iｸ_, чез_, 
   {{0x3958a81c,0x613c0221,0xbbe843fb,0x58400131}},	//   _fiss_, fëll, _فریم_, پپەق, 
   {{0x3868a81d,0x395800e8,0x63840108,0x3c440064}},	//   ccar_, _giss_, егда, būvį_, 
   {{0x42c800c7,0xa38400b8,0x00000000,0x00000000}},	//   мҳан_, daõó, --, --, 
   {{0xdecca81e,0x62641a59,0xddd802fb,0x69c803b2}},	//   ባትን_, راتق, hatš, _áfes, 
   {{0xddd8000a,0x26c80083,0xd0580198,0x7d1c1d55}},	//   katš, _iabo_, nkuɗ, érsk, 
   {{0x26c80184,0x77680798,0x7f580477,0x613c002e}},	//   _habo_, _éexc, _sivq, rëlo, 
   {{0x7f58014f,0x8cc4033f,0x2d900118,0xe29801c4}},	//   _pivq, िजनो, ázen_, _наа_, 
   {{0x248405da,0x7f580455,0x26c8a81f,0xdd8c0131}},	//   laom_, _qivq, _jabo_, مۈت_, 
   {{0xddd87483,0x26c8a820,0x38680998,0xd12c0014}},	//   fatš, _mabo_, ycar_, _گۅٹ_, 
   {{0x26c8a821,0xddd81ebd,0x7f580455,0x8cd84d21}},	//   _labo_, gatš, _wivq, यागो, 
   {{0xd12ca822,0x7b0801fa,0x69d8a823,0xdef800fd}},	//   _امن_, džur, åten, _нык_, 
   {{0xd84c413b,0x2b58017a,0x613c036e,0x69d80115}},	//   _dọla_, _cipc_, zëll, ĥten, 
   {{0xddd80f8b,0x2484a824,0x39580f85,0x613c002e}},	//   batš, kaom_, _piss_, yëll, 
   {{0x26c8a825,0x1b006768,0x3868067c,0xfe780153}},	//   _aabo_, түүн, ucar_, lbį_, 
   {{0x3868a826,0x98140502,0x3958a827,0x613c0200}},	// [d5b0] rcar_, ربرا, _viss_, vëll, 
   {{0x3958a828,0xbebc00da,0x613c0221,0xab600205}},	//   _wiss_, lnīb, wëll, şüce, 
   {{0x26c8a829,0x3958a82a,0xaadc590f,0x613ca82b}},	//   _dabo_, _tiss_, मारक, tëll, 
   {{0x1cdc0003,0x39580493,0xb7d802dd,0x349401f0}},	//   _ལོས_, _uiss_, _قوجا_, тадр, 
   {{0xd8380323,0x26c8a82c,0x613c0036,0x8504178c}},	//   _хэн_, _fabo_, rëll, دونن, 
   {{0x26c8a82d,0x00000000,0x00000000,0x00000000}},	//   _gabo_, --, --, --, 
   {{0x45d436e1,0x74c400c7,0xa28012ea,0xa2c00ce8}},	//   _йорс, _ишаҧ, شینو, шәтк, 
   {{0x26c8a82e,0x1474a82f,0x613c036e,0x70bc01f9}},	//   _zabo_, _سارج, qëll, ्येल, 
   {{0xb35421b5,0x9c10063f,0xd2580276,0x9f8029a3}},	//   _акаш, họba, _еце_, агыд, 
   {{0x9c1001f2,0x26c8058a,0xbebc00de,0x00000000}},	//   kọba, _xabo_, enīb, --, 
   {{0x291c0214,0xed4400f5,0xcca814fb,0x00000000}},	//   étak_, кноп, ىندۇ_, --, 
   {{0x30140139,0x2b58045a,0xa6c8022e,0x00000000}},	//   _идер, _sipc_, llаt, --, 
   {{0x2b580618,0xddd802fb,0xdcf8002d,0xaadc278e}},	//   _pipc_, ratš, nstę, मालक, 
   {{0xdbcc0022,0x26100037,0x00000000,0x00000000}},	//   _añór, _धइली_, --, --, 
   {{0xddd8000a,0x26c8a830,0x00000000,0x00000000}},	//   patš, _rabo_, --, --, 
   {{0x26c8a831,0x2b58005a,0x6d54067c,0xa6c8022e}},	//   _sabo_, _wipc_, ïzad, hlаt, 
   {{0x248406d9,0xf7e80131,0xa6c8022e,0xebe401d5}},	// [d5c0] vaom_, ىركى_, klаt, _ропп, 
   {{0x952c0003,0x26c80050,0xbebc00da,0xe9d80276}},	//   ྨོའི_, _qabo_, mnīc, _жко_, 
   {{0xd6cca832,0x3568005e,0x248405da,0x692473b3}},	//   تقل_, ерін_, taom_, _амна, 
   {{0x70bc227c,0x00000000,0x00000000,0x00000000}},	//   ्योल, --, --, --, 
   {{0x26c8a833,0x29000c3a,0x8bf402f5,0x248403d1}},	//   _tabo_, _ilka_, _চেতন_, raom_, 
   {{0x93407208,0x776800d8,0xcc701870,0x00000000}},	//   анче, _éexa, _ﺳﯩﺰﮔ, --, 
   {{0x55e0a834,0x95d4023a,0x2d900118,0x00000000}},	//   _корб, _идёт_, ázel_, --, 
   {{0xe4d8006c,0x38ac002e,0xe3b80395,0x00000000}},	//   _تورت_, móró_, _обб_, --, 
   {{0xd0480296,0xbebc005f,0xbf3402e8,0xdb0c013a}},	//   _ingɛ, jnīc, лнищ, _ždím, 
   {{0x225c01c4,0x629c056a,0xb2c4805c,0xa6c801a9}},	//   _ugtk_, ópod, _مغمو, mlаs, 
   {{0x2900a835,0x69d82b27,0xbebc1c52,0x7b080427}},	//   _olka_, åtel, tnīb, džup, 
   {{0xa3b41e61,0x91800075,0x3b000204,0x00000000}},	//   _जहा_, _ئۇيۇ, _slhq_, --, 
   {{0x5f041e80,0x21240c6a,0x7f9401c0,0xbebc005f}},	//   _изда, _ijoh_, _салх, rnīb, 
   {{0xbebc00e2,0xfb34009d,0x7c2800b8,0x00000000}},	//   snīb, унгэ, _āmrā, --, 
   {{0xd90c3faa,0xa6c801a9,0xdcf8012d,0x4cb00154}},	//   قید_, hlаs, zstę, য়াজু, 
   {{0xd7f8066f,0xa6c8022e,0x9ba000d1,0x090400db}},	//   муз_, klаs, _پەسى, ачум, 
   {{0x21240036,0x5b240354,0xda780150,0x00000000}},	// [d5d0] _mjoh_, _аьна, _оян_, --, 
   {{0x9c10063f,0x96b80691,0xbaa4023b,0xa6c8022e}},	//   pọba, بارز_, _суиқ, dlаs, 
   {{0x6f1c00d8,0xa6c801d5,0x30e400cd,0xf4900240}},	//   ésci, vlаt, कामः_, _ከምልጥ_, 
   {{0x769801e1,0x212402d3,0x2d80062c,0x00000000}},	//   _bùyà, _njoh_, _çhee_, --, 
   {{0x289805e1,0xd3a4a836,0x03a819e2,0x22900131}},	//   _אירא, треп, ندوو_, ڭلىس, 
   {{0xd5b80104,0x00000000,0x00000000,0x00000000}},	//   _осб_, --, --, --, 
   {{0xbebc00da,0x2d980165,0x28a808df,0xb3780023}},	//   znīc, ńsez_, ङ्कि, ርእዮን_, 
   {{0xefc80d08,0x44f415d4,0x00000000,0x00000000}},	//   елил_, _кпсс, --, --, 
   {{0x2f547c3f,0xa1540063,0xa6c801d5,0x70bc00bc}},	//   лтос, ћању_, mlаr, ्यौल, 
   {{0xa6c801d5,0x00000000,0x00000000,0x00000000}},	//   llаr, --, --, --, 
   {{0x6ad00c58,0xe8180037,0x00000000,0x00000000}},	//   _সকলো, _नेना_, --, --, 
   {{0xeb98a837,0xdee0020a,0xa6c801b9,0x00000000}},	//   ним_, _ҳоши, nlаr, --, 
   {{0xe0cc01d9,0x00000000,0x00000000,0x00000000}},	//   _رٲو_, --, --, --, 
   {{0x6da4a838,0xa9a4a839,0x6e9400c6,0x63a403cd}},	//   _бика, лигд, _إلغا, _åkne, 
   {{0xbebc00da,0x24580166,0xa6c801d5,0x00000000}},	//   snīc, _kümü_, klаr, --, 
   {{0xbebc005f,0x613c0221,0xa6c801a9,0x00000000}},	//   pnīc, vëlk, ylаs, --, 
   {{0xd9407843,0x2d80062c,0x28a816d1,0x29000306}},	// [d5e0] сети, _çheb_, ङ्गि, _vlka_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x5924031c,0x5ef8008f,0xa6c8022e,0x58400116}},	//   _རྩམས_, עפעד, flаr, لپېق, 
   {{0xa6c801a9,0xdcf801ef,0x00000000,0x00000000}},	//   glаr, dstě, --, --, 
   {{0x82840131,0x613c002e,0x00000000,0x00000000}},	//   иқад, sëlk, --, --, 
   {{0x31640356,0x16840133,0xfbd400cd,0xa6c854a0}},	//   _bulz_, _مافێ, दितम, _ялга_, 
   {{0xa6c8022e,0x31844c17,0x56540153,0x6d440055}},	//   blаr, атың, _баёў_, _īhan, 
   {{0x6d441d76,0x13e40032,0x24540014,0x49240023}},	//   _ūhan, тмәй_, _منزس, _ተለቪዥ, 
   {{0xb2440032,0xa6c801d5,0xcf84009d,0x4ad40825}},	//   лмәһ, qlаs, лсэд_, दयाव, 
   {{0x63a0a83a,0xd24c0502,0x3f145169,0x69d80115}},	//   muon, _کنم_, рдос, ĥtej, 
   {{0x6288a83b,0x63a0a83c,0x6fc4031c,0xf1a8a83d}},	//   mafo, luon, _ཀརྨའ, _لانه_, 
   {{0x62882f06,0x63a001f7,0x613c036e,0x00000000}},	//   lafo, ouon, këli, --, 
   {{0xab60a83e,0x8ff4591a,0x00000000,0x00000000}},	//   şüne, _مرور_, --, --, 
   {{0x6288a83f,0xd7f80588,0xab6003b9,0xa6c801a9}},	//   nafo, ҭуа_, _şüca, zlаr, 
   {{0x63a0a840,0xa8000ac1,0x6d54067c,0x9dbc0327}},	//   huon, çınd, ïzac, _མགྲེ, 
   {{0x63a0a841,0x6288a842,0xb8084832,0xd7e402bf}},	//   kuon, hafo, نيزم_, лізо, 
   {{0x6288a843,0x613c0240,0x63a00108,0xa6c801a9}},	// [d5f0] kafo, gëli, juon, vlаr, 
   {{0x63a0a844,0x628801b8,0x80cc0073,0x00000000}},	//   duon, jafo, _दोघे, --, 
   {{0x6288a845,0xa6c801b9,0xd5b80024,0x00000000}},	//   dafo, tlаr, эса_, --, 
   {{0x297825f9,0x486400a7,0x63a007c5,0xf3f81cc9}},	//   _שטרא, _гърб, fuon, кнеш_, 
   {{0xdfc4501f,0x63a0a846,0x62880109,0xd2b402dd}},	//   _بي_, guon, fafo, лқаш_, 
   {{0xdd84a847,0xa3b40c2e,0xe294a848,0x7c2c031c}},	//   _وو_, _जहर_, ааш_, _mxar, 
   {{0xf07400dd,0xa6c8022e,0x00000000,0x00000000}},	//   لیاں_, plаr, --, --, 
   {{0x63a0a849,0xa6c801d5,0x00000000,0x00000000}},	//   buon, qlаr, --, --, 
   {{0x6288013e,0x7528401f,0xaf043e07,0x63a0004d}},	//   bafo, _ijez, ипил, cuon, 
   {{0x5184a84a,0x628800db,0xa56000cf,0x69d805ac}},	//   _буда, cafo, _اگەن, åtek, 
   {{0x245805d1,0x4174009f,0x7c2ca84b,0x6d24011c}},	//   _tümü_, _هانس, _axar, идоз, 
   {{0x7c2c025c,0x75280083,0x690800a2,0x3d1000bc}},	//   _bxar, _jjez, _iýeg, दोले_, 
   {{0x6e2c0a28,0x00000000,0x00000000,0x00000000}},	//   _śabd, --, --, --, 
   {{0x7ff416ac,0xad2400db,0x00000000,0x00000000}},	//   _دسما, اىڭى, --, --, 
   {{0xada40323,0x7c2c16b8,0x7528014b,0x63a001c8}},	//   _тайл, _exar, _ojez, zuon, 
   {{0x75283879,0x92b000bd,0x613c02d3,0x7c2c010a}},	//   _njez, য়ায়_, tëli, _fxar, 
   {{0x6674a84c,0xa684a84d,0x6288014b,0xe7388ab1}},	// [d600] لدار, илад, yafo, веа_, 
   {{0x7528a84e,0x63a0a84f,0x628800db,0x613c1bce}},	//   _ajez, vuon, xafo, rëli, 
   {{0x63a00161,0x75281710,0x09c00eac,0x613c0240}},	//   wuon, _bjez, _উপকা, sëli, 
   {{0x63a0a850,0x6288a851,0xeab001d3,0xf6544d56}},	//   tuon, wafo, _اٹھ_, стую, 
   {{0x75280221,0x377400ee,0x7c2c0327,0x00000000}},	//   _djez, _гысс, _xxar, --, 
   {{0x63a0a852,0x75282572,0x62880421,0x00000000}},	//   ruon, _ejez, uafo, --, 
   {{0xe81819e5,0x63a0a853,0x9e6402f2,0x00000000}},	//   _नेता_, suon, یادن, --, 
   {{0x6288a854,0xc3c4010b,0x63a0a855,0x75280200}},	//   safo, _гөкл, puon, _gjez, 
   {{0x93c81973,0x3f140131,0x63a0387a,0x00000000}},	//   _لالہ_, йдис, quon, --, 
   {{0x1cdc0867,0x3eb809f3,0x00000000,0x00000000}},	//   _ལོང_, ýrt_, --, --, 
   {{0xb6d800c8,0xb0b8031c,0xc0e40023,0xea8801ec}},	//   אַרט, _དིཝེ, ምሳል_, _ﺑﯘﺯﯞ, 
   {{0xfcc4a856,0x00000000,0x00000000,0x00000000}},	//   сәкм, --, --, --, 
   {{0xb0740184,0x00000000,0x00000000,0x00000000}},	//   _уҡыу_, --, --, --, 
   {{0x4e1404fb,0x9e646caa,0x00000000,0x00000000}},	//   اتید_, _ئاشن, --, --, 
   {{0x76b8a857,0x59640395,0x00000000,0x00000000}},	//   һлар_, ръга, --, --, 
   {{0x8d70a858,0x7c2c05f5,0x4d703267,0x8ee400d1}},	//   _باوا, _txar, _بطور, _مېۋە_, 
   {{0x7c2c005a,0x81bc0eac,0x00000000,0x00000000}},	// [d610] _uxar, ইটি_, --, --, 
   {{0x7d1ca859,0x752800bc,0x6b80062d,0x8d7c0092}},	//   liss, _sjez, _çoga, _የሰብል_, 
   {{0x35b4a85a,0x7d1c023a,0x7bcc00d8,0x75280064}},	//   сбер, oiss, _hsau, _pjez, 
   {{0x7d1ca85b,0x3954a85c,0x98485d4e,0x291c0098}},	//   niss, çası_, _аяга_, état_, 
   {{0xd4083009,0x7528a85d,0x842408b0,0x9acc00b8}},	//   ختام_, _vjez, يىمن, _śoṇā, 
   {{0x7d1ca85e,0x7bcc0161,0x690800ee,0x6d440055}},	//   hiss, _msau, _eýed, _īham, 
   {{0x7d1ca85f,0x81a81564,0xdee01772,0x32000122}},	//   kiss, لطيف_, ምናን_, áhy_, 
   {{0x7bcc02ce,0x7d1ca860,0x75280117,0x0584a861}},	//   _osau, jiss, _ujez, _фурм, 
   {{0x7d1ca862,0x2e68a863,0xdfcca864,0x00000000}},	//   diss, липп_, فيي_, --, 
   {{0xaf0478cd,0xd20008c9,0x7d1ca865,0x2ed000dc}},	//   спол, _мүлк, eiss, तयेत, 
   {{0x7d1ca866,0xed5895de,0x7bcca867,0x2d900216}},	//   fiss, лоо_, _asau, éze_, 
   {{0xada4052f,0x7d1ca868,0xccf82fab,0x2d98a869}},	//   _ғаил, giss, рқи_, čse_, 
   {{0x8fc41f84,0xe8f80e46,0x613ca86a,0x7d1c1f3f}},	//   _خزان, қла_, gëlu, èrsa, 
   {{0x4dcc00cc,0x7d1c01f4,0xa8000205,0x00000000}},	//   িমবং, aiss, çımd, --, 
   {{0x7d1ca86b,0x7bcca86c,0x48c40032,0x8cc80354}},	//   biss, _esau, оҙна, _кĕвĕ_, 
   {{0x7d1ca86d,0x3cf00030,0xad240220,0x966801e1}},	//   ciss, ľová_, _دىبى, _è̟jé, 
   {{0x3cf00232,0x00000000,0x00000000,0x00000000}},	// [d620] žová_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x798403ac,0x291c0687,0x61e802d0,0x00000000}},	//   _gwhw, étas_, xxfl, --, 
   {{0xe7680cd2,0x64a4a86e,0x00000000,0x00000000}},	//   _محسن_, сада, --, --, 
   {{0x86b40220,0x81bc0f22,0x19540375,0x4394009d}},	//   _мәжі, ইয়া_, _לבטל_, цалс, 
   {{0x7d1ca86f,0xf3641ac3,0x613c01c7,0x81bc0154}},	//   ziss, ітін, hëlt, ইটস_, 
   {{0x7d1ca870,0x66dc013d,0x00000000,0x00000000}},	//   yiss, _eçkä, --, --, 
   {{0x7d1ca871,0x1fa429e4,0x00000000,0x00000000}},	//   xiss, брог, --, --, 
   {{0x7d1ca872,0x2000a873,0x9cc80150,0x00000000}},	//   viss, áki_, қына_, --, 
   {{0xc0d0067d,0x7d1ca874,0x613c0af9,0x00000000}},	//   _እዮም_, wiss, eëlt, --, 
   {{0x2000a875,0x7d1ca876,0x30e400dc,0x00000000}},	//   ški_, tiss, काशः_, --, 
   {{0xa068a877,0x7d1ca878,0x7bcc06af,0x613c0036}},	//   _сада_, uiss, _psau, gëlt, 
   {{0x30e400dc,0xe044267c,0x10a001c6,0x00000000}},	//   कारः_, _унди, _хичн, --, 
   {{0x7d1ca879,0x5b2412c4,0x05c807af,0x614415bf}},	//   siss, сьма, रबाब, _ئىچە, 
   {{0x7d1ca87a,0x613ca87b,0x00000000,0x00000000}},	//   piss, sëlu, --, --, 
   {{0x7bcca87c,0x7d1ca87d,0xe8184da4,0x78780209}},	//   _tsau, qiss, _नेहा_, рйар_, 
   {{0x7bcca87e,0x588401ec,0x00000000,0x00000000}},	// [d630] _usau, _қына, --, --, 
   {{0x776c022e,0x88580139,0x00000000,0x00000000}},	//   rqax, сиус_, --, --, 
   {{0x9474a87f,0x057400d1,0xdcf82737,0x4d7800df}},	//   مدشا, كاند, lttı, ָרדע, 
   {{0x73d8a880,0x6d4402b1,0x09c0009e,0xe81800bc}},	//   идер_, _īhak, _উপচা, _नेवा_, 
   {{0xd7f80116,0x75380810,0xd3441272,0x020401ec}},	//   _сун_, rowz, میره_, үзін, 
   {{0x6aa8002f,0xb5c800db,0x95740092,0x00000000}},	//   _öfft, _پورم_, ርጅቱን_, --, 
   {{0x8afc008f,0x613c002e,0xb9e01954,0x00000000}},	//   רהוי, yëlt, _እኰ_, --, 
   {{0x1fd00154,0x61fc5f03,0x00000000,0x00000000}},	//   ়মনস, øpla, --, --, 
   {{0xa11000db,0x93400e56,0x8cbc00bc,0x00000000}},	//   بويت, _فىرۇ, ष्फो, --, 
   {{0xef18a881,0x63e40150,0xbebc00e2,0xdf34007b}},	//   рмо_, _بيكە, lnīj, يكيت_, 
   {{0x6b50019b,0xace8a882,0x6cc4a883,0x6f00324c}},	//   lægg, амна_, ойна, rklc, 
   {{0x9c1001f2,0x40940116,0x7ae4a884,0x00000000}},	//   pọla, _ершт, _anht, --, 
   {{0x80d400db,0x00000000,0x00000000,0x00000000}},	//   _رموچ, --, --, --, 
   {{0x6a8400f7,0x613c0023,0x00000000,0x00000000}},	//   юлга, bëls, --, --, 
   {{0x2fdc0109,0xdcf80205,0x00000000,0x00000000}},	//   _hrwg_, attı, --, --, 
   {{0x2fdc003e,0x1864a885,0x6b5001bf,0x9d1400d8}},	//   _krwg_, жати_, kægg, _мојт_, 
   {{0xdee00023,0x6d44022e,0x0cb80118,0x00000000}},	// [d640] ምዓኒ_, mlka, ेजीम, --, 
   {{0x6d44a886,0x6b5001bf,0xb8d0012d,0x00000000}},	//   llka, dægg, _ऑफ़_, --, 
   {{0xe6182850,0xa968026a,0xdd10036b,0x6d44a887}},	//   јде_, _њима_, _رویخ, olka, 
   {{0x69dca888,0x1cdc031c,0xec34008f,0xa444119e}},	//   _irpe, _ལོབ_, ֿאַר_, онед, 
   {{0x6d44a889,0x69dc1dd5,0x68e40857,0x8cbc1684}},	//   ilka, _hrpe, _inkd, ष्यो, 
   {{0x69dc0552,0x6d44a88a,0x41840116,0xdee00023}},	//   _krpe, hlka, птиғ, ምዓና_, 
   {{0xaab01092,0x91e00063,0xeca8012d,0xc4340244}},	//   _जानक, доје, _कांफ, _ککات, 
   {{0xa2b803f3,0x69dc0221,0xa49001f7,0x00000000}},	//   _शॉर्, _mrpe, _آڏاڻ, --, 
   {{0x6d440009,0xdec40063,0xaac80b4c,0x2bdc00bc}},	//   dlka, ољно, ाजाक, मिफा, 
   {{0x6d4435ec,0x63a001a9,0x69dca88b,0x2bdca88c}},	//   elka, mron, _orpe, मिना, 
   {{0x1cdc31d9,0xb8fc081f,0x63a0017a,0x6b9402d0}},	//   _ལོད_, _རྣ_, lron, _avyg, 
   {{0x672c0036,0x63a0a88d,0x6abc002f,0x00000000}},	//   _ljbj, oron, _abpf, --, 
   {{0x69dca88e,0x9f440730,0x82c8031c,0x69d801bf}},	//   _arpe, _groß_, _གྲོའ, æten, 
   {{0x63a0a88f,0x6d44a890,0xdcf8247e,0x776800d8}},	//   iron, alka, rttı, _éexi, 
   {{0x63a0a891,0x69dc00f3,0x2d9000bc,0xdd0400ac}},	//   hron, _crpe, ázet_, şqır, 
   {{0x8d18a892,0x6b940175,0xb78801e0,0xdc3c02f0}},	//   _وزير_, _fvyg, йәге_, líčo, 
   {{0x63a0a893,0x69dca894,0x6298a895,0xda641b45}},	// [d650] jron, _erpe, _odto, _وادي, 
   {{0x629ca896,0x9c1002e3,0x1954054a,0x6b5000b5}},	//   ópol, họka, сағы_, vægg, 
   {{0x63a0a897,0x9c10a898,0x80bc05d7,0x46ac2052}},	//   eron, kọka, ्जाइ, _चारह, 
   {{0x62980ecf,0x613c02d3,0x6b940124,0x33d401ec}},	//   _adto, këlq, _yvyg, зікт, 
   {{0x63a0a899,0x2bdc1414,0x00000000,0x00000000}},	//   gron, मिया, --, --, 
   {{0x78ac00da,0x4b7c0a7c,0x6b5001bf,0xdc3c0419}},	//   lgav, סאוו, rægg, jíčo, 
   {{0x63a0a89a,0x6d44a89b,0x79940112,0x136400ec}},	//   aron, ylka, nszw, _ڀائٽ, 
   {{0x629802d0,0x2bdc00cd,0xee3800c7,0x00000000}},	//   _edto, मिमा, ҩни_, --, 
   {{0x6b50037e,0xef18a89c,0x78ac0194,0x00000000}},	//   læge, йми_, igav, --, 
   {{0x59c800bc,0xdcf800e2,0x6d440067,0x00000000}},	//   ाबार, kstē, wlka, --, 
   {{0x6d4401af,0x62e80050,0xa6c8022e,0x00000000}},	//   tlka, _دِلہ_, moаt, --, 
   {{0xefdc001f,0x78ac01f5,0xddd80064,0xeab000e5}},	//   ንሲው_, jgav, batž, کٹس_, 
   {{0x6d44a89d,0x69dc012c,0x78aca89e,0xafe4a89f}},	//   rlka, _srpe, dgav, _холл, 
   {{0x78aca8a0,0x2fcc1543,0x69dca8a1,0xbf400022}},	//   egav, mweg_, _prpe, _иҭыл, 
   {{0x2fcc93d6,0xed5800a8,0x6b501cf3,0x1ee401d3}},	//   lweg_, _лок_, jæge, _روٹی_, 
   {{0x78aca8a2,0x63a0a8a3,0xac841a71,0x7de4009f}},	//   ggav, yron, _эгил, _آسوم, 
   {{0x2fcca8a4,0x8cbc00dc,0x5ecc0154,0x6fbc0118}},	// [d660] nweg_, ष्णो, ়ারে, ्बिं, 
   {{0x63a04345,0x78aca8a5,0x00000000,0x00000000}},	//   vron, agav, --, --, 
   {{0x69dc30ab,0x2fcc0e78,0x629c0077,0x657c1d0e}},	//   _urpe, hweg_, ópom, upph, 
   {{0x63a0a8a6,0x2fcc01a4,0xaa440014,0xd5ac4e77}},	//   tron, kweg_, _ونکى, طفه_, 
   {{0x82c80135,0x2fcc01f5,0xaa8400a2,0x7198001f}},	//   _གྲུའ, jweg_, _gyýç, _ፅህፈት_, 
   {{0xb3e83adf,0x2fcca8a7,0x6b5000b5,0x53a000d1}},	//   تعمل_, dweg_, bæge, رمىك, 
   {{0xd24c1129,0x63a001a9,0x2fcc77d0,0x1a98010f}},	//   هنه_, sron, eweg_, ציקע, 
   {{0x673ca8a8,0x2fcc057b,0x656c0afe,0x1fa4050b}},	//   lopj, fweg_, _iubh, прог, 
   {{0x2fcc1a7c,0x673c000f,0xd24c00d1,0xd0940137}},	//   gweg_, oopj, پچە_, سئيا_, 
   {{0x656ca8a9,0x62980589,0x673c01f5,0xd24c00e5}},	//   _kubh, _udto, nopj, ئچے_, 
   {{0x127800c8,0x9c1001f2,0xb5dc00a2,0x5ecc0154}},	//   _האבע, pọka, _öýtý, ়ালে, 
   {{0x656c0e8a,0x2fcc030a,0x673c01f5,0x613c0240}},	//   _mubh, bweg_, hopj, pëlq, 
   {{0x656ca8aa,0xe04425a1,0xdee41ee3,0x673ca8ab}},	//   _lubh, _энди, _ноди, kopj, 
   {{0x1cdc025c,0xaab00073,0x98b0008e,0x673ca8ac}},	//   _ལོམ_, _जाणक, _ruxı_, jopj, 
   {{0xceb00bd9,0x78aca8ad,0x656c00cd,0x4a541d39}},	//   _ניק_, tgav, _nubh, екрс, 
   {{0x6b5004ce,0x8e440597,0x78ac7a23,0x8af006be}},	//   væge, _عليك_, ugav, _muəy, 
   {{0x78aca8ae,0x7d0c20ac,0x69d80267,0x36d428a8}},	// [d670] rgav, _ilas, åter, моар, 
   {{0x3ce80070,0x78aca8af,0x656ca8b0,0x00000000}},	//   _hnav_, sgav, _bubh, --, 
   {{0x7d0ca8b1,0x78aca8b2,0x8afc0302,0xb954664d}},	//   _klas, pgav, _להזי, _овощ, 
   {{0xe8e45a4f,0x656ca537,0xed9402d3,0x690802d2}},	//   _ཤོགག, _dubh, _መደበር_, _hýen, 
   {{0x7d0c2638,0x3948a8b3,0x656c01c3,0x00000000}},	//   _mlas, mlas_, _eubh, --, 
   {{0x49b8a8b4,0x2bdc0882,0x7d0ca8b5,0x39481948}},	//   _باید_, मिता, _llas, llas_, 
   {{0x3948a8b6,0x656ca8b7,0x7d0ca8b8,0x29140428}},	//   olas_, _gubh, _olas, _ôbaò_, 
   {{0x2fcca8b9,0xa1540640,0x7d0c022e,0xafe400d8}},	//   tweg_, мају_, _nlas, доил, 
   {{0x3948a8ba,0x656c002b,0x00000000,0x00000000}},	//   ilas_, _zubh, --, --, 
   {{0x2fcca8bb,0x3948a8bc,0xa5080135,0xe3c809d7}},	//   rweg_, hlas_, _གཞོག_, señó_, 
   {{0x2fcca8bd,0xed5807d6,0x82c8025c,0xe2d800db}},	//   sweg_, жон_, _གྲིའ, _باقچ_, 
   {{0x7d0c4bbe,0x62240220,0x39480115,0x49b400c7}},	//   _clas, _تومە, jlas_, ҕәоу, 
   {{0xaae426c9,0x2ef42b39,0x7d04031c,0x7d0c4d8c}},	//   وسسو, _оздр, _ċist, _dlas, 
   {{0x3948a8be,0xada001a2,0x3ce80793,0xada4004e}},	//   elas_, ľúbe, _enav_, _жакл, 
   {{0x7d0ca8bf,0x69cc01a4,0x3948a8c0,0x00000000}},	//   _flas, uwbe, flas_, --, 
   {{0x7d0c512d,0x3ce8010a,0x9f9c002e,0x656ca8c1}},	//   _glas, _gnav_, _séég_, _rubh, 
   {{0x656ca8c2,0x673c002d,0x6d540205,0xf8a4009d}},	// [d680] _subh, topj, _ihya, эгтү, 
   {{0x3948a8c3,0x7d0ca8c4,0x656c01e4,0x00000000}},	//   alas_, _zlas, _pubh, --, 
   {{0x3948a8c5,0x7d0c01b9,0x656c014f,0x673c0240}},	//   blas_, _ylas, _qubh, ropj, 
   {{0x673c002d,0x00000000,0x00000000,0x00000000}},	//   sopj, --, --, --, 
   {{0x656c0b6f,0xd87400cf,0x93f00073,0xed940092}},	//   _wubh, _تاپب, _आपणच_, _መደብር_, 
   {{0xa2f807f7,0x656ca8c6,0xf6d400d4,0x00000000}},	//   ्सेज_, _tubh, _піся, --, 
   {{0x9660a8c7,0x338c02d3,0x6d5400b5,0xa5081d4a}},	//   _акре, _ህደግኤ_, _ohya, _дева_, 
   {{0x6d54009a,0xe3b000f1,0xc15401e1,0x68f4a8c8}},	//   _nhya, _لرئ_, _ẹgbọ, njyd, 
   {{0x8fa0a8c9,0x77680798,0x74f00150,0x7d0c01d5}},	//   вање, _éext, _حۋنا, _rlas, 
   {{0x24840598,0x6d5402d0,0x7d0c48ed,0x3948a8ca}},	//   lbom_, _ahya, _slas, zlas_, 
   {{0x7d0ca8cb,0x3948a8cc,0xb8d0031c,0x6d5400dc}},	//   _plas, ylas_, _ནྰ_, _bhya, 
   {{0x6d54a8cd,0xf1a803e6,0x7d0c022e,0x3948a8ce}},	//   _chya, _رامه_, _qlas, xlas_, 
   {{0x291000dc,0x39480c86,0x3ce8a8cf,0x60c00248}},	//   dhya_, vlas_, _vnav_, _ibom, 
   {{0x7bdc819e,0x3d94020a,0x7d0c033f,0x6d5402d0}},	//   rvsu, _зикр, _wlas, _ehya, 
   {{0x7d0c2246,0xcda42004,0x7e6401e4,0x3ce80334}},	//   _tlas, _قهوه_, _ŝipf, _tnav_, 
   {{0x39480c86,0xfe780064,0x00000000,0x00000000}},	//   ulas_, lcį_, --, --, 
   {{0x3948a8d0,0xd6d806bb,0x60c0a8d1,0x248405ce}},	// [d690] rlas_, жте_, _mbom, dbom_, 
   {{0x3948a8d2,0x085409fe,0xa5080135,0x9aa40014}},	//   slas_, твую, _གཞུག_, _کَھے_, 
   {{0x3948a8d3,0x60c0a8d4,0x29100882,0xdc3c0118}},	//   plas_, _obom, bhya_, _míčk, 
   {{0xd4980220,0x57a401b9,0xdc3c02f0,0x4a0400c7}},	//   іре_, _ошга, _líčk, _рџьа, 
   {{0xc4840006,0x00000000,0x00000000,0x00000000}},	//   тлік, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x60c00337,0x6444022c,0x20000174,0x00000000}},	//   _bbom, _økin, økin_, --, 
   {{0x60c001ab,0x890c010f,0x00000000,0x00000000}},	//   _cbom, ַליִ, --, --, 
   {{0xd75c0201,0xafe40845,0x6d54a8d5,0x00000000}},	//   ታወቂያ_, хопл, _rhya, --, 
   {{0x6d540796,0x60c0a8d6,0x5184a8d7,0x2bdc134e}},	//   _shya, _ebom, _жуда, मिसा, 
   {{0x6d540076,0x2ef4010b,0x3eb8068c,0x9f9400c7}},	//   _phya, _үзер, òrta_, _ҧышә, 
   {{0x60c027dd,0x6578a8d8,0xdcf80064,0xbf700124}},	//   _gbom, _éthe, istė, ықәы, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69080209,0x24842375,0xdcf80064,0x00000000}},	//   _eýel, zbom_, kstė, --, 
   {{0x2910a8d9,0x6d5418f7,0x68f4005c,0x24840051}},	//   thya_, _thya, tjyd, ybom_, 
   {{0x9f40025a,0x6d5447b1,0xd94000db,0x248401e3}},	//   âkö_, _uhya, геси, xbom_, 
   {{0x29100004,0xe7cc015b,0xa6e4a8da,0xe7a86e1f}},	// [d6a0] rhya_, রম্য, нжал, явал_, 
   {{0x29104c99,0x2a7800d8,0x63a401e3,0x00000000}},	//   shya_, _ufpb_, _åkni, --, 
   {{0x291002b9,0x248401fa,0xe5780212,0x2bdc00cd}},	//   phya_, tbom_, їзд_, मिवा, 
   {{0xbebc00e2,0x00000000,0x00000000,0x00000000}},	//   lnīt, --, --, --, 
   {{0x64a404a9,0x95b40166,0x00000000,0x00000000}},	//   _җаза, _үрсә, --, --, 
   {{0x23e007f7,0x6d44032e,0x66e400d8,0x00000000}},	//   पिबद, _íhaf, _џова, --, 
   {{0x21644553,0x64a40006,0x85b4035b,0x00000000}},	//   нтиг, _пава, _шәач, --, 
   {{0xa5080135,0x4ac002a0,0x80bc03ba,0xe3b8a8db}},	//   _གཞིག_, श्तव, ्जें, _нбб_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe2984fac,0x53980375,0x21740117,0x00000000}},	//   _хаж_, _מימו, _зудр, --, 
   {{0x30f80451,0xdc3c0118,0xf2cc05ac,0xd12ca8dc}},	//   _ڪونھ_, _víčk, লাখণ, _бх_, 
   {{0x60c000aa,0x21183fe2,0x95840023,0xbebc00ef}},	//   _ubom, _عتاب_, _ዝነብዕ_, enīt, 
   {{0xc9840116,0x20000254,0x6024009d,0x00000000}},	//   ғуси, äkid_, _ядда, --, 
   {{0xdcf80006,0x905000c0,0x00000000,0x00000000}},	//   ystė, _свіц, --, --, 
   {{0xb92400c6,0xd9c807f7,0x00000000,0x00000000}},	//   نفسي, ाबेट, --, --, 
   {{0x2d980118,0x79740210,0x00000000,0x00000000}},	//   ízeň_, _wąwo, --, --, 
   {{0x0e609151,0xda7801c6,0xd7f800d4,0x20c01546}},	// [d6b0] _икән, _нян_, чув_, व्यध, 
   {{0x6b5004ce,0x2bdc06ff,0x00000000,0x00000000}},	//   lægn, मिरा, --, --, 
   {{0xa8001b0d,0x69f03004,0x35b40064,0x00000000}},	//   çırd, _күрт, тбер, --, 
   {{0xd91807d5,0x00000000,0x00000000,0x00000000}},	//   _хьо_, --, --, --, 
   {{0xda6433ae,0x00000000,0x00000000,0x00000000}},	//   _تاکي, --, --, --, 
   {{0xefe41b49,0x8c1c0375,0xf2d000ae,0xdcf80064}},	//   ዝባዊ_, הודי, شآت_, pstė, 
   {{0x66800244,0xb594009d,0x00000000,0x00000000}},	//   _ئیمل, _шивш, --, --, 
   {{0x25fc5a30,0x7654035a,0x00000000,0x00000000}},	//   लहरी_, _izzy, --, --, 
   {{0xe0d45067,0x2f54a8dd,0xb2b8011c,0x00000000}},	//   твы_, ктос, _олаф_, --, 
   {{0xaf0433cd,0x00000000,0x00000000,0x00000000}},	//   тпол, --, --, --, 
   {{0xa2b802ab,0x41c40014,0x7c600092,0x00000000}},	//   _शॉट्, _مٲلِ, _ታስረው_, --, 
   {{0xeb98a8de,0x2bdc65c5,0x1f240050,0x00000000}},	//   мим_, मिला, _یِنہ, --, 
   {{0x4084020a,0xcbc8004b,0x00000000,0x00000000}},	//   _сухб, رېدو_, --, --, 
   {{0xa3e01d8a,0x43800131,0x7e6400df,0x00000000}},	//   धित_, ﻧﺪﯨﻦ_, _ŝipe, --, 
   {{0x49040145,0xcdc0a8df,0xabc400db,0x00000000}},	//   гүнг, _сайқ, رۇگۅ_, --, 
   {{0x2d84a8e0,0x61fc03cd,0x6fa401f9,0x00000000}},	//   mple_, øpli, _गटां, --, 
   {{0x3958a8e1,0x765402d0,0xa6940640,0x2d84a8e2}},	// [d6c0] _dhss_, _azzy, вреј, lple_, 
   {{0x2d84a8e3,0xb86401f7,0x00000000,0x00000000}},	//   ople_, طاقو, --, --, 
   {{0xdbe0004a,0x2d84a8e4,0xa8885f0f,0x64a40022}},	//   _rééc, nple_, _ойна_, ҵаҵа, 
   {{0x2d801368,0x00000000,0x00000000,0x00000000}},	//   _çheu_, --, --, --, 
   {{0xd464a8e5,0xe3b40798,0x00000000,0x00000000}},	//   вице_, тсеќ, --, --, 
   {{0x776800d8,0xa6c800fd,0x6b8056f8,0x626400d1}},	//   _éexp, _юлга_, _çogu, پاتق, 
   {{0x95b4a8e6,0x7bc00276,0x613c0036,0x00000000}},	//   _иртә, ălui, mëlz, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x5e84084c,0x6fc40327,0x1ea83592,0xb24401e0}},	//   кунз, _ཀརྞའ, وادي_, кмәһ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x62880072,0x7e64010f,0x2ff40220,0x2168009b}},	//   mbfo, _ŝipb, _ەتىڭ, _жижи_, 
   {{0x397401d5,0x60080117,0x00000000,0x00000000}},	//   ғлаё, _онем_, --, --, 
   {{0xdcf80029,0xd00c0597,0x613c0240,0x6b8402d0}},	//   lstī, _ولم_, këlz, gpkg, 
   {{0xb34403b7,0xda78034b,0x5b240212,0x00000000}},	//   moçã, ьям_, тьма, --, 
   {{0x1db4a8e7,0x6b50037e,0x2d840076,0x06340092}},	//   _अमित, mægl, cple_, ባራዊነ, 
   {{0x0dc4a8e8,0xc984020a,0x48a800db,0xdcf800de}},	//   _руши_, рури, ктум_, istī, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [d6d0] --, --, --, --, 
   {{0xdcf80029,0x1db411bc,0x00000000,0x00000000}},	//   kstī, _अमात, --, --, 
   {{0x0574a8e9,0xd5b80dce,0x4b38011a,0x8d7c0116}},	//   لاند, ьса_, _ברזל_, ﯩﻘﺎﺕ_, 
   {{0x394c038f,0x61700020,0xd3446071,0x00000000}},	//   ċess_, _ብሔራዊ_, چیره_, --, 
   {{0x4ac01428,0xf1e00131,0x291c003a,0xd8388e21}},	//   श्वव, _ﺋﯧﻴﺘ, ëtae_, _цэн_, 
   {{0xbbb00412,0x00000000,0x00000000,0x00000000}},	//   _जमैक, --, --, --, 
   {{0xe4e4104b,0x765403ac,0x3074004e,0x00000000}},	//   _өстү, _uzzy, лупс, --, 
   {{0x657806af,0x00000000,0x00000000,0x00000000}},	//   _étha, --, --, --, 
   {{0x35a40116,0x09e000bc,0xb354014b,0x00000000}},	//   _шаңг, _पछ्य, _бкаш, --, 
   {{0xaab00037,0x00000000,0x00000000,0x00000000}},	//   _जाइक, --, --, --, 
   {{0x2d842165,0x6804016b,0x00000000,0x00000000}},	//   uple_, mɔde, --, --, 
   {{0x9a94001f,0x2d84a8ea,0x41740131,0xed2000eb}},	//   ውሳኔው_, rple_, _ئالس, ফক্স_, 
   {{0xbebc005f,0xa3b40073,0x5ecc0154,0xa0980a7c}},	//   rnīr, चंय_, ়াজে, _ניסט, 
   {{0xe45400c8,0xdb0c020c,0x2d842517,0xeab801c6}},	//   טירט_, nucè, pple_, эйг_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd04801e4,0x00000000,0x00000000,0x00000000}},	//   _angɩ, --, --, --, 
   {{0x27e40491,0x00000000,0x00000000,0x00000000}},	// [d6e0] íon_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa3b40574,0xdb0c0561,0x27e40115,0xa5080108}},	//   चून_, ducè, ŭon_, нежа_, 
   {{0x6d44a8eb,0x4ac000dc,0x00000000,0x00000000}},	//   noka, श्रव, --, --, 
   {{0x442007ae,0x2900a8ec,0x23280107,0x25a4002e}},	//   ài_, _ioka_, ноди_, ōol_, 
   {{0x6d44a8ed,0x2900a8ee,0xb3440798,0x06d80154}},	//   hoka, _hoka_, voçã, সাহি, 
   {{0x6d44a8ef,0x92e400ec,0x6288002f,0x00000000}},	//   koka, طفيٰ_, rbfo, --, 
   {{0x2900426d,0x6d44a8f0,0x41540261,0xdcf800e2}},	//   _joka_, joka, јвис, rstī, 
   {{0x29007483,0xe29006d5,0x6d4403b4,0x3f14a8f1}},	//   _moka_, _هذا_, doka, идис, 
   {{0x6560016d,0x3eb85d8b,0xe37401e0,0x41dc4142}},	//   lmoh, ürt_, _алҡы, _मनपस, 
   {{0x2900a8f2,0xd54001e1,0xdce80356,0xd12c0050}},	//   _ooka_, _jé̟j, _nufă, _کمن_, 
   {{0x2900a8f3,0x65600842,0x6d44a8f4,0xab94001f}},	//   _noka_, nmoh, goka, _ሆነዋል_, 
   {{0x7f94a8f5,0xd54001e1,0x93fc0327,0xdee00092}},	//   _талх, _lé̟j, ཙཱརྱ_, ዝናኛ_, 
   {{0x5018025f,0x656027cc,0x29000851,0x6d4400b0}},	//   _אודו, hmoh, _aoka_, aoka, 
   {{0x6d44a8f6,0x2900a8f7,0x98c4a3ae,0xd6a800e5}},	//   boka, _boka_, лсал, ہدام_, 
   {{0x29000286,0x93c40276,0x6b500008,0x65600978}},	//   _coka_, ltăţ, nægj, jmoh, 
   {{0x76b89a1d,0xdd90005e,0x2900a8f8,0x6560047e}},	// [d6f0] клар_, _тақы, _doka_, dmoh, 
   {{0x1954774d,0x7bcca8f9,0x290001e4,0xdaa00150}},	//   тағы_, _ipau, _eoka_, _دەسپ, 
   {{0x2900a8fa,0x5504009d,0x00000000,0x00000000}},	//   _foka_, лчда, --, --, 
   {{0x39a00953,0x79846ad0,0x81bc02a6,0x2900a8fb}},	//   mės_, _ithw, েটা_, _goka_, 
   {{0x39a04077,0x2898010f,0x07a400c0,0x00000000}},	//   lės_, _בירא, _лаўн, --, 
   {{0x6d44263d,0x2124011f,0x9f440660,0xaa840432}},	//   zoka, _amoh_, _droë_, _ilýä, 
   {{0x39a0a8fc,0x6d44a8fd,0x2900a8fe,0x247c0521}},	//   nės_, yoka, _yoka_, _ịme_, 
   {{0xccf4013f,0x79840921,0x93c40276,0x7bcc180f}},	//   _ahɛn_, _mthw, etăţ, _opau, 
   {{0x7bcc0457,0x92a41f5a,0x06d80154,0x00000000}},	//   _npau, _бјел, সারি, --, 
   {{0x6d44a8ff,0x39a00953,0x212400f2,0x7984a900}},	//   woka, kės_, _emoh_, _othw, 
   {{0x7984a901,0x2d90503f,0xed58a902,0x67182356}},	//   _nthw, èze_, коо_, फोटक_, 
   {{0x39a002d5,0x6d4401e4,0x1db409b2,0x6618013d}},	//   dės_, uoka, _अमरत, _ütke, 
   {{0x7984a903,0x2900a904,0xdce80356,0xfb8401d5}},	//   _athw, _roka_, _sufă, یگیی, 
   {{0x6d44a905,0x2900a906,0x656002f0,0x39a00064}},	//   soka, _soka_, zmoh, fės_, 
   {{0x2900a907,0x7bcc0428,0x39a00006,0x798402d0}},	//   _poka_, _epau, gės_, _cthw, 
   {{0x290023e0,0x00000000,0x00000000,0x00000000}},	//   _qoka_, --, --, --, 
   {{0x79840944,0x290003d1,0x65600978,0x00000000}},	// [d700] _ethw, _voka_, vmoh, --, 
   {{0x39a00953,0xe6108ab7,0x2900a908,0x613c0265}},	//   bės_, يشا_, _woka_, mīle, 
   {{0x2900a909,0x2bdc21b8,0x291c068c,0x287407e6}},	//   _toka_, मिका, ètas_, _выгр, 
   {{0x7a84a90a,0x69800521,0xd7d800b5,0x59a800c5}},	//   _پشیم, _ọgwụ, _egパ_, _छितर, 
   {{0x6560a90b,0x23d4a90c,0x85e401ec,0xa69400d8}},	//   rmoh, рцер, _گۋان, _врбј, 
   {{0x65600978,0xe738330e,0x6578a90d,0x1db401ad}},	//   smoh, _рег_, _étho, _अमलत, 
   {{0xd1b4a90e,0xe82c0092,0x58c803d4,0x6560016d}},	//   لايا_, _በመቀነ, ৱাৰী, pmoh, 
   {{0xdc2c013d,0x6560016d,0xa3b40c70,0x91a40037}},	//   _nığr, qmoh, चंद_, _गिरई, 
   {{0x39a002d5,0xd4641d0f,0x2f0802d2,0xe298014b}},	//   zės_, _вите_, _lúgu_, _ааз_, 
   {{0xe1f02bd9,0x93c4054e,0xab5c0092,0x613c00ef}},	//   _وسا_, utăţ, _ተፅእኖ_, dīle, 
   {{0x7bcca90f,0xf1a8168d,0x93c40311,0xed4c1893}},	//   _spau, _مانه_, rtăţ, کھو_, 
   {{0x39a00953,0x93c40356,0x1fa8014b,0x00000000}},	//   vės_, stăţ, _акди_, --, 
   {{0x26c80a4d,0x50840075,0x93c40311,0xd12c135f}},	//   _obbo_, _ئامې, ptăţ, _غمه_, 
   {{0x39a04077,0x8f9804ac,0xa3ac038e,0xd00c54af}},	//   tės_, _יידי, _किन_, _تله_, 
   {{0x7f48014f,0x6d5c002e,0xa6c8022e,0x00000000}},	//   modq, ŋsaa, rnаl, --, 
   {{0x39a002d5,0x26c801a4,0x00000000,0x00000000}},	//   rės_, _abbo_, --, --, 
   {{0x39a00953,0x7bcc0944,0x984800a7,0x69d80393}},	// [d710] sės_, _upau, тява_, æter, 
   {{0x39a002d5,0x67c800da,0x1dd80034,0x7f48047e}},	//   pės_, dējā, _बनात, nodq, 
   {{0x79840944,0xdb0c0165,0x2b440332,0x00000000}},	//   _uthw, lucï, _íoca_, --, 
   {{0x26c8009f,0xa3e000dc,0xf40403d4,0x00000000}},	//   _ebbo_, धिं_, _শেষৰ_, --, 
   {{0x3948056a,0x8cbc00cd,0x73e40798,0x00000000}},	//   moas_, ष्टो, солз, --, 
   {{0xc3244dba,0x81e0009e,0x3948030a,0x032400d4}},	//   омік, দমন_, loas_, одін, 
   {{0x94a81d1f,0x2000049b,0xf07401ed,0xd498a910}},	//   _لاءِ_, äkin_, میاں_, _арз_, 
   {{0x3948a911,0xada401e0,0x67c800e2,0x00000000}},	//   noas_, ҙамл, bējā, --, 
   {{0x7528a912,0xa3e00882,0xa3dc000d,0x3ebc0208}},	//   _imez, धिः_, _तनय_, _bcvt_, 
   {{0xa28000e5,0x00000000,0x00000000,0x00000000}},	//   _ٹیٹو, --, --, --, 
   {{0x21cc00ac,0x7db40024,0x645c0210,0x6e4400d8}},	//   _cəhd_, осяц, ępie, сенз, 
   {{0xa3ac15e0,0x61ec02d2,0x00000000,0x00000000}},	//   _किम_, _ábla, --, --, 
   {{0x3948a913,0x752802e3,0x7ff4009f,0x00000000}},	//   doas_, _mmez, _وسها, --, 
   {{0x81bc015b,0x21cc06be,0x00000000,0x00000000}},	//   েটর_, _fəhd_, --, --, 
   {{0x75280316,0x00000000,0x00000000,0x00000000}},	//   _omez, --, --, --, 
   {{0x3948a914,0xe618a915,0xc7b4013f,0x7bc00356}},	//   goas_, ңда_, tuɑ_, ălur, 
   {{0xa6c805f5,0xd7d800b5,0x78bc0175,0x5c8400fb}},	// [d720] ллаа_, _afモ_, _dcsv, _уйым_, 
   {{0x7528985a,0xe64410f5,0x6908010e,0x48e800e1}},	//   _amez, безп, _aýet, _चोरो_, 
   {{0x39481709,0xc7b40134,0x6abc03ac,0xe57000ec}},	//   boas_, suɑ_, _icpf, سطا_, 
   {{0x69dca916,0x3948a917,0x67c800e2,0xf524003b}},	//   _ispe, coas_, tējā, офін, 
   {{0x6d8c0943,0x00000000,0x00000000,0x00000000}},	//   _ṱale, --, --, --, 
   {{0x7528a918,0x6284013f,0x67c8005f,0x26c8002d}},	//   _emez, _ɑkow, rējā, _ubbo_, 
   {{0x9f5000d5,0x29101418,0xbbc400dc,0x3d18012d}},	//   _écés_, okya_, _लङ्क, _पतले_, 
   {{0x11d004a9,0xccf4013b,0x7e64008f,0x29100337}},	//   ستىد, _nnɛ_, _ŝipo, nkya_, 
   {{0xc43404d3,0xc600015b,0x93c801d9,0xdef00124}},	//   _بکات, _এইটা_, _مالہ_, зҿлы, 
   {{0x63a0a919,0x69dca91a,0x2b4800b5,0x00000000}},	//   mson, _ospe, jobc_, --, 
   {{0x63a0a91b,0x6298a91c,0x7d1c036e,0x00000000}},	//   lson, _ieto, ërso, --, 
   {{0x6298a91d,0x6b940142,0x39480077,0x5c048675}},	//   _heto, _bwyg, xoas_, бяга, 
   {{0x6298a91e,0x1dd80490,0x78bc0010,0x3948030a}},	//   _keto, _बनवत, _rcsv, voas_, 
   {{0x63a0a91f,0x6298044e,0x257c0ba1,0x6b940042}},	//   ison, _jeto, _oïl_, _dwyg, 
   {{0x69dc04cc,0x394800c5,0xc838001f,0x1278008f}},	//   _cspe, toas_, _በመከላ, ראלע, 
   {{0x6298a920,0x69dc08cd,0x7c34003b,0x00000000}},	//   _leto, _dspe, _мейх, --, 
   {{0xdb0ca921,0x3948a922,0x257c0165,0xe7780588}},	// [d730] lucí, roas_, _aïl_, иатә_, 
   {{0x6298a923,0x69dc0175,0x00000000,0x00000000}},	//   _neto, _fspe, --, --, 
   {{0x247c0521,0x63a0a924,0x6aa8045f,0x95240327}},	//   _ịma_, eson, _ôffa, ྡྲའི_, 
   {{0x6298a925,0x69c8014a,0x63a0a926,0x85440276}},	//   _aeto, _äfea, fson, пэче, 
   {{0x6298a927,0x63a0a928,0x690800ee,0x290c016b}},	//   _beto, gson, _eýes, ɔfa_, 
   {{0x6298a929,0x69dc0142,0x69080432,0x02c400cd}},	//   _ceto, _yspe, _wýet, ल्लभ, 
   {{0x63a0a92a,0x69080432,0x47e000fe,0x00000000}},	//   ason, _iýer, নমণী, --, 
   {{0xdb0ca92b,0x7528a92c,0x6298062c,0x0584a92d}},	//   ducí, _umez, _eeto, _хурм, 
   {{0x6298a92e,0x60042ecc,0x63a000dd,0x2bdc00bc}},	//   _feto, жным_, cson, मिछा, 
   {{0x6298a92f,0x6b940042,0x00000000,0x00000000}},	//   _geto, _rwyg, --, --, 
   {{0xad240075,0x6b940af9,0xd1580092,0x2ed801f9}},	//   قىدى, _swyg, ልከቻው, _बघीत, 
   {{0x2fdc0218,0x69dc007f,0x690800a2,0xf1a81e4b}},	//   _tswg_, _rspe, _lýer, _ماچه_, 
   {{0x6298a930,0xa1105f6b,0xdb0c054e,0xbc1802dd}},	//   _yeto, _زووت, ducâ, бірі_, 
   {{0xc1780064,0x62980051,0x00000000,0x00000000}},	//   _grės_, _xeto, --, --, 
   {{0xed583756,0x63a001d3,0xd9780124,0x3e88009f}},	//   _кок_, zson, иртә_, _اَٺَ_, 
   {{0x63a0a931,0x7d1ca932,0x1d840133,0x00000000}},	//   yson, chss, _بدوێ, --, 
   {{0xaa8804fb,0x6908010e,0x2910a933,0x00000000}},	// [d740] _پنجم_, _býer, rkya_, --, 
   {{0xeab02832,0x29100158,0x63a0a934,0x8e2401a9}},	//   _کٹھ_, skya_, vson, _yanа_, 
   {{0x69dca935,0x00000000,0x00000000,0x00000000}},	//   _uspe, --, --, --, 
   {{0x63a0a936,0x690800ee,0x00000000,0x00000000}},	//   tson, _eýer, --, --, 
   {{0xd40000c9,0x4394a937,0x63a0a938,0x00000000}},	//   дящи, чалс, uson, --, 
   {{0x6298a939,0x37d800c8,0x7e6401e4,0x2bb02802}},	//   _qeto, _פֿרע, _ŝipm, _जिना, 
   {{0x6298a93a,0x63a0a93b,0x00000000,0x00000000}},	//   _veto, sson, --, --, 
   {{0x63a0a93c,0x1fa44b17,0x6298a93d,0x00000000}},	//   pson, орог, _weto, --, 
   {{0x6298a93e,0x50b4034c,0xa3dc00c5,0x63a001b9}},	//   _teto, زديد_, _तनि_, qson, 
   {{0x62980857,0x61f4009f,0x00000000,0x00000000}},	//   _ueto, _وساء, --, --, 
   {{0xa3e00d2b,0x09d00154,0x7d1c7c49,0x7e54003b}},	//   धिक_, ায়তা, thss, явоє, 
   {{0x644406ea,0xf3f800a2,0x291c002e,0x6d440252}},	//   _økis, _agţy_, ëtal_, _íhal, 
   {{0xdee4a93f,0x29e8a940,0xa068026a,0x4fb08d1a}},	//   _моди, _aĝa_, _тада_, _قصور, 
   {{0xdb0c0306,0x00000000,0x00000000,0x00000000}},	//   pucí, --, --, --, 
   {{0x7d1c03ac,0x00000000,0x00000000,0x00000000}},	//   phss, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x29e801e4,0x7d2800f1,0x2bb02982,0x00000000}},	// [d750] _eĝa_, _پيښې_, _जिया, --, 
   {{0xd6d8026a,0xaa5800f2,0x00000000,0x00000000}},	//   јта_, _گلپا_, --, --, 
   {{0x7ae4054e,0xdfc400f1,0x00000000,0x00000000}},	//   _iaht, _ګي_, --, --, 
   {{0xea600150,0x7ae401f4,0x04c815eb,0xee48010e}},	//   _سۇقپ, _haht, قومي_, leýä_, 
   {{0x7ae418db,0xd7f8a941,0x690800a2,0x04c800b3}},	//   _kaht, _тун_, _týer, توني_, 
   {{0x23b0040d,0x7d1c0240,0xe294a942,0x96e800f5}},	//   رمىس, ërsj, паш_, _тьма_, 
   {{0x3494a943,0x7ae4a944,0x9f4400c6,0x6b50a945}},	//   _навр, _maht, _croí_, mægt, 
   {{0x7ae4a946,0x777c01a9,0x30040116,0x6b5001bf}},	//   _laht, _kusx, ззиг, lægt, 
   {{0x15a402dd,0xdb0c009a,0x7654010e,0xc954011a}},	//   _ءﺗﺎﻟ, kucà, _hyzy, ומק_, 
   {{0xef18764a,0x777c0a63,0x76540158,0x7ae423ac}},	//   смо_, _musx, _kyzy, _naht, 
   {{0xf1d00323,0x9f40a947,0x9f440332,0xb5dc00ee}},	//   _чөлө, íká_, _groí_, _öýdý, 
   {{0x765400a2,0x00000000,0x00000000,0x00000000}},	//   _myzy, --, --, --, 
   {{0x7ae4102c,0x777c036b,0x291c003a,0x00000000}},	//   _baht, _nusx, ëtam_, --, 
   {{0xa3ac2068,0x28cc448b,0xedc800ec,0x00000000}},	//   _किस_, ह्नि, _هِتي_, --, 
   {{0x76540fac,0xa3e0023e,0x00000000,0x00000000}},	//   _nyzy, _फैन_, --, --, 
   {{0x657807ea,0xdca00107,0x00000000,0x00000000}},	//   _éthi, _заъи, --, --, 
   {{0x6d8c0943,0x7ae40109,0x1864a948,0x6b50005c}},	// [d760] _ṱahe, _faht, зати_, fægt, 
   {{0x7654036e,0x41dc00c5,0x59c00116,0x00000000}},	//   _byzy, _मनलस, بيېك, --, 
   {{0x765400a2,0xa8840137,0x63640051,0x00000000}},	//   _cyzy, _ىلدى, _hưng, --, 
   {{0x7e6400df,0x76540432,0x54800023,0x00000000}},	//   _ŝipk, _dyzy, _ክበርህ_, --, 
   {{0x7ae40477,0x00000000,0x00000000,0x00000000}},	//   _yaht, --, --, --, 
   {{0x68e40209,0x779003e6,0xe5a48e43,0xdc340a7c}},	//   _hakd, _شیما, _ниги, האנט_, 
   {{0x765409a5,0x26d8a949,0x7d1c0660,0x6b503c38}},	//   _gyzy, mepo_, ërsk, lægs, 
   {{0x26d8a94a,0x68e40198,0x7bdc015d,0x00000000}},	//   lepo_, _jakd, ywsu, --, 
   {{0x68e407ab,0x24847881,0xd9500240,0x00000000}},	//   _makd, mcom_, _መጥባሕ, --, 
   {{0x26d8a94b,0x68e4a94c,0xdef80022,0x291c0200}},	//   nepo_, _lakd, сыи_, ëtaj_, 
   {{0x30140228,0x7ae4a94d,0x68e4a94e,0x6b5003b2}},	//   здөр, _raht, _oakd, hægs, 
   {{0x26d8a94f,0x68e41bb5,0x2484a950,0x9bb4025c}},	//   hepo_, _nakd, ncom_, _བཀྱོ, 
   {{0x26d8a951,0x60c0a952,0x7bdc01a4,0x248400db}},	//   kepo_, _icom, uwsu, icom_, 
   {{0x26d81727,0xd00c7af1,0x60c00175,0x7ae4022e}},	//   jepo_, _حله_, _hcom, _qaht, 
   {{0x68e4a953,0x7ae405a7,0x2484008b,0x6b5000b5}},	//   _bakd, _vaht, kcom_, vægt, 
   {{0x672c038f,0x76540034,0xc7b4013f,0x24840419}},	//   _ambj, _ryzy, frɑ_, jcom_, 
   {{0x7ae4a954,0x9bb40003,0x9f440c67,0x6b50037e}},	// [d770] _taht, _བཀྲོ, _groã_, tægt, 
   {{0x60c00421,0x68e4035a,0x765400a2,0x2bb0194b}},	//   _lcom, _eakd, _pyzy, _जिता, 
   {{0x68e40115,0x60c0a955,0x6b501924,0x00000000}},	//   _fakd, _ocom, rægt, --, 
   {{0x33d40046,0x7d1c044e,0x60c0a956,0xd7f800f3}},	//   дікт, ërsh, _ncom, _луг_, 
   {{0x96e8187a,0x0574a957,0x7654012d,0x00000000}},	//   _льва_, رامد, _wyzy, --, 
   {{0x68e4571f,0x35b42a3b,0x24840419,0xc6e40150}},	//   _zakd, _обгр, acom_, _пісп, 
   {{0x60c00175,0x9554a958,0x41dc01bc,0x24840216}},	//   _bcom, _فخرا, _मनःस, bcom_, 
   {{0x60c01529,0x2484a959,0x4c8c01ec,0xcfc400d1}},	//   _ccom, ccom_, _ﺒﻘﺎﺀ_, _ﻫﻪﺭﻗ, 
   {{0x60c00334,0xb4b852f2,0xc0a800e3,0x00000000}},	//   _dcom, चली_, سايل_, --, 
   {{0xee38a95a,0x60c0a95b,0xc7d8011a,0xdcec0171}},	//   жно_, _ecom, לוחי_, _ēdāj, 
   {{0xfe74104b,0x7b180309,0x60c00334,0x00000000}},	//   нүш_, _pìun, _fcom, --, 
   {{0x60c00491,0x30148b16,0x26d802ce,0x244800e4}},	//   _gcom, _одер, zepo_, ỹme_, 
   {{0x68e4030a,0x26d801f7,0x00000000,0x00000000}},	//   _rakd, yepo_, --, --, 
   {{0x68e4a95c,0x26d8005a,0x2484a95d,0x00000000}},	//   _sakd, xepo_, zcom_, --, 
   {{0x68e4414b,0xcfac02f5,0x26d8006f,0x00000000}},	//   _pakd, _কহিন, vepo_, --, 
   {{0x26d8a95e,0xa3ac00dc,0x24840129,0x60c00332}},	//   wepo_, _किल_, xcom_, _xcom, 
   {{0x68e4a95f,0x26d802ce,0x24840030,0xa6e43594}},	// [d780] _vakd, tepo_, vcom_, мжал, 
   {{0x6f1c04c4,0x7e6400df,0x2484a960,0xdb0c00e4}},	//   ësch, _ŝipi, wcom_, pucá, 
   {{0x68e4a961,0x2484a962,0x26d8a963,0x6b5001bf}},	//   _takd, tcom_, repo_, bægr, 
   {{0x26d8a964,0xe458a965,0x24840356,0x00000000}},	//   sepo_, оже_, ucom_, --, 
   {{0x2484a966,0x7d1c0023,0xa348a967,0x6a1403e6}},	//   rcom_, ërsi, озда_, _ربگر, 
   {{0x60c0a968,0x71700372,0x672c032e,0x00000000}},	//   _scom, ۇۇلا, _umbj, --, 
   {{0x2484a969,0x273c0248,0x6d1c4da4,0xa31c000d}},	//   pcom_, _ẹní_, _पतंग_, _भतीज_, 
   {{0x60c00175,0x63040451,0x00000000,0x00000000}},	//   _qcom, _ڪوئل, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2214a96a,0x60c001af,0x3d94a96b,0x00000000}},	//   _офер, _wcom, ниор, --, 
   {{0x93100220,0xdbf001e1,0x00000000,0x00000000}},	//   _جولش, _s̟àl, --, --, 
   {{0x60c0014b,0x6aa8002d,0x28cc0c4c,0x00000000}},	//   _ucom, _ôffj, _हॉलि, --, 
   {{0x5f04a96c,0x909400d4,0x00000000,0x00000000}},	//   _озда, _цвіт_, --, --, 
   {{0xbec86e98,0xd00400d8,0x00000000,0x00000000}},	//   _brūž, _цеље_, --, --, 
   {{0xd90c4c12,0xc1dc0574,0xf6945f32,0xdb2001e1}},	//   لید_, _मनोग, _ﺗﯘﻟﭙ, _òrín, 
   {{0xa3aca96d,0xa3dc00e1,0x7a6400db,0x6284013d}},	//   _किं_, तबा_, _ۋئدە, _şkol, 
   {{0x7d0c0069,0xc7c8005b,0xda78009d,0x4c9c08c3}},	// [d790] _ioas, дыхе_, _мян_, _ובחו, 
   {{0x7d0c8845,0x37540137,0x63a403cd,0x3ce8000d}},	//   _hoas, رپاس, _åkny, _haav_, 
   {{0xb8e403f4,0x07087ae6,0x39740276,0x00000000}},	//   _এস_, بيلي_, _плоё, --, 
   {{0xb4b85345,0xa6c801d5,0xdb0c0332,0xd4800023}},	//   चले_, liаl, ircí, _ክበጽሑ_, 
   {{0x7d0c334b,0x3ce8020b,0x33580276,0x00000000}},	//   _moas, _maav_, падэ_, --, 
   {{0x88b0013f,0x7f880023,0x724400d1,0x00000000}},	//   nkɛn, _ኣሰካፊ_, ىھال, --, 
   {{0x7d0c1368,0x25a8002f,0x11643cc4,0x00000000}},	//   _ooas, _gvbl_, ولتی_, --, 
   {{0x7d0c0262,0x45d4a96e,0x3d18012d,0x00000000}},	//   _noas, _шосс, दसों_, --, 
   {{0xed58016c,0x919c0307,0xe7f00037,0x00000000}},	//   ҷон_, _गौरै, घिया_, --, 
   {{0x4394a96f,0xeb0c0490,0x84640395,0x9264a970}},	//   _рафс, _हवेत_, _ръсе, _قدام, 
   {{0x7d0ca971,0x2bb00d2c,0x00000000,0x00000000}},	//   _boas, _जिहा, --, --, 
   {{0x7d0ca972,0x00000000,0x00000000,0x00000000}},	//   _coas, --, --, --, 
   {{0x7d0c000f,0x316ca973,0x09a80490,0x00000000}},	//   _doas, mmez_, गळ्य, --, 
   {{0xada41f09,0x316c54ee,0xdee007d6,0x37e40154}},	//   _закл, lmez_, _боши, নমার, 
   {{0xa9680640,0x7d0c0731,0xf1bc03d4,0x7e640115}},	//   зива_, _foas, _আনুভ, _ŝipv, 
   {{0x7d0ca974,0x316c509e,0xb4b89e61,0xaa44010b}},	//   _goas, nmez_, चलो_, _җемл, 
   {{0x6d5400ca,0x7f8c008f,0xa764a975,0x684460a1}},	// [d7a0] _ikya, ַנאַ, екад, хнаа, 
   {{0xcfa80220,0x66d80124,0x00000000,0x00000000}},	//   _ﺳﻪﻟﺒ, џьар_, --, --, 
   {{0x3ce80218,0x2b84003a,0x7d0c009f,0x316ca976}},	//   _yaav_, _hôc_, _yoas, kmez_, 
   {{0x3ce801d4,0x2ebc00dc,0xa80000e4,0xa6c801a9}},	//   _xaav_, ्भुत, _êñom, tnаs, 
   {{0x9878010f,0x00000000,0x00000000,0x00000000}},	//   _מאכט, --, --, --, 
   {{0xf65000f8,0xd36c007b,0xe2a801c8,0x00000000}},	//   ائے_, مهن_, ساتن_, --, 
   {{0x6d54a977,0xaad046df,0xc0c4a978,0xdb140c6a}},	//   _okya, द्यक, вәли, écés, 
   {{0x6d540a49,0x25640014,0x51f01063,0x316c010b}},	//   _nkya, _سازُ, اسور, gmez_, 
   {{0x7d0c2517,0x2ebc00dc,0x8fa016a4,0xfff80133}},	//   _roas, ्भूत, гање, بکات_, 
   {{0x6d54a979,0x7d0ca97a,0x33d402bf,0x3ce8000d}},	//   _akya, _soas, _шіст, _saav_, 
   {{0xd36c8958,0x7d0c0023,0xdbd8002e,0x56b4010f}},	//   _اهل_, _poas, _ràña, עפטן_, 
   {{0xa0a405f5,0x316c0205,0x00000000,0x00000000}},	//   _чадд, cmez_, --, --, 
   {{0x7d0ca97b,0xad24014d,0x00000000,0x00000000}},	//   _voas, ئرپو, --, --, 
   {{0x6d542f99,0x7d0c016b,0x628806af,0x00000000}},	//   _ekya, _woas, ncfo, --, 
   {{0x7d0ca97c,0xcf540302,0x3ce80140,0xa6c801a9}},	//   _toas, _רבות_, _taav_, riаl, 
   {{0x0e580302,0x00000000,0x00000000,0x00000000}},	//   _מדוב, --, --, --, 
   {{0xb90802f8,0xd90ca97d,0x7d1c0240,0xc0540023}},	// [d7b0] _यस_, لیگ_, ërsu, _ምትህል, 
   {{0x95c8a97e,0x4c3c00d9,0x4734011c,0xdb200241}},	//   зуда_, _מתחב, гнус, _òràn, 
   {{0xd5b8a97f,0x00000000,0x00000000,0x00000000}},	//   яса_, --, --, --, 
   {{0x45180212,0x00000000,0x00000000,0x00000000}},	//   нція_, --, --, --, 
   {{0xc48402dd,0x48640395,0x316c03e0,0x00000000}},	//   улік, _бърб, vmez_, --, 
   {{0x82344bf3,0x6d440162,0x95c800f3,0x91bc012d}},	//   گرها, _íhav, _нуба_, _एमआई, 
   {{0x316c509e,0x04c80451,0xf07400e5,0x257c013a}},	//   tmez_, _ڳولي_, چیاں_, _půle_, 
   {{0x057407d6,0x2bb0033f,0xf07401d3,0xca7c022e}},	//   _ماقد, _जिला, نیاں_, hirа, 
   {{0x3374a980,0xa3ac068f,0x316ca981,0xb4dc00af}},	//   _агар, _किए_, rmez_, तजी_, 
   {{0x5184074d,0x316c0205,0x69d815b7,0x00000000}},	//   _зуда, smez_, çtek, --, 
   {{0x6e446145,0x6aa8000f,0xa2b401f9,0x00000000}},	//   тенз, _ôffi, _ईयत्, --, 
   {{0x6ac83bec,0xb034104e,0x203000f2,0x7db40006}},	//   िभ्र, _инеш, افیس, ысьц, 
   {{0x5ba00184,0x9d40a982,0x00000000,0x00000000}},	//   аһығ, реяд, --, --, 
   {{0x806402bf,0x4f680ce8,0x00000000,0x00000000}},	//   _свіж, _эшем_, --, --, 
   {{0x2fcca983,0xff500b24,0x00000000,0x00000000}},	//   lteg_, _اخن_, --, --, 
   {{0x6d540784,0x200001e6,0x377401e0,0x00000000}},	//   _ukya, åkig_, ғыус, --, 
   {{0x2fcca984,0x21cc03e3,0xe2f801e1,0x00000000}},	// [d7c0] nteg_, _rəhm_, _ṣígu, --, 
   {{0x6674a985,0x394c0219,0x2fcc04e6,0x260400ce}},	//   ندار, česa_, iteg_, _सऊदी_, 
   {{0x2fcc0a40,0x758802bf,0xa50802e8,0xa48401e2}},	//   hteg_, есів_, межа_, نجشن, 
   {{0x69cc03fa,0x2fcc030a,0x18a00d34,0x9f44a986}},	//   mtbe, kteg_, _каюм, _troç_, 
   {{0x23280107,0x6d4402d2,0x364c0023,0x00000000}},	//   моди_, _íhau, _ንዳግማ, --, 
   {{0x9f440589,0x291c7bc9,0x69cc0b4f,0xe0bc0154}},	//   _kroå_, ītau_, otbe, _আসেন, 
   {{0xf6640e26,0xe5a41955,0x27f0a987,0x2fcc002e}},	//   _берү, _шиви, lvyn_, eteg_, 
   {{0x2fcc074d,0x69cc13ee,0xc3c40bd6,0x5180121c}},	//   fteg_, itbe, _бөкл, шуша, 
   {{0x69cc01c7,0xd2600ce8,0x61ec0064,0x22500210}},	//   htbe, лкәй, _žilė, łyk_, 
   {{0x69cc3b52,0xdcd800dc,0x00000000,0x00000000}},	//   ktbe, यज्ञ, --, --, 
   {{0x7994010a,0x2fcc0489,0x69cc7eb6,0x7e9800e5}},	//   xpzw, ateg_, jtbe, ونکر_, 
   {{0x200000af,0x7e640115,0x69cc0112,0x68181c52}},	//   äkis_, _ŝips, dtbe, _kādā, 
   {{0xd12ca988,0x69cc0549,0x2fcc0042,0x6eb801f9}},	//   _بمن_, etbe, cteg_, ऊलखु, 
   {{0x69cc7824,0x6d440115,0x68180055,0xca7c022e}},	//   ftbe, _ŭhat, _mādā, tirа, 
   {{0xaad02f2e,0x69cc005c,0x1f4c0023,0x00000000}},	//   द्धक, gtbe, _ምእዙዝ, --, 
   {{0x29141884,0x613c00ef,0x00000000,0x00000000}},	//   ﻳﻼﭖ_, fīli, --, --, 
   {{0x36d40262,0x69cc0b4f,0xdb6894c9,0xa3e0033f}},	// [d7d0] лоар, atbe, _орол_, _फैल_, 
   {{0x7d1ca989,0xc7c400d8,0x00000000,0x00000000}},	//   lkss, јсти, --, --, 
   {{0x80a82158,0x35b4a98a,0x33740046,0x69cc0d27}},	//   _গান্, убер, ңгер, ctbe, 
   {{0x7d1ca98b,0x466800f0,0xa3ac01f9,0x613c00ef}},	//   nkss, трум_, कळं_, bīli, 
   {{0x7984a98c,0x7d1ca98d,0x681800b8,0x533000c7}},	//   _huhw, ikss, _cādā, аҵат, 
   {{0x8c1c008d,0x7984a98e,0xd68400db,0xb2a80014}},	//   וודי, _kuhw, _шумп, رُبم_, 
   {{0x66800b43,0x7984047e,0xc3040133,0x00000000}},	//   _ایمل, _juhw, شبوو, --, 
   {{0x7984a98f,0x2fcc0a40,0x6b80011c,0x7bcc0194}},	//   _muhw, tteg_, _èogg, _oqau, 
   {{0x7bcc0218,0xef180022,0x53a000db,0x69cc5380}},	//   _nqau, емп_, _ئۅتك, ztbe, 
   {{0x2fcca990,0x7d1c0373,0xaf0462d9,0x00000000}},	//   rteg_, ekss, упол, --, 
   {{0x2fcca991,0x7e6401e4,0x5184a992,0x613c00e2}},	//   steg_, _ŝipr, _руза, zīli, 
   {{0x2d90005f,0xccf8872a,0xc104004b,0xd7d804ce}},	//   īze_, тқи_, _پوهي, _ngワ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9500038f,0x7984a993,0x69cc3468,0x7d1c017a}},	//   _ཚོའི_, _buhw, ttbe, akss, 
   {{0x7de407c0,0x00000000,0x00000000,0x00000000}},	//   _نسيم, --, --, --, 
   {{0x7984019f,0x7d1ca994,0xf8b000f1,0x28740166}},	//   _duhw, ckss, يکټ_, гызр, 
   {{0x69cca995,0xc05402d3,0xa7840f47,0xa69416a4}},	// [d7e0] stbe, _ምትሕል, اشرو, греј, 
   {{0x613c005f,0x69cc343a,0x27f00076,0x68180171}},	//   rīli, ptbe, rvyn_, _rādā, 
   {{0x96d403a5,0x7984a996,0x3958003e,0x613ca997}},	//   ыстә, _guhw, _fkss_, sīli, 
   {{0x569016c3,0x64a40124,0x291c0f40,0xb54400c7}},	//   _ҳаёт, уада, ītas_, аҧса_, 
   {{0xbd2c04ac,0x291ca998,0x00000000,0x00000000}},	//   וואָ, ūtas_, --, --, 
   {{0xc4480133,0x6818002b,0x00000000,0x00000000}},	//   _ییان_, _vādā, --, --, 
   {{0x6aa8000f,0x7d1c002d,0xb35401d5,0x9254569f}},	//   _ôffu, ykss, جیلا_, лашт_, 
   {{0x68180a30,0x7538012d,0xdec40023,0x14202abf}},	//   _tādā, ciwz, ጽዓን_, рдәм, 
   {{0xa3ac03f3,0x753401c6,0xa44400f3,0x00000000}},	//   _किट_, _тэрх, _снад, --, 
   {{0xd1c80092,0x00000000,0x00000000,0x00000000}},	//   በረች_, --, --, --, 
   {{0xdef80166,0x5754010f,0x216801a9,0x00000000}},	//   _җыл_, רביע_, _зижи_, --, 
   {{0x798400ca,0x9bc42401,0x8ed40214,0x41340092}},	//   _ruhw, лёгк, پذیر_, ኮሙኒኬ, 
   {{0x7d1ca999,0xd12c9cdf,0x00000000,0x00000000}},	//   rkss, _عمه_, --, --, 
   {{0x3cec09a8,0x39580051,0x00000000,0x00000000}},	//   žev_, _skss_, --, --, 
   {{0x5a380020,0xf2340020,0xc3000154,0x00000000}},	//   _አድራሻ, _እንደሌ, ্সপি_, --, 
   {{0xc984a99a,0xfb8816c3,0x0fc00131,0x0dc467b5}},	//   сури, _ироқ_, _тйән, _суши_, 
   {{0x7bcc6018,0x26c801ee,0x3734036b,0x00000000}},	// [d7f0] _uqau, _bcbo_, анаё, --, 
   {{0x291c044e,0x247c044e,0x79847d58,0x16480166}},	//   ëtar_, _እሱራት_, _tuhw, нчеп_, 
   {{0x39581730,0x00000000,0x00000000,0x00000000}},	//   _tkss_, --, --, --, 
   {{0x54a404fb,0x00000000,0x00000000,0x00000000}},	//   احاف, --, --, --, 
   {{0xd838009d,0x00000000,0x00000000,0x00000000}},	//   _чэн_, --, --, --, 
   {{0x71b4034b,0x67b80375,0x317c0210,0x00000000}},	//   ащих, _במשק, _siwz_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2bb40f4a,0x00000000,0x00000000,0x00000000}},	//   _अटला, --, --, --, 
   {{0x7e6401e4,0x1fa40022,0x00000000,0x00000000}},	//   _ŝipp, акыи_, --, --, 
   {{0x80a800cc,0xcdc001a9,0xa44002f2,0xbebc002b}},	//   _গাণ্, баоқ, _بێهو, bhīm, 
   {{0xed44a99b,0x8024036b,0x81d4014b,0x00000000}},	//   иноп, لریم, _гохх, --, 
   {{0x2b5801fa,0x2d5004d4,0x3074a99c,0x00000000}},	//   _skpc_, láez_, _кулс, --, 
   {{0xa09804ac,0x6b6401a9,0x00000000,0x00000000}},	//   _סיסט, икма, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa9a407d6,0x00000000,0x00000000,0x00000000}},	//   рибд, --, --, --, 
   {{0x68442ba5,0xdca00131,0xe8f800a7,0xd1d40023}},	//   анба, _даъи, ълб_, _ኮነት_, 
  
   {{0x6d440921,0x7cc400cf,0x38040107,0xebe4a99d}},	// [d800] mnka, _ازىم, ботҳ, _топп, 
   {{0xd1c8044e,0x6b940472,0x00000000,0x00000000}},	//   በረት_, _ityg, --, --, 
   {{0x97749bce,0x6d44a887,0xe4a40354,0x1a980677}},	//   рттә, onka, арло, _שיטע, 
   {{0x69dca99e,0xaad070bb,0x00000000,0x00000000}},	//   _ippe, द्रक, --, --, 
   {{0x2900a257,0x4420a99f,0x9cd40302,0x54b40a4a}},	//   _inka_, ái_, שונה_, ргія_, 
   {{0x934058f0,0x21cc00ac,0xa594034b,0x27340131}},	//   онче, _məhv_, _вращ, _ئىسس, 
   {{0x4420a9a0,0x78b00a87,0x64a4014b,0x00000000}},	//   ši_, _ókvæ, _ваба, --, 
   {{0x6d44a9a1,0x90940395,0x00000000,0x00000000}},	//   jnka, авът_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d44a9a2,0x6560a9a3,0x00000000,0x00000000}},	//   enka, lloh, --, --, 
   {{0x6560a9a4,0x6b940124,0x6d200d0a,0xa114a9a5}},	//   oloh, _atyg, मसंग_, _پوشت, 
   {{0x6560a9a6,0x00000000,0x00000000,0x00000000}},	//   nloh, --, --, --, 
   {{0x21240343,0x557400df,0x00000000,0x00000000}},	//   _iloh_, יעטן_, --, --, 
   {{0x2900013b,0x6560a9a7,0x8e342ab4,0x6d44a9a8}},	//   _anka_, hloh, اسیر_, anka, 
   {{0x6d440218,0xd1c80023,0x3eac00e5,0x00000000}},	//   bnka, በረቶ_, madt_, --, 
   {{0x7b180ffb,0x6b940334,0xd7f8520c,0x26cc00db}},	//   _aìut, _ftyg, куз_, òfon_, 
   {{0x69dc092e,0xdd90005e,0x656002fb,0xe79497d1}},	// [d810] _eppe, _уақы, dloh, مالک, 
   {{0x2900a9a9,0x656006c8,0x61f80857,0x27e4067c}},	//   _enka_, eloh, _ortl, çona_, 
   {{0xd5a001b9,0x65600112,0x58840024,0xd7c40133}},	//   زلشی, floh, _выга, اوڕه_, 
   {{0xfebc02f5,0x6aa8000f,0x45840212,0x656035c0}},	//   অভিধ, _ôffr, ігів, gloh, 
   {{0x61f8a9aa,0x3eaca9ab,0x78aca9ac,0x00000000}},	//   _artl, kadt_, maav, --, 
   {{0x78aca9ad,0x6560166a,0x2124a9ae,0x69dc7c1d}},	//   laav, aloh, _aloh_, _yppe, 
   {{0x349447c1,0x6d44a9af,0x656000e4,0x290001e3}},	//   _габр, ynka, bloh, _ynka_, 
   {{0x78aca9b0,0x212400ad,0x656017ce,0xefc8020f}},	//   naav, _cloh_, cloh, глил_, 
   {{0x78ac20ac,0x61f86282,0xa1540063,0xe2541954}},	//   iaav, _ertl, љању_, _ልዕልና, 
   {{0xeb98723c,0x6d447d85,0x3eac00e5,0x00000000}},	//   һим_, wnka, gadt_, --, 
   {{0x78aca9b1,0x6b94a9b2,0x21cc00ac,0x21240112}},	//   kaav, _styg, _səhv_, _floh_, 
   {{0x6d444702,0x78aca9b3,0x82642732,0x00000000}},	//   unka, jaav, _بهمن, --, 
   {{0x6d44a9b4,0x1c4034be,0x3eac0327,0x78ac0171}},	//   rnka, зням, badt_, daav, 
   {{0x6e940597,0x65600313,0x6d440083,0xa2d84a76}},	//   _الغا, zloh, snka, प्प्, 
   {{0x656051e2,0x78ac0607,0xed5800ee,0xaa480395}},	//   yloh, faav, _йок_, упва_, 
   {{0x78aca9b5,0x2ee4002f,0x00000000,0x00000000}},	//   gaav, lelf_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [d820] --, --, --, --, 
   {{0x6560a9b6,0x00000000,0x00000000,0x00000000}},	//   wloh, --, --, --, 
   {{0x6560a9b7,0x69dca9b8,0x78ac0337,0x2d8000e5}},	//   tloh, _uppe, baav, _éhes_, 
   {{0x29002878,0x6aac002f,0x00000000,0x00000000}},	//   _unka_, labf, --, --, 
   {{0x6560a9b9,0x23d42e01,0xecc40210,0x00000000}},	//   rloh, сцер, _वाईफ, --, 
   {{0x25a8007b,0x212402f0,0x6560005b,0x6aac0112}},	//   _مدري_, _sloh_, sloh, nabf, 
   {{0x3ce80316,0x2ee4017a,0xd1b40f11,0xe7f400c5}},	//   _जसले_, delf_, مايا_, ँटवा_, 
   {{0x673c01f5,0x00000000,0x00000000,0x00000000}},	//   lipj, --, --, --, 
   {{0x3eaca9ba,0xb2440032,0x4f240023,0x00000000}},	//   tadt_, ймәһ, _ስለዝር, --, 
   {{0x673c0054,0xf1a819bc,0x78ac04ba,0xbdb41f5a}},	//   nipj, _چانه_, zaav, обој, 
   {{0xf1a804d3,0x3eac00dd,0x78aca9bb,0x975808a8}},	//   _نانه_, radt_, yaav, רדיט, 
   {{0x394c0010,0xdb200248,0x00000000,0x00000000}},	//   česk_, _òrún, --, --, 
   {{0x78aca9bc,0x673ca9bd,0xdb0c00ae,0x420800cd}},	//   vaav, kipj, lscé, _वपुः_, 
   {{0x29300020,0x673c000f,0x78ac0337,0x26cc00db}},	//   _አብዛኛ, jipj, waav, òfol_, 
   {{0x78aca9be,0x8d744144,0xdb0c007b,0x00000000}},	//   taav, تایا, nscé, --, 
   {{0xdb0c00ae,0x00000000,0x00000000,0x00000000}},	//   iscé, --, --, --, 
   {{0x78aca9bf,0x6aac0165,0xdb0c0332,0x387c0142}},	// [d830] raav, babf, hscé, äwr_, 
   {{0x78aca9c0,0xaaa892c1,0x00000000,0x00000000}},	//   saav, करणक, --, --, 
   {{0xdfc400b2,0x78ac023a,0x21cc06be,0x00000000}},	//   _ڪي_, paav, _məhs_, --, 
   {{0x2ee40936,0x78ac20ac,0xf3f81cc9,0x98c4a9c1}},	//   zelf_, qaav, инеш_, _усол, 
   {{0xdfc43432,0x42b804a2,0xd2b4a9c2,0xd1c80023}},	//   _تي_, ڭنىڭ_, йқаш_, በየት_, 
   {{0xdd8415fa,0xa3a822e3,0x65ac06d6,0x39482602}},	//   _يو_, _खबर_, ṱhah, lnas_, 
   {{0x3494a9c3,0x3948a9c4,0xd4980e92,0x31940171}},	//   _мавр, onas_, _брз_, _oāze_, 
   {{0x3948a9c5,0x2ee4257c,0x256c0419,0xd7600345}},	//   nnas_, welf_, týle_, _بۆڕی, 
   {{0x3948a9c6,0x7528014b,0x21cc00ac,0x93c40356}},	//   inas_, _ilez, _bəhs_, frăţ, 
   {{0x7528a9c7,0x849402d3,0x6f1800d8,0x3948a9c8}},	//   _hlez, ልድልን_, рцис_, hnas_, 
   {{0xf1dc2699,0x3948a9c9,0x7528a9ca,0x80a800bd}},	//   _महिन, knas_, _klez, _গার্, 
   {{0xed580d4b,0x394800c8,0x2ee4a9cb,0x5108010a}},	//   ром_, jnas_, self_, _сĕмĕ, 
   {{0x752800ec,0xc1789124,0x93c4054e,0x3948a9cc}},	//   _mlez, _اصلا_, brăţ, dnas_, 
   {{0xf1dc1bd6,0x3948a9cd,0x7528009a,0xada4a9ce}},	//   _महान, enas_, _llez, _дакл, 
   {{0x2bb400af,0xe8e4031c,0xe9380f14,0x39480477}},	//   _अटका, _སྒུག, ачај_, fnas_, 
   {{0x3948a9cf,0x752801f2,0x698002e3,0x6aac0112}},	//   gnas_, _nlez, _ọgbụ, sabf, 
   {{0xd940a9d0,0x673c0327,0xe7380798,0x00000000}},	// [d840] фети, tipj, аеа_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa968a9d1,0x673c0054,0x3948a9d2,0x7528a9d3}},	//   _вина_, ripj, bnas_, _blez, 
   {{0x673c0054,0x6aa8012d,0x661c0210,0x00000000}},	//   sipj, _क़ुर, rypk, --, 
   {{0x661ca9d4,0x9390020c,0x68f40064,0x00000000}},	//   sypk, وجوا, mdyd, --, 
   {{0x7528a9d5,0xd36c16cb,0x673c0023,0x68f471d4}},	//   _elez, نهن_, qipj, ldyd, 
   {{0x35c401d5,0x68f40042,0x12a400db,0x00000000}},	//   _нарҳ, odyd, زگلى_, --, 
   {{0x7528a9d6,0x68f4a9d7,0x67340034,0x291004ce}},	//   _glez, ndyd, żają, njya_, 
   {{0x93c80050,0xd0041677,0x68f40368,0x93c40356}},	//   _نالہ_, жење_, idyd, trăţ, 
   {{0x39482109,0x75289ae3,0xdb0c0332,0x00000000}},	//   znas_, _zlez, pscé, --, 
   {{0x3948a9d8,0x13cc0349,0x68f40153,0x00000000}},	//   ynas_, _িনয়, kdyd, --, 
   {{0x3948a9d9,0x2d500135,0x3cf4000d,0x00000000}},	//   xnas_, eġeb_, इयें_, --, 
   {{0x0c84a3f7,0x39480c86,0x68f403cb,0xf08827dc}},	//   дырм, vnas_, ddyd, _ائمه_, 
   {{0x4f54a9da,0xd00c158b,0x68f40142,0x00000000}},	//   _وجود_, _جله_, edyd, --, 
   {{0x3a2405a4,0xd1bc02d3,0xbebc02b5,0x3948a9db}},	//   álp_, _ዶባት_, whīw, tnas_, 
   {{0xdc28a9dc,0x3948a9dd,0xa2d800dc,0x00000000}},	//   _نسخه_, unas_, प्त्, --, 
   {{0x394860ab,0x8d749a12,0xd874a9de,0x657806af}},	// [d850] rnas_, _تاوا, زارب, _éthy, 
   {{0x613ca9df,0x7528a9e0,0x3948a9e1,0x8f9802e4}},	//   kūlo, _slez, snas_, יימי, 
   {{0x7528a9e2,0xd0102158,0x95c8372a,0x3948a9e3}},	//   _plez, িনয়_, руза_, pnas_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x310800dc,0x7528013a,0x4908146b,0xdcf80205}},	//   वासः_, _vlez, हारो_, nstı, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x752801f7,0x3cf40034,0x34945a5e,0x93a80c4f}},	//   _ulez, इयों_, _хаар, _نائف_, 
   {{0x60044566,0xc0c80114,0x00000000,0x00000000}},	//   зным_, цује_, --, --, 
   {{0x91f400c6,0x5184a9e4,0x00000000,0x00000000}},	//   _وأضا, _дуда, --, --, 
   {{0x98c80034,0x68f400a9,0xad240131,0xfe740137}},	//   िलाए, ydyd, كىدى, мүш_, 
   {{0xebe4667a,0x30146c9a,0x00000000,0x00000000}},	//   помп, _ндер, --, --, 
   {{0xa1103bd6,0x60c40d12,0x00000000,0x00000000}},	//   _سووت, ókme, --, --, 
   {{0x699400d6,0xeb341dc8,0x2078010f,0x68f40042}},	//   зрах, سىزد, _פאסא, wdyd, 
   {{0xdebc0116,0x00000000,0x00000000,0x00000000}},	//   _ﻣﯘﺧﺒ, --, --, --, 
   {{0x5fc0028a,0x29045f34,0xa3e4012c,0x2b4803e0}},	//   _शिमल, ñoa_, यौँ_, snbc_, 
   {{0x68f40cfd,0x2b480175,0xb4a8012d,0x00000000}},	// [d860] rdyd, pnbc_, _खड़े_, --, 
   {{0x256c01ef,0x00000000,0x00000000,0x00000000}},	//   dýla_, --, --, --, 
   {{0x6e2003ac,0x569000d4,0xb5a400d4,0xcfc000eb}},	//   nylb, хаєт, дрій, ্বিন, 
   {{0x256c02d2,0x00000000,0x00000000,0x00000000}},	//   fýla_, --, --, --, 
   {{0xa3e40f44,0x25640014,0x6e2002d0,0x69e401e4}},	//   यौं_, _ہارُ, hylb, ŭreĝ, 
   {{0x6e2002d0,0xa6c801a9,0x00000000,0x00000000}},	//   kylb, shаb, --, --, 
   {{0x64a4a9e5,0xf664411a,0xe5a40835,0x00000000}},	//   _нава, _жерү, _хиби, --, 
   {{0x55b8011a,0x256c02d2,0x00000000,0x00000000}},	//   _למלו, býla_, --, --, 
   {{0xdef8a9e6,0x9cc801e0,0x4adc00cd,0x00000000}},	//   бын_, ҙына_, यभाव, --, 
   {{0x539862b9,0x62640354,0x05e0000d,0x221400f3}},	//   _לימו, _евза, _नहाब, _нфер, 
   {{0xd12c2e8d,0x00000000,0x00000000,0x00000000}},	//   _зх_, --, --, --, 
   {{0xdd4000b0,0x00000000,0x00000000,0x00000000}},	//   pōōn, --, --, --, 
   {{0x46cc044b,0x00000000,0x00000000,0x00000000}},	//   ालाह, --, --, --, 
   {{0x399401e4,0xdcf80205,0x00000000,0x00000000}},	//   _aĥsa_, rstı, --, --, 
   {{0x9cc801ec,0x00000000,0x00000000,0x00000000}},	//   _лыпа_, --, --, --, 
   {{0x203c02d3,0x00000000,0x00000000,0x00000000}},	//   _ክትሰር, --, --, --, 
   {{0x9e7000d1,0xbebc00cd,0x00000000,0x00000000}},	// [d870] _زۇڭت, bhīt, --, --, 
   {{0x3e5836d7,0x76b80046,0xdaa02a8b,0xc86401b9}},	//   _ፍራንክ, ілер_, _سەرپ, хтси, 
   {{0x25a803cb,0x0708a9e7,0x00000000,0x00000000}},	//   _cwbl_, ثيلي_, --, --, 
   {{0xa2d80b7c,0x1d9c001f,0x38c85022,0x25a803cb}},	//   प्स्, ሀብቶች_, _بادی_, _dwbl_, 
   {{0x6d5c0421,0x78bc01f5,0x3358084c,0x87e40395}},	//   ōsag, _idsv, оадэ_, _пюре, 
   {{0xc2c400c6,0xa2d00073,0x394c0010,0xd7f8014b}},	//   فيهي, _ठाण्, česu_, _куҳ_, 
   {{0x25a800a9,0x00000000,0x00000000,0x00000000}},	//   _gwbl_, --, --, --, 
   {{0x61fc01bf,0x00000000,0x00000000,0x00000000}},	//   æpla, --, --, --, 
   {{0x147402dd,0x25a80175,0xdfcc00f1,0xef10004e}},	//   _ءازج, _zwbl_, ليي_, күдө, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x78bc0427,0xace8a9e8,0xf1d001af,0x00000000}},	//   _odsv, омна_, _рөлө, --, 
   {{0xbebc00b0,0x319400ef,0x257c013a,0x00000000}},	//   whīt, _gāza_, _půli_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x78bca9e9,0x257c0118,0x6e2002d0,0x5fc00b4c}},	//   _adsv, _vůli_, pylb, _शितल, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x1864a9ea,0x9cd40a1e,0xfe080137,0x00000000}},	// [d880] дати_, _חופה_, _وقۇي_, --, 
   {{0xe5a48354,0x78bc007c,0xdb2003b2,0x6a840ce8}},	//   дижи, _edsv, _ørða, _олпа, 
   {{0x6374002d,0xd5ac00ae,0x00000000,0x00000000}},	//   lâng, لفل_, --, --, 
   {{0x64a40f89,0xa4440166,0x00000000,0x00000000}},	//   фада, мнед, --, --, 
   {{0x394ca9eb,0x00000000,0x00000000,0x00000000}},	//   čest_, --, --, --, 
   {{0xdecc044e,0xae0ca9ec,0x65c4011c,0x00000000}},	//   ኣትን_, िमान_, _обга, --, 
   {{0x91e00640,0x00000000,0x00000000,0x00000000}},	//   воје, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x1ea805d9,0x1ee800d8,0x00000000,0x00000000}},	//   يادي_, оќно_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x62981290,0x00000000,0x00000000,0x00000000}},	//   _ifto, --, --, --, 
   {{0xa0080597,0x63740428,0x63a0009f,0x602402e8}},	//   _وقال_, fâng, opon, _одеа, 
   {{0x63a0a9ed,0xa0340137,0x00000000,0x00000000}},	//   npon, _تىشت, --, --, 
   {{0x358402d3,0x63a0a9ee,0x386c025c,0x00000000}},	//   ይቶታት_, ipon, _ġer_, --, 
   {{0xb3440120,0x386c009b,0x6374054e,0xbebc00cd}},	//   liçã, _šer_, mând, bhīr, 
   {{0x637487e0,0x1b0005f5,0x97a40120,0x672c0200}},	//   lând, хүүн, држл, _albj, 
   {{0xc984a9ef,0xb3440261,0x6298a9f0,0xd1f4001f}},	// [d890] тури, niçã, _ofto, _ገፅታ_, 
   {{0x64a00220,0x63740311,0xda64a9f1,0x63a01155}},	//   қаша, nând, _يادي, dpon, 
   {{0x0574a9f2,0x0708a9f3,0x6e2c0b45,0x63a0a9f4}},	//   چاند, ظيمي_, _ƙabi, epon, 
   {{0x6298a9f5,0x0574a9f6,0xe0c003d4,0x63a0003a}},	//   _afto, ناند, ্জুন, fpon, 
   {{0x63a09969,0xc0f0044e,0xdfc43a16,0x00000000}},	//   gpon, ሃንስ_, _حي_, --, 
   {{0xb3440261,0x637407a8,0x62980175,0xdb0c067c}},	//   diçã, jând, _cfto, nscà, 
   {{0x63740356,0x00000000,0x00000000,0x00000000}},	//   dând, --, --, --, 
   {{0x6374025a,0x63a0003a,0xdb0c033f,0x3994376e}},	//   yâng, bpon, orcó, _mås_, 
   {{0x3994a9f7,0x63740798,0xaf3c0023,0x80d007b7}},	//   _lås_, fând, _ኪህልወ, _धारे, 
   {{0xee38a9f8,0x63740311,0x68e001e4,0x27e40200}},	//   зно_, gând, ĵodi, çoni_, 
   {{0x399493e0,0x6224005e,0x00000000,0x00000000}},	//   _nås_, _كوكە, --, --, 
   {{0xb34406ed,0x6374a9f9,0x50000131,0x00000000}},	//   biçã, tâng, _аҗиз, --, 
   {{0xc1040979,0xa1147b63,0x63740276,0xafe401a9}},	//   _جوني, _سقوط_, bând, _чолл, 
   {{0x643800c8,0x6374a9fa,0x59802d2e,0xab2802d5}},	//   לערנ, când, ғлуб, чога_, 
   {{0x6374a9fb,0x63a000dd,0x612c01ab,0xb9b400a7}},	//   sâng, zpon, _hùla, кстъ, 
   {{0x637400a8,0x2fcc0dd4,0x63a0a9fc,0x1d7c0092}},	//   mâne, oueg_, ypon, _ጥረቶች_, 
   {{0x63749fe9,0x63a0007c,0xc1780064,0x27e403cb}},	// [d8a0] lâne, xpon, _spėk_, ïon_, 
   {{0x3994a9fd,0xe9d82083,0x2cb006be,0x00000000}},	//   _fås_, _еко_, _heyd_, --, 
   {{0xc0f802d3,0x63a00117,0x612c01ab,0x6d44009f}},	//   _ገድሊ_, wpon, _lùla, oika, 
   {{0xdecc02d3,0x2cb00076,0x69cca9fe,0x63740311}},	//   ኣትና_, _jeyd_, mube, zând, 
   {{0x6d44022f,0x2cb00067,0x2408030d,0x00000000}},	//   iika, _meyd_, янди_, --, 
   {{0x672c01bf,0x77900133,0xdb0c0332,0x490800bc}},	//   _ulbj, _ئیلا, oscá, हाको_, 
   {{0x27f0a9ff,0xf1b807f7,0x63740356,0xdb0c0332}},	//   lwyn_, ैंगन, vând, nscá, 
   {{0x6d4432b9,0xb3440261,0xd1348c75,0x2cb00009}},	//   jika, tiçã, ехь_, _neyd_, 
   {{0x6d44aa00,0x6374aa01,0x2000aa02,0x612c08c2}},	//   dika, tând, íki_, _cùla, 
   {{0xb3440cfc,0x6d44aa03,0x612c01ab,0x6840001f}},	//   riçã, eika, _dùla, _ኮንስት, 
   {{0x6d44aa04,0x6374aa05,0xb34403b7,0xa0a44170}},	//   fika, rând, siçã, _заед, 
   {{0x6d44aa06,0x69ccaa07,0x6560409c,0x399405ac}},	//   gika, dube, nooh, _rås_, 
   {{0x8fa0aa08,0x399438aa,0x69cc0af9,0x63740356}},	//   _баче, _sås_, eube, pând, 
   {{0x6560aa09,0x69cc0f3f,0x6d44aa0a,0x27f00368}},	//   hooh, fube, aika, dwyn_, 
   {{0x6d44aa0b,0xd90c6f3f,0x27f0017a,0x4ef8011a}},	//   bika, مید_, ewyn_, _מהגו, 
   {{0xa3c000e1,0x39940450,0x2cb006be,0x7d780066}},	//   ्ढा_, _vås_, _geyd_, _تمبر_, 
   {{0x7d0caa0c,0x65600066,0x8e8000c7,0x36d4084c}},	// [d8b0] _inas, dooh, _игәе, коар, 
   {{0x69ccaa0d,0x7bdcaa0e,0x2cb0aa0f,0x195401e0}},	//   bube, mtsu, _zeyd_, фағы_, 
   {{0xceb004ac,0x69ccaa10,0x7d0caa11,0x7bdcaa12}},	//   ריע_, cube, _knas, ltsu, 
   {{0x7bdc7578,0x2cb00009,0xf9600345,0x00000000}},	//   otsu, _xeyd_, _ئۆرێ, --, 
   {{0x7bdcaa13,0x7d0c00ec,0x3d180034,0x27f00042}},	//   ntsu, _mnas, _बचने_, cwyn_, 
   {{0x6d44aa14,0x7bdc9d0d,0x32440c75,0x00000000}},	//   zika, itsu, келг, --, 
   {{0x7d0caa15,0x7bdc00af,0x6d44aa16,0x612c00a3}},	//   _onas, htsu, yika, _sùla, 
   {{0x25bc2242,0x7bdc061f,0x7d0c0337,0xafe40a15}},	//   _ætla_, ktsu, _nnas, воил, 
   {{0x6d446846,0x69ccaa17,0x3d141a2a,0x7ae401ab}},	//   vika, zube, धाने_, _obht, 
   {{0x7d0caa18,0x6d44aa19,0xd2f4066d,0x63740120}},	//   _anas, wika, _سکتا_, tâne, 
   {{0xed58aa1a,0x69cc01f0,0x7bdc0098,0x2d90000f}},	//   дон_, xube, etsu, êze_, 
   {{0x2cb00cc1,0x7bdc0b1a,0x637406ed,0x7ae40882}},	//   _qeyd_, ftsu, râne, _abht, 
   {{0x69ccaa1b,0x7bdcaa1c,0x00000000,0x00000000}},	//   wube, gtsu, --, --, 
   {{0x316caa1d,0x63740276,0x2cb0058a,0x310800cd}},	//   llez_, mânc, _weyd_, वाकः_, 
   {{0x7bdcaa1e,0x637406ed,0x8fd000d1,0x27340388}},	//   atsu, lânc, _рәқә, _hæng_, 
   {{0xdb0c0597,0xfe70158b,0x6c04aa1f,0x6d44aa20}},	//   rscá, _اده_, _азиз, qika, 
   {{0x69cc04ba,0x6d54aa21,0x63743e07,0x7bdc44b6}},	// [d8c0] sube, _ijya, nânc, ctsu, 
   {{0x69cc0393,0x9bb40302,0x27f00368,0x7d0c0034}},	//   pube, _שהיה_, rwyn_, _znas, 
   {{0x6560aa22,0xa9a4aa23,0x7d0caa24,0x69ccaa25}},	//   tooh, _шинд, _ynas, qube, 
   {{0x6844aa26,0x66e800ef,0x00000000,0x00000000}},	//   _анма, _sūkļ, --, --, 
   {{0x3204aa27,0xd8400122,0x6560aa28,0x316c0332}},	//   _arly_, ročí_, rooh, dlez_, 
   {{0x63740120,0x65600009,0x00000000,0x00000000}},	//   dânc, sooh, --, --, 
   {{0x0fc00f22,0x656000b0,0x7bdc0e78,0x316c030a}},	//   ্বোধ, pooh, ztsu, flez_, 
   {{0x316caa29,0x6d540796,0x637406ed,0x7e986646}},	//   glez_, _njya, fânc, کندر_, 
   {{0x7d0caa2a,0x638405f5,0x6374aa2b,0x7bdcaa2c}},	//   _rnas, _агаа, gânc, xtsu, 
   {{0x7d0c3e79,0x6d540796,0x21cc03be,0x7bdc01d4}},	//   _snas, _ajya, _məhz_, vtsu, 
   {{0x7d0c037e,0x316c030a,0xdb0c0129,0xeff80092}},	//   _pnas, blez_, _àdém, _ገዥው_, 
   {{0x7bdc21e3,0x7d0c01b9,0xa0a4020a,0xe044035b}},	//   ttsu, _qnas, _радд, _инеи, 
   {{0x60c0aa2d,0x101004fb,0xad2405d9,0x63740798}},	//   _idom, _نبود, ارپو, cânc, 
   {{0x7bdcaa2e,0x6d540113,0x60c00076,0xcfb4025d}},	//   rtsu, _ejya, _hdom, _ילדי_, 
   {{0x7bdcaa2f,0x2734019b,0x99647adb,0x7d0c0165}},	//   stsu, _mænd_, втал, _tnas, 
   {{0x7d0caa30,0x7bdc0bac,0x2734005c,0x20040200}},	//   _unas, ptsu, _lænd_, _kroi_, 
   {{0x60c000ec,0x6aa0aa31,0xe5140882,0x984802e8}},	// [d8d0] _mdom, _şofe, णानि_, фява_, 
   {{0xf6b40046,0xd5a02f4d,0x4734004e,0x7f48047e}},	//   اماج, للطی, анус, nidq, 
   {{0x60c0038c,0xba4800cf,0x00000000,0x00000000}},	//   _odom, _سسدۅ_, --, --, 
   {{0x60c0aa32,0x200400b0,0x26cc00db,0x00000000}},	//   _ndom, _oroi_, òfor_, --, 
   {{0xd1001f13,0xa6b0015b,0x316c0165,0x00000000}},	//   _शोषण_, _চারট, vlez_, --, 
   {{0x60c0aa33,0x63740120,0x70bcaa34,0x00000000}},	//   _adom, vânc, ोल्ल, --, 
   {{0xe7780131,0x200001a8,0x273408a5,0x00000000}},	//   _чарә_, ækin_, _sæng_, --, 
   {{0x3948aa35,0x63740261,0x0574aa36,0x316c0165}},	//   nias_, tânc, _ناقد, ulez_, 
   {{0x316caa37,0x1c04068f,0x60c0aa38,0xa5c001a8}},	//   rlez_, शिफल_, _ddom, _þórh, 
   {{0x60c0aa39,0x6374aa3a,0x20040368,0x316c01c4}},	//   _edom, rânc, _droi_, slez_, 
   {{0x2004aa3b,0x316caa3c,0x39480006,0xbfa80014}},	//   _eroi_, plez_, kias_, _یاوٕ_, 
   {{0x60c0aa3d,0x3948aa3e,0x6374042f,0x20040175}},	//   _gdom, jias_, mâna, _froi_, 
   {{0x3948aa3f,0xa924036b,0xd084005b,0x00000000}},	//   dias_, қдал, _рыжи, --, 
   {{0xdd8c15fa,0x2d90aa40,0x60c00210,0x6aa003e0}},	//   _کوي_, ízes_, _zdom, _şofb, 
   {{0x3948aa41,0x60c000c0,0x00000000,0x00000000}},	//   fias_, _ydom, --, --, 
   {{0x3948aa42,0x6d54aa43,0xd940aa44,0x00000000}},	//   gias_, _ujya, беси, --, 
   {{0xa6e4036b,0x3d1805f9,0xa8040137,0x2734005c}},	// [d8e0] лжал, _बचते_, ызал, _læne_, 
   {{0x667404fb,0x2d80045f,0x394800c5,0x06cc015b}},	//   هدار, lmke_, aias_, র্নি, 
   {{0x5ae00150,0x273403b2,0x7c6461be,0xdb2001d3}},	//   _اقپە, _rænd_, _مایل, _órán, 
   {{0x3948aa45,0x27e4aa46,0xe458661f,0x6b948e9e}},	//   cias_, çons_, нже_, _kuyg, 
   {{0x9cd40302,0x2d800010,0x24900153,0x1c04107c}},	//   רונה_, imke_, žymo_, शियल_, 
   {{0x08fc03f4,0x7c3800a2,0x00000000,0x00000000}},	//   _একটু_, _üwre, --, --, 
   {{0xf2c4aa47,0x7f480477,0x216401e5,0x00000000}},	//   рсін, vidq, лтиг, --, 
   {{0x200405be,0x80d000db,0x00000000,0x00000000}},	//   _proi_, زۅتچ, --, --, 
   {{0x273400b5,0xbf3402e8,0x203c0023,0x00000000}},	//   _tænd_, инищ, _ክትምር, --, 
   {{0x39480c86,0x2d80002d,0x6d54007f,0x142001d5}},	//   zias_, emke_, ézan, _удум, 
   {{0xdeb002dd,0x3948003a,0xe0e401b9,0xcdb401c6}},	//   _құны, yias_, _бўло, лгэц_, 
   {{0x3948aa48,0x2004aa49,0x40a83047,0x60c02630}},	//   xias_, _troi_, _شخصی_, _udom, 
   {{0x61f80165,0x20040240,0x5574008f,0x9e64009d}},	//   _hstl, _uroi_, טעטן_, _өвдд, 
   {{0x6b94aa4a,0x7f48014f,0x39480210,0x00000000}},	//   _duyg, qidq, wias_, --, 
   {{0x3948aa4b,0x3a24054e,0x00000000,0x00000000}},	//   tias_, âlp_, --, --, 
   {{0x6b940363,0x06cc015b,0x30f800dc,0x256c01a8}},	//   _fuyg, র্মি, ्ययः_, býli_, 
   {{0x6b940022,0x7d1c003e,0xb76800ec,0x21cc03e3}},	// [d8f0] _guyg, mjss, نٽرل_, _vəhy_, 
   {{0x3948aa4c,0x61f8aa4d,0x00000000,0x00000000}},	//   sias_, _ostl, --, --, 
   {{0x06cc00bd,0x7c2804e6,0x61f8002f,0x35f40395}},	//   র্ভি, äerf, _nstl, рпер, 
   {{0x4668aa4e,0xd7d800b5,0x55700aac,0x00000000}},	//   урум_, _myペ_, ёҳат, --, 
   {{0x78acaa4f,0x61f80c8c,0xc3040133,0x2d50031c}},	//   mbav, _astl, ڵبوو, wġek_, 
   {{0x06cc015b,0x2734037e,0x9f50007f,0x020401ec}},	//   র্বি, _pæne_, _èyè_, өзін, 
   {{0x38ac022e,0x3ce80118,0x00000000,0x00000000}},	//   _kоr_, _obav_, --, --, 
   {{0x3124aa50,0xd1b40451,0x203c0023,0x63740356}},	//   рдиг, ناڊا_, _ክትመር, râna, 
   {{0x61f8aa51,0x2f54aa52,0xa1540063,0x80e8010b}},	//   _estl, итос, јању_, угың_, 
   {{0x6b94062c,0x6374002d,0x7fe8007b,0x00000000}},	//   _ruyg, lânn, اريف_, --, 
   {{0xad240058,0x43840597,0x6b9401d5,0x7c28005c}},	//   لىدى, _اللق, _suyg, øern, 
   {{0xeb98aa53,0xc21c1aac,0xccf8448f,0x8234007b}},	//   ким_, _mpɔ́_, уқи_, _اركا, 
   {{0x3ce805b1,0x2d80aa54,0xf08400db,0x6b9401a9}},	//   _dbav_, rmke_, _ئداۋ, _quyg, 
   {{0x2d5008a4,0x6b940076,0x2fccaa55,0x61f803cb}},	//   kšeg_, _vuyg, mreg_, _ystl, 
   {{0x38ac022e,0x3958aa56,0x319400de,0x06cc0154}},	//   _bоr_, _bjss_, _bāzi_, র্ডি, 
   {{0xa6b000fe,0x6b9420c2,0x00000000,0x00000000}},	//   _চাইট, _tuyg, --, --, 
   {{0x7d0800e2,0x2fcc319a,0xbbe807d6,0x6adc00fe}},	// [d900] ķest, nreg_, _یریم_, য়বো, 
   {{0x78ac0083,0x7dd000e4,0x00000000,0x00000000}},	//   abav, ẽseh, --, --, 
   {{0x3f60aa57,0x2fcc0036,0x78ac01e3,0x319400ef}},	//   _uçuş_, hreg_, bbav, _fāzi_, 
   {{0x2fcc01c7,0x249005ac,0x319400de,0x19b8011a}},	//   kreg_, øym_, _gāzi_, _במטב, 
   {{0x63840323,0x7de8016b,0x4394005b,0xa3f40108}},	//   агда, _mɛsa, щалс, ряеш, 
   {{0x69cc0936,0x2fcc00cc,0xdef0010c,0x00000000}},	//   orbe, dreg_, ሃትን_, --, 
   {{0xd24c8658,0x2fcc0221,0x9f5001e1,0x00000000}},	//   ونه_, ereg_, _èyé_, --, 
   {{0x2fccaa58,0x69cc03d5,0x00000000,0x00000000}},	//   freg_, irbe, --, --, 
   {{0x2fcc7dec,0x69ccaa59,0x06cc015b,0xd0140276}},	//   greg_, hrbe, র্ণি, афэ_, 
   {{0x3ce8011c,0x78ac245e,0x69cc0427,0x5f24aa5a}},	//   _sbav_, zbav, krbe, рфиз, 
   {{0x5fc00490,0x06cc0011,0x61f803ac,0x69cc01bf}},	//   _शिकल, র্থি, _ustl, jrbe, 
   {{0xd24c02c9,0x1e9400c7,0x00000000,0x00000000}},	//   _تنم_, ырҩр, --, --, 
   {{0x69cc3a5e,0x91803baf,0x01c80154,0x00000000}},	//   erbe, _بۇيۇ, _শহিদ, --, 
   {{0x06cc0f22,0x9204005f,0x2b580356,0x30f800cd}},	//   র্তি, stāš, _cjpc_, ्यथः_, 
   {{0x9524025c,0xc1780024,0x13dc009e,0x637400e4}},	//   _རྭའི_, _upės_, ণবয়, hâno, 
   {{0x2d500989,0x0dc44a1a,0x1ad0000d,0x9cc80064}},	//   všeg_, _туши_, _ताकथ, _рыка_, 
   {{0x5884100e,0x30f800dc,0x78acaa5b,0x7c2804e6}},	// [d910] рыва, ्यतः_, rbav, äerd, 
   {{0x87d4aa5c,0x81ac03d4,0x15a80395,0x00000000}},	//   تغفا, _কটন_, въди_, --, 
   {{0x49c8013d,0x7af400e5,0x00000000,0x00000000}},	//   _куям_, mezt, --, --, 
   {{0x7af4aa5d,0x04c80472,0x00000000,0x00000000}},	//   lezt, لومي_, --, --, 
   {{0xa3b010f7,0xd838009d,0x5ec401f9,0x00000000}},	//   झील_, _рэн_, लणाऱ, --, 
   {{0x2d5008a4,0xefc802f4,0x7af48440,0x8484001f}},	//   pšeg_, қлол_, nezt, _ምናምን_, 
   {{0x6d84002b,0x2fcc04e6,0xe5000037,0x00000000}},	//   _kųat, wreg_, _रोकि_, --, 
   {{0x2fccaa5e,0x06cc015b,0x7af49b03,0x4a58011a}},	//   treg_, র্দি, hezt, ישול_, 
   {{0x2fccaa5f,0x7af401ed,0x5fa00131,0x273402d2}},	//   ureg_, kezt, كەنم, _hæna_, 
   {{0x2fccaa60,0xef18aa61,0x7af401d3,0x622400db}},	//   rreg_, умо_, jezt, _گومە, 
   {{0x82347ee5,0x02a400a8,0x7af4aa62,0x2fcc0ea0}},	//   _ورما, _фрум, dezt, sreg_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xad244d2d,0x308400c6,0x27340174,0xa0a401af}},	//   لىگى, _الشف, _læna_, _уҡығ_, 
   {{0x7af4a586,0xbf640345,0x6df8009d,0xbe480066}},	//   gezt, _ودوو, _бхис_, اشیم_, 
   {{0x69ccaa63,0x3b000327,0x7ae000a3,0x00000000}},	//   urbe, _dahq_, òlta, --, 
   {{0x3a2404f3,0xbebc0882,0xd9400209,0xaa94010b}},	//   älpa_, dhīy, песи, риңч, 
   {{0x3d145096,0xc06802d3,0x69cc00f3,0x00000000}},	// [d920] धारे_, _ምትሕግ, srbe, --, 
   {{0x2d900198,0x7af404cc,0x7c2804e6,0xd1c80092}},	//   _hiye_, cezt, äere, ሠረት_, 
   {{0x30f80a28,0x2d90aa64,0x3194005f,0xa5080a31}},	//   ्याः_, _kiye_, _kāzu_, лежа_, 
   {{0x2d90aa65,0x5a1405d0,0x2d500327,0x1e54010f}},	//   _jiye_, _הקטן_, rġew_, זשער_, 
   {{0x290003a2,0x68f4aa66,0x2d90aa67,0x2328aa68}},	//   _iaka_, meyd, _miye_, лоди_, 
   {{0x2900aa69,0xf6d410f5,0x2d904a6c,0x68f4aa6a}},	//   _haka_, _міся, _liye_, leyd, 
   {{0x2900aa6b,0x64a4aa6c,0x84c42777,0x35c416c3}},	//   _kaka_, _габа, _дәлд, _марҳ, 
   {{0x2900138f,0x68f4aa6d,0x2d90aa6e,0x7af404cc}},	//   _jaka_, neyd, _niye_, zezt, 
   {{0x2900aa6f,0x7af401ed,0x942001af,0x00000000}},	//   _maka_, yezt, _емте, --, 
   {{0x2900aa70,0x2d900ca8,0x68f41368,0x26d8003e}},	//   _laka_, _aiye_, heyd, ngpo_, 
   {{0x2d90aa71,0x68f4aa72,0x29000109,0x61442c68}},	//   _biye_, keyd, _oaka_, _лежа, 
   {{0x2900aa73,0x2d905f3a,0x68f4aa74,0x859007d2}},	//   _naka_, _ciye_, jeyd, _ﺑﺎﺯﺍ_, 
   {{0x2d900ab7,0x71641834,0x7af4aa75,0x68f4aa76}},	//   _diye_, _بالك, tezt, deyd, 
   {{0x2124aa77,0x2900aa78,0x2d9001e1,0xfaa8aa79}},	//   _hooh_, _aaka_, _eiye_, شهري_, 
   {{0x2d903142,0x68f40368,0x7af4aa7a,0x32480092}},	//   _fiye_, feyd, rezt, _እንሰጣ, 
   {{0x290003b4,0x21244562,0x7af401c6,0x68f40363}},	//   _caka_, _jooh_, sezt, geyd, 
   {{0x76b84a45,0x2900aa7b,0x212400f2,0x8c440640}},	// [d930] илар_, _daka_, _mooh_, _неће, 
   {{0x2900aa7c,0x2d900912,0x2124020b,0x06cc015b}},	//   _eaka_, _ziye_, _looh_, র্সি, 
   {{0x2900aa7d,0x68f4090e,0x2d900605,0x6374002d}},	//   _faka_, beyd, _yiye_, rânl, 
   {{0x2124aa7e,0x2d900564,0x2900aa7f,0x68f4aa80}},	//   _nooh_, _xiye_, _gaka_, ceyd, 
   {{0x582807d6,0x69c803cd,0x98040bd6,0x3ce0000d}},	//   _сўнг_, _åfer, _уянд, _काने_, 
   {{0x2900aa81,0x55b853be,0x6374002d,0xd1c8001f}},	//   _zaka_, _مطرح_, lânj, ሠረቱ_, 
   {{0x2900aa82,0x212406f2,0x74c40588,0xaa840432}},	//   _yaka_, _booh_, _мшаҧ, _inýä, 
   {{0x29000564,0xefc8447e,0x00000000,0x00000000}},	//   _xaka_, алил_, --, --, 
   {{0x2d9023ee,0xe5000dba,0x00000000,0x00000000}},	//   _riye_, _रोटि_, --, --, 
   {{0x68f4aa83,0x319400ef,0x236400f7,0x00000000}},	//   zeyd, _bāzt_, _وڭوي_, --, 
   {{0x2d90aa84,0x68f4aa85,0x60d0010e,0x4174085b}},	//   _piye_, yeyd, _şemş, _کالس, 
   {{0xac08aa86,0x30143004,0x7fb400f2,0x00000000}},	//   анма_, _мдер, _کلوچ, --, 
   {{0xeb98aa87,0x2d9000ca,0x68f4aa88,0x1c400153}},	//   риг_, _viye_, veyd, дням, 
   {{0x2900aa89,0x68f49fd3,0xd1cc02d3,0x7b8002dd}},	//   _saka_, weyd, _ባእታ_, нғыд, 
   {{0x68f45e22,0x2124011f,0x31940171,0x6a8401ec}},	//   teyd, _yooh_, _gāzt_, ілба, 
   {{0x290001e0,0x61ec014a,0x25bc09f3,0x24900024}},	//   _qaka_, _äble, _ætli_, žymi_, 
   {{0x2900aa8a,0x68f40731,0x8c8801af,0x00000000}},	// [d940] _vaka_, reyd, _ыҙма_, --, 
   {{0x2900aa8b,0x68f4aa8c,0xadec216a,0x00000000}},	//   _waka_, seyd, _जहान_, --, 
   {{0x3ce05852,0x68f4aa8d,0x80dc39bc,0xa95c010a}},	//   _कामे_, peyd, फलमे, _акнă_, 
   {{0x24080022,0x68f41e02,0x00000000,0x00000000}},	//   инеи_, qeyd, --, --, 
   {{0x06cc00bd,0x00000000,0x00000000,0x00000000}},	//   র্ষি, --, --, --, 
   {{0xe738aa8e,0x2440022e,0x00000000,0x00000000}},	//   _тег_, _jаmi_, --, --, 
   {{0x21240c3a,0x64a400f0,0x00000000,0x00000000}},	//   _pooh_, _мава, --, --, 
   {{0x06cc0154,0xc58401e0,0x15880220,0xe4d80345}},	//   র্শি, _эҫел, _ﺑﺎﺳﯩ, _خورت_, 
   {{0x46380092,0x00000000,0x00000000,0x00000000}},	//   _በሚጠራ, --, --, --, 
   {{0x2124011f,0x00000000,0x00000000,0x00000000}},	//   _wooh_, --, --, --, 
   {{0x9f500570,0xf1a80133,0x5778010f,0x00000000}},	//   _èyí_, _هانه_, שטיצ, --, 
   {{0x64400076,0x00000000,0x00000000,0x00000000}},	//   ozoi, --, --, --, 
   {{0x6440aa8f,0x88c000fe,0x3ce005dc,0x7f440023}},	//   nzoi, ইলাক, _काठे_, _ንጥፍኣ, 
   {{0x64400433,0xdb4c03e6,0xa3d03f7e,0x2d50031c}},	//   izoi, ئێد_, _विन_, wġet_, 
   {{0xd90c0502,0x9e643d93,0xbebc00e2,0x00000000}},	//   نید_, _باشن, pjīb, --, 
   {{0x81ac04c5,0x8d64009b,0x00000000,0x00000000}},	//   _কটা_, _овје, --, --, 
   {{0xd7f8036b,0xd6a857d4,0x2d500135,0x2734032e}},	// [d950] шув_, لدام_, rġet_, _vænn_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf8b005d9,0x3ebc10d1,0x06cc0154,0xf7940153}},	//   _سکر_, _levt_, র্লি, _намэ, 
   {{0x660c002f,0x588400fb,0x78bc00de,0x00000000}},	//   _erbk, _фына, _iesv, --, 
   {{0x78bc047e,0x2d50031c,0x00000000,0x00000000}},	//   _hesv, nġer_, --, --, 
   {{0x78bcaa90,0x91f400e5,0x465801f4,0x00000000}},	//   _kesv, تہاء_, _дарю_, --, 
   {{0x4a5c0a7c,0x00000000,0x00000000,0x00000000}},	//   ידוו, --, --, --, 
   {{0xe80c02e5,0x78bcaa91,0x92a40640,0x4adc5b67}},	//   सिया_, _mesv, _дјел, _बालव, 
   {{0x7528aa92,0xd3340a11,0x32a40131,0x22280014}},	//   _hoez, _بعرع, _хуаң, _گٲمی_, 
   {{0x75282165,0xe80003f3,0x78bc017a,0x38c400c0}},	//   _koez, _रैना_, _oesv, _kūrį_, 
   {{0xed581049,0xc104aa93,0xdbd4023a,0x41740c71}},	//   сом_, _يولي, kääj, _قانس, 
   {{0x752801a4,0xa098008f,0xdbd40254,0x00000000}},	//   _moez, _הינט, jääj, --, 
   {{0x94f807e4,0xade804fb,0x316c5e50,0xdee00212}},	//   _ནིའི_, _هفتم_, loez_, _зоши, 
   {{0x78bcaa94,0xdeb80375,0x6440aa95,0x00000000}},	//   _besv, _המצל, zzoi, --, 
   {{0x752806d9,0x316c005a,0x78bc0171,0xe5a400d1}},	//   _noez, noez_, _cesv, җиди, 
   {{0x78bcaa96,0xa6c80323,0xaa882580,0xd940aa97}},	// [d960] _desv, йлаа_, _گندم_, хети, 
   {{0x98a000fd,0x25a8010a,0x00000000,0x00000000}},	//   _җире, _ptbl_, --, --, 
   {{0x1a9804ac,0x65940014,0x7528282c,0x1c040490}},	//   _לייע, سجار, _boez, शिअल_, 
   {{0x63740262,0x6abc01b2,0x673c0023,0xd5ac00ec}},	//   mâni, _hepf, shpj, افن_, 
   {{0x75280582,0x316c005a,0x9a6c001f,0x8d9c0150}},	//   _doez, doez_, _በሆነው_, _ﺍﻟﺴﺕ_, 
   {{0x42541afc,0x78bc013a,0xe50401e2,0x00000000}},	//   وچار, _zesv, _ډبري, --, 
   {{0xa50806bb,0x78bc0099,0x660c01e4,0xb744009f}},	//   _лева_, _yesv, _urbk, _آئُو, 
   {{0x11d00131,0x316c005a,0x3ebc02f0,0x00000000}},	//   رتىد, goez_, _sevt_, --, 
   {{0xd00406ed,0xa6c801b9,0x4adc08a3,0xc4340345}},	//   зење_, hkаm, बलाव, _تکات, 
   {{0x75280451,0x6abc05b8,0x63a0aa98,0xe3644c87}},	//   _zoez, _nepf, mqon, _экзи, 
   {{0x6da002b5,0x316caa99,0x88d400cc,0x63a001d5}},	//   _wēan, boez_, হ্যক, lqon, 
   {{0x612c00a3,0xd654011a,0x00000000,0x00000000}},	//   _cùlt, ליית_, --, --, 
   {{0x78bcaa9a,0x63a0aa9b,0x6abc0112,0xbe3411dc}},	//   _resv, nqon, _bepf, سىڭب, 
   {{0x78bcaa9c,0xdb2007d6,0xd6d400fe,0x00000000}},	//   _sesv, روزی, _হস্প, --, 
   {{0x63740261,0x63a0aa9d,0x78bcaa9e,0xbb58037e}},	//   gâni, hqon, _pesv, treタ_, 
   {{0x63a0009a,0x78bc014f,0xd7f8004e,0x00000000}},	//   kqon, _qesv, йуз_, --, 
   {{0xb90499b6,0x78bc016d,0xd90c1680,0x2704015b}},	// [d970] _ना_, _vesv, نیگ_, রানো_, 
   {{0xfb8453e2,0xc6a4aa9f,0x6298089c,0x6abc03fa}},	//   _تدبی, ерци, _ngto, _gepf, 
   {{0x7528aaa0,0x63740261,0x78bc014f,0xdbd40108}},	//   _poez, câni, _tesv, sääj, 
   {{0x6298aaa1,0x6abc009a,0x7454aaa2,0xdbd401f4}},	//   _agto, _zepf, وپائ, pääj, 
   {{0xdfc4aaa3,0x63a00928,0x2d500fb7,0x6abcaaa4}},	//   _جي_, gqon, kšen_, _yepf, 
   {{0x752801a4,0x9f540100,0x2d500219,0x87040153}},	//   _woez, _ògèy_, jšen_, _пясе, 
   {{0x75280cf9,0x63a00194,0x316c005a,0xa3d01b87}},	//   _toez, aqon, toez_, _विथ_, 
   {{0x50a00075,0xf8dc00c5,0x6fb4027d,0xdb0c0332}},	//   رەتل, यलिय, ومعا, oscó, 
   {{0x6004467b,0x3ce017cb,0xc0c80640,0xdb0c00db}},	//   дным_, कलने_, чује_, nscó, 
   {{0x3338aaa5,0xc624015b,0x316c01c4,0xe80c5572}},	//   _بزرگ_, _যেটা_, soez_, सिता_, 
   {{0xc2c405d9,0x6abc0099,0x00000000,0x00000000}},	//   _سيني, _repf, --, --, 
   {{0x6abc0099,0x0fc40131,0xc1080209,0x212800f1}},	//   _sepf, _еқип_, _нэче_, _ويلی_, 
   {{0x6abcaaa6,0x26cc01d3,0xdb0c0210,0x00000000}},	//   _pepf, ófok_, jscó, --, 
   {{0x637406ed,0x3b9400f0,0x00000000,0x00000000}},	//   tâni, ејст, --, --, 
   {{0x6abc0099,0xad240131,0x6994aaa7,0x00000000}},	//   _vepf, _يىتى, драх, --, 
   {{0x6abc5745,0x6374aaa8,0x00000000,0x00000000}},	//   _wepf, râni, --, --, 
   {{0x6abc00d2,0x637400d8,0x63a0022e,0x9d50009a}},	// [d980] _tepf, sâni, xqon, _جنيت, 
   {{0xcab40131,0xa1440171,0x00000000,0x00000000}},	//   _سەرخ, _zeķī, --, --, 
   {{0xdb0c01e7,0xa96800d8,0x4dd800fe,0x84840240}},	//   ascó, _миоа_, _বনুৱ, _ዝሓሸን_, 
   {{0xf6540d30,0xa3d077d7,0xe7d000cf,0x00000000}},	//   хтую, _विद_, _لۅرگ, --, 
   {{0x5980063b,0xe8c80073,0xd40001f4,0x00000000}},	//   _шлюб, िणीच, вящи, --, 
   {{0x7790179e,0x63a0aaa9,0xe7180066,0x02c807b7}},	//   _میقا, rqon, _بيست_, रणेन, 
   {{0xa5640bbf,0x06840220,0x00000000,0x00000000}},	//   _قدرن, _ﺩﺍﻣﯩ, --, --, 
   {{0x63a0022e,0xc17400cf,0x00000000,0x00000000}},	//   pqon, رگات, --, --, 
   {{0xe2c80e91,0x63a01148,0x93f80210,0x00000000}},	//   _млад_, qqon, _एनएच_, --, 
   {{0x3ce0033d,0xdb0c0200,0x00000000,0x00000000}},	//   _काहे_, rpcë, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x273400b5,0x716400be,0x61e80112,0x7c280108}},	//   _bænk_, _كانك, mtfl, äero, 
   {{0x2d501696,0x61e8aaaa,0xa3b001f9,0x00000000}},	//   pšen_, ltfl, झीच_, --, 
   {{0xc4c4066d,0x7e98aaab,0x8ba4036b,0x6374002d}},	//   _ھے_, _عنبر_, тиёж, rânw, 
   {{0xc4c4aaac,0x61e803ac,0xb9840220,0x3f8caaad}},	//   _پے_, ntfl, етақ, mmdu_, 
   {{0x63740311,0x00000000,0x00000000,0x00000000}},	//   mânu, --, --, --, 
   {{0xe3bc015b,0x61e80857,0x8d745cfc,0x9e3000ec}},	// [d990] _উৎসব, htfl, _جاوا, _سوکڙ, 
   {{0x7bdcaaae,0x9f980664,0x6b40002d,0x0708027d}},	//   musu, mään_, _rôgg, ويقي_, 
   {{0x7bdcaaaf,0x7ae4aab0,0x82ec0135,0x9f98023a}},	//   lusu, _icht, _ལྡེའ, lään_, 
   {{0x61e8002f,0x15880046,0x00000000,0x00000000}},	//   dtfl, _ﺑﺎﺗﯩ, --, --, 
   {{0x7bdcaab1,0x9f98049b,0x798caab2,0x69d8026c}},	//   nusu, nään_, mmaw, àtev, 
   {{0x7bdc013c,0x363801af,0x798c00fd,0x00000000}},	//   iusu, _езгэ_, lmaw, --, 
   {{0xe294aab3,0x9f98005b,0x00000000,0x00000000}},	//   наш_, hään_, --, --, 
   {{0x9f980664,0x798caab4,0x64585f5b,0x00000000}},	//   kään_, nmaw, áciá, --, 
   {{0x7ae4aab5,0x9f9802f6,0x7bdcaab6,0x798c022f}},	//   _ocht, jään_, jusu, imaw, 
   {{0x7bdcaab7,0xdca00184,0x798c6368,0x9f98023a}},	//   dusu, ғари, hmaw, dään_, 
   {{0x06cc03f4,0x798c30b5,0x2734005c,0xe298010f}},	//   র্কি, kmaw, _sænk_, _זשער, 
   {{0x7ae4aab8,0x7bdcaab9,0xf0e80220,0x661800e5}},	//   _acht, fusu, _ءىشى_, _átke, 
   {{0x3ce00254,0x798c003e,0xc0e80023,0x00000000}},	//   _कारे_, dmaw, ማኦም_, --, 
   {{0xdfcc0592,0x798c0327,0x158807d2,0x3f640ce8}},	//   _ايو_, emaw, _ﺑﺎﺑﯩ, _үтәб, 
   {{0x6374aaba,0x7bdc0064,0xa2c008dd,0x00000000}},	//   mânt, ausu, _रजस्, --, 
   {{0x7ae4aabb,0x2734037e,0x63740120,0x2bc80058}},	//   _echt, _tænk_, lânt, _елип_, 
   {{0x7bdcaabc,0xe7380261,0x1864aabd,0x00000000}},	// [d9a0] cusu, пеа_, еати_, --, 
   {{0x6b40002d,0x798c04ba,0xbc780118,0x00000000}},	//   _bôge, amaw, íšťa, --, 
   {{0x1f340bd9,0xc8c80014,0x2d5000bc,0x3d140073}},	//   ערער_, _ٲڈرن_, yšel_, धाचे_, 
   {{0x2d5001a6,0x64a43d89,0x387c031c,0x00000000}},	//   kšem_, хада, żwra_, --, 
   {{0x3ce005f9,0x2d5009a8,0x7ae4000f,0x3204010b}},	//   कलते_, jšem_, _ycht, _asly_, 
   {{0x4908038e,0x62040276,0x00000000,0x00000000}},	//   ाएको_, ечиз, --, --, 
   {{0x3ce00e7d,0x7bdc0c3c,0xe2700137,0x17180677}},	//   _काले_, zusu, ыккө, _צולע, 
   {{0x61e8aabe,0x7bdcaabf,0x9f98023a,0x2d5000bc}},	//   rtfl, yusu, yään_, ušel_, 
   {{0x7bdc0213,0x63740356,0x00000000,0x00000000}},	//   xusu, fânt, --, --, 
   {{0x4adcaac0,0xccf4016b,0x7bdcaac1,0x9f9802f6}},	//   _बागव, _abɛ_, vusu, vään_, 
   {{0x798c0227,0xb1f400aa,0x7e9800e3,0x7bdcaac2}},	//   ymaw, _ټينګ, بندر_, wusu, 
   {{0x9f98426d,0xd00c3ef3,0x7ae4756d,0x3ce00574}},	//   tään_, _گله_, _scht, _काळे_, 
   {{0x7bdc0140,0x1ca40133,0x00000000,0x00000000}},	//   uusu, وێژی_, --, --, 
   {{0x7bdc32ff,0x60c0aac3,0xccf4013f,0x68e403ac}},	//   rusu, _heom, _ebɛ_, _ackd, 
   {{0x7bdcaac4,0x0a6805c1,0x63740b21,0x798c0263}},	//   susu, ерти_, lâns, tmaw, 
   {{0x9f98049b,0xd90c2ab4,0x798c020b,0x60c0aac5}},	//   sään_, حیح_, umaw, _jeom, 
   {{0x60c0aac6,0x7bdc0869,0x9f98023a,0x6374000f}},	// [d9b0] _meom, qusu, pään_, nâns, 
   {{0x60c0aac7,0x798c0bc9,0x7ae4aac8,0x2d5001f1}},	//   _leom, smaw, _ucht, jšej_, 
   {{0x2d5001f1,0x628c00d0,0x672caac9,0x00000000}},	//   dšej_, _úboh, _dobj, --, 
   {{0x63740a85,0x60c0aaca,0x0574aacb,0x668001b9}},	//   kâns, _neom, هاند, شیقل, 
   {{0x672c031c,0x6374002d,0x287401ee,0xa5081411}},	//   _fobj, jâns, _аҡты_, بىنە_, 
   {{0x2d5005ce,0x69d8937c,0x6374002d,0x67400014}},	//   všem_, áteg, dâns, _پێمٕ, 
   {{0x6374084c,0x7c2801c7,0x00000000,0x00000000}},	//   vânt, äerj, --, --, 
   {{0x9f4405c7,0x672c0219,0x00000000,0x00000000}},	//   _ipoù_, _zobj, --, --, 
   {{0x60c00dd4,0x6374002d,0xc0a84fca,0x5fa000d1}},	//   _deom, gâns, رايل_, لەنم, 
   {{0xee386719,0x2d5009a8,0x00000000,0x00000000}},	//   дно_, ršem_, --, --, 
   {{0x60c00618,0x7bccaacc,0x1e80aacd,0x9f8001c0}},	//   _feom, _avau, ильм, ргэд, 
   {{0xd14800c6,0x6374000f,0xc104009f,0x2d500427}},	//   _عشان_, bâns, _مومي, mšek_, 
   {{0x06cc00bd,0xafe49b4e,0x7bcc0076,0x2d500427}},	//   র্টি, _ролл, _cvau, lšek_, 
   {{0x6374002d,0x38440023,0x98a400df,0x00000000}},	//   lânr, _መመላእ, ĉiĝo_, --, 
   {{0x60c006f2,0x672c004e,0x2d500219,0x442001fb}},	//   _yeom, _robj, nšek_, ̣i_, 
   {{0x60c01709,0xa3d01025,0xe80c012c,0x621000cd}},	//   _xeom, _विल_, सिला_, थितौ_, 
   {{0x672c1727,0xdd8caace,0xa80400fd,0xab280cc9}},	// [d9c0] _pobj, _بوي_, ъзал, _жопа_, 
   {{0xc120054e,0xb89402e8,0x8cb00210,0x00000000}},	//   ăţiş, урсъ, ंडवो, --, 
   {{0xe7fc09fd,0x76480198,0x7bcc05b8,0xa69410fc}},	//   _उनका_, _ƙeya, _zvau, трај, 
   {{0x68e4035a,0x23c40014,0x6d440051,0x00000000}},	//   _uckd, ہٕچہ, nhka, --, 
   {{0x69d805a1,0x60c0aacf,0x2d5000d7,0x00000000}},	//   šted, _reom, tšej_, --, 
   {{0x60c0aad0,0x06cc0011,0xf58402f2,0x00000000}},	//   _seom, র্জি, نشۆپ, --, 
   {{0x44200262,0x60c05bae,0x6d4405b1,0x779004fb}},	//   ţi_, _peom, khka, _ایلا, 
   {{0x6374000f,0x7c2804e6,0xf04c0023,0x00000000}},	//   tâns, äerk, _ንስምም, --, 
   {{0x60c02aef,0x6d440014,0x2d500030,0x656002f0}},	//   _veom, dhka, pšej_, mnoh, 
   {{0x6374aad1,0x6d540100,0x65600419,0x00000000}},	//   râns, èzan, lnoh, --, 
   {{0x60c0aad2,0x3d94aad3,0x7bcc0076,0x6560036e}},	//   _teom, лиор, _svau, onoh, 
   {{0x3e88067c,0x6d4c0de2,0x65604e3c,0x6d5400e4}},	//   _aïtí_, _ňaar, nnoh, ézap, 
   {{0xa03400db,0x273402d2,0x656001f4,0xccc401a9}},	//   _جىشت, _hænu_, inoh, шбўй, 
   {{0x6d44207a,0xdcf80790,0x65600254,0x00000000}},	//   ahka, rptı, hnoh, --, 
   {{0x4f980302,0x656000ec,0x00000000,0x00000000}},	//   _קבוצ, knoh, --, --, 
   {{0x6d441bb7,0x3f9c02c4,0xa3d00490,0x06cc0183}},	//   chka, _hivu_, वळा_, ৰ্মি, 
   {{0x3f9caad4,0x7d0c0280,0x6560012c,0x7bcc0810}},	// [d9d0] _kivu_, _iaas, dnoh, _uvau, 
   {{0x7d0caad5,0x3f9c01f7,0x65600124,0x00000000}},	//   _haas, _jivu_, enoh, --, 
   {{0xf4d8aad6,0x0c74158b,0x935001d5,0xb5d400d8}},	//   емеш_, _مدید, یرتچ, ужеј, 
   {{0x7d0c1bce,0x2d5009a8,0x6560aad7,0x78742d4b}},	//   _jaas, všek_, gnoh, _مُجا, 
   {{0x7d0caad8,0x799c2cd9,0x61f883fb,0x78ac036e}},	//   _maas, _iisw, _aptl, mcav, 
   {{0x7d0caad9,0x78acaada,0x799c02c4,0x06cc03d4}},	//   _laas, lcav, _hisw, ৰ্বি, 
   {{0x799caadb,0x7d0c0254,0x2d500118,0x656002f0}},	//   _kisw, _oaas, ušek_, bnoh, 
   {{0x7d0caadc,0x3ce801d4,0x78acaadd,0xf0e80075}},	//   _naas, _ncav_, ncav, رىخى_, 
   {{0x799caade,0x14742a9f,0x94740244,0x00000000}},	//   _misw, _شارج, _شدرا, --, 
   {{0x799caadf,0x00000000,0x00000000,0x00000000}},	//   _lisw, --, --, --, 
   {{0x7d0caae0,0x439445fd,0x3f9caae1,0x799c0810}},	//   _baas, _тафс, _divu_, _oisw, 
   {{0x6d442113,0x7d0caae2,0x799c047e,0xc1d41945}},	//   uhka, _caas, _nisw, _төшә, 
   {{0x7d0caae3,0xdf5401c6,0xd98c0150,0x00000000}},	//   _daas, _өнцө, _ﻓﻬﺫﻩ_, --, 
   {{0x6d44aae4,0x799caae5,0x78ac0393,0x2fcc0165}},	//   shka, _aisw, ecav, mseg_, 
   {{0x7d0caae6,0x6f0002d0,0xed58aae7,0x6d44009a}},	//   _faas, melc, _пок_, phka, 
   {{0x7d0caae8,0x3f9c0e3c,0x27340162,0xaa448818}},	//   _gaas, _zivu_, _lænt_, _ەندى, 
   {{0x799caae9,0x6d540537,0x3f9c0399,0xbce800c7}},	// [d9e0] _disw, _imya, _yivu_, _ргыҧ_, 
   {{0x6f00127b,0x7d0c04ba,0x799c2ad7,0x3f400241}},	//   nelc, _zaas, _eisw, _lòun_, 
   {{0x799caaea,0x7d0caaeb,0x3a2401e6,0x6560aaec}},	//   _fisw, _yaas, älpt_, tnoh, 
   {{0x78ac3dde,0x7d0caaed,0x799caaee,0x7a4800e8}},	//   ccav, _xaas, _gisw, _wëté, 
   {{0x6560aaef,0x2fcc00d8,0xc7080022,0x320000ad}},	//   rnoh, jseg_, _иҭаз_, çhyn_, 
   {{0x6f00aaf0,0x799c0223,0x6d54003e,0x43940b7e}},	//   jelc, _zisw, _lmya, шалс, 
   {{0x6f00aaf1,0x799c0230,0x213800d2,0x6d54035b}},	//   delc, _yisw, êpho_, _omya, 
   {{0x69ccaaf2,0x3f9c049b,0x799c07a9,0x6b9c18c1}},	//   isbe, _sivu_, _xisw, _lipg, 
   {{0x7d0c1ace,0xd4640679,0x3f9caaf3,0x6f00002f}},	//   _raas, _бите_, _pivu_, felc, 
   {{0x7d0caaf4,0x69cc12ed,0x6f0002c1,0x6d54aaf5}},	//   _saas, ksbe, gelc, _amya, 
   {{0x7d0caaf6,0x3f9caaf7,0x69cc09b6,0x3ce09a28}},	//   _paas, _vivu_, jsbe, कलले_, 
   {{0x3f9c00ec,0x7d0caaf8,0xa0a4aaf9,0x00000000}},	//   _wivu_, _qaas, _садд, --, 
   {{0x6f000455,0x7d0caafa,0x69cc0373,0x3f9c014f}},	//   belc, _vaas, esbe, _tivu_, 
   {{0x7d0caafb,0x799caafc,0x6d542f99,0x69ccaafd}},	//   _waas, _sisw, _emya, fsbe, 
   {{0x7d0caafe,0x69ccaaff,0x99641f10,0x00000000}},	//   _taas, gsbe, гтал, --, 
   {{0x799cab00,0x78ac05a1,0xbc4400cf,0x00000000}},	//   _qisw, ucav, _ەرگۉ, --, 
   {{0xd6d8ab01,0x23c42435,0xb7d40372,0x7ae004cc}},	// [d9f0] ете_, रीमद, شقاب, òlts, 
   {{0x799c0223,0x69ccab02,0x6d540175,0x69d800bc}},	//   _wisw, bsbe, _zmya, átec, 
   {{0x34b401d5,0x78ac821e,0x799c0003,0xf65406ed}},	//   لماز, pcav, _tisw, јвеќ, 
   {{0xf8b010e5,0x7de8016b,0x7bdcab03,0x6f001d43}},	//   _ذکر_, _yɛsr, orsu, zelc, 
   {{0x394814d0,0xba000020,0x31140882,0x2734037e}},	//   mhas_, _ውሃ_, _दोषः_, _pænt_, 
   {{0x3948ab04,0x2fcc0fcf,0x4cc000cc,0x360408f0}},	//   lhas_, vseg_, ্লযু, _پورف, 
   {{0x7bdc0e78,0x2000510c,0x3244ab05,0x42b800d1}},	//   hrsu, çkin_, рейг, دنىڭ_, 
   {{0x3948ab06,0xb4f804ac,0x6f00ab07,0x2fccab08}},	//   nhas_, _שפּי, welc, tseg_, 
   {{0x6f00ab09,0x60600131,0x27340162,0x2fcc0165}},	//   telc, يۇمل, _tænt_, useg_, 
   {{0x2fcc0489,0x69ccab0a,0x37ac03d4,0x2d500010}},	//   rseg_, ysbe, _চিঞৰ, nšev_, 
   {{0x2fccab0b,0x7bdcab0c,0x6f00ab0d,0x3948ab0e}},	//   sseg_, ersu, relc, khas_, 
   {{0xed58ab0f,0x6b9cab10,0x00000000,0x00000000}},	//   том_, _sipg, --, --, 
   {{0x5d646a46,0x6f007664,0xc104ab11,0x69cc0112}},	//   риям_, pelc, _دوني, wsbe, 
   {{0x2ee4074d,0xfe702ea3,0x6f00016d,0x4f680166}},	//   qglf_, _کده_, qelc, _яшем_, 
   {{0x7bdc0eda,0x69cc0112,0xa6c8022e,0x5e541410}},	//   arsu, usbe, chаy, _پليس_, 
   {{0x98a061ff,0x6d542935,0x3948ab12,0x00000000}},	//   жите, _umya, ghas_, --, 
   {{0x69cc3b52,0xd9400da9,0xf8a8027d,0x88c80118}},	// [da00] ssbe, цети, ادفه_, jtěž, 
   {{0x57440640,0xdc34008f,0xa68409a0,0x6b9c03ac}},	//   азум_, _כאפט_, алзд, _uipg, 
   {{0x3948ab13,0xc3302928,0x86380092,0x7c640bce}},	//   bhas_, ۋەر_, _በሚኒስ, _نایل, 
   {{0x3948ab14,0x61ec0793,0x00000000,0x00000000}},	//   chas_, _äbli, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2d801cfd,0x68f400a9,0x29100165,0xd1ec069d}},	//   hlke_, lfyd, ldya_, ቀረቡ_, 
   {{0x6ce405f9,0xd624ab15,0xe80c3156,0x27f00363}},	//   _कांग_, _коре_, सिका_, ltyn_, 
   {{0x2910ab16,0x68f40368,0x8df00327,0x7bdcab17}},	//   ndya_, nfyd, _ཨཱཿལ, yrsu, 
   {{0x27f0ab18,0xa2e40e84,0x320805f5,0x29100099}},	//   ntyn_, _возд, вхөн_, idya_, 
   {{0xf1a803e6,0x27f00363,0x3948ab19,0x98a80055}},	//   _ڵامه_, ityn_, zhas_, _mocā_, 
   {{0x60e80022,0xd12c0451,0x27f01368,0x61440120}},	//   _амем_, _ڪمن_, htyn_, _кежа, 
   {{0x39480200,0x00000000,0x00000000,0x00000000}},	//   xhas_, --, --, --, 
   {{0xd12c01d9,0x291004ba,0xa6c8022e,0xf17401f7}},	//   _تمن_, ddya_, shаy, _اَنگ, 
   {{0xdb5801ee,0x7bdc4cab,0x00000000,0x00000000}},	//   тюм_, rrsu, --, --, 
   {{0x39483e79,0x98c40d84,0x68f413e9,0x7bdc0194}},	//   thas_, исал, ffyd, srsu, 
   {{0x3ce01b57,0x0dc40116,0x2d4002d2,0x9cb000db}},	//   _काटे_, _өләй_, _jóel_, _گۅڭت, 
   {{0x3948ab1a,0x9b680139,0x1be401b9,0xe80012eb}},	// [da10] rhas_, _ашна_, _тўйг, रौला_, 
   {{0x3948ab1b,0x5bd00490,0x7c280036,0x175c0023}},	//   shas_, तळीव, äeru, _ተረዲኡ_, 
   {{0x3948ab1c,0x2d5009a8,0x27f00363,0xae1800af}},	//   phas_, ršev_, atyn_, धियन_, 
   {{0xfd4c0055,0x00000000,0x00000000,0x00000000}},	//   _paiṇ, --, --, --, 
   {{0x3958ab1d,0xdb2001a8,0x79540014,0xf31401c6}},	//   _imss_, _þróa, _نَگا, йддэ, 
   {{0xa6dc0154,0xfd4c00b8,0xd694010a,0x00000000}},	//   ন্বয়, _vaiṇ, _кăлп, --, 
   {{0x45d405c1,0x25b80354,0xba00001f,0x2d8000cc}},	//   _морс, cppl_, _ውኃ_, ylke_, 
   {{0xe9f402dd,0x00000000,0x00000000,0x00000000}},	//   _نﺎ_, --, --, --, 
   {{0xb6400150,0x7fc80166,0x00000000,0x00000000}},	//   _ﺃﻗ_, авың_, --, --, 
   {{0x035800fd,0x7c3c01ab,0xd25800f3,0x00000000}},	//   _күчә_, dysr, _ице_, --, 
   {{0x27f0ab1e,0xad240075,0x9148022e,0x00000000}},	//   ztyn_, مىدى, _ичда_, --, 
   {{0x5184ab1f,0x27f0ab20,0x00000000,0x00000000}},	//   _туза, ytyn_, --, --, 
   {{0x814c1a4c,0x41740597,0xc17401d3,0x601043bc}},	//   _בעאַ, _بالس, _بدلت, rımç, 
   {{0x7fb412dd,0x3958009b,0x2d800131,0xd9e0000d}},	//   _بلوچ, _amss_, ﺩﯨﻜﻰ_, गढंत_, 
   {{0x27f00042,0x00000000,0x00000000,0x00000000}},	//   wtyn_, --, --, --, 
   {{0x29100099,0xeab8010b,0x27f00363,0x00000000}},	//   udya_, _өйи_, ttyn_, --, 
   {{0x2910ab21,0xf1a8033f,0x23c4033f,0x7c280221}},	// [da20] rdya_, _चूसन, _रौंद, äert, 
   {{0x27f01368,0xa6c82eac,0xa6941d39,0xb86400db}},	//   rtyn_, اوال_, бреј, زاقو, 
   {{0x27f0ab22,0xb5a8007b,0x068402dd,0x00000000}},	//   styn_, لانك_, _ﺩﺍﻗﯩ, --, 
   {{0x59b001c0,0x569002bf,0x00000000,0x00000000}},	//   _хөрс, чаєт, --, --, 
   {{0x06cc03d4,0xd4640114,0x2b200d2e,0x00000000}},	//   ৰ্ষি, бице_, माऊँ_, --, 
   {{0xf8700131,0x53300276,0x00000000,0x00000000}},	//   _غۇلج, зешт, --, --, 
   {{0x55e001a9,0x733000cf,0x00000000,0x00000000}},	//   _норб, بۉلا, --, --, 
   {{0x26c801fa,0x06cc03d4,0x5638010f,0xdb0c032e}},	//   _hebo_, ৰ্শি, _געלײ, _þjöp, 
   {{0x26c8ab23,0xa44401c0,0x8fa01d39,0x00000000}},	//   _kebo_, _унад, пање, --, 
   {{0x26c89606,0x00000000,0x00000000,0x00000000}},	//   _jebo_, --, --, --, 
   {{0xa014034c,0xd12cab24,0x26c8009f,0x2d5000bc}},	//   _گذاش, _ех_, _mebo_, yšet_, 
   {{0x26c801a2,0x2b580077,0x7c3c005b,0xf1a802f2}},	//   _lebo_, _ampc_, tysr, _ئاله_, 
   {{0x69d801f1,0xed4c01ed,0xd7a4000d,0x00000000}},	//   áten, ڑھی_, _कूंच, --, 
   {{0x26c802f8,0x3958031c,0x00000000,0x00000000}},	//   _nebo_, _smss_, --, --, 
   {{0x69d804b9,0x237c01fa,0x6b40002d,0x391400d8}},	//   šten, _mktj_, _kôgj, омвр, 
   {{0x8e80ab25,0x2d50012c,0x9cf00327,0x95c800fb}},	//   _عليه, ušet_, _ཨཡིས, ғужа_, 
   {{0x58840a8f,0x26c8123b,0x98a00408,0x00000000}},	// [da30] сыва, _bebo_, çисе, --, 
   {{0x26c80921,0x2b580077,0xdb1c005b,0x15a80166}},	//   _cebo_, _gmpc_, äväm, гъди_, 
   {{0x26c8ab26,0xdf3401fb,0x23c40825,0x00000000}},	//   _debo_, _đặt_, रीसद, --, 
   {{0x25a813b5,0x26c86835,0x04c801e2,0x3958032e}},	//   _dubl_, _eebo_, مومي_, _umss_, 
   {{0x26c8299d,0x8c1c008f,0xd83801c6,0xf79400cf}},	//   _febo_, ָווי, _сэн_, _мамэ, 
   {{0x26c8058a,0x9f4402dd,0x00000000,0x00000000}},	//   _gebo_, _ﯗﺭﻻﯞ_, --, --, 
   {{0xd6f804ce,0x7730001f,0x00000000,0x00000000}},	//   _stシ_, _በማሳደ, --, --, 
   {{0xf0a8ab27,0x13a424c5,0x456401d9,0xa3d02c2e}},	//   шкил_, _هنری_, _ٹھٔہ, _विच_, 
   {{0x26c8ab28,0xdfcc088c,0x00000000,0x00000000}},	//   _yebo_, نيي_, --, --, 
   {{0xd3443016,0xef380114,0xf7d402dd,0x00000000}},	//   _دیته_, рџић_, _ﺟﻪﻟﻪ, --, 
   {{0x02a44316,0xd04403b9,0x00000000,0x00000000}},	//   _хрум, _ələn, --, --, 
   {{0x200c023a,0xdcec0311,0x00000000,0x00000000}},	//   äjiä_, vocă, --, --, 
   {{0xad2400d1,0x00000000,0x00000000,0x00000000}},	//   مىگى, --, --, --, 
   {{0xab6400d4,0x00000000,0x00000000,0x00000000}},	//   іввл, --, --, --, 
   {{0x6e946a48,0x26c8ab29,0x2d9400cf,0x7ae0ab2a}},	//   _بلغا, _rebo_, _мөмө_, ólta, 
   {{0x6844ab2b,0x25a8ab2c,0x6f8400d1,0xaba81d39}},	//   онба, _rubl_, ﺮﯨﻐﺎ_, _квиз_, 
   {{0xa6c801c6,0x00000000,0x00000000,0x00000000}},	// [da40] илаа_, --, --, --, 
   {{0x2b5802fa,0x25a8ab2d,0x7e6400b8,0x00000000}},	//   _umpc_, _publ_, _śipi, --, 
   {{0xe4a400f7,0x39b00064,0x00000000,0x00000000}},	//   орло, _tąsa_, --, --, 
   {{0x26c8ab2e,0xa3cc01ad,0x02b40303,0x7dec00df}},	//   _webo_, _शबद_, ुर्न, רקאַ, 
   {{0x26c827be,0x00000000,0x00000000,0x00000000}},	//   _tebo_, --, --, --, 
   {{0x64440139,0x00000000,0x00000000,0x00000000}},	//   _ükim, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2d90013f,0xe3b80798,0xc0341d39,0x528000d1}},	//   _nhye_, _вба_, зниј, بلىك, 
   {{0x90940395,0x00000000,0x00000000,0x00000000}},	//   овът_, --, --, --, 
   {{0x644c03b9,0x00000000,0x00000000,0x00000000}},	//   _əbil, --, --, --, 
   {{0x69d80316,0x6b40002d,0x1718008f,0x00000000}},	//   átel, _tôgj, בויע, --, 
   {{0x2d905103,0xd24c2ad5,0x1278010f,0x5114003b}},	//   _chye_, _جنم_, _דאבע, _моєю_, 
   {{0x69d8ab2f,0x4fc000d1,0xffb40304,0x00000000}},	//   štel, _قەيە, _эйлэ, --, 
   {{0xada401f1,0x98a8012d,0xf7d40220,0x00000000}},	//   _skúš, _mocą_, _ﺟﻪﻛﻪ, --, 
   {{0x81bc0171,0x8eb00145,0x00000000,0x00000000}},	//   _drēg, _تەپت, --, --, 
   {{0x1b000137,0xca7800db,0x00000000,0x00000000}},	//   чүүн, تەپت_, --, --, 
   {{0xc9840bd6,0xf1d0012c,0x98a8012d,0x00000000}},	// [da50] фури, _सबभन, _nocą_, --, 
   {{0xf53800d0,0x6d54007f,0x2fc800a2,0xbb54104c}},	//   _piťo_, èzav, _çage_, _رنجب, 
   {{0x6374aa01,0xccf4013f,0xba18009f,0x00000000}},	//   bânz, _mmɛn_, _ايجا_, --, 
   {{0x45240014,0x00000000,0x00000000,0x00000000}},	//   ِروِ, --, --, --, 
   {{0x37c401af,0x00000000,0x00000000,0x00000000}},	//   _хәбб, --, --, --, 
   {{0x21241c06,0x7944001f,0x1dd80490,0xd378ab30}},	//   _anoh_, _የለበት, _भिंत, шче_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x21244dff,0x00000000,0x00000000,0x00000000}},	//   _enoh_, --, --, --, 
   {{0x2d900076,0xa2c000fd,0x00000000,0x00000000}},	//   _phye_, _чәчк, --, --, 
   {{0x6f840131,0xf4900023,0xe8a801f9,0x00000000}},	//   ﺮﯨﻜﺎ_, _ዝሓስብ_, _कलेच, --, 
   {{0xeb9884cc,0x31b000dd,0x506400c6,0x00000000}},	//   йим_, _ház_, _بطاق, --, 
   {{0xa024008c,0xe454008f,0x69d80010,0xa09805d0}},	//   stöð, לירט_, štem, _פיסט, 
   {{0x2d90ab31,0x81bc0171,0x27340725,0x00000000}},	//   _thye_, _grēd, ۋىرس, --, 
   {{0x0d7401c8,0x00000000,0x00000000,0x00000000}},	//   _تختگ, --, --, --, 
   {{0x945c03f9,0x63742776,0x6b400051,0x31b000e5}},	// [da60] _fāɗ, rânz, _lôgi, _láz_, 
   {{0x6d44049b,0xec680116,0x040400cc,0x00000000}},	//   lkka, _врүк_, লিমী_, --, 
   {{0x6d44005b,0x6374054e,0x69240153,0xcd380092}},	//   okka, pânz, _емна, _ይከናወ, 
   {{0x6d44ab32,0xdecc0092,0x386c013a,0x00000000}},	//   nkka, ጣትና_, _žere_, --, 
   {{0x6d44ab33,0x8cd4012d,0xd464009b,0x00000000}},	//   ikka, _भजनो, пице_, --, 
   {{0x21240649,0x6d440037,0x00000000,0x00000000}},	//   _snoh_, hkka, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d4c0083,0x9c8400bc,0x6d4401f5,0x06e400cc}},	//   _ŋaan, _jičí, jkka, _নঘটি, 
   {{0xef9001b9,0x6560340f,0xa2e401f0,0x00000000}},	//   چیند, mioh, _ноад, --, 
   {{0x6560ab34,0x6d440a55,0x291c016b,0x61b000db}},	//   lioh, ekka, _ɔtaa_, _كەتا, 
   {{0x69d8242b,0xce6465cb,0x31b001ed,0x00000000}},	//   štej, зряд_, _gáz_, --, 
   {{0xd8400232,0x6d440194,0x9c8402fb,0x2ff80014}},	//   ničí_, gkka, _ničí, _ژونگ_, 
   {{0x61e801a8,0x6440ab35,0x00000000,0x00000000}},	//   lufl, nyoi, --, --, 
   {{0x6d44ab36,0x8fa0ab37,0x6440004c,0x656031cf}},	//   akka, _заче, iyoi, hioh, 
   {{0x61e8ab38,0xd90c94f1,0x6440020c,0x90780023}},	//   nufl, هید_, hyoi, _ርትዓዊ_, 
   {{0x9c8002fb,0x656000b5,0x00000000,0x00000000}},	//   áčsk, jioh, --, --, 
   {{0x36d40314,0xd194011a,0xbb74033a,0x00000000}},	// [da70] дозр, לכלי_, _огиј, --, 
   {{0x9e4002fb,0x00000000,0x00000000,0x00000000}},	//   žďuj, --, --, --, 
   {{0x9c8400d7,0xceb0011a,0x00000000,0x00000000}},	//   _fičí, תיע_, --, --, 
   {{0x6560107d,0x31b00518,0xe1b400b5,0xb50400db}},	//   gioh, _ráz_, dコ_, بۉرۅ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x07a402d5,0x2324ab39,0x82340271,0x89f80345}},	//   _паўн, доши_, کرها, _بعیز_, 
   {{0xe2945d25,0x6d444098,0x94a805d9,0xf5380306}},	//   маш_, ykka, _هاءِ_, _toť_, 
   {{0xc0c4001f,0x3494ab3a,0x64400036,0x31b001d3}},	//   ቸጋሪ_, _жабр, byoi, _váz_, 
   {{0x61e8ab3b,0x7528ab3c,0xb86c001f,0xc3580131}},	//   aufl, _inez, _በመጪው_, تكۈچ_, 
   {{0x27e41ebd,0xe8a839a1,0x81bc005f,0x6e441318}},	//   šong_, _कल्च, _drēb, деоз, 
   {{0x75281050,0x61e80009,0x06cc03d4,0xb4f800df}},	//   _knez, cufl, ৰ্কি, ֿפֿי, 
   {{0x6d44a9b5,0x41740137,0x69d8ab3d,0x90e40220}},	//   ukka, _كانس, štek, _ءسان, 
   {{0x6d44049b,0x316c054e,0x4c04004b,0x00000000}},	//   rkka, mnez_, رېدل, --, 
   {{0x6d443400,0xa098011a,0x42980023,0x00000000}},	//   skka, _וינט, _ቅንኣት_, --, 
   {{0x7528ab3e,0x316cab3f,0x6d540100,0x00000000}},	//   _onez, onez_, èzas, --, 
   {{0x316cab40,0xeb9801d5,0x00000000,0x00000000}},	//   nnez_, сиҳ_, --, --, 
   {{0x316cab41,0xfa3400f1,0x656001f4,0x6d9c0ca8}},	// [da80] inez_, ورېد, vioh, _ṣawa, 
   {{0x752807e4,0x644000ec,0xcc88004b,0x316c0165}},	//   _anez, vyoi, _ونډه_, hnez_, 
   {{0xd6cc2264,0x6560ab42,0x66e40107,0x00000000}},	//   شقن_, tioh, зоҷа, --, 
   {{0xf5680150,0x00000000,0x00000000,0x00000000}},	//   пшік_, --, --, --, 
   {{0x3204089c,0x29000009,0x65600821,0x7988025c}},	//   _aply_, _ibka_, rioh, ċewt, 
   {{0x7528ab43,0x316c01c0,0x6560ab44,0x61e81427}},	//   _enez, enez_, sioh, tufl, 
   {{0x291c013f,0x24f4ab45,0x11d00ae5,0x2fc80327}},	//   _ɔtan_, _очар, پتىد, _ħaga_, 
   {{0x316cab46,0x61e8ab47,0x7528ab48,0x9f98005b}},	//   gnez_, rufl, _gnez, näön_, 
   {{0xd00403b7,0x61e8ab49,0x81bc00ef,0x00000000}},	//   дење_, sufl, _brēc, --, 
   {{0x316c0489,0x00000000,0x00000000,0x00000000}},	//   anez_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x316c0369,0x00000000,0x00000000,0x00000000}},	//   cnez_, --, --, --, 
   {{0xdb20ab4a,0xdef8ab4b,0x00000000,0x00000000}},	//   پوزی, _дый_, --, --, 
   {{0x29000198,0x2fc800ee,0xd00cab4c,0x81bc0171}},	//   _abka_, _çaga_, _خله_, _grēc, 
   {{0xaa94008e,0x00000000,0x00000000,0x00000000}},	//   егрә, --, --, --, 
   {{0xd90c2c6c,0xa26c01f3,0x00000000,0x00000000}},	//   جیح_, እመናን_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [da90] --, --, --, --, 
   {{0x752891aa,0x316c0007,0x20040334,0x566416ac}},	//   _snez, znez_, _mpoi_, وداف, 
   {{0x7bcc004c,0x44bc02e3,0x74b84623,0x00000000}},	//   _hwau, _ịsụ_, пулс_, --, 
   {{0x88b002ea,0x7bcc05b8,0x200400e4,0x6a980375}},	//   ndɛl, _kwau, _opoi_, _משתנ, 
   {{0xd408ab4d,0x04580131,0xe4d40345,0x00000000}},	//   تتام_, ۋجۇت_, رووت_, --, 
   {{0x7bcc0bd7,0xc2c80116,0x00000000,0x00000000}},	//   _mwau, وبىل_, --, --, 
   {{0x200400a8,0x4b380302,0x50a00131,0x394800c0}},	//   _apoi_, ורגל_, ھەتل, okas_, 
   {{0x3948ab4e,0x69d806ed,0x7528ab4f,0xa2801272}},	//   nkas_, átei, _unez, دیمو, 
   {{0x316cab50,0x60046feb,0x3948ab51,0x3f40180f}},	//   rnez_, еным_, ikas_, _nòus_, 
   {{0x320000ad,0x39480254,0xe8680092,0x670001f9}},	//   çhys_, hkas_, _በዘጠኝ_, र्पक_, 
   {{0x3948ab52,0x7bcc91a1,0x20040112,0x61800092}},	//   kkas_, _awau, _epoi_, ዕከላዊ_, 
   {{0x3074074d,0x61ec0fac,0xebe4009d,0x00000000}},	//   _пулс, _åbla, номп, --, 
   {{0xdbc80428,0x3948ab53,0x92c00eac,0xbc1810da}},	//   _bòñe, dkas_, ্লী_, мірі_, 
   {{0x7bcc0204,0x6a84ab54,0xeb3421ef,0x3948ab55}},	//   _dwau, елга, رىزد, ekas_, 
   {{0xdb0c00c6,0x38b40521,0x3948ab56,0x79440092}},	//   ádái, _ụra_, fkas_, _የገቡት, 
   {{0x3948ab57,0x386c01fa,0x02ac00bc,0xacc800db}},	//   gkas_, _žera_, _चल्न, _эгиз_, 
   {{0x2d80ab58,0x7bccab59,0x2aec216a,0x00000000}},	// [daa0] moke_, _gwau, _जाऊँ_, --, 
   {{0x66740075,0x3948ab5a,0x00000000,0x00000000}},	//   ىدار, akas_, --, --, 
   {{0x7bcc1682,0x3948ab5b,0x20d00073,0x00000000}},	//   _zwau, bkas_, सरमध, --, 
   {{0x3a24019b,0x3948ab5c,0x2d80ab5d,0x29000548}},	//   ælpe_, ckas_, noke_, _ubka_, 
   {{0x9cd40375,0x2d8001c4,0x7790006c,0xe364010b}},	//   תונה_, ioke_, _چیقا, нкди, 
   {{0x2d80ab5e,0x76440022,0x00000000,0x00000000}},	//   hoke_, byhy, --, --, 
   {{0x2d80ab5f,0x3fac09bd,0x15400139,0xf2c40150}},	//   koke_, _গবেষ, _өерм, тсін, 
   {{0x1594215c,0x80bc01f9,0x00000000,0x00000000}},	//   _كەلگ_, ैरें, --, --, 
   {{0x7ae00162,0x50b406c2,0x00000000,0x00000000}},	//   óltk, رديد_, --, --, 
   {{0x4424ab60,0x7bcc004c,0x39480024,0x56700023}},	//   _irm_, _rwau, zkas_, _ጸላእቱ_, 
   {{0x3f400ba1,0x7bcc01f7,0x2d80ab61,0x91e00395}},	//   _sòus_, _swau, foke_, _бохе, 
   {{0x2d80ab62,0x442401e3,0xbfc80220,0x06cc03d4}},	//   goke_, _krm_, _قاتە_, ৰ্চি, 
   {{0x3948ab63,0x57dc00e1,0xa9c40014,0x06f0000d}},	//   vkas_, _फटेह, ێزٲو, _चांव_, 
   {{0x4424ab64,0x67000882,0x3f40067c,0xdb2001a9}},	//   _mrm_, र्मक_, _vòus_, دوسی, 
   {{0x2d80ab65,0x3948ab66,0xfd38007b,0x764402d0}},	//   boke_, tkas_, _يكتب_, xyhy, 
   {{0x44241549,0x69d8ab67,0x394802d5,0x7bcc0810}},	//   _orm_, âtea, ukas_, _twau, 
   {{0x394813e1,0xb8d84284,0x44240a49,0x7bcc52ae}},	// [dab0] rkas_, _चल_, _nrm_, _uwau, 
   {{0x3948ab68,0x7d1cab69,0x2aec068f,0x48140006}},	//   skas_, ldss, _जाएँ_, ымус, 
   {{0x35f439fb,0x2d4000d8,0x4424ab6a,0x3f8c005a}},	//   тпер, _góes_, _arm_, ildu_, 
   {{0x7d1cab6b,0x442400f3,0x76440209,0x4668ab6c}},	//   ndss, _brm_, ryhy, хрум_, 
   {{0x798cab6d,0x0574ab6e,0x7d1cab6f,0x61f8013d}},	//   mlaw, دالد, idss, _aqtl, 
   {{0x798c0986,0x2d80ab70,0x76440124,0x2c2000cd}},	//   llaw, zoke_, pyhy, मितं_, 
   {{0x69d80fb7,0x52d0045e,0x798c009a,0x2d80ab71}},	//   štev, _সাদৃ, olaw, yoke_, 
   {{0x798cab72,0x4424030d,0x7d1c1cf1,0x2d7400b0}},	//   nlaw, _frm_, jdss, kāea_, 
   {{0x2d80ab73,0x4424ab74,0x798c0280,0xb4dc0490}},	//   voke_, _grm_, ilaw, ढणी_, 
   {{0x798cab75,0xad240075,0x3f8c03f2,0x81bc00de}},	//   hlaw, چىدى, gldu_, _irēn, 
   {{0xf1d0ab76,0x2d80ab77,0xad2404a9,0x3f400ba1}},	//   _төлө, toke_, نىدى, _pòur_, 
   {{0x3f8c0ffb,0x60600137,0x00000000,0x00000000}},	//   aldu_, دۇۇل, --, --, 
   {{0x2d80ab78,0x798cab79,0x00000000,0x00000000}},	//   roke_, dlaw, --, --, 
   {{0x2d80ab7a,0x78bc01bf,0x205400df,0x00000000}},	//   soke_, _afsv, _שיסל_, --, 
   {{0x2d80ab7b,0x798c00a9,0x2d94ab7c,0xda600d08}},	//   poke_, flaw, _ирис, аври, 
   {{0x798cab7d,0x2d800107,0x3878022e,0x2c2000dc}},	//   glaw, qoke_, _bxsr_, मिदं_, 
   {{0x1864ab7e,0xe7a81881,0x78b001ef,0x00000000}},	// [dac0] вати_, двал_, _škvá, --, 
   {{0x442404cc,0x798c0083,0x00000000,0x00000000}},	//   _rrm_, alaw, --, --, 
   {{0x88b0043b,0x798c0198,0x81bc00e2,0x2a340006}},	//   ndɛk, blaw, _arēn, _рэпр, 
   {{0x4424ab7f,0x92c002f5,0x798c1d01,0x00000000}},	//   _prm_, ্লো_, claw, --, 
   {{0x3f8c2833,0x00000000,0x00000000,0x00000000}},	//   yldu_, --, --, --, 
   {{0x442400c0,0x00000000,0x00000000,0x00000000}},	//   _vrm_, --, --, --, 
   {{0xd24cab80,0xbebc00da,0x672c01e6,0xf54405f5}},	//   ينه_, ldīg, _inbj, _өдрү, 
   {{0x65b80055,0x15401887,0x651402f2,0x00000000}},	//   _gįha, _кесм, _جورئ, --, 
   {{0x6700228d,0x6f00003a,0x4424ab81,0x4fd002d5}},	//   र्थक_, fflc, _urm_, ажыт, 
   {{0x3f40068c,0xbebc005f,0x798c0399,0x00000000}},	//   _còup_, idīg, zlaw, --, 
   {{0x13d42f04,0x798c0724,0x00000000,0x00000000}},	//   _সময়, ylaw, --, --, 
   {{0x67001d8a,0x798cab82,0xe7e00d79,0x7d1c01f5}},	//   र्तक_, xlaw, _पिंप, udss, 
   {{0x7d1c035a,0x8c64ab83,0x69d80129,0x20100248}},	//   rdss, атрд, âten, _èyi_, 
   {{0x61e8ab84,0x05d80037,0x00000000,0x00000000}},	//   orfl, _ढबढब, --, --, 
   {{0x798cab85,0x0a68033a,0xbebc00ef,0x00000000}},	//   tlaw, врти_, edīg, --, 
   {{0x672c05ac,0x798cab86,0x9c44020a,0x2e580953}},	//   _anbj, ulaw, _ахол, _яшчэ_, 
   {{0x58840948,0x779800f0,0xdce800ef,0x00000000}},	// [dad0] тыва, екар_, _žiķe, --, 
   {{0xd6d80261,0x61e8035a,0x7b140108,0x00000000}},	//   ќта_, krfl, _сдох, --, 
   {{0xdfc406d0,0x6b80007b,0x7bdc4b68,0x798cab87}},	//   _گي_, _íoga, lssu, plaw, 
   {{0x451802bf,0x798c00fd,0xb4dc0073,0x98b000de}},	//   кція_, qlaw, ढणे_, ādēt_, 
   {{0xdfc4ab88,0x69d86b48,0x61e8ab89,0xd6d8005b}},	//   _دي_, štet, erfl, _отв_, 
   {{0x7bdcab8a,0xf5d401b9,0x38c80244,0x00000000}},	//   issu, _مصرگ, _تاگی_, --, 
   {{0x45d477c6,0xc6a41677,0x42b80131,0x44f400f7}},	//   _восс, _врти, خنىڭ_, اسۅز, 
   {{0xe3c40220,0x7bdc005c,0xe45000c7,0xe1f40166}},	//   _әртү, kssu, ркәы, угъ_, 
   {{0xef84030d,0x00000000,0x00000000,0x00000000}},	//   ллип, --, --, --, 
   {{0xee3898cc,0x7bdc12e8,0x00000000,0x00000000}},	//   ено_, dssu, --, --, 
   {{0x7bdc22a9,0x88b80183,0x6da400a8,0x877c08a8}},	//   essu, জৰিক, лиоа, ואזי, 
   {{0xc104004b,0xdfcc1699,0x00000000,0x00000000}},	//   _نومي, _کيو_, --, --, 
   {{0xafe407d6,0x7bdcab8b,0x69dc003a,0xc104a3a9}},	//   _солл, gssu, _svpe, _خوني, 
   {{0x8f6401d3,0xbf3401e2,0x00000000,0x00000000}},	//   _جلتے_, _پرهغ, --, --, 
   {{0x7bdc0eda,0xb9b400a7,0x6e200175,0x98b00205}},	//   assu, истъ, qvlb, çeğe_, 
   {{0xfe701416,0x00000000,0x00000000,0x00000000}},	//   _بده_, --, --, --, 
   {{0xd6f804ce,0x7c6400aa,0x9f480798,0xdca00117}},	// [dae0] _auケ_, _پايل, _àmão_, _лаъи, 
   {{0xbebc00e2,0x18a001ec,0x69d800e5,0x00000000}},	//   rdīg, саум, átes, --, 
   {{0x24e800c7,0xaa440f89,0x97740139,0x00000000}},	//   емеи_, _сенл, уттә, --, 
   {{0xd5ac65dd,0x61e80334,0x4ca80154,0x00000000}},	//   سفه_, vrfl, _ক্যু, --, 
   {{0x2910ab8c,0xc3302e56,0x684401d5,0x393401c4}},	//   meya_, يەر_, _ёнга, _тээс, 
   {{0x68f400ee,0x63b001ef,0x00000000,0x00000000}},	//   lgyd, _čeně, --, --, 
   {{0x26d8ab8d,0xa6a800db,0x1c18033f,0x61e8035a}},	//   mapo_, _ساسق_, _पैनल_, urfl, 
   {{0x64a4ab8e,0x26d8ab8f,0x58f8025c,0x7bdcab90}},	//   _баба, lapo_, ྒུགས_, yssu, 
   {{0xdef8ab91,0x00000000,0x00000000,0x00000000}},	//   нын_, --, --, --, 
   {{0x26d8ab92,0xade4032c,0x2910ab93,0xe12400d1}},	//   napo_, _किशन_, heya_, _әмди, 
   {{0x2910ab94,0x81bc005f,0x69d8004a,0x42a40092}},	//   keya_, _krēm, âtel, ገናኘት_, 
   {{0x26d8ab95,0xc0c404a9,0x7bdc0112,0xade4012d}},	//   hapo_, _тәки, tssu, _किरन_, 
   {{0x7bdcab96,0x2910ab97,0x07140927,0x68f401bf}},	//   ussu, deya_, ड़ाव_, dgyd, 
   {{0x909400d6,0x7bdcab98,0x68f40076,0x26d80588}},	//   _світ_, rssu, egyd, japo_, 
   {{0x26d8ab99,0x29100099,0x27f0817f,0x3d94013d}},	//   dapo_, feya_, euyn_, _кикр, 
   {{0x2910ab9a,0x68f40072,0x6b800162,0x00000000}},	//   geya_, ggyd, _íogn, --, 
   {{0x8d74168d,0xbebc005f,0x26d806d9,0xb8fc00e1}},	// [daf0] _داوا, mdīb, fapo_, _ड़_, 
   {{0xbebc0029,0x26d8ab9b,0x4c9c011a,0x00000000}},	//   ldīb, gapo_, _אבחו, --, 
   {{0x69d807f5,0x0c74598b,0x2910ab9c,0xcf9004ac}},	//   šter, _ندید, beya_, צטע_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x26d800b2,0xf8681541,0x386c0221,0x00000000}},	//   bapo_, _شمسي_, _äer_, --, 
   {{0x26d8ab9d,0xb5c801d9,0xd76048a7,0x00000000}},	//   capo_, _لوسم_, _طنزی, --, 
   {{0x81c40131,0x6d540200,0x862401af,0x6d9408a5}},	//   مەلۇ, ëzak, _льте, dáan, 
   {{0xb144ab9e,0x81bc00e2,0xe9e40419,0x00000000}},	//   рнил, _krēj, _šúkl_, --, 
   {{0x947400aa,0x670039de,0x673001d3,0x00000000}},	//   _صدرا, र्वक_, _újjá, --, 
   {{0x6f642bd4,0x5f40104b,0x2910006f,0x939400c6}},	//   рвоз, قچىل, zeya_, _إجرا, 
   {{0xed5822f7,0x2910ab9f,0xb114729a,0x62240150}},	//   вон_, yeya_, _вмеш, _پونە, 
   {{0x26d8055a,0x6aa0010f,0x799c03ac,0x29100009}},	//   zapo_, _ŝofo, _nhsw, xeya_, 
   {{0x26d8aba0,0x802400f1,0x00000000,0x00000000}},	//   yapo_, _هروم, --, --, 
   {{0x2910aba1,0xeb987d98,0x62880083,0x68f40042}},	//   weya_, тиг_, ŋooŋ, wgyd, 
   {{0x29101aac,0xa9680c56,0x26d805b8,0x8fd00116}},	//   teya_, вива_, vapo_, _тәқә, 
   {{0x26d8aba2,0x7ae40200,0x00000000,0x00000000}},	//   wapo_, _edht, --, --, 
   {{0x2910aba3,0x6d542b93,0x799c02d0,0xa764aba4}},	// [db00] reya_, _ilya, _dhsw, акад, 
   {{0x2910aba5,0x66e4aba6,0xed900020,0xa6c801d5}},	//   seya_, рожа, _ማህበር_, jjаt, 
   {{0x26d8aba7,0x67001ab2,0x6d54aba8,0x2910aba9}},	//   rapo_, र्षक_, _klya, peya_, 
   {{0x2910abaa,0x26d8abab,0x00000000,0x00000000}},	//   qeya_, sapo_, --, --, 
   {{0x7790136e,0x00000000,0x00000000,0x00000000}},	//   _کیلا, --, --, --, 
   {{0x6700abac,0x6d5402d0,0xf3c80345,0xaab41cba}},	//   र्शक_, _llya, ابنه_, ंशिक, 
   {{0x6d54066d,0x4cdc045e,0x55e0abad,0x00000000}},	//   _olya, _ভানু, _морб, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa2c8098a,0xe3a808da,0x2c1401f9,0x00000000}},	//   _स्थ्, _акад_, _पैलू_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x30382352,0x2174abae,0x6d542d75,0x660c05b1}},	//   نتیک_, _кудр, _blya, _jpbk, 
   {{0xa2c87a18,0x629809a8,0x5d645bc6,0x01ac0150}},	//   _स्त्, _izto, ртоз, _ﺷﺎﻣﻨ, 
   {{0x60c06e0e,0x38bc0248,0x040400cc,0x11380a7c}},	//   _ifom, _láró_, লিকী_, _שתדל, 
   {{0x6d54abaf,0x7868022e,0xabb40116,0x8fa0011c}},	//   _elya, _lоvc, сарә, _даче, 
   {{0xdd98abb0,0x671805d7,0x8f0400cf,0x4e9002dd}},	//   _иши_, नजनक_, _ئيىق_, _وشىر, 
   {{0x9804004e,0x00000000,0x00000000,0x00000000}},	//   иязд, --, --, --, 
   {{0xd6d803b7,0x7ae00579,0x60c00134,0x69d8abb1}},	// [db10] вте_, ólts, _mfom, štep, 
   {{0x629801c0,0xd6a82363,0x473400cf,0x6b9c0051}},	//   _ozto, ندام_, онус, _ghpg, 
   {{0x85b827a1,0x799c5479,0x6d5400a2,0x00000000}},	//   لانس_, _thsw, _ylya, --, 
   {{0x38bc01e1,0x3cf8010a,0x74340150,0x00000000}},	//   _dáró_, ngsv_, йнеф, --, 
   {{0xf4083ece,0x6298abb2,0x1164136e,0x73c4abb3}},	//   ايتى_, _azto, یلتی_, сәбе, 
   {{0x60c0abb4,0x934005a9,0x81bc00e2,0x2fc80139}},	//   _afom, تىتۇ, _grēk, _çagi_, 
   {{0xd1b8001f,0x324402dd,0x920400e2,0x95c80114}},	//   ደፊት_, сейг, ksāš, _југа_, 
   {{0x0fe40075,0xfbbc00eb,0x22285cfc,0x680800ef}},	//   алиқ_, _অবনত, ازوی_, bēdā, 
   {{0x629801c4,0x38bc00e5,0x00000000,0x00000000}},	//   _ezto, _záró_, --, --, 
   {{0x60c02959,0x031800f7,0x00000000,0x00000000}},	//   _efom, _ۅتۅت_, --, --, 
   {{0x4cdc0729,0xab28abb5,0x6d54abb6,0x00000000}},	//   _ভাবু, қова_, _plya, --, 
   {{0x8234007b,0x00000000,0x00000000,0x00000000}},	//   _بركا, --, --, --, 
   {{0x316cabb7,0xafc40dd8,0xd060013f,0x6da40116}},	//   miez_, _ايتى, _ɑsɛd, _һика, 
   {{0xc0c40201,0x316cabb8,0xaa44abb9,0x00000000}},	//   ቸዋል_, liez_, бегл, --, 
   {{0x6da4abba,0x00000000,0x00000000,0x00000000}},	//   _лика, --, --, --, 
   {{0x316cabbb,0x6d54abbc,0xeb9801a9,0x00000000}},	//   niez_, _ulya, тиҳ_, --, 
   {{0xd940a99b,0xa6e400f7,0x5fb8010f,0x38bc01e1}},	// [db20] чети, йжал, ָצענ, _sáró_, 
   {{0x316cabbd,0x16840133,0x00000000,0x00000000}},	//   hiez_, ڕانێ, --, --, 
   {{0xdd8c4fe0,0x316c01c4,0xa968074d,0x7c641888}},	//   _زوی_, kiez_, _бина_, _هایل, 
   {{0xed900020,0x95e800dd,0x758802bf,0xf608004b}},	//   _ማኅበር_, ابلہ_, асів_, شتمه_, 
   {{0x2a6c01fa,0x316c8f78,0x62981f6f,0xae180037}},	//   _žfbh_, diez_, _szto, _फैसन_, 
   {{0x64a4abbe,0xdc980677,0x00000000,0x00000000}},	//   _ғаза, ניסל, --, --, 
   {{0x316c20ef,0x9660abbf,0x2164036b,0xdef802dd}},	//   fiez_, _екре, йтиг, қып_, 
   {{0x316cabc0,0x00000000,0x00000000,0x00000000}},	//   giez_, --, --, --, 
   {{0xa2e4010b,0x00000000,0x00000000,0x00000000}},	//   _гозд, --, --, --, 
   {{0xb56001e1,0xf1d8012a,0x25a4abc1,0x95200133}},	//   _lẹ̀k, _यौवन, lmol_, _وکۆم, 
   {{0xd1b8001f,0x6298022e,0xaabc00bc,0x00000000}},	//   ደፊቱ_, _uzto, ्डनक, --, 
   {{0x316cabc2,0x25a4abc3,0x846402d3,0xdcec00e2}},	//   ciez_, nmol_, ጻጸርን_, vocē, 
   {{0x3cf801e3,0x00000000,0x00000000,0x00000000}},	//   rgsv_, --, --, --, 
   {{0x1398008f,0x9f60005b,0x25a404e6,0x00000000}},	//   ָבלע, övän_, hmol_, --, 
   {{0x9e700132,0x00000000,0x00000000,0x00000000}},	//   _رۇحت, --, --, --, 
   {{0x4e3000f7,0x00000000,0x00000000,0x00000000}},	//   _رعىز, --, --, --, 
   {{0x225800d7,0x00000000,0x00000000,0x00000000}},	// [db30] ĺpky_, --, --, --, 
   {{0x7c2cabc4,0x316c005a,0x25a40221,0x9cb00014}},	//   _irar, ziez_, emol_, _وۅگت, 
   {{0x0c78a03c,0x7c2000e2,0x316c0129,0x8f98011a}},	//   _نصیب_, ālru, yiez_, ניבי, 
   {{0x7c2c2aad,0x7d0c031c,0xb92800db,0x25a40c6a}},	//   _krar, _jbas, _ئزدۅ_, gmol_, 
   {{0xc0d40201,0x7d0cabc5,0x316c8682,0x5edc0f22}},	//   _የስራ_, _mbas, viez_, _মানে, 
   {{0x7c2c06be,0x12c00022,0x87040064,0x00000000}},	//   _mrar, чикҟ, _нясе, --, 
   {{0x9268abc6,0x71580209,0x3ce800c5,0x316c06af}},	//   ырда_, ирис_, _odav_, tiez_, 
   {{0x7c2cabc7,0x7d0c01a9,0x395800ef,0x75c40064}},	//   _orar, _nbas, _jlss_, _vėzd, 
   {{0x7c2c0280,0x316cabc8,0x35a40116,0x00000000}},	//   _nrar, riez_, _гаңг, --, 
   {{0x7d0c8a12,0x3ce80139,0x316cabbd,0x82f806c2}},	//   _abas, _adav_, siez_, _هرمز_, 
   {{0x7d0cabc9,0xae180034,0x316c004a,0x6da4abca}},	//   _bbas, _फैशन_, piez_, жина, 
   {{0x7d0c2ab0,0x7c2cabcb,0x00000000,0x00000000}},	//   _cbas, _brar, --, --, 
   {{0x7c2c0005,0xd02002dd,0xeb98022e,0x00000000}},	//   _crar, _ءوتۋ, иим_, --, 
   {{0x7d0c007d,0x2fcc0098,0x7c2cabcc,0x25a4022e}},	//   _ebas, mpeg_, _drar, zmol_, 
   {{0x7c2cabcd,0xed58abce,0x25a4abcf,0x7d0c0175}},	//   _erar, _вой_, ymol_, _fbas, 
   {{0x7c2c0abf,0x7d0c05db,0xe8c8abd0,0xbebc00de}},	//   _frar, _gbas, ргал_, ndīn, 
   {{0x7c2c04ce,0x4ca80154,0x18b0013d,0x69cc28fe}},	// [db40] _grar, _ক্রু, дәрр, धीजी, 
   {{0x3dc018a6,0xa6941d39,0xd1bc0092,0x00000000}},	//   _ōiwi_, ореј, ቶሬት_, --, 
   {{0xe618abd1,0x39580327,0x25a40158,0xdb2002d2}},	//   рде_, _flss_, tmol_, _þráa, 
   {{0xa50809f7,0x69ccabd2,0x38c80117,0x00000000}},	//   реда_, mpbe, _гуён_, --, 
   {{0x7c2c0327,0x00000000,0x00000000,0x00000000}},	//   _xrar, --, --, --, 
   {{0x25a4abd3,0xe5c88b4d,0x69cc0d27,0x5330abd4}},	//   smol_, _نظره_, opbe, дешт, 
   {{0x27f000a2,0x00000000,0x00000000,0x00000000}},	//   lryn_, --, --, --, 
   {{0x27f000ad,0x00000000,0x00000000,0x00000000}},	//   oryn_, --, --, --, 
   {{0x2000025a,0x2b5801f2,0x98a8054e,0x27f00072}},	//   îki_, _olpc_, _incă_, nryn_, 
   {{0x386c0209,0x7d0c07de,0x7c2c005a,0x27f01368}},	//   _ýere_, _sbas, _rrar, iryn_, 
   {{0x7d0cabd5,0x7cf401a9,0x2fcc05c7,0x13cc0154}},	//   _pbas, _bоrа, apeg_, _রিয়, 
   {{0x7c2cabd6,0xfcc4013d,0x00000000,0x00000000}},	//   _prar, чәкм, --, --, 
   {{0x91803baf,0x98b000da,0x69cc0b4f,0xd12cabd7}},	//   _تۇيۇ, ādīt_, epbe, _جمن_, 
   {{0x7c2c02d3,0x395801e7,0x386c06be,0x27f0abd8}},	//   _vrar, _slss_, _ümrə_, dryn_, 
   {{0x3f8cabd9,0x27f040f0,0x7d0cabda,0x29c800db}},	//   modu_, eryn_, _tbas, йттү_, 
   {{0x7c2cabdb,0x7d0cabdc,0x3f8c005f,0x27f003cb}},	//   _trar, _ubas, lodu_, fryn_, 
   {{0x81bc0171,0xe77800c7,0x00000000,0x00000000}},	// [db50] _grēv, әахә_, --, --, 
   {{0x3f8c0003,0x89d80014,0xc7e800db,0x00000000}},	//   nodu_, _ڈوٝر_, زىمن_, --, 
   {{0x27f01368,0x35b400ee,0x00000000,0x00000000}},	//   aryn_, чбер, --, --, 
   {{0x3f8c54b1,0x39580395,0x27f00042,0x3a20036e}},	//   hodu_, _ulss_, bryn_, _ishp_, 
   {{0x3f8cabdd,0xc324015b,0xd6d80108,0xd83873f6}},	//   kodu_, পানি_, _втб_, _тэн_, 
   {{0x798c06c8,0x67b80375,0x76400129,0x3f8cabde}},	//   loaw, _למשק, _àlyo, jodu_, 
   {{0x3f8cabdf,0xa2c80073,0x00000000,0x00000000}},	//   dodu_, सुध्, --, --, 
   {{0xa28056a7,0x6aa80213,0x8a7c011a,0x823406c2}},	//   رینو, ülfə, יאות, برها, 
   {{0x85542ab4,0x8504006c,0xe0d4005b,0x2fcc030a}},	//   _زیور_, _توقن, чвы_, upeg_, 
   {{0x3f8cabe0,0xb8dc0867,0x798c06c8,0xa2c80490}},	//   godu_, _ཅུ_, hoaw, सुद्, 
   {{0xc7b4abe1,0x490c07f7,0x27f00076,0x00000000}},	//   ובץ_, ड्डो_, zryn_, --, 
   {{0x27f0abe2,0x7cf4022e,0x2fcc33ec,0x9f9400c7}},	//   yryn_, _qоrа, ppeg_, _ҭышә, 
   {{0x3f8cabe3,0x8f80023b,0xc0d40b82,0x00000000}},	//   bodu_, _оқил, ረኩም_, --, 
   {{0x8ccc0254,0xaa440798,0x00000000,0x00000000}},	//   _थ्रो, пегл, --, --, 
   {{0x8d4801c0,0x27f0062c,0x00000000,0x00000000}},	//   _дүнг_, wryn_, --, --, 
   {{0xd940abe4,0x6ea401d9,0x69cc01a4,0x27f0abe5}},	//   неси, _وچھہ_, rpbe, tryn_, 
   {{0x27e47f70,0xb6d400b5,0x5edc00cc,0x27f00076}},	// [db60] éon_, _webｻ_, _মাতে, uryn_, 
   {{0xd7ec2ab5,0x27f0abe6,0x69cc007c,0x81bc00de}},	//   اكل_, rryn_, ppbe, _krēt, 
   {{0x9f40abe7,0x386c013a,0x6d9c0055,0x00000000}},	//   éké_, _žert_, _ṣaya, --, 
   {{0x3f8cabe8,0x35680212,0x9c8001a6,0x798c02d0}},	//   zodu_, орін_, šček, coaw, 
   {{0x332401a9,0x3f8c05d1,0x64a4abe9,0x00000000}},	//   _balx_, yodu_, чада, --, 
   {{0x3a20030d,0x3324003a,0x59d00b6d,0xaabc0303}},	//   _yshp_, _calx_, धीकर, ्डिक, 
   {{0x3f8cabea,0x00000000,0x00000000,0x00000000}},	//   vodu_, --, --, --, 
   {{0x3f8cabeb,0x2d901418,0xc0340063,0xa0200254}},	//   wodu_, _nkye_, дниј, _öökr, 
   {{0x3324003a,0x3f8cabec,0x1b20015b,0xe458009b}},	//   _falx_, todu_, মাতে_, _ужа_, 
   {{0x3eb8abed,0x2d90013f,0xe29000c6,0x798c0810}},	//   ørt_, _akye_, _كذا_, zoaw, 
   {{0x2d900334,0x290000d7,0x00000000,0x00000000}},	//   _bkye_, _ocka_, --, --, 
   {{0x75c40024,0x00000000,0x00000000,0x00000000}},	//   _jėza, --, --, --, 
   {{0xe0a80183,0x3f8c0115,0xdb0400e5,0x00000000}},	//   _গ্ৰন, podu_, lmjé, --, 
   {{0x29000113,0x2d900337,0xade40c4c,0x31a002f0}},	//   _acka_, _ekye_, _किचन_, róze_, 
   {{0x798c00b5,0x8f9800d9,0x00000000,0x00000000}},	//   toaw, _היגי, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x81bc005f,0x212401ab,0x798c00b0,0xb8d43156}},	// [db70] _krēs, _maoh_, roaw, _छः_, 
   {{0x7bccabee,0x62940213,0x9ba02ba5,0x29000064}},	//   _itau, əyov, _سەزى, _ecka_, 
   {{0xc884013d,0x5f0c00dc,0x00000000,0x00000000}},	//   _alğı_, त्य्_, --, --, 
   {{0x7f940137,0x260c00e1,0x2124045a,0xd838009d}},	//   màqu, _ठहरी_, _naoh_, _лэг_, 
   {{0x533000c7,0xa50802de,0x00000000,0x00000000}},	//   нҵат, تىنە_, --, --, 
   {{0x7bccabef,0x3324abf0,0xdb20007c,0x00000000}},	//   _mtau, _qalx_, _örän, --, 
   {{0x6fd409d9,0xd564abf1,0xc0d4001f,0xc8840139}},	//   _मौजू, _етап, _የድሮ_, _elğı_, 
   {{0x7bccabf2,0x9dd8013f,0x6ad800bc,0xf07400e5}},	//   _otau, _ɛkɔɔ_, _बज्र, ویاں_, 
   {{0x7bcc0190,0x85041370,0x3324022e,0x6b8c022e}},	//   _ntau, _سولن, _talx_, yobg, 
   {{0x2d90abf3,0xbebc00da,0x3594063f,0x00000000}},	//   _skye_, ldīj, _ụsụụ_, --, 
   {{0x7bccabf4,0x6b8c036b,0x9f8001c6,0x92a800fe}},	//   _atau, vobg, тгэд, _ক্ৰ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6b8c01d5,0x1c40003b,0x00000000,0x00000000}},	//   tobg, вням, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7bccabf5,0xb0d09506,0x6b8c01a9,0x00000000}},	//   _etau, _सभाग, robg, --, 
   {{0x7bcc3495,0x61ec04ce,0x6b8c036b,0x2490012d}},	//   _ftau, _æble, sobg, żymi_, 
   {{0x66e44d9b,0x798000d2,0xa8040408,0x9c200064}},	// [db80] доза, élwa, ьзал, _адыд, 
   {{0x6d4405a1,0x6674abf6,0xfca80014,0x18a00150}},	//   ljka, ودار, _ژایو_, таум, 
   {{0x5b540375,0x00000000,0x00000000,0x00000000}},	//   _חייב_, --, --, --, 
   {{0x6d440f03,0x660c000d,0x94d0009f,0x00000000}},	//   njka, _सहीए_, نيمش, --, 
   {{0x5edc00bd,0x277402d5,0x78dc0208,0x00000000}},	//   _মাসে, _жывё, _énbạ, --, 
   {{0x68380240,0x00000000,0x00000000,0x00000000}},	//   _ከመሓድ, --, --, --, 
   {{0xa3b80451,0x644c03e3,0x2718012d,0x00000000}},	//   _ڀائر_, _əbiy, नजीर_, --, 
   {{0xfe780323,0x64a4abf7,0x00000000,0x00000000}},	//   үүд_, _жаба, --, --, 
   {{0x656027cc,0x429c01ec,0x00000000,0x00000000}},	//   mhoh, _ﯞﯨﻨﭽ, --, --, 
   {{0x65600564,0x5edc03d4,0x00000000,0x00000000}},	//   lhoh, _মাহে, --, --, 
   {{0x7bccabf8,0xf1a8004b,0xdc10015b,0xce64abf9}},	//   _stau, _ځانه_, িয়াস_, дряд_, 
   {{0x7f9400db,0x65600108,0x00000000,0x00000000}},	//   vàqu, nhoh, --, --, 
   {{0x80ac0154,0x00000000,0x00000000,0x00000000}},	//   _ট্র্, --, --, --, 
   {{0x4424abfa,0x31a002f0,0x00000000,0x00000000}},	//   _msm_, móza_, --, --, 
   {{0x6560abfb,0x44240263,0xdcec00e2,0x31a00306}},	//   khoh, _lsm_, nocī, lóza_, 
   {{0xa6380201,0x442400bc,0x7cd8abfc,0x0d842cc8}},	//   _የሚያደ, _osm_, _эмир_, _үлән, 
   {{0x5ba40228,0x44240fac,0x6560abfd,0x31a002f0}},	// [db90] _ороз, _nsm_, dhoh, nóza_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb9043fa7,0xf404015b,0x44240f85,0xaabc00bc}},	//   _না_, োয়ার_, _asm_, ्डरक, 
   {{0x7d1cabfe,0xc6a4188b,0x588400f7,0xbebc00e2}},	//   ness, труи, _жыга, udīj, 
   {{0x4424abff,0xc7c4ac00,0x0574007b,0x00000000}},	//   _csm_, _асси, خالد, --, 
   {{0x7d1cac01,0x34940107,0xcc58011a,0x00000000}},	//   hess, _ҷабр, ובדי_, --, 
   {{0x7d1c5fa7,0x4424000d,0x65607a03,0x07a40953}},	//   kess, _esm_, bhoh, _раён, 
   {{0x34942b39,0x65600978,0x4424ac02,0x8ab80375}},	//   _забр, choh, _fsm_, ולוג_, 
   {{0xa2c80cb4,0x7d1cac03,0x00000000,0x00000000}},	//   _स्क्, dess, --, --, 
   {{0x7528ac04,0x7d1cac05,0x9f8006d3,0x78bc00d7}},	//   _haez, eess, лгыд, _lgsv, 
   {{0x7d1cac06,0x4424382c,0x75280489,0x8d4801c6}},	//   fess, _zsm_, _kaez, дүйг_, 
   {{0x78bc0112,0x00000000,0x00000000,0x00000000}},	//   _ngsv, --, --, --, 
   {{0x7528ac07,0x5edc00eb,0xaabc1bd6,0x00000000}},	//   _maez, _মারে, ्डलक, --, 
   {{0x20080311,0x75280489,0x65600023,0x6d4433b8}},	//   ăbit_, _laez, zhoh, sjka, 
   {{0x7d1cac08,0xa6c801a9,0x3a280139,0x18640022}},	//   bess, ldаg, мерү_, ҭаси_, 
   {{0x7528004c,0x9f500086,0x9c80242a,0x6560036e}},	//   _naez, _òdòn_, ščak, xhoh, 
   {{0x7c2400c7,0x5eb000d1,0xa6c8022e,0xdb140200}},	// [dba0] _азыҧ, _ийәт, ndаg, _xixë, 
   {{0x6f000e14,0x00000000,0x00000000,0x00000000}},	//   nglc, --, --, --, 
   {{0x6560ac09,0x75280007,0x4424ac0a,0x48c400fb}},	//   thoh, _baez, _ssm_, _аҙба, 
   {{0x4424ac0b,0x75280399,0x88b0016b,0x2ee4ac0c}},	//   _psm_, _caez, neɛk, half_, 
   {{0x75280097,0x6560ac0d,0x2ee405e4,0x1b200154}},	//   _daez, rhoh, kalf_, মারে_, 
   {{0x6560ac0e,0x7d1cac0f,0x69dc009a,0x22a401e1}},	//   shoh, zess, _kwpe, _níkí_, 
   {{0x7528ac10,0x6560ac11,0x7d1cac12,0x442401bf}},	//   _faez, phoh, yess, _wsm_, 
   {{0xc0bc02d3,0x752805c7,0x7d1cac13,0xa2740023}},	//   _ደቆም_, _gaez, xess, _ክንክን_, 
   {{0x4424ac14,0xdb140ba1,0xd00403b7,0xb424ac15}},	//   _usm_, _fixè, еење_, _لعلو, 
   {{0x7d1cac16,0x31a02358,0x6f00037e,0x1010ac17}},	//   wess, róza_, のblo, ابيد, 
   {{0x7528949e,0x3d040b67,0x00000000,0x00000000}},	//   _yaez, _वादे_, --, --, 
   {{0x63b804b9,0x7d1c1e54,0xade000c5,0x3234010f}},	//   _hitn, uess, _खबरन_, _שטײן_, 
   {{0x69dc01e1,0x0ca8ac18,0x63b800d8,0x00000000}},	//   _awpe, етри_, _kitn, --, 
   {{0x63b8ac19,0xdb1414a9,0x6aa001e4,0x99d4484d}},	//   _jitn, _xixè, _ĝofr, فترا, 
   {{0x61e8ac1a,0x7d1cac1b,0x63b8ac1c,0x75c40064}},	//   nsfl, pess, _mitn, _rėzo, 
   {{0x63b8ac1d,0xdb1402fb,0x0e9804ae,0x090400cf}},	//   _litn, _mixé, _משול, лчум, 
   {{0x7528ac1e,0xdb14011f,0xd87400db,0x636402d2}},	// [dbb0] _raez, _lixé, رارب, _iðnf, 
   {{0x63b8ac1f,0x7528715a,0x3a24005c,0xe208012d}},	//   _nitn, _saez, ælps_, _zbóż_, 
   {{0x7528030a,0x62980728,0xa6c8022e,0x00000000}},	//   _paez, _nyto, zdаg, --, 
   {{0x1cbc038f,0x61e83fc1,0x2ee401f5,0x00000000}},	//   _ཇུས_, dsfl, zalf_, --, 
   {{0x63b81326,0x7528ac20,0xdb14180f,0x6298ac21}},	//   _bitn, _vaez, _pixè, _ayto, 
   {{0x629805dd,0x3948ac22,0xb7c40589,0x63b8022f}},	//   _byto, ljas_, _trãª, _citn, 
   {{0x3868ac23,0x6350147e,0x61e8ac24,0x6298ac25}},	//   lzar_, рвју, gsfl, _cyto, 
   {{0xdb140005,0x6298003a,0x63b8ac26,0x386801c4}},	//   _dixé, _dyto, _eitn, ozar_, 
   {{0x3868ac27,0x60041de1,0x05847488,0xef840131}},	//   nzar_, вным_, _сурм, клип, 
   {{0x63b88b14,0xdb14ac28,0x394800c5,0x629802f0}},	//   _gitn, _fixé, hjas_, _fyto, 
   {{0xa2c83d60,0xc324015b,0x39480115,0x2ee403cd}},	//   _स्ट्, পাশি_, kjas_, ralf_, 
   {{0xed58ac29,0x2ee417b5,0x2f380055,0x00000000}},	//   фом_, salf_, _ṅgā_, --, 
   {{0x63b8ac2a,0x5d640580,0x69dc015d,0x6298343a}},	//   _yitn, тиям_, _swpe, _zyto, 
   {{0x38680a2e,0xdfcc216b,0xeb740006,0x2078010f}},	//   dzar_, _بيو_, тымэ, _קאסא, 
   {{0x6994ac2b,0x00000000,0x00000000,0x00000000}},	//   врах, --, --, --, 
   {{0x3948ac2c,0x00000000,0x00000000,0x00000000}},	//   gjas_, --, --, --, 
   {{0x6b6404b3,0x00000000,0x00000000,0x00000000}},	// [dbc0] _акпа, --, --, --, 
   {{0xe7384fc6,0x44380e96,0x6364032e,0x394800ef}},	//   ьез_, _čr_, _iðng, ajas_, 
   {{0x3868ac2d,0x63b8ac2e,0x2d808bbb,0x6d4c00e8}},	//   azar_, _ritn, onke_, _ŋaay, 
   {{0x63b804b9,0x38680198,0x62980006,0x2d8000f3}},	//   _sitn, bzar_, _ryto, nnke_, 
   {{0x61e894a8,0xdb140048,0x14240212,0x629887b5}},	//   wsfl, _sixé, віщо_, _syto, 
   {{0x77640227,0x61e8ac2f,0x2d80002f,0x63b80200}},	//   chhx, tsfl, hnke_, _qitn, 
   {{0xe4c4ac30,0x5b780a1e,0xe69401d5,0x61e81196}},	//   _айби, ורסא, _شلرد, usfl, 
   {{0x63b8ac31,0x61e8ac32,0xdb14056a,0x629802fb}},	//   _witn, rsfl, _vixé, _vyto, 
   {{0xdef8ac33,0x61e8713c,0xe3140736,0x63b8ac34}},	//   мын_, ssfl, _لباب, _titn, 
   {{0x63b82595,0x6298ac35,0x00000000,0x00000000}},	//   _uitn, _tyto, --, --, 
   {{0x3868ac36,0x6d9403b2,0x60e80108,0x00000000}},	//   zzar_, váar, _жмем_, --, 
   {{0xd1340022,0x77540240,0x00000000,0x00000000}},	//   _ахш_, _ዘየስተ, --, --, 
   {{0x06e800bd,0xeb0c0c6f,0x394800b5,0x00000000}},	//   _পানি, िभूत_, vjas_, --, 
   {{0x2fc801e7,0xb7c40116,0x10a05a41,0x38c800e5}},	//   _éaga_, ғрақ, _тичн, ڑائی_, 
   {{0x3948ac37,0x00000000,0x00000000,0x00000000}},	//   tjas_, --, --, --, 
   {{0x3868ac38,0x39481039,0x00000000,0x00000000}},	//   tzar_, ujas_, --, --, 
   {{0x394800af,0x7b840efb,0x0c7419bc,0x3834199e}},	// [dbd0] rjas_, _مادە, _پديد, ынар, 
   {{0x3868ac39,0x39480037,0x00000000,0x00000000}},	//   rzar_, sjas_, --, --, 
   {{0x35f4ac3a,0x38684579,0x3948ac3b,0x64546b8a}},	//   упер, szar_, pjas_, øyin, 
   {{0x38680789,0x7ae4005b,0x00000000,0x00000000}},	//   pzar_, _heht, --, --, 
   {{0x7ae4033d,0xd7f801c6,0x00000000,0x00000000}},	//   _keht, _юун_, --, --, 
   {{0x7ae4025c,0x7ae0022e,0x00000000,0x00000000}},	//   _jeht, аlti, --, --, 
   {{0xe294ac3c,0x2d8015c0,0x00000000,0x00000000}},	//   лаш_, ynke_, --, --, 
   {{0x7ae4ac3d,0x62300114,0x00000000,0x00000000}},	//   _leht, сећу, --, --, 
   {{0xa1f00075,0x7ae4005a,0xd4980798,0x41444660}},	//   لۋەت, _oeht, _црв_, рдың, 
   {{0x7ae4ac3e,0xd2582ff5,0x00000000,0x00000000}},	//   _neht, _оце_, --, --, 
   {{0xb644037e,0x06e800cc,0x00000000,0x00000000}},	//   _ｉｂ_, _পামি, --, --, 
   {{0x81441d1f,0x6abc66c0,0x00000000,0x00000000}},	//   _پنهن, ्ड्र, --, --, 
   {{0x7ae4ac3f,0x41b00137,0x3d049a09,0xa2c81bd6}},	//   _beht, _بۅير, _वारे_, सुक्, 
   {{0x7ae4004e,0x2d8001fa,0x4aa8000d,0xdbb80139}},	//   _ceht, snke_, _गरदव, етсә_, 
   {{0x186402f4,0x7ae4013a,0x6a8448d4,0x00000000}},	//   ҳати_, _deht, улва, --, 
   {{0x6da4010b,0xc61c00eb,0x00000000,0x00000000}},	//   _щийа, ণিমা_, --, --, 
   {{0x18646a09,0x7ae40010,0xe7385fb2,0xe7a8ac40}},	// [dbe0] гати_, _feht, неа_, евал_, 
   {{0x7ae4ac41,0xaa440117,0x00000000,0x00000000}},	//   _geht, _беол, --, --, 
   {{0x9bb40302,0x4aa80118,0x1f5800df,0x366800c7}},	//   _תהיה_, _गरिव, עדעא, ҭаӡо_, 
   {{0xd7ec0137,0x00000000,0x00000000,0x00000000}},	//   زكۅ_, --, --, --, 
   {{0x06e800bd,0xbebc00da,0x7ae40921,0xdcec0311}},	//   _পাঠি, ldīt, _yeht, lică, 
   {{0x7ae4037e,0xd2cc00e1,0x4ab80073,0x00000000}},	//   _xeht, सुलझ, _आणाव, --, 
   {{0x3d0414cf,0x68e405b1,0xdcec0311,0x7790ac42}},	//   _वाले_, _kekd, nică, _بیلا, 
   {{0x41545882,0x672cac43,0xb62c0150,0x00000000}},	//   рвис, _habj, _ﺒﺄ_, --, 
   {{0x68e409a5,0x672cac44,0x00000000,0x00000000}},	//   _mekd, _kabj, --, --, 
   {{0x49780020,0x1418008f,0x672c0009,0x8af803e3}},	//   _በወቅቱ_, _אומב, _jabj, _çəhr, 
   {{0x672c0770,0x7ae4ac45,0xe0d80452,0xd12c009d}},	//   _mabj, _reht, _зве_, _лх_, 
   {{0x68e4140b,0x5c04ac46,0xfde80228,0xdcec0311}},	//   _nekd, ляга, ндүк_, dică, 
   {{0x60c01389,0x7ae40427,0x5574010f,0x8e440220}},	//   _igom, _peht, רעכן_, _ەلىك_, 
   {{0xdcec084c,0x7ae4014f,0x00000000,0x00000000}},	//   fică, _qeht, --, --, 
   {{0x60c0ac47,0x7ae40023,0x68e4ac48,0x8e343918}},	//   _kgom, _veht, _bekd, _مسير_, 
   {{0x7ae4ac49,0x68e46cba,0x78d41c96,0x00000000}},	//   _weht, _cekd, ржах, --, 
   {{0x60c0ac4a,0x7ae4ac4b,0x68e4010f,0x7c28ac4c}},	// [dbf0] _mgom, _teht, _dekd, çerd, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x60c0ac4d,0x7b8407d2,0x69f0004e,0x0708027d}},	//   _ogom, _ماگە, _мүрт, ايمي_, 
   {{0x60c0ac4e,0x68e400a2,0xb9040116,0x38c802f2}},	//   _ngom, _gekd, _өзүк, _جادی_, 
   {{0x672cac4f,0x00000000,0x00000000,0x00000000}},	//   _fabj, --, --, --, 
   {{0x60c0ac50,0x1b2000bd,0xd76053e2,0x672c0100}},	//   _agom, মাকে_, _انسی, _gabj, 
   {{0x45d4ac51,0xb14433d2,0x8ee0009e,0xd5a0030f}},	//   _госс, инкл, _মালগ, _هلسی, 
   {{0x672c0cf4,0xefc80092,0x514001d5,0x00000000}},	//   _zabj, _በለው_, сдиғ, --, 
   {{0x6f64ac52,0x06e80729,0xdb14004e,0x00000000}},	//   ивиз, _পাতি, _així, --, 
   {{0xee38ac53,0x2f543caf,0x60c0ac54,0x889c008f}},	//   вно_, ртис, _egom, עבזי, 
   {{0xc2c4115a,0xf1cc0220,0x00000000,0x00000000}},	//   _ايمي, _ﻗﺎﻣﺘ, --, --, 
   {{0x81bc0607,0x60c00a49,0xc104009f,0x84640092}},	//   _apēf, _ggom, _هومي, ጻጸምን_, 
   {{0x68e433b8,0x1b0c009e,0xafe40408,0x00000000}},	//   _rekd, াজনে_, _толл, --, 
   {{0x68e4ac55,0x60c00276,0xbb740395,0x00000000}},	//   _sekd, _zgom, бусъ, --, 
   {{0x672cac56,0xada45b7f,0xbebc00e2,0x6da4010a}},	//   _rabj, _какл, udīt, _кика, 
   {{0xdcec054e,0xf1e00150,0x6c74010a,0xa92400d8}},	//   rică, _ﺍﻹﻟﺘ, _вуох, јдал, 
  
   {{0xdd8c1a59,0x1cbc025c,0x672c014f,0xa6e400f5}},	// [dc00] _توي_, _ཇུག_, _pabj, ижал, 
   {{0x7c2870f7,0x68e4034c,0x672c047e,0x574000cf}},	//   çere, _wekd, _qabj, онуб, 
   {{0xc0d402d3,0xaa4400db,0xfca843fb,0xa9a4ac57}},	//   _የድሊ_, _ئنجى, _لایو_, _винд, 
   {{0xe458ac58,0xe578016c,0x00000000,0x00000000}},	//   кже_, ъзе_, --, --, 
   {{0xe6f401d9,0x00000000,0x00000000,0x00000000}},	//   _نژاں_, --, --, --, 
   {{0x60c000a7,0xd36c1b45,0x53941cb8,0x2fc8010e}},	//   _sgom, وهن_, авія_, _çagy_, 
   {{0x216405c2,0x8ee000cc,0x1718010f,0x65b801af}},	//   итиг, _মাংগ, _שולע, _ауар_, 
   {{0xd134ac59,0x1fd8015b,0x52800131,0xe4740166}},	//   ахь_, _দিবস, تلىك, _кузэ, 
   {{0xe3b8ac5a,0x3cec000d,0x00000000,0x00000000}},	//   _аба_, _अजबे_, --, --, 
   {{0x1b180154,0x9e64007b,0x00000000,0x00000000}},	//   _ফোনে_, لاجن, --, --, 
   {{0x60c007de,0xdb1400d8,0x1cbc0327,0x00000000}},	//   _tgom, _lixã, _ཇུང_, --, 
   {{0x60c05413,0xdb140005,0xe0d8011c,0x00000000}},	//   _ugom, _vixí, _рвд_, --, 
   {{0xd004ac5b,0xab7801a9,0x10a00022,0xdc7002d3}},	//   _вече_, _bo鼠g, _дицн, _ኣድላይ_, 
   {{0x386c0209,0x0b880354,0xdb200205,0x909400d4}},	//   _ýeri_, асси_, _örün, _твіт_, 
   {{0x0624001f,0xdda80166,0xdb0c01e1,0x00000000}},	//   _ደጋፊዎ, _итил_, _àjíp, --, 
   {{0x8d74680d,0x00000000,0x00000000,0x00000000}},	//   _وايا, --, --, --, 
   {{0x7d0cac5c,0x00000000,0x00000000,0x00000000}},	// [dc10] _icas, --, --, --, 
   {{0x7c2cac5d,0x7b8400db,0xaab40014,0x9b400244}},	//   _isar, _دابە, _گگُر_, _بۆسو, 
   {{0x3ce80dd4,0xcf90008f,0x7c2c025c,0x81bc00de}},	//   _keav_, קטע_, _hsar, _drēz, 
   {{0x394c0798,0xc1cc02dd,0x00000000,0x00000000}},	//   _ões_, _ﻗﯟﺯﺍ, --, --, 
   {{0x7c2c031c,0x7d0cac5e,0x972001d9,0x386c01bf}},	//   _jsar, _mcas, _وہرو, _åer_, 
   {{0xb5c8ac5f,0x3ce805d5,0x5edc015b,0xd3780395}},	//   _موسم_, _leav_, _মাঝে, ъче_, 
   {{0xd5b8ac60,0x92686a11,0xc0d40092,0x00000000}},	//   _аса_, ърда_, _የስም_, --, 
   {{0x7c2cac61,0x7d0c00eb,0xb144ac62,0x64580419}},	//   _osar, _ncas, снил, íciá, 
   {{0xed58085a,0x5edc4251,0x7c2c0135,0x00000000}},	//   ҳон_, _মাজে, _nsar, --, 
   {{0x7d0cac63,0x5f403baf,0x2ca4031c,0xc0d40092}},	//   _acas, كچىل, _ġod_, _የድል_, 
   {{0xed58aa1a,0x7c2cac64,0x5184408a,0x7d0c0120}},	//   гон_, _asar, _куда, _bcas, 
   {{0x7d0c07ab,0x63640008,0x013400c6,0x703801d9}},	//   _ccas, _iðna, _وعند, _مستس_, 
   {{0x7c2c01d3,0x00000000,0x00000000,0x00000000}},	//   _csar, --, --, --, 
   {{0x7d0cac65,0x7c2c01a6,0x28d8ac66,0xc0e00023}},	//   _ecas, _dsar, युनि, ነጸረ_, 
   {{0xa9680395,0x00000000,0x00000000,0x00000000}},	//   гива_, --, --, --, 
   {{0x3ce805c7,0x75c40024,0x7d0c00ae,0x00000000}},	//   _geav_, _jėzu, _gcas, --, 
   {{0x7c2c0205,0x00000000,0x00000000,0x00000000}},	// [dc20] _gsar, --, --, --, 
   {{0x6d54ac67,0x66e400d8,0x00000000,0x00000000}},	//   _hoya, сожа, --, --, 
   {{0x6d54ac68,0x64c4ac69,0x5b54010f,0x7c2c00e5}},	//   _koya, ميال, _הייב_, _zsar, 
   {{0x6d54ac6a,0x5edc015b,0x69240b56,0xa4444c79}},	//   _joya, _মাছে, _умма, йнед, 
   {{0x6d54ac6b,0xdb140561,0xd36c0451,0xb80801ed}},	//   _moya, _hixá, ڙهه_, _نکلے_, 
   {{0x27f005ac,0x9c8000d0,0x6d54ac6c,0x23c40014}},	//   msyn_, áčik, _loya, لٕچہ, 
   {{0x27f00623,0x6d54ac6d,0x00000000,0x00000000}},	//   lsyn_, _ooya, --, --, 
   {{0x6d54ac6e,0xc0d4001f,0xdb140306,0x3ff806ed}},	//   _noya, _የትም_, _mixá, аниќ_, 
   {{0x27f000ed,0x9878010f,0x31b00419,0x6560000d}},	//   nsyn_, ָריק, _všzp_, mkoh, 
   {{0x543804ac,0x7d0cac6f,0x6d54019b,0x7c2c0472}},	//   _געמא, _scas, _aoya, _rsar, 
   {{0x6d54ac70,0x17980bd9,0x7d0c011c,0x7c2c0194}},	//   _boya, רייב, _pcas, _ssar, 
   {{0x27f0ac71,0x7c2cac72,0x00000000,0x00000000}},	//   ksyn_, _psar, --, --, 
   {{0x6d54ac73,0x7d0cac74,0x29cc010b,0x7c2c031c}},	//   _doya, _vcas, _aýa_, _qsar, 
   {{0x27f0ac75,0x6560ac76,0x1fb40138,0x92e403d4}},	//   dsyn_, hkoh, _усер, _ভাৱ_, 
   {{0x6d54ac77,0x65600e03,0x27f00363,0x996402a9}},	//   _foya, kkoh, esyn_, бтал, 
   {{0x7c2cac78,0x7d0cac79,0x2b180316,0xdd8c05d9}},	//   _tsar, _ucas, म्बु_, _ڪوڊ_, 
   {{0xb8d0534e,0x7c2cac7a,0x5b2412c4,0xd5b802dd}},	// [dc30] _ओर_, _usar, _льна, ңсе_, 
   {{0x7bdcac7b,0x6d5402ce,0x9f40ac7c,0xdb14a73a}},	//   mpsu, _zoya, èkè_, _fixá, 
   {{0x6d54ac7d,0x6560009b,0x27f0062c,0xdb04002f}},	//   _yoya, fkoh, asyn_, rmjä, 
   {{0x85b8ac7e,0x3a20009a,0x6560003e,0x85041916}},	//   مانس_, _iphp_, gkoh, كومن, 
   {{0x06e800bd,0x27f03deb,0x00000000,0x00000000}},	//   _পারি, csyn_, --, --, 
   {{0x823400aa,0x8c1c011a,0x65600e03,0x7bdc000d}},	//   ګرها, טודי, akoh, ipsu, 
   {{0x656000d7,0x01d00ef6,0x00000000,0x00000000}},	//   bkoh, _ﻗﺎﻧﻨ, --, --, 
   {{0x349402d5,0x6560ac7f,0x00000000,0x00000000}},	//   _дабр, ckoh, --, --, 
   {{0x6d54ac80,0x636402d2,0x00000000,0x00000000}},	//   _roya, _iðnn, --, --, 
   {{0x6d54ac81,0x00000000,0x00000000,0x00000000}},	//   _soya, --, --, --, 
   {{0x6d54ac82,0x7bdcac83,0xa6c8022e,0x5108010a}},	//   _poya, epsu, ddаl, _йĕнĕ, 
   {{0x6d54ac84,0x27f00363,0xefc80092,0x00000000}},	//   _qoya, ysyn_, በሌው_, --, 
   {{0x6d54ac85,0x316c01d3,0x00000000,0x00000000}},	//   _voya, mhez_, --, --, 
   {{0x6d54ac86,0x0df4001f,0x316cac87,0x7c280200}},	//   _woya, ላለፍ_, lhez_, çera, 
   {{0x06e809bd,0x6d54ac88,0x65600240,0x4ea4ac89}},	//   _পালি, _toya, ykoh, _урда, 
   {{0x2bc88cca,0xd9401586,0x27f0a0be,0xdb140077}},	//   _клип_, меси, tsyn_, _vixá, 
   {{0x98a0ac8a,0x27e40561,0x27f00076,0x6560002f}},	// [dc40] дите, èon_, usyn_, vkoh, 
   {{0x27f0ac8b,0x00000000,0x00000000,0x00000000}},	//   rsyn_, --, --, --, 
   {{0x6560ac8c,0x316c00dd,0x27f00731,0xdd8c5175}},	//   tkoh, khez_, ssyn_, _سوی_, 
   {{0x27f000ee,0x07c40022,0x656026bb,0x287400c0}},	//   psyn_, _намҽ, ukoh, _дыгр, 
   {{0x6560044e,0x23280902,0x23d40108,0xe8c401f9}},	//   rkoh, иоди_, ццер, वशीच, 
   {{0x6560ac8d,0x9c8004bf,0xf2940150,0x00000000}},	//   skoh, _účel, _ﺘﺼﺒﺢ_, --, 
   {{0xd254858f,0x1aec00eb,0x6658030d,0x644400ef}},	//   жцы_, _জামে_, _тавă, _škid, 
   {{0x31a002f0,0x316cac8e,0xb61801ec,0x80d000cf}},	//   kózu_, ghez_, _ﹼﺫ_, رۅتچ, 
   {{0x65b8013a,0xa6c801d5,0xd1b00066,0x00000000}},	//   _bůhv, ydаl, ذیهک, --, 
   {{0x25a4ac8f,0xac7802d3,0x13000cdd,0x28d808df}},	//   llol_, _ኣስላም_, _озум, युति, 
   {{0x7bdc0209,0xf1cc0873,0xe2988083,0x00000000}},	//   wpsu, _ﻗﺎﻳﺘ, _таж_, --, 
   {{0x316cac90,0x91e000d8,0x00000000,0x00000000}},	//   chez_, _цоце, --, --, 
   {{0xefd40092,0xed4c00d1,0x00000000,0x00000000}},	//   _የብዙ_, اھى_, --, --, 
   {{0x99d400c6,0xe0e00154,0x4f9000f3,0x00000000}},	//   قترا, _যায়ন, _орју, --, 
   {{0xaad8033f,0x25a4022e,0x28d40150,0xf98800ae}},	//   भड़क, klol_, _ﺘﺘﺒﻠ, منسي_, 
   {{0x7f58014f,0x3d040073,0x7bdc007c,0x00000000}},	//   _hovq, _वाटे_, ppsu, --, 
   {{0x25a40042,0x00000000,0x00000000,0x00000000}},	// [dc50] dlol_, --, --, --, 
   {{0xd6d8ac91,0x97a43981,0x5a4402d5,0x316cac92}},	//   рта_, ірал, _дэма, zhez_, 
   {{0x7bccac93,0xd5b80fc0,0x7f5803e3,0x25a403e0}},	//   _huau, асд_, _movq, flol_, 
   {{0x057444e7,0x7bccac94,0x7bc40477,0x25a4011f}},	//   واند, _kuau, _hihu, glol_, 
   {{0x7bc4ac95,0x97000075,0xc0f80092,0xc0d40092}},	//   _kihu, _يېرى, _ለስራ_, _ከስራ_, 
   {{0x7bccac96,0x395804e6,0x1cbc0135,0x7bc4014f}},	//   _muau, _hoss_, _ཇུན_, _jihu, 
   {{0x7bc4ac97,0x25a4003e,0x316c01d3,0x6444031c}},	//   _mihu, blol_, thez_, _ġkie, 
   {{0x7bc4ac98,0x7bcc0093,0x25a40429,0xe124031c}},	//   _lihu, _ouau, clol_, _རྒྱད_, 
   {{0x81bc005f,0xb4c80490,0x7bc401c6,0x316c57be}},	//   _spēc, ोडी_, _oihu, rhez_, 
   {{0x7bc4ac99,0x316c00dd,0x3958ac9a,0xdb04002d}},	//   _nihu, shez_, _loss_, rmjû, 
   {{0x7bcc096b,0xada4ac9b,0x39580076,0xdb140139}},	//   _auau, занл, _ooss_, _mixä, 
   {{0x7bc4166a,0x39581570,0x69c806ed,0x628c0427}},	//   _aihu, _noss_, _éfei, _žbog, 
   {{0x7bc4ac9c,0x7bccac9d,0x2128004b,0x98a4012c}},	//   _bihu, _cuau, _دينی_, ěně_, 
   {{0x7bc4ac9e,0x7bcc0a73,0x09b4330a,0x8ca00bc5}},	//   _cihu, _duau, ंग्य, _गुणो, 
   {{0x3958ac9f,0xe6a800af,0xed5843e6,0x25a4015d}},	//   _boss_, _करेज, _гой_, ylol_, 
   {{0x7bcc0618,0x65a80122,0xe8c805f5,0x3958aca0}},	//   _fuau, výho, сгал_, _coss_, 
   {{0x2d80aca1,0x7bccaca2,0x395800ad,0xa8041771}},	// [dc60] mike_, _guau, _doss_, язал, 
   {{0x7bc4aca3,0x4e1c01ad,0xeb04aca4,0xe6c400ae}},	//   _gihu, _बहाई_, _эпоп, ستطي, 
   {{0xa524aca5,0xe9a473ef,0x98a80055,0xa968aca6}},	//   змед, _наоп, _vacā_, _همدم_, 
   {{0x7bc4aca7,0x39580036,0xa508074d,0x25a40280}},	//   _zihu, _goss_, седа_, ulol_, 
   {{0x27ec0316,0x69c40472,0x7bc4aca8,0x1b240023}},	//   álně_, _iike, _yihu, _ስምብራ, 
   {{0x2d80aca9,0x7bc418f7,0x53300276,0x69c4acaa}},	//   hike_, _xihu, еешт, _hike, 
   {{0x69c4acab,0x7f580218,0x26c8acac,0xb35400e5}},	//   _kike, _rovq, _igbo_, بیلا_, 
   {{0x69c42747,0x25a4036b,0xdc3c0276,0x2d80acad}},	//   _jike, qlol_, nţăr, jike_, 
   {{0x2d80acae,0xa3c405f9,0x7f58014f,0x974000f3}},	//   dike_, _ईंट_, _povq, šćet, 
   {{0x7bccacaf,0xdeb001ec,0x00000000,0x00000000}},	//   _ruau, нұлы, --, --, 
   {{0x69c4acb0,0x7bc401b2,0x7bccacb1,0x1010006c}},	//   _oike, _rihu, _suau, وبید, 
   {{0x69c4acb2,0x44240092,0x7bc4acb3,0x7bccacb4}},	//   _nike, _kpm_, _sihu, _puau, 
   {{0x39589fc4,0x2b58004e,0x7bcc1497,0x7bc4acb5}},	//   _ross_, _bopc_, _quau, _pihu, 
   {{0x7fb8acb6,0x3958092e,0x69c4acb7,0xddd800dd}},	//   _بهتر_, _soss_, _aike, sztő, 
   {{0x3958acb8,0x9964acb9,0x7bc4047e,0xd1f00020}},	//   _poss_, птал, _vihu, _ሃብት_, 
   {{0x4424acba,0x69c4acbb,0x26c80cad,0x39b0013f}},	//   _opm_, _cike, _agbo_, _kɑsɑ_, 
   {{0x7bc418f7,0x3958acbc,0x442405d5,0x00000000}},	// [dc70] _tihu, _voss_, _npm_, --, 
   {{0x3f8cacbd,0x69c4acbe,0x7d1cacbf,0x69d80077}},	//   nndu_, _eike, lfss, ítec, 
   {{0xda64acc0,0x69c4acc1,0x39581590,0x3f8cacc2}},	//   _رادي, _fike, _toss_, indu_, 
   {{0x69c40eb4,0x26c8acc3,0x395804cc,0x4424045a}},	//   _gike, _egbo_, _uoss_, _bpm_, 
   {{0x98a80262,0x4424acc4,0x00000000,0x00000000}},	//   _dacă_, _cpm_, --, --, 
   {{0x442400cd,0x69c4acc5,0x798c0280,0x8c1c008f}},	//   _dpm_, _zike, lnaw, צווי, 
   {{0x2d80acc6,0x69c407a8,0x98a8084c,0x798c004c}},	//   yike_, _yike, _facă_, onaw, 
   {{0x69c418f7,0x3f8c08e5,0x7d1c01a4,0x2d80005a}},	//   _xike, endu_, jfss, xike_, 
   {{0x4424acc7,0x798cacc8,0x7c2803ee,0x85540214}},	//   _gpm_, inaw, çerl, _سیور_, 
   {{0x798cacc9,0x2d80acca,0xefc8001f,0x3f8c02d2}},	//   hnaw, wike_, _በገዛ_, gndu_, 
   {{0x2d80accb,0x01d00ed1,0x798caccc,0x7d1c2305}},	//   tike_, _ﻗﺎﻳﻨ, knaw, ffss, 
   {{0x2d800270,0x798c037e,0x3f8caccd,0xe298011a}},	//   uike_, jnaw, andu_, _ושער, 
   {{0x2d8029eb,0xe6a80bae,0x3f9800b0,0x798c0042}},	//   rike_, _कर्ज, ōrua_, dnaw, 
   {{0x69c4acce,0x3f8c0ffb,0x6364032e,0xd1f00257}},	//   _sike, cndu_, _aðnj, _ሃብተ_, 
   {{0x69c4accf,0x798c00c6,0x2d80acd0,0x6fd403f4}},	//   _pike, fnaw, pike_, _দিয়ে, 
   {{0x69c4acd1,0xb4c8acd2,0x75380007,0x2d80acd3}},	//   _qike, ोडो_, jdwz, qike_, 
   {{0x2d900526,0xed6808a5,0x00000000,0x00000000}},	// [dc80] _ijye_, _enþá_, --, --, 
   {{0x4424acd4,0x69c4acd5,0x798c0083,0x28dc503c}},	//   _rpm_, _wike, anaw, _फ्रि, 
   {{0x4424acd6,0x00000000,0x00000000,0x00000000}},	//   _spm_, --, --, --, 
   {{0x81bc0421,0x69c4acd7,0x69dc00d5,0x44240f85}},	//   _apēn, _uike, _itpe, _ppm_, 
   {{0xd24cacd8,0x2fdc0218,0x3f8c05f7,0xdb0405ac}},	//   ینه_, _ntwg_, yndu_, tmjø, 
   {{0x06e800bd,0x26c8acd9,0x28d8acda,0x6d940135}},	//   _পাকি, _ugbo_, युरि, nġab, 
   {{0x2c18045e,0x88b003d4,0x3f8c022c,0x51f0198a}},	//   দিয়ে_, _কলিক, vndu_, پسىر, 
   {{0xd1cc067d,0x2d9001aa,0xd1f0044e,0xc03407fa}},	//   _ኣብቲ_, _njye_, _ሃብቲ_, ениј, 
   {{0x4424acdb,0x69dc0036,0xc50800f1,0x1858010f}},	//   _upm_, _ltpe, _وتړل_, ַכטע, 
   {{0x2d900230,0x2368acdc,0x69dc17a3,0x798c0034}},	//   _ajye_, _بحري_, _otpe, znaw, 
   {{0xe0d80b16,0x798c9b55,0xf1a800aa,0x00000000}},	//   _две_, ynaw, _کاله_, --, 
   {{0x7d1c0e78,0x5bc44c5b,0x28dca4cd,0x00000000}},	//   ufss, लद्व, _फ्लि, --, 
   {{0xd1cc044e,0x7d1c0008,0x69dc3e9d,0x91b8011a}},	//   _ኣብታ_, rfss, _atpe, _ומאי, 
   {{0x7c3cacdd,0x61f80139,0x386c025c,0x798c012d}},	//   rvsr, _kvtl, _żero_, wnaw, 
   {{0x8fa00114,0xea24004e,0x00000000,0x00000000}},	//   _шаље, нчтү, --, --, 
   {{0x69d80491,0x798cacde,0x4f0401ee,0x28d801f9}},	//   ítea, unaw, _енән_, युलि, 
   {{0x798cacdf,0x00000000,0x00000000,0x00000000}},	// [dc90] rnaw, --, --, --, 
   {{0x798cace0,0x00000000,0x00000000,0x00000000}},	//   snaw, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xceb005e1,0x7af4ace1,0xa50800d1,0x00000000}},	//   דיע_, lazt, كىمە_, --, 
   {{0x3dc803a2,0xd6d806ed,0x98b000c0,0x00000000}},	//   _miaw_, _мтв_, _įdėk_, --, 
   {{0x3dc80c67,0xe4e4ace2,0x7af4ace3,0x00000000}},	//   _liaw_, _үстү, nazt, --, 
   {{0xc6a4ace4,0x9f440112,0xf31401c6,0xf1cc9c97}},	//   _арти, _stoß_, _үдбэ, _ﻗﺎﻗﺘ, 
   {{0x7af405f5,0x00000000,0x00000000,0x00000000}},	//   hazt, --, --, --, 
   {{0x7af4009d,0xdbc400a2,0x00000000,0x00000000}},	//   kazt, _göçj, --, --, 
   {{0x6298022c,0x00000000,0x00000000,0x00000000}},	//   áboð, --, --, --, 
   {{0x7af401c4,0xd1380064,0x00000000,0x00000000}},	//   dazt, _мхд_, --, --, 
   {{0x20000006,0x7de4ace5,0x2b10000d,0x00000000}},	//   škia_, کسیم, _ताहु_, --, 
   {{0xf53801a2,0x3dc80129,0x00000000,0x00000000}},	//   _mať_, _diaw_, --, --, 
   {{0x7af401c6,0xbcc001e0,0xff5001e2,0x00000000}},	//   gazt, шҡыл, _پخه_, --, 
   {{0x8ca000dc,0x00000000,0x00000000,0x00000000}},	//   _गुरो, --, --, --, 
   {{0x2d900796,0xece80209,0xed5801f0,0xf538013a}},	//   _ujye_, _эдил_, _хои_, _nať_, 
   {{0x7af401c0,0x66e40166,0xcfe000cc,0x38540395}},	// [dca0] bazt, еоза, _মিডন, къфс, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69dc85da,0x76b8030d,0x00000000,0x00000000}},	//   _utpe, çлар_, --, --, 
   {{0x98500882,0x636402d2,0x00000000,0x00000000}},	//   ṇā_, _iðni, --, --, 
   {{0xd464ace6,0x68f407d6,0xf53801f1,0x6384036b}},	//   нице_, mayd, _dať_, нгда, 
   {{0x68f4ace7,0x29100589,0x29bc063f,0x00000000}},	//   layd, lgya_, _ọchụ_, --, 
   {{0x69c80066,0xd62400f3,0xddd80210,0x00000000}},	//   _éfes, _поре_, zytł, --, 
   {{0x64a4ace8,0x68f4ace9,0x7c282258,0x5ab4010f}},	//   _заба, nayd, çerk, עלקע_, 
   {{0xa4449a58,0xa3b81374,0x29100009,0xd14c0051}},	//   _янад, _فائر_, igya_, _tễnh_, 
   {{0x68f4acea,0xf3c8a2f2,0x3dc803a2,0x29100007}},	//   hayd, _قبله_, _siaw_, hgya_, 
   {{0x29100399,0x68f43536,0x614402e8,0xdb780023}},	//   kgya_, kayd, _пежа, _ኣብዞም_, 
   {{0x68f4aceb,0xbd8c037e,0x76400153,0xf1a802f2}},	//   jayd, d用cn, _šlyk, _قانه_, 
   {{0x68f40050,0xd12cacec,0x69d800dd,0x716400c6}},	//   dayd, _دمن_, íten, _جالك, 
   {{0x29100009,0x00000000,0x00000000,0x00000000}},	//   egya_, --, --, --, 
   {{0x7af40323,0x68f40429,0x606401d9,0x4f541867}},	//   razt, fayd, _زٕژِ_, _سجود_, 
   {{0x29102f99,0xf8b805f5,0x68f4aced,0xa6380092}},	//   ggya_, дөг_, gayd, _ከሚያደ, 
   {{0x36d472e5,0x7af4005a,0x00000000,0x00000000}},	// [dcb0] возр, pazt, --, --, 
   {{0x81bc0029,0x76400008,0xf53800d7,0x57a401f0}},	//   _spēl, _ályk, _sať_, хшба, 
   {{0x7994035b,0x61fc0427,0x4b7c011a,0x8f9800d9}},	//   _аинф, šplj, _מאזו, לימי, 
   {{0x68f4058a,0x46a40137,0x6e2400a2,0xdfc400f1}},	//   cayd, ушуб, _ähbe, _ږي_, 
   {{0xca480344,0x588406ae,0xd8380137,0xf5380419}},	//   _قلیه_, _чына, _ээн_, _vať_, 
   {{0x80c409ab,0x1b0c00eb,0x00000000,0x00000000}},	//   ाइने, াজকে_, --, --, 
   {{0xe294acee,0xe3e401b9,0x00000000,0x00000000}},	//   каш_, _یکون_, --, --, 
   {{0xb14474be,0xc1d4035b,0x00000000,0x00000000}},	//   тнил, уҩцә, --, --, 
   {{0x07a40014,0xb6a40131,0x00000000,0x00000000}},	//   _شمہُ, _чиңл, --, --, 
   {{0x29100399,0x5f4003cc,0xe2d800db,0x6f6400d4}},	//   zgya_, لچىل, _قامچ_, твоз, 
   {{0x2eb4016c,0xb114014b,0x00000000,0x00000000}},	//   ъсис, _амеш, --, --, 
   {{0x68f4acef,0x31340114,0x00000000,0x00000000}},	//   xayd, _једр, --, --, 
   {{0x68f41444,0xa178011a,0xd0000150,0x00000000}},	//   vayd, _קטנט, _солқ, --, 
   {{0x68f4acf0,0x69d40490,0x6fc4031c,0xeb98005b}},	//   wayd, _मंदी, _གངྒའ, фиг_, 
   {{0x561000bd,0x68f4acf1,0x2a7c01ab,0xcc1400cf}},	//   সবুক_, tayd, àtb_, _өчпө, 
   {{0xada40372,0x6cc4022e,0x00000000,0x00000000}},	//   _шайл, _иййа, --, --, 
   {{0x2910acf2,0xe738016c,0x7c2400c7,0x80c400ab}},	// [dcc0] rgya_, меа_, _бзыҧ, ाइये, 
   {{0x68f44a4a,0x66e418ac,0xeaf80ee8,0xb86407fc}},	//   sayd, тожа, _کرکت_, دافو, 
   {{0x68f4acf3,0x00000000,0x00000000,0x00000000}},	//   payd, --, --, --, 
   {{0x59803580,0xf5680220,0x569002bf,0x64c41916}},	//   _влюб, ншік_, шаєт, نيال, 
   {{0x29002aff,0x7b081d0e,0x04440022,0x00000000}},	//   _idka_, _ístó, ыҵан, --, 
   {{0x7c28acf4,0xb5e40032,0x00000000,0x00000000}},	//   çeri, _әйтһ, --, --, 
   {{0x33240175,0x00000000,0x00000000,0x00000000}},	//   _dblx_, --, --, --, 
   {{0x60444575,0xd624311c,0xca7c0139,0x1a98010f}},	//   вхоз, _шосе_, _üzеn, ויצע, 
   {{0xb4244e25,0x3f98003a,0x101401d3,0xd0041fbe}},	//   _معلو, ōrum_, نکوں_, вење_, 
   {{0x607c0020,0x64400998,0x200002d5,0x3324010a}},	//   _እድገት_, mvoi, škio_, _gblx_, 
   {{0x69d8012c,0x6440acf5,0x2214084c,0xd12c074d}},	//   ítel, lvoi, _шфар, _кх_, 
   {{0x629801c4,0xfde800f7,0x644001f4,0x00000000}},	//   _ixto, мдүк_, ovoi, --, 
   {{0x6440acf6,0x00000000,0x00000000,0x00000000}},	//   nvoi, --, --, --, 
   {{0x88b002f5,0x6440023a,0x2900acf7,0xa6c8022e}},	//   _কলংক, ivoi, _adka_, ndаs, 
   {{0x64444b16,0x6440005b,0xdd9808ca,0x00000000}},	//   _škil, hvoi, _оши_, --, 
   {{0x81bc00da,0x7c340aac,0x00000000,0x00000000}},	//   _spēj, _беих, --, --, 
   {{0x21240066,0x61fc0306,0x81e80154,0x00000000}},	// [dcd0] _mboh_, šplh, _বিফ_, --, 
   {{0x81e80f22,0x2bb407b6,0x00000000,0x00000000}},	//   _বিন_, ूषणा, --, --, 
   {{0xc6a4acf8,0xc7c4acf9,0xa6c801a9,0x85b801d9}},	//   арци, рсти, ddаs, چانس_, 
   {{0x63b80113,0x85b80150,0x13c800dc,0xf85800f3}},	//   _ahtn, نانس_, ाद्भ, _замј_, 
   {{0x629802d0,0x2a800092,0x00000000,0x00000000}},	//   _axto, _የሆነች_, --, --, 
   {{0x212400f2,0x6d940327,0x81640133,0xd7f80b01}},	//   _aboh_, jġan, یۆلۆ, _нуҳ_, 
   {{0x2bd8acfa,0xb594acfb,0x38683107,0x021801ed}},	//   _यूना, _бивш, lyar_, نٹوں_, 
   {{0x63b80037,0xd16006dc,0x00000000,0x00000000}},	//   _ehtn, рниқ, --, --, 
   {{0x3868acfc,0x6298acfd,0x2d9000dd,0x32540724}},	//   nyar_, _exto, ézem_, _әвер, 
   {{0x386803f9,0x6298037e,0x00000000,0x00000000}},	//   iyar_, _fxto, --, --, 
   {{0x62240150,0x3868acfe,0x00000000,0x00000000}},	//   _مولە, hyar_, --, --, 
   {{0x2b440311,0xdee00116,0x3868acff,0x00000000}},	//   _şoc_, _һоши, kyar_, --, 
   {{0xbc1802dd,0xf1a8023f,0xe534010f,0xa6c801a9}},	//   кірі_, _قاچه_, נטשט_, ndаr, 
   {{0xdee02830,0xdcec00da,0x69d800df,0x3868010b}},	//   _лоши, ficē, ŭtem, dyar_, 
   {{0x4aa401ad,0x1ae00faf,0x636402d2,0x6994ad00}},	//   _खुशव, сосм, _iðnt, грах, 
   {{0x8d2800d1,0x316c5440,0x64404132,0x00000000}},	//   _рниң_, nkez_, yvoi, --, 
   {{0x3868066d,0x81bc0029,0xe5a42f8d,0xf9c4004e}},	// [dce0] gyar_, _spēk, қиди, ратү, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa968ad01,0xb684035b,0x316c0205,0xdb202bef}},	//   _зина_, аҩра_, kkez_, _اوپی, 
   {{0x64407cea,0x63b801d5,0xb5a40212,0xb86400e5}},	//   tvoi, _shtn, арій, داہو, 
   {{0x64403d8b,0xa50800ee,0xba440129,0x948000ee}},	//   uvoi, _җеза_, poïé, йышд, 
   {{0x6440ad02,0x2124ad03,0xe19001c0,0xd3b40212}},	//   rvoi, _sboh_, өллө, глії_, 
   {{0x644032cb,0x46b801ad,0x287400c7,0x81dc00cc}},	//   svoi, _अरिह, _рыҽр, তীন_, 
   {{0xe5a44a77,0x84c40075,0xdfe80395,0xe4e800ae}},	//   _сиби, _кәлд, ньол_, _سعره_, 
   {{0xa2e40364,0x25a490f0,0xe4740006,0x00000000}},	//   _бозд, mool_, _сувэ, --, 
   {{0x6148006a,0x25a4ad04,0x85140cb4,0x6298017a}},	//   _bêlä, lool_, _डाँट_, _txto, 
   {{0x4aa41889,0x386800ee,0x629802d0,0x5754010f}},	//   _खुलव, zyar_, _uxto, אביע_, 
   {{0x3868ad05,0x25a4ad06,0x7e68017a,0x316c0129}},	//   yyar_, nool_, rydp, ckez_, 
   {{0x768000a2,0x38680067,0x3cf80254,0x00000000}},	//   _aзyl, xyar_, rasv_, --, 
   {{0x25a4ad07,0x9e64182c,0x8eb01e4a,0xdcec00e2}},	//   hool_, _مابن, _گەپت, ticē, 
   {{0x25a4ad08,0x35d80c2e,0x7e680175,0x00000000}},	//   kool_, _बूढ़, qydp, --, 
   {{0x8eb016a0,0x1b003bfd,0x6d940327,0x00000000}},	//   _دەپت, шүүн, nġal, --, 
   {{0x37f80276,0x00000000,0x00000000,0x00000000}},	// [dcf0] тезэ_, --, --, --, 
   {{0x7c2cad09,0x3868ad0a,0x70d02052,0x69d40034}},	//   _ipar, ryar_, _हल्ल, _मूवी, 
   {{0x0708acdc,0x3868ad0b,0x5a440b5e,0x00000000}},	//   طيني_, syar_, _сэпа, --, 
   {{0x8af80cc1,0x7c2c02e3,0x25a40067,0x00000000}},	//   _şəxs, _kpar, gool_, --, 
   {{0x7c2c0472,0x59d8012d,0x4d7c010f,0x00000000}},	//   _jpar, _मंडर, ערדע, --, 
   {{0x7c2cad0c,0xdb0cad0d,0xcfe00f22,0x15f4007b}},	//   _mpar, _ädäm, _মিলন, _مسرح, 
   {{0x25a459bf,0x756401ed,0x75c8ad0e,0x7c2c0055}},	//   bool_, _پیشہ_, _атаң_, _lpar, 
   {{0x3004036b,0x00000000,0x00000000,0x00000000}},	//   азиг, --, --, --, 
   {{0x316cad0f,0x307411db,0x35a40116,0x7c2c01e1}},	//   rkez_, руйс, _баңг, _npar, 
   {{0x316c030a,0xd1c80092,0x826400ec,0x00000000}},	//   skez_, ጠየቁ_, _گهمن, --, 
   {{0xf2c401c0,0x31340958,0x00000000,0x00000000}},	//   _төди, _веер, --, --, 
   {{0x6da4ad10,0x6cc40408,0x7c2c007b,0x2bd80073}},	//   рима, ийна, _bpar, _यंदा, 
   {{0x7c2cad11,0x7528ad12,0x6364032e,0xe0cc011c}},	//   _cpar, _mbez, _iðnr, _фв_, 
   {{0xad241b56,0x20780a7c,0xddd801ef,0x00000000}},	//   دىڭى, _באנא, hytř, --, 
   {{0x75284ca5,0x7c2cad13,0x25a400e8,0xda6000d8}},	//   _obez, _epar, yool_, оври, 
   {{0xac7404a9,0x7c2cad14,0x8514033f,0xec48ad15}},	//   _ناخش, _fpar, _डाइट_, _азил_, 
   {{0xbe3401d9,0x186401b9,0x6d940003,0xe8c8009d}},	// [dd00] _نى۪ب, аати_, nġam, тгал_, 
   {{0x7528ad16,0x25a4005c,0x28d80a17,0xe9d80114}},	//   _abez, wool_, युजि, _ико_, 
   {{0x25a4ad17,0xe61809a5,0x7c2c0171,0x00000000}},	//   tool_, тде_, _zpar, --, 
   {{0xa968ad18,0xf608ad19,0x7c2c00e4,0xa5080063}},	//   _рима_, اتله_, _ypar, теда_, 
   {{0x25a4ad1a,0xd36c168d,0x9f40025a,0x38c8036b}},	//   rool_, ژهه_, ëkë_, _буён_, 
   {{0x75281cdf,0x25a43199,0xaab86b9b,0xd1c8001f}},	//   _ebez, sool_, _इराक, ጠየቅ_, 
   {{0x31a002f0,0x1798011a,0xd3300137,0x00000000}},	//   lózy_, _סילב, زعوع, --, 
   {{0x6f0c03f9,0x25a40009,0x81e800eb,0x00000000}},	//   _ɓace, qool_, _বিদ_, --, 
   {{0xdb140005,0x31a002f0,0x00000000,0x00000000}},	//   _xixó, nózy_, --, --, 
   {{0xdb040267,0x3f98000d,0x00000000,0x00000000}},	//   lmjö, õru_, --, --, 
   {{0x3eb82d62,0x048800f1,0x00000000,0x00000000}},	//   årt_, _شخړو_, --, --, 
   {{0x7c2cad1b,0x31a00306,0xa0a40120,0xdb0401e3}},	//   _ppar, kózy_, _каед, nmjö, 
   {{0x61e8ad1c,0x09e00154,0x00000000,0x00000000}},	//   lpfl, _বটগা, --, --, 
   {{0xdb1400db,0x08f00154,0x00000000,0x00000000}},	//   _això, _ছাগু_, --, --, 
   {{0xd90c205b,0x3f8c90ee,0x61e803fa,0x0a68ad1d}},	//   وید_, midu_, npfl, арти_, 
   {{0x3f8cad1e,0x7c280e2d,0x7c2c025c,0x5f4401c6}},	//   lidu_, çers, _tpar, _сүүн_, 
   {{0x7c2cad1f,0x57a4010b,0xc8d80212,0x61e8002f}},	// [dd10] _upar, ашжа, рмує_, hpfl, 
   {{0x7528026c,0x3f8cad20,0x3a740395,0x477806a6}},	//   _sbez, nidu_, _глор, абую_, 
   {{0x20000219,0x65a802f0,0x00000000,0x00000000}},	//   ških_, výhr, --, --, 
   {{0x3f8cad21,0x451802bf,0x69b801bc,0xceb00375}},	//   hidu_, иція_, ्षणी, קיף_, 
   {{0x798cad22,0x3f8c16a3,0x8534036b,0x61e80042}},	//   miaw, kidu_, زووچ, epfl, 
   {{0x798cad23,0xd76004d3,0x045400db,0x07a400c0}},	//   liaw, _گۆڕی, تئمد, _маўн, 
   {{0x88b00085,0x95c8035b,0x61e80e78,0x3f8c1210}},	//   ngɛn, _ауаа_, gpfl, didu_, 
   {{0x9484ad24,0x7528ad25,0x82340214,0x3cf0012d}},	//   _кызд, _ubez, ترها, चरों_, 
   {{0x3f8c6f19,0x00000000,0x00000000,0x00000000}},	//   fidu_, --, --, --, 
   {{0x798cad26,0x3f8c005a,0x733400d1,0x61e8002f}},	//   hiaw, gidu_, _دىئا, bpfl, 
   {{0xdb04007f,0x63a402d2,0x00000000,0x00000000}},	//   mojè, _íkna, --, --, 
   {{0x6e200334,0x00000000,0x00000000,0x00000000}},	//   rtlb, --, --, --, 
   {{0x798cad27,0x3f8cad28,0x35a00023,0xaf48007b}},	//   diaw, bidu_, ግሶታት_, _مشغل_, 
   {{0x3f8cad29,0x06b8009e,0x00000000,0x00000000}},	//   cidu_, _জলসি, --, --, 
   {{0xeab000dd,0x798c00a9,0x00000000,0x00000000}},	//   سٹر_, fiaw, --, --, 
   {{0x3eb80112,0xfe7002f2,0x00000000,0x00000000}},	//   ürte_, _تده_, --, --, 
   {{0xab98ad2a,0xa9a4136b,0xe72800f3,0x27280150}},	// [dd20] _مخدر_, _ҳинд, лоад_, лжап_, 
   {{0x31a00306,0x2d8c033f,0x5c580677,0xdca0030d}},	//   rózy_, śleć_, _עדיק, _хаьи, 
   {{0x671c2db8,0xaa4400db,0xc0d40023,0xa9a400db}},	//   _पाठक_, _انجى, _ከድሊ_, _гинд, 
   {{0x798cad2b,0x6b8c01a9,0x3f8cad2c,0xf2200210}},	//   ciaw, libg, zidu_, _महज़_, 
   {{0xd5acad2d,0xdb04007c,0xd4000d1d,0x00000000}},	//   رفه_, rmjö, пящи, --, 
   {{0xd1f40020,0xdb04ad2e,0x61e80e78,0x46dc098a}},	//   ለጹት_, smjö, tpfl, _बलिह, 
   {{0x3f8c5101,0xdef8052f,0x65b8008e,0xa1a80116}},	//   vidu_, һын_, _буар_, лтиз_, 
   {{0x61e80730,0x13e40032,0x6b8c022e,0xe57801d5}},	//   rpfl, шмәй_, hibg, _ёза_, 
   {{0xdef8ad2f,0x61e803fa,0x386c05d5,0x2cb00037}},	//   лын_, spfl, _üert_, _nyyd_, 
   {{0x20080219,0xead80154,0x61e8007c,0xdb04036e}},	//   čbi_, থরুম, ppfl, rojë, 
   {{0x3f8cad30,0xe1f03868,0x6b8c009a,0x39a00024}},	//   ridu_, _رسا_, dibg, lėse_, 
   {{0xa1c47336,0x5fb82de3,0xdb040240,0x63a8ad31}},	//   _убед, _उठवल, pojë, lofn, 
   {{0x39a002d5,0x3f8cad32,0x4c94ad33,0x798c02d0}},	//   nėse_, pidu_, зияс, viaw, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x798c3f9a,0xce90013e,0x00000000,0x00000000}},	//   tiaw, _нашъ, --, --, 
   {{0x63a80042,0xd8c800db,0x39a00064,0x00000000}},	//   hofn, гызд_, kėse_, --, 
   {{0x8d180372,0xf8b86d71,0x6b8c022e,0x7bdc031c}},	// [dd30] _ازىر_, рөн_, bibg, qqsu, 
   {{0x798cad34,0xfb14411c,0x9ba00131,0x39a00064}},	//   siaw, _بودج, _رەزى, dėse_, 
   {{0x798cad35,0xb6342bd8,0xc7b8005b,0xf4d80353}},	//   piaw, تفاع, сёт_, амеш_, 
   {{0xf434010b,0xdb04033b,0x21e002dd,0xe60400ee}},	//   жедэ, wojè, _ﺍﺨﺘﺭ, _ösýä, 
   {{0x81e802a6,0x88b0043b,0x63a80270,0x799c01f5}},	//   _বিষ_, ngɛl, fofn, _ijsw, 
   {{0x63a800a9,0x78bc00de,0x00000000,0x00000000}},	//   gofn, _izsv, --, --, 
   {{0xb5c80133,0xcb1400df,0xd5b8011c,0x00000000}},	//   _نوسم_, ללס_, _бса_, --, 
   {{0x39a00024,0xdb043b52,0x00000000,0x00000000}},	//   bėse_, lljä, --, --, 
   {{0x85047b02,0x96080154,0x81bc00de,0xdbc400a2}},	//   _رولن, _রহিম_, _apēs, _söýj, 
   {{0x93943047,0x81bc00e2,0xc2c401e2,0x00000000}},	//   _اجرا, _spēt, _کيمي, --, 
   {{0xc1cc02dd,0xed5811eb,0x00000000,0x00000000}},	//   _ﺗﯟﺭﺍ, аон_, --, --, 
   {{0xa2c400cd,0xc2cc00df,0x00000000,0x00000000}},	//   ाधर्, _עמאָ, --, --, 
   {{0x6b8c022e,0x802400f2,0x653800df,0x01a8009f}},	//   tibg, _فروم, בערד, _اُني_, 
   {{0x7ae4031c,0x00000000,0x00000000,0x00000000}},	//   _cfht, --, --, --, 
   {{0x998401e4,0x6b8c01d5,0x00000000,0x00000000}},	//   ŝiŝo_, ribg, --, --, 
   {{0x799c02d0,0x28e8ad36,0x80b002dd,0x6b8c0083}},	//   _cjsw, рдап_, _تەۋش, sibg, 
   {{0x6d542dab,0xa7645bd7,0xeb9808a0,0x6d4426bc}},	// [dd40] _inya, окад, _вип_, mdka, 
   {{0x6d540070,0x6674ad37,0xaadc000d,0x39a00006}},	//   _hnya, يدار, _मलिक, vėse_, 
   {{0x6d54ad38,0x9f4401c7,0xa9a40063,0x7790583d}},	//   _knya, _stoë_, _миод, ریفا, 
   {{0x6d44ad39,0x6d54003e,0x39a00024,0xdcf40055}},	//   ndka, _jnya, tėse_, _ācīr, 
   {{0x6d54ad3a,0x63a80008,0x68e00086,0x6434038b}},	//   _mnya, tofn, ñodu, تراء, 
   {{0x6d440076,0x39a00024,0x00000000,0x00000000}},	//   hdka, rėse_, --, --, 
   {{0x6d541958,0x5ee0015b,0x23c40014,0x63a8ad3b}},	//   _onya, ফরমে, مٕچہ, rofn, 
   {{0x64a4ad3c,0x6d54ad3d,0x63a8ad3e,0x6d4401f5}},	//   _даба, _nnya, sofn, jdka, 
   {{0x4f78001f,0x6d44ad3f,0x35c401f0,0x81bc00de}},	//   _ብዙዎቹ_, ddka, _хатҳ, _spēs, 
   {{0x543804ac,0x6d44ad40,0x8fa01fbe,0x6560022e}},	//   _דעמא, edka, мање, ljoh, 
   {{0x6d54207a,0xd36c07c0,0x6d440d27,0x6d940327}},	//   _bnya, _جهل_, fdka, nġaw, 
   {{0x6560ad41,0x6d4401f5,0xf1a402dd,0x00000000}},	//   njoh, gdka, _ерін, --, 
   {{0xe25004d3,0x9b6802e8,0x65600332,0x00000000}},	//   _رێکخ, ашва_, ijoh, --, 
   {{0x6d44ad42,0x4424045a,0x200400ef,0x1f0000f1}},	//   adka, _mqm_, _ivoi_, _کړکې, 
   {{0x4f840583,0x81dc0154,0xca7400f1,0x00000000}},	//   _بانہ, তীর_, وافغ, --, 
   {{0x6d54ad43,0x2d9001ed,0xd7500092,0xceb000d9}},	//   _gnya, ézet_, _ለማሸነ, _קיק_, 
   {{0xd6d8ad44,0xd7f807a5,0x00000000,0x00000000}},	// [dd50] ате_, руб_, --, --, 
   {{0x6d940f8b,0x27e400c6,0x7d1c08cb,0xcb68026a}},	//   tšag, íona_, lgss, _мање_, 
   {{0x69d800dd,0x95c86943,0x69b80254,0x47dc015b}},	//   ítet, ауда_, ्षशी, মীলী, 
   {{0xdcec00da,0x65600023,0x00000000,0x00000000}},	//   dicī, gjoh, --, --, 
   {{0x38c88e33,0x78bc005f,0xa3bc01ad,0x00000000}},	//   _دادی_, _uzsv, ीगढ_, --, 
   {{0x25a405be,0x83880212,0xdcec00e2,0xd610004e}},	//   čola_, обів_, ficī, _озгө, 
   {{0x200400e4,0x6d44ad45,0x00000000,0x00000000}},	//   _avoi_, ydka, --, --, 
   {{0x44243d19,0x057400db,0x81bc00de,0x317800e5}},	//   _fqm_, _قاقد, _spēr, ósz_, 
   {{0xf8b82356,0x974001a6,0x6d4402d0,0x00000000}},	//   _आरोप, šćut, vdka, --, 
   {{0x28bc1a4e,0x7d1c0112,0x6d440009,0x00000000}},	//   ्धति, egss, wdka, --, 
   {{0x6d540a2e,0x200400c7,0x7c3c127b,0x671c000d}},	//   _pnya, _evoi_, ewsr, _पासक_, 
   {{0x7d1c143a,0x00000000,0x00000000,0x00000000}},	//   ggss, --, --, --, 
   {{0x6d54009a,0xad68024c,0x00000000,0x00000000}},	//   _vnya, _ҳайз_, --, --, 
   {{0x307400d1,0xbfa80050,0x1ee400e5,0x00000000}},	//   _муһс, _واوٕ_, _ٹوٹی_, --, 
   {{0x6f00ad46,0x6d54020b,0xa3e00dba,0xa3bc0f4a}},	//   malc, _tnya, _नून_, ीगत_, 
   {{0x6d543e44,0x13e00183,0x6f00ad47,0x00000000}},	//   _unya, নীয়, lalc, --, 
   {{0x6c743de2,0x00000000,0x00000000,0x00000000}},	// [dd60] _хуйх, --, --, --, 
   {{0x69d84ac2,0x6560007f,0xab9800f1,0x00000000}},	//   ítes, wjoh, _دخبر_, --, 
   {{0x7c648375,0x6498151e,0x44240f85,0x00000000}},	//   _فایل, әтер_, _sqm_, --, 
   {{0x69dc0607,0xe45800d6,0x4424020c,0xe9a4299f}},	//   _iupe, йже_, _pqm_, _хамп, 
   {{0x69dcad48,0x6f0046aa,0xbb4802d3,0x6560ad49}},	//   _hupe, kalc, _ብምብጋ, rjoh, 
   {{0x69dcad4a,0x6f000fb7,0x656002f6,0xdcec005f}},	//   _kupe, jalc, sjoh, ticī, 
   {{0x6f00ad4b,0x69dcad4c,0x65600023,0xdef80032}},	//   dalc, _jupe, pjoh, ҙып_, 
   {{0x69dcad4d,0x1540026a,0xded404b2,0x00000000}},	//   _mupe, _песм, ሪያን_, --, 
   {{0x24080276,0x00000000,0x00000000,0x00000000}},	//   _ынаи_, --, --, --, 
   {{0x6f00ad4e,0x69dc4e7b,0x69bc000d,0x7e740107}},	//   galc, _oupe, _वीसी, дгох, 
   {{0x69dcad4f,0x00000000,0x00000000,0x00000000}},	//   _nupe, --, --, --, 
   {{0x61f80477,0xa1c40209,0x39b00139,0x00000000}},	//   _iwtl, _эбед, _nƅsp_, --, 
   {{0xf1a8006c,0x69dcad50,0xeff8001f,0x7c3cad51}},	//   _باله_, _aupe, _ለብዙ_, uwsr, 
   {{0x6f00ad52,0x9a84ad53,0x69dc1418,0x9e0404a9}},	//   calc, публ, _bupe, _ечил, 
   {{0x27e406d5,0x69dcad54,0x7980017a,0x97a4070e}},	//   íonn_, _cupe, ëlwo, җрал, 
   {{0xc1d41c5c,0xdeb8069d,0x98040395,0x0e98011a}},	//   _ﺟﺎﺯﺍ, _ደመና_, зяжд, _לשול, 
   {{0x7d0cad55,0x69dcad56,0x69d85b84,0x00000000}},	// [dd70] _idas, _eupe, íter, --, 
   {{0x69dcad57,0xddd800e5,0x00000000,0x00000000}},	//   _fupe, lytő, --, --, 
   {{0xd49821bf,0x7bc40117,0x69dcad58,0x69bc00e1}},	//   әре_, _ihhu, _gupe, _वीवी, 
   {{0x6f000219,0x00000000,0x00000000,0x00000000}},	//   zalc, --, --, --, 
   {{0x7d0cad59,0xf8b013de,0x3958315a,0x69dc0034}},	//   _mdas, _شکر_, _inss_, _zupe, 
   {{0x8c1c025f,0x69dc2af2,0xdb0400bc,0xded40092}},	//   מודי, _yupe, kojí, ሪካና_, 
   {{0x6f00ad5a,0x67d40bc9,0x7d0c0365,0xc30404d3}},	//   valc, _uņja, _odas, ربوو, 
   {{0x6f00ad5b,0x6d94025c,0xdb04032e,0x00000000}},	//   walc, nġat, gljú, --, 
   {{0x6f00ad5c,0x3948a3b8,0x5de401ec,0x010800f1}},	//   talc, idas_, _ﺍﻟﻨﻴ, ستيو_, 
   {{0x7d0cad5d,0x3948ad5e,0x43940640,0x2618012d}},	//   _adas, hdas_, _заус, मूवी_, 
   {{0x6f00ad5f,0xada4ad60,0x59bc80ee,0x3948020b}},	//   ralc, данл, ्षार, kdas_, 
   {{0xed58024d,0x6f00ad61,0x394899c9,0x61440150}},	//   цом_, salc, jdas_, _يىلە, 
   {{0x69dcad62,0x3948ad63,0x5928025c,0x7d0ca573}},	//   _supe, ddas_, _སྡེས_, _ddas, 
   {{0x7d0c033d,0x3948ad64,0x7bc44c27,0x69dcad65}},	//   _edas, edas_, _chhu, _pupe, 
   {{0x69dc013c,0x1ae0011c,0x00000000,0x00000000}},	//   _qupe, тосм, --, --, 
   {{0x39580048,0x3948ad66,0x69dc18f7,0xfe706eb7}},	//   _cnss_, gdas_, _vupe, _حده_, 
   {{0x1c40ad67,0xf3fc05ac,0x00000000,0x00000000}},	// [dd80] _аным, _উৎসৰ_, --, --, 
   {{0x69dc2af2,0xb864ad68,0xeb98005b,0xbbe801d3}},	//   _tupe, راقو, _фио_, _ڈریم_, 
   {{0x69dc1a56,0xa96807d5,0x2b5800d8,0x28ac01ad}},	//   _uupe, _дина_, _inpc_, _झुरि, 
   {{0x39580135,0xa3e00412,0x00000000,0x00000000}},	//   _gnss_, _नंद_, --, --, 
   {{0xd4640640,0x12d402dd,0x00000000,0x00000000}},	//   мице_, _ﻀﺭﻭﺭ, --, --, 
   {{0x5330ad69,0x68f4ad6a,0x2d8000b5,0x66180267}},	//   вешт, lbyd, hhke_, _åtko, 
   {{0xded4001f,0x28bc1b61,0xf4240166,0x626405a9}},	//   ሪያና_, ्धवि, _үзсү, باشق, 
   {{0x68f408fb,0x27f0062c,0x52700114,0xdeb80023}},	//   nbyd, opyn_, ђују, _ደመኛ_, 
   {{0x7d0c022e,0xa6c80154,0xbf10013d,0x3218002b}},	//   _rdas, াঁওয়, гүлә, _āsye_, 
   {{0x3e4c012c,0x39480006,0x7d0c1c4b,0xd24c05d9}},	//   _pět_, zdas_, _sdas, _ھنن_, 
   {{0xd24c0a81,0x39480024,0x3d9400c7,0x248400d7}},	//   _پنن_, ydas_, еинр, lzom_, 
   {{0xc0f8044e,0x2b580276,0xdb0400bc,0x27f0017a}},	//   _ወትሩ_, _anpc_, rojí, kpyn_, 
   {{0xf1a8ad6b,0x403422ff,0x68f4ad6c,0x671c0037}},	//   _عامه_, _челс, dbyd, _पांक_, 
   {{0xdb0402fb,0x69c4023a,0x60c0ad6d,0xdbc40254}},	//   pojí, _ahke, _izom, _lööj, 
   {{0x3d9400d1,0x5928031c,0x0bd40120,0x1ea8020c}},	//   _пикр, _སྡུས_, торџ, _باشي_, 
   {{0x7d0c1a8a,0x69c40295,0x2d80ad6e,0x27f00ea0}},	//   _udas, _chke, chke_, fpyn_, 
   {{0x3948ad6f,0x24840e3c,0x80c40034,0x60c0031c}},	// [dd90] rdas_, jzom_, ाइटे, _jzom, 
   {{0x3948ad70,0x2a6c0240,0x59bc012c,0x7bc40254}},	//   sdas_, ëmbë_, ्षहर, _uhhu, 
   {{0x3948ad71,0xd5e802de,0x2618473c,0xb6c800e5}},	//   pdas_, زعان_, मूली_, سائے_, 
   {{0x60c0675a,0x2a740375,0x3958ad72,0x95c81a5c}},	//   _ozom, _נערך_, _unss_, цуза_, 
   {{0x60c0ad73,0x18b001e0,0xe464010e,0xd8b800e5}},	//   _nzom, _рҙар, _çöli_, _گدھا_, 
   {{0x8c1c008d,0x69c8011c,0x59bc1d97,0x24508863}},	//   קווי, _èfer, ्षवर, انوس, 
   {{0x60c0ad74,0x00000000,0x00000000,0x00000000}},	//   _azom, --, --, --, 
   {{0x6ff4ad75,0x42b800d1,0xd5b8003b,0x00000000}},	//   нчох, بنىڭ_, _єсв_, --, 
   {{0x2484012d,0x1b1400eb,0x00000000,0x00000000}},	//   czom_, দ্যে_, --, --, 
   {{0x60c0ad76,0x6adc5219,0x80c405d7,0xf1b80010}},	//   _dzom, _मलेर, ाइजे, slš_, 
   {{0x60c0ad77,0x59d8ad78,0x68f403cb,0x00000000}},	//   _ezom, _मंगर, ybyd, --, 
   {{0x27f00108,0x52c80709,0x00000000,0x00000000}},	//   ypyn_, ाधीस, --, --, 
   {{0xc0f802d3,0x3e7401e1,0xc02415bf,0x00000000}},	//   ለኩም_, _pútú_, _لىني, --, 
   {{0x69c4069c,0x2d8002d3,0x00000000,0x00000000}},	//   _shke, shke_, --, --, 
   {{0x7c900020,0x60c0031c,0x68f4143a,0x00000000}},	//   ጀመረው_, _zzom, tbyd, --, 
   {{0xd9403db0,0x81dc2b1b,0xf9c401c6,0x24840419}},	//   леси, তীক_, васү, yzom_, 
   {{0x68f4ad79,0xee4800e4,0xeb98005b,0x3e7401e1}},	// [dda0] rbyd, _hẽ_, _нии_, _tútú_, 
   {{0xee48ad7a,0x27f000ad,0xdbc4000d,0xaa4418a4}},	//   _kẽ_, rpyn_, _sööj, _зеол, 
   {{0x5af80a7c,0x58740014,0x00000000,0x00000000}},	//   _מליצ, وٝہس_, --, --, 
   {{0xee48001e,0xeaf8ad7b,0x69c400c5,0x27f0ad7c}},	//   _mẽ_, _برکت_, _uhke, ppyn_, 
   {{0xee480016,0x55e00032,0x47440124,0x59280327}},	//   _lẽ_, _ҡорб, _иҭаг, _སྡིས_, 
   {{0x2900ad7d,0x290c013f,0x64a40124,0x2484ad7e}},	//   _heka_, ɔfaa_, _ҟаза, rzom_, 
   {{0x2484ad7f,0x60c000dd,0x2900ad80,0xdbc400af}},	//   szom_, _szom, _keka_, _tööj, 
   {{0xd6540302,0xae0800e1,0x2900ad81,0x27e00221}},	//   _אילת_, _विजन_, _jeka_, _kukn_, 
   {{0x2900ad82,0xcb20012d,0x00000000,0x00000000}},	//   _meka_, _बांड_, --, --, 
   {{0x2d9004ba,0xee480208,0x00000000,0x00000000}},	//   _amye_, _bẽ_, --, --, 
   {{0xe0d803b7,0x661c0280,0xdb04035b,0xef200037}},	//   _еве_, nupk, jojá, _मारऽ_, 
   {{0x29001326,0xc2f802f5,0x673c01a4,0x5698010f}},	//   _neka_, _ঘাটি_, hepj, לייצ, 
   {{0x60c0ad83,0xdcb800a7,0x661c003e,0x64400165}},	//   _uzom, ящо_, hupk, nwoi, 
   {{0x661cad84,0x6440004c,0xc98401d5,0x26e8012d}},	//   kupk, iwoi, қуси, टडोर_, 
   {{0x2900601a,0x6d940029,0x27e00010,0xdb4c0133}},	//   _beka_, mšan, _aukn_, لێک_, 
   {{0x661c33cb,0x6d94005f,0x58843cbb,0x00000000}},	//   dupk, lšan, ныза, --, 
   {{0x3dc81c06,0x00000000,0x00000000,0x00000000}},	// [ddb0] _ihaw_, --, --, --, 
   {{0xdd900046,0xde5c044e,0x29006011,0x3a74ad85}},	//   _шақы, _ንመንግ, _eeka_, _алор, 
   {{0x661c0a2e,0x3dc8ad86,0x29000085,0xcf9000c8}},	//   gupk, _khaw_, _feka_, נטע_, 
   {{0x2124002f,0xf4980133,0x99640108,0x74f80815}},	//   _ncoh_, وپات_, _чтол, федр_, 
   {{0x6d940029,0x25e4000d,0x00000000,0x00000000}},	//   kšan, _जूठी_, --, --, 
   {{0x6d940fb7,0x2900ad87,0x3234009d,0x00000000}},	//   jšan, _zeka_, вхис, --, 
   {{0x2900ad88,0xe280010b,0x00000000,0x00000000}},	//   _yeka_, илши, --, --, 
   {{0x3dc8016b,0x6d94ad89,0x45d4ad8a,0xee4801fb}},	//   _nhaw_, ešan, _босс, _rẽ_, 
   {{0xee4801dc,0x8af803e3,0x00000000,0x00000000}},	//   _sẽ_, _şəms, --, --, 
   {{0x7654a719,0x2124003e,0x6d94005f,0x3dc8ad8b}},	//   _krzy, _ecoh_, gšan, _ahaw_, 
   {{0x1b240183,0x21240076,0xf7cc0220,0xdb0401e1}},	//   য়াই_, _fcoh_, _ﺑﻮﻟﻪ, _ìmùk, 
   {{0x3dc8ad8c,0xee480016,0xdb0402fb,0xd24c036b}},	//   _chaw_, _vẽ_, vojá, _پنچ_, 
   {{0x2900ad8d,0x3dc801d9,0x6d94ad8e,0x1c400108}},	//   _reka_, _dhaw_, bšan, аням, 
   {{0x2900ad8f,0xdee0ad90,0x27e0ad91,0x7ae000d7}},	//   _seka_, _коши, _rukn_, žltn, 
   {{0x2900ad92,0x49041e4a,0xa4940115,0x6440012d}},	//   _peka_, лүнг, raϲi, zwoi, 
   {{0xdb04ad93,0x3dc8047e,0x7bd80066,0xccb40166}},	//   rojá, _ghaw_, _èwun, _бәгь, 
   {{0x2900ad94,0x1b142f8b,0xd940ad95,0x7654010b}},	// [ddc0] _veka_, দ্ধে_, шети, _arzy, 
   {{0x2900ad96,0x661cad97,0x7654033f,0xdb040022}},	//   _weka_, tupk, _brzy, pojá, 
   {{0x2900ad98,0xf608ad99,0xa9a40124,0x673c01d3}},	//   _teka_, فتنه_, _аинд, repj, 
   {{0x661cad9a,0x673c025c,0x765421f2,0xa804022e}},	//   rupk, sepj, _drzy, _измл, 
   {{0x661c0438,0x76540165,0x321800b8,0x00000000}},	//   supk, _erzy, _āsya_, --, 
   {{0xf65000dd,0xd36c21ec,0x66e41614,0x93b002d5}},	//   جئے_, يهن_, _јова, абіц, 
   {{0x25a8038b,0x76540034,0xb6c401e0,0xa3e00412}},	//   _قدري_, _grzy, _бирһ, _नूर_, 
   {{0xf1d400f7,0x6d940113,0x7de801ef,0x84c401ee}},	//   гөчө, wšan, _běsn, _йәлд, 
   {{0x6d94000a,0x3dc80042,0xe3b800f3,0x00000000}},	//   tšan, _rhaw_, _жба_, --, 
   {{0x3dc8ad9b,0x9f4401e1,0x6d9400e2,0x9f880254}},	//   _shaw_, _awoò_, ušan, _löön_, 
   {{0x6d946c85,0x539804ae,0x1718008f,0xa2cc1fd2}},	//   ršan, _קיבו, וויע, धेश्, 
   {{0x614415ed,0x6f0c02a8,0x9cc80228,0xd83c02fb}},	//   _једа, _ɓaci, дыга_, áčku_, 
   {{0x6d94ad9c,0x1abc00eb,0x397401a9,0x00000000}},	//   pšan, _আলো, қлаё, --, 
   {{0x7e54007b,0xd83c0427,0xfc7001d5,0x00000000}},	//   _منتص, ščku_, иққў, --, 
   {{0xd1f40201,0x3dc80652,0xf7cc0150,0x00000000}},	//   _ወቅት_, _thaw_, _ﺑﻮﻛﻪ, --, 
   {{0x3dc822d0,0x00000000,0x00000000,0x00000000}},	//   _uhaw_, --, --, --, 
   {{0x6d940153,0x9f5001e1,0x00000000,0x00000000}},	// [ddd0] išal, _ìyó_, --, --, 
   {{0x765414cf,0x7c2c025c,0xda78084c,0xbd8801d5}},	//   _przy, _iqar, _жям_, _آچگن_, 
   {{0x6d9407f5,0x9f88000d,0x8aa41b0a,0x3eb8002f}},	//   kšal, _föön_, _вряд, ürth_, 
   {{0x9f40006a,0x6d9409a8,0x628803e3,0x00000000}},	//   êkê_, jšal, dzfo, --, 
   {{0x58846bb9,0x7c2c025c,0x64b401e4,0x00000000}},	//   _рына, _jqar, jĝiĉ, --, 
   {{0x76543177,0xd3780262,0x7c2c031c,0x6ff400d1}},	//   _trzy, ьче_, _mqar, қчих, 
   {{0xdb04008c,0xe72c01d5,0xd1600022,0x8af803b9}},	//   lljó, rnеt_, инкқ, _şəks, 
   {{0x7c2c32ff,0xb14400a8,0xdb0401f4,0x00000000}},	//   _oqar, унил, lojä, --, 
   {{0xdb041427,0x00000000,0x00000000,0x00000000}},	//   nljó, --, --, --, 
   {{0x10a00075,0x5f40104b,0xdb0401f4,0x9f8018bc}},	//   лиқн, مچىل, nojä, йгыд, 
   {{0x7c2c4f6b,0x5184ad9d,0x29e80115,0xdb0401a8}},	//   _aqar, _иуда, _aĝan_, hljó, 
   {{0x7de8012c,0x6da40ee8,0xa3e00037,0x00000000}},	//   _těsn, امحم, _नूँ_, --, 
   {{0xd0000046,0x78bc4268,0xdb040108,0xf91c000d}},	//   _толқ, _nysv, kojä, _फाड़ा_, 
   {{0xeab88fa3,0x9f880037,0x01d002dd,0x6d940064}},	//   ейг_, _söön_, _ﺗﺎﯕﻌ, mšam, 
   {{0x7528014b,0x7c2c0869,0xe72c01a9,0x3a28013d}},	//   _ocez, _eqar, znеs_, керү_, 
   {{0x1ce00003,0x6e20058a,0x888401d3,0x9f5001e1}},	//   _ཧུར_, mulb, لیجن, _ìyò_, 
   {{0x6e20ad9e,0xdb040008,0xa3e000c5,0xec781d39}},	// [dde0] lulb, gljó, _नूं_, _чпп_, 
   {{0x9bf80375,0xdb04007c,0x00000000,0x00000000}},	//   _רהיט, gojä, --, --, 
   {{0x6e200280,0xd1f40092,0x00000000,0x00000000}},	//   nulb, _ወቅቱ_, --, --, 
   {{0x2408ad9f,0x1a98008f,0xf65428f6,0x64c40b24}},	//   енди_, _טייע, штую, هيال, 
   {{0x6e2003fa,0x1ce0031c,0x648401d5,0x6d940427}},	//   hulb, _ཧུལ_, _rаis, jšam, 
   {{0x7528014b,0x9878008f,0x628817da,0x3774010b}},	//   _ecez, _טאכט, tzfo, _кысс, 
   {{0xf1c802fb,0xf66400fd,0x6d840162,0x6d94ada0}},	//   znáš_, _керү, _móab, ešam, 
   {{0x62880112,0x92540472,0x00000000,0x00000000}},	//   rzfo, اشور_, --, --, 
   {{0x6d48016b,0x6d941a5c,0x705401d3,0x628800e5}},	//   _ɔfat, ršal, لنٹا, szfo, 
   {{0x7c2c022e,0x6e200857,0x00000000,0x00000000}},	//   _rqar, fulb, --, --, 
   {{0x6d94ada1,0x7c2c02d3,0x6e20ada2,0x62582cc8}},	//   pšal, _sqar, gulb, _ярар_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x0c840961,0x00000000,0x00000000,0x00000000}},	//   бырм, --, --, --, 
   {{0x6e200115,0x78bc017a,0x8fa0048a,0xdb040162}},	//   bulb, _rysv, _лаче, vljó, 
   {{0x39a00153,0xdb0401f4,0x00000000,0x00000000}},	//   lėsi_, vojä, --, --, 
   {{0x6abc0fac,0x7c2c0135,0x0904004e,0xada000d7}},	//   _dypf, _tqar, йчум, ťúre, 
   {{0x7c2c0357,0xdb04005b,0x39a000c0,0x00000000}},	// [ddf0] _uqar, tojä, nėsi_, --, 
   {{0x78bc0232,0x25e405f9,0xd77410e0,0xdb04066a}},	//   _vysv, _जूही_, دارع, rljó, 
   {{0xe7e80034,0x78bc0af9,0xc7c400cf,0xdb040108}},	//   _झूठा_, _wysv, ссти, rojä, 
   {{0x85044950,0x78bc03d4,0x39a00006,0x63b8ada3}},	//   مومن, _tysv, kėsi_, _aktn, 
   {{0x671c02ab,0xb4e43be5,0x271800cc,0x88d80108}},	//   _पाचक_, _नली_, ন্ধো_, _бьёт_, 
   {{0x9d9402e3,0x1b140154,0x39a00153,0x00000000}},	//   ụahị, দ্রে_, dėsi_, --, 
   {{0x6d400022,0x386803b9,0x00000000,0x00000000}},	//   _ñoag, lxar_, --, --, 
   {{0x752801f0,0x63b801a9,0xd5a02099,0x6e20ada4}},	//   _ucez, _ektn, _الری, vulb, 
   {{0x6004ada5,0xef84ada6,0x3868ada7,0x34943bfd}},	//   аным_, илип, nxar_, _таар, 
   {{0xdfcc1129,0x3868ada8,0x6e20ada9,0xb4b401ee}},	//   ويي_, ixar_, tulb, _биғә, 
   {{0xdcec01ef,0x00000000,0x00000000,0x00000000}},	//   _úděl, --, --, --, 
   {{0x6e2000f2,0x3034005b,0x39a00064,0x00000000}},	//   rulb, _ведё, bėsi_, --, 
   {{0xdfcc1d1f,0x6e20adaa,0x00000000,0x00000000}},	//   _ڪيو_, sulb, --, --, 
   {{0x6a84adab,0x6e20adac,0xef1855dd,0xee380064}},	//   алга, pulb, _рмк_, _анк_, 
   {{0x6994adad,0x67d40227,0xaa44adae,0xdfcc009a}},	//   арах, _uņji, шевл, _تيو_, 
   {{0x316cadaf,0xdd8c01e2,0x00000000,0x00000000}},	//   njez_, _يوو_, --, --, 
   {{0x2bc82374,0xfd4c00b8,0xe54001e1,0x87e800e5}},	// [de00] _илип_, _nanṛ, _àséè, اظرہ_, 
   {{0x6abc0b21,0x3ea00055,0x00000000,0x00000000}},	//   _typf, _śiti_, --, --, 
   {{0xdd8cadb0,0xa50800d8,0x00000000,0x00000000}},	//   _روی_, вееа_, --, --, 
   {{0xaa840510,0x316c025c,0x2bb41684,0x00000000}},	//   _edýä, jjez_, ृतवा, --, 
   {{0xd4002dc1,0x64a4adb1,0x6d9400c0,0x00000000}},	//   оящи, шада, ešak, --, 
   {{0xa6c8adb2,0xd3b402bf,0x853406c3,0x00000000}},	//   _алга_, алії_, _گورچ, --, 
   {{0xe81c7382,0x6d940960,0x00000000,0x00000000}},	//   यंका_, ršaj, --, --, 
   {{0x16f00867,0x26c817a3,0x316c0023,0x39a00024}},	//   _བཅོམ_, _izbo_, gjez_, tėsi_, 
   {{0xdef8adb3,0x03540116,0x20000066,0x6d940010}},	//   кын_, _гүлә_, èki_, pšaj, 
   {{0x303820d4,0x39a00153,0x00000000,0x00000000}},	//   اتيک_, rėsi_, --, --, 
   {{0xdce8adb4,0xdb2006af,0x4f640006,0xa2980023}},	//   šiča, _àréa, ршым_, _ፈርኦን_, 
   {{0x25a40cfd,0x6f2c0051,0x39a00064,0x00000000}},	//   nnol_, _ấntư, pėsi_, --, 
   {{0x3ff40f1b,0x25a40429,0x3868adb5,0x00000000}},	//   _اكتر, inol_, xxar_, --, 
   {{0x4fb0007b,0x00000000,0x00000000,0x00000000}},	//   _وصور, --, --, --, 
   {{0xb34403b7,0x38680054,0xce9012d7,0x99d40b73}},	//   leçã, wxar_, _машъ, لترا, 
   {{0x386821cb,0xf8b001d9,0x00000000,0x00000000}},	//   txar_, ۪کھ_, --, --, 
   {{0xa3e0000d,0x2ee80205,0x00000000,0x00000000}},	// [de10] _नंग_, _şafi_, --, --, 
   {{0x38680137,0xd7640efb,0x25a40368,0x855800e5}},	//   rxar_, جەسى_, enol_, یشنز_, 
   {{0x7ae414dc,0x73d8adb6,0x0708212d,0xf8b00014}},	//   _ight, ңдер_, شيني_, تکھ_, 
   {{0x25a4adb7,0x05742dfc,0x6d940219,0x00000000}},	//   gnol_, ياند, však, --, 
   {{0xb34406ed,0xe81c2a05,0xd7f80408,0x00000000}},	//   jeçã, _पिया_, _шун_, --, 
   {{0x25a40042,0x47e401e0,0x00000000,0x00000000}},	//   anol_, _фәтҡ, --, --, 
   {{0x29e8010f,0x25a40254,0x9564030d,0x00000000}},	//   _aĝaj_, bnol_, _къад, --, 
   {{0x25a4004e,0x92e400eb,0x00000000,0x00000000}},	//   cnol_, পরে_, --, --, 
   {{0x3374adb8,0x7ae4047e,0x316c05c7,0x00000000}},	//   _лгар, _oght, rjez_, --, 
   {{0x11640bce,0x439402dd,0xa3c837cc,0x2be400fe}},	//   الکی_, _даус, ोषण_, _কবলৈ_, 
   {{0x31340116,0x00000000,0x00000000,0x00000000}},	//   _геер, --, --, --, 
   {{0x6da4adb9,0x7ae41368,0xb34400d8,0xd77c0023}},	//   сима, _aght, beçã, ረሽበራ_, 
   {{0xb3440120,0xe0ccadba,0x2bb405d7,0xf1b8adbb}},	//   ceçã, _хв_, ृतला, moš_, 
   {{0xf1b8adbc,0x00000000,0x00000000,0x00000000}},	//   loš_, --, --, --, 
   {{0x25a40cfd,0x1a000395,0x00000000,0x00000000}},	//   ynol_, зпсм, --, --, 
   {{0x7ae4016d,0xf1b8adbd,0x6d94139f,0x00000000}},	//   _eght, noš_, kšai, --, 
   {{0x1864adbe,0x25a4adbf,0xdb2007d6,0xe738adc0}},	// [de20] бати_, vnol_, _کوپی, леа_, 
   {{0x25a40368,0xaf18015b,0x6a84084c,0x661c02f0}},	//   wnol_, ত্রণ_, _глоа, trpk, 
   {{0xe618adc1,0xf1b80841,0x6d940024,0x88c40055}},	//   уде_, koš_, ešai, _āśuk, 
   {{0xa9682bbd,0xe7380166,0xa0240254,0xe2a801d9}},	//   _сима_, _өем_, nmöö, ۯاشن_, 
   {{0xf1b82a53,0x69d4a2d3,0x25a4015d,0x00000000}},	//   doš_, mmye, rnol_, --, 
   {{0xdc3400df,0x944000d1,0x00000000,0x00000000}},	//   מאנט_, سپىن, --, --, 
   {{0x6d58005f,0x66e401b9,0xe81c0892,0xa0240037}},	//   ētaj, _воҳа, _पिडा_, kmöö, 
   {{0x6d441326,0xb34403b7,0xf1b8009b,0xe0e400eb}},	//   jeka, teçã, goš_, নর্ন, 
   {{0xb1440014,0x8760001f,0x92e400fe,0x00000000}},	//   زیوم_, _ለማስቀ, পৰে_, --, 
   {{0xb3440261,0xb35445b6,0xdb040008,0xf1a400f7}},	//   reçã, _وینا_, lljö, йрөн, 
   {{0x6d4408f5,0xdce81109,0xf1b82e31,0xe1f8004e}},	//   feka, žičn, boš_, _сге_, 
   {{0x6d44adc2,0xf1b801a6,0x72e000db,0xef800116}},	//   geka, coš_, _تۋىم, зһәп, 
   {{0x7de80118,0x5de402dd,0x00000000,0x00000000}},	//   _měsi, _ﺍﻟﻌﻴ, --, --, 
   {{0x61e0adc3,0x60c0adc4,0xdde0010b,0xa024000d}},	//   _hiol, _iyom, _нәмү, amöö, 
   {{0x6d443917,0x61e0adc5,0x60c0213f,0x77740175}},	//   beka, _kiol, _hyom, _rozx, 
   {{0x61e0adc6,0x69d4089c,0x60c0adc7,0x5f4401c6}},	//   _jiol, gmye, _kyom, _түүн_, 
   {{0x61e0adc8,0x7798adc9,0x00000000,0x00000000}},	// [de30] _miol, акар_, --, --, 
   {{0x6d84022c,0x19540220,0x7ae40363,0xf1b813d5}},	//   _jóan, шағы_, _ught, zoš_, 
   {{0x60c00083,0x09e406ed,0x629c00db,0x00000000}},	//   _lyom, _ноќн, úpol, --, 
   {{0x61e0adca,0xf9840046,0x60c0adcb,0x3f8c0327}},	//   _niol, _بەرۋ_, _oyom, hhdu_, 
   {{0x60c0066d,0x3f8c01d9,0x798cadcc,0xf1b800d0}},	//   _nyom, khdu_, mhaw, voš_, 
   {{0xe81c13da,0x6d44adcd,0x61e0adce,0xcec0012c}},	//   _पिता_, zeka, _aiol, _jiří_, 
   {{0x2d8039c2,0x60c0adcf,0x4b7c27af,0xf1b8142b}},	//   ykke_, _ayom, ראוו, toš_, 
   {{0x60c0add0,0x798c778b,0xc7900020,0x20040076}},	//   _byom, nhaw, _ሁለተኛ_, _bwoi_, 
   {{0x6d44add1,0x61e0add2,0xf1b83421,0x60c0add3}},	//   veka, _diol, roš_, _cyom, 
   {{0x6d44add4,0x798c0227,0xf1b84ca5,0x61e00254}},	//   weka, hhaw, soš_, _eiol, 
   {{0x798c9601,0x60c0add5,0x3134add6,0xa0240254}},	//   khaw, _eyom, _межр, tmöö, 
   {{0x798cadd7,0x68e00006,0x61e0add8,0x2bec256a}},	//   jhaw, žodi, _giol, _इंदू_, 
   {{0x798cadd9,0xe6c40bca,0x6d9405ce,0x60c0adda}},	//   dhaw, _वर्ज, kšav, _gyom, 
   {{0x61e0addb,0x6d940219,0x3f8c047e,0x5f2401af}},	//   _ziol, jšav, chdu_, _дошм_, 
   {{0x6d44addc,0x798c045f,0x61e0062c,0x1ae001d5}},	//   peka, fhaw, _yiol, дорм, 
   {{0xddc08807,0xe8f8addd,0x798cadde,0x6d44addf}},	//   _общи, рла_, ghaw, qeka, 
   {{0xf990009f,0x5de401ec,0x00000000,0x00000000}},	// [de40] ربِ_, _ﺍﻟﻐﻴ, --, --, 
   {{0x98700092,0x00000000,0x00000000,0x00000000}},	//   _የዘመኑ_, --, --, --, 
   {{0x798cade0,0x00000000,0x00000000,0x00000000}},	//   bhaw, --, --, --, 
   {{0x798c6e38,0xe4585119,0x3f8c0200,0x00000000}},	//   chaw, иже_, zhdu_, --, 
   {{0xd24c0272,0xa3481607,0x61e001a4,0xdb100248}},	//   ێنه_, изда_, _riol, _ọ̀yọ, 
   {{0x61e0ade1,0x60c0037e,0x3f8c025c,0x00000000}},	//   _siol, _ryom, xhdu_, --, 
   {{0x6f000175,0x60c0ade2,0x6d8408a5,0xa50800f3}},	//   dblc, _syom, _róan, _веба_, 
   {{0xb82c0092,0xd1340408,0xddd800c7,0x673800a2}},	//   _ድርጅቱ, охь_, pytũ, _ötjb, 
   {{0x23281377,0x00000000,0x00000000,0x00000000}},	//   _вози_, --, --, --, 
   {{0x60c0ade3,0xe298ade4,0x798cade5,0x61ec6c80}},	//   _vyom, _каз_, zhaw, _éblo, 
   {{0x60c0ade6,0x1ce00135,0x61e0ade7,0xdb040240}},	//   _wyom, _ཧུང_, _tiol, snjë, 
   {{0x61f80c8c,0x9c1001f2,0xe04800aa,0x798cade8}},	//   _ittl, _jọgb, _نشته_, xhaw, 
   {{0x4c94ade9,0x60c04a7d,0xe7e800e1,0x2b840798}},	//   дияс, _uyom, _झूला_, _côco_, 
   {{0x798c04fe,0x00000000,0x00000000,0x00000000}},	//   whaw, --, --, --, 
   {{0x798c055a,0x3f9cadea,0x7f4802d0,0x25e4190e}},	//   thaw, _imvu_, medq, _जंगी_, 
   {{0x6d8403b2,0x00000000,0x00000000,0x00000000}},	//   _jóal, --, --, --, 
   {{0x798c2784,0xf8b80323,0x7d0c009a,0x3ce800c5}},	// [de50] rhaw, сөн_, _ieas, _igav_, 
   {{0x798cadeb,0x2bd01b87,0x61f80857,0x7d0cadec}},	//   shaw, _दीपा, _ottl, _heas, 
   {{0x798c4ec2,0x6d9407f5,0xc8c801d3,0x00000000}},	//   phaw, ršav, موہن_, --, 
   {{0xb8d000bd,0x798caded,0x7f480455,0x85e800d4}},	//   _ওর_, qhaw, hedq, ідів_, 
   {{0x3948adee,0x6d9408ad,0x7d0c50c6,0x61f8adef}},	//   meas_, pšav, _meas, _attl, 
   {{0x7d0cadf0,0x6d5800e2,0xa878011a,0x287800d9}},	//   _leas, ētai, _האשר, _הנשמ, 
   {{0x7e7c1477,0x799c0175,0x7d0c02d0,0x36d4005a}},	//   ørpl, _kmsw, _oeas, _ховр, 
   {{0x7d0cadf1,0x3ce8014f,0x2bd009fa,0x00000000}},	//   _neas, _ngav_, _दीना, --, 
   {{0x61f8adf2,0xb82c0092,0x00000000,0x00000000}},	//   _ettl, _ድርጊቱ, --, --, 
   {{0x39489a0f,0x7d0c02c4,0x8d640092,0x9264adf3}},	//   heas_, _aeas, _ስማቸው_, _ودام, 
   {{0xed58adf4,0x6d941b24,0x799c62f1,0x3948adf5}},	//   бон_, kšat, _omsw, keas_, 
   {{0x7d0cadf6,0x3f9c014b,0x6d9409a8,0x606000cf}},	//   _ceas, _emvu_, jšat, بۇۇل, 
   {{0x7d0c0876,0x3948adf7,0x5de401ec,0x00000000}},	//   _deas, deas_, _ﺍﻟﻜﻴ, --, 
   {{0xf1940014,0x7d0c1368,0x799c035a,0x00000000}},	//   _بُچھ, _eeas, _amsw, --, 
   {{0xa96823b3,0x799c035a,0x7d0cadf8,0xad4000db}},	//   бива_, _bmsw, _feas, _كۉدۉ, 
   {{0x7d0c4011,0x799c03ac,0xfe70adf9,0x7e7c0267}},	//   _geas, _cmsw, _جده_, ärpe, 
   {{0xa2a00d2b,0x1864adfa,0x6d54757e,0x57e41cb8}},	// [de60] _केन्, пати_, _iaya, здум_, 
   {{0x6d54adfb,0x799c8a15,0x6d942ba4,0x5c58123b}},	//   _haya, _emsw, ršau, _פדיק, 
   {{0x7d0cadfc,0x3948adfd,0x6d54adfe,0x6b9c02d0}},	//   _yeas, beas_, _kaya, _impg, 
   {{0x6d54adff,0x799c02d0,0xe87000d1,0x7f4803ac}},	//   _jaya, _gmsw, _كۆزگ, zedq, 
   {{0x6d8403b2,0xd4e00eba,0xf7700583,0xf3f40ee8}},	//   _róal, нюши, راے_, وتوک, 
   {{0x6d54ae00,0x2910ae01,0x64a400c7,0x9c1001e1}},	//   _laya, laya_, _ҵаба, _wọgb, 
   {{0x9c10063f,0x799c02d0,0xd1d00092,0xe20802d2}},	//   _tọgb, _ymsw, _ያለች_, dmóð_, 
   {{0x2910ae02,0x6d54ae03,0x7de8038e,0xd5e40327}},	//   naya_, _naya, _měst, _སྤྲག, 
   {{0x7d0cae04,0x5de402dd,0x7f48035a,0x00000000}},	//   _reas, _ﺍﻟﻘﻴ, tedq, --, 
   {{0x29104ec2,0x6d54ae05,0xe7bc590f,0x7d0c976a}},	//   haya_, _aaya, ्तिप, _seas, 
   {{0x6d54ae06,0x931002dd,0x7d0c0d92,0x6144ae07}},	//   _baya, _سونش, _peas, _нежа, 
   {{0x6d540050,0xd00c0133,0x7f480857,0xe2980117}},	//   _caya, _ڕله_, sedq, _каҷ_, 
   {{0x2910ae08,0xe7bc4c83,0x7d0c6931,0x39480381}},	//   daya_, ्ताप, _veas, veas_, 
   {{0x7d0cae09,0x6d5403ac,0x799c035a,0xcbe401f4}},	//   _weas, _eaya, _smsw, ецси, 
   {{0x7d0c1cf8,0x6d54ae0a,0x6d941ebd,0x291029ef}},	//   _teas, _faya, tšat, faya_, 
   {{0x394801ab,0x7de801ef,0x00000000,0x00000000}},	//   ueas_, _děst, --, --, 
   {{0x6d9408a4,0x3834ae0b,0xd7f81188,0x00000000}},	// [de70] ršat, ьнар, суб_, --, 
   {{0x3948ae0c,0x6d54ae0d,0x29100083,0x68f401ab}},	//   seas_, _zaya, aaya_, acyd, 
   {{0x3948ae0e,0x95c8ae0f,0xe9f00124,0x6d5800e2}},	//   peas_, буда_, _аҧсы, ētav, 
   {{0x2910ae10,0x799c0117,0x2c400605,0x6d54ae11}},	//   caya_, _umsw, _wɔde_, _xaya, 
   {{0x05740046,0xefbc0023,0x00000000,0x00000000}},	//   عامد, _ሰሪዑ_, --, --, 
   {{0x67d40227,0x6d940427,0xca9c0023,0x00000000}},	//   _uņjp, nšar, _ግዜኦም_, --, 
   {{0x6d840005,0x00000000,0x00000000,0x00000000}},	//   _sóam, --, --, --, 
   {{0xc0a80451,0x998000ef,0xf4a40092,0x00000000}},	//   ڻايل_, drjū_, ማቋረጥ_, --, 
   {{0x6d54ae12,0xc1d40022,0x00000000,0x00000000}},	//   _raya, хҩцә, --, --, 
   {{0x2910ae13,0x5f403955,0xc780001f,0xa3c800cd}},	//   zaya_, نچىل, _የከተማ_, ोषः_, 
   {{0x2910ae14,0x6d544c28,0xe2080162,0x68f40210}},	//   yaya_, _paya, rmóð_, ycyd, 
   {{0x6d54ae15,0x2910ae16,0xa6c8022e,0xdb040210}},	//   _qaya, xaya_, lgаc, kojó, 
   {{0x6d54ae17,0x6db00421,0xdb0400e4,0x00000000}},	//   _vaya, gāaa, jojó, --, 
   {{0xc0e80020,0x6d54ae18,0x7de8012c,0xee080276}},	//   መዋል_, _waya, _pěst, _декл_, 
   {{0x2910ae19,0x6d843e33,0x00000000,0x00000000}},	//   taya_, _jóak, --, --, 
   {{0x6d54014b,0xbbe8004b,0xd940ae1a,0xf1c802f0}},	//   _uaya, _کريم_, кеси, biáš_, 
   {{0x2910ae1b,0x3cf00122,0x60d8010f,0x8c4806be}},	// [de80] raya_, ťová_, ַקענ, _dağü, 
   {{0x7de8012c,0xaad407f7,0x68f40210,0x00000000}},	//   _těst, _धरपक, scyd, --, 
   {{0x291062bc,0x7c640244,0x999c00d7,0x00000000}},	//   paya_, _قایل, ňuš_, --, 
   {{0x2910ae1c,0xf6083bdb,0xdb04012d,0x00000000}},	//   qaya_, ستمه_, bojó, --, 
   {{0x1ce0031c,0x00000000,0x00000000,0x00000000}},	//   _ཧུབ_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe5a4aa08,0xd2545c78,0x29e8008f,0x9754011a}},	//   _живи, дцы_, _iĝas_, _קילו_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdfd80395,0x00000000,0x00000000,0x00000000}},	//   жън_, --, --, --, 
   {{0x7e740d1d,0x00000000,0x00000000,0x00000000}},	//   егох, --, --, --, 
   {{0xd12cae1d,0x6d940010,0x06b000cc,0x00000000}},	//   _их_, všar, _কৰতি, --, 
   {{0x1ce0025c,0xd00cae1e,0x00000000,0x00000000}},	//   _ཧུད_, _چلن_, --, --, 
   {{0x5c040a89,0x3cec0010,0xb7c400d1,0xbf1001af}},	//   ьяна, ževo_, ﯩﻼﺭﻏ, _йүпә, 
   {{0xdfa430a7,0x2bd0033f,0xfb344b00,0x00000000}},	//   _تحصي, _दीदा, энгэ, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xceb0008d,0x29e800df,0x98b003ca,0x00000000}},	//   _שיק_, _aĝas_, šeče_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [de90] --, --, --, --, 
   {{0x9a8407d6,0x98ac0724,0xa8000077,0xdb04012d}},	//   _жумл, ñgı_, áñan, rojó, 
   {{0x98ac0598,0x7bc4ae1f,0x7f5801b9,0xc7c400f3}},	//   ıgı_, _ikhu, _mavq, тсти, 
   {{0xf7c80131,0x8aa400c7,0xdb04012d,0x00000000}},	//   ﺪﯨﻜﻪ, _шрыд, pojó, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3958ae20,0x1ce0025c,0x7f5801b9,0xb4c000af}},	//   _hass_, _ཧུན_, _navq, _ुरी_, 
   {{0x7bc42782,0xe7bc1db2,0x3958ae21,0xa2a002ab}},	//   _mkhu, ्तरप, _kass_, _केद्, 
   {{0x3958ae22,0x3cf80034,0x942000db,0xa2340022}},	//   _jass_, ंडों_, _لورۇ, хьшә, 
   {{0x7bc481b3,0x3958ae23,0x87e80050,0x00000000}},	//   _okhu, _mass_, _رٹہِ_, --, 
   {{0x3958ae24,0x7bc4ae25,0x82f804fb,0x35a400e1}},	//   _lass_, _nkhu, _قرمز_, _खगड़, 
   {{0x1e8001c0,0x6da4009b,0xada41180,0x00000000}},	//   глэм, еина, еанл, --, 
   {{0x7dc43306,0x3958ae26,0xed58ae27,0x7e7c01e3}},	//   َتَك, _nass_, чом_, ärpa, 
   {{0x7f58036b,0xe534010f,0x00000000,0x00000000}},	//   _favq, עטשט_, --, --, 
   {{0x39580194,0x2078008f,0x61fc01e4,0xd1280023}},	//   _aass_, _מאנא, ŭple, _ተቀባል, 
   {{0x6da41dbc,0xfb840953,0xada4ae28,0x39582517}},	//   _пика, тыўн, _пакл, _bass_, 
   {{0x3958ae29,0x7bc41253,0xcdc40220,0x79a40640}},	//   _cass_, _ekhu, _шайқ, врђе, 
   {{0x3958ae2a,0x7bc40418,0xdd8c00aa,0xa764ae2b}},	// [dea0] _dass_, _fkhu, _دوي_, нкад, 
   {{0xdc380302,0x26dc0122,0x00000000,0x00000000}},	//   _צעיר, _útok_, --, --, 
   {{0x3958ae2c,0xa5240026,0x0ae801e2,0x00000000}},	//   _fass_, емед, _کرښي_, --, 
   {{0x3958ae2d,0xf65000dd,0x7c640046,0xe578ae2e}},	//   _gass_, گئے_, _ساۋل, язе_, 
   {{0x69c4ae2f,0xdce807f5,0x59b00139,0x6fb006e3}},	//   _ikke, šića, _сөрс, ीकां, 
   {{0x77902263,0xc79801d3,0x98a80055,0x25b0015d}},	//   _پیما, _کپڑا_, _uccā_, ŵyl_, 
   {{0x27e80083,0x36e40117,0x00000000,0x00000000}},	//   _iibn_, _абрҳ, --, --, 
   {{0x2b580042,0x662400e2,0x00000000,0x00000000}},	//   _lapc_, īskā, --, --, 
   {{0x7f58014f,0xd0a401c0,0x7654012d,0x25a4045a}},	//   _pavq, етэд_, _zszy, miol_, 
   {{0x25a4ae30,0xdb040113,0x7f58013d,0x8fa01d39}},	//   liol_, yojñ, _qavq, лање, 
   {{0x69c4ae31,0x7f58014f,0xd36c0ccb,0x248401d3}},	//   _okke, _vavq, _دهل_, lyom_, 
   {{0x25a4ae32,0x7bc4ae33,0x00000000,0x00000000}},	//   niol_, _skhu, --, --, 
   {{0x3958ae34,0xdde803e6,0x7f58022e,0x24844e79}},	//   _rass_, _کرته_, _tavq, nyom_, 
   {{0x69c4ae35,0x25a400a9,0x39588860,0x394c00b8}},	//   _akke, hiol_, _sass_, _źes_, 
   {{0x1ce00156,0x3958ae36,0x26c81924,0xd1f00092}},	//   _ཧུམ_, _pass_, _nybo_, _ኃብት_, 
   {{0x2c40016b,0x2b5800db,0x683c001f,0x00000000}},	//   _wɔda_, _eapc_, _አካላት, --, 
   {{0x25a4ae37,0xd5b8052f,0x2bd0068f,0x2b5805da}},	// [deb0] diol_, үсе_, _दीवा, _fapc_, 
   {{0x69c4ae38,0x7bc4ae39,0xd6d8ae3a,0x39580ae6}},	//   _ekke, _ukhu, пте_, _wass_, 
   {{0x69c40270,0x7c3c0c8c,0x26c8017a,0x1adc0183}},	//   _fkke, ltsr, _cybo_, _ব্ৰা, 
   {{0xceb005d0,0x00000000,0x00000000,0x00000000}},	//   ניף_, --, --, --, 
   {{0x765414cf,0x7c3c0c8c,0xf8d40c2e,0x37e40075}},	//   _wszy, ntsr, _दरिय, _җоңг, 
   {{0x170407d6,0x7c3cae3b,0x76542b24,0xe7bc00cd}},	//   _سفری_, itsr, _tszy, ्तःप, 
   {{0x25a4ae3c,0x7c3c0c8c,0x661001d9,0xe7e8012c}},	//   biol_, htsr, _نژنا, _झूटा_, 
   {{0x6db00421,0x75680014,0x7c3c78d0,0x2484011f}},	//   gāal, _تٍرِ_, ktsr, byom_, 
   {{0x27e403a2,0x0fe404a9,0x04c800b2,0x35a402dd}},	//   ïong_, нлиқ_, _ٻولي_, _заңг, 
   {{0xa2a00490,0x00000000,0x00000000,0x00000000}},	//   _केव्, --, --, --, 
   {{0x7c64001f,0x7c3cae3d,0x51840209,0x00000000}},	//   _ስላለው_, etsr, _пуда, --, 
   {{0x6da4ae3e,0xc2c4007b,0xeb081788,0x00000000}},	//   тима, _صيني, वर्त_, --, 
   {{0x7c3c01bf,0x2518010f,0x00000000,0x00000000}},	//   gtsr, וורא, --, --, 
   {{0x69c40165,0x00000000,0x00000000,0x00000000}},	//   _skke, --, --, --, 
   {{0x7c3cae3f,0xed58036b,0x4ea4497a,0x526800d1}},	//   atsr, _жой_, _ярда, _ﻳﯧﯖﯩ, 
   {{0x3a241f60,0x61ec04cc,0x248401d5,0x00000000}},	//   álpa_, _èble, yyom_, --, 
   {{0x25a4013c,0x7d08056a,0x645c3a2f,0x7c3c0857}},	// [dec0] viol_, ñese, āpik, ctsr, 
   {{0x25a40368,0xebe44a1a,0x22500210,0x00000000}},	//   wiol_, _шопп, łyki_, --, 
   {{0xe9d815ed,0x25a403cb,0xb8e82e37,0x00000000}},	//   _око_, tiol_, _लु_, --, 
   {{0x69c4ae40,0x75880212,0xc77401c6,0x36340014}},	//   _ukke, нсів_, _өтгө, ارٕس, 
   {{0x25a4ae41,0x26c8002d,0x76400108,0x00000000}},	//   riol_, _wybo_, _älyn, --, 
   {{0xdce80d0f,0xd70006bb,0x9340ae42,0x25a4015d}},	//   žićn, _взри, инче, siol_, 
   {{0x2d90434d,0x25a400db,0x9c100241,0x65c40024}},	//   _olye_, piol_, _nọnb, _абва, 
   {{0xe57801b9,0x764c00e5,0x00000000,0x00000000}},	//   _ўза_, őnyé, --, --, 
   {{0xc3c41cd1,0x033400ec,0x91b40395,0x00000000}},	//   _йөкл, _مظاھ, ъгът_, --, 
   {{0x2d908ac8,0x629c00d0,0xe28401af,0x00000000}},	//   _alye_, úpos, _илзи, --, 
   {{0xa2e4165d,0x2d90ae43,0xe19401c0,0x30381fae}},	//   _рожд, _blye_, _ирдэ, وتیک_, 
   {{0x7c3cae44,0xbbbc243c,0x60240006,0x518000c0}},	//   ttsr, ोत्क, _адда, _вуша, 
   {{0x5f74034c,0xa804247e,0x00000000,0x00000000}},	//   _لاغر, ntığ, --, --, 
   {{0x8fa01342,0xdb04044e,0x7c3c127b,0x2d900100}},	//   _каче, mijë, rtsr, _elye_, 
   {{0x39941512,0xdb4c03e6,0x7c3c03ac,0x8f500244}},	//   _låse_, مێک_, stsr, _ئۆپش, 
   {{0xa80403ee,0xa6c801a9,0x7e7c0162,0x00000000}},	//   ktığ, tgаn, ørpu, --, 
   {{0x3dc8ae45,0xc88403b9,0xaee401ee,0x00000000}},	// [ded0] _ikaw_, _nağı_, _ибәһ, --, 
   {{0x3b54ae46,0x9ba00075,0x7f84642b,0x8c1c0375}},	//   _скор, _ئەسى, _tòqu, _חוזי, 
   {{0xa2a005ba,0xcf9000c8,0xda640451,0x00000000}},	//   _केल्, סטע_, _شادي, --, 
   {{0x9f48006a,0xc8843361,0x399401bf,0xf77000f1}},	//   öbê_, _bağı_, _båse_, جاړ_, 
   {{0xf4d009bd,0x9894001f,0x798c0117,0x9870001f}},	//   িশ্ব, _ለመሆኑ_, mkaw, _ከመሆኑ_, 
   {{0xc884ae47,0xa8540375,0x399400b5,0x28980a7c}},	//   _dağı_, _גישה_, _dåse_, _טירא, 
   {{0x798c00b5,0x7e7c007c,0x00000000,0x00000000}},	//   okaw, ärpl, --, --, 
   {{0x798cae48,0x61fc0122,0xdb040200,0x9f4408a5}},	//   nkaw, ípla, fijë, _stoð_, 
   {{0x69d81a7c,0x00000000,0x00000000,0x00000000}},	//   ïtei, --, --, --, 
   {{0xe0d40962,0x2f5402bf,0x798c009a,0xaf0400c0}},	//   ывы_, утис, hkaw, ыпол, 
   {{0x2d90007f,0x798cae49,0x00000000,0x00000000}},	//   _plye_, kkaw, --, --, 
   {{0xc884ae4a,0x6d8409e8,0x00000000,0x00000000}},	//   _yağı_, _nóat, --, --, 
   {{0x798c0463,0x00000000,0x00000000,0x00000000}},	//   dkaw, --, --, --, 
   {{0x3dc80428,0x798cae4b,0xa3d401f9,0x00000000}},	//   _ekaw_, ekaw, सतय_, --, 
   {{0x798c02a8,0x2d9003e0,0x00000000,0x00000000}},	//   fkaw, _tlye_, --, --, 
   {{0x798c417f,0xed58016c,0x6d4c0306,0x628c0327}},	//   gkaw, _чои_, íhač, _żbok, 
   {{0x1ae02b8d,0xaa84010e,0x00000000,0x00000000}},	// [dee0] _қоюм, _beýä, --, --, 
   {{0x66e4ae4c,0x798c0099,0x4e1400c5,0xdc98011a}},	//   гоза, akaw, _दबाई_, _נסיכ, 
   {{0x798c0198,0xdb0402e2,0x7640005b,0xc88408a9}},	//   bkaw, dijè, _älyl, _sağı_, 
   {{0x798cae4d,0xa80403ee,0x29540801,0x39943bdc}},	//   ckaw, ttığ, _съор, _påse_, 
   {{0x6d840579,0xd4644c7f,0xd9180375,0xc4480811}},	//   _hóas, лице_, _אוכל, ضیان_, 
   {{0xdb04036e,0xa80415b7,0x00000000,0x00000000}},	//   vijë, rtığ, --, --, 
   {{0xe2449486,0xa804083c,0xb59c0241,0x2fc40010}},	//   اختي, stığ, _kẹ̀w, dolg_, 
   {{0xa804a493,0x3cec04a7,0xc8846b8e,0x09c40154}},	//   ptığ, ževi_, _tağı_, ্দকা, 
   {{0x2fc40730,0x8b08012d,0x00000000,0x00000000}},	//   folg_, _zwęż, --, --, 
   {{0xf1a80272,0x3dc8ae4e,0x53c4014b,0x00000000}},	//   _یانه_, _skaw_, _бгум_, --, 
   {{0x798cae4f,0xa20402e8,0x00000000,0x00000000}},	//   ykaw, _спед, --, --, 
   {{0xe0c40729,0x63a84cd5,0x00000000,0x00000000}},	//   শেষভ, lifn, --, --, 
   {{0x5b24ae50,0xe0d0282b,0xdb04ae51,0x10a00114}},	//   льва, _ازا_, lijé, _лицн, 
   {{0x2fc40175,0x2904005a,0x6d8402d2,0x0cd401c6}},	//   colg_, ñoan_, _bóas, ёорю, 
   {{0x7ddc01f5,0x798c02d0,0x3d940354,0x6288ae52}},	//   vésf, tkaw, _вийр, nyfo, 
   {{0x3dc80054,0x63a8208d,0x99d4ae53,0x798cae54}},	//   _ukaw_, hifn, اتسا, ukaw, 
   {{0x798cae55,0xf8b8ae56,0xcd340137,0x44d40241}},	// [def0] rkaw, төн_, _ارىب, _ǹ_, 
   {{0x798cae57,0x00000000,0x00000000,0x00000000}},	//   skaw, --, --, --, 
   {{0x941c03be,0x8aa4011b,0x44d4004d,0xf9d40153}},	//   ərək_, _гряд, _à_, _вонэ, 
   {{0xceb0008f,0x628803e0,0xdb040066,0x764001f4}},	//   זיע_, dyfo, wijè, _älym, 
   {{0xdb04007f,0x2ed000cd,0x00000000,0x00000000}},	//   tijè, _हर्त, --, --, 
   {{0x9c107eeb,0xf7940139,0x00000000,0x00000000}},	//   _nọmb, _тагэ, --, --, 
   {{0x2fc4225e,0xa8040365,0x6288ae58,0xe294013e}},	//   volg_, rtış, gyfo, иаш_, 
   {{0x22ac00ac,0xdb0402e2,0xc594041b,0x00000000}},	//   _dək_, sijè, _лисј, --, 
   {{0xd344ae59,0x63a8208d,0x25ac06af,0xdb0401f4}},	//   _میشه_, bifn, èfle_, onjä, 
   {{0x6288508f,0xdb040254,0x00000000,0x00000000}},	//   byfo, nnjä, --, --, 
   {{0x6288009f,0x8d4801c6,0x614400d1,0xd06003b9}},	//   cyfo, гүйг_, _چىمە, _ərəs, 
   {{0xdb040112,0x6d84032e,0x614400d1,0x00000000}},	//   hnjä, _róas, _نىمە, --, 
   {{0x7d080005,0x7e7c03cd,0x00000000,0x00000000}},	//   ñesa, ørpr, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x78a00213,0x386c031c,0x6b8c007f,0x7c280135}},	//   _əlve, _ġera_, rkbg, ġera, 
   {{0x667455b2,0xdb04023a,0x7c2816a3,0x386c02f0}},	//   یدار, enjä, šera, _šera_, 
   {{0xe738059f,0x00000000,0x00000000,0x00000000}},	// [df00] кеа_, --, --, --, 
   {{0x27ec0008,0x6b8c0175,0x32040432,0x00000000}},	//   öfn_, qkbg, _otly_, --, 
   {{0x6d44017a,0x65c40108,0xdb200244,0x00000000}},	//   ofka, абжа, _بوپی, --, 
   {{0xdb0401f4,0xf62800be,0x00000000,0x00000000}},	//   anjä, اسلى_, --, --, 
   {{0x320409a5,0x63a89e4f,0x29000014,0x6288015d}},	//   _atly_, tifn, _ifka_, wyfo, 
   {{0xa6540014,0xc5f803e6,0xe1f033d2,0xb8a00092}},	//   _پَرت, _موسڵ_, يسع_, _ለመጣል_, 
   {{0x7ddc00dd,0x63a8ae5a,0xefd0001f,0x00000000}},	//   lése, rifn, _የሙያ_, --, 
   {{0x39940158,0x63a8208d,0x6d4401f5,0x09d80154}},	//   _kåsa_, sifn, jfka, _দূতা, 
   {{0xd0040261,0x3fc4ae5b,0x24c80022,0x7ddc01d3}},	//   аење_, йроғ, _ргап_, nése, 
   {{0x22ac00ac,0x33d401ce,0x6d443c68,0x6440ae5c}},	//   _tək_, _ліхт, efka, mtoi, 
   {{0x6440ae5d,0x39940267,0x6d4403cd,0x539800d9}},	//   ltoi, _låsa_, ffka, _שיבו, 
   {{0x6560ae5e,0x64401ca6,0x82640451,0x7ddc00e5}},	//   ndoh, otoi, _پهچن, kése, 
   {{0x6440ae5f,0x0ca81503,0x92f401e1,0x00000000}},	//   ntoi, атри_, _ẹ̀ẹ́_, --, 
   {{0x2900ae60,0x7ddc01ed,0x6ec00316,0x6440ae61}},	//   _afka_, dése, _रुकु, itoi, 
   {{0x6440ae62,0x8f78011a,0x28d000d1,0x0f78011a}},	//   htoi, _בנגק, ﻛﯩﺘﻠ, _ברגל, 
   {{0xd90c10e5,0x2d900240,0x64400821,0x1db85a17}},	//   بیح_, ëzet_, ktoi, _उदित, 
   {{0x7d1cae63,0xa3d443d1,0x656049f0,0x490401b9}},	// [df10] mass, सता_, ddoh, توقق, 
   {{0x764002f6,0x2ca4010e,0x9b244130,0x00000000}},	//   _älyk, _ýoda_, _тфил, --, 
   {{0x212408ad,0x1db80b7c,0x6440005b,0xfb040171}},	//   _odoh_, _उदात, etoi, grūž_, 
   {{0x7d1cae64,0x3cec0e3c,0x200401c4,0x09e406ed}},	//   nass, ževu_, _otoi_, _моќн, 
   {{0x7d1c0140,0xe81400e1,0x00000000,0x00000000}},	//   iass, दीदा_, --, --, 
   {{0x212404fb,0x7d1cae65,0x5344ae66,0x00000000}},	//   _adoh_, hass, рхда, --, 
   {{0x6440ae67,0xd58404d3,0x3e4c0134,0x2004005a}},	//   atoi, _پێشه_, _yɛte_, _atoi_, 
   {{0x7d1cae68,0x3494ae69,0x9324152f,0x942000f7}},	//   jass, _лабр, _چران, _ووزۇ, 
   {{0xba080f16,0x6440ae6a,0x60040962,0x9f4c02bd}},	//   _ገጽ_, ctoi, бным_, _kifè_, 
   {{0x2124003e,0xc0c80640,0x7d1c0076,0x00000000}},	//   _edoh_, јуће_, eass, --, 
   {{0x7d1cae6b,0x7ddc01ed,0x00000000,0x00000000}},	//   fass, zése, --, --, 
   {{0x7d1cae6c,0xccf8044c,0x6ed80882,0x20040240}},	//   gass, шқи_, ṃbod, _ftoi_, 
   {{0x7c2809a8,0x6d44017a,0x7e00063f,0x7ddc0077}},	//   šern, rfka, ịspe, xése, 
   {{0x7d1c20ac,0x399400cc,0x3b940b3e,0x21240427}},	//   aass, _råsa_, ојст, _zdoh_, 
   {{0x2900070d,0x6994ae6d,0xdf54004b,0xad68009d}},	//   _pfka_, брах, _درنښ, _байз_, 
   {{0x7ddc00dd,0x75380007,0x2d90005f,0x8d280116}},	//   tése, jgwz, īzes_, _тниң_, 
   {{0x2bb800c6,0x7c240022,0x65600200,0xfca83cc6}},	// [df20] _مادة_, _дзыҧ, vdoh, _پايو_, 
   {{0x7ddc01ed,0xe0d0008f,0x30e800cd,0x64400037}},	//   rése, לײן_, ञेयः_, vtoi, 
   {{0x9f4c007f,0xd7ec00c6,0x7ddc01d3,0x00000000}},	//   _difè_, ركم_, sése, --, 
   {{0x6440ae6e,0x7ddcae6f,0x499401d5,0x29000205}},	//   ttoi, mésc, _بیرر, _ufka_, 
   {{0xf3f001fb,0x6560ae70,0x7ddc5f5e,0x64401ca6}},	//   _bị_, rdoh, lésc, utoi, 
   {{0x6440ae71,0x7d1cae72,0x61b00b7c,0x9cd40375}},	//   rtoi, zass, ुक्ष, זונה_, 
   {{0x6440ae73,0xf3f0ae74,0x2004ae75,0x00000000}},	//   stoi, _dị_, _stoi_, --, 
   {{0x15405882,0x7d1c07d6,0x8f4001c0,0x7ddc01d3}},	//   _несм, xass, үхэд, zésb, 
   {{0x7d1cae76,0xded00020,0x249000cc,0x00000000}},	//   vass, ረውን_, øymd_, --, 
   {{0xf3f001f2,0x4424ae77,0x7ddc01d3,0x2054ae78}},	//   _gị_, _ivm_, késc, атүр, 
   {{0x7d1cae79,0xf8d4ae7a,0x7ddc01ed,0x6efc02d2}},	//   tass, _दर्प, vésb, _sæbó, 
   {{0x44247c52,0x7d1c013c,0x00000000,0x00000000}},	//   _kvm_, uass, --, --, 
   {{0x3cec00af,0x20040093,0x61f8016d,0xdea04fe0}},	//   äev_, _utoi_, _hutl, تیژی, 
   {{0x61f8ae7b,0x7d1c1905,0x225c0051,0x00000000}},	//   _kutl, sass, _kstk_, --, 
   {{0x61f8ae7c,0x99d400ae,0x00000000,0x00000000}},	//   _jutl, مترا, --, --, 
   {{0x7d1c32ff,0x61f8ae7d,0x764001f4,0x4424ae7e}},	//   qass, _mutl, _älyi, _ovm_, 
   {{0x44240cf9,0x61f80978,0x3c580276,0x7ddc00e5}},	// [df30] _nvm_, _lutl, _типэ_, pésb, 
   {{0x6fdc20ef,0xba541b88,0x61f826c2,0xaae400e5}},	//   pèce, _двој, _outl, _ڈسپو, 
   {{0x2cc40156,0x4424ae7f,0x61f8ae80,0x0708007b}},	//   _གཙོབ, _avm_, _nutl, صيني_, 
   {{0x7bd40b70,0x442406af,0xf3f80356,0x00000000}},	//   llzu, _bvm_, _puţ_, --, 
   {{0x61f8ae81,0x4424ae82,0x6444ae83,0x00000000}},	//   _autl, _cvm_, _äkil, --, 
   {{0x61f8ae84,0x8c1c008d,0x9f440165,0x3948ae85}},	//   _butl, נווי, _tuoù_, lfas_, 
   {{0x61f8232c,0xf3f0004d,0x324412b9,0x35f40212}},	//   _cutl, _vị_, цейг, _єпар, 
   {{0x7bd40998,0x61f8ae86,0x3948ae87,0xded40092}},	//   hlzu, _dutl, nfas_, ኪያነ_, 
   {{0x7528ae88,0x38681e7d,0x76440857,0x6fdc0ffb}},	//   _idez, nvar_, lthy, jècc, 
   {{0xd344129e,0x249000cc,0xef180137,0x38680174}},	//   _طیبه_, øyme_, шмо_, ivar_, 
   {{0x7644ae89,0x61f80209,0x290401c4,0x386803b2}},	//   nthy, _gutl, ñoak_, hvar_, 
   {{0x386805ac,0x3948ae8a,0xace8188b,0x7bd4002f}},	//   kvar_, jfas_, имна_, elzu, 
   {{0x7644014a,0x06b0015b,0x5d64034b,0x01c801d3}},	//   hthy, _করছি, циям_, _اونٹ_, 
   {{0x3868ae8b,0x7644ae8c,0x00000000,0x00000000}},	//   dvar_, kthy, --, --, 
   {{0x3948ae8d,0xbf6403e6,0x75280cf1,0xda600a31}},	//   ffas_, _ردوو, _odez, мври, 
   {{0x7528ae8e,0x7ddc0120,0x9f4c004e,0x7bd4030a}},	//   _ndez, résc, _rifé_, alzu, 
   {{0xe7a8ae8f,0x38680579,0x76440368,0xab28119e}},	// [df40] авал_, gvar_, ethy, _копа_, 
   {{0x2d801050,0x7528ae90,0x00000000,0x00000000}},	//   ljke_, _adez, --, --, 
   {{0x442400f3,0x7ddc0de2,0x764403ac,0x00000000}},	//   _svm_, lésa, gthy, --, 
   {{0x61f8ae91,0x44240aec,0xa9685336,0x2d802230}},	//   _rutl, _pvm_, _тима_, njke_, 
   {{0x2910ae92,0x61f8ae93,0xa3e8ae94,0x19540375}},	//   mbya_, _sutl, адда_, _ובכל_, 
   {{0x61f8ae95,0x752801f2,0x69d401ed,0x442401bf}},	//   _putl, _edez, llye, _vvm_, 
   {{0xd62434da,0x61f8ae96,0x62641e4a,0x7ddc020c}},	//   _море_, _qutl, تاشق, hésa, 
   {{0x4424ae97,0x61f807a9,0x29100369,0x7ddc0df4}},	//   _tvm_, _vutl, nbya_, késa, 
   {{0xb144ae98,0x442467c4,0x61f8ae99,0x00000000}},	//   سیوم_, _uvm_, _wutl, --, 
   {{0x3f981f60,0xff98026a,0x7ddcae9a,0x2ee801e4}},	//   óru_, ској_, désa, _ŝafa_, 
   {{0x6144ae9b,0x29100369,0x2cc40327,0xa0240254}},	//   _межа, kbya_, _གཙུབ, flöö, 
   {{0x386c02f0,0x38680162,0x01e401af,0x00000000}},	//   _šerm_, yvar_, _эйеү, --, 
   {{0x61e0aa77,0x764001f4,0x5c0401a9,0x00000000}},	//   _ihol, _älyv, ўяма, --, 
   {{0x61e00117,0x764400a9,0x29100083,0x1ea82764}},	//   _hhol, ythy, ebya_, _پاتي_, 
   {{0x3868083a,0x8f9806a9,0x6aa002a8,0x0a68ae9c}},	//   wvar_, _דיגי, _ƙofa, орти_, 
   {{0x2910ae9d,0x38680790,0x69d40022,0x76b801e0}},	//   gbya_, tvar_, glye, ҡлар_, 
   {{0x3948382f,0x61e0ae9e,0x7ddc06af,0x77980116}},	// [df50] rfas_, _mhol, césa, бкар_, 
   {{0x291004ba,0x47780c9e,0x3948ae9f,0x69d40175}},	//   abya_, обую_, sfas_, alye, 
   {{0x61e0aea0,0xa3cc098a,0x291004ba,0x69d40200}},	//   _ohol, रवन_, bbya_, blye, 
   {{0x7644aea1,0x61e0031c,0x7c900023,0x386800d7}},	//   rthy, _nhol, _ዚመስል_, pvar_, 
   {{0x7644aea2,0xa3d40073,0xa978011a,0x69a401f9}},	//   sthy, सतं_, _הארכ, घोळी, 
   {{0x61e0aea3,0xefc802d3,0xe3600108,0x00000000}},	//   _ahol, _አለዎ_, екши, --, 
   {{0x60c0022e,0x61e0aea4,0x80d00118,0x2bbc01f9}},	//   _axom, _bhol, _डुबे, ोवता, 
   {{0x42b804a9,0x98a847af,0x61e0aea5,0x3124010b}},	//   تنىڭ_, _hacı_, _chol, чдиг, 
   {{0xefc80201,0x61e0aea6,0x600412c4,0xcec0013a}},	//   _አለው_, _dhol, пным_, _ohří_, 
   {{0x61e0aea7,0xee381e80,0x29100097,0x00000000}},	//   _ehol, бно_, zbya_, --, 
   {{0x61e0aea8,0x60c0070d,0x98a80205,0x81bc00de}},	//   _fhol, _exom, _macı_, _kvēl, 
   {{0x61e0aea9,0xc104082e,0x62240150,0x7ddc003e}},	//   _ghol, _قومي, _ءونە, tésa, 
   {{0x69d4020c,0x00000000,0x00000000,0x00000000}},	//   vlye, --, --, --, 
   {{0x29100369,0x6370013d,0x7ddcaeaa,0x53c8085c}},	//   wbya_, _iñnä, résa, िविश, 
   {{0xd9781945,0x7ddc0c6a,0xeab001d3,0x7e7c01e3}},	//   әрсә_, sésa, رٹر_, ärpt, 
   {{0xa8044d86,0x7ddcaeab,0xdb0400d8,0x61fc00d8}},	//   ззал, pésa, tijã, ípli, 
   {{0x69d4aeac,0x98a80213,0x29106d1f,0x6134aead}},	// [df60] rlye, _bacı_, rbya_, lülü, 
   {{0x7ddcaeae,0x00000000,0x00000000,0x00000000}},	//   nésn, --, --, --, 
   {{0xeab04197,0x9b140a1e,0x61341432,0x69f80354}},	//   _سعد_, _מחיה_, nülü, _ыннă, 
   {{0x9cb00ec9,0x00000000,0x00000000,0x00000000}},	//   _آمیت, --, --, --, 
   {{0x61e0aeaf,0xd4000108,0x00000000,0x00000000}},	//   _rhol, нящи, --, --, 
   {{0x613406b9,0x00000000,0x00000000,0x00000000}},	//   külü, --, --, --, 
   {{0x66e4aeb0,0x7790aeb1,0x7ddc00e5,0x00000000}},	//   _хова, _جیلا, désn, --, 
   {{0x61e001e0,0x61342ca8,0xada002d2,0x00000000}},	//   _qhol, dülü, _þúha, --, 
   {{0x61e00943,0x2328aeb2,0x67e000d0,0x00000000}},	//   _vhol, _гози_, pôjd, --, 
   {{0x61e0aeb3,0x7bc001fa,0x6fdc068c,0xd24c00cf}},	//   _whol, čluk, tèca, ئچە_, 
   {{0xe21407d6,0x7640023a,0xd24caeb4,0x613456f8}},	//   _رباع, _älyt, _منل_, gülü, 
   {{0x61e0aeb5,0x60c0aeb6,0x753c01ed,0x6144030d}},	//   _uhol, _txom, _öszt, _хеда, 
   {{0x6288063f,0xe0d80108,0x00000000,0x00000000}},	//   ̣mọ, _увд_, --, --, 
   {{0x10a0023a,0xa6c801d5,0x00000000,0x00000000}},	//   _яичн, ngаs, --, --, 
   {{0xdb4c04d3,0x61343535,0x0dcc0092,0x88c40055}},	//   نێک_, cülü, _አረፉ_, _āśak, 
   {{0xceb00375,0xbb5c04ce,0x98a80205,0x673c0064}},	//   _ריק_, ftyユ_, _sacı_, egpj, 
   {{0x7ddc0098,0x58840006,0x00000000,0x00000000}},	// [df70] léso, чыва, --, --, 
   {{0x4c9c0302,0xdb040f57,0x00000000,0x00000000}},	//   _לבחו, bijá, --, --, 
   {{0x3e4c013f,0x41ccaeb7,0xcf90008f,0x00000000}},	//   _mɛto_, ावास, עטע_, --, 
   {{0xf96003e6,0x7ddc01d3,0x29dc0142,0x6c6800e5}},	//   _جۆرێ, zésn, lïan_, _الیہ_, 
   {{0xf8c0aeb8,0xc3140729,0x6134aeb9,0x98a86b5f}},	//   _एशिय, _সাজি_, zülü, _tacı_, 
   {{0x249000cc,0x00000000,0x00000000,0x00000000}},	//   øyma_, --, --, --, 
   {{0x934004da,0xed900023,0xd694010a,0x00000000}},	//   _ۋىرۇ, _ዚገብር_, _хăйп, --, 
   {{0xd9e01fb0,0x2ee800df,0x55600137,0x7658012d}},	//   _कीमत_, _ŝafo_, _سۇتك, łwys, 
   {{0x3e4c016b,0xafe400c2,0x55c00220,0x7ddc01ed}},	//   _bɛto_, моил, _жаңғ, tésn, 
   {{0xd7d800b5,0x6134083c,0x7ddc8075,0xd7bc07d0}},	//   _msハ_, tülü, féso, ्विच, 
   {{0x92b80183,0xed58aeba,0x799c03ac,0x00000000}},	//   _ঘৰৰ_, оон_, _olsw, --, 
   {{0x61342c6f,0xdb0402fb,0x3f9c02d2,0xdce801e4}},	//   rülü, vijá, _elvu_, ŭiĝa, 
   {{0x6aa002a8,0xd7bc412f,0x6134aebb,0x69d80129}},	//   _ƙofo, ्वाच, sülü, îtem, 
   {{0x799c035a,0x00000000,0x00000000,0x00000000}},	//   _alsw, --, --, --, 
   {{0xf1e00034,0x7ddc00e4,0xa3cc3042,0xece40220}},	//   _पठान, céso, रवत_, _ﺍﺭﻩﻛ, 
   {{0xe9d8aebc,0x799c02d0,0x99800064,0x00000000}},	//   іка_, _clsw, dujų_, --, 
   {{0xdd8c45d7,0xa76401fe,0xc4b80154,0x00000000}},	// [df80] _خوي_, мкад, _জর্জ, --, 
   {{0x3c44007b,0xe8dc5843,0x00000000,0x00000000}},	//   _أضيف, _मरीच, --, --, 
   {{0xa9a4aebd,0xac74aebe,0x3a2406ea,0xf1dc06ff}},	//   _жинд, _راکش, álpt_, मतान, 
   {{0xe5789f4d,0x00000000,0x00000000,0x00000000}},	//   юзе_, --, --, --, 
   {{0x6b9c0cf9,0x6ad400fe,0x380401f0,0x00000000}},	//   _klpg, _দলটো, _пояҳ, --, 
   {{0x6b9c0cf9,0x78541bf4,0xa95801f7,0x00000000}},	//   _jlpg, _سیمز_, _اجگر_, --, 
   {{0x6fdc0137,0xa508023b,0x7c280135,0x00000000}},	//   tècn, _мева_, ġeri, --, 
   {{0x386c05be,0x6afc031c,0x7c280024,0xa6c8022e}},	//   _šeri_, _དུའོ_, šeri, bgаr, 
   {{0x3e4c02ea,0xe2082507,0x00000000,0x00000000}},	//   _pɛto_, flóð_, --, --, 
   {{0x284c2295,0x39940267,0x18780375,0x8fa0041b}},	//   _ምክንያ, _påsk_, קטיב, кање, 
   {{0x262800c8,0x00000000,0x00000000,0x00000000}},	//   nĝo_, --, --, --, 
   {{0x2628008f,0x7ddc0022,0x7c340139,0x00000000}},	//   iĝo_, réso, немх, --, 
   {{0x672c0841,0x7ddc00d5,0xe2080a87,0x00000000}},	//   _odbj, séso, blóð_, --, 
   {{0x799c02d0,0xc0e40092,0x00000000,0x00000000}},	//   _slsw, ሞክር_, --, --, 
   {{0x99642bda,0x799c02d0,0x00000000,0x00000000}},	//   мтал, _plsw, --, --, 
   {{0x6f0c17a3,0x69c80162,0x20e000b8,0x00000000}},	//   _đaci, _ífel, _पराध, --, 
   {{0xa3cc19ec,0xb4dc0dad,0xbc9400d8,0x00000000}},	// [df90] रवा_, _डरे_, _чапј, --, 
   {{0xd6d8aebf,0x7c3caec0,0xda780276,0x15800150}},	//   оте_, musr, _дям_, _ﯩﻜﺘﯩ, 
   {{0x7c3c00c5,0x799c03ac,0xdfc40eff,0x799401ee}},	//   lusr, _tlsw, _ەي_, _зинф, 
   {{0x7c3c02d0,0x00000000,0x00000000,0x00000000}},	//   ousr, --, --, --, 
   {{0x92b800bd,0x33d40220,0x660c009d,0x7c3caec1}},	//   _ঘরে_, нікт, _etbk, nusr, 
   {{0xd378aec2,0xf268aec3,0xa6c801a9,0x73341411}},	//   юче_, зикл_, rgаr, رىعا, 
   {{0xdb040e03,0xd5b800d8,0x00000000,0x00000000}},	//   mijä, _дса_, --, --, 
   {{0xdb04aec4,0x5f400075,0x7c3c7c70,0xf06403f6}},	//   lijä, ۇچىل, kusr, екип, 
   {{0x0fe404a9,0x85040014,0x4a8c0023,0x00000000}},	//   млиқ_, _شولن, _ዓዘቕቲ_, --, 
   {{0xee386e27,0x7c3caec5,0xdb048234,0x6e3c0092}},	//   пно_, dusr, nijä, _በተጨባ, 
   {{0xb1140006,0x00000000,0x00000000,0x00000000}},	//   _змеш, --, --, --, 
   {{0xdb0401f4,0x00000000,0x00000000,0x00000000}},	//   hijä, --, --, --, 
   {{0xdb04049b,0x7c3c00af,0xbf643a56,0x1ae001d5}},	//   kijä, gusr, ردیو, ғотм, 
   {{0x94fc0135,0xa0643529,0xeb98352d,0x09c801bc}},	//   _ཞུའི_, _чаша_, чиг_, लव्य, 
   {{0xdb1c00bc,0x4ea4010b,0xc4dc2982,0x7c3c002f}},	//   ávám, _юрда, _बर्ख, ausr, 
   {{0x28141867,0x7db40024,0x00000000,0x00000000}},	//   فورس, _асьц, --, --, 
   {{0x26dc04b9,0x98a0094e,0xf1c80306,0x6ce401ec}},	// [dfa0] _što_, гите, cháš_, _ﺍﺭﺣﻴ, 
   {{0x6ed80882,0x9f4c0241,0xdb041b99,0x00000000}},	//   ṃbud, _kifá_, gijä, --, 
   {{0x81c800fe,0x66e4a3f8,0x284c01f3,0xe9d831fd}},	//   োগত_, хожа, _ምክኒያ, _нко_, 
   {{0x64c4049e,0x7ae001ed,0xbebc0b10,0x2628008f}},	//   ىيال, ülte, kaīn, rĝo_, 
   {{0x53c82a67,0x00000000,0x00000000,0x00000000}},	//   िवंश, --, --, --, 
   {{0x7ce801a9,0x92b803d4,0x00000000,0x00000000}},	//   dоrl, _ঘৰে_, --, --, 
   {{0x9f4caec6,0x764002f6,0xd7d8037e,0xd25434be}},	//   _rifà_, _älyp, _irバ_, ецы_, 
   {{0xdef82440,0xe61801b9,0x00000000,0x00000000}},	//   ሊያን_, _мдҳ_, --, --, 
   {{0xdfd80395,0x00000000,0x00000000,0x00000000}},	//   зън_, --, --, --, 
   {{0x7c3c000d,0x00000000,0x00000000,0x00000000}},	//   vusr, --, --, --, 
   {{0xa8040166,0x00000000,0x00000000,0x00000000}},	//   luığ, --, --, --, 
   {{0x7c3c05a7,0x9f4c01e1,0xa0a40153,0x00000000}},	//   tusr, _difá_, _паед, --, 
   {{0xd00c38b7,0x48c4015b,0xf1a80753,0xffa4004e}},	//   _هلن_, ্ধুর, _تاله_, _илдү, 
   {{0x7c3c0108,0x00000000,0x00000000,0x00000000}},	//   rusr, --, --, --, 
   {{0xdb04023a,0x00000000,0x00000000,0x00000000}},	//   vijä, --, --, --, 
   {{0x9a840364,0x7c3caec7,0x8300025c,0x98040395}},	//   _ҷумл, pusr, _ཝུའུ_, еяжд, 
   {{0x7d0caec8,0xdb04aec9,0x00000000,0x00000000}},	// [dfb0] _ifas, tijä, --, --, 
   {{0x7ddc003e,0x2ec000cc,0x92b800cc,0x00000000}},	//   késk, _উৰিষ, _ঘৰো_, --, 
   {{0x7c2caeca,0xc7c4aecb,0xdb04aecc,0x386c0327}},	//   _hvar, усти, rijä, _ġeru_, 
   {{0x7c2caecd,0xd7d8037e,0x7d0c0135,0xdb040e03}},	//   _kvar, _erバ_, _jfas, sijä, 
   {{0x7d0caece,0x7c2caecf,0xe86401c6,0xdb0401f4}},	//   _mfas, _jvar, _ихрү, pijä, 
   {{0x7c2caed0,0x7d0c00a3,0xe72c022e,0x00000000}},	//   _mvar, _lfas, shеr_, --, 
   {{0x7d0c03ac,0x653000ec,0x57bc00bc,0x25b000ae}},	//   _ofas, _چڙها, ्वीह, únlú_, 
   {{0x7d0caed1,0x7c2caed2,0x7ce8022e,0x00000000}},	//   _nfas, _ovar, tоrl, --, 
   {{0x9f4c011f,0x7c2caed3,0x63ac08fb,0xa1540640}},	//   _sifá_, _nvar, ønnø, тању_, 
   {{0x7d0caed4,0x7ddc01ed,0x7ce801a9,0xa3a000cf}},	//   _afas, lésh, rоrl, _ۅڭۉن, 
   {{0x6da41e80,0x7d0caed5,0xada4aed6,0xdcf40882}},	//   вина, _bfas, ванл, _ācār, 
   {{0x7d0c07ab,0x7c2c0810,0x7bc4020b,0xfbc80375}},	//   _cfas, _bvar, _ajhu, _ות_, 
   {{0x316c0dd4,0x6444aed7,0x00000000,0x00000000}},	//   mdez_, _äkit, --, --, 
   {{0x316caed8,0x7d0caed9,0x7c2c0006,0x00000000}},	//   ldez_, _efas, _dvar, --, 
   {{0xc0c40201,0xbf88aeda,0x7d0c0368,0x7bc406be}},	//   ጸዋል_, _سئول_, _ffas, _djhu, 
   {{0x316caedb,0xfe7000aa,0x7c2c0175,0x00000000}},	//   ndez_, _دده_, _fvar, --, 
   {{0x6d54aedc,0x316c7d3d,0x7ddc00e5,0x00000000}},	// [dfc0] _ibya, idez_, désh, --, 
   {{0x3ea001ef,0x00000000,0x00000000,0x00000000}},	//   _řiti_, --, --, --, 
   {{0x7c2caedd,0x4394aede,0xdd8c07d6,0xa5242716}},	//   _zvar, ғайс, _طوی_, вмед, 
   {{0x316c0369,0xb68400c7,0x00000000,0x00000000}},	//   jdez_, ыҩса_, --, --, 
   {{0x59b005f5,0x6d54aedf,0xa3cc013a,0x00000000}},	//   _төрс, _mbya, रवल_, --, 
   {{0x9774013d,0x7ddc01d3,0xc0c400d1,0x43dc00cd}},	//   _итсә, tésk, һәли, यतेऽ, 
   {{0x6d54aee0,0x377409a5,0xa18401f4,0x00000000}},	//   _obya, _сыяс, выпл, --, 
   {{0x7ddc3847,0x6fdc0129,0xc1cc01bc,0xc0c40166}},	//   résk, lèch, ावेग, ләли, 
   {{0xded0001f,0x035405a2,0xbf100166,0xe81401f9}},	//   የውን_, _бүлә_, бүлә, दीचा_, 
   {{0x7d0caee1,0x6d54aee2,0x25a4aee3,0x7c2c030a}},	//   _sfas, _abya, lhol_, _rvar, 
   {{0x7ddcaee4,0x00000000,0x00000000,0x00000000}},	//   lési, --, --, --, 
   {{0x25a4aee5,0x90400214,0x6e3401d3,0x64440108}},	//   nhol_, دنیه, ázba, _äkis, 
   {{0x7ddc5d1a,0x4034aee6,0x3994007c,0xad242363}},	//   nési, _селс, _måst_, درپو, 
   {{0x6d540c8a,0x8fa00640,0x7ddc01d3,0x7c2c0327}},	//   _ebya, _ваље, zésh, _vvar, 
   {{0x6fdcaee7,0x7ddc20ef,0x7d0c0003,0xbf0001ad}},	//   dèch, hési, _tfas, ोडीन_, 
   {{0x7c2caee8,0x6d54006a,0x7d0c555f,0xe7780124}},	//   _tvar, _gbya, _ufas, ҭатә_, 
   {{0x7bc401af,0xc9847a83,0x25a4aee9,0x7c2c0030}},	// [dfd0] _tjhu, шури, dhol_, _uvar, 
   {{0x05745000,0x7ddcaeea,0x7c285c92,0x00000000}},	//   یاند, dési, šers, --, 
   {{0xd6d89ed2,0x7bd4aeeb,0xb6c801ed,0x7ddc01d3}},	//   фта_, mozu, رائے_, tésh, 
   {{0x7bd4aeec,0xceb002e4,0x7ddc8075,0x99400133}},	//   lozu, סיף_, fési, _خێره, 
   {{0x7ddc26b6,0xa3cc043e,0x00000000,0x00000000}},	//   gési, रवं_, --, --, 
   {{0x7bd4aeed,0x7ddc01d3,0x25a40f91,0x6fdc0036}},	//   nozu, sésh, ahol_, rèck, 
   {{0x3e4c02ea,0x7bd4005a,0x25a4aeee,0xada400d0}},	//   _fɛti_, iozu, bhol_, _hnúš, 
   {{0x25a4aeef,0x225400c6,0x7ddc0098,0xfac0004d}},	//   chol_, اليد_, mésw, _đầy_, 
   {{0x316caef0,0x7bd4aef1,0x7ddc0005,0x673002d2}},	//   rdez_, kozu, cési, _ákjö, 
   {{0x3994003b,0x60e4443f,0x31c001d9,0xd34400f1}},	//   _kåss_, ымым_, _گۅبہ, _شیبه_, 
   {{0x6fdc66ce,0x7bd42c2b,0x00000000,0x00000000}},	//   nèci, dozu, --, --, 
   {{0x23a002d2,0x9d400150,0x00000000,0x00000000}},	//   _iðja_, беюд, --, --, 
   {{0xed58016c,0xc0a800ae,0x00000000,0x00000000}},	//   _ҷой_, _لاول_, --, --, 
   {{0xf1b802ae,0xaa44aef2,0x7bd4aef3,0x53d001ad}},	//   liš_, легл, gozu, दकिश, 
   {{0x3204025f,0x8aa4001f,0x00000000,0x00000000}},	//   _july_, _ማዘጋጃ_, --, --, 
   {{0x6d540526,0x80b002dd,0x3ec4035f,0x7ae003e0}},	//   _ubya, _دەۋش, _әсәб, ülta, 
   {{0xa2d805ba,0x7ddcaef4,0x7bd4aef5,0x00000000}},	// [dfe0] _पुन्, xési, bozu, --, 
   {{0x6d444e9b,0xc1b0012c,0xab6414a3,0x9f8c0240}},	//   lgka, _जग्ग, _свол, _ዝወዓሉ_, 
   {{0x25a400a9,0x2d9081d6,0x32040306,0x6d4401f5}},	//   thol_, _koye_, _nuly_, ogka, 
   {{0x7ddcae51,0xa5d86f33,0x2d900248,0x6fdc0129}},	//   tési, ربار_, _joye_, sèch, 
   {{0x69d4aef6,0x25a4aef7,0x2d90aef8,0x27e80223}},	//   moye, rhol_, _moye_, _thbn_, 
   {{0x7ddcaef9,0x69d420a2,0x3204aefa,0x6fdc00db}},	//   rési, loye, _buly_, bèci, 
   {{0x2484070d,0x25a4aefb,0xf1b801a6,0x7ddc003e}},	//   sxom_, phol_, fiš_, sési, 
   {{0x69d4aefc,0x2d90aefd,0x7bd4aefe,0xc0346997}},	//   noye, _noye_, zozu, аниј, 
   {{0x32040280,0x80dc09bd,0x7bd4aeff,0xe7b402f5}},	//   _euly_, মেন্, yozu, জকীয, 
   {{0x69d44520,0x6560af00,0x6440000f,0x6d440942}},	//   hoye, leoh, muoi, egka, 
   {{0x2d903d81,0xf1b80f03,0x69d4af01,0xe29805f5}},	//   _boye_, biš_, koye, _яаж_, 
   {{0xf1b807f5,0xe0e4036b,0x69d4af02,0x6d443d0c}},	//   ciš_, _йўло, joye, ggka, 
   {{0x7bd4af03,0x2d90002e,0x3204007f,0x64400051}},	//   tozu, _doye_, _zuly_, nuoi, 
   {{0x6d440211,0x00000000,0x00000000,0x00000000}},	//   agka, --, --, --, 
   {{0x2d9000e8,0x7bd433c8,0x2124062c,0xcfb40375}},	//   _foye_, rozu, _keoh_, _תלוי_, 
   {{0x3914af04,0x2d900198,0x20040270,0x6440023a}},	//   рмар, _goye_, _kuoi_, kuoi, 
   {{0x200405b1,0x7bd4af05,0x65601a53,0x3dc8af06}},	// [dff0] _juoi_, pozu, deoh, _ijaw_, 
   {{0x8d740ae5,0x212400ad,0x644005d5,0xaab40214}},	//   _ناۋا, _leoh_, duoi, اگیر_, 
   {{0x7c3c0a73,0x69d401b9,0x65600418,0x2d90007f}},	//   lrsr, boye, feoh, _yoye_, 
   {{0x39440228,0x20040093,0x3204003e,0x6fdc067c}},	//   _өнүг, _ouoi_, _ruly_, rèci, 
   {{0x798c009f,0x2004004d,0x3204010e,0x64400208}},	//   mjaw, _nuoi_, _suly_, guoi, 
   {{0x6fdcaf07,0x83641c5c,0x798c24e4,0x3234af08}},	//   pèci, مدىل, ljaw, ахис, 
   {{0x20040618,0x7c3c0e78,0x64400076,0x6d4401e3}},	//   _auoi_, hrsr, auoi, ygka, 
   {{0x798caf09,0x3494af0a,0x2004af0b,0xa2801bf4}},	//   njaw, _кабр, _buoi_, تیمو, 
   {{0x3e4c0134,0x934400aa,0x2004001e,0x644401b8}},	//   _mɛtu_, _مخام, _cuoi_, _äkip, 
   {{0x81bc0029,0x7d1c03fa,0x69d4af0c,0x200401fb}},	//   _svēt, ebss, zoye, _duoi_, 
   {{0x798c0054,0x78ac02c4,0x7c3c01f5,0x21240363}},	//   kjaw, hzav, ersr, _feoh_, 
   {{0x387801f1,0x81bc005f,0x62e801d9,0x798c0a49}},	//   _orsr_, _dvēs, _شِنہ_, jjaw, 
   {{0x69d42047,0x2d900d29,0x6d44af0d,0x20040076}},	//   voye, _voye_, rgka, _guoi_, 
   {{0x78acaf0e,0x69d4af0f,0x2d90af10,0xa2d80b4c}},	//   dzav, woye, _woye_, _पुड्, 
   {{0x69d4af11,0x2124af12,0x7c3c002d,0xed34084c}},	//   toye, _yeoh_, arsr, _кэпэ, 
   {{0x798c0ac5,0x7c3c0175,0xed5801f0,0xec780395}},	//   gjaw, brsr, _рои_, _апи_, 
  
   {{0xe8f8af13,0x69d4af14,0x880800f1,0x20040051}},	// [e000] тла_, roye, اعرې_, _xuoi_, 
   {{0x1780af15,0x69d40083,0x38780419,0x86d402dd}},	//   огум, soye, _drsr_, _ﺤل_, 
   {{0x78ac7693,0x96d4035b,0xf1d42977,0xa2d801f9}},	//   azav, асцә, दवान, _पुढ्, 
   {{0x1e5404ac,0x78ac01b9,0x6440023a,0x395800a2}},	//   ישער_, bzav, tuoi, _gbss_, 
   {{0x7ddcaf16,0x6fdc00cf,0xe36401b9,0x82340092}},	//   mést, lècu, икди, _አይሁዳ, 
   {{0xdb04026c,0xe35459e6,0x93b00111,0x7ddcaf17}},	//   ghjè, ртдэ, обіц, lést, 
   {{0x200406bb,0x21240165,0x228400f7,0xd6240117}},	//   _suoi_, _peoh_, рулг, _восе_, 
   {{0x20040c04,0xa2d8810c,0x7ddcaf18,0xffd401e0}},	//   _puoi_, _पुण्, nést, әҫкә_, 
   {{0x2004af19,0x7e780334,0x9c8402f0,0x2124af1a}},	//   _quoi_, _srvp, _mlčí, _veoh_, 
   {{0x200406bb,0x442401d9,0x3ce8009b,0x29dc0042}},	//   _vuoi_, _iwm_, _rzav_, mïau_, 
   {{0x44240457,0x21248574,0x29dc0042,0xdb040200}},	//   _hwm_, _teoh_, lïau_, shjë, 
   {{0x2004af1b,0x44240070,0xd24c0799,0x798c02d0}},	//   _tuoi_, _kwm_, _زنه_, xjaw, 
   {{0xa2d81a75,0x7c3c27bb,0x29dc03cb,0x7d1c7421}},	//   _पुत्, ursr, nïau_, rbss, 
   {{0x442400d8,0x1ea80592,0x9a8401b9,0x3d28af1c}},	//   _mwm_, _لابي_, қуҳл, ختگی_, 
   {{0x44240190,0x2b580100,0x7ddc056a,0xd9b00131}},	//   _lwm_, _dbpc_, fést, قەدد, 
   {{0x78ac0137,0x4ef80302,0x7ce0063f,0x81bc005f}},	//   tzav, _בלוג, _ịrun, _zvēr, 
   {{0x798c7cba,0x225c020b,0x442402f0,0x9be400d4}},	// [e010] rjaw, _lptk_, _nwm_, _вінк, 
   {{0x78ac0b91,0x29dc0142,0x00000000,0x00000000}},	//   rzav, dïau_, --, --, 
   {{0x4424af1d,0x5f3c001f,0x78ac01d3,0x798c0327}},	//   _awm_, _በአስቸ, szav, pjaw, 
   {{0x6fdc1497,0xa6c8022e,0x00000000,0x00000000}},	//   lèct, ngаy, --, --, 
   {{0x4a240d46,0x4424af1e,0x05740372,0x7ddc01ed}},	//   _འཆོལ_, _cwm_, تالد, léss, 
   {{0x3948af1f,0x38681529,0x232402a9,0x00000000}},	//   lgas_, mwar_, боши_, --, 
   {{0x3868af20,0x27e40198,0xa2d800cd,0xc34800d4}},	//   lwar_, ɓon_, _पुद्, ряче_, 
   {{0x3948af21,0x442401d4,0x29dc0042,0x95c81c56}},	//   ngas_, _fwm_, bïau_, _руга_, 
   {{0x3948af22,0x4424af23,0xb6a405a2,0x00000000}},	//   igas_, _gwm_, _тиңл, --, 
   {{0x386802a8,0x88b4015b,0x752801a4,0x6fdc2508}},	//   iwar_, _ঝুঁক, _heez, jèct, 
   {{0x59c42894,0x44240211,0x7528af24,0x00000000}},	//   रचार, _zwm_, _keez, --, 
   {{0x3868af25,0x44240211,0x7bc8af26,0x7ddc01d3}},	//   kwar_, _ywm_, éeun, déss, 
   {{0x44240190,0x7528af27,0x6fdc068c,0x3948702e}},	//   _xwm_, _meez, fèct, dgas_, 
   {{0x3868af28,0x3948a9c4,0x00000000,0x00000000}},	//   dwar_, egas_, --, --, 
   {{0x3868000f,0x3a9802bf,0x39480549,0x7ddcaeab}},	//   ewar_, аттю_, fgas_, tést, 
   {{0x3948af29,0x75282ad1,0x7e7c00b5,0x00000000}},	//   ggas_, _neez, ærpe, --, 
   {{0xeb98af2a,0xb86400db,0x3868857f,0x67e00109}},	// [e020] _бип_, ياكو, gwar_, lôji, 
   {{0x7ddc004e,0x39480024,0x94080213,0x00000000}},	//   béss, agas_, _ömər_, --, 
   {{0x38680198,0x4424af2b,0x7ddc06af,0x44d4054e}},	//   awar_, _swm_, céss, _sπ_, 
   {{0x44240211,0x7ddc01ed,0x00000000,0x00000000}},	//   _pwm_, lésr, --, --, 
   {{0x4394af2c,0x752814a9,0x4424020c,0x00000000}},	//   жалс, _deez, _qwm_, --, 
   {{0x64a40184,0x44240070,0x29dc0368,0x2734129d}},	//   _һаба, _vwm_, rïau_, _دىسس, 
   {{0x75281418,0x29dc0368,0xf7b00150,0x5234007b}},	//   _feez, sïau_, _تەلح, مسيح_, 
   {{0x64a4af2d,0x752806f2,0x4424af2e,0x29dc03cb}},	//   _лаба, _geez, _twm_, pïau_, 
   {{0x9580121c,0x7ddc01ed,0xd00406ed,0x717000db}},	//   _элте, zéss, бење_, بۇنا, 
   {{0x75280d27,0x9cc814d4,0x00000000,0x00000000}},	//   _zeez, ғыма_, --, --, 
   {{0x3868af2f,0x67e00109,0x75282ad1,0x39480024}},	//   zwar_, gôji, _yeez, ygas_, 
   {{0x38680198,0xdef80124,0x71240e56,0xf1a800f1}},	//   ywar_, _ҩык_, _ۇرۇل, _پامه_, 
   {{0x6fdc068c,0x38680009,0x00000000,0x00000000}},	//   tèct, xwar_, --, --, 
   {{0x386864d3,0x7ddc01ed,0x98c40032,0x76440098}},	//   vwar_, téss, ҡсал, yuhy, 
   {{0x0f541203,0x39481570,0x6fdc1497,0xb4d400e1}},	//   _היום_, tgas_, rèct, _हड्_, 
   {{0x3868382f,0x394802d5,0x63b8037e,0x6fdc068c}},	//   twar_, ugas_, _lmtn, sèct, 
   {{0xa2d82ce6,0x7528af30,0x38680198,0x6fdc180f}},	// [e030] _पुस्, _reez, uwar_, mècr, 
   {{0x3868af31,0x3948af32,0x7528af33,0x0c7401ec}},	//   rwar_, sgas_, _seez, _ءديد, 
   {{0x3868af34,0x75280036,0xc9580131,0x76b8041b}},	//   swar_, _peez, شلەش_, јлер_, 
   {{0xf8b807a7,0x63b8045f,0xfe780064,0xf41c00cc}},	//   _көз_, _amtn, ivį_, _নিবৰ_, 
   {{0x63b801b9,0xf1c80208,0xdb040254,0xb7d801f7}},	//   _bmtn, hạc_, kijü, _نوحا_, 
   {{0x80dc1533,0x752804ce,0xb9d8044e,0x63b80051}},	//   _पड़े, _weez, _በሎ_, _cmtn, 
   {{0x932401ec,0x00000000,0x00000000,0x00000000}},	//   _ۇران, --, --, --, 
   {{0x7ddc01ed,0x752803ac,0x00000000,0x00000000}},	//   zésr, _ueez, --, --, 
   {{0xccf4013f,0x249003d4,0x94a8009b,0x60040006}},	//   _abɛn_, øymt_, _ства_, оным_, 
   {{0xd5840133,0xe0540014,0xd24401c6,0xe4ec4709}},	//   _خێڵه_, تیٖت_, _гэди, _जरति_, 
   {{0x41a805f5,0xad240075,0xb274af35,0x437002dd}},	//   рвөн_, يىدى, _флеш, _سۇير, 
   {{0x7d080006,0x00000000,0x00000000,0x00000000}},	//   žesn, --, --, --, 
   {{0x90e4af36,0x7ddc01ed,0x00000000,0x00000000}},	//   _اسان, tésr, --, --, 
   {{0xf1c80208,0xa2bc0d79,0x37b800cc,0x3bb800d4}},	//   bạc_, _वेड्, _অৱসৰ, бусю_, 
   {{0x69943ab4,0x7ddc01d3,0x00000000,0x00000000}},	//   орах, résr, --, --, 
   {{0x8d2804a9,0xada40835,0x00000000,0x00000000}},	//   _униң_, _фаил, --, --, 
   {{0x7ddc01d3,0x00000000,0x00000000,0x00000000}},	// [e040] pésr, --, --, --, 
   {{0x7ddc004a,0xe7380212,0x00000000,0x00000000}},	//   lésp, реж_, --, --, 
   {{0xa6c80597,0x00000000,0x00000000,0x00000000}},	//   جوال_, --, --, --, 
   {{0xa2d808dd,0x00000000,0x00000000,0x00000000}},	//   _पुष्, --, --, --, 
   {{0xeaf853e2,0x8cc000c5,0x00000000,0x00000000}},	//   _حرکت_, _लेमो, --, --, 
   {{0x7a140034,0x6ab800d2,0x2450af37,0xdb04033b}},	//   _wąte, útfw, râm_, lijò, 
   {{0xa2d802e5,0xd5ac00f1,0x2bd0276a,0x00000000}},	//   _पुश्, رځې_, _सदना, --, 
   {{0xdb040428,0xe86c0023,0xa2bc043e,0x51f0009f}},	//   nijò, _ትርጕም_, _वेण्, وسير, 
   {{0xa2d8af38,0xd1b40244,0x91b400ae,0x00000000}},	//   _पुर्, تاوا_, تطور_, --, 
   {{0xdb04026c,0x1ea801c8,0x661c143a,0x64400327}},	//   ghjì, لاجي_, oppk, mroi, 
   {{0x6e3c0020,0x00000000,0x00000000,0x00000000}},	//   _በተግባ, --, --, --, 
   {{0xd83c0122,0x64409809,0xe0d8009b,0x00000000}},	//   íčku_, oroi, _кве_, --, 
   {{0xa2bc00dc,0x6440286e,0xd5f8010f,0x9fc8004e}},	//   _वेत्, nroi, יפטר, _кгда_, 
   {{0xbebc0029,0x6440af39,0x00000000,0x00000000}},	//   rbīb, iroi, --, --, 
   {{0x6440af3a,0x80dc045e,0xbae4af3b,0x00000000}},	//   hroi, মেশ্, سكري, --, 
   {{0x6440af3c,0xcf400184,0x7ddc0789,0xd1bc01f3}},	//   kroi, _енәй, césp, _ትዝታ_, 
   {{0xdb58004e,0x8c4400f3,0x00000000,0x00000000}},	// [e050] _кюн_, _жење, --, --, 
   {{0x5ba423b3,0x9a84022e,0x00000000,0x00000000}},	//   _фриз, _думл, --, --, 
   {{0xa2d80358,0x19e000c7,0x6440af3d,0x2d980010}},	//   _पुल्, _жәаҳ, eroi, žgeš_, 
   {{0x6440af3e,0x42940023,0x00000000,0x00000000}},	//   froi, ማውነት_, --, --, 
   {{0x6440af3f,0x04c8007b,0xc6840092,0x00000000}},	//   groi, يومي_, _ሐዋርያ_, --, 
   {{0x8c1c0a1e,0x2898011a,0x73c4013d,0x00000000}},	//   סווי, _הישא, чәбе, --, 
   {{0x6440062c,0xa2bc00cd,0xc2c401c8,0x00000000}},	//   aroi, _वेद्, ويهي, --, 
   {{0x29dc03a2,0x6440af40,0x2bd012eb,0xb5c82bef}},	//   nïap_, broi, _सदभा, _اورم_, 
   {{0x6440af41,0x777400b5,0x7ae40108,0x14741888}},	//   croi, _kazx, _lyht, _بازج, 
   {{0xc2c400ec,0x00000000,0x00000000,0x00000000}},	//   _ڪيمي, --, --, --, 
   {{0xb62c04ce,0x7ae401f4,0xefb80092,0x00000000}},	//   _ｒｄ_, _nyht, _ዳኛው_, --, 
   {{0x7e7c05ac,0xc2c400ae,0x70940117,0x00000000}},	//   ærpa, _تيمي, _наеф, --, 
   {{0x7ddc0098,0x00000000,0x00000000,0x00000000}},	//   résp, --, --, --, 
   {{0x41b400cf,0x00000000,0x00000000,0x00000000}},	//   _ىمەر, --, --, --, 
   {{0xdee0af42,0x6924004e,0x00000000,0x00000000}},	//   _поши, змба, --, --, 
   {{0x644026de,0x1ae04627,0x00000000,0x00000000}},	//   yroi, хосм, --, --, 
   {{0x1c400022,0x684401c4,0x00000000,0x00000000}},	// [e060] _зным, янаа, --, --, 
   {{0x6440af43,0xad4000cf,0x00000000,0x00000000}},	//   vroi, _تۉڭۉ, --, --, 
   {{0xfe0411a9,0xdd8c15fa,0xbb0000d1,0xa968af44}},	//   _üçün_, _شوی_, _аҗри, _лина_, 
   {{0x7c34af45,0x80dc0490,0xc7b4013f,0x00000000}},	//   _äfrä, _पडले, mpɑm_, --, 
   {{0x9420af46,0x6440005b,0x1414007b,0xd36c00ec}},	//   емче, uroi, كينة_, ڏهن_, 
   {{0x6440af47,0x9440198a,0xdc340a7c,0x00000000}},	//   rroi, رپىن, לאנט_, --, 
   {{0x3f980008,0x81c00154,0x93c801d3,0x6440af48}},	//   örum_, ংকস_, حانہ_, sroi, 
   {{0x6440af49,0x7ae003fa,0x262801e4,0x25a8009f}},	//   proi, ülti, mŝo_, _ادسي_, 
   {{0x660c0050,0xd00406ed,0xe0d018fd,0x705001d3}},	//   _hubk, пење_, عزع_, نچوا, 
   {{0x25a4083a,0x660c5f0b,0xa3140408,0x00000000}},	//   lkol_, _kubk, _хьаш, --, 
   {{0x1ea80691,0x68e4a700,0x629c01b8,0x3eb80e89}},	//   صادي_, _lykd, äpod, àrt_, 
   {{0xdb040882,0x7ae402f6,0x00000000,0x00000000}},	//   vijñ, _ryht, --, --, 
   {{0x61e0af4a,0xfde8010b,0x660c0419,0x0c84af4b}},	//   _ikol, йдүк_, _lubk, нырм, 
   {{0xdb040882,0x25a4af4c,0x7ae401f4,0x00000000}},	//   tijñ, hkol_, _pyht, --, 
   {{0x61e0af4d,0x25a4af4e,0x262801e4,0x00000000}},	//   _kkol, kkol_, jŝo_, --, 
   {{0x61e0038f,0x00000000,0x00000000,0x00000000}},	//   _jkol, --, --, --, 
   {{0x61e0af4f,0x8d740533,0xa2bc4707,0x68e40432}},	// [e070] _mkol, _سايا, _वेस्, _cykd, 
   {{0x660c5b25,0x777400b5,0x61e00003,0x68e400a2}},	//   _bubk, _qazx, _lkol, _dykd, 
   {{0x9f4c0270,0x629c0ac8,0x00000000,0x00000000}},	//   _hifó_, øpol, --, --, 
   {{0x61e0af50,0x77740083,0x660c058a,0x25a40098}},	//   _nkol, _wazx, _dubk, gkol_, 
   {{0x386c04cc,0xc674001f,0x853401b9,0x98e4ad00}},	//   _èer_, _የዋርካ_, رووچ, _хюнд, 
   {{0x61e0af51,0x25a4002e,0x00000000,0x00000000}},	//   _akol, akol_, --, --, 
   {{0x61e00327,0x660caf52,0xe29402e8,0x00000000}},	//   _bkol, _gubk, дащ_, --, 
   {{0x68e400a2,0xc4ec0022,0x25a400d7,0xc55801af}},	//   _yykd, rữrã, ckol_, _нисє_, 
   {{0x660caf53,0xf1c80208,0xa03000d1,0x00000000}},	//   _zubk, bạn_, نىيت, --, 
   {{0x61e0af54,0xee38af55,0xb9d8001f,0xa1f00131}},	//   _ekol, оно_, _በጎ_, ىۋەت, 
   {{0x61e01132,0x76440368,0x5184af56,0xd24409a5}},	//   _fkol, nrhy, _нуда, _хэзи, 
   {{0x61e0007f,0x8470001f,0x00000000,0x00000000}},	//   _gkol, _ባይሆን_, --, --, 
   {{0xc104af57,0x00000000,0x00000000,0x00000000}},	//   _كومي, --, --, --, 
   {{0x68e4af58,0x7f9407d5,0xeab001d3,0x61e0013a}},	//   _rykd, _пачх, پٹر_, _zkol, 
   {{0x68e400d6,0xed589960,0xdb040ffb,0x25a45db4}},	//   _sykd, _дой_, ghjà, ykol_, 
   {{0x672c1ebd,0x660c01e4,0x68e40064,0x00000000}},	//   _sebj, _rubk, _pykd, --, 
   {{0xfe040014,0x00000000,0x00000000,0x00000000}},	// [e080] _ثبوٝ, --, --, --, 
   {{0x68e402d5,0xa6c80124,0x00000000,0x00000000}},	//   _vykd, олза_, --, --, 
   {{0x672c2dba,0x660c0009,0x25a4af59,0x6924011c}},	//   _vebj, _qubk, tkol_, _омна, 
   {{0x25a422d0,0xa2bc1a3e,0x628c06af,0x2628010f}},	//   ukol_, _वेष्, _àboi, rŝo_, 
   {{0xb3a80490,0x764401f5,0x00000000,0x00000000}},	//   कसंख, arhy, --, --, 
   {{0x61e0af5a,0x25a41509,0x2018166a,0xdb040008}},	//   _skol, skol_, _ōpio_, lhjá, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6840af5b,0x41540139,0x95806f5a,0xa0a401b9}},	//   _ክርስት, хвис, _илсе, дшол, 
   {{0xe11001f2,0x61e0af5c,0xa2bc2e04,0x00000000}},	//   _bụrị, _vkol, _वेर्, --, 
   {{0x61e0038f,0xf00000d1,0xf6b000db,0x7e7c12e8}},	//   _wkol, гүчи, _جۅۅج, ærpo, 
   {{0x9f4c004e,0xdb04023a,0x61e0af5d,0x764003cd}},	//   _sifó_, lijö, _tkol, _ålyt, 
   {{0x61e0af5e,0x5634008f,0x61440120,0x518001af}},	//   _ukol, ואטע_, _цеда, _ауша, 
   {{0xd90c24c5,0xf0b001d3,0x4c9401b9,0xdb04af5f}},	//   یید_, _میٹھ, вияс, dhjá, 
   {{0xbed40120,0x00000000,0x00000000,0x00000000}},	//   _полј, --, --, --, 
   {{0xb984085a,0x9f4c01e1,0x3ce0000d,0x00000000}},	//   нтақ, _fifò_, _गँवइ_, --, 
   {{0xdb0402f6,0x9f4c00db,0x23a0032e,0x003c0023}},	//   kijö, _tifó_, _iðju_, _ኩርንዓ, 
   {{0x7d0caf60,0x3f9caf61,0x764403cb,0x00000000}},	// [e090] _igas, _kovu_, wrhy, --, 
   {{0x7c2caf62,0x3b600014,0x3a741422,0xd6e8022e}},	//   _iwar, _حێسہ, _злор, офел_, 
   {{0x7d0caf63,0x7c2c0433,0x20c80574,0x3f9c00df}},	//   _kgas, _hwar, ापुढ, _movu_, 
   {{0x7c2caf64,0x85b801d9,0xd7d804ce,0x4ef8008f}},	//   _kwar, وانس_, _usマ_, קלאג, 
   {{0x7d0c089c,0x2d8c013f,0x7c2c025c,0x799c02d0}},	//   _mgas, _ɑfe_, _jwar, _iosw, 
   {{0x3f9caf65,0x7c2caf66,0x799c047e,0x83640d1f}},	//   _novu_, _mwar, _hosw, ندىل, 
   {{0x799caf67,0x7c2c0472,0x06140024,0x68400240}},	//   _kosw, _lwar, _адсю, _ክርሰት, 
   {{0x7c2caf68,0x799c0477,0x00000000,0x00000000}},	//   _owar, _josw, --, --, 
   {{0x799c175b,0x3f9caf69,0x3ce801d4,0x7c2c0134}},	//   _mosw, _bovu_, _nyav_, _nwar, 
   {{0x7d0caf6a,0x799caf6b,0xedf8af6c,0x2f5400d1}},	//   _agas, _losw, ृद्ध_, хтис, 
   {{0xdca0006c,0x3f9caf6d,0x7d0c063f,0x7c2caf6e}},	//   қари, _dovu_, _bgas, _awar, 
   {{0x7c2c0516,0x31b00122,0x661801ed,0x799c03cb}},	//   _bwar, _báze_, _étke, _nosw, 
   {{0x5e54034c,0x7c2c0042,0x7d0c054e,0xbc1802dd}},	//   ولیس_, _cwar, _dgas, дісі_, 
   {{0x7c2caf6f,0x7d0caf70,0xad242f7c,0x316c009d}},	//   _dwar, _egas, بىڭى, leez_, 
   {{0x799caf71,0x7c2caf72,0xdfcc8326,0xa7a800c7}},	//   _bosw, _ewar, _ديو_, ҿкаа_, 
   {{0x3f9c05a1,0x31b002fb,0xfe701ec7,0x316c005a}},	//   _zovu_, _fáze_, _خده_, neez_, 
   {{0x6d544c99,0x18646ca7,0x5828031c,0xdb04af73}},	// [e0a0] _icya, нати_, _སྦྱོ_, jhjæ, 
   {{0x5c5825f9,0xdb04af74,0x7d0caf75,0x2fc401b9}},	//   _צדיק, dhjæ, _zgas, nilg_, 
   {{0x7c2c383b,0xa9a40364,0x799c000f,0xfd4c0208}},	//   _zwar, _зинд, _fosw, _ngiệ, 
   {{0xa2d80316,0x7c2c035a,0x2fc436f4,0x00000000}},	//   _पुग्, _ywar, hilg_, --, 
   {{0x3ce801d4,0x18a0121c,0x316c009d,0xdb04005c}},	//   _xyav_, _баям, deez_, ghjæ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x799c2252,0x316c01f7,0x48fc00e1,0x6d5402d0}},	//   _yosw, feez_, लेरो_, _ocya, 
   {{0x3f9caf76,0x2fc44230,0x91e00114,0xc0c40166}},	//   _sovu_, eilg_, лоје, кәли, 
   {{0x3f9caf77,0x6b9c0660,0x7d0c022e,0x80f402e8}},	//   _povu_, _oopg, _rgas, ъпих, 
   {{0x7c2c015c,0x6d54af78,0x4fd002dd,0x543800df}},	//   _rwar, _acya, лжыт, _מעמא, 
   {{0x7c2caf79,0x3014869e,0x316c005a,0x7ddc00e5}},	//   _swar, ндөр, beez_, mész, 
   {{0xc0c00020,0xa1b86bd8,0x7c2caf7a,0xe1f8004e}},	//   _ትግል_, _عطاء_, _pwar, _эге_, 
   {{0x799c47b2,0x3f9c0a73,0x7d0c0010,0x00000000}},	//   _rosw, _tovu_, _vgas, --, 
   {{0x3f9c76ed,0xd00400a8,0x799c016d,0x7c2c007f}},	//   _uovu_, _зече_, _sosw, _vwar, 
   {{0x799c1682,0x19a81c3e,0x6b9caf7b,0x7d0c05d5}},	//   _posw, птап_, _dopg, _tgas, 
   {{0x7d0caf7c,0x799caf7d,0x628c06af,0x7ddc00e5}},	//   _ugas, _qosw, _àbou, hész, 
   {{0x7c2caf7e,0x7ddc00dd,0x3ce80166,0x48fc0073}},	// [e0b0] _uwar, kész, _uyav_, लेलो_, 
   {{0x799c0161,0x224c0270,0x7ae001ed,0x6b9c010e}},	//   _wosw, kufk_, ülts, _gopg, 
   {{0x799c0083,0xfb840022,0x7ddc00e5,0x00000000}},	//   _tosw, _зыҟн, dész, --, 
   {{0xd838152d,0xd7d800b5,0xdb04005c,0x2fc4022e}},	//   _нэг_, _spツ_, thjæ, zilg_, 
   {{0x69c00fdc,0x6b9c01a9,0xdb040254,0x7ddc00e5}},	//   _төрб, _yopg, rijõ, fész, 
   {{0x7ddc00dd,0xded0010c,0x316c0129,0xdb04af7f}},	//   gész, ከልን_, weez_, rhjæ, 
   {{0x225413e1,0xdb0400b5,0x316c005a,0xd5b8af80}},	//   نلود_, shjæ, teez_, _еса_, 
   {{0x82840046,0xa5c02347,0xdb040728,0x00000000}},	//   اجول, _көче, phjæ, --, 
   {{0x316c005a,0xdb040267,0x92480023,0x33740063}},	//   reez_, lhjä, _ዘይምዃ, _игар, 
   {{0xedc800dc,0x00000000,0x00000000,0x00000000}},	//   ाच्छ, --, --, --, 
   {{0x6b9c0221,0x2fc4022e,0xdb0401e3,0xdb0c0248}},	//   _ropg, rilg_, nhjä, _èdùm, 
   {{0x50a00131,0x308400c6,0xc2c402dd,0xbf640014}},	//   _مەبل, _للصف, _حيمي, پدیو, 
   {{0xdb0401e3,0xf0c00354,0x653800df,0x00000000}},	//   hhjä, _тιаь, וערד, --, 
   {{0x2fc401b9,0x6b9c022e,0xa06400f3,0xc30403d4}},	//   qilg_, _qopg, _раша_, _উভতি_, 
   {{0x2954074d,0x00000000,0x00000000,0x00000000}},	//   къар, --, --, --, 
   {{0x6d540a28,0xac8468ba,0xdb040267,0xdbdc032e}},	//   _ucya, _агил, dhjä, _bíóh, 
   {{0x2d580fb7,0x6b9caf81,0x6c74020a,0xeb98af82}},	// [e0c0] _všeč_, _topg, _руйх, _жип_, 
   {{0xfe10000d,0xdb04007c,0xbebc00b8,0x00000000}},	//   _ठूँस_, fhjä, dbīj, --, 
   {{0x7ddc00dd,0xd7d8037e,0xdb200332,0xdb0401e3}},	//   vész, _opテ_, _úrán, ghjä, 
   {{0xa9a4af83,0xe9a44d87,0x2d580427,0x7ddc007f}},	//   _римд, _рамп, _ušeč_, fésy, 
   {{0x7790af84,0xf608035c,0x7ddc01d3,0x8848136e}},	//   _گیلا, رتمه_, tész, _سیاق_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7ddc01ed,0x77900133,0xd254005b,0x53a00120}},	//   rész, _دیلا, вцы_, рајб, 
   {{0x80e03fae,0x16740302,0x7d0802b5,0x768c00a2}},	//   _পৃষ্, _בגלל_, _hīrū, _ỳygy, 
   {{0xb46404fb,0xe404af85,0xdfd800a7,0xffc43740}},	//   _مدله, _азап, дън_, лөкп, 
   {{0xc60000b4,0x9f6834da,0x1af800cc,0xed300051}},	//   _ịchọ, фриз_, ্ডতে_, _đượ_, 
   {{0xd1b003e6,0xa2d81b61,0xdeb00150,0x00000000}},	//   دیۆک, _पुच्, рұйы, --, 
   {{0xe044af86,0x91e01789,0x00000000,0x00000000}},	//   _анди, _кохе, --, --, 
   {{0xa4a00ba1,0xe0900133,0x157c00d1,0x00000000}},	//   _çòdi, _ڕیکخ, _ﺭﯗﺳﯩ, --, 
   {{0xdb20af87,0x7d0800b8,0xf0780166,0x628c01e1}},	//   شوری, _nīrū, _чишә_, _àbos, 
   {{0x4f840014,0xcb3400a7,0xa3c8924b,0x31b001d3}},	//   _جانہ, ресъ, _लगन_, _háza_, 
   {{0xdb0401e3,0x7d54011c,0x527800df,0x00000000}},	//   vhjä, _свих, ונלא, --, 
   {{0x7d1caf88,0xdd8c00f1,0x47240241,0x00000000}},	// [e0d0] mcss, _هوډ_, _ẹ́lí, --, 
   {{0x7d1c01ed,0xdb040267,0x8bc40138,0xeff401f3}},	//   lcss, thjä, _всюд, ለምዶ_, 
   {{0x7bc45745,0xa3d4085c,0x00000000,0x00000000}},	//   _imhu, ाचन_, --, --, 
   {{0x7d08005f,0xdb0401e6,0xded01ee0,0xf3f80183}},	//   _tīrī, rhjä, ከልና_, ুৱাৰ_, 
   {{0xdb0401e6,0x70e00ce0,0x533000c7,0x00000000}},	//   shjä, _पडेल, иҵат, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xafe401b9,0x82a40063,0xe58400cf,0xf1c80208}},	//   ғонл, ишће, _өттү, lại_, 
   {{0x94203baf,0x38780ac5,0xe49400fd,0x05840137}},	//   _نورۇ, _kssr_, ткәч_, _куум, 
   {{0x7bc4af89,0x7d1c0784,0xafe40107,0x00000000}},	//   _omhu, dcss, лоил, --, 
   {{0x53b40574,0x9f5c0100,0x387803b9,0x00000000}},	//   _अतिश, nmtè_, _mssr_, --, 
   {{0xada4af8a,0xed580364,0x6da4af8b,0x38780064}},	//   ганл, нон_, гина, _lssr_, 
   {{0x7bc400a3,0x753801f7,0x31b000d0,0x2d9400d8}},	//   _amhu, nawz, _fáza_, урос, 
   {{0x7c3c04cc,0x628caf8c,0x00000000,0x00000000}},	//   gssr, _àbor, --, --, 
   {{0xeb9800d8,0x00000000,0x00000000,0x00000000}},	//   ѕив_, --, --, --, 
   {{0x395801ee,0x387820b2,0x7c3c0076,0xa96800ea}},	//   _bcss_, _assr_, assr, нива_, 
   {{0x3958020c,0x7bc4af8d,0x64c40024,0x00000000}},	//   _ccss_, _emhu, lčiū, --, 
   {{0x38780a73,0xa764af8e,0x18b00166,0xdd140166}},	// [e0e0] _cssr_, лкад, бәрр, läşm, 
   {{0x317c0097,0xe618af8f,0x64c40024,0xeb981353}},	//   _lawz_, едж_, nčiū, _чио_, 
   {{0x2b580100,0x98a800e2,0x7d080e04,0x64c40064}},	//   _icpc_, _vecā_, žest, ičiū, 
   {{0x35e4160b,0x2b580048,0x3878020c,0x1e54008f}},	//   аців, _hcpc_, _fssr_, טשער_, 
   {{0x69c4af90,0xdedc02d3,0x1b480023,0x00000000}},	//   _imke, _ነዘን_, _ንምብራ, --, 
   {{0x425401b9,0x31b00022,0x533001e0,0x00000000}},	//   لنتر, _ráza_, бешт, --, 
   {{0x27e82a1f,0x656003fa,0xe0e80241,0x3878af91}},	//   _ikbn_, pfoh, _okòó_, _zssr_, 
   {{0x317c0007,0xbebc00e2,0x7e7802d0,0x42040014}},	//   _cawz_, lcīg, _rsvp, جستہ, 
   {{0xded01e38,0x317c0226,0x6600af92,0xb0600724}},	//   ከውን_, _dawz_, mmok, _şäre, 
   {{0x4424019b,0x6600af93,0x2b580356,0xdeb001ec}},	//   _itm_, lmok, _ncpc_, йұлы, 
   {{0x4424074d,0x7d1c074d,0x69c4af94,0xbebc005f}},	//   _htm_, tcss, _omke, icīg, 
   {{0x7a14068f,0x2b58004e,0xd434001f,0x6600af95}},	//   _wątk, _acpc_, _ሲነፃፀ, nmok, 
   {{0x4424af96,0x403404b4,0x7d1c1f06,0xf1a83bea}},	//   _jtm_, _телс, rcss, _جاله_, 
   {{0x69c435f9,0x46b41fbc,0xdb04000f,0x7d1c0175}},	//   _amke, ंनाह, chjû, scss, 
   {{0x2a78af97,0x200c208d,0x6600af98,0x2b580175}},	//   _cspb_, _iifi_, kmok, _dcpc_, 
   {{0x4424af99,0xbebc00e2,0x6d5801d3,0x8e44007b}},	//   _otm_, ecīg, őtar, _إليك_, 
   {{0x98142550,0x200c0b45,0x4424af9a,0x2a7800f3}},	// [e0f0] ابرا, _kifi_, _ntm_, _espb_, 
   {{0xd6d8af9b,0x7bc4af9c,0x200c0009,0x387800d7}},	//   нте_, _umhu, _jifi_, _vssr_, 
   {{0xd6d8af9d,0x9a84af9e,0x95c8af9f,0x69d80129}},	//   хта_, _супл, нуда_, étec, 
   {{0xd5e8afa0,0x39580048,0x200cafa1,0x44240334}},	//   رعان_, _ucss_, _lifi_, _btm_, 
   {{0x387807ab,0xb4ac0ca8,0x18b001e0,0x3374009d}},	//   _ussr_, _gẹ́g, _уҙар, игдр, 
   {{0x200cafa2,0x8c1c008f,0x60d40158,0x74400023}},	//   _nifi_, עווי, _øymy, _ኣይገብ, 
   {{0x7bd4afa3,0x0fe40131,0x02c400db,0x00000000}},	//   inzu, һлиқ_, йишү, --, 
   {{0x200cafa4,0x48fc0316,0x7bd4002f,0xdec00023}},	//   _aifi_, लेको_, hnzu, ትኡን_, 
   {{0x4424afa5,0x0fe404a9,0x33947ee4,0x00000000}},	//   _gtm_, ллиқ_, _پلاز, --, 
   {{0x7bd401f5,0xae1810eb,0x439401af,0x9f5801e1}},	//   jnzu, _नंदन_, _лаус, _òpì_, 
   {{0x200cafa6,0x60cc03be,0xaa600023,0xa3c80acd}},	//   _difi_, _əhmə, _ምፍሕፋ, _लगत_, 
   {{0x7bd4afa7,0x4424afa8,0x2b5800d8,0x60d40024}},	//   enzu, _ytm_, _scpc_, _žyme, 
   {{0x200c0cad,0x8cc0473c,0x00000000,0x00000000}},	//   _fifi_, _लेखो, --, --, 
   {{0x200c0048,0x00000000,0x00000000,0x00000000}},	//   _gifi_, --, --, --, 
   {{0x660074af,0x00000000,0x00000000,0x00000000}},	//   ymok, --, --, --, 
   {{0xe204008c,0x6844afa9,0xa924afaa,0x200c0793}},	//   _þótt_, инба, рдал, _zifi_, 
   {{0x2d9000b4,0x66000010,0xae1809b2,0x00000000}},	// [e100] _inye_, vmok, _नूतन_, --, 
   {{0x18646b10,0x00000000,0x00000000,0x00000000}},	//   рафи_, --, --, --, 
   {{0x4424afab,0x2d90009a,0x9f5c00e8,0x6600afac}},	//   _stm_, _knye_, umté_, tmok, 
   {{0x6600afad,0x44240115,0xf41c0c58,0x237c0165}},	//   umok, _ptm_, _নিজৰ_, _satj_, 
   {{0x69d4afae,0x2d9000f1,0xd7d800b5,0x00000000}},	//   mnye, _mnye_, _jpホ_, --, 
   {{0x6600afaf,0x442401a4,0x7ae80356,0x00000000}},	//   smok, _vtm_, şete, --, 
   {{0x2d9044fc,0x69d405d9,0xa59400d6,0x4424009f}},	//   _onye_, onye, _кращ, _wtm_, 
   {{0x69d4afb0,0x64a49480,0x200cafb1,0x2d90afb2}},	//   nnye, _каба, _sifi_, _nnye_, 
   {{0x69d40099,0xdfa4007b,0x90940395,0x00000000}},	//   inye, لحدي, ивът_, --, 
   {{0x69d40ac5,0x2d90afb3,0x1fa429ee,0xa2d408a3}},	//   hnye, _anye_, рриг, यपद्, 
   {{0x2484019b,0xc224afb4,0xdb040174,0x69d4afb5}},	//   lvom_, _اکتو, shjú, knye, 
   {{0x200cafb6,0xe298014b,0x00000000,0x00000000}},	//   _wifi_, _паҷ_, --, --, 
   {{0xa3c82007,0x2d90007f,0x200cafb7,0xdb0401bf}},	//   _लगा_, _dnye_, _tifi_, lhjø, 
   {{0x2d90afb8,0x248401b8,0x69d4afb9,0x2d8000d0}},	//   _enye_, ivom_, enye, adke_, 
   {{0x7bd40112,0xaa80010e,0xe20402d2,0x00000000}},	//   rnzu, _ýýll, _þóst_, --, 
   {{0x69d40097,0x248404b9,0x3914afba,0xce900107}},	//   gnye, kvom_, смар, _фаъъ, 
   {{0xa3d42413,0x3dc80280,0x69d80129,0xe3bc03e0}},	// [e110] ाचा_, _imaw_, étea, şıyo_, 
   {{0x69d4004e,0x3b543dab,0x248400d7,0xf1c80051}},	//   anye, _укор, dvom_, lạt_, 
   {{0x751406d5,0xa8000077,0x248400d7,0x00000000}},	//   مواض, íñan, evom_, --, 
   {{0xb9940597,0xd7d8019b,0xf8b800fd,0x00000000}},	//   _الحب, _jpペ_, _йөз_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x38740724,0x87e4afbb,0x00000000,0x00000000}},	//   ğarı_, _дюсе, --, --, 
   {{0x78acafbc,0x387403ee,0x0bb80375,0xb8b402dd}},	//   lyav, şarı_, שלום_, _төңі, 
   {{0x9474afbd,0x37b803d4,0x00000000,0x00000000}},	//   _پدرا, _আদিৰ, --, --, 
   {{0x78acafbe,0x2d901529,0x386c0221,0x00000000}},	//   nyav, _rnye_, _äerd_, --, 
   {{0x69d40007,0x2d900ea0,0x00000000,0x00000000}},	//   znye, _snye_, --, --, 
   {{0xbebc0029,0x2d9005b1,0xb648037e,0xc0c00240}},	//   ecīb, _pnye_, _ｊｕ_, _ስግረ_, 
   {{0x26080490,0xf17400d1,0x00000000,0x00000000}},	//   िषयी_, ﺳﻠﻪﭘ, --, --, 
   {{0x6578010f,0xa0240108,0x00000000,0x00000000}},	//   נטשה, rnöö, --, --, 
   {{0x09d00490,0xa0240254,0xa0a001c4,0x00000000}},	//   सच्य, snöö, _хашд, --, 
   {{0x2d900ac5,0x248401f1,0x78ac0083,0xada4013d}},	//   _tnye_, zvom_, eyav, _гайл, 
   {{0xad24afbf,0x2d9031a9,0x69d4003e,0xed580108}},	//   _ارغو, _unye_, unye, _сои_, 
   {{0xe8f8afc0,0x69d4afc1,0xdd140139,0x1b44013e}},	// [e120] ула_, rnye, _häşi, шҷӯи_, 
   {{0x684c02d3,0x66e46031,0xdd1420a9,0x3cec0073}},	//   _ንክርስ, боза, _käşi, _घडते_, 
   {{0xa6c800f1,0x18647577,0xe4d804f2,0x00000000}},	//   دوال_, _қари_, گوشت_, --, 
   {{0x2484a1f5,0x78acafc2,0xaa84010e,0xdd14010e}},	//   tvom_, byav, _egýä, _mäşi, 
   {{0xc44804d3,0xdd14010e,0xe4d80b6c,0x78acafc3}},	//   شیان_, _läşi, دوشت_, cyav, 
   {{0x5330afc4,0x00000000,0x00000000,0x00000000}},	//   пешт, --, --, --, 
   {{0x2484afc5,0x9c8401f1,0xdd140166,0x00cc0220}},	//   svom_, _kočí, _näşi, _ﯗﻟﺘﺘ, 
   {{0xa5080063,0x048800fb,0x673cafc6,0x65340066}},	//   _беба_, _вәки_, lapj, _درآذ, 
   {{0x2328013e,0xdb0403cd,0x00000000,0x00000000}},	//   _бози_, shjø, --, --, 
   {{0x3dc8039a,0x673cafc7,0x7d04007f,0xdd143e1f}},	//   _smaw_, napj, _jérō, _bäşi, 
   {{0xc0c04be7,0xe2142961,0x644001e3,0x95e800e5}},	//   _ስፍራ_, _طباع, lsoi, _شبہہ_, 
   {{0x6440afc8,0x673cafc9,0xc0c00023,0xabe00220}},	//   osoi, hapj, _ስግር_, _ﺍﻳﻨﺎ, 
   {{0x9cc855c7,0x6440afca,0x673cafcb,0xd12c00ae}},	//   уына_, nsoi, kapj, _أمه_, 
   {{0x673cafcc,0x69d84aee,0x78ac0882,0xc0a801d3}},	//   japj, éten, vyav, _ماڈل_, 
   {{0x5e2442f4,0x6ef003f2,0x1be401a9,0xcff4011a}},	//   _اعتق, rðbú, _ҳўнг, _הצגה_, 
   {{0x38343bb3,0x78ac0882,0x644002f6,0xd7d8037e}},	//   жнар, tyav, ksoi, _upペ_, 
   {{0x9c8413d5,0x3ec80153,0x1be4022e,0x00000000}},	// [e130] _dočí, žutė_, _гўнг, --, 
   {{0x78ac0882,0xc864024c,0xdd14008e,0x9958013d}},	//   ryav, ятси, _yäşi, bäşi_, 
   {{0x16380491,0x78acafcd,0x00000000,0x00000000}},	//   اسطة_, syav, --, --, 
   {{0x785801b9,0x00000000,0x00000000,0x00000000}},	//   _кимё_, --, --, --, 
   {{0x78ac0477,0x00000000,0x00000000,0x00000000}},	//   qyav, --, --, --, 
   {{0x5724afce,0xc7b80006,0x00000000,0x00000000}},	//   _درحق, _лёс_, --, --, 
   {{0x6440afcf,0x00000000,0x00000000,0x00000000}},	//   asoi, --, --, --, 
   {{0x95c8afd0,0x64400076,0x1af800cc,0x60d40153}},	//   _суга_, bsoi, _আলাই_, _žyma, 
   {{0x55c002dd,0x00000000,0x00000000,0x00000000}},	//   _даңғ, --, --, --, 
   {{0xe3e40832,0xdb04072b,0x148400ec,0x00000000}},	//   _وکون_, mkjæ, _پھچي_, --, 
   {{0xd9f80574,0xd3940075,0x63e402dd,0xdb0401bf}},	//   ्षात_, _вәқә_, _بيلە, lkjæ, 
   {{0xed58afd1,0xdcfc6656,0x51f400e5,0xee840022}},	//   шом_, _alqı, _اسطر, быҭо, 
   {{0x673c0054,0xdb04072b,0xdd1400a2,0x09f800cc}},	//   yapj, nkjæ, _wäşi, _আংলং_, 
   {{0xeab805f5,0xd1e80092,0x00000000,0x00000000}},	//   айг_, ሆዎች_, --, --, 
   {{0x9c84278a,0xe93810fc,0x92d40154,0x9f580248}},	//   _počí, ичај_, _সরু_, _òpá_, 
   {{0x64400197,0x451000fe,0x6c741503,0x629c01f4}},	//   ysoi, হঁতক_, _дуох, äpoi, 
   {{0x673cafd2,0x691c0219,0xa3c800af,0xe7e41d34}},	// [e140] tapj, všeč, _लगल_, कवला_, 
   {{0xdb042833,0x00000000,0x00000000,0x00000000}},	//   skjá, --, --, --, 
   {{0x673c0bc9,0xccf4013b,0xa968afd3,0x4bc40220}},	//   rapj, _hyɛ_, _кина_, _дөңг, 
   {{0x6440afd4,0xccf4016b,0xe990afd5,0xd8840014}},	//   tsoi, _kyɛ_, _تۇرگ, _ژھلن_, 
   {{0x24088343,0xa3d41062,0x4394afd6,0x64400108}},	//   анди_, ाचल_, залс, usoi, 
   {{0x673c0054,0x6440afd7,0xdd00002b,0x00000000}},	//   qapj, rsoi, _śrīn, --, 
   {{0x6440afd8,0x9660afd9,0xf6b000f7,0x00000000}},	//   ssoi, _окре, _كۅكج, --, 
   {{0x60440b30,0x7c28afda,0xdb0401bf,0xe4740006}},	//   охоз, ţeri, bkjæ, _музэ, 
   {{0xccf4013b,0x00000000,0x00000000,0x00000000}},	//   _nyɛ_, --, --, --, 
   {{0xd00406ed,0x00000000,0x00000000,0x00000000}},	//   оење_, --, --, --, 
   {{0xccf40605,0x63b801bf,0x95200133,0x23280107}},	//   _ayɛ_, _iltn, _رکۆم, _боҷи_, 
   {{0x69d8066d,0xa0683c8f,0x00000000,0x00000000}},	//   étel, _вада_, --, --, 
   {{0x0ca8afdb,0x628820e4,0x009401c0,0x809401ee}},	//   отри_, lvfo, _хилэ, _халє, 
   {{0xd004084c,0xec1801e0,0x21a00150,0x00000000}},	//   _дече_, серә_, _ﺃﻗﻠﻴ_, --, 
   {{0xccf4013f,0xaff8008f,0x0f5408c3,0x00000000}},	//   _eyɛ_, _פּני, _ויום_, --, 
   {{0x4e9024d0,0x92d40c58,0xc4bc012d,0x00000000}},	//   _آشور, _সৰু_, ्छाओ, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [e150] --, --, --, --, 
   {{0x6aa80036,0x3b5401af,0x00000000,0x00000000}},	//   ëmfë, _экор, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x63b8010f,0x4638007b,0xdc380139,0x00000000}},	//   _altn, تأكد_, lçıy, --, 
   {{0xc864afdc,0xdb140077,0xa3d40574,0xbb3408b0}},	//   _отри, _alxé, ाचं_, ﺯﮔﻪ_, 
   {{0xdb04383d,0xdc3806be,0x00000000,0x00000000}},	//   rkjæ, nçıy, --, --, 
   {{0xdb0408fb,0x31b001ed,0x00000000,0x00000000}},	//   skjæ, _házi_, --, --, 
   {{0x76440076,0xabe002dd,0x00000000,0x00000000}},	//   mshy, _ﺍﻳﻤﺎ, --, --, 
   {{0x7644afdd,0x29d4010e,0x5348010a,0xdc382ca8}},	//   lshy, _uýaň_, _кăпă, kçıy, 
   {{0xaec41cc9,0xaf98a437,0x5f400131,0xd9c00011}},	//   збол, стих_, ىچىل, ্কিম, 
   {{0x5184afde,0x7644afdf,0xc0a82c1f,0xb1140032}},	//   _муда, nshy, مایل_, _емеш, 
   {{0x76440731,0xfbc8011a,0x20100241,0x02d800ec}},	//   ishy, _גת_, _èyin_, _بگهڙ_, 
   {{0x1c400826,0x69d8afe0,0xdc380205,0x768c010b}},	//   нням, étem, fçıy, _ỳyly, 
   {{0x941c0213,0xdb040254,0xef180108,0x74bc00eb}},	//   ürəm_, kkjä, _умк_, _আখাউ, 
   {{0x3af400c9,0x00000000,0x00000000,0x00000000}},	//   дятс, --, --, --, 
   {{0x65b80022,0x31b000bc,0xeab801d5,0x764401e3}},	//   _oïha, _bázi_, айҳ_, dshy, 
   {{0x2e2001a8,0xdbd80241,0x7644062c,0xb8c40014}},	// [e160] _hóf_, _kàìn, eshy, ٘زلى, 
   {{0x66e400f0,0x00000000,0x00000000,0x00000000}},	//   поза, --, --, --, 
   {{0xaa8801ed,0xdb34011a,0x7644afe1,0x00000000}},	//   _انجم_, _מניח_, gshy, --, 
   {{0x7a14033f,0x31b000bc,0xbebc00de,0xe3b801ec}},	//   _wątr, _fázi_, kcīn, өбе_, 
   {{0x88840184,0x28140150,0x76440076,0xe7d00372}},	//   _юғал, _ءوسس, ashy, _كۅرگ, 
   {{0x60d40006,0x999c0030,0x6288007f,0x7644010e}},	//   _žymo, čuť_, tvfo, bshy, 
   {{0xdb04007c,0x00000000,0x00000000,0x00000000}},	//   ckjä, --, --, --, 
   {{0xdb2001d3,0x3cec0073,0xdcec0356,0x6288000d}},	//   _őrül, _घडले_, necă, rvfo, 
   {{0xdef40201,0x2e2000ae,0x55e00116,0xe534013d}},	//   ለውን_, _aóf_, _чотб, _меңь, 
   {{0x94b80375,0x63b802d0,0xd12c00db,0x205400db}},	//   _הממת, _ultn, _ەمن_, отүр, 
   {{0xdbcc03b9,0x00000000,0x00000000,0x00000000}},	//   _hıçq, --, --, --, 
   {{0xa0a4afe2,0x00000000,0x00000000,0x00000000}},	//   _наед, --, --, --, 
   {{0xdcec084c,0x81bc0421,0x5c04784b,0xdc38afe3}},	//   decă, _auēg, зява, tçıy, 
   {{0x8fa00b3b,0x58840022,0x00000000,0x00000000}},	//   _паче, ҟыба, --, --, 
   {{0xbae4007b,0x00000000,0x00000000,0x00000000}},	//   ذكري, --, --, --, 
   {{0xb0600166,0xca14011c,0x00000000,0x00000000}},	//   _ğäze, едсъ, --, --, 
   {{0xdc380205,0x00000000,0x00000000,0x00000000}},	// [e170] pçıy, --, --, --, 
   {{0x7c2cafe4,0x5ba4390e,0x7644007c,0x00000000}},	//   _itar, _хриз, tshy, --, 
   {{0x752c09c2,0xdb0401a8,0x76440108,0x00000000}},	//   ñazo, rhjó, ushy, --, 
   {{0x7644a0be,0x0708819a,0x7ae40200,0x7c28054e}},	//   rshy, سيني_, _ixht, ţeru, 
   {{0x7c2c0327,0x764411c0,0x1b480023,0x00000000}},	//   _jtar, sshy, _ንምቕራ, --, 
   {{0x3868afe5,0x7c2cafe6,0xa920032e,0x00000000}},	//   mtar_, _mtar, _óþrj, --, 
   {{0x71a43129,0x00000000,0x00000000,0x00000000}},	//   дайз, --, --, --, 
   {{0x38680332,0x00000000,0x00000000,0x00000000}},	//   otar_, --, --, --, 
   {{0x7c2cafe7,0x75286837,0x00000000,0x00000000}},	//   _ntar, _ifez, --, --, 
   {{0x3868afe8,0x00000000,0x00000000,0x00000000}},	//   itar_, --, --, --, 
   {{0x90e4afe9,0x69d80525,0x3868afea,0xac880023}},	//   _کسان, étek, htar_, _ንኩሎም_, 
   {{0x386833b8,0x7c2c005a,0x9b900014,0xd6bc00eb}},	//   ktar_, _btar, ۆلُت, _আশায, 
   {{0xdc10afeb,0x3868afec,0xab280a89,0x6e200022}},	//   _ağıl, jtar_, жога_, sqlb, 
   {{0xee385267,0x3868afed,0x7c2c007b,0x5f880014}},	//   _днк_, dtar_, _dtar, _وٕنہ_, 
   {{0x7c2cafee,0x38680261,0x7528afef,0xb0600724}},	//   _etar, etar_, _ofez, _ğäye, 
   {{0x3868aff0,0xcee46112,0xae040220,0x75280327}},	//   ftar_, _ورژن_, _توبى, _nfez, 
   {{0x186462ba,0x38680597,0xe7a8722e,0x6ea40014}},	// [e180] мати_, gtar_, овал_, _رچھہ_, 
   {{0x75289c78,0x7a140034,0xc3080154,0x8c380117}},	//   _afez, _wątp, রুটি_, _мӯҳр_, 
   {{0xfd640208,0x80d407af,0x00000000,0x00000000}},	//   _nhuố, _बेने, --, --, 
   {{0x3868aff1,0x7c2c03b2,0x00000000,0x00000000}},	//   btar_, _ytar, --, --, 
   {{0xe3bc00c6,0xa3e8039b,0x7c2c025c,0xdbcc008e}},	//   иαи_, одда_, _xtar, _qıçq, 
   {{0x7528aff2,0x66e40209,0x7ae4022e,0x69ac012d}},	//   _efez, _жога, _yxht, ीसवी, 
   {{0x75281418,0xfd64001e,0x316c06af,0xdef40092}},	//   _ffez, _chuố, ffez_, ለውና_, 
   {{0x6814007f,0x31b002f0,0xdbcc0139,0x91e000ea}},	//   _kņdo, _oázu_, _tıçq, које, 
   {{0x6e2c0063,0xb1441fc2,0x80b8033f,0x00000000}},	//   _čaba, ریوم_, इनें, --, 
   {{0x7c2c0140,0xdef80006,0x629c39fa,0xa2240066}},	//   _rtar, жым_, äpos, _قرصه, 
   {{0x3eb8aff3,0x3f980598,0x1ea83090,0x386801c4}},	//   árt_, ıru_, زادي_, ztar_, 
   {{0x25a4aff4,0xa3d40d01,0x3868aff5,0x301400f7}},	//   njol_, ाचक_, ytar_, мдөр, 
   {{0x61e0aff6,0x3868aff7,0x5b2401f4,0x00000000}},	//   _ijol, xtar_, дьба, --, 
   {{0xb34403b7,0x61e002d2,0x386806ea,0x7ae80205}},	//   maçã, _hjol, vtar_, şetm, 
   {{0xb3440cfc,0x61e06ab9,0x2900020b,0xc92c0521}},	//   laçã, _kjol, _azka_, _ọsịs, 
   {{0x3868aff8,0x3914aff9,0x61e001c7,0x25a401a9}},	//   ttar_, ембр, _jjol, jjol_, 
   {{0xb34403b7,0x3868affa,0x80d41524,0xda1c00e1}},	// [e190] naçã, utar_, _बेमे, _मूरत_, 
   {{0x3868affb,0xd7740a2c,0x291c9b98,0xb7880166}},	//   rtar_, بارع, _ştat_, чәме_, 
   {{0x7bd4affc,0x61e00789,0x7528005a,0xdc100139}},	//   mizu, _ojol, _pfez, _uğıl, 
   {{0x61e0affd,0x00000000,0x00000000,0x00000000}},	//   _njol, --, --, --, 
   {{0x38680a84,0x00000000,0x00000000,0x00000000}},	//   qtar_, --, --, --, 
   {{0x7bd4affe,0xb3440261,0x3a20562c,0xd7607be0}},	//   nizu, daçã, _kuhp_, _جنسی, 
   {{0xef1864b6,0xd5640108,0x00000000,0x00000000}},	//   үми_, _отап, --, --, 
   {{0x7bd4afff,0x7528b000,0xb3440798,0xf6440408}},	//   hizu, _ufez, façã, ăхĕн, 
   {{0xb34403b7,0x7bd4b001,0x61e0b002,0x69d8004a}},	//   gaçã, kizu, _djol, étei, 
   {{0xfd6407ae,0x6004876e,0x61e0004b,0x09dc0782}},	//   _thuố, нным_, _ejol, _यद्य, 
   {{0x61e0b003,0x645c0034,0x7bd4b004,0xda1c05d7}},	//   _fjol, ąpie, dizu, _मूलत_, 
   {{0xfce80020,0xc2c40150,0x82349b26,0x6da4b005}},	//   _መዋጮ_, _جيمي, _شرما, хима, 
   {{0xb3440cfc,0x320cb006,0x7bd402d3,0x40840032}},	//   caçã, mmey_, fizu, _аҙым_, 
   {{0x320c0978,0x7bd470b5,0x31b002f0,0xbb74011c}},	//   lmey_, gizu, _vázu_, кусъ, 
   {{0x6e940597,0xc4dc0254,0x320c058a,0xddc800a2}},	//   _ألعا, _मख्ख, omey_, _çişd, 
   {{0x3eb810b8,0x320cb007,0x7d0800de,0xa784036b}},	//   ørte_, nmey_, _būrī, کشرو, 
   {{0x6d4459e4,0xa804b008,0xdbd80ca8,0xbbe805d9}},	// [e1a0] maka, езал, _fààn, _ڪريم_, 
   {{0x6d44b009,0x7d086991,0xa024005b,0x7bd40200}},	//   laka, _dūrī, liöö, cizu, 
   {{0xb3440cfc,0xfca800f2,0x764000c7,0x00000000}},	//   zaçã, _فایو_, иҭра, --, 
   {{0x6d44b00a,0x06c400fe,0x320c0978,0xa024000d}},	//   naka, ্থলি, jmey_, niöö, 
   {{0xb34406ed,0x320c016d,0x393401c6,0x25a40327}},	//   xaçã, dmey_, _шээс, rjol_, 
   {{0x69d4b00b,0x6d44b00c,0xb34403b7,0xf1b800da}},	//   liye, haka, vaçã, ekš_, 
   {{0x6d44b00d,0x61e00fac,0x68f000bc,0x23c40014}},	//   kaka, _pjol, ředě, وٕچہ, 
   {{0x6d44b00e,0x7bd4b00f,0xb3440cfc,0x320c047e}},	//   jaka, zizu, taçã, gmey_, 
   {{0x61e0b010,0x7bd4b011,0xd5ac4ce4,0x69d40009}},	//   _vjol, yizu, _افق_, iiye, 
   {{0xb3440a16,0x69d445b2,0x6d440221,0x50b400c6}},	//   raçã, hiye, eaka, عديد_, 
   {{0x6d44b012,0x7bd4b013,0xd3340302,0xb34406ed}},	//   faka, vizu, _נראה_, saçã, 
   {{0x6560b014,0x7bd4b015,0xb3440261,0x69d40050}},	//   ngoh, wizu, paçã, jiye, 
   {{0x69d4b016,0xc0c40075,0xdb0408fb,0x4cd40183}},	//   diye, _шәки, lkjø, _ধুবু, 
   {{0x69d40295,0x5018025d,0x6d4400e4,0xb0600139}},	//   eiye, _זוגו, aaka, _şäge, 
   {{0x7bd4b017,0x656001e0,0x69d4b018,0xdb0403a1}},	//   rizu, kgoh, fiye, nkjø, 
   {{0x6d44b019,0x69d4b01a,0xceb00302,0x7bd43058}},	//   caka, giye, _תיק_, sizu, 
   {{0x3914b01b,0x47bc0183,0x7bd4005a,0x3f8c0009}},	// [e1b0] тмар, োচনী, pizu, oddu_, 
   {{0x320c05b1,0x386c01c7,0x7bd40240,0xdb0403cd}},	//   zmey_, _äerm_, qizu, kkjø, 
   {{0x69d4b01c,0x320cb01d,0xc30803d4,0x00000000}},	//   biye, ymey_, ৰুতি_, --, 
   {{0x69d4b01e,0x7d0800b0,0xdb0408fb,0xb90400db}},	//   ciye, _tūrī, dkjø, _үзүк, 
   {{0x799cb01f,0x3f9c0083,0xdb0403cd,0x84280212}},	//   _insw, _onvu_, ekjø, ежів_, 
   {{0x798cb020,0x78040107,0x320c047e,0xdbd801e1}},	//   ldaw, _рӯба, wmey_, _yàán, 
   {{0xdb041445,0x6560022e,0x320c0978,0x701000b8}},	//   gkjø, bgoh, tmey_, _nākṛ, 
   {{0x798c7e70,0xa2b009fa,0x6d44b021,0x64d00490}},	//   ndaw, _अथर्, xaka, _देवळ, 
   {{0x6d44b022,0x320cb023,0x798cb024,0xafe40108}},	//   vaka, rmey_, idaw, коил, 
   {{0xe0d4023a,0x799c02d0,0x320c0978,0x3f8c0142}},	//   твь_, _lnsw, smey_, gddu_, 
   {{0x6d44b025,0xed581d18,0xc0e0044e,0x798c0066}},	//   taka, мон_, _ሓያል_, kdaw, 
   {{0x69d40050,0x3f8c198f,0x30740276,0x320c0978}},	//   xiye, addu_, _аукс, qmey_, 
   {{0xc8d013b4,0x798cb026,0x69d403ee,0xa0241577}},	//   _सेंट, ddaw, viye, riöö, 
   {{0x799caf02,0x798c009a,0x69d4b027,0xa02426bb}},	//   _answ, edaw, wiye, siöö, 
   {{0x6d44b028,0x7d0802b5,0xab84010b,0x798c0327}},	//   paka, _rūrū, нуңк, fdaw, 
   {{0x798c2819,0x60d40006,0x60040ad9,0x00000000}},	//   gdaw, _žymi, rðme, --, 
   {{0x7d0800b0,0x799c035a,0x5c84b029,0xa764b02a}},	// [e1c0] _pūrū, _dnsw, _айым_, ккад, 
   {{0x69d4b02b,0x799cb02c,0xea6001d9,0x57e4010b}},	//   siye, _ensw, _پھسی, вдум_, 
   {{0x69d4b02d,0x798c0198,0xdb0403cd,0x656001d5}},	//   piye, bdaw, xkjø, tgoh, 
   {{0xdb0403cd,0x68441246,0x2bcc8109,0x69d41898}},	//   vkjø, _инма, होरा, qiye, 
   {{0x6560b02e,0x7d0800b0,0x3f8c0368,0x69d80129}},	//   rgoh, _tūrū, yddu_, éteu, 
   {{0xdb0403cd,0x13f0109a,0x95940022,0x00000000}},	//   tkjø, азія, етәу_, --, 
   {{0x2284405c,0x00000000,0x00000000,0x00000000}},	//   тулг, --, --, --, 
   {{0xdb04168c,0x80b000cc,0x00000000,0x00000000}},	//   rkjø, _জেষ্, --, --, 
   {{0xdb04b02f,0x35c415d1,0x14200229,0x437414fb}},	//   skjø, _сатҳ, _вдум, _مۇشر, 
   {{0xdb0408fb,0x4424b030,0x798c012d,0x234801c8}},	//   pkjø, _ium_, zdaw, _آلاپ_, 
   {{0x798cb031,0x3d140073,0x3f8c03cb,0x9958010e}},	//   ydaw, नेने_, rddu_, bäňi_, 
   {{0x4424b032,0x798c0007,0x7c34036b,0x3f8c0142}},	//   _kum_, xdaw, лемх, sddu_, 
   {{0x4424b033,0xe20c01ad,0x9cc83c1a,0x799c03ac}},	//   _jum_, ागीण_, фына_, _rnsw, 
   {{0x44242f99,0x452800bd,0x798cb034,0x00000000}},	//   _mum_, মরিক_, wdaw, --, 
   {{0x4424b035,0x9964807e,0x9e0413c3,0x7f48011f}},	//   _lum_, ктал, _ичил, madq, 
   {{0xd83805f5,0x3ce80070,0x1da406b1,0x4424b036}},	//   дэж_, _txav_, _औचित, _oum_, 
   {{0x4424b037,0xf8b805f5,0x798cb038,0x7798b039}},	// [e1d0] _num_, хөн_, rdaw, нкар_, 
   {{0x3dd87acd,0x7f48014f,0x798cb03a,0x00000000}},	//   lisw_, nadq, sdaw, --, 
   {{0x95c8016c,0x799c02d0,0x8ae41cb8,0x00000000}},	//   муда_, _tnsw, _віял, --, 
   {{0x4424b03b,0x799c514c,0x7f48628c,0x69d8559d}},	//   _bum_, _unsw, hadq, étet, 
   {{0x4424b03c,0x33d4005e,0x3948b03d,0x38780092}},	//   _cum_, лікт, maas_, _upsr_, 
   {{0x4424b03e,0x3948b03f,0x6ec400cd,0x249400f1}},	//   _dum_, laas_, ानमु, انود_, 
   {{0x44240de4,0x3dd8b040,0xc668b041,0xc3480212}},	//   _eum_, kisw_, _иште_, тяче_, 
   {{0x4424b042,0x3948b043,0x81bc00ef,0x00000000}},	//   _fum_, naas_, _stēr, --, 
   {{0x44240013,0x544004a9,0x6ec40406,0x3db803d4}},	//   _gum_, _ئۆتك, ानभु, ঁফাল, 
   {{0xee388af4,0xafc40c50,0x39480050,0x439401ee}},	//   нно_, ايدى, haas_, _каус, 
   {{0x4424b044,0x3948b045,0xda000574,0xd2002cc8}},	//   _zum_, kaas_, लतात_, _күкк, 
   {{0x4424b046,0x3948b047,0x00000000,0x00000000}},	//   _yum_, jaas_, --, --, 
   {{0x39480a81,0x4424b048,0xbf881079,0x7f480139}},	//   daas_, _xum_, رئیل_, badq, 
   {{0xa0645660,0xe0400323,0x00000000,0x00000000}},	//   _саша_, _унши, --, --, 
   {{0x3948208d,0x94f0031c,0x452800fe,0x98940022}},	//   faas_, _བཙའི_, মৰিক_, қутә, 
   {{0x3948b049,0x6ab4031c,0xabe00150,0xf3e800eb}},	//   gaas_, _ċafċ, _ﺍﻳﻌﺎ, গতির_, 
   {{0x2d80b04a,0x98a0470c,0xab28b04b,0xeb9800f3}},	// [e1e0] meke_, бите, _попа_, _зип_, 
   {{0x2d80b04c,0x9d180375,0x574000db,0x00000000}},	//   leke_, _אופט, йнуб, --, 
   {{0x44248c07,0x68440166,0x69d874f2,0x00000000}},	//   _sum_, _әнга, étes, --, 
   {{0x2d80b04d,0x4424b04e,0x7ae010e6,0x394801d9}},	//   neke_, _pum_, últe, caas_, 
   {{0x44240978,0x2d8001c4,0x00000000,0x00000000}},	//   _qum_, ieke_, --, --, 
   {{0x44241859,0x2d80b04f,0x65b800b0,0x4394b050}},	//   _vum_, heke_, _mïhi, ракс, 
   {{0x2d80b051,0x4424b052,0x42a40075,0x97c03947}},	//   keke_, _wum_, рулғ, _уйре, 
   {{0x2d80b053,0x44240de4,0x65b800e4,0x71700136}},	//   jeke_, _tum_, _oïhi, قۇما, 
   {{0x4424b054,0xb5d000e5,0x717000db,0x00000000}},	//   _uum_, _بےنظ, تۇنا, --, 
   {{0x24840165,0x53a000f3,0x00000000,0x00000000}},	//   mwom_, _лауб, --, --, 
   {{0x200000da,0x3948b055,0x2d8072dc,0x9f5c0023}},	//   ēki_, yaas_, feke_, lltë_, 
   {{0x2d8042c9,0x394801d9,0x40a800f2,0x60d40153}},	//   geke_, xaas_, _لختی_, _žymu, 
   {{0xdfd806bb,0x2484013f,0x00000000,0x00000000}},	//   _пък_, nwom_, --, --, 
   {{0x3948b056,0x9a84b057,0x7f48014f,0xd00c00ae}},	//   waas_, лубл, qadq, _فلن_, 
   {{0x3948b058,0xec18053f,0x53980302,0x91d400fe}},	//   taas_, терә_, עילו, ডকৰ্, 
   {{0x2d806837,0xc4c4033f,0x6ab8003b,0x0e9800df}},	//   ceke_, वनाओ, øtfa, _טשול, 
   {{0x3948b059,0x4bc42be5,0xa80000ac,0x7ae000e5}},	// [e1f0] raas_, рөөг, ğınc, últb, 
   {{0x3948b05a,0xa8000790,0x69d800e5,0x57a40132}},	//   saas_, şınc, éter, ышба, 
   {{0x7bc4153b,0x39480de2,0x00000000,0x00000000}},	//   _ilhu, paas_, --, --, 
   {{0x39480a55,0x00000000,0x00000000,0x00000000}},	//   qaas_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2d80b05b,0x60040162,0x534418cd,0x321c0210}},	//   zeke_, yðma, ухда, _siwy_, 
   {{0x2d806ae1,0x02d817ee,0xabe001ec,0x3d1405c0}},	//   yeke_, _भेदभ, _ﺍﺳﻔﺎ, नेते_, 
   {{0x2d80966a,0xa6e0032e,0x00000000,0x00000000}},	//   xeke_, _æðak, --, --, 
   {{0x81bc0418,0x2d80b05c,0x00000000,0x00000000}},	//   _tuēn, veke_, --, --, 
   {{0x2d80b05d,0x9394027d,0x00000000,0x00000000}},	//   weke_, _حجرا, --, --, 
   {{0x2d80b05e,0x2b480a73,0xd0600213,0xc3300050}},	//   teke_, vabc_, _əsəd, _ژٕے_, 
   {{0xa6b000cc,0x41e40006,0x71240116,0x00000000}},	//   _টেঁট, _ліча, _ئىشم, --, 
   {{0x814c008f,0xe7f8227c,0x628c032e,0x00000000}},	//   _טעאַ, ्तमा_, _ábor, --, 
   {{0x2d80b05f,0xeb34198a,0xc1043090,0x6b6416a4}},	//   seke_, شىرد, _اوهي, јква, 
   {{0x2d80b060,0xaa441de1,0x7ff44c9a,0x7bc40419}},	//   peke_, ребл, _اسنا, _dlhu, 
   {{0x7bc41ac7,0x2d800b6f,0x2b485d80,0x00000000}},	//   _elhu, qeke_, sabc_, --, 
   {{0xdb140166,0x6d54b061,0xa6c8022e,0x00000000}},	// [e200] _alxä, _idya, hbаt, --, 
   {{0xeb98b062,0xe7380c17,0xa69400d8,0x00000000}},	//   _рио_, теж_, иреј, --, 
   {{0xa524b063,0xa684b064,0xbbe85230,0x7f740023}},	//   амед, рлед, _حريم_, ጥሮኣዊ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69c4b065,0x638401c0,0xf1a82802,0x645c012d}},	//   _ilke, игда, कानन, ąpio, 
   {{0x7d0000ae,0x53300139,0x00000000,0x00000000}},	//   lárú, оешт, --, --, 
   {{0x6d54033b,0xdec01954,0x00000000,0x00000000}},	//   _odya, ስቡን_, --, --, 
   {{0x6d54b066,0xc0c40032,0x00000000,0x00000000}},	//   _ndya, йәли, --, --, 
   {{0x1f28069c,0xdfa40f14,0x6600b067,0xa34801d5}},	//   _ተቓወም, ајно, mlok, _азза_, 
   {{0x6d54b068,0xfbe40150,0x00000000,0x00000000}},	//   _adya, _ﺍﻳﺎﻛ, --, --, 
   {{0x69c4b069,0x66002e6d,0xd36c00e3,0x9d000011}},	//   _olke, olok, _آهم_, _এলেন_, 
   {{0x6600b06a,0x629802f6,0xbc880022,0xe0d8009b}},	//   nlok, _irto, гӡоз_, _иве_, 
   {{0x7bc40211,0xa3c8000d,0xbebc00ef,0x00000000}},	//   _plhu, _ऊता_, ecīt, --, 
   {{0x6600b06b,0x69c4b06c,0x6d540209,0x69d8004a}},	//   hlok, _alke, _edya, èten, 
   {{0x8f500244,0x00000000,0x00000000,0x00000000}},	//   _بۆپش, --, --, --, 
   {{0x9c44074d,0x660000e5,0xdb0c0241,0xbc9001ee}},	//   _кхол, jlok, _àdíj, _еңмә, 
   {{0xdb58b06d,0x6600b06e,0x7bc40978,0x58840024}},	// [e210] _июн_, dlok, _tlhu, шыва, 
   {{0x960c1810,0x69c4b06f,0x9ba041c3,0x6600b070}},	//   िष्ट_, _elke, _بەسى, elok, 
   {{0x660026b8,0x9a8418ce,0xf1a89417,0x629c007c}},	//   flok, _тупл, कामन, åpol, 
   {{0xa6c8022e,0xf8b000e5,0x00000000,0x00000000}},	//   vbаt, _ٹکر_, --, --, 
   {{0xd8c800a8,0xe7a4b071,0x00000000,0x00000000}},	//   _рынд_, _گۇلى_, --, --, 
   {{0x629801a6,0x6600b072,0x833802e8,0x13a400f1}},	//   _brto, alok, ачът_, شنبی_, 
   {{0x956406bb,0x629801a6,0x4b7c010f,0x00000000}},	//   _възд, _crto, דאוו, --, 
   {{0x92e82be7,0x629805da,0xe7f800dc,0x6600b073}},	//   _یراق_, _drto, ्तथा_, clok, 
   {{0x6298b074,0xa6c8022e,0x1368014b,0x00000000}},	//   _erto, sbаt, _ашеи_, --, 
   {{0x6d54003e,0xa6c8022e,0x1f280023,0x00000000}},	//   _sdya, mbаr, _ተቓውም, --, 
   {{0xb63804ce,0xe7f80e85,0x3d1401ad,0x25ec00c5}},	//   _ｅｋ_, ्तता_, नेसे_, _अदमी_, 
   {{0xc0a801d3,0xafc404b3,0xabe00150,0xb4f8010f}},	//   _چاول_, _گيتى, _ﺍﻳﻘﺎ, ָפֿי, 
   {{0xc0a8b075,0x00000000,0x00000000,0x00000000}},	//   _ناول_, --, --, --, 
   {{0xcbb802a6,0x80b000cc,0x00000000,0x00000000}},	//   ুচ্ছ, _জেক্, --, --, 
   {{0xd5c405d7,0xff500214,0xdee002a9,0xa6c801d5}},	//   लसाज, _آخه_, _ноши, hbаr, 
   {{0x7ae00aaa,0x3eb803fa,0x6d5400dc,0xed4400f3}},	//   últa, ärte_, _udya, _унип, 
   {{0x98a0b076,0x2d900083,0xb8640b24,0x6600017a}},	// [e220] пите, _iaye_, قالو, vlok, 
   {{0xab643580,0x2d90b077,0xb86400cf,0x6fb801ad}},	//   _увол, _haye_, تافو, ेसिं, 
   {{0x2d90b078,0x6600b079,0xdb98008f,0xa968074d}},	//   _kaye_, tlok, _עסטר, _йина_, 
   {{0x5ef8008f,0x69c403e0,0x2d90b07a,0x00000000}},	//   אפעד, _ulke, _jaye_, --, 
   {{0x6600b07b,0x2d90b07c,0x545001ce,0x28b8084c}},	//   rlok, _maye_, звіт, _сунэ_, 
   {{0x64a4b07d,0x2d90b07e,0x9d18008f,0x937402dd}},	//   _қаза, _laye_, אונט, йбіт_, 
   {{0x6600b07f,0x2d90062c,0x93c81893,0x17c44965}},	//   plok, _oaye_, دانہ_, _угри_, 
   {{0x2d90b080,0x84c40032,0xc0341677,0xc1b87b17}},	//   _naye_, _мәлд, ониј, рлих_, 
   {{0x386c04e6,0x00000000,0x00000000,0x00000000}},	//   _äert_, --, --, --, 
   {{0x2d90110e,0x290000a2,0x60040162,0x00000000}},	//   _aaye_, _myka_, rðmo, --, 
   {{0xd334025f,0x2d90b081,0x2900079b,0x63041c4e}},	//   _הרבה_, _baye_, _lyka_, _اوال, 
   {{0x2d9005b1,0x823401e2,0x00000000,0x00000000}},	//   _caye_, _هرچا, --, --, 
   {{0x2d90b082,0x21240055,0x290000a2,0xdb580395}},	//   _daye_, _igoh_, _nyka_, люв_, 
   {{0x7a3001e4,0xd9b00034,0x399401f2,0xa3bc39a1}},	//   _aĥta, ीस्ट, _ụs_, ँघट_, 
   {{0x2900b083,0x4f840014,0x0c040014,0x6d58036e}},	//   _ayka_, _دانہ, سوفُ, ėtar, 
   {{0x2d90b084,0x00000000,0x00000000,0x00000000}},	//   _gaye_, --, --, --, 
   {{0x3dc8113c,0x5724b085,0x8d74b086,0x69d81c54}},	// [e230] _ilaw_, مراق, _رايا, _नगरी, 
   {{0x2d90b087,0x2900a9e3,0x00000000,0x00000000}},	//   _zaye_, _dyka_, --, --, 
   {{0x2d90021a,0x2900022c,0x21240b43,0x00000000}},	//   _yaye_, _eyka_, _ogoh_, --, 
   {{0x996413dc,0x21240477,0x99c40050,0x4ef80a7c}},	//   _утол, _ngoh_, _چُھے_, נהאו, 
   {{0xf8b80323,0x00000000,0x00000000,0x00000000}},	//   _төв_, --, --, --, 
   {{0x36d409a5,0x3dc800a9,0x7dcc002d,0xcc78011a}},	//   _догр, _llaw_, _hûsd, צגות_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa6b000bd,0x5f400131,0xa1f000d1,0x00000000}},	//   _টেকট, ۈچىل, ۋۋەت, --, 
   {{0x2d90b088,0x7d0c2e6e,0x78acb089,0xefcc0092}},	//   _raye_, _nzas, nxav, _ቢሮው_, 
   {{0x2d90b08a,0x3dc8b08b,0x78ac004e,0x00000000}},	//   _saye_, _alaw_, ixav, --, 
   {{0x2d90b08c,0x7d0cb08d,0x3dc80493,0x7c3c0373}},	//   _paye_, _azas, _blaw_, epsr, 
   {{0x3dc8b08e,0x71400014,0xc2c4007b,0x6da4b08f}},	//   _claw_, _کھژٕ, _عيني, цима, 
   {{0x7d0c006d,0x7fe8144c,0x27f8089c,0x6e2c01fa}},	//   _czas, شریف_, yopn_, _čabu, 
   {{0x7d0c3dc1,0x2d90b090,0xeb9801c0,0x2900007c}},	//   _dzas, _waye_, шиг_, _ryka_, 
   {{0x7d0c016e,0x7dcc002d,0x2d90b091,0x7dd000e4}},	//   _ezas, _bûsd, _taye_, _ẽsem, 
   {{0x39580161,0xed5825ea,0x3dc80368,0x8d4400ee}},	//   _cdss_, _тои_, _glaw_, _эдиҗ, 
   {{0x78ac014b,0x7d0c0139,0xc8c407f7,0x00000000}},	// [e240] gxav, _gzas, लैंट, --, 
   {{0x62880142,0xb0600139,0x00000000,0x00000000}},	//   ywfo, _ğäle, --, --, 
   {{0xc44803e6,0x85a40166,0xb0600166,0x00000000}},	//   ڵیان_, зылҗ, _şäle, --, 
   {{0x395801f7,0x2900b092,0x752c01c4,0x7d0c010e}},	//   _gdss_, _tyka_, ñazp, _yzas, 
   {{0x29000309,0xb0d80210,0x54301699,0x59bc8497}},	//   _uyka_, _बेलग, ورور, _एकतर, 
   {{0xdc98008f,0x39580010,0x7d00032e,0x2bcc01f9}},	//   יינל, _zdss_, _hárþ, होचा, 
   {{0x04fc03f4,0x62880d27,0xe61800f5,0x00000000}},	//   েশের_, uwfo, _вдв_, --, 
   {{0xd6cc00c6,0x62880036,0xe7f84709,0x80b42901}},	//   _شقق_, rwfo, ्तवा_, збих, 
   {{0x30382354,0x00000000,0x00000000,0x00000000}},	//   یتیک_, --, --, --, 
   {{0x3dc80493,0x18780375,0x84c4008e,0xb0d80073}},	//   _slaw_, סטיב, _мәһд, _बेळग, 
   {{0x3dc80218,0xf1a803e6,0x7d0cb093,0x2bcc00bc}},	//   _plaw_, _گاله_, _szas, होछा, 
   {{0x31b002f0,0xbb280116,0x00000000,0x00000000}},	//   _oázy_, ﻤﺪﻩ_, --, --, 
   {{0x48cc015b,0xf1a80133,0x00000000,0x00000000}},	//   লপুর, _داله_, --, --, 
   {{0x8ff400aa,0x3958107d,0x7c3cb094,0x8fa00276}},	//   _ورور_, _sdss_, rpsr, _оаче, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7dcc000f,0x7e680a73,0x3834b095,0x7c3c3402}},	//   _bûse, mudp, знар, ppsr, 
   {{0x7d0cb096,0x247c1a14,0x9f5c02f0,0x7e688e54}},	// [e250] _uzas, nāmā_, hltí_, ludp, 
   {{0x3a740220,0x78ac00db,0xa6d400cc,0xee740244}},	//   _елор, rxav, _তুইট, _بڵیت_, 
   {{0x7c2c0325,0x7e680477,0xb0600139,0x98a4b097}},	//   _huar, nudp, _ğäme, ğnı_, 
   {{0x7c2c0588,0x7dcc002d,0x85b8143e,0x31b000d0}},	//   _kuar, _hûsb, يانس_, _fázy_, 
   {{0xb0d80027,0x7e680477,0xa93405d0,0x85041291}},	//   _बेंग, hudp, _מטרה_, وومن, 
   {{0x386802d3,0x7c2cb098,0x7c24014f,0x247c00e2}},	//   muar_, _muar, _jihr, dāmā_, 
   {{0x3868b099,0x7c2cb09a,0xe7f86653,0x59bc8109}},	//   luar_, _luar, ्तरा_, _एकार, 
   {{0x7c2cb09b,0x95c8b09c,0x948401ec,0x00000000}},	//   _ouar, _туга_, _мызд, --, 
   {{0x7528b09d,0xafe40212,0x00000000,0x00000000}},	//   _igez, зопл, --, --, 
   {{0x7c240455,0x09b807f7,0xe0d40006,0x2f5400d1}},	//   _nihr, _इक्य, явы_, чтис, 
   {{0x7e680280,0x3868b09e,0x7c2c6704,0x2b580129}},	//   gudp, huar_, _auar, _rdpc_, 
   {{0x3868069c,0x3eb8049f,0x7c2cb09f,0x41740a11}},	//   kuar_, ärta_, _buar, _يانس, 
   {{0x7c2cb0a0,0x3868044e,0x7dcc045f,0xd6c004c5}},	//   _cuar, juar_, _bûsb, ্পিয, 
   {{0x7c2cb0a1,0x386802d3,0xad2408c9,0x7f480137}},	//   _duar, duar_, تىڭى, _ۇلۇق_, 
   {{0x7c2c0561,0x752812c5,0xf3ec0154,0x00000000}},	//   _euar, _ogez, _ওঠার_, --, 
   {{0x75288cdb,0x4890044e,0x7c2cb0a2,0x316cb0a3}},	//   _ngez, _ብርግጽ_, _fuar, ngez_, 
   {{0xbb28040d,0x7c2cb0a4,0x7c2403f9,0x38682b9d}},	// [e260] ﻤﻪﻥ_, _guar, _fihr, guar_, 
   {{0xab64b0a5,0x75289390,0xdc98b0a6,0x31b00306}},	//   _эвол, _agez, _פסיכ, _vázy_, 
   {{0x7528014b,0xdee80125,0xa9a40124,0x9bb8011a}},	//   _bgez, _መካነ_, _еинд, _הציפ, 
   {{0x3868b0a7,0x316c0399,0x7c2c0139,0x00000000}},	//   buar_, jgez_, _yuar, --, 
   {{0x614000d2,0x2a686afa,0x4394b0a8,0xd46400a8}},	//   _lílâ, lubb_, далс, зиче_, 
   {{0x7528b0a9,0xdb0401a8,0x14840131,0x00000000}},	//   _egez, rkjö, سپىي_, --, 
   {{0xdb0401a8,0x00000000,0x00000000,0x00000000}},	//   skjö, --, --, --, 
   {{0x7e68b0aa,0x00000000,0x00000000,0x00000000}},	//   vudp, --, --, --, 
   {{0xe3b80108,0x00000000,0x00000000,0x00000000}},	//   _лба_, --, --, --, 
   {{0x7c2cb0ab,0x00000000,0x00000000,0x00000000}},	//   _ruar, --, --, --, 
   {{0x3868069c,0x7c2cb0ac,0x00000000,0x00000000}},	//   zuar_, _suar, --, --, 
   {{0x7c2cb0ad,0x7c242a6d,0x63b8084c,0x38680198}},	//   _puar, _sihr, _hotn, yuar_, 
   {{0x7c2cb0ae,0x3868044e,0x63b86185,0x80d40883}},	//   _quar, xuar_, _kotn, _बेचे, 
   {{0x38687370,0x7e680280,0x63b8b0af,0x23bc00cd}},	//   vuar_, pudp, _jotn, ्सिद, 
   {{0x63b80fb7,0x7c2402f6,0x7c2c0221,0x2a6801e3}},	//   _motn, _vihr, _wuar, gubb_, 
   {{0x3868067d,0x7c2cb0b0,0x63b8b0b1,0xdb1400e8}},	//   tuar_, _tuar, _lotn, _joxé, 
   {{0x63b8b0b2,0x7c2cb0b3,0xfe780024,0xdcfc0166}},	// [e270] _ootn, _uuar, ltį_, _toqı, 
   {{0x3868067d,0xd7d8019b,0xb90413f7,0x8be800cf}},	//   ruar_, _spモ_, _भइ_, _ىىيق_, 
   {{0x3868b0b4,0xfe7802d5,0x463c001f,0xc7b8b0b5}},	//   suar_, ntį_, _ይነገራ, чёт_, 
   {{0x28dc47d0,0xfe780006,0x38680023,0x99645f0f}},	//   _नेवि, itį_, puar_, _этол, 
   {{0x63b89428,0x3868b0b6,0x95c800d1,0x00000000}},	//   _botn, quar_, _ғува_, --, 
   {{0xfe7802d5,0x63b8b0b7,0xdbd40158,0xdee80092}},	//   ktį_, _cotn, bøås, _መጫን_, 
   {{0x3d2400b0,0xf1a80034,0xd5b806b4,0x00000000}},	//   _hīwī_, कालन, _лса_, --, 
   {{0x7528015c,0x3d2406c8,0xa804083c,0xcb1400df}},	//   _ugez, _kīwī_, rpış, עלק_, 
   {{0x93243e86,0xccf40134,0x63b8b0b8,0x316c20ef}},	//   _فران, _adɛn_, _fotn, rgez_, 
   {{0x6004b0b9,0x63b802d2,0x75f8008e,0x92680798}},	//   мным_, _gotn, _wäzğ, _грда_, 
   {{0xaf080b73,0xfe780153,0x00000000,0x00000000}},	//   تقدم_, gtį_, --, --, 
   {{0x63b885d7,0xfbc802e4,0x00000000,0x00000000}},	//   _zotn, _דת_, --, --, 
   {{0x63b80455,0x00000000,0x00000000,0x00000000}},	//   _yotn, --, --, --, 
   {{0xd01807d8,0x70c84c5b,0x2c7401bf,0x00000000}},	//   _уфе_, िनील, ræd_, --, 
   {{0xb06009a5,0x6994b0ba,0x2c7401bf,0x00000000}},	//   _şähe, мрах, sæd_, --, 
   {{0x2a681600,0x00000000,0x00000000,0x00000000}},	//   rubb_, --, --, --, 
   {{0xeb981248,0x3dd80af9,0x00000000,0x00000000}},	// [e280] _дип_, ërwe_, --, --, 
   {{0xee600240,0x00000000,0x00000000,0x00000000}},	//   _ተሰንዩ_, --, --, --, 
   {{0x7dcc002d,0xb9040037,0x5a6000db,0xc69000f1}},	//   _hûsa, _भे_, _икэб, دېز_, 
   {{0x80d4015b,0xe9900046,0x63b8b0bb,0x00000000}},	//   দপত্, _جۇرگ, _sotn, --, 
   {{0x63b8151c,0x6d442a1f,0x9470b0bc,0xe76800ae}},	//   _potn, ibka, ندوا, _وحسن_, 
   {{0x9cd402e4,0x63b86735,0x00000000,0x00000000}},	//   וונה_, _qotn, --, --, 
   {{0xf1a80574,0x6fb001ad,0xe3c000cc,0x02a82e04}},	//   कांन, जानं, ্চলব, कमेन, 
   {{0x628c006a,0xa3c80d2e,0x00000000,0x00000000}},	//   _âbom, _ऊतक_, --, --, 
   {{0x7988002e,0x63b8b0bd,0xe4b00133,0x00000000}},	//   _ñewe, _totn, _جڤاک, --, 
   {{0x6440b0be,0x81bc00b0,0x33d40064,0x00000000}},	//   mpoi, _auēt, _піхт, --, 
   {{0x6440b0bf,0xd7d8019b,0x9f5c036e,0x00000000}},	//   lpoi, _jpメ_, lotë_, --, 
   {{0xfe7802d5,0x64400b23,0xb7d40241,0x00000000}},	//   rtį_, opoi, _iṣej, --, 
   {{0x5c0406bb,0x6440b0c0,0xfe780006,0x9f5c0240}},	//   дява, npoi, stį_, notë_, 
   {{0x644004c9,0x2018b0c1,0x6d440009,0xfe780153}},	//   ipoi, _òpi_, abka, ptį_, 
   {{0x6d44b0c2,0x64400175,0x8ae40212,0x00000000}},	//   bbka, hpoi, вітл, --, 
   {{0x3e7800dd,0x3f8cb0c3,0x644003ac,0x3eb80174}},	//   mét_, ledu_, kpoi, ørtu_, 
   {{0xb8141614,0x3e785b53,0xc4c401ed,0x7b8402dd}},	// [e290] едај, lét_, _ئے_, _كادە, 
   {{0x3f8cb0c4,0x6fcc00d2,0xd764005e,0xbd6803e6}},	//   nedu_, _kúca, بەسى_, _بڕگه_, 
   {{0x3d2404fe,0x3e78b0c5,0x644000d7,0x00000000}},	//   _wīwī_, nét_, epoi, --, 
   {{0x3f8c209c,0xc0c00092,0x00000000,0x00000000}},	//   hedu_, _ድግስ_, --, --, 
   {{0xb7d401e1,0x629c003a,0x3f8c0009,0x798c0b84}},	//   _aṣej, æpon, kedu_, meaw, 
   {{0x3f8cb0c6,0xdb040054,0x798c18a6,0x3e78b0c7}},	//   jedu_, pjjä, leaw, két_, 
   {{0x3f8cb0c8,0x3e7800dd,0x668004d3,0x9f5c02e2}},	//   dedu_, jét_, _میلل, motè_, 
   {{0x69d8004a,0x9f5cb0c9,0x798c02d0,0x3e78b0ca}},	//   étex, lotè_, neaw, dét_, 
   {{0xd378036b,0x3f8c015d,0x6d4402d0,0x6440b0cb}},	//   _мчж_, fedu_, vbka, cpoi, 
   {{0x3e7891f8,0x798c02b1,0x6fcc0332,0x9f5c033b}},	//   fét_, heaw, _búca, notè_, 
   {{0x3e7800dd,0x6fcc01e7,0x798c50eb,0x00000000}},	//   gét_, _cúca, keaw, --, 
   {{0x3f8c000d,0x00000000,0x00000000,0x00000000}},	//   aedu_, --, --, --, 
   {{0x2d9c0316,0x3f8cb0cc,0x707400c8,0xab2801b9}},	//   ěte_, bedu_, _נײַע_, зога_, 
   {{0x3e78b0cd,0x3f8c6c4b,0x6ab8002f,0x00000000}},	//   bét_, cedu_, ätfo, --, 
   {{0x3e78aeae,0x9f5c0100,0x25f010eb,0x00000000}},	//   cét_, dotè_, ंचमी_, --, 
   {{0x644004fb,0x6924b0ce,0xf4140154,0x00000000}},	//   ypoi, емба, াদির_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [e2a0] --, --, --, --, 
   {{0x06c403d4,0x64400175,0x59bc0118,0x78a8013a}},	//   _এইবি, vpoi, _एकअर, _ševc, 
   {{0x6fcc0077,0xf414015b,0x798c0175,0x644072c6}},	//   _xúca, াদার_, beaw, wpoi, 
   {{0x6440b0cf,0x96f401ed,0x673400e2,0x6ab80158}},	//   tpoi, رٹنر_, _šajā, øtfu, 
   {{0x5f0401d9,0x3f8cb0d0,0x9f5c007f,0x3e7801d3}},	//   _सुन्_, yedu_, botè_, zét_, 
   {{0xa6c80724,0x3e7801ed,0xc0d4001f,0x281402dd}},	//   _елга_, yét_, ይነህ_, _سوزس, 
   {{0x644036ed,0xb5d80241,0x3f98003a,0x00000000}},	//   spoi, _kẹ̀s, ôrum_, --, 
   {{0x9f5cb0d1,0x3e7801ed,0x6440b0d2,0x3398001f}},	//   moté_, vét_, ppoi, መሠረተ_, 
   {{0x3f8c07f5,0x6600b0d3,0x9f5c06af,0x3e782cc3}},	//   tedu_, mook, loté_, wét_, 
   {{0x6600b0d4,0xdef8b0d5,0x3e7800dd,0xf1a8012c}},	//   look, зым_, tét_, काउन, 
   {{0x3f8cb0d6,0x3568010a,0x00000000,0x00000000}},	//   redu_, _арĕн_, --, --, 
   {{0x6600b0d7,0x3e78b0d8,0x00000000,0x00000000}},	//   nook, rét_, --, --, 
   {{0x61e0b0d9,0x3f8cb0da,0x3e7800dd,0x7a3001e4}},	//   _imol, pedu_, sét_, _iĥti, 
   {{0x6600b0db,0xdef8088b,0x9f5c0066,0x798c02b5}},	//   hook, _ный_, koté_, weaw, 
   {{0x61e00270,0x5fa40da3,0x798cb0dc,0x9e04004e}},	//   _kmol, _कोयल, teaw, _пчил, 
   {{0x660000af,0xca480592,0x9f5c0100,0x201c0327}},	//   jook, علقه_, wotè_, lmti_, 
   {{0x61e0b0dd,0xd8740137,0x8dfc0375,0x77980137}},	// [e2b0] _mmol, عارب, _מההת, мкар_, 
   {{0x61e001e1,0x5fa42802,0x00000000,0x00000000}},	//   _lmol, _कोमल, --, --, 
   {{0x61e0b0de,0x66000bd7,0xf70800c2,0x201c0006}},	//   _omol, fook, ффақ_, imti_, 
   {{0x6600b0df,0x201c0327,0x69d80100,0x00000000}},	//   gook, hmti_, ètet, --, 
   {{0xdb140139,0x3d140073,0x9f5c007f,0x00000000}},	//   _moxí, नेचे_, potè_, --, 
   {{0x61e0b0e0,0x3948b0e1,0x386848bb,0xdb14056a}},	//   _amol, lbas_, mrar_, _loxí, 
   {{0xe2940801,0x61e00393,0x9f5ca62b,0x00000000}},	//   ващ_, _bmol, coté_, --, 
   {{0x6600b0e2,0xd3d8036b,0x61e001a6,0xd9bc000d}},	//   cook, _کبرا_, _cmol, _एकोट, 
   {{0x386863ac,0x13e44acd,0x45d4448f,0xd7d800b5}},	//   nrar_, _كورۋ_, _сотс, _avド_, 
   {{0xee383533,0x764498a6,0x3868b0e3,0x00000000}},	//   мно_, ophy, irar_, --, 
   {{0x3868b0e4,0xef180816,0xcdc400c7,0x7644002f}},	//   hrar_, ьмо_, ганқ, nphy, 
   {{0x3868b0e5,0xdb140077,0xbf700588,0x7bc0b0e6}},	//   krar_, _coxí, ақәы, ölun, 
   {{0x320cb0e7,0x3948b0e8,0x3868b0e9,0x7e68b0ea}},	//   mley_, dbas_, jrar_, ardp, 
   {{0x38682b27,0x3948b0eb,0x320cb0ec,0x06d8009e}},	//   drar_, ebas_, lley_, থপতি, 
   {{0x3868b0ed,0x6b8c00ca,0x6600b0ee,0xddd801e4}},	//   erar_, rebg, yook, lutŝ, 
   {{0x320cb0ef,0x6fcc0af2,0x39480004,0x6b8c02ea}},	//   nley_, _kúco, gbas_, sebg, 
   {{0x66000841,0x320c00ad,0xa8040354,0x9ce400e5}},	// [e2c0] vook, iley_, взал, _لوٹے_, 
   {{0x320cb0f0,0x7bd40730,0x6600b0f1,0x2d8003e2}},	//   hley_, chzu, wook, lfke_, 
   {{0x3948b0f2,0xe5784077,0x6600b0f3,0x320cb0f4}},	//   bbas_, дзе_, took, kley_, 
   {{0xaa84010e,0x320c0076,0x9f5c0129,0x00000000}},	//   _ezýä, jley_, roté_, --, 
   {{0x320cb0f5,0x3868b0f6,0x69d4013f,0x7988002e}},	//   dley_, crar_, mhye, _ñewa, 
   {{0x66002f99,0x320c0363,0x9f5cb0f7,0x00000000}},	//   sook, eley_, poté_, --, 
   {{0x66e4b0f8,0x7dcc002d,0x660004b6,0xa3dc1f13}},	//   _рова, _bûsl, pook, दोष_, 
   {{0x69d43ba0,0x320cb0f9,0x64a400c7,0xa1842b95}},	//   nhye, gley_, _иаба, тыкл, 
   {{0xdb140005,0xd1b4007b,0xe3f801ec,0x9f5c0108}},	//   _roxí, ضايا_, _قىرت_, yltä_, 
   {{0x1fa4b0fa,0x2054b0fb,0xd9bc4103,0x2d80000f}},	//   триг, нтүр, _एक्ट, efke_, 
   {{0x320cb0fc,0x442cb0fd,0x61e000ee,0x39480024}},	//   bley_, _iid_, _tmol, ybas_, 
   {{0x3868b0fe,0x61e0b0ff,0x320c13b0,0x69d4037e}},	//   yrar_, _umol, cley_, jhye, 
   {{0x4cb8468d,0x442c011a,0xee9403e6,0x2054b100}},	//   вляю_, _kid_, ندێک, _ртер, 
   {{0x3868b101,0x442cb102,0x1b60044e,0xd138044e}},	//   vrar_, _jid_, _ፈስቲቫ, _ተሳተፍ, 
   {{0x442cb103,0x7dcc002d,0xdeb001ec,0xdb140419}},	//   _mid_, _hûsm, _тұны, _toxí, 
   {{0x442cb104,0x3f9c010f,0x3948b105,0x5cc401f0}},	//   _lid_, _havu_, ubas_, _асоз, 
   {{0x442cb106,0x3948b107,0x3f9cb108,0x3868b109}},	// [e2d0] _oid_, rbas_, _kavu_, urar_, 
   {{0x6fcc2137,0x442cb10a,0x39484cd3,0x7d0cb10b}},	//   _núcl, _nid_, sbas_, _iyas, 
   {{0x320cb10c,0x3f9c650b,0x7d0c00cd,0x69d400cd}},	//   yley_, _mavu_, _hyas, bhye, 
   {{0x7644b10d,0x3868b10e,0x3f9cb10f,0x320cb110}},	//   rphy, prar_, _lavu_, xley_, 
   {{0x442cb111,0x225c005a,0x799c02d0,0x6fcc0332}},	//   _bid_, _avtk_, _iasw, _búcl, 
   {{0x442cb112,0x320cb113,0x7d0cb114,0x799cb115}},	//   _cid_, wley_, _myas, _hasw, 
   {{0x36d4b116,0x7d0cb117,0x442c0c3e,0x2d80000f}},	//   _совр, _lyas, _did_, yfke_, 
   {{0x442cb118,0x7d0cb119,0x2c1800af,0x799c0165}},	//   _eid_, _oyas, _मीनू_, _jasw, 
   {{0x442cb11a,0x7d0cb11b,0x320c410f,0xf3f80063}},	//   _fid_, _nyas, rley_, _знаш_, 
   {{0x320cb11c,0x442cb11d,0x3f9c0481,0x799cb11e}},	//   sley_, _gid_, _cavu_, _lasw, 
   {{0x7d0cb11f,0xd1d8044e,0x9f5000bc,0x3f9cb120}},	//   _ayas, _ሕዝቢ_, ádám_, _davu_, 
   {{0x799c0c11,0x7d0cb121,0x3074487f,0x320c058a}},	//   _nasw, _byas, _букс, qley_, 
   {{0x7d0c0796,0xd13802d3,0x442cb122,0x2b48037e}},	//   _cyas, _ተሳታፍ, _yid_, tbbc_, 
   {{0x799c04ba,0x7d0c02bd,0x442c9003,0xf31c1954}},	//   _aasw, _dyas, _xid_, _ትሕትና, 
   {{0x799cb123,0x09cc00bd,0x69d4b124,0x7d0cb125}},	//   _basw, রোফা, thye, _eyas, 
   {{0x09cc00bd,0x799c0142,0xf9d40006,0xc9440150}},	//   রোনা, _casw, ацую, рдақ, 
   {{0x18643048,0x3f9c23e0,0x799c047e,0x7d0c1418}},	// [e2e0] лати_, _yavu_, _dasw, _gyas, 
   {{0xd1d80201,0x69d40796,0x6d54b126,0x2c50007f}},	//   _ሕዝብ_, shye, _heya, mņd_, 
   {{0x799cb127,0x5b7802e4,0x69d4009a,0xe5a42826}},	//   _fasw, _אריא, phye, лижи, 
   {{0x799c4fa5,0x6d54a869,0xc7941669,0x6b9c010e}},	//   _gasw, _jeya, ырғы, _hapg, 
   {{0x100010f7,0x442cb128,0x6d54b129,0x7dcc002d}},	//   रकाश_, _pid_, _meya, _bûsj, 
   {{0x6d54b12a,0xa3dc068f,0x442cb12b,0x95940022}},	//   _leya, दों_, _qid_, втәу_, 
   {{0x442cb12c,0x22840323,0xf3649e08,0x73480212}},	//   _vid_, уулг, ртін, тчів_, 
   {{0x3f9c0029,0x442c4f7f,0x799c00e8,0xdd1c0419}},	//   _savu_, _wid_, _xasw, _líšk, 
   {{0x3e3c0023,0xa5f80150,0x00000000,0x00000000}},	//   _ከተካይ, _жеңу_, --, --, 
   {{0x987804ac,0x7d0c015c,0x442cb12d,0x2c50007f}},	//   עריק, _ryas, _uid_, dņd_, 
   {{0x6d54b12e,0x7d0c1529,0x3df465cf,0x3f9c0270}},	//   _beya, _syas, изос, _vavu_, 
   {{0x6298b12f,0x3f9cb130,0xd24c03e6,0x3014b131}},	//   _isto, _wavu_, _رنه_, лдөр, 
   {{0x9cc8b132,0x6d54b133,0x7dcc000f,0x3f9cb134}},	//   хына_, _deya, _hûsk, _tavu_, 
   {{0x7d0c1802,0x6b9cb135,0x799cb136,0x6298b137}},	//   _vyas, _capg, _sasw, _ksto, 
   {{0x799cb138,0x6298b139,0x6d54b13a,0x7d0c7dec}},	//   _pasw, _jsto, _feya, _wyas, 
   {{0x7d0cb13b,0x6298090c,0x6d54102c,0x7dcc002d}},	//   _tyas, _msto, _geya, _mûsk, 
   {{0x6b9c0369,0x7d0c136f,0x17680b8d,0x799cb13c}},	// [e2f0] _fapg, _uyas, ереп_, _vasw, 
   {{0x799cb13d,0x6298b13e,0x6d5418cb,0x6b9c7e8b}},	//   _wasw, _osto, _zeya, _gapg, 
   {{0x799cb13f,0x6d54b140,0x6f680023,0xab040139}},	//   _tasw, _yeya, _ተበጊሰ_, _ırçı_, 
   {{0x6d5403e3,0x00000000,0x00000000,0x00000000}},	//   _xeya, --, --, --, 
   {{0x1ca80156,0x6298b141,0x00000000,0x00000000}},	//   བའི_, _asto, --, --, 
   {{0xb7d40241,0x9f5c02f0,0x84242d40,0xb78800fb}},	//   _iṣoj, fotí_, مىنن, _шәбе_, 
   {{0xb594014b,0x32440150,0x00000000,0x00000000}},	//   _кивш, шейг, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d540d29,0x6298b142,0x5fa425fe,0x6f680240}},	//   _reya, _esto, _कोहल, _ተበገሰ_, 
   {{0x6298b143,0xafe4b144,0x7dcc002d,0x6d54b145}},	//   _fsto, роол, _hûsh, _seya, 
   {{0x72b8286d,0x71780798,0x00000000,0x00000000}},	//   _جهاز_, _абер_, --, --, 
   {{0x6b9c05d5,0xefcc02d3,0x6d540175,0xc2c415f2}},	//   _sapg, ብናዮ_, _qeya, _ديمي, 
   {{0x6d54b146,0x321c01ab,0x6b9c0af9,0xb3980023}},	//   _veya, _ihwy_, _papg, መጠይቕ_, 
   {{0x62980cfd,0x6d54b147,0x00000000,0x00000000}},	//   _ysto, _weya, --, --, 
   {{0x6d54b148,0xdee0016c,0xb7d40ca8,0x0e0400ee}},	//   _teya, _моши, _aṣoj, _гүно, 
   {{0x6b9c0208,0xab8000db,0x00000000,0x00000000}},	//   _wapg, حۇگۉ, --, --, 
   {{0x68381d56,0xe7380598,0x6b9c0209,0x98a0b149}},	// [e300] тябр_, вез_, _tapg, оите, 
   {{0x3cf00122,0x3c4400ae,0x47c801e2,0x00000000}},	//   šová_, _اضيف, دارۍ_, --, 
   {{0x321c0175,0x56900212,0x69f8010a,0x00000000}},	//   _ohwy_, жаєт, _аннă, --, 
   {{0xe9a41d4a,0xa3dc0034,0x6298107d,0x963001ce}},	//   _тамп, दोई_, _rsto, ініц, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc5f0021a,0x00000000,0x00000000,0x00000000}},	//   _کړئ_, --, --, --, 
   {{0xd25402d5,0x3528515c,0x93c801d3,0xe57800f3}},	//   ацы_, نسۇپ_, خانہ_, _изв_, 
   {{0x6298140b,0x9f5c00e4,0xe61800f3,0x00000000}},	//   _vsto, rotí_, _рдб_, --, 
   {{0xdfd806bb,0x80b049fc,0x29cc010b,0x528000d1}},	//   вън_, जमें, _aýak_, ملۈك, 
   {{0x9f5c0270,0xa2e40137,0x00000000,0x00000000}},	//   potí_, _козд, --, --, 
   {{0x6298b14a,0x7e880134,0x6fcc00ae,0xd734011a}},	//   _usto, _bɛpa, _múch, יטית_, 
   {{0x5fa40073,0x6fcc48f4,0x69d80036,0xf2c001c6}},	//   _कोरल, _lúch, ëtel, _хөши, 
   {{0x9f5c0589,0x00000000,0x00000000,0x00000000}},	//   gotã_, --, --, --, 
   {{0xf53800d7,0x00000000,0x00000000,0x00000000}},	//   _maťa_, --, --, --, 
   {{0x4f840583,0xf31c0b82,0x8aa401a9,0xdb2015b4}},	//   _خانہ, _ትንተና, ортд, زوری, 
   {{0x79c81063,0x00000000,0x00000000,0x00000000}},	//   دورف_, --, --, --, 
   {{0x6fcc2d95,0x00000000,0x00000000,0x00000000}},	// [e310] _búch, --, --, --, 
   {{0x7f58014f,0x9f5c0109,0xfc1400a8,0x6fcc0332}},	//   _jevq, notà_, _ымпэ, _cúch, 
   {{0x7bc40421,0x6fcc00c6,0x7f580455,0xdd1c00bc}},	//   _iohu, _dúch, _mevq, vířo, 
   {{0x7bc404fe,0xf5380306,0x956402e8,0x69cc01f9}},	//   _hohu, _baťa_, ръжд, _सवयी, 
   {{0x7bc4b14b,0x3958b14c,0x321c0142,0xdb1406be}},	//   _kohu, _iess_, _rhwy_, _boxç, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7bc4b14d,0x9f5c0395,0x3958007f,0x321c03cb}},	//   _mohu, dotà_, _kess_, _phwy_, 
   {{0x3958b14e,0x7bc4b14f,0xf4340064,0x00000000}},	//   _jess_, _lohu, _геаэ, --, 
   {{0x3958b150,0x04c800f1,0x63b00118,0xd37800db}},	//   _mess_, _پولي_, ádní, _аче_, 
   {{0x3958b151,0x9268b152,0x9f5cb153,0xaf98b154}},	//   _less_, _арда_, gotà_, утих_, 
   {{0xed58b155,0x6da4016c,0xada43500,0x41c401d9}},	//   лон_, бина, банл, _ڈٲلِ, 
   {{0xfbc83d99,0x39583d19,0x7bc400b0,0x41c401d9}},	//   _את_, _ness_, _aohu, _وٲلِ, 
   {{0x6fcc3c50,0x7bc4b156,0xc0d002d3,0x260c00a2}},	//   _lúci, _bohu, ብባር_, mýot_, 
   {{0xac08ae94,0x7bc4b157,0x260c010e,0xe9a40022}},	//   унга_, _cohu, lýot_, әаап, 
   {{0x39581bce,0x15f405d7,0xa968a9f8,0x91d86bf6}},	//   _bess_, ंचार_, лива_, _बताई, 
   {{0x395800a2,0x6fcc0332,0x9f5c02f0,0x00000000}},	//   _cess_, _súch, motá_, --, 
   {{0x3958b158,0x6c840597,0x6fcc0030,0x7f58834a}},	// [e320] _dess_, _الخم, _púch, _yevq, 
   {{0x76540369,0x3958022f,0x66d8b159,0xeb98b15a}},	//   _bwzy, _eess_, льер_, _сио_, 
   {{0x76540369,0x3958b15b,0x7d080327,0x00000000}},	//   _cwzy, _fess_, żest, --, 
   {{0x7bc40117,0x3958b15c,0x00000000,0x00000000}},	//   _zohu, _gess_, --, --, 
   {{0x69c40069,0x6fcc002d,0x18b0151e,0xf438004b}},	//   _ioke, _túch, _нәфр, لينډ_, 
   {{0x9f5c02ea,0x39580077,0x00000000,0x00000000}},	//   kotá_, _zess_, --, --, 
   {{0x69c4b15d,0xe5a47826,0xf6d402bf,0x00000000}},	//   _koke, _ливи, _дітя, --, 
   {{0x6fcc00d2,0x69c4b15e,0x7f5806be,0x925400f2}},	//   _kúcw, _joke, _sevq, حشور_, 
   {{0x69c4b15f,0x00000000,0x00000000,0x00000000}},	//   _moke, --, --, --, 
   {{0x69c4b160,0x78a805be,0x00000000,0x00000000}},	//   _loke, _ševk, --, --, 
   {{0x66f80b26,0x9f5cb161,0x69c4b162,0xd36c00c6}},	//   ्थिक_, gotá_, _ooke, _أهم_, 
   {{0x69c4b163,0x7bc4b164,0x108000d1,0xa8040139}},	//   _noke, _sohu, _ﻫﻪﺩﯨ, lqığ, 
   {{0x2b58b165,0x7bc4b166,0xf1a8b167,0xa5400092}},	//   _bepc_, _pohu, _خاله_, _ይጠናቀ, 
   {{0x3958b168,0x8fa003a6,0x69c402b5,0x3eb82ba9}},	//   _sess_, _наче, _aoke, ärts_, 
   {{0x9964b169,0x69c4b16a,0x7bc4b16b,0x39580327}},	//   йтал, _boke, _vohu, _pess_, 
   {{0x69c425a9,0x7bc4b16c,0x9a840032,0x8e44007b}},	//   _coke, _wohu, _һумл, _اليك_, 
   {{0x7bc4b16d,0x3958b16e,0xcc88027d,0x6fcc0419}},	// [e330] _tohu, _vess_, _هنيه_, _súci, 
   {{0xd6d8b16f,0x39580221,0x00000000,0x00000000}},	//   лте_, _wess_, --, --, 
   {{0x3958b170,0x69c4b171,0x95c8026f,0x00000000}},	//   _tess_, _foke, луда_, --, 
   {{0x69c4b172,0xd5680212,0xbb84009f,0x00000000}},	//   _goke, рiал, _الھي, --, 
   {{0xd7f810f5,0x44640006,0x00000000,0x00000000}},	//   _був_, звів, --, --, 
   {{0x69c4b173,0x00000000,0x00000000,0x00000000}},	//   _zoke, --, --, --, 
   {{0x65780491,0x69c4b174,0xd6c04d20,0x5fa410fa}},	//   úchá, _yoke, _عمری, _कोइल, 
   {{0x108000d1,0x69c40139,0xe8a00092,0x00000000}},	//   _ﻫﻪﺭﯨ, _xoke, ፈልጉም_, --, 
   {{0x0fe45894,0x2fe801a9,0xa1540114,0x7f440166}},	//   йлиқ_, аtgа_, цању_, _şiqa, 
   {{0xaab82efd,0x622000b8,0x60c40254,0x00000000}},	//   _उपलक, _vṛṣo_, äkma, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2b5800db,0xd20400db,0xf5380419,0xf8d800dc}},	//   _sepc_, _ابئى, _maťo_, णनाय, 
   {{0x94b40490,0xd24c00e5,0xc0a8009f,0xa8040139}},	//   _आपोआ, _آنچ_, _هاول_, lqış, 
   {{0x69c4b175,0x00000000,0x00000000,0x00000000}},	//   _soke, --, --, --, 
   {{0xab28b176,0x69c4b177,0x4ea400f7,0xe95800a7}},	//   рова_, _poke, _ырда, иращ_, 
   {{0x69c40472,0xdd1c0118,0x00000000,0x00000000}},	//   _qoke, _síťk, --, --, 
   {{0xad240b24,0x00000000,0x00000000,0x00000000}},	// [e340] _برغو, --, --, --, 
   {{0x69c41028,0x00000000,0x00000000,0x00000000}},	//   _woke, --, --, --, 
   {{0x7c940020,0x69c4b178,0x9bb405d0,0x1dac6d65}},	//   ያደርግ_, _toke, _והיה_, _जोडत, 
   {{0xe8a0001f,0x75880212,0x69c40139,0x00000000}},	//   ፈልግም_, йсів_, _uoke, --, 
   {{0x27e80789,0x260c00a2,0x00000000,0x00000000}},	//   _tmbn_, fýor_, --, --, 
   {{0x66e4b179,0x6fcc00d2,0x00000000,0x00000000}},	//   _дога, _kúcu, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc1b8b17a,0xa088013e,0x78a80e04,0x00000000}},	//   слих_, асоз_, _ševi, --, 
   {{0xd1cc0092,0x00000000,0x00000000,0x00000000}},	//   ብዳቤ_, --, --, --, 
   {{0x629c0393,0x00000000,0x00000000,0x00000000}},	//   æpos, --, --, --, 
   {{0x25a400a9,0x00000000,0x00000000,0x00000000}},	//   odol_, --, --, --, 
   {{0x2484b17b,0xd0e80490,0x923000d1,0x712405af}},	//   otom_, _जेवण_, _قىلش, _کرمل, 
   {{0x24849a69,0x25a40042,0x00000000,0x00000000}},	//   ntom_, idol_, --, --, 
   {{0xa03402d3,0x24840c5c,0x8fa0009b,0x00000000}},	//   _ኣሰናዳ, itom_, _жаље, --, 
   {{0x25a40280,0x6fcc00eb,0xce640022,0xcb3400a7}},	//   kdol_, _cúcu, _дрыд_, деръ, 
   {{0x2484181f,0x00000000,0x00000000,0x00000000}},	//   ktom_, --, --, --, 
   {{0x25a4b17c,0xb17c0306,0x24840aa6,0x70640092}},	// [e350] ddol_, ciťu, jtom_, _ግዴታቸ, 
   {{0x25a401f1,0xd77402de,0xda780139,0xdb788087}},	//   edol_, تارع, _кям_, _өсүш_, 
   {{0x7dcc000f,0x80ac05f9,0x291c00df,0x24840332}},	//   _fûst, जिडे, _ŝtat_, etom_, 
   {{0xd1cc069c,0x248416a3,0x7bd401f5,0x6ab805ac}},	//   ብታት_, ftom_, lkzu, åtfe, 
   {{0x3a280194,0xd77400c6,0xd4980354,0x00000000}},	//   mmap_, _واسع, рре_, --, 
   {{0x25a40368,0xb9f002d3,0x938801d5,0xf2a400db}},	//   adol_, _ጓሳ_, рсда_, зикп, 
   {{0x2484b17d,0x7bd4013a,0x00000000,0x00000000}},	//   atom_, ikzu, --, --, 
   {{0x24840070,0x00000000,0x00000000,0x00000000}},	//   btom_, --, --, --, 
   {{0x4dc40729,0x69d82ad4,0xf8bc0307,0x00000000}},	//   শসমূ, ëtei, ोहिय, --, 
   {{0x60e4005b,0x602001ec,0x00000000,0x00000000}},	//   ямым_, ндыа, --, --, 
   {{0x6da4b17e,0x3a280784,0x9f4801ed,0x7988002e}},	//   пина, kmap_, émák_, _ñeww, 
   {{0x6da401b9,0x6fccb17f,0x24a80153,0xada401d5}},	//   чима, _rúcu, žumų_, чамл, 
   {{0x621805e1,0x4174168d,0xb12801d9,0x3a28b180}},	//   _פונק, _زانس, _آشن_, dmap_, 
   {{0x320c0036,0x3a28b181,0x00000000,0x00000000}},	//   loey_, emap_, --, --, 
   {{0x25a4910d,0x7dcc002d,0xa6e40174,0xed580563}},	//   ydol_, _pûst, _miðø, _лой_, 
   {{0x66e000d2,0x684406ed,0x24843ba3,0x3a280477}},	//   _líké, знаа, ytom_, gmap_, 
   {{0x2484b182,0xefe40092,0xdcac00db,0x6d44035a}},	// [e360] xtom_, ምጠው_, _مىي_, mcka, 
   {{0x7bd403fa,0x29cc010b,0x3a280175,0x6d44062c}},	//   ckzu, _aýat_, amap_, lcka, 
   {{0x91d83d60,0x6e340166,0x25a40042,0xf41000fe}},	//   बसाई, _kiyb, tdol_, াষাৰ_, 
   {{0xe610005e,0x6d442e22,0x2484b183,0x6e3401a9}},	//   رشا_, ncka, ttom_, _jiyb, 
   {{0xc4488375,0x8884b184,0x78a80b4b,0x69d4013f}},	//   زیان_, _زیان, _ševv, mkye, 
   {{0x9d18008f,0xa7d8065f,0x54940006,0x00000000}},	//   זונט, _اوسط_, явіў_, --, 
   {{0x5330b185,0x69d40083,0xb4e0002e,0x27f40118}},	//   нешт, okye, _ñàng, čeně_, 
   {{0x69d4013b,0xb30800d1,0xa0240108,0x00740150}},	//   nkye, ڭغۇل_, kköö, _ﺳﻪﺭﭘ, 
   {{0x63046c71,0x656002b5,0x00000000,0x00000000}},	//   _کوال, maoh, --, --, 
   {{0x6560b186,0x6d44062c,0xd84002f0,0x00000000}},	//   laoh, ecka, lačí_, --, 
   {{0xa11404d3,0x7a040153,0x00000000,0x00000000}},	//   _کوشت, lėte, --, --, 
   {{0xf1a8168d,0x656000ec,0x9c8402fd,0x6fcc01d3}},	//   _وانه_, naoh, _načí, _búcs, 
   {{0x6e3401ab,0x3a280175,0x31e41867,0x6440022e}},	//   _diyb, vmap_, _تسلّ, nqoi, 
   {{0x6560b187,0xfa601b49,0x3a28b188,0x69d41418}},	//   haoh, _ገብረማ, wmap_, ekye, 
   {{0x3a28b189,0x6560b18a,0x8fa00114,0x00000000}},	//   tmap_, kaoh, _чаје, --, 
   {{0x64bc0490,0x6e340718,0x65600e03,0x8b04012d}},	//   ्हाळ, _giyb, jaoh, _łęcz, 
   {{0x6560b18b,0x00000000,0x00000000,0x00000000}},	// [e370] daoh, --, --, --, 
   {{0x320c0b6f,0x69d40083,0xba980212,0x6fcc01e7}},	//   zoey_, akye, _двоє_, _húcr, 
   {{0x3a2801e1,0x656005da,0xdcfc0166,0x6b8801a8}},	//   pmap_, faoh, _inqı, _öfga, 
   {{0x66e000d2,0x6b7c033f,0x00000000,0x00000000}},	//   _síké, rągł, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9c84031d,0x78ac004b,0x980401c0,0x836400d1}},	//   _začí, mvav, _хямд, ىدىل, 
   {{0x78ac00af,0x6d4401e6,0x8364b18c,0xc9000eac}},	//   lvav, ycka, ردول, ্ধৃত_, 
   {{0xd5840133,0x29cc00a2,0xc0dc0092,0x798c015d}},	//   _رێته_, _uýat_, _ሕልም_, nfaw, 
   {{0x6ab8012c,0xafe48701,0xc45801c6,0xd3440133}},	//   _उप्र, допл, _нитх_, _فیشه_, 
   {{0x798c0368,0x78acb18d,0x5344009d,0x00000000}},	//   hfaw, ivav, _ххаа, --, 
   {{0x1dac00ab,0x78ac0243,0xadbc0408,0x926800db}},	//   _जोहत, hvav, аннă_, _ыраа_, 
   {{0xdcfc0139,0x3eb80267,0x3074004e,0x6e3406be}},	//   _anqı, årta_, _жукс, _qiyb, 
   {{0x798c0042,0x00000000,0x00000000,0x00000000}},	//   dfaw, --, --, --, 
   {{0x7c2400a3,0xeab801c0,0xa024000d,0x00000000}},	//   _chhr, ойг_, rköö, --, 
   {{0xada45841,0xbfa80014,0x612401a9,0x798c0042}},	//   _жайл, _راوٕ_, hаll, ffaw, 
   {{0x7ae008c2,0x00000000,0x00000000,0x00000000}},	//   ùlta, --, --, --, 
   {{0x2d900230,0xc0dc02d3,0xe8f8b18e,0x29cc03b2}},	// [e380] _ibye_, _ሕልሚ_, цла_, _býar_, 
   {{0x69d428b3,0x6560037e,0x7ae801e4,0x3fc01884}},	//   skye, waoh, ŝeta, ﺭﻳﺎﻧ, 
   {{0x78acb18f,0xab28b190,0x6a8401b9,0x8200002b}},	//   avav, _фона_, _ўлма, _iṣṭā_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x24982ef8,0x64b40f1b,0x24080124,0x65600072}},	//   تخاب_, بحار, онди_, raoh, 
   {{0xe738b191,0x2cb00042,0x00000000,0x00000000}},	//   _фев_, _mryd_, --, --, 
   {{0x65600374,0x61fc020c,0xd84000d7,0x00000000}},	//   paoh, éplo, pačí_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe0b400b8,0x93c801d9,0xf2c4009d,0x00000000}},	//   _bhāḥ_, _ڈالہ_, дсөн, --, 
   {{0x93c80d83,0x2d90007f,0xe29827fe,0x9f5c0270}},	//   _والہ_, _abye_, _маз_, lotú_, 
   {{0x63b81529,0x78ac0433,0xe0b40055,0x8c24009e}},	//   _intn, zvav, _dhāḥ_, পদান_, 
   {{0x2cb000a9,0x62882959,0x820000b8,0xd4540023}},	//   _bryd_, mtfo, _aṣṭā_, _ዝተጠቅ, 
   {{0x2cb00142,0x9cc8b192,0x905000c0,0x0c84013d}},	//   _cryd_, цына_, _авіц, кырм, 
   {{0x2d901418,0xdef8b193,0xe0b40055,0x62880af9}},	//   _ebye_, _мый_, _ghāḥ_, otfo, 
   {{0x9e04b194,0x63b8020c,0x494c01f2,0xa3e41f14}},	//   _очил, _mntn, _ọdịy, _पतन_, 
   {{0x2cb0b195,0xfde805d9,0xdb0401d3,0x62880254}},	//   _fryd_, _رکجو_, ndjé, itfo, 
   {{0x9be400d6,0x63b80926,0x22ac012d,0x798c1bef}},	// [e390] _жінк, _ontn, _lęk_, rfaw, 
   {{0x78acb196,0x3b540d1d,0x798cb197,0x00000000}},	//   rvav, _якор, sfaw, --, 
   {{0x78acb198,0x045402d3,0xf558007b,0x00000000}},	//   svav, _ዝተጻሕ, كلاب_, --, 
   {{0x63b8b199,0x00000000,0x00000000,0x00000000}},	//   _antn, --, --, --, 
   {{0x3a38009a,0x6288017a,0x00000000,0x00000000}},	//   _iisp_, etfo, --, --, 
   {{0x62883c12,0xb9d8044e,0x3a384eba,0x64a00417}},	//   ftfo, _አሎ_, _hisp_, уаша, 
   {{0x59d00fc8,0x628800b5,0x394808c2,0x6124022e}},	//   _सवार, gtfo, ocas_, sаll, 
   {{0x3948b19a,0x3a380113,0x63b803fa,0x2290004b}},	//   ncas_, _jisp_, _entn, اليس, 
   {{0x3868b19b,0xefcc001f,0x50a00131,0x92bc00cc}},	//   nsar_, ብዓዊ_, ئەتل, ঁনে_, 
   {{0x386803b7,0x9324380e,0x394805b1,0xaec47b0e}},	//   isar_, _قران, hcas_, ебол, 
   {{0x6288b19c,0xef18b19d,0x39480115,0xf1d0004e}},	//   ctfo, ямо_, kcas_, _бөпө, 
   {{0x2cb000a9,0x3868b19e,0x6224237e,0xa6e0148b}},	//   _pryd_, ksar_, _كولە, ýðil, 
   {{0x3948009a,0x42900b82,0x386801e3,0x25d400df}},	//   dcas_, _ሐርነት_, jsar_, גורן_, 
   {{0xc05817b9,0x29cc010b,0x3948b19f,0x7bc0b1a0}},	//   _آشنا_, _aýap_, ecas_, ölup, 
   {{0x3a38a98d,0x394801e4,0x3af4005b,0x00000000}},	//   _bisp_, fcas_, вятс, --, 
   {{0x3868248f,0x00000000,0x00000000,0x00000000}},	//   fsar_, --, --, --, 
   {{0x3a38b1a1,0x3868b1a2,0x78a800f3,0x00000000}},	// [e3a0] _disp_, gsar_, _ševr, --, 
   {{0x3a380472,0x3948b1a3,0x21f802b5,0x6288002d}},	//   _eisp_, acas_, rīhi_, ytfo, 
   {{0x3868b1a4,0x39480218,0x62887b85,0x00000000}},	//   asar_, bcas_, xtfo, --, 
   {{0x2d80b1a5,0x3948b1a6,0x00000000,0x00000000}},	//   ngke_, ccas_, --, --, 
   {{0x211c189a,0x00000000,0x00000000,0x00000000}},	//   _परेश_, --, --, --, 
   {{0x6288b1a7,0xddd8b1a8,0x4394b1a9,0x7a040153}},	//   ttfo, tutū, такс, mėta, 
   {{0xa5949842,0xe72801c0,0xc4e0009e,0x9f5c01d3}},	//   _пращ, _ховд_, বপেজ, potú_, 
   {{0x64a46816,0x717003cc,0xddd80374,0x528000d1}},	//   _паба, لۇما, rutū, چلۈك, 
   {{0x7a040024,0x528000d1,0x00000000,0x00000000}},	//   nėta, نلۈك, --, --, 
   {{0x394800eb,0xc0580092,0x95700023,0x00000000}},	//   zcas_, _ያደረግ, _ከምተን_, --, 
   {{0x686c0150,0x00000000,0x00000000,0x00000000}},	//   _ﺷﻪﮔﻰ_, --, --, --, 
   {{0x3868b1aa,0x7a040024,0xe2980124,0x00000000}},	//   ysar_, kėta, _маҷ_, --, 
   {{0x3a380395,0x50d09c17,0xa298001f,0x38680309}},	//   _risp_, _مزور, _ለይኩን_, xsar_, 
   {{0x7a040024,0x3868b1ab,0x00000000,0x00000000}},	//   dėta, vsar_, --, --, 
   {{0x386823db,0x7ae800df,0x00000000,0x00000000}},	//   wsar_, ĝeto, --, --, 
   {{0x3868b1ac,0xdd8400f7,0x3cb401b9,0x3d940022}},	//   tsar_, _чыкп, _айир, _риир, 
   {{0xc4c4066d,0x4bc40137,0x2b480175,0x3868b1ad}},	// [e3b0] _اے_, төөг, bcbc_, usar_, 
   {{0x3a380204,0xc9140114,0x48180108,0x69d8036e}},	//   _wisp_, удућ, ежую_, ëter, 
   {{0x34d80316,0xae040d2e,0x9f5c036e,0x39480115}},	//   भन्द, रवचन_, entë_, pcas_, 
   {{0x3a380395,0x3868b1ae,0x72a403e6,0x58840209}},	//   _uisp_, psar_, ێڕان, _пыга, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7294b1af,0x04540d28,0xdee80092,0xdb0c02d2}},	//   вших, ائند, ሆነና_, _ídóm, 
   {{0x071c01ec,0x00000000,0x00000000,0x00000000}},	//   _ﺷﺎﯓ_, --, --, --, 
   {{0xf48400dd,0x00000000,0x00000000,0x00000000}},	//   _لائی, --, --, --, 
   {{0xc1d40124,0x00000000,0x00000000,0x00000000}},	//   ыҩцә, --, --, --, 
   {{0x9f5c033b,0x1ab00118,0x00000000,0x00000000}},	//   nntè_, ुमाथ, --, --, 
   {{0x442003f9,0xc0580092,0x09cc00eb,0xdef80354}},	//   ɓi_, _ያደርግ, রোটা, çын_, 
   {{0x67380b21,0x91a401d3,0xdd0000cd,0x00000000}},	//   _útje, _سنتے_, _śrān, --, 
   {{0xf0e8075e,0x261000cd,0xc0d00240,0x00000000}},	//   _تىشى_, तवती_, ብባል_, --, 
   {{0x2eb44cc3,0xab28a52f,0x00000000,0x00000000}},	//   _асис, дога_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2b48009a,0x09cc03d4,0x00000000,0x00000000}},	//   scbc_, ৰোনা, --, --, 
   {{0x1864b1b0,0xddd8012c,0xebe40124,0xe7a80024}},	// [e3c0] кати_, jstř, _аопп, мвал_, 
   {{0x9cd4011a,0xddd801ef,0x00000000,0x00000000}},	//   _סויה_, dstř, --, --, 
   {{0x7a040024,0x00000000,0x00000000,0x00000000}},	//   sėta, --, --, --, 
   {{0x85080032,0x7a040064,0x00000000,0x00000000}},	//   ндең_, pėta, --, --, 
   {{0xf1c40b3c,0x557001ec,0x049400ae,0x00000000}},	//   वानन, ргіт, التح, --, 
   {{0x9cd40375,0x942000db,0x00000000,0x00000000}},	//   כונה_, амче, --, --, 
   {{0xc17800ee,0x16a40798,0x00000000,0x00000000}},	//   еҗе_, _иври_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb9d8001f,0x693400bc,0xdef4001f,0x66000115}},	//   _አዎ_, břež, ፈውን_, mnok, 
   {{0xdef8b1b1,0xa3e407c1,0xbbd00316,0x6600655d}},	//   дым_, _पति_, _सकेक, lnok, 
   {{0x2ee802a8,0xdb140ba1,0xe5900023,0x6600010f}},	//   _ƙafa_, _loxò, _ፍቓደኛ_, onok, 
   {{0xe0d815ed,0xe1f81064,0x6600b1b2,0x629803ac}},	//   _ове_, _юге_, nnok, _ipto, 
   {{0xa3e4534e,0x61e0b1b3,0x93600020,0x660003f5}},	//   _पता_, _ilol, _ግንባታ, inok, 
   {{0x61e0b1b4,0x6600b1b5,0x212401b9,0x69d806af}},	//   _hlol, hnok, _izoh_, êten, 
   {{0x6600b1b6,0x61e0b1b7,0x1af000cc,0x00000000}},	//   knok, _klol, _আঁহে_, --, 
   {{0x660000dd,0x201cb1b8,0x00000000,0x00000000}},	//   jnok, llti_, --, --, 
   {{0xdd90005e,0x201c5bd9,0x61e0b1b9,0x9f5c004a}},	// [e3d0] _бақы, olti_, _mlol, enté_, 
   {{0x61e0004e,0x66000099,0x62982bab,0x00000000}},	//   _llol, enok, _opto, --, 
   {{0x61e0b1ba,0x07444411,0x00000000,0x00000000}},	//   _olol, рхум, --, --, 
   {{0x7a040006,0x39146356,0x660000df,0x09cc03d4}},	//   mėto, _موجز, gnok, ৰোবা, 
   {{0x6298b1bb,0x7a040006,0x939800e8,0x1ca80327}},	//   _apto, lėto, _nj胃n, _ྔགས_, 
   {{0x61e0b1bc,0x6600b1bd,0x56f00166,0x45480116}},	//   _alol, anok, _күзс, нчәм_, 
   {{0x61e00036,0x7a040024,0x8384a8dd,0xe2940395}},	//   _blol, nėto, рыче, гащ_, 
   {{0x629800db,0x42d402bf,0x45d4014b,0xb2c000db}},	//   _dpto, рішу, _косс, _ۇڭعۇ, 
   {{0x61e0007f,0xd5144667,0x629802d0,0x45d4013d}},	//   _dlol, _شبرغ, _epto, _тотс, 
   {{0xab4801c0,0x7a040006,0x61e00608,0x600435c7}},	//   _kaмe, kėto, _elol, лным_, 
   {{0x3254b1be,0x00000000,0x00000000,0x00000000}},	//   _свер, --, --, --, 
   {{0x7a040024,0x201c0205,0x00000000,0x00000000}},	//   dėto, alti_, --, --, 
   {{0x50a00075,0x00000000,0x00000000,0x00000000}},	//   _ئەخل, --, --, --, 
   {{0x0ff8b1bf,0x66000034,0x629803ac,0xc6a80092}},	//   _تعصب_, znok, _ypto, _ዘጋሥጫ_, 
   {{0xa804b1c0,0x61e00142,0xda9800c7,0x7a040064}},	//   ҳзал, _ylol, нстә_, gėto, 
   {{0x3eb82d75,0x61e00076,0x00000000,0x00000000}},	//   ærte_, _xlol, --, --, 
   {{0xa6c8021a,0xa924b1c1,0x61fc0798,0x66000427}},	// [e3e0] کوال_, удал, épli, vnok, 
   {{0x7c640075,0x7a040153,0x00000000,0x00000000}},	//   _ئايل, bėto, --, --, 
   {{0xe578b1c2,0xf3e8015b,0x9f5c002e,0x6124022e}},	//   езе_, কচার_, unté_, rаli, 
   {{0x6600004c,0xdb2000f2,0x00000000,0x00000000}},	//   unok, _دوپی, --, --, 
   {{0x52800046,0x6600b1c3,0x46a40db3,0x201c03b2}},	//   ەلىك, rnok, _गैरह, ylti_, 
   {{0x6600b1c4,0xaa84010e,0x61e00037,0xa6640127}},	//   snok, _guýç, _slol, _مطرو, 
   {{0x66e40209,0x61e006c8,0xdcfc0327,0x00000000}},	//   _сова, _plol, _taqħ, --, 
   {{0x425405d9,0xbbd00892,0x81d42901,0x00000000}},	//   هنڪر, _सक्क, роих, --, 
   {{0x26d80024,0xe50467b3,0x58f400df,0x00000000}},	//   lypo_, _صبري, ָמיע_, --, 
   {{0x1fa401b9,0xd0943592,0x909400ae,0x00000000}},	//   уриг, ائيا_, اضير_, --, 
   {{0x61e018d6,0xb17c02f0,0x442c0205,0x977800df}},	//   _tlol, chťo, _ihd_, ערטה, 
   {{0x614440cd,0x61e0b1c5,0x56b4010f,0x00000000}},	//   _седа, _ulol, אפטן_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9f5c014a,0x442c002f,0x00000000,0x00000000}},	//   notü_, _jhd_, --, --, 
   {{0x442cb1c6,0x00000000,0x00000000,0x00000000}},	//   _mhd_, --, --, --, 
   {{0x5fa00075,0x442c0042,0x7a040153,0xb95402e8}},	//   _ئەھم, _lhd_, rėto, рващ, 
   {{0x442c0369,0xf1c417c6,0x00000000,0x00000000}},	// [e3f0] _ohd_, वातन, --, --, 
   {{0x964401c6,0x00000000,0x00000000,0x00000000}},	//   гэдд, --, --, --, 
   {{0x9f5c0418,0x355418fd,0xb4bc012d,0xdb1c01f4}},	//   lotó_, لناز, इम्_, öväk, 
   {{0x8aa405f5,0x442c01d5,0x752c0209,0xf4d8013d}},	//   _урьд, _ahd_, ýazo, кмеш_, 
   {{0x442c001f,0x85480212,0x00000000,0x00000000}},	//   _bhd_, узів_, --, --, 
   {{0xa8780bd9,0x9f5c01b8,0x442c045a,0x04b801d3}},	//   _באשר, gotü_, _chd_, اپوں_, 
   {{0x442c2caa,0x7ae001ab,0x170400f2,0x00000000}},	//   _dhd_, ùlth, _صفری_, --, 
   {{0x6738b1c7,0xb14406b3,0x32180109,0xb2241fbe}},	//   _útja, шнил, ôsy_, јмил, 
   {{0x04c800ec,0x00000000,0x00000000,0x00000000}},	//   _ٽولي_, --, --, --, 
   {{0x752801e2,0xc46c008f,0x442c0f85,0xf1c801ef}},	//   _izez, _נדבֿ, _ghd_, deáš_, 
   {{0xf1c400dc,0x00000000,0x00000000,0x00000000}},	//   वादन, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8234021f,0x69d8004a,0x3078008f,0x3e4c0118}},	//   _ارلا, êtem, _סאַנ, _věta_, 
   {{0xbc180220,0x2078010f,0x00000000,0x00000000}},	//   гісі_, _יאנא, --, --, 
   {{0xa96806bb,0x7d0cb1c8,0xfbd0004b,0x00000000}},	//   кива_, _exas, ښتې_, --, 
   {{0x26cc01b8,0xd940001b,0xdd8c007b,0xcfe400cc}},	//   äfom_, жети, _قوى_, _পদিন, 
  
   {{0x9f5c00d8,0x6754007b,0x5d6401ec,0xa3e40037}},	// [e400] cotó_, لخار, _тиым_, _पतल_, 
   {{0x26d8b1c9,0x9cd80a7c,0xa738431a,0x00000000}},	//   typo_, _סקיפ, نثار_, --, 
   {{0x5b78025f,0x66749a99,0x442cb1ca,0x7528b1cb}},	//   _בריא, شدار, _rhd_, _azez, 
   {{0x9cb052cb,0x69940826,0x99940050,0xe8f80166}},	//   _امیت, _трох, _پھِر_, _алм_, 
   {{0x9f5c0793,0x442c2517,0x26d80588,0x00000000}},	//   totü_, _phd_, sypo_, --, 
   {{0x752805b8,0x442ca7cc,0x3fb00154,0xf62811dc}},	//   _dzez, _qhd_, _চক্ষ, _ەسكى_, 
   {{0x7528b1cc,0xe5a45d6b,0x682000d0,0xf3645074}},	//   _ezez, _киви, hôdk, стін, 
   {{0xdb042a31,0x29cc010e,0x00000000,0x00000000}},	//   ndjá, _aýaz_, --, --, 
   {{0x7ae801e4,0xe3b01e4b,0xe3a80114,0x51f0009a}},	//   ĝeti, _ورئ_, _икад_, تسور, 
   {{0x442c010a,0x7ae801e4,0x00000000,0x00000000}},	//   _uhd_, ŝeti, --, --, 
   {{0x3eb801d3,0x9f4c08a5,0x00000000,0x00000000}},	//   írt_, _umfí_, --, --, 
   {{0x51809dc6,0x544000db,0x944000cf,0xd25003e6}},	//   _душа, _انەك, _اپەن, _بکوژ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x10100a2c,0x8fa05847,0x4c6801f0,0x00000000}},	//   _وبود, _маче, риён_, --, 
   {{0x9964b1cd,0x9f5c00c6,0xde6402e8,0x9e6400d1}},	//   итал, nntí_, _тълп, _ئاتن, 
   {{0x9f5cb1ce,0x7d0c005a,0x00000000,0x00000000}},	//   potó_, _txas, --, --, 
   {{0x7c940597,0x779838ab,0x7e9815b4,0x80ac06e3}},	// [e410] _الخص, лкар_, _شنکر_, जिटे, 
   {{0xdb140120,0x7528b1cf,0x05b800f2,0x00000000}},	//   _enxá, _rzez, یدنت_, --, 
   {{0x95c8b1d0,0xd7d800b5,0x752801ed,0x00000000}},	//   куда_, _cwチ_, _szez, --, 
   {{0x99280166,0xb9840107,0xf7700133,0x140c0073}},	//   _аюга_, _утоқ, زاڕ_, िव्ह_, 
   {{0x33d402dd,0xf1c41fe7,0x8504009f,0xba18009f}},	//   йікт, वासन, يومن, _ليگا_, 
   {{0x83880212,0x021800e5,0x752801ef,0x00000000}},	//   ибів_, یٹوں_, _vzez, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdfc400c6,0x360401d3,0xfeac05ac,0x854400c0}},	//   _בي_, _اورف, গমাধ, _дэфе, 
   {{0x0fe404a9,0x335800a8,0x00000000,0x00000000}},	//   илиқ_, _базэ_, --, --, 
   {{0x80ac00af,0xf1c400cd,0x7414009f,0x00000000}},	//   जिजे, वाहन, _اوئا, --, 
   {{0xee38b1d1,0x76402056,0x5194030d,0x00000000}},	//   лно_, _élys, _кăна, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb0401bf,0x00000000,0x00000000,0x00000000}},	//   ndjæ, --, --, --, 
   {{0x316c0369,0x20d00150,0x09e000dc,0xe5180037}},	//   laez_, _ءقوس, नस्य, _फँसि_, 
   {{0x16140118,0x00000000,0x00000000,0x00000000}},	//   तवार_, --, --, --, 
   {{0xf40c00eb,0x5e74011a,0x00000000,0x00000000}},	//   ষতির_, _התקן_, --, --, 
   {{0xa9a419b8,0x9a8c0023,0xe84800ec,0x00000000}},	// [e420] _һинд, _ዝውክል_, اجرن_, --, 
   {{0xddd8000a,0xe7380598,0x00000000,0x00000000}},	//   mutš, гез_, --, --, 
   {{0x316c0165,0x00000000,0x00000000,0x00000000}},	//   kaez_, --, --, --, 
   {{0x758800d4,0x5a9801e4,0x00000000,0x00000000}},	//   исів_, _גשטא, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x67380b21,0x66e0006a,0xe5780131,0x00000000}},	//   _útjo, gâkö, _әза_, --, 
   {{0xd7e4188b,0xaab802ab,0xd2540500,0x6b8802d2}},	//   _умре_, ॉमिक, бцы_, _öfgu, 
   {{0xe6180798,0x00000000,0x00000000,0x00000000}},	//   _сдб_, --, --, --, 
   {{0xdd140307,0x7640020c,0xc8c8000d,0xb62001ec}},	//   _धुंध_, _èlya, रमिट, _ﺩﺃ_, 
   {{0x7e74299f,0x20080254,0x00000000,0x00000000}},	//   огох, õbi_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdde8b1d2,0xa06800ee,0x25a4b1d3,0x00000000}},	//   ارده_, _бада_, neol_, --, 
   {{0x4c940046,0x248405be,0xf1c41a22,0xdd040139}},	//   пияс, nuom_, वारन, _döşm, 
   {{0x712402cb,0x7a040153,0xd00403fb,0x25a4b1d4}},	//   _برمل, mėti, _лече_, heol_, 
   {{0x7a040024,0xa3e400c5,0x3d940354,0x41dc0456}},	//   lėti, _पतई_, _дийр, _बवास, 
   {{0xd2540375,0xdd0400a2,0x24840064,0x00000000}},	//   משלה_, _göşm, kuom_, --, 
   {{0x7a040153,0x25a40254,0xbc0800cf,0xb0b00210}},	// [e430] nėti, deol_, _ۅرگۅ_, जिएग, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x316c0007,0xee480208,0x00000000,0x00000000}},	//   yaez_, _lẽn_, --, --, 
   {{0x19a80021,0x7a040006,0x95640801,0x25a40098}},	//   _стоп_, kėti, съжд, geol_, 
   {{0x74a8b1d5,0x316c03bd,0x00000000,0x00000000}},	//   рсең_, vaez_, --, --, 
   {{0x7a0402d5,0xe8a000cf,0x00000000,0x00000000}},	//   dėti, _تۅكپ, --, --, 
   {{0x78bc01a6,0x316c01c6,0x321c045a,0x00000000}},	//   _hrsv, taez_, _pkwy_, --, 
   {{0x93942c10,0x9f5c07de,0xee480208,0x62300798}},	//   _گجرا, entà_, _bẽn_, меју, 
   {{0x316cb1d6,0x7bc4013f,0x9f5c0120,0x2484003a}},	//   raez_, _onhu, mitê_, cuom_, 
   {{0x20302834,0x799c03ac,0x3ebc0051,0x92680114}},	//   وفيس, _lbsw, _brvt_, _брда_, 
   {{0x799c02d0,0xc1e801c6,0x6da401f0,0xdb040254}},	//   _obsw, рдөж_, оина, ndjä, 
   {{0xfbc8025f,0x9f5c026c,0x78bc00a2,0x8234b1d7}},	//   _בת_, antà_, _orsv, _فرنا, 
   {{0xf2840451,0xdef0001f,0xd9cc00eb,0x00000000}},	//   _اھڙو_, ልተኛ_, রসাম, --, 
   {{0x799c808f,0x6538008f,0x00000000,0x00000000}},	//   _absw, יערד, --, --, 
   {{0xed58b1d8,0x25a4b1d9,0x78bc0158,0xeb341df2}},	//   _кой_, yeol_, _arsv, زىرد, 
   {{0x799c02d0,0x7db40006,0x00000000,0x00000000}},	//   _cbsw, _есьц, --, --, 
   {{0x799c03ac,0x6fcc2ef1,0x6d5402d0,0x25a4000d}},	// [e440] _dbsw, तापू, _ifya, veol_, 
   {{0x799c03ac,0xf8b0004b,0xeb980114,0xdc0000d7}},	//   _ebsw, رکټ_, _тио_, zčúl, 
   {{0xbbe80128,0xe618014b,0xee480208,0x00000000}},	//   _دريم_, адж_, _mẽo_, --, 
   {{0x64a4b1da,0xa5247abe,0x2484b1db,0x799c02d0}},	//   жада, омед, tuom_, _gbsw, 
   {{0x69c4b1dc,0x7bc4002d,0x25a4b1dd,0x00000000}},	//   _inke, _ynhu, reol_, --, 
   {{0x316801e4,0x05980214,0x265800d8,0xd3a00395}},	//   _ĵaza_, _گمرک_, _враќ_, дръп, 
   {{0x53307dfb,0xf1c40490,0x6d540857,0x25a40037}},	//   мешт, वांन, _ofya, peol_, 
   {{0x672c1727,0x2fc802a8,0x682000d2,0x00000000}},	//   _izbj, _ɗage_, gôdv, --, 
   {{0x6560b1de,0xd1b00b28,0xdfa40b3e,0x9f5c00d8}},	//   mboh, بینک, ојно, entá_, 
   {{0x33d4063b,0xc33008b0,0x9f5cb1df,0x6d5443c5}},	//   _ніхт, _كەش_, mitë_, _afya, 
   {{0x69c4b1e0,0x9f5c0240,0x7a0400c0,0xefc80023}},	//   _onke, litë_, sėti, ጽበዮ_, 
   {{0x6560b1e1,0xbf100116,0x7cd800ae,0x171800df}},	//   nboh, _җүмә, موجز_, שוטע, 
   {{0x9f5c0023,0xa11400f7,0x8cf40006,0xcfdc00cc}},	//   nitë_, _بوشت, дзяц, যোধন, 
   {{0xdde81550,0x799c03ac,0x6560002f,0x5e8400d8}},	//   ارگه_, _sbsw, hboh, _дуиз, 
   {{0x9f5c0240,0x799c03ac,0x00000000,0x00000000}},	//   hitë_, _pbsw, --, --, 
   {{0xa2b00b67,0x656002fb,0x527802e4,0x1b0028fc}},	//   _आनन्, jboh, ינלא, зүүн, 
   {{0xdde800aa,0x9f5c0240,0x6560b1e2,0xa3e8b1e3}},	// [e450] _مرکه_, jitë_, dboh, मसा_, 
   {{0x69c4b1e4,0x9ba00075,0x3f8cb1e5,0x7bc4b1e6}},	//   _enke, _تەسى, ngdu_, _unhu, 
   {{0x799c1662,0x6560002f,0x2f8000d1,0xf1b8013a}},	//   _tbsw, fboh, ﯩﺪﯨﻢ_, loše_, 
   {{0x9f5c02d3,0x9ad001f2,0x799c02d0,0x0f34010f}},	//   fitë_, hịko, _ubsw, קראט_, 
   {{0x798c009f,0xf1b8013a,0x78bc01e3,0xd7e400d4}},	//   mgaw, noše_, _ursv, _діво, 
   {{0xd6d80395,0x00000000,0x00000000,0x00000000}},	//   _ктб_, --, --, --, 
   {{0x9f5c14ba,0x78ac00d2,0x69c4b1e7,0xe7a40150}},	//   mitè_, lwav, _ynke, _ءۇمى_, 
   {{0x9f5cb1e8,0xf1b81505,0xf1c43174,0x00000000}},	//   litè_, koše_, वाइन, --, 
   {{0x798c00b5,0x9f5c0240,0x85544d66,0x78ac02d0}},	//   igaw, citë_, _غیور_, nwav, 
   {{0xf1b805a1,0x9f5c02bd,0xd3e01079,0x60c499c0}},	//   doše_, nitè_, _تقطی, åkma, 
   {{0x78acb1e9,0x7a040006,0x798c00f2,0x37bc015b}},	//   hwav, lėtu, kgaw, _আকার, 
   {{0x78acb1ea,0x3208b1eb,0x3204009f,0x00000000}},	//   kwav, _ñay_, _عِشق, --, 
   {{0xf1b80e3c,0x9f5c0100,0x10600050,0x612401a9}},	//   goše_, kitè_, _کُڈُ, qаlp, 
   {{0xfa2400cc,0x6560b1ec,0xeb980063,0xee480051}},	//   _মংগল_, zboh, љив_, _hẽm_, 
   {{0xab284018,0x9f5c59a7,0xee4801fb,0x06e000fe}},	//   сова_, zitë_, _kẽm_, _যেনি, 
   {{0x798cb1ed,0x6d54009f,0x3d140521,0x7a040153}},	//   ggaw, _ufya, ụwa_, kėtu, 
   {{0x2d900223,0xf1b805a1,0x18a0a5d5,0x78ac6ca2}},	// [e460] _icye_, coše_, натм, gwav, 
   {{0x798cb1ee,0x7a040024,0x9f5c0200,0x9f0000e5}},	//   agaw, dėtu, vitë_, _آڈیو, 
   {{0x6abc070d,0x656001e4,0x00000000,0x00000000}},	//   _urpf, tboh, --, --, 
   {{0x69c4b1ef,0x9f5c0023,0x78ac1418,0x2874008e}},	//   _unke, titë_, bwav, _ныгр, 
   {{0x6498b1f0,0x69d87f70,0x9f5c02e2,0x53c407b6}},	//   стер_, êteu, bitè_, लांश, 
   {{0x9f5c044e,0x9948010e,0x6560002f,0x00000000}},	//   ritë_, _köşi_, sboh, --, 
   {{0x9f5c02d3,0xd2548fd9,0xd7e479ea,0xf5200014}},	//   sitë_, пцы_, _эмре_, _یۂَ, 
   {{0x9f5cb1f1,0x68200770,0x7a0400c0,0xc0dc0240}},	//   mité_, rôdu, sėtv, _ዕልል_, 
   {{0x9f5cb1f2,0x6600b1f3,0xdb040023,0xd46413d6}},	//   lité_, miok, tejë, _ните_, 
   {{0x6600b1f4,0x798c0007,0x4438b1f5,0xf1c400bc}},	//   liok, zgaw, _òr_, वाउन, 
   {{0x9f5cb1f6,0xdef8b1f7,0x798c0280,0x3f8c0162}},	//   nité_, сып_, ygaw, rgdu_, 
   {{0x6600b1f8,0xf1b8000a,0x63a8b1f9,0x78ac020b}},	//   niok, toše_, lefn, ywav, 
   {{0x62881ca6,0xe12400cf,0x00000000,0x00000000}},	//   lufo, _эмди, --, --, 
   {{0x63a8008c,0x798c0198,0x9f5c0066,0x6600b1fa}},	//   nefn, wgaw, kité_, hiok, 
   {{0x628823db,0x6600b1fb,0x798cb1fc,0x3db402f5}},	//   nufo, kiok, tgaw, টাবল, 
   {{0x63a8b1fd,0x9f5c20ef,0x78acb1fe,0xdde800aa}},	//   hefn, dité_, twav, _درته_, 
   {{0x6600b1ff,0x798c0151,0xdd900046,0x97a41768}},	// [e470] diok, rgaw, _жақы, зрел, 
   {{0x201cb200,0x8d741c5c,0x22440113,0x6288b201}},	//   noti_, _قاۋا, _liok_, kufo, 
   {{0x3dc8b202,0x201c0a73,0x63a800a9,0xd6d80801}},	//   _knaw_, ioti_, defn, щта_, 
   {{0x201cb203,0xd1cc001f,0x316800df,0x69d806af}},	//   hoti_, ሥታት_, _ĵazo_, êtet, 
   {{0x201cb204,0x3e4c038e,0x1ca80003,0x3a28b205}},	//   koti_, _děti_, _པགས_, mlap_, 
   {{0x3a28b206,0x7a040006,0x2244005a,0x9f5cb207}},	//   llap_, rėtu, _aiok_, bité_, 
   {{0x9f5cb208,0x201cb209,0x224401c6,0x6600b20a}},	//   cité_, doti_, _biok_, biok, 
   {{0x6600b20b,0x3a28b20c,0xdb040100,0xa1f400e5}},	//   ciok, nlap_, rejè, وڑنا_, 
   {{0x201cb20d,0x3a281c06,0x2244005a,0x62880472}},	//   foti_, ilap_, _diok_, aufo, 
   {{0x201cb20e,0x6288014b,0x63a80113,0xb4e81414}},	//   goti_, bufo, cefn, मनी_, 
   {{0x3a2836ae,0x03783868,0xef180104,0x2d900205}},	//   klap_, _رحلت_, юмо_, _pcye_, 
   {{0x22448106,0x9f5c0108,0xed34009d,0x00000000}},	//   _giok_, entä_, дэгэ, --, 
   {{0x201cb20f,0x3a28b210,0x21240369,0xd060016b}},	//   boti_, dlap_, _gyoh_, _ɔsɛe, 
   {{0x660001c0,0x9b54039b,0x320cb211,0x224401c4}},	//   ziok, диёт_, lney_, _ziok_, 
   {{0x320cb212,0x9f5c4afb,0x6600009a,0x00000000}},	//   oney_, xité_, yiok, --, 
   {{0x320c02a4,0x9f5c2047,0x3dc80295,0x3d18b213}},	//   nney_, vité_, _gnaw_, _युके_, 
   {{0x6600b214,0x2794b215,0x62880112,0x9f5c00f2}},	// [e480] viok, дшер, zufo, wité_, 
   {{0x3a280649,0x66e408da,0x9f5c8da1,0x6288014b}},	//   alap_, моза, tité_, yufo, 
   {{0x320c039a,0x81b404c5,0x3e4c00bc,0xa024b216}},	//   kney_, ঞাত_, _pěti_, ljöö, 
   {{0x9f5cb217,0x201cb218,0x2fc802a8,0x95c40120}},	//   rité_, zoti_, _ɗaga_, душа_, 
   {{0x201c006c,0x6600b219,0x9f5cb21a,0x63a8008c}},	//   yoti_, riok, sité_, tefn, 
   {{0x6600b21b,0x62882c98,0x320cb21c,0x9f5cb21d}},	//   siok, tufo, eney_, pité_, 
   {{0xdb0400dd,0x63a8b21e,0x6e3402fb,0x387800d7}},	//   tejé, refn, _ohyb, _zvsr_, 
   {{0x320c1368,0x6288b21f,0x63a80008,0x69d4b220}},	//   gney_, rufo, sefn, njye, 
   {{0x6288b221,0x9f5c0108,0x00000000,0x00000000}},	//   sufo, yntä_, --, --, 
   {{0x248489b3,0x3dc80493,0x9e700328,0xff98026a}},	//   mrom_, _snaw_, نۇتت, чкој_, 
   {{0x201cb222,0x3a28b223,0x06e00183,0x248403cd}},	//   roti_, ylap_, _যেতি, lrom_, 
   {{0x6e34b224,0x201c23e0,0x320c0009,0x00000000}},	//   _chyb, soti_, cney_, --, 
   {{0x201cb225,0xe0d0b226,0xb91000e4,0xa020000d}},	//   poti_, _جزا_, salẽ_, öösu, 
   {{0x7fb8b227,0x60c0b228,0xf1b827c4,0x201cb229}},	//   _رهبر_, _irom, moša_, qoti_, 
   {{0xf1b8b22a,0x3a28b22b,0x60c0b22c,0x24840fa8}},	//   loša_, tlap_, _hrom, hrom_, 
   {{0x1de0190c,0x60c0b22d,0x2484181f,0xd2b40375}},	//   _पवित, _krom, krom_, וללת_, 
   {{0x3a28b22e,0xf1b800de,0x8d74b22f,0xc32415bf}},	// [e490] rlap_, noša_, _شايا, _چە_, 
   {{0x3a28b230,0xc3241473,0x2484b231,0x60c014af}},	//   slap_, _نە_, drom_, _mrom, 
   {{0x3a28b232,0xf1b8000a,0x60c001af,0x7c24b233}},	//   plap_, hoša_, _lrom, _ikhr, 
   {{0x2484b234,0x60c08928,0x3a2800fd,0xdcfc03b9}},	//   from_, _orom, qlap_, _haqı, 
   {{0xb4e81431,0xf1b8b235,0x320c05d5,0x69f0113e}},	//   मने_, joša_, vney_, _сүтт, 
   {{0xc7c406b3,0xf1b80171,0x00000000,0x00000000}},	//   _исси, doša_, --, --, 
   {{0x60c0b236,0x320cb237,0x7c2402ce,0x5fd035e0}},	//   _arom, tney_, _mkhr, तानल, 
   {{0x320cb238,0xf1a8007b,0x975801e1,0x98b803e3}},	//   uney_, ساعه_, _è̟bù, laqı_, 
   {{0x6e3400a9,0x225c0254,0x84940023,0x3078007b}},	//   _rhyb, _ettk_, _ዘፍርሕ_, أحبة_, 
   {{0x752800f1,0x764800ad,0x320cb239,0xb4bc36c7}},	//   _iyez, _hiey, sney_, ेमी_, 
   {{0x60c0b23a,0x320c0589,0x68f40072,0x00000000}},	//   _erom, pney_, zzyd, --, 
   {{0x7c24b23b,0x75281418,0x2b18012c,0xf1b800d7}},	//   _akhr, _kyez, _मुगु_, boša_, 
   {{0x2e300008,0x764800ad,0xdcfc008e,0x00000000}},	//   gáfa_, _miey, _baqı, --, 
   {{0x7648b23c,0x7528b23d,0x6e340142,0xa0240037}},	//   _liey, _myez, _whyb, rjöö, 
   {{0x161c1b37,0x248413fd,0xada401c0,0x7528033b}},	//   यकार_, zrom_, _зайл, _lyez, 
   {{0x7c24009a,0x60c002d0,0xec780305,0x248400d7}},	//   _ekhr, _yrom, _епи_, yrom_, 
   {{0x75281446,0x98b800ac,0xeb740276,0x60c0263e}},	// [e4a0] _nyez, faqı_, _пынэ, _xrom, 
   {{0x68f40034,0x9f8800c5,0xdc98008f,0x03d4010e}},	//   rzyd, söök_, _צייל, _düỳb, 
   {{0x7528013e,0xdee01ee0,0xab2815d1,0xe4d405af}},	//   _ayez, ምፒክ_, _хона_, کتاب, 
   {{0xe570b23e,0x2484b23f,0x752861de,0x7ae0b240}},	//   اطا_, trom_, _byez, älte, 
   {{0x75280223,0xdcfc0724,0x4394b241,0x225c0869}},	//   _cyez, _yaqı, валс, _sttk_, 
   {{0x2484b242,0x75280100,0xdcfc0724,0x60c0b243}},	//   rrom_, _dyez, _xaqı, _rrom, 
   {{0x248408fb,0x7528b244,0x626401d3,0x60c0b245}},	//   srom_, _eyez, راثق, _srom, 
   {{0xf1b8b246,0x2484b247,0x35c40022,0x443cb248}},	//   toša_, prom_, _иасҳ, smv_, 
   {{0x75281418,0xe0d0b249,0x11d00131,0x00000000}},	//   _gyez, ازع_, اتىد, --, 
   {{0x60c00b4f,0xf1b80171,0x00000000,0x00000000}},	//   _vrom, roša_, --, --, 
   {{0x2118b24a,0x9f5c00c6,0xf1b8b24b,0x7648016b}},	//   _کتاب_, ontú_, soša_, _yiey, 
   {{0xdcfc0139,0x63b8b24c,0x00000000,0x00000000}},	//   _saqı, _hatn, --, --, 
   {{0x63b8b24d,0x60c0b24e,0x9cc802d5,0x229883cc}},	//   _katn, _urom, чына_, lëk_, 
   {{0x63b8b24f,0xd12cb250,0x00000000,0x00000000}},	//   _jatn, _امه_, --, --, 
   {{0x63b8b251,0xf1c40316,0x9f5c03a0,0xdcfc013d}},	//   _matn, वाचन, nití_, _vaqı, 
   {{0xdcfc0598,0x99cc00bd,0x63b8b252,0x8e8000c6}},	//   _waqı, রস্ক, _latn, _إليه, 
   {{0x764805b1,0x9f5cb253,0x55c00220,0x7c3400c7}},	// [e4b0] _riey, hití_, ғалғ, _иеих, 
   {{0x62840325,0x752800ca,0x7c245e03,0x629801d5}},	//   _ākon, _ryez, _ukhr, _oqto, 
   {{0x7528b254,0xb4e800dc,0x5018011a,0x8ae40006}},	//   _syez, मन्_, לומו, _біял, 
   {{0xd624b255,0x7528007f,0x2b18012c,0x9a8c0240}},	//   رعاي, _pyez, _मुटु_, _ዝልዓለ_, 
   {{0x63b808ce,0x76481743,0xc5ec0417,0x00000000}},	//   _batn, _viey, _ғғ_, --, 
   {{0x63b8b256,0xec70008f,0x09c400c7,0x6380009d}},	//   _catn, בֿה_, _иӡӡо, агша, 
   {{0x63b8b257,0xae0000af,0x9f5c01e7,0x764801f4}},	//   _datn, _लगलन_, gití_, _tiey, 
   {{0x63b803ac,0xb5c80214,0xb4e800db,0xdb04013a}},	//   _eatn, _تورم_, _قىزم_, její, 
   {{0x3494b258,0x63b84351,0x7528b259,0x53a000db}},	//   _шаар, _fatn, _uyez, _مۅشك, 
   {{0x63b80510,0x93240f1b,0x9f5c0216,0xafe40137}},	//   _gatn, _كران, bití_, тоол, 
   {{0xfbd40b33,0x0ea800bc,0x00000000,0x00000000}},	//   दानम, टौंड, --, --, 
   {{0xf1b81ebd,0xed58b25a,0x63b8b25b,0x9f5c026c}},	//   mošo_, ьом_, _zatn, intù_, 
   {{0xf1b8000a,0xc3300050,0x63b800dc,0x7e64013a}},	//   lošo_, _نٕے_, _yatn, _čipe, 
   {{0x63b83ae4,0x00000000,0x00000000,0x00000000}},	//   _xatn, --, --, --, 
   {{0xcdc43ce1,0x9f5c003a,0x69940153,0x00000000}},	//   _байқ, bitâ_, крах, --, 
   {{0xada4b25c,0xdb04013a,0x00000000,0x00000000}},	//   _раил, cejí, --, --, 
   {{0x2bb8007b,0x00000000,0x00000000,0x00000000}},	// [e4c0] _قادة_, --, --, --, 
   {{0x941c013f,0xf1b800e2,0x9f5c00c7,0x00000000}},	//   _osuɑ_, košo_, mitã_, --, 
   {{0xf1b8005f,0x5fd00073,0x52d8000d,0xa96801f0}},	//   jošo_, तातल, बहोस, _оина_, 
   {{0x63b81b24,0xb6840075,0xf1b800e2,0xd6cc27b4}},	//   _satn, اشلى, došo_, تقم_, 
   {{0x2b04028a,0x00000000,0x00000000,0x00000000}},	//   _हेतु_, --, --, --, 
   {{0x63b88258,0xdb0400bc,0x00000000,0x00000000}},	//   _qatn, zejí, --, --, 
   {{0x63b8b25d,0x31c000d1,0xe57801f4,0xf1b800de}},	//   _vatn, ﻣﻠﯩﻜ, _озв_, gošo_, 
   {{0x63b8039a,0xe5a4b25e,0x00000000,0x00000000}},	//   _watn, _шиби, --, --, 
   {{0xa444b25f,0x63b8b260,0x9f5c0093,0xc3c4010b}},	//   _анад, _tatn, sití_, _бөйл, 
   {{0x9f5c02f0,0xbed80cb6,0x00000000,0x00000000}},	//   pití_, едох_, --, --, 
   {{0xd36cb261,0xdb144738,0xf1b800ef,0xdcec002b}},	//   _ذهن_, _taxé, cošo_, dacā, 
   {{0xa0680137,0x4e9001d5,0x9e6400f2,0x00000000}},	//   _жада_, گشیر, _یابن, --, 
   {{0x5c0406bb,0xdb040407,0xa3b40073,0x00000000}},	//   вява, rejí, _जसा_, --, 
   {{0xdb040316,0x00000000,0x00000000,0x00000000}},	//   sejí, --, --, --, 
   {{0x9f5c4d72,0x3cec33e9,0x00000000,0x00000000}},	//   mità_, šev_, --, --, 
   {{0x9f5c7b34,0x62880158,0x00000000,0x00000000}},	//   lità_, irfo, --, --, 
   {{0x101400dd,0xb8941e95,0xdb0401d3,0xdce40064}},	// [e4d0] _سکیں_, طلاع, ldjü, _ėmėm, 
   {{0x9f5cb262,0x10980375,0xddd856ce,0xdcec002b}},	//   nità_, ובמב, kstū, cacā, 
   {{0x7cfc0158,0xa3b4033f,0x6288b263,0x00000000}},	//   bærå, ज़न_, jrfo, --, 
   {{0x9f5c0109,0xf1a002dd,0x1dc000cd,0x00000000}},	//   hità_, _ﺃﻤﺎﻡ_, षयित, --, 
   {{0x0574b264,0x458402bf,0x6aa80142,0x9f5c031c}},	//   شاند, ргів, _âffr, kità_, 
   {{0xf1b828dd,0x7294005a,0x00000000,0x00000000}},	//   tošo_, гших, --, --, 
   {{0x73340058,0x9f5cb265,0x2324013e,0x964400c7}},	//   دىغا, dità_, лоши_, _аэад, 
   {{0x85040574,0xf48401ed,0x2d9c013f,0xae0000bc}},	//   _शेवट_, _مائی, ɑtew_, _लगइन_, 
   {{0x6288b266,0x9f5c07c5,0x7654010e,0x04c800f1}},	//   arfo, fità_, _huzy, _ټولي_, 
   {{0x9f5c011c,0x83840153,0x7654012d,0xe2080162}},	//   gità_, _выце, _kuzy, tjóð_, 
   {{0xb904031c,0x6e4429c6,0x00000000,0x00000000}},	//   _ཨཽ_, леоз, --, --, 
   {{0x7654b267,0x7774009a,0x6da433ae,0x316800ee}},	//   _muzy, _lezx, دمحم, _ýaz_, 
   {{0xe0ccb268,0x2d9c0034,0x9f5cb269,0xc0bc02d3}},	//   _ув_, ęte_, bità_, ታቶር_, 
   {{0x9f5cb26a,0x2d9c012c,0x76540100,0x00000000}},	//   cità_, řte_, _ouzy, --, 
   {{0x76540064,0x00000000,0x00000000,0x00000000}},	//   _nuzy, --, --, --, 
   {{0x9f5cb26b,0x7ae00267,0xf3340023,0x00000000}},	//   pitã_, älta, _ብንቕሓ, --, 
   {{0x9f5c579d,0xcab40131,0x6e2401d3,0x0fb4000d}},	// [e4e0] litá_, _ھەرخ, mokb, _असाढ, 
   {{0x67f0008c,0x76540204,0x628803cd,0xdb040162}},	//   _bæja, _buzy, yrfo, gdjó, 
   {{0x9f5c4a1f,0x18a02d40,0xdb98011a,0x00000000}},	//   nitá_, _қарм, _אסיר, --, 
   {{0x7654b26c,0x80a400af,0x6e2400e5,0x9f5c0327}},	//   _duzy, _कहले, nokb, zità_, 
   {{0x93c800e5,0xdb0401d3,0x00000000,0x00000000}},	//   کانہ_, zdjü, --, --, 
   {{0x9f5cb26d,0x6e2401a4,0xdb0400e5,0x00000000}},	//   kitá_, hokb, lejá, --, 
   {{0x9f5cb26e,0x6288b26f,0x76540432,0x3f98004e}},	//   vità_, urfo, _guzy, òrum_, 
   {{0x9f5cb270,0x6288369d,0x7ae003b2,0x00000000}},	//   ditá_, rrfo, ølti, --, 
   {{0x9f5cb271,0xdef40020,0x0a3c001f,0x76540210}},	//   tità_, ገውን_, _በእስራ, _zuzy, 
   {{0x9f5c03a0,0xd0040f5c,0xdb040124,0x81b400cc}},	//   fitá_, лење_, hejá, ঞাই_, 
   {{0x9f5cb272,0xdc6c0201,0x1ea86ea9,0xf8d030a4}},	//   rità_, _ጠቅላይ_, رادي_, _सप्प, 
   {{0x9f5cb273,0x33380014,0x6e2401d3,0xf1a8b274}},	//   sità_, _شٲنگ_, gokb, _لاهه_, 
   {{0x9f5cb275,0x672c002d,0x0c84b276,0x0ca83252}},	//   pità_, _lybj, йырм, лтри_, 
   {{0x61e0b277,0x9f5c45a7,0x3db40154,0xcfd0009b}},	//   _hool, bitá_, টাইল, _гошћ, 
   {{0xc4c4b278,0x9f5c4a1f,0x61e06e5e,0xdb040162}},	//   _کے_, citá_, _kool, vdjó, 
   {{0x61e0947b,0x76540118,0x5fd00b02,0x00000000}},	//   _jool, _ruzy, तावल, --, 
   {{0x61e0b279,0xcfb4015b,0x26e0015b,0x5f44009d}},	// [e4f0] _mool, জারন, _গেলো_, _шүүн_, 
   {{0x61e01105,0x67f002d2,0x6fcc012d,0x00000000}},	//   _lool, _pæja, ़ाएं, --, 
   {{0xdb0403b2,0x00000000,0x00000000,0x00000000}},	//   rdjó, --, --, --, 
   {{0x61e0b27a,0xdb040174,0xcec0013a,0x00000000}},	//   _nool, sdjó, _hoří_, --, 
   {{0xdb14283a,0x672c03b2,0xd7f8b27b,0x00000000}},	//   _maxí, _eybj, _зув_, --, 
   {{0xd5a08bee,0x61e00618,0xdb0401e7,0x28b8000d}},	//   _گلری, _aool, _ómói, _उनति, 
   {{0x61e0b27c,0x9f5c0048,0x255c063f,0x6b88000f}},	//   _bool, xitá_, _ịle_, _ôfge, 
   {{0x9f5cb27d,0x61e0b27e,0x439401d5,0xc2c80472}},	//   vitá_, _cool, _ҳафс, ابول_, 
   {{0x61e0b27f,0x38682035,0x61e488e9,0x7e640427}},	//   _dool, npar_, ökla, _čipa, 
   {{0x38689d2b,0x9f5c0998,0xf39401b9,0x6e240175}},	//   ipar_, titá_, _خطرگ, wokb, 
   {{0x3254b280,0x3868b281,0xee38b1e0,0x6e2401ed}},	//   _твер, hpar_, кно_, tokb, 
   {{0x61e0b282,0x9f5c34fe,0x6cc4b283,0x38681529}},	//   _gool, ritá_, айма, kpar_, 
   {{0x7ae0097d,0x9f5c45a7,0x316cad72,0x506400d8}},	//   ältn, sitá_, mbez_, _стеа, 
   {{0x3868b284,0xcfdc04c5,0x6e2401ed,0xdc640a5b}},	//   dpar_, যোজন, sokb, рард_, 
   {{0xab28b285,0x61e01dd0,0xc60c045e,0x6e2401ed}},	//   това_, _yool, ষকতা_, pokb, 
   {{0x61e0b286,0xbe8400db,0xba540395,0x3e84007b}},	//   _xool, _اجوو, стръ, _اشوف, 
   {{0xa804b287,0xb86400f1,0x3868003e,0x00000000}},	// [e500] азал, مالو, gpar_, --, 
   {{0xdb04b288,0x00000000,0x00000000,0x00000000}},	//   sejá, --, --, --, 
   {{0x98a40a30,0xa9a4b289,0x6f1c0e78,0x4bc401ee}},	//   ānā_, _кинд, ßsch, _көңг, 
   {{0xe5a4b28a,0x00000000,0x00000000,0x00000000}},	//   риди, --, --, --, 
   {{0x64983b5f,0x61e01059,0xa4444cd0,0x28f800c0}},	//   ттер_, _rool, андд, _рэнэ_, 
   {{0x61e0b28b,0x68200030,0x672c01bf,0x316c013d}},	//   _sool, hôdz, _tybj, ebez_, 
   {{0x66e4b28c,0x61e0b28d,0x00000000,0x00000000}},	//   _това, _pool, --, --, 
   {{0x61e0b28e,0xc1b8361e,0xd6cc00ae,0x00000000}},	//   _qool, улих_, _تقف_, --, 
   {{0x61e000af,0x7f582773,0x2a68002f,0x5fd012f8}},	//   _vool, лапс_, hpbb_, तालल, 
   {{0x61e0b28f,0x205404a9,0xb60402fb,0x93c800e5}},	//   _wool, лтүр, _višň, _لامہ_, 
   {{0x61e0b290,0x3fc82172,0xe04803e6,0x0a3c0092}},	//   _tool, ندگی_, _یشته_, _በብሄራ, 
   {{0xc2c49245,0x25a4000f,0x3868b291,0x2088022e}},	//   _پيچي, nfol_, ypar_, _айди_, 
   {{0x20540c75,0x10d4129e,0x00000000,0x00000000}},	//   _ттер, _نبوغ_, --, --, 
   {{0xd004b292,0x442c0072,0x8fa00063,0xdb140139}},	//   _кече_, _jkd_, _даље, _waxí, 
   {{0xdb140306,0xd5400241,0x8da00150,0x8b080118}},	//   _taxí, _kẹ́k, _ﺃﻋﺩﺕ_, voří, 
   {{0x442cb293,0xb95402e8,0x00000000,0x00000000}},	//   _lkd_, сващ, --, --, 
   {{0x26c8b294,0xa3b434ef,0xe7d00490,0x9f5c003a}},	// [e510] _arbo_, ज़ा_, सांप, ritæ_, 
   {{0x3868b295,0x442cb296,0xda780139,0x9f5c003a}},	//   rpar_, _nkd_, _иям_, sitæ_, 
   {{0x3554007b,0x25a4022e,0x9f5c4132,0xdd0c013d}},	//   مناز, ffol_, mitä_, _yışr, 
   {{0x3868b297,0x25a401b8,0x9f5cb298,0xd1e80023}},	//   ppar_, gfol_, litä_, ቅታት_, 
   {{0xd498b299,0x442c4cdf,0x799c02d0,0xf2c4009d}},	//   тре_, _bkd_, _icsw, өөжи, 
   {{0x799c03ac,0x6aa80036,0x84280212,0x25a40042}},	//   _hcsw, _äffc, ажів_, afol_, 
   {{0xd5b809a5,0x442cb29a,0x52b400eb,0xf1d039af}},	//   _иса_, _dkd_, _অপহৃ, зөлө, 
   {{0x94840209,0xef1000f7,0x442cb29b,0xdb040037}},	//   _выжд, үүдө, _ekd_, mejä, 
   {{0xf1b8b29c,0x442c03f9,0x316c008e,0xdb043110}},	//   noši_, _fkd_, rbez_, lejä, 
   {{0x799c02d0,0x00000000,0x00000000,0x00000000}},	//   _lcsw, --, --, --, 
   {{0xdedc02d3,0xb8e8025c,0xd1700032,0xb8d8031c}},	//   _ንርኢ_, _ཊན_, _һыҙы, _ཙར_, 
   {{0xcfb4015b,0xb63800b5,0xf1b8597b,0x78bc02d0}},	//   জাইন, _ｄｘ_, koši_, _ossv, 
   {{0x320c05b1,0xf1b800e2,0xe0cc01c6,0xd9cc03d4}},	//   miey_, joši_, _эв_, ৰসাম, 
   {{0x320c05b1,0x799c03ac,0x3c1802d5,0x6538010f}},	//   liey_, _acsw, аўся_, טערד, 
   {{0x6e94b29d,0x9f5c0789,0x799c02d0,0xed58030d}},	//   _العا, antó_, _bcsw, _йой_, 
   {{0x320c2a1f,0xb95400d1,0xdb040254,0x49b40124}},	//   niey_, ەئەت, dejä, цәоу, 
   {{0x81cc00bd,0xd940b29e,0x799c02d0,0x1864013e}},	// [e520] _রকম_, зети, _dcsw, йати_, 
   {{0x9944a285,0x00000000,0x00000000,0x00000000}},	//   спуб_, --, --, --, 
   {{0x5b5400c8,0x799c02d0,0x6fa80cf1,0xbbe800e3}},	//   _לייב_, _fcsw, ज्यू, _خريم_, 
   {{0x26c8b29f,0x6abc04cc,0x3a280869,0x442cb2a0}},	//   _vrbo_, _ispf, coap_, _skd_, 
   {{0x442c38d2,0xd54001e1,0x25a4b2a1,0x00000000}},	//   _pkd_, _rẹ́k, rfol_, --, 
   {{0x7a040024,0x25a4045f,0x1b18015b,0xe72801c6}},	//   dėty, sfol_, _ধরতে_, _богд_, 
   {{0x26c804ac,0x6d54b2a2,0x7e64b2a3,0x25a4002d}},	//   _urbo_, _ogya, _čipo, pfol_, 
   {{0x6d54b2a4,0xda78008f,0x24540214,0x78ac00e5}},	//   _ngya, אנקר, _هنرس, _önvé, 
   {{0x442c016d,0x33f80ba1,0xc10400c6,0x9f5c01f4}},	//   _tkd_, _sèxe_, توظي, yitä_, 
   {{0x6d54b2a5,0x320c0076,0x00000000,0x00000000}},	//   _agya, aiey_, --, --, 
   {{0x9f5c023a,0xdb0401d3,0x8e640014,0x135400ae}},	//   vitä_, ldjö, یمیٰ_, _المخ_, 
   {{0xd7340375,0x65609718,0x00000000,0x00000000}},	//   מטית_, ncoh, --, --, 
   {{0xa1342309,0x904004fb,0x1b880868,0x3c58084c}},	//   _اراش, تنیه, лёво_, ригэ_, 
   {{0x6d54b2a6,0x81b400cc,0x00000000,0x00000000}},	//   _egya, ঞাও_, --, --, 
   {{0xdb140548,0xb4b400e1,0xf8d016d1,0x9f5c005b}},	//   _baxá, _जन्_, सम्प, ritä_, 
   {{0xf1b800da,0xdb140429,0x6d541418,0xf1bc9417}},	//   toši_, _caxá, _ggya, ्ययन, 
   {{0xd8380323,0x9c84009f,0x00000000,0x00000000}},	// [e530] гэж_, _اشبه, --, --, 
   {{0xf1b8b2a7,0x3a2801f5,0x799c02d0,0xdb041577}},	//   roši_, soap_, _wcsw, tejä, 
   {{0x76b8b2a8,0x255c01f2,0xf1b8b2a7,0x799c02d0}},	//   рлер_, _ịla_, soši_, _tcsw, 
   {{0x67f002d2,0x836400d1,0xc958022e,0x00000000}},	//   _jæjj, ۋدىل, _гўр_, --, 
   {{0x78bc0076,0xdb0426bb,0xba1800ec,0xd508b2a9}},	//   _ussv, sejä, _ميگا_, دغان_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6560009a,0x41c4af6c,0x46a4014b,0x00000000}},	//   bcoh, वयंस, _наёв, --, 
   {{0xca1c0046,0x43840145,0x3494014b,0xf06401f4}},	//   ﺴﻘﺎ_, قلۇق, _мабр, окип, 
   {{0x320c0295,0x6d5400b8,0xd3a400d8,0x00000000}},	//   riey_, _rgya, _греп, --, 
   {{0x70a84ca3,0x00000000,0x00000000,0x00000000}},	//   _कहील, --, --, --, 
   {{0xa3b4033f,0x0a3c001f,0xc60c0154,0x00000000}},	//   ज़र_, _በብሔራ, ষকরা_, --, 
   {{0xddc80118,0x30740798,0x00000000,0x00000000}},	//   _kufř, _дукс, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x92d802f5,0x6d540334,0x00000000,0x00000000}},	//   ডনী_, _wgya, --, --, 
   {{0xada444a5,0x00000000,0x00000000,0x00000000}},	//   _дайл, --, --, --, 
   {{0x6d54066d,0x09d80729,0x1e6404d3,0xcfb803d4}},	//   _ugya, সস্থ, _بخوێ, _অচিন, 
   {{0xe80801f0,0x18a001a9,0x6c341095,0x00000000}},	// [e540] анад_, матм, _وفعا, --, 
   {{0x9cb05311,0xda080490,0x00000000,0x00000000}},	//   _کمیت, सोबत_, --, --, 
   {{0x569000d6,0x7c6403b6,0x00000000,0x00000000}},	//   даєт, _وایل, --, --, 
   {{0x26dc00db,0x00000000,0x00000000,0x00000000}},	//   _àtom_, --, --, --, 
   {{0x64b40517,0xa3b41533,0xdb04002d,0x65600023}},	//   تحار, ज़ल_, kejû, rcoh, 
   {{0x65600558,0xdb04002d,0xf8c001e0,0x00000000}},	//   scoh, jejû, _яҡуп, --, 
   {{0xaac81223,0x00000000,0x00000000,0x00000000}},	//   ाटिक, --, --, --, 
   {{0x7cf00248,0xc0c40139,0xd6240064,0x00000000}},	//   _jórú, зәки, _досе_, --, 
   {{0xf1b8005f,0xd4643756,0x00000000,0x00000000}},	//   jošu_, _мите_, --, --, 
   {{0x7cf00cad,0x20080ba1,0xf1b800e2,0x9f5c0419}},	//   _lórú, òbi_, došu_, litú_, 
   {{0x2bdc3f55,0x291c013f,0x232801a9,0x00000000}},	//   माना, _ɛtaa_, _тожи_, --, 
   {{0x729c0023,0x9f5c00d7,0x00000000,0x00000000}},	//   _ወርቃዊ_, nitú_, --, --, 
   {{0xd24cb184,0xf1b80171,0x00000000,0x00000000}},	//   _شنه_, gošu_, --, --, 
   {{0x386c08a9,0x00000000,0x00000000,0x00000000}},	//   _çeri_, --, --, --, 
   {{0xbb301884,0x99d4027d,0x3db400cc,0x00000000}},	//   ﺭﯨﻢ_, يترا, য়াবল, --, 
   {{0x628c01bf,0xfd7400fb,0x9f5c00d7,0xf1b800ef}},	//   _åbou, _элиэ, jitú_, bošu_, 
   {{0xd7d804ce,0x2e300008,0xf1bc2bf1,0xf1b800ef}},	// [e550] _avメ_, gáfu_, ्यतन, cošu_, 
   {{0xdb1403be,0x00000000,0x00000000,0x00000000}},	//   _naxç, --, --, --, 
   {{0x35b49cff,0x394c04d4,0x7cf00241,0x5a440105}},	//   збер, _ºeso_, _fórú, _мэма, 
   {{0x7bc4b2aa,0xf31401c6,0xa2cc0243,0x63a8002f}},	//   _hahu, үддэ, थिन्, effn, 
   {{0x7bc4b2ab,0x74a84990,0x70a800af,0xdb145043}},	//   _kahu, ссең_, _कहेल, _baxç, 
   {{0x7bc4b2ac,0x395828b5,0x2bdc102f,0x00000000}},	//   _jahu, _hgss_, माया, --, 
   {{0xa8000005,0x4bfc010f,0x9f5c00d7,0x00000000}},	//   éñen, שלוס, bitú_, --, 
   {{0x7bc4b2ad,0xf1b80010,0x98dc00bc,0x00000000}},	//   _lahu, jošt_, _नपाए, --, 
   {{0x3494b2ae,0xdb040b21,0x942003cc,0x7bc403ac}},	//   _хазр, tejû, _قورۇ, _oahu, 
   {{0xaf0406bb,0x339402dd,0x5fd001f9,0x00000000}},	//   зпол, _ءلاز, तागल, --, 
   {{0x2cb00ac8,0x00000000,0x00000000,0x00000000}},	//   _spyd_, --, --, --, 
   {{0x7bc4028c,0xf1b8005f,0xd5ac02dd,0x24900153}},	//   _aahu, tošu_, есi_, šyme_, 
   {{0x7bc4b2af,0xf1b81a48,0x200000b0,0xed5801d5}},	//   _bahu, meš_, ūkia_, _қоп_, 
   {{0x7bc42b1d,0xf1b8b2b0,0x409401ec,0xbfc4003b}},	//   _cahu, leš_, _іріт, _обік, 
   {{0x7bc4b2b1,0xeb3404a2,0x2bdc2c30,0x7cf00332}},	//   _dahu, سىرد, माबा, _pórú, 
   {{0x9e3000f0,0x00000000,0x00000000,0x00000000}},	//   _пејч, --, --, --, 
   {{0x2d80b2b2,0x7bc40093,0x2cb04a29,0x6b88002d}},	// [e560] make_, _fahu, _upyd_, _ôfgo, 
   {{0x7bc4b2b3,0x2d80b2b4,0x9ce400dd,0x00000000}},	//   _gahu, lake_, _روپے_, --, 
   {{0xf1bcb2b5,0x7e64b2b6,0xbb30005e,0x2d8000b0}},	//   ्यान, _čipk, ﺭﯨﻦ_, oake_, 
   {{0x7bc4b2b7,0x317cb2b8,0x776401ab,0xdd100066}},	//   _zahu, _newz_, achx, _آویخ, 
   {{0xf1b83ebb,0x6d58012d,0x989401af,0xc7b000e5}},	//   deš_, śtaw, _нурә, _لڑا_, 
   {{0x69c4b2b9,0x2d80b2ba,0x18643b7e,0x7bc4b2bb}},	//   _hake, hake_, _хари_, _xahu, 
   {{0x2d801060,0xf1b800e2,0x26dca75a,0xd7040354}},	//   kake_, jošs_, _çto_, _енре_, 
   {{0x69c4b2bc,0x64a4b2bd,0x7ae003fa,0xf1b8b2be}},	//   _jake, _наба, älti, geš_, 
   {{0x2d80b2bf,0x69c4b2c0,0xdb2001a8,0xdb1406be}},	//   dake_, _make, _þrön, _taxç, 
   {{0x248401a4,0x69c4b2c1,0x67f002d2,0x26100073}},	//   msom_, _lake, _bæji, _दगडी_, 
   {{0x69c4b2c2,0x7bc4b2c3,0x2d802747,0xf1b8b2c4}},	//   _oake, _rahu, fake_, beš_, 
   {{0x7bc4b2c5,0x21a40364,0xf1b82195,0x69c43af1}},	//   _sahu, _хидм, ceš_, _nake, 
   {{0x24840134,0x6448b2c6,0x225c0309,0xe0442519}},	//   nsom_, omfi, _hutk_, _енди, 
   {{0x60c0b2c7,0x69c4011f,0x7bc40113,0x6448007f}},	//   _isom, _aake, _qahu, nmfi, 
   {{0x69c4b2c8,0x2b5826b7,0x7bc4b2c9,0xbe2401b9}},	//   _bake, _dgpc_, _vahu, _очиқ, 
   {{0x2d80b2ca,0x7bc4b2cb,0x9f5cb2cc,0x7e482832}},	//   cake_, _wahu, vitù_, _بستہ_, 
   {{0x7bc4b2cd,0xbd44082e,0x225cb2ce,0x60c00009}},	// [e570] _tahu, _تنظي, _lutk_, _jsom, 
   {{0xd6d88374,0x60c0b2cf,0x2bdc2435,0x7bc40798}},	//   йте_, _msom, माणा, _uahu, 
   {{0x95b00348,0x39580077,0x629c004e,0x5fac92c1}},	//   ерлә, _tgss_, àpol, ज्यल, 
   {{0x69c43dd4,0x60c0b2d0,0x64480472,0x00000000}},	//   _gake, _osom, emfi, --, 
   {{0xd83805f5,0x60c0b2d1,0xf1b81a48,0x8cd08bb5}},	//   _гэв_, _nsom, veš_, दियो, 
   {{0x2d80b2d2,0x69c40936,0x628400b0,0xaeb4031c}},	//   zake_, _zake, _ākor, _ཐགཅོ, 
   {{0x60c0013b,0x69c4b2d3,0x2d80b2d4,0x2bdc1a4e}},	//   _asom, _yake, yake_, माता, 
   {{0x200cb2d5,0x2d800117,0x69c4b2d6,0x2d240023}},	//   _amfi_, xake_, _xake, ተራእየ, 
   {{0xf1b80fb7,0x2d80b2d7,0x60c000dd,0x14740150}},	//   reš_, vake_, _csom, _ءارج, 
   {{0x2d8000b2,0xf1b800e2,0x7f740006,0x00000000}},	//   wake_, tošs_, нуюц, --, 
   {{0x2d80b2d8,0x60c05b88,0xb8e8025c,0x9f5c023a}},	//   take_, _esom, _ྲག_, yntö_, 
   {{0x5184b2d9,0x81d40064,0x00000000,0x00000000}},	//   _хужа, _пціц, --, --, 
   {{0x2d80b2da,0x69c4b2db,0x00000000,0x00000000}},	//   rake_, _rake, --, --, 
   {{0x69c4b2dc,0xe51c033f,0x9f5c00c7,0xa3000432}},	//   _sake, बपति_, mitÿ_, _öōün, 
   {{0x2d80b2dd,0x1bfc00c5,0xdb0c0241,0x248400d7}},	//   pake_, _उतरल_, _ìdìm, zsom_, 
   {{0x69c401ee,0xe8f873e6,0xa2cc0b7c,0x26dc0129}},	//   _qake, олб_, थित्, _àtoi_, 
   {{0x69c4b2de,0x7e646b48,0xb894005b,0x2bdc00cd}},	// [e580] _vake, _čipi, ерхъ, मादा, 
   {{0x69c4b2df,0x6eb02f36,0x00000000,0x00000000}},	//   _wake, _जहाँ, --, --, 
   {{0x69c4b2e0,0x248403cb,0xe5c44316,0x00000000}},	//   _take, wsom_, дсло, --, 
   {{0x2484b2e1,0x9f5c0023,0x69c4b2e2,0x00000000}},	//   tsom_, thtë_, _uake, --, 
   {{0x284800d8,0x3a240022,0x7ae0007c,0x00000000}},	//   _мзмп_, élpe_, ältv, --, 
   {{0x2484b2e3,0xd36c16cb,0x6448b2e4,0x4de400cc}},	//   rsom_, لهه_, umfi, মসিং, 
   {{0x9f5c069c,0x96607863,0x2484b2e5,0x64480334}},	//   shtë_, _аксе, ssom_, rmfi, 
   {{0x78a80356,0x00000000,0x00000000,0x00000000}},	//   _ţevi, --, --, --, 
   {{0x66000810,0x00000000,0x00000000,0x00000000}},	//   mhok, --, --, --, 
   {{0x660058a1,0x44380f33,0x60c00009,0xefd80023}},	//   lhok, _ór_, _vsom, ሮጳዊ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x66000099,0x00000000,0x00000000,0x00000000}},	//   nhok, --, --, --, 
   {{0x6600b2e6,0x7f9401c6,0xd09000c7,0x9fe400ae}},	//   ihok, _залх, _ҧшәы, _يسته, 
   {{0x200cb2e7,0x6600014b,0xfb340166,0x80bc01f9}},	//   _umfi_, hhok, енгэ, ्टीं, 
   {{0x66002747,0x62a00232,0xa3e41715,0x201c04ba}},	//   khok, _útoč, _बचन_, mnti_, 
   {{0x99cc03d4,0x5e24007b,0x00000000,0x00000000}},	//   ৰস্ক, _تعتق, --, --, 
   {{0x6600b2e8,0xdcfc00e2,0xdd9002dd,0x9c44292c}},	// [e590] dhok, āvēj, _зақы, _охол, 
   {{0x201c0008,0x9ba02f7c,0x19540417,0x8d7400d1}},	//   nnti_, _جەسى, зағы_, _كاۋا, 
   {{0xa3e010fa,0x201c049b,0x3dc800e8,0xdbc801e1}},	//   धान_, inti_, _kaaw_, _fòòb, 
   {{0x3dc80009,0x2244004d,0x00000000,0x00000000}},	//   _jaaw_, _nhok_, --, --, 
   {{0xd7f8086f,0xc864014b,0x00000000,0x00000000}},	//   _дув_, _атси, --, --, 
   {{0x224404a4,0x727800f3,0x67f008a5,0x00000000}},	//   _ahok_, псис_, _bæju, --, 
   {{0xc6a41086,0x00000000,0x00000000,0x00000000}},	//   _ирти, --, --, --, 
   {{0x6600b2e9,0x201cb2ea,0x2244b2eb,0x3dc81bce}},	//   chok, enti_, _chok_, _naaw_, 
   {{0x6f140589,0xfa0c004d,0x00000000,0x00000000}},	//   ºzco, _đấu_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb8d01b4b,0xc2c4a9f3,0x6da4b2ec,0xe3e46449}},	//   _དད_, _ليلي, нина, _سکون_, 
   {{0x201cb2ed,0x28d001ad,0x6fa001f9,0x00000000}},	//   anti_, सिमि, _खावू, --, 
   {{0x3dc88fea,0x30c80150,0x9f5c0306,0x00000000}},	//   _daaw_, _ءوتپ_, litý_, --, 
   {{0x3cec00af,0xa3e000dc,0x5fa40490,0x6600004c}},	//   äeva_, धाय_, _खायल, zhok, 
   {{0x3dc8226d,0x9f5c0306,0x18b00131,0xbb3000d1}},	//   _faaw_, nitý_, һәрр, ﺭﯨﻲ_, 
   {{0x3dc80694,0xb8648207,0x66000fec,0x00000000}},	//   _gaaw_, چالو, xhok, --, 
   {{0xb86400aa,0xdb140077,0x2794b2ee,0xa924030d}},	// [e5a0] نالو, _xaxú, ешер, хдал, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9f5c0306,0x2c54013a,0x00000000,0x00000000}},	//   jitý_, _vědě_, --, --, 
   {{0xf5380038,0xf60839b1,0xe4a45716,0x9f5c02f0}},	//   _byť_, وتنه_, ерко, ditý_, 
   {{0x6600b2ef,0x224402c4,0x201cb2f0,0x42bc0154}},	//   rhok, _rhok_, ynti_, _অপেশ, 
   {{0x66001cbd,0x224446c8,0x68f4023a,0x67f0032e}},	//   shok, _shok_, myyd, _pæju, 
   {{0x5330506f,0x6600b2f1,0x26dc00f3,0x27f800b5}},	//   лешт, phok, _štof_, mkpn_, 
   {{0x66001db4,0x201c0e14,0x00000000,0x00000000}},	//   qhok, wnti_, --, --, 
   {{0x80bc05ba,0x3dc8198f,0x2c64015d,0x68f4005b}},	//   ्टें, _raaw_, _nôd_, nyyd, 
   {{0x201cb2f2,0xa2e4b2f3,0x3dc8002e,0x9f5c02fb}},	//   unti_, _позд, _saaw_, bitý_, 
   {{0x2244b2f4,0x6458b2f5,0x201c0194,0x68f40108}},	//   _thok_, _iiti, rnti_, hyyd, 
   {{0x62881088,0x68f4023a,0x443c343a,0xf1a83cc6}},	//   msfo, kyyd, llv_, _يانه_, 
   {{0x6458b2f6,0xc0bc044e,0x62885f03,0x2c6403cb}},	//   _kiti, ታቶም_, lsfo, _côd_, 
   {{0x6458b2f7,0x3dc80694,0x4e9001d5,0x443c0051}},	//   _jiti, _waaw_, خشیر, nlv_, 
   {{0x3dc80de2,0x80c80210,0x8fa0009b,0x00000000}},	//   _taaw_, ़िके, _саје, --, 
   {{0x64581fd8,0x00000000,0x00000000,0x00000000}},	//   _liti, --, --, --, 
   {{0xc0dc044e,0x6458b2f8,0xb9540801,0x2c640042}},	// [e5b0] _ንግሆ_, _oiti, тващ, _gôd_, 
   {{0x6288b2f9,0x57242f7c,0x9f5c0407,0x7ae03bba}},	//   ksfo, ىراق, mitó_, älts, 
   {{0x9f5c3eba,0x2bdc08e6,0x79940022,0xe514000d}},	//   litó_, मारा, _иинф, _देबि_, 
   {{0x6458b2fa,0x62881088,0x9f5c02fb,0x443c0158}},	//   _aiti, dsfo, vitý_, elv_, 
   {{0x494401dd,0x69a45d9c,0x80bc0073,0xefdc0023}},	//   _бэрб, _छाती, ्टों, _ንሽዑ_, 
   {{0x7414a638,0x6458b2fb,0x78ac2611,0x62881308}},	//   ضوعا, _citi, mtav, fsfo, 
   {{0x6458b2fc,0x78acb2fd,0x78b001a6,0x23240cb6}},	//   _diti, ltav, ževč, коши_, 
   {{0x645800c6,0x78ac011c,0xdb04b2fe,0xd12c01d9}},	//   _eiti, otav, lejó, یمژ_, 
   {{0x6458b2ff,0xa614035b,0xb144130f,0xafe414b3}},	//   _fiti, _рзтә, ънил, вопл, 
   {{0x6e34b300,0x6458b301,0x62886688,0x9f5c0789}},	//   _skyb, _giti, bsfo, ditó_, 
   {{0x78acb302,0x764801d9,0x6b88002d,0xa3e407af}},	//   htav, _khey, _ôfgi, _बचत_, 
   {{0x78acb303,0x64580e78,0xb11404b4,0xe7cc0073}},	//   ktav, _ziti, _имеш, _होईप, 
   {{0x78ac02d3,0x6458b304,0x2bdcb305,0x3cfc012c}},	//   jtav, _yiti, माला, रैले_, 
   {{0x645807a9,0x68f4023a,0x2c6400d0,0x00000000}},	//   _xiti, vyyd, _vôd_, --, 
   {{0xa3e00490,0x248c1772,0x7648037e,0x78acb306}},	//   धात_, _ነፍሳት_, _ohey, etav, 
   {{0x7648b307,0x78ac09e8,0x47c8004b,0x68f4005b}},	//   _nhey, ftav, کارۍ_, tyyd, 
   {{0x9f5c09d7,0x5fac043e,0x443c0162,0x45d41c34}},	// [e5c0] citó_, ज्वल, ylv_, ғолс, 
   {{0x76480050,0x9f5c0268,0xdc9808a8,0x443c003a}},	//   _ahey, litò_, _קייל, xlv_, 
   {{0x6458b308,0x76480099,0x68f402f6,0x78acb309}},	//   _riti, _bhey, syyd, atav, 
   {{0x7648b30a,0x628812ed,0x78acb30b,0x7ae0072b}},	//   _chey, vsfo, btav, ålte, 
   {{0x6458b30c,0x78acb30d,0x7648b30e,0xd464010b}},	//   _piti, ctav, _dhey, виче_, 
   {{0x6458b30f,0x24900006,0xa2cc0b98,0x76486607}},	//   _qiti, šymo_, थिल्, _ehey, 
   {{0x6458b310,0xe73803fb,0x628804e6,0x00000000}},	//   _viti, _цев_, usfo, --, 
   {{0x2d90b311,0x6288b312,0x6458b313,0x76480363}},	//   _ndye_, rsfo, _witi, _ghey, 
   {{0x6458b314,0x62881f53,0xd24c0131,0x63840209}},	//   _titi, ssfo, ڭچە_, _агза, 
   {{0x6458b315,0x2d90b316,0x6288143a,0x9f5c00eb}},	//   _uiti, _adye_, psfo, vitó_, 
   {{0x233400c7,0xd24c0798,0x00000000,0x00000000}},	//   _рхар, _вц_, --, --, 
   {{0xdb044baa,0x78acb317,0xdf50001f,0x9f5c9347}},	//   zejó, ytav, _መናፍቃ, titó_, 
   {{0xa3e40c2e,0x78acb318,0x10a013b5,0xfa240124}},	//   _बचा_, xtav, _вичн, ҳчаҟ, 
   {{0x3ed4007b,0x00000000,0x00000000,0x00000000}},	//   _مقتر, --, --, --, 
   {{0x9f5cb319,0xdb1c00a2,0x6b9803b2,0x00000000}},	//   sitó_, _öwüd, ótga, --, 
   {{0x78acb31a,0x0f540302,0x9f5c0093,0xdb04032e}},	//   ttav, _ביום_, pitó_, gfjá, 
   {{0xc4c4b31b,0xc984b31c,0x76480731,0x00000000}},	// [e5d0] _بے_, руси, _rhey, --, 
   {{0x78acb31d,0x7648b31e,0x48243ee0,0x8cd02144}},	//   rtav, _shey, لىقق, दिरो, 
   {{0xcf9004ac,0xa3d41d34,0x7c344be9,0x19e000c7}},	//   שטע_, ियन_, mozr, _кәаҳ, 
   {{0x78acb31f,0x7c3402fb,0xc9580131,0xf1d001ad}},	//   ptav, lozr, رلەش_, _दोंन, 
   {{0x78ac0d04,0xc4c4b320,0x644400c0,0x57a4014b}},	//   qtav, لتوو, _ūkia, _ишва, 
   {{0x764800d8,0x38680200,0x00000000,0x00000000}},	//   _whey, mqar_, --, --, 
   {{0x7648b321,0x32340408,0x629001e1,0x38680f77}},	//   _they, лхис, _àfò, lqar_, 
   {{0x7648b322,0x932403e6,0xd5840133,0x00000000}},	//   _uhey, _یران, _شێته_, --, 
   {{0x9f5c011c,0xd3a40124,0x93a40022,0x7c340306}},	//   vitò_, _ареп, _ашед, kozr, 
   {{0x7068069c,0x69d801ad,0x3a3800ef,0x09e000cd}},	//   _ተባሂሉ_, _पोनी, _lksp_, _पच्य, 
   {{0x7c340030,0xdb040fac,0x00000000,0x00000000}},	//   dozr, lfjæ, --, --, 
   {{0xfbc802e4,0xf3f0004d,0xd24c1e2f,0x3e680129}},	//   _מת_, _họ_, _بچت_, _dût_, 
   {{0x9f5cb323,0x3e686c80,0x8c0400ee,0x6fd400d4}},	//   ritò_, _eût_, иҗил, _бійц, 
   {{0x3e68004a,0x3c900220,0x28d03f7e,0x00000000}},	//   _fût_, _ﺑﻪﺗﻰ_, सिसि, --, 
   {{0x9f5c5bd9,0x99840e3c,0xf3f001e1,0x7ae0007c}},	//   pitò_, _šiša_, _mọ_, ältp, 
   {{0x316cb324,0x2d905b9a,0xf3f00241,0x00000000}},	//   ncez_, _udye_, _lọ_, --, 
   {{0xa3d428d4,0x7c3403da,0x00000000,0x00000000}},	// [e5e0] ियम_, bozr, --, --, 
   {{0x3a38220a,0x66e4b325,0xe78400db,0x00000000}},	//   _eksp_, лоза, الاپ, --, 
   {{0x9f500086,0x3a3801ef,0x00000000,0x00000000}},	//   _ùdôn_, _fksp_, --, --, 
   {{0x1f34008f,0x2a08569f,0x00000000,0x00000000}},	//   ארער_, _чемп_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9f4c007f,0x00000000,0x00000000,0x00000000}},	//   _fofè_, --, --, --, 
   {{0xa44402dd,0xd9f862a8,0x00000000,0x00000000}},	//   _ұнад, _एकमत_, --, --, 
   {{0x98a4033f,0x00000000,0x00000000,0x00000000}},	//   łną_, --, --, --, 
   {{0x15400006,0xa4448083,0xe2e401ec,0x00000000}},	//   _гетм, _бнад, _әжеп, --, 
   {{0x25a41c06,0x845000db,0x3e680129,0x035401ee}},	//   lgol_, _بۉتچ, _pût_, _күлә_, 
   {{0xd36c3df2,0x20540145,0xe0440022,0x7c3400d7}},	//   _رهن_, ктүр, _ҩнеи, vozr, 
   {{0x25a4b326,0xd12cb327,0xa068b328,0x9cc80733}},	//   ngol_, _کمه_, _зада_, ныга_, 
   {{0x7c3400d0,0xa074013d,0xf3f001e1,0x00000000}},	//   tozr, _сыеш, _yọ_, --, 
   {{0x69d8013f,0x3a740395,0x00000000,0x00000000}},	//   _ɔtee, илгр, --, --, 
   {{0x3a380175,0x38680986,0xda48005b,0x705000f1}},	//   _pksp_, wqar_, ечал_, _بچيا, 
   {{0x7cd8b329,0x5ec80154,0xb4f801ad,0xb924007b}},	//   _амир_, িমদে, ्नमय_, لفزي, 
   {{0xb8140640,0x22ac03e3,0x7c340419,0x00000000}},	// [e5f0] адај, _dəki_, pozr, --, 
   {{0xb8dc0882,0x64440006,0x7b14023a,0xf6780014}},	//   _आह_, _ūkin, _вдох, ٖماب_, 
   {{0x05740133,0x316c0205,0x00000000,0x00000000}},	//   ڵاند, ycez_, --, --, 
   {{0x8f340bd9,0xdb14014a,0xbbc478bf,0x06982c10}},	//   נטאג_, _maxü, _लघुक, اخلت_, 
   {{0x53b457aa,0x3868002e,0x26c8a9cc,0x74a80150}},	//   лғар_, qqar_, _esbo_, тсең_, 
   {{0x25a40036,0xb2940063,0x22ac06be,0x729410e4}},	//   agol_, ајић, _zəki_, аших, 
   {{0xd5b8361e,0xdb040158,0xf3f803d4,0xefd80092}},	//   _пса_, sfjæ, ্চলৰ_, ዮታዊ_, 
   {{0xe5143996,0xf484b32a,0x29240309,0x95c80166}},	//   _देवि_, _نائی, šqaš_, _яуга_, 
   {{0x3ebc007f,0x316cb32b,0x300401d5,0xdb0401e3}},	//   _apvt_, rcez_, изиг, lfjä, 
   {{0x6ff401c0,0x44f4b32c,0x78bc00d7,0x00000000}},	//   рчих, _упус, _mpsv, --, 
   {{0xa3e03d1d,0xdb043b52,0xf1d001af,0xee24119e}},	//   धार_, nfjä, _дөпө, имоп, 
   {{0x6da40131,0x78bc00b5,0xa28001d3,0x00000000}},	//   шима, _opsv, _بیٹو, --, 
   {{0xafe4b32d,0xc174010b,0xcc880133,0xd17001ee}},	//   _волл, _уҗы_, دۆخه_, _кыҙы, 
   {{0xab28b32e,0x22ac06be,0xdb04007c,0x1b1400eb}},	//   вога_, _səki_, kfjä, _দুধে_, 
   {{0x78bc1494,0x25a40368,0xa3d4228d,0x7c28020c}},	//   _apsv, ygol_, ियत_, éera, 
   {{0x6924b32f,0xf1bc5168,0xd7d8037e,0xdb04007c}},	//   амба, ्यटन, _stバ_, dfjä, 
   {{0x1864013e,0xe85401d5,0x5e54010f,0xe7a80395}},	// [e600] иати_, لنرد, _דיקע_, квал_, 
   {{0x6a8403fb,0x078800db,0x00000000,0x00000000}},	//   _клоа, اماۋ_, --, --, 
   {{0xdb0401e3,0x22ac03e3,0x64440064,0x69d80b4c}},	//   gfjä, _təki_, _ūkio, _पोथी, 
   {{0xe6180801,0x2bdc0882,0x85080032,0x00000000}},	//   ъде_, माका, лдең_, --, 
   {{0x25a400db,0x6e2401d3,0x23e05b29,0xa3e001f9}},	//   rgol_, inkb, पालद, धाल_, 
   {{0x25a400a9,0x2b4c0332,0x386c01e1,0x9cd4011a}},	//   sgol_, _úfcs_, _éera_, יונה_, 
   {{0x44200b91,0x3f982833,0x26c80117,0x00000000}},	//   đi_, órum_, _usbo_, --, 
   {{0x1a98008f,0x00000000,0x00000000,0x00000000}},	//   דיקע, --, --, --, 
   {{0xa3ac0073,0xf1bc1a55,0x00000000,0x00000000}},	//   _काप_, ्यजन, --, --, 
   {{0xdef82ecc,0x6abc1a82,0xdfd87075,0xd3e40451}},	//   вым_, _oppf, тъи_, _پڙهو_, 
   {{0x629c0077,0x2bc807b7,0x00000000,0x00000000}},	//   ápod, ाजना, --, --, 
   {{0xf1a8b330,0xfe780024,0x91e001f4,0x00000000}},	//   _ماهه_, rpį_, _мохе, --, 
   {{0x61e0b331,0xb0640209,0x28c4012d,0x00000000}},	//   _inol, rnäç, _रैलि, --, 
   {{0x212000d2,0x103000cf,0xd00400f3,0x2bdc024a}},	//   ûkhu_, _وعوج, _веље_, मागा, 
   {{0xa3ac4d53,0x61e00a40,0x3f8cb332,0x19a81e49}},	//   _कान_, _knol, madu_, ктап_, 
   {{0x3f8cb333,0xdb140005,0xb5fc0024,0x8e70072d}},	//   ladu_, _saxó, _kiše, _باوض, 
   {{0xa3d4b334,0x58849219,0x22580118,0x752c025c}},	// [e610] िया_, рыба, ípky_, żazz, 
   {{0xf1b8000a,0x3f8cb335,0xdb040200,0x00000000}},	//   miše_, nadu_, ngjë, --, 
   {{0xb5fc0e3c,0xf1b838bb,0xe7a80116,0x00000000}},	//   _liše, liše_, اپمۇ_, --, 
   {{0x3f8c7809,0x6b88045f,0xdb0401e3,0xf9c41291}},	//   hadu_, _ôfgr, rfjä, _احدی, 
   {{0xf1b838bb,0xdb140077,0x798cb336,0xb8e801d9}},	//   niše_, _taxó, maaw, _صبحے_, 
   {{0x798cb337,0x61e0b338,0x83640075,0x00000000}},	//   laaw, _anol, يدىل, --, 
   {{0x3f8cb339,0x870447f9,0xe294010b,0xf1b80010}},	//   dadu_, _дяте, бащ_, hiše_, 
   {{0x798cb33a,0xb5fc17a3,0xdb040200,0xb7e800fe}},	//   naaw, _biše, egjë, _গতিত_, 
   {{0x83fc00f3,0x3f8cb33b,0x63ac0200,0x00000000}},	//   _siđe, fadu_, çinë, --, 
   {{0xa3ac2413,0xf1b82fba,0x6004b33c,0xb5fc15ad}},	//   _काय_, diše_, йным_, _diše, 
   {{0xb8e803bd,0x798cb33d,0x262800df,0xa1440171}},	//   _ིག_, kaaw, iĝon_, _apķī, 
   {{0xb5fcb33e,0x83fc0989,0x3254b33f,0x2d9c03fa}},	//   _fiše, _viđe, _увер, ßte_, 
   {{0xa3acb340,0x798c852e,0x3f8cb341,0xed3401c0}},	//   _काम_, daaw, badu_, сэнэ, 
   {{0x2d9cb342,0x3f8cb343,0x6a8401c0,0x00000000}},	//   şte_, cadu_, йлга, --, 
   {{0xdb1456eb,0x798c1559,0x6994b344,0xdb040254}},	//   _saxò, faaw, йрах, kejõ, 
   {{0xf1b8000a,0x798c198f,0xaf6c0092,0x00000000}},	//   biše_, gaaw, _አበባና_, --, 
   {{0xc044001e,0xf1b801fa,0x81b400fe,0x9d500220}},	// [e620] _đoạt_, ciše_, _ছোঁ_, _ىنىت, 
   {{0x2fc402b5,0x00000000,0x00000000,0x00000000}},	//   nelg_, --, --, --, 
   {{0x6abcb345,0x798cb346,0xa3d409b2,0x00000000}},	//   _uppf, baaw, ियस_, --, 
   {{0xe5a404a9,0x3f8c0122,0x6b8cb347,0x2fc478d0}},	//   сиди, zadu_, labg, helg_, 
   {{0x3f8cb348,0x64983d6c,0x00000000,0x00000000}},	//   yadu_, утер_, --, --, 
   {{0x2fc405ac,0xb5fc0427,0x6b8c0112,0x3f8c058a}},	//   jelg_, _riše, nabg, xadu_, 
   {{0x3f8cb349,0x2fc4017a,0xa3ac5373,0x00000000}},	//   vadu_, delg_, _काठ_, --, 
   {{0xd04803b9,0x3f8cb34a,0x00000000,0x00000000}},	//   _irgə, wadu_, --, --, 
   {{0x66000e90,0x3f8cb34b,0xbb1800d1,0x00000000}},	//   mkok, tadu_, ﻳﺎﻝ_, --, 
   {{0xb5fc0bb8,0xf1b804b9,0xa0a400c2,0x69d8013f}},	//   _više, više_, _ҳадд, _ɔtea, 
   {{0xa040044e,0xdef8774d,0x6600b34c,0xdb040023}},	//   _ርእይቶ, уып_, okok, rgjë, 
   {{0x61e0b34d,0x442c00ca,0xf1b808a4,0x224801d5}},	//   _unol, _hjd_, tiše_, _ёпди_, 
   {{0xddd81d64,0x33f81497,0x7f94b34e,0x798c0a49}},	//   lptū, _tèxt_, _далх, vaaw, 
   {{0xf1b80384,0x798cb34f,0x46c80316,0x20541768}},	//   riše_, waaw, रबाह, _утер, 
   {{0x6600b350,0x798cb351,0x9f4c0270,0xd7f80224}},	//   kkok, taaw, _kofí_, қуа_, 
   {{0x201cb352,0x442c0064,0xada00162,0x00000000}},	//   liti_, _ljd_, ðútb, --, 
   {{0x798cb353,0x442c1184,0x66000427,0x9de401d9}},	// [e630] raaw, _ojd_, dkok, _نفژٕ_, 
   {{0x798c2252,0x66000085,0x9f5c007f,0x00000000}},	//   saaw, ekok, tktè_, --, 
   {{0xb4e00a28,0x798c1c06,0x7bd4090c,0x6600b354}},	//   धम्_, paaw, mdzu, fkok, 
   {{0x201cb355,0x7bd4b356,0xd1cc044e,0x442c05ce}},	//   hiti_, ldzu, እታት_, _ajd_, 
   {{0x201cb357,0xd498b358,0x2bdc2802,0xdb040254}},	//   kiti_, уре_, माचा, rejõ, 
   {{0x201c094a,0x7bd40c11,0x3a2801ed,0xd75800f2}},	//   jiti_, ndzu, lnap_, _مجزا_, 
   {{0x66000198,0xdb0400c5,0x4bfc010f,0x2fc40254}},	//   bkok, pejõ, רלוס, velg_, 
   {{0x3a28b359,0x442c020c,0xb9e402d3,0x6600b35a}},	//   nnap_, _ejd_, _ራኢ_, ckok, 
   {{0x201cb35b,0x9f4c00db,0x442c009f,0x3a280140}},	//   fiti_, _dofí_, _fjd_, inap_, 
   {{0x201cb35c,0x6b8c0175,0x7c2800e8,0x00000000}},	//   giti_, xabg, éerl, --, 
   {{0x1cac0489,0xa3d41dd1,0x2fc40a40,0x3a28b35d}},	//   _ནདཔ_, ियर_, relg_, knap_, 
   {{0x201cb35e,0x7bd401f5,0x2fc4000d,0x00000000}},	//   aiti_, edzu, selg_, --, 
   {{0x3a28b35f,0x4174208f,0x7e780254,0x320c047e}},	//   dnap_, _رانس, _etvp, mhey_, 
   {{0x6600b360,0x320c047e,0xbc1802dd,0x00000000}},	//   zkok, lhey_, бісі_, --, 
   {{0x6b8cb361,0x6600b362,0x00000000,0x00000000}},	//   rabg, ykok, --, --, 
   {{0x3a28b363,0x6b8c0112,0x66000784,0x320c014f}},	//   gnap_, sabg, xkok, nhey_, 
   {{0x2bb02068,0xd9400137,0xeb9854d9,0x00000000}},	// [e640] _जापा, дети, _кип_, --, 
   {{0x3a28013c,0x7f8c008f,0x320cb364,0x22ac06be}},	//   anap_, ָנאַ, hhey_, _məkr_, 
   {{0x6674b365,0x66008910,0x00000000,0x00000000}},	//   زدار, tkok, --, --, 
   {{0x201c08ad,0x320c014f,0xdeb800df,0x00000000}},	//   ziti_, jhey_, ימעל, --, 
   {{0x66003142,0x201cb366,0x320cb367,0x442cb368}},	//   rkok, yiti_, dhey_, _pjd_, 
   {{0x201c0054,0x00000000,0x00000000,0x00000000}},	//   xiti_, --, --, --, 
   {{0x7790082a,0x2bb00882,0x69d80134,0xf3f80356}},	//   _سینا, _जाना, _ɔten, _nuţu_, 
   {{0x320c9d34,0x201cb369,0x69d4b36a,0x442c01f5}},	//   ghey_, witi_, ndye, _wjd_, 
   {{0x291004ba,0x239806c2,0x00000000,0x00000000}},	//   nzya_, _نخاع_, --, --, 
   {{0x2d80b36b,0x3f98006a,0x320c0014,0xd9c400af}},	//   ebke_, ûru_, ahey_, _लस्ट, 
   {{0x443cb36c,0xb5fc1fe6,0x320c047e,0x101000db}},	//   mov_, _hiša, bhey_, ببيد, 
   {{0xae143eaf,0x320cb36d,0x6b800114,0x69d81098}},	//   दोलन_, chey_, _đoga, _पोली, 
   {{0xdb040158,0xa3ac000d,0x3a2801d3,0xd2500244}},	//   lfjø, कलप_, vnap_, _تکوژ, 
   {{0x443cb36e,0xf1b81ebd,0x60c01ed9,0x387804cc}},	//   nov_, miša_, _ipom, _rtsr_, 
   {{0x7e9801d9,0xa2a002ab,0xf1b81711,0x7bd4b36f}},	//   _انبر_, _गिफ्, liša_, rdzu, 
   {{0x69d42819,0x9f4c0421,0x00000000,0x00000000}},	//   gdye, _tofâ_, --, --, 
   {{0x443cb370,0xf1b83324,0x3a2800dd,0xb5fc3421}},	// [e650] kov_, niša_, rnap_, _niša, 
   {{0xd6d88a6f,0x443c0038,0x60c0b371,0x3a2801d3}},	//   ите_, jov_, _mpom, snap_, 
   {{0x443cb372,0x76b800ee,0xa3ac00ce,0xc578063f}},	//   dov_, слер_, कलन_, _ịgục, 
   {{0xf1b81ebd,0x83fc0841,0x261447b8,0x00000000}},	//   kiša_, _riđa, पोली_, --, 
   {{0x443cb373,0x2bb00243,0xdb040158,0xa3d400dc}},	//   fov_, _जामा, efjø, ियं_, 
   {{0xf1b80f8b,0x262800c8,0xb5fc09a8,0x83fc01a6}},	//   diša_, nĝoj_, _diša, _piđa, 
   {{0x60c0b374,0x320c047e,0x262800df,0x00000000}},	//   _apom, they_, iĝoj_, --, 
   {{0x83fc05ce,0x5f280023,0x00000000,0x00000000}},	//   _viđa, _ብመራኸ, --, --, 
   {{0x443cb375,0x92a8015b,0xf1b88bbb,0x320cb376}},	//   bov_, গবে_, giša_, rhey_, 
   {{0x320cb377,0x443cb378,0xa3d400dc,0x76580042}},	//   shey_, cov_, ियः_, lmwy, 
   {{0xee38b379,0x69d40280,0x60c0003a,0xdfe401c0}},	//   йно_, ydye, _epom, чдэд_, 
   {{0xf1b81ebd,0x32548388,0x320c047e,0x00000000}},	//   biša_, _эвер, qhey_, --, 
   {{0x246c0020,0x3078010f,0x00000000,0x00000000}},	//   ስፖርት_, _פאַנ, --, --, 
   {{0xc104b37a,0xa3acb213,0xa0240108,0x28c4012d}},	//   _توهي, कलय_, rdöö, _रैगि, 
   {{0x60c000bc,0x6dc000db,0xa3acb37b,0x00000000}},	//   _zpom, _كۅدۅ, _कास_, --, 
   {{0x443cb37c,0x291000b5,0xe9d80063,0xda601cd6}},	//   zov_, tzya_, љка_, евси, 
   {{0x69d4b37d,0x443cb37e,0x00000000,0x00000000}},	// [e660] rdye, yov_, --, --, 
   {{0x443cb37f,0xe7380598,0x9d18008f,0xaba807b5}},	//   xov_, без_, _לופט, _увоз_, 
   {{0x443cb380,0x6f0003ac,0x69d400d7,0x00000000}},	//   vov_, nylc, pdye, --, 
   {{0x2bc8b381,0xb5fc07f5,0xa2a001ad,0xa3ac0037}},	//   ाजवा, _piša, _गिब्, _काह_, 
   {{0x443cb382,0xd4e01de1,0xe514b383,0x6f006bba}},	//   tov_, еющи, _देखि_, hylc, 
   {{0xb5fc07f5,0xf1b81aff,0x74680212,0x245000c7}},	//   _viša, viša_, ірів_, kâme_, 
   {{0x443cb382,0x60c0b384,0x9390b385,0x4254b386}},	//   rov_, _spom, رجوا, ونتر, 
   {{0x443cb387,0xf1b8000a,0xb5fc151c,0xdef80032}},	//   sov_, tiša_, _hišn, ҡын_, 
   {{0x443cb388,0x9f4c4286,0x64a4b389,0xb5fc05ce}},	//   pov_, _sofà_, _хаза, _kišn, 
   {{0xf1b80f8b,0xdcec005f,0x443cb38a,0x78680024}},	//   riša_, sacī, qov_, _užve, 
   {{0x6f000cfd,0x26dc01fa,0x234800f7,0xd24c03e6}},	//   gylc, _štoj_, _الاپ_, _ڵنه_, 
   {{0xa2d006e3,0x00000000,0x00000000,0x00000000}},	//   _भैय्, --, --, --, 
   {{0x60c0b38b,0xd84c0051,0x9be4003b,0x00000000}},	//   _upom, _lọan_, півк, --, 
   {{0x2bb00574,0x51580375,0x2054004e,0x6f0015c0}},	//   _जाणा, _הכדו, _этер, bylc, 
   {{0xdb204fdc,0x262800df,0x765803cb,0x00000000}},	//   روری, rĝoj_, ymwy, --, 
   {{0x7f6801ec,0x00000000,0x00000000,0x00000000}},	//   _ﻓﻬل_, --, --, --, 
   {{0x2bc8610a,0x00000000,0x00000000,0x00000000}},	// [e670] ाजशा, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2bb00412,0x35b4b38c,0xb5fc2375,0xba54041b}},	//   _जाता, дбер, _dišn, _овој, 
   {{0x8aa401c0,0xf8b000f1,0x00000000,0x00000000}},	//   _ярьд, _ټکر_, --, --, 
   {{0xa3ac0c2e,0x76580368,0x799c02d0,0x00000000}},	//   _काश_, rmwy, _idsw, --, 
   {{0xb4ac1431,0x76580042,0xc7b80064,0x84140022}},	//   _कमी_, smwy, _нёс_, нмчх, 
   {{0xa3ac09bb,0x629c00d0,0x6f0003ac,0x00000000}},	//   _कार_, špon, xylc, --, 
   {{0xc5ec01b9,0x9f5c00ae,0x45d40108,0x00000000}},	//   _ёғ_, bhtú_, _посс, --, 
   {{0x9f5c0491,0x6608002d,0x799c03ac,0x94201870}},	//   chtú_, êfke, _mdsw, _كورۇ, 
   {{0x9f4cb38d,0xb5fc1b24,0x6b8000f3,0x6f00045a}},	//   _sofá_, _kišo, _đogo, tylc, 
   {{0xada4b38e,0xdcf000b8,0x00000000,0x00000000}},	//   манл, _āgāy, --, --, 
   {{0xf1b827c4,0x3f9c01fa,0x799c02d0,0x6f0002d0}},	//   mišo_, _edvu_, _ndsw, rylc, 
   {{0xd14800db,0x6ff400c6,0x2bb000af,0x2bc800bc}},	//   _اشان_, _يستط, _जादा, ाजला, 
   {{0x799c0857,0x862c0092,0x24500022,0x35840092}},	//   _adsw, ታማነት, pâme_, ርስበት_, 
   {{0x81b400bd,0xa3ac00c5,0xb5fc00c0,0xe0ac0154}},	//   _ছোট_, कलत_, _nišo, কবৃন, 
   {{0x799c03ac,0xf9d407e6,0x00000000,0x00000000}},	//   _cdsw, нцую, --, --, 
   {{0xa3ac0d5f,0x799c03ac,0x6dc00137,0xd84c0208}},	// [e680] _काल_, _ddsw, _كۅگۅ, _sọan_, 
   {{0xf1b80f8b,0x799c03ac,0x83fc04a7,0x1c40005b}},	//   kišo_, _edsw, _riđo, _иным, 
   {{0xb5fc39ae,0xa968b38f,0xa6c800f1,0x00000000}},	//   _višn, _мина_, توال_, --, 
   {{0xf1b80f8b,0xa524b390,0xe52400db,0x00000000}},	//   dišo_, ммед, мдеп, --, 
   {{0x85240014,0xb5fc0118,0x00000000,0x00000000}},	//   رکرٕ, _tišn, --, --, 
   {{0xa3ac0490,0xa2a01428,0x2a6400d7,0xb4b4104e}},	//   _काळ_, _गिद्, _čoby_, хишә, 
   {{0xf1b8000a,0x1864020f,0x53300132,0x00000000}},	//   gišo_, _цари_, кешт, --, 
   {{0x7ae02b96,0x00000000,0x00000000,0x00000000}},	//   ålti, --, --, --, 
   {{0xb5fc1326,0xd0a401c0,0x64440024,0x24500356}},	//   _mišl, мтэд_, _ūkiu, râmb_, 
   {{0xf1b81ebd,0xa5c400b8,0xa2e400f7,0x04c800f1}},	//   bišo_, _duųņ, _оозд, _ووځي_, 
   {{0x630447e7,0x00000000,0x00000000,0x00000000}},	//   _توال, --, --, --, 
   {{0xb5fc0063,0xa068b391,0x00000000,0x00000000}},	//   _nišl, _дада_, --, --, 
   {{0xd7d807ad,0xdfd000c6,0xf3f00051,0x3a2c0166}},	//   _auポ_, _ليش_, _kịp_, _ıep_, 
   {{0xa3ac00c5,0x799c03ac,0x81b00154,0x4fc001a9}},	//   कलि_, _sdsw, _ওসি_, _асъа, 
   {{0xbc90b392,0x394c05be,0x644801e7,0xfee801d5}},	//   _әңгә, _šes_, ilfi, _хулқ_, 
   {{0xb5fc01fa,0x588400db,0x00000000,0x00000000}},	//   _rišo, дыжа, --, --, 
   {{0xa3ac9e3f,0x1b14009e,0xb5fc00ef,0xb4ac00c5}},	// [e690] कला_, _দুখে_, _dišl, _कमे_, 
   {{0x8858a421,0xb5fc1a48,0x6448508f,0x00000000}},	//   диус_, _pišo, jlfi, --, 
   {{0xbb4408b0,0x629c5aa5,0x799c02d0,0xb064013d}},	//   ﯘﺭﻯ_, ápol, _tdsw, liäç, 
   {{0xb5fc07f5,0x64483c68,0x3a2c00e8,0x497402e8}},	//   _višo, elfi, _ñep_, _илюс, 
   {{0x6298b393,0xe00c05ba,0x23180228,0xcc340214}},	//   _avto, िसाद_, үнчө_, _سریع, 
   {{0xf1b80f8b,0xb5fc00d0,0x64480d12,0x3eac005c}},	//   tišo_, _zišl, glfi, kudt_, 
   {{0x78acb394,0xf3f00051,0x0744010a,0x090400eb}},	//   luav, _dịp_, _ахтм, _রেপু_, 
   {{0xf1b81ebd,0x200cb395,0x6448162a,0xdb0403b2}},	//   rišo_, _alfi_, alfi, lfjó, 
   {{0x78ac4f3b,0x00000000,0x00000000,0x00000000}},	//   nuav, --, --, --, 
   {{0x92e80a2c,0xb5fc9a64,0xc100010b,0x00000000}},	//   _وراق_, _mišm, рүшл, --, 
   {{0x78ac01f4,0x4394014b,0x00000000,0x00000000}},	//   huav, _рахс, --, --, 
   {{0x200c011c,0x3f980579,0x78ac035b,0xa5c400b8}},	//   _elfi_, órur_, kuav, _tuųņ, 
   {{0xdef00020,0x78acb396,0x1ae001d5,0xb5fc0064}},	//   ፍተኛ_, juav, қотм, _rišl, 
   {{0x78acb397,0xb5fc0e3c,0x09a81fbc,0x12c0015b}},	//   duav, _sišl, गल्य, ্মীদ, 
   {{0x2450006a,0xb5fc01a6,0x00000000,0x00000000}},	//   nâma_, _pišl, --, --, 
   {{0x78acb398,0x2bb011d7,0x7ae00413,0x00000000}},	//   fuav, _जावा, ælta, --, 
   {{0x98a0470c,0x18a05a0e,0xb5fc0e04,0xad2403cc}},	// [e6a0] лите, латм, _višl, _سىدى, 
   {{0x6e24b399,0x2d900309,0xe73800f0,0x47c800f1}},	//   likb, _heye_, пез_, بارۍ_, 
   {{0xb5fc0010,0x70bc0ebb,0xa3ac0037,0x00000000}},	//   _tišl, ्बुल, कलस_, --, 
   {{0x2d9001e1,0x6e2422d9,0xe450179e,0x00000000}},	//   _jeye_, nikb, گفتگ, --, 
   {{0x2d90b39a,0xddcc031c,0x6aac01f5,0x32d000c0}},	//   _meye_, _ཏིལླ, lubf, _ašy_, 
   {{0x6e240936,0x2d90b39b,0x229800da,0x468402dd}},	//   hikb, _leye_, tīk_, _ақжа, 
   {{0x245000d2,0xb5fc892f,0x78680024,0x6e24017a}},	//   gâma_, _mišj, _užva, kikb, 
   {{0x2d90b39c,0xd2546bf1,0x64480175,0xdb04b39d}},	//   _neye_, нцы_, slfi, ngjá, 
   {{0xe3b06112,0xe5c401e0,0x6aac002f,0x51f000f7}},	//   _مرا_, _осҡо, hubf, اسىر, 
   {{0xd918010f,0xa348030d,0x00000000,0x00000000}},	//   פויל, _езза_, --, --, 
   {{0xd36c286d,0x2d90b39e,0x2f180327,0x00000000}},	//   _اهم_, _beye_, _nżgħ_, --, 
   {{0x3eac037e,0x00000000,0x00000000,0x00000000}},	//   rudt_, --, --, --, 
   {{0x2d90b39f,0x2244003e,0xf1a80133,0x00000000}},	//   _deye_, _ikok_, _زانه_, --, 
   {{0xa3d402ab,0x78ac0108,0xb82400cc,0x00000000}},	//   ियट_, vuav, _ভৱনত_, --, 
   {{0x8ff41de7,0xa3ac00e1,0x2d90b3a0,0xb4ac146b}},	//   _سرور_, _काई_, _feye_, _कम्_, 
   {{0xdb04022c,0x00000000,0x00000000,0x00000000}},	//   ggjá, --, --, --, 
   {{0x97a4b3a1,0x00000000,0x00000000,0x00000000}},	// [e6b0] ерел, --, --, --, 
   {{0x1954b3a2,0x2d901529,0x78ac04cc,0x59ac0118}},	//   дағы_, _zeye_, ruav, टलहर, 
   {{0x2d9000b2,0x81a82158,0x7bc4b3a3,0xcf9000c8}},	//   _yeye_, খ্য_, _ibhu, רטע_, 
   {{0x78acb3a4,0xdb0405f7,0xb5fc00f3,0xe3bc0db1}},	//   puav, sfjó, _tišm, çına_, 
   {{0x78acb3a5,0x1ccc0135,0xb5fc09a8,0x00000000}},	//   quav, _ུགས_, _hišk, --, 
   {{0xd838b3a6,0xb5fc0153,0x6e243ecb,0x00000000}},	//   _хэм_, _kišk, zikb, --, 
   {{0x7bc4b3a7,0xaa800432,0x4b7c00df,0xd24c0244}},	//   _mbhu, _öýtm, האוו, _تۆù_, 
   {{0xb5fcb3a8,0x71680323,0x66100214,0xa2a007af}},	//   _mišk, майг_, _پژما, _गिर्, 
   {{0x2d90b3a9,0x7bc40b6f,0x2bb005c0,0xb5fcb3aa}},	//   _reye_, _obhu, _जाला, _lišk, 
   {{0x2d901937,0x1cdc031c,0x15ec00e1,0x26a400db}},	//   _seye_, _ལླེ_, छावर_, _سۇۇپ_, 
   {{0xb8ec31d9,0x2d905079,0xc2c4b3ab,0xb5fc0063}},	//   _ྱད_, _peye_, _ميلي, _nišk, 
   {{0x7bc4b3ac,0xd1d002d3,0x786800d7,0xc0f40092}},	//   _abhu, ራሕቲ_, _ožvo, _ጎጃም_, 
   {{0xb5fc02d5,0x2d90b3ad,0x6e246df9,0x261401f9}},	//   _aišk, _veye_, rikb, पोटी_, 
   {{0x2d90b3ae,0xb5fcb3af,0xa0a04411,0x69d800ce}},	//   _weye_, _bišk, _ташд, _पोजी, 
   {{0xb5fc0fb7,0xdc640276,0x7ff4b3b0,0x7bc4002b}},	//   _višj, тард_, _حسنا, _dbhu, 
   {{0x7bc4b3b1,0x7ae405ce,0x69d8013f,0xff5000f2}},	//   _ebhu, _drht, _ɔtew, _اخه_, 
   {{0xb5fc0427,0x00000000,0x00000000,0x00000000}},	// [e6c0] _tišj, --, --, --, 
   {{0x6d5405b1,0xb864004b,0x66e44a1d,0xb5fca01b}},	//   _izya, هالو, коза, _fišk, 
   {{0x43940220,0xd6cc007b,0x00000000,0x00000000}},	//   қайс, يقك_, --, --, 
   {{0xe5a404a9,0xf6280131,0x692493cf,0x2bc81546}},	//   тиди, ىسنى_, _амма, ाजका, 
   {{0xa3ac007d,0x64981797,0x00000000,0x00000000}},	//   कलल_, фтер_, --, --, 
   {{0xc4483028,0x9d1802e4,0x00000000,0x00000000}},	//   ریان_, וונט, --, --, 
   {{0x92b000c6,0x00000000,0x00000000,0x00000000}},	//   لحيا, --, --, --, 
   {{0x6d5402e2,0x00000000,0x00000000,0x00000000}},	//   _ozya, --, --, --, 
   {{0xe3b8b3b2,0x00000000,0x00000000,0x00000000}},	//   _оба_, --, --, --, 
   {{0xe284b3b3,0x69c40334,0x00000000,0x00000000}},	//   _алжи, _lbke, --, --, 
   {{0x6458b3b4,0x6d54b3b5,0x93c801d9,0x69c4022e}},	//   _ihti, _azya, _زالہ_, _obke, 
   {{0x3a745026,0x9f4c0270,0x2244009f,0x68e45126}},	//   ғлар, _kofú_, _ukok_, _orkd, 
   {{0xef2c0240,0x00000000,0x00000000,0x00000000}},	//   _ብዘይው, --, --, --, 
   {{0xb5fc4859,0x69c4b3b6,0xd12c0133,0x7f94030d}},	//   _pišk, _abke, _بمه_, _сакх, 
   {{0xdb200ab7,0x68e4b3b7,0x2628010f,0x60c4031c}},	//   _ürün, _arkd, nĝos_, ħkmu, 
   {{0xb5fc041a,0x9ba00131,0x26280115,0x00000000}},	//   _višk, _ھەزى, iĝos_, --, 
   {{0x7e6c009a,0xb95400a7,0x9ba00131,0xd7f82e70}},	// [e6d0] _iiap, уващ, _پەزى, муж_, 
   {{0x7e6c0069,0x7bc41cdf,0xd7d800b5,0x1b48007b}},	//   _hiap, _ubhu, _gtレ_, _يؤدي_, 
   {{0x7e6cb3b8,0xc86413c3,0xb5fc09a8,0x8aa4084c}},	//   _kiap, ртти, _hiši, _кряд, 
   {{0x2af00316,0x6458b3b9,0xb5fc0064,0x00000000}},	//   ीहरु_, _ahti, _kiši, --, 
   {{0x88b0043b,0xd498b3ba,0x5884b3bb,0x68e401ab}},	//   nzɛl, фре_, _шына, _grkd, 
   {{0xf1b8000a,0x7e6c0032,0x3a280eda,0xdb0403cd}},	//   miši_, _liap, liap_, rgjæ, 
   {{0xd5b8b3bc,0x7e6c00d8,0xb5fc8ead,0x4e04000d}},	//   _оса_, _oiap, _liši, _लवलई_, 
   {{0x6458b3bd,0x3a2806a3,0xda100316,0x7e6cb3be}},	//   _ehti, niap_, ठसित_, _niap, 
   {{0x85047226,0xb5fc0cf4,0x7648b3bf,0xafe4005b}},	//   _پولن, _niši, _ikey, гопл, 
   {{0x7e6cb3c0,0x64580295,0x3a2800d5,0x00000000}},	//   _aiap, _ghti, hiap_, --, 
   {{0x7e6c00e4,0xdb043b52,0x6d5401a9,0xf1b80010}},	//   _biap, ngjä, _szya, hiši_, 
   {{0xf1b8000a,0x7c240491,0x7e6c0332,0x7094014b}},	//   kiši_, _amhr, _ciap, _бадф, 
   {{0x645802f6,0x3a28b3c1,0x7e6cb3c2,0x7e540262}},	//   _yhti, diap_, _diap, ртэц, 
   {{0xb5fcb3c3,0x320cb3c4,0x7c2400a3,0xf1b80010}},	//   _diši, lkey_, _cmhr, diši_, 
   {{0x764890f9,0x7e6c0421,0x320c014b,0xe0b4002b}},	//   _okey, _fiap, okey_, _imāḥ_, 
   {{0x7e6cb3c5,0x764828da,0xb5fc0b4b,0xed588985}},	//   _giap, _nkey, _fiši, _пой_, 
   {{0xc8241884,0x00000000,0x00000000,0x00000000}},	// [e6e0] азақ, --, --, --, 
   {{0x7648b3c6,0x671421d0,0xb5fc0784,0x9d180a1e}},	//   _akey, льеф, _kišw, _נויט, 
   {{0x3a280194,0x37740032,0x320cb3c7,0xb5fc00d7}},	//   biap_, рыус, kkey_, _ziši, 
   {{0x6458b3c8,0x248403a2,0xe61822bf,0x6594183b}},	//   _shti, tpom_, эде_, اجار, 
   {{0x439401c0,0x320cb3c9,0x98a40311,0xf10c01f9}},	//   аалс, dkey_, ănă_, िनोद_, 
   {{0x7648b3ca,0xd46400cf,0x320c0072,0xdc98010f}},	//   _ekey, гиче_, ekey_, גיסל, 
   {{0x386c05d5,0x76480175,0x99d40183,0x248401a6}},	//   _èera_, _fkey, হাৰক, spom_, 
   {{0x26280115,0xe5c801e1,0x387001e1,0x00000000}},	//   rĝos_, _àsàà, _únré_, --, 
   {{0x7e6cb3cb,0xf1d401c6,0x32000051,0x6384014b}},	//   _riap, рөхө, _ởcác_, _бгза, 
   {{0x7e6c27ed,0xa3ac1533,0xd07000c6,0x320c0076}},	//   _siap, _काट_, حديث, akey_, 
   {{0x6304b3cc,0x7e6c0069,0x320cb3cd,0x21a46135}},	//   _حوال, _piap, bkey_, _бием, 
   {{0xb5fc341a,0x320cb3ce,0x41280032,0xbe2401a9}},	//   _piši, ckey_, _инеү_, рчоқ, 
   {{0x7e6cb3cf,0x3a28013c,0x00000000,0x00000000}},	//   _viap, viap_, --, --, 
   {{0xb5fc0fb7,0xf1b80cf4,0xe7c400dc,0xca4c0150}},	//   _viši, viši_, र्मप, _ﺀﺍﺭ_, 
   {{0x3a2827ed,0x60140261,0x7e6cb3d0,0xfa240022}},	//   tiap_, _câme, _tiap, ачаҟ, 
   {{0x59dc73ca,0xb5fc15ad,0x8e8000c6,0x62e40154}},	//   _पोखर, _tiši, _اليه, _কথায়_, 
   {{0xc98464ab,0x3a28b3d1,0x6d58012d,0x63b801ef}},	// [e6f0] суси, riap_, ętac, _octn, 
   {{0xf1b8b3d2,0x7648b3d3,0x3eac0d27,0x3a280869}},	//   riši_, _skey, ordt_, siap_, 
   {{0x6014006a,0x76b89cbd,0xa3ac00af,0x3ce80165}},	//   _kâmb, тлер_, _काज_, _hrav_, 
   {{0xf1b8242a,0x5eb403d4,0xdef00092,0x00000000}},	//   piši_, _জনাই, ቃሴና_, --, 
   {{0x3dc80097,0x2ed01b61,0xc958022e,0xdb0402d2}},	//   _mbaw_, _तन्त, _бўр_, gfjö, 
   {{0x3ce805a1,0xb5fc9d28,0x78ac02d3,0xf3e40138}},	//   _mrav_, _nišv, mrav, ржко, 
   {{0x78acb3d4,0x7d1c003e,0x26280115,0x764800a2}},	//   lrav, hzss, mŝon_, _tkey, 
   {{0x76480223,0x798cb3d5,0x3f980436,0x3ce82449}},	//   _ukey, nbaw, ðrun_, _orav_, 
   {{0x3ce80218,0x63b001e4,0x320c7156,0xe1f43edd}},	//   _nrav_, _ŝenŝ, rkey_, ргы_, 
   {{0x3dc8016b,0xaec40354,0x320c2278,0x6004005b}},	//   _abaw_, абол, skey_, иным_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x78acb3d6,0x3ce8b3d7,0x6014b3d8,0x3f8c022f}},	//   krav, _brav_, _câmb, abdu_, 
   {{0x3eac257d,0x60140311,0x78acb3d9,0x3f8c031c}},	//   ardt_, _dâmb, jrav, bbdu_, 
   {{0x6a840517,0x78acb3da,0x92d409bd,0xa13400c8}},	//   илга, drav, ামী_, _דאנק_, 
   {{0x78acb3db,0x6994b3dc,0x6abc010a,0x6b64b3dd}},	//   erav, ирах, _qqpf, рква, 
   {{0xada43129,0xace805f5,0xece8b3de,0x3ce8030a}},	//   _таил, _амиа_, _адил_, _frav_, 
   {{0xe9680228,0x3958107d,0xe7f00073,0x00000000}},	// [e700] таал_, _czss_, घाला_, --, 
   {{0x60143e07,0x798c0337,0xf1b8009b,0xca780116}},	//   _zâmb, abaw, mišu_, _مەست_, 
   {{0x78acb3df,0x798cb3e0,0x00000000,0x00000000}},	//   arav, bbaw, --, --, 
   {{0x849002d3,0x3870009b,0x1a98008f,0x65c4024c}},	//   _ዝሰርሕ_, _žorž_, _ביטע, рбда, 
   {{0xf1b81591,0x78acb3e1,0x59dc0ce0,0x5d78008f}},	//   nišu_, crav, _पोटर, דאנק, 
   {{0x66e4b3e2,0xdb040008,0xd918011a,0xd3b400d4}},	//   _кога, rfjö, _יוכל, илії_, 
   {{0xe7c408e6,0xdb0401a8,0x7d1c0098,0x00000000}},	//   र्णप, sfjö, zzss, --, 
   {{0xd7d800b5,0xbebc005f,0xd0480213,0xb5fc00ef}},	//   _itメ_, lzīg, _isgə, _bišu, 
   {{0xe7c40b7c,0x00000000,0x00000000,0x00000000}},	//   र्थप, --, --, --, 
   {{0x798cb3e3,0x6014b3e4,0xf1b800f3,0xbed801c6}},	//   zbaw, _sâmb, dišu_, гдох_, 
   {{0xe68c044e,0x6014025a,0x78acb3e5,0x9c8402f0}},	//   _ዝነበሮ_, _pâmb, zrav, _odčí, 
   {{0x3ce80f72,0xa3ac05f9,0xf1b80cf4,0x78acb3e6}},	//   _prav_, कलक_, fišu_, yrav, 
   {{0x628801a4,0x5c044f55,0x31d400f1,0x99d433ae}},	//   lpfo, аява, _دمنځ, یترا, 
   {{0x78acb3e7,0x798c089c,0x7f8400c6,0x3ce805c7}},	//   vrav, wbaw, _الغن, _vrav_, 
   {{0xbebc0029,0x8ed47427,0xb5fc276e,0x6288002f}},	//   dzīg, _نذير_, _kišt, npfo, 
   {{0x3ce8b3e8,0x9da80801,0xf8b805f5,0xf1b800f3}},	//   _trav_, _ръка_, лөг_, bišu_, 
   {{0xf1b801a6,0xabf8033f,0x78ac4198,0x00000000}},	// [e710] mišt_, _łóże, urav, --, 
   {{0x78acb3e9,0xb5fc0122,0x798c4405,0x2c0c0406}},	//   rrav, _lišt, sbaw, _हवयं_, 
   {{0x8ae410f5,0x78acb3ea,0x7bd44068,0x1768010b}},	//   _діял, srav, mezu, трап_, 
   {{0xb5fc04b9,0x7bd407ab,0x7e78014f,0x0f340115}},	//   _ništ, lezu, _muvp, סראט_, 
   {{0x6288017a,0x672001e4,0x78ac036e,0x00000000}},	//   epfo, ĝoja, qrav, --, 
   {{0xb5fc0784,0xd7e4b3eb,0x00000000,0x00000000}},	//   _rišu, _тімо, --, --, 
   {{0xefd81b49,0x7e780978,0xf1b80064,0xcc700150}},	//   ኮታዊ_, _nuvp, kišt_, _ﺳﻮﺯﮔ, 
   {{0x7bd40912,0xb5fc0e3c,0xcb380375,0x21f00131}},	//   hezu, _pišu, ינוק_, ككىس, 
   {{0x7bd4b3ec,0xb5fc00d0,0x00000000,0x00000000}},	//   kezu, _dišt, --, --, 
   {{0x4394005e,0xf1b8b3ed,0x6ff401c6,0xa2d000cd}},	//   _маус, višu_, счих, _भैक्, 
   {{0x59a40574,0xafe4036b,0xb5fc0010,0x00000000}},	//   गणार, _ҳолл, _fišt, --, 
   {{0x32c0011f,0xf1b80cf4,0xb0340209,0xeec400db}},	//   móy_, tišu_, рнүш, _ۇيتپ, 
   {{0x30840597,0xae0412b7,0xb4f8010f,0x629c0427}},	//   _التف, لوگى, נפֿי, špot, 
   {{0xf1b82625,0x7bd40c52,0xab28b3ee,0xdb80b3ef}},	//   rišu_, gezu, гога_, згри, 
   {{0x32c0011f,0xead40154,0xe454008f,0xfe74009d}},	//   nóy_, হম্ম, מישט_, _мүэ_, 
   {{0xf1b81505,0x60140051,0x9e3000d8,0xbe840345}},	//   pišu_, _tâmc, _нејч, _بجوو, 
   {{0x6cc4b3f0,0x00000000,0x00000000,0x00000000}},	// [e720] _уйпа, --, --, --, 
   {{0x6b8c0175,0x00000000,0x00000000,0x00000000}},	//   qbbg, --, --, --, 
   {{0x7c64189c,0x387801fa,0x205400c8,0x271c00cc}},	//   _بايل, _eusr_, ציעל_, _বুজো_, 
   {{0x8a14021a,0x32c00548,0xfb240046,0x00000000}},	//   _بېرت, dóy_, _گرۋپ, --, 
   {{0x69d4b3f1,0xb5fc0064,0x6c7800df,0x00000000}},	//   meye, _rišt, נאַפ, --, 
   {{0x69d40365,0xa0881607,0x00000000,0x00000000}},	//   leye, қсиз_, --, --, 
   {{0x32c0011f,0x1b78010f,0x52700114,0x00000000}},	//   góy_, נטקע, пуњу, --, 
   {{0x69d4b3f2,0x7bd4b3f3,0x7e78014f,0xe61801a9}},	//   neye, zezu, _ruvp, _ёда_, 
   {{0x7bd4b3f4,0xb5fc0006,0xe4580022,0x3fd80276}},	//   yezu, _višt, _бжа_, ампэ_, 
   {{0xdef8916f,0x3f98b3f5,0x6288a2ec,0xff980063}},	//   гым_, úru_, ppfo, шкој_, 
   {{0x7f58b3f6,0x60140261,0x6448143a,0x32c0011f}},	//   ранс_, _câma, mofi, cóy_, 
   {{0x64482486,0xf1a8848c,0x6d58012d,0x5754010f}},	//   lofi, _ناهه_, ętan, מביע_, 
   {{0x7bd4b3f7,0x69d460b7,0xdb04b3f8,0x00000000}},	//   tezu, deye, lgjø, --, 
   {{0x6448b3f9,0x9f5c044e,0x61e0166a,0x4e90034c}},	//   nofi, njtë_, _haol, _کشور, 
   {{0x5e840323,0x61e0b3fa,0xdb04b3fb,0x3878067c}},	//   _уулз, _kaol, ngjø, _susr_, 
   {{0x6448b3fc,0x7bd43058,0x69d4b3fd,0x61e00641}},	//   hofi, sezu, geye, _jaol, 
   {{0x6448b3fe,0x61e0b3ff,0x5884b400,0x77983169}},	// [e730] kofi, _maol, сыба, икар_, 
   {{0x61e06980,0x20c009cc,0x64480115,0xdb040fac}},	//   _laol, iði_, jofi, kgjø, 
   {{0x6448b401,0x69d4b402,0x61e001ab,0xb6d41a9b}},	//   dofi, beye, _oaol, تقاع, 
   {{0x61e0b403,0x60c030d7,0x64480472,0x3870003e}},	//   _naol, _oqom, eofi, _wizr_, 
   {{0xcc34066d,0x644823db,0x42b82e51,0x37c4b404}},	//   _ذریع, fofi, ەنىڭ_, _мәжб, 
   {{0x6448b405,0xd7f8b406,0x32c0011f,0x9f5c0240}},	//   gofi, _сум_, tóy_, gjtë_, 
   {{0x61e00170,0xdb0402bf,0x2d8001e6,0xcec001ef}},	//   _baol, ggjø, ycke_, _maří_, 
   {{0x20c000fc,0x5924003d,0x61e0b407,0x64481140}},	//   fði_, _ལྟོས_, _caol, aofi, 
   {{0x20c011c3,0x6448b408,0xe7c45ce0,0x61e0a5f2}},	//   gði_, bofi, र्वप, _daol, 
   {{0xbebc0029,0x6448b409,0x69d4983f,0x00000000}},	//   dzīb, cofi, zeye, --, 
   {{0x61e0006c,0x60c00b6f,0x44200b45,0x32c00548}},	//   _faol, _eqom, ɗi_, qóy_, 
   {{0xace8b40a,0x61e000c6,0x6cc40064,0x69d40009}},	//   амма_, _gaol, ойма, xeye, 
   {{0x2450019f,0x69d4b40b,0x00000000,0x00000000}},	//   wâmi_, veye, --, --, 
   {{0x50a00032,0x61e0030a,0x2d80017a,0x69d4b40c}},	//   _дуҫҡ, _zaol, scke_, weye, 
   {{0x69d4b40d,0x61e0030a,0x3af413f3,0x1ae0084c}},	//   teye, _yaol, пятс, морм, 
   {{0xe9d86997,0x7d0801c7,0x245000c7,0x00000000}},	//   јка_, äesc, râmi_, --, 
   {{0xe8f8b40e,0x6448b40f,0x69d4b410,0xebe4b411}},	// [e740] шла_, yofi, reye, _допп, 
   {{0x69d4b412,0xe730b413,0xe4f800dc,0x00000000}},	//   seye, وصا_, ्हसि_, --, 
   {{0x69d402bd,0x644807d6,0xe57802c6,0x44388af3}},	//   peye, vofi, азе_, _ır_, 
   {{0x20c00436,0x09d00c58,0x6448b414,0xdb04b415}},	//   yði_, ৱাহা, wofi, vgjø, 
   {{0xe4d4543c,0x61e0b416,0x62680118,0x00000000}},	//   تتاب, _raol, _křov, --, 
   {{0x20c01125,0x61e0b417,0xdb04b418,0xd36c01d5}},	//   vði_, _saol, tgjø, چهه_, 
   {{0x6448b419,0x61e0b41a,0xded402d3,0xd36c32cc}},	//   rofi, _paol, ራብን_, نهه_, 
   {{0xdb043ad2,0xdb0c007c,0x6b8000a2,0x00000000}},	//   rgjø, _ödåk, _şogl, --, 
   {{0xd1b4282b,0x64480451,0x61e0b41b,0xdb040174}},	//   زايا_, pofi, _vaol, sgjø, 
   {{0x20c0b41c,0x61e0b41d,0x93c800dd,0xdb04b41e}},	//   rði_, _waol, _نامہ_, pgjø, 
   {{0x61e0b41f,0x01ac00eb,0x00000000,0x00000000}},	//   _taol, ক্ষদ, --, --, 
   {{0x6600b420,0x3dcc0209,0x7f580454,0x9e2400d4}},	//   njok, ýew_, _қайс_, ієнк, 
   {{0x9cc8b421,0x60c0014b,0x442c00b5,0xa1341888}},	//   шына_, _uqom, _kmd_, _براش, 
   {{0xb5fc0113,0x442cb422,0x908400ae,0x69c800e5}},	//   _lišp, _jmd_, _بنوك_, őfel, 
   {{0x442c019b,0x66000113,0x26280115,0xcec00118}},	//   _mmd_, kjok, rŝoj_, _vaří_, 
   {{0x442c005c,0x66000083,0x3f9c03b2,0x00000000}},	//   _lmd_, jjok, _hevu_, --, 
   {{0x3f9c0a73,0x442cb423,0x245000d2,0x660014bb}},	// [e750] _kevu_, _omd_, lâmu_, djok, 
   {{0xc7f802bf,0x9ba05f32,0x442c0051,0x3f9c013a}},	//   онує_, _زەرى, _nmd_, _jevu_, 
   {{0xeb880184,0x66000175,0xe0c00011,0x2aa00092}},	//   _урыҫ_, fjok, ্টিভ, ልጣኞች_, 
   {{0x3f9c601a,0xb5fc02d1,0x442c6fb0,0x00000000}},	//   _levu_, _pišq, _amd_, --, 
   {{0x799cb424,0x442cb425,0x26dc0086,0x201c01d9}},	//   _iesw, _bmd_, _âton_, khti_, 
   {{0x442cb426,0x799cb427,0xd0500b45,0x370401d9}},	//   _cmd_, _hesw, ɗaɗe, _ٹورِ, 
   {{0xc6a4006c,0x442cb428,0x201c0240,0x81d40154}},	//   _орти, _dmd_, dhti_, িএন_, 
   {{0x6600b429,0x799c016d,0xb9e40023,0x59c800dc}},	//   cjok, _jesw, _ያኢ_, ाभिर, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x799cb42a,0x3f9cb42b,0xc32c0075,0x201c0135}},	//   _lesw, _cevu_, _ھەي_, ghti_, 
   {{0x3f9cb42c,0x799c03ac,0x84241183,0x6d58012d}},	//   _devu_, _oesw, _تىلن, ętam, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd758001f,0x442c0165,0xe0ccb42d,0x00000000}},	//   _ውሳኔዎ, _ymd_, _яв_, --, 
   {{0x799c02d0,0x3f9c03b2,0x2a600240,0x66000010}},	//   _aesw, _gevu_, _shkb_, zjok, 
   {{0x799cb42e,0x39300092,0x00000000,0x00000000}},	//   _besw, _በመወያ, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe7a805f5,0x799cb42f,0xb5fc0309,0xfbd00f22}},	// [e760] йвал_, _desw, _rišp, ায়ত, 
   {{0x6d54b430,0x799c02d0,0x00000000,0x00000000}},	//   _iyya, _eesw, --, --, 
   {{0x799c08cd,0x6674b431,0x9be4025c,0xb5fc0309}},	//   _fesw, سدار, _སྣྲོ, _pišp, 
   {{0x799c05e4,0xb5fc0309,0x6b9c03cb,0x6d5400a2}},	//   _gesw, _qišp, _hepg, _kyya, 
   {{0x7dec008f,0x6b9c010e,0x66002de9,0x81d40154}},	//   יקאַ, _kepg, rjok, িএম_, 
   {{0x66005f92,0x799c009a,0x82c80327,0x00000000}},	//   sjok, _zesw, _གྱུའ, --, 
   {{0x799cb432,0x3f9cb433,0xf3c80244,0x00000000}},	//   _yesw, _revu_, تبنه_, --, 
   {{0x3f9c0481,0xe2986603,0x201c00b0,0x55e0059f}},	//   _sevu_, _ҳаж_, whti_, _посб, 
   {{0x442c070d,0x3f9c01c8,0x6d54010b,0x201c0200}},	//   _tmd_, _pevu_, _nyya, thti_, 
   {{0x6b9c26be,0xe44800cf,0xe29801c6,0xa4f801f9}},	//   _nepg, _الئى_, _гаж_, ्हीच_, 
   {{0x6d54b434,0x931001ec,0x443c0051,0x00000000}},	//   _ayya, _كوكش, mnv_, --, 
   {{0x201cb435,0x00000000,0x00000000,0x00000000}},	//   shti_, --, --, --, 
   {{0x3f9ca263,0x799c03cb,0x9f9c0036,0x201c009a}},	//   _tevu_, _resw, _lééd_, phti_, 
   {{0x799cb436,0x6b9c0223,0x443c0d81,0x00000000}},	//   _sesw, _cepg, nnv_, --, 
   {{0x88b00134,0x6b9c00ee,0x6d54b437,0xb4a8791c}},	//   hyɛd, _depg, _eyya, _खट्_, 
   {{0x9f4c026c,0x799c047e,0x0f54011a,0x01540023}},	//   _infà_, _qesw, _מיום_, _ምስትም, 
   {{0x39a40064,0x00000000,0x00000000,0x00000000}},	// [e770] _rūsį_, --, --, --, 
   {{0x799cb438,0x30ec00dc,0x7c280373,0x629803ac}},	//   _wesw, जितः_, ëerd, _owto, 
   {{0x799cb439,0xf1dc05d7,0xd76401ed,0x6d540432}},	//   _tesw, _मसलन, سائٹ, _zyya, 
   {{0xe9f00124,0x00000000,0x00000000,0x00000000}},	//   _иҧсы, --, --, --, 
   {{0x6298b43a,0x49743417,0xc4840220,0x98e4010b}},	//   _awto, _плюс, елік, _эюнд, 
   {{0x2008007c,0x00000000,0x00000000,0x00000000}},	//   öbil_, --, --, --, 
   {{0x6298015d,0x95b000fb,0x6fbc07b7,0xa28000e5}},	//   _cwto, _зөлх, ्भसं, نیلو, 
   {{0xccf40134,0xd61800db,0x00000000,0x00000000}},	//   _hyɛe_, _اتسا_, --, --, 
   {{0x3c0c05d7,0x6298035a,0x76580042,0xb14400d4}},	//   _सकूँ_, _ewto, mlwy, ьнил, 
   {{0x76580368,0x60600131,0x443c0208,0x229800c0}},	//   llwy, نۇنل, cnv_, būk_, 
   {{0x6d5400ee,0x76580368,0x6298015d,0x6b9c18c3}},	//   _syya, olwy, _gwto, _repg, 
   {{0xed58b43b,0x8fc4004b,0x6d5400a2,0x6b9c010b}},	//   жом_, _کېدل_, _pyya, _sepg, 
   {{0x76580142,0x00000000,0x00000000,0x00000000}},	//   ilwy, --, --, --, 
   {{0xdddc0166,0x76580042,0x00000000,0x00000000}},	//   _tiqş, hlwy, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x628400b0,0x9f9c0165,0x55fc00cc,0x00000000}},	//   _ōkok, _rééd_, ংসুক_, --, 
   {{0xb1500882,0x6d54b43c,0x76580368,0x6ea02e3b}},	// [e780] ṣṭaṃ_, _uyya, dlwy, _कौतु, 
   {{0x321c03cb,0x76580142,0xdb0402d2,0x00000000}},	//   _llwy_, elwy, ggjó, --, 
   {{0x76580cfd,0x569002bf,0x1cb8031c,0x7c2801f5}},	//   flwy, ваєт, _ངའོ_, ëere, 
   {{0x765800a9,0xdb200248,0x00000000,0x00000000}},	//   glwy, _àrán, --, --, 
   {{0xd32001e4,0x00000000,0x00000000,0x00000000}},	//   lanʈ, --, --, --, 
   {{0x68e00135,0x00000000,0x00000000,0x00000000}},	//   ħodd, --, --, --, 
   {{0x93c82832,0x321c0142,0xe61806ed,0xdef00092}},	//   تانہ_, _blwy_, _ддв_, ግተን_, 
   {{0xd2540aec,0x321c03cb,0x7658015d,0x00000000}},	//   мцы_, _clwy_, clwy, --, 
   {{0x64c402dd,0xe3a8005b,0x00000000,0x00000000}},	//   _زيال, _мкад_, --, --, 
   {{0x321c0042,0x15402377,0x00000000,0x00000000}},	//   _elwy_, _реум, --, --, 
   {{0x53a0039b,0x7dd403b2,0xda0c0073,0x00000000}},	//   _рахб, _nýsæ, _सवलत_, --, 
   {{0x321c0042,0xb8d00327,0x4e90036b,0x00000000}},	//   _glwy_, _ནྷ_, کشیر, --, 
   {{0x628406c8,0x88b0013f,0x0e4401c6,0x00000000}},	//   _ōkoh, hyɛb, тээм, --, 
   {{0x2d8c013f,0x823402f2,0x00000000,0x00000000}},	//   _ɑfei_, _توڵڵ, --, --, 
   {{0x76580368,0x02dc190c,0xf9d40b5e,0xbf100166}},	//   ylwy, _मनोन, новэ, _сүнә, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc98400a7,0x41d021f6,0x00000000,0x00000000}},	// [e790] туси, थ्यस, --, --, 
   {{0x7658015d,0x00000000,0x00000000,0x00000000}},	//   wlwy, --, --, --, 
   {{0x7bc40588,0xc7c400a7,0x35b4b43d,0xdb0406ea}},	//   _ichu, ъсти, ебер, rgjó, 
   {{0x7ae4b43e,0xdb0403b2,0x00000000,0x00000000}},	//   _isht, sgjó, --, --, 
   {{0x7658015d,0xc95801a9,0x00000000,0x00000000}},	//   rlwy, _жўр_, --, --, 
   {{0x7ae40023,0x76580142,0x00000000,0x00000000}},	//   _ksht, slwy, --, --, 
   {{0x7bc4b43f,0x321c0042,0x76580175,0x3958007c}},	//   _mchu, _plwy_, plwy, _hyss_, 
   {{0x7ae40451,0x3958713c,0xddd80064,0xae1c000d}},	//   _msht, _kyss_, iptų, _पतइन_, 
   {{0xe0d40c98,0xd3a400d8,0x00000000,0x00000000}},	//   евы_, _жреп, --, --, 
   {{0x7bc406e4,0xaf04041b,0x7ae4036e,0x00000000}},	//   _nchu, епол, _osht, --, 
   {{0xb8e0031c,0x7178010b,0x02a40117,0x00000000}},	//   _གའ_, _ебер_, _арчм, --, 
   {{0x7bc4b440,0xfbc8025f,0xed500014,0xefcc0023}},	//   _achu, _לת_, ێپھ_, ጥናዮ_, 
   {{0x39583953,0x7ae4b441,0x672001e4,0x00000000}},	//   _nyss_, _asht, ĝoji, --, 
   {{0x291c0325,0x7bc40055,0xa5c002d2,0x00000000}},	//   _āta_, _cchu, _þóvi, --, 
   {{0x7ae403e0,0x00000000,0x00000000,0x00000000}},	//   _csht, --, --, --, 
   {{0x7bc40489,0x2ca80801,0xd32000df,0x00000000}},	//   _echu, _екип_, ranʈ, --, 
   {{0x7ae4067d,0x02dc0d2c,0x02ac00bc,0x25f40210}},	// [e7a0] _esht, _मन्न, _घट्न, _एफबी_, 
   {{0x999c00e2,0x7ae4036e,0x65a800e4,0x00000000}},	//   ārša_, _fsht, köhí, --, 
   {{0xa9a40a93,0xc8ac0490,0xeb3414af,0x00000000}},	//   _пинд, _चिकट, _سردخ, --, 
   {{0x317c0399,0x5ab400c8,0x103c0023,0x00000000}},	//   _ngwz_, _אלטע_, _ይጥቀመ, --, 
   {{0x69c4127b,0x18b0013d,0xf53802f0,0x5ee40118}},	//   _icke, _бәхр, _peťa_, _छैन्_, 
   {{0x68e4127b,0x7ae40200,0xe7c405c0,0xafe00162}},	//   _iskd, _ysht, र्खप, ðøld, 
   {{0x2bd01276,0x779003e6,0x835400ec,0xc05001d9}},	//   द्या, _ئیما, ڙپڪا, یٖب_, 
   {{0x27e8002f,0x5fc000bc,0x00000000,0x00000000}},	//   _habn_, _शाहल, --, --, 
   {{0x154020db,0xe3b81eed,0xa44406a7,0x64340e56}},	//   _бетм, _нба_, _знад, _كىرئ, 
   {{0x490800e1,0x00000000,0x00000000,0x00000000}},	//   _सपनो_, --, --, --, 
   {{0x69c4b442,0x7bc401ab,0xd24c01d9,0xe0c00011}},	//   _ocke, _rchu, _گۆٹ_, ্টেন, 
   {{0x7bc42a38,0xccf4016b,0x72a00075,0xc0d40092}},	//   _schu, _brɛ_, _ئەين, ያህል_, 
   {{0xd24c0014,0x601406ed,0x2bd000dc,0xbebc00e2}},	//   _انن_, _lâmi, द्भा, mzīm, 
   {{0x69c4b443,0x25a40368,0xd00421fa,0x26c801a9}},	//   _acke, haol_, _пече_, _oqbo_, 
   {{0x25a4af4c,0x395802d2,0x00000000,0x00000000}},	//   kaol_, _syss_, --, --, 
   {{0xccf40134,0xfd74010b,0xd90c0214,0x200c3e33}},	//   _frɛ_, _илйэ, میج_, _hofi_, 
   {{0x200c013b,0x1cb8b444,0x7bc4b445,0x25a4b446}},	// [e7b0] _kofi_, _ངའི_, _tchu, daol_, 
   {{0xb9080dad,0x7bc4b447,0x200c0333,0xda78b448}},	//   _मन_, _uchu, _jofi_, _ням_, 
   {{0x7ae4b449,0x200cb44a,0x3958b44b,0x68e4035a}},	//   _usht, _mofi_, _wyss_, _eskd, 
   {{0x2b0c0316,0x52b001e0,0x200c21f1,0xb4940063}},	//   ठहरु_, ҫҡас, _lofi_, видљ, 
   {{0x3604b44c,0x1dd01944,0x200c208d,0x09c80220}},	//   _یوسف, ध्यत, _oofi_, _سۇلۋ_, 
   {{0x293404ac,0x200c00f2,0x27e801ab,0x00000000}},	//   _יארן_, _nofi_, _gabn_, --, 
   {{0xd5b8a20e,0x03a8b44d,0xb208011c,0x00000000}},	//   _нса_, ردوو_, дейз_, --, 
   {{0x200cb44e,0x21f000d1,0x25a403cb,0x00000000}},	//   _aofi_, لكىس, caol_, --, 
   {{0x200c007f,0xd378084c,0x6b8002e3,0x2fb800a8}},	//   _bofi_, _ече_, ọgid, мынэ_, 
   {{0x200c75d3,0xef184d87,0x1cac0327,0x6ff4009d}},	//   _cofi_, дмо_, _ཕྷེ_, тчих, 
   {{0x926807d6,0x200c0036,0x00000000,0x00000000}},	//   _ерда_, _dofi_, --, --, 
   {{0xd05c00ac,0x518412c4,0x3f980d12,0x00000000}},	//   _əvəz, _чужа, ðrur_, --, 
   {{0x00944090,0xc0c800f3,0x00000000,0x00000000}},	//   _бичэ, _зује_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf1a42d6b,0x0dd4010a,0x00000000,0x00000000}},	//   _गजान, _йăви_, --, --, 
   {{0x200c01e4,0xed5800db,0x7db40024,0x3eb800d7}},	//   _zofi_, _оой_, _йсьц, árte_, 
   {{0xec4800d8,0x00000000,0x00000000,0x00000000}},	// [e7c0] _озил_, --, --, --, 
   {{0xbebc005f,0xd9940150,0x00000000,0x00000000}},	//   dzīj, _ﺘﻘﺼﺩ_, --, --, 
   {{0x36880046,0x3d64130e,0x6b6400a8,0xf71802d5}},	//   есін_, _لطیف, _шкоа, ніцы_, 
   {{0x69c4b44f,0xe61843c6,0xe69400c7,0x00000000}},	//   _ucke, ьде_, еиҧы, --, 
   {{0x25a4b450,0xd87400db,0x00000000,0x00000000}},	//   raol_, رمۅت_, --, --, 
   {{0xa7d81060,0x545001ce,0x25a40332,0x00000000}},	//   _توسط_, авіт, saol_, --, 
   {{0xe71898f0,0x7d0800e8,0xbebc00e2,0x00000000}},	//   _غيرت_, _kërë, tzīm, --, 
   {{0xe3b03cb9,0x78b0008c,0x7d080de2,0x262801e4}},	//   _چرا_, _ákvæ, _jërë, rŝos_, 
   {{0xe3b06a3b,0x24840327,0x92640395,0x00000000}},	//   _نرا_, qqom_, ърша_, --, 
   {{0xa3b812e3,0x200c058a,0xdfd8013e,0x00000000}},	//   _زائر_, _qofi_, фъи_, --, 
   {{0x211800b2,0x539802e4,0x7e7401c0,0x63043a16}},	//   _ڪتاب_, _חיבו, лгох, _جوال, 
   {{0x5180b451,0x200c0134,0x7d0800e8,0x00000000}},	//   _куша, _wofi_, _nërë, --, 
   {{0x200cb452,0x22442a1f,0x60241ee3,0xf1a804d3}},	//   _tofi_, _ijok_, _идда, _سانه_, 
   {{0x200c0093,0x2b440055,0x00000000,0x00000000}},	//   _uofi_, _śoca_, --, --, 
   {{0x2bd03156,0x7d080694,0xdd000790,0xa3b800bc}},	//   द्धा, _bërë, ırıd, _आएन_, 
   {{0x7d08002e,0x261c0042,0xdb040200,0x00000000}},	//   _cërë, _sïon_, lajë, --, 
   {{0xccf40134,0x7d080de2,0x52bc05d7,0x052400eb}},	// [e7d0] _hyɛn_, _dërë, _एम्स, বপুর_, 
   {{0x2bd04c5b,0xccf40134,0xdb040200,0x00000000}},	//   द्दा, _kyɛn_, najë, --, 
   {{0x2244b453,0xdcec083c,0xf5380419,0x7c2801e4}},	//   _ojok_, macı, _peťo_, ɨerp, 
   {{0x7d080694,0xdcec2ca8,0xdb0402d2,0x00000000}},	//   _gërë, lacı, fgjö, --, 
   {{0x798c011f,0x98b000e2,0x996406a6,0xdb0401a8}},	//   mcaw, ādēs_, _штол, ggjö, 
   {{0x78acb454,0xbebc00e2,0xd6d8022e,0xdcec03e0}},	//   msav, rzīj, _отб_, nacı, 
   {{0x78aca6ba,0x7d081bce,0xafe401b9,0x2e20032e}},	//   lsav, _yërë, қонл, _lófa_, 
   {{0x798cb455,0x7d081bce,0x3ce8000d,0x4b7c0a7c}},	//   ncaw, _xërë, _osav_, ואוו, 
   {{0x78acb456,0x3eac009a,0x798c009a,0xdb040240}},	//   nsav, esdt_, icaw, fajë, 
   {{0x78acb457,0x798c0042,0xc2c46af3,0xa5c001a8}},	//   isav, hcaw, _چيلي, _þóri, 
   {{0x6da4b458,0xada43b49,0xc2c4009f,0xdcec03e0}},	//   лина, ланл, _نيلي, dacı, 
   {{0x78ac0bed,0x798c0369,0x22440200,0x00000000}},	//   ksav, jcaw, _gjok_, --, 
   {{0x78ac456d,0x7d08036e,0xa3b80037,0xdcec0205}},	//   jsav, _rërë, _आएम_, facı, 
   {{0x798c009a,0x2e2001e7,0xd24c2586,0x6e24036e}},	//   ecaw, _dófa_, _انچ_, shkb, 
   {{0xdc64b459,0xe6d0032c,0x3ce801e4,0x7d0883cc}},	//   уард_, _सहेज, _esav_, _përë, 
   {{0x798c0163,0x35980092,0xc3380b82,0xfaa40108}},	//   gcaw, ሆንበት_, _እንጥቀ, ршён, 
   {{0x78acb45a,0xbce800c7,0x6d58033f,0x684401c6}},	// [e7e0] gsav, _агыҧ_, ętas, гнаа, 
   {{0xebe4b45b,0x7d0800e8,0x1cac0327,0xdcec0790}},	//   _сооп, _wërë, _ཕྷི_, cacı, 
   {{0x7d08b45c,0x09b000bd,0x78acb45d,0xaa440014}},	//   _tërë, ঙ্গা, asav, _مندى, 
   {{0xa5244ec9,0x95c4b45e,0x798cb45f,0x00000000}},	//   лмед, гуша_, ccaw, --, 
   {{0xe3b0b460,0x78ac00e5,0x69c800e5,0xc448032f}},	//   مرغ_, csav, őfes, پیان_, 
   {{0xdb0401a8,0xf1a00220,0x7d080108,0xb55400b8}},	//   rgjö, _ﺍﺩﺍﻡ_, äesi, _ūṣma, 
   {{0xb9d0044e,0x2578008e,0xdb040240,0xd82006ed}},	//   _ስቕ_, _bülü_, vajë, _удри, 
   {{0xdb0401a8,0xdcec05d1,0x626400cf,0x00000000}},	//   pgjö, zacı, داتق, --, 
   {{0xdcec71e1,0xa49001b9,0x25680137,0xd0a401c6}},	//   yacı, _ایتت, _чаап_, лтэд_, 
   {{0x4438b461,0x40340138,0x2e2002d2,0x00000000}},	//   _ör_, реос, _rófa_, --, 
   {{0x6458b462,0x93c89105,0xdcec05d1,0x2e2008a5}},	//   _ikti, _سالہ_, vacı, _sófa_, 
   {{0x78acb463,0x798c0007,0x25783361,0x9c840f91}},	//   ysav, xcaw, _gülü_, _nečí, 
   {{0xc0c40131,0x0e34b464,0x0c9401d5,0xdcec15b7}},	//   _тәйи, сняю, یگیگ, tacı, 
   {{0x78ac03b2,0x7f940354,0x00000000,0x00000000}},	//   vsav, _такх, --, --, 
   {{0x501806a9,0xc0f002d3,0xf33402d3,0xdcec06b9}},	//   _אוגו, _ጀብሃ_, _እንተሓ, racı, 
   {{0x3ce80457,0x62880369,0x63a80008,0x201cb465}},	//   _tsav_, iqfo, hafn, lkti_, 
   {{0x7e6cb466,0x798c004e,0x78acb467,0x645800a2}},	// [e7f0] _ihap, rcaw, usav, _okti, 
   {{0x201cb468,0x37c418ce,0x798c920e,0x00000000}},	//   nkti_, шәмб, scaw, --, 
   {{0x78acb469,0x7e6cb46a,0xd6d8b46b,0x201cb46c}},	//   ssav, _khap, эта_, ikti_, 
   {{0xceb0008d,0xd1cc02d3,0x798c0007,0xc984b46d}},	//   מיע_, ጥታት_, qcaw, _гури, 
   {{0x2bd04b01,0x88b00085,0x7e6cb46e,0xf504b46f}},	//   द्वा, nyɛl, _mhap, рзло, 
   {{0x63a8b470,0x7e6c0076,0x0574b471,0xdb04007f}},	//   gafn, _lhap, حامد, tajè, 
   {{0x7e6cb472,0x628400b0,0x00000000,0x00000000}},	//   _ohap, _ōkor, --, --, 
   {{0x6458b473,0x7e6c006f,0x4b380375,0xb9d00023}},	//   _ekti, _nhap, טרול_, _ስን_, 
   {{0x7648019f,0x645803a0,0xdb044bc7,0x00000000}},	//   _ijey, _fkti, sajè, --, 
   {{0x7e6cb474,0x909002d3,0x613801bf,0x00c40116}},	//   _ahap, _ዘነግህ_, _sølø, _ﻫﻪﺗﺘ, 
   {{0x43840491,0x7e6c4e2b,0x3a2803a2,0x764803b2}},	//   _المق, _bhap, khap_, _kjey, 
   {{0x3eb808de,0x764800b8,0x644403b2,0x201c0254}},	//   árta_, _jjey, _íkir, akti_, 
   {{0x7e6c034c,0x320c014b,0x3a2804fb,0xd16400a7}},	//   _dhap, mjey_, dhap_, _съжи, 
   {{0x7e6cb475,0xd12c0014,0x320c0363,0x00000000}},	//   _ehap, _وۅں_, ljey_, --, 
   {{0x7648701f,0x320c00ad,0x9c840118,0x00000000}},	//   _ojey, ojey_, _pečí, --, 
   {{0x7e6cb476,0xf35402d3,0x3a28003e,0x320c0076}},	//   _ghap, _ምንቕቓ, ghap_, njey_, 
  
   {{0x7c2400b5,0x9c8400bc,0x320c0076,0xb0b4010f}},	// [e800] _flhr, _večí, ijey_, יפּס_, 
   {{0x2794b477,0x764800b8,0x320c00ad,0x7e6c0200}},	//   ршар, _ajey, hjey_, _zhap, 
   {{0xab28010a,0x9bb8011a,0x00000000,0x00000000}},	//   _рона_, _בציפ, --, --, 
   {{0x2bd007f8,0x3a28b478,0x80dc0f22,0xd7d8037e}},	//   द्रा, chap_, বিত্, _vuメ_, 
   {{0x201cb479,0xaa440014,0x76481180,0x320c1368}},	//   ykti_, _منگى, _djey, djey_, 
   {{0x18a0b47a,0x947005d9,0xd7d804ce,0x98a0b47b}},	//   _фарм, يدوا, _auユ_, _фире, 
   {{0x63a8b47c,0xe5a402bf,0xe7381376,0x77901a4b}},	//   rafn, _виби, _рев_, _رینا, 
   {{0x63a8008c,0xb060007c,0xe2c400ec,0x66e4014b}},	//   safn, ääng, هوڙو_, _йоҳа, 
   {{0x7e6cb47d,0x88b0013f,0x60440a5b,0xdb040df4}},	//   _rhap, kyɛm, ихоз, rajé, 
   {{0x201c1d64,0x7e6cb47e,0x6458464e,0xd00406ed}},	//   ukti_, _shap, _ukti, иење_, 
   {{0x7e6cb47f,0x201c02d5,0x3a28089c,0x443cb480}},	//   _phap, rkti_, yhap_, miv_, 
   {{0x7e6c1bb7,0xc224876d,0x4ea00006,0x201c06ea}},	//   _qhap, _دکتو, ўрэа, skti_, 
   {{0x409406d5,0x0ca8b481,0x7e6c06d6,0xd12c00db}},	//   _التر, итри_, _vhap, _ۉمۅ_, 
   {{0xbebc0029,0x7e6cb482,0x80dc0eac,0xa2c800cd}},	//   dzīv, _whap, বিদ্, संप्, 
   {{0x7e6cb483,0x9a840f37,0x3a28b484,0xba4401d3}},	//   _thap, ругл, thap_, منسٹ, 
   {{0x7e6cb485,0x443cb486,0x4e9006c2,0x00000000}},	//   _uhap, hiv_, _بشور, --, 
   {{0xc4c432db,0x3a280240,0x00000000,0x00000000}},	// [e810] _تے_, rhap_, --, --, 
   {{0x7d1c0731,0x3a28b487,0x764806ea,0x00000000}},	//   myss, shap_, _sjey, --, 
   {{0x443cb488,0x76b80046,0x7d1cb489,0x3a28b48a}},	//   div_, улер_, lyss, phap_, 
   {{0x06840046,0x3a280113,0xb80404af,0x00000000}},	//   ігін, qhap_, राहम_, --, 
   {{0xd8740879,0x443c004e,0x7d1c0363,0x00000000}},	//   _ناسب, fiv_, nyss, --, 
   {{0x443cb48b,0xeac40086,0x39480022,0x00000000}},	//   giv_, òùga_, _азҭо_, --, 
   {{0x7d1cb48c,0x37ac00fe,0xb0a80118,0xf1b800ef}},	//   hyss, _চাপৰ, चीनग, ekša_, 
   {{0x7d1cb48d,0x320c0076,0x438400d1,0x644401e1}},	//   kyss, ujey_, ملۇق, _ìkin, 
   {{0x765886d2,0x443cb48e,0x2ba8539d,0x320c0363}},	//   mowy, biv_, करमा, rjey_, 
   {{0x443c45a7,0x7d1c35e5,0x7658b48f,0x9f4cb490}},	//   civ_, dyss, lowy, _kafè_, 
   {{0x9f4c0100,0xd244010b,0xeb9801b9,0xc2c4007b}},	//   _jafè_, _кэди, ғиб_, _ويكي, 
   {{0x76587aaa,0xf3f00208,0x7d1c01f4,0xa00400db}},	//   nowy, _hạ_, fyss, _ۇسىۇ, 
   {{0xada4052f,0xd7c4032c,0x30740f43,0x7d1c00ad}},	//   _һайл, _लांच, _лукс, gyss, 
   {{0xee3800fd,0x765855e3,0x6f94007b,0x3a3801ef}},	//   _әни_, howy, _الغض, _amsp_, 
   {{0x6b64b491,0x765805ff,0x7d1c062c,0xf3f00051}},	//   сква, kowy, ayss, _mạ_, 
   {{0x76580034,0x31a402e5,0xf3f00208,0x7d1cb492}},	//   jowy, _गजोध, _lạ_, byss, 
   {{0x7658b493,0xe8f8b494,0x7d1c0076,0x7d080108}},	// [e820] dowy, ыла_, cyss, äest, 
   {{0x443cb495,0xf20805f9,0x69c400af,0x2984008e}},	//   xiv_, वाड़_, िलही, рыңг, 
   {{0x443cb496,0x9f4cb497,0x00000000,0x00000000}},	//   viv_, _cafè_, --, --, 
   {{0x60140261,0x3d300dc9,0x9f4c007f,0x76580034}},	//   _lâmp, ṅwe_, _dafè_, gowy, 
   {{0xf638004b,0x99d400f7,0xb7bc0131,0xf3f00051}},	//   جينګ_, _اتپا, _ﻧﯘﺭﻏ, _bạ_, 
   {{0x9cd40302,0x9f4c0023,0x83f81d5b,0x00000000}},	//   מונה_, _qafë_, рекс_, --, 
   {{0x76580034,0xbebc00e2,0xf3f00051,0xd820030d}},	//   bowy, nzīt, _dạ_, _эдри, 
   {{0x7658033f,0xdef820b0,0x92b0007b,0x7d1c01f4}},	//   cowy, ңын_, أحوا, yyss, 
   {{0x9f4c0699,0x443cb498,0x00000000,0x00000000}},	//   _zafè_, piv_, --, --, 
   {{0x6014084c,0x9f4c0165,0x443c0477,0xbed84f5c}},	//   _câmp, _hafé_, qiv_, адох_, 
   {{0x9f4cb499,0x7d1c54ac,0x37ac00cc,0x00000000}},	//   _kafé_, wyss, _চামৰ, --, 
   {{0x7d1cb49a,0x9f4c1bce,0x9cc809a5,0xbebc005f}},	//   tyss, _jafé_, лыга_, dzīt, 
   {{0x5c040801,0x3a3800e4,0x80dc009e,0xa09800d8}},	//   бява, _rmsp_, বিহ্, _стеф_, 
   {{0x76586b7e,0x7d1c1368,0x3dcc0135,0x00000000}},	//   zowy, ryss, żew_, --, 
   {{0x7d1cb49b,0x628000ad,0x76580009,0x75cc00e5}},	//   syss, _kioo, yowy, lőző, 
   {{0x7d0802f6,0x62801368,0xb9c4007b,0xb998b49c}},	//   äess, _jioo, تقري, рвах_, 
   {{0xb814026a,0x9be401ce,0x9a84036b,0x99640108}},	// [e830] одај, _лінк, руҳл, ствл, 
   {{0x2ba87922,0x62800731,0x76580034,0x9f4c02bd}},	//   करणा, _lioo, wowy, _pafè_, 
   {{0x7658068f,0x17681411,0xf4c400fe,0x00000000}},	//   towy, урап_, _এনেব, --, 
   {{0x68ecb49d,0xdb0402fd,0x62806e43,0x2cb0b49e}},	//   ändä, nají, _nioo, _ändä_, 
   {{0x7658b49f,0x00000000,0x00000000,0x00000000}},	//   rowy, --, --, --, 
   {{0x05745c86,0x6280b4a0,0x76580034,0xdb046818}},	//   ساند, _aioo, sowy, hají, 
   {{0x8c1cb4a1,0x6d8c1682,0xdb040316,0xa3b8012c}},	//   רווי, _ṱamb, kají, _आएर_, 
   {{0x779036c1,0xb5c8a5f4,0x00000000,0x00000000}},	//   _ریچا, _خورم_, --, --, 
   {{0xdb04012c,0x628cb4a2,0x6280b4a3,0xc7600092}},	//   dají, _ébon, _dioo, _ሶስተኛ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6280062c,0x73c000fb,0xbebc00de,0x00000000}},	//   _fioo, _еҙҙе, dzīs, --, 
   {{0x62800363,0xbebc00e2,0xc0d40023,0x4174072d}},	//   _gioo, ezīs, ሪሖም_, _کامس, 
   {{0x60140311,0xe0cc01af,0xf1b80064,0x5ca000db}},	//   _tâmp, _юв_, lkšo_, мияб, 
   {{0xb3c802c3,0x151403d4,0xdd2c01ef,0x00000000}},	//   रलिख, _দেৱী_, běžc, --, 
   {{0xc0582756,0x6280062c,0x7bc001e7,0xdb041a5e}},	//   _اشنا_, _yioo, ólua, bají, 
   {{0xbebc005f,0x00000000,0x00000000,0x00000000}},	//   rzīt, --, --, --, 
   {{0xe7a81d1c,0xc5f80184,0xa3b800c5,0xa7a81fce}},	// [e840] ивал_, ҙға_, _आएल_, икаа_, 
   {{0x6ae43395,0x1c4002dd,0x3cec0240,0x9f4c0241}},	//   _джоз, _оным, çeve_, _safé_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x1b100154,0x75cc01d3,0x4f380023,0x00000000}},	//   _ডেকে_, yőző, _ኣንድር, --, 
   {{0x62801af3,0xa3e801b9,0x43940108,0xb17c0419}},	//   _rioo, идда_, палс, deťo, 
   {{0x628020ac,0xdb0400bc,0x43940166,0x00000000}},	//   _sioo, zají, чакс, --, 
   {{0x62800076,0xa2c80825,0x00000000,0x00000000}},	//   _pioo, संध्, --, --, 
   {{0xd5f80051,0xaae0012d,0x61e4022e,0x00000000}},	//   _giù, _पहनक, еkla, --, 
   {{0xa3d00a28,0xdb04012c,0x62801a7c,0x154000db}},	//   _वाप_, vají, _vioo, _жетм, 
   {{0xa2e40064,0x68e0025c,0x00000000,0x00000000}},	//   _мозд, ħodh, --, --, 
   {{0xdb0400bc,0xd7cc0073,0x7f5868eb,0x00000000}},	//   tají, स्टच, санс_, --, 
   {{0x6298b4a4,0xdda806ed,0xa3b812eb,0x00000000}},	//   _itto, штол_, _आएँ_, --, 
   {{0x8d84497a,0xbebc00e2,0xdb04022a,0xfcc40116}},	//   дурд, tzīs, rají, чәйм, 
   {{0x6448b4a5,0xa3d00073,0xdb04b4a6,0x00000000}},	//   nnfi, _वाफ_, sají, --, 
   {{0x644800c6,0xe80c0456,0xa3d05b29,0xebc00022}},	//   infi, साना_, _वान_, хәын, 
   {{0xdde85aa3,0x0fc00032,0x00000000,0x00000000}},	//   _ضربه_, _ейән, --, --, 
   {{0xa2c81408,0xa3b800ce,0xca640092,0x00000000}},	// [e850] सूत्, _आएं_, _ለጥያቄ, --, 
   {{0x6298b4a7,0xe6140fb7,0xb804b4a8,0x6448010f}},	//   _otto, _čišč, राइम_, jnfi, 
   {{0x8c5400cf,0x9f4c01d3,0x37ac00fe,0x00000000}},	//   _تئيا, _infó_, _চাদৰ, --, 
   {{0x69f001af,0x00000000,0x00000000,0x00000000}},	//   _пүст, --, --, --, 
   {{0x54e4543c,0x644808a5,0x00000000,0x00000000}},	//   تساق, fnfi, --, --, 
   {{0x99d401d3,0xd7f8010a,0x24840092,0x00000000}},	//   _اتھا, _тум_, ክብሮት_, --, 
   {{0xdb0406d9,0x1704b4a9,0x95c8005b,0xd76000f2}},	//   najà, _ظفری_, _вуза_, _آنزی, 
   {{0x64480a55,0x00000000,0x00000000,0x00000000}},	//   anfi, --, --, --, 
   {{0x6298b4aa,0xd5f801fb,0x35a4013d,0xd58001d5}},	//   _etto, _giú, _маңг, _ўғло, 
   {{0x35d000e1,0xd3a40902,0xe80cb4ab,0xa3d043d1}},	//   _हाड़, _фрап, साया_, _वाय_, 
   {{0x2e2008a5,0x625c0200,0x68e00327,0x00000000}},	//   _hófi_, rëor, ħodi, --, 
   {{0x7bc0438d,0x9f4400a2,0x00000000,0x00000000}},	//   ólun, _çiýg_, --, --, 
   {{0xc1040491,0x823400aa,0xa3d03156,0xe80c00bc}},	//   _يومي, _ترلا, _वाम_, सामा_, 
   {{0xa0981775,0x5ed800bd,0x2c740295,0xc18401d9}},	//   _היסט, _বছরে, dùdù_, _تگى۪, 
   {{0xef180022,0x5da800cc,0x00000000,0x00000000}},	//   _ымк_, _কাৰু, --, --, 
   {{0x3d300084,0xdeb800d9,0x00000000,0x00000000}},	//   ṅwa_, _המקל, --, --, 
   {{0x9ac0025c,0xad24129d,0x68400248,0x00000000}},	// [e860] _ċċek, _رىدى, _nídè, --, 
   {{0x5f4007d6,0x00000000,0x00000000,0x00000000}},	//   _آچیل, --, --, --, 
   {{0x98a0008e,0x00000000,0x00000000,0x00000000}},	//   _җисе, --, --, --, 
   {{0xd6ccb4ac,0xa2c83f55,0x6e240280,0x00000000}},	//   طقه_, संस्, nkkb, --, 
   {{0xd5ac2073,0x7a301511,0xd9d001ec,0xdb0401d3}},	//   افه_, _båtf, _سەلگ, majá, 
   {{0xdb0401d3,0xdab40244,0x00000000,0x00000000}},	//   lajá, _بهێت_, --, --, 
   {{0x6448b4ad,0xe5a421fa,0xd13400c7,0x00000000}},	//   rnfi, _ниви, ҧхь_, --, 
   {{0x1a98010f,0xbebc00de,0x00000000,0x00000000}},	//   זיקע, dzīp, --, --, 
   {{0x4034084c,0x84540137,0x00000000,0x00000000}},	//   депс, _قىرچ, --, --, 
   {{0xe36400a8,0x24480592,0x7a3001e3,0x00000000}},	//   _екзи, _اجري_, _gåtf, --, 
   {{0x6298b4ae,0x442c1600,0xdb04b4af,0xd4780a1e}},	//   _utto, _ild_, kajá, _פאבל, 
   {{0xdb0400e4,0xa22400ae,0x00000000,0x00000000}},	//   jajá, _عرضه, --, --, 
   {{0x5c046345,0x442cb4b0,0xcfac0150,0x00000000}},	//   пява, _kld_, _ﺳﯘﺭﻗ, --, 
   {{0x442c87ed,0x00000000,0x00000000,0x00000000}},	//   _jld_, --, --, --, 
   {{0x9f4c02e2,0x00000000,0x00000000,0x00000000}},	//   _enfò_, --, --, --, 
   {{0xda780212,0x4ddc012c,0xdb0401d3,0xca140395}},	//   сяг_, ग्दै_, gajá, ндсъ, 
   {{0x442cb4b1,0x2ba802ab,0xa3d00490,0xcb600de2}},	// [e870] _old_, करशा, _वाढ_, _r茜ew_, 
   {{0x442cb4b2,0x9ba02033,0x8c4400f3,0x00000000}},	//   _nld_, _سەرى, _пење, --, 
   {{0xc6a43756,0x2e2001a8,0x3a7498c5,0x2ba801f9}},	//   ерчи, _sófi_, _олор, कररा, 
   {{0x442cb4b3,0x00000000,0x00000000,0x00000000}},	//   _ald_, --, --, --, 
   {{0x442cb4b4,0x94a801b9,0xd56800d4,0x00000000}},	//   _bld_, ётда_, цiал, --, 
   {{0xc0cc0020,0xdeb80092,0x451c00cc,0x00000000}},	//   _በሥራ_, ሳለን_, _দেহক_, --, 
   {{0x35b40261,0x442c03cd,0x254c063f,0x6e24143a}},	//   _обвр, _dld_, wụtị_, ykkb, 
   {{0x442cb4b5,0xf9fc00fe,0x00000000,0x00000000}},	//   _eld_, ীসকল_, --, --, 
   {{0x4900038e,0x442c016b,0x00000000,0x00000000}},	//   रियो_, _fld_, --, --, 
   {{0x05740137,0x442cb4b6,0x04c87427,0x7ae46e16}},	//   _ساقد, _gld_, _رومي_, _opht, 
   {{0xe80c07f7,0x2f540139,0xa3d01cc3,0xd2580798}},	//   साता_, ьтис, _वात_, _лцд_, 
   {{0x442c0010,0x00000000,0x00000000,0x00000000}},	//   _zld_, --, --, --, 
   {{0xeb9805f5,0x7ae4b4b7,0x30140120,0xdb0400e5}},	//   жиг_, _apht, _оддр, vajá, 
   {{0x7ae40263,0x00000000,0x00000000,0x00000000}},	//   _bpht, --, --, --, 
   {{0xab2800c0,0xdb0401d3,0x00000000,0x00000000}},	//   цова_, tajá, --, --, 
   {{0xe9d802d5,0xdb2000e5,0x00000000,0x00000000}},	//   ўка_, úráb, --, --, 
   {{0xd940b4b8,0xdb04b4b9,0xed58003b,0xed44003b}},	// [e880] вети, rajá, _фоп_, _іноп, 
   {{0xac740f87,0xdb0401ed,0x00000000,0x00000000}},	//   _تابش, sajá, --, --, 
   {{0x7a30713c,0x442c02d2,0x00000000,0x00000000}},	//   _båtd, _rld_, --, --, 
   {{0x248402d3,0x442c0210,0xe5a44c91,0x00000000}},	//   _ክቡራት_, _sld_, фиди, --, 
   {{0xf7b804a9,0x442cb4ba,0xa3d02232,0x98bc025c}},	//   زدەش_, _pld_, _वाद_, _ġuħ_, 
   {{0x290001e4,0x254c0521,0x442cb4bb,0x9f4c0166}},	//   _irka_, wụsị_, _qld_, _safí_, 
   {{0x442c0247,0xc0c40023,0x2e2008a5,0x5430911a}},	//   _vld_, _ጸለመ_, _hófu_, ضرور, 
   {{0x2900b4bc,0x7a300158,0x442c003e,0xb91000b8}},	//   _krka_, _våtg, _wld_, _phaḍ_, 
   {{0x442cb4bd,0xccf4013f,0xe3b85660,0x00000000}},	//   _tld_, _nsɛ_, _мба_, --, 
   {{0x3f14b4be,0x25a4b4bf,0x2900009b,0x442cb4c0}},	//   едос, lbol_, _mrka_, _uld_, 
   {{0x3eb800f8,0x6d580311,0x629c0561,0xdef80024}},	//   ért_, ştal, ípod, цып_, 
   {{0x25a4b4c1,0x2900b4c2,0x683006ea,0x2c740174}},	//   nbol_, _orka_, _hædd, hædd_, 
   {{0x61e0b4c3,0xa2c8002b,0xa3d001ad,0x6e340200}},	//   _ibol, सूर्, वलप_, ëzba, 
   {{0x7a30964d,0x61e0005c,0x00000000,0x00000000}},	//   _måte, _hbol, --, --, 
   {{0x7a30b4c4,0x2900b4c5,0x00000000,0x00000000}},	//   _låte, _arka_, --, --, 
   {{0x29000b4b,0x25a40427,0x7a30007c,0x6830032e}},	//   _brka_, jbol_, _oåte, _lædd, 
   {{0x61e0b4c6,0xb95400a7,0x7e7c002f,0x25a4022e}},	// [e890] _mbol, хващ, mmsp, dbol_, 
   {{0xc984026a,0xe5a006b3,0x2900892f,0x61e001d5}},	//   ђути, қиши, _drka_, _lbol, 
   {{0xda7800c6,0x61e05946,0x0cd00183,0xb5fc0b4b}},	//   _мям_, _obol, িবৃত, _akša, 
   {{0x290008ad,0x7a3077d4,0xd5b8b4c7,0x7e7c0332}},	//   _frka_, _båte, ісе_, nmsp, 
   {{0x290005a1,0xc9840262,0x3a2801f5,0x7e7cb4c8}},	//   _grka_, _аури, mkap_, imsp, 
   {{0x61e0b4c9,0xe8d4011a,0x2934010f,0x97c4007b}},	//   _abol, _אושר_, _טארן_, _تتحم, 
   {{0x38600158,0xe294010b,0x00000000,0x00000000}},	//   mohr_, нащ_, --, --, 
   {{0x3a28b4ca,0x29004bc1,0xdb043110,0x7e7c00df}},	//   nkap_, _yrka_, majä, jmsp, 
   {{0x850415fa,0x7084006c,0x68300008,0x2c74037e}},	//   _ټولن, нгиз, _fædd, læde_, 
   {{0xed58016c,0x919c0034,0x7e7c0036,0x6830032e}},	//   ҷом_, _ग्रै, emsp, _gædd, 
   {{0xdb04014a,0x3a2820ac,0x9f4c0327,0x30140220}},	//   najä, kkap_, _cafà_, _үдер, 
   {{0xed58a29d,0x61e00ca8,0xf28400ec,0x7e7c02d0}},	//   зом_, _gbol, _ڪھڙو_, gmsp, 
   {{0xd1482df0,0xdb0400c5,0x683000b5,0x00000000}},	//   _بشان_, hajä, _hæde, --, 
   {{0x29cc06d6,0x6830037e,0x2c74037e,0x61e009a8}},	//   _ḽa_, _kæde, kæde_, _zbol, 
   {{0x9b90a413,0x9f4c025c,0xa3d00a8a,0x399402e3}},	//   الفت, _gafà_, _वास_, _ụsa_, 
   {{0xed58b4cb,0x3a28b4cc,0x61e00ac5,0xdb040793}},	//   _ной_, gkap_, _xbol, dajä, 
   {{0x683004ce,0x6d540784,0x7a30b4cd,0x386001c7}},	// [e8a0] _læde, _uxya, _båtb, fohr_, 
   {{0x3a28013c,0xdb040793,0x7a300fac,0xea900131}},	//   akap_, fajä, _råte, _مۇسھ, 
   {{0xdb0400af,0x7a300158,0x569002bf,0x68300321}},	//   gajä, _såte, гаєт, _rædd, 
   {{0xa3d03eaf,0x321c84c9,0x29002625,0x7a300ac8}},	//   _वाह_, _nowy_, _trka_, _påte, 
   {{0x25a4b4ce,0x888414d4,0x29000009,0x2e2002d2}},	//   rbol_, _ағал, _urka_, _hófs_, 
   {{0x61e0b4cf,0x9f4c0548,0x68300fac,0x7a30143a}},	//   _sbol, _lafá_, _bæde, _våte, 
   {{0x6830b4d0,0xe61801af,0x00000000,0x00000000}},	//   _cæde, _едв_, --, --, 
   {{0xa3d01a2a,0x25a401b9,0x7a300fac,0xe7380107}},	//   _वाव_, qbol_, _tåte, _деҳ_, 
   {{0x64c400aa,0xb5fc0010,0x85640022,0x260401f9}},	//   _سيال, _kkšn, _рнаҧ, _सोयी_, 
   {{0xd1b40014,0x00000000,0x00000000,0x00000000}},	//   ٘ایا_, --, --, --, 
   {{0xd24cb4d1,0x9834010f,0x91ac03d4,0x53a0014b}},	//   _ڏنل_, גריף_, _টাৰ্, _сахб, 
   {{0x321c09a5,0x61e0b4d2,0x41440166,0x4ddc00bc}},	//   _gowy_, _ubol, _идең, ग्लै_, 
   {{0x7e7c6b7b,0x9f4c01e1,0x4c94b4d3,0x10a001c0}},	//   rmsp, _dafá_, лияс, _бичн, 
   {{0x35a00023,0x7e7c7664,0x205400d4,0xbf140244}},	//   ልትታት_, smsp, _ятер, _لوتب, 
   {{0x2ce834ef,0x9f4c00d8,0x3a280205,0x8ac401d5}},	//   टबॉल_, _fafá_, tkap_, лётл, 
   {{0xbeec00e1,0xd9c801ad,0xdb0426bb,0x00000000}},	//   जबीन_, िलेट, vajä, --, 
   {{0x3a28b4d4,0x00000000,0x00000000,0x00000000}},	// [e8b0] rkap_, --, --, --, 
   {{0x3a289161,0xdb041057,0x00000000,0x00000000}},	//   skap_, tajä, --, --, 
   {{0x8d74b4d5,0x853802a8,0x38600e78,0xdb0c0241}},	//   _لایا, ɗɗiy, rohr_, _ìjàp, 
   {{0x2c745268,0x6830005c,0xdb040108,0x00000000}},	//   ræde_, _ræde, rajä, --, 
   {{0x6830037e,0xc95801b9,0x2c74005c,0x55700022}},	//   _sæde, _зўр_, sæde_, уҳат, 
   {{0xd6100372,0x22880100,0xdb040108,0x00000000}},	//   _өзгө, yòkè_, pajä, --, 
   {{0xa3d002ab,0x00000000,0x00000000,0x00000000}},	//   _वार_, --, --, --, 
   {{0x05d806ab,0xc30403e6,0x67280158,0x683001bf}},	//   _डायब, ابوو, øfje, _væde, 
   {{0x34948af4,0x3ce80070,0x3ea005ce,0x43840131}},	//   _разр, _npav_, _čita_, نلۇق, 
   {{0x601c012c,0x6d582ac2,0x629c00d7,0x00000000}},	//   _námě, ştak, ípoc, --, 
   {{0x34d01276,0x321c0204,0xada4b4d6,0x6da4b4d7}},	//   _समुद, _towy_, канл, кина, 
   {{0xc0c4069c,0x799c035a,0x00000000,0x00000000}},	//   _ጸገም_, _nfsw, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdca0b4d8,0x799c017a,0xbc180220,0xa134008f}},	//   рари, _afsw, нісі_, _באנק_, 
   {{0x3ce8007f,0x78bc007c,0xca84022e,0x4aac01f9}},	//   _epav_, _avsv, аrаr, टींव, 
   {{0xc0cc001f,0x00000000,0x00000000,0x00000000}},	//   _በጥሩ_, --, --, --, 
   {{0x799c03ac,0xe80c482a,0x23d000bc,0x6c341291}},	// [e8c0] _dfsw, साला_, _सालद, _لفظا, 
   {{0x6ab4014b,0x00000000,0x00000000,0x00000000}},	//   _исмх, --, --, --, 
   {{0xb8640956,0x5e54072d,0x00000000,0x00000000}},	//   ااقو, _سلیس_, --, --, 
   {{0x64a4b4d9,0x601c00bc,0x103c02d3,0x799c02d0}},	//   вада, _zámě, _ክጥቀመ, _gfsw, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa6c8b4da,0x66e4a5de,0x00000000,0x00000000}},	//   _олга_, _иога, --, --, 
   {{0x77905929,0x96d40724,0x53300276,0x661401f4}},	//   _ایما, _истә, иешт, öyks, 
   {{0xa3e003f3,0x7a30007c,0x00000000,0x00000000}},	//   _फॉर_, _kåta, --, --, 
   {{0x23d4035b,0x3e78b4db,0xf4e41291,0x00000000}},	//   _ацер, néte_, _مثلً, --, 
   {{0x7a3003d4,0x6d480134,0x041c00cc,0x74b001af}},	//   _måta, _ɛfat, ভোজী_, _уҡшу, 
   {{0x7a3000bf,0xf1b8005f,0x3fc83321,0x00000000}},	//   _låta, ekšu_, ودگی_, --, 
   {{0xd36cb4dc,0x6b9c02d0,0xbf1001e0,0x3e780022}},	//   _بهم_, _afpg, _ғүмә, kéte_, 
   {{0xa2c800dc,0xdfd0009f,0x00000000,0x00000000}},	//   संक्, _نيش_, --, --, 
   {{0x3e78002e,0xd9c8012d,0x50400354,0xdb040419}},	//   déte_, िल्ट, _кечб, majú, 
   {{0x200c000d,0xbc4400db,0x3d94030d,0xdb040419}},	//   _infi_, _ەرجۉ, _йийр, lajú, 
   {{0x7a30b0aa,0x628c06af,0xce6800c7,0x3e78002e}},	//   _båta, _ébou, _ирыд_, féte_, 
   {{0xa3d0b4dd,0xdb040030,0x787800ee,0x596402e8}},	// [e8d0] वला_, najú, ейар_, тъва, 
   {{0xb5fc01a6,0x981400c6,0x00000000,0x00000000}},	//   _ekšl, خبرا, --, --, 
   {{0xdb040030,0x68303c02,0xd6d8b4de,0xb17c02f0}},	//   hajú, _sædc, ьта_, leťt, 
   {{0xdb0401f1,0x7a300250,0x9a845211,0x799c02d0}},	//   kajú, _fåta, _шупл, _ufsw, 
   {{0x7a3001e3,0x09dc0154,0xdb040419,0x00000000}},	//   _gåta, _ঢোকা, jajú, --, 
   {{0x05740f1b,0xdb040030,0x37ac0183,0x00000000}},	//   جامد, dajú, _চাকৰ, --, 
   {{0xa2c818ea,0x82a40063,0xa85400fb,0x00000000}},	//   संग्, ашње, _серә, --, 
   {{0x200cb4df,0xa530497a,0x00000000,0x00000000}},	//   _anfi_, рнәч, --, --, 
   {{0xf0642ecb,0xf0e80131,0x00000000,0x00000000}},	//   лкип, رىدى_, --, --, 
   {{0xef18b4e0,0xa2c805cd,0x92e84e74,0xa3b86225}},	//   емо_, संख्, _يراق_, _अजय_, 
   {{0xe7f473c6,0x43941086,0x59c001bc,0x00000000}},	//   ीयता_, _тахс, षणार, --, 
   {{0xe808068f,0xe298008f,0x53dc085c,0xdb040030}},	//   _होना_, _טשער, प्रश, bajú, 
   {{0xf1b8242a,0xafe45ded,0xb4f8008f,0x51846dac}},	//   maš_, _болл, עפֿי, _ружа, 
   {{0xf1b8b4e1,0x7a3003cd,0xa2c800cd,0x00000000}},	//   laš_, _råta, सूक्, --, 
   {{0xdef80023,0x7a300055,0xd5d00037,0x00000000}},	//   ላእከ_, _såta, _डांड़, --, 
   {{0xf1b8b4e2,0x6a844ecc,0xff5003e6,0x3e7803df}},	//   naš_, улба, _بخه_, téte_, 
   {{0xe09c01f2,0xeb982a9d,0x98a000db,0x00000000}},	// [e8e0] _kọọ_, _пип_, йите, --, 
   {{0xe738b4e3,0x7a3005ac,0xf1b81a48,0x6a840116}},	//   нез_, _våta, haš_, _әлма, 
   {{0xa3b86225,0xdb0401f1,0xa3d000af,0xaa44014b}},	//   _अजब_, zajú, वलस_, _бенл, 
   {{0xe9a402e8,0x00000000,0x00000000,0x00000000}},	//   _щамп, --, --, --, 
   {{0x0444035b,0x3af40419,0x69d4b4e4,0x00000000}},	//   аҵан, _zťp_, mgye, --, 
   {{0x64a40184,0xdb0401f1,0xe09c01f2,0x69d401d3}},	//   _ҡаба, vajú, _nọọ_, lgye, 
   {{0x68f400a9,0x2d90016b,0x2cb00b88,0xf1b80010}},	//   lwyd, _ogye_, _lwyd_, faš_, 
   {{0x69d4b4e5,0x62b400c6,0x2d90013f,0xddcc0311}},	//   ngye, _ěļļŏ_, _ngye_, docş, 
   {{0x68f40368,0xc0340b3e,0x2cb00142,0xe3b00244}},	//   nwyd, иниј, _nwyd_, _هرا_, 
   {{0x2d90013b,0x41a41b6e,0xdb0401f1,0x34440131}},	//   _agye_, _ग्रस, rajú, _күчи_, 
   {{0xd24c4af1,0xf1b870b1,0x68f40042,0xdb040419}},	//   _کنن_, baš_, hwyd, sajú, 
   {{0x6448b4e6,0x2cb000a9,0x68f4017a,0xdb040419}},	//   lifi, _bwyd_, kwyd, pajú, 
   {{0x2cb00042,0x9d4401f7,0x00000000,0x00000000}},	//   _cwyd_, ائجن, --, --, 
   {{0x2d90b4e7,0xe09c063f,0xdfa4143e,0x9f5c036e}},	//   _egye_, _gọọ_, _صحتي, ndtë_, 
   {{0xa3e400a5,0xa3d01b76,0xabb41321,0xebc00022}},	//   य्य_, _वाई_, расә, цәын, 
   {{0x2d900337,0x7e480014,0x2cb00368,0x69d4b4e8}},	//   _ggye_, _جستہ_, _fwyd_, ggye, 
   {{0x6448b4e9,0x68f40cfd,0x3914b4ea,0xe09c063f}},	// [e8f0] kifi, gwyd, шмар, _yọọ_, 
   {{0x6830b4eb,0x6448b4ec,0x69d4013f,0xf1b800d7}},	//   _pæda, jifi, agye, zaš_, 
   {{0x6448b4ed,0xf1b8b4ee,0x7bc40023,0x2604012c}},	//   difi, ljše_, _idhu, _सोही_, 
   {{0xd5f8004d,0x23d000bc,0x59640395,0x00000000}},	//   _khủ, _साउद, _бъга, --, 
   {{0x6448b4ef,0xf1b8151c,0x629c0216,0x68f40042}},	//   fifi, njše_, ípon, cwyd, 
   {{0x2244b4f0,0x6448b4f1,0x81cc02f5,0xb9f00f7c}},	//   _amok_, gifi, শ্ম_, _ዓሳ_, 
   {{0xf1b807f5,0x7bc4009f,0x91c000fd,0x32342766}},	//   taš_, _mdhu, байҗ, ихис, 
   {{0xb224b4f2,0xe09c063f,0xa2c800dc,0x466801af}},	//   рмил, _sọọ_, संज्, _брум_, 
   {{0x64480796,0x629c00e4,0xf3f801f0,0x00000000}},	//   bifi, ãpor, _инаш_, --, 
   {{0x6448b4f3,0x22440098,0x7bc4b4f4,0xb4d00073}},	//   cifi, _emok_, _ndhu, वढी_, 
   {{0xf1b80bf1,0xc2c47ae6,0x7a3033b8,0x6aa00010}},	//   paš_, _هيلي, _råtn, _čofo, 
   {{0x7bc4b4f5,0xa6e0022c,0x68f40368,0xf1b80784}},	//   _adhu, øðil, ywyd, qaš_, 
   {{0xe09c01f2,0x307401a9,0x05d8000d,0x00000000}},	//   _tọọ_, _кукс, _डासब, --, 
   {{0x7a300267,0x00000000,0x00000000,0x00000000}},	//   _båto, --, --, --, 
   {{0xae1c1533,0xada401fc,0xb00401ee,0x00000000}},	//   _बचपन_, _кайл, _боҙһ, --, 
   {{0xa9a439f6,0x7bc4020c,0x2d90b4f6,0x00000000}},	//   риад, _edhu, _ugye_, --, 
   {{0x6844b4f7,0xec78b4f8,0xe8f800a7,0x6164001f}},	// [e900] анаа, _ипи_, ъла_, _ውጤቶች, 
   {{0x68f4b4f9,0x6448b4fa,0x66e40166,0x69d401d3}},	//   rwyd, xifi, иоза, sgye, 
   {{0xd1c80020,0x6448b4fb,0x68f40368,0x7a30007c}},	//   በሩት_, vifi, swyd, _gåto, 
   {{0xe4a41481,0x6448015d,0x32880150,0x00000000}},	//   арко, wifi, _ﺗﺎﻻﺱ_, --, 
   {{0x6448b4fc,0x3e781de4,0xa3100118,0x00000000}},	//   tifi, néta_, čičí_, --, 
   {{0x2244b4fd,0x61ac17ee,0x7a300267,0x2a700072}},	//   _smok_, घर्ष, _låtl, llyb_, 
   {{0x15e406ab,0x6e34b4fe,0xded40023,0x00000000}},	//   _टॉवर_, _olyb, ካብን_, --, 
   {{0xe808b4ff,0x228400f7,0xd6240556,0xe80c0118}},	//   _होता_, шулг, _косе_, साका_, 
   {{0x1da4b500,0xe3b80124,0x6600848b,0x3e7800e4}},	//   _क्षत, _абз_, mdok, jéta_, 
   {{0x44e0110e,0x6600b501,0x6e340432,0x3e78003e}},	//   mò_, ldok, _alyb, déta_, 
   {{0x6458b502,0x44e0b503,0x7a300efa,0x3d9401b9}},	//   _ijti, lò_, _båtl, йинр, 
   {{0x6e340368,0x9cc864c2,0xa184013d,0x00000000}},	//   _clyb, кыга_, _кылл, --, 
   {{0x44e0b504,0x3e780129,0x00000000,0x00000000}},	//   nò_, géta_, --, --, 
   {{0x78a807c4,0xd12cb184,0x69c4b505,0x44e00ffb}},	//   _çevi, _تمه_, _adke, iò_, 
   {{0x8ff4b506,0x3ea40f31,0x00000000,0x00000000}},	//   _ضرور_, _اشتہ, --, --, 
   {{0xbdb41614,0x44e0b507,0x7a3003cd,0x6e34b508}},	//   _убиј, kò_, _våto, _glyb, 
   {{0x1be407d6,0x69c40076,0x3e78026c,0x09a40150}},	// [e910] _кўнг, _ddke, céta_, _ﺘﺘﻌﹼ_, 
   {{0x44e0b509,0x7bc4b50a,0x60c001f7,0x6600005a}},	//   dò_, _udhu, _mvom, edok, 
   {{0x7c2406a3,0x7e6c0083,0x44e00428,0x2bf40375}},	//   _iohr, _kkap, eò_, _המתן_, 
   {{0x6600b50b,0x00000000,0x00000000,0x00000000}},	//   gdok, --, --, --, 
   {{0x7e6c0451,0xa3d0412f,0x58840c98,0x44e0b50c}},	//   _mkap, वलं_, _выва, gò_, 
   {{0x84241df2,0x7c24b50d,0xdeb80092,0x34940022}},	//   يىنن, _johr, ዳለን_, _ҳаар, 
   {{0x7e6cb50e,0x7c242305,0x60c0b50f,0x66000055}},	//   _okap, _mohr, _avom, bdok, 
   {{0x7e6cb510,0x44e0b511,0x7c24a1cd,0x45d43cc5}},	//   _nkap, bò_, _lohr, _мосс, 
   {{0x7648b512,0x44e0b513,0x54f8000d,0xafe475a0}},	//   _imey, cò_, _एनिए_, бопл, 
   {{0x7e6cb514,0x12e400d6,0x60c0b515,0x7c24b516}},	//   _akap, _відг, _dvom, _nohr, 
   {{0x60c04ff3,0xa6c8022e,0x737400ec,0x88a800eb}},	//   _evom, lzаr, _اٿائ, _ওয়াক, 
   {{0x201c0023,0x7a303402,0x81d4010b,0x3e7800c7}},	//   ajti_, _båtm, _дцшц, téta_, 
   {{0x7c24b517,0x764814af,0x254c063f,0x8fc00124}},	//   _bohr, _mmey, wụzị_, _далҵ, 
   {{0x7e6cb518,0x3e78b519,0x7c24062c,0xa96802a9}},	//   _ekap, réta_, _cohr, ҳиба_, 
   {{0x7e6c03a0,0x76480109,0x60c005b8,0x2d9c013f}},	//   _fkap, _omey, _zvom, ɛten_, 
   {{0xdb140ffb,0x68303774,0xccb40166,0x6d58002f}},	//   _mexè, _pædo, _мәгь, ßtas, 
   {{0xdb14067c,0x00000000,0x00000000,0x00000000}},	// [e920] _lexè, --, --, --, 
   {{0x7648b51a,0x44e06933,0x279406a6,0x7e6c01ef}},	//   _amey, vò_, сшар, _zkap, 
   {{0x660000b5,0x44e00428,0xd1f40b82,0x00000000}},	//   tdok, wò_, ላንታ_, --, 
   {{0x44e0b51b,0x7c24b51c,0x16840133,0xf6440212}},	//   tò_, _zohr, مانێ, охін, 
   {{0x6600b51d,0xb8fc03d4,0x1dd801bc,0x673c0175}},	//   rdok, _থৈ_, _भासत, szpj, 
   {{0x44e0b51e,0x7648b51f,0x6600b520,0xa5c4068f}},	//   rò_, _emey, sdok, dróż, 
   {{0x44e0b521,0x4900197e,0xe7380ce1,0xe5a401f4}},	//   sò_, रिको_, _сев_, _гиби, 
   {{0xd754b522,0x76480076,0x733000db,0xa6e00174}},	//   _الفت_, _gmey, بۉما, øðul, 
   {{0x7e880210,0x00000000,0x00000000,0x00000000}},	//   _uśpi, --, --, --, 
   {{0x7e6c9ee0,0xa3d0205d,0xe29802dc,0xb4240aaa}},	//   _skap, _वाट_, _баж_, _وعلو, 
   {{0x7c24b523,0x6304b524,0x2d9c012c,0x63b8b525}},	//   _rohr, _دوال, ěten_, _ietn, 
   {{0x62980280,0x7c2406a3,0x60c005a1,0x63b85613}},	//   _iuto, _sohr, _tvom, _hetn, 
   {{0x6298b526,0x60c000ca,0x2eec013f,0x63b8b527}},	//   _huto, _uvom, _ɛmfɑ_, _ketn, 
   {{0x6298b528,0x80a4034c,0x63b80e14,0x7a30b529}},	//   _kuto, _همچن, _jetn, _våtm, 
   {{0x63b8b52a,0xf1b8151c,0x7c240810,0x6298b52b}},	//   _metn, ljša_, _vohr, _juto, 
   {{0x63b8a409,0x6298b52c,0x7e6cb52d,0x31780034}},	//   _letn, _muto, _ukap, ższe_, 
   {{0x6298b52e,0xf1b8151c,0x629c0122,0x7c24b52f}},	// [e930] _luto, njša_, ípoj, _tohr, 
   {{0x6298b530,0x63b82501,0x7648b531,0xb900000d}},	//   _outo, _netn, _smey, _धम_, 
   {{0x6298b532,0x7994005b,0xa5c4012d,0x28d817ee}},	//   _nuto, _минф, zróż, यूबि, 
   {{0x63b8b533,0x4e1c0882,0x478821f3,0x638000e5}},	//   _aetn, यायै_, ссум_, zíné, 
   {{0x63b8b534,0x99840024,0x13a405af,0x00000000}},	//   _betn, ėnų_, منشی_, --, 
   {{0x78acb535,0xb9e40020,0x63b81225,0x3e7801f1}},	//   mpav, _ይሄ_, _cetn, kéto_, 
   {{0x6298b536,0x78acb537,0x37040014,0xf1b0007b}},	//   _cuto, lpav, _بوزِ, وءة_, 
   {{0x7d0cb538,0x7648b539,0x6298b53a,0x3dc8b53b}},	//   _oras, _umey, _duto, _ndaw_, 
   {{0x63b8b53c,0xa3d0578b,0xe80c0073,0xf10400db}},	//   _fetn, _वाच_, साचा_, تۉشۉ_, 
   {{0x6298b53d,0xaec413d6,0x63b801a8,0x78ac00d8}},	//   _futo, обол, _getn, ipav, 
   {{0x6298b53e,0x3e780098,0x00000000,0x00000000}},	//   _guto, géto_, --, --, 
   {{0x7d0cb53f,0x76580f7b,0xdb0401d3,0xe2080413}},	//   _bras, nnwy, hajó, rgóð_, 
   {{0x1dd82f0a,0x629801c4,0x7d0c2749,0x3dc80368}},	//   _भारत, _zuto, _cras, _ddaw_, 
   {{0x7d0cb540,0x6298b48b,0x00000000,0x00000000}},	//   _dras, _yuto, --, --, 
   {{0x7d0cb541,0xa3d00490,0x7a303bdc,0x629806be}},	//   _eras, _वाघ_, _kåth, _xuto, 
   {{0xfd980209,0x78ac00de,0x00000000,0x00000000}},	//   _гөрә_, fpav, --, --, 
   {{0x2848010b,0x6cf8074d,0x00000000,0x00000000}},	// [e940] азап_, _тепĕ, --, --, 
   {{0x63640030,0x7658b542,0x7d080115,0xfaa800ec}},	//   nčné, enwy, ĥest, _گهٽي_, 
   {{0x63b86ab9,0x7d0cb543,0x76580368,0x160802e5}},	//   _retn, _zras, fnwy, _सोहर_, 
   {{0x6298b544,0x63b8b545,0x2a08b546,0x7d0c0022}},	//   _ruto, _setn, _темп_, _yras, 
   {{0x443c02c4,0xdb140077,0x63640419,0x787000e4}},	//   thv_, _rexé, kčné, ẽvar, 
   {{0x62980552,0x63b86591,0x7658b547,0x5ea80154}},	//   _puto, _qetn, anwy, _কিসে, 
   {{0x7a3078d0,0xe5a40116,0x63b8b548,0x00000000}},	//   _båth, _миви, _vetn, --, 
   {{0x6298b549,0x444400dd,0x3e780118,0x63b8010e}},	//   _vuto, _کررہ, véto_, _wetn, 
   {{0xdb140036,0x62980de2,0x2d9c0118,0x61f400a2}},	//   _vexé, _wuto, ětel_, _ıyld, 
   {{0xe3147092,0x6298b54a,0x7d0c0240,0x00000000}},	//   _وباب, _tuto, _rras, --, 
   {{0xe7e029da,0x6298079b,0xe2982bb6,0x7d0c00b8}},	//   _पानप, _uuto, _тае_, _sras, 
   {{0x7d0cb54b,0xef0c004b,0x3e7800d5,0x63640419}},	//   _pras, اڼو_, réto_, ačné, 
   {{0x6280b54c,0x5c04311c,0x10a05211,0x7d0c06be}},	//   _ihoo, оява, _жичн, _qras, 
   {{0x7d0cb54d,0xe808b54e,0xa2e80118,0x3a380419}},	//   _vras, _होला_, _léčí_, _slsp_, 
   {{0x62800190,0x7d0c8689,0x76580368,0x29c80137}},	//   _khoo, _wras, ynwy, өттү_, 
   {{0x7d0cb54f,0xb9980395,0x81cc00eb,0x41bc01f9}},	//   _tras, свах_, শ্র_, ोणिस, 
   {{0x7d0cb550,0xc4c41893,0x00000000,0x00000000}},	// [e950] _uras, _جے_, --, --, 
   {{0x78acb551,0x48181e76,0x62801368,0xd7f80e92}},	//   rpav, ожую_, _lhoo, јуа_, 
   {{0x6280b552,0x7a300267,0x35f40212,0xc7c40354}},	//   _ohoo, _låti, зпер, ьсти, 
   {{0x78acb553,0x3b0001b9,0xdb04b554,0xbab000fe}},	//   ppav, _ishq_, sajó, _ছিপছ, 
   {{0x0404015b,0xdb04b555,0x7a3008fb,0x06080006}},	//   লানী_, pajó, _nåti, ўнік_, 
   {{0x6280b556,0x96d002ab,0xe4d00131,0x00000000}},	//   _ahoo, _डिपॉ, رقىد, --, 
   {{0xf48401ed,0x1dd80456,0x15f41291,0x00000000}},	//   _ہائی, _भांत, _وسرح, --, 
   {{0x6280b557,0x3124b558,0x7a30007c,0x00000000}},	//   _choo, здиг, _båti, --, 
   {{0x6280b559,0xd3a41142,0xf484335b,0x00000000}},	//   _dhoo, _дреп, _فائی, --, 
   {{0x628081a5,0x2d9c00bc,0x7a3001e3,0x2ee4005c}},	//   _ehoo, ětem_, _dåti, ttlf_, 
   {{0xfd4cb55a,0x96d002ab,0x2f5402bf,0xd20002dd}},	//   _triệ, _डिफॉ, ятис, _жүйк, 
   {{0x62800731,0x453000db,0x2ee40174,0xd1f40092}},	//   _ghoo, _سۉۉر, rtlf_, _ገፆች_, 
   {{0xf1b80fb7,0x80240014,0x41e40006,0x636400d7}},	//   ljšo_, سریم, _ціха, pčné, 
   {{0x2ee405ac,0xc0040212,0xae1c00af,0xab28b55b}},	//   ptlf_, _опік, _बचवन_, бога_, 
   {{0xdb80b55c,0xf1b809a8,0x4e1c00bc,0x6a84011c}},	//   егри, njšo_, यादै_, злва, 
   {{0x160806ab,0x62800e14,0x2d9400ee,0x61500023}},	//   _सोलर_, _xhoo, _эркс, _ክትበጽ, 
   {{0x3b0006be,0x3e84007b,0x00000000,0x00000000}},	// [e960] _eshq_, _تشوف, --, --, 
   {{0xb86461fa,0x97c001af,0xdb040100,0x3ec401af}},	//   والو, ейфе, rajò, _эсәб, 
   {{0xa9a4b55d,0x040400bd,0x63805e4f,0x7c64b55e}},	//   _нинд, লামী_, _míní, _تايل, 
   {{0xfd4c0055,0x6380007b,0xd5f80051,0x00000000}},	//   _ariṇ, _líní, _chù, --, 
   {{0xb8c40032,0x27e40b45,0x6280b55f,0x18b0010b}},	//   _оҫта_, ƙon_, _rhoo, _зәхр, 
   {{0x2900b560,0xccf4016b,0x6280b561,0x86b402dd}},	//   _iska_, _mpɛ_, _shoo, _жәді, 
   {{0x6280b562,0x78a84ba9,0x16142dfc,0x7a30007c}},	//   _phoo, _çevr, تسەڭ, _såti, 
   {{0x628001e0,0x00000000,0x00000000,0x00000000}},	//   _qhoo, --, --, --, 
   {{0x26d8b563,0xf1a80150,0x00000000,0x00000000}},	//   lupo_, _ﺴﺘﻌﺘ, --, --, 
   {{0x25a46a7d,0x3f980174,0x00000000,0x00000000}},	//   lcol_, øru_, --, --, 
   {{0x6280b564,0xccf4013f,0xdb040882,0x3eb8180f}},	//   _thoo, _apɛ_, yajñ, èrt_, 
   {{0x2900b565,0x31fc025c,0xd378008f,0x31780034}},	//   _oska_, _དྲྭར_, _פראט, ższa_, 
   {{0x61e0b566,0x26d8b567,0x29000589,0x63806b3c}},	//   _icol, hupo_, _nska_, _fíní, 
   {{0xd12c168d,0xd0040228,0x09d4009e,0x26d8b568}},	//   _حمه_, _нече_, হ্মা, kupo_, 
   {{0x2900b569,0x70240014,0x7ae40175,0x9b6801a9}},	//   _aska_, _ترنٕ, _qqht, ёшга_, 
   {{0x4fc00058,0x00000000,0x00000000,0x00000000}},	//   _قەۋە, --, --, --, 
   {{0x61e0007c,0x00000000,0x00000000,0x00000000}},	// [e970] _mcol, --, --, --, 
   {{0x25a40165,0x4cbc011a,0x00000000,0x00000000}},	//   ecol_, _המזג, --, --, 
   {{0x2900b56a,0xa3c042e3,0x26d81c06,0x25a4b56b}},	//   _eska_, ्णन_, gupo_, fcol_, 
   {{0xcf9000c8,0x25a40175,0x00000000,0x00000000}},	//   גטע_, gcol_, --, --, 
   {{0x9f4c0418,0x7a30a075,0xd5f801fb,0xfd4c0055}},	//   _kafó_, _båtv, _chú, _priṇ, 
   {{0x61e0b56c,0xdb14056a,0x00000000,0x00000000}},	//   _acol, _lexí, --, --, 
   {{0x26d8b56d,0xd5f80051,0x95c8014b,0x00000000}},	//   cupo_, _thù, _гуза_, --, 
   {{0x394c0f99,0x25a4011c,0x61e02076,0x21f00131}},	//   _þess_, ccol_, _ccol, نكىس, 
   {{0x68300165,0xc2c40150,0xdb04002f,0xfd4c00b8}},	//   _cædw, _ۋيكي, lbjä, _triṇ, 
   {{0x80dc0034,0x2c74037e,0xd3a40064,0x683001bf}},	//   पढ़े, pædi_, _храп, _pædi, 
   {{0x61e00175,0xb8e80327,0x00000000,0x00000000}},	//   _fcol, _ྋས_, --, --, 
   {{0x7bc005f7,0x61e0b56e,0x90c400d1,0xb0b8030d}},	//   ðlun, _gcol, _еғиз_, _дукх_, 
   {{0x37d40154,0xd24c00e5,0x00000000,0x00000000}},	//   স্যর, _لچک_, --, --, 
   {{0x4e1c0034,0x26d801c8,0x00000000,0x00000000}},	//   याहै_, yupo_, --, --, 
   {{0x3af47edd,0xeab001ed,0x29000718,0x25a42aa8}},	//   нятс, ئٹر_, _sska_, ycol_, 
   {{0xed58b56f,0x25a4011f,0x00000000,0x00000000}},	//   _мой_, xcol_, --, --, 
   {{0xe7e000cd,0x3a28013d,0x00000000,0x00000000}},	// [e980] _पादप, четү_, --, --, 
   {{0x26d8b570,0xf9900c4b,0x6b8001e4,0x5980059f}},	//   tupo_, ابِ_, _ŝogu, тлуб, 
   {{0x6d44b571,0x25a4010a,0xfca812ea,0x00000000}},	//   lzka, tcol_, _وایو_, --, 
   {{0xd6cc006c,0x26d8b572,0x29001c06,0xe57899fd}},	//   شقه_, rupo_, _tska_, озе_, 
   {{0x29007dcc,0x26d8b573,0x61e00076,0x6d442305}},	//   _uska_, supo_, _rcol, nzka, 
   {{0x61e0b574,0x25a4b575,0x6d440010,0x37d40154}},	//   _scol, scol_, izka, স্বর, 
   {{0xae0c0cf1,0xd700b576,0x65c416ab,0xba080092}},	//   ियान_, _изри, _обва, _ዋቢ_, 
   {{0x2604b577,0xd5f80208,0x1fc4012d,0x78c8032e}},	//   _सोची_, _thú, लण्ड, _ósvö, 
   {{0xdb141709,0x7a300627,0x845400db,0x9264074d}},	//   _rexí, _gåtu, _كىرچ, ьрша_, 
   {{0x6d447881,0x203c0023,0x3e7800e5,0xdb1401ef}},	//   dzka, _ፖሎቲከ, méti_, _sexí, 
   {{0x2c200882,0x402400fd,0x0f200b7e,0x442c0356}},	//   मानं_, _үзең, вьям, _iod_, 
   {{0x442cb578,0x61e0b579,0x7a3003cd,0x00000000}},	//   _hod_, _ucol, _jått, --, 
   {{0x442c098d,0x7a302759,0xf1a8b57a,0x60240261}},	//   _kod_, _mått, _رانه_, _одда, 
   {{0x205400d6,0x7a304cab,0xd0040063,0x60c400e5}},	//   _ютер, _lått, _жеље_, ákmu, 
   {{0x442cb57b,0xc10807ae,0x4c94b57c,0x00000000}},	//   _mod_, _hỗ_, тирс, --, 
   {{0x442cb57d,0x7b84313e,0x7a30007c,0x9e6400f2}},	//   _lod_, _ۋادە, _nått, _تاتن, 
   {{0x442cb57e,0x28d802ab,0x6d440034,0x381401a9}},	// [e990] _ood_, यूलि, czka, нмаё, 
   {{0xc108004d,0x442cb57f,0xfca800ec,0x00000000}},	//   _mỗ_, _nod_, _واڌو_, --, 
   {{0xc108001e,0x7a301511,0xade400ab,0x87e401c4}},	//   _lỗ_, _bått, _कामन_, ъюте, 
   {{0x442c0489,0x420800dc,0x00000000,0x00000000}},	//   _aod_, वयोः_, --, --, 
   {{0x442c0f7b,0xc108001e,0xdb14004e,0x4bd82fc0}},	//   _bod_, _nỗ_, _hexà, _عبید_, 
   {{0x25b0b580,0x6830037e,0x6fdc02ab,0x7a30007c}},	//   ıyla_, _sædv, _माइं, _våtu, 
   {{0x442cb581,0x1284031b,0x6d440b21,0x81e800fe}},	//   _dod_, ومتی_, zzka, মজন_, 
   {{0x2f2405bb,0x442c0393,0x2d9c013f,0x2c7400b5}},	//   _lêgë_, _eod_, ɛtew_, lædt_, 
   {{0x442c0f7b,0xc10801fb,0xd4980212,0x799c02d0}},	//   _fod_, _cỗ_, _єра_, _mgsw, 
   {{0x442cb582,0xc10801fb,0x058401fe,0x00000000}},	//   _god_, _dỗ_, _русм, --, 
   {{0xe7e06b9b,0x00000000,0x00000000,0x00000000}},	//   _पासप, --, --, --, 
   {{0x6d44b583,0x442c06f2,0x799c02d0,0x78bc02d0}},	//   tzka, _zod_, _ngsw, _owsv, 
   {{0xc1080016,0x442cb584,0x7a30b585,0x6d440489}},	//   _gỗ_, _yod_, _låts, uzka, 
   {{0x799c02d0,0xafe4457e,0x442c7caa,0xbc1802dd}},	//   _agsw, _чокл, _xod_, місі_, 
   {{0x6d44006d,0xe808006d,0xab2801ca,0x8b0400bc}},	//   szka, _होगा_, чова_, ěřov, 
   {{0xad6805f5,0x799c02d0,0xacc80131,0x2744013a}},	//   _найз_, _cgsw, _егиз_, _líné_, 
   {{0xed58b586,0x0c68036b,0x7a30b587,0xc0ac008f}},	// [e9a0] _хоп_, _озиқ_, _rått, ַיאָ, 
   {{0x1afc00bd,0x2fc40204,0x7a301511,0x00000000}},	//   _উপরে_, nalg_, _båts, --, 
   {{0x3e7800d2,0x78bc02d0,0x442cb588,0x00000000}},	//   wéti_, _ewsv, _rod_, --, 
   {{0x442cb589,0x6674b58a,0xe5a45c25,0x450c0327}},	//   _sod_, ردار, хиди, _གླུར_, 
   {{0x7a30007c,0x00000000,0x00000000,0x00000000}},	//   _vått, --, --, --, 
   {{0x66e43b76,0x2fc4b58b,0xdb1404d4,0x442cb58c}},	//   _пога, jalg_, _hexá, _qod_, 
   {{0x442cb58d,0xc1080051,0x2fc48021,0x00000000}},	//   _vod_, _sỗ_, dalg_, --, 
   {{0x442c38c6,0x6fdc06ab,0x00000000,0x00000000}},	//   _wod_, _माउं, --, --, 
   {{0x442cb58e,0xd5ac00c6,0xc3f400ec,0x00000000}},	//   _tod_, _طفل_, _لتاڙ, --, 
   {{0x442cb58f,0x3f14a784,0xc10801fb,0x0404009e}},	//   _uod_, вдос, _vỗ_, লাহী_, 
   {{0xdef8b590,0x00000000,0x00000000,0x00000000}},	//   чып_, --, --, --, 
   {{0x629c0115,0xa0a4014b,0x00000000,0x00000000}},	//   ŭpos, _задд, --, --, 
   {{0x625c06c8,0xc0e00023,0x382c0023,0x208801a9}},	//   hīok, ዓቶም_, _ተዛሪብ, _ейди_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x799c02d0,0x00000000,0x00000000,0x00000000}},	//   _pgsw, --, --, --, 
   {{0x6b9c0077,0x09dc0135,0x15dc02dd,0x0f78011a}},	//   _egpg, _རྐྱ_, _ﺇﻋﺎﺩ, _מאוב, 
   {{0xa3c05cac,0x7a30b591,0xdb040254,0x00000000}},	// [e9b0] ्णा_, _båtr, vajõ, --, 
   {{0x7e7c8c75,0x80d8012c,0x4974b592,0x2c2000dc}},	//   llsp, _मिने, улус, माणं_, 
   {{0xd6d8b593,0x7e7cb594,0x382c0023,0xc86406dc}},	//   ята_, olsp, _ተዛረብ, утти, 
   {{0x8624011b,0x799c03ac,0x7a303bdc,0xda6401f7}},	//   льче, _ugsw, _våts, _ساجي, 
   {{0x7e7cb595,0x04c80691,0x38c82304,0x00000000}},	//   ilsp, فوني_, _تاجی_, --, 
   {{0x0b58036b,0xd1f4001f,0x3948b596,0x64a00137}},	//   _آشیب_, ዋዕት_, mzas_, шаша, 
   {{0x2fc48784,0xf1b80fb7,0xb5fc01a6,0x39480407}},	//   valg_, ljši_, _ejša, lzas_, 
   {{0x3a285a5f,0x2fc4017a,0x7e7c005c,0x39480064}},	//   njap_, walg_, jlsp, ozas_, 
   {{0x3948b597,0x20c0b598,0xf1b8151c,0xf1d000fb}},	//   nzas_, айым, njši_, гөһө, 
   {{0x683000b5,0x7e7c8700,0xdef80023,0x04d800ec}},	//   _hædr, elsp, ላጥን_, _سگهڻ_, 
   {{0x2fc401f7,0xf1d00cab,0xcdc40124,0x3a28010e}},	//   ralg_, _көпө, ланқ, kjap_, 
   {{0xed58b599,0x2fc4b59a,0x39480100,0x3e78b59b}},	//   дом_, salg_, kzas_, kétu_, 
   {{0x321c017a,0x0404015b,0x00000000,0x00000000}},	//   _inwy_, লারী_, --, --, 
   {{0x320cb59c,0x307800c8,0x3948005f,0x7e7c0c8c}},	//   ldey_, _קאַנ, dzas_, alsp, 
   {{0x39483942,0xbad40953,0x205400c8,0xa3c000e1}},	//   ezas_, літы, _ביסל_, ंरत_, 
   {{0x320cb59d,0x3e78002e,0xa6c800f1,0xda6008ca}},	//   ndey_, fétu_, ېوال_, авси, 
   {{0xac8404a9,0x320c0363,0x3948007f,0x00000000}},	// [e9c0] _игил, idey_, gzas_, --, 
   {{0xe738b59e,0x683000b5,0xd9401fbe,0x3a2800c7}},	//   мез_, _ræds, јефи, ajap_, 
   {{0x7c646aed,0x7a30b59f,0x3948b5a0,0x1cdc031c}},	//   _حايل, _våtr, azas_, _ཤའོ_, 
   {{0x9470af84,0xe9a424fc,0xa9a4086f,0x3e7800e8}},	//   یدوا, _шамп, _шимд, bétu_, 
   {{0xd4e009fe,0x320c0731,0x3948033f,0xd1d00023}},	//   ающи, ddey_, czas_, ረኸት_, 
   {{0x29101446,0x320c058a,0x683001bf,0xb6840220}},	//   mvya_, edey_, _væds, _ەشكى, 
   {{0x683011c0,0x63a801ab,0xc1a401ec,0x00000000}},	//   _fædr, rcfn, лыпқ, --, 
   {{0x468401a9,0x6d5803e0,0x00000000,0x00000000}},	//   _ёқда, ştay, --, --, 
   {{0x64a4b5a1,0xdfd80395,0x00000000,0x00000000}},	//   _раза, мън_, --, --, 
   {{0x7eb805f5,0x320cb5a2,0x00000000,0x00000000}},	//   нгос_, adey_, --, --, 
   {{0x39481570,0x9f5c0200,0xe29800c0,0x00000000}},	//   zzas_, metë_, _жаж_, --, 
   {{0x320c01d9,0x9f5c0240,0xdb040158,0xd35405d0}},	//   cdey_, letë_, mbjø, _ביבי_, 
   {{0xdb04b5a3,0xd00c01d9,0xd24c0244,0x00000000}},	//   lbjø, _ڈلن_, _بنن_, --, 
   {{0x394805d5,0xd00c08de,0x9f5c0240,0x38c801d3}},	//   vzas_, _ولن_, netë_, ہائی_, 
   {{0x7a3078d0,0x3a2801f5,0xdb04b5a4,0x00000000}},	//   _båtp, tjap_, nbjø, --, 
   {{0x9f5c036e,0x39484fe7,0x00000000,0x00000000}},	//   hetë_, tzas_, --, --, 
   {{0x3a280263,0x9f5c0023,0xdc8801c0,0xa3c000c5}},	// [e9d0] rjap_, ketë_, _осол_, ंरा_, 
   {{0x3948b5a5,0x9f5c02d3,0xaf140154,0xfe2001ad}},	//   rzas_, jetë_, াহরণ_, यावस_, 
   {{0x7bc4b5a6,0x320cb5a7,0x76b8010b,0x8d74015e}},	//   _iehu, ydey_, хлер_, _مایا, 
   {{0x7bc402b1,0xb8d802f5,0x320c0014,0xd1f402d3}},	//   _hehu, _ঘট_, xdey_, ዋዕታ_, 
   {{0x7bc4b5a8,0x9f5c036e,0x00000000,0x00000000}},	//   _kehu, fetë_, --, --, 
   {{0x7bc4b5a9,0x320c0014,0xf3e432eb,0x00000000}},	//   _jehu, wdey_, ужко, --, 
   {{0x7bc4b5aa,0x43841e4a,0xdb0408fb,0x00000000}},	//   _mehu, ۇلۇق, gbjø, --, 
   {{0x7bc4b5ab,0x310822bf,0x9f5c007f,0x00000000}},	//   _lehu, енип_, metè_, --, 
   {{0x76580309,0x443c0175,0x9f5cb0c9,0x7124b5ac}},	//   miwy, bkv_, letè_, ارعل, 
   {{0x7658b5ad,0x7bc4b5ae,0x9f5c0240,0x320c0009}},	//   liwy, _nehu, cetë_, sdey_, 
   {{0x9f5c02e2,0x8fd000c7,0x00000000,0x00000000}},	//   netè_, гәқә, --, --, 
   {{0x76580368,0x320c0014,0x7bc400d8,0xdbe0009e}},	//   niwy, qdey_, _aehu, য়োফ, 
   {{0x7bc4b5af,0x31341cb5,0x00000000,0x00000000}},	//   _behu, _щедр, --, --, 
   {{0xdca0b5b0,0x7bc4208d,0x9f5c02e2,0xf2840451}},	//   сари, _cehu, ketè_, _جھڙو_, 
   {{0x7bc402d3,0xae780104,0x6b640a8d,0x2bc428fe}},	//   _dehu, _псих_, уква, वरबा, 
   {{0x9f5c0240,0x00000000,0x00000000,0x00000000}},	//   zetë_, --, --, --, 
   {{0x7bc41132,0x765800a9,0xe8f8b5b1,0x3e780008}},	// [e9e0] _fehu, diwy, эла_, rétt_, 
   {{0x7bc45be4,0xdb1401b8,0x57e403cc,0x9cb80a1e}},	//   _gehu, _bexä, лдум_, _רציח, 
   {{0x7658015d,0x9f5c036e,0x2a641291,0x00000000}},	//   fiwy, vetë_, _مُدّ, --, 
   {{0x64a4b5b2,0x7bc401c7,0x625c00b0,0x16a45211}},	//   гада, _zehu, pīoi, увци_, 
   {{0x7bc4b5b3,0x9f5c02d3,0x42545598,0x00000000}},	//   _yehu, tetë_, ینتر, --, 
   {{0x69c4b5b4,0x83f82c08,0xb3d40116,0x81e80154}},	//   _heke, текс_, айшә, মড়া_, 
   {{0x186418f4,0xf8700150,0x9f5c0240,0x76580042}},	//   _сари_, _بۇلج, retë_, biwy, 
   {{0x69c4b5b5,0xdb0455c2,0x76586b95,0x9f5c036e}},	//   _jeke, rbjø, ciwy, setë_, 
   {{0x69c4398e,0x6600b5b6,0x9f5c5ab3,0x8ca028d4}},	//   _meke, meok, meté_, _गंगो, 
   {{0x69c4b5b7,0x660005da,0x9f5cb5b8,0x232808a0}},	//   _leke, leok, leté_, _пози_, 
   {{0x7bc4b5b9,0x65ac1682,0x249c0ffb,0x69c40086}},	//   _rehu, ṱhuw, _iitm_, _oeke, 
   {{0x69c4b5ba,0x7bc4b5bb,0xa184b5bc,0x66007302}},	//   _neke, _sehu, _йылл, neok, 
   {{0xd24c3567,0xade400af,0x7bc4b5bd,0xd654011a}},	//   _عنه_, _कारन_, _pehu, ריכת_, 
   {{0x9f5cb5be,0x69c4005a,0x3fc801d5,0x7658033f}},	//   heté_, _aeke, _شدتی_, ziwy, 
   {{0x69c4b5bf,0x200c0418,0x60c00433,0x7bc40433}},	//   _beke, _iafi_, _hwom, _vehu, 
   {{0x200cb5c0,0x69c4b5c1,0x60c0b5c2,0x7bc40433}},	//   _hafi_, _ceke, _kwom, _wehu, 
   {{0x200cb5c3,0x69c4b5c4,0x1cdc0135,0x7bc4b5c5}},	// [e9f0] _kafi_, _deke, _ཤའི_, _tehu, 
   {{0x200cb5c6,0x60c0b5c7,0x27e80175,0x2bc41fbc}},	//   _jafi_, _mwom, _ccbn_, वरणा, 
   {{0x200cb5c8,0x69c4b5c9,0x5abc0135,0x60c00337}},	//   _mafi_, _feke, _མཆིམ, _lwom, 
   {{0x69c4b5ca,0x200cb5cb,0x9f5c5051,0x00000000}},	//   _geke, _lafi_, geté_, --, 
   {{0x60c0016b,0xa3c00882,0x765803cb,0x00000000}},	//   _nwom, ्णं_, riwy, --, 
   {{0x69c4b5cc,0x200c0ac5,0x7658b5cd,0x32d49d46}},	//   _zeke, _nafi_, siwy, ацис, 
   {{0x60c0b5ce,0x69c4b5cf,0x249c007f,0xa8540daf}},	//   _awom, _yeke, _ditm_, _терә, 
   {{0x200c0ba7,0x60c0b5d0,0x14c400f2,0x00000000}},	//   _aafi_, _bwom, _مهری_, --, 
   {{0x249c0109,0xd47401af,0x00000000,0x00000000}},	//   _fitm_, _йәкш_, --, --, 
   {{0xb4c0069f,0x6af40003,0x200cb5d1,0xa3c000dc}},	//   ंठी_, _བྱའོ_, _cafi_, ्णः_, 
   {{0x200cb5d2,0x60c004ba,0x53e40124,0x92b00132}},	//   _dafi_, _ewom, _ацҵа, _اڭتا, 
   {{0x60c002e2,0x200c0254,0xf1c80150,0x802402dd}},	//   _fwom, _eafi_, _شوتى_, _ۇرىم, 
   {{0x69c4b5d3,0x200cb5d4,0x60c0b5d5,0x5184b5d6}},	//   _reke, _fafi_, _gwom, _сужа, 
   {{0x69c4b5d7,0x660001c4,0xd24c6a0e,0x1d040063}},	//   _seke, zeok, _بنچ_, јери_, 
   {{0x69c4b5d8,0x660001f7,0xad2400db,0x00000000}},	//   _peke, yeok, _چىبى, --, 
   {{0x200c0c09,0x69c4014b,0xad2400cf,0x00000000}},	//   _zafi_, _qeke, _نىبى, --, 
   {{0x69c4b5d9,0x200c0c09,0x61f43712,0x9f5cb5da}},	// [ea00] _veke, _yafi_, _öyle, veté_, 
   {{0x69c40936,0x49a40220,0x98a00b3b,0x66001418}},	//   _weke, рыңғ, цифе, weok, 
   {{0x69c4b5db,0x249cb5dc,0x6600b5dd,0x28d85d4f}},	//   _teke, _ritm_, teok, यूजि, 
   {{0x68440022,0x00000000,0x00000000,0x00000000}},	//   ынҷа, --, --, --, 
   {{0x9f5cb5de,0x00000000,0x00000000,0x00000000}},	//   reté_, --, --, --, 
   {{0xe3080156,0x6600b5df,0x60c0006f,0x7790b5e0}},	//   _གནདཔ_, seok, _rwom, _کیما, 
   {{0xc3c4052f,0x200cb5e1,0x60c0002d,0xe0b0009e}},	//   _һөйл, _rafi_, _swom, _টটেন, 
   {{0x60c00699,0x200cb5e2,0x91b40395,0xf5440166}},	//   _pwom, _safi_, агът_, рдәү, 
   {{0xf668035c,0x200c00df,0xa1840209,0x00000000}},	//   _صحفه_, _pafi_, шыкл, --, 
   {{0x249c0092,0x156401e0,0x1fa44c91,0x53a0014b}},	//   _uitm_, _әүәҫ_, шриг, _дафб, 
   {{0x200cb5e3,0x63041afc,0x00000000,0x00000000}},	//   _vafi_, _خوال, --, --, 
   {{0x60c0b5e4,0x200c013f,0xe0d801c6,0xee940014}},	//   _twom, _wafi_, _авд_, ٝدُک, 
   {{0x200cb5e5,0x60c00526,0x2244b5e6,0xa1149f6d}},	//   _tafi_, _uwom, _ilok_, _خوشت, 
   {{0xfd4c004d,0x52900220,0x00000000,0x00000000}},	//   _khoắ, _ﺟﺎﯕﯩ, --, --, 
   {{0x2244b5e7,0xfaa8131e,0xcf8401ec,0x00000000}},	//   _klok_, اهري_, _ﺭﺍﻳﻮ_, --, 
   {{0x3e680ec9,0x8e4800cf,0x0f78011a,0x00000000}},	//   _حجتی_, _ۅلۉك_, _שאהב, --, 
   {{0x97a4798c,0xb5dc00cc,0x644806be,0x00000000}},	// [ea10] арел, ণ্ডচ, khfi, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x224481be,0x7cfc007c,0xd9ec000d,0x644800ae}},	//   _olok_, _fårö, _छापत_, dhfi, 
   {{0x7d0c0198,0xb59400d8,0x00000000,0x00000000}},	//   _ksas, биеш, --, --, 
   {{0x38c8b5e8,0xb4c0069f,0x38bc0241,0x22ac012d}},	//   _حاجی_, ंठे_, _dárò_, _ręka_, 
   {{0x2244ab57,0x7d0cb5e9,0xb7f401e2,0x00000000}},	//   _alok_, _msas, _دګرش, --, 
   {{0x4cb0015b,0x22ac0210,0x00000000,0x00000000}},	//   জীপু, _pęka_, --, --, 
   {{0x7d0cb5ea,0x80d803ce,0x9644009d,0x00000000}},	//   _osas, _मिशे, _тэгд, --, 
   {{0x7d0cb5eb,0x64480332,0x0f1c03ba,0x00000000}},	//   _nsas, bhfi, यम्स_, --, 
   {{0x2244001f,0xf3f400f1,0xdb0406ea,0xba000092}},	//   _elok_, _دترک, nbjó, _ልጄ_, 
   {{0x7d0c0605,0x2244b5ec,0xada4086c,0x6da436da}},	//   _asas, _flok_, йанл, йина, 
   {{0x224405c7,0x00000000,0x00000000,0x00000000}},	//   _glok_, --, --, --, 
   {{0x4274b5ed,0xada400d1,0x7cfc007c,0x8144009a}},	//   _بالآ, _қапл, _rårö, _ونمن, 
   {{0xaf48805c,0xac08b5ee,0x5ea40154,0x00000000}},	//   _مشعل_, ынга_, _খবরে, --, 
   {{0x7d0cb5ef,0x291c00b0,0x712400f1,0x00000000}},	//   _esas, _ōta_, _خرڅل, --, 
   {{0xa9a40598,0xdb0400e5,0x00000000,0x00000000}},	//   сиад, émáv, --, --, 
   {{0xdb140077,0x2ee4003a,0xaa440150,0xdcac00db}},	// [ea20] _xexú, lulf_, _ۇندى, _كىي_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2ee403cd,0x7cfc01e3,0xd1c80092,0x00000000}},	//   nulf_, _tårö, ሠሩት_, --, 
   {{0x80d8b5f0,0x2d600134,0xa5242e9a,0x00000000}},	//   _मिले, _kɔe_, ймед, --, 
   {{0x64480597,0x7d0c0076,0x00000000,0x00000000}},	//   thfi, _xsas, --, --, 
   {{0x2244282c,0x54c000d1,0x00000000,0x00000000}},	//   _slok_, ﺮﮔﯜﺯ, --, --, 
   {{0x2244b5f1,0xb9f00023,0x2ee403cd,0x00000000}},	//   _plok_, _ናታ_, julf_, --, 
   {{0x966000a8,0x8238084c,0x6e34047e,0x2ee40158}},	//   _ексе, рзис_, _noyb, dulf_, 
   {{0x80d80574,0xd0a401c0,0x22440ea0,0x256800db}},	//   _मिळे, йтэд_, _vlok_, _саап_, 
   {{0xfd4c0208,0x9f5c0241,0x00000000,0x00000000}},	//   _thoắ, betì_, --, --, 
   {{0x64580f36,0x6e34b5f2,0x37d400bd,0x7a3001ed}},	//   _imti, _boyb, স্কর, _hűtő, 
   {{0x9f94010b,0x00000000,0x00000000,0x00000000}},	//   _güýz_, --, --, --, 
   {{0x91e04d15,0x9f5c0407,0x64580332,0x00000000}},	//   _хоче, metí_, _kmti, --, 
   {{0x9f5cb5f3,0x99640032,0x2bec0073,0x00000000}},	//   letí_, ҡтал, _जाणं_, --, 
   {{0x101000f2,0xdb0403b2,0x00000000,0x00000000}},	//   _ربود, vbjó, --, --, 
   {{0x7d0c03d1,0x9f5c0093,0xda7801c0,0x6e34010b}},	//   _tsas, netí_, уяг_, _goyb, 
   {{0x3834b5f4,0x7e6c0588,0x64580b21,0xdb040162}},	// [ea30] онар, _ijap, _omti, tbjó, 
   {{0x97a4b5f5,0xc3243ee0,0x00000000,0x00000000}},	//   срал, _كە_, --, --, 
   {{0x7e6c168c,0x9f5c0270,0x98c40220,0x2bec08e6}},	//   _kjap, ketí_, рсұл, _जातं_, 
   {{0xceb000c8,0x6458b5f6,0x9f5c012c,0xdfc400f1}},	//   ליע_, _amti, jetí_, _ښي_, 
   {{0xf56c0784,0x7e6cb5f7,0x78ac0869,0xf8b001ed}},	//   _pol葵, _mjap, qqav, _آکر_, 
   {{0xc8640440,0x2c20033f,0x00000000,0x00000000}},	//   _етси, माएं_, --, --, 
   {{0x7e6c07dd,0x53c40137,0x733400d1,0x14a801f9}},	//   _ojap, _ۇزاق, تىغا, _चढवण, 
   {{0x6458003c,0x7a3001d3,0xa2000395,0xb1441422}},	//   _emti, _fűtő, дпъд, жнил, 
   {{0x55c01c5c,0x7648b5f8,0x6458005a,0xfbe0009e}},	//   _маңғ, _iley, _fmti, ম্যত, 
   {{0x6e34b5f9,0x7e6cb5fa,0x764801a8,0x9f5c05d5}},	//   _soyb, _ajap, _hley, petì_, 
   {{0x53440323,0x7648b094,0x62e80014,0x9f5c00d7}},	//   _ухаа, _kley, _نِلہ_, betí_, 
   {{0x7c24b5fb,0x6e34014f,0x2aac0030,0x7e6c0200}},	//   _anhr, _qoyb, _rýb_, _cjap, 
   {{0x76480066,0x2bc40ebb,0x80b0215c,0x00000000}},	//   _mley, वरला, _كەيش, --, 
   {{0xeab84e90,0x7e6cb5fc,0x7648b5fd,0xef1800d8}},	//   ийг_, _ejap, _lley, _вмк_, 
   {{0xeb98b5fe,0x6e340072,0xea580261,0x8d70001f}},	//   рив_, _toyb, арај_, በራቸው_, 
   {{0x6e3402d0,0x3eb800d7,0x00000000,0x00000000}},	//   _uoyb, írte_, --, --, 
   {{0x3de82309,0x673c0175,0x00000000,0x00000000}},	// [ea40] _اعىپ_, wypj, --, --, 
   {{0x673c0023,0x7e6c1710,0x66e400cf,0x00000000}},	//   typj, _zjap, жожа, --, 
   {{0xa9a4b5ff,0x7648b600,0xab28b601,0x9f5c00d2}},	//   _минд, _bley, _тона_, yetí_, 
   {{0x5ef804ac,0x64580ffb,0x7648b602,0xe5a422c3}},	//   יפעד, _smti, _cley, циди, 
   {{0x2408b603,0xd0580b45,0x3d1c02c3,0x9f5c00d7}},	//   инди_, ntuɓ, मिये_, vetí_, 
   {{0x7648b604,0x68f40ea0,0x00000000,0x00000000}},	//   _eley, mtyd, --, --, 
   {{0x7648b605,0x68f4b606,0xdc98010f,0xf71800c0}},	//   _fley, ltyd, ביסל, _літы_, 
   {{0x7648008c,0x5ba400dc,0xca2802dd,0x00000000}},	//   _gley, _खल्व, _ﺣﺰﺏ_, --, 
   {{0x68f4b607,0x7e6c002d,0x00000000,0x00000000}},	//   ntyd, _rjap, --, --, 
   {{0x6458192e,0x2900009f,0x7e6c03cd,0x68f40153}},	//   _umti, _mpka_, _sjap, ityd, 
   {{0x3eb8b608,0x9f5c0270,0xc69400df,0x00000000}},	//   ërt_, petí_, ּאָ_, --, 
   {{0x74c00825,0xdb1c0579,0x13cc015b,0x7e6401e4}},	//   रीकृ, ðvík, _রায়, _ĉips, 
   {{0xa068b609,0x92300150,0x68f4005c,0x00000000}},	//   _када_, _تىنش, jtyd, --, 
   {{0xabb41fc7,0xd12c0133,0x68f4017a,0x9f5c00e4}},	//   зарә, _جمه_, dtyd, retâ_, 
   {{0x7e6c017a,0x68f4017a,0xf7cc2d40,0x00000000}},	//   _tjap, etyd, ﮕﻪﻧﺪ, --, 
   {{0x7e6c1541,0x68f4b60a,0x9f5c0022,0x7e4800e5}},	//   _ujap, ftyd, petâ_, _دستہ_, 
   {{0x7e7cb60b,0x9f5cb60c,0xb95400a7,0x9a640023}},	// [ea50] mosp, letà_, чващ, _ተወከል_, 
   {{0xb910004d,0x764803b2,0x00000000,0x00000000}},	//   _khoả_, _sley, --, --, 
   {{0x7648b60d,0x290001a6,0xcd34b60e,0x00000000}},	//   _pley, _epka_, _فریب, --, 
   {{0x8f980302,0xb90003d4,0x4ef8010f,0x00000000}},	//   ביבי, _দহ_, שלאג, --, 
   {{0xc98400a8,0x68f40142,0x00000000,0x00000000}},	//   _жури, ctyd, --, --, 
   {{0x3a3807de,0x7e7cb60f,0x6ba0010e,0x00000000}},	//   _hosp_, hosp, _ýygý, --, 
   {{0x1ca80f50,0x3244b610,0x9f5c0003,0x23b0009f}},	//   _བཤའ_, зейг, jetà_, رميس, 
   {{0x76480117,0xdbd402f6,0xdb200086,0x7e7c004e}},	//   _uley, lääk, ùrùb, josp, 
   {{0x7e7cb611,0x932400e5,0x00000000,0x00000000}},	//   dosp, _ڈران, --, --, 
   {{0x9324b612,0x3a3800ef,0x6730032e,0x00000000}},	//   _وران, _losp_, _íkjö, --, 
   {{0x66d00166,0xb0a40014,0x9dc01884,0x92685e0c}},	//   _iñká, _کٍتى, ﯩﻨﯩﺸ, _крда_, 
   {{0x359002d3,0x7e7cb613,0x6aa80129,0x814400ec}},	//   _ዝሓትት_, gosp, _éffi, _ڪنهن, 
   {{0x5d6401f0,0x68f4010a,0x9f5c00e4,0xdbd40108}},	//   зиям_, xtyd, tetã_, kääk, 
   {{0x814400b2,0x9f5c004e,0xdbd43110,0x1d041fbe}},	//   _تنهن, betà_, jääk, џери_, 
   {{0x9f5cb614,0x7e7c0158,0x3af4005b,0x00000000}},	//   cetà_, bosp, мятс, --, 
   {{0x9f94008d,0x68f4002d,0x2bec0073,0x00000000}},	//   _צדקה_, ttyd, _जावं_, --, 
   {{0x1ca8025c,0x3a380306,0xceb000fb,0x9f5c0588}},	// [ea60] _བཤར_, _dosp_, _эшһө, petã_, 
   {{0x68f4775d,0x2c20033f,0x9f5c00bc,0x00000000}},	//   rtyd, माओं_, letá_, --, 
   {{0x68f4b615,0xd7ec00c6,0xdc380375,0xbb180212}},	//   styd, اكم_, _העיר, _діяч_, 
   {{0x3a3870b1,0x95c4084c,0x00000000,0x00000000}},	//   _gosp_, пуша_, --, --, 
   {{0x1a9800c8,0x24200075,0x6fbc01f9,0x00000000}},	//   _ליטע, нҗаң, ोरां, --, 
   {{0x1ca80dd4,0xd75400f2,0x9cd4011a,0x94200114}},	//   _བཤལ_, _کلفت_, לונה_, емље, 
   {{0x6aa40585,0x6ad805f9,0x28e0012c,0xd8200354}},	//   _kikf, _बटोर, _पिडि, _ядри, 
   {{0x6ed40d1a,0x779002f2,0x00000000,0x00000000}},	//   _भिजु, _شینا, --, --, 
   {{0x64c4b616,0x7e7cb617,0xd5e40014,0xbfc800d1}},	//   _ريال, vosp, _رٹٕن_, يادە_, 
   {{0xb0dc0ce0,0x6aa4007c,0x63841fbe,0xbed8009d}},	//   _मिरग, _likf, _егза, одох_, 
   {{0x9f5c00d8,0xa2d44caa,0x00000000,0x00000000}},	//   fetá_, _ريشت, --, --, 
   {{0x9f5cb618,0x00000000,0x00000000,0x00000000}},	//   retà_, --, --, --, 
   {{0x9f5c0ffb,0x6280b619,0x1278010f,0x00000000}},	//   setà_, _ikoo, _פאדע, --, 
   {{0x3cec05f9,0xb91001fb,0x3a3801bf,0xdde801d5}},	//   _जमीं_, _thoả_, _sosp_, جرگه_, 
   {{0x6280b61a,0x7e7cb61b,0x1cdc0327,0xdbd4005b}},	//   _kkoo, posp, _ཤའམ_, vääk, 
   {{0x6aa405b1,0x7e7c0113,0x38600129,0x00000000}},	//   _cikf, qosp, wihr_, --, 
   {{0x1dc007b7,0xdbd402f6,0x6aa40115,0x381401d5}},	// [ea70] _व्यत, tääk, _dikf, ммаё, 
   {{0x3a380175,0x00000000,0x00000000,0x00000000}},	//   _wosp_, --, --, --, 
   {{0x6280b61c,0xdbd400af,0x7d1cb61d,0xabf808c3}},	//   _okoo, rääk, lvss, _והתר, 
   {{0x6280b61e,0xf9c4179e,0xdbd40108,0x00000000}},	//   _nkoo, _تحدی, sääk, --, 
   {{0x1ca80135,0xdbd40108,0xdb0408a5,0x00000000}},	//   _བཤས_, pääk, gbjö, --, 
   {{0x6280b61f,0x78bc05b8,0x668007d6,0x28e00037}},	//   _akoo, _itsv, _ییلل, _पिति, 
   {{0xd584168d,0x26c80042,0x69d80118,0x00000000}},	//   _کێشه_, _gwbo_, ůbež, --, 
   {{0xfe1c0037,0x00000000,0x00000000,0x00000000}},	//   _बोलस_, --, --, --, 
   {{0x3f6c0943,0x93a400a8,0xd3a400d8,0x3dc400eb}},	//   ḓulu_, _ешед, _ереп, ্লাল, 
   {{0x6280b620,0x78bc0810,0x8504b621,0x3e7800d7}},	//   _ekoo, _mtsv, _سومن, méty_, 
   {{0x49142871,0x12c40133,0x00000000,0x00000000}},	//   _नैनो_, _رتاپ, --, --, 
   {{0x2bc400cd,0x3eb800e5,0xec100241,0x00000000}},	//   वर्थ, írta_, _ọ̀hú, --, 
   {{0x6aa40158,0x3e7800d0,0x9f5c00e4,0x00000000}},	//   _rikf, néty_, retá_, --, 
   {{0xe8d80156,0x00000000,0x00000000,0x00000000}},	//   ྲེལག, --, --, --, 
   {{0xdca0b622,0xddc8098d,0x9f5c0093,0x3ebc01fb}},	//   тари, žišn, petá_, _gtvt_, 
   {{0x7ae0066d,0x9f500241,0x00000000,0x00000000}},	//   álta, _àdán_, --, --, 
   {{0xac740058,0xa9680022,0x00000000,0x00000000}},	// [ea80] _ياخش, циаа_, --, --, 
   {{0xc5f800cd,0x00000000,0x00000000,0x00000000}},	//   ृज्य_, --, --, --, 
   {{0xe618b623,0xeb98b624,0x6aa42430,0x3ebc05b1}},	//   жде_, _фин_, _tikf, _xtvt_, 
   {{0xfb540583,0x1f340a7c,0xdb04007c,0xa50800d8}},	//   _سرپھ, ורער_, tbjö, жеда_, 
   {{0x69d80053,0x15fc05d7,0x00000000,0x00000000}},	//   _ēteh, ोज़र_, --, --, 
   {{0x62800591,0xdb04b625,0xdb14011f,0x66e40228}},	//   _skoo, rbjö, _gexó, _оога, 
   {{0x62800076,0xca3c0150,0x00000000,0x00000000}},	//   _pkoo, _ﺒﻁﺕ_, --, --, 
   {{0xc1141614,0x00000000,0x00000000,0x00000000}},	//   емиј, --, --, --, 
   {{0x9580771e,0x6280020b,0x1274007b,0xa5444e77}},	//   _алте, _vkoo, بحوث_, _غضرو, 
   {{0xbf341422,0x22ac0210,0x00000000,0x00000000}},	//   енощ, _lęki_, --, --, 
   {{0x3fc8072d,0x00000000,0x00000000,0x00000000}},	//   يدگی_, --, --, --, 
   {{0x6280014b,0x752c00d0,0x5220014b,0x00000000}},	//   _ukoo, ťaze, _афша, --, 
   {{0x8d840209,0x101001b9,0x80d8134e,0xbd4400db}},	//   вурд, ربید, _मिटे, رپسى, 
   {{0x7d1cb626,0x5ab401ec,0x00000000,0x00000000}},	//   rvss, мқор_, --, --, 
   {{0x2560022e,0x00000000,0x00000000,0x00000000}},	//   _jаlb_, --, --, --, 
   {{0x1da4b627,0xdb140789,0x7cd83db7,0xbebc00ef}},	//   _गणपत, _sexó, _емир_, evīg, 
   {{0x88b0016b,0x00000000,0x00000000,0x00000000}},	// [ea90] hwɛf, --, --, --, 
   {{0x3ea8003a,0x7b140816,0x00000000,0x00000000}},	//   _hiat_, _здох, --, --, 
   {{0x7bd4b628,0x3ea8b629,0xd6d80801,0x00000000}},	//   mazu, _kiat_, юта_, --, 
   {{0x7bd4b62a,0xb9340cfc,0x3ea8020c,0x9f5c9226}},	//   lazu, _земј, _jiat_, metä_, 
   {{0x3ea8b62b,0x78bc006f,0x668001d5,0xf4080154}},	//   _miat_, _utsv, ایقل, লাঘর_, 
   {{0xe3e80dd4,0x3ea8b62c,0x7bd400ec,0x37c400c6}},	//   _རྐྱང, _liat_, nazu, _سيرف, 
   {{0x38c8145e,0x7bd409c2,0x3ea800e4,0x22900214}},	//   bîrî_, iazu, _oiat_, گليس, 
   {{0x3ea84460,0x7bd4b62d,0x6b6c01d3,0x00000000}},	//   _niat_, hazu, lőgé, --, 
   {{0x9f5c049b,0x28d000dc,0x00000000,0x00000000}},	//   hetä_, दीपि, --, --, 
   {{0xaec4b62e,0x7bd4009f,0xe800012c,0xa3c007f7}},	//   нбол, jazu, र्पा_, ूरण_, 
   {{0x3ea8a73f,0x1ca80135,0x7bd42360,0x00000000}},	//   _biat_, _བཤུ_, dazu, --, 
   {{0x3ea804ba,0x76581ae4,0xd72c001f,0x9f5c005b}},	//   _ciat_, _çayı, _በቋሚነ, detä_, 
   {{0x61d40302,0x3ea8b62f,0x22ac033f,0x320c0067}},	//   _נוסף_, _diat_, _ręki_, meey_, 
   {{0x320c6928,0x649400e4,0x00000000,0x00000000}},	//   leey_, râig, --, --, 
   {{0xa3c009d9,0xeab000e5,0xa2d011a0,0x00000000}},	//   ूरत_, اٹر_, णीप्, --, 
   {{0x3ea8b630,0x320c3011,0xd0580198,0xe800024a}},	//   _giat_, neey_, ttuɗ, र्ना_, 
   {{0x2bec0412,0x00000000,0x00000000,0x00000000}},	// [eaa0] _जाऊं_, --, --, --, 
   {{0x6d44b631,0x7bd4b632,0x3d1c012c,0xdd780375}},	//   myka, cazu, मिरे_, _מטפל, 
   {{0x6d44b633,0x7c646886,0x3ea8062c,0x320c058a}},	//   lyka, _جايل, _yiat_, keey_, 
   {{0x320c0e14,0xe800007d,0x27e408a9,0x00000000}},	//   jeey_, _रउवा_, şon_, --, 
   {{0x69d4b634,0x320c47ad,0x38c8145e,0x2a600790}},	//   maye, deey_, rîrî_, _imkb_, 
   {{0x69d4b635,0x2bc407f7,0x00000000,0x00000000}},	//   laye, वरटा, --, --, 
   {{0x2bec007d,0x320c0009,0x6d44b636,0x00000000}},	//   _जाईं_, feey_, hyka, --, 
   {{0xd254b637,0x69d4b638,0x320c1574,0x6d440209}},	//   ець_, naye, geey_, kyka, 
   {{0x7bd4b639,0x3ea80649,0x6d4420e5,0xd1b4b63a}},	//   yazu, _riat_, jyka, رايا_, 
   {{0x69d4b63b,0x3ea8b63c,0x7bd4013e,0x577002d3}},	//   haye, _siat_, xazu, _ጸላእቲ_, 
   {{0x442cb63d,0x69d4b63e,0xe80061b8,0x7bd4b63f}},	//   _ind_, kaye, र्या_, vazu, 
   {{0x7bd49854,0x442cb640,0xa2588fcb,0x69d40882}},	//   wazu, _hnd_, _عشاء_, jaye, 
   {{0x7bd4b641,0x69d4b642,0x5c0406bb,0x6448b643}},	//   tazu, daye, нява, okfi, 
   {{0xe8000b9a,0x7ae001ed,0x442c0076,0x3ea8b644}},	//   र्मा_, álto, _jnd_, _wiat_, 
   {{0x7bd439eb,0xc4c40c55,0x69d4420d,0x442cb645}},	//   razu, _گے_, faye, _mnd_, 
   {{0x98a401fa,0x3ea8013c,0x6d44282c,0x442c0162}},	//   _điđa_, _uiat_, byka, _lnd_, 
   {{0x442c0f7b,0xc4c4066d,0x2cb0089c,0x6448449c}},	// [eab0] _ond_, _دے_, _guyd_, kkfi, 
   {{0xb9080a81,0x28e0069f,0x2bec068f,0xdee002d3}},	//   _यि_, _पिरि, _जाएं_, _ሑሴን_, 
   {{0x69d4b646,0xe800033d,0x320c80b0,0x2cb001f5}},	//   baye, _रउरा_, yeey_, _zuyd_, 
   {{0x442cb647,0x69d4b648,0x320c0014,0xaab4012d}},	//   _and_, caye, xeey_, _आंतक, 
   {{0xcc34b649,0x442cb64a,0xd7e400d4,0x34940022}},	//   _شریع, _bnd_, _піво, ҭаҵр, 
   {{0x320c058a,0x22ac0210,0x00000000,0x00000000}},	//   weey_, _lęku_, --, --, 
   {{0x442c0004,0x07a4136b,0x6d44033f,0x320c343b}},	//   _dnd_, _баён, zyka, teey_, 
   {{0x442c0c3e,0xb22408e2,0x5bbc00dc,0x20080254}},	//   _end_, тмил, ्रुव, õbin_, 
   {{0x320c47ad,0x442cb64b,0x94a805d9,0x6d440076}},	//   reey_, _fnd_, _راءِ_, xyka, 
   {{0x442cb64c,0x6d44b64d,0xa5080c75,0x69d4b64e}},	//   _gnd_, vyka, _تىكە_, zaye, 
   {{0x118c0023,0x1dc00073,0xbebc00ef,0x00000000}},	//   _ብድምጺ_, _व्हत, evīb, --, 
   {{0x6d44b64f,0x69d40014,0x5f402374,0x320c058a}},	//   tyka, xaye, شچىل, qeey_, 
   {{0x69d4b650,0x622402dd,0xd00001a9,0x00000000}},	//   vaye, _جونە, _болқ, --, 
   {{0x69d4b651,0xafe40801,0x6d440034,0xeb980354}},	//   waye, _рокл, ryka, диг_, 
   {{0x69d4b652,0x92b000fe,0x6d440124,0x00000000}},	//   taye, জীৰ_, syka, --, 
   {{0x6d449333,0x2910009a,0x6d24030d,0x3e7800e4}},	//   pyka, twya_, _адиз, tĩte_, 
   {{0x69d46adf,0xb5b80183,0x3ce80307,0xad2400cf}},	// [eac0] raye, ুণাচ, _जिये_, _شىدى, 
   {{0x1ca849a6,0xc0f00023,0xaf700092,0xb68400d1}},	//   _བཤག_, _ቀብሪ_, _ጥራትና_, ۇشنى, 
   {{0x442cb653,0x69d4b654,0x5c340375,0x00000000}},	//   _rnd_, paye, _סרטן_, --, 
   {{0x442cb655,0x69d4b656,0x443803cb,0x2568008e}},	//   _snd_, qaye, _ŵr_, маеп_, 
   {{0x26d800b5,0x38300137,0x58d00153,0x00000000}},	//   sspo_, _گۉلز, _коўт, --, 
   {{0x7d08b657,0x442c13d6,0xc1bc00cd,0x00000000}},	//   çesi, _qnd_, ैर्ग, --, 
   {{0x442c0016,0xe800b658,0x6448b659,0x00000000}},	//   _vnd_, र्णा_, rkfi, --, 
   {{0xc794054a,0xc17800ee,0x442c045a,0xa524004e}},	//   _арғы, нҗе_, _wnd_, _имбд, 
   {{0xb504b65a,0x6600b65b,0xe800296e,0x22ac012d}},	//   _مظلو, mfok, र्था_, _ręku_, 
   {{0x442cb65c,0x6600848b,0xd0f007af,0xfcc400c7}},	//   _und_, lfok, _आमरण_, қәим, 
   {{0x6d5801e4,0x9f5c00d7,0x00000000,0x00000000}},	//   ŝtal, letú_, --, --, 
   {{0xe800b65d,0x1ca80135,0x22bc00b4,0x00000000}},	//   र्ता_, _བཤང_, _ọkwa_, --, 
   {{0x88b0013f,0xd00c0214,0xa3e407f7,0xc0e00023}},	//   hwɛb, _ژله_, _भया_, ናቶም_, 
   {{0x60c0b65e,0x21240429,0x1dc041ac,0x5f2400c7}},	//   _itom, _iroh_, _व्रत, _афиз, 
   {{0x60c000b5,0xcb447756,0x8ff40035,0x9a8400f5}},	//   _htom, ахти, _شرور_, вуал, 
   {{0x212403a2,0xbdf406ed,0x60c01155,0x57c800dc}},	//   _kroh_, _спиј, _ktom, िर्ह, 
   {{0x61e0b65f,0x1da41df0,0xd7f80024,0x660085aa}},	// [ead0] _mdol, _गणित, дуе_, dfok, 
   {{0x60c01bb6,0xd7680107,0x6d4801e1,0x00000000}},	//   _mtom, мшед_, _ńfag, --, 
   {{0x61e0b660,0xe800255c,0x60c000b5,0x66000003}},	//   _odol, र्धा_, _ltom, ffok, 
   {{0x60c0b661,0x61e0b662,0x00000000,0x00000000}},	//   _otom, _ndol, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x61e0b663,0x3948b664,0xe800012c,0x9f9801f4}},	//   _adol, myas_, र्दा_, _kääk_, 
   {{0x9f98000d,0x00000000,0x00000000,0x00000000}},	//   _jääk_, --, --, --, 
   {{0x2124020b,0xd9e007f7,0xe294010b,0xd2400131}},	//   _broh_, गणित_, лащ_, рмиқ, 
   {{0x3948b665,0x34940372,0x61e000a9,0x70840137}},	//   nyas_, _баар, _ddol, лгиз, 
   {{0x61e03058,0x60c001e7,0x5bbc1b87,0x201c0332}},	//   _edol, _dtom, ्रोव, gdti_, 
   {{0x60c0b666,0x21240687,0xb8d40327,0xd9e00073}},	//   _etom, _eroh_, _ཛང_, गणात_, 
   {{0x3948b667,0x212403fa,0xf1584727,0xb64400b5}},	//   kyas_, _froh_, _пиеш_, _ｉｃ_, 
   {{0xdde009a5,0xaa4407d6,0x9e600006,0x00000000}},	//   şuşy, қеал, свяд, --, 
   {{0xbf64b668,0x3948b669,0xfba41223,0x61e0182d}},	//   ادیو, dyas_, _गृहम, _zdol, 
   {{0x3ce80490,0x61e0003a,0x321c033f,0xf19000d1}},	//   _जिथे_, _ydol, _kawy_, ﻟﯩﻐﯘ, 
   {{0x2124011f,0x60c002d0,0x321c01ef,0x394808a9}},	//   _yroh_, _ytom, _jawy_, fyas_, 
   {{0xa8043bfd,0x2a700076,0x321c010b,0x3948b66a}},	// [eae0] лзал, rnyb_, _mawy_, gyas_, 
   {{0x3ce8024a,0x00000000,0x00000000,0x00000000}},	//   _जिते_, --, --, --, 
   {{0xa6e4b66b,0x66002959,0x2794b66c,0xdb1401e3}},	//   ужел, tfok, ушар, _sexö, 
   {{0x31780034,0x56900212,0x3948b66d,0xe5780108}},	//   ższy_, баєт, byas_, нзе_, 
   {{0x6600b66e,0x61e0208d,0x752c0030,0x394800b8}},	//   rfok, _rdol, ťazn, cyas_, 
   {{0x6600072d,0x00000000,0x00000000,0x00000000}},	//   sfok, --, --, --, 
   {{0xa69416a4,0x660001d3,0x00000000,0x00000000}},	//   _брај, pfok, --, --, 
   {{0x77903f0b,0xe5a4b66f,0x2124b670,0x60c00072}},	//   _بیما, _биби, _proh_, _ptom, 
   {{0xc3c4b671,0x61e014b2,0x6d5801e4,0xe3f402c9}},	//   _көйл, _vdol, ŝtaj, _مثاب, 
   {{0x64a4b672,0x60c0022e,0x14200023,0x00000000}},	//   _саза, _vtom, ተበልኩ, --, 
   {{0x7f9401c0,0x3948b673,0xc6080154,0x201c0254}},	//   ранх, zyas_, _রোযা_, rdti_, 
   {{0x61e023e0,0xfdc402f5,0x21240165,0x321c00a2}},	//   _udol, ্ল্ড, _troh_, _gawy_, 
   {{0x60c0b674,0x72a0021f,0x394800b5,0x9be40212}},	//   _utom, _بەين, xyas_, лівк, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69d800e2,0x00000000,0x00000000,0x00000000}},	//   _ēter, --, --, --, 
   {{0x8a18010a,0xe80028fe,0x00000000,0x00000000}},	//   лосс_, र्सा_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [eaf0] --, --, --, --, 
   {{0xb7c40588,0x9f980254,0x00000000,0x00000000}},	//   ррақ, _tääk_, --, --, 
   {{0x8d74b675,0x35b4b676,0x8c5400db,0x3948b677}},	//   _نایا, абер, _دئيا, syas_, 
   {{0x7d0c01f2,0x394822d0,0xdddc00d7,0x00000000}},	//   _kpas, pyas_, ávňo, --, 
   {{0x7d0c0327,0xe8001a04,0xbf10000d,0xb4c0012d}},	//   _jpas, र्हा_, ़बुन_, ूठे_, 
   {{0x7d0cb678,0x752c0030,0xa3e4011c,0x00000000}},	//   _mpas, ťazo, адша_, --, 
   {{0x321c0076,0x00000000,0x00000000,0x00000000}},	//   _pawy_, --, --, --, 
   {{0x85b800c6,0x32440108,0x00000000,0x00000000}},	//   _ماكس_, реиг, --, --, 
   {{0xe0d4b679,0x6ec000da,0xe80006ff,0x7d0c009a}},	//   авы_, _mēbe, र्वा_, _npas, 
   {{0xaf04b67a,0xf06401e0,0x7528054e,0x80f802e8}},	//   апол, ркоп, _irez, ухът_, 
   {{0x7d0cb67b,0x8f6400e5,0x2eb40798,0x00000000}},	//   _apas, الجے_, јсос, --, 
   {{0x7528b67c,0x765800a9,0x7d0c0332,0xfe780153}},	//   _krez, nhwy, _bpas, drįs_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x75281225,0x7d0c003e,0xbc181d31,0xb5fc0419}},	//   _mrez, _dpas, лісі_, _omšo, 
   {{0x7d0cb67d,0xaa44b67e,0x00000000,0x00000000}},	//   _epas, аевл, --, --, 
   {{0x7528b67f,0xee080022,0x00000000,0x00000000}},	//   _orez, _реил_, --, --, 
   {{0xebe400db,0x9d4021f3,0x00000000,0x00000000}},	// [eb00] _копп, _меъд, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7528b680,0x91d800cc,0xe8004a18,0x00000000}},	//   _arez, _ধানখ, र्षा_, --, 
   {{0x7528b681,0xa524b682,0x3cec07f5,0xa9680022}},	//   _brez, имед, ševe_, _аима_, 
   {{0x7528b683,0x7d0c05b1,0x64a460a1,0x00000000}},	//   _crez, _xpas, аада, --, 
   {{0x7528b684,0x3ce8068f,0xb6840150,0x6ec000ef}},	//   _drez, _जिसे_, _ۇشقى, _zēbe, 
   {{0x7528b685,0xd36cb686,0x186401ee,0x26dc0241}},	//   _erez, وهه_, _тари_, _ìto_, 
   {{0x7658b687,0x6700063f,0xe8002982,0x00000000}},	//   chwy, _ọkwe, र्रा_, --, 
   {{0x0488052f,0x7528b688,0x443c05d5,0x09d000cc}},	//   _йәки_, _grez, pjv_, িণপা, 
   {{0xa2e489ed,0xa3480408,0x7d0c022e,0xe474b689}},	//   _вожд, _изза_, _rpas, _тубэ, 
   {{0x7528b68a,0xd24c01f4,0xe1f800f3,0x00000000}},	//   _zrez, _дц_, _аге_, --, 
   {{0xdce849ad,0x6d2034ef,0x6f240055,0x00000000}},	//   šičn, मिंग_, _ũucã, --, 
   {{0xc19400ec,0x00000000,0x00000000,0x00000000}},	//   _اداڪ, --, --, --, 
   {{0xdcbc01e4,0x00000000,0x00000000,0x00000000}},	//   ŝĉov_, --, --, --, 
   {{0xd5f002dd,0x1b0c0154,0xdef80150,0x7d0c0210}},	//   рiлг, ায়নে_, _рыл_, _wpas, 
   {{0x254c18a6,0x0f540375,0xd354011a,0xdb0c01e1}},	//   _kēlā_, _כיום_, בילי_, _èdíj, 
   {{0x7d0cb68b,0x97c40a11,0x7878010b,0xa3e400dc}},	// [eb10] _upas, لتام, гйар_, _भयं_, 
   {{0x7528044e,0xe800146c,0x249c0208,0xbc080166}},	//   _rrez, र्ला_, _nhtm_, _şäfı, 
   {{0x765800a9,0x752807f5,0x87d401b9,0x482400db}},	//   thwy, _srez, زغلا, تىلق, 
   {{0xdfc40451,0xb558084c,0x752c0419,0x00000000}},	//   _ڙي_, лиеф_, ťazm, --, 
   {{0x7af42e80,0x85e800d4,0x00000000,0x00000000}},	//   luzt, рдів_, --, --, 
   {{0x75280dd4,0xd404b68c,0x6cd8010f,0x00000000}},	//   _vrez, ряди, אַקצ, --, 
   {{0x1ca8031c,0x7528030a,0x7af4009d,0x76580042}},	//   _བཤན_, _wrez, nuzt, phwy, 
   {{0x07d80f31,0x249c0175,0x00000000,0x00000000}},	//   _مذہب_, _ehtm_, --, --, 
   {{0x733800fd,0x00000000,0x00000000,0x00000000}},	//   _әзер_, --, --, --, 
   {{0x7af4005a,0x00000000,0x00000000,0x00000000}},	//   kuzt, --, --, --, 
   {{0x33940aaa,0x00000000,0x00000000,0x00000000}},	//   _الاز, --, --, --, 
   {{0x3494013e,0x37a80154,0x00000000,0x00000000}},	//   _таҷр, _ওভার, --, --, 
   {{0xeb341178,0x2054728c,0x625c02b5,0x51842377}},	//   ڭىزد, ртөр, pūor, _тужа, 
   {{0x9f5c00bc,0x3ce80490,0xac98b68d,0x00000000}},	//   letý_, _जिरे_, انسا_, --, 
   {{0x20000cc1,0x7af4005a,0x6e440f06,0x00000000}},	//   əki_, guzt, _гейз, --, 
   {{0x9f5801e1,0xff500345,0x00000000,0x00000000}},	//   _ùpá_, _تخه_, --, --, 
   {{0xed0400f1,0x00000000,0x00000000,0x00000000}},	// [eb20] _اوخپ, --, --, --, 
   {{0xe73808e0,0xb864b68e,0x2d900429,0x3cf402f0}},	//   лез_, يالو, _iyye_, ňavý_, 
   {{0xdb04004e,0x00000000,0x00000000,0x00000000}},	//   scjò, --, --, --, 
   {{0xa5d80372,0x6a1400cf,0x249c0175,0x96e800f1}},	//   ابار_, _ابدر, _shtm_, ابلې_, 
   {{0x7c4806af,0x00000000,0x00000000,0x00000000}},	//   _àpré, --, --, --, 
   {{0x68442e2c,0xe854b68f,0x2d900fac,0x68f40205}},	//   _унга, _انسد, _myye_, muyd, 
   {{0xe3b001d3,0x5eb800d1,0x68f42ca8,0x00000000}},	//   _ہرا_, ﻠﺪﯗﺭ, luyd, --, 
   {{0xd254b690,0x3ce8068f,0x254c166a,0xaf700092}},	//   йцы_, _जिले_, _pēlā_, _ጥያቄና_, 
   {{0xe3f8380e,0xe3b00271,0xc1e400fb,0xdfd80395}},	//   _معاش_, _فرا_, бөҙҙ, лън_, 
   {{0xdde86694,0x50b400c6,0x1858008f,0x254c00de}},	//   گرده_, حديد_, ָכטע, _vēlā_, 
   {{0xe2c842cb,0x2000006d,0xd24c00d1,0x68f40051}},	//   _след_, ęki_, بچە_, huyd, 
   {{0x539802e4,0x9f5cb691,0xa3c007f7,0x254c0171}},	//   _גיבו, metü_, ूरक_, _tēlā_, 
   {{0x8cd407f7,0x00000000,0x00000000,0x00000000}},	//   बीलो, --, --, --, 
   {{0x7af4152d,0xa000031c,0x2244011a,0xa8000139}},	//   tuzt, _མཁྲང_, _hook_, _şınd, 
   {{0x2244b692,0x78a8011c,0x9f5c2045,0xabc40150}},	//   _kook_, _èevi, netü_, _ﺒﺸﻌﺎ, 
   {{0x1ca8025c,0x7af4005a,0x22440037,0x7e4800e5}},	//   _བཤམ_, ruzt, _jook_, _خستہ_, 
   {{0x2244b693,0x00000000,0x00000000,0x00000000}},	// [eb30] _mook_, --, --, --, 
   {{0x22442537,0x7af4009d,0x97a4005b,0x9a500092}},	//   _look_, puzt, брел, _መገኘቱ, 
   {{0x38ac01a6,0xdb0c005b,0x78a40fac,0x7c5800e5}},	//   _hžrk_, äjäs, rmhv, _ملکر_, 
   {{0x9f5cb694,0x63d0004b,0x2244045a,0x7ae02a49}},	//   letó_, ېښنا, _nook_, áltu, 
   {{0x22bc01f2,0xe7c80139,0x68f40205,0x00000000}},	//   _ọkpa_, _älğä, cuyd, --, 
   {{0xd838b695,0xd7e400cf,0x36d400f3,0x3f9c01ef}},	//   _сэм_, _دوسۇ_, _могр, _ozvu_, 
   {{0x2244b696,0x7bc402b9,0x95c8b697,0x00000000}},	//   _book_, _mfhu, _буза_, --, 
   {{0x22441382,0x00000000,0x00000000,0x00000000}},	//   _cook_, --, --, --, 
   {{0x2244b698,0x7bc401c7,0x28e000af,0xbbb80037}},	//   _dook_, _ofhu, _पिछि, _आलूक, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2244002e,0x5348010a,0x00000000,0x00000000}},	//   _fook_, _сăнă, --, --, 
   {{0xa6e00008,0x22440205,0xfbc8011a,0x3134004e}},	//   æðil, _gook_, _ית_, _меер, 
   {{0x7bc401e7,0x7e7c0c63,0x00000000,0x00000000}},	//   _bfhu, érpa, --, --, 
   {{0x2244003b,0x7ae40208,0x4254247f,0x53cc08a3}},	//   _zook_, _bvht, _ونەر, _स्मश, 
   {{0x224400e8,0x82640345,0xaa480395,0x6e44014b}},	//   _yook_, _بهۆن, апва_, _мекз, 
   {{0x3cec1591,0x60e00724,0x0b580961,0x00000000}},	//   ševa_, _äxmä, арғы_, --, 
   {{0x7cf00139,0x6844551b,0x59b0009d,0x00000000}},	// [eb40] _cırğ, онаа, дөрс, --, 
   {{0x27940229,0x68f40205,0x18a00150,0x00000000}},	//   ошер, ruyd, даум, --, 
   {{0xd1ec001f,0xf6e400d4,0xaa44030d,0x68f403e0}},	//   ቀሩት_, зцін, _денл, suyd, 
   {{0x2560022e,0x649400e4,0x6ab803b2,0x00000000}},	//   _hаli_, râim, ítfu, --, 
   {{0x2244b699,0xe4a43a29,0x64940022,0x68f40051}},	//   _rook_, орко, sâim, quyd, 
   {{0x2244b69a,0x00000000,0x00000000,0x00000000}},	//   _sook_, --, --, --, 
   {{0x2244b69b,0x6e341c1d,0x7f2c001f,0x7bc00153}},	//   _pook_, _onyb, _ስራዎች, žlug, 
   {{0x7cf006be,0x00000000,0x00000000,0x00000000}},	//   _yırğ, --, --, --, 
   {{0x88b00134,0x256800f7,0xe04807d6,0x7cf00e2d}},	//   hwɛm, _таап_, لشده_, _kırş, 
   {{0x2244213f,0x6e341b3d,0x25840118,0xe0480798}},	//   _wook_, _anyb, _cílů_, рџик_, 
   {{0x6458b69c,0xd7b80bd9,0x22440c30,0xf3c8141b}},	//   _ilti, יציר, _took_, _طبله_, 
   {{0x6e3400d4,0x26c8013a,0x00000000,0x00000000}},	//   _cnyb, _mtbo_, --, --, 
   {{0x6560b69d,0x7bc418f7,0xa3bc01ad,0x00000000}},	//   nzoh, _pfhu, _इला_, --, 
   {{0xd00c3567,0x69c4b69e,0x672c02d0,0xdde801b9}},	//   _لله_, _afke, _orbj, درگه_, 
   {{0x645807a8,0x9f5cb69f,0x69c40175,0x752c0115}},	//   _mlti, retó_, _bfke, ĥazi, 
   {{0x6e3400c0,0x752c0419,0x00000000,0x00000000}},	//   _gnyb, ťazi, --, --, 
   {{0x6458b6a0,0x7e6cb6a1,0x7cf0a090,0x7bc4010a}},	// [eb50] _olti, _imap, _qırğ, _tfhu, 
   {{0x69c40a85,0xb5fc05be,0x7bf800a8,0x6560022e}},	//   _efke, _imši, _унор_, dzoh, 
   {{0x50180302,0x5eb80131,0x6d58010f,0x23dc012d}},	//   שובו, ﻠﺪﯛﺭ, ŝtat, _नज़द, 
   {{0x6458b6a2,0x59640395,0x00000000,0x00000000}},	//   _alti, _дъга, --, --, 
   {{0x672c04f3,0x7e6cb6a3,0x7c2403ee,0x25080214}},	//   _erbj, _mmap, _kahr, مروی_, 
   {{0x7c2409f0,0xfbd80729,0xbbb837e3,0x32d40798}},	//   _jahr, _তাঁত, _आलोक, пцис, 
   {{0x7c24b6a4,0xd6c0073e,0x7e6cb6a5,0x78bcb6a6}},	//   _mahr, _آمری, _omap, _husv, 
   {{0x6458b6a7,0x78bc0e8a,0x7c240477,0xb14403f6}},	//   _elti, _kusv, _lahr, знил, 
   {{0x8624010b,0xe8001428,0x649400e4,0x95c80107}},	//   _юьре, र्का_, kâih, _буҷа_, 
   {{0x7c241b5c,0x7e6c4b5d,0x78bcaa9e,0x6e34017a}},	//   _nahr, _amap, _musv, _snyb, 
   {{0x78b4715a,0x7648003e,0x33981e2f,0xd3400101}},	//   _mizv, _koey, _اناج_, _تفضی, 
   {{0x7c24062c,0x00000000,0x00000000,0x00000000}},	//   _aahr, --, --, --, 
   {{0x7c24b6a8,0x7e6c003e,0x78bc7acb,0x64580108}},	//   _bahr, _dmap, _nusv, _ylti, 
   {{0x7e6c3917,0x7c240100,0x78b405a1,0x4174b6a9}},	//   _emap, _cahr, _nizv, _تامس, 
   {{0x09b407b6,0x7c24b6aa,0xeb98b6ab,0x78bc3f5b}},	//   ंख्य, _dahr, сив_, _ausv, 
   {{0x78b41724,0x76480309,0x78bc55af,0xfec80133}},	//   _aizv, _noey, _busv, _ببوو_, 
   {{0x7c2409f0,0x672c00f3,0x2ebc0f22,0x673c0334}},	// [eb60] _fahr, _srbj, _আবিষ, wxpj, 
   {{0x397810f5,0x78bc0926,0x7c2400ee,0x7e6c0306}},	//   істю_, _dusv, _gahr, _zmap, 
   {{0xe800023e,0x1ae0b6ac,0x4e20012c,0x7e6c0334}},	//   र्गा_, _поэм, _बसाई_, _ymap, 
   {{0x7c240300,0xd6cc31f6,0x78b40810,0x00000000}},	//   _zahr, اقن_, _eizv, --, 
   {{0x6abcb6ad,0xe8700075,0xe5a4b6ae,0x00000000}},	//   _hupf, _كۆرگ, чиди, --, 
   {{0x6abc0e8a,0x66e4255b,0xe800012c,0x43941214}},	//   _kupf, _нога, र्खा_, малс, 
   {{0x7648002d,0x98a0b6af,0x64580381,0x18a0b6b0}},	//   _foey, _чире, _vlti, _чарм, 
   {{0x6abcb6b1,0x246401e2,0x00000000,0x00000000}},	//   _mupf, _کارټ, --, --, 
   {{0x6abc06d6,0x7e6c0055,0xd54401af,0x00000000}},	//   _lupf, _rmap, _епте_, --, 
   {{0x6458b6b2,0x6abc0099,0x7e6cb6b3,0xc39001e0}},	//   _ulti, _oupf, _smap, _иҫлә, 
   {{0x6abc0223,0x3de00154,0xe04801b9,0x00000000}},	//   _nupf, _ভাবল, لشگه_, --, 
   {{0x7c24b6b4,0x0dc8013e,0x53980a1e,0xf3f400fb}},	//   _sahr, зури_, _פיאו, _еңә_, 
   {{0x7c2405b1,0x7d1c01a4,0x82340150,0x00000000}},	//   _pahr, uwss, _ىرچا, --, 
   {{0x3cec08ad,0x6abc0223,0x78bcb6b5,0x7c24036b}},	//   ševo_, _bupf, _rusv, _qahr, 
   {{0x9f60049b,0x78b4b6b6,0x78bcb6b7,0x6abcb6b8}},	//   ävän_, _rizv, _susv, _cupf, 
   {{0x7c24b6b9,0x6abc01b2,0x78bcb6ba,0x7e6cb6bb}},	//   _wahr, _dupf, _pusv, _umap, 
   {{0x7c24ace7,0x6abc0099,0xca743765,0x78bc0477}},	// [eb70] _tahr, _eupf, رافغ, _qusv, 
   {{0x78bc0810,0x7b1819bb,0x97a40f4d,0xc7c40305}},	//   _vusv, _доор_, прел, есци, 
   {{0x6abc015c,0x7e7cb6bc,0xcd3401ed,0x78b4002b}},	//   _gupf, onsp, _قریب, _vizv, 
   {{0x78bcb6bd,0x205002d3,0xab60313e,0x0ba400ee}},	//   _tusv, _ዝገበረ, _شۇقى, _яшым, 
   {{0x3a38b6be,0x78b4b6bf,0x6abc0112,0x7e7c6460}},	//   _insp_, _tizv, _zupf, insp, 
   {{0x7e7c0112,0x3a28b6c0,0x00000000,0x00000000}},	//   hnsp, ldap_, --, --, 
   {{0x7e7c05ac,0xd5f8004d,0x3a3801bf,0x7bd40112}},	//   knsp, _chụ, _knsp_, ibzu, 
   {{0x3a28b6c1,0x7e7c01a4,0xcb140a7c,0x00000000}},	//   ndap_, jnsp, תלק_, --, 
   {{0x3494004e,0x756400e5,0x00000000,0x00000000}},	//   _жаар, _تیشہ_, --, --, 
   {{0xaec4b6c2,0x94200134,0xb6480046,0x00000000}},	//   мбол, _ɔwɛn_, _ﻋﻥ_, --, 
   {{0x3ce8007f,0x8ff001b9,0x93a8072d,0x92a400f3}},	//   _avav_, وزگچ, _طائف_, _ејдл, 
   {{0x6abc66af,0x7e7cb6c3,0xfba000d1,0x00000000}},	//   _rupf, gnsp, _ﺋﯜﺯﯛ, --, 
   {{0x5d6407a5,0x00000000,0x00000000,0x00000000}},	//   диям_, --, --, --, 
   {{0x7e7cb6c4,0x7e64031c,0x00000000,0x00000000}},	//   ansp, _ċipe, --, --, 
   {{0x3a380112,0x320c090e,0xee08022e,0x260c0b9a}},	//   _bnsp_, ofey_, _дейл_, ण्डी_, 
   {{0x6abc0564,0x6fd40154,0x39900248,0x00000000}},	//   _vupf, _দায়ে, _ẹsan_, --, 
   {{0x6abc0564,0x2a70036b,0xac84014b,0x00000000}},	// [eb80] _wupf, riyb_, _огил, --, 
   {{0x6abc0112,0xfba000d1,0xeb9800f3,0x00000000}},	//   _tupf, _ﺋﯜﺭﯛ, _мип_, --, 
   {{0xb6c41ed2,0xea880276,0xca7800db,0x3a3800d7}},	//   есій, _мбол_, _فەست_, _fnsp_, 
   {{0xe80000ab,0xed6c0023,0x2bbc1b6e,0x00000000}},	//   र्जा_, _አንታይ_, ्डवा, --, 
   {{0x69d4b6c5,0x205002d3,0x00000000,0x00000000}},	//   mbye, _ዝገብረ, --, --, 
   {{0xa6e0008c,0xd5f8004d,0x69d403cd,0xe8a00023}},	//   æðsl, _phụ, lbye, _ፈሊጦም_, 
   {{0x320cb6c6,0x649400e4,0x9f4803e0,0x00000000}},	//   ffey_, kâiv, übü_, --, 
   {{0x69d4b6c7,0xd5ac00aa,0x66e4023b,0xe5a400cf}},	//   nbye, اځې_, _ноҳа, _жиби, 
   {{0x53cc4309,0x7e7c03b2,0x2fc8010e,0xa3e8011c}},	//   _स्वश, vnsp, _şaga_, _мдаа_, 
   {{0x7e7c02c4,0xe8003174,0x3dc8031c,0x69cc012c}},	//   wnsp, र्चा_, _sfaw_, धुती, 
   {{0x69d4b6c8,0x3ce80174,0xe2980d33,0x68f40142}},	//   kbye, _svav_, _даж_, hryd, 
   {{0xe28407d6,0xf1a839b1,0x68f4b6c9,0x0e340212}},	//   _ўлди, _کامه_, kryd, внюю, 
   {{0x7e7c9442,0x628022a9,0x69d4b6ca,0x5c0402e8}},	//   rnsp, _ijoo, dbye, мява, 
   {{0x68f41257,0xd6dc0034,0x270c0037,0x00000000}},	//   dryd, ółka_, _सहूर_, --, 
   {{0xa2d00073,0x9e64007b,0x00000000,0x00000000}},	//   णीच्, _يابن, --, --, 
   {{0xe80013da,0x62800083,0x68f40368,0xda7800d4}},	//   र्घा_, _jjoo, fryd, іяв_, 
   {{0x3834b6cb,0x3a28b6cc,0x68f4a530,0x00000000}},	// [eb90] ннар, rdap_, gryd, --, 
   {{0x87d4007b,0x628000ef,0xb8941411,0x00000000}},	//   نغما, _ljoo, رلاع, --, 
   {{0x0c74b6cd,0xa5080003,0x3a28b6ce,0x35f42083}},	//   _جديد, _གདུག_, pdap_, епер, 
   {{0x68f4b6cf,0x6280b6d0,0x05740131,0x6ec000ef}},	//   bryd, _njoo, ھاند, _bēbj, 
   {{0x05740220,0xceb40375,0xa2b000bc,0x00000000}},	//   پاند, דיף_, आगन्, --, 
   {{0x62807d05,0x00000000,0x00000000,0x00000000}},	//   _ajoo, --, --, --, 
   {{0xd6181ec7,0x00000000,0x00000000,0x00000000}},	//   _وترا_, --, --, --, 
   {{0x3124b6d1,0xf1b801ef,0x00000000,0x00000000}},	//   едиг, keše_, --, --, 
   {{0xf1b81e31,0xafe42c68,0xd498119e,0x00000000}},	//   ješe_, нопл, _држ_, --, 
   {{0x628004ba,0x752c01f1,0x7658b6d2,0x00000000}},	//   _ejoo, ťazs, lkwy, --, 
   {{0x69d40158,0x2d9c012d,0x1fe400f1,0xdfe401c6}},	//   ybye, ętem_, رکوي_, эдэд_, 
   {{0x2d941e76,0x76580ea0,0x69d4003b,0x68f473b0}},	//   ергс, nkwy, xbye, yryd, 
   {{0x2bbc194b,0x649400e4,0x00000000,0x00000000}},	//   ्डला, râiv, --, --, 
   {{0xe00409fd,0x68f405e4,0x81440451,0x628001bf}},	//   _शायद_, vryd, _جنهن, _zjoo, 
   {{0xdca000a8,0x6fd438d2,0x26fc012c,0x6a8402e8}},	//   уари, _म्यू, _उमेर_, елва, 
   {{0x68f4b6d3,0xada4b6d4,0xdee0014b,0x00000000}},	//   tryd, _пайл, _соъи, --, 
   {{0xe8f8b6d5,0x65b4b6d6,0xf1b801ef,0xe968009d}},	// [eba0] яла_, _mühü, beše_, чаал_, 
   {{0x69d43c12,0x68f47664,0x00000000,0x00000000}},	//   sbye, rryd, --, --, 
   {{0xe618b6d7,0xeb980408,0x68f401e3,0x00000000}},	//   зде_, _хин_, sryd, --, 
   {{0x68f4b6d8,0x7658017a,0xa5082cc8,0xb17c0419}},	//   pryd, gkwy, зеда_, zaťa, 
   {{0xbebc00e2,0xd5e401d3,0x64940022,0x00000000}},	//   lvīt, رٹون_, kâit, --, 
   {{0xd4641d9b,0xdce805ce,0x00000000,0x00000000}},	//   ниче_, šićn, --, --, 
   {{0x544000d1,0x00000000,0x00000000,0x00000000}},	//   انىك, --, --, --, 
   {{0xa508213d,0x17980bd9,0xaf24045e,0x2d9c033f}},	//   _неба_, _זילב, যমাণ_, ętej_, 
   {{0xc0f0001f,0x042400c7,0xcb800092,0xbaac01ec}},	//   _ቀጥሎ_, _изаҟ, _የድህረ_, _ﺳﯟﺳﺎ, 
   {{0x660001ed,0x64940356,0xb4f000db,0x2328283c}},	//   lgok, tâiu, _түшч, _нози_, 
   {{0x3f980ad9,0x628001c7,0x931002dd,0xd12c7c3f}},	//   æru_, _tjoo, _مولش, _өх_, 
   {{0x66003824,0x62800067,0xd12c0133,0xc0f00092}},	//   ngok, _ujoo, _گمه_, _ቀጥል_, 
   {{0x71700451,0x6fd0206b,0x8d846d64,0x00000000}},	//   _پڇيا, _द्वं, гурд, --, 
   {{0x60c00421,0x21240d51,0x2cb80022,0xd12cb6d9}},	//   _iuom, _isoh_, _cipd_, _دمه_, 
   {{0x60c00664,0x6600b6da,0xf1b802f0,0xdb204c8b}},	//   _huom, kgok, reše_, دوزی, 
   {{0x60c0b6db,0x61e003e0,0xefcc0092,0x9ba00137}},	//   _kuom, _jeol, ቢያው_, _ەەسى, 
   {{0x60c002f6,0x3ea8b6dc,0x55c00131,0x98a80055}},	// [ebb0] _juom, _ihat_, қалғ, _arcā_, 
   {{0x61e0b405,0x3b540f74,0x60c0b6dd,0xb8e82c82}},	//   _leol, _акор, _muom, _लं_, 
   {{0x3ea8b6de,0x60c002f6,0x61e00327,0x92b800cc}},	//   _khat_, _luom, _oeol, _অব্_, 
   {{0x201cb6df,0x660066b0,0xb5fc0010,0x212400d7}},	//   heti_, ggok, _olše, _osoh_, 
   {{0x201cb6e0,0x60c00953,0x765862f1,0x00000000}},	//   keti_, _nuom, rkwy, --, 
   {{0x201cb6e1,0x3ea8079b,0x61e02ab9,0x660001c6}},	//   jeti_, _lhat_, _aeol, agok, 
   {{0x60c00b23,0x2124007f,0xe360005b,0x478401af}},	//   _auom, _asoh_, икши, _бытб, 
   {{0x3ea80016,0x61e000c6,0xe7a40131,0x715817a0}},	//   _nhat_, _ceol, _شۇنى_, дрос_, 
   {{0x201cb6e2,0x60c0037e,0x61e0030a,0xb59400c7}},	//   feti_, _cuom, _deol, _риаш, 
   {{0x85746afe,0x60c0b6e3,0x9060425b,0x201cb6e4}},	//   _слух, _duom, اندۇ, geti_, 
   {{0x61e0b6e5,0x60c0003a,0x6494035b,0x00000000}},	//   _feol, _euom, râit, --, 
   {{0x3ea82f75,0x32540e92,0xf1d022fd,0x00000000}},	//   _chat_, _швер, _төкө, --, 
   {{0x201cb6e6,0x26fc028a,0x60c003f9,0x1e800024}},	//   beti_, _उम्र_, _guom, рлям, 
   {{0x201cb6e7,0xe0cc0014,0x660002ce,0x42440124}},	//   ceti_, _بٲو_, zgok, _ахәб, 
   {{0x3af4b6e8,0x61e00472,0x60c000b5,0x6f740131}},	//   лятс, _yeol, _zuom, ﻼﺭﻏﺎ_, 
   {{0x61e01709,0x3ea8b6e9,0x3a980108,0x00000000}},	//   _xeol, _ghat_, етую_, --, 
   {{0x19c001c0,0x2cb8007f,0xa92401d5,0x365c0023}},	// [ebc0] рбум, _tipd_, ъдал, _ገምጋማ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb8e8032c,0x6a841cb3,0x4f740023,0x3ea801a9}},	//   _लू_, _ална, _ኣንበሳ_, _yhat_, 
   {{0x201cb6ea,0xc6080154,0xe578009b,0x00000000}},	//   zeti_, _রোজা_, мзе_, --, 
   {{0x61e0b6eb,0x201cb6ec,0x6600b6ed,0x9b905439}},	//   _reol, yeti_, rgok, _ملیت, 
   {{0x61e0b6ee,0x60c00099,0x201cb6ef,0x00000000}},	//   _seol, _ruom, xeti_, --, 
   {{0x60c0426d,0x65c4b6f0,0x61e0b6f1,0x886800a2}},	//   _suom, _абба, _peol, _görỳ, 
   {{0x201cb6f2,0x3cec0552,0x60c00108,0x64940356}},	//   weti_, ševi_, _puom, tâis, 
   {{0x201cb6f3,0x61e0b6f4,0x60c00483,0xe0c805ac}},	//   teti_, _veol, _quom, লীনভ, 
   {{0xb424a4ca,0x61e04fb0,0x201c003a,0x3ea800a2}},	//   _معمو, _weol, ueti_, _shat_, 
   {{0x442c3c60,0x3ea8b6f5,0xa204b6f6,0x7054030f}},	//   _iad_, _phat_, _апед, انپا, 
   {{0x442cb6f7,0x60c0b6f8,0x201cb6f9,0xd0580198}},	//   _had_, _tuom, seti_, kruɗ, 
   {{0x442cb6fa,0xcec00118,0x81e80154,0x9be400d4}},	//   _kad_, _peří_, _বাপ_, ківк, 
   {{0x3ea80052,0x201c03b4,0x442cb6fb,0x2054b6fc}},	//   _what_, qeti_, _jad_, _штер, 
   {{0x3ea8b6fd,0x8ac4036b,0x16100cf1,0x442c0c18}},	//   _that_, иётл, ण्डर_, _mad_, 
   {{0x442cb6fe,0x8d7404a9,0xcfb40a1e,0xf1b801a6}},	//   _lad_, _ھايا, _בלוי_, leša_, 
   {{0x442c0489,0xceb40a1e,0xbf1401d5,0x8d74b6ff}},	// [ebd0] _oad_, _דיק_, _شوکب, _پايا, 
   {{0xf1b8b700,0x7d0cb701,0x00000000,0x00000000}},	//   neša_, _iqas, --, --, 
   {{0xae080a8a,0x766400f1,0x2298036e,0x00000000}},	//   _वामन_, هیسې_, lëku_, --, 
   {{0x442c0d62,0x41b4b702,0xc6a4b703,0x1de000cd}},	//   _aad_, ुशास, арчи, परित, 
   {{0x442cb704,0x7d0c025c,0x00000000,0x00000000}},	//   _bad_, _jqas, --, --, 
   {{0x442cb705,0xf1b81e31,0xc0cc001f,0x7d0c0135}},	//   _cad_, ješa_, _አሥራ_, _mqas, 
   {{0x442cb706,0xf1d000f7,0x799c0142,0x1de007b6}},	//   _dad_, бөлө, _hysw, परात, 
   {{0x442cb707,0x7d0cb708,0xb22400f3,0x67380162}},	//   _ead_, _oqas, умил, _átja, 
   {{0x442c387b,0x3f9c0124,0x6aa80221,0x644804cc}},	//   _fad_, _ayvu_, _ëffe, bjfi, 
   {{0x442cb709,0x7528b70a,0x058401c6,0xd3440330}},	//   _gad_, _isez, _тусм, _لیته_, 
   {{0x7d0cb70b,0x00c80032,0x00000000,0x00000000}},	//   _aqas, нлөк_, --, --, 
   {{0x442cb70c,0x00000000,0x00000000,0x00000000}},	//   _zad_, --, --, --, 
   {{0x442cb70d,0xf1b801a6,0x00000000,0x00000000}},	//   _yad_, beša_, --, --, 
   {{0x2d9c0aed,0x442c01d9,0xafe400fd,0xab28b70e}},	//   āte_, _xad_, _сокл, нога_, 
   {{0x7d0cb70f,0x799c127b,0x3f9c00c0,0x00000000}},	//   _eqas, _aysw, _gyvu_, --, 
   {{0x75280173,0xddcc0276,0x6f00b710,0x799c0042}},	//   _osez, ricţ, mulc, _bysw, 
   {{0xed58a3c3,0x75280223,0x799c00a9,0xd940b711}},	// [ebe0] _чоп_, _nsez, _cysw, бети, 
   {{0xd0580198,0x00000000,0x00000000,0x00000000}},	//   rruɗ, --, --, --, 
   {{0x442cb712,0x7528b713,0x25a00010,0xcb980133}},	//   _rad_, _asez, _škl_, _شۆرش_, 
   {{0x442c0c18,0x799c015d,0x48e8012c,0x24e800cf}},	//   _sad_, _fysw, _चौथो_, емди_, 
   {{0x442cb714,0x24f4b715,0xbd74001f,0x799c03cb}},	//   _pad_, учер, _አንተም_, _gysw, 
   {{0x442cb716,0xc8780205,0x6f0000e5,0x661400b8}},	//   _qad_, _öğ_, kulc, _śakā, 
   {{0x442cb717,0x7528b718,0x69d8013f,0x81e8009e}},	//   _vad_, _esez, _ɑten, _বাব_, 
   {{0x442cb719,0x6f00b71a,0xc0cc001f,0xbd040036}},	//   _wad_, dulc, _አሥር_, nnéë, 
   {{0x98a8054e,0xf1b80841,0x9f401432,0x00000000}},	//   _urcă_, teša_, şkü_, --, 
   {{0xdef82b41,0xb9080521,0x3f1455c3,0x442c45a7}},	//   ным_, _achị_, адос, _uad_, 
   {{0x4ab40490,0x02c400fb,0x00000000,0x00000000}},	//   ंगाव, _тиеү, --, --, 
   {{0x91e021fa,0x1ea815eb,0x00000000,0x00000000}},	//   _гоце, عادي_, --, --, 
   {{0xf1b80e04,0x0d540023,0x00000000,0x00000000}},	//   peša_, _ዝኸፈል, --, --, 
   {{0xf1a81272,0x5b24109a,0x69b880f3,0x799cb71b}},	//   _شانه_, льба, ्शनी, _rysw, 
   {{0xd1c80092,0xd004009b,0x00000000,0x00000000}},	//   _አስብ_, _сеје_, --, --, 
   {{0xa3bc00ab,0x7d0c0003,0xc68400f1,0xb5fc0c5e}},	//   _ेलन_, _tqas, _رې_, _olša, 
   {{0x7d0c0117,0xb8f400be,0x00000000,0x00000000}},	// [ebf0] _uqas, شكاب, --, --, 
   {{0x2c643f04,0x4cd4004b,0x2be400dc,0xa8000139}},	//   _pôde_, _اغيز, करणं_, _şırd, 
   {{0x97a4b71c,0x75281418,0x57a45f2d,0xb6c401c6}},	//   урал, _ssez, ушаа, рөгд, 
   {{0x3cec2f61,0xb5fc01ef,0x7bdc0154,0x00000000}},	//   ševu_, _blša, _বায়ো, --, 
   {{0x5884b71d,0xb4b4487f,0x00000000,0x00000000}},	//   _быва, айдш, --, --, 
   {{0xc4844dba,0xc0cc0020,0x752809a8,0x2008004e}},	//   блік, _አብሮ_, _vsez, òbil_, 
   {{0xd7340020,0x0fe40131,0x00000000,0x00000000}},	//   _የሚሆነ, ңлиқ_, --, --, 
   {{0x75280897,0x6f00b71e,0x31140a5b,0xdef80023}},	//   _tsez, vulc, афос, ፋእን_, 
   {{0xf064a19b,0x7528b71f,0x39481709,0x60e4b720}},	//   икип, _usez, nxas_, амым_, 
   {{0x3948b721,0x6f000198,0x81e800fe,0x3244721b}},	//   ixas_, tulc, _বাণ_, انکف, 
   {{0xae0806ab,0x00000000,0x00000000,0x00000000}},	//   _वादन_, --, --, --, 
   {{0xed58b722,0xd1c8b723,0x6f002d7c,0x00000000}},	//   вом_, _чужд_, rulc, --, 
   {{0xa6940375,0x8fc000c7,0x6f00b724,0x1f480240}},	//   שכרה_, _лалҵ, sulc, _ንዘይም, 
   {{0x6f00b725,0x316c030a,0xd05801e4,0x50a000d1}},	//   pulc, mzez_, ltuɾ, _دەخل, 
   {{0xb8c400d1,0x00000000,0x00000000,0x00000000}},	//   ەزمى, --, --, --, 
   {{0xda60576f,0x00000000,0x00000000,0x00000000}},	//   овси, --, --, --, 
  
   {{0x93f401f9,0x00000000,0x00000000,0x00000000}},	// [ec00] ीलाच_, --, --, --, 
   {{0x6b9c3bba,0xe73801ec,0x00000000,0x00000000}},	//   _typg, кез_, --, --, 
   {{0x65c400d8,0x00000000,0x00000000,0x00000000}},	//   абеа, --, --, --, 
   {{0x76a800d4,0xf4bc0150,0x97a4030d,0x00000000}},	//   гтів_, _ﺠﺎﺭﺜ, ăрал, --, 
   {{0x963002d5,0x83f8014b,0xf6080b24,0xf1b80064}},	//   ўніц, гелс_, اتمه_, dešo_, 
   {{0x29100472,0x045800c6,0xf53802f0,0x18a008da}},	//   mtya_, طلبة_, _drť_, _маям, 
   {{0xed780023,0xe4d401b9,0xdc3400df,0x00000000}},	//   _ኣስቴር_, _چقرد, שאצט_, --, 
   {{0xd2541c22,0xe7d0012c,0xc1a401ec,0x39900248}},	//   ицы_, दुरप, йыпқ, _ẹsin_, 
   {{0x2910b726,0x26d802f6,0x00000000,0x00000000}},	//   ntya_, lppo_, --, --, 
   {{0x64a42ba5,0x2910b727,0x2008b728,0x00000000}},	//   _таза, itya_, übi_, --, 
   {{0x50b40597,0x93c80014,0xd24c0451,0x00000000}},	//   جديد_, _شالہ_, _ڪنن_, --, 
   {{0xd10400f2,0x00000000,0x00000000,0x00000000}},	//   دقیه_, --, --, --, 
   {{0x403400ee,0xc0d42309,0x56b4010f,0xd24c009f}},	//   _гелс, _ايتب, יפטן_, _تنن_, 
   {{0x51580375,0x00000000,0x00000000,0x00000000}},	//   _בכדו, --, --, --, 
   {{0x2c140882,0x61300166,0x00000000,0x00000000}},	//   द्धं_, bılç, --, --, 
   {{0x8f980302,0xd90c6676,0x8e74007b,0x09b00154}},	//   _שיהי, ویج_, _وايض, কশনা, 
   {{0x7e7cb729,0x394800d8,0x69d4033f,0x00000000}},	// [ec10] misp, uxas_, बड़ी, --, 
   {{0x7e7cb72a,0xe79403e6,0x39480005,0xb7c40124}},	//   lisp, ڕانک, rxas_, срақ, 
   {{0x7bc4b72b,0x291004ba,0x8d74158b,0x9fbc013a}},	//   _ighu, atya_, _هایا, _očím_, 
   {{0x7e7cb72c,0x35b401af,0xb8ec0154,0x870800d4}},	//   nisp, ббер, _রব_, реїв_, 
   {{0x04c805d4,0xc984014b,0xd90c2313,0x2da00150}},	//   لوني_, _дури, _زیا_, _ﺍﺭﻟﻰ_, 
   {{0x7e7cb72d,0xb17c00d7,0x613008a9,0x00000000}},	//   hisp, saťk, zılç, --, 
   {{0x7e7c4f6b,0x43f81cb8,0xf1d000cf,0x00000000}},	//   kisp, рхія_, пөлө, --, 
   {{0x32c80156,0x316c01c0,0x7e7c05a1,0x321800ee}},	//   ཇཉཏཐ, tzez_, jisp, ýsy_, 
   {{0xf1b80f8b,0x7bc40076,0xa11000c6,0x80e8010b}},	//   rešo_, _oghu, كويت, агың_, 
   {{0xae08023e,0x0fe4661d,0x7e7c01f5,0x7bc4b72e}},	//   _वाहन_, шлоқ_, eisp, _nghu, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe28c03ee,0x82340220,0xccf8b72f,0x00000000}},	//   _ѕа_, _ورنا, ақи_, --, 
   {{0x613003e0,0xc0c8009b,0x26180ca8,0x00000000}},	//   rılç, _кује_, _ṣoki_, --, 
   {{0x3e680a85,0xb5fc02f0,0x6598010f,0x7e7cb730}},	//   _rûte_, _olšo, רישק, aisp, 
   {{0xca74052f,0x7bc40327,0x00000000,0x00000000}},	//   ҡуғы, _dghu, --, --, 
   {{0x7e7c0784,0x2a640de2,0xe7880118,0x00000000}},	//   cisp, óob_, tíží, --, 
   {{0xd940b731,0x2f1000dd,0x2910007f,0x6a6802d2}},	// [ec20] пети, lág_, utya_, _nýfe, 
   {{0x2910b732,0x57e46030,0x6e2401d3,0x00000000}},	//   rtya_, йдум_, lekb, --, 
   {{0x2910b733,0x7f7002d3,0xe63401c6,0x00000000}},	//   stya_, _ኣዕናዊ_, йхдэ, --, 
   {{0x69d8084c,0x26d8009f,0xa968014b,0x00000000}},	//   _ştef, rppo_, _бима_, --, 
   {{0x64a4b734,0x7c440252,0x044c010e,0xa49401e4}},	//   бада, _útrá, _güỳj, luϲi, 
   {{0x7e7cb735,0xc1e03711,0x00000000,0x00000000}},	//   zisp, नर्ग, --, --, 
   {{0x64a40220,0xb3400166,0x6e2400e5,0x00000000}},	//   _ғажа, _öçle, kekb, --, 
   {{0x81e802a6,0x7e7cb736,0xd7040276,0x6e24b737}},	//   _বাহ_, xisp, _ынсе_, jekb, 
   {{0x26c8b738,0x7e7cb739,0x22400205,0x00000000}},	//   _hubo_, visp, ıkk_, --, 
   {{0x26c85b36,0xf1a4b73a,0x645c0254,0x00000000}},	//   _kubo_, өрөн, öpid, --, 
   {{0x26c80048,0x256c01d3,0x95980023,0xc564009f}},	//   _jubo_, _fölé_, _ንሓደጋ_, _اُڃي, 
   {{0x26c8b73b,0x69c4b73c,0x27e801ab,0x9fbc0306}},	//   _mubo_, _ngke, _lebn_, _učím_, 
   {{0x7e7cb73d,0x249c05b1,0x2f840032,0x26c80419}},	//   risp, _kktm_, йҙән_, _lubo_, 
   {{0x7e7cb73e,0x2c6400d0,0x3f980dd6,0xcc0801d9}},	//   sisp, _pôda_, ürus_, ٝزِن_, 
   {{0xf3f001fb,0x26c8b73f,0x7e7c02d1,0xd7f80131}},	//   _học_, _nubo_, pisp, ғуз_, 
   {{0x38c8066d,0x27e801c4,0x7e7cb740,0xfbd84f76}},	//   لائی_, _aebn_, qisp, _ब्रम, 
   {{0x672c7f4f,0xd83801c0,0xca48007b,0x00000000}},	// [ec30] _asbj, лэж_, حلقه_, --, 
   {{0x68e40369,0x6aa80036,0x37f8010b,0x885800d8}},	//   _dwkd, _ëffn, режэ_, биус_, 
   {{0x5018011a,0xf3f00051,0x00000000,0x00000000}},	//   רובו, _lọc_, --, --, 
   {{0xd5e813d7,0x26c8b741,0x39900241,0x00000000}},	//   اعان_, _dubo_, _ẹsun_, --, 
   {{0x2f1000dd,0x672c553d,0x26c80036,0x88a403e6}},	//   zág_, _esbj, _eubo_, _کیلۆ, 
   {{0xc484177b,0x6e2400e5,0x00000000,0x00000000}},	//   плік, zekb, --, --, 
   {{0x26c8b742,0xae08007d,0x0ab82fc0,0x6e24b743}},	//   _gubo_, _वालन_, _خطیب_, yekb, 
   {{0x2f10b744,0xb3400432,0x4b7c0115,0x00000000}},	//   vág_, _öçme, טאוו, --, 
   {{0x26c8b745,0xb1440212,0x6e2401d3,0x00000000}},	//   _zubo_, інол, vekb, --, 
   {{0xef18b746,0x8504b747,0x26c8022e,0xf8a80037}},	//   амо_, _رومن, _yubo_, कतिय, 
   {{0x81e803f4,0x6e2401ed,0x26c80009,0x645c01f4}},	//   _বার_, tekb, _xubo_, öpie, 
   {{0x6da41de1,0x2f1001ed,0xf1b80024,0xb50c00ab}},	//   жима, rág_, nešk_, _समाय_, 
   {{0x2f10066d,0x6e2401ed,0x20543a49,0xfd800023}},	//   ság_, rekb, стөр, _ከቕርቦ_, 
   {{0x01a805d9,0xa49401e4,0x6e2401d3,0x00000000}},	//   _اُهي_, tuϲi, sekb, --, 
   {{0xa098008f,0xdca00b01,0x81f401d3,0x6e24b748}},	//   _דיסט, фари, _ظہیر_, pekb, 
   {{0xf1d005f9,0x26c8b749,0x00000000,0x00000000}},	//   _हलफन, _rubo_, --, --, 
   {{0x26c8b74a,0x5f900032,0x61e403b2,0x00000000}},	// [ec40] _subo_, _ниәт, ðkli, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe5c43a61,0x6ab402c4,0xd6ccb74b,0x26c80009}},	//   осло, pmyf, نقل_, _qubo_, 
   {{0xe3e403d4,0x2c1400dc,0xb5600241,0x00000000}},	//   _নাইব, द्रं_, _tẹ́k, --, 
   {{0x50b40156,0x6fc837bb,0x3208002e,0x1fa410eb}},	//   བམཙཚ, रशां, _ñayy_, _ऑर्ड, 
   {{0x66e4b74c,0x64984478,0x09b000fe,0x00000000}},	//   _мога, штер_, _কলপা, --, 
   {{0xe4d8b74d,0x00000000,0x00000000,0x00000000}},	//   _چورت_, --, --, --, 
   {{0xe4d8007b,0x00000000,0x00000000,0x00000000}},	//   _نورت_, --, --, --, 
   {{0x3fc861f4,0x91b402e8,0x00000000,0x00000000}},	//   یدگی_, огът_, --, --, 
   {{0xe3b0036b,0x321c015d,0xd42800cf,0x00000000}},	//   _قرا_, _ebwy_, _ۅتۅۅ_, --, 
   {{0xd9b402c3,0x3cdc00cc,0x00000000,0x00000000}},	//   _अण्ट, _বিধৱ, --, --, 
   {{0xb8fc025c,0xe0e4036b,0xd36c01f7,0xe1f00cd6}},	//   _ལྕ_, _дўко, _جهم_, _آسا_, 
   {{0x224401c4,0xf3f00208,0x00000000,0x00000000}},	//   _inok_, _họa_, --, --, 
   {{0xed4c32db,0x4034119e,0xea240137,0x00000000}},	//   چھی_, _хекс, үчтү, --, 
   {{0xda7801c0,0xcb3402e8,0x00000000,0x00000000}},	//   аяа_, меръ, --, --, 
   {{0x3e68145e,0x4e78b74e,0x00000000,0x00000000}},	//   _fûta_, _وحيد_, --, --, 
   {{0xf4e411ba,0x3eb8b74f,0x22440fac,0x78a40978}},	// [ec50] _নম্ব, mmst_, _mnok_, tlhv, 
   {{0x17f800c6,0x19543007,0x97a426b1,0x00000000}},	//   شرطة_, бағы_, орел, --, 
   {{0xaab420d3,0x22440214,0xc5d8063f,0xb17c02f0}},	//   تگیر_, _onok_, _ịrụb, laťt, 
   {{0x1dac0490,0x35b40150,0x7bd40210,0x00000000}},	//   _घरात, пбер, lczu, --, 
   {{0x3a280113,0x7af40c57,0x00000000,0x00000000}},	//   meap_, lszt, --, --, 
   {{0x224405b1,0xd8385fd0,0xd6d8119e,0x7af400e5}},	//   _anok_, _тэм_, _вта_, oszt, 
   {{0x3dc80009,0xc4cc0154,0x35a40133,0x7af4b750}},	//   _ogaw_, রীলঙ, _کۆشێ_, nszt, 
   {{0x21f00075,0x3dc8003e,0xf3f00051,0xae080f4a}},	//   ىكىس, _ngaw_, _dọa_, _वाइन_, 
   {{0x44f4084c,0x00000000,0x00000000,0x00000000}},	//   _оптс, --, --, --, 
   {{0x3dc84cd3,0x2244b751,0x7af40034,0xf1b8005f}},	//   _agaw_, _enok_, kszt, neši_, 
   {{0x3a28002d,0x5348010a,0x00000000,0x00000000}},	//   keap_, _тăнă, --, --, 
   {{0xc2c401d5,0x7bd4012d,0x51080354,0x00000000}},	//   _قيلي, eczu, _кĕмĕ, --, 
   {{0x3ce801ab,0x9184007b,0x6a6802d2,0x3cd401a9}},	//   _cwav_, _بجام, _nýfa, дўст, 
   {{0xf1b81711,0x3eb8003a,0xa1540375,0x7ae800f3}},	//   ješi_, amst_, _מבנה_, ćetn, 
   {{0x320c0076,0xa9f8009d,0x7af400e5,0x00000000}},	//   ogey_, йхах_, gszt, --, 
   {{0x32d0431d,0x320c0731,0x00000000,0x00000000}},	//   _máy_, ngey_, --, --, 
   {{0x7af400dd,0x3ce802e2,0x320c0363,0x32d00208}},	// [ec60] aszt, _gwav_, igey_, _láy_, 
   {{0x6e34b752,0x98bc0724,0x6a68032e,0x00000000}},	//   _hayb, ırğa_, _dýfa, --, 
   {{0x6e34b753,0x3ec42fbe,0xe618b754,0x32d00208}},	//   _kayb, _üstü_, йдж_, _náy_, 
   {{0xdd8c313e,0x3a2801ab,0x00000000,0x00000000}},	//   _جوۋ_, ceap_, --, --, 
   {{0x6e34b755,0xd83c0427,0xe61801a9,0xae0801f9}},	//   _mayb, ščat_, _қда_, _वाईन_, 
   {{0x320c01d9,0x6e3460b7,0x2244003b,0x1c1c07af}},	//   egey_, _layb, _snok_, म्पल_, 
   {{0x76980139,0x68f40ea0,0x32d00051,0x66e401f0}},	//   _bäyğ, lsyd, _cáy_, _хоба, 
   {{0x320c02a4,0x6e340477,0x32d00051,0x66e40117}},	//   ggey_, _nayb, _dáy_, _моҳа, 
   {{0x68f40ea0,0xcfe000cc,0x00000000,0x00000000}},	//   nsyd, _মাজন, --, --, 
   {{0x3dc80165,0xd4640022,0x320c0363,0x7af4033f}},	//   _sgaw_, _еиуе_, agey_, yszt, 
   {{0x6e347de9,0x645823e0,0x32d001fb,0x6560b756}},	//   _bayb, _ioti, _gáy_, lyoh, 
   {{0x6458b757,0x20000e2d,0x3ce80100,0x6e340009}},	//   _hoti, şki_, _pwav_, _cayb, 
   {{0x6458b758,0x6e34232c,0x6560b759,0x31300022}},	//   _koti, _dayb, nyoh, _аҵыр, 
   {{0x91b80302,0xd00c1056,0x68f4005c,0xb17c0118}},	//   _המדי, _مله_, dsyd, raťt, 
   {{0x20d004cc,0x7c78001f,0x4c9401c6,0xb17c00d0}},	//   _hâi_, ጨረሻው_, хирс, saťt, 
   {{0x6458b75a,0x20d0006a,0x7af40034,0x3ce80120}},	//   _loti, _kâi_, rszt, _twav_, 
   {{0x6458b75b,0x7e6cb75c,0x3914035b,0x38344ad0}},	// [ec70] _ooti, _ilap, ьмар, мнар, 
   {{0x7e6cb75d,0x6458b75e,0x20d0145e,0x656006e4}},	//   _hlap, _noti, _mâi_, dyoh, 
   {{0x6e340429,0xf3f00208,0xc3240154,0xf1b882c7}},	//   _yayb, _bọn_, ভিডি_, reši_, 
   {{0x68f40b21,0x6458030a,0x6e34b75f,0x32d00208}},	//   bsyd, _aoti, _xayb, _ráy_, 
   {{0x6458b760,0x6560019f,0xf3f00051,0x6a38011a}},	//   _boti, gyoh, _dọn_, _וגרפ, 
   {{0x7e6c1bb7,0xdfc499db,0x32d000e4,0xb50c012d}},	//   _llap, _لي_, _páy_, _समीप_, 
   {{0x6560089c,0x7e6c11b0,0x8704023a,0x7698008e}},	//   ayoh, _olap, _пяте, _päyğ, 
   {{0x32d00016,0x6560b761,0xf3f00051,0xb5fc01ef}},	//   _váy_, byoh, _gọn_, _olši, 
   {{0x320cb762,0x7648b763,0x6e34b764,0x6458b765}},	//   rgey_, _iney, _rayb, _foti, 
   {{0x7e6cb766,0x6f642ff7,0x764801a8,0x32d00051}},	//   _alap, двоз, _hney, _táy_, 
   {{0x7e6c0af9,0x6fa8007b,0x00000000,0x00000000}},	//   _blap, تهدف_, --, --, 
   {{0x6e34b767,0x6458044e,0x68f4b768,0x00000000}},	//   _qayb, _zoti, ysyd, --, 
   {{0x7e6cb769,0x6458b76a,0x61440131,0x20d00042}},	//   _dlap, _yoti, _يىمە, _gâi_, 
   {{0x6458006c,0x6e34b76b,0xc0e8001f,0x7e6cb76c}},	//   _xoti, _wayb, _መኖሩ_, _elap, 
   {{0x6e34b76d,0x76480c8c,0x2d9c012d,0xea5800d8}},	//   _tayb, _oney, łte_, орај_, 
   {{0x76480134,0x6560036b,0x7e6c1876,0x00000000}},	//   _nney, yyoh, _glap, --, 
   {{0x69d40023,0xe8f800cf,0xbfd4032e,0x2d94010a}},	// [ec80] rcye, юла_, _ííþr, _юркс, 
   {{0x65605944,0x68f417b5,0xa848b76e,0x9c8402fb}},	//   vyoh, rsyd, غلام_, _vyčí, 
   {{0xb8640e5a,0x68f4002d,0x356802dd,0x00000000}},	//   راكو, ssyd, үрін_, --, 
   {{0x6458b76f,0xb68400d1,0x9c8401ef,0x68f4b770}},	//   _soti, ىشنى, _tyčí, psyd, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x65601389,0x6458036b,0xd464b771,0xf1b8005f}},	//   ryoh, _qoti, миче_, nešu_, 
   {{0x6458420d,0x65604511,0x97c00bad,0x752c031c}},	//   _voti, syoh, _айре, ħaza, 
   {{0x65607bad,0x64580134,0x7648007f,0x40e400fb}},	//   pyoh, _woti, _gney, нсоғ, 
   {{0x6458b772,0x11d000d1,0x00000000,0x00000000}},	//   _toti, ختىد, --, --, 
   {{0x7e6cb773,0xc0e80020,0x6458b774,0x00000000}},	//   _slap, _መኖር_, _uoti, --, 
   {{0x8c1402f5,0x6a6803b2,0xdbc401e3,0x33240208}},	//   াজান_, _nýfo, _höök, _gplx_, 
   {{0xa40c0dad,0x20d000e4,0xdbc40037,0xaad00118}},	//   _साँप_, _tâi_, _köök, _दूधक, 
   {{0xb17c0030,0x7e6c017a,0x1610000d,0x0dc85ab8}},	//   saťr, _vlap, ण्टर_, дури_, 
   {{0x21240092,0x5fd063d3,0x3944013a,0x00000000}},	//   _ipoh_, _सलिल, _čls_, --, 
   {{0x7e6cb775,0xdbc40037,0x69d80356,0x30380133}},	//   _tlap, _löök, _ştea, _رتوک_, 
   {{0x21240649,0x7e6cb776,0x2d9c0276,0xda7802d5}},	//   _kpoh_, _ulap, ştea_, цяг_, 
   {{0xa40c45bf,0x201c022f,0xdff033ee,0xdbc40254}},	// [ec90] _सांप_, ofti_, _आजाद_, _nöök, 
   {{0xfaf0004b,0x764803b2,0x195402dd,0xdd900150}},	//   _مګر_, _sney, пағы_, _пақы, 
   {{0x45dc01f2,0x201c208d,0x9ba02160,0x97a40166}},	//   _ịpụ_, ifti_, _شەرى, фрал, 
   {{0xd7dc35e0,0x645c04f3,0xdcf007f7,0xa6c801a9}},	//   _प्रच, öpin, _अबाध_, vvаt, 
   {{0xd5f8063f,0xd87400db,0x6a6808a5,0x58840006}},	//   _akụ, _قاسب, _mýfl, _жыва, 
   {{0x3a380113,0x383401b9,0x76480042,0x00000000}},	//   _hasp_, _янгр, _wney, --, 
   {{0x245016a0,0x3a3800c0,0x1c14000d,0xfd7c0023}},	//   انىس, _kasp_, _तानल_, _ኣድህቦ_, 
   {{0x7648009a,0x3a380100,0xda0c4c19,0x6a68032e}},	//   _uney, _jasp_, िलित_, _nýfl, 
   {{0x3494b777,0x3a38b778,0x00000000,0x00000000}},	//   _заар, _masp_, --, --, 
   {{0x932425aa,0x44b41188,0x00000000,0x00000000}},	//   _يران, _абус, --, --, 
   {{0x53a00034,0xda0c0406,0x6a681d1d,0x7e640003}},	//   _ओडिश, िलात_, _býfl, _ċipr, 
   {{0x2ca80175,0xed34009d,0x73c001af,0x00000000}},	//   wlbd_, нэгэ, _иҙҙе, --, 
   {{0xd34403e6,0x6a6802d2,0xa6c8022e,0x00000000}},	//   _ریکه_, _dýfl, nvаr, --, 
   {{0x6f0000b5,0x61e403e0,0x00000000,0x00000000}},	//   のbol, ıkle, --, --, 
   {{0xf1b8005f,0xf3f0004d,0x20000024,0x2008012d}},	//   rešu_, _mẹ_, ėkit_, óbie_, 
   {{0x3a381c69,0x70900023,0x9f78011a,0xf7e800d1}},	//   _casp_, _ዝብሃሉ_, _מנצח, ېرنى_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [eca0] --, --, --, --, 
   {{0x3a381c7e,0xdbc41577,0x3e740248,0xfbd800bc}},	//   _easp_, _röök, _tútù_, बुआम, 
   {{0x27945411,0xdbc400c5,0x2be42052,0x660400d8}},	//   хшар, _söök, _ज्यू_, епеа, 
   {{0x9f4c0100,0x3a38b779,0xe800000d,0x00000000}},	//   _defè_, _gasp_, _लयवा_, --, 
   {{0x59200ee8,0x201c03b2,0x00000000,0x00000000}},	//   _مکلف, yfti_, --, --, 
   {{0x3a380010,0xdbc4000d,0x00000000,0x00000000}},	//   _zasp_, _vöök, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdbc4007d,0xe5a4010b,0x00000000,0x00000000}},	//   _töök, _зиби, --, --, 
   {{0xdedc001f,0x83fc0208,0xa5080354,0x00000000}},	//   ናወን_, _blđt, _хеза_, --, 
   {{0x6abc1fe7,0x92dc00fe,0xbed801c4,0x00000000}},	//   ्दुर, _তিৰ_, мдох_, --, 
   {{0x201c008c,0x2d9c0e78,0x7f94b77a,0x00000000}},	//   rfti_, ßten_, танх, --, 
   {{0x1cb0031c,0x00000000,0x00000000,0x00000000}},	//   _ྟེང_, --, --, --, 
   {{0xe3b004c5,0x6280b77b,0x2d9c05d1,0xf3f00241}},	//   _চলিব, _imoo, şten_, _yẹ_, 
   {{0x62800b89,0x81e80729,0xe8a002d3,0x443c2ce8}},	//   _hmoo, _বাট_, _ገሊጾም_, ndv_, 
   {{0x3a3801fa,0xae08330a,0x2c100406,0x6fd400d4}},	//   _pasp_, _वाचन_, _तारू_, _річц, 
   {{0x9f4c033b,0xe3b000fe,0xebc000c7,0x00000000}},	//   _refè_, _চলাব, шәын, --, 
   {{0x6280b77c,0x9f4c0100,0x3a3800d8,0x3cb400db}},	// [ecb0] _mmoo, _sefè_, _vasp_, _ийир, 
   {{0x91ac0022,0x6aa400b5,0x60c80327,0x3a38b77d}},	//   _hag̃_, _ekkf, _jifm, _wasp_, 
   {{0x7d1cb77e,0x7c24b040,0x3a38b77f,0x3a2c0077}},	//   ltss, _ibhr, _tasp_, _ºep_, 
   {{0x68f00008,0x4788b780,0x00000000,0x00000000}},	//   úkdó, хсум_, --, --, 
   {{0x7d1c0c8c,0x443c45a7,0xc8d80073,0x00000000}},	//   ntss, fdv_, _भूपट, --, 
   {{0x62801574,0x7d1cb781,0x60c8031c,0xded00092}},	//   _amoo, itss, _nifm, ካሙን_, 
   {{0x7c2401ab,0xe0d800fe,0x7d1c349c,0x889401af}},	//   _mbhr, _দিগভ, htss, _сирх, 
   {{0x7d1c4699,0x60c8031c,0x31240801,0xdedc001f}},	//   ktss, _aifm, вдиг, ናወነ_, 
   {{0x62800036,0x7e64025c,0x7c2400d7,0xf3f001e1}},	//   _dmoo, _ċipp, _obhr, _tẹ_, 
   {{0x628001c7,0x25b005d1,0xe040010a,0xf064119e}},	//   _emoo, üyle_, аньи, ткоп, 
   {{0x7d1c01c7,0x00000000,0x00000000,0x00000000}},	//   etss, --, --, --, 
   {{0x7c2400cd,0x82ec0327,0xa2a00073,0x8f4000cd}},	//   _abhr, _ལྦིའ, खवण्, _īśān, 
   {{0xdedc001f,0x7d1c00b5,0x81e800fe,0xe0cc0395}},	//   ናወኑ_, gtss, _বাচ_, _ъв_, 
   {{0xab28b782,0x7528b783,0x60c8017a,0xac080408}},	//   мога_, _mpez, _gifm, ьнга_, 
   {{0x7d1cb784,0x6aa405b1,0x7c24b785,0x46d00037}},	//   atss, _pkkf, _dbhr, _तूंह, 
   {{0x752802ce,0x7c240810,0x00000000,0x00000000}},	//   _opez, _ebhr, --, --, 
   {{0x69a0a3d5,0x0c94b786,0xebe40022,0x7d1c0857}},	// [ecc0] _कुशी, _مددگ, _иопп, ctss, 
   {{0x4da8015b,0xb5fc00c0,0xc6d401c4,0x00000000}},	//   _গণপূ, _lošd, гсдө, --, 
   {{0x7528b787,0xeb98084c,0xe618b788,0x69a0216a}},	//   _apez, _цин_, дде_, _कुरी, 
   {{0xa9680408,0xa50801ec,0x7ae001e7,0x00000000}},	//   _жима_, деда_, ílte, --, 
   {{0x04480116,0x00000000,0x00000000,0x00000000}},	//   нҗап_, --, --, --, 
   {{0x4394b789,0x6280b0ec,0x22f401d9,0x3168010e}},	//   лалс, _smoo, ن٘تھ_, _ýazy_, 
   {{0xd36c3738,0x443c0d81,0x17c40276,0x60c8010e}},	//   يهه_, rdv_, _агри_, _rifm, 
   {{0x62800477,0x443c020c,0x00000000,0x00000000}},	//   _qmoo, sdv_, --, --, 
   {{0xc0c402d3,0x50f03395,0x00000000,0x00000000}},	//   _ሸለል_, азыт, --, --, 
   {{0xdef8b78a,0xa3b800db,0x00000000,0x00000000}},	//   мым_, _قاار_, --, --, 
   {{0xbebc00e2,0xa31400c7,0x00000000,0x00000000}},	//   ntīg, _шьаш, --, --, 
   {{0x83fc098d,0x7d1cb78b,0x6280014b,0x6abc041c}},	//   _dođe, ttss, _umoo, ्दोर, 
   {{0xffa40209,0x69a000b8,0xc338009f,0x00000000}},	//   _өлдү, _कुली, _آڻڻا_, --, 
   {{0xbebc00e2,0x00000000,0x00000000,0x00000000}},	//   ktīg, --, --, --, 
   {{0x7d1cb78c,0x5ab401ec,0xb5fc01ef,0xd5f00150}},	//   stss, кқор_, _hoše, тiлг, 
   {{0x5f4405f5,0xb5fca1f5,0x00000000,0x00000000}},	//   _зүүн_, _koše, --, --, 
   {{0x3ea802b4,0xbebc00de,0x5c0401af,0x00000000}},	// [ecd0] _ikat_, etīg, _ияна, --, 
   {{0x3ea8020c,0x6ae00154,0xb5fcb78d,0x3b54014b}},	//   _hkat_, _ফিরো, _moše, _бкор, 
   {{0xb5fc0989,0x00000000,0x00000000,0x00000000}},	//   _loše, --, --, --, 
   {{0xb9080c58,0xcf90010f,0x00000000,0x00000000}},	//   _যি_, בטע_, --, --, 
   {{0xb5fc2a10,0x00000000,0x00000000,0x00000000}},	//   _noše, --, --, --, 
   {{0xdef402d3,0x00000000,0x00000000,0x00000000}},	//   _ገሊኡ_, --, --, --, 
   {{0x59a4000d,0x82f402d5,0xc7c40212,0x78a40254}},	//   _कुतर, ачыц, _всти, mohv, 
   {{0x83fc0bb8,0xb6c40dd8,0xf3f0004d,0x55c000fb}},	//   _rođe, _сөзд, _mọi_, _ҡаңғ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x61e40e42,0x3ea8011f,0x83fc0e3c,0xb5fcb78e}},	//   ıkla, _akat_, _pođe, _doše, 
   {{0xaec4a941,0x94bc012d,0x798800a2,0xd258009b}},	//   лбол, एगीआ, _ýewf, _оцд_, 
   {{0x83fc0b91,0x2d9cb78f,0x78a4014f,0x00000000}},	//   _vođe, ştem_, hohv, --, 
   {{0xc0c80201,0x3ea80a2e,0x2054b790,0xeb341cbf}},	//   _በሙሉ_, _dkat_, ттөр, گىزد, 
   {{0x6abc29c7,0xddc8054e,0x3ea8005b,0xfbd0072d}},	//   ्द्र, ţişa, _ekat_, قتِ_, 
   {{0x78a416a3,0x3ea80139,0xca6401ec,0x6e440395}},	//   dohv, _fkat_, аевқ, _бейз, 
   {{0xeb98070e,0x8ca400cf,0xa9a401a9,0x00000000}},	//   _җим_, _چەحو, гибд, --, 
   {{0x645c01b8,0x6ea40014,0x3964013e,0x59a441d8}},	// [ece0] öpik, _لۆگہ_, антҳ, _कुदर, 
   {{0x2c640030,0x7b080790,0x00000000,0x00000000}},	//   _pôdu_, üstü, --, --, 
   {{0x27e404ac,0x5c340bd9,0xf3f0004d,0x00000000}},	//   ĝon_, _גרין_, _gọi_, --, 
   {{0xbebc00da,0xd6cc036b,0x27e4008f,0x00000000}},	//   rtīg, سقه_, ŝon_, --, 
   {{0xbebc005f,0x8af80213,0x59800024,0x00000000}},	//   stīg, _şəhr, _гляб, --, 
   {{0x291006d6,0xd5442571,0xfce00092,0xf424004e}},	//   muya_, الوو_, _ፓኬጅ_, изчү, 
   {{0x06d03fae,0x2910b791,0x00000000,0x00000000}},	//   _ৱিকি, luya_, --, --, 
   {{0xb5fc2a10,0xd790007b,0xf66400cf,0x00000000}},	//   _poše, _الفخ, _кесү, --, 
   {{0x2910b792,0x92340640,0x20180254,0x00000000}},	//   nuya_, учју_, _öpik_, --, 
   {{0x3ea8b793,0x75800014,0x425439b1,0x2910004c}},	//   _skat_, _بیٖم, انکر, iuya_, 
   {{0xa2e4b794,0x29100810,0x00000000,0x00000000}},	//   _соед, huya_, --, --, 
   {{0x29103917,0x5398008d,0xb5fc3341,0xd334011a}},	//   kuya_, _איבו, _toše, _תראה_, 
   {{0x5c04b795,0xa0684c7f,0x78a401b9,0xd83c0427}},	//   лява, _пада_, yohv, ščit_, 
   {{0x29101cce,0x5c04010b,0xcd640023,0x5f7400ae}},	//   duya_, ыяма, ድርያና_, _ماعر, 
   {{0xcfe4a864,0x3ce000af,0xf8ec02e5,0x78a401f4}},	//   _صفيه_, _कऽके_, _चौड़ा_, vohv, 
   {{0x3ea82e95,0x7d7801e2,0x00000000,0x00000000}},	//   _ukat_, _لمبر_, --, --, 
   {{0x2910b796,0x77400092,0x4e9400f1,0x00000000}},	// [ecf0] guya_, _የሚመሰ, _دشور, --, 
   {{0x95fc03ce,0x00000000,0x00000000,0x00000000}},	//   ॉल्ट_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd6a80372,0xa3c82871,0x7ae44c56,0x78a416ca}},	//   ردام_, ोशन_, _itht, sohv, 
   {{0x2910b797,0x596402e8,0xb5d401ec,0xaa8401af}},	//   cuya_, _съна, _ﯞﻻﻧﻌ, _тәрж_, 
   {{0x1cb00327,0x00000000,0x00000000,0x00000000}},	//   _ཟེས_, --, --, --, 
   {{0x1cb0031c,0xc30400c6,0x00000000,0x00000000}},	//   _ྟེན_, مبيو, --, --, 
   {{0x3e68145e,0xe9600023,0x644c0327,0x00000000}},	//   _kûtu_, _ተራእየ_, _ħniż, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x1b081c82,0x60600075,0x70840137,0x058401c6}},	//   _হৈছে_, يۇنل, ргоз, _уусм, 
   {{0x291004ce,0x63e400db,0xff4401f3,0x00000000}},	//   zuya_, _ئيمە, ንግሊዘ, --, 
   {{0x2910b798,0x62240046,0x5f4000d1,0xbebc00de}},	//   yuya_, _نومە, زچىل, etīb, 
   {{0x7ae405b1,0x20140030,0x7e7c036e,0x00000000}},	//   _atht, údiá_, ërpa, --, 
   {{0x2910b799,0xeb982add,0xafe402ac,0x7e9801e4}},	//   vuya_, виг_, _токл, rĉpa, 
   {{0x2910b79a,0xaac40244,0xa3e40073,0x92d400fe}},	//   wuya_, لترن, पडत_, ়ীৰ_, 
   {{0x2910b79b,0x7d0816a3,0x63b000a2,0x7ae000e5}},	//   tuya_, šesa, _ýenş, ílta, 
   {{0xfbc40154,0xe8f8005a,0x9dd4011a,0x00000000}},	// [ed00] ্রগত, тлз_, _דופק_, --, 
   {{0x7ae001e4,0x00000000,0x00000000,0x00000000}},	//   ŭlta, --, --, --, 
   {{0xccf40605,0x2910b79c,0x6d4403b2,0xe634009d}},	//   _hwɛ_, suya_, lvka, ихдэ, 
   {{0x2910b79d,0xe8f81b74,0xe9a463e6,0x7f8c008f}},	//   puya_, _илм_, _вамп, ענאַ, 
   {{0xe4c4044c,0xe81c0c2e,0x2910b79e,0x3a2c00e4}},	//   айди, _पापा_, quya_, _ñepa_, 
   {{0x843800c6,0x29000419,0x273400d1,0xa2d8033f}},	//   اكثر_, _ivka_, _پىرس, _पंद्, 
   {{0xd46415ed,0x7ebc01d3,0x6d440254,0xa2a001f9}},	//   рије_, lépe, hvka, खवल्, 
   {{0x4420012c,0x83fc009b,0x26c001e1,0xa2d8276a}},	//   ři_, _dođa, _òko_, _पूण्, 
   {{0x44200b45,0x200800d8,0xf528b79f,0x00000000}},	//   ƙi_, óbio_, _مثله_, --, 
   {{0x09fc02f5,0x3e4c00c0,0x00000000,0x00000000}},	//   ইলিং_, _mėtų_, --, --, 
   {{0xe81c03f8,0x823c0092,0x00000000,0x00000000}},	//   _पाना_, _ጠቀሜታ, --, --, 
   {{0xb5fc5a11,0x7ebc00dd,0x21a400fd,0x29000841}},	//   _koša, képe, _кием, _ovka_, 
   {{0x61e0b7a0,0x518002f4,0xb5fc0cf4,0xa134114f}},	//   _ifol, _муша, _joša, _خراش, 
   {{0x7ebcb7a1,0xab78022e,0x644c00d8,0xbebc00e2}},	//   dépe, _bo鼠d, _óbid, utīb, 
   {{0xbebc0029,0x6d44007c,0x9a84b7a2,0x7ac4004e}},	//   rtīb, avka, ауал, йөма, 
   {{0xbebc0029,0x9e6401b9,0x39140395,0x00000000}},	//   stīb, _خاتن, ймбр, --, 
   {{0x9f4c067c,0x7ebc01ed,0xa3e4146c,0xb5fc00de}},	// [ed10] _hefà_, gépe, पडा_, _noša, 
   {{0x085400d6,0x2bdc0b67,0x68e0007b,0x00000000}},	//   овую, _मलया, íoda, --, 
   {{0xec34025f,0x61e0b7a3,0xece00154,0x7ae40857}},	//   _האתר_, _ofol, _বিএড, _utht, 
   {{0x83fc0b91,0x69a00c4c,0xb5fc05b6,0x7c340200}},	//   _rođa, _कुकी, _boša, lezr, 
   {{0xc95801b9,0x06081cd0,0xb0d4012d,0xb17c00d7}},	//   _кўр_, рнік_, _डूंग, saťz, 
   {{0xb5fc1326,0x61e0b7a4,0xe81c34ef,0xc4843334}},	//   _doša, _afol, _पाया_, олік, 
   {{0xa3e400e1,0x00000000,0x00000000,0x00000000}},	//   पड़_, --, --, --, 
   {{0xb5fc1ebd,0x83fc0e3c,0x61e00175,0x538002d3}},	//   _foša, _vođa, _cfol, _ክዕወት_, 
   {{0x708400f7,0x7c34030a,0xb5fc00a2,0x691c0205}},	//   йгиз, kezr, _goša, _içeç, 
   {{0x61e0b7a5,0xd3a42f33,0x7c34b7a6,0xed5800c2}},	//   _efol, _креп, jezr, ҳом_, 
   {{0x61e003cb,0xda040073,0x6e44005a,0x7ebc00e5}},	//   _ffol, षणात_, бенз, zépe, 
   {{0xed583967,0xb638037e,0x55080456,0x00000000}},	//   гом_, _ｘｐ_, _हटाए_, --, 
   {{0x22a40014,0xd00004a9,0xd72000eb,0x7bc003b2}},	//   _أنہ, _долқ, ফিয়া_, ýlun, 
   {{0xfd48063f,0xbf885a9d,0xef186c9a,0x6d44000d}},	//   lomọ, ائیل_, _бмк_, rvka, 
   {{0x61e002d0,0x7c2001c3,0x00000000,0x00000000}},	//   _yfol, òlra, --, --, 
   {{0x7ebc2cf4,0x00000000,0x00000000,0x00000000}},	//   tépe, --, --, --, 
   {{0x316c0399,0xa804b7a7,0xbebc005f,0x5e740375}},	// [ed20] nyez_, йзал, stīc, _לתקן_, 
   {{0x3e6806af,0xea600014,0x7ebc0525,0x00000000}},	//   _fûts_, _کھسی, répe, --, 
   {{0xe81c00c5,0x00000000,0x00000000,0x00000000}},	//   _पाठा_, --, --, --, 
   {{0xb5fc56c0,0x76a800d6,0x5b540375,0x4614009f}},	//   _poša, атів_, _היטב_, زوتر, 
   {{0x316c0100,0x00000000,0x00000000,0x00000000}},	//   jyez_, --, --, --, 
   {{0x61e00395,0x6a680122,0x00000000,0x00000000}},	//   _sfol, _výfu, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe6940491,0x77903135,0x9f4c004e,0x2a7000b5}},	//   _الرد, _تیما, _refà_, nkyb_, 
   {{0x26c4b7a8,0xc61403ce,0x00000000,0x00000000}},	//   mmoo_, डलीय_, --, --, 
   {{0x244823bb,0x00000000,0x00000000,0x00000000}},	//   _حجري_, --, --, --, 
   {{0x61e0003c,0xb5fc6b92,0x26c400b5,0x0f2001af}},	//   _tfol, _mošn, omoo_, пьям, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x26c40a55,0x442c0334,0x1d880451,0x7e7c56ce}},	//   imoo_, _kbd_, ائجي_, ūrpo, 
   {{0x7c283421,0x2bb8134e,0x00000000,0x00000000}},	//   đero, _इरशा, --, --, 
   {{0x442c070d,0x83fc0841,0x00000000,0x00000000}},	//   _mbd_, _lođo, --, --, 
   {{0xb924007b,0x7ae00115,0x7cd80107,0x06cc01ec}},	//   يفزي, ŭlto, _кмир_, _ﺑﺎﻻﺩ, 
   {{0xb5fc3ad4,0x442c03f0,0x7e7c00c6,0x26c40332}},	// [ed30] _bošn, _obd_, mhsp, dmoo_, 
   {{0x442cb7a9,0x00000000,0x00000000,0x00000000}},	//   _nbd_, --, --, --, 
   {{0x94a8036b,0x316c0399,0xf7981291,0xf9d40fdc}},	//   қтда_, zyez_, جناب_, _монэ, 
   {{0x442cb7aa,0x35b4b7ab,0x7e7c0051,0xe81c0037}},	//   _abd_, обер, nhsp, _पाथा_, 
   {{0xd90c79af,0x442cb7ac,0xb5fc01ef,0xc984009b}},	//   _سیا_, _bbd_, _fošn, _еури, 
   {{0x442cb7ad,0x83fc05a1,0x26c4b7ae,0xd49848bd}},	//   _cbd_, _dođo, amoo_, ыре_, 
   {{0x8c1c10df,0x3948b7af,0x442cb281,0xe81cb7b0}},	//   אווי, lvas_, _dbd_, _पाता_, 
   {{0x2b5c00d7,0x39480064,0x00000000,0x00000000}},	//   ätci_, ovas_, --, --, 
   {{0xe0d4b7b1,0x3494b7b2,0x3ce801d4,0x39488bab}},	//   овы_, _даар, _ntav_, nvas_, 
   {{0x3948b7b3,0x442cb7b4,0xb5fc0419,0x00000000}},	//   ivas_, _gbd_, _košo, --, 
   {{0x7d08b7b5,0x3ce80dd4,0x394800af,0xfd4802e3}},	//   šesl, _atav_, hvas_, pomọ, 
   {{0xb5fc0f8b,0x3948008f,0xccf8016c,0x00000000}},	//   _mošo, kvas_, бқи_, --, 
   {{0xb5fc07f5,0x6f8801ec,0x00000000,0x00000000}},	//   _lošo, _ﻗﻁﻌﺎ_, --, --, 
   {{0x32540022,0x39480254,0x6a68032e,0x00000000}},	//   _ывҵр, dvas_, _nýfr, --, 
   {{0x39480254,0xa9f8005b,0x1ae0b7b6,0xb5fcb7b7}},	//   evas_, ихах_, досм, _nošo, 
   {{0x7e7cb7b8,0xb81000cc,0x00000000,0x00000000}},	//   chsp, স্মত_, --, --, 
   {{0x6bd40553,0x00000000,0x00000000,0x00000000}},	// [ed40] _وتدر, --, --, --, 
   {{0x83fc00f3,0xbebc1a14,0x6b500022,0x00000000}},	//   _rođo, ntīn, _ẽguy, --, 
   {{0x442cb7b9,0x3a280369,0xe7382c0b,0xe61832e6}},	//   _rbd_, bfap_, рее_, идж_, 
   {{0x442cb7ba,0x26c4022f,0xbbe801d3,0xb5fc0171}},	//   _sbd_, umoo_, _پریم_, _došo, 
   {{0x64a4b7bb,0x442c05d5,0x6ac40406,0x14f002d5}},	//   оада, _pbd_, लगीर, дзіў, 
   {{0x6ab4b7bc,0x83fc0e3c,0xefc80023,0x7988010e}},	//   llyf, _vođo, በልዕ_, _ýewa, 
   {{0x7ebc003e,0xa6941fbe,0x148400cf,0x00000000}},	//   hépa, _драј, تپوي_, --, 
   {{0x29100280,0x7ebcae51,0x6ab4b7bd,0xe5a401f4}},	//   orya_, képa, nlyf, _диби, 
   {{0xa2d892c2,0xdce4005f,0x442cb7be,0x645c005b}},	//   _पूर्, ēlīg, _tbd_, öpis, 
   {{0x442c45a7,0x2d800030,0xa354007b,0x19540375}},	//   _ubd_, dzke_, _وخاص, קביל_, 
   {{0x7e7c01ab,0x61400131,0x9f5c0023,0x6ab4b7bf}},	//   thsp, سىھە, matë_, klyf, 
   {{0x394802d5,0xe2903f0b,0x9f5c036e,0xd04003e3}},	//   yvas_, _غذا_, latë_, _minə, 
   {{0xd24c00ec,0x6ab4b7c0,0x00000000,0x00000000}},	//   _جنن_, dlyf, --, --, 
   {{0x7e7c03ac,0x71640150,0x9f5c0240,0x52800150}},	//   shsp, _ءپوە, natë_, _ىلەك, 
   {{0xdef871fe,0x7e7c0857,0x8af803b9,0x5e84014b}},	//   _тыл_, phsp, _şərr, _муиз, 
   {{0x9f5c036e,0x6ab4b7c1,0x1c14000d,0x7ebc01e1}},	//   hatë_, glyf, _ताकल_, bépa, 
   {{0xb5fcb7c2,0x3ce801e6,0x38c80405,0x3a28013c}},	// [ed50] _došl, _utav_, مائی_, rfap_, 
   {{0x9f5c0023,0xb788b7c3,0xd04000ac,0x98143226}},	//   jatë_, бәбе_, _binə, تبرا, 
   {{0x3948b7c4,0x9f5c0240,0x6ab4b7c5,0x99880064}},	//   svas_, datë_, blyf, _pacų_, 
   {{0x3a280369,0xb5fc00f3,0xd04006be,0x29100139}},	//   qfap_, _vošo, _dinə, brya_, 
   {{0x73e40c04,0x9814034c,0x00000000,0x00000000}},	//   полз, _وبسا, --, --, 
   {{0xb5fc54ae,0x9f5cb7c6,0x4488109a,0xd72c0092}},	//   _tošo, ratê_, обін_, _አጋርነ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb5fc1a5c,0x9f5c02bd,0x8b9c011a,0x00000000}},	//   _košm, matè_, יבות, --, 
   {{0x9f5c033b,0xd04003e3,0x00000000,0x00000000}},	//   latè_, _zinə, --, --, 
   {{0x9474b7c7,0x84140c60,0xcee001a9,0x00000000}},	//   _بدرا, _омух, мбоқ, --, 
   {{0x9f5c0d29,0xe81c05d7,0xb4c80210,0xd244b7c8}},	//   natè_, _पासा_, ोदी_, _мэди, 
   {{0x6da4b7c9,0xbebc1a5a,0x7ebc0098,0xada400d1}},	//   зима, stīn, tépa, замл, 
   {{0xf8bc00cd,0x30740454,0x00000000,0x00000000}},	//   ्गाय, _нукс, --, --, 
   {{0x7ebc5f5e,0x9f5c02bd,0x61408ab1,0xf9f40154}},	//   répa, katè_, _чеша, _ছাগল_, 
   {{0xb5fc389e,0x7ebc2dfb,0x2d801f6f,0x7e880b1a}},	//   _pošl, sépa, szke_, øspø, 
   {{0xe9d81377,0x2910019f,0xada4b7ca,0xe81c0490}},	//   ска_, trya_, _найл, _पाहा_, 
   {{0x6ab4b7cb,0xd0400213,0xb5fc0419,0x00000000}},	// [ed60] rlyf, _sinə, _vošl, --, 
   {{0x2910b7cc,0x6ab4b7cd,0x00000000,0x00000000}},	//   rrya_, slyf, --, --, 
   {{0xc2f009bd,0x9f5cb7ce,0x6ab4007c,0xa6c80066}},	//   _টিভি_, gatè_, plyf, موئل_, 
   {{0x26dc0c6a,0x569002bf,0x59a421bd,0x00000000}},	//   _étom_, наєт, _कुकर, --, 
   {{0x9f5c02d3,0xb5fc0432,0x00000000,0x00000000}},	//   tatë_, _gošm, --, --, 
   {{0x9f5c02e2,0x00000000,0x00000000,0x00000000}},	//   batè_, --, --, --, 
   {{0x9f5c044e,0x9878008f,0x00000000,0x00000000}},	//   ratë_, _פאלט, --, --, 
   {{0xf7940014,0xd624b7cf,0x415468eb,0xe4d800f1}},	//   _تۆمب_, _носе_, двис, _هورت_, 
   {{0xe57800fd,0x6600b7d0,0x9f5cb7d1,0x95e400e5}},	//   _уза_, maok, maté_, _رکنِ_, 
   {{0x443808d2,0x6600b7d2,0x33280054,0x9f5cb7d3}},	//   _úr_, laok, ńaxa_, laté_, 
   {{0xb5fc00a2,0x34241291,0x1be00118,0x00000000}},	//   _alšy, _ترقّ, _खलबल_, --, 
   {{0x6600b7d4,0x9f5c02fb,0x322401ec,0x00000000}},	//   naok, naté_, _قۋىپ_, --, 
   {{0x9f5c0699,0x9da80395,0x00000000,0x00000000}},	//   zatè_, съна_, --, --, 
   {{0x6600b7d5,0x22440098,0x9f5cb7d6,0x5574008f}},	//   haok, _haok_, haté_, לעכן_, 
   {{0x6600b7d7,0x9f5cb7d8,0x2d9c002f,0x00000000}},	//   kaok, katé_, ßter_, --, 
   {{0x69d8b7d9,0x201c2ba4,0x9f5cb7d6,0xb5fc02f0}},	//   _şter, lgti_, jaté_, _pošm, 
   {{0x7ebcb7da,0x6d4c1772,0x22440c6a,0x660005da}},	// [ed70] lépo, ንክፈር, _maok_, daok, 
   {{0x201c0953,0x3eb8b7db,0x9f5c02e2,0x00000000}},	//   ngti_, llst_, tatè_, --, 
   {{0x6600b7dc,0x7ebc0789,0x9f5c0214,0xe81c230e}},	//   faok, népo, faté_, _पारा_, 
   {{0x6600b7dd,0x9f5cb7de,0xf59400e3,0x6b98148b}},	//   gaok, gaté_, ولاج, útge, 
   {{0x9848b7df,0x3eb8002f,0xb5fc01ef,0x85040116}},	//   _лява_, ilst_, _hošk, فونن, 
   {{0x3eb80e78,0xb5fc5a54,0x43cc0131,0x629c06af}},	//   hlst_, _košk, ﻗﻘﯩﺪ, épon, 
   {{0x9f5cb7e0,0x22440c6a,0xb5fc8847,0x660092de}},	//   baté_, _baok_, _jošk, baok, 
   {{0xb5fc0f72,0x7ebc06fd,0x201c1ebf,0x644c03b2}},	//   _mošk, dépo, egti_, _óbin, 
   {{0xb5fc0219,0xc4500133,0x71a40022,0x41e400ae}},	//   _lošk, _ڕێوب, ьаиз, رسيف, 
   {{0x3eb8b7e1,0xd9ac00fe,0x00000000,0x00000000}},	//   elst_, _কণাম, --, --, 
   {{0x7ebc003e,0xd3780f7e,0xa77800df,0x00000000}},	//   répn, _уча_, ַרשפ, --, 
   {{0xed34b7e2,0x7ebc0098,0xf1580353,0x91d801ec}},	//   мэгэ, sépn, _миеш_, _уәкi, 
   {{0xe81c1889,0x1e8001f4,0xc538010a,0x00000000}},	//   _पाला_, тлям, _япăх_, --, 
   {{0xb5fc08a4,0x66000109,0xbd8c037e,0x42540150}},	//   _bošk, zaok, d用do, _ينەر, 
   {{0x6600009f,0x6d4c0023,0x9f5c4bc7,0x00000000}},	//   yaok, ንክፎር, yaté_, --, 
   {{0x3eb80334,0x25b0033f,0xcdc401d5,0x00000000}},	//   clst_, żyli_, _пайқ, --, 
   {{0x660006d9,0x9f5c0306,0x673c0175,0x684401c6}},	// [ed80] vaok, vaté_, wwpj, мнаа, 
   {{0x6600b7e3,0xc25c0356,0xdcf800e5,0x6fd001f9}},	//   waok, ăţiţ, _برٹش_, _सणां, 
   {{0x6600b7e4,0x9f5c5f72,0x98a80208,0x00000000}},	//   taok, taté_, _cscđ_, --, 
   {{0x168403e6,0x00000000,0x00000000,0x00000000}},	//   وانێ, --, --, --, 
   {{0x9f5c90ed,0x224403bd,0x7ebc0129,0x39340006}},	//   raté_, _raok_, dépl, _пэрс, 
   {{0x9f5c0066,0x660000b5,0x00000000,0x00000000}},	//   saté_, saok, --, --, 
   {{0x9f5cb7e5,0x6600b7e6,0x3eb8002d,0x00000000}},	//   paté_, paok, ylst_, --, 
   {{0x7c28b7b5,0xda78010f,0x7ae003b2,0x00000000}},	//   đeri, ַניר, ílti, --, 
   {{0xa2d83be5,0x68e00332,0x00000000,0x00000000}},	//   _पंक्, íodh, --, --, 
   {{0x54c0b7e7,0x00000000,0x00000000,0x00000000}},	//   _абуб, --, --, --, 
   {{0x1414495f,0x443cb7e8,0xdb0847af,0x201c0024}},	//   _زينة_, mev_, ünüz, rgti_, 
   {{0x443cb7e9,0xe0d84c6b,0xb5fc5160,0x7ebc5fe6}},	//   lev_, _двд_, _rošk, répo, 
   {{0x6458089c,0xd00c2814,0xdbc4afeb,0xb5fc1b5c}},	//   _knti, _چله_, _köçk, _sošk, 
   {{0xb5fcb7ea,0x443cb7eb,0x91b8011a,0x00000000}},	//   _pošk, nev_, _ומדי, --, 
   {{0x8f400124,0x644801ab,0x3eb8010a,0x986c0210}},	//   _ахыд, idfi, plst_, nżą_, 
   {{0x443cb7ec,0x83fc05ce,0x1b000137,0x29600092}},	//   hev_, _dođi, нүүн, _ተካፋይ_, 
   {{0x443cb7ed,0x6458b7ee,0x7e6c0374,0x5cc4b7ef}},	// [ed90] kev_, _onti, _ioap, _осоз, 
   {{0x443c341a,0x7e6c18a6,0x7d1cb7f0,0x9f5c0bc9}},	//   jev_, _hoap, muss, natï_, 
   {{0x443c0842,0x7d1cb7f1,0x7e6c0793,0xb5fc01fa}},	//   dev_, luss, _koap, _hoši, 
   {{0x64580e21,0xb5fcb7f2,0x7e6c00c7,0x629c004e}},	//   _anti, _koši, _joap, épol, 
   {{0x9f5c0054,0x443c01af,0xb5fc0cf4,0x59c013f7}},	//   katï_, fev_, _joši, _शरिर, 
   {{0xdfc4b7f3,0x64580a2e,0x7e6c4d11,0x443c00af}},	//   _مي_, _cnti, _loap, gev_, 
   {{0xb5fc07f5,0x7d1cb7f4,0x645801f5,0x32d4b7f5}},	//   _loši, huss, _dnti, нцис, 
   {{0xb144b7f6,0x7d1cb7f7,0x7e6cb7f8,0xbebc005f}},	//   енил, kuss, _noap, stīj, 
   {{0x7c24b7f9,0x7d1c0af5,0x443cb7fa,0x317801ed}},	//   _ochr, juss, bev_, ász_, 
   {{0x7d1cb7fb,0x443cb7fc,0x6f644623,0x7648020b}},	//   duss, cev_, евоз, _haey, 
   {{0xb3741e38,0x7e6c01af,0x932404d3,0xaf980212}},	//   ራውያን_, _boap, _زران, ятих_, 
   {{0x7d1cb7fd,0x7c24b7fe,0x7e6cb7ff,0x491000bc}},	//   fuss, _achr, _coap, _ढिलो_, 
   {{0x7d1cb800,0x64580b21,0xf0c0030d,0x00000000}},	//   guss, _ynti, _бιаь, --, 
   {{0x83fc16a3,0x7c240055,0x2d9c0083,0xac083b26}},	//   _pođi, _cchr, ăte_, янга_, 
   {{0x7e6c08cd,0x7c240472,0x7d1c0e78,0x3eac0100}},	//   _foap, _dchr, auss, èktè_, 
   {{0x443cb801,0x7e6c05c7,0x83fc00f3,0x7c240142}},	//   zev_, _goap, _vođi, _echr, 
   {{0x443cb802,0x7d1cb803,0x7c2401ab,0xebe46f65}},	// [eda0] yev_, cuss, _fchr, _попп, 
   {{0xe3c80139,0xf8a800f1,0x9dd4011a,0xd820011c}},	//   _jiñü_, ودله_, _אופק_, лдуи, 
   {{0x443cb804,0x764801e4,0xb5fc0030,0xeab800d1}},	//   vev_, _baey, _zoši, _нйо_, 
   {{0xb5fc073c,0x645805b1,0x443c009a,0xd1c8001f}},	//   _mošw, _snti, wev_, ጠሩት_, 
   {{0x443c4859,0x66d800bc,0x629c0118,0x00000000}},	//   tev_, _důka, épom, --, 
   {{0xd5acb805,0x88b00134,0x68445b7f,0x2c640030}},	//   حفه_, brɛa, _янга, _pôdy_, 
   {{0x98a0b806,0x18a03776,0x76480076,0x6448b807}},	//   _сире, _сарм, _faey, rdfi, 
   {{0x443cb808,0xa6a8b809,0x21640063,0x97540375}},	//   sev_, _رازق_, етог, _אילו_, 
   {{0x7e6c03d1,0xdbc40139,0x7d1c002f,0x91b40395}},	//   _roap, _töçk, xuss, нгът_, 
   {{0x6458b80a,0xe3c80724,0x271c01f2,0x7d1c33eb}},	//   _unti, _ciñü_, _ọnye_, vuss, 
   {{0x7d1cb80b,0xb5fc01a6,0x7e6cb80c,0xe3140472}},	//   wuss, _soši, _poap, _سباب, 
   {{0x7c24b80d,0xb5fc0f03,0x1798008d,0xd36c04fb}},	//   _schr, _poši, לייב, _دهم_, 
   {{0x7d1c20ac,0x7e6c03d1,0x9f5cb80e,0x9cc8023a}},	//   uuss, _voap, patï_, зыва_, 
   {{0x7d1cb80f,0x7e6c013f,0x40940014,0x9f5c1d55}},	//   russ, _woap, _جلتر, latí_, 
   {{0x7d1c32ff,0x7e6c007c,0x00000000,0x00000000}},	//   suss, _toap, --, --, 
   {{0x7d1cb810,0xb5fc0960,0x9f5c0270,0x1cb00327}},	//   puss, _toši, natí_, _ཟེམ_, 
   {{0xf8b08bf7,0x7d1c20ac,0x63b801bf,0x7e7c036e}},	// [edb0] لکس_, quss, _lytn, ërpu, 
   {{0x7c24006c,0x7d0c022c,0x9f5c0306,0x00000000}},	//   _uchr, _ivas, hatí_, --, 
   {{0x7d0c0d12,0x63b80334,0x394c0003,0x97a44b36}},	//   _hvas, _nytn, _ġesu_, храл, 
   {{0x9f5c01f1,0x5ee0009e,0x26c4002e,0x00000000}},	//   jatí_, _মবাই, ŋoon_, --, 
   {{0x6d58b811,0x49748675,0x1be8033f,0xd5a001d5}},	//   ātag, _бляс, जुअल_, دلشی, 
   {{0x764801f9,0x5884b6f6,0xd838b812,0x00000000}},	//   _waey, _чыма, _ээм_, --, 
   {{0x7648b813,0x7ebc00e5,0xf79400c0,0x00000000}},	//   _taey, gépk, _равэ, --, 
   {{0xa560034c,0x7d0cb814,0x91c0010b,0xd5b800d8}},	//   _چگون, _ovas, лайҗ, _есз_, 
   {{0x1850001f,0x3a2c0022,0x7d0c0055,0x00000000}},	//   _ለማንኛ, _ñepu_, _nvas, --, 
   {{0x7ebcb815,0x44b4022e,0x00000000,0x00000000}},	//   léph, _ббус, --, --, 
   {{0x7d0cb816,0x63b80354,0xaec42bcb,0xdc240154}},	//   _avas, _gytn, кбол, য়াস_, 
   {{0x7ebc06af,0x717800c0,0xc2e401d5,0xe28c0063}},	//   néph, _обер_, _сўфи, _ђа_, 
   {{0x9f5c0421,0xe0cc0408,0x5d64023a,0x7d0c0356}},	//   gatâ_, _вв_, виям_, _cvas, 
   {{0x7d0c0006,0x2f5400d1,0x6ad86766,0x7ebc003e}},	//   _dvas, _атис, भद्र, héph, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb5fc098d,0x2bdca4ea,0x00000000,0x00000000}},	//   _košu, _मलका, --, --, 
   {{0x6e34030d,0x7ebc01d3,0xcbc400fe,0x00000000}},	// [edc0] _ibyb, zépk, ্ডেছ, --, 
   {{0x6d548aa7,0x394c031c,0x6ae401d5,0x7d080135}},	//   _irya, _ġest_, _ижоз, ġest, 
   {{0x394c0552,0x7d08098d,0x7d0c006f,0x6d54062c}},	//   _šest_, šest, _zvas, _hrya, 
   {{0x940400ac,0x6d540139,0x7d0c0162,0x00000000}},	//   minə_, _krya, _yvas, --, 
   {{0x940400ac,0x6d546e25,0x7ae801e4,0x00000000}},	//   linə_, _jrya, ĉete, --, 
   {{0x6d54003e,0x69c401c4,0xa2d80a5a,0xc4486646}},	//   _mrya, _izke, _पूज्, عیان_, 
   {{0x94040213,0x6e3402d0,0xb3d40011,0xa6a800cf}},	//   ninə_, _obyb, _স্বজ, _قارق_, 
   {{0x6d54b817,0x7ebca4f1,0x13e43bf0,0x9f5c0022}},	//   _orya, céph, нмәй_, hatã_, 
   {{0x15407390,0x9f5c02fb,0xa444035b,0xb5fc00d0}},	//   _кетм, ratí_, _инад, _pošv, 
   {{0x6e340857,0x7d0c022e,0xe50000cd,0xb7a40166}},	//   _abyb, _rvas, रीणि_, _çäçs, 
   {{0x6d54b818,0x7d0cb819,0x6e340076,0x50d000c6}},	//   _arya, _svas, _bbyb, جزير, 
   {{0x69c40427,0x2fc402dd,0x94040213,0xb19401e0}},	//   _ozke, ырың, dinə_, _әлшә, 
   {{0xbebc00da,0x3a743ba6,0x4034b81a,0x63b40209}},	//   ktīv, қлар, _белс, şynd, 
   {{0x6280b81b,0x6d54b81c,0x94040213,0x9f5c003a}},	//   _hloo, _drya, finə_, ratâ_, 
   {{0x69c4152d,0xb5fc0bb8,0x6d54b81d,0x6280b81e}},	//   _azke, _košt, _erya, _kloo, 
   {{0x6d54003b,0x7d0cb81f,0x00000000,0x00000000}},	//   _frya, _tvas, --, --, 
   {{0x62800190,0x7d0c2812,0xb5fcb820,0x3834b821}},	// [edd0] _mloo, _uvas, _mošt, лнар, 
   {{0x9f5c0589,0x7e7c62f1,0x62800072,0x940400ac}},	//   catã_, lksp, _lloo, binə_, 
   {{0x6280b822,0x69c405f5,0xb7c40588,0x20c01d0e}},	//   _oloo, _ezke, урақ, yðin_, 
   {{0x62800218,0x0708b823,0xb5fc00d7,0x009400d1}},	//   _nloo, ئيني_, _nošt, ﺗﺮﺍﭘ, 
   {{0x7ae4049b,0x7e7c89c2,0xa2c40864,0x57f00327}},	//   _huht, iksp, ातन्, _བཅྭོ_, 
   {{0x04c832e8,0x6280b824,0x7ebc0129,0xe7f4b825}},	//   نوني_, _aloo, séph, ेरणा_, 
   {{0x7ae4033d,0x62808b35,0xb5fc09a8,0x7e7c168c}},	//   _juht, _bloo, _bošt, kksp, 
   {{0x6280b826,0x7ae4b827,0x4254081d,0x437403cc}},	//   _cloo, _muht, атьт, рушт, 
   {{0x20c005a4,0x7ae43110,0x7ebc0129,0xafe41318}},	//   rðin_, _luht, cépi, лопл, 
   {{0x94040cc1,0x6280198f,0x6d540076,0xd3781f5a}},	//   yinə_, _eloo, _rrya, _оче_, 
   {{0x6280b828,0x9f5c00db,0x7ae4b829,0x94040213}},	//   _floo, gatà_, _nuht, xinə_, 
   {{0xd1700831,0x6838005c,0x94040213,0x62800afa}},	//   _ҡыҙы, _kødæ, vinə_, _gloo, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7ae4b82a,0x7e7cb82b,0x940403be,0xb5fc00d0}},	//   _buht, ërpr, tinə_, _zošt, 
   {{0x7ae40076,0xaf04036b,0x09cc00dc,0x7ebc01d3}},	//   _cuht, _ёпил, ऽध्य, zépi, 
   {{0x94040cc1,0x7e7cb82c,0x6d54b82d,0xa9680107}},	//   rinə_, cksp, _trya, ниба_, 
   {{0x94040cc1,0xa81822f3,0x9f5c0589,0x6d54b82e}},	// [ede0] sinə_, فتار_, patã_, _urya, 
   {{0x7ae40165,0xa848007b,0x7dc8022e,0x9f5c022a}},	//   _fuht, علام_, dоsh, latá_, 
   {{0xe618b82f,0x7ae40165,0x94040213,0x00000000}},	//   еде_, _guht, qinə_, --, 
   {{0x9f5cb830,0xa9685169,0x637803b2,0x7ebc00e4}},	//   natá_, _зима_, _lønú, tépi, 
   {{0x69c40064,0x00000000,0x00000000,0x00000000}},	//   _uzke, --, --, --, 
   {{0x6280b831,0xd46400a8,0xbebc005f,0x9f5c02fb}},	//   _sloo, личе_, ltīt, hatá_, 
   {{0xb5fcb832,0x6280b833,0x68e40113,0xe618b834}},	//   _pošt, _ploo, _hukd, _пдв_, 
   {{0xbebc3a71,0x42747bea,0x851c05f9,0x398c01a9}},	//   ntīt, ргис, _निपट_, _bоsh_, 
   {{0x62804fa9,0x83fc9ac0,0x81dc015b,0xb5fc0e04}},	//   _vloo, _anđe, তুন_, _vošt, 
   {{0xdde82a60,0x83fc3881,0x68e400ee,0x88b0016b}},	//   کرده_, _vođs, _mukd, krɛm, 
   {{0xe35806b3,0x26dc003e,0x6280b835,0x00000000}},	//   _яшаш_, _étos_, _tloo, --, 
   {{0x7e7c030a,0x7ae4b836,0x10a00166,0x00000000}},	//   uksp, _ruht, _һичн, --, 
   {{0x7ae4b837,0x61e0b838,0x8d84b839,0x68e4010b}},	//   _suht, _igol, бурд, _nukd, 
   {{0x7ae4b83a,0x7e7c4bc1,0x9f5c026c,0x00000000}},	//   _puht, sksp, patà_, --, 
   {{0x61e099df,0x4f5421e7,0x2900b83b,0x1dd40228}},	//   _kgol, _مجيد_, _awka_, _өлкө_, 
   {{0x61e0009a,0x79f42ced,0x2db40521,0xd8740133}},	//   _jgol, рзах, ọkụ_, گارب, 
   {{0x3ea88a7b,0x391403e6,0x38c82ab4,0x00000000}},	// [edf0] _ijat_, شواز, نائی_, --, 
   {{0x68e403f9,0xd87419e2,0x7ae4b83c,0x55c001e0}},	//   _dukd, دارب, _tuht, ҙалғ, 
   {{0x61e0b83d,0x3ea80652,0x00000000,0x00000000}},	//   _ogol, _kjat_, --, --, 
   {{0x68e40369,0x7d1c03ac,0xfca800ec,0x00000000}},	//   _fukd, orss, _ساڌو_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x61e0b83e,0x4d7c00c8,0x798c009f,0x167002dd}},	//   _agol, ערגע, mzaw, шқұр, 
   {{0x7d1cb83f,0x36d4023a,0x9f5c003a,0x798c0175}},	//   hrss, _вовр, latæ_, lzaw, 
   {{0x3dc805b1,0x3f8c01fa,0x798c00b5,0x3ea80200}},	//   _ozaw_, dzdu_, ozaw, _njat_, 
   {{0x798cb840,0x9f5cb841,0x3f8c00d0,0x7d1c01bf}},	//   nzaw, vatá_, ezdu_, jrss, 
   {{0x61e0b842,0x3ea8b843,0xe81c007d,0x339400c0}},	//   _egol, _ajat_, _पाछा_, _казё, 
   {{0x798c02b9,0x7d1c1401,0x9f5c00d8,0x3f8c0171}},	//   hzaw, erss, tatá_, gzdu_, 
   {{0x3a38b844,0x2cb84862,0x3134781e,0x61e01418}},	//   _nbsp_, _skpd_, _ведр, _ggol, 
   {{0x6cc4b845,0x9f5c00d8,0x7bc00112,0x6d4401a4}},	//   ийма, ratá_, ülun, uwka, 
   {{0x798cb846,0x61e0b847,0x7ebc0129,0x3ea80171}},	//   dzaw, _zgol, dépu, _ejat_, 
   {{0xa0980bd9,0x68e4b848,0x798c0083,0x7d080cf4}},	//   _ביסט, _sukd, ezaw, šesp, 
   {{0x3ea80023,0x8ea40137,0x3958036e,0xee38442d}},	//   _gjat_, _دلبۇ, _brss_, _рни_, 
   {{0xa804b849,0xacc800d1,0xbd880014,0x6d440113}},	// [ee00] изал, _игиз_, _منٹن_, qwka, 
   {{0xbebc9787,0x00000000,0x00000000,0x00000000}},	//   stīt, --, --, --, 
   {{0xa6c804fb,0x798c002d,0xbebc00e2,0x91f407af}},	//   نوئل_, azaw, ptīt, ीराज_, 
   {{0x798c02a8,0x77906276,0x1f34008f,0x3a2c1bce}},	//   bzaw, سیقا, ירער_, _ñepp_, 
   {{0xe5a405c2,0x9f4c033b,0xd624023a,0x9f5c003a}},	//   шиди, _jefò_, роче_, catæ_, 
   {{0x3200013f,0x61e0b84a,0x3a3801c7,0x7ebcb84b}},	//   _ɑhye_, _sgol, _zbsp_, lépt, 
   {{0x2a60045f,0x95e40014,0x7dc8022e,0x00000000}},	//   _knkb_, اکہِ_, rоsi, --, 
   {{0xd254b84c,0x92b00fb4,0x7d1c005c,0x259800b8}},	//   аць_, يحيا, yrss, _pūṣṇ, 
   {{0xa18400fd,0xca7c022e,0x403404b3,0xa0a401d5}},	//   рыйл, ktrо, бепс, ишол, 
   {{0x9f4c2045,0x3ea8005c,0x20c400f0,0x00000000}},	//   _tefü_, _sjat_, јсиг, --, 
   {{0xb5fc01fa,0x9878008f,0x3ea8005c,0x798cb84d}},	//   _košp, דריק, _pjat_, zzaw, 
   {{0x61e0b84e,0x442cb84f,0x77600005,0x259800cd}},	//   _ugol, _hcd_, _álxe, _tūṣṇ, 
   {{0x88b002ea,0x442c00f2,0xa0a4b850,0x7d1c01f5}},	//   grɛk, _kcd_, _кадд, urss, 
   {{0x442c0100,0x3cf8007c,0x00000000,0x00000000}},	//   _jcd_, rpsv_, --, --, 
   {{0x6d5800b0,0x3ea801e3,0xe8b0013d,0xf7c40150}},	//   ātaa, _tjat_, _şeşä, _ﺩﺍﻋﺪ, 
   {{0x7d7801ed,0x7a3000e5,0xb5fc00ef,0x00000000}},	//   _ممبر_, dótó, _nošp, --, 
   {{0x442cb851,0x3eb8b852,0x00000000,0x00000000}},	// [ee10] _ocd_, most_, --, --, 
   {{0x3eb80b9d,0x798c0c09,0x3ce8011c,0x442c05b1}},	//   lost_, rzaw, _iuav_, _ncd_, 
   {{0x3ce801d4,0x9f4c007f,0x7ebc003e,0x3a38045a}},	//   _huav_, _zefò_, sépu, _tbsp_, 
   {{0xc6a4b853,0x3ce80218,0x7ebc04d4,0x4b540014}},	//   орчи, _kuav_, cépt, _بێٲر, 
   {{0x3958b854,0x0a68084c,0x3a28022e,0x00000000}},	//   _urss_, _трэи_, mgap_, --, 
   {{0x3eb8b855,0x9f4c002e,0xd49801f0,0x3a28372c}},	//   host_, _effé_, ъре_, lgap_, 
   {{0xd6d8b856,0x442cb857,0x3eb8b858,0x3ce80218}},	//   _ата_, _dcd_, kost_, _luav_, 
   {{0x442cb859,0x3a28b85a,0xd040043b,0x3eb81b24}},	//   _ecd_, ngap_, _linɔ, jost_, 
   {{0x3eb833dc,0x3ce80211,0x442cb85b,0x39480549}},	//   dost_, _nuav_, _fcd_, nwas_, 
   {{0x39485f99,0x9f5c02b5,0xed5800fb,0x00000000}},	//   iwas_, katä_, ңон_, --, 
   {{0x16080b26,0x63e407d2,0x73c401ec,0x3eb80254}},	//   _हजार_, _ايمە, _уәде, fost_, 
   {{0x394823db,0xddc80010,0xa0640022,0x5f400228}},	//   kwas_, _šiše, _ҳаша_, سچىل, 
   {{0x3ce80070,0x2b580356,0xafe4030d,0x3074009d}},	//   _cuav_, _srpc_, _лолл, _гуйс, 
   {{0x3ce80211,0x644c0798,0x394804ce,0x442c2370}},	//   _duav_, _óbit, dwas_, _xcd_, 
   {{0xbebc00ef,0x00000000,0x00000000,0x00000000}},	//   frīd, --, --, --, 
   {{0x3a2887d3,0x3eb8b85c,0xdb1c0118,0xbebc00de}},	//   ggap_, cost_, ývák, grīd, 
   {{0x39481e92,0x9f4c01a8,0x00000000,0x00000000}},	// [ee20] gwas_, _hefð_, --, --, 
   {{0x81ac015b,0x7ebc003e,0x7a3000e5,0x6cc401af}},	//   _গরম_, sépt, tótó, _ыйпа, 
   {{0x442cb85d,0xb5fc4b16,0x7ebc90d0,0x9cd808c3}},	//   _rcd_, _pošp, pépt, _תקיפ, 
   {{0xc5f8b85e,0x3ce80e37,0x5fb800c8,0x7ebc0129}},	//   рға_, _yuav_, אצענ, lépr, 
   {{0x442c0c86,0x3ce801d4,0xf608208f,0x151000d4}},	//   _pcd_, _xuav_, شتنه_, здія, 
   {{0x442cb85f,0x7aec01ed,0x3eb8013a,0x00000000}},	//   _qcd_, _öltö, zost_, --, 
   {{0x79880209,0xd464026a,0x959400c7,0xf4d401ec}},	//   _ýewr, сије_, итәу_, _ﺟﻮﺗﻜ, 
   {{0x7ebc020c,0xdef81de6,0x78a8032e,0x26c00248}},	//   hépr, һым_, _íevr, _óko_, 
   {{0x3eb8b860,0x2910b861,0x7ebc01d3,0xb3a401e0}},	//   vost_, nsya_, zéps, йләһ, 
   {{0xdef8b862,0x3f14b863,0x442cb864,0xb5fc05be}},	//   лым_, одос, _ucd_, _inša, 
   {{0x3eb8b865,0x3ce80190,0x7ebc73a0,0x629c2056}},	//   tost_, _suav_, dépr, épos, 
   {{0x3ce80070,0x3a280007,0xe290009f,0x21c801af}},	//   _puav_, xgap_, _عذا_, _йылп_, 
   {{0x3ce80070,0x2d9c009a,0x8d84013e,0x5fb801f9}},	//   _quav_, фte_, пурд, _उडवल, 
   {{0x3eb8b866,0x528002dd,0xa2c400cd,0x00000000}},	//   sost_, _ولەك, ातव्, --, 
   {{0x3eb8b867,0x4c94b868,0x7ae80115,0x28bc00cd}},	//   post_, чирс, ĉeto, ्तनि, 
   {{0x139800c8,0x3ce80457,0x394803fa,0x9f5c0034}},	//   אבלע, _tuav_, twas_, śród_, 
   {{0x3a28b869,0x7ebc003e,0x391401f0,0x00000000}},	// [ee30] rgap_, séps, юмар, --, 
   {{0x3948b86a,0x7ebc003e,0xf8b800f7,0x3c640244}},	//   rwas_, cépr, рөм_, _بیسێ_, 
   {{0x3948b86b,0x29100ecf,0x32f400cd,0x81ac03d4}},	//   swas_, asya_, _kāye_, _গৰম_, 
   {{0x66c802fb,0xc8840166,0x76b800ee,0x59640395}},	//   týka, _arğı_, шлер_, _лъга, 
   {{0x32f40055,0x09e00154,0x4d5c010f,0xdcec00ef}},	//   _māye_, যুবা, ָדוצ, dzcī, 
   {{0x1bf82699,0xf7940006,0x00000000,0x00000000}},	//   ्रिल_, _дагэ, --, --, 
   {{0xe7ec012d,0x00000000,0x00000000,0x00000000}},	//   _जलता_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x81dc009e,0x60e4005b,0x648402d2,0x18340092}},	//   _ত্ব_, омым_, _iðin, _ከማንኛ, 
   {{0xd43400f1,0x00000000,0x00000000,0x00000000}},	//   _دعرب, --, --, --, 
   {{0xbebc0029,0xb4d40073,0x629c0022,0x00000000}},	//   drīb, सगी_, ĩpor, --, 
   {{0x2910b86c,0x644c02d2,0xc8d00dba,0x00000000}},	//   ysya_, _óbir, _तीनट, --, 
   {{0x3074b86d,0xa2c44195,0x28bc00cd,0xbc840051}},	//   _мукс, ातर्, ्तमि, ưỡn, 
   {{0xeb9801b9,0x00000000,0x00000000,0x00000000}},	//   ҳиҳ_, --, --, --, 
   {{0x7ebc004a,0x00000000,0x00000000,0x00000000}},	//   répr, --, --, --, 
   {{0xdfcc0150,0x2d9401ee,0x00000000,0x00000000}},	//   _جيى_, _дөгө_, --, --, 
   {{0xe96801c0,0x6c740131,0xe80801af,0x316c005a}},	// [ee40] шаал_, _дунх, инад_, nxez_, 
   {{0x2910b86e,0xe7380276,0xeb980114,0x00000000}},	//   rsya_, иез_, _вио_, --, 
   {{0x32f40055,0x00000000,0x00000000,0x00000000}},	//   _yāye_, --, --, --, 
   {{0x291002ce,0xa274001f,0x56900212,0x669800db}},	//   psya_, ራችንን_, маєт, جئئح_, 
   {{0x1fd41b51,0x00000000,0x00000000,0x00000000}},	//   _ठण्ड, --, --, --, 
   {{0xf1b80427,0x5904b86f,0x5c34010f,0x00000000}},	//   ngšu_, _ферм_, ַרפן_, --, 
   {{0x4420079d,0xa2c40574,0x7ebc01d3,0x75980023}},	//   ği_, ातल्, képp, ሓላለፎ_, 
   {{0xcfcc0154,0x2284009d,0x00000000,0x00000000}},	//   রশান, юулг, --, --, 
   {{0x6600b870,0x26c41bce,0x32f40055,0x00000000}},	//   mbok, mloo_, _rāye_, --, 
   {{0x26c4b871,0x660005f5,0x44380013,0x6d58b872}},	//   lloo_, lbok, _ùr_, ātal, 
   {{0x44f0b873,0x9f5c01d3,0x26c41574,0x00000000}},	//   _hà_, latú_, oloo_, --, 
   {{0x6600b874,0x44f00cad,0x26c4002e,0xd24c00f1}},	//   nbok, _kà_, nloo_, _ټنه_, 
   {{0x9f5cb875,0xd12c4a3b,0x26c40270,0x44f0110e}},	//   natú_, _لمن_, iloo_, _jà_, 
   {{0x44f0b876,0xbf14adb0,0x2bb403f8,0x50b40b24}},	//   _mà_, _فوتب, _आँखा, _ودود_, 
   {{0x44f0431d,0x9f5c0419,0xa6c8022e,0x00000000}},	//   _là_, hatú_, ttаl, --, 
   {{0xc68400aa,0x0cb4033f,0x26c400e8,0x9f5c7523}},	//   _شې_, ंकॉम, jloo_, katú_, 
   {{0x44f00570,0x660078d0,0x81dc015b,0x26c40009}},	// [ee50] _nà_, dbok, তুর_, dloo_, 
   {{0xd7f80c26,0x9404013f,0xdd9002dd,0x26c400e8}},	//   руа_, yinɑ_, _нақы, eloo_, 
   {{0x44f001e1,0x26c40de2,0x00000000,0x00000000}},	//   _aà_, floo_, --, --, 
   {{0x44f0b877,0x26c41bce,0xeb8800fb,0x00000000}},	//   _bà_, gloo_, _ырыҫ_, --, 
   {{0x44f0b878,0x58840153,0x00000000,0x00000000}},	//   _cà_, _дыва, --, --, 
   {{0x44f0b879,0xa97802e4,0x26c4b87a,0x7ebc01d3}},	//   _dà_, _האשכ, aloo_, zépp, 
   {{0x8c440cc1,0x44f00428,0x66000083,0x26c47171}},	//   əşdi, _eà_, bbok, bloo_, 
   {{0x44f0b87b,0x316c01c4,0x75980023,0xf1d041b9}},	//   _fà_, txez_, ሓላልፎ_, нөлө, 
   {{0x44f0b87c,0xd5a051ae,0x94200131,0xa1540114}},	//   _gà_, _غلطی, _يورۇ, зању_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7bc4b87d,0x44f003d1,0xe7ec02e5,0x22a40014}},	//   _nyhu, _zà_, _जलसा_, _کٔنہ, 
   {{0xccf80c60,0xe3b0008f,0x44f0110e,0x00000000}},	//   оқи_, _אױב_, _yà_, --, 
   {{0x44f001fb,0xd14803e6,0x82343fa9,0x00000000}},	//   _xà_, _خشان_, _آرما, --, 
   {{0xaff800aa,0x7bc4005c,0x00000000,0x00000000}},	//   _افغا_, _byhu, --, --, 
   {{0x7bc403cb,0x660003cd,0x26c42da0,0x9f5c01d3}},	//   _cyhu, ybok, yloo_, zatú_, 
   {{0x6484008c,0x7bc40142,0xddc81527,0x26c400e8}},	//   _aðil, _dyhu, šiša, xloo_, 
   {{0xa9243981,0xada40640,0xb5fc00ef,0x00000000}},	// [ee60] ядал, _хапл, _anšo, --, 
   {{0x44f0b87e,0x13e000bd,0xf42000bd,0x2d80003b}},	//   _rà_, নুয়, প্তর_, myke_, 
   {{0x44f0b87f,0x2d80b880,0x7bc403cb,0x26c400e8}},	//   _sà_, lyke_, _gyhu, tloo_, 
   {{0x44f00c95,0xe7ec0c2e,0x66d40428,0x66c80306}},	//   _pà_, _जलवा_, dükù, rýko, 
   {{0x26c4b881,0x00000000,0x00000000,0x00000000}},	//   rloo_, --, --, --, 
   {{0x44f04cc5,0x26c488c9,0xd3800952,0x9f5c00e5}},	//   _và_, sloo_, ﯨﻠﯩﻖ_, ratú_, 
   {{0x44f00570,0x6600b882,0x69c401f4,0x92c800fe}},	//   _wà_, pbok, _hyke, লদৈ_, 
   {{0x44f0b883,0xdb2007ea,0x69c4b884,0x6d581c52}},	//   _tà_, érée, _kyke, ātaj, 
   {{0x69c40108,0x00000000,0x00000000,0x00000000}},	//   _jyke, --, --, --, 
   {{0x2d80014b,0x69c4b885,0x1dd00490,0x00000000}},	//   dyke_, _myke, _सरबत, --, 
   {{0x6448b886,0x69c4002d,0xe298b887,0x81dc00eb}},	//   mefi, _lyke, _лаж_, তুং_, 
   {{0xd24cb888,0x69c46aad,0xf49401ec,0x71200137}},	//   _منم_, _oyke, _ىشەد, رۉۉم, 
   {{0x69c412e8,0xdb2000f1,0x1a540137,0x2d8000e4}},	//   _nyke, کوزی, үзгө_, gyke_, 
   {{0x6448b889,0x19a80032,0xb144036b,0x3f98003a}},	//   nefi, ҡтап_, _کییم_, úrus_, 
   {{0x32f4002b,0x00000000,0x00000000,0x00000000}},	//   _kāya_, --, --, --, 
   {{0x644800a9,0x69c406f2,0xf8c400dc,0x7bc40306}},	//   hefi, _byke, वत्प, _vyhu, 
   {{0x69c4b88a,0x32f400b8,0x200cb88b,0x00000000}},	// [ee70] _cyke, _māya_, _kefi_, --, 
   {{0x644858af,0x88b002ea,0x200cb88c,0x69c4b88d}},	//   jefi, drɛs, _jefi_, _dyke, 
   {{0x69c403b2,0xb7c402dd,0xf3f00208,0x00000000}},	//   _eyke, фрақ, _lạc_, --, 
   {{0x200ca06a,0x69c4143a,0x32f40055,0x00000000}},	//   _lefi_, _fyke, _nāya_, --, 
   {{0x64481132,0x88b0016b,0xd7f81d82,0x349401f0}},	//   fefi, trɛt, _губ_, мадр, 
   {{0x6448b88e,0x20c02880,0x200cb88f,0x854800d4}},	//   gefi, iðis_, _nefi_, язів_, 
   {{0x360445cf,0xb9cc0023,0x00000000,0x00000000}},	//   _يوسف, _ተር_, --, --, 
   {{0x23240107,0xf3f00208,0x81c800fe,0x62300114}},	//   фоъи_, _bạc_, োখন_, већу, 
   {{0x6448b890,0x200c013f,0x9f4c04cc,0xc4f8b891}},	//   befi, _befi_, _affà_, _فعلا_, 
   {{0xef1826af,0x7658b892,0x644834b9,0x33680150}},	//   омо_, ldwy, cefi, _وجاۋ_, 
   {{0x200cb893,0x2d800af9,0xa2500214,0x76580142}},	//   _defi_, wyke_, رپیش, odwy, 
   {{0x2d80b894,0x200c198f,0xada4b895,0x7658b896}},	//   tyke_, _eefi_, дамл, ndwy, 
   {{0x200c0109,0xd1c800cf,0x76580042,0x3f9803f2}},	//   _fefi_, _ابام_, idwy, úrur_, 
   {{0x69c4b897,0x2d80b898,0x7644013f,0x60d80175}},	//   _ryke, ryke_, ɑhye, cmtm, 
   {{0x69c400d6,0x2d800815,0x6fb401d3,0x4fc401b9}},	//   _syke, syke_, _تمغا, _эсда, 
   {{0x6448b899,0x200cb89a,0xad240137,0x00000000}},	//   zefi, _zefi_, _قىبى, --, 
   {{0x6448b89b,0x76580cfd,0x200c016b,0xa81813d7}},	// [ee80] yefi, ddwy, _yefi_, قتار_, 
   {{0xb8c40075,0xc73c001f,0x69c402f0,0x76580142}},	//   ىزلى, _አላውቅ, _vyke, edwy, 
   {{0x6448b89c,0x69c40b21,0x443c05b1,0x00000000}},	//   vefi, _wyke, vfv_, --, 
   {{0xa968b89d,0x25880aaf,0x69c4b89e,0x76a800d4}},	//   _дима_, يناپ_, _tyke, птів_, 
   {{0x6448b89f,0x20c008a7,0x1fb86b26,0xd36c0344}},	//   tefi, iðir_, _उड्ड, یهه_, 
   {{0x6d5804fe,0x321c0042,0x7658015d,0x958002e8}},	//   ātah, _adwy_, adwy, ълче, 
   {{0x200cb8a0,0x87e41075,0x2734215c,0x32f40055}},	//   _refi_, _ستسە, _تىزس, _pāya_, 
   {{0x6448b8a1,0x200c5c6a,0x28bc00dc,0x41543849}},	//   sefi, _sefi_, ्तवि, евис, 
   {{0x6448b8a2,0x321c00a9,0x7ae80115,0x15d80150}},	//   pefi, _ddwy_, ĉeti, _ﻁﺭﻓﻬ, 
   {{0x94201d0f,0x200c036e,0x00000000,0x00000000}},	//   _амфе, _qefi_, --, --, 
   {{0x69d8008f,0xa2e40137,0x32f400b8,0x200cb8a3}},	//   _ŝtel, _жожд, _tāya_, _vefi_, 
   {{0xe2a815f8,0x20c001a8,0x00000000,0x00000000}},	//   _باطن_, gðir_, --, --, 
   {{0xbebc005f,0x55b8010f,0x200c0139,0xe9e40332}},	//   brīn, ַמלו, _tefi_, íúla_, 
   {{0x4034b8a4,0xdbf81025,0xa6c801a9,0x00000000}},	//   _чекс, ्रेड_, stаh, --, 
   {{0x321c0042,0x76580042,0x504000d8,0x00000000}},	//   _ydwy_, ydwy, _рејб, --, 
   {{0x228801e1,0xdb0c0248,0x00000000,0x00000000}},	//   _mùko_, _ìdíj, --, --, 
   {{0x127800c8,0x1dd0738f,0xb998447e,0x5c041c34}},	// [ee90] קאמע, _सरित, чвах_, _ояна, 
   {{0x7d0cb8a5,0x6d58012d,0x76580042,0x00000000}},	//   _iwas, łtac, wdwy, --, 
   {{0x7d0c006f,0xc6d40014,0x97000116,0x00000000}},	//   _hwas, چتنت, ئېرى, --, 
   {{0xc6d40014,0x00000000,0x00000000,0x00000000}},	//   نتنت, --, --, --, 
   {{0x7658b8a6,0x3af4168c,0x7d0c0003,0x00000000}},	//   rdwy, _håp_, _jwas, --, 
   {{0x7d0cb8a7,0xa0200213,0x00000000,0x00000000}},	//   _mwas, _çöhr, --, --, 
   {{0xc7c40075,0x28bcb8a8,0x6d58b8a9,0x20c00bcd}},	//   _асти, ्तरि, ātai, yðir_, 
   {{0x7d0c5935,0x78a4000d,0x84e803ce,0x00000000}},	//   _owas, lihv, टआउट_, --, 
   {{0x7d0cb8aa,0x3dc8013f,0xbebc00e2,0x00000000}},	//   _nwas, _nyaw_, trīn, --, 
   {{0x212000d2,0x78a403b2,0xaf0401f4,0x00000000}},	//   ákha_, nihv, нпол, --, 
   {{0x3dc8417f,0x00000000,0x00000000,0x00000000}},	//   _ayaw_, --, --, --, 
   {{0x322801ec,0x78a4016d,0xd5d00562,0x00000000}},	//   _ءتاۋ_, hihv, _तराज, --, 
   {{0x20c011c3,0x32f400cd,0x00000000,0x00000000}},	//   rðir_, _kāyo_, --, --, 
   {{0x7d0c0af9,0x8fc0035b,0x9f5c0118,0x00000000}},	//   _dwas, _иалҵ, latý_, --, 
   {{0xfbd001d3,0x62840037,0x5fc400bc,0x00000000}},	//   لتِ_, ökog, _रुपल, --, 
   {{0x7d0cb8ab,0x9f5c02fb,0x3af408fb,0x00000000}},	//   _fwas, natý_, _dåp_, --, 
   {{0x7d0c0f7b,0x3dc8016b,0x59b005f5,0x22980171}},	// [eea0] _gwas, _gyaw_, гөрс, cūku_, 
   {{0x6d54b8ac,0x9f5c02fb,0x7d080356,0xcb840117}},	//   _isya, hatý_, ţesc, _авоқ, 
   {{0x7d0c06d6,0xdc980115,0x9f5c01ef,0x00000000}},	//   _zwas, _זייל, katý_, --, 
   {{0x83fc0114,0x9f5c02fb,0x00000000,0x00000000}},	//   _inđi, jatý_, --, --, 
   {{0xa3e00882,0x3dc80070,0x00000000,0x00000000}},	//   नेन_, _xyaw_, --, --, 
   {{0x6d540280,0x1dd000c5,0x9d180a7c,0x00000000}},	//   _msya, _सरसत, לונט, --, 
   {{0xe8bc0574,0x851c4c19,0xbebc00e2,0x00000000}},	//   ्तीच, _निकट_, rtīz, --, 
   {{0x09e400bd,0x66e44c7f,0x6d5404ce,0x3db400fe}},	//   _ফ্যা, _чоба, _osya, _ঘৰফল, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7d0c2dab,0xf3f0004d,0x5de401ec,0x00000000}},	//   _rwas, _hạn_, _ﺍﯞﻟﻴ, --, 
   {{0x6d54b8ad,0x645800b0,0x6384010b,0x9f5c02f0}},	//   _asya, _iati, _ягжа, batý_, 
   {{0x6458b8ae,0x4c948d51,0x7d0cb8af,0x78a40175}},	//   _hati, қисс, _pwas, zihv, 
   {{0x6458b8b0,0x83fc05be,0xa06834b7,0xf3f00051}},	//   _kati, _anđi, _нада_, _mạn_, 
   {{0x6458b8b1,0x91e02c0b,0xf1a82d8d,0xd00cb8b2}},	//   _jati, _соче, _تامه_, _هله_, 
   {{0x6458b8b3,0x6d54127b,0x2bd40073,0x9058b8b4}},	//   _mati, _esya, _धरणा, _זכות, 
   {{0x8aa4b8b5,0x6458b8b6,0x7af405b1,0xf3f00208}},	//   груд, _lati, rqzt, _nạn_, 
   {{0xc0e836bc,0x7d0cb8b7,0xc98455c3,0x7ebc01ed}},	// [eeb0] _መለስ_, _uwas, луфи, képz, 
   {{0x6458b8b8,0x9f5c02b5,0x7e6c01a8,0x6f0c033f}},	//   _nati, katü_, _hnap, _łaci, 
   {{0xf3f0001e,0x9f5c0789,0x32f400b8,0x00000000}},	//   _bạn_, mató_, _rāyo_, --, 
   {{0x6458b8b9,0x9f5cb8ba,0x00000000,0x00000000}},	//   _aati, lató_, --, --, 
   {{0xdfc415fa,0x7e6cb8bb,0x78a4023a,0x29e4037e}},	//   _چي_, _mnap, pihv, のapi_, 
   {{0xdfc4b8bc,0x85b8a675,0x634800ac,0x6b540135}},	//   _ني_, رانس_, _mənf, bżgħ, 
   {{0x7e6cb8bd,0x6458b8be,0x32f40055,0x9f5c0241}},	//   _onap, _dati, _vāyo_, _èrèe_, 
   {{0x6458b8bf,0x9f5c00dd,0x7e6cb8c0,0xcb1408a8}},	//   _eati, ható_, _nnap, אלק_, 
   {{0x9f5c40f7,0xa3e0000d,0x75d4007b,0x00000000}},	//   kató_, नेब_, _شيئا, --, 
   {{0x6458b8c1,0x7e6cb8c2,0xd378b8c3,0x6d540438}},	//   _gati, _anap, _нче_, _rsya, 
   {{0xb4cc2ecf,0x93247138,0xe478010f,0x00000000}},	//   रती_, _سران, _קרעכ, --, 
   {{0x6458b8c4,0x12bc040d,0x7e6cb8c5,0xc8800356}},	//   _zati, ﺭﻟﻪﺭ, _cnap, ăşit_, 
   {{0x64581269,0x26c80134,0x62840254,0x85740354}},	//   _yati, _ɔbo_, ökoe, _улăх, 
   {{0x6458a860,0x9f5c01ed,0x3a2c00ef,0x00000000}},	//   _xati, gató_, _ķepa_, --, 
   {{0xaac4b8c6,0x8e640075,0x00000000,0x00000000}},	//   نترن, _бейҗ, --, --, 
   {{0xccf40134,0x6e4407dd,0x6d540055,0x490400db}},	//   _asɛe_, _реиз, _tsya, лүмг, 
   {{0x3eb8b8c7,0x6d540784,0x9f5c3d5a,0xfbd000f1}},	// [eec0] érte_, _usya, bató_, لتې_, 
   {{0x7c841614,0xf9902586,0xe8bc0073,0xa848007b}},	//   _буџе, حبِ_, ्तेच, ظلام_, 
   {{0x6458b8c8,0xccf4013f,0x6d580421,0x66e401af}},	//   _rati, _prɛw_, ātau, вожа, 
   {{0x9bb40302,0x6458b8c9,0x634806be,0xf3f00051}},	//   _יהיה_, _sati, _həng, _bạo_, 
   {{0x6458b8ca,0x955049c2,0x634803b9,0xe69400c7}},	//   _pati, لخوا, _kəng, ниҧы, 
   {{0x64580bf1,0xd464b8cb,0x59b0013d,0xf3f00051}},	//   _qati, киче_, _төсс, _dạo_, 
   {{0x6458b8cc,0x98a0b8cd,0xd4640640,0x47e00011}},	//   _vati, _тире, тије_, _প্রী, 
   {{0x6458b8ce,0x63480213,0xe65400de,0x216400d4}},	//   _wati, _ləng, _rūķī, втог, 
   {{0x6458b8cf,0xf3f00051,0x00000000,0x00000000}},	//   _tati, _gạo_, --, --, 
   {{0x40940f1b,0x64580393,0xe6540171,0x00000000}},	//   الدر, _uati, _pūķī, --, 
   {{0xd24c00f3,0x673c0064,0x00000000,0x00000000}},	//   _кц_, ntpj, --, --, 
   {{0x290000f3,0x926400ee,0x00000000,0x00000000}},	//   _otka_, _арша_, --, --, 
   {{0x9f5c00dd,0x7e6c09a8,0xe1900116,0x0dc801d5}},	//   tató_, _vnap, _әлһө, вури_, 
   {{0x634803e3,0x10a00166,0xd00c00cf,0x65600051}},	//   _cəng, _кичн, _ۇلۇ_, ivoh, 
   {{0x9f5c00f7,0x2f84013d,0xabb40166,0x30d800df}},	//   rató_, _бәян_, гарә, _אַקע, 
   {{0xd5f801f2,0x77600005,0x9f5c0407,0x00000000}},	//   _mmụ, _álxi, sató_, --, 
   {{0x2244034c,0x9f5c0407,0x634803e3,0xe90401c6}},	// [eed0] _mbok_, pató_, _hənd, гцхү, 
   {{0x634803be,0x656002c4,0x19543419,0x80d8000d}},	//   _kənd, dvoh, нағы_, _नीमे, 
   {{0x22440034,0x66c80022,0xc7c40305,0x00000000}},	//   _obok_, hýku, асци, --, 
   {{0x634800ac,0xbebc005f,0x66c800e4,0x00000000}},	//   _zəng, drīk, kýku, --, 
   {{0x634806be,0x06080024,0x0e9c0115,0xbebc00ef}},	//   _lənd, тнік_, ושאל, erīk, 
   {{0xb4cc04fa,0x22440086,0x85b800c6,0x58846bb9}},	//   रते_, _abok_, خامس_, _рыма, 
   {{0xf2a401d5,0x555000e5,0x00000000,0x00000000}},	//   ликп, _چھتر, --, --, 
   {{0xf3f0004d,0x76640c4f,0xd6d800d8,0x00000000}},	//   _tạo_, _حُرم, _цтг_, --, 
   {{0xe28cb8d0,0x63b80c8c,0x83fc009b,0x44f46be2}},	//   _ға_, _extn, _anđu, _впус, 
   {{0x22440428,0x634800ac,0xed580022,0x00000000}},	//   _ebok_, _bənd, ҭон_, --, 
   {{0x634803be,0x2ee4004e,0x00000000,0x00000000}},	//   _rəng, лжог, --, --, 
   {{0xed34b8d1,0xe28cb8d2,0x63480213,0x02a4119e}},	//   лэгэ, _ѓа_, _səng, _крчм, 
   {{0x25e40034,0x5d64b8d3,0xe0cc00f5,0xaddc012d}},	//   जेपी_, гиям_, _гв_, नेंऔ, 
   {{0xc174b8d4,0x6cd40597,0x25d4008f,0x634803b9}},	//   _خدمت, اقسا, טורן_, _fənd, 
   {{0xeb98b8d5,0x3af401b9,0xd12c0451,0x9b540107}},	//   хив_, иятс, _امڙ_, лиёт_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x634806be,0x684496f0,0x00000000,0x00000000}},	// [eee0] _təng, лнаа, --, --, 
   {{0x27940046,0xb4ccb8d6,0x7824b8d7,0x00000000}},	//   лшер, रतो_, لعمل, --, 
   {{0x66cc022e,0xd9400131,0x634803b9,0x183400e5}},	//   _bеkо, _қери, _xənd, آمد_, 
   {{0x2b58004e,0x65a401d5,0x672000e2,0xa2740092}},	//   _ispc_, _rаhb, ņojo, ያችንን_, 
   {{0x81a800bd,0x95c4b8d8,0x2900013d,0x00000000}},	//   _খুন_, луша_, _utka_, --, 
   {{0x6560b8d9,0xa8740212,0x02dc00dc,0x95b4035b}},	//   rvoh, _сумщ, मग्न, ырхә, 
   {{0x4394b8da,0x86b402dd,0x65600108,0xa344022e}},	//   райс, _кәді, svoh, уэлл, 
   {{0x363402dd,0x634806be,0x66c80124,0x00000000}},	//   _ەرەس, _rənd, týku, --, 
   {{0xc61011b1,0x68ec0198,0x634800ac,0xe164007b}},	//   ारीय_, _kibd, _sənd, ادبي, 
   {{0x68eca307,0x63b8010a,0x143c0b82,0x66c8b8db}},	//   _jibd, _txtn, ነበርኩ, rýku, 
   {{0x68ec0135,0xc0e80023,0x634803e3,0xfd4801e1}},	//   _mibd, _መገሻ_, _qənd, bimọ, 
   {{0x68ecb8dc,0x634806be,0x7180035b,0x00000000}},	//   _libd, _vənd, сқәе, --, 
   {{0xb5fcb8dd,0xa6c8022e,0x00000000,0x00000000}},	//   _inšt, ntаq, --, --, 
   {{0xbebc005f,0x68ec0135,0x2ca801a9,0x634803b9}},	//   ksīg, _nibd, gibd_, _tənd, 
   {{0x7f58b8de,0xdde801b9,0x634803b9,0x9f4801e1}},	//   _райс_, برگه_, _hənb, _àjàs_, 
   {{0x2b58004e,0x8c4400ac,0x00000000,0x00000000}},	//   _dspc_, əşmi, --, --, 
   {{0x4e3400cf,0x4fe4151e,0x98f41291,0xb8140114}},	// [eef0] _اعىز, _имән_, اثرا, идај, 
   {{0x634803be,0xb6bc0432,0x180c00cd,0x00000000}},	//   _mənb, _ýüzý, िरेव_, --, 
   {{0x68ec113c,0x50180302,0x3a38067c,0x35f40816}},	//   _dibd, גובו, _tcsp_, апер, 
   {{0xb4cc146b,0x070816ac,0xb5fc00a2,0xd5840133}},	//   रत्_, ايني_, _mašg, هێزه_, 
   {{0xd90cb8df,0xa3e00bc0,0x2c0801f9,0x00000000}},	//   _ریا_, नेस_, वरचं_, --, 
   {{0x68ec81f1,0xd4989095,0xf3f00208,0x00000000}},	//   _gibd, эре_, _tạm_, --, 
   {{0xe8d40302,0x32f40055,0x72940395,0xc4181063}},	//   _כושר_, _kāyi_, иших, اغها_, 
   {{0x3124006c,0x28f001ec,0x23b00131,0x00000000}},	//   адиг, _اۋەس, تمىس, --, 
   {{0x81a82f8b,0x7648b8e0,0x45d451e8,0x68ec01d5}},	//   _খুব_, _ibey, _готс, _yibd, 
   {{0xa3e0813f,0x7c240066,0xb5fc0432,0x68ec0175}},	//   नेह_, _ndhr, _bašg, _xibd, 
   {{0x3254b8e1,0x00000000,0x00000000,0x00000000}},	//   _ввер, --, --, --, 
   {{0x7c24987a,0x12e40220,0x83a80114,0x00000000}},	//   _adhr, _сізг, _стуб_, --, 
   {{0x76480451,0x60c80270,0x320cb8e2,0xd1e00150}},	//   _mbey, _fkfm, mbey_, _ايشۋ, 
   {{0xab28b8e3,0x8f6401ed,0x320c0363,0xa3e000dc}},	//   кога_, _ملتے_, lbey_, नेव_, 
   {{0x2ca8b8e4,0x7648b8e5,0xb9e40131,0x6a84b8e6}},	//   ribd_, _obey, ەسلى, алва, 
   {{0x692400a8,0x320c2f88,0x66c800d0,0x25e41414}},	//   имба, nbey_, hýkr, जेडी_, 
   {{0x78200490,0x320c0067,0x00000000,0x00000000}},	// [ef00] मणूक_, ibey_, --, --, 
   {{0x7648b8e7,0x68ecb8e8,0x00000000,0x00000000}},	//   _abey, _qibd, --, --, 
   {{0x634800ac,0xeab81058,0x320c0205,0xe738011c}},	//   _mənc, _айн_, kbey_, тее_, 
   {{0x83fc01a6,0xe6440212,0x68ecb8e9,0xa5081920}},	//   _mađe, редп, _wibd, веда_, 
   {{0x68ec038f,0x83fc00f3,0x09e4015b,0x320c0067}},	//   _tibd, _lađe, _ফ্রা, dbey_, 
   {{0x76480944,0x320c00ad,0x648403b2,0xbb4c02dd}},	//   _ebey, ebey_, _rðis, _ﺍﻵﻥ_, 
   {{0x83fc2d2b,0x69c805d1,0xb5fc00a2,0x403401e0}},	//   _nađe, şfed, _bašd, ҙенс, 
   {{0x6ab4013f,0x76480248,0x320c0076,0xc2741f5a}},	//   nnyf, _gbey, gbey_, слиј, 
   {{0xb3a40184,0xe458a90c,0x634803b9,0xe084007b}},	//   иләһ, _ижа_, _qənb, لجدي, 
   {{0x320c526b,0x634806be,0xdef8b8ea,0x40340063}},	//   abey_, _cənc, кым_, љенс, 
   {{0x320c1368,0xa3e06956,0x7e7c05b1,0xc5b80154}},	//   bbey_, नेश_, tjsp, _জরিপ, 
   {{0x6144b8eb,0x9f5c00b0,0x63480213,0x00000000}},	//   _веда, katö_, _tənb, --, 
   {{0xa3e02cce,0x7e7c0784,0xa03400db,0x00000000}},	//   नेर_, rjsp, _نىشت, --, 
   {{0x63480cc1,0x00000000,0x00000000,0x00000000}},	//   _gənc, --, --, --, 
   {{0x83fc0fcf,0x09e40eac,0x46b8012c,0xb5fc0118}},	//   _gađe, _ফ্লা, ेकाह, _haše, 
   {{0xb5fcb8ec,0x634800ac,0x1ea8211f,0x79580108}},	//   _kaše, _zənc, _جاتي_, либр_, 
   {{0x3ea8b8ed,0x76480076,0xb5fc5049,0xdde018c7}},	// [ef10] _imat_, _rbey, _jaše, _фәнү, 
   {{0x8934b8ee,0x3ea80156,0xb5fc6b92,0xdcc8a5f4}},	//   تعفا, _hmat_, _maše, _جذبه_, 
   {{0x66c80030,0xb5fc0153,0x00000000,0x00000000}},	//   výkr, _laše, --, --, 
   {{0x320c0009,0x8f98011a,0xdac40116,0x366800d8}},	//   xbey_, כיבי, _ئېرى_, ѓало_, 
   {{0xbebc00da,0x3ea80194,0xd7f8004e,0xf3f00208}},	//   brīv, _mmat_, _ауб_, _hại_, 
   {{0xbebc00da,0x4a24025c,0x3954b8ef,0x798c0337}},	//   nsīb, _འཇོལ_, ğası_, myaw, 
   {{0x3ea8b8f0,0xd76004fb,0x3954b8f1,0x798cb8f2}},	//   _omat_, _بنزی, şası_, lyaw, 
   {{0x83fc1591,0xb5fc8c2c,0x7648b8f3,0x0bb80375}},	//   _rađe, _baše, _ubey, ילום_, 
   {{0x83fc16a3,0x320c4700,0xf3f0001e,0x634800ac}},	//   _sađe, rbey_, _lại_, _pənc, 
   {{0x3ea8b8f4,0x92b40729,0xf1b808ad,0x83fc01a6}},	//   _amat_, ছতে_, jaše_, _pađe, 
   {{0xd3a4b8f5,0xaec4b8f6,0xf1b80e3c,0x798c0066}},	//   _трап, йбол, daše_, hyaw, 
   {{0xeb981621,0xbebc00da,0x83fc05ce,0xb5fc0010}},	//   қиб_, esīb, _vađe, _faše, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3ea8b8f7,0xf1b80558,0x798cb8f8,0x3f8c01ef}},	//   _emat_, gaše_, dyaw, bydu_, 
   {{0x634803be,0xdca0b8f9,0x798c04ba,0xf3f00051}},	//   _kəna, чари, eyaw, _bại_, 
   {{0xed58b8fa,0xee38aa08,0x3ea8045a,0xd1c80b82}},	//   _бои_, _сни_, _gmat_, _ኣመት_, 
   {{0xe9d82082,0x634803be,0x798c0337,0xf1b80841}},	// [ef20] ука_, _məna, gyaw, baše_, 
   {{0xc61012eb,0x00000000,0x00000000,0x00000000}},	//   ार्य_, --, --, --, 
   {{0x798c04ba,0x32f400b8,0x00000000,0x00000000}},	//   ayaw, _kāyu_, --, --, 
   {{0x798c97a0,0xd680004e,0x00000000,0x00000000}},	//   byaw, зушп, --, --, 
   {{0x798c00ca,0x00000000,0x00000000,0x00000000}},	//   cyaw, --, --, --, 
   {{0xb5fc0306,0x92b403d4,0x870801d3,0x00000000}},	//   _raše, ছতো_, _نعرہ_, --, 
   {{0xa3e002a0,0x634803b9,0xb5fc00c0,0x62840037}},	//   नें_, _bəna, _saše, ökoo, 
   {{0x634800ac,0xb5fca7ab,0xdef801e0,0x4ac8276a}},	//   _cəna, _paše, ҫын_, लविव, 
   {{0xb5fcb515,0x6600003c,0xa18489d0,0x2120003e}},	//   _inšp, mcok, сыйл, ékh_, 
   {{0x3ea8b8fb,0x33280227,0x3f8c012d,0x649801a9}},	//   _smat_, ņaxa_, tydu_, _ётар_, 
   {{0xf1b80fcf,0xbebc0f40,0x798c0399,0x9878010f}},	//   vaše_, krīt, zyaw, אריק, 
   {{0x6600b8fc,0x05dc22e3,0x798c0b45,0xdb200098}},	//   ncok, _बराब, yyaw, _érén, 
   {{0xf1b805ce,0xdce80030,0x50b4179e,0xbebc00de}},	//   taše_, žičo, شدید_, drīt, 
   {{0x798c019f,0x7f94074d,0x32f400b8,0x00000000}},	//   vyaw, _малх, _vāyv_, --, 
   {{0xf41c0c58,0x660006d1,0xf1b80153,0x634806be}},	//   _নামৰ_, kcok, raše_, _yəna, 
   {{0x3ea841d0,0x7d780d28,0x201800c5,0x798cb8fd}},	//   _umat_, _نمبر_, _õpib_, tyaw, 
   {{0x4e940150,0xec6802dd,0x8e380132,0x798c0099}},	// [ef30] _ءشىر, _ءﯗﺵ_, _اسىر_, uyaw, 
   {{0x798cb8fe,0x624c06d6,0x7b180276,0x6900012d}},	//   ryaw, _ṱoli, _коор_, _żydó, 
   {{0x798cb8ff,0xf3f001fb,0x201cb900,0x1768b901}},	//   syaw, _tại_, iati_, ырап_, 
   {{0x201cb902,0x3eb8b903,0x66002959,0x798c0007}},	//   hati_, nnst_, gcok, pyaw, 
   {{0x2a3804ac,0x3eb8b904,0x00000000,0x00000000}},	//   _דערמ, inst_, --, --, 
   {{0x6734022c,0x634800ac,0x3eb80112,0x00000000}},	//   ðgjø, _səna, hnst_, --, 
   {{0xd6d8964b,0x63480213,0xefd00023,0x844400d1}},	//   _бта_, _pəna, _ከመዮ_, سخول, 
   {{0x634800ac,0x3eb801f5,0xf1d00137,0x87040139}},	//   _qəna, jnst_, мөлө, _хяре, 
   {{0x201cb905,0x80b4009e,0x668001d5,0x44d000b8}},	//   fati_, ুতন্, _تینل, _ṛtūn_, 
   {{0x201cb906,0x3eb8b907,0xefd0069c,0x2ed00a28}},	//   gati_, enst_, _ከመይ_, सत्त, 
   {{0x32f40055,0x634806be,0x00000000,0x00000000}},	//   _pāyu_, _təna, --, --, 
   {{0x3eb802d2,0x00000000,0x00000000,0x00000000}},	//   gnst_, --, --, --, 
   {{0xb5fc0010,0x32f4002b,0x00000000,0x00000000}},	//   _zašc, _vāyu_, --, --, 
   {{0x2b1407dd,0x672000e2,0xeff00023,0x634803b9}},	//   жьар, ņoji, _ሃጸይ_, _mənn, 
   {{0x6e44011c,0x00000000,0x00000000,0x00000000}},	//   _дейз, --, --, --, 
   {{0x83fc0bb8,0x80e00729,0x00000000,0x00000000}},	//   _mađa, নদণ্, --, --, 
   {{0xd940b908,0xa924b909,0x83fc1710,0x66000010}},	// [ef40] мети, юдал, _lađa, vcok, 
   {{0xaba80b87,0x2b38084c,0x6d44002f,0x00000000}},	//   _ввоз_, _кямэ_, mtka, --, 
   {{0x3cec01f5,0x00000000,0x00000000,0x00000000}},	//   ïeve_, --, --, --, 
   {{0x66741169,0x6d440b4f,0x634806be,0x00000000}},	//   غدار, otka, _bənn, --, 
   {{0x201cb90a,0x3934b90b,0x634800ac,0xe57000ec}},	//   yati_, _нэрс, _cənn, بطا_, 
   {{0x201cb90c,0x6d44b90d,0x6c7800c8,0xb5fc0171}},	//   xati_, itka, שאַפ, _pašc, 
   {{0xccf40605,0x6d44b90e,0x3eb80252,0xd6cc00f7}},	//   _nsɛm_, htka, ynst_, رقۇ_, 
   {{0x201cb90f,0x63480213,0x00000000,0x00000000}},	//   wati_, _fənn, --, --, 
   {{0xccf40605,0x6d44b910,0xb4e80014,0xb6180150}},	//   _asɛm_, jtka, جى۪م_, _ﹼﺨ_, 
   {{0x201c1140,0xa088453d,0xe05401d5,0x6d44b911}},	//   uati_, рсиз_, زیبت_, dtka, 
   {{0x83fc0552,0x1ea8a864,0x57f80375,0x6d4400d7}},	//   _gađa, لاحي_, יליו, etka, 
   {{0x6448b912,0x3eb8045f,0xf2c402dd,0x00000000}},	//   lffi, unst_, _есін, --, 
   {{0x201cb913,0x6448b914,0xb5fc08ad,0x3eb8b915}},	//   pati_, offi, _jaša, rnst_, 
   {{0x201cb916,0x443cb917,0xb5fc3673,0x6448b918}},	//   qati_, ngv_, _maša, nffi, 
   {{0x6d4415a5,0xf1b80fcf,0x64480eda,0xb5fc0153}},	//   atka, maša_, iffi, _laša, 
   {{0x386cb919,0x5398011a,0x00000000,0x00000000}},	//   _şer_, בילו, --, --, 
   {{0xb5fc2d2b,0xf3f00208,0x00000000,0x00000000}},	// [ef50] _naša, _hạt_, --, --, 
   {{0xf1b80f03,0xdb140548,0x644801f5,0xd80801c6}},	//   naša_, _exxá, jffi, рхал_, 
   {{0x2bd00490,0x64480042,0x634806be,0x572000db}},	//   _दुपा, dffi, _sənn, بۉزك, 
   {{0x83fc05ce,0xb5fc110c,0x65a401a9,0xf52001ec}},	//   _rađa, _baša, _tаhl, ендi_, 
   {{0x26081533,0x634803b9,0xf8480117,0x00000000}},	//   ाड़ी_, _qənn, _гӯед_, --, 
   {{0xf1b8041a,0xb5fcb91a,0x00000000,0x00000000}},	//   jaša_, _daša, --, --, 
   {{0xf1b801a6,0x00000000,0x00000000,0x00000000}},	//   daša_, --, --, --, 
   {{0x6448b91b,0x6d4400fd,0x00000000,0x00000000}},	//   affi, ytka, --, --, 
   {{0xb6a40209,0x6d44007c,0x00000000,0x00000000}},	//   _диңл, xtka, --, --, 
   {{0xf1b80960,0x76580368,0x61400131,0x50a00116}},	//   gaša_, lewy, رىپە, بەتل, 
   {{0xb3741e38,0x04c800aa,0xb5fc01a6,0x66800345}},	//   ካውያን_, _بولي_, _zaša, _تیۆل, 
   {{0xed58b91c,0x6d441072,0x76580368,0x634803e3}},	//   бом_, ttka, newy, _mənl, 
   {{0xf1b80e3c,0x6d44b91d,0x2bf800cd,0x00000000}},	//   baša_, utka, ्डलं_, --, 
   {{0xb3280135,0xace801d5,0x13ac0154,0x2d9c0210}},	//   _ལྷོང_, смга_, _চুয়, ąte_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7fe80f84,0xdb0c00e5,0xdee00395,0x6d4422d9}},	//   _ظروف_, ójár, _пощи, ptka, 
   {{0x76584011,0xdeb40302,0x64480142,0xc0ec0023}},	// [ef60] dewy, _מפקח_, yffi, ቀምሉ_, 
   {{0xb5fc2ba4,0x321c012d,0xf8a801e2,0xebe4014b}},	//   _raša, _lewy_, يدله_, _нопп, 
   {{0x2f001bce,0x6284023a,0x9bf8011a,0xb5fc00de}},	//   _jóg_, ökok, _להיט, _saša, 
   {{0xb5fc5914,0x765805e4,0x321c0175,0x7b040030}},	//   _paša, gewy, _newy_, žuté, 
   {{0x2f000579,0x443c0129,0x00000000,0x00000000}},	//   _lóg_, tgv_, --, --, 
   {{0x6448b91e,0xb5fc248d,0xa888b91f,0x634803e3}},	//   uffi, _vaša, _уйга_, _fənl, 
   {{0x2f0005a4,0x64480368,0xb5fc0113,0x76580ea0}},	//   _nóg_, rffi, _waša, bewy, 
   {{0x85e40046,0xd254084c,0x734800d4,0x00000000}},	//   _قۋان, пць_, ючів_, --, 
   {{0x321c0204,0x65a401b9,0xc3300050,0x05b80133}},	//   _dewy_, _mаhk, رٕک_, _بگات_, 
   {{0x2bd00d01,0x67200029,0x2f00033f,0x224c0055}},	//   _दुभा, ņoju, _bóg_, _śokā_, 
   {{0xe314b920,0x442cb921,0x0f2036a6,0xb5fc2a53}},	//   _رباب, _idd_, ньям, _mašn, 
   {{0x321c0ea0,0x442c5e74,0x00000000,0x00000000}},	//   _gewy_, _hdd_, --, --, 
   {{0x442c0789,0xd12c007b,0x2bd023ef,0x634806be}},	//   _kdd_, _ممن_, _दुबा, _mənm, 
   {{0xe7bc41ac,0xbf14023f,0x442c5efc,0x7658012d}},	//   ्थाप, _قوتب, _jdd_, zewy, 
   {{0x442c23db,0x5ad835b6,0xcfd000f3,0x00000000}},	//   _mdd_, مبرج_, _пошћ, --, 
   {{0x628405a7,0x442c9017,0xf8b00214,0xca240116}},	//   ökoh, _ldd_, چکس_, еффи, 
   {{0x99d424e0,0x9cc80598,0xf8b0424b,0x83fc05a1}},	// [ef70] سترا, _гына_, نکس_, _nađo, 
   {{0x7d0cb922,0xd7f807dd,0x3a2c0171,0x00000000}},	//   _itas, суа_, _ķepu_, --, 
   {{0xd5b80598,0xb5fc01fa,0xb8d41d34,0x76580af9}},	//   әсе_, _dašn, _जग_, tewy, 
   {{0x442c025f,0x35b4b923,0x7bc40921,0x00000000}},	//   _add_, мбер, _ixhu, --, 
   {{0x442c4663,0xb5fc107d,0x7658013f,0x00000000}},	//   _bdd_, _fašn, rewy, --, 
   {{0xb3280003,0x3948b924,0x442cb925,0x7d0cb926}},	//   _ལྷུང_, mtas_, _cdd_, _mtas, 
   {{0x7d0c1529,0x76580477,0x00000000,0x00000000}},	//   _ltas, pewy, --, --, 
   {{0x442cb927,0x394802d5,0x7d0cb928,0xb9300092}},	//   _edd_, otas_, _otas, _እርስዎ, 
   {{0x442c5975,0x7d0cb929,0xa1540063,0x00000000}},	//   _fdd_, _ntas, дању_, --, 
   {{0x7bc40b6f,0x7528b92a,0x11f4004b,0x2f00007b}},	//   _oxhu, _ivez, _ځواک_, _póg_, 
   {{0x7d0cb92b,0x3948b92c,0x75280306,0x00000000}},	//   _atas, htas_, _hvez, --, 
   {{0x3948b92d,0x20180037,0x00000000,0x00000000}},	//   ktas_, _õpin_, --, --, 
   {{0x3948b92e,0x7bc4379d,0xe0cc074d,0xa16000c7}},	//   jtas_, _axhu, _ав_, _аҭыҵ, 
   {{0x442cb92f,0x7528b930,0x3948b931,0x2f00007b}},	//   _xdd_, _mvez, dtas_, _tóg_, 
   {{0x38ac11a9,0x316cb932,0x7d0cb933,0xb5fc8b8c}},	//   _görə_, lvez_, _etas, _našo, 
   {{0xd1d00201,0xa3e023ef,0x752801f0,0x3948b934}},	//   _ያሉት_, नेट_, _ovez, ftas_, 
   {{0x3948b935,0x316c03bd,0xb5fcb936,0x2ec800dc}},	// [ef80] gtas_, nvez_, _pašn, रवीत, 
   {{0xb5fc1ebd,0x6d540588,0x316c004a,0x634806be}},	//   _bašo, _ipya, ivez_, _sənm, 
   {{0x7528b937,0xca9402d3,0x442c01a6,0xf40403d4}},	//   _avez, _ዘለኹም_, _rdd_, ৰণাৰ_, 
   {{0x7d0c0158,0x394800c0,0x00000000,0x00000000}},	//   _ytas, btas_, --, --, 
   {{0x64a42b42,0x3948b938,0xb5fc8bbb,0x7d0cb939}},	//   мада, ctas_, _tašn, _xtas, 
   {{0x69c40327,0x6d54009f,0x2910b93a,0xfb24158f}},	//   _ixke, _mpya, mpya_, _تریپ, 
   {{0x7528b93b,0x316c0327,0x00000000,0x00000000}},	//   _evez, evez_, --, --, 
   {{0x2240b93c,0xa68402d5,0x6d5406be,0xd9bc00cc}},	//   ükk_, _ўлад, _opya, _আৰিম, 
   {{0x442c0100,0xb5fc13d5,0xa44486e5,0xe504009f}},	//   _tdd_, _mašl, _онад, _آبري, 
   {{0x7d0c006c,0x3f14b93d,0x69c40332,0x00000000}},	//   _rtas, ндос, _mxke, --, 
   {{0x7528b93e,0x7e98b93f,0x7d0cb940,0x3f981ab0}},	//   _zvez, كندر_, _stas, áru_, 
   {{0xe7e4006d,0x394802d5,0xb3280003,0x634803be}},	//   _करना_, ytas_, _ལྷིང_, _lənk, 
   {{0xa0680f14,0xd41400c7,0x25a4b941,0xe1e00b02}},	//   _мада_, _хьӡы, nzol_, _परिघ, 
   {{0xbef40118,0x00000000,0x00000000,0x00000000}},	//   _říča, --, --, --, 
   {{0x6d54b942,0xa3e00490,0xb5fcb943,0xdfa4007b}},	//   _epya, नेच_, _bašl, _تحشي, 
   {{0x3948b944,0x2ec81b61,0x7d0c0109,0xb5fc386f}},	//   ttas_, रवृत, _ttas, _rašo, 
   {{0x7d0cb945,0x3d94af2a,0xb5fc00f3,0x69c000cf}},	// [ef90] _utas, _чипр, _sašo, гөрб, 
   {{0x7bc40b89,0x61e0014b,0x63b40209,0xb5fc139f}},	//   _txhu, _mzol, şyny, _pašo, 
   {{0xe7e8069f,0x870400d6,0x7bc4401f,0xb7c40588}},	//   झेला_, вяче, _uxhu, храқ, 
   {{0x3948b946,0x8d743ce1,0xb5fcb947,0xa3e00316}},	//   ptas_, _ساۋا, _vašo, नेछ_, 
   {{0x7aecb948,0xd90c2c6c,0x39480784,0x6e380208}},	//   mmat, _ضیا_, qtas_, đtbx, 
   {{0xb5fcb949,0xb4c8033f,0x00000000,0x00000000}},	//   _zašl, ईवे_, --, --, 
   {{0x61e0b94a,0xf1b80010,0x25a400d7,0xa6c8022e}},	//   _azol, tašo_, azol_, ytаx, 
   {{0x634806be,0x4374b94b,0x00000000,0x00000000}},	//   _mənh, тушт, --, --, 
   {{0x7528b94c,0x316c0231,0xf1b80006,0x7aec2447}},	//   _uvez, uvez_, rašo_, imat, 
   {{0x316c03bd,0x61e002c4,0x1474b94d,0x3cf809bb}},	//   rvez_, _dzol, _تارج, ंदों_, 
   {{0x7aecb94e,0xc0a8415d,0x61e01cdf,0x316c0165}},	//   kmat, بايل_, _ezol, svez_, 
   {{0x4394b94f,0x7aecb950,0xed586baf,0x6da40124}},	//   _шахс, jmat, пом_, еима, 
   {{0x7aecb951,0xb5fc0960,0x90c401b9,0x8b08013a}},	//   dmat, _našm, _оғиз_, _ohřá, 
   {{0x7aec09ad,0x6140136b,0x00000000,0x00000000}},	//   emat, _сеша, --, --, 
   {{0xb5fc005f,0x25a405b1,0xfc044990,0x00000000}},	//   _pašl, zzol_, тосү, --, 
   {{0xa80400c7,0x634806be,0xe7e4000d,0x00000000}},	//   kañý, _sənk, _करबा_, --, 
   {{0x6e24b952,0x6d5403f0,0xa3b40f90,0xe8183769}},	// [efa0] makb, _upya, _चेन_, كزات_, 
   {{0x7aecb953,0x6e24b954,0xab643334,0x18640220}},	//   amat, lakb, _звол, науи_, 
   {{0xb5fc01fa,0x7aec5a7a,0x2ab80139,0xdc3800df}},	//   _tašl, bmat, gübä_, _צעטר, 
   {{0x7aec0429,0x6e240f68,0xd7ec00c6,0x29101418}},	//   cmat, nakb, حكم_, ppya_, 
   {{0xfca800f1,0x9c100051,0x00000000,0x00000000}},	//   _رایو_, _họac, --, --, 
   {{0x2900b955,0x6e24b956,0x1cb8031c,0x281400be}},	//   _iuka_, hakb, མོར_, _سورس, 
   {{0x61e0066d,0x290004fe,0x25a401d3,0x634806be}},	//   _szol, _huka_, szol_, _kəni, 
   {{0x754801d3,0xc2741d39,0x00000000,0x00000000}},	//   öszö, тлиј, --, --, 
   {{0x63480cc1,0x29000022,0x6e2406d1,0x673c03b2}},	//   _məni, _juka_, dakb, lupj, 
   {{0x2900b957,0x7aec510d,0x6560b958,0xdfa416a4}},	//   _muka_, zmat, mwoh, ејмо, 
   {{0x7aecb959,0x518001e0,0xd4940375,0x6560002f}},	//   ymat, _ҡуша, _רכבת_, lwoh, 
   {{0x7aecb95a,0x29000f12,0x21a40798,0x5270009b}},	//   xmat, _ouka_, _пием, _буљу, 
   {{0x7aecb95b,0x6560b95c,0x2900b95d,0x61e00c60}},	//   vmat, nwoh, _nuka_, _uzol, 
   {{0xe0480502,0x7aecb95e,0x673c8ad5,0x2bd00b7d}},	//   _رشته_, wmat, kupj, _दुहा, 
   {{0x2900b95f,0x65600112,0xdeb002dd,0x634803b9}},	//   _auka_, hwoh, _бұны, _bəni, 
   {{0x656000ca,0xb5fc005f,0x8eb40116,0x00000000}},	//   kwoh, _pašm, _مەپت, --, 
   {{0x634803be,0x8ae401ec,0xe810000d,0x00000000}},	// [efb0] _dəni, уірл, _ढ्हा_, --, 
   {{0x2900b960,0x19541ac1,0x63480213,0x00000000}},	//   _duka_, мағы_, _tənh, --, 
   {{0x7aecb961,0x290000e4,0xe7e40073,0xaa400116}},	//   pmat, _euka_, _करणा_, _ھۆكى, 
   {{0x2900b962,0xb5fc009b,0x65a400b0,0x7aec03b9}},	//   _fuka_, _tašm, kōhī, qmat, 
   {{0x250801e2,0x00000000,0x00000000,0x00000000}},	//   وروی_, --, --, --, 
   {{0x39580048,0x6e2401ed,0xbebc00de,0xb5fc0064}},	//   _ipss_, zakb, usīj, _kašk, 
   {{0x64a009fe,0x2900b963,0xdec002d3,0xb5fc5a54}},	//   раща, _zuka_, ኹምን_, _jašk, 
   {{0xe7e40d35,0x2244020c,0xb5fcb964,0x395803ee}},	//   _करता_, _ccok_, _mašk, _kpss_, 
   {{0xb5fc09a8,0x9f5c0393,0x2900b965,0x6e244400}},	//   _lašk, nctæ_, _xuka_, vakb, 
   {{0xd3a41920,0x307418a4,0x00000000,0x00000000}},	//   _преп, туис, --, --, 
   {{0x6e24113c,0xb5fc05a1,0x3dc8011f,0x00000000}},	//   takb, _našk, _axaw_, --, 
   {{0x395805b1,0x6fb80116,0x628416ca,0xd36c00ec}},	//   _opss_, згүр_, ökot, _پهچ_, 
   {{0x39580114,0x6e24b966,0xccf80075,0xb820000d}},	//   _npss_, rakb, нқи_, यराम_, 
   {{0x2900b967,0x634803be,0x00000000,0x00000000}},	//   _ruka_, _səni, --, --, 
   {{0x290020af,0x6e24b968,0x62080793,0xfbd0489b}},	//   _suka_, pakb, _äplö, متِ_, 
   {{0x2900b969,0x634800ac,0xb5fc00a2,0xf3300092}},	//   _puka_, _qəni, _dašk, _አይተና, 
   {{0xe9d8b96a,0x2bd0a583,0x2900009a,0x2de8004b}},	// [efc0] фка_, _दुरा, _quka_, _ډوډۍ_, 
   {{0x2794b96b,0x2900b96c,0x98a000c7,0x7ae8031c}},	//   кшер, _vuka_, аиуе, ċeta, 
   {{0x290002a8,0xdc980375,0xd70000c7,0x634806be}},	//   _wuka_, _חייל, азхи, _təni, 
   {{0x2900b96d,0x6560b96e,0x673c0327,0x46840150}},	//   _tuka_, twoh, rupj, ықба, 
   {{0xb5fc02fb,0x95c4b96f,0x29000009,0x78a40175}},	//   _zašk, куша_, _uuka_, bhhv, 
   {{0x6560b970,0xec34010f,0x673c0477,0xc3300050}},	//   rwoh, דאַר_, pupj, مٕت_, 
   {{0x437400f2,0x65600112,0x00000000,0x00000000}},	//   اهبر, swoh, --, --, 
   {{0x779004d3,0x83fc08a4,0x66e4b971,0xaae00b98}},	//   _دیما, _mađi, _роба, पतिक, 
   {{0x2018000d,0xa184013d,0x00000000,0x00000000}},	//   _õpik_, тыйл, --, --, 
   {{0x544000f7,0x00000000,0x00000000,0x00000000}},	//   _ەنەك, --, --, --, 
   {{0x2b5807ab,0x2bd049f1,0x14180375,0x23d400c7}},	//   _nppc_, _दुला, _חובב, _рцар, 
   {{0xb5fc3421,0x83fc05a1,0x22440e4f,0x00000000}},	//   _rašk, _nađi, _ucok_, --, 
   {{0xa3b43517,0x25e40073,0xf3f42a9d,0x00000000}},	//   _चेत_, जेची_, _иңә_, --, 
   {{0xb5fcb972,0x91e00416,0xd19404ae,0x00000000}},	//   _pašk, _точе, _בכדי_, --, 
   {{0x99bc00bd,0x200c022f,0xcf8c026a,0x3eb805d5}},	//   _আরেক, _iffi_, _тј_, érts_, 
   {{0xa3c8007d,0x39580438,0xb5fcb973,0x2b580175}},	//   _लखन_, _ppss_, _vašk, _dppc_, 
   {{0x3eb8367a,0x672c022c,0x65a401a9,0x47b000cc}},	// [efd0] mist_, _avbj, _mаhs, _জুলী, 
   {{0x3eb8b974,0x7e6cb975,0xb5fcb976,0x2b580175}},	//   list_, _haap, _tašk, _fppc_, 
   {{0x7e6cb977,0xb5fc2625,0x9ba00131,0x07080592}},	//   _kaap, _haši, _ئەزى, نيلي_, 
   {{0xb5fc1050,0x7e6cb978,0xa3d40cb4,0xdfc40137}},	//   _kaši, _jaap, _सड़_, _ۇي_, 
   {{0xc984b979,0x7c24b97a,0x7afcb97b,0x200c0e14}},	//   _кури, _kehr, _iist, _offi_, 
   {{0xdfc4b97c,0x1b3407db,0xb5fc5968,0x3a28b97d}},	//   _هي_, _ኤርትራ, _maši, laap_, 
   {{0x7c24b97e,0x3eb8b97f,0xb5fc0024,0x38600112}},	//   _mehr, kist_, _laši, mehr_, 
   {{0x36d463e3,0x7e6cb980,0x7c24b981,0x7afcb982}},	//   _собр, _naap, _lehr, _jist, 
   {{0x7c24b983,0xc1d40588,0x764802d0,0x3eb83fe5}},	//   _oehr, аҩцә, _icey, dist_, 
   {{0xb5fcb984,0x7c24b985,0x3a2824d1,0x6284b986}},	//   _naši, _nehr, haap_, ökor, 
   {{0x7e6cb6da,0x7afcb987,0x3eb8b988,0xb3981b49}},	//   _baap, _oist, fist_, ላውያን_, 
   {{0x3eb8b989,0x634803be,0x7e6c00e4,0xb5fc00de}},	//   gist_, _cənu, _caap, _pašh, 
   {{0x307400fd,0x7e6c198f,0xb5fc2804,0x38600e78}},	//   _буйс, _daap, _baši, kehr_, 
   {{0x7afcb98a,0xf1b807f5,0xafe4b98b,0xa0641586}},	//   _aist, jaši_, _йолл, _баша_, 
   {{0x7e6c2f06,0x7c24003d,0x3eb85886,0xf1b801a6}},	//   _faap, _dehr, bist_, daši_, 
   {{0x3eb8b98c,0x3a28b98d,0x7e6c0036,0x6a84b98e}},	//   cist_, gaap_, _gaap, ылба, 
   {{0x7afcb98f,0x7c24b990,0xc82400c7,0xec78009b}},	// [efe0] _dist, _fehr, изақ, _зпп_, 
   {{0x7afc0cfd,0xf1b8248d,0xb5fc07f5,0x764803ac}},	//   _eist, gaši_, _gaši, _acey, 
   {{0x6ac4b991,0x7afcb992,0x7e6cb993,0x3a28002e}},	//   _مقدم, _fist, _yaap, baap_, 
   {{0x7afcb994,0x5f04b995,0x634803be,0xe9a40cb9}},	//   _gist, _संस्_, _mənt, _бамп, 
   {{0xe7e40c2e,0x3cfc00ac,0x38600ffb,0xf1b80841}},	//   _करवा_, _üzvü_, behr_, baši_, 
   {{0x7afcb996,0x7648011f,0x320c01c7,0x43943de2}},	//   _zist, _ecey, ecey_, иалс, 
   {{0x7afc0227,0x07d80edf,0xd04400ac,0x00000000}},	//   _yist, _شهرک_, _ölən, --, 
   {{0x3eb8b997,0x7afcb998,0xe208033f,0x00000000}},	//   xist_, _xist, _otóż_, --, 
   {{0xe57801d2,0x09c40eac,0x7e6cb999,0xdbdc0174}},	//   _яза_, ্ধকা, _raap, _líði, 
   {{0x7e6cb99a,0x3eb8952e,0x320c3424,0xbebc00e2}},	//   _saap, wist_, acey_, nsīv, 
   {{0xb5fcb99b,0x7e6cb99c,0x3a280d04,0x0dc8013e}},	//   _bašw, _paap, yaap_, ҳури_, 
   {{0x7c24b99d,0xb5fc04a7,0x320c8988,0xa6c801a9}},	//   _sehr, _saši, ccey_, qsаd, 
   {{0x7afcb99e,0x7e6cb99f,0x99bc00bd,0xb5fc262b}},	//   _rist, _vaap, _আর্ক, _paši, 
   {{0x7e6cb9a0,0x200cb9a1,0xdbdc06ea,0x3eb8b9a2}},	//   _waap, _uffi_, _bíði, sist_, 
   {{0x7e6cb9a3,0x9f4800fd,0x3a280869,0x7c24aa8d}},	//   _taap, äbä_, taap_, _vehr, 
   {{0x38600730,0x7c24b9a4,0x7afcb9a5,0x00000000}},	//   wehr_, _wehr, _qist, --, 
   {{0xf1b87dfd,0x3a28b9a6,0x7afc0d63,0x3ea40014}},	// [eff0] taši_, raap_, _vist, _مشکہ, 
   {{0x7afcb9a7,0x3a28013c,0x9c440212,0x00000000}},	//   _wist, saap_, _схил, --, 
   {{0x7afcb9a8,0x3a28079b,0x634800ac,0x09c400cc}},	//   _tist, paap_, _məns, ্ধগা, 
   {{0x7afcb9a9,0xd62402dd,0x3860002f,0x06f4007b}},	//   _uist, اعاي, sehr_, مسنج, 
   {{0xccf40134,0xb5fc96c0,0x060801ec,0x00000000}},	//   _mpɛn_, _lašv, унік_, --, 
   {{0x54348efb,0x5884b9aa,0xa3b407b6,0x64a000db}},	//   ارشر, _сыма, _चेह_, жаша, 
   {{0xdb1c0108,0x00000000,0x00000000,0x00000000}},	//   _äxäs, --, --, --, 
   {{0xd6c0b9ab,0xd6181046,0x320c058a,0x229000d1}},	//   _امری, _سترا_, ucey_, قلىس, 
   {{0x95c8b9ac,0x8e900023,0x634806be,0xc6a4030d}},	//   _чува_, ዝኽእሉ_, _sənt, _урри, 
   {{0xe1f40209,0x136401c8,0x9f500241,0x00000000}},	//   шгы_, _ٽائٽ, _ńyá_, --, 
   {{0xaec4b9ad,0xdb200066,0xafe4b9ae,0xd37800d4}},	//   ибол, _èrèn, ронл, _яча_, 
   {{0x9fa00321,0xdbdc0174,0xf41c00fe,0xa3c80037}},	//   ríða_, _ríði, _নাটৰ_, _लखत_, 
   {{0x9fa02833,0xc3300014,0xdbdc0d12,0x7f740022}},	//   síða_, _وٕے_, _síði, _ҳуыц, 
   {{0x61e4aa4a,0x659800c8,0x63480213,0xa1100133}},	//   ükle, דישק, _tənt, _بووت, 
   {{0x6ab460a9,0x60d40115,0x00000000,0x00000000}},	//   асах, _דוסא_, --, --, 
   {{0x6f0c0306,0xdbdc01a8,0x00000000,0x00000000}},	//   _čach, _víði, --, --, 
  
   {{0xb5fcb9af,0x2ca8023a,0x00000000,0x00000000}},	// [f000] _kašu, _акпп_, --, --, 
   {{0xdbdc5573,0xec7800db,0x00000000,0x00000000}},	//   _tíði, _рпо_, --, --, 
   {{0x6e340316,0xdc380375,0x18640138,0xbebc00de}},	//   _kdyb, _בעיר, рахи_, rsīv, 
   {{0xf1b80171,0xb5fc139f,0xf7e80116,0xbb8401c8}},	//   lašu_, _lašu, اركى_, _الٽي, 
   {{0xa8040a8f,0xaa840432,0x00000000,0x00000000}},	//   _взгл, _etýä, --, --, 
   {{0xe7185214,0x989400d1,0xf1b80024,0xb5fc0153}},	//   _ليست_, _кусә, našu_, _našu, 
   {{0x6e340c8c,0xa6c8022e,0x43943947,0x00000000}},	//   _odyb, frаt, сайс, --, 
   {{0x634800ac,0xe57800f3,0x9374011c,0x00000000}},	//   _səns, _изб_, рбът_, --, 
   {{0x13e47400,0xa508074d,0x20c400ee,0xa3b4000d}},	//   лмәй_, _реза_, исог, _चेर_, 
   {{0xb5fc0029,0xf1b8b0e8,0x6e342dc9,0x00000000}},	//   _pašv, jašu_, _adyb, --, 
   {{0x787800c8,0x2284b9b0,0x6458b9b1,0xa3c800af}},	//   אָרו, _вулг, _ibti, _लखि_, 
   {{0x26c4b9b2,0x00000000,0x00000000,0x00000000}},	//   nnoo_, --, --, --, 
   {{0x6280b9b3,0x26c40429,0x1cb847e7,0x2a7001f7}},	//   _inoo, inoo_, ناسب_, ddyb_, 
   {{0x628001d4,0x3a740588,0xf1b8009b,0x00000000}},	//   _hnoo, әлар, gašu_, --, 
   {{0x62801a93,0x6458005a,0xb5fc02f0,0x5018011a}},	//   _knoo, _mbti, _hašt, _יוגו, 
   {{0xb34403b7,0xb5fcb9b4,0x6e340034,0x201c0006}},	//   luçã, _kašt, _gdyb, lbti_, 
   {{0xb5fcb9b5,0x6280009b,0x3834b9b6,0x9d4400db}},	// [f010] _jašt, _mnoo, йнар, _ئئبن, 
   {{0x2bd03eaf,0xb5fc098d,0x645c00af,0x26c4058a}},	//   _दुका, _mašt, õpil, enoo_, 
   {{0x62802252,0xd7f80224,0xb064023a,0xb5fcb9b7}},	//   _onoo, туа_, lmää, _lašt, 
   {{0x6458b9b8,0x6280b9b9,0x26c46ed5,0xa6c8022e}},	//   _abti, _nnoo, gnoo_, drаs, 
   {{0xb5fc2a92,0xb064005b,0x74b824fc,0x00000000}},	//   _našt, nmää, лукс_, --, 
   {{0x05740075,0x6280b9ba,0x64580407,0x26c4b9bb}},	//   غاند, _anoo, _cbti, anoo_, 
   {{0xb3440cfc,0x6280002d,0xb064023a,0x69c805d1}},	//   duçã, _bnoo, hmää, şfet, 
   {{0xb5fcb9bc,0x62800009,0x201c0153,0x629c0200}},	//   _bašt, _cnoo, ebti_, ëpop, 
   {{0x8d98001f,0xb5fcb9bd,0x30740120,0x55040395}},	//   ልክተው_, _pašu, бунс, _ъчва, 
   {{0x6280b9be,0x128404fb,0x92b400eb,0x00000000}},	//   _enoo, امکی_, চকে_, --, 
   {{0xb5fc01ef,0x00000000,0x00000000,0x00000000}},	//   _vašu, --, --, --, 
   {{0x628000e8,0x201c0009,0x12e402dd,0xafe401ec}},	//   _gnoo, abti_, _тізг, _қойл, 
   {{0xc108001e,0xf1b817a3,0x8f6401ed,0xb5fc00d0}},	//   _hỗn_, tašu_, _چلتے_, _gašt, 
   {{0x98a4038e,0x1d04b9bf,0xb3440261,0x3870022e}},	//   čně_, сери_, cuçã, _nazr_, 
   {{0xb5fc04b9,0x2bd0b9c0,0xf1b8b9c1,0x26c4b9c2}},	//   _zašt, _दुखा, rašu_, ynoo_, 
   {{0xd1bc0020,0xbebc005f,0xa968361e,0xb064000d}},	//   _ስሜት_, usīt, либа_, bmää, 
   {{0xf1b801fa,0x7bc0004a,0x00000000,0x00000000}},	// [f020] pašu_, ûlur, --, --, 
   {{0x673c1710,0x00000000,0x00000000,0x00000000}},	//   trpj, --, --, --, 
   {{0xeb98b9c3,0xe6183e1e,0x7bc80311,0x26c4208d}},	//   _син_, где_, şeur, tnoo_, 
   {{0x69c80112,0x00000000,0x00000000,0x00000000}},	//   ßfes, --, --, --, 
   {{0x26c40a63,0x1d980092,0x393400c0,0x201c0009}},	//   rnoo_, ህርቶች_, _мэрс, ybti_, 
   {{0xb5fc02d5,0x68ec107d,0x6c78008f,0x62802278}},	//   _rašt, _uhbd, ראַפ, _snoo, 
   {{0x6d4434fd,0x66e476cd,0xb4e80014,0xa5c00210}},	//   huka, _гова, گى۪م_, _łódk, 
   {{0x6d445088,0x52800058,0xb5fc0953,0xc1141b6b}},	//   kuka, كلىك, _pašt, омиј, 
   {{0x6d44b9c4,0x1a9800c8,0x216401b9,0x2444010a}},	//   juka, טיקע, ётиг, _лĕпс, 
   {{0x645803ac,0x2cb80171,0x00000000,0x00000000}},	//   _ubti, _nmpd_, --, --, 
   {{0x201c02d5,0xb3440120,0x634800ac,0x64480175}},	//   rbti_, ruçã, _tənq, mgfi, 
   {{0x6d44b9c5,0xfa240135,0x6280006f,0x614400ee}},	//   fuka, _འབེན_, _unoo, _геда, 
   {{0x6d44b9c6,0x072401ec,0xabd000d1,0x00000000}},	//   guka, _ﭼﻴﯔ_, ﺘﯩﻘﺎ, --, 
   {{0x6448b9c7,0x61e001f0,0xb0648234,0x3a2c0219}},	//   ngfi, _iyol, rmää, _žep_, 
   {{0x38707cea,0xb0641073,0x6d440124,0x9054011a}},	//   _razr_, smää, auka, _הסוף_, 
   {{0x60d85e23,0x61e00337,0x00000000,0x00000000}},	//   lotm, _kyol, --, --, 
   {{0x6d44021a,0x3ea8b9c8,0x53dc043e,0xa9740124}},	// [f030] cuka, _ilat_, _पुनश, овтә, 
   {{0x61e0009a,0x7ae800f1,0x00000000,0x00000000}},	//   _myol, اوړې_, --, --, 
   {{0x7d1c03cd,0x3ea823fc,0xb5fc013a,0xb7c40022}},	//   lpss, _klat_, _našr, црақ, 
   {{0x61e049cf,0x2124003e,0x60d8014f,0xa3bc1bbb}},	//   _oyol, _owoh_, hotm, ीपन_, 
   {{0x61e0b9c9,0x4efc00c8,0x60d801ed,0xea6000d1}},	//   _nyol, אלאג, kotm, _زۇلپ, 
   {{0x3ea80309,0x60d8014f,0x64480efa,0xd7f8022e}},	//   _llat_, jotm, ggfi, _буб_, 
   {{0x6d44b9ca,0x61e0b9cb,0x21240066,0x61fc00ac}},	//   zuka, _ayol, _awoh_, əzlə, 
   {{0x6d44b9cc,0x61e0b9cd,0x00000000,0x00000000}},	//   yuka, _byol, --, --, 
   {{0x60d80158,0x6d44009d,0x00000000,0x00000000}},	//   fotm, xuka, --, --, 
   {{0x61e0007f,0x85b80014,0x00000000,0x00000000}},	//   _dyol, _طاقس_, --, --, 
   {{0x3ea8b9ce,0x21240066,0x61e03926,0x7d1c01a4}},	//   _blat_, _ewoh_, _eyol, epss, 
   {{0x6d44b9cf,0x3ea85f8b,0x212800f1,0x76580042}},	//   tuka, _clat_, _چينی_, nfwy, 
   {{0xb5fcb9d0,0x61e00337,0xab600209,0x7bc00bcd}},	//   _kašq, _gyol, _ýüzl, úlun, 
   {{0x6ae06ae8,0x3ea8b9d1,0x60d8b9d2,0x798c0009}},	//   पत्र, _elat_, cotm, dxaw, 
   {{0x6d44b9d3,0xab28188c,0x61e00161,0x09b400cd}},	//   suka, роба_, _zyol, ूप्य, 
   {{0x3ea8b9d4,0xa924b9d5,0xc1cc0150,0x692401c6}},	//   _glat_, ждал, _ﯗﺟﺪﺍ, жмаа, 
   {{0x6d44b9d6,0xdd8c00aa,0x798c009a,0xbe480137}},	// [f040] quka, _لوي_, gxaw, _اشىم_, 
   {{0x3ea80427,0xab6495b2,0x00000000,0x00000000}},	//   _zlat_, _двол, --, --, 
   {{0xfca8ac15,0x798c011f,0xeb500137,0x765803cb}},	//   _دايو_, axaw, _تۉزگ, ffwy, 
   {{0xe578b9d7,0x77900811,0x1f58010f,0x3af400c0}},	//   изе_, ریقا, ידעא, _няяс, 
   {{0x60d8022e,0x00000000,0x00000000,0x00000000}},	//   yotm, --, --, --, 
   {{0x54b41c26,0xb5fc005f,0x2de40150,0x00000000}},	//   огія_, _pašr, _ﺍﻭﻟﻤ, --, 
   {{0x61e000ca,0x64482bad,0x60d812bb,0xd36c009f}},	//   _syol, rgfi, votm, َهه_, 
   {{0x7eac002d,0x61e004ba,0x60d8020c,0x3f800064}},	//   _kûpe, _pyol, wotm, _čiu_, 
   {{0xa3d40316,0x3f8c0208,0x00000000,0x00000000}},	//   _सडक_, wxdu_, --, --, 
   {{0x61e021a5,0x3ea8b9d8,0x425400f1,0x9594011a}},	//   _vyol, _slat_, آنکر, _וכמו_, 
   {{0x442cb9d9,0xa2e48046,0x987808a8,0x60d802ed}},	//   _ied_, _дожд, בריק, rotm, 
   {{0x442cb9da,0xb5fcb9db,0x00c80075,0x07240150}},	//   _hed_, _kašp, рлүк_, _ﭼﻴﯟ_, 
   {{0x442c0038,0x61e00107,0x21240066,0x60d80356}},	//   _ked_, _uyol, _uwoh_, potm, 
   {{0x442cb9dc,0x7d1cb9dd,0x255c1a14,0x60d8014f}},	//   _jed_, rpss, mālā_, qotm, 
   {{0x442c708a,0x00000000,0x00000000,0x00000000}},	//   _med_, --, --, --, 
   {{0x3ea87ab4,0x798c01d4,0x442c0c30,0x7d1ca2ec}},	//   _ulat_, txaw, _led_, ppss, 
   {{0x442c0cfd,0x81dc00bd,0x255c00da,0xb5fc5160}},	// [f050] _oed_, ণের_, nālā_, _našp, 
   {{0x442cb9de,0x04380150,0xe814ac66,0x3b54011c}},	//   _ned_, _دارﯨ, दुला_, _екор, 
   {{0x9ba00131,0x7f480455,0x00000000,0x00000000}},	//   _غەرى, nudq, --, --, 
   {{0x7d0c0020,0xcf90008f,0x35f4b9df,0x255c00e2}},	//   _kuas, וטע_, ппер, kālā_, 
   {{0x7d0401f7,0x442c0c30,0x7d0c00c7,0x76580042}},	//   _kihs, _bed_, _juas, rfwy, 
   {{0x7d0cb9e0,0x442cb9e1,0x39480a2e,0x76580142}},	//   _muas, _ced_, muas_, sfwy, 
   {{0x442cb9e2,0x00000000,0x00000000,0x00000000}},	//   _ded_, --, --, --, 
   {{0x442cb9e3,0x7d040254,0x3d2000cc,0x255c00ef}},	//   _eed_, _lihs, _বিন্_, fālā_, 
   {{0x7d0c0491,0xb5fc74f4,0x442c0c18,0x255c00de}},	//   _nuas, _gašp, _fed_, gālā_, 
   {{0x442cb9e4,0xa3b4000b,0x75280451,0xf0a8b9e5}},	//   _ged_, _चेक_, _iwez, скол_, 
   {{0x3948b9e6,0x7528b9e7,0x7d0c75fb,0x81dc009e}},	//   huas_, _hwez, _auas, ণেল_, 
   {{0x75281cdf,0x394802b4,0x5f403baf,0x7d0cb9e8}},	//   _kwez, kuas_, رچىل, _buas, 
   {{0x7d0cb9e9,0x3948b9ea,0xf1d4000d,0x255c0055}},	//   _cuas, juas_, _डँटन, cālā_, 
   {{0x7528b9eb,0x7d040007,0x7d0cb9ec,0x7eac000f}},	//   _mwez, _cihs, _duas, _rûpe, 
   {{0x75280928,0xdb80b9ed,0x7eac000f,0x7d0c0381}},	//   _lwez, нгри, _sûpe, _euas, 
   {{0x7d0cb9ee,0x752806cc,0xa3500023,0x9e5c0023}},	//   _fuas, _owez, _ዘይበሃ, ዳበልና_, 
   {{0x7d0cb9ef,0x3948b9f0,0x752801f2,0x00000000}},	// [f060] _guas, guas_, _nwez, --, 
   {{0xb5fc627e,0xf91801d9,0xbef40419,0x00000000}},	//   _rašp, ترٲژ_, číňa, --, 
   {{0xdc98159d,0x7528b9f1,0x442c0302,0x7d0c005a}},	//   _הייל, _awez, _red_, _zuas, 
   {{0x442cb9f2,0x3948b9f3,0x7528b9f4,0x7d0c037e}},	//   _sed_, buas_, _bwez, _yuas, 
   {{0x7528014b,0xb3a8ae4a,0x3948b9f5,0x7d0c022e}},	//   _cwez, çını, cuas_, _xuas, 
   {{0x442cb9f6,0x255c00e2,0x7f48014f,0x00000000}},	//   _qed_, vālā_, yudq, --, 
   {{0x442c708a,0x752802e3,0x54300145,0xaf2c0023}},	//   _ved_, _ewez, ررور, ተብህለ, 
   {{0xb9080016,0x7528009f,0x61e400c5,0x442cb9f7}},	//   _nghị_, _fwez, üklo, _wed_, 
   {{0x75280489,0x316caf7a,0x442cb9f8,0x15400120}},	//   _gwez, gwez_, _ted_, _петм, 
   {{0x7d0cb9f9,0xa088086f,0x255c00e2,0xa49001d5}},	//   _ruas, ссиз_, rālā_, _سیبت, 
   {{0xdef89b35,0x6d54b9fa,0x7d040309,0xdddc0139}},	//   йым_, _aqya, _rihs, _baqş, 
   {{0x7d0c8590,0x39480218,0x00000000,0x00000000}},	//   _puas, yuas_, --, --, 
   {{0x39480218,0x7f48014f,0xef640139,0x31706171}},	//   xuas_, sudq, _çını_, _ағыт, 
   {{0x9cc83007,0x7d0c036e,0x0a68010b,0x00000000}},	//   сыма_, _vuas, үрти_, --, 
   {{0x7d0c0789,0x90580375,0x88c40011,0x95340023}},	//   _wuas, _הכות, ্তাক, _ኣይንደ, 
   {{0x3948b9fb,0x7d0cb9fc,0xe7e400c5,0x00000000}},	//   tuas_, _tuas, _करजा_, --, 
   {{0x7d040784,0xa3500023,0x00000000,0x00000000}},	// [f070] _tihs, _ዘይብሃ, --, --, 
   {{0x3948b9fd,0x7528b9fe,0xdd8c05d9,0x7b846431}},	//   ruas_, _rwez, _لوڊ_, _قاجە, 
   {{0x8d18b9ff,0xdaa00075,0x39480070,0xdb58010b}},	//   _وزیر_, _كەسپ, suas_, _уюп_, 
   {{0x7528ba00,0xcb44030d,0x00000000,0x00000000}},	//   _pwez, _яхьи, --, --, 
   {{0xb60800da,0x394816b8,0xdb040254,0x00000000}},	//   višķ, quas_, ömõt, --, 
   {{0xf3e401c0,0x73e400d8,0x00000000,0x00000000}},	//   мжло, молз, --, --, 
   {{0xb608005f,0x964400c0,0x00000000,0x00000000}},	//   tišķ, _нэад, --, --, 
   {{0x75282c36,0x5928025c,0x69c0a4cd,0x00000000}},	//   _twez, _སྦོས_, _रेडी, --, 
   {{0x752800b2,0x63c406be,0x00000000,0x00000000}},	//   _uwez, _əsnə, --, --, 
   {{0x6d54022e,0x316c641a,0xc564009f,0x00000000}},	//   _rqya, rwez_, _سُمي, --, 
   {{0x6e44ba01,0x72180276,0x864402d3,0x93a4010a}},	//   менз, _джер_, _ከምእት, _эшад, 
   {{0x81dc04c5,0xed5801c0,0xdb040e78,0xdddc013d}},	//   ণেই_, оом_, nzjä, _qaqş, 
   {{0x6d5403f9,0xdc10008e,0x11e8107b,0x82343b98}},	//   _qqya, _ağım, _اعاي_, _سرنا, 
   {{0x44200069,0xa064004e,0x00000000,0x00000000}},	//   ʝi_, _жаша_, --, --, 
   {{0x3bd4656c,0xeb3473c5,0x7d0801e4,0x00000000}},	//   еютс, بىزد, ŭesp, --, 
   {{0xeb9801d5,0x00000000,0x00000000,0x00000000}},	//   биҳ_, --, --, --, 
   {{0x6d5402d1,0xd6d0015b,0x7c3801e7,0xec780108}},	// [f080] _uqya, ়তায, éaró, _дпп_, 
   {{0x6d440067,0x00000000,0x00000000,0x00000000}},	//   mrka, --, --, --, 
   {{0xb3a8538f,0x00000000,0x00000000,0x00000000}},	//   çılı, --, --, --, 
   {{0xa3bc0a81,0x9f940302,0x6d44ba02,0x56900212}},	//   ीपस_, ודעה_, orka, каєт, 
   {{0xe8f83da1,0x7ae8003d,0x00000000,0x00000000}},	//   _млм_, ċett, --, --, 
   {{0xd1bc1e38,0xf1e005b3,0x00000000,0x00000000}},	//   ስነት_, _पड़न, --, --, 
   {{0x442000c8,0x69c002ab,0x6d44ba03,0xe7380640}},	//   ĝi_, _रेती, hrka, _феб_, 
   {{0x26c0ba04,0xc17410d9,0x4420010f,0xe6340023}},	//   _öko_, елищ, ŝi_, _ኣጽኒዕ, 
   {{0xdee80092,0x6470022e,0x00000000,0x00000000}},	//   _ዘረኛ_, _аҳлу, --, --, 
   {{0x634803be,0x6d440e04,0x503401af,0x00000000}},	//   _mənz, drka, мпью_, --, 
   {{0xc10807ae,0xd24cba05,0x6d44ba06,0x00000000}},	//   _mỗi_, _иц_, erka, --, 
   {{0xd12c156d,0xc10807ae,0x66f0013f,0x6d4470b1}},	//   _چمن_, _lỗi_, _bɛkɑ, frka, 
   {{0xd9e0069f,0xdde8ba07,0x00000000,0x00000000}},	//   _कुढत_, ترده_, --, --, 
   {{0x409400f2,0xf1a80244,0x00000000,0x00000000}},	//   _سلبر, _عانه_, --, --, 
   {{0x6d44ba08,0xc1080016,0x3d282be7,0xbebc00e2}},	//   arka, _nỗi_, _کتبی_, rpīb, 
   {{0x6d4407f5,0x634800ac,0x00000000,0x00000000}},	//   brka, _bənz, --, --, 
   {{0x9fa401af,0x00000000,0x00000000,0x00000000}},	// [f090] _хыҙҙ, --, --, --, 
   {{0x6d58054e,0x97c41bf4,0x00000000,0x00000000}},	//   ătat, وتام, --, --, 
   {{0xa6380023,0xc1080208,0xd5840133,0x00000000}},	//   _ከምዝደ, _cỗi_, ژێره_, --, 
   {{0xc108004d,0xb6c401c0,0xa61400c7,0x9994012d}},	//   _dỗi_, хөгд, езцә, ągły_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6ef40077,0xbb3400d1,0x44240101,0x00000000}},	//   mábe, ﺯﯗﻥ_, پروف, --, 
   {{0x998801ef,0xf2c4009d,0x6d440419,0x00000000}},	//   _keců_, нөди, zrka, --, 
   {{0x1cbc31d9,0x6d44ba09,0x3f58ba0a,0xf1d00137}},	//   _གཏའ_, yrka, déu_, лөлө, 
   {{0x6ef40077,0xe8141810,0x00000000,0x00000000}},	//   nábe, दुका_, --, --, 
   {{0x3f5806ed,0xd1bc0b82,0x44f40024,0x45d400fb}},	//   féu_, ስነቱ_, _апус, _роус, 
   {{0x453c0020,0x1b1c0154,0x6d44058a,0x66800244}},	//   _አልነበ, _বয়সে_, wrka, _جیۆل, 
   {{0x0378ba0b,0x6d442876,0x82a40063,0x1be00037}},	//   _زحمت_, trka, _ишче, _गड़ल_, 
   {{0x6d44ba0c,0x1164006c,0xed3401c0,0xccf804a9}},	//   urka, _آلتی_, ээнэ, мқи_, 
   {{0x3f582e27,0x6ef4056a,0x6d44ba0d,0xa134010f}},	//   béu_, dábe, rrka, _טאנק_, 
   {{0xeb986522,0x6d440427,0xa9d400d1,0xb81400eb}},	//   чив_, srka, ﯞﺳﯩﻴ, িরাত_, 
   {{0xd1d0001f,0xc10801fb,0x6d4416a3,0xd1f40092}},	//   _ካሉት_, _rỗi_, prka, _ላሉት_, 
   {{0x6da40276,0x6ef40005,0xada4ba0e,0xa908027d}},	// [f0a0] _чипа, gábe, _чапл, سيال_, 
   {{0x9f40043b,0x1cbc025c,0x56900417,0x00000000}},	//   ́kí_, _གཏར_, ғашт, --, 
   {{0xe66458a8,0xac700023,0x7ae8031c,0x00000000}},	//   етло, _ብምሓዝ_, ċetr, --, 
   {{0x66740220,0x6ef4ba0f,0x634800ac,0x237401d9}},	//   عدار, bábe, _tənz, ہلتھ_, 
   {{0x1a9800c8,0x6ef4056a,0x00000000,0x00000000}},	//   _זיכע, cábe, --, --, 
   {{0x592849a6,0xe73800f3,0x00000000,0x00000000}},	//   _སྦིས_, _нег_, --, --, 
   {{0x29082210,0x25e400c5,0x05c000bc,0x53c007b7}},	//   _iiba_, ड़ेजी_, _शेरब, _वेदश, 
   {{0xe60804fb,0x2908ba10,0x4ad0190c,0x00000000}},	//   _رزرو_, _hiba_, सचिव, --, 
   {{0x2908b032,0x26c40093,0xe66401e0,0x765c010e}},	//   _kiba_, mioo_, _отҡо, _ösya, 
   {{0xdfd806bb,0xe50400c6,0x2908ba11,0x26c40418}},	//   зъм_, _أبري, _jiba_, lioo_, 
   {{0x2908ba12,0x6ef40077,0x77740175,0x69c006e3}},	//   _miba_, zábe, _xszx, _रेसी, 
   {{0x26c4ba13,0x249c0036,0x63bc00d7,0x00000000}},	//   nioo_, _hotm_, úpnu, --, 
   {{0x25a4ba14,0x6ef40077,0xa0a40153,0x00000000}},	//   nyol_, xábe, _падд, --, 
   {{0x29084c99,0x3f5806ed,0x6ef40005,0x8234ba15}},	//   _niba_, péu_, vábe, _سرچا, 
   {{0x9a84ba16,0x249c0010,0x25a40076,0x3eb8068c}},	//   нуал, _motm_, hyol_, èrts_, 
   {{0x2908084c,0x6ef4056a,0x6d580311,0xd87414af}},	//   _aiba_, tábe, ătar, کارب, 
   {{0x29080a03,0x7e7cba17,0x7cd8ba18,0xdd84004e}},	// [f0b0] _biba_, mdsp, _омир_, _чыйп, 
   {{0x7e7cba19,0x2908ba1a,0x6ef41709,0xdde800f1}},	//   ldsp, _ciba_, rábe, _ورکه_, 
   {{0x2908ba1b,0x26c40270,0x6ef40077,0xd51401e1}},	//   _diba_, fioo_, sábe, _ọ̀w, 
   {{0xdc2802f2,0x46a400d4,0xb92000d1,0x00000000}},	//   _بسکه_, лаєв, _نېرۋ, --, 
   {{0x3a2831e5,0x7e7cb2f9,0x8aa400c0,0x00000000}},	//   mbap_, idsp, _срэд, --, 
   {{0x7aecba1c,0xe5a0ba1d,0x5928025c,0x84580801}},	//   llat, риши, _སྦགས_, ерът_, 
   {{0x7aecba1e,0x8c1c025f,0xe8d40a1e,0x3948ba1f}},	//   olat, לוגי, _יושר_, lras_, 
   {{0x7aecba20,0x7e7c019b,0x2908ba21,0xa96400db}},	//   nlat, jdsp, _ziba_, _سۅۅم_, 
   {{0x2908ba22,0x7e7c713c,0x8544104e,0x3948ba23}},	//   _yiba_, ddsp, _бэхе, nras_, 
   {{0x39487c36,0x2908011f,0xef180408,0x7e7c127b}},	//   iras_, _xiba_, ммо_, edsp, 
   {{0x6ef4066d,0x3254ba24,0x645c00f7,0x394800c6}},	//   vább, _авер, òpie, hras_, 
   {{0x3948ba25,0xada404a9,0x7e7c282c,0x6da40107}},	//   kras_, вамл, gdsp, вима, 
   {{0x7aecba26,0x3eb80023,0x3f9806ea,0x3948ba27}},	//   dlat, ërta_, ørur_, jras_, 
   {{0x7aec1730,0x7e7c017a,0x61400408,0x216401f0}},	//   elat, adsp, _теша, _риши_, 
   {{0x1d04ba28,0x3948ba29,0x6ef400dd,0x7eac002d}},	//   тери_, eras_, rább, _kûpl, 
   {{0x5928031c,0x21dc0521,0x6d480c4f,0x6a840395}},	//   _སྦངས_, ịhe_, _قلبِ_, ълба, 
   {{0x3948ba2a,0x2908ba2b,0x69c001f9,0x00000000}},	// [f0c0] gras_, _piba_, _रेशी, --, 
   {{0x7aecba2c,0x00000000,0x00000000,0x00000000}},	//   alat, --, --, --, 
   {{0x7aecba2d,0x3948ba2e,0x26c403a0,0xd9400276}},	//   blat, aras_, tioo_, леӂи, 
   {{0x7aecba2f,0x76a800d6,0x1cbc0135,0x290800ca}},	//   clat, нтів_, _གཏོ_, _wiba_, 
   {{0x2908209d,0x3948ba30,0x26c4068c,0x00000000}},	//   _tiba_, cras_, rioo_, --, 
   {{0x4904ba31,0x26c403a0,0x545002bf,0xdb200200}},	//   _сүзг, sioo_, ивіт, ërçe, 
   {{0x9878008f,0x7e7c2b96,0x00000000,0x00000000}},	//   _קאלט, ydsp, --, --, 
   {{0x415400c7,0x8534ba32,0x52800075,0xa26402e8}},	//   гвис, _مورچ, للىك, тъкл, 
   {{0xe57836da,0xe4d800f2,0xc0c40166,0x00000000}},	//   _юза_, _قورت_, ләки, --, 
   {{0x1cbc025c,0x7e7c0204,0x649801b9,0x3d9408ca}},	//   _གཏེ_, wdsp, _ўтар_, ҳимр, 
   {{0x39480c86,0xa3b81867,0x00000000,0x00000000}},	//   zras_, _غائر_, --, --, 
   {{0x3948ba33,0x7e7c4174,0x22500158,0x00000000}},	//   yras_, udsp, _øyk_, --, 
   {{0x7aec006c,0x9e7c0023,0x95680023,0x00000000}},	//   vlat, _ንኹልና_, _ጽቡቕን_, --, 
   {{0x3948ba34,0x201806be,0x00000000,0x00000000}},	//   vras_, _üpi_, --, --, 
   {{0x7aecba35,0xcb3400a7,0x4c94ba36,0xd0f404ae}},	//   tlat, иеръ, ширс, _שמות_, 
   {{0x3948ba37,0x7aecba38,0x6ab40368,0x8eb400cf}},	//   tras_, ulat, ghyf, _نەپت, 
   {{0x7aecba39,0x3948ba3a,0x8934007b,0x79f4074d}},	// [f0d0] rlat, uras_, لعلا, узах, 
   {{0x6ef4ba3b,0x97a40f15,0x00000000,0x00000000}},	//   mába, крел, --, --, 
   {{0x6ef400dd,0x3948ba3c,0x8a1401d3,0x2aac01ef}},	//   lába, sras_, اظہا, _kýbl_, 
   {{0x7aecba3d,0x00000000,0x00000000,0x00000000}},	//   qlat, --, --, --, 
   {{0x6ef401ed,0xf1b800a2,0x00000000,0x00000000}},	//   nába, bašy_, --, --, 
   {{0x7eac002d,0xfa3407d2,0x6d9c03e3,0x00000000}},	//   _sûpl, _جىڭج, lçaç, --, 
   {{0xd5bc005f,0x36d4010b,0x61ec0213,0x6ef401d3}},	//   _šādu_, _бовр, əbli, hába, 
   {{0x6ef401ed,0xe45000c7,0xaac42c2e,0x00000000}},	//   kába, акәы, रोपक, --, 
   {{0x6ef400dd,0xfac0004d,0x645c00cf,0x00000000}},	//   jába, _đấy_, òpic, --, 
   {{0xe1f4ba3e,0x53442386,0x6ef41a74,0x1474ba3f}},	//   ыгы_, _ахда, dába, _جارج, 
   {{0xb5fc0953,0x3f9800b5,0x6d9c013d,0x00000000}},	//   _rašy, ørup_, kçaç, --, 
   {{0x313410ae,0x1cbc0327,0x79880327,0x148400ec}},	//   _бедр, _གཏུ_, _ġewn, _سھڻي_, 
   {{0x6ef4ba3b,0x6144a67e,0xb5fc0064,0x00000000}},	//   gába, _مىنە, _pašy, --, 
   {{0xed58016c,0xaec4008e,0x7054ba40,0x3cd40006}},	//   _ҷои_, _әбил, _صنعا, аўст, 
   {{0xb5fc0010,0xda6001c6,0x6ab403ac,0xca4c0150}},	//   _obšo, өври, thyf, _ﺍﻻﺭ_, 
   {{0x2d9402f6,0x6ef401d3,0xed5873f9,0xdb2031b7}},	//   _брос, bába, _зои_, áráb, 
   {{0xceb49f20,0x6ef4ba41,0xe9d8ba42,0xb5fc0064}},	// [f0e0] _ilə_, cába, хка_, _tašy, 
   {{0x48c40d42,0xb4dc0316,0x6e34ba43,0x6ab4003e}},	//   ্ত্র, णको_, _heyb, shyf, 
   {{0x6e34ba44,0xf7180006,0x00000000,0x00000000}},	//   _keyb, вічы_, --, --, 
   {{0x4ab40323,0x44380024,0x9f480267,0xf6e40024}},	//   _төгр, _žr_, _åmål_, ацін, 
   {{0x96300006,0x00000000,0x00000000,0x00000000}},	//   сніц, --, --, --, 
   {{0x6e34ba45,0x04c897b5,0x00000000,0x00000000}},	//   _leyb, ضوعي_, --, --, 
   {{0xf774ba46,0x6ef4ba47,0xc33000d1,0x544000f7}},	//   _кутю, zába, زەش_, حنىك, 
   {{0x66e4524d,0x57e403b7,0x6ef401d3,0x00000000}},	//   _соба, _сдсм_, yába, --, 
   {{0x6ed00882,0x6ef40005,0x13e40032,0x80b46191}},	//   mābh, xába, кмәй_, ибих, 
   {{0x6ed00882,0xb9cc0023,0xceb403b9,0x443808a5}},	//   lābh, _ደይ_, _alə_, _þr_, 
   {{0x64586656,0x2a700009,0x626400f7,0x3eb80200}},	//   _icti, keyb_, _ماشق, ërto_, 
   {{0x6ed00882,0x6ef4ba48,0xb5fc0010,0x00000000}},	//   nābh, tába, _obšl, --, 
   {{0xe1f0ba49,0xd00c004b,0x63a8015d,0xe0e401a9}},	//   _اسا_, _ځله_, lyfn, _йўко, 
   {{0xceb40cc1,0x6ef4ba4a,0x6ed00882,0xd00cba4b}},	//   _elə_, rába, hābh, _فله_, 
   {{0x6ef400dd,0xefc0001f,0xfac4035b,0x9f580248}},	//   sába, ስተው_, ашаҽ, _àpà_, 
   {{0x8aa4ba4c,0x6ef4ba4d,0x6fa00118,0x00000000}},	//   бруд, pába, खहरू, --, 
   {{0x383416e4,0x6458ba4e,0x63a803cb,0x58841367}},	// [f0f0] инар, _octi, hyfn, лыжа, 
   {{0x201c0483,0x1cbc0135,0x6e3403e0,0x673c02d2}},	//   ncti_, _གཏི_, _zeyb, fspj, 
   {{0x201c003a,0x2a70058a,0x91c800dc,0xdb0400c7}},	//   icti_, beyb_, _तेनै, hyjé, 
   {{0x2a700067,0x53b408b0,0x6e3406be,0x95b00166}},	//   ceyb_, ңғар_, _xeyb, йрлә, 
   {{0xdfc40451,0x2a380a7c,0x040c00eb,0x00000000}},	//   _ڀي_, _בערמ, সুমী_, --, 
   {{0x645801e4,0xf8b0ba4f,0x850401b9,0xd5b800c7}},	//   _ccti, _بکر_, مونن, _ҧса_, 
   {{0xab640724,0x57a4036b,0x645c56ed,0x63a803cb}},	//   _itüç, _ёшга, òpia, gyfn, 
   {{0x64580c8c,0x201c0381,0x6ed0002b,0xb22400d8}},	//   _ecti, ecti_, cābh, јмпл, 
   {{0x3494ba50,0x00000000,0x00000000,0x00000000}},	//   _каар, --, --, --, 
   {{0x6f6456cd,0x6e34ba51,0x3eb8002f,0xca4c01ec}},	//   авоз, _seyb, ehst_, _ﺍﻻﺤ_, 
   {{0x6e34ba52,0x850412ea,0x7afc02d0,0x00000000}},	//   _peyb, _اولن, _ohst, --, 
   {{0x6e340050,0x8d780022,0x00000000,0x00000000}},	//   _qeyb, гәоу_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6e340009,0xb7e437d0,0x00000000,0x00000000}},	//   _weyb, कथाम_, --, --, 
   {{0xea5803b7,0x6ed00882,0x3eb801ab,0x6e3403e0}},	//   крај_, yābh, bhst_, _teyb, 
   {{0x3eb8ba53,0x7afc0589,0x7ff41aa3,0x9f580248}},	//   chst_, _chst, _اسها, _àpá_, 
   {{0xa96852a4,0x2d9401e0,0x80c80154,0x00000000}},	// [f100] ضمام_, _төнө_, রকর্, --, 
   {{0x270c05dc,0x2cac002d,0x1cbc031c,0x7afc036e}},	//   िद्र_, _ôfd_, _གཏག_, _ehst, 
   {{0x6ed00882,0xab282716,0x850800fb,0x00000000}},	//   tābh, _шона_, ңдең_, --, 
   {{0xf74801b9,0x6458003a,0x368802dd,0x2a70058a}},	//   اجله_, _scti, лсін_, qeyb_, 
   {{0xc5f8416c,0x6ed00882,0x7eac002d,0x6458002f}},	//   уға_, rābh, _sûpk, _pcti, 
   {{0x63a8ba54,0x00000000,0x00000000,0x00000000}},	//   tyfn, --, --, --, 
   {{0xa6940b7f,0x836800aa,0xe61800c0,0xe738011c}},	//   _крај, اشتې_, _адб_, _шев_, 
   {{0x21648525,0x6d880113,0xe5a4010a,0x00000000}},	//   атог, 鯵ari, _киби, --, 
   {{0xa6c8022e,0x00000000,0x00000000,0x00000000}},	//   ssаs, --, --, --, 
   {{0xa0a4ba55,0x6458ba56,0x733000aa,0x65600023}},	//   ршил, _ucti, _کډوا, mtoh, 
   {{0x443cba57,0x80c82aab,0x6560ba58,0x200800fd}},	//   mav_, রকল্, ltoh, äbi_, 
   {{0xa184ba59,0x1cbc03bd,0x443cba5a,0x00000000}},	//   _выкл, _གཏང_, lav_, --, 
   {{0x8644001f,0x5194104c,0x20a00023,0x0dc800d8}},	//   _የኮንስ, _نخود_, _ዝገልጹ_, аури_, 
   {{0x443cba5b,0x6560ba5c,0x212400b5,0xdfd002dd}},	//   nav_, itoh, _itoh_, _қоқы, 
   {{0xd00c0032,0xabb400d1,0xa3bc01ad,0x6560ba5d}},	//   _фф_, барә, ीपट_, htoh, 
   {{0x443c0457,0x6560ba5e,0x00000000,0x00000000}},	//   hav_, ktoh, --, --, 
   {{0x6560044e,0xaac423c1,0xf8b801c6,0x313c0023}},	// [f110] jtoh, रोधक, гөв_, _ሓተትክ, 
   {{0x6560409c,0x19546f78,0x443c54b0,0x00000000}},	//   dtoh, лағы_, jav_, --, 
   {{0x443cba5f,0x2df81bf3,0xc7c400f0,0xef641ea0}},	//   dav_, _لبیک_, осци, _çıtı_, 
   {{0x22443e0e,0x65600023,0xf9d40064,0x00000000}},	//   _ndok_, ftoh, _гомэ, --, 
   {{0x443c014a,0x98b003be,0x6560036e,0x00000000}},	//   fav_, şdır_, gtoh, --, 
   {{0x2244ba60,0x443ca081,0x3a380204,0xf794084c}},	//   _adok_, gav_, _hesp_, _лагэ, 
   {{0x21240438,0x17046f43,0x3a38010e,0x324401ec}},	//   _atoh_, _نفسی_, _kesp_, бейг, 
   {{0x443c0421,0xca2c06ba,0x4bfc011a,0xcb14011a}},	//   aav_, ﻧﻴﺎ_, כלוס, חלק_, 
   {{0x443c04b9,0x35b46ec1,0xd49805f5,0x765803cb}},	//   bav_, _убар, _ирж_, mgwy, 
   {{0x443cba61,0xada40032,0xab780023,0x6ef401d3}},	//   cav_, ҡанл, _ብልዑል_, tábo, 
   {{0xafe407d6,0x00000000,0x00000000,0x00000000}},	//   сонл, --, --, --, 
   {{0x2eb4ba62,0x21240200,0x76586fe6,0x00000000}},	//   ссос, _ftoh_, ngwy, --, 
   {{0x6218011a,0x5d64014b,0x00000000,0x00000000}},	//   _עוסק, биям_, --, --, 
   {{0x3a38020c,0xace8ba63,0x76580142,0xdc540014}},	//   _aesp_, умга_, hgwy, ٝرِک, 
   {{0x3a38009a,0x7fe82586,0x00000000,0x00000000}},	//   _besp_, _پروف_, --, --, 
   {{0x443cba64,0x39540b82,0xdcac215c,0x2d9401af}},	//   zav_, _ዝርዝራ, _ۋىي_, _лөгө_, 
   {{0x443c0070,0xfd98035f,0x684401c6,0x66241870}},	// [f120] yav_, _көрә_, йнаа, ەرتك, 
   {{0xeb9815ed,0xec784b4d,0x76580142,0xef640139}},	//   _био_, _спо_, egwy, _çısı_, 
   {{0x443c1aff,0x3a380005,0x6560016b,0xc69000f1}},	//   vav_, _fesp_, wtoh, وېس_, 
   {{0x3a3801a4,0x6560ba65,0x5b7808a8,0x443cba66}},	//   _gesp_, ttoh, _ערכא, wav_, 
   {{0x443cba67,0x6bd40133,0x78c403b2,0x00000000}},	//   tav_, _ختکر, øtvø, --, 
   {{0x6560ba68,0x6aa4045f,0x9d180a1e,0x4394010b}},	//   rtoh, _hokf, אוסט, жакс, 
   {{0x6560ba69,0x23680592,0x6ef46d6c,0x6aa40200}},	//   stoh, احتي_, tábl, _kokf, 
   {{0x443cba6a,0x656002d3,0x97c009a5,0x00000000}},	//   sav_, ptoh, _эйсе, --, 
   {{0x443cba6b,0xb3a8029f,0x5a98008f,0x00000000}},	//   pav_, çırı, רשפא, --, 
   {{0x6aa4ba6c,0xca4c02dd,0x00000000,0x00000000}},	//   _lokf, _ﺍﻻﺴ_, --, --, 
   {{0xd1b4040b,0x6aa402d0,0xbed802e8,0x228483f5}},	//   لایا_, _ookf, идох_, _гулг, 
   {{0x8c0000eb,0x00000000,0x00000000,0x00000000}},	//   ্ডান_, --, --, --, 
   {{0x3a38ba6d,0x61f400c6,0x61b0ba6e,0xd5e800c7}},	//   _resp_, _اساء, _رەدا, meg̃, 
   {{0x62800093,0x3f9800af,0xdc34008e,0x7170009f}},	//   _haoo, ärus_, _däğw, _آڇيا, 
   {{0x6aa46afa,0x6280ba6f,0x7658015d,0x10104363}},	//   _bokf, _kaoo, ygwy, _عبود, 
   {{0xc32449c6,0x8aa4ba70,0x00000000,0x00000000}},	//   _ۋە_, пруд, --, --, 
   {{0x9cc8052f,0x7e6c0117,0x6280ba71,0x3a38003a}},	// [f130] _бына_, _ibap, _maoo, _vesp_, 
   {{0x3a3801f5,0x3e6c022e,0x00000000,0x00000000}},	//   _wesp_, lоt_, --, --, 
   {{0xb064049b,0x628004ba,0x06440023,0xaac43cbe}},	//   llää, _oaoo, _ከምዝቐ, रोहक, 
   {{0x35f4ba72,0xb6c800dd,0xb06401f4,0x00000000}},	//   опер, جائے_, olää, --, 
   {{0xd564554c,0x7e6c7af8,0x956400ee,0xb064023a}},	//   степ, _mbap, съед, nlää, 
   {{0x765800a9,0x81cc09bd,0xd6c001b9,0x00000000}},	//   sgwy, _শুভ_, _کمری, --, 
   {{0x7e6c5a1f,0x68f80375,0xb06401f4,0x6ac408a5}},	//   _obap, _כלשה, hlää, _útfö, 
   {{0xf48401d3,0x312401d5,0x00000000,0x00000000}},	//   _ڈائی, одиг, --, --, 
   {{0x7648ba73,0xb5fc0dfe,0x62840109,0x81cc00cc}},	//   _idey, _obši, ôkoa, _শুব_, 
   {{0x7e6ca82e,0x7528ba74,0xb50400db,0x25b003cd}},	//   _abap, _itez, _بۉتۅ_, øyle_, 
   {{0x77640227,0xb4e46fe9,0x43940fc0,0xd3440244}},	//   nthx, नवी_, _нафс, _ایبه_, 
   {{0x2d940032,0x7c2402d2,0xc8840432,0x00000000}},	//   оргс, _afhr, _kişä_, --, 
   {{0xe1ec0114,0x00000000,0x00000000,0x00000000}},	//   _цг_, --, --, --, 
   {{0x6c340491,0x7e6cba75,0xc10431b1,0xc8840139}},	//   تفسا, _ebap, _فوني, _mişä_, 
   {{0x7648ba76,0x7d080165,0xb0640108,0x6a84011c}},	//   _odey, ïesa, alää, олва, 
   {{0x7e6cba77,0x752805d5,0x7648ba78,0x00000000}},	//   _gbap, _otez, _ndey, --, 
   {{0xf7e804a9,0x75280b12,0xe8c8ba79,0xd6cc0154}},	// [f140] ەرنى_, _ntez, агал_, িকায, 
   {{0x7648ba7a,0x3d2005ac,0x00000000,0x00000000}},	//   _adey, _বিচ্_, --, --, 
   {{0xe6182826,0xeb98ba7b,0xc688001f,0x7528ba7c}},	//   аде_, _тин_, _በምርጫ_, _atez, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6280003e,0x2cb801f5,0x7ae001d3,0x3eb8036e}},	//   _raoo, _klpd_, élte, ërti_, 
   {{0x7ae8151c,0xddcc084c,0x76489c11,0x00000000}},	//   čete, lecţ, _edey, --, 
   {{0x7528216e,0xdc9808d8,0x9374007b,0x00000000}},	//   _etez, ייסל, قصير_, --, 
   {{0xc298ba7d,0x48f4012c,0xb064005b,0x5ab4008f}},	//   ских_, ्गको_, ylää, ַליע_, 
   {{0xddcc0311,0x628005c7,0x00000000,0x00000000}},	//   iecţ, _vaoo, --, --, 
   {{0x6ef400ae,0xf1d800cd,0x00000000,0x00000000}},	//   lábh, यॊधन, --, --, 
   {{0x62800618,0x2aac0419,0x7e980472,0x00000000}},	//   _taoo, _hýbu_, مندر_, --, 
   {{0x2168a752,0xddcc054e,0x6ef400ae,0x00000000}},	//   _види_, jecţ, nábh, --, 
   {{0x1cbc0ed9,0x8d844d58,0xded00023,0x712000db}},	//   _གཏད_, мурд, ከሎኻ_, _كۉيم, 
   {{0xf1a8168d,0x61e0014b,0xa2a401ad,0xdb2001c7}},	//   _دامه_, _ixol, टॉर्, _ërën, 
   {{0x0b8845ce,0xb06402f6,0x6ef400d2,0xddcc0276}},	//   ости_, slää, kábh, fecţ, 
   {{0x7e6cba7e,0x3e6c022e,0xb06401f4,0x00000000}},	//   _ubap, qоt_, plää, --, 
   {{0xb9540801,0x14d80073,0xe518000d,0x00000000}},	// [f150] яващ, _बदलण, _फूलि_, --, 
   {{0xa2c8ba7f,0x61e0209c,0x3ea8001e,0x60d8ba80}},	//   तोत्, _mxol, _hoat_, nntm, 
   {{0x6d480618,0x7528ba81,0x3ea8030a,0x60d8ba82}},	//   _āfai, _stez, _koat_, intm, 
   {{0x61e00b6f,0x8d740131,0x6ef40332,0x8f9805d0}},	//   _oxol, _راۋا, gábh, ייבי, 
   {{0x3ea80225,0xceb400c8,0x7aecba83,0x7988003d}},	//   _moat_, ויף_, moat, _ġeww, 
   {{0x3b0800ac,0x3ea80208,0xb4e41408,0xa508ba84}},	//   lmaq_, _loat_, नवे_, مىنە_, 
   {{0x61e026ef,0xd76048dc,0x00000000,0x00000000}},	//   _axol, _تنزی, --, --, 
   {{0x60d845a7,0x7aecba85,0x3b0800ac,0x3ea8000f}},	//   entm, noat, nmaq_, _noat_, 
   {{0xc2c8ba86,0x7528ba87,0x00000000,0x00000000}},	//   تبول_, _utez, --, --, 
   {{0x7aecba88,0x6ef400d2,0xa92001a8,0xf19400c7}},	//   hoat, mábi, _óþek, _ҭижь, 
   {{0x3ea8ba89,0x7aecba8a,0xc0a84630,0x61e0ba8b}},	//   _boat_, koat, تايل_, _exol, 
   {{0x7aec86e5,0x3ea80c18,0x71400137,0x00000000}},	//   joat, _coat_, _كۉبۅ, --, 
   {{0x3ea872f0,0x3b0806be,0x00000000,0x00000000}},	//   _doat_, dmaq_, --, --, 
   {{0xdc100790,0x00000000,0x00000000,0x00000000}},	//   _aşım, --, --, --, 
   {{0xddcc084c,0xa098008f,0x7aecba8c,0x6ef4056a}},	//   tecţ, _ליסט, foat, hábi, 
   {{0x3ea8ba8d,0xee383ba6,0x7aecba8e,0xaac405d7}},	//   _goat_, _уни_, goat, रोंक, 
   {{0xddcc084c,0xe8185734,0xc8b401b9,0xdd8c0066}},	// [f160] recţ, مزات_, ولرک, _موي_, 
   {{0xab64ba8f,0x6ef4003a,0xb4e42d3b,0xec3000d1}},	//   _евол, dábi, नवो_, _سۈرگ, 
   {{0x6ef400d2,0xe7380107,0x4d88009f,0x00000000}},	//   tábh, ёед_, _اَڌُ_, --, 
   {{0x7aecba90,0xa3e4228d,0x6d44ba91,0xd7ec00c6}},	//   coat, _युग_, oska, دكم_, 
   {{0x6d44ba92,0x7c340a85,0x60d80204,0x6f140477}},	//   nska, _ôfrû, yntm, _miyc, 
   {{0x6d44ba93,0xe3b0007b,0x00000000,0x00000000}},	//   iska, فرع_, --, --, 
   {{0x6d44030a,0x61e027ac,0x00000000,0x00000000}},	//   hska, _sxol, --, --, 
   {{0x6d44ba94,0x62640597,0x6f140309,0x6ab401f5}},	//   kska, سابق, _niyc, nkyf, 
   {{0x6d44ba95,0xdb0401ed,0x3ea8007c,0x00000000}},	//   jska, nyjá, _roat_, --, 
   {{0x6d44ba96,0x3ea807d6,0x3b0803be,0x7aec9662}},	//   dska, _soat_, zmaq_, zoat, 
   {{0x3ea8ba97,0x7aec01c8,0xd36c05d9,0xd24c9120}},	//   _poat_, yoat, _مهل_, _пц_, 
   {{0x3b0800ac,0x61e001c4,0x7aec0077,0x6d44ba98}},	//   xmaq_, _txol, xoat, fska, 
   {{0x50b40502,0x7aecba99,0x61e04242,0x3ea80076}},	//   زدید_, voat, _uxol, _voat_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7aecba9a,0x6d44ba9b,0x3b0803be,0x3ea8ba9c}},	//   toat, aska, tmaq_, _toat_, 
   {{0xcff40bd9,0x6d44005c,0x80b400bc,0x00000000}},	//   _מצוה_, bska, इसके, --, 
   {{0x3b08ba9d,0xdb0401ed,0x3914014b,0x6d44ba9e}},	// [f170] rmaq_, gyjá, дмар, cska, 
   {{0x7aec2a4e,0x1ea800ec,0x00000000,0x00000000}},	//   soat, _خاڪي_, --, --, 
   {{0x7aecba9f,0xba186883,0x3b080213,0x00000000}},	//   poat, _ويدا_, pmaq_, --, 
   {{0x2f2400e2,0xb5fc3493,0x6d8800e5,0x00000000}},	//   _jēga_, _obšt, _امیہ_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x39040014,0x05740a52,0x25b00158,0x00000000}},	//   _آوسٲ, عاند, øyla_, --, 
   {{0x6ef40998,0x6d44baa0,0x798cbaa1,0x5ae80327}},	//   sábi, zska, lvaw, _རྩོམ, 
   {{0x6d4458de,0xf1d00228,0x11a401d5,0xef24000d}},	//   yska, көлө, зйиқ_, üüme_, 
   {{0x6f140784,0x14c8005b,0xe16001c8,0x00000000}},	//   _riyc, _лыжи_, نگوي, --, 
   {{0x798c6c35,0x2ef00ea0,0x00000000,0x00000000}},	//   ivaw, _skyf_, --, --, 
   {{0x5f4004da,0x6d440210,0x2f2400ef,0x00000000}},	//   پچىل, wska, _bēga_, --, 
   {{0x6d44baa2,0x0dc8001f,0x00000000,0x00000000}},	//   tska, _ጽሁፍ_, --, --, 
   {{0x6d44baa3,0x205400f7,0x6f14baa4,0x78a40175}},	//   uska, чтөр, _viyc, kjhv, 
   {{0x9f600798,0x17240327,0x00000000,0x00000000}},	//   óvão_, རྩོམ_, --, --, 
   {{0x6f141529,0x798c0472,0xaec42d29,0x98b00118}},	//   _tiyc, evaw, _обкл, ždět_, 
   {{0x6d44baa5,0xed58084c,0xfaf40212,0x3d18121d}},	//   pska, _дои_, ечую, _यूके_, 
   {{0xe9d8baa6,0xad240131,0x00000000,0x00000000}},	// [f180] цка_, _تىخى, --, --, 
   {{0x7ae80bb8,0x2d900223,0x6ab40af9,0xdb0400e4}},	//   četa, _irye_, skyf, ryjá, 
   {{0xeb500137,0x00000000,0x00000000,0x00000000}},	//   _جۉزگ, --, --, --, 
   {{0xd1d80125,0x2d9002d3,0x69241621,0x798c0099}},	//   ፖርት_, _krye_, _омма, bvaw, 
   {{0x1040001f,0x963002d5,0x85e400db,0x1b000117}},	//   ቨስትመ, тніц, رۋئن, _рӯён, 
   {{0x6498baa7,0x84380597,0xf60839b1,0xe7380117}},	//   ютер_, أكثر_, ستنه_, _мег_, 
   {{0xf41000eb,0x00000000,0x00000000,0x00000000}},	//   _স্বর_, --, --, --, 
   {{0xe2a801d5,0x14200352,0x00000000,0x00000000}},	//   تاتن_, ндәм, --, --, 
   {{0xe5040691,0xa2c81b61,0x00000000,0x00000000}},	//   _قبطي, तोष्, --, --, 
   {{0x5500824d,0xe3b406ed,0x00000000,0x00000000}},	//   _апуб, _осеќ, --, --, 
   {{0x2d900223,0x798c006f,0x00000000,0x00000000}},	//   _arye_, zvaw, --, --, 
   {{0x7d040270,0xa2c81a47,0x00000000,0x00000000}},	//   _shhs, तोश्, --, --, 
   {{0x5634010f,0x00000000,0x00000000,0x00000000}},	//   ואכע_, --, --, --, 
   {{0xbca400c6,0x101000e5,0x00000000,0x00000000}},	//   رمزي, عبید, --, --, 
   {{0x2d9004ba,0x2fc80198,0x80d001d9,0x7f9400db}},	//   _erye_, _ƙage_, _لۅکچ, _чайх, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7e7cbaa8,0xbc94009b,0x00000000,0x00000000}},	// [f190] mesp, _запј, --, --, 
   {{0xb8f40f1b,0xd874baa9,0xfba400c7,0xe2a001ec}},	//   ركاب, بارب, _зымҽ, _ﺃﻗﻴﻡ_, 
   {{0x8bc400c0,0xf7e4072d,0x00000000,0x00000000}},	//   _асяд, رآئی, --, --, 
   {{0x7e7cbaaa,0xcf9000c8,0x3eb8baab,0x00000000}},	//   nesp, כטע_, nkst_, --, 
   {{0x6ef4baac,0x3a2804c6,0xc9840124,0x668007d6}},	//   cábu, mcap_, _иури, دیقل, 
   {{0x04c80c8b,0x7e7c9f58,0x850401d5,0xc48402d5}},	//   ووني_, hesp, نونن, клік, 
   {{0x7e7c1be9,0xa6c801a9,0x3a280051,0x00000000}},	//   kesp, mpаn, ocap_, --, 
   {{0x7158165d,0x7e7cbaad,0x3a28baae,0x3b1802d1}},	//   прос_, jesp, ncap_, _jisq_, 
   {{0x7e7cbaaf,0x3948bab0,0x80a8009e,0x00000000}},	//   desp, nsas_, গসন্, --, 
   {{0x3948bab1,0x3a280369,0xdb0401f4,0x00000000}},	//   isas_, hcap_, lyjä, --, 
   {{0x7e7c045a,0x6ff4009d,0x35a40037,0x6ef40419}},	//   fesp, эчих, _खपड़, zábu, 
   {{0x3948bab2,0x2d900100,0x00000000,0x00000000}},	//   ksas_, _prye_, --, --, 
   {{0x3a280175,0xcbdc0154,0x3948007c,0xa6e003b2}},	//   dcap_, _ধরেছ, jsas_, íðil, 
   {{0x2d900660,0xafe43129,0x39489e7a,0x00000000}},	//   _vrye_, _полл, dsas_, --, 
   {{0x7e7cbab3,0x3948bab4,0xa2a402ab,0x0ce03ec5}},	//   besp, esas_, टॉक्, _नदीम, 
   {{0x7e7c127b,0xa9a4016c,0x3eb81a80,0xee381180}},	//   cesp, нибд, ckst_, _эни_, 
   {{0x2d9000ca,0x00000000,0x00000000,0x00000000}},	// [f1a0] _urye_, --, --, --, 
   {{0xccb40139,0x00000000,0x00000000,0x00000000}},	//   _рәмь, --, --, --, 
   {{0x6bd40133,0x39481db0,0x6b641d9c,0xaa440835}},	//   _ستدر, asas_, _якна, _пенл, 
   {{0xb75800d4,0x394800c0,0xa9a401a9,0xe9a40108}},	//   ьшує_, bsas_, _зимд, _замп, 
   {{0xdddc0784,0x2b480009,0x39480332,0x3a140354}},	//   _kaqš, lsbc_, csas_, _аьрс, 
   {{0x7e7c0341,0x884801b9,0x83f80353,0x00000000}},	//   zesp, _آیاق_, мелс_, --, 
   {{0x7e7cbab5,0xd464026a,0x672c0158,0x77900133}},	//   yesp, хије_, _utbj, _پینا, 
   {{0x93907cf6,0xd25400a8,0x1b78010f,0x7e7c03ac}},	//   اجوا, нць_, פטפע, xesp, 
   {{0x7e7cbab6,0x00000000,0x00000000,0x00000000}},	//   vesp, --, --, --, 
   {{0xd1b410fe,0x7e7cbab7,0xa3b800e5,0x00000000}},	//   عايا_, wesp, _ٹائر_, --, 
   {{0x0f200b2c,0xb424072d,0xdecc0092,0x00000000}},	//   льям, _شعلو, _ባሮክ_, --, 
   {{0x39482aff,0x6d58033f,0x7e7c017a,0x442c007c}},	//   ysas_, ątan, uesp, _hfd_, 
   {{0x3b18025c,0x00000000,0x00000000,0x00000000}},	//   _risq_, --, --, --, 
   {{0x7e7cbab8,0x442c0175,0xda0400e1,0x00000000}},	//   sesp, _jfd_, _शरबत_, --, 
   {{0x39480227,0xec180daf,0xdb20bab9,0x3a28037e}},	//   wsas_, дерә_, اوری, tcap_, 
   {{0xf9887cbc,0x3948baba,0x442c0010,0x7ae882c7}},	//   ونزي_, tsas_, _lfd_, četo, 
   {{0x3948babb,0x38c800dd,0xa0280023,0x99d41bf4}},	// [f1b0] usas_, وائی_, _ተሓድሶ, رترا, 
   {{0x442c7c86,0x3b18babc,0x00000000,0x00000000}},	//   _nfd_, _wisq_, --, --, 
   {{0x3948babd,0x3a280051,0x972001d3,0xdb04005b}},	//   ssas_, pcap_, اہرو, tyjä, 
   {{0xd3a006b3,0x6ef402f0,0x35b401ec,0xaadc00bc}},	//   ғлиқ, lábr, кбер, _नआएक, 
   {{0x442c0334,0x0c040014,0x00000000,0x00000000}},	//   _bfd_, _لویُ, --, --, 
   {{0x442c1b08,0xdb04023a,0xd800010a,0x060820c8}},	//   _cfd_, syjä, _йăл_, хнік_, 
   {{0x442c2076,0x00000000,0x00000000,0x00000000}},	//   _dfd_, --, --, --, 
   {{0x442cbabe,0x22900131,0x81cc03d4,0x1db02429}},	//   _efd_, للىس, _শুই_, ुनात, 
   {{0x0574babf,0xa154026a,0x442cbac0,0x46f4bac1}},	//   _مالد, вању_, _ffd_, _счёт, 
   {{0x45d48271,0xe0d4034b,0x00000000,0x00000000}},	//   _соус, квы_, --, --, 
   {{0xafe4036b,0xe518000d,0xaf04022e,0x00000000}},	//   тонл, _फूटि_, кпол, --, 
   {{0x442c00ca,0x1ccc031c,0x2eb401af,0x1284020c}},	//   _zfd_, ྱིའ_, тсос, _سمتی_, 
   {{0x2d804fa5,0x7ae80118,0xdb0c0241,0x00000000}},	//   uwke_, četl, _àdùk, --, 
   {{0xa1540375,0xca4c0150,0x99d800cc,0x00000000}},	//   _יבנה_, _ﺍﻻﺘ_, _দৰ্ক, --, 
   {{0x316c20ef,0xdca0bac2,0x6b6402e8,0x00000000}},	//   ltez_, шари, ъква, --, 
   {{0x316c0789,0xdaa000d1,0x00000000,0x00000000}},	//   otez_, لەپپ, --, --, 
   {{0x316cbac3,0x68e0bac4,0xece812d7,0x6da43605}},	// [f1c0] ntez_, éodo, _одил_, _рипа, 
   {{0xe738bac5,0x316c4a85,0x2b48009a,0xaac4000d}},	//   деж_, itez_, psbc_, रोजक, 
   {{0x6fc002ab,0x442c017a,0x316c01c4,0xe664009d}},	//   शनिं, _rfd_, htez_, втло, 
   {{0xdd8c6071,0x316cbac6,0x442cbac7,0xa92002d2}},	//   _اوی_, ktez_, _sfd_, _óþok, 
   {{0x96600166,0x00000000,0x00000000,0x00000000}},	//   ркче, --, --, --, 
   {{0x1ccc081f,0xb3ac03d4,0x00000000,0x00000000}},	//   ྱིར_, _কেইজ, --, --, 
   {{0x18640131,0x2908014f,0x316c0129,0x38040107}},	//   _шари_, _ihba_, etez_, _борҳ, 
   {{0x442c025c,0x316c0356,0x6ef402f0,0x80d4bac8}},	//   _wfd_, ftez_, zábr, योने, 
   {{0x442c051f,0xa6e00162,0x5af8011a,0x00000000}},	//   _tfd_, íðul, ולקצ, --, 
   {{0x443808a5,0x00000000,0x00000000,0x00000000}},	//   _ýr_, --, --, --, 
   {{0x1ccc081f,0x2fc80198,0x249c0175,0x28b8000d}},	//   ྱིལ_, _ƙaga_, _intm_, _इवनि, 
   {{0xe314bac9,0x26c447a5,0xe80809bb,0x00000000}},	//   _شباب, nhoo_, _वरना_, --, 
   {{0x316c0231,0x26c40270,0x2908047e,0x25a4004e}},	//   ctez_, ihoo_, _ohba_, nxol_, 
   {{0x69d8013f,0x3ce40254,0x00000000,0x00000000}},	//   _ɛtet, õlv_, --, --, 
   {{0x248c01ab,0x7ce40228,0x00000000,0x00000000}},	//   idfm_, _ۅزدۅ, --, --, 
   {{0x29080014,0x00000000,0x00000000,0x00000000}},	//   _ahba_, --, --, --, 
   {{0x26c4baca,0x00000000,0x00000000,0x00000000}},	// [f1d0] dhoo_, --, --, --, 
   {{0x9f580ca8,0x00000000,0x00000000,0x00000000}},	//   _àpó_, --, --, --, 
   {{0x316c5dbf,0xd800074d,0x0ee800e5,0xd1e40240}},	//   ztez_, рăн_, _سٹیٹ_, _ማያት_, 
   {{0x95b0723c,0x26c400ad,0x00000000,0x00000000}},	//   ирлә, ghoo_, --, --, 
   {{0xded00023,0x316c0129,0x00000000,0x00000000}},	//   ከሎና_, xtez_, --, --, 
   {{0x26c4136d,0x80d43c71,0xf504bacb,0x41d0000d}},	//   ahoo_, योमे, ызло, _तेइस, 
   {{0x84640395,0x00000000,0x00000000,0x00000000}},	//   ръче, --, --, --, 
   {{0x77900050,0x26c4198f,0x316c20ef,0x237406f6}},	//   _پیچا, choo_, ttez_, اميد_, 
   {{0x316c20ef,0xf4340064,0x4144839a,0x6fc407b7}},	//   utez_, _безэ, адың, ानभू, 
   {{0x316cbacc,0x6da4023b,0xf1a40209,0x6fa80114}},	//   rtez_, ҳима, врүн, евог_, 
   {{0x316cbacd,0x7ae80219,0x00000000,0x00000000}},	//   stez_, četj, --, --, 
   {{0xed58bace,0x316cbacf,0xada401c0,0xb8e4031c}},	//   ном_, ptez_, гамл, _ཏཾ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x409402e8,0x00000000,0x00000000,0x00000000}},	//   _врът, --, --, --, 
   {{0xf1b800a2,0x00000000,0x00000000,0x00000000}},	//   lyš_, --, --, --, 
   {{0x2908044e,0x26c40218,0x00000000,0x00000000}},	//   _shba_, xhoo_, --, --, 
   {{0x9f580248,0xf1d8000d,0x00000000,0x00000000}},	// [f1e0] _àpò_, _बेमन, --, --, 
   {{0x3324011c,0x00000000,0x00000000,0x00000000}},	//   _oulx_, --, --, --, 
   {{0x26c401af,0x5c94010f,0x00000000,0x00000000}},	//   thoo_, _עכטע_, --, --, 
   {{0x25a400db,0xaaf800d4,0x3688346d,0xf1b8010e}},	//   txol_, _їхнє_, ксін_, kyš_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x26c4bad0,0x4904bad1,0x2608033f,0x25a4022e}},	//   shoo_, _түзг, ़ेगी_, rxol_, 
   {{0x66e4414a,0x26c4bad2,0x645c00db,0x249c0051}},	//   _бова, phoo_, òpiq, _vntm_, 
   {{0x52800075,0xb060025a,0x4154bad3,0xc298bad4}},	//   ملىك, ïäng, авис, тких_, 
   {{0xe4d818fd,0x00000000,0x00000000,0x00000000}},	//   _كورت_, --, --, --, 
   {{0x249c0241,0x656001f4,0xe50400ae,0x00000000}},	//   _untm_, muoh, _إبري, --, 
   {{0x6560bad5,0x80c80c58,0x1858010f,0xa26400ec}},	//   luoh, ৰকল্, עכטע, _مٿاه, 
   {{0x6448bad6,0x6144bad7,0x9ec40214,0x00000000}},	//   lafi, _беда, ازده, --, 
   {{0x91b4007b,0x00000000,0x00000000,0x00000000}},	//   _مطور_, --, --, --, 
   {{0x2244005a,0x7f942fc3,0xfb34009d,0x00000000}},	//   _heok_, _вакх, ингэ, --, 
   {{0x65600418,0x22440e02,0x2124005b,0x8fa00114}},	//   huoh, _keok_, _huoh_, _гаје, 
   {{0x6448bad8,0x60d8bad9,0x6560bada,0x00000000}},	//   hafi, litm, kuoh, --, 
   {{0x6448badb,0x7ce40228,0x00000000,0x00000000}},	// [f1f0] kafi, _ۅزگۅ, --, --, 
   {{0x60d845a7,0x6448badc,0x2244badd,0x6560000d}},	//   nitm, jafi, _leok_, duoh, 
   {{0x6448bade,0x00000000,0x00000000,0x00000000}},	//   dafi, --, --, --, 
   {{0x9a84016c,0x60d8badf,0x00000000,0x00000000}},	//   _суол, hitm, --, --, 
   {{0x35a4bae0,0x6448bae1,0x60d8bae2,0x864400d4}},	//   ралг, fafi, kitm, сніж, 
   {{0x09e0003d,0x6448bae3,0xd7f8bae4,0x00000000}},	//   _སྨྲ_, gafi, _зуб_, --, 
   {{0x60d8bae5,0x00000000,0x00000000,0x00000000}},	//   ditm, --, --, --, 
   {{0x64480421,0x6560bae6,0xb224070e,0x00000000}},	//   aafi, buoh, шмил, --, 
   {{0x645cbae7,0x6448bae8,0x2244020b,0x2fc80198}},	//   ópic, bafi, _deok_, _ƙago_, 
   {{0x60d80d04,0xe1f40022,0x00000000,0x00000000}},	//   gitm, ргь_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xccf825f8,0x60d8bae9,0x3dd800cc,0x00000000}},	//   лқи_, bitm, _ধুবল, --, 
   {{0x60d8baea,0x6c34007b,0x00000000,0x00000000}},	//   citm, شفرا, --, --, 
   {{0xab281606,0x00000000,0x00000000,0x00000000}},	//   тоба_, --, --, --, 
   {{0x6448baeb,0xdce40421,0xdee00395,0x00000000}},	//   zafi, āmāi, _мощи, --, 
   {{0xe8f8baec,0xa8340aa0,0x2bd4772c,0x684401c6}},	// [f200] вла_, لعاش, _डेरा, инаа, 
   {{0x64480014,0x2794baed,0xe80827f2,0xa81802f2}},	//   xafi, ишер, _वरदा_, نتار_, 
   {{0x5c58025f,0x6448baee,0xc5b400f7,0x7de430fe}},	//   _בדיק, vafi, өрдө, _نسیم, 
   {{0x6448baef,0x65600522,0x60d800d7,0x00000000}},	//   wafi, tuoh, zitm, --, 
   {{0xe4a407d6,0x377401ec,0x00000000,0x00000000}},	//   ирко, _қырс, --, --, 
   {{0xd9407d17,0x22440263,0xc448baf0,0xd8400122}},	//   _фери, _seok_, ایان_, ručí_, 
   {{0x6448baf1,0x1af80154,0x60d80455,0x65600108}},	//   rafi, ্দরে_, vitm, suoh, 
   {{0x6448baf2,0x66e4074d,0x60d8017a,0x0cb400cd}},	//   safi, _тоба, witm, ुसुम, 
   {{0x6448baf3,0x7ae00077,0x67d400ee,0x60d80129}},	//   pafi, élti, _соңу, titm, 
   {{0x7ae80e04,0x6448013c,0x62640131,0x00000000}},	//   četi, qafi, _چاشق, --, 
   {{0x3f980122,0x00000000,0x00000000,0x00000000}},	//   íru_, --, --, --, 
   {{0xd36c03e6,0x00000000,0x00000000,0x00000000}},	//   _زهه_, --, --, --, 
   {{0xd24c07d6,0x3f980115,0x00000000,0x00000000}},	//   _آنه_, ŭru_, --, --, 
   {{0x91b80375,0x00000000,0x00000000,0x00000000}},	//   _במדי, --, --, --, 
   {{0x01e8015b,0xd00cbaf4,0xbae4007b,0x5b24475a}},	//   _পরিদ, _قله_, مكسي, рьга, 
   {{0x8aa4baf5,0x9d2800c7,0xdd0c03b9,0xe8980092}},	//   оруд, _ицоз_, _fışq, _ለማገዝ_, 
   {{0x7e6cbaf6,0xd91801c0,0xc0ec001f,0x787800ee}},	// [f210] _icap, вьж_, ቅጠር_, лйар_, 
   {{0xc3241c5c,0x4ddc0302,0xb7880daf,0x7e6c0165}},	//   _يە_, _שחזו, ләбе_, _hcap, 
   {{0x97a4497c,0x7c245da9,0xd1c4010c,0x2c74009f}},	//   шрал, _ighr, _ሽፍታ_, _اُپس, 
   {{0x2b5c00bc,0xdfc401d3,0x1da80073,0x41b8043e}},	//   átce_, _ہي_, _चपात, ेनास, 
   {{0xdfc400aa,0x8e9802e4,0x955401d3,0x7afcbaf7}},	//   _ځي_, ידאו_, شیاء_, _ikst, 
   {{0xdfc4baf8,0x7e6c0175,0x00000000,0x00000000}},	//   _في_, _lcap, --, --, 
   {{0x2aac00a2,0x7afc0010,0xb38401b9,0x00000000}},	//   _aýby_, _kkst, ёлил, --, 
   {{0x3998069c,0xd6c00345,0x00000000,0x00000000}},	//   _መራሕቲ_, _بمری, --, --, 
   {{0x78b4533a,0x7c2400ad,0x764802d0,0xeaa8008f}},	//   _kozv, _oghr, _ieey, רױפֿ, 
   {{0x7648baf9,0xd4e4bafa,0x7c2403cb,0x00000000}},	//   _heey, _тюби, _nghr, --, 
   {{0x7648bafb,0x339436ba,0x7afc12bb,0xef18022e}},	//   _keey, _دلاز, _okst, лмо_, 
   {{0x7e6c0113,0x7528bafc,0x7c24bafd,0x7520005a}},	//   _ccap, _kuez, _aghr, _hilz, 
   {{0x7528bafe,0xdd0c723e,0x7648baff,0xada400d0}},	//   _juez, _qışq, _meey, _opúš, 
   {{0x76480a81,0x78b40489,0xa5d800c8,0x7afcbb00}},	//   _leey, _nozv, אַלי, _akst, 
   {{0x7520005f,0xa3a81524,0xaf341411,0xe8e80818}},	//   _milz, खमय_, _ارتت, ҳмад_, 
   {{0x95041b4b,0xada40598,0x7c24014f,0x7648bb01}},	//   _ཆེའི_, _гаил, _eghr, _neey, 
   {{0x7528030a,0x00000000,0x00000000,0x00000000}},	// [f220] _nuez, --, --, --, 
   {{0x7afcbb02,0xa848049e,0x6c840597,0x752000d8}},	//   _ekst, الام_, _الدم, _nilz, 
   {{0x78b40552,0x7648bb03,0xa5d80214,0xf1d80073}},	//   _dozv, _beey, گبار_, _बेसन, 
   {{0x6a84352d,0x7528030a,0x76480067,0x7778013e}},	//   _улма, _buez, _ceey, рёфт_, 
   {{0x76481dd0,0x7520bb04,0x20c80073,0xa5d835e6}},	//   _deey, _bilz, िसमध, دبار_, 
   {{0xe5a43ba6,0x1ccc0003,0x78b40369,0x684400cf}},	//   _қизи, ྱིག_, _gozv, _ынга, 
   {{0x41d007b7,0x76480363,0x7afc340f,0xa50814fb}},	//   _तेजस, _feey, _ykst, نىچە_, 
   {{0x7648bb05,0xe618151e,0x78b40165,0xe3b80124}},	//   _geey, _бдб_, _zozv, _ҩба_, 
   {{0xdef84d50,0x75280077,0x7520647e,0xae1801ad}},	//   ғын_, _guez, _filz, नेमन_, 
   {{0x7520bb06,0x7648bb07,0x232875a0,0x00000000}},	//   _gilz, _zeey, _божи_, --, 
   {{0x7648bb08,0x737400c7,0xe1f02a9f,0x00000000}},	//   _yeey, _мыцх, _کسا_, --, 
   {{0x7520bb09,0x20009ec4,0x7648058a,0xc69400df}},	//   _zilz, āki_, _xeey, קאָ_, 
   {{0x0dc8014b,0xf09401d9,0x7afc01ef,0x00000000}},	//   бури_, _ڈُنگ, _rkst, --, 
   {{0x1fa4bb0a,0x7e6c009a,0xff2400b5,0xf1a8bb0b}},	//   _григ, _wcap, _estの, _خامه_, 
   {{0x78b403c6,0x20080037,0xff8801af,0x00000000}},	//   _rozv, übid_, _төпл_, --, 
   {{0x7e6c50f9,0x1ccc0135,0xada40030,0x78b4bb0c}},	//   _ucap, ྱིང_, _spúš, _sozv, 
   {{0x7c2405b1,0x7648090e,0xc9840166,0x00000000}},	// [f230] _tghr, _reey, зухи, --, 
   {{0x7648bb0d,0x9c447e7e,0x58b81867,0x7c2400b8}},	//   _seey, _ухил, دارج_, _ughr, 
   {{0xdde800aa,0x78b40099,0x76481bce,0x7528bb0e}},	//   _جرګه_, _vozv, _peey, _suez, 
   {{0x35a40588,0x8f980375,0x78b4bb0f,0x76480014}},	//   ҩаҧг, טיבי, _wozv, _qeey, 
   {{0x75280c67,0x78b40099,0x752017da,0x23b00131}},	//   _quez, _tozv, _pilz, ېمىس, 
   {{0x7648bb10,0x75280165,0x799c035a,0x64a0365f}},	//   _weey, _vuez, _irsw, даша, 
   {{0x76480de2,0x799c035a,0x80ac2a67,0xb38400d4}},	//   _teey, _hrsw, जाने, ілил, 
   {{0x76480076,0x00000000,0x00000000,0x00000000}},	//   _ueey, --, --, --, 
   {{0x95c8abbf,0x3f9c00af,0x850401d3,0x00000000}},	//   _сува_, _arvu_, _کولن, --, 
   {{0x147400db,0x9474bb11,0x63600521,0x799c4c3e}},	//   _دارج, _ددرا, ịnay, _mrsw, 
   {{0x42c80372,0x3f9c01a6,0x00000000,0x00000000}},	//   ргөн_, _crvu_, --, --, 
   {{0x3f9c01a6,0x0cb41fe7,0x799c02d0,0x92e400cc}},	//   _drvu_, ुस्म, _orsw, _মীৰ_, 
   {{0x9204bb12,0x799c02d0,0xdd8c00ec,0x7094014b}},	//   _اذان, _nrsw, نوَ_, _мадф, 
   {{0xa0643485,0x2f240171,0x00000000,0x00000000}},	//   _даша_, _bēgt_, --, --, 
   {{0xec14bb13,0xdfcc4d49,0x799cbb14,0xa11002f2}},	//   زورد, _ليو_, _arsw, _تووت, 
   {{0x1be400d4,0x00000000,0x00000000,0x00000000}},	//   ідти_, --, --, --, 
   {{0xa968bb15,0x799c03ac,0x692401ec,0x00000000}},	// [f240] риза_, _crsw, імжа, --, 
   {{0x6d5443d6,0x0c6807d6,0x799c02d0,0xec680145}},	//   _ivya, _узоқ_, _drsw, _өрүк_, 
   {{0xd7fc0276,0x799c03ac,0x2570bb16,0xb6540023}},	//   _ţări_, _ersw, wâl_, _ከምዝጀ, 
   {{0x98ac00da,0xd1cc02d3,0x2570bb17,0xe9a401c6}},	//   īgā_, _ብጾት_, tâl_, _дамп, 
   {{0x645c10d8,0x6aa402d0,0x00000000,0x00000000}},	//   ópio, _inkf, --, --, 
   {{0xd1d8069c,0x43940228,0xe7180214,0x25700142}},	//   ሕነት_, закс, _چيست_, râl_, 
   {{0xd46430ba,0xe7182614,0xa3f80011,0x68e00129}},	//   ције_, _نيست_, েখ্য_, éodu, 
   {{0x26c005bb,0x799c03ac,0x00000000,0x00000000}},	//   _ôko_, _yrsw, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3f9c04b9,0xa508404b,0x6aa40175,0x6560bb18}},	//   _prvu_, _теза_, _lnkf, mroh, 
   {{0xf3ec0364,0xd1b400dd,0x6d54bb19,0x78a0007f}},	//   _чӣ_, مایا_, _avya, _ólve, 
   {{0x65600109,0x3ce40220,0x956c0023,0x00000000}},	//   oroh, _ﺍﻳﺘﻤ, _ኣኼባን_, --, 
   {{0x6560bb1a,0x171800c8,0x6d540055,0x00000000}},	//   nroh, יוטע, _cvya, --, 
   {{0x6aa4127b,0x65600810,0x6d54002b,0x00000000}},	//   _ankf, iroh, _dvya, --, 
   {{0x2d9c0374,0xda48487f,0x00000000,0x00000000}},	//   ātea_, ичал_, --, --, 
   {{0xb7880032,0x799c02d0,0x6560bb1b,0x00000000}},	//   ҙәге_, _prsw, kroh, --, 
   {{0x645801f1,0xa3c84709,0x00000000,0x00000000}},	// [f250] _odti, रैत_, --, --, 
   {{0x6560bb1c,0xa3a8012c,0x645c0077,0x6ef403b2}},	//   droh, खमा_, ópil, dáby, 
   {{0x65600124,0x6d540139,0x00000000,0x00000000}},	//   eroh, _zvya, --, --, 
   {{0x0f780302,0x6458bb1d,0xdaa00131,0xabf80375}},	//   שראל, _adti, _تەرپ, _להתר, 
   {{0x799c02d0,0x00000000,0x00000000,0x00000000}},	//   _ursw, --, --, --, 
   {{0x6458005a,0x798cbb1e,0x66ec01e4,0x5fc84195}},	//   _cdti, mwaw, rĝka, ानाल, 
   {{0x6560014b,0x32080113,0x798c0a49,0x07680024}},	//   aroh, _šay_, lwaw, _маёй_, 
   {{0x42b80075,0xdffc0cb4,0x6560000d,0x64580162}},	//   قنىڭ_, _उड़द_, broh, _edti, 
   {{0x65602b6a,0x798c1dcb,0xe1f000e5,0x00000000}},	//   croh, nwaw, ٹسٹ_, --, 
   {{0xf8bc5f46,0x6d54002b,0xd1d80023,0x00000000}},	//   ोसिय, _rvya, ሕነቱ_, --, 
   {{0x798cbb1f,0x6d5428e5,0x7e6801e4,0x2f2400ef}},	//   hwaw, _svya, ϲept, _rēgs_, 
   {{0x798cbb20,0x952c02d3,0x60c80112,0x02a401c0}},	//   kwaw, _ብሃንደ, _elfm, _орчм, 
   {{0xe0ccbb21,0xb0b801c0,0x6b9c02d0,0x71a401c6}},	//   _зв_, _гуйх_, _srpg, _халз, 
   {{0x798c0bd7,0xc104009f,0xa6c8022e,0x00000000}},	//   dwaw, _قوني, npаr, --, 
   {{0x6f04074d,0x30f801d9,0xeb98117e,0x00000000}},	//   plkc, _پوژھ_, щив_, --, 
   {{0x798c0161,0x65600240,0x28dc03e5,0x6d540009}},	//   fwaw, yroh, फोनि, _tvya, 
   {{0x798cbb22,0x00000000,0x00000000,0x00000000}},	// [f260] gwaw, --, --, --, 
   {{0x2d900100,0xedf400f2,0x65600200,0x00000000}},	//   _isye_, _ويژگ, vroh, --, 
   {{0x66e49fb7,0x29e00135,0xa68400ee,0xa9680107}},	//   пожа, _sħaħ_, злед, риҷа_, 
   {{0x798c2252,0x6560bb23,0x6aa403ac,0x6a84004e}},	//   bwaw, troh, _unkf, _элма, 
   {{0xa5081d83,0x7c6407d6,0xd6cc00e3,0x69c801e4}},	//   беда_, _عایل, دقن_, ĝfes, 
   {{0x2d90bb24,0x6560bb25,0x6ef41427,0x00000000}},	//   _msye_, rroh, ráby, --, 
   {{0x65600086,0x18a001c6,0xe6440815,0x6ef4148b}},	//   sroh, _яарм, _невп, sáby, 
   {{0x76400022,0x6560bb26,0x3f98bb27,0x21640137}},	//   _аҭца, proh, ærum_, птог, 
   {{0x672c01fa,0xeff01772,0x2918009f,0x142091cb}},	//   _hubj, ጂካዊ_, ompa_, мдәм, 
   {{0x26c4bb28,0xbf042017,0x1ccc0327,0xfbe00154}},	//   lkoo_, रत्न_, ྱིབ_, _মুফত, 
   {{0x2d90bb29,0x798c0810,0x66ec0115,0xfbe000eb}},	//   _asye_, zwaw, nĝko, _মুনত, 
   {{0x26c4bb2a,0x0b0009bd,0x798c0309,0x68fc047e}},	//   nkoo_, ্দুল_, ywaw, hopd, 
   {{0x68fc0936,0x26c4947b,0xf1a8bb2b,0x672cbb2c}},	//   kopd, ikoo_, _واهه_, _lubj, 
   {{0x2cb8bb2d,0x00000000,0x00000000,0x00000000}},	//   _copd_, --, --, --, 
   {{0x26c4bb2e,0x2d90007f,0x798c0e14,0x00000000}},	//   kkoo_, _esye_, wwaw, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3ea814fd,0x798c01f7,0x26c40067,0x955c0023}},	// [f270] _inat_, uwaw, dkoo_, ሰባትን_, 
   {{0x798cbb2f,0x7e7cbb30,0x3ea8022e,0x9534013e}},	//   rwaw, lfsp, _hnat_, ҷҷат_, 
   {{0x41c8012c,0x798c006f,0x5724bb31,0x7b1401c4}},	//   ाईँस, swaw, سراق, _одох, 
   {{0x672cac19,0x2bd42f0a,0x291801f4,0xc6a40114}},	//   _dubj, _डेटा, ampa_, ерљи, 
   {{0x7aecbb32,0x3a38bb33,0xc984bb34,0x5fdc01ad}},	//   mnat, _ifsp_, _пури, _फेसल, 
   {{0xe5a084cc,0x2eb80a28,0x3b08bb35,0x26c40093}},	//   тиши, _उक्त, llaq_, akoo_, 
   {{0x26c4058a,0x3ea8010b,0x37c41541,0xc3040133}},	//   bkoo_, _onat_, _غيرف, کبوو, 
   {{0x26c4bb36,0x2324722e,0x7e7c0196,0x3ea8011f}},	//   ckoo_, мощи_, jfsp, _nnat_, 
   {{0x7aecbb37,0xfbe002f5,0x854400ee,0x45d401a9}},	//   inat, _মুমত, _зэхе, _зотс, 
   {{0x3ea8bb38,0x3b083223,0x7e7c1730,0x7aecbb39}},	//   _anat_, hlaq_, efsp, hnat, 
   {{0x7aecbb3a,0x7e7cbb3b,0xc0ec0023,0x3f9801bf}},	//   knat, ffsp, ቅበሎ_, årup_, 
   {{0x926401ec,0x63e401ec,0x3a380009,0x00000000}},	//   _ءدام, _تيمە, _nfsp_, --, 
   {{0x3ea8026c,0xa3080014,0xf1d0941b,0x39580175}},	//   _dnat_, _برٕے_, _шөкө, _nvss_, 
   {{0xab282081,0x3ea8bb3c,0xc0ec0023,0x7e7c005c}},	//   жова_, _enat_, ቅበል_, afsp, 
   {{0x1d04bb3d,0x7aecbb3e,0x6ef40327,0x00000000}},	//   фери_, fnat, eġbe, --, 
   {{0x3a38031c,0xdd8c05d9,0x672c8860,0x00000000}},	//   _cfsp_, _چوي_, _rubj, --, 
   {{0xdd8c021a,0x672cbb3f,0xa924bb40,0x7bd4011c}},	// [f280] _نوي_, _subj, ддал, azzu, 
   {{0x7aec1311,0x3ea870b1,0x6d909358,0x186456a1}},	//   anat, _znat_, ržać, дафи_, 
   {{0x68fcbb41,0x7aecbb42,0xfbe000fe,0x26c4083e}},	//   ropd, bnat, _মুঠত, tkoo_, 
   {{0x68fcbb43,0x26c4208d,0xb6c402bf,0x7aecbb44}},	//   sopd, ukoo_, нсій, cnat, 
   {{0x26c4bb45,0xd83c0010,0x35c40124,0x00000000}},	//   rkoo_, žčas_, нацҳ, --, 
   {{0x26c4bb46,0xca880023,0x00000000,0x00000000}},	//   skoo_, _ሒዝኩም_, --, --, 
   {{0xd820bb47,0x7e7c017a,0x82480092,0x00000000}},	//   _адри, yfsp, _ያበረታ, --, 
   {{0x52800075,0xa6a8030c,0x00000000,0x00000000}},	//   نلىك, _باسق_, --, --, 
   {{0x50440020,0x69d4bb48,0x456401d3,0x00000000}},	//   _የአካባ, nzye, _سپاہ, --, 
   {{0x7aec04b9,0xd36c2651,0x2d9c05d5,0x2ef00208}},	//   znat, _چهل_, ātel_, _ajyf_, 
   {{0x7aecbb49,0x3ea803a2,0x80d400dc,0xe6940cad}},	//   ynat, _pnat_, योगे, _àkóó, 
   {{0xa1c47413,0xc68c0020,0x6f14bb4a,0x7e7c0e78}},	//   _обед, _መምሪያ_, _chyc, ufsp, 
   {{0x7aecbb4b,0x6280bb4c,0x2b58004e,0x7e7c28dc}},	//   vnat, _iboo, _avpc_, rfsp, 
   {{0x7e7c074d,0x7aecbb4d,0x249c0092,0x3f580022}},	//   sfsp, wnat, ቀበሉት_, pĩu_, 
   {{0x7aecbb4e,0x3b08bb4f,0x7bd4bb50,0x00000000}},	//   tnat, tlaq_, uzzu, --, 
   {{0x7aecbb51,0x3ea81c06,0x7ce80b4b,0x3b080194}},	//   unat, _unat_, džre, ulaq_, 
   {{0x62803d27,0x66140209,0x442c01c7,0x3b08bb52}},	// [f290] _mboo, ýykl, _ogd_, rlaq_, 
   {{0x7aecbb53,0x628002fa,0xc8f40107,0xbb940212}},	//   snat, _lboo, взуъ, _заощ, 
   {{0x7d040a2e,0x6280384e,0x7aecbb54,0x2f1001d3}},	//   _ikhs, _oboo, pnat, lága_, 
   {{0xa29c038e,0x99640801,0x3a3805d5,0x442c033f}},	//   _खोल्, _отгл, _ufsp_, _agd_, 
   {{0x442cbb55,0x69f00137,0xaa38011a,0x628401e4}},	//   _bgd_, _бүтт, _מתרח, ĵkol, 
   {{0x6280bb56,0xd7f83b2b,0x85440262,0xdc2000eb}},	//   _aboo, _дуб_, тэце, _ব্যস_, 
   {{0xa3c800ab,0x32d00241,0xf1d0012c,0x36d40120}},	//   रैल_, _láye_, दैनन, _зовр, 
   {{0x9f5801e1,0x00000000,0x00000000,0x00000000}},	//   _ápù_, --, --, --, 
   {{0x15f08360,0x3124bb57,0x442c00d5,0x3074bb58}},	//   _आखिर_, ндиг, _fgd_, нунс, 
   {{0x442c8d28,0x22400724,0x6280bb59,0xd344006c}},	//   _ggd_, ıkka_, _eboo, _قیته_, 
   {{0x09bc01d9,0x62800334,0x7bc00162,0x00000000}},	//   _ईथ्य, _fboo, ølul, --, 
   {{0x6280bb5a,0x61e801ed,0x7d04009f,0xd1b80014}},	//   _gboo, ámlá, _akhs, _واشا_, 
   {{0x7d04009f,0x6224005e,0x00000000,0x00000000}},	//   _bkhs, _كومە, --, --, 
   {{0x170c0156,0x00000000,0x00000000,0x00000000}},	//   _ཏེའམ_, --, --, --, 
   {{0x316cbb5b,0x80ac05d7,0x6f140142,0x6b64bb5c}},	//   luez_, जारे, _thyc, эква, 
   {{0x2d9400d6,0x32d00241,0x316c0165,0x80b00150}},	//   _зрос, _fáye_, ouez_, _مەۋش, 
   {{0xe9d80b16,0x316cabbd,0x68441920,0x87ec00eb}},	// [f2a0] чка_, nuez_, енза, _করেছ_, 
   {{0x69d41529,0x0ea801f9,0x00000000,0x00000000}},	//   rzye, गाकड, --, --, 
   {{0x26101025,0x00000000,0x00000000,0x00000000}},	//   _तरही_, --, --, --, 
   {{0x442cbb5d,0x316c005a,0xe61800ee,0x48c4035b}},	//   _sgd_, kuez_, пде_, хәҭа, 
   {{0x442cbb5e,0xd544ac57,0x96300816,0x00000000}},	//   _pgd_, епче_, уніц, --, 
   {{0x316c005a,0xb864009f,0x628401e4,0x02c800cd}},	//   duez_, _لافو, ĵkom, िघ्न, 
   {{0x23240945,0x442c0212,0xa3c84244,0x00000000}},	//   нфиг, _vgd_, रैं_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x442c0171,0x62800332,0x228001d5,0x00000000}},	//   _tgd_, _vboo, rаk_, --, 
   {{0x442c008b,0x44380139,0x00000000,0x00000000}},	//   _ugd_, _ür_, --, --, 
   {{0x8d8400d1,0x00000000,0x00000000,0x00000000}},	//   һурд, --, --, --, 
   {{0xa3c80882,0x316c06af,0x62800bfa,0x81c00150}},	//   रैः_, buez_, _uboo, _نەعۇ, 
   {{0x98a0033b,0x3cfc0118,0x00000000,0x00000000}},	//   _sijč_, लकले_, --, --, 
   {{0x10a00063,0x248c0051,0x2f10398f,0x00000000}},	//   _биљн, nefm_, rága_, --, 
   {{0x0b8800a8,0x2f1001ed,0x32d001e1,0x00000000}},	//   нсти_, sága_, _wáye_, --, 
   {{0xa0240086,0x6fbc00bc,0x28dc012d,0xdeb00150}},	//   _eköñ, शहरू, फोसि, _сұмы, 
   {{0xbdf40063,0x18640114,0x00000000,0x00000000}},	// [f2b0] _шпиј, ењег, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xec34025f,0x8c640eed,0x316c01c4,0xa2640064}},	//   _באתר_, _стыд, zuez_, dėžę_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3dd80369,0xb5fc0219,0x00000000,0x00000000}},	//   nzsw_, _odše, --, --, 
   {{0xd70407d5,0x81c800fe,0xe8081d94,0x853400f7}},	//   ĕнче_, োপা_, _वरचा_, دووچ, 
   {{0x04b46abd,0xd6d8130f,0xc6a40116,0x20080254}},	//   الىڭ, _ета_, _өрти, übil_, 
   {{0x316cbb5f,0x27ec00d7,0x00000000,0x00000000}},	//   tuez_, úfne_, --, --, 
   {{0x34940588,0x2334009d,0x00000000,0x00000000}},	//   _иаар, нхөр, --, --, 
   {{0xff3c001f,0x316c01c4,0xfbd006ff,0xfd4c01e1}},	//   _የተመዘ, ruez_, सनाम, bulẹ, 
   {{0xb274bb60,0x316cbb61,0x93a401d5,0x6e44bb62}},	//   _алеш, suez_, _яшад, кенз, 
   {{0xed5823c4,0x34380050,0x00000000,0x00000000}},	//   мом_, _رٲچھ_, --, --, 
   {{0x316c0231,0xf1d80034,0x00000000,0x00000000}},	//   quez_, _बेचन, --, --, 
   {{0x9d40bb63,0x80a80073,0x300400d8,0x00000000}},	//   рерд, _झोपे, _излг, --, 
   {{0x09bc16d1,0xac7433ae,0xd0900150,0x00000000}},	//   ोन्य, _یادش, _ашқы, --, 
   {{0x63bc0fac,0x00000000,0x00000000,0x00000000}},	//   øpni, --, --, --, 
   {{0xaa9400d1,0x00000000,0x00000000,0x00000000}},	// [f2c0] ниңч, --, --, --, 
   {{0x6d44bb64,0xa6c80214,0xdd54011a,0x6ea80b4c}},	//   mpka, ژوال_, _שביט_, टाकु, 
   {{0x6d440254,0x00000000,0x00000000,0x00000000}},	//   lpka, --, --, --, 
   {{0x6d4401a4,0x00000000,0x00000000,0x00000000}},	//   opka, --, --, --, 
   {{0x7c2c045f,0x00000000,0x00000000,0x00000000}},	//   _ûnrê, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd374010b,0x977404b4,0xa6940798,0x00000000}},	//   вчы_, _иттә, _ирај, --, 
   {{0xb864066d,0xc17402e8,0x2bb861ef,0x9c8401ef}},	//   _لاہو, глищ, _उपना, _krčí, 
   {{0xa5240354,0x1fc800bc,0x00000000,0x00000000}},	//   _амад, ान्ड, --, --, 
   {{0xa0a4119e,0x00000000,0x00000000,0x00000000}},	//   тшил, --, --, --, 
   {{0xe29801d5,0x00000000,0x00000000,0x00000000}},	//   _оаж_, --, --, --, 
   {{0xe244099f,0x3eac45a7,0x64480e78,0x98a00171}},	//   _شخصي, ñet_, lbfi, _mijā_, 
   {{0x2000068f,0x670002e3,0xfcc4104e,0x00000000}},	//   łki_, ọkwa, гәнм, --, 
   {{0x443c037e,0x1fa4bb65,0x00000000,0x00000000}},	//   ncv_, _ариг, --, --, 
   {{0x6d44bb66,0x98a00055,0x00000000,0x00000000}},	//   apka, _nijā_, --, --, 
   {{0x32d001e1,0x443c02e2,0xbf1400db,0x539800df}},	//   _káya_, hcv_, _حوبب, וסלא, 
   {{0xca2488d6,0x29f80208,0x98a00171,0x6d4403ac}},	// [f2d0] аффи, ỏan_, _aijā_, cpka, 
   {{0xf8b8009d,0x00000000,0x00000000,0x00000000}},	//   хөм_, --, --, --, 
   {{0x32d00ca8,0x00000000,0x00000000,0x00000000}},	//   _láya_, --, --, --, 
   {{0x0f34010f,0x47880454,0x00000000,0x00000000}},	//   דראט_, ъсум_, --, --, 
   {{0x09e40153,0x00000000,0x00000000,0x00000000}},	//   _воўн, --, --, --, 
   {{0x5fc005f9,0x2bb800cd,0x57a401ee,0x00000000}},	//   शहाल, _उपमा, _ишба, --, 
   {{0xa56012b7,0x7414bb67,0x7bc003b2,0x00000000}},	//   لگەن, دوغا, øluh, --, 
   {{0x32d0bb68,0xe3a4034c,0x0574bb69,0xc6a43da1}},	//   _báya_, اشوی, _چالد, _круи, 
   {{0xd49805f5,0x64484032,0xb4e802dd,0x443c0129}},	//   _орж_, bbfi, _كىرم_, bcv_, 
   {{0x7658bb6a,0x203802d3,0x00000000,0x00000000}},	//   lawy, _ከበርክ, --, --, 
   {{0xa29c0b4c,0x00000000,0x00000000,0x00000000}},	//   _खोक्, --, --, --, 
   {{0xc2e407d6,0x32d00241,0x932402cb,0x7658bb6b}},	//   _кўчи, _fáya_, _شران, nawy, 
   {{0xb27400c7,0xca740244,0x317800df,0x00000000}},	//   _алҵш, ینسک, _נאַד, --, 
   {{0xeb980408,0xa3c8033f,0xac08668d,0x50a000d1}},	//   ниг_, रैक_, енга_, _ئەدل, 
   {{0x7658033f,0xfb300092,0x00000000,0x00000000}},	//   kawy, _በቴክኒ, --, --, 
   {{0x6d44bb6c,0x98a80055,0x4a4401ec,0x2d9401ee}},	//   ppka, _rucā_, рмаң, _йөгө_, 
   {{0x6da4bb6d,0x765803cb,0x44200208,0xba54014b}},	// [f2e0] _сипа, dawy, ̀i_, ртсъ, 
   {{0xa908bb6e,0x443c003a,0xea6000e5,0xb864bb6f}},	//   ريال_, xcv_, _گھسی, لامو, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x765800a2,0x00000000,0x00000000,0x00000000}},	//   gawy, --, --, --, 
   {{0x9c840306,0x443c0205,0x00000000,0x00000000}},	//   _určí, tcv_, --, --, 
   {{0xd1d802d3,0x2734129d,0x6c7800df,0x00000000}},	//   ዕነት_, _مىسس, גאַפ, --, 
   {{0x2588044e,0x6448bb70,0x7658010e,0xe00001f9}},	//   _መውጽኢ_, rbfi, bawy, _रुंद_, 
   {{0x937402e8,0x00000000,0x00000000,0x00000000}},	//   убът_, --, --, --, 
   {{0x6f04010f,0x6720bb71,0x990000df,0xe61800d8}},	//   dokc, mmoj, ŝĉer, _чда_, 
   {{0x6720bb72,0x14a801f9,0xdfd8011c,0x00000000}},	//   lmoj, _टोपण, еъм_, --, 
   {{0x2284bb73,0x249c009a,0x11d001d5,0xd1b401d3}},	//   _булг, _iatm_, لتید, نایا_, 
   {{0x249c00a2,0xe31402da,0x9e644e77,0x32d00248}},	//   _hatm_, _صباب, دادن, _táya_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6720bb74,0x3ce4067c,0x9160009f,0x00000000}},	//   hmoj, òlv_, _اهوه, --, 
   {{0x249c0810,0x67200200,0xcb44004e,0xbb94003b}},	//   _matm_, kmoj, йхти, шавщ, 
   {{0x6720bb75,0xef6401c6,0xade400e5,0x00000000}},	//   jmoj, _тэшү, اہیم_, --, 
   {{0xdd84bb76,0x9cc8010b,0x98a8054e,0x66ec01e4}},	// [f2f0] _сыйп, _зына_, _nucă_, nĝku, 
   {{0xc0ec001f,0xd7f80006,0xc9840114,0x67206e98}},	//   ህበሩ_, нуе_, љути, emoj, 
   {{0xd7f839f6,0x97a4bb77,0xb90c0241,0xa7340022}},	//   хуа_, ырал, _kikẹ_, адхә, 
   {{0x67200115,0x200c015d,0xb064000d,0x00000000}},	//   gmoj, _myfi_, onää, --, 
   {{0xb064023a,0x200c032e,0x765848da,0x34940108}},	//   nnää, _lyfi_, rawy, иадр, 
   {{0x67200024,0x98a80311,0x6f0401e4,0xc484155b}},	//   amoj, _ducă_, zokc, йлік, 
   {{0x3948bb78,0x84640395,0x00000000,0x00000000}},	//   lpas_, съче, --, --, 
   {{0x394802f6,0x6f04017a,0x6720036e,0x6ea80118}},	//   opas_, xokc, cmoj, टाछु, 
   {{0x39480bf1,0x37e40598,0xa6e0032e,0xa2801424}},	//   npas_, _соңг, _æðah, تینو, 
   {{0x3948bb79,0x6ad01b6e,0x344801f0,0x66140205}},	//   ipas_, _सत्र, _рӯди_, üyke, 
   {{0x20001395,0xef18bb7a,0x2bb8102f,0xd35c010a}},	//   şkin_, кмо_, _उपधा, _цiач, 
   {{0x3948bb7b,0x200c015d,0x03c40124,0x00000000}},	//   kpas_, _dyfi_, _усум, --, 
   {{0x8234bb7c,0x6f0407d6,0xe0cc5332,0x3948bb7d}},	//   _ارما, rokc, _дв_, jpas_, 
   {{0xe7f80f44,0x2164001b,0x3948bb7e,0x249c022e}},	//   ्थमा_, _тиши_, dpas_, _xatm_, 
   {{0x1be4014b,0x67200200,0x3948139f,0x00000000}},	//   адри_, ymoj, epas_, --, 
   {{0xaa44bb7f,0x39480113,0x316c06af,0x4150001f}},	//   реал, fpas_, orez_, _መቁጠሪ, 
   {{0x394822d0,0x9b000220,0x9f580241,0x00000000}},	// [f300] gpas_, ізуд, _ápò_, --, 
   {{0xdd8c00aa,0x61e42242,0xebe403b7,0x316c0129}},	//   _کوی_, úkli, _вооп, irez_, 
   {{0x3948bb80,0x6934bb81,0x67200115,0x00000000}},	//   apas_, _oņeg, tmoj, --, 
   {{0xe5c4bb82,0xaac8bb83,0x394801f5,0x316c030a}},	//   исло, _रविक, bpas_, krez_, 
   {{0x6720bb84,0xa5d800c6,0x2d8025d8,0x7ae00036}},	//   rmoj, خبار_, ntke_, ëlte, 
   {{0xa29c038e,0x32d001e1,0x29080472,0x6720bb85}},	//   _खोज्, _báyo_, _ukba_, smoj, 
   {{0x316cbb86,0xdb2000e4,0xe4d801b9,0x6638007b}},	//   erez_, _írãn, _یورت_, _لكزس_, 
   {{0x316cbb87,0x32d001e1,0x2d001bf9,0x98a8054e}},	//   frez_, _dáyo_, लकुल_, _tucă_, 
   {{0x316c0129,0xe3b001d3,0x200c0142,0x91b40395}},	//   grez_, _ڈرا_, _syfi_, игът_, 
   {{0x25a4bb88,0x20c4bb89,0x753c01ed,0x2d800112}},	//   mvol_, рсиг, _észa, dtke_, 
   {{0x316c014b,0x25a40af9,0x4034013d,0x2d800419}},	//   arez_, lvol_, _һелс, etke_, 
   {{0x316c1529,0x91b404fb,0x2d80045f,0x39480986}},	//   brez_, _چطور_, ftke_, ypas_, 
   {{0x25a41a7c,0x316c0276,0xe1f00f01,0xd1b40244}},	//   nvol_, crez_, _بسا_, _ناوا_, 
   {{0x7bc0023a,0x9fe40214,0xb06401f4,0x00000000}},	//   äluo, _پسته, rnää, --, 
   {{0x60d8bb8a,0xd10042e3,0x394802d1,0x2d80bb8b}},	//   mhtm, रकरण_, wpas_, atke_, 
   {{0x60d8bb8c,0x25a4017a,0x3948bb8d,0x7ac801d9}},	//   lhtm, kvol_, tpas_, دورِ_, 
   {{0x39480153,0x10840137,0x00000000,0x00000000}},	// [f310] upas_, _сөөк_, --, --, 
   {{0x3948bb8e,0x97a402a3,0x58b800c6,0x60d800d5}},	//   rpas_, ирел, خارج_, nhtm, 
   {{0x3948bb8f,0x9ba00075,0x25a40af9,0x316c0219}},	//   spas_, _بەزى, evol_, zrez_, 
   {{0x3948bb90,0x35b494ab,0x60d80c6a,0x00000000}},	//   ppas_, йбер, hhtm, --, 
   {{0x1dd401d9,0x35a4a6e6,0x39480986,0x60d80098}},	//   डनित, салг, qpas_, khtm, 
   {{0x316c0231,0x799cbb91,0x98a00210,0x00000000}},	//   vrez_, _issw, _biją_, --, 
   {{0x60d8bb92,0x00000000,0x00000000,0x00000000}},	//   dhtm, --, --, --, 
   {{0x7aecbb93,0x316cbb94,0xc304143e,0x8c1c0a7c}},	//   niat, trez_, يبيو, כווי, 
   {{0x2000722d,0x316c59e5,0xb6a41cd1,0x45d40107}},	//   şkil_, urez_, _киңл, _дотс, 
   {{0x316cbb95,0x1474230f,0x60d8bb96,0x799c02d0}},	//   rrez_, _خارج, ghtm, _mssw, 
   {{0x8504bb97,0x934404f2,0x98a00064,0xf53801ef}},	//   _بولن, _ضخام, _giją_, _huť_, 
   {{0xc2c4a9f3,0x316cbb98,0x7aec005a,0x6a7001a9}},	//   _ويلي, prez_, jiat, _nаfа, 
   {{0x7aecbb99,0x2bb80562,0xa5c000d8,0x00000000}},	//   diat, _उपहा, _éóti, --, 
   {{0x2d80b745,0x60d8bb9a,0x7fe800f2,0x104800d4}},	//   rtke_, chtm, اریف_, _ряди_, 
   {{0x2d80bb9b,0x799cbb9c,0x628c013f,0x00000000}},	//   stke_, _assw, ɑbob, --, 
   {{0x7aecae08,0x1ae000f3,0x25a4022e,0x00000000}},	//   giat, посм, yvol_, --, 
   {{0xa834aaab,0x2bb80f4a,0x799c03ac,0x2d9c00e2}},	// [f320] معاش, _उपवा, _cssw, ātes_, 
   {{0x7aecbb9d,0x25a401d5,0x00000000,0x00000000}},	//   aiat, vvol_, --, --, 
   {{0x7aecbb9e,0xfbc80882,0x799c0337,0x6d54015d}},	//   biat, रहणम, _essw, _hwya, 
   {{0x66740597,0x25a4bb9f,0xf6e402bf,0x49180037}},	//   إدار, tvol_, оцін, _बीरो_, 
   {{0x53300184,0x60d80098,0xdb20bba0,0x968000f1}},	//   үешт, yhtm, _írán, سټون, 
   {{0x6d540cfd,0x25a4bba1,0xd940bba2,0x60d8020c}},	//   _mwya, rvol_, _хери, xhtm, 
   {{0x25a4bba3,0x0ec80ce0,0xa4140154,0x00000000}},	//   svol_, _लवंड, াশ্য_, --, 
   {{0xb0600209,0x25a40926,0x60d80175,0x6d54010e}},	//   ýänd, pvol_, whtm, _owya, 
   {{0x60d80098,0x50600092,0xe3b80139,0x0f400092}},	//   thtm, _ለአካባ, _әбе_, _የተማረ, 
   {{0x7aecbba4,0x0f400020,0x60d8003e,0x6560022e}},	//   ziat, _የተመረ, uhtm, msoh, 
   {{0x6d544c27,0x60d8bba5,0x6458005f,0xca2c0873}},	//   _awya, rhtm, _ieti, ﻧﺪﺍ_, 
   {{0x6458bba6,0x60d802d3,0xb5fc09a8,0x7aecbba7}},	//   _heti, shtm, _odšl, xiat, 
   {{0x6458bba8,0x7aecbba9,0xd24c0597,0x6b9c035a}},	//   _keti, viat, _أنه_, _aspg, 
   {{0x6e3401ed,0x7aec0034,0x6458bbaa,0x6d540142}},	//   _egyb, wiat, _jeti, _dwya, 
   {{0x2f1001ed,0xd00c00c6,0x65600200,0x00000000}},	//   zági_, _كله_, hsoh, --, 
   {{0x6458bbab,0x6d5400a9,0x65600023,0x2bb804aa}},	//   _leti, _fwya, ksoh, _उपरा, 
   {{0x273c1e54,0xf8b006fe,0xfbe002f5,0x64587664}},	// [f330] _aïn_, وکس_, _মুখত, _oeti, 
   {{0x6458bbac,0x7aecbbad,0x2f10022c,0xb0b0033f}},	//   _neti, siat, vági_, जाएग, 
   {{0x2d906b48,0xf53802f0,0x799c035a,0x17dc0154}},	//   čneš_, _suť_, _wssw, _বুড়ি, 
   {{0x6458bbae,0xc0e4044e,0x1b14015b,0x87040b87}},	//   _aeti, _ምኽሪ_, _দূরে_, пяче, 
   {{0x6458bbaf,0x1a240014,0x7afcbbb0,0x799c035a}},	//   _beti, _دردُ, _ijst, _ussw, 
   {{0x7afc01f5,0x8d5c010f,0x00000000,0x00000000}},	//   _hjst, רכגי, --, --, 
   {{0xc7c4bbb1,0x2f1000dd,0x36d4bbb2,0x78b4006f}},	//   _ести, sági_, _довр, _inzv, 
   {{0x6458bbb3,0xb144295d,0xc8780205,0xa3dc013a}},	//   _eeti, онил, _öğr_, běží_, 
   {{0x64587d49,0xa6c8022e,0x00000000,0x00000000}},	//   _feti, rqаt, --, --, 
   {{0x6458bbb4,0x78a4bbb5,0x6f6418ac,0x30740276}},	//   _geti, ndhv, овоз, цуис, 
   {{0x7afc24e7,0x28dc07b7,0x00000000,0x00000000}},	//   _ojst, फोटि, --, --, 
   {{0x82345d62,0xa6c801b9,0xf3f00241,0x2d9c0210}},	//   _فرها, lqаr, _yẹn_, łtem_, 
   {{0x6458bbb6,0x78b40810,0xfe7001ed,0xf3f00051}},	//   _yeti, _onzv, رگٹ_, _kẹo_, 
   {{0x7afc01fa,0x6b9c0129,0xafc40150,0x00000000}},	//   _ajst, _pspg, _ويشى, --, 
   {{0xea5803b7,0xeb98bbb7,0x407800f7,0x80240eff}},	//   ирај_, шив_, _الىڭ_, _ىرىم, 
   {{0x2d9428e8,0xbdf80014,0xc9448abc,0x63bc01e3}},	//   _дрос, _گر٘ا_, здақ, äpni, 
   {{0x98a805d1,0xe8e8bbb8,0x656c00b8,0x7bc003b2}},	// [f340] _avcı_, амад_, _ābho, ølur, 
   {{0x7afc01bf,0x00000000,0x00000000,0x00000000}},	//   _ejst, --, --, --, 
   {{0xadec1b76,0x00000000,0x00000000,0x00000000}},	//   _चेतन_, --, --, --, 
   {{0x268806d5,0x6458bbb9,0x6560052f,0x78b4478b}},	//   شخصي_, _seti, tsoh, _enzv, 
   {{0x6458bbba,0x65940597,0x753c01d3,0xdb0c01e1}},	//   _peti, تجار, _észl, _àdák, 
   {{0x6560bbbb,0x645801e0,0x2d90017a,0x779001d3}},	//   rsoh, _qeti, _mpye_, بیہا, 
   {{0x6458bbbc,0x65600e14,0x00000000,0x00000000}},	//   _veti, ssoh, --, --, 
   {{0x6458bbbd,0x8bfc015b,0x2164bbbe,0x00000000}},	//   _weti, _ইরান_, отог, --, 
   {{0x6458bbbf,0x27e80024,0x68e001e4,0x65600200}},	//   _teti, žinė_, ɨodr, qsoh, 
   {{0x7a400241,0x7bc001f4,0x00000000,0x00000000}},	//   _kátó, äluk, --, --, 
   {{0xc0f81b49,0x2d9002e2,0xe298014b,0x00000000}},	//   _ወኪል_, _apye_, _вае_, --, 
   {{0xc4441fae,0x539805d0,0x7a4000e5,0x00000000}},	//   _بیژن_, _כיבו, _mátó, --, 
   {{0xa0a4bbc0,0xfa880023,0x7a40398f,0x24e000cd}},	//   _мадд, _ምኽኑይ_, _látó, _śiṃś, 
   {{0xd12c0953,0x0e34bbc1,0x00000000,0x00000000}},	//   _іх_, ьняю, --, --, 
   {{0xdef812c4,0xfbe00154,0xf8b80051,0x00000000}},	//   _вып_, _মুজত, _đũ_, --, 
   {{0x7a380220,0x7dd00332,0x940406be,0x00000000}},	//   спар_, _cósú, genə_, --, 
   {{0x71240014,0x00000000,0x00000000,0x00000000}},	// [f350] _بى۪م, --, --, --, 
   {{0x7e7ca3ba,0xd874bbc2,0x00000000,0x00000000}},	//   lgsp, تارب, --, --, 
   {{0x629c013f,0x7e7c017a,0xdcac0137,0xc864074d}},	//   _ɔpor, ogsp, _كۉڭ_, ьтти, 
   {{0xb934009b,0x00000000,0x00000000,0x00000000}},	//   _немј, --, --, --, 
   {{0xc9840276,0x2ab8011a,0xb0600166,0x00000000}},	//   _оури, _המרא, _şämb, --, 
   {{0x7a406791,0x04c85230,0x96a8000d,0x00000000}},	//   _fátó, يوني_, _घोरउ, --, 
   {{0xa6c8022e,0x31a800d7,0x321c0210,0x00000000}},	//   rqаr, _sĺz_, _szwy_, --, 
   {{0x3a3800f3,0x4bfc011a,0xd6d875a5,0x00000000}},	//   _jgsp_, ילוס, _ттг_, --, 
   {{0x95c80131,0xd4988eb4,0x52d80037,0xc6a4030d}},	//   _тува_, _вре_, _बतीस, _юрри, 
   {{0x39581c06,0xafe40139,0x7e7c3ce6,0x7a400241}},	//   _mwss_, зоол, egsp, _yátó, 
   {{0xb5fc389c,0x3cf000e1,0xee38010b,0xd3440133}},	//   _odšk, ुचने_, йнн_, _بیبه_, 
   {{0x7e7c0eef,0xff2800b5,0x38600165,0x00000000}},	//   ggsp, _phpで, hahr_, --, 
   {{0xc2c40b24,0x00000000,0x00000000,0x00000000}},	//   _تيني, --, --, --, 
   {{0x6cd40491,0x38600730,0x010804d3,0x21a000fd}},	//   أقسا, jahr_, _وتوو_, _чишм, 
   {{0x3ec400b5,0xdfcca864,0x80240228,0x00000000}},	//   æstø_, _ميو_, _ۉرۉم, --, 
   {{0x32d001e1,0x00000000,0x00000000,0x00000000}},	//   _báyi_, --, --, --, 
   {{0x3860bbc3,0xc0ec0092,0x00000000,0x00000000}},	// [f360] fahr_, ጀምሩ_, --, --, 
   {{0xb5fc01fa,0x764c0309,0x3f640166,0xec78009b}},	//   _kešf, ñayn, _этәб, _упо_, 
   {{0xb8640a2c,0xaa4401ec,0xdc38011a,0x00000000}},	//   باقو, _ىندى, _לעיר, --, 
   {{0x73f400cc,0x00000000,0x00000000,0x00000000}},	//   _ছৰ্ট_, --, --, --, 
   {{0x38600ffb,0x00000000,0x00000000,0x00000000}},	//   bahr_, --, --, --, 
   {{0xb8940209,0x43948740,0xa8d800f1,0x00000000}},	//   _орсъ, дакс, _اوسئ_, --, 
   {{0x6aa4007c,0xd4640063,0xbb3c0ef6,0x7e7c007c}},	//   _kakf, чије_, _ﺟﯩﻦ_, ygsp, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe16400c6,0x21c8008e,0x00000000,0x00000000}},	//   أدبي, сыйп_, --, --, 
   {{0x6aa40ce2,0x5464055f,0x95e801ed,0x00000000}},	//   _lakf, _наум_, _طبقہ_, --, 
   {{0xbfc800d1,0x23d40354,0xf3ec014b,0x00000000}},	//   زادە_, _эцар, _рӣ_, --, 
   {{0x6aa4009f,0x3cf00175,0x225000a2,0x00000000}},	//   _nakf, wizv_, _ýyk_, --, 
   {{0x6280bbc4,0x7e7c0250,0xd1e00023,0xc0ec001f}},	//   _icoo, rgsp, _ምግቢ_, ጀምር_, 
   {{0xdcec084c,0x6280507c,0x00000000,0x00000000}},	//   ducă, _hcoo, --, --, 
   {{0x6aa45794,0xb7f000fe,0x00000000,0x00000000}},	//   _bakf, _জুনত_, --, --, 
   {{0x60c8bbc5,0x68ecbbc6,0x0f780375,0x3860002f}},	//   _hofm, _ambd, _האהב, wahr_, 
   {{0x60c80048,0x7e6cbbc7,0xbc4400db,0x00000000}},	// [f370] _kofm, _idap, _ۉرگۉ, --, 
   {{0x6aa4035a,0xa5440023,0x00000000,0x00000000}},	//   _eakf, _ንሰራዊ, --, --, 
   {{0xf7984e5c,0x6aa4bbc8,0x628000e4,0x00000000}},	//   تناب_, _fakf, _ocoo, --, 
   {{0xd1e00020,0x68ec003e,0x06440023,0x00000000}},	//   _ምግብ_, _embd, _ንበይነ, --, 
   {{0x60c80036,0x00000000,0x00000000,0x00000000}},	//   _oofm, --, --, --, 
   {{0x62800334,0x060802d5,0x00000000,0x00000000}},	//   _acoo, чнік_, --, --, 
   {{0x62800327,0x6aa40166,0x00000000,0x00000000}},	//   _bcoo, _yakf, --, --, 
   {{0x628001c4,0x42b80131,0x00000000,0x00000000}},	//   _ccoo, كنىڭ_, --, --, 
   {{0x76480161,0x3074bbc9,0x3124bbca,0xb098003b}},	//   _ifey, мунс, мдиг, отнє_, 
   {{0x7e6cbbcb,0x628000e8,0xa064010b,0x00000000}},	//   _adap, _ecoo, маьа_, --, 
   {{0x693400e4,0xafe401b9,0xa5080eff,0x031800f2}},	//   _oņen, фонл, _بىلە_, _کتلت_, 
   {{0x0378bbcc,0x2f1006ea,0x00000000,0x00000000}},	//   _رحمت_, vágs_, --, --, 
   {{0xa6c8009e,0x6aa4bbcd,0x00000000,0x00000000}},	//   লোকট, _rakf, --, --, 
   {{0xc104bbce,0x7e6c0066,0x6aa4bbcf,0x00000000}},	//   _كوني, _edap, _sakf, --, 
   {{0xa1100133,0xdca001d5,0xc0a815f8,0x00000000}},	//   _جووت, ъари, _راول_, --, 
   {{0x764c0113,0x00000000,0x00000000,0x00000000}},	//   ñayl, --, --, --, 
   {{0x2bb8a583,0x657c001f,0x6aa405d1,0xdee00107}},	// [f380] _उपका, _የፍትህ_, _vakf, _шоъи, 
   {{0x7648bbd0,0x6aa4139d,0xeb980063,0x271400dc}},	//   _afey, _wakf, _дио_, तत्र_, 
   {{0x6aa4bbd1,0x00000000,0x00000000,0x00000000}},	//   _takf, --, --, --, 
   {{0xe6180283,0x7e6c0ac5,0xca64022e,0x00000000}},	//   оде_, _xdap, lliо, --, 
   {{0x83fc0fcf,0x62800098,0xb5fc0064,0xe4f001f9}},	//   _međe, _rcoo, _nešd, _अगदि_, 
   {{0x7648002e,0x6280bbd2,0x68ec035a,0x00000000}},	//   _efey, _scoo, _umbd, --, 
   {{0x54400075,0x779015d6,0xb17c00d0,0x43940334}},	//   خنىك, _میلا, vzťa, хайс, 
   {{0x60c80998,0x29180986,0xca680023,0xdb0403b2}},	//   _sofm, llpa_, ታትኩም_, ðløg, 
   {{0x26c40263,0x958094f8,0x60c801ab,0xd20401c0}},	//   mjoo_, _илте, _pofm, дээд_, 
   {{0x94c800f1,0x26c40108,0xb5fc0171,0x00000000}},	//   _والې_, ljoo_, _sešg, --, 
   {{0x7e6c0477,0x2284010b,0x00000000,0x00000000}},	//   _pdap, _жулг, --, --, 
   {{0x26c4784f,0x6280014b,0x83fc009b,0x00000000}},	//   njoo_, _ucoo, _ceđe, --, 
   {{0xb7d40241,0x8d847488,0x3fc804f2,0x00000000}},	//   _iṣek, курд, زدگی_, --, 
   {{0xa0340b38,0x00000000,0x00000000,0x00000000}},	//   _قىشت, --, --, --, 
   {{0xbbc8038e,0x956002d3,0x00000000,0x00000000}},	//   रहेक, _ስደትን_, --, --, 
   {{0x7e6cbbd3,0x26c4022f,0x00000000,0x00000000}},	//   _udap, jjoo_, --, --, 
   {{0xb5fc15b2,0x26c4020c,0x5f900131,0x2ca80175}},	// [f390] _keše, djoo_, _чиқт, bdbd_, 
   {{0x3ea8bbd4,0x39140633,0xb0640821,0xc0ec0240}},	//   _haat_, رواز, miää, ህበሉ_, 
   {{0x7674bbd5,0x3ea80429,0x8c440261,0xb064005b}},	//   елеф, _kaat_, _шеќе, liää, 
   {{0xb5fc245e,0x0708bbd6,0x50180375,0xdaa000db}},	//   _leše, ويلي_, חובו, _جەرپ, 
   {{0x3ea82596,0x76480076,0xb064023a,0x7bd402fb}},	//   _maat_, _vfey, niää, lyzu, 
   {{0x3ea8bbd7,0x26c4bbd8,0xb5fcbbd9,0x00000000}},	//   _laat_, ajoo_, _neše, --, 
   {{0x53c001ec,0xb06401f4,0xb5fc00de,0x84640395}},	//   тайұ, hiää, _sešd, тъче, 
   {{0x3ea8bbda,0x76480009,0xb06401f4,0x4ca805ac}},	//   _naat_, _ufey, kiää, খাযু, 
   {{0x83fc107d,0xb5fc1155,0x35b40166,0x00000000}},	//   _ređe, _beše, _ябар, --, 
   {{0x6348002d,0x7ae00ea0,0x2a8c0023,0x00000000}},	//   _sęne, ëltj, _ብጎነጽ_, --, 
   {{0x3254bbdb,0x3ea81574,0xb9d01b49,0x4ca800fe}},	//   _звер, _baat_, _ጴጥ_, খামু, 
   {{0x3ea8bbdc,0x63bc003b,0x926400f2,0x74e000eb}},	//   _caat_, åpne, _آدام, _বদিউ, 
   {{0x3ea804d1,0x5d64bbdd,0xc32c0ef6,0x6260010b}},	//   _daat_, ниям_, _بەي_, _ёвша, 
   {{0x332cbbde,0xa0a00209,0x63540092,0x00000000}},	//   lmex_, _башд, _ያነጣጠ, --, 
   {{0x3ea8bbdf,0x00000000,0x00000000,0x00000000}},	//   _faat_, --, --, --, 
   {{0x3ea8bbe0,0x1c400022,0x332c058a,0x00000000}},	//   _gaat_, _ҩным, nmex_, --, 
   {{0xa924bbe1,0xdd8c027d,0x9b640133,0x69240120}},	// [f3a0] едал, _هوي_, وڕێم_, емаа, 
   {{0xec7801ee,0x00000000,0x00000000,0x00000000}},	//   _эпо_, --, --, --, 
   {{0x3ea8bbe2,0xe738023a,0x9cd400d9,0x7bd40210}},	//   _yaat_, чее_, _נוטה_, cyzu, 
   {{0x3ea800e8,0xd68000db,0x00000000,0x00000000}},	//   _xaat_, гушп, --, --, 
   {{0x7640035b,0x26c401f4,0xe21c00cd,0xd6640137}},	//   рҭуа, rjoo_, _परेण_, رموو_, 
   {{0xc4340b28,0x491800ab,0x69d400a2,0x00000000}},	//   نکات, _बीचो_, myye, --, 
   {{0xb5fc8f81,0x66e4a401,0xa69416a4,0x555000d1}},	//   _reše, _зова, _прај, نھەر, 
   {{0xb5fc013a,0x00000000,0x00000000,0x00000000}},	//   _seše, --, --, --, 
   {{0x3ea8bbe3,0x69d40198,0xb5fc2e31,0x5044001f}},	//   _raat_, nyye, _peše, _ከአካባ, 
   {{0x3ea8bbe4,0x693400e4,0xb5d801e1,0xb064005b}},	//   _saat_, _oņem, _mẹ́s, viää, 
   {{0x3ea8bbe5,0xb5fc01ef,0x69d400a2,0x00000000}},	//   _paat_, _veše, hyye, --, 
   {{0x2bb80ad7,0xe50c3be5,0xb0640108,0x00000000}},	//   _उपजा, ाकवि_, tiää, --, 
   {{0xb5fcbbe6,0x3ea884cd,0x21740166,0x00000000}},	//   _teše, _vaat_, _чуер, --, 
   {{0x3ea804d1,0x7bd40210,0x91b8011a,0xb0641577}},	//   _waat_, tyzu, _ממדי, riää, 
   {{0x3ea802b4,0xccf4013f,0x764c02d1,0xb0640e03}},	//   _taat_, _twɛn_, ñayk, siää, 
   {{0x69d8003a,0x7bd4033f,0x7d786168,0xb06401f4}},	//   _ęter, ryzu, _قمبر_, piää, 
   {{0x693400e4,0x601803b2,0x3f8c06be,0x00000000}},	// [f3b0] _eņem, bømú, ltdu_, --, 
   {{0x2bb8000b,0x60d8265c,0xed600171,0x00000000}},	//   _उपचा, nktm, _dižā_, --, 
   {{0x3f8cbbe7,0x69d4022f,0x00000000,0x00000000}},	//   ntdu_, ayye, --, --, 
   {{0x332c0221,0xdaf8031c,0x69d4002d,0x7130002b}},	//   xmex_, _དམིཌ_, byye, _mādṛ, 
   {{0x35a4bbe8,0x18b000fb,0x00000000,0x00000000}},	//   талг, _йҙар, --, --, 
   {{0x798cbbe9,0x6b8c006a,0xf8682764,0x00000000}},	//   mtaw, _ângû, _زمري_, --, 
   {{0x798c2d3e,0x713000b8,0x00000000,0x00000000}},	//   ltaw, _nādṛ, --, --, 
   {{0x798c009f,0x00000000,0x00000000,0x00000000}},	//   otaw, --, --, --, 
   {{0x798cbbea,0xa61400c7,0x332cbbeb,0x3078007b}},	//   ntaw, _азтә, rmex_, وحدة_, 
   {{0x765800a9,0x798c0433,0x3db80154,0x612403b2}},	//   lbwy, itaw, ুনাল, yðle, 
   {{0x798cbbec,0x713000b8,0x8e64010b,0x00000000}},	//   htaw, _cādṛ, ленҗ, --, 
   {{0x92e8bbed,0x798cbbee,0x93600022,0x76580142}},	//   _عراق_, ktaw, _анҧҵ, nbwy, 
   {{0x798cbbef,0x00000000,0x00000000,0x00000000}},	//   jtaw, --, --, --, 
   {{0x76580042,0x00000000,0x00000000,0x00000000}},	//   hbwy, --, --, --, 
   {{0x2d9c0232,0x76580175,0x00000000,0x00000000}},	//   ňte_, kbwy, --, --, 
   {{0x2ef00810,0x798cbbf0,0x9f940124,0xdb200ca8}},	//   _umyf_, ftaw, _рышә, _ìrìn, 
   {{0x798c417f,0x83fc16a3,0x765803cb,0xd940bbf1}},	// [f3c0] gtaw, _međa, dbwy, иети, 
   {{0x713000dc,0xc0ac010f,0x00000000,0x00000000}},	//   _yādṛ, ּיאָ, --, --, 
   {{0x18a0bbf2,0x76580368,0x798c0ba7,0xb9540131}},	//   рахм, fbwy, ataw, نئەت, 
   {{0x798cbbf3,0xaa44010b,0x95540023,0x61f400ee}},	//   btaw, _шемл, _ዝተኸተ, _ýylg, 
   {{0x798cbbf4,0xb68400d1,0x00000000,0x00000000}},	//   ctaw, اشمى, --, --, 
   {{0xf6083bd6,0x7c38010e,0x39340064,0x151000d4}},	//   رتنه_, _ýarý, _бэсс, адія, 
   {{0xb5fc0219,0x6b8c031c,0x656c00b8,0x00000000}},	//   _pešc, ntbg, _ābhu, --, 
   {{0x693400e4,0x64480332,0x00000000,0x00000000}},	//   _oņek, scfi, --, --, 
   {{0x154000ee,0xb7d40cad,0x713000cd,0x142000b1}},	//   _веум, _iṣak, _sādṛ, лдәм, 
   {{0xb1441169,0x99e00432,0x00000000,0x00000000}},	//   دیوم_, _öňeg, --, --, 
   {{0xe28400c7,0x60d81543,0x2edc66eb,0xb7d400b8}},	//   _алеи, rktm, मसूत, _kṣak, 
   {{0xc694008f,0x798cbbf5,0xd240030d,0x93f4011a}},	//   נאָ_, ytaw, _кэши, _בצבא_, 
   {{0x00940323,0x91e0bbf6,0x798c0054,0xb5fc00ef}},	//   _билэ, _коце, xtaw, _keša, 
   {{0x40a82e6b,0x71300882,0x00000000,0x00000000}},	//   _سختی_, _tādṛ, --, --, 
   {{0x7f940323,0xb5fcbbf7,0x798c013f,0xbf1009a5}},	//   _сайх, _meša, wtaw, _гүнә, 
   {{0x798cbbf8,0xc1040451,0xb7d401e1,0xb5fc01ef}},	//   ttaw, _جوڻي, _nṣak, _leša, 
   {{0x61f409a5,0x9ba00075,0x798c02a8,0x8ac401d5}},	// [f3d0] _ýyld, _ھەرى, utaw, шёрл, 
   {{0x798cbbf9,0x9ba01b56,0xb5fcbbfa,0xdce40064}},	//   rtaw, _پەرى, _neša, _ėmėj, 
   {{0x798cbbfb,0x7d14022e,0x765803cb,0x00000000}},	//   staw, mozs, tbwy, --, 
   {{0xcf9000c8,0x0714177b,0x798cbbfc,0x7d140e79}},	//   יטע_, афія, ptaw, lozs, 
   {{0x55c0bbfd,0x83fc009b,0x798cbbfe,0x49740006}},	//   ралғ, _ređa, qtaw, _кляс, 
   {{0x05740597,0x4ddc0375,0xd77401ec,0x6aa001e4}},	//   شاهد, וחדו, _لارع, ĵofe, 
   {{0xb5fc2aef,0xc4c419e2,0x6348003a,0x94040134}},	//   _deša, شتوو, _pęna, tenɑ_, 
   {{0x7d140083,0xd5b8011c,0x00000000,0x00000000}},	//   hozs, _осз_, --, --, 
   {{0xb5fc00d7,0x3948003d,0xf578bbff,0x00000000}},	//   _feša, nqas_, _سماع_, --, 
   {{0x3dd800b5,0x6ee4032e,0xe3c4104e,0x14a801f9}},	//   dysw_, _móbe, трәү, _टोचण, 
   {{0x838407d8,0x764c0113,0x61ec01e4,0xff3c0092}},	//   _выче, ñayw, ĝbla, _ከተመዘ, 
   {{0x2edc0d2c,0x42140521,0xb1b49448,0x00000000}},	//   मसेत, ịsọ_, _محتش, --, 
   {{0xdecc02d3,0xd09002dd,0xc0a800f1,0x6ee408a5}},	//   _ብጀካ_, _ұшқы, رایل_, _nóbe, 
   {{0x3f48006a,0x9d40bc00,0x6b8c0175,0x2fd4009f}},	//   _fûu_, серд, ttbg, _متبح, 
   {{0x3bd41c22,0x83fc39ae,0x5fb050d8,0x23b4012d}},	//   аютс, _leđn, _هموط, _आज़ाद, 
   {{0xa9a4bc01,0xd5680408,0x00000000,0x00000000}},	//   либд, _гiил, --, --, 
   {{0x316cbc02,0xee38a89c,0x8d280116,0x3a4402a9}},	// [f3e0] nsez_, _яни_, _иниң_, рмуҳ, 
   {{0x2d80bc03,0x316c06af,0xbd040036,0x00000000}},	//   muke_, isez_, rgéë, --, 
   {{0xb5fcbc04,0x98a800ef,0xeb9800f0,0xe6d4009d}},	//   _reša, _aucē_, _џим_, лцдэ, 
   {{0x76a802bf,0xdd8cbc05,0x1ae0010b,0x5b78008f}},	//   ктів_, _بوی_, _гоюм, _ארטא, 
   {{0xb5fc597e,0x2d80bc06,0x80a401f9,0x00000000}},	//   _peša, nuke_, _कसले, --, 
   {{0x291cbc07,0x9774bc08,0x00000000,0x00000000}},	//   _óta_, _әтрә, --, --, 
   {{0xb5fcbc09,0xd37402d5,0x00000000,0x00000000}},	//   _veša, гчы_, --, --, 
   {{0xc1740126,0xd2540262,0x316c0166,0x76b400f3}},	//   алищ, лць_, fsez_, _кљуц, 
   {{0xb5fcb0e8,0x63880120,0x00000000,0x00000000}},	//   _teša, _bênç, --, --, 
   {{0xa0a40f37,0xd46403f6,0x25a4010e,0x00000000}},	//   ушил, _бифе_, mwol_, --, 
   {{0x66d80129,0x20080205,0x6124032e,0x00000000}},	//   _aïki, çbi_, gðla, --, 
   {{0x753c01ed,0x2d80bc0a,0xb06000ee,0x1ea83be1}},	//   _észr, fuke_, ýärd, راجي_, 
   {{0x2d80bc0b,0xb5fc9ae3,0x25a47f17,0x7d14022e}},	//   guke_, _lešn, nwol_, tozs, 
   {{0x4034bc0c,0x3eac012c,0xd12c00c6,0x6ee4bc0d}},	//   _келс, žet_, _فمن_, _róbe, 
   {{0x2d802665,0x39480477,0xb5fc0064,0x61f400a2}},	//   auke_, wqas_, _nešn, _ýylb, 
   {{0xcd800023,0x00000000,0x00000000,0x00000000}},	//   ሓሒዝና_, --, --, --, 
   {{0x2d80bc0e,0x25a4000f,0x82b8031c,0xfce84609}},	// [f3f0] cuke_, jwol_, _ཐོནའ, _لفظي_, 
   {{0x3948bc0f,0xd8080107,0x00000000,0x00000000}},	//   rqas_, нхел_, --, --, 
   {{0x394803f0,0xd1e00240,0x00000000,0x00000000}},	//   sqas_, _ምውቕ_, --, --, 
   {{0xd6a8bc10,0x35b475f1,0x656c0055,0xdb200ca8}},	//   عدام_, ибер, _ābhr, _ìràn, 
   {{0x3948003d,0xa2cc00e1,0x6ee40694,0xa61400c7}},	//   qqas_, _तवज्, _yóbb, азцә, 
   {{0x2ee05b99,0xa978011a,0x94744c8b,0x00000000}},	//   _पत्त, _באשכ, ادشا, --, 
   {{0x2d80bc11,0x442001ec,0x80c8012d,0x00000000}},	//   zuke_, сi_, ़ाने, --, 
   {{0x2d80bc12,0x00000000,0x00000000,0x00000000}},	//   yuke_, --, --, --, 
   {{0x46f4034b,0x764c0309,0xb1440a5b,0x00000000}},	//   _учёт, ñayu, јнол, --, 
   {{0xe0d41de1,0x2d8003b4,0x316cbc13,0x2edc87ea}},	//   ивы_, vuke_, rsez_, मस्त, 
   {{0x316c0231,0x03782ad5,0x2d803917,0xd3f000fe}},	//   ssez_, _محنت_, wuke_, _চুৰি_, 
   {{0x6124008c,0x2d80bc14,0x799cbc15,0xe28c0120}},	//   rðla, tuke_, _opsw, _ќа_, 
   {{0xb5fc0f8b,0xb9240248,0xdcfc008e,0x2d80020c}},	//   _mešo, _dupẹ_, _arqı, uuke_, 
   {{0x2d8056c0,0xb5fc000a,0x05782e1f,0xcdc400c7}},	//   ruke_, _lešo, _አግባብ_, _ҳаиқ, 
   {{0x2d80bc16,0x799c0857,0x6ee40162,0x7d08007f}},	//   suke_, _apsw, _vóbb, éesa, 
   {{0x2d80bc17,0x799c03ac,0x1ae00114,0xb5fc00c0}},	//   puke_, _bpsw, оосм, _nešo, 
  
   {{0x6da465cb,0x799c02d0,0x442001fb,0x2d80676c}},	// [f400] _типа, _cpsw, ́i_, quke_, 
   {{0x6d54bc18,0xb864027d,0x31400023,0xab640816}},	//   _itya, مامو, _ከነቕር, _квол, 
   {{0xe6642f23,0x7c280198,0x25a4011f,0x799c03ac}},	//   атло, ƙera, wwol_, _epsw, 
   {{0x799c03ac,0x25a4bc19,0x81cc0154,0x00000000}},	//   _fpsw, twol_, রনত_, --, 
   {{0x64a4bc1a,0x6f0401e2,0x799c035a,0x56740816}},	//   иада, inkc, _gpsw, рбія_, 
   {{0xb5fc0558,0x25a4bc1b,0xd568030d,0x6c78010f}},	//   _tešn, rwol_, _гiол, דאַפ, 
   {{0xc68801d9,0x25a401f5,0xb354179e,0x00000000}},	//   _مێان_, swol_, میلا_, --, 
   {{0x2240bc1c,0x6d542ad1,0x764c02d1,0x00000000}},	//   økk_, _otya, ñayt, --, 
   {{0x6d54bc1d,0x64c44fca,0xe6180212,0x9a780023}},	//   _ntya, _پيال, _рда_, _እኽእል_, 
   {{0x6720bc1e,0x6b9c1a82,0x6f04004b,0x00000000}},	//   lloj, _oppg, enkc, --, 
   {{0x6720bc1f,0x6d540882,0x3f141b04,0xd24cb754}},	//   oloj, _atya, йдос, _мц_, 
   {{0xe1f800fb,0x2184030d,0xd00400d8,0x00000000}},	//   _иге_, _кăмр, реџе_, --, 
   {{0xb5fc0122,0x290802d2,0xf8c85347,0x00000000}},	//   _nešl, _ojba_, रामय, --, 
   {{0x67200032,0xdfd026c0,0x8ff401ed,0x10a03f1d}},	//   hloj, _ويش_, اریر_, _мичн, 
   {{0x7f840491,0x6720bc20,0x6d54bc21,0x2d9c054e}},	//   _العن, kloj, _etya, ătea_, 
   {{0xb5fc2804,0x6720010f,0x799c03ac,0xdef8190b}},	//   _bešl, jloj, _ppsw, _шыл_, 
   {{0x4b040006,0xdd84004e,0x5fac09b2,0x00000000}},	// [f410] цярб, _тыйп, टिकल, --, 
   {{0xb5fcbc22,0x261809fd,0x612403b2,0x6aa001e4}},	//   _sešo, _बड़ी_, iðlo, ĵofa, 
   {{0x672001e4,0x5a440139,0x4ba8008e,0x799c02d0}},	//   floj, _вэга, _көтү_, _wpsw, 
   {{0x6720bc23,0xba18007b,0x00000000,0x00000000}},	//   gloj, _ميجا_, --, --, 
   {{0x63b87635,0xb5fc3421,0x799c035a,0x49c800cf}},	//   _artn, _vešo, _upsw, _курм_, 
   {{0xb4e00034,0x845800a7,0x67205d40,0x81cc015b}},	//   दसे_, арът_, aloj, রনা_, 
   {{0x6720bc24,0x764c0784,0xb5fc00c0,0x00000000}},	//   bloj, ñays, _iešm, --, 
   {{0x42b80075,0x67200115,0x78a4003b,0x00000000}},	//   لنىڭ_, cloj, lehv, --, 
   {{0x63b848a2,0x81cc03d4,0x00000000,0x00000000}},	//   _ertn, _ৱেব_, --, --, 
   {{0x70c8026a,0x00000000,0x00000000,0x00000000}},	//   угог_, --, --, --, 
   {{0xb6400220,0x6d54bc25,0x00000000,0x00000000}},	//   _ﺍﻝ_, _stya, --, --, 
   {{0x6da4bc26,0x00000000,0x00000000,0x00000000}},	//   бима, --, --, --, 
   {{0xe0cc0c82,0x205400f7,0x6ee4bc27,0x00000000}},	//   _ев_, штөр, _cóba, --, 
   {{0x7054a482,0xb5fc5a54,0xaf04010b,0x61f400ee}},	//   _انغا, _rešl, рчүк, _ýyla, 
   {{0xb5fc00bc,0x78a401bf,0xfbd0210e,0x00000000}},	//   _sešl, dehv, وتِ_, --, 
   {{0xe8b000dc,0x3b840092,0x00000000,0x00000000}},	//   ुञ्च, ርቲዎች_, --, --, 
   {{0x6d5400f1,0xada400d8,0x29540395,0x00000000}},	// [f420] _utya, _ѓаол, събр, --, 
   {{0x5e54bc28,0xac8464d6,0x2ca83e07,0x78a420e4}},	//   _پلیس_, _угол, _скоп_, gehv, 
   {{0x6b9cbc29,0xb8640228,0xa968013e,0x00000000}},	//   _uppg, زالو, тиҷа_, --, 
   {{0xb5fc0024,0x6720501a,0x612403b2,0x00000000}},	//   _tešl, uloj, yðlo, --, 
   {{0xa5940801,0x67208489,0x00000000,0x00000000}},	//   срещ, rloj, --, --, 
   {{0xe69401d5,0x00000000,0x00000000,0x00000000}},	//   _گلرد, --, --, --, 
   {{0x6720bc2a,0x63b8037e,0x291800c7,0x00000000}},	//   ploj, _qrtn, mopa_, --, 
   {{0x2918bc2b,0x63b8bc2c,0x4154bb7f,0x68fcbc2d}},	//   lopa_, _vrtn, овис, lipd, 
   {{0x3cf805f9,0x52700640,0xd62400f3,0x00000000}},	//   _उगले_, чују, _готе_, --, 
   {{0x2918bc2e,0xff980063,0x6ee400ae,0xe504007b}},	//   nopa_, акој_, _róba, _ابري, 
   {{0x05740032,0x4438bc2f,0xc0c0001f,0x00000000}},	//   _уҙҙы_, _àr_, _ድጎማ_, --, 
   {{0x21680261,0x442c0427,0x212c0175,0x68fc4c43}},	//   _биди_, _izd_, _whfh_, hipd, 
   {{0x3f98025c,0x68fc010b,0x00000000,0x00000000}},	//   ħruq_, kipd, --, --, 
   {{0xd040043b,0xcc5402e8,0x29180064,0x00000000}},	//   _monɛ, звръ, jopa_, --, 
   {{0x29180784,0x68fc00ee,0x92a80183,0x442c013a}},	//   dopa_, dipd, খাৰ_, _jzd_, 
   {{0x6ee443e5,0xa6f80154,0x00000000,0x00000000}},	//   _tóba, ইকুম_, --, --, 
   {{0x0ca803d4,0x00000000,0x00000000,0x00000000}},	// [f430] _ওচৰত, --, --, --, 
   {{0x2918bc30,0x68fc010e,0x097400d4,0x00000000}},	//   gopa_, gipd, ягую, --, 
   {{0x22440428,0xc864bc31,0x78a400c5,0xb5fc01a6}},	//   _ogok_, ятти, rehv, _vešm, 
   {{0x2244004b,0xdb1c02f6,0x00000000,0x00000000}},	//   _ngok_, äväk, --, --, 
   {{0xb5fc0953,0x7aecbc32,0x2918949e,0x764c0113}},	//   _iešk, mhat, bopa_, ñayq, 
   {{0x7aecbc33,0x2918bc34,0x442c01e4,0x68fc010e}},	//   lhat, copa_, _bzd_, cipd, 
   {{0x7aec02b5,0xb5fc02f0,0xe69000ec,0x00000000}},	//   ohat, _kešk, _ڊڄند, --, 
   {{0x3b08bc35,0xb5fcbc36,0x7aecbc37,0x442cbc38}},	//   nnaq_, _ješk, nhat, _dzd_, 
   {{0xb5fcbc39,0xb9f0001f,0x442cbc3a,0x04c800ec}},	//   _mešk, _ነክ_, _ezd_, _گولي_, 
   {{0x3b080455,0x39580139,0x7aec0205,0x00000000}},	//   hnaq_, _mtss_, hhat, --, 
   {{0x7aecbc3b,0x3254bc3c,0x04c8007b,0x61f400a2}},	//   khat, _двер, _دولي_, _ýyln, 
   {{0x8234bc3d,0xb5fc19d6,0x7aecbc3e,0x2918006f}},	//   _کرما, _nešk, jhat, zopa_, 
   {{0x7aecbc3f,0x2918090c,0x3b080067,0xd69c0150}},	//   dhat, yopa_, dnaq_, _ﺍﺤﻤﺭ_, 
   {{0xafe4bc40,0x29180564,0x7aec0009,0x68fc0175}},	//   _молл, xopa_, ehat, xipd, 
   {{0xb5fc91aa,0x1d041d0f,0x2b4000ef,0x38600055}},	//   _bešk, цери_, _pikc_, dbhr_, 
   {{0x7aecbc41,0x291802ce,0x6aa001e4,0x00000000}},	//   ghat, wopa_, ĵofo, --, 
   {{0xb5fc0010,0xec78bc42,0xf3900248,0xfbd000f1}},	// [f440] _dešk, _кпп_, _iṣuu_, وتې_, 
   {{0x3b080869,0x6ee400e5,0x00000000,0x00000000}},	//   anaq_, _kóbo, --, --, 
   {{0x7aecbc43,0xab2810f5,0x68fc0209,0xaa4439fb}},	//   bhat, _вона_, ripd, _менл, 
   {{0x7aecbc44,0x3958009a,0x2918b955,0xe5c40b32}},	//   chat, _ftss_, sopa_, жско, 
   {{0x2b58bc45,0x2918bc46,0x27f40118,0x95501fb8}},	//   _htpc_, popa_, _ženě_, وخوا, 
   {{0x68fc014f,0x6ab40142,0x5db80115,0x6fc81546}},	//   qipd, ldyf, יזנה, िमां, 
   {{0x66e409a5,0x2d8001ab,0xe048036b,0xd940009b}},	//   _дова, hrke_, یشده_, _цери, 
   {{0x6ab40042,0xc3300131,0x442c5563,0xefe401f3}},	//   ndyf, رەش_, _vzd_, _ዝርያ_, 
   {{0x83fcbc47,0x00000000,0x00000000,0x00000000}},	//   _međi, --, --, --, 
   {{0x7aecbc48,0x83fc1b24,0xa2b80764,0xdb20032e}},	//   zhat, _leđi, _शोर्, _írön, 
   {{0x2d805e32,0x22440ac5,0x3b08bc49,0x7cf00241}},	//   erke_, _tgok_, ynaq_, _lórù, 
   {{0x22440280,0x7aec004b,0x61447e7e,0x00000000}},	//   _ugok_, xhat, _деда, --, 
   {{0xd00c03e6,0xb5fcbc4a,0x79600241,0x6ab40042}},	//   _یله_, _rešk, _máwò, ddyf, 
   {{0x7aecbc4b,0xb5fcbc4c,0x00000000,0x00000000}},	//   what, _sešk, --, --, 
   {{0xb5fc2625,0x2d80bc4d,0xa2cc00dc,0x3b080455}},	//   _pešk, arke_, थाप्, tnaq_, 
   {{0x395801f5,0x4ca80eac,0xb95402e8,0xdde80133}},	//   _ptss_, খাগু, зващ, _نرخه_, 
   {{0xb5fc0316,0x3b08bc4e,0xb7d40241,0x78781719}},	// [f450] _vešk, rnaq_, _iṣik, ййар_, 
   {{0x7e6cbc4f,0x3b080477,0x1158010f,0x00000000}},	//   _heap, snaq_, ידמע, --, 
   {{0x7aec2ffc,0xb5fc04b9,0x7e6cbc50,0x7798bc51}},	//   phat, _tešk, _keap, скер_, 
   {{0x7aecbc52,0xc0e402d3,0x3b08014f,0xec34011a}},	//   qhat, _ዝኽሪ_, qnaq_, _מאתר_, 
   {{0x7e6cbc53,0x1dc800dc,0x7afc0112,0xa2cc00cd}},	//   _meap, ामित, _imst, थान्, 
   {{0x7e6cbc54,0xb5fcbc55,0xdfc400c6,0x00000000}},	//   _leap, _ješi, _كي_, --, 
   {{0xb5fcbc56,0x7e6c00c7,0x7afc0fac,0xa520009d}},	//   _meši, _oeap, _kmst, эмшд, 
   {{0x7e6cbc57,0x2d806ab9,0x78b40e8a,0xd6c024c5}},	//   _neap, yrke_, _hazv, _تمری, 
   {{0x61f409a5,0x78b40099,0x7afc00b5,0x764803ac}},	//   _ýyll, _kazv, _mmst, _igey, 
   {{0xb5fcbc58,0xe1f4bc59,0x78b400d0,0xef8462d9}},	//   _neši, ягы_, _jazv, плоп, 
   {{0x78b40433,0x7e6c00b5,0xb9f0001f,0xef18bc5a}},	//   _mazv, _beap, _ነጭ_, ймо_, 
   {{0x7e6cbc5b,0x2b580165,0x00000000,0x00000000}},	//   _ceap, _rtpc_, --, --, 
   {{0xb5fc0960,0x7e6c00e4,0x3228005e,0x2d80002d}},	//   _beši, _deap, _اتاۋ_, urke_, 
   {{0x78b4bc5c,0xeab0066d,0x6ee402ea,0x307800c8}},	//   _nazv, کٹر_, _tóbo, _האַנ, 
   {{0xb5fc02d5,0x76480050,0x7e6cbc5d,0x63480381}},	//   _deši, _ogey, _feap, _pęni, 
   {{0x7648bc5e,0x95280135,0x7e6cbc5f,0x7c24493a}},	//   _ngey, _སེའི_, _geap, _dyhr, 
   {{0x78b401e4,0x6ab4015d,0x00000000,0x00000000}},	// [f460] _bazv, rdyf, --, --, 
   {{0x76480083,0x7afcbc60,0x1cc8031c,0x6ab40142}},	//   _agey, _emst, _ཊོར_, sdyf, 
   {{0x70a80316,0x78b40165,0x7e6cbc61,0x00000000}},	//   _कसैल, _dazv, _yeap, --, 
   {{0x5b54011a,0xb5fc01ef,0x00000000,0x00000000}},	//   _מיטב_, _zeši, --, --, 
   {{0x9f58006a,0x78b40369,0xe4e40111,0x00000000}},	//   _âpö_, _fazv, зійн, --, 
   {{0x7648009a,0x9630177b,0x791801b9,0x3934009d}},	//   _egey, хніц, _дўст_, _жэсс, 
   {{0x94702807,0x147003e6,0x1cc80327,0xe0b400b8}},	//   ردوا, راوج, _ཊོལ_, _nyāḥ_, 
   {{0x76481418,0xe6d401c4,0x00000000,0x00000000}},	//   _ggey, _эцгэ, --, --, 
   {{0x78b4006f,0xe578bc62,0xe04807d6,0x00000000}},	//   _yazv, _ыза_, یشگه_, --, 
   {{0x76480175,0x7e6c6b41,0x2a700009,0x52100006}},	//   _zgey, _seap, hayb_, эдыт, 
   {{0xb5fcbc63,0x7e6cbc64,0xb3e815b0,0x8cd00950}},	//   _reši, _peap, _وعمل_, दानो, 
   {{0xb5fcbc65,0x00000000,0x00000000,0x00000000}},	//   _seši, --, --, --, 
   {{0xb5fcbc66,0x7e6cbc67,0xd24c00c6,0x009401c0}},	//   _peši, _veap, _إنه_, _жилэ, 
   {{0xc900000e,0xd12c10f5,0x7e6cbc68,0xd238011a}},	//   ্তুত_, _їх_, _weap, _הגדל, 
   {{0x50b40597,0x7e6cbc69,0xb5fc0030,0xdef80139}},	//   _ردود_, _teap, _veši, _гып_, 
   {{0x7c240745,0x7e6c0327,0x00000000,0x00000000}},	//   _vyhr, _ueap, --, --, 
   {{0x78b405b8,0xb5fcbc6a,0x00000000,0x00000000}},	// [f470] _pazv, _teši, --, --, 
   {{0x7e9801d9,0x78b4022e,0x9c600228,0x3eb86d54}},	//   _اچھر_, _qazv, _سۇرو, ldst_, 
   {{0x78b40433,0x36d40a5b,0x00000000,0x00000000}},	//   _vazv, можр, --, --, 
   {{0x7afcbc6b,0x3eb8019b,0x92c40729,0x78b4006f}},	//   _umst, ndst_, _উত্_, _wazv, 
   {{0x83fc1326,0x78b4004c,0xa5600014,0x00000000}},	//   _među, _tazv, نگٕن, --, 
   {{0x64a0bc6c,0x00000000,0x00000000,0x00000000}},	//   ваша, --, --, --, 
   {{0x0478004b,0xb5fc5746,0x61f4010e,0x00000000}},	//   سليک_, _nešv, _ýylj, --, 
   {{0x76480067,0xa2c00116,0xd498030d,0x32440150}},	//   _ugey, кәчк, _ӳре_, мейг, 
   {{0x3eb80036,0xd498009b,0xe0b400b8,0x00000000}},	//   ddst_, _гре_, _syāḥ_, --, 
   {{0xccf4016b,0xafe400cf,0xf4844ea7,0x00000000}},	//   _atɛn_, доол, _زائی, --, 
   {{0xc0bc01f3,0xb6380220,0x00000000,0x00000000}},	//   ታትሎ_, _ﻘﻓ_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdfcc16cb,0x2a70009f,0x48b80183,0x273c0118}},	//   _چيو_, wayb_, _আক্ৰ, _vůni_, 
   {{0x9d402dfa,0xdfcc774e,0xb5fc00ef,0xdbb800c7}},	//   терд, _نيو_, _iešu, оттә_, 
   {{0xee08bc6d,0x3eb8010a,0xb0600139,0x00000000}},	//   _мейл_, cdst_, _ğäyb, --, 
   {{0x2a70007f,0x09c800cd,0xb0600139,0xa2cc043e}},	// [f480] rayb_, रमेय, _şäyb, थात्, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xab280139,0x61240ad9,0x2a70058a,0xf6e40006}},	//   _фома_, rðli, qayb_, нцін, 
   {{0x6da4016b,0x00000000,0x00000000,0x00000000}},	//   _wɔaf, --, --, --, 
   {{0xb4b400c7,0xb5fc0064,0x00000000,0x00000000}},	//   еишә, _nešu, --, --, 
   {{0x2618000d,0x00000000,0x00000000,0x00000000}},	//   _बडकी_, --, --, --, 
   {{0x86f817a6,0x61f4010b,0x00000000,0x00000000}},	//   _عکاس_, _ýylk, --, --, 
   {{0x651404d3,0x22400254,0xe51400cd,0x00000000}},	//   _قورئ, äkk_, _तदपि_, --, 
   {{0xf65000f8,0x6560bc6e,0x64340597,0x00000000}},	//   _لئے_, mpoh, _قراء, --, 
   {{0x6458bc6f,0xe298bc70,0x7c280198,0xf3ec013e}},	//   _ifti, _маж_, ƙeri, _сӣ_, 
   {{0x656001f4,0x00000000,0x00000000,0x00000000}},	//   opoh, --, --, --, 
   {{0x800800dd,0x3eb85282,0x65600e03,0x20002c20}},	//   ترکہ_, rdst_, npoh, ńki_, 
   {{0x28d01889,0x656000e4,0x00000000,0x00000000}},	//   साफि, ipoh, --, --, 
   {{0x28d06c5a,0x65600205,0x00000000,0x00000000}},	//   सानि, hpoh, --, --, 
   {{0x3f8c03b4,0xefd81772,0x68ec0200,0x795800c7}},	//   mudu_, ዮጲያ_, _albd, зиар_, 
   {{0xb5fc038e,0x3f8c003d,0x6458bc71,0x65600306}},	// [f490] _ješt, ludu_, _ofti, jpoh, 
   {{0xb5fc39ae,0xa3cc0316,0x68ec01ab,0xf8c80456}},	//   _mešt, शमा_, _clbd, राइय, 
   {{0x3f8c04b9,0xb5fc0122,0x29a40022,0x00000000}},	//   nudu_, _lešt, _ҿырҳ, --, 
   {{0x6458bc72,0xdc000306,0xfd4c0055,0xda64216b}},	//   _afti, nčím, _sunṛ, _تادي, 
   {{0xb5fc04b9,0x3f8cbc73,0x6ee401e7,0xdbdc00c7}},	//   _nešt, hudu_, _dóbh, pãóp, 
   {{0x3f8c5ad8,0x6da4016b,0x798c0083,0xdc0002f0}},	//   kudu_, _wɔag, muaw, hčím, 
   {{0xa5602e51,0x3f8c17fa,0xb5fc09a8,0x889401c0}},	//   نگەن, judu_, _rešu, _ширх, 
   {{0x645808d2,0xb5fcbc74,0x3f8c08e7,0x612403b2}},	//   _efti, _sešu, dudu_, iðlu, 
   {{0x3178066d,0xb144134b,0xb5fc0841,0x95547c3c}},	//   ész_, ннил, _pešu, _آخرا, 
   {{0x28d09f23,0xb5fc219b,0x3f8c6ca2,0x6aa001e4}},	//   सायि, _dešt, fudu_, ĵofi, 
   {{0x3f8c55fa,0x798c0069,0x31300023,0xafe401d5}},	//   gudu_, huaw, _ብእግዚ, хонл, 
   {{0xb5fc2375,0x798cbc75,0x3274008f,0x09e4009e}},	//   _fešt, kuaw, _װײַל_, _নেফা, 
   {{0xc2c418a1,0xeab801c0,0xe1ec00f3,0xb5fc25ad}},	//   _جيني, үйг_, _сг_, _gešt, 
   {{0x6ee4172e,0x3f8cbc76,0x00000000,0x00000000}},	//   _móbi, budu_, --, --, 
   {{0x09c81a2a,0x3f8c7225,0xb5fc0118,0x9c140166}},	//   रम्य, cudu_, _zešt, ечтә, 
   {{0x656000e4,0x00000000,0x00000000,0x00000000}},	//   ypoh, --, --, --, 
   {{0xae040131,0x6ee4bc77,0xa8c4010b,0x798c02d0}},	// [f4a0] _سودى, _nóbi, нйад, guaw, 
   {{0xb86410ed,0x92a8015b,0xc9002b1b,0xeb980395}},	//   نامو, খায়_, ্ত্ত_, _еио_, 
   {{0x6da40134,0xb8940801,0xa684bc78,0x66e4bc79}},	//   _wɔad, ъртъ, елед, ножа, 
   {{0x6a8418c7,0xc0bc0023,0x27340145,0x00000000}},	//   _ялма, ታትሓ_, رىشس, --, 
   {{0x64580334,0xa2cc00dc,0x6b8c022e,0x20d0076e}},	//   _pfti, थास्, lubg, तामध, 
   {{0xb5fc01a2,0x6f0403f0,0x656002f0,0x24f40276}},	//   _rešt, hikc, rpoh, эчер, 
   {{0xfd680521,0xccf40134,0xb5fc09a8,0x6560bc7a}},	//   _bipụ, _ntɛm_, _sešt, spoh, 
   {{0x8558bc7b,0xb5fc5c92,0x3f8c009b,0x21644f41}},	//   _قیصر_, _pešt, vudu_, нтог, 
   {{0x3f8c2784,0x05440588,0x6720208d,0x6f044dd9}},	//   wudu_, _адаҟ, mooj, dikc, 
   {{0xb5fcbc7c,0x6720bc7d,0x3f8cbc7e,0x5574008f}},	//   _vešt, looj, tudu_, _נעבן_, 
   {{0x6f04738e,0xa3c80cb4,0x78a0bc7f,0x228401c4}},	//   fikc, _लपट_, _ölve, _зулг, 
   {{0x3f8cbc80,0xb5fc0419,0xe29838ad,0xf1a800ec}},	//   rudu_, _tešt, _хад_, _ڊاهه_, 
   {{0xc0ec0020,0x3f8c098d,0x00000000,0x00000000}},	//   ኅበረ_, sudu_, --, --, 
   {{0x672001d4,0xfd6801f2,0x3f8c107d,0xc0bc0092}},	//   hooj, _zipụ, pudu_, ታትም_, 
   {{0xee9403e6,0x2cb80112,0x672001f4,0x6f0400ef}},	//   ردێک, _dapd_, kooj, bikc, 
   {{0x798c02b1,0xe7f800af,0x00000000,0x00000000}},	//   tuaw, _एइजा_, --, --, 
   {{0x3f7c01e4,0xbf1c0073,0x09e400eb,0x00000000}},	// [f4b0] lĉu_, नवीन_, _নেবা, --, 
   {{0xc0ec001f,0x798c02b1,0xd5e80022,0x78080139}},	//   ኅበሩ_, ruaw, hag̃, мьең_, 
   {{0xd7f800c7,0xb06400c5,0x3f7c0115,0x475800d4}},	//   чуа_, lhää, nĉu_, ерія_, 
   {{0x7bc4bc81,0x798c02b5,0x48240131,0x6b98004e}},	//   _irhu, puaw, دىمق, àtge, 
   {{0x04b801d3,0xd5a00ed8,0x76580142,0x00000000}},	//   ڑپوں_, التی, rcwy, --, 
   {{0x2118bc82,0x3834bc83,0xb5fc00ef,0x00000000}},	//   नकोश_, _ангр, _sešs, --, 
   {{0x969000aa,0x67200014,0x23b000ae,0x00000000}},	//   _میاش, booj, لموس, --, 
   {{0x7bc4bc84,0xb5fc0024,0xa28065dc,0x6700014b}},	//   _mrhu, _dešr, لیمو, _кӯчб, 
   {{0xfe000037,0x00000000,0x00000000,0x00000000}},	//   _लेलस_, --, --, --, 
   {{0x7bc42093,0x61e4bc85,0x44b401af,0x09e400cc}},	//   _orhu, økla, _йбус, _নেডা, 
   {{0x12e400d6,0x7bc40218,0x6f04bc86,0x00000000}},	//   _підг, _nrhu, tikc, --, 
   {{0x2cb80ea0,0x8e24022e,0x61f40210,0x00000000}},	//   _sapd_, аmа_, _żyle, --, 
   {{0x7bc4bc87,0x6f04bc88,0x00000000,0x00000000}},	//   _arhu, rikc, --, --, 
   {{0x332c0393,0x7bc40882,0x3eac01e4,0x6f0401bf}},	//   llex_, _brhu, ĵeta_, sikc, 
   {{0x672000e8,0x00000000,0x00000000,0x00000000}},	//   yooj, --, --, --, 
   {{0x332c37e9,0x00000000,0x00000000,0x00000000}},	//   nlex_, --, --, --, 
   {{0xee380c04,0x6da40134,0x7bc4bc89,0xa9248ed5}},	// [f4c0] _юни_, _wɔab, _erhu, вдал, 
   {{0xdb140166,0x332c00b5,0x1cc80327,0x28d01684}},	//   _arxä, hlex_, _ཊོག_, साधि, 
   {{0x6a84151e,0xae0402dd,0x6720bc8a,0x00000000}},	//   _илна, _سوگى, tooj, --, 
   {{0xf1d02a09,0x213c00d8,0xe6b001b9,0x237401d9}},	//   तमान, zmth_, شلتگ, ۆلتھ_, 
   {{0xf748bc8b,0x6720198f,0x2c040073,0x28d0043e}},	//   رجمه_, rooj, _हेतू_, सादि, 
   {{0xd5ac24e0,0x6720bc8c,0x69c4bc8d,0x00000000}},	//   تفه_, sooj, _irke, --, 
   {{0x2ef00af9,0x00000000,0x00000000,0x00000000}},	//   _olyf_, --, --, --, 
   {{0x3f8004ac,0xdb0c01ed,0x69d4009a,0xc1b84b1f}},	//   _ĉiu_, ődöt, oxye, елих_, 
   {{0x09e411ba,0xe3b005d9,0xe570007b,0x84c401ec}},	//   _নেতা, ارڻ_, _خطأ_, _бәйд, 
   {{0x69c40707,0xb5fc00ef,0x00000000,0x00000000}},	//   _mrke, _iešp, --, --, 
   {{0x42a4bc8e,0x332c0998,0x3af408fb,0x6ee409c2}},	//   _булғ, blex_, _håpe_, _lóbu, 
   {{0x69c4bc8f,0x0fe000f7,0x442c022e,0x1cc8031c}},	//   _orke, рөшү, _iyd_, _ཊོང_, 
   {{0x442c0f7b,0x62804091,0xddcc0311,0xb5fc0010}},	//   _hyd_, _idoo, dacţ, _ješp, 
   {{0x7bc4107d,0x7f947701,0xb064000d,0x00000000}},	//   _prhu, _бакх, rhää, --, 
   {{0x69c4bc90,0x4fb01541,0x5f74007b,0xddcc0356}},	//   _arke, _نصير, _شاغر, facţ, 
   {{0x442cbc91,0x8f080408,0x00000000,0x00000000}},	//   _myd_, _ахьа_, --, --, 
   {{0x442c6ab9,0x4a54bc92,0xb5fcbc93,0xb994007b}},	// [f4d0] _lyd_, ркус, _nešp, طلاب, 
   {{0x8d7404a9,0x332c0998,0x7bc405be,0xdb581e4a}},	//   _ئايا, zlex_, _trhu, _оюм_, 
   {{0x69c4bc94,0x7bc4bc95,0x442c037e,0x6280bc96}},	//   _erke, _urhu, _nyd_, _odoo, 
   {{0x35f4040e,0x62801bce,0x6284bc97,0x5ec000eb}},	//   лпер, _ndoo, ókol, ৎসকে, 
   {{0x7aecbc98,0x442c1368,0x3ce00037,0x068438a9}},	//   mkat, _ayd_, _kohv_, ргін, 
   {{0x7aecbc99,0x442c0cfd,0x6280bc9a,0xb4bc2871}},	//   lkat, _byd_, _adoo, इये_, 
   {{0x442c00a9,0x399c04cc,0xf2a4004e,0xd76015b4}},	//   _cyd_, lìs_, гийп, _خنزی, 
   {{0x442cbc9b,0x69c41121,0xd040043b,0x7f4c20ac}},	//   _dyd_, _yrke, _monɔ, _niaq, 
   {{0x7aecbc9c,0x5800005e,0x442cbc9d,0x6280bc9e}},	//   ikat, _соңғ, _eyd_, _ddoo, 
   {{0x7aecbc9f,0x62800083,0x442c0368,0x00000000}},	//   hkat, _edoo, _fyd_, --, 
   {{0x332cbca0,0x6e34006d,0x3b08bca1,0x442c00a9}},	//   plex_, _szyb, kiaq_, _gyd_, 
   {{0x7aecbca2,0x7d040332,0x0d840116,0xd1b800d1}},	//   jkat, _amhs, аһин, _ياشا_, 
   {{0x6aa40109,0x7aec4f60,0x7f4c0213,0xa11003e6}},	//   _rbkf, dkat, _diaq, _گووت, 
   {{0x7aec0a49,0x941401f9,0x00000000,0x00000000}},	//   ekat, _तशाच_, --, --, 
   {{0x7aecbca3,0x3b08013c,0x80247f51,0xc0580212}},	//   fkat, fiaq_, _پروم, _річ_, 
   {{0x7aec1085,0x3b080140,0xfaf400d4,0x69c4013a}},	//   gkat, giaq_, ачую, _prke, 
   {{0xddcc0276,0xe8c8bca4,0x00000000,0x00000000}},	// [f4e0] racţ, нгал_, --, --, 
   {{0x7aecbca5,0xb5fc0030,0xb4bcbca6,0xdca0030d}},	//   akat, _rešp, इयो_, _лаьи, 
   {{0x6d54bca7,0x3af408fb,0x799c02d0,0x1cb402e4}},	//   _huya, _såpe_, _eqsw, _גליל_, 
   {{0xe61892fd,0x7aecbca8,0x667491e8,0x442c84ae}},	//   нде_, ckat, ادار, _ryd_, 
   {{0x442c0726,0x6d54bca9,0xa504bcaa,0x45d428fb}},	//   _syd_, _juya, лякл, ролс, 
   {{0x6d54bcab,0x7c2803fa,0x442c5b6b,0xdb200248}},	//   _muya, ßerg, _pyd_, _ìròn, 
   {{0x746800d6,0xf48402dd,0x78a008a5,0x23240798}},	//   трів_, руін, _ölva, лфиг, 
   {{0x6d542f05,0x41b42088,0x61e40158,0x05140154}},	//   _ouya, لمبر, øklo, িতের_, 
   {{0x442cbcac,0x7f4cbcad,0x6d54bcae,0xa3d001b9}},	//   _wyd_, _riaq, _nuya, роқч, 
   {{0x442c0591,0x7aec05f5,0x7f4c0194,0x19b400df}},	//   _tyd_, zkat, _siaq, נפיר_, 
   {{0x4034bcaf,0x7aecbcb0,0x6d540810,0x7f4c20ac}},	//   ренс, ykat, _auya, _piaq, 
   {{0xd36c168d,0x63b8068f,0x62807c86,0x7aecbcb1}},	//   _رهه_, _istn, _udoo, xkat, 
   {{0x6d54bcb2,0x7aec01a9,0x3b080140,0xa3dc0118}},	//   _cuya, vkat, viaq_, věří_, 
   {{0x6d54bcb3,0x7f4c0113,0xbb300873,0x7aec0113}},	//   _duya, _wiaq, ﺭﺩﻩ_, wkat, 
   {{0x7f4c0d04,0x7aecbcb4,0x3b080d04,0x6d540098}},	//   _tiaq, tkat, tiaq_, _euya, 
   {{0x6d54bcb5,0x3dac0183,0x7aecbcb6,0x61f4010e}},	//   _fuya, খিবল, ukat, _ýyls, 
   {{0x6d54bcb7,0x7aecbcb8,0x3ea8bcb9,0x3b08bca1}},	// [f4f0] _guya, rkat, _ibat_, riaq_, 
   {{0x7aecbcba,0x3dc802d1,0x3b0820ac,0x63b8bcbb}},	//   skat, _iraw_, siaq_, _ostn, 
   {{0xb8dcbcbc,0x7aecbcbd,0x7c280639,0x3b08020c}},	//   _आस_, pkat, ßerd, piaq_, 
   {{0x6d541bb7,0xbb3023f6,0xda640150,0x7c280e2d}},	//   _yuya, ﺭﺩﻯ_, _حادي, ğerd, 
   {{0x55c00046,0x3ea80097,0x63b801e4,0x6d54002e}},	//   салғ, _mbat_, _astn, _xuya, 
   {{0x2eb0038e,0x3dc80649,0x798cbcbe,0xd77400cf}},	//   _जस्त, _mraw_, mraw, _مارع, 
   {{0x3ea85447,0x200800d0,0x28d04f3c,0x33d401ec}},	//   _obat_, úbil_, सारि, рілт, 
   {{0x61f4012d,0x00000000,0x00000000,0x00000000}},	//   _żyla, --, --, --, 
   {{0x63b8bcbf,0x798cbcc0,0xc0c00023,0xbb500150}},	//   _estn, nraw, _ኵሎም_, _ﺎﺘﻑ_, 
   {{0x60e40b30,0x6ee40798,0x798cbcc1,0x6d54bcc2}},	//   имым_, _nóbr, iraw, _ruya, 
   {{0x3dc8bcc3,0x6d54bcc4,0x798c00a9,0x758001d3}},	//   _araw_, _suya, hraw, _ایڈم, 
   {{0xed58aa53,0x6d54bcc5,0x3dc81c1d,0x00000000}},	//   ком_, _puya, _braw_, --, 
   {{0x3dc80493,0x3f8c08e5,0x6d54bcc6,0xad2407fc}},	//   _craw_, ardu_, _quya, لرسو, 
   {{0x6d5402c4,0x6ee40005,0x272c0008,0x3dc8bcc7}},	//   _vuya, _cóbr, rýni_, _draw_, 
   {{0x6d540c09,0x272c0ad9,0x798c1418,0xef18010b}},	//   _wuya, sýni_, eraw, _имк_, 
   {{0xf1a84425,0x3dc80042,0x63bc0158,0xa7d40066}},	//   _कहान, _fraw_, æpni, یتاص, 
   {{0x798cbcc8,0x6d54bcc9,0xc0d402d3,0xed3400c0}},	// [f500] graw, _uuya, ርሓሉ_, _вэнэ, 
   {{0xdd78008f,0x9ad001f2,0x3ea80356,0x63b4012d}},	//   _שטיל, rịal, _zbat_, łyni, 
   {{0x798c011c,0x62841686,0x09e40154,0xdb200244}},	//   araw, ókok, _নেশা, _ژوپی, 
   {{0x7c64004b,0x7c2803fa,0x798cbcca,0x2600022e}},	//   _پایل, ßere, braw, _fаol_, 
   {{0x28747798,0xb4b00210,0x00000000,0x00000000}},	//   _выбр, टजू_, --, --, 
   {{0x051400bd,0x7c287bfb,0xa3b00316,0x3f8c022c}},	//   িত্র_, şere, टबल_, yrdu_, 
   {{0x3af400cc,0x59040276,0xd374bccb,0xd9180375}},	//   _håpa_, _терм_, ачы_, _סולל, 
   {{0xe738010b,0x3f8c0841,0x3af401e3,0x200800d7}},	//   _реб_, vrdu_, _kåpa_, úbim_, 
   {{0xb5a800c6,0x00000000,0x00000000,0x00000000}},	//   _مالك_, --, --, --, 
   {{0x60e42773,0x00000000,0x00000000,0x00000000}},	//   рциз, --, --, --, 
   {{0x63b8bccc,0x3f8c009a,0x00000000,0x00000000}},	//   _ustn, urdu_, --, --, 
   {{0xd36c1d1f,0x6ee40798,0x3dc80034,0x798cbccd}},	//   _آهن_, _sóbr, _praw_, yraw, 
   {{0x3ea80048,0x6da4013b,0x3dc8031c,0x00000000}},	//   _vbat_, _wɔan, _qraw_, --, 
   {{0x3e7401fb,0x3dc8030a,0x00000000,0x00000000}},	//   ất_, _vraw_, --, --, 
   {{0x61b40d41,0xec181945,0x09e400cc,0x798c0327}},	//   _अनुष, герә_, _নেলা, wraw, 
   {{0x3ea80020,0x3dc8bcce,0x00000000,0x00000000}},	//   _ubat_, _traw_, --, --, 
   {{0x798cbccf,0x7e7cbcd0,0x7f580455,0x3dc80139}},	// [f510] uraw, masp, _huvq, _uraw_, 
   {{0x7e7cbcd1,0x798cbcd2,0x00000000,0x00000000}},	//   lasp, rraw, --, --, 
   {{0x798c04fb,0xdde8411c,0x00000000,0x00000000}},	//   sraw, _سرکه_, --, --, 
   {{0x798c006d,0x7e7c0bf1,0x7f580455,0x00000000}},	//   praw, nasp, _muvq, --, 
   {{0xc984bcd3,0x7e7c0113,0x798cbcd4,0x61f40210}},	//   _мури, iasp, qraw, _żyln, 
   {{0x7e7cbcd5,0x7cf800a3,0xa85401af,0x272c02d2}},	//   hasp, _fìre, _герә, dýnu_, 
   {{0x7e7cbcd6,0x3958bcd7,0x7f580455,0x00000000}},	//   kasp, _huss_, _nuvq, --, 
   {{0x7e7cbcd8,0x3958bcd9,0x32b8007b,0x00000000}},	//   jasp, _kuss_, ادثة_, --, 
   {{0xd4980262,0x3958bcda,0xc30403e6,0x35f44031}},	//   _аре_, _juss_, تبوو, _упар, 
   {{0x395802b8,0x7f580455,0xa3a400ec,0xe294bcdb}},	//   _muss_, _buvq, _ڇڏيل_, _ғаш_, 
   {{0x7e7cbcdc,0x3958bcdd,0x04c801e2,0x00000000}},	//   fasp, _luss_, _خولي_, --, 
   {{0x7e7cbcde,0x386000e4,0x51940354,0x37b800cc}},	//   gasp, hchr_, _кăма, _ইপাৰ, 
   {{0xccf8bcdf,0x39580112,0xa254011a,0x30740108}},	//   иқи_, _nuss_, _הבנק_, _луйс, 
   {{0xeb98bce0,0x8234bce1,0xa0640354,0x00000000}},	//   лиг_, _برما, _лаша_, --, 
   {{0x6f9406d5,0x7e7cbce2,0x3958bce3,0x3af401e3}},	//   _العض, basp, _auss_, _såpa_, 
   {{0x39580efa,0xbf64bce4,0x00000000,0x00000000}},	//   _buss_, _بدوو, --, --, 
   {{0x39582353,0x9c800010,0x00000000,0x00000000}},	// [f520] _cuss_, _ščem, --, --, 
   {{0x2d80b384,0xa854026a,0x7c340008,0x395803b2}},	//   mske_, стај, ðfræ, _duss_, 
   {{0x1b400014,0xff500205,0x7c280205,0x00000000}},	//   تھیُ, _üçüz_, ğerc, --, 
   {{0x39581570,0xf72800d6,0x856802d3,0x2d80020c}},	//   _fuss_, ацій_, _ዝተፈጥ, oske_, 
   {{0x39580048,0xa14000e2,0x26d005d1,0x1a98010f}},	//   _guss_, šķil, ıyo_, _גיכע, 
   {{0x2b580117,0x2d8005ac,0x6ab40008,0x7e7cbce5}},	//   _kupc_, iske_, leyf, zasp, 
   {{0x2908bce6,0x2d80000f,0x7e7cbce7,0x83f86e1e}},	//   _imba_, hske_, yasp, рейс_, 
   {{0x26c0019f,0x2d808d56,0x7e7c01c4,0x00000000}},	//   _ûko_, kske_, xasp, --, 
   {{0x7f580455,0x9f48bce8,0xe61877a8,0xa2e401d5}},	//   _suvq, ábí_, _сда_, _қодд, 
   {{0x2d8004b9,0x7e7cbce9,0xd04001e4,0x00000000}},	//   dske_, wasp, _konɨ, --, 
   {{0x7e7cbcea,0xd8d800c8,0x54d40050,0x2d80000f}},	//   tasp, אקיר, _دِلس_, eske_, 
   {{0x2908070d,0xd04001e4,0x7f58014f,0x5438010f}},	//   _lmba_, _monɨ, _vuvq, _געבא, 
   {{0x7e7cbceb,0x29080588,0x2b580175,0x2d80bcec}},	//   rasp, _omba_, _aupc_, gske_, 
   {{0x3958bced,0x7e7cbcee,0x26c8016b,0x7f58014f}},	//   _russ_, sasp, _ɔboa_, _tuvq, 
   {{0x7e7cbcef,0x2d80000f,0x38c813de,0x395000e5}},	//   pasp, aske_, یائی_, _rizs_, 
   {{0x29080dc9,0x39580250,0x2d8024c6,0x7e7c03f0}},	//   _amba_, _puss_, bske_, qasp, 
   {{0x395005d5,0x2d8001d3,0x69c0009d,0x00000000}},	// [f530] _pizs_, cske_, мөрб, --, 
   {{0xd7f80064,0x4ddc011a,0x00000000,0x00000000}},	//   луе_, _תחזו, --, --, 
   {{0x96e84855,0x4ac4193d,0x39580076,0xc95801d5}},	//   льда_, _लोकव, _wuss_, _қўя_, 
   {{0x2908bcf0,0x3860bcf1,0xf1a800af,0xf9d4009d}},	//   _emba_, schr_, _कहलन, _домэ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xca4c0150,0x00000000,0x00000000,0x00000000}},	//   _ﻀﺎﺀ_, --, --, --, 
   {{0x494c02d3,0x02c40b02,0xb6c4013d,0x2d800419}},	//   _ጐረባብ, वयंभ, _мөдд, zske_, 
   {{0x2d80334b,0x42b8a70b,0x00000000,0x00000000}},	//   yske_, منىڭ_, --, --, 
   {{0xdec40201,0x8b080118,0x828400ae,0x00000000}},	//   ችንን_, _hořá, سجيل, --, 
   {{0xef84361e,0x6fa80063,0x61e43f3b,0x00000000}},	//   олоп, авог_, äkla, --, 
   {{0xef18bcf2,0x2d80000f,0x8544013d,0x20000115}},	//   имо_, wske_, _хэте, ŝkin_, 
   {{0x2d80bcf3,0x6da4bcf4,0x5f4001d5,0x00000000}},	//   tske_, _wɔam, وچيل, --, 
   {{0xed58736a,0x11644d2f,0x2d80000f,0x4ac400c5}},	//   рог_, _التی_, uske_, _लोगव, 
   {{0x91c0bcf5,0x2d80119a,0x316cbcf6,0xdbc40008}},	//   _дәүл, rske_, mpez_, töðv, 
   {{0x316c01c4,0x00000000,0x00000000,0x00000000}},	//   lpez_, --, --, --, 
   {{0x2d800552,0xed580a16,0xeb98036b,0x290801bf}},	//   pske_, _кои_, лиҳ_, _smba_, 
   {{0xe9d8bcf7,0x5c380092,0x00000000,0x00000000}},	// [f540] шка_, _በድፍረ, --, --, 
   {{0xceb80032,0x316c0129,0x00000000,0x00000000}},	//   _тәү_, ipez_, --, --, 
   {{0xb86400db,0x320006be,0x00000000,0x00000000}},	//   سالو, _əhya_, --, --, 
   {{0x76a802bf,0x00000000,0x00000000,0x00000000}},	//   йтів_, --, --, --, 
   {{0x443800d7,0x00000000,0x00000000,0x00000000}},	//   _šr_, --, --, --, 
   {{0x29084f4e,0x3eac01e4,0x00000000,0x00000000}},	//   _umba_, ĵeti_, --, --, 
   {{0x04880032,0x4394bcf8,0x7dfc06be,0x6ec83be5}},	//   _ғәли_, чайс, _mьsa, ियाँ, 
   {{0x7cf801e1,0xa1a8005a,0x00000000,0x00000000}},	//   _mìra, атоз_, --, --, 
   {{0x29180ea0,0xe3b000ec,0x95800117,0x00000000}},	//   onpa_, _ڊرا_, _олте, --, 
   {{0xe3d40150,0xb5fc00c0,0x6600010e,0x00000000}},	//   _وتاع, _nešy, mzok, --, 
   {{0x4438bcf9,0x26c4058a,0xdbc40254,0x291801f4}},	//   _ár_, odoo_, lööv, inpa_, 
   {{0x26c4bcfa,0x3eac09a5,0x00000000,0x00000000}},	//   ndoo_, ýet_, --, --, 
   {{0x25a4bcfb,0x4cc402f5,0x6600bcfc,0x26c4bcfd}},	//   ntol_, শানু, nzok, idoo_, 
   {{0x6600004c,0x26c40009,0xdbb00139,0x00000000}},	//   izok, hdoo_, магө, --, 
   {{0xdbc40254,0x00000000,0x00000000,0x00000000}},	//   hööv, --, --, --, 
   {{0x25a4bcfe,0x00000000,0x00000000,0x00000000}},	//   ktol_, --, --, --, 
   {{0x3eb8bcff,0xc0d40020,0x26c4bd00,0xa2a044af}},	// [f550] mest_, ርጓል_, ddoo_, _गान्, 
   {{0x3eb8bd01,0x8b080316,0x66000e8a,0x26c4343b}},	//   lest_, _pořá, dzok, edoo_, 
   {{0xb06402f6,0x9ba021ef,0x25a40419,0x00000000}},	//   lkää, _تەزى, etol_, --, 
   {{0x070800f1,0x41bc8109,0x29180108,0x00000000}},	//   ييلي_, ्टास, anpa_, --, 
   {{0xb064049b,0x3eb80fac,0x25a40174,0xa2bc0b8f}},	//   nkää, iest_, gtol_, वजन्, 
   {{0xe4c000c9,0x9de0013f,0x26c4058a,0x3eb8bd02}},	//   ейши, ɔbɔɔ_, adoo_, hest_, 
   {{0x3eb8bd03,0xdec40020,0x26c40ba7,0x660005da}},	//   kest_, ችንና_, bdoo_, azok, 
   {{0x3eb81727,0x8c1c05e1,0xb06402f6,0x26c4058a}},	//   jest_, יווי, kkää, cdoo_, 
   {{0x25a4bd04,0x34940228,0xf55812e3,0x3eb8b28d}},	//   ctol_, _наар, _طلاب_, dest_, 
   {{0x6da4013b,0x3eb8bd05,0x66d0022e,0x00000000}},	//   _wɔak, eest_, lаkа, --, 
   {{0x3254bd06,0x316c8489,0x85047aaf,0xc954011a}},	//   _евер, spez_, _تولن, ומץ_, 
   {{0x316c07ea,0x3eb8bd07,0x00000000,0x00000000}},	//   ppez_, gest_, --, --, 
   {{0xc8840166,0x00000000,0x00000000,0x00000000}},	//   _yuğı_, --, --, --, 
   {{0x09b404c5,0x680001e1,0xdc640fbe,0xb80003d4}},	//   ঘিমা, _jíjé, зард_, _এখনত_, 
   {{0xad243baf,0x1d04bd08,0xb5fc6c3c,0x26c4058a}},	//   قىڭى, чери_, _ofšo, ydoo_, 
   {{0x25a400d0,0x3eb82517,0x26c4058a,0x00000000}},	//   ytol_, cest_, xdoo_, --, 
   {{0xe8f81685,0x00000000,0x00000000,0x00000000}},	// [f560] бла_, --, --, --, 
   {{0x26c40009,0x00000000,0x00000000,0x00000000}},	//   wdoo_, --, --, --, 
   {{0x66640395,0x00000000,0x00000000,0x00000000}},	//   пълз, --, --, --, 
   {{0xe73809fe,0x660001c0,0xe5a4bd09,0xdecc1ee0}},	//   щее_, tzok, зиди, _ቤቱን_, 
   {{0x26c4948b,0x00000000,0x00000000,0x00000000}},	//   rdoo_, --, --, --, 
   {{0xdbc400c5,0x26c40076,0xc8b400f2,0x25a4072d}},	//   rööv, sdoo_, _تلسک, rtol_, 
   {{0x6600066d,0x25a4bd0a,0x6da4013b,0xd940bd0b}},	//   szok, stol_, _wɔah, _чери, 
   {{0x52803ee0,0x25a4107d,0xe5a4004e,0xc298005b}},	//   ىلىك, ptol_, _ниби, цких_, 
   {{0x25a4025c,0x7af000e5,0x00000000,0x00000000}},	//   qtol_, _éjtő, --, --, 
   {{0x3eb8bd0c,0x00000000,0x00000000,0x00000000}},	//   west_, --, --, --, 
   {{0x3eb8bd0d,0x64580724,0x628400e5,0x00000000}},	//   test_, _igti, ókos, --, 
   {{0x1ea8bd0e,0xb06402f6,0xf2c402bf,0x28cc2d8f}},	//   حادي_, tkää, _осін, _होसि, 
   {{0x3eb879b5,0x00000000,0x00000000,0x00000000}},	//   rest_, --, --, --, 
   {{0x3eb8367a,0x7c280e78,0xa2a074f6,0x91b80375}},	//   sest_, ßero, _गाड्, _למדי, 
   {{0x3eb8066d,0x8fa015ed,0xed4c0451,0xb064005b}},	//   pest_, _заје, جھي_, skää, 
   {{0x7c287236,0xb3400205,0xf9780798,0xb9200ca8}},	//   şero, _üçte, жбај_, basọ_, 
   {{0x64580014,0xb95400a7,0x99c80154,0x8e4800db}},	// [f570] _ogti, дващ, লঙ্ক, _ىلىك_, 
   {{0xfca805d9,0x8e38007b,0xc8641d0f,0x00000000}},	//   _ڏاڍو_, _عسير_, етци, --, 
   {{0x9bb4003d,0x7bc00205,0x00000000,0x00000000}},	//   _བགྲོ, çlud, --, --, 
   {{0x6458bd0f,0xdfc4004b,0x19a40150,0x00000000}},	//   _agti, _یي_, _ﺷﻴﭙﺎ, --, 
   {{0x463c0020,0x6560020c,0x7afc035a,0x66d001a9}},	//   _ይናገራ, gqoh, _ilst, rаkа, 
   {{0x7afcbd10,0x17041176,0x00000000,0x00000000}},	//   _hlst, _کفری_, --, --, 
   {{0x256002d2,0xdb040200,0xca4c01ec,0x5ee000eb}},	//   _eðl_, jtjë, _ﻀﺎﺕ_, _পতনে, 
   {{0xa2a0bd11,0x733400db,0x00000000,0x00000000}},	//   _गाण्, بىعا, --, --, 
   {{0xb144bd12,0x3d0c00bc,0xab9c0023,0xf8d00d2e}},	//   мнил, सफाइ_, _ዝግደፍ_, _सफाय, 
   {{0xc8e00073,0x00000000,0x00000000,0x00000000}},	//   नायट, --, --, --, 
   {{0x7c280e78,0x7afc0857,0x00000000,0x00000000}},	//   ßerl, _olst, --, --, 
   {{0x7c280ab7,0x62e801d9,0xdce80115,0x3014004e}},	//   ğerl, _وِلہ_, ĝiĝa, здүр, 
   {{0xa2a04668,0xdce800df,0x72042f0d,0x00000000}},	//   _गात्, ŝiĝa, _توشم, --, 
   {{0x072ca70b,0x91480798,0x00000000,0x00000000}},	//   ﻧﯩﯔ_, _учеа_, --, --, 
   {{0x2f000162,0xaf0400f3,0x00000000,0x00000000}},	//   _nógg_, _опкл, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe8e8bd13,0xc0d40023,0xa96833d2,0x00000000}},	// [f580] омад_, ርጓም_, زمام_, --, 
   {{0x7afcbd14,0xd1c4044e,0x6fb006ab,0x28cc5d4f}},	//   _elst, _ጸጥታ_, _जहां, _होशि, 
   {{0x66e4bd15,0x98a032b0,0x18a00395,0x00000000}},	//   можа, тихе, тахм, --, 
   {{0xe68c01b8,0x6a84030d,0x28cc00e1,0x00000000}},	//   _äsüü, _юлма, _होरि, --, 
   {{0xe4e402bf,0x5edc00dc,0xa9680108,0x386c00a2}},	//   дійн, गात्_, _фига_, _şere_, 
   {{0x6da40134,0x6368b42d,0x23680063,0x00000000}},	//   _wɔaw, ориг_, ојио_, --, 
   {{0x18a0bd16,0x09e404c5,0x98a07f10,0xec34008f}},	//   _шарм, _নেচা, _шире, ואַר_, 
   {{0x5af8010f,0x00000000,0x00000000,0x00000000}},	//   ַליצ, --, --, --, 
   {{0xb4e80014,0x00000000,0x00000000,0x00000000}},	//   تى۪م_, --, --, --, 
   {{0x7cf800b0,0xdec40023,0x00000000,0x00000000}},	//   _rìro, _ሽዑኡ_, --, --, 
   {{0x3f1400d8,0x00000000,0x00000000,0x00000000}},	//   еднс, --, --, --, 
   {{0xc694010f,0xd0140108,0x00000000,0x00000000}},	//   עאָ_, ьфы_, --, --, 
   {{0xb8e0081f,0x00000000,0x00000000,0x00000000}},	//   _ཁྲ_, --, --, --, 
   {{0xc6840131,0xc1bc01ad,0x28cc1a4e,0x4c680107}},	//   _ھې_, ्टीग, _होलि, диён_, 
   {{0xd00cbd17,0x9a84036b,0x7afc0216,0xc68401e2}},	//   _рф_, дузл, _plst, _پې_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8ac401b9,0xdb0401d3,0xcb3402e8,0xb99854fa}},	// [f590] ъёрл, ntjé, тетъ, явах_, 
   {{0x7afc0142,0x00000000,0x00000000,0x00000000}},	//   _wlst, --, --, --, 
   {{0x76b80209,0x7d145fa3,0x7afc0419,0x00000000}},	//   злер_, mizs, _tlst, --, 
   {{0x7bc4bd18,0x7afcbd19,0x7d14bd1a,0x00000000}},	//   _ishu, _ulst, lizs, --, 
   {{0x55c01ac1,0x00000000,0x00000000,0x00000000}},	//   талғ, --, --, --, 
   {{0x61f409a5,0x7d14bd1b,0x64a0bd1c,0x7bc4bd1d}},	//   _ýyly, nizs, гаша, _kshu, 
   {{0xd800010a,0x96b8114f,0x00000000,0x00000000}},	//   _шăк_, _وارز_, --, --, 
   {{0x7bc47f87,0xf770004b,0x23b00b24,0x00000000}},	//   _mshu, _لاړ_, اميس, --, 
   {{0x7d1401fa,0x2f000694,0x7bc40200,0x00000000}},	//   kizs, _jóge_, _lshu, --, 
   {{0x7bc41188,0x656400d2,0xf48400dd,0x00000000}},	//   _oshu, _ékha, _سائی, --, 
   {{0x7bc40796,0xb4bc1414,0x9f80009d,0x78a001a8}},	//   _nshu, ेयी_, лгэд, _ölvu, 
   {{0xb8e00003,0x59dc1a22,0x4230063f,0xd34402f2}},	//   _ཁི_, नमार, ịbọk, _تیبه_, 
   {{0xf1c80150,0x01c401e0,0x3ec401ec,0x0288009f}},	//   _ءوتى_, _аҫыл_, тқым_, _آَهي_, 
   {{0x25a033b8,0xe80000bc,0x00000000,0x00000000}},	//   _åkle_, लनमा_, --, --, 
   {{0xdfcc05d9,0x298801ec,0x3ec80108,0x00000000}},	//   _هيو_, _ﺗﻪﭘﻪ_, öttä_, --, 
   {{0x2e580166,0x7d1400ef,0x00000000,0x00000000}},	//   _эшкэ_, aizs, --, --, 
   {{0x7bc459b2,0xd5bc0073,0xa2a0024a,0x00000000}},	// [f5a0] _eshu, _शैलज, _गास्, --, 
   {{0x5de000c7,0x18a002dd,0x00000000,0x00000000}},	//   _сжьа, лаум, --, --, 
   {{0xeaf8bd1e,0x6d4cbd1f,0x00000000,0x00000000}},	//   _فرحت_, mmba, --, --, 
   {{0x6d4c7dac,0xab286206,0x1ae000db,0x00000000}},	//   lmba, _хома_, _боюм, --, 
   {{0x6d4cbd20,0x6aa402d0,0xe610015e,0x80c00073}},	//   omba, _ickf, دشا_, _वसले, 
   {{0x293c0075,0xdb0400d2,0xa2a0012c,0x6d4cbd21}},	//   ﻟﯘﭖ_, ntjî, _गाह्, nmba, 
   {{0x69c40489,0x3f8001e4,0x00000000,0x00000000}},	//   _hske, _ʈiu_, --, --, 
   {{0x6d4cbd22,0x7d14bd23,0xfbd000dc,0x00000000}},	//   hmba, zizs, हितम, --, 
   {{0x6d4c0369,0x2240143a,0x00000000,0x00000000}},	//   kmba, åkk_, --, --, 
   {{0x6d4c0097,0xa0a4bd24,0x68ecbd25,0x59240327}},	//   jmba, хшил, _jobd, ྡོགས_, 
   {{0x68ec0477,0x7d14bd26,0x6aa403ac,0x23d40408}},	//   _mobd, vizs, _ockf, _яцар, 
   {{0x6d4cbd27,0x69c48d2d,0xc21001d9,0x7c28236c}},	//   emba, _oske, _پٔت_, şerk, 
   {{0x69c40fac,0x51f00c4f,0x7d1400e5,0x00000000}},	//   _nske, _مسور, tizs, --, 
   {{0x6aa4035a,0x68ec0455,0x7bc4036e,0x22980205}},	//   _ackf, _nobd, _pshu, bükü_, 
   {{0x69c4bd28,0x7d14bd29,0x00000000,0x00000000}},	//   _aske, rizs, --, --, 
   {{0x60c8032e,0x00000000,0x00000000,0x00000000}},	//   _hafm, --, --, --, 
   {{0x0f5800c8,0x68ecbd2a,0x7e6cbd2b,0xb9340120}},	// [f5b0] _איהם_, _bobd, _ifap, веај, 
   {{0x7bc4bd2c,0x68ec56eb,0x60c802d2,0x03bc00cc}},	//   _tshu, _cobd, _jafm, _অপৈণ, 
   {{0x69c4bd2d,0x7bc4bd2e,0x68ec0086,0x6da4013b}},	//   _eske, _ushu, _dobd, _wɔat, 
   {{0x5924025c,0x6280bd2f,0xb6c800e5,0x1aac00fe}},	//   ྡོངས_, _neoo, بائے_, _চোৰা, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x05740137,0xb4bc1fbc,0x00000000,0x00000000}},	//   ااند, ेये_, --, --, 
   {{0x62803441,0x7e6c01af,0x064802d3,0x7c2803fa}},	//   _beoo, _ofap, _ዝዓይነ, ßerh, 
   {{0x0ed00574,0xd3446071,0x6d4c0007,0x69c4017a}},	//   _तोंड, ریشه_, zmba, _yske, 
   {{0x68ec0477,0x312400ee,0x1aac03d4,0x6d4c0124}},	//   _yobd, кдиг, _চোৱা, ymba, 
   {{0x7e6c05da,0x6e440133,0x00000000,0x00000000}},	//   _afap, ێندم, --, --, 
   {{0x60c800e8,0x439402a9,0xe3e40451,0x00000000}},	//   _dafm, _бахс, _لکين_, --, 
   {{0x62801a7c,0x7e6c0334,0x59b00709,0x00000000}},	//   _geoo, _cfap, ुबार, --, 
   {{0x78b40122,0xe1ec1164,0xc0bc001f,0xdcfc0139}},	//   _obzv, _тг_, ዳድሮ_, _apqı, 
   {{0x7e6cbd30,0x6d4cbd31,0x2cbc022e,0x271c08dd}},	//   _efap, umba, еtda_, _भद्र_, 
   {{0x6d4c044e,0xdb8049c4,0x00000000,0x00000000}},	//   rmba, игри, --, --, 
   {{0x68ec198f,0x6d4cbd32,0x00000000,0x00000000}},	//   _sobd, smba, --, --, 
   {{0x5a60bd33,0xed44010b,0xa96807a5,0x44200208}},	// [f5c0] ркуб, _инип, физа_, ̃i_, 
   {{0x6da40134,0x6d4c0007,0x6b64084c,0x68ec014f}},	//   _wɔas, qmba, _икоа, _qobd, 
   {{0xf99015bf,0x00000000,0x00000000,0x00000000}},	//   لبە_, --, --, --, 
   {{0xe618bd34,0x6aa4035a,0x00000000,0x00000000}},	//   мде_, _uckf, --, --, 
   {{0x68ecbd35,0x05b400c6,0xa50882de,0x69c48b98}},	//   _tobd, امتح, меда_, _uske, 
   {{0xf6280116,0x00000000,0x00000000,0x00000000}},	//   رسنى_, --, --, --, 
   {{0x17c40697,0x779011fc,0x60c80008,0x9d180677}},	//   _игри_, _هیلا, _rafm, ווסט, 
   {{0xe06402d3,0x7c280112,0x00000000,0x00000000}},	//   _ተቓዋሚ_, ßeri, --, --, 
   {{0x7c2803ee,0x60c800df,0x67200115,0x78b402d0}},	//   ğeri, _pafm, mnoj, _ybzv, 
   {{0x672002d5,0x60c805b1,0x00000000,0x00000000}},	//   lnoj, _qafm, --, --, 
   {{0x7e6c02c4,0x6280bd36,0x6720bd37,0x00000000}},	//   _pfap, _teoo, onoj, --, 
   {{0x67203f41,0x81f80327,0x35c40022,0x753c00e2}},	//   nnoj, ནགྱི_, _рҳәо_, _īszi, 
   {{0x6720bd38,0x92a800e5,0x00000000,0x00000000}},	//   inoj, _آئمہ_, --, --, 
   {{0x6720bd39,0x1010bd3a,0xbd44ba86,0x00000000}},	//   hnoj, ابید, اپسى, --, 
   {{0x7de80de2,0xbb300046,0x6720bd3b,0x0b88bd3c}},	//   _bësë, ﺭﻩﻙ_, knoj, ксти_, 
   {{0x6720bd3d,0x90540375,0x37c40131,0x00000000}},	//   jnoj, _בסוף_, һәбб, --, 
   {{0x3ea80724,0x00000000,0x00000000,0x00000000}},	// [f5d0] _icat_, --, --, --, 
   {{0x3dc81c06,0x8650001f,0x672056ce,0x2f000332}},	//   _isaw_, ንድነት, enoj, _ióga_, 
   {{0x7de81bce,0x2f000124,0x572406b3,0x3f8c0036}},	//   _fësë, _hóga_, پراق, nsdu_, 
   {{0x07a4bd3e,0x1670bd3f,0x6720bd40,0x7de800e8}},	//   раїн, рқар, gnoj, _gësë, 
   {{0x63b80076,0x3ea80b0e,0x2f00bd41,0x00000000}},	//   _aptn, _mcat_, _jóga_, --, 
   {{0x798cbd42,0x3ea80175,0x67200115,0xf8b0824e}},	//   msaw, _lcat_, anoj, _دکر_, 
   {{0x224400dd,0x3ea863e0,0x2f00032e,0xaaa8095f}},	//   _azok_, _ocat_, _lóga_, ङ्कक, 
   {{0x42b8a70b,0x3ea80175,0x72c40902,0x324404f0}},	//   ننىڭ_, _ncat_, убиз, лейг, 
   {{0xe28cbd43,0x798cbd44,0x2f0002d2,0x00000000}},	//   _қа_, nsaw, _nóga_, --, 
   {{0x78a40399,0x798c004c,0x00000000,0x00000000}},	//   nghv, isaw, --, --, 
   {{0x798cbd45,0x00000000,0x00000000,0x00000000}},	//   hsaw, --, --, --, 
   {{0x213cbd46,0xb9040c99,0xc5f001d9,0x3dc80334}},	//   alth_, _ཨོ_, _آے_, _bsaw_, 
   {{0xe0cc156b,0x3ea80175,0x5d6401a9,0x7bc00205}},	//   _лв_, _dcat_, лиям_, çlun, 
   {{0x798c03a2,0x6720260c,0x3ea80332,0x2af400af}},	//   dsaw, znoj, _ecat_, _एकहु_, 
   {{0x3ea8033b,0x798c0368,0x7de800e8,0xef180ebe}},	//   _fcat_, esaw, _pësë, _пмк_, 
   {{0x3ea801e7,0x00000000,0x00000000,0x00000000}},	//   _gcat_, --, --, --, 
   {{0x798cbd47,0xcdc404a2,0xa92472cb,0xaaa818cc}},	// [f5e0] gsaw, _тапқ, гдал, ङ्गक, 
   {{0xed600024,0x28cc00af,0xa88400db,0x00000000}},	//   įžę_, _होखि, الاى, --, 
   {{0x6d5cbd48,0x3ea8010a,0x00000000,0x00000000}},	//   _iipa, _ycat_, --, --, 
   {{0x6d5cbd49,0xdb989b62,0x798c0218,0x63b80175}},	//   _hipa, _אסטר, bsaw, _rptn, 
   {{0x6d5cbd4a,0x6720bd4b,0x63b80263,0x25b40014}},	//   _kipa, rnoj, _sptn, انتھ_, 
   {{0xa784bd4c,0x6d5cbd4d,0x6720bd4e,0x5e54010f}},	//   _مشرو, _jipa, snoj, אינע_, 
   {{0x6d5cbd4f,0x96d40598,0x291803c1,0x2244b2fe}},	//   _mipa, _өстә, mipa_, _szok_, 
   {{0x6d5cbd50,0x2918bd51,0x05140154,0x00000000}},	//   _lipa, lipa_, াকের_, --, 
   {{0x8af003be,0x171800c8,0x3ea800db,0x6d5c0124}},	//   mməd, _נומע, _rcat_, _oipa, 
   {{0x6d5cbd52,0x3ea80354,0x2918bd53,0x8af003be}},	//   _nipa, _scat_, nipa_, lməd, 
   {{0x30e4abc6,0x3ea80334,0xd36c007b,0x00000000}},	//   рсың, _pcat_, _فهل_, --, 
   {{0x2918bd54,0x6d5c0323,0x8af00213,0x798cbd55}},	//   hipa_, _aipa, nməd, ysaw, 
   {{0x6d5cbd56,0x2918bd57,0x798c0369,0x3f8c002d}},	//   _bipa, kipa_, xsaw, ssdu_, 
   {{0x6d5cbd58,0x291801c8,0x2f0000e4,0x20c8009f}},	//   _cipa, jipa_, _vóga_, _سبتي_, 
   {{0x6d5cbd59,0x798c0054,0x3ea8010a,0x6da4016b}},	//   _dipa, wsaw, _tcat_, _wɔap, 
   {{0x3a74bd5a,0x798c380b,0x5438008f,0x442c0165}},	//   рлар, tsaw, געלא, _mxd_, 
   {{0x29180161,0x6d5cbd5b,0x3914bd5c,0x798c0083}},	// [f5f0] fipa_, _fipa, амар, usaw, 
   {{0x4a54bd5d,0x6d5c22b9,0x7bf8024c,0x00000000}},	//   скус, _gipa, _анор_, --, 
   {{0x7f4ca28f,0x07080ccb,0x78a4016d,0x00000000}},	//   _khaq, گيني_, rghv, --, 
   {{0x6d5c0925,0x7c2803fa,0x0c743629,0x291800e4}},	//   _zipa, ßeru, _پدید, aipa_, 
   {{0x7aec4be2,0x0708bd5e,0x6d5cbd5f,0x00000000}},	//   mjat, ديني_, _yipa, --, 
   {{0x7aecbd60,0x2918bd61,0x6d5c18f7,0xda640451}},	//   ljat, cipa_, _xipa, _جاگي, 
   {{0x442c0165,0x7aec0c98,0xa50400a7,0x00000000}},	//   _cxd_, ojat, реща_, --, 
   {{0x8af006be,0x00000000,0x00000000,0x00000000}},	//   cməd, --, --, --, 
   {{0xb9dc067d,0x54a4bd62,0x442c0334,0x85b80014}},	//   _ኣነ_, _محاف, _exd_, _مالس_, 
   {{0x7aecbd63,0x6f14bd64,0x76480099,0x442c0165}},	//   hjat, _smyc, _izey, _fxd_, 
   {{0x3b080cfe,0x7aecbd65,0x7bc00790,0x442c0051}},	//   khaq_, kjat, çlul, _gxd_, 
   {{0x7f4cbd66,0x6d5cbd67,0x7aecbd68,0x2918bd69}},	//   _chaq, _sipa, jjat, zipa_, 
   {{0x7f4cbd6a,0x6d5cbd6b,0x7aecbd6c,0x29180bd7}},	//   _dhaq, _pipa, djat, yipa_, 
   {{0xa064bd6d,0xa0a01f10,0x6d5c0986,0x320cbd6e}},	//   _каша_, _дашд, _qipa, mzey_, 
   {{0x6d5cbd6f,0x2918009f,0x442c0036,0x7d040f91}},	//   _vipa, vipa_, _xxd_, _dlhs, 
   {{0x29180bc9,0x7f4cbd70,0x7aecbd71,0x6d5c1fc6}},	//   wipa_, _ghaq, gjat, _wipa, 
   {{0x2918bd72,0x76480526,0xe9a400a7,0xa9a400db}},	// [f600] tipa_, _nzey, разп, ризд, 
   {{0x68440588,0xc8e011b1,0x6d5c02b5,0xed58682d}},	//   анза, नाइट, _uipa, _шоп_, 
   {{0x7648bd73,0xdc98008d,0x7c280e78,0x8af00213}},	//   _azey, _בייל, ßert, tməd, 
   {{0xe9a4bd74,0xa9a4bd75,0xbb50037e,0x3b081181}},	//   _камп, _кимд, _ecoキ_, chaq_, 
   {{0x628405a4,0x2918bd76,0x70c40c2e,0xe4c42097}},	//   ðkom, pipa_, _वसूल, ийди, 
   {{0x76480810,0x29181181,0x95500ee8,0xd5440798}},	//   _dzey, qipa_, يخوا, апче_, 
   {{0x442c4e61,0x764804ba,0x3d0c01e1,0x9930004b}},	//   _qxd_, _ezey, _hówù_, _بېلګ, 
   {{0x26181b87,0x6ab4bd77,0x75800066,0x00000000}},	//   _मेथी_, nfyf, _کیوم, --, 
   {{0xdb0401ed,0x64a4bd78,0x69d40100,0xd56801ca}},	//   ntjá, _ваза, nvye, _бiбл, 
   {{0x7f4cbd79,0x7aec003d,0x3d0c01e1,0x00000000}},	//   _shaq, zjat, _mówù_, --, 
   {{0x7aec0054,0x7f4c0986,0x51f00ec9,0x403422c3}},	//   yjat, _phaq, مسیر, сенс, 
   {{0x33f456da,0x7f4cbd7a,0xdb203535,0x926400f3}},	//   _учус, _qhaq, ürüc, _крша_, 
   {{0x2cb8070d,0x0e34005b,0x7e7cbd7b,0xb230002e}},	//   _bbpd_, жняю, rbsp, ëñté, 
   {{0xabb40588,0x3b08014f,0x00000000,0x00000000}},	//   әатә, whaq_, --, --, 
   {{0x7f4c2e95,0x2f0000d2,0x7aecbd7c,0x8fa00063}},	//   _thaq, _gógo_, tjat, _даје, 
   {{0x7f4c014b,0x2cb8007f,0xd54001e1,0x9058011a}},	//   _uhaq, _ebpd_, _kẹ́h, _בכות, 
   {{0x7aecbd7d,0x9f500034,0x3b08022e,0x00000000}},	// [f610] rjat, ńców_, rhaq_, --, 
   {{0x7aecbd7e,0x7c2803fa,0x3b08058a,0x00000000}},	//   sjat, ßers, shaq_, --, 
   {{0x7aecbd7f,0x8e3804fb,0x7798bd80,0xd5400248}},	//   pjat, _مسیر_, укер_, _lẹ́h, 
   {{0xec34025f,0xb5fc00a2,0x7c28bd81,0x7aecbd82}},	//   _לאתר_, _agša, şers, qjat, 
   {{0x58840953,0x02bc197c,0x00000000,0x00000000}},	//   _выба, ्जनभ, --, --, 
   {{0xa5f40640,0x0608109a,0x05d400d1,0x00000000}},	//   сељу_, шнік_, زمىڭ, --, 
   {{0x3494039b,0xc7c800a8,0x36d4bd83,0x07a40006}},	//   _ҳазр, _кыте_, _ловр, _маён, 
   {{0x5924081f,0xafc40075,0x668001d3,0x59a807f7}},	//   ྡོམས_, ەيدى, _فیمل, _चमार, 
   {{0x34940323,0xd4c40314,0x7648bd84,0x8af003b9}},	//   _газр, _всеп, _uzey, lməc, 
   {{0x69d8008f,0xefc801c6,0x00000000,0x00000000}},	//   אַטו, глол_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x02d402f2,0xc0d40092,0x00000000,0x00000000}},	//   _وتنخ, _ይዟል_, --, --, 
   {{0xcdc40022,0x00000000,0x00000000,0x00000000}},	//   әаҳқ, --, --, --, 
   {{0x61e42d8b,0x2f000248,0x00000000,0x00000000}},	//   åkle, _tógo_, --, --, 
   {{0x3bd40108,0x00000000,0x00000000,0x00000000}},	//   оютс, --, --, --, 
   {{0x6e9400c6,0xa9a401d5,0xa024000d,0x7c2001e7}},	//   _الظا, йибд, svöö, úlra, 
   {{0xe9d8bd85,0xed3401c0,0x6fd400af,0x6ab40042}},	// [f620] ыка_, _гэнэ, धिवं, rfyf, 
   {{0xdb0401ed,0x00000000,0x00000000,0x00000000}},	//   rtjá, --, --, --, 
   {{0xdb04008c,0xd7042347,0x00000000,0x00000000}},	//   stjá, әнче_, --, --, 
   {{0xdd8c2dcd,0x76a802bf,0x68440107,0x00000000}},	//   _توی_, итів_, анҷа, --, 
   {{0x18680023,0xd6cc42f4,0x00000000,0x00000000}},	//   ድንጋር_, عقه_, --, --, 
   {{0x18640395,0x201006be,0x00000000,0x00000000}},	//   _гари_, _əyib_, --, --, 
   {{0x73880510,0x5f0800dc,0xd54001e1,0x00000000}},	//   арың_, ासम्_, _sẹ́h, --, 
   {{0x316c0076,0x1b78008f,0xe7381606,0x2d9c0210}},	//   fqez_, נטפע, _себ_, ątej_, 
   {{0x9ae8008f,0x00000000,0x00000000,0x00000000}},	//   אַיִ, --, --, --, 
   {{0x26c40607,0x20c80114,0x00000000,0x00000000}},	//   leoo_, ућио_, --, --, 
   {{0x248c02fa,0x25a403cb,0x64a4014b,0x00000000}},	//   mafm_, luol_, _ваҷа, --, 
   {{0x26c401e0,0xa34801b9,0x9da80395,0x00000000}},	//   neoo_, _ёзда_, лъга_, --, 
   {{0x00940166,0x00000000,0x00000000,0x00000000}},	//   _дилэ, --, --, --, 
   {{0x248c009f,0xd25408c3,0x00000000,0x00000000}},	//   nafm_, _השדה_, --, --, 
   {{0x26c401fa,0x3c580276,0xdef801af,0x00000000}},	//   keoo_, ривэ_, _бып_, --, 
   {{0xd84c0241,0x00000000,0x00000000,0x00000000}},	//   _mọto_, --, --, --, 
   {{0x26c4022e,0x00000000,0x00000000,0x00000000}},	// [f630] deoo_, --, --, --, 
   {{0x4dd402dd,0x25a4bd86,0x3eb8002f,0x00000000}},	//   _ءتيس, duol_, lfst_, --, 
   {{0x8d74bd87,0x25a4015d,0x00000000,0x00000000}},	//   _وایا, euol_, --, --, 
   {{0x25a404cc,0x8c440311,0xa3e0000d,0x00000000}},	//   fuol_, ăşti, _फऊज_, --, 
   {{0x75c802dd,0x3eb869a9,0x25a4bd88,0x00000000}},	//   ртең_, ifst_, guol_, --, 
   {{0x739806ed,0x5f1800b4,0x00000000,0x00000000}},	//   атис_, ụghị_, --, --, 
   {{0xd800074d,0x66f0000d,0x3f9800e5,0x3eb800d7}},	//   _хăй_, _अकचक_, árul_, kfst_, 
   {{0x8c1c00c8,0xf1c80132,0x85b80014,0x386cbd89}},	//   טווי, لوبى_, _گافس_, _şerh_, 
   {{0x349451d4,0x2d9c068f,0x3108bd8a,0xd4987136}},	//   _маар, ątek_, инип_, _бре_, 
   {{0x161c1d8a,0xdb0401e6,0xd84c0ca8,0x3eb801a4}},	//   _मेयर_, ltjä, _fọto_, efst_, 
   {{0x3eb817da,0x00000000,0x00000000,0x00000000}},	//   ffst_, --, --, --, 
   {{0xdb04712c,0x660c010e,0x00000000,0x00000000}},	//   ntjä, _önkü, --, --, 
   {{0xc32c00db,0xd344bd8b,0x00000000,0x00000000}},	//   _حەي_, _پیکه_, --, --, 
   {{0xac08bd8c,0x311c0092,0xdb04002f,0x00000000}},	//   анга_, ትሌቲክ, htjä, --, 
   {{0xab184f73,0xdb0401e3,0x7c28002f,0x7054007b}},	//   ацах_, ktjä, ßerp, _بنغا, 
   {{0xa2a0000d,0xe20403b2,0xf2280240,0x50a00116}},	//   _गाछ्, óógv_, _ድስፕሊ, _بەگل, 
   {{0xbca4004b,0x7cf000c7,0xdb04007c,0xb5084195}},	// [f640] _کمپي, _ẽrek, dtjä, वसाय_, 
   {{0x98a000a8,0x8d740451,0x00000000,0x00000000}},	//   дифе, _واڌا, --, --, 
   {{0xe664a796,0x69a4012d,0x00000000,0x00000000}},	//   отло, _चमकी, --, --, 
   {{0xe7380b32,0xdb04007c,0x25a403cb,0xe81c01f9}},	//   шее_, gtjä, tuol_, _येणा_, 
   {{0x7c640150,0x00000000,0x00000000,0x00000000}},	//   _باۋل, --, --, --, 
   {{0x3a147ef2,0x00000000,0x00000000,0x00000000}},	//   _хьюс, --, --, --, 
   {{0x2618bd8d,0x8848036b,0x752c020c,0x00000000}},	//   _मेरी_, _ایاق_, éaza, --, 
   {{0x25a40108,0x3774010a,0x00000000,0x00000000}},	//   puol_, _хырс, --, --, 
   {{0x7a0c022e,0x248c054e,0xe81c0073,0xd04003b9}},	//   _kўta, pafm_, _येता_, _ianə, 
   {{0xe450bd8e,0xd464084c,0x1b0000eb,0x00000000}},	//   _قضا_, _дифе_, রোপে_, --, 
   {{0xe3b02421,0xa280036b,0x00000000,0x00000000}},	//   _زرا_, _قیغو, --, --, 
   {{0x5438010f,0x3eb8002f,0x00000000,0x00000000}},	//   _דעבא, ufst_, --, --, 
   {{0x3eb8a271,0x91802928,0x290800a2,0xed4c00ec}},	//   rfst_, _قۇيۇ, _olba_, گھي_, 
   {{0x9f683ab8,0x1fa4014b,0x00000000,0x00000000}},	//   _криз_, _дриг, --, --, 
   {{0x5f0800bc,0x00000000,0x00000000,0x00000000}},	//   ासद्_, --, --, --, 
   {{0x29080876,0x5398008d,0xd04006be,0x397401a9}},	//   _alba_, יילו, _nanə, злаё, 
   {{0x290802f0,0x8e480150,0x2ea8010f,0x00000000}},	// [f650] _blba_, _ولىك_, _השפּ, --, 
   {{0xecb00a8a,0x00000000,0x00000000,0x00000000}},	//   _जायफ, --, --, --, 
   {{0xb340bd8f,0xdb040267,0xd7f806ed,0x00000000}},	//   _üçge, ttjä, јуз_, --, 
   {{0x2908bd90,0x8af00213,0x00000000,0x00000000}},	//   _elba_, lmən, --, --, 
   {{0xdb0401e6,0xd04003b9,0x2a74011a,0x80b00154}},	//   rtjä, _danə, _מערך_, _জঘন্, 
   {{0xdb04049f,0x33f4bd91,0xf7940064,0x8af003b9}},	//   stjä, зчис, _нагэ, nmən, 
   {{0x49000574,0x84580801,0x87b401c0,0x00000000}},	//   _शकतो_, орът_, _ойрх, --, 
   {{0x22902e51,0x71580209,0xf1c800d7,0x8af003e3}},	//   ىلىس, әрис_, hráš_, hmən, 
   {{0x8af006be,0x84f401f9,0x00000000,0x00000000}},	//   kmən, _अवचट_, --, --, 
   {{0x82340014,0x3dd00011,0x00000000,0x00000000}},	//   بر٘ا, ামাল, --, --, 
   {{0xafe401d5,0xe4e400cf,0x00000000,0x00000000}},	//   чонл, _эстү, --, --, 
   {{0x33280de2,0x91f4007b,0xd0400213,0xf5440345}},	//   _ñax_, _وأشا, _xanə, _بفڕێ, 
   {{0xed58bd92,0x00000000,0x00000000,0x00000000}},	//   йом_, --, --, --, 
   {{0x2d9c0232,0x25ec87ee,0xed5801c6,0x5eb80154}},	//   čte_, _आपसी_, сог_, োগে, 
   {{0x78e40150,0x00000000,0x00000000,0x00000000}},	//   _ﺍﺷﺘﻰ, --, --, --, 
   {{0x63ac019b,0x0a20001f,0x511800c5,0xb3400432}},	//   _åbne, _ተመልካ, _फगुआ_, _üçde, 
   {{0xfd9800fb,0xf1bc1157,0x00000000,0x00000000}},	// [f660] _мөрә_, ्बिन, --, --, 
   {{0x8f1c03f9,0xb92401f2,0x98940124,0xeb98009b}},	//   ɗɗaɗ, mkpụ_, зуцә, _лио_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf1bcbd93,0x3a2c0b3d,0x2b14010a,0x00000000}},	//   ्बान, _žepe_, _хьор, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x35680220,0xa88800db,0x00000000,0x00000000}},	//   ірін_, _ыйга_, --, --, 
   {{0xdb04bd94,0xd37418bc,0x43b400c7,0x00000000}},	//   stjå, пчы_, ьӡар, --, 
   {{0x6da40134,0x00000000,0x00000000,0x00000000}},	//   _wɔay, --, --, --, 
   {{0x6720bd95,0x8534bd96,0x00000000,0x00000000}},	//   mioj, _قورچ, --, --, 
   {{0x6720bd97,0x66000369,0xdb04036e,0x00000000}},	//   lioj, myok, tujë, --, 
   {{0x6600bd98,0x54780375,0x44380042,0x6264030d}},	//   lyok, _הטבו, _âr_, _евеа, 
   {{0x6720bd99,0x6e94004b,0x00000000,0x00000000}},	//   nioj, ولپا, --, --, 
   {{0x6600bd9a,0x91b419b6,0x91e0bd9b,0xd2400276}},	//   nyok, _فطور_, _поце, _пэши, 
   {{0x314c0023,0x00000000,0x00000000,0x00000000}},	//   _ፕሪቶር, --, --, --, 
   {{0x213cbd9c,0x6600bd9d,0xcc540801,0x236401e4}},	//   moth_, hyok, евръ, _kioj_, 
   {{0x23641509,0x213c011f,0x8eb4104b,0x6600bd9e}},	//   _jioj_, loth_, _كەپت, kyok, 
   {{0x236401e4,0x7dec013f,0x6720bd9f,0x6e1800ec}},	// [f670] _mioj_, kɑsɛ, dioj, _ويٺس_, 
   {{0x8af003be,0x2bcc3994,0x213c07de,0x6600bda0}},	//   lməl, _हैवा, noth_, dyok, 
   {{0xf6d402bf,0x660004ba,0x67200115,0x97a4bda1}},	//   діля, eyok, fioj, ярал, 
   {{0x7bc4bda2,0x67209657,0x95b00220,0x8af00213}},	//   _iphu, gioj, еркә, nməl, 
   {{0x497421d0,0x224413bb,0x6600bda3,0xc0180055}},	//   _пляс, _nyok_, gyok, _vīṇe_, 
   {{0x94a844b2,0xb0640108,0x00000000,0x00000000}},	//   стда_, njää, --, --, 
   {{0xd040013f,0x22443743,0x66001418,0xdec40092}},	//   _danɛ, _ayok_, ayok, ሽንና_, 
   {{0x6720bda4,0x7bc4055a,0x6600bda5,0x2f0003b2}},	//   cioj, _mphu, byok, _hógv_, 
   {{0x2364008f,0x63a80112,0x41b4084c,0xf8d00073}},	//   _dioj_, aufn, нсэт, _हसाय, 
   {{0x7bc415d3,0x213c06f2,0x63a8054e,0x00000000}},	//   _ophu, goth_, bufn, --, 
   {{0x5ed40154,0x00000000,0x00000000,0x00000000}},	//   ধানে, --, --, --, 
   {{0x2f0003b2,0x213c01ab,0x1b000154,0x46440240}},	//   _lógv_, aoth_, রোতে_, _ንሓጥያ, 
   {{0x213cbda6,0x7bc438f3,0xee380845,0xdb04002d}},	//   both_, _aphu, інг_, stjû, 
   {{0x2f005573,0x332c020b,0x6720bd4b,0x213c0332}},	//   _nógv_, lnex_, zioj, coth_, 
   {{0xad240131,0xdc640b3e,0x6600007f,0x6dc00137}},	//   كىڭى, дард_, zyok, رۅگۅ, 
   {{0x332c1570,0x25ec0574,0x613c001f,0xd84c0241}},	//   nnex_, _आपली_, _አባታች, _rọpo_, 
   {{0x7bc40912,0x2bcc4eae,0x2f000162,0x59b02309}},	// [f680] _ephu, _हैरा, _bógv_, көрс, 
   {{0x660005d9,0xebe40372,0x7c38bda7,0x6cc407d6}},	//   vyok, _жооп, ébré, _ўйна, 
   {{0x8af000ac,0x67205d40,0x1b0000eb,0x00000000}},	//   lməm, tioj, রোধে_, --, 
   {{0xe5c4bda8,0x6600bda9,0xe5a40131,0x2d80002d}},	//   дско, tyok, диди, opke_, 
   {{0xe61004a9,0x6720764f,0x8af00213,0xd1f00023}},	//   خشا_, rioj, nməm, ልባብ_, 
   {{0x6720bdaa,0x9f5c02fb,0x6600adc7,0x23640064}},	//   sioj, ryté_, ryok, _sioj_, 
   {{0x224447d8,0x9390bdab,0x6600bdac,0x6720bd4b}},	//   _syok_, نجيا, syok, pioj, 
   {{0xc298026a,0x66001801,0x61e41f53,0x8af003e3}},	//   чких_, pyok, åklo, kməm, 
   {{0x84c40166,0xb0640108,0x63a8bdad,0x2f00013a}},	//   _зәйд, yjää, sufn, _jógu_, 
   {{0x15f8011a,0x20c401a9,0x00000000,0x00000000}},	//   _והמע, фсиг, --, --, 
   {{0x3f98bdae,0x25a4bdaf,0x23640115,0x2d80000f}},	//   éru_, lrol_, _tioj_, epke_, 
   {{0x626438eb,0x69c4bdb0,0x2168bdb1,0xa2045290}},	//   _قاشق, _opke, _диди_, _опед, 
   {{0x2244089c,0x8af003be,0x2f000008,0xe0d8bdb2}},	//   _uyok_, rməl, _nógu_, _мвд_, 
   {{0x61e0bdb3,0x23c00034,0x25a40548,0x00000000}},	//   _irol, _शहाद, irol_, --, 
   {{0xb06405a7,0x25a4bdb4,0x2d800066,0x628c016b}},	//   rjää, hrol_, apke_, ɔbor, 
   {{0xb0643110,0x8f98011a,0xbdb4009b,0x00000000}},	//   sjää, _ויהי, _збиј, --, 
   {{0x7e6cbdb5,0x25a4bdb6,0x00000000,0x00000000}},	// [f690] _igap, jrol_, --, --, 
   {{0x25a439ea,0x02bc4c83,0x008403e3,0x7bc003e0}},	//   drol_, ्जुन, _üçdə_, çlus, 
   {{0x7bc42782,0x7e6c9676,0x69c4003e,0xebc00116}},	//   _uphu, _kgap, _epke, _йәтн, 
   {{0x61e0bdb7,0x25a47c3a,0x9ae400f7,0x00000000}},	//   _orol, frol_, _تۉرك_, --, 
   {{0x7e6c409c,0x61e000b5,0x3b080309,0x7afc01e7}},	//   _mgap, _nrol, mkaq_, _iost, 
   {{0x7afc26c2,0x044802d3,0x3b08bdb8,0x8214009e}},	//   _host, _ምሕጽን, lkaq_, াপাপ_, 
   {{0x61e0bdb9,0x7e6c035b,0x25a4015d,0x00000000}},	//   _arol, _ogap, arol_, --, 
   {{0x7e6c2935,0x25a4bdba,0x7afcbdbb,0x61e0bdbc}},	//   _ngap, brol_, _jost, _brol, 
   {{0x61e0bdbd,0x27e400b0,0x22840022,0x00000000}},	//   _crol, āone_, хәхо_, --, 
   {{0x7afcbdbe,0x7648bdbf,0x3b080309,0xe1f001d3}},	//   _lost, _iyey, hkaq_, اسٹ_, 
   {{0x7afc2c01,0x3b080ee9,0x00000000,0x00000000}},	//   _oost, kkaq_, --, --, 
   {{0x61e0bdc0,0x6da41e28,0x7768020b,0x76482252}},	//   _frol, нима, _jiex, _kyey, 
   {{0x52a80034,0x77680135,0x59cc033f,0x49000073}},	//   छलीस, _miex, _सैलर, _शकलो_, 
   {{0x7afcbdc1,0x7e6cbdc2,0x8af000ac,0x7648bdc3}},	//   _aost, _egap, rməm, _myey, 
   {{0x1be4bdc4,0x7afcbdc5,0x764804ba,0x31b8bdc6}},	//   ндри_, _bost, _lyey, lèz_, 
   {{0x7afca93b,0x77680135,0x3a2c0b3d,0x764801e1}},	//   _cost, _niex, _žepa_, _oyey, 
   {{0x8af000ac,0x31b802bd,0x00000000,0x00000000}},	// [f6a0] lmək, nèz_, --, --, 
   {{0x290cbdc7,0x7afc7d9b,0xe9440101,0x00000000}},	//   ófa_, _eost, رناپ, --, 
   {{0x7afcbdc8,0x7648bdc9,0xe27c01e1,0x7e6c00c7}},	//   _fost, _ayey, _bọlé_, _ygap, 
   {{0x7afcbdca,0xa968006c,0x25a4bdcb,0x76480a49}},	//   _gost, _нима_, trol_, _byey, 
   {{0x69c420a2,0x45d4bdcc,0x94c800f1,0xd7480023}},	//   _upke, толс, ګانې_, _ዝኣምነ, 
   {{0x7afcbdcd,0x25a4172e,0x61e0036e,0xe9e80419}},	//   _zost, rrol_, _rrol, rhúľ_, 
   {{0x25a4bdce,0x7648bdcf,0x7afc01d5,0xf48402dd}},	//   srol_, _eyey, _yost, туін, 
   {{0x61e0a148,0x18640212,0x02bc27a6,0x7afc01a9}},	//   _prol, _часи_, ्जेन, _xost, 
   {{0x76480337,0x85640124,0x61e0031c,0x00000000}},	//   _gyey, _анаҧ, _qrol, --, 
   {{0x61e0bdd0,0x7e6c0e89,0xdb0406ea,0x00000000}},	//   _vrol, _sgap, stjø, --, 
   {{0xb3e800c6,0x7bd402dd,0xe28400c7,0xd1b401d3}},	//   _يعمل_, _ءﺍﺷﯩ, _злеи, وایا_, 
   {{0x61e0bdd1,0x6fb00927,0xde38001f,0x00c80075}},	//   _trol, _अमरू, _የሕይወ, члүк_, 
   {{0x7afcbdd2,0x61e03077,0x20080219,0x00000000}},	//   _rost, _urol, šbi_, --, 
   {{0xd24cbdd3,0x3b0802d1,0x00000000,0x00000000}},	//   _انه_, wkaq_, --, --, 
   {{0xd00cbdd4,0x7e6c07de,0x64540213,0x7f5c0113}},	//   _сф_, _tgap, əyic, pmsq, 
   {{0x7e6cbdd5,0x7afc7769,0x28c406e3,0x00000000}},	//   _ugap, _qost, _रॉबि, --, 
   {{0x7afcbdd6,0x9f5c01ed,0x3b080240,0x5ed40154}},	// [f6b0] _vost, sztó_, rkaq_, ধাদে, 
   {{0x63600521,0x3b080309,0x20280023,0xdc8800db}},	//   _ọnla, skaq_, _ብመትከ, _эсил_, 
   {{0x7afcbdd7,0xdb0400bc,0x76b800d8,0x31b8007f}},	//   _tost, lují, длер_, zèz_, 
   {{0x7afcbdd8,0x3b080309,0x31b8033b,0xd58402f2}},	//   _uost, qkaq_, yèz_, فێره_, 
   {{0x02bc00af,0xdb0400bc,0x55c002dd,0x00000000}},	//   ्जैन, nují, уалғ, --, 
   {{0x7648bdd9,0xb4640832,0x31b802e2,0xe27c0248}},	//   _vyey, نگاه, vèz_, _wọlé_, 
   {{0x776805b1,0xdb0400bc,0x75200175,0x00000000}},	//   _tiex, hují, _vmlz, --, 
   {{0x8f801955,0x32441d37,0xdb0400bc,0x31b80100}},	//   ққил, кейг, kují, tèz_, 
   {{0x3dc80218,0x51400e46,0xdb040118,0x54c001ec}},	//   _npaw_, лдиғ, jují, _бұлб, 
   {{0xdb040316,0xeb0c2d3b,0x23b800e8,0x31b8033b}},	//   dují, _सत्त_, bëj_, rèz_, 
   {{0x3dc8016b,0x31b802e2,0x00000000,0x00000000}},	//   _apaw_, sèz_, --, --, 
   {{0x8af000ac,0xe28c0640,0x31b8007f,0x9f5c0118}},	//   rmək, _ња_, pèz_, bytí_, 
   {{0x3f9c0337,0x90b00184,0x2f340618,0xeab001d3}},	//   _evvu_, _йәнш, gāga_, یٹس_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x799c02d0,0x00000000,0x00000000,0x00000000}},	//   _avsw, --, --, --, 
   {{0xdb040118,0xdee007a5,0x00000000,0x00000000}},	//   bují, _воъи, --, --, 
   {{0xad5805f5,0x799c02d0,0xdb0400bc,0x28940114}},	// [f6c0] _орох_, _cvsw, cují, вјес, 
   {{0xc0dc0023,0x00000000,0x00000000,0x00000000}},	//   _ንሎሚ_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d4cbdda,0xd7ec0597,0x00000000,0x00000000}},	//   llba, تكم_, --, --, 
   {{0x6d4cbddb,0x31bcbddc,0x84701954,0x940403e3}},	//   olba, ्बोध, _ብሄርን_, manə_, 
   {{0x260c00af,0xd1f002d3,0x6d4c02d0,0xb2c801ec}},	//   तैषी_, ልኣት_, nlba, _ﺒﺄﻭﺍ, 
   {{0x25ec068f,0x68ec031c,0xdb0400bc,0x94200640}},	//   _आपकी_, _inbd, zují, имље, 
   {{0x6d4c03fa,0x68ec0175,0x538c0023,0x00000000}},	//   hlba, _hnbd, ሞቴዎስ_, --, 
   {{0x2618012c,0x95b4035b,0x2c280092,0xe7d801f9}},	//   _मेची_, _архә, ደሚጀም, णिकप, 
   {{0x1fb404c5,0xddc80024,0xdb0400bc,0xaa580023}},	//   _জনবস, šiūn, vují, _ቆንስላ, 
   {{0xd0040a16,0xf650066d,0xa3b800cf,0xbfc800d1}},	//   веќе_, _نئے_, _زاار_, رادە_, 
   {{0x6d4cbddd,0xdb04bdde,0x00000000,0x00000000}},	//   elba, tují, --, --, 
   {{0x6e200419,0x51f01fa1,0x00000000,0x00000000}},	//   _žobr, _نسور, --, --, 
   {{0x6d4c0158,0xf1a805d9,0xdb0400bc,0x25d80037}},	//   glba, _ساهه_, rují, _खईनी_, 
   {{0x2f340421,0xdb6801c0,0xdb0400bc,0x5fb41bd6}},	//   sāga_, драл_, sují, _अमिल, 
   {{0x6d4cbddf,0xdb04012c,0x940400ac,0x9e0400c0}},	//   alba, pují, ganə_, _ачол, 
   {{0xba5403b7,0x00000000,0x00000000,0x00000000}},	// [f6d0] увај, --, --, --, 
   {{0xb89402de,0x68ec01ab,0xdb0400e5,0x00000000}},	//   الاع, _cnbd, ltjü, --, 
   {{0xc62000cc,0xf1d80037,0x00000000,0x00000000}},	//   _ফুলা_, _भनभन, --, --, 
   {{0x2bf00316,0x799c02d0,0xdb0401d3,0x9b400133}},	//   ीहरू_, _tvsw, ntjü, _ئۆرو, 
   {{0xdfc400b2,0x00000000,0x00000000,0x00000000}},	//   _ڏي_, --, --, --, 
   {{0x68ec007f,0x00000000,0x00000000,0x00000000}},	//   _gnbd, --, --, --, 
   {{0xa85423c9,0x03940006,0xb1440116,0xccf40115}},	//   _берә, арыя, һнил, יכס_, 
   {{0xe5840131,0xeff00023,0xdb040174,0xa6140166}},	//   _әттү, ልቃዊ_, mtjó, _өзсә, 
   {{0xb144094d,0x80dc0011,0xdb0403b2,0x6d4c87dc}},	//   лнил, বান্, ltjó, ylba, 
   {{0x28c41b6e,0xe00c2c35,0xe27c01e1,0x00000000}},	//   र्पि, ानंद_, _yọké_, --, 
   {{0x09d000dc,0x63c00118,0xe3e41913,0x00000000}},	//   _हन्य, ěvní, _مکين_, --, 
   {{0xe378008f,0x515001ec,0xafe400fb,0x6d4c0042}},	//   _טרער, ытқу, _ҡолл, wlba, 
   {{0xe1ec352d,0x3f9806ea,0x6d4c030a,0x6fd40073}},	//   _уг_, árur_, tlba, _बनवू, 
   {{0x80241547,0xd08400c7,0x00000000,0x00000000}},	//   اریم, _рыди, --, --, 
   {{0x6d4c39cf,0x6b6c01e4,0xc0c80640,0x25d87dad}},	//   rlba, _aĝgr, _јуче_, _खैनी_, 
   {{0x28c408ec,0x5de000cc,0x00000000,0x00000000}},	//   र्नि, _পথৰু, --, --, 
   {{0x28e810e0,0x8c1c03d4,0x1e801de6,0x00000000}},	// [f6e0] ндап_, _দুখন_, _улым, --, 
   {{0xfd6800b4,0x61e4168c,0x940400ac,0x777406be}},	//   _mkpụ, åkli, sanə_, _buzx, 
   {{0xa684bde0,0x2cb80048,0x66e4bde1,0x00000000}},	//   глед, _icpd_, ложа, --, 
   {{0x0684016c,0xdb040798,0x38580108,0x940406be}},	//   рҳан, rujã, трую_, qanə_, 
   {{0x636c007f,0x6ab40142,0x00000000,0x00000000}},	//   kònè, mgyf, --, --, 
   {{0x6ab4bde2,0xd7ec0137,0x00000000,0x00000000}},	//   lgyf, تكۅ_, --, --, 
   {{0xfd680521,0xdb04bde3,0xa3f00154,0x9f4801d3}},	//   _akpụ, lujá, জন্য_, őjét_, 
   {{0xba0002d3,0x6ab40368,0xb3400bbc,0x63a8bde4}},	//   _ሂቡ_, ngyf, _üçle, rrfn, 
   {{0xd2040323,0x216450e3,0xdec002d3,0x64b41622}},	//   гээд_, лтог, _ስኢኑ_, _محار, 
   {{0x645403be,0x6ab40042,0x758000f2,0x00000000}},	//   əyin, hgyf, _بیوم, --, 
   {{0x2d900204,0x58f400c8,0x69d40142,0x00000000}},	//   _awye_, אמיע_, hwye, --, 
   {{0xf8d0012c,0xe298bde5,0x8af006be,0x00000000}},	//   _हस्प, _чад_, lləf, --, 
   {{0x3fc82580,0x6ab4015d,0xc0c401af,0xe044009d}},	//   ردگی_, dgyf, _кәни, _өнди, 
   {{0xdbcc00e4,0x69d403cb,0x2f3400ef,0x00000000}},	//   _añáp, dwye, bāgo_, --, 
   {{0x4294001f,0xc0f0001f,0xc5e400e5,0x00000000}},	//   _መቀነስ_, ልናል_, _کۓ_, --, 
   {{0x6ab4bde6,0x00000000,0x00000000,0x00000000}},	//   ggyf, --, --, --, 
   {{0x28c4bde7,0xdb040162,0xceb4011a,0x00000000}},	// [f6f0] र्भि, gujá, _היפ_, --, 
   {{0xd2540375,0x0a68bde8,0xd838010b,0x00000000}},	//   רשמה_, урси_, нэе_, --, 
   {{0xdec00240,0x00000000,0x00000000,0x00000000}},	//   _ስኢና_, --, --, --, 
   {{0x1670005e,0xd5f8063f,0x28c4a765,0xf98400cf}},	//   сқар, _ndụ, र्बि, _نەرۋ_, 
   {{0xdb0431ac,0xaa980375,0xc98457e5,0xaac000bc}},	//   stjó, _בברכ, _гуси, शभरक, 
   {{0x42b800d1,0x00000000,0x00000000,0x00000000}},	//   ۇنىڭ_, --, --, --, 
   {{0x36d444c9,0x62840205,0x00000000,0x00000000}},	//   _ковр, ıkon, --, --, 
   {{0xdc0c00bc,0x8cac0037,0x00000000,0x00000000}},	//   _něče, _जयभो, --, --, 
   {{0xf4d88a6f,0x7158bde9,0x7cdc00de,0x8af003b9}},	//   _имаш_, крос_, _kārļ, mmət, 
   {{0x31243605,0x61e401bf,0x8af003b9,0x955400ae}},	//   рдог, ækla, lmət, _إخرا, 
   {{0x2d900ea0,0x6ab40042,0xc564009f,0x00000000}},	//   _swye_, ygyf, _اُلي, --, 
   {{0x8fc000f7,0x8e24022e,0x00000000,0x00000000}},	//   _ۇمتۇ, оmа_, --, --, 
   {{0xf1d80316,0x28c41f13,0x3134026b,0xd1b806c2}},	//   _भनिन, र्डि, _кедр, _ساشا_, 
   {{0xed580640,0x8af00213,0x9f5c0216,0xafe40024}},	//   тог_, hmət, rytá_, _вокл, 
   {{0xab2802bf,0x6a9402bf,0xbc1801ec,0x6ab40042}},	//   вова_, ирає, гіті_, tgyf, 
   {{0x2d941553,0x6a8401c0,0x09b0031c,0xc0f00023}},	//   _крос, рлаа, _དཀྱ_, ልዓል_, 
   {{0x8af00cc1,0xe9d80801,0x6ab4bde2,0x6924bdea}},	// [f700] dmət, ъка_, rgyf, амаа, 
   {{0x69d40042,0x6ab40142,0xdb0400c7,0xaf3400ec}},	//   rwye, sgyf, rujá, _حرڪت, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xeab03b2a,0x7f8c010f,0xdb0400e5,0x00000000}},	//   _بعد_, גנאַ, pujá, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6f14015d,0xa7841699,0x00000000,0x00000000}},	//   _llyc, _نشرو, --, --, 
   {{0x6f14bdeb,0x28c49ad9,0x291808c2,0x43940108}},	//   _olyc, र्णि, mhpa_, щайс, 
   {{0xc1b8bdec,0xc8c800ec,0x00000000,0x00000000}},	//   глих_, _جوڀن_, --, --, 
   {{0x8af00cc1,0x28c408ec,0xd254bded,0x7d00008c}},	//   lməs, र्थि, иць_, ölsk, 
   {{0x202802d3,0x26c4bdee,0x6ad000cc,0x8af003b9}},	//   _ብመልክ, lfoo_, হাটো, bləg, 
   {{0x8af000ac,0x6f140368,0x54780677,0x00000000}},	//   nməs, _blyc, _סטאו, --, 
   {{0x28c408dd,0x6458bdef,0x26c40134,0x5f241eed}},	//   र्ति, _izti, nfoo_, рфоз, 
   {{0x6280bdf0,0x3dcc03a2,0xa0d80014,0x626401d5}},	//   _ifoo, ïew_, _لِشا_, _твда, 
   {{0x6d5c00e4,0x88d8009e,0x4c94bdf1,0x4094007b}},	//   _chpa, সাঁক, жирс, _الثر, 
   {{0x8af000ac,0x6f14152c,0x291801ab,0x9b240064}},	//   ymət, _flyc, dhpa_, афал, 
   {{0x3a74bdf2,0x6d5c004a,0x00000000,0x00000000}},	//   слар, _ehpa, --, --, 
   {{0x7f4c0194,0x4ccc04c5,0x383405a2,0x3914026b}},	// [f710] _ikaq, ায়ু, әнер, бмар, 
   {{0x27e800a3,0x26c4013f,0x64585594,0x3eb801a8}},	//   _brbn_, efoo_, _ozti, lgst_, 
   {{0x7d0403a2,0x6280bdf3,0x26c4022f,0x3eb801a4}},	//   _iohs, _ofoo, ffoo_, ogst_, 
   {{0x7d0401fa,0x35f43981,0xa3e805d7,0x00000000}},	//   _hohs, йпер, मिन_, --, 
   {{0xd5b8bdf4,0x8af000ac,0x6458009d,0x7d040175}},	//   тсе_, rmət, _azti, _kohs, 
   {{0x28c404e4,0x6280bdf5,0x2918bdf6,0x26c40134}},	//   र्दि, _afoo, chpa_, afoo_, 
   {{0x3ce001a9,0x1768bdf7,0xa5040395,0x8af003e3}},	//   _mahv_, _арап_, сеща_, mmər, 
   {{0x237469ef,0x7d040007,0x8af000ac,0x9f5c01f4}},	//   حميد_, _lohs, lmər, nytä_, 
   {{0x312407d6,0x645801c6,0x62800334,0x645400ac}},	//   йдиг, _ezti, _dfoo, əyim, 
   {{0x7f4c0944,0x7d0403a2,0xdb048234,0x62800175}},	//   _akaq, _nohs, lujä, _efoo, 
   {{0x628004ba,0x311c00dc,0x201c0153,0x00000000}},	//   _ffoo, योगः_, gzti_, --, 
   {{0x6d5cbdf8,0x62800076,0x3eb80008,0x58d00eac}},	//   _shpa, _gfoo, ggst_, সায়ী, 
   {{0x6d5c0354,0x332c003d,0x7d040ac5,0x60c80175}},	//   _phpa, miex_, _bohs, _fbfm, 
   {{0x307804ac,0x332c003d,0x3ce00194,0x8af00213}},	//   _גאַנ, liex_, _cahv_, zləd, 
   {{0xad240222,0x26c4016b,0x8af000ac,0xdb043110}},	//   لىڭى, yfoo_, yləd, kujä, 
   {{0xed58013e,0xfaf40212,0x320c0009,0x332c0135}},	//   тоҳ_, очую, oyey_, niex_, 
   {{0x27e802c4,0xa9a4bdf9,0xdb0400c5,0xe8c81058}},	// [f720] _srbn_, сизд, dujä, лгал_, 
   {{0x320c0050,0x27e8003e,0x8af000ac,0x332c0003}},	//   iyey_, _prbn_, tməs, hiex_, 
   {{0xa1540302,0xeb98010b,0xab2802e8,0x16840133}},	//   צבעה_, _щин_, _бона_, ڵانێ, 
   {{0xe6187c6c,0x63acbdfa,0x8af003be,0x29180986}},	//   лде_, _åbni, rməs, shpa_, 
   {{0xa5088040,0x44980cb9,0x332c025c,0xc5f80116}},	//   леда_, авлю_, diex_, шға_, 
   {{0x26c4016b,0x320c0009,0xaa280023,0x344800dc}},	//   sfoo_, dyey_, _ተመሓላ, _ṣaṭ_, 
   {{0x320c0050,0x64a4035b,0xe7380261,0x66e46c1f}},	//   eyey_, _ҳаза, _бев_, _лова, 
   {{0x3a2c0b3d,0x21640116,0x53400022,0x8af003b9}},	//   _žepi_, әтиг, зхьа, lləb, 
   {{0x64a4bdfb,0x80dc2f8b,0x84c40075,0xa5f0009d}},	//   _газа, বাস্, _дәйд, _хүлц, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x332c038f,0x6280010a,0x6458005f,0x7d0403fa}},	//   biex_, _tfoo, _uzti, _rohs, 
   {{0x7d040007,0x1ea84c1c,0x62800009,0x3ce001a9}},	//   _sohs, دادي_, _ufoo, _sahv_, 
   {{0x5fd8bdfc,0x201c01ed,0x6144ad75,0xdb1c00e4}},	//   _बनवल, szti_, _леда, _ûvév, 
   {{0x80dc00bd,0x91b8010f,0x7f94030d,0x00000000}},	//   বাহ্, _עמוי, _дакх, --, 
   {{0x9f5c0108,0x00000000,0x00000000,0x00000000}},	//   tytä_, --, --, --, 
   {{0x28c447d0,0x3b541cb8,0xf8c80241,0x80b800dc}},	//   र्सि, ікар, _oléè_, ्भवे, 
   {{0xd0400198,0xdd9801b9,0xa3e807af,0x8d700092}},	// [f730] _banɗ, _ёши_, मिड_, በረችው_, 
   {{0xa78c0023,0x9f5c0108,0x00000000,0x00000000}},	//   _ዝቐጸለ_, sytä_, --, --, 
   {{0xb90022e3,0xb7d4027d,0xda6400ec,0xdb040821}},	//   _दस_, تقاب, _گادي, tujä, 
   {{0x332c0327,0xf6540798,0x00000000,0x00000000}},	//   xiex_, овеќ, --, --, 
   {{0xf8a84955,0x5884010b,0xda64aaa2,0x320c0009}},	//   _نگاه_, _гыба, _دادي, xyey_, 
   {{0x798c0912,0xd0400198,0x13a401b9,0xd49860a9}},	//   mpaw, _ganɗ, منتی_, урд_, 
   {{0x3ea8bdfd,0xc4c403e6,0x798c02d1,0x332c0135}},	//   _odat_, ستوو, lpaw, tiex_, 
   {{0x3ea8bdfe,0x320c0076,0x7bc00790,0x733400cf}},	//   _ndat_, tyey_, çluy, تىعا, 
   {{0x28c4085c,0x798cbdff,0x00000000,0x00000000}},	//   र्वि, npaw, --, --, 
   {{0xefc8be00,0x320c0067,0x332c031c,0x00000000}},	//   алол_, ryey_, siex_, --, 
   {{0xa3e8202e,0x82f82b9f,0xb4d477ca,0xb4b42e04}},	//   मिण_, _گرلز_, िजी_, झली_, 
   {{0x798cbe01,0xc62004c5,0x80dc00cc,0x332c0327}},	//   kpaw, _ফুটা_, বাষ্, qiex_, 
   {{0xed58be02,0xa3e80f4a,0x00000000,0x00000000}},	//   иом_, मिथ_, --, --, 
   {{0x3ea8af07,0xe41c00a2,0x00000000,0x00000000}},	//   _edat_, _öňün_, --, --, 
   {{0xeb98be03,0x3ea8031c,0xbf64be04,0xda84063f}},	//   риб_, _fdat_, تدیو, _ụlọa, 
   {{0xa3e800ce,0x25d8000d,0x00000000,0x00000000}},	//   मित_, _खईली_, --, --, 
   {{0x798c4cd3,0x80dc00bd,0x6c74009d,0x00000000}},	// [f740] gpaw, বার্, _мунх, --, 
   {{0x7c3403b2,0x645c0022,0x00000000,0x00000000}},	//   áfrá, ýpik, --, --, 
   {{0x28c40db3,0x18a0013e,0x15dc012d,0x00000000}},	//   र्षि, фахм, _खैबर_, --, 
   {{0xd0400198,0x00000000,0x00000000,0x00000000}},	//   _wanɗ, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x28c4a064,0xa3d43507,0x24f40108,0x00000000}},	//   र्शि, िबल_, ючер, --, 
   {{0xc4480345,0xe8080108,0xa3440139,0x00000000}},	//   حیان_, _тнвд_, жэпл, --, 
   {{0xe73806bb,0x1780109a,0x0ae800cc,0x28c400ce}},	//   _теб_, _ігум, _গকুল_, र्रि, 
   {{0xa3d8000d,0x00000000,0x00000000,0x00000000}},	//   _ढैर_, --, --, --, 
   {{0x3ea8026c,0x212800a3,0x854801d3,0xa3e80950}},	//   _sdat_, òbh_, _آئے_, मिद_, 
   {{0x200800d2,0x98780a7c,0x1878011a,0x33d40153}},	//   âbi_, יאיט, יטיב, _ніцт, 
   {{0xd12cb44c,0x9c840306,0x798cbe05,0x00000000}},	//   _یمن_, _ovčí, ypaw, --, 
   {{0x5ce400d4,0x2f00013a,0xd36cbe06,0x00000000}},	//   оюва, _jógy_, _شهه_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb040419,0x00000000,0x00000000,0x00000000}},	//   mujú, --, --, --, 
   {{0xf8b801c0,0x3ea8be07,0xdb04be08,0x798c033b}},	//   өөг_, _udat_, lujú, tpaw, 
   {{0xdce40598,0x9cc80724,0x00000000,0x00000000}},	// [f750] şlıg, _кына_, --, --, 
   {{0x3e84145e,0xdb0400d0,0x188829dc,0x7f6402dd}},	//   bëtï_, nujú, рсап_, _ﺒﻜل_, 
   {{0x798c094a,0xd7f80124,0xbf78004d,0xd76400d1}},	//   spaw, шуа_, _đuợc_, قەسى_, 
   {{0x7bc4be09,0x7754044e,0xdb04be0a,0x3a2c0219}},	//   _iqhu, _ዝኣመሰ, hujú, _žepu_, 
   {{0xdb040030,0x75c801e0,0x00000000,0x00000000}},	//   kujú, стең_, --, --, 
   {{0xb4d400af,0xb4b40037,0xdb0400d0,0x7d140334}},	//   िजे_, झले_, jujú, nkzs, 
   {{0xdb04be0b,0xd8d00327,0x00000000,0x00000000}},	//   dujú, _ཌིཇི, --, --, 
   {{0x7bc401f0,0xe7a402dd,0x0a38001f,0xb92000b8}},	//   _mqhu, _ءۇنى_, _በመሥራ, _rarṇ_, 
   {{0x94a87cbc,0x8cdc033f,0xe1f42fe5,0x00000000}},	//   _نطاق_, _फसलो, згы_, --, 
   {{0x0574be0c,0x44b489ed,0x7bc40944,0xf48420e8}},	//   _قالد, _обус, _oqhu, _رائی, 
   {{0x7bc401d4,0xb2742db7,0x00000000,0x00000000}},	//   _nqhu, _елеш, --, --, 
   {{0xd6cc01ec,0x4394009d,0x00000000,0x00000000}},	//   етi_, _цацс, --, --, 
   {{0x7bc41cdf,0xa3080014,0xdb0400d0,0x325401c6}},	//   _aqhu, _درٕے_, bujú, _эвдр, 
   {{0x823407d6,0xeea80228,0xf1b80e04,0xdb040030}},	//   _ترما, штүк_, muš_, cujú, 
   {{0xf1b80306,0x00000000,0x00000000,0x00000000}},	//   luš_, --, --, --, 
   {{0xc0e00023,0x65780092,0x00000000,0x00000000}},	//   ሓድር_, ጠባበቅ_, --, --, 
   {{0x7bc40912,0xf1b8be0d,0xdeb80375,0x00000000}},	// [f760] _eqhu, nuš_, _המפל, --, 
   {{0xe63405f5,0xb4d44196,0x00000000,0x00000000}},	//   үхдэ, िजो_, --, --, 
   {{0xf1b824e1,0xa848007b,0xe7380eed,0x64a40022}},	//   huš_, حلام_, беж_, ҧада, 
   {{0x6d4cbe0e,0xdd8c04fb,0xdb040030,0x27e4008f}},	//   loba, _جوی_, zujú, ĉon_, 
   {{0xb0bc146b,0x6d4c0076,0x598000c0,0x00000000}},	//   ्भाग, ooba, _пляб, --, 
   {{0x6d4cbe0f,0xc434331c,0x00000000,0x00000000}},	//   noba, وکات, --, --, 
   {{0x290818a6,0xdb040030,0x9f5c00d7,0x5fd80037}},	//   _ioba_, vujú, rytú_, _बनइल, 
   {{0x6d4cbe10,0x2908be11,0xa684be12,0x00000000}},	//   hoba, _hoba_, _хлад, --, 
   {{0xdb040030,0xe618009b,0xf1b800d7,0xa3e800cd}},	//   tujú, _уда_, guš_, मिह_, 
   {{0x2908be13,0x64a40432,0xf4f0035b,0x25a401a9}},	//   _joba_, _хажа, _аҧшь, msol_, 
   {{0x6d4cbe14,0x25a4be15,0x3f58be16,0xdb0401f1}},	//   doba, lsol_, séum_, rujú, 
   {{0x2908be17,0x200008ad,0x2c60001f,0x9db4025c}},	//   _loba_, ćki_, _ተስፋዬ_, _བཀྱེ, 
   {{0xdb0401f1,0x2908011f,0xa3e800dc,0x00000000}},	//   pujú, _ooba_, मिव_, --, 
   {{0x6d4cbe18,0x61e0be19,0x2908be1a,0x6568007b}},	//   goba, _isol, _noba_, nmfh, 
   {{0x49000316,0x3d0c0927,0xb5fc0219,0x60d80bb9}},	//   रानो_, _सकीं_, _izše, metm, 
   {{0x25a40254,0x00000000,0x00000000,0x00000000}},	//   ksol_, --, --, --, 
   {{0x2908be1b,0x9db40135,0x61e0031c,0x69c00137}},	// [f770] _boba_, _བཀྲེ, _jsol, көрб, 
   {{0x2908be1c,0x60d8be1d,0x61e07f88,0x82fc0327}},	//   _coba_, netm, _msol, _ཐོའུ_, 
   {{0x7bc4be1e,0x8af000ac,0xf1b800d0,0x25a41828}},	//   _uqhu, mlən, zuš_, esol_, 
   {{0x8af00213,0xd7609f6d,0x60d8010e,0x00000000}},	//   llən, رنشی, hetm, --, 
   {{0x60d8be1f,0x61e0be20,0x06cc015b,0x00000000}},	//   ketm, _nsol, _রোহি, --, 
   {{0x29085723,0x8af00213,0x33f4566b,0x27e4012d}},	//   _goba_, nlən, дчис, łona_, 
   {{0x61e0be21,0xa3d014b7,0x25a40419,0x00000000}},	//   _asol, војч, asol_, --, 
   {{0x6d4cbe22,0x2908be23,0xa5600075,0x25a4be24}},	//   zoba, _zoba_, ىگەن, bsol_, 
   {{0x2908be25,0x6d4cbe26,0x61e0be27,0x8af000ac}},	//   _yoba_, yoba, _csol, klən, 
   {{0x61e0003a,0x604001f2,0x6d4cbe28,0x6fa80063}},	//   _dsol, _ọmal, xoba, овог_, 
   {{0x6d4cbe29,0x61e0be2a,0x932401ed,0x8af003b9}},	//   voba, _esol, _ٹران, dlən, 
   {{0xada40348,0x61e0031c,0x941c0790,0x6d4cbe2b}},	//   мамл, _fsol, ışıy, woba, 
   {{0x61e00393,0x8af000ac,0xf1b80113,0x60d8acfe}},	//   _gsol, flən, quš_, betm, 
   {{0xdb040112,0xfd6400b8,0xdd8c007b,0x00000000}},	//   hrjä, _karṃ, شوف_, --, 
   {{0x242c0020,0x61e001ed,0x69b00034,0x6140030d}},	//   _እንደዚ, _zsol, ेंभी, _шеша, 
   {{0x6d4cbe2c,0x61e800d2,0x25a4be2d,0xceb406be}},	//   soba, _úmlâ, ysol_, _iləo_, 
   {{0x6d4c8f5a,0x25a4011f,0x2908be2e,0x8af00213}},	// [f780] poba, xsol_, _poba_, blən, 
   {{0x29080032,0x6d4cbe2f,0x8af000ac,0xa8182a8b}},	//   _qoba_, qoba, clən, يتار_, 
   {{0xf9904da8,0x290805d5,0xab64b154,0x37880248}},	//   نبە_, _voba_, _овол, _ṣeré_, 
   {{0xb8647d09,0x29088f29,0x60d8be30,0x25a40158}},	//   رالو, _woba_, zetm, tsol_, 
   {{0x2908be31,0x60d803be,0x06e0009e,0x6e2400b5}},	//   _toba_, yetm, ণালি, nzkb, 
   {{0xa3e8534e,0x00000000,0x00000000,0x00000000}},	//   मिल_, --, --, --, 
   {{0x25a4be32,0x61e00135,0x249c036e,0x00000000}},	//   ssol_, _ssol, _vetm_, --, 
   {{0x25a4be33,0xd1f00020,0x8af003be,0x0a38001f}},	//   psol_, ውጣት_, zlən, _በመስራ, 
   {{0x60d8be34,0x672000ec,0xb3540214,0x00000000}},	//   tetm, mhoj, ریها_, --, 
   {{0x3d0c9ced,0x66000472,0xa3b40d0d,0xb6300150}},	//   _सकें_, mxok, _जिप_, _ﯞﺍ_, 
   {{0x60d81295,0x6e50001f,0xa3e80073,0x3f8000c0}},	//   retm, _ማስገባ, मिळ_, _čius_, 
   {{0x60d8be35,0x6720be36,0x7500035b,0x61e0be37}},	//   setm, nhoj, _аҟәе, _tsol, 
   {{0x61e02a73,0x8af000ac,0x6600009a,0x7ae803b2}},	//   _usol, tlən, nxok, _óeti, 
   {{0x6600005a,0x2f3400ef,0x60d803e3,0x00000000}},	//   ixok, fāgs_, qetm, --, 
   {{0x8af000ac,0x67200472,0x628400d0,0x09d800eb}},	//   rlən, khoj, ľkof, সিফা, 
   {{0xa3b40034,0x8af000ac,0x09d8015b,0x67209034}},	//   _जिन_, slən, সিনা, jhoj, 
   {{0x6720be38,0x213c045a,0x5d640108,0x98c41b0a}},	// [f790] dhoj, onth_, _отоз, дсел, 
   {{0x8af00213,0xea6401b9,0x8b08013a,0x7e98179e}},	//   lləl, رپلی, _pařá, _بنکر_, 
   {{0x6fa001ad,0xcd3406c7,0x784400c7,0x3c5801af}},	//   कीपू, _جريب, хьаҧ, _хинэ_, 
   {{0x38b40241,0x67200978,0x00000000,0x00000000}},	//   _bùrà_, ghoj, --, --, 
   {{0x16700fae,0xc9840022,0x00000000,0x00000000}},	//   тқар, _ауси, --, --, 
   {{0x23640232,0x67200e14,0x6ef4008e,0x490000dc}},	//   _ahoj_, ahoj, _kübä, राणो_, 
   {{0xc7c4be39,0x78a4020b,0x672000dc,0x00000000}},	//   _исти, mahv, bhoj, --, 
   {{0x23640070,0x672000ec,0x2d5400b5,0xcc780375}},	//   _choj_, choj, læet_, וגות_, 
   {{0xe28c052f,0x6ef401b8,0x32180122,0x28c407af}},	//   _ҙа_, _lübä, ásy_, र्कि, 
   {{0xe28c00c7,0xd49800f3,0x00000000,0x00000000}},	//   _әа_, _фра_, --, --, 
   {{0xa3e800dc,0x00000000,0x00000000,0x00000000}},	//   मिः_, --, --, --, 
   {{0x2364047e,0x78a40477,0x799c02d0,0xe28c0114}},	//   _ghoj_, hahv, _owsw, _ља_, 
   {{0x78a4023a,0x010800f1,0xf1d001ee,0x00000000}},	//   kahv, ستیو_, _сөйө, --, 
   {{0x2b4005b1,0x67200023,0x9d5003e6,0xa3b40027}},	//   _sjkc_, zhoj, ێنێت, _जिम_, 
   {{0x799c02d0,0x6c3400c6,0x00000000,0x00000000}},	//   _awsw, رفرا, --, --, 
   {{0x8af003be,0xc0f00023,0x6720036e,0x1ae00b01}},	//   lməz, ውዓል_, xhoj, лосм, 
   {{0xc18c008f,0x2d5401bf,0xaa440006,0x6600031c}},	// [f7a0] ַטאָ, fæet_, хеал, xxok, 
   {{0x1cdc0135,0x56903769,0xebe41318,0x30bc0f22}},	//   _ལིར_, қашт, _зооп, _অসুস, 
   {{0x28c409fa,0x6720be3a,0x799c035a,0x24640241}},	//   र्गि, thoj, _ewsw, _mímí_, 
   {{0xe5c44f65,0x660001c0,0x3a08004b,0x6720023a}},	//   еско, txok, _ښکلی_, uhoj, 
   {{0x8af003e3,0x6720023a,0x78a4014f,0x602401d3}},	//   nləm, rhoj, bahv, _kémé, 
   {{0x6720be3b,0x28c409bb,0x2244022e,0x00000000}},	//   shoj, र्खि, _rxok_, --, 
   {{0xa5080075,0x6024be3c,0x291801f2,0x5f0000dc}},	//   يىچە_, _mémé, mkpa_, षाम्_, 
   {{0x6024003e,0x8af000ac,0x00000000,0x00000000}},	//   _lémé, kləm, --, --, 
   {{0xd624014b,0x1ddc1bbb,0x00000000,0x00000000}},	//   _зоте_, _पैंत, --, --, 
   {{0x11d000f1,0xab6000a2,0x20c401d5,0x8af006be}},	//   اتيد, _çüfl, хсиг, dləm, 
   {{0x4438be3d,0x657800aa,0x23640070,0xb5fc0171}},	//   _är_, _iith, _thoj_, _izša, 
   {{0x1cdc03bd,0x78a405a1,0x6578901c,0x0c84190b}},	//   _ལིཤ_, zahv, _hith, ғырм, 
   {{0x6578be3e,0x5180010b,0x64580108,0x628400d7}},	//   _kith, _йуща, _hyti, ľkod, 
   {{0x6578be3f,0x6024003e,0x64580122,0x645400ac}},	//   _jith, _cémé, _kyti, əyir, 
   {{0x6578be40,0x8af003be,0x6024be41,0x78a4be42}},	//   _mith, lməy, _démé, vahv, 
   {{0x3df4aaba,0x65783d97,0x91d000fe,0x8af006be}},	//   _азис, _lith, তিৰ্, bləm, 
   {{0x3a74be43,0x78a40842,0x64580006,0x8af000ac}},	// [f7b0] тлар, tahv, _lyti, nməy, 
   {{0x97a4be44,0x65781554,0x6ef40598,0x00000000}},	//   ердл, _nith, _tübä, --, 
   {{0x6458be45,0x78a4be46,0x2d5412e8,0x00000000}},	//   _nyti, rahv, ræet_, --, 
   {{0x6578be47,0xcda8034c,0x2c0c038e,0x8af00213}},	//   _aith, _تهیه_, ठहरू_, kməy, 
   {{0x6458be48,0x6578be49,0x7aecbe4a,0x78a40108}},	//   _ayti, _bith, mdat, pahv, 
   {{0x6578be4b,0x6458be4c,0x1cdc0135,0x9c10063f}},	//   _cith, _byti, _ལིས_, pọdo, 
   {{0x65786980,0x80dc0729,0x7aec4b7d,0x7afc0083}},	//   _dith, বাঞ্, odat, _knst, 
   {{0x7aecbe4d,0x6578be4e,0x8af000ac,0x64580240}},	//   ndat, _eith, yləm, _dyti, 
   {{0x6458be4f,0x6578be50,0x7aecbe51,0x3a28be52}},	//   _eyti, _fith, idat, nzap_, 
   {{0x6578be53,0x7aecbe54,0x9f5c02fb,0x64580240}},	//   _gith, hdat, rytý_, _fyti, 
   {{0x7afc709e,0x28c465d9,0x6024ae51,0x7aecbe55}},	//   _onst, र्टि, _rémé, kdat, 
   {{0x6578be56,0xa3b4024a,0x3b080135,0x73380108}},	//   _zith, _जित_, jjaq_, _юзер_, 
   {{0x7aecbe57,0x6578be58,0x8af006be,0xdd8c01c8}},	//   ddat, _yith, cməy, يوَ_, 
   {{0x65780564,0x7aec0381,0xefc0001f,0x00000000}},	//   _xith, edat, ቻለው_, --, 
   {{0xdca0329c,0xa0640124,0x2d54005c,0xa1540063}},	//   раси, _иаша_, fæer_, _шаљу_, 
   {{0x7aec8b14,0x8af003e3,0x00000000,0x00000000}},	//   gdat, mlək, --, --, 
   {{0xe8e8be59,0x1ce401ed,0x2d9401c0,0x6024be5a}},	// [f7c0] ммад_, رکیٹ_, _шөнө_, _témé, 
   {{0x7afcbe5b,0x7aecbe5c,0x39400280,0x2d90bc61}},	//   _enst, adat, gnhs_, _itye_, 
   {{0x6578be5d,0x7aecbe5e,0x764803ac,0x2bb8007b}},	//   _rith, bdat, _axey, _غادة_, 
   {{0x6578be5f,0x28c4449f,0x9550be60,0x75201a80}},	//   _sith, र्जि, یخوا, _allz, 
   {{0x77680a81,0xd70400a7,0x5f0000dc,0x09ac07f7}},	//   _dhex, ънце_, षात्_, _चिटठ, 
   {{0x64580042,0x1dc001ad,0xa9680408,0xa3b4023e}},	//   _pyti, वंतत, _цига_, _जिद_, 
   {{0x7afc0225,0x6578be61,0x148400d1,0xe738009b}},	//   _ynst, _vith, خپىي_, _жев_, 
   {{0x6578662c,0x6458be62,0x2d90be63,0x77680327}},	//   _with, _vyti, _otye_, _ghex, 
   {{0x2d901529,0x2164be64,0x64580204,0x65786b41}},	//   _ntye_, ктог, _wyti, _tith, 
   {{0x65782595,0x8af003be,0x28c46766,0x00000000}},	//   _uith, rməy, र्चि, --, 
   {{0x2d90be65,0x7aec0034,0x3b08014f,0xd36c00f5}},	//   _atye_, ydat, yjaq_, _вч_, 
   {{0x7aecbe66,0xff242f4d,0x7178be67,0x3d9401f0}},	//   xdat, ابدی, мбөр_, лимр, 
   {{0xa3e81d8a,0xa3dc068f,0xc0c404a9,0x57dc09bb}},	//   मिक_, दौर_, _йәни, _नन्ह, 
   {{0x7aecbe68,0x8af003b9,0x00000000,0x00000000}},	//   wdat, lləh, --, --, 
   {{0x46b41524,0x7aecbe69,0x9f4c032e,0x614400d1}},	//   ुलाह, tdat, _hrfí_, _كىچە, 
   {{0x7aecbe6a,0x22b40134,0x58f8025c,0x3074010b}},	//   udat, _bɛkɔ_, _ནོངས_, _сучс, 
   {{0x2d54005c,0x00000000,0x00000000,0x00000000}},	// [f7d0] ræer_, --, --, --, 
   {{0x7aecbe6b,0x61e403cd,0x776803e3,0x00000000}},	//   sdat, åkly, _shex, --, 
   {{0x7aec6afa,0x76b8be6c,0x77680a55,0xc7c4009b}},	//   pdat, елер_, _phex, исци, 
   {{0x3f58be6d,0x00000000,0x00000000,0x00000000}},	//   méus_, --, --, --, 
   {{0x55300022,0x5990be6e,0x00000000,0x00000000}},	//   аҭас, _ضیاء, --, --, 
   {{0xb4ac0490,0xdb040407,0x64a01513,0x5884be6f}},	//   कणे_, pujó, баша, _шыма, 
   {{0x04b402d5,0x6910005c,0x03a806c5,0x6cd40150}},	//   рсія, _tæer, نديو_, _ﺘﺤﺴﻴ, 
   {{0x22b4016b,0xc2f400c7,0x00000000,0x00000000}},	//   _yɛkɔ_, аџьы, --, --, 
   {{0xd4c400e4,0x3f580120,0xe7840022,0xb5fc0427}},	//   _асеп, héus_, _ауӡо, _izšo, 
   {{0x2d901529,0x00000000,0x00000000,0x00000000}},	//   _rtye_, --, --, --, 
   {{0xad2400d1,0x00000000,0x00000000,0x00000000}},	//   ۇرسو, --, --, --, 
   {{0x6ae0000d,0x00000000,0x00000000,0x00000000}},	//   _पसेर, --, --, --, 
   {{0x437016a0,0x00000000,0x00000000,0x00000000}},	//   _بۇير, --, --, --, 
   {{0x3f58be70,0x17000327,0x00000000,0x00000000}},	//   féus_, _ཚོའམ_, --, --, 
   {{0xed5864b6,0x00000000,0x00000000,0x00000000}},	//   _җон_, --, --, --, 
   {{0xa3b4068f,0xff380022,0xaec4005b,0x34340092}},	//   _जिस_, _аџьы_, _сбил, _እንድሪ, 
   {{0xe8f8be71,0x2d90bc61,0xe9d80024,0xed580107}},	// [f7e0] нла_, _utye_, эка_, _пои_, 
   {{0x692400c7,0x00000000,0x00000000,0x00000000}},	//   ымза, --, --, --, 
   {{0xa3e0033f,0x00a000d1,0x00000000,0x00000000}},	//   _कैंप_, _ﺋﯘﺳﯘ, --, --, 
   {{0x66140158,0x00000000,0x00000000,0x00000000}},	//   øyko, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6aa4000f,0xb5fc09a8,0x20080254,0x00000000}},	//   _hekf, _izšl, äbik_, --, 
   {{0x6aa4083a,0x3804016c,0x4394be72,0x79500133}},	//   _kekf, _корҳ, шайс, _بێلا, 
   {{0x68ecbe73,0x27e8be74,0xceb403e3,0xe2a8be75}},	//   _habd, _isbn_, _ndə_, رابن_, 
   {{0x6aa400a1,0x68ec0009,0x6f9c02dd,0x5b78010f}},	//   _mekf, _kabd, _ﺃﻨﻨﺎ_, ערפא, 
   {{0x8af003be,0x68ec208d,0x6aa4369d,0xceb406be}},	//   sləh, _jabd, _lekf, _adə_, 
   {{0x27e8003e,0x2ca80109,0x68ecbe76,0xa3b800cf}},	//   _jsbn_, dabd_, _mabd, _ساار_, 
   {{0xd24c5d35,0x26c4be77,0xe72c022e,0x00000000}},	//   _کنه_, ngoo_, tsеy_, --, 
   {{0x6280be78,0x26c4062c,0xaab80118,0x00000000}},	//   _igoo, igoo_, ेलनक, --, 
   {{0xceb403be,0xd00c00aa,0x68ec0067,0x3f58020c}},	//   _edə_, _ډله_, _nabd, téus_, 
   {{0x6aa4be79,0xa3e80d0a,0xdbe00005,0x3c5800a8}},	//   _bekf, मिट_, téñe, тивэ_, 
   {{0xab6007c4,0x68ec0334,0x8aa4004e,0xcfa0010a}},	//   şünc, _aabd, йруд, _ушши, 
   {{0x795805f5,0x6aa4be7a,0x2ca8020c,0x8e840063}},	// [f7f0] виар_, _dekf, babd_, _угње, 
   {{0x68ec0d62,0x3f580798,0x26c40009,0x38c80101}},	//   _cabd, péus_, egoo_, ضائی_, 
   {{0x6280be7b,0x383410f3,0x68ecbdad,0x645c00c5}},	//   _ogoo, јнер, _dabd, üpil, 
   {{0x36d4be7c,0x35f40fbe,0x6280be7d,0x26c42857}},	//   родр, ипер, _ngoo, ggoo_, 
   {{0x75c80184,0xaae400db,0x60c802d0,0x5fa4043e}},	//   ттең_, _ئسپو, _ocfm, _कौसल, 
   {{0x68ecbe7e,0x6280be7f,0x26c40009,0x5ea80154}},	//   _gabd, _agoo, agoo_, _কাফে, 
   {{0x78b405b8,0x5ea80f22,0x73c40166,0x00000000}},	//   _idzv, _কানে, рәзе, --, 
   {{0x62801529,0x1cdc025c,0x8c380375,0x68ec652c}},	//   _cgoo, _ལིཀ_, טטוס_, _zabd, 
   {{0x31247b45,0xfba432ed,0x6280010a,0x68ec016d}},	//   идиг, गीतम, _dgoo, _yabd, 
   {{0x6280be80,0x8574be81,0x68ec0009,0x307468ba}},	//   _egoo, _глух, _xabd, иунс, 
   {{0x62800175,0x68e8002d,0x0324009d,0x00000000}},	//   _fgoo, ôfdi, рдөн, --, 
   {{0x62801418,0xa8540375,0xefc80022,0x325404c2}},	//   _ggoo, ייתה_, нуҭк_, _квер, 
   {{0x6f9c02dd,0x00000000,0x00000000,0x00000000}},	//   _ﺃﻨﻬﺎ_, --, --, --, 
   {{0xdca0be82,0xc2440845,0x00000000,0x00000000}},	//   жари, _унік, --, --, 
   {{0x68ecbe83,0x6a84be84,0x6aa401e3,0x1d04be85}},	//   _rabd, илва, _pekf, шери_, 
   {{0x68ecbe86,0x78b40810,0x5274010a,0x8af003e3}},	//   _sabd, _adzv, _руçу, hləv, 
  
   {{0x68ec014f,0x00000000,0x00000000,0x00000000}},	// [f800] _pabd, --, --, --, 
   {{0x68ecbe87,0x1cdc025c,0x994c00ee,0xb3040327}},	//   _qabd, _ལིག_, nüň_, _མོའང_, 
   {{0xeab80323,0xeb98be88,0x6aa4be89,0x3cf000bc}},	//   _ийн_, _шин_, _tekf, řová_, 
   {{0x81dc02f5,0xe61809a5,0x98a800e2,0x00000000}},	//   ডিত_, кде_, ēmās_, --, 
   {{0x5ea8045e,0xc5f81669,0x1a9800c8,0x26c4be8a}},	//   _কামে, ыға_, _ביכע, rgoo_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x66e47f9a,0x77901a69,0x232401d5,0x994c00a2}},	//   _кова, _فیلا, ифиг, düň_, 
   {{0x52801e87,0xe23c0023,0x00000000,0x00000000}},	//   يلىك, _ክስርሓ, --, --, 
   {{0xb59404d3,0x7c28010f,0x06bc00eb,0x00000000}},	//   _هێنا_, ĝeri, _ইউপি, --, 
   {{0xc39001af,0x994c010e,0x00000000,0x00000000}},	//   _еҫкә, güň_, --, --, 
   {{0xe3b0be8b,0xa2e406ed,0x194c00b5,0x5fa4be8c}},	//   _ذرا_, _воед, _ｍｉｅ_, _कौशल, 
   {{0xe298be8d,0x1cdc2fb5,0x62800b6f,0xbb9001ec}},	//   _рад_, _ལིང_, _ugoo, _ﻓﺎﻨﻪ_, 
   {{0x614417a0,0xfd74009d,0x00000000,0x00000000}},	//   _кеда, йлмэ, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x06bc2f8b,0x0b88be8e,0xabb400d1,0x1aa400f0}},	//   _ইউনি, исти_, йарә, ијаг, 
   {{0xb0500014,0x0a380092,0x00000000,0x00000000}},	//   _ژھێت, _በመምራ, --, --, 
   {{0xe0e801e1,0xf8b801c0,0xa90801a9,0x00000000}},	// [f810] _gbòò_, лөв_, rmоn, --, 
   {{0xfaf000aa,0x3ea8be8f,0x3cf0010a,0xa908022e}},	//   _ډګر_, _heat_, qdzv_, smоn, 
   {{0x8d745841,0x3ea805b1,0x6cd4021f,0x9a840111}},	//   _بايا, _keat_, _اقپا, _вугл, 
   {{0x47580212,0x00000000,0x00000000,0x00000000}},	//   арія_, --, --, --, 
   {{0x8af000ac,0x3ea826e7,0x09e400c0,0x00000000}},	//   tləv, _meat_, _доўн, --, 
   {{0x3ea8be90,0x78b40099,0x64a000c0,0xb924009f}},	//   _leat_, _udzv, паша, _افسي, 
   {{0x442002bf,0x62840030,0x8534be91,0x798c0139}},	//   цi_, ľkon, تووچ, lqaw, 
   {{0x3ea8be92,0x7744009f,0x00000000,0x00000000}},	//   _neat_, _اَرم, --, --, 
   {{0x798c02d1,0x35b400ee,0xdee00023,0x76640451}},	//   nqaw, _ыбар, ምንን_, _اڏام, 
   {{0x8af003be,0x3ea8215a,0x00000000,0x00000000}},	//   llət, _aeat_, --, --, 
   {{0x3ea82734,0x720408f0,0xdb040254,0xb63002dd}},	//   _beat_, _گوشم, lujõ, _ﺐﻠ_, 
   {{0x6438008f,0x63bc02f0,0x00000000,0x00000000}},	//   _געענ, ápne, --, --, 
   {{0x3ea8af97,0x3208046c,0x72041617,0xdfcc05af}},	//   _deat_, _çay_, _دوشم, ويی_, 
   {{0x2d9c03c6,0xdaa00131,0x7ad4033f,0xceb403e3}},	//   ďte_, ۋەپپ, ड्सअ, _alət_, 
   {{0xab2805c5,0x3ea8be93,0xdbb80022,0x8af006be}},	//   гова_, _feat_, лттә_, klət, 
   {{0xcc8800aa,0x3ea8be94,0x6a8401c6,0x3a980108}},	//   انځه_, _geat_, слаа, итую_, 
   {{0x798c009a,0xdd8c02ef,0x5ea80183,0xdb040254}},	// [f820] gqaw, _كوي_, কলশে, jujõ, 
   {{0x6f14be95,0x2ef0022e,0xdb0408a5,0x00000000}},	//   _hoyc, _hayf_, frjó, --, 
   {{0x6d5cbe96,0x2ef0be97,0x6f140205,0x1d14011a}},	//   _ikpa, _kayf_, _koyc, _הקיר_, 
   {{0x6f140e1a,0x00000000,0x00000000,0x00000000}},	//   _joyc, --, --, --, 
   {{0x6f14022e,0x398c02d2,0xdbe001a8,0x00000000}},	//   _moyc, _gþs_, _héða, --, 
   {{0x6f143c2a,0x2ef00139,0x791801d5,0xdb04032e}},	//   _loyc, _layf_, _кўст_, brjó, 
   {{0x6d5c00b4,0xc4484a23,0x98a0be98,0xdb0403b2}},	//   _mkpa, جیان_, _хисе, lsjá, 
   {{0x070c19e5,0x49000316,0x2ef0002d,0x628401f1}},	//   _सचिव_, राको_, _nayf_, ľkoo, 
   {{0x442000da,0x8af000ac,0xe648be99,0x6d5c0fac}},	//   ņi_, lləs, _спад_, _okpa, 
   {{0xb9f0069c,0x6720be9a,0x6d5c02e3,0xdee002d3}},	//   _ዓዲ_, lkoj, _nkpa, ምዕን_, 
   {{0x3ea847b4,0xb5fc04bf,0xf1b801f1,0xaab80118}},	//   _peat_, _vyše, vyše_, ेलाक, 
   {{0x6d5c00b4,0x6720be9b,0x8108004b,0x3e6c022e}},	//   _akpa, nkoj, ارکې_, lоti_, 
   {{0x6f14014f,0x9340be9c,0x5ea8015b,0x6d5c0175}},	//   _doyc, _энце, _কাদে, _bkpa, 
   {{0x303890c7,0x6720be9d,0x8af00213,0x2fc401a9}},	//   اتیک_, hkoj, zlət, bulg_, 
   {{0x6720049b,0x3ea8be9e,0x4034be9f,0x3f8c0135}},	//   kkoj, _teat_, _фейс, qqdu_, 
   {{0x6d5c010f,0x672001e4,0x4500009e,0x6f1406be}},	//   _ekpa, jkoj, ্সিক_, _goyc, 
   {{0x8af00cc1,0x6d5c1132,0x201c0006,0x712401d9}},	// [f830] vlət, _fkpa, lyti_, _دى۪م, 
   {{0x213cbea0,0x7e6cbea1,0x95c801ec,0x67200171}},	//   nith_, _izap, ғуда_, ekoj, 
   {{0xdbe00077,0xb78829db,0x201c0024,0x798c03f0}},	//   _téña, рәге_, nyti_, sqaw, 
   {{0xd6a8113e,0x15b400aa,0xcf9000c8,0xfd600241}},	//   ادام_, مختګ_, לטע_, _niyẹ, 
   {{0xd5b8170a,0x7bd401c6,0x628400d0,0x74cc043e}},	//   усе_, ltzu, ľkol, _सादृ, 
   {{0x201c0953,0x98e40228,0x550032ed,0x94a801d5}},	//   kyti_, _уюмд, लाइए_, утда_, 
   {{0x7bd40323,0x8af00cc1,0x213cbea2,0xb45802d3}},	//   ntzu, mlər, dith_, _ልዕላዉ, 
   {{0x201c0953,0x8af00213,0xb064049b,0x7f4c00e8}},	//   dyti_, llər, hdää, _njaq, 
   {{0x6f14bea3,0x7e6c2776,0xf1a81ec7,0x95c800ea}},	//   _royc, _nzap, جاعه_, _љуба_, 
   {{0x8af00cc1,0x7f4c0113,0xe0d4bea4,0x6f1400eb}},	//   nlər, _ajaq, овь_, _soyc, 
   {{0x201c0006,0xa3b405f9,0xa9380375,0xc0b80092}},	//   gyti_, _जिए_, שתתפ, ዲመራ_, 
   {{0x6f140113,0x7d04004d,0x213c03cb,0xd34402f2}},	//   _qoyc, _anhs, aith_, _دیبه_, 
   {{0x9264bea5,0x8af00cc1,0x7e6c033f,0xd04403b9}},	//   _ادام, klər, _czap, _ələl, 
   {{0x7e6c006f,0x7bd417da,0x2ef001bf,0x201cbea6}},	//   _dzap, ftzu, _wayf_, byti_, 
   {{0x8af003be,0x7e6c209c,0x3078008f,0xad240c50}},	//   dlər, _ezap, _דאַנ, مىڭى, 
   {{0xab64063b,0x332c01ab,0x7f4c036e,0x81dc0154}},	//   івал, nhex_, _gjaq, ডির_, 
   {{0x8af003be,0x2c0800eb,0x00000000,0x00000000}},	// [f840] flər, রনেই_, --, --, 
   {{0x6844bea7,0xdb0401a8,0xa3b837f3,0x6d5c02d0}},	//   онза, rsjá, _अटल_, _ukpa, 
   {{0xdb04819e,0x672002f6,0xa024000d,0x00000000}},	//   dsjæ, tkoj, mtöö, --, 
   {{0xa02433eb,0x67200024,0xbc7001ec,0x69c00073}},	//   ltöö, ukoj, _سۇقب, _लिपी, 
   {{0x6720bea8,0x8af003be,0x24e81411,0x290c01b8}},	//   rkoj, blər, имди_, öfas_, 
   {{0x6720bea9,0x1cdc31d9,0x69d4beaa,0x55500131}},	//   skoj, _ལིབ_, mtye, ۋھەر, 
   {{0x213c00d8,0xa0240254,0x5ea800eb,0x8af006be}},	//   vith_, itöö, _কাসে, qləs, 
   {{0x213c0368,0xe6180006,0x2be0033f,0xa024005b}},	//   with_, _кдб_, _पहना, htöö, 
   {{0x69d4beab,0xb06402f6,0xa3b401ad,0x69b00412}},	//   ntye, ydää, _जिक_, ेंटी, 
   {{0x201c0953,0xa0883755,0xe4c800ec,0xa490179e}},	//   tyti_, шсиз_, _خبرن_, _غیبت, 
   {{0x27f804fb,0x213cbeac,0x232815ab,0x7e6c01ed}},	//   nvpn_, rith_, _кожи_, _szap, 
   {{0x8af00cc1,0x201c02d5,0x69d43464,0x213cbead}},	//   zlər, ryti_, ktye, sith_, 
   {{0xb8fc003d,0x8af003be,0x201c0006,0x3f98005f}},	//   _རྡ_, ylər, syti_, ūru_, 
   {{0x61e0beae,0x201c0024,0x9cc8b5ff,0x4034beaf}},	//   _ipol, pyti_, шыма_, _нелс, 
   {{0x8af003be,0xffb400ee,0x00000000,0x00000000}},	//   vlər, _эййэ, --, --, 
   {{0x7bd405f5,0xe68002d3,0x7f4c0869,0xc1780153}},	//   rtzu, ንስትዮ_, _ujaq, lmė_, 
   {{0x8af00cc1,0x7bd403fa,0x7f5c29a5,0xda781b0a}},	// [f850] tlər, stzu, mosq, ряв_, 
   {{0x25fc04fa,0x61e064f1,0x9964beb0,0x7f5cbeb1}},	//   लिनी_, _mpol, італ, losq, 
   {{0x8af011a9,0x61e001af,0x7c2801e4,0xdb0401bf}},	//   rlər, _lpol, ĝers, vsjæ, 
   {{0x61e0beb2,0x2570193f,0x8af003be,0x3ae80e3f}},	//   _opol, hâld_, slər, _ابدی_, 
   {{0xd30c001e,0xc1780006,0x8af000ac,0x61e05cb6}},	//   _lệch_, kmė_, plər, _npol, 
   {{0x8af000ac,0x7f5c0477,0x00000000,0x00000000}},	//   qlər, hosq, --, --, 
   {{0x1cdc0003,0x61e0beb3,0x394004cc,0x658001d9}},	//   _ལིན_, _apol, mihs_, ریمٕ, 
   {{0x60d8010a,0x61e0007b,0xf748007b,0x00000000}},	//   eftm, _bpol, _الري_, --, 
   {{0x61e01529,0xb6a4beb4,0x956400a7,0x7f5c0381}},	//   _cpol, _миңл, _дъжд, dosq, 
   {{0x81dc0eac,0xb5fc00a2,0xd30c0208,0x320c0067}},	//   ডিং_, _gyša, _bệch_, rxey_, 
   {{0x61e0beb5,0x7f5c00db,0xa024000d,0xaf080efe}},	//   _epol, fosq, vtöö, مقدم_, 
   {{0x33740372,0xd340beb6,0x7f5c003a,0xdb04007c}},	//   _эгер, _تفصی, gosq, nsjä, 
   {{0xa0240e03,0x5ea80154,0x42540798,0xdb040108}},	//   ttöö, _কাশে, _отшт, isjä, 
   {{0xf8dc00dc,0xa024000d,0x00000000,0x00000000}},	//   न्मय, utöö, --, --, 
   {{0xeb9816c3,0x7f5c003a,0x61e002f0,0x5ea80154}},	//   сиб_, bosq, _zpol, _কারে, 
   {{0xa024793d,0x8af000ac,0x69d4beb7,0x61e0003a}},	//   stöö, tləq, ttye, _ypol, 
   {{0x2000005f,0x81dc0183,0xdb040267,0x6ea0503c}},	// [f860] ākie_, ডিঅ_, dsjä, _क्यु, 
   {{0x69d4beb8,0x00000000,0x00000000,0x00000000}},	//   rtye, --, --, --, 
   {{0x69d4beb9,0xdcf4054e,0x7c8001e0,0xb5fc1155}},	//   stye, şcăt, _аҫра, _ryša, 
   {{0x69d4beba,0x7bc001fa,0x62840030,0xdb04007c}},	//   ptye, šluc, ľkok, gsjä, 
   {{0x62840006,0x7cc42099,0x2498007b,0xd68000db}},	//   žkok, _عزیم, منشد_, нушп, 
   {{0x9f4c0100,0x758800d4,0x9b900244,0x00000000}},	//   _esfè_, ісів_, _تلێت, --, 
   {{0x61e01f48,0xa3b40254,0x1b0c03d4,0xb5fc00d7}},	//   _spol, _जिओ_, _সততে_, _vyša, 
   {{0x25700a85,0xe73806bb,0xf7400022,0xb35430fe}},	//   wâld_, _уеб_, _иҵхо, ویلا_, 
   {{0x5ea80f22,0x7f5c0393,0xc17402e8,0xa3d001d5}},	//   _কালে, vosq, млищ, фоқч, 
   {{0x6b8401e3,0xc8cc00bc,0x21280332,0x00000000}},	//   _likg, ालिट, óbh_, --, 
   {{0x2570000f,0x7f5c16b8,0xdb04143a,0x11d001d5}},	//   râld_, tosq, lsjå, وتید, 
   {{0xc1780024,0x15e0000d,0x00000000,0x00000000}},	//   smė_, _गहमर_, --, --, 
   {{0x61e0bebb,0x7f5c1730,0xddcc0006,0xe3bc03d4}},	//   _upol, rosq, ždži, _আহিব, 
   {{0x14dcbebc,0xb5fc0010,0x7f5c0393,0x00000000}},	//   प्पण, _izšt, sosq, --, 
   {{0xd0f4008d,0xdb04005b,0x50d8011a,0x01a8009f}},	//   _זצוק_, ysjä, _החוצ, _اُڻي_, 
   {{0x6b84001f,0x1cdc025c,0x7f5c1fc6,0x1398010f}},	//   _cikg, _ལིམ_, qosq, מבלע, 
   {{0x6b84bebd,0xd8e402e8,0x00000000,0x00000000}},	// [f870] _dikg, зцеп, --, --, 
   {{0x9e6404fb,0x61e401bf,0x5eb400e5,0x628400d7}},	//   _واکن, ækly, _بچھڑ_, ľkoh, 
   {{0x77980166,0x00000000,0x00000000,0x00000000}},	//   цкер_, --, --, --, 
   {{0x3ce00a28,0xb9140521,0xfaa43321,0xdb04005b}},	//   _hbhv_, _yabụ_, _تجدی, usjä, 
   {{0xdb04007c,0x00000000,0x00000000,0x00000000}},	//   rsjä, --, --, --, 
   {{0x85e810f5,0x799c14dc,0x25dc1d15,0xa504013e}},	//   ядів_, _itsw, _गहरी_, деша_, 
   {{0x06bc00eb,0x00000000,0x00000000,0x00000000}},	//   _ইউরি, --, --, --, 
   {{0x799c02d0,0x00000000,0x00000000,0x00000000}},	//   _ktsw, --, --, --, 
   {{0x81d401c6,0xd568074d,0x00000000,0x00000000}},	//   нцэц, _дiал, --, --, 
   {{0x34b400f2,0xa1540114,0x00000000,0x00000000}},	//   _آماز, мању_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe28cbebe,0xf8dc0882,0x12c40150,0x799cbebf}},	//   _ја_, न्तय, _ءتاپ, _otsw, 
   {{0x799cbec0,0xe0cc8e38,0xc32c1066,0xd24401c0}},	//   _ntsw, _ив_, _دەي_, _ээжи, 
   {{0xac08006c,0x6b84014b,0x82f803e6,0xa1600124}},	//   онга_, _sikg, _ورۆز_, _иҭыҵ, 
   {{0x799cbec1,0xef180137,0x7c94084c,0x2f5400ea}},	//   _atsw, _ммк_, эряц, _отис, 
   {{0x1ae036ca,0x9ac00083,0x50a000d1,0xfaf400d4}},	//   косм, ŋŋng, _تەگل, нчую, 
   {{0x799c03ac,0x2d9401d5,0xed340024,0x00000000}},	// [f880] _ctsw, _ўрис, _жэнэ, --, 
   {{0xb5fc02fb,0x00000000,0x00000000,0x00000000}},	//   _pyšn, --, --, --, 
   {{0x799c052f,0x60dc05d2,0x00000000,0x00000000}},	//   _etsw, _öpme, --, --, 
   {{0x6fc40574,0xb5fcbec2,0xaab00210,0x26d003e0}},	//   _विनं, _vyšn, _ज़िक, üyo_, 
   {{0x6d4c01a4,0x6ed43ec5,0xef240205,0x00000000}},	//   onba, _भानु, çüye_, --, 
   {{0x7c6415c3,0xf4b40131,0xdb0403cd,0x00000000}},	//   _تاۋل, ىشىگ, rsjå, --, 
   {{0x6d4c34eb,0xdb0408fb,0x29080009,0x3218005b}},	//   inba, ssjå, _inba_, äsyn_, 
   {{0xe24402d3,0x05000eac,0x6d4c0e78,0xd700bec3}},	//   _ንስርዓ, ্সের_, hnba, _изси, 
   {{0x9660bec4,0xa3b80d79,0x6d4c03cd,0xdbe006af}},	//   _акте, _अटक_, knba, réée, 
   {{0xb5fc04bf,0x6d4c18c0,0xdeb8010c,0xe504bec5}},	//   _myšl, jnba, ታዉን_, _تبري, 
   {{0xe2980006,0x800800e5,0x00000000,0x00000000}},	//   _дае_, سردہ_, --, --, 
   {{0x6d4cbec6,0x656808c2,0x93400107,0x00000000}},	//   enba, llfh, _инхе, --, 
   {{0x656801e7,0x00000000,0x00000000,0x00000000}},	//   olfh, --, --, --, 
   {{0x6d4c69c9,0xf1a832cc,0x3cf8000d,0x00000000}},	//   gnba, _راهه_, _ऋोखे_, --, 
   {{0xd30c001e,0x4c94010a,0x799c02d0,0x656801e7}},	//   _mệnh_, тисс, _stsw, ilfh, 
   {{0x2908217e,0xd30c001e,0x6d4cbec7,0x8f4400c7}},	//   _anba_, _lệnh_, anba, _ахьд, 
   {{0x81dc009e,0x00000000,0x00000000,0x00000000}},	// [f890] ডিক_, --, --, --, 
   {{0x6b9c0175,0x9ba000db,0x00000000,0x00000000}},	//   _ftpg, _لەسى, --, --, 
   {{0x3f88bec8,0xf1c800d7,0x00000000,0x00000000}},	//   _kiau_, mpáš_, --, --, 
   {{0x29081529,0x3e840374,0x8f7c010f,0x0f7c00df}},	//   _enba_, _tītī_, ַנגק, ַרגל, 
   {{0xd30c07ae,0x3f8804c4,0x7aecbec9,0x799c0b58}},	//   _bệnh_, _miau_, meat, _utsw, 
   {{0x33f4beca,0x7aecbecb,0x2bd80344,0x3f8800c0}},	//   ечис, leat, _بایک_, _liau_, 
   {{0x3f8803a0,0xc4f800c6,0xc864becc,0xc7b8014b}},	//   _oiau_, بعنا_, _атти, _оёт_, 
   {{0x3f88becd,0x7aeca3d6,0x644c01a6,0xa03c0023}},	//   _niau_, neat, _žbic, _ኣሕዋቶ, 
   {{0x6d4cbece,0xd5b890a9,0x15e000af,0x45d400f3}},	//   ynba, _фсб_, _गहिर_, _иотс, 
   {{0x63b8005a,0xdb04002d,0xb1a4004e,0x00000000}},	//   _fvtn, tsjû, мшүк, --, 
   {{0x7aecbecf,0x3f88bed0,0xde60001f,0x00000000}},	//   keat, _biau_, _ማስወገ, --, 
   {{0x3f88bed1,0xdb04002d,0x6d4c02d0,0x00000000}},	//   _ciau_, rsjû, wnba, --, 
   {{0x7aecbed2,0x3f880042,0x7bc0bed3,0x3f1c01e1}},	//   deat, _diau_, álun, _ọrán_, 
   {{0xdd8c117d,0x6218008d,0x8234bed4,0x6d4c0067}},	//   صوف_, _מונק, _جرما, unba, 
   {{0x7aecbed5,0x2908070d,0x3f880421,0x69c09c21}},	//   feat, _rnba_, _fiau_, _लिही, 
   {{0x7aecbed6,0x628401f1,0x6a84bed7,0x3f88bed8}},	//   geat, ľkov, елба, _giau_, 
   {{0x6fc419ec,0x62840232,0xe7380032,0x24500023}},	// [f8a0] _विडं, žkov, үез_, _ዝዕድሚ, 
   {{0xb5fc0122,0x2d90009a,0xec78468b,0x25fc547d}},	//   _vyšl, _iuye_, _нпп_, लिसी_, 
   {{0x7aecbed9,0x2d90beda,0x6144bedb,0x6e24bedc}},	//   beat, _huye_, _hélè, lykb, 
   {{0x2d90136f,0xbbe85533,0x2908208d,0x7aecbedd}},	//   _kuye_, _کریم_, _wnba_, ceat, 
   {{0x2d9003f9,0x00000000,0x00000000,0x00000000}},	//   _juye_, --, --, --, 
   {{0x2d90bede,0x61440129,0x00000000,0x00000000}},	//   _muye_, _mélè, --, --, 
   {{0x2d90bedf,0x00000000,0x00000000,0x00000000}},	//   _luye_, --, --, --, 
   {{0xd374bee0,0x2d90007f,0x64d00073,0xc1a80150}},	//   нчы_, _ouye_, _सावळ, _ﺴﻨﺭﺍ, 
   {{0x3f88bee1,0xf8dc190c,0xe5a401b9,0x85b00345}},	//   _riau_, न्वय, _чизи, _ئیتڵ, 
   {{0x3f88bee2,0x257000d2,0x6b8001f2,0x7aec005a}},	//   _siau_, bâla_, ọghe, zeat, 
   {{0x2d9084b5,0xdb04041e,0x7f581d0f,0x3f880042}},	//   _auye_, rsjú, данс_, _piau_, 
   {{0xe2900491,0x2d90bee3,0xdb040436,0x7aec01c4}},	//   _إذا_, _buye_, ssjú, xeat, 
   {{0x7aecbee4,0x614420ef,0x1600068f,0x3f88067c}},	//   veat, _célè, लियर_, _viau_, 
   {{0x7aecbee5,0xdb04bee6,0x2d9000a2,0xe60c02dd}},	//   weat, lsjø, _duye_, рдi_, 
   {{0x81dc03f4,0x29f00054,0x3f880076,0x00000000}},	//   ডিও_, _aņa_, _tiau_, --, 
   {{0xdb0403d4,0x7bc00024,0xdb2000f2,0x91bc01e1}},	//   nsjø, šluo, دوری, _ìṣe_, 
   {{0x98c4bee7,0x2d9000ca,0xdbcc0139,0x00000000}},	// [f8b0] فغان, _guye_, kıçt, --, 
   {{0x7aecbee8,0x00000000,0x00000000,0x00000000}},	//   seat, --, --, --, 
   {{0x80d82d8f,0xdb040158,0x7aecbee9,0x070800f1}},	//   _माने, ksjø, peat, کيني_, 
   {{0x23640070,0xfd4c0208,0xd3a00131,0x00000000}},	//   _nkoj_, _ngoắ, қлиқ, --, 
   {{0xdb0403cd,0x668001d5,0x69f01075,0x16706ecf}},	//   dsjø, لیفل, _күтт, уқар, 
   {{0xcd980302,0xc9844a77,0x257000d2,0xe4c0beea}},	//   עדות_, _буси, tâla_, айши, 
   {{0x6e24002d,0x258401e1,0x00000000,0x00000000}},	//   zykb, _sílì_, --, --, 
   {{0x42b824a7,0xd77400db,0x00000000,0x00000000}},	//   ىنىڭ_, _سازع, --, --, 
   {{0x6ea0bc82,0xb5fc0306,0xdee00023,0x00000000}},	//   _क्षु, _myšk, ዝንን_, --, 
   {{0x2d900a73,0xd498beeb,0x23640064,0x00000000}},	//   _ruye_, _хра_, _ekoj_, --, 
   {{0x2d90beec,0xc30404d3,0x00000000,0x00000000}},	//   _suye_, _ڕبوو, --, --, 
   {{0x6ab40009,0x00000000,0x00000000,0x00000000}},	//   xayf, --, --, --, 
   {{0xf1d000fb,0xd20001af,0x00000000,0x00000000}},	//   _төйө, _сүпк, --, --, 
   {{0x2d900564,0x6ea006ff,0x80d8041c,0x6ab402d0}},	//   _vuye_, _क्रु, _माये, wayf, 
   {{0x2d90013f,0x6e24002d,0xcb940066,0x00000000}},	//   _wuye_, sykb, اهرک, --, 
   {{0xef2405d1,0x2d90beed,0x2ee401ee,0x20540a7c}},	//   çüde_, _tuye_, _ржиг, _שיקל_, 
   {{0xe9d810f5,0xe8f83f9b,0x2d90004c,0x6ab4007c}},	// [f8c0] ька_, мла_, _uuye_, rayf, 
   {{0x6ab40365,0xdd8c2a77,0x3934009d,0x00000000}},	//   sayf, _گوی_, лэхс, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe5a4beee,0xe5c4beef,0xdd8c021a,0xb8c8bef0}},	//   види, вско, _دوی_, _ग्_, 
   {{0x39100131,0xd5ac01f7,0x00000000,0x00000000}},	//   _گۈلز, قفن_, --, --, 
   {{0x23640267,0x98a00484,0x84700023,0x00000000}},	//   _skoj_, _вире, _ኣቢለን_, --, 
   {{0xdb0400cc,0x00000000,0x00000000,0x00000000}},	//   tsjø, --, --, --, 
   {{0x80a4012d,0x00000000,0x00000000,0x00000000}},	//   चुने, --, --, --, 
   {{0xdb044673,0x256800f7,0xa90801a9,0x77780108}},	//   rsjø, _жаап_, lmоq, _чёрт_, 
   {{0x240800a7,0x660003cd,0xdb04143a,0xf36400db}},	//   _онзи_, mvok, ssjø, ктөн, 
   {{0x25a41c06,0x6600bef1,0x00000000,0x00000000}},	//   lpol_, lvok, --, --, 
   {{0x6458bef2,0x236401e4,0xd2a4010a,0x8af003b9}},	//   _ixti, _ukoj_, _акце_, nnəd, 
   {{0x6600bef3,0x628401a2,0xb5fc0006,0x31e00eac}},	//   nvok, ľkos, _ryšk, বিউশ, 
   {{0xd24c168d,0x62841f98,0x8af00213,0x00000000}},	//   _بنه_, žkos, hnəd, --, 
   {{0xd00c0b36,0xa92400e2,0x8af003e3,0xdbb0004e}},	//   _وله_, idžā, lləy, рабө, 
   {{0x6600bef4,0x93f800d9,0x00000000,0x00000000}},	//   kvok, וללי, --, --, 
   {{0x3eb8bef5,0x27e801f9,0x9f4c0ffb,0xb5fc0308}},	// [f8d0] mast_, _apbn_, _isfà_, _vyšk, 
   {{0x2ca80175,0x00000000,0x00000000,0x00000000}},	//   cbbd_, --, --, --, 
   {{0x7e6cbef6,0x9ba00131,0xc984bef7,0x81e80eac}},	//   _hyap, _خەزى, рути, মটি_, 
   {{0x61340225,0x7e6cbef8,0x8af00213,0x6fc4530e}},	//   _hâld, _kyap, kləy, _विसं, 
   {{0x6134045f,0x6458022e,0x3eb8bef9,0x7afc03ac}},	//   _kâld, _axti, iast_, _iast, 
   {{0x7afcbefa,0x3eb800af,0x657833ec,0x536c02d3}},	//   _hast, hast_, _chth, _ስቅያት_, 
   {{0x7afcbefb,0x3eb83d28,0xd6d807d6,0x3a2822d0}},	//   _kast, kast_, _ота_, lyap_, 
   {{0x3eb8befc,0x78b4004c,0x7e6cbefd,0x373401b9}},	//   jast_, _hezv, _oyap, _ёнаё, 
   {{0x6458befe,0x3eb8beff,0x7e6cbf00,0x3a28bf01}},	//   _exti, dast_, _nyap, nyap_, 
   {{0x3eb800ad,0xada405a2,0x00000000,0x00000000}},	//   east_, һамл, --, --, 
   {{0x7e6cbf02,0x5ea800bd,0x78b4bf03,0x7afcbf04}},	//   _ayap, _কাজে, _mezv, _oast, 
   {{0x6da4bf05,0x3eb8bf06,0x75209235,0x7e6cbf07}},	//   лима, gast_, _holz, _byap, 
   {{0x7e6c0223,0x7520bf08,0xed3401c6,0x7db40022}},	//   _cyap, _kolz, гэвэ, исрц, 
   {{0x7afc367a,0x78b41cbd,0x6ed4033d,0x7e6cbf09}},	//   _aast, _nezv, _भावु, _dyap, 
   {{0x7afcbf0a,0xad2412b7,0x7e6c4005,0x660005b8}},	//   _bast, نىڭى, _eyap, zvok, 
   {{0x66000153,0x25a40076,0x63bc03b2,0x00000000}},	//   yvok, ypol_, ápni, --, 
   {{0x7afcbf0b,0x6134000f,0x29180113,0xc94400c7}},	// [f8e0] _dast, _fâld, tjpa_, адақ, 
   {{0x7afcbf0c,0x2b500ffb,0x78b40205,0x25a4007f}},	//   _east, snyc_, _cezv, vpol_, 
   {{0x78b400a8,0x8af003be,0xae0401ec,0x00000000}},	//   _dezv, zləy, _شوگى, --, 
   {{0x7afc193f,0x25a4bf0d,0x31649e02,0x8af000ac}},	//   _gast, tpol_, holz_, yləy, 
   {{0x7520bf0e,0x16a4006c,0xe4e4063b,0x6578bf0f}},	//   _bolz, увчи_, гійн, _phth, 
   {{0x6600bf10,0x25a4bf11,0x7520bf12,0x5ea8015b}},	//   rvok, rpol_, _colz, _কাছে, 
   {{0x7afcbf13,0x25a4bf14,0x7520036b,0x3eb83619}},	//   _yast, spol_, _dolz, yast_, 
   {{0x7afcbf15,0x6134a556,0x25a40268,0x78b4030a}},	//   _xast, _mâle, ppol_, _zezv, 
   {{0x3eb8bf16,0xe4d4bf17,0x93840220,0x78b405b8}},	//   vast_, _متاب, ысша_, _yezv, 
   {{0x7520bf18,0x3eb80493,0x06bc0eac,0x7e6c01a9}},	//   _golz, wast_, _ইউটি, _ryap, 
   {{0x3eb83d28,0xb5fc0006,0xd5100014,0x8af00213}},	//   tast_, _ryši, _دِلد, sləy, 
   {{0x7bc00e3c,0x7e6cbf19,0x75200165,0x6fc40073}},	//   šluk, _pyap, _zolz, _विरं, 
   {{0x3eb8bf1a,0x7afcbf1b,0x88cc00bd,0x3d946bed}},	//   rast_, _rast, র্যক, ригр, 
   {{0x7e6cbf1c,0x3eb8bf1d,0x3164010a,0x61340356}},	//   _vyap, sast_, colz_, _bâle, 
   {{0x9f68bafa,0x3eb8bf1e,0x8ca41533,0xd00cbf1f}},	//   _приз_, past_, कड़ो, _уф_, 
   {{0x78b41cbd,0x7afc0842,0x61340b21,0x7e6c0124}},	//   _sezv, _qast, _wâld, _tyap, 
   {{0x7afcbf20,0x7e6cbf21,0x78b405b8,0xcd344710}},	// [f8f0] _vast, _uyap, _pezv, _گريب, 
   {{0x7afcbf22,0x3a2803e0,0x00000000,0x00000000}},	//   _wast, ryap_, --, --, 
   {{0x78b4bf23,0xe794bf24,0x3a28bf25,0x1fe000fe}},	//   _vezv, لانک, syap_, যিকস, 
   {{0x7520183d,0x7afcbf26,0x78b405b8,0xdb0405d5}},	//   _solz, _uast, _wezv, nsjü, 
   {{0x7520bf27,0x78b4004c,0x2ab8011a,0x00000000}},	//   _polz, _tezv, _במרא, --, 
   {{0x6fc40d2c,0xd7f84130,0xf50401f4,0x00000000}},	//   _विलं, _пуб_, рзко, --, 
   {{0xa2600798,0x75200247,0x00000000,0x00000000}},	//   çôni, _volz, --, --, 
   {{0x229000d1,0x00000000,0x00000000,0x00000000}},	//   يلىس, --, --, --, 
   {{0x7520bf28,0x514004a9,0x332c0109,0x637c01c7}},	//   _tolz, йдиғ, rkex_, kënf, 
   {{0xc4f84bf3,0xb1440108,0x628400d0,0x8f840075}},	//   _معما_, рнол, ľkop, әқил, 
   {{0xdb04022c,0xafe4036b,0xa4f8031c,0x61340356}},	//   nsjó, шонл, _ྒྲིག_, _bâlb, 
   {{0x61345dae,0x00000000,0x00000000,0x00000000}},	//   _râle, --, --, --, 
   {{0x72040214,0xad6400ae,0x8af006be,0x00000000}},	//   _خوشم, لاسه, hnəc, --, 
   {{0x61340129,0xdb040162,0x03e00051,0x00000000}},	//   _pâle, ksjó, _nước, --, 
   {{0xeb98006c,0x88cc0154,0x6ab4bf29,0x00000000}},	//   тиб_, র্ডক, исах, --, 
   {{0xdf3400cf,0x00000000,0x00000000,0x00000000}},	//   _ۅكۉت_, --, --, --, 
   {{0x3eac035b,0x6134002d,0xb5fc0064,0x2be0000d}},	// [f900] ñete_, _wâle, _kyšu, _पहका, 
   {{0xdb04032e,0x00000000,0x00000000,0x00000000}},	//   fsjó, --, --, --, 
   {{0xdb040436,0x22a40118,0x80d81546,0x00000000}},	//   gsjó, líků_, _मासे, --, 
   {{0x66e4bf2a,0x637ca82b,0xaa48010a,0xf6e4003b}},	//   рода, mëng, _апма_, йцін, 
   {{0x637c006a,0x22a4012c,0xc4482a77,0x443c0175}},	//   lëng, níků_, گیان_, wzv_, 
   {{0x439406b5,0x00000000,0x00000000,0x00000000}},	//   бакс, --, --, --, 
   {{0xc448328a,0x637c006a,0x00000000,0x00000000}},	//   دیان_, nëng, --, --, 
   {{0x6614023a,0x80d805c0,0x6d5800b0,0x00000000}},	//   äyks, _माहे, ōtah, --, 
   {{0x24f4bf2b,0xe7d0012c,0x224000e8,0x637c00c7}},	//   _вчер, दूरप, àkk_, hëng, 
   {{0x637c02d3,0xa2a40709,0x22a4013a,0x00000000}},	//   këng, _ट्र्, díků_, --, 
   {{0x88cc015b,0xa0c000f1,0x64a4014b,0x00000000}},	//   র্থক, ميښو, _баҷа, --, 
   {{0x2284bf2c,0x141400c6,0x63bcbf2d,0x637c0036}},	//   _кулг, _خيمة_, ápnu, dëng, 
   {{0x9754011a,0x9e6400ae,0x00000000,0x00000000}},	//   שיכו_, شاحن, --, --, 
   {{0xd0d002e8,0xdb040036,0x00000000,0x00000000}},	//   _дошъ, mpjé, --, --, 
   {{0xdb68bf2e,0x704401f0,0x00000000,0x00000000}},	//   врал_, _гӯям_, --, --, 
   {{0x9e640d28,0xb0640014,0x417400d1,0x22a4013a}},	//   _پابن, _دپى۪, _ئاچس, bíků_, 
   {{0x61340356,0x637c036e,0x0f7c011a,0x00000000}},	// [f910] _gâlc, mënd, _באהב, --, 
   {{0x637c02d3,0xadd40375,0x7c344130,0x00000000}},	//   lënd, _פותח_, _геох, --, 
   {{0x490401d5,0xb0640108,0x00000000,0x00000000}},	//   تولق, meää, --, --, 
   {{0xdb0409f3,0xdfc40228,0xab60008e,0xb06401f4}},	//   rsjó, _ۉي_, _çüpl, leää, 
   {{0x7bd4bf2f,0xaae4bf30,0xdb04008c,0x06c802bf}},	//   luzu, _اسپو, ssjó, ргій_, 
   {{0x637c02d3,0xe5f0581f,0xd564bf31,0xd8740150}},	//   hënd, سكىد, штеп, _نازب, 
   {{0xf40800f7,0xb34402d3,0x637c0023,0x7bd4bf32}},	//   ايبى_, _ንህግደ, kënd, nuzu, 
   {{0xcc58011a,0xb0640108,0x22880248,0x00000000}},	//   יסוק_, heää, _ẹka_, --, 
   {{0x7bd48a07,0x79840218,0xb1440139,0xb06401f4}},	//   huzu, omhw, йнил, keää, 
   {{0x637c0ea0,0x0fe401a9,0x602806be,0x00000000}},	//   eënd, алоқ_, kəmd, --, 
   {{0x80d82c30,0xc1e801c0,0x637c0694,0xb5fc02f0}},	//   _मारे, гдөж_, fënd, _vyšu, 
   {{0x7bd4bf33,0x602806be,0x00000000,0x00000000}},	//   duzu, dəmd, --, --, 
   {{0x107c0116,0x490802c3,0x00000000,0x00000000}},	//   _ﺭﺍﺩﯨ, _सफलो_, --, --, 
   {{0xdca076c5,0x7bd4bf34,0x61340276,0x00000000}},	//   зари, fuzu, _vâlc, --, 
   {{0xafc4113e,0x7bd4a48c,0x83fc0051,0x9d40013d}},	//   _ايبى, guzu, _hyđr, черд, 
   {{0x61340356,0x637c0036,0x7cfc00b8,0xc60000fe}},	//   _tâlc, rëng, _pårõ, ্হতা_, 
   {{0x28e8bf35,0x00000000,0x00000000,0x00000000}},	// [f920] лдап_, --, --, --, 
   {{0x7bd4bf36,0x602806be,0x00000000,0x00000000}},	//   buzu, bəmd, --, --, 
   {{0x6d4cbf37,0x00000000,0x00000000,0x00000000}},	//   miba, --, --, --, 
   {{0x33e0011f,0xa6842d3c,0x00000000,0x00000000}},	//   dóx_, блед, --, --, 
   {{0x2cb80327,0x80d808f2,0x6a84bf38,0x00000000}},	//   _kepd_, _माले, _ылма, --, 
   {{0x69d466a0,0xe27000f7,0x7c440413,0xd1f00023}},	//   muye, үккө, _útræ, ፍኣት_, 
   {{0x69d40407,0xb060007c,0x00000000,0x00000000}},	//   luye, ääld, --, --, 
   {{0x6d4cbf39,0x779001b9,0xc2980640,0x00000000}},	//   hiba, _قیلا, шких_, --, 
   {{0x6d4cbf3a,0x69d4bf3b,0xdef80572,0x7e980f01}},	//   kiba, nuye, қын_, یندر_, 
   {{0x7bd401b2,0xb5fc0f91,0xdbdc01e1,0x55e000f3}},	//   yuzu, _vyšt, _ṣís, _хофб, 
   {{0x6d4cbf3c,0x160002ab,0x69d4004d,0x8eb00154}},	//   diba, लिअर_, huye, _কাজগ, 
   {{0xe298bf3d,0x69d415d3,0x717805f5,0x65681682}},	//   _сад_, kuye, лбөр_, lofh, 
   {{0x637c044e,0x7bd4bf3e,0x25fc134e,0x6d4cbf3f}},	//   rënd, wuzu, लिटी_, fiba, 
   {{0x61e00117,0x7bd490ee,0x6d4cbf40,0x65680036}},	//   _iqol, tuzu, giba, nofh, 
   {{0xdfa4bf41,0xb0640037,0xd00c01c4,0x00000000}},	//   _احتي, reää, _эф_, --, 
   {{0x7bd4bf42,0x69d40b6f,0xb06402f6,0x6d4c27bb}},	//   ruzu, fuye, seää, aiba, 
   {{0x6d4c9390,0x7bd40516,0x69d4bf43,0xd9980345}},	// [f930] biba, suzu, guye, اخرا_, 
   {{0x6d4cbf44,0x2be009fd,0x61e0009a,0x60d80270}},	//   ciba, _पहचा, _mqol, ngtm, 
   {{0x7bd44b2a,0xf69800d8,0x00000000,0x00000000}},	//   quzu, авеј_, --, --, 
   {{0x69d42935,0x61e001a9,0x9a8461ac,0x71880055}},	//   buye, _oqol, _гугл, _mākṣ, 
   {{0x2cb004f3,0x61e00117,0xceb40375,0x7188002b}},	//   _ändå_, _nqol, ליף_, _lākṣ, 
   {{0xd9180395,0x8af003b9,0x00000000,0x00000000}},	//   _сьм_, nnən, --, --, 
   {{0x61e0009a,0xe3b0066d,0x5ae4025c,0xa8540131}},	//   _aqol, ورٹ_, _སྡོམ, _дерә, 
   {{0x6d4cbf45,0x637c01f5,0x8af003e3,0x80d000eb}},	//   ziba, eënb, hnən, ত্ম্, 
   {{0x6d4c2dab,0x7158010a,0x00000000,0x00000000}},	//   yiba, ирос_, --, --, 
   {{0x9554bf46,0x7bc40161,0x6d4cbf47,0xd3780139}},	//   _اخرا, _ovhu, xiba, _өче_, 
   {{0x3d1cbf48,0x61e0bf49,0x69d40230,0x718800cd}},	//   माने_, _eqol, zuye, _cākṣ, 
   {{0x718800cd,0x00000000,0x00000000,0x00000000}},	//   _dākṣ, --, --, --, 
   {{0x7bc406d6,0x61e000f1,0x3eac120f,0x69d40051}},	//   _avhu, _gqol, ñeta_, xuye, 
   {{0x69d4bf4a,0x2cb80789,0x00000000,0x00000000}},	//   vuye, _qepd_, --, --, 
   {{0x6d4cbf4b,0x69d453ff,0x00000000,0x00000000}},	//   riba, wuye, --, --, 
   {{0xe8181079,0x00000000,0x00000000,0x00000000}},	//   یزات_, --, --, --, 
   {{0x6d4cbf4c,0x6f1400d0,0xed580064,0x00000000}},	// [f940] piba, _inyc, _воп_, --, 
   {{0x69d4bf4d,0x6d4c022e,0x71880055,0x00000000}},	//   ruye, qiba, _yākṣ, --, 
   {{0x69d4a897,0x7bc006ea,0xeb980640,0x6f1401e3}},	//   suye, álut, _њим_, _knyc, 
   {{0x69d45725,0xeab0007b,0xe9d860a7,0x00000000}},	//   puye, _تعد_, _ккм_, --, 
   {{0x69d4004d,0x1af4011a,0xd6ccbf4e,0x00000000}},	//   quye, _ומכל_, ئقه_, --, 
   {{0x3d1c0b7d,0x7ae8010e,0x387400c7,0x14680248}},	//   माये_, _ıeti, ñarõ_, _ṣiṣi_, 
   {{0x6568007c,0x00000000,0x00000000,0x00000000}},	//   rofh, --, --, --, 
   {{0x442004b9,0x6700166d,0x27343256,0x71880882}},	//   ći_, _रोचक_, _بىرس, _rākṣ, 
   {{0x0a480020,0x6d5c0113,0x71880882,0x78c8032e}},	//   _መመሪያ, _ojpa, _sākṣ, _ásvö, 
   {{0x6720005b,0x71880055,0x6fc406b1,0x00000000}},	//   ljoj, _pākṣ, _विखं, --, 
   {{0xa2e4026a,0x67200024,0x7e9801d3,0x28e01d34}},	//   _можд, ojoj, ینگر_, _पानि, 
   {{0x6720bf4f,0x6d5c0113,0x93f80375,0xdb0436d5}},	//   njoj, _ajpa, _כלבי, lsjö, 
   {{0x672000c7,0x004400f1,0x00000000,0x00000000}},	//   ijoj, تیژي_, --, --, 
   {{0x9f4c019f,0x3af401fb,0xe0481a69,0xdb04bf50}},	//   _mpfé_, _ấp_, _پشته_, nsjö, 
   {{0x4fb000c6,0x4c9401d5,0x403400db,0xc0f00092}},	//   _قصير, дирс, _хейс, ፍናል_, 
   {{0x6d5c004e,0x67200b45,0x3f980115,0xda780166}},	//   _ejpa, jjoj, ŭrus_, аяз_, 
   {{0x7f4cbf51,0x200c02d2,0xb9340120,0xdb04007c}},	// [f950] _imaq, _hrfi_, пеај, ksjö, 
   {{0x3f9cbf52,0x7cd82377,0x213c0051,0xd67c01ec}},	//   _kuvu_, _умор_, nhth_, _ﺩﻭﻻﺭ_, 
   {{0xc7c4005b,0xdb04007c,0x671407af,0x00000000}},	//   дсчи, dsjö, णांक_, --, 
   {{0x672002d3,0xb78802d9,0x7f4c0327,0x8af003e3}},	//   gjoj, сәге_, _jmaq, nnəl, 
   {{0x3f9cb79c,0x6d5c02d0,0x42980092,0xdb0402d2}},	//   _luvu_, _yjpa, _መሳካት_, fsjö, 
   {{0x7d04bf53,0x8af00213,0x67200f12,0xdb04007c}},	//   _jahs, hnəl, ajoj, gsjö, 
   {{0x7d04bf54,0xc7c407d6,0x7f4c014b,0x799c004c}},	//   _mahs, _ости, _omaq, _husw, 
   {{0x799c090c,0x799400ca,0xdce415b2,0xd68402e8}},	//   _kusw, _hizw, dojč, _дузп, 
   {{0x79942dab,0x200cbf55,0x799c014f,0x6f140076}},	//   _kizw, _arfi_, _jusw, _rnyc, 
   {{0x799cbf56,0x7f4c0928,0xd584168d,0x7d04a30b}},	//   _musw, _amaq, _بێته_, _nahs, 
   {{0x799cbf57,0x3f9c0a73,0x79944861,0x78a4bf58}},	//   _lusw, _cuvu_, _mizw, ichv, 
   {{0x799c37b6,0x79946ae5,0x3f9c0036,0xd5dc166d}},	//   _ousw, _lizw, _duvu_, _नमाज, 
   {{0x7d04bf59,0xe1ec05f5,0x799c0214,0xe0cc0c69}},	//   _bahs, _яг_, _nusw, _пв_, 
   {{0x16f80489,0x7f4c1cdf,0x799401f0,0x200c01fa}},	//   _ནིའམ_, _emaq, _nizw, _frfi_, 
   {{0x799cbf5a,0x3f9c00ef,0xfbd0009f,0x67200022}},	//   _ausw, _guvu_, َتِ_, yjoj, 
   {{0x799cbf5b,0x98a000d7,0x00000000,0x00000000}},	//   _busw, _dojč_, --, --, 
   {{0x7994bf5c,0xbca405d9,0x7d04bf5d,0x3f9c0064}},	// [f960] _bizw, _ڪمپي, _fahs, _zuvu_, 
   {{0x799c00ca,0x3d1c00a5,0x6d5c02d1,0x3e84002b}},	//   _dusw, माणे_, _ujpa, _dūtī_, 
   {{0x7994033b,0x28e0145f,0xdc98011a,0xdb04007c}},	//   _dizw, _पाठि, _לסיכ, vsjö, 
   {{0xe618bf5e,0x799c0007,0x637c0023,0x847c0023}},	//   йде_, _fusw, këna, _ብሕማቕ_, 
   {{0x799c0796,0x672002f6,0x7d04bf5f,0x6b9c0455}},	//   _gusw, rjoj, _yahs, _hupg, 
   {{0x994c36b5,0x79940327,0xb5fc02fb,0x6b9c022e}},	//   müş_, _gizw, _vyšp, _kupg, 
   {{0x8af00213,0xdb0401e6,0x994cbf60,0x2d88bf61}},	//   ynəl, rsjö, lüş_, imbe_, 
   {{0xdce40bb8,0x2d88006a,0x7994ab94,0x3f9c01c8}},	//   vojč, hmbe_, _zizw, _ruvu_, 
   {{0x2574bf62,0x994c0259,0x79947276,0x3f9cbf63}},	//   _فهرس, nüş_, _yizw, _suvu_, 
   {{0x92602be7,0x6b9c0c8c,0xbfa8084c,0x00000000}},	//   رگنم, _oupg, оӂие_, --, 
   {{0x7d040020,0x38200023,0x00000000,0x00000000}},	//   _rahs, _ተዋሳእ, --, --, 
   {{0x7d04bf64,0x3f9c0481,0x98780375,0xdce479eb}},	//   _sahs, _vuvu_, מריק, rojč, 
   {{0x7d04089c,0x0e34034b,0xdb1c03b2,0x00000000}},	//   _pahs, еняю, ávík, --, 
   {{0x799cbf65,0x5ba4bf66,0x3f9cbf67,0x3e8400ef}},	//   _rusw, зраз, _tuvu_, _rūtī_, 
   {{0x79947837,0x7d04bf68,0x63b800b5,0x799c4d89}},	//   _rizw, _vahs, _jwtn, _susw, 
   {{0x7d04bf69,0x3e8400b0,0x799c014f,0x2d8800e4}},	//   _wahs, _pūtī_, _pusw, ambe_, 
   {{0x7d04bf6a,0x3a745950,0x799c0477,0x3ea8bec7}},	// [f970] _tahs, флар, _qusw, _ifat_, 
   {{0x799cbf6b,0x28e000dc,0x7d0400d8,0x41d4012c}},	//   _vusw, _पाणि, _uahs, _दिनस, 
   {{0x78a4010a,0x799c014f,0x7f5c127b,0x8af003b9}},	//   rchv, _wusw, onsq, fiəd, 
   {{0x79940223,0x799c0083,0x78a4bf6c,0x15f807f7}},	//   _wizw, _tusw, schv, _एनआर_, 
   {{0x7aecbf6d,0xc1780006,0x79940810,0xd060013f}},	//   mfat, klė_, _tizw, _ɑsɑb, 
   {{0x7aecbf6e,0x80d813f7,0x6b9c0455,0x3b08016d}},	//   lfat, _मागे, _yupg, ldaq_, 
   {{0xc4c404d3,0x7aec0421,0x3ea801d5,0x62840306}},	//   رتوو, ofat, _ofat_, ýkon, 
   {{0x97000075,0x7aecbf6f,0x3b08bf70,0x637c036e}},	//   _سېتى, nfat, ndaq_, tëna, 
   {{0x7aecbf71,0xb9e402d3,0x45d42975,0x42540276}},	//   ifat, _ካኣ_, _потс, етэт, 
   {{0x3ea8102c,0xefc801c0,0x7aec020c,0x7f5c003a}},	//   _afat_, олол_, hfat, ensq, 
   {{0x60280213,0x92640214,0xb4b80b8f,0x2d880455}},	//   təma, _کدام, चरी_, vmbe_, 
   {{0x3b080842,0x994c47af,0x04580736,0x7bd40210}},	//   jdaq_, yüş_, _عجلت_, drzu, 
   {{0x7bd402c1,0x3b08016d,0x7aec6460,0x999c010b}},	//   erzu, ddaq_, dfat, _çuň_, 
   {{0x7aecbf72,0x2d8838ed,0xeb98bf73,0x994c0790}},	//   efat, umbe_, жив_, vüş_, 
   {{0xdca0006c,0x7aec22a9,0x320c2689,0xcd781954}},	//   таси, ffat, lvey_, _ራእይና_, 
   {{0xb0dc0c2e,0x7aec4032,0x637c04e6,0x3b080455}},	//   _माँग, gfat, hënn, gdaq_, 
   {{0x637c0a40,0x320c0afa,0x2d880477,0x78a80bb9}},	// [f980] kënn, nvey_, pmbe_, _şeva, 
   {{0x994c4a4a,0x7aecbf74,0x3b08014f,0xac740ee8}},	//   rüş_, afat, adaq_, _يادش, 
   {{0xdba01884,0x9d180bd9,0xab280fc0,0x3b08016d}},	//   _ақсү, _וויט, _дона_, bdaq_, 
   {{0xd6cc10fe,0x3b080477,0x00000000,0x00000000}},	//   لقم_, cdaq_, --, --, 
   {{0xb0dc3323,0x3e841e0d,0x637c04e6,0x04f402e8}},	//   _मांग, _tūtū_, fënn, езлю, 
   {{0x320c0fac,0xbbe80214,0x225008a5,0x00000000}},	//   dvey_, _بریم_, _þyki_, --, 
   {{0xe738bf75,0xdce400e2,0x00000000,0x00000000}},	//   _дев_, nojā, --, --, 
   {{0xd374bf76,0x7ae80694,0xc1b8bf77,0x5b3800df}},	//   мчы_, _ñett, плих_, ַגיק, 
   {{0x64a42ba5,0xd5e0bf78,0x69d42165,0xa2c80b7c}},	//   _жаза, _ижти, nrye, सृष्, 
   {{0x3ea80276,0xc1780024,0x00000000,0x00000000}},	//   _sfat_, ulė_, --, --, 
   {{0xd36cbf79,0x7aecbf7a,0x715002d3,0xc1780153}},	//   _ач_, yfat, _ንእሽቶ, rlė_, 
   {{0x69d4bf7b,0xc1780024,0x7f5c0036,0xdce400de}},	//   krye, slė_, unsq, dojā, 
   {{0x9264b159,0x3b080978,0xc1780064,0x00000000}},	//   _орша_, vdaq_, plė_, --, 
   {{0x6280009a,0x3b080455,0x929000c0,0x00000000}},	//   _izoo, wdaq_, _раіц, --, 
   {{0x8aac063f,0x3b08016d,0xd0f4011a,0xdce40a88}},	//   _ọgịg, tdaq_, _חמות_, gojā, 
   {{0x7aec01ee,0x6ab4017a,0x69d40240,0x7c840116}},	//   ufat, gbyf, frye, дуғе, 
   {{0x7aecbf7c,0x25fc7382,0x3914bf7d,0x3b08016d}},	// [f990] rfat, _शैली_, нмар, rdaq_, 
   {{0x3b08bf7e,0x98a0005f,0xdce400e2,0x6f1800e2}},	//   sdaq_, _bojā_, bojā, ētce, 
   {{0x7a3403b2,0x3b08016d,0x00000000,0x00000000}},	//   _býtú, pdaq_, --, --, 
   {{0x637c0a40,0x98bc050e,0x62800083,0x7aec208d}},	//   wënn, ırın_, _ozoo, qfat, 
   {{0x69f00116,0x07080f54,0xe7941dd8,0x00000000}},	//   _йүтт, بيني_, رامک, --, 
   {{0xb0dc05d7,0x06080006,0xf3e41d5b,0xb4b807b7}},	//   _माइग, ьнік_, ежко, चरे_, 
   {{0x36d48fad,0xa3dc00dc,0x637c0221,0x644c02f0}},	//   _повр, _तमः_, rënn, _žbir, 
   {{0x637c01c7,0x320c00ad,0x42b82d40,0xc25400e5}},	//   sënn, tvey_, ونىڭ_, ھکنڈ, 
   {{0x59a402ab,0xdbd40108,0xe1f40166,0x00000000}},	//   _कंफर, _hääv, егы_, --, 
   {{0x62800161,0x70d80490,0x320cbf7f,0xf1f401c6}},	//   _dzoo, ढलेल, rvey_, _үзжэ, 
   {{0xdbd41059,0x62801418,0xdfe401c0,0x00000000}},	//   _jääv, _ezoo, ндэд_, --, 
   {{0x69d40022,0x00000000,0x00000000,0x00000000}},	//   yrye, --, --, --, 
   {{0x31340f64,0x3e840024,0x5ea40451,0xdbd401f4}},	//   _педр, jūtį_, رگيٽ_, _lääv, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x602803b9,0x00000000,0x00000000,0x00000000}},	//   nəml, --, --, --, 
   {{0x28e005ba,0x69d41529,0x39500219,0xa908022e}},	//   _पाहि, trye, _amzs_, nlоv, 
   {{0xe9d8bf80,0x6ab42f48,0xed5802e8,0x00000000}},	// [f9a0] яка_, rbyf, _нои_, --, 
   {{0xf40401fb,0x69d43d7e,0x35c8033f,0x6ab401bf}},	//   _đãng_, rrye, _रिज़, sbyf, 
   {{0x3d1c0490,0x69d40ea0,0x00000000,0x00000000}},	//   मारे_, srye, --, --, 
   {{0x69d40585,0x5e540ec9,0x16a440c4,0x28e0041c}},	//   prye, _آلیس_, евци_, _पावि, 
   {{0xdd8c6b5d,0x2d98bf81,0xe5f00014,0x00000000}},	//   _خوی_, _kipe_, اقتھ, --, 
   {{0x2d98bf82,0x963002d5,0x2ebcbf83,0x00000000}},	//   _jipe_, ыніц, ्णुत, --, 
   {{0x29080083,0x18644109,0x00000000,0x00000000}},	//   _iaba_, _зари_, --, --, 
   {{0x2908bf84,0x2d9804a7,0x68fc00a2,0x00000000}},	//   _haba_, _lipe_, lepd, --, 
   {{0x29082f6e,0x6498bf85,0x26c40270,0x2d98035b}},	//   _kaba_, _етер_, maoo_, _oipe_, 
   {{0x2908bf86,0x6600bf87,0x2d98bf88,0x26c40418}},	//   _jaba_, mwok, _nipe_, laoo_, 
   {{0x6600bf89,0x25a406be,0x00000000,0x00000000}},	//   lwok, lqol_, --, --, 
   {{0x2d9803c1,0x6134013c,0x55200022,0x7c3402f0}},	//   _aipe_, _mâli, _аҟәҕ, vyzr, 
   {{0x2d980477,0xd36c46bc,0x3d1c00bc,0x602803e3}},	//   _bipe_, _اهن_, माले_, məmm, 
   {{0x2d98bf8a,0x64440213,0x68fc00a2,0x59a401f9}},	//   _cipe_, _əkin, jepd, _कंबर, 
   {{0x2d98bf8b,0x26c40093,0x66000099,0x68fc010e}},	//   _dipe_, kaoo_, hwok, depd, 
   {{0x2d98bf8c,0x6600bf8d,0x29083ede,0xbf100131}},	//   _eipe_, kwok, _aaba_, _түмә, 
   {{0x2908bf8e,0x2d98bf8f,0xd060013f,0x26c40009}},	// [f9b0] _baba_, _fipe_, ɑsɑf, daoo_, 
   {{0x3eb809f0,0x9ba004a9,0x2908bf90,0x602800ac}},	//   lbst_, _مەسى, _caba_, həmm, 
   {{0xb908bf91,0x3f88bf92,0x2908bf93,0x28e03d1d}},	//   _या_, _khau_, _daba_, _पारि, 
   {{0x29080184,0x87d40a11,0x36d43b9e,0x26c4058a}},	//   _eaba_, اغلا, тодр, gaoo_, 
   {{0x2908bf94,0x3eb803fa,0x61340311,0x66000083}},	//   _faba_, ibst_, _tâlh, gwok, 
   {{0x2908bf95,0x3f880218,0xe5a05026,0x33f401b9}},	//   _gaba_, _lhau_, шиши, вчис, 
   {{0x3ce844ab,0xd75400db,0x00000000,0x00000000}},	//   _जाने_, _كئرب, --, --, 
   {{0x3f88bf96,0x660001aa,0x2908bf97,0x8c1c04ae}},	//   _nhau_, bwok, _zaba_, לווי, 
   {{0xd498bf98,0xb5940124,0xa92400e2,0xf8c4000d}},	//   _ере_, _аиаш, bežā, _लजाय, 
   {{0x3f881243,0x2908bf99,0x3eb8002f,0x00000000}},	//   _ahau_, _xaba_, ebst_, --, 
   {{0x2d98bf9a,0x3f882de1,0x85440276,0x60280213}},	//   _ripe_, _bhau_, _сэте, qəml, 
   {{0x2d98bf9b,0x32545822,0xada49a58,0x3f88bf9c}},	//   _sipe_, _ивер, камл, _chau_, 
   {{0x3f880190,0x2d98bf9d,0x00000000,0x00000000}},	//   _dhau_, _pipe_, --, --, 
   {{0x3f880374,0xde00399f,0x6e9457be,0x00000000}},	//   _ehau_, јпри, _یلغا, --, 
   {{0x2908bf9e,0x3930001f,0x2d980455,0x26c40009}},	//   _raba_, _በማያያ, _vipe_, yaoo_, 
   {{0x2908bf9f,0xf8b801fb,0x2d98bfa0,0xa51c00dc}},	//   _saba_, _đũa_, _wipe_, _यच्च_, 
   {{0x2d98bfa1,0x2908bfa2,0x26c40093,0x00000000}},	// [f9c0] _tipe_, _paba_, vaoo_, --, 
   {{0x3ce80bb2,0x2908bfa3,0x637c0023,0x61340129}},	//   _जाये_, _qaba_, gënj, _pâli, 
   {{0x37a8005e,0x2908007d,0xeab801c0,0x26c40093}},	//   етін_, _vaba_, _ойн_, taoo_, 
   {{0x2908bfa4,0x68fc0175,0x6600bfa5,0x25a4022e}},	//   _waba_, sepd, twok, tqol_, 
   {{0x2908bfa6,0xe51c0ebb,0x3ce8000d,0x5b540a7c}},	//   _taba_, पालि_, _जामे_, _ייטב_, 
   {{0x6600bfa7,0x7c6402dd,0x95b4035b,0x01cc01ec}},	//   rwok, _جاۋل, трцә, _ﻓﺈﻨﻨ, 
   {{0x25a401a9,0x00000000,0x00000000,0x00000000}},	//   sqol_, --, --, --, 
   {{0xa1a801b9,0x00000000,0x00000000,0x00000000}},	//   мтоз_, --, --, --, 
   {{0xe5a4bfa8,0x25a4036b,0xe4c40bd6,0xf664013d}},	//   _ризи, qqol_, _айзи, _бетү, 
   {{0xb62401ec,0x3f880200,0x2b400171,0xe5042161}},	//   _ﯨﺲ_, _shau_, _llkc_, _جبري, 
   {{0x3f880457,0x41d42368,0x05940150,0xe20802d2}},	//   _phau_, _दिवस, _ﺗﻮﺳﭙ, fróð_, 
   {{0x3f880218,0x3eb80e78,0x3eac05c7,0x644403e3}},	//   _qhau_, ubst_, ùet_, _əkil, 
   {{0x3f881682,0x3eb803fa,0xfcc41f0e,0xb2fc031c}},	//   _vhau_, rbst_, ләнм, _དྲིང_, 
   {{0x3f8802b1,0x98a00153,0xdce4012d,0xc0e00092}},	//   _whau_, _koją_, koją, ናትም_, 
   {{0x3f88bfa9,0x9f683529,0x246c0023,0x8fa0009b}},	//   _thau_, _ориз_, _ድሕሪት_, _каје, 
   {{0x98a0033f,0x3cec00bc,0xc3340a7c,0xc5e800eb}},	//   _moją_, řev_, נוּ_, _গননা_, 
   {{0xdfd002dd,0x98c400d8,0xb6a401d5,0x00000000}},	// [f9d0] _соқы, всел, қилл, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x637c02d3,0x3c5812cf,0x23640820,0x7a3c007c}},	//   rënj, _чинэ_, _ojoj_, fåtö, 
   {{0x236404b9,0x8dc401d9,0x644800e2,0x95b000c7}},	//   _njoj_, _حقیٖ, dzfi, аркә, 
   {{0x5fc00490,0xdb04007c,0x246c0240,0x00000000}},	//   वीतल, rpjä, _ድሕረት_, --, 
   {{0x236401a6,0x37c40166,0x98a0012d,0xdb04007c}},	//   _ajoj_, _бәдб, _boją_, spjä, 
   {{0xc3c815eb,0x739800f3,0x5ed80154,0x65900063}},	//   نظيم_, нтис_, য্যে, љају, 
   {{0x398c02d3,0x00000000,0x00000000,0x00000000}},	//   ቓወምቲ_, --, --, --, 
   {{0x514004a9,0x00000000,0x00000000,0x00000000}},	//   идиғ, --, --, --, 
   {{0x2364010f,0x3124bfaa,0x00000000,0x00000000}},	//   _ejoj_, удог, --, --, 
   {{0xb5fc0024,0xe8141116,0x00000000,0x00000000}},	//   _ryšy, णिया_, --, --, 
   {{0x8af000ac,0x72040014,0x41c40050,0x00000000}},	//   nnət, _موصم, _چٲنِ, --, 
   {{0xd2002dfc,0x8af003b9,0x00000000,0x00000000}},	//   _түпк, fiən, --, --, 
   {{0xe81406e3,0x3ce80490,0xafe40801,0x637c01f5}},	//   णिमा_, _जाणे_, _бокл, eënh, 
   {{0xab180c98,0x09cc0490,0x00000000,0x00000000}},	//   нцах_, ाळ्य, --, --, 
   {{0xdb040b21,0x2ee40c9e,0x95000327,0xeb341884}},	//   mpjû, _сжиг, _ཚིའི_, دىرد, 
   {{0x6a8405f5,0x6134054e,0x637c0036,0x00000000}},	// [f9e0] улаа, _vâlv, wënk, --, 
   {{0x30d40183,0xe5a408ca,0x8af003e3,0x321801f4}},	//   ত্ৰস, ҳиди, ciən, äsyy_, 
   {{0x3ce83a19,0xe738bfab,0xeb980114,0x00000000}},	//   _जाते_, неж_, _пио_, --, 
   {{0xe5a4785a,0xe5c4005b,0xe664009d,0x41d419cc}},	//   гиди, гско, лтло, _दिलस, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x98a0bfac,0x64481196,0x56900114,0x00000000}},	//   _гире, tzfi, љашт, --, 
   {{0xec3400c8,0x02c81086,0xc448158b,0x00000000}},	//   טאַר_, вқеи_, خیان_, --, 
   {{0x64482ad7,0x8334014b,0x9c8401ef,0x00000000}},	//   rzfi, рних, _hučí, --, 
   {{0xe61800ee,0x602800ac,0xdef800c7,0x00000000}},	//   _яда_, məmi, ҭым_, --, 
   {{0x602800ac,0x41541422,0x9ac0031c,0x59a406e3}},	//   ləmi, рвос, ċċit, _कंसर, 
   {{0x637c044e,0xdb20025a,0x24a40882,0xd8d8008f}},	//   hëni, êrëb, ātmā_, עקטר, 
   {{0x69d800b0,0x2364bfad,0x04c83090,0x42040014}},	//   _āten, _ujoj_, _سوچي_, _نستہ, 
   {{0x3ce8007d,0x2f180139,0x0e440166,0x8af00213}},	//   _जादे_, _sügä_, бэрм, hnəs, 
   {{0x009411ca,0x5c0400c0,0x602803b9,0x8af006be}},	//   _килэ, ляба, həmi, knəs, 
   {{0xbc9403b7,0x602803be,0x637c05e4,0x00000000}},	//   равј, kəmi, eëni, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x65780163,0xb9540801,0x637c0200,0x602803e3}},	// [f9f0] _okth, аващ, gëni, dəmi, 
   {{0x2f180139,0x17f8007b,0xbb54114f,0x57a401c4}},	//   _tügä_, فرصة_, _چندب, гшда, 
   {{0xf6b42674,0xc984b3bc,0x602803e3,0xbf4c002b}},	//   لماج, сути, fəmi, _śeṣe_, 
   {{0xb7881cd1,0x87d8bfae,0x637c0200,0x00000000}},	//   тәге_, ابلس_, bëni, --, 
   {{0xf62401c0,0xceb40a1e,0x9c8402f0,0xd5b80107}},	//   рдло, ציס_, _fučí, хсе_, 
   {{0xdfc4bfaf,0xf8a807f7,0x25b4007b,0x00000000}},	//   _وي_, _औलिय, جهود_, --, 
   {{0x602803b9,0xdec41954,0x00000000,0x00000000}},	//   bəmi, ጽዕኖ_, --, --, 
   {{0x7e6c0784,0xd76000f2,0x602806be,0x00000000}},	//   _oxap, _انری, cəmi, --, 
   {{0xb144bfb0,0xd1f00020,0x00000000,0x00000000}},	//   инил, ግባቡ_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb4d00490,0x7e6c0200,0x00000000,0x00000000}},	//   वणी_, _axap, --, --, 
   {{0x6134045f,0x2f54bfb1,0x8234bfb2,0xb2740798}},	//   _sâlt, ртос, _گرما, _клеш, 
   {{0xada4bfb3,0x6da4bfb4,0xdce438a5,0x637c0200}},	//   рагл, рига, loję, xëni, 
   {{0x8234304e,0x2d9cbfb5,0x3d1c4fed,0x637c036e}},	//   _درما, öte_, मागे_, vëni, 
   {{0x307804ac,0x7e6c067c,0xafe492fd,0x9c8402f0}},	//   _באַנ, _exap, _тойл, _ručí, 
   {{0x6134000f,0x6b4803b2,0xb0640254,0x637c0200}},	//   _wâlt, _mýgg, afää, tëni, 
   {{0x6b480162,0x2d888087,0x6cd84627,0x00000000}},	// [fa00] _lýgg, _ийип_, _ифнс_, --, 
   {{0x637c0240,0xdce4bfb6,0x00000000,0x00000000}},	//   rëni, koję, --, --, 
   {{0x6b485573,0x602800ac,0xa804bfb7,0xabac00d1}},	//   _nýgg, təmi, рзел, _ﻳﺎﻣﺎ, 
   {{0x28e02122,0x332c0003,0x23a80051,0xdce400c0}},	//   _पाकि, jjex_, _rùj_, doję, 
   {{0x637c036e,0xd1f0069d,0x59b0009d,0x00000000}},	//   qëni, ግባብ_, _дөхс, --, 
   {{0xa96808e0,0x6b4803b2,0xa8880fca,0x00000000}},	//   _рига_, _býgg, _айга_, --, 
   {{0x22a4013e,0x84c40116,0xdce40064,0x00000000}},	//   қуқҳ, _һәйд, goję, --, 
   {{0x186401b9,0x00000000,0x00000000,0x00000000}},	//   _таси_, --, --, --, 
   {{0x2164bfb8,0x42a400fb,0x78a80139,0xed640240}},	//   итог, _һулғ, _şevi, ተማቕር_, 
   {{0x3fe000cc,0x98a0012d,0x6578bfb9,0xa2c800cd}},	//   _বনৌষ, _boję_, _ukth, सृज्, 
   {{0xdce4012d,0x213c0200,0x8af006be,0x4254085b}},	//   coję, rkth_, hnəq, شنگر, 
   {{0x398c08a5,0x00000000,0x00000000,0x00000000}},	//   _kósý_, --, --, --, 
   {{0x443c0030,0x3f8400e2,0x0dc800c7,0xd24c00db}},	//   lyv_, ēlu_, иури_, _ۉنۅ_, 
   {{0x1fa43893,0x00000000,0x00000000,0x00000000}},	//   _криг, --, --, --, 
   {{0x443c00dd,0x7f94074d,0x00000000,0x00000000}},	//   nyv_, _лакх, --, --, 
   {{0x4fb0bfba,0x7e6c05f5,0x3ce810e3,0xb06425c6}},	//   _بصور, _txap, _जावे_, sfää, 
   {{0x7f5cbfbb,0x443c0789,0x00000000,0x00000000}},	// [fa10] misq, hyv_, --, --, 
   {{0x7f5cbfbc,0x443c02f0,0x00000000,0x00000000}},	//   lisq, kyv_, --, --, 
   {{0x46b402e3,0x6b4803b2,0x48a800db,0x5c04010a}},	//   _ịtọ_, _býgd, ртум_, _тяпа, 
   {{0x7f5cbfbd,0x443c0076,0xe7940bce,0x482400d1}},	//   nisq, dyv_, مانک, تىمق, 
   {{0x20180010,0x6b480174,0x00000000,0x00000000}},	//   _špil_, _sýgg, --, --, 
   {{0xb4d00157,0x7f5cbfbe,0x8c5400db,0xdce40153}},	//   वणे_, hisq, _دئۋا, toję, 
   {{0x7f5c0bf1,0x332c0076,0x00000000,0x00000000}},	//   kisq, tjex_, --, --, 
   {{0xa56012b7,0x7f5c0309,0x00000000,0x00000000}},	//   يگەن, jisq, --, --, 
   {{0x7f5cbfbf,0x00000000,0x00000000,0x00000000}},	//   disq, --, --, --, 
   {{0x637c0200,0xafe400db,0xb144022e,0x00000000}},	//   dënu, боол, снол, --, 
   {{0x9324bfc0,0x39400327,0x00000000,0x00000000}},	//   _پران, ikhs_, --, --, 
   {{0x7f5cbfc1,0x644c0327,0x00000000,0x00000000}},	//   gisq, _żbig, --, --, 
   {{0xe28cbfc2,0xb638037e,0x437001ec,0xb17c00d0}},	//   _ха_, _ｘｓ_, _تۇير, vrťf, 
   {{0x4bc401e0,0xd7a401f9,0x00000000,0x00000000}},	//   ҙөүг, गदाच, --, --, 
   {{0x7f5cbfc3,0x3ce800c5,0x659800df,0x00000000}},	//   bisq, _जारे_, טישק, --, 
   {{0xaec426c7,0x7f5cbfc4,0x95240327,0x2848010b}},	//   _убил, cisq, _ཡོའི_, ңзап_, 
   {{0xe8f84bbe,0x6ebc06ff,0x6b4809e8,0x637c0200}},	// [fa20] лла_, _व्यु, _nýge, cënu, 
   {{0x637c002e,0x1e54011a,0xc1e000d1,0xed0400f1}},	//   lënt, _לשפר_, _ﺋﻪﺯﺍ, _اودپ, 
   {{0x3eacbfc5,0xac0801d5,0xb864009a,0x18a0011c}},	//   žete_, _ёнма_, يامو, чахм, 
   {{0x6f0408ad,0xa6c8bfc6,0x66e40aac,0xab284130}},	//   nekc, улда_, сода, _сома_, 
   {{0x3d1c0490,0x45d4009d,0x00000000,0x00000000}},	//   माचे_, цолс, --, --, 
   {{0x443cbfc7,0x28e0bfc8,0x6b94005c,0x78a803e0}},	//   tyv_, _पाटि, lmyg, _şevv, 
   {{0x68ec010a,0x6b48010e,0xd940010b,0x7f5c0113}},	//   _icbd, _eýge, _эери, yisq, 
   {{0xe7180451,0xb92402e3,0x7f5c0393,0x637c0de2}},	//   _حيرت_, kepụ_, xisq, jënt, 
   {{0x443cbfc9,0x3ce800af,0xc0ec001f,0x7f5cbfca}},	//   syv_, _जाले_, _ጀመር_, visq, 
   {{0x637c01f5,0x7f5c0113,0x6b94015d,0xf1500133}},	//   eënt, wisq, hmyg, وێند, 
   {{0x7f5cbfcb,0x32080327,0x00000000,0x00000000}},	//   tisq, _ཀརྨར_, --, --, 
   {{0x923800bc,0x637c0de2,0x00000000,0x00000000}},	//   ířát, gënt, --, --, 
   {{0x7f5cbfcc,0x6b940142,0xe28401d5,0x8d940150}},	//   risq, dmyg, _улди, _ﺜﺎﺒﺕ_, 
   {{0x63a0bfcd,0x6280198f,0x4db000fe,0x7f5cbfce}},	//   _hion, _iyoo, জীভূ, sisq, 
   {{0x63a0bfcf,0x69c4172c,0x7f5c02d1,0xdb681f39}},	//   _kion, _awke, pisq, грал_, 
   {{0x63a0bfd0,0xbab8352d,0x62800337,0x7e4801ed}},	//   _jion, ргах_, _kyoo, _نسخہ_, 
   {{0x63a0bfd1,0x200c01a6,0xad240451,0xd91801c0}},	// [fa30] _mion, _hsfi_, _ڀرپو, льж_, 
   {{0x628001f4,0x38c8179e,0x00000000,0x00000000}},	//   _myoo, شائی_, --, --, 
   {{0x62800083,0xd7640202,0x645c0030,0x63a0005a}},	//   _lyoo, مەسى_, úpil, _oion, 
   {{0x63a01aac,0x628001f2,0x50180375,0x68ec0175}},	//   _nion, _oyoo, טובו, _ecbd, 
   {{0x62800457,0xd1f00020,0x7afc02d0,0xd58403e6}},	//   _nyoo, ግባት_, _ibst, مێره_, 
   {{0x63a0bfd2,0x33d8023a,0x637c0036,0x97a40a4a}},	//   _aion, афию_, këns, _грал, 
   {{0xb9e42295,0x63a0bfd3,0x6280bfd4,0xc7c400a8}},	//   _ይህ_, _bion, _ayoo, _нсти, 
   {{0x63a0bfd5,0x65ac06d6,0x628004ba,0xb92401f2}},	//   _cion, ṱhav, _byoo, yepụ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x63a0bfd6,0x7afc0175,0x637c01c7,0x85880108}},	//   _eion, _lbst, fëns, _лёха_, 
   {{0x63a0bfd7,0x62801418,0x7afcbfd8,0x637c01c7}},	//   _fion, _eyoo, _obst, gëns, 
   {{0x63a0bfd9,0xc2c40592,0x00000000,0x00000000}},	//   _gion, _فيمي, --, --, 
   {{0xe0ccbfda,0x628004ba,0xe1ec082d,0xdcfc0139}},	//   _ов_, _gyoo, _юг_, _atqı, 
   {{0x63a0bfdb,0x6f040115,0x7afcbfdc,0x200cbfdd}},	//   _zion, sekc, _abst, ämiä_, 
   {{0xdca00b7e,0x7afc0175,0x69c405c7,0x6b582fde}},	//   дари, _bbst, _swke, ашар_, 
   {{0x63a0bfde,0xbf640137,0xee3800f3,0x00000000}},	//   _xion, _ىديو, _вни_, --, 
   {{0x62800457,0xe8c82472,0x6b940042,0x00000000}},	// [fa40] _xyoo, игал_, rmyg, --, 
   {{0x7afc02d0,0x1e801de6,0x00000000,0x00000000}},	//   _ebst, _юлым, --, --, 
   {{0xb17c00d0,0x00000000,0x00000000,0x00000000}},	//   huťo, --, --, --, 
   {{0x20180427,0xa6842083,0x645c00d7,0x00000000}},	//   _špik_, олед, úpim, --, 
   {{0x63a0bfdf,0x00000000,0x00000000,0x00000000}},	//   _rion, --, --, --, 
   {{0x63a0bfe0,0x6d4c3ba0,0x69d802b1,0x628000b5}},	//   _sion, nhba, _āteh, _ryoo, 
   {{0x1864bfe1,0x6d4c0007,0x281400db,0x60c80f85}},	//   _дари_, ihba, _بوزس, _refm, 
   {{0x28280023,0xf8b80051,0xdc9800d9,0x00000000}},	//   _ሰሚናራ, _đũi_, סיקל, --, 
   {{0x63a000b2,0x6d4c05b1,0x637c0221,0x00000000}},	//   _vion, khba, wëns, --, 
   {{0x321c0cfd,0x628001f7,0x93c80050,0x63a00254}},	//   _drwy_, _vyoo, _چانہ_, _wion, 
   {{0x63a0bfe2,0x6d4c0597,0x60c801a8,0xaaa81428}},	//   _tion, dhba, _vefm, _कलंक, 
   {{0x63a0009f,0x6e200010,0x6d4cbfe3,0xd4780677}},	//   _uion, _šoba, ehba, _דאבל, 
   {{0xdcf4031c,0xe298bfe4,0xc8840166,0x7180035b}},	//   _jixħ, _тад_, _yaşä_, ьқәе, 
   {{0x6d4cbfe5,0x6568007b,0xdcf4031c,0x00000000}},	//   ghba, nnfh, _mixħ, --, 
   {{0xdb2004d3,0x656801e7,0x00000000,0x00000000}},	//   ووسی, infh, --, --, 
   {{0x6d4c058a,0x99000a59,0xf364030d,0x00000000}},	//   ahba, रज्ञ_, _ятĕн, --, 
   {{0x3ea82af2,0x7984bfe6,0x00000000,0x00000000}},	// [fa50] _igat_, tlhw, --, --, 
   {{0x6d4cbfe7,0xcd00068f,0xf1dc00bc,0x01ac00eb}},	//   chba, ęści_, _मिसन, _গবাদ, 
   {{0xfc140323,0x8d7407a7,0x3f98022f,0x7afc238a}},	//   _эмнэ, _تايا, omsu_, _tbst, 
   {{0x7afc0c8c,0x3dc8009a,0x475802bf,0x572400d1}},	//   _ubst, _kwaw_, орія_, غراق, 
   {{0x63b802d0,0x7aec009a,0x3a2c36e1,0x81b003d4}},	//   _attn, mgat, _çep_, টীত_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7bd4bfe8,0x3dc8009a,0x46680724,0x64a074df}},	//   nszu, _lwaw_, йрәм_, наша, 
   {{0x3ea8bfe9,0xa2d00075,0x3f9800f3,0xf2d01968}},	//   _ngat_, ىيىت, jmsu_, رآب_, 
   {{0x7aecbfea,0x321c0175,0xc2e8007b,0x00000000}},	//   igat, _qrwy_, زعيم_, --, 
   {{0x3ea8bfeb,0x2eb43156,0x7aec045a,0x30740f06}},	//   _agat_, ूर्त, hgat, зумс, 
   {{0x7aec7318,0x31740171,0x00000000,0x00000000}},	//   kgat, _ķezā_, --, --, 
   {{0x321c0cfd,0x23f80375,0x7aec4ac8,0x031802f2}},	//   _trwy_, _לפעמ, jgat, _وتنت_, 
   {{0x7aec00dc,0x9264014d,0x6d4c5337,0x7bd4002f}},	//   dgat, _بدام, thba, eszu, 
   {{0x320c02e2,0xdd8c009f,0xa2840023,0x00000000}},	//   mwey_, ُوَ_, _ምስኣን_, --, 
   {{0xa064213d,0x320c0204,0x3eacbfec,0xab28bfed}},	//   _наша_, lwey_, žeta_, бова_, 
   {{0x7aecbfee,0x3dc8007f,0x3e7405db,0x802400f2}},	//   ggat, _fwaw_, ụta_, _آروم, 
   {{0x6d4c0175,0x00000000,0x00000000,0x00000000}},	// [fa60] phba, --, --, --, 
   {{0x6f14bfef,0x7aecbff0,0x78a80139,0x00000000}},	//   _hayc, agat, _şevr, --, 
   {{0x6f140309,0x5d38011a,0x645c00d0,0xa0240254}},	//   _kayc, _התיא, ĺpik, msöö, 
   {{0x7aec074d,0x6f1404c4,0x7e6c27c4,0xf9900131}},	//   cgat, _jayc, šopš, ىبە_, 
   {{0xd6cc4e02,0x6f14bff1,0xd7040153,0x00000000}},	//   اقه_, _mayc, янце_, --, 
   {{0x6f14003a,0x684401a9,0xcb08009f,0x00000000}},	//   _layc, _енга, _ايڏن_, --, 
   {{0xa84800c6,0x6d5c0200,0xa02401f4,0x00000000}},	//   _الأم_, _mmpa, isöö, --, 
   {{0x6f147a06,0x98a016ab,0xdcf4031c,0x6e20031c}},	//   _nayc, _чисе, _tixħ, _ġobn, 
   {{0x69d4bff2,0x6d5c2f05,0xf6640137,0x3ea8022e}},	//   nsye, _ompa, _жетү, _rgat_, 
   {{0x7aec4f49,0x6d5c0ac5,0x3ea801c3,0x8af003b9}},	//   zgat, _nmpa, _sgat_, ciəv, 
   {{0x3dc810ff,0x6f14bff3,0x320c058a,0x248802d2}},	//   _swaw_, _bayc, awey_, _ábm_, 
   {{0x6d5cbff4,0x6f14bff5,0x69d4bff6,0x6cc802dd}},	//   _ampa, _cayc, ksye, _ﺒﺩﺍﻴ, 
   {{0xe2840372,0x0dc89a5c,0xd33402e4,0x4f28010c}},	//   _элди, зуси_, _מראה_, _ስዊዘር, 
   {{0x7aec00ee,0x6d5c0175,0x7bd4bff7,0xa0240254}},	//   wgat, _cmpa, tszu, gsöö, 
   {{0x7aecbff8,0x6f14bff9,0x6d5c0204,0x3ea804cc}},	//   tgat, _fayc, _dmpa, _tgat_, 
   {{0x3ea8bffa,0x7aec084c,0x3ce8007d,0x31a8002d}},	//   _ugat_, ugat, _जाके_, _wźze_, 
   {{0x7aecbffb,0x7f4c0eda,0x7bd400dd,0x3914bffc}},	// [fa70] rgat, _ilaq, sszu, ммар, 
   {{0x7aecbffd,0x7bd401d3,0x00000000,0x00000000}},	//   sgat, pszu, --, --, 
   {{0x69d402e2,0x7aecbffe,0x6f1406be,0x00000000}},	//   asye, pgat, _yayc, --, 
   {{0xf1dc068f,0xdb04bfff,0x320c0493,0x7f4c031c}},	//   _मिलन, ömäs, ywey_, _jlaq, 
   {{0xda6402dd,0x6d5cc000,0x7f4c031c,0xab6002dd}},	//   _راحي, _ympa, _mlaq, _شۇكى, 
   {{0x7f4c4375,0xc98402bf,0x799401af,0x00000000}},	//   _llaq, _зуси, _цигф, --, 
   {{0x7f4c0139,0x00000000,0x00000000,0x00000000}},	//   _olaq, --, --, --, 
   {{0x7f4c0327,0xe7a42d40,0x00000000,0x00000000}},	//   _nlaq, _قۇلى_, --, --, 
   {{0x7994035a,0x6e200135,0x00000000,0x00000000}},	//   _khzw, _ġobo, --, --, 
   {{0x320cc001,0x6f14a062,0x3ce80b03,0x2008031c}},	//   rwey_, _sayc, _जागे_, ħbin_, 
   {{0x6f14c002,0x79940857,0xc0580006,0x00000000}},	//   _payc, _mhzw, зіў_, --, 
   {{0x6d5c207a,0x8fc00588,0x7f4c37a7,0x6f1401a9}},	//   _smpa, _ҟаиҵ, _claq, _qayc, 
   {{0xa354004b,0x6f14014f,0xad2400f1,0x00000000}},	//   _ترلږ, _vayc, ورسو, --, 
   {{0x6f1402d1,0x7f4cc003,0x00000000,0x00000000}},	//   _wayc, _elaq, --, --, 
   {{0x7f4cc004,0x6f140455,0xd1b80133,0xa0240254}},	//   _flaq, _tayc, _ئاڵا_, rsöö, 
   {{0xceb406be,0xa0240037,0x00000000,0x00000000}},	//   _enər_, ssöö, --, --, 
   {{0x6d5c02b4,0xed58319b,0x2d94c005,0x6ab4c006}},	// [fa80] _tmpa, _мои_, _орос, rcyf, 
   {{0x2bb8b745,0x6d5c07e2,0x69d4c007,0x00000000}},	//   _واجة_, _umpa, rsye, --, 
   {{0xc0ac008f,0x00000000,0x00000000,0x00000000}},	//   ציאָ, --, --, --, 
   {{0x69d4c008,0xaa4400ee,0x57d00451,0x8af006be}},	//   psye, _жемл, ئينء, hnəz, 
   {{0xd5acc009,0x6b48010e,0x00000000,0x00000000}},	//   لفن_, _yýgn, --, --, 
   {{0xf9f81b4b,0x79940857,0x5e54010f,0x62840254}},	//   _ཕྱིན_, _ghzw, וינע_, ükom, 
   {{0x9ba401d9,0x8af003e3,0x98a000d8,0x00000000}},	//   _رگہِ_, biət, _аире, --, 
   {{0x68fc074d,0x8af000ac,0x61840092,0x00000000}},	//   lfpd, ciət, _ነባራዊ_, --, 
   {{0xd3e00241,0x256800db,0xe8141788,0x8af006be}},	//   _lọṣọ_, _даап_, णिका_, liəs, 
   {{0x2918c00a,0x270c032c,0xa31c0316,0x55e00902}},	//   ndpa_, _ससुर_, _मोरङ_, _шоуб, 
   {{0x7f4cc00b,0x917001c0,0x26c4c00c,0x00000000}},	//   _plaq, тгэц, oboo_, --, 
   {{0xdc2c0882,0x38b40241,0x26c400b5,0x57f8011a}},	//   jñāt, _kúró_, nboo_, חלטו, 
   {{0xcd00033f,0x450c0327,0x3eac00c0,0x38b402d2}},	//   ęśni_, _གྲོར_, žeto_, _júró_, 
   {{0x8ca00764,0x38b401e1,0x00000000,0x00000000}},	//   _गृहो, _múró_, --, --, 
   {{0x7f4cc00d,0x50b4431a,0x00000000,0x00000000}},	//   _tlaq, _غدود_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd91811ed,0x3a74c00e,0x682c001f,0x201c0174}},	// [fa90] жье_, хлар, _ተቋማት, lvti_, 
   {{0x8af000ac,0x69d80374,0x291c0321,0x00000000}},	//   fiəs, _ātet, _ótal_, --, 
   {{0x8af00213,0xc984119e,0x00000000,0x00000000}},	//   hnəy, тути, --, --, 
   {{0x05e00d01,0xd6d852c4,0x00000000,0x00000000}},	//   _निशब, іте_, --, --, 
   {{0xae200406,0x00000000,0x00000000,0x00000000}},	//   मियन_, --, --, --, 
   {{0x26c4208d,0x38b4110e,0xb9080050,0x05e000c5}},	//   aboo_, _dúró_, _عٲزم_, _निरब, 
   {{0xd880627d,0xd7740eff,0x1768084c,0x8af00213}},	//   _شهری, _قارع, _драп_, ciəs, 
   {{0x38b4c00f,0x57c801f9,0x20080327,0x00000000}},	//   _fúró_, ाठीह, ħbil_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x20300133,0x045800cf,0x06a001e1,0x289800df}},	//   ۆفیس, _ۉجۅت_, _íírì_, ּירא, 
   {{0x182c0092,0x00000000,0x00000000,0x00000000}},	//   _በዋነኛ, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xeb98bde1,0x6ff4007b,0x00000000,0x00000000}},	//   зив_, _أستط, --, --, 
   {{0xdca001d5,0x00000000,0x00000000,0x00000000}},	//   уаси, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [faa0] --, --, --, --, 
   {{0x5e5400c8,0x1984084c,0xed5801c4,0x00000000}},	//   _נייע_, ебуи_, _хоо_, --, 
   {{0xa6e40a52,0xdbdc01e1,0x186421fe,0x00000000}},	//   ежел, _jììg, нафи_, --, 
   {{0xdc34008f,0xf424015b,0x28b0146c,0x4de4023e}},	//   _נאכט_, বহার_, _जलवि, _कटाई_, 
   {{0x450c025c,0x8af000ac,0x26c4c010,0xed840023}},	//   _གྲུར_, rhəd, rboo_, _ሓብተይ_, 
   {{0x97c0c011,0x795003e6,0x00000000,0x00000000}},	//   _әйте, _پێما, --, --, 
   {{0x66e4c012,0x884801d5,0x00000000,0x00000000}},	//   _пова, _تیاق_, --, --, 
   {{0x78540543,0x940006f6,0x38b400e5,0x470802f2}},	//   _جیمز_, اويه, _túró_, _ترسێ_, 
   {{0x77900345,0x00000000,0x00000000,0x00000000}},	//   _ئینا, --, --, --, 
   {{0x64a4c013,0x35c4014b,0x00000000,0x00000000}},	//   _заза, _рафҳ, --, --, 
   {{0xc1b00184,0x1af40154,0x9100013d,0x00000000}},	//   ыҙҙы, ঁজতে_, учыд, --, 
   {{0x3eac2759,0x91bc00cc,0x00000000,0x00000000}},	//   øet_, _এটৰ্, --, --, 
   {{0x62640323,0x316401c4,0xfcc4c014,0x270c000d}},	//   _явда, bilz_, кәнм, _ससैर_, 
   {{0x3d94026b,0x00000000,0x00000000,0x00000000}},	//   тигр, --, --, --, 
   {{0x7124823d,0x9040c015,0xec18104e,0x00000000}},	//   _جرنل, _منوه, мерә_, --, 
   {{0x2e000134,0xd7f8016c,0x05e00073,0x3f9c0ca8}},	//   _wɔfa_, ҷуд_, _निंब, _òwu_, 
   {{0xd8e406ed,0x644c025c,0xdb200241,0x00000000}},	// [fab0] ецеп, _żbil, _óríl, --, 
   {{0xa3c09387,0xd7f8016c,0x00000000,0x00000000}},	//   ्ठा_, зуд_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7bc000c8,0x7c2404e6,0x68300092,0x00000000}},	//   ŭlud, _hrhr, _በዋልድ, --, 
   {{0x6b480162,0xd73001c6,0xb17c00d7,0x00000000}},	//   _nýgj, _өдгө, vrťo, --, 
   {{0x889400d1,0xb6f40063,0xdbdc0241,0x04b41cd0}},	//   _бирх, _извј, _oìíg, усія, 
   {{0x5fd80073,0x00000000,0x00000000,0x00000000}},	//   _भिजल, --, --, --, 
   {{0x81d4009d,0x00000000,0x00000000,0x00000000}},	//   лцэц, --, --, --, 
   {{0x65300451,0x00000000,0x00000000,0x00000000}},	//   _پڙها, --, --, --, 
   {{0x450c0327,0x645c00d7,0x8af006be,0x00000000}},	//   _གྲིར_, úpit, nhəc, --, 
   {{0x7d0454fb,0x1b1000fe,0xcdc40150,0x00000000}},	//   _abhs, হাঁই_, ламқ, --, 
   {{0x780c000b,0x31640112,0x00000000,0x00000000}},	//   सबुक_, pilz_, --, --, 
   {{0x0cb003f4,0x61400b7e,0x6da4026a,0x7c78001f}},	//   কর্ত, _веша, ђива, _የድሮው_, 
   {{0x2030c016,0xab1806a6,0x506400ee,0x8024027d}},	//   _نفوس, мцах_, _ятда, _مريم, 
   {{0x0c8c069c,0xeb3400d1,0x00000000,0x00000000}},	//   _መድረኽ_, خىرد, --, --, 
   {{0xac640092,0xcc14009d,0x76580210,0x7f5c0200}},	// [fac0] ደዚሁም_, _өчнө, jzwy, ërqe, 
   {{0x271c063f,0x6da4c017,0x7658012d,0x780c0e49}},	//   _ịn_, _шипа, dzwy, सबूक_, 
   {{0x9fa00077,0xe7380902,0x00000000,0x00000000}},	//   cíón_, меж_, --, --, 
   {{0x66e4c018,0x28740022,0x00000000,0x00000000}},	//   тода, ныҵр, --, --, 
   {{0x628c0034,0x7c2802b1,0x00000000,0x00000000}},	//   ębok, āere, --, --, 
   {{0xa8046145,0x569006ed,0x02bc00cd,0x00000000}},	//   _изгл, јашт, ैर्न, --, 
   {{0x637c01c7,0x31d000b8,0x00000000,0x00000000}},	//   mënz, _āsaṃ_, --, --, 
   {{0xdc2c00cd,0x00000000,0x00000000,0x00000000}},	//   _jñāp, --, --, --, 
   {{0x3b0c02d1,0xb3540f01,0x24f40124,0x3774004e}},	//   _ñeqe_, دینا_, _ачер, _сырс, 
   {{0x1a98010f,0x00000000,0x00000000,0x00000000}},	//   ויפע, --, --, --, 
   {{0x2e00016b,0x141400c6,0x64a41cf2,0x630400ae}},	//   _bɔfo_, _ليلة_, _ража, _لوال, 
   {{0x61b001ec,0xa3800254,0xa5c002d2,0x00000000}},	//   _پەدا, õõdi, _þósv, --, 
   {{0xd1b80020,0x2e00013f,0x1ea80979,0x7c2401ab}},	//   _ተገቢ_, _dɔfo_, بادي_, _srhr, 
   {{0xffb8007b,0x00000000,0x00000000,0x00000000}},	//   _كُتب_, --, --, --, 
   {{0x317801d3,0x0cb003d4,0x00000000,0x00000000}},	//   észe_, কৰ্ত, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdd98052f,0x3f880333,0x49b8c019,0x9a8401d5}},	// [fad0] _ошо_, _ikau_, نالد_, тувл, 
   {{0x6284012d,0x7c340117,0x00000000,0x00000000}},	//   żkow, _беох, --, --, 
   {{0x9ba04da8,0xbc6800e5,0xf794a8db,0x6cd8010f}},	//   _نەسى, _سجدے_, гажэ, _אַכצ, 
   {{0x8704008e,0x9b240022,0x00000000,0x00000000}},	//   ияче, _рфол, --, --, 
   {{0x62f800bd,0xd04003b9,0xd5840133,0x00000000}},	//   ্যায়_, _denə, نێره_, --, 
   {{0xc5080131,0x00000000,0x00000000,0x00000000}},	//   نتىل_, --, --, --, 
   {{0x97a4c01a,0x7984016d,0x57a400db,0x00000000}},	//   _арал, mohw, _ашаа, --, 
   {{0x3f880218,0x7984239a,0x32600023,0xd04006be}},	//   _nkau_, lohw, _ንስልጣ, _genə, 
   {{0xca300131,0x00000000,0x00000000,0x00000000}},	//   ﯨﻐﺎ_, --, --, --, 
   {{0x3f88c01b,0x7984c01c,0x61e402f0,0xd16001d5}},	//   _akau_, nohw, ákla, рноқ, 
   {{0xd04003e3,0x93400116,0x00000000,0x00000000}},	//   _yenə, _پىشۇ, --, --, 
   {{0x79840455,0x00000000,0x00000000,0x00000000}},	//   hohw, --, --, --, 
   {{0x79840433,0x145801e0,0x712401e2,0x00000000}},	//   kohw, _эшҡы_, _مرغل, --, 
   {{0x3f88c01d,0xe1f410fc,0x116400e5,0x82341bf4}},	//   _ekau_, _сгш_, _جلتی_, _خرما, 
   {{0x3f8803a0,0xdf800014,0x637c01c7,0x78a003b2}},	//   _fkau_, _گُٹی, vënz, _úlvh, 
   {{0x637c0036,0x00000000,0x00000000,0x00000000}},	//   wënz, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [fae0] --, --, --, --, 
   {{0x79840099,0x7bc00332,0x00000000,0x00000000}},	//   gohw, íluc, --, --, 
   {{0xb86400f1,0x00000000,0x00000000,0x00000000}},	//   ټالو, --, --, --, 
   {{0x6d4cc01e,0x637c006a,0xc5c40022,0xf7740124}},	//   lkba, sënz, аркҩ, аҧс_, 
   {{0x79840223,0x6b480413,0x6d4c3602,0x27e4002e}},	//   bohw, _nýgi, okba, ōon_, 
   {{0x9f4002fb,0x00000000,0x00000000,0x00000000}},	//   čké_, --, --, --, 
   {{0x4ab809d9,0x6d4cbdd0,0x00000000,0x00000000}},	//   _अलाव, ikba, --, --, 
   {{0xd37407ee,0x00000000,0x00000000,0x00000000}},	//   лчы_, --, --, --, 
   {{0x6d4cc01f,0x4154361e,0xe578009d,0x00000000}},	//   kkba, ивис, _зза_, --, 
   {{0x6d4c0936,0xe5a40209,0x637c02b1,0xb504bbed}},	//   jkba, _сизи, kīng, _نظمو, 
   {{0x6b48010e,0xd36c0214,0x00000000,0x00000000}},	//   _eýgi, _کهن_, --, --, 
   {{0x65681682,0x6d4c27bb,0x7984c020,0x9f4c007c}},	//   lifh, ekba, zohw, _lpfö_, 
   {{0x6448c021,0xe2900597,0x246c0cc1,0x5ce400d6}},	//   lyfi, _اذا_, _həm_, люва, 
   {{0x65680084,0x246cc022,0x00000000,0x00000000}},	//   nifh, _kəm_, --, --, 
   {{0x07041b76,0xf1a800b2,0x38600023,0x00000000}},	//   रभाव_, _شاهه_, _ተጸሚዱ_, --, 
   {{0x65680dc9,0x60d8bd81,0xdef8823b,0x79840433}},	//   hifh, latm, _чык_, wohw, 
   {{0x2364009f,0x79840810,0xdfd002dd,0x4cd40154}},	// [faf0] _mmoj_, tohw, _тоқы, _তারু, 
   {{0x60d8c023,0x64480af9,0x5b000131,0x38c401ec}},	//   natm, kyfi, _گېرم, ршаң, 
   {{0x656806d6,0x6aa400bd,0x0fd40034,0x236401e4}},	//   difh, গুলো, भीपढ, _omoj_, 
   {{0x60d8c024,0x6448c025,0x00000000,0x00000000}},	//   hatm, dyfi, --, --, 
   {{0xf49002d3,0x8b040118,0x5a440024,0x00000000}},	//   _ምቕራብ_, ířet, _сэна, --, 
   {{0x236401e4,0x167002dd,0xa3c000dc,0x246c06be}},	//   _amoj_, ақұр, ्ठं_, _bəm_, 
   {{0x60d8c026,0x36d40006,0x246c03b9,0x05742309}},	//   datm, _вобр, _cəm_, حاند, 
   {{0x7bc40bd7,0xc2e8015b,0x246c0213,0x23640200}},	//   _mthu, ক্সি_, _dəm_, _cmoj_, 
   {{0x60d8198f,0x6d4c0660,0x63000131,0x473401c6}},	//   fatm, ykba, تۈنل, _унтс, 
   {{0x7bc41cdf,0x236401e4,0x6448007c,0x64440213}},	//   _othu, _emoj_, byfi, _əkiz, 
   {{0x7bc4c027,0xb4c05345,0x64480034,0xa3c000dc}},	//   _nthu, ंडी_, cyfi, ्ठः_, 
   {{0xa3600451,0x00000000,0x00000000,0x00000000}},	//   _وڏيو, --, --, --, 
   {{0x7bc400fc,0x43840491,0x2b400010,0x246c03b9}},	//   _athu, _النق, _rokc_, _zəm_, 
   {{0x637c00b0,0xb5fc02f0,0x6d4c0af9,0x00000000}},	//   tīng, _dxšx, ukba, --, 
   {{0x7bc4c028,0xb17c00d7,0x00000000,0x00000000}},	//   _cthu, vrťh, --, --, 
   {{0x3a2c01fa,0x2078008f,0x34d0012c,0xaac40330}},	//   _šepa_, _באצא, हरुद, شترن, 
   {{0x7bc43e94,0x4420001e,0x8af003e3,0x00000000}},	// [fb00] _ethu, ̉i_, bhən, --, 
   {{0xad240075,0x224003b2,0x00000000,0x00000000}},	//   _ئىدى, økki_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe5c4c029,0x60d851ca,0x57e4010b,0x246c03b9}},	//   аско, zatm, рдцм_, _rəm_, 
   {{0xe61002dd,0x66743c97,0x3b0c0113,0xd6142d4b}},	//   تشا_, جدار, _ñeqa_, لتوا_, 
   {{0x69c4c02a,0x76c40131,0x281400f2,0x644866fe}},	//   _itke, لغۇل, _پورس, tyfi, 
   {{0x656806d6,0x7bc40175,0x6c78008f,0x2908032e}},	//   rifh, _xthu, כאַפ, _ibba_, 
   {{0x6448c02b,0x60d89e1e,0x442000df,0x8334c02c}},	//   ryfi, watm, ĉi_, сних, 
   {{0x6448c02d,0x60d8c02e,0xdb0c0129,0x67200064}},	//   syfi, tatm, _bicê, mdoj, 
   {{0x6600c02f,0x6720008f,0x246c06be,0xa90801d5}},	//   mtok, ldoj, _təm_, xnоl, 
   {{0x6600c030,0x60d87bc0,0xd13400ee,0x4438c031}},	//   ltok, ratm, рхы_, _çr_, 
   {{0x6720c032,0x660000ec,0x2364009f,0x93c80014}},	//   ndoj, otok, _umoj_, _شامہ_, 
   {{0x60d8c033,0x2908a6af,0x7bc4002b,0x00000000}},	//   patm, _obba_, _sthu, --, 
   {{0xd24c021a,0x61e0601a,0x66006c3f,0xb5fc02f0}},	//   _تنه_, _ivol, itok, _vxšx, 
   {{0xdeb00220,0x61e00008,0x6600023a,0x69c40024}},	//   _мұны, _hvol, htok, _atke, 
   {{0x2908c034,0x6600c035,0x200c0084,0xc2e800bd}},	//   _abba_, ktok, _ipfi_, ক্রি_, 
   {{0x98c404a9,0x9524031c,0x6b4803b2,0x200c01bf}},	// [fb10] لغان, _རྣའི_, _nýgu, _hpfi_, 
   {{0x98c4c036,0x1bec00c5,0x200c0171,0x9cf4004e}},	//   рсал, _छिपल_, _kpfi_, _өчүш, 
   {{0x7bc41253,0x97a40323,0x57a4c037,0x7d1403ee}},	//   _uthu, ардл, ашда, mezs, 
   {{0x61e005a1,0x29081876,0x200c00d8,0x6600a39f}},	//   _ovol, _ebba_, _mpfi_, ftok, 
   {{0x7afc8d34,0x66000589,0x61e0031c,0xcc880133}},	//   _icst, gtok, _nvol, _منیه_, 
   {{0xb4c00b03,0x7d14c038,0x05640212,0x67200153}},	//   ंडे_, nezs, овін, adoj, 
   {{0x6600c039,0x61e0c03a,0xc7c4c03b,0xf7940064}},	//   atok, _avol, _мсти, _гавэ, 
   {{0x7d140156,0xdce4007f,0xcc780375,0xd6140451}},	//   hezs, dijč, יגות_, _نڪتا_, 
   {{0x77680003,0x63e402dd,0x00000000,0x00000000}},	//   _imex, _ۇيلە, --, --, 
   {{0x26c8013f,0x54340214,0x65780240,0xadec00bc}},	//   _ɑbom_, _پرطر, _gjth, _जिबन_, 
   {{0xba000201,0x61e0c03c,0xdb0c02d3,0x7d140165}},	//   _ልጅ_, _evol, _cicë, dezs, 
   {{0xb8f807e4,0x2f54c03d,0x77680135,0x637c00b0}},	//   _ོབ_, стос, _jmex, tīne, 
   {{0x7520c03e,0x823405d9,0xd1b80150,0x77680135}},	//   _kalz, _ورها, _شاشا_, _mmex, 
   {{0x7afc02d0,0xada4c03f,0x69c4022e,0x6da421f3}},	//   _acst, сагл, _rtke, сига, 
   {{0x61e003c6,0x75200365,0x6600c040,0x8af000ac}},	//   _zvol, _malz, ztok, bhəl, 
   {{0xf3f80154,0x7520036e,0x2008025c,0x00000000}},	//   _আনার_, _lalz, ħbit_, --, 
   {{0x7afc0175,0xc94401ec,0x67200200,0x00000000}},	// [fb20] _dcst, одақ, vdoj, --, 
   {{0xdb0c180f,0xb4c00027,0x30f800dc,0x2ba80073}},	//   _licè, ंडो_, ्भिः_, _कळवा, 
   {{0x2d88c041,0x60d8008f,0x7afc054e,0x6b481427}},	//   mobe_, רקענ, _fcst, _sýgu, 
   {{0x2d88c042,0xad240075,0x7afc02c4,0x7520002d}},	//   lobe_, _ئىگى, _gcst, _aalz, 
   {{0x6720c043,0x66002ffb,0x5c440092,0xac740066}},	//   rdoj, utok, ነጋገር, _خاکش, 
   {{0x7520c044,0x2d881cea,0x77680944,0x29080998}},	//   _calz, nobe_, _emex, _ubba_, 
   {{0x61e0c045,0x75200268,0x321c0142,0x00000000}},	//   _svol, _dalz, _aswy_, --, 
   {{0x2d88c046,0x752002d0,0x22400254,0xb18001e3}},	//   hobe_, _ealz, äkko_, åång, 
   {{0x2d88c047,0x7520c048,0xdb0c0066,0x6b48010b}},	//   kobe_, _falz, _dicè, _uýgu, 
   {{0x2d882dee,0xe50400f1,0xdb0c0200,0x8af003e3}},	//   jobe_, _دبري, _picë, lkəd, 
   {{0x2d88c049,0x1dd401c6,0x776802d0,0x3ed40b24}},	//   dobe_, өлнө_, _ymex, يقدر, 
   {{0x442c01ab,0x7520031c,0x00000000,0x00000000}},	//   _ird_, _zalz, --, --, 
   {{0x6e2000da,0x442c0263,0x8af003be,0x61e002fd}},	//   _šobr, _hrd_, rhəl, _uvol, 
   {{0x63b8c04a,0x442c0882,0xdb14002e,0xe16801b9}},	//   _kutn, _krd_, _tuxë, _حصصه_, 
   {{0x7164198a,0x200c1682,0x442cc04b,0x63b801d3}},	//   _بانك, _upfi_, _jrd_, _jutn, 
   {{0x442c9306,0x63b807f5,0xabac0ed1,0xc1780024}},	//   _mrd_, _mutn, _ﺳﺎﻧﺎ, lnė_, 
   {{0x442c030d,0x8b04012c,0x2d88c04c,0x63b8c04d}},	// [fb30] _lrd_, ířat, bobe_, _lutn, 
   {{0x442cc04e,0xdb0c0077,0x2d88c04f,0x63b801e3}},	//   _ord_, _micé, cobe_, _outn, 
   {{0x63b8031d,0xdb0c2508,0x6e200077,0x76b8c050}},	//   _nutn, _licé, _áobr, алер_, 
   {{0x48a8c051,0x2c600014,0x6e340ca8,0x00000000}},	//   стум_, _کۯہُ, _ògbú, --, 
   {{0x442cc052,0x63b801fa,0x75200036,0x3b08045a}},	//   _ard_, _autn, _palz, mfaq_, 
   {{0x442cc053,0x63b82ecd,0x795800e6,0x7520031c}},	//   _brd_, _butn, _тигр_, _qalz, 
   {{0x64a0c054,0x7520c055,0xdb0c01e7,0x7768003d}},	//   маша, _valz, _aicé, _tmex, 
   {{0xc1780006,0xf34800d1,0x2d88c056,0xdff002ab}},	//   enė_, рпил_, zobe_, _अमजद_, 
   {{0x3dc801d4,0x2d88c057,0xdb0c0129,0x00000000}},	//   _ntaw_, yobe_, _cicé, --, 
   {{0xdb0c84aa,0x442cc058,0x2d88005a,0x78a003b2}},	//   _dicé, _frd_, xobe_, _úlvs, 
   {{0x63b80bed,0x3dc8c059,0x442cc05a,0x2d880109}},	//   _gutn, _ataw_, _grd_, vobe_, 
   {{0x61ec0c3c,0x00000000,0x00000000,0x00000000}},	//   ünlü, --, --, --, 
   {{0x20080365,0x2d88c05b,0x25b00365,0xe28c8c75}},	//   çbir_, tobe_, _ünlü_, _ца_, 
   {{0xf1c00010,0x8af00213,0x02a401c6,0x6b48032e}},	//   _vešč_, rhəm, _эрхм, _nýgr, 
   {{0xa06416a8,0x3b0801b9,0xdbb800d1,0x442c0f85}},	//   _маша_, ffaq_, иттә_, _xrd_, 
   {{0xdca0036b,0x2d880223,0x7f5c0784,0x6da4023b}},	//   фаси, sobe_, chsq, сиҳа, 
   {{0x2d88c05c,0x00000000,0x00000000,0x00000000}},	// [fb40] pobe_, --, --, --, 
   {{0x2d88c05d,0xa9a40026,0xa968c05e,0x00000000}},	//   qobe_, цизд, шиза_, --, 
   {{0xeb9865cb,0xa6c8004b,0x443c31c1,0x5ebc03d4}},	//   _вин_, لوال_, xxv_, ্ণৰূ, 
   {{0x63b8007c,0x00000000,0x00000000,0x00000000}},	//   _rutn, --, --, --, 
   {{0x442c0b4b,0x88843737,0xc1780024,0xe9a4004e}},	//   _srd_, _کیان, ynė_, _мамп, 
   {{0x442cc05f,0x6b94c060,0xa6d00154,0x00000000}},	//   _prd_, llyg, _হাওয়, --, 
   {{0xfa300020,0x00000000,0x00000000,0x00000000}},	//   _ሠራተኞ, --, --, --, 
   {{0x6b940209,0xdb14056a,0x442cc061,0xdb0c0332}},	//   nlyg, _puxé, _vrd_, _picé, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x442cc062,0x64a40124,0xe164007b,0x6b948b89}},	//   _trd_, _даза, تدبي, hlyg, 
   {{0x3dc8c063,0x4034c064,0x6b940209,0x3b0802c4}},	//   _staw_, ченс, klyg, yfaq_, 
   {{0xc17802d5,0xdb0c00c6,0x7f9c0194,0xdce41c52}},	//   snė_, _ticé, féqa, dijā, 
   {{0x63a0c065,0x637c0f40,0x628c0e78,0xc0c4013d}},	//   _ihon, cīna, ßbod, _нәни, 
   {{0x7f5c02d0,0xe3bc0139,0x00000000,0x00000000}},	//   shsq, _şıya_, --, --, 
   {{0xdb68c066,0x6b940250,0x9b6801c0,0x00000000}},	//   арал_, flyg, ашаа_, --, 
   {{0x6b940209,0xbab805f5,0x00000000,0x00000000}},	//   glyg, сгах_, --, --, 
   {{0xb9b4c067,0x63a0c068,0x3b08c069,0xb95402e8}},	// [fb50] سماع, _mhon, rfaq_, пващ, 
   {{0xceb40375,0x63a00731,0x8938084c,0xc0f00023}},	//   _קיץ_, _lhon, опус_, _ቁስሊ_, 
   {{0x63a000a9,0xdce400da,0xd7f8c06a,0x6b940368}},	//   _ohon, cijā, руз_, blyg, 
   {{0x63a0c06b,0xdb0c0356,0x00000000,0x00000000}},	//   _nhon, _zicî, --, --, 
   {{0xeb3800c8,0x47dc03d4,0x69f000d1,0x07080338}},	//   _הערש, মূলী, _пүтт, تيني_, 
   {{0x63a0c06c,0x2c0c0183,0xd1480023,0x00000000}},	//   _ahon, হিৰে_, _ዝፈትው, --, 
   {{0x3f80008f,0x63a01483,0x97ac00fb,0xb17c00d7}},	//   _ĉiun_, _bhon, _араh, jsťa, 
   {{0x63a0c06d,0x42b804a9,0xd618009f,0x232401f0}},	//   _chon, ينىڭ_, _پترا_, зоъи_, 
   {{0x63a0c06e,0x7f9006be,0x00000000,0x00000000}},	//   _dhon, cıqə, --, --, 
   {{0x6b940209,0x63a0c06f,0x44f40229,0x0ef402ab}},	//   zlyg, _ehon, _опус, अल्स_, 
   {{0x6b9409a5,0x63a000c6,0xf4980150,0x5f480023}},	//   ylyg, _fhon, _اپات_, _ዝከላኸ, 
   {{0xe80c53c7,0x63a0c070,0xf49002d3,0xa854011a}},	//   _सहसा_, _ghon, _ምሕሳብ_, פירה_, 
   {{0x80cca782,0x43700150,0x313414b3,0xa2b8123b}},	//   _द्वे, _جۇير, _недр, _המנט, 
   {{0xc1043497,0x63a0c071,0x9f400313,0xa2a0010b}},	//   _يوني, _zhon, čká_, _яңыҗ, 
   {{0x6b944c38,0xc618b37b,0xadec7ef5,0xdbd4005b}},	//   tlyg, _धन्य_, _जिवन_, jääh, 
   {{0xdce40318,0x63a00240,0x5f90041b,0x00000000}},	//   rijā, _xhon, _пијт, --, 
   {{0x6b940209,0xdce400e2,0x2d940139,0x00000000}},	// [fb60] rlyg, sijā, _нрос, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd1d00092,0xdc380677,0x00000000,0x00000000}},	//   ኩረት_, _העטר, --, --, 
   {{0x63a0c072,0x98a00724,0x76b406be,0x00000000}},	//   _rhon, _җите, _rəyç, --, 
   {{0x63a0c073,0x77900ec9,0xded402d3,0x00000000}},	//   _shon, _ییلا, _ክዳን_, --, 
   {{0x63a0c074,0x2918c075,0x942000f0,0x00000000}},	//   _phon, mepa_, емје, --, 
   {{0x2918c076,0x987800c8,0x63a00113,0xb9c0013d}},	//   lepa_, _האלט, _qhon, _öçön, 
   {{0x63a01aa1,0xb17c00d0,0xdef801e0,0x00000000}},	//   _vhon, vrťr, ҙын_, --, 
   {{0x2918c077,0x68fc03a2,0x765c0213,0x00000000}},	//   nepa_, ngpd, _üsya, --, 
   {{0x63a0c078,0xc32400cc,0x00000000,0x00000000}},	//   _thon, ভাবি_, --, --, 
   {{0x2918c079,0x62800457,0xefd4001f,0x26c40ba7}},	//   hepa_, _txoo, ራሪያ_, ncoo_, 
   {{0xa3c0068f,0x4ea4c07a,0xdb0c026c,0x2918c07b}},	//   _एंड_, ерра, _dicì, kepa_, 
   {{0x29181f7f,0x00000000,0x00000000,0x00000000}},	//   jepa_, --, --, --, 
   {{0x29188bd2,0xdef80121,0x92dc03d4,0x31a400f1}},	//   depa_, _лып_, তলৰ_, _تلوې, 
   {{0x4c94086f,0x69bc00af,0x9e04022e,0x00000000}},	//   хисс, _वंशी, _ечол, --, 
   {{0x29180789,0xd9b400ec,0x00000000,0x00000000}},	// [fb70] fepa_, سناڪ_, --, --, 
   {{0xdbd40108,0x3f980003,0x4ddc011a,0x00000000}},	//   tääh, llsu_, _החזו, --, 
   {{0xecb000fb,0x00000000,0x00000000,0x00000000}},	//   _аҡры, --, --, --, 
   {{0xabac005e,0xe7fc00ab,0x00000000,0x00000000}},	//   _ﺳﺎﻳﺎ, _उमरा_, --, --, 
   {{0x29180099,0x00000000,0x00000000,0x00000000}},	//   bepa_, --, --, --, 
   {{0xdb14172e,0x2918c07c,0xdbd4005b,0x0c740066}},	//   _muxí, cepa_, pääh, _آدید, 
   {{0x59c002ab,0xc50800f1,0x00000000,0x00000000}},	//   _वंडर, ستول_, --, --, 
   {{0x26c4c07d,0x572000db,0xc2f400c7,0xadec000d}},	//   ccoo_, _سۉتك, нџьы, _जिलन_, 
   {{0xf8e0033f,0x00000000,0x00000000,0x00000000}},	//   _फ़ाय, --, --, --, 
   {{0xc66801e0,0xf8dc3d1d,0x307400c0,0x00000000}},	//   _эшсе_, यरिय, думс, --, 
   {{0xdb1406ed,0xdb0c01e7,0xd83c00a2,0x15f4012d}},	//   _auxí, _aicí, _öōde_, ूझकर_, 
   {{0xdb140077,0x2918c07e,0x32540556,0xc0c8001f}},	//   _buxí, zepa_, _овер, _በዘር_, 
   {{0x29180810,0xf8dc012d,0xdcfc0055,0x00000000}},	//   yepa_, यराय, _śvāv, --, 
   {{0xdb0c1709,0x9f5c0268,0x2918009d,0x00000000}},	//   _dicí, attà_, xepa_, --, 
   {{0x1d04a863,0xdb0c01e7,0x29180124,0x92dc00eb}},	//   ьери_, _eicí, vepa_, তলী_, 
   {{0xe9d8c07f,0xdb140077,0x26c4011f,0xddc80030}},	//   жка_, _fuxí, xcoo_, žišo, 
   {{0x2918c080,0xa924c081,0x8eb402de,0x00000000}},	// [fb80] tepa_, мдал, _سەست, --, 
   {{0x2240c082,0x66040f23,0x00000000,0x00000000}},	//   äkki_, _äkki, --, --, 
   {{0x6d5c011c,0x8cd400e1,0x5d38011a,0x00000000}},	//   _ilpa, _ब्यो, _ותיא, --, 
   {{0x2918c083,0x59d8012c,0xeb980276,0x06d000fe}},	//   sepa_, मीहर, _фим_, _ৱাহি, 
   {{0xc5f84ef9,0x2918c084,0x00000000,0x00000000}},	//   яға_, pepa_, --, --, 
   {{0x29180784,0x8d3c0023,0x00000000,0x00000000}},	//   qepa_, _ኣወሃሂ, --, --, 
   {{0xd820c085,0x97c001af,0x00000000,0x00000000}},	//   _идри, _айсе, --, --, 
   {{0x18a0c086,0x2734313e,0xdb0c054e,0x00000000}},	//   _расм, _تىرس, _zicâ, --, 
   {{0xa184010b,0xd6cc00ae,0xe578026b,0x00000000}},	//   дынл, _خقق_, _дза_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb0cc087,0x00000000,0x00000000,0x00000000}},	//   _sicí, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x91e00022,0x626400ee,0x0dc85bc6,0x00000000}},	//   _аоче, _ювда, дуси_, --, 
   {{0xdb0c00ae,0xe60c01ec,0x00000000,0x00000000}},	//   _vicí, удi_, --, --, 
   {{0x4c94497c,0x6d5c002f,0x00000000,0x00000000}},	//   вирс, _dlpa, --, --, 
   {{0x6d5cc088,0x8f080150,0x00000000,0x00000000}},	//   _elpa, _قيىق_, --, --, 
   {{0x6d5c02c4,0x68ecc089,0x00000000,0x00000000}},	// [fb90] _flpa, _bdbd, --, --, 
   {{0xdeec0150,0x7f4c0051,0x00000000,0x00000000}},	//   _حۋڭ_, _hoaq, --, --, 
   {{0x3f801a4c,0x8d7402dd,0x7d04c08a,0x317800e5}},	//   _ĉiuj_, _جايا, _ichs, észi_, 
   {{0x7f4cc08b,0x7c242aef,0x8c441fbe,0x5ebc0154}},	//   _joaq, _ishr, _реџе, ্ণকে, 
   {{0x8f9c0302,0x3ce000c5,0x60c803ac,0xaaf4011a}},	//   קידי, _kehv_, _offm, _אזרח_, 
   {{0x7f4c01a9,0x8af00213,0xd6d40154,0x7658008e}},	//   _loaq, nkən, _হাওয, _ğayı, 
   {{0x3ac8022e,0x3d1001bc,0x13a4030f,0x3ce006be}},	//   _kўp_, द्ये_, ونتی_, _mehv_, 
   {{0x7c2401f7,0xb22400f0,0xe7a40150,0x00000000}},	//   _mshr, емил, _كۇلى_, --, 
   {{0x7d04c08c,0x98a0007f,0x290c00db,0xc8240092}},	//   _ochs, _majč_, òfag_, _ዱራሰን, 
   {{0x98a00100,0x7c24022e,0x9f98000d,0x92dc0154}},	//   _lajč_, _oshr, hääl_, তলে_, 
   {{0x7f4c00e4,0x8af003b9,0x00000000,0x00000000}},	//   _boaq, dkən, --, --, 
   {{0x7d04c08d,0x6d5c05b1,0x98a000f3,0x9f980254}},	//   _achs, _slpa, _najč_, jääl_, 
   {{0xdca01171,0x5f400228,0x00000000,0x00000000}},	//   ғати, اچىل, --, --, 
   {{0x8af00213,0x00000000,0x00000000,0x00000000}},	//   hhət, --, --, --, 
   {{0x307800c8,0x5fc4012c,0x7058010a,0xab3400f0}},	//   _מאַנ, _रूपल, _хайĕ, нхај, 
   {{0x28d006ab,0xdfcc742b,0x6d5c75d3,0x7d041196}},	//   दुनि, _ايي_, _wlpa, _echs, 
   {{0xbfa80014,0x7c240200,0x84700092,0x6a84009d}},	// [fba0] _تاوٕ_, _eshr, _ኤድስን_, хлаа, 
   {{0x3ce00a94,0xdb1400d8,0x6d5c01c3,0x00000000}},	//   करणे_, _puxã, _ulpa, --, 
   {{0x9f4400d8,0xeb98009b,0x00000000,0x00000000}},	//   üiça_, _нио_, --, --, 
   {{0xaa44c08e,0xdc7400c8,0x7f4c0077,0x80ac010f}},	//   _земл, _טעיפ_, _xoaq, קסאַ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x95c000c6,0xe73400ef,0x16840133,0x00000000}},	//   ديوه, _dūšī, رانێ, --, 
   {{0x98a0c08f,0x92dc03d4,0x00000000,0x00000000}},	//   _бире, তলৈ_, --, --, 
   {{0x5430009a,0x2130010e,0x00000000,0x00000000}},	//   ارور, _şyh_, --, --, 
   {{0xa3c000ce,0x8af006be,0x00000000,0x00000000}},	//   _एंव_, lhəs, --, --, 
   {{0x0418015b,0x4154322f,0x00000000,0x00000000}},	//   থিবী_, твос, --, --, 
   {{0x92dc1c82,0xc4a40406,0x3ce00037,0x00000000}},	//   _তাৰ_, _ओरिओ, _rehv_, --, 
   {{0x2284897a,0x3ce003e3,0x00000000,0x00000000}},	//   _пулг, _sehv_, --, --, 
   {{0xdb0c5490,0xdb140165,0x5ba40022,0x00000000}},	//   _ricà, _nuxá, ҵраз, --, 
   {{0xd1b82440,0xd238011a,0x00000000,0x00000000}},	//   _ሰለባ_, _מגדל, --, --, 
   {{0xbf1014d4,0x5ba4c090,0xd91800c7,0x00000000}},	//   _күнә, ераз, ҟьа_, --, 
   {{0xdb140429,0x7f94c091,0x9098123b,0x00000000}},	//   _buxá, _шайх, _מסוק, --, 
   {{0xfbd00451,0xdb0c01d3,0x00000000,0x00000000}},	// [fbb0] _چڪر_, _cicá, --, --, 
   {{0x7d042f05,0x7c2401ee,0x8af003b9,0xd9180124}},	//   _uchs, _tshr, lkəl, џьа_, 
   {{0xd7f80276,0x7c24035a,0x9f980037,0x26d003e0}},	//   яуа_, _ushr, pääl_, ıyon_, 
   {{0x57249d9a,0xdb0c24b0,0xf7440063,0xeb34014b}},	//   عراق, _ficá, ђело, _иҷсш_, 
   {{0x601401b8,0x2d7000e2,0xab600116,0x00000000}},	//   _yümö, zņem_, _ئۇقى, --, 
   {{0x8af000ac,0x00000000,0x00000000,0x00000000}},	//   bhəs, --, --, --, 
   {{0xdb202507,0x8af003e3,0xdedc0240,0x00000000}},	//   _óról, kkəl, ሓሉን_, --, 
   {{0x9f5c023a,0xa92002d2,0x00000000,0x00000000}},	//   nttä_, _íþrj, --, --, 
   {{0x47840224,0x35b4c092,0x656c01bf,0x9f5c01f4}},	//   _сырб, _абар, ønhø, ittä_, 
   {{0xeb1c033f,0xa56000db,0xefc801c4,0x00000000}},	//   _पस्त_, _ۅگۉن, млол_, --, 
   {{0xe53400c8,0x00000000,0x00000000,0x00000000}},	//   _שטעט_, --, --, --, 
   {{0xb27422fd,0xdb0c01e1,0x8af006be,0x00000000}},	//   _илеш, _èdèk, hhər, --, 
   {{0xfe2402d5,0x332c0f85,0x81d4014b,0x00000000}},	//   льён, mdex_, _бочх, --, 
   {{0x332c00b5,0x6da4c093,0xada4747c,0xc10400ec}},	//   ldex_, тига, тагл, _موهي, 
   {{0xeb98c094,0xdb0cc095,0x3d100b7c,0x9d402123}},	//   див_, _sicá, द्धे_, шерд, 
   {{0x332cc096,0x644c0129,0x491400dc,0x320c0009}},	//   ndex_, _àbie, न्नो_, otey_, 
   {{0x320cc097,0x6f140175,0x60140790,0xf8dc726b}},	// [fbc0] ntey_, _ibyc, _tümö, यरूप, 
   {{0x3d1013b4,0xdb0c003a,0xed5801c6,0xdaa4041b}},	//   द्दे_, _nicæ, _цоо_, твуд_, 
   {{0xaba8136b,0x9cd408d8,0x320c0731,0xa0241577}},	//   _овоз_, _שוטה_, htey_, mpöö, 
   {{0xdb0c00d2,0x6e342f48,0x186424cd,0x1ae0004e}},	//   _ticá, _kryb, њаци_, _коюм, 
   {{0x332c0050,0xc44858fb,0x46141056,0xe7ec878d}},	//   ddex_, کیان_, اوتر, _चटका_, 
   {{0x291c08f3,0x69d40066,0x637c00e2,0x00000000}},	//   _úta_, mpye, mīni, --, 
   {{0x8af000ac,0x386c03f9,0x6f14c098,0xb86401d9}},	//   hkəm, _ƙere_, _obyc, _یاہو, 
   {{0x320c0067,0xd3742eca,0xe6180816,0x00000000}},	//   ftey_, кчы_, _одб_, --, 
   {{0x77901194,0x2490068f,0x320c01d9,0x070400c7}},	//   _اینا, łym_, gtey_, _аҧҵо, 
   {{0x35c40364,0x6f14012c,0x637c00b0,0x64a40022}},	//   _сафҳ, _abyc, kūng, _ҟаҵа, 
   {{0x9f5c049b,0x320c5d3e,0x491411bc,0xa0240254}},	//   yttä_, atey_, न्यो_, dpöö, 
   {{0x320c01d9,0x6e340129,0x66040254,0x69d40200}},	//   btey_, _bryb, _äkks, kpye, 
   {{0x6e3465d0,0x9f5c0240,0x0e08010b,0xee840139}},	//   _cryb, lutë_, кэри_, гърү, 
   {{0xd12c0597,0x317801ed,0x6f140142,0xd254011a}},	//   _ومن_, észt_, _ebyc, _בשדה_, 
   {{0x1fa4c099,0x9f5c0240,0x00000000,0x00000000}},	//   _ириг, nutë_, --, --, 
   {{0x6b8434fe,0x6e3407c5,0x2ec000ee,0xc4c401d9}},	//   _cjkg, _fryb, _гөрм, _ژے_, 
   {{0x6e34c09a,0x69d40280,0x3914a44d,0x8f380a1e}},	// [fbd0] _gryb, gpye, лмар, _יאהו_, 
   {{0x7bc001ed,0xd7f8023b,0x6f14012d,0x00000000}},	//   ílus, дуд_, _zbyc, --, 
   {{0x1aec00bd,0x35b40220,0x4e942ab4,0x69d40022}},	//   ঙ্গে_, ңбер, _مشیر, apye, 
   {{0x7f5c0175,0xe79400ec,0x320cc09b,0x00000000}},	//   nksq, هانک, ytey_, --, 
   {{0xb90803f4,0x637c005f,0x5570036b,0x09e40153}},	//   _যা_, cīni, аҳат, _коўн, 
   {{0x7bc416cb,0x69a80c5a,0xf504005b,0x9f5c0200}},	//   _kuhu, _जीपी, узко, futë_, 
   {{0x7bc4c09c,0x6b4800ee,0xc0c8001f,0x644401e1}},	//   _juhu, _aýgy, _በመላ_, _ńkir, 
   {{0x7bc4c09d,0x320cc09e,0xdb0c00d8,0x98a000b8}},	//   _muhu, ttey_, _dicç, _gajā_, 
   {{0x7bc4c09f,0xd9e029d6,0x320c014b,0xdce40024}},	//   _luhu, गठित_, utey_, siję, 
   {{0x320cc0a0,0xdb0c0120,0xb1442773,0x9f5c0200}},	//   rtey_, _ficç, унол, butë_, 
   {{0x7bc41dd4,0x320c0731,0x332c014f,0x6da40116}},	//   _nuhu, stey_, pdex_, ғива, 
   {{0xb8e40327,0xea1001e1,0x00000000,0x00000000}},	//   _ཌུ_, _ọ̀wẹ, --, --, 
   {{0x8234c0a1,0x7bc400d8,0x320c0009,0x49141fd2}},	//   _پرنا, _auhu, qtey_, न्डो_, 
   {{0x7bc4c0a2,0x3178008f,0x8af000ac,0x6e340ea0}},	//   _buhu, _ראַד, rkəm, _vryb, 
   {{0x9f980036,0x7bc406be,0xa0240254,0x00000000}},	//   _bääh_, _cuhu, rpöö, --, 
   {{0xa098008f,0x8cd46b9b,0x6e340034,0xeb980107}},	//   _איצט, _ब्रो, _tryb, хиб_, 
   {{0xa8483837,0xa9c400db,0x6e3402d0,0x7bc00162}},	// [fbe0] کلام_, ازرو, _uryb, ílur, 
   {{0x69d40280,0xdef002d3,0x6d5800af,0x637c0374}},	//   rpye, _ውሳነ_, ötad, pūng, 
   {{0x7bc40516,0x2d9800b4,0x637c0064,0x00000000}},	//   _guhu, _ikpe_, lūne, --, 
   {{0x64a40220,0x468402dd,0xf7280212,0x637c00e2}},	//   ңада, ақба, кцій_, pīni, 
   {{0x7bc4c0a3,0x9f48026c,0x667452d4,0x7658015d}},	//   _zuhu, ébé_, ددار, gywy, 
   {{0x69c40421,0x7bc401d9,0x9f5c0023,0xece0015b}},	//   _iuke, _yuhu, tutë_, _বাঁড, 
   {{0x98a000da,0x69c4c0a4,0x6a44013f,0x7bc4005a}},	//   _tajā_, _huke, rɔfu, _xuhu, 
   {{0x6b940174,0xdc3400df,0xa76401a9,0x637c0064}},	//   noyg, ראקט_, _ёкад, kūne, 
   {{0xa6847b98,0x67200115,0x69c42278,0x11d0036b}},	//   _слад, meoj, _juke, یتید, 
   {{0x6600c0a5,0x8cd40c4c,0x6720009f,0xc0c400d1}},	//   muok, _ब्लो, leoj, шшиқ, 
   {{0x69c4c0a6,0x6600c0a7,0x6304c0a8,0x64a4c0a9}},	//   _luke, luok, _موال, _сажа, 
   {{0x491408f8,0x78a00158,0x7f94c0aa,0x69c4c0ab}},	//   न्तो_, _ølve, рамх, _ouke, 
   {{0x7bc4c0ac,0x9f5c0232,0x69c4c0ad,0x6b9403b2}},	//   _suhu, nuté_, _nuke, doyg, 
   {{0x7bc4246f,0xbd44c0ae,0x4034117e,0xd6940150}},	//   _puhu, جنسي, _векс, _ﺘﺜﻴﺭ_, 
   {{0x69c4c0af,0x77780227,0x7bc40309,0x672001e4}},	//   _auke, yiwx, _quhu, keoj, 
   {{0x2d980521,0x6600c0b0,0x7bc4c0b1,0x61e00337}},	//   _ekpe_, kuok, _vuhu, _kwol, 
   {{0xd1e80201,0x6720c0b2,0xbab805f5,0x7bc4013f}},	// [fbf0] _መብት_, deoj, тгах_, _wuhu, 
   {{0x69c43621,0x7bc4c0b3,0x3ea805b1,0x61e02255}},	//   _duke, _tuhu, _izat_, _mwol, 
   {{0xe3bc0598,0x7bc4090c,0xdb0c01b8,0x69c4c0b4}},	//   _ğına_, _uuhu, _picä, _euke, 
   {{0x69c4c0b5,0x61e0c0b6,0xc7b400c6,0x3d1006ff}},	//   _fuke, _owol, مصنع, द्रे_, 
   {{0x69c466a9,0x25bcc0b7,0x3f88c0b8,0x9f5c020c}},	//   _guke, _bitl_, _mjau_, guté_, 
   {{0x212c0332,0x33f401d5,0x491408df,0x00000000}},	//   _nafh_, ачис, न्दो_, --, 
   {{0x61e0c0b9,0x25bc05c7,0x69c401c4,0x97a4a6bb}},	//   _awol, _ditl_, _zuke, _брал, 
   {{0x61e00337,0x9f5cc0ba,0x3f88009f,0x28a80ce0}},	//   _bwol, buté_, _njau_, _करति, 
   {{0xe7a404a9,0x69c4005a,0x7f9c0036,0x9f5c0129}},	//   _ئۇنى_, _xuke, néqu, cuté_, 
   {{0x82a8010b,0xd5a0179e,0xc65400f1,0x00000000}},	//   ыбың_, _الطی, _دځمک, --, 
   {{0x3494c0bb,0x3ea86733,0x6fa80063,0x8b0800bc}},	//   _тажр, _azat_, квог_, _jeřá, 
   {{0x2d980120,0x25bc05c7,0x20081f40,0x00000000}},	//   _skpe_, _zitl_, àbia_, --, 
   {{0x61e0c0bc,0x83b400db,0x3ea8033f,0xe0cc2502}},	//   _gwol, _احلئ, _czat_, _мв_, 
   {{0x69c4c0bd,0x3ea8065c,0x54f4033f,0x7f9c0129}},	//   _ruke, _dzat_, ीलिए_, déqu, 
   {{0x69c4c0be,0x660004ce,0x61e0c0bf,0x3ea800f3}},	//   _suke, zuok, _zwol, _ezat_, 
   {{0x69c4c0c0,0xee388284,0x6a84c0c1,0x9f5c020c}},	//   _puke, _ани_, алба, yuté_, 
  
   {{0xfe74008e,0x6b94c0c2,0x00000000,0x00000000}},	// [fc00] _гүя_, royg, --, --, 
   {{0xebe40372,0x69c403b4,0x3a38007f,0x6600023a}},	//   _кооп, _vuke, _drsp_, vuok, 
   {{0x69c407a8,0x6720c0c3,0x386c02a8,0x6d4c0007}},	//   _wuke, teoj, _ƙera_, mjba, 
   {{0x69c4c0c4,0x3a380223,0x660002d5,0x25bc05da}},	//   _tuke, _frsp_, tuok, _sitl_, 
   {{0x69c4022f,0xd1e8001f,0x67200115,0xd7040139}},	//   _uuke, _መብቱ_, reoj, рнче_, 
   {{0x6600c0c5,0x9580c0c6,0x6d4c0007,0x785401ed}},	//   ruok, олче, njba, _گیمز_, 
   {{0x61e0c0c7,0xa6c805f5,0x66e4016c,0x6600c0c8}},	//   _swol, _алба_, _воба, suok, 
   {{0x9f5cc0c9,0xaac40034,0x61e0033b,0x660000c0}},	//   puté_, वशिक, _pwol, puok, 
   {{0x25bc0dd4,0xd6240cb6,0x00000000,0x00000000}},	//   _titl_, _коте_, --, --, 
   {{0xe5a49fb6,0xe50400aa,0x5a1408a8,0x2b4000ef}},	//   _тизи, _خبري, סקין_, _lnkc_, 
   {{0x656807f0,0xc0c400d1,0xd1b40592,0x10a00120}},	//   mhfh, _қәпи, جايا_, жиќн, 
   {{0x61e01418,0xa3b800f7,0x00000000,0x00000000}},	//   _twol, _شاار_, --, --, 
   {{0x236400c8,0x442cc0ca,0x98a40960,0x61e0c0cb}},	//   _iloj_, _hsd_, _čiča_, _uwol, 
   {{0x23640218,0x5180010b,0x8234c0cc,0xa2d000cd}},	//   _hloj_, _муща, _پرچا, णुर्, 
   {{0x442c05b1,0xcc5400a7,0xe50c0037,0x00000000}},	//   _jsd_, овръ, _सानि_, --, 
   {{0x442c07a8,0x3a3800ca,0x3ea8009d,0x3f7c01e4}},	//   _msd_, _prsp_, _tzat_, rĉus_, 
   {{0x98a0068f,0x3f9825b5,0xcf7804fb,0x98c44af9}},	// [fc10] _mają_, mosu_, _خصوص_, асел, 
   {{0x442c02fa,0x3f98c0cd,0x2364044e,0x7f9c0129}},	//   _osd_, losu_, _lloj_, réqu, 
   {{0xf6d4177b,0x7f9c2d7d,0x442c007c,0x00000000}},	//   біля, séqu, _nsd_, --, 
   {{0x3f9808ad,0x97000075,0xdb1428ed,0x00000000}},	//   nosu_, تېرى, _luxú, --, 
   {{0x7aecc0ce,0x442cc0cf,0x0f380a1e,0x27e401a6}},	//   maat, _asd_, יראט_, ćona_, 
   {{0x236401e4,0x3f9800b5,0x673c00de,0x00000000}},	//   _aloj_, hosu_, ēpja, --, 
   {{0x3f980a40,0x739801d5,0x00000000,0x00000000}},	//   kosu_, лтис_, --, --, 
   {{0x7aecc0d0,0x3b08c0d1,0x9f5c145e,0x3f9808e5}},	//   naat, ngaq_, dutï_, josu_, 
   {{0x7aec20ac,0x3dc80086,0x98a0033f,0x656801ab}},	//   iaat, _nuaw_, _dają_, bhfh, 
   {{0x7aecc0d2,0x442c0334,0x23640100,0x3b080007}},	//   haat, _fsd_, _eloj_, hgaq_, 
   {{0x7aecc0d3,0x331800d6,0x3f98c0d4,0xa0a00166}},	//   kaat, _біля_, fosu_, заэд, 
   {{0x7aecc0d5,0x3f9805d1,0xd6cc01ec,0x2bc80131}},	//   jaat, gosu_, птi_, ғлап_, 
   {{0x7aecc0d6,0x442c0072,0x824800ae,0x00000000}},	//   daat, _zsd_, _نشوف_, --, 
   {{0x61d4025f,0x6d4c0007,0x637c4a38,0x00000000}},	//   _הוסף_, ujba, mūna, --, 
   {{0x7aecc0d7,0xab1805f5,0x3f980ffb,0x41740740}},	//   faat, лцах_, bosu_, _بانس, 
   {{0x7aecc0d8,0xd110107c,0x3f9819f5,0xa03002dd}},	//   gaat, त्रण_, cosu_, _ءىيت, 
   {{0xed580220,0xee380640,0x00000000,0x00000000}},	// [fc20] _боп_, _снп_, --, --, 
   {{0x3b080869,0xf9901884,0x29d401a9,0xf0880023}},	//   agaq_, ۋبە_, _қўмс, _ዓንዳሪ_, 
   {{0x7aec1f9f,0xe73897d0,0x00000000,0x00000000}},	//   baat, леж_, --, --, 
   {{0x7aec07d5,0x442c5663,0xe5c415a0,0x637c0153}},	//   caat, _rsd_, бско, kūna, 
   {{0xe5a4825e,0x637c0024,0x3a0801d3,0x656800ae}},	//   биди, jūna, _نکلی_, thfh, 
   {{0x442cc0d9,0x02e03599,0xbbe804fb,0x3f98026c}},	//   _psd_, नर्न, _حریم_, zosu_, 
   {{0x8884c0da,0x23640457,0xe50c2983,0x64480007}},	//   _بیان, _ploj_, _साठि_, uxfi, 
   {{0x442cc0db,0xb9e00023,0x637c00c0,0x00000000}},	//   _vsd_, _እቶ_, fūna, --, 
   {{0x637c02d5,0x42541fc2,0x442c0072,0xda78010f}},	//   gūna, زندر, _wsd_, ָניר, 
   {{0x7aec0083,0xdfd802e8,0x563800df,0x00000000}},	//   zaat, лъм_, _געמײ, --, 
   {{0x7aecc0dc,0x3f98c0dd,0x442cc0de,0x6578c0df}},	//   yaat, tosu_, _usd_, _imth, 
   {{0x9f5c0054,0x2364010f,0x7aecc0e0,0x637c00c0}},	//   rutï_, _uloj_, xaat, būna, 
   {{0x7aecc0e1,0x3f98c0e2,0x88c000bd,0x2258c0e3}},	//   vaat, rosu_, েরিক, _حجاب_, 
   {{0x7aecc0e4,0x3f98c0e5,0x00000000,0x00000000}},	//   waat, sosu_, --, --, 
   {{0x7aecc0e6,0x3f98c0e7,0x3dc80036,0xf1a802f2}},	//   taat, posu_, _wuaw_, _ئانه_, 
   {{0x7aec0194,0x3b08013c,0x3a28c0e8,0x8ff40214}},	//   uaat, ugaq_, twap_, _ارور_, 
   {{0x7aecc0e9,0x6578b00f,0x9f5c04bf,0x98c48709}},	// [fc30] raat, _omth, nutí_, مغان, 
   {{0x7aecc0ea,0x2dd01df2,0x3a280113,0x7ad801f9}},	//   saat, _ﻛﻮﻣﻤ, rwap_, _फ्रॅ, 
   {{0x7aecc0eb,0x3a28051f,0x9f5c022a,0x37c401e1}},	//   paat, swap_, hutí_, _ṣebí_, 
   {{0x6578c0ec,0x7aecc0ed,0x77981075,0x41c81788}},	//   _amth, qaat, шкер_, रदास, 
   {{0xdfc405d9,0x94080073,0xab780354,0x00000000}},	//   _ڊي_, सूनच_, _тӳрĕ_, --, 
   {{0xdfc4021a,0x637c0006,0x13b000dc,0x4c1402f2}},	//   _يي_, vūna, ुद्भ, _ببیس, 
   {{0x657801ab,0x644c0129,0x00000000,0x00000000}},	//   _dmth, _àbil, --, --, 
   {{0x6578c0ee,0xe50c0118,0x2bbc00cd,0x00000000}},	//   _emth, _साथि_, ्दया, --, 
   {{0x77680005,0x9f5c004e,0xd50850d8,0x00000000}},	//   _ilex, gutí_, _مغان_, --, 
   {{0x7158c0ef,0x637c0024,0x6ac400bc,0x85b800c0}},	//   ррис_, rūna, _वल्र, _глус_, 
   {{0x453000cf,0x0ca800bc,0x2bbc00cd,0x5ed80154}},	//   _سۉير, _गरेम, ्दमा, _ভয়ে, 
   {{0x7ad80490,0x9f5c01ef,0x00000000,0x00000000}},	//   _फ्लॅ, butí_, --, --, 
   {{0x31341c3e,0x00000000,0x00000000,0x00000000}},	//   _медр, --, --, --, 
   {{0xafe4c0f0,0x7ae8010f,0xc1740209,0x88c00183}},	//   _докл, _ĵeta, _нҗы_, েৰিক, 
   {{0xeb7800f0,0xd69401ec,0xe6d00150,0x00000000}},	//   асај_, _ﺘﻜﻔﺭ_, _ﺟﯩﮕﺎ, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6ea40014,0x2bbc04aa,0x8ca400db,0x00000000}},	// [fc40] _گچھہ_, ्दबा, تەگو, --, 
   {{0x1b780020,0xa9040035,0xec780108,0x00000000}},	//   _ተገለጸ_, تبرن, _впо_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2a08005a,0x00000000,0x00000000,0x00000000}},	//   _кемп_, --, --, --, 
   {{0x9d5003e6,0xe99000cf,0x4ab4009d,0x00000000}},	//   _رنێت, _قۇرگ, _хөвр, --, 
   {{0x7768c0f1,0x3eac0209,0x96300006,0x1e38010f}},	//   _elex, ýeti_, ьніц, יגנא, 
   {{0x18a00eff,0x7768c0f2,0x2d8801ab,0xd4640063}},	//   _жарм, _flex, inbe_, жије_, 
   {{0x9f5c0240,0x261000e4,0x00000000,0x00000000}},	//   rrtë_, pâo_, --, --, 
   {{0x636c07c5,0xa508c0f3,0xc8440092,0xc88801ee}},	//   _lùng, _веза_, _የሚጠቁ, _тәҡд_, 
   {{0x5500c0f4,0x65781253,0x2918022e,0x66000162}},	//   _опуб, _umth, nfpa_, mrok, 
   {{0xe734005f,0x425404fb,0x443801ed,0x6600c0f5}},	//   _mūžī, زنگر, _ér_, lrok, 
   {{0x6d58908f,0xe298c0f6,0xf1f800fe,0x00000000}},	//   ötan, _кае_, _অহৰহ_, --, 
   {{0x3eac019b,0x6600c0f7,0x98a0012d,0x00000000}},	//   ået_, nrok, _daję_, --, 
   {{0x8af006be,0x00000000,0x00000000,0x00000000}},	//   kkəs, --, --, --, 
   {{0x6600c0f8,0xdef80166,0x00000000,0x00000000}},	//   hrok, _кып_, --, --, 
   {{0xdb20b5e0,0x29180af9,0x9a840108,0x00000000}},	//   بوری, efpa_, оузл, --, 
   {{0x3a74a3ae,0x4fb435b6,0x9f5c0ffb,0x49d80c9e}},	// [fc50] члар, _تصور, mutà_, ждую_, 
   {{0xc4c4c0f9,0x9f5c19f5,0x84780023,0x5d640fac}},	//   _لے_, lutà_, ርራሕን_, _фтиз, 
   {{0xc2f000fe,0x636c01e1,0x660000c7,0xf6d4187f}},	//   _টানি_, _gùng, erok, піля, 
   {{0x6600c0fa,0x9f5c19f5,0x76b821b4,0x00000000}},	//   frok, nutà_, блер_, --, 
   {{0x8af00cc1,0x8d747be0,0x98a803be,0x66000784}},	//   rkət, _رایا, ılıb_, grok, 
   {{0x636c0241,0x2ab8011a,0x00000000,0x00000000}},	//   _yùng, _למרא, --, --, 
   {{0x43d400f1,0xdedc010c,0x5fc4c0fb,0x8af006be}},	//   وموړ, ዓሉን_, _रंगल, ckəs, 
   {{0x6600c0fc,0x38600fac,0x8af006be,0x00000000}},	//   brok, myhr_, lkər, --, 
   {{0x0ca84ff1,0x00000000,0x00000000,0x00000000}},	//   _गर्म, --, --, --, 
   {{0x8af003be,0xd49818a4,0x637c0153,0x00000000}},	//   nkər, _кре_, būno, --, 
   {{0xf8bc00e1,0x00000000,0x00000000,0x00000000}},	//   ्खिय, --, --, --, 
   {{0x8af003b9,0x00000000,0x00000000,0x00000000}},	//   bhəy, --, --, --, 
   {{0xe28cc0fd,0x636c0248,0x2d880083,0xded00023}},	//   _ча_, _dùnd, tnbe_, _ጨቋኒ_, 
   {{0x20140419,0x6ab4035b,0x00000000,0x00000000}},	//   édiá_, ҧсах, --, --, 
   {{0x66000427,0x9f5c004e,0x3b98001f,0x00000000}},	//   zrok, butà_, _ዘዴዎች_, --, 
   {{0x9f5c026c,0x88e80eac,0xdca00fc0,0x66000108}},	//   cutà_, _পাইক, хаси, yrok, 
   {{0xe8f8205a,0x48440014,0x00000000,0x00000000}},	// [fc60] йла_, ژھرٲ, --, --, 
   {{0x9f5c02fb,0xe8f80006,0x2a64025c,0xed5800d8}},	//   vrté_, ёле_, ġob_, _ѓон_, 
   {{0xab280117,0x00000000,0x00000000,0x00000000}},	//   _лона_, --, --, --, 
   {{0x6600c0fe,0xe5c415ed,0xca640046,0xe50c03ce}},	//   trok, пско, _жемқ, _साहि_, 
   {{0xe5a404a9,0x9f5c0122,0x3a148c75,0xc5f802dd}},	//   пиди, nutá_, _оьрс, юға_, 
   {{0x6600c0ff,0x00000000,0x00000000,0x00000000}},	//   rrok, --, --, --, 
   {{0xe738c100,0x66003bb4,0x4394004e,0x00000000}},	//   _лев_, srok, макс, --, 
   {{0x6600c101,0xe768963b,0x68ecc102,0x9f5c0306}},	//   prok, _احسن_, _hebd, kutá_, 
   {{0xa6a8c103,0x9f5c0205,0x00000000,0x00000000}},	//   _طارق_, rttü_, --, --, 
   {{0x637c00b0,0x95800064,0x6d5801f4,0x00000000}},	//   pūno, _злуе, ötal, --, 
   {{0x9ad001f2,0xc3900184,0x6aa4000f,0x0ec802ab}},	//   _kịta, _иҫкә, _lykf, रखंड, 
   {{0x69d80316,0xde8c02e3,0x7ae800df,0xc62400cc}},	//   _čten, kịta_, _ĵeto, পিঠা_, 
   {{0x6144c104,0x63a0c105,0xe3cc015b,0x9f5c026c}},	//   _неда, _ikon, _রবিব, rutà_, 
   {{0x63a00334,0x40e40014,0xd5680408,0x00000000}},	//   _hkon, _کٲژہ, _кiел, --, 
   {{0x63a0694e,0x7f58c106,0xdb687579,0x9f5c07c5}},	//   _kkon, _макс_, брал_, putà_, 
   {{0x5aa801f7,0xebc0013d,0x8fa400f3,0x00000000}},	//   ماءَ_, кәян, _паје, --, 
   {{0x63a000b2,0x68ec014f,0x256001a8,0x9f5c00d8}},	// [fc70] _mkon, _bebd, _eðli_, cutá_, 
   {{0x63a00093,0x9ce4084c,0x38c801d3,0x00000000}},	//   _lkon, _эцил, زائی_, --, 
   {{0x97c4c107,0x68ecc108,0xd7f822bf,0x00000000}},	//   ستام, _debd, суз_, --, 
   {{0x7c24c109,0x63a0c10a,0x870800d4,0x00000000}},	//   _iphr, _nkon, зеїв_, --, 
   {{0x7afc03ac,0x00000000,0x00000000,0x00000000}},	//   _idst, --, --, --, 
   {{0xb9240f13,0x613c0790,0xce38011a,0x00000000}},	//   _تفسي, nçlı, פאות_, --, 
   {{0x26d00ab7,0xf8b007f7,0x00000000,0x00000000}},	//   ıyor_, _झरिय, --, --, 
   {{0x63a00585,0x68ec067c,0x02f40131,0x00000000}},	//   _ckon, _zebd, ىقىڭ, --, 
   {{0xd4c40046,0x63a001c7,0x724401ed,0x7afc002f}},	//   _есеп, _dkon, بھال, _mdst, 
   {{0xf0646af7,0x00000000,0x00000000,0x00000000}},	//   дкоп, --, --, --, 
   {{0x63a01132,0x6d5800af,0x636c01ab,0x00000000}},	//   _fkon, ötam, _dùnb, --, 
   {{0x63a000ca,0xdb0c0077,0x7afc037e,0x00000000}},	//   _gkon, _micó, _ndst, --, 
   {{0x7c24c10b,0xdb14004e,0x2d9401c6,0xc2c4007b}},	//   _aphr, _luxó, дөнө_, _كيمي, 
   {{0x7afcc10c,0x224004ce,0x63a000bc,0x9f5c0789}},	//   _adst, ække_, _zkon, rutá_, 
   {{0x63a007ab,0x6aa4002d,0x68ec010e,0x6ea801f9}},	//   _ykon, _sykf, _rebd, _घरकु, 
   {{0x68ec01ee,0xdcac6923,0xae0402dd,0x00000000}},	//   _sebd, شىق_, _قوبى, --, 
   {{0x7c24c10d,0x9ad001f2,0xc94404a9,0x1ef8011a}},	// [fc80] _ephr, _aịsa, ндақ, _ולפע, 
   {{0xe8f8c10e,0xde8c00b4,0x7afc01e3,0x1e800022}},	//   іле_, rịta_, _edst, _шлым, 
   {{0x6aa4002d,0xeb980305,0xe738005b,0xad4000db}},	//   _wykf, _мио_, жее_, _كۉڭۉ, 
   {{0x66e4016c,0xa684c10f,0xb7640212,0x3774013d}},	//   фода, млед, нтій, нычс, 
   {{0x2bd0146c,0x63a0007f,0x68ec0205,0x00000000}},	//   _दूता, _rkon, _tebd, --, 
   {{0x63a0c110,0x9f5c003a,0x692401d5,0x69c0015d}},	//   _skon, cutæ_, _юмга, ïoed, 
   {{0x42540014,0x00000000,0x00000000,0x00000000}},	//   کچار, --, --, --, 
   {{0x6d58007d,0x443c0158,0x574000f3,0x00000000}},	//   ötaj, rvv_, _инсб, --, 
   {{0x6ea80490,0xd204009d,0x00000000,0x00000000}},	//   _घरगु, мээд_, --, --, 
   {{0xf3880051,0x00000000,0x00000000,0x00000000}},	//   bảo_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x63a0c111,0x53400124,0x00000000,0x00000000}},	//   _ukon, _ахша, --, --, 
   {{0x1ea801f7,0x52701d0a,0x00000000,0x00000000}},	//   تادي_, _لاوز, --, --, 
   {{0x636c05d5,0x00940276,0x00000000,0x00000000}},	//   _fùnc, _пилэ, --, --, 
   {{0xbf100184,0x394c05be,0x613c0790,0x00000000}},	//   _йүнә, _đes_, rçlı, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9cc8c112,0xdb0c0113,0x5ce400db,0x00000000}},	// [fc90] _мына_, _sicó, _оюна, --, 
   {{0x9f5c00c6,0xdb0c04d4,0x3ea8c113,0xdc400118}},	//   irtí_, _picó, _iyat_, léče, 
   {{0x7c240b6f,0x00000000,0x00000000,0x00000000}},	//   _uphr, --, --, --, 
   {{0x7afc019b,0x76b800ee,0x3ea8009f,0x00000000}},	//   _udst, плер_, _kyat_, --, 
   {{0x3c38012c,0x85e80212,0xdce40205,0x2bbc00b8}},	//   bývá_, ддів_, lojı, ्दरा, 
   {{0xdb0c011f,0x1ae40eac,0x1fb805d7,0xb0640254}},	//   _ticó, _ফায়া, ईगुड, naää, 
   {{0x64a0c114,0x26c00306,0x00000000,0x00000000}},	//   лаша, _úkon_, --, --, 
   {{0x3ea844f0,0x7984c115,0x6ac4007c,0x47e400fb}},	//   _oyat_, lihw, _åtfö, _рәфҡ, 
   {{0x3ea8c116,0x6d5826bb,0x00000000,0x00000000}},	//   _nyat_, ötak, --, --, 
   {{0x7984019f,0xafe40137,0xb06401f4,0x00000000}},	//   nihw, ноол, jaää, --, 
   {{0x3ea850f9,0xc4500133,0x69d8013a,0x49140acd}},	//   _ayat_, _نێوب, _čtem, न्टो_, 
   {{0x3ea80097,0x3c380118,0xb274c117,0x777803b9}},	//   _byat_, zývá_, _плеш, _çaxı, 
   {{0xdb0c013a,0x00000000,0x00000000,0x00000000}},	//   _chcí, --, --, --, 
   {{0x332c0067,0xdfcc05d9,0x3eac5133,0xa2ac07b7}},	//   leex_, _ڏيو_, üeta_, ुधर्, 
   {{0x6da41fc7,0xada4c118,0x2bbcc119,0xbc1800d4}},	//   _җина, _җанл, ्दला, міті_, 
   {{0xe9d81fdf,0x92c003f4,0x8e84036b,0x332c0de2}},	//   зка_, ্রী_, _аҳме, neex_, 
   {{0x6f140857,0x92c00183,0x00000000,0x00000000}},	// [fca0] _icyc, ্ৰৰ_, --, --, 
   {{0xcdc402dd,0x2ef003b9,0x5980c11a,0x00000000}},	//   _шапқ, _heyf_, глуб, --, 
   {{0x6d5cb1a8,0x636c0e89,0x3c3800bc,0x2ef00205}},	//   _iopa, _lùna, rývá_, _keyf_, 
   {{0xeb98c11b,0x6d5cc11c,0x332c058a,0xfaa400c7}},	//   _хим_, _hopa, jeex_, хаӡо, 
   {{0x6d5c9bd5,0x79842c36,0x92c00154,0x20480023}},	//   _kopa, bihw, ্রু_, _ንዘቕረ, 
   {{0x6d5c0124,0x9f5c02f0,0x6d581b99,0x00000000}},	//   _jopa, vrtí_, ötah, --, 
   {{0x6d5cc11d,0x69d4044e,0xc448c11e,0x332c00e8}},	//   _mopa, lqye, بیان_, feex_, 
   {{0xd374c11f,0x88e8045e,0x636c07c5,0x98a01b9f}},	//   ечь_, _পাটক, _bùna, _сисе, 
   {{0xc2988b16,0x6d5c06c8,0x320cc120,0xe578074d}},	//   ьких_, _oopa, guey_, _еза_, 
   {{0x6d5cc121,0x02e00c70,0x636c08c2,0x15f80375}},	//   _nopa, _ग्रह_, _dùna, _מהמע, 
   {{0x69d402d3,0x2328023a,0xceb406be,0xb0640821}},	//   hqye, _ножи_, _azə_, vaää, 
   {{0x798400ca,0x3ea80100,0xe0440116,0x637cc122}},	//   zihw, _pyat_, _үнди, kūni, 
   {{0x6d5cc123,0x798407a8,0x200002b5,0x91e063e6}},	//   _bopa, yihw, ōki_, _боче, 
   {{0x6f140857,0x00000000,0x00000000,0x00000000}},	//   _ecyc, --, --, --, 
   {{0x1fa40126,0xdb4c0133,0xc5e401d3,0x6e340064}},	//   _приг, مێد_, _گۓ_, _esyb, 
   {{0x6d5c035a,0x2bc40073,0x3ea80055,0xcb340395}},	//   _eopa, _वळणा, _tyat_, лесъ, 
   {{0x3914086a,0x7f4c0135,0x92c00183,0x3ea801d5}},	// [fcb0] кмар, _inaq, ্ৰী_, _uyat_, 
   {{0x6d5cc124,0x7cd8c125,0x00000000,0x00000000}},	//   _gopa, _юмор_, --, --, 
   {{0x7984337a,0x7f4c0240,0xfaa401e0,0xb8d8c126}},	//   rihw, _knaq, хаҡо, _चर_, 
   {{0x6d5cc127,0x7f4c0135,0x7984009f,0x35a8033f}},	//   _zopa, _jnaq, sihw, _चीज़, 
   {{0x05740132,0x6d5cc128,0x798405b8,0x7f4c0135}},	//   گاند, _yopa, pihw, _mnaq, 
   {{0x6d5c0564,0x636c0e89,0x6ea89129,0x00000000}},	//   _xopa, _rùna, _घरघु, --, 
   {{0x0574c129,0x69a804fa,0x636c04cc,0xb7c4c12a}},	//   داند, _जीटी, _sùna, _арақ, 
   {{0x78b40219,0x7f4c031c,0x36040066,0x00000000}},	//   _izzv, _nnaq, _لورف, --, 
   {{0x960005f5,0xdb0c01ab,0xa6140022,0x332c0009}},	//   _сүлж, _mhcà, _изтә, reex_, 
   {{0x7f4cc12b,0x69d800b0,0x224001a8,0x332c0009}},	//   _anaq, _ōtek, ækka_, seex_, 
   {{0x6d5cc12c,0x92c000bd,0x636c01ab,0xb4cc01f9}},	//   _ropa, ্রে_, _iùnn, ळशी_, 
   {{0x6e3400a3,0x00000000,0x00000000,0x00000000}},	//   _psyb, --, --, --, 
   {{0x6d5cc12d,0x9f5c049b,0x231400ae,0x00000000}},	//   _popa, yttö_, _شيوخ_, --, 
   {{0x7f4c05d5,0x6d5c0213,0x69d4022e,0x00000000}},	//   _enaq, _qopa, vqye, --, 
   {{0xdb0c01ab,0x69d40007,0x644c00a3,0x2b140022}},	//   _bhcà, wqye, _àbit, кьар, 
   {{0x98a40316,0x6d5cc12e,0x00000000,0x00000000}},	//   žně_, _wopa, --, --, 
   {{0x6d5cc12f,0xda60c130,0x6e34035a,0xed580408}},	// [fcc0] _topa, авти, _usyb, _жоп_, 
   {{0xfbd000f1,0x59ac012d,0x00000000,0x00000000}},	//   شتې_, _जीआर, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6a84c131,0x00000000,0x00000000,0x00000000}},	//   _алма, --, --, --, 
   {{0x290c0ba1,0x66740345,0x00000000,0x00000000}},	//   òfas_, خدار, --, --, 
   {{0x636c00a3,0x7ae8008f,0xb17c0306,0xd9d000d1}},	//   _cùnn, _ĵeti, ypťa, _ئەلگ, 
   {{0x95500214,0x92c00154,0x00000000,0x00000000}},	//   شخوا, ্রো_, --, --, 
   {{0x4420038f,0x823806bd,0x644c031c,0x5340c132}},	//   ċi_, езис_, _ġbid, ахьа, 
   {{0x171804ac,0x65c400c7,0x67200115,0x44200de2}},	//   _קומע, _абаа, mfoj, ŋi_, 
   {{0x67200115,0x00000000,0x00000000,0x00000000}},	//   lfoj, --, --, --, 
   {{0x61fc00b8,0x00000000,0x00000000,0x00000000}},	//   _āplu, --, --, --, 
   {{0xa2e4c133,0xe28400c7,0x672001e4,0x57f800d9}},	//   _родд, _илеи, nfoj, ולטו, 
   {{0xe250168d,0x0e34c134,0x7f4c003a,0xc694010f}},	//   _ڕێکخ, аняю, _vnaq, ראָ_, 
   {{0x61e0c135,0x22440548,0xdd8400a8,0x9f5c0419}},	//   _itol, _irok_, тымп, nutú_, 
   {{0x224401a6,0x7f4c003d,0x672001e4,0x00000000}},	//   _hrok_, _tnaq, kfoj, --, 
   {{0x7f4cc136,0x7ec80374,0x22442a5c,0x201c022f}},	//   _unaq, _pīpī, _krok_, mtti_, 
   {{0x201cc137,0xd918518e,0xcb340395,0x00000000}},	// [fcd0] ltti_, дье_, шетъ, --, 
   {{0xd7e410f5,0x201cc138,0x61e0c139,0x98c40131}},	//   відо, otti_, _mtol, نغان, 
   {{0x201cc13a,0x213c0354,0x6720005b,0x9e646646}},	//   ntti_, idth_, ffoj, _ساکن, 
   {{0x201c30ef,0x2244c13b,0xd6d800d6,0x6d5800af}},	//   itti_, _orok_, єте_, ötav, 
   {{0x61e0c13c,0xe794c13d,0x15c80131,0x31b80129}},	//   _ntol, دالک, _ﺗﻮﺭﺩ, lèze_, 
   {{0x201c0227,0x7d140097,0x9f5c0421,0x6720008f}},	//   ktti_, ngzs, tutû_, afoj, 
   {{0x22442b4b,0xdd000153,0x78b40171,0x00000000}},	//   _arok_, ūrėd, _uzzv, --, 
   {{0x637c0064,0x00000000,0x00000000,0x00000000}},	//   kūnu, --, --, --, 
   {{0x201cc13e,0x2244003e,0x6f8801d9,0x59b4216a}},	//   etti_, _crok_, ہندِ_, _अठार, 
   {{0x2244c13f,0x201c208d,0x9f5c02fb,0x61e000ae}},	//   _drok_, ftti_, vrtá_, _dtol, 
   {{0x61e0c140,0x22440098,0xb7e00154,0xf3880051}},	//   _etol, _erok_, _পটুয়, hải_, 
   {{0x213c7785,0x2f540556,0x924401f0,0x637c0064}},	//   adth_, утос, _аҷиб_, fūnu, 
   {{0x201c0a4d,0x637c0024,0x00000000,0x00000000}},	//   atti_, gūnu, --, --, 
   {{0x333c04fb,0x00000000,0x00000000,0x00000000}},	//   _hawx_, --, --, --, 
   {{0xca700020,0x201c208d,0xa3e4000d,0x219800df}},	//   ቸውንም_, ctti_, _बढ़ा_, _אבסא, 
   {{0x61e002d0,0x200802f0,0xc5880051,0x00000000}},	//   _ytol, ábie_, rồi_, --, 
   {{0xa924c141,0x69242bda,0x00000000,0x00000000}},	// [fce0] лдал, лмаа, --, --, 
   {{0x1e54011a,0xed5800cf,0x65b400e4,0x3a4401a9}},	//   _עשיר_, _чоо_, kâha, шмуҳ, 
   {{0x9d1800c8,0x1864c142,0xa804c143,0x6d5801f4}},	//   _אויט, лафи_, узел, ötau, 
   {{0x3a3816fe,0x2d88c144,0x09e804c5,0x00000000}},	//   _fssp_, libe_, _পিঠা, --, 
   {{0xdb040005,0x6720008f,0xd68000db,0x00000000}},	//   _émái, rfoj, йушп, --, 
   {{0x201cc145,0x2d88c146,0x69d800b0,0x2244036e}},	//   ytti_, nibe_, _ōtew, _rrok_, 
   {{0x333c0097,0x69cc0254,0x22440166,0x2420010b}},	//   _bawx_, _iibe, _srok_, сҗең, 
   {{0x69ccc147,0x2d881311,0x333c0399,0xfd4c00a2}},	//   _hibe, hibe_, _cawx_, _bilỳ, 
   {{0x69ccc148,0xc174bfb7,0x2d88c149,0x00000000}},	//   _kibe, илищ, kibe_, --, 
   {{0x69cc016d,0x2d88020c,0x637c0024,0x00000000}},	//   _jibe, jibe_, vūnu, --, 
   {{0x69cc3d81,0x201c22a9,0x22442694,0x1954010f}},	//   _mibe, utti_, _wrok_, אביל_, 
   {{0x201cc14a,0x442cc14b,0x2244c14c,0x636c01e1}},	//   rtti_, _ipd_, _trok_, _kùnm, 
   {{0x61e0c14d,0x442cc14e,0x3eac037e,0x644c0077}},	//   _utol, _hpd_, æet_, _ábib, 
   {{0x442cc14f,0x3a380230,0x2d88c150,0x8d8401d5}},	//   _kpd_, _rssp_, gibe_, бусд, 
   {{0x9964005e,0x442c0072,0xec1805a2,0x00000000}},	//   қтал, _jpd_, керә_, --, 
   {{0x442c0113,0x69cc039a,0x637c00b0,0x50180375}},	//   _mpd_, _aibe, pūnu, _נוחו, 
   {{0x69ccc151,0x2d88c152,0x3d9400d6,0xe8680092}},	// [fcf0] _bibe, bibe_, _випр, _በሚገኝ_, 
   {{0x2d8828f2,0xf1b8000a,0x442cc153,0x6d5800c5}},	//   cibe_, otša_, _opd_, ötat, 
   {{0x69cc2f2b,0x8d740228,0x442c1f0c,0x3834119e}},	//   _dibe, _دايا, _npd_, рнер, 
   {{0x636c0ca8,0x69ccc154,0x6ec0012c,0x99d4007b}},	//   _bùnm, _eibe, रेवु, _متسا, 
   {{0x442c8e6f,0xb6c405f5,0x7e7c1196,0x00000000}},	//   _apd_, рөвд, nzsp, --, 
   {{0x69ccc155,0x8ddc010f,0x65b400e4,0xf3e40f06}},	//   _gibe, עקוק, tâha, ажко, 
   {{0xa85404a9,0x7aec0083,0xc4f8007b,0xda640e56}},	//   _керә, obat, اعها_, _شاڭي, 
   {{0x7aecc156,0x442cc157,0x2d88c158,0x336400d1}},	//   nbat, _dpd_, zibe_, рвиг, 
   {{0x2d88c159,0xe1f4b590,0x69ccc15a,0x7aec6c05}},	//   yibe_, агы_, _yibe, ibat, 
   {{0x7aec07d6,0x442c009a,0x76480472,0x2d88c15b}},	//   hbat, _fpd_, _irey, xibe_, 
   {{0x8af00cc1,0x7648008c,0x442c01e1,0x98a0007f}},	//   rkəz, _hrey, _gpd_, _objč_, 
   {{0x764811c1,0x00000000,0x00000000,0x00000000}},	//   _krey, --, --, --, 
   {{0x2d88c15c,0xd1e002dd,0x764802d2,0x636c01e1}},	//   tibe_, _ايتۋ, _jrey, _oùnj, 
   {{0x7aecc15d,0x216424cd,0x320c0363,0x6fe000de}},	//   ebat, _виши_, mrey_, _pēcd, 
   {{0x2d88c15e,0x6b6406bb,0xb91402e3,0x5c70316e}},	//   ribe_, аква, _webụ_, олёт, 
   {{0x7aecc15f,0x2d88c160,0x76489f4e,0x320cc161}},	//   gbat, sibe_, _orey, orey_, 
   {{0x7648020c,0x6d5825c6,0x320cc162,0x2d88005c}},	// [fd00] _nrey, ötas, nrey_, pibe_, 
   {{0x7aecc163,0x7de405d9,0x2d8800f1,0x320c00ad}},	//   abat, _اسيم, qibe_, irey_, 
   {{0x7aec3fce,0x69ccc164,0x7648c165,0x320cc166}},	//   bbat, _vibe, _arey, hrey_, 
   {{0x7648c167,0x7aec0115,0xa6c800f1,0x320c00b5}},	//   _brey, cbat, نوال_, krey_, 
   {{0x76480407,0x442cc168,0x65c4c169,0x16a43169}},	//   _crey, _spd_, абда, авци_, 
   {{0x442cc16a,0x320cc16b,0x7648c16c,0x69cc0327}},	//   _ppd_, drey_, _drey, _uibe, 
   {{0x76482f1d,0x9cd40302,0xa7a81eed,0x320c1368}},	//   _erey, בוצה_, _аква_, erey_, 
   {{0x7648c16d,0x6b942c18,0xa3440166,0x96600166}},	//   _frey, nnyg, рэкл, скәе, 
   {{0x320cc16e,0xd25400a8,0x442c045a,0xa6a82e0b}},	//   grey_, ацэ_, _wpd_, _شارق_, 
   {{0x7aec084c,0xdfd800a7,0x636c01e1,0x21646140}},	//   zbat, към_, _kùnk, ртиг, 
   {{0x442cc16f,0x7aecc170,0x64a4c171,0x4034c172}},	//   _upd_, ybat, _тажа, щенс, 
   {{0x320cc173,0x7e7c0e78,0x9f68022e,0x7aecc174}},	//   brey_, tzsp, троз_, xbat, 
   {{0xa1141060,0x7aec07d6,0x320c06af,0x7e7c0036}},	//   _نوشت, vbat, crey_, uzsp, 
   {{0x7aec039a,0x403401f4,0x7e7c002f,0x00000000}},	//   wbat, _гекс, rzsp, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d58c175,0x7aec0ac5,0x6b9400ad,0x9f5c036e}},	//   ötar, ubat, gnyg, istë_, 
   {{0xcfe80183,0x3f88c176,0xbab8064d,0xabb40124}},	// [fd10] _কিয়_, _imau_, угах_, сатә, 
   {{0x7aecc177,0x69d800bc,0x2bd003ce,0x00000000}},	//   sbat, _čtet, _दूका, --, 
   {{0x7aecc178,0xee940133,0xa3e40037,0x00000000}},	//   pbat, _ندیک, _बढ़ल_, --, 
   {{0x07082781,0x7648c179,0x3e7c0129,0x320c1368}},	//   ليمي_, _prey, _gâté_, yrey_, 
   {{0x764803b9,0x59d800bc,0x00000000,0x00000000}},	//   _qrey, _बढिर, --, --, 
   {{0x2a38008f,0x7648c17a,0x320c1368,0xcbf83b7a}},	//   _געשמ, _vrey, vrey_, _حریص_, 
   {{0x3f88c17b,0x845802e8,0x320c1368,0x69c004b4}},	//   _omau_, ирът_, wrey_, _хөтб, 
   {{0x7648c17c,0x9ad002e3,0x65b400d2,0xa92400ef}},	//   _trey, _aịza, lâhl, _vižņ, 
   {{0x320c1368,0x764803e3,0x00000000,0x00000000}},	//   urey_, _urey, --, --, 
   {{0x320c02a4,0x3f88c17d,0x04641a98,0xd5b8009b}},	//   rrey_, _amau_, стәм, _рсб_, 
   {{0x320c062c,0x00000000,0x00000000,0x00000000}},	//   srey_, --, --, --, 
   {{0x320c1713,0x2008c17e,0x2d9c00bc,0xa8540375}},	//   prey_, ábia_, čtem_, צירה_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3f8808f5,0x61e456cf,0x00000000,0x00000000}},	//   _emau_, íkle, --, --, 
   {{0xc0c80640,0x3e7c06af,0xc0a80472,0x00000000}},	//   _куће_, _pâté_, _پاول_, --, 
   {{0xef1815ab,0xda00007d,0x00000000,0x00000000}},	//   _сми_, _लिखत_, --, --, 
   {{0x9f5c0122,0x00000000,0x00000000,0x00000000}},	// [fd20] nutý_, --, --, --, 
   {{0x44cc013b,0x6b940267,0x645c0022,0x00000000}},	//   yɛ_, snyg, äpik, --, 
   {{0x9cd40115,0x00000000,0x00000000,0x00000000}},	//   _לויה_, --, --, --, 
   {{0x3f8805b1,0x9f5c0216,0x18180014,0x18641d39}},	//   _xmau_, kutý_, ارٕک_, љаци_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4994036b,0x2b400051,0x00000000,0x00000000}},	//   _بیطر, _hakc_, --, --, 
   {{0x18643f07,0x66e4010a,0x00000000,0x00000000}},	//   _лари_, _гоба, --, --, 
   {{0x44cc1958,0xd374c17f,0x68fcc180,0x00000000}},	//   rɛ_, йчы_, lapd, --, 
   {{0x25bc2a1f,0x44cc0605,0xaaac01ad,0x96603fc2}},	//   _thtl_, sɛ_, _झुमक, _екте, 
   {{0x2918c181,0x3f880334,0x6600c182,0x68fc0432}},	//   ngpa_, _smau_, msok, napd, 
   {{0x6498055f,0x44381497,0x66003402,0xe7e400eb}},	//   _стар_, _èr_, lsok, _পটুয, 
   {{0x68fcc183,0xe1f8c184,0x00000000,0x00000000}},	//   hapd, _бгд_, --, --, 
   {{0x6600c185,0xd04001e4,0x68fca700,0xf9f40327}},	//   nsok, _genɾ, kapd, _བསེན_, 
   {{0x23640218,0x6d58005b,0x9f5c013a,0xaabc190c}},	//   _hooj_, ötap, isté_, ्धनक, 
   {{0x236401d4,0xfb88c186,0x9fe41c43,0x68fc010e}},	//   _kooj_, арақ_, _استه, dapd, 
   {{0x3f880618,0x23640841,0xdef8010b,0x660001e4}},	//   _umau_, _jooj_, _сык_, ksok, 
   {{0x236401d4,0x00000000,0x00000000,0x00000000}},	// [fd30] _mooj_, --, --, --, 
   {{0x23640211,0x644c0327,0x3d940835,0x68fc0432}},	//   _looj_, _ġbin, _фиор, gapd, 
   {{0x03c40a28,0xa9240171,0x00000000,0x00000000}},	//   śeṣa, dažā, --, --, 
   {{0x50180a7c,0xbb5400f2,0x09e800eb,0xb0640166}},	//   רואו, _بچسب, _পিরা, ltäç, 
   {{0x6600c187,0x68fc010b,0x00000000,0x00000000}},	//   gsok, bapd, --, --, 
   {{0xd5ac0f31,0x3f9803f9,0xd1e80023,0x6fe000de}},	//   رہا_, hnsu_, _ዘእቱ_, _lēca, 
   {{0xc8643924,0x733400d1,0x00000000,0x00000000}},	//   _етти, قىغا, --, --, 
   {{0x23640218,0x9f5c007b,0x1af400eb,0x22bc110e}},	//   _cooj_, artú_, ইলকে_, _ọkan_, 
   {{0x6600c188,0x00000000,0x00000000,0x00000000}},	//   csok, --, --, --, 
   {{0x3f98c189,0xbbb41116,0x3004004e,0x00000000}},	//   ensu_, ंतुक, озог, --, 
   {{0x98a00064,0x00000000,0x00000000,0x00000000}},	//   _vajė_, --, --, --, 
   {{0x2fd0022e,0x95580092,0x00000000,0x00000000}},	//   _qiyg_, ሲዎችን_, --, --, 
   {{0x68fc01a9,0xd26800ae,0x00000000,0x00000000}},	//   yapd, _حصان_, --, --, 
   {{0x236401d4,0x3f98c18a,0x9f5c01d3,0xb4f800df}},	//   _zooj_, ansu_, futó_, יפֿי, 
   {{0x23640457,0xf9f4025c,0x2fd0022e,0x00000000}},	//   _yooj_, _བསུན_, _tiyg_, --, 
   {{0x203005d9,0x611002dd,0x645c0108,0x62000166}},	//   _آفيس, _едәу, äpii, _äxlä, 
   {{0xdd8c01d3,0x8eb41e4a,0x89440092,0x0c940092}},	// [fd40] روہ_, _رەست, _የማይቻ, _የድምጽ_, 
   {{0x9f5c09d7,0x660003b2,0x00000000,0x00000000}},	//   butó_, vsok, --, --, 
   {{0x68fc0209,0xab2800d1,0x9f5c9fab,0x3dcc0af9}},	//   rapd, _кона_, cutó_, ïewe_, 
   {{0x68fcc18b,0xeb500137,0x7a3000c7,0x80ac010f}},	//   sapd, _تۉرگ, _ẽtev, נסאַ, 
   {{0x23640457,0xe5a40353,0x00000000,0x00000000}},	//   _rooj_, оиди, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6600c18c,0x66e4c18d,0x236401d4,0xd820c18e}},	//   ssok, _мова, _pooj_, _одри, 
   {{0x6600792b,0x00000000,0x00000000,0x00000000}},	//   psok, --, --, --, 
   {{0x3f981bce,0x42540fb4,0xcfe001ec,0x00000000}},	//   érum_, سندر, _ﺍﻟﻨﺒ, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x23640457,0xd8d8008f,0x657838a6,0xceb40213}},	//   _tooj_, יקיר, _ilth, _ayə_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8224038f,0x644806ea,0x00000000,0x00000000}},	//   _འདྲི_, lvfi, --, --, 
   {{0xd12c24e0,0x6dc002e3,0xe9300432,0xdfd8010a}},	//   _لمه_, ịanr, _ülňü, _къи_, 
   {{0x69d802b1,0xc02800f1,0x5b240022,0xdfa4007b}},	//   _ōtep, _اړخه_, жьза, _وحبي, 
   {{0x9f5c0407,0x29080067,0x8bc47da1,0x3cec01e4}},	//   rutó_, _adba_, дсуд, ŝev_, 
   {{0xc0c40201,0x9fbc01f1,0x443c0211,0x7ce40372}},	// [fd50] ቸውም_, nčín_, hwv_, _ىزدۅ, 
   {{0xbdc00150,0x00000000,0x00000000,0x00000000}},	//   _سەزۋ, --, --, --, 
   {{0x29080175,0x4528031c,0xbd8c0023,0x443c017a}},	//   _ddba_, _ལྡེར_, _ናብቶም_, jwv_, 
   {{0x6578c18f,0x29080327,0xde8c063f,0x6ec0000d}},	//   _alth, _edba_, rịfa_, रेकु, 
   {{0x7afc0029,0x27e801c4,0x3328002e,0x9fbc00d7}},	//   _iest, _etbn_, _ñaxi_, jčín_, 
   {{0x7afc00ed,0x443c0211,0xf98801e2,0x33f400db}},	//   _hest, fwv_, _طنزي_, пчис, 
   {{0x7afcc190,0x20080120,0x644c02d2,0x239c0327}},	//   _kest, ábil_, _ábil, wċja_, 
   {{0x7afcc191,0x03a80597,0x853c0153,0xdec81954}},	//   _jest, يديو_, _skėt, ቡልን_, 
   {{0x9ad002e3,0x7768045a,0x00000000,0x00000000}},	//   _dịga, _ioex, --, --, 
   {{0x61e403c6,0x7768009a,0x00000000,0x00000000}},	//   íkla, _hoex, --, --, 
   {{0x26c002fb,0x00000000,0x00000000,0x00000000}},	//   _úkor_, --, --, --, 
   {{0x505c0023,0x00000000,0x00000000,0x00000000}},	//   _ፈደረሽ, --, --, --, 
   {{0x720401d3,0x00000000,0x00000000,0x00000000}},	//   _عہدہ_, --, --, --, 
   {{0x7afcc192,0x61f400a2,0x2d9c0037,0x00000000}},	//   _aest, _çyla, õte_, --, 
   {{0x7afcc193,0x307800c8,0x1af4015b,0x8b0801ef}},	//   _best, _לאַנ, েলনে_, jtří, 
   {{0x7afc1f48,0x77680784,0x7c2001c3,0x09c401f9}},	//   _cest, _noex, àlra, वग्य, 
   {{0x7afcc194,0x6a8401c0,0xcfe0005e,0x00000000}},	// [fd60] _dest, члаа, _ﺍﻟﻠﺒ, --, 
   {{0x7afc4c21,0x00000000,0x00000000,0x00000000}},	//   _eest, --, --, --, 
   {{0x443c0070,0xa6e80208,0x3eac0327,0x00000000}},	//   xwv_, _ngưò, żett_, --, 
   {{0x7768c195,0xc5f8c196,0xd7ec00c6,0xacf404fb}},	//   _coex, жға_, اكن_, _بسکت, 
   {{0x636c04cc,0x00000000,0x00000000,0x00000000}},	//   _mùnt, --, --, --, 
   {{0x7afcc197,0x00000000,0x00000000,0x00000000}},	//   _zest, --, --, --, 
   {{0x7afcc198,0xd4640640,0x853c0064,0x98a0c199}},	//   _yest, зије_, _skės, _зире, 
   {{0x7afc36ed,0x7768009a,0x6fe000de,0x00000000}},	//   _xest, _goex, _pēcn, --, 
   {{0x443c0070,0xaabc1a55,0x93740395,0x00000000}},	//   swv_, ्धिक, ябът_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x636c01ab,0x42540066,0x00000000,0x00000000}},	//   _bùnt, سنگر, --, --, 
   {{0x636cc19a,0xaabc6b26,0x00000000,0x00000000}},	//   _cùnt, ्धाक, --, --, 
   {{0x636c01ab,0xad2401d9,0xd2a40064,0x00000000}},	//   _dùnt, ژرٲو, _екце_, --, 
   {{0x25ac0165,0x00000000,0x00000000,0x00000000}},	//   nofl_, --, --, --, 
   {{0x7164c19b,0x7afc3498,0x40a85530,0x91b80375}},	//   _تانك, _pest, _بخشی_, _המגי, 
   {{0x7afc070d,0xbbb80212,0x83d402dd,0x00000000}},	//   _qest, ігає_, _ﺟﺎﺯﺳ, --, 
   {{0x7afcc19c,0x7ce400cf,0x00000000,0x00000000}},	// [fd70] _vest, _ۉزگۅ, --, --, 
   {{0xc4c40d83,0x98c4c19d,0x9f5c00ae,0x00000000}},	//   _مے_, псел, istí_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7afcc19e,0x78b40232,0x75200175,0x478400cf}},	//   _uest, _vyzv, _sclz, нычб, 
   {{0x8b0800bc,0x79d0035b,0xc95800d1,0xcfe002dd}},	//   stří, _аҩаӡ, تلەش_, _ﺍﻟﻤﺒ, 
   {{0x2bd804d3,0x3a28c19f,0x853c0064,0x83d40150}},	//   _دایک_, mtap_, _skėr, _ﺟﺎﺭﺳ, 
   {{0x64a0016c,0x3a2803f0,0xdedc0240,0x00000000}},	//   каша, ltap_, ናሉን_, --, 
   {{0x77043456,0x00000000,0x00000000,0x00000000}},	//   _آژان, --, --, --, 
   {{0x3a2833cb,0x0eac0034,0x07080451,0x622000f1}},	//   ntap_, _टुंड, _ريلي_, نډول, 
   {{0x04c800f1,0xafe441b9,0x00000000,0x00000000}},	//   _کومي_, моол, --, --, 
   {{0xf1b80f8b,0x4528025c,0x636c05d5,0x850403e6}},	//   ntši_, _ལྡིར_, _pùnt, _سونن, 
   {{0xb2742235,0x2f541d0f,0x01c800e5,0x3a28008e}},	//   _олеш, фтос, _ہونٹ_, ktap_, 
   {{0xe28cc1a0,0x6d480174,0xdb040241,0x00000000}},	//   _ра_, _ófak, _òmùw, --, 
   {{0x01c800dd,0x3a280fac,0x22540cd2,0x6da4014b}},	//   _فونٹ_, dtap_, _آلود_, фига, 
   {{0x21a00032,0x6ec00b7d,0x862c01f3,0xd9e00037}},	//   _шишм, रेजु, _ሳይንስ, _कूबत_, 
   {{0x332c02c4,0x7a300022,0x274400c0,0xeb3453f0}},	//   nfex_, _ẽtav, _kūnų_, بىرد, 
   {{0xaec4c1a1,0x636c0cad,0x332800e8,0x3a28010b}},	// [fd80] _юбил, _kùnr, _ñaxu_, gtap_, 
   {{0x851c0210,0x28940114,0x9f580241,0xe8000037}},	//   _नाइट_, мјес, _ípò_, _लबदा_, 
   {{0x3a28013c,0xb8c40372,0xdd8c03e6,0x00000000}},	//   atap_, ىزمى, _ڕوی_, --, 
   {{0x9ad0063f,0x00000000,0x00000000,0x00000000}},	//   _dịba, --, --, --, 
   {{0x9f5c0589,0x09e804c5,0x00000000,0x00000000}},	//   lstã_, _পিকা, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x5b7800c8,0x248802d3,0x61e402f0,0xe6180064}},	//   ַריא, _ንዕለት_, íklo, _мдб_, 
   {{0xa5245e95,0xc2988b16,0x636c01e1,0xc0ec01f3}},	//   _омад, яких_, _sùns, _ቀመር_, 
   {{0x307402d3,0x636c01ab,0x84c454a2,0x394408a5}},	//   _ይመጽእ_, _cùnr, _пәйд, _ólst_, 
   {{0xa0a4c1a2,0x232806ed,0xf2880023,0x6e3400c0}},	//   ьшил, _можи_, _ንድግማ_, _apyb, 
   {{0x3a28879f,0x00000000,0x00000000,0x00000000}},	//   ytap_, --, --, --, 
   {{0x63a0c1a3,0x00000000,0x00000000,0x00000000}},	//   _ijon, --, --, --, 
   {{0x63a0030a,0x3a280205,0x00000000,0x00000000}},	//   _hjon, vtap_, --, --, 
   {{0xdb68c1a4,0x960801f9,0x851c0fe3,0x00000000}},	//   орал_, _हट्ट_, _नाईट_, --, 
   {{0x63a0020b,0x3a280869,0xc1780153,0x00000000}},	//   _jjon, ttap_, lkė_, --, 
   {{0x63a00b6f,0xb95402e8,0x4efc011a,0x4ea40024}},	// [fd90] _mjon, нващ, _והחו, _арэа, 
   {{0xc17802d5,0x3a28c1a5,0x2ea800c8,0x63a00158}},	//   nkė_, rtap_, _משפּ, _ljon, 
   {{0x3a28c1a6,0x63a00acb,0xc1780006,0x38c801ed}},	//   stap_, _ojon, ikė_, سائی_, 
   {{0x63a0c1a7,0x00000000,0x00000000,0x00000000}},	//   _njon, --, --, --, 
   {{0xf674152d,0x9f5cc1a8,0x3a280986,0x7bcc0108}},	//   эгдэ, istà_, qtap_, mmau, 
   {{0x7bccc1a9,0x63a0c1aa,0x9f5c13d5,0xd8740c75}},	//   lmau, _ajon, vrtý_, _قازب, 
   {{0xf868c1ab,0x63a002d3,0x0574c1ac,0x27440153}},	//   _عمري_, _bjon, خاند, _sūnų_, 
   {{0xaaac0037,0xe430009f,0xc1780064,0x00000000}},	//   _झुँक, افيد, ekė_, --, 
   {{0x63a0c1ad,0x7bcc2306,0x332c0327,0x00000000}},	//   _djon, imau, rfex_, --, 
   {{0x7bcc0086,0x63a0c1ae,0xf0641768,0xf1b800f3}},	//   hmau, _ejon, екоп, kuše_, 
   {{0x7bcc08cd,0x63a0c1af,0x00000000,0x00000000}},	//   kmau, _fjon, --, --, 
   {{0xa3c0023e,0xf1b89a24,0x63a00023,0x637c0064}},	//   ूषण_, duše_, _gjon, kūny, 
   {{0x7bcc0036,0x24880023,0x7e0000c7,0x2b5c0051}},	//   dmau, _ንቕሓት_, аҧыз, _đtc_, 
   {{0x66d40365,0x6140c1b0,0x63a0025c,0x00000000}},	//   _hükü, _беша, _zjon, --, 
   {{0xdca0c1b1,0xfd6802e3,0x66d421d8,0xddc0a2ae}},	//   гари, _hapụ, _kükü, убри, 
   {{0x7bcc0004,0xeb98036b,0xae04030c,0xf3f000cc}},	//   gmau, чиб_, _كوبى, _ঘটাৰ_, 
   {{0x66d406be,0xd9e0000d,0x3a28013d,0x6f04010e}},	// [fda0] _mükü, _कूदत_, метү_, makc, 
   {{0x6f04c1b2,0xfd6801f2,0x7bcc0618,0xf1b8013a}},	//   lakc, _mapụ, amau, buše_, 
   {{0xe738088b,0xb9b40395,0x00000000,0x00000000}},	//   зее_, тстъ, --, --, 
   {{0x66e4188c,0x6f040115,0x7c940022,0x00000000}},	//   хода, nakc, _шрыц, --, 
   {{0xe4e40212,0x00000000,0x00000000,0x00000000}},	//   нійн, --, --, --, 
   {{0x63a00225,0x9f5c00d8,0x6b94022e,0x00000000}},	//   _sjon, istá_, liyg, --, 
   {{0xf1b81ebd,0x63a0c1b3,0xb92402e3,0x66d40c44}},	//   ntšu_, _pjon, hapụ_, _bükü, 
   {{0x6b94022e,0x96600139,0x00000000,0x00000000}},	//   niyg, ткәе, --, --, 
   {{0x6f04c1b4,0x38540092,0x00000000,0x00000000}},	//   dakc, _የሚሰጥ, --, --, 
   {{0xfd6801f2,0xc1780006,0x6720005f,0x6b94022e}},	//   _dapụ, ukė_, lgoj, hiyg, 
   {{0x2cb80477,0x6f04c1b5,0x63a0c1b6,0xc1780024}},	//   _nypd_, fakc, _tjon, rkė_, 
   {{0x6720c1b7,0x63a01cdf,0xf1b8c1b8,0x23281985}},	//   ngoj, _ujon, vuše_, _ходи_, 
   {{0x9f5c04cc,0x67200ff8,0x6b9401d5,0x8d780092}},	//   rstà_, igoj, diyg, _ያለችው_, 
   {{0x22440214,0x403400c7,0x7ec800e2,0xd24c1fb8}},	//   _isok_, _аекс, _rūpī, _دنه_, 
   {{0x61e00664,0x0ca8c1b9,0x66d42fbe,0x4c68013e}},	//   _huol, етти_, _yükü, ниён_, 
   {{0x61e0c1ba,0x213cc1bb,0x201cc1bc,0x7bcc04c9}},	//   _kuol, leth_, muti_, umau, 
   {{0x9ad001f2,0x4fd80302,0xfdc80075,0x67201710}},	// [fdb0] _bịaa, _אוהב_, _отоқ_, dgoj, 
   {{0x8478044e,0x61e001d5,0x7bccc1bd,0xf1b816a3}},	//   ክራስን_, _muol, smau, puše_, 
   {{0x61e0c1be,0x6b94022e,0x213c0142,0xbf88002b}},	//   _luol, biyg, ieth_, _śeṣa_, 
   {{0x22440438,0x213cc1bf,0x5fb0190c,0xe8000037}},	//   _osok_, heth_, ीतिल, _लबरा_, 
   {{0x201cc1c0,0x61e05067,0x6b98067c,0x66d4496e}},	//   huti_, _nuol, ètge, _rükü, 
   {{0x201c37ae,0x3834a3f8,0x3a380254,0x66d47b47}},	//   kuti_, _ингр, _ipsp_, _sükü, 
   {{0x201cc1c1,0x61e0c1c2,0x2244c1c3,0xcec401ef}},	//   juti_, _auol, _asok_, _kuří_, 
   {{0x201cc1c4,0x9f5c0122,0x2244020b,0x61e005d5}},	//   duti_, ystá_, _bsok_, _buol, 
   {{0x61e00c86,0x201c0100,0x6f0400ef,0x213c0142}},	//   _cuol, euti_, vakc, feth_, 
   {{0x201cc1c5,0x3a380ac5,0x61e001b9,0x6f04003e}},	//   futi_, _mpsp_, _duol, wakc, 
   {{0x201c3427,0x224460e7,0x6f0407d6,0x61e00393}},	//   guti_, _esok_, takc, _euol, 
   {{0x229059c7,0x213c0cfd,0x61e008f5,0x00000000}},	//   الیس, aeth_, _fuol, --, 
   {{0x201c0024,0x61e0c1c6,0x9c8000d0,0x6b94022e}},	//   auti_, _guol, áčni, viyg, 
   {{0x201cc1c7,0xbec4c1c8,0x116401b9,0x820c0327}},	//   buti_, ыңыз_, _سلبی_, _གྷྲི_, 
   {{0x201c6f0e,0x61e005d5,0x9c800219,0xb924063f}},	//   cuti_, _zuol, ščni, sapụ_, 
   {{0x6e9400c6,0xd1b803e6,0x3eac002e,0xee38009b}},	//   _للعا, _باڵا_, ékté_, _жни_, 
   {{0x7ec802b1,0xcfe001ec,0xdfcc01e2,0x6b94c1c9}},	// [fdc0] _pūpū, _ﺍﻟﻀﺒ, _بيي_, riyg, 
   {{0xdd8c0b6c,0xda6c0014,0x5980c1ca,0x00000000}},	//   _ووي_, غُل_, алуб, --, 
   {{0xd940010b,0x6d4c0158,0xe728014b,0x2bc801af}},	//   рехи, mdba, доед_, _олоп_, 
   {{0xeb9802bf,0x213cc1cb,0x3ea801d5,0xd9e0000d}},	//   _цим_, zeth_, _yxat_, _कूवत_, 
   {{0x6720c1cc,0x201c0311,0xdb1c0cad,0x00000000}},	//   rgoj, zuti_, _ìwád, --, 
   {{0x61e00801,0xcfe002dd,0xcec4013a,0x00000000}},	//   _ruol, _ﺍﻟﻁﺒ, _zuří_, --, 
   {{0x4394c1cd,0x61e0c1ce,0x213cc1cf,0x6d4c0112}},	//   лакс, _suol, veth_, idba, 
   {{0x61e00664,0x201cc1d0,0x213c013e,0x18a0785f}},	//   _puol, vuti_, weth_, _тасм, 
   {{0x201c043b,0x61e016b8,0x3a38020c,0x6d5cc1d1}},	//   wuti_, _quol, _xpsp_, _onpa, 
   {{0x61e006bb,0x6d4c0d27,0xa3e4033f,0x00000000}},	//   _vuol, jdba, _यूथ_, --, 
   {{0xd9180bd9,0x5dd80220,0x6d4c02d2,0x00000000}},	//   וויל, _ﺜﺎﻨﻴ, ddba, --, 
   {{0xd36c9fb1,0x6d5cc1d2,0x61e0049b,0x6d4cc1d3}},	//   _وهل_, _anpa, _tuol, edba, 
   {{0x201cc1d4,0x224422d0,0x213c00a9,0x2168013e}},	//   suti_, _usok_, peth_, _оиди_, 
   {{0x2174084c,0x6084007b,0x00000000,0x00000000}},	//   _шуер, _لشبك, --, --, 
   {{0x4034c1d5,0x3f9806af,0x11380375,0x00000000}},	//   _сейс, érus_, _חתול, --, 
   {{0x6d5cc1d6,0x3ea8009d,0xb24401af,0xf1b86e98}},	//   _enpa, _txat_, _рмәһ, muša_, 
   {{0xf1b873d0,0x7e98c1d7,0x00000000,0x00000000}},	// [fdd0] luša_, _سندر_, --, --, 
   {{0x7f4cc1d8,0x3f98c1d9,0x7c9400ae,0x00000000}},	//   _haaq, lisu_, _ملخص, --, 
   {{0x4d74495f,0x6fe000ef,0xf1b800d7,0x00000000}},	//   _خطير, _pēci, nuša_, --, 
   {{0x7d0403a2,0xed8802d3,0x00000000,0x00000000}},	//   _hehs, _ማለተይ_, --, --, 
   {{0x7bdcc1da,0x7aec859f,0x7f4c102c,0x6d5c000f}},	//   _iisu, mcat, _maaq, _ynpa, 
   {{0x7aecc1db,0xf1b81225,0x7bdcc1dc,0x3b08c1dd}},	//   lcat, kuša_, _hisu, laaq_, 
   {{0x7bdcc1de,0x38540020,0x7aecc1df,0x3f980548}},	//   _kisu, _የሚቆጠ, ocat, kisu_, 
   {{0x36d4c1e0,0x7d0406a3,0x3f980a73,0x3b08c1e1}},	//   _бобр, _lehs, jisu_, naaq_, 
   {{0x7bdcc1e2,0x9f5c049b,0x3f98c1e3,0xfee8015b}},	//   _misu, istä_, disu_, পরাধ, 
   {{0x7bdcc1e4,0x3b08c1e5,0x3724004b,0x7648c1e6}},	//   _lisu, haaq_, _جوړې, _isey, 
   {{0x7f4c0050,0x3b080140,0x136801b9,0x3f9800e8}},	//   _baaq, kaaq_, _ошди_, fisu_, 
   {{0x7bdcc1e7,0x32447f51,0x7f4c0014,0x3b08013c}},	//   _nisu, _منصف, _caaq, jaaq_, 
   {{0x260406ab,0x7f4c01d9,0xe1ec05f5,0x799401f5}},	//   सीपी_, _daaq, _ыг_, _omzw, 
   {{0x320cc1e8,0x9f5c02f6,0x7bdc04ce,0x7aec003a}},	//   msey_, estä_, _aisu, ecat, 
   {{0x7bdcc1e9,0x320cc1ea,0x3f98c1eb,0x7f4c0067}},	//   _bisu, lsey_, bisu_, _faaq, 
   {{0x7aec074d,0x7bdcc1ec,0x3f9808e5,0x3b080869}},	//   gcat, _cisu, cisu_, gaaq_, 
   {{0x320c05e5,0x5e5400ec,0xed580395,0xa9a4004e}},	// [fde0] nsey_, _مليس_, _зоп_, гиад, 
   {{0x6d5cc1ed,0x7aecc1ee,0xed44c1ef,0x7d040e78}},	//   _unpa, acat, _сноп, _gehs, 
   {{0x7f4cc1f0,0x7aecc1f1,0x7648b07e,0x7bdcc1f2}},	//   _yaaq, bcat, _asey, _fisu, 
   {{0xdc9805e1,0x7bdcc1f3,0x7994014b,0xa684c1f4}},	//   _טייל, _gisu, _emzw, ллед, 
   {{0xa28001ec,0xf1b800d7,0x7f8c00df,0x00000000}},	//   _ﺨﻁﺎﺒ_, zuša_, ונאַ, --, 
   {{0x7bdcc1f5,0x3f980921,0x00000000,0x00000000}},	//   _zisu, zisu_, --, --, 
   {{0x7648c1f6,0x7bdcc1f7,0x3f98043b,0xa2d428f5}},	//   _esey, _yisu, yisu_, मेन्, 
   {{0xf1b81b24,0x7bdc18f7,0xc2244d66,0xe9a40107}},	//   vuša_, _xisu, لکتو, _раҳп, 
   {{0x7790c1f8,0xd20405f5,0x86b40046,0x7f4c102c}},	//   _بینا, лээд_, _тәжі, _raaq, 
   {{0x7f4cc1f9,0x3f98c1fa,0x442c0789,0x3b082878}},	//   _saaq, wisu_, _tqd_, zaaq_, 
   {{0x4034c1fb,0x7aecc1fc,0x7d0457a0,0x9f5c049b}},	//   шенс, ycat, _rehs, ystä_, 
   {{0xf1b80552,0x7f4cc1fd,0xa2e40fc0,0x7d040112}},	//   ruša_, _qaaq, _содд, _sehs, 
   {{0x7bdcc1fe,0x3f98c1ff,0x7aec5edb,0xeff40023}},	//   _risu, risu_, vcat, _ገዛይ_, 
   {{0x7bdcc200,0x7f4c0a4d,0x3f98c201,0x7aec1d6f}},	//   _sisu, _waaq, sisu_, wcat, 
   {{0x7bdcc202,0x3b08c203,0x7aecc204,0x7f4cc205}},	//   _pisu, taaq_, tcat, _taaq, 
   {{0x9ad001f2,0x7bdc20ac,0x3f98c206,0x10100350}},	//   _fịla, _qisu, qisu_, _ابود, 
   {{0x7aecc207,0x7bdcc208,0x3b08c209,0x7d0403e3}},	// [fdf0] rcat, _visu, raaq_, _tehs, 
   {{0x7bdcc20a,0x3b08c20b,0xe0e000cc,0x00000000}},	//   _wisu, saaq_, _য়ুন, --, 
   {{0x7bdcc20c,0x7e980050,0x394004cc,0x7aecc20d}},	//   _tisu, _سنگر_, rehs_, pcat, 
   {{0x3b08c20e,0x7bdcc20f,0x320c01d9,0x290cc210}},	//   qaaq_, _uisu, ysey_, ófar_, 
   {{0xda640fb4,0x4ba8013d,0xf5049607,0x00000000}},	//   _صاحي, _сөрү_, азло, --, 
   {{0x5ec40c58,0x799401f0,0x95e000cf,0x00000000}},	//   _এলাই, _umzw, _ۇيرۇ, --, 
   {{0x26044142,0x00000000,0x00000000,0x00000000}},	//   सीबी_, --, --, --, 
   {{0x7648c211,0x320cc212,0x323450ce,0x35f40108}},	//   _tsey, tsey_, ахос, _впар, 
   {{0x76480107,0xa90801a9,0x00000000,0x00000000}},	//   _usey, mkоr, --, --, 
   {{0x71583129,0x200000f3,0x25e801ad,0x9d240154}},	//   трис_, ćkin_, _चढती_, য়ুন_, 
   {{0x320c0731,0xde8c063f,0xefc802a9,0x00000000}},	//   ssey_, sịla_, клол_, --, 
   {{0x320c0af9,0x00000000,0x00000000,0x00000000}},	//   psey_, --, --, --, 
   {{0xcfe001ec,0x00000000,0x00000000,0x00000000}},	//   _ﺍﻟﻌﺒ, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x1d04c213,0x9d240154,0x00000000,0x00000000}},	//   реси_, য়ূন_, --, --, 
   {{0xdca002bf,0x9f5c0efa,0x2604121d,0x5f9000d8}},	//   іати, tstå_, सीडी_, _мијт, 
   {{0x5f741564,0x6da400d6,0xada400f3,0xed340064}},	// [fe00] _خميس_, _випа, _вапл, _кэнэ, 
   {{0x9e780375,0x80cc00c5,0x78a80055,0xed58005a}},	//   _סניפ, _हरमे, _śeva, _роо_, 
   {{0xa6e4084c,0x27e401e4,0x684400d8,0x00000000}},	//   ажел, ĉono_, рнеа, --, 
   {{0x9f5c5243,0xf1b800e2,0x2d88014f,0x1864399f}},	//   pstå_, kušo_, lhbe_, јаци_, 
   {{0xf1b8005f,0xde2c0023,0x00000000,0x00000000}},	//   jušo_, _እዋናው, --, --, 
   {{0x5e5400c8,0xe8680023,0x7c640244,0xf1b800de}},	//   יינע_, _ተዋሂቡ_, _ئایل, dušo_, 
   {{0x18640131,0x69cc014f,0x6f1403ac,0x0458007b}},	//   _кари_, _ihbe, _odyc, البة_, 
   {{0x58f06d7e,0x9cd4011a,0xd4640114,0x53f4007b}},	//   _བཅོས_, סוקה_, риће_, جروح_, 
   {{0xf1b800e2,0x171800d9,0x8af003b9,0x00e40066}},	//   gušo_, _שומע, mdəd, یتگی, 
   {{0x64980032,0x8af003b9,0x00000000,0x00000000}},	//   _итер_, ldəd, --, --, 
   {{0x53dc01ad,0x2d8801e7,0x00000000,0x00000000}},	//   _पंचश, dhbe_, --, --, 
   {{0xf1b8c214,0x6458c215,0x8af003be,0xc3300014}},	//   bušo_, _irti, ndəd, _رٕت_, 
   {{0x3eacc216,0x644c145e,0x6f140368,0x69cc047e}},	//   çet_, _âbib, _ddyc, _ohbe, 
   {{0xd12c7a3f,0x6f140034,0x58f0031c,0x1278008f}},	//   _يمن_, _edyc, _བཅེས_, _באדע, 
   {{0x8af00213,0xd0f4011a,0x00000000,0x00000000}},	//   kdəd, _דמות_, --, --, 
   {{0xdb20c217,0x201c07f5,0x69cc00a2,0xd080084c}},	//   توری, mrti_, _ahbe, _фыши, 
   {{0x3914c218,0x3d940a93,0x8af003e3,0x00000000}},	// [fe10] ймар, _гипр, ddəd, --, 
   {{0x6458c219,0xd7f8727e,0x69cc0076,0x6b840ea0}},	//   _orti, вуд_, _chbe, _elkg, 
   {{0x6f140cfd,0x7e7c33d5,0x38340354,0xa2d400cd}},	//   _ydyc, lysp, снер, मेत्, 
   {{0x30d800c8,0x69cc009d,0x201cc21a,0x1034008f}},	//   אַנע, _ehbe, irti_, שטאם_, 
   {{0x98a40c07,0x7e7cc21b,0x92e400fe,0x00000000}},	//   ını_, nysp, ভৰু_, --, 
   {{0xd90c7c12,0x9f5c002d,0xf7c000d1,0x00000000}},	//   _آیا_, tstû_, ﺭﯨﻜﻪ, --, 
   {{0x64582804,0xd7f810fc,0x97840354,0x8af003b9}},	//   _crti, _југ_, _вăйă_, bdəd, 
   {{0x645800bc,0xf348399b,0x69cc0200,0xb9e00092}},	//   _drti, упил_, _zhbe, _ኧረ_, 
   {{0x6458c21c,0x201cc21d,0xd67c06ba,0x00000000}},	//   _erti, erti_, ﯩﻠﻪﺭ_, --, 
   {{0x7790c21e,0x057436e7,0x95c800d1,0xd4982cc8}},	//   _بیچا, _والد, _руба_, _ире_, 
   {{0xed58c21f,0x201c003e,0x395000e2,0xb64001ec}},	//   қов_, grti_, _mazs_, _ﺃﻫ_, 
   {{0x09dc025c,0x7e7c0857,0x3494014b,0x00000000}},	//   _ལངྐ_, fysp, _каҷр, --, 
   {{0x201cc220,0x9ad00521,0x7e7c02d0,0x6f1400d7}},	//   arti_, _dịka, gysp, _vdyc, 
   {{0xa3e42122,0x98a40118,0x3078007b,0x64580108}},	//   _यूँ_, ýně_, _محبة_, _yrti, 
   {{0x6ff40aaa,0x201c01a6,0xceb8012d,0x00000000}},	//   _استط, crti_, łę_, --, 
   {{0x58f0025c,0x7e7c2963,0xdca0036b,0x6fb42984}},	//   _བཅུས_, bysp, часи, _دمعا, 
   {{0x395004cc,0x7e7c035a,0xe808810b,0x00000000}},	// [fe20] _bazs_, cysp, हीना_, --, 
   {{0x1af40183,0xa90800cf,0xed5801c4,0x00000000}},	//   েলগে_, ايال_, _ёон_, --, 
   {{0x6e242296,0x2d98003a,0xa3e40034,0x00000000}},	//   lukb, _impe_, _यूं_, --, 
   {{0xdc3800c8,0xf72802bf,0x249806be,0x60b8010f}},	//   _געטר, ицій_, _üzmə_, אצעד, 
   {{0x8af00213,0x00000000,0x00000000,0x00000000}},	//   rdəd, --, --, --, 
   {{0x2d9805b1,0x64580427,0x09dc0327,0x00000000}},	//   _jmpe_, _prti, _ལངྒ_, --, 
   {{0x6e240280,0x19840588,0x43940b2c,0x7e7c033f}},	//   hukb, _убри_, жайс, zysp, 
   {{0x64585ed6,0xadf81025,0x27e8017a,0x29082f13}},	//   _vrti, ्ठान_, _iubn_, _heba_, 
   {{0x2908c221,0x2d9801af,0xa6840953,0x20000e3c}},	//   _keba_, _ompe_, _улад, ćkim_, 
   {{0x21641d83,0x64a4b2bd,0xc014082d,0x201c0219}},	//   стиг, _лаза, омощ, trti_, 
   {{0x64c4c222,0x21748af9,0xdb0c00dd,0x2908013f}},	//   _ايال, _қудр, ődés, _meba_, 
   {{0x2908c223,0x2d98c224,0x7e7cc225,0x1e700116}},	//   _leba_, _ampe_, tysp, зғис, 
   {{0x3d04012c,0xac88001f,0xcfe00220,0x6e2400e5}},	//   वरले_, ነዚህም_, _ﺍﻟﻜﺒ, gukb, 
   {{0x3ce40c58,0x201c09a8,0xa3c00764,0x52d4011a}},	//   ølv_, prti_, ूषक_, _הודע_, 
   {{0x395005d5,0x7e7c02d0,0x00000000,0x00000000}},	//   _razs_, sysp, --, --, 
   {{0x2d98c226,0x6e24c227,0x8fa4147e,0x61f400a2}},	//   _empe_, bukb, _наје, _çyls, 
   {{0x2908041a,0x3f88c228,0x6e24003e,0x2ec000db}},	// [fe30] _beba_, _ilau_, cukb, _жөрм, 
   {{0x3f880070,0x2908c229,0x25bc0083,0xa0600023}},	//   _hlau_, _ceba_, _nktl_, _ፈተነታ, 
   {{0x2908c22a,0x260403ce,0x00000000,0x00000000}},	//   _deba_, सीसी_, --, --, 
   {{0x9f5c03b2,0x588401e0,0x1fa800fe,0x9b24011c}},	//   gstø_, _һыба, _গীতস, _уфол, 
   {{0x290801ee,0xbd900020,0x3668c22b,0xf6240212}},	//   _feba_, _ማለትም_, рало_, ідко, 
   {{0x2908c22c,0xce380302,0x33f455ee,0x3f880142}},	//   _geba_, צאות_, очис, _llau_, 
   {{0xb4e40241,0xa2d405d7,0x3f88c22d,0x00000000}},	//   _afàì, मेस्, _olau_, --, 
   {{0x6e24c22e,0x844400d1,0x00000000,0x00000000}},	//   yukb, سخىل, --, --, 
   {{0x2908c22f,0x8af003b9,0x00000000,0x00000000}},	//   _yeba_, ldəc, --, --, 
   {{0x3f881509,0x2908c230,0xd58403e6,0x00000000}},	//   _alau_, _xeba_, _دێته_, --, 
   {{0x6fa80063,0x94a82bb6,0x8af003e3,0x00000000}},	//   ивог_, _стаа_, ndəc, --, 
   {{0x3f88c231,0x2d9801f9,0xa8540375,0xaf98009d}},	//   _clau_, _smpe_, קירה_, ртох_, 
   {{0x3f880218,0x92b4c232,0xe020043b,0xe7e0000d}},	//   _dlau_, _احضا, ɔ́mí_, _औंघा_, 
   {{0x3f880607,0x1d04bd91,0x973400c0,0xdd8c2162}},	//   _elau_, жери_, _вiчы_, پوف_, 
   {{0x2908c233,0x6e24c234,0x3f88c235,0x91c005a2}},	//   _reba_, sukb, _flau_, _мәүл, 
   {{0x2908c236,0xef842ded,0x6a846e17,0x3f8875d3}},	//   _seba_, _флип, олба, _glau_, 
   {{0x2908014f,0x00000000,0x00000000,0x00000000}},	// [fe40] _peba_, --, --, --, 
   {{0xada4006c,0x2d98b8b7,0x645c0fac,0xbd900240}},	//   _фаол, _umpe_, åpik, _ማለቶም_, 
   {{0xa8180372,0x212801ab,0x25bc0108,0x29080205}},	//   شتار_, òbhi_, _rktl_, _veba_, 
   {{0xe738c237,0x2908c238,0x00000000,0x00000000}},	//   ред_, _weba_, --, --, 
   {{0x2908c239,0x81c000fe,0x9f5c03cd,0x20d40037}},	//   _teba_, ংগত_, rstø_, _ठण्ढ, 
   {{0xa2d84ff1,0x58f00f50,0x9e5800df,0x00000000}},	//   _पृष्, _བཅགས_, יכנט, --, 
   {{0xefc80023,0xb5a8007b,0x9f5c0162,0x00000000}},	//   _በጊዕ_, حانك_, pstø_, --, 
   {{0x579400c7,0x6448c23a,0x42745a52,0x57f80115}},	//   _дыуӡ, rwfi, згис, _כללו, 
   {{0x67d4010b,0xa1a81429,0x25682503,0x96540064}},	//   _гоңу, итоз_, _каап_, _нiбы_, 
   {{0xb61802dd,0xa2d400cd,0xbb300150,0x1a9800df}},	//   _ﹼﺩ_, मेष्, _ﺭﺴﻡ_, ייפע, 
   {{0x3f88c23b,0x6fe000e2,0x00000000,0x00000000}},	//   _plau_, _pēcp, --, --, 
   {{0x2fd000a2,0x01a814fb,0x00000000,0x00000000}},	//   _chyg_, ркүк_, --, --, 
   {{0xa2d435e0,0x2364010f,0x81f80214,0xe80807b6}},	//   मेश्, _inoj_, _افتر_, हीता_, 
   {{0x009401c0,0x236402f0,0xbb580022,0x00000000}},	//   _нилэ, _hnoj_, әаах_, --, 
   {{0x50d000cf,0xbf1001af,0x00000000,0x00000000}},	//   _ۉزۉر, _пүнә, --, --, 
   {{0x58f00003,0x8af800ac,0x79f4036b,0xdef8081b}},	//   _བཅངས_, _şərq, ззах, _тык_, 
   {{0x5d380354,0x00000000,0x00000000,0x00000000}},	// [fe50] _кунĕ, --, --, --, 
   {{0x98c411f4,0xe00c012d,0x00000000,0x00000000}},	//   осел, _ाबाद_, --, --, 
   {{0x23640b91,0xa3e44da4,0x9f580241,0x00000000}},	//   _onoj_, _यंग_, _ìpó_, --, 
   {{0x20000fcf,0xc79401e2,0x00000000,0x00000000}},	//   ćkih_, وشنب, --, --, 
   {{0xaaf4159d,0x7aec00b0,0x00000000,0x00000000}},	//   _מזרח_, āitā, --, --, 
   {{0x2364008f,0xa3e400dc,0xa5041606,0x8af803b9}},	//   _anoj_, पदं_, пеша_, _çərp, 
   {{0x80e02158,0x3a282ebc,0x7984c23c,0x17680120}},	//   পুত্, luap_, mkhw, _крап_, 
   {{0xf1b800e2,0x00000000,0x00000000,0x00000000}},	//   muši_, --, --, --, 
   {{0x3a28013c,0xa2d43885,0x00000000,0x00000000}},	//   nuap_, मेल्, --, --, 
   {{0x23640115,0x79840925,0x0f040807,0xf59407fc}},	//   _enoj_, nkhw, लर्स_, _علاج, 
   {{0xd49817d0,0x7984009a,0x3a280098,0xd0000022}},	//   _тра_, ikhw, huap_, ьонқ, 
   {{0x3dc0009a,0x23645160,0xb4c808f2,0xe45400df}},	//   _akhw_, _gnoj_, ोधी_, _מיעט_, 
   {{0x826494d2,0x1e80524d,0x20306467,0xb62c00b5}},	//   _يهمن, елям, وفیس, _ｒｆ_, 
   {{0xf1b8005f,0xac0805f5,0x98b00118,0x8af00213}},	//   kuši_, йнга_, ádět_, ddəa, 
   {{0xf1b80029,0x41740ed1,0xad241a50,0x9f880241}},	//   juši_, _تانس, يىڭى, bùà_, 
   {{0x661402d5,0x33f0a896,0x798401e2,0xf1b8c23d}},	//   šyki, _máx_, ekhw, duši_, 
   {{0xada4c23e,0xaac40214,0x50a000d1,0x00000000}},	// [fe60] _наил, سترن, _رەڭل, --, 
   {{0x6c5401af,0x9f580248,0x00000000,0x00000000}},	//   _етмє, _ìpò_, --, --, 
   {{0x98a0c23f,0xf1b800e2,0x81800092,0x684401c4}},	//   нифе, guši_, _ይገባሉ_, янжа, 
   {{0xad24129d,0xbbe8c240,0xd1f40023,0xc0ac010f}},	//   _بىگى, _گریم_, _ገጻት_, סיאָ, 
   {{0x83fc01a6,0x332c01ab,0x00000000,0x00000000}},	//   _mrđe, dgex_, --, --, 
   {{0xbbe8182f,0x23640010,0xf1b800ef,0x00000000}},	//   _دریم_, _snoj_, buši_, --, 
   {{0xc44870c8,0x88841a69,0x19840166,0x2794030d}},	//   تیان_, _تیان, _эбри_, _ешар, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x63c001e0,0xe61800c7,0xb35412fd,0xa6840354}},	//   маҫҡ, _ыда_, بینا_, _элад, 
   {{0x25a8bd5e,0x00000000,0x00000000,0x00000000}},	//   _ادري_, --, --, --, 
   {{0x65783b17,0xa0a40276,0x00000000,0x00000000}},	//   _ioth, яшил, --, --, 
   {{0x6578c241,0x00000000,0x00000000,0x00000000}},	//   _hoth, --, --, --, 
   {{0x6578c242,0xa18400fd,0x2e34032e,0x00000000}},	//   _koth, _ныкл, gæf_, --, 
   {{0xd12c168d,0x6578047e,0x528000db,0x9da802e8}},	//   _ممه_, _joth, _سلىك, съма_, 
   {{0x6578c243,0x00000000,0x00000000,0x00000000}},	//   _moth, --, --, --, 
   {{0x8bc4c244,0xf1b8005f,0x83fc01a6,0x3a280140}},	//   есуд, vuši_, _grđe, tuap_, 
   {{0xf9780e92,0x6578c245,0xe8080073,0xce68010a}},	// [fe70] обај_, _ooth, हीसा_, _ерэд_, 
   {{0x6578c246,0x3a2805b1,0xf1b800e2,0x77b80166}},	//   _noth, ruap_, tuši_, _mäxş, 
   {{0x3a28c247,0x8af003b9,0x00000000,0x00000000}},	//   suap_, mdən, --, --, 
   {{0xe7941a69,0xe3f4019b,0xf1b800de,0x65780208}},	//   وانک, dケ_, ruši_, _aoth, 
   {{0xcd34c248,0xf1b88a8a,0x26c00158,0x6578b178}},	//   _غریب, suši_, _økol_, _both, 
   {{0x65780ea3,0x33f01709,0xceb4008f,0x09e402d5}},	//   _coth, _páx_, עיס_, _поўн, 
   {{0x6578c249,0xceb403e3,0xe4fc000d,0x00000000}},	//   _doth, _ndən_, _उभरि_, --, 
   {{0xb9cc044e,0x9f5c0407,0x6578119f,0x630000d1}},	//   _ቶም_, istó_, _eoth, نۈمل, 
   {{0x657807f0,0x8af003b9,0x00000000,0x00000000}},	//   _foth, kdən, --, --, 
   {{0x2978008f,0xf1a80244,0x33f000d7,0x8af006be}},	//   ַטרא, تاعه_, _táx_, jdən, 
   {{0x80e0009e,0xbef80073,0x9f5c0174,0x63ac00ae}},	//   পুস্, ंडून_, sstý_, úiné, 
   {{0x657849e1,0x00000000,0x00000000,0x00000000}},	//   _zoth, --, --, --, 
   {{0xceb40cc1,0x6578c24a,0x8af006be,0xe714011a}},	//   _edən_, _yoth, fdən, וחרר_, 
   {{0x2d9c0699,0x2e341b25,0x00000000,0x00000000}},	//   òte_, ræf_, --, --, 
   {{0x77686b53,0xec1400db,0xa19000d8,0x00000000}},	//   _onex, بوزد, _јајч, --, 
   {{0xca80022e,0x7d00c24b,0x00000000,0x00000000}},	//   аtаd, ılsa, --, --, 
   {{0xed58c24c,0x7d180332,0x8af006be,0x00000000}},	// [fe80] _доп_, éasó, bdən, --, 
   {{0x776812c9,0x8af003b9,0x00000000,0x00000000}},	//   _anex, cdən, --, --, 
   {{0x6578c24d,0x2d080574,0x6d680066,0xa84892af}},	//   _roth, वरील_, _همکف_, تلام_, 
   {{0xc5f8c24e,0xeb500228,0x6ac4007b,0xa6c800d8}},	//   зға_, _جۉرگ, _يقدم, олеа_, 
   {{0x6578c24f,0xe9d898a4,0x9f4c00d8,0xfa7c0092}},	//   _poth, _мкм_, _bufê_, _የመኖር_, 
   {{0x7768c250,0x6578c251,0xa3e4033f,0x291401f7}},	//   _enex, _qoth, _यूज_, _زورآ, 
   {{0x9f5c011c,0xd464026a,0xf1b801fa,0xa8040006}},	//   istò_, дије_, nušu_, _ізал, 
   {{0x6578c252,0xb5fcc253,0xd99400db,0x93a000db}},	//   _woth, _srše, _ىچەت_, кшыд, 
   {{0x6578c254,0xb5fc2438,0xda78010f,0x00000000}},	//   _toth, _prše, ַנטר, --, 
   {{0x6600c255,0x25640014,0x9f5c06af,0x77b80139}},	//   mpok, _تارُ, mpté_, _växş, 
   {{0x66001028,0xb5fc0fcf,0xf3c800aa,0x4438995d}},	//   lpok, _vrše, _کبله_, _ër_, 
   {{0x835404fb,0x6600009f,0x160802ab,0x6ee4335b}},	//   _سپتا, opok, सीवर_, کسپل, 
   {{0x660001c0,0xf1a804d3,0x6fe0003a,0xb5fc0010}},	//   npok, _کانه_, _mœch, _trše, 
   {{0xd24c04d3,0x6600c256,0xa3e40b6d,0x32084dd9}},	//   _خنه_, ipok, पदक_, _çaya_, 
   {{0x2b40070d,0xb5fc01fa,0xfb880116,0x4c680107}},	//   _bbkc_, _kršc, прақ_, миён_, 
   {{0x6600c257,0x213c23bd,0x00000000,0x00000000}},	//   kpok, lfth_, --, --, 
   {{0xc68400aa,0x77680003,0xc4c401d9,0x6600013a}},	// [fe90] _ئې_, _rnex, _چے_, jpok, 
   {{0xc4c455c1,0x660005dd,0x22440263,0xf1b80171}},	//   _نے_, dpok, _mpok_, bušu_, 
   {{0x7d14b580,0x660000df,0xe8080073,0x98c401d5}},	//   mazs, epok, हीला_, фсал, 
   {{0x8af003be,0xb78800fd,0x00000000,0x00000000}},	//   ndəl, чәге_, --, --, 
   {{0x6600c258,0x7768001e,0x06080006,0xdb1c0200}},	//   gpok, _vnex, днік_, hoqë, 
   {{0x6fd40030,0x47880139,0x00000000,0x00000000}},	//   máce, зсәм_, --, --, 
   {{0x224406d9,0x6fd40118,0x66000588,0x00000000}},	//   _apok_, láce, apok, --, 
   {{0x7768c259,0xd6d80153,0x8af003b9,0x00000000}},	//   _unex, _дтз_, jdəl, --, 
   {{0xb5c8c25a,0x8af000ac,0x6fd45b84,0x32180129}},	//   _فورم_, ddəl, náce, ésy_, 
   {{0x300458e5,0x00000000,0x00000000,0x00000000}},	//   нзог, --, --, --, 
   {{0x2244c25b,0x00000000,0x00000000,0x00000000}},	//   _epok_, --, --, --, 
   {{0x73d809a5,0xf1b801a6,0x6fd4013a,0x00000000}},	//   _эдер_, vušu_, káce, --, 
   {{0xe28cc25c,0xace8377b,0x00000000,0x00000000}},	//   _са_, змга_, --, --, 
   {{0x83fc0841,0x3cf400d0,0x00000000,0x00000000}},	//   _hrđa, _ľavý_, --, --, 
   {{0xf3f0063f,0x66000219,0x7ae8013f,0x614000a7}},	//   _jụ_, zpok, ɛmtɛ, _сеща, 
   {{0x66001caa,0xf1b8c25d,0x9f5c0129,0x8af003b9}},	//   ypok, rušu_, ypté_, cdəl, 
   {{0x25ac0204,0x00000000,0x00000000,0x00000000}},	// [fea0] ynfl_, --, --, --, 
   {{0xf1b8bc36,0x5e54010f,0x8af006be,0x00000000}},	//   pušu_, _טיפע_, mdəm, --, 
   {{0x6d4cc25e,0x66000618,0xebe413d6,0x66741fb8}},	//   meba, wpok, _пооп, کدار, 
   {{0x6d4cc25f,0x6fd400d8,0x6600007c,0x00000000}},	//   leba, báce, tpok, --, 
   {{0xe5c4c260,0xe5a404a9,0x3d040574,0x6fd40077}},	//   нско, ниди, वरचे_, cáce, 
   {{0xf3f001f2,0x6d4cc261,0x2d8801d3,0x00000000}},	//   _bụ_, neba, nkbe_, --, 
   {{0x6844c262,0x83fc110c,0x66001718,0x974000f3}},	//   _янва, _brđa, spok, šćar, 
   {{0x6d4cc263,0x6600c264,0xceb403e3,0xf3f00208}},	//   heba, ppok, _adəm_, _dụ_, 
   {{0xb5fc0114,0xd62401af,0x00000000,0x00000000}},	//   _vršc, _поте_, --, --, 
   {{0x6d4c70b1,0x3074044e,0x98a4033f,0x9f4c0240}},	//   jeba, _ክመጽእ_, żną_, _tufë_, 
   {{0x6d4cc265,0x69dcc266,0x93c801d9,0x6edc00bc}},	//   deba, impe, _کالہ_, नेसँ, 
   {{0xceb406be,0x7d14007f,0xa9bc012d,0x1070187f}},	//   _edəm_, wazs, ्तुए, улюю, 
   {{0x63a0c267,0x443cc268,0xb5fc01a6,0xd384311c}},	//   _imon, ltv_, _krša, _яйце_, 
   {{0x63a00070,0xf1a80451,0x6fd40118,0x00000000}},	//   _hmon, _ٺاهه_, váce, --, 
   {{0x3ce40628,0xb5fc2d2b,0x443cc269,0x61e8009a}},	//   älv_, _mrša, ntv_, _iifl, 
   {{0xa3c0375c,0xf2141d15,0x69dc00f1,0x6fd40005}},	//   ृति_, _दौड़_, empe, táce, 
   {{0x63a0c26a,0x443c0051,0xda7800d1,0x8af006be}},	// [feb0] _mmon, htv_, чяв_, cdəm, 
   {{0x6d4c0483,0x63a0089c,0x6fd4012c,0x61e8025c}},	//   ceba, _lmon, ráce, _jifl, 
   {{0x61e8c26b,0xa3c01cba,0x38340022,0x443c3c52}},	//   _mifl, ृता_, тнер, jtv_, 
   {{0x69dcc26c,0xf3f0063f,0x61e80b97,0x97c433d2}},	//   ampe, _rụ_, _lifl, رتام, 
   {{0x7bccc26d,0x8d74c26e,0xb5fc01a6,0x61e801ab}},	//   mlau, _شایا, _brša, _oifl, 
   {{0x83fc597f,0x63a0c26f,0x61e8031c,0x3a28034c}},	//   _srđa, _amon, _nifl, mrap_, 
   {{0x63a0008e,0xc514009f,0x48e4022e,0x00000000}},	//   _bmon, ابهت, _боёв, --, 
   {{0x7bccc270,0xf3f001fb,0x6d4cc271,0x63a0c272}},	//   nlau, _vụ_, zeba, _cmon, 
   {{0x6d4cc273,0x63a00204,0x3a280649,0x00000000}},	//   yeba, _dmon, nrap_, --, 
   {{0x63a0c274,0x443cc275,0x7bccc276,0x7648c277}},	//   _emon, btv_, hlau, _ipey, 
   {{0x7bccc278,0x443cc279,0x6d4cc27a,0x7afcc27b}},	//   klau, ctv_, veba, _ofst, 
   {{0x301406e7,0x7bcc0211,0x3a280ea0,0x63a0009f}},	//   ндүр, jlau, krap_, _gmon, 
   {{0x61e8c27c,0x277400c8,0x7bccc27d,0x3f980240}},	//   _fifl, דערש_, dlau, ërua_, 
   {{0x7afcc27e,0x63a0c27f,0x7648009a,0x61e8c280}},	//   _afst, _zmon, _mpey, _gifl, 
   {{0x6d4cc281,0x7bccc282,0x6b582d31,0x51500116}},	//   reba, flau, мшар_, _атқу, 
   {{0x7bccc283,0xaf34c284,0xdcac1a59,0x22bc01f2}},	//   glau, _شربت, زىق_, ịke_, 
   {{0x3a28c285,0x6d4cc286,0x70d000bc,0x8af003e3}},	// [fec0] grap_, peba, _हरुल, ldək, 
   {{0x6d4cc287,0x7afc0008,0x7bcc1e76,0x443c0208}},	//   qeba, _efst, alau, ytv_, 
   {{0x8af003be,0x3a280652,0x7afc003e,0x7bcc1f05}},	//   ndək, arap_, _ffst, blau, 
   {{0x7bccc288,0x3a2800ca,0x6604010b,0x443c0051}},	//   clau, brap_, впда, vtv_, 
   {{0x63a001b9,0x3a28c289,0xbad40220,0xb5fc0419}},	//   _rmon, crap_, _біры, _prša, 
   {{0x63a000a7,0x443c037e,0x68440408,0xfa800116}},	//   _smon, ttv_, _инга, _уқум, 
   {{0xb5fc17a3,0x63a000b5,0x61e8c28a,0xf78400ee}},	//   _vrša, _pmon, _rifl, _өврү, 
   {{0x61e802e2,0x8af006be,0xe61001e2,0x00000000}},	//   _sifl, ddək, _نشئ_, --, 
   {{0x443cc28b,0x61e8bf7c,0xb5fc0010,0x1608033f}},	//   stv_, _pifl, _trša, सीआर_, 
   {{0x7bccc28c,0x443cc28d,0xceb403be,0xb5fc01a6}},	//   zlau, ptv_, _edək_, _kršn, 
   {{0xb4242ad9,0x7bcc00fd,0x9f5c005b,0x3374009d}},	//   _معنو, ylau, istö_, тгөр, 
   {{0x63a0c28e,0x7bcc0399,0x60c8017a,0x9a880240}},	//   _umon, xlau, _vyfm, _ጥርኑፍ_, 
   {{0x61e8c28f,0x4ea4035b,0xa2d800dc,0x52700133}},	//   _tifl, арра, _पृच्, _ناوز, 
   {{0x4034c290,0x1ee401b9,0x00000000,0x00000000}},	//   _бекс, _یوغی_, --, --, 
   {{0x3a2807d5,0x7bccc291,0x8af003e3,0x0c2401f4}},	//   wrap_, tlau, cdək, имён, 
   {{0xf1b80b91,0x3a28c292,0x7bccc293,0xe500a5cd}},	//   vrši_, trap_, ulau, रुति_, 
   {{0x7bccc294,0x040c015b,0x5fa00131,0x3b08031c}},	// [fed0] rlau, সূচী_, _مەھم, rbaq_, 
   {{0x7bccc295,0x391404d3,0x0a6802e8,0x67f80055}},	//   slau, اواز, ърси_, _sįja, 
   {{0x7648c296,0x6fd40030,0x7bccc297,0xd7f80107}},	//   _spey, láca, plau, фуз_, 
   {{0xd1e40020,0x6b940561,0x0708038b,0x3940037e}},	//   _ማየት_, chyg, نيمي_, sfhs_, 
   {{0x1670006c,0x8af00213,0x41b40b98,0xc8840139}},	//   шқар, zdək, ुवास, _peşä_, 
   {{0xc984252c,0xb8d80154,0x61f400a2,0xdb4c009f}},	//   _куси, _চর_, _çyly, _اَڏ_, 
   {{0x62840e38,0x15400032,0x4d7c00df,0x15ec0210}},	//   økon, геҙм, ורגע, _चढकर_, 
   {{0xa530008e,0x00000000,0x00000000,0x00000000}},	//   анәч, --, --, --, 
   {{0x6fd40789,0x7648002b,0x9f8801e1,0x00000000}},	//   jáca, _upey, bùú_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x0584c298,0xf334007b,0xafe422cb,0xb95401ec}},	//   _тутм, _مفاج, лоол, ткiз, 
   {{0x8f840131,0x8af000ac,0x00000000,0x00000000}},	//   рқил, rdək, --, --, 
   {{0x62240e56,0x9f5c0108,0x00000000,0x00000000}},	//   _مونە, ystö_, --, --, 
   {{0x6218010f,0x00000000,0x00000000,0x00000000}},	//   _טונק, --, --, --, 
   {{0x6b940cfd,0xa0640801,0xc0580022,0xb5fc0841}},	//   thyg, _баща_, _арыц_, _oršo, 
   {{0x71a48383,0xee38009b,0x00000000,0x00000000}},	//   _шаһз, _зни_, --, --, 
   {{0x612c022e,0xb5fc0306,0x00000000,0x00000000}},	// [fee0] _kеlа, _sršn, --, --, 
   {{0x6b94c299,0xed580e92,0xe7f401c0,0x6f1403e0}},	//   shyg, _џон_, гчдэ, _heyc, 
   {{0x6bd41f3c,0x6f14c29a,0x6d5cc29b,0x6b9403ac}},	//   _متحر, _keyc, _iapa, phyg, 
   {{0x6d5cc29c,0xb5fc05ce,0xeb98c29d,0x6f140455}},	//   _hapa, _vršn, _чим_, _jeyc, 
   {{0x6d5cc29e,0x9cb0034c,0x6f14047e,0x465801ca}},	//   _kapa, _نمیت, _meyc, талю_, 
   {{0x6f140784,0x6d5800e4,0xe9a4014b,0x00000000}},	//   _leyc, ôtah, _сагп, --, 
   {{0x2918c29f,0x6d5cc2a0,0x9440028e,0xb8d800fe}},	//   mapa_, _mapa, مپون, _চৰ_, 
   {{0x2918c2a1,0x6d5cc2a2,0x66e4324f,0x6f140076}},	//   lapa_, _lapa, _боба, _neyc, 
   {{0x1718008f,0xa1840661,0x29180356,0x230800f1}},	//   _רומע, гынл, oapa_, وتکي_, 
   {{0x6d5cc2a3,0x2918c2a4,0x41841884,0x6fd400d0}},	//   _napa, napa_, ртиғ, váca, 
   {{0xe048109c,0xd24c0050,0x6f140205,0x394456f8}},	//   رشده_, _ہۆٹ_, _beyc, _ölse_, 
   {{0x2918c2a5,0x6d5c3217,0xe1f8119e,0x62640efe}},	//   hapa_, _aapa, _згд_, _ماتق, 
   {{0x2918c2a6,0x645802c4,0x6284025a,0x93400262}},	//   kapa_, _hsti, äkod, _ынце, 
   {{0x6fd400d0,0x291800e4,0x00000000,0x00000000}},	//   ráca, japa_, --, --, 
   {{0x6d5cc2a7,0x2918c2a8,0x6fd40232,0x4c940f45}},	//   _dapa, dapa_, mácn, бирс, 
   {{0x6d5c0076,0x201cc2a9,0x6458c2aa,0x3b540120}},	//   _eapa, msti_, _msti, јкар, 
   {{0x3a747617,0x6d5cc2ab,0x291800fb,0x201cc2ac}},	// [fef0] шлар, _fapa, fapa_, lsti_, 
   {{0x6458c2ad,0x2918c2ae,0x52d4010f,0x80d80037}},	//   _osti, gapa_, רומע_, _डराइ, 
   {{0x201cc2af,0x6458c2b0,0x98a003b9,0x229801e1}},	//   nsti_, _nsti, _pajı_, _yàké_, 
   {{0x3f980007,0x00000000,0x00000000,0x00000000}},	//   nhsu_, --, --, --, 
   {{0x6d5cc2b1,0x2918c2b2,0x62840158,0x6d6403b2}},	//   _yapa, bapa_, økol, _øtað, 
   {{0x201cc2b3,0x6d5c004e,0x6fd402f0,0x35c8011c}},	//   ksti_, _xapa, jácn, ъгло_, 
   {{0x73340075,0x7994009a,0x7bdc003e,0xa3c00882}},	//   لىغا, _ilzw, _khsu, ृतं_, 
   {{0xb2240131,0xb384c2b4,0x645800b5,0x00000000}},	//   амил, рлил, _dsti, --, 
   {{0x6458c2b5,0x6f140113,0x00000000,0x00000000}},	//   _esti, _reyc, --, --, 
   {{0x6f14c2b6,0xd49815ed,0x74a8013d,0x22980241}},	//   _seyc, _пре_, _исең_, _sàké_, 
   {{0x05b40014,0x201cc2b7,0x2be40073,0x73386b01}},	//   _دۯوت_, gsti_, _कळलं_, _азер_, 
   {{0x6d5cc2b8,0x93e407d6,0xa3c000dc,0x22bc01f2}},	//   _sapa, _сўзл, ृतः_, ịka_, 
   {{0x2918c2b9,0x201c049b,0x6d5c62bc,0x40781411}},	//   yapa_, asti_, _papa, _ەلىڭ_, 
   {{0x6d5cc2ba,0xf1b807f5,0x7bdc00d8,0x6458c2bb}},	//   _qapa, gršt_, _ahsu, _ysti, 
   {{0x6d5cc2bc,0x2918c2bd,0x23b800de,0xc10401f7}},	//   _vapa, vapa_, līja_, _اوٺي, 
   {{0x6d5cc2be,0x291805d9,0x8024221d,0xb5fcc2bf}},	//   _wapa, wapa_, _اروم, _pršl, 
   {{0x2918c2c0,0xbe4813f9,0x23b8005f,0x6fd402f0}},	// [ff00] tapa_, _یشیم_, nīja_, láco, 
   {{0x6d5cc2c1,0x6844a0d5,0x00000000,0x00000000}},	//   _uapa, инза, --, --, 
   {{0x29182831,0x48d4015b,0xbd44009f,0x00000000}},	//   rapa_, ়শ্র, _انپي, --, 
   {{0x29180863,0x6458c2c2,0x80ac008f,0x6fd402f0}},	//   sapa_, _rsti, עסאַ, zácn, 
   {{0x2918c2c3,0xb5fc0010,0xd6cc0244,0x00000000}},	//   papa_, _uršl, وقم_, --, 
   {{0x201cc2c4,0x29184c27,0x23b800da,0x9f4c004e}},	//   ysti_, qapa_, dīja_, _rufí_, 
   {{0xe7380276,0x6fd40419,0x955000f2,0x00000000}},	//   _иев_, vácn, زخوا, --, 
   {{0x645805d5,0x201c262a,0x377401af,0xe7a800cd}},	//   _vsti, vsti_, _лыус, _कषिप, 
   {{0x17980bd9,0x9f4c013d,0x3f98002e,0x826801d3}},	//   _סימב, _qufí_, ërum_, اشبہ_, 
   {{0x64a4c2c5,0x6458030d,0x2408c2c6,0x201c0bc9}},	//   _каза, _tsti, _анжи_, tsti_, 
   {{0x6458aa24,0x201cc2c7,0xd6cc01ed,0x58f4010f}},	//   _usti, usti_, _فقہ_, יצין_, 
   {{0x1fa40108,0x23b800ef,0x00000000,0x00000000}},	//   ррог, bīja_, --, --, 
   {{0x23b8005f,0x201c01a8,0x0e342d29,0x3afc01e1}},	//   cīja_, ssti_, оняю, _lápó_, 
   {{0x91e04205,0x201c0254,0xc1040472,0x9da80395}},	//   _доче, psti_, _اوغي, тъма_, 
   {{0x5ba4c2c8,0x5f74c2c9,0x2b8c00d7,0x00000000}},	//   араз, _ناظر, _kých_, --, 
   {{0x853c0006,0x386c012c,0x6ab8002d,0x8fa41d39}},	//   _smėl, _čer_, _śtfa, _маје, 
   {{0xd9184d30,0x2b8c00bc,0x799403ac,0x00000000}},	// [ff10] вье_, _mých_, _plzw, --, 
   {{0xbc900032,0x5c18030d,0x00000000,0x00000000}},	//   _еңгә, _итмĕ, --, --, 
   {{0xfbd005d9,0xf8b0114f,0x00000000,0x00000000}},	//   _فڪر_, سکس_, --, --, 
   {{0x2b8c0419,0x00000000,0x00000000,0x00000000}},	//   _ných_, --, --, --, 
   {{0x13a401b9,0x4ba80733,0xa3c8000d,0x00000000}},	//   ینتی_, _төрү_, लकन_, --, 
   {{0x35f400c7,0x5884004e,0x32080205,0x3dc400fe}},	//   _ҳпар, _кыба, _çayi_, _এওঁল, 
   {{0xf8e40d42,0xb8940491,0xb5fcc2ca,0xd49802e8}},	//   _প্রথ, _الأع, _kršk, ърд_, 
   {{0x349407d6,0x23b800da,0x32340139,0x00000000}},	//   _қаер, tīja_, бхос, --, 
   {{0x57b001f9,0x883c0092,0x00000000,0x00000000}},	//   ंचीह, _ያልተደ, --, --, 
   {{0x6fd4172e,0x23b800e2,0x71580276,0x91780208}},	//   táco, rīja_, урис_, _kể_, 
   {{0x69b81b6e,0x23b8005f,0x31700205,0x00000000}},	//   ्वती, sīja_, ızz_, --, 
   {{0x12bc1884,0x00000000,0x00000000,0x00000000}},	//   ﺭﯞﻩﺭ, --, --, --, 
   {{0x720407d6,0x63bc00e5,0x00000000,0x00000000}},	//   _اوتم, épne, --, --, 
   {{0xa280129e,0x00000000,0x00000000,0x00000000}},	//   _ریپو, --, --, --, 
   {{0xceb40213,0x1d04c2cb,0x8af003e3,0x00000000}},	//   _adət_, сеси_, hdət, --, 
   {{0x8c8800c7,0x7f74030d,0x00000000,0x00000000}},	//   гәҭа_, _дуьц, --, --, 
   {{0xada465c2,0xb5fc39ae,0x6fa8004b,0x69244f41}},	// [ff20] _гапл, _dršk, _لنډې_, ймаа, 
   {{0xe8f80323,0x8af003be,0xed5822cb,0xa3dc098a}},	//   улж_, ddət, _соо_, _दीन_, 
   {{0xa3c81414,0xab1c030d,0x684400d8,0x00000000}},	//   लकम_, _пинă_, снеа, --, 
   {{0xb5fc09a8,0xc70800c7,0x00000000,0x00000000}},	//   _gršk, рҭаз_, --, --, 
   {{0x2b8c00d7,0x680c0064,0xf4d40150,0x00000000}},	//   _rých_, _sėdę, _ﺘﺭﺍﻜ, --, 
   {{0x6b84010e,0x27f8009a,0x3934009d,0x00000000}},	//   _hokg, _مفسد_, _мэсс, --, 
   {{0x69ccc2cc,0xa3440209,0x6b84c2cd,0x00000000}},	//   _ikbe, бэпл, _kokg, --, 
   {{0xe7b413f9,0x2b8c01ef,0x00000000,0x00000000}},	//   _امرد, _býci_, --, --, 
   {{0x6b847318,0x27e4c2ce,0x2b8c02f0,0xa5080408}},	//   _mokg, mmon_, _vých_, _беза_, 
   {{0x6b84009a,0x27e49a62,0x8af006be,0x00000000}},	//   _lokg, lmon_, ldəs, --, 
   {{0xb914063f,0x2b8c01f1,0x00000000,0x00000000}},	//   _agbụ_, _tých_, --, --, 
   {{0x6b84014b,0x8af000ac,0x46dc012a,0x27e4c2cf}},	//   _nokg, ndəs, _बराह, nmon_, 
   {{0xa1840724,0x27e4c2d0,0x00000000,0x00000000}},	//   _гыйл, imon_, --, --, 
   {{0x27e4c2d1,0x7c340841,0x10100066,0x00000000}},	//   hmon_, tuzr, _کبود, --, 
   {{0x6b847e24,0x4c9401d5,0x27e40200,0x9b24013d}},	//   _bokg, пирс, kmon_, йфал, 
   {{0x9cc80184,0x27e49494,0x69cc2093,0xb05001d3}},	//   _ҡына_, jmon_, _akbe, _کھیت, 
   {{0x7f4c009a,0x27e401d5,0x8af000ac,0xb5fc01ef}},	// [ff30] _ibaq, dmon_, ddəs, _vršk, 
   {{0x7e6cc2d2,0x82f80003,0x27e4c2d3,0xd6d8016c}},	//   _irap, _པུའུ_, emon_, қте_, 
   {{0x7e6cc2d4,0xb5fc0010,0x95c801a9,0x00000000}},	//   _hrap, _tršk, қуда_, --, 
   {{0x69ccc2d5,0xbd4405d9,0x7f4c0327,0xb5fc0219}},	//   _ekbe, _انھي, _jbaq, _uršk, 
   {{0xb5fc0f03,0xeb3800c8,0x0c0401d9,0x00000000}},	//   _krši, _דערש, _وویُ, --, 
   {{0x27e4c2d6,0x7e6cc2d7,0x75c89735,0x00000000}},	//   amon_, _mrap, штең_, --, 
   {{0xb5fc28b5,0x7398c2d8,0xe51800c5,0x94a8010b}},	//   _mrši, итис_, _नजरि_, ытда_, 
   {{0x7e6cc2d9,0x31680198,0xfdf8033f,0x27e4c2da}},	//   _orap, _ɗazu_, ंदास_, cmon_, 
   {{0xe7a40075,0x7e6c0066,0xe1f4c2db,0xb5fc01a6}},	//   _بۇنى_, _nrap, огы_, _orši, 
   {{0x7f4c0928,0x3d180037,0x23b80055,0x2c18134e}},	//   _abaq, _बड़ले_, bījo_, _बबलू_, 
   {{0x7e6cc2dc,0x8af00cc1,0xafe4036b,0x5184504c}},	//   _arap, ndər, жонл, _қуда, 
   {{0x7e6c207a,0xa2a80574,0x98b00006,0x6fd40306}},	//   _brap, _जेव्, ždės_, máck, 
   {{0x7e6cc2dd,0x7c2402d0,0x6fd402f0,0x6b8400de}},	//   _crap, _avhr, láck, _rokg, 
   {{0xac08c2de,0x7f4c0b6f,0x320cc2df,0x22401bce}},	//   инга_, _ebaq, mpey_, àkke_, 
   {{0x27e4c2e0,0x7e6cc2e1,0x6b64c2e2,0xab18023a}},	//   ymon_, _erap, оква, ицах_, 
   {{0x7e6cc2e3,0xeb3457d7,0x320c0076,0x644c013d}},	//   _frap, تىرد, opey_, _äbie, 
   {{0x7e6cc2e4,0xceb400ac,0xa3c8000d,0xada40a5b}},	// [ff40] _grap, _edər_, लकत_, _маил, 
   {{0x2d941a21,0x6b8401f5,0x00000000,0x00000000}},	//   _фрис, _wokg, --, --, 
   {{0x27e4c2e5,0x6b8400a2,0x6fd401ef,0x00000000}},	//   tmon_, _tokg, jáck, --, 
   {{0x6fd40306,0x6fc8098a,0x69b8095f,0x00000000}},	//   dáck, रविं, ्वही, --, 
   {{0x16a40861,0xe18c0023,0x8b080153,0x65c401d5}},	//   овци_, _ዝገብሩ_, gręž, обда, 
   {{0x27e4c2e6,0xa2a84da1,0x69cc01c6,0x00000000}},	//   smon_, _जेष्, _ukbe, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x872800f1,0x27e4022e,0x00000000,0x00000000}},	//   _دغسې_, qmon_, --, --, 
   {{0x2d98c2e7,0xd04003b9,0xa5241188,0x00000000}},	//   _olpe_, _iynə, _ммад, --, 
   {{0x7e6cb010,0x6fd402fb,0x00000000,0x00000000}},	//   _rrap, lách, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7e6cc2e8,0xd36c0597,0x6fd400ae,0x00000000}},	//   _prap, _لهم_, nách, --, 
   {{0xb5fc10bf,0xf2c400c7,0xe0b40055,0xd36c01f7}},	//   _prši, _еицҿ, _dvāḥ_, _جهن_, 
   {{0x7e6cc2e9,0x91800131,0x8af00213,0x9250009f}},	//   _vrap, _يۇيۇ, ydər, _آڙيڪ, 
   {{0x7e6cc2ea,0x7f4c031c,0x7f94030d,0x00000000}},	//   _wrap, _tbaq, _накх, --, 
   {{0x7f4c209c,0x2d9800a2,0x3f1401a9,0x00000000}},	//   _ubaq, _elpe_, _эдис, --, 
   {{0x7e6cc2eb,0xb5fc0010,0x6fd41155,0xc0e80092}},	// [ff50] _urap, _trši, záck, ዚያም_, 
   {{0x5a48044e,0xbf14036b,0xb5fc0427,0x00000000}},	//   _ምክልኻ, _بوکب, _urši, --, 
   {{0xa3c853db,0x3f8803c1,0x81bc02f5,0x3774c2ec}},	//   लका_, _koau_, _আঠা_, зылс, 
   {{0xcd3400dd,0x6fd40122,0x00000000,0x00000000}},	//   _ٹریب, váck, --, --, 
   {{0x3f8803a0,0x7bcc0421,0x366872c5,0xda78014b}},	//   _moau_, moau, сало_, _тян_, 
   {{0xce380302,0x8a18039b,0x05a802bf,0x3f88c2ed}},	//   קאות_, _форс_, овій_, _loau_, 
   {{0x69b83599,0x6284023a,0x8af006be,0x00000000}},	//   ्वरी, äkon, neən, --, 
   {{0x7bccc2ee,0xd7746396,0x6fd40306,0x4cbc00df}},	//   noau, _باسع, ráck, יזוו, 
   {{0xf1d000f7,0x4638007b,0x00000000,0x00000000}},	//   нөкө, _وأكد_, --, --, 
   {{0x6fd4c2ef,0x116401d5,0x320c1368,0xe0b400b8}},	//   máci, آلدی_, rpey_, _svāḥ_, 
   {{0x6fd401a2,0xfbbc1a55,0xd64807d5,0x320c1b32}},	//   láci, ्काम, _гiул, spey_, 
   {{0x09b80b7c,0x3f880076,0x320cc2f0,0x00000000}},	//   _आद्य, _coau_, ppey_, --, 
   {{0x6fd4c2f1,0x3f88030a,0x7bccc2f2,0x92e800db}},	//   náci, _doau_, doau, _ئراق_, 
   {{0x1d04c2f3,0x6fd402f0,0x00000000,0x00000000}},	//   зери_, zách, --, --, 
   {{0x3f880165,0xe1643267,0xebe40150,0x307401c4}},	//   _foau_, _رضوی, зовп, _хулс, 
   {{0x6fd4c2f4,0xef180364,0x09b40490,0x5f400131}},	//   káci, _уми_, ःच्य, _كۆپل, 
   {{0x69b802c3,0x201802d2,0x00000000,0x00000000}},	// [ff60] ्वली, _æpir_, --, --, 
   {{0x6fd401f1,0x00000000,0x00000000,0x00000000}},	//   dáci, --, --, --, 
   {{0x7bc006af,0x00000000,0x00000000,0x00000000}},	//   éluc, --, --, --, 
   {{0xe7380364,0x6fd40120,0x6f04a061,0x00000000}},	//   сед_, fáci, nckc, --, 
   {{0x6fd4c2f5,0x7d14000f,0xb5fc01a6,0x6e242611}},	//   gáci, _ôfsû, _oršu, nskb, 
   {{0x67f8012c,0xfbc4009e,0x00000000,0x00000000}},	//   _půjd, ্ষণত, --, --, 
   {{0xd3680952,0x6fd40306,0xe8300023,0xd7b40014}},	//   ﻳﻠﯩﻖ_, pách, _ኣልቦነ, _کۆنڈ_, 
   {{0x58b80302,0xc2980815,0x6fd400d7,0x628401f4}},	//   _המלצ, жких_, báci, äkoo, 
   {{0x6fd406ed,0x00000000,0x00000000,0x00000000}},	//   cáci, --, --, --, 
   {{0x6600c2f6,0x0094c2f7,0x40300092,0x67200e03}},	//   mqok, диоэ, _በተገኙ, laoj, 
   {{0x66000784,0x6b940076,0x27e402f0,0x59bc1546}},	//   lqok, kkyg, ňonu_, ्वतर, 
   {{0x67200451,0x00000000,0x00000000,0x00000000}},	//   naoj, --, --, --, 
   {{0x660000f1,0x00000000,0x00000000,0x00000000}},	//   nqok, --, --, --, 
   {{0x9f880295,0x4034a74b,0x05dc00bc,0x00000000}},	//   rùñ_, _жекс, यतिब, --, 
   {{0xf1a87a1f,0x6fd4c2f4,0x3f880421,0x7bccc2f8}},	//   _بانه_, záci, _toau_, toau, 
   {{0xb5fc1674,0x2364c2f9,0x6ecc01f9,0x00000000}},	//   _kršt, _jaoj_, _धुवु, --, 
   {{0x7bccc2fa,0x6fd400d0,0x00000000,0x00000000}},	// [ff70] roau, xáci, --, --, 
   {{0x6fd456b1,0x127800c8,0x213c2403,0x59bc0882}},	//   váci, זאמע, ngth_, ्वधर, 
   {{0x7bcc1e7f,0x0f2000fe,0x00000000,0x00000000}},	//   poau, _ভাতৃ_, --, --, 
   {{0x6fd4c2f1,0x078001e1,0x00000000,0x00000000}},	//   táci, _áìlì_, --, --, 
   {{0x0574082a,0x6600c2fb,0x59bc00cd,0x628401f4}},	//   کاند, gqok, ्वदर, äkol, 
   {{0x6fd4c2f4,0xc6a405f5,0x167001ec,0xd7f801c4}},	//   ráci, эрхи, мқұр, _гуа_, 
   {{0x97a40150,0x00000000,0x00000000,0x00000000}},	//   _ерал, --, --, --, 
   {{0xc8c80014,0xb9dc00b7,0x6e24002d,0x6fd43afd}},	//   _روقن_, _ቡሽ_, yskb, páci, 
   {{0xb5fc2230,0x15a802e8,0xc30400e3,0xf7400092}},	//   _pršu, _лъжи_, ربيو, _የምታሟ, 
   {{0x387002fa,0x59bc227c,0x00000000,0x00000000}},	//   _krzr_, ्विर, --, --, 
   {{0xa3dc02a0,0x4094005b,0xa3c8012d,0x00000000}},	//   _दीव_, ерят, लकश_, --, 
   {{0x23640165,0x78a40156,0xaadc000d,0x00000000}},	//   _gaoj_, izhv, _मरलक, --, 
   {{0x59bcc2fc,0xa3c856e9,0xe18c0023,0x42d40006}},	//   ्वार, लकर_, _ዝፈጸሞ_, _пішу, 
   {{0x823446bc,0x6e2400fe,0xb5fc0010,0x00000000}},	//   _سرها, rskb, _uršu, --, 
   {{0x300407d6,0xe500c2fd,0xdc6408ca,0xab284c79}},	//   _ўзиг, रुटि_, мард_, жоба_, 
   {{0xee38c2fe,0x66000784,0x91780208,0x00000000}},	//   _дни_, yqok, _hề_, --, 
   {{0x6720c2ff,0x98b000b8,0x00000000,0x00000000}},	// [ff80] vaoj, _ādāv_, --, --, 
   {{0x6b94c300,0xbb3400d1,0x3ca400cc,0xb4cc01f9}},	//   skyg, ﺮﻧﻰ_, _খুওৱ, _रडू_, 
   {{0xd940c301,0x6720007f,0x00000000,0x00000000}},	//   техи, taoj, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe5c4ace6,0xe5a4c302,0x6674c303,0x00000000}},	//   мско, миди, بدار, --, 
   {{0x672000d8,0x83f8005a,0x628401f4,0x00000000}},	//   saoj, пекс_, äkom, --, 
   {{0x3e84067d,0xd9400e26,0x84e817cb,0x6d4cc304}},	//   _këtë_, _шери, टेंट_, ifba, 
   {{0x66e4005e,0xb5fc0e04,0xbefc0ebb,0x00000000}},	//   _жоба, _pršt, _एलेन_, --, 
   {{0xfd6401fb,0x6fd4c305,0x28bc3af4,0x91780051}},	//   _chuồ, nácu, ्थवि, _bề_, 
   {{0x6d4c01f5,0x6734012d,0x00000000,0x00000000}},	//   jfba, łają, --, --, 
   {{0x81f8036b,0xa3440166,0x71f000c7,0x00000000}},	//   _کفتر_, _жэлл, ыҧшу, --, 
   {{0x443cc306,0x62640131,0x6d4cc307,0x00000000}},	//   muv_, _ياشق, efba, --, 
   {{0x443cc308,0xbf4801e1,0x93c80050,0x6d4ca21b}},	//   luv_, _aṣíp, _بالہ_, ffba, 
   {{0x701800dd,0xd12c6071,0x23b800ef,0x00000000}},	//   _کروڑ_, _نمه_, dīji_, --, 
   {{0x0cd400d6,0x443cc309,0x3e84036e,0xec180166}},	//   ворю, nuv_, _bëtë_, зесә_, 
   {{0x200c031c,0x29080009,0x64480332,0xd07c0023}},	//   _itfi_, _afba_, itfi, _ክመሃሩ_, 
   {{0x7984c30a,0x6578c30b,0xa020c30c,0x443c01d4}},	// [ff90] tjhw, _onth, _şöhr, huv_, 
   {{0x443cc30d,0x7f5c5727,0x9178004d,0x3f980254}},	//   kuv_, lesq, _kế_, lksu_, 
   {{0x443cc30e,0xc1780006,0xa3dc08f2,0xa3bc37f3}},	//   juv_, lmės_, णता_, ँचा_, 
   {{0x7f5cc30f,0x443cc310,0x6578c311,0x59bc92c1}},	//   nesq, duv_, _anth, ्वहर, 
   {{0x7afc02d0,0x78a40200,0x00000000,0x00000000}},	//   _igst, szhv, --, --, 
   {{0x6fd4c312,0x3a280649,0x6448343a,0x14c404fb}},	//   láct, msap_, ftfi, وهشی_, 
   {{0x33f4c313,0x3a280373,0xa3c801bc,0x6448005c}},	//   нчис, lsap_, लकं_, gtfi, 
   {{0x36d400d6,0xc1780006,0x6578c314,0x6fd4012c}},	//   _зобр, kmės_, _enth, náct, 
   {{0x644c420d,0x644802c4,0x7f5cc315,0x3a28c316}},	//   _äbin, atfi, desq, nsap_, 
   {{0x3a28013c,0x443cc317,0x05741046,0xcad8011a}},	//   isap_, buv_, _لامد, ווחת_, 
   {{0x7afc089c,0x64480334,0x9178001e,0xc5a801d9}},	//   _ogst, ctfi, _về_, _تُلن_, 
   {{0x75200036,0x3a280113,0x7afc1308,0x7f5c0381}},	//   _helz, ksap_, _ngst, gesq, 
   {{0x6fd4c318,0x6578127b,0xc1780064,0x00000000}},	//   dáct, _ynth, gmės_, --, 
   {{0x752001ed,0x7afcc319,0x6d4c0e78,0x7bc04985}},	//   _jelz, _agst, ufba, élun, 
   {{0x7f5c003a,0x3a28017a,0x816003e6,0x2b380276}},	//   besq, esap_, _ئۆپۆ, зязэ_, 
   {{0xef180372,0x6fd4c31a,0x7f5cc31b,0x00000000}},	//   _эми_, tácu, cesq, --, 
   {{0xdb0c01ed,0x443c3149,0x7afc0175,0x6d4c0112}},	// [ffa0] ájár, zuv_, _dgst, pfba, 
   {{0x7520012c,0x443cc31c,0xdd000356,0xc0e00023}},	//   _nelz, yuv_, ărăc, _ቐጺሉ_, 
   {{0x64486445,0x3a28013c,0x776801f5,0xb70c00a2}},	//   xtfi, asap_, _baex, _ỳaỳb, 
   {{0xa3dc033d,0xd704c029,0x182402d3,0x62840108}},	//   _दीं_, енце_, _ስነጽሑ, äkok, 
   {{0x7520c31d,0xfaa0001f,0x443c047e,0x6fd400e5}},	//   _belz, _ለመኖር_, wuv_, lács, 
   {{0x443cc31e,0x6448c31f,0xd6cc0691,0x29080798}},	//   tuv_, ttfi, حقه_, _ufba_, 
   {{0x77680097,0x6fd400dd,0x4614004b,0x7f5c0784}},	//   _faex, nács, روګر, yesq, 
   {{0x443c07d6,0x49080316,0xc2240066,0x9470c320}},	//   ruv_, ाँको_, نکتو, ادوا, 
   {{0x7f5cc321,0x443cc322,0xdbc400c5,0x85640022}},	//   vesq, suv_, _tööh, _инаҧ, 
   {{0x6578c323,0xe4d40597,0x200c020b,0x6fd401d3}},	//   _unth, _كتاب, _ptfi_, kács, 
   {{0x7f5cc324,0x443c014f,0x649801d5,0xd1340022}},	//   tesq, quv_, _этар_, ххы_, 
   {{0x7f5c003a,0x3a280076,0x1ac80154,0x75208e9f}},	//   uesq, ysap_, লেয়া, _zelz, 
   {{0x7f5cc325,0x93c81893,0x00000000,0x00000000}},	//   resq, _عامہ_, --, --, 
   {{0x127800c8,0x442c030a,0x9178004d,0xc0f80092}},	//   _מאדע, _kvd_, _tế_, _ፊልሙ_, 
   {{0x706400c7,0x6fd4c326,0xc1780024,0x7f5cc327}},	//   _ахыҧ, táct, smės_, pesq, 
   {{0x3a28c328,0xbbbc00bc,0x7f5cc329,0x00000000}},	//   tsap_, ्केक, qesq, --, 
   {{0x6fd429ac,0x3a28b1a4,0xc684004b,0x6284005b}},	// [ffb0] ráct, usap_, _اې_, äkoh, 
   {{0x98c45b87,0x3a28c32a,0x442cc32b,0xc4c400e5}},	//   ىغان, rsap_, _ovd_, _هے_, 
   {{0x3a280eda,0xfb3400ee,0x442cc32c,0x3940134a}},	//   ssap_, _иннэ, _nvd_, rghs_, 
   {{0xdb045d8a,0x76b80209,0x0c84010b,0x7afc03ac}},	//   ämät, млер_, _сыьм, _ugst, 
   {{0x8ae40046,0x75200732,0x442c8fee,0x23b800e2}},	//   _бірл, _pelz, _avd_, nīju_, 
   {{0x442c281e,0xe6900131,0x2ac00131,0x00000000}},	//   _bvd_, شلىد, _тәсв, --, 
   {{0x98700020,0x75205282,0x6590026a,0x885800d8}},	//   _የሚሆኑ_, _velz, рају, _пирс_, 
   {{0x442c3c36,0x75206142,0x34e00034,0x00000000}},	//   _dvd_, _welz, _फरीद, --, 
   {{0x35f4c32d,0x7648058a,0xb5c80150,0xc7c400cf}},	//   _апар, _uqey, _قورم_, _ссри, 
   {{0x7520c32e,0xd58403e6,0x23b800e2,0x200001e4}},	//   _uelz, _سێبه_, dīju_, ĉkin_, 
   {{0x442c3b4d,0xd498994d,0xafe400db,0x00000000}},	//   _gvd_, _эра_, коол, --, 
   {{0x7bc000d2,0xb4cc04aa,0x68f81427,0x6fd401d3}},	//   élul, रथी_, _útde, vács, 
   {{0xe28cc32f,0xfe780962,0x9e6002d5,0x324401e0}},	//   _та_, нёры_, авяд, _релг, 
   {{0xf1c825aa,0x814416cb,0x9178004d,0x3084007b}},	//   _توتى_, _منهن, _dễ_, _للتف, 
   {{0x1d04c330,0x442c020c,0xa1540114,0x00000000}},	//   теси_, _xvd_, _рају_, --, 
   {{0xdfcc16cb,0x6fd400dd,0x00000000,0x00000000}},	//   _ويو_, rács, --, --, 
   {{0x23b80171,0xe968004e,0x00000000,0x00000000}},	// [ffc0] cīju_, маал_, --, --, 
   {{0x62840108,0x6c0400f3,0x6fd400e5,0x00000000}},	//   äkoi, _изоз, pács, --, 
   {{0xe8bc0073,0x6c38010a,0x6744009d,0x00000000}},	//   ्थेच, _юлнă, вэлз, --, 
   {{0x2d8801a6,0xea6000e5,0xfd640055,0x00000000}},	//   ljbe_, _پھری, darṇ, --, 
   {{0x442c049f,0xd1ec044e,0xb74400db,0x4a9400a8}},	//   _svd_, _ቀሪቡ_, ائمو, _сынӂ, 
   {{0x5690c331,0xd690026a,0x442cc332,0x2a700175}},	//   рашт, ришћ, _pvd_, mvyb_, 
   {{0xfd641682,0x442c04cc,0xa3bc02e5,0x785400e5}},	//   _vhuḓ, _qvd_, ँचल_, _میلز_, 
   {{0x442c3b59,0xb8240183,0xd4640114,0x00000000}},	//   _vvd_, মূহত_, тиће_, --, 
   {{0x69dc017a,0xb6c401af,0x00000000,0x00000000}},	//   olpe, _битһ, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x443809e0,0x9938025d,0x69dc01ab,0x00000000}},	//   _ír_, ותיה, ilpe, --, 
   {{0x6458c333,0x30e439fb,0x23b800e2,0xd24c4451}},	//   _ipti, ысың, tīju_, _ژنن_, 
   {{0x63a0c334,0x53980bd4,0xc2100014,0xd33400d9}},	//   _ilon, _קידו, _أت_, _יראה_, 
   {{0xbbbc0d01,0x63a0c335,0x9254013e,0xada000d7}},	//   ्क्क, _hlon, _рашт_, _žúro, 
   {{0x23b800e2,0xdb6801c6,0xd1ec0023,0x8af006be}},	//   sīju_, мрал_, _ቀሪባ_, hfəd, 
   {{0x63a0020c,0x0ba4119e,0x8af003b9,0x00000000}},	//   _jlon, ашум, ldəy, --, 
   {{0x3a74c336,0x63a0055a,0xb95402e8,0x00000000}},	// [ffd0] ылар, _mlon, лващ, --, 
   {{0x6458c337,0xd83805f5,0x63a0c338,0x8af00213}},	//   _opti, дэд_, _llon, ndəy, 
   {{0x63a0325f,0x38c82ab4,0xaf8802d3,0x97c4c339}},	//   _olon, رائی_, _ንረብሓ_, پتام, 
   {{0xfd640a28,0xecb000fb,0xdb04007c,0x00000000}},	//   varṇ, _уҡсы, åläg, --, 
   {{0x6458c33a,0xc6480b24,0x8af003b9,0x00000000}},	//   _apti, نجول_, kdəy, --, 
   {{0x63a0c33b,0x59a4449f,0x00000000,0x00000000}},	//   _alon, _गतिर, --, --, 
   {{0x63a0c33c,0x26d003ee,0x64580175,0x5fd028d4}},	//   _blon, üyor_, _cpti, सवाल, 
   {{0x97000131,0x336401b9,0x00000000,0x00000000}},	//   _ئېشى, увиг, --, --, 
   {{0x63a0031c,0x0708038b,0x6458127b,0x61e8007b}},	//   _dlon, _شيلي_, _epti, _bhfl, 
   {{0x63a03d81,0xd4985f67,0x278400c7,0xbad801ec}},	//   _elon, _оре_, _аӡәи_, _ﺃﺼﺤﺎ, 
   {{0x63a007de,0x716400d1,0x00000000,0x00000000}},	//   _flon, ناھك, --, --, 
   {{0x63a0c33d,0xa3dc0825,0x00000000,0x00000000}},	//   _glon, णतः_, --, --, 
   {{0x82840244,0x69dc01f4,0x2d9401c6,0x00000000}},	//   _نجول, ylpe, гөнө_, --, 
   {{0xde00736a,0xf0e84d2d,0x645802d0,0xdb0c0210}},	//   спри, _كىشى_, _ypti, _ojcó, 
   {{0xdca0c33e,0xd7d007b6,0x63a003ac,0xc83c0023}},	//   бари, तवाच, _ylon, _ኣልኮላ, 
   {{0xdcac2b62,0x00000000,0x00000000,0x00000000}},	//   سىق_, --, --, --, 
   {{0x37b800fe,0x00000000,0x00000000,0x00000000}},	// [ffe0] ইকাৰ, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xeb9800c7,0x6da400c7,0x8a14004b,0x9f880254}},	//   _зин_, _аиҿа, _چېرت, _vööl_, 
   {{0x2a64025c,0x3ce400e5,0x00000000,0x00000000}},	//   ħobb_, ülve_, --, --, 
   {{0x9f8800c5,0x64580175,0x7718030d,0x00000000}},	//   _tööl_, _spti, ĕклĕ, --, 
   {{0xe4e4177b,0xa76800e2,0xe46848a4,0x2be00210}},	//   лійн, _šķīd, ешил_, पतवा, 
   {{0x2eb017c6,0x00000000,0x00000000,0x00000000}},	//   ीपुत, --, --, --, 
   {{0x7790411c,0x61e8c33f,0x491c00bc,0x439426dc}},	//   _ویلا, _shfl, यरको_, раис, 
   {{0x63a0c340,0xf66400f7,0x00000000,0x00000000}},	//   _vlon, _кетү, --, --, 
   {{0xb87c0092,0x216401a9,0x00000000,0x00000000}},	//   _የሚጥል_, утиг, --, --, 
   {{0x63a00770,0x64585e23,0x7bc0c341,0x4aac000d}},	//   _tlon, _upti, éluk, _घेघव, 
   {{0x63a0c342,0xd9e805d7,0x23b800de,0x00000000}},	//   _ulon, _जीनत_, būja_, --, 
   {{0x2bf800cd,0x00000000,0x00000000,0x00000000}},	//   ्दनं_, --, --, --, 
   {{0x6284023a,0x8af003b9,0x00000000,0x00000000}},	//   äkou, qdəy, --, --, 
   {{0x11d80302,0xfcc400d1,0x00000000,0x00000000}},	//   _רחוב, рәпм, --, --, 
   {{0x7f58020a,0x7b14c343,0x00000000,0x00000000}},	//   _раис_, рдах, --, --, 
   {{0xbb4402dd,0xdcac00f7,0x00000000,0x00000000}},	// [fff0] леңк, زۉڭ_, --, --, 
   {{0xbec80171,0x00000000,0x00000000,0x00000000}},	//   gmūž, --, --, --, 
   {{0x9c7001f7,0x00000000,0x00000000,0x00000000}},	//   _انجڻ, --, --, --, 
   {{0x0708c344,0x59a41223,0x6e2c0139,0xa82800db}},	//   هيمي_, _गतवर, _änbä, ئينە_, 
   {{0x3668c345,0x443c07de,0xc92403d4,0xa3c82e2a}},	//   тало_, erv_, _পাৰত_, ोवन_, 
   {{0xc0e800b7,0x86240006,0xfe1c3d1d,0xbb4c0150}},	//   መልስ_, сьце, बीएस_, _ﺍﻴﻠ_, 
   {{0xcd980302,0xd9e800c5,0x00000000,0x00000000}},	//   רדות_, _जीयत_, --, --, 
   {{0x68f8c346,0x59bc00dc,0x906000d1,0x04480023}},	//   _útda, ्वकर, ەندۇ, _ዘይጸን, 
   {{0x443cc347,0x00000000,0x00000000,0x00000000}},	//   arv_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8504c348,0x62e80014,0x00000000,0x00000000}},	//   _اومن, _یِمہ_, --, --, 
   {{0x72d47eb9,0x00000000,0x00000000,0x00000000}},	//   _коеф, --, --, --, 
   {{0x63e400cf,0xd0600213,0xdce800df,0x62840108}},	//   _ئينە, _əsəb, ĉiĝa, äkot, 
   {{0x6d7002d3,0x9f4c004e,0x6140c349,0xdee00212}},	//   _ብዝያዳ_, _bufó_, _деша, іори, 
   {{0xab28c34a,0x9f4c0793,0xafe4026b,0x00000000}},	//   кова_, _yufü_, _кокл, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
  
   {{0xa924c34b,0x7fe8c34c,0x6924c34d,0x00000000}},	// [10000] идал, _حروف_, имаа, --, 
   {{0xdd8c004b,0x443c0076,0x4bc400fb,0x00000000}},	//   _يوي_, yrv_, рөүг, --, 
   {{0xe0e80428,0x2134008f,0x5d38011a,0x00000000}},	//   _ijòñ_, שטעל_, _בתיא, --, 
   {{0xe738c34e,0xaa44c34f,0x443c01bf,0x31a800e5}},	//   тед_, _кемл, vrv_, _húzd_, 
   {{0x7c280e04,0x00000000,0x00000000,0x00000000}},	//   ćere, --, --, --, 
   {{0xd5ac781c,0xf7e800db,0x00000000,0x00000000}},	//   وفن_, _ەركى_, --, --, 
   {{0xd9d007a7,0x281404fb,0x00000000,0x00000000}},	//   _بەلگ, _خوزس, --, --, 
   {{0xa66405af,0xd3740108,0xb62000e5,0x906001f3}},	//   _پطرو, ачь_, _کہوٹ, _ሶርያዊ_, 
   {{0x443c0334,0x9f4c007f,0x256800c7,0x00000000}},	//   srv_, _oufò_, _иаап_, --, 
   {{0x41840075,0xc0e8010c,0x00000000,0x00000000}},	//   стиғ, መልሱ_, --, --, 
   {{0x3ff806ed,0x54640117,0x00000000,0x00000000}},	//   лноќ_, _вахм_, --, --, 
   {{0xe3b0027d,0x74b80137,0x62840108,0x8af003b9}},	//   _برئ_, _суус_, äkos, neəs, 
   {{0xc608015b,0x9d04003b,0x00000000,0x00000000}},	//   রীরা_, иївк, --, --, 
   {{0xe1f005d9,0x11d002e9,0x50b400f2,0xdce80118}},	//   _ڏسڻ_, _وتود, ادید_, řičn, 
   {{0x7f9405f5,0xcfc404c5,0x26c8016b,0x9b2401b9}},	//   _гайх, োষজন, _ɛboa_, ифал, 
   {{0x7e98c009,0xde4400f1,0xab6000a2,0x00000000}},	//   _منبر_, _پیسو_, _ýülm, --, 
   {{0x795801c6,0x00000000,0x00000000,0x00000000}},	// [10010] лиар_, --, --, --, 
   {{0x7e6c2cd9,0x6e20c350,0x853c0024,0xd54001e1}},	//   _isap, _çoba, _slėn, _mẹ̀f, 
   {{0x7d04119f,0x00000000,0x00000000,0x00000000}},	//   _ighs, --, --, --, 
   {{0xc7c4c351,0x9ba013d7,0x00000000,0x00000000}},	//   осчи, _بەرى, --, --, 
   {{0x7bdcc352,0xd6a800c6,0x7e6c0334,0x9a84344a}},	//   _iksu, خدام_, _jsap, _тунл, 
   {{0x067400d1,0xaae400f1,0x88c4002b,0xb99400ae}},	//   زنىڭ, _دسپو, _āśvi, _الآب, 
   {{0xd7f8c353,0x73340075,0x7f4c0213,0x00000000}},	//   _ауа_, مىغا, _ocaq, --, 
   {{0x7e6cc354,0x799400ca,0xb3844df9,0xd9e8000d}},	//   _osap, _hozw, слил, _जीतत_, 
   {{0x7bdc0a2e,0x79941aac,0x7e6c02ce,0x7d0400ad}},	//   _mksu, _kozw, _nsap, _oghs, 
   {{0xd54001e1,0x7f4c02d0,0x00000000,0x00000000}},	//   _dẹ̀f, _acaq, --, --, 
   {{0x7e6cc355,0x799402ea,0x05744cd0,0x6284005b}},	//   _asap, _mozw, _باقد, äkor, 
   {{0x79940943,0xedb01db2,0xd5400241,0xc1e801c6}},	//   _lozw, ुच्छ, _fẹ̀f, лдөж_, 
   {{0x7e6c066d,0x00000000,0x00000000,0x00000000}},	//   _csap, --, --, --, 
   {{0x7994c356,0x7bdc0724,0x7e6c0109,0xc2c4009f}},	//   _nozw, _aksu, _dsap, _بيهي, 
   {{0x5cb40006,0xb4e400cd,0x00000000,0x00000000}},	//   блёў_, _नरो_, --, --, 
   {{0x2608033d,0x95040135,0x98a8012c,0xd62c030d}},	//   ादमी_, _ཅུའི_, ůměr_, _гiиз, 
   {{0x79940296,0x644c00a2,0x00000000,0x00000000}},	// [10020] _bozw, _äbiv, --, --, 
   {{0x7bdc0115,0x799464b1,0x613c0092,0x31a8013a}},	//   _eksu, _cozw, _በአደባ, _fúze_, 
   {{0x7bdc0418,0xfbd000aa,0xdce800f3,0x7994033f}},	//   _fksu, ستې_, _ćiće, _dozw, 
   {{0x7e6c00c7,0x6b6418bc,0xa68438be,0x00000000}},	//   _ysap, _укма, йлед, --, 
   {{0x36e83955,0x65a401a8,0x31641196,0x96300024}},	//   ۇرۇپ_, _aðha, kelz_, зніц, 
   {{0x68f8c357,0x5904c358,0x5ef8010f,0x291c01a8}},	//   _útdo, _герм_, אפנד, _ýta_, 
   {{0x332c0369,0xb86402f2,0x00000000,0x00000000}},	//   faex_, _وافو, --, --, 
   {{0x23683cc6,0x823800d8,0x67e800d7,0x00000000}},	//   احثي_, азис_, býja, --, 
   {{0x93740104,0x59bc00cd,0x77900244,0xb35435cf}},	//   сбыт_, ्वचर, _تینا, تینا_, 
   {{0x84c4c359,0xdef80032,0x26f40490,0xc1b801c6}},	//   _мәйд, ҫым_, ेशीर_, рлох_, 
   {{0x7e6cc35a,0xd51001d9,0xa908022e,0x234800e5}},	//   _ssap, _رِند, ydоn, _ملاپ_, 
   {{0xdb1c0784,0xe2e4014b,0xa3e801d5,0x00000000}},	//   yoqñ, _лжеп, _ёдда_, --, 
   {{0x4ad8069f,0xa3480022,0x9da8013d,0x00000000}},	//   _भुलव, _азҵа_, гъва_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x5ba46988,0x7994006d,0xf3240150,0x00000000}},	//   браз, _rozw, _اۋۋى_, --, 
   {{0x7e6c0851,0x78a00213,0x00000000,0x00000000}},	//   _tsap, _ülvi, --, --, 
   {{0x7e6cc35b,0x7994068f,0x09c40154,0xd918009d}},	// [10030] _usap, _pozw, ্তনা, гье_, 
   {{0x8af800c7,0x67e800d7,0xdde8c35c,0x00000000}},	//   снус_, výja, _حربه_, --, 
   {{0xa3c809b2,0x00000000,0x00000000,0x00000000}},	//   ोवा_, --, --, --, 
   {{0x7994014b,0x7bdc00a2,0x8d1800e5,0x00000000}},	//   _wozw, _uksu, _پزیر_, --, 
   {{0x79940296,0x00000000,0x00000000,0x00000000}},	//   _tozw, --, --, --, 
   {{0xea6001ec,0x1fcc0154,0x00000000,0x00000000}},	//   _تۇكپ, রতিস, --, --, 
   {{0x34480107,0x00000000,0x00000000,0x00000000}},	//   рӯзи_, --, --, --, 
   {{0x94840046,0x31640129,0x00000000,0x00000000}},	//   _қызд, welz_, --, --, 
   {{0x5edc009e,0x954801d3,0xb5fc0064,0x8af006be}},	//   নেতে, _مشاق_, _apše, hfən, 
   {{0x869885c0,0xdee001ec,0x00000000,0x00000000}},	//   _укус_, _ﺍﺭﺘﺒ, --, --, 
   {{0xfbd80fc8,0xc1000131,0x5348030d,0x00000000}},	//   भकाम, нүшл, _йăнă, --, 
   {{0x222801d9,0x31640334,0x9f4c01e1,0x00000000}},	//   _چٲنی_, selz_, _ògì_, --, 
   {{0x67cc0115,0x3164002f,0x00000000,0x00000000}},	//   nĝja, pelz_, --, --, 
   {{0x853c0024,0x80244e10,0xa1540114,0x00000000}},	//   _alėj, _کروم, _даљу_, --, 
   {{0xbc1802dd,0xeb9800d8,0x00000000,0x00000000}},	//   йіті_, аив_, --, --, 
   {{0xeb98006c,0x3b940798,0x00000000,0x00000000}},	//   шиб_, пјут, --, --, 
   {{0x7c2805a1,0x6fa8004b,0x00000000,0x00000000}},	// [10040] ćera, _منډې_, --, --, 
   {{0xed58b144,0xd940c35d,0x6e346e25,0x3cec0118}},	//   _тоо_, дефи, _ivyb, řeva_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa6e42077,0xc7080022,0x00000000,0x00000000}},	//   ожел, сҭаз_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x672007dd,0x6d5cc35e,0x00000000,0x00000000}},	//   mboj, _obpa, --, --, 
   {{0x27e4adfe,0x2a600ac5,0xdb20007b,0xd2540953}},	//   llon_, _mpkb_, árúc, іцы_, 
   {{0x27e4c35f,0x6ac4c360,0x64c416ac,0x00000000}},	//   olon_, लपुर, _بيال, --, 
   {{0x75ec3eba,0x67200100,0x00000000,0x00000000}},	//   púzc, nboj, --, --, 
   {{0xa2d404fb,0x45000327,0x672000c0,0x00000000}},	//   _بيشت, _ཝུཌར_, iboj, --, 
   {{0x51740014,0x98a000de,0x644cc361,0x00000000}},	//   _وٕنس_, _lejā_, _äbis, --, 
   {{0x6f14015d,0x644c143a,0x00000000,0x00000000}},	//   _ffyc, _åbid, --, --, 
   {{0x2a6001f9,0x201cc362,0xdb1c0023,0x6d5c03ac}},	//   _bpkb_, mpti_, miqë, _ebpa, 
   {{0x27e4c363,0x67202b5d,0x68f8c364,0x9c840118}},	// [10050] dlon_, dboj, _útdj, dičů, 
   {{0x27e4c365,0xd8e40353,0xc9b800f1,0x672000d7}},	//   elon_, оцеп, يدلئ_, eboj, 
   {{0xd7642e56,0xc5d002f5,0x7bc000d2,0x984800a7}},	//   يەسى_, িতাপ, élus, ряза_, 
   {{0x27e4c366,0x201c0024,0x31a802f0,0x00000000}},	//   glon_, ipti_, _múza_, --, 
   {{0x4ae4036b,0x2720022e,0x99640014,0x98a00171}},	//   _жўра, _dаn_, _وۅرٕ_, _dejā_, 
   {{0x27e4c367,0xea600150,0x00000000,0x00000000}},	//   alon_, _سۇمپ, --, --, 
   {{0x0574c368,0x27e4c369,0x272001a9,0x8af003e3}},	//   باند, blon_, _fаn_, hfəl, 
   {{0xb224c36a,0x00000000,0x00000000,0x00000000}},	//   пмил, --, --, --, 
   {{0x35b4084c,0x59bc00c5,0xe1f001d3,0x00000000}},	//   _ебар, _एगार, کسٹ_, --, 
   {{0x057400f7,0x95c80902,0x31a800e5,0x00000000}},	//   _يالد, _туба_, _búza_, --, 
   {{0xafe401b9,0x72044d2f,0xe584004e,0x11649c1d}},	//   зонл, _کوتم, _эттү, ملکی_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa3c8177c,0x00000000,0x00000000,0x00000000}},	//   ोवर_, --, --, --, 
   {{0x67200989,0x7c2805ce,0xd34401b9,0x6d5cc36b}},	//   zboj, ćern, _ایکه_, _qbpa, 
   {{0x27e4c36c,0x67200153,0xd7d80073,0xe0340798}},	//   ylon_, yboj, यकाच, _езјч_, 
   {{0x65a4032e,0xe8c801e0,0xeef400c0,0x00000000}},	//   _aðhl, ҙгел_, _няпэ, --, 
   {{0x27e401a9,0x67208a8a,0xfbd001d3,0xa3bc4709}},	// [10060] vlon_, vboj, ڑتے_, ुचत_, 
   {{0xfa4800c6,0x99e0084c,0x2720022e,0x6d5c0857}},	//   تشفى_, ежуд, _sаn_, _ubpa, 
   {{0x27e4c36d,0x18640c69,0x6d4c0175,0x6720007c}},	//   tlon_, захи_, mgba, tboj, 
   {{0x2d988977,0x27e4c36e,0x092403d4,0x6b64022e}},	//   _hope_, ulon_, _পাওঁ_, _экма, 
   {{0x2d98c36f,0x6720c370,0xf99001d3,0x00000000}},	//   _kope_, rboj, ربے_, --, 
   {{0x6d4cc371,0x2d98a3bc,0x201cc372,0x27e4c373}},	//   ngba, _jope_, ypti_, slon_, 
   {{0x69dcc374,0x2d9801af,0x27e4c375,0x6d4cc376}},	//   mope, _mope_, plon_, igba, 
   {{0x2908025a,0x2d98c377,0x8af006be,0x00000000}},	//   _hgba_, _lope_, hfəm, --, 
   {{0xd6240b3b,0xc8780241,0x00000000,0x00000000}},	//   _ноте_, _è̟bi_, --, --, 
   {{0x69dcc378,0x6d4c0cf9,0x5634008f,0x2d980f85}},	//   nope, jgba, _מאמע_, _nope_, 
   {{0xdec8044e,0x29080521,0xd5ac00c6,0xf7f4004b}},	//   ኡውን_, _mgba_, _حفل_, _رسېد, 
   {{0xd36cc379,0x69dcc37a,0x6448c37b,0x201cc37c}},	//   _مهم_, hope, mufi, rpti_, 
   {{0x69dcc37d,0x2d98c37e,0x29080248,0x00000000}},	//   kope, _bope_, _ogba_, --, 
   {{0x2d983b08,0x656806d6,0x7e8c016b,0x6d4c1f53}},	//   _cope_, nefh, nɑpɛ, ggba, 
   {{0x7c2805ce,0xab1801f2,0x5ba4c37f,0x3ce400b5}},	//   ćero, _ọlụs, праз, ælv_, 
   {{0x2908c380,0x200c0421,0x6d4cc381,0x614001e1}},	//   _agba_, _iufi_, agba, _fílà, 
   {{0xb9983bb3,0x3f888cae,0x64480093,0x614001e1}},	// [10070] овах_, _inau_, hufi, _gílà, 
   {{0x6448124c,0x5c0406bb,0x2d984d11,0xc17802d5}},	//   kufi, _няма, _gope_, ndė_, 
   {{0x9ba01a59,0x3f880093,0x75ec0306,0xa3bc27f2}},	//   _كەسى, _knau_, fúzn, ुचा_, 
   {{0x200cc382,0x69dc0618,0xdeec001f,0x2d98c383}},	//   _mufi_, aope, _ሁሉን_, _zope_, 
   {{0x69dcc384,0x2d98c385,0x7bccc386,0xc1780024}},	//   bope, _yope_, mnau, kdė_, 
   {{0x6448208d,0x7bccc387,0x00000000,0x00000000}},	//   fufi, lnau, --, --, 
   {{0x200c0c09,0xf74800aa,0x3f8803a0,0x33f4c388}},	//   _nufi_, _ولسي_, _onau_, мчис, 
   {{0x7bccc389,0x26080027,0xc1780064,0x00000000}},	//   nnau, ादशी_, edė_, --, 
   {{0x4254c38a,0x7bcc2321,0x86982852,0x6d4c007c}},	//   нтэт, inau, _ектс_, ygba, 
   {{0x7bcc060a,0x3f8803c1,0x200cc38b,0x6448c38c}},	//   hnau, _anau_, _bufi_, bufi, 
   {{0x2d98c38d,0x94a801c6,0x76580142,0x00000000}},	//   _rope_, _утаа_, ltwy, --, 
   {{0x69dcc38e,0x200c00ca,0x2d98c38f,0x3f8803cb}},	//   zope, _dufi_, _sope_, _cnau_, 
   {{0x2d98c390,0x200c0093,0x69dcc391,0x92e80202}},	//   _pope_, _eufi_, yope, _اراق_, 
   {{0x3f880924,0x69dcc392,0x200c208d,0x7bcc1ffa}},	//   _enau_, xope, _fufi_, enau, 
   {{0x1d04c393,0x3f880270,0x200c011c,0x6ac43f55}},	//   дери_, _fnau_, _gufi_, लप्र, 
   {{0x7bccc394,0x2d98013b,0x69dcc395,0x68f8000f}},	//   gnau, _wope_, wope, _útdi, 
   {{0x6448c396,0x00000000,0x00000000,0x00000000}},	// [10080] zufi, --, --, --, 
   {{0x7bccc397,0x2d9800e4,0xb9e400d1,0x5a600166}},	//   anau, _uope_, ىسلى, ъкуб, 
   {{0xeb98c398,0x69dcc399,0x644801d9,0x2adc00dc}},	//   _дин_, rope, xufi, _कुरु_, 
   {{0x75ec00d7,0x00000000,0x00000000,0x00000000}},	//   fúzo, --, --, --, 
   {{0x6448aac2,0x6a84036b,0x80a40073,0x00000000}},	//   wufi, _ўлга, _चॅने, --, 
   {{0x543004a9,0x6448c39a,0x2908063f,0x85e400d1}},	//   ھرىر, tufi, _ugba_, رۋان, 
   {{0x8438007b,0xd36800d1,0x00000000,0x00000000}},	//   أكبر_, ﺳﻠﯩﻖ_, --, --, 
   {{0x4274c39b,0x200cc39c,0x6448c39d,0xc27410f3}},	//   егис, _rufi_, rufi, елиј, 
   {{0x200cc39e,0x7658015d,0x5a98010f,0x6658010a}},	//   _sufi_, ctwy, ַשטא, _фазă, 
   {{0x6448442c,0xc1780024,0x3f88143a,0x7bcc04cc}},	//   pufi, udė_, _snau_, znau, 
   {{0x26ecc39f,0x212c0076,0xc1780024,0x00000000}},	//   _जरुर_, _vefh_, rdė_, --, 
   {{0xe0200085,0x2d9cc3a0,0x7bcc0369,0xa3b800db}},	//   ɛ́lí_, öten_, xnau, _بائر_, 
   {{0x200c013f,0x442c0142,0x7bcc03b2,0x75ec00d7}},	//   _wufi_, _hwd_, vnau, kúzl, 
   {{0x200cc3a1,0x6280c3a2,0x442c0175,0x7e7c36e0}},	//   _tufi_, _iroo, _kwd_, rvsp, 
   {{0x3f880270,0x200c198f,0x62800363,0x00000000}},	//   _tnau_, _uufi_, _hroo, --, 
   {{0x26ec4614,0x6280c3a3,0x7bccc3a4,0x442c015d}},	//   _जरूर_, _kroo, unau, _mwd_, 
   {{0x7bccc3a5,0x8ff8c3a6,0xdee408e8,0xa3d42e05}},	// [10090] rnau, _ترور_, _تأثي, _सदन_, 
   {{0x442c0158,0x7bccc3a7,0x98c42c12,0x00000000}},	//   _owd_, snau, мсел, --, 
   {{0x76580142,0x00000000,0x00000000,0x00000000}},	//   wtwy, --, --, --, 
   {{0xd7f83d48,0x6280c3a8,0x1cdc0327,0xc60800fe}},	//   цуз_, _oroo, _སྙར_, ৰীমা_, 
   {{0x62800457,0x442c0b84,0x8b08013a,0x00000000}},	//   _nroo, _awd_, _vyřá, --, 
   {{0xea640150,0x7658c3a9,0xdee8069d,0x00000000}},	//   _سەمي_, rtwy, መርና_, --, 
   {{0x6280c3aa,0x765800a9,0xc6d41e4a,0x442c0042}},	//   _aroo, stwy, ىتۇت, _cwd_, 
   {{0x6280c3ab,0xd62c0408,0xca700023,0x00000000}},	//   _broo, _гiаз, ጸልኩም_, --, 
   {{0x1cdc031c,0x09c4015b,0x6280b561,0xc674007b}},	//   _སྙལ_, ্তরা, _croo, _لطلب, 
   {{0x442cc3ac,0x62803a6f,0xe1f40724,0xa6e002d2}},	//   _fwd_, _droo, нгы_, _óðav, 
   {{0x6280c3ad,0x442c152c,0x853c0006,0x3cf8033f}},	//   _eroo, _gwd_, _plėv, ंधों_, 
   {{0x6280c3ae,0x26a400db,0x4384007b,0xa3d4000d}},	//   _froo, _تۇۇپ_, _للمق, _सदय_, 
   {{0x62800917,0x1e8000c0,0x00000000,0x00000000}},	//   _groo, глям, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x61d40375,0xa3c40073,0xabf40d1d,0x00000000}},	//   _אוסף_, _उगम_, ечащ, --, 
   {{0x628001ab,0xaf28010b,0x160c1b76,0xee3803f6}},	//   _yroo, _эжиз_, ादार_, _ени_, 
   {{0x853c00c0,0x5ca000db,0x95380092,0x00000000}},	// [100a0] _klėt, _ەلپە, _የጎንደ, --, 
   {{0xab6c001f,0x00000000,0x00000000,0x00000000}},	//   ስበዋል_, --, --, --, 
   {{0x6ab40210,0x00000000,0x00000000,0x00000000}},	//   szyf, --, --, --, 
   {{0xad24525b,0xcb740150,0xe7bc00eb,0x00000000}},	//   _تىگى, _جۇرة, ইক্য, --, 
   {{0x442cc3af,0x00000000,0x00000000,0x00000000}},	//   _swd_, --, --, --, 
   {{0x442c0334,0x75ec045f,0x6284713c,0x00000000}},	//   _pwd_, lúzj, åkom, --, 
   {{0x186418ec,0xdb040108,0xa3bc0037,0xd5f0030d}},	//   _пари_, ämöt, ुचल_, _дiог, 
   {{0x6280c3b0,0x779000f2,0x6844014b,0x66e4a5de}},	//   _proo, _پیها, _онҳа, _зоба, 
   {{0xd2540262,0x442c045a,0x81d42143,0x98a000c0}},	//   нцэ_, _wwd_, коих, _veją_, 
   {{0x6280c3b1,0x442c009f,0x00000000,0x00000000}},	//   _vroo, _twd_, --, --, 
   {{0x65780652,0x8af00213,0x442c0042,0xdee80023}},	//   _iath, lgəd, _uwd_, መይን_, 
   {{0x64584f08,0x6578c3b2,0x62807156,0x00c80131}},	//   _iqti, _hath, _troo, злүк_, 
   {{0x6578c3b3,0x2458c3b4,0x62809b14,0xd36cc3b5}},	//   _kath, lëm_, _uroo, _دهن_, 
   {{0xd12cc3b6,0x6578c3b7,0x409400c6,0x635406be}},	//   _همه_, _jath, _للتر, bənö, 
   {{0x6578c3b8,0x24580200,0x0cd400f5,0x00000000}},	//   _math, nëm_, горю, --, 
   {{0x6578c3b9,0xdef878da,0xb5fc00c0,0x00000000}},	//   _lath, _нып_, _apšl, --, 
   {{0x2458069c,0x3df406bb,0x6578c3ba,0xb95402e8}},	// [100b0] hëm_, _изис, _oath, кващ, 
   {{0x6578c3bb,0x64440374,0xc4b0033f,0x2458036e}},	//   _nath, _ākin, जनाओ, këm_, 
   {{0x98081d0a,0x24580de2,0x7bf800cf,0xe8f8030d}},	//   ستاف_, jëm_, _онор_, çла_, 
   {{0x65781c1d,0xc17800c0,0x00000000,0x00000000}},	//   _aath, olės_, --, --, 
   {{0x8a18c3bc,0x6578c243,0x6458332b,0xdcf406be}},	//   _пояс_, _bath, _aqti, _ilxı, 
   {{0x6578c3bd,0xd240036b,0x2458002e,0xc5940114}},	//   _cath, қмоқ, fëm_, личј, 
   {{0x6578c3be,0x733400d1,0x00000000,0x00000000}},	//   _dath, نىغا, --, --, 
   {{0xc17802d5,0xc5f800b0,0x6578c3bf,0x853c0153}},	//   klės_, _ehē_, _eath, _blės, 
   {{0x853c0006,0xd5f80208,0xd50816cc,0x00000000}},	//   _plėt, _trù, _فغان_, --, 
   {{0x6578c3c0,0x245800e8,0x00000000,0x00000000}},	//   _gath, bëm_, --, --, 
   {{0xc1780064,0x00000000,0x00000000,0x00000000}},	//   elės_, --, --, --, 
   {{0x657881b3,0x1cdc0135,0x43745a9e,0x00000000}},	//   _zath, _སྙེ_, _бушт, --, 
   {{0x6578c3c1,0x63a401d3,0x0244009f,0xada00419}},	//   _yath, ökne, _مَنَ, _ľúbo, 
   {{0xceb8104e,0x00000000,0x00000000,0x00000000}},	//   дәү_, --, --, --, 
   {{0x2b380276,0x38800153,0x00000000,0x00000000}},	//   дязэ_, _nėr_, --, --, 
   {{0xa0300131,0x3f98037e,0x6f6400c7,0xdca001d5}},	//   _ئىيت, cjsu_, _рвиз, шаси, 
   {{0x2458044e,0xb5fc0064,0x00000000,0x00000000}},	// [100c0] zëm_, _apšm, --, --, 
   {{0x245800e8,0xc0e80092,0x00000000,0x00000000}},	//   yëm_, መግም_, --, --, 
   {{0x6578c3c2,0xab2800f7,0x00000000,0x00000000}},	//   _rath, _оона_, --, --, 
   {{0x6578c3c3,0x628403cd,0x7c2003b2,0xa6c8009f}},	//   _sath, åkok, ílre, ووال_, 
   {{0x6578c3c4,0xc5f800fb,0x00000000,0x00000000}},	//   _path, еға_, --, --, 
   {{0x2458069c,0x601c1e0d,0x65780fec,0xa63c0023}},	//   tëm_, _hīme, _qath, _ኣይወሰ, 
   {{0x6578c3c5,0xd4640063,0xe738014b,0x00000000}},	//   _vath, вије_, _оев_, --, 
   {{0x65783824,0x2458c3c6,0xc5f802b1,0x853c0153}},	//   _wath, rëm_, _whē_, _plės, 
   {{0x65781161,0x2458a86a,0x7c280e04,0x940000ec}},	//   _tath, sëm_, ćeri, جويه, 
   {{0x65780597,0x601c00da,0x64a40124,0x41b40133}},	//   _uath, _līme, _иаза, امدر, 
   {{0x7f581f0a,0xd36cc3c7,0x2558007f,0x645801d5}},	//   нанс_, _кч_, _vņlč_, _uqti, 
   {{0xdef80323,0x6d58c3c8,0x443c0051,0xf2c40150}},	//   дыг_, òtan, msv_, _өсін, 
   {{0xc1780153,0x62580022,0xdce400de,0xd62c0354}},	//   ulės_, _црер_, dejā, _гiез, 
   {{0x64480eda,0x1cdc0327,0xe0480133,0x3eac0327}},	//   orfi, _སྙུ_, _قشبه_, ġet_, 
   {{0xa3d45843,0xc1780024,0x443c0077,0x3eac2919}},	//   _सदा_, slės_, nsv_, šet_, 
   {{0x644800c6,0x64440418,0x547808a8,0xc1780153}},	//   irfi, _ākil, וטלו, plės_, 
   {{0xdc70069c,0x2e8400fd,0x443c009b,0x6448002f}},	// [100d0] _ብፍላይ_, _йөри_, hsv_, hrfi, 
   {{0x443c4f8c,0x00000000,0x00000000,0x00000000}},	//   ksv_, --, --, --, 
   {{0x17d80150,0x35a401d5,0xadd4011a,0x00000000}},	//   _ﺃﻓﺭﺯ, ғайг, _תותח_, --, 
   {{0x443cc3c9,0xc86416a4,0x36380139,0x00000000}},	//   dsv_, ртфи, ездэ_, --, 
   {{0x6448c3ca,0x75ec5f5b,0x24500725,0x00000000}},	//   erfi, lúzi, ەنىس, --, 
   {{0x601c005f,0x32440150,0x00000000,0x00000000}},	//   _zīme, ңейг, --, --, 
   {{0xdc7002d3,0x644800e4,0x8894c3cb,0x98940092}},	//   _ብፍሉይ_, grfi, _кирх, _ለሚሆኑ_, 
   {{0xd3a004a9,0xf1d00137,0x2bc40846,0xd7f801c6}},	//   рлиқ, өөлө, रोपा, _цуг_, 
   {{0x64480af5,0x36d400a8,0x68f8c3cc,0xddcc00d0}},	//   arfi, _соар, _útdr, pucň, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x5f4000d1,0x8af006be,0x00000000,0x00000000}},	//   ڭچىل, lfət, --, --, 
   {{0xdb0c06af,0x01c801d3,0x73d8c3cd,0x00000000}},	//   _ulcè, _یونٹ_, _ядер_, --, 
   {{0xe1ecc3ce,0xe28cc3cf,0x2bc41ab2,0x3244004e}},	//   _гг_, _уа_, रोफा, _селг, 
   {{0xc2b800cf,0xace80166,0x61ac01f9,0x00000000}},	//   _جامئ_, емга_, टसृष, --, 
   {{0xafe400fd,0xec1404f2,0xd24c00ec,0xe63c0240}},	//   _йокл, اورد, _انڙ_, _ኣይንሕ, 
   {{0x8b080118,0x5110000d,0x00000000,0x00000000}},	//   jpří, _ठलुआ_, --, --, 
   {{0x6da4c3d0,0xada4010b,0x00000000,0x00000000}},	// [100e0] _бипа, _бапл, --, --, 
   {{0x5eb8011a,0x00000000,0x00000000,0x00000000}},	//   _נזיק, --, --, --, 
   {{0x601c00e2,0x674401c0,0xe5a400d1,0x00000000}},	//   _tīme, гэлз, һиди, --, 
   {{0x1cdc0135,0xb8640150,0x8af006be,0x00000000}},	//   _སྙི_, شامو, ffət, --, 
   {{0xe5a4c3d1,0xe5c4623a,0x00000000,0x00000000}},	//   лиди, лско, --, --, 
   {{0x2814c3d2,0xe3d063f5,0x6448009b,0x31a801ef}},	//   _موسس, өйлө, trfi, _fúzi_, 
   {{0x6448c3d3,0x35440212,0x18a0030d,0xa908022e}},	//   urfi, рхів, _ларм, rdоs, 
   {{0x6448c3d4,0xd64802dd,0x5edc0154,0x5c34010f}},	//   rrfi, _бiрл, নেটে, ארקן_, 
   {{0x27e4c3d5,0x54c00139,0x00000000,0x00000000}},	//   moon_, ибәб, --, --, 
   {{0x27e4c3d6,0x98a4012d,0xa50803f6,0x00000000}},	//   loon_, źną_, _зеза_, --, 
   {{0x7f949ad7,0x6448013c,0x00000000,0x00000000}},	//   аанх, qrfi, --, --, 
   {{0x27e4c3d7,0x23640427,0x2bc4acda,0x00000000}},	//   noon_, _uboj_, रोमा, --, 
   {{0x63a09e7a,0xdb0c0129,0x0c8400fb,0x00000000}},	//   _ioon, _ulcé, ҙырм, --, 
   {{0x63a0c3d8,0x27e4c3d9,0x3cb42991,0x8af003e3}},	//   _hoon, hoon_, айгр, hfəs, 
   {{0xc6848f38,0x63a0c3da,0x27e4c3db,0x7040001f}},	//   _کې_, _koon, koon_, _ኮርፖሬ, 
   {{0x27e4c3dc,0x63a0c3dd,0x00000000,0x00000000}},	//   joon_, _joon, --, --, 
   {{0x27e4c3de,0x38c800dd,0x68ec01b9,0x63a0c3df}},	// [100f0] doon_, ھائی_, _aybd, _moon, 
   {{0xca48c3e0,0x63a0c3e1,0x7e6cc3e2,0x2bc423fd}},	//   الله_, _loon, _ipap, रोबा, 
   {{0x27e4c3e3,0xbc940640,0x00000000,0x00000000}},	//   foon_, _танј, --, --, 
   {{0x7b840058,0x63a0c3e4,0x27e4c3e5,0x68ec32b8}},	//   _ئادە, _noon, goon_, _dybd, 
   {{0x466400ae,0x00000000,0x00000000,0x00000000}},	//   مدوّ, --, --, --, 
   {{0x7e6cc3e6,0xce380375,0x3a28c3e7,0x61dc07f7}},	//   _mpap, נאות_, mpap_, नकोष, 
   {{0x63a0c3e8,0x27e4a6ec,0x85b801d9,0x3a280c05}},	//   _boon, boon_, دانس_, lpap_, 
   {{0x63a0c3e9,0x7e6cc3ea,0x88a403e6,0xd344030f}},	//   _coon, _opap, _دیمۆ, ایشه_, 
   {{0x63a0c3eb,0x7e6c0280,0xa3d40490,0x7768005a}},	//   _doon, _npap, _सदर_, _ibex, 
   {{0xb5fc0bb8,0xf4842580,0x7dc8009b,0xf0640064}},	//   _opši, _پائی, džso, акоп, 
   {{0x7e6cc3ec,0x63a0c3ed,0xe1f4ade4,0x22980006}},	//   _apap, _foon, ргэ_, ešką_, 
   {{0x63a0c3ee,0x30140058,0x61e8010f,0xafe4c3ef}},	//   _goon, лдүр, _ekfl, ромл, 
   {{0x7c24c3f0,0x77680327,0xb5fc0024,0x41740150}},	//   _athr, _mbex, _apši, _گانس, 
   {{0x63a0c3f1,0x1cdc025c,0x27e4c3f2,0x00000000}},	//   _zoon, _སྙང_, zoon_, --, 
   {{0x63a0c3f3,0x27e4bb2a,0x4174c3f4,0x77680b6f}},	//   _yoon, yoon_, _دانس, _obex, 
   {{0x7c24493a,0x63a0c3f5,0x27e41574,0x332c0327}},	//   _dthr, _xoon, xoon_, nbex_, 
   {{0x7c24009a,0x27e4005b,0x3a28005c,0x62840306}},	// [10100] _ethr, voon_, gpap_, ťkov, 
   {{0x27e4c3f6,0x1e380375,0x601c0055,0xf7e800d1}},	//   woon_, _שגיא, _hīma, ۇرنى_, 
   {{0x27e4c3f7,0xe738c3f8,0x601c00b0,0x5ea8009e}},	//   toon_, вее_, _kīma, _চেপে, 
   {{0xa68400f7,0xd82002bf,0xb5300b82,0x00000000}},	//   илед, ідчи, _ጽሕፈት, --, 
   {{0x27e4c3f9,0x63a04f7f,0x888404d3,0x2bc4298e}},	//   roon_, _roon, _گیان, रोणा, 
   {{0x27e4c3fa,0x776807c5,0x63a00e21,0x7c340129}},	//   soon_, _ebex, _soon, _égrè, 
   {{0x27e4c3fb,0x63a0c3fc,0x88843b93,0x71700023}},	//   poon_, _poon, _دیان, _ጹሑፋት_, 
   {{0x63a09f02,0x61dc954a,0x27e4b87a,0x98780a7c}},	//   _qoon, नक्ष, qoon_, _באלט, 
   {{0x5ea82baf,0xe5788c75,0x63a0004c,0xf668c3fd}},	//   _চেনে, _иза_, _voon, _محله_, 
   {{0x63a0c3fe,0x2adc007d,0xdce4033f,0x00000000}},	//   _woon, _कुछु_, leją, --, 
   {{0x7e6c1825,0xa508c3ff,0x31846215,0xc21001d9}},	//   _spap, _режа_, стың, _کٔت_, 
   {{0x3b980020,0x9f5005d1,0x23281f91,0x644400b0}},	//   _መሪዎች_, _ödül_, _роди_, _ākih, 
   {{0x53980bd4,0x7c240076,0xe29833d2,0xdb1c06be}},	//   _שידו, _sthr, _шад_, liqç, 
   {{0x75ec00d2,0xe0b400cd,0x3c580276,0x7c24045a}},	//   búzu, _etāḥ_, лигэ_, _pthr, 
   {{0x5900b444,0x0ca850e6,0x51f8011a,0x00000000}},	//   _མཛེས_, атти_, _שהוצ, --, 
   {{0xbf3400a7,0x00000000,0x00000000,0x00000000}},	//   _унищ, --, --, --, 
   {{0x7e6c0882,0x2bc43abc,0x8af00213,0xdde8006c}},	// [10110] _upap, रोधा, ffəq, _لرده_, 
   {{0xf7400023,0x00000000,0x00000000,0x00000000}},	//   _ከምዘሕ, --, --, --, 
   {{0x89340a11,0x7c24035a,0x0c840024,0x00000000}},	//   زعلا, _uthr, _дыям, --, 
   {{0x76b8c400,0x3a280194,0x9a8410fc,0x75ec00e5}},	//   ллер_, ppap_, _кугл, húzt, 
   {{0x7bcc02d5,0x3a280784,0x09c40154,0x7768c401}},	//   miau, qpap_, ্তজা, _vbex, 
   {{0x7bcc0953,0x85e800d6,0xe5a01638,0x4284001f}},	//   liau, адів_, зиши, ካይነት_, 
   {{0x7768031c,0x2788010b,0xd8800214,0x628401bf}},	//   _tbex, _өртү_, _بهزی, ækon, 
   {{0x7bccc402,0x7768014b,0x74540023,0x7a400118}},	//   niau, _ubex, _ዘይገብ, cátý, 
   {{0x332c0036,0x00000000,0x00000000,0x00000000}},	//   rbex_, --, --, --, 
   {{0xb5fc0006,0x7bccc403,0x756401d3,0x601c0a2f}},	//   _apšv, hiau, _طیبہ_, _sīma, 
   {{0x7bccc404,0xa920032e,0xafe4004e,0x00000000}},	//   kiau, _áþek, йоол, --, 
   {{0x09d400dc,0x00000000,0x00000000,0x00000000}},	//   _दद्य, --, --, --, 
   {{0x7bccc405,0x63e42309,0xea64313e,0x00000000}},	//   diau, _اينە, _ﺷﻴﺎﯞ, --, 
   {{0x6e940132,0xdce4012d,0x00000000,0x00000000}},	//   _ۇلعا, zeją, --, --, 
   {{0x601c0325,0x7bcc005a,0x80e80014,0x765c007c}},	//   _tīma, fiau, _پروِ_, _åsyf, 
   {{0x7bccc406,0x3204c407,0xa4a000e4,0x00000000}},	//   giau, lmly_, ñòih, --, 
   {{0xe9d8c408,0xdb0c0798,0xaa4400fd,0xef20012d}},	// [10120] гка_, _alcâ, сезл, ążą_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6c840491,0x7bcc02d5,0x6d5c0857,0x4b540014}},	//   _الجم, biau, _icpa, _وێسر, 
   {{0x7bccc409,0x00000000,0x00000000,0x00000000}},	//   ciau, --, --, --, 
   {{0x66e40212,0xd7ec007b,0x00000000,0x00000000}},	//   щода, ركه_, --, --, 
   {{0x490400ee,0x7a4000bc,0x387c01f4,0x00000000}},	//   _дүзг, sátý, äyrä_, --, 
   {{0x31cc03f4,0x6e340368,0x298400fd,0x00000000}},	//   রকাশ, _lwyb, _кыңг, --, 
   {{0x78a000db,0xa29002d3,0x00000000,0x00000000}},	//   _àlva, ግጋእን_, --, --, 
   {{0xe6f401d9,0x23340220,0xa1840bb0,0x6d5c01ab}},	//   _اژاں_, апқы_, бынл, _ocpa, 
   {{0x1540c40a,0x25640014,0x7bccc40b,0x614001ef}},	//   _неум, _دارُ, ziau, dílí, 
   {{0xed6000e2,0x00000000,0x00000000,0x00000000}},	//   _mežā_, --, --, --, 
   {{0x6720c40c,0x6d5c03ac,0x7bcc0ffb,0x73740022}},	//   ncoj, _acpa, xiau, _мычх, 
   {{0x7bccc40d,0x57f8011a,0x00000000,0x00000000}},	//   viau, טלטו, --, --, 
   {{0x6d5c004e,0x0dc89cff,0x4034404b,0x52d400d9}},	//   _ccpa, буси_, _декс, _פוגע_, 
   {{0x7bccc40e,0x19a80046,0x672001e4,0x601c00ef}},	//   tiau, қтап_, kcoj, _zīmn, 
   {{0x5c04c40f,0x601c02b5,0x26340034,0x6d5c02d0}},	//   сяга, _hīmo, kło_, _ecpa, 
   {{0x7bcc0953,0x6e340f7b,0x6140013a,0x00000000}},	// [10130] riau, _gwyb, cílí, --, 
   {{0x213cc410,0x7bccc411,0x2d9cc412,0x26340034}},	//   nath_, siau, ötet_, dło_, 
   {{0xdb1c0054,0x271c0521,0x8af003e3,0x8ed801ed}},	//   tiqä, _ịna_, lgəl, _نذیر_, 
   {{0x213cc413,0x00000000,0x00000000,0x00000000}},	//   hath_, --, --, --, 
   {{0xb5fcc414,0x1c1c652f,0x213c0472,0x2634033f}},	//   _opšt, _मंडल_, kath_, gło_, 
   {{0x7afcc415,0x7dc805be,0x00000000,0x00000000}},	//   _izst, džsk, --, --, 
   {{0x7994c416,0x2634033f,0x4d5c008f,0xd7f8008e}},	//   _inzw, ało_, אדוצ, _буа_, 
   {{0xb224c417,0x8c1c011a,0x00000000,0x00000000}},	//   омил, נוחי, --, --, 
   {{0x213c0042,0x00000000,0x00000000,0x00000000}},	//   fath_, --, --, --, 
   {{0x66c4022e,0xa50800db,0x85043fe6,0x00000000}},	//   _mаkl, _چىكە_, _کومن, --, 
   {{0x6d5c020c,0x32041a7b,0xabb400c7,0xa5080137}},	//   _rcpa, rmly_, ̆атә, _نىكە_, 
   {{0xb4d405d7,0x00000000,0x00000000,0x00000000}},	//   सपी_, --, --, --, 
   {{0xa0200139,0x00000000,0x00000000,0x00000000}},	//   _çönq, --, --, --, 
   {{0x11646bde,0xbef800b5,0xed580798,0x22901291}},	//   _طلبی_, _sにcp, јов_, _آلوس, 
   {{0xdb0c004e,0xe8c4031c,0x1db810eb,0x7afc06be}},	//   _alcà, _གཟེག, _उतरत, _azst, 
   {{0x7994c418,0x601c005f,0x26340034,0xeb28470c}},	//   _anzw, _zīmo, yło_, ржал_, 
   {{0xba280aaa,0x99600118,0x601c00de,0xed6000ef}},	// [10140] مسلم_, líři_, _līml, _pežā_, 
   {{0xbb502e56,0x6d5cc419,0xe8f8009d,0x00000000}},	//   ﺎﻧﻰ_, _ucpa, алз_, --, 
   {{0xaf90001f,0x290c04cc,0x00000000,0x00000000}},	//   _ልማትና_, äfa_, --, --, 
   {{0x799404e6,0x8af006be,0x00000000,0x00000000}},	//   _enzw, lgəm, --, --, 
   {{0x25e4069f,0x6674c41a,0x6720a602,0x213c0083}},	//   टवली_, تدار, rcoj, yath_, 
   {{0x672000eb,0x213c009a,0x2634012d,0x7c6400f1}},	//   scoj, xath_, rło_, _بایل, 
   {{0x2634068f,0x213c180f,0x66c4022e,0xb60800ef}},	//   sło_, vath_, _tаko, dzšķ, 
   {{0x66e431df,0x2634033f,0x213c0072,0xe7b40244}},	//   _доба, pło_, wath_, _بمرد, 
   {{0x1cdc08ea,0x386c0960,0x213c068c,0xd624030d}},	//   _སྙན_, _ćeri_, tath_, _моте_, 
   {{0x2018020c,0x6494009b,0x00000000,0x00000000}},	//   _épik_, _мјех, --, --, 
   {{0x213cc41b,0xe7bc00fe,0x00000000,0x00000000}},	//   rath_, েকীয, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x601c4f67,0x0e3400c0,0x00000000,0x00000000}},	//   _tīmo, мняю, --, --, 
   {{0x346c01e1,0x00000000,0x00000000,0x00000000}},	//   _òṣón, --, --, --, 
   {{0x5ba4c41c,0x00000000,0x00000000,0x00000000}},	//   ораз, --, --, --, 
   {{0xdeb00efb,0x2bc4c41d,0xdb0c09c2,0x2d9c01e6}},	//   _жұмы, रोला, _alcá, öter_, 
   {{0x59000003,0x00000000,0x00000000,0x00000000}},	// [10150] _མཛངས_, --, --, --, 
   {{0x79840810,0xdce4033f,0xca48036b,0x7f5c002f}},	//   udhw, zeję, زلمه_, lgsq, 
   {{0x9f4800d8,0xa3d80073,0x9f4c01e1,0x00000000}},	//   você_, डचा_, _ògó_, --, 
   {{0x7e7c030d,0x6c7800c8,0x3dd0216b,0x7f5c11a7}},	//   owsp, _פארפ, lizw_, ngsq, 
   {{0x7afc00da,0x00000000,0x00000000,0x00000000}},	//   _uzst, --, --, --, 
   {{0x7994006f,0x3d18033f,0x00000000,0x00000000}},	//   _unzw, _दलों_, --, --, 
   {{0x2244c41e,0xa85401ee,0x00000000,0x00000000}},	//   _avok_, _нерә, --, --, 
   {{0x3a380092,0x644400b0,0xdd1c0118,0x36d400f3}},	//   _kwsp_, _ākit, _víři, _еобр, 
   {{0x76b8c41f,0xd54804d3,0x224402f0,0x628403cd}},	//   _улар_, _نجام_, _cvok_, åkop, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x0574075e,0x7e7c03ac,0xf4981f0d,0x00000000}},	//   _زالد, ewsp, _دھشت_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3fc804fb,0x76580309,0x828002dd,0x7ec00129}},	//   تگوی_, nuwy, _аңыз, _râpé, 
   {{0xda1c0c2e,0x5ea800fe,0x00000000,0x00000000}},	//   _बढ़त_, _চেহে, --, --, 
   {{0x224409a8,0xeb98c420,0xceb406be,0x601c00ef}},	//   _zvok_, бив_, _afət_, _līmj, 
   {{0x6b6400cf,0x76580432,0x00000000,0x00000000}},	//   якба, kuwy, --, --, 
   {{0x6e440597,0x3dd0009a,0x2d940a5b,0x15e8012d}},	// [10160] _عندم, bizw_, _ернс, टवार_, 
   {{0x1cdc003d,0xa6e402d2,0x9f4c01e1,0x00000000}},	//   _སྙམ_, _liðþ, _ògò_, --, 
   {{0x9d1800c8,0x76580042,0xe9940023,0x00000000}},	//   _לויט, euwy, _መዛረቢ_, --, 
   {{0xdc980bd9,0x6a8400fd,0x333c0175,0x2cbc083c}},	//   _היטל, _елма, _newx_, ıydı_, 
   {{0x7f8c008f,0x9b14011a,0x38b40022,0x00000000}},	//   ינאַ, _מחכה_, túrö_, --, 
   {{0x6b8400a2,0xe2a403b2,0x388803b2,0xd5600395}},	//   _hakg, _óðir_, ðurí_, етъп, 
   {{0x69ccc421,0xe8c41efe,0x80d06569,0x6b840770}},	//   _imbe, _གཟིག, _সুন্, _kakg, 
   {{0x6b8400a2,0x76580042,0x77900244,0x00000000}},	//   _jakg, buwy, _لیما, --, 
   {{0x6b840159,0x77900133,0xd34001d3,0x00000000}},	//   _makg, _جینا, رہوی, --, 
   {{0x6b8400a2,0x00000000,0x00000000,0x00000000}},	//   _lakg, --, --, --, 
   {{0x69cc0943,0xfee804c5,0xb5fc0309,0x601c00de}},	//   _mmbe, _গণেশ_, _uqša, _zīmj, 
   {{0x60e00882,0x333c031c,0x6b840432,0x00000000}},	//   _ātmā, _gewx_, _nakg, --, 
   {{0x69ccc422,0x88c402f5,0x442c0334,0x9f480407}},	//   _ombe, ্থিক, _htd_, nocé_, 
   {{0xefcc02d3,0x442c009f,0x6280c423,0x7e7c01c7}},	//   _ጥዑይ_, _ktd_, _isoo, rwsp, 
   {{0x6b84c424,0x409402da,0x07cc01e1,0x8af006be}},	//   _bakg, _آلبر, _àìwà_, lgəh, 
   {{0x3dd0009a,0x3e6000b0,0xc1b400c7,0x7bf81cb8}},	//   sizw_, tōtā_, _хәҩы, інар_, 
   {{0x6b84c425,0x442c0375,0x3940c426,0x8f0800f7}},	// [10170] _dakg, _ltd_, tahs_, _ىيىق_, 
   {{0x628000b5,0x630c0154,0x6d5802e2,0x00000000}},	//   _msoo, _সভায়_, òtat, --, 
   {{0xd6d824ce,0xd7f81d56,0x6b84c427,0x97700724}},	//   әте_, буд_, _fakg, етлә, 
   {{0x69ccc428,0x6b844d11,0x6280c429,0xad5401d3}},	//   _embe, _gakg, _osoo, _ٹریڈ, 
   {{0x442c4ec5,0x4ae4036b,0x62801418,0xeaf816da}},	//   _atd_, _зўра, _nsoo, ्धृत_, 
   {{0x442c01ee,0x644402b5,0x6b84c42a,0x4cd401b9}},	//   _btd_, _ākir, _zakg, _آغیز, 
   {{0x6280c42b,0x442c0334,0x73c44445,0xa504016c}},	//   _asoo, _ctd_, мәде, меша_, 
   {{0x442c0408,0x7f4cc42c,0xd7640046,0x49042a8b}},	//   _dtd_, _ndaq, _رەتى_, _سوقق, 
   {{0xe7a40150,0x69ccc42d,0xa3bc012d,0x00000000}},	//   _تۇنى_, _ymbe, ीफ़_, --, 
   {{0x442c7c8c,0x7f4cc42e,0xd58404d3,0x00000000}},	//   _ftd_, _adaq, _رێبه_, --, 
   {{0x442c068c,0x62800a49,0xafe401b9,0x5ea800fe}},	//   _gtd_, _esoo, донл, _চেলে, 
   {{0x62800421,0x76480055,0x00000000,0x00000000}},	//   _fsoo, _kvey, --, --, 
   {{0x62800036,0xe1ec8c91,0x6b84c42f,0xd6cc0220}},	//   _gsoo, _аг_, _rakg, ктi_, 
   {{0x442c03e0,0x6b84c430,0x7f00010b,0xa28000f2}},	//   _ytd_, _sakg, ыҗыд, _شیپو, 
   {{0x7f4c0327,0x6b84c431,0x8024007b,0x6b64010a}},	//   _fdaq, _pakg, _كريم, мква, 
   {{0x7648009a,0x00000000,0x00000000,0x00000000}},	//   _ovey, --, --, --, 
   {{0x63a404f3,0x1e806465,0x6b840af4,0xd1c4001f}},	// [10180] ökni, _алым, _vakg, _ችሎት_, 
   {{0x99e0036b,0x6e440014,0x6b8400a2,0x6d581427}},	//   вжуд, _ٹنگم, _wakg, ótad, 
   {{0x2d980585,0x6b84020c,0xbb3cb071,0x00000000}},	//   _inpe_, _takg, ﻟﺴﻪ_, --, 
   {{0x442cc432,0x61a80882,0x00000000,0x00000000}},	//   _rtd_, _चक्ष, --, --, 
   {{0x442c9bd8,0x65c423be,0x00000000,0x00000000}},	//   _std_, мбда, --, --, 
   {{0x69ccc433,0x442cc434,0x56904e1e,0x2d8800e5}},	//   _umbe, _ptd_, ташт, ndbe_, 
   {{0x442c0120,0x62808786,0x2d8801ab,0xd8200395}},	//   _qtd_, _ssoo, idbe_, _адси, 
   {{0xae1c01ad,0x442c0064,0x00000000,0x00000000}},	//   पदान_, _vtd_, --, --, 
   {{0xefe80020,0x2d980789,0x966000cf,0x00000000}},	//   _ዙሪያ_, _onpe_, _икте, --, 
   {{0x442c4da0,0x601c00b0,0x2d880427,0xa508074d}},	//   _ttd_, _hīmi, jdbe_, _деза_, 
   {{0x19540375,0x26c40175,0x69dc01f4,0x00000000}},	//   וביל_, lzoo_, inpe, --, 
   {{0x62800457,0x2d98c435,0xe2980953,0x26c40218}},	//   _tsoo, _anpe_, _мае_, ozoo_, 
   {{0x601cc436,0x62807c86,0x670c17ee,0x00000000}},	//   _mīmi, _usoo, िधिक_, --, 
   {{0xa1141178,0x54180150,0x69dc01f5,0x12f8011a}},	//   _قوشت, _ارەڭ_, jnpe, _והדב, 
   {{0xd1b402f2,0x00000000,0x00000000,0x00000000}},	//   _زاوا_, --, --, --, 
   {{0x2d9864d3,0x9fe47b8f,0x00000000,0x00000000}},	//   _enpe_, _تسته, --, --, 
   {{0x26c401d4,0x9e040212,0x9da80395,0x00000000}},	// [10190] jzoo_, _очол, _дъна_, --, 
   {{0x8934b93f,0xc0d40092,0xe2a42507,0x00000000}},	//   نعما, _የራስ_, _óður_, --, 
   {{0x3f880093,0x917801fb,0x998c01d3,0x601c00ef}},	//   _kaau_, _hệ_, égű_, _dūmg, 
   {{0x69dcc437,0xb6c400f7,0x91780051,0x00000000}},	//   anpe, нөзд, _kệ_, --, 
   {{0x3f8803c1,0x06ec0037,0x00000000,0x00000000}},	//   _maau_, _छुआव_, --, --, 
   {{0x3f88c438,0x246c06be,0xe6904cec,0x00000000}},	//   _laau_, _cəmo_, الود, --, 
   {{0xc864c439,0x91780208,0x2bc40456,0x05b0012d}},	//   _итти, _lệ_, रोका, _जकरब, 
   {{0x3f88123c,0x26c401d4,0x76480162,0x00000000}},	//   _naau_, bzoo_, _tvey, --, 
   {{0x1950037e,0xf1d000cf,0x00000000,0x00000000}},	//   _ｉｐｓ_, лөкө, --, --, 
   {{0xd4980305,0xbee80205,0x00000000,0x00000000}},	//   _мре_, _üçyı, --, --, 
   {{0xddc805d1,0xe0d40276,0x00000000,0x00000000}},	//   _şişe, евэ_, --, --, 
   {{0xa854011a,0x00000000,0x00000000,0x00000000}},	//   עירה_, --, --, --, 
   {{0x7f180220,0x65a408a5,0x00000000,0x00000000}},	//   діру_, _aðhy, --, --, 
   {{0x3d2401e1,0x00000000,0x00000000,0x00000000}},	//   _rèwó_, --, --, --, 
   {{0x3f880618,0xd1c40020,0x61e401ed,0xeb98c43a}},	//   _faau_, _ችሎታ_, ékle, пив_, 
   {{0x3d240241,0x09d80073,0x6d580413,0x00000000}},	//   _pèwó_, णच्य, ótab, --, 
   {{0xfbd00316,0x7e54084c,0x2bc4041c,0xe938007b}},	// [101a0] _सगरम, _итэц, रोगा, كسات_, 
   {{0xac8403b7,0x26c40218,0x2018004e,0x00000000}},	//   _згол, vzoo_, _èpic_, --, 
   {{0xa818c43b,0x2e24045f,0x601c00b0,0x69dc007c}},	//   ستار_, _hôf_, _pīmi, rnpe, 
   {{0xe6645847,0xa6e43f6e,0x7d009d06,0x26c4007c}},	//   етко, нжел, ülse, tzoo_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x601c02b1,0xc0d4001f,0x00000000,0x00000000}},	//   _hūme, _የራሱ_, --, --, 
   {{0x601c02b1,0xdbe00248,0x26c40218,0x765c1f53}},	//   _kūme, _béèn, szoo_, _åsyn, 
   {{0xc298c43c,0x427401d5,0xc27400d8,0x00000000}},	//   дких_, вгис, влиј, --, 
   {{0x65ac1682,0x61f804ba,0x00000000,0x00000000}},	//   _ṱhuk, tltl, --, --, 
   {{0x64a4c43d,0xbbac5345,0x216401b9,0x212801c3}},	//   _паза, _टक्क, хтиг, ùbh_, 
   {{0x3f88c43e,0x07cc01e1,0x31840150,0x00000000}},	//   _paau_, _àìsà_, ттың, --, 
   {{0x601c0b23,0xd12c0116,0x88c400b8,0xd8d80115}},	//   _nūme, _әх_, _āśli, לקיר, 
   {{0x6618c43f,0x236401e4,0xf1a805d9,0x2e240142}},	//   _kitk, _icoj_, _ڪانه_, _côf_, 
   {{0x6618c440,0x9f480316,0x2e24002d,0x9178004d}},	//   _jitk, mocí_, _dôf_, _vệ_, 
   {{0x6618c441,0x3f8847f8,0xf1a8208f,0x00000000}},	//   _mitk, _taau_, _تانه_, --, 
   {{0x6618c442,0x644801e7,0x91780051,0xde00010a}},	//   _litk, isfi, _tệ_, ăпри, 
   {{0x9f4800eb,0x79f437a4,0x2b400036,0x6448002d}},	// [101b0] nocí_, взах, _dekc_, hsfi, 
   {{0x6618c443,0x6448c444,0xdbe001c7,0x20180200}},	//   _nitk, ksfi, _méén, _hiqi_, 
   {{0x201806af,0x7c340116,0x00000000,0x00000000}},	//   _épis_, _шенх, --, --, 
   {{0x661801ab,0x644826cc,0xfbd0009f,0xa3d00118}},	//   _aitk, dsfi, _ئڪس_, होम_, 
   {{0x6618c445,0xdbe000e8,0x46a402bf,0x366800d8}},	//   _bitk, _néén, лаїв, фало_, 
   {{0x66180724,0x2018c446,0xa0600023,0x644808a5}},	//   _citk, _liqi_, _ጉባኤታ, fsfi, 
   {{0x6618c447,0xd49884dc,0x942000db,0x00000000}},	//   _ditk, ярд_, دوبۇ, --, 
   {{0x661805ac,0x20180009,0xdce401a6,0x00000000}},	//   _eitk, _niqi_, nejđ, --, 
   {{0xdb0c00cf,0x6448054e,0x661802f0,0xb2080139}},	//   _alcú, asfi, _fitk, меиз_, 
   {{0x2364008f,0xdbe001c7,0x644801bf,0x2fd001e3}},	//   _ecoj_, _déén, bsfi, _smyg_, 
   {{0x76580368,0x2018058a,0x40940395,0x00000000}},	//   lrwy, _biqi_, грят, --, 
   {{0x20180a73,0x661801f5,0x9988013a,0x00000000}},	//   _ciqi_, _zitk, _otců_, --, 
   {{0x1e8093fb,0x601c02b5,0x76580368,0x66c4022e}},	//   алям, _rūme, nrwy, _fаku, 
   {{0x76580142,0xa6ec0432,0x3cec1414,0x50600150}},	//   irwy, _ýöňk, _आँखे_, _бекұ, 
   {{0xdc64016c,0x20180067,0xab28c448,0x7658015d}},	//   кард_, _fiqi_, доба_, hrwy, 
   {{0x2eb4a3c3,0xdbe000e8,0x00000000,0x00000000}},	//   _асос, _yéén, --, --, 
   {{0x395001fa,0xaa44013d,0x00000000,0x00000000}},	// [101c0] _bdzs_, тезл, --, --, 
   {{0x765800a9,0x2bc40034,0x5ea8009e,0x66c401a9}},	//   drwy, रोजा, _চেকে, _mаkt, 
   {{0x66186ec5,0x601c02b5,0x76580142,0xac0800d8}},	//   _ritk, _tūme, erwy, _оноа_, 
   {{0x6618c449,0xe7380364,0x64900113,0x2018002e}},	//   _sitk, фед_, nñiš, _xiqi_, 
   {{0x66180664,0x76580cfd,0xe5a40075,0xe5c40945}},	//   _pitk, grwy, киди, кско, 
   {{0xd5ac7427,0xd1d40023,0x601c00de,0x00000000}},	//   يفن_, ርበብ_, _zīmu, --, 
   {{0x18a0c44a,0x98a0c44b,0xdbe06790,0x83f80798}},	//   _карм, _кире, _séén, некс_, 
   {{0xdb0c0268,0x765803cb,0x6618c44c,0x00000000}},	//   _alcù, brwy, _witk, --, 
   {{0x6618c44d,0x6d2003e5,0x97540375,0x76580368}},	//   _titk, _मलंग_, _שימו_, crwy, 
   {{0x66180e29,0x20180227,0x8af000ac,0x80d00154}},	//   _uitk, _siqi_, lgəs, _সুষ্, 
   {{0x20180a73,0xdb0c0142,0x00000000,0x00000000}},	//   _piqi_, _cocê, --, --, 
   {{0x20180481,0x291c01a8,0xdb0c00d8,0x31a802f0}},	//   _qiqi_, _útaf_, _docê, _múzy_, 
   {{0x2018c44e,0x00000000,0x00000000,0x00000000}},	//   _viqi_, --, --, --, 
   {{0x201802d1,0x20d4009f,0x84940092,0x00000000}},	//   _wiqi_, _لتعج, ግራሙን_, --, 
   {{0x7f940323,0x601c02b5,0x20180113,0x6d580162}},	//   _байх, _pīmu, _tiqi_, ótaa, 
   {{0x5f747ff6,0x8bc41084,0x5c042a3b,0x76580042}},	//   _شاعر, асуд, тяга, yrwy, 
   {{0xc684021a,0x3dc00770,0xdd000213,0x397401a9}},	// [101d0] _بې_, _tlhw_, ırıb, ллаё, 
   {{0x7e6cc44f,0x00000000,0x00000000,0x00000000}},	//   _iqap, --, --, --, 
   {{0xc9840b3b,0xf7949731,0x76580042,0x7d040064}},	//   шути, лажэ, wrwy, _uzhs, 
   {{0x76580cfd,0xded00023,0x00000000,0x00000000}},	//   trwy, _የላን_, --, --, 
   {{0xab040220,0xe7340063,0x76580142,0x00000000}},	//   _бірқ, ћеш_, urwy, --, 
   {{0x7e6c0117,0x66d005d1,0x31a800d7,0x7658015d}},	//   _mqap, _sıkç, _fúzy_, rrwy, 
   {{0x7afcc450,0x7c240c6a,0x76580368,0x04d00055}},	//   _hyst, _juhr, srwy, _kāṇv, 
   {{0x7afc7a1e,0x7e6cc451,0xb384530c,0x7c24c452}},	//   _kyst, _oqap, улил, _muhr, 
   {{0x7c24c453,0x59b4c454,0x7afca46e,0x3a280113}},	//   _luhr, _आकार, _jyst, nqap_, 
   {{0xf0a8c455,0x3eb83b97,0xe2c401c0,0x057410e9}},	//   екол_, dyst_, ульд_, _نامد, 
   {{0x7e6cc456,0x7afc12ed,0x1c1c924b,0xdb1c0784}},	//   _aqap, _lyst, _मंगल_, hiqñ, 
   {{0xdb0c03b7,0x26a400cf,0xa3d001ad,0x61ec007f}},	//   _você, _جۇۇپ_, होद_, čbla, 
   {{0xb644037e,0x00000000,0x00000000,0x00000000}},	//   _ｉｄ_, --, --, --, 
   {{0x7c2403a2,0x2d9c0de2,0x00000000,0x00000000}},	//   _buhr, ñte_, --, --, 
   {{0x7e6c0107,0x7afc127b,0x3eb80363,0x3078008f}},	//   _eqap, _ayst, ayst_, _טאַנ, 
   {{0x64900784,0x332c00d8,0x2d9c002d,0x3eb80142}},	//   qñiš, ncex_, űte_, byst_, 
   {{0x7afc00a9,0x3eb8c457,0xa9582824,0xa154002b}},	// [101e0] _cyst, cyst_, فجار_, _kḷpt, 
   {{0x7afcc458,0x601c02b1,0x7c2417da,0x386017da}},	//   _dyst, _hūma, _fuhr, fuhr_, 
   {{0x7afc2880,0x601c04fe,0x9f480120,0x00000000}},	//   _eyst, _kūma, locá_, --, 
   {{0x77680076,0x7afc4bc1,0xad240a52,0x00000000}},	//   _ccex, _fyst, _جىگى, --, 
   {{0x7c24c459,0x7afc00a9,0x4ab4010b,0x8af00213}},	//   _zuhr, _gyst, _төвр, rgəs, 
   {{0xa4c003a2,0x246c06be,0x00000000,0x00000000}},	//   dãƒâ_, _həmi_, --, --, 
   {{0xd464026a,0x888459cf,0x7afc167c,0x95b4035b}},	//   гије_, _خیان, _zyst, ырцә, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7afc0393,0x9f48b618,0xa6e401f4,0x00000000}},	//   _xyst, vocà_, _сжал, --, 
   {{0xdb0c0137,0xc1b801c6,0x00000000,0x00000000}},	//   _docè, тлох_, --, --, 
   {{0xdb0c0561,0xe28c01ec,0x00000000,0x00000000}},	//   _eocè, _ﻓﻴﻬﻡ_, --, --, 
   {{0x3038267a,0x6d58c45a,0xdb0c067c,0x7c240e78}},	//   کتیک_, ótan, _focè, _ruhr, 
   {{0x601c56ce,0xb5fc00c0,0xdb0c0200,0x0ee80166}},	//   _dūma, _apšy, _vocë, гьри_, 
   {{0x7afc11c0,0x3eb80076,0x00000000,0x00000000}},	//   _ryst, ryst_, --, --, 
   {{0xa29001f3,0x00000000,0x00000000,0x00000000}},	//   _ቁርአን_, --, --, --, 
   {{0xc4c4c45b,0x7afc049b,0x246c03be,0xbff8c45c}},	//   _ہے_, _pyst, _cəmi_, _шейх_, 
   {{0x7e6c1cdf,0xdb0c0098,0x79d402bf,0x246c06be}},	// [101f0] _uqap, _kocé, ажає, _dəmi_, 
   {{0x7afcc45d,0xe794c45e,0x3a280309,0x7c240108}},	//   _vyst, یانک, rqap_, _tuhr, 
   {{0x7afc006d,0x3a2803f0,0xd6a800f2,0x00000000}},	//   _wyst, sqap_, کدام_, --, 
   {{0x31e0c45f,0x7afcc460,0x76b80209,0x765c003b}},	//   _पद्ध, _tyst, клер_, _åsyk, 
   {{0xb6a4c461,0x3a2820ac,0x4c040014,0x00000000}},	//   рилл, qqap_, _دَِل, --, 
   {{0xa3d00316,0xd1d4001f,0x955402e9,0xe6900116}},	//   होस_, ርበት_, اخشا, زلىد, 
   {{0x1cd80327,0xf8b82ef1,0x00000000,0x00000000}},	//   རཌི_, _इथिय, --, --, 
   {{0xd3a03500,0x2d2000bc,0xf7700583,0x23b000d1}},	//   слиқ, _मल्ल_, _گاڑ_, قمىس, 
   {{0x36d4084c,0x00000000,0x00000000,0x00000000}},	//   _тоар, --, --, --, 
   {{0x601cc462,0x00000000,0x00000000,0x00000000}},	//   _rūma, --, --, --, 
   {{0x66c800dd,0xd498074d,0x47b800fe,0x108001a9}},	//   _töké, _яра_, _আগতী, ёғиг, 
   {{0x601c0053,0xe0d4c463,0x00000000,0x00000000}},	//   _pūma, рвю_, --, --, 
   {{0x324429db,0x9e606a10,0x00000000,0x00000000}},	//   _телг, овяд, --, --, 
   {{0x6cc4c464,0x9d400026,0x246c06be,0xa2901954}},	//   айга, жерд, _səmi_, _ቁርኣን_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x601c0053,0x246c03b9,0x48dc000d,0x00000000}},	//   _tūma, _qəmi_, _गइबो_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [10200] --, --, --, --, 
   {{0xf0a80241,0xdeb808a8,0x28940114,0x2d94004e}},	//   _gbàà_, _סמיל, ијес, _төмө_, 
   {{0x6e2002e8,0x42a80023,0xed0448cd,0xdd8c00f1}},	//   _èobb, ዋርነት_, _خودپ, _کوۍ_, 
   {{0xab28013d,0x44380064,0x00000000,0x00000000}},	//   _шома_, _įr_, --, --, 
   {{0xb8fcc465,0x66e40107,0x00000000,0x00000000}},	//   _ते_, шода, --, --, 
   {{0x601c0171,0xd5e000d4,0x00000000,0x00000000}},	//   _līmp, ожчи, --, --, 
   {{0x31cc1c82,0x81c400cc,0x00000000,0x00000000}},	//   ৰকাশ, _এদল_, --, --, 
   {{0x2908c466,0x25b00024,0x00000000,0x00000000}},	//   _izba_, _žalą_, --, --, 
   {{0xe618c467,0x27e4c468,0x00000000,0x00000000}},	//   _ада_, mnon_, --, --, 
   {{0x27e404cc,0x06bc0154,0x6d58c469,0x00000000}},	//   lnon_, _আইপি, ótal, --, 
   {{0x27e4a602,0x645c0798,0x6e3400a2,0xe0e401b9}},	//   onon_, ápid, _atyb, рўпо, 
   {{0x27e4c46a,0x53a00657,0x78a001a8,0xa3d0924b}},	//   nnon_, _махб, _álve, होश_, 
   {{0x63a0c46b,0x27e4c46c,0x00000000,0x00000000}},	//   _inon, inon_, --, --, 
   {{0xa3d06b9b,0x63a00030,0x92e40139,0x9254004e}},	//   होर_, _hnon, _әдәб_, _ташт_, 
   {{0x27e4c46d,0x63a0007f,0xd12c0137,0x941c0b97}},	//   knon_, _knon, _تۅپ_, _üşüy, 
   {{0x27e4bc24,0x0ba400cf,0xc1780064,0x00000000}},	//   jnon_, ошум, knėk_, --, 
   {{0x2908007f,0x27e41aef,0x9a84036b,0x63a0c46e}},	// [10210] _azba_, dnon_, шувл, _mnon, 
   {{0x601c00b0,0x27e40165,0xd8385184,0xf1d82314}},	//   _kūmo, enon_, вэд_, योपन, 
   {{0x28d80210,0x00000000,0x00000000,0x00000000}},	//   _येदि, --, --, --, 
   {{0x63a0c46f,0x06d800eb,0x00000000,0x00000000}},	//   _nnon, _তড়ি, --, --, 
   {{0x29080175,0x6e2000d8,0xb7bc0356,0x15b401e0}},	//   _ezba_, _éobt, _niţe, ғыҙы_, 
   {{0x63a0c470,0x27e4c471,0xce380375,0xb9c40150}},	//   _anon, anon_, סאות_, _اقسي, 
   {{0x0574c472,0x97a4192a,0x27e4089c,0x38340276}},	//   تاند, _крал, bnon_, _ынвр, 
   {{0x27e4c473,0x798401e0,0x63a00142,0xa3d01025}},	//   cnon_, lehw, _cnon, होल_, 
   {{0x770400aa,0xd6d80114,0x1dc4190c,0x00000000}},	//   _اژان, _ртв_, रघात, --, 
   {{0x63a0c474,0x79849970,0x00000000,0x00000000}},	//   _enon, nehw, --, --, 
   {{0x6e34c475,0x6d58c476,0x00000000,0x00000000}},	//   _styb, ótam, --, --, 
   {{0x63a0c477,0x7984c478,0x601c4e96,0x00000000}},	//   _gnon, hehw, _dūmo, --, 
   {{0x79841446,0x6fc400c6,0xff2400fe,0x00000000}},	//   kehw, _cóca, পৰ্শ_, --, 
   {{0x27e40007,0x63a0022e,0x22540127,0x020400c0}},	//   znon_, _znon, _الود_, _дзін, 
   {{0x6b546093,0x27e4c479,0xace80276,0x7984004c}},	//   йтах, ynon_, умва_, dehw, 
   {{0xdcac278f,0xfd6801f2,0x6fc4007b,0x6fd40064}},	//   رىق_, _kepụ, _fóca, kšci, 
   {{0x68ec0009,0x00000000,0x00000000,0x00000000}},	// [10220] _sxbd, --, --, --, 
   {{0xfd680521,0xdb0c0dd5,0x1e800b14,0x8d7400ec}},	//   _mepụ, _alcó, _эльм, _ڏاڍا, 
   {{0xe618c47a,0x6fc409d7,0x27e47bad,0x16f0025c}},	//   ңде_, _zóca, tnon_, _བཙུམ_, 
   {{0x8a880014,0x7ae80010,0xf1cc0150,0x00000000}},	//   _پھرِ_, _žete, _ﻗﻀﻴﺘ, --, 
   {{0xdd047b4e,0xf1b80037,0xded00092,0x00000000}},	//   _köşk, ेसान, _የዋና_, --, 
   {{0x27e4c47b,0xfa803500,0x63a001bf,0x20c80aa2}},	//   snon_, _юқум, _snon, ानमध, 
   {{0x69dcc47c,0x6d4c0077,0xdd040166,0x00000000}},	//   mipe, iaba, _möşk, --, 
   {{0x69dcc47d,0xa3d00034,0xf3f80356,0xdc9800df}},	//   lipe, हों_, goţ_, ריקל, 
   {{0x6d4cc47e,0xaadc0490,0x00000000,0x00000000}},	//   kaba, _नेमक, --, --, 
   {{0x8c0009bd,0xfd6801f2,0x601c0374,0xb7bc0356}},	//   ্দিন_, _depụ, _pūmo, _viţe, 
   {{0x63a00280,0x20180066,0x6fc400d8,0x00000000}},	//   _tnon, _èpik_, _sóca, --, 
   {{0x69dcc47f,0x63a0c480,0x443c0204,0x23b00014}},	//   hipe, _unon, mpv_, _رۅخس, 
   {{0x93c80014,0x80d004c5,0x443c017a,0x06bc0011}},	//   _حالہ_, _সুখ্, lpv_, _আইডি, 
   {{0x6d4cc481,0x22441028,0x601c04fe,0x3fc8034c}},	//   gaba, _iwok_, _tūmo, ادگی_, 
   {{0x61f8006c,0xdc340139,0x1050007b,0x20c807c0}},	//   motl, _däğv, _فضيح, _حبشي_, 
   {{0x61f8c482,0x2244129e,0x6fc40005,0x7984013b}},	//   lotl, _kwok_, _tóca, wehw, 
   {{0xdb0c068c,0x69dc0793,0x7984006f,0xdde82614}},	// [10230] _alcò, fipe, tehw, _مرده_, 
   {{0x6d4cc483,0x61f8c484,0x69dcc485,0xa6ac00fe}},	//   caba, notl, gipe, কনাট, 
   {{0x7984c486,0x4f200023,0x00000000,0x00000000}},	//   rehw, ተዘይክ, --, --, 
   {{0x61f8c487,0x6e200798,0x7984002f,0x1da4c488}},	//   hotl, _éobr, sehw, खावत, 
   {{0x61f8c489,0x7bccc48a,0x69dc000d,0x6fa801f9}},	//   kotl, mhau, bipe, टातू, 
   {{0x3a380048,0x61f8c48b,0xe5a0c48c,0x69dc307e}},	//   _itsp_, jotl, диши, cipe, 
   {{0x22440ac5,0x61f826ec,0x7bcc00b0,0x0ee005dc}},	//   _awok_, dotl, ohau, _पेनड, 
   {{0x6d4cc48d,0x7bccc48e,0x3a380263,0x7278c48f}},	//   zaba, nhau, _ktsp_, асос_, 
   {{0x61f8036b,0x394000a3,0xc5a80050,0x246c03b9}},	//   fotl, obhs_, _گُلن_, _səmt_, 
   {{0x61f827be,0xb9dc001f,0x3a3800d8,0x601c00ef}},	//   gotl, _ጣና_, _mtsp_, _dūmm, 
   {{0x7bccc490,0x6d4cc491,0x2244c492,0xfd680521}},	//   khau, vaba, _ewok_, _wepụ, 
   {{0x6d4cc493,0x69dcc494,0x645c0113,0x7c2801e4}},	//   waba, zipe, špic, ĉerl, 
   {{0x61f8c495,0xf1d00228,0x69dc02ce,0x386004e6}},	//   botl, _жөнө, yipe, hrhr_, 
   {{0x7bccc496,0xdb0c0005,0x11280212,0x61f8c497}},	//   ehau, _cocí, _сюди_, cotl, 
   {{0xe0cc01d9,0x7bcc0112,0x310c00dc,0xdb0c0118}},	//   _لٲو_, fhau, _हरिः_, _docí, 
   {{0x7bccc498,0x3a380356,0xaa4401d5,0x00000000}},	//   ghau, _btsp_, жеал, --, 
   {{0xe9d82826,0x6d4cc499,0xed583410,0xfbd0c49a}},	// [10240] ака_, paba, _коп_, رتِ_, 
   {{0x6d4cb63b,0x7bcc0798,0xea880150,0x00000000}},	//   qaba, ahau, лбұл_, --, 
   {{0x3204c49b,0x1da4000d,0x0cd800fe,0x7bccc49c}},	//   illy_, खारत, _দুৰত, bhau, 
   {{0x7bcc07dd,0x69dcc49d,0xeb9896f4,0x61f80205}},	//   chau, sipe, _тим_, zotl, 
   {{0x61f8c49e,0xacf404fb,0x6b940432,0x00000000}},	//   yotl, _دسکت, mdyg, --, 
   {{0x69dc069c,0x61f8022e,0xd5442377,0x28b80153}},	//   qipe, xotl, опље_, _кубэ_, 
   {{0x6fc40077,0x61f8c49f,0xa78400c6,0x76c400d1}},	//   _nóco, votl, _وشرو, يغۇل, 
   {{0x6b9409a5,0x78a0c4a0,0xa3b80597,0xc6e0031c}},	//   ndyg, _álva, شاعر_, ེཌཱུ, 
   {{0x443c004e,0x61f8c4a1,0x5ab4010f,0x00000000}},	//   spv_, totl, ַלטע_, --, 
   {{0x7bcc0399,0x00000000,0x00000000,0x00000000}},	//   zhau, --, --, --, 
   {{0x61f8c4a2,0xdb0c21fc,0xf1d8c4a3,0x6b940209}},	//   rotl, _rocí, योधन, kdyg, 
   {{0x61f8073c,0x3204c4a4,0x7bccc4a5,0x442c6a97}},	//   sotl, ally_, xhau, _iud_, 
   {{0x61f8c4a6,0x6b9400a9,0x7bccc4a7,0xdb0c02fb}},	//   potl, ddyg, vhau, _pocí, 
   {{0x442cc4a8,0x61f8100f,0x7bccc4a9,0x72e800c8}},	//   _kud_, qotl, whau, _פֿײַ, 
   {{0x7bccc4aa,0x442cc4ab,0x4c940212,0x4058007b}},	//   thau, _jud_, мирс, _البح_, 
   {{0x7bcc88d4,0x3a381710,0x442c98dc,0x6b94010e}},	//   uhau, _ptsp_, _mud_, gdyg, 
   {{0x442c2ce2,0x7bcc7418,0x6fc40077,0x07cc01e1}},	// [10250] _lud_, rhau, _zóco, _àìyà_, 
   {{0x7bccc4ac,0x442c1aa7,0x62800337,0x98c40131}},	//   shau, _oud_, _mpoo, يغان, 
   {{0x442cc4ad,0x7bcc261e,0xdb0c00d8,0x20c811a6}},	//   _nud_, phau, _bocã, ानिध, 
   {{0x7bccc4ae,0x9ba01b56,0x6280c4af,0xd7640202}},	//   qhau, _تەرى, _opoo, تەرى_, 
   {{0xd6d86fbd,0x62800218,0x320400ee,0x7f4c0393}},	//   јте_, _npoo, ylly_, _meaq, 
   {{0x442cc4b0,0x20c8194b,0x2ab8011a,0x00000000}},	//   _bud_, ानाध, _המשא, --, 
   {{0x442c1c1d,0x6280c4b1,0xdb1c03f0,0x70a8000d}},	//   _cud_, _apoo, shqä, _छपेल, 
   {{0x442c03bd,0x799406d6,0x645c00d7,0x00000000}},	//   _dud_, _hazw, ápia, --, 
   {{0x79940928,0x442cc4b2,0x7bdc00b5,0xf1d800cd}},	//   _kazw, _eud_, _mmsu, योऽन, 
   {{0x442cc4b3,0x85b85dd0,0x76480d5e,0x3494c4b4}},	//   _fud_, _والس_, _iwey, _назр, 
   {{0x442cc4b5,0x7994c4b6,0x7648013f,0x7bdcc4b7}},	//   _gud_, _mazw, _hwey, _omsu, 
   {{0x7994382f,0xfcbc044e,0x76483926,0x842400d1}},	//   _lazw, _ዳርጋ_, _kwey, _قىلن, 
   {{0xd1b8c4b8,0x442c0156,0x705440bf,0x00000000}},	//   _پاشا_, _zud_, _کنعا, --, 
   {{0x7994c4b9,0x7648c4ba,0x7bdcc4bb,0x442cc4bc}},	//   _nazw, _mwey, _amsu, _yud_, 
   {{0x764831ab,0xf1940d62,0xa19000d8,0x00000000}},	//   _lwey, _وُچھ, _чајч, --, 
   {{0x7648c4bd,0x06bc015b,0xaff80451,0x714000f7}},	//   _owey, _আইসি, _دفعا_, _تۉگۅ, 
   {{0x7994c4be,0x6b94c4bf,0x37e000bd,0x3c1802d5}},	// [10260] _bazw, rdyg, যকার, іўся_, 
   {{0x7bdc0921,0xa96800c6,0x6b94c4c0,0x7d040175}},	//   _emsu, إمام_, sdyg, _fyhs, 
   {{0x76480014,0x79940e78,0x8af003e3,0x00000000}},	//   _awey, _dazw, ngəz, --, 
   {{0x442c387b,0x2d888683,0x76482252,0x5fac0490}},	//   _rud_, lebe_, _bwey, टायल, 
   {{0xdb0c0798,0x96b40640,0x00000000,0x00000000}},	//   _vocã, зују_, --, --, 
   {{0x442c06a3,0x2d8803a2,0x76480042,0x5e54010f}},	//   _pud_, nebe_, _dwey, לינע_, 
   {{0x6280c4c1,0x76480083,0x442c0784,0x7bdc06ea}},	//   _spoo, _ewey, _qud_, _ymsu, 
   {{0x2d888755,0x79940034,0x442c016d,0x82380120}},	//   hebe_, _zazw, _vud_, озис_, 
   {{0x442cc4c2,0x76480337,0x2d880a1d,0x7f4c0139}},	//   _wud_, _gwey, kebe_, _reaq, 
   {{0x442cc4c3,0x7a280006,0x7f4c05b1,0x2d88c4c4}},	//   _tud_, _užte, _seaq, jebe_, 
   {{0x2d88c4c5,0x442c509f,0x7c2801e4,0x00000000}},	//   debe_, _uud_, ĉerk, --, 
   {{0x7f4c00fb,0x00000000,0x00000000,0x00000000}},	//   _qeaq, --, --, --, 
   {{0xdef8c4c6,0x1ee42fb6,0x2d88c4c7,0x53980375}},	//   сын_, سوسی_, febe_, _ליאו, 
   {{0x21740364,0x53a00150,0x601c0171,0xc0c40150}},	//   _худр, _يمەك, _mūmi, _жәми, 
   {{0x48dc0574,0x7994c4c8,0x0c8400fb,0x7f94022e}},	//   _गेलो_, _razw, нытм, _жайх, 
   {{0xdde804fb,0x8af003e3,0x00000000,0x00000000}},	//   _گربه_, lgəy, --, --, 
   {{0x2d88c4c9,0x79940810,0xbdf400ea,0x00000000}},	// [10270] bebe_, _pazw, _опиј, --, 
   {{0x2d88c4ca,0x7648c4cb,0xdb0c004e,0xf8b001d3}},	//   cebe_, _rwey, _vocà, پکس_, 
   {{0x76481529,0xc1780006,0x3ea40014,0x8e3801d5}},	//   _swey, lnės_, _رشکہ, _وسیر_, 
   {{0x7994c4cc,0xb8d40d2c,0x7bdc4a7d,0xf6f404fb}},	//   _wazw, _जप_, _umsu, وزشگ, 
   {{0xdb206b5d,0x9f48036e,0x645cc4cd,0x6fd40051}},	//   _سوسی, encë_, ápin, nơca, 
   {{0x06f4c4ce,0x601c5106,0xc1780153,0x84d800cd}},	//   رسنج, _dūmi, inės_, _śruṇ, 
   {{0x6fc4007b,0x645c0306,0x95480137,0x00000000}},	//   _sócm, špin, _ۇشاق_, --, 
   {{0x2d88c4cf,0x7648c4d0,0x9b2800b8,0x1fd40b4c}},	//   zebe_, _twey, _cūḍā, डफोड, 
   {{0x2d889147,0x7648058a,0x9f480240,0xf8dc9417}},	//   yebe_, _uwey, ancë_, _मधुप, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x05743ed0,0xc1780024,0x00000000,0x00000000}},	//   _سالد, enės_, --, --, 
   {{0xafa004a9,0x2d88c4d1,0xc50c010f,0x00000000}},	//   тқиқ, webe_, _פלאָ, --, 
   {{0x2d88c4d2,0x6fc40005,0xc17800c0,0x00000000}},	//   tebe_, _hóck, gnės_, --, 
   {{0xb4f8008f,0xd344797d,0x00000000,0x00000000}},	//   ַפּי, _بیکه_, --, --, 
   {{0x2d88c4d3,0x6ff401c6,0xeb9817a0,0x00000000}},	//   rebe_, _очих, оив_, --, 
   {{0x6ff406d5,0x2d8815fa,0x6fa801f9,0x00000000}},	//   _تستط, sebe_, टाळू, --, 
   {{0x6ff00055,0x00000000,0x00000000,0x00000000}},	// [10280] cāca, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb0c10d5,0x6d5ca2e5,0x4cdc015b,0x00000000}},	//   _vocá, _idpa, _মুরু, --, 
   {{0xa6c800aa,0x6d5c007c,0x5bc02cdd,0x00000000}},	//   يوال_, _hdpa, _айюб, --, 
   {{0xdb0c04d4,0x78240efc,0xafe003cd,0x5fac0073}},	//   _tocá, رعمل, åøye, टातल, 
   {{0x645c0798,0xe4a40120,0x3d14000d,0x00000000}},	//   ápio, дрио, _धरमे_, --, 
   {{0xd494c4d4,0x02b800dc,0xf1b000cd,0xb7bc00cc}},	//   дры_, ेन्न, जानन, _আগৰট, 
   {{0xc1780024,0x77900bce,0x683800b8,0x00000000}},	//   ynės_, _میما, _vįdd, --, 
   {{0xc0f00023,0xc3c40166,0x00000000,0x00000000}},	//   _ሃዋሁ_, _җөйл, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd36cc4d5,0x69cc017a,0x93100f1c,0x00000000}},	//   _ич_, _mlbe, _یومش, --, 
   {{0x6d5cc4d6,0x934000f3,0x6fe000cc,0x00000000}},	//   _adpa, _анце, _নৱবৈ, --, 
   {{0x6d5c0076,0x4cdc009e,0x753c01ed,0x55500133}},	//   _bdpa, _মুলু, _őszi, _سپۆر, 
   {{0xfd740323,0x6fc4c4d7,0x1944037e,0x8d8401d5}},	//   элгэ, _lóch, _ｄｖｄ_, кусд, 
   {{0xc1780006,0x24583a71,0x0f200092,0x00000000}},	//   snės_, nīm_, ተመለከ, --, 
   {{0x6d5c02d0,0x5aa80451,0x6fc400ae,0x6e28002e}},	//   _edpa, ياءَ_, _nóch, ñmbë, 
   {{0x69cc02fb,0xe51c00dc,0x00000000,0x00000000}},	// [10290] _blbe, येति_, --, --, 
   {{0x20080200,0x00000000,0x00000000,0x00000000}},	//   llci_, --, --, --, 
   {{0x645cc4d8,0x9f4806af,0xdb0c0129,0x601c00de}},	//   ápil, encé_, _alcô, _dūmv, 
   {{0x69ccc4d9,0xfb34010f,0x00000000,0x00000000}},	//   _elbe, _ראָש_, --, --, 
   {{0x6fc40597,0x6458c4da,0x645c00e2,0xd67801d5}},	//   _dóch, _avti, špil, تحضا_, 
   {{0x64580175,0x69cc00c0,0xd1d40092,0x00000000}},	//   _bvti, _glbe, ይበት_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x601c02b1,0x6fc401e7,0xe9a40150,0xd3a00075}},	//   _kūmu, _góch, _يگەن_, тлиқ, 
   {{0x644c003d,0x69cc0240,0xa8002737,0x27380051}},	//   _ħbie, _ylbe, ğıta, _ừng_, 
   {{0xf1b00597,0xc18401d9,0x26140210,0x00000000}},	//   اءة_, نگى۪, _पीपी_, --, 
   {{0x39500c86,0x42c800f7,0x76580ea0,0x245824b8}},	//   _mezs_, згөн_, lswy, cīm_, 
   {{0x6498025f,0x395007de,0x72d406ed,0x00000000}},	//   _מסעד, _lezs_, _поеф, --, 
   {{0xe1ec06bb,0xdca001b9,0x7658c4db,0x92e8598f}},	//   _бг_, қати, nswy, _براق_, 
   {{0x20080fcf,0xb39c0208,0x76580042,0x00000000}},	//   alci_, _độhi, iswy, --, 
   {{0xafe42c9d,0x1e800220,0x3d1401f9,0x00000000}},	//   _покл, _ұлым, _धरणे_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xada49cff,0x6fc401e7,0xa9a4009d,0x6d58148b}},	// [102a0] _запл, _róch, ниад, ótas, 
   {{0x7658002d,0x2bd0000d,0x6d5c005c,0x6fc40332}},	//   dswy, _सतवा, _udpa, _sóch, 
   {{0x2d980421,0x5828025c,0x7658c4dc,0x00000000}},	//   _iape_, _སྤྱོ_, eswy, --, 
   {{0x2d98052f,0x395008cd,0x24580b13,0x3d14c4dd}},	//   _hape_, _eezs_, vīm_, _धरते_, 
   {{0x2d98c4de,0x7dd40133,0x66d80022,0x00000000}},	//   _kape_, _سمێڵ, џьер_, --, 
   {{0x24580318,0x69ccc4df,0x6fc43822,0x2d98c4e0}},	//   tīm_, _ulbe, _dóci, _jape_, 
   {{0xc7b001ed,0x7a280024,0x43941553,0x6fc401e7}},	//   _پڑا_, _užta, вайс, _tóch, 
   {{0x2d983459,0x2a900100,0xd5440166,0x987800df}},	//   _lape_, _kņb_, _үпте_, _מאלט, 
   {{0x24581a14,0x76580142,0xe5701291,0xdb040174}},	//   sīm_, cswy, _مطا_, áløg, 
   {{0x27e4c4e1,0x2d98c4e2,0x6458005c,0x91e00063}},	//   lion_, _nape_, _tvti, лоње, 
   {{0x79800112,0x26c40009,0x61ec0153,0x1540010a}},	//   _ölwe, lyoo_, _čilė, _сехм, 
   {{0x2d980270,0x27e4c4e3,0x6304007b,0x00000000}},	//   _aape_, nion_, _كوال, --, 
   {{0x26c4c4e4,0x2d98c4e5,0x0e340c9e,0xf8ac74f6}},	//   nyoo_, _bape_, лняю, _टप्प, 
   {{0xbbc80401,0x27e4c4e6,0x601c0024,0x2d98c4e7}},	//   रस्क, hion_, _rūmu, _cape_, 
   {{0x27e4c4e8,0x2fd02776,0x2d98c4e9,0x5ba400c7}},	//   kion_, ângâ_, _dape_, нраз, 
   {{0x6d58c4ea,0x27e40dd4,0x601c02b1,0x39500c86}},	//   ótar, jion_, _pūmu, _sezs_, 
   {{0x27e4c4eb,0x99643304,0x8af800c7,0x395004cc}},	// [102b0] dion_, етел, ентс_, _pezs_, 
   {{0x2d985114,0x1040001f,0x49741086,0x26c40009}},	//   _gape_, _የተቀመ, ллус, dyoo_, 
   {{0x7e7c014a,0x6fc406ed,0x27e4c4ec,0x4ddc02e4}},	//   ltsp, _sóci, fion_, _מחזו, 
   {{0x27e4c4ed,0x2d98c4ee,0x76580368,0xd76001b9}},	//   gion_, _zape_, tswy, انشی, 
   {{0x7e7cc4ef,0x18b0052f,0x9f480407,0x2d9802e2}},	//   ntsp, _әҙер, locó_, _yape_, 
   {{0xd5b80598,0x7e7cc4f0,0x857800a7,0xc8640131}},	//   ясе_, itsp, есът_, _әтри, 
   {{0x27e4c4f1,0xd90cc4f2,0x94a8036b,0x33f4c4f3}},	//   bion_, _ایا_, ятда_, кчис, 
   {{0x27e4c4f4,0x981401d9,0x7e7c11ad,0x26142983}},	//   cion_, _سبزا, ktsp, _पीठी_, 
   {{0xb5940124,0x7e7c01f5,0x07080451,0x0ee0107c}},	//   _ииаш, jtsp, _ٻيلي_, _पेंड, 
   {{0x7e7cc4f5,0x683800b8,0x00000000,0x00000000}},	//   dtsp, _hįda, --, --, 
   {{0x2d98c4f6,0x7e7c0575,0x3374004e,0x00000000}},	//   _rape_, etsp, _агер, --, 
   {{0x2d985909,0xd340006c,0x712400f1,0xafe401a9}},	//   _sape_, _صفتی, _یرغل, томл, 
   {{0x7e7cc4f7,0x00000000,0x00000000,0x00000000}},	//   gtsp, --, --, --, 
   {{0x27e4c4f8,0xf1b400dc,0x00000000,0x00000000}},	//   zion_, _अचिन, --, --, 
   {{0x2d98c4f9,0x7e7cc4fa,0x27e40086,0x1d042b97}},	//   _vape_, atsp, yion_, вери_, 
   {{0x27e4c4fb,0x26c40a4d,0x2d9801f7,0x29082f53}},	//   xion_, yyoo_, _wape_, _ryba_, 
   {{0x7e7c0c8c,0xf1b406e3,0xef18013e,0x2d98c4fc}},	// [102c0] ctsp, _अचान, _юми_, _tape_, 
   {{0x26140307,0x2490033f,0x27e4015d,0x00000000}},	//   _पीढी_, łymi_, wion_, --, 
   {{0x27e4c4fd,0x9f48004e,0xc0ec0240,0x00000000}},	//   tion_, cocó_, _ቅርሺ_, --, 
   {{0xf7e80131,0x7e682438,0x6fd400c5,0x00000000}},	//   ىرنى_, šepe, मोचू, --, 
   {{0x27e4c4fe,0x00000000,0x00000000,0x00000000}},	//   rion_, --, --, --, 
   {{0xd940c4ff,0x290800c7,0xc0f8001f,0xc0d4001f}},	//   _вери, _tyba_, _ለራሱ_, _ከራሱ_, 
   {{0x2794c500,0x27e4c501,0x00000000,0x00000000}},	//   _ишар, pion_, --, --, 
   {{0xc27406ed,0xcffc009e,0x6f1402d0,0xa024032e}},	//   глиј, ীগড়_, _ozyc, _mjöð, 
   {{0x7790350a,0xa49001d5,0xf7200092,0xe578c502}},	//   _دینا, _چیتت, ታቸውን, _оза_, 
   {{0x42a40032,0xe5a4c503,0x25a8007b,0x5bbc3cc3}},	//   _ҡулғ, _шизи, _تدري_, _एक्व, 
   {{0x6f140857,0x2fd001e3,0xf080179e,0xe3b0b1bf}},	//   _azyc, _blyg_, میوپ, _پرا_, 
   {{0x7e7c60e2,0x9f482760,0x626405f5,0x5ed80154}},	//   ttsp, vocó_, _авда, _যুগে, 
   {{0xd48401c6,0x7e7c057d,0x00000000,0x00000000}},	//   _зөөж_, utsp, --, --, 
   {{0x91e0c504,0xd1c406bd,0x00000000,0x00000000}},	//   _коче, _илче_, --, --, 
   {{0x7e7cc505,0x2fd000bf,0x6aa4062c,0x2ec00075}},	//   stsp, _flyg_, _arkf, _һөрм, 
   {{0x7e7cc506,0x6fc40208,0x5fac01f9,0x00000000}},	//   ptsp, _sócv, टाळल, --, 
   {{0x2b440077,0x7b146d5f,0x00000000,0x00000000}},	// [102d0] ñoca_, удах, --, --, 
   {{0xdb0c00d0,0xa02401a8,0xc0ec0092,0x00000000}},	//   _kocú, _fjöð, _ቅርስ_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd800074d,0x1b48007b,0x36d42901,0x00000000}},	//   рăм_, _تؤدي_, лоер, --, 
   {{0x7bccc507,0x36681429,0xdd0400a2,0x3cf8000d}},	//   mkau, хало_, _söňk, _उखडे_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa504084c,0x73c400fd,0x00000000,0x00000000}},	//   леша_, ләде, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7bccc508,0x87e4011b,0x7c2801e4,0x00000000}},	//   ikau, _тюре, ʈera, --, 
   {{0xe1f4c509,0x7bccc1d1,0x00000000,0x00000000}},	//   лгы_, hkau, --, --, 
   {{0x7bcc0664,0xd4986c6b,0x9f480bdf,0x2fd00142}},	//   kkau, _юра_, vocò_, _plyg_, 
   {{0x7bcc0218,0x00000000,0x00000000,0x00000000}},	//   jkau, --, --, --, 
   {{0x291c022c,0xa778010f,0x7bcc0254,0xe818012d}},	//   _útav_, ערשפ, dkau, _फीफा_, 
   {{0x88c400fe,0x7bcc0036,0x6da40063,0x00000000}},	//   _এইসক, ekau, ћива, --, 
   {{0x320401ed,0x30c008b0,0x6c347660,0xe8040118}},	//   moly_, ﺭﻣﻪﻧ, افرا, षकमा_, 
   {{0x7bcc1c81,0xdb0c06ed,0x6fc42760,0x7f74030d}},	//   gkau, _incê, _cóct, _куьц, 
   {{0x6f140210,0x00000000,0x00000000,0x00000000}},	// [102e0] _uzyc, --, --, --, 
   {{0x7bccc50a,0x32040306,0xa8481291,0x00000000}},	//   akau, noly_, ّلام_, --, 
   {{0x7bcc75e8,0x6e34c50b,0x397802e8,0x18b00166}},	//   bkau, _huyb, ъстю_, бәтр, 
   {{0x3204c50c,0xe738013e,0x7bcc1f0c,0x6e340166}},	//   holy_, хед_, ckau, _kuyb, 
   {{0x32040851,0x65840139,0x65c401d5,0x7b940244}},	//   koly_, гыйз, лбда, _ئاپڕ, 
   {{0x6e3400b5,0xa2a001ad,0xa8d0010a,0x753c00e5}},	//   _muyb, कटस्, _гιод, _őszr, 
   {{0x3204c50d,0x7980002f,0x00000000,0x00000000}},	//   doly_, _ölwa, --, --, 
   {{0x8334013e,0x853c036e,0xdce40327,0x00000000}},	//   шних, _anėt, nejġ, --, 
   {{0x22401574,0xdb0c4056,0xd254084c,0x00000000}},	//   ëkk_, _ancê, лцэ_, --, 
   {{0x20180200,0xda78010f,0x3d140073,0x60d8002f}},	//   _shqi_, עניר, _धरले_, tztm, 
   {{0x65780076,0x7bcc1f39,0xa44400c0,0x06bc00eb}},	//   _icth, ykau, _снед, _আইটি, 
   {{0x6e340334,0xb7bc054e,0x4420c50e,0x5fac121d}},	//   _buyb, _piţi, _òi_, टाइल, 
   {{0x32041311,0x1ea80b24,0x60d800e5,0xae14000d}},	//   boly_, راحي_, sztm, _दीहन_, 
   {{0x6e34c50f,0x20d406c2,0xf7d008a5,0xbd4400ec}},	//   _duyb, _متعج, _áþví_, شنري, 
   {{0xd13c068f,0x7bccc510,0xf1b00b7d,0xf1a850bc}},	//   łącz_, tkau, जारन, _جانه_, 
   {{0x7bccc511,0x261402a0,0x8fa400f3,0x00000000}},	//   ukau, _पीसी_, _гаће, --, 
   {{0x7bccc512,0xb95400a7,0x00000000,0x00000000}},	// [102f0] rkau, иващ, --, --, 
   {{0x7bccc513,0x05a417ee,0x00000000,0x00000000}},	//   skau, _गोलब, --, --, 
   {{0x3ea8c514,0x6fa80073,0x6b8001e4,0x2d9c01e4}},	//   _hrat_, _जोडू, ĵogr, ɾte_, 
   {{0x3ea8c515,0x6e34011f,0x320402f0,0x144407a5}},	//   _krat_, _yuyb, zoly_, қоиқ_, 
   {{0x3f880117,0x2614000d,0x00000000,0x00000000}},	//   _mbau_, _पीही_, --, --, 
   {{0xb5fc012c,0x7afc02d0,0xf9d40166,0x7c280115}},	//   _ovše, _ixst, _тогэ, ʈern, 
   {{0x32040170,0xb4640e4a,0xd7f80124,0xed8c0023}},	//   voly_, شگاه, _зуа_, _ህዝበይ_, 
   {{0x3ea8c516,0x600c0086,0xd58404d3,0x657802d0}},	//   _orat_, bùmi, _ڕێته_, _ecth, 
   {{0xe3b4c517,0x26140401,0x7ae800ee,0x9f900174}},	//   рбы_, _पीवी_, _ýetd, vøðu_, 
   {{0x41440020,0x6ff0005f,0x3f880139,0x708403c5}},	//   _የአገሪ, māci, _abau_, агоз, 
   {{0x3ea8c518,0x6ff000da,0x600c0086,0x9f90022c}},	//   _arat_, lāci, nùmw, tøðu_, 
   {{0xf1d8a22b,0x78a00174,0x3204c519,0x00000000}},	//   योजन, _álvu, soly_, --, 
   {{0x3ea80428,0x6ff000da,0x9f9006ea,0xfe440133}},	//   _crat_, nāci, røðu_, یکیی, 
   {{0x3ea80072,0x6da4c51a,0x00000000,0x00000000}},	//   _drat_, шига, --, --, 
   {{0x3ea8c51b,0x2d9c01f1,0xc0a8212d,0x6b545cfa}},	//   _erat_, ľte_, _مايل_, итах, 
   {{0x6ff000da,0x2d9c0e96,0x6e34011f,0x3f8801e1}},	//   kāci, žte_, _tuyb, _gbau_, 
   {{0x3ea8c51c,0xbc1802dd,0x7c28010f,0xed64032e}},	// [10300] _grat_, уірі_, ĉerp, _óþol_, 
   {{0x6ff00aed,0x2bf400cc,0x50400092,0x2bd0000d}},	//   dāci, চতেই_, _የተነሣ, _सतका, 
   {{0x7afc1730,0xefdc0023,0x6d4cc51d,0x18a0c51e}},	//   _exst, _ሓምድ_, mbba, жахм, 
   {{0x7afc020b,0x6578010a,0x1864c064,0x6d4c0175}},	//   _fxst, _scth, раци_, lbba, 
   {{0x7ae804a7,0x6ff0005f,0xd704518d,0xa5e401e0}},	//   _žetv, gāci, анце_, аһаҡ_, 
   {{0x600c0086,0x6d4c00b5,0x00000000,0x00000000}},	//   rùmi, nbba, --, --, 
   {{0xdb0c50b6,0x6d4c0a55,0x7c2801e4,0x00000000}},	//   _ancè, ibba, ʈero, --, 
   {{0x14c4040e,0x6d4c0076,0xdc34010f,0x6ff000de}},	//   рыши_, hbba, סאפט_, bāci, 
   {{0xf1b00073,0x02b027a6,0x6ff00055,0x00000000}},	//   जांन, जमेन, cāci, --, 
   {{0x7ae80209,0x745000e5,0xa0600092,0x00000000}},	//   _ýete, _کھوئ, _ለተከታ, --, 
   {{0xdb0c381a,0x202802d3,0x3ea825b4,0xf5b40946}},	//   _encè, ተገብረ, _srat_, _устю, 
   {{0x3ea8c51f,0x6fc41dec,0x9f480023,0x6d4c2a6e}},	//   _prat_, _sócr, micë_, ebba, 
   {{0xdef8c4c6,0x2364008f,0x9f480023,0x3ea80327}},	//   тын_, _idoj_, licë_, _qrat_, 
   {{0x2244c520,0x3ea8c521,0x644801f5,0x44240356}},	//   _itok_, _vrat_, opfi, lmm_, 
   {{0x6ff00029,0x3ea80204,0x9f480023,0xd12c014b}},	//   zāci, _wrat_, nicë_, _фх_, 
   {{0x3ea8c522,0x4424c523,0x6d4c6d78,0x3f880036}},	//   _trat_, nmm_, abba, _ubau_, 
   {{0x7f5c0bf1,0xba5400c6,0xca7400d1,0x5b24009d}},	// [10310] masq, صناع, قالغ, рьва, 
   {{0x7f5cc524,0xc17802d5,0x6ff00318,0x9f480240}},	//   lasq, ngė_, vāci, kicë_, 
   {{0x224400c0,0xc1780153,0x00000000,0x00000000}},	//   _ltok_, igė_, --, --, 
   {{0x7f5c0986,0x2244c525,0x6ff000da,0x600c0428}},	//   nasq, _otok_, tāci, rùmw, 
   {{0xb6a4c526,0x00000000,0x00000000,0x00000000}},	//   силл, --, --, --, 
   {{0x7f5c4375,0x6ff00029,0x44240a73,0xe6900131}},	//   hasq, rāci, emm_, سلىد, 
   {{0x2244c527,0x7f5c0986,0x6ff01a14,0x9f480200}},	//   _atok_, kasq, sāci, gicë_, 
   {{0xdb0c0ba1,0xb7bc0311,0x6ff01a14,0x386001ab}},	//   _ancé, _piţu, pāci, mshr_, 
   {{0x97000075,0x7f5cc528,0xba900150,0x00000000}},	//   _بېشى, dasq, _ﺟﻴﻪﻙ_, --, 
   {{0x3940c529,0x4424c52a,0xf1b087ee,0x00000000}},	//   nchs_, amm_, जाइन, --, 
   {{0x22440066,0x394017da,0x7f5c0393,0x00000000}},	//   _etok_, ichs_, fasq, --, 
   {{0x7f5cc52b,0xdb0cc52c,0x442400db,0x43740150}},	//   gasq, _encé, cmm_, _душт, 
   {{0x1e800024,0x932400db,0x71a401c6,0x7e680427}},	//   плям, _ئران, _галз, šepn, 
   {{0x9d402de5,0x2250010e,0x6d4c002f,0x00000000}},	//   зерд, _çyka_, ubba, --, 
   {{0x7f5c0784,0x6d4cc52d,0x53d800ab,0xac9800f2}},	//   basq, rbba, _बताश, دنزا_, 
   {{0xa3c802ab,0x7f5cc52e,0x3940067c,0xc0440244}},	//   रॉप_, casq, echs_, _بخوو, 
   {{0x3a380b1d,0x6b940064,0xed5801ee,0x00000000}},	// [10320] _cusp_, _čagč, _йоп_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4424c52f,0xad2400d1,0x00000000,0x00000000}},	//   ymm_, _دىدى, --, --, 
   {{0x9f480023,0x39400036,0x7d080356,0x00000000}},	//   vicë_, achs_, şesc, --, 
   {{0xe5c40ec6,0xe5a40075,0xa3c801ad,0x00000000}},	//   йско, йиди, रॉफ_, --, 
   {{0x6b946f68,0x7f5c0309,0x23f401e0,0x9f48036e}},	//   leyg, zasq, өмлө_, ticë_, 
   {{0x7f5c0986,0x44240076,0xf5680150,0x00000000}},	//   yasq, tmm_, ршік_, --, 
   {{0x6b944935,0x6448011c,0x9f48036e,0xdce40003}},	//   neyg, rpfi, ricë_, sejħ, 
   {{0x7ae80f99,0x7f5c78aa,0xe6180107,0x00000000}},	//   _þett, vasq, _бда_, --, 
   {{0x6448933c,0x6d5809f3,0xdef83419,0xc1780024}},	//   ppfi, ðtal, ғым_, ugė_, 
   {{0xe4505263,0x7f5c0bf1,0x9f480407,0xc1780024}},	//   _رضا_, tasq, licé_, rgė_, 
   {{0x78a0002d,0x236401e4,0x00000000,0x00000000}},	//   _âlve, _udoj_, --, --, 
   {{0x7f5c0bf1,0x22442819,0xe314c530,0x63e400aa}},	//   rasq, _utok_, _اباب, _پېښې_, 
   {{0x63a0c531,0x7e6827c4,0x7f5cc532,0x5eb80154}},	//   _haon, šepo, sasq, উনলে, 
   {{0x63a0c533,0x7f5c1bb7,0x7a280006,0x3a380393}},	//   _kaon, pasq, _užti, _susp_, 
   {{0x63a00851,0x7f5c0bf1,0x6b940014,0x685402d3}},	//   _jaon, qasq, geyg, _ምሁራት, 
   {{0x63a0c534,0x394007ea,0x249c0162,0xfaf80064}},	// [10330] _maon, tchs_, _lstm_, _žūb_, 
   {{0x20080fff,0x63a0c535,0x3940c536,0xd83805f5}},	//   loci_, _laon, uchs_, гэд_, 
   {{0xb89443f6,0x3940c537,0x865800b8,0x6b9474b1}},	//   تلاع, rchs_, _āmuṣ, beyg, 
   {{0x63a0c538,0x3940060a,0xb6d4c539,0x6280058a}},	//   _naon, schs_, يقاع, _oqoo, 
   {{0xb5fc0122,0x4ae402d5,0x249c045a,0xd1bc0240}},	//   _avša, _еўра, _astm_, ስሓብ_, 
   {{0x38600175,0x9fac0118,0x00000000,0x00000000}},	//   pshr_, dří_, --, --, 
   {{0x62800a81,0x200819a2,0x63a0c53a,0x00000000}},	//   _aqoo, koci_, _baon, --, 
   {{0x61e801e4,0x766401d9,0x63a04230,0x291000d7}},	//   _amfl, _وُزم, _caon, ínať_, 
   {{0x20080b91,0x63a0379c,0xd4980131,0x9fac013a}},	//   doci_, _daon, _әрз_, gří_, 
   {{0x63a00093,0x76480230,0xd7f80aac,0xd9f81157}},	//   _eaon, _itey, _руҳ_, ्वित_, 
   {{0x63a0c53b,0x645c01f1,0x7e6801a6,0x54b0104e}},	//   _faon, špir, šepl, _хәлф, 
   {{0x2008c53c,0x9fac0118,0x142800d4,0x00340ca8}},	//   goci_, bří_, _сізо_, _ẹlẹ́, 
   {{0xd9f80574,0x301404da,0xdedc0023,0x92e400fe}},	//   ्वात_, йдүр, _ሓውኻ_, _মুৰ_, 
   {{0x63a0c53d,0x2bd023c1,0x453000db,0xd13801c6}},	//   _zaon, सस्थ, _تۉۉر, _схд_, 
   {{0x63a0c53e,0x2008c53f,0xdcac0131,0x68380055}},	//   _yaon, boci_, پىق_, _gįdh, 
   {{0x2008c540,0x76480085,0x1d0411f7,0xee38014b}},	//   coci_, _otey, цеси_, _кни_, 
   {{0x76480223,0xed34c541,0x6b94c542,0xada40064}},	// [10340] _ntey, _мэнэ, reyg, _дапл, 
   {{0x6b943602,0xa9680138,0x00000000,0x00000000}},	//   seyg, рижа_, --, --, 
   {{0x7648c543,0x5fac0574,0xa3c802ab,0xbb44001f}},	//   _atey, _जोडल, रॉड_, ያስችላ, 
   {{0x6b940009,0x00000000,0x00000000,0x00000000}},	//   qeyg, --, --, --, 
   {{0x63a0c544,0xad2404da,0x18180014,0x00000000}},	//   _raon, _دىگى, جرٕک_, --, 
   {{0x63a0c545,0x76480076,0xe45000c6,0xe4680353}},	//   _saon, _dtey, وضع_, ашил_, 
   {{0x63a0c546,0x76480296,0x2ca8010a,0x1864c547}},	//   _paon, _etey, nvbd_, _мари_, 
   {{0x9fac0316,0x66080036,0xdd0000cd,0x00000000}},	//   tří_, sofk, _śrīl, --, 
   {{0x2008c548,0x63a0c549,0x76480076,0xb3840014}},	//   voci_, _vaon, _gtey, سێوم_, 
   {{0x63a0c54a,0x6d18000d,0x00000000,0x00000000}},	//   _waon, _धरंग_, --, --, 
   {{0x63a0c54b,0x200823db,0x78440024,0x32d8036b}},	//   _taon, toci_, _tėve, لدیک_, 
   {{0x7a280024,0x00000000,0x00000000,0x00000000}},	//   _užtv, --, --, --, 
   {{0x20081068,0x62800009,0xe7e00456,0x8af003e3}},	//   roci_, _uqoo, _खतना_, nbəd, 
   {{0xddcc0276,0x61e80276,0x81448efb,0x20080268}},	//   ducţ, _umfl, _عنعن, soci_, 
   {{0xa800046c,0x61f801e2,0x0ca8022e,0x00000000}},	//   şıya, mntl, отти_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3f98c54c,0xdb0c09a9,0x61f80af9,0xdde800f2}},	// [10350] mesu_, _rocó, ontl, _نرده_, 
   {{0x3b880597,0x3f98c54d,0xdb0c004e,0x61f83f5b}},	//   _ťǻĩľ_, lesu_, _socó, nntl, 
   {{0x61f8c54e,0x7648c54f,0xdb0c7a26,0x00000000}},	//   intl, _stey, _incí, --, 
   {{0x76b838c2,0x3f98c550,0x76480076,0x9a640014}},	//   йлер_, nesu_, _ptey, _وۅزل_, 
   {{0x61f80139,0x00000000,0x00000000,0x00000000}},	//   kntl, --, --, --, 
   {{0x69dcc551,0x3f98c552,0x85e802bf,0x00000000}},	//   chpe, hesu_, одів_, --, 
   {{0xc8648b5b,0x3f98c553,0x00000000,0x00000000}},	//   _отти, kesu_, --, --, 
   {{0x61f8c554,0x3f98c555,0x7768014b,0xe4d0007b}},	//   entl, jesu_, _udex, عقيد, 
   {{0x764801b2,0x3f98c556,0x6d5805f7,0xa2a006b1}},	//   _utey, desu_, ðtak, कटग्, 
   {{0x61f80036,0xe16000d1,0x2b500210,0x00000000}},	//   gntl, ىگىي, zbyc_, --, 
   {{0x92c8015b,0x3f98c557,0xc2c802f2,0x00000000}},	//   রছে_, fesu_, مبیل_, --, 
   {{0x69dc07e4,0x3f980e14,0x34940107,0x271c00cc}},	//   zhpe, gesu_, _маҷр, _ফলতো_, 
   {{0x61f80472,0xe28c1ebb,0x3d1060c7,0x00000000}},	//   bntl, _яа_, _दुबे_, --, 
   {{0xd1b86bd8,0xc1040451,0x00000000,0x00000000}},	//   _خاصا_, _ڪوٺي, --, --, 
   {{0x3f98c558,0xed580fae,0x81bc00e2,0x61e4002e}},	//   besu_, _қон_, kmēj, ëkle, 
   {{0xdb0c5a8b,0x6374029f,0xe8f800fb,0x3b9400f0}},	//   _encí, münü, ҙле_, мјут, 
   {{0xe8f85dc9,0xeb980184,0xe9d87705,0x63741ae4}},	// [10360] әле_, _һин_, бка_, lünü, 
   {{0xddcc0311,0x8af000ac,0x00000000,0x00000000}},	//   rucţ, vbəd, --, --, 
   {{0x6d5c00da,0x63743535,0x5d38011a,0xe6a401e1}},	//   _iepa, nünü, _לתיא, _òjúò, 
   {{0x69dc0240,0x00000000,0x00000000,0x00000000}},	//   shpe, --, --, --, 
   {{0x6d5cc559,0xe618023a,0x61f803b2,0x00000000}},	//   _kepa, бдд_, yntl, --, 
   {{0x6d5cc55a,0x3f9801c0,0x9a240474,0x63741432}},	//   _jepa, zesu_, _нояб_, künü, 
   {{0x6d5cc55b,0x3f98c55c,0x00000000,0x00000000}},	//   _mepa, yesu_, --, --, 
   {{0x9a8002d3,0x27f81291,0x6374453a,0x00000000}},	//   _ይክኣል_, _افرد_, dünü, --, 
   {{0x3f98c55d,0xc22405af,0x00000000,0x00000000}},	//   vesu_, وکتو, --, --, 
   {{0x64a4c55e,0xfbdc0597,0x20001326,0xe8e81b4b}},	//   _наза, _ɢɪя_, čkim_, _རྟོག, 
   {{0x3f982b1d,0x63744a98,0x865402d3,0x784400c0}},	//   tesu_, günü, _ዝተኣስ, _kėva, 
   {{0x58f4010f,0x00000000,0x00000000,0x00000000}},	//   לצין_, --, --, --, 
   {{0x6d5cc55f,0xb80c11b1,0x00000000,0x00000000}},	//   _bepa, िकतम_, --, --, 
   {{0x6d5c15a5,0x3f980368,0x63741432,0x9f48c560}},	//   _cepa, sesu_, bünü, micí_, 
   {{0x3f98c561,0x6374029f,0x9f4800bc,0xcd040137}},	//   pesu_, cünü, licí_, ечти, 
   {{0x6d5cc562,0xd114008f,0xab9c001f,0x00000000}},	//   _eepa, _מקוה_, ሕአዴግ_, --, 
   {{0x6d5cc563,0x99d001e4,0x8c1c00fe,0x9f48c564}},	// [10370] _fepa, _liʈe, _দংশন_, nicí_, 
   {{0x6d5cc565,0xbc900304,0x00000000,0x00000000}},	//   _gepa, _иңгә, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbd8805d9,0x6d5cc566,0x378800d4,0x981400ae}},	//   _انھن_, _zepa, ібло_, أبطا, 
   {{0x35a495de,0x81bc00da,0x63740259,0x7bdc00fd}},	//   далг, rmēj, zünü, _ilsu, 
   {{0xdb0c05d5,0x06740075,0x63743535,0x9f48c567}},	//   _incà, رنىڭ, yünü, dicí_, 
   {{0x981400c6,0x64a00801,0x00000000,0x00000000}},	//   _فبرا, ваща, --, --, 
   {{0xd9bc2158,0x74149ce2,0x00000000,0x00000000}},	//   _ইতিম, بوعا, --, --, 
   {{0xb224c568,0x580002dd,0x2464001f,0x00000000}},	//   ммил, _жоңғ, _ሲደርስ_, --, 
   {{0x6374029f,0x8af00213,0x3210c569,0x00000000}},	//   tünü, lbəc, ôzy_, --, 
   {{0x7bdc0baf,0x5fac000d,0x00000000,0x00000000}},	//   _olsu, _जोहल, --, --, 
   {{0x637407c4,0x9f48013a,0x00000000,0x00000000}},	//   rünü, bicí_, --, --, 
   {{0x6d5cc56a,0x9f4800d2,0x6374029f,0x8af00213}},	//   _pepa, cicí_, sünü, naət, 
   {{0x5184c56b,0x6d5cc56c,0x7204c56d,0x5ae8031c}},	//   _худа, _qepa, _توتم, _ལྟེམ, 
   {{0x6d5c7f28,0xe12000c7,0x30f80014,0xa19000f0}},	//   _vepa, _имши, _گوژھ_, _рајч, 
   {{0x6d5cc56e,0x644402b5,0xdca0119e,0x00000000}},	//   _wepa, _ōkik, њати, --, 
   {{0x6d5c06fa,0x7ae800a2,0xa9a400f3,0x00000000}},	// [10380] _tepa, _ýetl, миад, --, 
   {{0x7bdc848b,0xe8f40244,0x00000000,0x00000000}},	//   _elsu, وساخ, --, --, 
   {{0xdb0c1e7b,0xb864c56f,0x9f480118,0xfba80118}},	//   _encà, فانو, zicí_, _चोकम, 
   {{0xd5acc570,0x6fdc09b2,0x2614012d,0x8af003b9}},	//   یفن_, मसिं, _पीजी_, faət, 
   {{0xcd84044e,0xbd9402d3,0x779043fb,0x96b40063}},	//   _ዝምድና_, _ህዝቦም_, طیلا, дују_, 
   {{0x68541ee0,0x7c64c571,0x161807f7,0x9f480118}},	//   ምህርት, _تایل, _पीआर_, vicí_, 
   {{0x784402d5,0xd9d00c75,0x4cd000fe,0x00000000}},	//   _tėva, _جەلگ, _হেতু, --, 
   {{0x7a280024,0x9f48c572,0x00000000,0x00000000}},	//   _užtr, ticí_, --, --, 
   {{0xa80007c4,0x8af003b9,0x81d40a5b,0x00000000}},	//   ğıda, caət, еопх, --, 
   {{0xc0f802d3,0x9f48007b,0x8c24009e,0x41840116}},	//   _ወራር_, ricí_, ভদিন_, хтиғ, 
   {{0x568c0240,0x00000000,0x00000000,0x00000000}},	//   _ሓርነቱ_, --, --, --, 
   {{0x9f480118,0x64a40117,0x00000000,0x00000000}},	//   picí_, _наҷа, --, --, 
   {{0x644402b5,0x9f48003a,0x00000000,0x00000000}},	//   _ōkih, ticâ_, --, --, 
   {{0xd334011a,0x00000000,0x00000000,0x00000000}},	//   _חרדה_, --, --, --, 
   {{0x5ba4c573,0x9f48003a,0xa5c0033f,0xfce80092}},	//   мраз, ricâ_, żówk, _መውጫ_, 
   {{0x01b000cc,0x63b402d2,0x00000000,0x00000000}},	//   _চকিদ, _óynd, --, --, 
   {{0xa3d4032c,0x9f48026c,0x9cb000db,0x00000000}},	// [10390] _हवन_, micà_, رۅڭت, --, 
   {{0x7e7cc574,0x4974c575,0x7ae80209,0x9f4819f5}},	//   musp, клус, _ýetm, licà_, 
   {{0x7e7cc576,0xed4c0050,0xd7e40a4a,0x00000000}},	//   lusp, _چھہ_, мідо, --, 
   {{0xbb3c7a32,0xdb0c056a,0x9ba010e0,0x9f480268}},	//   ﻟﺪﻯ_, _encá, _جەرى, nicà_, 
   {{0x20001326,0x7c2cc577,0xda64c578,0x44f80115}},	//   čkih_, mmar, _تاجي, _aɩ_, 
   {{0x996000d7,0x00000000,0x00000000,0x00000000}},	//   líži_, --, --, --, 
   {{0xd5f8063f,0x7c2c74b4,0xbb3c0952,0xd7f83740}},	//   _asụ, omar, ﻟﻪﻡ_, _дуа_, 
   {{0x7c2cc579,0x7e7cc57a,0xb38402a9,0xa3c80401}},	//   nmar, kusp, хлил, रॉल_, 
   {{0x7c2cc57b,0x44f801e4,0x9f48c57c,0xdd1c0306}},	//   imar, _eɩ_, dicà_, _níži, 
   {{0x7c2cc57d,0xf1d40075,0x7e7cc57e,0x41600092}},	//   hmar, _ﯞﺍﻗﺘ, dusp, _ለአገሪ, 
   {{0x9f480c95,0x7c2cc57f,0x057400cf,0x00000000}},	//   ficà_, kmar, _جاقد, --, 
   {{0x93a401ec,0xe45400d9,0x7e7c08a5,0x00000000}},	//   _ішед, _נינט_, fusp, --, 
   {{0xb8d05078,0x7c2c143a,0x7e7c0037,0x61e40024}},	//   _དན_, dmar, gusp, ūkla, 
   {{0x270c001e,0x82f80214,0x222801d9,0x21a004b4}},	//   ộng_, _ترمز_, _فٲنی_, _бишм, 
   {{0x7c2c324c,0x7e7c0254,0x3164002f,0x7ae80432}},	//   fmar, ausp, malz_, _ýetj, 
   {{0x7c2cc580,0x9f480ffb,0x7e7c014f,0x714000db}},	//   gmar, cicà_, busp, _جۉگۅ, 
   {{0x291c1326,0x160c0da3,0x7e7c9add,0x00000000}},	// [103a0] _šta_, िवार_, cusp, --, 
   {{0x7c2cc581,0x3d100574,0x5de00124,0x7e04007f}},	//   amar, _दुवे_, _бжьа, _pčsņ, 
   {{0x9f4800d8,0x12d00150,0x00000000,0x00000000}},	//   licá_, _ﺘﻐﻴﺭ, --, --, 
   {{0xfd00247f,0xf7e80116,0xe7d000db,0x00000000}},	//   _түсп, ورنى_, دۅرگ, --, 
   {{0x9f480798,0x00000000,0x00000000,0x00000000}},	//   nicá_, --, --, --, 
   {{0xe4a4c582,0x9f480ffb,0x00000000,0x00000000}},	//   ерио, zicà_, --, --, 
   {{0xd494c583,0x291c498d,0xdedc0023,0x79500244}},	//   еры_, _áta_, _ሓውን_, _ئێما, 
   {{0x69ccc584,0x77907380,0xfd4c0432,0x9f4800cf}},	//   _hobe, _نیما, _bolỳ, xicà_, 
   {{0x69cc1aac,0x3164203d,0x9f48026c,0x1798010f}},	//   _kobe, falz_, vicà_, _צימב, 
   {{0x31640810,0x69ccc585,0x7e7cc586,0x96a4c587}},	//   galz_, _jobe, vusp, _якуб_, 
   {{0x69ccc588,0x9f48c589,0xdbd80248,0x00000000}},	//   _mobe, ticà_, _làál, --, 
   {{0x69ccc58a,0x7e7c1059,0xa2e4c58b,0xc000045e}},	//   _lobe, tusp, _поед, ৃষ্ণ_, 
   {{0x9f48c58c,0x69cc02c4,0xd24c00b2,0x7c2cc58d}},	//   ricà_, _oobe, _هنن_, vmar, 
   {{0x7e7cc58e,0x7c2cc58f,0x6b84127b,0x9f48026c}},	//   rusp, wmar, _ackg, sicà_, 
   {{0x7e7cc590,0x6b840175,0x9f48026c,0x2480001f}},	//   susp, _bckg, picà_, ከተሉት_, 
   {{0x7e7cc591,0xdd1c013a,0x00000000,0x00000000}},	//   pusp, _tíži, --, --, 
   {{0x69ccc592,0x2ec0040d,0x7f4c0327,0x7f480407}},	// [103b0] _bobe, _көрм, _ifaq, ñequ, 
   {{0x7e6c545f,0x3cd4004e,0x4efc011a,0x00000000}},	//   _ivap, _ажос, _מהחו, --, 
   {{0x7c2c0354,0x00000000,0x00000000,0x00000000}},	//   pmar, --, --, --, 
   {{0x7e6cc593,0x69cc0086,0x7c2c0bc9,0x7f4c031c}},	//   _kvap, _eobe, qmar, _jfaq, 
   {{0xe7e01b37,0x85b81129,0xb6a4c594,0x8af006be}},	//   _खतरा_, کانس_, тилл, lbən, 
   {{0x69ccc595,0xd1f00020,0xaa400131,0x4508110e}},	//   _gobe, ልበት_, _ئۆلى, _ìmọ̀_, 
   {{0x8af003e3,0x00000000,0x00000000,0x00000000}},	//   nbən, --, --, --, 
   {{0x23b004a9,0x7e6c0357,0xd344675b,0x7f4c0327}},	//   لمىس, _ovap, ریته_, _nfaq, 
   {{0x69ccc596,0x7e6c0055,0x41dc041c,0xa80003e0}},	//   _yobe, _nvap, यसंस, şıca, 
   {{0xb6347f51,0xb144036b,0x69cc002e,0x9f48003a}},	//   _شفاع, ънол, _xobe, nicæ_, 
   {{0xf8e02068,0xafe407d6,0x42c8009d,0x00000000}},	//   पनिय, вонл, дгөн_, --, 
   {{0x13a4034c,0x9f4800d8,0x31640112,0x7f4c036e}},	//   _سنتی_, ticá_, salz_, _cfaq, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7e6c05ce,0x9f480798,0xe2940064,0x6da40063}},	//   _dvap, ricá_, _раш_, њива, 
   {{0x40940006,0x7c840798,0x00000000,0x00000000}},	//   _брыт, луѓе, --, --, 
   {{0x69ccc597,0x79940112,0xf42400a2,0x00000000}},	//   _sobe, _abzw, _ýäde_, --, 
   {{0x69ccc598,0x78b40165,0xaf048271,0x00000000}},	// [103c0] _pobe, _arzv, _шпил, --, 
   {{0x69cc0032,0x9f48003a,0xda6c01d9,0xa92400ef}},	//   _qobe, gicæ_, زُم_, _ložņ, 
   {{0x69ccc599,0x7e6c05b8,0xe7841606,0x00000000}},	//   _vobe, _zvap, вуло, --, 
   {{0x69ccc59a,0x78b401fa,0x6ec4c59b,0xea9400ee}},	//   _wobe, _drzv, ामपु, _ишгэ, 
   {{0x69ccc59c,0x26d0019f,0xdedc02d3,0xdb0802d2}},	//   _tobe, âyo_, _ሓውና_, _þiðn, 
   {{0x557084e8,0x692401c0,0x00000000,0x00000000}},	//   агшт, _амга, --, --, 
   {{0x43941925,0x354400d4,0x00000000,0x00000000}},	//   гайс, ухів, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x27e401a9,0x99800064,0xe618009b,0x00000000}},	//   mhon_, _gijų_, _жда_, --, 
   {{0x27e4c59d,0x24f4c59e,0x7d089d25,0x7e6c0fac}},	//   lhon_, _ичер, şesi, _rvap, 
   {{0x7e6c0882,0x25bcc59f,0x161802ab,0x40340b3b}},	//   _svap, _intl_, _पीटर_, леос, 
   {{0x7ec8044e,0x27e4c5a0,0x71800588,0x14d402e4}},	//   _nëpë, nhon_, ақәе, _שואל_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7ae809a5,0x27e4022e,0xdb0c0cad,0x91e00114}},	//   _ýeti, hhon_, _àdéh, _воље, 
   {{0x27e4c5a1,0xa3d45345,0x7f4c025c,0x7c800092}},	//   khon_, _हवा_, _tfaq, _ይውላል_, 
   {{0x3ed4c5a2,0x27e4c5a3,0x7d280790,0x2d8c002f}},	//   _مقبر, jhon_, _ıssı, _öfen_, 
   {{0x7e6c0d04,0x27e4c5a4,0x9f48003a,0x68380118}},	// [103d0] _uvap, dhon_, ticæ_, _půdn, 
   {{0x3ea8079b,0x3f8800a3,0x10400092,0x8af006be}},	//   _isat_, _hcau_, _ከተቀመ, mbəl, 
   {{0xf7742626,0xc7a800f1,0x99800064,0x377404f0}},	//   гулю, ږدول_, _sijų_, гылс, 
   {{0xace8c5a5,0x27e4c5a6,0x96d00075,0x6b7c0356}},	//   _سرپل_, ghon_, ислә, răgâ, 
   {{0x7dd8026c,0x7c3c00c5,0x8af000ac,0x35d42f6a}},	//   _aìsi, _iisr, nbəl, лодё, 
   {{0x27e4079b,0x7c3c0142,0xceb40a7c,0x00000000}},	//   ahon_, _hisr, יינ_, --, 
   {{0x27e40472,0x57a40124,0xc1dc012c,0x3ea8045a}},	//   bhon_, _ишаа, यसैग, _lsat_, 
   {{0x27e4c5a7,0x3f8801d4,0x249404fb,0x3ea802f6}},	//   chon_, _ncau_, انيد_, _osat_, 
   {{0x7c3c17c7,0x8704013d,0x76b80354,0x00000000}},	//   _misr, _кяфе, _ялар_, --, 
   {{0x7984c5a8,0x85b80014,0x3f88015d,0xf2c4010b}},	//   nghw, _لامس_, _acau_, всүн, 
   {{0x3ea8c5a9,0xc91c03b9,0x7c3c0332,0x8fc400c7}},	//   _asat_, _barә, _oisr, аанҵ, 
   {{0x7c3c0003,0x60d45dad,0x2f540108,0x00000000}},	//   _nisr, _ńymc, ытос, --, 
   {{0x7984014b,0x3ea8c5aa,0x7f1800d4,0x00000000}},	//   kghw, _csat_, віру_, --, 
   {{0x27e403bd,0x7c3cbb1f,0x2f5400d1,0x62700451}},	//   zhon_, _aisr, _өтис, _اهوئ, 
   {{0x1d04c5ab,0x7ec824ba,0x3ea8c5ac,0x27e401b9}},	//   гери_, _pëpë, _esat_, yhon_, 
   {{0x7c3c003a,0x81bc005f,0xef8428e8,0x8af006be}},	//   _cisr, smēt, _слип, bbəl, 
   {{0xa3d4033f,0x1ee400e5,0x6d58236c,0x00000000}},	// [103e0] _हवस_, _موٹی_, ıtab, --, 
   {{0x7c3cc5ad,0x38a40142,0x68380118,0x00000000}},	//   _eisr, _bŷr_, _půdo, --, 
   {{0x81bc0029,0x27e4c5ae,0x7ec80200,0x6cf8030d}},	//   slēg, thon_, _tëpë, _ченĕ, 
   {{0xa818c5af,0x7dd8026c,0xe81802ef,0x6e3c000d}},	//   رتار_, _rìsi, رزات_, _hipb, 
   {{0x27e4c5b0,0x99900118,0x00000000,0x00000000}},	//   rhon_, řeše_, --, --, 
   {{0x27e4c5b1,0x7c3c05c7,0xd940119e,0x6d4c00e5}},	//   shon_, _zisr, _гери, ncba, 
   {{0x7c3cc5b2,0x6e3c047e,0x947016ac,0x682803b2}},	//   _yisr, _mipb, مديا, týdd, 
   {{0xc2742424,0x6e3cc5b3,0x69240124,0x7c3c022e}},	//   алиј, _lipb, _амҳа, _xisr, 
   {{0x248c02fa,0x26c00219,0xd1f00b82,0x27380205}},	//   stfm_, _škof_, ልጠት_, _dünü_, 
   {{0x3ea801a9,0x7dd801e1,0xf1a8411c,0x81bc00de}},	//   _rsat_, _tìsi, ناپه_, emēr, 
   {{0x65680098,0x0094084c,0x69dc00e4,0x7f5800d8}},	//   mafh, шинэ, ikpe, канс_, 
   {{0x27386f30,0x65680943,0x75240e78,0xd478025d}},	//   _günü_, lafh, ühze, _טאבל, 
   {{0xde30001f,0x2448004d,0x69dc143a,0x201800ef}},	//   _በህይወ, _hùm_, kkpe, _ūpis_, 
   {{0x65684174,0x3ea80153,0x8af00213,0x6d40054e}},	//   nafh, _vsat_, rbəl, _şoar, 
   {{0x61f8c5b4,0x6e3c0421,0x7c3cc5b5,0x27380205}},	//   mitl, _dipb, _pisr, _yünü_, 
   {{0x61f8c5b6,0x81bc00da,0xdb0c0077,0x3b54c5b7}},	//   litl, slēd, _incú, ркар, 
   {{0x3ea834fe,0x7c3cc5b8,0x79f49d61,0x6618007f}},	// [103f0] _usat_, _visr, азах, _oktk, 
   {{0x61f8c5b9,0x79840c8c,0x7c3cc5ba,0x6d4c02d0}},	//   nitl, ughw, _wisr, ccba, 
   {{0x3c58152d,0xa8003535,0x7984016d,0x7c3c00cd}},	//   _шинэ_, ğına, rghw, _tisr, 
   {{0x61f8c5bb,0x7c3c0107,0x7e7c057b,0x236401e4}},	//   hitl, _uisr, orsp, _neoj_, 
   {{0xd90cc5bc,0x8d7404a9,0x61f8c5bd,0x224402e2}},	//   _کیا_, _ئاۋا, kitl, _nuok_, 
   {{0xf98850a3,0x24480428,0x7e7cc5be,0x69c00304}},	//   _جنسي_, _bùm_, irsp, _мөхб, 
   {{0x7aecc5bf,0x2448c5c0,0x61f88216,0x7804016c}},	//   lzat, _cùm_, ditl, _кӯда, 
   {{0x7bccc5c1,0x22440428,0x20180472,0x2448001e}},	//   njau, _buok_, _nkqi_, _dùm_, 
   {{0x7aecc5c2,0x61f8c5c3,0xd5b8c5c4,0x7e7c01e4}},	//   nzat, fitl, _псж_, jrsp, 
   {{0x61f8c5c5,0x7bcc023a,0x22440153,0x1638007b}},	//   gitl, hjau, _duok_, _أسرة_, 
   {{0x7e7c2506,0x236401e4,0xc2c80150,0x30040395}},	//   ersp, _feoj_, _ەبىل_, изог, 
   {{0xb4b08061,0x7aec01d3,0x00000000,0x00000000}},	//   टटी_, kzat, --, --, 
   {{0xceb40213,0xb8d00327,0x81bc00e2,0x784400c0}},	//   _azər_, _ྐར_, rmēr, _dėvi, 
   {{0x7aec055a,0x7bcc0024,0x6e3c014f,0xa2500214}},	//   dzat, ejau, _qipb, _بپوش, 
   {{0x6e3c6586,0x32040649,0x7aec0472,0x2244005a}},	//   _vipb, mnly_, ezat, _zuok_, 
   {{0x3950045a,0x00000000,0x00000000,0x00000000}},	//   _afzs_, --, --, --, 
  
   {{0x32040072,0xa3c801ad,0x7aec01d3,0x00000000}},	// [10400] only_, रॉट_, gzat, --, 
   {{0x6924c5c6,0x8af006be,0x00000000,0x00000000}},	//   амза, lbək, --, --, 
   {{0x3204c5c7,0x7d080112,0x7de400f1,0x7bcc0153}},	//   inly_, ßest, _دسيم, bjau, 
   {{0x24480013,0x61f8c5c8,0x9614006c,0x00000000}},	//   _rùm_, zitl, یغور_, --, 
   {{0xe5c40114,0x61f88dbf,0x7aec033f,0x656801bf}},	//   иско, yitl, czat, tafh, 
   {{0x61f8c5c9,0x00000000,0x00000000,0x00000000}},	//   xitl, --, --, --, 
   {{0x61f8c5ca,0x6568c5cb,0x22440589,0x26c003ca}},	//   vitl, rafh, _suok_, _škod_, 
   {{0xdb0c07de,0x22440086,0xf8700150,0x60d8005b}},	//   _ancù, _puok_, _ءۇنج, vytm, 
   {{0x61f854dc,0x64480327,0x00000000,0x00000000}},	//   titl, sqfi, --, --, 
   {{0x2448004d,0x5bd00073,0x6b94015d,0x00000000}},	//   _tùm_, _सव्व, hfyg, --, 
   {{0x7aec692e,0x236401e4,0x64480327,0x00000000}},	//   zzat, _teoj_, qqfi, --, 
   {{0x4420c5cc,0x61f8c5cd,0x320447b4,0x2d980165}},	//   _ói_, sitl, anly_, _abpe_, 
   {{0x4254c5ce,0x61f8c5cf,0x7e7c0942,0xd36c0451}},	//   _انتر, pitl, ursp, _آهه_, 
   {{0x752c0316,0x249cc5d0,0x7aec0216,0x7e7cb83f}},	//   řaze, _kptm_, vzat, rrsp, 
   {{0x4034c5d1,0x3d1000c5,0x6b9403cb,0x78440153}},	//   _лекс, _दुखे_, ffyg, _tėvi, 
   {{0x2cb8207a,0x7aec4ecc,0x113800d9,0xada00419}},	//   _drpd_, tzat, _בתול, _šúto, 
   {{0x7bcc0664,0xa800c5d2,0x0e447c3f,0x7aec01a9}},	// [10410] rjau, ğıla, _мээм, uzat, 
   {{0x7bccc5d3,0xa800494d,0x13ac0011,0x00000000}},	//   sjau, şıla, কায়, --, 
   {{0x97a405f5,0x57a48a0f,0x7bcc0006,0x7aec01ed}},	//   ирдл, ишда, pjau, szat, 
   {{0xdce428b5,0x00000000,0x00000000,0x00000000}},	//   najč, --, --, --, 
   {{0xcfb8011a,0x00000000,0x00000000,0x00000000}},	//   ילאי_, --, --, --, 
   {{0xc98402a9,0xb8fc03d4,0x070842f4,0x00000000}},	//   _муси, _তই_, جيهي_, --, 
   {{0x249c0798,0x33f4c5d4,0x00000000,0x00000000}},	//   _cptm_, йчис, --, --, 
   {{0xdce40010,0x7ae80432,0x00000000,0x00000000}},	//   jajč, _ýets, --, --, 
   {{0x98b00213,0x00000000,0x00000000,0x00000000}},	//   maxı_, --, --, --, 
   {{0x7768208d,0x50a00131,0x41440092,0x00000000}},	//   _heex, قەتل, _ከአገሪ, --, 
   {{0x3204c5d5,0x94a805d9,0xdce40030,0xdb0c0200}},	//   rnly_, _جاءِ_, fajč, _bacë, 
   {{0x7768ad04,0x764000ca,0xdce40e04,0x03940212}},	//   _jeex, _hily, gajč, _мрія, 
   {{0x764077aa,0x7768011f,0x1dc03af7,0x00000000}},	//   _kily, _meex, शांत, --, 
   {{0x776801d9,0x7640c5d6,0x764806be,0x00000000}},	//   _leex, _jily, _muey, --, 
   {{0xdcf40cc1,0x0cb802f5,0xc0a8007b,0x00000000}},	//   _baxı, ীন্ত, _نايل_, --, 
   {{0x7768c5d7,0x7640c5d8,0x6a8405f5,0x28e80220}},	//   _neex, _lily, йлба, ңдап_, 
   {{0x764002d0,0xdcf403b9,0x205400db,0x00000000}},	// [10420] _oily, _daxı, _ктөр, --, 
   {{0x7dd80268,0xa96825ef,0x00000000,0x00000000}},	//   _dìss, امام_, --, --, 
   {{0xb864c5d9,0xa8000259,0x2d880521,0x77680009}},	//   قانو, şıma, mgbe_, _beex, 
   {{0x7648c5da,0x7640c5db,0x00000000,0x00000000}},	//   _buey, _aily, --, --, 
   {{0xc5f8c5dc,0x7640c5dd,0xa6f800c6,0x7768058a}},	//   аға_, _bily, دعاء_, _deex, 
   {{0x2d880978,0x76400142,0x33a001ec,0x00000000}},	//   ngbe_, _cily, _ﺃﻤﻨﻲ_, --, 
   {{0xdcf40cc1,0xd46415ed,0x76400cfd,0x77681bce}},	//   _yaxı, бије_, _dily, _feex, 
   {{0x7768c1b6,0xc6b8031c,0x76400042,0x9470007b}},	//   _geex, དའདུ, _eily, أدوا, 
   {{0x76400100,0xdb0c0240,0xb6840150,0x97c0008e}},	//   _fily, _racë, _وشكى, _эйте, 
   {{0x764000a9,0x94700014,0xf42400a2,0xa8200244}},	//   _gily, _کۯٹا, _ýäne_, _بکڕن, 
   {{0x77689a67,0x4034034f,0x8af00213,0xdb0c0200}},	//   _yeex, женс, lcəd, _pacë, 
   {{0x76402622,0x7c28003d,0xdef805f5,0x77680694}},	//   _zily, ċerk, гыг_, _xeex, 
   {{0xdef8c5de,0x442405b1,0x8af000ac,0x7640485b}},	//   уын_, mlm_, ncəd, _yily, 
   {{0xc21001d9,0xc0c4c5df,0x6440c5e0,0xada000d7}},	//   _تٔت_, _дәми, _hioi, _šúro, 
   {{0x7f940209,0x4424c5e1,0x42540451,0xdcf403e3}},	//   _дайх, olm_, _انڪر, _paxı, 
   {{0xbb5805f5,0xdb0c0407,0x6440062c,0x9fe400f2}},	//   раах_, _hacé, _jioi, _دسته, 
   {{0x4424007d,0x3a743119,0x33340055,0x00000000}},	// [10430] ilm_, юлар, _āpīḍ, --, 
   {{0x77682f66,0x4424c5e2,0x712400db,0x98c4010b}},	//   _seex, hlm_, _ارۇل, йсел, 
   {{0x644006c8,0x44240270,0xdcf400ac,0xdb0c2dfb}},	//   _oioi, klm_, _taxı, _macé, 
   {{0x7640c5e3,0x76b8c5e4,0x776801d9,0x7648c5e5}},	//   _sily, илер_, _qeex, _puey, 
   {{0xdb2042c0,0x7640c5e6,0x44240a2e,0x764806af}},	//   _روسی, _pily, dlm_, _quey, 
   {{0x6440c5e7,0x764001b9,0x4424c5e8,0x776800e8}},	//   _aioi, _qily, elm_, _weex, 
   {{0x6440c5e9,0x77680548,0x24501fb8,0x76404831}},	//   _bioi, _teex, ونوس, _vily, 
   {{0x7640c5ea,0xd1d80023,0xd7f8014b,0xd1bc0023}},	//   _wily, ቕዓት_, _суг_, ድዓት_, 
   {{0x6440c5eb,0xdb0c0098,0x76400548,0x87e4010b}},	//   _dioi, _bacé, _tily, _эюре, 
   {{0xe160104b,0x76406064,0x00000000,0x00000000}},	//   وگىي, _uily, --, --, 
   {{0x64400270,0x78440024,0x3f98031c,0x00000000}},	//   _fioi, _tėvu, ffsu_, --, 
   {{0x6440c5ec,0xefdc02d3,0xc4d80114,0x00000000}},	//   _gioi, _ዓምዲ_, _уђу_, --, 
   {{0x9324c5ed,0xdb0cc5ee,0xe28c008e,0x637400a2}},	//   _اران, _facé, _юа_, _dünı, 
   {{0xace8c5ef,0x00000000,0x00000000,0x00000000}},	//   амга_, --, --, --, 
   {{0x9d4034b1,0x644000ad,0x00000000,0x00000000}},	//   дерд, _yioi, --, --, 
   {{0xec140214,0x63740205,0x00000000,0x00000000}},	//   آورد, _günı, --, --, 
   {{0xfaf80064,0xc1780153,0x00000000,0x00000000}},	// [10440] _žūr_, chės_, --, --, 
   {{0x3eac456f,0xa6c800aa,0x2afc12eb,0xa2d400fe}},	//   çete_, یوال_, _रेणु_, _তেঁও, 
   {{0xeb98084c,0xe8f806ed,0xa178008f,0xac7433d2}},	//   _кин_, јле_, שטעט, _باخش, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdce40318,0x00000000,0x00000000,0x00000000}},	//   majā, --, --, --, 
   {{0xdce448e1,0x55e0010b,0x644001f4,0xa9680114}},	//   lajā, мочб, _sioi, _њива_, 
   {{0x644000b0,0x00000000,0x00000000,0x00000000}},	//   _pioi, --, --, --, 
   {{0x71640ed1,0xdb0c0098,0xdce40318,0x44240489}},	//   ۋاپك, _sacé, najā, ulm_, 
   {{0xdb0c0c6a,0xdce85160,0x64400108,0x48f4095f}},	//   _pacé, _čiče, _vioi, ्पको_, 
   {{0x44240427,0x7c280327,0x00000000,0x00000000}},	//   slm_, ċeri, --, --, 
   {{0x84c4506f,0xd36cc5f0,0xdce40318,0x65780857}},	//   _хәлд, _оч_, kajā, _idth, 
   {{0x6458c5f1,0xada000d7,0x1fa4009d,0x00000000}},	//   _itti, _šúpo, црог, --, 
   {{0x11d0c5f2,0xf1a80214,0x3f980327,0xf3c80472}},	//   ستید, _گانه_, rfsu_, _دبله_, 
   {{0x3eb80162,0x7ae80210,0x5180022e,0x00000000}},	//   rvst_, _żeto, _жуъа, --, 
   {{0xf1a85da7,0xdb68c5f3,0x3ce40579,0xc31c015b}},	//   _دانه_, ирал_, álv_, দেশি_, 
   {{0xdce41a14,0xda64007b,0x54780677,0x00000000}},	//   gajā, قائي, יטלו, --, 
   {{0x20080356,0x39a40139,0x00000000,0x00000000}},	// [10450] mnci_, зыең, --, --, 
   {{0x6458c5f4,0x20080198,0x19a806ed,0x65780051}},	//   _otti, lnci_, јтап_, _ndth, 
   {{0xdb0c019f,0xdce40171,0x00000000,0x00000000}},	//   _gacî, bajā, --, --, 
   {{0xee740133,0x7c380205,0xdce40a88,0x77540240}},	//   _بڵێت_, çarı, cajā, _ዝአመሰ, 
   {{0x61e802d0,0x41bc043e,0x4fbc010f,0x00000000}},	//   _olfl, ्ञास, יזאצ, --, 
   {{0xd8740345,0x8f1c011a,0x00000000,0x00000000}},	//   _وازب, בודת, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x61e8010f,0x00000000,0x00000000,0x00000000}},	//   _alfl, --, --, --, 
   {{0x6458c5f5,0xdb0cb9f0,0x35f4c5f6,0x4658011c}},	//   _etti, _incó, _епар, _матю_, 
   {{0x2008033f,0x8af003b9,0x00000000,0x00000000}},	//   enci_, mbət, --, --, 
   {{0x78a00267,0x8af006be,0x00000000,0x00000000}},	//   _älvd, lbət, --, --, 
   {{0x850407d6,0x61e8c5f7,0xc4840220,0x63e400db}},	//   _تومن, _elfl, _ілік, _ىيلە, 
   {{0xdce40a30,0xe1ec009d,0x00000000,0x00000000}},	//   vajā, _зг_, --, --, 
   {{0x2008030a,0x00000000,0x00000000,0x00000000}},	//   anci_, --, --, --, 
   {{0x8af003be,0xdce40f40,0x20080198,0xdb0cc5f8}},	//   hbət, tajā, bnci_, _oncó, 
   {{0x1d04c5f9,0x20780677,0x8af003e3,0x00000000}},	//   чеси_, _האקא, kbət, --, 
   {{0xdce43a71,0xdb8001c0,0xad4000db,0x00000000}},	// [10460] rajā, эгти, بۉگۉ, --, 
   {{0xdb0c0309,0x00000000,0x00000000,0x00000000}},	//   _ancó, --, --, --, 
   {{0x02a81431,0x00000000,0x00000000,0x00000000}},	//   _कन्न, --, --, --, 
   {{0x3ce40183,0x645801a9,0x00000000,0x00000000}},	//   ølve_, _rtti, --, --, 
   {{0x9660008e,0xfaa40107,0x00000000,0x00000000}},	//   екче, _ошён, --, --, 
   {{0xdb0c056a,0xe8f000ec,0x00000000,0x00000000}},	//   _encó, _ٻٻر_, --, --, 
   {{0x18a01c61,0x98a0c5fa,0xd4640640,0x20080042}},	//   _парм, _пире, пије_, ynci_, 
   {{0xdb0c00cf,0xc0d0001f,0x8af00213,0xd94000d8}},	//   _incò, _እርሻ_, bbət, _чеси, 
   {{0x27e4c5fb,0x00000000,0x00000000,0x00000000}},	//   mkon_, --, --, --, 
   {{0xdce4054e,0x2b4400d0,0x8078011c,0x00000000}},	//   najă, ľoch_, обос_, --, 
   {{0x6458c5fc,0xb64402dd,0xe3144e10,0x042c0240}},	//   _utti, _ﺎﺭ_, _کباب, _ብጅግን, 
   {{0x27e4c5fd,0x64a4016c,0x78a001e3,0x8af003b9}},	//   nkon_, _маҷа, _älve, nbəs, 
   {{0x27e4af92,0x00000000,0x00000000,0x00000000}},	//   ikon_, --, --, --, 
   {{0xefdc02d3,0xdb0c004e,0x27e4be9d,0x41e000e1}},	//   _ጕዳይ_, _oncò, hkon_, _पकिस, 
   {{0x11d00228,0x27e4c5fe,0x9e64c5ff,0x00000000}},	//   _ستود, kkon_, _کابن, --, 
   {{0xdb0c0268,0x27e4c600,0x00000000,0x00000000}},	//   _facì, jkon_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [10470] --, --, --, --, 
   {{0x8af003be,0xc0d00020,0xceb402e4,0xdce40311}},	//   vbət, _እርስ_, _טיפ_, gajă, 
   {{0xc864c601,0x4ddc0375,0x00000000,0x00000000}},	//   етчи, _לחזו, --, --, 
   {{0xdb0c204e,0x27e4adaa,0x8934c602,0x00000000}},	//   _hací, gkon_, رعلا, --, 
   {{0xdb0cc603,0x9f480407,0x00000000,0x00000000}},	//   _encò, licó_, --, --, 
   {{0x27e4c604,0xe5a0c605,0x7c280327,0xd5c40d2e}},	//   akon_, виши, ċeru, लाइज, 
   {{0xd5f8063f,0xdb0c04d4,0x8af003e3,0x9f480407}},	//   _apụ, _mací, sbət, nicó_, 
   {{0xdedc02d3,0x8af00213,0x27e4c606,0x752c0118}},	//   _ጕባኤ_, mbər, ckon_, řazo, 
   {{0x8af006be,0x00000000,0x00000000,0x00000000}},	//   lbər, --, --, --, 
   {{0x81bc00da,0xdb0cc607,0x67240174,0xd9fc1fd2}},	//   blēm, _nací, _økja, ोचित_, 
   {{0x23b04d4e,0x8af003b9,0x00000000,0x00000000}},	//   رمیس, nbər, --, --, 
   {{0x9f4804cf,0x00000000,0x00000000,0x00000000}},	//   dicó_, --, --, --, 
   {{0x8af00cc1,0xdb0c0005,0x00000000,0x00000000}},	//   hbər, _bací, --, --, 
   {{0x9f4804cf,0x27e4005a,0x3eacc608,0x453000db}},	//   ficó_, zkon_, çeta_, _جۉۉر, 
   {{0x81bc00da,0x27e4c609,0xceb403b9,0xc0c00092}},	//   klēj, ykon_, _ayət_, ድቃል_, 
   {{0xf1a88863,0x00000000,0x00000000,0x00000000}},	//   _داچه_, --, --, --, 
   {{0xdb0c172e,0x78a808ad,0xfd10004b,0x8af00213}},	// [10480] _fací, _ćeva, نجې_, vbəs, 
   {{0xceb411a9,0x628407f5,0x5980bae4,0x645c00e4}},	//   _isə_, škog, клуб, ãpik, 
   {{0x27e4c60a,0x6da40124,0x6b64005b,0xdce4054e}},	//   tkon_, _еиҿа, _окна, rajă, 
   {{0x9f480395,0xdb0c0306,0x27e40108,0x7e680356}},	//   licò_, _zací, ukon_, ţepe, 
   {{0x27e4c60b,0x8af000ac,0xa738007b,0x39500332}},	//   rkon_, rbəs, آثار_, íosú_, 
   {{0x27e4c60c,0xc0d00020,0xdb0cc60d,0x00000000}},	//   skon_, _እርሱ_, _facâ, --, 
   {{0xd9400276,0x94709bfe,0x2794c60e,0xc0dc0023}},	//   _аери, نديا, _ошар, ቕቃሕ_, 
   {{0xb60400d0,0xd5c40037,0x853c0153,0xb794009b}},	//   _rušň, लाउज, _abėc, _прућ, 
   {{0xe5780124,0xdce4012d,0x00000000,0x00000000}},	//   _мза_, mają, --, --, 
   {{0x95800276,0xdce40034,0x70c81db2,0x00000000}},	//   _алфе, lają, िमूल, --, 
   {{0x9f484d72,0x7f940022,0x00000000,0x00000000}},	//   dicò_, нанх, --, --, 
   {{0xdce4033f,0x626431f0,0xdb0c013a,0x00000000}},	//   nają, _قاتق, _sací, --, 
   {{0x63a0c60f,0x3f844ba9,0x9f48c044,0x64a400c7}},	//   _ibon, ğlu_, ficò_, _хаҵа, 
   {{0x9f480407,0x0dc81086,0xeeb80092,0x00000000}},	//   ticó_, муси_, _ሊያመጣ_, --, 
   {{0x6284c610,0xdb0c204e,0xdce40034,0x26c000bc}},	//   škod, _vací, kają, _škol_, 
   {{0x9f481ada,0xdce4033f,0x00000000,0x00000000}},	//   ricó_, jają, --, --, 
   {{0x63a042da,0xdce4068f,0x7f4c009a,0x2ec0008e}},	// [10490] _mbon, dają, _igaq, _йөрм, 
   {{0x7e6cc611,0x58840137,0x9cc80108,0x2d9c0254}},	//   _iwap, дыда, _дыма_, õtet_, 
   {{0x63a04a6c,0x7e6c006f,0x00000000,0x00000000}},	//   _obon, _hwap, --, --, 
   {{0x63a00ffb,0xdce40034,0x9bc40131,0xdb0c00d8}},	//   _nbon, gają, _تۈرك_, _vacâ, 
   {{0x3668c612,0x7bdcc613,0x7f4c004b,0xcff80302}},	//   чало_, _iosu, _mgaq, וצאה_, 
   {{0x7e6cc614,0x7bdc8b9f,0x9f98002e,0xdb0c0356}},	//   _mwap, _hosu, _mëñ_, _tacâ, 
   {{0x7bdcc615,0x7e6cc616,0xb7d40241,0xdb0c0798}},	//   _kosu, _lwap, _aṣeh, _facã, 
   {{0x7f4cc617,0x7e6c2782,0x47880261,0xdce4033f}},	//   _ngaq, _owap, _осум_, cają, 
   {{0x7bdcc1e4,0x6fbc012c,0x32440022,0x8af003b9}},	//   _mosu, षयसू, неиг, hcən, 
   {{0x7f4c009a,0x63a09024,0xe1f400c7,0xad98010e}},	//   _agaq, _ebon, егь_, giºl, 
   {{0x7e6c4b44,0xbb300150,0xdee001a9,0x70c82052}},	//   _awap, _ﺨﺎﻱ_, қори, िमेल, 
   {{0x9f9800e8,0x7e6cc618,0x34bc1d15,0x63a00ca8}},	//   _bëñ_, _bwap, ्मीद, _gbon, 
   {{0xdca00116,0xe4640254,0x00000000,0x00000000}},	//   һари, öövi_, --, --, 
   {{0x7f4c009a,0x7e6c560d,0xdce40034,0x4918000d}},	//   _egaq, _dwap, zają, _बुझो_, 
   {{0xdca05c81,0x3204c619,0x7bdcc61a,0x7e6c0b6f}},	//   лари, mily_, _bosu, _ewap, 
   {{0x7bdcc61b,0x3204c61c,0x7e6c0100,0x00000000}},	//   _cosu, lily_, _fwap, --, 
   {{0x7e6cc61d,0x7bdc62bb,0x2d9c0254,0x34bc1408}},	// [104a0] _gwap, _dosu, õtes_, ्मुद, 
   {{0xdce40034,0x32040118,0xf4140154,0x682802f0}},	//   wają, nily_, াতির_, mýdi, 
   {{0xdce40034,0xbb2800d1,0xe7a80d1d,0x8af006be}},	//   tają, ﻤﻨﻰ_, звел_, ccən, 
   {{0x7bdc1250,0xe738c61e,0x00000000,0x00000000}},	//   _gosu, пее_, --, --, 
   {{0xdce40034,0x32040109,0x2448007f,0xe7380395}},	//   rają, kily_, kòmè_, чед_, 
   {{0x7bdc9614,0xd5c400e1,0x63a0c61f,0x81bc00e2}},	//   _zosu, लागज, _sbon, rlēk, 
   {{0x3204c620,0xdb0c01e7,0x00000000,0x00000000}},	//   dily_, _iacá, --, --, 
   {{0x06840c60,0x78a001e3,0x7bdcc621,0x00000000}},	//   _аҳдн, _älva, _xosu, --, 
   {{0x32040122,0x63a00051,0x00000000,0x00000000}},	//   fily_, _vbon, --, --, 
   {{0x51f411ed,0x7e6c5745,0x4154c3ff,0x00000000}},	//   енью_, _rwap, ъвос, --, 
   {{0x7e6c0408,0x9f981574,0x157401d9,0xdb0c007b}},	//   _swap, _sëñ_, _سٕند_, _macá, 
   {{0x7e6c007f,0xdb0c01e7,0x44200413,0xe4c4014b}},	//   _pwap, _lacá, _ði_, _ойҷи, 
   {{0x7bdcc622,0x3204c623,0xe04804fb,0x628405be}},	//   _rosu, bily_, _کشته_, škob, 
   {{0xd12c0137,0x00000000,0x00000000,0x00000000}},	//   _گۅپ_, --, --, --, 
   {{0xc31c02f5,0x9f9800e8,0x63b40162,0x622400db}},	//   দেখি_, _wëñ_, _óyns, _قوچە, 
   {{0xb5fc000a,0x7f4c014b,0x7bdcc624,0x200c002e}},	//   _itše, _ugaq, _qosu, _ñgi_, 
   {{0x7e6cc625,0xbbe01d8a,0xdb0c01e7,0xcf9400df}},	// [104b0] _uwap, _नवीक, _bacá, _עטץ_, 
   {{0x3ea8020c,0x7bdcc626,0xdb0c07c5,0xfe7801f0}},	//   _ipat_, _wosu, _vacà, _нӯҳ_, 
   {{0x7bdcc627,0xfca80451,0xca4801b9,0xfc800023}},	//   _tosu, _کاڌو_, رلمه_, _ክፍጽሙ_, 
   {{0x9b400014,0x3204c628,0x6c7808d8,0xb6c404b3}},	//   _مۆزو, zily_, _קארפ, көзд, 
   {{0x7c2cc629,0x8af000ac,0x3204009a,0x00000000}},	//   mlar, ncəl, yily_, --, 
   {{0x66e0419e,0x85e80212,0x00000000,0x00000000}},	//   роша, ндів_, --, --, 
   {{0x3204c62a,0x34bc0918,0x97a41fe2,0x7c2cc62b}},	//   vily_, ्मेद, _прал, olar, 
   {{0x3ea8c62c,0xc4c4c62d,0x00000000,0x00000000}},	//   _opat_, اتوو, --, --, 
   {{0x7c2cc62e,0x35b40075,0x14f4004b,0x3204c62f}},	//   ilar, _ибар, _ګواښ_, tily_, 
   {{0x7c2cc630,0x22900502,0x8af003b9,0x600801f4}},	//   hlar, گلیس, dcəl, yömä, 
   {{0x7c2cc631,0x3204c632,0x3ea88b14,0x3ec4016c}},	//   klar, rily_, _apat_, ҳияҳ, 
   {{0x7c2cc633,0x9f580548,0x320426e7,0x628400d7}},	//   jlar, _amqâ_, sily_, ákoc, 
   {{0x7c2c1444,0xb5fc27c4,0x3ea80042,0x66880023}},	//   dlar, _etše, _cpat_, _ብተስፋ_, 
   {{0x3ea8c634,0x7c2cc635,0x600802f6,0x229000db}},	//   _dpat_, elar, tömä, _ئلوس, 
   {{0x7c2c6151,0x3ea80428,0xeb980212,0xd344c636}},	//   flar, _epat_, мив_, _تیکه_, 
   {{0x7c2c4e54,0xaec4a267,0xdce40034,0xdb0c09c2}},	//   glar, _абил, naję, _sacá, 
   {{0xdb0c0597,0xe09400b5,0xbf6400ec,0x8af006be}},	// [104c0] _pacá, _zゲ_, _صديو, ccəl, 
   {{0x7c2cc637,0x00000000,0x00000000,0x00000000}},	//   alar, --, --, --, 
   {{0x7c2cc638,0x64a80213,0x6d5c03ac,0x7db402d5}},	//   blar, _zəif, _ifpa, _ёсьц, 
   {{0x1864c639,0x60d8010f,0x780000db,0xebe40835}},	//   таци_, וקענ, бүса, _ромп, 
   {{0xad240aaf,0xa6940798,0x00000000,0x00000000}},	//   _سىڭى, треј, --, --, 
   {{0x7c64006c,0xa88801b9,0x8af006be,0x00000000}},	//   _جایل, _ойга_, ncəm, --, 
   {{0x69cc9435,0xc3300228,0xd494c63a,0xa7b40a5b}},	//   _inbe, ڭەش_, вры_, _исај, 
   {{0x77900344,0x8af006be,0x00000000,0x00000000}},	//   _هیما, hcəm, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7c2cc63b,0xdb0c0120,0x09e40154,0xa1a8010b}},	//   zlar, _incô, ফোরা, фтиз_, 
   {{0x7c2c3297,0x3ea8c63c,0x64a806be,0x8af003b9}},	//   ylar, _spat_, _səif, dcəm, 
   {{0xe28404a9,0x3ea8020b,0x7c2ca860,0x00000000}},	//   _алди, _ppat_, xlar, --, 
   {{0x69ccc63d,0x7c2cc63e,0x6d5c0334,0xdef8c63f}},	//   _onbe, vlar, _bfpa, фын_, 
   {{0x7c2c9033,0x20c40262,0x00000000,0x00000000}},	//   wlar, _асиг, --, --, 
   {{0x7c2cc640,0x44242bad,0xc0c40131,0x00000000}},	//   tlar, oom_, _сәпи, --, 
   {{0x69ccc641,0x7c2cc642,0x6c6800dd,0x6d5c01e4}},	//   _anbe, ular, علقہ_, _efpa, 
   {{0x3ea8c643,0x4ea40024,0x00000000,0x00000000}},	// [104d0] _upat_, _крэа, --, --, 
   {{0x4424c644,0x6d5c0998,0x2a60013a,0x99d430d6}},	//   hom_, _gfpa, _dtkb_, خترا, 
   {{0x7c2c41b5,0xd7f8016c,0x0c8412db,0xc1780024}},	//   plar, муд_, _кыям, lkės_, 
   {{0x7c2cc645,0x44248b8c,0x69ccc646,0x00000000}},	//   qlar, jom_, _enbe, --, 
   {{0xc1780006,0x557002a9,0x00000000,0x00000000}},	//   nkės_, иҳат, --, --, 
   {{0x7e7c0112,0x78a0007c,0x00000000,0x00000000}},	//   issp, _älvo, --, --, 
   {{0x4424c647,0xd90c9767,0x7e7c0112,0x6614002e}},	//   fom_, _بیا_, hssp, éyka, 
   {{0x23b00075,0x7e7cc648,0xd83801c0,0x32500023}},	//   ممىس, kssp, _цэг_, _ኣሰልጣ, 
   {{0xb224c649,0x69cc000f,0xe4643110,0x39500010}},	//   лмил, _ynbe, ööri_, _kgzs_, 
   {{0x7e7c1496,0x71b401f4,0x00000000,0x00000000}},	//   dssp, ущих, --, --, 
   {{0x3394c64a,0xdb0c0120,0xafe401d5,0x7e7c127b}},	//   _ملاز, _facç, гонл, essp, 
   {{0x872400c6,0x7f5c0334,0x2e3402d2,0x7e7c032e}},	//   _comط_, gcsq, dæfa_, fssp, 
   {{0x71a40798,0xad98010e,0x00000000,0x00000000}},	//   _балз, liºi, --, --, 
   {{0x568c00b7,0x00000000,0x00000000,0x00000000}},	//   _ዓይነቱ_, --, --, --, 
   {{0xac38234c,0xcbc801e2,0x6218011a,0x00000000}},	//   ечах_, نېدو_, _אוסק, --, 
   {{0x7e7c01bf,0x00000000,0x00000000,0x00000000}},	//   bssp, --, --, --, 
   {{0xa9a40022,0x1f6000fd,0x77780009,0x7e7c02d0}},	// [104e0] лиад, _укым, dawx, cssp, 
   {{0xda6c01d9,0xadf800f2,0x00000000,0x00000000}},	//   سُم_, _سرخط_, --, --, 
   {{0xe784c64b,0xae040014,0x2d980129,0x69cc0051}},	//   гуло, _لوکى, _icpe_, _vnbe, 
   {{0x4424c64c,0x8af006be,0x00000000,0x00000000}},	//   xom_, ncək, --, --, 
   {{0x4424a286,0xfbd02432,0xa3c041d8,0xbad40006}},	//   vom_, हारम, एएस_, _кіры, 
   {{0x69ccc64d,0x4424c64e,0x4904c64f,0x6ab40042}},	//   _unbe, wom_, _күзг, mwyf, 
   {{0xd9d000cf,0x3568753d,0xe5d800ef,0x6ab40042}},	//   _دەلگ, трін_, _aļģē, lwyf, 
   {{0x267400f2,0x7e7cc650,0x00000000,0x00000000}},	//   _مهرآ, yssp, --, --, 
   {{0x6594c651,0x81bc0029,0xe6180124,0xdb0c008e}},	//   _مجار, klēt, _зда_, _gacä, 
   {{0x4424c652,0xdd1c00d0,0x00000000,0x00000000}},	//   som_, _líši, --, --, 
   {{0x6608003e,0x00000000,0x00000000,0x00000000}},	//   mifk, --, --, --, 
   {{0x7e7cc653,0x6608c654,0x44242d80,0xd36cc655}},	//   tssp, lifk, qom_, _فهم_, 
   {{0x81d43129,0x25bc0139,0x7e7cc656,0xc1780153}},	//   _волх, _katl_, ussp, ukės_, 
   {{0xdb0400dd,0x7e7cc657,0x6ab40204,0x528000c6}},	//   ámít, rssp, dwyf, _الوك, 
   {{0x25bc02b9,0x4034c658,0x6ab40204,0x7c08009a}},	//   _matl_, _кекс, ewyf, نيسف_, 
   {{0x224c023a,0xc17800c0,0x00000000,0x00000000}},	//   _hifk_, pkės_, --, --, 
   {{0x2008c659,0xb9983159,0x3974036b,0x2d98a573}},	// [104f0] mici_, квах_, илаё, _fcpe_, 
   {{0xd918822f,0x25bc73cd,0x49743cc5,0x9ba00150}},	//   нье_, _natl_, йлус, _گەرى, 
   {{0xd918c65a,0xd7e40845,0x66080327,0x224c0108}},	//   хьа_, лідо, difk, _mifk_, 
   {{0x9ba00058,0xdb0c0793,0x3dcc03f9,0xf3f0004d}},	//   _دەرى, _pacä, ɓewa_, _mục_, 
   {{0xb5fc0006,0xd1d80023,0xf3f00208,0xdb0807d9}},	//   _atša, ሕሓብ_, _lục_, änäy, 
   {{0xdb1c00c5,0xe7340063,0xf8680ee8,0x00000000}},	//   övõi, јеш_, _لمسي_, --, 
   {{0x2008c65b,0x25b400c6,0xfa340c75,0x33f43d2a}},	//   kici_, شهيد_, _مىڭج, ичис, 
   {{0x73e40cca,0x28e000c5,0x00000000,0x00000000}},	//   роиз, पहरि, --, --, 
   {{0x2008c65c,0x6284c65d,0x6fe4015b,0x00000000}},	//   dici_, škon, খোঁজ_, --, 
   {{0x25bc0166,0xa380000d,0x00000000,0x00000000}},	//   _gatl_, _õõns, --, --, 
   {{0x2008c65e,0x0c840020,0xe0d4084c,0xf3f00208}},	//   fici_, _ክልሎች_, авэ_, _cục_, 
   {{0x2008c65f,0x2cb8003e,0xf3f0004d,0x00000000}},	//   gici_, _rspd_, _dục_, --, 
   {{0xd34004fb,0x91c0010b,0x81bc00e2,0x7298010a}},	//   _افشی, _галҗ, tlēt, _ролĕ, 
   {{0x752c0118,0xa2441291,0x00000000,0x00000000}},	//   řazu, _پیپل_, --, --, 
   {{0x3074c660,0x1d0413d6,0x00000000,0x00000000}},	//   _тулс, аери_, --, --, 
   {{0xab64c661,0x6b64035b,0x6ab405e4,0x78440024}},	//   рвал, ркаа, twyf, _tėvy, 
   {{0xee386393,0x6ab40af9,0x00000000,0x00000000}},	// [10500] _ини_, uwyf, --, --, 
   {{0xada407d6,0xa96801b9,0x996000d7,0x00000000}},	//   _таол, тижа_, tíši_, --, 
   {{0xa81813ef,0x8af003b9,0x00000000,0x00000000}},	//   پتار_, nbəz, --, --, 
   {{0xca78c662,0xf98400c7,0x00000000,0x00000000}},	//   _مەرت_, игӡо, --, --, 
   {{0x660802b4,0xa02408a5,0xa6b402e8,0x00000000}},	//   tifk, _hlöð, рсещ, --, 
   {{0x20080316,0x645c06ed,0xd6cc0fba,0x25bc01d5}},	//   zici_, ípio, بقه_, _qatl_, 
   {{0x20082fbe,0x6608438a,0xa3c001ad,0x87c40352}},	//   yici_, rifk, एएल_, _гөлз, 
   {{0xc29835dd,0x66e4c663,0xc27407b5,0x20084ff3}},	//   гких_, _коба, блиј, xici_, 
   {{0x776c0005,0xf804023a,0xe7280798,0xf3f00051}},	//   ñaxe, _учён, _роад_, _sục_, 
   {{0x66080009,0x20086b95,0x00000000,0x00000000}},	//   qifk, wici_, --, --, 
   {{0x32d8036b,0x26c4005b,0x048801af,0x00000000}},	//   ندیک_, lvoo_, _сәли_, --, 
   {{0x2fd0062c,0x00000000,0x00000000,0x00000000}},	//   _cnyg_, --, --, --, 
   {{0xe1f810fc,0x8f0800c7,0x00000000,0x00000000}},	//   _игд_, ахра_, --, --, 
   {{0x6280c664,0xa02401a8,0xf3f0004d,0x224c007c}},	//   _ivoo, _blöð, _tục_, _uifk_, 
   {{0xdc0c0055,0x8af000ac,0x2df80014,0xd238011a}},	//   _aśāb, mbəy, ابُک_, _שגול, 
   {{0xd0f40375,0x5f740131,0x1ee40214,0x62800037}},	//   _כמות_, _ئاغر, _نوعی_, _kvoo, 
   {{0xcfe8c665,0x61f80037,0xdef800cf,0x3d9400d8}},	// [10510] _خفيه_, ohtl, _шык_, _липр, 
   {{0x98c4196e,0x8af000ac,0x78a00267,0x23a407b7}},	//   исел, nbəy, _älvk, क्तद, 
   {{0xa02402d2,0x8bf800f1,0x00000000,0x00000000}},	//   _glöð, _چوپړ_, --, --, 
   {{0x3f980264,0x00000000,0x00000000,0x00000000}},	//   ngsu_, --, --, --, 
   {{0x21f007a8,0xc7b80108,0x00000000,0x00000000}},	//   _nâho_, рёх_, --, --, 
   {{0xe940168d,0x7aecc666,0x3eb80036,0x00000000}},	//   _کۆمپ, myat, iwst_, --, 
   {{0x7aecc667,0x3dc002b5,0x8af003b9,0x00000000}},	//   lyat, _mahw_, dbəy, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb6f40114,0x8af003b9,0x00000000,0x00000000}},	//   _узај, fbəy, --, --, 
   {{0xe1f4823b,0x61f8c668,0x62800010,0x3eb80042}},	//   йгы_, ghtl, _dvoo, dwst_, 
   {{0x7aec0882,0x4094011b,0xd498010a,0x00000000}},	//   hyat, орят, _шра_, --, 
   {{0x7aecc669,0x3e8c044e,0x00000000,0x00000000}},	//   kyat, _ኤውሮጳ_, --, --, 
   {{0x7aec0882,0x0cd008e9,0x60c8017a,0x8af006be}},	//   jyat, हम्म, _erfm, bbəy, 
   {{0x61f8c66a,0x7aec0a28,0xdb0c0005,0x6da40640}},	//   chtl, dyat, _facú, љива, 
   {{0x60d80175,0x7aec0de2,0x8af00213,0x81600244}},	//   cxtm, eyat, ncəv, _تۆپۆ, 
   {{0x3ce404f3,0x7aecc66b,0xe8f8c66c,0xab28009b}},	//   älva_, fyat, ңла_, гоба_, 
   {{0x7aecc66d,0x322c001f,0x00000000,0x00000000}},	// [10520] gyat, _ስብሰባ, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6cc4c66e,0xe93807fa,0xdb0c01ab,0x7aecc66f}},	//   _уйна, учај_, _macù, ayat, 
   {{0x7aecc670,0x00000000,0x00000000,0x00000000}},	//   byat, --, --, --, 
   {{0x7aec0a28,0x6618020b,0x00000000,0x00000000}},	//   cyat, _pjtk, --, --, 
   {{0x600c02e2,0xd6242069,0x8af00213,0xbab000cf}},	//   _kòmè, боче_, dbəx, _تۅكب, 
   {{0x758802bf,0x18641173,0xd7b40014,0x628008a5}},	//   рсів_, _гаси_, _گۆنڈ_, _svoo, 
   {{0x28140152,0x62847a94,0x3ce4013c,0xe3b0007b}},	//   _اورس, škom, ølvi_, سرع_, 
   {{0xdb040174,0x00000000,0x00000000,0x00000000}},	//   íløg, --, --, --, 
   {{0x60c80263,0xdb0c00e4,0x2d9c068c,0x3d08000d}},	//   _prfm, _pacú, òtel_, _सधले_, 
   {{0x64c4c671,0xd36cc672,0x6578b4fe,0x3fd8084c}},	//   _ديال, _нч_, _ieth, амнэ_, 
   {{0x7aecc673,0x657856fe,0x61f8c674,0x6458c675}},	//   yyat, _heth, shtl, _iuti, 
   {{0x6458c676,0x6578c677,0x6284025a,0x3eb8000f}},	//   _huti, _keth, âkod, uwst_, 
   {{0x7aec0882,0x6724022c,0xdb0c0332,0x3eb80142}},	//   vyat, _økju, _tacú, rwst_, 
   {{0xf1a8c678,0x6458094a,0x6578c679,0xf3f00051}},	//   _خانه_, _juti, _meth, _mụn_, 
   {{0x7aecc67a,0x3a74344a,0x786803e3,0x00000000}},	//   tyat, жлар, növş, --, 
   {{0x6458c67b,0xed4cc67c,0x7aecc67d,0x1a580597}},	// [10530] _luti, ٹھی_, uyat, اشرة_, 
   {{0x6458c67e,0x7aecc67f,0x600c02e2,0x9f4800bc}},	//   _outi, ryat, _fòmè, nkcí_, 
   {{0x6458c680,0x7aecc681,0x3eac0327,0x00000000}},	//   _nuti, syat, ħetu_, --, 
   {{0x6578c682,0x7aec0882,0x4c340153,0x00000000}},	//   _aeth, pyat, _нэўт, --, 
   {{0x64580bed,0x3f8800ec,0x62840006,0x068402dd}},	//   _auti, _mdau_, škoj, згін, 
   {{0x6578c683,0x00000000,0x00000000,0x00000000}},	//   _ceth, --, --, --, 
   {{0xc6a80201,0x6458c684,0x8ccc45bf,0x6578c685}},	//   _መግለጫ_, _cuti, हियो, _deth, 
   {{0x65780c8c,0x64580e21,0x3f880240,0x00000000}},	//   _eeth, _duti, _ndau_, --, 
   {{0x6578c686,0x645800d5,0x78a4b484,0x580001ec}},	//   _feth, _euti, lthv, _доңғ, 
   {{0x6578c687,0x6458c688,0xe16402d3,0x50a00131}},	//   _geth, _futi, _ተሓቢሩ_, كەتل, 
   {{0x9f480030,0xd6640244,0x00000000,0x00000000}},	//   chcú_, _ئمڕو_, --, --, 
   {{0x65780928,0x81bc00da,0x3f880142,0x00000000}},	//   _zeth, slēp, _cdau_, --, 
   {{0x65780928,0x3f8800a9,0x6458c689,0x600c01e1}},	//   _yeth, _ddau_, _zuti, _sòmè, 
   {{0x3f88c68a,0x645801b9,0x2d9c7148,0xa2d001f7}},	//   _edau_, _yuti, üte_, _آيوت, 
   {{0x645801c4,0x61ec01e3,0x00000000,0x00000000}},	//   _xuti, öble, --, --, 
   {{0xa2bc0490,0x996000d7,0x290c00d7,0x00000000}},	//   वटच्, _ríšu_, úfam_, --, 
   {{0x64a800ac,0x261852be,0xaa886794,0x7640007c}},	// [10540] _nəin, _बदली_, شنام_, _ohly, 
   {{0x996002fb,0x00000000,0x00000000,0x00000000}},	//   _píšu_, --, --, --, 
   {{0x98a00107,0x9dd4010f,0x18a00395,0x00000000}},	//   дихе, _וויק_, дахм, --, 
   {{0x6578c384,0x37a80046,0xf39000b8,0x628401d3}},	//   _seth, йтін_, _kṣut_, ákok, 
   {{0xaa440efb,0x6458c68b,0x6578c68c,0x764001ab}},	//   _мемл, _suti, _peth, _bhly, 
   {{0x764003cb,0x6284c68d,0x94040213,0x6578c68e}},	//   _chly, škok, munə_, _qeth, 
   {{0x645801b9,0x6fc80a8a,0xd4c006a6,0x00000000}},	//   _quti, ियां, дсып, --, 
   {{0x6578c68f,0x645806e4,0xda6c0d62,0x00000000}},	//   _weth, _vuti, _سُہ_, --, 
   {{0x6578c690,0x6458c691,0x23a42802,0x8af003b9}},	//   _teth, _wuti, क्षद, ccət, 
   {{0x6458c692,0xe4d44363,0x00000000,0x00000000}},	//   _tuti, _وتاب, --, --, 
   {{0x64580664,0x42542dcd,0x40340006,0x161c05f9}},	//   _uuti, _کنتر, зенс, _बदतर_, 
   {{0x3f880139,0x8af00213,0x00000000,0x00000000}},	//   _qdau_, ncəs, --, --, 
   {{0x4ec406a6,0x93c800e5,0xd320010a,0x00000000}},	//   мёрз, _خالہ_, _оьши, --, 
   {{0x81f84a6a,0xd24c01ca,0x50b4179e,0x8af003b9}},	//   _دفتر_, _іц_, حدید_, hcəs, 
   {{0xfb889fde,0xf3ec03d4,0x9c08035b,0x8af006be}},	//   йрақ_, _জগতৰ_, ахаз_, kcəs, 
   {{0x0c840020,0xc4c40a81,0x00000000,0x00000000}},	//   _ክፍሎች_, _یے_, --, --, 
   {{0x64404695,0x8af000ac,0xc68401e2,0x00000000}},	// [10550] _mhoi, dcəs, _جې_, --, 
   {{0x78a400fc,0x64400076,0x00000000,0x00000000}},	//   tthv, _lhoi, --, --, 
   {{0x6440005a,0x628402fb,0x7c340314,0x00000000}},	//   _ohoi, škoh, _неох, --, 
   {{0xefcc02d3,0x764046c8,0x78a4032e,0xc8c801c8}},	//   _ብቑዕ_, _shly, rthv, غونن_, 
   {{0x7c2cc693,0xc6680261,0x75fc033b,0x55c002dd}},	//   moar, ошје_, _lèze, далғ, 
   {{0x7c2cc694,0x64400418,0x1dc8076e,0x236401a6}},	//   loar, _ahoi, ायित, _afoj_, 
   {{0x64407ea1,0x00000000,0x00000000,0x00000000}},	//   _bhoi, --, --, --, 
   {{0x7c2cc695,0x6440c696,0x8ccc206b,0x96b800cf}},	//   noar, _choi, हितो, _پارز_, 
   {{0xd5b85aa2,0x644014d0,0x7c2c009d,0x1dc801bc}},	//   _все_, _dhoi, ioar, ायात, 
   {{0x7c2cc697,0x64400076,0x00000000,0x00000000}},	//   hoar, _ehoi, --, --, 
   {{0x6440387b,0x7c2cc698,0x8af000ac,0x8b080210}},	//   _fhoi, koar, ncər, mięż, 
   {{0x6440c699,0x7f84c69a,0x7c2cc69b,0x93a86356}},	//   _ghoi, ولپن, joar, _خائف_, 
   {{0x7c2cc69c,0xf1a800f1,0x00000000,0x00000000}},	//   doar, _هاغه_, --, --, 
   {{0x8b08033f,0x9f4800e5,0x21a0022e,0x00000000}},	//   nięż, émái_, _зишм, --, 
   {{0x7c2cc69d,0xb5fc00ef,0x00000000,0x00000000}},	//   foar, _atšk, --, --, 
   {{0x7c2cc69e,0x64400472,0x00000000,0x00000000}},	//   goar, _xhoi, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [10560] --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb5fc000a,0x6e2cc69f,0xb3bc0b7c,0xb910063f}},	//   _itšh, mobb, ्याख, miaị_, 
   {{0x6e2c014f,0x7c2cc6a0,0x3f9c00a2,0xd820009d}},	//   lobb, coar, _öwut_, ндхи, 
   {{0xfbb8012c,0x6440015d,0x00000000,0x00000000}},	//   उजरम, _rhoi, --, --, 
   {{0x6440c6a1,0x6e2cc6a2,0x00000000,0x00000000}},	//   _shoi, nobb, --, --, 
   {{0x644061a1,0x75fc02e2,0x2aa400d7,0xc3c4009d}},	//   _phoi, _bèzb, lôb_, дөлл, 
   {{0x6e2cc6a3,0xd6a800cc,0x00000000,0x00000000}},	//   hobb, _গছৰপ, --, --, 
   {{0x644006d6,0x31640354,0x6e2c12e8,0x00000000}},	//   _vhoi, fclz_, kobb, --, 
   {{0x6440c6a4,0xb5fc1ebd,0x7c2cc6a5,0x6e2c3be7}},	//   _whoi, _ntšh, zoar, jobb, 
   {{0x64403c5d,0x6e2cc6a6,0x7c2c0009,0x00000000}},	//   _thoi, dobb, yoar, --, 
   {{0x7c2c05f5,0x2aa40109,0xa83801ec,0xa3b801ed}},	//   xoar, kôb_, _اﯙﺗﻮ, _دائر_, 
   {{0x7c2cc6a7,0x63a0c6a8,0x81e40154,0x00000000}},	//   voar, _icon, নসব_, --, 
   {{0x91e05a5a,0x6e2c003e,0x7c2c8a45,0x2aa40419}},	//   _поче, gobb, woar, dôb_, 
   {{0x7c2c1142,0xcb30002b,0x00000000,0x00000000}},	//   toar, _īśaḥ_, --, --, 
   {{0x8bc400d1,0x64a806be,0x00000000,0x00000000}},	//   нсуд, _nəim, --, --, 
   {{0x7c2cc6a9,0x6e2cc6aa,0x63a02959,0x61e804cc}},	// [10570] roar, bobb, _mcon, _kofl, 
   {{0x7c2cc6ab,0x7e6cc6ac,0x6e2cc6ad,0x61e805be}},	//   soar, _itap, cobb, _jofl, 
   {{0x63a0c6ae,0x7c2cc6af,0xf8b80b61,0xe1ac01f9}},	//   _ocon, poar, تهاب_, ज्यघ, 
   {{0x63a0192e,0x33f00120,0xd760035c,0x61e80af9}},	//   _ncon, _táxi_, رنتی, _lofl, 
   {{0x7e68084c,0x61e833ec,0x1ca80327,0xea600150}},	//   _împă, _oofl, བསམ_, _لۇقپ, 
   {{0x61e88215,0x7e6cc6b0,0x00000000,0x00000000}},	//   _nofl, _mtap, --, --, 
   {{0x2d9c067c,0x00000000,0x00000000,0x00000000}},	//   òtei_, --, --, --, 
   {{0x63a00334,0x23b00131,0x8b08012d,0x00000000}},	//   _ccon, نمىس, sięż, --, 
   {{0x7e6cc6b1,0x6e2c0429,0xe9080327,0xdb0c0332}},	//   _ntap, yobb, _གཟོབ_, _iacó, 
   {{0x78a001e6,0x61e8015d,0xd4980798,0xd61800e5}},	//   _älvs, _cofl, _грд_, _اترا_, 
   {{0x7e6cc6b2,0x9324c6b3,0x61e8002e,0x63a0c6b4}},	//   _atap, _کران, _dofl, _fcon, 
   {{0x63a000c6,0x31640175,0x00000000,0x00000000}},	//   _gcon, sclz_, --, --, 
   {{0x6e2c0548,0xb5fc2ba4,0xcb0c01ad,0x00000000}},	//   tobb, _atši, _सेंड_, --, 
   {{0xdb0c25e6,0x61e80142,0x7e6c0332,0x02c40166}},	//   _lacó, _gofl, _dtap, _чишү, 
   {{0xdca0c6b5,0x6e2cc6b6,0x62840122,0xe908031c}},	//   кари, robb, ákov, _གཟེབ_, 
   {{0x6e2c67e5,0x77680327,0xf3300023,0x63a00175}},	//   sobb, _nfex, _ኣሓትና, _xcon, 
   {{0xee08041b,0x78b46e98,0xfb2400cf,0x00000000}},	// [10580] _меил_, _apzv, ептү, --, 
   {{0x7c281326,0x2aa400d0,0x6e2c0175,0x61e806be}},	//   čera, rôb_, qobb, _xofl, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7c94009d,0x00000000,0x00000000,0x00000000}},	//   _ярьц, --, --, --, 
   {{0x7e6c0fac,0x0e2c00b8,0x00000000,0x00000000}},	//   _xtap, _ṛṣer_, --, --, 
   {{0xfca80014,0x63a09ff4,0xe4680fbe,0xaa440212}},	//   _بایو_, _scon, ошил_, _цегл, 
   {{0x63a0030d,0xdb0c0129,0x00000000,0x00000000}},	//   _pcon, _abcè, --, --, 
   {{0xd940c6b7,0xc4341699,0x1bf8010f,0x31680139}},	//   _реси, رکات, ַליב, _ğaza_, 
   {{0x752c046c,0x27e401b9,0x83fc110c,0x61e8003a}},	//   ğaza, mjon_, _nuđe, _pofl, 
   {{0x27e4c6b8,0x24f43549,0xe46802d2,0x00000000}},	//   ljon_, _очер, glöð_, --, 
   {{0xdb0c067c,0x7e6c0e2b,0x00000000,0x00000000}},	//   _jacò, _stap, --, --, 
   {{0x27e4c6b9,0x63a03d1a,0x83fc05ce,0x98a407f5}},	//   njon_, _ucon, _buđe, žići_, 
   {{0xe46801a8,0x61e801ef,0x00000000,0x00000000}},	//   blöð_, _tofl, --, --, 
   {{0x8d7401d3,0x02bcc6ba,0x00000000,0x00000000}},	//   ہاہا, ्टीन, --, --, 
   {{0x7e6c037e,0x00000000,0x00000000,0x00000000}},	//   _wtap, --, --, --, 
   {{0x75fc0100,0x7e6c01c4,0x3b5400fd,0x00000000}},	//   _mèza, _ttap, екбр, --, 
   {{0x7e6cc6bb,0x27e43c73,0xdb0c004e,0x75fc02e2}},	// [10590] _utap, djon_, _racó, _lèza, 
   {{0x27e401e4,0xce3400f1,0x00000000,0x00000000}},	//   ejon_, _ټوپک, --, --, 
   {{0x7dd400a2,0x27e401d5,0x00000000,0x00000000}},	//   _eýsä, fjon_, --, --, 
   {{0x27e4c6bc,0xe36c0241,0xe5a00b01,0xb5fcc6bd}},	//   gjon_, _sọnù_, ҳиши, _muše, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe5a0548a,0x6fd40166,0x27e401f4,0x00000000}},	//   гиши, _kücä, ajon_, --, 
   {{0x97a4c6be,0xdb0cc6bf,0x7984004c,0x27e44d2f}},	//   _орал, _tacó, mahw, bjon_, 
   {{0x7984c6c0,0x75fc0100,0x72c40137,0x27e40200}},	//   lahw, _dèza, ебиз, cjon_, 
   {{0xb06402f6,0x47e401e0,0x473400db,0xe3700139}},	//   kyää, _шәфҡ, _антс, уһчы, 
   {{0xb5fcc6c1,0x7984004c,0x83fc4bc9,0xb9dc1ef7}},	//   _buše, nahw, _ruđe, _ባና_, 
   {{0x83fc0bb8,0x645c02f0,0x798402d0,0x00000000}},	//   _suđe, ípit, iahw, --, 
   {{0xb5fc76e0,0x79840223,0xaad0012c,0xafe4c6c2}},	//   _duše, hahw, सिमक, хомл, 
   {{0x7984c6c3,0xc30403e6,0xe0cc01c0,0xe28c3d2a}},	//   kahw, _لبوو, _өв_, _ща_, 
   {{0x79843e61,0x6224005e,0x27e4c6c4,0x6b4800e5}},	//   jahw, _كونە, zjon_, högé, 
   {{0x6284c6c5,0xb5fc07f5,0x7c280331,0x79840526}},	//   škot, _guše, čern, dahw, 
   {{0x83fc05a1,0xdb0c0ba1,0x1be417a0,0xf3f00051}},	//   _tuđe, _racò, ндси_, _bụi_, 
   {{0x27e401d3,0x6994010a,0xaa4401a9,0x00000000}},	// [105a0] vjon_, ерех, ееал, --, 
   {{0x798400ca,0x30d000cc,0x2e3408a5,0x00000000}},	//   gahw, াহীস, gæft_, --, 
   {{0x27e4c6c6,0x6d5cc643,0x00000000,0x00000000}},	//   tjon_, _igpa, --, --, 
   {{0xa83400cf,0x2a700076,0x27e401e4,0xb3a827ac}},	//   رعاش, ppyb_, ujon_, _şını, 
   {{0x79840516,0x75fc0100,0x27e4c6c7,0xd7840014}},	//   bahw, _sèza, rjon_, رنوو_, 
   {{0x27e4c6c8,0x6d5c0798,0xb95400d1,0x00000000}},	//   sjon_, _jgpa, رئەت, --, 
   {{0xd940c6c9,0x6d5c1c06,0x27e4c6ca,0xb86400ae}},	//   _бери, _mgpa, pjon_, _لاقو, 
   {{0x27e401a9,0x82d801a9,0x00000000,0x00000000}},	//   qjon_, ддис_, --, --, 
   {{0x02bc06b1,0x61ecc6cb,0x6d5c02d0,0xb5fc00ef}},	//   ्टेन, öblo, _ogpa, _atšu, 
   {{0xb5fc08a4,0x6d5c79b8,0x1718008f,0x92b000c6}},	//   _puše, _ngpa, _זומע, احيا, 
   {{0x98b01674,0x5a140375,0x00000000,0x00000000}},	//   čeće_, תקין_, --, --, 
   {{0x6d5c0280,0x79840223,0x00000000,0x00000000}},	//   _agpa, zahw, --, --, 
   {{0x79840810,0xb064005b,0x5334010a,0x00000000}},	//   yahw, tyää, _пушă, --, 
   {{0xb5fc46aa,0x84e402ab,0x6284276e,0x81e40154}},	//   _tuše, _कपाट_, škos, নসহ_, 
   {{0x9c44c6cc,0x00000000,0x00000000,0x00000000}},	//   ехал, --, --, --, 
   {{0x6d5c0660,0xc1780006,0xd7ccc6cd,0x79840810}},	//   _egpa, lbė_, _सोंच, wahw, 
   {{0x3b54807e,0x7984c6ce,0xc1780064,0x00000000}},	// [105b0] ткар, tahw, obė_, --, 
   {{0x61f8c6cf,0x00000000,0x00000000,0x00000000}},	//   nktl, --, --, --, 
   {{0x2e3400b5,0x7984c6d0,0x00000000,0x00000000}},	//   ræft_, rahw, --, --, 
   {{0x7984006f,0xf3f00051,0xcf9400df,0x00000000}},	//   sahw, _tụi_, ָטס_, --, 
   {{0x7bccc6d1,0x35a48a0f,0x79840099,0x02bc1025}},	//   mdau, валг, pahw, ्टोन, 
   {{0x0c740502,0x63d000f1,0xbb3c02dd,0xb89400e5}},	//   _جدید, یښنا, _ﺟﻮﻓ_, _لارڈ, 
   {{0xb7c417de,0xf86801f7,0xd808005b,0x00000000}},	//   _ирақ, _آمري_, _ехал_, --, 
   {{0x7bccc6d2,0xd774594c,0x6680065f,0xc17800c0}},	//   ndau, _سارع, _چینل, ebė_, 
   {{0x7bccc6d3,0xb2243943,0x05740133,0xdce40153}},	//   idau, кмил, _ڕاند, pajė, 
   {{0x7bdc089c,0xf280044e,0x33f0056a,0xf61823bb}},	//   _lnsu, _ሓደገኛ_, _páxs_, _غياث_, 
   {{0x7bdcc6d4,0x62840174,0x623000d8,0x00000000}},	//   _onsu, ákor, реќу, --, 
   {{0x7bcc0007,0xb4bc00af,0x00000000,0x00000000}},	//   jdau, इबी_, --, --, 
   {{0x7bcc0198,0x6284b9b7,0x60040064,0x00000000}},	//   ddau, škor, тням_, --, 
   {{0x7bdcc6d5,0x7bcc0a73,0x5184c6d6,0x00000000}},	//   _ansu, edau, _чуда, --, 
   {{0x75fc0100,0x3b08031c,0x00000000,0x00000000}},	//   _lèzo, ezaq_, --, --, 
   {{0x7bccc6d7,0x92e003d4,0xdca01fbe,0x7c440014}},	//   gdau, ননী_, јати, ُکَے, 
   {{0xa9a4ad0e,0x6e4400c7,0x2d9c067c,0xeac401b9}},	// [105c0] киад, _иеиз, òtes_, ъбап, 
   {{0x6d5cc6d8,0x7bdcc6d9,0xed580137,0x1a00084c}},	//   _ugpa, _ensu, _ооп_, апум, 
   {{0x83fc3c52,0xe7a80108,0x00000000,0x00000000}},	//   _luđa, двел_, --, --, 
   {{0x9cd4008d,0xb3d00316,0x752cc6da,0x6a84074d}},	//   _סוכה_, _दोलख, ğazl, _илма, 
   {{0x7790c6db,0xc17802d5,0x61f8c6dc,0x00000000}},	//   صیلا, ybė_, yktl, --, 
   {{0x6284025a,0x96300006,0x00000000,0x00000000}},	//   âkom, аніц, --, --, 
   {{0x7bdc002d,0x65680332,0xdecc0092,0x00000000}},	//   _ynsu, rcfh, ብቅና_, --, 
   {{0x83fc0cf4,0xb0d400af,0x656800ae,0x00000000}},	//   _buđa, धिनग, scfh, --, 
   {{0xd400c6dd,0x2a64007b,0x24940014,0x65c4004e}},	//   рящи, íobh_, رمکھ_, _ибаа, 
   {{0x44fc0135,0x3204c6de,0x2cb8031c,0x7bcc0153}},	//   ྐྱུར_, ghly_, _oppd_, zdau, 
   {{0x61f86cbd,0xc1780024,0x94d000ec,0x00000000}},	//   rktl, rbė_, _پينش, --, 
   {{0x44201105,0x7bcc0007,0x320400d0,0x20ec06be}},	//   _ñi_, xdau, ahly_, bəin_, 
   {{0x62641c3e,0x00000000,0x00000000,0x00000000}},	//   _شاشق, --, --, --, 
   {{0xb5fc0331,0x3204c6df,0x0e34011b,0x00000000}},	//   _kuša, chly_, иняю, --, 
   {{0x7bccc6e0,0x5ba40022,0xb5fc00ef,0xa02001f4}},	//   tdau, краз, _juša, äöst, 
   {{0x81e4009e,0xb5fc8969,0x7bcc03ef,0x00000000}},	//   _নতি_, _muša, udau, --, 
   {{0x7bccc6e1,0x7d0800e8,0x00000000,0x00000000}},	// [105d0] rdau, _bëré, --, --, 
   {{0xd918656c,0x7bcc1362,0x09740229,0x497403c5}},	//   мье_, sdau, игую, илус, 
   {{0x7798c6e2,0xb5fc0153,0x7bcc0076,0x5884c6e3}},	//   екер_, _nuša, pdau, тыза, 
   {{0xc794c6e4,0x06cc0154,0x9ba000d1,0x00000000}},	//   аршы, লমনি, _خەرى, --, 
   {{0x4ae407d6,0xb5fc0171,0x00000000,0x00000000}},	//   _кўра, _auša, --, --, 
   {{0xb5fc0e3c,0xdb1c02d3,0xa2d40b9a,0xf3f00051}},	//   _buša, heqë, बिन्, _lụt_, 
   {{0x2ba8c6e5,0xd0ac013f,0xb4bc00af,0x074400d1}},	//   ङ्का, yɛɑs, इबे_, лхәм, 
   {{0xa8540184,0x00000000,0x00000000,0x00000000}},	//   _бесә, --, --, --, 
   {{0xe3b4c1a1,0x3204c6e6,0xdb0c0118,0x628400c7}},	//   убы_, thly_, _obcí, ákop, 
   {{0x50a00075,0x7a380ffb,0xb5fc0010,0x96440276}},	//   لەتل, pìtu, _fuša, _рэбд, 
   {{0x7c28151c,0x04c87427,0x628400de,0x00000000}},	//   čerj, _لولي_, škop, --, 
   {{0xc50c008f,0xa3cc00dc,0x3204c6e7,0xb5c80133}},	//   _קלאָ, शयः_, shly_, _زوڵم_, 
   {{0xb8e4003d,0x00000000,0x00000000,0x00000000}},	//   _ཉག_, --, --, --, 
   {{0x22900597,0x2bf400af,0xaad004af,0xdce40055}},	//   _الوس, _एकहू_, सिसक, cajī, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3ec836be,0x6e440454,0xe8f800c7,0xc0c800f3}},	//   ättä_, теҳз, ҭла_, _руље_, 
   {{0x2ba82f2e,0x6a64036b,0xaa480120,0x59b001c6}},	// [105e0] ङ्गा, اطرل, епаа_, өөрс, 
   {{0x5980004e,0x00000000,0x00000000,0x00000000}},	//   йлуб, --, --, --, 
   {{0xb86400aa,0x2d88c6e8,0xad5801c0,0x3ce40267}},	//   لانو, mabe_, _ярих_, älvt_, 
   {{0x2d88c6e9,0xdc9802e4,0x9d18008f,0xb5fc0010}},	//   labe_, _איטל, _טויט, _ruša, 
   {{0xb5fcc6ea,0x00000000,0x00000000,0x00000000}},	//   _suša, --, --, --, 
   {{0x2d88c6eb,0x45d400a8,0x295400a7,0x45440022}},	//   nabe_, рокс, _бъбр, аҕза, 
   {{0xd49409a5,0x69ccc6ec,0x291c00c7,0x00000000}},	//   гры_, _iabe, _ãta_, --, 
   {{0x69ccc6ed,0x9cd40375,0xe7380b01,0x00000000}},	//   _habe, רוקה_, _зеб_, --, 
   {{0x6b84c6ee,0xd6940014,0xb6c401e0,0xb81000f1}},	//   _mekg, _مۅنڈ_, _китһ, _بېنظ, 
   {{0x6b846336,0x69ccc6ef,0x2d88c6f0,0x26c4037e}},	//   _lekg, _jabe, jabe_, mwoo_, 
   {{0x69ccc6f1,0x2d88c6f2,0x03140dad,0xd1b400dd}},	//   _mabe, dabe_, _तेरह_, ھایا_, 
   {{0x69ccc6f3,0xb5fc341a,0x6b84c6f4,0x403401f4}},	//   _labe, _jušn, _nekg, ремс, 
   {{0xdef83c7f,0x26c40263,0x4424003a,0x2d880205}},	//   хын_, nwoo_, mnm_, fabe_, 
   {{0x2d88c6f5,0x0dc800d1,0x62800ca8,0xb5fc0427}},	//   gabe_, луси_, _iwoo, _lušn, 
   {{0x6b8405e4,0xc0c4013d,0x00000000,0x00000000}},	//   _bekg, _тәпи, --, --, 
   {{0x8c6423c0,0x6280c6f6,0x6b8405b1,0x69ccc6f7}},	//   стрд, _kwoo, _cekg, _aabe, 
   {{0x2d88c6f8,0x3d940b59,0x6b840af9,0x442400ae}},	// [105f0] babe_, _кипр, _dekg, inm_, 
   {{0x69cc748d,0x2d88c6f9,0x6280062c,0x6b8403ac}},	//   _cabe, cabe_, _mwoo, _eekg, 
   {{0x69ccc6fa,0x391400f0,0x752c03e0,0x00000000}},	//   _dabe, јмер, ğazk, --, 
   {{0x8d74034c,0x69ccc6fb,0x62800337,0x6c78010f}},	//   _پایا, _eabe, _owoo, _שארפ, 
   {{0x7d000158,0xb5fc01ef,0x00000000,0x00000000}},	//   ølsf, _dušn, --, --, 
   {{0x69ccc6fc,0x64a806be,0x7c300135,0x23d801f9}},	//   _gabe, _nəis, żerċ, _मोबद, 
   {{0x62800a81,0x26c40e14,0xf3e42d29,0x8af003e3}},	//   _awoo, awoo_, ижко, dcəy, 
   {{0x69ccc6fd,0x33d40046,0x6280c6fe,0x24500b6c}},	//   _zabe, рікт, _bwoo, ينوس, 
   {{0x69cc046a,0x2d88c6ff,0x0ec4012d,0xf3480395}},	//   _yabe, yabe_, _लैंड, ъпил_, 
   {{0x248c0421,0x69ccc700,0xe1f402d9,0x2d8801c4}},	//   bsfm_, _xabe, игы_, xabe_, 
   {{0x2d889ef6,0x6280c701,0x6fa80490,0x44240175}},	//   vabe_, _ewoo, _कादं, bnm_, 
   {{0x2d88c702,0x44240175,0x437400db,0xc0580006}},	//   wabe_, cnm_, _лушт, ліў_, 
   {{0x2d88c703,0x6280a6a4,0xa3b00073,0x7994012d}},	//   tabe_, _gwoo, टभर_, _odzw, 
   {{0x2164896a,0x6b8418d6,0x799402b9,0x60c8088b}},	//   _киши_, _sekg, _ndzw, ämmä, 
   {{0x69ccc704,0x2d88c705,0x82343b5f,0x6b640801}},	//   _rabe, rabe_, _ارنا, иква, 
   {{0x2d88c706,0x31c41a2a,0x799402d0,0x628002d0}},	//   sabe_, _वसुध, _adzw, _ywoo, 
   {{0xcb00c707,0xb5fcc708,0xa96800f3,0x802400f1}},	// [10600] लैंड_, _rušn, виза_, _دروم, 
   {{0xa958911b,0x69cc2845,0x2d94804a,0x2d88c709}},	//   نجار_, _qabe, _трис, qabe_, 
   {{0x69cc05b8,0x61ec00af,0xb5fc0010,0x26c400e8}},	//   _vabe, öbli, _pušn, wwoo_, 
   {{0xb5fc07f5,0xe0b4010f,0x00000000,0x00000000}},	//   _bušo, ילעט_, --, --, 
   {{0x44240564,0x16a40063,0x671432ed,0x65c401b9}},	//   vnm_, ивци_, _देशक_, ибда, 
   {{0x69cc009a,0x7d000158,0x96f4c70a,0x26c40036}},	//   _uabe, ølsg, решт_, rwoo_, 
   {{0x6280c70b,0x291cc70c,0xf99000aa,0x439492fe}},	//   _swoo, _äta_, _ژبې_, байс, 
   {{0x6820063f,0x00000000,0x00000000,0x00000000}},	//   ọdba, --, --, --, 
   {{0xe5a4c70d,0xb5fc01fa,0x386c85a2,0x44240393}},	//   _визи, _kušl, _čeri_, rnm_, 
   {{0x7c28c70e,0x216424a9,0x83fc07f5,0xb4b405d9}},	//   čeri, штиг, _tuđo, _ڇڏيا_, 
   {{0x64c42781,0xb5fc0306,0xd36c0108,0x00000000}},	//   _خيال, _mušl, _мч_, --, 
   {{0x1e70036b,0xe29801c0,0x00000000,0x00000000}},	//   оғис, _аад_, --, --, 
   {{0x6280009a,0x81d4014b,0x00000000,0x00000000}},	//   _uwoo, _голх, --, --, 
   {{0xca400952,0xb5fc0153,0xa3cc07f7,0xa908022e}},	//   ﻜﯩﺮ_, _nušl, शयक_, nbоs, 
   {{0x4094b6cd,0xa2c81b6e,0xe7c401f9,0x00000000}},	//   _البر, _तैत्, ळजाप, --, 
   {{0x3cec0989,0xda640451,0x31680166,0x515805d0}},	//   ćev_, لائي, _ğazi_, _בכוו, 
   {{0x9964c70f,0x9a8412e6,0x0a68c710,0x752c7225}},	// [10610] ател, рубл, архи_, ğazi, 
   {{0xd35408a8,0xd07c0092,0xb5fc00ef,0xdb20032e}},	//   שימי_, _የተሠሩ_, _rušo, _þríl, 
   {{0x7d0000cc,0xb3100327,0x3774c2ec,0xb5fc0064}},	//   ølsd, ྋགོང_, былс, _sušo, 
   {{0xb5fc000a,0x00000000,0x00000000,0x00000000}},	//   _pušo, --, --, --, 
   {{0xa3e80d79,0x3f880481,0xd87400f7,0x79940175}},	//   मान_, _meau_, _چارب, _tdzw, 
   {{0x3f88c711,0x79940099,0x857800a7,0x4cd4004b}},	//   _leau_, _udzw, асът_, _اغیز, 
   {{0x8894c712,0xcd980375,0x394402d2,0x00000000}},	//   _мирх, בדות_, _áls_, --, 
   {{0x3f88c713,0xb5fc01ef,0x00000000,0x00000000}},	//   _neau_, _zušl, --, --, 
   {{0x35f40022,0x00000000,0x00000000,0x00000000}},	//   _лпар, --, --, --, 
   {{0x3f880421,0xd49805f5,0xb5fc0309,0x00000000}},	//   _aeau_, _ард_, _kušm, --, 
   {{0x3f88c714,0x00000000,0x00000000,0x00000000}},	//   _beau_, --, --, --, 
   {{0x3f881368,0xb5fc00ef,0x00000000,0x00000000}},	//   _ceau_, _mušm, --, --, 
   {{0xb8d82b88,0xaac40c2e,0xe1ec084c,0x23c40014}},	//   _མད_, _रैंक, _ег_, _دٕنہ, 
   {{0xee38bd06,0x7c3c003e,0x307400f0,0xc2440064}},	//   унг_, _aksr, _луис, _днік, 
   {{0xeb9879e5,0x3f88c715,0x78a4a75f,0x3074009d}},	//   лив_, _feau_, juhv, _уулс, 
   {{0x78a40384,0x3f88c716,0x200800bc,0xa3e800dc}},	//   duhv, _geau_, chci_, माय_, 
   {{0xb5fc0010,0xada40b00,0x6da40334,0xad4000cf}},	// [10620] _pušl, _лапл, _липа, تۉگۉ, 
   {{0x7c3cc717,0xb5fc01fa,0xae44004b,0x78a402d2}},	//   _eksr, _bušm, _دپخو, fuhv, 
   {{0x3f88009a,0x645c0109,0x6cf8010a,0x00000000}},	//   _yeau_, ìpik, _сенĕ, --, 
   {{0xb5fc2630,0x7d002ab7,0x37a801ec,0x999001ef}},	//   _dušm, ølse, итін_, boxů_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x66e47c2e,0x78a40cf4,0x386c02f0,0x7c640244}},	//   _қоза, buhv, _červ_, _دایل, 
   {{0x7c280122,0x18a0c718,0x98a00209,0x00000000}},	//   červ, _нарм, _нире, --, 
   {{0x83fc098d,0x4274c719,0xc27410fc,0xd88401d9}},	//   _tuđm, огис, олиј, _چھۆن_, 
   {{0x68fc0209,0x3f88c71a,0x00000000,0x00000000}},	//   lypd, _reau_, --, --, 
   {{0xd9cc00bd,0x3f88c71b,0xa5085cdd,0x00000000}},	//   রাথম, _seau_, _йеза_, --, 
   {{0x3f88c71c,0x68fc0209,0xa18401e0,0x00000000}},	//   _peau_, nypd, _һыйл, --, 
   {{0x7f580395,0x00000000,0x00000000,0x00000000}},	//   ианс_, --, --, --, 
   {{0x3f88004a,0x2c6c00a2,0xe67c00a2,0x68fc010e}},	//   _veau_, _aýd_, _öräý, hypd, 
   {{0xcd740395,0x68fc00ee,0x00000000,0x00000000}},	//   згръ, kypd, --, --, 
   {{0x3f88c71d,0xfb8800d1,0x68fc0432,0xdbc4032e}},	//   _teau_, ирақ_, jypd, föðu, 
   {{0x82340137,0x7c3c0175,0x68fc00ee,0x00000000}},	//   _ارچا, _qksr, dypd, --, 
   {{0x79f4c71e,0x7d0005ac,0x00000000,0x00000000}},	// [10630] озах, ølsb, --, --, 
   {{0xdda8c71f,0x7f4c014b,0xbdc000d1,0x78a403b2}},	//   _стил_, _izaq, _تەسۋ, tuhv, 
   {{0xd7f8c720,0x68fc010e,0xdbc402d2,0x00000000}},	//   луд_, gypd, böðu, --, 
   {{0xb8f00f4a,0x629c0069,0x16700ed1,0xad180302}},	//   _वन_, _āpon, зқар, _כותר, 
   {{0x2c0c00dc,0xcfb8123b,0x00000000,0x00000000}},	//   _सततं_, מלאי_, --, --, 
   {{0x6d5809a5,0x2364008f,0xb5fc0219,0x6080001f}},	//   ýtag, _agoj_, _tušm, _የሰጡት_, 
   {{0x7aecc721,0xb5fc05a1,0xe72c0133,0x79e401ec}},	//   lxat, _hušk, _یڵه_, _ﺍﻷﻓﻀ, 
   {{0xc0cc001f,0x7f4c008e,0x00000000,0x00000000}},	//   ባኖስ_, _ozaq, --, --, 
   {{0x7aecc722,0x7f4c0175,0xb5fc56ce,0xaad000bc}},	//   nxat, _nzaq, _jušk, सिएक, 
   {{0xb5fc0bb8,0x31241de1,0x7aec004e,0x62300114}},	//   _mušk, ждог, ixat, мењу, 
   {{0x7aec0227,0x2fd0036b,0x7f4c013d,0xb5fc0427}},	//   hxat, _payg_, _azaq, _lušk, 
   {{0xa3e80118,0xb4d4023e,0x7aec094a,0x2fd001b9}},	//   माण_, िटी_, kxat, _qayg_, 
   {{0xe2d800dd,0x6284025a,0xb5fc0010,0x1e80188c}},	//   _پانچ_, âkot, _nušk, млям, 
   {{0xa0500020,0x00000000,0x00000000,0x00000000}},	//   መለከታ, --, --, --, 
   {{0x7f4c0921,0xdbc4008c,0xb5fc00ef,0x66140100}},	//   _ezaq, töðu, _aušk, èyki, 
   {{0xb5fc0b4b,0x00000000,0x00000000,0x00000000}},	//   _bušk, --, --, --, 
   {{0xa3e80574,0xa994c723,0x7aec0117,0x7e7c02d0}},	// [10640] मात_, قشات, gxat, cpsp, 
   {{0xb5fc0960,0xc18c008f,0xfe74009d,0x00000000}},	//   _dušk, ָטאָ, _хүр_, --, 
   {{0x6d580209,0xa3280784,0x18b000b1,0x00000000}},	//   ýtad, l葵ti, мәтр, --, 
   {{0x68fc00ee,0x7aec0ba7,0x386c0306,0xb5fc02f0}},	//   rypd, bxat, _čert_, _fušk, 
   {{0x6284012c,0x00000000,0x00000000,0x00000000}},	//   škoz, --, --, --, 
   {{0x23700210,0xdb20032e,0x991800dc,0x00000000}},	//   _żyj_, _þrál, _śāśv, --, 
   {{0xd9402a20,0x6ab4c724,0x80a8c725,0x4394c726}},	//   _жери, ltyf, _कमें, пайс, 
   {{0x2d9801af,0x186406ed,0x6ab400b5,0x7e7c0162}},	//   _ldpe_, _фати_, otyf, ypsp, 
   {{0x6ab4c727,0x54303090,0x00000000,0x00000000}},	//   ntyf, برور, --, --, 
   {{0x7f4c06be,0xb3a80166,0x00000000,0x00000000}},	//   _rzaq, _şıtı, --, --, 
   {{0xa3e83994,0x24f40022,0x2364007c,0xa2c800cd}},	//   माद_, _ьчар, _tgoj_, _तैर्, 
   {{0x7aecc728,0x6ab4c729,0x00000000,0x00000000}},	//   yxat, ktyf, --, --, 
   {{0x7aecadb5,0x1858010f,0xd12c35aa,0xf7880166}},	//   xxat, יכטע, _یمه_, luçí_, 
   {{0xb5fcc72a,0x91e003f5,0x00000000,0x00000000}},	//   _rušk, _ооче, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7aecc72b,0x3a747617,0x83fc00f3,0x78a005ac}},	//   txat, злар, _buđi, _ålvi, 
   {{0x7f4c00ac,0x00000000,0x00000000,0x00000000}},	// [10650] _uzaq, --, --, --, 
   {{0x527804ac,0x7aec004e,0xc98407c6,0x69d8148b}},	//   ינמא, rxat, дуци, _ótel, 
   {{0x7e6cc72c,0x7aec0054,0x81bc005f,0x2bd400bc}},	//   _huap, sxat, tnēj, _ढोका, 
   {{0x7e6cc72d,0x7aec094a,0x7c280122,0x25bc0175}},	//   _kuap, pxat, čers, _abtl_, 
   {{0x7aec0054,0xeb7400c8,0x366801f4,0x00000000}},	//   qxat, _מערץ_, щало_, --, 
   {{0x7e6cc72e,0xb5fc02d1,0x7e64014f,0x00000000}},	//   _muap, _kuši, _jihp, --, 
   {{0x85b801d9,0x7e6cc72f,0xf50402d5,0xb5fc01a6}},	//   تانس_, _luap, язко, _juši, 
   {{0xb5fc0558,0xf2d807d6,0x00000000,0x00000000}},	//   _muši, مبخش_, --, --, 
   {{0x38c401e1,0x00000000,0x00000000,0x00000000}},	//   bèrò_, --, --, --, 
   {{0x7e64014f,0x05741178,0x00000000,0x00000000}},	//   _nihp, _قامد, --, --, 
   {{0x7e6c0607,0xb5fcbb62,0x38b42611,0xdb2001a8}},	//   _auap, _nuši, når_, _þræl, 
   {{0xdbf401ad,0x77340023,0x00000000,0x00000000}},	//   ीसोड_, _እናሓሰ, --, --, 
   {{0x7e6c00e4,0xb5fc0024,0x3a2000b5,0x94d8012d}},	//   _cuap, _auši, kihp_, _मछुआ, 
   {{0xb5fcc730,0x7e6c0e02,0x38b41511,0xa2f4025d}},	//   _buši, _duap, kår_, _ממנה_, 
   {{0xe1640502,0x614086a1,0x1d04c731,0x59dc00e1}},	//   _عضوی, _пеша, пери_, _नफ़र, 
   {{0x7768021a,0x7e6c0093,0x83fc01a6,0x6ab4032e}},	//   _ngex, _fuap, _puđi, ttyf, 
   {{0x7640010e,0xca6400c7,0x00000000,0x00000000}},	// [10660] _okly, деақ, --, --, 
   {{0xa3e00d0d,0xaa445882,0x6ab4c732,0x32040afa}},	//   _फोन_, чезл, rtyf, nkly_, 
   {{0x38b438aa,0xb5fc07f5,0x5df80375,0x629c00b8}},	//   går_, _guši, _הפינ, _āpom, 
   {{0x83fc08ad,0x7640010b,0xd7f40408,0xab28030d}},	//   _tuđi, _akly, зуш_, _гома_, 
   {{0xa3e80c93,0xc5f8c733,0x45d400d8,0x00000000}},	//   मास_, оға_, долс, --, 
   {{0x2814c734,0x38b403cd,0x7768045a,0x00000000}},	//   _کورس, bår_, _egex, --, 
   {{0xdb0cc735,0xe8e80b7e,0x00000000,0x00000000}},	//   _accè, _умвд_, --, --, 
   {{0x3204037e,0x95800032,0xb3a84283,0x00000000}},	//   ekly_, _үлте, _şırı, --, 
   {{0x48f4012c,0x00000000,0x00000000,0x00000000}},	//   ंहको_, --, --, --, 
   {{0x7e6cc736,0x6fa8547d,0xa3e800dc,0xe62800ec}},	//   _ruap, _काउं, माह_, _اثرن_, 
   {{0x7e6cc737,0x40341d16,0xb86401d3,0xc4c4009f}},	//   _suap, денс, _راہو, _آڪتو, 
   {{0xe4582607,0x7e6c04c9,0x44dc00df,0xdef801c6}},	//   _уже_, _puap, _iĉ_, быг_, 
   {{0x7e6c16b8,0x6440c738,0xe2d801ed,0xc694010f}},	//   _quap, _ikoi, _دباؤ_, ואָ_, 
   {{0x9c8001f1,0x44dc01e4,0x3204c739,0x8eb40131}},	//   účov, _kĉ_, ckly_, رەپت, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7e6cc73a,0xa3e001ad,0x38b4007c,0x00000000}},	//   _tuap, _फोम_, vår_, --, 
   {{0x8f9c0302,0x00000000,0x00000000,0x00000000}},	// [10670] _היחי, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x64400810,0x3eb80e78,0x4e78c73b,0x00000000}},	//   _okoi, ltst_, _وحید_, --, 
   {{0x38b400b5,0x6440090c,0x76400006,0x3eb80d27}},	//   rår_, _nkoi, _skly, otst_, 
   {{0x7c2cc73c,0x32040209,0x44dc0115,0xb4d400dc}},	//   mnar, ykly_, _aĉ_, िट्_, 
   {{0xb9c486bf,0x7c2cc73d,0x6440c73e,0x38b401e6}},	//   _تقسي, lnar, _akoi, pår_, 
   {{0xd7f80276,0xf8d0982f,0x76400139,0x00000000}},	//   _луа_, _सनिय, _vkly, --, 
   {{0xdb0cc73f,0x7c2cc740,0xb5fc0153,0xb80800e3}},	//   _accé, nnar, _nušv, _بيرم_, 
   {{0x44dc04ac,0x7c2cc741,0x35b43eae,0x00000000}},	//   _eĉ_, inar, _обар, --, 
   {{0xa5604d2d,0x644001c0,0x7c2cc742,0xb5fc36dd}},	//   رگەن, _ekoi, hnar, _aušv, 
   {{0x7c2cc743,0x3204c744,0x850401ec,0x33b4005b}},	//   knar, rkly_, _كوكن, _жёлт, 
   {{0x78a005ac,0x3eb803b2,0x00000000,0x00000000}},	//   _ålvu, ftst_, --, --, 
   {{0xa3e80da3,0x7c2c0fb7,0xe28cc745,0x7d000158}},	//   मार_, dnar, _ша_, ølsn, 
   {{0x7c2cc746,0xace8c747,0x851c000d,0x00000000}},	//   enar, омга_, _भेँट_, --, 
   {{0x3eb80460,0x9d402a30,0x7c2c008c,0x9e6007fa}},	//   atst_, верд, fnar, тврд, 
   {{0x386c00d7,0xea8800d8,0xa0a00117,0x00000000}},	//   _čerp_, жбал_, _раъд, --, 
   {{0x7c280122,0xc06c0092,0x0aa801ec,0x00000000}},	// [10680] čerp, አዴግን_, ябақ_, --, 
   {{0x7c2cc748,0x5f1400c5,0x00000000,0x00000000}},	//   anar, _पेट्_, --, --, 
   {{0x851c0c2e,0x7c2c0427,0x00000000,0x00000000}},	//   _भेंट_, bnar, --, --, 
   {{0x7c2c01e4,0x674401c6,0x00000000,0x00000000}},	//   cnar, мэлз, --, --, 
   {{0xb864c749,0x00000000,0x00000000,0x00000000}},	//   رامو, --, --, --, 
   {{0xa5280003,0x64400156,0x6e2c003e,0xb3a80139}},	//   _སྨུག_, _skoi, nnbb, _şıpı, 
   {{0xa3e83806,0x281402dd,0x55e0041b,0xe5c80150}},	//   माल_, _قوسس, тојб, _ﻓﺄﻜﺜ, 
   {{0xe7380517,0xd4e000b1,0x3eb803b2,0x00000000}},	//   _деб_, тюши, ytst_, --, 
   {{0x9ad001f2,0xc33000f7,0x00000000,0x00000000}},	//   tịim, دەش_, --, --, 
   {{0xf77001d9,0xb5fc0153,0xc1b8009d,0x759c0240}},	//   _لاے_, _sušv, члох_, ገበርዎ_, 
   {{0xa3b40c2e,0x65780857,0x00000000,0x00000000}},	//   _जाप_, _ifth, --, --, 
   {{0xb5fcc74a,0x3eb8324c,0x644001f4,0x00000000}},	//   _dušu, ttst_, _ukoi, --, 
   {{0x7c2cc74b,0x44b00220,0xdef801c0,0xd4c000cf}},	//   vnar, _рұқс, цын_, _зөөк, 
   {{0x7c2c010a,0xb8e0025c,0x7d000627,0x00000000}},	//   wnar, _ཁྱ_, ølso, --, 
   {{0x7c2cc74c,0x44240332,0x3218036e,0xa0201b99}},	//   tnar, oim_, ësye_, ööss, 
   {{0x4424228f,0x7c2cc74d,0xb5fc01ef,0xfe7000f2}},	//   nim_, unar, _hušt, _مگس_, 
   {{0x7c2cc74e,0xa3b419e5,0xcd04012c,0x3950003e}},	// [10690] rnar, _जान_, vněž_, _szzs_, 
   {{0x7c2cc74f,0xa3e85b82,0xc1780064,0x00000000}},	//   snar, माँ_, ncė_, --, 
   {{0x44242b92,0x7c2ca7ff,0x1abc0154,0x00000000}},	//   kim_, pnar, উটো, --, 
   {{0x44241326,0x657802d0,0xb5fcc750,0xd9cc0154}},	//   jim_, _afth, _lušt, রাইম, 
   {{0x7bccc751,0x61e8127b,0xb6a4c752,0x00000000}},	//   meau, _onfl, хилл, --, 
   {{0xb5fc01a6,0x44244230,0x00000000,0x00000000}},	//   _nušt, eim_, --, --, 
   {{0x4424c753,0xa3e8bc82,0xb4e84196,0x00000000}},	//   fim_, मां_, ममे_, --, 
   {{0x61e8c754,0x7bccc755,0x36d4587f,0x657803ac}},	//   _anfl, neau, _побр, _efth, 
   {{0x63a4c756,0x6ec4013f,0xb5fcc757,0xd5b8009d}},	//   ókna, _kɔbe, _bušt, _мсж_, 
   {{0x4424c758,0x7bcc0798,0xb5fc00ef,0x00000000}},	//   aim_, heau, _pušu, --, 
   {{0x4424c759,0x0574113e,0x7d0005ac,0x7bcc000d}},	//   bim_, _شالد, ølsl, keau, 
   {{0x61e875b6,0xa3b42a05,0xa528025c,0xa3e800dc}},	//   _enfl, _जाय_, _སྨིག_, माः_, 
   {{0x7bccc75a,0xb8e00135,0x00000000,0x00000000}},	//   deau, _ཁཱ_, --, --, 
   {{0xb5fcc75b,0x2d9cc75c,0x02c401e0,0x6df40116}},	//   _gušt, ûte_, _ришү, ركزا, 
   {{0x7bccc75d,0xa3b4230e,0x6e2c00b5,0x00000000}},	//   feau, _जाम_, rnbb, --, 
   {{0x7bcc020c,0x6b6412b9,0xe68400a2,0x00000000}},	//   geau, екба, _özçü, --, 
   {{0x61e80b21,0x00000000,0x00000000,0x00000000}},	// [106a0] _ynfl, --, --, --, 
   {{0x20440023,0xed58009b,0x00000000,0x00000000}},	//   _ማህሰይ, _ноп_, --, --, 
   {{0x4424c75e,0x7bccc75f,0xb9b40395,0x6f04010e}},	//   yim_, beau, ъстъ, lykc, 
   {{0x4424c760,0x7bcc0129,0xfaf000f1,0x7d002bf2}},	//   xim_, ceau, دثې_, älse, 
   {{0x44241028,0xa3b410f7,0x9d5001d5,0x0b4400c7}},	//   vim_, _जाब_, _لنیت, _рҽан, 
   {{0x4424c761,0x6b94c762,0x00000000,0x00000000}},	//   wim_, layg, --, --, 
   {{0x4424c763,0xb5fc02fb,0x26143c71,0x00000000}},	//   tim_, _rušt, भोगी_, --, 
   {{0xb5fc2aef,0xd46415ed,0x81bc005f,0x00000000}},	//   _sušt, није_, giēn, --, 
   {{0x4424c764,0xb5fc04b9,0x2a24001f,0xe618023a}},	//   rim_, _pušt, _ተከታዮ, _еда_, 
   {{0x4424c765,0x6b94c766,0x7bcc00b5,0x657802d0}},	//   sim_, hayg, zeau, _ufth, 
   {{0x4424c767,0x2a68c768,0x6b94c769,0x7bcc0165}},	//   pim_, _mibb_, kayg, yeau, 
   {{0x4424016d,0x35c40124,0xe4580137,0x7d0000cc}},	//   qim_, _зҳәо_, _эже_, ølsm, 
   {{0x7bccc76a,0x6b94c76b,0x6d58c76c,0x93f80375}},	//   veau, dayg, ýtan, _מלאי, 
   {{0x61e815ac,0x81bc00e2,0x91e00063,0xa3b40073}},	//   _unfl, gnēt, _боље, _जाड_, 
   {{0x7bccc76d,0xf1b400c7,0x00000000,0x00000000}},	//   teau, _рӡы_, --, --, 
   {{0x6b94c76e,0x99d41fb8,0x00000000,0x00000000}},	//   gayg, کترا, --, --, 
   {{0xc684ab88,0x7bccc76f,0xb5fc0b4b,0x23c0c770}},	// [106b0] _دې_, reau, _mušr, व्यद, 
   {{0x7bccc771,0x49d812a2,0x00000000,0x00000000}},	//   seau, ндую_, --, --, 
   {{0x6b9401d9,0x391404d3,0x7bccc772,0x2d9000d1}},	//   bayg, خواز, peau, _ﺑﯘﻧﻰ_, 
   {{0x6ec4016b,0x2008012c,0x386801e6,0x6b940067}},	//   _wɔbe, nkci_, öar_, cayg, 
   {{0x09b80183,0xb4e80882,0xa3e82c30,0xd6c08dff}},	//   ীয়া, मम्_, माई_, امتی, 
   {{0x2a68c773,0xb5fc0024,0x06080006,0x00000000}},	//   _gibb_, _aušr, ннік_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd7600014,0x2a680175,0x73e403fb,0xa3b40073}},	//   _منزی, _zibb_, тоиз, _जाण_, 
   {{0xd24000d1,0x64980137,0x95c804b4,0x00000000}},	//   лмиқ, птөр_, _нужа_, --, 
   {{0x85b8c774,0x30743756,0x59b000dc,0x00000000}},	//   _плус_, кумс, ुभिर, --, 
   {{0x6b940009,0x00000000,0x00000000,0x00000000}},	//   yayg, --, --, --, 
   {{0xdb0c003a,0x6b94058a,0x00000000,0x00000000}},	//   _accí, xayg, --, --, 
   {{0xa3b4c775,0x6b94035b,0xc30402f2,0xc0ec0092}},	//   _जात_, vayg, _مبوو, _ኅይል_, 
   {{0xed58352d,0x71a40022,0x6b949108,0x6f040210}},	//   дог_, _ракз, wayg, rykc, 
   {{0x6b94a17f,0x00000000,0x00000000,0x00000000}},	//   tayg, --, --, --, 
   {{0x7ae8098d,0x2ee401c0,0x2a6801ab,0xa3e80d0d}},	//   _šeta, _ажиг, _sibb_, माए_, 
   {{0xee38c776,0xe9d82a30,0xab64c777,0xaa4406ed}},	// [106c0] _они_, мка_, твал, веал, 
   {{0x5ac43461,0x7d000ade,0x6b9401d5,0xdee0030d}},	//   ълум_, älsc, sayg, _тоьи, 
   {{0x6b94c778,0x20100153,0x00000000,0x00000000}},	//   payg, šnių_, --, --, 
   {{0x09d802a6,0xe728013e,0x98a057c6,0x6b94058a}},	//   সাধা, моед_, рице, qayg, 
   {{0x2a68c779,0x00000000,0x00000000,0x00000000}},	//   _tibb_, --, --, --, 
   {{0xb68400d1,0xa9a401c6,0xd704011c,0x00000000}},	//   اشنى, _шигд, ънче_, --, 
   {{0x6844c77a,0x00000000,0x00000000,0x00000000}},	//   _анва, --, --, --, 
   {{0xb8641ec7,0x69dc05ac,0xa6c800f3,0x00000000}},	//   _ماقو, ldpe, _олба_, --, 
   {{0xa184013d,0x00000000,0x00000000,0x00000000}},	//   кынл, --, --, --, 
   {{0x69dcc77b,0xa3e0166d,0x7d000158,0x9f9c03e0}},	//   ndpe, _फोर_, ølsk, nçöz_, 
   {{0x7f940124,0x6d580497,0x626407d6,0x00000000}},	//   ланх, ýtal, _یاتق, --, 
   {{0x7ca40092,0x00000000,0x00000000,0x00000000}},	//   _ፈጥሯል_, --, --, --, 
   {{0x63a0c77c,0x20080427,0x5270033a,0x00000000}},	//   _idon, rkci_, _кују, --, 
   {{0x6280c77d,0x69dc0d27,0xa3e802c3,0x0dc8c77e}},	//   _itoo, jdpe, माक_, куси_, 
   {{0xbd44027d,0x6270012d,0xcfc000eb,0x00000000}},	//   انزي, _błog, োজন, --, 
   {{0x69dc017a,0x0c84104e,0x00000000,0x00000000}},	//   edpe, рырм, --, --, 
   {{0x3f98c77f,0x3b54c780,0x69dc0d27,0xb16400fb}},	// [106d0] masu_, укар, fdpe, _инәһ, 
   {{0x3f98c781,0x7f4c0944,0x25e0038e,0xb994c782}},	//   lasu_, _iyaq, _टोली_, الاب, 
   {{0x9964c783,0x35a40672,0x00000000,0x00000000}},	//   ттал, ҳалг, --, --, 
   {{0x63a0c784,0x6280c785,0xc7c4c786,0x3878001f}},	//   _ndon, _otoo, исчи, _እነርሱ_, 
   {{0x501c13e2,0x62800070,0x07a402d5,0x35a401c0}},	//   וואו, _ntoo, раін, галг, 
   {{0x6270068f,0x7bdcc787,0x61f80083,0x290c0165}},	//   _młod, _hasu, jjtl, ñkañ_, 
   {{0x7bdcc788,0xb5fc0784,0x09480116,0x7d0005ac}},	//   _kasu, _qušq, _ачти_, ølsh, 
   {{0x799406d6,0xa3e81533,0x63a0c789,0x7bdcc78a}},	//   _hezw, माग_, _cdon, _jasu, 
   {{0x7bdcc78b,0xf268c78c,0x3b080724,0x3f98c78d}},	//   _masu, ниил_, nyaq_, dasu_, 
   {{0x386cc78e,0x80dc02a6,0x7bdcc78f,0x63a0c790}},	//   _hier_, যমন্, _lasu, _edon, 
   {{0x3f980198,0x7f4c0f77,0x6280c791,0xf0e80372}},	//   fasu_, _ayaq, _etoo, رىحى_, 
   {{0x7bdcc792,0x386c0385,0x4374c793,0x7994379d}},	//   _nasu, _jier_, _кушт, _lezw, 
   {{0x7ae8098d,0x386ca62c,0x2d947f7a,0x835401d9}},	//   _šetn, _mier_, лөнө_, _پھٹا, 
   {{0x7994c794,0x63a0c795,0x6e4400f2,0x90b00150}},	//   _nezw, _zdon, انآم, _кәмш, 
   {{0x7f4c0944,0x3f98c796,0x386c01c6,0x63a00393}},	//   _eyaq, basu_, _oier_, _ydon, 
   {{0x7bdcc797,0x386cc798,0x81c804c5,0x3f98c799}},	//   _casu, _nier_, _লোপ_, casu_, 
   {{0x7994c79a,0x7f4c0369,0x7bdcc79b,0x3b080399}},	// [106e0] _bezw, _gyaq, _dasu, gyaq_, 
   {{0x7bdc0c8c,0x5c000150,0x00000000,0x00000000}},	//   _easu, _ۇكپە, --, --, 
   {{0x69dc200c,0xeb98074d,0x7bdcc79c,0x799401f5}},	//   rdpe, _пин_, _fasu, _dezw, 
   {{0xe738c79d,0x7bdcc79e,0x3cf00122,0x6fa40183}},	//   нее_, _gasu, ňová_, গ্ৰে, 
   {{0x386cc79f,0xb5fc0427,0x18a000d1,0x63a0c7a0}},	//   _dier_, _pušp, _қатм, _rdon, 
   {{0x386cc7a1,0x63a0011c,0x3f98c7a2,0xb5fc0784}},	//   _eier_, _sdon, zasu_, _qušp, 
   {{0x386cc7a3,0x7bdcc7a4,0x3f98019b,0xe5b00032}},	//   _fier_, _yasu, yasu_, айҙы, 
   {{0x7994c7a5,0x7bdc0050,0x79504451,0x386c0034}},	//   _zezw, _xasu, _بێما, _gier_, 
   {{0x3f98c7a6,0x7994013e,0x6d5801f1,0xe7380e92}},	//   vasu_, _yezw, ýtaj, _џез_, 
   {{0xa3b4033d,0x3f98c7a7,0x75c40014,0x386c522f}},	//   _जाव_, wasu_, _نغمٕ, _zier_, 
   {{0x7f4c0a2e,0x3f983636,0x62700034,0x61f804ba}},	//   _syaq, tasu_, _słod, rjtl, 
   {{0x63a0c7a8,0x62801418,0x6270033f,0x00000000}},	//   _udon, _ttoo, _płod, --, 
   {{0x7bdcc7a9,0x3f98c7aa,0x6280000d,0x92900064}},	//   _rasu, rasu_, _utoo, _гаіц, 
   {{0x3f98015c,0x2174c7ab,0xd2b402e4,0x9340030d}},	//   sasu_, _судр, _עלות_, _унче, 
   {{0x3f98c7ac,0x799412ba,0x3b080113,0x6270033f}},	//   pasu_, _rezw, wyaq_, _włod, 
   {{0x7bdc44d3,0x79940107,0x6ec4016b,0x3f98c7ad}},	//   _qasu, _sezw, _wɔba, qasu_, 
   {{0x7bdcc7ae,0x7f4c1cdf,0x386cc7af,0x19a80daf}},	// [106f0] _vasu, _uyaq, _rier_, етеп_, 
   {{0x386c10f5,0x7b840131,0xb984c7b0,0x62700210}},	//   _sier_, _ھاجە, ртақ, _kłob, 
   {{0x7bdc033d,0x3b080309,0x9f0000f1,0x636401a9}},	//   _tasu, syaq_, _خوښو, lаnd, 
   {{0x7994c7b1,0x20d81225,0x87b801f0,0x00000000}},	//   _wezw, mšić_, гушт_, --, 
   {{0x386ca8b9,0x3b080309,0x2458036e,0xf7440063}},	//   _vier_, qyaq_, këmb_, јело, 
   {{0x386cc7b2,0x14600588,0xf5041422,0x00000000}},	//   _wier_, әеиҭ, изло, --, 
   {{0xb6040cad,0xf8c80cb4,0x386c3344,0xaa4000d1}},	//   _aláì, _रहिय, _tier_, _بۆلى, 
   {{0x629c0374,0x386c0af9,0xb4b4134e,0x00000000}},	//   _āpor, _uier_, _जमी_, --, 
   {{0xa3b42ba2,0x32340828,0x76b801a9,0x00000000}},	//   _जार_, ихос, _шлар_, --, 
   {{0x20d805ce,0x50a00075,0xb22400cf,0xf8c80073}},	//   kšić_, مەتل, рмол, _रहाय, 
   {{0x04c801f7,0x00000000,0x00000000,0x00000000}},	//   _مولي_, --, --, --, 
   {{0xa4f800c8,0xb14400f1,0x2458036e,0x614000db}},	//   _בלעט, هیږم_, tëme_, تىپە, 
   {{0x32f4013f,0x7d0001e6,0x6364022e,0x00000000}},	//   kɛyɛ_, älsn, gаnd, --, 
   {{0x2458c7b3,0x00000000,0x00000000,0x00000000}},	//   rëme_, --, --, --, 
   {{0xdca007d6,0xeb98030d,0x245800e4,0x00000000}},	//   жаси, кив_, sëme_, --, 
   {{0x1d0406d3,0x245800e4,0x00000000,0x00000000}},	//   шеси_, pëme_, --, --, 
   {{0xa3d411b1,0x6da40e92,0x00000000,0x00000000}},	// [10700] ाजत_, _кипа, --, --, 
   {{0xa9a4c7b4,0xec7800f3,0x5e98011a,0x00000000}},	//   рижд, _ипо_, _שביק, --, 
   {{0x6844c7b5,0x6ec4013f,0xe0e80086,0x09d8015b}},	//   анжа, _kɔbo, _ibòñ_, সালা, 
   {{0xf8a81e95,0xb864bbcc,0xebe4c7b6,0xa6e41d0f}},	//   ادله_, مانو, _томп, ижел, 
   {{0x32f4013b,0x7d0005ac,0x7c20017a,0x00000000}},	//   bɛyɛ_, ølsv, ëlre, --, 
   {{0xe4a4c7b7,0x64a40022,0xe0b40154,0x77900014}},	//   арио, ашиз, _জনসভ, _ہیما, 
   {{0x98a01cc9,0xd1d80023,0x00000000,0x00000000}},	//   _мире, ንናት_, --, --, 
   {{0x14a401f9,0x23b000db,0x00000000,0x00000000}},	//   _गिरण, زۅتس, --, --, 
   {{0x75fc007f,0xd4640063,0x00000000,0x00000000}},	//   _lèzy, шиће_, --, --, 
   {{0x64a468d9,0xa3e8012c,0xd9cc03d4,0x00000000}},	//   _важа, माङ_, ৰাথম, --, 
   {{0xe3b8192a,0xc33001d9,0x62700210,0x00000000}},	//   _абе_, تٕک_, _błoc, --, 
   {{0x20d805a1,0x403498a4,0xc0c40131,0x636401a9}},	//   všić_, семс, _һәми, tаnd, 
   {{0xa1849dc3,0x81c800cc,0x00000000,0x00000000}},	//   _кыйл, _লোণ_, --, --, 
   {{0x528002dd,0xa3b4130b,0x7d000267,0xb3a806be}},	//   _بلوك, _जाँ_, älso, _şıxı, 
   {{0x270c02b5,0xad240014,0x62840115,0x00000000}},	//   _hēnā_, مرٲو, ŭkod, --, 
   {{0xa3b4c7b8,0x20d80841,0xabb40131,0x98a40003}},	//   जलि_, ršić_, йасә, żiċi_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [10710] --, --, --, --, 
   {{0x270c0053,0xd8e457c6,0x6270012d,0x00000000}},	//   _mēnā_, ицеп, _złoc, --, 
   {{0xa3d402ab,0xa3b4878d,0xd7f84f0c,0x270c0171}},	//   ाजा_, जला_, куд_, _lēnā_, 
   {{0x610806be,0x00000000,0x00000000,0x00000000}},	//   məld, --, --, --, 
   {{0x7c2cc7b9,0x00000000,0x00000000,0x00000000}},	//   miar, --, --, --, 
   {{0x4aac515b,0x00000000,0x00000000,0x00000000}},	//   _चितव, --, --, --, 
   {{0xd90c9a12,0x61080213,0x7c2c32e5,0x2d28001f}},	//   _تیا_, nəld, oiar, ደሚኖረ, 
   {{0x7c2c0d90,0xd1d802d3,0x33d402dd,0xd8380e3b}},	//   niar, ንዓት_, сікт, _рэг_, 
   {{0xa3d42aa1,0x37e4070e,0x4e08000d,0x00000000}},	//   ाज़_, _коңг, _सकलै_, --, 
   {{0x7c2cc7ba,0x95c86a24,0x610803b9,0x236003b2}},	//   hiar, _шуба_, kəld, ýkja_, 
   {{0x7c2cc7bb,0x6270033f,0x7d0001e3,0x00000000}},	//   kiar, _płoc, älsl, --, 
   {{0xc50c008f,0x7c2c020c,0xbd8800f1,0x00000000}},	//   _שלאָ, jiar, ینټن_, --, 
   {{0x75fc007f,0x00000000,0x00000000,0x00000000}},	//   _sèzy, --, --, --, 
   {{0x6ec40134,0x62700034,0x00000000,0x00000000}},	//   _wɔbo, _włoc, --, --, 
   {{0x7c2cc7bc,0x6270012d,0x69c861ef,0x2d9001ec}},	//   fiar, _tłoc, स्फी, _ﺑﯘﻋﻰ_, 
   {{0x7c2cc7bd,0x75fc007f,0x6d9002d2,0x013406c2}},	//   giar, _vèzy, fðaþ, _بعهد, 
   {{0x63a4c7be,0x00000000,0x00000000,0x00000000}},	// [10720] ókni, --, --, --, 
   {{0x7c2cc7bf,0xed3401c6,0x2d94c7c0,0x3eb402f0}},	//   aiar, _гэмэ, _урис, ňatý_, 
   {{0x7c2c013b,0x7d00143a,0x245800e4,0xda6c0050}},	//   biar, ølst, hëma_, رُم_, 
   {{0x2d98c7c1,0x6e2cc7c2,0xa3b400af,0x1864c7c3}},	//   _hepe_, libb, _जाइ_, бахи_, 
   {{0xefe8044e,0x6b6400f7,0x2d98c7c4,0x97c00137}},	//   _ቅኑዕ_, _ыкма, _kepe_, سقوو, 
   {{0x6e2c038f,0x2d980588,0x9e78008f,0xd7380124}},	//   nibb, _jepe_, אנספ, ыцхә_, 
   {{0x2d98c7c5,0x291c168c,0x395001f5,0x00000000}},	//   _mepe_, _åta_, _gyzs_, --, 
   {{0x6e2cc7c6,0x270c04fe,0x2d98c7c7,0xdecc0023}},	//   hibb, _pēnā_, _lepe_, _ኤደኪ_, 
   {{0xe7380261,0x6e2cc7c8,0x610800ac,0xe37001ec}},	//   _сеа_, kibb, zəld, олқы, 
   {{0x7c2cc7c9,0x2d98033b,0x6e2cc7ca,0xd6cc1291}},	//   ziar, _nepe_, jibb, _سقم_, 
   {{0xa3b40da8,0xb9f002d3,0x270c0374,0x69c80cf1}},	//   _जाऊ_, _ዓዱ_, _wēnā_, स्यी, 
   {{0xb0a801d9,0x270c0325,0xe298c7cb,0x92b40c58}},	//   _किरग, _tēnā_, _бад_, _চনৰ_, 
   {{0x2d980099,0xb45401d9,0x6e2cc7cc,0xa2b00073}},	//   _bepe_, _بخٕش, fibb, _आमट्, 
   {{0x2d98c7cd,0x6e2c04ba,0x7c2c033f,0x91e0c7ce}},	//   _cepe_, gibb, wiar, _ноче, 
   {{0x7c2c07dd,0x4b380020,0x2d98c7cf,0x272001a9}},	//   tiar, _በመጨረ, _depe_, _bаnk_, 
   {{0x38800953,0x2d9801e1,0xc5f40198,0x7c2c0869}},	//   _nėra_, _eepe_, ɓɓe_, uiar, 
   {{0x7c2cc7d0,0xa3b4367a,0xda64092f,0x2d98c7d1}},	// [10730] riar, _जाई_, مائي, _fepe_, 
   {{0x7c2cc7d2,0xd918c7d3,0x13c002a6,0x9a840853}},	//   siar, лье_, ্যয়, _қумл, 
   {{0x3c58084c,0xcfdc0154,0x75e800e5,0x8c0800eb}},	//   _винэ_, ধারন, nöző, রোইন_, 
   {{0xc78002d3,0x7c2c013c,0x28b80cb4,0x1fa80154}},	//   _ንበይኑ_, qiar, _उमरि, গ্রস, 
   {{0x2d98c7d4,0xb6a4c7d5,0x1fe00154,0x6d586aad}},	//   _yepe_, цилл, যাপস, ýtav, 
   {{0xa3b4c7d6,0x853c02d5,0xd1f000b7,0x366861ac}},	//   _जाउ_, _idėj, ግበት_, шало_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x981401d9,0x6e2c0337,0xd8e40327,0x00000000}},	//   _ابسا, zibb, སའཛི, --, 
   {{0x32d400d4,0x00000000,0x00000000,0x00000000}},	//   іцис, --, --, --, 
   {{0xdb1c180f,0x24580240,0x6e2c0009,0x70c8009b}},	//   deqü, rëma_, xibb, агог_, 
   {{0x2d984a3e,0x1fe00154,0x25ec000d,0x6e2c031c}},	//   _repe_, যানস, _आफती_, vibb, 
   {{0xa3b4534e,0xa2b005ba,0x2d98014c,0x62840030}},	//   _जाए_, _आमच्, _sepe_, íkoc, 
   {{0x2d98c7d7,0x82341973,0x1284179e,0x6e2c0003}},	//   _pepe_, _کرنا, _امتی_, tibb, 
   {{0x7124004b,0x2d98036e,0xfe7000f1,0x25500023}},	//   _ورغل, _qepe_, ېدې_, _ምንባሩ, 
   {{0xac0802e8,0x00000000,0x00000000,0x00000000}},	//   анва_, --, --, --, 
   {{0x6e2cc7d8,0x3eac1aff,0x7f740354,0x00000000}},	//   sibb, šeta_, _нуьц, --, 
   {{0x81dc00bd,0x2d98c7d9,0x7d000158,0x6e2c0327}},	// [10740] ডার_, _tepe_, ølsr, pibb, 
   {{0x2d980421,0x00000000,0x00000000,0x00000000}},	//   _uepe_, --, --, --, 
   {{0x25bc062c,0x28b8013d,0x00000000,0x00000000}},	//   _rctl_, рузэ_, --, --, 
   {{0x6d5cc7da,0x77900066,0x00000000,0x00000000}},	//   _izpa, فیفا, --, --, 
   {{0x66d8c7db,0xe664352b,0xe738016c,0x25bc010a}},	//   рьер_, отко, шед_, _pctl_, 
   {{0xb0a803f3,0x00000000,0x00000000,0x00000000}},	//   _किंग, --, --, --, 
   {{0x69cca1cd,0xa3d405f9,0x6270033f,0x38800153}},	//   _ibbe, ाजल_, _błon, _tėra_, 
   {{0xa6a8c2c9,0x7ae80010,0x2814a706,0xc29801f4}},	//   _ناطق_, _šeti, _بورس, бких_, 
   {{0x69c823c1,0x6270033f,0x48f4012c,0x1fe00154}},	//   स्थी, _dłon, ूहको_, যামস, 
   {{0x27e4c7dc,0x7d000267,0xf4940014,0xa3b4000d}},	//   ldon_, älsk, _کھوت_, _जाक_, 
   {{0x81dc045e,0x26c492b6,0x66180166,0x27e40108}},	//   ডাল_, ltoo_, _iltk, odon_, 
   {{0x26c4c7dd,0x27e4c7de,0x69c8b8d6,0x00000000}},	//   otoo_, ndon_, स्ती, --, 
   {{0x6720a602,0x69ccc7df,0x5340c7e0,0x60d8009f}},	//   nzoj, _obbe, _охша, swtm, 
   {{0x20d80618,0x27e402f6,0x00000000,0x00000000}},	//   _tūi_, hdon_, --, --, 
   {{0x26c4c7e1,0x27e4089c,0xcfd004c5,0x601c0036}},	//   htoo_, kdon_, িয়ন, _rëmf, 
   {{0x27e42f4d,0x69cc982e,0x00000000,0x00000000}},	//   jdon_, _abbe, --, --, 
   {{0x68ecc7e2,0x9b680801,0x6d5c01c0,0x6b84058a}},	// [10750] _arbd, ршва_, _ezpa, _dfkg, 
   {{0x3eb8c7e3,0x27e4014a,0x6720c7e4,0x81bc00de}},	//   must_, edon_, dzoj, ciēt, 
   {{0x3eb8c7e5,0x69cc02c4,0x26c4208d,0x68e00034}},	//   lust_, _dbbe, etoo_, łodn, 
   {{0x69ccc7e6,0x6618c7e7,0x27e4c7e8,0x26c4c7e9}},	//   _ebbe, _altk, gdon_, ftoo_, 
   {{0xd6d82579,0x26c4c7ea,0x3eb800af,0x4f500092}},	//   рте_, gtoo_, nust_, _መንደር, 
   {{0x95c8c7eb,0x62700034,0x27e4c7ec,0xdce40790}},	//   руда_, _słon, adon_, lajı, 
   {{0x1c0c0d54,0xd7f8c7ed,0x3eb800c5,0x26c4c7ee}},	//   _सवाल_, _куа_, hust_, atoo_, 
   {{0x3eb8007d,0x26c4c7ef,0x79842a13,0x1fe00154}},	//   kust_, btoo_, lchw, যাডস, 
   {{0x7984009a,0x26c4003a,0x572000f7,0x00000000}},	//   ochw, ctoo_, _تۉشك, --, 
   {{0x3eb8c7f0,0x2018c7f1,0x6a60000f,0x5eec00bc}},	//   dust_, _alqi_, rôfg, इटन्_, 
   {{0x3374c7f2,0x610800ac,0x79840e78,0x3d04033f}},	//   _егер, vəlc, ichw, रहों_, 
   {{0x54341997,0x3eb801a8,0x35d000af,0xa3d400dc}},	//   _برطر, fust_, _दउड़, ाजः_, 
   {{0xd17401c0,0xb8dc031c,0x2f54c7f3,0x6d5c4579}},	//   _мөнх_, _ཀཀ_, ятос, _szpa, 
   {{0x80a41025,0xb5fc0153,0x8248007b,0x25fc012d}},	//   _किचे, _pušy, _وشوف_, लायी_, 
   {{0xed5862bd,0xd344168d,0x27e4c7f4,0x31e0009e}},	//   сов_, _دیکه_, ydon_, বাদশ, 
   {{0x601c0036,0x3eb8b9de,0x6c34007b,0x78a4072b}},	//   _rëmg, bust_, أفرا, dshv, 
   {{0x3eb8c7f5,0x25fc0456,0x68ec0175,0x26c4002e}},	// [10760] cust_, लामी_, _srbd, xtoo_, 
   {{0x1f60010b,0x79840142,0x6d580162,0x00000000}},	//   _якым, gchw, ýtas, --, 
   {{0xe784b18e,0x69c00562,0x26c40de2,0x81c800fe}},	//   пуло, _लाठी, wtoo_, _লোঁ_, 
   {{0x798465e3,0x27e4030a,0x26c43081,0x18641468}},	//   achw, udon_, ttoo_, пахи_, 
   {{0x27e4c7f6,0x78a40165,0xf1bc090a,0x00000000}},	//   rdon_, ashv, ्भान, --, 
   {{0x26c4c7f7,0x69ccc7f8,0xa96817a0,0x672001e4}},	//   rtoo_, _ubbe, _гига_, rzoj, 
   {{0x26c49c7c,0x27e40522,0xd940020a,0x25fcc7f9}},	//   stoo_, pdon_, _зери, लाबी_, 
   {{0xa3b449fc,0xb93401ec,0x53a000d1,0x00000000}},	//   _जाओ_, _تۋما_, ىمىك, --, 
   {{0x2bcc53b7,0x18646963,0x601c0de2,0xd7040276}},	//   ह्या, _хати_, _jëme, _енте_, 
   {{0x3eb8007d,0x59cc53c3,0x661802d0,0x00000000}},	//   vust_, स्पर, _ultk, --, 
   {{0x3eb86a56,0x601c0200,0x610806be,0x918000db}},	//   wust_, _lëme, fəla, رۇيۇ, 
   {{0x3eb8033d,0x81dc02f5,0x8fa407b5,0x2bcc00dc}},	//   tust_, ডাই_, наџе, ह्मा, 
   {{0x79840368,0x00000000,0x00000000,0x00000000}},	//   ychw, --, --, --, 
   {{0x3eb8c7fa,0x00000000,0x00000000,0x00000000}},	//   rust_, --, --, --, 
   {{0x3eb8007d,0x610806be,0xb22800ae,0x00000000}},	//   sust_, bəla, _بأنك_, --, 
   {{0x3eb85a11,0x25fc09ab,0x69c8278e,0x79840042}},	//   pust_, लाडी_, स्सी, wchw, 
   {{0x3eb8c7fb,0x3a74c7fc,0x3f880b23,0x6d58c7fd}},	// [10770] qust_, длар, _ifau_, ýtar, 
   {{0xdce40365,0x3ea80472,0x9964c7fe,0xdd98337e}},	//   sajı, _ivat_, птел, _уши_, 
   {{0x3ea81125,0x7984c7ff,0x1cb4031c,0x00000000}},	//   _hvat_, rchw, _ཛའི_, --, 
   {{0x798402be,0x62440579,0x464c02d3,0x3ea80158}},	//   schw, rðoy, _ንሃገራ, _kvat_, 
   {{0x601cc800,0x06840220,0x7984015d,0x67f001a9}},	//   _këmb, егін, pchw, rаjа, 
   {{0x7aecc801,0x7bccc802,0x601c00e8,0x00000000}},	//   mvat, lfau, _jëmb, --, 
   {{0xd90cc803,0x7aecc804,0xa50400a7,0x628402f0}},	//   _حیا_, lvat, деща_, íkon, 
   {{0x3ea8426d,0x65780ea0,0x3f889280,0x66780240}},	//   _ovat_, _egth, _nfau_, _ብጃምላ_, 
   {{0x7aecc805,0xf1a400f7,0x661001d3,0x6284010f}},	//   nvat, үрүн, ükkö, ŭkon, 
   {{0x3f880421,0x6364022e,0xb80000cc,0x70840022}},	//   _afau_, mаnl, _্ষিত_, мгоз, 
   {{0x7aec08ad,0x3ea8c806,0x09d8009e,0x75146d29}},	//   hvat, _avat_, সাচা, _تواض, 
   {{0xead00570,0x33180064,0x00000000,0x00000000}},	//   fẹ́_, _міля_, --, --, 
   {{0x7aec047e,0x6270012d,0x4394004e,0x00000000}},	//   jvat, _złom, _чачс, --, 
   {{0x2d9c0b21,0x59cc0b9a,0x7aec4f3c,0x601c0221}},	//   úte_, स्मर, dvat, _rëme, 
   {{0xafe4006c,0x3ea80589,0x7bccc807,0xc0a8c808}},	//   _жойл, _evat_, ffau, _فايل_, 
   {{0x599001fb,0x7c6401d5,0xa098011a,0xead00cad}},	//   _đềnà, فاقل, _ויקט, bẹ́_, 
   {{0x3ea80115,0x00000000,0x00000000,0x00000000}},	// [10780] _gvat_, --, --, --, 
   {{0xed5800c6,0x601c02d3,0x992800aa,0x7bcc0421}},	//   _моп_, _vëme, ښتنې_, afau, 
   {{0x7aec0eda,0x3ea80301,0x18a002e8,0x6cc401d5}},	//   avat, _zvat_, вахм, _ўйма, 
   {{0x6a841751,0xd7f40408,0x601c0200,0x2dd40150}},	//   _олма, душ_, _tëme, _ﺘﻤﻠﻤ, 
   {{0x6b94c809,0x7aec0276,0x6a60000f,0x636401d5}},	//   mbyg, cvat, rôfb, gаnl, 
   {{0x442000e4,0x6270012d,0x00000000,0x00000000}},	//   _ŷi_, _płom, --, --, 
   {{0x601c002e,0x1334001f,0x00000000,0x00000000}},	//   _jëmc, _እስከሚ, --, --, 
   {{0x6b94c80a,0xd4640640,0x73c00032,0x00000000}},	//   nbyg, мије_, гәше, --, 
   {{0x42744301,0xf6b00014,0xd400c80b,0xc2740114}},	//   нгис, _مۅنج, тящи, нлиј, 
   {{0x657802d0,0x6364022e,0xbb900150,0x00000000}},	//   _ugth, sаno, _ﺑﯩﻠﻪ_, --, 
   {{0x7aecbc5c,0x2ef0010e,0x6b940158,0x1fe0009e}},	//   zvat, _aryf_, kbyg, যাসস, 
   {{0x7aecc80c,0x6ab4733a,0x00000000,0x00000000}},	//   yvat, kryf, --, --, 
   {{0x6b94c80d,0x6d500020,0x2ef00368,0x4034013d}},	//   dbyg, _መስፈር, _cryf_, _җепс, 
   {{0xead0110e,0x7aec07d6,0x2ef005e4,0x6ab405e4}},	//   rẹ́_, vvat, _dryf_, dryf, 
   {{0xd12c77a8,0xb274008e,0x00000000,0x00000000}},	//   _рх_, _якшә, --, --, 
   {{0x7aecc80e,0x6b941f53,0x7bcc0421,0xc4c40014}},	//   tvat, gbyg, ufau, _ێے_, 
   {{0x7bcc0086,0x2ef0c80f,0x7aec0393,0x7ae80327}},	// [10790] rfau, _gryf_, uvat, _ġets, 
   {{0x81dc009e,0x69c8202e,0x9e640cd2,0x00000000}},	//   ডাক_, स्ली, _تابن, --, 
   {{0x7aecc810,0x64400241,0x7bcc002f,0x00000000}},	//   svat, _ojoi, pfau, --, 
   {{0xad24c811,0x7aecc812,0x2a680092,0x7d14010e}},	//   _سرپو, pvat, ቲከኞች_, myzs, 
   {{0x59c40abd,0x7d0005ac,0x55c00075,0x62840118}},	//   _लापर, ålsf, валғ, íkol, 
   {{0x644002f6,0x06080006,0x00000000,0x00000000}},	//   _ajoi, мнік_, --, --, 
   {{0x610803e3,0x487400db,0x0b380092,0x00000000}},	//   dəlo, ردۅس, _በመተማ, --, 
   {{0x64400129,0x00000000,0x00000000,0x00000000}},	//   _cjoi, --, --, --, 
   {{0xf6b46e9a,0x95c8c813,0xfd8c0150,0x00000000}},	//   _سماج, _мужа_, _ﺒﺸﺎﻥ_, --, 
   {{0x2f24006a,0x644003ac,0x00000000,0x00000000}},	//   _lêgé_, _ejoi, --, --, 
   {{0x69c0033f,0xafc41183,0x00000000,0x00000000}},	//   _लासी, ىيدى, --, --, 
   {{0x80a0068f,0x59cc1c15,0x3cf800e1,0x70a8001f}},	//   _खबरे, स्तर, _उपजे_, _መደረጉ_, 
   {{0x81d402f5,0x6b9400cc,0x16000037,0x1e8000d4}},	//   হয়_, vbyg, लापर_, ллям, 
   {{0x2ef005e4,0x00000000,0x00000000,0x00000000}},	//   _vryf_, --, --, --, 
   {{0xeb9807d6,0x6b946525,0x9d40c814,0xee380022}},	//   зиб_, tbyg, герд, _ҽни_, 
   {{0xa0a0020a,0x3a300175,0xc32c02dd,0x853c0064}},	//   _саъд, _amzp_, _دەۋ_, _idėt, 
   {{0x7ae80122,0xdd2c012c,0x61080213,0x1b44011b}},	// [107a0] _šetr, _měře, həll, езти_, 
   {{0x692400c7,0x2b9c0051,0x610803b9,0x00000000}},	//   нмза, ắc_, kəll, --, 
   {{0x6b94c815,0xed58c816,0x25fc3f7e,0xfd0039af}},	//   pbyg, _хон_, लासी_, _күрп, 
   {{0xb864004b,0x00000000,0x00000000,0x00000000}},	//   نانو, --, --, --, 
   {{0x601c0694,0x2ca8004e,0x644001f4,0x00000000}},	//   _jëma, lsbd_, _rjoi, --, 
   {{0x85746f04,0xd62400d4,0x00000000,0x00000000}},	//   نگائ, ноче_, --, --, 
   {{0x69dcc817,0x2d8801ab,0xa96801d5,0xe8080108}},	//   mepe, icbe_, _хива_, _енвд_, 
   {{0x66e4c818,0x25fc0574,0x6270012d,0x628401e4}},	//   _поба, लाही_, _tłok, ŭkom, 
   {{0x81c8009e,0x66b00220,0x491800bc,0x00000000}},	//   _লোগ_, _сұлу, पनको_, --, 
   {{0x69dcc819,0x00000000,0x00000000,0x00000000}},	//   nepe, --, --, --, 
   {{0x610800ac,0xf7700050,0x69dc03cd,0x6d580254}},	//   cəll, _ماے_, iepe, ütal, 
   {{0x25fc0073,0x601cc81a,0x93e001d5,0x40345a92}},	//   लावी_, _bëma, _бўшл, темс, 
   {{0xdef8c81b,0x4424c81c,0xe2a8a012,0x00000000}},	//   чын_, mhm_, _راشن_, --, 
   {{0x63a0c81d,0x69dcc81e,0x1278008f,0x0e0800ee}},	//   _heon, jepe, _זאגע, нэси_, 
   {{0x63a0c81f,0x6280020c,0x69dcc820,0x00000000}},	//   _keon, _huoo, depe, --, 
   {{0x61e8c821,0x63a0213f,0x6280c822,0x61080213}},	//   _hafl, _jeon, _kuoo, nəlm, 
   {{0x63a0c823,0x61e8c824,0x69dcc825,0x601c0de2}},	// [107b0] _meon, _kafl, fepe, _gëma, 
   {{0x09dc6d7e,0x69dcc826,0x61e80100,0x3f980135}},	//   _རྒྱ_, gepe, _jafl, lbsu_, 
   {{0x62800270,0x610803b9,0x00000000,0x00000000}},	//   _luoo, kəlm, --, --, 
   {{0x63a0c827,0x610800ac,0x28d000c5,0xfb84030f}},	//   _neon, vəll, _सहरि, _جددی, 
   {{0x44240491,0x69dcc828,0x61e800ca,0x62800093}},	//   dhm_, bepe, _oafl, _nuoo, 
   {{0x69dcc829,0x63a00295,0x61e8c82a,0x3eb80334}},	//   cepe, _aeon, _nafl, irst_, 
   {{0x63a00036,0x3eb80e78,0x2bcc00dc,0x00000000}},	//   _beon, hrst_, ह्वा, --, 
   {{0x33d40220,0x80dc009e,0xb6f40114,0x610803e3}},	//   тікт, যমঞ্, _избј, gəlm, 
   {{0x63a0c82b,0x81bc00b0,0xa2807611,0x7674c82c}},	//   _deon, whēa, لینو, _алаф, 
   {{0x61e807de,0x644c0162,0x00000000,0x00000000}},	//   _cafl, _íbin, --, --, 
   {{0x61e8c82d,0x63a0c82e,0x932400aa,0x25fc0dba}},	//   _dafl, _feon, _ګران, लारी_, 
   {{0x63a0c82f,0x69dcc830,0x61e8035a,0x6d580037}},	//   _geon, zepe, _eafl, ütam, 
   {{0xf1d00184,0x69dcc831,0x69c0012c,0x2414010f}},	//   _көнө, yepe, _लाली, _שחנן_, 
   {{0xc21c0085,0x63a0037e,0x69dc005a,0xdee0033a}},	//   ndɔ́_, _zeon, xepe, јори, 
   {{0x63a07623,0x3eb8c832,0x3f98031c,0x00000000}},	//   _yeon, arst_, bbsu_, --, 
   {{0x1c40c833,0x63a0056a,0x60d404ae,0x69dc009f}},	//   ансм, _xeon, _יוצא_, wepe, 
   {{0x69dcc834,0x6270012d,0x00000000,0x00000000}},	// [107c0] tepe, _słoi, --, --, 
   {{0x61e80050,0xac84005b,0x2458002e,0x69dc0036}},	//   _xafl, _игол, rëmi_, uepe, 
   {{0xeb9801f0,0x00000000,0x00000000,0x00000000}},	//   _оин_, --, --, --, 
   {{0x69dcc835,0xe73801dd,0x7d00143a,0xea90215c}},	//   sepe, мее_, ålse, _نۇرھ, 
   {{0xc5f8c836,0x69dcc837,0x6270068f,0x63a0c838}},	//   нға_, pepe, _głow, _reon, 
   {{0xaa44c839,0x63a0c83a,0x69dc0200,0x9660011c}},	//   _регл, _seon, qepe, акче, 
   {{0x61e8c83b,0x98a0c83c,0x63a0c83d,0x6280037e}},	//   _rafl, _висе, _peon, _suoo, 
   {{0x61e80cfd,0x94200063,0x78000107,0x636401a9}},	//   _safl, имје, _гӯша, lаni, 
   {{0x59cc1b61,0x2688c83e,0xa6c8a012,0x61e80115}},	//   स्वर, _آخري_, _زوال_, _pafl, 
   {{0x610803be,0x63a00789,0x61e87aac,0x44246521}},	//   səlm, _weon, _qafl, shm_, 
   {{0x63a000b0,0x60c80334,0x00000000,0x00000000}},	//   _teon, _qqfm, --, --, 
   {{0x63a000b0,0x6364022e,0x30380014,0x61e80210}},	//   _ueon, hаni, فتُک_, _wafl, 
   {{0x61e8c83f,0x81d4c840,0x3eac0221,0x6364022e}},	//   _tafl, _болх, éet_, kаni, 
   {{0x601c002e,0x6724032e,0x00000000,0x00000000}},	//   _gëmn, _ýkju, --, --, 
   {{0x6270006d,0xc1780153,0x636401a9,0x0ca800db}},	//   _słow, rdės_, dаni, ктти_, 
   {{0xd10c0cb4,0x3eb8110c,0x5fa42e05,0x3cec01e4}},	//   ाहरण_, prst_, _ख़िल, ĉev_, 
   {{0xda6405d4,0xdb0c067c,0x6ec4013f,0x94bc01ad}},	// [107d0] نائي, _accò, _wɔbr, _एम्आ, 
   {{0x200808a4,0xbd8805d9,0x6364022e,0x00000000}},	//   ljci_, _ڪنھن_, gаni, --, 
   {{0x601c1bce,0x00000000,0x00000000,0x00000000}},	//   _jëmo, --, --, --, 
   {{0xc86498c1,0xbd8805d9,0x00000000,0x00000000}},	//   атчи, _تنھن_, --, --, 
   {{0x601cc3b4,0x00000000,0x00000000,0x00000000}},	//   _lëmo, --, --, --, 
   {{0x26340034,0x81bc00b0,0xdbdc0241,0x16001025}},	//   słon_, whēn, _ṣèr, लाधर_, 
   {{0x236401e4,0x26340210,0xc9580024,0xa0480092}},	//   _azoj_, płon_, _аўт_, _ነፃነታ, 
   {{0x5ddc0154,0xe3680055,0x00000000,0x00000000}},	//   মায়ু, _ṭānt, --, --, 
   {{0x69c813f7,0x00000000,0x00000000,0x00000000}},	//   स्की, --, --, --, 
   {{0x6d580037,0xa0200108,0x00000000,0x00000000}},	//   ütak, ööns, --, --, 
   {{0x1acc00bd,0x85b80150,0x7158010b,0x00000000}},	//   রিয়া, _جاقس_, эрис_, --, 
   {{0xad880261,0x8f840131,0x35c8000d,0x00000000}},	//   _maкe, шқил, _राड़, --, 
   {{0xe0cc0014,0xc3040244,0x00000000,0x00000000}},	//   _ہٲو_, _نبوو, --, --, 
   {{0x437401af,0x00000000,0x00000000,0x00000000}},	//   _туєт, --, --, --, 
   {{0x601c0694,0x13d4015b,0x091800cc,0xc0c40023}},	//   _gëmo, _দোয়, _ধেনু_, ኻእለ_, 
   {{0xa92402dd,0xec1400f7,0x00000000,0x00000000}},	//   ңдал, دورد, --, --, 
   {{0xab64c420,0x601c0036,0x6364022e,0x6b640124}},	// [107e0] увал, _zëmo, tаni, укаа, 
   {{0x5f9001ed,0x00000000,0x00000000,0x00000000}},	//   _پلیئ, --, --, --, 
   {{0x610803be,0xe8f805f5,0x00000000,0x00000000}},	//   vəlk, элж_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d5cc841,0x00000000,0x00000000,0x00000000}},	//   _hypa, --, --, --, 
   {{0xa8a4c842,0xe81401f9,0x00000000,0x00000000}},	//   _مصرو, _थकवा_, --, --, 
   {{0x6270012d,0xdecc0b82,0xb86428f4,0x00000000}},	//   _młot, _ኤደን_, _چاقو, --, 
   {{0x6d5cc843,0xb86415f6,0x780001c6,0xaa440117}},	//   _mypa, _ناقو, _мүха, _реҳл, 
   {{0x610803be,0x29189c36,0x00000000,0x00000000}},	//   məli, lypa_, --, --, 
   {{0x610803be,0x6d5c01a9,0xe5d801e1,0x00000000}},	//   ləli, _oypa, _àràá, --, 
   {{0x601c0200,0x6eb000bc,0x00000000,0x00000000}},	//   _qëmo, _जिउँ, --, --, 
   {{0x601c0de2,0x20080399,0x61080213,0x00000000}},	//   _gëml, ujci_, nəli, --, 
   {{0xe31401d9,0xe29403b7,0x29180209,0x6d5cc844}},	//   _حباب, _среќ, hypa_, _aypa, 
   {{0xc0c40209,0x09d40154,0x245800e8,0x5ce400c0}},	//   _кәми, _হোসা, rëmu_, люба, 
   {{0x6d5c003a,0x7f940107,0x291800e4,0x610806be}},	//   _cypa, _кайх, jypa_, kəli, 
   {{0x601c04e6,0x6d5c0240,0x0c8401ec,0x00000000}},	//   _këmm, _dypa, сырм, --, 
   {{0x601c0694,0xc88000ac,0x61080213,0xca48036b}},	// [107f0] _jëmm, əşir_, dəli, گلله_, 
   {{0x7f4c0327,0x5884c845,0x00000000,0x00000000}},	//   _ixaq, гыда, --, --, 
   {{0x99640c17,0x601c226d,0xca4807fc,0x6d5c0200}},	//   утал, _lëmm, دلله_, _gypa, 
   {{0x6270033f,0xb0640037,0x1fe00154,0x610806be}},	//   _złot, mvää, যাকস, gəli, 
   {{0x601c04c4,0xf65000cf,0x35a428fc,0xb06416ca}},	//   _nëmm, يئت_, аалг, lvää, 
   {{0x0f7c010f,0x00000000,0x00000000,0x00000000}},	//   ׂראל, --, --, --, 
   {{0xb064005b,0xbadc01ec,0x610803e3,0x3b0827ac}},	//   nvää, _ﺇﻴﺠﺎ, bəli, lxaq_, 
   {{0xb6c801ed,0xb384010b,0x61080213,0x00000000}},	//   _لائے_, шлил, cəli, --, 
   {{0xb224c846,0xd3440edf,0x386c036e,0x00000000}},	//   имил, دیشه_, _iher_, --, 
   {{0xd7c400aa,0x7768014b,0xe1f40124,0x98c000c0}},	//   _جوړه_, _izex, агь_, _švęs_, 
   {{0x386c5dad,0x69c813e0,0x261800dc,0x00000000}},	//   _kher_, स्टी, _भवती_, --, 
   {{0x601c0221,0x16001098,0x6d5c8736,0x00000000}},	//   _fëmm, लावर_, _rypa, --, 
   {{0x6d5cc847,0x601c002e,0x6270012d,0x00000000}},	//   _sypa, _gëmm, _płot, --, 
   {{0x5184c848,0x5f401823,0x610800ac,0x3e3c001f}},	//   _суда, تچىل, zəli, _አቅርቧ, 
   {{0xed589d04,0xe814069f,0x62840232,0x601c04e6}},	//   тов_, _थकला_, íkov, _zëmm, 
   {{0x6d5c031d,0x60cc00d0,0x7d0012e8,0x29180022}},	//   _vypa, žimí, ålsa, vypa_, 
  
   {{0x6270068f,0x6d5c068f,0x610800ac,0x628400df}},	// [10800] _głos, _wypa, vəli, ŭkov, 
   {{0x6d5c03d4,0x3eac003d,0x386c020b,0x6994c849}},	//   _typa, ġett_, _aher_, ррах, 
   {{0x386c062c,0x332c0369,0x6d5c0784,0x61080213}},	//   _bher_, hzex_, _uypa, təli, 
   {{0x386cc84a,0x6fc40027,0x2918248f,0x00000000}},	//   _cher_, वलिं, rypa_, --, 
   {{0x386c1ee5,0x61080213,0x7f4c0327,0xaaa800bc}},	//   _dher_, rəli, _xxaq, _छबिक, 
   {{0x386c0639,0x601c0036,0x96301cd0,0x29180124}},	//   _eher_, _rëmm, оніц, pypa_, 
   {{0xd940c84b,0x77680472,0x758802bf,0x6fc401f9}},	//   _дери, _ezex, усів_, वलां, 
   {{0x386c014f,0x247c063f,0x68e0033f,0x00000000}},	//   _gher_, _ọmba_, łods, --, 
   {{0x26c000e4,0x00000000,0x00000000,0x00000000}},	//   _êko_, --, --, --, 
   {{0x51f4005b,0xb0640108,0xca440150,0x00000000}},	//   анью_, yvää, _ﺘﺼﺏ_, --, 
   {{0x807800cf,0x00000000,0x00000000,0x00000000}},	//   лбос_, --, --, --, 
   {{0x245801c7,0x25fc0d0d,0xc244010b,0x00000000}},	//   rëms_, लाकी_, рнүк, --, 
   {{0x3b080429,0x00000000,0x00000000,0x00000000}},	//   xxaq_, --, --, --, 
   {{0x63540241,0x91e0023a,0x00000000,0x00000000}},	//   _e̟nì, _моче, --, --, 
   {{0x6270068f,0x5ba4c84c,0x9c584028,0x00000000}},	//   _włos, ираз, نجرز_, --, 
   {{0xd0080640,0x853c00c0,0xb06426bb,0x00000000}},	//   _веће_, _neėm, rvää, --, 
   {{0xb06400af,0x7f4c0009,0x00000000,0x00000000}},	// [10810] svää, _uxaq, --, --, 
   {{0xb9842c1d,0x386caaa9,0x00000000,0x00000000}},	//   стақ, _sher_, --, --, 
   {{0x386c06a3,0x4f5842c2,0x4ddc011a,0x00000000}},	//   _pher_, _مجید_, _יחזו, --, 
   {{0xc794a1a1,0x00000000,0x00000000,0x00000000}},	//   оршы, --, --, --, 
   {{0x6ea82aa1,0x38bc0162,0x61080213,0x6d58000d}},	//   जीपु, _bárð_, məlu, ütav, 
   {{0xe5a0c84d,0x25fc00bc,0x386c0254,0x58b806c2}},	//   пиши, लागी_, _wher_, _لارج_, 
   {{0x386cc84e,0xb4e00490,0x81ac0154,0x798800a2}},	//   _ther_, धबे_, গলা_, _şeww, 
   {{0x386c01ef,0x00000000,0x00000000,0x00000000}},	//   _uher_, --, --, --, 
   {{0x13a400f1,0x00000000,0x00000000,0x00000000}},	//   هنګی_, --, --, --, 
   {{0xb224c84f,0x00000000,0x00000000,0x00000000}},	//   смол, --, --, --, 
   {{0x601c002e,0x1b18015b,0x00000000,0x00000000}},	//   _gëmk, _নেমে_, --, --, 
   {{0xc24400cf,0x00000000,0x00000000,0x00000000}},	//   йнөк, --, --, --, 
   {{0x045400f7,0x7d000158,0x69d8010e,0x59d409ab}},	//   _بئلد, ålsn, _öteg, डभार, 
   {{0xb63800b5,0x6364022e,0x00000000,0x00000000}},	//   _ｅｍ_, rаnt, --, --, 
   {{0x8234c850,0xdca01f71,0x50d82c2e,0x6140010b}},	//   _برنا, заси, _बहिष, _неша, 
   {{0xeb342e51,0xac08c851,0xc5f403f9,0x6094c852}},	//   مىزد, ынба_, ɓɓu_, _انيس_, 
   {{0x6270033f,0x1b18015b,0x2bcc000d,0x00000000}},	// [10820] _kłop, _নেবে_, ह्गा, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x5180001f,0x51a40092,0x00000000,0x00000000}},	//   _ከአንተ_, _ለአንተ_, --, --, 
   {{0xa2a809bb,0xe9d800cf,0x00000000,0x00000000}},	//   _फ़िल्, _өкм_, --, --, 
   {{0x2004013f,0x00000000,0x00000000,0x00000000}},	//   _ɑni_, --, --, --, 
   {{0x1dd80b9a,0x00000000,0x00000000,0x00000000}},	//   म्पत, --, --, --, 
   {{0x74a8b1d5,0xd49402d5,0x61080213,0x00000000}},	//   асың_, бры_, nəlt, --, 
   {{0x68ec0009,0x64a401a9,0x00000000,0x00000000}},	//   _isbd, _ҳажа, --, --, 
   {{0x59ccc853,0xb9f0044e,0xa1842d55,0xd3740276}},	//   स्कर, _ናቱ_, йынл, йчь_, 
   {{0x27e4c854,0x6204084c,0x69d803e0,0x7e98bb12}},	//   leon_, счиз, _öted, ینجر_, 
   {{0x69cc007f,0xd5ac00ae,0xe568014b,0x00000000}},	//   _mcbe, _سفن_, _сижд_, --, 
   {{0x4420001e,0x6360063f,0x601c0240,0x1dd83c71}},	//   _ôi_, _ọnun, _këmi, म्नत, 
   {{0x26c40076,0x44f80051,0x2c1800fe,0x3d94a8dc}},	//   nuoo_, _hĩ_, নোৱে_, жигр, 
   {{0x27e4c5d5,0x44f8001e,0x25fc01ad,0x7d000217}},	//   heon_, _kĩ_, लाटी_, ålso, 
   {{0xceb400ac,0xb424033f,0x601c0240,0x27e4bb75}},	//   _evə_, łżeń, _lëmi, keon_, 
   {{0x44f801fb,0x69cc6c65,0x00000000,0x00000000}},	//   _mĩ_, _acbe, --, --, 
   {{0x7a3879e4,0xf8c801e1,0x00000000,0x00000000}},	// [10830] апар_, _oléé_, --, --, 
   {{0x44f807dd,0x00000000,0x00000000,0x00000000}},	//   _oĩ_, --, --, --, 
   {{0x4e9403e6,0x27e40115,0x00000000,0x00000000}},	//   _وشیر, feon_, --, --, 
   {{0x27e4c855,0x601c0200,0x80c087ea,0x00000000}},	//   geon_, _bëmi, _विने, --, 
   {{0x7c2cc856,0x7bdc0a55,0x6a6005da,0x00000000}},	//   mhar, _ibsu, zôfi, --, 
   {{0x7afc14dc,0x601c0240,0x44f80051,0x00000000}},	//   _irst, _dëmi, _bĩ_, --, 
   {{0x7c2c009f,0x1dd800dc,0x27e401e4,0x25fc4da4}},	//   ohar, म्यत, beon_, लाजी_, 
   {{0x7c2cc857,0x7afc1050,0x601c069c,0x27e4c858}},	//   nhar, _krst, _fëmi, ceon_, 
   {{0x7c2cc859,0x61080213,0x245801c7,0x00000000}},	//   ihar, zəlt, rëmp_, --, 
   {{0xc0cc001f,0x1dd86c52,0x86c4009f,0x7e7c0150}},	//   ባለሁ_, म्मत, _ريمن, _ﺤﺎﻻﺕ_, 
   {{0x7c2cc85a,0x7bdcc85b,0x7168039b,0x62840162}},	//   khar, _obsu, ранг_, íkor, 
   {{0x7c2c01af,0x7afcc85c,0x00000000,0x00000000}},	//   jhar, _orst, --, --, 
   {{0x7c2cc85d,0x25fc0490,0x628401e4,0xc1ac0220}},	//   dhar, लाची_, ŭkor, _ﺳﯘﺭﺍ, 
   {{0x7c2c00b0,0x27e40115,0x88e000cc,0x41d800cd}},	//   ehar, zeon_, ণিতক, ब्दस, 
   {{0x27e4c85e,0x7afcc85f,0x7c2cc860,0x7bdc01f4}},	//   yeon_, _arst, fhar, _bbsu, 
   {{0x7c2cc861,0xeb98c862,0x799401f5,0x7afcc863}},	//   ghar, риа_, _afzw, _brst, 
   {{0x69cc0332,0x00000000,0x00000000,0x00000000}},	// [10840] _pcbe, --, --, --, 
   {{0x7c2cc864,0x7afcac72,0xa96800c7,0xda6c01d9}},	//   ahar, _drst, аиза_, پُم_, 
   {{0x7afcc865,0x27e4c866,0x7c2c3e7c,0x28e8c867}},	//   _erst, teon_, bhar, рдеп_, 
   {{0x86581aac,0x7c2cc868,0x60d8008f,0x44f80208}},	//   _elɔ́, char, יקענ, _rĩ_, 
   {{0x44f807ae,0x27e4c869,0x80c02c2e,0x8de80327}},	//   _sĩ_, reon_, _विभे, _སྲོལ, 
   {{0x26c400b5,0x1ef8010f,0xe4e8007b,0x00000000}},	//   ruoo_, ילנע, لعبه_, --, 
   {{0x98940075,0x49a402dd,0x27e401e4,0x00000000}},	//   _мутә, _мыңғ, peon_, --, 
   {{0x44f8001e,0x94700338,0x00000000,0x00000000}},	//   _vĩ_, وديا, --, --, 
   {{0xe7381d0f,0x93740395,0x00000000,0x00000000}},	//   _теа_, обът_, --, --, 
   {{0x44f80022,0x00000000,0x00000000,0x00000000}},	//   _tĩ_, --, --, --, 
   {{0x7c2cc86a,0x59cc25fe,0x00000000,0x00000000}},	//   yhar, स्टर, --, --, 
   {{0xe3b06f43,0x7c2c036e,0x7d00007c,0x630400ae}},	//   _آرا_, xhar, ålsm, _ووال, 
   {{0x7c2c05b8,0x442406d1,0xded40023,0x00000000}},	//   vhar, mkm_, ይቶኡ_, --, 
   {{0x7c2c0053,0x1600012c,0x11d000db,0x00000000}},	//   whar, लाएर_, _قتىد, --, 
   {{0x7c2cc86b,0x7afcc86c,0x5634008f,0xe2c4009f}},	//   thar, _srst, קאלע_, _اوڙو_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7c2cc86d,0xdce807c4,0x5f740131,0x60940451}},	// [10850] rhar, ınız, _باغر, _انڊس_, 
   {{0x7c2cc86e,0x3ea801c7,0x0a6801c6,0xf8b000e5}},	//   shar, _iwat_, орхи_, ٹکس_, 
   {{0x7c2cc86f,0x3f8800fb,0xf8b0c870,0x3ea80b21}},	//   phar, _kgau_, عکس_, _hwat_, 
   {{0x7c2c0227,0x7afc5a54,0x3ea8c871,0xbb4c00b5}},	//   qhar, _trst, _kwat_, _comツ_, 
   {{0x3ea80649,0xb6a4c872,0x442400b5,0x7c3c02d0}},	//   _jwat_, чилл, dkm_, _imsr, 
   {{0x7aecc873,0x3ea8c874,0x7bccc875,0x00000000}},	//   mwat, _mwat_, lgau, --, 
   {{0x7aecc876,0x3ea813bb,0xd90c2633,0x85780801}},	//   lwat, _lwat_, _جیا_, осът_, 
   {{0x7bccc877,0x3f88c878,0x23b00075,0x7aec01c8}},	//   ngau, _ngau_, ىمىس, owat, 
   {{0x7aecc879,0x787003d4,0x601c0de2,0xabdc0150}},	//   nwat, gåve, _jëmu, _ﺇﺤﻴﺎ, 
   {{0x3f880421,0x7aec771d,0x3aec0306,0x00000000}},	//   _agau_, iwat, _mžp_, --, 
   {{0x7aec5bae,0x7bcc00fb,0x3ea8c87a,0x0ef45325}},	//   hwat, kgau, _awat_, इट्स_, 
   {{0x7aecc87b,0x3ea8c87c,0x16000d0a,0xa4f400d9}},	//   kwat, _bwat_, लाकर_, _מצעד_, 
   {{0xb8fc0135,0xb15c01ec,0x00000000,0x00000000}},	//   _ཡཱ_, _өндi, --, --, 
   {{0x7aecc87d,0x3ea80699,0x3f88068c,0xe80005f9}},	//   dwat, _dwat_, _egau_, _रोना_, 
   {{0x7bcc010a,0x2dd40150,0x00000000,0x00000000}},	//   fgau, _ﺘﺤﻜﻤ, --, --, 
   {{0x7bccc87e,0x7aecc87f,0x6fd800fe,0x00000000}},	//   ggau, fwat, _বোৰে, --, 
   {{0x7aecc880,0x6e444303,0x6fa0c881,0x35740092}},	// [10860] gwat, _неиз, _क्यू, ችሉበት_, 
   {{0x7bcc0a73,0x1ef8008f,0x44240175,0x00000000}},	//   agau, _פליע, zkm_, --, 
   {{0xd9401a92,0xa3ac30a4,0x7aec00b0,0x7bcc0098}},	//   нефи, करम_, awat, bgau, 
   {{0x7aec0d5a,0x00000000,0x00000000,0x00000000}},	//   bwat, --, --, --, 
   {{0x7aec4b26,0x601c1bce,0x156400d1,0x00000000}},	//   cwat, _gëmu, ﻴﯩﺘﯩ, --, 
   {{0x97c00046,0x160005f9,0x44240ac5,0x36880220}},	//   _үйре, लागर_, wkm_, ісін_, 
   {{0x80c00f4c,0x6ab40af9,0xd49400c0,0x35e0012d}},	//   _विधे, lsyf, пры_, फ़ज़, 
   {{0xc2981049,0xdc98011a,0x00000000,0x00000000}},	//   оких_, זיקל, --, --, 
   {{0x6ab4c882,0x26c00022,0x939016ac,0x65c401c6}},	//   nsyf, _íko_, رجيا, _нбаа, 
   {{0x80c022e3,0x7bccc883,0x6ab40142,0x44240254}},	//   _विदे, zgau, isyf, skm_, 
   {{0x3ea81590,0x00000000,0x00000000,0x00000000}},	//   _swat_, --, --, --, 
   {{0x7aecc884,0x66189ea3,0x6e3c127b,0x6ab4017a}},	//   ywat, _hotk, _ampb, ksyf, 
   {{0x6618c885,0x6a60002d,0x81bc00b0,0x672000b5}},	//   _kotk, nôfs, whēu, nyoj, 
   {{0x66180664,0x7aec02ea,0x6e3c010a,0xf2c40220}},	//   _jotk, vwat, _cmpb, _ісін, 
   {{0x601c044e,0x7aecc886,0x2484c887,0x7bccc888}},	//   _sëmu, wwat, _kiom_, tgau, 
   {{0x3f8807c5,0x8c640220,0x7bcc0024,0x6720037e}},	//   _ugau_, етуд, ugau, kyoj, 
   {{0x601c02d3,0x7aec0a73,0xabb40588,0x6618005b}},	// [10870] _dëmt, uwat, ьатә, _ootk, 
   {{0x24840491,0x6618008c,0x20180240,0xb1300432}},	//   _liom_, _notk, _hoqi_, _öýüm, 
   {{0x7aecc889,0x98c43633,0x7bcc00c0,0x00000000}},	//   swat, ясал, pgau, --, 
   {{0x3dcc02a8,0x248400e8,0x5fbc9a28,0x977000d1}},	//   ɗewa_, _niom_, ्लिल, нтлә, 
   {{0xd6d8c88a,0x23640218,0x7aec02d1,0x00000000}},	//   сте_, _nyoj_, qwat, --, 
   {{0x24840649,0x20180286,0x992801ca,0x95c8c88b}},	//   _aiom_, _loqi_, _люба_, суда_, 
   {{0x2484013f,0x601c00e8,0x66181718,0xb81000c7}},	//   _biom_, _jëms, _dotk, _иҧжә, 
   {{0xb4ac0037,0xa01801e3,0xe3b000e5,0x00000000}},	//   _कबी_, lmöf, پرٹ_, --, 
   {{0x6618c88c,0xe1f02c10,0x254c06be,0x601c036e}},	//   _fotk, چسپ_, _cәlb_, _lëms, 
   {{0x1b3c00b7,0x45d413d6,0x31247a6f,0x057401e2}},	//   _ኮንትራ, _поус, ддог, _ړاند, 
   {{0x24840395,0xb7bc0276,0x2018022e,0x068c00d1}},	//   _fiom_, _alţi, _boqi_, ﮕﯩﻠﯩ, 
   {{0xa3ac072a,0x81bc02b5,0x00000000,0x00000000}},	//   करण_, whēt, --, --, 
   {{0x1cd00156,0x2018002e,0x9f5c01a8,0x26340210}},	//   _ེདཔ_, _doqi_, ðuð_, płot_, 
   {{0x24840793,0x8ed003d4,0x644c0162,0x1e800006}},	//   _ziom_, িবলগ, _íbir, клям, 
   {{0x3dc400d2,0xfe70004b,0xded40023,0x00000000}},	//   ólwa_, ږدې_, ይቶኻ_, --, 
   {{0x601c0240,0x6ab417b5,0x9f5c0022,0xab28004e}},	//   _dëms, tsyf, ñuã_, ооба_, 
   {{0xdd8c066d,0x6a8405f5,0x00000000,0x00000000}},	// [10880] اوہ_, длаа, --, --, 
   {{0x672000ec,0x6ab475cc,0x6e3c035a,0x09d400fe}},	//   vyoj, rsyf, _umpb, _হোজা, 
   {{0x6ab4007c,0x601c036e,0xfaf80171,0x00000000}},	//   ssyf, _tëmt, _šūt_, --, 
   {{0x320823db,0x6618c88d,0x80c02d3b,0x98a01d4a}},	//   _ɗaya_, _sotk, _विसे, тице, 
   {{0x2484c88e,0xdce80115,0x00000000,0x00000000}},	//   _riom_, _ĉiĉe, --, --, 
   {{0x248403cb,0x658400cf,0x00000000,0x00000000}},	//   _siom_, мыйз, --, --, 
   {{0x4394c88f,0x6a60002d,0x00000000,0x00000000}},	//   найс, sôfs, --, --, 
   {{0x69dc257c,0x99300c4f,0x00000000,0x00000000}},	//   lfpe, _شفقت, --, --, 
   {{0x661800fd,0x2018002e,0xa01801a8,0x69dc01f5}},	//   _totk, _roqi_, lmög, ofpe, 
   {{0x2018c890,0xb7240150,0xe800012d,0x26c403b9}},	//   _soqi_, _سۋىم_, _रोता_, mroo_, 
   {{0x2484c887,0x00e401d5,0xa018002f,0x00000000}},	//   _tiom_, رتدی, nmög, --, 
   {{0xdb0c00d8,0x2018022e,0x00000000,0x00000000}},	//   _decê, _qoqi_, --, --, 
   {{0x6ed0013b,0xa018002f,0x51f0072d,0x00000000}},	//   _yɛbɛ, hmög, رسیر, --, 
   {{0xe24427b4,0x00000000,0x00000000,0x00000000}},	//   _تخصي, --, --, --, 
   {{0x2018002e,0x0cd400d4,0x91e000f3,0x00000000}},	//   _toqi_, корю, _роје, --, 
   {{0x26c4208d,0x8bc4c891,0x69dc01a4,0x3448010a}},	//   kroo_, ксуд, efpe, _ячĕн_, 
   {{0x3a74c892,0x0c84c893,0x7c440092,0x69dc002f}},	// [10890] елар, тырм, _ከእርሱ, ffpe, 
   {{0x61f812ed,0x4a5450d3,0x26c4036e,0x99840118}},	//   ndtl, вкус, droo_, ónů_, 
   {{0xa3ac033d,0x31c40075,0x9964036b,0x26c40449}},	//   करा_, ﯩﺪﯨﻜ, фтал, eroo_, 
   {{0x26c40036,0x3eb80036,0x601c036e,0x69d8010e}},	//   froo_, osst_, _zëmr, _öten, 
   {{0x6b980375,0x78700267,0x19f00124,0x26c4007f}},	//   _משרד, gåva, _иҟар, groo_, 
   {{0x3eb80d16,0x249c00a2,0x60d80083,0x7d0000cc}},	//   isst_, _bttm_, kttm, ålsw, 
   {{0x26c40a63,0x80c00fe6,0x1fc400cc,0x61f80327}},	//   aroo_, _विषे, ষ্যস, ddtl, 
   {{0xb464c894,0xe3e8025c,0xc7c40276,0xd6c0004b}},	//   رگاه, _རྒྱང, _асфи, _لمری, 
   {{0xa3dc1d34,0xf558297d,0x00000000,0x00000000}},	//   द्ध_, _کلاب_, --, --, 
   {{0x80c02ce6,0x3eb802bf,0x65780227,0x00000000}},	//   _विशे, dsst_, ñchä, --, 
   {{0x3eb80ade,0x6eb00243,0xbacc0220,0x00000000}},	//   esst_, _अबहु, _ﯗﻗﺴﺎ, --, 
   {{0x2d9801e4,0xa3dcb9c0,0xb33801c6,0x80c00b8f}},	//   _sfpe_, द्द_, _нялх_, _विरे, 
   {{0xc2c8c895,0x932415d6,0x92f00107,0xfbd400cc}},	//   _قبول_, _تران, _рӯйх, হজাত, 
   {{0x32d8033b,0xde8c0150,0xf1dc00cc,0x00000000}},	//   mèy_, _ﻓﻮﺗﻮ_, _ভোৰভ, --, 
   {{0x1d04c896,0x32d80699,0xc0a84072,0x2164048a}},	//   нери_, lèy_, _قايل_, _пиши_, 
   {{0xdb0c020c,0x03b0002b,0xb3ac0154,0x7d000feb}},	//   _kecè, _klīṃ_, _গাঁজ, ælsa, 
   {{0x32d802e2,0x776801e3,0xa9a4011c,0x00000000}},	// [108a0] nèy_, _nyex, еизд, --, 
   {{0xdb0c5051,0x2d9800d8,0xa0180112,0x26c40076}},	//   _mecè, _ufpe_, tmög, vroo_, 
   {{0x77680117,0xeb98c897,0x1cdc0327,0xac08010a}},	//   _ayex, _нин_, _ལཱར_, _енна_, 
   {{0xa018c898,0xdc98008f,0x7640c899,0x32d802e2}},	//   rmög, _מיטל, _amly, kèy_, 
   {{0xc5f8c89a,0x45d4c89b,0xa01803fa,0xdb0c067c}},	//   мға_, волс, smög, _necè, 
   {{0x26c4c89c,0x80c00bca,0x32d80100,0x249c0051}},	//   rroo_, _विले, dèy_, _pttm_, 
   {{0xd82005f5,0xa7e00131,0xb5a400d4,0x00000000}},	//   _өдри, _бөлҗ, трій, --, 
   {{0x764003cb,0x60d80083,0x32d802e2,0x3eb801e3}},	//   _emly, vttm, fèy_, ysst_, 
   {{0x32d8033b,0x00000000,0x00000000,0x00000000}},	//   gèy_, --, --, --, 
   {{0xdb0c1497,0x236800e2,0x3774010a,0x00000000}},	//   _decè, ābj_, _рысс, --, 
   {{0x4034c89d,0x35f80014,0x21280332,0x00000000}},	//   венс, _زرٕد_, ábh_, --, 
   {{0x32d80100,0x3eb8003e,0x92dc00eb,0xfbe400cc}},	//   bèy_, tsst_, দয়ে_, _পোনত, 
   {{0x3eb80221,0x601c0036,0xef6401c0,0x6440c89e}},	//   usst_, _dëmp, вэрү, _imoi, 
   {{0xd36cb385,0xd62c0408,0x00000000,0x00000000}},	//   _اهه_, _кiез, --, --, 
   {{0x6288021a,0xcfb0015b,0xd12c02bf,0x387c0042}},	//   _iifo, _কারন, _сх_, ymwr_, 
   {{0x6288c89f,0x1dd00882,0x5bc8230e,0xb06001f4}},	//   _hifo, _तावत, िलेव, ääte, 
   {{0x06e82992,0x8ff81564,0x6440073c,0xdb0c0098}},	// [108b0] পিডি, _سرير_, _mmoi, _kecé, 
   {{0x62880009,0xdda88726,0x8b080118,0x787001e3}},	//   _jifo, _этил_, _spřá, gåvn, 
   {{0xe800069f,0x6288c8a0,0x64405c36,0xbc780212}},	//   _रोहा_, _mifo, _omoi, _обох_, 
   {{0x6288c8a1,0xa01826bc,0x7d0003cd,0x59ac00bc}},	//   _lifo, lmöb, ålsu, टरहर, 
   {{0x387c03cb,0x5edc0154,0x00000000,0x00000000}},	//   rmwr_, মিকে, --, --, 
   {{0xdb0c1497,0x6288c8a2,0x65c00124,0x6440c8a3}},	//   _recè, _nifo, абша, _amoi, 
   {{0x4a5400d8,0xc880236c,0x00000000,0x00000000}},	//   _скрс, şşar_, --, --, 
   {{0x6288c8a4,0x9c1002e3,0x7d040327,0x32d802bd}},	//   _aifo, bọel, _mrhs, tèy_, 
   {{0x6288c8a5,0x35f43e07,0xf7483090,0x36d400d1}},	//   _bifo, _ипар, _غلطي_, _шоар, 
   {{0x32d80699,0x6440c8a6,0xb22400cf,0x02640133}},	//   rèy_, _emoi, тмол, هێنێ, 
   {{0x6288c8a7,0x32d80100,0xa018002f,0x1acc03d4}},	//   _difo, sèy_, dmöb, ৰিয়া, 
   {{0x62880171,0x00000000,0x00000000,0x00000000}},	//   _eifo, --, --, --, 
   {{0x6288c8a8,0xd3445c81,0xc2c4c8a9,0x32680023}},	//   _fifo, _سیده_, _ميني, _ምጥርጣ, 
   {{0x62888efd,0x9bc8004b,0x708c0023,0xace8004e}},	//   _gifo, ېدلې_, ነብረሉ_, ммга_, 
   {{0xd7b0c8aa,0xb060005b,0xa3dc07d0,0xd00401d5}},	//   ुणाच, ääse, द्व_, _бойқ, 
   {{0xec1404fb,0x6288c8ab,0x64400129,0x6fb41b87}},	//   خورد, _zifo, _xmoi, _अजिं, 
   {{0x7d0402c4,0xea8814b7,0x6288baf6,0x00000000}},	// [108c0] _erhs, дбал_, _yifo, --, 
   {{0x62880356,0x6d2400c0,0x00000000,0x00000000}},	//   _xifo, _адоз, --, --, 
   {{0xed580022,0x7d001f53,0x78700267,0xec7800f3}},	//   _цон_, ålst, gåvo, _опо_, 
   {{0x3eac0311,0xb8641e95,0xb8c400d1,0x6118010f}},	//   ţete_, هانو, ازلى, וועה, 
   {{0x1cdc0327,0x6994014b,0xf60801e2,0x00000000}},	//   _ལཱོ_, _арбх, کتنه_, --, 
   {{0x5690c8ac,0x64401713,0xd5e000d4,0x00000000}},	//   шашт, _smoi, ижчи, --, 
   {{0x6288c8ad,0xdb0cc8ae,0x198407dd,0x00000000}},	//   _rifo, _recé, _абри_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa684c8af,0x9f4809d7,0xe0ac015b,0x6288c8b0}},	//   _алад, pecé_, _কমেন, _pifo, 
   {{0x620402bf,0xdb0400e5,0x00000000,0x00000000}},	//   тчиз, ömér, --, --, 
   {{0x3c3403cd,0x84c46518,0xe3b8009b,0x00000000}},	//   _håve_, _сәлд, _жбе_, --, 
   {{0x14d402e4,0x40341f39,0x50d01291,0x00000000}},	//   _יובל_, уемс, گزیر, --, 
   {{0x6288c8b1,0x93c801d9,0x745000e5,0x00000000}},	//   _tifo, _زانہ_, _دھوئ, --, 
   {{0xc0c40032,0xf424000d,0xb0601057,0x00000000}},	//   _йәми, _ääre_, ääre, --, 
   {{0x3c34143a,0xa0180112,0x9f580200,0x127c0023}},	//   _låve_, rmöb, _kaqë_, _ብእኩብ_, 
   {{0xdb0c0311,0xa01801e3,0x00000000,0x00000000}},	//   _decî, smöb, --, --, 
   {{0xba5400f0,0x9e641291,0x00000000,0x00000000}},	// [108d0] гвај, _لادن, --, --, 
   {{0xbdf40b3e,0xabdc02dd,0x00000000,0x00000000}},	//   _спој, _ﺇﻤﻜﺎ, --, --, 
   {{0xd838009d,0x00000000,0x00000000,0x00000000}},	//   мэд_, --, --, --, 
   {{0xf7580395,0x00000000,0x00000000,0x00000000}},	//   наещ_, --, --, --, 
   {{0x7c2cc8b2,0x0b88013e,0x00000000,0x00000000}},	//   mkar, _асри_, --, --, 
   {{0x7c2cc8b3,0x00000000,0x00000000,0x00000000}},	//   lkar, --, --, --, 
   {{0x5edc0f22,0x2458005f,0xa3ac00dc,0x04b400db}},	//   মিটে, zīme_, करं_, асыя, 
   {{0xfbb000cc,0x00000000,0x00000000,0x00000000}},	//   _ছাঁত, --, --, --, 
   {{0x7c2cc8b4,0x3c3400fe,0x1dd02274,0x93400116}},	//   ikar, _gåve_, _तांत, شىدۇ, 
   {{0x7c2cc8b5,0xd24007d6,0xa280c8b6,0x942000d1}},	//   hkar, рмоқ, مینو, _ھوشۇ, 
   {{0x7c2cc8b7,0x9f580023,0x7d000162,0x00000000}},	//   kkar, _faqë_, ælsl, --, 
   {{0xb2740598,0x7c2cc8b8,0xd5dc00dc,0x116401b9}},	//   _өлеш, jkar, प्रज, _یلشی_, 
   {{0x7c2cc8b9,0x1cdc0327,0x3ec401f0,0xdb6800d1}},	//   dkar, _ལཱུ_, исёб, ﺳﯩﺮﻯ_, 
   {{0x7c2c0108,0x00000000,0x00000000,0x00000000}},	//   ekar, --, --, --, 
   {{0x7c2c0af9,0x8cd4033f,0xd344006c,0x856c00d1}},	//   fkar, बंधो, _سیگه_, ﺴﯩﺪﺍ_, 
   {{0x7c2c9b94,0x09cc08e6,0x0fe800d1,0x2b38084c}},	//   gkar, ाल्य, _рлиқ_, нязэ_, 
   {{0x9b900597,0x69d805d1,0x7d0003cd,0xabdc0150}},	// [108e0] إلكت, _ötek, ålsr, _ﺇﺤﻜﺎ, 
   {{0x7c2cc8ba,0xb9c40bbf,0x09cc015b,0x00000000}},	//   akar, لتمه, র্না, --, 
   {{0x7c2c00ac,0x6e2c0175,0xbf64029e,0x00000000}},	//   bkar, mkbb, _مدیو, --, 
   {{0x7c2cc8bb,0xdbd403fa,0x3c34007c,0x00000000}},	//   ckar, mäßi, _påve_, --, 
   {{0xd704034b,0xad249c97,0xa5e401e0,0x988801d3}},	//   лнце_, _شىڭى, лһаҡ_, رحمہ_, 
   {{0x9f580023,0x00000000,0x00000000,0x00000000}},	//   _saqë_, --, --, --, 
   {{0x9f58036e,0x644c01e1,0x00000000,0x00000000}},	//   _paqë_, _ìbik, --, --, 
   {{0xd4640640,0x1b1800eb,0x00000000,0x00000000}},	//   лије_, _নেটে_, --, --, 
   {{0xa6c866df,0xe5a409a5,0xded402d3,0x00000000}},	//   _سوال_, _бизи, ይቶን_, --, 
   {{0xd6cc36e7,0x7c2c0323,0x1fbc0027,0x00000000}},	//   _رقم_, zkar, ्ल्ड, --, 
   {{0x7c2cc8bc,0xc3c4c8bd,0x00000000,0x00000000}},	//   ykar, _көпл, --, --, 
   {{0xdef80323,0x557400c8,0xe298c8be,0xcfb00eac}},	//   ныг_, _געבן_, _зад_, _কাউন, 
   {{0x09cc03f4,0x80c0c8bf,0x7c2cc8c0,0x6d586c80}},	//   র্যা, _विके, vkar, ûtan, 
   {{0x7c2cc8c1,0x00000000,0x00000000,0x00000000}},	//   wkar, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x09cc03f4,0x254c06be,0x9f480118,0x92d400fe}},	//   র্মা, _məl_, lecí_, াবৰ_, 
   {{0xda640451,0x4c943769,0x254c03b9,0x8d900092}},	// [108f0] هائي, _қияс, _ləl_, ጅታቸው_, 
   {{0x7c2cc8c2,0xa8000790,0x4e8001ec,0x00000000}},	//   skar, çınc, _ﺤﺎﻓﻅ_, --, 
   {{0x7c2cc8c3,0x09cc015b,0x1cdc031c,0x98480131}},	//   pkar, র্ভা, _ལཱི_, няда_, 
   {{0x9c100521,0x00000000,0x00000000,0x00000000}},	//   bọal, --, --, --, 
   {{0xc1ac02dd,0x00000000,0x00000000,0x00000000}},	//   _ﺳﺘﺮﺍ, --, --, --, 
   {{0x09cc0d42,0x9f4800bc,0x00000000,0x00000000}},	//   র্বা, jecí_, --, --, 
   {{0x53c002dd,0x00000000,0x00000000,0x00000000}},	//   байұ, --, --, --, 
   {{0x72c4030d,0xdecc0092,0xc5080ee8,0x00000000}},	//   абиз, _እጁን_, اتول_, --, 
   {{0x6e2c00b5,0xd2400131,0x960004b3,0x54f4010a}},	//   ykbb, ймиқ, _гүлж, ăхшă, 
   {{0xdb0c02fb,0xba00010c,0x00000000,0x00000000}},	//   _necí, _ሃና_, --, --, 
   {{0x254c00ac,0x0478036b,0x30740120,0x00000000}},	//   _gəl_, ضلیک_, иумс, --, 
   {{0xdb0c0261,0x9484113e,0x00000000,0x00000000}},	//   _mecâ, _сызд, --, --, 
   {{0x92b40491,0xf1dc17ee,0x254c06be,0x00000000}},	//   _إحصا, _मापन, _zəl_, --, 
   {{0xdb0c17cd,0xed5815ed,0x71a401f0,0x00000000}},	//   _cecí, вог_, _такз, --, 
   {{0x61400aa5,0xdb0c09ff,0xa018023a,0x00000000}},	//   _меша, _decí, mmön, --, 
   {{0x3eac0311,0xa01801e3,0xaf3400db,0x92d40154}},	//   ţeta_, lmön, _ەرگت, াবী_, 
   {{0xe9d815d5,0x24580aea,0x6994074d,0x1fb400db}},	// [10900] кка_, nīma_, арех, _өсөр, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf1dc1d8a,0x612400d7,0x00000000,0x00000000}},	//   _मानन, _ičlá, --, --, 
   {{0xdb0c00a8,0xeab80323,0xeb985858,0xe7d000f7}},	//   _decâ, _ийм_, _шим_, تۅرگ, 
   {{0x78a809a8,0x2b380276,0x25f00d79,0x9b000006}},	//   _čeve, _рянэ_, ंजली_, _дзяд, 
   {{0x8a34009f,0x00000000,0x00000000,0x00000000}},	//   _اِسڪ, --, --, --, 
   {{0xf9900f11,0x00000000,0x00000000,0x00000000}},	//   _ربّ_, --, --, --, 
   {{0x2908bad2,0x68ec00b5,0x76c40131,0x254c03b9}},	//   _irba_, _ipbd, شغۇل, _vəl_, 
   {{0xd374c8c4,0x09cc015b,0x27e401e4,0x758001d9}},	//   ичь_, র্ণা, mfon_, _ہیٖم, 
   {{0x27e4c8c5,0x7d00c8c6,0x254c03b9,0xa018032e}},	//   lfon_, ælsk, _təl_, gmön, 
   {{0x9f480789,0x00000000,0x00000000,0x00000000}},	//   recí_, --, --, --, 
   {{0x78a001ed,0x27e40368,0x645cc8c7,0x765c00e4}},	//   _élve, nfon_, épid, _êsyr, 
   {{0x44f8c8c8,0x63a0c8c9,0xdb0c0077,0x6d5c0857}},	//   _hũ_, _ifon, _pecí, _axpa, 
   {{0x2908c8ca,0x63a0030a,0x44f80022,0xb8f8031c}},	//   _orba_, _hfon, _kũ_, _འྀ_, 
   {{0x63a00076,0x9c44c8cb,0xcd040b7e,0xc1040451}},	//   _kfon, ахал, очти, _چوڻي, 
   {{0x1dd00c2e,0x44f8001e,0xdb0c0356,0xab6003e3}},	//   _ताकत, _mũ_, _recâ, _şüal, 
   {{0x29080953,0x63a0013b,0x44f8001e,0xdb0c0077}},	// [10910] _arba_, _mfon, _lũ_, _tecí, 
   {{0xbaa401a9,0x00000000,0x00000000,0x00000000}},	//   _қумқ, --, --, --, 
   {{0x27e4c8cc,0x63a0c8cd,0x44f80051,0x00000000}},	//   ffon_, _ofon, _nũ_, --, 
   {{0x63a0013b,0x21c000d1,0x00000000,0x00000000}},	//   _nfon, ﯩﺪﺍﺭ, --, --, 
   {{0x29089784,0x09cc2aab,0x7bdc07de,0xbd8805d9}},	//   _erba_, র্ধা, _icsu, _جنھن_, 
   {{0x7afca2e5,0x27e4002e,0x1a740150,0x00000000}},	//   _isst, afon_, _тұзы_, --, 
   {{0x44f807ae,0xe80007c1,0xf3f8054e,0xce38011a}},	//   _cũ_, _रोका_, loţi_, שאות_, 
   {{0x80c0c8ce,0x61e80e78,0x7afc03b2,0x09cc0154}},	//   _विजे, _abfl, _ksst, র্দা, 
   {{0x86985169,0x386cc8cf,0x7afc0175,0x24040022}},	//   _вкус_, _iker_, _jsst, сныи_, 
   {{0x63a0c8d0,0xdb0c0137,0x668004d3,0x9564030d}},	//   _efon, _mecà, _فینل, _къед, 
   {{0x63a000a9,0xa01801a8,0x7bdc0175,0xf0643129}},	//   _ffon, rmön, _ocsu, йкоп, 
   {{0xa0180008,0x7afc03ac,0x72d40798,0x00000000}},	//   smön, _osst, _годф, --, 
   {{0x645c4e01,0x7afc0009,0xa018005b,0x00000000}},	//   épie, _nsst, mmöl, --, 
   {{0x7bdc011f,0x44f80022,0xa0180108,0xf67800df}},	//   _acsu, _yũ_, lmöl, טאָמ, 
   {{0x7afc062c,0x386c8bb0,0x518433ea,0xac9802f2}},	//   _asst, _oker_, _туда, انرا_, 
   {{0xdb0c004e,0xed580aac,0x386c01bf,0x3e7c0118}},	//   _becà, воҳ_, _nker_, _pátý_, 
   {{0x29080bb8,0x4f8401d9,0x7afc0334,0x7bdc0175}},	// [10920] _srba_, _باغہ, _csst, _dcsu, 
   {{0x386cc8d1,0xdb0c00cf,0xa018002f,0x699418cd}},	//   _aker_, _decà, hmöl, срах, 
   {{0x7afc4431,0x00000000,0x00000000,0x00000000}},	//   _esst, --, --, --, 
   {{0xe7381c31,0x386c0295,0x44f8001e,0x6838004e}},	//   лее_, _cker_, _rũ_, _oïde, 
   {{0xeabc00c6,0x27e4c8d2,0x7afc003e,0x00000000}},	//   _яιп_, rfon_, _gsst, --, 
   {{0x63a0c8d3,0x386cc8d4,0x27e40198,0x290800f3}},	//   _sfon, _eker_, sfon_, _trba_, 
   {{0x2908008f,0x534007dd,0x00000000,0x00000000}},	//   _urba_, ҧхьа, --, --, 
   {{0x44f807ae,0x7d00022c,0xd940010b,0x6844004e}},	//   _vũ_, ælsi, _эеси, _унба, 
   {{0x8238c8d5,0xead4045e,0x7afc00e4,0x9f48004e}},	//   изис_, _হনুম, _xsst, xecà_, 
   {{0x44f80022,0x00000000,0x00000000,0x00000000}},	//   _tũ_, --, --, --, 
   {{0xdb0c1280,0xe5580e92,0x00000000,0x00000000}},	//   _mecá, _сјај_, --, --, 
   {{0xcfac2e56,0x00000000,0x00000000,0x00000000}},	//   _ﺳﯩﺮﺗ, --, --, --, 
   {{0x2284010b,0x00000000,0x00000000,0x00000000}},	//   _лукг, --, --, --, 
   {{0xdb0c00cf,0x7afc005a,0xbc9406ed,0x787005ac}},	//   _recà, _rsst, жавј, råvi, 
   {{0x0ca80131,0x6ecc23e9,0x05e001f9,0xa01806be}},	//   йтти_, _तिथु, _नानब, lmöm, 
   {{0x787008cb,0x00000000,0x00000000,0x00000000}},	//   påvi, --, --, --, 
   {{0x7b1800a7,0x3b542377,0x00000000,0x00000000}},	// [10930] шоар_, цкар, --, --, 
   {{0x386cc8d6,0xdb0c0077,0x09cc0154,0x00000000}},	//   _sker_, _cecá, র্সা, --, 
   {{0xdb0c09c2,0x291c0327,0xf3f80356,0x7798c8d7}},	//   _decá, _àtal_, soţi_, акер_, 
   {{0xf3f80356,0x7bdc06be,0x4b2000fe,0x00000000}},	//   poţi_, _ucsu, _নেওগ_, --, 
   {{0xb6f80075,0x7afca2e5,0x00000000,0x00000000}},	//   شىغا_, _usst, --, --, 
   {{0x34a84eeb,0x39800023,0x58b835ea,0xa800c8d8}},	//   авко_, ራመርቲ_, _مارج_, _çıng, 
   {{0x39040014,0xaa4000d1,0x349400c7,0x00000000}},	//   _بوزٲ, _تۆلى, әаҩр, --, 
   {{0x386c00d6,0xf42816c3,0x3ea8005b,0x085401ee}},	//   _uker_, роил_, _otat_, _евсю, 
   {{0xe8140574,0x3ea80032,0x9f580166,0xa01808a5}},	//   णारा_, _ntat_, _baqí_, gmöm, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3ea800a8,0x3b080007,0x2290004b,0x0ef41b76}},	//   _atat_, hvaq_, ګلیس, ेट्स_, 
   {{0xa0183167,0x00000000,0x00000000,0x00000000}},	//   lmöj, --, --, --, 
   {{0x6da4034b,0x05e000bc,0x00000000,0x00000000}},	//   жига, _नामब, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3ea8c8d9,0xdb0c0407,0xafe4c8da,0xa3ac0490}},	//   _etat_, _recá, _дойл, करच_, 
   {{0x3204c8db,0x00000000,0x00000000,0x00000000}},	//   ldly_, --, --, --, 
   {{0xfbd00583,0x3b080097,0x78a86b48,0xa01801e3}},	// [10940] عتِ_, gvaq_, _čeva, kmöj, 
   {{0x32040c18,0xe8003c20,0x00000000,0x00000000}},	//   ndly_, _रोजा_, --, --, 
   {{0xe8f8c8dc,0xe8140574,0x6844004e,0x00000000}},	//   рле_, णाला_, онжа, --, 
   {{0x6bd4c8dd,0x00000000,0x00000000,0x00000000}},	//   _بتدر, --, --, --, 
   {{0xdb0c0789,0x00000000,0x00000000,0x00000000}},	//   _tecá, --, --, --, 
   {{0x2d4c01c0,0x3af800c8,0xe4a4c8de,0x00000000}},	//   _eнee_, _פּרע, орио, --, 
   {{0x3204045a,0x6d5800e4,0x7854072d,0x00000000}},	//   ddly_, ûtah, _کینز_, --, 
   {{0x87a40124,0x3204045a,0xd54400f1,0x09cc0154}},	//   _хлаҧ, edly_, غليو_, র্শা, 
   {{0x69d805d1,0x26c00248,0x00000000,0x00000000}},	//   _ötes, _ìko_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa2b85444,0x3ea8228f,0x3b080369,0xd25402d5}},	//   _शौर्, _stat_, zvaq_, ўцы_, 
   {{0x629c02b5,0x442000c7,0x363402dd,0x32047c8f}},	//   _ōpou, _õi_, _ورەس, adly_, 
   {{0x72a004a2,0xf2340517,0x3d942b97,0xf3f800f1}},	//   _كەين, زبیک, зигр, _دونګ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4034c8df,0x99d401d9,0xa01801f4,0x644c01e1}},	//   _некс, ۪ترا, nmök, _ìbis, 
   {{0x82c8031c,0x7e740334,0x5fa400dc,0x00000000}},	//   _གྷོའ, slzp, कुशल, --, 
   {{0x101406f6,0x3ea8c8e0,0xa018002f,0xab60013d}},	// [10950] _زبيد, _utat_, hmök, _çülm, 
   {{0xf8b0c8e1,0x5fa400bc,0x00000000,0x00000000}},	//   فکر_, कुरल, --, --, 
   {{0xd9180588,0xd7f801c0,0xa3d800c5,0x00000000}},	//   шьа_, иуд_, ़ला_, --, 
   {{0xdb1c02d3,0xa80005d1,0x09cc0154,0x7d0006ea}},	//   naqë, _çılg, র্লা, ælsu, 
   {{0xe7a40075,0xa018007c,0xc7e800db,0x99d400ae}},	//   سۇلى_, tmöj, تىنن_, _وتسا, 
   {{0xa3dc2e05,0x66004690,0x00000000,0x00000000}},	//   द्घ_, епша, --, --, 
   {{0x7af87975,0x64a0005b,0x00000000,0x00000000}},	//   şatı, наща, --, --, 
   {{0xd838c8e2,0xa0180267,0x1cdc0327,0x32040076}},	//   _тэг_, smöj, _ལཱན_, wdly_, 
   {{0xf7480491,0x35d41188,0x00000000,0x00000000}},	//   _الذي_, _ноаё, --, --, 
   {{0xdfe405f5,0x3204c8e3,0xb1441d39,0xa01801e3}},	//   үдэд_, udly_, знол, lmöh, 
   {{0x716801b9,0x320441fb,0xdb1c0240,0x22401bce}},	//   санг_, rdly_, faqë, ëkka_, 
   {{0x293400c8,0x96cc012c,0xd7ec0150,0x00000000}},	//   פארן_, _हटाउ, еуi_, --, 
   {{0xf3f80356,0x59c8041c,0xb2a801f7,0x00000000}},	//   meţ_, ाणार, _اُتم_, --, 
   {{0xf3f8054e,0x644c01e1,0x00000000,0x00000000}},	//   leţ_, _ìbir, --, --, 
   {{0xed50a268,0xd00401ec,0xa018010b,0x00000000}},	//   رپر_, _жойқ, kmöh, --, 
   {{0xeb980588,0x01343918,0xf3f8054e,0x00000000}},	//   сиа_, _تعهد, neţ_, --, 
   {{0x99800118,0x00000000,0x00000000,0x00000000}},	// [10960] _bojů_, --, --, --, 
   {{0xe8f80064,0xab600432,0x00000000,0x00000000}},	//   йлз_, _çümm, --, --, 
   {{0x290c0008,0xa96800c6,0x7d00c0fa,0x00000000}},	//   ífa_, حمام_, ælst, --, 
   {{0x66e4059f,0x00000000,0x00000000,0x00000000}},	//   зода, --, --, --, 
   {{0xf3f80276,0x82e80327,0xbb7401b9,0x18647696}},	//   deţ_, _འདེའ, _журъ, чаци_, 
   {{0xdb0c0120,0xf9900131,0x45d401af,0x6bd40244}},	//   _secç, ربە_, фокс, _بتگر, 
   {{0x1fc404c5,0xb5080490,0x6fbc0a59,0x00000000}},	//   ষ্টস, विषय_, ्णां, --, 
   {{0x439446ee,0x66e4c8e4,0xe7380261,0x69dc332e}},	//   майс, _ноба, _леб_, lgpe, 
   {{0x6fd40073,0x00000000,0x00000000,0x00000000}},	//   _भाजू, --, --, --, 
   {{0x69dcc8e5,0x55e00261,0xa018023a,0x26c40254}},	//   ngpe, _поуб, mmöi, msoo_, 
   {{0xf1dc1d15,0xa018005b,0x26c40254,0x00000000}},	//   _मारन, lmöi, lsoo_, --, 
   {{0x26c40009,0x4acc0073,0x00000000,0x00000000}},	//   osoo_, ाळाव, --, --, 
   {{0x26c4c8e6,0xe2840026,0x25840118,0xdbcc0118}},	//   nsoo_, _елди, bílé_, jžád, 
   {{0x6ecc0c6e,0x26c4058a,0x93404316,0xdb1c0200}},	//   _तिरु, isoo_, _янче, saqë, 
   {{0x61f8c8e7,0x25bc0166,0x1278010f,0x24e40150}},	//   metl, _metl_, _האגע, _ﺍﻛﻪﻣ, 
   {{0x61f8c8e8,0x249c0198,0x26c400c5,0x44240072}},	//   letl, _mutm_, ksoo_, njm_, 
   {{0xe2f80489,0x60d84a1f,0x442401f5,0x1cdc0327}},	// [10970] _དགསཔ_, lutm, ijm_, _ལཱམ_, 
   {{0x61f8c8e9,0x1a7000aa,0x02d40fc8,0x00000000}},	//   netl, رپاڼ, _दिनभ, --, 
   {{0x44240fac,0x00000000,0x00000000,0x00000000}},	//   kjm_, --, --, --, 
   {{0x61f8c8ea,0x3754030f,0xd88001b9,0xf77400d4}},	//   hetl, وپاس, رهشی, мулю, 
   {{0x61f8c8eb,0xdb0401e3,0x5fd80b26,0x00000000}},	//   ketl, ömär, _भाईल, --, 
   {{0x61f81727,0xf3f80311,0x8d741c02,0x645c0129}},	//   jetl, inţe_, _تاۋا, épin, 
   {{0x82e80003,0x26c422ac,0xf3f80356,0x61f8c8ec}},	//   _འདུའ, asoo_, teţ_, detl, 
   {{0x26c422a9,0x25bc01f5,0x4424037e,0x06e800cc}},	//   bsoo_, _eetl_, gjm_, পিজি, 
   {{0x61f8c8ed,0xf3f80311,0x6fbc07b6,0x24940092}},	//   fetl, reţ_, ्णसं, _ማጣራት_, 
   {{0x61f8c8ee,0x4424036e,0xa2806646,0x00000000}},	//   getl, ajm_, نینو, --, 
   {{0x224c01c7,0x2164010b,0xf3f80356,0x60d80205}},	//   _dmfk_, диэи_, enţe_, gutm, 
   {{0x78a8c8ef,0xf3180798,0x00000000,0x00000000}},	//   _čevl, _моеш_, --, --, 
   {{0x4374c8f0,0x61f8c8f1,0x69dc007c,0x00000000}},	//   _пушт, betl, ygpe, --, 
   {{0x60d8005c,0x61f80999,0x712400f1,0x25bc0139}},	//   butm, cetl, _يرغل, _xetl_, 
   {{0xe2f807e4,0x1d0408a0,0xf3f80311,0xe6b8095f}},	//   _དགོཔ_, мери_, anţe_, _उब्ज, 
   {{0xec780816,0x26c40067,0x00000000,0x00000000}},	//   іпа_, ysoo_, --, --, 
   {{0x2d7800d1,0x26c4058a,0x00000000,0x00000000}},	// [10980] ﻠﯩﻜﻰ_, xsoo_, --, --, 
   {{0x68fc0175,0x9f4c01e1,0x00000000,0x00000000}},	//   twpd, _úgá_, --, --, 
   {{0xeb98c8f2,0xac8400d6,0x3cf02195,0x2bb800c6}},	//   _мин_, _огол, čová_, _واحة_, 
   {{0x61f8c8f3,0x26c4023a,0x00000000,0x00000000}},	//   zetl, tsoo_, --, --, 
   {{0x61f8c8f4,0x3af40153,0x00000000,0x00000000}},	//   yetl, _пярс, --, --, 
   {{0x26c4c8f5,0x7cc401b9,0xd5acc8f6,0xe5c400d4}},	//   rsoo_, _تزیم, لفه_, єсло, 
   {{0x61f8c8f7,0x5e5404ac,0x26c4348e,0x7c3c0175}},	//   vetl, ויסע_, ssoo_, _ylsr, 
   {{0x61f8c8f8,0x60d80cfe,0x2814c8f9,0x273400db}},	//   wetl, vutm, _تورس, _قىزس, 
   {{0x61f8c8fa,0x245800e2,0x00000000,0x00000000}},	//   tetl, nīmi_, --, --, 
   {{0xd6d401b9,0x00000000,0x00000000,0x00000000}},	//   _آولش_, --, --, --, 
   {{0x61f8c8fb,0xae200dad,0x6618025c,0xdeb80023}},	//   retl, मानन_, _intk, ታዊን_, 
   {{0x61f8c8fc,0x44e8025a,0xe298c8fd,0x6e3c0cf4}},	//   setl, mû_, _дад_, _alpb, 
   {{0x82e8038f,0x61f8c8fe,0x69cc01a2,0x3eac05e4}},	//   _འདིའ, petl, _odbe, ëet_, 
   {{0x2e240109,0x6838004e,0x60d80066,0x61f86edb}},	//   _kôfy_, _oïdo, putm, qetl, 
   {{0x2484c8ff,0x0d840108,0x00000000,0x00000000}},	//   _khom_, влён, --, --, 
   {{0x69ccc900,0xdb580166,0x1bb8007b,0x00000000}},	//   _adbe, оюз_, تاسع_, --, 
   {{0x66182595,0x1ea87427,0x6720002e,0x98c00205}},	// [10990] _ontk, _بابي_, jxoj, _ıvır_, 
   {{0x24840327,0x44e8002d,0x00000000,0x00000000}},	//   _lhom_, kû_, --, --, 
   {{0xb7bc0311,0x00000000,0x00000000,0x00000000}},	//   _hoţi, --, --, --, 
   {{0x7d04c901,0x248401fb,0x66180024,0x69ccc902}},	//   _ishs, _nhom_, _antk, _edbe, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x75d4c903,0xb7bc0311,0xae2000c5,0xf1dc3d1d}},	//   ريعا, _moţi, मायन_, _माइन, 
   {{0x248400a3,0x38b40241,0xc88400fd,0xb7bc0356}},	//   _bhom_, _dúrò_, äşü_, _loţi, 
   {{0x6618c904,0xcd981203,0x248403bd,0x5884c905}},	//   _entk, ודות_, _chom_, _цыга, 
   {{0xb7bc0311,0x2484c906,0x00000000,0x00000000}},	//   _noţi, _dhom_, --, --, 
   {{0xe72c03e6,0x47840c75,0x7d0401a9,0x52bc20f0}},	//   _دڵم_, _рысб, _oshs, _एबीस, 
   {{0xfdec02ab,0x245800e2,0x1ca80327,0x09cc0154}},	//   _चॉइस_, zīmi_, ྔམས_, র্কা, 
   {{0x24840978,0xaab43535,0xaad807f7,0x6ef4032e}},	//   _ghom_, _ölçü_, यूँक, _nýbö, 
   {{0xb8e00ad3,0x7d04c907,0x86880023,0x00000000}},	//   _གས_, _ashs, _ዝሃብዎ_, --, 
   {{0x6ef400a2,0x24840129,0x98a40118,0x11d4009f}},	//   _aýbö, _zhom_, áně_, _آتشد, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x98a4012c,0x826402d3,0x00000000,0x00000000}},	//   šně_, _ፍጻሜታ, --, --, 
   {{0xab64c908,0x7d04022e,0xada40006,0xb7bc054e}},	// [109a0] хвал, _eshs, _папл, _goţi, 
   {{0x24580374,0x9b002de5,0xa018007c,0x00000000}},	//   rīmi_, ызуд, glöf, --, 
   {{0xec7828e8,0x99e000d7,0x00000000,0x00000000}},	//   _нпо_, áňac, --, --, 
   {{0x27f009a5,0xe78402bf,0xc18c00c8,0x61440129}},	//   ýyn_, нуло, קטאָ, _hélé, 
   {{0x24840564,0x77902050,0xf3fc025c,0xa01801b8}},	//   _rhom_, لیفا, _དྲེད_, blöf, 
   {{0x69cc04ce,0x200802fb,0x44e8011f,0x6144585c}},	//   _udbe, zdci_, tû_, _jélé, 
   {{0x24840070,0xb90403d4,0x61444de4,0xdb200241}},	//   _phom_, _বৈ_, _mélé, _òròm, 
   {{0xdb0c0077,0x44e8c909,0x614400d5,0x5500023a}},	//   _recú, rû_, _lélé, учша, 
   {{0xa018008c,0x44e8006a,0x7c280086,0xdb0c0393}},	//   llög, sû_, _òere, _secú, 
   {{0xe5a400d1,0x61440c6a,0xddc409a8,0x2484be8f}},	//   _чижи, _nélé, kojš, _whom_, 
   {{0xb7bc084c,0xe4d4c90a,0x12a80150,0x35c4014b}},	//   _soţi, _ستاب, _ﺴﻨﻜﻭ, _рахҳ, 
   {{0x23640b89,0x44cc0316,0x248401a6,0x14d40a7c}},	//   _txoj_, mě_, _uhom_, _טובל_, 
   {{0x1e700116,0x71800124,0x00000000,0x00000000}},	//   лғис, лқәе, --, --, 
   {{0x61444aee,0x65780493,0x4254c90b,0x00000000}},	//   _célé, _kyth, _جنتر, --, 
   {{0x44cc0316,0x6144c90c,0x710400c7,0x8d6800d8}},	//   ně_, _délé, _ацыҧ, ејта_, 
   {{0x3f140228,0xb7bc0311,0x6578c90d,0xa018007c}},	//   _адис, _toţi, _myth, gmöt, 
   {{0x3a74b283,0x6578c90e,0x6144c90f,0x48e003d4}},	// [109b0] влар, _lyth, _félé, নবোৰ, 
   {{0x9964a44d,0xddc4bc04,0x6144c910,0xf3f80311}},	//   нтел, bojš, _gélé, inţa_, 
   {{0x99641fa9,0x6578c911,0xdb1c0784,0xddc40010}},	//   хтал, _nyth, maqí, cojš, 
   {{0x44cc038e,0xb9080a28,0xa018c912,0x3b84004e}},	//   dě_, _मम_, mmös, _үлүг, 
   {{0xd90c00f8,0x65780165,0x614400e8,0xa0184268}},	//   _گیا_, _ayth, _yélé, lmös, 
   {{0x7aec2728,0x6578c913,0x00000000,0x00000000}},	//   mtat, _byth, --, --, 
   {{0xd90c00f8,0xf3fc025c,0x6578a365,0xf3f80311}},	//   _دیا_, _དྲུད_, _cyth, enţa_, 
   {{0x7aecc914,0x2584013a,0x612803e0,0x00000000}},	//   otat, _sílí_, zölç, --, 
   {{0xc864ba72,0x657814dc,0x48640801,0x5fd80073}},	//   _стри, _eyth, _сърб, _भाजल, 
   {{0x7aecc915,0x44cc00bc,0x6578015d,0x2fc40010}},	//   itat, bě_, _fyth, _žog_, 
   {{0x7640c916,0x7aec02d3,0xe8140490,0x387c0368}},	//   _illy, htat, णाचा_, olwr_, 
   {{0x6144c917,0xb3540bd6,0x73381b0a,0x00000000}},	//   _sélé, _икеш, _озер_, --, 
   {{0xe28cc918,0x7aecc919,0x09cc00bd,0x6578003a}},	//   _ва_, jtat, র্টা, _zyth, 
   {{0xc0a85350,0x7aecc91a,0x2d9c03a1,0x21a000ee}},	//   بایل_, dtat, øte_, _кишм, 
   {{0xed58c91b,0x7aecc91c,0xa01801e3,0x6140399b}},	//   фов_, etat, flöd, _веща, 
   {{0x6144003e,0x2b380276,0x00000000,0x00000000}},	//   _wélé, мязэ_, --, --, 
   {{0x6144c91d,0x7aec9b94,0x7640c91e,0xa0180267}},	// [109c0] _télé, gtat, _olly, rmöt, 
   {{0xa01801e6,0xa95802f2,0x09cc00fe,0x00000000}},	//   smöt, وجار_, ৰ্না, --, 
   {{0x7aecc91f,0x6994c920,0x77680077,0x387c0368}},	//   atat, трах, _axex, flwr_, 
   {{0x44cc038e,0x6578c921,0x6f1405d6,0x7aecc922}},	//   vě_, _ryth, _kryc, btat, 
   {{0xb864c923,0x65782a3d,0x45d409a0,0xa01801a8}},	//   دالو, _syth, голс, slög, 
   {{0x6578c924,0x09cc03f4,0x98a4084c,0x44cc0316}},	//   _pyth, র্জা, ână_, tě_, 
   {{0xe9743e58,0x77680077,0xdd38054e,0x00000000}},	//   _شهرد, _exex, _măşt, --, 
   {{0x76405f25,0x6f14c925,0x387c0142,0xd4640114}},	//   _elly, _oryc, clwr_, кије_, 
   {{0x65780cfd,0x4274c926,0xa01801a8,0xc2987651}},	//   _wyth, лгис, kmör, нких_, 
   {{0x95b40022,0x2fd000a2,0x44cc00bc,0xb35404fb}},	//   _арцә, _adyg_, pě_, دیها_, 
   {{0x7aecc927,0xd48cc928,0x6f1403ac,0x65780142}},	//   ztat, _вр_, _aryc, _uyth, 
   {{0x6f14c929,0x7aec33d8,0xdef805f5,0x31840150}},	//   _bryc, ytat, мыг_, ытың, 
   {{0x6440c92a,0x6f14c92b,0x1ea8027d,0xdd380356}},	//   _iloi, _cryc, باجي_, _băşt, 
   {{0x644001e0,0x6f142a41,0x7aec01a6,0xdd38054e}},	//   _hloi, _dryc, vtat, _căşt, 
   {{0x16dc084a,0x6f14c92c,0x7aec03f9,0xbca44630}},	//   _नम्ब, _eryc, wtat, امري, 
   {{0x7aec1436,0x09cc0c58,0x68100134,0x6f14c92d}},	//   ttat, ৰ্মা, bɛdɔ, _fryc, 
   {{0x7aecc92e,0x6f14c92f,0x4c94bbdd,0xc4c401ed}},	// [109d0] utat, _gryc, ритс, _ڈے_, 
   {{0x64400072,0xc4c41c3b,0x09cc00eb,0x00000000}},	//   _lloi, _وے_, র্ঘা, --, 
   {{0x7aecc930,0x6440c931,0x6f14c932,0x245800e2}},	//   stat, _oloi, _zryc, nīms_, 
   {{0x7aecc933,0x00000000,0x00000000,0x00000000}},	//   ptat, --, --, --, 
   {{0x7aecc934,0x870480b5,0xbd34113e,0x387c015d}},	//   qtat, لبول, _شىڭع, rlwr_, 
   {{0x64400664,0x09cc0c58,0x00000000,0x00000000}},	//   _aloi, ৰ্বা, --, --, 
   {{0x6440c935,0xb7bc0276,0x2ba80401,0x00000000}},	//   _bloi, _soţu, _कलमा, --, 
   {{0x6440c936,0xd3a005c2,0x8458c937,0xd7f801c6}},	//   _cloi, шлиқ, крыт_, _юуг_, 
   {{0x62880491,0x33f40150,0xf1d00137,0x047800f1}},	//   _bhfo, _ەستس, бөйө, خليک_, 
   {{0x64980228,0x47880276,0x7640c938,0xb224c939}},	//   мтөр_, _рссм_, _ully, умол, 
   {{0xf3f40214,0x60b000e5,0xa01801e3,0x2d9c00d7}},	//   _متشک, یمیئ, vmör, žtek_, 
   {{0x64401e67,0xe93c0327,0x00000000,0x00000000}},	//   _gloi, _ħażż, --, --, 
   {{0xbec40046,0x60d818c0,0x9324007b,0x51e000e5}},	//   аңыз_, artm, _جران, _نقشے, 
   {{0x7e7401c6,0x00000000,0x00000000,0x00000000}},	//   gozp, --, --, --, 
   {{0x9d40c93a,0xa0183720,0x6f14c93b,0x5f4001b9}},	//   берд, rmör, _wryc, لچیل, 
   {{0x6f14c93c,0x7c645026,0x409402d5,0xa0189632}},	//   _tryc, لاقل, _крыт, smör, 
   {{0xea8873e6,0x3a300306,0x6f1419b3,0x7c980395}},	// [109e0] ебал_, _bozp_, _uryc, търс_, 
   {{0x31d40154,0xceb403b9,0xa018007c,0x00000000}},	//   ত্রশ, _itə_, lmöp, --, 
   {{0x291c3421,0xed58c93d,0x00000000,0x00000000}},	//   _štab_, _чон_, --, --, 
   {{0xa6c80139,0x00000000,0x00000000,0x00000000}},	//   елда_, --, --, --, 
   {{0x6018023a,0xa0180e78,0x1ae00117,0x00000000}},	//   _hämä, llöc, _лоям, --, 
   {{0x6440c93e,0x6ec400ab,0x60180958,0x00000000}},	//   _sloi, ़ीयु, _kämä, --, 
   {{0x6440084c,0x60181611,0xa018002f,0x3978014b}},	//   _ploi, _jämä, nlöc, _астю_, 
   {{0xdb1c011f,0x2908058a,0xb508547d,0x60180166}},	//   laqá, _isba_, विजय_, _mämä, 
   {{0x38540c04,0x052400bd,0xe52402dd,0xa7640114}},	//   _търс, বনের_, _әдеп, _скад, 
   {{0x27e4c93f,0x64a4c940,0x00000000,0x00000000}},	//   lgon_, _бажа, --, --, 
   {{0x6018c941,0xc1e801d5,0x65c4014b,0x6d580419}},	//   _nämä, _یکدل_, _абҷа, útal, 
   {{0x27e4c942,0x64403c85,0x645c004e,0x00c800d1}},	//   ngon_, _uloi, èpid, нлүк_, 
   {{0x27e4c943,0x63a0c944,0x93c80014,0x00000000}},	//   igon_, _igon, _سانہ_, --, 
   {{0x539805e1,0xc694008f,0x2908014f,0xb7bc0356}},	//   _ניגו, יאָ_, _osba_, _inţe, 
   {{0x63a099df,0x27e401ee,0x60180724,0x7e743e91}},	//   _kgon, kgon_, _cämä, rozp, 
   {{0x1db400dc,0x63a000d8,0x60180139,0x00000000}},	//   _अभवत, _jgon, _dämä, --, 
   {{0x63a0c611,0xba544c70,0x9e6496c6,0x29080009}},	// [109f0] _mgon, авај, _مادن, _asba_, 
   {{0x27e40115,0xa0180112,0xada000d7,0x00000000}},	//   egon_, blöc, čúce, --, 
   {{0x63a0c945,0x9e6400aa,0xdd980724,0x3eb800e2}},	//   _ogon, _ټاکن, _яши_, lpst_, 
   {{0x27e4c946,0xf8c801e1,0x3eb801a4,0x97c4c947}},	//   ggon_, _aréè_, opst_, اتام, 
   {{0x7c2cc948,0x09cc0183,0xb5c49e1b,0x1ae000fe}},	//   mjar, ৰ্ধা, айлл, _নৈৰা, 
   {{0xe734c949,0x27e4005a,0x7afc127b,0x60180166}},	//   реш_, agon_, _ipst, _yämä, 
   {{0xce380302,0xc984c94a,0x60180166,0x00000000}},	//   ראות_, _гути, _xämä, --, 
   {{0x7afc089c,0x78b403ac,0x00000000,0x00000000}},	//   _kpst, _itzv, --, --, 
   {{0x7c2cc94b,0xf9a80248,0xe430007b,0xf69800f3}},	//   ijar, _gbèè_, تفيد, _авај_, 
   {{0x63a0c94c,0x7c2cc94d,0x323451e8,0x00000000}},	//   _egon, hjar, рхис, --, 
   {{0x7c2cc94e,0xd5640261,0x7afc0175,0x4918000d}},	//   kjar, _стап, _lpst, फियो_, 
   {{0x63a004ba,0x7c2cc94f,0xdd2c012c,0x846402e8}},	//   _ggon, jjar, _běže, _лъче, 
   {{0x6018372c,0x00000000,0x00000000,0x00000000}},	//   _sämä, --, --, --, 
   {{0x3f880943,0x60180793,0x7c2c057b,0x6aa40841}},	//   _dzau_, _pämä, ejar, _rukf, 
   {{0x7afc0029,0x7c2c2242,0x27e4c950,0x3178008f}},	//   _apst, fjar, ygon_, _באַד, 
   {{0x7c2c0a6c,0xdb0c0998,0xef18c951,0xa018002f}},	//   gjar, _necó, _ами_, rlöc, 
   {{0x207800c8,0xeb98035b,0x29087da0,0x5ba43be4}},	// [10a00] _באקא, тиа_, _ssba_, ркум_, 
   {{0x6018c952,0x27e4089c,0x7c2cc953,0x7afc0129}},	//   _tämä, wgon_, ajar, _dpst, 
   {{0x7afc0c8c,0x7c2cc954,0xad240116,0x00000000}},	//   _epst, bjar, _ئىجى, --, 
   {{0x27e4089c,0x7afc0175,0x83e401ec,0x0a68030d}},	//   ugon_, _fpst, _ﺍﻋﺎﺳ, ăрти_, 
   {{0xc5f8c955,0x27e4c956,0x6d4cc957,0x580000db}},	//   лға_, rgon_, lzba, زووك, 
   {{0x63a0c958,0xaa44c959,0x27e4c95a,0x966002e8}},	//   _sgon, _тегл, sgon_, окче, 
   {{0x6d4c0007,0x2908356c,0x00000000,0x00000000}},	//   nzba, _usba_, --, --, 
   {{0x3eb8002d,0x18a01a92,0x83980092,0x00000000}},	//   ypst_, _фатм, _መታወቅ_, --, 
   {{0xdc34008f,0x6d5800d7,0x00000000,0x00000000}},	//   שאפט_, útaj, --, --, 
   {{0x7c2c7b11,0xb060005b,0x00000000,0x00000000}},	//   zjar, ääne, --, --, 
   {{0x63a004cc,0x7c2c01a8,0x00000000,0x00000000}},	//   _tgon, yjar, --, --, 
   {{0x63a0c95b,0x334400d1,0x7c2c058a,0xa1940092}},	//   _ugon, рҗәм_, xjar, _መናፍቅ_, 
   {{0x7c2cc95c,0x84c40075,0x00000000,0x00000000}},	//   vjar, _тәһд, --, --, 
   {{0x66f80a30,0x527001d5,0xdb1c00e4,0xff2400c7}},	//   mākā, _واوز, _êvév, амҭо, 
   {{0x7c2cc95d,0xacd40598,0x7afc010a,0x66f848e1}},	//   tjar, йбрә, _spst, lākā, 
   {{0x3eb80221,0x7c2cc95e,0xdd2c013a,0x00000000}},	//   ppst_, ujar, _těže, --, 
   {{0xdb0cc95f,0x66f84424,0x5e84022e,0x00000000}},	// [10a10] _recó, nākā, _вунз, --, 
   {{0x84f800bc,0x00000000,0x00000000,0x00000000}},	//   ूबाट_, --, --, --, 
   {{0x2df42832,0x9e64c960,0x7c2c0054,0x3ea8c961}},	//   _آپر, _ماگن, pjar, _huat_, 
   {{0x3ea84aa5,0xc8643304,0xdb0c0ba1,0xad180375}},	//   _kuat_, отчи, _decò, _עורר, 
   {{0x7bccc962,0x3ea801c4,0xf3f80311,0x7afcc963}},	//   maau, _juat_, niţe_, _upst, 
   {{0x3ea887f2,0x4b240075,0x7bcc04c9,0xba4401ed}},	//   _muat_, _بېكە, laau, _انسٹ, 
   {{0x3ea8c964,0xdb0c030a,0xdb0400b5,0xd7e40212}},	//   _luat_, _tecó, ømæs, _візо, 
   {{0x7bccc965,0x3ea0c966,0x27600092,0x00000000}},	//   naau, _liht_, ቋቋመበ, --, 
   {{0x66f800e2,0xd76000e5,0xe8f80354,0x1bec0037}},	//   gākā, _بچای, _илӳ_, _छानल_, 
   {{0xb8080154,0x7bccc967,0x00000000,0x00000000}},	//   _রচিত_, haau, --, --, 
   {{0x1ab0015b,0xdb1c0166,0x00000000,0x00000000}},	//   টওয়া, laqä, --, --, 
   {{0x3ea85589,0xd928044e,0x66f800e2,0x96a800bc}},	//   _buat_, _ተጋዳላ, bākā, _चढाउ, 
   {{0xdb1c0054,0x2290030f,0x332806be,0x7bcc02d2}},	//   naqä, تلیس, _çax_, daau, 
   {{0x6d4c3262,0xccf8036b,0x3b08378b,0x3ea8c968}},	//   tzba, ақо_, dwaq_, _duat_, 
   {{0x3204c969,0x7bccc96a,0x6d4c2223,0x00000000}},	//   mely_, faau, uzba, --, 
   {{0x3204c96b,0x6d4cc96c,0xdb0cc96d,0x81680131}},	//   lely_, rzba, _recò, _әрәб_, 
   {{0x256c006a,0x2bec00dc,0x6d4cc96e,0x6fbc07d0}},	// [10a20] _kölï_, ङ्गं_, szba, _व्यू, 
   {{0x78a80b4b,0x3ea00e04,0x3204789b,0x2ba800ab}},	//   _čevr, _giht_, nely_, _कलवा, 
   {{0x397802d5,0x7bcc0254,0x00000000,0x00000000}},	//   асцю_, baau, --, --, 
   {{0x3204c96f,0x69c40406,0xc0ac00df,0x00000000}},	//   hely_, िरही, דיאָ, --, 
   {{0x3204c970,0x3ea801fb,0xa01801e3,0xbad40064}},	//   kely_, _xuat_, klön, _міры, 
   {{0x32040170,0xb7bc054e,0x00000000,0x00000000}},	//   jely_, _pnţc, --, --, 
   {{0x3204789b,0xcfe000cc,0x00000000,0x00000000}},	//   dely_, য্যন, --, --, 
   {{0x66f81991,0xb06000c5,0x9d18010f,0x82d8030d}},	//   tākā, ääle, רוקט, адис_, 
   {{0x3204123b,0xe2a80014,0x00000000,0x00000000}},	//   fely_, دابن_, --, --, 
   {{0x66f8198e,0x3ea826fc,0xdef80220,0xd6cc00c6}},	//   rākā, _ruat_, қым_, _أقل_, 
   {{0x3ea8c971,0x95b400c7,0x645c00e5,0xdb1c06be}},	//   _suat_, _ыртә, épis, paqç, 
   {{0x3ea8020c,0xe048036b,0xf3f8054e,0x6044030d}},	//   _puat_, اشده_, tiţe_, схоз, 
   {{0x3ea8c972,0xa3e80124,0x3204219b,0x3ea0062c}},	//   _quat_, _адҵа_, bely_, _piht_, 
   {{0x3de00183,0x3204c973,0x7bcc002e,0xf3f8054e}},	//   ম্নল, cely_, waau, riţe_, 
   {{0x7bccc974,0x3b08031c,0xd1c400d8,0x9c4401a9}},	//   taau, wwaq_, _улје_, бхал, 
   {{0x3ea8251c,0x225c0100,0x00000000,0x00000000}},	//   _tuat_, litk_, --, --, 
   {{0x0ab8c975,0xdef82dfa,0xdde801d5,0x5eb000cc}},	// [10a30] مطلب_, _сый_, _یرگه_, _জিকে, 
   {{0x9e6403e6,0x00000000,0x00000000,0x00000000}},	//   _دابن, --, --, --, 
   {{0x3b08009a,0x00000000,0x00000000,0x00000000}},	//   swaq_, --, --, --, 
   {{0xb90008a3,0x32049119,0x37f8013d,0x00000000}},	//   _दि_, zely_, редэ_, --, 
   {{0xd6d8b6c2,0xb06402f6,0x1dbcc976,0x3b080327}},	//   уте_, ltää, ्रपत, qwaq_, 
   {{0x95c80228,0xe8ec00ec,0xd1dc01f3,0x36680798}},	//   ууда_, _ڄڻن_, ናቆት_, јако_, 
   {{0xb064049b,0x3204c977,0xb6c801ed,0xa01801e3}},	//   ntää, vely_, _چائے_, vlön, 
   {{0x76c0010e,0x3204015d,0xb0640108,0x6d5801e7}},	//   _aňyň, wely_, itää, útai, 
   {{0x32048a83,0xb064005b,0x4734c978,0x00000000}},	//   tely_, htää, _ентс, --, 
   {{0xf1a40228,0x386cc346,0x9f580429,0x22906ac4}},	//   өрүн, _hjer_, _laqó_, وليس, 
   {{0x386c0f72,0xa0180008,0x32045ff1,0xe4300066}},	//   _kjer_, rlön, rely_, سفید, 
   {{0x3204c979,0x00000000,0x00000000,0x00000000}},	//   sely_, --, --, --, 
   {{0x32040122,0x386cc97a,0x01c80154,0x00000000}},	//   pely_, _mjer_, _শারদ, --, 
   {{0xa018005b,0x32640014,0x00000000,0x00000000}},	//   llöl, _گنڈہ, --, --, 
   {{0x2d9c0598,0xf3f8084c,0x518401c0,0x229001e2}},	//   äte_, enţi_, _ууда, _تلوس, 
   {{0x2ee4c97b,0xed5802f4,0x386c036e,0xac8400d4}},	//   _джиг, гоҳ_, _njer_, ігал, 
   {{0xa0980a1e,0xab64030d,0x6b640798,0x00000000}},	// [10a40] _דיקט, цвал, цкаа, --, 
   {{0x386cc97c,0x5e5400c6,0xadec000d,0x46e00037}},	//   _ajer_, _وليس_, _जािन_, _निबह, 
   {{0xda180c2e,0xe7a84727,0xf3f80356,0x386c036e}},	//   _नफरत_, авел_, anţi_, _bjer_, 
   {{0x225c0427,0x00000000,0x00000000,0x00000000}},	//   zitk_, --, --, --, 
   {{0x386c0066,0x98a000c7,0x00000000,0x00000000}},	//   _djer_, фице, --, --, 
   {{0x386c019b,0xa0180793,0x7ae8143a,0x1dbc00dc}},	//   _ejer_, elöl, _åeta, ्रयत, 
   {{0xdb040008,0x386c00b5,0x00000000,0x00000000}},	//   élög, _fjer_, --, --, 
   {{0x386c0c58,0x66e4c97d,0x9cd40375,0x98880014}},	//   _gjer_, _моба, קופה_, _نحقہ_, 
   {{0x213c00a9,0x225c0194,0xb4e80014,0x1dbc00cd}},	//   wyth_, titk_, لى۪م_, ्रमत, 
   {{0xb06402f6,0x415400d8,0x00000000,0x00000000}},	//   ytää, звос, --, --, 
   {{0x2cb8009a,0x8078004e,0x00000000,0x00000000}},	//   _ntpd_, йбос_, --, --, 
   {{0x213cc97e,0x64a801ef,0x56b801e1,0x00000000}},	//   ryth_, _přif, _ẹ̀ẹ̀, --, 
   {{0x213c03cb,0x8af003e3,0x00000000,0x00000000}},	//   syth_, nzəd, --, --, 
   {{0x3f840029,0x20540046,0xb06402f6,0xb8fc031c}},	//   ālu_, стүр, ttää, _ལྗ_, 
   {{0xa3dc0b7c,0xf3f8054e,0x91b8011a,0xa01801f4}},	//   _तया_, liţa_, _דמוי, llöm, 
   {{0x8cdc0d0a,0x1bb800c6,0xb064005b,0x00000000}},	//   _फिरो, شارع_, rtää, --, 
   {{0xb064049b,0x3b541ca9,0xdce447af,0xf3f80276}},	// [10a50] stää, чкар, ğlıd, niţa_, 
   {{0x53980375,0xca74009f,0x386c02d2,0xd9e00154}},	//   שימו, والغ, _sjer_, ন্নম, 
   {{0x386cc97f,0xa0180036,0xf3f80356,0x00000000}},	//   _pjer_, hlöm, hiţa_, --, 
   {{0x68300022,0x00000000,0x00000000,0x00000000}},	//   нҭст, --, --, --, 
   {{0x2b50033f,0x58b8a822,0x6d58c980,0xaae000e1}},	//   czyc_, _چارج_, útav, _पियक, 
   {{0xdb0c01b8,0xc1780006,0xc0f002d3,0xf3f80356}},	//   _becö, ngės_, ቃለስ_, diţa_, 
   {{0xe5a098c1,0x386c0240,0xb060005b,0xc1780153}},	//   ниши, _tjer_, ääke, igės_, 
   {{0x98482678,0xf42801f0,0xdb200241,0x00000000}},	//   _тяга_, соил_, _àról, --, 
   {{0xa0180267,0xdc2c0790,0x00000000,0x00000000}},	//   glöm, zığs, --, --, 
   {{0x460c025c,0x64a8013a,0xb4b800ec,0xf674009d}},	//   _གྲྭས_, _břid, _هُئا_, _эгзэ, 
   {{0x32180118,0xa01801f4,0x00000000,0x00000000}},	//   ěsy_, lmöy, --, --, 
   {{0xcf9400ee,0xf3f80356,0xa01801f4,0x00000000}},	//   дыгө, biţa_, llöj, --, 
   {{0xada4c981,0x3dd0009a,0x04540137,0x6da402a9}},	//   загл, fazw_, _تئلد, зига, 
   {{0xc21c0085,0x387c0009,0xad9800a2,0x00000000}},	//   ngɔ́_, howr_, leºi, --, 
   {{0x216403c5,0x823401e2,0x00000000,0x00000000}},	//   _ниши_, _ترنا, --, --, 
   {{0xadec0037,0x00000000,0x00000000,0x00000000}},	//   _जावन_, --, --, --, 
   {{0xaa4406ed,0x387c0175,0x6e9411dc,0xa018007c}},	// [10a60] пеал, dowr_, _ىلعا, klöj, 
   {{0x2b50012d,0x69942b2e,0x7adc01f9,0x00000000}},	//   rzyc_, прех, _पिरॅ, --, 
   {{0xe8f849f3,0x853c0064,0x2b50012d,0x00000000}},	//   сле_, _egėj, szyc_, --, 
   {{0xa3e8000b,0x00000000,0x00000000,0x00000000}},	//   _टाइप_, --, --, --, 
   {{0xdd8c021a,0xd614004b,0x98840023,0xa018007c}},	//   _لوی_, ړتيا_, _ዝኣምኑ_, flöj, 
   {{0xf3f80311,0x76a802bf,0x00000000,0x00000000}},	//   viţa_, ітів_, --, --, 
   {{0x69ccc982,0xd9d002dd,0xd8840014,0x00000000}},	//   _iebe, _سەنگ, _کھلن_, --, 
   {{0x69ccc983,0xf3f80311,0x387c062c,0xc1780153}},	//   _hebe, tiţa_, cowr_, zgės_, 
   {{0x69ccc984,0x2284c985,0xfd4c00a2,0x6b8400a2}},	//   _kebe, зунг, _belỳ, _jykg, 
   {{0x64a8038e,0x69ccc986,0xf3f80276,0x6b840fac}},	//   _přid, _jebe, riţa_, _mykg, 
   {{0x69ccc987,0x55b80375,0x2164036b,0x50f00276}},	//   _mebe, _המבו, ятиг, нзэт, 
   {{0x386c0115,0x66080009,0xb40401a9,0x00000000}},	//   _ĉerk_, lefk, _жўшқ, --, 
   {{0x69ccc988,0x7ae801e4,0x7654013d,0xa01802f7}},	//   _oebe, _ĥeto, _äfyü, llök, 
   {{0x69ccc989,0x6264c98a,0xbeec1fd5,0x9f4800d2}},	//   _nebe, _عاشق, _जमीन_, ngcé_, 
   {{0xc1780024,0xd214011a,0x51f8011a,0x64a801ef}},	//   rgės_, _זקוק_, _ההוצ, _hřib, 
   {{0x69cc01c0,0x629815c0,0x00000000,0x00000000}},	//   _aebe, lmto, --, --, 
   {{0x69ccc98b,0xa3e81b87,0x2008c98c,0x7a38009b}},	// [10a70] _bebe, _टाईप_, meci_, опар_, 
   {{0x19a8c98d,0x2008c98e,0x69d805da,0x6b84010b}},	//   стап_, leci_, _ôtel, _dykg, 
   {{0x69ccc98f,0x17683c1a,0x5884010b,0xecb001af}},	//   _debe, әреп_, пыда, _аҡсы, 
   {{0x69ccc990,0x20089736,0x59c8012c,0xa018007c}},	//   _eebe, neci_, िरहर, dlök, 
   {{0x2008003a,0x64940150,0x00000000,0x00000000}},	//   ieci_, _ﺗﺎﭘﭙ, --, --, 
   {{0x69ccc991,0x1dbc0882,0xc7c404a9,0x7958014b}},	//   _gebe, ्रित, _үсти, _дигр_, 
   {{0x3b400201,0x200801f1,0x1ca8031c,0x98141075}},	//   _የመጀመ, keci_, _པངས_, _ىبرا, 
   {{0x20081f7f,0xa018049f,0xdefc003d,0x00000000}},	//   jeci_, slöj, ċċji_, --, 
   {{0x2008c992,0x1dbc53b7,0x69cc013b,0xd2400022}},	//   deci_, ्रात, _yebe, емпқ, 
   {{0x69ccc993,0xc0c402d3,0xc0f0001f,0xb144c994}},	//   _xebe, _ጸሊም_, ቃለሁ_, днол, 
   {{0x20081570,0xafe407d6,0x00000000,0x00000000}},	//   feci_, монл, --, --, 
   {{0x04c800f1,0x00000000,0x00000000,0x00000000}},	//   _روهي_, --, --, --, 
   {{0xe1eca2ae,0x7d0403ac,0x99800024,0xd34402f2}},	//   _иг_, _aphs, _kojų_, _ریده_, 
   {{0x7bdc1730,0xce340271,0x28cc01f9,0x00000000}},	//   _adsu, روزک, हीडि, --, 
   {{0x2008c995,0x69ccc996,0x51940408,0xe2940166}},	//   beci_, _rebe, _хăва, _юаш_, 
   {{0x69ccc997,0xdd8cc998,0x2008c999,0x00000000}},	//   _sebe, شوق_, ceci_, --, 
   {{0x69ccc99a,0x00000000,0x00000000,0x00000000}},	// [10a80] _pebe, --, --, --, 
   {{0x291c0ad9,0xdb0c00d8,0x1e8000c7,0x69cc5043}},	//   _átak_, _recô, _илым, _qebe, 
   {{0xa908bd5e,0xbb7401f0,0x00000000,0x00000000}},	//   تيال_, _ҷуръ, --, --, 
   {{0x66e4c99b,0x6d600b45,0xe7841188,0x58740014}},	//   дода, _ƙwaƙ, муло, وٝلس_, 
   {{0x69ccc99c,0x09cc00fe,0x273400cf,0x6298c99d}},	//   _tebe, ৰ্গা, بىشس, ymto, 
   {{0x69ccc99e,0xa0180267,0x2008c99f,0x27f0033f}},	//   _uebe, tlök, zeci_, żyn_, 
   {{0x200803e0,0x00000000,0x00000000,0x00000000}},	//   yeci_, --, --, --, 
   {{0x64a80316,0xd9e00011,0xa018007c,0x9f5c0241}},	//   _přib, ন্দম, rlök, _ńrín_, 
   {{0x2008c9a0,0x6298022f,0x64a800bc,0x69a00073}},	//   veci_, tmto, _břic, _कृती, 
   {{0x62980de2,0x00000000,0x00000000,0x00000000}},	//   umto, --, --, --, 
   {{0xa01802f6,0x66e4013e,0x62981141,0xd8000356}},	//   llöi, _хоҷа, rmto, sfăţ_, 
   {{0x630401e2,0x2328014b,0x00000000,0x00000000}},	//   _يوال, _моеи_, --, --, 
   {{0x2008c9a1,0x718000c7,0x00000000,0x00000000}},	//   reci_, кқәе, --, --, 
   {{0x20081326,0xe3f40451,0xe7cc00d1,0x00000000}},	//   seci_, _روڪڻ_, _ﻗﯩﺰﻟ, --, 
   {{0x2008036e,0x3a2c004d,0x00000000,0x00000000}},	//   peci_, _đep_, --, --, 
   {{0xfc1401c0,0xbab82401,0xbed801af,0x7f94341e}},	//   эмбэ, згах_, _едих_, _пайх, 
   {{0x4ba80228,0xceb403e3,0x6d58c9a2,0x00000000}},	// [10a90] дөрү_, _asəf_, útar, --, 
   {{0x3f8823e0,0xdb200241,0x00000000,0x00000000}},	//   _iyau_, _òrím, --, --, 
   {{0x44cc033f,0x998000c0,0x00000000,0x00000000}},	//   jś_, _rojų_, --, --, 
   {{0x3f8823db,0x7798516c,0x7bdc005c,0x99800153}},	//   _kyau_, пкер_, _udsu, _sojų_, 
   {{0x7c3c07f0,0xa3d001ad,0x44cc0210,0x00000000}},	//   _iosr, वरन_, eś_, --, 
   {{0x7aecc9a3,0x46e061f2,0x3f880165,0x7c3c00a2}},	//   muat, _निरह, _myau_, _hosr, 
   {{0xd874c9a4,0xc984262e,0x7aeca9b8,0x82b801f2}},	//   _قارب, _аути, luat, _rịịl_, 
   {{0x97240408,0x69c80174,0x00000000,0x00000000}},	//   _оьзд, ðfev, --, --, 
   {{0x7aecc9a5,0x3f88c9a6,0x64a8012c,0x7c3c0240}},	//   nuat, _nyau_, _přic, _mosr, 
   {{0x78a80493,0xd24007d6,0x291c0006,0xb1d81064}},	//   _hiev, тмоқ, _štai_, чьих_, 
   {{0x78a8c9a7,0x7aecc9a8,0x75200354,0x3f8802a8}},	//   _kiev, huat, _urlz, _ayau_, 
   {{0x7c3c0ffb,0x71781669,0x00000000,0x00000000}},	//   _nosr, жбүр_, --, --, 
   {{0x7aecc9a9,0x78a8c9aa,0x64a800bc,0x7f18c9ab}},	//   juat, _miev, _třic, міру_, 
   {{0x78a8c9ac,0xec14006c,0xf4200154,0xdca001ec}},	//   _liev, کورد, _ফকির_, ғауи, 
   {{0x7c3c0373,0x64440267,0x3b5c0092,0x00000000}},	//   _bosr, ökig, _ለመጨመ, --, 
   {{0x7aecc9ad,0x78a8c9ae,0x7c3c026c,0xa018005b}},	//   fuat, _niev, _cosr, ylöi, 
   {{0x7aecc9af,0xadec0574,0x7c3cc9b0,0x00000000}},	// [10aa0] guat, _जाऊन_, _dosr, --, 
   {{0x9b900597,0xd9e00154,0xb5e400eb,0x00000000}},	//   الكت, ন্সম, প্তচ, --, 
   {{0xbd0402ea,0xd940170a,0x78a801c7,0x7d080356}},	//   riéé, лефи, _biev, ăesc, 
   {{0x6e3cc9b1,0x78a80030,0x00000000,0x00000000}},	//   _hopb, _ciev, --, --, 
   {{0x7aecc9b2,0x3f880218,0x6e3cc9b3,0x691c0055}},	//   cuat, _xyau_, _kopb, _ṣedh, 
   {{0x6e3c0477,0x2fd00162,0x09cc03d4,0xc44802f2}},	//   _jopb, _leyg_, ৰ্জা, ژیان_, 
   {{0x291c1dd4,0x78a8c9b4,0x7c3c2a1f,0x59041188}},	//   _éta_, _fiev, _yosr, _перм_, 
   {{0x98a0c9b5,0x18a08dc7,0x78a8c9b6,0x6e3c9407}},	//   _бисе, _басм, _giev, _lopb, 
   {{0x0edc2871,0x6e3c0ea0,0xa6c80271,0xc2741d39}},	//   _बिगड, _oopb, _روال_, клиј, 
   {{0x78a807de,0x6e3c047e,0xd6cc007b,0x00000000}},	//   _ziev, _nopb, _طقم_, --, 
   {{0x7aec005a,0xba080023,0x00000000,0x00000000}},	//   zuat, _ወዳ_, --, --, 
   {{0x6618c9b7,0xadec0073,0x7aecc9b8,0x1bec000d}},	//   _hatk, _जाउन_, yuat, _छाइल_, 
   {{0x66181dda,0x248401f2,0x6e3cc9b9,0xe36400c2}},	//   _katk, _ikom_, _bopb, _якди, 
   {{0x66180664,0x6e3c0007,0x7c3cc9ba,0x7aec0a73}},	//   _jatk, _copb, _sosr, vuat, 
   {{0x6618c9bb,0x7c3c341a,0x3f8803cb,0x6d5803b2}},	//   _matk, _posr, _wyau_, útap, 
   {{0x7aecc9bc,0x6618c9bd,0x7c3ca30f,0x00000000}},	//   tuat, _latk, _qosr, --, 
   {{0x7c3c070d,0x78a8c9be,0x428c0092,0xca4801b9}},	// [10ab0] _vosr, _riev, _ፕሪንት_, کلله_, 
   {{0x78a8c9bf,0x7aecc9c0,0x6618463d,0x2018036b}},	//   _siev, ruat, _natk, _haqi_, 
   {{0x78a8c9c1,0x7aec15a5,0x3d94020a,0x1278010f}},	//   _piev, suat, _шиор, לאמע, 
   {{0x20180bc9,0x7aecc9c2,0x7d000311,0x8c441fbe}},	//   _jaqi_, puat, gârţ, _беџе, 
   {{0xdb04c9c3,0x6618c9c4,0x78a82e70,0x7aecc9c5}},	//   ämäs, _batk, _viev, quat, 
   {{0x8d74c9c6,0x60d82d75,0x78a80730,0x66180072}},	//   _جاۋا, kstm, _wiev, _catk, 
   {{0x78a8c9c7,0x60d86864,0x661815c0,0x00000000}},	//   _tiev, jstm, _datk, --, 
   {{0x5884c9c8,0x201801a9,0x00000000,0x00000000}},	//   _чыга, _naqi_, --, --, 
   {{0xe72c168d,0x24840066,0x661802d3,0x60d800de}},	//   _وڵه_, _dkom_, _fatk, estm, 
   {{0xc30430bf,0x0708004b,0x66180af9,0x31240fc0}},	//   ابيو, _سيمي_, _gatk, вдог, 
   {{0x2018c9c9,0x6e3c0455,0x850402cb,0x00000000}},	//   _baqi_, _ropb, _مولن, --, 
   {{0xa3d03806,0x6618c9ca,0x6e3c047e,0x64a80118}},	//   वरण_, _zatk, _sopb, _třia, 
   {{0x6618c9cb,0x6e3c496c,0x60d8000d,0x64440108}},	//   _yatk, _popb, astm, ökie, 
   {{0xccc857aa,0x6e3c047e,0xa2e001d5,0x66180139}},	//   нғол_, _qopb, _тошд, _xatk, 
   {{0xfd780032,0x2018058a,0x00000000,0x00000000}},	//   естъ_, _faqi_, --, --, 
   {{0x3ce41bd1,0xc0f00023,0x68f800a2,0xab280117}},	//   álva_, ዃኖም_, _ätdi, моба_, 
   {{0x6e3cc9cc,0xdbdc01e1,0x5ca01246,0xa3d02072}},	// [10ac0] _topb, _gííw, ритб, वरत_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6618049b,0xdfcc01ec,0xa018c9cd,0x6d5801ab}},	//   _ratk, _ايۋ_, rlöv, ùtad, 
   {{0x6618c9ce,0x6b64c9cf,0x9cd40375,0xa018007c}},	//   _satk, _акма, _בוטה_, slöv, 
   {{0x69c809cc,0xd6cc07d6,0xa7303ad0,0xa01801e3}},	//   ðfes, ققن_, рдлә, plöv, 
   {{0x60d8002d,0x2484c9d0,0xa01802fc,0x00000000}},	//   ystm, _skom_, llöt, --, 
   {{0x7ae801e4,0x6618005b,0x64a8013a,0x19d001ec}},	//   _ĥeti, _vatk, _dřin, _ﺟﯘﻧﺠ, 
   {{0x4394c9d1,0xa018002f,0x00000000,0x00000000}},	//   лайс, nlöt, --, --, 
   {{0x6618c9d2,0x160002ab,0x18640798,0x20180200}},	//   _tatk, _शॉवर_, _рати_, _raqi_, 
   {{0x26c4c9d3,0x2018102c,0x4254c9d4,0x6720c9d5}},	//   mpoo_, _saqi_, اندر, mvoj, 
   {{0x6720c9d6,0xa018002f,0xe3e001ec,0x00000000}},	//   lvoj, klöt, _көпқ, --, 
   {{0x201819a2,0x60d842be,0xf3640046,0x2484020c}},	//   _qaqi_, rstm, _өтін, _ukom_, 
   {{0x6720c9d7,0x657801ab,0x69a001f9,0x00000000}},	//   nvoj, _hxth, केती, --, 
   {{0x52d40302,0x20180a2e,0xc694008f,0x3fc4009e}},	//   _יודע_, _waqi_, טאָ_, ্লেষ, 
   {{0x20181269,0x3a7407d6,0xd12c1056,0x6720005b}},	//   _taqi_, ҳлар, _ومه_, hvoj, 
   {{0x3f8400ac,0x67200ff8,0x8bc40815,0x5574010f}},	//   ğlub_, kvoj, исуд, דעלן_, 
   {{0x3a74c9d8,0xe2980208,0x0bb4187f,0x00000000}},	// [10ad0] глар, _khư_, рбую, --, 
   {{0x672004b9,0x4a544690,0x9e0400cf,0x8af003b9}},	//   dvoj, акус, _рчил, mzəl, 
   {{0xa3d04802,0x8af000ac,0xab600037,0x2c0c00eb}},	//   वरा_, lzəl, üürn, হাড়ে_, 
   {{0x69c8008c,0xa018893b,0x67200115,0xa8540124}},	//   ðfer, mlös, fvoj, лехә, 
   {{0x64a80316,0xa018c9d9,0x78b00115,0x672001e4}},	//   _přin, llös, _ŝevĉ, gvoj, 
   {{0xe29801dc,0xf3f80276,0x5a4400a8,0x0684109a}},	//   _như_, miţi_, _рэма, агін, 
   {{0x29080048,0xa018687f,0xdb1c0784,0xf3f80311}},	//   _gpba_, nlös, maqñ, liţi_, 
   {{0x05746eb7,0xc9840063,0x35b40124,0x31bc00cd}},	//   جاهد, _ђури, _ӡбар, ोर्ध, 
   {{0xf3f80276,0x78b40099,0x64a800bc,0xa018c9da}},	//   niţi_, _huzv, _třin, hlös, 
   {{0x78b40e8a,0xe29801fb,0xa0185b00,0x00000000}},	//   _kuzv, _chư_, klös, --, 
   {{0xe28cc9db,0x76400175,0xe0d40276,0x00000000}},	//   _ҳа_, _ioly, лвэ_, --, 
   {{0x7640c9dc,0x78b405b8,0x7e6403ac,0xa0180267}},	//   _holy, _muzv, _amhp, dlös, 
   {{0xe28cc9dd,0x64380375,0x7640c9de,0xdb1c0309}},	//   _га_, _רעננ, _koly, kaqñ, 
   {{0xa0180730,0x7640017a,0xb38402d3,0xf3f8054e}},	//   flös, _joly, ዝኸውን_, diţi_, 
   {{0x1d04c5e4,0xed58024d,0xa018c9df,0x7640c9e0}},	//   лери_, хов_, glös, _moly, 
   {{0x26c463b3,0x50a400d1,0x00000000,0x00000000}},	//   ypoo_, _خەجل, --, --, 
   {{0x76400083,0xf3f80356,0xa018002f,0x5f7400ec}},	// [10ae0] _ooly, giţi_, rlöt, _ماٿر, 
   {{0xa9a4c9e1,0xee38030d,0xa018343a,0xdbd4010e}},	//   гизд, _чно_, blös, mäýi, 
   {{0x6994497c,0x30e004c5,0xdbd400a2,0x00000000}},	//   урах, _বহুস, läýi, --, 
   {{0xf3f80311,0xd7f4c9e2,0x672001e4,0x3e6c02f0}},	//   biţi_, гуш_, tvoj, ržte_, 
   {{0x7640c9e3,0xf3f80311,0xd87400d1,0x67200108}},	//   _boly, ciţi_, ھمۇت_, uvoj, 
   {{0x6720c9e4,0x78b40399,0x7640c9e5,0x49a401e0}},	//   rvoj, _fuzv, _coly, _ҡыңғ, 
   {{0x6720c9e6,0x7640c9e7,0x78b408ad,0x7a40012c}},	//   svoj, _doly, _guzv, _dítě, 
   {{0x26c40694,0x672001e4,0x00000000,0x00000000}},	//   ppoo_, pvoj, --, --, 
   {{0x7640066d,0x494c0020,0xdc34008d,0x00000000}},	//   _foly, _በሚቀጥ, ראפט_, --, 
   {{0x76400cfd,0x65780175,0xbbb000bc,0xd48c010a}},	//   _goly, _txth, _झल्क, _ӳр_, 
   {{0xd48cc9e8,0xf3f80311,0x00000000,0x00000000}},	//   _гр_, ziţi_, --, --, 
   {{0x425493f5,0xc3c404b4,0x64a801ef,0x372001f3}},	//   انگر, _төкл, _křim, _ተልእኮ, 
   {{0xe29807ae,0x764000a2,0xa018007c,0xd4c000cf}},	//   _thư_, _yoly, flör, _көөк, 
   {{0x6440c9e9,0xa0185df7,0xf3f80311,0x205415bf}},	//   _hooi, tlös, viţi_, ттүр, 
   {{0x64405282,0xd12cb7b6,0xbc6400c7,0x00000000}},	//   _kooi, _ух_, ахақ, --, 
   {{0x78b40810,0xf3f80276,0xa018687f,0x64400076}},	//   _ruzv, tiţi_, rlös, _jooi, 
   {{0x6440c9ea,0xa018c9eb,0x90980cd2,0x4c940a8f}},	// [10af0] _mooi, slös, _حضور_, ситс, 
   {{0xf3f8084c,0xa0184c98,0x64405880,0x9cc8030d}},	//   riţi_, plös, _looi, _пыма_, 
   {{0x3914c9ec,0x7640c9ed,0xf3f80276,0x64a8012c}},	//   рмер, _roly, siţi_, _přil, 
   {{0x6440292b,0x7640c9ee,0x287401e0,0xdb1c0784}},	//   _nooi, _soly, аҡсы_, saqñ, 
   {{0x7bccc9ef,0x8704c9f0,0x170437f7,0xdb1c0784}},	//   mbau, مبول, افتی_, paqñ, 
   {{0xf6243ce7,0x7aecc9f1,0x7bccc9f2,0x78b49597}},	//   рдко, mrat, lbau, _tuzv, 
   {{0x7640c9f3,0x7a40012c,0x64401368,0x4a5473da}},	//   _voly, _vítě, _booi, _укрс, 
   {{0x7bccc9f4,0x7aecc9f5,0x644002a4,0x62880477}},	//   nbau, orat, _cooi, _akfo, 
   {{0x644002a4,0x7640c9f6,0x00000000,0x00000000}},	//   _dooi, _toly, --, --, 
   {{0x7bcc0399,0x6aac01d4,0x64400076,0xb7bc010e}},	//   hbau, _xibf, _eooi, _baţg, 
   {{0x7aecc9f7,0x64408ff7,0x00000000,0x00000000}},	//   hrat, _fooi, --, --, 
   {{0x64400a5c,0x62880115,0xe538011a,0x00000000}},	//   _gooi, _ekfo, _בתער, --, 
   {{0x628803c1,0x7bcc0007,0xe3ac1eed,0x7aecc9f8}},	//   _fkfo, dbau, _фб_, jrat, 
   {{0x7aecc9f9,0x644001f5,0x6cc4b42d,0xace801a9}},	//   drat, _zooi, ийга, кмга_, 
   {{0x7aec01a2,0x3a200882,0x7bcc03fa,0xabd40640}},	//   erat, ddhp_, fbau, ицај, 
   {{0x7bccc9fa,0x644006af,0xeb9801b9,0x7c6400d1}},	//   gbau, _xooi, виб_, ماقل, 
   {{0x8d600092,0x00000000,0x00000000,0x00000000}},	// [10b00] ደላቸው_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe8f80b65,0x7aecc9fb,0x7bcc08a1,0x24480241}},	//   тле_, arat, bbau, _wùmi_, 
   {{0x64a800bc,0xa018007c,0x7b0403b2,0x00000000}},	//   _přim, nlöp, óttø, --, 
   {{0x6440c9fc,0x00000000,0x00000000,0x00000000}},	//   _rooi, --, --, --, 
   {{0x64401368,0xf7e801ec,0x24e4011c,0x00000000}},	//   _sooi, _ەرلى_, ациг, --, 
   {{0x64403a11,0xb7bc00a2,0xa3d005dc,0x32040072}},	//   _pooi, _baţd, वरल_, dfly_, 
   {{0x32049337,0x00000000,0x00000000,0x00000000}},	//   efly_, --, --, --, 
   {{0x54400150,0xe6185f18,0x64401368,0x7ae803cd}},	//   تنيك, _ида_, _vooi, _åett, 
   {{0x1660c9fd,0x7bcc0399,0x6440c9fe,0x64a8013a}},	//   _двум, zbau, _wooi, _křik, 
   {{0x7aecc9ff,0x7bcc0006,0x64400731,0x00000000}},	//   zrat, ybau, _tooi, --, 
   {{0x7aecca00,0xa0180793,0x7bcc0113,0x00000000}},	//   yrat, glöp, xbau, --, 
   {{0x7bcc002f,0x7aecca01,0x3e6c00c0,0x00000000}},	//   vbau, xrat, ežta_, --, 
   {{0x7aec39e2,0x62880175,0x5398010f,0x201c0153}},	//   vrat, _ukfo, _סיגו, žui_, 
   {{0x7aecca02,0x7bcc0e78,0xbb5800b5,0xb7bc054e}},	//   wrat, tbau, dのap, _haţe, 
   {{0xebc000d1,0x00000000,0x00000000,0x00000000}},	//   зәрн, --, --, --, 
   {{0x7bccca03,0x64a80316,0x291c0552,0x2ff410e0}},	// [10b10] rbau, _přij, _štap_, _اتىڭ, 
   {{0x7bccca04,0x7aecca05,0xbe1416ac,0xdd84ca06}},	//   sbau, rrat, _اودع, _вымп, 
   {{0x19a81c3e,0x00000000,0x00000000,0x00000000}},	//   ттап_, --, --, --, 
   {{0x7aecca07,0xf758011c,0xd7e4003b,0x7bcc03b9}},	//   prat, лаещ_, ріжо, qbau, 
   {{0x3204784d,0xb0640108,0x00000000,0x00000000}},	//   yfly_, luää, --, --, 
   {{0x64440037,0xe734ca08,0xcfc801ec,0x00000000}},	//   ökin, сеш_, _ﺒﺘﻁﺒ, --, 
   {{0x3b5c0020,0xa3d000dc,0x853401b9,0x27880139}},	//   _ለመጀመ, वरं_, قووچ, крәү_, 
   {{0xfd5401f2,0x32040076,0x24900092,0x23a80248}},	//   _slaị, wfly_, _ምኅረት_, _ẹja_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x32340131,0x8b58011a,0x5f280092,0x00000000}},	//   схис, ייחס_, _ስላላቸ, --, 
   {{0xf5940491,0xa6e0022c,0x708400db,0x00000000}},	//   _الاج, _øðrv, йгоз, --, 
   {{0xa3d00882,0xb7bc0356,0xed580b01,0x00000000}},	//   वरः_, _faţe, қоб_, --, 
   {{0x6400129e,0xa018007c,0x00000000,0x00000000}},	//   _رژيم, rlöp, --, --, 
   {{0xceb824ce,0xf3f8054e,0xddc0a30d,0x00000000}},	//   ләү_, riţu_, збри, --, 
   {{0xb144084c,0x00000000,0x00000000,0x00000000}},	//   _ынкл, --, --, --, 
   {{0x2b38084c,0xef1800d8,0x00000000,0x00000000}},	//   лязэ_, _бми_, --, --, 
   {{0xeb9800c7,0x00000000,0x00000000,0x00000000}},	// [10b20] уиа_, --, --, --, 
   {{0x64a8012c,0x00000000,0x00000000,0x00000000}},	//   _přik, --, --, --, 
   {{0xa96800c6,0xbf6400f2,0x00000000,0x00000000}},	//   دمام_, _هدیو, --, --, 
   {{0x6d4cca09,0x00000000,0x00000000,0x00000000}},	//   myba, --, --, --, 
   {{0x6d4cca0a,0xb92002e3,0x1038001f,0x52e000d1}},	//   lyba, _kasị_, _እየተመ, _ﺋﻪﯞﻩ, 
   {{0x64a80118,0x96d400c7,0x00000000,0x00000000}},	//   _třik, ссцә, --, --, 
   {{0x69dcca0b,0xb92001f2,0x6d4cca0c,0x17d400fe}},	//   mape, _masị_, nyba, _হাৰি, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x18a0013e,0x98a00d6f,0x2c0800dc,0x69dc054e}},	//   _хатм, _хите, ह्यं_, oape, 
   {{0x6d4cca0d,0x5744ca0e,0x6498ca0f,0x00000000}},	//   kyba, _узум_, _өтер_, --, 
   {{0x81b00eac,0x212801e7,0x6d4c00c0,0xa01800a2}},	//   টুন_, íbh_, jyba, loöi, 
   {{0x69dcca10,0xdef80323,0xb2740228,0x6d4cca11}},	//   hape, лыг_, йлөш, dyba, 
   {{0xd9e00154,0x00000000,0x00000000,0x00000000}},	//   ন্টম, --, --, --, 
   {{0x3dd803f4,0x69dcca12,0x6d4c02d0,0x44240205}},	//   _তাহল, jape, fyba, ldm_, 
   {{0x69dcca13,0x64a8038e,0xd12c0323,0x44240280}},	//   dape, _přih, _эх_, odm_, 
   {{0xca740075,0xf1a804d3,0x9174011a,0xb06401f4}},	//   ۋالغ, _ئاهه_, _לעוף_, ruää, 
   {{0x69dcca14,0xb4e4000d,0x3e68179e,0x00000000}},	// [10b30] fape, _भट्_, _نجدی_, --, 
   {{0x69dcca15,0xb92000b4,0x61f803a2,0x00000000}},	//   gape, _gasị_, ngtl, --, 
   {{0x98487e25,0xf8b801c0,0x3ea0003b,0x4424007f}},	//   ляда_, рөг_, _ihht_, kdm_, 
   {{0x69dc0421,0xaae0107c,0x64440108,0x9f5c01e1}},	//   aape, _पिचक, ökil, _ńrùn_, 
   {{0x61f80770,0x69dcca16,0xda780116,0x84d800b8}},	//   kgtl, bape, _бяв_, _āruṇ, 
   {{0x69dc1948,0x3e6c0153,0x00000000,0x00000000}},	//   cape, ižto_, --, --, 
   {{0xea602e51,0xe5a0ca17,0x00000000,0x00000000}},	//   _تۇلپ, миши, --, --, 
   {{0x96f8ca18,0xd6d402a6,0x33440014,0x00000000}},	//   _معطر_, _সমীপ, ٲندِ, --, 
   {{0x767400c7,0x72780276,0x6d4c80c1,0x00000000}},	//   _длаф, исос_, zyba, --, 
   {{0x310800d1,0xb9e00023,0x00000000,0x00000000}},	//   аноп_, _እኵ_, --, --, 
   {{0x9324ca19,0xd6c00014,0x0478036b,0x6d4c0072}},	//   _گران, _بۅڈی, شلیک_, xyba, 
   {{0x69dcca1a,0x4424ca1b,0x80b8015b,0x6d4c0c53}},	//   zape, cdm_, _আবশ্, vyba, 
   {{0x92b47cbc,0x932450a2,0x69dcca1c,0x4374004e}},	//   _احصا, _دران, yape, _нушт, 
   {{0x6d4c9e2a,0xda080c2e,0x69dc005a,0x29180113}},	//   tyba, स्मत_, xape, ywpa_, 
   {{0x69dcca1d,0x00000000,0x00000000,0x00000000}},	//   vape, --, --, --, 
   {{0x69dcca1e,0x6d4cca1f,0x7c2803b2,0x6e300055}},	//   wape, ryba, _óerl, _ṣkār, 
   {{0x69dcca20,0x6d4c010b,0xef180166,0x00000000}},	// [10b40] tape, syba, _тмп_, --, 
   {{0xee080276,0x69940354,0x00000000,0x00000000}},	//   _теол_, орех, --, --, 
   {{0x69dcca21,0xdd0c0365,0xada4036b,0x3eacca22}},	//   rape, mışt, _фанл, ïete_, 
   {{0xdd0ca493,0x69dcca23,0xc18c010f,0x64a801ef}},	//   lışt, sape, נטאָ, _hřiv, 
   {{0xcfbc00bd,0x388c02d3,0x64a800bc,0xa68401c6}},	//   _অজান, _ንኣሽቱ_, _křiv, олдд, 
   {{0xdd0c7bfb,0x69dc01ee,0x00000000,0x00000000}},	//   nışt, qape, --, --, 
   {{0xd5ac24e0,0x1fa4227c,0x787000e4,0x00000000}},	//   نفه_, _गण्ड, ẽvap, --, 
   {{0x3ce4022c,0xb8640736,0x18a003c5,0x3804014b}},	//   álvi_, _فاقو, _жасм, _носҳ, 
   {{0xdd0c05d1,0x44240205,0xdd2c0118,0x00000000}},	//   kışt, rdm_, _měše, --, 
   {{0x4424ca24,0xe5a40276,0x79980113,0x624801c6}},	//   sdm_, _дизи, _ñawñ, рчиг_, 
   {{0xd2544077,0x44240175,0x50f00166,0xdd0c008e}},	//   іць_, pdm_, мзэт, dışt, 
   {{0x99d00115,0x3ea001b9,0xc4342d56,0xbde40150}},	//   _inʈe, _shht_, _رکعت, _ﺍﻨﻘل_, 
   {{0x23740472,0xcfc80150,0xdb040205,0x00000000}},	//   _بااح, _ﺒﺘﻌﺒ, ülüd, --, 
   {{0xb8fc0003,0xdd0c00fd,0xef0c004b,0xe60c02dd}},	//   _རྦ_, gışt, اڼي_, едi_, 
   {{0x9c4400f3,0x16d45c0e,0xe46801e1,0x69c80205}},	//   охал, _डब्ब, _ìjó̟, ıfel, 
   {{0x3cec8e70,0xe04803e6,0x3a2c0166,0x00000000}},	//   čev_, _خشته_, _şep_, --, 
   {{0x7644023a,0xdef850cb,0xdd0c008e,0x00000000}},	// [10b50] öhyk, _тый_, bışt, --, 
   {{0xd928447e,0x00000000,0x00000000,0x00000000}},	//   ицел_, --, --, --, 
   {{0xfea801d9,0x98c40131,0x01bc00eb,0x00000000}},	//   _پُھٹ_, زغان, _আজাদ, --, 
   {{0xb7bc00a2,0x37f8084c,0xe7cc0150,0x00000000}},	//   _baţa, седэ_, _ﺗﯩﺮﻟ, --, 
   {{0x7bdc1730,0xb7bc054e,0x61e802f0,0xb89400e5}},	//   _iesu, _caţa, _odfl, _ہارڈ, 
   {{0x7bdcca25,0xdc101432,0xfebc00eb,0x00000000}},	//   _hesu, _işık, _অবাধ, --, 
   {{0x7bdc5101,0x9814ca26,0x80e000cc,0x00000000}},	//   _kesu, _وبرا, পূত্, --, 
   {{0x4d7c0302,0x61e816b8,0xb7bc054e,0xdd0c236c}},	//   ירוע, _adfl, _faţa, zışt, 
   {{0x76d40597,0x386cca27,0x07400220,0x1dd80073}},	//   _رياض, _imer_, _ﯞﺍﯓ_, भरात, 
   {{0x7bdcca28,0x02640133,0xd6540116,0x00000000}},	//   _lesu, وێنێ, _بئرع, --, 
   {{0x54400075,0x386c020c,0x00000000,0x00000000}},	//   _يۆتك, _kmer_, --, --, 
   {{0x7bdcca29,0xd49801fc,0x61e802d0,0x359002d3}},	//   _nesu, _трз_, _edfl, _ምሕታት_, 
   {{0xdd0c3279,0x64a8012c,0xe1ec1422,0x5280014b}},	//   tışt, _přiv, _пг_, _оҳиб, 
   {{0x7bdc02d0,0xd1b80345,0x00000000,0x00000000}},	//   _aesu, _ئاشا_, --, --, 
   {{0x7bdcca2a,0x386cca2b,0xdd0cca2c,0xdc1062c7}},	//   _besu, _omer_, rışt, _aşık, 
   {{0x7bdcca2d,0xc0cc02d3,0x00000000,0x00000000}},	//   _cesu, ጣኖም_, --, --, 
   {{0x7bdcca2e,0x2d9c0232,0xdd0c03ee,0xab64166f}},	// [10b60] _desu, ťte_, pışt, чвал, 
   {{0xada4ca2f,0x7bdc009a,0xed58ca30,0x00000000}},	//   _напл, _eesu, _гоо_, --, 
   {{0x7bdcca31,0xdd2c01ef,0xba040022,0xb86400e5}},	//   _fesu, _těše, ьҭра_, ڈانو, 
   {{0x7bdcca32,0xb86429e0,0x2b3800a8,0x2aec012d}},	//   _gesu, وانو, _лягэ_, ेंदु_, 
   {{0xbb00c7e0,0x7520022e,0x77900ed8,0xa610008e}},	//   _иҗти, _aslz, نیفا, езлә, 
   {{0x7bdc04c4,0xaa5811dc,0x386cca33,0x00000000}},	//   _zesu, _السا_, _emer_, --, 
   {{0x7bdcca34,0x44f400d4,0x290c0003,0x787000d7}},	//   _yesu, єпис, ħfas_, sťva, 
   {{0x7bdc056a,0x6b280327,0x00000000,0x00000000}},	//   _xesu, _ཤློོ_, --, --, 
   {{0xcfc404c5,0x51640228,0x8af006be,0x3f840205}},	//   ্ণান, үүчү_, mzəs, ğluk_, 
   {{0x3f8451bb,0x386c0427,0x41541d39,0x00000000}},	//   şluk_, _zmer_, двос, --, 
   {{0x386cca35,0xe7dc00fe,0x64a80118,0x00000000}},	//   _ymer_, ডলীয, _břit, --, 
   {{0xdedc0023,0x64a801ef,0xe5a401f0,0x00000000}},	//   _ንኣኻ_, _přiu, _диҷи, --, 
   {{0x1acc00fe,0xa3140408,0x00000000,0x00000000}},	//   িওৱা, _хьеш, --, --, 
   {{0x7bdc5088,0x61e87823,0xad240014,0x00000000}},	//   _sesu, _udfl, ڈرٲو, --, 
   {{0xe1940323,0x7bdcca36,0x91b400c6,0x20c801c8}},	//   _эрдэ, _pesu, _عطور_, _ابتي_, 
   {{0x40a83b7a,0xfad802e8,0x00000000,0x00000000}},	//   _بختی_, ждащ_, --, --, 
   {{0x7bdcca37,0x00000000,0x00000000,0x00000000}},	// [10b70] _vesu, --, --, --, 
   {{0x7bdcca38,0x386cca39,0x37d800fe,0x00000000}},	//   _wesu, _smer_, _ডাইৰ, --, 
   {{0x9964ca3a,0x7bdcca3b,0xe3e0015b,0xd8000408}},	//   чтал, _tesu, _যানব, нăн_, 
   {{0x77980415,0xde540092,0x3ce40162,0x00000000}},	//   окер_, _ያለአግ, álvu_, --, 
   {{0xa3c00e49,0x79940034,0xb6f80131,0x6830022e}},	//   ्डन_, _wyzw, زىغا_, rаdа, 
   {{0x3b080309,0x9a84010a,0x00000000,0x00000000}},	//   mtaq_, _хумл, --, --, 
   {{0xb06401f4,0xc508007b,0x3b08ca3c,0x00000000}},	//   nrää, كتيل_, ltaq_, --, 
   {{0x45180212,0x2ba8000d,0x386c0200,0x00000000}},	//   яція_, चेवा, _umer_, --, 
   {{0x3b08ca3d,0xddc40010,0xb06401f4,0x00000000}},	//   ntaq_, zijš, hrää, --, 
   {{0x81bc005f,0xa018002f,0x00000000,0x00000000}},	//   ldēj, hnöd, --, --, 
   {{0x3554ca3e,0x64a8012c,0x8af000ac,0xbba80037}},	//   _تناز, _přit, nzər, कधुक, 
   {{0x3b0802d1,0x81bc00e2,0x942000db,0x69a00892}},	//   ktaq_, ndēj, _سوتۇ, केटी, 
   {{0xe28c7765,0xafa001b9,0xb8e80327,0xfcf00023}},	//   _аа_, ъқиқ, _ྲང_, ልወጥ_, 
   {{0x6da4ca3f,0xc0cc02d3,0xb0640254,0x00000000}},	//   дига, ኣለም_, frää, --, 
   {{0xed58ca40,0x22903e43,0xc0a8221d,0xa3d00490}},	//   цов_, _جلوس, تایل_, वरच_, 
   {{0xec14ca41,0xdca02097,0x8af000ac,0x00000000}},	//   بورد, васи, yyəd, --, 
   {{0x332c232c,0xc624015b,0x9f800166,0xdcac2374}},	// [10b80] nvex_, পাতা_, _игъд, شىك_, 
   {{0x5de00022,0x387c0042,0x81bc00de,0x00000000}},	//   _ижьа, enwr_, edēj, --, 
   {{0x3ce40579,0x3b080140,0xa8040953,0xa3c00e49}},	//   álvt_, ataq_, дзел, ्डम_, 
   {{0xeabc0034,0xd7ec00c6,0xeac800e5,0x00000000}},	//   _кιи_, لكم_, _وِجٹ_, --, 
   {{0xdd8c3c5b,0xfe9001d9,0x18b000d1,0x00000000}},	//   _موی_, _شیہج, тәрр, --, 
   {{0xa9684daa,0x00000000,0x00000000,0x00000000}},	//   _дига_, --, --, --, 
   {{0xf3f800fe,0x00000000,0x00000000,0x00000000}},	//   ্জনৰ_, --, --, --, 
   {{0x6f14127b,0xd494ca42,0x00000000,0x00000000}},	//   _opyc, мры_, --, --, 
   {{0xd700ca43,0xd5cc146b,0x6604ca44,0xcfc80150}},	//   _изти, _स्वज, _опаа, _ﺒﺘﻘﺒ, 
   {{0x67d40831,0x64a80316,0xb06401f4,0x00000000}},	//   _хоҡу, _přis, yrää, --, 
   {{0xd48cca45,0x55e0013e,0x5f1003d4,0x55b800d9}},	//   _ар_, _рохб, িয়াও_, _ומבו, 
   {{0x3b08bbfe,0x7644005b,0x00000000,0x00000000}},	//   ytaq_, öhyv, --, --, 
   {{0x934057c6,0x00000000,0x00000000,0x00000000}},	//   _инце, --, --, --, 
   {{0x63a0b71f,0x64a801ef,0xb06401f4,0x3d942b2e}},	//   _izon, _třis, trää, еигр, 
   {{0xb7bc010e,0xd2b4011a,0x387c03cb,0xa018007c}},	//   _baţl, _קלות_, ynwr_, tnöd, 
   {{0x3b08ca46,0xb0640108,0x3e6c0064,0x00000000}},	//   ttaq_, rrää, ižti_, --, 
   {{0xda641564,0x4c9411ed,0x3b080ee9,0x6298ca47}},	// [10b90] وائي, титс, utaq_, olto, 
   {{0x3b080eda,0x9de40014,0x387c0042,0x3ce40162}},	//   rtaq_, _زہرٕ_, wnwr_, álvs_, 
   {{0x3b08ca48,0x80e000bd,0x7e740099,0x629801f4}},	//   staq_, পূর্, mizp, ilto, 
   {{0x450c0135,0x3b080784,0x620c00dc,0x81bc00e2}},	//   _གྱེར_, ptaq_, त्तौ_, udēj, 
   {{0x63a0ca49,0xa3c021b1,0x26c00098,0x81bc00e2}},	//   _nzon, ंशन_, _ékol_, rdēj, 
   {{0x35a43b26,0x6d480129,0xf5040395,0xcf58011a}},	//   налг, _àfac, езко, ובדת_, 
   {{0x63a0ca4a,0x3b40001f,0x62986c3c,0xa01801f4}},	//   _azon, _ከመጀመ, dlto, slöy, 
   {{0x63a00003,0x6298ca4b,0x64a000a7,0x6d5801c3}},	//   _bzon, elto, лаща, ùtai, 
   {{0x64a8012c,0x2c780139,0x00000000,0x00000000}},	//   _přir, lüdä_, --, --, 
   {{0x63a0ca4c,0xc0f00092,0xdcfc0118,0x32101525}},	//   _dzon, ሃለሁ_, ívěj, ýzy_, 
   {{0x63a0ca4d,0x6f140210,0xf554009d,0x00000000}},	//   _ezon, _spyc, _явжэ, --, 
   {{0x6298ca4e,0x00000000,0x00000000,0x00000000}},	//   alto, --, --, --, 
   {{0x9248001f,0x1e280023,0x81b000eb,0xa854011a}},	//   _ይገልፃ, _ብምጽና, টুল_, גירה_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7c64267c,0x5f40006c,0x3178010f,0x00000000}},	//   چاقل, نچیل, _מאַד, --, 
   {{0x7c64ca4f,0x6da40364,0x00000000,0x00000000}},	//   ناقل, диҳа, --, --, 
   {{0x63a0ca50,0xc2cc010f,0x207800df,0x00000000}},	// [10ba0] _xzon, ַמאָ, _מאקא, --, 
   {{0x8f680117,0x00000000,0x00000000,0x00000000}},	//   _нақб_, --, --, --, 
   {{0x2c78013d,0x00000000,0x00000000,0x00000000}},	//   güdä_, --, --, --, 
   {{0x66e4030d,0x95840023,0xe7840116,0x00000000}},	//   еода, _ዝንቡዕ_, ىلاپ, --, 
   {{0x2d98ca51,0x6298ca52,0x5ac400d4,0xc70800c7}},	//   _hype_, ylto, _плям_, ьҭаз_, 
   {{0x450c038f,0xbba00150,0x96b40114,0xf99000e5}},	//   _གྱུར_, _ﺃﺭﻀﻪ_, нују_, ابے_, 
   {{0x62980118,0x63a000e5,0x00000000,0x00000000}},	//   vlto, _szon, --, --, 
   {{0x2908014f,0x68fc0810,0x43946b01,0xf8b80208}},	//   _iqba_, mupd, кайс, _giũ_, 
   {{0x68fc09a5,0x27e4ca53,0x2d980200,0x7c800092}},	//   lupd, maon_, _lype_, _የእህል_, 
   {{0x27e4ca54,0xbd040036,0x63a0ca55,0x71f0035b}},	//   laon_, nhéé, _vzon, аҧшу, 
   {{0x62984b5a,0xe3b889f9,0x64a41c90,0x00000000}},	//   rlto, _ебе_, _зажа, --, 
   {{0x27e4ca56,0x63a0009f,0x234800db,0x00000000}},	//   naon_, _tzon, _ىلاپ_, --, 
   {{0x63a0ca57,0xf1d044af,0x26c43d68,0xdde000fd}},	//   _uzon, _द्वन, nqoo_, ләнү, 
   {{0x27e4ca58,0x4c9412d7,0xfcc40131,0x68fc00a2}},	//   haon_, ҳисс, кәмм, kupd, 
   {{0x27e4ca59,0x7e7401c4,0xf1e000d1,0x00000000}},	//   kaon_, rizp, _ﺋﯘﻧﺘ, --, 
   {{0x2d981445,0xffb4010b,0x27e4ca5a,0xe19000fb}},	//   _dype_, _иййэ, jaon_, _илһө, 
   {{0x27e42b92,0x645c02e2,0x00000000,0x00000000}},	// [10bb0] daon_, èpiy, --, --, 
   {{0x9e6400c6,0x76b8010b,0x19a8113e,0xdb200174}},	//   _ساخن, _aňyn, птеп_, _órím, 
   {{0x2d98039a,0xa3c000ce,0x68fcca5b,0xd0940022}},	//   _gype_, ्डा_, gupd, _шшәы, 
   {{0xf7741cb8,0x36d4974c,0xda000073,0x37740139}},	//   кулю, водр, _लावत_, кылс, 
   {{0x7c2cca5c,0x67200521,0xc5d800cc,0xbab4007b}},	//   mdar, gwoj, _সাজপ, _لمحب, 
   {{0x7c2cca5d,0xe734ca5e,0x00000000,0x00000000}},	//   ldar, теш_, --, --, 
   {{0xc984ca5f,0x64a8038e,0x27e4ca60,0xd8745734}},	//   _бути, _přip, baon_, _كارب, 
   {{0x3d18033f,0x27e43cb2,0x87e40395,0x00000000}},	//   _पहने_, caon_, _бюфе, --, 
   {{0x7c2c03d4,0x78a805da,0xd5b8ca61,0xa3c0000d}},	//   idar, _ihev, _есе_, ्ड़_, 
   {{0x64a802a8,0x7c2cca62,0x00000000,0x00000000}},	//   _aƙid, hdar, --, --, 
   {{0x7c2cca63,0xc62400eb,0x00000000,0x00000000}},	//   kdar, পাশা_, --, --, 
   {{0x7c2cca64,0x33740220,0x2d98b2f9,0x81780150}},	//   jdar, _игер, _rype_, _ﺠﺒﻬﺔ_, 
   {{0x7c2cca65,0x78a80109,0x2d98ca66,0x82380092}},	//   ddar, _mhev, _sype_, _እገምታ, 
   {{0x7c2cca67,0x78a8068c,0x2d98ca68,0x27e40165}},	//   edar, _lhev, _pype_, zaon_, 
   {{0x1d04ca69,0x7c2ca090,0x2d98ca6a,0x27e413a4}},	//   кери_, fdar, _qype_, yaon_, 
   {{0x7c2cca6b,0x78a8004c,0xef18005b,0x68fc014f}},	//   gdar, _nhev, _жми_, vupd, 
   {{0xe9d004a9,0x7c3cca6c,0x27e403d1,0xeb9821e2}},	// [10bc0] لغا_, _dnsr, vaon_, фиа_, 
   {{0x2d98ca6d,0x78a80109,0x7c2cca6e,0x1ef80a1e}},	//   _type_, _ahev, adar, _קליע, 
   {{0x27e4ca6f,0x7c2cca70,0x81bc0421,0x2ca80166}},	//   taon_, bdar, seēg, _окоп_, 
   {{0x68fcca71,0x78a8ca72,0x7c2c0014,0xdecc0023}},	//   rupd, _chev, cdar, ኣየኒ_, 
   {{0xa3c001ad,0x68fc1543,0x78a80200,0xca7800cf}},	//   ्डस_, supd, _dhev, _كەرت_, 
   {{0x27e42819,0x68fc0334,0x78a80112,0xd6240063}},	//   saon_, pupd, _ehev, воље_, 
   {{0xd940ca73,0xa8040021,0x29080109,0xd9d00131}},	//   _кери, _извл, _uqba_, _ئەمگ, 
   {{0x78a8014f,0x74a86215,0x6e2c003e,0x6720007f}},	//   _ghev, нсың_, hdbb, pwoj, 
   {{0xd704ca74,0x26c4ca75,0xdc98008f,0xa3440e3b}},	//   _инте_, qqoo_, ויקל, тэйл, 
   {{0x7c2cca76,0x78a80810,0x06d80154,0x00000000}},	//   zdar, _zhev, _সিপি, --, 
   {{0xa4248c75,0x64440108,0x00000000,0x00000000}},	//   _аьлл, ökis, --, --, 
   {{0x78a80023,0x59a425c9,0x7c2c0009,0x00000000}},	//   _xhev, केटर, xdar, --, 
   {{0x69cc0008,0x2d9c03fa,0x7c2cb2be,0xe3b00244}},	//   _ofbe, üten_, vdar, _ئرا_, 
   {{0xd3540375,0x00000000,0x00000000,0x00000000}},	//   _בידי_, --, --, --, 
   {{0x7c2c00ee,0x0d8411db,0xa3e405f9,0x4034ca77}},	//   tdar, алён, _बजा_, _бейс, 
   {{0x69cc0936,0x620c00dc,0x06d8015b,0x8c6438be}},	//   _afbe, त्रौ_, _সিনি, атуд, 
   {{0x78a805da,0x6d4800a3,0xe500012d,0x00000000}},	// [10bd0] _rhev, _àfan, रूति_, --, 
   {{0x78a8ca78,0x7c2cca79,0xdde800f1,0x00000000}},	//   _shev, sdar, _کرکه_, --, 
   {{0x7c2cca7a,0x00000000,0x00000000,0x00000000}},	//   pdar, --, --, --, 
   {{0x2484071b,0x7c3cca7b,0x9ba00075,0x7c2c11d8}},	//   _njom_, _unsr, _نەزى, qdar, 
   {{0x68ec02d0,0x1670ca7c,0x8ae4187f,0xa3e4012d}},	//   _evbd, ақар, _вісл, _बज़_, 
   {{0x7aecca7d,0x7bccca7e,0x799400d8,0xb9080154}},	//   msat, lcau, _бигф, _মম_, 
   {{0x78a81682,0x7aecca7f,0xaa400131,0x7bcc0393}},	//   _thev, lsat, _دۆلى, ocau, 
   {{0x588400c0,0x4db000d1,0xda6c01c8,0x00000000}},	//   _рыга, ﺰﺩﯨﻨ, _اُڀ_, --, 
   {{0x442400c6,0x87940014,0x248400d7,0x7bcc0208}},	//   شريف, _پێور_, _djom_, icau, 
   {{0xb7bc00a8,0x7aecca80,0x64440821,0xca1800d1}},	//   _naţi, isat, ökir, ﻳﻐﺎ_, 
   {{0x7aecca81,0x42c84ecc,0x7bcc0007,0xafe406b3}},	//   hsat, нгөн_, kcau, лонл, 
   {{0x7aec4afc,0x7bcc0007,0x40940251,0xa5c001a8}},	//   ksat, jcau, ирят, _þóru, 
   {{0x7bccca82,0xa3c01d68,0x00000000,0x00000000}},	//   dcau, ्डर_, --, --, 
   {{0x7aecca83,0x7bcc003a,0x2d9c000d,0x00000000}},	//   dsat, ecau, üteo_, --, 
   {{0x32c80051,0xa018007c,0x00000000,0x00000000}},	//   _húy_, snöa, --, --, 
   {{0xc6200882,0xa3e40c2e,0x7aecca84,0x999c00a2}},	//   _यस्य_, _बड़ा_, fsat, _şuş_, 
   {{0x7aecca85,0x7fe8ca86,0x06d8015b,0x76b80432}},	// [10be0] gsat, _شريف_, _সিভি, _aňym, 
   {{0xa9680304,0x3204ca87,0xbacc0154,0xa0180108}},	//   низа_, ngly_, _লিখছ, nnön, 
   {{0x7aecca88,0x7bcc0218,0xfe74ca89,0xdefc031c}},	//   asat, bcau, _түр_, ċċew_, 
   {{0x7aecca8a,0xf8a8803c,0x7bccca8b,0xa764af83}},	//   bsat, ندنه_, ccau, лкед, 
   {{0x09e800bd,0x7aec0d83,0x81bc005f,0x2cb00076}},	//   _পাঠা, csat, ldēt, mmyd_, 
   {{0xdb040158,0xa3e400ab,0x24840200,0x063400d8}},	//   åmås, _बजह_, _sjom_, рекџ, 
   {{0xa3c06611,0xb9b402e8,0xda600114,0x00000000}},	//   ्डल_, _встъ, _уври, --, 
   {{0x95500597,0x28740c9e,0x7800014b,0x00000000}},	//   إخوا, _сыгр, _дӯша, --, 
   {{0x18640640,0xc33015bf,0x00000000,0x00000000}},	//   _сати_, تەش_, --, --, 
   {{0x42741513,0x8af00213,0x1718008f,0x3204045a}},	//   ргос, yyən, _אומע, ggly_, 
   {{0x44200077,0xb7bc0311,0x2484017a,0x2d9c00c5}},	//   _ºi_, _raţi, _tjom_, ütel_, 
   {{0x7aecca8c,0x4420ca8d,0xa2e401c0,0xa908022e}},	//   ysat, _úi_, _бодд, mzоd, 
   {{0x543804ac,0x7aeca617,0x7bcc0218,0x10740108}},	//   _רעדא, xsat, vcau, сляю, 
   {{0x7bcc0007,0x37cc00fe,0x7aec007c,0x81d40354}},	//   wcau, াৰপৰ, vsat, _токх, 
   {{0x7aec0054,0x6d4800d8,0x00000000,0x00000000}},	//   wsat, _àfal, --, --, 
   {{0x7aecca8e,0x10e0ca8f,0xec1801e0,0x00000000}},	//   tsat, _уюшм, кесә_, --, 
   {{0x7bccca90,0x7aecca91,0x0ca800c9,0x0f1801b9}},	// [10bf0] rcau, usat, утри_, _یغیب_, 
   {{0x7bccca92,0x996402d9,0x9e040116,0xf8d400d1}},	//   scau, лтел, _счил, иңгә_, 
   {{0xc984a8e8,0xd99801e2,0x00000000,0x00000000}},	//   буци, رخطا_, --, --, 
   {{0x7aecca93,0xfbd005d9,0x7bcc0369,0x08f8036b}},	//   psat, _ذڪر_, qcau, ارلب_, 
   {{0xf744ca94,0xd6d8ca95,0x7aec0724,0x00000000}},	//   рело, хте_, qsat, --, 
   {{0x95c8ca96,0x2ac00166,0x00000000,0x00000000}},	//   худа_, _фәтв, --, --, 
   {{0xa3c000dc,0x32c80051,0x00000000,0x00000000}},	//   ्डं_, _súy_, --, --, 
   {{0xa85454a2,0x628401d3,0xc98400d8,0x657c0162}},	//   _кесә, ékon, _ѓури, úpha, 
   {{0x76b8ca97,0x09e800bd,0xc86417d6,0x5604592e}},	//   _алар_, _পাতা, _утри, _مذاق, 
   {{0xe50000cd,0x645c0200,0x671c000d,0x00000000}},	//   रूहि_, ëpir, _मैटक_, --, 
   {{0xc4f8ca98,0x76404d25,0x8364036b,0x00000000}},	//   _معنا_, _inly, لدیل, --, 
   {{0xb4c00d5f,0x54a4ca99,0xa3c00882,0x32c8001e}},	//   ंदी_, _صحاف, ्डः_, _túy_, 
   {{0x8424104b,0x3244180b,0x00000000,0x00000000}},	//   _دىنن, _велг, --, --, 
   {{0x3f840790,0xa2d0007b,0x00000000,0x00000000}},	//   ğlup_, _بيوت, --, --, 
   {{0x81bc00e2,0x6c7400c7,0xeff40023,0x2d9c12e8}},	//   udēt, ауах, _ጉጉይ_, æte_, 
   {{0xb9400020,0xa018023a,0x6d4800d8,0x81bc00e2}},	//   _የሚካሄ, nnöl, _àfam, rdēt, 
  
   {{0x7640ca9a,0xb4c02c35,0x99800427,0xc0a8007b}},	// [10c00] _only, ंदु_, _rajš_, _حاول_, 
   {{0xa01804cc,0xee3800d8,0x81b000eb,0xed580150}},	//   hnöl, _рно_, টুও_, _аоо_, 
   {{0xa924ca9b,0xa018007c,0x5df8011a,0xa3e400c5}},	//   рдел, knöl, _בפינ, _बजल_, 
   {{0xb7bc0356,0xbd4400ec,0x00000000,0x00000000}},	//   _laţu, _انٽي, --, --, 
   {{0xd70486de,0x45d4ca9c,0x186400f0,0x00000000}},	//   инце_, болс, шаци_, --, 
   {{0xb4c038bf,0x44b40131,0x06d800fe,0xe3e00154}},	//   ंदू_, әбис, _সিদি, _যাইব, 
   {{0xdb64001f,0xd4c0005b,0xa018032e,0x00000000}},	//   ዲያውም_, осып, fnöl, --, 
   {{0x8af003be,0x76400076,0x779004fb,0xa01805d5}},	//   yyəl, _enly, _کیها, gnöl, 
   {{0xc29835c7,0x57f800d9,0x4274004e,0x00000000}},	//   лких_, _שלמו, йгис, --, 
   {{0xa5941fc1,0x2afc00bc,0x52102e8d,0x00000000}},	//   _крещ, _लिनु_, одьт, --, 
   {{0x40341cb8,0x7e640208,0x81b00154,0xa18400ee}},	//   бенс, _rlhp, য়ুন_, рыпл, 
   {{0x3e6c01e1,0x00000000,0x00000000,0x00000000}},	//   _oótù_, --, --, --, 
   {{0x4424ca9d,0x6440ca9e,0x6d580158,0x49084142}},	//   mem_, _inoi, øtan, ांडो_, 
   {{0xad140b8d,0x3f840356,0x9f480200,0xc69400df}},	//   әптә, ălu_, lacë_, מאָ_, 
   {{0xe0e4036b,0x4424003a,0xae1400bc,0x260c06b1}},	//   _тўло, oem_, द्धन_, _ठानी_, 
   {{0x4424ca9f,0x2614caa0,0x50d01291,0x00000000}},	//   nem_, प्ती_, _بزور, --, 
   {{0x4424caa1,0x2aa4006a,0x00000000,0x00000000}},	// [10c10] iem_, gôbo_, --, --, 
   {{0x4424caa2,0xae1400af,0x8af00213,0xca7400d1}},	//   hem_, द्दन_, nzəy, يالغ, 
   {{0x4424caa3,0x6440caa4,0x3914caa5,0x7f5c02d0}},	//   kem_, _onoi, смер, lysq, 
   {{0x97c00184,0x08c402dd,0x00000000,0x00000000}},	//   әйҙе, ібін, --, --, 
   {{0x4424caa6,0x7b0801e4,0x00000000,0x00000000}},	//   dem_, _gɾup, --, --, 
   {{0x6440caa7,0x81dc02a6,0x8d7404a9,0x94e40134}},	//   _anoi, তৃত_, _داۋا, _sɑɑ_, 
   {{0x4424caa8,0xa2580491,0xb4c01098,0x5bb40d2c}},	//   fem_, _ấşř_, ंदे_, _अणुव, 
   {{0x4424caa9,0xf8b8612e,0x62883421,0x644000ae}},	//   gem_, _сөз_, _ajfo, _cnoi, 
   {{0x387c0142,0x00000000,0x00000000,0x00000000}},	//   miwr_, --, --, --, 
   {{0x649800f7,0x387c03cb,0xa22400c7,0x00000000}},	//   ктөр_, liwr_, бжьа_, --, 
   {{0x94e4013f,0xf4d800f3,0x00000000,0x00000000}},	//   _tɑɑ_, _смеш_, --, --, 
   {{0x4424caaa,0xa3c000dc,0x64400332,0x387c015d}},	//   cem_, ंशः_, _gnoi, niwr_, 
   {{0xb8e82b88,0x4374caab,0xfc58001f,0xafe40131}},	//   _ིང_, _мушт, _ያረጋግ, _һойл, 
   {{0xda0010f7,0x387c0368,0x828002dd,0xeb9802a9}},	//   _लागत_, hiwr_, _оқыд, ҳиб_, 
   {{0x98a400bc,0x6da4caac,0x69dc01f5,0xd1b80023}},	//   íně_, сива, vbpe, ተልቲ_, 
   {{0xeb985ba8,0xab28caad,0x0ae40022,0x649c00e4}},	//   гиб_, лоба_, жбаҟ, sëiv, 
   {{0x387c00a9,0x64a8012c,0x22b40210,0x00000000}},	// [10c20] diwr_, _přiz, _ełku_, --, 
   {{0xbe7400f1,0x00000000,0x00000000,0x00000000}},	//   _وپيژ, --, --, --, 
   {{0xed58caae,0xe8f8caaf,0x8bf40eac,0x1e540375}},	//   _сон_, уле_, ঙ্গন_, _השיר_, 
   {{0x4424cab0,0xb4c017ee,0x387c0042,0x00000000}},	//   xem_, ंदो_, giwr_, --, 
   {{0x4424cab1,0xb86400aa,0x2bdc0b40,0xb4c000bc}},	//   vem_, غامو, _फ्या, ंदै_, 
   {{0x4424cab2,0x644001e7,0x33e40220,0x03c400cc}},	//   wem_, _snoi, _ﺍﺩﺍﻣ, _এজেণ, 
   {{0x6f040d04,0x9ac0003d,0xa9680faa,0x387c0142}},	//   hukc, ċċes, _сива_, biwr_, 
   {{0x4424cab3,0x28141d0a,0xfd4c0055,0x18640022}},	//   uem_, _دورس, _choṭ, _ласи_, 
   {{0x4424cab4,0x988801ed,0xf7700050,0x05080154}},	//   rem_, _صحفہ_, _ہاے_, লবের_, 
   {{0x4424cab5,0x3d1814cf,0x6f0412eb,0xc66400db}},	//   sem_, _पहले_, dukc, _بئرۉ, 
   {{0x4424cab6,0x1a9800c8,0x60d80112,0x00000000}},	//   pem_, רייע, uptm, --, 
   {{0x4424cab7,0x64400433,0x9f48004a,0xfd4c00b8}},	//   qem_, _unoi, lacé_, _ghoṭ, 
   {{0xa01801d3,0xd13400c7,0x9878010f,0x00000000}},	//   lnök, _ҳхы_, ראכט, --, 
   {{0x63a0bcc3,0x16180406,0x9f48004a,0xf424010b}},	//   _iyon, प्पर_, nacé_, _çäre_, 
   {{0x63a00e02,0x357802d3,0x61e8035a,0xa018005b}},	//   _hyon, _እንተስ_, _iefl, nnök, 
   {{0x6298cab8,0x63a0cab9,0x61e80156,0xb6cc031c}},	//   loto, _kyon, _hefl, żżiż, 
   {{0x61e8caba,0x5fa006ba,0x6f04cabb,0xba5416a4}},	// [10c30] _kefl, _رەسم, cukc, овај, 
   {{0x6298cabc,0x63a000b5,0x61e8002e,0x5e7003e6}},	//   noto, _myon, _jefl, _رنجڕ, 
   {{0x63a0cabd,0x09e8015b,0xc984084c,0x629800b0}},	//   _lyon, _পাশা, пуци, ioto, 
   {{0x6298cabe,0x63a0cabf,0x61e801c7,0x2008cac0}},	//   hoto, _oyon, _lefl, ngci_, 
   {{0x6298cac1,0x63a02173,0x387c0368,0x9f4806af}},	//   koto, _nyon, riwr_, facé_, 
   {{0x61e80793,0x2bd8012c,0xb4c001ad,0x387c015d}},	//   _nefl, युठा, ंद्_, siwr_, 
   {{0x63a0cac2,0xa0180267,0x387c0042,0x09744627}},	//   _ayon, rnöj, piwr_, _егрю, 
   {{0x63a0cac3,0x06d800bd,0x497401c0,0x9a800092}},	//   _byon, _সিরি, _элсс, ናገኘው_, 
   {{0x6298cac4,0x63a00530,0x50a40075,0x60c8cac5}},	//   foto, _cyon, ۋەتل, _aufm, 
   {{0x6298cac6,0x63a00c11,0x9f480129,0x91a400e5}},	//   goto, _dyon, cacé_, ینکے_, 
   {{0x63a0cac7,0x649c022e,0xd5640b3b,0xd70c030d}},	//   _eyon, gëis, _утап, _аiуз, 
   {{0x63a0009f,0x6d48004a,0x61e803ac,0x7fd401ec}},	//   _fyon, _àfai, _eefl, зірі, 
   {{0x63a0cac8,0xe1ec0408,0x28980115,0x00000000}},	//   _gyon, _ог_, שירא, --, 
   {{0x61e8cac9,0x6298caca,0x236000fe,0xceb40213}},	//   _gefl, coto, økje_, _ipək_, 
   {{0x63a01529,0x09e80154,0xac9801f7,0xa5c00037}},	//   _zyon, _পালা, لنسا_, _ललछौ, 
   {{0x5f8401d9,0x6b64026b,0x60940066,0xc8a8012d}},	//   _ژٕٹہ_, окба, _ونوس_, _छींट, 
   {{0x61e80472,0x63a0022e,0x814400db,0xe9d80efe}},	// [10c40] _yefl, _xyon, _ونۇن, لذات_, 
   {{0x61e8102c,0xa018cacb,0x2d9400cf,0x06d800eb}},	//   _xefl, riöe, _дөбө_, _সিলি, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69d808ec,0x6298cacc,0xeb980452,0x649c0022}},	//   _प्री, zoto, _вим_, hëir, 
   {{0xc5f8cacd,0x629805d9,0x3cec0989,0xf1c8cace}},	//   йға_, yoto, ćeve_, रशान, 
   {{0x63a00526,0x00000000,0x00000000,0x00000000}},	//   _ryon, --, --, --, 
   {{0x63a0cacf,0xd16400b8,0x00000000,0x00000000}},	//   _syon, _tūṇī_, --, --, 
   {{0x63a0cad0,0x6298cad1,0x6d4c00db,0xa01801d3}},	//   _pyon, woto, ixba, rnök, 
   {{0x32d8035c,0x9f480066,0x00000000,0x00000000}},	//   یدیک_, pacé_, --, --, 
   {{0x63a01459,0x60c801e4,0x7ae85775,0x62980153}},	//   _vyon, _pufm, _çete, uoto, 
   {{0x418400d1,0x61e808a5,0x00000000,0x00000000}},	//   ятиғ, _vefl, --, --, 
   {{0x6298cad2,0x61e8cad3,0x63a00477,0x40340166}},	//   soto, _wefl, _tyon, чемс, 
   {{0x62980972,0x63a0cad4,0x06cc015b,0xa018005b}},	//   poto, _uyon, রীরি, nnöi, 
   {{0x271c0882,0x69d802db,0x6298058a,0x00000000}},	//   mānā_, _प्ली, qoto, --, 
   {{0x9cc8cad5,0x00000000,0x00000000,0x00000000}},	//   рыга_, --, --, --, 
   {{0x2a680165,0x7f94109a,0x00000000,0x00000000}},	//   _albb_, _найх, --, --, 
   {{0x271c1d86,0x1d880451,0x00000000,0x00000000}},	// [10c50] nānā_, _چئجي_, --, --, 
   {{0x0b8800d6,0xa26c0092,0x6d58007c,0x00000000}},	//   істи_, _ብዙኃን_, ätac, --, 
   {{0x47d801f2,0x6e18009f,0x00000000,0x00000000}},	//   _ịzụk, _ايپس_, --, --, 
   {{0x88c80212,0xd7f801a9,0x2bd8cad6,0x00000000}},	//   ілів_, руж_, युदा, --, 
   {{0xce3802d3,0x2a680036,0xaca80014,0x209801f2}},	//   _ብምጥቃ, _flbb_, _دپَے_, ụkwụ_, 
   {{0xb90039db,0xb06401f4,0x00000000,0x00000000}},	//   _দি_, osää, --, --, 
   {{0x3b08cad7,0xb06402f6,0x3ea0022e,0xc9840114}},	//   luaq_, nsää, _mkht_, _жути, 
   {{0x451800d4,0x00000000,0x00000000,0x00000000}},	//   юція_, --, --, --, 
   {{0x3b08cad8,0x37e4013d,0xb3840131,0x00000000}},	//   nuaq_, _моңг, ялил, --, 
   {{0xc7c40212,0xb06401f4,0xf4841dd8,0x00000000}},	//   _істи, ksää, _کائی, --, 
   {{0x5bd800cd,0xc6a42377,0x00000000,0x00000000}},	//   _बभूव, _црти, --, --, 
   {{0xc5a80014,0x8af00213,0x38744dd9,0x271c0171}},	//   _بُمن_, myəv, _çarı_, bānā_, 
   {{0xb8cc081f,0xc3040133,0x24501291,0x0fbc00eb}},	//   _པེ_, _قبوو, _سنوس, ূর্ধ, 
   {{0xed5836dd,0x00000000,0x00000000,0x00000000}},	//   бог_, --, --, --, 
   {{0x21a0657c,0x9d401411,0xd11c0073,0x6d4c02d0}},	//   _пишм, нерд, _बहिण_, uxba, 
   {{0x2bc800fd,0x1d041fbe,0x92fc0011,0x69cc00c5}},	//   слап_, џети_, ্বীপ_, _तलही, 
   {{0x3b080eda,0xb0640037,0x5ac40b01,0x1ee400e5}},	// [10c60] guaq_, asää, злум_, _ٹوپی_, 
   {{0xefec0092,0x00000000,0x00000000,0x00000000}},	//   _ፀጋዬ_, --, --, --, 
   {{0x2f14019b,0xada41fc7,0x6da4cad9,0xa01801f4}},	//   læg_, _ханл, _хина, liöa, 
   {{0xc18c00c8,0x1ca8025c,0xae040150,0xccb40124}},	//   סטאָ, _བེར_, _بوگى, _цәгь, 
   {{0xd7ec00c6,0x2a68004d,0x2f1401bf,0x00000000}},	//   اكه_, _tlbb_, næg_, --, 
   {{0x91e00154,0x00000000,0x00000000,0x00000000}},	//   _মাঝখ, --, --, --, 
   {{0xda5c001f,0x2c6c0162,0x1514007b,0x00000000}},	//   _ደረጃና_, _týdd_, كزية_, --, 
   {{0x18a0cada,0x2f14005c,0x00000000,0x00000000}},	//   _засм, kæg_, --, --, 
   {{0x1ca8025c,0xa764cadb,0xa6c8007b,0x00000000}},	//   _བེལ_, _экад, _طوال_, --, 
   {{0x268826c0,0xdef80032,0x271c00e2,0xb0640108}},	//   _اخري_, ҙым_, rānā_, ysää, 
   {{0xecbc072a,0x00000000,0x00000000,0x00000000}},	//   ्दाफ, --, --, --, 
   {{0xa3e41533,0x271c00e2,0xb3e800db,0x00000000}},	//   _बजट_, pānā_, _ۇعۇل_, --, 
   {{0xe298cadc,0x35900023,0x00000000,0x00000000}},	//   _лад_, _ዝሕተት_, --, --, 
   {{0xb064005b,0x00000000,0x00000000,0x00000000}},	//   tsää, --, --, --, 
   {{0x9f4800bc,0x403441e5,0x00000000,0x00000000}},	//   mací_, _жейс, --, --, 
   {{0x9f4802fd,0x3b080140,0xb06401f4,0x00000000}},	//   lací_, tuaq_, rsää, --, 
   {{0xb064049b,0x2ca00810,0x00000000,0x00000000}},	// [10c70] ssää, _dkkd_, --, --, 
   {{0x9f4800bc,0xa01801d3,0x00000000,0x00000000}},	//   nací_, gnöv, --, --, 
   {{0x90a401d9,0x3b080869,0x2d9c0112,0x00000000}},	//   _زمیٖ, suaq_, ütet_, --, 
   {{0xd1b8044e,0x9f48022a,0x00000000,0x00000000}},	//   ተፍቲ_, hací_, --, --, 
   {{0x9f48012c,0x00000000,0x00000000,0x00000000}},	//   kací_, --, --, --, 
   {{0xa3c00034,0x9f4802fb,0x76b800ee,0x35a4cadd}},	//   ूशन_, jací_, _aňyr, малг, 
   {{0x9f4804bf,0xd7f800db,0x03e40154,0xd61000cf}},	//   dací_, _гуз_, _গাজী_, _үзбө, 
   {{0x1ca8031c,0x00000000,0x00000000,0x00000000}},	//   _བེས_, --, --, --, 
   {{0x386c020c,0xd75840ec,0x6610005b,0x4ae00037}},	//   _iler_, _اجزا_, äkkö, _पढ़ाव, 
   {{0x2f141b25,0x2360cade,0x9f480118,0x47340064}},	//   væg_, økja_, gací_, _янус, 
   {{0x386c2005,0xe43001d5,0x00000000,0x00000000}},	//   _kler_, رفید, --, --, 
   {{0x23700034,0xef1801af,0x00000000,0x00000000}},	//   _żyje_, омм_, --, --, 
   {{0xa01801d3,0xefbc0092,0x9f4801ef,0x00000000}},	//   ynöv, ተርዎ_, bací_, --, 
   {{0x7cd402d5,0x386c2611,0x2f141b25,0x00000000}},	//   _sąra, _ller_, ræg_, --, 
   {{0xdb5c0020,0x386ccadf,0xadb8cae0,0xa0180108}},	//   _ደመወዝ_, _oler_, زهرا_, miön, 
   {{0x40940006,0xed580c60,0x386c00a2,0xa01801f4}},	//   _прыт, боҳ_, _nler_, liön, 
   {{0x3cec2d2b,0x2ca001e4,0xefdc0092,0x628c0419}},	// [10c80] ćeva_, _vkkd_, ናኘው_, čbov, 
   {{0x1e800ee1,0x386c04e6,0xb7cc00eb,0x00000000}},	//   _альм, _aler_, ারোয়, --, 
   {{0x386c1570,0xa01800e5,0xb86469f1,0x00000000}},	//   _bler_, rnöv, کالو, --, 
   {{0x386c0c86,0x9f48012c,0xe7a8399b,0xc8b4036b}},	//   _cler_, zací_, овел_, رلشک, 
   {{0xd6cc143e,0x0e9c002b,0x00000000,0x00000000}},	//   لقن_, _ṛṣiv, --, --, 
   {{0xa0186b4e,0x7ae8cae1,0x09e800eb,0x2bd807b7}},	//   lnöt, _çeta, _পাকা, युरा, 
   {{0x386c9c56,0x9f480300,0x83f8014b,0x00000000}},	//   _fler_, vací_, пейс_, --, 
   {{0x386ccae2,0x833402e8,0xb35400f2,0xa018002f}},	//   _gler_, ених, کیها_, nnöt, 
   {{0x9f4800bc,0x06d8015b,0x7c280022,0x00000000}},	//   tací_, _সিকি, _ñere, --, 
   {{0x41542db9,0x27e401c0,0xa184cae3,0x3dc403d4}},	//   евос, lbon_, дымл, ্ৰিল, 
   {{0x9f4802fd,0x00000000,0x00000000,0x00000000}},	//   rací_, --, --, --, 
   {{0x27e4cae4,0x9f48cae5,0x1ca8025c,0x386c003e}},	//   nbon_, jacã_, _བེེ_, _xler_, 
   {{0x27e40793,0x9f4819b3,0x6d58007c,0x10742401}},	//   ibon_, pací_, ätan, тляю, 
   {{0x98bc00ef,0x00000000,0x00000000,0x00000000}},	//   _čuč_, --, --, --, 
   {{0x38b40158,0x27e401f5,0x00000000,0x00000000}},	//   låre_, kbon_, --, --, 
   {{0x8af011a9,0xbae400c6,0x80ac0154,0x09e800cc}},	//   yyət, فكري, _ঘূর্, _পাগা, 
   {{0x2d9ccae6,0x27e401a4,0x386c00a2,0xa9d400d1}},	// [10c90] üter_, dbon_, _rler_, ﯘﻟﯩﻴ, 
   {{0x386c0158,0x00000000,0x00000000,0x00000000}},	//   _sler_, --, --, --, 
   {{0xadb001ec,0x00000000,0x00000000,0x00000000}},	//   _бұрш, --, --, --, 
   {{0x59dc4a18,0xf8b0073e,0x00000000,0x00000000}},	//   _प्रर, اکس_, --, --, 
   {{0xf6240d5c,0x7c2ccae7,0x38b4049f,0xb6f80075}},	//   едло, mear, vård_, سىغا_, 
   {{0x7c2ccae8,0xe7949a12,0x00000000,0x00000000}},	//   lear, رانک, --, --, 
   {{0xe5a035f4,0xa018005b,0x27e4cae9,0x69bc024a}},	//   лиши, nnös, bbon_, वेदी, 
   {{0x7c2ccaea,0x386c41b2,0x27e4004d,0x00000000}},	//   near, _uler_, cbon_, --, 
   {{0xa018caeb,0x00000000,0x00000000,0x00000000}},	//   hnös, --, --, --, 
   {{0x7c2ccaec,0x95480150,0xd5640120,0x16c83507}},	//   hear, _وشاق_, _отеп, ादीब, 
   {{0x7c2ccaed,0x9f480004,0x48a8030d,0x3218012d}},	//   kear, yacã_, _атăм_, ęsy_, 
   {{0x7c2ccaee,0x7b9c01ec,0xdbd401f4,0x04c8007b}},	//   jear, _ﺃﺼﺎﺏ_, _jääu, _قولي_, 
   {{0xe28ccaef,0x7c2ccaf0,0xc90c0073,0xa01801f4}},	//   _ба_, dear, _हम्म_, miöl, 
   {{0xdca007d6,0xed5813dc,0xa0180108,0xf678010f}},	//   ҳаси, пог_, liöl, לאָמ, 
   {{0x7c2ccaf1,0x8af003be,0x2c6c010b,0x817401b9}},	//   fear, yyəs, _aýda_, _لنوچ, 
   {{0x7c2ccaf2,0xdca00ab2,0xb95c0092,0xa01801f4}},	//   gear, гаси, _ለሚካሄ, niöl, 
   {{0xaa44caf3,0x00000000,0x00000000,0x00000000}},	// [10ca0] неал, --, --, --, 
   {{0x29180fac,0xa0183b22,0x6fa800f1,0x00000000}},	//   ttpa_, hiöl, _ونډې_, --, 
   {{0x7c2ccaf4,0x81dc02f5,0x6e2c0083,0x7ae8caf5}},	//   bear, তৃক_, mebb, _çetn, 
   {{0x7c2ccaf6,0x27e40d27,0x6e2c3902,0xdd8c79af}},	//   cear, ubon_, lebb, _چوی_, 
   {{0xdd8ccaf7,0x00000000,0x00000000,0x00000000}},	//   _نوی_, --, --, --, 
   {{0x6e2ccaf8,0x161801ad,0x69d407b7,0xa96801a9}},	//   nebb, प्लर_, मुखी, _еига_, 
   {{0x69cc110e,0xd9400075,0x00000000,0x00000000}},	//   _igbe, _йери, --, --, 
   {{0x6e2ccaf9,0x27e4011f,0x941402e8,0x74a8010b}},	//   hebb, qbon_, ежът_, мсың_, 
   {{0xd3d4cafa,0x22040241,0x6e2ccafb,0xa018007c}},	//   ربيا_, _níhà_, kebb, knör, 
   {{0x7c2c05f5,0x6a700162,0x6e2c0076,0xd25400d4}},	//   zear, _fæfe, jebb, ецю_, 
   {{0xd48ccafc,0x69cc02e3,0x06d8015b,0x55e0010b}},	//   _бр_, _mgbe, _সিটি, _сохб, 
   {{0x7c2c01c6,0x69cc01e1,0xb60002d2,0x657c03b2}},	//   xear, _lgbe, _íárg, úphu, 
   {{0x63840510,0x69cccafd,0xa01802d2,0x00000000}},	//   _ягда, _ogbe, fnör, --, 
   {{0x7c2ccafe,0x6e2c01ed,0x9f4800db,0x69cccaff}},	//   wear, gebb, racà_, _ngbe, 
   {{0x7c2ccb00,0x3cec0552,0xff8000b7,0xa018005b}},	//   tear, ćevo_, _ከንቲባ_, liöm, 
   {{0x69cc110e,0xbf107196,0xa01801e6,0x6abc0112}},	//   _agbe, _күмә, rnös, empf, 
   {{0x7c2ccb01,0x6e2c1418,0x9f50033f,0x7a380276}},	// [10cb0] rear, bebb, ędów_, мпар_, 
   {{0x7c2ccb02,0x9f4800d2,0xaa9400d1,0xc17800c0}},	//   sear, cacá_, вгуә, ozė_, 
   {{0x7c2ccb03,0xdbd4023a,0x69f00137,0x00000000}},	//   pear, _pääu, рүст, --, 
   {{0x69cc0ca8,0x7c2c0194,0x49b80244,0x7ae806be}},	//   _egbe, qear, رالد_, _çeto, 
   {{0x7bdc022f,0xab600131,0xe8500d17,0x6a7002d2}},	//   _ifsu, _پۇلى, شنود, _sæfe, 
   {{0x6d480597,0x658806be,0x00000000,0x00000000}},	//   _áfac, _tәhl, --, --, 
   {{0x1ccc025c,0x09e8015b,0xa018005b,0x986400db}},	//   _ུངས_, _পাচা, tiöl, _كلسە_, 
   {{0x69cc01a6,0x20ec0118,0x6e2c3902,0xc17800c0}},	//   _zgbe, dři_, zebb, dzė_, 
   {{0x36d410f5,0x9f48cb04,0x3b08bbfe,0x6e2ccb05}},	//   _розр, yacá_, nraq_, yebb, 
   {{0xcb1400c8,0x3b080472,0xb1440212,0x6e2c0327}},	//   אלץ_, iraq_, внол, xebb, 
   {{0x6e2c01ed,0xafe42cdb,0x468001ec,0x20ec0118}},	//   vebb, конл, _ықша, gři_, 
   {{0x6e2ccb06,0x62840066,0x09e80011,0xe7d000fe}},	//   webb, ékor, _পাছা, াৰীয, 
   {{0x6e2ccb07,0x836400f2,0x8e4001a9,0xa854011a}},	//   tebb, _مدول, оrаt_, דירה_, 
   {{0x7bdc036b,0x3b080083,0x20ec01ef,0x00000000}},	//   _afsu, draq_, bři_, --, 
   {{0xada409fe,0x6e2ccb08,0xe294cb09,0x3b08cb0a}},	//   тавл, rebb, _шаш_, eraq_, 
   {{0x6e2ccb0b,0x6da40588,0xf8b801fb,0xa01801e3}},	//   sebb, еиҳа, _nhũ_, snör, 
   {{0x9f480407,0x7ae80432,0x00000000,0x00000000}},	// [10cc0] pacá_, _çetl, --, --, 
   {{0x20d802b5,0x7bdc03e0,0xa968022e,0x00000000}},	//   _hīia_, _efsu, миза_, --, 
   {{0x20d80053,0xe8f8cb0c,0x3b080869,0x7afc06ea}},	//   _kīia_, фле_, araq_, _evst, 
   {{0x66e4cb0d,0xe784cb0e,0xf8b80051,0xa76404b3}},	//   вода, куло, _chũ_, ккед, 
   {{0x20d800b0,0x00000000,0x00000000,0x00000000}},	//   _mīia_, --, --, --, 
   {{0xf8b80022,0x20ec012c,0x69240022,0xa904007b}},	//   _ehũ_, yři_, _имга, _لبرن, 
   {{0xf8accb0f,0xa0180112,0xb7bc00a2,0x6fc001f9}},	//   _гө_, knöp, _maţy, रेतू, 
   {{0x94402544,0xa9680124,0xa0180108,0x20ec0118}},	//   لپىن, _еиҳа_, tiöm, vři_, 
   {{0xe618cb10,0xc7b001d3,0x668000f1,0x00000000}},	//   _ода_, _اڑا_, _پیغل, --, 
   {{0x386c0327,0x20ec0118,0xa0180108,0x00000000}},	//   _ċeri_, tři_, riöm, --, 
   {{0x38b40158,0x2b4400d0,0x658803b9,0x31c40154}},	//   låra_, ťoch_, _mәhk, _শ্বশ, 
   {{0x3b08cb11,0x4420004d,0x00000000,0x00000000}},	//   yraq_, _ùi_, --, --, 
   {{0x2d98005a,0xd36c4c1c,0xb7bc00a2,0x38b405ac}},	//   _axpe_, _وهم_, _baţy, nåra_, 
   {{0x1ca8031c,0x03cc0055,0x2ba40037,0x91e0009b}},	//   _བེང_, _gṛḥp, _खड़ा, _коље, 
   {{0xd134035b,0x38b405ac,0xb7bc00a2,0x3b080113}},	//   _ахы_, håra_, _daţy, wraq_, 
   {{0x38b405ac,0x3b08cae1,0x00000000,0x00000000}},	//   kåra_, traq_, --, --, 
   {{0x0ff806f6,0x8ff80592,0xa0180108,0x00000000}},	// [10cd0] _شعيب_, _شرير_, hiök, --, 
   {{0x9964cb12,0x7e9801f7,0x00000000,0x00000000}},	//   ктел, _سنجر_, --, --, 
   {{0x49a4147e,0x38b40158,0xf8b8004d,0x00000000}},	//   ајца, eåra_, _phũ_, --, 
   {{0x7798cb13,0xc2e800fe,0x16c800cd,0x00000000}},	//   нкер_, _খিনি_, ाद्ब, --, 
   {{0xe7e00307,0x3b0802d1,0xa0180108,0x00000000}},	//   खड़ा_, qraq_, tiöj, --, 
   {{0x98b06f30,0x7c3ccb14,0xe7346179,0x00000000}},	//   ıdır_, _hasr, уеш_, --, 
   {{0x98c4cb15,0x857800a7,0x33d438a9,0x8534611f}},	//   _асал, ксът_, ліпт, لووچ, 
   {{0x7c3c05b1,0xa85400d1,0x38b403cd,0x00000000}},	//   _jasr, _йесә, båra_, --, 
   {{0x7c3ccb16,0x78a8014b,0x20d800b0,0x6a7008a5}},	//   _masr, _ikev, _rīia_, _hæfa, 
   {{0xe3b4cb17,0xa018005b,0x7c3c1cf8,0xb0e8cb18}},	//   ыбы_, liöh, _lasr, ндоз_, 
   {{0xc0cc001f,0xc61c0154,0x953000f1,0x71681188}},	//   ጣለሁ_, _ধোকা_, _خواږ, ханг_, 
   {{0x7c3ccb19,0x00000000,0x00000000,0x00000000}},	//   _nasr, --, --, --, 
   {{0xd20029db,0xb4c01f14,0xd3440345,0x7f180150}},	//   _күпк, ूदी_, _شیده_, кіру_, 
   {{0xe19400f7,0x7c3c03cd,0x91c00166,0x8acc0150}},	//   _өлчө, _aasr, _калҗ, _ﺒﺎﻫﻅ, 
   {{0x64a802a8,0x6cd45734,0x78a80022,0xe3c401af}},	//   _iƙir, اقرا, _okev, _ирәү, 
   {{0x7c3c01d9,0x291c00b8,0xb37c0023,0x00000000}},	//   _casr, _īta_, ሕጋውን_, --, 
   {{0xe9d00075,0x7c3c00b8,0xeb98b42d,0x2b4401e7}},	// [10ce0] مغا_, _dasr, хиа_, íoc_, 
   {{0x78a8cb1a,0x7c3c3a77,0xaae40133,0x38b401e3}},	//   _akev, _easr, نتڕۆ, våra_, 
   {{0xe8e8b15a,0x63ac012d,0x00000000,0x00000000}},	//   хмед_, ębni, --, --, 
   {{0xe7d00011,0x00000000,0x00000000,0x00000000}},	//   ার্য, --, --, --, 
   {{0x8f38044e,0x5fc4012c,0x57f00212,0xd7e40798}},	//   _እዚኣቶ, रेपल, спіт, умче_, 
   {{0x78a802b9,0x66e401e0,0xa018005b,0xa8040075}},	//   _ekev, _ҡоба, tiök, _әзал, 
   {{0x38b40158,0x6d584a3e,0x291c00c7,0x386c0327}},	//   såra_, ätah, _ëta_, _ċerv_, 
   {{0x6e3ccb1b,0x78a8030a,0x7c3cb75f,0xe2a800f2}},	//   _lapb, _gkev, _xasr, کابن_, 
   {{0x98940724,0x439458d8,0xc2740e92,0x6e3c02d0}},	//   _сурә, рапс, илиј, _oapb, 
   {{0xa018023a,0x7d00cb1c,0x69dc0393,0x6e3ccb1d}},	//   miöi, álsk, ncpe, _napb, 
   {{0xa018005b,0x65b8013d,0xda78010f,0x00000000}},	//   liöi, _чуар_, גניר, --, 
   {{0x2ef00142,0x00000000,0x00000000,0x00000000}},	//   _bwyf_, --, --, --, 
   {{0x2484036b,0xe3b0058c,0x442405b1,0x7c3ccb1e}},	//   _imom_, _ارا_, mfm_, _rasr, 
   {{0x6e3ccb1f,0x35a805f9,0x7c3cab1a,0x00000000}},	//   _capb, _चुड़, _sasr, --, 
   {{0x61f8cb20,0x7c3ccb21,0xdcb806bb,0x0d840024}},	//   matl, _pasr, еща_, блён, 
   {{0x61f8cb22,0x7c3c5310,0x2ef00142,0x7ae8010e}},	//   latl, _qasr, _fwyf_, _çetk, 
   {{0x3b54cb23,0x50b85ec2,0x2484013b,0x6d480008}},	// [10cf0] шкар, _حدود_, _mmom_, _áfan, 
   {{0x6e3c0369,0x78a8cb24,0x7c3c01a4,0x38b4007c}},	//   _gapb, _skev, _wasr, gårn_, 
   {{0x7c3c7dec,0x7c280022,0xc1780153,0xf4240432}},	//   _tasr, _ñero, mbės_, _çäge_, 
   {{0x61f8cb25,0x20d80036,0x6e3c00d8,0xc1780153}},	//   hatl, _mëi_, _zapb, lbės_, 
   {{0x61f8cb26,0x95b02e47,0x6e3c016d,0xe7d003d4}},	//   katl, әрлә, _yapb, াৰ্য, 
   {{0x61f80842,0x6a7001a8,0x00000000,0x00000000}},	//   jatl, _hæfn, --, --, 
   {{0x61f8074d,0x442401a6,0xdc840023,0xd7e41cd0}},	//   datl, ffm_, _ነብሰይ_, _бізо, 
   {{0x78a851e9,0xb46487db,0x44240165,0x5ed80154}},	//   _ukev, ркил, gfm_, _ভবনে, 
   {{0x61f8cb27,0xe4540e76,0x5fc420f0,0x7c2800a2}},	//   fatl, ржы_, रेमल, _ıerl, 
   {{0x61f8cb28,0x2ef00368,0x312400d8,0x00000000}},	//   gatl, _rwyf_, адог, --, 
   {{0xf8c801e1,0x6e3c047e,0x44240010,0x85042bd8}},	//   _gbéé_, _rapb, bfm_, _هولن, 
   {{0x1ccc0135,0x239c01f2,0x61f80064,0x00000000}},	//   ུམས_, ịja_, aatl, --, 
   {{0x61f8cb29,0x6e3c3e1d,0x045400f7,0xf1d030ab}},	//   batl, _papb, _دئلد, _мөнө, 
   {{0x6e3c047e,0x00000000,0x00000000,0x00000000}},	//   _qapb, --, --, --, 
   {{0x823400aa,0xafe4cb2a,0xd34401d5,0xabf405c1}},	//   _درنا, _койл, _شیگه_, ичащ, 
   {{0xab28cb2b,0xebe4084c,0x8f6801d3,0x00000000}},	//   коба_, роап, _ملبے_, --, 
   {{0x38b41455,0x6a84cb2c,0x87e434b1,0x09b802f5}},	// [10d00] tårn_, алаа, ەتتە, _জলধা, 
   {{0xa01801f4,0x00000000,0x00000000,0x00000000}},	//   viöi, --, --, --, 
   {{0xfd980831,0xac08b17e,0x442468c8,0x00000000}},	//   _бөтә_, _инна_, yfm_, --, 
   {{0xa018023a,0x61f8cb2d,0xc18c010f,0x00000000}},	//   tiöi, zatl, עטאָ, --, 
   {{0x61f8cb2e,0x18640b3e,0x2cb00098,0x386c0003}},	//   yatl, јачи_, mlyd_, _ċert_, 
   {{0xa01802f6,0x2484017a,0x2cb04159,0x61f801a9}},	//   riöi, _smom_, llyd_, xatl, 
   {{0x4424cb2f,0x5e54010f,0x76b800a2,0x60d8022e}},	//   tfm_, ייסע_, _yňyz, xqtm, 
   {{0x98a0cb30,0x61f8cb31,0x1864cb32,0x2cb0072b}},	//   _дисе, watl, _каси_, nlyd_, 
   {{0x61f8cb33,0xc17802d5,0x3cec1674,0xa6c800db}},	//   tatl, ybės_, ćevi_, _алаа_, 
   {{0x6720cb34,0x43941c5c,0xa6c84c84,0x4274cb35}},	//   mtoj, _қалс, _شوال_, сгос, 
   {{0xd254652e,0x2cb00158,0x62300133,0x00000000}},	//   рцы_, klyd_, موکڕ, --, 
   {{0x672002d5,0x61f80209,0x4424cb36,0x00000000}},	//   otoj, satl, qfm_, --, 
   {{0x61f8cb37,0x2cb04b21,0x909800a7,0x00c80116}},	//   patl, dlyd_, рвят_, клүк_, 
   {{0x61f8a67c,0x67200962,0x7ae8cb38,0xd36c3f32}},	//   qatl, itoj, _çeti, _تهه_, 
   {{0x1ca8003d,0xd12c8b4d,0x6720cb39,0xc1780024}},	//   _བེད_, _يمه_, htoj, rbės_, 
   {{0x67209789,0x4094cb3a,0xdb0c04d4,0x81bc0c58}},	//   ktoj, _دلبر, _azcá, _অলপ_, 
   {{0x3a74cb3b,0x6720cb3c,0xdb2005d2,0x9bc40108}},	// [10d10] блар, jtoj, _örüm, рёвк, 
   {{0x4a54cb3d,0x8af006be,0x00000000,0x00000000}},	//   окус, mxəl, --, --, 
   {{0x7e640649,0x6720cb3e,0x8aa40220,0xb7d425ef}},	//   _iohp, etoj, іруд, مقاب, 
   {{0x672002d3,0x7e64047e,0x49084540,0x30d8008f}},	//   ftoj, _hohp, _हिरो_, אַסע, 
   {{0x25b00213,0x6d58005b,0x67203be3,0x482400f7}},	//   əyli_, ätav, gtoj, تىنق, 
   {{0x7e64014f,0x5a4402d5,0x684400e5,0x00000000}},	//   _johp, _тэма, védő, --, 
   {{0x7e64047e,0x5f1400cd,0xf4240139,0x7d1403b9}},	//   _mohp, भूत्_, _ğäbd_, nuzs, 
   {{0x7e640418,0x47cc04c5,0x67200218,0x36d4084c}},	//   _lohp, াড়ী, btoj, _гоар, 
   {{0x1ca8031c,0x7e6402d0,0xdb080139,0x00000000}},	//   _བེན_, _oohp, _çiän, --, 
   {{0x7e6403a2,0xa0180112,0x00000000,0x00000000}},	//   _nohp, nhöf, --, --, 
   {{0x50a40075,0x0574cb3f,0x764002d0,0xc2c8007b}},	//   يەتل, _وامد, _ialy, جبيل_, 
   {{0x7640cb40,0x7d1406be,0x00000000,0x00000000}},	//   _haly, duzs, --, --, 
   {{0x7640cb41,0x7204034c,0x7d140369,0xe1eccb42}},	//   _kaly, _هوشم, euzs, _нг_, 
   {{0xcec400bc,0x2c6c010e,0xdeac0208,0xee38cb43}},	//   kařů_, _iýdi_, txcơ, ынг_, 
   {{0x7640cb44,0x7e640477,0x2d9c0e51,0xefd40092}},	//   _maly, _dohp, çte_, ራራው_, 
   {{0x67200953,0x76400585,0x6d480077,0x25b80209}},	//   ytoj, _laly, _áfam, ýpli_, 
   {{0x76400363,0xa0180108,0x2cb001bf,0x00000000}},	// [10d20] _oaly, tiöv, rlyd_, --, 
   {{0xa9a40372,0x7640cb45,0xee380114,0xed5822cb}},	//   бизд, _naly, _сно_, _боо_, 
   {{0x27940daf,0xa018005b,0x69240120,0xa9240354}},	//   әшер, riöv, смеа, сдел, 
   {{0x672002f6,0xb8640769,0xd7f400f7,0x76400009}},	//   ttoj, يانو, буш_, _aaly, 
   {{0xc5f80058,0x7640cb46,0x6720652e,0xa0180108}},	//   иға_, _baly, utoj, miöt, 
   {{0x6720cb47,0x1ae0cb48,0xa018023a,0xd9780139}},	//   rtoj, _хорм, liöt, _өрсә_, 
   {{0x67208ead,0x76400953,0x77380092,0x00000000}},	//   stoj, _daly, _በግለሰ, --, 
   {{0x6720cb49,0x764002d0,0x5994011a,0xa018007c}},	//   ptoj, _ealy, _הכלב_, mhög, 
   {{0x76400109,0x558400b1,0x00000000,0x00000000}},	//   _faly, ибәм_, --, --, 
   {{0x7640cb4a,0x7d14009f,0xda78008f,0x9f4800e4}},	//   _galy, yuzs, ָנטר, pacú_, 
   {{0x7e64002f,0x6a7002d2,0xa01801f4,0x00000000}},	//   _rohp, _ræfl, kiöt, --, 
   {{0x7e64cb4b,0x764000ee,0x92540107,0xdfe006e3}},	//   _sohp, _zaly, _ҳашт_, कुंद_, 
   {{0x64400418,0x7e64cb4c,0x7640cb4d,0x2d9c000f}},	//   _iaoi, _pohp, _yaly, ûten_, 
   {{0x6440cb4e,0x2bbc0b7c,0x7e64cb4f,0x9254013e}},	//   _haoi, ्धना, _qohp, _гашт_, 
   {{0x6a7002d2,0x0d840108,0xc0c460c6,0x00000000}},	//   _væfl, плён, _мәми, --, 
   {{0x7e64013f,0x6aac00b5,0x644001f4,0x7f946da0}},	//   _wohp, _akbf, _jaoi, _майх, 
   {{0x644035b8,0xa01801a8,0xbb58009d,0x00000000}},	// [10d30] _maoi, thöf, шаах_, --, 
   {{0x7f4ccb50,0x6440cb51,0x1ca8025c,0x7d140175}},	//   _iraq, _laoi, _བེམ_, puzs, 
   {{0x7640cb52,0x64400421,0xa01801a8,0x3b84001f}},	//   _raly, _oaoi, rhöf, ሪካዎች_, 
   {{0x7640cb53,0xdb0ccb54,0x6440cb55,0xa018840d}},	//   _saly, _lycé, _naoi, shöf, 
   {{0x7640cb56,0x3cec08ad,0x62887209,0x99d001e4}},	//   _paly, ćevu_, _omfo, _laʈi, 
   {{0x64401681,0xd88000f2,0x6d58007c,0x00000000}},	//   _aaoi, _کهری, åtag, --, 
   {{0x7aeccb57,0x7640cb58,0x6440cb59,0xa01805d5}},	//   lpat, _valy, _baoi, chög, 
   {{0x64407ea1,0x7f4ccb5a,0x62880a40,0x7640cb5b}},	//   _caoi, _oraq, _amfo, _waly, 
   {{0x644050c2,0x7aeccb5c,0x7640cb5d,0xb7bc084c}},	//   _daoi, npat, _taly, _obţi, 
   {{0x7aeccb5e,0x62880175,0x87e80014,0x00000000}},	//   ipat, _cmfo, _نٹہِ_, --, 
   {{0x64407e9f,0x7f4ccb5f,0xf5945085,0x5fc41b76}},	//   _faoi, _araq, _بلاج, रेसल, 
   {{0x7aec0cfe,0x6440cb60,0x7f4ccb61,0xf48400dd}},	//   kpat, _gaoi, _braq, _بائی, 
   {{0xe28ccb62,0x7f4ccb63,0x628806d9,0x7aec02d1}},	//   _жа_, _craq, _fmfo, jpat, 
   {{0x7f4c0561,0xace807d6,0x7aeccb64,0xa01801e3}},	//   _draq, имга_, dpat, yhög, 
   {{0x7aeccb65,0x7f4c0086,0x9d4000f7,0xa018cb66}},	//   epat, _eraq, мерд, giös, 
   {{0xec14cb67,0x7d04074d,0x7f4ccb68,0x9f58011f}},	//   تورد, _dvhs, _fraq, _meqê_, 
   {{0x7aec10c7,0xa018005b,0x00000000,0x00000000}},	// [10d40] gpat, riöt, --, --, 
   {{0x63b402bf,0xf22005f9,0x6d58023a,0xa2d8012d}},	//   _øyne, _माफ़_, ätas, नदत्, 
   {{0x7aeccb69,0xad2400d1,0x2ba40829,0x6d58007c}},	//   apat, _بىجى, _खडका, åtad, 
   {{0x3b840020,0xd7ec00c6,0x7aec3a52,0x628401d3}},	//   ሪያዎች_, نكم_, bpat, ékoz, 
   {{0xa6c8cb6a,0x64400e89,0xa018c9df,0x8af00213}},	//   алда_, _raoi, shög, yyəy, 
   {{0x64401549,0x7c28010e,0xfa1000eb,0x00000000}},	//   _saoi, _ıeri, স্বল_, --, 
   {{0x644000b0,0x157c0046,0x9e58010f,0x7be8032e}},	//   _paoi, ﺭﺍﺳﯩ, יכסט, _ásuð, 
   {{0x387c03cb,0x00000000,0x00000000,0x00000000}},	//   chwr_, --, --, --, 
   {{0x64400618,0x7ae80200,0xb86402f2,0x00000000}},	//   _vaoi, _çett, _عافو, --, 
   {{0xa508cb6b,0x291c01e3,0x00000000,0x00000000}},	//   _вежа_, _ätas_, --, --, 
   {{0x6440cb6c,0x7aec033f,0xd48c00f3,0x00000000}},	//   _taoi, zpat, _жр_, --, 
   {{0x7aeccb6d,0x7f4c03e3,0x44f000fe,0x00000000}},	//   ypat, _praq, _টিপক_, --, 
   {{0xe298cb6e,0x7aec0076,0x1fa401af,0x658806be}},	//   _кад_, xpat, юрог, _tәhs, 
   {{0x6288016c,0x63a0bdc2,0xa01833b4,0x9f580240}},	//   _umfo, _ixon, tiös, _heqë_, 
   {{0x7aec0784,0xdc886c00,0xbc90008e,0x00000000}},	//   wpat, асал_, еңнә, --, 
   {{0x7aeccb6f,0xa018cb70,0x7f4ccb71,0x00000000}},	//   tpat, riös, _traq, --, 
   {{0x3a749f91,0x6298cb72,0x6d58cb73,0x7f4c2e95}},	// [10d50] плар, onto, ätar, _uraq, 
   {{0x7aeccb74,0x6298007f,0x8e840114,0xa018007c}},	//   rpat, nnto, _огње, piös, 
   {{0x6298cb75,0xa3c80490,0x3834cb76,0x7aeccb77}},	//   into, ळेत_, знер, spat, 
   {{0x7aeccb78,0x7c5800c6,0x63a00393,0x10e00150}},	//   ppat, _الحر_, _oxon, _ﺍﻟﺯﺨ, 
   {{0x7aec0357,0x00000000,0x00000000,0x00000000}},	//   qpat, --, --, --, 
   {{0x629801e4,0x00000000,0x00000000,0x00000000}},	//   jnto, --, --, --, 
   {{0x63a0cb79,0xa50402e8,0x00000000,0x00000000}},	//   _axon, пеща_, --, --, 
   {{0x6298cb7a,0x00000000,0x00000000,0x00000000}},	//   ento, --, --, --, 
   {{0xd344036b,0x00000000,0x00000000,0x00000000}},	//   تیشه_, --, --, --, 
   {{0x6298383d,0x4734023b,0x00000000,0x00000000}},	//   gnto, _юнус, --, --, 
   {{0xfa100011,0x00000000,0x00000000,0x00000000}},	//   স্থল_, --, --, --, 
   {{0x6298cb7b,0x61ec00ac,0x14840451,0x6d480332}},	//   anto, ıbla, _گھڻي_, _áfai, 
   {{0x7fd40046,0x09b80b98,0x00000000,0x00000000}},	//   дірі, _अर्य, --, --, 
   {{0xe3c4009d,0x71580395,0x00000000,0x00000000}},	//   _эрхү, _грис_, --, --, 
   {{0xa0180267,0xceb801e0,0xddc00395,0x67002982}},	//   riör, йәү_, ебри, _रौनक_, 
   {{0xaf040b96,0x63a001a9,0x65c002d2,0xd8cc0150}},	//   _епил, _yxon, _híhí, _ﺑﺎﻻﻟ, 
   {{0x6a700008,0x2078008f,0x2bbc00dc,0xca240150}},	// [10d60] _hæfi, _לאקא, ्धधा, _ﺼﻴﺭ_, 
   {{0xa01801f4,0x00000000,0x00000000,0x00000000}},	//   liöp, --, --, --, 
   {{0xac74104c,0xe8f8009d,0xebe40117,0xe99000db}},	//   _فاحش, ёлд_, _нонп, رۇرگ, 
   {{0xc6043b29,0x18a000a7,0xab283129,0x98a08f3a}},	//   रण्य_, нахм, _лома_, нихе, 
   {{0x6298cb7c,0xb86445d7,0x3e8403e6,0xac8c02d3}},	//   ynto, بالو, _رشیف, _ነብሶም_, 
   {{0x63a0022e,0x65c001e1,0x81bc0154,0x00000000}},	//   _rxon, _níhí, _অলস_, --, 
   {{0x629801bf,0x7ae8cb7d,0x00000000,0x00000000}},	//   vnto, _çetr, --, --, 
   {{0x2a680327,0x2918cb7e,0x6298cb7f,0x6f0402d0}},	//   _hobb_, mupa_, wnto, kskc, 
   {{0x98a02c05,0x4dc4009e,0xa684cb80,0x18a000ee}},	//   _чите, ্ডিং, _елад, _чатм, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbbb84d53,0xdb2001ed,0x2918cb81,0x2a6803cd}},	//   _आर्क, _öröm, nupa_, _mobb_, 
   {{0x27e4cb82,0x7f94cb83,0x63a0009d,0x2a68031c}},	//   ncon_, дамх, _txon, _lobb_, 
   {{0x23b88073,0xa34800ee,0x2918cb84,0x27e400e4}},	//   _اداب_, _ызда_, hupa_, icon_, 
   {{0x2918cb85,0xd3540375,0x00000000,0x00000000}},	//   kupa_, _מידי_, --, --, 
   {{0xd12c890b,0x27e4cb86,0x2918cb87,0x6d58005b}},	//   _ях_, kcon_, jupa_, ätap, 
   {{0x29180309,0x213c0042,0x3e5400b8,0x00000000}},	//   dupa_, mwth_, _ṛtā_, --, 
   {{0x2a680de2,0x27e403cd,0xcb3400a7,0xabb40022}},	// [10d70] _bobb_, dcon_, нетъ, датә, 
   {{0x2918cb88,0x27e400df,0x2a681da7,0x0b8800d4}},	//   fupa_, econ_, _cobb_, їсти_, 
   {{0x2918cb89,0x2a68cb8a,0xf8b02fc0,0xa7a40150}},	//   gupa_, _dobb_, نکر_, _ﻋﺒﺭﺓ_, 
   {{0x3868b41c,0x00000000,0x00000000,0x00000000}},	//   ðar_, --, --, --, 
   {{0x7c2ccb8b,0x36682773,0x08d40214,0x00000000}},	//   mfar, жало_, رآمد, --, 
   {{0x55c0cb8c,0x2918006a,0x7c2ccb8d,0x668001d5}},	//   налғ, bupa_, lfar, نیقل, 
   {{0xa3c80490,0xe5a001a9,0x80d8000d,0xdb0c013a}},	//   ळेस_, киши, _नंगे, _mycí, 
   {{0x7c2ccb8e,0x6a70032e,0x9f4801e7,0xdef00023}},	//   nfar, _ræfi, nacó_, ግሶን_, 
   {{0x7c2ccb8f,0x72c4013e,0x2a681bce,0x48240150}},	//   ifar, мбиз, _yobb_, _سىلق, 
   {{0x7c2c5fc7,0x00000000,0x00000000,0x00000000}},	//   hfar, --, --, --, 
   {{0x0478006c,0x213c03cb,0xa01801f4,0x00000000}},	//   زلیک_, gwth_, tiöp, --, 
   {{0x7c2c0419,0xf8ac012d,0x00000000,0x00000000}},	//   jfar, टकिय, --, --, 
   {{0x7c2c1477,0x2918cb90,0x00000000,0x00000000}},	//   dfar, zupa_, --, --, 
   {{0x34380014,0xa2d8cb91,0xed5801c0,0x63b40158}},	//   _دٲچھ_, नदर्, оог_, _øyna, 
   {{0x2a6800a3,0x00000000,0x00000000,0x00000000}},	//   _robb_, --, --, --, 
   {{0x7c2ccb92,0x79840943,0xa0180112,0x00000000}},	//   gfar, dzhw, rhöc, --, 
   {{0xeb9807dd,0x2a6800e8,0xeab001ed,0x7d140036}},	// [10d80] циа_, _pobb_, نٹر_, arzs, 
   {{0xe9d00075,0x2918cb93,0xfbd06bd8,0xa9941bf4}},	//   نغا_, tupa_, اتِ_, وشات, 
   {{0x6da441e5,0x27e40051,0x00000000,0x00000000}},	//   _цина, tcon_, --, --, 
   {{0x2918cb94,0x7c2ccb95,0x9f48026c,0x7ae800e4}},	//   rupa_, cfar, macò_, _ũete, 
   {{0x29180b58,0x6d4c0158,0xb8640fb4,0x675403af}},	//   supa_, lvba, عامو, بخار, 
   {{0x27e4cb96,0xefa00092,0xa9a4009d,0x00000000}},	//   scon_, _ወንድሙ_, _жигд, --, 
   {{0x27e404fb,0x29184f79,0x2bbc0b98,0xa8a4027d}},	//   pcon_, qupa_, ्धवा, _قصرو, 
   {{0x7b0808a5,0x00000000,0x00000000,0x00000000}},	//   _óstö, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x29080af9,0xe5300124,0x7c2ccb97,0x00000000}},	//   _kvba_, _аҵкь, zfar, --, 
   {{0x7c2c00a9,0xd25400d4,0x2c0c00cd,0x00000000}},	//   yfar, єць_, िणां_, --, 
   {{0x23680849,0x81c003d4,0x69d80174,0x213c0142}},	//   _وحشي_, ংখল_, _útef, rwth_, 
   {{0x62646da1,0x6a7008a5,0x213c0042,0x2bac2e2a}},	//   _ياتق, _hæfu, swth_, _झुला, 
   {{0x9f480ffb,0x38b405ac,0x5330cb98,0x6a7002d2}},	//   facò_, lårt_, _решт, _kæfu, 
   {{0xc348001e,0x61e8cb99,0x7c2c4ebd,0xdb0c02f0}},	//   _hổ_, _iffl, tfar, _vycí, 
   {{0x670c02ab,0x490837c8,0x00000000,0x00000000}},	//   _सिंक_, _हिजो_, --, --, 
   {{0x6d4c010a,0x7c2c48ed,0x9f4801e7,0x6f280210}},	// [10d90] avba, rfar, racó_, ępcó, 
   {{0x29080d27,0xc348001e,0x38b4007c,0x5ce4004e}},	//   _bvba_, _mổ_, hårt_, _оюма, 
   {{0x7c2ccb9a,0xc348004d,0x58840209,0x6a7002d2}},	//   pfar, _lổ_, мыда, _næfu, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x61e8cb9b,0x7bdc94da,0xc348001e,0xae800139}},	//   _offl, _igsu, _nổ_, _çıñn, 
   {{0x3eb00036,0x799400f3,0x2bbc00cd,0x8f9c011a}},	//   nozt_, _зигф, ्धरा, חידי, 
   {{0x955401ed,0xb6c801ed,0x6d4843e9,0x98140150}},	//   بیاء_, _ہائے_, _áfat, _يبرا, 
   {{0xc3480016,0x3ce0000d,0x00000000,0x00000000}},	//   _bổ_, _muhv_, --, --, 
   {{0xc34807ae,0xa3c80574,0x10e002dd,0x14dc00cd}},	//   _cổ_, ळेल_, _ﺍﻟﺸﺨ, _पूरण, 
   {{0x386c77b3,0xda0c73ca,0x7bdc0263,0x3b080194}},	//   _hoer_, ाणित_, _lgsu, isaq_, 
   {{0x386c00af,0x6a70032e,0x8af006be,0x00000000}},	//   _koer_, _gæfu, lxət, --, 
   {{0x386c092e,0x61e82ab9,0x6a70037e,0x7afc03ac}},	//   _joer_, _effl, _hæft, _owst, 
   {{0x386c0942,0xda0c0574,0x6a7001bf,0xc3480208}},	//   _moer_, ाणात_, _kæft, _gổ_, 
   {{0x7bdccb9c,0x386c0660,0xdce4033f,0x6d4c02d0}},	//   _agsu, _loer_, zyją, tvba, 
   {{0x7afccb9d,0x3204cb9e,0x90c8016c,0x00000000}},	//   _awst, maly_, _оғоз_, --, 
   {{0x3204cb9f,0x386c020c,0x7afc0142,0x6d4c007c}},	//   laly_, _noer_, _bwst, rvba, 
   {{0xc348001e,0x7afc0142,0xee380395,0x6a1435b6}},	// [10da0] _xổ_, _cwst, _енп_, فبار, 
   {{0x3204cba0,0x3e7c01e1,0x00000000,0x00000000}},	//   naly_, _tìta_, --, --, 
   {{0x386ccba1,0x3b08cba2,0x7afccba3,0x00000000}},	//   _boer_, asaq_, _ewst, --, 
   {{0x3204cba4,0xfbd0004b,0x7afccba5,0x00000000}},	//   haly_, اتې_, _fwst, --, 
   {{0x6134066d,0x320409a5,0x386ccba6,0x7afc0142}},	//   _külö, kaly_, _doer_, _gwst, 
   {{0x3204cba7,0x2cb0cba8,0xc34801fb,0xd6cc009f}},	//   jaly_, loyd_, _rổ_, مقن_, 
   {{0x3204cba9,0xc3480016,0x7950168d,0x386ccbaa}},	//   daly_, _sổ_, _پێنا, _foer_, 
   {{0x9550415d,0x386ccbab,0xf9c40304,0x83340305}},	//   اخوا, _goer_, _расү, вних, 
   {{0x32040851,0xe618c34f,0x9cd40375,0xa018032e}},	//   faly_, _нда_, עופה_, fhön, 
   {{0x3204cbac,0xfcf002d3,0x386c01f5,0x2c7c0118}},	//   galy_, ፍለጥ_, _zoer_, růdy_, 
   {{0xd6cccbad,0x5a14008f,0x386c0051,0x00000000}},	//   _اقل_, עקטן_, _yoer_, --, 
   {{0xc34807ae,0x00000000,0x00000000,0x00000000}},	//   _tổ_, --, --, --, 
   {{0x3204cbae,0x6d58cbaf,0x9310cbb0,0x00000000}},	//   baly_, åtan, _مونش, --, 
   {{0xa01803fa,0x61e803ac,0xe2441e5a,0x00000000}},	//   chön, _uffl, _سختي, --, 
   {{0x3b0803f0,0x51500137,0xe194013d,0x2bec110e}},	//   wsaq_, _مئيز, _ярдэ, _ọjọ_, 
   {{0x3b08353d,0x40a86646,0xc03400f3,0x00000000}},	//   tsaq_, _تختی_, _рниј, --, 
   {{0x386ccbb1,0x3b08013c,0x613400e5,0x7c280139}},	// [10db0] _roer_, usaq_, _fülö, _öerm, 
   {{0x3b08cbb2,0x386c688b,0x7afc00b5,0xfd740139}},	//   rsaq_, _soer_, _vwst, _алоэ, 
   {{0x3b0832ff,0x98b009a8,0xfbc40073,0x5b0000f1}},	//   ssaq_, žeča_, लेजम, _څېرم, 
   {{0x3204cbb3,0xb06402f6,0x5b00004b,0x4878177b}},	//   zaly_, mpää, _مېرم, нсія_, 
   {{0xf744cbb4,0x386c0e29,0xb064000d,0x41e0cbb5}},	//   тело, _voer_, lpää, नशास, 
   {{0x386c168a,0x2a7800d8,0x9a84013e,0x38b4005c}},	//   _woer_, ckpb_, _чумл, tårs_, 
   {{0x3204cbb6,0x386ccbb7,0xb06402f6,0xf4240139}},	//   valy_, _toer_, npää, _çäke_, 
   {{0x32043c30,0x38b400b5,0x01b8009e,0x6284017a}},	//   waly_, rårs_, ুখাদ, ëkon, 
   {{0x3204cbb8,0x53a000cf,0xf8ac134e,0x00000000}},	//   taly_, دۅشك, टकीप, --, 
   {{0x20d800b0,0xdea802a8,0x8acc0150,0x00000000}},	//   _rūia_, ƙiƙa, _ﺒﺎﻟﻅ, --, 
   {{0x3204cbb9,0x71a418cd,0xd00400c7,0xcae800fe}},	//   raly_, танз, лонқ, _পিছফ, 
   {{0x3204cbba,0xa5c00166,0x5e540014,0xa01801f4}},	//   saly_, _төче, ۆلُس_, hköf, 
   {{0x3204cbae,0x4094084c,0xb06401f4,0xa018007c}},	//   paly_, урэт, epää, mhöl, 
   {{0x6da4cbbb,0x00000000,0x00000000,0x00000000}},	//   вига, --, --, --, 
   {{0x81746a72,0x7168009d,0x00000000,0x00000000}},	//   _منوچ, _цайг_, --, --, 
   {{0x6f9400c6,0x81e8015b,0x81c00137,0x8af006be}},	//   _للعض, বরণ_, _دەپۇ, dxər, 
   {{0x332c07ab,0xaec400cf,0xb0640108,0xa8400133}},	// [10dc0] ntex_, _ибил, apää, یکرۆ, 
   {{0x78a8008f,0xed5810de,0x00000000,0x00000000}},	//   _ĉeva, _жоо_, --, --, 
   {{0xa924cbbc,0x2cb00076,0x68e001e4,0xacc80107}},	//   тдел, poyd_, ĉodo, _огоз_, 
   {{0xd1f402d3,0x7b08002f,0x00000000,0x00000000}},	//   _ዉድብ_, ßstü, --, --, 
   {{0xdd8ccbbd,0x00000000,0x00000000,0x00000000}},	//   _هوی_, --, --, --, 
   {{0x26d80793,0x26ccbd4b,0xa018002f,0x00000000}},	//   öpo_, umfo_, cköf, --, 
   {{0x291c00c7,0x5e9800d9,0x2be408ec,0x00000000}},	//   _êta_, ובסק, _कलां_, --, 
   {{0x6abc0112,0xd49407e6,0x00000000,0x00000000}},	//   llpf, кры_, --, --, 
   {{0x82d8cbbe,0x00000000,0x00000000,0x00000000}},	//   ндис_, --, --, --, 
   {{0x29180194,0xc1e800f1,0xe2a80531,0xb06401f4}},	//   orpa_, رکتل_, بابن_, ypää, 
   {{0xa0180165,0x60cc1c7e,0x6d58007c,0x00000000}},	//   nkög, tmcm, åtal, --, 
   {{0xa01804cc,0x332c123b,0x6abc002f,0xe4d4cbbf}},	//   chöl, btex_, hlpf, _شتاب, 
   {{0xe28401b9,0x6b7800ef,0x60cc02d0,0xa01801f4}},	//   _илди, _jāgā, rmcm, hkög, 
   {{0x4ea4352d,0x29180e04,0xd24c0050,0x00000000}},	//   арса, krpa_, _ونن_, --, 
   {{0x20c4022e,0x00000000,0x00000000,0x00000000}},	//   _исиг, --, --, --, 
   {{0x442401c7,0xa3b4012d,0xb06401f4,0x00000000}},	//   ngm_, चअप_, rpää, --, 
   {{0xb064023a,0x37e401b9,0xc1b400c7,0x6b7800cd}},	// [10dd0] spää, қолг, _шәҩы, _nāgā, 
   {{0xdce40034,0xb064023a,0x89a801d9,0x00000000}},	//   zyję, ppää, چھِہ_, --, 
   {{0x3914cbc0,0x291c01e6,0xa0180793,0x3c940117}},	//   умер, _åtal_, rköf, _бинё, 
   {{0x2bac7db3,0x332c0204,0x9770446e,0xdb200271}},	//   _झुका, ytex_, итлә, _پوسی, 
   {{0x2918cbc1,0x00000000,0x00000000,0x00000000}},	//   arpa_, --, --, --, 
   {{0x7ac80583,0x332ccbc2,0x81e803d4,0x35a4009d}},	//   _سوزِ_, vtex_, বৰত_, лалг, 
   {{0x2918007f,0x27ec00bc,0x0f580092,0x25f00037}},	//   crpa_, émní_, _ሊያስከ, ँड़ी_, 
   {{0x332c038f,0xe1f40598,0xf3480108,0x8ddc00df}},	//   ttex_, ңгы_, епил_, וקוק, 
   {{0x97000075,0x6b780421,0x6aa800d2,0xa018cbc3}},	//   _ئېتى, _gāgā, _ímfê, rhöl, 
   {{0x332ccbc4,0x05740075,0x36d4a577,0x61640023}},	//   rtex_, _ھالد, _созр, _ትካላዊ_, 
   {{0x2ef005e4,0xce580133,0x00000000,0x00000000}},	//   _styf_, ۆڤدا_, --, --, 
   {{0xa01801e3,0x0584004e,0x6b78002b,0x00000000}},	//   lhöj, _туум, _yāgā, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdee0cbc5,0x2464035b,0x6724143a,0xf1c802dd}},	//   сори, _ахәҳ, _åkje, _كوشى_, 
   {{0xd1b8044e,0x81bc00e2,0xafe4030d,0xa3e80b4c}},	//   ደልቲ_, sfēr, _йойл, _मलम_, 
   {{0xdd8ccbc6,0x5f7403e6,0x629401e1,0x00000000}},	//   سوق_, _ڕاپر, _ìyor, --, 
   {{0xa01801e3,0xf3f400cc,0x00000000,0x00000000}},	// [10de0] khöj, _ইযাৰ_, --, --, 
   {{0x6a84121c,0x66e41086,0x2d9cb433,0x8af00213}},	//   ылза, ҳода, ûtes_, vvəd, 
   {{0xaf3462cd,0x290c43e5,0xe8f87e09,0x627800df}},	//   _شرکت, éfa_, хле_, ענענ, 
   {{0x66e4cbc7,0xa2c802a0,0x29180327,0x00000000}},	//   года, _सीन्, rrpa_, --, 
   {{0x2bb80597,0xd1e401f3,0xa3e80037,0x00000000}},	//   _ساحة_, ሙላት_, _मलब_, --, 
   {{0x96b40063,0xa01801e3,0x96300006,0x97e40372}},	//   лују_, ghöj, йніц, _ۅتكۅ, 
   {{0x2bbc9d35,0xbab000cf,0x387c0334,0xa018007c}},	//   ्धका, _بۅلب, bkwr_, lköe, 
   {{0x17800ce8,0x00000000,0x00000000,0x00000000}},	//   ргәм, --, --, --, 
   {{0xdc38010f,0x00000000,0x00000000,0x00000000}},	//   געפר, --, --, --, 
   {{0x67200006,0xa01801d3,0x00000000,0x00000000}},	//   muoj, zköd, --, --, 
   {{0xb1442491,0xd6540375,0x6720cbc8,0xc1a402dd}},	//   لیوم_, _תיבת_, luoj, рыпқ, 
   {{0x26dccbc9,0x1fdc02ab,0x66080067,0xe0840592}},	//   _hito_, नखेड, lafk, اجدي, 
   {{0x26dccbca,0x672002d5,0x937412d3,0x3b780092}},	//   _kito_, nuoj, _مصور_, _በሺዎች_, 
   {{0x6608cbcb,0x93401142,0x26dc00b8,0x00000000}},	//   nafk, _ынче, _jito_, --, 
   {{0x6298cbcc,0xbdd4005b,0x67200254,0x9ce400e5}},	//   mito, ровщ, huoj, اورے_, 
   {{0x6298cbcd,0x26dccbce,0x67200006,0x78a801e4}},	//   lito, _lito_, kuoj, _ĉevo, 
   {{0x26dc0a62,0x2d9c07ea,0x660805b1,0x2008cbcf}},	// [10df0] _oito_, ûter_, kafk, maci_, 
   {{0x26dcbcc3,0x2008cbd0,0x60dc014f,0x6720cbd1}},	//   _nito_, laci_, _hiqm, duoj, 
   {{0x66080014,0x19a800d1,0x17c000c7,0x00000000}},	//   dafk, хтап_, әалҭ, --, 
   {{0x26dccbd2,0x6298cbd3,0x89340491,0x92dc00fe}},	//   _aito_, hito, إعلا, ধীয়_, 
   {{0x6298cbd4,0x26dc93ea,0x67200006,0x66080067}},	//   kito, _bito_, guoj, fafk, 
   {{0x6298cbd5,0x26dccbd6,0x870434d8,0x2008cbd7}},	//   jito, _cito_, сяце, haci_, 
   {{0x26dc357f,0x2008cbd8,0xa018cbd9,0xe690c019}},	//   _dito_, kaci_, rhöj, تلود, 
   {{0x973053f3,0x2008181f,0x26dc0077,0x60dc0477}},	//   _هکتا, jaci_, _eito_, _niqm, 
   {{0x20080bb8,0x26dccbda,0xd624cbdb,0x78a80dde}},	//   daci_, _fito_, _معاي, _ijev, 
   {{0x26dccbdc,0x128401b9,0xa0180112,0x6d58248f}},	//   _gito_, امدی_, lhöh, åtak, 
   {{0x60dc014f,0x78a808fb,0x2008cbdd,0x425402d5}},	//   _biqm, _kjev, faci_, стыт, 
   {{0x26dc01c8,0x62980421,0x2008cbde,0xa0180e78}},	//   _zito_, aito, gaci_, nhöh, 
   {{0xa3e80037,0x00000000,0x00000000,0x00000000}},	//   _मलत_, --, --, --, 
   {{0x78a8c75b,0xa018002f,0x00000000,0x00000000}},	//   _ljev, hhöh, --, --, 
   {{0x672002d5,0x60dc0548,0x78a8035b,0x1d04329b}},	//   zuoj, _fiqm, _ojev, иери_, 
   {{0x78a80200,0x00000000,0x00000000,0x00000000}},	//   _njev, --, --, --, 
   {{0x60d40bd9,0x802402dd,0xab642bb6,0x6b642852}},	// [10e00] _דוקא_, _ارىم, швал, шкаа, 
   {{0x78a80022,0x291c00fe,0xece83c18,0x6720391d}},	//   _ajev, _åtak_, _идол_, vuoj, 
   {{0x26dccbdf,0x9608015b,0x00000000,0x00000000}},	//   _rito_, রলাম_, --, --, 
   {{0x26dccbe0,0x6298cbe1,0x67200006,0x78a81e31}},	//   _sito_, zito, tuoj, _cjev, 
   {{0x78a81727,0x6298cbe2,0x26dccbe3,0x25bc05da}},	//   _djev, yito, _pito_, _sytl_, 
   {{0x672002d5,0x26dc23e0,0x78a80022,0x2008012c}},	//   ruoj, _qito_, _ejev, zaci_, 
   {{0x6298cbe4,0x26dc06e4,0x2008cbe5,0x6608cbe6}},	//   vito, _vito_, yaci_, rafk, 
   {{0x6298cbe7,0x26dc0451,0x78a80183,0x67200024}},	//   wito, _wito_, _gjev, puoj, 
   {{0x224c0270,0x439412b9,0x60dc047e,0xe648009b}},	//   _pafk_, сапс, _riqm, _ипад_, 
   {{0x2008cbe8,0x26dc0270,0x60dc014f,0x78a800bc}},	//   waci_, _uito_, _siqm, _zjev, 
   {{0x2008cbe9,0xa444722e,0x78a80240,0x5bc0085c}},	//   taci_, _внед, _yjev, _शर्व, 
   {{0x6298cbea,0xf38401e0,0xc1a401ec,0x3cec01f9}},	//   sito, рҙәй_, _қылқ, _आंबे_, 
   {{0x2d9ccbeb,0xfa100154,0x00000000,0x00000000}},	//   úten_, স্টল_, --, --, 
   {{0x6298cbec,0x3afc0241,0x92b0007b,0xfb8800d1}},	//   qito, _lápò_, _وحوا, ңрақ_, 
   {{0xa3e82413,0x2008cbed,0xddcc0006,0x248401f5}},	//   _मला_, paci_, ūdži, _klom_, 
   {{0x9cc807ee,0x908800cf,0x00000000,0x00000000}},	//   тыга_, _ۅنۉك_, --, --, 
   {{0x24840211,0x7a384137,0xa3c80574,0x3c04036b}},	// [10e10] _mlom_, лпар_, ळेच_, _қўнғ, 
   {{0x78a81f7f,0x628402d3,0x248400cf,0x2b4400d8}},	//   _sjev, ëkoh, _llom_, çoca_, 
   {{0x78a822c1,0x9964cbee,0x24840170,0xa018002f}},	//   _pjev, штал, _olom_, thöh, 
   {{0xa018002f,0x00000000,0x00000000,0x00000000}},	//   uhöh, --, --, --, 
   {{0xa01803fa,0x69d8000f,0x7f4c031c,0x78a81710}},	//   rhöh, _úten, _jsaq, _vjev, 
   {{0xa018245f,0x2484cbef,0x7aec65b1,0x98f41291}},	//   shöh, _alom_, mqat, _نثرا, 
   {{0x2484cbf0,0x2c6c010e,0x7aec6eb0,0x3d14012d}},	//   _blom_, _aýdy_, lqat, _तटों_, 
   {{0x7aec0eda,0x2484cbf1,0x7f4c0fec,0x78a8bcf3}},	//   oqat, _clom_, _osaq, _ujev, 
   {{0x7f4c0327,0x7aec6b88,0x7374013d,0x00000000}},	//   _nsaq, nqat, сыйх, --, 
   {{0x2484003e,0x7aec9585,0xc67400c6,0xf4b800cc}},	//   _elom_, iqat, _وطلب, ুদেব, 
   {{0x7f4ccbf2,0xafe404a9,0x248408fb,0x6aa00c6a}},	//   _asaq, йонл, _flom_, éofi, 
   {{0xb7bc00a8,0x42c80228,0x7aec009a,0x00000000}},	//   _acţi, лгөн_, kqat, --, 
   {{0xafe4036b,0xec7801ec,0x68e001e4,0x245002f2}},	//   _қопл, қпа_, ĉodi, _رنوس, 
   {{0x24845653,0xa1400171,0x00000000,0x00000000}},	//   _zlom_, _šķen, --, --, 
   {{0x7f4c0921,0x7aec20ac,0x2d7c0331,0x70f41a9b}},	//   _esaq, eqat, _oćeš_, _استئ, 
   {{0x300401b9,0xfca800f1,0x7aec01d5,0x3028030d}},	//   _узиг, لاقو_, fqat, _соип_, 
   {{0x7aec00f1,0x2bc8cbf3,0x2fc4032e,0x6dc000cf}},	// [10e20] gqat, улап_, _áog_, تۅگۅ, 
   {{0xa968cbf4,0xee2428e8,0x3afc01e1,0x2a08215c}},	//   лиза_, _умоп, _sápò_, اقاپ_, 
   {{0xefd40020,0x7aec0eda,0x7de00174,0x00000000}},	//   ያያዝ_, aqat, rásø, --, 
   {{0x628400b0,0xa764004e,0x00000000,0x00000000}},	//   īkoi, йкед, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfd6407ae,0x248407f5,0xa01801f4,0x00000000}},	//   _nguồ, _slom_, rhöi, --, 
   {{0x24843813,0xa018023a,0x291c47f1,0xd8580166}},	//   _plom_, hköa, _íta_, _өчтә_, 
   {{0x7b0802d2,0x00000000,0x00000000,0x00000000}},	//   _ðstö, --, --, --, 
   {{0xf8700075,0x24840010,0x4adc01f9,0x00000000}},	//   _تۇنج, _vlom_, _बळाव, --, 
   {{0x2730084c,0xbae4015b,0x3d1800c5,0x00000000}},	//   mân_, _পৌঁছ, _बटले_, --, 
   {{0x2730334b,0xe3b0cbf5,0xd25402d5,0x24840010}},	//   lân_, _کرا_, сцы_, _tlom_, 
   {{0x248401b9,0x7aec022e,0x00000000,0x00000000}},	//   _ulom_, yqat, --, --, 
   {{0x7d040399,0xdb0c0798,0x00000000,0x00000000}},	//   _swhs, _excê, --, --, 
   {{0xfe78016c,0x00000000,0x00000000,0x00000000}},	//   рӯи_, --, --, --, 
   {{0x40342e3f,0x27300368,0x6b140327,0xca64022e}},	//   _дейс, hân_, ྲེའོ_, vriа, 
   {{0xc1b400c7,0x7f4ccbf6,0x7bf8cbf7,0x9f68399f}},	//   _гәҭы, _tsaq, рнар_, _броз_, 
   {{0x7aec0cfe,0x3a74cbf8,0x1ea868b0,0x7f4c0986}},	// [10e30] uqat, олар, _مادي_, _usaq, 
   {{0x9e04cbf9,0xefd40020,0x7aeccbfa,0x99642cc8}},	//   _учил, ያያዘ_, rqat, йтел, 
   {{0x7aec1bb7,0xfb08002e,0x69d8000f,0x97a402d9}},	//   sqat, _blëë_, _útel, әрел, 
   {{0x17f800c6,0x00000000,0x00000000,0x00000000}},	//   ارضة_, --, --, --, 
   {{0x7aeccbfb,0x7c3ccbfc,0x5a380408,0x290c0332}},	//   qqat, _ibsr, _йывă, áfar_, 
   {{0xa01804cc,0xbc4400db,0xcd340244,0x00000000}},	//   chöv, _ارگۉ, _بریب, --, 
   {{0xd7f8cbfd,0xefd4001f,0x00000000,0x00000000}},	//   _буз_, ያያዙ_, --, --, 
   {{0x2730045f,0x52b000dc,0x89a81e24,0x00000000}},	//   bân_, ुत्स, _اُفق_, --, 
   {{0xb22473b7,0x5800cbfe,0xd764030c,0x10e00150}},	//   омпл, _моңғ, _دەشى_, _ﺍﻟﺘﺨ, 
   {{0x727800d8,0x00000000,0x00000000,0x00000000}},	//   рсис_, --, --, --, 
   {{0xc6680cfc,0x7c3c02d0,0xf4343cc5,0xf0a800f5}},	//   _уште_, _obsr, _межэ, икол_, 
   {{0x649c0618,0x7e640208,0x5f18000d,0x4ad000bc}},	//   lūin, _anhp, _बिश्_, _तीनव, 
   {{0xf2680108,0x00000000,0x00000000,0x00000000}},	//   _вилл_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x26c00134,0xa01810ee,0x00000000,0x00000000}},	//   _ɔko_, mkön, --, --, 
   {{0x2b38084c,0xa018002f,0x20c801ab,0x00000000}},	//   иязэ_, lkön, lùin_, --, 
   {{0xdca0006c,0x89a800fb,0x70f4009f,0x00000000}},	// [10e40] фати, әйең_, _اسڪئ, --, 
   {{0xa018cbff,0xa9f80068,0xa9a421b4,0x00000000}},	//   nkön, рхах_, оизд, --, 
   {{0x3dcc03f9,0xa018002f,0x00000000,0x00000000}},	//   ƙewa_, ikön, --, --, 
   {{0x27300a85,0xab28cc00,0xa01833b4,0x18a0cc01}},	//   tân_, _кома_, hkön, махм, 
   {{0xa018cc02,0x00000000,0x00000000,0x00000000}},	//   kkön, --, --, --, 
   {{0x16a407d6,0x649c0421,0x6d5c6b48,0xea6001ed}},	//   овчи_, gūin, _krpa, _تھری, 
   {{0x2730000f,0x98a4054e,0x00000000,0x00000000}},	//   sân_, înă_, --, --, 
   {{0x69cccc03,0x5f1803ce,0x2614000d,0x00000000}},	//   _izbe, _बिल्_, _नयकी_, --, 
   {{0xd7ec00c6,0x648c00a3,0xa01802d2,0x15680116}},	//   _شكل_, _lùig, fkön, _ﻳﯧﺸﯩ, 
   {{0x68fc08fb,0xa01801d3,0xdb9800df,0x67200200}},	//   oppd, gkön, יספר, mroj, 
   {{0x2b4005b1,0xdb0ccc04,0x21640a4a,0x00000000}},	//   _lpkc_, _excè, ітог, --, 
   {{0x6e3c05b1,0x490c121d,0x67200108,0xa2e4014b}},	//   _abpb, डीयो_, oroj, _додд, 
   {{0x98b007f5,0x6d5ccc05,0x6720cc06,0x14d4008f}},	//   žeća_, _arpa, nroj, _וואל_, 
   {{0x6d5c020b,0x69cccc07,0xa018007c,0xc69400df}},	//   _brpa, _ozbe, ckön, לאָ_, 
   {{0x6288cc08,0x6720cc09,0x6d5c0010,0xd12c0354}},	//   _ilfo, hroj, _crpa, _юх_, 
   {{0xbca400c6,0x6d5c01a6,0x6720cc0a,0x3f140c17}},	//   أمري, _drpa, kroj, _едис, 
   {{0x6d5c0c8c,0xcb3400a7,0x6720c9d5,0xfa5c0092}},	// [10e50] _erpa, метъ, jroj, _ለማልማ, 
   {{0x6720cc0b,0x7c3c010a,0xc5e401d3,0x00000000}},	//   droj, _wbsr, _لۓ_, --, 
   {{0xdcec005f,0x67200124,0x6f1400d7,0x99280108}},	//   ēdēt, eroj, _zvyc, рюза_, 
   {{0x9c6000db,0x7c3c02d0,0x67200200,0x00000000}},	//   _تۇرو, _ubsr, froj, --, 
   {{0x69cccc0c,0x649c0421,0x6f14003e,0x648c01c3}},	//   _ezbe, tūin, _xvyc, _mùid, 
   {{0x55c0cc0d,0x00000000,0x00000000,0x00000000}},	//   малғ, --, --, --, 
   {{0x19e000c7,0x7c2c0437,0xa018007c,0x8af003b9}},	//   _цәаҳ, ogar, nhös, hvəl, 
   {{0xddc40030,0xe7940cbe,0x00000000,0x00000000}},	//   rejň, _کافک, --, --, 
   {{0x7c2ccc0e,0xf5583e1a,0x00000000,0x00000000}},	//   igar, _گلاب_, --, --, 
   {{0x7c2c00a9,0x8af000ac,0x2f20032e,0x69cc0200}},	//   hgar, dvəl, _lægð_, _yzbe, 
   {{0x7c2ccc0f,0xa018cc10,0x648c01ab,0xe1f4a5c1}},	//   kgar, rkön, _bùid, ягэ_, 
   {{0xefc82295,0x2eb4296e,0xdb0ccc11,0x6288cc12}},	//   _በላይ_, ृत्त, _excé, _elfo, 
   {{0xe28c1b10,0x7c2ccc13,0x6d5cb745,0xad680022}},	//   _за_, dgar, _srpa, әабз_, 
   {{0x7c2ccc14,0xbc2400d1,0x00000000,0x00000000}},	//   egar, ېرلى, --, --, 
   {{0x7c2ccc15,0x9f48026c,0x648c00a3,0x6f140175}},	//   fgar, accà_, _fùid, _wvyc, 
   {{0x7c2ccc16,0xeb98cc17,0x6720cc18,0xa018950c}},	//   ggar, биб_, yroj, nköl, 
   {{0xfbd000dd,0xa2940345,0x00000000,0x00000000}},	// [10e60] ہتے_, _بدۆڵ, --, --, 
   {{0x7c2ccc19,0x6d5ccc1a,0xa018023a,0x68fc010a}},	//   agar, _trpa, hköl, tppd, 
   {{0x7c2ccc1b,0x6d5c02d1,0xa0181876,0x68fc01e3}},	//   bgar, _urpa, mhör, uppd, 
   {{0x2b40070d,0x7c2c0171,0x00000000,0x00000000}},	//   _tpkc_, cgar, --, --, 
   {{0x18b00b8d,0xd7e00212,0xd700010b,0x3ce00073}},	//   хәрр, нішо, езчи, _कळते_, 
   {{0xa96821cc,0x6720cc1c,0x6e2c020c,0xa0180112}},	//   _лига_, rroj, ngbb, nhör, 
   {{0x69cccc1d,0x9c808e70,0x22a00241,0xd83c0010}},	//   _uzbe, ščev, _lékè_, ščar_, 
   {{0x6abc0564,0xa018007c,0x00000000,0x00000000}},	//   lopf, hhör, --, --, 
   {{0x68ec0009,0xe618005b,0xe3b000d1,0xa0183bba}},	//   _hubd, _гдз_, عرع_, khör, 
   {{0xaabcc2fc,0x7c2ccc1e,0x6abc05b8,0x8af003be}},	//   ्तिक, zgar, nopf, vvəl, 
   {{0x7c2ccc1f,0x00000000,0x00000000,0x00000000}},	//   ygar, --, --, --, 
   {{0x7c2c01d9,0x23281eed,0x33380050,0x6abc002f}},	//   xgar, _годи_, _ژٲنگ_, hopf, 
   {{0x7c2c2b05,0xaabcc853,0xa0180e78,0x9f480ffb}},	//   vgar, ्ताक, fhör, uccà_, 
   {{0x6288cc20,0xc66000b7,0xa018007c,0xf3c802f2}},	//   _ulfo, _ሶማሊያ_, thös, _ببمه_, 
   {{0xd2380302,0xa0180793,0x3cec01e4,0x95980023}},	//   _הגול, lköm, ĉevo_, _ንዕዳጋ_, 
   {{0x7c2ccc21,0xf1a805d9,0xa018007c,0x00000000}},	//   ugar, _باهه_, rhös, --, 
   {{0xebc000d1,0x6d5801e3,0x6abcb915,0x4bb401f0}},	// [10e70] вәрн, åtar, fopf, ейтс, 
   {{0x7c2ccc22,0xa0180036,0x9e04010b,0x200c0037}},	//   sgar, chör, _эчил, _õgib_, 
   {{0x69f00046,0xfcc40022,0xa018005b,0x38347ecf}},	//   түст, _жәам, hköm, днер, 
   {{0x68eccc23,0x670000b4,0xc8640063,0xa01801f4}},	//   _dubd, _ọkac, етљи, kköm, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x61e8020c,0x68ec003a,0xd8744f6f,0x068401ec}},	//   _ngfl, _fubd, _کاسب, нгін, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x61e80857,0x336480d7,0x041400d1,0x00000000}},	//   _agfl, двиг, ىكىڭ, --, 
   {{0x7afc0a73,0x68ec03f9,0x2d9c0129,0x291c007c}},	//   _jtst, _zubd, ûtez_, _åtar_, 
   {{0x9f8800a2,0x09b0015b,0x68ec0477,0x63a400e5}},	//   _döüm_, _করতা, _yubd, úkna, 
   {{0xc6680032,0x00000000,0x00000000,0x00000000}},	//   _эште_, --, --, --, 
   {{0xbe2400bd,0x7afccc24,0x6abccc25,0xf3d40150}},	//   ম্মদ_, _otst, zopf, _ققاج, 
   {{0x7afccc26,0xa018cc27,0x6fdc146b,0x00000000}},	//   _ntst, thör, _नृशं, --, 
   {{0x09d800cc,0xdbc408a5,0x7c2800de,0x00000000}},	//   দুটা, _röði, _ķera, --, 
   {{0x3204cc28,0x7afccc29,0x6d4c0cf9,0xa0180624}},	//   mbly_, _atst, uwba, rhör, 
   {{0x69d8cc2a,0x68ec0198,0x32040ea0,0xa018cc2b}},	//   _útei, _rubd, lbly_, shör, 
   {{0x68eccc2c,0x6abc888b,0x61f401b8,0xa01808c5}},	// [10e80] _subd, topf, _äglö, phör, 
   {{0x68eccc2d,0x32040af9,0xf1d00210,0x00000000}},	//   _pubd, nbly_, _हरान, --, 
   {{0x6abc0225,0x7afc0086,0x00000000,0x00000000}},	//   ropf, _etst, --, --, 
   {{0x6abccc2e,0x7640cc2f,0x00000000,0x00000000}},	//   sopf, _ably, --, --, 
   {{0xc6601772,0x9b0002e8,0x98a00063,0x00000000}},	//   _ሶማልያ_, _изяд, њиче, --, 
   {{0x68ec01b9,0xa924cc30,0x2908cc31,0x46144e77}},	//   _tubd, _одгл, _twba_, روبر, 
   {{0xf8accc32,0x00000000,0x00000000,0x00000000}},	//   _бө_, --, --, --, 
   {{0x7afccc33,0x3d100cb4,0x96600139,0x00000000}},	//   _ytst, _तबसे_, екәе, --, 
   {{0xe618cc34,0xa22404fb,0x73c002d9,0x98a021b4}},	//   _мда_, ورده, ләше, _рите, 
   {{0xa018cc35,0x32040ea0,0xa80000fd,0x00000000}},	//   rköm, gbly_, _ğıyb, --, 
   {{0x4034cc36,0x758000f2,0x00000000,0x00000000}},	//   ненс, _میوم, --, --, 
   {{0x442000c7,0x320475cd,0x80c8012d,0xdb0c01e1}},	//   _ÿi_, ably_, रतें, _ńdíw, 
   {{0x3204cc37,0x4fc401c0,0xc0c4013d,0xa018007c}},	//   bbly_, всра, _җәни, lkök, 
   {{0x6264215c,0x00000000,0x00000000,0x00000000}},	//   _زاتق, --, --, --, 
   {{0x7afc00b5,0x644000d8,0x7c8801ec,0xbc6400c7}},	//   _stst, _kboi, пшаң_, нхақ, 
   {{0xbf3402bf,0xa0180112,0x00000000,0x00000000}},	//   _знищ, chöp, --, --, 
   {{0xdde865fe,0xa018023a,0x6440cc38,0x69c8002f}},	// [10e90] _ورده_, hkök, _mboi, üfen, 
   {{0x2a680798,0xdc0002f0,0x7e98129e,0x0ab8104c}},	//   _cnbb_, mčík, _رنجر_, وطلب_, 
   {{0x64400086,0x2a680fac,0xdc0002f0,0x2440022e}},	//   _oboi, _dnbb_, lčík, kаm_, 
   {{0x3868cc39,0xf1a00037,0x3c9401a9,0x00000000}},	//   ñar_, _ओइसन, _чимё, --, 
   {{0x7afc5243,0x36680f37,0xdc000306,0xa01801f4}},	//   _utst, зало_, nčík, tköj, 
   {{0x64404a85,0x00000000,0x00000000,0x00000000}},	//   _aboi, --, --, --, 
   {{0xaabca3c6,0xa2c061f2,0xa01801f4,0x00000000}},	//   ्तरक, रकन्, rköj, --, 
   {{0xa3b845bf,0x3ea0004d,0xb7940451,0x14600022}},	//   _आँख_, _lmht_, _ٻارڙ, теиҭ, 
   {{0x644001ab,0x48243e52,0x3204017a,0xdc0002f0}},	//   _dboi, _جىقق, tbly_, jčík, 
   {{0x64400076,0xc6a4030d,0x00000000,0x00000000}},	//   _eboi, _ирхи, --, --, 
   {{0x3204cc3a,0x04783463,0x644001ab,0x79840472}},	//   rbly_, سلیک_, _fboi, nyhw, 
   {{0x644001e1,0x32040af9,0xa018005b,0x00000000}},	//   _gboi, sbly_, nköh, --, 
   {{0xa2c817cb,0x63e4030c,0x00000000,0x00000000}},	//   _सीक्, _كيمە, --, --, 
   {{0xf734037e,0x8e840107,0xa0180108,0x00000000}},	//   _mで_, тҳое, hköh, --, 
   {{0x9d40cc3b,0xd1b8007b,0xa0180108,0x00000000}},	//   лерд, _باشا_, kköh, --, 
   {{0xfa08015b,0xeb98036b,0xef18cc3c,0xdc0000d0}},	//   _লাগল_, пиб_, _еми_, bčík, 
   {{0x9c8000d7,0x00000000,0x00000000,0x00000000}},	// [10ea0] áčav, --, --, --, 
   {{0x6ac433f9,0x5ba408ca,0x6b94bfb6,0x00000000}},	//   رقام, хкум_, rzyg, --, 
   {{0x6da4cc3d,0x9c800219,0x78a801e4,0x2a680051}},	//   _чина, ščav, _ĉevr, _vnbb_, 
   {{0xae0402dd,0xe738cc3e,0x00000000,0x00000000}},	//   _توگى, зед_, --, --, 
   {{0xd704cc3f,0x00000000,0x00000000,0x00000000}},	//   енче_, --, --, --, 
   {{0x644001ab,0xb864085b,0xa018b1a0,0x00000000}},	//   _sboi, _یاقو, tkök, --, 
   {{0x6abc6b26,0x24e4011c,0x00000000,0x00000000}},	//   ्तीर, нциг, --, --, 
   {{0xd494cc40,0x04c800ae,0x00000000,0x00000000}},	//   ерь_, بوعي_, --, --, 
   {{0x64400165,0x332c0165,0x43946518,0x2b500208}},	//   _vboi, guex_, тапс, nwyc_, 
   {{0xb5f00220,0x3d1000c5,0xdbc400c5,0xdc000306}},	//   _күші, _तबले_, _tööi, včík, 
   {{0x7d0801fa,0x3ce00490,0x291802d1,0x644000a3}},	//   ćesk, _कळले_, nspa_, _tboi, 
   {{0x6abc5168,0xca2401ec,0x291801f4,0x7c2800ef}},	//   ्तुर, _ﹼﻴﺔ_, ispa_, _ķero, 
   {{0xdef8009d,0xa3b80118,0x00000000,0x00000000}},	//   яын_, _आँट_, --, --, 
   {{0xdc0013d5,0x533006ed,0x12f8011a,0x00000000}},	//   rčík, _сешт, _צהוב, --, 
   {{0xa01802f6,0x64b8025c,0x00000000,0x00000000}},	//   hköi, rċif, --, --, 
   {{0xa01801f4,0xdc000419,0x00000000,0x00000000}},	//   kköi, pčík, --, --, 
   {{0xe0dc026c,0x50d41ec7,0x6abccc41,0x3cec000d}},	// [10eb0] mmò_, _حزور, ्तूर, _आंके_, 
   {{0x61f8cc42,0xa90801a9,0x00000000,0x00000000}},	//   nctl, rxоn, --, --, 
   {{0x7cd8cc43,0x649c00b0,0xa01801f4,0xe9d8030d}},	//   _омор_, pūih, tköh, çка_, 
   {{0xe0dccc44,0x98c4cc45,0x64b80135,0x00000000}},	//   nmò_, رغان, nċid, --, 
   {{0x29180113,0x00000000,0x00000000,0x00000000}},	//   aspa_, --, --, --, 
   {{0xf8680451,0x35a4cc46,0xa0180108,0x4ae401a9}},	//   _ڪمري_, калг, sköh, _бўса, 
   {{0x06741473,0x25f000e1,0xc8640116,0x09e400db}},	//   انىڭ, ुड़ी_, _өтти, _боён, 
   {{0xb46403cc,0x7e840150,0x00000000,0x00000000}},	//   ткил, _ﺭﻀﻴﺕ_, --, --, 
   {{0x386c2e11,0x889400ee,0x53d8012d,0x7374008e}},	//   _iner_, _ситх, मेंश, тыйх, 
   {{0x23600008,0x321000d7,0x00000000,0x00000000}},	//   ækja_, úzy_, --, --, 
   {{0x43740032,0x00000000,0x00000000,0x00000000}},	//   _ҡушт, --, --, --, 
   {{0xa3b8375c,0x00000000,0x00000000,0x00000000}},	//   _आँच_, --, --, --, 
   {{0x386c04cc,0x0478cc47,0x3eb00175,0xb4dc0073}},	//   _mner_, _سلوک_, fnzt_, णगी_, 
   {{0xe0dcc044,0xb1446429,0x29180784,0x3cec03ce}},	//   amò_, _анкл, yspa_, _आंखे_, 
   {{0xca64022e,0x00000000,0x00000000,0x00000000}},	//   tsiо, --, --, --, 
   {{0x09b000bd,0x6f640124,0xa018005b,0xe3b000cc}},	//   _করলা, _авиз, yköi, _চৰিব, 
   {{0xdfcc01ec,0x4a4401ec,0x5f74007b,0x00000000}},	// [10ec0] _ويى_, лмаң, _لميس_, --, 
   {{0x386c04c4,0x29184d89,0x6abc08df,0x00000000}},	//   _aner_, tspa_, ्तेर, --, 
   {{0x386c3e39,0x00000000,0x00000000,0x00000000}},	//   _bner_, --, --, --, 
   {{0x29180158,0x50b401bc,0xc614009e,0xa018005b}},	//   rspa_, ीविष, _সাধা_, tköi, 
   {{0xb8f804fa,0x97c00024,0x64b80135,0x00000000}},	//   _ठी_, айце, nċie, --, 
   {{0x6f000ab7,0x648c00a3,0x96b40063,0xa0180254}},	//   _çocu, _cùin, кују_, rköi, 
   {{0x648c08c2,0xc614015b,0xdc0002f0,0x95040014}},	//   _dùin, _সাদা_, lčák, نہٕے_, 
   {{0x386c00b8,0x2cb03deb,0x64b8031c,0xa01800e5}},	//   _gner_, nnyd_, kċie, lköv, 
   {{0xa6e4cc48,0xdc0002f0,0xc5f800ef,0x00000000}},	//   _ажал, nčák, _paēd_, --, 
   {{0x7c2800da,0x42742bbd,0x69d80306,0xa018a6e1}},	//   _ķerm, угос, _útes, nköv, 
   {{0xd2540153,0x00000000,0x00000000,0x00000000}},	//   тцы_, --, --, --, 
   {{0x44f8cc49,0xa018005b,0x00000000,0x00000000}},	//   _ié_, hköv, --, --, 
   {{0x44f8cc4a,0xe0dc6933,0xd24c04d3,0x909800a7}},	//   _hé_, rmò_, _ژنه_, твят_, 
   {{0x44f8110e,0x236401e4,0x216401b9,0xad9800a2}},	//   _ké_, _iroj_, _атиг, laºy, 
   {{0x44f80570,0xc68400aa,0x9c8002fb,0xd33400b5}},	//   _jé_, _ېې_, áčov, _zデ_, 
   {{0x44f8cc4b,0x80d0015b,0x23645160,0x00000000}},	//   _mé_, _সূর্, _kroj_, --, 
   {{0x44f84e53,0x9bc40108,0x2d9c0419,0x00000000}},	// [10ed0] _lé_, тёвк, úter_, --, 
   {{0x7e5400d6,0x44f800c6,0x386c01bf,0x64b80327}},	//   _своє, _oé_, _sner_, nċib, 
   {{0x648c01c3,0x00000000,0x00000000,0x00000000}},	//   _rùin, --, --, --, 
   {{0x7e98009f,0x00000000,0x00000000,0x00000000}},	//   _آنگر_, --, --, --, 
   {{0xb6f80075,0x44f8cc4c,0x23640211,0xf624009d}},	//   رىغا_, _aé_, _nroj_, гдло, 
   {{0x44f8cc4d,0x57d00574,0xbd880092,0x59d80118}},	//   _bé_, _तरीह, _ዓመትም_, _भरपर, 
   {{0x44f80491,0xe5a0cc4e,0x2364010f,0xd7f8094f}},	//   _cé_, йиши, _aroj_, _жуз_, 
   {{0x23640bb8,0x44f8cc4f,0xf1d00184,0xa0180267}},	//   _broj_, _dé_, ҙөлө, ljöf, 
   {{0x69d8012c,0x44f8cc50,0x648c01ab,0x36d4014b}},	//   _úter, _eé_, _tùin, _боар, 
   {{0x44f80570,0x070800f2,0x8af00213,0x00000000}},	//   _fé_, _شيمي_, mvət, --, 
   {{0x44f8cc51,0x2364cc52,0x98b4033f,0xa0180108}},	//   _gé_, _eroj_, _अदाए, hköu, 
   {{0x010800f2,0x00000000,0x00000000,0x00000000}},	//   کتیو_, --, --, --, 
   {{0x3244cc53,0x44f8cc54,0x2364202a,0xd5840133}},	//   _белг, _zé_, _groj_, _سێکه_, 
   {{0xed58cc55,0x44f8cc56,0xee38080a,0x6da401a9}},	//   ног_, _yé_, энг_, гига, 
   {{0x44f801fb,0x8af003b9,0x00000000,0x00000000}},	//   _xé_, hvət, --, --, 
   {{0x6abccc57,0x0c780201,0x0c9c001f,0xada40032}},	//   ्त्र, _አገሮች_, _ሀገሮች_, _ҡапл, 
   {{0xab643c1b,0xdcac4418,0x4f940116,0x00000000}},	// [10ee0] ывал, سىك_, _әрқу, --, 
   {{0x2004013f,0xfcf000b7,0x66d40194,0xed580b3b}},	//   _ɑnim_, ግለጽ_, kâka, _зоо_, 
   {{0x648c01ab,0xa924cc58,0x6204013a,0xa01800e5}},	//   _bùil, удел, _úplň, rköv, 
   {{0x44f84e4f,0x648c00a3,0x63b40008,0x2d880024}},	//   _ré_, _cùil, _þyng, mybe_, 
   {{0x44f8cc59,0xbb74cc5a,0x648c01c3,0x2d88cc5b}},	//   _sé_, _куръ, _dùil, lybe_, 
   {{0x44f84e53,0x4ab81025,0xc6140154,0x2364036e}},	//   _pé_, _आदिव, _সাহা_, _rroj_, 
   {{0xe2a80014,0x2d88cc5b,0xbfb400cc,0x00000000}},	//   ہادن_, nybe_, _ঘৰাঘ, --, 
   {{0x44f80016,0xd544004b,0x2364cc5c,0xa2a447b8}},	//   _vé_, اليو_, _proj_, टोन्, 
   {{0x68e0cc5d,0xe80805ba,0x44f8cc5e,0x228407d6}},	//   mmod, _ह्या_, _wé_, гунг, 
   {{0x44f8cc5f,0x66e45199,0xd1f002d3,0xa018023a}},	//   _té_, _соза, _ፍርቂ_, hköt, 
   {{0x44f80120,0xa018cc60,0x1a98010f,0x81d40117}},	//   _ué_, kköt, גייע, ронх, 
   {{0x68e0cc61,0x23640419,0x2d88cc62,0x4034005b}},	//   nmod, _troj_, dybe_, шемс, 
   {{0x69cc20ac,0x236402d3,0x68e06df0,0x613800a2}},	//   _lybe, _uroj_, imod, _bälç, 
   {{0x69cc01b9,0x68e0cc63,0x925400cf,0x00000000}},	//   _oybe, hmod, _башт_, --, 
   {{0x69cc17b8,0x9c440354,0x2d886b78,0x9a8401ec}},	//   _nybe, лхал, gybe_, қуал, 
   {{0x217400c7,0xa01801d3,0xe2a80133,0x00000000}},	//   _ауҩр, gköt, _تاڵن_, --, 
   {{0x68e0cc64,0x69cc127b,0x32d8007f,0xbae4007b}},	// [10ef0] dmod, _aybe, sèye_, لكري, 
   {{0x69cc0591,0x68e0cc65,0x8f9c00c8,0x648c0e89}},	//   _bybe, emod, _ריזי, _sùil, 
   {{0xba440165,0x588439fb,0xb9b43adf,0x4fb462b7}},	//   _alïè, лыда, جماع, _نصیر, 
   {{0x68e0cc66,0x69cc037e,0x7d040857,0x00000000}},	//   gmod, _dybe, _iths, --, 
   {{0x69cccc67,0x648c01ab,0xdde80424,0xa7340124}},	//   _eybe, _cùim, _ترکه_, идцә, 
   {{0x63b40158,0x8af000ac,0xab64005f,0xf5042d29}},	//   _øyny, rvət, _daļē, азко, 
   {{0x68e00798,0x6e28002d,0x648c01ab,0x20c801c3}},	//   bmod, _ôfbe, _tùil, nùis_, 
   {{0x26c002d2,0x348403c2,0x68e0cc68,0x00000000}},	//   _íkon_, ргиг, cmod, --, 
   {{0x3b081bb7,0xc61400bd,0xc30400dd,0xd34468c0}},	//   npaq_, _সারা_, یبیو, ایته_, 
   {{0x3b080113,0xa018023a,0x7d0402d0,0x490c00bc}},	//   ipaq_, kkös, _oths, डीको_, 
   {{0x7f4c2b34,0x86e401d9,0xf578cc69,0x3b08014f}},	//   _apaq, _آلو, _جماع_, hpaq_, 
   {{0xafe4cb29,0x39400204,0x3b080986,0x77680327}},	//   ионл, iths_, kpaq_, _krex, 
   {{0x7d04cc6a,0xa8540375,0x8af006be,0x00000000}},	//   _aths, בירה_, hvər, --, 
   {{0x116401ed,0x2d880153,0x332c0254,0x232401a9}},	//   _ملتی_, tybe_, mrex_, _тоши_, 
   {{0xa2c04c83,0x68e0015d,0x42b400f1,0xa018cc6b}},	//   रकर्, ymod, _دلوړ, gkös, 
   {{0xed58039b,0x68e001e7,0x7768cc6c,0x39400f85}},	//   ноҳ_, xmod, _orex, dths_, 
   {{0x69cccc6d,0x68e0cc6e,0x3940180f,0x8af00213}},	// [10f00] _sybe, vmod, eths_, vvəs, 
   {{0x68e0cc6f,0xa018cc70,0x6da40276,0xa968024c}},	//   wmod, sköt, _виоа, киза_, 
   {{0x68e0cc71,0x776800b5,0x05c401ad,0xa018cc72}},	//   tmod, _arex, _लुंब, bjöd, 
   {{0x69cc03c6,0xa018cc73,0xe7840022,0xa7640733}},	//   _vybe, lkör, иуло, икед, 
   {{0x3940cc74,0x7768cc75,0x69cc000f,0x3b080784}},	//   aths_, _crex, _wybe, cpaq_, 
   {{0x69cccc76,0x7d0403ac,0xab640171,0x569000db}},	//   _tybe, _yths, _vaļē, жашт, 
   {{0x68e0cc77,0xa01801e6,0x77680381,0xd5ac06aa}},	//   pmod, ljöe, _erex, وفه_, 
   {{0x64b002ab,0x26042017,0x7768005a,0x7bd000e4}},	//   ुकेश, _स्री_, _frex, _ãkuá, 
   {{0xf7482dcd,0xa2c053b7,0x332c0129,0xe61800c0}},	//   _مجله_, रकल्, grex_, _адз_, 
   {{0xe5a4036b,0x2bdc000d,0xaac407b7,0x00000000}},	//   _кизи, _मरना, वविक, --, 
   {{0x99f4025f,0x45640014,0xb6840150,0xa0186b4e}},	//   יזיה_, _دپاہ, _اشقى, dkör, 
   {{0x3b081bb7,0x00000000,0x00000000,0x00000000}},	//   ypaq_, --, --, --, 
   {{0xe3b0cc78,0x7d040421,0xe298009d,0xa29c09b2}},	//   _برا_, _sths, _иад_, _ओतप्, 
   {{0xb384004b,0xa018cc79,0xa14000ef,0x00000000}},	//   _دجمه, gkör, _šķun, --, 
   {{0x57d00a28,0x2290025a,0x7f4c0113,0x3b080bf1}},	//   _तर्ह, _hâko_, _wpaq, wpaq_, 
   {{0x20c800a3,0x00000000,0x00000000,0x00000000}},	//   rùis_, --, --, --, 
   {{0x6d5829c2,0x9be40212,0x3940045a,0xca64022e}},	// [10f10] ætar, рівк, wths_, tsiа, 
   {{0x996440b9,0x3b08bb52,0x3d9400c7,0x62980208}},	//   ител, rpaq_, _гиор, nhto, 
   {{0x6298023a,0x3b080986,0x49a406ed,0x7d0402d0}},	//   ihto, spaq_, ојца, _uths, 
   {{0x7768172e,0xa01801e6,0x26dc0037,0x3b08ca3c}},	//   _prex, ljöb, _ahto_, ppaq_, 
   {{0xf748774e,0x66d4006a,0x36d41606,0x3b0803f0}},	//   التي_, gâko, бодр, qpaq_, 
   {{0x26dc0718,0x39402517,0x7e14000d,0x00000000}},	//   _chto_, pths_, _तजोग_, --, 
   {{0xb9940597,0x45180953,0x62980023,0x7768cc7a}},	//   _الأب, ацыя_, dhto, _wrex, 
   {{0x1704cc7b,0x6298049b,0xa0185380,0x74140fb4}},	//   _نفری_, ehto, zkör, حوظا, 
   {{0x78a8cc7c,0x7ae401e7,0xd67400ec,0x88a40244}},	//   _imev, omht, _پلاڻ_, _بینۆ, 
   {{0x80d01d4c,0x6298cc7d,0x6444036b,0xe72c0133}},	//   _সংগ্, ghto, еkis, _سڵه_, 
   {{0xa0180267,0xa20002d5,0x254c03b9,0x7ae41cf8}},	//   vkör, япэд, _cəld_, imht, 
   {{0x656c06d5,0x160802fe,0x2ce40073,0x629801f4}},	//   _ábha, _स्तर_, _कळेल_, ahto, 
   {{0x78a8009f,0xa018cc7e,0x00000000,0x00000000}},	//   _mmev, tkör, --, --, 
   {{0x629824d1,0xde00311c,0x64b80327,0x71582377}},	//   chto, зпри, nċin, _брис_, 
   {{0xa018cc7f,0xa24401d3,0x00000000,0x00000000}},	//   rkör, _ایپل_, --, --, 
   {{0x229007a8,0xdca0cc80,0xa018cc81,0x30940066}},	//   _yâko_, паси, skör, _دشتس, 
   {{0x7c3c0175,0xa0183653,0xbc180220,0x00000000}},	// [10f20] _dcsr, pkör, рісі_, --, 
   {{0xace8c7e0,0x78a8cc82,0xa0185b00,0xe808cc83}},	//   _әмма_, _amev, lköp, हुना_, 
   {{0xe9d80114,0x6844009d,0x00000000,0x00000000}},	//   ћке_, йнжа, --, --, 
   {{0xa018049f,0xa818cc84,0xe8187b63,0xab280184}},	//   nköp, اتار_, ازات_, _йома_, 
   {{0x6d5c074d,0x26dc003e,0xb864cae0,0xa7a80209}},	//   _hspa, _phto_, تالو, ыкда_, 
   {{0xa0180664,0x6a84cc85,0x62980175,0x00000000}},	//   hköp, _улга, xhto, --, 
   {{0xfcdc02d3,0xe4a4059f,0xabd80150,0xf8ac0150}},	//   ንጻጽ_, йрио, _ﺃﻭﻀﺎ, _жө_, 
   {{0xd494010b,0x7bd400e4,0x6f140210,0xb5d401ec}},	//   йры_, _êgué, _owyc, _ﺘﻭﻗﻌ, 
   {{0x57f825f9,0xa01801e6,0x6298cc86,0xe5780139}},	//   _תלמו, dköp, thto, _әзе_, 
   {{0x6d5ccc87,0x0cc407f7,0x67200024,0x78a8022e}},	//   _ospa, वकुम, msoj, _zmev, 
   {{0x63780220,0x6720005f,0x64a406ed,0xda78010f}},	//   _әсер_, lsoj, _лажа, אניר, 
   {{0x6618246f,0x557404ac,0x6298cc88,0xa018007c}},	//   _hetk, _לעבן_, shto, gköp, 
   {{0x6720cc89,0xe3d40372,0x6618cc8a,0x7c3c0356}},	//   nsoj, _اتاع, _ketk, _rcsr, 
   {{0x24840211,0x7d0000d8,0xd35400d9,0x672001f4}},	//   _hoom_, ílso, _לידי_, isoj, 
   {{0x2484cc8b,0x6d5c00b5,0x6f1402d0,0x9738001f}},	//   _koom_, _cspa, _ewyc, _የውድድ, 
   {{0x6618cc8c,0xa0180267,0x6fb401d9,0x6d5ccc8d}},	//   _letk, sjöb, _ژمٹا, _dspa, 
   {{0x6d5ccc8e,0x24841105,0x6f140368,0x2bdc4e6d}},	// [10f30] _espa, _moom_, _gwyc, _मरणा, 
   {{0x6618cc8f,0x24841590,0x6720020c,0x20180200}},	//   _netk, _loom_, dsoj, _heqi_, 
   {{0x6f140034,0x7e988235,0x625c031c,0x6e28000f}},	//   _zwyc, _منکر_, _għoż, _ôfba, 
   {{0x2484cc90,0x20180de2,0xd7f801c6,0x00000000}},	//   _noom_, _jeqi_, ууж_, --, 
   {{0x6618cc91,0x2018020b,0x8cb892c2,0x00000000}},	//   _betk, _meqi_, ्करो, --, 
   {{0x7bdc67e9,0xda7802d5,0x6d5ccc92,0x00000000}},	//   _izsu, _сям_, _yspa, --, 
   {{0x64b8025c,0xc9840a5b,0x00000000,0x00000000}},	//   rċin, _еути, --, --, 
   {{0x24844f3b,0x67200218,0x66180f49,0x20180140}},	//   _coom_, bsoj, _eetk, _neqi_, 
   {{0x6618000f,0x254c00ac,0x2484061d,0x850400e5}},	//   _fetk, _cəlb_, _doom_, _ہولن, 
   {{0x3124cc93,0xd24001b9,0x00000000,0x00000000}},	//   одог, чмоқ, --, --, 
   {{0x80d002a6,0x24840070,0x2018cc94,0x6f14012d}},	//   _সংজ্, _foom_, _beqi_, _swyc, 
   {{0x24840de2,0x64b80135,0xf8c83885,0x66180210}},	//   _goom_, nċil, िकिय, _zetk, 
   {{0x66185a7f,0x6d5c0408,0x2018cc95,0xa01826bc}},	//   _yetk, _sspa, _deqi_, rköp, 
   {{0xa018cc96,0x6d5c0072,0x2484cc97,0x407801ec}},	//   sköp, _pspa, _zoom_, _ۇلىڭ_, 
   {{0x71a422f7,0xed58cc98,0x2484198f,0xf8c809b4}},	//   _файз, шов_, _yoom_, िकाय, 
   {{0x2484cc99,0x6d5c0408,0x2bdc0037,0x30748404}},	//   _xoom_, _vspa, _मरदा, _фукс, 
   {{0x6d5c068f,0xeec400aa,0x7c2800de,0x00000000}},	// [10f40] _wspa, _ويبپ, _ķert, --, 
   {{0x1ae0cc9a,0x7bdc01d3,0x00000000,0x00000000}},	//   доум, _dzsu, --, --, 
   {{0x6618cc9b,0xa01801e6,0xd9400334,0xd1d00023}},	//   _retk, ljöa, дехи, _ረኺበ_, 
   {{0x66180f44,0x6720cc9c,0x0cd803d4,0x00000000}},	//   _setk, tsoj, _দূৰত, --, 
   {{0x66185946,0x2484cc9d,0x67543c46,0xd7e0003b}},	//   _petk, _room_, تخار, мішо, 
   {{0x6720cc9e,0x2484cc9f,0xbb500050,0x00000000}},	//   rsoj, _soom_, _سۆمب, --, 
   {{0x6618cca0,0x2484cca1,0x6720023a,0xd940010b}},	//   _vetk, _poom_, ssoj, _оери, 
   {{0xd1d002d3,0xaf8c1ee0,0x2484058a,0x67200153}},	//   _ረኺቡ_, ህርትና_, _qoom_, psoj, 
   {{0x160807af,0x6720036e,0x254c03e3,0x5c98010f}},	//   _स्वर_, qsoj, _qəlb_, ישקײ, 
   {{0x20180194,0xc3900032,0x248400e8,0x16844451}},	//   _seqi_, _үҫкә, _woom_, _والێ, 
   {{0xe45810f5,0x24840211,0x00000000,0x00000000}},	//   _вже_, _toom_, --, --, 
   {{0x290805be,0x80d0009e,0x00000000,0x00000000}},	//   _mtba_, _সংঙ্, --, --, 
   {{0xdfd802e8,0x9754010f,0x01a800ec,0x00000000}},	//   рън_, ֿילו_, _ڇڏجي_, --, 
   {{0xd24c07d6,0x00000000,0x00000000,0x00000000}},	//   _لنه_, --, --, --, 
   {{0x00940276,0x2908002f,0x8d680a5b,0x00000000}},	//   _никэ, _ntba_, ојта_, --, 
   {{0x90c42424,0x7bf8010a,0x7c2800ef,0xa2a40c6e}},	//   _обје, снар_, _ķers, टोर्, 
   {{0x1ea80597,0x7bc00034,0xe5180456,0x6f340354}},	// [10f50] _نادي_, _ślub, फीति_, _нӳрĕ, 
   {{0xc5f802b5,0xd1d00023,0x00000000,0x00000000}},	//   _ngē_, _ረኺባ_, --, --, 
   {{0x2908cca2,0xae580a7c,0xe89800d1,0x00000000}},	//   _ctba_, _הכתר, әбчә_, --, 
   {{0x3eb02d59,0x00000000,0x00000000,0x00000000}},	//   lizt_, --, --, --, 
   {{0xcb440cfc,0x8704cafa,0x7e6403e0,0x33f400d1}},	//   _охри, وبول, _kahp, үчис, 
   {{0x7afc0de4,0x26040ce0,0xb384013e,0x3ce8000d}},	//   _iust, सुली_, ҷлил, lmav_, 
   {{0xceb404ac,0x7afccca3,0x7e640477,0xd838084c}},	//   ויס_, _hust, _mahp, _вэз_, 
   {{0xd874cca4,0x7af405f5,0xb3840432,0x7e640477}},	//   _باسب, _hizt, злил, _lahp, 
   {{0x260401ad,0x00000000,0x00000000,0x00000000}},	//   _स्की_, --, --, --, 
   {{0x7278cca5,0x64b8031c,0x00000000,0x00000000}},	//   ссис_, nċij, --, --, 
   {{0x7af4005a,0x71b4005b,0x63b401a8,0x24940066}},	//   _mizt, ящих, _þynn, زنید_, 
   {{0x7afc8191,0x7af4009d,0x7b080030,0x00000000}},	//   _oust, _lizt, _kľud, --, 
   {{0x7afccca6,0xb4c80574,0x330800db,0x00000000}},	//   _nust, ोती_, _ايتپ_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb1280014,0x5f4007d6,0xa01801e3,0x7c280171}},	//   _آبن_, وچیل, sjöa, _ķerr, 
   {{0x7afccca7,0xa3e0007d,0x7af400da,0xdd8c8370}},	//   _bust, _धरम_, _aizt, دوف_, 
   {{0x7af4cca8,0x7afccca9,0xdca0ccaa,0x6e28002d}},	// [10f60] _bizt, _cust, хати, _ôfbo, 
   {{0x7afcccab,0xee38014b,0xb4c800cd,0x6924004e}},	//   _dust, _уно_, ोतु_, змжа, 
   {{0x7afcccac,0x7af4005a,0x0d940a98,0x5df8011a}},	//   _eust, _dizt, _غیرح, _לפינ, 
   {{0x7af4005a,0x6b64022e,0x00000000,0x00000000}},	//   _eizt, _екма, --, --, 
   {{0x7afcccad,0x7e64014f,0xd07c0092,0x00000000}},	//   _gust, _yahp, _እየሰሩ_, --, 
   {{0x6744044e,0xf53002d3,0x648c01ab,0xba5400a7}},	//   _መግዛእ, _አይኮነ, _lùit, _отсъ, 
   {{0x7afcccae,0xddc4033f,0x2908014f,0x254c03e3}},	//   _zust, dejś, _utba_, _bəla_, 
   {{0x7afcccaf,0x7640003a,0x7af401c6,0x00000000}},	//   _yust, _ecly, _zizt, --, 
   {{0x7afc0f71,0xa7845821,0x759c0023,0x73c00124}},	//   _xust, _عشرو, _ገይርዎ_, кәше, 
   {{0xa3d007d6,0x00000000,0x00000000,0x00000000}},	//   моқч, --, --, --, 
   {{0x4034ccb0,0x648c08c2,0x26ccccb1,0xdc3c00d0}},	//   менс, _bùit, mofo_, víľk, 
   {{0x26ccccb2,0x7e64014f,0x4420032e,0x00000000}},	//   lofo_, _sahp, _þi_, --, 
   {{0x7e64003e,0xae1c0037,0x00000000,0x00000000}},	//   _pahp, _बड़हन_, --, --, 
   {{0x26ccccb3,0x6e28000f,0x7e64047e,0x04c801c8}},	//   nofo_, _ôfbl, _qahp, _اوچي_, 
   {{0x62880421,0xc0c4023b,0x712401d9,0x91e00114}},	//   _iofo, _ошиқ, _ہى۪م, _поље, 
   {{0x6288ccb4,0x26cc5bae,0x6fcc0073,0x1138011a}},	//   _hofo, hofo_, _धुवू, _התהל, 
   {{0x98c4052f,0x7af401c0,0x26cc013f,0x7afcccb5}},	// [10f70] үсел, _pizt, kofo_, _qust, 
   {{0x7eb80716,0x26cc0109,0x7afcccb6,0x8f9c0375}},	//   _фгос_, jofo_, _vust, _ליחי, 
   {{0x6288ccb7,0xe80802e3,0x682001f2,0x26cc0099}},	//   _mofo, _ịbịa, _ọdab, dofo_, 
   {{0x6288449c,0x26cc0270,0xddc40034,0xad5401d3}},	//   _lofo, eofo_, zejś, _کریڈ, 
   {{0x16700224,0x26ccccb8,0xf7443869,0x7afc0037}},	//   нқар, fofo_, фело, _uust, 
   {{0x6288ccb9,0x64400005,0x26cc0607,0x6d9c01e1}},	//   _nofo, _acoi, gofo_, _ṣail, 
   {{0x95c8010b,0x00000000,0x00000000,0x00000000}},	//   щуда_, --, --, --, 
   {{0x62880618,0x64400332,0x6b8c01e1,0x00000000}},	//   _aofo, _ccoi, _àngù, --, 
   {{0x6288ccba,0x80c800bd,0x3204ccbb,0xa3e00073}},	//   _bofo, রগঞ্, tcly_, _धरण_, 
   {{0xd04803be,0xe3b4ccbc,0x648c01ab,0x00000000}},	//   əməy, ьбы_, _sùit, --, 
   {{0x648c0192,0x957401c0,0x71a416a4,0x00000000}},	//   _cùis, _хөлс_, фанз, --, 
   {{0x64400597,0xf4843b7a,0x648c01c3,0xa3cc01f2}},	//   _gcoi, _تائی, _dùis, ịbịa_, 
   {{0x6288ccbd,0xe3acccbe,0xa018ccbf,0xa11002f2}},	//   _fofo, _рб_, mjöl, _یووت, 
   {{0xd24405f5,0xa3e0ccc0,0x628803cb,0xa01801e3}},	//   _хэди, _धरत_, _gofo, ljöl, 
   {{0x9d40c7eb,0x1d04ccc1,0xa2d0009f,0x3d180118}},	//   керд, деси_, _جيوت, यीले_, 
   {{0x62880bd7,0x6d4801b8,0x6ac4045b,0x26cc010f}},	//   _zofo, _äfam, वव्र, zofo_, 
   {{0x2290025a,0xaec4cc9a,0xea88ccc2,0x1f60ccc3}},	// [10f80] _sâki_, _обил, обал_, _акым, 
   {{0xed58ccc4,0x00000000,0x00000000,0x00000000}},	//   _доо_, --, --, --, 
   {{0x648c01c3,0x00000000,0x00000000,0x00000000}},	//   _mùir, --, --, --, 
   {{0xb9e40131,0x648c01c3,0x00000000,0x00000000}},	//   رسلى, _lùir, --, --, 
   {{0x26cc0618,0xa6c8ccc5,0x00000000,0x00000000}},	//   tofo_, олда_, --, --, 
   {{0x6440ccc6,0x00000000,0x00000000,0x00000000}},	//   _scoi, --, --, --, 
   {{0x26ccccc7,0xa018008c,0x00000000,0x00000000}},	//   rofo_, fjöl, --, --, 
   {{0x26cc0134,0x6288ccc8,0xa0180008,0x648c01c3}},	//   sofo_, _sofo, gjöl, _rùis, 
   {{0x648c08c2,0x26cc090c,0x6440004d,0x6288ccc9}},	//   _bùir, pofo_, _vcoi, _pofo, 
   {{0x648c0e89,0x6288ccca,0x291c003a,0xe2a801d9}},	//   _cùir, _qofo, _ætas_, تابن_, 
   {{0x60cc084c,0x648c01c3,0x680000bc,0x6abc0112}},	//   tocm, _dùir, půjč, inpf, 
   {{0x62880161,0x10740212,0xa01801d3,0x6abc0112}},	//   _wofo, влюю, lköz, hnpf, 
   {{0xe2840517,0x6288cccb,0x23e0cccc,0x648c01ab}},	//   _олди, _tofo, _परिद, _fùir, 
   {{0x4424cccd,0x60cc0354,0xa01800e5,0x00000000}},	//   lam_, socm, nköz, --, 
   {{0xe648044e,0x20c40861,0xa0180267,0xdbc40166}},	//   _መጽናዕ, _осиг, ljöm, _köçi, 
   {{0xa3e003e5,0x28dc01ad,0x23e000cd,0x00000000}},	//   _धरा_, _फीलि, _पराद, --, 
   {{0x3a74ccce,0x4424cccf,0x7b080030,0x92c00183}},	// [10f90] нлар, iam_, _sľub, ্ষৰ_, 
   {{0xe7d005f9,0xed4c01d3,0x8a1400ae,0x00000000}},	//   _तड़प, جھی_, نظما, --, 
   {{0x4424ccd0,0xf3f80311,0x5fd001f9,0x39140064}},	//   kam_, leţe_, _धुतल, хмер, 
   {{0xe8085ca7,0x00000000,0x00000000,0x00000000}},	//   हुला_, --, --, --, 
   {{0x66d400e4,0xf3f8054e,0xdac400d1,0xf1e40150}},	//   hâku, neţe_, _قېرى_, _ﺎﻭﻤﺘ, 
   {{0x7ac80050,0x4424ccd1,0xa01801ed,0x66d400e4}},	//   _روزِ_, eam_, gköz, kâku, 
   {{0x4424ccd2,0x862400fd,0xa5040395,0x00000000}},	//   fam_, тьче, неща_, --, 
   {{0x4424ccd3,0x32d80100,0xa2940150,0x00000000}},	//   gam_, mèyi_, _ﺘﺠﺭﺒ_, --, 
   {{0x254c03be,0x163000d1,0xd72c001f,0x00000000}},	//   _həll_, _җеҗя, _አልሆነ, --, 
   {{0xf3f80311,0xb5040137,0x00000000,0x00000000}},	//   deţe_, _كۉتۅ_, --, --, 
   {{0xa0180205,0xbef800bc,0x00000000,0x00000000}},	//   lköy, ंदैन_, --, --, 
   {{0xf3f8054e,0x00000000,0x00000000,0x00000000}},	//   feţe_, --, --, --, 
   {{0xb7bc0311,0x260407f7,0xa018ccd4,0x00000000}},	//   _feţe, सुकी_, nköy, --, 
   {{0x67f400ee,0x00000000,0x00000000,0x00000000}},	//   _hüjü, --, --, --, 
   {{0x6da43c85,0x6cc40410,0xdee03acc,0xa0180108}},	//   хива, ейва, уори, hköy, 
   {{0x23cc038e,0xa01800dd,0xaf202baf,0x3cf80fac}},	//   _हुँद, zköz, ভূষণ_, _cisv_, 
   {{0xa2a40764,0x00000000,0x00000000,0x00000000}},	// [10fa0] टोक्, --, --, --, 
   {{0xa9a4ccd5,0xabd801ec,0x636800e5,0x00000000}},	//   низд, _ﺃﺭﻜﺎ, löná, --, 
   {{0x4424ccd6,0xe8f80724,0xa01800e5,0x72900240}},	//   yam_, чле_, vköz, _ዝወደቀ_, 
   {{0x4424ccd7,0xf8a800aa,0x18a00022,0x98a000d8}},	//   xam_, ودنه_, лахм, лихе, 
   {{0x4424ccd8,0xa01800dd,0xd7f43baf,0x23cc13f7}},	//   vam_, tköz, нуш_, _हुंद, 
   {{0x4424ccd9,0x4de400bc,0x92c00154,0x00000000}},	//   wam_, _गराई_, ্ষু_, --, 
   {{0x4424ccda,0xb7bc00a8,0x7cc40024,0xa01800e5}},	//   tam_, _reţe, lėra, rköz, 
   {{0x2a680327,0x1864013e,0x8af00213,0x44240381}},	//   _habb_, _паси_, vvəy, uam_, 
   {{0x98a0ccdb,0x18a0ccdc,0xa01801d3,0x2f040051}},	//   _сите, _сатм, pköz, _nôg_, 
   {{0x37c0052f,0xd754007b,0x2a6802d2,0x66d40124}},	//   _әҙәб, _سلمت_, _jabb_, tâku, 
   {{0x4424ccdd,0xd36cccde,0xa2a41f13,0x648c01ab}},	//   pam_, _өч_, टोग्, _fùip, 
   {{0x4424ccdf,0x2a68cce0,0x67f40432,0x66d400e4}},	//   qam_, _labb_, _güjü, râku, 
   {{0xa0180267,0xf3f8054e,0x2f040208,0x94c800f1}},	//   ljök, teţe_, _côg_, _عامې_, 
   {{0xd36c25da,0x2a680162,0x626413bd,0x00000000}},	//   _دهه_, _nabb_, _ساتق, --, 
   {{0xf3f80311,0xd1340124,0xa3c402e5,0x3b0c031c}},	//   reţe_, _зхы_, _उखड_, _ħeqq_, 
   {{0x11d8025f,0x213ccce1,0x225c02fa,0x52800124}},	//   _מחוב, muth_, letk_, _агәб, 
   {{0x213ccce2,0xabb40588,0x2a6802d2,0xcb3402e8}},	// [10fb0] luth_, ватә, _babb_, летъ, 
   {{0x6298394d,0x2ef8017a,0x20080798,0x2ebc185d}},	//   nkto, _gipf_, lcci_, ोवृत, 
   {{0x6298139f,0x00000000,0x00000000,0x00000000}},	//   ikto, --, --, --, 
   {{0x893419f9,0x6444007f,0x225c000d,0x6298000d}},	//   اعلا, òkil, hetk_, hkto, 
   {{0x366855c3,0x62980bfa,0x9b680354,0x00000000}},	//   дало_, kkto, _эшна_, --, 
   {{0x213c009a,0x629801f5,0x2a6802d2,0x57a400c7}},	//   kuth_, jkto, _gabb_, _ҧшаа, 
   {{0x23649d33,0xaf740092,0xa018cce3,0xd8380064}},	//   _asoj_, _ሊያስገ, sköy, _нэа_, 
   {{0x6298cce4,0xd1e4001f,0x25b882e3,0x00000000}},	//   ekto, _ዘመቻ_, úpla_, --, 
   {{0x9064167e,0x9f4c0241,0x00000000,0x00000000}},	//   ۇندۇ, _àgè_, --, --, 
   {{0x2f040165,0xa01801e3,0x6d5803e0,0x00000000}},	//   _rôg_, ljöh, çtak, --, 
   {{0x213c07c5,0xd1dc001f,0x00000000,0x00000000}},	//   guth_, ሐፍት_, --, --, 
   {{0x92c05d2d,0x2ef801fa,0x05a40023,0x00000000}},	//   ্ষে_, _sipf_, _ጉልባብ_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6298014a,0xed583cbc,0x200808e5,0x3ec401ec}},	//   ckto, мог_, acci_, лқым_, 
   {{0xdc0c00b4,0x00000000,0x00000000,0x00000000}},	//   _ụmụa, --, --, --, 
   {{0x6fb400c6,0xe7f4012c,0xf0e80137,0x59d80073}},	//   _لمعا, ेशमा_, _تىبى_, _भरजर, 
   {{0x2a680327,0xaa4401d5,0x00000000,0x00000000}},	// [10fc0] _pabb_, кеал, --, --, 
   {{0xeb5c0092,0x6994011c,0x00000000,0x00000000}},	//   ገልጻለ, крех, --, --, 
   {{0x6cc4cce5,0x6da45e78,0xada40120,0x00000000}},	//   _айна, _рина, _ранл, --, 
   {{0xeb98cce6,0xe738013e,0x1b400014,0x64b80327}},	//   _жим_, дед_, _چھلُ, nċit, 
   {{0x6d4ccce7,0x2a680de2,0xac7407d2,0x6298229b}},	//   ltba, _tabb_, _كاڭش, ykto, 
   {{0x490401c6,0x3cf400bc,0x3af40024,0xdb04007c}},	//   _бүжг, ्दथे_, _бясс, älåd, 
   {{0x6d4c7963,0xb4cc01f9,0x00000000,0x00000000}},	//   ntba, ळवू_, --, --, 
   {{0x769c007f,0x6d4cbddd,0x7dd802d2,0x00000000}},	//   _fèyo, itba, _húsþ, --, 
   {{0x6d4c5475,0x439401ec,0x00000000,0x00000000}},	//   htba, уапс, --, --, 
   {{0x6d4c1f53,0x800801d3,0xb4e80014,0x00000000}},	//   ktba, کردہ_, وى۪م_, --, 
   {{0x6d4c0d86,0xe5240124,0xa01801e3,0x225c000d}},	//   jtba, _рдеп, ljöi, retk_, 
   {{0x213c42a8,0x2364cce8,0x6d4c2ab7,0x6298cce9}},	//   ruth_, _tsoj_, dtba, skto, 
   {{0x6d4cccea,0x213c009a,0x00000000,0x00000000}},	//   etba, suth_, --, --, 
   {{0x213c009a,0x5330045c,0x00000000,0x00000000}},	//   puth_, _тешт, --, --, 
   {{0x5c04cceb,0x6d4c00b5,0xcd040137,0xdbbc00eb}},	//   вяза, gtba, ичти, _আরেফ, 
   {{0x11f4011a,0xa018007c,0xf00001f0,0x2bdc0037}},	//   _בזול_, xjöh, _гӯри, _मरखा, 
   {{0xd1e402d3,0x6d4c0072,0x76540432,0x63b4010b}},	// [10fd0] _ዘመተ_, atba, _özyg, _ýynd, 
   {{0x7f4cccec,0x1a5800c6,0xe0dc08e5,0x7d000162}},	//   _iqaq, بشرة_, llò_, ílss, 
   {{0x5884cced,0x3f980368,0x6d4c02d0,0x64b8025c}},	//   кыда, lysu_, ctba, nċis, 
   {{0x08d40212,0x00000000,0x00000000,0x00000000}},	//   ація, --, --, --, 
   {{0x3f98ccee,0xb8e401ec,0xe5740150,0x00000000}},	//   nysu_, _ұсақ, ғзы_, --, 
   {{0xa01801e3,0x95b00209,0x7d04ccef,0x00000000}},	//   sjöh, ирйә, _kuhs, --, 
   {{0xfb840588,0x3b080784,0xe0dc0100,0x0948004e}},	//   _рыҟн, lqaq_, klò_, _ичти_, 
   {{0x7d0407a1,0x7f4cccf0,0x7bdc0030,0x81bc00e2}},	//   _muhs, _oqaq, _kysu, raēl, 
   {{0x7f4c009a,0x3b080113,0x7d0400ef,0x00000000}},	//   _nqaq, nqaq_, _luhs, --, 
   {{0xf26801c0,0x7768ccf1,0x6d4c0728,0xc30c0154}},	//   хиол_, _isex, ytba, _শিখি_, 
   {{0x7bdc5522,0x386c0dd4,0x7f4cccf2,0x6d4c3bba}},	//   _lysu, _kaer_, _aqaq, xtba, 
   {{0x7f4c0327,0x386cccf3,0xe0dc026c,0x7bdc022e}},	//   _bqaq, _jaer_, glò_, _oysu, 
   {{0x386cccf4,0x7bdc003e,0x7d0400d8,0x408401e0}},	//   _maer_, _nysu, _auhs, рҙым_, 
   {{0x386cccf5,0x6d4c11ad,0x332c06f1,0x77680051}},	//   _laer_, ttba, msex_, _msex, 
   {{0x5184187d,0x2d9cccf6,0x7f4cccf7,0x7bdc0548}},	//   _шуда, áte_, _eqaq, _aysu, 
   {{0x7d040066,0x386ca081,0x7bdc613a,0x332c0076}},	//   _duhs, _naer_, _bysu, osex_, 
   {{0x2d9c00d0,0x77680204,0x7bdc03cb,0x6d4c6460}},	// [10fe0] šte_, _nsex, _cysu, stba, 
   {{0x386c0076,0x6d4c4431,0x8eb40131,0x00000000}},	//   _aaer_, ptba, _ئەست, --, 
   {{0x386c40c0,0x7d040369,0x3af4005b,0x2ca00051}},	//   _baer_, _guhs, рятс, _tlkd_, 
   {{0x386cccf8,0x42900020,0x274856ac,0x7bdc0042}},	//   _caer_, ምምነት_, ечко_, _fysu, 
   {{0x386c04c4,0x7bdc015d,0x00000000,0x00000000}},	//   _daer_, _gysu, --, --, 
   {{0x96e40212,0xaa44010a,0x00000000,0x00000000}},	//   льща_, _щегл, --, --, 
   {{0x77680117,0x386c015d,0x3a0861be,0x00000000}},	//   _esex, _faer_, _شکلی_, --, 
   {{0x386cccf9,0xa018ccfa,0x833425ea,0x98a0003b}},	//   _gaer_, ljöv, аних, _лисе, 
   {{0xe0dc0ffb,0x5c34008f,0x00000000,0x00000000}},	//   vlò_, ארפן_, --, --, 
   {{0x4154ccfb,0xa5d800c6,0x00000000,0x00000000}},	//   авос, _كبار_, --, --, 
   {{0x3f980042,0x00000000,0x00000000,0x00000000}},	//   wysu_, --, --, --, 
   {{0x7d04ccfc,0x925401b9,0x99f4011a,0x64b80003}},	//   _ruhs, پشیر_, טזיה_, rċis, 
   {{0xe0dc4d72,0xe2980953,0x77680076,0xddd403e3}},	//   rlò_, _пад_, _xsex, _baxş, 
   {{0xeab4045e,0x7bdc0034,0x245002f2,0x00000000}},	//   জকুম, _rysu, _ئۆکس, --, 
   {{0x254c00ac,0x3b080113,0x76540205,0x8d8401a9}},	//   _bəli_, wqaq_, _özye, бутд, 
   {{0x2fc40219,0x40340139,0x3f9800c7,0x00000000}},	//   _žoge_, _теис, pysu_, --, 
   {{0x7f4c3209,0x386cccfd,0x254c0213,0x00000000}},	// [10ff0] _uqaq, _raer_, _dəli_, --, 
   {{0x7bdc02fb,0x769c007f,0x3b08ccfe,0x386cccff}},	//   _vysu, _pèym, rqaq_, _saer_, 
   {{0x386ccd00,0xca480a0a,0x3b08cd01,0x7bdc033f}},	//   _paer_, المه_, sqaq_, _wysu, 
   {{0xd0dc013f,0x7bdc5e0b,0x254c06be,0x332c045a}},	//   ɑɑsɛ_, _tysu, _gəli_, ysex_, 
   {{0xddd4cd02,0x7bdccd03,0x3b08cd04,0x386c030a}},	//   _yaxş, _uysu, qqaq_, _vaer_, 
   {{0x386c0a40,0xd7f8013e,0x254c06be,0x00000000}},	//   _waer_, _ҷуз_, _zəli_, --, 
   {{0x1dd806ab,0x386ccd05,0xa018007c,0x3d1801f9}},	//   _मुमत, _taer_, ljöu, यीचे_, 
   {{0xdc200154,0x65800014,0x7768008e,0xf79400c0}},	//   _ফাঁস_, تیمٕ, _tsex, _кабэ, 
   {{0x48240075,0x7768014b,0x730407b5,0x00000000}},	//   _دىقق, _usex, јпоз, --, 
   {{0x72946e1f,0xf7d401ec,0x00000000,0x00000000}},	//   рших, _ﭘﻮﻳﻪ, --, --, 
   {{0x332ccd06,0x6678008f,0x00000000,0x00000000}},	//   ssex_, _שטעק, --, --, 
   {{0x332c0051,0x00000000,0x00000000,0x00000000}},	//   psex_, --, --, --, 
   {{0xd00401a9,0x00000000,0x00000000,0x00000000}},	//   _қопқ, --, --, --, 
   {{0xe2944294,0xada400c7,0x6da40022,0x00000000}},	//   _ваш_, аагл, аига, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x64b8038f,0x25a80112,0xddd40166,0x7c840114}},	//   nċip, _üble_, _waxş, буђе, 
  
   {{0x6a14cd07,0xab283b7e,0xdca0005b,0x254c03e3}},	// [11000] لبار, тоза_, цати, _vəli_, 
   {{0x6f14127b,0x2d946c9a,0x00000000,0x00000000}},	//   _ityc, _көбө_, --, --, 
   {{0xa80454e7,0x00000000,0x00000000,0x00000000}},	//   азел, --, --, --, 
   {{0x6d5ccd08,0x61fc0306,0xe7280472,0xa018007c}},	//   _ippa, _úple, نستو_, sjöv, 
   {{0xdc34010f,0x00000000,0x00000000,0x00000000}},	//   _דאכט_, --, --, --, 
   {{0xa0180fe7,0x00000000,0x00000000,0x00000000}},	//   ljöt, --, --, --, 
   {{0x8af00213,0x41d4000d,0x6370008e,0x00000000}},	//   ttəf, _ठुंस, kınç, --, 
   {{0xd494cd09,0x2918023a,0x941402e8,0x00000000}},	//   иры_, mppa_, ажът_, --, 
   {{0x15680131,0x2918005b,0x68e0852a,0x00000000}},	//   _ﺳﯧﺘﯩ, lppa_, mlod, --, 
   {{0x66e4bd3f,0x68e0cd0a,0xd2540212,0x00000000}},	//   _тоза, llod, ацю_, --, 
   {{0x64a4cd0b,0x68e0cd0c,0x81d40107,0x00000000}},	//   _кажа, olod, сонх, --, 
   {{0xd83c02fd,0x29180099,0x6578127b,0x68e0cd0d}},	//   _účtu_, ippa_, _irth, nlod, 
   {{0x6d5ccd0e,0x6578010a,0x68e00175,0x58f4010f}},	//   _appa, _hrth, ilod, ימטע_, 
   {{0x68e0cd0f,0x3ea4cd10,0x2918020b,0x53980375}},	//   hlod, ólt_, kppa_, _בידו, 
   {{0x3cf400bc,0x6f14012d,0x63700139,0xa01802d2}},	//   ्दले_, _etyc, bınç, fjöt, 
   {{0x0ca8cd11,0xe780002e,0x65780051,0x51f8011a}},	//   атуи_, _làññ, _mrth, _בהוצ, 
   {{0x6d5c9f58,0x68e0cd12,0x8af006be,0x8fa4009b}},	// [11010] _eppa, dlod, ktəd, _маће, 
   {{0xd9180323,0x6d5c067c,0x6578cd13,0x68e003cb}},	//   вьд_, _fppa, _orth, elod, 
   {{0x4dd80014,0x7b0800d0,0xb95412e7,0x00000000}},	//   _نوٝح_, _kľuk, свещ, --, 
   {{0x68e0cd14,0x6e280b21,0xd1cc0092,0x00000000}},	//   glod, _ôfbr, ብሰባ_, --, 
   {{0x65780a28,0x7c2ccd15,0x69cc0113,0x2918cd16}},	//   _arth, maar, _exbe, appa_, 
   {{0x6d5c05ac,0x7b3c0356,0xd1cc0092,0x00000000}},	//   _yppa, _căuş, ብሰብ_, --, 
   {{0x63700724,0x6d9c0003,0x00000000,0x00000000}},	//   yınç, _għaġ, --, --, 
   {{0x7c2ccd17,0x250804fb,0x213c02d2,0x00000000}},	//   naar, دروی_, drth_, --, 
   {{0x65780cfd,0x34941621,0x7c2c0194,0x4de407f7}},	//   _erth, _қадр, iaar, _गर्इ_, 
   {{0x7c2ca1b1,0xd5b8cd18,0x00000000,0x00000000}},	//   haar, _исе_, --, --, 
   {{0x7c2ccd19,0x6f14cd1a,0x69cc037e,0x738801ec}},	//   kaar, _styc, _xxbe, _әрең_, 
   {{0x7c2ccd1b,0x6f14005a,0x846402e8,0x81bc00e2}},	//   jaar, _ptyc, _мъче, zbēg, 
   {{0x527080e2,0x7c2ccd1c,0x213c9867,0xe28ccd1d}},	//   _ҳуқу, daar, arth_, _еа_, 
   {{0xceb80184,0x6370456f,0x29180158,0xf1a80133}},	//   рҙо_, sınç, yppa_, _ماعه_, 
   {{0x6f14033f,0x5194074d,0x68e0cd1e,0x1dd801f9}},	//   _wtyc, _тăва, ylod, _मुदत, 
   {{0xdd8ccd1f,0x7c2ccd20,0x00000000,0x00000000}},	//   روق_, gaar, --, --, 
   {{0x68e0047e,0x80c400dc,0x00000000,0x00000000}},	// [11020] vlod, ाचरे, --, --, 
   {{0x6d5c010a,0x68e0014f,0x00000000,0x00000000}},	//   _tppa, wlod, --, --, 
   {{0x68e0cd21,0x9e7800c8,0x6d5ccd22,0x6e2c105c}},	//   tlod, _ענטפ, _uppa, mabb, 
   {{0x6c8408de,0x6e2ccd23,0x7c2ccd24,0xa018c9df}},	//   _الحم, labb, caar, ljör, 
   {{0x66e4cd25,0xeaf80214,0xf8c801e1,0x00000000}},	//   бода, _مرآت_, _seéé_, --, 
   {{0x6e2ccd26,0x56900364,0xa01801e6,0x6578002b}},	//   nabb, зашт, njör, _prth, 
   {{0x6abc1682,0xd940bba2,0x00000000,0x00000000}},	//   mipf, _нери, --, --, 
   {{0x6e2ccd27,0x2908cd28,0xe7801bce,0x68e0016d}},	//   habb, _iuba_, _wàññ, qlod, 
   {{0xdc9804ac,0x213c0cfd,0x6e2ccd29,0x657800a9}},	//   טיקל, wrth_, kabb, _wrth, 
   {{0x6e2ccd2a,0x7c2c2f0f,0xe6c41541,0x6abc0175}},	//   jabb, zaar, _اتري, nipf, 
   {{0xd48ccd2b,0x7c2ccd2c,0x2908cd2d,0x6e2ccd2e}},	//   _ер_, yaar, _juba_, dabb, 
   {{0x6abccd2f,0x2908cd30,0x23287b31,0x7c2ccd31}},	//   hipf, _muba_, _боди_, xaar, 
   {{0x7c2ccd32,0x6e2ccd33,0x4394cd34,0xa0180008}},	//   vaar, fabb, _фалс, fjör, 
   {{0x7c2ccd35,0x6e2ccd36,0xa0180008,0x769c01e1}},	//   waar, gabb, gjör, _pèyi, 
   {{0x7c2c0680,0x8af00cc1,0x6abc0099,0x51f01075}},	//   taar, ktəb, dipf, _ىسىر, 
   {{0x7c2c0140,0x00000000,0x00000000,0x00000000}},	//   uaar, --, --, --, 
   {{0x7c2ccd37,0x6e2ccd38,0x2908068c,0xa018cc96}},	// [11030] raar, babb, _auba_, björ, 
   {{0x7c2ccd39,0x6abc3390,0x6e2c0548,0x2908cd3a}},	//   saar, gipf, cabb, _buba_, 
   {{0x29080020,0x7c2ccd3b,0x39140212,0x00000000}},	//   _cuba_, paar, цмер, --, 
   {{0x29083142,0x7c2ccd3c,0x26dccd3d,0xc1780153}},	//   _duba_, qaar, _akto_, ivė_, 
   {{0x6abc1419,0x2908cd3e,0x00000000,0x00000000}},	//   bipf, _euba_, --, --, 
   {{0x29081418,0x2bc40316,0xf65400d4,0x00000000}},	//   _fuba_, लपरा, ітлю, --, 
   {{0x2908cd3f,0xa3dc000d,0x00000000,0x00000000}},	//   _guba_, _दुब_, --, --, 
   {{0x6e2cb2a6,0xfd640521,0xc1780024,0x8af006be}},	//   zabb, wesị, dvė_, ctəb, 
   {{0x2908cd40,0x7ae4003e,0x6e2c96d6,0x43e800ec}},	//   _zuba_, olht, yabb, ٽريٽ_, 
   {{0x78a8cd41,0x2908cd42,0xd6d80212,0x6e2c01a9}},	//   _hlev, _yuba_, _стб_, xabb, 
   {{0x78a8cd43,0x52380020,0x6e2ccd44,0x71b4034b}},	//   _klev, _በአፍሪ, vabb, ющих, 
   {{0x25d41a4c,0x6e2c5559,0x1b1c00cc,0x6abccd45}},	//   _ווען_, wabb, _পিনে_, zipf, 
   {{0x6e2ccd46,0x78a8cd47,0x6abc0223,0xa8540375}},	//   tabb, _mlev, yipf, חירה_, 
   {{0x78a8cd48,0x9c100521,0x92e403d4,0x7c6400d1}},	//   _llev, _kọwa, _মূৰ_, ۋاقل, 
   {{0x78a8cd49,0xde0010f5,0x6abc0099,0x6da400ea}},	//   _olev, дпри, vipf, цива, 
   {{0x2908cd4a,0x6e2ccd4b,0x61fc02fb,0xdd8c2161}},	//   _ruba_, sabb, _úpla, خوف_, 
   {{0x2908cd4c,0xeab806d3,0x92c802f5,0x6abc004c}},	// [11040] _suba_, айа_, লতী_, tipf, 
   {{0xa01801e6,0xe8203c71,0x6e2c0703,0x00000000}},	//   ljöp, मर्थ_, qabb, --, 
   {{0x78a8105c,0xe9685660,0x2908cd4d,0x6abccd4e}},	//   _blev, раел_, _quba_, ripf, 
   {{0x29080516,0x588000f7,0x814c010f,0xe784011c}},	//   _vuba_, дыша, רעאַ, жуко, 
   {{0x8af000ac,0xc5f400bc,0x394000ef,0x00000000}},	//   rtəb, ेख्य_, arhs_, --, 
   {{0x7b08b2a7,0x6abc0240,0xeaf8cd4f,0x92c800eb}},	//   _džud, qipf, _خرجت_, লতু_, 
   {{0x78a8cd50,0x2908058a,0x00000000,0x00000000}},	//   _flev, _uuba_, --, --, 
   {{0x78a80489,0x74a825a2,0xd91802e4,0x00000000}},	//   _glev, йсың_, _כולל, --, 
   {{0x872800f1,0x00000000,0x00000000,0x00000000}},	//   _دغزې_, --, --, --, 
   {{0xc1780024,0x78a800bc,0x26dc00cd,0x00000000}},	//   tvė_, _zlev, _ukto_, --, 
   {{0x65b8760c,0xd6d402dd,0x78a81b99,0x00000000}},	//   _туар_, _بولش_, _ylev, --, 
   {{0x44200124,0x00000000,0x00000000,0x00000000}},	//   _ýi_, --, --, --, 
   {{0x2484cd51,0x9c1002e3,0xc1780024,0x2d9c143a}},	//   _inom_, _kọva, svė_, øten_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdcb89953,0x00000000,0x00000000,0x00000000}},	//   аща_, --, --, --, 
   {{0x8c6401ec,0x00000000,0x00000000,0x00000000}},	//   мтуд, --, --, --, 
   {{0x2484098d,0x46bc0404,0x38b40022,0x7ae40978}},	// [11050] _mnom_, ्चाह, húrõ_, tlht, 
   {{0x78a8a0e6,0xf77001ed,0x38b400e4,0x248400d7}},	//   _slev, ہات_, kúrõ_, _lnom_, 
   {{0x24840b91,0x78a8cd52,0x38b400c7,0x7958011c}},	//   _onom_, _plev, júrõ_, сиер_, 
   {{0xf770cd53,0x37740724,0xda189ad9,0x38b400e4}},	//   فات_, зыкс, _प्रत_, dúrõ_, 
   {{0x78a8cd54,0xd7680107,0x00000000,0x00000000}},	//   _vlev, ршед_, --, --, 
   {{0xd6d8cd55,0x2484cd56,0x8b880150,0xa3dc2052}},	//   ште_, _anom_, _بەكە_, _दुध_, 
   {{0x78a801fa,0x95c8cd57,0xd7b402e5,0xf3f80356}},	//   _tlev, шуда_, _अधकच, meţi_, 
   {{0x78a8cd58,0xf3f8054e,0xa018007c,0x00000000}},	//   _ulev, leţi_, xjöp, --, 
   {{0x61e40213,0x248400d7,0xe6980014,0x6ef0005c}},	//   əkli, _dnom_, _گمٕژ_, læbe, 
   {{0x248404fb,0xc6a4cd59,0xf3f8084c,0x46800046}},	//   _enom_, _орхи, neţi_, _ақша, 
   {{0xd5b8030d,0x00000000,0x00000000,0x00000000}},	//   _тса_, --, --, --, 
   {{0x8504cd5a,0x42c800f7,0x53480408,0xc1e8009d}},	//   _قولن, йгөн_, _кăмă, өдөж_, 
   {{0x61fc03c6,0x09b807af,0xc0d402d3,0xb7bc0311}},	//   _úpln, _आध्य, _ከከም_, _beţi, 
   {{0x6ef001bf,0x00000000,0x00000000,0x00000000}},	//   kæbe, --, --, --, 
   {{0xb7bc084c,0xf3f8084c,0x3568001f,0xf2740014}},	//   _deţi, deţi_, _ሰርቪስ_, _وَچھ, 
   {{0x2cb00241,0xac0885f2,0x254c03b9,0x00000000}},	//   _bímọ_, снаа_, _xəlq_, --, 
   {{0xf3f80356,0x7b080064,0x00000000,0x00000000}},	// [11060] feţi_, _ažub, --, --, 
   {{0xe9d00058,0xf3f80311,0xb7bc0356,0x00000000}},	//   ىغا_, geţi_, _geţi, --, 
   {{0x5e980375,0xda7c0306,0x00000000,0x00000000}},	//   _הביק, áďat_, --, --, 
   {{0xe968016c,0x00000000,0x00000000,0x00000000}},	//   _қабл_, --, --, --, 
   {{0x66e4cd5b,0x24840113,0xf3e00183,0xf3f80356}},	//   пода, _rnom_, খেতৰ_, beţi_, 
   {{0xf3f8084c,0x248482c7,0x38b400e4,0xeb6c0092}},	//   ceţi_, _snom_, túrõ_, _ትርጓሜ_, 
   {{0x490401c6,0x00000000,0x00000000,0x00000000}},	//   _жүжг, --, --, --, 
   {{0x38b400c7,0x00000000,0x00000000,0x00000000}},	//   rúrõ_, --, --, --, 
   {{0xe644cd5c,0x1fb800e1,0x38b40022,0xd3740139}},	//   _неап, _उधेड, súrõ_, пчэ_, 
   {{0x7790168d,0x2cf82017,0x9c10063f,0x96a4024c}},	//   _جیها, ्दुल_, _họta, _екуб_, 
   {{0x81e42158,0xb7bc084c,0x9c10063f,0xe7f400bc}},	//   পেন_, _reţi, _kọta, ेशका_, 
   {{0x24845947,0xc434009f,0x4ea40022,0x00000000}},	//   _unom_, _آباڻ, ҭрра, --, 
   {{0xdfd80801,0x00000000,0x00000000,0x00000000}},	//   сън_, --, --, --, 
   {{0xd24ccd5d,0x9c10063f,0xdb2000dd,0x61fc002d}},	//   _منه_, _lọta, ہوری, _úplo, 
   {{0xf3f8054e,0xcac400cc,0x00000000,0x00000000}},	//   veţi_, ্তাফ, --, --, 
   {{0x4c94cd5e,0xdb20136e,0x7b0800d7,0xed4c00e5}},	//   нисс, فوری, _oľut, گھی_, 
   {{0x3a74cd5f,0xf3f800a8,0x9ba00f78,0x6d4803cd}},	// [11070] млар, teţi_, رەسى, _åfan, 
   {{0xed4c01ed,0x9e2000f7,0x7a3801ca,0x00000000}},	//   دھی_, _سۉرو, іпер_, --, 
   {{0xf3f80311,0xa3dc0073,0x00000000,0x00000000}},	//   reţi_, _दुस_, --, --, 
   {{0x6ef0037e,0xf8b801c6,0xf3f80356,0x9c440108}},	//   ræbe, цөг_, seţi_, _эхол, 
   {{0xda78cd60,0x9c1001f2,0xf3f8054e,0x59a8012c}},	//   _ляв_, _dọta, peţi_, चनहर, 
   {{0x3ce8036e,0xcd3459cf,0x290c0332,0x8af003e3}},	//   llav_, _تریب, úmaí_, ltən, 
   {{0x655000b2,0x7b080064,0x00000000,0x00000000}},	//   نپوء, _užub, --, --, 
   {{0x8af00213,0xb384cd61,0xb4640139,0x00000000}},	//   ntən, длил, фкил, --, 
   {{0xc0f80092,0x33640212,0x00000000,0x00000000}},	//   _ወረራ_, євог, --, --, 
   {{0x3ce807de,0x69e00139,0x00000000,0x00000000}},	//   hlav_, _öyeñ, --, --, 
   {{0x3ce8cd62,0x7c3c035a,0x7b080419,0x00000000}},	//   klav_, _odsr, _zľut, --, 
   {{0x764c03f9,0x00000000,0x00000000,0x00000000}},	//   ɗaya, --, --, --, 
   {{0x5f24013e,0x00000000,0x00000000,0x00000000}},	//   моям_, --, --, --, 
   {{0x7c3c0334,0x7204006c,0xe2800166,0x00000000}},	//   _adsr, _قوشم, _алши, --, 
   {{0x8af00213,0x2d9c0356,0x00000000,0x00000000}},	//   ftən, âte_, --, --, 
   {{0x3ce80b3d,0x2cf802e5,0x61ec0036,0xe7ec00c5}},	//   glav_, ्देल_, üble, _जरला_, 
   {{0x200c00d0,0xbbe800ae,0x00000000,0x00000000}},	// [11080] ámiť_, كركم_, --, --, 
   {{0xa9a46d8c,0x00000000,0x00000000,0x00000000}},	//   мизд, --, --, --, 
   {{0xa9688fcb,0x44240334,0xcdc401d5,0x64b80003}},	//   تمام_, ybm_, _чанқ, rċiz, 
   {{0xb8c40075,0x3ce8cd63,0x18a002e8,0x00000000}},	//   ىزنى, clav_, кахм, --, 
   {{0xd7f4cd64,0x00000000,0x00000000,0x00000000}},	//   муш_, --, --, --, 
   {{0x9c1001f2,0x64d4107c,0x386801e4,0x00000000}},	//   _wọta, डक्श, ĵara_, --, 
   {{0xa9241cd0,0x00000000,0x00000000,0x00000000}},	//   _ідал, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9c10063f,0x7d0801e4,0xdb9800df,0x00000000}},	//   _kọra, ĉesi, ַסטר, --, 
   {{0xa6a8cd65,0x6720bd4b,0x91a800d1,0x00000000}},	//   _بارق_, mpoj, ﺷﻜﯩﻼ, --, 
   {{0x67200029,0x442405b1,0x6aac00b5,0xa3dccd66}},	//   lpoj, pbm_, _mlbf, _दुर_, 
   {{0x141400c6,0x00000000,0x00000000,0x00000000}},	//   _قيمة_, --, --, --, 
   {{0x26cc02e8,0x7c3c0356,0x67200108,0x00000000}},	//   onfo_, _rdsr, npoj, --, 
   {{0x26cc030a,0x33900241,0x81d4010a,0x00000000}},	//   nnfo_, _níṣé, _полх, --, 
   {{0x26cccd67,0x2364009a,0x6d480fac,0xce5800c7}},	//   info_, _hpoj_, _åfal, ьарц_, 
   {{0x2cb000a9,0x6aac0200,0x00000000,0x00000000}},	//   ghyd_, _albf, --, --, 
   {{0xe7dc044b,0x3ce801bf,0x8f44009d,0xcb340395}},	// [11090] _फुलप, rlav_, _ихэд, кетъ, 
   {{0x8af00213,0x672002f0,0x6fb40214,0x00000000}},	//   stən, dpoj, _سمپا, --, 
   {{0x3d24007f,0x3ce819d6,0x77380092,0x00000000}},	//   _dèwò_, plav_, _አልመሰ, --, 
   {{0x2cb00cfd,0x6288089c,0x3d2401e1,0x8af003e3}},	//   chyd_, _lnfo, _eèwò_, ltəl, 
   {{0x6288cd68,0x23640211,0x4c941870,0xf74400c7}},	//   _onfo, _npoj_, _рияс, хело, 
   {{0x9c10063f,0x9964082d,0x60cc004d,0x00000000}},	//   _tọsa, _отбл, hncm, --, 
   {{0x67200022,0xe69015bf,0x394408a5,0x00000000}},	//   apoj, الىد, _íls_, --, 
   {{0x6288cd69,0x8af006be,0x00000000,0x00000000}},	//   _anfo, htəl, --, --, 
   {{0x76b80139,0x87e801d9,0x3d240241,0x3d10000d}},	//   _елар_, _ہٹہِ_, _yèwò_, _दूसे_, 
   {{0x3124cd6a,0xda14000d,0x00000000,0x00000000}},	//   ндог, _तलफत_, --, --, 
   {{0x38540092,0x71a4cd6b,0x00000000,0x00000000}},	//   _የምትጠ, ханз, --, --, 
   {{0x6e3c01fa,0x6288cd6c,0xefec0023,0xb27c0354}},	//   _sdpb, _enfo, _ቀላይ_, _ӳллĕ_, 
   {{0xe3accd6d,0xd58403e6,0x8af00213,0x00000000}},	//   _сб_, _رێکه_, ftəl, --, 
   {{0x2cf80073,0xee38b27b,0x00000000,0x00000000}},	//   ्द्ल_, янг_, --, --, 
   {{0x98a4012c,0xacf410fc,0x9f6000bc,0x672002f0}},	//   éně_, ечај, ěvák_, zpoj, 
   {{0xde00013e,0x00000000,0x00000000,0x00000000}},	//   упси, --, --, --, 
   {{0x62880225,0x60d40375,0x3a300866,0x2ac40cad}},	// [110a0] _ynfo, _רופא_, _bezp_, _níbè_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d4ca996,0x00000000,0x00000000,0x00000000}},	//   muba, --, --, --, 
   {{0x6d4ccd6e,0xe52c010b,0x6aac02d0,0x00000000}},	//   luba, _düýş, _tlbf, --, 
   {{0x26cc9ccb,0x6720c9d7,0x8a880050,0x955c0092}},	//   unfo_, rpoj, _تھرِ_, ሰጡትን_, 
   {{0x6d4ccd6f,0x236404a7,0xe61c010e,0xe464000d}},	//   nuba, _spoj_, _güýį, _ööks_, 
   {{0x672002f6,0xa6c8552d,0x00000000,0x00000000}},	//   ppoj, _کوئل_, --, --, 
   {{0x68e0cd70,0x6d4c286b,0x00000000,0x00000000}},	//   mood, huba, --, --, 
   {{0x8af003be,0x9bb8011a,0x00000000,0x00000000}},	//   xtəl, פציפ, --, --, 
   {{0x6e280b21,0x6d4ccd71,0xd134009d,0x4aa8000d}},	//   _ôfby, juba, нхя_, _गवनव, 
   {{0x6d4ccd72,0xe0cc0154,0x84c400fb,0x00000000}},	//   duba, রত্ন, _шәлд, --, 
   {{0xdef8049b,0x6d4c0af9,0xd43408d8,0x00000000}},	//   зыв_, euba, _טראק_, --, 
   {{0x68e00050,0x418400d1,0x6288cd73,0xd5dc00bc}},	//   hood, _атиғ, _unfo, _पुँज, 
   {{0x68e0cd74,0x108402dd,0x00000000,0x00000000}},	//   kood, _ﺩﯗﺭﯨ, --, --, 
   {{0x8af003be,0x68e0cd75,0xf1a802f2,0x6e380162}},	//   stəl, jood, _تاهه_, ótbr, 
   {{0x68e0cd76,0x6d4c035a,0xba54041b,0x3d101a75}},	// [110b0] dood, auba, квај, _दूरे_, 
   {{0x8af00213,0xe52c010b,0x05b02e2a,0x2ac401e1}},	//   qtəl, _süýş, जनाब, _ríbè_, 
   {{0xc984cd77,0xb83402e8,0x2ac40cad,0x76540205}},	//   луци, веещ, _síbè_, _özyi, 
   {{0x68e0cd78,0x61e831c4,0x2fc4b2be,0x386800df}},	//   good, _myfl, _žogi_, ĵaro_, 
   {{0xd7607b43,0x61e8cd79,0x7f5c02d0,0x00000000}},	//   انتی, _lyfl, ntsq, --, 
   {{0x6444cd7a,0xc668026a,0xa3dc012c,0x61e80175}},	//   ókin, ешће_, _दुइ_, _oyfl, 
   {{0x68e0cd7b,0x00000000,0x00000000,0x00000000}},	//   bood, --, --, --, 
   {{0x68e001d9,0xa018007c,0x00000000,0x00000000}},	//   cood, ndöd, --, --, 
   {{0x6d4ccd7c,0xa3dc0c2e,0x7754cd7d,0x61e802d0}},	//   zuba, _दुआ_, _шкаф, _ayfl, 
   {{0x6d4ccd7e,0xd7f002dd,0x63a42147,0x00000000}},	//   yuba, _азғы, økna, --, 
   {{0x61e80f7b,0x6d4ccd7f,0x764002d0,0x81e40154}},	//   _cyfl, xuba, _idly, পেস_, 
   {{0xf484066d,0x3cf8017a,0x61e802d2,0x387c0042}},	//   _جائی, _nhsv_, _dyfl, ndwr_, 
   {{0x6d4ccd80,0x7fd402dd,0xf18802dd,0x1b140154}},	//   wuba, гірі, _ﯗﻳﻌﯘ, দীতে_, 
   {{0x6d4ccd81,0xf268bc00,0xc60400cc,0x68e00210}},	//   tuba, _цикл_, _উভতা_, zood, 
   {{0x61e80cfd,0x68e00050,0x7b080064,0x00000000}},	//   _gyfl, yood, _ažuo, --, 
   {{0x77680801,0x6d4c2831,0xef840145,0x7e640175}},	//   _opex, ruba, _алип, _ebhp, 
   {{0x6d4ccd82,0x387c0368,0x8af000ac,0x68e000c5}},	// [110c0] suba, ddwr_, stəm, vood, 
   {{0x68e0cd83,0x6d4c3e33,0x1f34011a,0x00000000}},	//   wood, puba, _שריר_, --, 
   {{0xa3dc038e,0x68e0cd84,0xfbd001ed,0x6d4ccd85}},	//   _दुई_, tood, لتے_, quba, 
   {{0x7640035a,0xd9400c17,0x00000000,0x00000000}},	//   _adly, реци, --, --, 
   {{0x68e0cd86,0x7d080115,0xb9e400db,0x0ee000cd}},	//   rood, ĉest, _ەسقى, _ṛṣir_, 
   {{0x68e0cd87,0xc448004b,0x387c0142,0xe9d828f6}},	//   sood, ځیان_, adwr_, _жкг_, 
   {{0xc0e802d3,0xd5ac2dd0,0xd04800ac,0x68e0cd88}},	//   _መሊሱ_, يفه_, şməy, pood, 
   {{0x98a0cd89,0x68e08c88,0x6b94045a,0x18a045c9}},	//   _кисе, qood, oxyg, _касм, 
   {{0x6ef0037e,0x18a0008e,0x98a08008,0x40340032}},	//   væbn, _татм, _тите, һенс, 
   {{0xc174005b,0xddcc0064,0x6eb40210,0x00000000}},	//   глощ, _ėdži, उसफु, --, 
   {{0x4034cd8a,0x7580732b,0x00000000,0x00000000}},	//   ленс, _هیوم, --, --, 
   {{0x7f5c074d,0x7f940022,0x00000000,0x00000000}},	//   ttsq, гамх, --, --, 
   {{0x2d9ccd8b,0x4fc4ad85,0x6440009d,0x1cdc025c}},	//   äten_, асра, _idoi, ྣོལ_, 
   {{0x31a400f1,0x0c900092,0x00000000,0x00000000}},	//   _څلوې, _ሐኪሞች_, --, --, 
   {{0x7b08cd8c,0x0dc83272,0x7f5c02d0,0x8af00213}},	//   _džul, вути_, stsq, mtəh, 
   {{0x62981050,0x1fa4055f,0x7b0800ef,0x00000000}},	//   ljto, _арог, _ežul, --, 
   {{0x1be000ab,0x3e180276,0x9be402bf,0xabb4035b}},	// [110d0] _कुशल_, _попэ_, тівк, гатә, 
   {{0x3d94cd8d,0xdd000259,0x62980240,0x7a340214}},	//   _биор, ırıc, njto, افاص, 
   {{0x81e400bd,0x64400109,0x6b84010e,0x7768007c}},	//   পের_, _odoi, _erkg, _spex, 
   {{0x6440cd8e,0x6b8402d2,0xc86400d8,0x383400f3}},	//   _ndoi, _frkg, итчи, ундр, 
   {{0x3ea0007d,0x7b080006,0xef2800a2,0x970000d1}},	//   _koht_, _užuo, _iküç_, لېرى, 
   {{0x6440cd8f,0x3ea001f4,0x00000000,0x00000000}},	//   _adoi, _joht_, --, --, 
   {{0x3ea0022e,0x7ae4cd90,0x00000000,0x00000000}},	//   _moht_, moht, --, --, 
   {{0x64400076,0xe6f00208,0x7ae40108,0x00000000}},	//   _cdoi, _vườ, loht, --, 
   {{0x64400042,0x00000000,0x00000000,0x00000000}},	//   _ddoi, --, --, --, 
   {{0x3ea00219,0x7ae40427,0xe6f00051,0xe3b401f4}},	//   _noht_, noht, _tườ, убь_, 
   {{0x27f8068f,0x0478006c,0xd498cd91,0x22480210}},	//   ępne_, رلیک_, _орд_, óbka_, 
   {{0x7ae4047e,0xd004035b,0x00000000,0x00000000}},	//   hoht, ионқ, --, --, 
   {{0x7ae4246f,0xc2c400ec,0x00000000,0x00000000}},	//   koht, _ھيٺي, --, --, 
   {{0x7ae402f6,0x2ab4005c,0xa01801d3,0x8af003b9}},	//   joht, _kæbe_, gdöb, ctəh, 
   {{0x8af003be,0xa2d00451,0x57ac012c,0x9d40010a}},	//   stək, _ديوت, झनुह, йерд, 
   {{0xeb980fab,0x7b08b0e8,0xec780032,0x61e4002f}},	//   ниб_, _džum, эпб_, ßkle, 
   {{0xbc1802dd,0x2ab401bf,0xea88cd92,0x1b1400eb}},	// [110e0] тісі_, _læbe_, нбал_, দীসে_, 
   {{0x5ac40139,0x00000000,0x00000000,0x00000000}},	//   глум_, --, --, --, 
   {{0x6da41e51,0xada414e8,0xa848007b,0x6f140051}},	//   _сина, _санл, فلام_, _huyc, 
   {{0x6f14cd93,0xea6001ed,0xeb98022e,0xe7380117}},	//   _kuyc, _گھری, _зим_, еед_, 
   {{0xd94004a9,0x8b0800c7,0xddc41d55,0x7c9402d5}},	//   _қети, _аҭаг_, mejš, _трэц, 
   {{0xddc45e64,0xd7841046,0x00000000,0x00000000}},	//   lejš, انوو_, --, --, 
   {{0x7b08b745,0xf8ac2519,0x4bc40166,0xdb0c00e5}},	//   _ožuj, _дө_, _сөңг, ödöt, 
   {{0xddc4cd94,0x00000000,0x00000000,0x00000000}},	//   nejš, --, --, --, 
   {{0xa3dc19e5,0x65902f0d,0x43040661,0x7bc0012d}},	//   _दुख_, рақу, аҗда, _śluz, 
   {{0x2ab402d2,0x24f40139,0x00000000,0x00000000}},	//   _hæbb_, _өчер, --, --, 
   {{0x23b80248,0x814003e6,0xc61005d7,0xa5241f5a}},	//   _bàjé_, ڕۆژن, ाशीय_, _смед, 
   {{0x65782f05,0x6f14cd95,0x3ea00036,0x61ec0327}},	//   _isth, _buyc, _soht_, żblo, 
   {{0x3ea02ed6,0x6d5c0309,0xe298004d,0x22844b00}},	//   _poht_, _aqpa, _nhưg_, _буйг, 
   {{0x6f14b484,0x254c06be,0x64a400c7,0x2bf800cd}},	//   _duyc, _bəlx_, _шаҵа, ्धनं_, 
   {{0xdc88004e,0x00000000,0x00000000,0x00000000}},	//   нсал_, --, --, --, 
   {{0x6578030d,0x7ae40477,0x00000000,0x00000000}},	//   _msth, woht, --, --, 
   {{0x4094021a,0x6f14010b,0xa0c0004b,0x2ca006be}},	// [110f0] _ملګر, _guyc, _پيښو, _dokd_, 
   {{0x3f880333,0x6578127b,0x7ee801ed,0x00000000}},	//   _irau_, _osth, _جذبہ_, --, 
   {{0x2d9c319f,0x657801d4,0x7ae4cd96,0xb8140120}},	//   øtet_, _nsth, roht, адеј, 
   {{0xf770044d,0xddc4cd97,0x3f88cd98,0x7ae40037}},	//   قات_, cejš, _krau_, soht, 
   {{0x2ab400b5,0xf674009d,0x00000000,0x00000000}},	//   _sæbe_, игдэ, --, --, 
   {{0x35a4b703,0x8f38010f,0x00000000,0x00000000}},	//   иалг, נאוו_, --, --, 
   {{0x6aa80112,0xc984cd99,0x00000000,0x00000000}},	//   öffe, _лути, --, --, 
   {{0x3f88cd9a,0x27f0033f,0x00000000,0x00000000}},	//   _orau_, żyna_, --, --, 
   {{0x6578cd9b,0x3f880218,0x7c2ccd9c,0x00000000}},	//   _esth, _nrau_, ibar, --, 
   {{0x7c2c006c,0x72c400c2,0xd5b8009b,0xe7dc07af}},	//   hbar, рбоз, _псе_, _फुटप, 
   {{0x7c2ccd9d,0x3f8801c0,0x3d104142,0x00000000}},	//   kbar, _arau_, _दंगे_, --, 
   {{0x7c2ccd9e,0x3f88cd9f,0xf8b40cb4,0x00000000}},	//   jbar, _brau_, ंसिय, --, 
   {{0xddc42e6a,0x3f880494,0xe0d4020f,0x6f140051}},	//   vejš, _crau_, рвя_, _quyc, 
   {{0x3f8823e0,0x81e4045e,0x7b0800f3,0x23b801e1}},	//   _drau_, পেই_, _džuk, _wàjé_, 
   {{0x3f88cda0,0x7c2ccda1,0xddc4b515,0xf8b400dc}},	//   _erau_, fbar, tejš, ंसाय, 
   {{0x7c2ccda2,0x3f88cda3,0x6f1402d1,0x00000000}},	//   gbar, _frau_, _tuyc, --, 
   {{0x3f88cda4,0xddc40fb7,0x888401e0,0xac08cda5}},	// [11100] _grau_, rejš, ҙғал, тнаа_, 
   {{0xaa44cda6,0x8eb400db,0xda040ebb,0x2d9c03cd}},	//   режл, _اەست, _वृहत_, øtes_, 
   {{0x3af411ed,0x7bdc1730,0x2d5c0548,0xddc400d7}},	//   сятс, _exsu, qïe_, pejš, 
   {{0x764c03f9,0xe7a80108,0x00000000,0x00000000}},	//   ɗayi, квел_, --, --, 
   {{0xab280e92,0x5c0002dd,0xd7ec007b,0x00000000}},	//   _јога_, _وكپە, وكم_, --, 
   {{0x6d4c67e9,0x9a24084c,0xaa5801c8,0x00000000}},	//   orba, _ворб_, _جلسا_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x29000428,0x00000000,0x00000000,0x00000000}},	//   _òka_, --, --, --, 
   {{0x6d4ccda7,0x2d9c00d0,0x00000000,0x00000000}},	//   hrba, ätej_, --, --, 
   {{0x26c8007c,0xd9e8000d,0x76f4010a,0x94c800f1}},	//   _öbo_, _जुडत_, _ляхх, _یانې_, 
   {{0x7c2ccda8,0x7b0801fa,0x65780c8c,0x5a1405d0}},	//   ybar, _džuh, _usth, יקין_, 
   {{0x7c2c0050,0xd5740302,0x3f88cda9,0x6d4ccdaa}},	//   xbar, _כתבה_, _prau_, drba, 
   {{0x7c2c010a,0xdfd800a7,0x6d5800db,0x6e2000a2}},	//   vbar, тън_, àtan, _şoba, 
   {{0x7c2c01a4,0x3f880023,0x7f940022,0xb4e001e1}},	//   wbar, _vrau_, _ҳаих, _ààre, 
   {{0x51f002dd,0x5190007b,0x776c0003,0x12f8011a}},	//   _وسىر, _ولهذ, ħaxi, _שהוב, 
   {{0x7c2ccdab,0xc0341614,0x00000000,0x00000000}},	//   ubar, _униј, --, --, 
   {{0x9a240dd8,0x5c0406bb,0x6d4ccdac,0x3f88cdad}},	// [11110] لعان, рява, arba, _urau_, 
   {{0x7c2ccdae,0x19a83b5f,0xd54001e1,0x6d4c0009}},	//   sbar, ктеп_, _jẹ̀g, brba, 
   {{0x6be80050,0x8934009f,0x180c08a3,0x00000000}},	//   ن٘ہہ_, قعنا, िश्व_, --, 
   {{0x38680510,0x7c940597,0x9b6807d6,0x7c2c56f7}},	//   ýar_, _الحص, _ишга_, qbar, 
   {{0xedb40133,0xa80000a2,0x00000000,0x00000000}},	//   _نجێک, _ýıld, --, --, 
   {{0xe0cc03d4,0x87040b24,0x38680055,0x9a84030d}},	//   ৰতিভ, يبول, _śirā_, _тумл, 
   {{0x6a20066d,0x27f8068f,0xd784040b,0x35a401d5}},	//   _رہنم, ępna_, انڈو_, сайг, 
   {{0xe9a40014,0x7e740784,0xd77400db,0x78ac007c}},	//   _دۯمن_, hezp, _پارع, öavd, 
   {{0xb7d40150,0x7e74005a,0xec70010f,0x998001ef}},	//   _اقءب, kezp, פֿה_, _jejž_, 
   {{0x97000075,0xad54001f,0xe510000d,0x00000000}},	//   _بېتى, _ዝግጅቶ, _ढूकि_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb64002dd,0x05e800df,0x00000000,0x00000000}},	//   _ﺃﻨ_, _דובֿ_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6da44a40,0xd54001e1,0x6d4c0356,0xe29400d8}},	//   бига, _gẹ̀g, trba, _гаш_, 
   {{0xb4f8010f,0x00000000,0x00000000,0x00000000}},	//   ָפּי, --, --, --, 
   {{0x6d4c8c66,0xceb400ac,0x3b180175,0xa018cdaf}},	//   rrba, _atət_, _busq_, ldön, 
   {{0x7e749637,0x6a1436e7,0xdcac2dfc,0xdca01bc0}},	// [11120] bezp, مبار, رىك_, чати, 
   {{0xa0180724,0x00000000,0x00000000,0x00000000}},	//   ndön, --, --, --, 
   {{0x1af402f5,0x9f4c01e1,0x1d6c0092,0x00000000}},	//   _অংশই_, _àgò_, _ስልቶች_, --, 
   {{0x0dc4001f,0x00000000,0x00000000,0x00000000}},	//   ሸነፍ_, --, --, --, 
   {{0xdd8c4e10,0x00000000,0x00000000,0x00000000}},	//   _قوی_, --, --, --, 
   {{0x6d4803cd,0x1b1c00cc,0x44200327,0x00000000}},	//   _åfas, _পিচে_, _żi_, --, 
   {{0x0dbc069c,0x00000000,0x00000000,0x00000000}},	//   _ሰልፊ_, --, --, --, 
   {{0x2cb000a2,0x00000000,0x00000000,0x00000000}},	//   nkyd_, --, --, --, 
   {{0x64a4cdb0,0x2904016b,0xb55402d3,0x2bf800dc}},	//   _қада, mmoa_, _ዘይፍት, ्धिं_, 
   {{0x290401c4,0x8af003b9,0x00000000,0x00000000}},	//   lmoa_, mtəs, --, --, 
   {{0x1b1c4251,0xd6cc1a73,0x26cc07c5,0x8af00213}},	//   _পিছে_, _ثقل_, mifo_, ltəs, 
   {{0x26cccdb1,0xe0480066,0x00000000,0x00000000}},	//   lifo_, دشده_, --, --, 
   {{0x29040418,0xe3f401b9,0x7e7401c4,0xc7b4008f}},	//   imoa_, _اثاب, tezp, קבֿ_, 
   {{0x3d9402f6,0x26cc2486,0x3d1000e1,0x29040108}},	//   оигр, nifo_, _दूजे_, hmoa_, 
   {{0x3b10036b,0x9c4401c0,0x00000000,0x00000000}},	//   _rizq_, йхал, --, --, 
   {{0x26cccdb2,0x8af003b9,0xbc7800d8,0x00000000}},	//   hifo_, ktəs, јбах_, --, 
   {{0x26cc0a49,0x7eb00124,0x60cc035a,0x7e74cdb3}},	// [11130] kifo_, _ẽpuk, micm, pezp, 
   {{0x60cccdb4,0x00000000,0x00000000,0x00000000}},	//   licm, --, --, --, 
   {{0x26cc0134,0xf8b0cdb5,0x00000000,0x00000000}},	//   difo_, وکر_, --, --, 
   {{0x60cccdb6,0x51580bd9,0x8af00213,0x9e640244}},	//   nicm, רכאו, ftəs, _ئاکن, 
   {{0xf744084c,0x291c0077,0x6d4803cd,0xb6a4cdb7}},	//   цело, _étan_, _åfar, жилл, 
   {{0x29041e5d,0xd6d8005b,0xb93400d8,0x69c80055}},	//   amoa_, ыте_, _мегј, _śleś, 
   {{0x77400023,0x65900063,0x00000000,0x00000000}},	//   _ኣይምተ, дају, --, --, 
   {{0xe6dc063f,0xb4a8014b,0xd3a000d1,0xf348329b}},	//   rịọ_, ркиз_, злиқ, апил_, 
   {{0x7b0801fa,0x386ccdb8,0x26cccdb9,0x36d4084c}},	//   _džuv, _iber_, bifo_, _доар, 
   {{0x63a401e6,0x8af000ac,0x26cc0115,0xe3b40024}},	//   äkna, ltər, cifo_, юбы_, 
   {{0xd4e410f5,0x60cc0048,0xc7240241,0x6e20054e}},	//   _люди, ficm, _iṣọw, _şobo, 
   {{0x60cc45a7,0x23741208,0x5348030d,0x339400ae}},	//   gicm, حمید_, _йăмă, _ولاز, 
   {{0x386ccdba,0x32440137,0x00000000,0x00000000}},	//   _mber_, _делг, --, --, 
   {{0x386c06a3,0x99800327,0xf8b40034,0x0dbc00b7}},	//   _lber_, _bejż_, ंसुप, _ሰልፍ_, 
   {{0x386ccdbb,0xc4e406a3,0xd1b80133,0xa1540640}},	//   _ober_, _ãƒâ_, _حاشا_, _дају_, 
   {{0xed583461,0x26cc0912,0x386ccdbc,0xe2980208}},	//   лоҳ_, zifo_, _nber_, _thưc_, 
   {{0xeab000dd,0x26cc016b,0xaec40276,0xeb9801a9}},	// [11140] وٹر_, yifo_, _мбил, шиа_, 
   {{0x386c91e1,0x81e403d4,0x63a4b41e,0xe9d00116}},	//   _aber_, পেও_, økni, وغا_, 
   {{0x09c4009e,0x98c000bc,0x290401c6,0x8af00213}},	//   ্থভা, _úvěr_, tmoa_, ftər, 
   {{0x61eccdbd,0x9f4c0124,0xe5a401e1,0x291033fe}},	//   übli, _ágã_, _àjẹ́, öya_, 
   {{0x26cc6965,0x290403f5,0x37dc00cc,0x66e4004e}},	//   tifo_, rmoa_, _বৰবৰ, оода, 
   {{0x290405f5,0x56908068,0x386c89fa,0xe66402bf}},	//   smoa_, дашт, _eber_, ітло, 
   {{0x26cccdbe,0x8af000ac,0x00000000,0x00000000}},	//   rifo_, stəs, --, --, 
   {{0x63680063,0x66740133,0x00000000,0x00000000}},	//   арог_, _ژدار, --, --, 
   {{0x8af000ac,0x26cc016b,0x00000000,0x00000000}},	//   qtəs, pifo_, --, --, 
   {{0x386c0030,0x4ecc0011,0x92e400ec,0xe5940244}},	//   _zber_, লকুল, يفيٰ_, _وشاخ, 
   {{0xe29801dc,0x60cccdbf,0x8af003e3,0x2b4400d7}},	//   _chưa_, ticm, ntəq, šoch_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe3b01a73,0x60cccdc0,0x34d8008f,0x3f8c00db}},	//   _ترا_, ricm, _פֿעב, íeu_, 
   {{0x4424003a,0x9254cdc1,0xa0180267,0x00000000}},	//   lcm_, _дашт_, mdöm, --, 
   {{0x9c80012c,0x81e4015b,0x60cc7a02,0x00000000}},	//   íčov, পেজ_, picm, --, 
   {{0x6aa80730,0x442484aa,0x00000000,0x00000000}},	//   öffn, ncm_, --, --, 
   {{0xdd8c3256,0xc5d000cc,0x386c0166,0x442400e4}},	// [11150] رۈڭ_, িথিপ, _rber_, icm_, 
   {{0x44240016,0x00000000,0x00000000,0x00000000}},	//   hcm_, --, --, --, 
   {{0xe2a431ac,0x8af003b9,0xcfb000cc,0x00000000}},	//   _áður_, drəd, _চেপন, --, 
   {{0xdcec0024,0x8d74cdc2,0xf8b407f7,0x7798026b}},	//   _įdėj, _کایا, ंसेप, йкер_, 
   {{0x8af003e3,0x4424003a,0x7c3c02d0,0x1be0033f}},	//   rtər, dcm_, _iesr, _कुचल_, 
   {{0x8af00cc1,0xcf580302,0x7c3ccdc3,0x06c80845}},	//   stər, קבות_, _hesr, огій_, 
   {{0x7c3c3743,0x7b0800ef,0x99800064,0x8af003b9}},	//   _kesr, _džut, _vejų_, mtəp, 
   {{0x7c3c0649,0xb4e40d2c,0x8858cdc4,0x8af006be}},	//   _jesr, पके_, _мисс_, ltəp, 
   {{0x7c3ccdc5,0x13a42be7,0xa01805d5,0x4c9c0677}},	//   _mesr, زندی_, rdöl, שבחו, 
   {{0x78a81aa7,0x7c3c02d2,0x12843267,0x00000000}},	//   _hoev, _lesr, آمدی_, --, 
   {{0x78a8cdc6,0x7c3c0af9,0x44240334,0x332c0393}},	//   _koev, _oesr, bcm_, spex_, 
   {{0x442400ec,0x78a801e4,0xafe401a9,0x00000000}},	//   ccm_, _joev, зомл, --, 
   {{0xefd00020,0x9c1001f2,0x78a8cdc7,0x6abc0175}},	//   _ከዚያ_, _jọda, _moev, yhpf, 
   {{0xb8fc2fb5,0xe298001e,0x78a8cdc8,0x00000000}},	//   _ཤམ_, _thưa_, _loev, --, 
   {{0xde007c0c,0x6da44f65,0xdee01ee3,0x61ec02fb}},	//   епри, чива, хори, čilé, 
   {{0xdca0cdc9,0x78a8cdca,0x7c3c0113,0x6d9000e4}},	//   наси, _noev, _cesr, _ẽasy, 
   {{0x7c3ccdcb,0x09b4043e,0x67181414,0x00000000}},	// [11160] _desr, ंन्य, _फूंक_, --, 
   {{0x7c3c0037,0x2b500076,0x44240175,0x7fe8cdcc}},	//   _eesr, rryc_, zcm_, _ظريف_, 
   {{0x78a8cdcd,0xe9d80063,0x3c440064,0x2248012d}},	//   _boev, љке_, _būvį_, óbki_, 
   {{0x7c3c0098,0x78a8cdce,0xb4e4012c,0xd82021fa}},	//   _gesr, _coev, पको_, едци, 
   {{0x8af003be,0x78a801f5,0x61400ca8,0x6e3c010e}},	//   stəq, _doev, _kílá, _kepb, 
   {{0x6e3c0432,0x7b08013a,0x00000000,0x00000000}},	//   _jepb, _džus, --, --, 
   {{0xc4485da7,0x4424cdcf,0x00000000,0x00000000}},	//   قیان_, tcm_, --, --, 
   {{0x9440040d,0x6e3c010e,0xe2980051,0x439401f0}},	//   ىپىن, _lepb, _chưn_, даис, 
   {{0x4424003a,0x4ac000dc,0xa6e003b2,0x00000000}},	//   rcm_, _एताव, áðsj, --, 
   {{0x4424070d,0x6e3ccdd0,0x78a801f5,0xa018c9df}},	//   scm_, _nepb, _zoev, rdöm, 
   {{0x4424037e,0xa01801e3,0x1a9800df,0x00000000}},	//   pcm_, sdöm, ציטע, --, 
   {{0xa38400b8,0x555000f2,0x00000000,0x00000000}},	//   _caõó, _سپهر, --, --, 
   {{0x6e3c0455,0xe3f801ec,0x7c94001f,0xa38400b8}},	//   _bepb, _اعاش_, _መሻሻል_, _daõó, 
   {{0x7c3ccdd1,0x272003b2,0x626400db,0x8af006be}},	//   _sesr, _mðn_, _راتق, hrəb, 
   {{0x248400d5,0x614000ae,0x7c3c9bdb,0xa0187305}},	//   _kaom_, _dílá, _pesr, ndök, 
   {{0x6e3c02d0,0x7c3c0455,0x11d8011a,0x00000000}},	//   _eepb, _qesr, _לחוב, --, 
   {{0x0fe4cdd2,0x00000000,0x00000000,0x00000000}},	// [11170] _зөрү, --, --, --, 
   {{0x7b081050,0x7c3cb13c,0x614001e1,0x78a8cdd3}},	//   _ažur, _wesr, _gílá, _soev, 
   {{0x2d9c0267,0x78a8000d,0x1cdc0327,0x6ef001bf}},	//   ätet_, _poev, ྣོད_, ræbt, 
   {{0x24840421,0xd83801c0,0x9ba00a52,0x3774004e}},	//   _naom_, сэж_, _كەزى, дыкс, 
   {{0x7b0801fa,0x6e3c014f,0x78a80139,0x00000000}},	//   _džur, _yepb, _voev, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x78a8cdd4,0xb9246245,0x00000000,0x00000000}},	//   _toev, _آفري, --, --, 
   {{0x20180b6f,0x6d580e89,0x3354004e,0x00000000}},	//   _ngqi_, àtai, дүдө_, --, 
   {{0x69d800e4,0x7b080064,0x630000d1,0x00000000}},	//   _ÿter, _užus, چۈنل, --, 
   {{0x312400db,0x00000000,0x00000000,0x00000000}},	//   мдог, --, --, --, 
   {{0x41b42e01,0x6e3c022f,0xd5b895a2,0x35f40006}},	//   есят, _repb, _уса_, _ўпер, 
   {{0x9c1001f2,0x6e3c0477,0x614001e1,0xd9bc05ac}},	//   _mọba, _sepb, _sílá, _আশাম, 
   {{0x1cdc025c,0xd344158b,0x00000000,0x00000000}},	//   ྣོན_, _عیده_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc0e80023,0x8af003e3,0x00000000,0x00000000}},	//   መሎም_, hrəc, --, --, 
   {{0x67200113,0x00000000,0x00000000,0x00000000}},	//   yqoj, --, --, --, 
   {{0x300401b9,0x6a842360,0x00000000,0x00000000}},	// [11180] _юзиг, млаа, --, --, 
   {{0xd1d0001f,0xae203c71,0xa018c2f8,0x00000000}},	//   _ያላት_, _मलिन_, geöf, --, 
   {{0x5e980375,0x00000000,0x00000000,0x00000000}},	//   _וביק, --, --, --, 
   {{0xeb98488e,0x7b9801d9,0x00000000,0x00000000}},	//   _дим_, _کھٲس_, --, --, 
   {{0x3ce401d3,0x00000000,0x00000000,0x00000000}},	//   élve_, --, --, --, 
   {{0x3cec08a4,0x69c80174,0x00000000,0x00000000}},	//   čeve_, úfes, --, --, 
   {{0x684401f0,0x00000000,0x00000000,0x00000000}},	//   _онва, --, --, --, 
   {{0x7b0816a3,0xb7bc00fe,0xa0180205,0x00000000}},	//   _užur, _আখৰট, rdök, --, 
   {{0x6720208d,0x00000000,0x00000000,0x00000000}},	//   qqoj, --, --, --, 
   {{0xc2240633,0x00000000,0x00000000,0x00000000}},	//   رکتو, --, --, --, 
   {{0x2484cdd5,0x00000000,0x00000000,0x00000000}},	//   _taom_, --, --, --, 
   {{0xf7b40137,0x00000000,0x00000000,0x00000000}},	//   _تۇۇع_, --, --, --, 
   {{0x9340a1a3,0xd24ccdd6,0x656801e7,0x00000000}},	//   _анче, _چنه_, ltfh, --, 
   {{0xd24c0aad,0x27f000ee,0x826801ed,0xdce80010}},	//   _ننه_, ýyny_, _رشتہ_, čičn, 
   {{0x291c0098,0x9ba00131,0x4a2c0327,0xa01801f4}},	//   _étah_, ھەسى, _ཧྥེལ_, hdöi, 
   {{0x394c01e4,0xfe040205,0x3084010a,0x00000000}},	//   _ĉes_, _ıçın_, _пăсс, --, 
   {{0x2d9ccdd7,0x3f8400da,0xbfd4742b,0xf0000117}},	// [11190] äter_, ālus_, _سيدع, _бӯри, 
   {{0x7f5ccdd8,0xde4400f6,0x4a5400cf,0x00000000}},	//   musq, _زیرو_, ккус, --, 
   {{0xc984084c,0xe0dc011c,0x7e64007f,0x224c04e6}},	//   куци, onò_, _ichp, _mdfk_, 
   {{0xe0dccdd9,0x907c010f,0x00000000,0x00000000}},	//   nnò_, ַטוי, --, --, 
   {{0x7f5ccdda,0xc95800d1,0xdde8cddb,0x36d41149}},	//   nusq, كلەش_, _درکه_, нодр, 
   {{0x01ac02dd,0x7f5c003a,0x63b4010e,0x00000000}},	//   _ءاﻮ_, iusq, _ýyny, --, 
   {{0x7f5c0113,0x7d0c0472,0xa5c00419,0x00000000}},	//   husq, omas, ňónm, --, 
   {{0x7d0ccddc,0x09c4009e,0x7f5c0bf1,0xd87400db}},	//   nmas, ্থশা, kusq, _تاسب, 
   {{0xc864ada6,0xc0c80020,0x7d0ccddd,0x37543c5b}},	//   _штри, _አማራ_, imas, _سپاس, 
   {{0x7d0ccdde,0x7f5c0381,0x6918010e,0xe2c4010a}},	//   hmas, dusq, _iįer, ельд_, 
   {{0x7d0ccddf,0x03240724,0x81bc00e2,0xdeb801f3}},	//   kmas, ндөн, lcēj, ሰኑን_, 
   {{0x764000f8,0xe0dc6933,0x7e64007f,0x3cf8033f}},	//   _hely, gnò_, _achp, ंतों_, 
   {{0x6e4c044e,0x7640cde0,0x752001f5,0x7f5c003a}},	//   _ንምግባ, _kely, _hulz, gusq, 
   {{0xe0dc011c,0x75200083,0x00000000,0x00000000}},	//   anò_, _kulz, --, --, 
   {{0x7640cde1,0x27f80210,0x00000000,0x00000000}},	//   _mely, ępni_, --, --, 
   {{0x7640cde2,0x7d0ccde3,0x7f5c6ce4,0x7af40083}},	//   _lely, gmas, busq, _akzt, 
   {{0x245803ee,0x75200023,0x7f5c16b8,0x2bc8013d}},	// [111a0] lümü_, _lulz, cusq, члап_, 
   {{0x160c46c7,0x7d0ccde4,0x94fc031c,0x76400024}},	//   ाधार_, amas, _ཝེའི_, _nely, 
   {{0x24581ae4,0x3af4005b,0x81bc0171,0x00000000}},	//   nümü_, тятс, ecēj, --, 
   {{0x7d0c005c,0xeff40023,0xe8f400f2,0x00000000}},	//   cmas, _ዉሉድ_, رساخ, --, 
   {{0x752007c5,0xf8a8027d,0x7e6402d0,0xb5ac00cc}},	//   _aulz, بدله_, _ychp, _কেলচ, 
   {{0x6a84b3a6,0x76400042,0x45d4cde5,0x24580342}},	//   _ялга, _cely, колс, kümü_, 
   {{0x764082b9,0x7c2800df,0x1ae0702f,0xa92400d4}},	//   _dely, _ĵerz, _сорм, _їдал, 
   {{0x7520cde6,0x7640035a,0x7f5c0309,0x65680332}},	//   _dulz, _eely, yusq, rtfh, 
   {{0x7640cde7,0x7f5c0393,0x00000000,0x00000000}},	//   _fely, xusq, --, --, 
   {{0x7640cde8,0x7d0ccde9,0x6aac037e,0x7520003e}},	//   _gely, zmas, _jobf, _fulz, 
   {{0x1dcc0c2e,0x75205395,0x40340354,0x00000000}},	//   _हेंत, _gulz, кенс, --, 
   {{0x7f5c1730,0x7d0c00ac,0x00000000,0x00000000}},	//   tusq, xmas, --, --, 
   {{0xe298cdea,0xe0dcc5bf,0x7d0c022e,0x00000000}},	//   _над_, rnò_, vmas, --, 
   {{0x6aac0204,0x644000a3,0x245805d1,0x7f5ccdeb}},	//   _nobf, _heoi, bümü_, rusq, 
   {{0x6288010f,0x644000ad,0x31843007,0x7f5ccdec}},	//   _iafo, _keoi, _атың, susq, 
   {{0xb5ac03d4,0xccf8026a,0x64400076,0x7f5c03f0}},	//   _কেঁচ, ећу_, _jeoi, pusq, 
   {{0x6288cded,0x64401368,0x7f5c02d1,0x00000000}},	// [111b0] _kafo, _meoi, qusq, --, 
   {{0x7f4c0286,0x7e6402d1,0x6440cdee,0x628801d5}},	//   _ivaq, _uchp, _leoi, _jafo, 
   {{0x7640cdef,0x6288014c,0x64400a73,0x7d0ccdf0}},	//   _rely, _mafo, _oeoi, pmas, 
   {{0x7640323e,0x6288cdf1,0x644003d5,0x7d0ccdf2}},	//   _sely, _lafo, _neoi, qmas, 
   {{0x167056ff,0x7520cdf3,0x7640cdf4,0x4c940058}},	//   лқар, _sulz, _pely, _сияс, 
   {{0x7520cdf5,0x64400093,0x81bc005f,0xe7b00116}},	//   _pulz, _aeoi, rcēj, شمىد, 
   {{0x64400597,0xc6480150,0x35a4cdf6,0x7640cdf7}},	//   _beoi, رجول_, тайг, _vely, 
   {{0x1cdc0156,0xe7d0cdf8,0x644000c6,0x62880067}},	//   _སམས_, _देवप, _ceoi, _aafo, 
   {{0x6288cdf9,0x6440679d,0x76407a9a,0x674001d9}},	//   _bafo, _deoi, _tely, _نێنٕ, 
   {{0x628800a9,0x752006f2,0xb22400c2,0xa24400e5}},	//   _cafo, _tulz, ъмол, پیٹل_, 
   {{0xd5b8006c,0x6440cdfa,0x7f4c0869,0x6288cdfb}},	//   _эса_, _feoi, _avaq, _dafo, 
   {{0x6440cdfc,0x6288cdfd,0x2458cdfe,0x108401b9}},	//   _geoi, _eafo, rümü_, уғиг, 
   {{0x62880161,0x999000bc,0xe3ac84dc,0x8af006be}},	//   _fafo, čeře_, _тб_, drən, 
   {{0x628800a9,0xd244010b,0xddc40327,0xe29401c6}},	//   _gafo, _чэди, bejż, _ааш_, 
   {{0x7f4c0113,0x8af000ac,0x9d40004e,0x00000000}},	//   _evaq, frən, иерд, --, 
   {{0x1d04cdff,0xeb9801d5,0xf8bc012d,0x62880210}},	//   веси_, миб_, ्फोप, _zafo, 
   {{0x7f4c0097,0x6288ce00,0xea88ce01,0xaec400c0}},	// [111c0] _gvaq, _yafo, мбал_, _абпл, 
   {{0x6a1403e6,0x63a401e6,0x628800db,0x7d080135}},	//   نبار, äkni, _xafo, ċesa, 
   {{0xaa1400d8,0x00000000,0x00000000,0x00000000}},	//   тфај, --, --, --, 
   {{0x7994068f,0xddc40030,0x8af00213,0xab28004e}},	//   _drzw, dajň, ntəz, _оома_, 
   {{0x6d5802d5,0xe7d00490,0x6440007b,0x79940112}},	//   štad, _देशप, _reoi, _erzw, 
   {{0x1cdc0156,0x6440007b,0x2a7c03b2,0xf1c007b7}},	//   _སམོ_, _seoi, _útb_, शनान, 
   {{0x6288ce02,0x6440ce03,0xa01801d3,0xd940ce04}},	//   _rafo, _peoi, ldöt, _веси, 
   {{0x628880dc,0x9f5c00e8,0xfb8401d3,0xd4640063}},	//   _safo, ërëg_, _جگہی, виће_, 
   {{0x6288ce05,0xa0180793,0x6674c539,0xa684ce06}},	//   _pafo, ndöt, _لدار, _илад, 
   {{0x68e0ce07,0x6288ce08,0x779002f2,0x00000000}},	//   lnod, _qafo, _دیها, --, 
   {{0x9f4c008c,0x6288036b,0x6440ce09,0x606000d1}},	//   _ágú_, _vafo, _teoi, لۇغل, 
   {{0xe3b8ce0a,0x628802ce,0x68e00368,0x1074177b}},	//   _обе_, _wafo, nnod, алюю, 
   {{0x68e0ce0b,0x00000000,0x00000000,0x00000000}},	//   inod, --, --, --, 
   {{0x11d0006c,0x68e00142,0xd9e8000d,0x00000000}},	//   اتید, hnod, _जुझत_, --, 
   {{0x51f004fb,0x9e640330,0x3a74134b,0xdc8830c2}},	//   _پسور, _یادن, һлар, мсал_, 
   {{0x68e00115,0xa3d40037,0x00000000,0x00000000}},	//   jnod, _सधा_, --, --, 
   {{0x68e003c6,0xfb34084c,0x4bb4004e,0xebc011ca}},	// [111d0] dnod, унзэ, айтс, бәрн, 
   {{0x68e0ce0c,0x3f8823e0,0xda64007b,0x00000000}},	//   enod, _isau_, ضائي, --, 
   {{0x68e00cfd,0xdde813f9,0x8af000ac,0x0a6800a7}},	//   fnod, _زرده_, mrəl, ърти_, 
   {{0x68e003cb,0x5c0460a1,0x0cd4117e,0xc8640114}},	//   gnod, _аяга, _воюю, атљи, 
   {{0x7c2c00c6,0x65780bc9,0x97c43009,0x7d1cce0d}},	//   mcar, _apth, ختام, _iiss, 
   {{0x7d1cce0e,0x68e0ce0f,0x8af003b9,0x00000000}},	//   _hiss, anod, ktəy, --, 
   {{0xc984b458,0x68e0ce10,0x7c2c0393,0x7d1cce11}},	//   _кути, bnod, ocar, _kiss, 
   {{0x7c2cce12,0x7d1cce13,0xa01801ed,0x13340092}},	//   ncar, _jiss, ndös, _የነጻነ, 
   {{0x7c2c0024,0x65780857,0x00000000,0x00000000}},	//   icar, _epth, --, --, 
   {{0xd24007d6,0x7c2cce14,0xa018005b,0xd5b80114}},	//   шмоқ, hcar, hdös, _осе_, 
   {{0x291c0231,0x3f88ce15,0xd5640063,0x7d1c02d0}},	//   _état_, _asau_, _штап, _oiss, 
   {{0x7c2cce16,0xa1c00108,0x00000000,0x00000000}},	//   jcar, сбюд, --, --, 
   {{0xe28cce17,0x7c2cce18,0x61e89442,0xa3d801ad}},	//   _ла_, dcar, _exfl, _डेप_, 
   {{0x7d1cce19,0x7c2c0393,0x68e0ce1a,0x3244004e}},	//   _aiss, ecar, znod, _секг, 
   {{0x3f88ce1b,0x81a82834,0x9f9c002e,0x68e000a9}},	//   _esau_, _لطيف_, _déñc_, ynod, 
   {{0x7d1cce1c,0x7c2c005c,0x66c408a5,0xf06401f4}},	//   _ciss, gcar, _iðke, _скип, 
   {{0x68e007f5,0xea58ce1d,0x8af003b9,0xfb2400cf}},	// [111e0] vnod, ереј_, brəl, иптү, 
   {{0x7d1c180f,0xccf4013f,0xee380006,0x6da43e38}},	//   _eiss, soɛ_, _яно_, _биоа, 
   {{0x2d9411e0,0x7d1cce1e,0x68e0ce1f,0xa3d807f7}},	//   _српс, _fiss, tnod, _डेन_, 
   {{0x7c2cce20,0x6844ce21,0x7d1cce22,0xb90801f2}},	//   ccar, унда, _giss, _ichọ_, 
   {{0x68e0ce23,0xd7f4ce24,0xa018007c,0x00000000}},	//   rnod, луш_, ldör, --, 
   {{0x68e0ce25,0x7d1c1418,0x6d4c017a,0x6fe000cc}},	//   snod, _ziss, osba, _নৰৱে, 
   {{0xeb9801d5,0x1ef8010f,0xa018ce26,0x00000000}},	//   _ўиҳ_, עלצע, ndör, --, 
   {{0x6f1c068f,0x44b4143d,0x6d4c1543,0x7d1c81f1}},	//   _lipc, рбис, isba, _xiss, 
   {{0x8af000ac,0xe73800a7,0x66c4032e,0x6d4c035a}},	//   hrəm, _чез_, _aðke, hsba, 
   {{0x6d4cce27,0xa018ce28,0x00000000,0x00000000}},	//   ksba, kdör, --, --, 
   {{0xa49401e4,0xb90802e3,0x6d4c01a4,0xd48c0c5c}},	//   _akϲe, _nchọ_, jsba, _лр_, 
   {{0x9f4c025a,0x6d4c127b,0xddc8025c,0x8af006be}},	//   _âgë_, dsba, ċiża, drəm, 
   {{0xb90800b4,0x2d9cce29,0x6d4cce2a,0x8af000ac}},	//   _achọ_, åten_, esba, stəy, 
   {{0x7d1cce2b,0x7c2c3c36,0x3dc80451,0x8af003e3}},	//   _siss, wcar, پورٽ_, frəm, 
   {{0x7c2cce2c,0x7d1cce2d,0x4034188c,0x6f1c0115}},	//   tcar, _piss, _кейс, _dipc, 
   {{0xd044013f,0x3f880211,0x7d1cce2e,0xd71c03d4}},	//   _mmiɛ, _tsau_, _qiss, নীয়া_, 
   {{0x7d1cce2f,0x6d4cce30,0x2a680175,0xa018ce31}},	// [111f0] _viss, asba, _bcbb_, rdös, 
   {{0x7d1c2bb9,0x7c2c49da,0x6d4cce32,0x00000000}},	//   _wiss, scar, bsba, --, 
   {{0x6d4cce33,0x7c2cce34,0x00000000,0x00000000}},	//   csba, pcar, --, --, 
   {{0x6f1cce35,0x7d1cce36,0x6d58009b,0x764c02a8}},	//   _zipc, _uiss, štac, ɗayy, 
   {{0x97000075,0x7eb000c7,0xc8c80066,0x00000000}},	//   مېرى, _ẽpyk, دونن_, --, 
   {{0x3868ce37,0x6f1c022e,0x6abc002f,0xc864035b}},	//   żar_, _xipc, ckpf, атәи, 
   {{0xd4f401e0,0x7bccce38,0x00000000,0x00000000}},	//   лфиә_, lzau, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7bccce39,0x56648a41,0x72c40372,0x6d4c00e5}},	//   nzau, _مداف, ибиз, zsba, 
   {{0x6d4cce3a,0x34940124,0x00000000,0x00000000}},	//   ysba, уаҩр, --, --, 
   {{0x2008013f,0x80c000eb,0x00000000,0x00000000}},	//   ɑhiɑ_, ৎচন্, --, --, 
   {{0x8af000ac,0x6d4c93e0,0x6f1c0356,0x00000000}},	//   stəx, vsba, _sipc, --, 
   {{0x7bccce3b,0xc32c02dd,0xe3a400f2,0x7b082109}},	//   jzau, _كەي_, _نشوی, _džuz, 
   {{0xed5830ba,0x6d4cce3c,0x7bccce3d,0x6f1c1ffc}},	//   ког_, tsba, dzau, _qipc, 
   {{0x1ae8009e,0x6f1cce3e,0x6d4c1f96,0x00000000}},	//   কতাই_, _vipc, usba, --, 
   {{0x6d4c9442,0xa0185b00,0x8af00213,0xdfcc004b}},	//   rsba, rdör, rrəm, _ښيي_, 
   {{0x6d4cce3f,0x9c1002e3,0xa11021ef,0xa01801e3}},	// [11200] ssba, _fọma, _بويت, sdör, 
   {{0xed4412a2,0x6d4cce40,0x3c180006,0x7f6001ec}},	//   _кноп, psba, уўся_, _ﻗﺘل_, 
   {{0xada49e05,0x00000000,0x00000000,0x00000000}},	//   _танл, --, --, --, 
   {{0xe7380364,0x7bcc0211,0x7ae4ce41,0xbe0400e5}},	//   вед_, bzau, anht, _دوپٹ, 
   {{0x18649088,0x2d98107d,0xa3d80550,0x00000000}},	//   рачи_, _hrpe_, _डेढ_, --, 
   {{0xd6cc0014,0xd7040a31,0x00000000,0x00000000}},	//   وقن_, анче_, --, --, 
   {{0x81bc00e2,0x00000000,0x00000000,0x00000000}},	//   ncēt, --, --, --, 
   {{0xd494ce42,0x3fd400d1,0x00000000,0x00000000}},	//   арь_, ﻟﻼﺭﻧ, --, --, 
   {{0x3804014b,0xb3d8134e,0x00000000,0x00000000}},	//   _готҳ, _बेदख, --, --, 
   {{0x59000003,0x9f4c004a,0xd1bc0092,0xa6641bc6}},	//   _མཚོས_, _âgé_, _ስሞች_, _خطرو, 
   {{0xadf01e61,0x7bcc07de,0x8c480205,0xd6cc007b}},	//   _आँगन_, zzau, _kiğı, _تقل_, 
   {{0x55b8011a,0xa3d807af,0x00000000,0x00000000}},	//   _שמאו, _डेथ_, --, --, 
   {{0x7ae40208,0x26100027,0xf2c401c6,0xa2e400db}},	//   ynht, धेरी_, рсөн, _кодд, 
   {{0x93c82832,0x8af000ac,0x3ef80276,0x92f0007b}},	//   _جامہ_, lsəf, унгэ_, _وأوض, 
   {{0x2d980561,0x9c440a42,0x91e0009b,0x00000000}},	//   _crpe_, ихал, _моље, --, 
   {{0x50d49afa,0x59000135,0x7bccce43,0x25dc007d}},	//   _وزير, _མཚེས_, tzau, _कइनी_, 
   {{0x2d982796,0x2bb80034,0x7e740175,0x0ca8084c}},	// [11210] _erpe_, jącą_, pfzp, штри_, 
   {{0x7bccce44,0x1cb80327,0x8cd801ad,0x2bb80210}},	//   rzau, མིང_, नोबो, dącą_, 
   {{0x9c100241,0x6b9400e4,0x7ae401ab,0xca4801b9}},	//   _kọka, avyg, rnht, شلنه_, 
   {{0xf77074bb,0x9c10063f,0xb7bc00a2,0x38c81079}},	//   كات_, _jọka, _agţa, دائی_, 
   {{0x2bdc0dc5,0x9c100241,0x17680139,0x00000000}},	//   _नेपा, _mọka, треп_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe57412c4,0xefc80092,0x00000000,0x00000000}},	//   ёзы_, _አጋዥ_, --, --, 
   {{0xd58403e6,0xf8b80208,0x78ac01f4,0x00000000}},	//   _چێته_, _giũa_, öavu, --, 
   {{0x05740e60,0xf48401d3,0xd5840133,0x15fc0037}},	//   _ژاند, _گائی, _نێته_, _ऊँपर_, 
   {{0x386c0841,0x25dc1025,0x2bdc0037,0x85b800f2}},	//   _kcer_, _केपी_, _नेना, _پالس_, 
   {{0x297805e1,0xf484a79f,0x66c4032e,0xb6400046}},	//   נטרא, _دائی, _iðka, _ﺍﻟ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdd8c0f1c,0x00000000,0x00000000,0x00000000}},	//   کوف_, --, --, --, 
   {{0x9c100241,0xd1b80137,0xee380022,0x2bb80210}},	//   _fọka, _جاشا_, _ҩни_, zącą_, 
   {{0x6da40046,0xa968ce45,0xed58039b,0x1704031c}},	//   _ғима, ғида_, коҳ_, _ཆེའམ_, 
   {{0x1d046145,0xac08009d,0x00000000,0x00000000}},	// [11220] сети_, унаа_, --, --, 
   {{0xd1c80020,0x2d981505,0x61ac00cc,0x00000000}},	//   _አራት_, _trpe_, _ছেটআ, --, 
   {{0x26c006c8,0x2f1401d9,0xf8b807f7,0x00000000}},	//   _ēko_, _پِھر, _आवशय, --, 
   {{0xebe4010b,0x00000000,0x00000000,0x00000000}},	//   _гомп, --, --, --, 
   {{0x3164002f,0x66c408a5,0x386c01ef,0x2a34030d}},	//   hulz_, _aðka, _dcer_, _гэбр, 
   {{0x8884168d,0x386c0a2e,0x81c000fe,0x2bbc00dc}},	//   _ژیان, _ecer_, ূপত_, _vācā_, 
   {{0x5e54010f,0x00000000,0x00000000,0x00000000}},	//   ציקע_, --, --, --, 
   {{0x833402ff,0x9550007b,0xd12c030d,0x00000000}},	//   оних, أخوا, _эхi_, --, 
   {{0x2bdc01f9,0x106c00d1,0xd8b8011a,0x00000000}},	//   _नेमा, _ﺳﯚﺯﯨ, _עצמכ, --, 
   {{0x415477c1,0x9c1001e1,0x00000000,0x00000000}},	//   овос, _sọka, --, --, 
   {{0x8af000ac,0x5af80115,0x00000000,0x00000000}},	//   msəd, רליצ, --, --, 
   {{0xef240790,0x20c8027d,0x8af003b9,0x00000000}},	//   ğüne_, ابدي_, lsəd, --, 
   {{0x9e4800a8,0x6d5801a2,0xef24ac4c,0x00000000}},	//   ţămâ, átan, şüne_, --, 
   {{0x20541823,0xef300022,0x00000000,0x00000000}},	//   штүр, ьҭьы, --, --, 
   {{0x6d580bb8,0x9c100241,0x00000000,0x00000000}},	//   štan, _tọka, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe0dc0268,0x5c0417a1,0x9a24069b,0x3b540395}},	// [11230] miò_, сява, معان, юкар, 
   {{0xe0dc19f5,0x3178033f,0x00000000,0x00000000}},	//   liò_, ńsze_, --, --, 
   {{0x386cce46,0xa3d807f7,0x1834007b,0x00000000}},	//   _pcer_, _डेस_, مرشح, --, 
   {{0x6b8c0598,0x7798ce47,0xa90801a9,0xe0dcce48}},	//   ängä, икер_, stоn, niò_, 
   {{0xdbe00077,0x3ce8010a,0xd5ac00e5,0xf624ce49}},	//   _téño, mnav_, کہا_, одло, 
   {{0x3ce87af6,0xe0dc011c,0xa3bc6c95,0x8d742304}},	//   lnav_, hiò_, ीनन_, _بایا, 
   {{0xf8a800f2,0xd83800c0,0x00000000,0x00000000}},	//   _پگاه_, _бэз_, --, --, 
   {{0x3ce8010a,0x81c0009e,0xefe80092,0xa01801f4}},	//   nnav_, ূপা_, _ሙያዊ_, teöl, 
   {{0xe0dcce4a,0xe3b40a89,0x00000000,0x00000000}},	//   diò_, жбы_, --, --, 
   {{0xe8c40135,0x3ce80254,0xc32c00db,0x00000000}},	//   _གཞོག, hnav_, دەو_, --, 
   {{0xc6a400ee,0xb0e858e5,0xc4c8009d,0x00000000}},	//   _эрти, идоз_, рлөж_, --, 
   {{0xafa0136b,0x9c1001f2,0xe0dc2b1d,0x057401ec}},	//   дқиқ, _tọha, giò_, _ءالد, 
   {{0x3ce80175,0x00000000,0x00000000,0x00000000}},	//   dnav_, --, --, --, 
   {{0x31641151,0xb144004e,0xada400c7,0x00000000}},	//   pulz_, _днкл, оагл, --, 
   {{0x3ce80175,0x7e600162,0x6cd801a9,0x3e740248}},	//   fnav_, ólpa, афас_, _ẹtì_, 
   {{0x0ce811ba,0xdca007d6,0xe0dcce4b,0x3ce801bf}},	//   পত্ত, маси, ciò_, gnav_, 
   {{0x09b400cd,0x00000000,0x00000000,0x00000000}},	// [11240] ून्य, --, --, --, 
   {{0x3ce80165,0x8af003b9,0x2bdc01f9,0x00000000}},	//   anav_, hrəv, _नेणा, --, 
   {{0x3ce80354,0xe8f805f5,0xe9d80640,0x00000000}},	//   bnav_, алж_, јке_, --, 
   {{0xe8f8ce4c,0xf8b80055,0x3ce80334,0xa178008f}},	//   шле_, _diũo_, cnav_, יטעט, 
   {{0xbc700150,0xdb0400d7,0x00000000,0x00000000}},	//   _سۇلب, žmár, --, --, 
   {{0xe0dcce4d,0xd61400f1,0x00000000,0x00000000}},	//   ziò_, ښتيا_, --, --, 
   {{0x2bdc060c,0x00000000,0x00000000,0x00000000}},	//   _नेता, --, --, --, 
   {{0x18641a4f,0x8af00213,0xe738030d,0x393401c4}},	//   _маси_, ssəd, _веа_, _хэрс, 
   {{0xe0dc0bdf,0xa6e4030d,0x82d80116,0x78000117}},	//   viò_, _джал, йдис_, _пӯша, 
   {{0x2904ce4e,0x8af003be,0xd3740006,0x7d08031c}},	//   lloa_, qsəd, ічы_, ċesi, 
   {{0x2904ce4f,0xd2540eed,0x6d5800e5,0xae4c01ec}},	//   oloa_, ццы_, átal, _ﺑﯘﺯﯞ_, 
   {{0x009401c0,0x6b080327,0x3ce80175,0xa3440006}},	//   чимэ, _ཀེའོ_, xnav_, _дэкл, 
   {{0x2904096b,0x6d588b8c,0xd36c21ec,0x3ce8a738}},	//   iloa_, štal, _لهن_, vnav_, 
   {{0xdef8ce50,0xcf243306,0x290401e0,0xe0dc08e7}},	//   рым_, ِرِي, hloa_, siò_, 
   {{0xc8bc375c,0x3ce8010a,0x290401c6,0x853c0006}},	//   ्घाट, tnav_, kloa_, _drėg, 
   {{0x5ce40212,0xa01801e3,0x3ea400e5,0x00000000}},	//   іюва, neök, űlt_, --, 
   {{0x3ce8ce51,0x98a000ef,0xc83c01e1,0x00000000}},	// [11250] rnav_, _nujā_, _èèyì, --, 
   {{0x2904ce52,0x3ce8ce53,0xe8c4031c,0x501c011a}},	//   eloa_, snav_, _གཞུག, _דוחו, 
   {{0x3ce80354,0xdc3c0232,0x19a80228,0x66c401a8}},	//   pnav_, líčk, штап_, _aðko, 
   {{0xf8b020d4,0x00000000,0x00000000,0x00000000}},	//   رکز_, --, --, --, 
   {{0xf744ce54,0xb6a41638,0xdc3c04bf,0xe8500efc}},	//   чело, зилл, níčk, رنود, 
   {{0x2904ce55,0x0a6800d8,0x690800a2,0x00000000}},	//   aloa_, _мрси_, lýel, --, 
   {{0x98640150,0x98a80114,0x00000000,0x00000000}},	//   _ولسە_, _књаз_, --, --, 
   {{0x213c010a,0xd3a00116,0x383400c7,0x24502d40}},	//   dpth_, длиқ, _хнар, ىنىس, 
   {{0xdc3c0122,0x00000000,0x00000000,0x00000000}},	//   jíčk, --, --, --, 
   {{0x32c800d2,0xdc3c0118,0xb5940d1d,0x00000000}},	//   _búya_, díčk, _низш, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe16000d1,0x98a000b8,0x6d5876cf,0xdc3c013a}},	//   رگىي, _yujā_, átam, fíčk, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d5817a3,0x046401ee,0x00000000,0x00000000}},	//   štam, _етәм, --, --, 
   {{0x2d9c03c6,0x00000000,0x00000000,0x00000000}},	//   íte_, --, --, --, 
   {{0xdc3c02fb,0x8af00213,0x98740166,0x00000000}},	//   bíčk, hrət, _oçı_, --, 
   {{0xab646345,0x98740724,0x29040421,0xafe40798}},	// [11260] явал, _nçı_, vloa_, _хопл, 
   {{0x98a000b8,0x9f98011a,0xed5801c4,0x00000000}},	//   _rujā_, _פסיפ, _лоо_, --, 
   {{0x29040032,0xdeb80302,0x9874ce56,0x8af00213}},	//   tloa_, _המיל, _açı_, drət, 
   {{0x290406c8,0x57c00131,0x50cc00cd,0xa90803b9}},	//   uloa_, ﯩﻠﯩﺮ, ासिष, ptоm, 
   {{0x2904005a,0x8af00213,0x00000000,0x00000000}},	//   rloa_, frət, --, --, 
   {{0x290400c5,0x00000000,0x00000000,0x00000000}},	//   sloa_, --, --, --, 
   {{0x38a4063f,0xdc3c0306,0xeaf8482a,0x00000000}},	//   ịram_, zíčk, ्तीत_, --, 
   {{0xe8c40003,0x6f00007b,0x63680063,0x00000000}},	//   _གཞིག, _íocf, брог_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x68e0ce57,0xdc3c02fb,0x8af003e3,0xa3d8012d}},	//   liod, víčk, mrəs, _डेः_, 
   {{0x6d580bb8,0x20d800dc,0xe00c012d,0x1a9800df}},	//   štaj, मोऽध, _सरहद_, זייע, 
   {{0xeaf8c881,0x68e0ce58,0xdc3c02fb,0x00000000}},	//   ्तुत_, niod, tíčk, --, 
   {{0x65681aa1,0x98a405ce,0x24080276,0xa01801d3}},	//   lufh, šići_, _унди_, ldöz, 
   {{0xdde8007b,0x68e003cb,0x3178012d,0x00000000}},	//   مرأه_, hiod, ńsza_, --, 
   {{0x8d840440,0x853c0153,0xdc3c022a,0x68e0022e}},	//   нутд, _urėd, síčk, kiod, 
   {{0x2bdc29da,0x1cb800c6,0x6b8002e3,0x27f0033f}},	//   _नेहा, حاسب_, _ọgag, żyny_, 
   {{0xbab80cb9,0x9a8407b5,0x25dc012c,0x8af00213}},	// [11270] огах_, зуел, _केसी_, yrət, 
   {{0x656806d6,0x19a81de6,0x8af003e3,0x88c40055}},	//   kufh, йтеп_, drəs, _āśav, 
   {{0xc17802d5,0x7ae8004b,0x9964ce59,0x68e0015d}},	//   ntė_, موړې_, ятал, fiod, 
   {{0xa3bc09d9,0xc17802d5,0x26dc030a,0x977029db}},	//   ीना_, itė_, _amto_, еткә, 
   {{0x5c040323,0x36d40266,0x00000000,0x00000000}},	//   _хяна, модр, --, --, 
   {{0x25dc038e,0x3cec0960,0xc1780153,0x70b800bc}},	//   _केही_, čevu_, ktė_, _उक्ल, 
   {{0x68e0ce5a,0x00000000,0x00000000,0x00000000}},	//   biod, --, --, --, 
   {{0x68e000a8,0x394006f2,0x889400d1,0x8af00213}},	//   ciod, mphs_, _писх, srət, 
   {{0xc5b405f5,0xc1780006,0x13a41079,0xe4d40137}},	//   дрөө, etė_, سندی_, بويت_, 
   {{0x59280003,0x78a800d0,0xa920032e,0x00000000}},	//   _སྤོས_, _hnev, _óþri, --, 
   {{0x78a813eb,0x00000000,0x00000000,0x00000000}},	//   _knev, --, --, --, 
   {{0xafe410f5,0x15e07039,0xa018007c,0x3cf8012d}},	//   домл, _केयर_, kföd, ूतों_, 
   {{0xd40811dc,0x842410a8,0x853c0153,0xa854011a}},	//   _اتام_, _كىمن, _grėb, וירה_, 
   {{0x68e0009d,0xa01801e3,0x00000000,0x00000000}},	//   ziod, dföd, --, --, 
   {{0x78a801f5,0x00000000,0x00000000,0x00000000}},	//   _onev, --, --, --, 
   {{0x68e00005,0x48b803d4,0x7c840114,0x00000000}},	//   xiod, _আগ্ৰ, нуђе, --, 
   {{0x68e0003a,0x00000000,0x00000000,0x00000000}},	// [11280] viod, --, --, --, 
   {{0x78a8ce5b,0xfbd001d3,0x68e066fe,0x25dc00c5}},	//   _anev, چتے_, wiod, _कइली_, 
   {{0x68e0ce5c,0xfbd000dd,0x387c015d,0x00000000}},	//   tiod, نتے_, ffwr_, --, 
   {{0x58800aec,0x48dc03d4,0xe78411eb,0xe8080107}},	//   выша, যক্ৰ, дуко, онед_, 
   {{0xd5ac2b09,0x7d080327,0x03e800eb,0x00000000}},	//   یفه_, ċest, _পর্ণ, --, 
   {{0x78a8ce5d,0x68e0ce5e,0xc1780006,0x00000000}},	//   _enev, siod, ytė_, --, 
   {{0xa6c004c5,0x68e0ce5f,0x853c0064,0x0a1c05ac}},	//   ্চলট, piod, _srėb, _প্ৰৱ_, 
   {{0x78a83341,0x6568031c,0x5c5800df,0x00000000}},	//   _gnev, rufh, ֿדיק, --, 
   {{0x22880063,0x84c4013d,0x25dc07af,0x00000000}},	//   ољно_, _җәйд, _केरी_, --, 
   {{0x78a802fb,0x2fc4010b,0x00000000,0x00000000}},	//   _znev, _ýogy_, --, --, 
   {{0xa508288a,0x224c03e0,0x00000000,0x00000000}},	//   _дежа_, _vefk_, --, --, 
   {{0xc17802d5,0x23280107,0x00000000,0x00000000}},	//   rtė_, _доди_, --, --, 
   {{0xc17802d5,0xe298b27b,0x2d9c005c,0x09c400cc}},	//   stė_, _мад_, æten_, _এইফা, 
   {{0x3940003e,0x63a0ce60,0x670c3507,0x3d9400f3}},	//   yphs_, _iron, ितिक_, нигр, 
   {{0x63a0ce61,0x27f8068f,0xdcb802bf,0x12f8011a}},	//   _hron, ępny_, оща_, _והגב, 
   {{0x6298ce62,0x5180ce63,0xfe780118,0x9594011a}},	//   ldto, _руша, řů_, וכלו_, 
   {{0x63a0ce64,0x3f9c00f2,0x7b14ce65,0x62980100}},	// [11290] _jron, _éwu_, едах, odto, 
   {{0x63a0ce66,0x7f4c0135,0x3f4c00e2,0x09e000cc}},	//   _mron, _iwaq, mžu_, _ভড়া, 
   {{0x25dc05ba,0x78a8151c,0x483c063f,0x2d9c01e6}},	//   _केली_, _pnev, _ịwụ_, åtet_, 
   {{0xd1d4044e,0x7d08038f,0x7f4c0912,0x6298010a}},	//   _ርክብ_, ċess, _kwaq, hdto, 
   {{0x7f4c0135,0x8af00213,0x63a001e1,0x3f4cb9bd}},	//   _jwaq, msən, _nron, nžu_, 
   {{0x7f4c0135,0x8b880137,0x25f800c5,0x8af003e3}},	//   _mwaq, _تەكە_, _ऊँखी_, lsən, 
   {{0x7f4c0944,0x7ae4003e,0x6298010a,0x32c80241}},	//   _lwaq, miht, ddto, _súyo_, 
   {{0x7f4c0944,0x7ae4ce67,0x6298ce68,0x6d585207}},	//   _owaq, liht, edto, átai, 
   {{0x63a0ce69,0x2f14037e,0x88a403e6,0x629801f5}},	//   _cron, læge_, _جینۆ, fdto, 
   {{0x3f4cce6a,0x629801f5,0x850401b9,0x6d584a97}},	//   džu_, gdto, _یولن, štai, 
   {{0x0574021a,0x7f4cce6b,0x46ac13f7,0x3f4c00e2}},	//   _لاند, _awaq, चारह, ežu_, 
   {{0x0ef803f3,0x6298ce6c,0x7ae4014f,0xa3d80562}},	//   ंक्स_, adto, hiht, _डेक_, 
   {{0x63a0ce6d,0x7ae40037,0xd7ec01ec,0x00000000}},	//   _gron, kiht, луi_, --, 
   {{0x6d4000f3,0x00000000,0x00000000,0x00000000}},	//   _čoab, --, --, --, 
   {{0x7f4c0b6f,0x09c40154,0x8af006be,0xa19000f3}},	//   _ewaq, _এইভা, fsən, _бајч, 
   {{0xeaf800af,0x63a002d0,0x00000000,0x00000000}},	//   ्त्त_, _yron, --, --, 
   {{0x63a0ce6e,0x00000000,0x00000000,0x00000000}},	// [112a0] _xron, --, --, --, 
   {{0x09c402a6,0x7c900092,0x634c0051,0xdb201427}},	//   _এইবা, ጀምረው_, ớngg, órða, 
   {{0xa848ce6f,0x00000000,0x00000000,0x00000000}},	//   كلام_, --, --, --, 
   {{0xcc14010b,0xab28013e,0x00000000,0x00000000}},	//   _ачгө, _нома_, --, --, 
   {{0x66e4ce70,0x6298045f,0x00000000,0x00000000}},	//   нода, ydto, --, --, 
   {{0xa3d800c5,0x63a0036e,0x00000000,0x00000000}},	//   _डेग_, _rron, --, --, 
   {{0x63a0016b,0x88841a4b,0x80e0000d,0x00000000}},	//   _sron, _لیان, _पगलइ, --, 
   {{0x63a06e16,0x9ba401d9,0x31d400fe,0x00000000}},	//   _pron, _تگہِ_, হপাশ, --, 
   {{0xe3b0ce71,0xa6849120,0x604002e3,0x2ab400b5}},	//   ارع_, _плад, ọmkw, _sæby_, 
   {{0x63a0417e,0x3f4c0010,0x6298508f,0x00000000}},	//   _vron, vžu_, udto, --, 
   {{0x63a00375,0x09c402f5,0xd0480ae5,0x64a48ed1}},	//   _wron, _এইডা, ﯩﻨﯩﭗ_, _пажа, 
   {{0x63a0431d,0xa49401e4,0xdef8001f,0x367000db}},	//   _tron, _okϲi, ሊዮን_, _مۇۇز, 
   {{0x63a0ce72,0x2408006c,0x7f4c00fb,0xd8d80375}},	//   _uron, _энди_, _qwaq, לקטר, 
   {{0xb3e800c6,0x3f4cce73,0xdce40427,0x4c940131}},	//   _تعمل_, ržu_, rujč, һисс, 
   {{0x7ae40219,0x257800e8,0x00000000,0x00000000}},	//   viht, nël_, --, --, 
   {{0x2f14037e,0x7f4c003d,0x4c940ce1,0x9cc850c0}},	//   væge_, _twaq, лисс, чыга_, 
   {{0x3a74ce74,0x7f4c0b6f,0x2d9cce75,0x8af000ac}},	// [112b0] клар, _uwaq, åter_, rsən, 
   {{0x25780023,0xde440101,0x00000000,0x00000000}},	//   kël_, _سیرو_, --, --, 
   {{0x7ae4ce76,0x257800e8,0x8af003b9,0x00000000}},	//   riht, jël_, msəl, --, 
   {{0x3f880093,0x7ae46775,0xd730009d,0x8af003e3}},	//   _kpau_, siht, гддө, lsəl, 
   {{0x7d0cce77,0x257805e4,0x7c3c02d0,0x7ae40254}},	//   mlas, eël_, _ifsr, piht, 
   {{0x7d0cce78,0x25780de2,0x799402d0,0x658803b9}},	//   llas, fël_, _tszw, _məhf, 
   {{0x6d581326,0x2578ce79,0x8aa40801,0xaa4000d1}},	//   štav, gël_, _сряд, _ئۆمى, 
   {{0x7d0cce7a,0x3f88166a,0xa3bc0a94,0xb38401d5}},	//   nlas, _opau_, ीनं_, влил, 
   {{0x3f880457,0x8af000ac,0x5928025c,0x7d0c75ee}},	//   _npau_, ksəl, _སྤགས_, ilas, 
   {{0xc3c8399c,0x2578ce7b,0x3f840356,0x39a000c0}},	//   عظيم_, bël_, ălul_, _kės_, 
   {{0x3de003f4,0x3f88c1c2,0x46f000db,0x00000000}},	//   _মুসল, _apau_, _دۋور, --, 
   {{0x34940b3e,0x7d0cce7c,0x720400f1,0x39a00064}},	//   _јадр, jlas, _یوشم, _mės_, 
   {{0xe28cce7d,0x7d0cce7e,0x2908013b,0xe0d402e8}},	//   _ка_, dlas, _ɔba_, твя_, 
   {{0x7d0cce7f,0xa3d82cce,0x00000000,0x00000000}},	//   elas, _डेट_, --, --, 
   {{0x3f880418,0x39a00024,0x8234007b,0xc0c40023}},	//   _epau_, _nės_, _إرها, ጸሎም_, 
   {{0xa0a01ee3,0xbef8019b,0xd5ac01ec,0x00000000}},	//   _ваъд, dにus, рсi_, --, 
   {{0x1d04ce80,0x7c3c0175,0x15e0298e,0x7c300118}},	// [112c0] тети_, _dfsr, _केसर_, _škrá, 
   {{0x7d0c00af,0x7c3c02d0,0xde600014,0x39a000c0}},	//   alas, _efsr, _پۯٲٹ, _bės_, 
   {{0x59280003,0x257800e8,0x00000000,0x00000000}},	//   _སྤངས_, xël_, --, --, 
   {{0x2d3c00b4,0x8af00213,0x39a00064,0x25780200}},	//   _ọgwụ_, msəm, _dės_, vël_, 
   {{0xd7ec0491,0xb8645220,0xd7f4ce81,0xae040046}},	//   يكم_, طانو, куш_, _سوڭى, 
   {{0x6d5801a2,0x257800e8,0x00000000,0x00000000}},	//   štau, tël_, --, --, 
   {{0x1ae06833,0x1a2401a9,0x8c2400eb,0x00000000}},	//   _торм, _ажри_, যুশন_, --, 
   {{0x25781bce,0xa49001b9,0xd4c00108,0x00000000}},	//   rël_, شیتت, исып, --, 
   {{0x613c00da,0x25781bce,0x00000000,0x00000000}},	//   _mīle, sël_, --, --, 
   {{0x7d0cce82,0x257800e8,0xd2900124,0xa6a8ce83}},	//   zlas, pël_, арџь, _تارق_, 
   {{0x7d0c006c,0xd48cce84,0x3f880ffb,0x658803b9}},	//   ylas, _кр_, _spau_, _səhf, 
   {{0x613c0055,0x00000000,0x00000000,0x00000000}},	//   _nīle, --, --, --, 
   {{0x248403f9,0x6d5c713c,0xe8c40327,0x42a400fb}},	//   _ibom_, _avpa, _གཞནག, _буйғ, 
   {{0x33e80597,0xe3b00451,0xd24c00db,0x00000000}},	//   _яєєм_, _مرڻ_, _ۇنۇ_, --, 
   {{0x7d0cce85,0x528000cf,0xd1b41e24,0x00000000}},	//   tlas, _ئلىك, _لايا_, --, 
   {{0x656800c6,0x8af000ac,0x7d0cce86,0x67e401a9}},	//   irfh, ssəl, ulas, _mаjb, 
   {{0x7d0cce87,0x5c0406bb,0xdb204f90,0x6d5c0166}},	// [112d0] rlas, тява, لوری, _evpa, 
   {{0x9a2410e0,0x39a00064,0xba540c75,0x19e800ae}},	//   نعان, _pės_, اناع, وراً_, 
   {{0x7d0c2b6f,0x6f000597,0x24840419,0x29a400c7}},	//   plas, _íoca, _obom_, лыцҳ, 
   {{0x7d0c006c,0x658800ac,0x9b4003e6,0x39a000c0}},	//   qlas, _məhd, _نۆرو, _vės_, 
   {{0x656801c7,0x00000000,0x00000000,0x00000000}},	//   erfh, --, --, --, 
   {{0x24840134,0x3ce8030a,0xe7a400d1,0xab6000d1}},	//   _abom_, liav_, دۇكى_, _دۇكى, 
   {{0xceb4159d,0x24840798,0x15e00b72,0x00000000}},	//   ייס_, _bbom_, _केशर_, --, 
   {{0xd8746884,0x8a189b4e,0x93600022,0x7f5c02d0}},	//   _جاسب, _росс_, аниҵ, kssq, 
   {{0x1b20001f,0xd5bc00e2,0x00000000,0x00000000}},	//   ታወቂያ, _šāds_, --, --, 
   {{0x3ce80190,0x2484013f,0x7f5c02d0,0x7294299f}},	//   hiav_, _ebom_, dssq, уших, 
   {{0x80dc045e,0x31241c13,0x658800ac,0x00000000}},	//   মচন্, лдог, _cəhd, --, 
   {{0xa5d8010f,0x00000000,0x00000000,0x00000000}},	//   _אַדי, --, --, --, 
   {{0xe3acce88,0x8774001f,0x6d5c0158,0x69080432}},	//   _уб_, _የውሳኔ_, _svpa, mýet, 
   {{0x7c6401d5,0x69d80139,0x6908010e,0x00000000}},	//   یاقل, _üteg, lýet, --, 
   {{0x613c0171,0xd36c01f7,0x00000000,0x00000000}},	//   _pīle, _اهڙ_, --, --, 
   {{0x1d04ce89,0x00000000,0x00000000,0x00000000}},	//   геси_, --, --, --, 
   {{0x6a8401c6,0xa908022e,0xa018007c,0x5ed00154}},	// [112e0] ллаа, ktоr, lfön, _সদরে, 
   {{0x6d58172e,0x63a4ce8a,0x8ca4033f,0x3a4421f3}},	//   átas, åkni, _चोरो, имуҳ, 
   {{0x15e001ad,0x9e780a7c,0x00000000,0x00000000}},	//   _केलर_, _אניפ, --, --, 
   {{0x1cb02fb5,0x00000000,0x00000000,0x00000000}},	//   _དོར_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa6a8007b,0x00000000,0x00000000,0x00000000}},	//   عاشق_, --, --, --, 
   {{0x45d431df,0x67c800ef,0x00000000,0x00000000}},	//   ройс, _sējā, --, --, 
   {{0x8af00213,0x656800ae,0x5fcc00bc,0xa6e003b2}},	//   ksək, rrfh, सैँल, íðbj, 
   {{0xe644ce8b,0x6674326c,0x186402e8,0x00000000}},	//   _безп, _مدار, _щати_, --, 
   {{0x2d98009d,0x5b78008f,0xa01802d2,0x00000000}},	//   _ospe_, עריא, ffön, --, 
   {{0xe5780212,0x5ab4010f,0x00000000,0x00000000}},	//   _їзд_, אליע_, --, --, 
   {{0x248401e2,0x40e401e0,0x658803e3,0x67c80171}},	//   _ubom_, рсоғ, _vəhd, _tējā, 
   {{0x2d98ce8c,0xef1400c5,0xa2e4b8d3,0x6b940210}},	//   _aspe_, _दीहऽ_, _йодд, jwyg, 
   {{0x539804ae,0x65880213,0x00000000,0x00000000}},	//   _ניוו, _təhd, --, --, 
   {{0x2904ce8d,0x5634008f,0xfce8007b,0x8af006be}},	//   kooa_, ראלע_, نفسي_, msəh, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2d98ce8e,0xba541677,0x6d58ce8f,0x7f940408}},	// [112f0] _espe_, ивај, átar, _тапх, 
   {{0xcb6836c1,0x3ce80218,0x658800ac,0xda640592}},	//   امله_, siav_, _məhb, طائي, 
   {{0x690809a5,0x38340408,0x6d58ce90,0x853c00c0}},	//   yýet, анер, štar, _brėm, 
   {{0xe7045bb8,0x5c0400a7,0xad247640,0x00000000}},	//   یسوی, _бяга, _پرپو, --, 
   {{0xc98407d6,0x00000000,0x00000000,0x00000000}},	//   _қури, --, --, --, 
   {{0xb6a40da6,0xd6d808e2,0xe734311b,0xb5c401c6}},	//   рикл, эте_, шеш_, ийлл, 
   {{0xb924092f,0xd1d40092,0x8a1801ee,0x00000000}},	//   _نفسي, ርቡት_, _борс_, --, 
   {{0x1cb0ce91,0x3364b32d,0xa908022e,0xed780023}},	//   _དོས_, авиг, stоr, _ይግባይ_, 
   {{0x7d1c020c,0xd7f8ce92,0x00000000,0x00000000}},	//   _mhss, _чув_, --, --, 
   {{0x690800ee,0xa018553f,0x32341086,0x63a4148b}},	//   sýet, tfön, шхис, ækna, 
   {{0x2a740302,0x69080432,0x00000000,0x00000000}},	//   בעתך_, mýer, --, --, 
   {{0x25dc012c,0xa01836d5,0x62e801d9,0x6538010f}},	//   _केटी_, rfön, _یِنہ_, _סענד, 
   {{0x7fd402dd,0xe3e40451,0x59280327,0x672c00a2}},	//   бірі, _پکين_, _སྤབས_, _ünjü, 
   {{0x7d1c00a3,0x71a40024,0xc3400354,0x00000000}},	//   _ahss, _вакз, _хĕр_, --, 
   {{0x7d1c0998,0xa01800dd,0x6cc4ce93,0xddc0ce94}},	//   _bhss, lföl, айва, обри, 
   {{0x66100432,0x00000000,0x00000000,0x00000000}},	//   _ýekş, --, --, --, 
   {{0xef18ce95,0xa018632c,0xdcb4004d,0x7d1c0332}},	// [11300] _ими_, nföl, ởng_, _dhss, 
   {{0xe9d00131,0xddc40115,0x690800a2,0xa01800e5}},	//   يغا_, lajŝ, jýer, iföl, 
   {{0x290400fb,0x2d98596b,0xf0a80248,0x613c002b}},	//   tooa_, _uspe_, _gbàá_, _kīla, 
   {{0x270c1886,0x7640037e,0x658803e3,0xad2400d1}},	//   ित्र_, _afly, _ləhc, _خىجى, 
   {{0xbc180046,0x613c00e2,0x25dca1fa,0x853c0064}},	//   _бірі_, _mīla, _केजी_, _grėj, 
   {{0x65880213,0xa01877b6,0x613c002b,0xae1800bc}},	//   _rəhb, dföl, _līla, _धरान_, 
   {{0xd9780cef,0x2904009f,0x3f840356,0x853c00c0}},	//   _иртә_, pooa_, ălui_, _trėm, 
   {{0xf8b40116,0x95c400f0,0x613c00dc,0xd9dc0154}},	//   _гөш_, руша_, _nīla, _বুকম, 
   {{0xe73800f0,0x7640015d,0x658803b9,0x69dc002f}},	//   _рез_, _ffly, _qəhb, lzpe, 
   {{0xdce4033f,0x168403e6,0x00000000,0x00000000}},	//   mują, _نامێ, --, --, 
   {{0x4034054a,0xdce4033f,0x69dc0036,0x00000000}},	//   йенс, lują, nzpe, --, 
   {{0xd464ce96,0x69dc01c0,0xa3e81fbe,0x00000000}},	//   _вице_, izpe, _идеа_, --, 
   {{0x6440ce97,0xdce40034,0xc0c40032,0x3f8c0129}},	//   _ifoi, nują, _ғәни, ïeu_, 
   {{0xdd9001e0,0xb4241291,0x00000000,0x00000000}},	//   ҙағы, _طعنو, --, --, 
   {{0x7d1c014b,0x9ce42386,0x00000000,0x00000000}},	//   _phss, ацал, --, --, 
   {{0xdce4068f,0x8af00213,0xb24401af,0x00000000}},	//   kują, mrəy, _кмәһ, --, 
   {{0x69dc005a,0x6d5816a3,0x853c0064,0xabb4035b}},	// [11310] ezpe, štap, _brėk, батә, 
   {{0xdce4ce98,0x0ab40798,0x00000000,0x00000000}},	//   ılıg, обуџ, --, --, 
   {{0x64401140,0x853c0024,0x3ea00356,0xb1840fac}},	//   _ofoi, _drėk, _iaht_, mmåå, 
   {{0xcd344e5c,0xbeb80306,0x28c003ce,0x00000000}},	//   _گریب, šíče, वॉलि, --, 
   {{0x366847ba,0xdce4033f,0x628802d0,0x3ea0adac}},	//   гало_, gują, _obfo, _kaht_, 
   {{0x6440ce99,0x3ea0ce9a,0x00000000,0x00000000}},	//   _afoi, _jaht_, --, --, 
   {{0x3ea000c5,0x7bccb743,0x49c80064,0x28a800cf}},	//   _maht_, lyau, _клён_, _өстү_, 
   {{0x6288ce9b,0xa01886cf,0x3ea04199,0xdce4012d}},	//   _abfo, tföl, _laht_, bują, 
   {{0x4a240d46,0x7bccce9c,0xdce4068f,0xe9a40014}},	//   _འཛོལ_, nyau, cują, _پۯۆن_, 
   {{0x7bcc0d04,0x644005da,0xa018ce9d,0x74540451}},	//   iyau, _efoi, rföl, _ڇپائ, 
   {{0x64400042,0x11f000cf,0x00000000,0x00000000}},	//   _ffoi, تتةگ, --, --, 
   {{0x90c82d2e,0xa01801e6,0x1fa40116,0x7bcc01f4}},	//   рғиз_, pföl, әкри_, kyau, 
   {{0x6f1c0077,0x98a40153,0x658803b9,0x613c00de}},	//   _phpc, ūnė_, _təhc, _vīla, 
   {{0x7bcc004c,0xeb9800d1,0x835400e5,0x00000000}},	//   dyau, һиб_, _بھٹا, --, 
   {{0xdce40034,0x6da40a8f,0x3ea00036,0x00000000}},	//   zują, щива, _daht_, --, 
   {{0xeb98ce9e,0x2fd812e3,0x69dc0219,0xa3bc01f9}},	//   либ_, _موعد_, vzpe, ीनच_, 
   {{0x7bcc0589,0xea8801c6,0x23d800dc,0x658803e3}},	// [11320] gyau, лбал_, मैपद, _məha, 
   {{0xe738016c,0x69dc005a,0x613c0171,0x00000000}},	//   ҳед_, tzpe, _mīln, --, 
   {{0x27200016,0xfd980b8d,0xdce40034,0x00000000}},	//   _hưng_, _көтә_, wują, --, 
   {{0x7bcc0399,0xe8f8ce9f,0x658800ac,0xdce4033f}},	//   byau, ыле_, _nəha, tują, 
   {{0x18642083,0x3bb800f5,0xa6c800b1,0x69dcb750}},	//   сачи_, _курю_, ллда_, szpe, 
   {{0xdce40034,0x27200051,0x00000000,0x00000000}},	//   rują, _mưng_, --, --, 
   {{0x27200016,0xdce40034,0x69c801b8,0x65880213}},	//   _lưng_, sują, äfed, _bəha, 
   {{0xd494151e,0xdce40034,0x62880175,0x658803e3}},	//   брь_, pują, _sbfo, _cəha, 
   {{0x82d8cea0,0x00000000,0x00000000,0x00000000}},	//   идис_, --, --, --, 
   {{0x7b18026c,0x15e000c5,0x2ca00064,0xdb98010f}},	//   hìun, _केकर_, _lakd_, נסיר, 
   {{0x7bcc0007,0x3ea0037e,0xd3d40214,0xe4a406ed}},	//   zyau, _raht_, لبیا_, _грло, 
   {{0xa524016c,0x2720004d,0x10740212,0x644001f4}},	//   _умед, _bưng_, плюю, _ufoi, 
   {{0x2720001e,0x3ea0007f,0x00000000,0x00000000}},	//   _cưng_, _paht_, --, --, 
   {{0x8c00000e,0x272001fb,0xa3e800c7,0x81d40354}},	//   ্ধান_, _dưng_, _идҵа_, _молх, 
   {{0xca7c022e,0xa1f002dd,0xd1340022,0xe60c02dd}},	//   _birо, _رۋحت, _лхы_, мдi_, 
   {{0x425400aa,0xed4c1893,0x3b54011c,0x00000000}},	//   _انګر, کھی_, жкар, --, 
   {{0x4a240ed9,0x3ea0cea1,0x3de0009e,0x00000000}},	// [11330] _འཛུལ_, _taht_, _মুখল, --, 
   {{0x3d9400c7,0xb4e401ad,0x1014724c,0xb4d4166d}},	//   _диор, _नष्_, _عبيد, _हत्_, 
   {{0x7c342377,0x613c00de,0xbf040073,0x00000000}},	//   _менх, _mīlo, ळवीन_, --, 
   {{0xb7d40137,0x81cc0183,0xfbd000ec,0xb81400d8}},	//   يقاب, _ৰখা_, _ٺڪر_, одеј, 
   {{0x6c7800c8,0x272001fb,0x2b6401f0,0x00000000}},	//   _דארפ, _xưng_, _мэрҳ, --, 
   {{0x35c8cea2,0x613c002b,0x65880213,0x00000000}},	//   игло_, _nīlo, _səha, --, 
   {{0x225c0010,0xc5f800de,0xd1e80092,0x00000000}},	//   datk_, _neēd_, ህተት_, --, 
   {{0x79841cdf,0xf74800aa,0x6d584056,0xf8dc2d8f}},	//   mthw, _نلري_, âtai, _मतिय, 
   {{0x798403ac,0x76b8084c,0x658803e3,0x00000000}},	//   lthw, _клар_, _vəha, --, 
   {{0x798401af,0xc79401b9,0x67e401d5,0x2720004d}},	//   othw, _عشقب, _mаjl, _rưng_, 
   {{0x7984cea3,0x272001fb,0xaadc4f71,0x658806be}},	//   nthw, _sưng_, फोटक, _təha, 
   {{0x798400a9,0x297800c8,0x00000000,0x00000000}},	//   ithw, סטרא, --, --, 
   {{0xbf040490,0xc50c010f,0x7fd4cea4,0xb4d428d4}},	//   ळवून_, _גלאָ, пірі, हसी_, 
   {{0x601c0241,0xea2401e1,0x00000000,0x00000000}},	//   _sàmí, _ẹ̀lẹ, --, --, 
   {{0xed58621a,0x6c5800f0,0x00000000,0x00000000}},	//   роб_, ијас_, --, --, 
   {{0x2720001e,0xec480395,0x8af003e3,0x00000000}},	//   _tưng_, рзал_, hsət, --, 
   {{0xab6400d6,0x79840368,0x00000000,0x00000000}},	// [11340] ювал, ethw, --, --, 
   {{0x602002d5,0xaa141f5a,0xed5800db,0x5f9000e5}},	//   _ідэа, офеј, _коо_, _کلیئ, 
   {{0xa8480145,0xca7c022e,0x00000000,0x00000000}},	//   للام_, _tirо, --, --, 
   {{0x1cb0081f,0xac74cea5,0x274807b5,0xe7a8005b}},	//   _དོག_, _بادش, ачко_, ивел_, 
   {{0x798403ac,0x3ce4036e,0x00000000,0x00000000}},	//   athw, ëlve_, --, --, 
   {{0x6d4c057b,0x658806be,0xadfc0118,0x00000000}},	//   opba, _dəhn, _उखान_, --, 
   {{0xd5440cfc,0xe6d80c2e,0x00000000,0x00000000}},	//   опје_, _भतीज, --, --, 
   {{0x67e4022e,0xc8f8009f,0x00000000,0x00000000}},	//   _hаjm, _اورچ_, --, --, 
   {{0xb7440137,0x656400b8,0x00000000,0x00000000}},	//   _فئلو, _ākhu, --, --, 
   {{0x6f00007b,0xc174023a,0x8af00213,0x7388010b}},	//   _íoch, площ, msəs, ёрың_, 
   {{0x6ebc07d0,0x6d4c01a4,0x8af00213,0x00000000}},	//   शानु, jpba, lsəs, --, 
   {{0x40341e76,0x00000000,0x00000000,0x00000000}},	//   яемс, --, --, --, 
   {{0x22840209,0x5450cea6,0x00000000,0x00000000}},	//   _дуйг, _цвіт, --, --, 
   {{0xe7f000e1,0xf1a80451,0xf8b80208,0x7984015d}},	//   _आइना_, _گاهه_, _nhũn_, ythw, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x910400f3,0x00000000,0x00000000,0x00000000}},	//   _опје, --, --, --, 
   {{0x7984cea7,0xabb40588,0x6d4c0373,0xf000014b}},	// [11350] wthw, патә, apba, _зӯри, 
   {{0x7e98cea8,0xda48035b,0xbf100139,0x658806be}},	//   _اندر_, рчал_, _чүгә, _rəhn, 
   {{0x658800ac,0x00000000,0x00000000,0x00000000}},	//   _səhn, --, --, --, 
   {{0x7984cea9,0x23641326,0xa3d805f9,0x09c40154}},	//   rthw, _ovoj_, ठना_, _এইখা, 
   {{0x7d0cceaa,0x3de004c5,0x7984009a,0x69d800fd}},	//   moas, _মুচল, sthw, _üten, 
   {{0x7d0cceab,0x78880014,0xa018002f,0x00000000}},	//   loas, _گَرِ_, rföh, --, 
   {{0x236401e4,0x7d0c062c,0x00000000,0x00000000}},	//   _avoj_, ooas, --, --, 
   {{0x7d0cceac,0xb4d4cead,0x00000000,0x00000000}},	//   noas, हसे_, --, --, 
   {{0xf3f80276,0x7d0c054e,0xe3b40137,0xdbe006af}},	//   faţa_, ioas, збы_, _déço, 
   {{0x3de00729,0x7d0cceae,0x23640f91,0x7c900023}},	//   _মুছল, hoas, _dvoj_, ዝበሃል_, 
   {{0x7d0cceaf,0x070815f2,0xdeb80023,0x00000000}},	//   koas, _بيلي_, ኰኑን_, --, 
   {{0x7d0c0276,0x658803e3,0x387c015d,0x3a24032e}},	//   joas, _məhl, ngwr_, _úlpu_, 
   {{0xe45400c8,0x92080e49,0x63e400cf,0x658806be}},	//   _זינט_, _सुरज_, _ىيمە, _yəho, 
   {{0x75287305,0x7d0c007f,0x629c03b2,0xb1440114}},	//   lmez, eoas, _ópop, _енкл, 
   {{0x7d0cceb0,0x00000000,0x00000000,0x00000000}},	//   foas, --, --, --, 
   {{0x92f0152d,0x7528ceb1,0xeb342f7c,0x7d0c0356}},	//   _хүүх, nmez, كىرد, goas, 
   {{0x6d4c1752,0x00000000,0x00000000,0x00000000}},	// [11360] spba, --, --, --, 
   {{0xed340323,0x1c4001c0,0x6d4c002f,0x658803e3}},	//   _нэмэ, _үнэм, ppba, _bəhl, 
   {{0x7d0cceb2,0xdd8c00f1,0xceb8013d,0x00000000}},	//   boas, _یوی_, _ләң_, --, 
   {{0x6f0cceb3,0x7d0cceb4,0xc18c008f,0x1864ceb5}},	//   lobc, coas, שטאָ, заци_, 
   {{0xdc3404ac,0xbc700132,0x20ec0118,0x80ac010f}},	//   _מאכט_, _جۇقب, dřil_, יסאַ, 
   {{0x65880213,0xa01801a8,0x6f0c0477,0xac740244}},	//   _fəhl, sgög, nobc, _باگش, 
   {{0x2364a1f5,0x8af003be,0x00000000,0x00000000}},	//   _svoj_, ssəs, --, --, 
   {{0x18a0ceb6,0x98a0011b,0x7528ceb7,0x6f0c31c5}},	//   _пасм, _писе, gmez, hobc, 
   {{0x6f0ca94c,0x09c40154,0x658803e3,0x66f00210}},	//   kobc, _এইটা, _zəhl, ałka, 
   {{0xe5a4ceb8,0x75280083,0xdb0c0042,0x7d0cceb9}},	//   _низи, amez, _arcê, zoas, 
   {{0xe0dc026c,0x7d0c01f7,0xb14401d9,0x6f0c01ef}},	//   thò_, yoas, ویوم_, dobc, 
   {{0x2364ceba,0x7d0c0311,0x55b80375,0xe524010b}},	//   _tvoj_, xoas, _למבו, _эдеп, 
   {{0x7d0ccebb,0x658803b9,0x00000000,0x00000000}},	//   voas, _məhm, --, --, 
   {{0x63a0cebc,0xdef8cebd,0x00000000,0x00000000}},	//   _ison, сым_, --, --, 
   {{0x7d0ccebe,0x6298cebf,0xbbc400dc,0x387c0142}},	//   toas, meto, लङ्क, ygwr_, 
   {{0x6298cec0,0x51f80375,0x658806be,0xa01801e3}},	//   leto, _להוצ, _nəhm, tgöd, 
   {{0x9cc8052f,0x7d0ccec1,0x3f9c00f2,0x43400023}},	// [11370] _ғына_, roas, _èwu_, _ኣደባባ, 
   {{0x63a0cec2,0x7d0c2f06,0x7f4c0483,0x7528512c}},	//   _mson, soas, _itaq, zmez, 
   {{0x63a00263,0x62985423,0x69d8cec3,0x7d0ccec4}},	//   _lson, ieto, _ütel, poas, 
   {{0x6298cec5,0x63a0cec6,0x2f1401a8,0x60e40166}},	//   heto, _oson, vægi_, _çumı, 
   {{0x6d48044e,0x63a0cec7,0x7f4c0327,0xb6a4927f}},	//   _çfar, _nson, _jtaq, дилл, 
   {{0x629829eb,0x65880cc1,0xdb20141b,0x7f4ccec8}},	//   jeto, _təhl, _سوزی, _mtaq, 
   {{0x6298cec9,0x75284252,0x7f4c0135,0x65900640}},	//   deto, tmez, _ltaq, вају, 
   {{0x7f4c03be,0xf3480d1d,0x33d400d4,0x00000000}},	//   _otaq, опил_, діот, --, 
   {{0x6298ceca,0x7528cecb,0xb9f81ee0,0x63a001ed}},	//   feto, rmez, _ዙር_, _cson, 
   {{0x6298cecc,0x658800ac,0x63a001c7,0xe3c80789}},	//   geto, _zəhm, _dson, _soñó_, 
   {{0x7f4c0869,0x63a0cecd,0x78f8010f,0x00000000}},	//   _ataq, _eson, ַפֿו, --, 
   {{0x386c020c,0x62980418,0x3cf8012d,0xf10400db}},	//   _jder_, aeto, ्कों_, بۉبۉ_, 
   {{0xb91401e1,0xb6040332,0xd1b80014,0x6f0c31c5}},	//   _bibẹ_, _fháí, _گاشا_, tobc, 
   {{0xe2940228,0x853c0006,0x799401a4,0xdce800df}},	//   _жаш_, _grės, _opzw, ĝiĝo, 
   {{0x386ccece,0x6f0c03c6,0xdcf406be,0xe1f001d3}},	//   _oder_, robc, _arxı, _لسٹ_, 
   {{0x386ccecf,0x7f4c0327,0x6f0c01a9,0x00000000}},	//   _nder_, _ftaq, sobc, --, 
   {{0x394c09a8,0x658800ac,0xf8b80051,0xaf040108}},	// [11380] _česa_, _rəhm, _chũm_, _опил, 
   {{0x63a4ced0,0x386c0ac5,0x7d0809a8,0x658800ac}},	//   ækni, _ader_, česa, _səhm, 
   {{0x61ec4b91,0x77680393,0x4ac41fca,0x6d2416a4}},	//   ºbli, _avex, लॉगव, _одоз, 
   {{0x6298ced1,0x291000d2,0x61ec0077,0x386c072b}},	//   zeto, ôya_, úbli, _cder_, 
   {{0x6298ced2,0xab285211,0x7f4c0135,0x7c8400f0}},	//   yeto, _мома_, _xtaq, _џуџе, 
   {{0x386cced3,0x63a01529,0x629801b8,0x56900da9}},	//   _eder_, _rson, xeto, вашт, 
   {{0x77680393,0x63a01418,0xa96800d8,0x658803e3}},	//   _evex, _sson, _фиба_, _təhm, 
   {{0x6298ced4,0x2d8801ab,0x63684a1a,0x00000000}},	//   weto, itbe_, орог_, --, 
   {{0xa68407d6,0x8334ced5,0x68e0b3ac,0x63a001a9}},	//   _олад, нних, mhod, _qson, 
   {{0x62980270,0x27e40810,0x68e0ced6,0x6d580113}},	//   ueto, mzon_, lhod, štay, 
   {{0x65880cc1,0x386c037e,0x425403e6,0x7f4c0135}},	//   _məhk, _yder_, ونکر, _staq, 
   {{0x63a0ced7,0x68e0ced8,0x754800dd,0x386c0ac5}},	//   _tson, nhod, őszö, _xder_, 
   {{0x63a004ac,0x27e4ced9,0x93747932,0x43940139}},	//   _uson, nzon_, _قصور_, _чалс, 
   {{0x6298ceda,0x27e4cedb,0x37d8008f,0xa018007c}},	//   qeto, izon_, פֿרע, dföt, 
   {{0x68e0cedc,0x1cb00003,0x8f340ff1,0xa90801a9}},	//   khod, _དོད_, терц, trоl, 
   {{0x68e00306,0x3df4013d,0x00000000,0x00000000}},	//   jhod, _үзис, --, --, 
   {{0x68e0cedd,0x7f4c0eda,0x69c8002f,0x051c00cc}},	// [11390] dhod, _utaq, äfen, _পূৱৰ_, 
   {{0x27e4003e,0x00000000,0x00000000,0x00000000}},	//   dzon_, --, --, --, 
   {{0x42700201,0x00000000,0x00000000,0x00000000}},	//   _በአንድ_, --, --, --, 
   {{0xf86800c6,0x68e0cede,0x00000000,0x00000000}},	//   سمتي_, ghod, --, --, 
   {{0x26dc0ba7,0x80a8009e,0xcb44022e,0x00000000}},	//   _blto_, গাপ্, _ахси, --, 
   {{0x6f00007b,0x00000000,0x00000000,0x00000000}},	//   _íoct, --, --, --, 
   {{0x68e03917,0x55c004a9,0x27e405da,0x66f0012d}},	//   bhod, тайғ, azon_, ałko, 
   {{0x68e09637,0x386ccedf,0x27e403ee,0x2f140008}},	//   chod, _uder_, bzon_, lægt_, 
   {{0x1cb01b35,0x00000000,0x00000000,0x00000000}},	//   _དོན_, --, --, --, 
   {{0x78a80093,0x562401ed,0xd5b8010a,0x00000000}},	//   _haev, _قرآ, _мсе_, --, 
   {{0x78a800af,0x80a80011,0xe1f40166,0x00000000}},	//   _kaev, গান্, егэ_, --, 
   {{0x78a801a9,0xdee0023b,0x7c3c002f,0x00000000}},	//   _jaev, қоси, _ngsr, --, 
   {{0x78a82a59,0x04c80c8b,0xe28ccee0,0x72d448e5}},	//   _maev, _توني_, _йа_, _подф, 
   {{0x68e00745,0x78a8cee1,0xada40432,0x6da4cee2}},	//   zhod, _laev, нагл, нига, 
   {{0x7d0808ad,0x27e4cee3,0x6834010e,0x68e00306}},	//   česn, zzon_, _küdü, yhod, 
   {{0xdca0cee4,0x78a8cee5,0x2d8800e5,0x20040210}},	//   ласи, _naev, rtbe_, _śnie_, 
   {{0x68e0b7f2,0x68340365,0x0aa802dd,0x00000000}},	// [113a0] vhod, _müdü, мбақ_, --, 
   {{0x7c3c02d0,0x613c0171,0xada40064,0x00000000}},	//   _egsr, _sīli, _заол, --, 
   {{0x68e0cee6,0xe938cee7,0x613c00de,0xaa8401ef}},	//   thod, سسات_, _pīli, jvýž, 
   {{0xa01804f3,0x27e4cee8,0x68e0012c,0xfd64063f}},	//   mför, tzon_, uhod, hasị, 
   {{0xa018049f,0x68e0cee9,0xfd6401f2,0x6d480798}},	//   lför, rhod, kasị, _éfab, 
   {{0x779002f2,0x00000000,0x00000000,0x00000000}},	//   شیما, --, --, --, 
   {{0x68e00384,0xa018ceea,0x6834010e,0x27e401ed}},	//   phod, nför, _büdü, szon_, 
   {{0x683406be,0x7c28010e,0x00000000,0x00000000}},	//   _cüdü, _ºert, --, --, 
   {{0x228400c2,0x68340342,0x613c002b,0xd4640063}},	//   нунг, _düdü, _mūle, хиње_, 
   {{0xa018049f,0x49080316,0xfd6402e3,0x9f5c00d8}},	//   kför, िकको_, gasị, çuí_, 
   {{0x73d800f7,0xd48c004e,0x78a86341,0x00000000}},	//   здөр_, _йр_, _yaev, --, 
   {{0xa018049f,0x68341b0d,0x00000000,0x00000000}},	//   dför, _güdü, --, --, 
   {{0x2484005c,0x6d5cceeb,0x67380170,0x65880213}},	//   _icom_, _awpa, _kitj, _səhh, 
   {{0x6618ceec,0x6738025c,0xa01801e3,0xf8dc00cd}},	//   _kytk, _jitj, fför, _मत्प, 
   {{0x67380372,0x2f141b25,0xa01801e6,0x6d5c0368}},	//   _mitj, vægt_, gför, _cwpa, 
   {{0x67385628,0x2484037e,0x7d080010,0x658803e3}},	//   _litj, _jcom_, česo, _vəhh, 
   {{0x2f14037e,0x67380113,0x78a8ceed,0x6d5c02d0}},	// [113b0] tægt_, _oitj, _raev, _ewpa, 
   {{0x78a81730,0x6738ceee,0x3e68036b,0x68380023}},	//   _saev, _nitj, _کجکی_, _እሱራት, 
   {{0x78a8ceef,0x6618023a,0x6d5c015d,0x00000000}},	//   _paev, _nytk, _gwpa, --, 
   {{0x6ee001f1,0x2b400477,0x00000000,0x00000000}},	//   _vôbe, _fukc_, --, --, 
   {{0x78a8cef0,0xbe14005e,0x673809a8,0x6618022e}},	//   _vaev, _سوڭع, _bitj, _aytk, 
   {{0xcf9400c8,0x24840109,0xca7c0139,0x6d4800d8}},	//   רטס_, _acom_, _birе, _éfac, 
   {{0x67380831,0xceb406a9,0x78a800af,0x2484cef1}},	//   _ditj, טיס_, _taev, _bcom_, 
   {{0x24844f3b,0x67380d27,0x81d4015b,0xca7c01a9}},	//   _ccom_, _eitj, _সেভ_, _dirе, 
   {{0x4794cef2,0x6738cef3,0x2484004d,0x613c00e2}},	//   _مجلس, _fitj, _dcom_, _mīlu, 
   {{0x2484030d,0x6738010b,0x7a7c0023,0xc7c401d5}},	//   _ecom_, _gitj, _ብቀጥታ_, _ёсти, 
   {{0x0574cef4,0x24480124,0x6834010e,0x9554007b}},	//   _ماند, _ỹme_, _tüdü, _أخطا, 
   {{0xa01801e6,0x6738cef5,0xfd6401f2,0x24840332}},	//   vför, _zitj, sasị, _gcom_, 
   {{0xa8540302,0x7ae400d2,0x658800ac,0x7d0872f2}},	//   כירה_, khht, _rəhi, česl, 
   {{0x65880cc1,0xa018049f,0x00000000,0x00000000}},	//   _səhi, tför, --, --, 
   {{0x2138cef6,0x613ccef7,0x7ae401ab,0x64440153}},	//   _fiqh_, _pūle, dhht, žkie, 
   {{0xa01836f6,0x30740117,0x00000000,0x00000000}},	//   rför, _рукс, --, --, 
   {{0xa01804f3,0xaa44cef8,0xdca0bb40,0xc0a8027d}},	// [113c0] sför, везл, шати, _سايل_, 
   {{0xa01801e6,0xed44005b,0x00000000,0x00000000}},	//   pför, _иноп, --, --, 
   {{0x673801a4,0xa0180008,0xe968055f,0x8024036b}},	//   _ritj, ngön, фаел_, _لریم, 
   {{0x6738cef9,0x774c0023,0xeff00023,0x66180108}},	//   _sitj, _ዝተመደ, _ግሁድ_, _rytk, 
   {{0x6738cefa,0x1864cefb,0xe7287610,0x66180108}},	//   _pitj, тачи_, وستو_, _sytk, 
   {{0xc1780006,0xd6cc0451,0x6738036e,0x658803e3}},	//   yrė_, يقن_, _qitj, _məhv, 
   {{0x8884cefc,0x6738cefd,0x442002d5,0xb0e02ecf}},	//   _میان, _vitj, _ši_, _पतंग, 
   {{0x44200016,0x6738cefe,0x66180306,0xd1d40023}},	//   _ơi_, _witj, _vytk, ኮነት_, 
   {{0x2b440597,0x6738ceff,0x3804014b,0x00000000}},	//   íoch_, _titj, _ботҳ, --, 
   {{0x2d982759,0x673827bb,0xca7c0139,0xe8d0000d}},	//   _oppe_, _uitj, _tirе, _थकुच, 
   {{0xe5a401c6,0xa0182bb4,0xe4a40153,0x00000000}},	//   _шижи, ggön, _арло, --, 
   {{0x64a410f3,0x248400ad,0x00000000,0x00000000}},	//   _јада, _ucom_, --, --, 
   {{0x4420a99f,0x661400ee,0x1af800cc,0x261412eb}},	//   _ái_, şykd, ্ততে_, _पुती_, 
   {{0x32080055,0x51f003c7,0x00000000,0x00000000}},	//   _śaye_, اسیر, --, --, 
   {{0x613c0055,0x00000000,0x00000000,0x00000000}},	//   _pīlu, --, --, --, 
   {{0x394c025c,0xddc40064,0x00000000,0x00000000}},	//   _ċes_, lajū, --, --, 
   {{0xbab805f5,0x613c0171,0x00000000,0x00000000}},	// [113d0] нгах_, _vīlu, --, --, 
   {{0xbb180597,0xca7400d1,0x4a54cf00,0xe814000d}},	//   رياض_, لامغ, икус, _तड़ा_, 
   {{0xc9840124,0xa2a83711,0x00000000,0x00000000}},	//   иуци, _जघन्, --, --, 
   {{0xf770cf01,0x00000000,0x00000000,0x00000000}},	//   مات_, --, --, --, 
   {{0x36d40d1d,0x69c801bf,0x00000000,0x00000000}},	//   лодр, øfer, --, --, 
   {{0xb3841b74,0xd6d8cf02,0x068402bf,0x8b880202}},	//   ҳлил, ьте_, игін, _جەكە_, 
   {{0x8478044e,0xf3f80276,0x00000000,0x00000000}},	//   _ኮምሽን_, maţi_, --, --, 
   {{0xf3f8084c,0xb924007b,0xb3840395,0x04b400d1}},	//   laţi_, _إفري, глил, للىڭ, 
   {{0xd77413d7,0xf4943ee6,0x844001a9,0x00000000}},	//   _جازع, نشکد, _ko喪s, --, 
   {{0xf3f80276,0x7e640477,0x8c1c0375,0x2ed001f9}},	//   naţi_, _nehp, ווחי, _हवेत, 
   {{0x80cc02f5,0x658800ac,0x764002d0,0x00000000}},	//   াসন্, _səhv, _igly, --, 
   {{0xc4580022,0xa01801a8,0x2978008f,0x032460a1}},	//   _аицх_, rgön, עטרא, лдөн, 
   {{0x45300137,0x65880213,0x00000000,0x00000000}},	//   _بۉير, _qəhv, --, --, 
   {{0xb8e45078,0xf3f80276,0x69c8002f,0x00000000}},	//   _ཏོ_, jaţi_, äfek, --, 
   {{0xe29406bb,0x3e300020,0x7e640455,0xf3f80276}},	//   _сащ_, _በትክክ, _dehp, daţi_, 
   {{0x6ee00086,0x6cc400f7,0x65880213,0x61d405d0}},	//   _dôba, ыйба, _təhv, _תוקף_, 
   {{0xa018cf03,0x76400432,0xf3f80356,0xeab858a7}},	// [113e0] ngöl, _ogly, faţi_, нйа_, 
   {{0xf3f80276,0x7640015d,0x00000000,0x00000000}},	//   gaţi_, _ngly, --, --, 
   {{0xc754044e,0x613c18a6,0x2d98049f,0xcdc41621}},	//   _ዝተዋህ, _kūla, _uppe_, _танқ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x386808a7,0xf3f80311,0x613c00dc,0x00000000}},	//   ðara_, baţi_, _mūla, --, 
   {{0xf3f800a8,0x3178012d,0x661c0254,0x00000000}},	//   caţi_, ńszy_, üpko, --, 
   {{0x224c005a,0x9a24004e,0x28e8011c,0x00000000}},	//   _rffk_, _борб_, _здвп_, --, 
   {{0x6aaccf04,0x76400064,0x00000000,0x00000000}},	//   _habf, _egly, --, --, 
   {{0x80cc045e,0x00000000,0x00000000,0x00000000}},	//   াসম্, --, --, --, 
   {{0x05140154,0x658806be,0x00000000,0x00000000}},	//   াগের_, _səhu, --, --, 
   {{0xe3b02ab4,0x7e64014f,0xda7800df,0xddc40064}},	//   _گرا_, _rehp, ענטר, rajū, 
   {{0xf3f8084c,0x7d08140b,0x7e64cf05,0x403400d8}},	//   zaţi_, česk, _sehp, иенс, 
   {{0x644051e2,0xe3b0cf06,0x20ec0118,0x613c00ef}},	//   _igoi, _درا_, dřit_, _dūla, 
   {{0xe2a81169,0x7e640455,0xf3f8054e,0x5438010f}},	//   _ساتن_, _qehp, xaţi_, _נעגא, 
   {{0xd1b405d4,0xf3f80311,0x528000cf,0x22ac06be}},	//   _مايا_, vaţi_, _الىك, mәk_, 
   {{0x8af00213,0x8c648984,0x00000000,0x00000000}},	//   msəy, йтуд, --, --, 
   {{0xdb2027c7,0xf3f8084c,0x18b00184,0x161800dc}},	// [113f0] موری, taţi_, ҙҙар, _पुनर_, 
   {{0x6aac0175,0x8af80064,0x613c01e1,0x00000000}},	//   _cabf, гнус_, bàlè, --, 
   {{0x658803be,0xf3f8084c,0xbc940798,0x613c00cd}},	//   _məhs, raţi_, _канј, _zūla, 
   {{0x6440cf07,0xf3f80276,0xc984cf08,0x76400142}},	//   _ngoi, saţi_, суфи, _sgly, 
   {{0xf3f80311,0xdee400b7,0xc00803d4,0xc95800d1}},	//   paţi_, _ማሽን_, ৰেৰণ_, نلەش_, 
   {{0x6440cf09,0x8af006be,0xe7b000d1,0xc1780064}},	//   _agoi, ksəy, زمىد, nzės_, 
   {{0x18b00022,0x244800e4,0xa018032e,0x00000000}},	//   _гәлр, _ỹma_, dgöm, --, 
   {{0xe4d004a9,0xdb0c0356,0x3ce8005c,0x00000000}},	//   ققىد, _urcâ, nhav_, --, 
   {{0xb4d445bf,0xe0dc007f,0x658803b9,0xbb2c00d1}},	//   _सकी_, dkò_, _bəhs, ﻧﯘﻥ_, 
   {{0x6440cf0a,0x7640cf0b,0xa3c40abd,0x47348ed9}},	//   _egoi, _ugly, _उपर_, _гнус, 
   {{0xd5b8cf0c,0xc1780064,0x2d9c0327,0xc64401f7}},	//   _яса_, dzės_, ħtek_, _اَمي, 
   {{0xf3f805a2,0x613c00ef,0x00000000,0x00000000}},	//   _инеш_, _pūla, --, --, 
   {{0x62880175,0x6fc405c0,0x00000000,0x00000000}},	//   _fcfo, ामधू, --, --, 
   {{0x02c40323,0x658806be,0x602001ca,0x00000000}},	//   _гишү, _təht, ідра, --, 
   {{0x6da4cf0d,0xacf41614,0x20ec012c,0x3074030d}},	//   шива, ачај, třit_, _купс, 
   {{0xdb0c35f5,0x613ccf0e,0xeb98036b,0x48e00154}},	//   _arcà, _tūla, киб_, _ভদ্র, 
  
   {{0x60c8007f,0x00000000,0x00000000,0x00000000}},	// [11400] _ògma, --, --, --, 
   {{0x658800ac,0xf1c80248,0x8ea400cf,0x00000000}},	//   _məhr, _gbáà_, _الدۇ, --, 
   {{0xed58cf0f,0x83740092,0xb4d407f7,0xec7800f3}},	//   _шон_, _በነዚህ_, _सकू_, _ипн_, 
   {{0x1ccc031c,0x3ce8016d,0x00000000,0x00000000}},	//   _ྱོར_, chav_, --, --, 
   {{0xa6c8151a,0x658806be,0x7bb801af,0x00000000}},	//   клда_, _nəhr, _йырс_, --, 
   {{0x64400876,0xd7002cdd,0x97740124,0xd6d00116}},	//   _sgoi, озчи, ртцә, قتىغ, 
   {{0xe4a4011c,0xe5c48dbb,0x1a98010f,0x00000000}},	//   арпо, рсло, _שילע, --, 
   {{0xd94023c3,0x658800ac,0x544000d1,0x00000000}},	//   _фети, _bəhr, ينىك, --, 
   {{0x66740502,0x764c0882,0x2614298e,0x18b01cd1}},	//   _ندار, śaya, _पुरी_, _фәхр, 
   {{0x29040093,0x273000db,0x88c80183,0xa6a800db}},	//   lnoa_, _بۉتس, _শতিক, _جارق_, 
   {{0xf7700050,0x571000d1,0x00000000,0x00000000}},	//   _واے_, _بولذ, --, --, 
   {{0x2904cf10,0x64400810,0xd5f80375,0xe458005b}},	//   nnoa_, _ugoi, _בפבר, _ржд_, 
   {{0x65880cc1,0x2904cf11,0xe0dc0268,0x83540eff}},	//   _təhs, inoa_, rkò_, _اپتا, 
   {{0xdef8cf12,0x539802e4,0xff28007b,0xa01800a2}},	//   тым_, _סיוו, اكسي_, lgök, 
   {{0x8e3800c6,0xdc88442d,0xd24c0133,0x658803e3}},	//   لسفر_, ксал_, _تۆپ_, _zəhr, 
   {{0xc7742295,0x9fe400f2,0xa018007c,0x5574010f}},	//   _ከፍተኛ_, _نسخه, ngök, יעלן_, 
   {{0x8af00213,0xdb0ccf13,0x3ce803b2,0x4bb401c4}},	// [11410] rpən, _arcá, rhav_, ойтс, 
   {{0x3ce80070,0xdd84084c,0xed4c01ed,0x6cd41c3e}},	//   shav_, _кымп, بھی_, _ۇقپا, 
   {{0x13cc02a6,0x3ce8cf14,0x6e94247f,0xf9f8cf15}},	//   িনয়, phav_, _الپا, دفاع_, 
   {{0xb4d41dd1,0x29040270,0xa3c4012c,0x613c00b8}},	//   _सके_, gnoa_, उमा_, _mūlo, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbae425aa,0x29041140,0xb6a4cf16,0x86980023}},	//   _اكسي, anoa_, сикл, _መኽፈቲ_, 
   {{0x65880213,0x3a2400d7,0x58840064,0x00000000}},	//   _səhr, _álp_, _выза, --, 
   {{0x7984013f,0x6444cf17,0x658803e3,0xd800010a}},	//   muhw, žkin, _pəhr, _мăй_, 
   {{0x69d80724,0x658800ac,0xdb0c00bc,0x81d40154}},	//   _üter, _qəhr, _zrcá, _সেল_, 
   {{0xb2240148,0x00000000,0x00000000,0x00000000}},	//   ймпл, --, --, --, 
   {{0xd9f4012d,0x00000000,0x00000000,0x00000000}},	//   ंछित_, --, --, --, 
   {{0x65880213,0x00000000,0x00000000,0x00000000}},	//   _təhr, --, --, --, 
   {{0x7984cf18,0xc3480208,0x2ee85729,0x91a400e5}},	//   huhw, _hổn_, thbf_, _چنتے_, 
   {{0x7984cf19,0xf2680032,0x00000000,0x00000000}},	//   kuhw, _сикл_, --, --, 
   {{0x2d9c006a,0x7984003e,0x6d2400ae,0x00000000}},	//   ïte_, juhw, معرك, --, 
   {{0xb4d475be,0x7984cf1a,0x307800c6,0xa5d8010f}},	//   _सको_, duhw, _صحبة_, אַמי, 
   {{0x2248036e,0xc3480051,0xeb4800ec,0xea580798}},	// [11420] _çikë_, _lổn_, اشرو_, греј_, 
   {{0xfd6802e3,0x20ec0198,0xa9a40137,0x7d1ccf1b}},	//   _jupụ, nƙin_, йизд, _ekss, 
   {{0x2ef89395,0x7984003e,0x9ee400db,0xda980022}},	//   _impf_, guhw, _دزيۇ, ыстә_, 
   {{0x65ac1682,0x2ef80036,0x2904cf1c,0x613c003a}},	//   _ṱhoh, _hmpf_, unoa_, _nūll, 
   {{0x29045191,0x684400c7,0x00000000,0x00000000}},	//   rnoa_, анҵа, --, --, 
   {{0xfd6801f2,0x79841ab4,0xc348004d,0x07a400d1}},	//   _nupụ, buhw, _bổn_, йаҗн, 
   {{0x6d4c0007,0xc3480051,0x00000000,0x00000000}},	//   nqba, _cổn_, --, --, 
   {{0x57e43531,0x658803b9,0x95c401ec,0x00000000}},	//   рдәм_, _qəhq, суша_, --, 
   {{0xfd68063f,0xa6940b3e,0x04200154,0x68e0cf1d}},	//   _bupụ, _греј, মেনী_, mkod, 
   {{0xe7380598,0x68e000dd,0x2a6808a5,0x00000000}},	//   _сез_, lkod, _jebb_, --, 
   {{0x658800ac,0xc0cc001f,0x5a98008f,0x80cc00eb}},	//   _təhq, _ጤናማ_, נשטא, াসস্, 
   {{0x68e0cf1e,0x2a68002e,0x00000000,0x00000000}},	//   nkod, _lebb_, --, --, 
   {{0x53a06afe,0x68e00099,0xdb740023,0x00000000}},	//   _нацб, ikod, _ኢልዎም_, --, 
   {{0x2a682d8b,0x996000d7,0x00000000,0x00000000}},	//   _nebb_, _líšt_, --, --, 
   {{0x68e0cf1f,0x8af00213,0x0dc8cf20,0x527800df}},	//   kkod, rpəl, бути_, _ענהא, 
   {{0x69dccf21,0x2ef8002f,0x00000000,0x00000000}},	//   dype, _empf_, --, --, 
   {{0x2d4c0209,0x8b5800c6,0x68e0cf22,0x2a680042}},	// [11430] _eýe_, مجلس_, dkod, _bebb_, 
   {{0x3a740046,0x2ef8017a,0x79840099,0x09b80327}},	//   ілер, _gmpf_, tuhw, _ཙནྡ_, 
   {{0x69dc074d,0x84e8012c,0xc98400f5,0x8c9800d1}},	//   gype, टघाट_, зучи, شپەز_, 
   {{0x386800fc,0x9bc45067,0x7f5c0395,0x2a68005a}},	//   úar_, _лёгк, opsq, _eebb_, 
   {{0xd6c001b9,0x8934007b,0x00000000,0x00000000}},	//   зилқ, أعلا, --, --, 
   {{0xb578769a,0x254c003a,0x79840230,0x69dc00d8}},	//   ащих_, _cęlo_, puhw, bype, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x68e0cf23,0xd87400db,0x6d5800df,0x739800d8}},	//   ckod, _داسب, ŭtag, атос_, 
   {{0xe4d40a2c,0x80ac012d,0x00000000,0x00000000}},	//   تويت_, ज़ने, --, --, 
   {{0xc348001e,0xf2a400d8,0x2a680327,0x00000000}},	//   _tổn_, циоп, _xebb_, --, 
   {{0x349401d5,0x00000000,0x00000000,0x00000000}},	//   _мажр, --, --, --, 
   {{0xa0180205,0x00000000,0x00000000,0x00000000}},	//   lföy, --, --, --, 
   {{0x63e40150,0x00000000,0x00000000,0x00000000}},	//   _ويمە, --, --, --, 
   {{0x68e0cf24,0xa3d400c5,0x69dc01f4,0x00000000}},	//   zkod, सहर_, yype, --, 
   {{0x69dc02d0,0xd15000cf,0x00000000,0x00000000}},	//   xype, _ээлө, --, --, 
   {{0x2a680ac5,0xac08cf25,0x7054007b,0xab640024}},	//   _sebb_, анба_, _بنظا, жвал, 
   {{0xa1100597,0xdfcc0b24,0x00000000,0x00000000}},	// [11440] _تويت, _ليي_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x68e0cf26,0xceb80075,0xf1c8024a,0x00000000}},	//   tkod, _кәң_, िमिन, --, 
   {{0x2a68cf27,0x69dccf28,0x394c560e,0xc18c010f}},	//   _webb_, rype, _čest_, רטאָ, 
   {{0x69dc457c,0x7d0804a7,0xe738013e,0xc0ac010f}},	//   sype, čest, аед_, טיאָ, 
   {{0x68e0cf29,0xf1c8090a,0xd7040c56,0x69dc0124}},	//   skod, िमान, онче_, pype, 
   {{0xc4486f51,0x64440010,0xe8140073,0x6b9403ac}},	//   میان_, žkim, _तडका_, ltyg, 
   {{0xd494cf2a,0x15140597,0x6284013f,0x00000000}},	//   орь_, يزية_, ɑkoy, --, 
   {{0x6b946dfa,0x78bc03f2,0x24540022,0x6b500064}},	//   ntyg, _ósva, бақь_, _užgę, 
   {{0xe5a40351,0x7f5c0334,0x00000000,0x00000000}},	//   _мизи, vpsq, --, --, 
   {{0xa018007c,0xe79401e2,0x00000000,0x00000000}},	//   ngöv, _داځک, --, --, 
   {{0xc3480051,0x2364012d,0x00000000,0x00000000}},	//   _hổm_, _twoj_, --, --, 
   {{0x705001e2,0x5fc801f9,0x00000000,0x00000000}},	//   رچيا, ामधल, --, --, 
   {{0x63a0cf2b,0x3cfc01ad,0x79400023,0x415402e8}},	//   _ipon, रोने_, ይቶታት, _евкс, 
   {{0x27300276,0x13dc0154,0x52100063,0x00000000}},	//   mând_, _বইয়, _одшт, --, 
   {{0x1fa41bb8,0x9f68026a,0x3b54cf2c,0x7bcccf2d}},	//   _дрог, _кроз_, зкар, txau, 
   {{0x62982430,0xebc000fd,0xcb38022e,0xa908022e}},	// [11450] ofto, нәрн, da蜢i_, vrоp, 
   {{0x63a0cf2e,0x2730084c,0x00000000,0x00000000}},	//   _mpon, nând_, --, --, 
   {{0x7f44014b,0x7f4c02d1,0x6298208d,0xa2b0227c}},	//   _iihq, _huaq, ifto, _असन्, 
   {{0x80a804c5,0xdd8c0451,0x6d5803b2,0x2d9c031c}},	//   গাক্, _ٻوڏ_, ítae, ħtet_, 
   {{0x661409a5,0x69c81196,0x62980240,0x2d8c0139}},	//   şykl, äfer, kfto, _äfer_, 
   {{0xb3440120,0x7f440455,0x629801f5,0x501c0375}},	//   _liçã, _jihq, jfto, בודו, 
   {{0x63a0cf2f,0x25bc003b,0x2730054e,0xe640004e}},	//   _apon, _crtl_, dând_, нешп, 
   {{0x629801f5,0x3994a075,0x63a001e7,0xd7f8cf30}},	//   efto, mås_, _bpon, _куз_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x386c088d,0x27300276,0x00000000,0x00000000}},	//   _heer_, gând_, --, --, 
   {{0x386cbbd7,0x63a0cf31,0x39942611,0xb2240229}},	//   _keer_, _epon, nås_, ямол, 
   {{0x386c0050,0x776800aa,0x63a0003a,0x6298017a}},	//   _jeer_, _kwex, _fpon, afto, 
   {{0x386ccf32,0x7cf005ac,0x600452f5,0x27300356}},	//   _meer_, _kårf, зням_, bând_, 
   {{0x27300311,0x39949c2a,0xf1d00166,0xc3480208}},	//   când_, kås_, _зөмө, _xổm_, 
   {{0xed581ee3,0x82f827a1,0x776800f1,0x7cf0003b}},	//   соб_, _برنز_, _lwex, _mårf, 
   {{0x13dc02a6,0x386c0e29,0x2730084c,0x399400cc}},	//   _বেয়, _neer_, mâne_, dås_, 
   {{0xdcaccf33,0x7f4c0309,0x2730cf34,0xa2b01b61}},	// [11460] دىق_, _guaq, lâne_, _असम्, 
   {{0x6b94049f,0x00000000,0x00000000,0x00000000}},	//   rtyg, --, --, --, 
   {{0x39940267,0x386ccf35,0xae0400db,0x6ee00208}},	//   gås_, _beer_, _روحى, _nôbi, 
   {{0x27300276,0x2d88046a,0xeb98cf36,0xa2b0098a}},	//   zând_, mube_, _лим_, _असभ्, 
   {{0x386c3b08,0x2d88cf37,0xa818cf38,0x6d4476bd}},	//   _deer_, lube_, حتار_, _iika, 
   {{0x6d44cf39,0xddc409a8,0x779000e5,0xd6b00395}},	//   _hika, lajš, ئیلا, ейшъ, 
   {{0x6d44cf3a,0x2d88cf3b,0x386c0731,0x2730054e}},	//   _kika, nube_, _feer_, vând_, 
   {{0x6d44cf3c,0x386c9380,0x63a001a9,0xddc400d0}},	//   _jika, _geer_, _ppon, najš, 
   {{0x6d44cf3d,0x2d88cf3e,0x27300276,0x7cf0007c}},	//   _mika, hube_, tând_, _fårf, 
   {{0x6d44cf3f,0x386c0936,0x2d881629,0x63a00427}},	//   _lika, _zeer_, kube_, _vpon, 
   {{0x64a42488,0x6d44cf40,0x62986083,0x27300311}},	//   _нажа, _oika, rfto, rând_, 
   {{0x386c22ac,0x613ccf41,0xdb0c0137,0x850400aa}},	//   _xeer_, _kūli, _escè, _کوچن, 
   {{0x386809cc,0x613c0029,0x63a00c8c,0x2730084c}},	//   ðari_, _jūli, _upon, pând_, 
   {{0x6d44cf42,0x1ccc025c,0x7f440455,0x2d888f29}},	//   _aika, _ྱོང_, _qihq, fube_, 
   {{0x6d44cf43,0x7f440455,0x0dc8041b,0x929800d9}},	//   _bika, _vihq, пути_, _היות, 
   {{0x6d44cf44,0x7cf00158,0x09e0015b,0x7f4c0393}},	//   _cika, _mårg, _যেভা, _tuaq, 
   {{0x386ccf45,0x00000000,0x00000000,0x00000000}},	// [11470] _reer_, --, --, --, 
   {{0x386ccf46,0x3994cf47,0x2d88cf48,0x6d44cf49}},	//   _seer_, tås_, bube_, _eika, 
   {{0x386ccf4a,0x6d441311,0x3f98cf4b,0x7ae401f7}},	//   _peer_, _fika, ltsu_, rkht, 
   {{0xf770044d,0x6d4422b9,0x399404f3,0x386c0009}},	//   نات_, _gika, rås_, _qeer_, 
   {{0x386ccf4c,0x3f98cf4d,0x39942b27,0xb9040b03}},	//   _veer_, ntsu_, sås_, _पक_, 
   {{0x386ccf4e,0x2730006a,0x7d0c0162,0x3f98005a}},	//   _weer_, yâne_, lnas, itsu_, 
   {{0xc984cf4f,0x6d44cf50,0x386ccf51,0x7cf011ad}},	//   _пути, _yika, _teer_, _vårf, 
   {{0x7d0ccf52,0x6d4406e4,0x60c80e89,0x00000000}},	//   nnas, _xika, _ògmh, --, 
   {{0x7d0ccf53,0x77680472,0x2d880072,0x613c00ef}},	//   inas, _uwex, zube_, _gūli, 
   {{0x7cf0cf54,0x7d0c0cfd,0xa2b00490,0x00000000}},	//   _hård, hnas, _असण्, --, 
   {{0x3dc00218,0x7d0ccf55,0x2d880944,0xdbd80241}},	//   _nrhw_, knas, xube_, _sàìm, 
   {{0x2730cf56,0x6c940150,0x00000000,0x00000000}},	//   râne_, _ﺘﺫﻫﺏ_, --, --, 
   {{0xe28ccf57,0xdb0ca92b,0x7d0ccf58,0x2d886580}},	//   _иа_, _escé, dnas, wube_, 
   {{0x6d44cf59,0x2d88cf5a,0x7cf005ac,0x7d0ccf5b}},	//   _sika, tube_, _lård, enas, 
   {{0x311462bd,0xa2b007b7,0x7d0c0008,0xd20039b7}},	//   _офис, _असत्, fnas, _чүнк, 
   {{0x2d88251d,0x7d0ccf5c,0xdca007d6,0x6d440429}},	//   rube_, gnas, каси, _qika, 
   {{0x6d44cf5d,0xddc4955b,0x2d88011f,0x7528005a}},	// [11480] _vika, rajš, sube_, ilez, 
   {{0x6d44cf5e,0xa018cf5f,0x7d0ccf60,0x7528013e}},	//   _wika, rgöt, anas, hlez, 
   {{0x6d44cf61,0xa95801d9,0x7d0c0589,0xa01801a8}},	//   _tika, زجار_, bnas, sgöt, 
   {{0x613ccf62,0x7d0ccf63,0x1864026a,0x6d44020c}},	//   _pūli, cnas, даци_, _uika, 
   {{0x7528cf64,0x6d5c037e,0xa0180267,0x00000000}},	//   dlez, _htpa, lgör, --, 
   {{0x7528cf65,0x657c19e4,0xf1dc1a55,0xa96802e8}},	//   elez, ápho, महान, _мига_, 
   {{0xa018cf66,0x035401e1,0x1618000d,0x00000000}},	//   ngör, _ìjẹf, _पुआर_, --, 
   {{0x7528cf67,0x7cf0cf68,0x2900049f,0xc348004d}},	//   glez, _gård, _öka_, _hổi_, 
   {{0x60c801ab,0x613c0064,0x00000000,0x00000000}},	//   _ògmi, _kūlv, --, --, 
   {{0x6d5c04b9,0x65c406bb,0x7d0ccf69,0x7cf001e3}},	//   _otpa, _обза, znas, _tårg, 
   {{0xd48c3352,0x7cf017c0,0x7528cf6a,0x3f981f94}},	//   _ир_, _håre, blez, wtsu_, 
   {{0x7cf017b8,0x7528c7cc,0x672803cd,0xc348004d}},	//   _kåre, clez, llfj, _lổi_, 
   {{0x6d5ccf6b,0x7d0c022c,0x61080210,0xd36c01c8}},	//   _atpa, vnas, nęli, _نهن_, 
   {{0x6d5c0268,0x3f98cf6c,0x7d0ccf6d,0x7cf0143a}},	//   _btpa, rtsu_, wnas, _måre, 
   {{0xc34807ae,0x2ca0070d,0x7d0ccf6e,0xb9000003}},	//   _nổi_, _bbkd_, tnas, _ཧྭ_, 
   {{0x4034cf6f,0x3a300419,0x261405dc,0x00000000}},	//   _пейс, _rzzp_, _पुछी_, --, 
   {{0x6d5c0857,0x3f9802d1,0x212801c7,0x81d40154}},	// [11490] _etpa, qtsu_, mlch_, _সেচ_, 
   {{0x6d5c00e4,0x19e800c6,0x21280986,0xc3480208}},	//   _ftpa, يراً_, llch_, _bổi_, 
   {{0x21280368,0x7528002d,0x6d5c045a,0x00000000}},	//   olch_, ylez, _gtpa, --, 
   {{0x7cf01512,0x7e74005a,0x7d0c5431,0x21280036}},	//   _båre, lazp, qnas, nlch_, 
   {{0x7cf004f3,0x7528cf70,0x14bc1276,0x8ccc39a7}},	//   _vård, vlez, _शोषण, हारो, 
   {{0x6d480395,0x7e7401c4,0x7cf0007c,0x672803b2}},	//   _èfac, nazp, _dåre, glfj, 
   {{0x7528a301,0x26000c6f,0x65780129,0x21280036}},	//   tlez, _वेदी_, _cvth, klch_, 
   {{0x7cf026cc,0x67280b4f,0x7e74005a,0x3ce8cf71}},	//   _fåre, alfj, hazp, nkav_, 
   {{0x7528cf72,0x7cf005ac,0x5fc0033f,0xc1780064}},	//   rlez, _kårb, शिफल, esė_, 
   {{0x752800bc,0xaad00b6d,0x21280076,0xdbd801e1}},	//   slez, सायक, elch_, _mààm, 
   {{0xb9dc02d3,0x7e740477,0xf8b800b8,0x7cf0007c}},	//   _ባኒ_, dazp, _kaũ_, _mårb, 
   {{0x27300311,0x658806be,0xa01801e3,0x00000000}},	//   mâna_, _nəhy, vgör, --, 
   {{0x13a4cf73,0xdbd801e1,0xe4780092,0x00000000}},	//   _آنتی_, _nààm, ሪታኒያ_, --, 
   {{0x86580296,0x7e74cf74,0x3cfc256a,0xacb4004b}},	//   _nyɔ́, gazp, रोसे_, کمرغ, 
   {{0xed50ae1e,0x00000000,0x00000000,0x00000000}},	//   اپر_, --, --, --, 
   {{0xdbd801e1,0x8fc40022,0xa018cf75,0xada400c7}},	//   _bààm, _ааиҵ, rgör, _ҟамл, 
   {{0x7e7401c4,0x6728002d,0xafe42143,0x00000000}},	// [114a0] bazp, ylfj, _чопл, --, 
   {{0xdbd80248,0xa0180267,0x00000000,0x00000000}},	//   _dààm, pgör, --, --, 
   {{0x6d5ccf76,0x7cf026ff,0xf96802bf,0x60cc01e7}},	//   _utpa, _såre, дрій_, _áimé, 
   {{0xdd2c0316,0x7cf00ac7,0x395001a6,0x658806be}},	//   pěšn, _påre, _duzs_, _təhz, 
   {{0x5fc003e5,0x0b440022,0x7cf0007c,0x00000000}},	//   शियल, _аҽан, _fårb, --, 
   {{0x7cf0cf77,0xeb341178,0x56900c60,0x00000000}},	//   _våre, _سىزد, гашт, --, 
   {{0x212800a9,0x65880213,0xf8ac7bf7,0x613c00ef}},	//   ylch_, _yəhy, _кө_, _kūlt, 
   {{0xd9400075,0x7cf008d7,0x7e74009d,0x955030cd}},	//   _беси, _tåre, zazp, دخوا, 
   {{0x2904009d,0xc78400db,0x7e74cf78,0x00000000}},	//   mioa_, _جازۉ, yazp, --, 
   {{0xf78803ee,0x27e4cf79,0x13f002f6,0x290401c0}},	//   _іçі_, myon_, узья, lioa_, 
   {{0x6d58063f,0xc1780024,0x917001c0,0x21280036}},	//   ̣tar, usė_, лгэц, tlch_, 
   {{0x26dccf7a,0x290401c4,0x28c40807,0xc5ec09b2}},	//   _hoto_, nioa_, _रोमि, जनीय_, 
   {{0x26dccf7b,0x6d58cf7c,0x2d98004e,0x27e464fe}},	//   _koto_, ítan, _aqpe_, nyon_, 
   {{0x26dc0451,0x290401c4,0xc1780064,0x00000000}},	//   _joto_, hioa_, psė_, --, 
   {{0x26dc2173,0x7e74cf7d,0x1ccc031c,0x2904009f}},	//   _moto_, razp, _ྱོད_, kioa_, 
   {{0x26dccf7e,0x7cf00ac8,0x2904009d,0x27e404ce}},	//   _loto_, _sårb, jioa_, kyon_, 
   {{0x27e40699,0x2904cf7f,0xf8b040bf,0x26dc01e1}},	// [114b0] jyon_, dioa_, یکر_, _ooto_, 
   {{0x26dccf80,0x2730025a,0x60dc0309,0x3ce80219}},	//   _noto_, yâna_, _hoqm, skav_, 
   {{0x29047d5e,0x7cf03402,0x853c0153,0x00000000}},	//   fioa_, _vårb, _apėm, --, 
   {{0x60dc014f,0x2904009d,0x27e4022e,0x668001d5}},	//   _joqm, gioa_, fyon_, ییقل, 
   {{0x27e4066d,0x2b480333,0x60dc047e,0x00000000}},	//   gyon_, _fibc_, _moqm, --, 
   {{0xd6d8cf81,0x60dccf82,0x2b480048,0xb6a4cf83}},	//   яте_, _loqm, _gibc_, тикл, 
   {{0x27e422d0,0x290401c4,0x95c802dd,0x26dccf84}},	//   ayon_, bioa_, яуда_, _doto_, 
   {{0x27e44430,0x81c8015b,0x60dc022e,0x27308f78}},	//   byon_, োনা_, _noqm, râna_, 
   {{0xf69815ed,0x27e4cf85,0x1fc80490,0xd83801c0}},	//   _овај_, cyon_, ामोड, _хэв_, 
   {{0x26dccf86,0x98a00064,0x8af003b9,0x00000000}},	//   _goto_, _ėję_, lpər, --, 
   {{0x60dc1ffc,0xf1d098c5,0x28c407f7,0xc4c40133}},	//   _boqm, рөлө, _रोडि, _ڕتوو, 
   {{0x26dccf87,0x8af00213,0x61080118,0xafe401d5}},	//   _zoto_, npər, yřle, вомл, 
   {{0x60dc014f,0xb87c0115,0x98bc0356,0x249400f2}},	//   _doqm, _toŭf, _ziuă_, _شنود_, 
   {{0x2904152d,0x0204005e,0x00000000,0x00000000}},	//   zioa_, _өзін, --, --, 
   {{0x27e445b4,0xeab000dd,0xde00119e,0xb910002b}},	//   zyon_, یٹر_, апри, bhoḥ_, 
   {{0x27e4208d,0x2904009d,0x853c0064,0x7c840063}},	//   yyon_, xioa_, _apėj, луђе, 
   {{0xeab8010b,0x9d4000ee,0xef181188,0xeb9800c7}},	// [114c0] мйа_, ретд, _оми_, ьиа_, 
   {{0x6b801ebd,0x27e4aac5,0x00000000,0x00000000}},	//   šogo, vyon_, --, --, 
   {{0x26dc1243,0x2904cf88,0x60dc01b9,0x7c2800b5}},	//   _roto_, tioa_, _yoqm, _øern, 
   {{0x27e402bd,0xe7840953,0xdbd801e1,0x00000000}},	//   tyon_, вуко, _wàám, --, 
   {{0xa2b005ba,0x26dccf89,0x290405f5,0x27e4409c}},	//   _असल्, _poto_, rioa_, uyon_, 
   {{0x290405f5,0xbb280ed1,0xdb0c0120,0x26dc0014}},	//   sioa_, ﻤﯩﻦ_, _escâ, _qoto_, 
   {{0x27e49dff,0x290401c0,0xc45801c0,0x7cf03b3b}},	//   syon_, pioa_, нийх_, _håra, 
   {{0x75380100,0x7cf04bc1,0x44b407b5,0x95c41cd0}},	//   _chwz, _kåra, убис, туша_, 
   {{0x60dc0455,0x853c0064,0x3868035b,0x26000b27}},	//   _roqm, _upėm, ñare_, _वेरी_, 
   {{0x2d881068,0x26dcc46e,0x27300311,0x60dc016d}},	//   krbe_, _uoto_, mâno_, _soqm, 
   {{0x6d580008,0x60dc014f,0x00000000,0x00000000}},	//   ítal, _poqm, --, --, 
   {{0x6384cf8a,0x60dc047e,0xa3e80798,0x00000000}},	//   _агда, _qoqm, _одеа_, --, 
   {{0x60dc047e,0x100400ee,0xe3b01a4b,0x00000000}},	//   _voqm, аярм, _خرا_, --, 
   {{0x60dc0455,0x00000000,0x00000000,0x00000000}},	//   _woqm, --, --, --, 
   {{0x60dc0477,0x91e0009b,0x00000000,0x00000000}},	//   _toqm, _воје, --, --, 
   {{0x8c6400a8,0x5180cf8b,0x23b417c6,0x853c0024}},	//   итуд, _туша, _अनाद, _spėj, 
   {{0x7b1401c0,0xdef801ec,0x8b588d1a,0x78bc1d1d}},	// [114d0] гдах, _жын_, نجلس_, _ósvi, 
   {{0x8c44026a,0x38c8c8b6,0x7cf0bb54,0x00000000}},	//   ређе, کائی_, _dåra, --, 
   {{0xae3401c0,0xca241d39,0x8d8401d5,0x3eb000e5}},	//   _бүрт_, афци, _куяд, mezt_, 
   {{0x7cf0007c,0x28c400cd,0x00000000,0x00000000}},	//   _fåra, _रोदि, --, --, 
   {{0x66180227,0x69d801e1,0x00000000,0x00000000}},	//   _axtk, _àten, --, --, 
   {{0xb384016c,0x853c0153,0x8ae40024,0x3eb000e5}},	//   қлол, _upėj, _кісл, nezt_, 
   {{0x75d4107b,0xd5ac01ed,0x58e001ec,0x09e400db}},	//   ايعا, تہا_, _پۋشك, _коён, 
   {{0x26000574,0x588465a7,0x58000131,0x335400db}},	//   _वेळी_, _шыга, _پۈتك, гүдө_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd6d8036b,0x0574cf8c,0x394c01c4,0x00000000}},	//   _ўта_, _چاند, _hies_, --, 
   {{0x394ccf8d,0x13a432de,0xb144355a,0x0574cf8e}},	//   _kies_, رنگی_, лнол, _ناند, 
   {{0x8f8449d2,0xa6e000fc,0x24040131,0x6d5800e4}},	//   ақил, _öðru, _әнши_, ítam, 
   {{0x394ccf8f,0x34940022,0x00000000,0x00000000}},	//   _mies_, _ааҵр, --, --, 
   {{0x394c782e,0x31640175,0x00000000,0x00000000}},	//   _lies_, pplz_, --, --, 
   {{0x26c80077,0x229010e0,0x394c06af,0x2d88005a}},	//   _óboe_, _الىس, _oies_, urbe_, 
   {{0x394ccf90,0x30740166,0xdb0c03e0,0x7cf00055}},	//   _nies_, _сукс, _ercü, _påra, 
   {{0x80d00d2c,0x2d8801fa,0x853c0064,0x00000000}},	// [114e0] धारे, srbe_, _spėk, --, 
   {{0x7cf0049f,0xaa440724,0x394c06af,0x1c400276}},	//   _våra, гезл, _aies_, снум, 
   {{0x394c0549,0xe9681a92,0xba040124,0x00000000}},	//   _bies_, хаел_, аҭра_, --, 
   {{0xdb0c9972,0x394ccf91,0x7cf001e6,0x67380023}},	//   _escà, _cies_, _tåra, _shtj, 
   {{0x66e48fd9,0xc5ec503c,0x2cb0058a,0xad2400db}},	//   лода, जन्य_, meyd_, _لىگى, 
   {{0x394c08fb,0x2cb0058a,0x8884cf92,0xc4480133}},	//   _eies_, leyd_, _چیان, ۆیان_, 
   {{0xc4486b5d,0x394c02c1,0xdb2001ed,0x88841e4b}},	//   چیان_, _fies_, _óráj, _نیان, 
   {{0xc4488375,0x394c1c1d,0x2cb0cf93,0x6368cf94}},	//   نیان_, _gies_, neyd_, нрог_, 
   {{0xb3540e3f,0x9cd40375,0xe7885d62,0x7800014b}},	//   لینا_, רופה_, _سپاه_, _мӯша, 
   {{0x2cb001d9,0x61f803fa,0xfd5001f2,0x7d0001ed}},	//   heyd_, tztl, gedọ, élsz, 
   {{0xd1c4013e,0xe61406ed,0xa2d40807,0x2cb0058a}},	//   гуяд_, _сфаќ, बाब्, keyd_, 
   {{0x61f80112,0x84540131,0x00000000,0x00000000}},	//   rztl, _ئىشچ, --, --, 
   {{0x92e00183,0x44200124,0x2cb00009,0x69c801bf}},	//   _নগৰ_, _âi_, deyd_, åfej, 
   {{0xbe64007b,0x00000000,0x00000000,0x00000000}},	//   شهري, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x557400c8,0x2cb00009,0x212c01e7,0x00000000}},	//   טעלן_, geyd_, _ógh_, --, 
   {{0x3a7456ff,0x394ccf95,0x4ba80228,0x8fe401e0}},	// [114f0] илар, _ries_, лөрү_, _ләрҙ, 
   {{0x394ccf96,0xfcd40092,0x05b40d79,0xc30803d4}},	//   _sies_, ጨበጫ_, ंबाब, _ৰীতি_, 
   {{0x28c40d41,0x394c1590,0x2cb00009,0x00000000}},	//   _रोहि, _pies_, beyd_, --, 
   {{0x394c0135,0x8af006be,0x00000000,0x00000000}},	//   _qies_, lqəl, --, --, 
   {{0x1be4006c,0xdb0c09ff,0xd83801c0,0x7cf0072b}},	//   _сўнг, _escá, хэж_, _håro, 
   {{0xf744a261,0x394c1196,0x70b000bc,0x00000000}},	//   шело, _wies_, _जस्ल, --, 
   {{0x394ccf97,0x8aa402bf,0xaad00316,0x33240051}},	//   _ties_, _уряд, सारक, volx_, 
   {{0xb384cf98,0xf428cf99,0x24500116,0x00000000}},	//   алил, койл_, ينىس, --, 
   {{0x78a803ac,0x836407d6,0x76b87de7,0x00000000}},	//   _ibev, یدیل, _илар_, --, 
   {{0x03a847ed,0x7304004e,0xe2c4cf9a,0x6d5803f2}},	//   اديو_, рпоз, альд_, ítak, 
   {{0xa6e002d2,0x00000000,0x00000000,0x00000000}},	//   _æðav, --, --, --, 
   {{0x33240ac5,0xa5600424,0x6d580115,0x00000000}},	//   solx_, _بگون, ŭtak, --, 
   {{0x78a8004c,0x00000000,0x00000000,0x00000000}},	//   _mbev, --, --, --, 
   {{0x3244cf9b,0x2cb0cf93,0xf1d001ee,0x00000000}},	//   _келг, weyd_, _дөмө, --, 
   {{0x2d9c20ef,0xed582c1d,0x78a8cf9c,0x6c740022}},	//   îte_, тоб_, _obev, иуах, 
   {{0x61ec1512,0x00000000,0x00000000,0x00000000}},	//   øble, --, --, --, 
   {{0x7cf00ac8,0xec48cf9d,0x2cb00067,0xdbc4002f}},	// [11500] _tårn, тзал_, reyd_, rößt, 
   {{0x78a853ff,0x09b0025c,0x7cf0007c,0xbf6401c8}},	//   _abev, _དགྱ_, _fåro, _اديو, 
   {{0x2a7800d8,0x69240b37,0x00000000,0x00000000}},	//   rapb_, амжа, --, --, 
   {{0xc5f8cbfe,0x3eac0989,0xf988cf9e,0xdd8c03e6}},	//   ңға_, đete_, اخله_, _کوێ_, 
   {{0x7d00017a,0x645c0166,0x00000000,0x00000000}},	//   ëlse, _şpio, --, --, 
   {{0x78a8cf9f,0x3af4010a,0x47b800cc,0x00000000}},	//   _ebev, _лясс, _আপদী, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfbc81944,0x883400e5,0x00000000,0x00000000}},	//   रियम, _اکائ, --, --, 
   {{0xc1b801c0,0x00000000,0x00000000,0x00000000}},	//   глох_, --, --, --, 
   {{0x8af000ac,0xfcd41954,0x00000000,0x00000000}},	//   vqəl, ጨበጠ_, --, --, 
   {{0xb9f007db,0x6568cfa0,0x00000000,0x00000000}},	//   _ሓደ_, mpfh, --, --, 
   {{0x7cf014f5,0xc43400ec,0xca3802dd,0xa01803b9}},	//   _dårl, _اباڻ, _ﺗﺎﺱ_, lgöz, 
   {{0xfd7405f5,0x9290030d,0xe3b000ec,0xa490072d}},	//   йлгэ, _дашц, _هرڻ_, _ایکت, 
   {{0x24840109,0x7cf005ac,0x8de8cfa1,0xfca804a2}},	//   _kdom_, _fårl, афта_, лсақ_, 
   {{0x7cf003cd,0xccf80063,0x06c40154,0x28c4190e}},	//   _våro, аћу_, ্সটি, _रोलि, 
   {{0xdd2c00bc,0x113c0375,0xe4ec000d,0x00000000}},	// [11510] _těžb, _בתהל, _जवनि_, --, 
   {{0xfeb816a4,0x645c00a2,0x00000000,0x00000000}},	//   _слој_, _şpil, --, --, 
   {{0xd8740137,0x2fc4025c,0x00000000,0x00000000}},	//   لاشب, _ġogi_, --, --, 
   {{0x7cf00158,0xe0dccfa2,0x5884cfa3,0x79a4010b}},	//   _kårm, njò_, рыжа, ирҗе, 
   {{0x7d0ccfa4,0x23640211,0x00000000,0x00000000}},	//   mias, _ntoj_, --, --, 
   {{0x7d0ccfa5,0xe0dc0268,0x2484cfa6,0xe7b000d1}},	//   lias, hjò_, _adom_, سمىد, 
   {{0x23640113,0x4b240131,0x05680114,0x00000000}},	//   _atoj_, _بېلە, ајњи_, --, 
   {{0x78a8cfa7,0x00000000,0x00000000,0x00000000}},	//   _ubev, --, --, --, 
   {{0x24840219,0x387c03cb,0xd6d8022e,0x00000000}},	//   _ddom_, mawr_, _итж_, --, 
   {{0x7d0ccfa8,0x2484cfa9,0x7cf0050a,0x23600ad9}},	//   hias, _edom_, _sårl, íkja_, 
   {{0x672402d2,0xb6341291,0x312400db,0x00000000}},	//   _íkja, _افاع, йдог, --, 
   {{0x387c00a9,0x23640240,0x69c80fac,0x7d0ccfaa}},	//   nawr_, _ftoj_, åfei, jias, 
   {{0x43702f7c,0x7cf078d0,0xd10405d7,0xe454010f}},	//   _قۇير, _vårl, शोषण_, _הינט_, 
   {{0xc8f407d0,0x75280d27,0x3f5c004d,0xc2c40b24}},	//   _आत्म_, loez, _dìu_, _ويني, 
   {{0xee300451,0xca4001ec,0x00000000,0x00000000}},	//   سٽر_, _ﯞﻋﺎ_, --, --, 
   {{0x7d0ccfab,0x1d0406ed,0xe0dc067c,0x00000000}},	//   gias, беси_, rmòc_, --, 
   {{0x2bc8cfac,0x6a8401c6,0xb60002d2,0x6e44cfad}},	// [11520] ылап_, йлаа, _óáfe, _گندم, 
   {{0xaad003f8,0x752801a4,0x69d8002e,0x7d0c000d}},	//   साइक, hoez, _àtek, aias, 
   {{0x3f5c026c,0x387c0368,0x1e54011a,0x6278010f}},	//   _zìu_, fawr_, _לשיר_, רנענ, 
   {{0x2730084c,0x6f0ca4bd,0x92c00183,0xada400d7}},	//   mâni_, libc, _একো_, _chúť, 
   {{0x09e000bd,0x752801c4,0xa09808a8,0x3f5c0208}},	//   _যেখা, doez, רינט, _xìu_, 
   {{0x97740588,0x4cc00154,0xdc34010f,0x00000000}},	//   стцә, _একটু, _לאכט_, --, 
   {{0x25a805d4,0x9f4c1700,0x36880220,0xe5c40108}},	//   ادتي_, _ågå_, рсін_, ссло, 
   {{0x98a0052f,0x18a0cfae,0xe8f800ee,0x291401d3}},	//   _нисе, _насм, _ёла_, _اورآ, 
   {{0xe73803b7,0x66740244,0xd9408cd0,0x00000000}},	//   _беа_, _هدار, _хети, --, 
   {{0xfbc82a09,0x3f5c001e,0x6f0c02a8,0x9bb8010f}},	//   रितम, _rìu_, jibc, נציפ, 
   {{0x7ae005d5,0x75280083,0x8ed00183,0x35c40107}},	//   _òlte, boez, ৱসাগ, _мафҳ, 
   {{0x672808fb,0x2484cfaf,0x5064cfb0,0xa2d4043e}},	//   lofj, _udom_, зтра, बाह्, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x63a01cdf,0xdef8cfb1,0x7cf0cfb2,0x7d0c033f}},	//   _iqon, уым_, _vårm, wias, 
   {{0x7d0ccfb3,0x27300356,0x387c0142,0xaad009ab}},	//   tias, gâni_, yawr_, साईक, 
   {{0x25bc00c0,0x00000000,0x00000000,0x00000000}},	//   _mstl_, --, --, --, 
   {{0x2128cfb4,0x6b94035b,0x6f0c0139,0x9e7c0408}},	// [11530] moch_, guyg, bibc, _пынă_, 
   {{0x6298cfb5,0xda640491,0x75280451,0x63a0401f}},	//   ngto, صائي, zoez, _mqon, 
   {{0xb9b4cfb6,0x7d0ccfb7,0x62980472,0x25bc0f85}},	//   تماع, pias, igto, _nstl_, 
   {{0x2128cfb8,0x63a0cfb9,0x7d0c0113,0xd6100137}},	//   noch_, _oqon, qias, үздө, 
   {{0x7d1c0196,0x7cf0072b,0x387c0142,0x21280332}},	//   _ijss, _lårk, rawr_, ioch_, 
   {{0x2128cfba,0xdb20035c,0x52b401ad,0xdd2c0118}},	//   hoch_, _روزی, _असेस, něžn, 
   {{0x63a0cfbb,0x212801a2,0x6298009a,0x7528cfbc}},	//   _aqon, koch_, dgto, toez, 
   {{0x2128cfbd,0xd7f80209,0x336401b9,0x6298cfbe}},	//   joch_, _йуз_, овиг, egto, 
   {{0x2128cfbf,0x7528cfc0,0xd7f865c2,0x67280158}},	//   doch_, roez, _сув_, bofj, 
   {{0xf6f4cfc1,0x27f003cd,0x62981141,0x853c0153}},	//   _بزرگ, øyne_, ggto, _spėt, 
   {{0x25bc0cf9,0x63a06f4f,0xf0e83256,0x7cf003cd}},	//   _gstl_, _eqon, لىدى_, _vårj, 
   {{0x2bb80316,0x2128cfc2,0x61ec0158,0xe5040451}},	//   _उनला, goch_, øbla, _وڊيو_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3cf804cc,0xe29467a6,0x7158b062,0x6d4800d8}},	//   _alsv_, _даш_, _крис_, _éfaz, 
   {{0xddc00262,0x7cf0050a,0x6cc4cfc3,0x2128cfc4}},	//   мбри, _kårh, ойва, boch_, 
   {{0x2128cfc5,0x6b940810,0x853c0153,0x2bd403ce}},	//   coch_, tuyg, _upėt, ठमला, 
   {{0xeb98cfc6,0x7cf00b1a,0xdd2c0118,0xef1800c0}},	// [11540] риз_, _mårh, běžn, _вмп_, 
   {{0x7cf003cd,0x52b40401,0x00000000,0x00000000}},	//   _lårh, _असोस, --, --, 
   {{0x0cd804c5,0x7768127b,0xed580063,0xbf64158b}},	//   _সতীত, _atex, _њом_, _ودیو, 
   {{0xeb98398a,0x28d80303,0xe8f800f0,0x00000000}},	//   _ким_, णाधि, јлд_, --, 
   {{0x1cb4011a,0xe818cfc7,0xbb440150,0x00000000}},	//   _ולכל_, جزات_, _ﻘﻭﻩ_, --, 
   {{0x77680036,0x21284d9a,0x00000000,0x00000000}},	//   _dtex, zoch_, --, --, 
   {{0x7cf0007c,0xb0c82efd,0x28d800dc,0xb8d400db}},	//   _bårh, ियाग, णादि, تتەش, 
   {{0x69cccfc8,0xd54400f7,0xd9400137,0xa2b00303}},	//   _irbe, يلوو_, _жеси, _असङ्, 
   {{0xa68402d7,0x69cc09a8,0x77680175,0x212800d0}},	//   _млад, _hrbe, _gtex, voch_, 
   {{0xe7386673,0x2128101d,0x68e001a6,0x04fc0154}},	//   _тез_, woch_, ljod, ুকের_, 
   {{0x62980942,0x212801f1,0x1a98008f,0x8354a268}},	//   rgto, toch_, סיטע, _کپتا, 
   {{0x68e0cfc9,0x7cf00efa,0x00000000,0x00000000}},	//   njod, _vårk, --, --, 
   {{0x2128cfca,0x63a01cdf,0xdd2c00bc,0x93c801d9}},	//   roch_, _uqon, těžn, _پانہ_, 
   {{0x69cccfcb,0x2128cfcc,0x42540101,0x00000000}},	//   _orbe, soch_, _عنبر, --, 
   {{0xb87c01e4,0x62882076,0x2128cfcd,0x7cf00267}},	//   _boŭl, _idfo, poch_, _håri, 
   {{0x7cf02d75,0x6aac02d0,0x2128047e,0x00000000}},	//   _kåri, _abbf, qoch_, --, 
   {{0x69dccfce,0x00000000,0x00000000,0x00000000}},	// [11550] expe, --, --, --, 
   {{0x3f98cfcf,0x3dc401ec,0x00000000,0x00000000}},	//   musu_, _ермұ, --, --, 
   {{0x3f98cfd0,0x7768010a,0x6288010a,0xc984af08}},	//   lusu_, _stex, _mdfo, дучи, 
   {{0x52b4acd2,0x68e0036e,0x00000000,0x00000000}},	//   _अस्स, gjod, --, --, 
   {{0x69cccfd1,0x3f98cfd2,0xecb00032,0x62880030}},	//   _erbe, nusu_, _яҡты, _odfo, 
   {{0x7cf02b96,0x78ac00cd,0x00000000,0x00000000}},	//   _sårh, _śivā, --, --, 
   {{0x3f9816cb,0x28c4012c,0x77680175,0x00000000}},	//   husu_, _रोकि, _wtex, --, 
   {{0x7984cfd3,0x00000000,0x00000000,0x00000000}},	//   mshw, --, --, --, 
   {{0x3ea0cfd4,0x776800ca,0x3f98cfd5,0x7cf003cd}},	//   _ocht_, _utex, jusu_, _vårh, 
   {{0x3f981ae4,0x7984009f,0x3ea0002f,0xc7c401d5}},	//   dusu_, oshw, _ncht_, _ўсти, 
   {{0xc6a41607,0x7984cfd6,0xe28c00c7,0x00000000}},	//   _юрти, nshw, _ҿа_, --, 
   {{0x3ea0cfd7,0x79846a6c,0x7cf0143a,0x3f98cfd8}},	//   _acht_, ishw, _fåri, fusu_, 
   {{0xe28ccfd9,0xf0e80dd8,0x798404ba,0x3f98701f}},	//   _па_, لىگى_, hshw, gusu_, 
   {{0xdb0c9223,0xddc82ba3,0x613c00cd,0x00000000}},	//   _escú, çişl, _mūly, --, 
   {{0x273000a8,0x3ea4cfda,0x249001e1,0x00000000}},	//   mânt_, òlta_, _ínmó_, --, 
   {{0x3ea0cfdb,0xab640c98,0xeb9807d6,0xef84cfdc}},	//   _echt_, звал, йиб_, _елип, 
   {{0x3f98cfdd,0x69cc5946,0x28c42a67,0x68e00165}},	// [11560] cusu_, _srbe, _रोगि, vjod, 
   {{0x8eb40075,0x79840032,0x6b40045f,0x6d58cfde}},	//   _تەست, fshw, kôge, ítas, 
   {{0xeb98013e,0x59b000db,0x00000000,0x00000000}},	//   риҷ_, нөтс, --, --, 
   {{0x6d5c0e07,0x69cccfdf,0x2200cfe0,0x684400d8}},	//   _iupa, _vrbe, _héhé_, пнеа, 
   {{0x68e0003d,0x6d5ccfe1,0xe738cfe2,0xa6c8cfe3}},	//   rjod, _hupa, бед_, йлда_, 
   {{0x6d5ccfe4,0x7cf0007c,0x00000000,0x00000000}},	//   _kupa, _råri, --, --, 
   {{0x69cccfe5,0x6d5c2e95,0x69d801f1,0x7ae005d5}},	//   _urbe, _jupa, _štef, _òlta, 
   {{0x6d5ccfe6,0xb8640979,0xc8f801b9,0x3f981cce}},	//   _mupa, _ياقو, _بورچ_, yusu_, 
   {{0x6d5ccfe7,0xd4640640,0x3f98cfe8,0x00000000}},	//   _lupa, чиње_, xusu_, --, 
   {{0xd36ccfe9,0x6d5ccfea,0x7cf0007c,0xd7f8011a}},	//   _үч_, _oupa, _våri, _ההמל, 
   {{0xa5083678,0x6d5ca4c0,0xdce81674,0x425402e9}},	//   _лежа_, _nupa, _žiča, بندر, 
   {{0x64a4cfeb,0x3f98cfec,0x7cf03bdc,0x3ea00036}},	//   _хада, tusu_, _hårv, _scht_, 
   {{0x6d5ccfed,0x7cf003cd,0x6288010a,0x6ce402dd}},	//   _aupa, _kårv, _tdfo, _ﺍﺠﺘﻴ, 
   {{0x3f98cfee,0x6288019b,0x6d5cc55a,0x33680345}},	//   rusu_, _udfo, _bupa, _بلوێ_, 
   {{0x3f982173,0x69c801a8,0x2730045f,0x7d00017a}},	//   susu_, æfel, lâns_, ëlso, 
   {{0x6d5ccfef,0x3f98cff0,0xd1cc044e,0x65780142}},	//   _dupa, pusu_, ባብቲ_, _mwth, 
   {{0x6d5c54b2,0xd00815ed,0x3b54cff1,0x65780142}},	// [11570] _eupa, _неће_, дкар, _lwth, 
   {{0x7e98cff2,0x798454ef,0x5f4004a9,0x3ea014c8}},	//   _بندر_, tshw, _سۆزل, _ucht_, 
   {{0x6d5ccff3,0x2730002d,0x3c58cff4,0x00000000}},	//   _gupa, hâns_, _минэ_, --, 
   {{0x79840066,0x2730002d,0x00000000,0x00000000}},	//   rshw, kâns_, --, --, 
   {{0x65780493,0x6d5ccff5,0x00000000,0x00000000}},	//   _awth, _zupa, --, --, 
   {{0x6d5ccff6,0x2730002d,0x6578015d,0x27f005ac}},	//   _yupa, dâns_, _bwth, øyna_, 
   {{0x27300276,0x66e0399b,0x00000000,0x00000000}},	//   vânt_, тоща, --, --, 
   {{0x6d480395,0x69d8009b,0x87d800cf,0x00000000}},	//   _èfat, _šteg, تبۅس_, --, 
   {{0x6578cff7,0x7cf001bf,0x7bcc005b,0x28c421f2}},	//   _ewth, _fårv, nvau, _रोटि, 
   {{0x7bcccff8,0x6578015d,0x55605f32,0x06f408f2}},	//   ivau, _fwth, _كۇتك, _अवयव_, 
   {{0x3f880421,0x2200003e,0x657803cb,0x7cf0007c}},	//   _avau_, _réhé_, _gwth, _håru, 
   {{0x6d5ccff9,0x8af006be,0x50a40116,0x00000000}},	//   _rupa, lqət, رەخل, --, 
   {{0x6d5ccffa,0xf2a4cffb,0x6004518e,0x00000000}},	//   _supa, _жилп, дням_, --, 
   {{0x3f8800dc,0xed58cffc,0xdb200248,0x00000000}},	//   _dvau_, жов_, _ìrèl, --, 
   {{0x6d5c03f0,0x2ca00175,0xf1b0000d,0x00000000}},	//   _qupa, _pckd_, _जहिन, --, 
   {{0x6d5c02b9,0x80a400cd,0x61b401f7,0x00000000}},	//   _vupa, _काये, _آهيس_, --, 
   {{0xd1cc0023,0x2d8000d1,0x00000000,0x00000000}},	// [11580] ባእቲ_, _ﺩﯨﻨﻰ_, --, --, 
   {{0x6a1404d3,0xf1b005d7,0x1e806584,0x00000000}},	//   وبار, _जहान, _ильм, --, 
   {{0x6d5ccffd,0x80a411a6,0x7bcc01f4,0x00000000}},	//   _uupa, _कामे, avau, --, 
   {{0xd6cc0014,0x00000000,0x00000000,0x00000000}},	//   یقن_, --, --, --, 
   {{0x7640010b,0x6d4400c5,0xe72800f1,0x7cf0002b}},	//   _azly, _ihka, يستو_, _pårv, 
   {{0x6b94017a,0xe7e40118,0x77905cfc,0x00000000}},	//   mryg, _těžš, ایلا, --, 
   {{0xf8accffe,0x49940451,0x7cf00efa,0xe8f800f3}},	//   _йө_, _سڌار, _vårv, _длв_, 
   {{0x7cf0005c,0x4dc000cc,0x00000000,0x00000000}},	//   _fåru, _উপাং, --, --, 
   {{0x6d4402c4,0x77906c71,0x42a40131,0x9f4401c7}},	//   _mhka, _مینا, нунғ, éiën_, 
   {{0x574001fc,0x7cf017b8,0x27302326,0xa5d8009a}},	//   _ануб, _hårt, râns_, _وبار_, 
   {{0x2fd000e4,0x7cf00158,0x7bcc0433,0x6d44cfff}},	//   _aryg_, _kårt, zvau, _ohka, 
   {{0x1604146c,0x2fd0463d,0x7bcc0153,0x6b94d000}},	//   _वेटर_, _bryg_, yvau, kryg, 
   {{0x7cf001e6,0x6044d001,0x386802d1,0x40940214}},	//   _mårt, ьхоз, ñari_, ولگر, 
   {{0x2fd010d1,0x6d44d002,0x764000a2,0x00000000}},	//   _dryg_, _ahka, _yzly, --, 
   {{0x6d44020b,0x32fc0209,0x81d41086,0x92980375}},	//   _bhka, yňyz_, _чойх, _ויות, 
   {{0x23d000dc,0xa2d405f9,0x6d446ea3,0x6b94005c}},	//   तिपद, बाक्, _chka, fryg, 
   {{0x2fd00142,0x6b9412e8,0x6d440200,0xabb40022}},	// [11590] _gryg_, gryg, _dhka, натә, 
   {{0x7bccd003,0x6d4403b9,0xbf1004b4,0x00000000}},	//   rvau, _ehka, _сүгә, --, 
   {{0x6d440270,0x7bcc023a,0xaacc01f9,0xd1081888}},	//   _fhka, svau, _होळक, _رقیه_, 
   {{0xf770d004,0x6440d005,0x38680165,0xd214011a}},	//   هات_, _ozoi, ùar_, וקבק_, 
   {{0x6440090c,0x3668bc3c,0x32040e21,0x16800133}},	//   _nzoi, пало_, zzly_, ناغێ, 
   {{0x291c0241,0x00000000,0x00000000,0x00000000}},	//   _ìtan_, --, --, --, 
   {{0x64400099,0xf8b045cc,0x00000000,0x00000000}},	//   _azoi, _مکش_, --, --, 
   {{0xc98410fc,0x7cf001bf,0x60c80332,0x00000000}},	//   _јури, _tåru, _ógmh, --, 
   {{0xe3b40962,0x2bd01df1,0xe81402e5,0xe7780022}},	//   ебы_, सिया, _दइया_, _натә_, 
   {{0x8af003be,0x4dc002f5,0x6440d006,0x7cf0d007}},	//   qqət, _উপসং, _dzoi, _kårs, 
   {{0xe3c4013d,0x07083cc6,0xb59400d8,0x00000000}},	//   _үрчү, _تيلي_, _чиеш, --, 
   {{0x7cf0005c,0x05742a8b,0x6b944b36,0x00000000}},	//   _mårs, _شامد, yryg, --, 
   {{0x2518010f,0x2240012d,0x32040210,0x00000000}},	//   _צונא, ękka_, szly_, --, 
   {{0x6d44069c,0x00000000,0x00000000,0x00000000}},	//   _shka, --, --, --, 
   {{0xe814068f,0xa0180108,0x6b940042,0x6d240108}},	//   _देना_, laöl, wryg, едвз, 
   {{0x6b940aab,0xa0a00364,0x2fd000b5,0x14400092}},	//   tryg, _баъд, _tryg_, _የታሰሩ, 
   {{0xf1c80016,0xac080261,0x710000c7,0x00000000}},	// [115a0] _hạ_, чнаа_, _аҧҟа, --, 
   {{0x6b94d008,0x34bc00dc,0x6d4400b0,0xe8140037}},	//   rryg, ्युद, _whka, _दइबा_, 
   {{0x69d80010,0x22f4010f,0x00000000,0x00000000}},	//   _šteb, עזען_, --, --, 
   {{0x6d4402f6,0xf1c801fb,0xa0180108,0xfc6407a5}},	//   _uhka, _mạ_, kaöl, _аъён, 
   {{0xf1c80016,0x7cf0b4cd,0x00000000,0x00000000}},	//   _lạ_, _vårt, --, --, 
   {{0xe5c49187,0x7cf001e3,0x00000000,0x00000000}},	//   есио, _fårs, --, --, 
   {{0x7cf00d74,0xf1c8001e,0x75c8054a,0x00000000}},	//   _tårt, _nạ_, дтың_, --, 
   {{0x6abcd009,0xd9d00014,0x35c4012d,0x70c817ee}},	//   lepf, _حٲفظ, विज़, ियोल, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf1c8001e,0x6abc0810,0x23d02d3b,0x81d4d00a}},	//   _bạ_, nepf, तिबद, воох, 
   {{0x7cf003cd,0xf1c80208,0x00000000,0x00000000}},	//   _mårr, _cạ_, --, --, 
   {{0xf1c8001e,0x6abcd00b,0x01a800d1,0xd36c00ec}},	//   _dạ_, hepf, пкүк_, _ڇهن_, 
   {{0xe3c80789,0x64400810,0xa348d00c,0x50f40a89}},	//   _dañó_, _uzoi, _езда_, узят, 
   {{0x3ea400dd,0x1ee4034c,0x6abcbff9,0xbe0401ed}},	//   ült_, روزی_, jepf, پورٹ, 
   {{0x6abc020c,0xf1c8004d,0xa6e00174,0x00000000}},	//   depf, _gạ_, _æðuv, --, 
   {{0x5634008f,0xd23805d0,0x00000000,0x00000000}},	//   גאלע_, _מגול, --, --, 
   {{0xdb203463,0x628c0034,0x7cf003cd,0x6ac80154}},	// [115b0] هوری, óbow, _sårs, রানো, 
   {{0x0a68d00d,0xbdc00131,0x6abcb970,0x00000000}},	//   ерци_, _پەرۋ, gepf, --, 
   {{0xf1c8001e,0xe814000d,0x00000000,0x00000000}},	//   _xạ_, _देबा_, --, --, 
   {{0x38c800dd,0x7cf01511,0x2bb80037,0x00000000}},	//   بائی_, _vårs, _उनचा, --, 
   {{0xb6a4d00e,0x6abc002f,0x00000000,0x00000000}},	//   вилл, bepf, --, --, 
   {{0xab600075,0xa01801f4,0x00000000,0x00000000}},	//   _ئۇلى, vaöl, --, --, 
   {{0x32180209,0x49c800c0,0x00000000,0x00000000}},	//   şsyz_, _плён_, --, --, 
   {{0xd87410e0,0xf1c80208,0x3ce80219,0x34bc00cd}},	//   _سارب, _rạ_, njav_, ्येद, 
   {{0x38680054,0x775410a7,0xf1c80051,0xf348009d}},	//   ñaru_, _акаф, _sạ_, мпил_, 
   {{0x2bd0258d,0x3ce80477,0x2918012d,0x00000000}},	//   सिता, hjav_, ązał_, --, 
   {{0x99e000ee,0x03a80244,0x00000000,0x00000000}},	//   _öňde, ودیو_, --, --, 
   {{0xf1c8004d,0x69c803b2,0x00000000,0x00000000}},	//   _vạ_, æfei, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf1c8001e,0x02c4009d,0x00000000,0x00000000}},	//   _tạ_, _бишү, --, --, 
   {{0x386cd00f,0x3f980ffb,0xad58d010,0xdee019ba}},	//   _ofer_, arsu_, драх_, шори, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xaf04d011,0x6abc006f,0xaf2801b9,0xc0c80063}},	// [115c0] _аппл, tepf, _ожиз_, _чује_, 
   {{0x386cd012,0xaf34007b,0x00000000,0x00000000}},	//   _afer_, _جربت, --, --, 
   {{0xdb0c0077,0x80c400bd,0x7cf03bb0,0xf96800d4}},	//   _ascó, ষার্, _vårr, ерій_, 
   {{0xe8f800fd,0x34bcd013,0x6abc002f,0x00000000}},	//   ьле_, ्योद, sepf, --, 
   {{0x98a062bd,0x66e4d014,0x00000000,0x00000000}},	//   риче, кода, --, --, 
   {{0x386c011f,0x7cf00450,0x00000000,0x00000000}},	//   _efer_, _hårp, --, --, 
   {{0xdb0cd015,0x386c017a,0xe2a402d2,0x00000000}},	//   _escó, _ffer_, _æðir_, --, 
   {{0x2cb0015d,0x00000000,0x00000000,0x00000000}},	//   nfyd_, --, --, --, 
   {{0x7cf00158,0x83340395,0xd7bc012d,0x29040051}},	//   _mårp, лних, _एनएच, mhoa_, 
   {{0x80a4033d,0xdc34008f,0x2cb0015d,0x27e401b9}},	//   _काहे, כאפט_, hfyd_, mxon_, 
   {{0x26dc8a83,0xe8140d5f,0x32080198,0xe4c4036b}},	//   _into_, _देता_, _ƙaya_, _аёлн, 
   {{0x2904d016,0x51f42f6a,0xf1a81046,0x24480241}},	//   nhoa_, тнюю_, راپه_, _ẹmu_, 
   {{0x9440121e,0x4394d017,0x2904d018,0xb7d40055}},	//   _پھٹن, _салс, ihoa_, _kṣai, 
   {{0x80a477ca,0x14200139,0x3f980327,0x29040051}},	//   _कावे, _әдәм, rrsu_, hhoa_, 
   {{0x29040184,0x0f24040e,0x3f980198,0x27e401d5}},	//   khoa_, рьям, srsu_, hxon_, 
   {{0xd138035b,0x3eac0118,0x27e401a9,0x2cb00142}},	//   _ихы_, řet_, kxon_, gfyd_, 
   {{0x0fe4302a,0x2b480013,0x26dc0375,0xa19004a9}},	// [115d0] _көрү, _bhbc_, _onto_, _сақч, 
   {{0x386cd019,0x27e401b9,0x00000000,0x00000000}},	//   _sfer_, dxon_, --, --, 
   {{0xed4c9105,0xb0a805c0,0x00000000,0x00000000}},	//   تھی_, _कामग, --, --, 
   {{0x26dcd01a,0x00000000,0x00000000,0x00000000}},	//   _anto_, --, --, --, 
   {{0x97a458f0,0x27e4002e,0xe6900131,0x00000000}},	//   трел, gxon_, ڭلىد, --, 
   {{0xa3d4375c,0xdb0c2508,0x290400b0,0x00000000}},	//   ाटन_, _escò, ahoa_, --, 
   {{0x7c3c0432,0x00000000,0x00000000,0x00000000}},	//   _hysr, --, --, --, 
   {{0x2904d01b,0x26dcd01c,0x386c0ade,0x58b802dd}},	//   choa_, _ento_, _ufer_, _تاسج_, 
   {{0x78a8d01d,0x18b00131,0x34bc095f,0x00000000}},	//   _icev, _бәһр, ्यौद, --, 
   {{0xa0646f78,0x2f04002d,0x81cc0011,0xafe401d5}},	//   ғара_, _kôge_, রমন_, ҳомл, 
   {{0x78a80165,0x3494d01e,0x550401a9,0x00000000}},	//   _kcev, _баер, _ичда, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7c3c4d29,0x80a40e5b,0x78a801bf,0xb0a801ad}},	//   _nysr, _कारे, _mcev, _काठग, 
   {{0x6da40262,0xada4d01f,0x7cf00fac,0xc04c0092}},	//   лига, лагл, _sårp, _በፕሮግ, 
   {{0x78a805a1,0x7c3c035a,0x27e401d5,0x00000000}},	//   _ocev, _aysr, zxon_, --, 
   {{0xdca00075,0x27e401a9,0x64440254,0x00000000}},	//   йаси, yxon_, ükig, --, 
   {{0x7cf01f53,0x9d400835,0x00000000,0x00000000}},	// [115e0] _vårp, сетд, --, --, 
   {{0x78a83a6c,0x2f04000f,0x7c3c045a,0x00000000}},	//   _acev, _bôge_, _dysr, --, 
   {{0x2904d020,0x692c01e4,0xaa840419,0x00000000}},	//   thoa_, nĝeg, jtýž, --, 
   {{0x27e4d021,0xe93840bb,0x588000cf,0x290401f4}},	//   txon_, رسات_, быша, uhoa_, 
   {{0x2794d022,0x0684013e,0x29040108,0x00000000}},	//   ушер, иҳан, rhoa_, --, 
   {{0x27e401b9,0x26dc00d8,0x2904d023,0x78a803e0}},	//   rxon_, _qnto_, shoa_, _ecev, 
   {{0x80a4d024,0x09880c60,0x27e401d5,0x00000000}},	//   _काले, _шавқ_, sxon_, --, 
   {{0xe8540014,0x97743c1a,0xe0dc0100,0x44f400d1}},	//   _منزد, _әттә, nmòt_, рпис, 
   {{0x228400db,0xa69416a4,0x27e401a9,0x00000000}},	//   лунг, _бреј, qxon_, --, 
   {{0x26dcd025,0xe0dc067c,0xadf400e1,0x61ec01f4}},	//   _unto_, ològ_, ीनान_, äblo, 
   {{0x38681050,0xb5a8007b,0x5a9800df,0x8c2800cc}},	//   žare_, _لانك_, עשטא, _মৰমন_, 
   {{0x256801c3,0x80a40073,0x00000000,0x00000000}},	//   _iùl_, _काळे, --, --, 
   {{0x64440254,0x00000000,0x00000000,0x00000000}},	//   ükid, --, --, --, 
   {{0xfd74152d,0x4ea401c6,0x00000000,0x00000000}},	//   илгэ, йрса, --, --, 
   {{0x69d80419,0x24840c6a,0x7c3c0175,0xac700241}},	//   _šten, _keom_, _sysr, _ọlọs, 
   {{0x6e3c0fac,0xc1780153,0x9f1401d3,0x61f8d026}},	//   _dypb, mpė_, ئےگا_, mytl, 
   {{0x78a80327,0x7b14d027,0x5bdc078a,0x4ae00a59}},	// [115f0] _rcev, адах, नमेव, नांव, 
   {{0x78a83eb9,0x248401ab,0x7c3c02f0,0x41a8000d}},	//   _scev, _leom_, _vysr, _कमास, 
   {{0xd91801c0,0x00000000,0x00000000,0x00000000}},	//   ньд_, --, --, --, 
   {{0xb87c01e4,0xe81454cb,0xc1780153,0x00000000}},	//   _roŭs, _देहा_, ipė_, --, 
   {{0x37e4d028,0xdb04772a,0x61f800a2,0x00000000}},	//   ролг, álód, hytl, --, 
   {{0x2f04002d,0x61f800a2,0x00000000,0x00000000}},	//   _tôge_, kytl, --, --, 
   {{0xb87c01e4,0x25680e89,0x6b40000f,0xa018002f}},	//   _doŭr, _cùl_, kôgj, lböd, 
   {{0xb46425f8,0xe81407b6,0x78a8014b,0x2d9c3881}},	//   шкил, _देवा_, _ucev, šteg_, 
   {{0x394c01c6,0x2484d029,0xa018002f,0xa4d40114}},	//   _ihes_, _deom_, nböd, рдњу_, 
   {{0x236400df,0xd344015e,0x00000000,0x00000000}},	//   _duoj_, دیته_, --, --, 
   {{0xf8c81b6e,0x394c0211,0x32443767,0x248406d9}},	//   _रसाय, _khes_, ренг, _feom_, 
   {{0x33d4063b,0x24840395,0x628cd02a,0x692c01e4}},	//   _вікт, _geom_, óbor, rĝeg, 
   {{0x03680220,0xa9340375,0x00000000,0x00000000}},	//   _биік_, שטרה_, --, --, 
   {{0xd5e01682,0x394cd02b,0xa8540302,0x23d0000d}},	//   haṋ, _lhes_, יירה_, तिरद, 
   {{0x71a401c0,0xe2d82586,0x6d1400c7,0xad3800d4}},	//   _тайз, _جانچ_, афах, вчає_, 
   {{0x6f6416a4,0x3074c891,0x6da40818,0x64440210}},	//   _квиз, _тукс, лиҳа, żkie, 
   {{0x81cc00bd,0x6a8401c6,0x00000000,0x00000000}},	// [11600] রমণ_, илаа, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x5e98011a,0x802400f2,0x2d8c0241,0xb0a80118}},	//   _בביק, _نریم, _ìfe_, _कााग, 
   {{0x394c7c8d,0x00000000,0x00000000,0x00000000}},	//   _ches_, --, --, --, 
   {{0x394c020c,0x24840165,0x256801c3,0xf8a80b24}},	//   _dhes_, _reom_, _sùl_, ادمه_, 
   {{0x97103334,0xab2803c5,0xd73400d4,0x69240022}},	//   оміц, _рога_, апії_, ымҵа, 
   {{0x442000a8,0x24840109,0x00000000,0x00000000}},	//   _ţi_, _peom_, --, --, 
   {{0x394c014f,0xc4480214,0x95d402e8,0x98a000d8}},	//   _ghes_, هیان_, рдът_, _мисе, 
   {{0xdcec07f5,0x14a400e1,0x00000000,0x00000000}},	//   žeće, _गारण, --, --, 
   {{0xb3540066,0x00000000,0x00000000,0x00000000}},	//   مینا_, --, --, --, 
   {{0xd624d02c,0x98ac005f,0x7ad8010f,0x394c1b99}},	//   _кофе_, logā_, אַרה, _yhes_, 
   {{0x25bc01c8,0x61f8d02d,0x23640024,0xd254782a}},	//   _iptl_, rytl, _tuoj_, шцы_, 
   {{0x4420035b,0x88d800cc,0x00000000,0x00000000}},	//   _ãi_, _থকাক, --, --, 
   {{0x62643832,0x692c010f,0x216400db,0xbb9002dd}},	//   _ئاشق, nĝeb, _ктиг, _ﺟﻪﻛﻪ_, 
   {{0xb1440014,0x8d6800d8,0x00000000,0x00000000}},	//   _گیَم_, ијта_, --, --, 
   {{0xc684004b,0x00000000,0x00000000,0x00000000}},	//   _ښې_, --, --, --, 
   {{0xb7d40882,0xbab801c0,0xe814007d,0x2d9c642b}},	// [11610] kṣam, лгах_, _देला_, àter_, 
   {{0x394c0f85,0x00000000,0x00000000,0x00000000}},	//   _shes_, --, --, --, 
   {{0x7e6402d0,0x9c800427,0x7c286b92,0x00000000}},	//   _ighp, _ščuk, _žerd, --, 
   {{0xa3d406e3,0x49b8ba4f,0x80c40011,0x00000000}},	//   ाटा_, شامد_, ষাক্, --, 
   {{0xb0a80034,0x69c8d02e,0x394c00e4,0x387c015d}},	//   _कासग, æfer, _vhes_, rbwr_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x394cd02f,0x98ac0b23,0xdcf8375c,0x9cf8009e}},	//   _thes_, aogā_, _एकाध_, ীচীন_, 
   {{0xb9249fb1,0x7af4a586,0x81cc0154,0xc9844623}},	//   _افري, _hozt, রমা_, _фури, 
   {{0x7e64047e,0xd7840345,0x00000000,0x00000000}},	//   _oghp, _ئۆتو_, --, --, 
   {{0x7af40010,0x9600004e,0x00000000,0x00000000}},	//   _jozt, _мүлж, --, --, 
   {{0x7af4d030,0x7c9002d3,0x139c00d1,0x00000000}},	//   _mozt, _ክጽሕፍ_, _ﺋﻪﮬﯟ, --, 
   {{0x5550211f,0xc324004e,0x00000000,0x00000000}},	//   _بھتر, ймөк, --, --, 
   {{0xc50c00c8,0xa2d000dc,0x764001f4,0x8fc40022}},	//   _בלאָ, _भोक्, _hyly, әаҳҵ, 
   {{0x77600054,0x80c4009e,0x69d84b16,0x76400432}},	//   _jilx, ষাগ্, _štem, _kyly, 
   {{0x42b800db,0x644c033f,0xde000166,0x6230009b}},	//   _ئنىڭ_, ębie, ппри, _нељу, 
   {{0x7e64014f,0xe0dc00a3,0xb018072d,0xb7f808df}},	//   _eghp, smòr_, _مآخذ_, ्नाम_, 
   {{0x7af4d031,0x00000000,0x00000000,0x00000000}},	// [11620] _bozt, --, --, --, 
   {{0xaa881eeb,0xd1d802d3,0xf5380419,0xa018007c}},	//   انام_, _ንሞት_, hoť_, taöv, 
   {{0x7af4005a,0x00000000,0x00000000,0x00000000}},	//   _dozt, --, --, --, 
   {{0x58809c36,0x6cc42a9d,0xa01801e3,0x7c280171}},	//   пыша, _уйма, raöv, _žere, 
   {{0x31b000dd,0x7760d032,0x7640010b,0xe0dc067c}},	//   ház_, _bilx, _ayly, llòc_, 
   {{0x6b400b21,0x1a780014,0x6a840cdd,0x7640d033}},	//   kôgi, _مشِک_, _ылга, _byly, 
   {{0x38680b91,0x98ac0618,0xa2d0d034,0x7760427b}},	//   žara_, sogā_, _भोग्, _dilx, 
   {{0x69cc01d9,0x7af4005a,0x76400142,0xa018002f}},	//   _isbe, _zozt, _dyly, nböc, 
   {{0x791807d6,0x77600023,0xa804009b,0x9f6000e5}},	//   _тўрт_, _filx, _узал, ívül_, 
   {{0x6d540369,0x20040055,0x00000000,0x00000000}},	//   hmya, _āni_, --, --, 
   {{0x69d8151c,0x764000ee,0xf538012c,0xa01849a2}},	//   _štej, _gyly, boť_, kböc, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb0a81533,0xa0180267,0x44206695,0xe3b00451}},	//   _कारग, dböc, _äi_, _ڀرڻ_, 
   {{0x65600069,0x6440020c,0x93400408,0x776001a9}},	//   _hioh, _iyoi, _енче, _xilx, 
   {{0x7af4a3f5,0x65600270,0x6440020c,0x6b8402d0}},	//   _rozt, _kioh, _hyoi, _awkg, 
   {{0x65600198,0xbc78d035,0x64400175,0x91e00063}},	//   _jioh, рбах_, _kyoi, _хоће, 
   {{0x7af4d036,0x656006d9,0x810800aa,0x200c119a}},	// [11630] _pozt, _mioh, _مرکې_, _ågi_, 
   {{0x6288d037,0x6d540067,0x00000000,0x00000000}},	//   _jefo, amya, --, --, 
   {{0x628800fb,0x6d540369,0x7768037e,0xca740131}},	//   _mefo, bmya, _suex, سالغ, 
   {{0x6288d038,0xd23800df,0x00000000,0x00000000}},	//   _lefo, נגאל, --, --, 
   {{0x7d0cd039,0xecb001e0,0x7640010e,0x31b001d3}},	//   mhas, _юҡты, _syly, záz_, 
   {{0x7d0c066d,0x7760208d,0x7bdc02d0,0x05180154}},	//   lhas, _qilx, _irsu, ডকোর_, 
   {{0x6560d03a,0xceb406a9,0xb0a80b7c,0x00000000}},	//   _bioh, פיק_, _कालग, --, 
   {{0x7d0cd03b,0x62880270,0x656001ab,0x7bdc0158}},	//   nhas, _aefo, _cioh, _krsu, 
   {{0x6288d03c,0x776001a9,0xd6a8d03d,0x00000000}},	//   _befo, _tilx, _مدام_, --, 
   {{0x7d0c9742,0x6444d03e,0x69ccd03f,0x7640023a}},	//   hhas, ükia, _ysbe, _tyly, 
   {{0x6288d040,0x7d0cd041,0x04c86ea9,0x00000000}},	//   _defo, khas, _گوني_, --, 
   {{0x6288009a,0x7bdcd042,0x69d8d043,0x656004cc}},	//   _eefo, _orsu, _štek, _gioh, 
   {{0x7528d044,0x7d0cd045,0x6288d046,0x6d540270}},	//   mnez, dhas, _fefo, vmya, 
   {{0x6288d047,0xa3d40d54,0xb4c80f4a,0x7d0cb061}},	//   _gefo, ाटर_, _लघु_, ehas, 
   {{0x7bdcd048,0x7d0c0084,0x7528d049,0xa018007c}},	//   _arsu, fhas, onez, tböc, 
   {{0x8494044e,0x6288d04a,0x75280489,0xec78d04b}},	//   _ፍትሕን_, _zefo, nnez, рпа_, 
   {{0x6d54d04c,0x6288d04d,0x7528002f,0xa01801e3}},	// [11640] rmya, _yefo, inez, rböc, 
   {{0xb0a8d04e,0x6d5448dd,0xe0dc068c,0x69d81d0e}},	//   _काँग, smya, plòc_, _átek, 
   {{0x6d5404ce,0x7bdcd04f,0xfbd001d3,0x99e00432}},	//   pmya, _ersu, وتے_, _öňle, 
   {{0x7d0cd050,0x61ec0112,0x00000000,0x00000000}},	//   chas, äbli, --, --, 
   {{0x6560d051,0xa6c8d052,0x69cc0142,0x6fc810eb}},	//   _rioh, илда_, _wsbe, िबिं, 
   {{0x69cc01ee,0x65600093,0x7528d053,0x00000000}},	//   _tsbe, _sioh, enez, --, 
   {{0xb0a8d054,0x69ccd055,0xe4a44a2e,0x2bd00a94}},	//   _कांग, _usbe, орпо, सिका, 
   {{0x7bdc003a,0x98ac054e,0xa2d0002b,0x00000000}},	//   _yrsu, rogă_, _भोज्, --, 
   {{0x6288d056,0xd9400640,0x25e400e1,0x00000000}},	//   _pefo, _цети, _झपकी_, --, 
   {{0x20d401fb,0xa6a82f84,0x752805c7,0xd5e40014}},	//   _ủi_, _خارق_, anez, _ژٹٕن_, 
   {{0xd48cd057,0x6288d058,0x67280158,0x257001b9}},	//   _ор_, _vefo, mnfj, _ўқис, 
   {{0x7d0cd059,0x6288d05a,0x4034d05b,0x6578d05c}},	//   xhas, _wefo, земс, _itth, 
   {{0x7d0cd05d,0x6288d05e,0x2328d05f,0x6440014b}},	//   vhas, _tefo, _коди_, _uyoi, 
   {{0x6728d060,0x98acd061,0x319400ef,0x00000000}},	//   nnfj, mogą_, bāz_, --, 
   {{0x7d0cd062,0x67280158,0x98ac0024,0xdc88d063}},	//   thas, infj, logą_, исал_, 
   {{0x80a46859,0x80c4015b,0x7bdc16a3,0x2e28001f}},	//   _काटे, ষাঙ্, _prsu, ደሚያመ, 
   {{0x7d0cd064,0xd00800f3,0x00000000,0x00000000}},	// [11650] rhas, _меће_, --, --, 
   {{0x657800dd,0x3f880286,0x7bdc003a,0x8fc40014}},	//   _otth, _iwau_, _vrsu, _کٲین, 
   {{0x7d0cd065,0x75280165,0x4aac00bc,0x00000000}},	//   phas, ynez, _चारव, --, 
   {{0x7d0c0054,0x212804e6,0x00000000,0x00000000}},	//   qhas, nnch_, --, --, 
   {{0x65786ad0,0x7bdcd066,0x2128039a,0x7d1c02d0}},	//   _atth, _ursu, inch_, _imss, 
   {{0x7bcc0099,0x67280158,0x00000000,0x00000000}},	//   mwau, gnfj, --, --, 
   {{0x18b00022,0x7bccd067,0xa5f40063,0x35a401d5}},	//   _жәлр, lwau, зеју_, чайг, 
   {{0x3f8818a6,0x391498a4,0x6728045f,0x7bcc009f}},	//   _owau_, _эмбр, anfj, owau, 
   {{0x7528d068,0x65780055,0x212801ab,0x84940023}},	//   rnez, _etth, dnch_, _ፍትሒን_, 
   {{0x212804cc,0x77f800e1,0x692c00df,0xd5b83cc5}},	//   ench_, ्नीक_, nĝen, _всд_, 
   {{0x3f880374,0x7bcc01ee,0x161c0764,0xf0e80131}},	//   _awau_, hwau, _बधिर_, مىدى_, 
   {{0x7bccd069,0x752806be,0x00000000,0x00000000}},	//   kwau, qnez, --, --, 
   {{0x9f840086,0x4aac0490,0x7fd41ac3,0xe4d402f2}},	//   _bòñe_, _चालव, мірі, _رووت_, 
   {{0x657800eb,0x7d1c03ac,0x161c000d,0x00000000}},	//   _ytth, _amss, _बधार_, --, 
   {{0x80a40073,0xc3040345,0x00000000,0x00000000}},	//   _काचे, _زبوو, --, --, 
   {{0xdbb8891e,0xa01801a8,0x69d803b2,0x70846be1}},	//   әттә_, mbön, _átei, _эгиз, 
   {{0xeb98d06a,0x3f880042,0xeb04004e,0x00000000}},	// [11660] сиз_, _gwau_, ппап, --, 
   {{0xe8140034,0x7d1c03ac,0xee0829c6,0x00000000}},	//   _देगा_, _emss, _геол_, --, 
   {{0x3f880943,0xa3d0012c,0x6f1cb4fe,0xfd1000f1}},	//   _zwau_, _हैन_, _impc, رجې_, 
   {{0x1cc8025c,0xe87001d5,0x00000000,0x00000000}},	//   _ཊིར_, رنتگ, --, --, 
   {{0xe8140abd,0x2ef80730,0xdcf40276,0x692c0115}},	//   _देखा_, _kopf_, şcăr, bĝen, 
   {{0xeb3401ec,0xa018007c,0x65780051,0x7c2802d2}},	//   _رىزد, kbön, _ptth, _þera, 
   {{0x2ef8002f,0x6b9401bf,0x00000000,0x00000000}},	//   _mopf_, lsyg, --, --, 
   {{0x65c400c7,0x6b4000e4,0xa018032e,0x00000000}},	//   _ҭбаа, rôgu, dbön, --, 
   {{0x2a68020b,0x6b94d06b,0x290401f7,0x6f1c03ac}},	//   _kgbb_, nsyg, mkoa_, _ompc, 
   {{0x290477e5,0x21280042,0xe50800ec,0xa6c800f2}},	//   lkoa_, wnch_, _ڏيئو_, _دوئل_, 
   {{0x2904d06c,0x25e400ab,0x6578d06d,0xa01800e5}},	//   okoa_, _झपटी_, _utth, gbön, 
   {{0x29045191,0x21281caa,0x6f1c0857,0x644c00ac}},	//   nkoa_, unch_, _ampc, əbin, 
   {{0xb90801f2,0x2904d06e,0x00000000,0x00000000}},	//   _aghọ_, ikoa_, --, --, 
   {{0x7d1c00d0,0x6b94005c,0x2904005b,0xf8c807f7}},	//   _smss, dsyg, hkoa_, _रस्प, 
   {{0x2d9c04b9,0x2904049b,0x8f343acc,0x00000000}},	//   šten_, kkoa_, херц, --, 
   {{0x6f1c0393,0x31780244,0x00000000,0x00000000}},	//   _empc, _بجوک_, --, --, 
   {{0xf1a40323,0xa018006a,0x7bcc01f5,0xbf340138}},	// [11670] _ерөн, mböo, uwau, _онищ, 
   {{0x2904005a,0x7bccd06f,0xe8700023,0x00000000}},	//   ekoa_, rwau, _ብሓገዝ_, --, 
   {{0x30a401ed,0xc0d40023,0x692c010f,0x00000000}},	//   _علیہ, _ርሑስ_, rĝen, --, 
   {{0x2ce40156,0x386805ac,0x7d1cd070,0x2ef8002f}},	//   _ཤོགབ, øar_, _umss, _zopf_, 
   {{0x64440254,0x00000000,0x00000000,0x00000000}},	//   ükil, --, --, --, 
   {{0x290418a6,0xcf940677,0xb6a401d5,0x00000000}},	//   akoa_, גטס_, фикл, --, 
   {{0x69d80f72,0x00000000,0x00000000,0x00000000}},	//   _štev, --, --, --, 
   {{0x1cc80327,0x692c00df,0x73e428e8,0xa908022e}},	//   _ཊིས_, nĝel, доиз, spоr, 
   {{0x6b400109,0x662403e3,0x00000000,0x00000000}},	//   môgr, _əskə, --, --, 
   {{0xe9080327,0xbb4401ec,0x4e0000bc,0x86980153}},	//   _གཞོབ_, _ﺘﺭﻯ_, रहमै_, _нкус_, 
   {{0xe0dc01ab,0x047807d6,0xf1d0d071,0x00000000}},	//   rlòn_, غلیک_, төлө, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6b9401bf,0x7c2801ef,0x00000000,0x00000000}},	//   xsyg, _žern, --, --, 
   {{0x29040323,0x7f180006,0x6b9401bf,0xe8a800cd}},	//   zkoa_, пісу_, vsyg, _चञ्च, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6b94005c,0x2904005a,0x6fa80108,0x00000000}},	//   tsyg, xkoa_, _двиг_, --, 
   {{0xab64d072,0x2ef80e78,0x9d403298,0x6f1c0334}},	// [11680] двал, _topf_, тетд, _tmpc, 
   {{0x6b9400b5,0x50a400d1,0x6f1c03ac,0x98ac0210}},	//   rsyg, _تەڭل, _umpc, mogę_, 
   {{0x6b94d008,0x2904023a,0x7c28032e,0x98ac0064}},	//   ssyg, tkoa_, _þern, logę_, 
   {{0x290418a6,0x09540e56,0xd1680092,0x00000000}},	//   ukoa_, رىشڭ, _በጃፓን_, --, 
   {{0x2904d073,0xca7c022e,0xe7380868,0x7b0801d3}},	//   rkoa_, _ijrо, оед_, ástó, 
   {{0x290401c0,0x6444000d,0x00000000,0x00000000}},	//   skoa_, ükim, --, --, 
   {{0xda600334,0x00000000,0x00000000,0x00000000}},	//   _аври, --, --, --, 
   {{0x87500150,0x00000000,0x00000000,0x00000000}},	//   _ﯗﺩﻩﭖ_, --, --, --, 
   {{0x644c0034,0x692c0115,0x27340eff,0x00000000}},	//   ębio, nĝem, _قىرس, --, 
   {{0x692c01e4,0xd7f8011a,0x00000000,0x00000000}},	//   iĝem, _והמל, --, --, 
   {{0x2d9c00bc,0xd5ac446a,0x00000000,0x00000000}},	//   átel_, _نفل_, --, --, 
   {{0x01e400f7,0x64a43de2,0xa424010a,0x00000000}},	//   _үйдү, _цада, _оьлл, --, 
   {{0x2d9c02ae,0xd464009b,0x00000000,0x00000000}},	//   štel_, _жице_, --, --, 
   {{0x7c288256,0x00000000,0x00000000,0x00000000}},	//   _žero, --, --, --, 
   {{0xa3d43eaf,0xebc0535f,0xff1c00b5,0x53301219}},	//   ाटक_, һәрн, sのos_, _шешт, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3b540262,0xebc0d074,0xdef8d075,0xa3bc00c5}},	// [11690] екар, ләрн, _дын_, ँझि_, 
   {{0xe9080327,0xda483da1,0x93b4011a,0x00000000}},	//   _གཞུབ_, очел_, ולמו_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3834d076,0x9ba0113e,0x08d400d4,0x00000000}},	//   ннер, _لەرى, кція, --, 
   {{0x69d80bb8,0x3f98002e,0xea900150,0x5ab401a9}},	//   _štet, nssu_, _ﺟﯘﺭﯞ, _оқар_, 
   {{0x3f989c81,0xab600131,0x692c00df,0x00000000}},	//   issu_, _مۇقى, nĝej, --, 
   {{0x49740354,0x00000000,0x00000000,0x00000000}},	//   _алсс, --, --, --, 
   {{0xded402d3,0x48a8004e,0x00000000,0x00000000}},	//   _ርዱእ_, _отум_, --, --, 
   {{0x386cd077,0x37340006,0xd17c0092,0x00000000}},	//   _iger_, _знаё, _የተቋሙ_, --, 
   {{0xd5e80046,0xa018007c,0x00000000,0x00000000}},	//   _وعان_, rböl, --, --, 
   {{0x64d80490,0x3f980a55,0x7c2800f3,0x00000000}},	//   _मोकळ, essu_, _žerl, --, 
   {{0x70a83027,0x2d9c0118,0x12c40150,0x00000000}},	//   कलेल, átem_, _ﺒﻤﻬﺭ, --, 
   {{0x600402e8,0x6d580137,0x21f00137,0xf1d000db}},	//   еням_, ïtam, _ەكىس, _өөнө, 
   {{0x2d9c098d,0x386c1529,0x61ec00ae,0x00000000}},	//   štem_, _lger_, óilí, --, 
   {{0xed58d078,0x81d40276,0x386c0165,0x33240135}},	//   зов_, _ацыц, _oger_, milx_, 
   {{0x386cd079,0x40400521,0x62180375,0x00000000}},	//   _nger_, ụmịh, _מוצק, --, 
   {{0xbbe8007b,0x3204010e,0x10a4022e,0x00000000}},	// [116a0] وركم_, lyly_, _зиқн, --, 
   {{0x2c740241,0x4e1c015b,0x692c01e4,0x1c400107}},	//   _bùdó_, _দুঃখ_, rĝem, унум, 
   {{0x386c07c5,0xe8c8008e,0xec7800f3,0x00000000}},	//   _bger_, згел_, _нпн_, --, 
   {{0xe8f8d07a,0x22a40ca8,0xa018007c,0xa178010f}},	//   яле_, _kíkà_, dböj, לטעט, 
   {{0x6d44d07b,0xa09808a8,0x256802e2,0x6abc002f}},	//   _ikka, פיסט, kòlè_, pfpf, 
   {{0x386c09a5,0xe5b404b4,0x3204010e,0x00000000}},	//   _eger_, евкә_, kyly_, --, 
   {{0x3324025c,0xfd4c0208,0x612801f4,0x3204010e}},	//   dilx_, _nghỉ, nölä, jyly_, 
   {{0x77901afc,0xe9080327,0x154016a4,0x32040432}},	//   _چینا, _གཞིབ_, лејм, dyly_, 
   {{0xd4e009fe,0x7790429e,0x69c8008f,0xe32400d8}},	//   ующи, _نینا, ŭleĝ, еќно, 
   {{0xb3542c04,0x00000000,0x00000000,0x00000000}},	//   نینا_, --, --, --, 
   {{0x6d44d07c,0x41540120,0x2d9c0427,0x38540023}},	//   _okka, квос, štej_, _ዝሓሰብ, 
   {{0x26ccd07d,0x6d440280,0xdcdc0307,0x7c28009b}},	//   lefo_, _nkka, _पोंछ, _žerm, 
   {{0x3f986f24,0x25ac007f,0x3324031c,0xf1c400c7}},	//   ussu_, lufl_, bilx_, ñáre_, 
   {{0x545010f5,0x6d448928,0xc2c423bb,0x320400bc}},	//   _світ, _akka, _شيعي, byly_, 
   {{0x0dc8343d,0xe04801d5,0x692c01e4,0x72d00116}},	//   нути_, تشگه_, rĝej, _ئەپچ, 
   {{0x26ccd07e,0xd24c0050,0x3f980098,0x9f3c030d}},	//   hefo_, _دۆپ_, pssu_, _ӳснĕ_, 
   {{0x3ba0001f,0x0fe42347,0x60cc0205,0x8fe401af}},	// [116b0] ቃሴዎች_, _йөрү, mecm, _йәрҙ, 
   {{0x6d442252,0xbf1000fd,0xe820010b,0x00000000}},	//   _ekka, _түгә, _iňňä, --, 
   {{0x6d4403c1,0x69d88256,0xd3340375,0x00000000}},	//   _fkka, _šter, ערבה_, --, 
   {{0x9c6000db,0x60cc03e3,0x00000000,0x00000000}},	//   _مۇزو, necm, --, --, 
   {{0xb8c8d07f,0x26cc9181,0xe1b404ce,0x9e6404fb}},	//   _गए_, fefo_, _lコ_, _تاکن, 
   {{0x48c400c7,0xf8b000f2,0x00000000,0x00000000}},	//   кәӡа, _چکش_, --, --, 
   {{0x6d440008,0x98c4d080,0x386c05d5,0x00000000}},	//   _ykka, _псал, _tger_, --, 
   {{0x386c019b,0x7984009a,0x481401c6,0x00000000}},	//   _uger_, mphw, _өмсс, --, 
   {{0x76b8d081,0x23b0005e,0xe1b400b5,0x7c280219}},	//   _олар_, لميس, _aコ_, _žerj, 
   {{0x2d9c012c,0x1cc8031c,0x057403e6,0x22a40241}},	//   átek_, _ཊིཀ_, _ڵامد, _ríkà_, 
   {{0x934402d3,0x00000000,0x00000000,0x00000000}},	//   _ከባቢታ, --, --, --, 
   {{0x2d9cd082,0x79840810,0xafa001b9,0x00000000}},	//   štek_, iphw, ақиқ, --, 
   {{0xf31401c6,0x8fc800f1,0x00000000,0x00000000}},	//   _иддэ, رېدل_, --, --, 
   {{0x32440139,0x5f900454,0x612801f4,0x06440092}},	//   _иелг, риёт, tölä, _ሕንፃዎ, 
   {{0x0464104e,0xe56800a2,0x8fd4035b,0x00000000}},	//   _итәм, _üňüz_, тәқә, --, 
   {{0x692c01e4,0x26cc010f,0x612801f4,0x00000000}},	//   rĝek, zefo_, rölä, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [116c0] --, --, --, --, 
   {{0x612801f4,0x314c0092,0x9e2001e2,0x00000000}},	//   pölä, _ማህበር, اډیو, --, 
   {{0xfc3001d3,0xda6c01d9,0x00000000,0x00000000}},	//   لحے_, زُن_, --, --, 
   {{0x6d44198f,0xb9e400cf,0x00000000,0x00000000}},	//   _ukka, دسكى, --, --, 
   {{0x26ccd083,0xab64033f,0x1864d084,0x00000000}},	//   tefo_, _pożą, ваци_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x26cc0134,0x48c4013d,0xd5b400fb,0x00000000}},	//   refo_, _бәла, всы_, --, 
   {{0x26ccd085,0x00000000,0x00000000,0x00000000}},	//   sefo_, --, --, --, 
   {{0x2284004e,0x00000000,0x00000000,0x00000000}},	//   кунг, --, --, --, 
   {{0x16a40117,0x00000000,0x00000000,0x00000000}},	//   _авфи_, --, --, --, 
   {{0x60cc0077,0x64c400c6,0xf3f40244,0xbb4401ec}},	//   tecm, _ليال, نتیک, _ﺘﺭﻴ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc3c463ef,0x00000000,0x00000000,0x00000000}},	//   _сөйл, --, --, --, 
   {{0x4ea4d086,0x00000000,0x00000000,0x00000000}},	//   ирса, --, --, --, 
   {{0xe60c01ec,0xce9402e8,0xc1a401ec,0x00000000}},	//   йдi_, расъ, _сылқ, --, 
   {{0x06480020,0x8d847a83,0xd1c4013e,0xa3b40037}},	//   _ምንድነ, рурд, _рушд_, _छमा_, 
   {{0x81e40729,0x69d8d087,0x00000000,0x00000000}},	// [116d0] _নথি_, _štep, --, --, 
   {{0x46c400bc,0xf1a800cd,0x00000000,0x00000000}},	//   ल्मह, _किमन, --, --, 
   {{0xb6a401d5,0x38bc01d3,0x853c0064,0x00000000}},	//   ҳилл, járó_, _kvėd, --, 
   {{0xe0dcb503,0xa3d0007d,0x2c4800c0,0x58844130}},	//   ndò_, _हईं_, _bėdą_, тыжа, 
   {{0xb6a4d088,0xf50c00e5,0x00000000,0x00000000}},	//   гилл, اﺅں_, --, --, 
   {{0x7d0cd089,0xc9580131,0x33f400d1,0x00000000}},	//   lkas, ىلەش_, ғчис, --, 
   {{0x7d0cb730,0x00000000,0x00000000,0x00000000}},	//   okas, --, --, --, 
   {{0x68080171,0x657c01e7,0xd3a0d08a,0xa810008e}},	//   _bēdā, ípha, алиқ, рдәш, 
   {{0x7d0cd08b,0x38341d0b,0xe0dc026c,0xe7a40220}},	//   ikas, _снар, ddò_, _مۇنى_, 
   {{0x7d0c0f23,0x63a4d08c,0xe4545443,0x970000d1}},	//   hkas, ákna, ыжы_, _خېتى, 
   {{0xb9cc069c,0x85b81291,0x00000000,0x00000000}},	//   _ደኣ_, _لانس_, --, --, 
   {{0x05740058,0x7d0cd08d,0x38680fcf,0x61ec0158}},	//   _ئالد, jkas, žaru_, åbla, 
   {{0x75280489,0x00000000,0x00000000,0x00000000}},	//   miez, --, --, --, 
   {{0x7528d08e,0xfd64004d,0x00000000,0x00000000}},	//   liez, _truồ, --, --, 
   {{0x2d9cd08f,0x7d0cd090,0xe7d80034,0x82880055}},	//   éte_, fkas, _मैनप, _kṛṃṣ, 
   {{0x7d0c8d3b,0x752807e4,0x53b405d7,0xaac400bc}},	//   gkas, niez, _आमाश, र्नक, 
   {{0xafe418ac,0x38bc01d3,0x81cc0183,0x80244fca}},	// [116e0] _сопл, záró_, ৰমণ_, _پريم, 
   {{0x7d0cd091,0x2eb406dc,0xa85001e0,0xaf08007b}},	//   akas, _ссис, ҙелә, _أقدم_, 
   {{0xdab40451,0x00000000,0x00000000,0x00000000}},	//   اهمت_, --, --, --, 
   {{0x88840046,0x25a8168c,0xb87c00df,0xeda40022}},	//   рғал, _åbli_, _laŭf, _ишҭо, 
   {{0xa3d01b13,0x98a0b19d,0x75289677,0xb59c0150}},	//   _हैं_, сиче, diez, _ﺍﻹﻨﺘ_, 
   {{0xaa44d092,0x569098c5,0x00000000,0x00000000}},	//   _бегл, башт, --, --, 
   {{0xe5c4d093,0x75280489,0x368801ec,0x680800ef}},	//   усло, fiez, тсін_, _sēdā, 
   {{0x752803bd,0x7c28d094,0x680800de,0xb60408a5}},	//   giez, _žeri, _pēdā, _smáí, 
   {{0xded402d3,0xa2bc0327,0x00000000,0x00000000}},	//   ርድኦ_, _མཁྱཻ, --, --, 
   {{0x9bb800c8,0x682401d5,0xa18400ee,0xa3d0012d}},	//   עציפ, _tаdb, лымл, _हैः_, 
   {{0xaac410fa,0x7d0cd095,0x26dc0421,0x7528d096}},	//   र्यक, ykas, _iato_, biez, 
   {{0x2498b745,0x26dc0652,0x7528d097,0x7d0c0014}},	//   _أنشد_, _hato_, ciez, xkas, 
   {{0x26dcd098,0xe3140156,0xe0dcc5bf,0x7d0cd099}},	//   _kato_, ྲིདཔ_, rdò_, vkas, 
   {{0x1ee45311,0x26dcd09a,0xdef8539e,0xaac4102f}},	//   دوسی_, _jato_, хым_, र्मक, 
   {{0x7d0cd09b,0xd4540092,0x00000000,0x00000000}},	//   tkas, _የታዳጊ, --, --, 
   {{0x26dcd09c,0x6298d09d,0xf1a8068f,0x7d0c9154}},	//   _lato_, lato, _कितन, ukas, 
   {{0x7d0cd09e,0x2128d09f,0xa19001b9,0x9f68010a}},	// [116f0] rkas, mich_, _тақч, _проз_, 
   {{0x2128d0a0,0x60dc2a89,0x692c01e4,0x6eb0033f}},	//   lich_, _haqm, jŝeb, _जाएँ, 
   {{0x7d0cd0a1,0x60dc02d1,0x67280175,0x2128679d}},	//   pkas, _kaqm, difj, oich_, 
   {{0x6298d0a2,0x2128d0a3,0x26dcd0a4,0x7d0c0054}},	//   hato, nich_, _aato_, qkas, 
   {{0x6298d0a5,0x26dc2173,0x7528d0a6,0x97a40276}},	//   kato, _bato_, viez, урел, 
   {{0x26dc102c,0x2128d0a7,0x60dcd0a8,0x7528d0a9}},	//   _cato_, hich_, _laqm, wiez, 
   {{0x2128006d,0x6298d0aa,0x7528d0ab,0x2d9c09a8}},	//   kich_, dato, tiez, štev_, 
   {{0x2128076f,0x60dc047e,0x0a2c0208,0xf5040798}},	//   jich_, _naqm, _ýđịn, рзио, 
   {{0x6298d0ac,0x2128d0ad,0x752803bd,0x26dcd0ae}},	//   fato, dich_, riez, _fato_, 
   {{0x212801ab,0xe6b40372,0x00000000,0x00000000}},	//   eich_, _ەلەگ, --, --, 
   {{0x7528d0af,0xcb140302,0x60dc0477,0xe1f400a8}},	//   piez, מלץ_, _baqm, агэ_, 
   {{0x2128d0b0,0x95640c04,0xb87c01e4,0x6298d0b1}},	//   gich_, _създ, _daŭg, aato, 
   {{0x26dcd0b2,0x5edc11ba,0x60dc047e,0x64440037}},	//   _yato_, মানে, _daqm, ükit, 
   {{0x6298d0b3,0x26dc036b,0x212808c2,0x00000000}},	//   cato, _xato_, aich_, --, 
   {{0xde003678,0x21280100,0xad6496e0,0x00000000}},	//   опри, bich_, لاره, --, 
   {{0xac84d0b4,0x212801a2,0xb87c01e4,0x2008003a}},	//   ргал, cich_, _jaŭd, byci_, 
   {{0xc0d002d3,0xb87c01e4,0xeb9810e7,0x6728009a}},	// [11700] ብኦም_, _maŭd, тиз_, yifj, 
   {{0xb87c008f,0xfe7429e1,0xad2400d1,0x00000000}},	//   _laŭd, _гүр_, _چىدى, --, 
   {{0xa96801f0,0xc0d40023,0x00000000,0x00000000}},	//   вижа_, ርሕሉ_, --, --, 
   {{0x6298d0b5,0x26dcd0b6,0xb87c0115,0x60dc0009}},	//   zato, _sato_, _naŭd, _xaqm, 
   {{0x26dcd0b7,0x6298d0b8,0x692cd0b9,0xa818d0ba}},	//   _pato_, yato, tŝeb, ختار_, 
   {{0x6298003a,0x26dcce08,0x29d400ec,0x7790029e}},	//   xato, _qato_, _پيرس, سیما, 
   {{0x96f46d20,0x26dc0851,0x3ea4022c,0xaac4194b}},	//   شعور_, _vato_, ólti_, र्णक, 
   {{0x62980502,0x26dc3142,0xd940d0bb,0x44f4d0bc}},	//   wato, _wato_, _деси, спис, 
   {{0x2128d0bd,0x26dc1d27,0xaac408ec,0x62989024}},	//   vich_, _tato_, र्थक, tato, 
   {{0x68e0d0be,0xe5a419c9,0x60dcd0bf,0x62980393}},	//   ldod, _вижи, _saqm, uato, 
   {{0x27e4d0c0,0x2128d0c1,0x60dc016d,0x65b800d1}},	//   lvon_, tich_, _paqm, _шуар_, 
   {{0x68e0d0c2,0x644400c5,0x60dcd0c3,0x61b4033f}},	//   ndod, ükis, _qaqm, _अमीष, 
   {{0x2284d0c4,0x60dc014f,0x27e4921c,0x90280124}},	//   _куйг, _vaqm, nvon_, ацра_, 
   {{0x21280192,0x69ccd0c5,0xb87c008f,0x6298d0c6}},	//   sich_, _opbe, _taŭg, qato, 
   {{0x2128d0c7,0x63a006ea,0x68e00af9,0xa3d0033f}},	//   pich_, _hvon, kdod, हौर_, 
   {{0xd1b403e6,0x27e4010f,0x3eac0e2d,0x21281ffc}},	//   _ئاوا_, kvon_, şet_, qich_, 
   {{0xf378044e,0x68e00cfd,0x69cc00e2,0x7ac8009f}},	// [11710] _ኣተኵሮ_, ddod, _apbe, ُورِ_, 
   {{0x63a00099,0x9a8402dd,0x6b800332,0xbed80108}},	//   _mvon, руал, íoga, _сдох_, 
   {{0xb87c010f,0xf87415eb,0x59640107,0xaac404e4}},	//   _laŭe, مهاج, аъда, र्धक, 
   {{0x68e0d0c8,0x63a000f3,0xf1a802a0,0x6d58004e}},	//   gdod, _ovon, _किसन, ïtat, 
   {{0x69d8006a,0xe0dc00cf,0x69cc00a2,0x2d9c0010}},	//   _âten, llòs_, _epbe, štet_, 
   {{0x7bdcd0c9,0x8d749a87,0x61e801e4,0xc72402bf}},	//   _issu, _دایا, _orfl, одій, 
   {{0x63a0d0ca,0x0a680f5c,0x6e3c0332,0x7c280432}},	//   _avon, _врти_, _xxpb, _ýerb, 
   {{0xce381203,0x00000000,0x00000000,0x00000000}},	//   יאות_, --, --, --, 
   {{0xa3d00c2e,0x1cc8025c,0x61e808a5,0x335400db}},	//   हौल_, _ཊིན_, _arfl, бүдө_, 
   {{0x63a0d0cb,0x00000000,0x00000000,0x00000000}},	//   _dvon, --, --, --, 
   {{0xb1443004,0x41b402bf,0x321028d1,0x3244b3f0}},	//   йнол, осят, ázy_, сенг, 
   {{0xa3d02871,0x628c008c,0x04c84d49,0x81bc00ef}},	//   _हैक_, ðbor, _نومي_, dzēd, 
   {{0x61e82694,0x79940165,0x04c8d0cc,0x527000d1}},	//   _erfl, _lwzw, _خوني_, _һуқу, 
   {{0x692c00c8,0xe7f80574,0x68e0a3cc,0x61e80419}},	//   nĝer, ्हता_, zdod, _frfl, 
   {{0x63a00b9b,0xb638037e,0xe0dc0100,0xab2801ec}},	//   _zvon, _ｅｎ_, tlòt_, қожа_, 
   {{0x61400c9b,0x27e401b9,0xb87c00df,0x32600050}},	//   _неща, yvon_, _laŭb, _وچھہ, 
   {{0xe0dc067c,0x2a7401d3,0x644c0213,0x68e001d5}},	// [11720] rlòt_, مداح, əbis, vdod, 
   {{0x394c020c,0xa2c80882,0x7ed40212,0x6e3c0175}},	//   _akes_, त्प्, _діюч, _txpb, 
   {{0x7bdcd0cd,0xe0dc0137,0x7c280118,0xa01801e3}},	//   _essu, clòs_, _žert, sböt, 
   {{0x5edc0154,0xad246c68,0x00000000,0x00000000}},	//   মাণে, _چىگى, --, --, 
   {{0x68e0d0ce,0x66c8009d,0x00000000,0x00000000}},	//   rdod, гуйг_, --, --, 
   {{0x27e4d0cf,0x394c27be,0x612c02e2,0x68e001f5}},	//   rvon_, _ekes_, _kòlè, sdod, 
   {{0x63a0d0d0,0xb87c0115,0x66e40220,0x76a802bf}},	//   _svon, _daŭb, _қожа, ртів_, 
   {{0x562802d3,0x6924588c,0x9f4401ef,0x00000000}},	//   _እንኽእ, _умба, _ční_, --, 
   {{0xa0180112,0x5edc0154,0x00000000,0x00000000}},	//   hbör, মাতে, --, --, 
   {{0xdcec01e4,0x24e80075,0xf1a83885,0xa0180432}},	//   _vicĉ, _әмди_, _किशन, kbör, 
   {{0x2d9cd0d1,0xd48c5c83,0x4254009a,0x00000000}},	//   âtel_, _нр_, تندر, --, 
   {{0x63a006d1,0x657800a3,0xd5ac02f2,0x048811ca}},	//   _tvon, _iuth, _سفه_, _тәки_, 
   {{0x657801f7,0x4ad80cb4,0x63a0017a,0x38480023}},	//   _huth, ड़ाव, _uvon, _እናተጠ, 
   {{0x543800c8,0x612c02e2,0xb87c0115,0x00000000}},	//   _געדא, _bòlè, _kaŭc, --, 
   {{0xb9040327,0x657801d3,0x5270007b,0x6b8003b2}},	//   _ྨྲ_, _juth, _عاوز, íogn, 
   {{0x6578d0d2,0x40340064,0x7cd8041b,0x00000000}},	//   _muth, _мейс, јмар_, --, 
   {{0x6578d0d3,0xba9802bf,0xb87c0115,0xcc080014}},	// [11730] _luth, иває_, _laŭc, ٝزٕن_, 
   {{0x3f88d0d4,0x65780c8c,0xa0180e78,0x9f50033f}},	//   _itau_, _outh, bbör, ądów_, 
   {{0x65780066,0xae340b8d,0x5edc015b,0x2d9c9a64}},	//   _nuth, _дүрт_, মাদে, šter_, 
   {{0xe0a800fe,0x80c001f9,0x00000000,0x00000000}},	//   গ্ৰন, _वाफे, --, --, 
   {{0x6578d0d5,0x7bdcd0d6,0x9a840024,0xbe540092}},	//   _auth, _ussu, _губл, _መስጠታ, 
   {{0x6578d0d7,0x0648044e,0xdb203f64,0xa2c80a94}},	//   _buth, _ምሕዝነ, örän, त्म्, 
   {{0x65781ee5,0x00000000,0x00000000,0x00000000}},	//   _cuth, --, --, --, 
   {{0x3f88d0d8,0x6578d0d9,0xc9847a16,0x394c1445}},	//   _otau_, _duth, _хури, _ukes_, 
   {{0x3f880b89,0x6578d0da,0xaac40b33,0x78a8d0db}},	//   _ntau_, _euth, र्वक, _idev, 
   {{0x6578187d,0xe2c40246,0x7ae401ab,0x00000000}},	//   _futh, ольд_, ndht, --, 
   {{0x3f887020,0x6578d0dc,0x1328044e,0x7ae43e7c}},	//   _atau_, _guth, _ብወገነ, idht, 
   {{0xe56c10f5,0x95540199,0x23c40014,0x2d9c003a}},	//   _із_, _اخطا, _ژٕنہ, âtem_, 
   {{0x612c007f,0xf2a40117,0x00000000,0x00000000}},	//   _sòlè, _дилп, --, --, 
   {{0x2d941b04,0x6578d0dd,0xa0180267,0x222803e6}},	//   жрас, _yuth, tbör, ازیی_, 
   {{0x3f880924,0x78a8d0de,0xec98147e,0xa49401e4}},	//   _etau_, _odev, итај_, _soϲi, 
   {{0x78a8d0df,0xa018d0e0,0x25a800b5,0x311c00dc}},	//   _ndev, rbör, _æble_, _पतिः_, 
   {{0xa018d0e1,0xeb28d0e2,0xfa4800d1,0x00000000}},	// [11740] sbör, ажал_, ەشنى_, --, 
   {{0x78a80262,0x6a1478e3,0x00000000,0x00000000}},	//   _adev, يبار, --, --, 
   {{0xed58d0e3,0xaac41b2b,0xe72801e2,0xe8a400d1}},	//   _вон_, र्षक, یستو_, قماپ, 
   {{0x6578d0e4,0x7ae403d5,0x00000000,0x00000000}},	//   _ruth, adht, --, --, 
   {{0x29340046,0x3f882a1f,0xb87c00df,0x00000000}},	//   ﺗﯩﭗ_, _xtau_, _saŭc, --, 
   {{0x78a813fd,0x6d54d0e5,0x6578d0e6,0x77600076}},	//   _edev, llya, _puth, _chlx, 
   {{0x657801ee,0x6d541418,0xa968005a,0xf8ac004e}},	//   _quth, olya, _вива_, _пө_, 
   {{0x657807a9,0xab28020a,0x00000000,0x00000000}},	//   _vuth, _соҳа_, --, --, 
   {{0x65784861,0x6d540108,0x592003c7,0x00000000}},	//   _wuth, ilya, _تکلف, --, 
   {{0x65784ff5,0xded41b49,0x074801ed,0x78a80306}},	//   _tuth, ርትን_, _آئی_, _zdev, 
   {{0x3f88d0e7,0xf6780014,0x657803cd,0xda78010f}},	//   _stau_, _أمک_, _uuth, יניר, 
   {{0xb87c01e4,0x212800d4,0x61280fac,0xc6840345}},	//   _kaŭa, ріон_, рцог_, _بێژن_, 
   {{0x2484021a,0xa2e416c3,0x65600796,0x6d540009}},	//   _ifom_, _модд, _ihoh, dlya, 
   {{0xf650066d,0x65600af2,0xc4440543,0x764c0213}},	//   _آئے_, _hhoh, _ویژن_, şaye, 
   {{0x65600032,0xfca81870,0xb87c0115,0x6d54d0e8}},	//   _khoh, йсақ_, _laŭa, flya, 
   {{0xe0dc067c,0x51f001f7,0xddc400e5,0x00000000}},	//   clòp_, _آسور, ülőf, --, 
   {{0x2484013f,0x0ca80801,0xb87c01e4,0x6560014f}},	// [11750] _mfom_, ютри_, _naŭa, _mhoh, 
   {{0x6d541418,0xaac408e6,0x00000000,0x00000000}},	//   alya, र्लक, --, --, 
   {{0x6560d0e9,0x13d000bd,0x37c00154,0x7ae4036e}},	//   _ohoh, ়িয়, োয়ার, rdht, 
   {{0xa2c83af4,0xd25405d0,0x62a001e1,0x00000000}},	//   त्त्, חשבה_, _ńtó, --, 
   {{0x6cf80375,0xc8c822ad,0x9a840798,0x2e500023}},	//   _הפרס, تونن_, _мувл, _መስደመ, 
   {{0x2484d0ea,0x65600134,0xe7b00075,0x5a440153}},	//   _afom_, _ahoh, رمىد, _дэба, 
   {{0x65600055,0x80c00073,0xe73400c0,0x996c01ee}},	//   _bhoh, _वाढे, яеш_, _атаh, 
   {{0x65600842,0x78a8d0eb,0xe0e00154,0x692c0115}},	//   _choh, _udev, যাডভ, nŝel, 
   {{0xd6a8168d,0x65600009,0x98ac054e,0xe0dc02e2}},	//   _ندام_, _dhoh, angă_, vlòp_, 
   {{0x2484009a,0x6560009a,0xf6b40220,0xb224d0ec}},	//   _efom_, _ehoh, _ءماج, змол, 
   {{0x656001ab,0xd58403e6,0x00000000,0x00000000}},	//   _fhoh, _بێبه_, --, --, 
   {{0x6560047e,0x692c0115,0x8fc40022,0x00000000}},	//   _ghoh, jŝel, ҟаҳҵ, --, 
   {{0x45640014,0x850400d1,0x942000d1,0x00000000}},	//   _تھوہ, _تونن, _توشۇ, --, 
   {{0x656005b1,0xd34001ed,0x6824022e,0x934000db}},	//   _zhoh, _تفتی, _bаdj, _تىتۇ, 
   {{0x551c47d0,0x92680166,0xd12800db,0xee3000ec}},	//   _बताए_, _трда_, _وقتۇ_, رٽر_, 
   {{0xec78ca77,0x2ef4054e,0x00000000,0x00000000}},	//   спа_, _şefă_, --, --, 
   {{0x1d04beaf,0x6d54d0ed,0x98ac0024,0xc0d40092}},	// [11760] чети_, rlya, logė_, ርንም_, 
   {{0x63a440db,0x1ae00a5b,0x00000000,0x00000000}},	//   ákni, ноум, --, --, 
   {{0x6d540280,0x692c01e4,0x1e94011a,0x7c28010e}},	//   plya, bŝel, _מכיל_, _ýern, 
   {{0x203001d3,0xdbc4000d,0x00000000,0x00000000}},	//   _آفیس, vööt, --, --, 
   {{0x5edc0154,0x00000000,0x00000000,0x00000000}},	//   মারে, --, --, --, 
   {{0x6560d0ee,0x45d4d0ef,0xa9a42049,0xdbc400af}},	//   _shoh, докс, _нигд, tööt, 
   {{0x48c407dd,0x6560d0f0,0x95500066,0x00000000}},	//   _жәла, _phoh, کخوا, --, 
   {{0xded42e1f,0x692401a9,0x00000000,0x00000000}},	//   ርትና_, _эмба, --, --, 
   {{0xd9401e80,0xb87c0115,0xdbc4000d,0x6674691d}},	//   _чети, _kaŭn, sööt, _فدار, 
   {{0x6abc0112,0x00000000,0x00000000,0x00000000}},	//   ngpf, --, --, --, 
   {{0x6560d0f1,0x56100150,0xe5a40798,0x98ac00c0}},	//   _thoh, _كوكء, _ѕиди, gogė_, 
   {{0x656000ca,0xb87c010f,0x4034004e,0x6440005a}},	//   _uhoh, _laŭn, демс, _txoi, 
   {{0x506415ed,0xdef80108,0x00000000,0x00000000}},	//   етра, быв_, --, --, 
   {{0xd13000cf,0x00000000,0x00000000,0x00000000}},	//   _ۅۅپ_, --, --, --, 
   {{0x975404ae,0x60d801e4,0x4e2808ca,0x5edc00eb}},	//   פילו_, ĵumb, поён_, মালে, 
   {{0xd2380d65,0x91b8011a,0x00000000,0x00000000}},	//   _לגול, _המהי, --, --, 
   {{0xa3bc000d,0xebc00166,0x00000000,0x00000000}},	// [11770] ुझि_, кәрн, --, --, 
   {{0x501c0375,0x4424d0f2,0x6d4802d2,0x00000000}},	//   _לוחו, izm_, _ífan, --, 
   {{0xda640451,0x00000000,0x00000000,0x00000000}},	//   سائي, --, --, --, 
   {{0xc1780024,0x3914858f,0xa3bc0037,0x7c2800a2}},	//   lvės_, ьмер, ुझा_, _ýero, 
   {{0xb87c00df,0x00000000,0x00000000,0x00000000}},	//   _faŭn, --, --, --, 
   {{0x8ae410f5,0x3ce800af,0xa04802d3,0x3cf80208}},	//   _післ, ldav_, _ሓድነታ, _hnsv_, 
   {{0x22a40085,0x09e4013e,0x2d840841,0xc17800c0}},	//   zíkí_, _поён, _čoek_, ivės_, 
   {{0xa2c80882,0x3ce800af,0x98ac0153,0xe4d000d1}},	//   त्स्, ndav_, vogė_, نقىد, 
   {{0xc0d40092,0xbf0c000d,0x00000000,0x00000000}},	//   ይንስ_, _सकून_, --, --, 
   {{0x31a400f2,0x00000000,0x00000000,0x00000000}},	//   ومخف, --, --, --, 
   {{0x7d1cd0f3,0xb208d0f4,0xc1780024,0xf1dc012d}},	//   _olss, ценз_, dvės_, _फैशन, 
   {{0x6fb005f9,0x7d1c06be,0x00000000,0x00000000}},	//   _जिदं, _nlss, --, --, 
   {{0xb87c0115,0x46c4012c,0xb4e808a3,0x00000000}},	//   _laŭo, ल्कह, मयी_, --, 
   {{0x3cf80fac,0x34dc01f9,0x00000000,0x00000000}},	//   _ansv_, _मसुद, --, --, 
   {{0xb87c0115,0xa62c001f,0xce3400f1,0xdee00818}},	//   _naŭo, _እንደደ, رورک, ъори, 
   {{0x2d6801e4,0xb87c0115,0xeb9801d5,0x853c0064}},	//   _aŝer_, _saŭn, жиа_, _avėj, 
   {{0x7c2809a5,0xe0400107,0xc1780064,0x00000000}},	// [11780] _ýerl, _инъи, bvės_, --, 
   {{0x7d1c01f5,0x3cf80037,0x00000000,0x00000000}},	//   _elss, _ensv_, --, --, 
   {{0x3ce802fa,0x00000000,0x00000000,0x00000000}},	//   bdav_, --, --, --, 
   {{0x3cf80077,0xe8f80166,0x4424012d,0x00000000}},	//   _gnsv_, юле_, yzm_, --, 
   {{0x98a01342,0x00000000,0x00000000,0x00000000}},	//   тиче, --, --, --, 
   {{0xb87c01e4,0x00000000,0x00000000,0x00000000}},	//   _haŭl, --, --, --, 
   {{0x7d1c0334,0x95c00b24,0xadfc000d,0xf1dc0456}},	//   _ylss, نيوه, उमिन_, _फैलन, 
   {{0x6824022e,0x61d807f7,0x00000000,0x00000000}},	//   _lаdi, _बनौष, --, --, 
   {{0xa62c0020,0xe7380354,0x18a0236f,0x6b8001e7}},	//   _እንዲደ, _деа_, _шатм, íogh, 
   {{0x764cd0f5,0xb87c008f,0x2904023a,0x1bf8008f}},	//   şaya, _laŭl, ljoa_, קליב, 
   {{0x42740276,0xf62800db,0x00000000,0x00000000}},	//   эгос, _ىسمى_, --, --, 
   {{0x6f1c04cc,0xb87c0115,0x29040109,0x00000000}},	//   _alpc, _naŭl, njoa_, --, 
   {{0xc1780006,0x2ec8d0f6,0x3ce80254,0x00000000}},	//   tvės_, िभूत, vdav_, --, 
   {{0xa62c1ee0,0x63a41a53,0x290401f4,0x00000000}},	//   _እንዳደ, áknu, hjoa_, --, 
   {{0x7d1c7433,0x62880135,0xb7d40ca8,0xc1780024}},	//   _plss, _iffo, _iṣew, rvės_, 
   {{0xa2c893cb,0x6d480162,0x6f1c00de,0x3dcc025c}},	//   त्र्, _ífal, _elpc, ċew_, 
   {{0x2ef80a73,0xc1780006,0x7f2c001f,0x7b180276}},	// [11790] _fnpf_, svės_, ደማይች, поар_, 
   {{0xbb54d0f7,0x5278010f,0x7c2800a2,0xb81c00cc}},	//   رناب, ַנדא, _ýerm, _দখলত_, 
   {{0xb87c00df,0xc984ae46,0x00000000,0x00000000}},	//   _faŭl, вучи, --, --, 
   {{0xb87c00df,0x6aac0175,0xfbd00451,0x00000000}},	//   _gaŭl, _edbf, _ٽڪر_, --, 
   {{0x6288d0f8,0x06e80eac,0xe5a00131,0x00000000}},	//   _offo, পানি, ңиши, --, 
   {{0xd5a001d5,0x290401f4,0x29000248,0x00000000}},	//   نلتی, ajoa_, _òkan_, --, 
   {{0x29040158,0x98c4d0f9,0x00000000,0x00000000}},	//   bjoa_, _осал, --, --, 
   {{0x3ea0d0fa,0x79840b6f,0xb4e80b7c,0x6288d0fb}},	//   _leht_, mqhw, मये_, _affo, 
   {{0x36d43e07,0xaac4197e,0x96f80035,0x37b800cc}},	//   _поар, र्कक, _وعطر_, _ইনকৰ, 
   {{0x5770004b,0x07f8007b,0x00000000,0x00000000}},	//   _شپاړ, _ترفع_, --, --, 
   {{0xb87c00df,0x79840369,0x645405ac,0x682401a9}},	//   _laŭm, nqhw, _øyin, _rаdi, 
   {{0x2ef80607,0x1acc0882,0x6288d0fc,0xf1f401c0}},	//   _snpf_, स्तथ, _effo, _үздэ, 
   {{0x653800c8,0x80c0a170,0xe1ec60a1,0x60d80254}},	//   _צענד, _वारे, _өг_, õuma, 
   {{0xa2e001b9,0x59dc00bc,0x00000000,0x00000000}},	//   _бошд, नबार, --, --, 
   {{0x3ea00036,0xb87c008f,0x6fb00490,0x2374072d}},	//   _deht_, _paŭl, _जिवं, _ثمود_, 
   {{0xb87c01e4,0x1d04d0fd,0x813400c7,0x21641ab7}},	//   _baŭm, неси_, _ахьц, _пищи_, 
   {{0x6b640798,0x00000000,0x00000000,0x00000000}},	// [117a0] екаа, --, --, --, 
   {{0x3ea0d0fe,0xdcec00dc,0xaa8400a2,0x00000000}},	//   _geht_, _vicā, daýý, --, 
   {{0x290400fb,0xaac423c1,0xed58011c,0x00000000}},	//   tjoa_, र्गक, _ноо_, --, 
   {{0xccb40022,0x30b000fe,0xb4e800cd,0x00000000}},	//   _шәгь, ট্ৰস, मयो_, --, 
   {{0xe7d00b43,0x2904023a,0x8ad40451,0xd9d000cf}},	//   امتگ, rjoa_, _لڪائ, _ۅەلگ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x290401af,0xaa440261,0x9850151e,0x26cc0142}},	//   pjoa_, _чевл, ктәш, rffo_, 
   {{0x628801fa,0x44f44c70,0xb87c01e4,0x6d5800e4}},	//   _sffo, тпис, _laŭj, îtah, 
   {{0x27341a02,0x00000000,0x00000000,0x00000000}},	//   _كىرس, --, --, --, 
   {{0xb87c01e4,0x8c4806be,0x00000000,0x00000000}},	//   _naŭj, _ilğı, --, --, 
   {{0x00940276,0x5ab4010f,0x00000000,0x00000000}},	//   кинэ, עלטע_, --, --, 
   {{0x64a40323,0x3ea00ade,0x5924031c,0x00000000}},	//   _чада, _seht_, ྡིགས_, --, 
   {{0xdcec0356,0xd0a8009d,0x00000000,0x00000000}},	//   _lică, этэд_, --, --, 
   {{0xb87c00df,0xa1a800d1,0xd1e00092,0x628802d0}},	//   _raŭm, _етиз_, _ዜጐች_, _uffo, 
   {{0xa01800dd,0x2ca0007f,0x51f000c6,0xdcec054e}},	//   nböz, _bekd_, _مسير, _nică, 
   {{0x3ea00112,0x98ac007f,0x7c28010e,0x13a40244}},	//   _weht_, tigč_, _ýerk, _تۆیی_, 
   {{0x3b542cdd,0x00000000,0x00000000,0x00000000}},	// [117b0] вкар, --, --, --, 
   {{0x7e9820d4,0xe0dcd0ff,0x00000000,0x00000000}},	//   _تندر_, leò_, --, --, 
   {{0x8c480139,0x00000000,0x00000000,0x00000000}},	//   _alğı, --, --, --, 
   {{0x9ba003cc,0x61fc06af,0x69d0000d,0x00000000}},	//   _مەرى, _àplu, _ठहरी, --, 
   {{0x37e44530,0x34dc00ce,0x00000000,0x00000000}},	//   толг, _मसौद, --, --, 
   {{0xb87cd100,0x7bccd101,0xe0dc01ab,0x47940066}},	//   _kaŭk, mtau, heò_, اجنس, 
   {{0xb89400c6,0x6444002d,0xe0dc007f,0x7bccd102}},	//   _للأع, ûkin, keò_, ltau, 
   {{0xf8a8d103,0x7bccd104,0xa5f40640,0xe8ec0451}},	//   _آگاه_, otau, ђењу_, _وڻن_, 
   {{0xe0dc08e5,0xb87c00df,0x494401dd,0x00000000}},	//   deò_, _laŭk, _сэрб, --, 
   {{0x7bccd105,0x4ee40c58,0x00000000,0x00000000}},	//   itau, মাৱল, --, --, 
   {{0xa2b0d106,0x7bcc02f6,0x32441411,0xaac41b76}},	//   _आयर्, htau, тенг, र्टक, 
   {{0x7bccd107,0x00000000,0x00000000,0x00000000}},	//   ktau, --, --, --, 
   {{0x7428007b,0xc50c010f,0xa0200037,0x00000000}},	//   _تكشف_, _מלאָ, ööpr, --, 
   {{0x7bccd108,0x81bc005f,0x00000000,0x00000000}},	//   dtau, izēj, --, --, 
   {{0x2d9cd109,0xb144d10a,0xa2d0215c,0x00000000}},	//   ète_, _инкл, _ئيىت, --, 
   {{0x7bcc03fa,0xa050063f,0x692c00df,0x00000000}},	//   ftau, ụmụa_, lŝev, --, 
   {{0x7bcc2a17,0x6f640124,0x06e800eb,0x00000000}},	// [117c0] gtau, _ивиз, পাতি, --, 
   {{0x81bc00da,0xb87c01e4,0xdcec0311,0x1b440c60}},	//   dzēj, _faŭk, _pică, взуи_, 
   {{0x7bccd10b,0x81bc0171,0x00000000,0x00000000}},	//   atau, ezēj, --, --, 
   {{0x7bcc002f,0x992800f1,0x00000000,0x00000000}},	//   btau, وتنې_, --, --, 
   {{0x7bccd10c,0xc0ac008f,0x6d4403ac,0x4ab40139}},	//   ctau, ליאָ, _ijka, _бөер, 
   {{0xb87c01e4,0xdcec054e,0xa610134b,0xa024032e}},	//   _laŭh, _tică, излә, _hröð, 
   {{0x644c03be,0xe9a40116,0x00000000,0x00000000}},	//   əbiy, _шавп, --, --, 
   {{0x7be80a87,0x04480166,0x00000000,0x00000000}},	//   _ísuð, нҗеп_, --, --, 
   {{0x77900133,0x00000000,0x00000000,0x00000000}},	//   _هینا, --, --, --, 
   {{0xe0dc0295,0x764c01ed,0xa1840166,0x00000000}},	//   weò_, ényé, кымл, --, 
   {{0x98ac0618,0x6d4416a3,0xb7d40248,0xe0dc0561}},	//   ligā_, _ojka, _iṣaw, teò_, 
   {{0x7bcc0006,0xb87c0115,0x94c800f1,0x5634010f}},	//   ytau, _raŭk, _يانې_, _באבע_, 
   {{0x7bcc0112,0x00000000,0x00000000,0x00000000}},	//   xtau, --, --, --, 
   {{0x7c2809a5,0xdb2003ee,0x545001ce,0x6d4400e5}},	//   _ýeri, örün, _твіт, _ajka, 
   {{0x5fac069f,0x6298070d,0xd3780a1e,0x6d440205}},	//   _झटकल, mbto, _קרוט, _bjka, 
   {{0x7bccd10d,0xd138d10e,0xaac4276a,0x6298d10f}},	//   ttau, _ахь_, र्घक, lbto, 
   {{0x7bccd110,0xabb40588,0x9f68004e,0x00000000}},	// [117d0] utau, латә, _ороз_, --, 
   {{0x1b180154,0x6ed8012d,0xdfcc00ec,0x0ab4007b}},	//   ফোনে_, _पॉपु, _هيڊ_, لحمد, 
   {{0x47c0045e,0x7bccd111,0x81bc00e2,0x6b9400e4}},	//   _শৈলী, stau, dzēk, apyg, 
   {{0xb7d40248,0xdbc8067c,0xc8b40220,0x00000000}},	//   _aṣaw, _nòça, асшы, --, 
   {{0x7bcc6018,0x58000184,0x199000d1,0x644c002f}},	//   qtau, ролғ, уаҗя, ßbil, 
   {{0xd044013b,0x3668326d,0xbb300046,0x9a842e36}},	//   _abiɛ, нало_, ﻪﺭﻯ_, _шумл, 
   {{0xb87c0115,0xc8640022,0x00000000,0x00000000}},	//   _laŭi, лтәи, --, --, 
   {{0x7398775e,0x5edc0154,0x00000000,0x00000000}},	//   нтос_, মায়ূ, --, --, 
   {{0x7c2804cc,0x00000000,0x00000000,0x00000000}},	//   _üerd, --, --, --, 
   {{0x8c4403e0,0x9f4c0241,0x00000000,0x00000000}},	//   _öğey, _égè_, --, --, 
   {{0x80dc04c5,0x040404c5,0x00000000,0x00000000}},	//   যযন্, শৈলী_, --, --, 
   {{0x8504021a,0x62980009,0x047801d5,0x6b9400e4}},	//   _پوهن, abto, علیک_, ypyg, 
   {{0xf5380030,0x6298007c,0x00000000,0x00000000}},	//   miť_, bbto, --, --, 
   {{0xf53801a2,0x682401a9,0x25b802f0,0xa854011a}},	//   liť_, _kаdr, šple_, רישה_, 
   {{0xd20000f7,0xa30801ed,0xde38001f,0x2b1400c7}},	//   _түнк, _سروے_, _አትክል, қьар, 
   {{0xf53801a2,0xed58016c,0xafe4d112,0x00000000}},	//   niť_, хоб_, _боил, --, 
   {{0xffe80032,0xaab8d113,0xa2c800dc,0x5edc0154}},	// [117e0] _алыҫ_, فدار_, त्क्, মাজে, 
   {{0x7c6400d1,0x00000000,0x00000000,0x00000000}},	//   شاقل, --, --, --, 
   {{0xbb740395,0x00000000,0x00000000,0x00000000}},	//   рутъ, --, --, --, 
   {{0xda6c0050,0xf53801f1,0x98ac0421,0xa8483ee0}},	//   سُن_, jiť_, tigā_, ىلام_, 
   {{0xe7380aa5,0xf53801a2,0x6d54d114,0xdd8c1547}},	//   нед_, diť_, moya, _ووی_, 
   {{0x6d54d115,0xc6d401c0,0xd494010b,0x00000000}},	//   loya, рсдө, ңры_, --, 
   {{0x75c84ef9,0x6ed41d97,0x6d54037e,0xf5380419}},	//   втың_, म्यु, ooya, fiť_, 
   {{0x6d54d116,0xa924010b,0x29cc010e,0x00000000}},	//   noya, _ёдал, mýa_, --, 
   {{0x68e00332,0xd7b40014,0x684400d8,0x939000f2}},	//   meod, _مۆنڈ_, _снаа, یجیا, 
   {{0x68e0d117,0xded4044e,0x6d54d118,0x27e40100}},	//   leod, ይትን_, hoya, mwon_, 
   {{0xf53801a2,0x64c40150,0x6298d119,0x636402d2}},	//   biť_, _ميال, rbto, gðna, 
   {{0x6d54d11a,0xf1a407f7,0x68e000ae,0x00000000}},	//   joya, _खबरन, neod, --, 
   {{0x6d5401b9,0x98ac0311,0xa2d400f1,0x29cc010b}},	//   doya, ligă_, _ميشت, hýa_, 
   {{0x68e0014b,0x63a0d11b,0x3ea4d11c,0x29cc010e}},	//   heod, _iwon, últ_, kýa_, 
   {{0x6d54d11d,0x68e00165,0x20d0010a,0xb6340023}},	//   foya, keod, _гιем, _እንተሊ, 
   {{0x27e4d11e,0x6b8401af,0x63a0d11f,0x5c040801}},	//   kwon_, _bukg, _kwon, ляза, 
   {{0x69cc0003,0x30a401c6,0xbb58009d,0x00000000}},	// [117f0] _aqbe, _өрөв, ваах_, --, 
   {{0xf5380038,0x63a0d120,0x5438008f,0x27e402e2}},	//   ziť_, _mwon, געמא, dwon_, 
   {{0x63a0d121,0x6b8000ae,0xadb00150,0xdee80092}},	//   _lwon, íogr, _мұрш, ሆንክ_, 
   {{0x63a0d122,0x0c84010b,0x6d54d123,0x68e0d124}},	//   _owon, _гырм, coya, geod, 
   {{0xf5380038,0x6b84020c,0x63a00134,0x7d0cd125}},	//   viť_, _gukg, _nwon, mjas, 
   {{0x7d0cd126,0x7bdc0de4,0x7c2c0198,0xdb20004b}},	//   ljas, _ipsu, mzar, _اوسی, 
   {{0xf53801a2,0x7c2cd127,0x63a0d128,0x7d0c0c98}},	//   tiť_, lzar, _awon, ojas, 
   {{0x63a0d129,0xb60401ed,0x7c2c01c4,0x27e4007f}},	//   _bwon, _aláí, ozar, bwon_, 
   {{0x7c2cd12a,0xf53801a2,0x2918016b,0xb7d4110e}},	//   nzar, riť_, ɔpa_, _iṣow, 
   {{0x63a0016b,0x6d5407a8,0xc6a403b7,0x7c2cd12b}},	//   _dwon, zoya, _грци, izar, 
   {{0xf53801a2,0x6d54d12c,0x63a0d12d,0x34b4d12e}},	//   piť_, yoya, _ewon, _نماز, 
   {{0x63a002bd,0x25f002ab,0x7bdc1096,0x853c00c0}},	//   _fwon, ंटरी_, _opsu, _dvės, 
   {{0xe28c9f1f,0x6d54d12f,0x63a0d130,0x75280810}},	//   _ма_, voya, _gwon, mhez, 
   {{0x6d54d131,0x00000000,0x00000000,0x00000000}},	//   woya, --, --, --, 
   {{0x7bdcd132,0xada49a41,0x6da4d133,0x63a00084}},	//   _apsu, рабл, риба, _zwon, 
   {{0x7d0cd134,0x27e494c3,0x7528d135,0x00000000}},	//   gjas, ywon_, nhez, --, 
  
   {{0x6d54d136,0xeab0d137,0xec78d138,0x3ec80158}},	// [11800] roya, قعا_, тпа_, åttå_, 
   {{0x6d54d139,0x7d0c8234,0x40244b1c,0x8eb40136}},	//   soya, ajas, _ызың, _دەست, 
   {{0x7d0c01fa,0x68e0d13a,0x7bdc0381,0x7c2cd13b}},	//   bjas, teod, _epsu, azar, 
   {{0x27e402bd,0x9c800306,0x752800bc,0x7c2c0356}},	//   twon_, účtu, jhez, bzar, 
   {{0x7c2c0034,0x68e000ae,0xdc9808a8,0x7528d13c}},	//   czar, reod, _ביכל, dhez, 
   {{0x63a00230,0x699402bf,0x27e40142,0x68e00332}},	//   _rwon, _врах, rwon_, seod, 
   {{0x63a00c11,0xb0b40034,0xb0c40490,0x799402d0}},	//   _swon, _आएंग, _वांग, _gtzw, 
   {{0x7528d13d,0xa9689cff,0x63a002bd,0x98ac054e}},	//   ghez, _риба_, _pwon, rigă_, 
   {{0xc82400d1,0x682401a9,0x7c280432,0x00000000}},	//   _узақ, _tаdq, _ýert, --, 
   {{0xe4e00037,0xd374013d,0x00000000,0x00000000}},	//   _खसकि_, ичэ_, --, --, 
   {{0x7c2c3003,0x7528d13e,0x63a0003e,0x00000000}},	//   zzar, bhez, _wwon, --, 
   {{0x7528d13f,0x63a0d140,0xd25474e7,0xded41772}},	//   chez, _twon, рць_, ይድን_, 
   {{0x63a0d141,0x5ec80eac,0x7d0cd142,0x39b00210}},	//   _uwon, াজসে, vjas, ząs_, 
   {{0xd4640640,0x98ac0064,0x00000000,0x00000000}},	//   _тиче_, migą_, --, --, 
   {{0x7d0cd143,0xb87c008f,0xbd4400c6,0x00000000}},	//   tjas, _haŭt, منسي, --, 
   {{0x7c2c9bb1,0x80c00574,0x1fa40139,0x00000000}},	//   tzar, _वाटे, _крог, --, 
   {{0x67d8005f,0x7bf800f7,0x98ac00c0,0x00000000}},	// [11810] nājā, ынар_, nigą_, --, 
   {{0x7d0c688b,0x764c0213,0x9de401d9,0x21280455}},	//   sjas, şayi, _پہرٕ_, lhch_, 
   {{0x7c2c295f,0xb87c008f,0xba540137,0x00000000}},	//   szar, _laŭt, حناع, --, 
   {{0x3f8800b0,0x00000000,0x00000000,0x00000000}},	//   _kuau_, --, --, --, 
   {{0x3f8000b0,0xb87c01e4,0x386805ac,0x318400e2}},	//   _kihu_, _naŭt, åar_, _vēzi_, 
   {{0x86980801,0x3f80d144,0x7528030a,0x38680115}},	//   атът_, _jihu_, whez, ĥar_, 
   {{0x3f800134,0x7ae4d145,0x7528d146,0x3f880356}},	//   _mihu_, meht, thez, _luau_, 
   {{0xb3c8d147,0x7ae40d77,0x3f8803a0,0x853c0153}},	//   глиз_, leht, _ouau_, _svėr, 
   {{0x85080efb,0x3f80009d,0x212808c2,0x752801a9}},	//   рдың_, _oihu_, dhch_, rhez, 
   {{0x78a80493,0x752859fc,0x6728002d,0x7ae4d148}},	//   _heev, shez, chfj, neht, 
   {{0x75288cdb,0x3f88d149,0x78a800c5,0xf59802e8}},	//   phez, _auau_, _keev, _свещ_, 
   {{0x3f800270,0x7ae402d3,0x7528009a,0x67d80171}},	//   _aihu_, heht, qhez, bājā, 
   {{0x78a8d14a,0x3f8000ca,0x7ae40821,0x67d86991}},	//   _meev, _bihu_, keht, cājā, 
   {{0x78a8d14b,0x3f88067c,0xb87c01e4,0xa8540375}},	//   _leev, _duau_, _haŭs, מירה_, 
   {{0x7ae43c85,0x853c0024,0x80c005c0,0x00000000}},	//   deht, _kvėp, _वाचे, --, 
   {{0x78a8d14c,0xac8443b6,0x52a4012d,0x00000000}},	//   _neev, сгал, _ग़ुस, --, 
   {{0x3f800418,0x3f882e27,0xeb98d14d,0xa0980115}},	// [11820] _fihu_, _guau_, уиз_, _גיפט, 
   {{0x3f800223,0x6ac40597,0xbc180220,0xb87c010f}},	//   _gihu_, إقام, шісі_, _laŭs, 
   {{0x1ef800c8,0x78a8d14e,0x671c07f7,0x00000000}},	//   _עלטע, _beev, _बकबक_, --, 
   {{0x78a8d14f,0xe784d150,0xa804d151,0x00000000}},	//   _ceev, буко, йзел, --, 
   {{0x2d800069,0x78a8d152,0x80c001ad,0x3f80014f}},	//   _iike_, _deev, _वाघे, _yihu_, 
   {{0xe9a804fb,0x2d80d153,0xdd8c02f2,0x00000000}},	//   _مدرن_, _hike_, _توێ_, --, 
   {{0x2d80d154,0x78a81fce,0x7c2800a2,0xf41400fe}},	//   _kike_, _feev, _ýerr, _তেলৰ_, 
   {{0xccf4043b,0x2d80d155,0x67d81c52,0x318400de}},	//   ndɛ_, _jike_, tājā, _jēzu_, 
   {{0xd044013b,0x2d800375,0x186423be,0x05d4000d}},	//   _obiɑ, _mike_, _гати_, _दहकब, 
   {{0x2d80d156,0x78a8d157,0xe5a400ee,0xd99400cf}},	//   _like_, _zeev, _гижи, _ئچەت_, 
   {{0x3f88d158,0xb87c01e4,0x78a8d159,0x2d800588}},	//   _suau_, _faŭs, _yeev, _oike_, 
   {{0x81bc0029,0x78a801d4,0x3f8800b0,0xb87c0115}},	//   dzēt, _xeev, _puau_, _gaŭs, 
   {{0x3f88180f,0xd8d4008f,0x3f800254,0x741000e5}},	//   _quau_, זוכט_, _pihu_, _ہڈیا, 
   {{0x4374d15a,0x2d80d15b,0xb87c00df,0xce9402e8}},	//   _بهتر, _aike_, _kaŭr, заръ, 
   {{0x2d80d15c,0xfca800d1,0x8d840137,0x8f34010b}},	//   _bike_, исақ_, зууд, черц, 
   {{0x2d800c09,0xb87c00df,0x394c0115,0x5f4401c6}},	//   _cike_, _maŭr, _ĉeso_, рүүн_, 
   {{0x2d80d15d,0x7ae4d15e,0xb87c010f,0x7b1401f0}},	// [11830] _dike_, teht, _laŭr, одах, 
   {{0x9a849021,0x2d800798,0xc1ec03ce,0x00000000}},	//   суал, _eike_, _जनाब_, --, 
   {{0x78a8d15f,0x2d80d160,0xd918d161,0x13c004c5}},	//   _peev, _fike_, льд_, ্বয়, 
   {{0x673800d2,0x7ae4d162,0x2d800223,0x5c04d163}},	//   _amtj, seht, _gike_, _ляга, 
   {{0xf7701acc,0x78a89092,0xaefc015b,0x2d5c0165}},	//   وات_, _veev, ুসরণ_, rïet_, 
   {{0x78a84e6c,0x2d801606,0x2b580810,0x24842126}},	//   _weev, _zike_, copc_, _agom_, 
   {{0x78a8d164,0xb87c01e4,0x978023cf,0xe7342bb6}},	//   _teev, _paŭs, _کیته, юеш_, 
   {{0xb87c04ac,0x00000000,0x00000000,0x00000000}},	//   _daŭr, --, --, --, 
   {{0x98140502,0xa4f401d5,0x18b001af,0x00000000}},	//   _ابزا, تکلر_, _дәһр, --, 
   {{0x386cd165,0x24840086,0x15a800a7,0x00000000}},	//   _izer_, _egom_, _бъди_, --, 
   {{0x81bc005f,0xf3640ce8,0xc68801f7,0x00000000}},	//   dzēs, йтүн, _اَمن_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2d80d166,0x200c00cf,0x394cd167,0xb4b4d168}},	//   _rike_, _àgil_, _mjes_, _гиҗә, 
   {{0x2d80d169,0x394c01a6,0x836400db,0x00000000}},	//   _sike_, _ljes_, _ىدول, --, 
   {{0xad3802bf,0x2d802517,0x00000000,0x00000000}},	//   ачає_, _pike_, --, --, 
   {{0x6da407d6,0x6448107d,0x2d800200,0x00000000}},	//   йиҳа, šmiš, _qike_, --, 
   {{0x2d80d16a,0x9d409735,0xc05800c0,0x00000000}},	// [11840] _vike_, фетд, _грэц_, --, 
   {{0x2d800225,0x09e4025c,0x00000000,0x00000000}},	//   _wike_, _ཨརྱ_, --, --, 
   {{0x2d80d16b,0x80b0068f,0x2d5c026c,0x386c4dd9}},	//   _tike_, _अजमे, uïes_, _azer_, 
   {{0x2d8003c1,0xdd0c05d1,0x6cf80354,0xfbd001e2}},	//   _uike_, mışs, _темĕ, بتې_, 
   {{0x394c01fa,0xb87c0115,0xdd0cd16c,0x63bc00dc}},	//   _djes_, _saŭr, lışs, _āpno, 
   {{0x394cd16d,0xab2815ed,0x386c00de,0xa9a400d4}},	//   _ejes_, _тога_, _dzer_, _мигд, 
   {{0x386cd16e,0x76a800d6,0x394c143a,0xe5c4003b}},	//   _ezer_, стів_, _fjes_, іско, 
   {{0x54800092,0x00000000,0x00000000,0x00000000}},	//   _የኢራቅ_, --, --, --, 
   {{0x9550035c,0xe79c00e2,0xa6940798,0x88c400f1}},	//   بخوا, ēlēš, _дреј, _وتړل, 
   {{0x673800d2,0xb87c010f,0x5edc015b,0x81bc00e2}},	//   _umtj, _taŭr, _ফোনে, dzēr, 
   {{0x248407c5,0x06680150,0x5af80a1e,0xd25400d4}},	//   _tgom_, _الاۋ_, בליצ, жця_, 
   {{0x14c40b3b,0xdd0c0139,0x00000000,0x00000000}},	//   _дыши_, dışs, --, --, 
   {{0xd24c78dd,0x203402d3,0xdfd800a7,0xd0840022}},	//   _ینه_, _ኣድላይ, шън_, дыри, 
   {{0x7c28012d,0x20340023,0x00000000,0x00000000}},	//   _żero, _ኣድለይ, --, --, 
   {{0xb87c010f,0xc8840139,0x00000000,0x00000000}},	//   _laŭp, loğı_, --, --, 
   {{0xd1d0001f,0x31700036,0x519418a2,0x00000000}},	//   ያኖች_, _ghyz_, _بخود_, --, 
   {{0xb7c409bd,0x5e84010b,0xdb200133,0x394c0055}},	// [11850] _এন্ট, _мунз, ووری, _rjes_, 
   {{0x9a2410de,0x99d42a14,0x5398d16f,0x59000327}},	//   يعان, قتصا, יימו, _ཚོངས_, 
   {{0x386c514a,0x394c0240,0xb7d40241,0x787400e5}},	//   _szer_, _pjes_, _iṣiw, küvé, 
   {{0x26dc0429,0x00000000,0x00000000,0x00000000}},	//   _abto_, --, --, --, 
   {{0x8cd8007d,0x00000000,0x00000000,0x00000000}},	//   मभरो, --, --, --, 
   {{0x3eb001d3,0x00000000,0x00000000,0x00000000}},	//   nazt_, --, --, --, 
   {{0x394c01a4,0x7af4005a,0xf62416ab,0x39140353}},	//   _tjes_, _iazt, ядко, _емвр, 
   {{0x7af4d170,0xf5087b0a,0x667001d5,0x10a000d1}},	//   _hazt, снил_, رگلر, _ﺋﯩﺪﯨ, 
   {{0x3dd004c5,0x7af4037e,0x81e40154,0xc8840139}},	//   াবিল, _kazt, নিফ_, goğı_, 
   {{0x9604d171,0x395c0375,0x7af401c4,0x00000000}},	//   _وبام, lows_, _jazt, --, 
   {{0x7af4d172,0x00000000,0x00000000,0x00000000}},	//   _mazt, --, --, --, 
   {{0x70c40574,0xb7d40248,0x7af4009d,0xe5f4011a}},	//   वलेल, _aṣiw, _lazt, _מזער_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2d94bf2b,0x7af40115,0x9d180154,0x1ac4000d}},	//   зрас, _nazt, ণফোন_, _लागथ, 
   {{0xde00003b,0x00000000,0x00000000,0x00000000}},	//   нпри, --, --, --, 
   {{0x17080489,0x7af4005a,0x62180a7c,0x00000000}},	//   _ཁོའམ_, _aazt, _לוצק, --, 
   {{0x7af405f5,0x395c029d,0xeab8374e,0x00000000}},	// [11860] _bazt, dows_, ййа_, --, 
   {{0x7af405d5,0xb87c0115,0x8eb40046,0xb3bc00cc}},	//   _cazt, _raŭp, _زەرت, _অহাজ, 
   {{0xe9d8d173,0xed583f1b,0xbc9000d7,0x628c013a}},	//   ске_, _гон_, _šášo, _úhoř, 
   {{0xace8d174,0x395c0142,0x00000000,0x00000000}},	//   _умма_, gows_, --, --, 
   {{0xa0980a1e,0x5880d175,0x2cb0b9c2,0x3f4c00d7}},	//   ציסט, ныша, mayd_, kľul_, 
   {{0x7af4152d,0x2cb00067,0x00000000,0x00000000}},	//   _gazt, layd_, --, --, 
   {{0x395cbed5,0xb9b400a7,0x00000000,0x00000000}},	//   bows_, _остъ, --, --, 
   {{0x2cb001d9,0x395c045a,0x00000000,0x00000000}},	//   nayd_, cows_, --, --, 
   {{0x7af40083,0x83f800d8,0x00000000,0x00000000}},	//   _yazt, цепс_, --, --, 
   {{0x2cb00050,0xc1b8d176,0x1798010f,0x5c3400d9}},	//   hayd_, олох_, _לימב, פרין_, 
   {{0x824802d3,0x2cb00067,0x65b801af,0x00000000}},	//   _ዓቕምታ, kayd_, _ыуар_, --, 
   {{0xe578d177,0x835400ec,0x00000000,0x00000000}},	//   _узе_, _ڪپتا, --, --, 
   {{0x656000ca,0x63ac00bc,0x2cb0058a,0x100400ee}},	//   _ikoh, áhně, dayd_, нярм, 
   {{0x26cc013f,0x81e403d4,0x00000000,0x00000000}},	//   ngfo_, নিব_, --, --, 
   {{0x7af4151c,0xdef80417,0x6ecc1810,0x00000000}},	//   _razt, _ғып_, _तारु, --, 
   {{0x8d747c3c,0x32c00131,0x00000000,0x00000000}},	//   فاقا, _ﻣﯘﮬﻪ, --, --, 
   {{0x7af407c5,0xe0dc0100,0x8fe401af,0xe1f001f7}},	// [11870] _pazt, riòd_, _пәрҙ, _آسڻ_, 
   {{0x9ba00075,0x2ee80175,0x5398011a,0x00000000}},	//   _ۋەزى, cebf_, ציבו, --, 
   {{0x6e94212c,0x2cb0058a,0x69d80139,0x636402d2}},	//   _تلپا, bayd_, _ätel, gðni, 
   {{0x6560d178,0xca740131,0x00000000,0x00000000}},	//   _nkoh, رالغ, --, --, 
   {{0x6cf80375,0x395cd179,0x2cf8011a,0xacf8011a}},	//   _ופרס, rows_, _ולרא, _והרכ, 
   {{0x6560d17a,0xbae400ae,0x00000000,0x00000000}},	//   _akoh, _تكسي, --, --, 
   {{0xb5081025,0x00000000,0x00000000,0x00000000}},	//   वालय_, --, --, --, 
   {{0x04b457d7,0x391401a9,0xb974009f,0x85c40116}},	//   ىلىڭ, _ўмар, _آئسڪ, رغىم, 
   {{0x6ecc2e3b,0x5eb00eac,0x98142a93,0x00000000}},	//   _तालु, _জানে, _عبرا, --, 
   {{0x79580139,0x70c4146b,0x4424007b,0x46a40798}},	//   _däwş, वल्ल, عريف, _заѕв, 
   {{0x65600093,0x87e80014,0x00000000,0x00000000}},	//   _fkoh, _وٹہِ_, --, --, 
   {{0x8fc40022,0x00000000,0x00000000,0x00000000}},	//   намҵ, --, --, --, 
   {{0x2cb007ab,0xe3ac67d7,0xb92401e1,0x00000000}},	//   vayd_, _шб_, _ńwọ_, --, 
   {{0x2cb00014,0x5f90020a,0xd3780063,0xf1c40b98}},	//   wayd_, тиёт, _уче_, _विपन, 
   {{0x9268d17b,0xb4f00037,0x2ee8007c,0x315800ae}},	//   _урда_, _अघाय_, rebf_, _وجبة_, 
   {{0x1d04aa4e,0x629c00e4,0x79580139,0x22480419}},	//   меси_, _õpor, _yäwş, úbke_, 
   {{0x2cb00067,0xe478010f,0x00000000,0x00000000}},	// [11880] rayd_, ַרעכ, --, --, 
   {{0x2cb0007f,0x00000000,0x00000000,0x00000000}},	//   sayd_, --, --, --, 
   {{0x2ea80574,0x6aac0240,0xfc3000e5,0x615000e5}},	//   करीत, _vebf, نحے_, _سنیئ, 
   {{0x68443306,0x2cb001d5,0xd6740150,0x00000000}},	//   وَال, qayd_, _ﺠﻭﻫﺭ_, --, 
   {{0xeb981214,0x00000000,0x00000000,0x00000000}},	//   _фиг_, --, --, --, 
   {{0x6aac0023,0x6560007c,0xb90401f9,0xa034011a}},	//   _uebf, _skoh, _बॉ_, ואנה_, 
   {{0x271c000d,0x5eb000eb,0x00000000,0x00000000}},	//   _बकीर_, _জামে, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd8d404ac,0xa288001f,0xe2a80451,0x00000000}},	//   _קומט_, መሆኑን_, يادن_, --, 
   {{0x394c00df,0xa4380092,0x647001a9,0x00000000}},	//   _ĉesi_, _እድገት, нгқу, --, 
   {{0x3e740241,0x00000000,0x00000000,0x00000000}},	//   _mùtí_, --, --, --, 
   {{0x6560d17c,0x40340108,0xf41400cc,0x00000000}},	//   _ukoh, еемс, _তেওৰ_, --, 
   {{0x9cd80156,0x5064d17d,0x131401d5,0x4f380023}},	//   ྲུལས, втра, ستیغ_, _ኣብዘይ, 
   {{0x442486d2,0x93f00816,0x00000000,0x00000000}},	//   mym_, _шпіц, --, --, 
   {{0x4424d17e,0xd13000f7,0xf1c41be1,0xdb1c06be}},	//   lym_, _چۅپ_, _वियन, luqç, 
   {{0xa3f00cb4,0x1bb80127,0x91b8011a,0x00000000}},	//   _अनाप_, قاطع_, _ומהי, --, 
   {{0x4424d17f,0x8d84d180,0x61fc022a,0xbb7400d8}},	// [11890] nym_, турд, _šplh, егај, 
   {{0xe0dc007f,0xa3e405b3,0xbacc0154,0x00000000}},	//   lfò_, _पहन_, রজ্ঞ, --, 
   {{0x4424d181,0xda640592,0xcb080451,0x3d2800f2}},	//   hym_, ذائي, ظيمن_, _فتحی_, 
   {{0x4424d182,0xe0dc02e2,0xf4dc0150,0x00000000}},	//   kym_, nfò_, _ﺃﻤﺎﻜ, --, 
   {{0xdac400d1,0x44240432,0x00000000,0x00000000}},	//   _يېرى_, jym_, --, --, 
   {{0x4424d183,0x7d1cd184,0x247c0f7c,0xa9340133}},	//   dym_, _hoss, _ብስራት_, وبۆچ, 
   {{0x3cf800c5,0x7d1cd185,0x44240363,0x64440413}},	//   _kasv_, _koss, eym_, úkin, 
   {{0x7d1c0664,0xb9c401b9,0x636406ea,0x00000000}},	//   _joss, _оёғи, iðnu, --, 
   {{0x7d1cd186,0x4424d187,0x7bcc0069,0xb464010b}},	//   _moss, gym_, nuau, экил, 
   {{0x798804e6,0x7d1cd188,0xe0c4009e,0xe0cc00cc}},	//   _hiew, _loss, ষ্মভ, িজোন, 
   {{0x7bccd189,0x7988d18a,0x7d1c0af9,0x4424062c}},	//   huau, _kiew, _ooss, aym_, 
   {{0x7d1cd18b,0x4424d18c,0x7bccd18d,0x00000000}},	//   _noss, bym_, kuau, --, 
   {{0x4424068f,0x7fd40046,0x85040150,0x53d007f7}},	//   cym_, кірі, _جونن, _दमिश, 
   {{0x7988d18e,0x752800dd,0x7bcc00c5,0xeb9885a1}},	//   _liew, lkez, duau, ҷиа_, 
   {{0x75285e50,0x2d9ca5eb,0x9fa00051,0x5f000166}},	//   okez, ëte_, _xêút_, ызра, 
   {{0x7d1cd18f,0x7988d190,0x2d9c0318,0x752801d3}},	//   _coss, _niew, īte_, nkez, 
   {{0x7d1cd191,0x2d9c05b4,0x2bc81c3e,0x2fc402d2}},	// [118a0] _doss, ūte_, ялап_, _íog_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7528d192,0x442486d2,0x7bcc0b23,0x79880036}},	//   kkez, zym_, auau, _biew, 
   {{0xace80510,0x6f1c014f,0x442400ee,0xed5846ed}},	//   _эмма_, _hopc, yym_, _хом_, 
   {{0x6f1cd193,0x7988a051,0x8ca0448b,0x752801d3}},	//   _kopc, _diew, गुणो, dkez, 
   {{0x57f0026a,0x442402fb,0x79880af9,0x6f180e78}},	//   упшт, vym_, _eiew, ötch, 
   {{0x7d1cd194,0x4424006d,0x2b941730,0x79880036}},	//   _yoss, wym_, _hæc_, _fiew, 
   {{0xc448d195,0x7988d196,0x7d1cd197,0x4424d198}},	//   ویان_, _giew, _xoss, tym_, 
   {{0xa80498f6,0x6f1c03ac,0x44240076,0x96600166}},	//   _язал, _oopc, uym_, ккәе, 
   {{0x4424d199,0x2ea853b7,0x81e4015b,0x6f1c695b}},	//   rym_, करोत, নিস_, _nopc, 
   {{0x442400ee,0xd9400262,0x23c01100,0x569001af}},	//   sym_, _реӂи, _शिवद, _саєт, 
   {{0x2a68d19a,0x7528d19b,0xe578013d,0x9d0800eb}},	//   _mybb_, ckez, _эзе_, _রত্ন_, 
   {{0x7d1cd19c,0x3cf8d19d,0x6b940477,0x51f00133}},	//   _ross, _rasv_, jqyg, نسێر, 
   {{0x7d1cd19e,0x53980bd9,0x6f1cd19f,0x3cf8017a}},	//   _soss, _ציוו, _copc, _sasv_, 
   {{0x7d1cd1a0,0x7c28010e,0x3d940ce1,0x00000000}},	//   _poss, _ýerz, тибр, --, 
   {{0x7bccd1a1,0x00000000,0x00000000,0x00000000}},	//   tuau, --, --, --, 
   {{0x7d1cd1a2,0x79880652,0x6728143a,0x6298bff5}},	// [118b0] _voss, _riew, kkfj, octo, 
   {{0x6298d1a3,0x7988d1a4,0x6f1c070d,0x7d1c0a40}},	//   ncto, _siew, _gopc, _woss, 
   {{0x6298015d,0x752815b4,0xbd78003b,0x00000000}},	//   icto, ykez, _обоє_, --, 
   {{0x7d1c1570,0xc98400f5,0xd1c80092,0x00000000}},	//   _uoss, гучи, _ጠየቀ_, --, 
   {{0x7988d1a5,0x7bccb866,0x64440162,0x97a4013d}},	//   _view, quau, úkil, хрел, 
   {{0xb87c00c8,0x59000135,0x3668d1a6,0x394c00df}},	//   _kaŭz, _ཚོམས_, мало_, _ĉesu_, 
   {{0x7528066d,0x39b0016b,0xb98404a2,0xc6a4d1a7}},	//   tkez, kɑsɑ_, _атақ, урчи, 
   {{0xb87c0115,0x62980393,0x73e449c4,0xd34401d5}},	//   _maŭz, ecto, воиз, کیته_, 
   {{0x7528d1a8,0xb87c01e4,0xdee80092,0x00000000}},	//   rkez, _laŭz, ሆንና_, --, 
   {{0x69c80261,0x49b801ed,0x6728007c,0xc3e400ae}},	//   áfeg, _زاہد_, ckfj, اثيو, 
   {{0x6f1cd1a9,0xb87c00df,0x00000000,0x00000000}},	//   _ropc, _naŭz, --, --, 
   {{0x2ea8095f,0x6f1cd1aa,0x62980327,0x224800d0}},	//   कर्त, _sopc, acto, úbka_, 
   {{0x3160011c,0x0be00150,0x81e40154,0x00000000}},	//   rokz_, _ﺇﻴﺎﻫ, নিষ_, --, 
   {{0xc0f01e38,0xf1d08da9,0x6f1c2a89,0xd378008e}},	//   _ልዑል_, _көмө, _qopc, _эче_, 
   {{0x6f1c00d7,0xa1900798,0x00000000,0x00000000}},	//   _vopc, _кајч, --, --, 
   {{0xa6c8045e,0x271c000d,0x81e40154,0x00000000}},	//   ল্পট, _बक्र_, নিশ_, --, 
   {{0x6f1cd1ab,0xdcac1a59,0xac8405f5,0xeb98d1ac}},	// [118c0] _topc, زىل_, тгал, физ_, 
   {{0x6f1c1711,0x81e400bd,0x5fb40302,0xaf0400c7}},	//   _uopc, নির_, _שהיא_, _рпол, 
   {{0xfe740323,0x6da4d1ad,0xada4d1ae,0x88c801ec}},	//   _бүр_, _جمجم, _шанл, екең_, 
   {{0x1e540375,0x6218008f,0x92040171,0xa8a01df2}},	//   _ישיר_, וועק, _glāž, рғақ, 
   {{0x6298d1af,0xac0801d5,0x97d406c2,0x00000000}},	//   ycto, _ўнга_, نظور_, --, 
   {{0xe0dc0086,0xb8648e33,0x00000000,0x00000000}},	//   jiòn_, دامو, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe8e8009f,0x2c6c0022,0xe0dc033b,0x44f40114}},	//   _ترسو_, _ẽdy_, nnòt_, упис, 
   {{0x69dc383d,0xfd680241,0x00000000,0x00000000}},	//   ltpe, _pipẹ, --, --, 
   {{0x6298d1b0,0x68e0d1b1,0x69dc017a,0x28dc06b1}},	//   ucto, lfod, otpe, फ्रि, 
   {{0x69dcd1b2,0x6298d1b3,0x9f4c0241,0x63bc00cd}},	//   ntpe, rcto, _ègé_, _āpnu, 
   {{0x64a4d1b4,0x68e0d1b5,0x212801ab,0x3ce00150}},	//   _рада, nfod, ukch_, _ﺇﻤﺎﻤ, 
   {{0x62980421,0x69dc25a3,0xfd6801e1,0x00000000}},	//   pcto, htpe, _tipẹ, --, 
   {{0x63a0d1b6,0x69dc1f53,0xe0dc0077,0xb87c010f}},	//   _iton, ktpe, ciòn_, _paŭz, 
   {{0x63a001a9,0x69dc0240,0x68e0007c,0x00000000}},	//   _hton, jtpe, kfod, --, 
   {{0xa3e40574,0x63a00083,0x61e8035a,0x69dc0fac}},	//   _पहा_, _kton, _ipfl, dtpe, 
   {{0x50b8a2f2,0x4c94d1b7,0x69dc037e,0x68e04161}},	// [118d0] _شديد_, риус, etpe, dfod, 
   {{0x69dc560b,0xe4e01092,0x63a0d1b8,0xbab40372}},	//   ftpe, क्ति_, _mton, اماب, 
   {{0x9a84d1b9,0x68e00368,0x99840118,0x9ba000cf}},	//   туал, ffod, ánů_, _چەرى, 
   {{0x63a0d1ba,0x23c01098,0x38343c18,0x08d40212}},	//   _oton, _शिंद, лнер, иція, 
   {{0x63a0d1bb,0x69dc045f,0x3f980135,0x08c4187f}},	//   _nton, atpe, nqsu_, рбін, 
   {{0x257804e6,0x61e803ac,0xe7b0027d,0x28a800cf}},	//   hëld_, _opfl, حمود, _үстү_, 
   {{0x63a0d1bc,0x69dc0d27,0x0a6800a8,0xe7141e87}},	//   _aton, ctpe, _арти_, ايىت_, 
   {{0x7440044e,0x7994009f,0x00000000,0x00000000}},	//   _ክትገብ, _iuzw, --, --, 
   {{0x494405f5,0x25bc097d,0x61e8d1bd,0xa854008e}},	//   _тэрб, _evtl_, _apfl, _бетә, 
   {{0x7994d1be,0x63a000ae,0xf2d814af,0x05e8013d}},	//   _kuzw, _dton, ربخش_, хфәи_, 
   {{0x63a0d1bf,0xe0dc0086,0x00000000,0x00000000}},	//   _eton, riòn_, --, --, 
   {{0x3494d1c0,0x386c0134,0x81e40eac,0x63a00240}},	//   _садр, _kyer_, নিং_, _fton, 
   {{0x79940b6f,0x2518011a,0x00000000,0x00000000}},	//   _luzw, _רונא, --, --, 
   {{0x386c01af,0xb1445183,0x720401f7,0x00000000}},	//   _myer_, _әнил, _موتم, --, 
   {{0x237465fe,0x386cd1c1,0x7bdc0166,0x68e00368}},	//   _حمود_, _lyer_, _aqsu, yfod, 
   {{0x63a002f0,0x527000d1,0xcca4035b,0x00000000}},	//   _yton, _йуқу, ргақ, --, 
   {{0x386cd1c2,0x6ae4030c,0xdcec00c0,0x68e0376e}},	// [118e0] _nyer_, лжаз, _licė, vfod, 
   {{0x79943dbc,0x3dd00472,0x257800e8,0x6d580129}},	//   _buzw, buzw_, mële_, étab, 
   {{0x386cd1c3,0x6ea836c7,0x68e0376e,0x00000000}},	//   _ayer_, _ज्यु, tfod, --, 
   {{0x386c32b8,0x69dcd1c4,0x00000000,0x00000000}},	//   _byer_, rtpe, --, --, 
   {{0x6d446f30,0x68e00cfd,0xa28002d3,0xe0dc0ba1}},	//   _imka, rfod, ነትናን_, diòl_, 
   {{0x386cd1c5,0x69dc324c,0x00000000,0x00000000}},	//   _dyer_, ptpe, --, --, 
   {{0x6b8c49f0,0x68e04b55,0x76a80212,0x7ae0002f}},	//   _iibg, pfod, ттів_, _ölta, 
   {{0x386c37b6,0x63a0004e,0x61e8002f,0x95d40395}},	//   _fyer_, _pton, _rpfl, удът_, 
   {{0xb7f000af,0x7c2804cc,0x833421ee,0x74400240}},	//   _आईएम_, _üert, иних, _ክትግብ, 
   {{0x6b8ca304,0x00000000,0x00000000,0x00000000}},	//   _jibg, --, --, --, 
   {{0x41546522,0x6d44d1c6,0x6b8c0003,0x00000000}},	//   ивос, _omka, _mibg, --, 
   {{0xd5ac03e6,0x6b8cd1c7,0x63a00337,0xe0dc0ba1}},	//   _رفه_, _libg, _tton, enòr_, 
   {{0x63a0d1c8,0x81e40154,0x2af4012d,0x232801f4}},	//   _uton, নিই_, ीयाँ_, _поди_, 
   {{0x6d440bd7,0x6b8c025c,0x3868067c,0x00000000}},	//   _amka, _nibg, üari_, --, 
   {{0xd2b427af,0x563c02d3,0x0dc81515,0xce5800c7}},	//   _גלות_, _ክንነብ, лути_, гарц_, 
   {{0x7994af78,0x13a40244,0x00000000,0x00000000}},	//   _ruzw, _جۆیی_, --, --, 
   {{0x6b8c04cc,0xdd901669,0xafc0a705,0x50d40372}},	// [118f0] _bibg, рағы, _мәрй, _ازىر, 
   {{0x386c1529,0x6d4402d0,0x0edc01ad,0x6b8c03b9}},	//   _ryer_, _emka, _बायड, _cibg, 
   {{0x6b8c30ac,0x386c0ac5,0x3ea00450,0x6d58d1c9}},	//   _dibg, _syer_, _ifht_, étac, 
   {{0xf8b01169,0x386c427b,0x0a68ad85,0x00000000}},	//   تکس_, _pyer_, уруи_, --, 
   {{0xb9640241,0x8f840014,0xdcec033f,0x00000000}},	//   _adìé, _خلیٖ, _chcą, --, 
   {{0x386cd1ca,0xa6c40408,0x9a841b0a,0x00000000}},	//   _vyer_, алша_, _бубл, --, 
   {{0x7bccd1cb,0xab604da8,0x799401f7,0xe73400a7}},	//   lrau, _بۇلى, _uuzw, рещ_, 
   {{0x386c07ab,0xf8b800c5,0x7ae4002f,0x00000000}},	//   _tyer_, _उजिय, lfht, --, 
   {{0x36d4d1cc,0xe3b40cab,0x7bccd1cd,0xdef002d3}},	//   _возр, абы_, nrau, ልስን_, 
   {{0x7bccd1ce,0x92b000cc,0x00000000,0x00000000}},	//   irau, টল্_, --, --, 
   {{0x7bccd1cf,0xb5948dc7,0x72781086,0xd164036b}},	//   hrau, _тиеш, ъсис_, йноқ, 
   {{0x7bccd1d0,0x4254013d,0xab64012d,0x3004004e}},	//   krau, стьт, _zażą, азмг, 
   {{0x3074010b,0x537c0023,0x68e40432,0x021800e5}},	//   рунс, _ብጥይት_, _ökde, نٹیں_, 
   {{0x6d440ac5,0x69d80fac,0xe2941a11,0xe454008f}},	//   _smka, _åteg, _каш_, _דינט_, 
   {{0x7bccd1d1,0x99d400bd,0xd344d1d2,0x00000000}},	//   erau, সবুক, _لیکه_, --, 
   {{0x92f005f5,0x6a1403b6,0x6b8c013d,0x701001e1}},	//   _түүх, یبار, _sibg, _ẹ̀ṣọ, 
   {{0x6b8c0142,0x7c280135,0x00000000,0x00000000}},	// [11900] _pibg, _żerr, --, --, 
   {{0xdaa4d1d3,0x6b8c01a9,0x3c180006,0x2078010f}},	//   ивуд_, _qibg, ыўся_, _באפא, 
   {{0xe9d8d1d4,0x6dbc0882,0xe8a41884,0xab640210}},	//   тке_, ṇabh, لماپ, _rażą, 
   {{0x7bccd1d5,0x6d44d1d6,0xa3e4084a,0x853c0153}},	//   brau, _umka, _पहल_, _atėn, 
   {{0x6d542747,0x7bccd1d7,0x6b8c0003,0x3cec00e4}},	//   mnya, crau, _tibg, _ñeva_, 
   {{0xe5c4d1d8,0x78ac0162,0x00000000,0x00000000}},	//   асио, ðavr, --, --, 
   {{0x6d54d1d9,0x75c8d1da,0xf8ac009d,0x00000000}},	//   onya, гтың_, _нө_, --, 
   {{0x6d54d1db,0xccf4013f,0xab640210,0xfd6c0092}},	//   nnya, neɛ_, _ważą, _ሰብስቦ_, 
   {{0x6d54d1dc,0x78ac568e,0xe4e000cd,0x00000000}},	//   inya, ñave, क्षि_, --, 
   {{0xdef002d3,0x2454035b,0x959400c7,0x6d54d1dd}},	//   ልትን_, лақь_, ытәу_, hnya, 
   {{0x6d54d1de,0x7bcc005f,0xd25402bf,0x2d9c00bc}},	//   knya, zrau, ицю_, ítel_, 
   {{0x7bccd1df,0x70200eac,0xd494033a,0x6d54013d}},	//   yrau, _পেইজ_, _крш_, jnya, 
   {{0xccf4016b,0x363400cf,0x6d540139,0x00000000}},	//   deɛ_, _پرەس, dnya, --, 
   {{0x6d54d1e0,0x7bcc05d5,0x3ef800a8,0xe4e02c2e}},	//   enya, vrau, ынгэ_, क्रि_, 
   {{0x9378008d,0x7050129e,0xa3e4000d,0x00000000}},	//   _שטות, قچیا, _पहँ_, --, 
   {{0x7bccd1e1,0x8d7402dd,0x6d54d1e2,0x80b402e8}},	//   trau, قاقا, gnya, _убих, 
   {{0x7bccd1e3,0x7b840131,0xfcc400d1,0xbc785541}},	// [11910] urau, مائە, _қәвм, убах_, 
   {{0x6d54052f,0x7bccd1e4,0xda0400d4,0x5b2400c7}},	//   anya, rrau, ичеп, шьба, 
   {{0xf77076b9,0xcb686a15,0x0b88d1e5,0x0a68d1e6}},	//   ۋات_, جمله_, рсти_, арци_, 
   {{0x7bccd1e7,0xc8c800ec,0xdcec00ef,0x00000000}},	//   prau, لومن_, _micī, --, 
   {{0x7bcc0369,0xb6a421d1,0x9ac401ed,0x6e440092}},	//   qrau, билл, _نگاہ_, _የሆነች, 
   {{0xf5480051,0x6d480241,0x00000000,0x00000000}},	//   hất_, _ìfar, --, --, 
   {{0x7c2cd1e8,0xab600220,0x8a1800d8,0xdef00b82}},	//   lyar, _عۇمى, _корс_, ልስና_, 
   {{0x668001b9,0x33d400d4,0xdb04005c,0x00000000}},	//   سینل, біот, ømær, --, 
   {{0x7c2cd1e9,0xd6d810e2,0xb7f01524,0x15f00037}},	//   nyar, _ате_, _आईटम_, _आनकर_, 
   {{0x6d540007,0x9780030f,0x85b88ec3,0x00000000}},	//   znya, _بیته, _چانس_, --, 
   {{0x7c2cd1ea,0x07080214,0x999c06be,0x98ac008e}},	//   hyar, _خيلي_, _ərşi_, logı_, 
   {{0x7c2cd1eb,0x645c0034,0x0584013d,0x2d9c29e8}},	//   kyar, _śpie, _дучм, ítem_, 
   {{0x7c2cd1ec,0x00000000,0x00000000,0x00000000}},	//   jyar, --, --, --, 
   {{0x7c2cd1ed,0x6d5402d0,0x8364d1ee,0x00000000}},	//   dyar, wnya, _ودول, --, 
   {{0xada40075,0x6da402f4,0x6d5400b8,0x26c00134}},	//   сабл, сиба, tnya, _ɛko_, 
   {{0x6da4d1ef,0x6d54d1f0,0x00000000,0x00000000}},	//   _қима, unya, --, --, 
   {{0x7c2c066d,0xa9683ba6,0x6d542c3e,0xc0f00092}},	// [11920] gyar, қида_, rnya, ልንም_, 
   {{0xccf40134,0x6d54d1dd,0x00000000,0x00000000}},	//   seɛ_, snya, --, --, 
   {{0xb4f81b57,0xfbd0278f,0x3a981b04,0x00000000}},	//   ्याय_, كتە_, ртую_, --, 
   {{0x7c2cd1f1,0x6d540007,0xf9680212,0x0eb8000d}},	//   byar, qnya, арій_, _अ़ँड, 
   {{0x7c2c0796,0x291007c4,0x2bb800c6,0x7b00005b}},	//   cyar, ıya_, _حاجة_, öytä, 
   {{0x2d98d1f2,0xd6cc02eb,0x6994d1f3,0xea88276c}},	//   _kupe_, فقه_, _грах, _مخزن_, 
   {{0x2b480936,0x2d98d1f4,0x6abc006f,0x00000000}},	//   _imbc_, _jupe_, mapf, --, 
   {{0x6abc06d6,0x2d98004c,0x98ac008e,0x6e380162}},	//   lapf, _mupe_, bogı_, útby, 
   {{0x2d98d1f5,0x55e000c7,0x9d180a7c,0xdcec0171}},	//   _lupe_, _ҭоуб, רופט, _sicī, 
   {{0x2bd800e1,0x6abcd1f6,0xc8d80cb4,0x00000000}},	//   यूया, napf, _डाँट, --, 
   {{0x26dc0393,0xa184010b,0x2d98d1f7,0xe7880150}},	//   _icto_, йымл, _nupe_, _ﺗﻮﺳﯟ, 
   {{0xd25404db,0x7c2cd1f8,0x6abcad0c,0xdfd800a7}},	//   сць_, yyar, hapf, лъг_, 
   {{0x6abcd1f9,0x39a00024,0x92b403d4,0x7c2cd1fa}},	//   kapf, _mėsa_, _ছাৰ_, xyar, 
   {{0x6d58d1fb,0x7c2cd1fc,0x2908016b,0xdcec00e2}},	//   étan, vyar, _ɔbaa_, _ticī, 
   {{0x6abc0526,0x2d98054e,0x6fcc0490,0xb6480092}},	//   dapf, _cupe_, _तिथू, _እንደጀ, 
   {{0x2d98d1fd,0x7c2c0a28,0x26dc0036,0x85900ef6}},	//   _dupe_, tyar, _lcto_, _ﺟﺎﺯﺍ_, 
   {{0x26dcd1fe,0x7c2c0357,0x6abc18f7,0x2d980de2}},	// [11930] _octo_, uyar, fapf, _eupe_, 
   {{0x6abc01b2,0x7c2cd1ff,0xec780408,0x00000000}},	//   gapf, ryar, ăпа_, --, 
   {{0x7c2c2c62,0x7d440201,0xeeb80032,0x853c0024}},	//   syar, _የፖለቲ, _өлөш_, _atėm, 
   {{0x26dcd200,0xcebc03be,0x391432f4,0x7c2cb180}},	//   _acto_, _şəxs_, юмер, pyar, 
   {{0x26dc01ee,0x6abc01b2,0xb90000e1,0xbac801d9}},	//   _bcto_, bapf, _दा_, _نژان_, 
   {{0xe7341377,0x6abc019f,0x00000000,0x00000000}},	//   жеш_, capf, --, --, 
   {{0xca24d201,0x09e401c6,0x2bd800bc,0xf988009a}},	//   _ефти, _ноён, यूठा, _ننسي_, 
   {{0xce380375,0x853c00c0,0x00000000,0x00000000}},	//   מאות_, _utėl, --, --, 
   {{0xb6480092,0xc4c4678e,0xd838009d,0x00000000}},	//   _እንዲጀ, ستيو, _сэв_, --, 
   {{0xf348d202,0x2d9cd203,0xd24001b9,0x00000000}},	//   рпол_, ítek_, змоқ, --, 
   {{0x74f806a6,0x0574d204,0x00000000,0x00000000}},	//   _веер_, _کالد, --, --, 
   {{0x6abcd205,0x955c001f,0x00000000,0x00000000}},	//   zapf, ቶቻችን_, --, --, 
   {{0x6abc0526,0xf1c4012c,0x13a4297d,0x46e000bc}},	//   yapf, _विकन, _انتی_, _नामह, 
   {{0xee38d206,0x2d98d207,0x3f8001ab,0xdfcc007b}},	//   анг_, _pupe_, _chhu_, ضيف_, 
   {{0xde005822,0x6abcd208,0xdee01985,0xc3040133}},	//   мпри, vapf, ьори, _ربوو, 
   {{0x853c0006,0x6abc0223,0x2ca80137,0x6cd40b61}},	//   _atėj, wapf, ркап_, تقرا, 
   {{0x6abcd209,0xeab82f16,0x00000000,0x00000000}},	// [11940] tapf, ийа_, --, --, 
   {{0x2d982f06,0x00000000,0x00000000,0x00000000}},	//   _tupe_, --, --, --, 
   {{0x6abc015c,0x00000000,0x00000000,0x00000000}},	//   rapf, --, --, --, 
   {{0x6abc004c,0xd97800d1,0x00000000,0x00000000}},	//   sapf, арчә_, --, --, 
   {{0x98a011ed,0xaae016d1,0xa7700150,0x00000000}},	//   фиче, _पापक, _ﺸﻬﺭﺓ_, --, 
   {{0xaa44010b,0x2cb012e8,0x00000000,0x00000000}},	//   _дегл, lbyd_, --, --, 
   {{0x7790d20a,0x3f4c01fa,0x00000000,0x00000000}},	//   ریما, džul_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x53940953,0x81e400fe,0x00000000,0x00000000}},	//   овыя_, নিছ_, --, --, 
   {{0x27e4d20b,0x2904419d,0x00000000,0x00000000}},	//   mton_, ldoa_, --, --, 
   {{0x2908013f,0xd754179e,0x9af4011a,0x00000000}},	//   _ɔban_, _ظلمت_, חזיק_, --, 
   {{0x2904d20c,0x25ac0998,0x6d5806af,0xe164007b}},	//   ndoa_, mpfl_, étal, تدخي, 
   {{0x27e4d20d,0x798001c7,0x41b40066,0x00000000}},	//   nton_, _ëlwe, _کمبر, --, 
   {{0x2d800270,0x27e4023a,0xfe7800bc,0x3ea408c2}},	//   _ahke_, iton_, řům_, ùlt_, 
   {{0x62645a42,0xdcb8d20e,0xce9406bb,0x3eac01e4}},	//   _باشق, ища_, даръ, ĝet_, 
   {{0x27e4d20f,0xa3ac49f1,0x200c00d8,0x8d8401c6}},	//   kton_, _ओझा_, _ágio_, дууд, 
   {{0xdfd806bb,0x27e4cb3c,0x2904005a,0x2ee80334}},	// [11950] _тъй_, jton_, ddoa_, bfbf_, 
   {{0x27e44ba8,0x3f80014b,0x6e280023,0xdce805d1}},	//   dton_, _uhhu_, ëmbë, ınıy, 
   {{0x27e4d210,0xc0f00023,0x00000000,0x00000000}},	//   eton_, _ውሑስ_, --, --, 
   {{0x67380579,0x27e4d211,0x6e18009f,0x00000000}},	//   _altj, fton_, _ايٽس_, --, 
   {{0xb6a4d212,0xd7f8d213,0x00000000,0x00000000}},	//   пилл, руе_, --, --, 
   {{0xb6a4d214,0x5fd0012c,0x96e80166,0x00000000}},	//   чикл, _तिनल, рьда_, --, 
   {{0x27e4426d,0x20080175,0x2578036e,0x00000000}},	//   aton_, hvci_, gëlo_, --, 
   {{0x27e4089c,0xdb1c0113,0x673800a2,0x29a400c7}},	//   bton_, muqñ, _eltj, _хырҳ, 
   {{0x394c0561,0x36d40276,0xf79800f2,0x5ed00154}},	//   _imes_, _ноар, _طناب_, দ্যে, 
   {{0x63a40174,0x00000000,0x00000000,0x00000000}},	//   íkna, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x05741a59,0x850400d1,0xf5480051,0x00000000}},	//   _قاند, _يولن, cấp_, --, 
   {{0x200cd215,0x394c009f,0x057400e5,0x6d58d216}},	//   _ágil_, _mmes_, _غامد, étam, 
   {{0xdb1c0309,0x63b40432,0x00000000,0x00000000}},	//   kuqñ, _çyna, --, --, 
   {{0x394c0793,0xc04c001f,0x551c000d,0x27e47b02}},	//   _omes_, ጀመረው, _मचाए_, zton_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x27e4d217,0x2cb0a689,0x9d40008e,0x00000000}},	// [11960] xton_, rbyd_, хетд, --, 
   {{0x394c0f85,0xa0640408,0x00000000,0x00000000}},	//   _ames_, _хаьа_, --, --, 
   {{0x27e4d218,0xaae06495,0xfe740046,0x802421f4}},	//   wton_, _पाठक, _жүр_, _فریم, 
   {{0x0edc0316,0x27e4d219,0x613c0036,0x2d8000c5}},	//   _बाँड, tton_, _gëld, _uhke_, 
   {{0x2904d21a,0x27e4023a,0x6c7428f3,0x00000000}},	//   rdoa_, uton_, _хунх, --, 
   {{0x27e4d21b,0x394cd21c,0xc8d800c5,0xfbd40154}},	//   rton_, _emes_, _डाकट, _সৈকত, 
   {{0x27e4d21d,0x5690d21e,0x394c01f7,0x613c0036}},	//   ston_, нашт, _fmes_, _hële, 
   {{0xda5802e4,0x394cd21f,0xd8840014,0xaa4421f3}},	//   _הכלל, _gmes_, _کھمن_, _деҳл, 
   {{0x0edc0358,0x613c1bce,0x636801c6,0x00000000}},	//   _बांड, _jële, йрог_, --, 
   {{0x394c79eb,0x613c0036,0x00000000,0x00000000}},	//   _zmes_, _mële, --, --, 
   {{0x32dc000d,0x00000000,0x00000000,0x00000000}},	//   _मारऽ, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa4940115,0xdb1c02d1,0x6fcc09b2,0x00000000}},	//   _naϲi, yuqñ, _तिरू, --, 
   {{0x2bd801ad,0xdef801e0,0x00000000,0x00000000}},	//   यूसा, _һын_, --, --, 
   {{0x22480419,0x00000000,0x00000000,0x00000000}},	//   úbku_, --, --, --, 
   {{0x25780023,0x28e401ec,0xdef8d220,0x00000000}},	// [11970] vëll_, _ﺍﺤﺘﻠ, _лын_, --, 
   {{0xc68415fa,0x394c0003,0x613c01c7,0xe0dc0ba1}},	//   _مې_, _smes_, _wëld, riòu_, 
   {{0xf9f81375,0x394c00d8,0x00000000,0x00000000}},	//   تفاع_, _pmes_, --, --, 
   {{0xa3bc01f9,0x00000000,0x00000000,0x00000000}},	//   ेळा_, --, --, --, 
   {{0x25780a40,0xa49401e4,0x394c09a8,0x69d808fb}},	//   rëll_, _faϲi, _vmes_, _åten, 
   {{0xe298001e,0x25780200,0x00000000,0x00000000}},	//   _ngư_, sëll_, --, --, 
   {{0xdb1c0113,0xaae011bc,0x00000000,0x00000000}},	//   quqñ, _पातक, --, --, 
   {{0x394c310a,0xe3dc00cc,0xdef00b82,0x980400c0}},	//   _umes_, _বৈধব, _ውዱእ_, _нязд, 
   {{0xb4ac2007,0x395c0218,0xb3840209,0x3f9c0066}},	//   _कभी_, mnws_, млил, _éwuh_, 
   {{0xd7583047,0xe0dc011c,0x3a2c013a,0x2c0c00cd}},	//   _اجرا_, egò_, _řepy_, सितं_, 
   {{0x7e60002d,0xb634007b,0x5ee00011,0x00000000}},	//   ûlpl, _تفاع, য়াই, --, 
   {{0x604001f2,0x33d402dd,0x395c0042,0x00000000}},	//   _ọmaj, _жікт, nnws_, --, 
   {{0xe44c1fce,0x31a00210,0x00000000,0x00000000}},	//   _рж_, _wóz_, --, --, 
   {{0x7204004b,0xd34407d6,0x00000000,0x00000000}},	//   _يوشم, _ریجه_, --, --, 
   {{0x2d9c0231,0x2d94d221,0x5fd00490,0xe2800022}},	//   ête_, драс, _तिथल, _илши, 
   {{0x395c0218,0xe6b805dc,0x7058030d,0x00000000}},	//   jnws_, _ईज्ज, _майĕ, --, 
   {{0x5ed02aab,0xe0dc0100,0xe51c00cd,0x00000000}},	// [11980] দ্ধে, riòt_, भाति_, --, 
   {{0x78a80270,0x5fd005f9,0x8eb43e52,0xf1c023ef}},	//   _afev, _तितल, _سەرت, _शबान, 
   {{0x613c0036,0x1ae0299f,0x00000000,0x00000000}},	//   _wële, тохм, --, --, 
   {{0x395c0218,0x613c01c7,0xa3ac00e1,0x7a8401b9}},	//   gnws_, _tële, _ओझल_, رشلم, 
   {{0xa7840372,0x1c4000c0,0x00000000,0x00000000}},	//   وشتو, _аням, --, --, 
   {{0xb864d222,0x613c036e,0x645c0210,0x00000000}},	//   رانو, _këlc, _śpio, --, 
   {{0x395c01d4,0x310c00cd,0x00000000,0x00000000}},	//   bnws_, ियाः_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x671c3eaf,0x43940022,0xa6e40354,0xa804022e}},	//   पादक_, наис, _ожал, _юзал, 
   {{0xd88401d9,0x853c00c0,0x00000000,0x00000000}},	//   _کھۅن_, _suėd, --, --, 
   {{0x3d8802dd,0x09b000cc,0x00000000,0x00000000}},	//   _ﺣﺎﯞﭘ, _চয়তা, --, --, 
   {{0xd2546c60,0x356801ec,0x00000000,0x00000000}},	//   ьцы_, _ерін_, --, --, 
   {{0x6560201d,0x05741a71,0x32000142,0x00000000}},	//   _ijoh, _قاچد, _âhyn_, --, 
   {{0xc2100050,0xd1d0001f,0x00000000,0x00000000}},	//   _مٔت_, ራለች_, --, --, 
   {{0xe6c800e4,0xd24c00f3,0x2164130f,0x00000000}},	//   _ãrõñ, _рц_, _отиг, --, 
   {{0x613c1bce,0xe0dc004e,0x528000db,0x00000000}},	//   _wëlb, riòs_, _جلىك, --, 
   {{0x7b984e74,0x7b14d223,0x395c0218,0x00000000}},	// [11990] سپاس_, ндах, vnws_, --, 
   {{0x65600254,0x00000000,0x00000000,0x00000000}},	//   _ljoh, --, --, --, 
   {{0x656000c7,0x69d80423,0x30e400cd,0xd9740150}},	//   _ojoh, _åtel, _कामः_, _ﺸﻌﺭﻩ_, 
   {{0x6560069c,0xd254011a,0x261007b7,0x00000000}},	//   _njoh, ושבה_, थिनी_, --, 
   {{0x580001e0,0x3774004e,0x00000000,0x00000000}},	//   толғ, ныкс, --, --, 
   {{0x6560d224,0x395c0218,0x00000000,0x00000000}},	//   _ajoh, snws_, --, --, 
   {{0x19e000c7,0x00000000,0x00000000,0x00000000}},	//   _шәаҳ, --, --, --, 
   {{0x78a80433,0x00000000,0x00000000,0x00000000}},	//   _ufev, --, --, --, 
   {{0x6d58d225,0x6560020b,0x7f540083,0xe61001e1}},	//   étai, _djoh, kizq, _léèé, 
   {{0x6560014b,0xa0a00220,0xb22432b1,0xd3440133}},	//   _ejoh, ғард, емол, بیته_, 
   {{0x32102b57,0x00000000,0x00000000,0x00000000}},	//   ízy_, --, --, --, 
   {{0x69c80162,0xd58402f2,0x00000000,0x00000000}},	//   áfei, _تێبه_, --, --, 
   {{0xc30400e5,0x00000000,0x00000000,0x00000000}},	//   ربیو, --, --, --, 
   {{0xd34407d6,0xd3780276,0x733401ec,0xe45400df}},	//   _آیده_, _ьче_, _سىعا, _אינט_, 
   {{0x9f580548,0xd1f0001f,0xb640037e,0xd1b40014}},	//   _arqó_, ሌቶች_, _ｌｌ_, _کاڈا_, 
   {{0xa1c000a7,0xed5801f0,0x00000000,0x00000000}},	//   _сбъд, чоб_, --, --, 
   {{0xe7d803f4,0x2a7c0419,0x00000000,0x00000000}},	// [119a0] _ধন্য, _štb_, --, --, 
   {{0x2d9c06ed,0xc0f00023,0x1ae07abe,0x00000000}},	//   ítes_, ውዕል_, лоум, --, 
   {{0xe8f8d226,0xdeb825f9,0x5eb80375,0x00000000}},	//   зле_, _ממיל, _מזיק, --, 
   {{0xeb983f36,0x6dac00c7,0xaae000cd,0xd940d227}},	//   _ним_, _aĝag, _पावक, лехи, 
   {{0x6d54d228,0x613c1bce,0xc70800c7,0x00000000}},	//   miya, _jëla, мҭаз_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe63401c0,0x850401d3,0xa76400c7,0x00000000}},	//   эхдэ, ہوںن, _ҷкад, --, 
   {{0x6134006a,0x69dcd229,0x6dac01e4,0x69246135}},	//   _mûlê, mupe, _iĝad, _ямба, 
   {{0xd940d22a,0x68e00117,0x9fc8009e,0x18b0d22b}},	//   _сети, mgod, _লঙ্গ, _сәхр, 
   {{0xdef002d3,0x63b4010e,0xc1a40022,0x0edc0f4a}},	//   ውትን_, _çynm, кымқ, _बागड, 
   {{0x6d54d22c,0x00c80228,0x69dc7f58,0x656001e3}},	//   kiya, үлүк_, nupe, _tjoh, 
   {{0xba08069c,0x68e0d22d,0x6d54d22e,0x6560016c}},	//   _ወዲ_, ngod, jiya, _ujoh, 
   {{0x6d54d22f,0x5430179c,0x69dcd230,0x557400c8}},	//   diya, _مرور, hupe, _װעגן_, 
   {{0x69dcd231,0x6d540076,0xcf9816a4,0x903401f7}},	//   kupe, eiya, ејс_, اءَا, 
   {{0x63a0d232,0x6d54d233,0x68e0073c,0x7f540083}},	//   _huon, fiya, kgod, rizq, 
   {{0x6d54d234,0x63a0d235,0x69dccdc8,0x00000000}},	//   giya, _kuon, dupe, --, 
   {{0x68e0332e,0x63a002f6,0x7b840131,0x8d8401c6}},	// [119b0] dgod, _juon, نائە, уурд, 
   {{0x69dc090c,0x6d540009,0x88c400b8,0x00000000}},	//   fupe, aiya, _īśat, --, 
   {{0xda64d236,0x63a0d237,0x69dcd238,0x00000000}},	//   رائي, _luon, gupe, --, 
   {{0x6d545be5,0x44240208,0x68e0d239,0xf8b0583d}},	//   ciya, kxm_, ggod, شکر_, 
   {{0x63a0d23a,0xc5f8d23b,0x7d0c0008,0x7d1cd23c}},	//   _nuon, _apē_, mdas, _inss, 
   {{0x68e00077,0x5ed0015b,0xc1780153,0x6d580022}},	//   agod, দ্রে, otės_, étav, 
   {{0xc17802d5,0x63a000b5,0x7d0c03cb,0x00000000}},	//   ntės_, _auon, odas, --, 
   {{0x63a0d23d,0x7d0cd23e,0xc1780006,0x15900150}},	//   _buon, ndas, itės_, _ﺟﺎﺷﯩ, 
   {{0x7d0cd23f,0x63a0001e,0xa8200214,0x2454005c}},	//   idas, _cuon, _نکون, _rømø_, 
   {{0x63a0d240,0x6d54a175,0x7d0c02f6,0xc1780064}},	//   _duon, ziya, hdas, ktės_, 
   {{0x6d545975,0x7d1cd241,0xe0dc00a3,0x7d0c3d3c}},	//   yiya, _onss, tiòp_, kdas, 
   {{0x6d54d242,0x8504d243,0x2450a766,0x7d1c0472}},	//   xiya, _مومن, انیس, _nnss, 
   {{0x7d0c2c73,0x6d541148,0xaae00490,0x7528a84e}},	//   ddas, viya, _पालक, mjez, 
   {{0x6d54d244,0x75283d67,0x7d1cd245,0x7d0cc966}},	//   wiya, ljez, _anss, edas, 
   {{0x6d54d246,0x6da4052f,0xada4d247,0x68e0c80f}},	//   tiya, тиба, табл, ygod, 
   {{0x75280925,0x7d0cd248,0x261072d0,0x69dcd249}},	//   njez, gdas, थिती_, vupe, 
   {{0xeb98d24a,0xc0f00020,0xc2e811ba,0xdcac3b5f}},	// [119c0] диа_, ውንም_, _কোটি_, تىق_, 
   {{0x79880069,0x7d1c007f,0x613c00e8,0x75280ffb}},	//   _ahew, _enss, _jëln, hjez, 
   {{0xfbd0d24b,0x6d54d24c,0x3ed800c8,0x7d0c0882}},	//   لتە_, piya, _אַרא, bdas, 
   {{0x6d54d24d,0x6c8400c6,0x6f1c01f5,0x75280083}},	//   qiya, _للجم, _hnpc, jjez, 
   {{0x79880502,0x68e06044,0x6d580129,0x671c00bc}},	//   _dhew, rgod, étau, पालक_, 
   {{0x6a84d24e,0x29cc0784,0xd6cc036b,0x68e0015d}},	//   _алга, _añaš_, ققه_, sgod, 
   {{0x63a0d24f,0x69949d5c,0xf6880131,0x461416ac}},	//   _suon, _арах, ىڭمۇ_, اوبر, 
   {{0x63a09181,0x7988d250,0x75280240,0x048800ee}},	//   _puon, _ghew, gjez, нәли_, 
   {{0x63a00de4,0x168403e6,0x00000000,0x00000000}},	//   _quon, _یامێ, --, --, 
   {{0x63a0d251,0x7d0c00dd,0x6f0c004e,0xc1780024}},	//   _vuon, zdas, jdbc, ytės_, 
   {{0x7d0cd252,0xa504d253,0x61e8010a,0xfb14008f}},	//   ydas, _аялл, _qqfl, אַרט_, 
   {{0xdb0c00cf,0xd1b4072d,0x15900220,0x00000000}},	//   _etcè, کایا_, _ﺟﺎﺳﯩ, --, 
   {{0x74b0052f,0x14d405e1,0x7d0cd254,0x4fc4014b}},	//   _уҡыу, _יואל_, vdas, исра, 
   {{0xc0e44be7,0x533014b7,0x46b400c5,0x248400e5}},	//   _ምሳሌ_, _вешт, ुरिह, _izom_, 
   {{0x13980375,0x0dc80a42,0x7d0c467e,0xdd98d255}},	//   _קבוע, кути_, tdas, дша_, 
   {{0xe7d006ab,0xc1780006,0x7d0cd256,0xc0ec0023}},	//   _सिंप, rtės_, udas, ህቦም_, 
   {{0x7d0cd257,0x2bd80d01,0x69ccd258,0xc17802d5}},	// [119d0] rdas, यंगा, _avbe, stės_, 
   {{0x7d0c29ef,0x7988d259,0x7528242b,0x6f1c01ab}},	//   sdas, _shew, zjez, _gnpc, 
   {{0x3ea01730,0x613c1bce,0xc0e40023,0x7d600092}},	//   _ight_, _jëlo, _ምሳሕ_, _ለፖለቲ, 
   {{0x18b0052f,0x6d58d25a,0x7d0c1290,0x09e400d4}},	//   рҙар, état, qdas, роїн, 
   {{0x3868d25b,0x79881682,0x75280841,0xe61401ec}},	//   çar_, _vhew, vjez, ғды_, 
   {{0x38681f21,0x81b8045e,0x79882887,0x7bcc96d8}},	//   ħar_, _চিন_, _whew, msau, 
   {{0x7988d25c,0x7bcc0c86,0x248405da,0x613c036e}},	//   _thew, lsau, _azom_, _nëlo, 
   {{0xb4ac05ba,0x7988014b,0x7bcc01b8,0xf50417a0}},	//   कडे_, _uhew, osau, узио, 
   {{0xd874d25d,0xf2a4d25e,0x3ea0062c,0x752806e8}},	//   _شارب, липп, _oght_, rjez, 
   {{0x7ae4d25f,0x7bcc08a1,0xb6c801d3,0x00000000}},	//   nght, isau, _سائے_, --, 
   {{0x7ae4d260,0x7bccd261,0x24840165,0x35b4d262}},	//   ight, hsau, _ezom_, _сбер, 
   {{0x3ea00731,0x6d1002ab,0x7bcc0108,0x00000000}},	//   _aght_, _ढोंग_, ksau, --, 
   {{0xdb0c2b76,0x00000000,0x00000000,0x00000000}},	//   _etcé, --, --, --, 
   {{0x613c04c4,0xa8000086,0x3ea00142,0x7bcc12e8}},	//   _hëll, ûñij, _cght_, dsau, 
   {{0xe29400d1,0x613c0200,0x7bcc00c0,0x6b6400c7}},	//   _йаш_, _këll, esau, ҳкаа, 
   {{0x1d042e5d,0x613c00e8,0x7bccd263,0x2f545183}},	//   леси_, _jëll, fsau, _әтис, 
   {{0xdcac76b9,0x7bccd264,0x613c0221,0xd004d265}},	// [119e0] سىل_, gsau, _mëll, _топқ, 
   {{0xaf04d266,0x5fb80375,0x7ae40076,0xf2d40154}},	//   _спол, _רצינ, gght, ত্রণ, 
   {{0x7bcc0421,0x6d58003e,0xe7c421f2,0x00000000}},	//   asau, étas, रीनप, --, 
   {{0x7ae40731,0x7bcc0e78,0xb4ac0073,0x5ea80154}},	//   aght, bsau, कडो_, করণে, 
   {{0x6eb81b61,0x7bcc00ef,0x00000000,0x00000000}},	//   ्रपु, csau, --, --, 
   {{0xd9400116,0x257804e6,0x00000000,0x00000000}},	//   _һеси, hëlt_, --, --, 
   {{0x613c0221,0x2d9004ba,0xca2801ec,0xbb701c3e}},	//   _bëll, omye_, _جۋان_, _بۇلع, 
   {{0x2d9002e2,0x2b580009,0x295402e8,0x6a840b01}},	//   nmye_, lipc_, _съгр, _алҳа, 
   {{0x2d900337,0x613c0200,0xf4c002dd,0x795002f2}},	//   imye_, _dëll, _ﺭﻩﺗﻜ, _بێنا, 
   {{0x29240cf4,0x57f80375,0xf6d400c0,0x00000000}},	//   štač_, _אלמו, _віця, --, 
   {{0x613cd267,0x52100276,0x00000000,0x00000000}},	//   _fëll, бдэт, --, --, 
   {{0x613c04c4,0x64a476b6,0x7bccd268,0xc0c40aac}},	//   _gëll, _сада, ysau, шшоқ, 
   {{0x261000dc,0x00000000,0x00000000,0x00000000}},	//   थिवी_, --, --, --, 
   {{0x645c012d,0x35a80456,0x00000000,0x00000000}},	//   _śpiw, _चूड़, --, --, 
   {{0x46ac0118,0x00000000,0x00000000,0x00000000}},	//   _चलनह, --, --, --, 
   {{0x7bccd269,0x613c002e,0x409401b9,0x3cb40209}},	//   tsau, _xëll, _پلخر, рйар, 
   {{0x3b54d26a,0xbed40798,0x00000000,0x00000000}},	// [119f0] акар, _копј, --, --, 
   {{0x7bccd26b,0x6d58d26c,0x7ae4d26d,0x3ea0d26e}},	//   rsau, étar, ught, _ught_, 
   {{0x7bccd26f,0x7ae4047e,0x81b800cc,0x00000000}},	//   ssau, rght, _চিড_, --, 
   {{0x98c40597,0x7bccd270,0xb8140a5b,0x00000000}},	//   اغان, psau, идеј, --, 
   {{0xf770d271,0x69c806ea,0x46e00037,0x00000000}},	//   يات_, áfer, _नाखह, --, 
   {{0xaae00316,0x613cd272,0x6eb800dc,0xfa0400ec}},	//   _पाएक, _sëll, ्रयु, _پورٽ, 
   {{0x65c0a1be,0x613cd273,0x30e400cd,0x8f38010f}},	//   обща, _pëll, _कालः_, ראוו_, 
   {{0x613c044e,0x0b4c0020,0x395805d1,0x33f493fb}},	//   _qëll, _ሁለተኛ, _öss_, ачос, 
   {{0x613c044e,0x6eb83f55,0xcebc00ac,0x779800ee}},	//   _vëll, ्रमु, _şəms_, _акар_, 
   {{0x613c04c4,0x72c4010b,0x00000000,0x00000000}},	//   _wëll, шбоз, --, --, 
   {{0x320404cc,0xbb900150,0x00000000,0x00000000}},	//   uwly_, _ﺑﻮﻟﻪ_, --, --, 
   {{0xd3400214,0x6eb81bd6,0x1168104c,0x00000000}},	//   _گفتی, ्रभु, الحی_, --, 
   {{0x7fd40220,0x349402a9,0x2164013e,0x942000cf}},	//   йірі, _тадр, рияи_, _دوشۇ, 
   {{0xe0dc0ba1,0xd4c000fb,0xdb2001e1,0x00000000}},	//   lhòl_, _төҫк, _àrèm, --, 
   {{0xed58722e,0x00000000,0x00000000,0x00000000}},	//   вов_, --, --, --, 
   {{0x24900113,0xdca0d274,0xe0dc1497,0x2d9004ba}},	//   _źymi_, жати, nhòl_, umye_, 
   {{0x2d90d275,0xebe400d4,0x1d04167f,0x00000000}},	// [11a00] rmye_, розп, шети_, --, 
   {{0x6a8405f5,0x6ab4d276,0xee3801f4,0x00000000}},	//   алза, рсах, _ано_, --, 
   {{0x6f440014,0x00000000,0x00000000,0x00000000}},	//   _منکٔ, --, --, --, 
   {{0xaae005ba,0xb304031c,0x5ea803d4,0x71800092}},	//   _पाकक, _མིའང_, কৰদে, _የፃፉት_, 
   {{0x6d44d277,0x00000000,0x00000000,0x00000000}},	//   _ilka, --, --, --, 
   {{0x2610c6cd,0x6d440009,0x2fd000dc,0xd04406be}},	//   थिली_, _hlka, _mvyg_, _qdiə, 
   {{0x386c6a89,0x613c0de2,0x76a800d4,0xb6c400d4}},	//   _exer_, _sëlm, утів_, ссій, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x66e4147e,0x955025da,0xf9901867,0x00000000}},	//   _воза, تخوا, _ربِ_, --, 
   {{0x77900bce,0x69dc017a,0x00000000,0x00000000}},	//   _فینا, orpe, --, --, 
   {{0x6d44d278,0x95e80014,0xe61800d8,0x2508022e}},	//   _olka, _لبنہ_, _јде_, _ахло_, 
   {{0x69dcd279,0x92540c9e,0xe45801f4,0x00000000}},	//   irpe, рают_, _иже_, --, 
   {{0x32180882,0x661800f3,0x38ac0241,0x69dc0112}},	//   āsya_, _hrtk, _hóró_, hrpe, 
   {{0x6d44d27a,0x661802fb,0x38ac0248,0x6d58020c}},	//   _alka, _krtk, _kóró_, ètan, 
   {{0xce5800c7,0xd2b40677,0x91e00114,0x00000000}},	//   аарц_, _דלות_, _доје, --, 
   {{0x9298025f,0xbea400ee,0x25dc07af,0x6d5800e4}},	//   _ביות, раңк, _गिनी_, étap, 
   {{0x613c002e,0x69dc04e6,0x38ac0248,0x853c0153}},	// [11a10] _lëlk, erpe, _lóró_, _nuėm, 
   {{0x6d44d27b,0x2018d27c,0xdd90678d,0x6dac00df}},	//   _elka, _irqi_, сағы, _iĝan, 
   {{0x98bc0fcf,0xce68023a,0x38ac01e1,0x00000000}},	//   _smuđ_, _вряд_, _nóró_, --, 
   {{0xae180302,0x98b400d1,0x8d600092,0x00000000}},	//   _עורכ, рһат_, _ተገቢው_, --, 
   {{0x1b0c00bd,0x661800fd,0x69dc0268,0x00000000}},	//   সাবে_, _artk, arpe, --, 
   {{0x38ac0241,0xdb203ee6,0x3668d27d,0x3ce80254}},	//   _bóró_, _بوسی, лало_, lgav_, 
   {{0x69dc00f3,0x6eb800cd,0xca54010a,0xe7340395}},	//   crpe, ्रतु, _мĕшп, сещ_, 
   {{0x98ac031c,0x3ce8d27e,0x15900220,0xe51c0118}},	//   digħ_, ngav_, _ﺟﺎﺗﯩ, भागि_, 
   {{0x66180139,0x1ca80327,0x00000000,0x00000000}},	//   _ertk, _པཅན_, --, --, 
   {{0x38ac01e1,0x195401e0,0x98ac031c,0xc8c801d3}},	//   _fóró_, _сағы_, figħ_, _موہن_, 
   {{0x201802d1,0x6dac01e4,0x8468001f,0x00000000}},	//   _arqi_, _aĝan, ችላለን_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x0574d27f,0xd3a41cc9,0xcfa00131,0x307400cf}},	//   _بالد, _треп, _ﺋﻮﺭﯗ, сунс, 
   {{0x395c02c4,0x59a42208,0x853c0024,0x6e380158}},	//   hiws_, गदार, _nuėj, øtbo, 
   {{0x6adc00bd,0xb1b40736,0x00000000,0x00000000}},	//   ন্ডো, _احتش, --, --, 
   {{0xc0e40092,0x00000000,0x00000000,0x00000000}},	//   ምቷል_, --, --, --, 
   {{0x5f4001d5,0x395c0142,0x6d4400d7,0x00000000}},	// [11a20] زچیل, diws_, _vlka, --, 
   {{0x7c64d280,0xa8040588,0x6e4400f3,0x159001ec}},	//   زاقل, heñó, _геоз, _ﺟﺎﺑﯩ, 
   {{0xe9d8d281,0x69dc01a4,0xed58d282,0x853c0153}},	//   уке_, urpe, _бон_, _suėm, 
   {{0x6d44503a,0xda6c0050,0x00000000,0x00000000}},	//   _ulka, رُن_, --, --, 
   {{0xe7380577,0x6b8c0175,0xc6c80131,0x18640114}},	//   лед_, _thbg, иқад_, баци_, 
   {{0x782400c6,0x7cf02805,0xdd8c01e2,0xa09800d9}},	//   تعمل, póró, _يوی_, אינט, 
   {{0x75c800ee,0xa9689808,0x3a280724,0xa5c402d2}},	//   атың_, _бива_, _керү_, dmóð, 
   {{0xc808004b,0x613c01c7,0x395c55e9,0x00000000}},	//   _نښته_, _vëlk, ciws_, --, 
   {{0x68441c13,0xd4940724,0x290401f7,0xe7d00037}},	//   _унаа, йрь_, meoa_, _सिटप, 
   {{0x27e494da,0x2904d283,0x1b0c015b,0x69d833b8}},	//   muon_, leoa_, সাথে_, _åtes, 
   {{0x26cc013b,0x27e4010f,0x661802d0,0xdb78010f}},	//   mafo_, luon_, _urtk, רניכ, 
   {{0x26ccceca,0xddc8003d,0x1a98008f,0x853403e6}},	//   lafo_, ġiżl, טייע, _گوڵچ, 
   {{0x29040a73,0x27e451e2,0x613c00e8,0xf77001d9}},	//   ieoa_, nuon_, _jëli, _راے_, 
   {{0x26cc0134,0x3ea408fb,0x2ee800e4,0xb3440205}},	//   nafo_, ølt_, ggbf_, reçç, 
   {{0x27e40589,0x290401c4,0x3ce807c5,0xa2240066}},	//   huon_, keoa_, tgav_, _درشه, 
   {{0x52800491,0x27e4d284,0x26cc0109,0x0d2c0023}},	//   _عليك, kuon_, hafo_, _ተኻፈል, 
   {{0x26ccd285,0x4c94d286,0x290405f5,0x3ce8050a}},	// [11a30] kafo_, зитс, deoa_, rgav_, 
   {{0x27e4d287,0x6e28145e,0x101402dd,0x00000000}},	//   duon_, êmbë, _ءبيد, --, 
   {{0x3ce8d288,0x29040421,0x26cc0134,0x613c0240}},	//   pgav_, feoa_, dafo_, _pëlh, 
   {{0x224800d0,0xc8c8009f,0x95b000ee,0x2fd00166}},	//   úbky_, مومن_, үрйә, _ängä_, 
   {{0x27e40004,0x26cc0607,0xccf4016b,0x6adc00fe}},	//   guon_, fafo_, rnɛt_, ন্ধো, 
   {{0x6dac01e4,0x7c2cb75f,0x613c036e,0x00000000}},	//   _oĝal, mxar, _dëli, --, 
   {{0xa5c406ea,0x7c2c03b9,0x00000000,0x00000000}},	//   vmóð, lxar, --, --, 
   {{0x27e4d289,0x6adc045e,0x9c1002e3,0x2618007d}},	//   buon_, ন্দো, họmm, _मछरी_, 
   {{0x69d80628,0x7c2cd28a,0x613c01c7,0x26cc0798}},	//   _åter, nxar, _gëli, bafo_, 
   {{0x95c8016c,0x7c2c5efb,0x2d9c00c7,0x88c400b8}},	//   _буда_, ixar, ítez_, _īśit, 
   {{0x85b80682,0xa5c4148b,0x00000000,0x00000000}},	//   _هانس_, rmóð, --, --, 
   {{0x71582cdd,0x00000000,0x00000000,0x00000000}},	//   ррос_, --, --, --, 
   {{0xd58404d3,0x7bd800d2,0x2978010f,0x00000000}},	//   _پێکه_, áwul, שטרא, --, 
   {{0x6da4d28b,0x3244010b,0x60cc0175,0x290401c4}},	//   жива, _мелг, aacm, zeoa_, 
   {{0xad58d28c,0x6e9401d5,0x2904009f,0x00000000}},	//   арах_, زلرا, yeoa_, --, 
   {{0x27e42819,0xafe400a8,0x2904005a,0x7054027d}},	//   yuon_, _доил, xeoa_, _ونغا, 
   {{0xaab8d28d,0x7c2c009a,0xccf801a9,0x00000000}},	// [11a40] لدار_, gxar, _ққа_, --, 
   {{0x26182871,0xca7c01a9,0x27e4010f,0xbad40006}},	//   _मछली_, _borа, vuon_, зіцы, 
   {{0x2904009d,0x98bc025c,0x26ccd28e,0x2c0800eb}},	//   teoa_, _xjuħ_, vafo_, রমেই_, 
   {{0x26ccd28f,0x27e4d290,0x3a98ccbc,0x7c2c004e}},	//   wafo_, tuon_, стую_, bxar, 
   {{0xc8cc0316,0x26cc03d1,0x06941884,0x00000000}},	//   ारबट, tafo_, ﻜﯩﻨﯩ, --, 
   {{0xd82005f5,0x290401c6,0x27e4d291,0x00000000}},	//   ьдчи, seoa_, ruon_, --, 
   {{0x26ccd292,0x27e4d293,0xcd48001f,0x613c1bce}},	//   rafo_, suon_, _ማከናወ, _wëli, 
   {{0x26ccd294,0x5ab40327,0xe9682c90,0x01d800cc}},	//   safo_, _བཅོམ, _табл_, _তহলদ, 
   {{0x98bc0421,0x27e40428,0xb864075e,0xe7641fbe}},	//   _uluā_, quon_, _فاكو, _двап, 
   {{0x228401d5,0x60cc058a,0x2be0d295,0x00000000}},	//   жумг, wacm, _पिना, --, 
   {{0xdb0c01d3,0x00000000,0x00000000,0x00000000}},	//   ödés, --, --, --, 
   {{0x7c2c0227,0x80b402ab,0xa2b807b7,0x98b000ef}},	//   yxar, ंडें, _श्र्, _ēdīs_, 
   {{0x60ccd296,0xf3f400f2,0x7c2c0327,0xe08400ae}},	//   racm, _فتوک, xxar, تجدي, 
   {{0x937400c6,0x60cc036e,0x00000000,0x00000000}},	//   _وصور_, sacm, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x91b4923f,0x7c2c01c0,0x00000000,0x00000000}},	//   _بطور_, txar, --, --, 
   {{0x613c04e6,0xdef800ee,0x7e980014,0x00000000}},	// [11a50] _sëlw, _кын_, _گندر_, --, 
   {{0x2b840a85,0x7c2c0665,0x13b8010f,0x00000000}},	//   nôch_, rxar, יזמע, --, 
   {{0x7c2cd297,0x9508031c,0xca7c01a9,0x7d440092}},	//   sxar, _ཁྲའི_, _qorа, _ከፖለቲ, 
   {{0x7c2c094a,0x89a800d4,0x9298011a,0x00000000}},	//   pxar, іків_, ביבת, --, 
   {{0x2be00ce0,0x2d9c0548,0x613c01c7,0xa800083c}},	//   _पिया, ïtee_, _wëlw, _çıld, 
   {{0xe734d298,0xfb3401c0,0xbb48007b,0xabb40166}},	//   зеш_, _энгэ, _السن_, _харә, 
   {{0x6dac0115,0x2b84002d,0x66b005d9,0x869802e8}},	//   _aĝaj, dôch_, رٽيء, отът_, 
   {{0xe4d00131,0x00000000,0x00000000,0x00000000}},	//   ىقىد, --, --, --, 
   {{0x78a80793,0x613c00e8,0x13a400f1,0x00000000}},	//   _igev, _jëlu, غندی_, --, 
   {{0x3f800161,0xf34800a8,0x16440137,0xe454d299}},	//   _nkhu_, спол_, _мүлк_, яжы_, 
   {{0x128413f9,0x613c002e,0x6d580066,0x83380395}},	//   تمدی_, _lëlu, ètak, ючът_, 
   {{0x1b400023,0x322c0240,0x00000000,0x00000000}},	//   ረሽበራ, _ብካልኣ, --, --, 
   {{0xe81c7db3,0x629c02f0,0x06941870,0xa064009d}},	//   पिया_, _úpon, ﻜﯩﻠﯩ, заяа_, 
   {{0xdfcc092f,0x55fc009e,0x753800a2,0x00000000}},	//   طيف_, ্মীক_, _howz, --, 
   {{0xeb340952,0xfe700050,0x510c030d,0x00000000}},	//   ۋىرد, ندِ_, _кĕвĕ, --, 
   {{0xf8a4d29a,0x78a8d29b,0x75380009,0x2ca80798}},	//   _لک_, _ngev, _jowz, скап_, 
   {{0x3f8003a0,0x75380209,0x1ee401b9,0x609400db}},	// [11a60] _fkhu_, _mowz, _کوپی_, _ىنىس_, 
   {{0x78a800a7,0x9508031c,0x2be00073,0xaf084954}},	//   _agev, _ཁིའི_, _पिठा, _اقدم_, 
   {{0xe8f801c0,0x00000000,0x00000000,0x00000000}},	//   йлж_, --, --, --, 
   {{0x29e000fb,0x628c0327,0x98700055,0x00000000}},	//   _үҙаң, żbog, _ṣā_, --, 
   {{0x2d801578,0x1864d29c,0x7c8001e0,0x97c0011c}},	//   _ikke_, паци_, _аҫта, ейче, 
   {{0x78a89fc6,0x98a094d6,0x37a801ec,0x00000000}},	//   _egev, хиче, ітін_, --, 
   {{0x78ac04b9,0xdb0c01ed,0x8654074d,0xd5b4d29d}},	//   žava, _utcá, ьккх, псы_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7538010b,0x284814fb,0xe73828eb,0x1b0c0154}},	//   _dowz, _узап_, _леа_, সারে_, 
   {{0x613c01c7,0x36e401f0,0x00000000,0x00000000}},	//   _lëlt, _обуҳ, --, --, 
   {{0x2d80d29e,0x7538058a,0x91e00120,0x15e03d1d}},	//   _okke_, _fowz, ноќе, _गियर_, 
   {{0x6738d29f,0x3f800099,0xa28402d3,0x753800a2}},	//   _hotj, _skhu_, _ማዕከን_, _gowz, 
   {{0x67380032,0x00000000,0x00000000,0x00000000}},	//   _kotj, --, --, --, 
   {{0x67385c7e,0x2d80102c,0x2484009a,0x909800a7}},	//   _jotj, _akke_, _iyom_, явят_, 
   {{0x67380032,0x12f8011a,0xeeec000d,0x00000000}},	//   _motj, _להגב, _जारऽ_, --, 
   {{0x673875c4,0x3d9400f3,0x00000000,0x00000000}},	//   _lotj, фибр, --, --, 
   {{0x25a48133,0x00000000,0x00000000,0x00000000}},	// [11a70] _miol_, --, --, --, 
   {{0x2d809058,0x3f8003f0,0x6b5001bf,0x3b7c001f}},	//   _ekke_, _ukhu_, _lægf, ባሪዎች_, 
   {{0x2d800270,0x1fac02f5,0x62840034,0x613c00e8}},	//   _fkke_, _কবিস, ękow, _wëlu, 
   {{0x25a42165,0x832c025c,0x613c0036,0x00000000}},	//   _niol_, _ཧོའུ_, _gëlt, --, 
   {{0x2484d2a0,0x6738d2a1,0x00000000,0x00000000}},	//   _nyom_, _botj, --, --, 
   {{0x2be01157,0x00000000,0x00000000,0x00000000}},	//   _पिता, --, --, --, 
   {{0x24847dec,0x6dac01e4,0x67381710,0xe9f00124}},	//   _ayom_, _eŝaf, _dotj, _аҧхы, 
   {{0xb92422e0,0x82e80489,0x25dc1524,0x05540104}},	//   _تفري, _འཐུའ, _गिरी_, етья, 
   {{0x394cd2a2,0x25a4d2a3,0xd3a00058,0xe0dc180f}},	//   _iles_, _diol_, нлиқ, nhòu_, 
   {{0x67380cf4,0x3244399a,0x7538045a,0xe72c0133}},	//   _gotj, деог, _wowz, _پڵه_, 
   {{0x25a4d2a4,0x66f00bc0,0x394c0fac,0x74f801af}},	//   _fiol_, _घातक_, _kles_, _межр_, 
   {{0x2ec429d9,0x6fb001f9,0x00000000,0x00000000}},	//   वर्त, _इंदू, --, --, 
   {{0x020402dd,0x00000000,0x00000000,0x00000000}},	//   _үзін, --, --, --, 
   {{0x394cd2a5,0xe81c2e35,0x00000000,0x00000000}},	//   _lles_, पिता_, --, --, 
   {{0xe8200118,0x00000000,0x00000000,0x00000000}},	//   _měšť, --, --, --, 
   {{0x61fc01b8,0x394c067c,0xa1840801,0x82340014}},	//   _äpla, _nles_, _обща_, _سر٘ا, 
   {{0xfe7015fa,0x248401d4,0x00000000,0x00000000}},	// [11a80] ندې_, _xyom_, --, --, 
   {{0x394c00a8,0x613c0036,0xeb98011c,0x46ac0037}},	//   _ales_, _fëls, циз_, _चलइह, 
   {{0x6cc4d2a6,0x6b50019b,0x394cd2a7,0x673801f5}},	//   _ойна, _lægg, _bles_, _rotj, 
   {{0x394cbcf6,0x1d80001f,0xed1000db,0xa84800d1}},	//   _cles_, _የሴቶች_, _جۋرگ, يلام_, 
   {{0x394c04cc,0x98a000f5,0x00000000,0x00000000}},	//   _dles_, вице, --, --, 
   {{0x394cd2a8,0x25a4d2a9,0x6dac00c7,0xe0dc0ba1}},	//   _eles_, _siol_, _aĝai, lhòt_, 
   {{0x394cd2aa,0x09d811ba,0x00000000,0x00000000}},	//   _fles_, _সহকা, --, --, 
   {{0xe0dc0561,0x394c007c,0x38780129,0xf67400db}},	//   nhòt_, _gles_, égré_, رۅنب_, 
   {{0x25a4d2ab,0x67381497,0x6b5001bf,0xaab0a71d}},	//   _viol_, _totj, _vægf, _जलाक, 
   {{0x25f40034,0xe51c000d,0x00000000,0x00000000}},	//   _एमपी_, _मोरि_, --, --, 
   {{0xe5a4352d,0x394c000d,0x25a4d2ac,0x777c013d}},	//   _жижи, _yles_, _tiol_, _ísxa, 
   {{0x74140451,0x27e40108,0xa50800d1,0x00000000}},	//   _ڳوٺا, oron_, _گىچە_, --, 
   {{0x27e4d2ad,0x00000000,0x00000000,0x00000000}},	//   nron_, --, --, --, 
   {{0x27e4068c,0x39940158,0x93400408,0x00000000}},	//   iron_, måse_, _инче, --, 
   {{0x27e4d2ae,0x4e28039b,0x3994005c,0x00000000}},	//   hron_, моён_, låse_, --, 
   {{0x26140037,0x00000000,0x00000000,0x00000000}},	//   _भईनी_, --, --, --, 
   {{0xc6848f38,0x27e47929,0x1ea83a16,0x00000000}},	// [11a90] _چې_, jron_, _وادي_, --, 
   {{0x27e4d2af,0x7f58188b,0xa3e438d2,0x4c940261}},	//   dron_, _хаос_, _बटन_, тиус, 
   {{0x394cd2b0,0x27e4d2b1,0x61f802c4,0x98b00427}},	//   _ples_, eron_, nttl, šeča_, 
   {{0x26dcd2b2,0xe0dc068c,0x9d240150,0xca4800f2}},	//   _adto_, chòt_, _تۋرك_, بلمه_, 
   {{0x7d0cd2b3,0x78ac08ad,0x27e4d2b4,0x25bc0334}},	//   meas, žavo, gron_, _attl_, 
   {{0xdb0402d3,0x61f805ac,0x3994005c,0x00000000}},	//   _mijë, kttl, dåse_, --, 
   {{0x27e4d2b5,0xdb040de2,0xb904015b,0xfbb437f3}},	//   aron_, _lijë, _বউ_, _अंडम, 
   {{0x27e4d2b6,0x7d0cd2b7,0x394c003e,0x00000000}},	//   bron_, neas, _ules_, --, 
   {{0x25bc0036,0xe0dc007f,0x00000000,0x00000000}},	//   _ettl_, tkòn_, --, --, 
   {{0x7d0cd2b8,0x2be0d2b9,0x6b50037e,0x00000000}},	//   heas, _पिसा, _vægg, --, 
   {{0x1d380020,0x7d0c049b,0xe1f48159,0x00000000}},	//   _የገንዘ, keas, нгэ_, --, 
   {{0x7d0cd2ba,0xe28c0032,0xdb040240,0xafe4030d}},	//   jeas, _ҡа_, _bijë, номл, 
   {{0x7d0cd2bb,0xf4281def,0x6b500eef,0xe0dc007f}},	//   deas, _холл_, _hæge, pkòn_, 
   {{0xb8d0081f,0xa8540375,0xe0dc007f,0xdb040200}},	//   _ནུ_, גישה_, lkòl_, _dijë, 
   {{0x7d0c03d5,0x6b501fcd,0x2d9434cb,0x2bd000dc}},	//   feas, _jæge, ерас, दीना, 
   {{0x27e4d2bc,0x7d0cbcec,0xf118c009,0x1fac0154}},	//   yron_, geas, _رغبت_, _কবরস, 
   {{0x6b50019b,0x33f80ba1,0x613c036e,0x2614000d}},	// [11aa0] _læge, nèx_, _gëlq, _भैनी_, 
   {{0x27e4d2bd,0xe0dc0100,0x952c0327,0x91d00037}},	//   vron_, hkòl_, _ཨོའི_, _दबाई, 
   {{0x7d0cd2be,0xdb04020c,0xada40353,0xe0dc00a3}},	//   beas, _mijè, _паол, mhòr_, 
   {{0x27e4d2bf,0x7d0cd2c0,0x25f408e9,0x6eb82802}},	//   tron_, ceas, _एमबी_, ्रकु, 
   {{0x5880d2c1,0x27e4d2c2,0x1af40183,0xe7840a5b}},	//   лыша, uron_, ীয়ে_, нуко, 
   {{0xdb04007f,0x33f8180f,0x6b50005c,0x61f801e3}},	//   _nijè, dèx_, _bæge, yttl, 
   {{0x27e4d2c3,0x6b5001bf,0x61f80175,0x95740092}},	//   sron_, _vægd, xttl, _ይህችን_, 
   {{0xdb0c068c,0x04881cd1,0x27e48170,0x76a800d4}},	//   _aucè, мәли_, pron_, фтів_, 
   {{0x2c40013f,0x853c0064,0x00000000,0x00000000}},	//   bɔde_, _suės, --, --, 
   {{0x26dcc95a,0xdb0c0561,0x7d0c0276,0xb9ec0023}},	//   _udto_, _cucè, zeas, _ሕቖ_, 
   {{0xdb041f5d,0x7d0c009a,0xf628007b,0x00000000}},	//   _dijè, yeas, _يسمى_, --, 
   {{0x613c044e,0x2900049f,0x39940267,0x9f480240}},	//   _pëlq, _ökad_, påse_, pucë_, 
   {{0x7d0cd2c4,0x65600280,0x613c0036,0x1dd01a4e}},	//   veas, _imoh, _dëlp, धीनत, 
   {{0x61fc01b8,0x6560014f,0x7d0c016b,0xdb040023}},	//   _äplo, _hmoh, weas, _vijë, 
   {{0xd24c73f9,0xe0dc0100,0x00000000,0x00000000}},	//   _сц_, lkòm_, --, --, 
   {{0xbacc0c58,0x2be0d295,0xdb04036e,0xad240014}},	//   _লাইছ, _पिशा, _tijë, پرٲو, 
   {{0x6560052f,0x63a8011f,0x69cc03ac,0x7d0cd2c5}},	// [11ab0] _mmoh, _kifn, _awbe, reas, 
   {{0x09d802f5,0x7d0cd2c6,0x2be01025,0xdd9014d4}},	//   _সহজা, seas, _पिरा, тағы, 
   {{0x7d0c16ca,0x65600588,0x63a80327,0x2d4c010b}},	//   peas, _omoh, _mifn, _iýen_, 
   {{0x62880334,0xb7bc0356,0x776002d0,0x63a808a5}},	//   _myfo, _arţa, _smlx, _lifn, 
   {{0xb908d2c7,0xdb0c00e4,0x5eb800b8,0x00000000}},	//   _मय_, _lucé, _ḍiṇḍ, --, 
   {{0x6560052f,0x34c8007a,0x7af4012d,0x1b08004e}},	//   _amoh, रर्द, _uczt, _ээмп_, 
   {{0x69cc0142,0xe73400a7,0x62884161,0x00000000}},	//   _gwbe, тещ_, _nyfo, --, 
   {{0xdb0c020c,0x1dd000dc,0x6b50005c,0x00000000}},	//   _sucè, धीयत, _væge, --, 
   {{0x338c044e,0x628802d0,0x00000000,0x00000000}},	//   _ሕብረተ_, _ayfo, --, --, 
   {{0x0b440020,0x6288d2c8,0x65604db4,0x6b5001bf}},	//   _የከተማ, _byfo, _emoh, _tæge, 
   {{0x628800a9,0x63a8025c,0x65600327,0x46f00046}},	//   _cyfo, _difn, _fmoh, _اۋىر, 
   {{0x628800a9,0x6f0c304b,0xdb047dec,0x63a80036}},	//   _dyfo, webc, _dijé, _eifn, 
   {{0x844401d9,0x62882bcc,0x30740120,0x8f8400d1}},	//   _مخول, _eyfo, тунс, лқил, 
   {{0x656002f0,0xe45400df,0x00000000,0x00000000}},	//   _zmoh, _שיסט_, --, --, 
   {{0x62880368,0x7bdc2729,0x7c28025c,0x00000000}},	//   _gyfo, _avsu, _ġera, --, 
   {{0x247c01f2,0x7c280841,0x1d040137,0x69cc015d}},	//   ịme_, _šera, кеси_, _rwbe, 
   {{0x2ca40037,0x00000000,0x00000000,0x00000000}},	// [11ac0] äod_, --, --, --, 
   {{0x442001e4,0x5f746b89,0x00000000,0x00000000}},	//   _ɩi_, _لاپر, --, --, 
   {{0xed58d2c9,0xa9a40801,0xe8f80953,0x6d5802e2}},	//   _жон_, вижд, дле_, ètas, 
   {{0xb9e40075,0x81bc005f,0xe8a4d2ca,0x00000000}},	//   اسلى, lvēc, نماپ, --, 
   {{0xdd8c03e6,0x7d080022,0x6b50005c,0xd9400114}},	//   _گوێ_, _ñesa, _vægb, јечи, 
   {{0xd7003500,0x69cc0142,0x2604bb65,0xf3f803d4}},	//   изчи, _twbe, вчиг, ্টাৰ_, 
   {{0xa968c2f3,0x442000e4,0x63a8d2cb,0xdd8c02f2}},	//   _жива_, _ũi_, _rifn, _دوێ_, 
   {{0xd94009f8,0x00000000,0x00000000,0x00000000}},	//   _кеси, --, --, --, 
   {{0x98a0d2cc,0x18a00166,0xdb0c0005,0xd940d2cd}},	//   _вите, _ватм, _sucé, _тети, 
   {{0xdc98010f,0xeeec000d,0x00000000,0x00000000}},	//   ויפל, _जागऽ_, --, --, 
   {{0x6d540882,0x3994007c,0xd6cc009f,0x00000000}},	//   khya, låsa_, _ذقن_, --, 
   {{0x6560209c,0x628802fb,0x403406a6,0x00000000}},	//   _umoh, _vyfo, гемс, --, 
   {{0x6d541161,0x5064d2ce,0x44200588,0xdb040098}},	//   dhya, атра, _éi_, _wijé, 
   {{0x6288d2cf,0x20e00051,0x60d803b2,0x764401f4}},	//   _tyfo, ổi_, ðumb, ähyg, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8d743abe,0xa3e41fd2,0x78ac0419,0x00000000}},	//   لاقا, _बटा_, ľavk, --, 
   {{0x78ac01a6,0x3ae800f2,0xda64132f,0x00000000}},	// [11ad0] žavk, فبای_, ھائي, --, 
   {{0x6d54d2d0,0x93f800d9,0x00000000,0x00000000}},	//   ahya, ולמי, --, --, 
   {{0x6d540a28,0x1bec000d,0x00000000,0x00000000}},	//   bhya, _चमकल_, --, --, 
   {{0x6d54d2d1,0x44e800cc,0xce680022,0x00000000}},	//   chya, ক্তক_, _шрыд_, --, 
   {{0x7d1c1d63,0x88c8003b,0x00000000,0x00000000}},	//   _iass, тлів_, --, --, 
   {{0x849002d3,0x7ac80014,0xdb040267,0x63b40432}},	//   _ምስራሕ_, _سورِ_, åmär, _çyny, 
   {{0x6444d2d2,0x00000000,0x00000000,0x00000000}},	//   økin, --, --, --, 
   {{0x7d1cd2d3,0x00000000,0x00000000,0x00000000}},	//   _jass, --, --, --, 
   {{0x7d1c982e,0x7988d2d4,0xb3845a3b,0x628c0793}},	//   _mass, _ikew, ллил, übon, 
   {{0x7d1cd2d5,0x95c8d2d6,0xd7640eff,0xf53800d7}},	//   _lass, _жуда_, _جەتى_, sjť_, 
   {{0x7d1c0076,0x32d800a2,0x628c0003,0x00000000}},	//   _oass, _aýyñ_, żbon, --, 
   {{0x7d1cd2d7,0xd58403e6,0x7bc00118,0x8504d2d8}},	//   _nass, _جێبه_, _člun, _نومن, 
   {{0x79880451,0x73e40261,0x09e017e6,0x6b5003b2}},	//   _mkew, _солз, _पट्य, _læga, 
   {{0x7d1cd2d9,0xde0000d1,0x00000000,0x00000000}},	//   _aass, әпти, --, --, 
   {{0x6d54d2da,0x7db4035b,0x06d8015b,0x7988d2db}},	//   thya, истц, _সামি, _okew, 
   {{0x798802e3,0xbacc015b,0xad24c019,0x6444d2dc}},	//   _nkew, _লাগছ, درسو, äkig, 
   {{0xeab00eff,0xeb2846ee,0x2b0000af,0xe7cc0154}},	// [11ae0] معا_, нжал_, _रउआँ_, _রম্য, 
   {{0x6d54d2dd,0x7988d2de,0x7d1cd2df,0x00000000}},	//   shya, _akew, _eass, --, 
   {{0x7d1cd2e0,0x2ef8009a,0x24980125,0xf1e02baf}},	//   _fass, _icpf_, _ቅድስት_, _বহুভ, 
   {{0xfe7478dc,0x6f1cd2e1,0x98ac0166,0xed583425}},	//   _түс_, _hapc, figı_, _чом_, 
   {{0x6f1cd2e2,0xf8a800ec,0x98b401ec,0x00000000}},	//   _kapc, ندهه_, уліт_, --, 
   {{0x779020bf,0x7d1cd2e3,0x7988d2e4,0x39940158}},	//   قیقا, _zass, _ekew, råsa_, 
   {{0x7d1cd2e5,0x6f1cd2e6,0x9f4807de,0xf6e40006}},	//   _yass, _mapc, ducì_, рцін, 
   {{0x7d1c6999,0xf8b402dd,0x00000000,0x00000000}},	//   _xass, _көш_, --, --, 
   {{0x98b001a6,0xc3540114,0xa3440fdc,0x236800f0}},	//   _šeće_, икиј, гэнл, ејно_, 
   {{0x6f1cd2e7,0x00000000,0x00000000,0x00000000}},	//   _napc, --, --, --, 
   {{0xd51001d9,0xd5c8022e,0x00000000,0x00000000}},	//   _گِند, _аxбо, --, --, 
   {{0x69dc0597,0x6f1c02d0,0xd254d2e8,0x84c40352}},	//   ispe, _aapc, уць_, _тәкд, 
   {{0x644400af,0x7c28031c,0x69dc343a,0xf3f800f1}},	//   äkid, _ġero, hspe, _لونګ_, 
   {{0x69dcd2e9,0x6f1cd2ea,0x7c280114,0x4424003a}},	//   kspe, _capc, _šero, mvm_, 
   {{0x69dc01f5,0x4424003a,0x78ac00d7,0x00000000}},	//   jspe, lvm_, ľavi, --, 
   {{0x69dc3899,0x7d1cd2eb,0x6f1c565e,0x6d58007f}},	//   dspe, _qass, _eapc, ètap, 
   {{0x7d1cd2ec,0x69dccd9c,0x3cf8017a,0x44240393}},	// [11af0] _vass, espe, _vcsv_, nvm_, 
   {{0x7d1cd2ed,0x6f1c009f,0x6618d2ee,0xda7802d5}},	//   _wass, _gapc, _ostk, няе_, 
   {{0x7d1cd2ef,0xae34030c,0xefd40092,0x00000000}},	//   _tass, _күрт_, ያየው_, --, 
   {{0xe0e40eac,0x7d1c003a,0x977001e0,0xc98400f3}},	//   গ্রহ_, _uass, өтлә, бучи, 
   {{0x6f1c3923,0x69dc0276,0x6444022c,0x661800d7}},	//   _yapc, aspe, økil, _astk, 
   {{0x99d4c2c9,0x3668d2f0,0x2b00000d,0x3788011c}},	//   _مترا, кало_, _रउएँ_, ъбло_, 
   {{0xf8c820ef,0xc8640022,0x00000000,0x00000000}},	//   _créé_, итәи, --, --, 
   {{0x2bd029d9,0x00000000,0x00000000,0x00000000}},	//   दीवा, --, --, --, 
   {{0x85080046,0xdb0c2d7b,0xeff00023,0x00000000}},	//   удың_, _lucí, ፍቅድ_, --, 
   {{0x33640b32,0xd7c4004b,0xa3e40d79,0x6b50005c}},	//   рвог, _لوړه_, _बटर_, _lægn, 
   {{0x6f1cd2f1,0xf9a801e1,0x7c282a4f,0x2fd005e4}},	//   _rapc, _gbèé_, _šerl, _swyg_, 
   {{0x6f1cd2f2,0xc4f800c6,0xdb0c0356,0xc17800c0}},	//   _sapc, _معها_, _jucâ, drės_, 
   {{0x60d80321,0x4424d2f3,0x00000000,0x00000000}},	//   ðuma, cvm_, --, --, 
   {{0x69dcd2f4,0x644402f6,0x6f1c047e,0x7f18d2f5}},	//   yspe, äkie, _qapc, лісу_, 
   {{0x92680166,0x02f400db,0x0d8401e0,0xcdc400d1}},	//   _ярда_, _اقىڭ, йһон, сабқ, 
   {{0xcdc40220,0x6f1c0051,0x00000000,0x00000000}},	//   _қамқ, _wapc, --, --, 
   {{0xab64d2f6,0x6b64035b,0x69dcd2f7,0x6f1cd2f8}},	// [11b00] авал, акаа, wspe, _tapc, 
   {{0x69dcd2f9,0xdbdc0162,0x2614000d,0x00000000}},	//   tspe, _víðv, _भईली_, --, 
   {{0x69dcd2fa,0x2be00490,0xfb880451,0x00000000}},	//   uspe, _पिका, ائقو_, --, 
   {{0x06d804c5,0xa3e40037,0x00000000,0x00000000}},	//   _সাধি, _बटल_, --, --, 
   {{0x1cac5078,0xdb0c054e,0xa2d40073,0x00000000}},	//   _ཕུག_, _ducâ, _मजल्, --, 
   {{0x5490001f,0xd704d2fb,0x66180175,0x18640e58}},	//   _ምስራቅ_, инче_, _pstk, шачи_, 
   {{0xdb04045f,0x9f480ecf,0x2bd00d79,0x00000000}},	//   _fijâ, lucã_, दीरा, --, 
   {{0xdb0c019f,0x61fc0793,0x249802d3,0x4424003a}},	//   _gucâ, _äpli, _ቅትለት_, tvm_, 
   {{0xd49400a8,0xe7a8d2fc,0x00000000,0x00000000}},	//   ирь_, _авал_, --, --, 
   {{0x29040421,0x44240381,0x9f480118,0x2b580051}},	//   lfoa_, rvm_, tucí_, nhpc_, 
   {{0x7c28003d,0xe81c262c,0x6618d2fd,0x00000000}},	//   _ġerm, पिका_, _ustk, --, 
   {{0x2b04385b,0x8c48046c,0xd5ac2088,0x613c01c7}},	//   स्तु_, _kağı, _قفل_, _hëlz, 
   {{0x29040421,0x64a4d2fe,0x01a80139,0x00000000}},	//   ifoa_, _тада, ккүк_, --, 
   {{0x98bc008e,0x9f480118,0x626400d1,0x00000000}},	//   _oluğ_, pucí_, _پاتق, --, 
   {{0x1cac003d,0x139806a9,0x53980302,0xc1780006}},	//   _ཕུང_, _שבוע, _שיוו, urės_, 
   {{0x3a2cd2ff,0x3a740032,0x0dc8d300,0x00000000}},	//   _čep_, ҡлар, рури_, --, 
   {{0x3a741945,0x8c4800ac,0x3b54144d,0x2bd04982}},	// [11b10] әлер, _nağı, бкар, दीला, 
   {{0xdb0cd301,0xa0c000f1,0x6e9400f2,0xbf1400f1}},	//   _tucí, _ايښو, _گلپا, _اودب, 
   {{0x49b8d302,0x1dd807f7,0x2d9002e2,0x800801d3}},	//   لاند_, _बबित, blye_, _شرکہ_, 
   {{0x38347111,0x8c484947,0x7f440477,0x394c031c}},	//   йнер, _bağı, _hohq, _ċess_, 
   {{0xcd5002d3,0xdc34001f,0x8c484dd9,0xd7f863bb}},	//   _ዘለኣለ, _ከመሆኑ, _cağı, туе_, 
   {{0x8c486f30,0x29040421,0xb34400d8,0xf8b80055}},	//   _dağı, afoa_, _moçã, _daũa_, 
   {{0x6b5004ce,0x19a80387,0xb3440120,0x7f44014f}},	//   _mægl, _атап_, _loçã, _mohq, 
   {{0x74140597,0x98bc02fb,0x8c4806be,0x81ac03d4}},	//   موعا, _kouč_, _fağı, গৱত_, 
   {{0xb34406ed,0xe81c0cb4,0x76e80166,0x00000000}},	//   _noçã, _मईया_, _буең_, --, 
   {{0x437402bf,0x9f4808e5,0x7f44014f,0x00000000}},	//   жуют, jucà_, _nohq, --, 
   {{0xf1d00228,0x468002dd,0x78ac00d7,0x00000000}},	//   чөлө, _оқша, ľavu, --, 
   {{0x92d40c58,0x8c487230,0x613c036e,0xd6cc00eb}},	//   িলে_, _yağı, _këly, _রায়প, 
   {{0x7f44014f,0x73c40372,0x9f48026c,0x2164013e}},	//   _bohq, _ايتم, fucà_, сияи_, 
   {{0x7c6c001f,0x2480002d,0x00000000,0x00000000}},	//   _በመላው_, ûkme_, --, --, 
   {{0xed583a8a,0xe81c0db3,0xadb800ec,0x00000000}},	//   гов_, _मैना_, اهرا_, --, 
   {{0x5d640276,0xde0001b9,0x00000000,0x00000000}},	//   бисм_, япси, --, --, 
   {{0xdca007d6,0x2d90017a,0x6fb0033f,0x5ca00395}},	// [11b20] зати, rlye_, _इंटू, зитб, 
   {{0xef1815ed,0x6b5001bf,0x2d90007f,0x00000000}},	//   _смо_, _vægo, slye_, --, 
   {{0xfe74d303,0x8c48d304,0x2d90007f,0x00000000}},	//   _дүр_, _sağı, plye_, --, 
   {{0x08c83007,0x6e38002f,0x00000000,0x00000000}},	//   рғап_, ätbu, --, --, 
   {{0x6d4406c8,0x2be0166d,0x7f44047e,0x8c4800fd}},	//   _ioka, _पिटा, _yohq, _qağı, 
   {{0x6d44d305,0xa09804ac,0xd820234c,0x00000000}},	//   _hoka, ניסט, ядчи, --, 
   {{0x6d44d306,0xda60d307,0x8c480139,0x98bc0205}},	//   _koka, _еври, _wağı, _uluğ_, 
   {{0x6d44d308,0x8c482523,0x613c0036,0x2afc01f9}},	//   _joka, _tağı, _wëlz, _लाडु_, 
   {{0x6d44d309,0x26f801d5,0x6b5001bf,0x92d403d4}},	//   _moka, _مراخ_, _lægm, িলৈ_, 
   {{0x6d44d30a,0xdb0c00d2,0xe81c05f9,0x81bc005f}},	//   _loka, _kucá, _मैया_, bvēl, 
   {{0x6d44d30b,0x9f480ffb,0x6d58005f,0x60d803b2}},	//   _ooka, vucà_, ītaj, ðumo, 
   {{0xb3440798,0x7f440477,0x92540108,0x00000000}},	//   _poçã, _sohq, сают_, --, 
   {{0xd4641515,0xaf4402d3,0xe0dc0100,0xd404009d}},	//   _лице_, _ዓለምለ, dkòt_, _хvрт, 
   {{0x60740020,0x6d44d30c,0x7f44014f,0x81d4030d}},	//   _የንግድ_, _aoka, _qohq, _докх, 
   {{0x627000cf,0x6b50005c,0x00000000,0x00000000}},	//   _رۇحئ, _vægl, --, --, 
   {{0x22ac11a9,0x6d4488a1,0x9f680116,0x00000000}},	//   mək_, _coka, _әриз_, --, 
   {{0x13a404d3,0x22ac00ac,0xdef80961,0x81bc00de}},	// [11b30] _خۆیی_, lək_, _йын_, zvēl, 
   {{0x6d4403d1,0x6b5008a5,0xdb0401ef,0x1aa40114}},	//   _eoka, _hægj, _bijá, бјег, 
   {{0x6d44d30d,0xde44182f,0x22ac0213,0xc904012d}},	//   _foka, _ایزو_, nək_, रभूम_, 
   {{0x6d445bae,0xc9843cc5,0x00000000,0x00000000}},	//   _goka, пучи, --, --, 
   {{0xf744d30e,0x5b2406a6,0x00000000,0x00000000}},	//   жело, _льва, --, --, 
   {{0x7bccd30f,0x6d44055a,0xdb040789,0x6b504a21}},	//   mpau, _zoka, _fijá, _lægj, 
   {{0x6d44d310,0x870404b3,0x7c2805be,0x7bccd311}},	//   _yoka, سبول, _šerh, lpau, 
   {{0x22ac03be,0x6d44a376,0xe8e80014,0x7bccd312}},	//   dək_, _xoka, _پرٲو_, opau, 
   {{0xe3b40948,0x06d8015b,0xb7bc0356,0x6284002f}},	//   обы_, _সারি, _orţi, ßkon, 
   {{0x19544908,0x7bcc04cc,0x8c1c0375,0xc8641a71}},	//   _тағы_, ipau, רוזי, _этси, 
   {{0xd0640213,0x7bcc01f5,0xe0dc0100,0x22ac06be}},	//   ərəs, hpau, ykòt_, gək_, 
   {{0xa50804a9,0x33d40150,0x00000000,0x00000000}},	//   _نىمە_, _дікт, --, --, 
   {{0x6d44d313,0x7bccb87d,0xfbb4276a,0x00000000}},	//   _roka, jpau, _अंगम, --, 
   {{0x6d44d314,0xd344036b,0x22ac0213,0x93a40108}},	//   _soka, _چیکه_, bək_, _ушед, 
   {{0x22ac11a9,0xe0dc0428,0xa3ac0490,0x7bcc1543}},	//   cək_, baò_, _कळत_, epau, 
   {{0xacc800c7,0x6b500388,0x7bcc002f,0xdb0401ef}},	//   ргаз_, _vægm, fpau, _rijá, 
   {{0x6d44d315,0x7bcc89f7,0x6ab01788,0xc31c00eb}},	// [11b40] _voka, gpau, जश्र, তারি_, 
   {{0x6d44d316,0xda6c01d9,0xdcac00db,0xdb0401ef}},	//   _woka, ھُن_, ئىك_, _pijá, 
   {{0x3204771c,0x6d440c6d,0xe8f805f5,0x7bcc0607}},	//   ntly_, _toka, илж_, apau, 
   {{0x6d440069,0x00000000,0x00000000,0x00000000}},	//   _uoka, --, --, --, 
   {{0xa7a805bc,0x00000000,0x00000000,0x00000000}},	//   акда_, --, --, --, 
   {{0xba08015b,0x22ac0213,0xe5c40114,0x00000000}},	//   রয়েড_, yək_, осио, --, 
   {{0xd5b4d317,0xd54400b2,0x00000000,0x00000000}},	//   осы_, ڪليو_, --, --, 
   {{0x7c281505,0xca64039b,0xb864179e,0x00000000}},	//   _šeri, _деҳқ, _کافو, --, 
   {{0x1cac025c,0xe0dc033b,0x32042517,0xa5c41d1d}},	//   _ཕུབ_, chòy_, etly_, flóð, 
   {{0x3204d318,0x53a00220,0x22ac0213,0x24800092}},	//   ftly_, وميك, tək_, _ይድረስ_, 
   {{0x2c0400bd,0x91e00120,0x320400ee,0xe16800ae}},	//   রিয়ে_, моќе, gtly_, لصحه_, 
   {{0x81bc11f9,0x22ac0cc1,0x7bcc0076,0x00000000}},	//   lvēk, rək_, ypau, --, 
   {{0xe0dc0428,0x22ac0213,0x3204d319,0xf40c0133}},	//   raò_, sək_, atly_, _یڤی_, 
   {{0xdef8d31a,0x3204045a,0x3ce400b8,0x22ac03e3}},	//   шым_, btly_, _ślv_, pək_, 
   {{0x3204d31b,0x00000000,0x00000000,0x00000000}},	//   ctly_, --, --, --, 
   {{0x7bccd31c,0x1cac003d,0x395c0218,0x00000000}},	//   tpau, _ཕུད_, xhws_, --, 
   {{0x4c94d31d,0x3b54d31e,0xa3ac01f9,0x00000000}},	// [11b50] дитс, пкар, _कळा_, --, 
   {{0x7bccd31f,0x7f1812ea,0x00000000,0x00000000}},	//   rpau, _ايدز_, --, --, 
   {{0x39148374,0x7bccd320,0x0a68311b,0x998400bc}},	//   змер, spau, орци_, ínů_, 
   {{0x7bccd321,0x628c033f,0xf67401c6,0x00000000}},	//   ppau, żbow, үгдэ, --, 
   {{0xe81c1d34,0x00000000,0x00000000,0x00000000}},	//   _मैदा_, --, --, --, 
   {{0xfc5c001f,0x81bc00e2,0x00000000,0x00000000}},	//   ዲያገኙ_, rvēj, --, --, 
   {{0xd90c066d,0x6444d322,0x8b8800f7,0xd5a0d323}},	//   _لیا_, äkin, _بەلە_, ولتی, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x657cd324,0xb7d47b43,0x69d8d325,0xf3f000c6}},	//   épha, _رقاب, _æter, رأة_, 
   {{0x0cb8bd8d,0xd75400db,0x6d581a14,0x0b600092}},	//   _अल्म, _بئرب, ītai, _ለከተማ, 
   {{0xf6980150,0xa778010f,0xf48400e5,0x00000000}},	//   _اناع_, _פרעפ, _کاای, --, 
   {{0x3204d326,0x61ec01e7,0x00000000,0x00000000}},	//   rtly_, ábla, --, --, 
   {{0x3204d327,0x6598008d,0xab6001b8,0x538001d5}},	//   stly_, _פינק, üüko, _оқиз, 
   {{0xb8fc003d,0x13a401d3,0x83640150,0x32047c8f}},	//   _ལབ_, _بنتی_, _يدول, ptly_, 
   {{0x6da4d328,0xf3f80356,0xad5812e7,0x2b1400c7}},	//   зива, luţ_, брах_, ҟьар, 
   {{0xf8b8001e,0xefb80023,0xa19000d8,0x00000000}},	//   _ngũ_, ዳማይ_, _пајч, --, 
   {{0xaab8d329,0xf3f80276,0x81a42073,0x03b0002b}},	// [11b60] مدار_, nuţ_, _تحول, _hrīṃ_, 
   {{0xed14a735,0x03b00055,0x28cc000d,0x4db00150}},	//   _łódź_, _krīṃ_, हुनि, _ﺳﯟﯨﻨ, 
   {{0x69d800c6,0xdeb80375,0x2d9c1e7b,0x03b00055}},	//   صباح_, _למיל, ïtes_, _jrīṃ_, 
   {{0xda6001c0,0x7c280327,0xf9680212,0x9ac00135}},	//   эвхи, _ġerv, орій_, ċċar, 
   {{0x6b500a87,0x00000000,0x00000000,0x00000000}},	//   _lægi, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb0c0798,0x6b5001a8,0x6d54d32a,0x00000000}},	//   _sucç, _nægi, okya, --, 
   {{0x6d54d32b,0x00000000,0x00000000,0x00000000}},	//   nkya, --, --, --, 
   {{0x68e0d32c,0xc4340133,0xe76400d8,0x00000000}},	//   maod, بکات, _евап, --, 
   {{0x68e00bc8,0xdef01772,0x66e4322e,0xc0bc010c}},	//   laod, ፍትን_, _хожа, ሳያስ_, 
   {{0x6d5423db,0x98bc0327,0x6b50005c,0x00000000}},	//   kkya, _qmuħ_, _vægh, --, 
   {{0x26dc22d0,0x68e0d32d,0x55b802e4,0x03b00055}},	//   _heto_, naod, _המאו, _drīṃ_, 
   {{0x26dc044e,0x24a811ba,0xf3f80356,0xc1780064}},	//   _keto_, _গ্রহ, cuţ_, lsėk_, 
   {{0x27e42047,0x26dcd32e,0x68e0d32f,0xdb0c0139}},	//   ison_, _jeto_, haod, _xucä, 
   {{0x27e4d330,0x68e00099,0x26dcd331,0x00000000}},	//   hson_, kaod, _meto_, --, 
   {{0x26dcd332,0x61f8d333,0x1278010f,0x00000000}},	//   _leto_, mutl, _לאוע, --, 
   {{0x68e0d334,0x8d74d335,0x27e40cf4,0x61f8d336}},	// [11b70] daod, رافا, json_, lutl, 
   {{0x6d54d337,0x9f5c01e1,0x3ed400ae,0x00000000}},	//   akya, _òràn_, _تقدر, --, 
   {{0x98bc084c,0x7c280135,0x60dc036e,0x6cd402dd}},	//   _nouă_, _ġeru, _keqm, _ﺘﻘﺩﻴ, 
   {{0x26dc33db,0x7c280010,0x6d54d338,0x24980023}},	//   _aeto_, _šeru, ckya, _ቅድሚት_, 
   {{0x26dcd339,0x7d0c83a7,0x60dc047e,0x0c840022}},	//   _beto_, mfas, _meqm, _зырм, 
   {{0x7c2c60e2,0x61f8b6a3,0x26dc0c09,0xe734d33a}},	//   mvar, kutl, _ceto_, деш_, 
   {{0x26dc05b1,0x61f800c5,0x68e000d8,0x2d4c010e}},	//   _deto_, jutl, baod, _iýer_, 
   {{0x7d0cd33b,0x98bc00a8,0x61f8d33c,0xb3c8d33d}},	//   nfas, _două_, dutl, олиз_, 
   {{0xb4bc05ba,0xdc0800bd,0x490400cf,0xdb0400a2}},	//   _आली_, রিকস_, _سولق, _tijä, 
   {{0x26dcd33e,0x61f8073c,0x8d90001f,0x7d0cd33f}},	//   _geto_, futl, _መጥተው_, hfas, 
   {{0x61f8d340,0x7c2cd341,0x7d0cc323,0x60dc014f}},	//   gutl, hvar, kfas, _beqm, 
   {{0x7d0c01f5,0xafe401d5,0x33f400db,0x6b5002d2}},	//   jfas, момл, _жчкс, _vægi, 
   {{0x7d0cd342,0x60dc014f,0x75280489,0x2afca202}},	//   dfas, _deqm, mdez, _लालु_, 
   {{0xdfcc0491,0x61f8d343,0x7528d344,0x7d0c0549}},	//   شيف_, butl, ldez, efas, 
   {{0x7d0cd345,0x7c2cd346,0x61f803e0,0x7528d347}},	//   ffas, evar, cutl, odez, 
   {{0x7528d348,0xf8a4d349,0x6d54d34a,0x42a40150}},	//   ndez, _مک_, ukya, _ﺎﺭﺠﻲ_, 
   {{0x7c2cd34b,0x6d54d34c,0x7528a11b,0x68e00165}},	// [11b80] gvar, rkya, idez, vaod, 
   {{0xeab00a52,0x6d540158,0x27e4d34d,0xfbd000d1}},	//   نعا_, skya, vson_, چتە_, 
   {{0x26dcd34e,0x7c2c0eda,0xb4bc49fc,0xad2419c5}},	//   _reto_, avar, _आलू_, _قىدى, 
   {{0x27e4d34f,0x7c2cd350,0x752801f5,0x2d4c010e}},	//   tson_, bvar, jdez, _eýer_, 
   {{0xa8183b5f,0x26dcd351,0x7528d352,0x27e4004a}},	//   تتار_, _peto_, ddez, uson_, 
   {{0x27e40571,0x61f8d353,0x26dc0184,0x644400af}},	//   rson_, yutl, _qeto_, äkim, 
   {{0x26dcd354,0x27e4d355,0x75c83419,0x6e2c013f}},	//   _veto_, sson_, птың_, nvbb, 
   {{0x61f8d356,0x26dcd357,0x69cc014f,0x98bc054e}},	//   vutl, _weto_, _itbe, _vouă_, 
   {{0x26dcd358,0x61f800ee,0x60dc0204,0x27e4d359}},	//   _teto_, wutl, _reqm, qson_, 
   {{0x61f8d35a,0x2d800165,0x26dcd35b,0x06d8015b}},	//   tutl, _ljke_, _ueto_, _সাকি, 
   {{0x7c2c0e8a,0x6738d35c,0x7d0c495b,0xa010009e}},	//   zvar, _intj, yfas, িয়াব_, 
   {{0x7c2cd35d,0xb87c010f,0x60dc047e,0x61f8d35e}},	//   yvar, _feŭd, _qeqm, rutl, 
   {{0x7d0c0158,0x23282b45,0x6b5008a5,0x61f8d35f}},	//   vfas, _моди_, _hægu, sutl, 
   {{0x61f8d360,0x39943be7,0x6728d361,0x7c2c2994}},	//   putl, låst_, ndfj, vvar, 
   {{0x7d0cd362,0x6264d363,0x25a4d364,0xdbd40139}},	//   tfas, _تاشق, _khol_, _käçt, 
   {{0x8d8401c6,0x00000000,0x00000000,0x00000000}},	//   вууд, --, --, --, 
   {{0x7d0cd365,0xe81c1715,0x1fa441b9,0x69cc0413}},	// [11b90] rfas, _मैला_, _орог, _atbe, 
   {{0x7d0cd366,0x00000000,0x00000000,0x00000000}},	//   sfas, --, --, --, 
   {{0xdde8021a,0x3f90d367,0xdb0c00d2,0x7d0c1459}},	//   _برخه_, mozu_, _kucú, pfas, 
   {{0xb4bc05ba,0x8aa464d6,0x6738d368,0x7c2c5c04}},	//   _आले_, труд, _antj, pvar, 
   {{0x29e801e4,0xa3b801ad,0x98b000d0,0x52580240}},	//   aĝa_, _आंग_, šeľa_, _ጎይትኦ, 
   {{0x25a400dd,0x69cc00b5,0x3f900205,0x00000000}},	//   _ahol_, _ftbe, nozu_, --, 
   {{0x7ae4d369,0x2484067c,0x25a401ab,0x3f90009d}},	//   maht, _axom_, _bhol_, iozu_, 
   {{0x25a4d36a,0x6738d36b,0x7ae4d36c,0x6b5001a8}},	//   _chol_, _entj, laht, _dægu, 
   {{0x752800dd,0x25a40192,0x3f90005c,0x61e8007c}},	//   rdez, _dhol_, kozu_, _avfl, 
   {{0x0574d36d,0xb6c8066d,0x394cd36e,0x7bdcd36f}},	//   _یاند, _رائے_, _hoes_, _mwsu, 
   {{0x394cd370,0x3f90009d,0xdbd4005b,0x063800ae}},	//   _koes_, dozu_, _häät, _يسمع_, 
   {{0x04c8d371,0x25a4047e,0x6b50005c,0x92cc0011}},	//   _قومي_, _ghol_, _hægt, ষণে_, 
   {{0x394c0591,0xdbd418db,0x7ae416ca,0x44f8141b}},	//   _moes_, _jäät, kaht, _زرنج_, 
   {{0x7ae456e4,0x394cd372,0x2bb0007f,0x20a014d4}},	//   jaht, _loes_, _gņch_, ығың, 
   {{0xe294d373,0x7bdcd374,0xdbd400c5,0x6b501cf3}},	//   _паш_, _awsu, _läät, _mægt, 
   {{0xb4bc0490,0x61fc143a,0x7ae4062c,0x6b50005c}},	//   _आलो_, _åpla, eaht, _lægt, 
   {{0xa80003be,0x3f900098,0xdde000de,0xdbd40108}},	// [11ba0] _çıxd, bozu_, ērša, _näät, 
   {{0x6b50037e,0x317002fb,0xeb980107,0x00000000}},	//   _nægt, _hmyz_, чиз_, --, 
   {{0xa9f81cb8,0x00000000,0x00000000,0x00000000}},	//   яхах_, --, --, --, 
   {{0x394c015d,0x29e8008f,0x2d94004e,0x1da40092}},	//   _coes_, rĝa_, _чөгө_, _ለሴቶች_, 
   {{0x394cd375,0x2d901446,0x7ae4d376,0x25a40142}},	//   _does_, moye_, baht, _rhol_, 
   {{0x7ae40227,0x2d9007a9,0x25a40209,0x94f8025c}},	//   caht, loye_, _shol_, དཔའི_, 
   {{0x5690d377,0x672803d4,0x69cc1061,0x25a401ab}},	//   лашт, rdfj, _utbe, _phol_, 
   {{0x24841709,0x2d900223,0x394cd378,0x6b50d379}},	//   _pxom_, noye_, _goes_, _vægu, 
   {{0x2bb0007f,0x6b50005c,0x00000000,0x00000000}},	//   _pņch_, _fægt, --, --, 
   {{0x2d90015c,0x6738d37a,0x3f84110c,0x00000000}},	//   hoye_, _untj, čluk_, --, 
   {{0xd2541808,0x3f9083b2,0x6b50022c,0x25a40477}},	//   еця_, vozu_, _hægs, _thol_, 
   {{0x24840457,0x7ae40b3d,0x2bb0007f,0x25a400d0}},	//   _txom_, zaht, _wņch_, _uhol_, 
   {{0x4420068c,0xc5e800cc,0x7ae45f9c,0x00000000}},	//   _èi_, _খহটা_, yaht, --, 
   {{0x200801a6,0xd04400e5,0x5438010f,0x00000000}},	//   rtci_, اھٹي, _מעדא, --, 
   {{0x3f90037e,0x2d9000ca,0x7ae40f23,0x6b500ad9}},	//   rozu_, foye_, vaht, _lægs, 
   {{0x2d909d20,0x92980375,0x7ae43098,0xc034033a}},	//   goye_, _מיות, waht, _аниј, 
   {{0x7ae4d37b,0x394c3c75,0x3f90d37c,0x00000000}},	// [11bb0] taht, _roes_, pozu_, --, 
   {{0x6d58067d,0x2d90013f,0x394c017a,0xdbd416ca}},	//   ëtar, aoye_, _soes_, _räät, 
   {{0xf770d37d,0x2d900516,0xdbd402f6,0x394cd37e}},	//   یات_, boye_, _säät, _poes_, 
   {{0xdbd40664,0x7ae4d37f,0xc31c0154,0x870400d1}},	//   _päät, saht, তাটি_, ۇبىل, 
   {{0x7ae40664,0xb8e8069f,0x394c08cd,0x00000000}},	//   paht, _ईल_, _voes_, --, 
   {{0x394c0151,0x23a00252,0xdbd426bb,0xe7f0012d}},	//   _woes_, yðja_, _väät, _घिरा_, 
   {{0x6b5004ce,0x86980801,0x2bb4000d,0xddc400de}},	//   _vægt, нтът_, _अओता, dzjū, 
   {{0x7414165e,0x1da41d15,0x6b500162,0xca38035b}},	//   نوعا, _कीमत, _fægs, _áĝa_, 
   {{0xc98445fd,0xb38400ee,0x00000000,0x00000000}},	//   _сури, клил, --, --, 
   {{0x6b50d380,0x2d9000ca,0x8c1c0375,0xc6a401c0}},	//   _hægr, zoye_, לוחי, _өрхи, 
   {{0x7f600020,0x2d9000ca,0xefd40023,0xdb040051}},	//   _ታሪካዊ_, yoye_, ካየድ_, _phjê, 
   {{0xf8c08cce,0x6ab8d381,0x2900049f,0x5004008e}},	//   एशिय, _útfe, _ökat_, гҗиз, 
   {{0x2d900129,0x01080014,0xa3b803ba,0xe44c01ec}},	//   voye_, رتَو_, _आंच_, _тж_, 
   {{0x2d90d382,0x6b50d383,0xb8ec0327,0x60201d39}},	//   woye_, _lægr, _ླུ_, јдра, 
   {{0xdee00fd7,0xa6e42158,0x2d90d384,0x2d941086}},	//   роси, _নামট, toye_, врас, 
   {{0x6dac01e4,0x81bc00e2,0x6b5002d2,0x00000000}},	//   _aŝar, rvēt, _nægr, --, 
   {{0x4f3c044e,0x81bc00e2,0xcca40124,0xeb04004e}},	// [11bc0] _ኣፈወር, svēt, угақ, кпап, 
   {{0x2d9094a7,0x460c031c,0xee38009b,0x64440108}},	//   soye_, _གྱྀས_, _жно_, äkii, 
   {{0x6b5001bf,0xe8b801ad,0x00000000,0x00000000}},	//   _bægr, इश्च, --, --, 
   {{0x45d40107,0x2d900009,0x00000000,0x00000000}},	//   қоис, qoye_, --, --, 
   {{0xe0dc0100,0x6b50032e,0x00000000,0x00000000}},	//   djòl_, _dægr, --, --, 
   {{0x6b50005c,0x00000000,0x00000000,0x00000000}},	//   _vægs, --, --, --, 
   {{0xa8c4136b,0x43943419,0xb6c4187f,0x00000000}},	//   _айбд, ғанс, усій, --, 
   {{0x2fd0007c,0x00000000,0x00000000,0x00000000}},	//   _otyg_, --, --, --, 
   {{0xa8040022,0x00000000,0x00000000,0x00000000}},	//   _шзал, --, --, --, 
   {{0xdb040ffb,0x6cd401ec,0xefd40023,0x00000000}},	//   _chjè, _ﺘﻘﺴﻴ, ካየደ_, --, 
   {{0xd5acd385,0xa2640801,0x81bc005f,0xc33001d9}},	//   _вс_, тъпл, evēr, لٕک_, 
   {{0x92540b32,0x00000000,0x00000000,0x00000000}},	//   тают_, --, --, --, 
   {{0x656001b9,0x81bc0171,0x76440108,0x00000000}},	//   _iloh, tvēs, ähyv, --, 
   {{0x6560d386,0x247c063f,0x2afc1af8,0xd1f4001f}},	//   _hloh, ịms_, _लागु_, ላለች_, 
   {{0x4424af2b,0x3ea4369d,0xd24c00f5,0x00e4036b}},	//   lwm_, ålt_, _тц_, _یتکی, 
   {{0xeff8001f,0xdb040200,0x00000000,0x00000000}},	//   ላከያ_, _thjë, --, --, 
   {{0x6560d387,0x7b1485ce,0x4424015d,0x00000000}},	// [11bd0] _mloh, лдах, nwm_, --, 
   {{0x6b5028bf,0x45e402dd,0xdd9001ec,0x00000000}},	//   _sægr, _ﺍﻹﻁﻼ, уағы, --, 
   {{0x6560d388,0x44240457,0xfdb8763d,0x2e840166}},	//   _oloh, hwm_, _площ_, _бөти_, 
   {{0x61f81713,0xee700166,0x00000000,0x00000000}},	//   irtl, _уңсы, --, --, 
   {{0x44240218,0x37740661,0x6b5001bf,0xc1780064}},	//   jwm_, лыкс, _vægr, lsės_, 
   {{0x6560d389,0x66e00364,0x490805f9,0x62881320}},	//   _aloh, боша, _हाथो_, _oxfo, 
   {{0x8704023a,0x6560017a,0x20e000cd,0x00000000}},	//   ряче, _bloh, पराध, --, 
   {{0x66182a1f,0x442401d4,0x6560d38a,0x81bc005f}},	//   _dptk, fwm_, _cloh, zvēr, 
   {{0x6560d38b,0x66180857,0x6288007c,0x36d40107}},	//   _dloh, _eptk, _axfo, _бозр, 
   {{0x6560d38c,0x2900049f,0xbe5400dc,0x0b440092}},	//   _eloh, _ökar_, _kṣān, _ከከተማ, 
   {{0x656001cf,0x2fd00660,0x00000000,0x00000000}},	//   _floh, _styg_, --, --, 
   {{0x442403cb,0x00000000,0x00000000,0x00000000}},	//   bwm_, --, --, --, 
   {{0x44240368,0x81bc005f,0x61f8d38d,0xc17800c0}},	//   cwm_, tvēr, artl, esės_, 
   {{0x2324136b,0x7d08013f,0x40840114,0x00000000}},	//   _боши_, ɑmsɛ, руџб, --, 
   {{0x6e94d38e,0x86580085,0x81bc005f,0x926800ee}},	//   الزا, _nsɔ́, rvēr, _юрда_, 
   {{0x2d940962,0x707423bb,0x81bc005f,0xc0e4001f}},	//   ургс, _ماخذ, svēr, ኝቷል_, 
   {{0x09cc0574,0xeaf800c6,0xed58013e,0x81bc00e2}},	// [11be0] ाऱ्य, فرات_, _ҷон_, pvēr, 
   {{0xfbcc00bd,0xaa44c07f,0x6e4407a5,0x00000000}},	//   _লিখত, лезл, _беоз, --, 
   {{0xe8f8d38f,0xed58d390,0xe9d80408,0xf9c4009d}},	//   еле_, _зон_, хке_, аахү, 
   {{0x61ec04d7,0x6138008e,0xceb80153,0x00000000}},	//   ábli, _iälä, žęs_, --, 
   {{0x44240218,0x613800fd,0xbe5400b8,0x00000000}},	//   xwm_, _hälä, _eṣān, --, 
   {{0xd7c4168d,0xeb98d391,0x656002fb,0x6138008e}},	//   دووه_, _чиг_, _sloh, _kälä, 
   {{0x65601224,0x18a0016c,0x15f000c6,0x613801f4}},	//   _ploh, _ҳатм, مسيح, _jälä, 
   {{0x44240368,0x61f8d392,0x6138008e,0xb3900023}},	//   twm_, vrtl, _mälä, _ምብዛሕ_, 
   {{0x645c0393,0x6560d393,0x6138d394,0x00000000}},	//   _ępis, _vloh, _lälä, --, 
   {{0xf8c802ea,0x442400a9,0x257801e1,0x290401c4}},	//   _tséé_, rwm_, _bàlè_, lgoa_, 
   {{0x6560052f,0x4424d395,0x6138005b,0x764401f4}},	//   _tloh, swm_, _nälä, ähyt, 
   {{0x2904d396,0x4034b0b9,0x6560d397,0x257801e1}},	//   ngoa_, аемс, _uloh, _dàlè_, 
   {{0x29041140,0x95800a5b,0x23d40064,0x00000000}},	//   igoa_, _улце, _сцер, --, 
   {{0x6138d398,0x1ee404f2,0xf65000e5,0x00000000}},	//   _bälä, طوری_, _ائے_, --, 
   {{0x2904073c,0x52340849,0x53980a1e,0x6138008e}},	//   kgoa_, _مسيح_, _ריוו, _cälä, 
   {{0x8d74021f,0x61380139,0x3cd4d399,0x1fa4010a}},	//   ماقا, _dälä, ржас, ăкри_, 
   {{0xbb74399f,0x00000000,0x00000000,0x00000000}},	// [11bf0] агај, --, --, --, 
   {{0x3ce8013c,0xa3e40cf1,0x613800fd,0xc1780064}},	//   saav_, यीय_, _fälä, psės_, 
   {{0x3938001f,0x61380139,0x3a741fbe,0x00000000}},	//   _በፌዴራ, _gälä, јлер, --, 
   {{0xf1c8004d,0x3834d39a,0xddc4012d,0x75d000de}},	//   _hạc_, инер, zyjś, _jāze, 
   {{0xd83801c0,0xa3e402c3,0x00000000,0x00000000}},	//   ээж_, यीम_, --, --, 
   {{0x290405f5,0x247c01f3,0x75d000e2,0xd2f0000d}},	//   agoa_, _እስራት_, _lāze, _आयेब_, 
   {{0xf1c8001e,0xcf580302,0x0f5802e4,0xb6a401d5}},	//   _mạc_, רבות_, ריום_, шикл, 
   {{0xf1c807ae,0x6ab8d39b,0x00000000,0x00000000}},	//   _lạc_, _útfa, --, --, 
   {{0x2d9c0134,0x798801e1,0x336400d1,0x257801e1}},	//   _ɔte_, _ijew, ивиг, _sàlè_, 
   {{0xf1c8004d,0x95c80408,0xe76400db,0x00000000}},	//   _nạc_, _зуда_, _ۅڭۉن_, --, 
   {{0x75d000da,0x86c41410,0x9f5c0241,0x00000000}},	//   _bāze, _ايمن, _òrùn_, --, 
   {{0xdb0c00d2,0x7158bb62,0x55500014,0x3494d39c}},	//   _kucó, трос_, _چھکر, _каер, 
   {{0x6444d39d,0xf1c80016,0xb4d00574,0x61380724}},	//   äkit, _bạc_, वडी_, _sälä, 
   {{0xdee0d39e,0xe68c0023,0xf1c80208,0x613801f4}},	//   жори, _ዝሕብሮ_, _cạc_, _pälä, 
   {{0x648c0943,0x62840724,0x6138013d,0xf1c80051}},	//   ṱits, şkor, _qälä, _dạc_, 
   {{0x6444049f,0x7988d39f,0x75d0005f,0x6138005b}},	//   åkig, _njew, _gāze, _välä, 
  
   {{0x78a80433,0xeb9803f5,0x9bc800f1,0xc2e800cc}},	// [11c00] _nzev, виа_, ندلې_, _খাতি_, 
   {{0xaab8d3a0,0x798801e1,0x6138ad0d,0xf1c80208}},	//   ندار_, _ajew, _tälä, _gạc_, 
   {{0x6da4d3a1,0xe9d00075,0x78a80798,0x6e4424e5}},	//   _вина, زغا_, _azev, _тенз, 
   {{0xdb0c5b84,0x3a9812c4,0x22480037,0x6fd80118}},	//   _bucó, утую_, äbki_, _बझां, 
   {{0x2904d3a2,0x48c400fd,0xd8f400d4,0x00000000}},	//   rgoa_, _һәла, рнії_, --, 
   {{0x78a805b8,0xf1c8004d,0x798800a2,0x888401ec}},	//   _dzev, _xạc_, _ejew, ағұл, 
   {{0x78a8014b,0xb4d00490,0xaaa84196,0xf6e402d5}},	//   _ezev, वडू_, _करिक, сцін, 
   {{0xaad0190c,0x00000000,0x00000000,0x00000000}},	//   दुरक, --, --, --, 
   {{0xdb04d3a3,0x00000000,0x00000000,0x00000000}},	//   _gijó, --, --, --, 
   {{0xaaa805f9,0xa694119e,0x00000000,0x00000000}},	//   _कराक, _креј, --, --, 
   {{0x7f60044e,0xc1b86f83,0xf1c80208,0x135000db}},	//   _ታሪኻዊ_, ллох_, _rạc_, تئيج, 
   {{0x2c5c00da,0xf1c8001e,0x154099a4,0x644425c6}},	//   _kādā_, _sạc_, _мехм, äkis, 
   {{0x800801ed,0x75d00171,0x6384004e,0x00000000}},	//   درجہ_, _gāzb, _кгда, --, 
   {{0x68180882,0x9390827d,0x2bb00073,0x00000000}},	//   mādā, _وجوا, _जळगा, --, 
   {{0xa1843abd,0xa490d195,0x9ce4d3a4,0xdd983e4f}},	//   _выпл, _دیکت, ицал, вша_, 
   {{0x0b5801d5,0x00000000,0x00000000,0x00000000}},	//   یشلب_, --, --, --, 
   {{0xe0dc026c,0xf1c8004d,0x00000000,0x00000000}},	// [11c10] mbò_, _tạc_, --, --, 
   {{0xaad00254,0x00000000,0x00000000,0x00000000}},	//   दुलक, --, --, --, 
   {{0xdb0c004e,0x4fb423bb,0xa6cc00fe,0x78a800e5}},	//   _bucò, _بصير, ৰণাট, _szev, 
   {{0xdb0c0789,0xc9840305,0x8a1801d5,0xf8b802dd}},	//   _pucó, оучи, شتمس_, гөз_, 
   {{0xdb04180f,0x6b8c006a,0x0a401ee0,0x0c8400c7}},	//   _dijò, ïngä, _ሐዋርያ, _дырм, 
   {{0xdb040428,0x66e00117,0x00000000,0x00000000}},	//   _eijò, поша, --, --, 
   {{0xdb04002e,0x872400db,0x00000000,0x00000000}},	//   _wijó, زعوم, --, --, 
   {{0xb4d00490,0xe61402d5,0x59640395,0x00000000}},	//   वडे_, ёды_, _тъга, --, 
   {{0x681800da,0x78a807f5,0xc0ec0023,0x2c5c0171}},	//   gādā, _uzev, _ጀሚራ_, _gādā_, 
   {{0xc0ec02d3,0x7998127b,0x00000000,0x00000000}},	//   _ጀሚረ_, loww, --, --, 
   {{0x644402f6,0x95c8d3a5,0xdb0400dc,0x00000000}},	//   äkir, _руза_, _jijñ, --, 
   {{0xa6e01125,0x35b4d3a6,0x047807d6,0x00000000}},	//   _øðru, _убер, الیک_, --, 
   {{0x60d8d3a7,0x00000000,0x00000000,0x00000000}},	//   ñuma, --, --, --, 
   {{0x50d8d3a8,0xa8000086,0x799803ac,0x03680150}},	//   _भ्रष, ùñij, howw, _киік_, 
   {{0xc0ec044e,0xe0dc026c,0x00000000,0x00000000}},	//   _ጀሚሩ_, bbò_, --, --, 
   {{0x320400d7,0x31080108,0x00000000,0x00000000}},	//   muly_, _снип_, --, --, 
   {{0x7998d3a9,0xe0d4023a,0xdc540014,0xc0e40023}},	// [11c20] doww, _увы_, ٝرٕک, ዛዘመ_, 
   {{0x9524031c,0xdcac00f7,0xaf04d3aa,0x00000000}},	//   _ཡིའི_, رىل_, _упол, --, 
   {{0xe808069f,0x3ea00477,0x99842e11,0x320402fb}},	//   हूना_, _gyht_, çişi_, nuly_, 
   {{0x2c5c00b8,0x00000000,0x00000000,0x00000000}},	//   _pādā_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x68180aed,0xaa446aeb,0xc44804d3,0xe8f800d1}},	//   vādā, _легл, ییان_, _әла_, 
   {{0x1b7800c8,0x3204d3ab,0x785000cd,0xbb700046}},	//   _עטלע, july_, _aśvā, _تۇلع, 
   {{0x320402fb,0x79980548,0x2c5c005f,0x68181a14}},	//   duly_, coww, _tādā_, tādā, 
   {{0x7c28009b,0xa8840150,0xd940010b,0xa93401ec}},	//   _šerz, _الءى, _эети, _кеңш, 
   {{0x68180029,0xd7ec007b,0x00000000,0x00000000}},	//   rādā, _أكل_, --, --, 
   {{0x320409a5,0xe0dc02e2,0xe5080472,0xf63801e2}},	//   guly_, tbò_, _مياو_, _پينګ_, 
   {{0xe570d3ac,0x68180882,0x2164d3ad,0x00000000}},	//   _عطا_, pādā, стог, --, 
   {{0x64a40124,0x00000000,0x00000000,0x00000000}},	//   _уада, --, --, --, 
   {{0x3ea00076,0x00000000,0x00000000,0x00000000}},	//   _pyht_, --, --, --, 
   {{0xf1c807ae,0x2cd401f2,0xb87c0115,0x75d000e2}},	//   _hạn_, _ọhụ_, _reŭm, _kāza, 
   {{0x7bcc0357,0x0dc82c31,0xf1c8004d,0x7cd8d3ae}},	//   tqau, сури_, _kạn_, рмар_, 
   {{0x50dc00df,0x00000000,0x00000000,0x00000000}},	// [11c30] _עקזא, --, --, --, 
   {{0xf1c8001e,0x4fc400cf,0xda6400ec,0x9aa8007b}},	//   _mạn_, _رەفە, ٽائي, هداف_, 
   {{0x6ab808a7,0x799805e4,0x46cc012c,0xf1c80208}},	//   _útfl, toww, ाशनह, _lạn_, 
   {{0x49b8d3af,0xdb040a28,0x8ed842c2,0x9f4801e7}},	//   ماند_, _vijñ, _پذیر_, iscí_, 
   {{0xf1c80016,0x26042871,0xf8b801c0,0x9ba00e56}},	//   _nạn_, सूसी_, рөв_, _فەرى, 
   {{0xe7a40075,0xab6001ec,0x867400b8,0xdb0c01f4}},	//   قۇقى_, _قۇقى, _śruṣ, äjäp, 
   {{0x65800014,0xc4c40248,0x00000000,0x00000000}},	//   ژیمٕ, _ẹfọr, --, --, 
   {{0xf1c8431d,0x6aa8d3b0,0x16083bec,0x25b4007b}},	//   _bạn_, üffe, संबर_, يهود_, 
   {{0xf1c801fb,0x6d5806af,0x64440108,0x00000000}},	//   _cạn_, êtai, äkip, --, 
   {{0x437405b0,0xf2c40228,0x32040122,0xb87c01e4}},	//   зуют, өсүн, tuly_, _leŭk, 
   {{0x0584004b,0x00000000,0x00000000,0x00000000}},	//   _کلنټ, --, --, --, 
   {{0x32046738,0x7f440051,0xd5b800f3,0xbe380023}},	//   ruly_, _anhq, _ссз_, _ብልጫታ, 
   {{0x836401b9,0xd2900014,0xf1c80051,0xf4840066}},	//   زدیل, تُھک, _gạn_, _باای, 
   {{0x7d1c02d0,0x86800023,0x7f740006,0x00000000}},	//   _abss, _ክቕበሎ_, пусц, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf1c801fb,0x5d640276,0x7d1c0f85,0xed5808ca}},	//   _hạo_, оисм_, _cbss, шоб_, 
   {{0xdca0d3b1,0xca7c022e,0x5ca0022e,0x6f1800f3}},	// [11c40] дати, _qarо, дитб, _кцнс_, 
   {{0xdb040ffb,0x7d1cd3b2,0x670c0807,0x6a840108}},	//   _chjà, _ebss, _साधक_, олза, 
   {{0x2d9c07ea,0x7c3c0194,0x2ef8067c,0xf1c8001e}},	//   îtes_, _ersr, _idpf_, _mạo_, 
   {{0xf1c80051,0xa03400e5,0x6e38007c,0x00000000}},	//   _lạo_, _آیا_, åtbu, --, 
   {{0x27484140,0x6d4405ac,0x00000000,0x00000000}},	//   ичко_, _inka, --, --, 
   {{0xdb0419f5,0xf1c8004d,0x2b380276,0xa0980a1e}},	//   _ghjà, _rạn_, _тямэ_, סיסט, 
   {{0xf1c80016,0x237c007c,0x00000000,0x00000000}},	//   _sạn_, vitj_, --, --, 
   {{0x69dc023a,0xf1c8004d,0x00000000,0x00000000}},	//   mppe, _pạn_, --, --, 
   {{0xf1c8001e,0x1864b17a,0x6d442ac6,0x69dc0108}},	//   _bạo_, _дати_, _mnka, lppe, 
   {{0x68e003d4,0xf1c801fb,0x427406d4,0xc3300014}},	//   lbod, _vạn_, згос, رٕج_, 
   {{0x6d44d3b3,0xf1c8001e,0xc5b401c0,0xe5a46c33}},	//   _onka, _dạo_, _ердө, _дижи, 
   {{0x68e0d3b4,0x69dcd3b5,0x6d440cad,0x6b280327}},	//   nbod, ippe, _nnka, _ཤིའོ_, 
   {{0x260401ad,0x7d1c00ef,0x00000000,0x00000000}},	//   सूरी_, _rbss, --, --, 
   {{0x6d44d3b6,0xf1c8001e,0x64a40588,0x68e001a4}},	//   _anka, _gạo_, _лаҵа, hbod, 
   {{0xcdd80640,0xdb0401d3,0xa2d800dc,0x9db80633}},	//   жњу_, _kijö, पुण्, لدرز_, 
   {{0xd6540375,0x68e00419,0x8eb40eff,0x00000000}},	//   חילת_, jbod, بەپت, --, 
   {{0x68e0d3b7,0x69dcd3b8,0xb3440798,0xa0c000f1}},	// [11c50] dbod, eppe, _unçã, _کيښو, 
   {{0x69dc074d,0x68e0d3b9,0xf1c80208,0x2d9c0129}},	//   fppe, ebod, _xạo_, îter_, 
   {{0x53980375,0x81cc0154,0x00000000,0x00000000}},	//   סיבו, শীর_, --, --, 
   {{0x68e0d3ba,0xa2d8a5b3,0xca48036b,0x49c802dc}},	//   gbod, पुत्, تلمه_, ілін_, 
   {{0xfebc2158,0xf744d3bb,0x69dcd3bc,0x7d0cd3bd}},	//   _অভিধ, зело, appe, mgas, 
   {{0x7c2c1cbd,0x7d0cd3be,0xdb20571d,0x8e383cc4}},	//   mwar, lgas, _توسی, _اسیر_, 
   {{0x7c2cd3bf,0x6d44000f,0x3c2c01a6,0x7d0cd3c0}},	//   lwar, _ynka, _hžv_, ogas, 
   {{0x7d0cd3c1,0xd7f801ca,0xf1c80051,0x68e000d7}},	//   ngas, _вуж_, _sạo_, cbod, 
   {{0xa3e4069f,0xf8a801b9,0x7d0cd3c2,0x1bf002ab}},	//   यील_, _اگاه_, igas, ेंटल_, 
   {{0x31b4d3c3,0x77ac0077,0x7c2c017a,0x0f200154}},	//   ृद्ध, búxa, iwar, _ফোনঃ_, 
   {{0x7c2cd3c4,0x7d0cd3c5,0x32440166,0xd7c40133}},	//   hwar, kgas, ченг, _اوڕه_, 
   {{0x7c2cd3c6,0x358401d9,0x3a3001ed,0x3f8c0c6a}},	//   kwar, _عٔشق, _mszp_, éeun_, 
   {{0xf1c801dc,0x057413ef,0x7c2c364b,0x7fd402dd}},	//   _tạo_, _تالد, jwar, дісі, 
   {{0x7c2cd3c7,0x7d0cd3c8,0xf1c801fb,0x84940023}},	//   dwar, egas, _hạm_, ልኩምን_, 
   {{0x65640054,0x6b640588,0x68e0d3c9,0x7c2c4d57}},	//   _ŋkhi, ҿкаа, ybod, ewar, 
   {{0x7d0cd3ca,0x75289846,0xacc8283c,0xd7c8041c}},	//   ggas, neez, сгаз_, ादाच, 
   {{0x7c2cd3cb,0x3c2c0153,0x2bb8007b,0x68e0d3cc}},	// [11c60] gwar, _cžv_, مائة_, vbod, 
   {{0x7d0cd3cd,0xf1c801fb,0xefb001d5,0x75d00171}},	//   agas, _lạm_, _سیزگ, _rāzn, 
   {{0xa92412b4,0x68e0d3ce,0x752804ba,0x7c2c002e}},	//   здел, tbod, keez, awar, 
   {{0x7c2cd3cf,0x6d44105c,0x31b004bf,0x2bf4084c}},	//   bwar, _unka, báze_, _нягр, 
   {{0x6844d3d0,0x68e0d3d1,0x07342d29,0xe738014b}},	//   янда, rbod, делю, йед_, 
   {{0x1b0000bd,0x9be4031c,0x00000000,0x00000000}},	//   র্বে_, _སྦྲོ, --, --, 
   {{0x75280a49,0x68e00334,0x00000000,0x00000000}},	//   feez, pbod, --, --, 
   {{0x69ccd3d2,0x75282f99,0x151011ed,0x6b9cd3d3}},	//   _iube, geez, едъя, lopg, 
   {{0x69ccd3d4,0xa3e4813f,0xfa40001f,0x29e801e4}},	//   _hube, यीं_, _የሚሰማ, lŝa_, 
   {{0x7d0cd3d5,0x6b9c0221,0x81d401c0,0x00000000}},	//   zgas, nopg, моох, --, 
   {{0x69ccd3d6,0x521005f5,0x7c2cd3d7,0x7528d3d8}},	//   _jube, ндэт, zwar, beez, 
   {{0x67282dba,0x00c80228,0x7c2cd3d9,0x7d0c058a}},	//   lefj, өлүк_, ywar, xgas, 
   {{0x6b9cd3da,0x6608132e,0x7d0c05d1,0x7c2cb361}},	//   kopg, lufk, vgas, xwar, 
   {{0xefe40020,0x4fc4d3db,0x69ccd32a,0x67280623}},	//   ማሊያ_, есса, _oube, nefj, 
   {{0x69ccd3dc,0x7d0cd3dd,0x3ea408a7,0x7c2cd3de}},	//   _nube, tgas, ælt_, wwar, 
   {{0x7d0cd3df,0x7c2cd3e0,0xc8f801ad,0xd1380408}},	//   ugas, twar, ुलोम_, _ехь_, 
   {{0x7c2cd3e1,0x2128d3e2,0x7d0cd3e3,0x69ccd3e4}},	// [11c70] uwar, mech_, rgas, _aube, 
   {{0x21281859,0x69ccd3e5,0x7d0cd3e6,0x7c2cd3e7}},	//   lech_, _bube, sgas, rwar, 
   {{0x69ccd3e8,0x200805a1,0x7d0c0109,0x67280158}},	//   _cube, luci_, pgas, defj, 
   {{0x69ccd3e9,0x2128d3ea,0x6aa805d5,0x00000000}},	//   _dube, nech_, üffa, --, 
   {{0x69c8d3eb,0x69cc02d0,0x69c0717e,0x60d803b2}},	//   ífer, _eube, төрб, ðumy, 
   {{0x7bdcd3ec,0x66080198,0x75280337,0xf1c8004d}},	//   _itsu, fufk, weez, _sạm_, 
   {{0xa3c075be,0x69ccd3ed,0x212806af,0x64442c95}},	//   ्दन_, _gube, kech_, åkin, 
   {{0x2008d3ee,0xb9140ca8,0xa2d82894,0xceb408a8}},	//   kuci_, _labẹ_, पुस्, עיק_, 
   {{0x20081505,0x7528d3ef,0x69ccd3f0,0x2128d3f1}},	//   juci_, reez, _zube, dech_, 
   {{0x7bdc02ce,0xd2f400dd,0x752804ba,0x69cc002e}},	//   _mtsu, سکتا_, seez, _yube, 
   {{0xf1c80016,0xdb0401e6,0x69cc3018,0x1b000154}},	//   _tạm_, _ihjä, _xube, র্থে_, 
   {{0x7bdcd3f2,0x764002d0,0x21280036,0xf8dc00c5}},	//   _otsu, _irly, gech_, मडिय, 
   {{0x7bdc0190,0x2008d3f3,0x29000086,0x61e802d0}},	//   _ntsu, guci_, _ôkae_, _ewfl, 
   {{0x1b00015b,0xf268d3f4,0x02600133,0x06c000cc}},	//   র্তে_, _милл_, _ڕێپێ, _উভতি, 
   {{0xada4d3f5,0x7bdcd3f6,0xad640a8e,0x2128d3f7}},	//   давл, _atsu, واره, bech_, 
   {{0x2008d3f8,0x6ab80a85,0x32040af9,0x212800bc}},	//   buci_, _útfi, mrly_, cech_, 
   {{0x69ccd3f9,0xeaf8d3fa,0x6b9c005c,0x6728036e}},	// [11c80] _sube, قرات_, topg, yefj, 
   {{0x4b5404d3,0x76400162,0x3c180006,0xeff80092}},	//   رێزر, _orly, яўся_, ላከው_, 
   {{0x7bdcd3fb,0x69ccd3fc,0x6b9cd3fd,0xe9d8b91c}},	//   _etsu, _qube, ropg, цке_, 
   {{0x6b9c037e,0x32040493,0x7ae401ab,0x69cc00bc}},	//   sopg, irly_, abht, _vube, 
   {{0x69cc013b,0x7640d3fe,0x6b9c4174,0xa3c01408}},	//   _wube, _arly, popg, ्दम_, 
   {{0x21280cf1,0x66080009,0xc7b01867,0x00e000d1}},	//   zech_, tufk, دّت_, _ﺋﯩﺠﺘ, 
   {{0x200822dd,0x77900424,0xa968d3ff,0xe968300e}},	//   zuci_, دیلا, _дива_, _давл_, 
   {{0x6d540526,0x672805ac,0xdb04005b,0x66080009}},	//   njya, sefj, _ehjä, rufk, 
   {{0x61e8030d,0x2128d400,0x764003cb,0xd4940246}},	//   _swfl, vech_, _erly, дрэ_, 
   {{0x2008d3f3,0x2128d401,0x7414d402,0xca7c01d5}},	//   vuci_, wech_, روپا, _yarа, 
   {{0x2128d403,0xa2d80b7c,0x00000000,0x00000000}},	//   tech_, पुष्, --, --, 
   {{0x2008d404,0x6ea0000d,0x212800d4,0x00000000}},	//   tuci_, _गड़ु, ціон_, --, 
   {{0x2128d405,0x3204d406,0x55b8011a,0x00000000}},	//   rech_, arly_, _ומאו, --, 
   {{0x2128d407,0x6440d408,0x56800023,0xf1b000d1}},	//   sech_, _iroi, _ክንኣቱ_, _ﭼﯩﻘﺘ, 
   {{0x80e00729,0x20080687,0x21282b57,0x13e0015b}},	//   পৃষ্, suci_, pech_, _মিয়, 
   {{0x6d540007,0x8d74d409,0xa2d8c976,0x2008d40a}},	//   gjya, ناقا, पुर्, puci_, 
   {{0x91b83997,0xb72001af,0xd1b80345,0x00000000}},	// [11c90] _تطور_, _айhы, _تاوا_, --, 
   {{0x2b48045a,0x9a840124,0x00000000,0x00000000}},	//   _cnbc_, муел, --, --, 
   {{0xb87c00df,0x4de8033f,0x09e40212,0x7ae41554}},	//   _leŭt, टीआई_, воєн, rbht, 
   {{0x1adca765,0x3948d40b,0x644001c0,0x00000000}},	//   _प्रथ, ñas_, _oroi, --, 
   {{0x7bdcd40c,0x998401ed,0xb87c008f,0x3868041e}},	//   _utsu, ínű_, _neŭt, áar_, 
   {{0xe734d40d,0x38680003,0xbae46a87,0x37e000fe}},	//   ееш_, ġar_, _سكري, _নিদৰ, 
   {{0x38688ef1,0x8aa4457e,0x31b001ed,0x64404230}},	//   šar_, _артд, háza_, _aroi, 
   {{0x77ac056a,0x64401da7,0xa8500166,0x00000000}},	//   púxo, _broi, ткәч, --, 
   {{0x6440d40e,0x3f800450,0x49041c3e,0xa520010b}},	//   _croi, _omhu_, _جوقق, умыд, 
   {{0x6440d40f,0xf1c80016,0xb87c00df,0xe3b400f7}},	//   _droi, _hại_, _deŭt, нбы_, 
   {{0x644007ad,0x78a8002b,0x76406282,0x00000000}},	//   _eroi, _hyev, _urly, --, 
   {{0x6440d410,0x78a80083,0x00000000,0x00000000}},	//   _froi, _kyev, --, --, 
   {{0xf1c807ae,0x00000000,0x00000000,0x00000000}},	//   _mại_, --, --, --, 
   {{0xf1c801dc,0x753803f9,0xdfcc00c6,0x00000000}},	//   _lại_, _hawz, صيف_, --, 
   {{0xf8a44c9a,0x7538d411,0x6440030a,0x00000000}},	//   _چک_, _kawz, _zroi, --, 
   {{0xf8a4350a,0x31b00030,0x644002d0,0xfd94005b}},	//   _نک_, báza_, _yroi, вшую, 
   {{0x78a8d412,0xf1c801fb,0x4094084c,0x75380432}},	// [11ca0] _nyev, _nại_, _арэт, _mawz, 
   {{0x75380369,0xb87c01e4,0x5ba400a8,0x1b0000eb}},	//   _lawz, _leŭs, екум_, র্সে_, 
   {{0x78a86b6c,0xee38040e,0xa3c04da1,0x370805f9}},	//   _ayev, _энн_, ्दत_, _साड़ी_, 
   {{0x7e6004f3,0x78a802c4,0xebe4d413,0xf1c8001e}},	//   älpe, _byev, _помп, _bại_, 
   {{0x2b48009f,0x1864327c,0xd7e4003b,0xeb7400c0}},	//   _tnbc_, наци_, емче_, _зывэ, 
   {{0x78a80100,0xf1c801fb,0x78ac0037,0x63840129}},	//   _dyev, _dại_, üava, _ménè, 
   {{0x78a8289d,0x6440952b,0x00000000,0x00000000}},	//   _eyev, _sroi, --, --, 
   {{0xd5b45b8f,0x668001d5,0xeff80092,0x00000000}},	//   нсы_, پیچل, ዋረድ_, --, 
   {{0x75380369,0xe4509448,0xed5c0051,0x485400ec}},	//   _dawz, اضع_, _đột_, _جھاز, 
   {{0x6440d414,0x00000000,0x00000000,0x00000000}},	//   _vroi, --, --, --, 
   {{0x2d800b21,0x7538058a,0x80dc0073,0x24c800fb}},	//   _omke_, _fawz, पडले, _егеп_, 
   {{0x6440d415,0x6738d416,0xdef002d3,0x31b000d7}},	//   _troi, _hatj, ግድን_, táza_, 
   {{0xb87c0115,0x6440005a,0xd36c0451,0x00000000}},	//   _heŭr, _uroi, _ڏهن_, --, 
   {{0x53300364,0x425407d6,0xb87c00df,0x00000000}},	//   _бешт, _لنتر, _zeŭs, --, 
   {{0x6738d417,0x1c0000af,0x628c03b2,0x00000000}},	//   _matj, _लिहल_, úbod, --, 
   {{0x67381bce,0x8d8419bb,0x00000000,0x00000000}},	//   _latj, гууд, --, --, 
   {{0x6384004a,0x91bc0375,0x6ae000cc,0xec180bd6}},	// [11cb0] _génè, _צמחי, _পয়ো, метә_, 
   {{0x6738d418,0x2d8001e2,0x78bc0306,0xa3c0190c}},	//   _natj, _emke_, _úsvi, ्दि_, 
   {{0x61f8d419,0x3d94035b,0xb87c00df,0x31940109}},	//   nstl, _аинр, _neŭr, lāza_, 
   {{0x67380357,0x8aa464b6,0x25a40010,0x78a800b8}},	//   _aatj, уруд, _nkol_, _pyev, 
   {{0xa3c002f8,0x6738d41a,0x66180227,0x18b0052f}},	//   ्दा_, _batj, _aqtk, уҙар, 
   {{0x25a4d41b,0x6374045f,0x21380113,0x3f9004ce}},	//   _akol_, _hânf, _laqh_, nnzu_, 
   {{0xf8b80086,0x6738d41c,0x2d8001f5,0x61f86296}},	//   _ibũm_, _datj, _ymke_, jstl, 
   {{0xf1c801dc,0x78a800e4,0x75d000e2,0x61f8005c}},	//   _tại_, _tyev, _jāzi, dstl, 
   {{0x61f8d41d,0xd3a00075,0x78a8bc61,0x6738d41e}},	//   estl, ллиқ, _uyev, _fatj, 
   {{0x25a4d41f,0x6738d420,0x6374000f,0x3364022e}},	//   _ekol_, _gatj, _lânf, твог, 
   {{0x61f8d421,0x20180140,0x63840129,0x35f40022}},	//   gstl, _aqqi_, _sénè, _рпер, 
   {{0x638406af,0xc834001f,0x6738010e,0x24900064}},	//   _pénè, _ባይሆን, _zatj, _žyme_, 
   {{0x6738d422,0x2d8005b1,0x61f8d423,0x057407d6}},	//   _yatj, _rmke_, astl, _حالد, 
   {{0x63840129,0x6738022e,0x00e000d1,0xc7b80051}},	//   _vénè, _xatj, _ﺋﯩﺸﺘ, _xhđ_, 
   {{0x394c0375,0x00000000,0x00000000,0x00000000}},	//   _ones_, --, --, --, 
   {{0x2fd0036b,0xa5c00008,0x63844056,0x71a4084c}},	//   _tuyg_, _þótt, _ténè, _шайз, 
   {{0x2030ac15,0x1b18009e,0x8024036b,0xddc00116}},	// [11cc0] _نفيس, নজনে_, _یریم, рбти, 
   {{0x394c0493,0x7e60007c,0xdb2003b2,0x00000000}},	//   _anes_, älpc, ørða, --, 
   {{0x6738d424,0x00000000,0x00000000,0x00000000}},	//   _ratj, --, --, --, 
   {{0x6738d425,0x2d80d426,0x2720012c,0xb87c01e4}},	//   _satj, _umke_, _oční_, _reŭr, 
   {{0x394c076f,0x2d90021a,0xa8500cef,0x6738d427}},	//   _dnes_, mnye_, релә, _patj, 
   {{0x394cd428,0x25a403bd,0x2d900a2e,0x61f8d429}},	//   _enes_, _skol_, lnye_, ystl, 
   {{0x6374025a,0x25a40477,0x2d902255,0xd6240063}},	//   _hâng, _pkol_, onye_, воје_, 
   {{0x2d90d42a,0x63742776,0x6738d42b,0x68446c00}},	//   nnye_, _kâng, _watj, _инба, 
   {{0x2d9005b1,0x5abc0327,0x78240a11,0xc7b80051}},	//   inye_, _མཛོམ, _معلل, _thđ_, 
   {{0x27e4d42c,0xdef0001f,0x2d900ac5,0x63740311}},	//   mpon_, ግድና_, hnye_, _mâng, 
   {{0x27e4d42d,0xc22477c2,0x6374084c,0x2d9031e5}},	//   lpon_, اکتو, _lâng, knye_, 
   {{0x25a4113c,0xf68406ba,0x2164d42e,0x27e401e4}},	//   _ukol_, ﻪﺭﮔﻪ_, ттог, opon_, 
   {{0x27e4d42f,0x2d9005b1,0x61f869f5,0xedbc012c}},	//   npon_, dnye_, sstl, ्दैछ, 
   {{0x27e4079b,0x6374002d,0x2d90d430,0x61f8002f}},	//   ipon_, _sânf, enye_, pstl, 
   {{0xd24c3251,0xdb04026c,0x2604012c,0x6264d431}},	//   _ونه_, _ghjù, सूची_, _جاشق, 
   {{0x5f4405f5,0x3a74891e,0xc1140063,0x40340117}},	//   хүүн_, ңлар, _смиј, _беис, 
   {{0x0dc8d432,0x60d80309,0x00000000,0x00000000}},	// [11cd0] тури_, ñumu, --, --, 
   {{0x394c579b,0x2d90d433,0xbf3400a7,0x1ea80472}},	//   _snes_, anye_, _снощ, _يادي_, 
   {{0x2d9005b1,0xcb3401f4,0x00000000,0x00000000}},	//   bnye_, рехъ, --, --, 
   {{0x6374025a,0x26dc0332,0x49b8009a,0x2008015d}},	//   _hând, _afto_, ناند_, orci_, 
   {{0x637400d8,0x0904d434,0x75d00171,0x4c9400d4}},	//   _gâng, рпін, _jāzv, _вияс, 
   {{0xa3b00c2e,0xf1c80016,0x98bc00b0,0x394c0368}},	//   _झील_, _hạt_, _houī_, _wnes_, 
   {{0x63740276,0x5f180037,0x00000000,0x00000000}},	//   _mând, _बान्_, --, --, 
   {{0x394cd435,0x6374d436,0x7af4009d,0x00000000}},	//   _unes_, _yâng, _hezt, --, 
   {{0x7af4005a,0x7c280221,0xf1c8004d,0x6ab8148b}},	//   _kezt, _äerd, _mạt_, _útfr, 
   {{0xf1c8001e,0x7af4d437,0x00000000,0x00000000}},	//   _lạt_, _jezt, --, --, 
   {{0x751406d5,0x64a00046,0x20080034,0xa064d438}},	//   _مواض, _қаша, erci_, қара_, 
   {{0x7af4d439,0xf1c8004d,0xafe4d43a,0xe28c4990}},	//   _lezt, _nạt_, ломл, _ңа_, 
   {{0xe44c6ac5,0x64e00184,0xe3acd43b,0x7760d43c}},	//   _уж_, _уҡығ, _гб_, _kolx, 
   {{0x6374d43d,0x77ac0077,0x7af4d43e,0x83640150}},	//   _când, fúxi, _nezt, _ندىل, 
   {{0xa3c01533,0x200802e8,0x63742326,0x2d90d43f}},	//   ्दर_, arci_, _sâng, tnye_, 
   {{0x7e600267,0x27e40175,0x2d900100,0x00000000}},	//   älpa, ypon_, unye_, --, 
   {{0x2d900585,0x7de802e2,0xf1c8004d,0xa9a4d440}},	// [11ce0] rnye_, _pèsò, _dạt_, ңизд, 
   {{0x6374084c,0xee3802bf,0x195401ec,0x00000000}},	//   _gând, _зно_, ғашы_, --, 
   {{0x2d9005b1,0x22f4010f,0x6ab401c6,0x00000000}},	//   pnye_, רזען_, усах, --, 
   {{0x6374145e,0x27e40280,0xf1c801fb,0x00000000}},	//   _tâng, tpon_, _gạt_, --, 
   {{0x6374d441,0x77601b08,0xe784d442,0x80e000fe}},	//   _yând, _bolx, луко, পৃক্, 
   {{0x27e4d443,0x46140472,0x00000000,0x00000000}},	//   rpon_, لوتر, --, --, 
   {{0x27e4d444,0x6a8409a5,0x00000000,0x00000000}},	//   spon_, _ёлба, --, --, 
   {{0x78b009f3,0x63740311,0x48c400c7,0x0488013d}},	//   ðkvæ, _mâne, _кәла, кәли_, 
   {{0xa3c005ba,0x66e4d445,0x6374002d,0x69c0d446}},	//   ्दल_, _боза, _lâne, mmoe, 
   {{0x69c09045,0x77600009,0x7c2804e6,0x4ab80f90}},	//   lmoe, _golx, _äere, _अराव, 
   {{0x6374084c,0x73d800f7,0xa2d800bc,0x24e8005b}},	//   _rând, ндөр_, पुग्, _змеи_, 
   {{0x69c0d447,0x6374d448,0xa01804cc,0x00000000}},	//   nmoe, _sând, nzög, --, 
   {{0x6374d449,0x69c0020b,0x2008004a,0xa3440f89}},	//   _aâne, imoe, urci_, _бэйл, 
   {{0x65604774,0x69c00369,0xf1c8004d,0x10e400d1}},	//   _hooh, hmoe, _sạt_, _ﺋﯩﺸﻨ, 
   {{0x65ac06d6,0xf3c807d6,0x656002b1,0x6374054e}},	//   ṱhut, _شبهه_, _kooh, _vând, 
   {{0x69c02112,0x00000000,0x00000000,0x00000000}},	//   jmoe, --, --, --, 
   {{0x6560d44a,0x4034d44b,0xdef80276,0xf1c8004d}},	// [11cf0] _mooh, _тепс, _пын_, _vạt_, 
   {{0x6560d44c,0x34d0d44d,0x6374ba97,0x69c00b23}},	//   _looh, _हल्द, _hânb, emoe, 
   {{0x69c0002d,0xf1c8004d,0x7af400c0,0x2ef4004e}},	//   fmoe, _tạt_, _vezt, _өзөр, 
   {{0x69c00926,0x656004ba,0xe0dc0bdf,0x6aac01bf}},	//   gmoe, _nooh, ncò_, _dybf, 
   {{0x69d820ef,0x9814009f,0x63740356,0x1824ace5}},	//   _éten, ابصا, _zâne, اقتی_, 
   {{0xf7448701,0x63740b21,0x99d00115,0x00000000}},	//   реко, _lânb, _esʈa, --, 
   {{0xfaa89b78,0x6560ae2f,0x8704d44e,0x62f8015b}},	//   _شهري_, _booh, сяче, ংলায়_, 
   {{0x8a6404d3,0x656001a6,0xf428afe2,0xe69000d1}},	//   _دێمۆ, _cooh, воил_, تلىد, 
   {{0xa3c000dc,0x00000000,0x00000000,0x00000000}},	//   ्दं_, --, --, --, 
   {{0xb7bc0276,0xb224d44f,0xb384702f,0x00000000}},	//   _opţi, амол, рлол, --, 
   {{0x65600093,0xe3b4084c,0x00000000,0x00000000}},	//   _fooh, рбэ_, --, --, 
   {{0x71a40588,0x6374045f,0x6560058a,0x00000000}},	//   рамз, _râne, _gooh, --, 
   {{0x6374000f,0x00000000,0x00000000,0x00000000}},	//   _sâne, --, --, --, 
   {{0xb4c00d5f,0xa3c00882,0x29d4010e,0x00000000}},	//   ंधी_, ्दः_, lýaň_, --, 
   {{0xd7200c58,0x656000b5,0xacf40640,0x69c0d03f}},	//   _যোৱা_, _yooh, ичај, ymoe, 
   {{0xb04822f7,0xe0dcb2cc,0x63740356,0x1d0400ee}},	//   _азиз_, ccò_, _vâne, иеси_, 
   {{0x9c840030,0x1c40d450,0xf4840023,0x00000000}},	// [11d00] vočí, онтм, _ክትህብ_, --, 
   {{0x81ac0154,0x5f741e4b,0x00000000,0x00000000}},	//   কগণ_, _ناپر, --, --, 
   {{0x69c0225e,0xe8f8d451,0x6d9000a2,0xb4c00f90}},	//   tmoe, вле_, _aýaň, ंधु_, 
   {{0xda6c0014,0xad681188,0x00000000,0x00000000}},	//   بُم_, _рамз_, --, --, 
   {{0x69c09045,0x6560d382,0xa01803fa,0x1c404d56}},	//   rmoe, _rooh, rzög, _дням, 
   {{0xf7e804a9,0x6374084c,0x69c0d452,0x6560d453}},	//   ارنى_, _mânc, smoe, _sooh, 
   {{0x9c840232,0x6560d454,0x8a440014,0xd61400f1}},	//   počí, _pooh, _دێان, لتيا_, 
   {{0x7c280036,0xb4c010eb,0xc5380305,0xaf280092}},	//   _äerc, ंधू_, упих_, _ትጮሀለ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6374000f,0x765401ed,0xa5c4032e,0x00000000}},	//   _sânb, ógyí, fnóð, --, 
   {{0x1b0003f4,0x6560d455,0x66e40117,0x00000000}},	//   র্কে_, _tooh, _боҷа, --, 
   {{0x51f47734,0x24080e54,0x21840798,0x00000000}},	//   шнюю_, _анди_, рѓов, --, 
   {{0x50645e5f,0x637406ed,0xe0dc4d72,0x041400bd}},	//   отра, _cânc, rcò_, _তৈরী_, 
   {{0x93f8025f,0x1ee403e6,0xe0dc0268,0x213c0010}},	//   _ילדי, شوری_, scò_, žuh_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x91bc0375,0x00000000,0x00000000,0x00000000}},	// [11d10] _במהי, --, --, --, 
   {{0x3f14d456,0xf1c80208,0xa2d81bd6,0xdae400e5}},	//   _удос, _hạp_, पुच्, شہرو_, 
   {{0x69d800dd,0x95240327,0xd99c0150,0x00000000}},	//   _étel, _རྡའི_, _ﺃﻓﺭﺩ_, --, 
   {{0x7e600162,0x00000000,0x00000000,0x00000000}},	//   ølpu, --, --, --, 
   {{0x3cf8003a,0xf1c80208,0x00000000,0x00000000}},	//   _iesv_, _mạp_, --, --, 
   {{0xf1c801fb,0x00000000,0x00000000,0x00000000}},	//   _lạp_, --, --, --, 
   {{0x0a94010b,0x644401a8,0x7bc4d457,0x00000000}},	//   _дарю, ækin, mmhu, --, 
   {{0x7bc45c7f,0xf1c8001e,0x7d1c0175,0x588450c0}},	//   lmhu, _nạp_, _jcss, _кыза, 
   {{0x79880451,0xe80c142d,0x7bc4d458,0x7d1c0076}},	//   _imew, _सिया_, omhu, _mcss, 
   {{0x63740356,0x7bc43e7c,0x00000000,0x00000000}},	//   _rânc, nmhu, --, --, 
   {{0x7e600267,0x7bc401ab,0x71680353,0xd6840108}},	//   älpl, imhu, ганг_, _туап, 
   {{0xf1c801fb,0x637409b1,0x7c3c8e01,0x7bc401e7}},	//   _cạp_, _pânc, _ossr, hmhu, 
   {{0x798801f7,0x00000000,0x00000000,0x00000000}},	//   _mmew, --, --, --, 
   {{0xdee0d459,0xe3e405d9,0xf1d0009d,0xd34402f2}},	//   зори, _اکين_, _нөмө, _ئیده_, 
   {{0x7c3c8118,0x31b001d3,0x3cf8005c,0xf3f80154}},	//   _assr, házi_, _besv_, _আমির_, 
   {{0xa19007fa,0x7bc40369,0x1c00033d,0xafe4014b}},	//   _најч, emhu, _लिखल_, _лоил, 
   {{0xeb980124,0x7d1c0334,0x3cf801bf,0x7bc400a3}},	// [11d20] гиа_, _dcss, _desv_, fmhu, 
   {{0xf3f80d42,0x7988d45a,0x7d1c03ac,0x65bc0200}},	//   _আমার_, _amew, _ecss, mëhe, 
   {{0x6e44d45b,0x7c3cd45c,0xada4086f,0xa3dc134e}},	//   _انجم, _essr, _ганл, _दंभ_, 
   {{0xed583f54,0x6f1c0113,0x7bc401f5,0x69d800d8}},	//   _сом_, _hcpc, amhu, _étem, 
   {{0x6cc400f7,0x00000000,0x00000000,0x00000000}},	//   _ыйма, --, --, --, 
   {{0x7988d45d,0x7bc400a3,0x68440022,0x4adc190c}},	//   _emew, cmhu, инҵа, _बलिव, 
   {{0x65bc02d3,0xabc81d00,0x30f800cd,0x00000000}},	//   hëhe, _ﺑﻮﻳﺎ, ्णाः_, --, 
   {{0x31b000bc,0x80a80073,0x00000000,0x00000000}},	//   bázi_, _घडले, --, --, 
   {{0xf1c8001e,0x65bc036e,0x99800419,0xa80404b3}},	//   _rạp_, jëhe, _upjš_, _ызал, 
   {{0x68e0d45e,0x798800ca,0xa49401e4,0xf1c8004d}},	//   lcod, _zmew, _neϲe, _sạp_, 
   {{0xd6240117,0x00000000,0x00000000,0x00000000}},	//   _гохе_, --, --, --, 
   {{0x68e0d45f,0xf65000dd,0x5a9800c8,0x7e6001e6}},	//   ncod, _کئے_, רשטא, älpm, 
   {{0x6e3c03ac,0x1b000154,0xf3640137,0x00000000}},	//   _aspb, র্টে_, стөн, --, 
   {{0x7c3c005a,0x93200014,0x00000000,0x00000000}},	//   _rssr, _فر٘ن, --, --, 
   {{0xf1c80016,0x68e001f5,0xa3dcd460,0xc2c4a9e7}},	//   _tạp_, kcod, _दंड_, _بيغي, 
   {{0x65bc036e,0x31a401e2,0x00000000,0x00000000}},	//   bëhe, _ولوې, --, --, 
   {{0x68e00334,0xc0c429db,0x8d840116,0xa01801d3}},	// [11d30] dcod, _фәни, чурд, szöb, 
   {{0x2ef8d461,0x7bc40810,0x7988025c,0xda780006}},	//   _gepf_, umhu, _smew, ляе_, 
   {{0x7a3400c6,0x3cf80055,0x7bc4078c,0x7a384130}},	//   تفاص, _tesv_, rmhu, рпер_, 
   {{0x68e0d462,0xdb04026c,0xc1780153,0x7bc4679d}},	//   gcod, _chjò, mpės_, smhu, 
   {{0x442405b1,0xbd880451,0x7c3c02d0,0xc1780153}},	//   jtm_, _منھن_, _ussr, lpės_, 
   {{0xbae4007b,0x68e002d0,0x464801ec,0x2ba801f9}},	//   _ذكري, acod, өзін_, कवणा, 
   {{0x68e06144,0x29dc05d5,0x9a940092,0x00000000}},	//   bcod, _gïa_, ቃራኒው_, --, 
   {{0x798800ec,0xdb040268,0xbee40073,0x146000c7}},	//   _umew, _ghjò, कडुन_, зеиҭ, 
   {{0xe574cea6,0x739801af,0x00000000,0x00000000}},	//   ізь_, итос_, --, --, 
   {{0xd5b801ec,0xe80c024a,0xf1dc878d,0x00000000}},	//   _өсе_, _सिता_, _नंदन, --, 
   {{0xe3b001d3,0x2ba801f9,0x00000000,0x00000000}},	//   برٹ_, कवता, --, --, 
   {{0x8544010b,0x6374054e,0x442430e8,0x95c8d463}},	//   _нэче, _vâna, btm_, _суза_, 
   {{0xbee40574,0x7528d464,0x44240334,0x00000000}},	//   कडून_, mfez, ctm_, --, 
   {{0x65bc02d3,0xa3dc02ab,0x752802e2,0x6374054e}},	//   rëhe, _दंत_, lfez, _tâna, 
   {{0x68e0051f,0xa3b0000d,0xed503779,0x00000000}},	//   ycod, _झीट_, وپس_, --, 
   {{0x7528d465,0xece87a16,0x527000d1,0xe0dc180f}},	//   nfez, рдал_, _муқу, rdòc_, 
   {{0xab64d466,0xdcac08b0,0x3ea001a9,0x6fb418a5}},	// [11d40] овал, پىل_, _exht_, _ومعا, 
   {{0x6374002d,0x00000000,0x00000000,0x00000000}},	//   _lânn, --, --, --, 
   {{0x68e0d467,0x00000000,0x00000000,0x00000000}},	//   tcod, --, --, --, 
   {{0x98bc008e,0x2d94228c,0x4424d468,0x37e000fe}},	//   _aluı_, _фрос, ytm_, _নিজৰ, 
   {{0x68e0d469,0x6844499d,0x3a3000d7,0xa83406c2}},	//   rcod, юнда, _epzp_, تعاش, 
   {{0x68e0d46a,0x75280083,0x1b0003d4,0x3ea001a9}},	//   scod, efez, ৰ্বে_, _yxht_, 
   {{0x68e0d46b,0x6994084c,0xd6cc1ec7,0x3ce001f9}},	//   pcod, _драх, نقه_, _कलमे_, 
   {{0x7ae800f3,0xc4d80154,0x1dbc08df,0x31940171}},	//   _đeti, সর্জ, ्षयत, bāzi_, 
   {{0x4424020c,0x51e00150,0x7b08032e,0xdd000055}},	//   utm_, _ﺍﻟﻨﺸ, _ástö, _śrīj, 
   {{0x44240ac5,0x63680408,0x00000000,0x00000000}},	//   rtm_, рриг_, --, --, 
   {{0x91e001e0,0x1dbc2072,0x26c80248,0x7c2800ef}},	//   үҙәһ, ्षमत, _àbo_, _ģerm, 
   {{0xc5f00183,0xddc80024,0x00000000,0x00000000}},	//   _টিপা_, čiūn, --, --, 
   {{0x01a8013d,0x00000000,0x00000000,0x00000000}},	//   икүк_, --, --, --, 
   {{0x53302852,0x00000000,0x00000000,0x00000000}},	//   _жешт, --, --, --, 
   {{0x5d640104,0x00000000,0x00000000,0x00000000}},	//   отаз, --, --, --, 
   {{0x61e802d0,0xc1780024,0x00000000,0x00000000}},	//   _itfl, rpės_, --, --, 
   {{0xdcec0311,0x9cc81507,0x00000000,0x00000000}},	// [11d50] _alcă, рыва_, --, --, 
   {{0xa3c8012d,0x00000000,0x00000000,0x00000000}},	//   लगि_, --, --, --, 
   {{0x3f90019b,0x6374002d,0x00000000,0x00000000}},	//   mizu_, _lâno, --, --, 
   {{0x3f900b91,0x6cd402dd,0x31b000d0,0xca4801d5}},	//   lizu_, _ىقپا, bázu_, غلنه_, 
   {{0xa3c80574,0xf8b801c0,0xe72c02dd,0xc4e401ec}},	//   लगा_, сөв_, не_, _ﺍﺸﺘﻌ, 
   {{0xa3dc11d7,0x7bdcd46c,0x7c380724,0x7f440455}},	//   _दूध_, _iusu, ğarı, _jahq, 
   {{0x7bdcd46d,0x7c380365,0xb9840022,0x5bd800bc}},	//   _husu, şarı, _етақ, _बढुव, 
   {{0x3dc806a3,0x7f44014f,0x7ae41543,0x00000000}},	//   nmaw_, _lahq, lcht, --, 
   {{0x7528d46e,0x7bd4d46f,0x7bdc8732,0x3f9005f5}},	//   rfez, _kizu, _jusu, kizu_, 
   {{0x7bdcd470,0xd774d471,0x75281529,0x43742d29}},	//   _musu, _بارع, sfez, дуют, 
   {{0x7bd4105c,0x7ae4d472,0x7bdcd473,0xd58404d3}},	//   _mizu, icht, _lusu, _وێته_, 
   {{0xe1ec0323,0x7bd4d474,0x7bdc0af9,0x76400064}},	//   _үг_, _lizu, _ousu, _isly, 
   {{0x7bdcd475,0x3f9002a8,0xfa202b1b,0xfbbc1c15}},	//   _nusu, fizu_, নবিল_, ्गाम, 
   {{0x7bd4d476,0x3f90005a,0x98bc0306,0xf53802f0}},	//   _nizu, gizu_, _nauč_, leť_, 
   {{0xed58d477,0x7bdcd478,0x6374002d,0x2ca00208}},	//   бов_, _ausu, _mânl, _sxkd_, 
   {{0x7ae4d479,0x6374002d,0x69d85725,0x7bd4d47a}},	//   echt, _lânl, _étei, _aizu, 
   {{0x7bdc0a81,0x7bd4046a,0xdca05cf0,0x3f9094c1}},	// [11d60] _cusu, _bizu, еати, bizu_, 
   {{0xef84d47b,0x3f900064,0x00000000,0x00000000}},	//   _хлоп, cizu_, --, --, 
   {{0x7bd4d47c,0x7bdc0005,0x8cc0033f,0xdf4401c6}},	//   _dizu, _eusu, लेजो, _эзэд_, 
   {{0x7ae406d5,0x7bdcd47d,0xada4d47e,0x7bd403ac}},	//   acht, _fusu, _хамл, _eizu, 
   {{0x2d90d47f,0x7bdcd480,0x6d44d481,0xccf4043b}},	//   miye_, _gusu, _iaka, mbɛ_, 
   {{0x2d90d482,0xa3c0038e,0x7bd40083,0x98bc0306}},	//   liye_, ्दछ_, _gizu, _gauč_, 
   {{0x6d44d483,0x6b8c025c,0x7bdc0036,0xe80c924b}},	//   _kaka, _imbg, _zusu, _सिवा_, 
   {{0x2d90d484,0x6d44d485,0xd940d486,0x7bd4d487}},	//   niye_, _jaka, _песи, _zizu, 
   {{0x6d44d488,0x7bdc93bc,0x7bd4d489,0xdbd80cad}},	//   _maka, _xusu, _yizu, _nàìj, 
   {{0x7bd402b9,0xb3440120,0x427454d9,0xe72801e2}},	//   _xizu, _raçã, дгос, _دسرو_, 
   {{0x2d900537,0x3dc80054,0x3f90d48a,0x9f6000e4}},	//   kiye_, ymaw_, vizu_, _ãvéi_, 
   {{0x6d44ae45,0x7f44047e,0x2d90d48b,0x071c00c5}},	//   _naka, _sahq, jiye_, _नाँव_, 
   {{0x2d90d48c,0x6374002d,0x3f90009d,0x1074b464}},	//   diye_, _hânm, tizu_, еляю, 
   {{0x6d44d48d,0x1be005f9,0x6440023a,0x7f448e61}},	//   _aaka, _कंबल_, _isoi, _qahq, 
   {{0x4ea4d48e,0x2d90d48f,0x7bdcd490,0x61e82ff9}},	//   ерта, fiye_, _susu, _utfl, 
   {{0x2d900537,0x7bdcd491,0x6d44d492,0x7bd4d493}},	//   giye_, _pusu, _caka, _sizu, 
   {{0x071c19ec,0x6d44d494,0x7f44d36a,0x6374002d}},	// [11d70] _नांव_, _daka, _tahq, _lânm, 
   {{0x7bdc1682,0x7ae4d495,0x0bb4224f,0x6d44d496}},	//   _vusu, ucht, ебую, _eaka, 
   {{0x6d44d497,0x7bd4d498,0x2d90d499,0x7ae4d49a}},	//   _faka, _vizu, biye_, rcht, 
   {{0x7ae404d1,0x2d90d49b,0x6d44d49c,0x7bdcd49d}},	//   scht, ciye_, _gaka, _tusu, 
   {{0x7bd4d49e,0xb90405f9,0x7bdc0194,0xf744671b}},	//   _tizu, _नल_, _uusu, дело, 
   {{0x7bd40204,0x320402fb,0xe80c9543,0x4e94006c}},	//   _uizu, ysly_, _सिरा_, _آشیر, 
   {{0x6d44d49f,0x8704d4a0,0x81bc00e2,0xb18001e3}},	//   _yaka, ربول, ttēl, ååke, 
   {{0x1dbc0b9c,0x5ebc00bd,0x6d44d4a1,0xa3dc02ab}},	//   ्षित, _আলাই, _xaka, _दंश_, 
   {{0x64400175,0x31b001ed,0x00000000,0x00000000}},	//   _csoi, zázs_, --, --, 
   {{0xdbd80241,0x628401e4,0xa3d00073,0x842400d1}},	//   _nàíj, ĝkon, _वळण_, رىپن, 
   {{0x64400109,0x3204b561,0x2d90d4a2,0x1dbc08a3}},	//   _esoi, usly_, yiye_, ्षात, 
   {{0x81bc00de,0x2d900067,0xe4d015b4,0x00000000}},	//   ltēj, xiye_, عقید, --, 
   {{0x6d44d4a3,0xa018066d,0xe3ac4077,0x2d9003ee}},	//   _raka, szön, _аб_, viye_, 
   {{0x2d90d4a4,0x81bc005f,0x21e40046,0xdd14010e}},	//   wiye_, ntēj, _ﺍﻟﺩﻭ, läňi, 
   {{0x6d44d4a5,0x2d900516,0xa3c80118,0x00000000}},	//   _paka, tiye_, लगर_, --, 
   {{0x6d440117,0xa2a40254,0xe80c02e5,0x31b001ed}},	//   _qaka, _घुट्, _सिला_, rázs_, 
   {{0x6d44d4a6,0x2d90d4a7,0xdb040008,0xf9040183}},	// [11d80] _vaka, riye_, _skjá, ৰভাৱ_, 
   {{0x6d4492f1,0xdcec0a30,0x7c642097,0x92dc03d4}},	//   _waka, ādāt, راقل, তৰৰ_, 
   {{0xa924d4a8,0x2d90d4a9,0x1ee41888,0xdd1400a2}},	//   ддел, piye_, _توپی_, käňi, 
   {{0x6d4403a0,0x21e40150,0xdd1400a2,0x81bc00de}},	//   _uaka, _ﺍﻟﺯﻭ, jäňi, etēj, 
   {{0xa7a8036b,0x6374054e,0x1864503d,0x00000000}},	//   окда_, _sânm, маци_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfcf00023,0xc5f000f1,0xfbbc01f9,0x00000000}},	//   _ውሕጅ_, اړئ_, ्गरम, --, 
   {{0x19cc1c5c,0xd5b4d4aa,0xe0dc007f,0x84c400fb}},	//   _ﺑﺎﻳﻠ, мсы_, gdòl_, нәлд, 
   {{0x7aec0c6a,0x00000000,0x00000000,0x00000000}},	//   _énté, --, --, --, 
   {{0x21e401ec,0x50e4002b,0x00000000,0x00000000}},	//   _ﺍﻟﺭﻭ, _āvāṃ_, --, --, 
   {{0x81bc0029,0xa3dc1f5e,0xd5acd4ab,0xc33001d9}},	//   stēm, _दूर_, _ас_, نٕک_, 
   {{0x98bc0374,0x6440d4ac,0x2d9c01ed,0x64c401ec}},	//   _hauā_, _tsoi, étel_, _قيال, 
   {{0x98bc0374,0x13f00024,0x20c4009d,0x00000000}},	//   _kauā_, _азія, ьсог, --, 
   {{0x81bc00da,0xd68001e4,0x00000000,0x00000000}},	//   otēk, menϲ, --, --, 
   {{0xe2a8d4ad,0x6374000f,0xf1c801fb,0x00000000}},	//   _باشن_, _lânk, _lạy_, --, 
   {{0xcd6c0092,0x63b80142,0x925400f2,0x98acbfb6}},	//   _በቻይና_, lltn, _آشور_, legą_, 
   {{0x3b54d4ae,0x4c94d4af,0x65bc0240,0xe0dc02e2}},	// [11d90] нкар, витс, hëho, ndòm_, 
   {{0x25c807b7,0x00000000,0x00000000,0x00000000}},	//   ागुण, --, --, --, 
   {{0x99e825aa,0x63b80076,0x3914d4b0,0xbdd42077}},	//   زعاق_, iltn, емер, _поощ, 
   {{0x81ac03d4,0x63b800d7,0x00000000,0x00000000}},	//   _কওঁ_, hltn, --, --, 
   {{0xf8b02c26,0xf1c80208,0x00000000,0x00000000}},	//   اکز_, _cạy_, --, --, 
   {{0xf1c80016,0xdb04168c,0xf62464cf,0xd90c0133}},	//   _dạy_, _skjæ, едко, _چیا_, 
   {{0xd90cd4b1,0x81bc0029,0xbbbc2ef1,0x3dd8016b}},	//   _نیا_, rtēj, ्गीक, _kisw_, 
   {{0x81bc005f,0x63b82305,0x62840115,0x068c0150}},	//   stēj, eltn, ĝkol, _ﺒﺒﻌﺽ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe7a40222,0xd7c403e6,0x76e80116,0xc8a800c5}},	//   _كۇنى_, _کوڕه_, _хуаң_, _छुटट, 
   {{0x1dd8000d,0xf4d801e0,0x78f800df,0x00000000}},	//   _मंगत, _емеш_, ּפֿו, --, 
   {{0x92dc00bd,0x6374000f,0x45d007d2,0x463800ae}},	//   তরে_, _lânh, _ﺗﺎﻳﻼ, _تأكد_, 
   {{0x600410f5,0xb9f8001f,0x29080134,0x05741411}},	//   нням_, _ህገ_, _ɛba_, _جالد, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6da4005b,0x63a400e5,0x00000000,0x00000000}},	//   еива, ékne, --, --, 
   {{0x61ec04cf,0x5d64084c,0xa3dc012d,0x00000000}},	//   íble, нисм_, _दूँ_, --, 
   {{0xeaf800c6,0x1be00037,0x00000000,0x00000000}},	// [11da0] كرات_, _कूदल_, --, --, 
   {{0xef180958,0x2ca40003,0x00000000,0x00000000}},	//   _эмо_, ħod_, --, --, 
   {{0xe9d8d4b2,0x8eb423f6,0x7e6001e6,0x6374002d}},	//   чке_, _شەرت, älpt, _sânk, 
   {{0x98bc0607,0x3ce804cc,0xa80454a0,0x3078008f}},	//   _sauā_, ccav_, ездл, ּאַנ, 
   {{0x21e40150,0xa3dc012d,0x63b801e3,0x00000000}},	//   _ﺍﻟﺤﻭ, _दूं_, yltn, --, 
   {{0xf1c80051,0x00000000,0x00000000,0x00000000}},	//   _vạy_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x65bc0200,0x00000000,0x00000000,0x00000000}},	//   rëho, --, --, --, 
   {{0x98a0d4b3,0x98bc0ef0,0x29045ede,0x66d8010b}},	//   _бите, _tauā_, maoa_, _еьер_, 
   {{0x2904d4b4,0xe0dc067c,0x628401e4,0x00000000}},	//   laoa_, rdòm_, ŝkom, --, 
   {{0x637400d8,0x27e401b9,0x00000000,0x00000000}},	//   _jâni, lqon_, --, --, 
   {{0x2904d4b5,0x6374054e,0x1a98010f,0x00000000}},	//   naoa_, _mâni, לייע, --, 
   {{0x6374002d,0x27e4d4b6,0x92dc00fe,0x94700345}},	//   _lâni, nqon_, তৰে_, _مدوا, 
   {{0x29041132,0xd5dc0cf1,0xe8009856,0x4adc0037}},	//   haoa_, _पूँज, रीया_, _बलगव, 
   {{0x27e401b9,0x01c400c7,0x8fe401e0,0x00000000}},	//   hqon_, _ириҭ, _ҡәрҙ, --, 
   {{0x6374000f,0x290401f7,0x212c01ab,0xd99c0150}},	//   _sânh, jaoa_, _ùgh_, _ﺃﻓﺎﺩ_, 
   {{0xe8000316,0x3ce80ffb,0x290401c4,0x00000000}},	// [11db0] रीमा_, rcav_, daoa_, --, 
   {{0x2008d4b7,0x7e6001e6,0x6e2c01bf,0x00000000}},	//   msci_, älps, ønbæ, --, 
   {{0xd5dc1533,0x29040421,0x1be000e1,0x200833e7}},	//   _पूंज, faoa_, _कंवल_, lsci_, 
   {{0x29040421,0x27e401f5,0x00000000,0x00000000}},	//   gaoa_, fqon_, --, --, 
   {{0xdbd80248,0x2008d4b8,0x00000000,0x00000000}},	//   _fàáj, nsci_, --, --, 
   {{0x7c2c069c,0x39485914,0x8b0403f9,0x2b1c0cf1}},	//   mtar, žas_, ƙƙad, _पाएँ_, 
   {{0x6374045f,0xcf580302,0x3f8001ef,0x00000000}},	//   _hânw, תבות_, _mlhu_, --, 
   {{0x4904d4b9,0x7c2cd4ba,0x27200270,0xab6c001f}},	//   _موفق, otar, _pōní_, _በጊዜው_, 
   {{0xd6d8d4bb,0x200805a1,0xd7f80364,0xa804d4bc}},	//   _ете_, jsci_, _хуб_, rañó, 
   {{0x7c2cd4bd,0x69d814a9,0xd7640046,0x00000000}},	//   itar, _éter, _سەبى_, --, 
   {{0x7c2cd4be,0x5f240183,0x6374002d,0x2d9c01ed}},	//   htar, য়াও_, _lânw, étek_, 
   {{0xafe4d4bf,0x00000000,0x00000000,0x00000000}},	//   комл, --, --, --, 
   {{0x7c2c02d3,0x21a0d4c0,0x4ce00154,0x21e402dd}},	//   jtar, риям, _ফজলু, _ﺍﻟﺼﻭ, 
   {{0x7334005e,0x00000000,0x00000000,0x00000000}},	//   _شىعا, --, --, --, 
   {{0x7c2cd4c1,0x3244586a,0xde003c18,0x3f8000d0}},	//   etar, _рейг, ипри, _dlhu_, 
   {{0x7c2c7f37,0x2b48d4c2,0xe8000833,0xf8a4d4c3}},	//   ftar, _sabc_, रीडा_, _هک_, 
   {{0x7c2cd4c4,0x29040607,0x63743c6b,0x2008009f}},	// [11dc0] gtar, vaoa_, _sâni, csci_, 
   {{0xfd540521,0x63740120,0x290401f7,0x06cc0154}},	//   _kraị, _pâni, waoa_, রুটি, 
   {{0x6da40124,0x29040618,0x78a83b22,0x7c2800a2}},	//   _аина, taoa_, _axev, _ţert, 
   {{0x7c2cd4c5,0x63743bd4,0x8fd4035b,0x98ac0210}},	//   btar, _vâni, _шәҟә, legę_, 
   {{0x2904d4c6,0xdb042dba,0x26dc00d8,0x2d8005d1}},	//   raoa_, _skjå, _pgto_, _ilke_, 
   {{0xf8a8168d,0x29040607,0x63740798,0x18640063}},	//   ردنه_, saoa_, _tâni, таљи_, 
   {{0x290402b5,0xe9a800ec,0x09880b01,0xe8000037}},	//   paoa_, _قدرن_, _завқ_, _रौरा_, 
   {{0xe5c40063,0x27e4022e,0x20080210,0x00000000}},	//   њско, pqon_, ysci_, --, 
   {{0x27e401d5,0xbb2802dd,0x00000000,0x00000000}},	//   qqon_, _ﺤﻴﻥ_, --, --, 
   {{0x6cc80150,0x00000000,0x00000000,0x00000000}},	//   _ﻓﺼﺤﻴ, --, --, --, 
   {{0xe524d4c7,0xa524035b,0x7c2c1bfe,0x2d8003b9}},	//   _адеп, _амед, ztar, _olke_, 
   {{0xfd5401f2,0x64440008,0x73d800f7,0x92900006}},	//   _draị, ækis, мдөр_, раюц, 
   {{0x7c2cd4c8,0x3f8001d4,0x25a400f2,0x64440213}},	//   xtar, _plhu_, _ijol_, çkid, 
   {{0xfd5402e3,0x425401f7,0x00000000,0x00000000}},	//   _fraị, _منتر, --, --, 
   {{0x91e0026a,0x6374000f,0x7c2c0034,0x25a40267}},	//   _које, _sânw, wtar, _kjol_, 
   {{0x7c2cd4c9,0xd1ec044e,0xb8d4025c,0x01a800ec}},	//   ttar, _ቀረባ_, _ཛྙ_, _سڏجي_, 
   {{0xd1b82cb0,0x7c2cd4ca,0xbb68037e,0x3f80047e}},	// [11dd0] _جاوا_, utar, _netメ_, _tlhu_, 
   {{0x7c2cd4cb,0x2d8025eb,0xd9c80bca,0x1dc02e1e}},	//   rtar, _elke_, िष्ट, _वीरत, 
   {{0x25a40098,0x1ea83229,0xdde801e2,0x00000000}},	//   _ojol_, _زادي_, _ترخه_, --, 
   {{0x7c2c067d,0xe80c012d,0x00000000,0x00000000}},	//   ptar, _सिखा_, --, --, 
   {{0x7c2cd4cc,0x6fd8009e,0xa3dc1b76,0xab605f32}},	//   qtar, _বৌয়ে, _दंग_, _گۇلى, 
   {{0x25a400d5,0xd76004d3,0x69d80395,0x33f41955}},	//   _ajol_, شنبی, _èten, қчис, 
   {{0xc794d4cd,0xb9080f22,0x00000000,0x00000000}},	//   جشنب, _য়_, --, --, 
   {{0x0554d4ce,0x78a800db,0x69d800e4,0x6374054e}},	//   атья, _txev, _étep, _mânu, 
   {{0x25a402e2,0x394c01e4,0x79980036,0x7374009d}},	//   _djol_, _iaes_, miww, гынх, 
   {{0x394cd4cf,0xfd5401f2,0x799804e6,0x24c49a25}},	//   _haes_, _praị, liww, ыгып_, 
   {{0x35f4d4d0,0x25a401e6,0x394c0036,0x753401c6}},	//   _спер, _fjol_, _kaes_, _бэлх, 
   {{0x79980221,0x95780092,0x00000000,0x00000000}},	//   niww, ኖቻችን_, --, --, 
   {{0x394c0cfd,0xb5e400cc,0x00000000,0x00000000}},	//   _maes_, _নবিচ, --, --, 
   {{0x649804ac,0x394c0037,0x439400db,0xa3800254}},	//   _אינה, _laes_, _качс, õõtu, 
   {{0xad582fc3,0x00000000,0x00000000,0x00000000}},	//   нрах_, --, --, --, 
   {{0x394c1509,0xe1f400ee,0x908801d3,0xeb4807d6}},	//   _naes_, _ёгы_, _لمبے_, کشرو_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [11de0] --, --, --, --, 
   {{0x09dc1fbc,0xddc80118,0x00000000,0x00000000}},	//   यद्य, čišn, --, --, 
   {{0x4a440aeb,0xdca0d4d1,0x394c002d,0xba0400c7}},	//   рмең, _ғари, _baes_, иҭра_, 
   {{0x394c8f9b,0x6374002d,0x2d80d4d2,0x79980e14}},	//   _caes_, _hânt, _ulke_, giww, 
   {{0xa85091e3,0x394c1c1d,0x00000000,0x00000000}},	//   селә, _daes_, --, --, 
   {{0x1ae021c1,0xc44803e6,0x81bc00e2,0xc7b80051}},	//   _горм, ێیان_, ltēt, _qkđ_, 
   {{0x63740276,0x394cd4d3,0xdb80d4d4,0x00000000}},	//   _mânt, _faes_, _угри, --, 
   {{0xe5c48727,0x5e5400c8,0x81bc00da,0x394c1c1d}},	//   ысло, ריקע_, ntēt, _gaes_, 
   {{0x6fb40825,0x00000000,0x00000000,0x00000000}},	//   ृतां, --, --, --, 
   {{0xdb040174,0xba0c0139,0x00000000,0x00000000}},	//   _skjú, _äçäk, --, --, 
   {{0xc0c80020,0x25a4017a,0x1b000183,0x65bc0240}},	//   _በዚሁ_, _tjol_, ৰ্কে_, hëhi, 
   {{0xc0c80201,0x2164d4d5,0xa5087696,0xda7800df}},	//   _በሚል_, утог, _чеда_, גנטר, 
   {{0x6374054e,0x8cb00406,0x44200022,0x7f480023}},	//   _sânu, _अँगो, _êi_, _ብምፍጣ, 
   {{0x6374084c,0x81bc00ef,0x00000000,0x00000000}},	//   _cânt, etēt, --, --, 
   {{0x925400ec,0x63740208,0xbed40798,0x00000000}},	//   _مشير_, _dânt, ровј, --, 
   {{0x9e400122,0xfc1400a8,0xbca4007b,0x00000000}},	//   žďov, имбэ, لمزي, --, 
   {{0x394cd4d6,0x63740311,0x7cd800db,0xfcc4a4c3}},	// [11df0] _raes_, _fânt, тмар_, рәнм, 
   {{0x394c08cd,0x6d88032e,0x00000000,0x00000000}},	//   _saes_, _nýaf, --, --, 
   {{0x6374045f,0x394cd4d7,0xa49401e4,0x7998d4d8}},	//   _hâns, _paes_, _deϲi, tiww, 
   {{0x63740b21,0x49b8a87f,0x81bc0171,0x00000000}},	//   _kâns, هاند_, ctēt, --, 
   {{0x79980a40,0x6374002d,0x287401e0,0x977000d1}},	//   riww, _jâns, аҡты_, йткә, 
   {{0x394cd4d9,0x6374045f,0x7c3c02d0,0x79980036}},	//   _waes_, _mâns, _ipsr, siww, 
   {{0xc0c82295,0x63740b21,0x394cd4da,0x7c3c005a}},	//   _በዚህ_, _lâns, _taes_, _hpsr, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb384d4db,0x5724bd62,0x5884030d,0x00000000}},	//   илил, _مراق, _сыва, --, 
   {{0xe0dc067c,0x00000000,0x00000000,0x00000000}},	//   ndòu_, --, --, --, 
   {{0x6374002d,0x49b801ed,0x255c063f,0x00000000}},	//   _rânt, _شاہد_, ọlam_, --, 
   {{0xe294d4dc,0x24940502,0x6374d4dd,0x00000000}},	//   раю_, انید_, _sânt, --, 
   {{0xafe4d4de,0x63748416,0xfbc400cd,0x51e00150}},	//   рогл, _pânt, वताम, _ﺍﻟﻌﺸ, 
   {{0x63740311,0xdce80115,0x00000000,0x00000000}},	//   _dâns, ĉiĝo, --, --, 
   {{0x2d94d221,0x63740311,0x3170054e,0xf1d000cf}},	//   арас, _vânt, _toyz_, _мөмө, 
   {{0xa6b0009e,0xa1900e92,0x45d000d1,0xed441fbe}},	//   টেকট, _мајч, _ﺗﺎﻟﻼ, јнап, 
   {{0x63749fe9,0x81bc005f,0x1be40108,0xeb280150}},	// [11e00] _gâns, rtēt, идти_, кжал_, 
   {{0x81bc005f,0x62840115,0x2eec0205,0x65bc036e}},	//   stēt, ĝkov, _üff_, rëhi, 
   {{0x7c3cd4df,0x81bc00e2,0x69240026,0x00000000}},	//   _epsr, ptēt, имжа, --, 
   {{0x6e3c05b1,0x00000000,0x00000000,0x00000000}},	//   _ippb, --, --, --, 
   {{0x69d8011c,0x7c3c01c4,0x6d8800ee,0x6d5800b0}},	//   _ètem, _gpsr, _aýag, _ėtah, 
   {{0x6374002d,0xe0dc01ab,0x2078010f,0x46140271}},	//   _lânr, leòc_, כאנא, موتر, 
   {{0xe664d021,0x57200228,0x00000000,0x00000000}},	//   ртло, زىيك, --, --, 
   {{0xdb04d4e0,0x764402d1,0x00000000,0x00000000}},	//   _skjø, çhya, --, --, 
   {{0x69c000c5,0x81bc00e2,0xe0dc007f,0xf3f4030f}},	//   mloe, ktēr, ndòt_, یتیک, 
   {{0x69c0d4e1,0x6e3c03a1,0x3eac03e0,0x00000000}},	//   lloe, _oppb, şeti_, --, 
   {{0xa6941614,0x63740b21,0xa5740014,0x94701bf4}},	//   _трај, _sâns, _پُشت, مدیا, 
   {{0x6374002d,0xc21001d9,0x00000000,0x00000000}},	//   _pâns, _ۂت_, --, --, 
   {{0xb9dc069c,0x69c0252c,0x65600438,0x6e3c5b4f}},	//   _እወ_, iloe, _inoh, _appb, 
   {{0x4424d4e2,0x69c0d4e3,0x8cb0007d,0xdb040158}},	//   mum_, hloe, _अँजो, _ukjø, 
   {{0x8de8d4e4,0x69c0d4e5,0x6374000f,0x81d40354}},	//   ифта_, kloe, _wâns, _локх, 
   {{0xccf80640,0x44240165,0x61f89337,0x8eb40228}},	//   ићу_, oum_, mptl, تەپت, 
   {{0x4424d4e6,0x656003c6,0x7f94013e,0x69c003cb}},	// [11e10] num_, _mnoh, _гапх, dloe, 
   {{0x44241730,0x6d88010e,0x69c0020c,0x8af8009b}},	//   ium_, _aýad, eloe, инус_, 
   {{0x4424d4e7,0x69c00b21,0x6560d4e8,0xe0dc067c}},	//   hum_, floe, _onoh, rdòu_, 
   {{0x69c0017a,0x98f400c7,0x49a40114,0x7aec00de}},	//   gloe, рҭас_, ојча, _šitā, 
   {{0x4424d4e9,0x7d0cd4ea,0xe80052f2,0x30f81be1}},	//   jum_, maas, रीला_, ूरतः_, 
   {{0xbb8406d5,0x4424d4eb,0xf744afe2,0x6560d4ec}},	//   _السي, dum_, секо, _anoh, 
   {{0x4424d4ed,0x69c0d4ee,0x6d5000c7,0xf8b801c6}},	//   eum_, bloe, _ëkañ, _өөд_, 
   {{0x7d0cd4ef,0x4424d4f0,0x69c00137,0xa0180730}},	//   naas, fum_, cloe, nzös, 
   {{0x44240ad9,0x7d0c0869,0xac740023,0x80d8134e}},	//   gum_, iaas, _በጺሖም_, नेमे, 
   {{0x7d0cd4f1,0x6374000f,0x6560d4f2,0x6a70022e}},	//   haas, _sânr, _enoh, _kаfе, 
   {{0x7d0c193f,0x32101ab0,0xa0180108,0xa560215c}},	//   kaas, ézy_, hyöd, تگەن, 
   {{0x7d0cd4f3,0x44243af1,0x3d20033f,0x8544013d}},	//   jaas, bum_, यलों_, _мэче, 
   {{0x4424d4f4,0x7d0cd4f5,0x75280b6f,0x6e3c05b1}},	//   cum_, daas, mgez, _sppb, 
   {{0xa02400fc,0x7d0c0037,0x00000000,0x00000000}},	//   _stöð, eaas, --, --, 
   {{0x7d0cd4f6,0x75281418,0xfe70072d,0x81bc00de}},	//   faas, ogez, ودِ_, frēd, 
   {{0x7d0c193f,0x7528d4f7,0x1b1c00fe,0x81bc00de}},	//   gaas, ngez, ন্মই_, stēr, 
   {{0x69c0225e,0x7528002f,0xbb280150,0xfd5400a2}},	// [11e20] vloe, igez, _ﺤﺴﻲ_, lmeỳ, 
   {{0xefb0030f,0xa01801d3,0x75282ad7,0x387c0042}},	//   _ریزگ, rzöt, hgez, dywr_, 
   {{0x7d0cd4f8,0x6e3cd4f9,0x69c0d4fa,0xe8f8d4fb}},	//   baas, _uppb, tloe, гле_, 
   {{0x4424d4fc,0x7d0cd4fd,0x75280d27,0x6f0cd4fe}},	//   yum_, caas, jgez, labc, 
   {{0x4424d4ff,0x69c0cfbc,0x98a05a31,0x7644062c}},	//   xum_, rloe, пице, çhyn, 
   {{0x4424d500,0x6f0cd501,0x75280489,0x3a0801d3}},	//   vum_, nabc, egez, _چکنی_, 
   {{0x4424d502,0x69c0d503,0x75283262,0xdb80010b}},	//   wum_, ploe, fgez, _эгри, 
   {{0x4424d504,0x7528d505,0x6b9cd506,0x6f0c014f}},	//   tum_, ggez, lipg, habc, 
   {{0x4424d507,0x2bbc012a,0x00000000,0x00000000}},	//   uum_, ्तपा, --, --, 
   {{0x4424d508,0x6f0cd509,0x75281418,0x7d0cd50a}},	//   rum_, jabc, agez, zaas, 
   {{0x4424d50b,0x7d0c331f,0x97c0040e,0x6f0c014f}},	//   sum_, yaas, _эйфе, dabc, 
   {{0x6560d50c,0x7d0c0050,0x25700131,0x244401a9}},	//   _unoh, xaas, _رۇخس, _гхкг, 
   {{0x5430d50d,0x4424d50e,0xe4c401d5,0x51e00150}},	//   _فرور, qum_, _уйди, _ﺍﻟﻜﺸ, 
   {{0x7d0c1db9,0x6728332c,0x6f0c0198,0x2bbc00e1}},	//   waas, ngfj, gabc, ्तफा, 
   {{0x7d0cd50f,0x88c0045e,0x2bbc215d,0xdda800ee}},	//   taas, েশিক, ्तना, гтал_, 
   {{0x63b8d510,0xd1300e26,0xdb14056a,0x00000000}},	//   lotn, _كۅپ_, moxé, --, 
   {{0x7d0cd511,0x6f0c01b9,0x8cc812a5,0x61e80208}},	// [11e30] raas, babc, موفق_, _hufl, 
   {{0x7d0cd512,0x61e8014b,0x63b81290,0x2d9cd513}},	//   saas, _kufl, notn, éter_, 
   {{0xdb140077,0x61e8022e,0x99540139,0xd9bc0011}},	//   noxé, _jufl, _cçş_, েদসম, 
   {{0x41c80be7,0x63b8d514,0x7d0cd515,0x61e881cb}},	//   रतिस, hotn, qaas, _mufl, 
   {{0x63b8d516,0xf8b00f01,0x6cd40150,0x00000000}},	//   kotn, ذکر_, _وقپا, --, 
   {{0x36181c22,0x752801a4,0x63b8d517,0x67280174}},	//   ацию_, wgez, jotn, ggfj, 
   {{0x7528d518,0x63b8d519,0x6444d51a,0xbbc4012c}},	//   tgez, dotn, çkin, वतीक, 
   {{0x6374ba97,0x7bc4d51b,0x0e9c0a1e,0x00000000}},	//   _sânp, llhu, טשול, --, 
   {{0x61e88e11,0x79880c8c,0x63b801a9,0x00000000}},	//   _aufl, _ilew, fotn, --, 
   {{0x7528d51c,0x79880156,0x36d41bc0,0xdb200166}},	//   sgez, _hlew, _дозр, _äräm, 
   {{0x7988d51d,0x61e805d5,0x7bc40165,0x75281190}},	//   _klew, _cufl, ilhu, pgez, 
   {{0x61e8d51e,0x00000000,0x00000000,0x00000000}},	//   _dufl, --, --, --, 
   {{0x2bbc96e9,0x61e80076,0x7988031c,0xdb040174}},	//   ्तमा, _eufl, _mlew, _skjý, 
   {{0x798803cb,0xd34412e1,0x63b801ef,0x04c801f7}},	//   _llew, _ایده_, cotn, _اوهي_, 
   {{0xe2940323,0x7988d51f,0xdee0d520,0x6f0c0c09}},	//   _маш_, _olew, дори, rabc, 
   {{0x7bc4d521,0xb4f8008f,0x00000000,0x00000000}},	//   elhu, שפּי, --, --, 
   {{0xeb98035b,0xa01801ed,0x61e80b70,0x6f0c047e}},	// [11e40] аиа_, ször, _zufl, pabc, 
   {{0x7640105c,0x61e80009,0xeb98022e,0x00000000}},	//   _oply, _yufl, шиз_, --, 
   {{0x7988d522,0x6b9c0b21,0xe8e801ec,0x28e8004e}},	//   _blew, ripg, амед_, адеп_, 
   {{0xed58d523,0x6b9c03ac,0x00000000,0x00000000}},	//   _том_, sipg, --, --, 
   {{0x63b807d6,0x798800f2,0x6d540472,0x1b1c00cc}},	//   yotn, _dlew, mdya, ন্ধই_, 
   {{0x7988d524,0xd0b0013f,0x6d54d525,0x8f1c009d}},	//   _elew, _sɛɛv, ldya, _бvх_, 
   {{0x63b87c95,0x672805ac,0x79880042,0x00000000}},	//   votn, rgfj, _flew, --, 
   {{0x6d542d5b,0xabc404a9,0x61e80998,0x1b1c02f5}},	//   ndya, ﺪﯨﻐﺎ, _rufl, ন্দই_, 
   {{0x61e800a8,0x23681b88,0x63b8d526,0x6d54d527}},	//   _sufl, ајно_, totn, idya, 
   {{0x40340032,0xdb140005,0x61e801a9,0x3868050a}},	//   үенс, toxé, _pufl, åare_, 
   {{0x63b8d528,0xe0c404c5,0x21e401ec,0x00000000}},	//   rotn, _এলেন, _ﺍﻟﺒﻭ, --, 
   {{0x63b8d529,0xdb140005,0x81bc00de,0x00000000}},	//   sotn, roxé, cuēl, --, 
   {{0x63b8151c,0x83f80395,0xd49400d8,0x7640013a}},	//   potn, _уелс_, _мрш_, _zply, 
   {{0x6440d52a,0xdb140077,0x2d9c0066,0x61e8d52b}},	//   _ipoi, poxé, èten_, _tufl, 
   {{0xdd98d52c,0x00000000,0x00000000,0x00000000}},	//   аша_, --, --, --, 
   {{0xabb4035b,0x00000000,0x00000000,0x00000000}},	//   ҧатә, --, --, --, 
   {{0xc0c402d9,0x7bc4016d,0xd0080120,0xe7c82e35}},	// [11e50] _хәни, tlhu, _дење_, िताप, 
   {{0x64400109,0xdde8d52d,0x79880076,0x7bc40066}},	//   _mpoi, _پرده_, _slew, ulhu, 
   {{0xdb041ffb,0x7a380a5b,0x7bc40076,0x6d5400b8}},	//   _skjó, спер_, rlhu, bdya, 
   {{0x6440d52e,0xd91805f5,0xc9848f18,0x00000000}},	//   _opoi, рьж_, мучи, --, 
   {{0x644403be,0x76400306,0x515c011a,0x00000000}},	//   çkil, _sply, יכאו, --, 
   {{0x7988012d,0xdb5801af,0x00000000,0x00000000}},	//   _wlew, _тюм_, --, --, 
   {{0x64407c36,0x66e00064,0x3868054e,0x48a80166}},	//   _apoi, ноша, ţar_, йтәм_, 
   {{0x764001f1,0x6440d52f,0x2bbc00dc,0x7988d530}},	//   _vply, _bpoi, ्तथा, _ulew, 
   {{0x76400210,0x00000000,0x00000000,0x00000000}},	//   _wply, --, --, --, 
   {{0x644000d8,0x00000000,0x00000000,0x00000000}},	//   _dpoi, --, --, --, 
   {{0x4b7c04ac,0x6440c8cd,0x76400122,0x22b40118}},	//   יאזו, _epoi, _uply, věké_, 
   {{0xe800089a,0x42c8869e,0x95c828e5,0x00000000}},	//   रीका_, өгөн_, _туза_, --, 
   {{0x85b801d9,0x11680214,0x21e40220,0xa9d000d1}},	//   _بالس_, ملگی_, _ﺍﻟﺜﻭ, ﯘﺭﯨﺴ, 
   {{0x6d540009,0xe0d40395,0xed5000e5,0x00000000}},	//   wdya, явя_, کپر_, --, 
   {{0x69ac01f9,0x00000000,0x00000000,0x00000000}},	//   ंचमी, --, --, --, 
   {{0x3ea408de,0xd344006c,0xace801c6,0x644002d0}},	//   últa_, _ایگه_, смаа_, _ypoi, 
   {{0x6d54d531,0x00000000,0x00000000,0x00000000}},	// [11e60] rdya, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6ac40597,0x00000000,0x00000000,0x00000000}},	//   أقام, --, --, --, 
   {{0x7e60019b,0x00000000,0x00000000,0x00000000}},	//   ælpe, --, --, --, 
   {{0x2bbc4c3d,0xbc180212,0x59b0009d,0x00000000}},	//   ्तदा, _мірі_, хөрс, --, 
   {{0x80d839db,0x6a840724,0xa03800df,0x00000000}},	//   ভুক্, _елга, מענפ, --, 
   {{0x64440327,0x00000000,0x00000000,0x00000000}},	//   ħkim, --, --, --, 
   {{0xd9d0192c,0x84c4506f,0x7754001f,0x00000000}},	//   _كەلگ, мәлд, መሠረተ, --, 
   {{0x21e40220,0x00000000,0x00000000,0x00000000}},	//   _ﺍﻟﺘﻭ, --, --, --, 
   {{0x57f80302,0x42a40116,0xd7f8011a,0x64400051}},	//   _ללמו, думғ, _להמל, _vpoi, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdcec0356,0x00000000,0x00000000,0x00000000}},	//   _mocă, --, --, --, 
   {{0x64400618,0x00000000,0x00000000,0x00000000}},	//   _upoi, --, --, --, 
   {{0x61400162,0x00000000,0x00000000,0x00000000}},	//   _bílæ, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4424d532,0xe0dc007f,0xbbc400dc,0x00000000}},	//   orm_, leòm_, वत्क, --, 
   {{0x3b540075,0xda6400ec,0xb06400d7,0x00000000}},	// [11e70] мкар, ڻائي, tpäť, --, 
   {{0x4424379c,0x8fa4009b,0x00000000,0x00000000}},	//   irm_, _пање, --, --, 
   {{0xdac400d1,0x00000000,0x00000000,0x00000000}},	//   سېرى_, --, --, --, 
   {{0x44240306,0x6c0400db,0x00000000,0x00000000}},	//   krm_, سكۅۅ, --, --, 
   {{0xdb1436ed,0x9ba020ea,0x98c400c6,0x7d1c02d0}},	//   loxí, _كەرى, أغان, _idss, 
   {{0x3dc8d533,0x7d1c28b5,0xf77000c6,0xdb20023a}},	//   llaw_, _hdss, ضات_, äräa, 
   {{0x44240221,0x6d88010e,0x29cc010e,0x00000000}},	//   erm_, _mýan, mýan_, --, 
   {{0x29cc09a5,0x4424d534,0x3dc8047e,0x00000000}},	//   lýan_, frm_, nlaw_, --, 
   {{0x3dc81c06,0xf74800aa,0x6d88010b,0xccf4010f}},	//   ilaw_, _ولري_, _oýan, עכץ_, 
   {{0x29cc0209,0x3dc80842,0x00000000,0x00000000}},	//   nýan_, hlaw_, --, --, 
   {{0x3dc8d535,0x44240b21,0x60e00213,0x00000000}},	//   klaw_, arm_, ətmə, --, 
   {{0x6d88010e,0x44240175,0x3dc80978,0x645001f4}},	//   _aýan, brm_, jlaw_, äjiä, 
   {{0x4424009a,0x3dc8d536,0xc4f8d537,0x85b80014}},	//   crm_, dlaw_, _رعنا_, _عامس_, 
   {{0x7df40024,0x3dc800e8,0xb2240137,0x61ec01e7}},	//   _sąsa, elaw_, _жмкл, úilí, 
   {{0xe8a80882,0xdb14056a,0xed5801c0,0x29cc00ee}},	//   _कश्च, goxí, оов_, dýan_, 
   {{0x3cf4033f,0x3dc880ab,0xa0180108,0xa2d81408}},	//   एँगे_, glaw_, myön, नधर्, 
   {{0xdca0d538,0xa01802f6,0x908800e5,0x00000000}},	// [11e80] вати, lyön, _رمدے_, --, 
   {{0x7d1c02d0,0xdcec0311,0x29cc0432,0x00000000}},	//   _edss, _pocă, gýan_, --, 
   {{0x3dc8d539,0x92b80011,0xf4240166,0x00000000}},	//   blaw_, _অণু_, _şäle_, --, 
   {{0x3dc8d53a,0x5ce0005e,0x7df40153,0x44240205}},	//   claw_, ركەل, _kąsn, yrm_, 
   {{0xa8500cef,0x48cc00fe,0x00000000,0x00000000}},	//   телә, িশ্ৰ, --, --, 
   {{0xdcec054e,0x00000000,0x00000000,0x00000000}},	//   _tocă, --, --, --, 
   {{0xc30c009e,0x386801e4,0x00000000,0x00000000}},	//   _শালি_, ĥara_, --, --, 
   {{0xd1d402d3,0x2bbc228a,0x2d900263,0x44240175}},	//   ረኽበ_, ्तवा, nhye_, trm_, 
   {{0x2904d53b,0x44240dd4,0xefe00092,0x81bc0171}},	//   mboa_, urm_, _ሞገድ_, frēn, 
   {{0x42748ed7,0x6374045f,0x3dc8d53c,0x442400b0}},	//   егос, _hânz, zlaw_, rrm_, 
   {{0x3dc8d53d,0x7c2801e4,0x2ba407b6,0x00000000}},	//   ylaw_, _ĥerm, _गगना, --, 
   {{0xe4a4d53e,0x6b8c0076,0x5a14008f,0x290401c4}},	//   _орло, _llbg, וקטן_, nboa_, 
   {{0x107405b0,0x2d900882,0xd1d402d3,0xe8000490}},	//   вляю, dhye_, ረኽቡ_, रीचा_, 
   {{0x47cc09bd,0x3dc8d53f,0xc7b4010f,0xdb1400d7}},	//   াদকী, wlaw_, גבֿ_, toxí, 
   {{0x3dc8d540,0x7c2804e6,0x4ea400ea,0x00000000}},	//   tlaw_, _äerz, врта, --, 
   {{0x3dc8089c,0xcdd80640,0xabd80150,0x00000000}},	//   ulaw_, дњу_, _ﻁﻌﻨﺎ, --, 
   {{0x3dc8016d,0x0dc802d9,0x00000000,0x00000000}},	// [11e90] rlaw_, фури_, --, --, 
   {{0x3dc8d541,0x2fc80175,0x8cd00073,0x6d88010e}},	//   slaw_, clbg_, _दररो, _uýan, 
   {{0x29cc0209,0x3dc8d542,0x1c18000d,0x2d9000b8}},	//   rýan_, plaw_, _फटकल_, bhye_, 
   {{0x3dc8d543,0x2d9002bd,0x25f0228d,0x7d1c057d}},	//   qlaw_, chye_, ँदनी_, _udss, 
   {{0x6cf802e4,0xc8b402dd,0x00000000,0x00000000}},	//   _מפרס, ксшы, --, --, 
   {{0x37c430cb,0x7c2cd544,0x2904013f,0x6d8800a2}},	//   хәбб, muar, aboa_, _lýal, 
   {{0x2bbc8929,0x7c2cd545,0xcf94008f,0xa3c000c5}},	//   ्तरा, luar, כטס_, ंवन_, 
   {{0x84240131,0x6fd40037,0x6d8802d2,0x98480395}},	//   ھىپن, _मीनू, _nýal, _мяза_, 
   {{0x7c2cd546,0x9ac00116,0x73e412e7,0x7798030d}},	//   nuar, _чиңҗ, ноиз, _екар_, 
   {{0x69d8011c,0x6d880209,0x7c2cd547,0xa018023a}},	//   _èter, _aýal, iuar, työn, 
   {{0x7c2cd548,0x00000000,0x00000000,0x00000000}},	//   huar, --, --, --, 
   {{0x7c2cd549,0xe56c01b9,0x00000000,0x00000000}},	//   kuar, _ёз_, --, --, 
   {{0x7c2cd54a,0xe3ac3605,0x841400c7,0x8534036b}},	//   juar, _бб_, _амчх, _شووچ, 
   {{0x7c2cd54b,0xe4680008,0x00000000,0x00000000}},	//   duar, stöð_, --, --, 
   {{0x2d90d54c,0x9eb40daf,0x59bc012d,0x00000000}},	//   thye_, ештә, एकार, --, 
   {{0xed3405f5,0x7c2c007b,0x5f4007d6,0xdee010e4}},	//   ээгэ, fuar, پچیل, уоси, 
   {{0x7c2cd54d,0xab64d54e,0x2bbc3ec5,0x9d4000ee}},	// [11ea0] guar, нвал, ्तला, ыетд, 
   {{0x2d904c99,0x6374054e,0xb7d000cc,0xe0d4d54f}},	//   shye_, _sânz, াদুট, _явы_, 
   {{0xa924d550,0x200c041e,0x63740311,0x2b582ffe}},	//   едел, _ægir_, _pânz, rdpc_, 
   {{0x7c2cd551,0x6e2c1418,0x00000000,0x00000000}},	//   buar, mubb, --, --, 
   {{0x7c2cd552,0x637400a8,0x290403f5,0x0734117e}},	//   cuar, _vânz, rboa_, велю, 
   {{0x2904d553,0xd1d402d3,0xdb0401a8,0x27940139}},	//   sboa_, ረኽቦ_, _skjö, эшер, 
   {{0x6e2c8913,0xdd1c022a,0x29cc010e,0x00000000}},	//   nubb, líšk, lýam_, --, 
   {{0x2c50007f,0xfa880006,0x7a940244,0x00000000}},	//   _kņd_, _ўсёй_, _جێمز_, --, 
   {{0x98ac0024,0x6e2c0455,0x00000000,0x00000000}},	//   degė_, hubb, --, --, 
   {{0x661801a6,0xa6940f5c,0x6e2cd554,0x5c34008f}},	//   _tvtk, _преј, kubb, ערין_, 
   {{0x94700e60,0x7c2cd555,0xd5ac0220,0x2c500100}},	//   ندیا, zuar, _бс_, _lņd_, 
   {{0x9254005b,0x7c2c022e,0x00000000,0x00000000}},	//   хают_, yuar, --, --, 
   {{0x7c2cd556,0x64a401c6,0xd46400f3,0x00000000}},	//   xuar, _яада, _пице_, --, 
   {{0x6e2c00b5,0x7c2cd557,0x4fc4009d,0x00000000}},	//   fubb, vuar, гсса, --, 
   {{0x5d64d558,0x6e2cd559,0x6d8800a2,0x61b00046}},	//   нтаз, gubb, _eýam, _مەدا, 
   {{0x7c2cd55a,0x409400c6,0x6d880432,0x9c84013a}},	//   tuar, _للبر, _uýal, jičí, 
   {{0xdef8d55b,0x7c2c735c,0x9c84013a,0x00000000}},	// [11eb0] _нын_, uuar, dičí, --, 
   {{0x6e2cd55c,0x3df49808,0x0fe400d1,0x04fc00fe}},	//   bubb, _изос, _бөсү, _এযোৰ_, 
   {{0x7c2cd55d,0x6e2c0548,0x80a40950,0x00000000}},	//   suar, cubb, _चेते, --, 
   {{0x7c2cd55e,0xfbd000aa,0x4ac4007b,0xbdc000d1}},	//   puar, اتړ_, ديمق, _ئەرۋ, 
   {{0x8d840276,0x8934d55f,0x3c0401d5,0x00000000}},	//   _суэд, اعما, _шўнғ, --, 
   {{0xb6a4d560,0xf7442773,0xd97001c6,0x00000000}},	//   килл, теко, _өвгө, --, 
   {{0xd90c0244,0x993000e5,0x04240022,0x00000000}},	//   _هیا_, _مہات, ҳзыҟ, --, 
   {{0x6d88010e,0xa018023a,0xf9d40153,0x00000000}},	//   _aýaj, työl, _робэ, --, 
   {{0xe4300597,0x91a80014,0x00000000,0x00000000}},	//   لفيد, ہندے_, --, --, 
   {{0x260c0490,0x2d9c06af,0xb384009d,0x00000000}},	//   णीही_, étez_, тлол, --, 
   {{0x3674d561,0x6e2c0009,0xa778010f,0x00000000}},	//   _جهاز, xubb, _קרעפ, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x45d402f6,0x7e6001bf,0x842400d1,0x98ac0064}},	//   _соцс, ælpn, _مىنن, regė_, 
   {{0xafa001d5,0x00000000,0x00000000,0x00000000}},	//   рқоқ, --, --, --, 
   {{0x6da4d562,0xad584ed4,0x00000000,0x00000000}},	//   вива, мрах_, --, --, 
   {{0x3204d563,0xf064004e,0x00000000,0x00000000}},	//   mply_, _акип, --, --, 
   {{0x395c0083,0x6e2c0083,0x2b140108,0x320400a2}},	// [11ec0] ddws_, subb, вьер, lply_, 
   {{0x6e2cd564,0xaf0800c6,0x21f80055,0x00000000}},	//   pubb, _تقدم_, _hīha_, --, 
   {{0xa3c09129,0x69c04e2d,0x6e2c014f,0x81bc00ef}},	//   ंवत_, tooe, qubb, drēj, 
   {{0xda6c01d9,0x637c00bc,0x2adc00dc,0x00000000}},	//   تُم_, _záně, केषु_, --, 
   {{0xd1d402d3,0x6d4401e1,0xfbd001d3,0x3cd401d5}},	//   ረሽታ_, _ibka, شتے_, _бўрт, 
   {{0xa0980a7c,0x69c00076,0x81bc00de,0x00000000}},	//   וינט, sooe, grēj, --, 
   {{0xd61400f1,0xe938033a,0x00000000,0x00000000}},	//   نتيا_, _очај_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd9d00131,0x6d8800ee,0x32040175,0xa018005b}},	//   _ئەنگ, _aýak, eply_, työm, 
   {{0x76f401c0,0x57441fbe,0x00000000,0x00000000}},	//   _бяцх, _изум_, --, --, 
   {{0x66e41be7,0x81bc00e2,0x80a4000d,0x00000000}},	//   _рожа, kuēt, _चइहे, --, 
   {{0xa01801f4,0x00000000,0x00000000,0x00000000}},	//   syöm, --, --, --, 
   {{0x3204045a,0x00000000,0x00000000,0x00000000}},	//   aply_, --, --, --, 
   {{0x54780302,0x6d44d565,0xa26400d1,0xa3800037}},	//   _קטגו, _abka, _аъил, õõdu, 
   {{0x236c009f,0xd9e80037,0x00000000,0x00000000}},	//   _infj_, _जूझत_, --, --, 
   {{0x7e649a64,0xa01800e5,0x00000000,0x00000000}},	//   _vrhp, nyök, --, --, 
   {{0xfbd81b88,0x2fd80334,0x3cd400d8,0x00000000}},	// [11ed0] едај_, _fhpg_, ужас, --, 
   {{0xa018023a,0xdb1c00a2,0x00000000,0x00000000}},	//   hyök, _övüs, --, --, 
   {{0x6298002f,0xf9d4009d,0x00000000,0x00000000}},	//   nzto, гожэ, --, --, 
   {{0x3f800270,0x629801c4,0x9f5c010e,0x00000000}},	//   _hohu_, izto, _örân_, --, 
   {{0xa3c02413,0x3f80d566,0xdb200405,0x81bc00e2}},	//   ंवा_, _kohu_, _پوزی, trēj, 
   {{0xe7344990,0x00000000,0x00000000,0x00000000}},	//   геш_, --, --, --, 
   {{0x81bc005f,0x3f80d567,0x86980801,0x88f80014}},	//   grēk, _mohu_, ктът_, رى۪ر_, 
   {{0x7bc4d568,0x3f80d569,0x00000000,0x00000000}},	//   lohu, _lohu_, --, --, 
   {{0x6aa001e4,0xa01801f4,0x629800de,0x00000000}},	//   ĝofe, syöj, ezto, --, 
   {{0xd240036b,0x3f80d56a,0xe3b4d56b,0x88b401e0}},	//   амоқ, _nohu_, лбы_, _әҫәр_, 
   {{0x4254d56c,0x21f8002b,0xfcbc0092,0x36d40108}},	//   атят, _pīha_, ተሰጠ_, _сожр, 
   {{0x3204d56d,0x7bc4cf1c,0x74b8055f,0x80a40073}},	//   rply_, hohu, _пулс_, _चेहे, 
   {{0x7bc4d56e,0x343800c8,0x3f8002fb,0x64440240}},	//   kohu, _נײַע, _bohu_, çkit, 
   {{0x3204d56f,0xdc940092,0x13a40c62,0x3f800200}},	//   pply_, _ለመላክ_, _جنتی_, _cohu_, 
   {{0xa2c81971,0x62980034,0xdfcc007b,0x23b000f1}},	//   _सुप्, czto, سيف_, _دموس, 
   {{0x5ba400c2,0x7bc4000d,0x00000000,0x00000000}},	//   ҳкум_, eohu, --, --, 
   {{0x4ba439fb,0x00000000,0x00000000,0x00000000}},	// [11ee0] алаң, --, --, --, 
   {{0xa098008f,0xaab800d1,0xdd9801ec,0x00000000}},	//   _נייט, ىدار_, _ﻅﻠﹼﻪ_, --, 
   {{0xfe7405a2,0xa9580014,0x00000000,0x00000000}},	//   _күр_, ٹجار_, --, --, 
   {{0x6d440548,0x00000000,0x00000000,0x00000000}},	//   _ubka, --, --, --, 
   {{0xa2c80aff,0x2d800418,0x7bc4d570,0x18640b7b}},	//   _सुन्, _ioke_, bohu, лаци_, 
   {{0x2d800093,0x6bd80014,0x7bc40051,0xeb7400c0}},	//   _hoke_, _سوزس_, cohu, _сымэ, 
   {{0x2d80123c,0xa018023a,0x629800b5,0xa64402c9}},	//   _koke_, työk, xzto, اختن, 
   {{0x7df40006,0x2bbc543b,0x28141d0a,0x2d800e21}},	//   _sąsk, ्तका, _مورس, _joke_, 
   {{0x2d80d571,0x20e042e3,0x87e802dd,0x00000000}},	//   _moke_, _गणेश_, _алаң_, --, 
   {{0x2d80d572,0x279401d5,0x6d8800a2,0x6298002f}},	//   _loke_, _ёшар, _wýah, tzto, 
   {{0xd5acd573,0x2d800270,0x3f80d574,0x00000000}},	//   _کفن_, _ooke_, _rohu_, --, 
   {{0x3f80030d,0x7bc4d575,0x2d80d576,0x644400ac}},	//   _sohu_, zohu, _noke_, çkis, 
   {{0x6298a3e2,0x7bc40451,0x3f800418,0x10481985}},	//   szto, yohu, _pohu_, ляри_, 
   {{0x64a4035b,0x00000000,0x00000000,0x00000000}},	//   _иаҵа, --, --, --, 
   {{0x2d80d577,0x12f8011a,0x00000000,0x00000000}},	//   _boke_, _אהוב, --, --, 
   {{0x3f80d578,0x7bc45c46,0x3cb400a7,0x2d800f85}},	//   _wohu_, wohu, айбр, _coke_, 
   {{0x3f800325,0x7bc4d579,0x2d800c09,0x6e3c037e}},	// [11ef0] _tohu_, tohu, _doke_, _eqpb, 
   {{0xa018023a,0x39b00024,0x00000000,0x00000000}},	//   vyöh, mąsi_, --, --, 
   {{0x2cac03be,0x7bc4d57a,0x2d800263,0x25a40022}},	//   _əldə_, rohu, _foke_, _omol_, 
   {{0x2d800241,0x7bc4d57b,0xa018005b,0x25a4d57c}},	//   _goke_, sohu, työh, _nmol_, 
   {{0x7bc4d57d,0xb8fc228d,0x998401ed,0x6d880432}},	//   pohu, _डर_, énő_, _aýaw, 
   {{0x2d80d57e,0x25a40429,0xdb20c5a5,0x03b8009e}},	//   _zoke_, _amol_, _دوسی, ুগুণ, 
   {{0x7d0c01c4,0x98a401a6,0x2d80d57f,0x68f40153}},	//   obas, điđi_, _yoke_, žyda, 
   {{0x7c2cd580,0x7d0cd581,0xf3e800fe,0x00000000}},	//   orar, nbas, ওৱাৰ_, --, 
   {{0x7c2c0cad,0xe574d582,0xa2c85612,0x290c00ee}},	//   nrar, рзы_, _सुब्, ýlaş_, 
   {{0x25a4092e,0x7d0cd583,0x473404fb,0x7c2c899b}},	//   _emol_, hbas, _هرمز, irar, 
   {{0x324476d0,0x00000000,0x00000000,0x00000000}},	//   шенг, --, --, --, 
   {{0xb3741208,0x7df4012d,0x7d0c0166,0x00000000}},	//   ادکش, _gąsi, jbas, --, 
   {{0x2d80d584,0xe0dc067c,0x644c054e,0x0fc80116}},	//   _roke_, deòs_, ăbic, лқип_, 
   {{0x7c2cd585,0x2d80d586,0x7d0cd587,0x00000000}},	//   drar, _soke_, ebas, --, 
   {{0x2d80d588,0xa3c0d589,0x7c2c01c0,0x7d0c723e}},	//   _poke_, ंवर_, erar, fbas, 
   {{0x7d0cd58a,0x2a74136e,0xd0040117,0x00000000}},	//   gbas, یداح, _лоиқ, --, 
   {{0x6fd45b97,0x2bc800d1,0x20d002dd,0x2d800064}},	// [11f00] _вінц, влап_, _وقىس, _voke_, 
   {{0x2d80d58b,0x7d0c2252,0x79980175,0xae8800c0}},	//   _woke_, abas, ehww, _абоз_, 
   {{0x7c2cd58c,0x2d9cd58d,0x2d80d58e,0xcdc400c7}},	//   arar, ètes_, _toke_, _ганқ, 
   {{0x7c2cd58f,0x2d800270,0xee4800a2,0x2d94004e}},	//   brar, _uoke_, _ezýä_, _төгө_, 
   {{0x7c2cd590,0x6c7401c6,0x79c401d5,0x00000000}},	//   crar, _тунх, ёқуб_, --, 
   {{0x25a42b92,0x7df4d591,0xa50c25fe,0xaa040a0a}},	//   _smol_, _sąsi, सर्च_, _نظره, 
   {{0xe8f800a8,0x25a4045a,0x00000000,0x00000000}},	//   _алб_, _pmol_, --, --, 
   {{0x8574d592,0xda5800d9,0x00000000,0x00000000}},	//   слих, _בכלל, --, --, 
   {{0x6fc40490,0xe7380220,0x4ca80011,0x00000000}},	//   लकां, _үеұ_, _কুতু, --, 
   {{0x6718012c,0x7df40210,0x6368026b,0xe3b0d593}},	//   _नजिक_, _wąsi, триг_, ترع_, 
   {{0xadf005f9,0xd374d594,0x7d0cd595,0x9af427af}},	//   _आंगन_, рчы_, ybas, יזיק_, 
   {{0xa5084c7f,0x7c2cd596,0x66080e78,0x00000000}},	//   _реда_, yrar, mpfk, --, 
   {{0x6f000276,0xdcec0f40,0x7d0c022e,0x00000000}},	//   _şoca, ādīt, vbas, --, 
   {{0x7c2c0262,0x5330d597,0x161001f9,0x94000244}},	//   vrar, _дешт, णीवर_, _بووه, 
   {{0x7c2c0784,0xfb8800d1,0xd24c50a3,0x13a402f2}},	//   wrar, қрақ_, _ينه_, _ڕۆیی_, 
   {{0x527806a9,0x7d0c00b5,0x00000000,0x00000000}},	//   _ינוא, ubas, --, --, 
   {{0x7d0cd598,0x7c2cd599,0xa2c8a589,0x5ce400d6}},	// [11f10] rbas, urar, _सुत्, рюва, 
   {{0x7c2cd59a,0xd9bc1d8a,0x2b4875d3,0x2d9c0066}},	//   rrar, एक्ट, _cbbc_, èter_, 
   {{0x7d0cd59b,0x2bbcd59c,0x20080010,0x00000000}},	//   pbas, ्तजा, lpci_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc5f804fe,0xee9403e6,0x2a68045a,0x6aa001e4}},	//   _auē_, _ندێک, _erbb_, ĝofa, 
   {{0x9a84d59d,0x7f54036e,0x00000000,0x00000000}},	//   _кубл, nezq, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3a20010a,0xa2c80be7,0x7c280fac,0xe7a4025c}},	//   mshp_, _सुध्, _åers, ġeġġ, 
   {{0x98bc04fe,0x49903321,0x2bbc1b51,0x3ce4012d}},	//   _mauī_, _زیور, ्तचा, _कणों_, 
   {{0x224c05b1,0x962400e5,0x00000000,0x00000000}},	//   _bpfk_, _نقطے_, --, --, 
   {{0xa2c80574,0xe1f40139,0x00000000,0x00000000}},	//   _सुद्, йгэ_, --, --, 
   {{0xa0640588,0x77600067,0xe2941188,0x00000000}},	//   әара_, _halx, саю_, --, 
   {{0x54e40137,0xafe4d59e,0x44ac01e1,0x00000000}},	//   _ئساق, йомл, _tùsẹ_, --, 
   {{0xafe43d6c,0x308402d3,0x00000000,0x00000000}},	//   согл, _ዝኸፍአ_, --, --, 
   {{0x2d94d59f,0xb8c80135,0x77603a73,0x716801c6}},	//   брас, _བཟ_, _malx, _байг_, 
   {{0x2b48020b,0xdcec06b9,0x6d8803b2,0x6aa803b9}},	//   _sbbc_, _amcı, _nýat, _ülfə, 
   {{0xdd8c00c6,0xac08084c,0x4ca800cc,0x00000000}},	// [11f20] روك_, унза_, _কঁহু, --, 
   {{0x2a68004e,0x6d88010b,0xc91008e9,0xa018005b}},	//   _prbb_, _aýat, ार्म_, työv, 
   {{0xdb0400dd,0x433001f3,0xa9285eb4,0xa96800f3}},	//   ámár, _ተጠባባ, гіле_, лижа_, 
   {{0x0b5863eb,0x87140154,0xa2c80b98,0x0d941bf4}},	//   ырғы_, _সাইফ_, _सँस्, _بیرح, 
   {{0x53c4098b,0x6d54d5a0,0x776001a9,0xa018005b}},	//   रकाश, meya, _balx, syöv, 
   {{0x6d54d5a1,0xca74052f,0xb8640ed8,0x00000000}},	//   leya, _һуғы, غانو, --, 
   {{0x3a20030d,0x776001d9,0xe66401a9,0x00000000}},	//   cshp_, _dalx, стло, --, 
   {{0xd940d5a2,0x76c40131,0xe5c40063,0x6d54cbea}},	//   _неси, ڭغۇل, љско, neya, 
   {{0x54400150,0x77600009,0x03f80063,0x1864283c}},	//   كنيك, _falx, јној_, _лати_, 
   {{0x5c5800c8,0x776006be,0x13f0030d,0x04f80154}},	//   נדיק, _galx, язья, ঘরের_, 
   {{0x6d54d5a3,0x5b78010f,0x3f8401a8,0xa01801f4}},	//   keya, אריא, ölum_, hyöt, 
   {{0x7df40006,0x73d8593d,0x00000000,0x00000000}},	//   _mąst, лдөр_, --, --, 
   {{0xe4d4d5a4,0x6d54d5a5,0x7df40006,0x23e40845}},	//   _اتاب, deya, _ląst, _лікв, 
   {{0x6560d5a6,0x2d9c01a4,0x3a200175,0x776006be}},	//   _haoh, ëten_, yshp_, _xalx, 
   {{0x6560166a,0x6d54007f,0xe3b000ec,0x81bc00de}},	//   _kaoh, feya, _ورڻ_, frēt, 
   {{0x6d5400f2,0x81bc00e2,0x4034ad00,0x00000000}},	//   geya, grēt, _деис, --, 
   {{0x4dd400c6,0xd1b804d3,0x6560d5a7,0x6d880432}},	// [11f30] ستفس, _داوا_, _maoh, _aýas, 
   {{0x2d900083,0x4ca8009e,0x26d00213,0x6560285e}},	//   akye_, _কুহু, əyov_, _laoh, 
   {{0x6d54d5a8,0xba542d4b,0x50b800f2,0x98c400d1}},	//   beya, تناع, _ندید_, ڭغان, 
   {{0x7760679e,0x6d54d5a9,0x00000000,0x00000000}},	//   _salx, ceya, --, --, 
   {{0xc97400c6,0x0f3c0023,0x00000000,0x00000000}},	//   ثالث, _ይምህረ, --, --, 
   {{0x9f5c0209,0x776000ac,0x00000000,0x00000000}},	//   _örän_, _qalx, --, --, 
   {{0x644001d5,0x66e0d5aa,0x7760022e,0x65604bca}},	//   _aqoi, моша, _valx, _baoh, 
   {{0x7760d5ab,0x65600051,0x6fd0005c,0x00000000}},	//   _walx, _caoh, ræci, --, 
   {{0x6560a8cf,0x2ed4d5ac,0x77600009,0xd8b80066}},	//   _daoh, _धर्त, _talx, _صدرا_, 
   {{0xb4e82cbb,0x00000000,0x00000000,0x00000000}},	//   _मणी_, --, --, --, 
   {{0x80d003f4,0x6d54d5ad,0x65600109,0xc7b4013f}},	//   সেম্, yeya, _faoh, ɑɑ_, 
   {{0x29cc09a5,0x65603495,0x6d54058a,0x00000000}},	//   lýar_, _gaoh, xeya, --, 
   {{0x6d54d5ae,0x394c036e,0x6d880432,0xe3ac30c2}},	//   veya, _mbes_, _oýar, _жб_, 
   {{0x29cc0209,0xa2c81d03,0x65bc3e16,0x6d54d5af}},	//   nýar_, _सुव्, mīha, weya, 
   {{0x6d54d5b0,0x6560d5b1,0x394c05b1,0x83644dc1}},	//   teya, _yaoh, _obes_, _ردول, 
   {{0xa018112c,0x7df40153,0x242c0092,0xdee008ca}},	//   työt, _rąst, _በነፃነ, фоси, 
   {{0xae1805f9,0x6d8806ea,0x29cc00ee,0x2d90d5b2}},	// [11f40] _फौरन_, _býar, kýar_, rkye_, 
   {{0xeab0911b,0x6d54d5b3,0x3d640014,0xab2800c0}},	//   وعا_, seya, _ہُپٲ, рожа_, 
   {{0xe8f8d5b4,0x29cc0209,0x386c0055,0xa018005b}},	//   але_, dýar_, _arer_, syöt, 
   {{0x6d54d5b5,0x386c1f53,0x65bc00b0,0xf1c8085c}},	//   qeya, _brer_, kīha, रविन, 
   {{0x386cd5b6,0x77900517,0xebe400db,0x00000000}},	//   _crer_, کیلا, _момп, --, 
   {{0x65600810,0x394c0036,0x2628009b,0x29cc0432}},	//   _saoh, _ebes_, ацио_, gýar_, 
   {{0x386cd5b7,0x656002b1,0xf1c809fa,0x6d880432}},	//   _erer_, _paoh, रवान, _uýas, 
   {{0x386c2005,0xa2c81562,0x00000000,0x00000000}},	//   _frer_, _सुष्, --, --, 
   {{0x6560d481,0x29cc03b2,0xe738119e,0x00000000}},	//   _vaoh, býar_, _вез_, --, 
   {{0x66e40408,0x00000000,0x00000000,0x00000000}},	//   _доза, --, --, --, 
   {{0xa2c807d0,0x6560d5b8,0xd5ac02dd,0x7d0001d3}},	//   _सुश्, _taoh, _жс_, _járó, 
   {{0x9630242f,0x81bc00b0,0x70a4002b,0x00000000}},	//   _ініц, erēr, _śakṣ, --, 
   {{0xa2c8000b,0x506405f5,0x48b800bd,0x7d0001e1}},	//   _सुर्, мтра, _জরুর, _láró, 
   {{0x4424d5b9,0x00000000,0x00000000,0x00000000}},	//   msm_, --, --, --, 
   {{0xdda80a27,0xa018112c,0x1ee42418,0x260c0073}},	//   атал_, työs, زوری_, णीची_, 
   {{0x6aa001e4,0x3ec000b8,0x5bd000cd,0x00000000}},	//   ĝofl, _ārtā_, थत्व, --, 
   {{0x1b1c015b,0xdfd802e8,0xa0180108,0x00000000}},	// [11f50] _পাবে_, _вън_, ryös, --, 
   {{0x63b82155,0x3fd8084c,0xe0dc02e2,0xdfa842ed}},	//   nntn, _ымпэ_, nfòm_, _خطبه_, 
   {{0x1a7000aa,0x450000fe,0x00000000,0x00000000}},	//   بپاڼ, _এজনক_, --, --, 
   {{0x386c166e,0xb6f80131,0xbb840633,0x44240139}},	//   _prer_, ڭىغا_, _کلسي, ksm_, 
   {{0x7d1c0a40,0x29cc00ee,0xf8b075f5,0x6f18022e}},	//   _iess, týar_, رکر_, аtch, 
   {{0x7d1cd5ba,0xdb20015e,0x6dbc0306,0x386c036e}},	//   _hess, _زوری, nďan, _vrer_, 
   {{0x7d1c22a9,0x29cc09a5,0xa2c87039,0x98bc01a6}},	//   _kess, rýar_, _सुल्, _obuć_, 
   {{0x386cd5bb,0x65bc00b0,0x2de400d1,0x63b80139}},	//   _trer_, tīha, _ﺋﺎﻟﻤ, entn, 
   {{0x7d1c1b44,0x386c04cc,0x7d0001d3,0xb0a80a8a}},	//   _mess, _urer_, _záró, _चेंग, 
   {{0x79889045,0xc86401b9,0x7d0001e1,0x4ad001f9}},	//   _hoew, _ўтти, _yáró, _तुडव, 
   {{0x9ad001f2,0x442401a6,0xf8b80055,0x7d1cc319}},	//   _dịgo, asm_, _deũe_, _oess, 
   {{0x7d1c3173,0x8504d5bc,0x65bc00b0,0xa01801f4}},	//   _ness, _قومن, pīha, vyör, 
   {{0x4424070d,0x7988d5bd,0xe44c3633,0x290806be}},	//   csm_, _moew, _яж_, _əba_, 
   {{0x798804ce,0x7d1c030a,0xe4e401c6,0xa0180108}},	//   _loew, _aess, _эсхү, työr, 
   {{0x7d1cd5be,0x2d94a1f9,0xdee028eb,0x82340133}},	//   _bess, прас, еори, _قووڵ, 
   {{0xdcec00ef,0x61c401f9,0x00000000,0x00000000}},	//   _nocē, ळकृष, --, --, 
   {{0xeb9835f6,0x21f80374,0x61ec00cf,0x7d0001e7}},	// [11f60] биа_, _rīhi_, ïble, _sáró, 
   {{0xa018049b,0x7d1c0a55,0x00000000,0x00000000}},	//   pyör, _eess, --, --, 
   {{0x21f802b5,0x7988d5bf,0x6f1c03ac,0x66e001e1}},	//   _pīhi_, _boew, _iepc, _míkí, 
   {{0xe9d004a9,0x7d1cd5c0,0x44249af9,0x6f1c0205}},	//   رغا_, _gess, ysm_, _hepc, 
   {{0x7988020c,0x22a07cf3,0xdcecd5c1,0x21f80055}},	//   _doew, _kéké_, _docē, _vīhi_, 
   {{0x7d1c23e8,0x00000000,0x00000000,0x00000000}},	//   _zess, --, --, --, 
   {{0x7d1cd5c2,0x21f802b1,0x2b580175,0x6f1c01f4}},	//   _yess, _tīhi_, mepc_, _mepc, 
   {{0x798805e4,0x4424d5c3,0x00000000,0x00000000}},	//   _goew, tsm_, --, --, 
   {{0x1b1c04c5,0xe0dc033b,0x18a0005b,0x98a003f6}},	//   _পাতে_, tfòm_, _затм, _зите, 
   {{0x6f1cd5c4,0x22a000e8,0x442400f1,0x75f40419}},	//   _nepc, _néké_, rsm_, _všza, 
   {{0xaabc694b,0x63b80112,0x26dc01a9,0xc4440214}},	//   ्थिक, rntn, _uzto_, سیژن_, 
   {{0xd5f8011a,0x00000000,0x00000000,0x00000000}},	//   _הפאר, --, --, --, 
   {{0x6f1c014f,0x2904005a,0x7a040064,0x00000000}},	//   _bepc, icoa_, _mėta, --, 
   {{0x7d1cd5c5,0x81c4009e,0x7a040024,0xaabc0b98}},	//   _sess, ৌষধ_, _lėta, ्थाक, 
   {{0x7d1c0cfc,0xbdd4005b,0xd24c07d5,0xdef802dd}},	//   _pess, довщ, _яц_, _қып_, 
   {{0xb3080135,0x6f1c90e7,0x9f500129,0xdcec00ef}},	//   _གཅོང_, _eepc, _mixé_, _ancā, 
   {{0x22a00de2,0x7d1cd5c6,0x66e00241,0x00000000}},	// [11f70] _féké_, _vess, _yíkí, --, 
   {{0x7d1cd5c7,0x7e60037e,0x7988d5bf,0x382c0023}},	//   _wess, ælps, _soew, _ብሰማእ, 
   {{0x91440014,0x79a4010b,0xbe2401a9,0x00000000}},	//   _غنیٖ, үрҗе, _ўчоқ, --, 
   {{0x6f1c171e,0x7d1c0857,0x00000000,0x00000000}},	//   _zepc, _uess, --, --, 
   {{0x6f1c014f,0x20d000bc,0x7a040064,0x0afc00fe}},	//   _yepc, _धुमध, _dėta, ইৰেল_, 
   {{0x7988020c,0xdb5800f7,0x00000000,0x00000000}},	//   _woew, _уюм_, --, --, 
   {{0x7988d5c8,0xfbd8547d,0xc7c802d5,0x872400cf}},	//   _toew, _बीएम, чыце_, رعوم, 
   {{0x75d4d5c9,0xa77000fd,0x0e9c010f,0x66e00241}},	//   بيعا, еләч, משול, _síkí, 
   {{0x25a80214,0x79400092,0x73e44538,0xef1c0037}},	//   تضوی_, _የምታስ, моиз, _बजलऽ_, 
   {{0x21f806c8,0x5f0c0882,0x9f505725,0xd3440345}},	//   _līhu_, तुम्_, _fixé_, سیبه_, 
   {{0x95c81575,0x22a001e1,0x6f1c00e5,0x00000000}},	//   _луда_, _réké_, _repc, --, 
   {{0x6f1cd5ca,0x22a00c6a,0xa018005b,0x31a0012d}},	//   _sepc, _séké_, työp, _mózg_, 
   {{0x21a0034b,0xbf080073,0xa1600022,0x00000000}},	//   тиям, वडून_, тҭыҵ, --, 
   {{0x29040bf2,0x64a01fbe,0xa0180108,0x00000000}},	//   zcoa_, _јаша, ryöp, --, 
   {{0xa018023a,0x926800db,0x63500798,0x00000000}},	//   syöp, _ырда_, _рвју, --, 
   {{0x6014063f,0x22a001e1,0x00000000,0x00000000}},	//   ụmag, _wéké_, --, --, 
   {{0x6f1c037e,0xab6402d5,0x5f0c00cd,0x00000000}},	// [11f80] _tepc, мвал, _त्व्_, --, 
   {{0x09b806e3,0x00000000,0x00000000,0x00000000}},	//   ेक्य, --, --, --, 
   {{0x6da4005e,0xada40661,0xc0580092,0x00000000}},	//   _жина, _жанл, ያደርግ, --, 
   {{0x6f00054e,0xbe8001b9,0xec7800d8,0x00000000}},	//   _şoch, _ёқти, _дпм_, --, 
   {{0x2b58004e,0x00000000,0x00000000,0x00000000}},	//   pepc_, --, --, --, 
   {{0x2904d5cb,0x65bc00b0,0xbe4800f2,0x0c24030d}},	//   scoa_, tīho, _بشیم_, ăмĕн, 
   {{0xda608b30,0x45d4042f,0x7a0400b0,0x99d01e4a}},	//   _иври, нокс, _tėta, رقۇت, 
   {{0xb3080135,0x1ae0022e,0x00000000,0x00000000}},	//   _གཅུང_, _росм, --, --, 
   {{0xdcec0356,0x00000000,0x00000000,0x00000000}},	//   _incă, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x43940166,0xb744009f,0x00000000,0x00000000}},	//   _җайс, _سئلو, --, --, 
   {{0x14ac0490,0x4034d5cc,0xd5f40131,0x92900006}},	//   _जेवण, немс, _قىلش_, таюц, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc0c404a9,0x00000000,0x00000000,0x00000000}},	//   _җәми, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbf10008e,0x00000000,0x00000000,0x00000000}},	//   _әүвә, --, --, --, 
   {{0x80ac0154,0xdef849b4,0x450000fe,0xbb7400ea}},	// [11f90] _টুর্, _мын_, _এজাক_, нгај, 
   {{0x3f1400a7,0x1b1c00fe,0x00000000,0x00000000}},	//   _ядос, _পাহে_, --, --, 
   {{0x2ec00032,0x8f440022,0x00000000,0x00000000}},	//   _бөтм, _рхыд, --, --, 
   {{0x7e640113,0xd2b4011a,0x00000000,0x00000000}},	//   _ishp, ולבת_, --, --, 
   {{0xd0540198,0x00000000,0x00000000,0x00000000}},	//   ɓaɓa, --, --, --, 
   {{0xf7700597,0xbd3401ec,0x06b00154,0x00000000}},	//   طات_, _تىڭع, _ছড়ি, --, 
   {{0xb90404c5,0xf65012fd,0x00000000,0x00000000}},	//   _নল_, ائت_, --, --, 
   {{0xb464010b,0x18b001ee,0x6ed4000d,0xdc0001ef}},	//   екил, _иҙер, _मुफु, hčíh, 
   {{0x7f44022e,0x67700133,0x31a001ef,0x00000000}},	//   _ochq, _ڕێوڕ, _józe_, --, 
   {{0x437402bf,0x7e6493c1,0xd774075e,0xdc0001ef}},	//   вуют, _oshp, _تارع, jčíh, 
   {{0xb344315a,0xdc000118,0x7e640200,0x7a040153}},	//   _acçã, dčíh, _nshp, _mėto, 
   {{0x4658007b,0x7a040064,0x00000000,0x00000000}},	//   _تؤكد_, _lėto, --, --, 
   {{0x7e64d5cd,0x8364036b,0xddc80356,0xdee001d5}},	//   _ashp, ردیل, _şişc, ғоти, 
   {{0xa2c8d5ce,0x81bc005f,0x03c40139,0xc2f40154}},	//   _सुक्, nsēj, _үсәм, ছড়ি_, 
   {{0xdca0023b,0x00000000,0x00000000,0x00000000}},	//   ҳати, --, --, --, 
   {{0x1838001f,0xac080120,0x00000000,0x00000000}},	//   _የግንዛ, знаа_, --, --, 
   {{0x7e64022e,0x395c017a,0x6cd4036b,0x81bc00e2}},	// [11fa0] _eshp, dews_, رقطا, ksēj, 
   {{0xf40003f4,0xaabc012c,0x00000000,0x00000000}},	//   _এবার_, ्थलक, --, --, 
   {{0x1b1c09bd,0x00000000,0x00000000,0x00000000}},	//   _পাশে_, --, --, --, 
   {{0x6da4d5cf,0xa8c4010b,0x33240327,0xada401c4}},	//   _чима, нйед, halx_, _чамл, 
   {{0x1b1c03f4,0x6d4402d0,0x00000000,0x00000000}},	//   _পারে_, _icka, --, --, 
   {{0xd7ec00c6,0xe66410f3,0x7e640334,0xaa4452d1}},	//   مكن_, етио, _yshp, _пегл, 
   {{0x1ae007d6,0xd2cc05b3,0x6ed400dc,0x00000000}},	//   _борм, _सुलझ, _मुमु, --, 
   {{0xa2c8d5d0,0x00000000,0x00000000,0x00000000}},	//   _सुग्, --, --, --, 
   {{0xe738d5d1,0xb8644cec,0x39e401d5,0x75800066}},	//   _неа_, _لالو, _рўёб, شیوم, 
   {{0x6b8cd5d2,0x42740212,0x00000000,0x00000000}},	//   _jobg, вгос, --, --, 
   {{0x6d9c0a28,0x6b8cd5d3,0x6d44035a,0xd7ec007b}},	//   ṣaya, _mobg, _ocka, _اكل_, 
   {{0x6b8cd5d4,0x00000000,0x00000000,0x00000000}},	//   _lobg, --, --, --, 
   {{0x557404ac,0x33240083,0x60d800e2,0x5280113e}},	//   _רעדן_, balx_, ļumo, _ەلىك, 
   {{0x6d44127b,0x00000000,0x00000000,0x00000000}},	//   _acka, --, --, --, 
   {{0x1b1c0183,0xdd98d5d5,0x00000000,0x00000000}},	//   _পালে_, пша_, --, --, 
   {{0xcdd8026a,0xfbd800cd,0x00000000,0x00000000}},	//   ењу_, _बीजम, --, --, 
   {{0x0dc80107,0xfcc40116,0x00000000,0x00000000}},	// [11fb0] хури_, тәнм, --, --, 
   {{0x7f44d5d6,0x6d4426bd,0x799813bb,0x61ec0142}},	//   _uchq, _ecka, wkww, lmcl, 
   {{0x29100342,0x7e64d5d7,0x61ec035a,0x00000000}},	//   ıyan_, _ushp, omcl, --, 
   {{0xc98451f2,0x49980212,0x61ec03ac,0xf8b8d5d8}},	//   лучи, нтія_, nmcl, وهاب_, 
   {{0xf7442bb7,0x0904d5d9,0x395c3c3f,0x00000000}},	//   вело, упін, rews_, --, 
   {{0xfbd81b90,0x97a40276,0xec3400d9,0x00000000}},	//   _बीचम, эрел, _באשר_, --, 
   {{0x0cc42158,0x19a8d5da,0x81bc00e2,0x00000000}},	//   ্ধৃত, _етап_, rsēj, --, 
   {{0x4ca802f5,0xc6540acb,0x6b8c00ef,0x00000000}},	//   _কুটু, افيک, _zobg, --, 
   {{0x9f500372,0x6b8c01b9,0x33240356,0x00000000}},	//   _així_, _yobg, talx_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3940001f,0x25f8033f,0xc32c6911,0x00000000}},	//   _የምዕራ, _ऊंची_, سەي_, --, 
   {{0xe2941fdf,0x3324031c,0xc0ec0023,0x00000000}},	//   таю_, salx_, _ቀሚሽ_, --, 
   {{0x69d80022,0xfbd007b6,0x00000000,0x00000000}},	//   _êtee, तकाम, --, --, 
   {{0x7fd40046,0xafe4033a,0xa024007c,0xb600032e}},	//   гісі, тогл, _sköö, _þáse, 
   {{0x6d44089c,0x6b8c01c7,0x7168004e,0x00000000}},	//   _pcka, _robg, _жайг_, --, 
   {{0xa2c80490,0x6b8c0327,0xddc001d5,0x00000000}},	//   _सुट्, _sobg, абси, --, 
   {{0x92f005f5,0xd9d402f5,0xab280107,0x6f00054e}},	// [11fc0] _шүүх, তগাম, доза_, _şocu, 
   {{0xaab8d5db,0x6af4431a,0x00000000,0x00000000}},	//   ودار_, نثار, --, --, 
   {{0x6a8406bb,0xfe740116,0x00000000,0x00000000}},	//   ължа, _йүр_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd940d5dc,0x998001d9,0xa878007b,0x00000000}},	//   речи, شلوو, بحار_, --, 
   {{0xb9e4113e,0x00000000,0x00000000,0x00000000}},	//   _ەسكى, --, --, --, 
   {{0xcd980023,0xe5c4d5dd,0x040801e1,0x00000000}},	//   _ወለድና_, ксио, _ìjẹj, --, 
   {{0xd5b4d5de,0x6d880432,0xdcac004b,0xb674004b}},	//   ксы_, _aýaz, _اډې_, اخوږ, 
   {{0x80e013b4,0x65bc0374,0x368801c0,0xe0dc007f}},	//   _नरें, nīhi, дсөн_, nfòt_, 
   {{0x69c000f3,0x00000000,0x00000000,0x00000000}},	//   lnoe, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x80d01d4c,0x69c00368,0x65bc00b0,0x944001d5}},	//   _সৃষ্, nnoe, kīhi, دپین, 
   {{0x753c01d3,0x69c05184,0x00000000,0x00000000}},	//   ósze, inoe, --, --, 
   {{0x4fc4d5df,0xd36c06f6,0x9f5c03e0,0x00000000}},	//   асса, _وهن_, _örün_, --, 
   {{0x93f80bd9,0x75e401ed,0x69c0d452,0xfc3801e4}},	//   _קלוי, lóza, knoe, _ŭŭ_, 
   {{0x7ae00268,0xbda40e56,0x00000000,0x00000000}},	//   _ùlti, اڭدو, --, --, 
   {{0x3b54d5e0,0x00000000,0x00000000,0x00000000}},	// [11fd0] лкар, --, --, --, 
   {{0xc5b800eb,0x00000000,0x00000000,0x00000000}},	//   ঁকিপ, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x57c80490,0x61fc06af,0xdcec00de,0x69c0d5e1}},	//   िव्ह, _éplu, _jocī, gnoe, 
   {{0x0c841df9,0x7d0c975e,0xa2c800c5,0xdcec00de}},	//   _кырм, mcas, _सुघ्, _mocī, 
   {{0xb6040300,0x7d0cd5e2,0xdcec005f,0x69c0005a}},	//   hláš, lcas, _locī, anoe, 
   {{0x7d0c011c,0x6b6800ef,0xa3e4095f,0x993000e5}},	//   ocas, _dīgļ, पतन_, _نہات, 
   {{0x4efc025f,0xe0dc007f,0x7c2c01ab,0x69c00142}},	//   ולוג, nfòs_, osar, cnoe, 
   {{0xd3a004a9,0xa8540075,0xe430007b,0x0424035b}},	//   илиқ, _йетә, مفيد, азыҟ, 
   {{0x7c2c0af5,0x7d0cb64b,0xc5f80171,0x00000000}},	//   isar, hcas, _apēd_, --, 
   {{0x7d0c5c00,0x6b5803b2,0x3210045f,0xd7dc07f7}},	//   kcas, _høgæ, ëzy_, _पीएच, 
   {{0x7c2cd5e3,0x8424075e,0x00000000,0x00000000}},	//   ksar, _چىنن, --, --, 
   {{0x7c2cd5e4,0x7d0cd5e5,0x7528030a,0x942000d1}},	//   jsar, dcas, maez, _ئوتۇ, 
   {{0x7c2c3899,0x7528c6a5,0x644c0311,0x31a00306}},	//   dsar, laez, ăbit, _dóza_, 
   {{0x69c0d5e6,0x6da41e28,0xb644037e,0xfe7000e3}},	//   ynoe, гива, _ｉｆ_, يدِ_, 
   {{0x752801c4,0x7d0c0076,0x5d640276,0x7c2c007c}},	//   naez, gcas, лисм_, fsar, 
   {{0x9f5007de,0x6abc00dc,0x0fe82c11,0x00000000}},	// [11fe0] _fixà_, ्थ्र, _илиқ_, --, 
   {{0x7d0cd5e7,0x2bb800c6,0x75280165,0x00000000}},	//   acas, راءة_, haez, --, 
   {{0x7c2c32ff,0x7528d5e8,0x6398010f,0x00000000}},	//   asar, kaez, עסענ, --, 
   {{0xe8c8d5e9,0x2d9c005f,0x69241887,0x7c2cd5ea}},	//   нгел_, ītes_, умда, bsar, 
   {{0x64e009d9,0x69c00b4f,0x7528009d,0x7c2c01d3}},	//   _परेश, rnoe, daez, csar, 
   {{0x69c01af3,0xad243e52,0x2fd8007c,0x52cc000d}},	//   snoe, _جىڭى, _jkpg_, _सु्स, 
   {{0x49946112,0x3af40108,0x00000000,0x00000000}},	//   _پیشر, _вятс, --, --, 
   {{0x2fd8007c,0x00000000,0x00000000,0x00000000}},	//   _lkpg_, --, --, --, 
   {{0xd494084c,0xb60402f0,0x6e2c0327,0xa684013d}},	//   грэ_, vláš, hsbb, _әлед, 
   {{0x629c02b1,0x194c01f3,0xc69000f1,0x00000000}},	//   _üpok, _መዝሙሮ, _وېش_, --, 
   {{0x7c2c0029,0x66e400c9,0x75e402fb,0x5b54010f}},	//   zsar, _сожа, mózn, נשטן_, 
   {{0x7c2cd5eb,0x2a68070d,0x81d4d5ec,0x7ae0072b}},	//   ysar, _msbb_, ромх, _ølte, 
   {{0xd5ac03e6,0xd5b8010f,0x00000000,0x00000000}},	//   _عفه_, _אזאל, --, --, 
   {{0x6728d5ed,0x6ed4d5ee,0x7d0cd5ef,0x75e40306}},	//   nafj, _मुहु, wcas, nózn, 
   {{0x2a68070d,0x7c2cd5f0,0x539802e4,0xb6041155}},	//   _nsbb_, wsar, _איגו, pláš, 
   {{0x7c2cd5f1,0x63b80300,0x3eac01e4,0x61b00137}},	//   tsar, litn, ŝeto_, _چەگا, 
   {{0x7c2c0eda,0x26dc020b,0x2128d5f2,0x6298d5f3}},	// [11ff0] usar, _lyto_, mach_, lyto, 
   {{0x2128d5f4,0x7c2cd5f5,0x7d0c102c,0x63b80ebd}},	//   lach_, rsar, scas, nitn, 
   {{0x7c2c9a36,0xf1c82432,0x3f800003,0x75280399}},	//   ssar, रवचन, _inhu_, yaez, 
   {{0x2128d5f6,0x7c2cd5f7,0x63b80efc,0x3dd8d5f8}},	//   nach_, psar, hitn, _uksw_, 
   {{0x39480029,0x63b88a67,0x752805c7,0x7a0400c0}},	//   ļas_, kitn, vaez, _mėti, 
   {{0x2128d5f9,0xb6584a77,0xe734d5fa,0x629802d5}},	//   hach_, вших_, аеш_, kyto, 
   {{0x21287726,0xb6a43b26,0x69c84afb,0x752801c6}},	//   kach_, рийл, éfec, taez, 
   {{0x6298d5fb,0x212880d3,0x61fc022e,0x668001b9}},	//   dyto, jach_, _niql, تیمل, 
   {{0x2128d5fc,0x3868d5fd,0x3f80013f,0x7bc401f5}},	//   dach_, çard_, _onhu_, onhu, 
   {{0x63b8d5fe,0x13a4caf7,0x7bc403cd,0x752870b5}},	//   gitn, اندی_, nnhu, saez, 
   {{0x2128d5ff,0x61fcd600,0x629801d3,0x00000000}},	//   fach_, _biql, gyto, --, 
   {{0x3f80d601,0x644c054e,0x7df40064,0xe1f40166}},	//   _anhu_, ăbir, _tąsy, игэ_, 
   {{0xc5643cc6,0x7a0400c0,0xad6400f2,0x75e41aa9}},	//   _دُني, _dėti, یاره, lózo, 
   {{0x6298d602,0x63b82e31,0x7bc401a4,0x28980a7c}},	//   byto, citn, jnhu, דישא, 
   {{0x6298d603,0x628c0158,0x324400fb,0xadb40395}},	//   cyto, øbot, _тейг, ащащ, 
   {{0x2128d604,0x7bc4371a,0xf8a40214,0x6cc4d605}},	//   cach_, enhu, _فک_, айба, 
  
   {{0x61fc04cc,0xac840510,0x2b48007f,0xe0dc0ba1}},	// [12000] _èpla, шгал, _pcbc_, sfòr_, 
   {{0xeaf87092,0xa098010f,0x2078008f,0x75e402f0}},	//   نرات_, _סייט, _יאפא, kózo, 
   {{0x61fc014f,0x64e00b6d,0x27fcd606,0x00000000}},	//   _yiql, _पर्श, _ritn_, --, 
   {{0xeae40574,0x26dc0006,0xfc3000f1,0x00000000}},	//   _करीत_, _ryto_, تحې_, --, 
   {{0x63b8d607,0x2d800198,0x6d54009f,0x6298033f}},	//   yitn, _inke_, mfya, zyto, 
   {{0x81bc0029,0x2128489d,0x57b00212,0x97c002e8}},	//   lsēt, zach_, обіт, ойче, 
   {{0x6728d608,0x75e41155,0x212803cb,0xa4780023}},	//   rafj, rózn, yach_, ካይድዎ_, 
   {{0x6d54d609,0x63b8d60a,0xd94009a5,0x28141af5}},	//   nfya, witn, _меси, _نورس, 
   {{0x58fc1b4b,0x63b8d60b,0x98a0035b,0x2128d60c}},	//   _ཞུགས_, titn, _дите, vach_, 
   {{0x3868044e,0x26dc0316,0x6298d60d,0x21280034}},	//   çare_, _tyto_, tyto, wach_, 
   {{0x6ed49845,0x2128d60e,0x63b8d60f,0x2d80d059}},	//   _मुलु, tach_, ritn, _onke_, 
   {{0x6298d610,0x61fc5fda,0x1b040154,0x21280142}},	//   ryto, _qiql, _লড়াই_, uach_, 
   {{0x2128d611,0x6298cc62,0x7bc4017a,0x61fc06be}},	//   rach_, syto, ynhu, _viql, 
   {{0x2128d612,0x2d80d613,0xd83c0e96,0x25a40270}},	//   sach_, _anke_, _účet_, _hlol_, 
   {{0x2128d614,0x61fc016d,0x7a040153,0x00000000}},	//   pach_, _tiql, _tėti, --, 
   {{0xaad81d15,0x5634008f,0x2128014f,0x00000000}},	//   _भड़क, יאלע_, qach_, --, 
   {{0xbfc80220,0xbb58009d,0x7bc40051,0x00000000}},	// [12010] _مادە_, лаах_, tnhu, --, 
   {{0xa3e41715,0x3f800433,0x6d540009,0x00000000}},	//   पति_, _unhu_, afya, --, 
   {{0x25a4d615,0x5a44741d,0xbdd4234c,0x7a3800d8}},	//   _olol_, рэза, _гонщ, упер_, 
   {{0xa2740023,0x00000000,0x00000000,0x00000000}},	//   ክልናን_, --, --, --, 
   {{0xa3e400e1,0x482467d1,0xa3c4482a,0x00000000}},	//   पता_, قىنق, ईचा_, --, 
   {{0xb6a4d616,0x00000000,0x00000000,0x00000000}},	//   йилл, --, --, --, 
   {{0xab600220,0x00000000,0x00000000,0x00000000}},	//   _ءۇمى, --, --, --, 
   {{0x1dc40a94,0x75e402f0,0x1be80037,0x00000000}},	//   रचित, rózo, _जीतल_, --, 
   {{0x394cd617,0xd3940032,0x6840001f,0x2450007b}},	//   _ices_, ғәҙә_, _የፍልስ, كنيس, 
   {{0x81e4045e,0x25a40098,0x386c0036,0x75e402f0}},	//   _ভূল_, _elol_, _iser_, pózo, 
   {{0xd6d81064,0x70b02ce1,0x1af4015b,0x00000000}},	//   _рта_, ीप्ल, েরকে_, --, 
   {{0x13a4d618,0x35f4d619,0x00000000,0x00000000}},	//   انگی_, _упер, --, --, 
   {{0x0f48044e,0xa3a405d9,0x867801c6,0x628c12e8}},	//   _ዝምልከ, _گڏيل_, _бөөр_, øbor, 
   {{0x3de0009e,0x80ac00eb,0x00000000,0x00000000}},	//   _মংগল, _টুঙ্, --, --, 
   {{0x394c0e04,0xad5873b3,0x00000000,0x00000000}},	//   _oces_, лрах_, --, --, 
   {{0x394c0218,0x386cd61a,0x201c0356,0x20d00037}},	//   _nces_, _oser_, ţuia_, _धुकध, 
   {{0xece801c0,0xe0dc56ec,0x2bc80166,0x00000000}},	// [12020] удал_, ngòl_, глап_, --, 
   {{0x2d80014b,0x317001d5,0x394c045a,0x1ee4179e}},	//   _wnke_, _hayz_, _aces_, _گوپی_, 
   {{0x386cd61b,0x65bc00b0,0x81bc00e2,0xfed800ec}},	//   _aser_, hūha, psēt, _ناٽڪ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x25a40066,0xa85406ed,0x0f3c0023,0x6b5008a5}},	//   _rlol_, стеј, _ክምስረ, gðgó, 
   {{0x394c00d5,0xc7b0059e,0x3bd401f4,0x00000000}},	//   _eces_, بّت_, _дюсс, --, 
   {{0x386cd61c,0x888401d3,0x00000000,0x00000000}},	//   _eser_, _ڈیان, --, --, 
   {{0x76a802bf,0x8884004b,0x1a9808a8,0xadf800bc}},	//   штів_, _ویان, _גילע, ्दिन_, 
   {{0xf8acd61d,0x7a0400c0,0xf8b401af,0x00000000}},	//   _لکو_, _dėtu, _мөш_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x21f802b5,0x4df82aa1,0xd3740137,0x00000000}},	//   _hūhi_, ंगाई_, счы_, --, 
   {{0x25a41c06,0xa5088fdf,0xeae400af,0x386c00a2}},	//   _ulol_, _седа_, _करैत_, _yser_, 
   {{0x660006c8,0x395800a2,0x00000000,0x00000000}},	//   _iiok, _össe_, --, --, 
   {{0x66000270,0x9254b226,0x44b001ec,0x00000000}},	//   _hiok, جشیر_, _нұқс, --, 
   {{0x317001d5,0xd3540375,0x00000000,0x00000000}},	//   _fayz_, _השוק_, --, --, 
   {{0x6600009f,0xbd182472,0xc8a80709,0x00000000}},	//   _jiok, ржах_, कनाट, --, 
   {{0xfff80066,0x00000000,0x00000000,0x00000000}},	// [12030] _نکست_, --, --, --, 
   {{0x6600d61e,0x00000000,0x00000000,0x00000000}},	//   _liok, --, --, --, 
   {{0x394c00d8,0x98c401e0,0xae34004e,0x3d940107}},	//   _pces_, әсел, _мүрт_, _динр, 
   {{0x6600d61f,0x127800c8,0xce6801c0,0x5d1000d1}},	//   _niok, טאבע, _урьд_, _رېئا, 
   {{0x8b8800cf,0x00000000,0x00000000,0x00000000}},	//   _گەلە_, --, --, --, 
   {{0x89180131,0x00000000,0x00000000,0x00000000}},	//   لغۇز_, --, --, --, 
   {{0x869800a7,0x8b880228,0x753c00e5,0x00000000}},	//   йтът_, _دەلە_, ószo, --, 
   {{0x394c682a,0x3dc803f0,0xf5e80798,0x00000000}},	//   _uces_, nnaw_, јмил_, --, 
   {{0x386c025f,0x4990d620,0xb46414d1,0x7c280240}},	//   _user_, _سیور, تگاه, _çerd, 
   {{0x31701529,0xfe0802ab,0xe7944c8b,0xd24001a9}},	//   _sayz_, वदास_, _والک, пмоқ, 
   {{0x75340323,0x6600009b,0x3dc80309,0x7a040064}},	//   _дэлх, _fiok, knaw_, _tėtu, 
   {{0xe56c0517,0x6600011c,0x65bc00b0,0x13a401d3}},	//   _ўз_, _giok, pūha, _گنتی_, 
   {{0x3dc80327,0x00000000,0x00000000,0x00000000}},	//   dnaw_, --, --, --, 
   {{0x3cdc652f,0x6600005a,0xc4f801c8,0x00000000}},	//   _खड़े_, _ziok, _طعنا_, --, 
   {{0x2d94d621,0x660001e1,0x00000000,0x00000000}},	//   орас, _yiok, --, --, 
   {{0x3dc8d622,0x1d04d623,0x00000000,0x00000000}},	//   gnaw_, жети_, --, --, 
   {{0xac980023,0x00000000,0x00000000,0x00000000}},	// [12040] _ቀጺሎም_, --, --, --, 
   {{0x3dc80295,0xab180a89,0x00000000,0x00000000}},	//   anaw_, рцах_, --, --, 
   {{0xed580cfc,0x3dc81c06,0x6a1400db,0xea640451}},	//   _кон_, bnaw_, زبار, تهاپ, 
   {{0xe9d8d624,0xad580006,0xf1c800cd,0x00000000}},	//   шке_, _трох_, ाचिन, --, 
   {{0x660000b5,0xf1740248,0x8f380023,0x00000000}},	//   _riok, _nmọ́_, _እምንቶ, --, 
   {{0x6600d625,0x3868d626,0x685802d3,0x2078008f}},	//   _siok, çara_, _ሃይለስ, יאנא, 
   {{0x66001442,0xa96800d8,0x3868025c,0xe968014b}},	//   _piok, _кива_, ħara_, _кавл_, 
   {{0x2d904c99,0xdb0402e2,0x00000000,0x00000000}},	//   njye_, _aljè, --, --, 
   {{0xa7386eff,0x6600d627,0x36240014,0x00000000}},	//   _نثار_, _viok, _ہوٕہ, --, 
   {{0x7c28d628,0x752c01e4,0xf41803d4,0xf74800f2}},	//   _çere, _ĵaze, _দিশৰ_, _هجمه_, 
   {{0x6600d629,0x3dc80986,0x00000000,0x00000000}},	//   _tiok, ynaw_, --, --, 
   {{0x5ba40882,0x2fc80175,0xb61801ec,0xdb04032e}},	//   _गत्व, enbg_, _ﹼﺯ_, _ólöf, 
   {{0xcf0000ac,0xfd7401c0,0x3dc80309,0x00000000}},	//   əşən_, үлгэ, vnaw_, --, 
   {{0x437453f3,0x3f8400e8,0xd36c01d5,0xdfd80395}},	//   _رهبر, ñlu_, _ўч_, ръм_, 
   {{0x3ea400dd,0x00000000,0x00000000,0x00000000}},	//   ált_, --, --, --, 
   {{0xdb14056a,0x7c28031c,0x3dc8015d,0xd1b801f7}},	//   rixí, _ħerb, unaw_, _وايا_, 
   {{0x3cb4010b,0x3dc80003,0x0dc800f3,0x8f1c01c4}},	// [12050] чйар, rnaw_, цури_, _дvр_, 
   {{0x1fa4042f,0xda78d62a,0x69d800c7,0x00000000}},	//   _фриг, ияе_, _êtej, --, 
   {{0xadf83be5,0x00000000,0x00000000,0x00000000}},	//   ्दशन_, --, --, --, 
   {{0x8f381b49,0x7aec00e2,0x00000000,0x00000000}},	//   _እምነቶ, _ģitā, --, --, 
   {{0x6618d62b,0xdcec0024,0x00000000,0x00000000}},	//   _attk, _įdėk, --, --, 
   {{0x6cf80302,0x7bb800cc,0xacf8011a,0x00000000}},	//   _לפרס, _অৱৰো, _להרכ, --, 
   {{0x752c01e4,0x7c280139,0x00000000,0x00000000}},	//   _ĵazb, _çerb, --, --, 
   {{0x39140845,0x00000000,0x00000000,0x00000000}},	//   _хмар, --, --, --, 
   {{0xd8741888,0x00000000,0x00000000,0x00000000}},	//   _بازب, --, --, --, 
   {{0x81e400fe,0x970000d1,0x21cc00e4,0x00000000}},	//   _ভংগ_, _قېشى, vęha_, --, 
   {{0x95c895c8,0x38c006ea,0x00000000,0x00000000}},	//   _куда_, _færø_, --, --, 
   {{0x63a80165,0x75e40aa6,0x59d805c0,0x00000000}},	//   _elfn, kózi, यकिर, --, 
   {{0x31a000d2,0x92081d15,0xe3ac20c8,0x00000000}},	//   _józi_, _सूरज_, _зб_, --, 
   {{0xa4f80375,0xd344082a,0xc0900023,0x00000000}},	//   _פלסט, _بیده_, ዝርጋሕ_, --, 
   {{0x59d80da5,0x71a4014b,0x00000000,0x00000000}},	//   यकार, _накз, --, --, 
   {{0xde00d62c,0x68000241,0x82a4024c,0xdee008ca}},	//   епси, _kíjì, _юшче, хоси, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [12060] --, --, --, --, 
   {{0xee3800d8,0x91c4586a,0x00000000,0x00000000}},	//   _лно_, _хәүл, --, --, 
   {{0x29841e49,0x9f980375,0xeb980023,0x69d80022}},	//   зылг, _הסיפ, _ወከፍና_, _êtek, 
   {{0xe8f82bbd,0x3ea4143a,0xb5f80153,0x00000000}},	//   бле_, ølte_, _кнiг, --, 
   {{0x7f9404d3,0x98a035dd,0xd820d62d,0x6c84030d}},	//   _رهێڵ, нице, едчи, _хăлх, 
   {{0x65bc00b0,0x23c001e1,0xd94001c6,0x00000000}},	//   tūho, _méjè_, _үери, --, 
   {{0xdbc4d62e,0xe5c400a7,0x7a040153,0x00000000}},	//   töös, зспо, _vėtr, --, 
   {{0x7c280205,0x00000000,0x00000000,0x00000000}},	//   _çerc, --, --, --, 
   {{0x69c06df3,0xe4a40816,0xe7384e73,0x395802d2}},	//   mioe, ярко, _гез_, _össa_, 
   {{0x69c0d62f,0x65bc02b5,0xdc98008f,0x6738005c}},	//   lioe, pūho, צייל, _udtj, 
   {{0x5b54010f,0xd25400d4,0x66180055,0xd5ac7b0e}},	//   הייב_, пця_, _uttk, _зс_, 
   {{0x925400c9,0x69c0d630,0xa01801b8,0x201c0356}},	//   чают_, nioe, nvög, ţuim_, 
   {{0xdee40092,0x543014fb,0xd46400f3,0x00000000}},	//   ሚውን_, _كرور, _нице_, --, 
   {{0x69c0005a,0x00000000,0x00000000,0x00000000}},	//   hioe, --, --, --, 
   {{0x228405f5,0xd358011a,0x28dc0037,0x523400ae}},	//   _хулг, _הדול, _फुसि, _فسيح_, 
   {{0x91e4026a,0x69c001c4,0xdd140210,0x00000000}},	//   _поје, jioe, धुंध_, --, 
   {{0x113c0375,0x00000000,0x00000000,0x00000000}},	// [12070] _התחל, --, --, --, 
   {{0x75e437b5,0x00000000,0x00000000,0x00000000}},	//   rózi, --, --, --, 
   {{0x69c0005a,0xbdf42377,0xb4c819cc,0x00000000}},	//   fioe, _опој, _ईश्_, --, 
   {{0x682002e3,0x6ed40f44,0xcb4401c6,0x7e64002f}},	//   _ọdac, _मुटु, _үхри, _iphp, 
   {{0xf7f40133,0x1be80037,0x00000000,0x00000000}},	//   وستد, _जीअल_, --, --, 
   {{0x69d8d631,0x59d8012c,0x00000000,0x00000000}},	//   _íten, यकहर, --, --, 
   {{0x69c001c4,0xa82001b9,0x00000000,0x00000000}},	//   bioe, _یکون, --, --, 
   {{0x69c05e94,0x49b82f84,0xa5f40114,0x00000000}},	//   cioe, _فاقد_, меју_, --, 
   {{0x3a2001ee,0x7988d632,0xcd540023,0x00000000}},	//   lphp_, _inew, _ዝኽእለ, --, 
   {{0xe2a0004d,0xf2a40d1d,0x00000000,0x00000000}},	//   _thử_, диоп, --, --, 
   {{0xd62406f6,0x7988017a,0xf65406ed,0xd0480213}},	//   _رعاي, _knew, _цвеќ, əməx, 
   {{0x92f00205,0x00000000,0x00000000,0x00000000}},	//   _ışım, --, --, --, 
   {{0x6ed40bae,0x293400df,0x00000000,0x00000000}},	//   _मुजु, וארן_, --, --, 
   {{0x69c005f5,0x63806bd5,0xd84c01f2,0xbef80073}},	//   zioe, _агша, lọsi_, ंधून_, 
   {{0x79882f05,0x4668010a,0x00000000,0x00000000}},	//   _onew, _ярăм_, --, --, 
   {{0x798804ba,0x2be401ad,0x69c0005a,0x3d1812eb}},	//   _nnew, _जीजू_, xioe, युले_, 
   {{0xa5c408a7,0x7e6401ab,0x00000000,0x00000000}},	// [12080] ljóð, _ephp, --, --, 
   {{0x7988d633,0xd84c01f2,0xb7ec000d,0xb60002d2}},	//   _anew, họsi_, _चीलम_, _þáfe, 
   {{0x69c058e5,0x6ed49ea0,0x00000000,0x00000000}},	//   tioe, _मुचु, --, --, 
   {{0x7988d634,0x00000000,0x00000000,0x00000000}},	//   _cnew, --, --, --, 
   {{0x69c001c0,0x79880334,0x8c480bbc,0xa018002f}},	//   rioe, _dnew, _dişç, rvög, 
   {{0x7988d635,0x69c0d636,0xb86400f7,0xe0b40677}},	//   _enew, sioe, عانو, ולנט_, 
   {{0x79880334,0xfa7c001f,0x69c0009d,0x00000000}},	//   _fnew, _የሚኖር_, pioe, --, 
   {{0x79880142,0xe4a401c4,0x00000000,0x00000000}},	//   _gnew, дроо, --, --, 
   {{0xe738016c,0x2368147e,0xc5f80171,0x5c98010f}},	//   _ҳеҷ_, ојно_, _upēm_, ַשטײ, 
   {{0x57440137,0x00000000,0x00000000,0x00000000}},	//   _озум_, --, --, --, 
   {{0x798803ac,0x00000000,0x00000000,0x00000000}},	//   _ynew, --, --, --, 
   {{0x7988031c,0x00000000,0x00000000,0x00000000}},	//   _xnew, --, --, --, 
   {{0x65600223,0x00000000,0x00000000,0x00000000}},	//   _iboh, --, --, --, 
   {{0xa5c4022c,0xdcec00b8,0x00000000,0x00000000}},	//   bjóð, _nacā, --, --, 
   {{0xdd98074d,0x3cec02f0,0x2d440023,0x00000000}},	//   оша_, _šev_, _ንኽካየ, --, 
   {{0xc5f8005f,0xfd7401c6,0x00000000,0x00000000}},	//   _spēj_, элбэ, --, --, 
   {{0x79880395,0x65600588,0x6e2000d7,0x628c00d7}},	// [12090] _rnew, _mboh, _čobe, ťbod, 
   {{0xdcec00cd,0x79880175,0xf000014b,0x00000000}},	//   _cacā, _snew, _бӯси, --, 
   {{0x65600122,0x7988d637,0x8c480139,0xb600032e}},	//   _oboh, _pnew, _pişç, _þáge, 
   {{0x383400c7,0x49b8d638,0x3dcc1bce,0x3a2001a4}},	//   ендр, واند_, _ñew_, rphp_, 
   {{0x79880175,0x3a2000d8,0xa3dcd639,0x00000000}},	//   _vnew, sphp_, ढवा_, --, 
   {{0x6560d63a,0x798803cb,0x00000000,0x00000000}},	//   _aboh, _wnew, --, --, 
   {{0x4ae40953,0x7bc40223,0x66e0014b,0x00000000}},	//   _аўта, mihu, лоша, --, 
   {{0x7bc4d63b,0xc8c005ba,0x79888a15,0xc6a40395}},	//   lihu, _शेवट, _unew, ърчи, 
   {{0x4a08084c,0x98140066,0x00000000,0x00000000}},	//   _цэрм_, _آبرا, --, --, 
   {{0x7bc4d63c,0x6560014b,0xa5c40579,0x349400c7}},	//   nihu, _eboh, tjóð, даҩр, 
   {{0xa0a0d63d,0xc7c4d63e,0x00000000,0x00000000}},	//   қард, _рсти, --, --, 
   {{0x7bc406d6,0xe29801fb,0x65600248,0xdecc02d3}},	//   hihu, _ngưu_, _gboh, _ባርካ_, 
   {{0x7bc4d63f,0xa5c4008c,0x81d4009d,0x22541424}},	//   kihu, sjóð, тцэц, ولید_, 
   {{0x7bc4d640,0x656002fb,0x09dc0490,0x69d800e4}},	//   jihu, _zboh, _बऱ्य, _êtev, 
   {{0x7bc4016b,0x3d1405db,0x00000000,0x00000000}},	//   dihu, _ụwa_, --, --, 
   {{0x64440024,0xdcec00b8,0x8fc400c7,0x3ea403b2}},	//   škie, _sacā, хаҳҵ, ølta_, 
   {{0x628400b0,0x7bc4d641,0xdcec002b,0xafe4447e}},	// [120a0] ākoe, fihu, _pacā, _поил, 
   {{0x7bc42001,0xe2c400dd,0x6be4d642,0x00000000}},	//   gihu, _آڈیو_, ركام, --, 
   {{0x6da4d643,0x7c28d644,0x8ca000af,0x7ac0035b}},	//   _зина, _çern, _गॅरो, аҩра, 
   {{0xe8f8d645,0x00000000,0x00000000,0x00000000}},	//   пле_, --, --, --, 
   {{0x7bc40230,0x69d82815,0x00000000,0x00000000}},	//   bihu, _ítem, --, --, 
   {{0x6560013a,0x00000000,0x00000000,0x00000000}},	//   _sboh, --, --, --, 
   {{0x26048748,0x2560022e,0x00000000,0x00000000}},	//   нчиг, tаl_, --, --, 
   {{0xd5b407a2,0xda580375,0x84c47a15,0xa92400ae}},	//   есь_, _מכלל, кәлд, _سعره, 
   {{0xc33004a9,0xd940d646,0x256001a9,0x43942abf}},	//   لەش_, _щети, rаl_, вапс, 
   {{0xdb14467d,0xe590069d,0x00000000,0x00000000}},	//   rixç, ግሊዘኛ_, --, --, 
   {{0xdbc80241,0x75e400e5,0x626400db,0x00000000}},	//   _jòán, tózt, رادق, --, 
   {{0x7bc4d647,0x656002f0,0x00000000,0x00000000}},	//   zihu, _uboh, --, --, 
   {{0x7bc46f2e,0x5064d648,0x93c80014,0x2490010e}},	//   yihu, лтра, _کانہ_, _çym_, 
   {{0x23b0019f,0xdcec0356,0x44240175,0x7bc40165}},	//   _bâje_, _lacă, mpm_, xihu, 
   {{0xdda8d649,0x384002d3,0xdd8c0131,0xbd88009f}},	//   птал_, _ኣይትበ, مۈد_, ونسن_, 
   {{0x7bc40223,0x00000000,0x00000000,0x00000000}},	//   wihu, --, --, --, 
   {{0x7bc4d64a,0xd16406bb,0x3b54d64b,0x442400f3}},	// [120b0] tihu, _същи, ккар, npm_, 
   {{0xe1fc5e06,0x46b000bc,0x00000000,0x00000000}},	//   lmó_, जनाह, --, --, 
   {{0xdcec0276,0xb9340120,0x795800d8,0x00000000}},	//   _bacă, вееј, диер_, --, 
   {{0x752c0115,0x7bc4d64c,0xd8540166,0x00000000}},	//   _ĵazo, sihu, ечкә_, --, 
   {{0x0c8401af,0x00000000,0x00000000,0x00000000}},	//   _йырм, --, --, --, 
   {{0xf770d64d,0x7bc4013c,0x93ec000d,0x00000000}},	//   شات_, qihu, _घींच_, --, 
   {{0xcec40118,0x41e000b8,0x996400c0,0x00000000}},	//   moří_, नवास, _птал, --, 
   {{0x6aa82ab7,0xc64800db,0x00000000,0x00000000}},	//   øffe, رجىل_, --, --, 
   {{0x24500150,0x21000073,0x25a0000d,0x00000000}},	//   لنيس, रेमळ_, ökla_, --, 
   {{0x5ed400bd,0x8a880014,0x638000c7,0x4374003b}},	//   _ধরনে, _تپہِ_, агьа, гуют, 
   {{0xd6840184,0x466400ec,0x00000000,0x00000000}},	//   _яуап, _مهلق, --, --, 
   {{0xd7c40133,0xcec40118,0x311401d5,0x75e400e5}},	//   _توڕه_, hoří_, ъфос, rózs, 
   {{0x7528d64e,0x34940139,0xa938011a,0x00000000}},	//   mbez, _шадр, ותרפ, --, 
   {{0x644416a3,0x7528d64f,0x7d1c39b4,0x660c01e1}},	//   škic, lbez, _afss, _ònkò, 
   {{0x9f500137,0x09c802f5,0x00000000,0x00000000}},	//   _aixó_, ষকতা, --, --, 
   {{0x7528d650,0x65bc0374,0x00000000,0x00000000}},	//   nbez, tūhi, --, --, 
   {{0x7528009f,0xac08d651,0xb8840381,0x6b5890a9}},	// [120c0] ibez, днаа_, ntĭā, дшер_, 
   {{0x65bc00b0,0x00000000,0x00000000,0x00000000}},	//   rūhi, --, --, --, 
   {{0xf1c426d9,0x2d9c4aee,0x3bd40b32,0x752813eb}},	//   _लगान, êtes_, уютс, kbez, 
   {{0x6cc4d652,0x65bc02b5,0x44240076,0x6da40fac}},	//   _айма, pūhi, ypm_, _рима, 
   {{0x636001f2,0x88846171,0xcec401ef,0x00000000}},	//   ọnik, ығал, boří_, --, 
   {{0x75280166,0x666402a9,0x00000000,0x00000000}},	//   ebez, въиз, --, --, 
   {{0x16340597,0x6b8c009a,0x44240175,0x25dc1d94}},	//   نسية_, _inbg, wpm_, खवली_, 
   {{0x752801f5,0x795003e6,0x00000000,0x00000000}},	//   gbez, _هێما, --, --, 
   {{0xe8e8d653,0xa804d654,0xb86400aa,0xa02408a5}},	//   _آرزو_, _азал, _مالو, _mjöö, 
   {{0x6e3c00f3,0x988801d3,0x3cf400dc,0x00000000}},	//   _ovpb, _تحفہ_, ्धते_, --, 
   {{0xf1f40034,0xd374d655,0x4424d656,0xdb04032e}},	//   ीगढ़_, тчы_, spm_, _kljá, 
   {{0x98acd657,0x42a40032,0x44240472,0x78ac03cd}},	//   lagā_, _ҡуйғ, ppm_, øavg, 
   {{0xe1fcd658,0x10742627,0x6e201674,0xe474010a}},	//   rmó_, аляю, _čoba, _шужэ, 
   {{0x9f500372,0x386802d3,0x248435e9,0x9f400240}},	//   _això_, çari_, _irom_, mojë_, 
   {{0x9f4002d3,0xcec400bc,0x2484517b,0x5270030c}},	//   lojë_, voří_, _hrom_, _نايز, 
   {{0x2484d659,0x415400f5,0x00000000,0x00000000}},	//   _krom_, _свис, --, --, 
   {{0x7bf8d65a,0x9f4002d3,0x3d1800cd,0x00000000}},	// [120d0] енар_, nojë_, युगे_, --, 
   {{0x61ecd65b,0x2d9c004a,0x752800f3,0x752c01e4}},	//   llcl, êter_, zbez, _ĵazm, 
   {{0x9f400240,0x65bc01ef,0x98ac00ef,0x00000000}},	//   hojë_, _záhř, dagā_, --, 
   {{0x9f4002d3,0xc8480020,0x248401d5,0x7d1c0139}},	//   kojë_, _አውሮፕ, _orom_, _ufss, 
   {{0x24840218,0x98ac0618,0x9f400023,0xf7442c08}},	//   _nrom_, fagā_, jojë_, гело, 
   {{0xdb0400dd,0x9f400023,0x00000000,0x00000000}},	//   _eljá, dojë_, --, --, 
   {{0x2484d65c,0xcf9410df,0x75281543,0x33f8068c}},	//   _arom_, יטס_, tbez, nèxe_, 
   {{0x3dc803a2,0x69c89ec6,0xdb04032e,0x9f40036e}},	//   niaw_, éfet, _gljá, fojë_, 
   {{0x75280020,0x2484d65d,0x9f400023,0x061801c6}},	//   rbez, _crom_, gojë_, нхөө_, 
   {{0x7528d65e,0x2484777e,0xd77410de,0xcfd800cc}},	//   sbez, _drom_, _جارع, _দীনন, 
   {{0x2484d65f,0x35546640,0x39400092,0x80e00037}},	//   _erom_, _مناز, _ከምዕራ, _गँउओ_, 
   {{0x2484d660,0x644402d5,0xadf800bc,0x9f40036e}},	//   _from_, škia, ्दछन_, bojë_, 
   {{0xf53801f1,0x35a400c7,0x628400b0,0x3dc80142}},	//   mať_, _иаҧг, ākoa, diaw_, 
   {{0xf53801f1,0xf1c4d661,0x00000000,0x00000000}},	//   lať_, _әйип, --, --, 
   {{0x61ec0113,0x38400240,0x7168009d,0x00000000}},	//   blcl, _ኣይህብ, _зайг_, --, 
   {{0xf53801f1,0x40e40521,0xf1a8221c,0x00000000}},	//   nať_, ụrị_, _ساعه_, --, 
   {{0x6b64035b,0x5ed4015b,0xac8421ae,0x80a401d3}},	// [120e0] лкаа, _ধরণে, ыгал, _نمٹن, 
   {{0xf53801f1,0x00000000,0x00000000,0x00000000}},	//   hať_, --, --, --, 
   {{0x9f4002d3,0xf53801f1,0x201c0311,0x00000000}},	//   zojë_, kať_, ţuit_, --, 
   {{0x3ea4d662,0xf5380030,0x00000000,0x00000000}},	//   älte_, jať_, --, --, 
   {{0xf5383351,0x98acd663,0xd9401575,0x9f400240}},	//   dať_, tagā_, сечи, xojë_, 
   {{0x9f4002d3,0x6e000521,0x24840356,0x98a00063}},	//   vojë_, _ọchụ, _rrom_, сиље, 
   {{0xdb040008,0x248401ab,0xf5380419,0x00000000}},	//   _smjö, _srom_, fať_, --, 
   {{0x6d549b94,0x9f4002d3,0x75c8425c,0xa6e402d2}},	//   ngya, tojë_, ктың_, _auðþ, 
   {{0xa8482614,0x6d54d664,0x675426c6,0x4904009d}},	//   _سلام_, igya, _مخار, _түдг, 
   {{0x9f40044e,0x6d540007,0x248401a4,0x78000139}},	//   rojë_, hgya, _vrom_, _дүча, 
   {{0x9f4002d3,0xe8180034,0x6d540007,0xf5380030}},	//   sojë_, _फंडा_, kgya, bať_, 
   {{0x2484d665,0x6d540369,0x9f400240,0xf5380030}},	//   _trom_, jgya, pojë_, cať_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d5401d9,0x2a640034,0x14d40375,0x95940022}},	//   egya, łoby_, _גודל_, _атәу_, 
   {{0x6fb40073,0x1ee40244,0x3dc401ec,0xe24400ae}},	//   _उतरू, اوزی_, араұ, _إختي, 
   {{0x6d54d666,0x7c28d667,0x65bc02b5,0x00000000}},	//   ggya, _çerk, pūhu, --, 
   {{0x3dc80649,0x13040032,0x4c946ee4,0x9984031c}},	// [120f0] riaw_, _инәй_, битс, ġiżi_, 
   {{0x954c0491,0xf53801a2,0x2fc800f3,0x6d540083}},	//   _ẵśệł_, zať_, cibg_, agya, 
   {{0x3a74d668,0x6d540369,0x00000000,0x00000000}},	//   рлер, bgya, --, --, 
   {{0x3e400153,0xaa4000a2,0x99e81411,0x92cc00eb}},	//   mėt_, _ösýä_, رعاق_, _শরৎ_, 
   {{0xf5383351,0x180c6c5a,0xa3c43174,0x3e4000c0}},	//   vať_, ादेव_, ैचा_, lėt_, 
   {{0x69c8d669,0x10380bd9,0x38800092,0x00000000}},	//   éfer, נטום_, _ቫይረሱ_, --, 
   {{0xf53801a2,0x3e400153,0xcf5800d9,0x6444d66a}},	//   tať_, nėt_, אבות_, ákin, 
   {{0xf9d40166,0xe3e41291,0x00000000,0x00000000}},	//   _тобэ, یکون_, --, --, 
   {{0x644402d5,0xf53801a2,0x00000000,0x00000000}},	//   škin, rať_, --, --, 
   {{0xf53801a2,0x386cd66b,0xb450001f,0x81bc005f}},	//   sať_, _iper_, _ባደረጉ, spēl, 
   {{0xf5380030,0x00000000,0x00000000,0x00000000}},	//   pať_, --, --, --, 
   {{0x386c06a3,0x6d540399,0x3e400153,0xf1c4013a}},	//   _kper_, xgya, dėt_, _žába_, 
   {{0x85b801d9,0xe3ac61ac,0x7f400240,0x00000000}},	//   _حالس_, _дб_, _ንምዝኽ, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6da400c9,0xad580354,0x00000000,0x00000000}},	//   аива, крах_, --, --, 
   {{0x386c0585,0xe6480092,0x6da401f4,0x00000000}},	//   _oper_, _አይጠፋ, шиба, --, 
   {{0x6d54d66c,0xc06800c7,0xec7800a7,0xa0a0059f}},	// [12100] rgya, _бзыҧ_, ъпа_, _маъд, 
   {{0xeab0d66d,0xca7c022e,0xaec40212,0xfca800f1}},	//   يعا_, _berа, _вбол, دافو_, 
   {{0x386cd66e,0x200c04cc,0x00000000,0x00000000}},	//   _aper_, _ègia_, --, --, 
   {{0x291003a1,0xa0180008,0x386c0165,0x6d540097}},	//   øya_, kvöl, _bper_, qgya, 
   {{0x764078d0,0x6ec81be1,0x6d44035a,0x00000000}},	//   _avly, _हेतु, _idka, --, 
   {{0x7e78010e,0x86e40220,0xa01802d2,0x00000000}},	//   _çapý, _ﺒل_, dvöl, --, 
   {{0xd6cc7a1f,0x295406bb,0x6994d66f,0xf9901e4a}},	//   وقه_, _възр, _крах, تبە_, 
   {{0x6d4405b1,0xc9d4d670,0xcfcc00eb,0xc5940798}},	//   _jdka, _امرک, লকিন, сииј, 
   {{0x2614006d,0xd32001e4,0xe2080ad9,0xa01801a8}},	//   _पूरी_, _konʈ, _ljóð_, gvöl, 
   {{0xf8a81c36,0x3d1c0248,0x64440153,0x228400c7}},	//   _صدقه_, _káwó_, škio, аумг, 
   {{0x6d440745,0xd5acd671,0xf4b401d5,0x6abc002f}},	//   _odka, _дс_, لشیگ, nzpf, 
   {{0xd6cc00ae,0x00000000,0x00000000,0x00000000}},	//   _تقم_, --, --, --, 
   {{0x3d1c01e1,0x27fc0208,0x00000000,0x00000000}},	//   _láwó_, _khtn_, --, --, 
   {{0x6d44d672,0x752c01e4,0x925404f2,0x13f00064}},	//   _adka, _ĵazi, دشیر_, _дзія, 
   {{0x3d1c0248,0x5398011a,0xfdd800ec,0xc5f800de}},	//   _náwó_, _ביגו, هارڻ_, _upēs_, 
   {{0x2fd80175,0x6288ad31,0x27fc0051,0xd2b4011a}},	//   _ejpg_, _irfo, _lhtn_, _כלות_, 
   {{0x33f80ba1,0xe68001e1,0x36ec000d,0x00000000}},	// [12110] lèxa_, _láàà, _चुनअ_, --, 
   {{0x6d440327,0x2d8c0607,0x9b24d673,0x8fa40114}},	//   _edka, ēfea_, рфал, _мање, 
   {{0x386cd674,0x33f80ba1,0x629829b3,0x391400ae}},	//   _sper_, nèxa_, nxto, مواز, 
   {{0x3f8002b5,0x3d1c0248,0xd54001e1,0x00000000}},	//   _hahu_, _dáwó_, _mẹ́w, --, 
   {{0x3f802bae,0xf868d675,0xd54001e1,0x27fc0208}},	//   _kahu_, امتي_, _lẹ́w, _bhtn_, 
   {{0x3f80d676,0x683c044e,0x6288d677,0x3d1c01e1}},	//   _jahu_, _ኣይመስ, _orfo, _fáwó_, 
   {{0x3f80d678,0x6440d679,0xca740f1c,0x81bc005f}},	//   _mahu_, _avoi, _وافغ, rpēj, 
   {{0x81bc11f9,0x3f8003f9,0x62980009,0x00000000}},	//   spēj, _lahu_, dxto, --, 
   {{0x3f80d67a,0x628800a9,0x26dc01f5,0xc7c80051}},	//   _oahu_, _arfo, _exto_, tốt_, 
   {{0xd7f8d67b,0x3f80166a,0xe3b400f7,0xa0180008}},	//   _руб_, _nahu_, йбы_, rvöl, 
   {{0x644002d0,0xa0183b7b,0xdcec0419,0x60880023}},	//   _evoi, svöl, _nocľ, _ሕላገት_, 
   {{0x3f8018a6,0x30a00131,0xe20802d2,0x00000000}},	//   _aahu_, зғиғ, _rjóð_, --, 
   {{0x6288d67c,0x3f80d67d,0x2978010f,0xe20808a5}},	//   _erfo, _bahu_, נטשא, _sjóð_, 
   {{0x63b8d67e,0x23248c67,0x64a0b5f5,0xe818012d}},	//   chtn, _лоши_, _хаша, _फंसा_, 
   {{0xdfcc9f43,0x6440006f,0x71a4008e,0x00000000}},	//   ريف_, _zvoi, _гайз, --, 
   {{0x3ea40267,0xfd940212,0xfd640051,0xae000210}},	//   älta_, ошую, mmuố, लगइन_, 
   {{0x3f80d67f,0x00000000,0x00000000,0x00000000}},	// [12120] _fahu_, --, --, --, 
   {{0xa3c8d680,0x3f80198f,0xf9f0009e,0xe20806ea}},	//   रोप_, _gahu_, _জংগল_, _tjóð_, 
   {{0xed58d681,0xd68001e4,0xda6c01d9,0xaaf8003b}},	//   _йон_, zanϲ, ٹُن_, ухає_, 
   {{0xe9d8d682,0x753807ad,0xe93819f9,0x6d44037e}},	//   ыке_, _newz, اسات_, _udka, 
   {{0x3f80d683,0x81bc0154,0xf77400d1,0x00000000}},	//   _yahu_, _আদম_, ﺸﻠﯩﻚ_, --, 
   {{0x2d800924,0x3d1c01e1,0x98700006,0x63b8022e}},	//   _hake_, _táwó_, яліц, xhtn, 
   {{0x2d80d684,0x779008cf,0x9f5c003e,0x6440d685}},	//   _kake_, ظیما, éréd_, _svoi, 
   {{0x2d80d686,0xd5b4d687,0xa3c805d7,0x6444d688}},	//   _jake_, йсы_, रोन_, škim, 
   {{0x2d80025f,0xe5a407d6,0x81bc005f,0x61fc0175}},	//   _make_, _қиди, spēk, _rhql, 
   {{0xd4e01de1,0x2d800375,0x62880010,0xe61800a7}},	//   яющи, _lake_, _prfo, _бдж_, 
   {{0x2d80d689,0x3f80d68a,0x629800ca,0x673801a4}},	//   _oake_, _rahu_, uxto, _ietj, 
   {{0x2d80d68b,0x3f80d68c,0x67380321,0x63b8d68d}},	//   _nake_, _sahu_, _hetj, shtn, 
   {{0x6738049b,0x3f8018a6,0x9f400241,0x00000000}},	//   _ketj, _pahu_, bojì_, --, 
   {{0x25a4d68e,0x2d80d68f,0x43940b2c,0x673801f5}},	//   _hool_, _aake_, _факс, _jetj, 
   {{0x25a4d690,0x67385393,0x6288143a,0x2d80d691}},	//   _kool_, _metj, _urfo, _bake_, 
   {{0x6738d692,0x5f4405f5,0x3f80d693,0x25a40af9}},	//   _letj, шүүн_, _wahu_, _jool_, 
   {{0x3f80d694,0x2d804437,0x25a4d695,0x4c943da1}},	// [12130] _tahu_, _dake_, _mool_, питс, 
   {{0x6738d696,0x25a41574,0x66180198,0x2d8008e7}},	//   _netj, _lool_, _outk, _eake_, 
   {{0x2d80011a,0x661844ef,0x039c010e,0x00000000}},	//   _fake_, _nutk, _söỳg, --, 
   {{0x25a40050,0x201002c4,0x2d803811,0x20180240}},	//   _nool_, _hixi_, _gake_, _kuqi_, 
   {{0x673817c1,0x644401a6,0x6618033f,0x9f4002f0}},	//   _betj, škij, _autk, hojí_, 
   {{0x2d8069bf,0x7c2c1e13,0x6618d697,0xa3c8547d}},	//   _zake_, mpar, _butk, रोम_, 
   {{0x2d80d640,0x20100a5c,0x201852ac,0x25a4d698}},	//   _yake_, _mixi_, _luqi_, _bool_, 
   {{0x2010d699,0x25a4527a,0x39580158,0x2d80009d}},	//   _lixi_, _cool_, _øss_, _xake_, 
   {{0x673801af,0x25a45e20,0xb60002d2,0x00000000}},	//   _fetj, _dool_, _þáme, --, 
   {{0x6738017a,0x18b000d1,0x37f8084c,0x2010d69a}},	//   _getj, _мәһр, _тезэ_, _nixi_, 
   {{0xd6d8d69b,0x629c00d8,0x25a42517,0x00000000}},	//   _ста_, _àpol, _fool_, --, 
   {{0x20100137,0x25a40014,0x673801f5,0x00000000}},	//   _aixi_, _gool_, _zetj, --, 
   {{0x2d80d69c,0x7c2cd69d,0x201001d9,0x6738d69e}},	//   _rake_, jpar, _bixi_, _yetj, 
   {{0x2d80d69f,0x7c2cd6a0,0x20100561,0x25a4d6a1}},	//   _sake_, dpar, _cixi_, _zool_, 
   {{0x2d80d6a2,0x7c2cd6a3,0x20101730,0x21380ac5}},	//   _pake_, epar, _dixi_, _feqh_, 
   {{0x2018d6a4,0x2d80062c,0x024800db,0xdb0401a8}},	//   _fuqi_, _qake_, _اجوو_, _fljú, 
   {{0x7c2cd6a5,0x2bc81d37,0x2d800e8a,0x2010d6a6}},	// [12140] gpar, алап_, _vake_, _fixi_, 
   {{0x2d80d6a7,0xdb780055,0x00000000,0x00000000}},	//   _wake_, _īṣād, --, --, 
   {{0x7c2cd6a8,0x2d80025f,0xada4804b,0x6738007f}},	//   apar, _take_, _данл, _retj, 
   {{0xa9682d2e,0x6738d6a9,0x2d800070,0x3ce400e1}},	//   рида_, _setj, _uake_, _झुके_, 
   {{0x661803b9,0x98a0d6aa,0x6738d6ab,0x20180ba7}},	//   _sutk, мице, _petj, _xuqi_, 
   {{0x25a4d6ac,0x6618d6ad,0xbc7008b0,0x2010c17e}},	//   _sool_, _putk, _سۇمب, _xixi_, 
   {{0xd7c404d3,0x6738d6ae,0x25a40375,0xbab00137}},	//   تووه_, _vetj, _pool_, _كۅكب, 
   {{0x6738d6af,0x25a4058a,0xe46806ed,0x2444005b}},	//   _wetj, _qool_, ашол_, охог, 
   {{0x2b480115,0x661800e8,0x6738d6b0,0x7c284353}},	//   _kdbc_, _wutk, _tetj, _çert, 
   {{0x6618d6b1,0x2018002e,0x934003e6,0x25a4123b}},	//   _tutk, _ruqi_, ورپۆ, _wool_, 
   {{0xe5780801,0xe5240022,0x7c2cd6b2,0x384c0092}},	//   _взе_, _ддеп, zpar, _አልተጠ, 
   {{0x7c2cd6b3,0x20100067,0x00000000,0x00000000}},	//   ypar, _sixi_, --, --, 
   {{0x6600d6b4,0x14c411ed,0x7c2c0423,0x6e3802d3}},	//   _ihok, _мыши_, xpar, _ጸብጻባ, 
   {{0x9f4002fb,0xd36c1fa1,0x00000000,0x00000000}},	//   pojí_, _لهه_, --, --, 
   {{0x6600d6b5,0x7c2cd6b6,0x2010d6b7,0xa3c80db3}},	//   _khok, wpar, _vixi_, रोण_, 
   {{0x7c2cd6b8,0xc68415fa,0x2018d6b9,0x20100014}},	//   tpar, _یې_, _tuqi_, _wixi_, 
   {{0x7c2c01a8,0xa3c803ce,0xb60001ef,0x00000000}},	// [12150] upar, रोथ_, _žáke, --, 
   {{0x7c2cd6ba,0x81bc0c58,0x66000263,0x20040428}},	//   rpar, _আদি_, _lhok, _òni_, 
   {{0x9a2413d7,0x6600d6bb,0x00000000,0x00000000}},	//   زعان, _ohok, --, --, 
   {{0xa3c86b9b,0x6600d6bc,0xdb040200,0xfd740139}},	//   रोत_, _nhok, _hojë, _элмэ, 
   {{0x7c2c022e,0x81bc0154,0x00000000,0x00000000}},	//   qpar, _আদা_, --, --, 
   {{0x66000134,0xec340375,0x31a002fb,0xe8500131}},	//   _ahok, _מאשר_, _dózy_, رنىد, 
   {{0x6600d6bd,0xb60002d2,0x478400c7,0xb934009b}},	//   _bhok, _þáke, ьыцб, _невј, 
   {{0x6600d6be,0xdb0402d3,0x00000000,0x00000000}},	//   _chok, _lojë, --, --, 
   {{0x6600d6bf,0xd8800ee8,0x00000000,0x00000000}},	//   _dhok, _تهذی, --, --, 
   {{0x2d9c0129,0x73981d0f,0x00000000,0x00000000}},	//   êtez_, стис_, --, --, 
   {{0x03a800ae,0x00000000,0x00000000,0x00000000}},	//   تديو_, --, --, --, 
   {{0x98ac012d,0xf1c40037,0x00000000,0x00000000}},	//   wagę_, _लगओन, --, --, 
   {{0x3394005b,0xdb04036e,0x00000000,0x00000000}},	//   _надё, _bojë, --, --, 
   {{0x35d005f9,0x1c1c00af,0x09b80a59,0x606000d1}},	//   _तगड़, _बढ़ल_, _आत्य, رۇپل, 
   {{0x7760003a,0x1d040107,0x5f0002e8,0x98ac0064}},	//   _mclx, ҷети_, езра, ragę_, 
   {{0x66000200,0x8d7800c7,0x00000000,0x00000000}},	//   _xhok, цәоу_, --, --, 
   {{0x1d04d6c0,0x6e2c0334,0x9f4001e1,0x00000000}},	// [12160] зети_, spbb, bojà_, --, 
   {{0xdb040023,0xab180024,0x00000000,0x00000000}},	//   _gojë, сцах_, --, --, 
   {{0x6a1400f2,0xcdc401ec,0x00000000,0x00000000}},	//   سبار, _жанқ, --, --, 
   {{0x9f400004,0x6a7001a8,0xaf34bbed,0x31a002f0}},	//   pojã_, _aðfö, _برکت, _pózy_, 
   {{0xbf58004d,0xc18c008f,0xa2881ef7,0x9844011c}},	//   _điếc_, יטאָ, _ሄዋንን_, пяща_, 
   {{0x6600d6c1,0xaa44d6c2,0x77600381,0x00000000}},	//   _shok, _негл, _cclx, --, 
   {{0x6600d6c3,0x7760003a,0x97200592,0x7c2800a2}},	//   _phok, _dclx, رفيو, _çerr, 
   {{0x9ad80302,0x7c440166,0x00000000,0x00000000}},	//   _החלט, _äträ, --, --, 
   {{0x66000943,0xa7a80022,0xa8a40101,0x00000000}},	//   _vhok, _лкаа_, _عصرو, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x66006980,0x2c6400d0,0x2568008e,0x9f400022}},	//   _thok, hôd_, _гаеп_, jojá_, 
   {{0x6600009a,0xdb042568,0x27ec03cb,0x81b400fe}},	//   _uhok, _sojë, lofn_, ছোন_, 
   {{0x442000a8,0x656002d0,0x81bc0171,0x00000000}},	//   _îi_, _icoh, dpēt, --, 
   {{0xdfd802e8,0x00000000,0x00000000,0x00000000}},	//   съм_, --, --, --, 
   {{0xdb04020c,0xf3c803e6,0x7c280135,0x00000000}},	//   _gojè, _ببنه_, _ħerq, --, 
   {{0x8d843bfd,0x63a8d6c4,0x7af40064,0x00000000}},	//   нууд, _hofn, _ryzt, --, 
   {{0xc104007b,0x0dc8bf29,0x7c1400d4,0x00000000}},	// [12170] _توظي, чури_, ддає, --, 
   {{0x0004104c,0x7de40064,0x9ba00137,0x00000000}},	//   _تثبی, dėse, رەزى, --, 
   {{0xdb04003e,0x00000000,0x00000000,0x00000000}},	//   _kojé, --, --, --, 
   {{0x6aa804f3,0x63a803cb,0x7af40118,0x2c640419}},	//   äffa, _lofn, _vyzt, bôd_, 
   {{0xac6c0023,0xc79401e2,0x00000000,0x00000000}},	//   _ስርሖም_, کشنب, --, --, 
   {{0x63a80270,0x6560037e,0x61ec0332,0x7c280139}},	//   _nofn, _acoh, hocl, _çerq, 
   {{0x35a400f7,0x66e000f3,0x1aa800cc,0x00000000}},	//   дайг, коша, _গেৰা, --, 
   {{0xd838152d,0xc6a47314,0x05540139,0xdcec0166}},	//   _гэж_, эрчи, нтья, _xacğ, 
   {{0x394c05a1,0x61ecd6c5,0x63a80ba7,0x00000000}},	//   _ides_, docl, _bofn, --, 
   {{0x63a800a9,0x656000d8,0xb2244965,0x7bd80066}},	//   _cofn, _ecoh, ммол, éwuh, 
   {{0x61ec01e7,0x63a8032e,0x394c01ef,0x8c2400eb}},	//   focl, _dofn, _kdes_, _পিছন_, 
   {{0xf4980150,0x75e800fd,0x61ec0051,0x00000000}},	//   _وپات_, _qözğ, gocl, --, 
   {{0xa3c842e3,0xd41800fe,0x00000000,0x00000000}},	//   रोह_, _দৌৰি_, --, --, 
   {{0x63a80368,0x00000000,0x00000000,0x00000000}},	//   _gofn, --, --, --, 
   {{0x394c08ad,0x61ec0798,0x81bc0154,0xddc801e4}},	//   _odes_, bocl, _আদর_, ŝiŝo, 
   {{0x394c020c,0x61ec020c,0x2614033f,0xde000131}},	//   _ndes_, cocl, _पंछी_, впси, 
   {{0xdd8c0f87,0x64440552,0x3a2c96c0,0xceb80024}},	// [12180] جوق_, škiv, _čepa_, šę_, 
   {{0x394cd6c6,0xaab8d6c7,0x9bc800f1,0xfd10210e}},	//   _ades_, يدار_, يدلې_, اجِ_, 
   {{0x64d8012d,0x9f9808c3,0xe68c0254,0x00000000}},	//   _बख्श, _וסיפ, ösüü, --, 
   {{0xe8f8d6c8,0x394c00d8,0xed580066,0x00000000}},	//   оле_, _cdes_, _بشدت_, --, 
   {{0x394c0042,0x584000d1,0xa87807fc,0x00000000}},	//   _ddes_, پپىق, تحار_, --, 
   {{0x394c049b,0xc5f85c0e,0x98a00063,0x00000000}},	//   _edes_, ुष्य_, тиље, --, 
   {{0x63a8032e,0x00000000,0x00000000,0x00000000}},	//   _rofn, --, --, --, 
   {{0x394c02e2,0x63a801a8,0x629c0129,0xa018002f}},	//   _gdes_, _sofn, _àpoi, nwöc, 
   {{0xa7646bd5,0xefcc02d3,0x69c001f5,0xa018002f}},	//   _окад, _ባጽዕ_, mhoe, iwöc, 
   {{0x69c0d6c9,0x63a80014,0x394c28e5,0x00000000}},	//   lhoe, _qofn, _zdes_, --, 
   {{0x61ecd6ca,0x394c00b5,0xe2a82e44,0x17180a7c}},	//   tocl, _ydes_, زادن_, _וובע, 
   {{0x69c0d6cb,0xf6083629,0x9f4401e1,0x81bc00ef}},	//   nhoe, _فتنه_, _ónú_, epēr, 
   {{0x64b42942,0x69c0d6cc,0x5064d6cd,0x5ef800cc}},	//   _تحار, ihoe, ктра, _আলেখ_, 
   {{0x69c00007,0x00000000,0x00000000,0x00000000}},	//   hhoe, --, --, --, 
   {{0x69c00032,0xdda8005b,0x1ee400e5,0x00000000}},	//   khoe, отал_, ذوری_, --, 
   {{0x64440024,0x81dc00eb,0x00000000,0x00000000}},	//   škiu, _তীর_, --, --, 
   {{0x69c0d6ce,0x26140307,0x00000000,0x00000000}},	// [12190] dhoe, _पूछी_, --, --, 
   {{0x69c01a7c,0x00000000,0x00000000,0x00000000}},	//   ehoe, --, --, --, 
   {{0x394c009a,0x69c00549,0x44240175,0x00000000}},	//   _pdes_, fhoe, hqm_, --, 
   {{0x69c0d6cf,0x00000000,0x00000000,0x00000000}},	//   ghoe, --, --, --, 
   {{0x394c02d3,0xf3f80311,0xf1c40118,0x00000000}},	//   _vdes_, luţe_, _žáka_, --, 
   {{0xa018cce3,0x00000000,0x00000000,0x00000000}},	//   lvös, --, --, --, 
   {{0x99645f0f,0xf3f80356,0x78b80139,0x00000000}},	//   _отал, nuţe_, _şavı, --, 
   {{0x69c0d6d0,0x394c9358,0x34a80114,0xada002d2}},	//   choe, _udes_, звио_, _íútl, 
   {{0xd7740302,0x2d9c013f,0xd7e4075e,0x4824075e}},	//   _ياطع, _ɑte_, _قورۇ_, _لىقق, 
   {{0x798801af,0xb6040122,0xa3c858c1,0x97a4a8d7}},	//   _haew, dnáš, रोल_, _ўрал, 
   {{0xeb9004ac,0x7988394e,0xc6a4009d,0x00000000}},	//   אָר_, _kaew, _ирци, --, 
   {{0xdb0400fc,0x7d1cd6d1,0x7c3c035a,0x00000000}},	//   _hljó, _ngss, _owsr, --, 
   {{0x7988394e,0x33d4109a,0xdee0059f,0xc4c40133}},	//   _maew, _пікт, ҳори, _لتوو, 
   {{0x7528d6d2,0x69c00399,0xe454010f,0x00000000}},	//   lcez, zhoe, _ניצט_, --, 
   {{0x69c00368,0x64440024,0x752801e4,0x7ed400d4}},	//   yhoe, škit, ocez, вітч, 
   {{0x7988039a,0x69c00472,0xdb04032e,0x00000000}},	//   _naew, xhoe, _lljó, --, 
   {{0x6b54d6d3,0x00000000,0x00000000,0x00000000}},	// [121a0] فضائ, --, --, --, 
   {{0x2ac401e1,0x00000000,0x00000000,0x00000000}},	//   _níbé_, --, --, --, 
   {{0xc0a80502,0x69c0d6d4,0x7c3c03ac,0xf3f8054e}},	//   _فایل_, thoe, _ewsr, cuţe_, 
   {{0xf3f0063f,0x7c3c0334,0x7988015d,0x00000000}},	//   họ_, _fwsr, _caew, --, 
   {{0x69c0368d,0x2ac40241,0xd91400c0,0x752803e0}},	//   rhoe, _bíbé_, ньш_, dcez, 
   {{0x69c0d6d5,0xeb3407a7,0xfe6c0014,0x17c4ca0e}},	//   shoe, _سىرد, _دۯہ_, нгчи_, 
   {{0x69c0d6d6,0xb6040f91,0x00000000,0x00000000}},	//   phoe, znáš, --, --, 
   {{0x69c001ee,0x3ea4005b,0x79880042,0xe4a401c4}},	//   qhoe, älti_, _gaew, ероо, 
   {{0xdb04d6d7,0xb8d400fe,0x00000000,0x00000000}},	//   _fljó, _ছে_, --, --, 
   {{0xa3c814cf,0xe1f8000b,0x9470724c,0x00000000}},	//   रों_, ृष्ण_, اديا, --, 
   {{0xd48cd6d8,0x2694036b,0x44240175,0xefd80092}},	//   _өр_, _яшаё, sqm_, _ኮሪያ_, 
   {{0x75280395,0xa01802d2,0x00000000,0x00000000}},	//   ccez, dvör, --, --, 
   {{0x2408a99d,0x00000000,0x00000000,0x00000000}},	//   _енди_, --, --, --, 
   {{0x248400ca,0x6444151c,0xdec800a8,0xa018032e}},	//   _isom_, škis, публ_, fvör, 
   {{0x9e04729a,0xb6040118,0xa3c800cd,0x28d0012d}},	//   ечал, snáš, रोः_, _देसि, 
   {{0xf3f80356,0xb7b40051,0x00000000,0x00000000}},	//   ruţe_, _kịc, --, --, 
   {{0xa0185b00,0xf3f80356,0xdcec00ef,0xb41402d2}},	// [121b0] rvös, suţe_, _racē, _þúþa, 
   {{0xdcec0171,0x00000000,0x00000000,0x00000000}},	//   _sacē, --, --, --, 
   {{0xc0f80020,0x798831cf,0xb7b4004d,0x13e0015b}},	//   ለይም_, _paew, _lịc, _নীড়, 
   {{0x248401fa,0x629c0129,0x391406c2,0x7d1c02d0}},	//   _osom_, _àpou, نواز, _ugss, 
   {{0x63b80083,0x55c000fb,0xf770007b,0x00000000}},	//   kktn, ҫалғ, لاث_, --, 
   {{0x9a84d6d9,0x79880053,0xe10000fe,0x237c0200}},	//   _публ, _waew, _এলাহ_, jetj_, 
   {{0x2484d6da,0x7988d6db,0xdb04022a,0xd51401e1}},	//   _asom_, _taew, _kojí, _ọ̀t, 
   {{0xf3f001f2,0x798803ac,0x2cc406be,0xf9600133}},	//   wọ_, _uaew, _öpdü_, _ڕۆڵێ, 
   {{0x7528d6dc,0xdb04d6dd,0x73e40395,0xeab8010a}},	//   rcez, _mojí, коиз, _ейӳ_, 
   {{0xe7940583,0xb7b4004d,0x7bc4004d,0x9814007b}},	//   _لامک, _dịc, nhhu, _أبرا, 
   {{0x2484013f,0x9f8c03fa,0x70b8012c,0x161801ad}},	//   _esom_, _süß_, उन्ल, _पंटर_, 
   {{0x862400c0,0x00000000,0x00000000,0x00000000}},	//   _сьфе, --, --, --, 
   {{0x6444b2a7,0x628cd6de,0x6adc01f9,0x00000000}},	//   škir, åbor, _मश्र, --, 
   {{0xfd6800c7,0x628400b0,0x5ed00154,0x00000000}},	//   _tapỹ, ākor, _দুধে, --, 
   {{0xdb040308,0xa01801a8,0xfe7000f1,0x00000000}},	//   _bojí, tvör, یدې_, --, 
   {{0xdb040407,0x6be400d1,0x7cf40ca8,0x00000000}},	//   _cojí, ھكام, _ẹran, --, 
   {{0xab647e81,0xa02003ee,0xa0180008,0x744c001f}},	// [121c0] квал, şört, rvör, _በቁጥጥ, 
   {{0xa01843e5,0xe0d4005b,0xdfcc00f1,0xee24009d}},	//   svör, _швы_, _ويي_, _имоп, 
   {{0x7de40024,0xaf0400d4,0x00000000,0x00000000}},	//   sėsa, _шпол, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x63b8168c,0x6cd40150,0x28d000cd,0x00000000}},	//   yktn, _شقسا, _देशि, --, 
   {{0x7bc40bc9,0xd7f4011c,0x00000000,0x00000000}},	//   chhu, кущ_, --, --, 
   {{0x6924d6df,0xc7b80b4b,0x45d4010a,0xaa44030d}},	//   _амба, _niđe_, локс, _шевл, 
   {{0x2484d6e0,0x5e5400c8,0x96b40640,0xe85401d5}},	//   _psom_, דיקע_, ђују_, _لنرد, 
   {{0x785400e5,0x765c0055,0x00000000,0x00000000}},	//   _مینز_, _āsye, --, --, 
   {{0xda6c01d9,0x823c0092,0x00000000,0x00000000}},	//   _دُہ_, _የተረዳ, --, --, 
   {{0xd7ec0597,0x63b801a4,0x93a000ee,0x00000000}},	//   _بكل_, rktn, ршыд, --, 
   {{0xa5d85194,0xb6d800c8,0x24840070,0x9f5c0077}},	//   _غبار_, _אַנט, _tsom_, _árúa_, 
   {{0x64a4009d,0x00000000,0x00000000,0x00000000}},	//   _шада, --, --, --, 
   {{0x225c0254,0x00000000,0x00000000,0x00000000}},	//   putk_, --, --, --, 
   {{0xdb040118,0x00000000,0x00000000,0x00000000}},	//   _pojí, --, --, --, 
   {{0xdb0400d8,0xf3f80356,0x1314011a,0x00000000}},	//   _lojã, muţa_, _בחול_, --, 
   {{0xf3f80356,0x28d04709,0xd01000f1,0xe1fc00e5}},	// [121d0] luţa_, _देलि, صلې_, mló_, 
   {{0xe1fcd6e1,0x1ae400bd,0xf09002e4,0x629c0129}},	//   lló_, _করবে_, _פני_, _àpos, 
   {{0xf3f8054e,0xa3d8000d,0x00000000,0x00000000}},	//   nuţa_, _ठगन_, --, --, 
   {{0xe1fc00dd,0x7bc407d6,0xf77003e6,0xc95401ec}},	//   nló_, shhu, ڵات_, атшы, 
   {{0xe1fc00db,0xa3e00490,0xc9843ed6,0x00000000}},	//   iló_, नचा_, рухи, --, 
   {{0xf7700b73,0xe1fc00ae,0x00000000,0x00000000}},	//   صات_, hló_, --, --, 
   {{0x3618005b,0xe1fc00e5,0x00000000,0x00000000}},	//   нцию_, kló_, --, --, 
   {{0x7f440327,0x859400c7,0xa5f40114,0xe1fc00e5}},	//   _lehq, ашьц, леју_, jló_, 
   {{0xc7b808a4,0xe574d6e2,0x2450009f,0xe1fc00e5}},	//   _siđe_, узы_, منيس, dló_, 
   {{0x7f44047e,0xe4540022,0x00000000,0x00000000}},	//   _nehq, ыжь_, --, --, 
   {{0x7c9402d3,0xf3f8054e,0x716807a5,0x00000000}},	//   _ሃዋህው_, guţa_, нанг_, --, 
   {{0xe1fcd6e3,0x00000000,0x00000000,0x00000000}},	//   gló_, --, --, --, 
   {{0x7bd4d6e4,0xe9e400ae,0x00000000,0x00000000}},	//   _omzu, íúil_, --, --, 
   {{0xe1fc0407,0x2450d6e5,0xa44001c6,0x00000000}},	//   aló_, _انوس, _уншд, --, 
   {{0xe1fcd6e6,0x7f44036b,0xf3f80311,0x00000000}},	//   bló_, _dehq, cuţa_, --, 
   {{0x7bd416cc,0xe1fc00db,0x00000000,0x00000000}},	//   _amzu, cló_, --, --, 
   {{0xeb980588,0xdca0d6e7,0xa3c86b9b,0x629ca547}},	// [121e0] ниа_, бати, रोक_, _àpor, 
   {{0x7640035a,0x7ae00419,0x00000000,0x00000000}},	//   _owly, _žlta, --, --, 
   {{0x290002f0,0x00000000,0x00000000,0x00000000}},	//   _úkaz_, --, --, --, 
   {{0x7bd40921,0x6da4d6e8,0x28e8113e,0x2868030d}},	//   _emzu, _сима, ндеп_, ерко_, 
   {{0x6d44005f,0x7f44014b,0x47440022,0x00000000}},	//   _ieka, _yehq, иҭаг, --, 
   {{0x6d44d6e9,0xe72800f1,0xc7b0009f,0x5fa401f9}},	//   _heka, رستو_, تّت_, खायल, 
   {{0x6d44d6ea,0xe1fc0429,0x7790030f,0x00000000}},	//   _keka, yló_, تیلا, --, 
   {{0x6d44d6eb,0x7c28031c,0xb864d6ec,0xebe401f0}},	//   _jeka, _ħerz, _چالو, _роҳп, 
   {{0x6b8cd6ed,0x76400857,0x81b40183,0xb86474d7}},	//   _kabg, _ewly, ছোঁ_, _نالو, 
   {{0x1ae40d42,0x6d44d6ee,0x4274d6ef,0x7790d6f0}},	//   _করতে_, _leka, агос, _وینا, 
   {{0xd3740598,0xb34406ed,0x6d44d6f1,0x6b8c0099}},	//   учы_, _seçã, _oeka, _mabg, 
   {{0x6d44d6f2,0xdb0400e4,0xd254d6f3,0x6b8c00b5}},	//   _neka, _jojá, ыць_, _labg, 
   {{0x1074276f,0xdb040789,0xe1fcd6f4,0xf3f8054e}},	//   бляю, _mojá, rló_, suţa_, 
   {{0x6d440069,0x7f44047e,0xa0240254,0xdb040aa6}},	//   _aeka, _qehq, _amöö, _lojá, 
   {{0xdd980efb,0x64400810,0xe1fc01d3,0x00000000}},	//   нша_, _hwoi, pló_, --, 
   {{0x6d44d6f5,0x62880003,0x64400099,0x9cc8010b}},	//   _ceka, _isfo, _kwoi, ныза_, 
   {{0x6d440c67,0x629c0077,0x7f44047e,0x5ce40212}},	// [121f0] _deka, _ápob, _tehq, уюва, 
   {{0x6d44d6f6,0x7eb80022,0x64400076,0xdd900220}},	//   _eeka, _агос_, _mwoi, шағы, 
   {{0x6d4408f5,0x62880175,0x26d86abf,0xdb0401ef}},	//   _feka, _jsfo, úpol_, _bojá, 
   {{0x6d44d6f7,0xbdc0030c,0x00000000,0x00000000}},	//   _geka, _بەرۋ, --, --, 
   {{0xb7b4063f,0x3dc8d6f8,0x386c00d8,0x00000000}},	//   _dịn, mhaw_, _qqer_, --, 
   {{0x3f900c11,0x62880158,0x6b8c757e,0x9f5c020c}},	//   ndzu_, _osfo, _gabg, èrèd_, 
   {{0x62881529,0xb6f800d1,0x00000000,0x00000000}},	//   _nsfo, خىغا_, --, --, 
   {{0x6b8c0198,0x64401368,0x3dc8016b,0x8a180d33}},	//   _zabg, _bwoi, nhaw_, _босс_, 
   {{0x6b8c49cd,0x62880334,0x49903b93,0x00000000}},	//   _yabg, _asfo, _ریور, --, 
   {{0x64408689,0xd84c01f2,0xe3b4d6f9,0x785401d3}},	//   _dwoi, nọmi_, ибы_, _میچز_, 
   {{0x3dc80589,0xc32c1b56,0xdb0401d3,0xa018002f}},	//   khaw_, رەي_, _eljö, rwöl, 
   {{0xf4d81cd1,0xe4d403e6,0x6aa8b1e1,0xa24401d3}},	//   _имеш_, اویت_, äffi, جیٹل_, 
   {{0x6288d6fa,0x30746418,0x3dc8c284,0x2bf800cd}},	//   _esfo, шунс, dhaw_, ्तमं_, 
   {{0x6d44d6fb,0x7fd401ec,0x00000000,0x00000000}},	//   _seka, бісі, --, --, 
   {{0x6b8cbe52,0x629c00d8,0x7ae000d7,0x00000000}},	//   _rabg, _àpop, _žltn, --, 
   {{0x3dc84cd3,0x6b8cd6fc,0xefbc001f,0xdee00212}},	//   ghaw_, _sabg, ሰቢያ_, іоти, 
   {{0xec149f5f,0x6d44d6fd,0xab280414,0x5c8c02d3}},	// [12200] لورد, _veka, воза_, _ዘካየዶ_, 
   {{0x6d44d6fe,0x6b8cd6ff,0x3dc80009,0x320000d7}},	//   _weka, _qabg, ahaw_, llky_, 
   {{0xa924d700,0xed58d701,0x7fe8a3a9,0xa3c8a1fa}},	//   адел, _ион_, _حريف_, रोट_, 
   {{0x3dc8d702,0x6d44394e,0x3ea403cd,0x00000000}},	//   chaw_, _ueka, ålte_, --, 
   {{0xd84c01f2,0xdb04d703,0x765c002b,0x00000000}},	//   lọji_, _vojá, _āsya, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6440006d,0xdb0401ed,0x1ae0084c,0xf7480035}},	//   _swoi, _tojá, _дорм, اجهه_, 
   {{0x2d90d704,0xd5b4d705,0x32000419,0x95340395}},	//   ndye_, исы_, jlky_, азът_, 
   {{0x3a2c0427,0x00000000,0x00000000,0x00000000}},	//   _čepi_, --, --, --, 
   {{0x32000419,0x628800d7,0x00000000,0x00000000}},	//   elky_, _psfo, --, --, 
   {{0x58f0025c,0x9f400240,0xd5ac00ec,0x00000000}},	//   _བཙོས_, snjë_, _ڪفن_, --, 
   {{0x6440068f,0xf1d047b8,0xa3c81b87,0x5bc000cd}},	//   _twoi, दोलन, रोज_, _षत्व, 
   {{0x4394d706,0xd20801c0,0xd464009b,0x00000000}},	//   _галс, рээд_, _виче_, --, 
   {{0x4fc4d707,0xdfd802e8,0x94c8004b,0x14d40677}},	//   осса, тъм_, _جامې_, _דודל_, 
   {{0x3dc8d708,0x245001ed,0x217402dd,0x3200013a}},	//   thaw_, _انڈس, _ұйқы_, blky_, 
   {{0x3dc8079b,0x8d7400f7,0x3eac0841,0x7ae00419}},	//   uhaw_, ياقا, ćet_, _žlto, 
   {{0x26e00034,0x4c94034b,0x58f0031c,0xa3d800e1}},	// [12210] गपुर_, оитс, _བཙེས_, _ठगा_, 
   {{0x3dc80070,0x5c8c02d3,0xde6400a7,0x2fc80175}},	//   shaw_, _ዘካይዶ_, _къмп, chbg_, 
   {{0x20000bb8,0x95240867,0x3a740209,0x3dc8d709}},	//   mlji_, _ལྔའི_, слер, phaw_, 
   {{0x6284068f,0x2000025c,0x00000000,0x00000000}},	//   łkow, llji_, --, --, 
   {{0xb4e4033f,0x4c94013d,0xdcec00ef,0x9cc8d70a}},	//   _नशे_, _дияс, _macī, _рына_, 
   {{0x7c2cd70b,0x26e00490,0x4e9401d5,0xfbc401c8}},	//   mqar, गपूर_, _اشیر, _ايسٽ, 
   {{0x7c2c006c,0x200001fa,0x683c0092,0x00000000}},	//   lqar, ilji_, _ይደርስ, --, 
   {{0x77bc0137,0xc7b807f5,0x46d80316,0x7c2c20ac}},	//   _mèxi, _viđa_, _भइरह, oqar, 
   {{0x825476e2,0x77bc00cf,0xd344036b,0x7c2cd70c}},	//   _መሰረታ, _lèxi, لیشه_, nqar, 
   {{0x29e80115,0xb42c0240,0x00000000,0x00000000}},	//   nĝan_, _ተባሂሉ, --, --, 
   {{0x7c2c7ca1,0xdb040200,0x320000d7,0x00000000}},	//   hqar, _dojç, tlky_, --, 
   {{0xd54001e1,0x7c2c0309,0x00000000,0x00000000}},	//   _dẹ̀d, kqar, --, --, 
   {{0xe3ac6d64,0xed5801b9,0x20000427,0x68280092}},	//   _еб_, ғоз_, flji_, ስፖርት, 
   {{0x7c2c02b9,0x20000010,0xdb040200,0xa018002f}},	//   dqar, glji_, _gojç, nwöh, 
   {{0xada41e28,0x6da453e9,0x7c2c0140,0x00000000}},	//   бавл, бива, eqar, --, 
   {{0xb144084c,0xefb0036b,0xdb04007c,0xceb800c7}},	//   _унил, _کیسگ, _mojä, гәҭ_, 
   {{0xdca04443,0x7c2c0194,0xda6c0050,0x7c640116}},	// [12220] пати, gqar, ہُل_, قالل, 
   {{0x6f640b3e,0x20000010,0x09e008a3,0x00000000}},	//   _увоз, clji_, पच्य, --, 
   {{0x7c2c0eda,0x161407c1,0x00000000,0x00000000}},	//   aqar, दगार_, --, --, 
   {{0x7c2c0009,0x3cf00037,0xdd9c0419,0x00000000}},	//   bqar, _अँचइ_, áňte_, --, 
   {{0x28d02765,0xfbd001ed,0x692400c7,0x00000000}},	//   _देखि, ستے_, амҵа, --, 
   {{0x20780a1e,0x00000000,0x00000000,0x00000000}},	//   ראסא, --, --, --, 
   {{0x9984000a,0x2b489c8f,0xe66421f3,0xf1c8013a}},	//   šiši_, _iebc_, ётко, _znáš_, 
   {{0x45b80580,0xa77402dd,0x00000000,0x00000000}},	//   ргию_, _ﹼﺤﺩﺓ_, --, --, 
   {{0x69c0257c,0x200003b2,0x5efc012d,0x00000000}},	//   mkoe, ylji_, _शुन्_, --, 
   {{0x66e4d70d,0x69c0d70e,0xdcec005f,0x2bf800dc}},	//   _лоза, lkoe, _sacī, ्तिं_, 
   {{0xd5acd70f,0x20008e70,0xc204033f,0x69c0005a}},	//   _ес_, vlji_, रतलब_, okoe, 
   {{0x69c0d710,0x9c800024,0x92540c9e,0x7c2c01d5}},	//   nkoe, ščiu, щают_, yqar, 
   {{0x10744e0c,0x69c0005a,0x2bf800dc,0xdcec0055}},	//   пляю, ikoe, ्तां_, _vacī, 
   {{0x2d9c016b,0x8f343246,0x09b0031c,0xf3f401d5}},	//   _ɔtee_, зерц, ནྡྷ_, _وتوک, 
   {{0x7de40006,0x7c2c03f0,0x850401c8,0xf8a40acd}},	//   lėsi, wqar, _اوڇن, _खप्प, 
   {{0x1ae400bd,0x7c2cd711,0x9254d712,0x91e40114}},	//   _করলে_, tqar, _اشور_, _ноје, 
   {{0x7c580075,0x2000098d,0x22ac03be,0x7de40153}},	// [12230] شلار_, plji_, dəki_, nėsi, 
   {{0x7c2cd713,0x69c0257c,0x2b480332,0xbed80108}},	//   rqar, ekoe, _cebc_, _вдох_, 
   {{0x7c2cd714,0xf9d401c0,0x29e8010f,0x22ac03e3}},	//   sqar, оожэ, rĝan_, fəki_, 
   {{0x3948d715,0x69c00af9,0x7de40153,0x5fa472a2}},	//   úas_, gkoe, kėsi, खावल, 
   {{0x7c2cd716,0x0a58013e,0xf8640212,0xa018002f}},	//   qqar, _қатъ_, івко, twöh, 
   {{0x7de40024,0x69c001c4,0xb6a4d717,0x6abc002f}},	//   dėsi, akoe, жикл, bypf, 
   {{0xa01803fa,0x629c1151,0x588400c7,0x22ac06be}},	//   rwöh, _špon, рыҵа, bəki_, 
   {{0x69c00036,0x22ac03e3,0xc0d40092,0x00000000}},	//   ckoe, cəki_, ጨርስ_, --, 
   {{0xb3c8084c,0x7de400c0,0x00000000,0x00000000}},	//   илиз_, gėsi, --, --, 
   {{0xd7f8d718,0xd7742309,0x58d0014b,0x00000000}},	//   _суб_, _دارع, _доғт, --, 
   {{0xa920032e,0x00000000,0x00000000,0x00000000}},	//   _áþri, --, --, --, 
   {{0xb1d802bf,0x7de40153,0x00000000,0x00000000}},	//   рьох_, bėsi, --, --, 
   {{0x09b0025c,0x98ac0024,0xa6e003b2,0xf3f80356}},	//   ནྡྲ_, ragė_, _áðru, arţa_, 
   {{0xee38d719,0x69c0d71a,0x00000000,0x00000000}},	//   инг_, zkoe, --, --, 
   {{0x611000b8,0xc0e80092,0x69c001f4,0x00000000}},	//   _aślī, _መዋል_, ykoe, --, 
   {{0xace8d71b,0x6cc414a8,0x802412ea,0xa154009b}},	//   амба_, ойба, _کريم, _даћу_, 
   {{0x6b54007b,0x43d40345,0x00000000,0x00000000}},	// [12240] قضائ, _بزۆز, --, --, 
   {{0xb7b401f2,0x40940395,0x5ba400cf,0x00000000}},	//   _dịk, _хрът, окум_, --, 
   {{0x49a40046,0x69c0057b,0xdcfc00e2,0x00000000}},	//   зылғ, tkoe, īvāk, --, 
   {{0x609401ed,0x6278008f,0x69c00af9,0x3e040153}},	//   _انیس_, ינענ, ukoe, _няўв, 
   {{0x69c02ad4,0x984402e8,0x0734187f,0x00000000}},	//   rkoe, ояща_, пелю, --, 
   {{0x69c0d71c,0xa0980bd9,0x7de40024,0xaa440a0e}},	//   skoe, יינט, vėsi, _мегл, 
   {{0xe66400d3,0x00000000,0x00000000,0x00000000}},	//   ітко, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x58f049a6,0x7ccc022e,0xe7a800f3,0x00000000}},	//   _བཙགས_, _kўra, _квал_, --, 
   {{0x7de40006,0x48c40166,0x00000000,0x00000000}},	//   rėsi, _мәһа, --, --, 
   {{0xab6003e0,0x5a280240,0x15b401c4,0x00000000}},	//   çüyo, _እነተኾ, свөө_, --, 
   {{0x69c8036e,0xb0a40037,0x7ae000d7,0x82540023}},	//   ëfeh, खमंग, _žltk, _መደረታ, 
   {{0x8438007b,0x84c42abf,0x00000000,0x00000000}},	//   _اكتر_, _хәйд, --, --, 
   {{0xe2a80133,0x0ce400cc,0x00000000,0x00000000}},	//   _نابن_, _মৰ্ত, --, --, 
   {{0x25a44fa5,0xe4340451,0xb60402f0,0x00000000}},	//   _knol_, _ايڪڙ_, siáš, --, 
   {{0x8d8401c6,0x00000000,0x00000000,0x00000000}},	//   мууд, --, --, --, 
   {{0xaa940131,0x00000000,0x00000000,0x00000000}},	// [12250] үгуә, --, --, --, 
   {{0x9f400407,0x00000000,0x00000000,0x00000000}},	//   rojó_, --, --, --, 
   {{0x58f00156,0xbdc00150,0x1cac0327,0x321001f4}},	//   _བཙངས_, _كەسۋ, ནདང_, _yhyy_, 
   {{0x3d88177a,0x00000000,0x00000000,0x00000000}},	//   _احدی_, --, --, --, 
   {{0x23c80490,0x629c01a6,0x80c800eb,0x00000000}},	//   िसाद, _špol, রপক্, --, 
   {{0x29e800df,0xd36001c4,0x00000000,0x00000000}},	//   nĝaj_, _гvйц, --, --, 
   {{0x7bc4124c,0x6fc087e1,0x2bf80b9c,0x1dbc716d}},	//   mkhu, _dôch, ्तरं_, _एकात, 
   {{0xfbac0154,0x00000000,0x00000000,0x00000000}},	//   _গতিত, --, --, --, 
   {{0x7bc4771d,0x81c000fe,0x00000000,0x00000000}},	//   okhu, ংফা_, --, --, 
   {{0x7bc4d71d,0x394cd71e,0x25a4d71f,0x47340214}},	//   nkhu, _hees_, _enol_, _قرمز, 
   {{0x7bc4d720,0xf3f80311,0x629c01ed,0x00000000}},	//   ikhu, nuţi_, _ápol, --, 
   {{0xdeb8069c,0x394c1368,0x7bc40649,0xdb0401e1}},	//   ኰነን_, _jees_, hkhu, _bojú, 
   {{0x394cd721,0xf8bcd722,0x628c01bf,0x6298d723}},	//   _mees_, ्निय, æbor, avto, 
   {{0x394cd724,0xdb040248,0x7bc4d725,0x2d9c0139}},	//   _lees_, _dojú, jkhu, _şte_, 
   {{0xb7bc0311,0xad581ebb,0x42a00023,0x00000000}},	//   _cuţi, йрах_, _ውጺኢት_, --, 
   {{0x394cd726,0xb7b401f2,0x7bc4d727,0xdb040248}},	//   _nees_, _dịi, ekhu, _fojú, 
   {{0xafe4d728,0x00000000,0x00000000,0x00000000}},	// [12260] _ноил, --, --, --, 
   {{0xa098008d,0x116800f2,0x00000000,0x00000000}},	//   _פייט, _الکی_, --, --, 
   {{0x394c1574,0xc7b807f5,0x59c40118,0x00000000}},	//   _bees_, _rođ_, लसंर, --, 
   {{0xa968d729,0x7bc40652,0x394cd72a,0xdb0401e1}},	//   сида_, akhu, _cees_, _yojú, 
   {{0x394cd72b,0x7bc40218,0x2744001f,0x18641d1c}},	//   _dees_, bkhu, _ያቀረበ, зачи_, 
   {{0x6e241c06,0x2bf405f5,0x25b00368,0x25a401f5}},	//   _hikb, _хямр, _ŵyl_, _snol_, 
   {{0xf3f80311,0x394cd72c,0x2cb00356,0x461402f2}},	//   cuţi_, _fees_, ţadă_, ووتر, 
   {{0x394cd72d,0x77bc067c,0x6e240003,0x00000000}},	//   _gees_, _sèxt, _jikb, --, 
   {{0x6e24037e,0xd4940276,0xf8ac0633,0x06a000d1}},	//   _mikb, прэ_, _نکو_, _ﺋﯧﻨﯩ, 
   {{0x6024004a,0x26080490,0xdb0400e4,0x7de40064}},	//   hémè, ातही_, _rojú, lėst, 
   {{0x394cd72e,0xdb0401e1,0x94701a37,0x00000000}},	//   _yees_, _sojú, ودیا, --, 
   {{0x394cd72f,0x25a400a9,0xdce809a8,0x7de40153}},	//   _xees_, _unol_, _žičn, nėst, 
   {{0x77bc2508,0x6600d730,0xf3f80311,0x7bc40113}},	//   _tèxt, _ikok, zuţi_, ykhu, 
   {{0xb7bc00a8,0xa940001f,0x62980175,0x22980171}},	//   _puţi, _ይጠበቅ, pvto, _tīk_, 
   {{0x660002ea,0x6e24d731,0x29e8010f,0x00000000}},	//   _kkok, _bikb, rĝaj_, --, 
   {{0x7bc40649,0xdb0401e1,0x00000000,0x00000000}},	//   wkhu, _tojú, --, --, 
   {{0x394cd732,0x6600d733,0x6e24017a,0x7de40024}},	// [12270] _rees_, _mkok, _dikb, dėst, 
   {{0x60cc2c70,0xe1fc0270,0x6e240162,0x394cd734}},	//   ınmı, loó_, _eikb, _sees_, 
   {{0x6600d735,0x394c5952,0x6aa801e3,0x00000000}},	//   _okok, _pees_, äffp, --, 
   {{0x660006e4,0x394c0211,0xe0dc007f,0x00000000}},	//   _nkok, _qees_, baòt_, --, 
   {{0x394cd736,0xf3f8054e,0xee940133,0xee4400c7}},	//   _vees_, suţi_, _فدێک, ñýva_, 
   {{0x394cd737,0x6600d738,0x8c540724,0xf3f80356}},	//   _wees_, _akok, şäüç, puţi_, 
   {{0x99640276,0xe1fc00e8,0x394c045a,0xedb40133}},	//   _нтал, koó_, _tees_, _رجێک, 
   {{0xe1fc0077,0x05340023,0x00000000,0x00000000}},	//   joó_, _ኣበርኪ, --, --, 
   {{0x85548117,0x57240050,0x00000000,0x00000000}},	//   ریور_, _فراق, --, --, 
   {{0x66003d81,0xd240036b,0x00000000,0x00000000}},	//   _ekok, нмоқ, --, --, 
   {{0x66000270,0x2bac041c,0xd20400cf,0x00000000}},	//   _fkok, घाता, нүкк, --, 
   {{0x3f800055,0x71d80212,0x45d4014b,0x00000000}},	//   _abhu_, ієнт_, _похс, --, 
   {{0x6e24025c,0x26080490,0x00000000,0x00000000}},	//   _rikb, ातरी_, --, --, 
   {{0x01e4010b,0x741414af,0x00000000,0x00000000}},	//   _үйшү, _غوغا, --, --, 
   {{0x7c3c0857,0xed587ce9,0x660002d0,0xe80c08f2}},	//   _atsr, жоб_, _ykok, ितता_, 
   {{0x7e602242,0xdb045ab3,0xdcec03e3,0x00000000}},	//   álpa, _injè, _ancı, --, 
   {{0x06a00075,0x72a40014,0x1d040640,0x6e2401e3}},	// [12280] _ﺋﯧﻠﯩ, _رٕکن, дети_, _vikb, 
   {{0x6e240de2,0xdcac14fb,0x00000000,0x00000000}},	//   _wikb, جىك_, --, --, 
   {{0x49642de5,0xefc4001f,0x6e240003,0x00000000}},	//   енең, ቸኳይ_, _tikb, --, 
   {{0xb9e415bf,0x629c00c0,0xdb2000b8,0x00000000}},	//   ىسنى, _špok, _ũrãm, --, 
   {{0x6d581f4c,0x00000000,0x00000000,0x00000000}},	//   _ētah, --, --, --, 
   {{0xae0401ec,0xa0180112,0x00000000,0x00000000}},	//   _ءوڭى, lwör, --, --, 
   {{0x66000263,0x26080490,0x00000000,0x00000000}},	//   _pkok, ातली_, --, --, 
   {{0xa018002f,0x00000000,0x00000000,0x00000000}},	//   nwör, --, --, --, 
   {{0xa80000e4,0x00000000,0x00000000,0x00000000}},	//   _áñov, --, --, --, 
   {{0x17800b2b,0x255c063f,0xa018ad1c,0x82d80276}},	//   _игум, ịl_, hwör, здос_, 
   {{0xe1fc0093,0x200c0024,0x6674a9de,0x61ec0df4}},	//   toó_, _ūgio_, _زدار, éblo, 
   {{0x7dd0b529,0xf6682a14,0x6600d739,0x00000000}},	//   _kåse, _رحمه_, _ukok, --, 
   {{0x58f00327,0xf77001d3,0x9390032f,0x00000000}},	//   _བཙབས_, _جاۓ_, رجیا, --, 
   {{0x9f40044e,0x645c04fe,0x7dd012e8,0x623000c7}},	//   mijë_, _āpih, _måse, _иҵоу, 
   {{0x7dd08076,0xe1fc0270,0x3e180276,0x24800327}},	//   _låse, poó_, зовэ_, ħkmu_, 
   {{0xa01803fa,0xf2c41cb8,0xa1840006,0x22ac06be}},	//   gwör, _ясін, _цыкл, bəkr_, 
   {{0x0e080139,0x00000000,0x00000000,0x00000000}},	// [12290] фэри_, --, --, --, 
   {{0x6e3c0022,0x4ba80137,0xefec0092,0xd9c407af}},	//   _ftpb, мөсү_, ቀቀው_, लस्ट, 
   {{0x61ec0010,0x9f40036e,0xee440022,0x00000000}},	//   oncl, hijë_, ñýta_, --, 
   {{0x6eac0316,0x7f540789,0x67388060,0xca7400d1}},	//   ीहरु, lazq, _aftj, ئالغ, 
   {{0x7c3c00b8,0x00000000,0x00000000,0x00000000}},	//   _utsr, --, --, --, 
   {{0xc3141c82,0x7dd0037e,0x00000000,0x00000000}},	//   _সলনি_, _dåse, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x24840263,0x7dd00158,0xa2a02894,0xc6d401b9}},	//   _bpom_, _håsb, गिन्, ختهت, 
   {{0x7dd02ab7,0x0efc4eae,0x885801d5,0x391400d8}},	//   _gåse, _एड्स_, _оитс_, _чмар, 
   {{0xb7bc0356,0x00000000,0x00000000,0x00000000}},	//   _puţu, --, --, --, 
   {{0x3dc80135,0x03940006,0x00000000,0x00000000}},	//   kkaw_, трыя, --, --, 
   {{0xe2942e01,0x7dd0795b,0x00000000,0x00000000}},	//   хаю_, _låsb, --, --, 
   {{0x3dc8031c,0x00000000,0x00000000,0x00000000}},	//   dkaw_, --, --, --, 
   {{0x6e3c00b5,0xe454010f,0x6fb40101,0xd3440133}},	//   _ptpb, _טינט_, رمزا, _تیده_, 
   {{0xf8bc038e,0xfe7800c0,0x00000000,0x00000000}},	//   ्नुप, мёты_, --, --, 
   {{0x160c179f,0x00000000,0x00000000,0x00000000}},	//   ातिर_, --, --, --, 
   {{0x2bc8d73a,0x320005da,0x61fc02d2,0xe47800df}},	// [122a0] плап_, moky_, _ípla, ּרעכ, 
   {{0x320071ee,0x7dd005ac,0x7c38033f,0x00000000}},	//   loky_, _råse, _żaró, --, 
   {{0x160c1dd1,0x7dd00267,0x5a280327,0x00000000}},	//   ातार_, _såse, _སྤྱེ_, --, 
   {{0x320005da,0x7dd001e3,0x2ca00175,0x3ea45522}},	//   noky_, _påse, _trkd_, ælte_, 
   {{0xefd400b7,0x888412ea,0x58340212,0xa9e000f1}},	//   _ያሬድ_, ضیان, езія_, نګړن, 
   {{0xec14005e,0x7dd00fac,0x9f400240,0x3b840022}},	//   _سوزد, _gåsb, vijë_, _иҩуп_, 
   {{0xe5c448ec,0x3200d73b,0x24840200,0x6a84013d}},	//   еспо, koky_, _spom_, _ялва, 
   {{0x6d54d73c,0x39482242,0x5a28025c,0x32000109}},	//   naya, ðast_, _སྤྲེ_, joky_, 
   {{0x186403b7,0x32000109,0x6d5400b5,0x00000000}},	//   _пати_, doky_, iaya, --, 
   {{0x9f400023,0x36440131,0x00000000,0x00000000}},	//   rijë_, رىۋې, --, --, 
   {{0x6d54d73d,0xb9cc044e,0xd25402bf,0x81d40818}},	//   kaya, _ሰበ_, нця_, вонх, 
   {{0x6d54d73e,0x61ec05d5,0xf608006c,0xe61800ee}},	//   jaya, uncl, _قتنه_, _эде_, 
   {{0x1ae403f4,0x6d54d73f,0xe5140316,0x0cbc07f7}},	//   _করছে_, daya, देखि_, ोनोम, 
   {{0xe7f4012c,0x3dc8d740,0xfdc81157,0xd494011a}},	//   इवटा_, wkaw_, रस्फ, _נכות_, 
   {{0x6d54a297,0x32002f4a,0x1ee4d741,0xbf1000d1}},	//   faya, boky_, روری_, рүнә, 
   {{0x6d54d742,0x00000000,0x00000000,0x00000000}},	//   gaya, --, --, --, 
   {{0xbc780a89,0x3dc8d743,0x00000000,0x00000000}},	// [122b0] ьбах_, rkaw_, --, --, 
   {{0xe7e0012c,0xb67400b8,0x00000000,0x00000000}},	//   कोमा_, _ūḍha, --, --, 
   {{0x3a7409a5,0x6d54d744,0x2000a65f,0x2e340022}},	//   тлер, baya, moji_, _аҧсы_, 
   {{0x6d54d745,0x5ce4030d,0xe9f000c7,0x00000000}},	//   caya, _зюга, аҧсы, --, 
   {{0xa0180008,0x1ac000eb,0x5f5c0023,0x00000000}},	//   rtöf, ্পো, _ንምሕጸ, --, 
   {{0xfd540055,0xa018d746,0x2000d747,0x320006d9}},	//   _aheḷ, stöf, noji_, zoky_, 
   {{0x34c81b61,0x1adc00cc,0x00000000,0x00000000}},	//   िन्द, _বুৰা, --, --, 
   {{0x20000451,0xdb0400a2,0x00000000,0x00000000}},	//   hoji_, _mojü, --, --, 
   {{0x2000d748,0x99840024,0x320006d9,0x4c040014}},	//   koji_, ūnų_, voky_, _شِہل, 
   {{0x2000d749,0xf4280327,0x00000000,0x00000000}},	//   joji_, སམེད_, --, --, 
   {{0x6d54d74a,0x32000851,0x7168036b,0x2000d74b}},	//   yaya, toky_, манг_, doji_, 
   {{0x6d5401d9,0x7fd402dd,0x00000000,0x00000000}},	//   xaya, ңірі, --, --, 
   {{0x3200d74c,0x6d54d74d,0xdb0400c7,0x85440209}},	//   roky_, vaya, _kojó, _сэхе, 
   {{0x6d54d74e,0x20000f72,0xe0dc180f,0xa8540375}},	//   waya, goji_, mbòl_, כישה_, 
   {{0xa3d42232,0x77600393,0x320005da,0x0cbc146b}},	//   _सतत_, _mdlx, poky_, ोन्म, 
   {{0xac9807d6,0xbc2406ba,0xeab004f2,0xd3440345}},	//   ونزا_, ۇرلى, یعا_, _تیگه_, 
   {{0xeb98d74f,0xe0dc033b,0xf8bc00cd,0x62180677}},	// [122c0] миа_, nbòl_, ्नोप, _קופק, 
   {{0x600407d8,0xaec4a267,0x200000b5,0x7640010b}},	//   _иным_, _абол, coji_, _otly, 
   {{0xc0a82c1f,0x4ec40139,0x00000000,0x00000000}},	//   _قایل_, _синң, --, --, 
   {{0x5e5404ac,0xe8e8d750,0x6d54d751,0x28e81075}},	//   _ביטע_, ммед_, qaya, мдеп_, 
   {{0x7640373e,0xe80c0490,0xa134008f,0x3af40150}},	//   _atly, ितला_, דאנק_, _ұятс, 
   {{0x6a84036b,0x4918000d,0x00000000,0x00000000}},	//   _илга, बेगो_, --, --, 
   {{0xd6cc30d6,0x386801ab,0x439400d1,0x6994c7c3}},	//   يقه_, àarr_, қанс, _ирах, 
   {{0x34400092,0x00000000,0x00000000,0x00000000}},	//   _የነዋሪ, --, --, --, 
   {{0xa9048bee,0xc7b800f3,0xe738d752,0x3948056a}},	//   _شبرن, _siđu_, _жез_, ñase_, 
   {{0x4394026a,0x7dd0050a,0x7c280115,0x20000200}},	//   ћанс, _måsa, _ɨero, xoji_, 
   {{0x7dd04cab,0xf4b400cf,0x66800345,0x00000000}},	//   _låsa, _ەشىگ, _ئیعل, --, 
   {{0x386884c4,0x00000000,0x00000000,0x00000000}},	//   šare_, --, --, --, 
   {{0x2000d753,0xa49002f2,0xd62400c0,0x00000000}},	//   toji_, _ئیخت, _роце_, --, 
   {{0xa3d40882,0xe6b40316,0x6440d754,0x3f8420be}},	//   _सति_, _अपाङ, _itoi, ýlu_, 
   {{0x9e0410f5,0x2000388e,0xdd980046,0x29e8008f}},	//   вчал, roji_, мша_, nĝas_, 
   {{0x6288d755,0x7dd00158,0x200022da,0x29e8010f}},	//   _ipfo, _båsa, soji_, iĝas_, 
   {{0xa3d41fe5,0x7ccc022e,0x200002f0,0xc2100014}},	// [122d0] _सता_, _kўri, poji_, _پٔک_, 
   {{0xe81000e1,0x20000213,0x00000000,0x00000000}},	//   _ढीला_, qoji_, --, --, 
   {{0x65600030,0x3f90d756,0xe0dc02e2,0x37c40124}},	//   _odoh, mezu_, zbòl_, қәаб, 
   {{0x6440d757,0x6560035b,0x3f9002f0,0xa0180267}},	//   _otoi, _ndoh, lezu_, stöd, 
   {{0x764000b5,0x37881d16,0x00000000,0x00000000}},	//   _stly, ебло_, --, --, 
   {{0x6288d758,0x656000f2,0xdd8c01c8,0x00000000}},	//   _opfo, _adoh, _اوڏ_, --, 
   {{0x64407801,0x06540006,0x387c0042,0x00000000}},	//   _atoi, атыў, stwr_, --, 
   {{0xd8b400dd,0x3f90d759,0xd1d402d3,0x6560036e}},	//   _لگتا_, hezu_, _ያፌት_, _cdoh, 
   {{0x3f9005f5,0x00000000,0x00000000,0x00000000}},	//   kezu_, --, --, --, 
   {{0x3a2c001e,0x645c0374,0x3f900841,0x644000ae}},	//   _hiep_, _āpit, jezu_, _dtoi, 
   {{0x6440d75a,0x3f90d75b,0x3a2cd75c,0x76405243}},	//   _etoi, dezu_, _kiep_, _utly, 
   {{0xd6241001,0x06dc0154,0x64400200,0x453401a9}},	//   _شعاي, _ঢুকি, _ftoi, _кхшт, 
   {{0x3a2c3a65,0xfee000fe,0x846800dc,0x629c01ef}},	//   _miep_, _মুলধ, _hṛṣṭ, _špot, 
   {{0x3a2c0196,0xb9cc001f,0x62880fac,0x69d80024}},	//   _liep_, _ሰጠ_, _fpfo, _įtem, 
   {{0xe7f41bcf,0x9c1001e1,0x71a4d75d,0x00000000}},	//   ेवता_, _pọnn, _байз, --, 
   {{0xa01800dd,0x7dd0d75e,0x8468002b,0xfd64009d}},	//   gtöb, _påsa, _mṛṣṭ, инсү, 
   {{0x2ca40332,0x00000000,0x00000000,0x00000000}},	// [122e0] íod_, --, --, --, 
   {{0x6288010a,0x5efc00e1,0x3f9001f0,0xeaf80b38}},	//   _ypfo, _शुक्_, cezu_, ىرات_, 
   {{0xed58d75f,0x2988d760,0x3a2c0166,0x26f00073}},	//   _пон_, есло_, _biep_, _अखेर_, 
   {{0x3a2c0399,0xe8f8b2ee,0x2d940108,0x00000000}},	//   _ciep_, нле_, _срос, --, 
   {{0x2d90b3f2,0x3a2cd761,0xa01801f4,0x00000000}},	//   meye_, _diep_, stöe, --, 
   {{0x2d90d762,0xdcec00dc,0x00000000,0x00000000}},	//   leye_, _uccā, --, --, 
   {{0x6440d763,0x3a2c04cc,0xa968d764,0xb7640212}},	//   _stoi, _fiep_, _пива_, ртій, 
   {{0x2d90d4a7,0x84680a28,0xa3d411b1,0xa2a01d8a}},	//   neye_, _dṛṣṭ, _सतह_, गिस्, 
   {{0x3f908f96,0x18a001f0,0x00000000,0x00000000}},	//   yezu_, _латм, --, --, 
   {{0x2d9001b2,0x3a2c04cc,0x66d8994d,0xdcec04a7}},	//   heye_, _ziep_, _пьер_, šeće, 
   {{0x2d90d765,0x3f900b91,0x3a2c0369,0xddc40010}},	//   keye_, vezu_, _yiep_, hujš, 
   {{0xf65000f8,0x3f90014b,0x2d900790,0x64400332}},	//   _گئے_, wezu_, jeye_, _ttoi, 
   {{0x3f901225,0x64400418,0x2d9003e0,0x00000000}},	//   tezu_, _utoi, deye_, --, 
   {{0xf65001d3,0x3dc000d1,0x00000000,0x00000000}},	//   _دئے_, ﺮﺳﯩﺘ, --, --, 
   {{0xdda8d766,0x7dd00158,0x2d900342,0xf3180139}},	//   нтал_, _dåsn, feye_, _иншә_, 
   {{0x2d909390,0xd04400ec,0x00000000,0x00000000}},	//   geye_, _گھٽي, --, --, 
   {{0x3b542c34,0x3a2c0d27,0xdb6802bf,0xd010004b}},	// [122f0] икар, _riep_, ерел_, زلې_, 
   {{0x3a2c2112,0xa0181196,0x629c0174,0xdbcc00d0}},	//   _siep_, stöb, _ápos, lľúb, 
   {{0x2d90d767,0x795800c7,0x3a2c2c6a,0xbf14d768}},	//   beye_, виер_, _piep_, _خودب, 
   {{0x2d90d769,0x00000000,0x00000000,0x00000000}},	//   ceye_, --, --, --, 
   {{0x8e8401e4,0x846800dc,0x00000000,0x00000000}},	//   ŭŝtu, _sṛṣṭ, --, --, 
   {{0x84680882,0x37c40075,0x00000000,0x00000000}},	//   _pṛṣṭ, шәбб, --, --, 
   {{0x3a2c01fb,0x7bd400ef,0x00000000,0x00000000}},	//   _tiep_, _ilzu, --, --, 
   {{0x6aa8037e,0x645c0374,0xb464023b,0x636c01d5}},	//   æffe, _āpir, акил, _sеnа, 
   {{0xe454d76a,0x798801e1,0x7798011c,0x00000000}},	//   ажы_, _ibew, _икар_, --, 
   {{0x2d90d4a7,0x78a8d76b,0x981400c6,0x3d1c060e}},	//   zeye_, _irev, _إبرا, _मरने_, 
   {{0x629ccd94,0x2d90d76c,0x78a8030a,0xa5c00332}},	//   _špor, yeye_, _hrev, íóch, 
   {{0x78a8d76d,0x2d90014b,0x69d800c0,0xef300092}},	//   _krev, xeye_, _įtek, _በኤኮኖ, 
   {{0x79881813,0x78a8005a,0x21a0d76e,0x258400f7}},	//   _mbew, _jrev, циям, _ئچىپ_, 
   {{0x78a80109,0x2d90b761,0x6004d76f,0x3234030d}},	//   _mrev, weye_, иням_, _кхис, 
   {{0xed58729a,0x2d90b3f2,0xdbcc01f1,0x7988013f}},	//   ков_, teye_, bľúb, _obew, 
   {{0x78a8d770,0x2d9c013f,0x7bd4005a,0xed44d771}},	//   _orev, _ɔtew_, _alzu, рнап, 
   {{0x2d900537,0x78a80784,0xdca0b4da,0xac0800d8}},	// [12300] reye_, _nrev, оати, внаа_, 
   {{0x2d90d772,0x7988d773,0xee381606,0x3f84000d}},	//   seye_, _abew, _ино_, õlut_, 
   {{0x78a8d774,0x2eec0267,0x1cbc0327,0xa0180112}},	//   _arev, _äff_, ྀའུ_, stöc, 
   {{0xa9683ba6,0xada4d775,0x3a980962,0x6da40408}},	//   тида_, _тамл, ытую_, _тима, 
   {{0x78a8d776,0x39480054,0xa0180108,0x00000000}},	//   _crev, ñasa_, ltöa, --, 
   {{0x78a8d777,0xe6641b88,0xdca00120,0x00000000}},	//   _drev, атио, _ќари, --, 
   {{0xe9b40014,0xa01801f4,0x00000000,0x00000000}},	//   _پچاں_, ntöa, --, --, 
   {{0x78a80175,0x7e600436,0x798801e1,0x1dbc0254}},	//   _frev, álpi, _gbew, _एकछत, 
   {{0x758001d9,0xb864484d,0xc3c401e0,0xa0180108}},	//   سیوم, _هالو, йөкл, htöa, 
   {{0x05500125,0x66e42ff5,0xdb04032e,0xe79400f1}},	//   _መጀመሪ, _коза, _hnjá, _څاڅک, 
   {{0x78a8d778,0xe578030d,0x00000000,0x00000000}},	//   _zrev, _азе_, --, --, 
   {{0x9254034b,0x9f8c0213,0x7dd0007c,0x24e800d8}},	//   шают_, _küç_, _råso, _имеи_, 
   {{0x9098c2fe,0x107412a2,0x7dd03593,0xa3b80214}},	//   авят_, оляю, _såso, _لاغر_, 
   {{0xc884d779,0xb60000d8,0xdbcc00d0,0x3d1c000d}},	//   mağı_, _àáre, sľúb, _मरबे_, 
   {{0x4ea45434,0x601800d2,0xdb20029f,0xc8840422}},	//   орта, tîmb, ürün, lağı_, 
   {{0xcdd815ed,0xa0240036,0x7dd0050a,0x41540395}},	//   ању_, _blöö, _gåsl, _увис, 
   {{0xc8845531,0x9f8401e0,0xa5500092,0x200c0064}},	// [12310] nağı_, _кѳнд, _ማጠናቀ, _ūgiu_, 
   {{0x6018019f,0x6c6832db,0x78a8d77a,0xff9800ea}},	//   sîmb, اللہ_, _rrev, _ској_, 
   {{0x1ea805d9,0xe0dc011c,0x999002d3,0x78a80077}},	//   _شادي_, lzò_, _መምርሒ_, _srev, 
   {{0xa024000d,0xc8840790,0x00000000,0x00000000}},	//   _flöö, kağı_, --, --, 
   {{0xf7449088,0xe0dc0ffb,0x78a803b9,0x00000000}},	//   бело, nzò_, _qrev, --, 
   {{0xc8840724,0x78a8110c,0x940c0b45,0x38340022}},	//   dağı_, _vrev, ɗaɗe_, _ҳнар, 
   {{0x7dd0007c,0x00000000,0x00000000,0x00000000}},	//   _låsm, --, --, --, 
   {{0x7988014b,0xc8840166,0x00000000,0x00000000}},	//   _ubew, fağı_, --, --, 
   {{0xcdb80302,0x9f8c03ee,0x1cbc031c,0x7c2401ab}},	//   שפחה_, _güç_, ྀའི_, omhr, 
   {{0x395cd77b,0x69d80006,0xf3e40108,0x56f00117}},	//   laws_, _įtei, ёжно, _мӯйс, 
   {{0x7c24007b,0x7ccc022e,0x7dd03402,0xe7f401ad}},	//   imhr, _kўrs, _påsl, ेवरा_, 
   {{0xc8847236,0xd9f421bd,0x047801b9,0x395c0042}},	//   bağı_, ंचित_, دلیک_, naws_, 
   {{0xc8844ba9,0x00000000,0x00000000,0x00000000}},	//   cağı_, --, --, --, 
   {{0x395c0457,0xa92008a5,0xa01801f4,0x00000000}},	//   haws_, _áþei, ttöa, --, 
   {{0x98ac0327,0x51980354,0xef1001e2,0x00000000}},	//   bagħ_, _кăва, سټر_, --, 
   {{0x9f44006a,0x00000000,0x00000000,0x00000000}},	//   _önî_, --, --, --, 
   {{0x9f8c0793,0x395c0211,0x308400c6,0xa018005b}},	// [12320] _büä_, daws_, _الخف, stöa, 
   {{0x2f540640,0xa01808a1,0xe50800c5,0xdb0402d2}},	//   _утис, ltön, _हँसि_, _snjá, 
   {{0x01080014,0xc8840db1,0xab18009d,0x00000000}},	//   _متیو_, zağı_, уцах_, --, 
   {{0xa9580133,0xc8840aba,0xa9241b15,0x7c2801e4}},	//   اجار_, yağı_, бдел, _ɨeri, 
   {{0xa8500598,0x00000000,0x00000000,0x00000000}},	//   челә, --, --, --, 
   {{0x3d1c0412,0xa0180108,0x98ac031c,0xc8840205}},	//   _मरते_, htön, zagħ_, vağı_, 
   {{0xe0dc0622,0x26886762,0xf3fc0154,0x00000000}},	//   zzò_, اختي_, ঁতার_, --, 
   {{0xc8846f38,0xc0f00023,0xa2c400dc,0x00000000}},	//   tağı_, _ቃልሱ_, ाहस्, --, 
   {{0xe8f87621,0x988800e5,0x00000000,0x00000000}},	//   _сла_, _محلہ_, --, --, 
   {{0xc8841d89,0x1cdc031c,0xa01801f4,0x00000000}},	//   rağı_, ལླི_, etön, --, 
   {{0xc88405d1,0xe56801c0,0x2568013d,0xa6c801f7}},	//   sağı_, _биед_, _баеп_, _حوال_, 
   {{0x7dd00158,0xc884083c,0x1718010f,0x00000000}},	//   _påsm, pağı_, _גובע, --, 
   {{0xc0f0067d,0xd20801c6,0x614000d1,0x00000000}},	//   _ቃልሲ_, сээд_, يىھە, --, 
   {{0x5478010f,0x00000000,0x00000000,0x00000000}},	//   _עטוו, --, --, --, 
   {{0xe244082e,0xd3581203,0xe6b407f7,0x200c0153}},	//   _اختي, _גדול, _अपोज, _ūgis_, 
   {{0x395c0211,0x7e74009d,0x3d1c00af,0x00000000}},	//   xaws_, ruzp, _मरदे_, --, 
   {{0x61ecd77c,0x7ce8022e,0x06a00131,0x00000000}},	// [12330] micl, _bоra, _ﺋﯧﻐﯩ, --, 
   {{0x61ecd77d,0x5438010f,0xf2dc010b,0x00000000}},	//   licl, טעמא, _öýüň_, --, 
   {{0x7d3401e0,0x229800ef,0x00000000,0x00000000}},	//   _менє, _jūk_, --, --, 
   {{0x7dd0105c,0x3914d77e,0xb9140241,0x229800ef}},	//   _måsk, омер, _igbẹ_, _mūk_, 
   {{0x9cc8d77f,0x395cd780,0x89340597,0x7dd03be7}},	//   _сына_, raws_, أعما, _låsk, 
   {{0x229806c8,0x395c0218,0x61ecd781,0xa01801ed}},	//   _oūk_, saws_, hicl, ztön, 
   {{0xf624d782,0xa018005b,0x7dd00fac,0x61ec037e}},	//   одко, ytön, _råsj, kicl, 
   {{0x99d4d783,0x61ec00f3,0x59dc00bc,0x35c8009d}},	//   _اتسا, jicl, पोखर, ргио_, 
   {{0xd3444144,0x24c40166,0xd7e400d4,0x00000000}},	//   میشه_, жгып_, _ліжо, --, 
   {{0x22980024,0xf3e40212,0x437400d4,0x00000000}},	//   _būk_, іжно, пуют, --, 
   {{0xa0186c3f,0x2bdc0a59,0x00000000,0x00000000}},	//   ttön, फोटा, --, --, 
   {{0x61ecd784,0x9c1001e1,0x85040214,0xe2940a89}},	//   gicl, _dọin, _کوهن, цаю_, 
   {{0xb91401e1,0xa01801d3,0x629800a2,0x00000000}},	//   _agbẹ_, rtön, awto, --, 
   {{0x12842be7,0xa018d785,0x61ec01ab,0xb4d41414}},	//   _همتی_, stön, aicl, सनी_, 
   {{0x61ec0522,0x7e640175,0xad58d786,0xa3840037}},	//   bicl, _cvhp, ирах_, smõõ, 
   {{0xa018d787,0x9bc800f1,0x64600166,0xdb200241}},	//   ltöl, یدلې_, _äxiä, _òrùk, 
   {{0xaf3424e0,0x7c6400d1,0x91a00208,0xafe4014b}},	// [12340] _وردت, كالل, _nhỉ_, _моил, 
   {{0xa018d788,0x7eb00588,0xab640212,0x9c20024c}},	//   ntöl, _ẽpeh, івел, ддуд, 
   {{0x5fb40375,0x7e6006ea,0xdb2001e1,0x00000000}},	//   _והיא_, álpt, _èrìm, --, 
   {{0x9088044e,0xc8540023,0xec780798,0xa0180108}},	//   _ንላዕሊ_, _ዝሰርሕ, _кпм_, htöl, 
   {{0x91a001fb,0x6d440009,0xe20802d2,0xe824d789}},	//   _chỉ_, _ifka, _hlóð_, офко, 
   {{0xa098008f,0x61ec05d5,0xdcac00f1,0x00000000}},	//   שיסט, zicl, _ګډې_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x99800006,0x7dd033b8,0x00000000,0x00000000}},	//   _dujų_, _råsk, --, --, 
   {{0x61ec0072,0x8d900023,0x00000000,0x00000000}},	//   vicl, _ምኽትል_, --, --, 
   {{0x69c00443,0x7dd01455,0x68e007d6,0xd5680354}},	//   ljoe, _påsk, mzod, _хiол, 
   {{0x61ecd78a,0x2a5002d3,0x6d4401c7,0x68e001a9}},	//   ticl, _ዝነበሮ, _ofka, lzod, 
   {{0x69c0d145,0x51f812c4,0x629804e6,0x7dd0007c}},	//   njoe, жнюю_, rwto, _gåsh, 
   {{0x61ecd78b,0x68e0d78c,0x6b8c0076,0x69c004e6}},	//   ricl, nzod, _obbg, ijoe, 
   {{0xa3cc4614,0x6d44d78d,0x68e0004c,0xe2080ad9}},	//   _रवि_, _afka, izod, _blóð_, 
   {{0x534007d6,0x68e001b9,0x7d1c003e,0xa018005b}},	//   _ўхша, hzod, _szss, stöo, 
   {{0x68e0022e,0x00000000,0x00000000,0x00000000}},	//   kzod, --, --, --, 
   {{0x6d4400b5,0x69c0020c,0xa3cc0490,0xad4400cf}},	// [12350] _dfka, djoe, _रवा_, سىلۉ, 
   {{0x6d44d78e,0x68e0d78f,0x7ccc022e,0xe2082507}},	//   _efka, dzod, _qўrq, _flóð_, 
   {{0x3f80d790,0x69c0000f,0x7dd003cd,0xe20802d2}},	//   _ichu_, fjoe, _låsi, _glóð_, 
   {{0x3ea0d359,0x996400d4,0x00000000,0x00000000}},	//   _isht_, ітел, --, --, 
   {{0xa0180108,0xf7440f37,0x7d1c022e,0x6aac002f}},	//   ytöl, пело, _uzss, _erbf, 
   {{0xb6a4d791,0xb6580cc9,0xf7440120,0x00000000}},	//   зикл, бших_, чеко, --, 
   {{0x7c3cd792,0x69c03e1d,0x55c002dd,0xab6000d1}},	//   _husr, bjoe, дайғ, _سۇنى, 
   {{0x7c3c0548,0x9f4002f6,0x00000000,0x00000000}},	//   _kusr, lijä_, --, --, 
   {{0xb4d4d793,0xd05403f9,0x7c34030a,0xf1b801fb}},	//   सने_, ɗaɗa, _kizr, _đơ_, 
   {{0x7c34d794,0x3ea00023,0x8a880014,0x3f801324}},	//   _jizr, _osht_, _دپہِ_, _nchu_, 
   {{0xa01843e5,0x2eb800cd,0x00000000,0x00000000}},	//   rtöl, _उपेत, --, --, 
   {{0x3f800bc9,0x37bc00bd,0xa018d795,0x7c3400b5}},	//   _achu_, _অতির, stöl, _lizr, 
   {{0x7c3cd796,0xe20809f3,0x3ea002d3,0x9f4002f6}},	//   _nusr, _slóð_, _asht_, kijä_, 
   {{0xf8a41060,0x045411c7,0x64a0912f,0xa0180108}},	//   _یک_, _آئند, _чаша, ltöj, 
   {{0x7c3cd797,0x68e0011c,0x69c00072,0x9f4000a2}},	//   _ausr, zzod, yjoe, dijä_, 
   {{0xf064d798,0x3f800489,0x7c34d799,0xbda4004b}},	//   _екип, _echu_, _aizr, وحقو, 
   {{0x7c340408,0x3ea002d3,0x7c3cd79a,0xdd8c007b}},	// [12360] _bizr, _esht_, _cusr, طول_, 
   {{0xafe40323,0xdcac0a52,0x7c34d79b,0x2f540139}},	//   _хоол, دىك_, _cizr, _этис, 
   {{0x69c0193f,0x160804fa,0x7c34d79c,0x00000000}},	//   tjoe, हकार_, _dizr, --, 
   {{0xf3f0312b,0x75380369,0xdfcc0150,0xa924010b}},	//   hị_, _ngwz, _ليۋ_, пдел, 
   {{0x2d80049f,0xb4d43ee1,0x6e3c0432,0x69c0d79d}},	//   _icke_, सनो_, _hupb, rjoe, 
   {{0x69c0d79e,0x6bd801d9,0x68e0d79f,0xab28d7a0}},	//   sjoe, _اوسس_, rzod, _гога_, 
   {{0x6e3c014f,0xf3f001f2,0x68e01877,0x164400db}},	//   _jupb, dị_, szod, пчып_, 
   {{0x7c3c3223,0x6e3c0455,0x7c340165,0x68e0020c}},	//   _yusr, _mupb, _zizr, pzod, 
   {{0x2814d7a1,0x2ca00010,0x7c3c01a9,0xdef00023}},	//   _فورس, _jskd_, _xusr, _ግደን_, 
   {{0xa018049b,0x00000000,0x00000000,0x00000000}},	//   ttöm, --, --, --, 
   {{0x6e3c047e,0xd54401e2,0x00000000,0x00000000}},	//   _nupb, غلیو_, --, --, 
   {{0x3f800295,0x7ae001ed,0x7dd0005c,0x3d1c00c5}},	//   _schu_, _ülte, _tåsi, _मरले_, 
   {{0xa018023a,0x95c00451,0x00000000,0x00000000}},	//   stöm, _سيوه, --, --, 
   {{0x92540502,0x6e3cd7a2,0x25a4030a,0xa0180008}},	//   _کشور_, _bupb, _haol_, mtök, 
   {{0x7c3c04b9,0x6e3c0b1d,0x25a47de2,0x9f40005b}},	//   _susr, _cupb, _kaol_, vijä_, 
   {{0x7c3cd7a3,0x1314011a,0x12f8011a,0xf1c401e1}},	//   _pusr, _מחול_, _להוב, _àápa_, 
   {{0xa018d7a4,0x25a4d7a5,0x4c94d7a6,0x00000000}},	// [12370] ntök, _maol_, нитс, --, 
   {{0x3f80d7a7,0x2d80d7a8,0xdb042852,0x6d40005a}},	//   _uchu_, _ecke_, _injú, ñoar, 
   {{0xa018005b,0x3ea00240,0x6e3ca530,0x8c480f77}},	//   htök, _usht_, _gupb, _azğı, 
   {{0x67380af9,0xa01801e3,0x9f400108,0x00000000}},	//   _agtj, ktök, sijä_, --, 
   {{0xdb04002d,0xf3f001f2,0xcd8402dd,0x7c3cd7a9}},	//   _ynjû, yị_, _سۇلۋ, _uusr, 
   {{0x7998d7aa,0x273000d1,0x2f8800df,0x5c04009d}},	//   seww, ھىيس, ַרפּ, _хяма, 
   {{0x64441f60,0xa018023a,0x25a4d7ab,0xb6a4c3ff}},	//   íkin, ttöj, _baol_, фийл, 
   {{0x25a414d0,0xcb3400a7,0xa01802d2,0x00000000}},	//   _caol_, _чесъ, ftök, --, 
   {{0x25a40489,0xa018d7ac,0x737401c6,0xa5040107}},	//   _daol_, gtök, мынх, меъа_, 
   {{0xa018023a,0x7dd003cd,0x7ce8022e,0xd3a00107}},	//   stöj, _gåsv, _nоrm, хлоқ, 
   {{0x25a407d6,0xb6d40691,0xe79401d9,0xd6d801a9}},	//   _faol_, _تقاع, _زالک, _ута_, 
   {{0x25a453c8,0x6e3c047e,0x88e4009e,0x34b800f1}},	//   _gaol_, _rupb, _ফুটক, _وهاج_, 
   {{0x7ce8022e,0x6e3c0455,0x2ed400dc,0x81d401c4}},	//   _bоrm, _supb, ठन्त, хцэц, 
   {{0x6e3c047e,0x25a4030a,0x7eb000e4,0xa01801f4}},	//   _pupb, _zaol_, _ẽpah, ntöh, 
   {{0x03a804d3,0xe7e00db3,0x00000000,0x00000000}},	//   _ردوو_, कोटा_, --, --, 
   {{0xa018023a,0xd6ac0154,0x00000000,0x00000000}},	//   htöh, _কথায, --, --, 
   {{0x7ae40165,0x2bc82c12,0xe3e400e5,0xac8400c7}},	// [12380] ezht, олап_, _رکین_, ьгал, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc61400fe,0x00000000,0x00000000,0x00000000}},	//   াগতা_, --, --, --, 
   {{0xa018023a,0x7ac00022,0x00000000,0x00000000}},	//   ytök, ыҩса, --, --, 
   {{0x1864ab37,0x6d54d7ad,0x7b2000b5,0xfd0000cf}},	//   дачи_, mbya, はuni, _бүтп, 
   {{0x25a40597,0xe6f40014,0x7ae801ef,0x00000000}},	//   _saol_, وژاں_, _řete, --, 
   {{0xc7b807ae,0xf8ac01c0,0x25a4d7ae,0x2ad401c8}},	//   _vnđ_, _өө_, _paol_, _غيرآ, 
   {{0x6d548cf6,0xa018d7af,0xe46800db,0x00000000}},	//   nbya, ttök, ошол_, --, 
   {{0xf3f401e2,0x41e80022,0x00000000,0x00000000}},	//   کتيک, ҧымҟ_, --, --, 
   {{0x6d540369,0x7dd00158,0xa01801a8,0x00000000}},	//   hbya, _håst, rtök, --, 
   {{0xa018d7b0,0x25a40dd4,0x88e403d4,0xd254d7b1}},	//   stök, _taol_, _ফুচক, мця_, 
   {{0x6d540007,0xa0180008,0x00000000,0x00000000}},	//   jbya, ptök, --, --, 
   {{0x7dd00628,0x6600d7b2,0x54501cb8,0xa0180108}},	//   _måst, _ijok, _авіт, ltöi, 
   {{0xd36c004b,0x386803b2,0x6f0000cd,0x00000000}},	//   _نهه_, áari_, _śoca, --, 
   {{0x2ee403f9,0xa018023a,0x660003b2,0x6204014b}},	//   _ƙofa_, ntöi, _kjok, _очиз, 
   {{0x6d540007,0x442c01a4,0x2b480175,0x386825b4}},	//   gbya, lmd_, _afbc_, šari_, 
   {{0x7bc4d7b3,0x442c0d27,0x212c00a3,0xd1b81d00}},	// [12390] tjhu, omd_, _àgh_, _زايا_, 
   {{0x6d54058a,0x7dd001e3,0xbf1001ee,0x9ba000d1}},	//   abya, _råsu, _бүгә, خەسى, 
   {{0xe1fcd7b4,0x442cd7b5,0x6600035b,0x7dd0369d}},	//   onó_, imd_, _ojok, _båst, 
   {{0x6600d7b6,0x1dd01408,0xe1fcd7b7,0x00000000}},	//   _njok, _सवित, nnó_, --, 
   {{0x38680597,0x2b480175,0xc98442fd,0xa01801f4}},	//   éar_, _ffbc_, тухи, ttöh, 
   {{0x48e000bd,0x66002f7e,0xdb04002e,0x442cd7b8}},	//   বপূর, _ajok, _jajë, jmd_, 
   {{0xe7344e73,0xdb040240,0x0a6801a9,0x00000000}},	//   неш_, _majë, _орти_, --, 
   {{0x442c0ae3,0xdcec07b3,0x7dd005ac,0xe6900fb4}},	//   emd_, _hacı, _gåst, اليد, 
   {{0x6600d7b9,0xc984d7ba,0xdcec03e0,0x00000000}},	//   _djok, _шури, _kacı, --, 
   {{0x6600d7bb,0x57246f33,0x6d540399,0x28bcd7bc}},	//   _ejok, _قراق, zbya, ्हरि, 
   {{0xdcec08a9,0x9f400419,0x00000000,0x00000000}},	//   _macı, bijú_, --, --, 
   {{0x442cd7bd,0x660002d3,0x7640d7be,0xdcec06be}},	//   amd_, _gjok, _iuly, _lacı, 
   {{0x7640d7bf,0x442c3c36,0x7dd001e3,0xed5801f0}},	//   _huly, bmd_, _låss, ҷоб_, 
   {{0x442c010a,0x7640d7c0,0x039402d9,0x66000427}},	//   cmd_, _kuly, _аръя, _zjok, 
   {{0xe1fc0548,0x7760002e,0xed5802a9,0x60200117}},	//   bnó_, _melx, зоб_, удра, 
   {{0x7640d7c1,0x11681046,0x25780b97,0x00000000}},	//   _muly, _کلکی_, mülü_, --, 
   {{0x76401418,0xdcecd7c2,0x7dd012ed,0xdb040023}},	// [123a0] _luly, _bacı, _råst, _fajë, 
   {{0xdb040066,0x76400165,0x6d54d7c3,0xc5ec00ab}},	//   _kajè, _ouly, sbya, _जग्य_, 
   {{0x76407a9a,0xdbe001e1,0x387c0142,0x257806be}},	//   _nuly, _méèl, euwr_, nülü_, 
   {{0x6a140f00,0x6d540097,0x2b48020c,0xdb04007f}},	//   ربار, qbya, _wfbc_, _majè, 
   {{0x776002c4,0x442c394a,0xdb040066,0xd96400ec}},	//   _belx, ymd_, _lajè, رٽون_, 
   {{0x7640d7c4,0x6600d7c5,0xa018005b,0x25782ca8}},	//   _buly, _sjok, ttöi, külü_, 
   {{0x6994d7c6,0x7640d7c7,0x6600003b,0x7dd0005c}},	//   _прах, _culy, _pjok, _tåst, 
   {{0x764070d4,0xe7f009bb,0x25780790,0x7e60054e}},	//   _duly, _अगवा_, dülü_, âlpi, 
   {{0x77600998,0xa49004fb,0x76400363,0xa01833eb}},	//   _felx, ایتت, _euly, stöi, 
   {{0x7640d7c8,0x6600002d,0x224c005a,0xdcec0139}},	//   _fuly, _wjok, _ptfk_, _xacı, 
   {{0x7640d7c9,0x442c0cf9,0x45e4001e,0x6600d7ca}},	//   _guly, rmd_, _đượ, _tjok, 
   {{0x6600014b,0x8da0001f,0x7eb000e4,0xd25400a8}},	//   _ujok, ምአቀፍ_, _ẽpoh, эць_, 
   {{0xe3b0034c,0xe1fcd7cb,0xdb040200,0x77600139}},	//   _مرغ_, rnó_, _pajë, _yelx, 
   {{0x64400076,0x7640d7cc,0xa01801f4,0x6b9c00a2}},	//   _iuoi, _yuly, htöv, jepg, 
   {{0x9f8c00a2,0x7640022e,0xce940354,0x8f0801f0}},	//   _güý_, _xuly, ларъ, ехта_, 
   {{0x8d84a6e6,0x63a8d7cd,0x3f840003,0x8bc476c5}},	//   лууд, _hafn, żlu_, қсуд, 
   {{0x63a80548,0x65600051,0x00000000,0x00000000}},	// [123b0] _kafn, _meoh, --, --, 
   {{0x63a800fc,0x6440d7ce,0x65600093,0x7ce8022e}},	//   _jafn, _muoi, _leoh, _jоri, 
   {{0x63a80109,0x9f8c00af,0x387c020c,0xa01801e3}},	//   _mafn, _müü_, wuwr_, ftöv, 
   {{0x6560d7cf,0x63a807ab,0x8aa46943,0x91a0004d}},	//   _neoh, _lafn, ыруд, _khí_, 
   {{0x7640d7d0,0x6b9c0208,0xdb200133,0x3dc80327}},	//   _suly, bepg, _ڕوسی, mjaw_, 
   {{0x63a8008c,0x7640d7d1,0xdb040066,0x36946c48}},	//   _nafn, _puly, _lajé, вшис, 
   {{0x67d00120,0x7640013d,0xe7f0000d,0x35a44c91}},	//   роју, _quly, _अगरा_, вайг, 
   {{0xceb404ac,0xdb040100,0x3dc80135,0x00000000}},	//   ריק_, _rajè, njaw_, --, 
   {{0x3834d7d2,0x6440d7d3,0x394c0048,0x7ce801a9}},	//   _анар, _cuoi, _ifes_, _bоri, 
   {{0x386c4b2e,0xd76400dd,0x7640d7d4,0x64407d10}},	//   _iver_, _سائٹ, _tuly, _duoi, 
   {{0x386cd7d5,0xd6d8bbdd,0x6560d7d6,0xe0dc0ba1}},	//   _hver_, _эта_, _feoh, scòl_, 
   {{0x53740201,0xdbe001c7,0x386807f5,0x00000000}},	//   _በአዲስ_, _déél, šaru_, --, 
   {{0x2ee40198,0x91a0004d,0x3dc80135,0xd498010a}},	//   _ƙofo_, _chí_, djaw_, _хре_, 
   {{0xb4cc0574,0xa0a01b88,0xe3b400ee,0x63a80009}},	//   रही_, јард, _абш_, _gafn, 
   {{0xdb0400e8,0x91a0001e,0xa018005b,0x00000000}},	//   _fajé, _thì_, ytöv, --, 
   {{0x386c025f,0xde0039be,0x00000000,0x00000000}},	//   _over_, апси, --, --, 
   {{0xdb7402d3,0xec14011d,0xe7f01d15,0x9d4002dd}},	// [123c0] _ኣዝዮም_, نورد, _अगला_, реуд, 
   {{0x394c0421,0xeaf82303,0x7ce8022e,0x320000d7}},	//   _afes_, ورات_, _xоri, lnky_, 
   {{0x386cd7d7,0xed580588,0x7ae80b45,0x3170012c}},	//   _aver_, _оон_, _ƙeta, _kdyz_, 
   {{0xe8f80b14,0xe9d800d6,0x386c0175,0x00000000}},	//   мле_, ьке_, _bver_, --, 
   {{0x656000b0,0x394c0142,0x48e00154,0xa018007c}},	//   _reoh, _dfes_, বপ্র, rtöv, 
   {{0x394cd7d8,0x6560d7d9,0x386c0076,0x9f400268}},	//   _efes_, _seoh, _dver_, ghjè_, 
   {{0x386c0c3e,0x63a8d7da,0xc82402dd,0x9f8c0254}},	//   _ever_, _rafn, _ұзақ, _rüü_, 
   {{0x63a8008c,0xa01801ed,0xdbe006af,0xb4cc0ce0}},	//   _safn, ltöt, _réél, रहू_, 
   {{0x6440d7db,0x98a0d7dc,0x18a029a3,0xdb040098}},	//   _quoi, _ките, _катм, _rajé, 
   {{0x32000038,0xa01801ed,0x3dc8025c,0x00000000}},	//   enky_, ntöt, zjaw_, --, 
   {{0x6560003e,0xdb040022,0x386c6a4e,0x63a8a75f}},	//   _teoh, _pajé, _zver_, _vafn, 
   {{0x22880086,0x386cd7dd,0x91a0004d,0x6440004d}},	//   rùk_, _yver_, _phí_, _tuoi, 
   {{0x4394545d,0x63a80109,0x50643129,0x3dc8031c}},	//   _балс, _tafn, итра, vjaw_, 
   {{0x95940022,0x1ee403c7,0xef8c0023,0x32000419}},	//   _зтәу_, پوری_, _ምዝዛሙ_, anky_, 
   {{0x443cd7de,0xdda81075,0x3dc8025c,0x22846c9a}},	//   _iiv_, мтал_, tjaw_, _рулг, 
   {{0x443cd7df,0x91a00208,0x31700210,0x00000000}},	//   _hiv_, _thí_, _gdyz_, --, 
   {{0x443cd7e0,0x3dc80003,0x00000000,0x00000000}},	// [123d0] _kiv_, rjaw_, --, --, 
   {{0x443c014f,0x2d90058a,0x00000000,0x00000000}},	//   _jiv_, afye_, --, --, 
   {{0x443cd7e1,0x20002220,0x3a745e18,0x2908016b}},	//   _miv_, mnji_, улер, _ɛbae_, 
   {{0x443cd7e2,0x386c0165,0x20000010,0x7e600356}},	//   _liv_, _pver_, lnji_, âlpu, 
   {{0xe734013e,0x443c01a9,0x2000037e,0x37f8084c}},	//   қеъ_, _oiv_, onji_, недэ_, 
   {{0x443cd7e3,0x69c40428,0x2000d7e4,0xba4400e5}},	//   _niv_, _òken, nnji_, _منسٹ, 
   {{0x7d1c03a2,0x5964020a,0xded0001f,0x3200d7e5}},	//   _hyss, _аъза, _የውኃ_, ynky_, 
   {{0x443c0218,0x386cd7e6,0x394c00d8,0x20000010}},	//   _aiv_, _tver_, _ufes_, hnji_, 
   {{0x4824425b,0x386c0585,0x443cd7e7,0x7988d7e8}},	//   _چىقق, _uver_, _biv_, _icew, 
   {{0x443cd7e9,0x200008ad,0x78a8d7ea,0xd6d8d7eb}},	//   _civ_, jnji_, _isev, _оте_, 
   {{0x443c8c75,0x7d1c04f3,0xf6540120,0xa0180108}},	//   _div_, _lyss, _свеќ, htös, 
   {{0x5ed40eac,0x2000037e,0xdb0402d2,0xb9cc0023}},	//   _ডেভে, enji_, _hnjó, _ደአ_, 
   {{0x443cd7ec,0x7988d7ed,0x7d1c0af9,0x5024035f}},	//   _fiv_, _mcew, _nyss, измғ, 
   {{0x443cd7ee,0xedd40451,0x04640116,0x200046aa}},	//   _giv_, گيرد, _өтәм, gnji_, 
   {{0xdee075dd,0x7d1c127b,0x9f60219b,0x00000000}},	//   бори, _ayss, ávám_, --, 
   {{0x78a8d7ef,0x7d1cd7f0,0x00000000,0x00000000}},	//   _osev, _byss, --, --, 
   {{0x78a802b9,0x443c0218,0x7c64129d,0x7d1c0142}},	// [123e0] _nsev, _yiv_, لالل, _cyss, 
   {{0x7d1c9750,0x7988576c,0x20000cf4,0x35c41d15}},	//   _dyss, _acew, cnji_, वाड़, 
   {{0x7d1c009a,0x98ac0598,0xdb280075,0xab28005b}},	//   _eyss, dagı_, ىزمۇ_, хожа_, 
   {{0x7d1c1368,0xa018d7f1,0x9e7800df,0x00000000}},	//   _fyss, stöt, _אנטפ, --, 
   {{0xd9143bb3,0xb4ccc488,0xe77400fd,0x7d1c010b}},	//   льш_, रहो_, галә_, _gyss, 
   {{0x6f1c0166,0x8654074d,0xa01801d3,0x00000000}},	//   _kypc, аккх, ltör, --, 
   {{0x443cd7f2,0x78a80944,0x00000000,0x00000000}},	//   _riv_, _esev, --, --, 
   {{0x443c0b89,0x20001505,0xa018049f,0xdb040ba1}},	//   _siv_, znji_, ntör, _enjó, 
   {{0x443cd7f3,0xdb0402d2,0x02dc5347,0x98ac0166}},	//   _piv_, _fnjó, मन्न, bagı_, 
   {{0x443cd7f4,0x8ccc033f,0x69b803ce,0x66e40408}},	//   _qiv_, _सपनो, _एफडी, _йоза, 
   {{0x443cd7f5,0xa018d7f6,0x78a800b5,0xd5ac1214}},	//   _viv_, ktör, _zsev, _лс_, 
   {{0xa018049b,0x443c016d,0x00000000,0x00000000}},	//   ytös, _wiv_, --, --, 
   {{0x443cd7f7,0x20000989,0xd5f8010f,0x00000000}},	//   _tiv_, tnji_, _אפאר, --, 
   {{0x7d1cd7f8,0xd7c40574,0x00000000,0x00000000}},	//   _ryss, लायच, --, --, 
   {{0x53980302,0x7d1c2ff9,0x940003e6,0xd24c0022}},	//   _ניהו, _syss, _دووه, _ыц_, 
   {{0x20000b91,0x7d1cd7f9,0xa018d7fa,0x7d54d7fb}},	//   snji_, _pyss, gtör, рвах, 
   {{0x2000d7fc,0x6f1c03ac,0xc0c40116,0xc4d40327}},	// [123f0] pnji_, _eypc, _тәни, ིརྒྱ, 
   {{0x9f48023a,0x58840220,0x7d1c1d55,0x4ba80137}},	//   äjät_, ғыда, _vyss, лөсү_, 
   {{0xa01802f6,0x78a804ba,0x8d9400d1,0x7d1c0210}},	//   stös, _ssev, شلەش, _wyss, 
   {{0x7d1cd7fd,0xdb04066a,0x5fc0c6cd,0x78a8d7fe}},	//   _tyss, _snjó, शावल, _psev, 
   {{0x79c8d7ff,0x00000000,0x00000000,0x00000000}},	//   _یوسف_, --, --, --, 
   {{0x9f400309,0xb8cc0dba,0x6c780a7c,0xc8640353}},	//   mijó_, _ओई_, _באשפ, стци, 
   {{0xdb04d800,0x59b00daf,0x0f580375,0xdb2000f2}},	//   _enjò, _гөлс, ניהם_, _طوری, 
   {{0x78a8d801,0xa018d802,0xee4400a2,0x762400d8}},	//   _tsev, brög, _öýem_, јмиз, 
   {{0x78a8d803,0xdb040118,0x0b1c0092,0xf3e400c7}},	//   _usev, _mají, _ሶስተኛ, ижио, 
   {{0xf8b800c7,0xe79401d3,0xa49001d9,0xa018007c}},	//   _irũ_, _نامک, تیٖت, nröd, 
   {{0xc7c407d6,0x3a2c0649,0x67b8010f,0xa0180d36}},	//   _усти, _khep_, _שמעק, ytör, 
   {{0xd9f406ab,0xdb04012c,0x3a2c05b1,0xb1d802bf}},	//   ूचित_, _nají, _jhep_, тьох_, 
   {{0x2bd4012c,0x6064010b,0x7bc001e1,0x00000000}},	//   _धवला, аҗың_, _òluw, --, 
   {{0x3a2c020c,0x245004d3,0xd3e001b9,0x28c44196}},	//   _lhep_, _بنوس, _دقتی, लमति, 
   {{0xdb040789,0xfe7812c4,0xa018d804,0x51980354}},	//   _bají, лёты_, ttör, _йăва, 
   {{0x9d4001e0,0x6f1c0419,0x3a2c0208,0xd3440345}},	//   жетд, _vypc, _nhep_, _جیگه_, 
  
   {{0xa018d805,0xdb04d806,0x6b64d807,0x6c34007b}},	// [12400] rtör, _najâ, икаа, لفرا, 
   {{0x3a2c0098,0x6b54d808,0x6f1c0036,0xa018007c}},	//   _ahep_, ртах, _typc, gröd, 
   {{0xa018d809,0xd1c002d3,0x00000000,0x00000000}},	//   ptör, _ትሑት_, --, --, 
   {{0x3a2c047e,0x2d94d80a,0x7ce8022e,0xa01801f4}},	//   _chep_, _трос, _pоrt, ltöp, 
   {{0xaf34d80b,0x3a2c020c,0xa01801e3,0x00000000}},	//   _حرکت, _dhep_, bröd, --, 
   {{0xdb04038e,0xa01808a1,0xdbb80166,0x6ab801d3}},	//   _zají, ntöp, _итсә_, _átfo, 
   {{0xb76400d6,0x00000000,0x00000000,0x00000000}},	//   стій, --, --, --, 
   {{0xd5b4230c,0x3a2c004d,0xa018005b,0x7ce8022e}},	//   ась_, _ghep_, htöp, _tоrt, 
   {{0xe4e40212,0x00000000,0x00000000,0x00000000}},	//   рійн, --, --, --, 
   {{0x9f40026c,0xb6000118,0x78bc032e,0x09e401a9}},	//   ghjì_, _šáte, _ásva, _тоғн, 
   {{0xa6c80597,0x43940032,0xe7380c82,0x00000000}},	//   _جوال_, _ғайс, _реж_, --, 
   {{0x3a2c0240,0x00000000,0x00000000,0x00000000}},	//   _xhep_, --, --, --, 
   {{0xfbc811bc,0xc0cc0023,0xa3e808ca,0xb61400e5}},	//   रामम, _ኣውራ_, _идда_, _آنک, 
   {{0x9f400ffb,0x53a0013e,0x00000000,0x00000000}},	//   chjì_, _мачб, --, --, 
   {{0x29080134,0x5d64005b,0x626400d1,0xe5944dd9}},	//   _ɛbaa_, итаз, _ئاتق, lçığ, 
   {{0xfe7800bc,0x8de800c7,0x51f400ae,0x00000000}},	//   čů_, афуа_, _وسير, --, 
   {{0x40940597,0xdb040122,0xe5940724,0x800801d3}},	// [12410] _الخر, _vají, nçığ, _مردہ_, 
   {{0x5ba40e92,0x49b83bdb,0xdd2c0118,0x77e400c5}},	//   јраз, یاند_, _těžc, _कतेक_, 
   {{0x810800aa,0x3a2c01fb,0x0fd8038b,0x795801d5}},	//   _جرګې_, _phep_, _خبيث_, гиер_, 
   {{0xe5940205,0xbc9400d8,0x00000000,0x00000000}},	//   kçığ, _ламј, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xad24129e,0x387c03cb,0x6f00002b,0x00000000}},	//   _درپو, rrwr_, _śoci, --, 
   {{0x3a2c06a3,0x955401d3,0x8ae4003b,0x00000000}},	//   _thep_, لیاء_, _дітл, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7bd4d80c,0x7f440477,0x97a410fc,0xa01801f4}},	//   _kozu, _oghq, _врел, ytöp, 
   {{0x4a240c99,0x7bd4d80d,0x981449f6,0x00000000}},	//   _འཚོལ_, _jozu, _ئبرا, --, 
   {{0x7bd4d80e,0x71685977,0xf2d82101,0xb144010b}},	//   _mozu, ланг_, ابخش_, йннл, 
   {{0x7f440477,0xee4400e4,0x57b40118,0x00000000}},	//   _aghq, ñýma_, _आफुह, --, 
   {{0x63c0012c,0x258400f7,0x61ec017a,0xa0183b22}},	//   ávní, _اچىپ_, ëbla, ttöp, 
   {{0x7bd4d80f,0x00000000,0x00000000,0x00000000}},	//   _nozu, --, --, --, 
   {{0xdee0d810,0x7a300158,0xc2c400ec,0xa018002f}},	//   пори, måtf, _ويهي, rtöp, 
   {{0x7f44047e,0x2254007b,0xa018d811,0x32040de2}},	//   _eghq, _اليد_, stöp, _ñoy_, 
   {{0xeb98d812,0x7bd4d813,0xada40032,0xac0806ed}},	// [12420] лиа_, _bozu, _һанл, гнаа_, 
   {{0x6fa8026a,0x7bd40bbc,0xe0b40a1e,0xad400137}},	//   _свог_, _cozu, _פליט_, تۉڭۉ, 
   {{0x7bd41539,0x6da42a9d,0x2eec007c,0x69c401e1}},	//   _dozu, _лина, _åff_, _òkek, 
   {{0x28e842c6,0xed580801,0xed3480f1,0x6da400c7}},	//   лдеп_, _щом_, _гэгэ, _уима, 
   {{0x6d44c95a,0x6e340076,0x25f406ab,0x20140419}},	//   _igka, mmyb, एफसी_, ždiť_, 
   {{0xa09825f9,0x7bd4d814,0xc61006b1,0xfbc8102f}},	//   ריסט, _gozu, ाव्य_, राणम, 
   {{0x1be40f5c,0x46140fba,0xfbdc0a8a,0x3e500210}},	//   _удри_, يوتر, _यवतम, _kąta_, 
   {{0xfbc812eb,0x5e54010f,0xb60001ef,0x00000000}},	//   राथम, זיקע_, _šáre, --, 
   {{0x6d441c06,0x7bd4d815,0xa34400ee,0x8c48013d}},	//   _mgka, _yozu, йэнл, _uyğı, 
   {{0xd4940962,0x4adc446c,0x42748271,0x03f80640}},	//   ёры_, _यथाव, огос, рној_, 
   {{0x175404ae,0xdb0401d3,0xa6a8009f,0xfbc82c2e}},	//   _הסבר_, _kajá, _حاذق_, रातम, 
   {{0x64441f60,0x6d44d816,0xdb040022,0x929002d5}},	//   íkis, _ngka, _jajá, чаюц, 
   {{0xdb041ab0,0x51f806a6,0x7a3003cd,0x00000000}},	//   _majá, сняю_, båtf, --, 
   {{0x6d44b1ee,0x00000000,0x00000000,0x00000000}},	//   _agka, --, --, --, 
   {{0x7bd43f9d,0x52700aa0,0xdd98d817,0x0c9402d3}},	//   _rozu, _فايز, лша_, _ዝርከባ_, 
   {{0x7bd4d818,0x926400ee,0x7ae00205,0x00000000}},	//   _sozu, _урша_, _ülti, --, 
   {{0x7bd403be,0xe1fcd819,0x7bf8c9cf,0x6aac035a}},	// [12430] _pozu, mió_, анар_, _asbf, 
   {{0xe1fcd81a,0x6aac010a,0x29fc0521,0x7f44047e}},	//   lió_, _bsbf, ọala_, _ughq, 
   {{0x7bd405be,0xdb0400e5,0xe0dc010e,0x00000000}},	//   _vozu, _bajá, lyò_, --, 
   {{0xe1fc0372,0x7bd402ce,0xdda8d81b,0xbdc00150}},	//   nió_, _wozu, _стол_, _تەرۋ, 
   {{0x7bd4d81c,0x3ea0020b,0x00000000,0x00000000}},	//   _tozu, _hpht_, --, --, 
   {{0x67d00063,0x4e945533,0xfaa800ec,0x00000000}},	//   дољу, _بشیر, _پهري_, --, 
   {{0xe1fc317c,0xe74400fb,0xe7940633,0x00000000}},	//   kió_, әфәү, تانک, --, 
   {{0xe1fc0789,0x3db803d4,0x8af802e8,0x7a30007c}},	//   jió_, ীসকল, _унсс_, dåtg, 
   {{0xe1fcd81d,0x00000000,0x00000000,0x00000000}},	//   dió_, --, --, --, 
   {{0x73040108,0x00000000,0x00000000,0x00000000}},	//   жпоз, --, --, --, 
   {{0x6e340006,0xe1fc0789,0xc7c4004e,0x00000000}},	//   ymyb, fió_, _эсти, --, 
   {{0xe1fcd81e,0x68ec0209,0x4734009d,0x00000000}},	//   gió_, _öndü, _энхс, --, 
   {{0x60180311,0xefd00023,0xe0dc0432,0x00000000}},	//   tîmp, _ከምይ_, gyò_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe1fc00bd,0x6d440280,0x9f402b1d,0x00000000}},	//   bió_, _pgka, ghjà_, --, 
   {{0xe1fcd81f,0xed58d820,0xddc000db,0x00000000}},	//   ció_, роа_, мбси, --, 
   {{0x7e68009b,0x6e340064,0x00000000,0x00000000}},	// [12440] ćepa, rmyb, --, --, 
   {{0xdb04066d,0x60d803fa,0x6e340024,0xdd2c01ef}},	//   _sajá, äume, smyb, běžo, 
   {{0xdb040309,0x9f4008e5,0x00000000,0x00000000}},	//   _pajá, chjà_, --, --, 
   {{0xa924529e,0x7c2401ab,0x68400023,0xcb6807d6}},	//   одел, alhr, _ክቡራት, شمچه_, 
   {{0xa7a807d6,0x9a640131,0x9f4001a8,0x00000000}},	//   икда_, ممەل_, mhjá_, --, 
   {{0xe1fc01ed,0xdc6401f0,0x00000000,0x00000000}},	//   zió_, _фард_, --, --, 
   {{0x98a00006,0x6aac0129,0xbb7000db,0x999c010e}},	//   _ąją_, _usbf, _سۇنع, _okuň_, 
   {{0xe1fc00f7,0xfa3000db,0x00000000,0x00000000}},	//   xió_, _كۉلج, --, --, 
   {{0xe1fc04cf,0xa80421b5,0xe8f8a30d,0x9534011c}},	//   vió_, _дзал, _тла_, озът_, 
   {{0x539400c9,0x78ac00db,0xe73000ec,0xd4940006}},	//   овья_, çave, _قصا_, іры_, 
   {{0xb9d80020,0xe1fc204e,0x00000000,0x00000000}},	//   _በቂ_, tió_, --, --, 
   {{0xe5a44990,0xcf3002d3,0x7a30007c,0xe4e40064}},	//   _фиди, _ተስፋታ, råtg, _мілн, 
   {{0xe1fc204e,0xc1041b45,0x7a3001e3,0x00000000}},	//   rió_, سوسي, såtg, --, 
   {{0xe1fc0372,0xa2d48b4d,0x7a3008fb,0x795402d3}},	//   sió_, _ويشت, måte, _ዝጠቐስ, 
   {{0x451c045e,0xe1fc5a8b,0x7a303402,0x795001e1}},	//   দেশক_, pió_, låte, _jówó, 
   {{0xe05404fb,0xecd4009e,0xdb2001e1,0x00000000}},	//   _ویجت_, _সেইড, _òrék, --, 
   {{0x5ce402bf,0x79500241,0x61ec01ab,0x7c24016d}},	// [12450] цюва, _lówó, mhcl, tlhr, 
   {{0xa2bc04e4,0x9b24023a,0x00000000,0x00000000}},	//   षिप्, офел, --, --, 
   {{0xdce403e0,0x00000000,0x00000000,0x00000000}},	//   ğlıb, --, --, --, 
   {{0xdb040200,0xfbc81157,0x00000000,0x00000000}},	//   _lajç, राहम, --, --, 
   {{0x7d242444,0x2ca00051,0xed5400df,0x6b8c01e3}},	//   _رفسن, _gpkd_, _מברר_, ångå, 
   {{0x1a58007b,0x00000000,0x00000000,0x00000000}},	//   _نشرة_, --, --, --, 
   {{0x7e7400e5,0x00000000,0x00000000,0x00000000}},	//   nszp, --, --, --, 
   {{0xb95400a7,0xb464cb6a,0x7dd001bf,0x61ec0200}},	//   _хващ, пкил, _påsy, ëbll, 
   {{0xdb0400d8,0x7a300fac,0x61ec01ab,0x4dfc00df}},	//   _enjô, gåte, dhcl, יפהא, 
   {{0xdb2001e1,0x00000000,0x00000000,0x00000000}},	//   _àrój, --, --, --, 
   {{0xdb040200,0x7a30007c,0x85b800e5,0x00000000}},	//   _dajç, måtb, _ڈانس_, --, 
   {{0x85b80014,0x7a30d821,0xe294d822,0x00000000}},	//   _وانس_, båte, чаю_, --, 
   {{0x229020d4,0x00000000,0x00000000,0x00000000}},	//   ولیس, --, --, --, 
   {{0xafe402e8,0x00000000,0x00000000,0x00000000}},	//   чогл, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x61ec0857,0x60d8002f,0x6d5836d9,0x00000000}},	//   chcl, äumc, _ştab, --, 
   {{0xdca05fa8,0x32000122,0xac8420c8,0x5ca00395}},	// [12460] нати, miky_, ягал, нитб, 
   {{0xa09425f9,0x3200d823,0x60f8011a,0x00000000}},	//   _צדיק_, liky_, _להפק, --, 
   {{0xe0dc0ba1,0x00000000,0x00000000,0x00000000}},	//   lcòp_, --, --, --, 
   {{0x3200d824,0x26c00419,0x00000000,0x00000000}},	//   niky_, _čko_, --, --, 
   {{0xd7c4d825,0xfbd001ed,0x68400248,0x57b800d1}},	//   लांच, رتے_, _nídì, ﻠﻠﯩﺮ, 
   {{0x320002f0,0xa0980a7c,0x7d0802d2,0x00000000}},	//   hiky_, מינט, _þesa, --, 
   {{0xfbc8c853,0xa0185df7,0x320006d9,0xeb340150}},	//   रारम, krön, kiky_, _ءىزد, 
   {{0x2fd80175,0x6d5400b5,0xed800023,0x00000000}},	//   _lopg_, ncya, _ክኽበር_, --, 
   {{0x32007794,0x672802d3,0x18642cdd,0xdb200241}},	//   diky_, _ትዕዝብ, _нати_, _àròj, 
   {{0x68400241,0x13f0c133,0x7a30143a,0x68e0d826}},	//   _dídì, езья, råte, myod, 
   {{0x27fc014b,0x61ec91fa,0x3200d827,0xdb040139}},	//   _imtn_, thcl, fiky_, _gajä, 
   {{0xddc801fa,0x32000306,0xa01836b2,0x00000000}},	//   _žiža, giky_, grön, --, 
   {{0x68e0d828,0x2fd8d829,0x4394b27b,0x00000000}},	//   nyod, _bopg_, _жалс, --, 
   {{0x61ecd82a,0xa01801ed,0x320006d9,0x746800d4}},	//   shcl, ltöz, aiky_, _єрів_, 
   {{0x2450001e,0x32000030,0x6d54003a,0x7e681710}},	//   _hâm_, biky_, fcya, ćepo, 
   {{0x32000419,0x92b0007b,0x68e0d82b,0x00000000}},	//   ciky_, _أحوا, kyod, --, 
   {{0x7c580075,0x5ba44538,0xfbc808df,0x00000000}},	// [12470] زلار_, зрез, रालम, --, 
   {{0x68e0d82c,0x245001fb,0x6d540009,0x00000000}},	//   dyod, _mâm_, acya, --, 
   {{0x2000d82d,0x24500016,0x7e981f0d,0x48a00023}},	//   miji_, _lâm_, _بنجر_, _ሓርገጽ_, 
   {{0x2cb00724,0x301439af,0x6ff406be,0x7a140210}},	//   ändä_, _ндөр, _təcü, kąte, 
   {{0x7a14012d,0x00000000,0x00000000,0x00000000}},	//   jąte, --, --, --, 
   {{0xb8d419e5,0xdb040793,0xde2402d3,0x32000865}},	//   _जन_, _pajä, _ሰብኣው, ziky_, 
   {{0xe734483d,0xe690034c,0xf988027d,0x68400248}},	//   меш_, نلود, _ونسي_, _sídì, 
   {{0xb9c4d82e,0x20001dd4,0x8d900023,0x66b000ec}},	//   _تقري, hiji_, _ዝኽተል_, ئٽيء, 
   {{0x32000109,0x2450004d,0x77a80014,0x68e00055}},	//   viky_, _câm_, _وُرِ_, cyod, 
   {{0x2000d82f,0x24500016,0x601c00bc,0x7ae0000d}},	//   jiji_, _dâm_, námě, _ülts, 
   {{0x3200d830,0x73c00184,0xa8000086,0x29dc04cc}},	//   tiky_, еҙҙе, _òñau, _gïas_, 
   {{0x7e680960,0x00000000,0x00000000,0x00000000}},	//   ćepl, --, --, --, 
   {{0x3200d831,0x2bb000cd,0x0584011c,0x00000000}},	//   riky_, ीयमा, _чухм, --, 
   {{0x32007794,0x7fd4d832,0x64a0d833,0x60d8002f}},	//   siky_, нісі, _раша, äuma, 
   {{0x3dbc0131,0x320006d9,0xa2bc00cd,0x00000000}},	//   ﻧﻠﯩﻘ, piky_, षिण्, --, 
   {{0x2000009f,0x68e0d834,0x6d540067,0xace87b0e}},	//   aiji_, yyod, ucya, омба_, 
   {{0x200056c0,0x2450001e,0xfbc80490,0xdd8c0472}},	// [12480] biji_, _xâm_, रांम, شول_, 
   {{0xbc241c02,0x68e000ec,0xe50c0fc8,0x6d540393}},	//   ىرلى, vyod, ापति_, scya, 
   {{0x68e00142,0xe8c409ab,0x00000000,0x00000000}},	//   wyod, लम्च, --, --, 
   {{0x7c34005a,0x5ed42cc5,0x02b000ce,0xa2bc00cd}},	//   _ehzr, _ডেকে, _जनसभ, षित्, 
   {{0x9d94044e,0xd6cc6ee9,0xd940516e,0x8c6801ec}},	//   _ውሽጣዊ_, یقه_, веци, _رەال_, 
   {{0x6a84006c,0x68e0d835,0x2450004d,0x78acd836}},	//   _олга, ryod, _râm_, çava, 
   {{0x2450d837,0x77903b7a,0x9bb4010f,0x69940114}},	//   _sâm_, ایما, _קהלה_, _орах, 
   {{0xe4e4003b,0x00000000,0x00000000,0x00000000}},	//   діон, --, --, --, 
   {{0x2000d838,0x2814d839,0xd61400f1,0x2bd06236}},	//   yiji_, _قورس, ړتیا_, सापा, 
   {{0x7a3000fe,0xe5300022,0x77900066,0x00000000}},	//   måta, неқь, _میها, --, 
   {{0x200008ad,0x7a3010d1,0xe2300023,0x00000000}},	//   viji_, låta, _ባህልና, --, 
   {{0x245001dc,0xd2540953,0x38680311,0x200004fb}},	//   _tâm_, ьць_, ţare_, wiji_, 
   {{0xd5cc0208,0xa0181876,0x00000000,0x00000000}},	//   _kềnh_, bröl, --, --, 
   {{0x14d40a1e,0xa2bc07d0,0xd3b40212,0xb4b4013d}},	//   _קוגל_, षिद्, _олії_, _чишә, 
   {{0xe7e4007d,0xd5cc004d,0xff28007b,0x2f84035b}},	//   _कवना_, _mềnh_, سكري_, хәын_, 
   {{0x200008ad,0x8d84499d,0x80e000fe,0xd5cc0051}},	//   siji_, кууд, _পেণ্, _lềnh_, 
   {{0x6298d83a,0xad1401ec,0xdb2002d2,0x00000000}},	// [12490] ltto, ептә, _írúm, --, 
   {{0xfe7037d7,0x63b8d83b,0x9a84036b,0xc7b8009b}},	//   _مگر_, ndtn, дудл, _nađ_, 
   {{0x495c0521,0x6298d83c,0xa3c40037,0x9b2401d5}},	//   _ịtụ_, ntto, _उफन_, ффал, 
   {{0x62980464,0x8f0807d5,0xdb0400d7,0xdb2001e1}},	//   itto, _цхьа_, _kajú, _òrík, 
   {{0xdb0400e4,0xd5cc004d,0x6298000d,0x7a30007c}},	//   _jajú, _bềnh_, htto, gåta, 
   {{0xdb0400f7,0x8d1801d9,0xa018023a,0x6298369d}},	//   _majú, _ززُر_, ttöy, ktto, 
   {{0xb6a40323,0xdb204768,0x684002dd,0x42d000cc}},	//   хийл, _شوری, ынша, ানুশ, 
   {{0x7a3039c3,0x7b8402dd,0xa01801e3,0x6298002f}},	//   båta, _تاڭە, dröm, dtto, 
   {{0x6298d83d,0x394c005a,0xdb040030,0xa018005b}},	//   etto, _iges_, _najú, stöy, 
   {{0x386c0a40,0x6298d83e,0x2bd008e6,0x850860c6}},	//   _iwer_, ftto, साया, ьдың_, 
   {{0x386c000f,0x629801bf,0x7ae40108,0xd5b800c0}},	//   _hwer_, gtto, nyht, _мсд_, 
   {{0x386c007f,0xe72c02f2,0x00000000,0x00000000}},	//   _kwer_, _اڵه_, --, --, 
   {{0x6298d83f,0x2bd008a3,0x25d4011a,0x04c8007b}},	//   atto, सामा, _רונן_, _يومي_, 
   {{0x386c0086,0xbde8009e,0x00000000,0x00000000}},	//   _mwer_, _গদগদ_, --, --, 
   {{0x6da4d840,0xada41301,0x62980175,0x23240166}},	//   нива, навл, ctto, _поши_, 
   {{0x386c4f7f,0x394c003e,0x7a300158,0xa01801e3}},	//   _ower_, _nges_, yåta, nröj, 
   {{0xdb04002d,0x63a401ed,0x2ca40142,0x00000000}},	// [124a0] _tajû, őkne, ïod_, --, 
   {{0xa09804ac,0x394cd841,0x317003b9,0x1d200209}},	//   _צייט, _ages_, _heyz_, умум, 
   {{0x386c04d1,0xed589fae,0x8e6400d1,0x2b14d842}},	//   _awer_, _нон_, _шенҗ, хьар, 
   {{0x2efc00d2,0x386cd843,0xe9d8117e,0x7a30248f}},	//   útfu_, _bwer_, яке_, tåta, 
   {{0x394c0175,0x7ae40108,0x27a001ec,0x186400d8}},	//   _dges_, ayht, лқаң, еачи_, 
   {{0xad240075,0x7a300ac8,0x394c65b4,0x629835e5}},	//   _يىگى, råta, _eges_, ytto, 
   {{0x386c0221,0x6298d844,0x2cb000a9,0xa968d845}},	//   _ewer_, xtto, lwyd_, _нива_, 
   {{0x2d90d846,0x1a98010f,0xc0f80092,0x7a30007c}},	//   ngye_, _מילע, ገርህ_, låtn, 
   {{0x2cb00cfd,0x386c0156,0x98a000ee,0xd5cc0208}},	//   nwyd_, _gwer_, _йите, _tềnh_, 
   {{0xa018d847,0x6834002d,0x7af001d3,0x00000000}},	//   tröm, fâde, űjtő, --, 
   {{0x6298d848,0x2cb003cb,0x93a001ec,0x23d00b4c}},	//   utto, hwyd_, ушыд, ताबद, 
   {{0x6298d849,0x386c0ea0,0x6d58d84a,0x00000000}},	//   rtto, _ywer_, _ştan, --, 
   {{0xd5acd84b,0x6600d84c,0xd36c0451,0x00000000}},	//   _دفن_, _imok, _ڇهه_, --, 
   {{0x2cb000a9,0x2d900009,0x9254072d,0x00000000}},	//   dwyd_, egye_, بشیر_, --, 
   {{0x6448d84d,0x6e240e02,0xc0dc02d3,0x31702791}},	//   _iifi, _bkkb, _ሒዞም_, _feyz_, 
   {{0x644806d9,0x442cd84e,0x2cb000a9,0x42040014}},	//   _hifi, lld_, fwyd_, _جستہ, 
   {{0x6448d84f,0x6600d850,0xd1b80150,0x2cb000a9}},	// [124b0] _kifi, _mmok, _سايا_, gwyd_, 
   {{0x64480135,0x7ae4d851,0xcb0800ec,0x75f400e5}},	//   _jifi, tyht, ڙيلن_, _gázf, 
   {{0x64480170,0x442cd852,0x6600d853,0x0a68004e}},	//   _mifi, ild_, _omok, ерчи_, 
   {{0x9a240a52,0x386c015d,0x2cb003cb,0x7ae49e30}},	//   رعان, _pwer_, bwyd_, ryht, 
   {{0x644850c2,0x7ae4023a,0x2cb00142,0x00000000}},	//   _oifi, syht, cwyd_, --, 
   {{0x6600a58f,0x6448ae97,0x442cd854,0x00000000}},	//   _amok, _nifi, jld_, --, 
   {{0x442c04fb,0xa0180267,0xcb3404f0,0xb6f800d1}},	//   dld_, tröj, _беръ, بىغا_, 
   {{0x6448d855,0x442cd856,0x394c037e,0x66000427}},	//   _aifi, eld_, _uges_, _cmok, 
   {{0x6448015c,0x8cc4d857,0x386c01f5,0xa8000213}},	//   _bifi, रियो, _uwer_, ğıro, 
   {{0x64480793,0x660003ac,0xd6d8084c,0xee0c01ad}},	//   _cifi, _emok, _нте_, _िद्ध_, 
   {{0xd244006c,0xd2042002,0xa2bc00dc,0x1db000cd}},	//   лмоқ, лүкк, षिष्, ुयात, 
   {{0x442cd157,0x3f80208d,0x6448d858,0x2cb003cb}},	//   ald_, _adhu_, _eifi, ywyd_, 
   {{0xe3acd859,0x6448d85a,0x442c0142,0x297800df}},	//   _кб_, _fifi, bld_, וטרא, 
   {{0x6448d85b,0x78a8009f,0x3f8000d8,0x442c0332}},	//   _gifi, _mpev, _cdhu_, cld_, 
   {{0x2d941d0b,0xf8a405d9,0xf1d87dad,0x00000000}},	//   крас, _ڏک_, _बचपन, --, 
   {{0x78a812fe,0xa2bc0b98,0x2cb00042,0xa6dc00cc}},	//   _opev, षिर्, twyd_, _ভেঁট, 
   {{0x1d043117,0x64485055,0x7a300158,0xed4406ed}},	// [124c0] вети_, _yifi, tåtn, тнап, 
   {{0x2bd04c5b,0x2cb000a9,0x2ee4004e,0x00000000}},	//   साधा, rwyd_, _ажог, --, 
   {{0xee38402e,0x78a802d0,0x2cb0d85c,0xa018002f}},	//   _оно_, _apev, swyd_, dröh, 
   {{0xa968036b,0x2cb003cb,0x296000c7,0xa9280150}},	//   фида_, pwyd_, рҭаҭ, міле_, 
   {{0x442cd85d,0x2bd0085c,0x7a30007c,0x00000000}},	//   yld_, सादा, måtl, --, 
   {{0x645c06c8,0x660026e7,0xb6c00327,0x2a780175}},	//   _ōpio, _smok, _གནྡྷ, pspb_, 
   {{0x6448d85e,0xc3c40184,0x2ca40003,0xf1b00d2e}},	//   _rifi, ғөлл, ħodu_, ज़ान, 
   {{0x442c0042,0x00000000,0x00000000,0x00000000}},	//   wld_, --, --, --, 
   {{0x442c0c67,0x64480170,0xd9403e07,0x68440124}},	//   tld_, _pifi, _вети, _анаа, 
   {{0x442c0c3b,0x64980137,0x82d801af,0x18642901}},	//   uld_, птүр_, едос_, _рафи_, 
   {{0x442c5ffb,0xd5acd85f,0x3f840008,0x6448014a}},	//   rld_, _кс_, ólum_, _vifi, 
   {{0x6448d860,0x66000117,0xe4a42cdd,0x442c0165}},	//   _wifi, _umok, _арко, sld_, 
   {{0x6448d861,0x25a4003e,0x442c05b1,0x7a14033f}},	//   _tifi, _ibol_, pld_, kątn, 
   {{0x93f00064,0x00000000,0x00000000,0x00000000}},	//   _кпіц, --, --, --, 
   {{0x25a40051,0x00000000,0x00000000,0x00000000}},	//   _kbol_, --, --, --, 
   {{0x4034013e,0xa4a40241,0x67e408a5,0x00000000}},	//   теҳс, _gbòó, _iðju, --, 
   {{0x25a4b7e6,0xae000210,0x00000000,0x00000000}},	// [124d0] _mbol_, रोधन_, --, --, 
   {{0x3f8001c8,0xa01801a8,0x2004010e,0x4ba800cf}},	//   _udhu_, dsög, _öni_, көсү_, 
   {{0x78a801f1,0x25a401a6,0x75f4634d,0x629402f0}},	//   _spev, _obol_, _háze, _úboč, 
   {{0xa0180008,0x75f402f0,0x49940212,0x00000000}},	//   fsög, _káze, ишіт, --, 
   {{0x34d00b67,0x41a408df,0xa01808a5,0x00000000}},	//   _तपेद, ग्यस, gsög, --, 
   {{0x25a47821,0x00000000,0x00000000,0x00000000}},	//   _abol_, --, --, --, 
   {{0x35a42be5,0x75f400bc,0x17f00b3c,0x96d00116}},	//   гайг, _láze, _अतीव_, рслә, 
   {{0xa01807de,0x668c00e4,0xa2d408df,0xdcec01ef}},	//   bsög, _ẽmín, यमन्, _lecč, 
   {{0x78a80588,0x75f40316,0x383400c7,0x737401c0}},	//   _upev, _náze, _бнар, лынх, 
   {{0x7c240122,0x25a40142,0x8cc4041c,0x61fc00c0}},	//   nohr, _ebol_, रितो, _įpla, 
   {{0x6d58d862,0xa06401e0,0x32440334,0xf5941291}},	//   _ştam, ғаса_, леог, _ملاج, 
   {{0x7c24014f,0xa15400c7,0x74f800d8,0xd3680150}},	//   hohr, лаџу_, _пеер_, _ﺳﺘﯩﻖ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7984013f,0xc3041968,0x69c803ba,0x2934010f}},	//   ɔhwe, ابیو, _सोनी, טארן_, 
   {{0x7c24d863,0x2bd00073,0xa018007c,0xf2a4374e}},	//   dohr, सासा, dsöd, _сийп, 
   {{0x75f429e8,0xeb3400d1,0x00000000,0x00000000}},	//   _házb, ۇراخ, --, --, 
   {{0x2bc8d864,0x44d80327,0xa5c403f2,0xafe401a9}},	// [124e0] нлап_, ིདགཞ, lgóð, _бопл, 
   {{0xcb5c010e,0x690403e3,0xa01801f4,0x00000000}},	//   _gorь, _üsdə, yröi, --, 
   {{0xdca06294,0xfbc81bcf,0x75f40308,0x29842eca}},	//   _қари, राजम, _záze, гылг, 
   {{0x8cc477d7,0x356801f3,0x2bd006ff,0x00000000}},	//   रिदो, ሰንበት_, साहा, --, 
   {{0x7c240112,0x99240064,0x02b00412,0xda980166}},	//   bohr, люша_, _जन्न, _үссә_, 
   {{0xa0180008,0x7d740014,0xe3e001ec,0x00000000}},	//   rsög, _مۅہر_, _ﺇﻀﺎﻓ, --, 
   {{0xf408015b,0x00000000,0x00000000,0x00000000}},	//   রকার_, --, --, --, 
   {{0x2bd04709,0x48c4008e,0xd6240114,0xa01801f4}},	//   सावा, _вәка, лоје_, rröi, 
   {{0xc22403e6,0x69c80073,0x00000000,0x00000000}},	//   یکبو, _सोयी, --, --, 
   {{0x4dc000fe,0x75f4013a,0x00000000,0x00000000}},	//   _একোৱ, _ráze, --, --, 
   {{0x75f400bc,0x16840133,0xe5680107,0x00000000}},	//   _sáze, _مانێ, _зиед_, --, 
   {{0x91a00034,0x7c240030,0xe61800a7,0x2164005b}},	//   ग्लै, zohr, _яде_, ытог, 
   {{0xb060013d,0x40340395,0x00000000,0x00000000}},	//   _şära, иемс, --, --, 
   {{0x270c06be,0x00000000,0x00000000,0x00000000}},	//   _kən_, --, --, --, 
   {{0x7c240306,0x2284013d,0xa01801e3,0x00000000}},	//   vohr, _сулг, vsöd, --, 
   {{0x270c0cc1,0xdeb00046,0x443c2142,0x387c0142}},	//   _mən_, _құбы, _hhv_, yswr_, 
   {{0x61ec009a,0xa0180267,0x7bc006ea,0x7c24d865}},	// [124f0] mkcl, dröv, _óluk, tohr, 
   {{0xcc880af6,0x61ec0165,0x46b4000d,0xffc40150}},	//   انله_, lkcl, _अईंह, _төмп, 
   {{0x7c24d866,0x443c01bf,0xabb40022,0xb954011c}},	//   rohr, _mhv_, рахә, авещ, 
   {{0x3c94036b,0x443c00c5,0x61ec18b0,0x8b8800db}},	//   _кимё, _lhv_, nkcl, _ەەلە_, 
   {{0x7c2402f0,0x395c0142,0xc30800eb,0x00000000}},	//   pohr, rcws_, _রুমি_, --, 
   {{0x270c06be,0x69c4d867,0xdb04002f,0xc8644a1a}},	//   _bən_, _óken, _kajü, ётчи, 
   {{0xec340302,0x2bd0810b,0x3618023a,0xf6d40212}},	//   _כאשר_, सारा, кцию_, ріля, 
   {{0x270c03be,0x15441772,0x443cd868,0x348401b9}},	//   _dən_, _መሳፍን, _ahv_, агиг, 
   {{0x443c78d6,0x00000000,0x00000000,0x00000000}},	//   _bhv_, --, --, --, 
   {{0x7a30007c,0x76a8210e,0x00000000,0x00000000}},	//   kåtk, _لُطف_, --, --, 
   {{0xddc40953,0xa3c40037,0x35b400d4,0x87040153}},	//   gpjū, _उफर_, _вбер, _ляце, 
   {{0xdb0401ed,0x443cd869,0xa5c40d12,0x00000000}},	//   _hajó, _ehv_, rgóð, --, 
   {{0x7e64d86a,0xdb0400e4,0x13a4d86b,0x443c01bf}},	//   _athp, _rajý, _منشی_, _fhv_, 
   {{0xa064d86c,0xcdc40588,0x00000000,0x00000000}},	//   рара_, әаақ, --, --, 
   {{0xdb048b9d,0x7ed400d4,0x00000000,0x00000000}},	//   _majó, бітч, --, --, 
   {{0x61ec18b0,0xc0f81ee0,0x7e5400c7,0xad6406c2}},	//   ckcl, ገርም_, стрц, شاره, 
   {{0xeb98d86d,0x7c6400d1,0x6b54030d,0x222800e5}},	// [12500] киа_, مالل, атех, _جزوی_, 
   {{0x272001f1,0xaf040a8f,0xafc400db,0x77600334}},	//   nčné_, _впол, _ئيدى, _nflx, 
   {{0xf1d80034,0x6da4340b,0xdb0400c7,0xada448bc}},	//   _बचान, _кина, _tajý, _канл, 
   {{0xa9a400c2,0xed5867d7,0xa8c4010b,0x28e80209}},	//   ридд, _шом_, ийед, кдеп_, 
   {{0x270c03be,0xdb040789,0x27200030,0x98a000d8}},	//   _sən_, _bajó, kčné_, жиче, 
   {{0xdb04d86e,0x1864026a,0x60d80112,0x6f00002b}},	//   _cajó, шаљи_, äumi, _śocy, 
   {{0x443c070d,0xa0180267,0xda9800fd,0x00000000}},	//   _rhv_, pröv, _истә_, --, 
   {{0xe5c43a8a,0x443c02fa,0x75f40419,0xe4a458e5}},	//   рско, _shv_, _rázc, ароо, 
   {{0x2848d86f,0xbb48005e,0x69c001f5,0x75f401ef}},	//   _азап_, _ﺇﻟﻰ_, mdoe, _sázc, 
   {{0x69c03441,0x270c03b9,0x7d080432,0xa018007c}},	//   ldoe, _tən_, _ýese, nröt, 
   {{0x443c03d1,0x5b540a7c,0x00000000,0x00000000}},	//   _vhv_, ישין_, --, --, 
   {{0x64a4d870,0x27200030,0xa0180b8b,0x00000000}},	//   _вада, ačné_, hröt, --, 
   {{0x69c00007,0x6560d871,0xa01817da,0x443c0582}},	//   idoe, _ifoh, kröt, _thv_, 
   {{0x69c00007,0x3f840af2,0xdb04007f,0xd01800c7}},	//   hdoe, ûlu_, _majò, афс_, 
   {{0x64b41a22,0x75f400dd,0x69c0d872,0x645c00b0}},	//   _अनुश, _háza, kdoe, _ōpih, 
   {{0x75f402f0,0x3f8c054e,0x7d540395,0x00000000}},	//   _káza, şeu_, свах, --, 
   {{0x69c00368,0xdb04007f,0x00000000,0x00000000}},	// [12510] ddoe, _najò, --, --, 
   {{0x69c00373,0x00000000,0x00000000,0x00000000}},	//   edoe, --, --, --, 
   {{0x75f47009,0x69c00942,0xbb480150,0xdb0400d7}},	//   _láza, fdoe, _ﺇﻟﻲ_, _rajó, 
   {{0x69c0057b,0x8cc41be1,0x00000000,0x00000000}},	//   gdoe, रिशो, --, --, 
   {{0xa01826bc,0xdb58d873,0x00000000,0x00000000}},	//   bröt, _аюб_, --, --, 
   {{0xefd0067d,0x656005da,0xa0180267,0x57a4009d}},	//   _ከምዚ_, _afoh, mrös, ршда, 
   {{0x29c80228,0xc668026a,0xdb0400d5,0xda48014b}},	//   _өттү_, ашње_, _objé, _ачал_, 
   {{0x75f4043b,0x88a40133,0x58840108,0x00000000}},	//   _báza, _ژینۆ, _выжа, --, 
   {{0xa018007c,0xc98400d8,0xd7d400ec,0x00000000}},	//   nrös, _фуси, _پهاڙ_, --, 
   {{0x7a3005ac,0x7a14012d,0x668000e5,0x7d0802d2}},	//   dåti, kątk, _کیٹل, _þesu, 
   {{0x7a14068f,0xb2246963,0x48240131,0x27201d55}},	//   jątk, ймол, _بىلق, rčné_, 
   {{0xa0180998,0xdb0400cd,0x75f40419,0xf1f806c2}},	//   krös, _jajñ, _fáza, اعدت_, 
   {{0x70540597,0x2d9401e0,0xa0a001d5,0x27200419}},	//   إنسا, ҙөнө_, паяд, pčné_, 
   {{0x69c00399,0x7d0801e4,0x00000000,0x00000000}},	//   zdoe, _ɾest, --, --, 
   {{0x625c02b5,0x69c00142,0x00000000,0x00000000}},	//   _hīon, ydoe, --, --, 
   {{0x69c00399,0x8cc40ad7,0x60e4036e,0x8d7800c7}},	//   xdoe, रिलो, ërmë, шәоу_, 
   {{0x69cc013f,0x9d40d874,0xa01826bc,0x799802d0}},	// [12520] _ɔbed, зетд, grös, dgww, 
   {{0x3a2cd875,0x80e0009e,0x6b54d876,0x7e680841}},	//   _akep_, _পেক্, стах, ćepr, 
   {{0xdcec0029,0x7d0808a4,0x74ac00bd,0x69c0257d}},	//   _vecā, _žest, কটিউ, tdoe, 
   {{0x69c00369,0xe8f8d877,0xafc40137,0xa018007c}},	//   udoe, лле_, _ئيگى, brös, 
   {{0x69c023f3,0x7c800184,0x48080124,0xa018007c}},	//   rdoe, _оҫта, аҵан_, mrör, 
   {{0xab280b74,0x69c023f3,0xa0180267,0x75f4013d}},	//   _бога_, sdoe, lrör, _ráza, 
   {{0x75f400bc,0x69c00af9,0x638001e7,0x260401c4}},	//   _sáza, pdoe, híní, йчиг, 
   {{0x69c00007,0xa0180267,0xa2d401bc,0x9b14011a}},	//   qdoe, nrör, यमस्, _החלה_, 
   {{0xe4e400d3,0x7a14012d,0x00000000,0x00000000}},	//   сійн, zątk, --, --, 
   {{0x75f40ac0,0x38040022,0xa01802d2,0x00000000}},	//   _váza, _доуҳ, hrör, --, 
   {{0xdb040882,0xa018007c,0x00000000,0x00000000}},	//   _yajñ, krör, --, --, 
   {{0x574005f5,0x7a300158,0x7bc00174,0x63800332}},	//   _энхб, tåti, _óluv, fíní, 
   {{0x75f40306,0xa018007c,0x653400f2,0xcbc800cd}},	//   _kázn, drör, _اراذ, रयाञ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8d98001f,0xa6a00150,0x7a30007c,0xdda8009d}},	//   _ጌታቸው_, _ﺍﻛﻪﻝ_, måtv, лтал_, 
   {{0x75f4012c,0xa01826bc,0xdcec054e,0x2bcc01ad}},	//   _lázn, trös, _necă, _होबा, 
   {{0x9f4008e5,0x51f401ec,0xae001df1,0x7cd821b4}},	// [12530] ghjò_, _ءسىر, रोइन_, шмар_, 
   {{0x3a2c0151,0x41a42c2e,0x75f402fb,0xdb0400b8}},	//   _skep_, ग्रस, _názn, _sajñ, 
   {{0x795800c7,0x9a8400ee,0x00000000,0x00000000}},	//   аиер_, сузл, --, --, 
   {{0xfbd000ec,0x00000000,0x00000000,0x00000000}},	//   _ڪڪر_, --, --, --, 
   {{0x9f400268,0xdcec054e,0xdbd40166,0x7a3001e3}},	//   chjò_, _decă, _käüs, kåtv, 
   {{0xab600075,0xf77000c6,0x907cd878,0x00000000}},	//   _يۇقى, ذات_, נטוי, --, 
   {{0x7bc401c8,0xcf94008f,0x66e0117e,0x00000000}},	//   mdhu, לטס_, доща, --, 
   {{0x7d080f99,0xf5e801f4,0x00000000,0x00000000}},	//   _þess, рмил_, --, --, 
   {{0x7bc4d879,0x7988127b,0x41dc1fe7,0x97a40108}},	//   odhu, _idew, यानस, _грел, 
   {{0x7bc4d87a,0xb6c801ed,0x78ac0200,0xfdc400cc}},	//   ndhu, _پائے_, çavu, _একোড, 
   {{0x7bc4d87b,0x24ac0150,0x00000000,0x00000000}},	//   idhu, _ﺳﻴﻼﻣ, --, --, 
   {{0x75f42195,0x625c00b0,0x79880327,0x7bc40332}},	//   _zázn, _tīon, _jdew, hdhu, 
   {{0x7bd4d87c,0x7988031c,0x7bc40066,0xd344036b}},	//   _onzu, _mdew, kdhu, _گیده_, 
   {{0xae0002ab,0x23c401d9,0xa30800e5,0x00000000}},	//   रोईन_, _وٕنہ, اریے_, --, 
   {{0xed58d87d,0xd344d87e,0x71a400ee,0xdbd40166}},	//   иов_, _دیده_, _дайз, _däüs, 
   {{0x7bd4d87f,0x7988d880,0xd0480213,0x7bc401f5}},	//   _anzu, _ndew, _ələk, edhu, 
   {{0xac08d881,0x7bc401a4,0xa0180267,0xdcec054e}},	// [12540] анаа_, fdhu, rrör, _recă, 
   {{0x7bc4d882,0x7988d883,0x95440020,0xa0180267}},	//   gdhu, _adew, _የኢንተ, srör, 
   {{0x75f4d884,0x2bcc05ba,0x79880327,0xa01801e6}},	//   _názo, _होणा, _bdew, prör, 
   {{0x7bd4d885,0x7bc40ba7,0x28685211,0x41dc012a}},	//   _enzu, adhu, арко_, यायस, 
   {{0x798800a9,0x6364012c,0xaec402dd,0xe50c012c}},	//   _ddew, nční, _ءﺗﻴﯩ, ापछि_, 
   {{0x6e34d886,0x7988d887,0x75f400d7,0x00000000}},	//   llyb, _edew, _bázo, --, 
   {{0xf1c81025,0xdcec054e,0x41dc1fe7,0x75f4013a}},	//   ियान, _tecă, यामस, _vázn, 
   {{0x2bcc0412,0x6e340784,0x636400bc,0xa0180b8b}},	//   _होता, nlyb, kční, hröp, 
   {{0x1864d888,0x758000f2,0xe7b4020c,0x00000000}},	//   _мати_, ریوم, _ومرد, --, 
   {{0x03f80063,0x75f4d889,0x8ec000cc,0x386800e4}},	//   сној_, _fázo, _উপনগ, íare_, 
   {{0x6fdcc39f,0x75f401d3,0xa1a00150,0xdd2c01ef}},	//   मानं, _gázo, _ﺃﻋﺭﻑ_, _měšc, 
   {{0x629400b8,0x00000000,0x00000000,0x00000000}},	//   _āyod, --, --, --, 
   {{0x1074d88a,0x7a303e04,0x909812e7,0x6e343607}},	//   мляю, mått, овят_, dlyb, 
   {{0x24840e04,0x7a30143a,0x7bc40009,0x7e640124}},	//   _ivom_, lått, xdhu, зхаҵ, 
   {{0x442cd88b,0xefc0044e,0x63640118,0x6e34d88c}},	//   mod_, ስትዮ_, ační, flyb, 
   {{0xe244d88d,0x7bc4045a,0x60d8002f,0xa01800e5}},	//   _بختي, wdhu, äums, csön, 
   {{0xa8000365,0x3b000208,0xc4bc0709,0x00000000}},	// [12550] şıyo, wzhq_, ्टिओ, --, 
   {{0x442cd88e,0x6d58d88f,0x7bc4d890,0x629c01b8}},	//   nod_, _ştat, udhu, _äpos, 
   {{0x7bc4d891,0x80e002f5,0x6e3402d0,0x442c0042}},	//   rdhu, _পেচ্, blyb, iod_, 
   {{0x24841326,0x442cd892,0x75f403da,0x6e3402d0}},	//   _ovom_, hod_, _rázo, clyb, 
   {{0x442cd893,0x00000000,0x00000000,0x00000000}},	//   kod_, --, --, --, 
   {{0x442cd894,0x7bd417da,0xd7e400db,0x00000000}},	//   jod_, _unzu, توتۇ_, --, 
   {{0x442cd895,0x69a402ab,0x2484022e,0x00000000}},	//   dod_, _टॉकी, _avom_, --, 
   {{0x7a303402,0xaa4000d1,0xdef40092,0x00000000}},	//   gått, _كۆلى, ለሁና_, --, 
   {{0x442cd896,0xdb0404cc,0xf1c800bc,0x7bc002d2}},	//   fod_, _cajö, ियसन, _ólus, 
   {{0x442cd897,0x730400a7,0x7d0801e4,0x24843883}},	//   god_, зпоз, _ɾesp, _dvom_, 
   {{0xdb0402fb,0xf40c0183,0x054c0064,0xa018007c}},	//   _objí, সকলৰ_, _žūtį_, tsön, 
   {{0x955c0092,0xabe00150,0x7a30007c,0x00000000}},	//   ሰቦችን_, _ﺍﻷﻤﺎ, måts, --, 
   {{0x442cd898,0xa0180639,0x7648d899,0x2b1002e5}},	//   bod_, rsön, mmey, _धेनु_, 
   {{0x7648d89a,0x7fd4d89b,0x442cd89c,0x4de80ed1}},	//   lmey, місі, cod_, ﺎﺳﯩﻨ, 
   {{0xb8dc49a6,0xd34401b9,0x76480009,0x6e3402d0}},	//   _ཇར_, _گیگه_, omey, tlyb, 
   {{0x7648d89d,0xe1fc0407,0xee38d89e,0x7084d89f}},	//   nmey, chó_, ёна_, _егиз, 
   {{0xd344034c,0x7648d8a0,0x75f401ef,0x802400ec}},	// [12560] _دیگه_, imey, _rázl, _ڪريم, 
   {{0x76480978,0x5eb8015b,0xbc2406ba,0x7a30007c}},	//   hmey, _উপরে, ورلى, kåts, 
   {{0x7648d8a1,0xdb140ba1,0xa018023a,0x6e340175}},	//   kmey, nexè, isöl, plyb, 
   {{0x442cd8a2,0x7648047e,0x6cc4022e,0x00000000}},	//   zod_, jmey, _ейма, --, 
   {{0x442cd8a3,0xed50034c,0xed3401c0,0x7648047e}},	//   yod_, _سپس_, _хэнэ, dmey, 
   {{0x29180311,0x764804ba,0xdc640902,0xd2d800bc}},	//   ăpa_, emey, _хард_, यमाझ, 
   {{0x24841326,0x8cc4d8a4,0x7648d8a5,0x7a3003cd}},	//   _svom_, रिको, fmey, tått, 
   {{0x442cd8a6,0xc9d40811,0x7648d8a7,0x00000000}},	//   wod_, _تمرک, gmey, --, 
   {{0x290004f3,0xe8e812ea,0x287400c7,0xe8f80408}},	//   _åka_, _ارزو_, _хыбр, _ула_, 
   {{0xb8640372,0x7648d8a8,0xfa080327,0x7a30007c}},	//   _زاكو, amey, _གཏོན_, båts, 
   {{0xe4d8d8a9,0x66740133,0x7648047e,0xa6c80b24}},	//   _گوشت_, _ردار, bmey, _دوال_, 
   {{0x24840b91,0x442cd8aa,0x65940150,0xd2540953}},	//   _tvom_, sod_, _ءجار, яць_, 
   {{0x442cd8ab,0x00000000,0x00000000,0x00000000}},	//   pod_, --, --, --, 
   {{0x442c9d78,0x6834002d,0xc7b4010f,0x14d4011a}},	//   qod_, fâdi, ובֿ_, _מודל_, 
   {{0x5330d8ac,0xe1fc00d2,0x0b0000cc,0x95ec0154}},	//   _пешт, phó_, ্থুল_, টফরম_, 
   {{0x63b8d8ad,0x753c068f,0xfa080327,0x6d580139}},	//   letn, ższe, _གཏེན_, _ştar, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [12570] --, --, --, --, 
   {{0x629801c8,0x76489d25,0xdb140129,0xef0c01e2}},	//   outo, zmey, lexé, اڼی_, 
   {{0x7648d8ae,0x44e00165,0x6e28020c,0xa5c4033f}},	//   ymey, _lʲ_, èmbè, _zróż, 
   {{0x3914d8af,0x39341e38,0x75f44487,0x63b800dd}},	//   ммер, _ኢሳይያ, _pázm, hetn, 
   {{0x6298d8b0,0x7648d8b1,0x2bcc0882,0x9cc801af}},	//   huto, vmey, _होवा, _уына_, 
   {{0x6298d8b2,0x63b8d8b3,0x3dc800ee,0x7648014f}},	//   kuto, jetn, ldaw_, wmey, 
   {{0x63b83847,0x7648d8b4,0x7ac801d9,0x6d6401b8}},	//   detn, tmey, _بوزِ_, _ätaö, 
   {{0x6298d8b5,0x7648d8b6,0xceb400d9,0x3dc8d8b7}},	//   duto, umey, תיק_, ndaw_, 
   {{0x7648d8b8,0xd8740220,0x7a3005ac,0xdb14d8b9}},	//   rmey, _ءارب, båtr, dexé, 
   {{0x386cd8ba,0x7648d8bb,0x3dc803a2,0x437402bf}},	//   _iter_, smey, hdaw_, нуют, 
   {{0x6298d8bc,0x3dc8089c,0x7648047e,0x00000000}},	//   guto, kdaw_, pmey, --, 
   {{0x386c0585,0x7648016d,0xa5c4012d,0x00000000}},	//   _kter_, qmey, _próż, --, 
   {{0x63b8d8bd,0x3dc80142,0x00000000,0x00000000}},	//   betn, ddaw_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6da43d03,0xa5c4033f,0x3dc8031c,0x00000000}},	//   мива, _wróż, fdaw_, --, 
   {{0xee381c26,0x386cd8be,0xd20400db,0xb224187f}},	//   іна_, _oter_, _чүмк, _імпл, 
   {{0x20c0107b,0xa0180108,0x00000000,0x00000000}},	// [12580] _айым, isöj, --, --, 
   {{0xdcac1a59,0x3dc803a2,0xeaf8d8bf,0x9d400220}},	//   شىم_, adaw_, يرات_, теуд, 
   {{0x386cd8c0,0xfbd000dd,0xed58d8c1,0x59cc60c7}},	//   _ater_, ھتے_, _мон_, _सोहर, 
   {{0xe9d8d8c2,0x78700022,0x32000208,0xae10000d}},	//   غذات_, _ẽvar, nhky_, _ठगिन_, 
   {{0x307800c8,0x625c00b0,0x629804ce,0x06a80150}},	//   קאַנ, _pīok, zuto, _ﺴﻴﻘﺩ, 
   {{0xccf4016b,0x75f401ed,0x6298d8c3,0x58d0d8c4}},	//   myɛ_, _házh, yuto, тошт, 
   {{0x63b82a3f,0x386c38bc,0x75f401d3,0x62980de2}},	//   vetn, _eter_, _gázk, xuto, 
   {{0x6298d8c5,0x386c0295,0x2fc80175,0x63b8003e}},	//   vuto, _fter_, hdbg_, wetn, 
   {{0x625c00b0,0x8cc4012c,0xccf4013b,0xc82400c7}},	//   _tīok, रिटो, nyɛ_, _ззақ, 
   {{0x6298d8c6,0x625c00b0,0x427405f5,0xa9240064}},	//   tuto, _hīoi, нгос, _vežę, 
   {{0x62981c06,0xccf40605,0x65c46eec,0x261800b0}},	//   uuto, hyɛ_, _обжа, hīoi_, 
   {{0x6298d8c7,0x63b8a7fd,0x51f80962,0xccf40134}},	//   ruto, setn, днюю_, kyɛ_, 
   {{0x386c1529,0x6298d8c8,0xd5ac0214,0x68e0022e}},	//   _xter_, suto, _خفن_, nxod, 
   {{0x2bcc012c,0xa01801e3,0xe6ac013a,0x00000000}},	//   _होला, msök, _léčí, --, 
   {{0xa0180267,0x8f34d8c9,0x3dc800b5,0x4034008e}},	//   lsök, верц, tdaw_, _җенс, 
   {{0x3200014b,0x3eac0327,0x88c40055,0x00000000}},	//   chky_, ċet_, _āśnu, --, 
   {{0x3c443306,0xa01801e6,0x40340276,0x7c580131}},	// [12590] َّذِ, nsök, _пеис, سلار_, 
   {{0x68e00009,0xa0180108,0xad4400cf,0x00000000}},	//   dxod, isök, رىلۉ, --, 
   {{0x386cd8ca,0x3f80d8cb,0x23a4a064,0x3a74010b}},	//   _ster_, _iehu_, _खानद, хлер, 
   {{0x3f8000b0,0x09e400d4,0x00000000,0x00000000}},	//   _hehu_, коєн, --, --, 
   {{0x0ca8010b,0x3f80d8cc,0x47c80154,0xa3bc09ab}},	//   _отри_, _kehu_, লানী, ँजा_, 
   {{0x3f80d8cd,0xf7440262,0x386c003a,0xa018007c}},	//   _jehu_, нело, _vter_, dsök, 
   {{0x3f80d8ce,0x75f400dd,0x68100210,0x320001f4}},	//   _mehu_, _házi, ałdo, yhky_, 
   {{0xcf580d65,0x3f80d8cf,0x20cc00ef,0x68e00166}},	//   ובות_, _lehu_, _oļi_, bxod, 
   {{0x386cd8d0,0x6288143a,0x176800a8,0xd05001e4}},	//   _uter_, _avfo, _дреп_, _ĝeɾm, 
   {{0x3f800652,0xe56cd8d1,0x38a8d8d2,0x87d46e0c}},	//   _nehu_, _әз_, múr_, _لغما, 
   {{0x38a8d8d3,0xf5380092,0x95c800f0,0xd24401d5}},	//   lúr_, _የዳኝነ, _муда_, кмоқ, 
   {{0xd58403e6,0x85740484,0xb41400d7,0xe2f00022}},	//   _کێکه_, _алцх, _šúľa, узџь, 
   {{0x3f800134,0x62880427,0xa01801ed,0x944000c7}},	//   _behu_, _evfo, csök, _иҭиж, 
   {{0x20000c95,0x76580784,0x3f80d8d4,0xf8a40133}},	//   ghji_, _hiwy, _cehu_, _ێک_, 
   {{0xccf4016b,0x38a801f6,0x00000000,0x00000000}},	//   wyɛ_, húr_, --, --, 
   {{0x75f401d3,0x3e500210,0x00000000,0x00000000}},	//   _bázi, _kąty_, --, --, 
   {{0xdd8c41ff,0x3f8008f5,0xeb985bfc,0x7c645856}},	// [125a0] صول_, _fehu_, зиз_, نالل, 
   {{0x20000c95,0xe8f805f5,0x3f800098,0x38a8d8d5}},	//   chji_, үлж_, _gehu_, dúr_, 
   {{0x625c02b5,0x2c50007f,0x47c8015b,0x274400bc}},	//   _pīoi, _jņdi_, লামী, _míní_, 
   {{0xa924d8d6,0x76580042,0x75f401d3,0xda600798}},	//   ндел, _niwy, _fázi, увци, 
   {{0x27fc0263,0x3f80013b,0x6b8c0175,0xefc00023}},	//   _pltn_, _yehu_, _tdbg, _ስሱዕ_, 
   {{0x2d80d8d7,0x29041b08,0x27440241,0x68e0022e}},	//   _heke_, rzoa_, _níní_, rxod, 
   {{0x2d8008f5,0x4df48360,0x75380208,0x00000000}},	//   _keke_, _इकाई_, _aywz, --, 
   {{0x2d80d8d8,0x45d413dc,0x69e00118,0x85b8d8d9}},	//   _jeke_, тоис, áteč, флис_, 
   {{0x2814d8da,0x2d80d8db,0x76580cfd,0xd1d80023}},	//   _كورس, _meke_, _diwy, ዮናት_, 
   {{0xa0180628,0x66e41c83,0x779002f2,0xe73800d8}},	//   rsök, _поза, _نیها, _еез_, 
   {{0x3f80d8dc,0xb35400f2,0xa0184268,0x00000000}},	//   _rehu_, نیها_, ssök, --, 
   {{0x3f800fac,0xa0180267,0xdb04269e,0x753c0210}},	//   _sehu_, psök, émér, ższa, 
   {{0x3f80d8dd,0x2000009a,0xf1d400ce,0x00000000}},	//   _pehu_, thji_, धाजन, --, 
   {{0x76580165,0x439408ca,0xf044009d,0x00000000}},	//   _ziwy, _ракс, вьсү, --, 
   {{0x2d8058a1,0x26c80042,0x53a0399f,0x842400cf}},	//   _beke_, _âbod_, _сајб, _كىچن, 
   {{0x3f80009f,0x2d80acd3,0xa0180108,0xe684013a}},	//   _wehu_, _ceke_, isöi, jžíš, 
   {{0x4c94d8de,0x2d80d8df,0x7d5400a7,0x3f80d8e0}},	// [125b0] литс, _deke_, твах, _tehu_, 
   {{0x2d8006c8,0xfe70d8e1,0x214402b5,0x9b24009b}},	//   _eeke_, _نگر_, ēwhē_, нфел, 
   {{0x2d80d8e2,0x2010025c,0x2ec02cc8,0xa01801d3}},	//   _feke_, _imxi_, _көтм, kröz, 
   {{0x38a8d8e3,0x2d802112,0x98bc0327,0x00000000}},	//   túr_, _geke_, _jfuħ_, --, 
   {{0x6738010b,0x109000d1,0xc98400d8,0x00000000}},	//   _aytj, ﭙﯩﺪﯨ, ѓуци, --, 
   {{0x2d80004c,0x38a8022c,0x67380af9,0x41dc2d81}},	//   _zeke_, rúr_, _bytj, याँस, 
   {{0xa01848b3,0x2d8024ba,0x38a800c6,0x3d140490}},	//   rsöh, _yeke_, súr_, _नेते_, 
   {{0xa0180295,0x38a801a8,0xd880028e,0x27448a9a}},	//   ssöh, púr_, _مهری, _síní_, 
   {{0xc568007b,0x00000000,0x00000000,0x00000000}},	//   رحيل_, --, --, --, 
   {{0x75f403c6,0x3364023b,0x00000000,0x00000000}},	//   _názv, ъвог, --, --, 
   {{0x41dc93cb,0x00000000,0x00000000,0x00000000}},	//   यांस, --, --, --, 
   {{0x3f8401a8,0x35f402e8,0x00000000,0x00000000}},	//   ðlun_, _шпер, --, --, 
   {{0x2d80d8e4,0x54b01945,0xe44c1985,0x00000000}},	//   _reke_, _сәйф, _вж_, --, 
   {{0x2d80d8e5,0x94200150,0x32d400d8,0x00000000}},	//   _seke_, _حوتۇ, _ацис, --, 
   {{0x2d80d8e6,0x91a0004d,0x53480408,0x5198010a}},	//   _peke_, _chị_, _хăвă, _пăва, 
   {{0x2d80d8e7,0x00000000,0x00000000,0x00000000}},	//   _qeke_, --, --, --, 
   {{0x6c3458fb,0x25b00365,0x2d80d8e8,0x00000000}},	// [125c0] نفرا, _öyle_, _veke_, --, 
   {{0x2d800151,0xa09804ae,0x7a14033f,0xc3080154}},	//   _weke_, _קייט, wątp, _রুটি_, 
   {{0x2d80d8e9,0x91a0063f,0xbad40953,0x6b54074d}},	//   _teke_, _ghị_, ліцы, ттах, 
   {{0x75f4d8ea,0x6738017a,0xda2000c7,0x00000000}},	//   _kázu, _rytj, аҧсқ, --, 
   {{0x186423b3,0x25a40175,0x67380200,0xf1a8d8eb}},	//   вачи_, _rcol_, _sytj, _कानन, 
   {{0xa8500348,0x25a4d8ec,0x6d44d529,0x67380023}},	//   шелә, _scol_, _izka, _pytj, 
   {{0x1ae0d8ed,0xeb340e56,0x28740124,0x628c0327}},	//   _корм, _شىرد, хыҵр, ġbok, 
   {{0x69c800c5,0x00000000,0x00000000,0x00000000}},	//   _सोची, --, --, --, 
   {{0xe7a800ee,0xe4e400d4,0x260c0210,0xe7e000cd}},	//   _овал_, тійн, तोषी_, पादप, 
   {{0x97740022,0xdb680023,0xa01801e3,0xc0c40124}},	//   _атцә, ድሕዶም_, lsöv, ҳәои, 
   {{0xdd2c00bc,0x25a40175,0xd70401ee,0x75f40419}},	//   měťo, _tcol_, _инфе_, _rázv, 
   {{0x21f000ee,0x6d440205,0xf2340133,0xa01801e3}},	//   рҗис, _ozka, ێبێک, nsöv, 
   {{0x66000751,0x4aa401ad,0xa01801f4,0xbe2400c7}},	//   _ilok, खंडव, isöv, ҳчақ, 
   {{0x6600d8ee,0xdb140261,0x7d0800ee,0x00000000}},	//   _hlok, nexã, _ýesi, --, 
   {{0x6d4405f5,0xbe6406f6,0xdb140005,0x98bc0327}},	//   _azka, اهري, texí, _tfuħ_, 
   {{0x6e24579d,0xd3540302,0xf1a80d2c,0x91e400f3}},	//   _cjkb, _בשוק_, _कायन, _воће, 
   {{0x660077fb,0xdb140077,0x98a00024,0xa01801e3}},	// [125d0] _mlok, rexí, _ąjį_, dsöv, 
   {{0x6600d8ef,0xc684021a,0x62980af5,0x75f401ed}},	//   _llok, _وې_, orto, _házt, 
   {{0x6600d8f0,0xfb14d8f1,0xf1a83be5,0x6d44009d}},	//   _olok, دواج, _कामन, _ezka, 
   {{0x6298023a,0x0a940212,0x660001e1,0xa01801e3}},	//   irto, рацю, _nlok, gsöv, 
   {{0x0c841e76,0x4c940139,0x2bcc0829,0x00000000}},	//   _высм, _кияс, _होका, --, 
   {{0x6600d8f2,0x7e640263,0x00000000,0x00000000}},	//   _alok, _kuhp, --, --, 
   {{0xe734d8f3,0x7e640455,0x8e9002d3,0x81e800fe}},	//   леш_, _juhp, _ዝኾነሉ_, _যতন_, 
   {{0x69cc013f,0x66000055,0xa01800e5,0x00000000}},	//   _ɔbek, _clok, csöv, --, 
   {{0x6298d8f4,0x64480597,0x17c41ee3,0x236c0175}},	//   erto, _bhfi, _аҳли_, _bffj_, 
   {{0x6600d8f5,0x0478158b,0x75f40419,0x2164024c}},	//   _elok, کلیک_, _rázu, ғири_, 
   {{0x6600d8f6,0xc6a4009b,0x00000000,0x00000000}},	//   _flok, _врчи, --, --, 
   {{0x66000489,0x95d00354,0x00000000,0x00000000}},	//   _glok, _тăма_, --, --, 
   {{0x62980af5,0x1bf0000d,0x853402f2,0x05740244}},	//   arto, _आकंल_, _پووچ, _ئامد, 
   {{0x5eb803f4,0x6fdc068f,0xdd200122,0x6600d8f7}},	//   _উপজে, माइं, _béžo, _zlok, 
   {{0x7f180845,0x995400e8,0xdd2c0118,0x6d440c57}},	//   віту_, _wàňi_, měřo, _szka, 
   {{0xd6cc1ac3,0x82340050,0x66000135,0x75f400e5}},	//   стi_, _پر٘ا, _xlok, _gázt, 
   {{0x75f401d3,0xe4680254,0xeb980395,0xec480108}},	// [125e0] _házs, miöö_, етещ_, езал_, 
   {{0x6d4402fd,0x2078008f,0xdca020c2,0x5ba44eca}},	//   _vzka, _ראיא, сафи, лкум_, 
   {{0x23a40073,0x6da40408,0xa01801e3,0x998c013a}},	//   _खासद, _йина, tsöv, gogů_, 
   {{0xa968472b,0xec7800d8,0xe4680254,0xdb4c009f}},	//   хида_, _ппм_, niöö_, سَن_, 
   {{0xe8f805f5,0x4614034c,0x47c800fe,0x6d441ebf}},	//   элд_, یوتر, লাসী, _uzka, 
   {{0x6600d8f8,0x57b0d8f9,0x6e340455,0x62980363}},	//   _slok, йбіт, loyb, yrto, 
   {{0x6600d8fa,0xa01801e3,0x00000000,0x00000000}},	//   _plok, psöv, --, --, 
   {{0x629801f1,0xdb2001d3,0x6e34d8fb,0x91d4000d}},	//   vrto, _órák, noyb, _बोलै, 
   {{0xd94009a5,0x94700b28,0x66000430,0x69c0005a}},	//   _гети, یدیا, _vlok, meoe, 
   {{0x439414b7,0x69c003cb,0x1864013e,0x14b427b4}},	//   јанс, leoe, _сафи_, اديث_, 
   {{0xa5f00323,0x6600d8fc,0x3f8409f3,0x69c00295}},	//   _гүйц, _tlok, ðlum_, oeoe, 
   {{0x66005c46,0x95c4010e,0x69c001c4,0xdb2001e7}},	//   _ulok, _буша_, neoe, íréa, 
   {{0x06bc015b,0x6e3401b9,0x00000000,0x00000000}},	//   _অপটি, doyb, --, --, 
   {{0x3f84c476,0x629809a8,0x00000000,0x00000000}},	//   úlu_, prto, --, --, 
   {{0x656001e0,0x62980009,0x215400cf,0x75f400e5}},	//   _kgoh, qrto, _өпкө_, _gázs, 
   {{0x82146e9a,0x75f400e5,0x80f40108,0x8d8400db}},	//   _خوبص, _házr, _впих, йууд, 
   {{0x69c032b8,0x7c140212,0x00000000,0x00000000}},	// [125f0] deoe, адає, --, --, 
   {{0x3f140212,0x7e640455,0x629400b8,0x00000000}},	//   _вдос, _tuhp, _āyoj, --, 
   {{0x6560036b,0x5e4400c6,0xdef80166,0xe7f89856}},	//   _ogoh, _مضحك, _чып_, ्सना_, 
   {{0x65601aa1,0x69c00af9,0x2efc0158,0x0d6402e8}},	//   _ngoh, geoe, øtfe_, _гърм, 
   {{0x38c4d8fd,0x00000000,0x00000000,0x00000000}},	//   ршең, --, --, --, 
   {{0xb8cc22e3,0x1be401b9,0xa01801f4,0x00000000}},	//   _कम_, _сўмг, msös, --, 
   {{0xe1fcd8fe,0x69c00373,0x3eb00036,0x7d0c007f}},	//   kkó_, beoe, ntzt_, lzas, 
   {{0x75f400d7,0x00000000,0x00000000,0x00000000}},	//   _rázs, --, --, --, 
   {{0xf42800f0,0x00000000,0x00000000,0x00000000}},	//   коил_, --, --, --, 
   {{0x478400c7,0xa018005b,0x33f4d8ff,0x80d809b2}},	//   _гыцб, isös, рчис, मिने, 
   {{0xd6d879c2,0xc4c801c0,0x7d0c01a9,0x87e40395}},	//   _ята_, влөж_, hzas, _уюте, 
   {{0xc0480bd9,0x98bc0022,0x00000000,0x00000000}},	//   _חז_, _aguĩ_, --, --, 
   {{0x7d0c110c,0x625c00b0,0x3eb00036,0x3d140829}},	//   jzas, _pīor, etzt_, _नेले_, 
   {{0x7d0cd900,0xe1fc03a0,0x69c001c4,0x60080037}},	//   dzas, akó_, zeoe, _lümf, 
   {{0x09c00327,0x6e340076,0x6e1800e3,0x7d0c0153}},	//   _ཀྲྀ_, toyb, نيسس_, ezas, 
   {{0x75f40122,0xde004c6b,0x60080254,0xe1fc01d3}},	//   _zázr, опси, _nümf, ckó_, 
   {{0x91e43461,0xed580cfc,0x5d6417a2,0x625c02b1}},	// [12600] _воқе, тоа_, риум_, _tīor, 
   {{0x91c40daf,0x2618003e,0x00000000,0x00000000}},	//   _тәүл, jūon_, --, --, 
   {{0x7d0c002d,0x9f98011a,0xa018007c,0x69c00254}},	//   azas, _בסיפ, rsöt, teoe, 
   {{0xe8f8d901,0x3ce80218,0x6e34014f,0xa0180108}},	//   кле_, bxav_, qoyb, ssöt, 
   {{0x7fe8d902,0xe7e005dc,0x7d0c033f,0x9994155b}},	//   _شریف_, पालप, czas, ркіт_, 
   {{0xeb980323,0xeab805f5,0xdb140005,0x69c0009d}},	//   _шиг_, _ийг_, sexá, seoe, 
   {{0xe5c4d903,0x2cb0d904,0xa9680124,0x2054010f}},	//   аспо, ltyd_, _аиба_, ביסל_, 
   {{0xa018691a,0x48c400c7,0x6d5806be,0x00000000}},	//   nsör, _гәка, _ştay, --, 
   {{0x2cb00ea0,0x74cc07b6,0xd5a4000d,0x00000000}},	//   ntyd_, तिगृ, _गारज, --, 
   {{0x168401d9,0x00000000,0x00000000,0x00000000}},	//   _چانێ, --, --, --, 
   {{0x7bd800c8,0xdec00b82,0x81d40107,0xa0180205}},	//   אַרק, ስብን_, бонх, ksör, 
   {{0x2cb00ea0,0x60080139,0x656002d0,0xc2e801d9}},	//   ktyd_, _kümg, _ugoh, ٖٹھم_, 
   {{0x24088663,0xe1fc01d3,0x00000000,0x00000000}},	//   _инди_, rkó_, --, --, 
   {{0x543000aa,0xe1fc3b7b,0x7d0c5a79,0x2cb0017a}},	//   _ورور, skó_, vzas, dtyd_, 
   {{0x2284d905,0xe1f0010b,0xd36c5f32,0x2cb00af9}},	//   _тулг, _дүнъ, _تۇپ_, etyd_, 
   {{0x2cb0af58,0x443c01a6,0x3eb00036,0x23a400bc}},	//   ftyd_, _hkv_, rtzt_, _खाँद, 
   {{0x2cb00ea0,0xefc00023,0x443cd906,0x7d0c0210}},	// [12610] gtyd_, ስድዎ_, _kkv_, uzas, 
   {{0x81e8009e,0x7d0cb750,0x60080037,0x00000000}},	//   _যতি_, rzas, _sümf, --, 
   {{0xdce43bc1,0x443c0f85,0x6fb4210e,0x7d0c0c57}},	//   ılıd, _mkv_, _امپا, szas, 
   {{0x61ec0036,0x443c1577,0x00000000,0x00000000}},	//   njcl, _lkv_, --, --, 
   {{0x23a40073,0x781800f5,0x00000000,0x00000000}},	//   _खांद, люкс_, --, --, 
   {{0x394801e4,0xed54011a,0x00000000,0x00000000}},	//   ĥas_, _לברר_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7bc4d907,0x5bc44709,0x443c2301,0x25d800ab}},	//   lehu, _रघुव, _akv_, _खोदी_, 
   {{0x999c0232,0x6008013d,0x443c1ac9,0xf7940006}},	//   _chuť_, _kümd, _bkv_, _газэ, 
   {{0x7bc4013b,0x75f4d908,0xf4080efb,0x7988011f}},	//   nehu, _vázq, ايدى_, _heew, 
   {{0xafe401e0,0x934000d1,0x00000000,0x00000000}},	//   ҡомл, تىدۇ, --, --, 
   {{0x7bc402d3,0x7988d909,0x443cd90a,0x2cb0017a}},	//   hehu, _jeew, _ekv_, ytyd_, 
   {{0x7bc4d821,0x79887ba0,0xa01801e3,0xf43400c0}},	//   kehu, _meew, vsör, _ледэ, 
   {{0xa064d90b,0x443c0112,0x7bc4035b,0x6538010f}},	//   сара_, _gkv_, jehu, _גענד, 
   {{0x7bc45f03,0xd138033f,0x2d94d90c,0xc2c816a2}},	//   dehu, łą_, йрас, _نبيل_, 
   {{0x79880694,0xb638037e,0x21f80240,0x2cb0017a}},	//   _neew, _ｅｏ_, _bëhu_, ttyd_, 
   {{0x7bc403a0,0xa01801e6,0xdd8c00c6,0x6c0400c7}},	// [12620] fehu, rsör, عوك_, бзаз, 
   {{0x7bc4d90d,0x2cb00660,0xac080276,0xafc40202}},	//   gehu, rtyd_, ынза_, _ايدى, 
   {{0x7988d90e,0x2cb005e4,0x7ed40212,0xeb000073}},	//   _beew, styd_, _діяч, लनेत_, 
   {{0x7bc400d8,0x2cb00af9,0xf83801d3,0xa9a4d90f}},	//   aehu, ptyd_, یزوں_, сидд, 
   {{0x98a062bd,0x79881bce,0x39481e4a,0x5e54008f}},	//   зиче, _deew, ۇشۇپ_, _ליטע_, 
   {{0x7bc41654,0x80d800cd,0x00000000,0x00000000}},	//   cehu, मिते, --, --, 
   {{0xf17401e1,0x798800e8,0x0524015b,0xa01801f4}},	//   _abọ́_, _feew, _পরের_, isöp, 
   {{0xe5c4d910,0x443c0008,0x798800e8,0x44980868}},	//   сско, _skv_, _geew, авию_, 
   {{0x2a6805b1,0xc82400c7,0x443c0112,0x60080205}},	//   _hubb_, _дзақ, _pkv_, _hüme, 
   {{0x600870f7,0x7988d911,0x64a4016c,0x2a685804}},	//   _küme, _zeew, _ҳада, _kubb_, 
   {{0x2a688988,0x7988d912,0x674400db,0x04e80154}},	//   _jubb_, _yeew, _اپاك, গনের_, 
   {{0x64a4d913,0x02a805f9,0x79881bce,0xe6101867}},	//   _гада, _कमीन, _xeew, _عشا_, 
   {{0x7bc400ec,0xf1740241,0xf1a80f90,0x60080205}},	//   yehu, _gbọ́_, _कारन, _lüme, 
   {{0x628c02f0,0xa018b35a,0x00000000,0x00000000}},	//   ábos, gsöp, --, --, 
   {{0x7bc4d914,0x9e0401b9,0x00000000,0x00000000}},	//   vehu, бчал, --, --, 
   {{0x9f501bce,0x3ae8030f,0x00000000,0x00000000}},	//   _joxé_, یبای_, --, --, 
   {{0x7bc4d915,0x79881574,0x69cc013f,0x02a8000d}},	// [12630] tehu, _reew, _ɔbet, _कमुन, 
   {{0x7988d916,0x7bc400d8,0x753400a2,0x25d8000d}},	//   _seew, uehu, _ýazň, _खोसी_, 
   {{0x7bc4d917,0xb994132f,0x7988d918,0x8d940131}},	//   rehu, قلاب, _peew, زلەش, 
   {{0xfcc40131,0x60080f7d,0x2a68007c,0xeb3c0092}},	//   _мәзм, _düme, _dubb_, ዲሸጋገ, 
   {{0x7bc4d919,0x79880549,0x37880114,0x3834026b}},	//   pehu, _veew, абло_, ондр, 
   {{0x6008d91a,0x79882252,0x7ac80014,0xceb401d3}},	//   _füme, _weew, _پورِ_, _بحیث, 
   {{0x2a68d91b,0x79881574,0xec1800d1,0x600884cd}},	//   _gubb_, _teew, _терә_, _kümb, 
   {{0xea602309,0x41d8000d,0x00000000,0x00000000}},	//   _قۇلپ, _बोलस, --, --, 
   {{0x9f50002e,0x20000327,0x6008496e,0xf79401c4}},	//   _doxé_, kkji_, _züme, _мааэ, 
   {{0x2484013b,0x2450d91c,0xf3640137,0x387c015d}},	//   _dwom_, ونيس, өтүн, mpwr_, 
   {{0x116801d5,0x00000000,0x00000000,0x00000000}},	//   یلگی_, --, --, --, 
   {{0x16840133,0x00000000,0x00000000,0x00000000}},	//   _ناچێ, --, --, --, 
   {{0x0574d91d,0x24840198,0x628c01ed,0x32000108}},	//   _راند, _gwom_, ábor, rkky_, 
   {{0x3a2c0841,0x68f4143a,0x628c031c,0x00000000}},	//   _ljep_, øydi, ġbor, --, 
   {{0x248401f5,0x0f0401ad,0x53442d7f,0x00000000}},	//   _zwom_, रनेस_, _ухда, --, 
   {{0x2a68070d,0x3d14367a,0x60080205,0x5de0009d}},	//   _rubb_, _नइखे_, _cümb, мжса, 
   {{0x6008d91e,0x00000000,0x00000000,0x00000000}},	// [12640] _süme, --, --, --, 
   {{0xeab830c7,0xdcac0116,0xeb780a5b,0x00000000}},	//   ийз_, ئىل_, рсај_, --, 
   {{0x29880b3b,0x00000000,0x00000000,0x00000000}},	//   асло_, --, --, --, 
   {{0x6008006a,0xafc4247f,0x00000000,0x00000000}},	//   _gümb, _ايگى, --, --, 
   {{0x3a2c0240,0xbe7400f1,0x00000000,0x00000000}},	//   _djep_, _وپیژ, --, --, 
   {{0x6008d91f,0x00000000,0x00000000,0x00000000}},	//   _tüme, --, --, --, 
   {{0x2484002d,0x02a82366,0xa9c401e2,0x00000000}},	//   _swom_, _कमेन, _وزرو, --, 
   {{0x16340491,0x7ae0066d,0xd5b4224f,0x44f4d5da}},	//   يسية_, _álta, ось_, зпис, 
   {{0x6fc80574,0x24840076,0x200003b2,0x00000000}},	//   ाजां, _qwom_, ykji_, --, 
   {{0x25d80037,0x98a00d1d,0x00000000,0x00000000}},	//   _खोरी_, _цифе, --, --, 
   {{0xe73802bf,0x48f4012c,0x35f80014,0x00000000}},	//   _теж_, ्नको_, _گرٕد_, --, 
   {{0x26dc4f58,0x00000000,0x00000000,0x00000000}},	//   _irto_, --, --, --, 
   {{0xd2584077,0x60080254,0x00000000,0x00000000}},	//   юць_, _rümb, --, --, 
   {{0xeeb804a9,0x600800af,0x00000000,0x00000000}},	//   әктә_, _sümb, --, --, 
   {{0x53300598,0x80d84709,0x200003b2,0x00000000}},	//   _оешт, मिहे, rkji_, --, 
   {{0xc1800014,0x1274007b,0x26dc0055,0x20000003}},	//   _سیؑٹ, _بحوث_, _mrto_, skji_, 
   {{0x69c41f60,0xdb68030d,0x9b6800d8,0xd01001e2}},	// [12650] _ókey, арел_, ашеа_, رلې_, 
   {{0x26dcd920,0x9c440024,0x61fc0064,0x00000000}},	//   _orto_, іхал, _įply, --, 
   {{0x3f90d921,0x05bc04e4,0xdec801ee,0xcb6801e2}},	//   mazu_, ्जाब, _тупл_, زمنه_, 
   {{0x3f90098d,0x25d80d0b,0x00000000,0x00000000}},	//   lazu_, _खोली_, --, --, 
   {{0x26dcd922,0x00000000,0x00000000,0x00000000}},	//   _arto_, --, --, --, 
   {{0xf770d923,0xa3d81889,0x3f90d924,0x366863dd}},	//   رات_, _ढोल_, nazu_, бако_, 
   {{0x3a2c003e,0x7bd40311,0x5bc400b8,0x00000000}},	//   _tjep_, _iazu, रजीव, --, 
   {{0x7bd4d925,0x63b80334,0xf1a8000d,0x290c03b2}},	//   _hazu, eftn, _काइन, íkað_, 
   {{0x3f90d926,0x7bd4105c,0x394cd927,0x63b80477}},	//   kazu_, _kazu, _uzes_, fftn, 
   {{0x437402bf,0x850801ec,0x00000000,0x00000000}},	//   муют, юдың_, --, --, 
   {{0x7bd4d928,0x3f9001c6,0x386cd929,0x32440246}},	//   _mazu, dazu_, _huer_, зенг, 
   {{0x7bd4d92a,0x386cd92b,0x98bc033f,0x00000000}},	//   _lazu, _kuer_, _czuć_, --, 
   {{0x386c0198,0x3dc80113,0x3f900115,0x00000000}},	//   _juer_, deaw_, fazu_, --, 
   {{0x7bd4d92c,0x04784bcf,0x386c0a40,0x3f90d4b6}},	//   _nazu, _بلوک_, _muer_, gazu_, 
   {{0xdee0d92d,0x386c143a,0x34380014,0x7eb4004e}},	//   нори, _luer_, _پٲژھ_, мётч, 
   {{0x386cd92e,0x9f600118,0x00000000,0x00000000}},	//   _ouer_, ívám_, --, --, 
   {{0x7bd4d92f,0x386c0198,0xd6c0009e,0xfca88ee7}},	// [12660] _bazu, _nuer_, ্মিয, قالو_, 
   {{0x7bd40262,0x91a801ed,0x80d8012c,0x213400d9}},	//   _cazu, _انکے_, मिरे, _מטפל_, 
   {{0x7bd4d930,0x386cd931,0x6e4432b0,0x2fc80175}},	//   _dazu, _auer_, _неоз, mebg_, 
   {{0x60080205,0xe9d00116,0x00000000,0x00000000}},	//   _tümc, عغا_, --, --, 
   {{0x386c354d,0x7bd4d932,0x60082ca8,0xe7f80a59}},	//   _cuer_, _fazu, _hüma, ्सला_, 
   {{0x386cd933,0x7bd4d934,0x6d440113,0x0ee009ab}},	//   _duer_, _gazu, _iyka, _पछाड, 
   {{0x386c03fa,0x00000000,0x00000000,0x00000000}},	//   _euer_, --, --, --, 
   {{0x386cd935,0x3f9001c0,0x6924d936,0xddcc054e}},	//   _fuer_, zazu_, _емба, _micş, 
   {{0x98a0b1cd,0x386c04c4,0x7bd4d937,0x6008000d}},	//   _пите, _guer_, _yazu, _lüma, 
   {{0x2d90d938,0x6d44d939,0xb864240f,0x6b8c0841}},	//   haye_, _myka, _قالو, _jebg, 
   {{0x6d440a85,0x60080cc1,0x26dcd93a,0x386c01c7}},	//   _lyka, _nüma, _urto_, _zuer_, 
   {{0x3f90d93b,0xb6c00166,0x673c0254,0x00000000}},	//   wazu_, _рөшд, üpju, --, 
   {{0x2d90d93c,0x6d44d93d,0x3f90d93e,0xf3f4bd8b}},	//   daye_, _nyka, tazu_, ستیک, 
   {{0x6008d93f,0x545000d6,0x506433d2,0x00000000}},	//   _büma, _звіт, етса, --, 
   {{0x645800fc,0x6d440054,0x442cd288,0x3f900609}},	//   mmti, _ayka, mnd_, razu_, 
   {{0x2d90d940,0x7bd44e64,0x6d440660,0x442cd941}},	//   gaye_, _sazu, _byka, lnd_, 
   {{0x442c1c1d,0x7bd4d942,0x6d4400ee,0xd1b800ec}},	// [12670] ond_, _pazu, _cyka, _رايا_, 
   {{0xf0901203,0x442cd943,0x600805d5,0x6d447c46}},	//   _שני_, nnd_, _füma, _dyka, 
   {{0x7bd4d944,0x386c4f3b,0x6d44d945,0x625c02b1}},	//   _vazu, _suer_, _eyka, _pūoh, 
   {{0x386cd946,0x2d900551,0x7bd47f83,0x6d440158}},	//   _puer_, caye_, _wazu, _fyka, 
   {{0x386c03b7,0x442c0421,0x7bd404ba,0x00000000}},	//   _quer_, knd_, _tazu, --, 
   {{0xf744042f,0x600801b8,0x442c0d27,0xddc4000f}},	//   мело, _yüma, jnd_, mpjű, 
   {{0x625c00b0,0xb6f80131,0x386c04e6,0x00000000}},	//   _tūoh, تىغا_, _wuer_, --, 
   {{0x442cd947,0x386cd948,0xf7700451,0x6b8c031c}},	//   end_, _tuer_, راڪ_, _zebg, 
   {{0x442c008c,0x62884b7b,0x14600022,0x26d8007c}},	//   fnd_, _awfo, неиҭ, åpor_, 
   {{0x2d90d949,0x442c0334,0x9734069d,0x00000000}},	//   zaye_, gnd_, ብራይስ, --, 
   {{0x2d9023db,0xc7c40801,0x71a41606,0x00000000}},	//   yaye_, _ясти, манз, --, 
   {{0x442c23f5,0x645801f5,0x0708d94a,0x2d900067}},	//   and_, amti, _عيني_, xaye_, 
   {{0x2d90d94b,0x62880327,0x7648d94c,0xe3ac022e}},	//   vaye_, _ewfo, mley, _иб_, 
   {{0x2d90d94d,0x6d44050a,0x600802b5,0x76487156}},	//   waye_, _ryka, _püma, lley, 
   {{0x6d4408c8,0x60cc0009,0x7648058a,0xd1340092}},	//   _syka, awcm, oley, በራቸው, 
   {{0x7648d94e,0x6b8c025c,0x6d4400c7,0x2d60013f}},	//   nley, _sebg, _pyka, tɔe_, 
   {{0x7648d94f,0xeb98027d,0x40940006,0x00000000}},	// [12680] iley, قضات_, _прэт, --, 
   {{0x2d90d950,0x76482045,0x6d440122,0x6008d951}},	//   saye_, hley, _vyka, _tüma, 
   {{0x7648d952,0x6008007d,0x6d440034,0x2d90d953}},	//   kley, _kümn, _wyka, paye_, 
   {{0x6b8c05f5,0x3a980c98,0xa9247bf7,0xa968680f}},	//   _webg, ятую_, мдел, цида_, 
   {{0x442c26b8,0x7648d954,0x6d440113,0xed3401c0}},	//   ynd_, dley, _uyka, _цэнэ, 
   {{0x76485dd8,0x00000000,0x00000000,0x00000000}},	//   eley, --, --, --, 
   {{0x442c0579,0xd6d4054a,0x7648d955,0xac240023}},	//   vnd_, дты_, fley, _ተረዳዲ, 
   {{0x7648d956,0x3e50013f,0x442cd957,0x68f40158}},	//   gley, _pɑtɑ_, wnd_, øyds, 
   {{0x43940166,0x442c0051,0x00000000,0x00000000}},	//   напс, tnd_, --, --, 
   {{0x442cc337,0x62880477,0x7648d958,0x66e400db}},	//   und_, _pwfo, aley, _ооза, 
   {{0x442cd959,0xe5780953,0x6d58010f,0x00000000}},	//   rnd_, _дзе_, _ŝtal, --, 
   {{0x64580ffb,0x76480014,0x628801a4,0x442c0208}},	//   smti, cley, _vwfo, snd_, 
   {{0xc1040338,0x50f40138,0x00000000,0x00000000}},	//   روسي, взят, --, --, 
   {{0x2d2c001f,0xffb405f5,0x00000000,0x00000000}},	//   _በመካከ, эйгэ, --, --, 
   {{0xcecc01e1,0x00000000,0x00000000,0x00000000}},	//   _làṣẹ_, --, --, --, 
   {{0x6008d95a,0x5bc4012a,0xa0180205,0x00000000}},	//   _gümn, रज्व, nsöz, --, 
   {{0x4c94d95b,0x20cc0135,0xde280023,0x00000000}},	// [12690] китс, _użi_, _ተወከል, --, 
   {{0x7648d95c,0x00000000,0x00000000,0x00000000}},	//   zley, --, --, --, 
   {{0x7648d95d,0xe0dc86ed,0x3d94030d,0x00000000}},	//   yley, lvò_, _пинр, --, 
   {{0x7648d95e,0x00000000,0x00000000,0x00000000}},	//   xley, --, --, --, 
   {{0x3e840248,0x41c000dc,0x3774013d,0x22480363}},	//   _fètò_, ष्यस, ныйс, ilck_, 
   {{0x3e74d95f,0xd76001d3,0x76485dd8,0xdcec0171}},	//   _kåt_, نچای, wley, _lecī, 
   {{0x7648d960,0xe728031c,0xcb4413b5,0x7608009d}},	//   tley, _སྨྱན_, _ахти, зейг_, 
   {{0xb8d46569,0x6ec005f9,0x53d400af,0xdcec00ef}},	//   _জন_, _लहसु, _भोजश, _necī, 
   {{0x3e74d961,0x7648d962,0xb4640017,0xdb040724}},	//   _låt_, rley, нкил, şmäs, 
   {{0x7648d963,0xe454d964,0x7c24d965,0x00000000}},	//   sley, нжы_, nihr, --, 
   {{0x764835b7,0x3e74049f,0x00000000,0x00000000}},	//   pley, _nåt_, --, --, 
   {{0x3dd80564,0xdbd40e03,0x76480067,0xdcec00de}},	//   _nasw_, _hääs, qley, _cecī, 
   {{0xdee0036b,0x70c8012c,0xa0180139,0x00000000}},	//   қоти, िबेल, lsöy, --, 
   {{0x3e7477d4,0xd6c0015b,0xdbd416ca,0x9f980037}},	//   _båt_, ্মীপ, _jääs, jääk_, 
   {{0x20c0005e,0x84640801,0xb8d0031c,0xdca000d1}},	//   _ұйым, _ръце, _ཐའ_, һати, 
   {{0xee3800d6,0x60082a36,0xf1a8033f,0x9c20013e}},	//   їна_, _fümo, _काटन, ҳдуд, 
   {{0xdca0d966,0xa3b4038e,0xfa2404c5,0x5ca00334}},	// [126a0] лати, ङ्क_, যকাল_, литб, 
   {{0x41c02cbc,0x6008010b,0x0cd003ce,0x9d500137}},	//   ष्ठस, _jüml, _हनीम, انكت, 
   {{0x34bc00dc,0x802400b3,0x61ec01e7,0x00000000}},	//   ्बुद, _جريم, _áilé, --, 
   {{0x60080793,0x60940214,0x7c2401ab,0xa0180108}},	//   _yümo, _تنیس_, aihr, npön, 
   {{0x56900150,0x00000000,0x00000000,0x00000000}},	//   ңашт, --, --, --, 
   {{0x1d0410fc,0x00000000,0x00000000,0x00000000}},	//   _џери_, --, --, --, 
   {{0x0cd0d967,0x7790d968,0x45d406a6,0x1ae000ee}},	//   _हनुम, شینا, войс, _йорм, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d5801e4,0x00000000,0x00000000,0x00000000}},	//   _ŝtaj, --, --, --, 
   {{0x60082c6f,0xdcec005f,0x68580ca8,0x00000000}},	//   _cüml, _secī, bòmọ, --, 
   {{0xa3b437e3,0x60080793,0x79540023,0x00000000}},	//   ङ्ग_, _sümo, _ዝሓተት, --, 
   {{0x3e7400b5,0x0cd000cd,0xe7f800bc,0x00000000}},	//   _råt_, _हनूम, ्सका_, --, 
   {{0x290401c8,0x27fc007f,0xd20801c6,0xdcec00de}},	//   nyoa_, _kotn_, хээд_, _vecī, 
   {{0xe0dc011c,0x80b005f9,0xd464084c,0x600806be}},	//   rvò_, _जमीं, _зиче_, _güml, 
   {{0x28e0d969,0x2b480332,0x7c24005b,0x3d940cb6}},	//   पिडि, _nybc_, vihr, кивр, 
   {{0x60080793,0x3e741511,0x6298d96a,0x00000000}},	//   _tümo, _våt_, msto, --, 
   {{0x6298d96b,0x6008d96c,0x5ba4d96d,0x41c08109}},	// [126b0] lsto, _hümm, ерез, ष्णस, 
   {{0x6008d96e,0x61fcd96f,0x62980108,0xa01801f4}},	//   _kümm, _hoql, osto, mpöo, 
   {{0x80d80a59,0x6008010b,0xdbd40037,0x00000000}},	//   मिके, _jümm, _rääs, --, 
   {{0xdbd40d77,0x7c2401fa,0x8b8800d1,0x127800df}},	//   _sääs, sihr, _ۋەقە_, פאדע, 
   {{0xdbd405c3,0x27fc394a,0x62980e78,0x61fc025c}},	//   _pääs, _botn_, hsto, _moql, 
   {{0xb6a4d970,0xb8c83f7e,0x00000000,0x00000000}},	//   викл, _खट_, --, --, 
   {{0x62980bb8,0xe734d971,0x41b00034,0x00000000}},	//   jsto, кеш_, _झांस, --, 
   {{0x2afc0316,0x18b00075,0x61fc022e,0x600800a2}},	//   लहरु_, _бәкр, _noql, _süml, 
   {{0x6298d972,0x6fb0068f,0x00000000,0x00000000}},	//   esto, _जालं, --, --, 
   {{0x6298d973,0xc4c400ec,0x00000000,0x00000000}},	//   fsto, اتيو, --, --, 
   {{0x35b4d974,0x61fc0455,0xe85000db,0x8cd809bb}},	//   _абер, _boql, _ئچند, _नैनो, 
   {{0xdb140005,0x60080112,0xf5580214,0xe72c0345}},	//   lexó, _dümm, _قلاب_, _بڵه_, 
   {{0x660400dd,0x2fd800ca,0x61fc014f,0xb39802d3}},	//   ökke, _papg_, _doql, _መጠይቕ_, 
   {{0x6298d975,0x7fd40046,0x64a08d4b,0x68f40108}},	//   bsto, лісі, _таша, äydi, 
   {{0xefcc069c,0xa064d976,0x2c74d977,0x640003e6}},	//   _ብናይ_, тара_, _sæd_, _ڕژێم, 
   {{0x3ea40e55,0x2c7401bf,0x6008010e,0x00000000}},	//   álta_, _pæd_, _jümj, --, 
   {{0xdd8c0350,0xeb983500,0x6c7407d6,0xe0d40166}},	// [126c0] زول_, диз_, тубх, _авы_, 
   {{0xaf040588,0x628417a3,0x7c64009f,0xa0183b22}},	//   _апол, ćkov, هالل, npöl, 
   {{0x61fc3ae4,0x6da40022,0xb3d80037,0x00000000}},	//   _yoql, _иина, _बघनख, --, 
   {{0x3cec0e3c,0x76580142,0xec7800d8,0x00000000}},	//   _ševe_, _nhwy, _опм_, --, 
   {{0x625c00b0,0x62985c59,0x34bc07b7,0x00000000}},	//   _kūor, zsto, ्बोद, --, 
   {{0x25d873ca,0x6298d978,0x9d400114,0x00000000}},	//   _खोजी_, ysto, _ђерд, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe5c4d979,0x7658d97a,0x62985792,0x69100115}},	//   тско, _chwy, vsto, _pɾeĝ, 
   {{0xc3c40cdd,0x61fc01a9,0x6008000d,0x00000000}},	//   гөйл, _roql, _sümm, --, 
   {{0x6298d97b,0x61fcd97c,0x69c0d97d,0xf4f00022}},	//   tsto, _soql, lfoe, сҧшь, 
   {{0x6298d97e,0x61fc014f,0x68e000c0,0x00000000}},	//   usto, _poql, lvod, --, 
   {{0xa52477e0,0x64a459e6,0x61fc014f,0x69c00393}},	//   _имед, _аада, _qoql, nfoe, 
   {{0x62985c02,0x69c00098,0x61fc014f,0x68e0d97f}},	//   ssto, ifoe, _voql, nvod, 
   {{0x6298d980,0x6fc80034,0xb4b400fd,0x61fc014f}},	//   psto, ाजगं, _сишә, _woql, 
   {{0xc43401ed,0x5ec80154,0x00000000,0x00000000}},	//   _لکھت, ায়নে, --, --, 
   {{0x68e0030a,0x24940092,0xa018005b,0x6abc002f}},	//   kvod, _መነሳት_, mpöm, dtpf, 
   {{0x68e02220,0x7d5400a7,0x00000000,0x00000000}},	// [126d0] jvod, увах, --, --, 
   {{0x60080fb9,0x68e0d981,0x6abc17da,0x00000000}},	//   _mümk, dvod, ftpf, --, 
   {{0xca740075,0x68e0054e,0x00000000,0x00000000}},	//   لانغ, evod, --, --, 
   {{0x3914d982,0xbdc00131,0x00000000,0x00000000}},	//   лмер, _دەرۋ, --, --, 
   {{0x765800a9,0x80d82982,0x6e3801d3,0xc7b80051}},	//   _rhwy, मिटे, étbe, _bcđ_, 
   {{0xba9405d9,0x00000000,0x00000000,0x00000000}},	//   _مارڪ, --, --, --, 
   {{0x0a940816,0x765803cb,0x00000000,0x00000000}},	//   _васю, _phwy, --, --, 
   {{0xcf580375,0x69f00107,0x00000000,0x00000000}},	//   כבות_, _гӯшт, --, --, 
   {{0x2d9c013b,0x7998198f,0x6738045a,0x00000000}},	//   _ɛte_, maww, _extj, --, 
   {{0x7998d983,0x2bc418cc,0x00000000,0x00000000}},	//   laww, र्पा, --, --, 
   {{0x75b40451,0x76580042,0xd6d85dbf,0x62a001e1}},	//   _مٽائ, _thwy, _юта_, _àtò, 
   {{0x394c0100,0x7998d984,0x3494d985,0xa0180108}},	//   _kyes_, naww, _бадр, spöl, 
   {{0x625c0374,0x42540276,0x956402e8,0xe7f80073}},	//   _pūor, ртэт, _ръжд, ्सचा_, 
   {{0x705442f4,0x7998d986,0xdd2c0118,0x21f00150}},	//   انسا, haww, měňo, _ۇكىس, 
   {{0x6da4d987,0x61ec007b,0x7998d988,0xe454010f}},	//   лива, áilí, kaww, _גיסט_, 
   {{0x2bc429ea,0xb8840115,0x394c0789,0x00000000}},	//   र्ना, _kaŭĉ, _oyes_, --, 
   {{0x394c1529,0x7998d989,0x6fb003ce,0x00000000}},	// [126e0] _nyes_, daww, _जाऊं, --, 
   {{0x2010020b,0x2b14d98a,0x6abc002f,0x00000000}},	//   _glxi_, льер, ttpf, --, 
   {{0x79980ba7,0x6b5401f0,0x5fb8010f,0x00000000}},	//   faww, утах, _אצינ, --, 
   {{0x79980c23,0x6abc0112,0xa99416ac,0xd7f400d1}},	//   gaww, rtpf, اشات, ғуш_, 
   {{0x69244478,0x69c0d98b,0x6abc4cf1,0x61e801a8}},	//   ымда, rfoe, stpf, _ógle, 
   {{0x394cd98c,0x68e0d98d,0xfd4c06d6,0x69cc013f}},	//   _dyes_, rvod, venḓ, _ɔbey, 
   {{0x7998208d,0x394cd98e,0x00000000,0x00000000}},	//   baww, _eyes_, --, --, 
   {{0xbb50186e,0x04c8d98f,0x394c0200,0x1af800cc}},	//   _بۆمب, نوعي_, _fyes_, _এইচে_, 
   {{0x394c01d3,0x68e001d5,0x3a540244,0x00000000}},	//   _gyes_, qvod, _ئینج_, --, 
   {{0x3170010b,0x1cb8008f,0xe7ac0490,0x9cd4011a}},	//   _agyz_, עמיע, _घाटप, נויה_, 
   {{0xa6846799,0x2bc4b305,0xe5a405f5,0x05140154}},	//   _след, र्या, _биеи, াপের_, 
   {{0xe4d4d990,0xe6940588,0x80c40022,0x00000000}},	//   _مقصد, _аиҧы, аӡоз, --, 
   {{0xc3c41cd1,0xb88401e4,0x944001d3,0xbf0c521a}},	//   _көнл, _gaŭĉ, _گھٹن, सन्न_, 
   {{0x2bc40b26,0x66004774,0xa018005b,0xc5bc0154}},	//   र्मा, _hook, mpök, _অফটপ, 
   {{0xe1fc01ed,0x79980ba7,0xd378011a,0x00000000}},	//   tmód_, yaww, _ארוט, --, 
   {{0x6600033d,0xc1041564,0x6008bd8f,0x5280007b}},	//   _jook, _نوعي, _mümi, _اليك, 
   {{0x6600d991,0x2bc408ec,0xa0180295,0xcd3400c6}},	// [126f0] _mook, र्भा, npök, مركب, 
   {{0x6600d992,0x6fb0068f,0x79980b45,0xdef8d993}},	//   _look, _जाएं, waww, _зым_, 
   {{0x7998d994,0x394c072b,0x810801e2,0x00000000}},	//   taww, _syes_, _سرکې_, --, 
   {{0xefcc044e,0x6600d995,0xfde80d0a,0x2bc45b29}},	//   _ብሓደ_, _nook, _ऑफिस_, र्बा, 
   {{0x0ff801ed,0x7998d996,0x64480419,0x00000000}},	//   _شعیب_, raww, _okfi, --, 
   {{0x7998d997,0x86480023,0xa7a400f3,0x80ac07d0}},	//   saww, _ካባኻት, акша_, _जिने, 
   {{0x6600d998,0x394c039a,0xdedc02d3,0x8b68014b}},	//   _book, _wyes_, _ሕቡእ_, _биёв_, 
   {{0x6600d999,0x7998d984,0x7bc401a4,0x05d400d1}},	//   _cook, qaww, lfhu, ممىڭ, 
   {{0x6600d99a,0x97a4d99b,0x49c8011c,0x00000000}},	//   _dook, _брел, _щурм_, --, 
   {{0x600801b8,0x72c411b5,0x7bc4b736,0x73c4013d}},	//   _fümi, абоз, nfhu, рәде, 
   {{0x6600d99c,0xd244036b,0x9600009d,0xa0180108}},	//   _fook, ймоқ, _гүйж, mpöh, 
   {{0xb34400db,0x998c0006,0x644801e4,0x6600d99d}},	//   _alçà, mogų_, _ekfi, _gook, 
   {{0xe0d406bb,0x64481132,0xe56cd99e,0x998c0024}},	//   авя_, _fkfi, _фз_, logų_, 
   {{0x394809a5,0x600829ef,0x6600d99f,0x6e2405b1}},	//   ýasy_, _yümi, _zook, _smkb, 
   {{0x66003316,0x2d94d9a0,0x5f006ac5,0xf8a4004b}},	//   _yook, ирас, озра, _ډک_, 
   {{0xed58a3c3,0x3cec0e3c,0x7bc401f5,0x00000000}},	//   воб_, _ševa_, efhu, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [12700] --, --, --, --, 
   {{0xfa480131,0xb3b4012d,0x00000000,0x00000000}},	//   ۇشنى_, ंलिख, --, --, 
   {{0xee380395,0xca6801d5,0x00000000,0x00000000}},	//   _анн_, аlаr, --, --, 
   {{0x7bc401e7,0xadb400db,0x80ac06b1,0x00000000}},	//   afhu, _өбүш, _जिमे, --, 
   {{0x6008014a,0x00000000,0x00000000,0x00000000}},	//   _sümi, --, --, --, 
   {{0x6600d9a1,0x00000000,0x00000000,0x00000000}},	//   _sook, --, --, --, 
   {{0x6600d9a2,0x2bc4193d,0xab28d9a3,0x998c0153}},	//   _pook, र्णा, _рова_, gogų_, 
   {{0x28d8033d,0x0b5814d4,0x00000000,0x00000000}},	//   _मैथि, _арғы_, --, --, 
   {{0x2bc47922,0x798c0784,0x00000000,0x00000000}},	//   र्था, ñawe, --, --, 
   {{0x6600d9a4,0x60080254,0x25840118,0xaab80709}},	//   _wook, _tümi, dílů_, _उमाक, 
   {{0xa018d9a5,0x00000000,0x00000000,0x00000000}},	//   spök, --, --, --, 
   {{0x2bc4095f,0xe4e402bf,0xa018005b,0xc7b80051}},	//   र्ता, _вікн, mpöi, _smđh_, 
   {{0x32d804d3,0x25a4123b,0x2ca00051,0x00000000}},	//   ندێک_, _idol_, _nvkd_, --, 
   {{0x2484d9a6,0x2d80045f,0x6e340024,0xf7600092}},	//   _itom_, _afke_, enyb, _ትንሣኤ_, 
   {{0x442cd9a7,0x8f086ac9,0x1df40022,0x93f8011a}},	//   mid_, ахта_, аҵны_, _בלגי, 
   {{0x442cd9a8,0x13140375,0xdce80427,0xecc40131}},	//   lid_, _כחול_, šičj, әштү, 
   {{0x442c02a4,0xd0440134,0xe048036b,0x00000000}},	// [12710] oid_, _esiɑ, _لشده_, --, 
   {{0x442cd2e7,0x2d80002d,0x9d5000aa,0x06ac03d4}},	//   nid_, _efke_, منځت, _কৈছি, 
   {{0x2bc43174,0x6d5804ac,0x25a48ac2,0xdb68d9a9}},	//   र्धा, _ŝtat, _odol_, трал_, 
   {{0x25a40076,0x248400d7,0x7bc40332,0x1ddc01f9}},	//   _ndol_, _otom_, sfhu, _पोचत, 
   {{0x24840218,0x7bc40564,0x89a802bf,0x00000000}},	//   _ntom_, pfhu, рків_, --, 
   {{0x7d0cd9aa,0x442cd9ab,0x25a482af,0x2bc41b61}},	//   myas, jid_, _adol_, र्दा, 
   {{0x7d0cd9ac,0x35a4d9ad,0x2d80002d,0x00000000}},	//   lyas, байг, _yfke_, --, 
   {{0x442cd9ae,0x7d0c0083,0xe5f000d1,0x25680248}},	//   eid_, oyas, ككىد, _ẹla_, 
   {{0x25a4d9af,0x3914d9b0,0xe1fc02d2,0x00000000}},	//   _ddol_, _умар, djó_, --, 
   {{0x33f4d9b1,0xaa8400db,0x442cd9b2,0x600800a2}},	//   счис, _ئچەم_, gid_, _kümu, 
   {{0x7d0cd9b3,0x24840139,0x37540137,0x87e4d9b4}},	//   hyas, _etom_, _اپاس, _ьюте, 
   {{0x442cd9b5,0x28ac0316,0x6ab800fe,0x7d0cd9b6}},	//   aid_, _घिमि, _åtfe, kyas, 
   {{0x250801d3,0x73e401f0,0x00000000,0x00000000}},	//   _مروی_, _голз, --, --, 
   {{0x442cd9b7,0x7d0cd9b8,0x00000000,0x00000000}},	//   cid_, dyas, --, --, 
   {{0x81cc00bd,0x600800ac,0x6398008f,0xe1fc02d2}},	//   রয়_, _nümu, _עסקנ, bjó_, 
   {{0x7d0cd9b9,0xdb1406ed,0x09cc00eb,0xafe401a9}},	//   fyas, nexõ, _রোনা, шоҳл, 
   {{0x6e34d9ba,0x7d0c00dd,0x2bc858a7,0x61e813db}},	// [12720] rnyb, gyas, ллап_, _ógla, 
   {{0x80ac21b8,0xe0f800d9,0x4ba40150,0x00000000}},	//   _जिते, _עליל, ілең, --, 
   {{0x2984807e,0xb5fc01fa,0x6b5800f7,0x7d0c0009}},	//   былг, zmša, ушар_, ayas, 
   {{0x442cd9bb,0x753c0034,0x7d0cd9bc,0x00000000}},	//   zid_, ższy, byas, --, 
   {{0x442cd9bd,0x888479af,0x3078010f,0x7d0cd9be}},	//   yid_, زیان, נאַנ, cyas, 
   {{0xec140efc,0xefcc0023,0x98940124,0x98a403e0}},	//   _اوسد, _ብሓዊ_, суцә, şiği_, 
   {{0x24845a29,0x798c0113,0x37a8753d,0x00000000}},	//   _stom_, ñawc, ртін_, --, 
   {{0x442cd9bf,0x76480c6a,0xd6d00131,0x00000000}},	//   wid_, goey, ستىغ, --, 
   {{0xa0180108,0x00000000,0x00000000,0x00000000}},	//   mpöv, --, --, --, 
   {{0x3e4002d5,0x2a640120,0x24840306,0x442c0363}},	//   mėte_, lmob_, _vtom_, uid_, 
   {{0x7648014b,0xe1fc00db,0x46dc02e5,0x7d0c2892}},	//   boey, tjó_, _मनिह, zyas, 
   {{0x26dcd9c0,0x442cd9c1,0xc7943e25,0x5184d9c2}},	//   _isto_, sid_, _ырғы, зура, 
   {{0x6b9c1613,0x2484d9c3,0x442cd9c4,0xf7400022}},	//   kapg, _utom_, pid_, _нҵәо, 
   {{0x7d0c00dc,0x09cc015b,0x442c2988,0x46dc05d7}},	//   vyas, _রোমা, qid_, _मनाह, 
   {{0x5330d9c5,0xb424314e,0x539827af,0x228401c6}},	//   _нешт, _بعنو, _גיוו, _уулг, 
   {{0x7d0cd9c6,0x2bc4012c,0x443c01bf,0x7e540212}},	//   tyas, र्सा, _hjv_, іває, 
   {{0xaf380092,0x00000000,0x00000000,0x00000000}},	// [12730] ተላለፈ, --, --, --, 
   {{0x2248d9c7,0x7d0cd9c8,0x63b808cd,0x443c007f}},	//   lock_, ryas, ngtn, _jjv_, 
   {{0x7d0cd275,0x3ad415f2,0x600800a2,0xe048036b}},	//   syas, تياز, _dümt, _لشگه_, 
   {{0xb95458f0,0x2248007f,0x752c09a5,0x7d0cd9c9}},	//   овещ, nock_, _ýazg, pyas, 
   {{0x26dc334b,0x98c4d9ca,0x7d0cbb52,0x2bc40bca}},	//   _asto_, ссел, qyas, र्हा, 
   {{0x2248d9cb,0x2a640175,0x00000000,0x00000000}},	//   hock_, amob_, --, --, 
   {{0x2a640211,0x3618005b,0x224801e3,0x3ce8000d}},	//   bmob_, ицию_, kock_, lvav_, 
   {{0x22480204,0x34a8026a,0x6008010e,0x3484022e}},	//   jock_, авио_, _küms, огиг, 
   {{0x2bc433af,0x26dcd9cc,0x2248d9cd,0xe61400d6}},	//   र्वा, _esto_, dock_, ідь_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x26dc0280,0x76480161,0x8c480e2d,0x00000000}},	//   _gsto_, poey, _hoşç, --, 
   {{0x8c48013d,0x00000000,0x00000000,0x00000000}},	//   _koşç, --, --, --, 
   {{0x3eb001c7,0xc4c4277d,0x6b9c022e,0x00000000}},	//   erzt_, _فتوو, yapg, --, 
   {{0xd13805c7,0xa18c01ec,0xc2c80066,0x00000000}},	//   ăą_, _ﺒﻘﺼﻑ_, جبیل_, --, 
   {{0xdee0d9ce,0x3dc80204,0x22485369,0x6da4022e}},	//   мори, ffaw_, bock_, жиба, 
   {{0xe1fc30cf,0xdce402b5,0xeaf83cc4,0x82a401af}},	//   lmón_, _ōmāh, یرات_, _эшље, 
   {{0xad640502,0xafe4828a,0x3eb004e6,0x752c00ee}},	// [12740] زاره, _допл, arzt_, _ýazd, 
   {{0xc10405d9,0xaf380092,0x00000000,0x00000000}},	//   _روپي, ተላልፈ, --, --, 
   {{0x2bc40a94,0xab340798,0x6e44014b,0x00000000}},	//   र्षा, цхај, _меоз, --, 
   {{0x88840046,0xf3900055,0xdce800c0,0x066802dd}},	//   зғал, _iṣur_, _šiąn, _ﺷﺎﻋﯩ, 
   {{0x2d90d9cf,0x68441efd,0x20400020,0x63b8037e}},	//   mbye_, онда, _የህብረ, ygtn, 
   {{0x2cb00cfd,0xb0b0033d,0x2d900083,0x2a6400d8}},	//   mryd_, _जिनग, lbye_, smob_, 
   {{0x26dc011c,0xa018d9d0,0x9680004b,0x31b0009e}},	//   _qsto_, mpöt, وټون, ট্যশ, 
   {{0x78ac1326,0x2d90b8ab,0x2bc47b05,0x600800a2}},	//   šava, nbye_, र्रा, _jümr, 
   {{0xdb04007f,0x2d9004ba,0x443c01f4,0x00000000}},	//   _adjè, ibye_, _pjv_, --, 
   {{0x26dc002d,0x3fe4015b,0xa018007f,0x2248012d}},	//   _tsto_, _নক্ষ, npöt, wock_, 
   {{0x2248d9d1,0xe618013d,0x26dc0841,0x5b780a7c}},	//   tock_, _кдж_, _usto_, יריא, 
   {{0xe1fc00c7,0x00000000,0x00000000,0x00000000}},	//   amón_, --, --, --, 
   {{0x2248d9d2,0x2d90d9d3,0xcfe40011,0x00000000}},	//   rock_, dbye_, মানন, --, 
   {{0x464400b8,0x78bc03cd,0x2cb00142,0xd46400f3}},	//   _aṣṭī, _åsve, dryd_, _диче_, 
   {{0x93c89105,0x3ea401ed,0x9e040212,0x61e80162}},	//   _خانہ_, élt_, очал, _óglo, 
   {{0x3eac076f,0x6288003c,0x62641411,0x2cb00368}},	//   čet_, _itfo, _باتق, fryd_, 
   {{0x403447c7,0x6fb46df1,0x628800d8,0x00000000}},	// [12750] _неис, _کمپا, _htfo, --, 
   {{0x2bc4070f,0x3f900327,0x3dc80003,0x00000000}},	//   र्ला, qbzu_, sfaw_, --, 
   {{0x23c01533,0xe8c40135,0x1d8805d9,0x3ce800c5}},	//   _शानद, _གདུག, _پئجي_, svav_, 
   {{0x6008d9d4,0x2cb00368,0x8c4800a2,0x00000000}},	//   _gümr, bryd_, _poşç, --, 
   {{0x8c48013d,0x00000000,0x00000000,0x00000000}},	//   _qoşç, --, --, --, 
   {{0x60081b0d,0xa0180108,0x69c401e3,0x00000000}},	//   _zümr, mpös, _öken, --, 
   {{0x628800d2,0x8aa401b9,0x35a401b9,0x99d4d9d5}},	//   _ntfo, _ортд, пайг, _وترا, 
   {{0xea6007d2,0x1dc80b98,0xc6680114,0x00000000}},	//   _كۇلپ, ाभित, ошње_, --, 
   {{0x6288d9d6,0x3a2cd9d7,0x27f400bc,0x39582131}},	//   _atfo, _imep_, ádní_, _áss_, 
   {{0xb9e40092,0xe63400d1,0x00000000,0x00000000}},	//   _ከሱ_, يۋەت_, --, --, 
   {{0x81e42f8b,0xc7c4d9d8,0x2ee80175,0x2d90366f}},	//   নান_, _юсти, xvbf_, ybye_, 
   {{0x76440014,0x2cb00042,0x00000000,0x00000000}},	//   _ڈیڈِ_, yryd_, --, --, 
   {{0x62880334,0xf55401c0,0xc7b8004d,0xe3ac0108}},	//   _etfo, _эвдэ, _tmđt_, _пб_, 
   {{0xf7601b49,0xa3d00210,0x00000000,0x00000000}},	//   _ትንሳኤ_, _हॉप_, --, --, 
   {{0x6ab8012c,0x2cb00142,0x752c010e,0x2414011a}},	//   _उमेर, wryd_, _ýazb, _מחסן_, 
   {{0x2cb0d9d9,0xac846235,0x6b6400c7,0x00000000}},	//   tryd_, згал, ҧкаа, --, 
   {{0x2d900493,0x00000000,0x00000000,0x00000000}},	// [12760] rbye_, --, --, --, 
   {{0xb32808ea,0xef180640,0x2d9000ca,0x2cb0062c}},	//   _སྟོང_, _гмо_, sbye_, rryd_, 
   {{0x9f940302,0x78b801a4,0x2cb00267,0xa0180108}},	//   _מדיה_, euwv, sryd_, rpöt, 
   {{0xe8f84720,0x2cb0015d,0x00000000,0x00000000}},	//   йле_, pryd_, --, --, 
   {{0xa0180793,0x41c0102f,0x78ac0427,0x00000000}},	//   mpör, ष्टस, šavn, --, 
   {{0xac08006c,0xd82001c0,0x3a2c0139,0x3e400024}},	//   _унга_, ндчи, _emep_, mėta_, 
   {{0x2040001f,0x7ac000c7,0x3e400153,0x00000000}},	//   _የኅብረ, _аҩха, lėta_, --, 
   {{0xb3281b4b,0x44f40126,0x24c000cc,0x80ac5c0b}},	//   _སྟེང_, дпис, ্টসহ, _जिले, 
   {{0x62880589,0x3e400153,0x00000000,0x00000000}},	//   _stfo, nėta_, --, --, 
   {{0xd48c0323,0x66e40818,0x00000000,0x00000000}},	//   _үр_, _ноза, --, --, 
   {{0xd5ac28a8,0x00000000,0x00000000,0x00000000}},	//   _пс_, --, --, --, 
   {{0x3e400024,0x00000000,0x00000000,0x00000000}},	//   kėta_, --, --, --, 
   {{0xdb2001ed,0x00000000,0x00000000,0x00000000}},	//   _örök, --, --, --, 
   {{0x3e400024,0xa34400c0,0x00000000,0x00000000}},	//   dėta_, _нэйл, --, --, 
   {{0x6288d9da,0xdda801c0,0x6008002f,0x00000000}},	//   _utfo, йтал_, _dümp, --, 
   {{0xd010004b,0x00000000,0x00000000,0x00000000}},	//   پلې_, --, --, --, 
   {{0x3e400064,0x00000000,0x00000000,0x00000000}},	// [12770] gėta_, --, --, --, 
   {{0x600800a2,0x9c440212,0xdb68005b,0x00000000}},	//   _gümp, їхал, брел_, --, 
   {{0x34d8038e,0x00000000,0x00000000,0x00000000}},	//   _भन्द, --, --, --, 
   {{0x3e400153,0xa01801f4,0x998c010e,0x00000000}},	//   bėta_, ppös, ingŧ_, --, 
   {{0x37e4d9db,0x9ce4010b,0xf770d9dc,0x00000000}},	//   долг, _эцнл, ھات_, --, 
   {{0xacf80302,0x78ac0960,0xf7700c50,0x3774008e}},	//   _והשכ, šavo, پات_, мыйс, 
   {{0xdb20023a,0x3c2c06be,0xdd380092,0x00000000}},	//   ärän, _növə_, _በመጠቆ, --, 
   {{0xab600075,0xe75400d1,0x56f0009d,0x00000000}},	//   _شۇنى, بلىغ_, _үүдс, --, 
   {{0x79880857,0xe7dc0139,0x453401f4,0x00000000}},	//   _ifew, _üzğä, ехэт, --, 
   {{0x78a8d9dd,0x00000000,0x00000000,0x00000000}},	//   _ivev, --, --, --, 
   {{0x3244d9de,0x6008002f,0xc4c402f2,0x00000000}},	//   денг, _rümp, وتیو, --, 
   {{0x600800c5,0x76440129,0x61200248,0x00000000}},	//   _sümp, éhyd, _ọlaj, --, 
   {{0xe44c0068,0x6ab81f14,0x47700022,0x78a80208}},	//   _аж_, _उम्र, _иқәу, _jvev, 
   {{0xccbc0150,0x44640064,0x00000000,0x00000000}},	//   _ﹼﺩﺨل_, _звів, --, --, 
   {{0x7988d9df,0xee3005d9,0x00000000,0x00000000}},	//   _ofew, نٽس_, --, --, 
   {{0x78a80124,0x00000000,0x00000000,0x00000000}},	//   _ovev, --, --, --, 
   {{0xdca0d9e0,0xec142d8d,0x1cc80327,0x6008265c}},	// [12780] кати, وورد, _ཊཱཾ_, _tümp, 
   {{0x79880a63,0xe3cc0051,0x00000000,0x00000000}},	//   _afew, _lựng_, --, --, 
   {{0x78a8d9e1,0x78ac39ae,0x6b54d9e2,0xa018023a}},	//   _avev, šavl, фтах, mpöp, 
   {{0xe3cc0051,0x00000000,0x00000000,0x00000000}},	//   _nựng_, --, --, --, 
   {{0x00500050,0x28680395,0xfd9801af,0x00000000}},	//   _شێہج, орко_, _хөсә_, --, 
   {{0xab2809a5,0x6d44025c,0xdca01d39,0xc78400db}},	//   _дога_, _ixka, _јари, راتۉ, 
   {{0x78a800e4,0x00000000,0x00000000,0x00000000}},	//   _evev, --, --, --, 
   {{0x3cec01a6,0x7d0800d8,0x2560022e,0x00000000}},	//   _ševi_, _àesc, lаli_, --, 
   {{0xe3cc07ae,0x00000000,0x00000000,0x00000000}},	//   _dựng_, --, --, --, 
   {{0xb86430a3,0x78bc143a,0xa49001d5,0xca200220}},	//   _كالو, _åsva, _ییبت, _ﺸﻲﺀ_, 
   {{0x78a80433,0xb0600166,0x00000000,0x00000000}},	//   _zvev, _çäyn, --, --, 
   {{0x66e40117,0x00000000,0x00000000,0x00000000}},	//   _ноҷа, --, --, --, 
   {{0xb9e40023,0x00000000,0x00000000,0x00000000}},	//   _ከዱ_, --, --, --, 
   {{0x656007d6,0x752c0209,0x506401c4,0x94d0009b}},	//   _izoh, _ýaza, втса, _рошц, 
   {{0x6d440067,0xe0cc00cc,0xbdd40108,0x4ea400d8}},	//   _axka, িটেন, новщ, крта, 
   {{0x64580cfd,0xb328031c,0xe24401f7,0xcdd80114}},	//   llti, _སྟིང_, _تختي, мњу_, 
   {{0xc4bc0183,0x3cf001f9,0x00000000,0x00000000}},	// [12790] _অনুজ, ीमधे_, --, --, 
   {{0x67340209,0x00000000,0x00000000,0x00000000}},	//   şyjy, --, --, --, 
   {{0x6458d9e3,0x6d44005a,0xf1c40825,0x9a8401b9}},	//   ilti, _exka, _वामन, фузл, 
   {{0x656001f0,0xddcc0276,0x64580306,0xca4802f2}},	//   _ozoh, _dicţ, hlti, ولله_, 
   {{0x656007a8,0x7e6cd9e4,0xa3bcd9e5,0x49740214}},	//   _nzoh, mmap, इला_, ندهآ, 
   {{0x7e6cd9e6,0xddcc054e,0x67d00114,0xb7d80066}},	//   lmap, _ficţ, гољу, سوعا_, 
   {{0x6560bee3,0x7e6c000d,0x3e4000c0,0x00000000}},	//   _azoh, omap, nėto_, --, 
   {{0xceb4b4a1,0x6458d9e7,0xda000d2e,0x78a8002b}},	//   דיק_, elti, _रचित_, _tvev, 
   {{0x2bc4454f,0xe3cc01fb,0x7e6c1577,0xf1b4000d}},	//   र्का, _vựng_, imap, _आएबन, 
   {{0x6930088e,0x7e6c3996,0x730414b7,0x3e4000c0}},	//   _حکمر, hmap, епоз, kėto_, 
   {{0x6560d9e8,0xc6a401c0,0xc48401e0,0xdb040118}},	//   _ezoh, _арчи, нлөк, _odjí, 
   {{0x6458d9e9,0x7e6c01e4,0x3e4000c0,0x00000000}},	//   alti, jmap, dėto_, --, 
   {{0x7e6c00cd,0x65600200,0x6fd400d4,0x753c00e5}},	//   dmap, _gzoh, нівц, úszd, 
   {{0x7414d9ea,0x66040008,0x841400c7,0x8f8401b9}},	//   _سوعا, ökkv, _имчх, ъқол, 
   {{0x3e4000c0,0x00000000,0x00000000,0x00000000}},	//   gėto_, --, --, --, 
   {{0x7e6cd9eb,0x42d400d4,0xc3400354,0x92f0009d}},	//   gmap, _рішу, _тĕс_, _зүүх, 
   {{0x2560022e,0x00000000,0x00000000,0x00000000}},	// [127a0] tаli_, --, --, --, 
   {{0xaf9834d8,0x248001f1,0x7e6c009a,0x3028118f}},	//   _этих_, íkmi_, amap, _хооп_, 
   {{0x2bc49e3f,0xe9d800e6,0x8f5403e6,0x0144001f}},	//   र्गा, зке_, _شۆرش, _ያስተም, 
   {{0xace8d9ec,0x2d9453e8,0x53cc00cd,0x98780023}},	//   _емма_, _ярос, त्तश, _ክሰምዑ_, 
   {{0xde2002d3,0xa968d9ed,0x2c640142,0xe78400db}},	//   ተዝኸው, чида_, tôdd_, нуйо, 
   {{0x2bc44da1,0x256001a9,0x00000000,0x00000000}},	//   र्खा, qаli_, --, --, 
   {{0xd6d4d9ee,0xd784021a,0xbb54037e,0x2c640142}},	//   еты_, رنيو_, _etcカ_, rôdd_, 
   {{0xa3d06495,0x6abcd9ef,0x00000000,0x00000000}},	//   ह्न_, mupf, --, --, 
   {{0x2900044e,0xd9405e87,0x68440261,0x69c00036}},	//   _çka_, _бети, _знаа, mgoe, 
   {{0x69c01af3,0x9c840f91,0x6458d9f0,0xf17c0150}},	//   lgoe, lačí, ulti, _ﺤﺯﺍﻡ_, 
   {{0x7e6c0784,0xb3680023,0x81e40154,0x68e003cb}},	//   ymap, _ደቓይቕ_, নাস_, lwod, 
   {{0x69c0d9f1,0xf3f40daf,0xe5a46191,0x9c840306}},	//   ngoe, еңә_, _чиди, načí, 
   {{0x6560d9f2,0x66040008,0x6abc006f,0x69c00549}},	//   _uzoh, ökku, hupf, igoe, 
   {{0x6abc0433,0x69c0d9f3,0x68f40108,0xf48400d4}},	//   kupf, hgoe, äydy, _руїн, 
   {{0x7e6cd9f4,0x69c0d9f5,0xefdc02d3,0x00000000}},	//   tmap, kgoe, ዕትዮ_, --, 
   {{0x6abc0526,0x69c00369,0x81e40011,0x7e6cd9f6}},	//   dupf, jgoe, নাহ_, umap, 
   {{0x7e6cd9f7,0x9c8401ef,0x00000000,0x00000000}},	// [127b0] rmap, dačí, --, --, 
   {{0x6abc4539,0x68e03bb5,0x113c011a,0xdb6800d8}},	//   fupf, dwod, _מתחל, прел_, 
   {{0xa3d007f8,0x6abc2dab,0x69c0d9f8,0x7e6c0369}},	//   ह्य_, gupf, fgoe, pmap, 
   {{0x68e00100,0xaad000bc,0x00000000,0x00000000}},	//   fwod, _सहरक, --, --, 
   {{0x1cc8031c,0xcdc8030c,0x22a40241,0x00000000}},	//   _ཊཱི_, _سۇلۇ_, _yíká_, --, 
   {{0xa3d053b7,0x6abc0230,0x69c001c6,0xc7a800d1}},	//   ह्म_, bupf, agoe, ىدىل_, 
   {{0xd3a00116,0x6abc7c49,0xb994007b,0x00000000}},	//   ңлиқ, cupf, _للأب, --, 
   {{0xd58404d3,0xe5f02d40,0x00000000,0x00000000}},	//   رێته_, لكىد, --, --, 
   {{0xe1fc0034,0xb7c40022,0x68e0020c,0x80ac0037}},	//   lmów_, _ареқ, cwod, _जिगे, 
   {{0x33f41955,0x249404fb,0x972418d9,0xd76401ec}},	//   тчис, کنید_, _пьед, _كەشى_, 
   {{0x2bc4a36b,0x4374234c,0xf1c407b7,0x00000000}},	//   र्टा, луют, _वादन, --, 
   {{0x752c010e,0x6d480112,0x8f180166,0x00000000}},	//   _ýazo, ßfak, larч_, --, 
   {{0x9350036b,0x20a01219,0x6abc002f,0xc4840064}},	//   ضرگچ, ағың, zupf, _блік, 
   {{0x9c841155,0x05640006,0x2fdc022e,0xb2f400f3}},	//   začí, _свін, еtga_, _аџић, 
   {{0x6da4d9f9,0xa3cc6b9b,0xada402bf,0xa3bc2d8f}},	//   кива, शभर_, кавл, इलर_, 
   {{0x68e00cfd,0x7bd40730,0x69c00007,0xdd8c36e7}},	//   ywod, _abzu, xgoe, قوف_, 
   {{0xdd8cd9fa,0x7af403fa,0x7528d9fb,0x6abc6e99}},	// [127c0] توق_, _arzt, nzez, wupf, 
   {{0xdcac07a7,0x6abc324c,0x5d6400d8,0x00000000}},	//   زىم_, tupf, тиум_, --, 
   {{0x81e40d42,0x69c0d9fc,0x75280036,0xfa8800d3}},	//   নার_, tgoe, hzez, есій_, 
   {{0x2bc4262c,0x6abcad0c,0xfe7401c0,0x7528009a}},	//   र्जा, rupf, _бүс_, kzez, 
   {{0x69c0d9fd,0x291087e5,0xfbd03ee0,0xccf800d1}},	//   rgoe, âya_, شتە_, _яқа_, 
   {{0x69c0d9fe,0x75280099,0x68e03743,0xeab801c6}},	//   sgoe, dzez, rwod, _ойг_, 
   {{0x752804ba,0x45d42401,0x69c00036,0x00000000}},	//   ezez, гойс, pgoe, --, 
   {{0xb0b003e5,0x48c4013d,0x68e0033b,0x00000000}},	//   _जिंग, _бәка, pwod, --, 
   {{0x752c0432,0x00000000,0x00000000,0x00000000}},	//   _ýazl, --, --, --, 
   {{0x2bc40316,0x7b08032e,0x228400cf,0x00000000}},	//   र्चा, _ístö, кумг, --, 
   {{0x4274d9ff,0x7528030a,0x00000000,0x00000000}},	//   лгос, azez, --, --, 
   {{0x6674168d,0x464400dc,0x00000000,0x00000000}},	//   _شدار, _aṣṭā, --, --, 
   {{0x81e40eac,0xe1fc033f,0x798c0309,0x54940064}},	//   নাল_, zmów_, ñawi, _авіў_, 
   {{0xe1fc0210,0x00000000,0x00000000,0x00000000}},	//   ymów_, --, --, --, 
   {{0x26cc13c4,0xdedc0023,0x804400db,0xd4780677}},	//   ntfo_, ዕብኡ_, _ۅردۅ, _קאול, 
   {{0x78ac0989,0x2bc4012a,0xf36402bf,0x00000000}},	//   šavi, र्घा, _стін, --, 
   {{0x61fcda00,0x7bf80598,0x39480034,0x16bc6b9b}},	// [127d0] _inql, ннар_, żasz_, _एम्ब, 
   {{0x7c580447,0x27fc020b,0x2904005a,0xdb0401d3}},	//   رلار_, _nntn_, dxoa_, _adjá, 
   {{0x7528da01,0x00000000,0x00000000,0x00000000}},	//   zzez, --, --, --, 
   {{0xf98804fb,0xe1fc0210,0x00000000,0x00000000}},	//   رنتي_, rmów_, --, --, 
   {{0x3948a1d4,0x7e7cbcc5,0xf1c408ec,0x98c40032}},	//   ças_, _iisp, _वासन, тсел, 
   {{0xa3d01f82,0xf744cf6f,0x26cc00d2,0x7e7cda02}},	//   _हॉल_, лело, ftfo_, _hisp, 
   {{0x4ae407d6,0x7e7c01d3,0x27fc0208,0x00000000}},	//   _кўта, _kisp, _dntn_, --, 
   {{0x7e7c003d,0x752801c0,0x7bc40158,0x0f7c011a}},	//   _jisp, tzez, lghu, ורול, 
   {{0x3f80063f,0xbb4400ee,0x44a43e1f,0x7bc401ab}},	//   _oghu_, _реңк, агың, oghu, 
   {{0x87d400c6,0x752c00ee,0xd3a012d7,0xf1c4da03}},	//   _نغما, _ýazm, шлоқ, _वाहन, 
   {{0x2c640109,0x95b00131,0x71a473b3,0x752801d3}},	//   nôda_, _көпх, ланз, szez, 
   {{0x7e7cda04,0x3f80026c,0xf55800ae,0x00000000}},	//   _nisp, _aghu_, _كلاب_, --, 
   {{0x04c800c6,0x0584da05,0x00000000,0x00000000}},	//   _لوني_, _тухм, --, --, 
   {{0x7e7c01e7,0x61ec0076,0x600803b9,0x00000000}},	//   _aisp, adcl, _zümz, --, 
   {{0xa064da06,0x00000000,0x00000000,0x00000000}},	//   уара_, --, --, --, 
   {{0xf8a4da07,0x7e7cda08,0x53cc1408,0xf73402d3}},	//   _وک_, _cisp, त्रश, _እንድሕ, 
   {{0x7e7cda09,0xdd8c46e6,0x82c0031c,0x80e8010b}},	// [127e0] _disp, سول_, _མའོའ, _агың_, 
   {{0x7e7cda0a,0xafe40228,0x81e40154,0x00000000}},	//   _eisp, _соол, নাঃ_, --, 
   {{0xe784023b,0x6e440736,0x00000000,0x00000000}},	//   қуло, _مندم, --, --, 
   {{0x7e7c00db,0x290401c0,0xe944026b,0x00000000}},	//   _gisp, txoa_, лхло, --, 
   {{0x27fc003e,0x205c001f,0x7bc40327,0xd94000d8}},	//   _pntn_, _ለህብረ, bghu, беци, 
   {{0xdd38008f,0x7e7c0489,0xa88401ec,0xb5a001ec}},	//   _װעלכ, _zisp, _ەلءى, _ﺍﺩﺍﻝ_, 
   {{0x6fd401ad,0xb6840022,0xaa440408,0x752c0432}},	//   म्यू, аҩха_, _бевл, _ýazj, 
   {{0xe4e400d6,0x7e7c004e,0x44b4da0b,0x97e400db}},	//   гіон, _xisp, абис, _ۅتمۅ, 
   {{0x27fc020c,0xe00402e5,0xe8f8da0c,0xe1fcda0d}},	//   _tntn_, शामद_, _яла_, llóg_, 
   {{0xc0d402d3,0xd4d4007b,0xe4c00022,0x16840133}},	//   _ክነሱ_, ابيض_, аиҩҩ, _ڵامێ, 
   {{0x3210010e,0x068c313e,0x00000000,0x00000000}},	//   _boyy_, _ﻗﺎﻣﯩ, --, --, 
   {{0x64a455a7,0x2d8000d5,0xa22404fb,0xb6840116}},	//   _бада, _ngke_, ارده, _ئشلى, 
   {{0x7e7cda0e,0x61ec1538,0x65c4035b,0x7bc4005c}},	//   _risp, rdcl, _абҵа, yghu, 
   {{0x4394da0f,0x7e7cda10,0x25a4da11,0x3e400006}},	//   _такс, _sisp, _heol_, mėti_, 
   {{0x7e7c08cd,0x248402f6,0x3e400006,0x42a401e0}},	//   _pisp, _huom_, lėti_, _тулғ, 
   {{0x92b0b65a,0x7e7c0986,0x6fd408df,0x3d94da12}},	//   _احوا, _qisp, म्बू, риар, 
   {{0x7e7cda13,0x3e4002d5,0x527c010f,0x6e380100}},	// [127f0] _visp, nėti_, _אנהא, ètba, 
   {{0x7e7cda14,0x25a400a9,0x996401ec,0x9a840166}},	//   _wisp, _leol_, қтел, гудл, 
   {{0x7e7cda15,0xb994470b,0x24840051,0x00000000}},	//   _tisp, للاب, _luom_, --, 
   {{0x201002b9,0x3e4002d5,0xca745f2e,0x2d80005a}},	//   _hoxi_, kėti_, مانغ, _ggke_, 
   {{0xaa4c069c,0x00000000,0x00000000,0x00000000}},	//   _ንኣምላ, --, --, --, 
   {{0x3e400953,0x2010da16,0x57a4927f,0x76b40063}},	//   dėti_, _joxi_, ушда, аљиц, 
   {{0xe7a400d1,0x068c5f32,0x00000000,0x00000000}},	//   شۇنى_, _ﻗﺎﻧﯩ, --, --, 
   {{0x25a4379c,0x201002c4,0xd1d80020,0x2484da17}},	//   _ceol_, _loxi_, ርቦት_, _buom_, 
   {{0x25a4da18,0x88040014,0xa5f40063,0x3e400153}},	//   _deol_, _گِلو, рењу_, gėti_, 
   {{0x8938084c,0xb4e4012c,0x2450009a,0x00000000}},	//   _спус_, _पनी_, ينيس, --, 
   {{0x25a400a3,0xa3e4000d,0xd30c0490,0x3c980150}},	//   _feol_, _पसर_, ाहेब_, _ﺘﻨﺴﻰ_, 
   {{0x25a4da19,0x3234016c,0x3e400006,0x24840142}},	//   _geol_, рхос, bėti_, _fuom_, 
   {{0xdb04005c,0x2010da1a,0x24840051,0x00000000}},	//   _udjæ, _boxi_, _guom_, --, 
   {{0x28ac000d,0x3c9801ec,0xc564009f,0x00000000}},	//   _घिघि, _ﺘﺨﺸﻰ_, _اُهي, --, 
   {{0x6e34da1b,0x201000e8,0x25a4213f,0x9ac4025c}},	//   ахах, _doxi_, _yeol_, _jiċħ, 
   {{0x3dd803cb,0x9ac4025c,0x00000000,0x00000000}},	//   _cbsw_, _miċħ, --, --, 
  
   {{0x6fd400d6,0x2bc84a40,0x2010da1c,0xe1fc43e5}},	// [12800] _кінц, клап_, _foxi_, rmót_, 
   {{0x20101bce,0x6b64da1d,0xef180354,0xeb982502}},	//   _goxi_, акза, _амо_, тиж_, 
   {{0x8024004b,0x9ac40327,0x394cda1e,0x93380023}},	//   _دريم, _niċħ, _axes_, _ኣንበሳ, 
   {{0x2ef84a29,0xe1fc022c,0x09cc0154,0x00000000}},	//   _irpf_, rlóg_, _রোজা, --, 
   {{0xe1fc0579,0x25a4da1f,0x6e2405d1,0xa3e400bc}},	//   slóg_, _reol_, _ilkb, _पसल_, 
   {{0x25a40597,0x9ad0063f,0x3e400024,0x635000bc}},	//   _seol_, sịak, vėti_, něné, 
   {{0x3af40116,0x25a40037,0x248442b9,0x205c0092}},	//   _лятс, _peol_, _suom_, _ለኅብረ, 
   {{0xc9d400f1,0x99880356,0x00000000,0x00000000}},	//   _دمرک, ălţa_, --, --, 
   {{0x248416b8,0x1cb00327,0x25a40254,0x00000000}},	//   _quom_, ྟེར_, _veol_, --, 
   {{0x3e400006,0x97e400db,0xf7e800ae,0x00000000}},	//   rėti_, _ۅتۅۅ, _مرمى_, --, 
   {{0x6350013a,0x00000000,0x00000000,0x00000000}},	//   děné, --, --, --, 
   {{0xd25800d6,0xd374da20,0x3e400024,0x2484da21}},	//   иця_, шчы_, pėti_, _tuom_, 
   {{0x0494da22,0x6600da23,0x6abc1196,0xd13821fe}},	//   _التح, _inok, hrpf, ахр_, 
   {{0x6e2402d0,0x398c0241,0xd3a002e8,0x09cc03d4}},	//   _alkb, _kósó_, _дръп, _ৰোমা, 
   {{0x5330da24,0x59d4194b,0x00000000,0x00000000}},	//   _мешт, ण्डर, --, --, 
   {{0x6e240076,0xa3d0012c,0xe1fc004e,0xd37802e4}},	//   _clkb, ह्र_, rmós_, _ברוט, 
   {{0x786c0120,0x660001f7,0x6abc002f,0xfb840133}},	// [12810] lúve, _mnok, erpf, مدای, 
   {{0xc684ab88,0x26dcda25,0x78bc01bf,0x9ba02a8b}},	//   _يې_, _opto_, _åsvi, تەسى, 
   {{0x6600da26,0x5398011a,0x00000000,0x00000000}},	//   _onok, דיבו, --, --, 
   {{0x81e42baf,0x66000083,0x9f400240,0x0a680c60}},	//   নাক_, _nnok, hejë_, арчи_, 
   {{0x26dca896,0x8cf402d5,0xd8e4033a,0x00000000}},	//   _apto_, _дзяц, рцеп, --, 
   {{0x6600da27,0x9f40036e,0x00000000,0x00000000}},	//   _anok, jejë_, --, --, 
   {{0xe734052f,0x6840da28,0x00000000,0x00000000}},	//   йеш_, янша, --, --, 
   {{0x3dc81089,0x26dc5781,0x753c01d3,0xdb040200}},	//   ngaw_, _dpto_, úszo, _lejë, 
   {{0x62980549,0xa018005b,0x8894022e,0x00000000}},	//   epto, spöy, _митх, --, 
   {{0x6600da29,0x78ac0cf4,0x9ac4025c,0x19540417}},	//   _enok, šavs, _tiċħ, _бағы_, 
   {{0x63500118,0xab640254,0x3e4000c0,0x00000000}},	//   věné, mmüü, lėtu_, --, 
   {{0x6600009a,0xab64000d,0x07081541,0x3f900210}},	//   _gnok, lmüü, _خيمي_, eczu_, 
   {{0xe56cda2a,0x9f400240,0xa3d0012d,0xf8c405ac}},	//   _хз_, bejë_, _हॉक_, _এনুঠ, 
   {{0xc2c804fb,0x33940e55,0xed581171,0x00000000}},	//   دبیل_, _الغز, ҳоб_, --, 
   {{0xc2e8acdc,0xfbcc015b,0xb4c40032,0x66000d13}},	//   _نعيم_, রজাত, _тиҙҙ, _ynok, 
   {{0x32d0011f,0x3e4000c0,0x00000000,0x00000000}},	//   máy_, kėtu_, --, --, 
   {{0xdc78044e,0x32d0011f,0x3ce802e2,0x7124004b}},	// [12820] ኣብሄር_, láy_, gwav_, _درغل, 
   {{0x3dc81c06,0x21340375,0x3e400064,0x00000000}},	//   agaw_, _לטפל_, dėtu_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb4cda2b,0xdb040241,0x6e24035a,0x00000000}},	//   رَن_, _mejè, _ulkb, --, 
   {{0xd9400124,0xdb040100,0x9f400240,0x9dd400f2}},	//   пеци, _lejè, yejë_, _ازپش, 
   {{0xbc180220,0x62980d63,0x66005794,0xd5b401e0}},	//   _кісі_, ypto, _snok, ҡсы_, 
   {{0x6600009a,0x00000000,0x00000000,0x00000000}},	//   _pnok, --, --, --, 
   {{0x32d0011f,0xa5640214,0x2d9000d8,0xa9d401e2}},	//   dáy_, یدکن, ncye_, _دقرغ, 
   {{0xa924da2c,0x9f400240,0x612c01e1,0x98a0da2d}},	//   _удал, tejë_, _mòlé, _ните, 
   {{0x44380086,0x82d800d8,0x00000000,0x00000000}},	//   òr_, адос_, --, --, 
   {{0x5c5800c8,0x9f400240,0x26dc6b41,0x21fc3b22}},	//   רדיק, rejë_, _upto_, _nähä_, 
   {{0x6600da2e,0x5b780bd9,0x5fd837f3,0xc0480023}},	//   _unok, טריא, म्नल, _ዓብላል, 
   {{0x62981a06,0xdb040240,0x64980150,0x00000000}},	//   spto, _pejë, _стер_, --, 
   {{0x6298da2f,0xb9200241,0x6560da30,0x3dc81c06}},	//   ppto, _aisọ_, _iyoh, wgaw_, 
   {{0x543800c8,0x442cda31,0x00000000,0x00000000}},	//   _געגא, mhd_, --, --, 
   {{0x63a8da32,0x628800df,0x6560037e,0x442cbcd7}},	//   _hefn, _iufo, _kyoh, lhd_, 
   {{0x62880115,0x40340107,0x6458da33,0x7c140212}},	// [12830] _hufo, _меис, ooti, одає, 
   {{0x6288da34,0x3dc8089c,0x442cda35,0x1fa4009d}},	//   _kufo, sgaw_, nhd_, _уриг, 
   {{0x6288058a,0xdb6801c6,0xb4e41116,0x6fb402f2}},	//   _jufo, урал_, _पन्_, _بمپا, 
   {{0x6458da36,0x3ce81529,0x6288da37,0x65600117}},	//   hoti, pwav_, _mufo, _oyoh, 
   {{0x656000ca,0x89a80212,0x628801f4,0x00000000}},	//   _nyoh, сків_, _lufo, --, 
   {{0x63a800fc,0x6458da38,0x81e4009e,0x4c94a0d5}},	//   _nefn, joti, নাট_, _хирс, 
   {{0xa3bc7db3,0x6560da39,0x7d0c0227,0x6288da3a}},	//   ेलन_, _ayoh, lxas, _nufo, 
   {{0x65600230,0xab640037,0x00000000,0x00000000}},	//   _byoh, smüü, --, --, 
   {{0x62880b23,0x65600526,0x32d00548,0x39140022}},	//   _aufo, _cyoh, wáy_, _ьмар, 
   {{0x6288da3b,0x656018f7,0x63a80cfd,0x6458da3c}},	//   _bufo, _dyoh, _cefn, goti, 
   {{0x63a80f7b,0x65600944,0xb5940139,0x0ea80037}},	//   _defn, _eyoh, _диеш, _छौंड, 
   {{0x6288da3d,0x7d0c00aa,0x32d0011f,0x680800e2}},	//   _dufo, kxas, ráy_, rēdņ, 
   {{0xe3aca29d,0x6458da3e,0x7648da3f,0x7d0c0227}},	//   _об_, boti, mney, jxas, 
   {{0x442cda40,0x6458da41,0x63a8da42,0x5f90039b}},	//   chd_, coti, _gefn, диёт, 
   {{0xa3d0006d,0x6288da43,0x7648d958,0xdb0401ed}},	//   _हॉट_, _gufo, oney, _fejé, 
   {{0x76481368,0xdb040036,0x21fc023a,0x225402f2}},	//   nney, _gejé, _vähä_, _ولود_, 
   {{0x62880e78,0x7648d958,0x6278011a,0xed4400d8}},	// [12840] _zufo, iney, _דנקנ, цнап, 
   {{0x09b40a94,0x62880793,0xafc40150,0x21fc01f4}},	//   ुल्य, _yufo, _بيدى, _tähä_, 
   {{0xaab82491,0x934c0023,0x5f7400ec,0x7648da44}},	//   شدار_, _ዛዕባታ, _واپر, kney, 
   {{0xe8f8da45,0xed5800a8,0xc2cc00c8,0x442c0240}},	//   иле_, _вом_, רמאָ, zhd_, 
   {{0x3eac0bb8,0x6458006c,0x7648da46,0x8884015e}},	//   ćete_, yoti, dney, سیان, 
   {{0x6560da47,0x6fa82ba2,0x76481081,0x58341cb8}},	//   _ryoh, करिं, eney, озія_, 
   {{0xe5c4da48,0xadfc00e1,0x6560037e,0x00000000}},	//   оспо, _उफान_, _syoh, --, 
   {{0x6458da49,0x7648da4a,0xf6e40006,0x5b3000e5}},	//   woti, gney, яцін, _کٹہر, 
   {{0xd9400372,0x6fa80490,0x6288da4b,0xe808014b}},	//   _жети, करां, _sufo, _кнад_, 
   {{0x656007a8,0xe73842c6,0x7648da4c,0x62880311}},	//   _vyoh, _кез_, aney, _pufo, 
   {{0x64580325,0x1bf800c8,0x63a80008,0x38680b45}},	//   roti, בליב, _vefn, ɓar_, 
   {{0x645829ef,0x76480067,0xe1fc08a5,0x00000000}},	//   soti, cney, flóa_, --, 
   {{0xda78025f,0x65601cdf,0x5184da4d,0x00000000}},	//   ינטר, _uyoh, дура, --, 
   {{0x6288da4e,0xa34401c0,0x6458da4f,0x00000000}},	//   _tufo, _мэйл, qoti, --, 
   {{0x2a641c06,0x539806a9,0x1b1c0c58,0xdda8da50}},	//   klob_, _דיוו, _যেনে_, итал_, 
   {{0x443cda51,0x7d0c0227,0xfbdc102f,0x00000000}},	//   _hmv_, txas, न्नम, --, 
   {{0xa3ac0037,0x786c00c7,0x5fd0044b,0x443c01ef}},	// [12850] _ओजा_, húva, _तापल, _kmv_, 
   {{0x443cda52,0x786c00d7,0x00000000,0x00000000}},	//   _jmv_, kúva, --, --, 
   {{0x7648da53,0x7d0c01b9,0x786c0022,0xa9b800d1}},	//   yney, sxas, júva, ﻧﻤﯩﺴ, 
   {{0x7d0c094a,0x443c047e,0x786c0419,0x76480009}},	//   pxas, _lmv_, dúva, xney, 
   {{0xd13402d3,0x91b000cc,0x00000000,0x00000000}},	//   _ኣድሓኖ, _কামখ, --, --, 
   {{0xfc1401c0,0xdd8c00ec,0x00000000,0x00000000}},	//   _эмгэ, _سوڀ_, --, --, 
   {{0x2a64356c,0x7c240af2,0x291005ac,0x5fd00037}},	//   blob_, mkhr, øyar_, _तानल, 
   {{0x7648a75f,0x443c045a,0x2f8000d1,0x00000000}},	//   uney, _amv_, ﯩﺮﯨﻢ_, --, 
   {{0x443cda54,0xe4d40597,0xfed000fe,0x798802d0}},	//   _bmv_, كويت_, াবিধ, _igew, 
   {{0x7c2406a3,0x7648da55,0xd7044c02,0x00000000}},	//   nkhr, sney, _وظاي, --, 
   {{0x78a8da56,0x07f8da57,0xfbdc1a3e,0x7c240472}},	//   _hwev, _برقع_, न्यम, ikhr, 
   {{0x78a805b8,0x443c0037,0x3a341432,0x7648058a}},	//   _kwev, _emv_, _çapı_, qney, 
   {{0x40940108,0x00000000,0x00000000,0x00000000}},	//   дрст, --, --, --, 
   {{0x7964010c,0x29340a1e,0xceb800fb,0x25a003e0}},	//   ግስታት, לארן_, оҙо_, ıkle_, 
   {{0x78a85617,0xada401a9,0xfc40069d,0x6da40aac}},	//   _lwev, забл, _ተረጋግ, зиба, 
   {{0xe1fc26c8,0x7988da58,0x78a80c8c,0x7c240472}},	//   llón_, _ngew, _owev, ekhr, 
   {{0x6c84da59,0x52d88054,0x09200eac,0x1d04da5a}},	// [12860] سلام, _बहुस, _মেনু_, пети_, 
   {{0x7988da5b,0xe0f80375,0x00000000,0x00000000}},	//   _agew, _פליל, --, --, 
   {{0x78a8014b,0xe8f801c0,0x2a64003d,0x00000000}},	//   _awev, өлж_, tlob_, --, 
   {{0x78a8090c,0x7c240009,0x00000000,0x00000000}},	//   _bwev, akhr, --, --, 
   {{0x20400092,0xe1fc0419,0x00000000,0x00000000}},	//   _ከህብረ, klón_, --, --, 
   {{0xdb040ca8,0x786c00c7,0x00000000,0x00000000}},	//   _kejì, túva, --, --, 
   {{0x443cda5c,0xe9a402bf,0x224801f5,0x7e940210}},	//   _rmv_, _навп, ynck_, _kąpa, 
   {{0x786cda5d,0x00000000,0x00000000,0x00000000}},	//   rúva, --, --, --, 
   {{0x443c74b3,0x78a8da5e,0xe1fc04d4,0x786cda5f}},	//   _pmv_, _gwev, flón_, súva, 
   {{0x39480005,0x786c0022,0xd6cc0133,0x35688b0a}},	//   úase_, púva, _ڕقم_, өрөн_, 
   {{0x78a80d27,0x443c017a,0x00000000,0x00000000}},	//   _zwev, _vmv_, --, --, 
   {{0x7ae00730,0x443c5717,0x66e40107,0xd0840022}},	//   _älte, _wmv_, _моҷа, ҵыси, 
   {{0x21641fdf,0xe1fcda60,0xd20801c6,0x443cda61}},	//   ятог, blón_, чээд_, _tmv_, 
   {{0xe1fc09c2,0x443c01bf,0x00000000,0x00000000}},	//   clón_, _umv_, --, --, 
   {{0xf1c40574,0x00000000,0x00000000,0x00000000}},	//   _वाचन, --, --, --, 
   {{0x1e500240,0x00000000,0x00000000,0x00000000}},	//   _ዘብጽሓ, --, --, --, 
   {{0x91bc0302,0x00000000,0x00000000,0x00000000}},	// [12870] _המחי, --, --, --, 
   {{0x78a8006f,0x5fa01896,0x1fa402ec,0x9f400118}},	//   _rwev, _سەرم, _эриг, lejí_, 
   {{0x78a8000f,0x7e74059f,0xff2400f2,0xbd900150}},	//   _swev, _огох, _آبخی, _ақбө, 
   {{0x78a80100,0x00000000,0x00000000,0x00000000}},	//   _pwev, --, --, --, 
   {{0xa3bcda62,0x8a140691,0xca24da63,0xff240133}},	//   ेला_, عظما, эффи, _ربگی, 
   {{0xfa0400ec,0x00000000,0x00000000,0x00000000}},	//   _ڪورٽ, --, --, --, 
   {{0xe81c1889,0xe1bc2e35,0x00000000,0x00000000}},	//   _बकरा_, ्लाघ, --, --, 
   {{0xc7440491,0xdb040316,0x79880221,0x78a80b54}},	//   عضوي, _její, _ugew, _twev, 
   {{0x8508005e,0xdb042e27,0xe1fc04d4,0x9f4002f0}},	//   здың_, _mejí, tlón_, dejí_, 
   {{0xdb040789,0xc8c810ef,0xe3b40262,0xe79402f2}},	//   _lejí, _رومن_, мбь_, _قامک, 
   {{0x1b1c00bd,0x3a2cda64,0x9f4002f0,0xdb200139}},	//   _যেতে_, _klep_, fejí_, _öräk, 
   {{0xfbdc0882,0xf8d0a3c6,0x27140154,0xdb04013a}},	//   न्तम, _समाय, _থেকো_, _nejí, 
   {{0x047801b9,0xe1fc0419,0x00000000,0x00000000}},	//   تلیک_, plón_, --, --, 
   {{0xf4d01df2,0x00000000,0x00000000,0x00000000}},	//   _ﻛﻪﺳﻜ, --, --, --, 
   {{0xa064013e,0x00000000,0x00000000,0x00000000}},	//   фара_, --, --, --, 
   {{0x9f400118,0xdcfc002b,0x8fc40022,0x00000000}},	//   cejí_, _śvās, ьаҳҵ, --, 
   {{0xac8405f5,0x995c00e8,0x9d40696b,0xdb0400d0}},	// [12880] дгал, _déŋk_, ветд, _dejí, 
   {{0x3a2cda65,0xcc64215c,0x00000000,0x00000000}},	//   _alep_, رناۋ, --, --, 
   {{0xfbdc227c,0x29880229,0xa25015b4,0x6da401f0}},	//   न्धम, осло_, _سپیش, _оина, 
   {{0x3a2c507c,0xa9a40b01,0x00000000,0x00000000}},	//   _clep_, фидд, --, --, 
   {{0xc7b80841,0x83fc16a3,0xec7800d8,0x00000000}},	//   _lođe_, lođe, _мпм_, --, 
   {{0x9f4000bc,0x3a2c013d,0xfbdca1f3,0xefcc0092}},	//   zejí_, _elep_, न्दम, ባቸዉ_, 
   {{0xdb80084c,0x3a2c0036,0xb864009f,0x00000000}},	//   _агри, _flep_, راهو, --, 
   {{0x44f4da66,0xe5c4cc9a,0x3a2c0142,0x00000000}},	//   епис, фско, _glep_, --, 
   {{0x59b00cef,0x83fc8185,0x00000000,0x00000000}},	//   _рөхс, hođe, --, --, 
   {{0x83fc1727,0x9f50002e,0x98a0014b,0xa2b044eb}},	//   kođe, _waxé_, _рифе, _आबद्, 
   {{0xd6ccda67,0x9f500129,0x00000000,0x00000000}},	//   _نقل_, _taxé_, --, --, 
   {{0xc7b804b9,0xf7482ad9,0x64a4da68,0x03540131}},	//   _dođe_, _عجله_, _жада, _җүмә_, 
   {{0xd1640395,0x00000000,0x00000000,0x00000000}},	//   въри, --, --, --, 
   {{0x9f4000bc,0xdb04013a,0x00000000,0x00000000}},	//   sejí_, _sejí, --, --, 
   {{0x83fc0bb8,0x00000000,0x00000000,0x00000000}},	//   gođe, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x101801ed,0xdb04013a,0x00000000,0x00000000}},	// [12890] سکیں_, _vejí, --, --, 
   {{0xefcc0201,0x83fc0b91,0x3a2cda69,0xa9a001b9}},	//   ባቸው_, bođe, _slep_, қишд, 
   {{0xb5fc0384,0x00000000,0x00000000,0x00000000}},	//   loše, --, --, --, 
   {{0xd378008f,0x00000000,0x00000000,0x00000000}},	//   קראט, --, --, --, 
   {{0xb5fc041a,0x26109ad9,0x00000000,0x00000000}},	//   noše, थानी_, --, --, 
   {{0x7d0800d8,0x00000000,0x00000000,0x00000000}},	//   _àesq, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb5fcda6a,0x7af400e5,0x00000000,0x00000000}},	//   koše, _iszt, --, --, 
   {{0xb5fc0063,0x74146bd8,0x7af40334,0xa4d40063}},	//   joše, فوظا, _hszt, едњу_, 
   {{0xb5fc1dd5,0x25a003ee,0x7af40034,0xc7b808a4}},	//   doše, ıkla_, _kszt, _pođe_, 
   {{0x43740212,0x482438eb,0x00000000,0x00000000}},	//   куют, _جىلق, --, --, 
   {{0x83fc1326,0x34942424,0xc7b81225,0xe60c02f4}},	//   vođe, _задр, _vođe_, _ёд_, 
   {{0xb5fc009b,0x3dd40154,0xe44c03f5,0x00000000}},	//   goše, হজাল, _бж_, --, 
   {{0x7af400dd,0x6f1800d7,0x00000000,0x00000000}},	//   _oszt, ätco, --, --, 
   {{0xdee05e7a,0x068c2e56,0xe298001e,0xe454008f}},	//   лори, _ﻗﺎﻟﯩ, _trưa_, _איסט_, 
   {{0x2610084a,0x83fc098d,0xd7dcda6b,0xfbdc454f}},	//   थायी_, rođe, प्तच, न्सम, 
   {{0x7af400dd,0x93f00490,0xe800012c,0x00000000}},	// [128a0] _aszt, _असाच_, लयमा_, --, 
   {{0xdb04067c,0x6b54da6c,0x3ec4029f,0x2e2c032e}},	//   _bejà, нтех, üstü_, _dýfa_, 
   {{0x20140419,0x00000000,0x00000000,0x00000000}},	//   údiť_, --, --, --, 
   {{0x6e580014,0xfd1001e2,0x00000000,0x00000000}},	//   _ژٔھر_, دجې_, --, --, 
   {{0x7af401ed,0x23c40241,0x7d0800d8,0x684400cf}},	//   _eszt, _jíjà_, _àesp, ннда, 
   {{0xfaf001ed,0x3c900244,0x00000000,0x00000000}},	//   دثے_, _ئیلز, --, --, 
   {{0x6b8c01e1,0xa3b4000d,0x00000000,0x00000000}},	//   _igbg, _ज़ब_, --, --, 
   {{0x7d080077,0xb8640efc,0x7ae001e3,0x95d402e8}},	//   _áesc, _یالو, _älta, едът_, 
   {{0x888400c7,0x23c401e1,0x00000000,0x00000000}},	//   _акаҧ, _níjà_, --, --, 
   {{0x28740032,0x24a00023,0xb5fc3858,0x00000000}},	//   _яҡлы_, _ግጥማት_, voše, --, 
   {{0xf2e4054e,0x6f18002f,0xe5a40117,0x00000000}},	//   ţând_, ätcl, _зиеи, --, 
   {{0x5ab41a4c,0x00000000,0x00000000,0x00000000}},	//   עלכע_, --, --, --, 
   {{0xf3f4da6d,0xe1fc30f9,0xba0802d3,0xd83c0427}},	//   رتیک, llók_, _ወዱ_, _ščit_, 
   {{0xb5fc0f03,0xdb0401ed,0x506401c6,0x00000000}},	//   roše, _lejá, гтса, --, 
   {{0x9e04da6e,0xb5fc9d28,0x91b0015b,0x26cc030a}},	//   нчал, soše, _কারখ, nufo_, 
   {{0x27ec03cb,0x00000000,0x00000000,0x00000000}},	//   hefn_, --, --, --, 
   {{0x7bf80598,0x61ec62e5,0x26cc016b,0xb5fc01a6}},	// [128b0] мнар_, mecl, hufo_, lošc, 
   {{0x61ec65ef,0xfb8403e6,0x645401e1,0x00000000}},	//   lecl, ندای, _ìyid, --, 
   {{0xdb0401ed,0xb5fc0841,0x00000000,0x00000000}},	//   _bejá, nošc, --, --, 
   {{0x61ecda6f,0x6b8c002f,0x00000000,0x00000000}},	//   necl, _egbg, --, --, 
   {{0x1cc80d46,0x7e6cda70,0xdb0409d7,0x19900116}},	//   _ིའི_, mlap, _dejá, ваҗя, 
   {{0x7e6cda71,0x7bd40034,0xf8d000dc,0x0c84004e}},	//   llap, _uczu, _समीप, _бысм, 
   {{0x8f9c00c8,0xe1fc011f,0x3b6401d9,0xcc5400a7}},	//   ליגי, glók_, _شُرِ, _свръ, 
   {{0x7e6c00dd,0x61ec0067,0x46380108,0x00000000}},	//   nlap, jecl, ечья_, --, 
   {{0x97a4447e,0xa3bc0490,0xe1fc002e,0x00000000}},	//   _зрел, ेलं_, koób_, --, 
   {{0x7e6cda72,0x19540220,0xe1fc0429,0x97000131}},	//   hlap, _жағы_, llóh_, _مېتى, 
   {{0x13a4021a,0x71a413cf,0xf8d00b7c,0xe1bc28d4}},	//   ونکی_, канз, _समुप, ्लंघ, 
   {{0xa69425f9,0x61ec6cf6,0x00000000,0x00000000}},	//   _סכנה_, gecl, --, --, 
   {{0x7e6cda73,0x628cda74,0x85b8da75,0x00000000}},	//   dlap, íbor, _سانس_, --, 
   {{0x7e6c01ee,0xb5fc01fa,0xa0a0a626,0xc17400ee}},	//   elap, bošc, рард, ыҗы_, 
   {{0x998c02d5,0x3ea00109,0xd58404d3,0x7e6c002d}},	//   nigų_, _ctht_, _تێکه_, flap, 
   {{0x7e6cda76,0x61ec0072,0xa5c40077,0xddc0036b}},	//   glap, cecl, mpóñ, ибси, 
   {{0x9f500429,0xc7b80e04,0x00000000,0x00000000}},	// [128c0] _caxâ_, _lođa_, --, --, 
   {{0xe0b413e2,0xdcac0447,0x29fc01f2,0xe1fc011f}},	//   _שליט_, تىك_, _ịa_, ylók_, 
   {{0xe9d8da77,0x7e6c003a,0xf1b42bf1,0xe46826bb}},	//   дке_, blap, _अजान, ljöö_, 
   {{0xceb80006,0x7e6cda78,0xfa480131,0x00000000}},	//   šęs_, clap, ىشنى_, --, 
   {{0x83fc01fa,0xb7b40208,0x7ae0002f,0x6c84007b}},	//   hođa, _vọn, _ältn, _للحم, 
   {{0x4ab4013d,0x22980055,0x00000000,0x00000000}},	//   _бөдр, _līka_, --, --, 
   {{0xd6d41669,0xe1fc011f,0x27ec0368,0xf53800d7}},	//   вты_, blóh_, refn_, ezť_, 
   {{0x26cc03f9,0xe1fcba60,0x61ec0129,0x3e600092}},	//   rufo_, clóh_, xecl, _ለእነር, 
   {{0x61ec7cea,0x26cc013f,0xcfb803d4,0xba5400a7}},	//   vecl, sufo_, _জানন, _стръ, 
   {{0xa8486b89,0x1e1c74ad,0xf4d006ba,0x00000000}},	//   _غلام_, _यक्ष_, _ﻛﻪﺗﻜ, --, 
   {{0x83fc05ce,0x61ec0857,0xccf40605,0x7e6cda79}},	//   gođa, tecl, hwɛ_, ylap, 
   {{0xe4c41eaf,0xe5a450ae,0x9f8800c5,0xe7d000c5}},	//   _айди, _риди, _köök_, _साँप, 
   {{0x61ecda7a,0x23086ea9,0xe4b0004e,0x00000000}},	//   recl, ستگي_, _тилө, --, 
   {{0xb5fcda7b,0x4fc4da7c,0x61ecda7d,0x6e3400d7}},	//   moša, исса, secl, ehyb, 
   {{0x7e6cda7e,0x61ec4e13,0x442cda7f,0xb5fc2672}},	//   tlap, pecl, mkd_, loša, 
   {{0x7e6c0069,0x442c0098,0x66e803b9,0x00000000}},	//   ulap, lkd_, _təkf, --, 
   {{0x7e6cda80,0x23b41533,0x3d0c068f,0xb5fc00da}},	// [128d0] rlap, _आजाद, समें_, noša, 
   {{0x7e6c2e03,0x9b2400f3,0xe1fcda81,0x00000000}},	//   slap, кфел, ldó_, --, 
   {{0xe0dcb2cc,0x7e6cda82,0x00000000,0x00000000}},	//   ltò_, plap, --, --, 
   {{0x6e340232,0xe1fcda83,0xb5fc005f,0x2cbc0024}},	//   chyb, ndó_, koša, _žydų_, 
   {{0xe0dcda84,0xb5fc005f,0x89a802bf,0x786c00d8}},	//   ntò_, joša, тків_, lúvi, 
   {{0xb5fc00da,0x19a40131,0x377400fd,0x8cc4010a}},	//   doša, _ﺷﯩﻨﺠ, лыйс, _тĕшĕ_, 
   {{0x3668da85,0x81b800bd,0x9a840124,0x3cf80208}},	//   нако_, _চান_, _ауал, _hssv_, 
   {{0x83fc04b9,0xc7b80989,0xd90c64ec,0x6dbc0882}},	//   vođa, _vođa_, _ویا_, ṇavi, 
   {{0xb4641eec,0x9f4002f6,0xe1fc0548,0xb5fc00e2}},	//   лкил, lejä_, ddó_, goša, 
   {{0xe574abc6,0x33f40131,0x6444020c,0x3cf80051}},	//   ызы_, учис, ékip, _mssv_, 
   {{0x229800b0,0x84580801,0x1dc0085c,0x9f40005b}},	//   _pīka_, ърът_, षणात, nejä_, 
   {{0x83fc1591,0xd7dc0825,0xe1fc011f,0xb5fc005f}},	//   rođa, प्रच, gdó_, boša, 
   {{0x7d0808ad,0x73e405f5,0x764803f9,0xa5c40077}},	//   _šesn, _болз, miey, spóñ, 
   {{0x9f40049b,0x442c0477,0x94200075,0x7648009a}},	//   kejä_, ckd_, _خوتۇ, liey, 
   {{0x752800dd,0xd5b411b1,0xb9040135,0xb7b401f2}},	//   lyez, _इजाज, _ཨཱ_, _nọm, 
   {{0x76480280,0x9f400108,0x00000000,0x00000000}},	//   niey, dejä_, --, --, 
   {{0xdb0401b8,0xec78da86,0xdcfc00ac,0x2fb80262}},	// [128e0] _lejä, епа_, faqı, _пынэ_, 
   {{0xdcac10a8,0x6e3402c4,0x32d8010e,0xe7d00d0d}},	//   سىم_, shyb, _güyç_, _साइप, 
   {{0x75280007,0x76480086,0x9f880037,0x6e34035a}},	//   hyez, kiey, _söök_, phyb, 
   {{0x752804ba,0x9f880254,0x00000000,0x00000000}},	//   kyez, _pöök_, --, --, 
   {{0x75280526,0x93f00073,0x00000000,0x00000000}},	//   jyez, _असंच_, --, --, 
   {{0xdb04014a,0xb5fc00da,0x7528da87,0xe1fc01d3}},	//   _bejä, voša, dyez, rlói_, 
   {{0x6f180036,0xe6640798,0x00000000,0x00000000}},	//   ätch, лтио, --, --, 
   {{0xb5fc0029,0x76480789,0x6abc002f,0x26e400cc}},	//   toša, giey, mspf, কিলো_, 
   {{0x752874e1,0x2a6401d4,0x2900020c,0xe5b001ec}},	//   gyez, moob_, _éka_, айқы, 
   {{0x2a648b14,0xb5fc00da,0x4614168d,0x2ef800b5}},	//   loob_, roša, اوکر, _ospf_, 
   {{0xd7900491,0xb5fcda88,0xdb040036,0x7ae8009b}},	//   _المخ, mošn, _gejä, _ćetk, 
   {{0xb5fcda89,0x2a640441,0xe0dccdd9,0x66745220}},	//   lošn, noob_, ttò_, _صدار, 
   {{0xe1fcda8a,0x27fc03a2,0x75280526,0x66700014}},	//   rdó_, _katn_, cyez, _پۯکر, 
   {{0xe0dc6933,0x2a640070,0xb5fc01fa,0x9f500327}},	//   rtò_, hoob_, nošn, _paxà_, 
   {{0xf8d0255c,0x2a64a51d,0xe0dcda8b,0x27fc07d6}},	//   _सम्प, koob_, stò_, _matn_, 
   {{0x9f500429,0xb1442a77,0x9f40005b,0x3df41d39}},	//   _caxá_, اییم_, vejä_, јзас, 
   {{0x2fd8010a,0x5bc80640,0x248c0334,0x7c58da8c}},	// [128f0] _fcpg_, ећег_, _kifm_, پلار_, 
   {{0x63b8da8d,0x2128068f,0x61fc298d,0x9f4002f6}},	//   natn, mych_, _haql, tejä_, 
   {{0x09bc00bd,0x61fc5d7a,0x21283ba3,0x229800e8}},	//   _ইউজা, _kaql, lych_, _jëk_, 
   {{0x2248da8e,0x9f40da8f,0xdb04049f,0x63b8da90}},	//   nick_, rejä_, _rejä, hatn, 
   {{0x2128da91,0x9770da92,0x61fcda93,0x27fc0010}},	//   nych_, әтлә, _maql, _batn_, 
   {{0x63b80d0f,0x75280dd4,0x229800b0,0x2248da94}},	//   jatn, vyez, _nīko_, hick_, 
   {{0xdb20006c,0x75d414a5,0xc7c40a8f,0x2248da95}},	//   _اوزی, ليغا, ссчи, kick_, 
   {{0x212801a2,0x248c031c,0x7624da96,0x4b240131}},	//   kych_, _aifm_, рмиз, _دېمە, 
   {{0xe614da97,0xe4d4da98,0xb5fc05be,0xf9a801e1}},	//   рды_, لويت_, bošn, _erèé_, 
   {{0x2128da99,0x63b8da9a,0x7528da9b,0x271c02e3}},	//   dych_, gatn, ryez, ọnal_, 
   {{0x35f4da9c,0x61fcccb5,0x75280489,0x2248002f}},	//   _впер, _baql, syez, fick_, 
   {{0x61fc01d9,0x22980de2,0x2248da9d,0x255c0521}},	//   _caql, _dëk_, gick_, ịla_, 
   {{0xb5fc27c4,0x61fc6895,0x04c80fb4,0x94000166}},	//   lošo, _daql, _موني_, _голҗ, 
   {{0x63b8da9e,0x2ef8009f,0x6538010f,0x3d081bd6}},	//   catn, _pspf_, _בענד, सिने_, 
   {{0x1cd80156,0xdfcc0597,0x71a40311,0xfbcc0183}},	//   _ཡདཔ_, ظيف_, _кайз, ৰজাত, 
   {{0x31240801,0xada46022,0x21280210,0x00000000}},	//   _вдиг, раал, bych_, --, 
   {{0x2128006d,0xeb98da9f,0x2ea401d3,0x9e6000d4}},	// [12900] cych_, виз_, _چھری_, івуд, 
   {{0x629c74c3,0xafe47bb3,0xda080490,0xb5fcdaa0}},	//   _époc, _тоол, _सोबत_, košo, 
   {{0x61fc0724,0x49a41669,0xb5fc00e2,0x6e940022}},	//   _yaql, былғ, jošo, _әиҭу, 
   {{0xaad01a2a,0x61fcdaa1,0x63b8072d,0x6abc02d0}},	//   दूषक, _xaql, zatn, rspf, 
   {{0x63b8daa2,0xb5fcdaa3,0x2a64daa4,0x6abc0112}},	//   yatn, tošn, roob_, sspf, 
   {{0x752c09a5,0x682401a8,0x84c401e0,0x3ea40115}},	//   _ýazy, _aðdr, ҡәлд, ŭlte_, 
   {{0x63b80bb8,0xeb3404a9,0x2128068f,0x27fcdaa5}},	//   vatn, _ئىزد, zych_, _vatn_, 
   {{0x2c0805ba,0x63b802b4,0x2a64198f,0x44b4daa6}},	//   _होतं_, watn, qoob_, ббис, 
   {{0x63b8489c,0x2248009f,0x3d0800e1,0x229800e8}},	//   tatn, vick_, सिये_, _sëk_, 
   {{0xe7b801d9,0x61fcdaa7,0x3cf82aa1,0x2128daa8}},	//   _ईजिप, _saql, _उनसे_, vych_, 
   {{0x212814cf,0x63b8daa9,0x61fcdaaa,0x43940116}},	//   wych_, ratn, _paql, _һалс, 
   {{0x63b8daab,0x2128772b,0xd544004b,0x61fc014f}},	//   satn, tych_, الیو_, _qaql, 
   {{0x2248daac,0x63b8daad,0x925800a7,0x61fc014f}},	//   rick_, patn, раят_, _vaql, 
   {{0x2128daae,0x224804ce,0x61fcdaaf,0x63b8dab0}},	//   rych_, sick_, _waql, qatn, 
   {{0x2248dab1,0x61fcdab2,0x671442e3,0xc7b808a4}},	//   pick_, _taql, थमिक_, _međ_, 
   {{0x68e0dab3,0x5bac01ad,0x212844ef,0x00000000}},	//   ktod, टर्व, pych_, --, 
   {{0xb5fcdab4,0x4d982401,0x127c010f,0x5fe400c0}},	// [12910] došl, ркую_, _באהע, _кінж, 
   {{0x5ba4dab5,0x38ac0241,0xa3b4000d,0x00000000}},	//   рраз, _lórò_, जरि_, --, 
   {{0x68e0dab6,0xb99400c6,0xe1fc3b7b,0x8c64331d}},	//   etod, ملاب, blót_, ітуд, 
   {{0x3914dab7,0x68e00115,0xb5fc5a54,0x383401ec}},	//   ймер, ftod, vošo, өнер, 
   {{0xe1fcdab8,0xa3b443d1,0x49c812fa,0xb4b40037}},	//   llós_, जरा_, рлін_, _जबे_, 
   {{0xb5fcdab9,0x20004464,0x81dc09bd,0x41f40882}},	//   tošo, ndji_, ড়ি_, ेयुः_, 
   {{0x68e0daba,0x29040194,0x8b880046,0xac800354}},	//   atod, avoa_, _نەكە_, _хӳтл, 
   {{0xcf580bd4,0x38c801d3,0x068c0220,0x291401e7}},	//   יבות_, _مائی_, _ﺗﺎﻧﯩ, ódaí_, 
   {{0x81dc03f4,0xdb0400bc,0x00000000,0x00000000}},	//   ড়া_, _nejú, --, --, 
   {{0xe1fcdabb,0xbf28002b,0x98bc013d,0xb5fc00d7}},	//   klós_, _kṣār, _uzuı_, mošm, 
   {{0xd6d815ed,0x75b40451,0x00000000,0x00000000}},	//   _шта_, _هٽائ, --, --, 
   {{0xf5940597,0x20000327,0x786c0174,0x00000000}},	//   _الإج, edji_, rúvu, --, 
   {{0x66e800ac,0x659808c3,0x00000000,0x00000000}},	//   _təkc, _עיסק, --, --, 
   {{0x3db002a6,0x0574dabc,0x229000f1,0x51ac0150}},	//   _ছাগল, _بامد, _کليس, _ﺳﯩﻨﺸ, 
   {{0xae580212,0x6da40131,0x9ed40108,0x00000000}},	//   грає_, йива, ймёт_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x66e800ac,0xab80001f,0xa3bc0073,0xd7d401f9}},	// [12920] _məka, _ይታያል_, ेलच_, ठलाच, 
   {{0xef181b15,0xd1dc0023,0x999c0356,0x00000000}},	//   _бмо_, ንንቲ_, _pluş_, --, 
   {{0xe1fc56eb,0x68e000d8,0xa8040022,0x2e2c02d2}},	//   clós_, wtod, heñò, _lýfi_, 
   {{0xb7b4063f,0x9ac801ed,0xb950001f,0x6da400f1}},	//   _kọw, ادلہ_, ቃዋሚዎ, _دمحم, 
   {{0xc7b800f3,0x68e000c5,0xb5fc04a7,0x00000000}},	//   _peđ_, utod, rošl, --, 
   {{0xdca0dabd,0x6c342868,0x3bd4084c,0xa17808d8}},	//   _хари, _افسا, _мюсс, נטסט, 
   {{0x68e0dabe,0xb5fc1326,0x6e2401e6,0xa9a4023a}},	//   stod, pošl, _kokb, _гибд, 
   {{0x68e00048,0xcd4c001f,0x8d7c00d1,0xaa44011c}},	//   ptod, _በመንገ, ﻣﺸﺎﻕ_, _уебл, 
   {{0x1cb0031c,0xaa5c01ec,0x00000000,0x00000000}},	//   ཟེར_, _жеңi, --, --, 
   {{0xf990dabf,0xdb0400c7,0x00000000,0x00000000}},	//   _آبِ_, _rejú, --, --, 
   {{0xe6940597,0xd5ac40e0,0x6e240c8c,0xfbdc4982}},	//   _الصد, _нс_, _ookb, न्टम, 
   {{0x80dc5d2d,0x3cf8038e,0xdb0400e4,0x81b80183}},	//   যবস্, _उनले_, _pejú, _চাহ_, 
   {{0x66000093,0xb5fc0010,0xdee00b82,0xddc8031c}},	//   _iaok, košj, ምዖን_, ġiżm, 
   {{0x25dc0cb2,0x6600030a,0x1dd40137,0x9f5001e3}},	//   _गाडी_, _haok, өлгө_, _laxå_, 
   {{0x6600dac0,0x6e24dac1,0x8f3471cd,0x7f8407d6}},	//   _kaok, _bokb, перц, زلرن, 
   {{0x6600007d,0x814401b9,0xd354011a,0xe1fc00e5}},	//   _jaok, _وپغم, _לשוק_, rlós_, 
   {{0x6e24020c,0x66000433,0xaea001f2,0x00000000}},	// [12930] _dokb, _maok, _ọptị, --, 
   {{0x6600dac2,0x00000000,0x00000000,0x00000000}},	//   _laok, --, --, --, 
   {{0x3d940868,0x720800e5,0xb9980395,0x00000000}},	//   _минр, _صفیہ_, авех_, --, 
   {{0x6600dac3,0xe1fc002e,0x00000000,0x00000000}},	//   _naok, koóm_, --, --, 
   {{0x64487328,0xd8e4361e,0x5c0400a7,0xc3140154}},	//   _omfi, сцеп, _лява, ানটি_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6600dac4,0x00000000,0x00000000,0x00000000}},	//   _baok, --, --, --, 
   {{0x25dc0574,0xb5fc2e31,0x66000051,0xf624003b}},	//   _गाणी_, mošk, _caok, ідпо, 
   {{0x7ae46586,0x6600a026,0x66e803b9,0x00000000}},	//   ltht, _daok, _vəka, --, 
   {{0x78a8dac5,0x72c4084c,0x81b8015b,0x5ecc00fe}},	//   _itev, обоз, _চাষ_, _হৈছে, 
   {{0x66e800ac,0x95b001e0,0x7ae40175,0x8c1c010f}},	//   _təka, _ерлә, ntht, טוזי, 
   {{0x64480b6f,0x753401c6,0x7ae4dac6,0x00000000}},	//   _emfi, _мэлх, itht, --, 
   {{0xe44cdac7,0x629cdac8,0x25dc02ab,0x26c80158}},	//   _жж_, _épon, _गाती_, _åbor_, 
   {{0xb5fc245e,0x16140490,0x234803e6,0x2898008f}},	//   košk, थावर_, اسیی_, יישא, 
   {{0xb5fc0b91,0x81b800bd,0x7f183327,0xb22400cf}},	//   jošk, _চার_, біту_, _ммкл, 
   {{0x78a8dac9,0xb5fc2b57,0xcca400c7,0x00000000}},	//   _otev, došk, згақ, --, 
   {{0xec4805cc,0xfca80acb,0x81dc02f5,0x78a832bc}},	// [12940] азал_, مالو_, ড়শ_, _ntev, 
   {{0x6e242b92,0x7ae402d0,0xe2a00150,0x3ea401e4}},	//   _wokb, ftht, _ﺍﺟﻪﻡ_, ŭlta_, 
   {{0x6e242b92,0x78a8daca,0x92b40183,0x98a40115}},	//   _tokb, _atev, _চমু_, ĝiĝi_, 
   {{0x6094030f,0x98a40115,0x00000000,0x00000000}},	//   _دنیس_, ŝiĝi_, --, --, 
   {{0xa888dacb,0x6600dacc,0x77600120,0x2be00a94}},	//   айда_, _raok, _axlx, _पापा, 
   {{0x75c80184,0x6600dacd,0xb5fca7ab,0xab640254}},	//   ҡтың_, _saok, bošk, glüü, 
   {{0xab28156b,0x6600dace,0x78a800c7,0xb5fc01fa}},	//   _това_, _paok, _etev, cošk, 
   {{0x3e44001f,0x3a3c0175,0x00000000,0x00000000}},	//   _ከእነር, chwp_, --, --, 
   {{0xe4e410f5,0x6600dacf,0x81b80eac,0xdc640092}},	//   ційн, _vaok, _চাল_, ዲጨምር_, 
   {{0x6600dad0,0x4438033f,0x64980137,0xdb100248}},	//   _waok, ór_, лтүр_, _ọ̀dọ, 
   {{0x2be0dad1,0x6600dad2,0x1fe000cc,0x00000000}},	//   _पाना, _taok, য়মস, --, 
   {{0x92580c9e,0xe800012c,0x00000000,0x00000000}},	//   жают_, लयका_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x28d00e49,0x00000000,0x00000000,0x00000000}},	//   _सिनि, --, --, --, 
   {{0x6458dad3,0xfdc802dd,0x7ae40334,0x8f0801f0}},	//   mnti, йтақ_, xtht, охта_, 
   {{0xc7b8041a,0x83fc110c,0xc0c435e3,0x00000000}},	//   _dođi_, dođi, _нәги, --, 
   {{0xe048034c,0x6458dad4,0xc0e41954,0x00000000}},	// [12950] _نشده_, onti, ምቶም_, --, 
   {{0x6458dad5,0xb5fc0306,0xdb14056a,0xdd9002dd}},	//   nnti, tošk, saxí, зағы, 
   {{0xc7b800f3,0x6ff8011a,0xe81c134e,0x00000000}},	//   _gođi_, _ההתפ, पाना_, --, 
   {{0xb5fc0f72,0x9a84dad6,0xbc940063,0x6458002f}},	//   rošk, цузл, _намј, hnti, 
   {{0x9a8002d3,0x77600175,0xb5fc0427,0x7e6c00c7}},	//   _ይኣክል_, _sxlx, sošk, moap, 
   {{0x2be01fbc,0xb5fcdad7,0x7e6cdad8,0x093400c6}},	//   _पाया, pošk, loap, برمج, 
   {{0xb5fc000a,0x9a8c01af,0x00000000,0x00000000}},	//   loši, _ауаh, --, --, 
   {{0x33540228,0x6458dad9,0x7e6c037e,0x66e806be}},	//   үүдө_, enti, noap, _təkn, 
   {{0x78a8dada,0x81b800fe,0xb5fc00e2,0x97a408db}},	//   _utev, _চাং_, noši, _дрел, 
   {{0x64580b1a,0x7e6c05da,0x97000131,0x66e803b9}},	//   gnti, hoap, _يېشى, _kəkl, 
   {{0xa820034c,0x7e6cdadb,0x25a4c92b,0x57d40073}},	//   _سکون, koap, _ffol_, ठलीह, 
   {{0x6458dadc,0xc0480302,0x98cc0d0d,0x28d0dadd}},	//   anti, _גז_, _हटाए, _सिमि, 
   {{0x645801d4,0x25089fa2,0xb5fc7a23,0xd49831e2}},	//   bnti, _هروی_, joši, _тре_, 
   {{0xc7b801a6,0x6458003a,0x1fa400a7,0xb5fcdade}},	//   _pođi_, cnti, зкри_, doši, 
   {{0x7e6c0421,0xd3b000c7,0x2d940137,0xa854011a}},	//   foap, _есқь, зөгө_, לישה_, 
   {{0x9f4801ed,0xc7b80960,0xfd9800d1,0x237400ae}},	//   áját_, _vođi_, ەئەت_, _عميد_, 
   {{0x2bc8d4b3,0xb5fcdadf,0x22989ec4,0xe81c00bc}},	// [12960] йлап_, goši, _rīki_, पामा_, 
   {{0x7c642d74,0x66e806be,0x054c0064,0x229800de}},	//   والل, _bəkl, _šūkį_, _sīki_, 
   {{0x229800b0,0x6f880014,0x6da4022e,0x2be01df0}},	//   _pīki_, _دندِ_, _нина, _पाठा, 
   {{0x628400bc,0x83fc009b,0xed58283c,0xb5fc00ef}},	//   ňkov, rođi, _гом_, boši, 
   {{0xb5fcdae0,0x6458dae1,0x00000000,0x00000000}},	//   lošw, ynti, --, --, 
   {{0x18644143,0x7b00005b,0x25dc0037,0x00000000}},	//   пачи_, äytä, _गाही_, --, 
   {{0xf1bc1d27,0xa6100209,0x00000000,0x00000000}},	//   ्णान, езйә, --, --, 
   {{0x6458dae2,0x6e34dae3,0xd6d000d1,0x2be00073}},	//   wnti, nkyb, رتىغ, _पाडा, 
   {{0x69c00165,0x279400d8,0x00000000,0x00000000}},	//   maoe, _ешер, --, --, 
   {{0x25dc0490,0xdb1400d0,0x16840014,0xc2f00154}},	//   _गावी_, laxá, _ہانێ, টিসি_, 
   {{0xe41801f1,0x81d408ca,0x51840124,0x00000000}},	//   _kľúč, монх, ҵура, --, 
   {{0x69c0dae4,0x25b009a5,0xf60804d3,0x46140345}},	//   naoe, _ýyl_, _وتنه_, _زوتر, 
   {{0x2c640109,0xa2cc00cd,0xe57800d4,0x00000000}},	//   sôdy_, _थिव्, _узд_, --, 
   {{0xb7b401f2,0x92d800cc,0x00000000,0x00000000}},	//   _họr, _ডনৰ_, --, --, 
   {{0x7e6cdae5,0x443c0165,0x69c0009f,0xdb0400a2}},	//   toap, _ilv_, kaoe, _bejý, 
   {{0xa508038f,0x443c001e,0xb5fc00e2,0x23c40118}},	//   _ཀློག_, _hlv_, toši, bíjí_, 
   {{0x7e6c00a8,0x69c0005a,0x5dc002dd,0x00000000}},	// [12970] roap, daoe, _ﺩﻩﻧﺴ, --, 
   {{0x443c0076,0x7e6c0311,0xd568074d,0x00000000}},	//   _jlv_, soap, _тiел, --, 
   {{0x3cf82007,0x69c00368,0xb5fcdae6,0x7e6c035b}},	//   _उनके_, faoe, soši, poap, 
   {{0x6e34037e,0x443c0175,0x66e806be,0x00000000}},	//   ckyb, _llv_, _cəkm, --, 
   {{0x443c429b,0xc7b816a3,0x88c800d4,0x00000000}},	//   _olv_, _lođu_, злів_, --, 
   {{0x7d0cdae7,0x66e803be,0x443c017a,0x8d600092}},	//   mvas, _təkl, _nlv_, ቲያቸው_, 
   {{0x2be009fa,0x69c000d8,0x96d00131,0x00000000}},	//   _पाता, baoe, хслә, --, 
   {{0x443cdae8,0x69c000d8,0xdb0400a2,0xe5f000d1}},	//   _alv_, caoe, _mejü, نكىد, 
   {{0x7d0cdae9,0x3ce83453,0x25dc00c5,0x00000000}},	//   nvas, ntav_, _गारी_, --, 
   {{0x9f400789,0x23c40118,0x57240228,0x00000000}},	//   nejó_, víjí_, _ىراق, --, 
   {{0x7d0cdaea,0x443c6144,0x3ce800af,0xb5fc0419}},	//   hvas, _dlv_, htav_, došv, 
   {{0xc7b80b91,0x443cdaeb,0x3ce80036,0x00000000}},	//   _dođu_, _elv_, ktav_, --, 
   {{0x443cdaec,0x22980064,0x00000000,0x00000000}},	//   _flv_, _rūke_, --, --, 
   {{0x4094daed,0xdb0401b8,0x7d0cdaee,0x443c089b}},	//   ерст, _bejü, dvas, _glv_, 
   {{0xdee0daef,0x7d0c679c,0xe81c045b,0x8c480139}},	//   кори, evas, पाता_, _laşç, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7d0ccd7a,0x5fac17c6,0x2be000dc,0x61e8007c}},	// [12980] gvas, _ज्वल, _पादा, _ögla, 
   {{0x443cdaf0,0x7e6816a3,0x2bc802dd,0x2f1400e4}},	//   _xlv_, čepa, ілеп_, _ẽguy_, 
   {{0x7d0cdaf1,0x7d081d2d,0x25dc35e8,0xae040150}},	//   avas, _šest, _गाली_, _قودى, 
   {{0x8c4803be,0x255c063f,0x7d0c007f,0xfe74009d}},	//   _başç, ịli_, bvas, _зүс_, 
   {{0x2198008f,0x98a02be9,0x69c00165,0x9f400241}},	//   קבסא, виче, raoe, bejó_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb04068c,0x443cdaf2,0x66e800ac,0x48f00037}},	//   _dejó, _rlv_, _təkm, _इहवो_, 
   {{0x443cdaf3,0xe96800d8,0x66e806be,0xa9680114}},	//   _slv_, _дабл_, _həkk, _диба_, 
   {{0x7d080077,0xb5fc00e2,0x00000000,0x00000000}},	//   _áest, jošu, --, --, 
   {{0x629c003e,0xd4640063,0x940406be,0xdb040210}},	//   _épok, миње_, _kinə_, _gejó, 
   {{0x7d0c8f07,0x66e80213,0x00000000,0x00000000}},	//   zvas, _məkk, --, --, 
   {{0xc7b805a1,0x06b402f5,0x2d800427,0x94040213}},	//   _vođu_, _টিপি, _ozke_, _minə_, 
   {{0x229800e2,0xb9d01954,0xd4d400f2,0x00000000}},	//   _rīku_, _ጵያ_, _قبوض_, --, 
   {{0x443c1477,0xd084023a,0xbe0401ed,0x22980171}},	//   _ulv_, выси, کورٹ, _sīku_, 
   {{0x9e04daf4,0x63a802d0,0x62200116,0x00000000}},	//   мчал, _iffn, _لوغە, --, 
   {{0x7d0c0882,0x3ce800c5,0x62644c2d,0x3e480092}},	//   tvas, ttav_, _تاتق, _መወያየ, 
   {{0xa2d8daf5,0x7d0c083a,0xb5fc107d,0xdd00005f}},	// [12990] पूर्, uvas, mošt, _ārēj, 
   {{0x7d0cdaf6,0x61ec1543,0x3ce804cc,0xb5fc5c82}},	//   rvas, lfcl, rtav_, lošt, 
   {{0x7d0cdaf7,0x3ce8daf8,0xdb04067c,0x00000000}},	//   svas, stav_, _rejó, --, 
   {{0xfe3404ac,0x7d0c2147,0x8d942928,0x94040213}},	//   _נאָך_, pvas, رلەش, _dinə_, 
   {{0xadd406a9,0x0e4400c0,0x00000000,0x00000000}},	//   _אורח_, _рээм, --, --, 
   {{0xdb040561,0xbc681698,0x8c480139,0xb5fc013a}},	//   _dejò, _رمزن_, _vaşç, hošt, 
   {{0x7bc4daf9,0x3ea000af,0xb5fc107d,0xa4f8031c}},	//   mahu, _juht_, košt, _དགུག_, 
   {{0x7bc4dafa,0x9a8405f5,0x63a8035a,0xb5fc2625}},	//   lahu, _цугл, _affn, jošt, 
   {{0x391463ed,0x3a2c0393,0x3ea0000d,0x00000000}},	//   _ямар, _ioep_, _luht_, --, 
   {{0xc984dafb,0x7bc4dafc,0x3a2c017a,0x00000000}},	//   _руси, nahu, _hoep_, --, 
   {{0x35b4160b,0x7bc400b0,0x2be092c1,0x3a2c0139}},	//   _збер, iahu, _पासा, _koep_, 
   {{0x3a2c09b6,0xb5fcdafd,0x00000000,0x00000000}},	//   _joep_, tošu, --, --, 
   {{0x7bc4dafe,0xa0a00116,0x054c0064,0x00000000}},	//   kahu, лаяд, _šūvį_, --, 
   {{0x7bc4daff,0x3a2c27bb,0xb5fc00e2,0x046405a2}},	//   jahu, _loep_, rošu, _үтәм, 
   {{0x7bc4db00,0xa064d842,0x3ea00076,0x53a00023}},	//   dahu, хара_, _cuht_, _ዉሑዳት_, 
   {{0x2be00490,0x66e80213,0x7bc400d8,0x940406be}},	//   _पाहा, _səkk, eahu, _rinə_, 
   {{0x6bd4db01,0x7bc42c98,0x90b40116,0x940403e3}},	// [129a0] فتار, fahu, _шәнш, _sinə_, 
   {{0x229802b5,0xdb04067c,0x09d81fbc,0xaf040022}},	//   _hūka_, _rejò, डल्य, _зпол, 
   {{0x3a2c017a,0x2cb02ab7,0x2298db02,0xb5fc0118}},	//   _boep_, spyd_, _kūka_, nošs, 
   {{0x298400fd,0xa9a4db03,0xb8080154,0x25bc0b26}},	//   нылг, хидд, লাফত_, _एजेण, 
   {{0x3a2c017a,0xfd00db04,0x229800b8,0x66e806be}},	//   _doep_, _күтп, _mūka_, _təkk, 
   {{0x7bc4db05,0x66e803be,0xb524009e,0x58340a4a}},	//   cahu, _həki, যনাথ_, нзія_, 
   {{0xe5c4d9ec,0x28d00da3,0x00000000,0x00000000}},	//   нспо, _सिवि, --, --, 
   {{0x068c0ed1,0x9b140375,0xe5c4db06,0x00000000}},	//   _ﺗﺎﻗﯩ, _אחלה_, хско, --, 
   {{0xcfd802f5,0x87e8010b,0x66e806be,0x00000000}},	//   দ্যন, _олаң_, _məki, --, 
   {{0x439400d8,0x684401c6,0x00000000,0x00000000}},	//   капс, _янза, --, --, 
   {{0x2ca0014b,0xe1fc00c6,0xe8140cb4,0x5fa405d7}},	//   _lukd_, nnóg_, _धोया_, _खलबल, 
   {{0x7bc4db07,0xa5d801ec,0x657403cd,0x3ea01196}},	//   zahu, _ءبار_, _øyho, _ruht_, 
   {{0x3ea005a7,0xb5fcdb08,0xd1640724,0xa6e00011}},	//   _suht_, rošt, гъри, _মনিট, 
   {{0x7bc4db09,0x2be008a3,0x63a8022e,0x3ea0000d}},	//   xahu, _पाषा, _uffn, _puht_, 
   {{0xb5fc05a1,0xe1900372,0x66e803e3,0x61e8007c}},	//   pošt, _өлкө, _bəki, _öglo, 
   {{0x7bc4db0a,0x142004a9,0x5f4401c6,0x66e803b9}},	//   wahu, _адәм, дүүн_, _cəki, 
   {{0x7bc4db0b,0x3a2c5b5e,0x628c0194,0x3d9401a9}},	// [129b0] tahu, _roep_, mmco, тиар, 
   {{0xdde83b99,0x3a2c0196,0xe1fcdb0c,0x81b8009e}},	//   _کرده_, _soep_, leó_, _চাট_, 
   {{0x3a2cdb0d,0x2be00b8f,0x7490002b,0xf1b400bc}},	//   _poep_, _पारा, _jāgṛ, ंरचन, 
   {{0x7bc4db0e,0x795800c7,0xe1fc0789,0xf8b801c0}},	//   sahu, миер_, neó_, дөж_, 
   {{0x7bc4db0f,0x8d84016c,0xe0dcdb10,0x37e4036b}},	//   pahu, _бурд, nuò_, волг, 
   {{0x7d080077,0x28d06859,0x66e806be,0x00000000}},	//   _áesq, _सिरि, _zəki, --, 
   {{0x81d8045e,0x3a2cdb11,0x749000b8,0x3d0808a3}},	//   ঠ্য_, _toep_, _nāgṛ, सिके_, 
   {{0xe1fc0789,0xa8002d1c,0x44ac0ca8,0x00000000}},	//   jeó_, çıra, _ẹsẹ_, --, 
   {{0xe1fc00dd,0xe81c0c2e,0xf86807f2,0xb5fc0010}},	//   deó_, पाशा_, _قمري_, jnše, 
   {{0x64440066,0x3cf80118,0x047c0240,0x00000000}},	//   èkip, _mpsv_, _ርእየዮ_, --, 
   {{0xe81c0d41,0xe1fc00cf,0x74900055,0x324436dd}},	//   पारा_, feó_, _cāgṛ, венг, 
   {{0x6b982833,0x95c83c1a,0x628400e8,0x229800ef}},	//   _útge, _хужа_, ŋkon, _pūka_, 
   {{0x7e6807f5,0x2be035e0,0x33000154,0x00000000}},	//   čepl, _पाला, এমইএ_, --, 
   {{0x66e803e3,0x00000000,0x00000000,0x00000000}},	//   _səki, --, --, --, 
   {{0xe45400c8,0x3cf800b8,0x386401f5,0x00000000}},	//   _ביסט_, _apsv_, _mjlr_, --, 
   {{0x28d005dc,0x068c1870,0xce3469f1,0x00000000}},	//   _सिलि, _ﺗﺎﻟﯩ, دورک, --, 
   {{0x66e803be,0x708400d1,0xac081fce,0x00000000}},	// [129c0] _vəki, _игиз, мнаа_, --, 
   {{0x2134008f,0x2be00073,0x1c4001ec,0x00000000}},	//   _סטיל_, _पाळा, анум, --, 
   {{0xa3840086,0xd5b02d6b,0x66e80213,0xca4c0150}},	//   _ijõñ, ीराज, _təki, _ﻀﻁﺭ_, 
   {{0x6da4db12,0x6cc400ee,0x2ef80112,0x999c013a}},	//   _шима, _ийма, _ippf_, _kouř_, 
   {{0x7d080077,0xe81c0073,0x00000000,0x00000000}},	//   _áesp, पाला_, --, --, 
   {{0x987002d5,0x291401b9,0x7b08068c,0xa7306b62}},	//   аліц, _یوزآ, ïstò, идлә, 
   {{0x442001dc,0x39900023,0xe664011c,0x00000000}},	//   _đi_, _ምዓልቲ_, ктио, --, 
   {{0x3cec0356,0x00000000,0x00000000,0x00000000}},	//   _ţevi_, --, --, --, 
   {{0x2ca40491,0xd1f4044e,0xa8040166,0x29000248}},	//   íodh_, ልኦት_, _изал, _èka_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe1fc0407,0xd4f001c6,0x26c80248,0x5c3405d0}},	//   teó_, гжөө, _ìbo_, דרין_, 
   {{0xe2700137,0xe0dc0393,0x74900055,0xae100037}},	//   ркмө, tuò_, _vāgṛ, _ढोलन_, 
   {{0x628c34b9,0x628400e8,0x944000e5,0x1540009b}},	//   rmco, ŋkoo, _چھپن, _кецм, 
   {{0xe1fc0789,0xb5fc0427,0x5064db13,0x135000e5}},	//   seó_, rnše, атса, ائیج, 
   {{0x9f500005,0x4ea42e1d,0x90981fbe,0x80a4000d}},	//   _raxó_, ирта, тврт_, _गंवइ, 
   {{0x6d0c13b4,0xd25800a8,0x00000000,0x00000000}},	//   सिंग_, _аць_, --, --, 
   {{0x8d74543c,0xe0dc08e7,0x2ef80009,0x64540241}},	// [129d0] لاكا, quò_, _eppf_, _ìyis, 
   {{0x5fb43b11,0xfb8401d5,0x00000000,0x00000000}},	//   _अभिल, هدای, --, --, 
   {{0x5f400075,0x0ba45fb2,0xddf00166,0x00000000}},	//   _ئۆزل, ршум, _конө, --, 
   {{0x629c4aee,0x63b80334,0x22980055,0x00000000}},	//   _épou, hbtn, _mūko_, --, 
   {{0xa3e0482a,0x4974009d,0x00000000,0x00000000}},	//   धला_, алцс, --, --, 
   {{0xfbc805d9,0x3dc82db1,0xa80003e0,0x00000000}},	//   _سڀئي_, laaw_, çıpa, --, 
   {{0x63b8010a,0x87e40108,0x00000000,0x00000000}},	//   dbtn, рюче, --, --, 
   {{0x3dc83d27,0x29c80943,0xf5087201,0xdb0401d3}},	//   naaw_, ṱari_, енил_, _bejö, 
   {{0x27f40118,0x756401d3,0x970000d1,0x27e80200}},	//   ídní_, دیشہ_, _چېتى, çinë_, 
   {{0x5884b71d,0xd0440115,0x3dc80036,0xe0dc02e2}},	//   _рыба, _spiɾ, haaw_, rzòl_, 
   {{0xf7380b82,0x291800b0,0x3dc83699,0x00000000}},	//   ራውያን, āpae_, kaaw_, --, 
   {{0xd2f40f01,0x229800c0,0x00000000,0x00000000}},	//   _یکجا_, _dūko_, --, --, 
   {{0x2ef82165,0xd4c4004e,0x00000000,0x00000000}},	//   _sppf_, _рсеп, --, --, 
   {{0x42ac01ec,0xa0a0db14,0x00000000,0x00000000}},	//   _ﺍﻟﯩﭙ, сард, --, --, 
   {{0xa56050c9,0x6d4801e4,0x00000000,0x00000000}},	//   _نگین, ĝfam, --, --, 
   {{0x3dc800e8,0x66e803b9,0x00000000,0x00000000}},	//   gaaw_, _təkv, --, --, 
   {{0xfca8009f,0x00000000,0x00000000,0x00000000}},	// [129e0] نالو_, --, --, --, 
   {{0x629c00f7,0x320002fb,0x00000000,0x00000000}},	//   _èpoc, leky_, --, --, 
   {{0xe9d8db15,0x28c46c8e,0x00000000,0x00000000}},	//   еке_, रीनि, --, --, 
   {{0x66e80cc1,0x60d8000a,0x320005da,0x30d400d1}},	//   _məkt, šume, neky_, ﭘﺘﻮﻧ, 
   {{0xc7b80e04,0xed34084c,0x6fb817c6,0x00000000}},	//   _anđa_, _сэнэ, ्रपू, --, 
   {{0xf53800bc,0xac08db16,0x2fc80e04,0xbc1802dd}},	//   dyť_, _янга_, nabg_, _иісі_, 
   {{0x999c0510,0xf1b807ae,0xdc644f85,0xd6d409a5}},	//   _onuň_, _đơn_, _сард_, гты_, 
   {{0x22980153,0x96b40114,0x00000000,0x00000000}},	//   _rūko_, ћују_, --, --, 
   {{0x320002f0,0x00000000,0x00000000,0x00000000}},	//   deky_, --, --, --, 
   {{0x29043545,0x3dc8022f,0x68e0db17,0xa3e800c7}},	//   mwoa_, zaaw_, muod, хьиз_, 
   {{0x2fc8003e,0x4de4012c,0x5c58008f,0x68e01f39}},	//   dabg_, गलाई_, תדיק, luod, 
   {{0xe5a4db18,0x612c0139,0xf53800d0,0x00000000}},	//   _сиди, _bеlе, byť_, --, 
   {{0x68e00024,0xd258084c,0x00000000,0x00000000}},	//   nuod, уцэ_, --, --, 
   {{0x4394807e,0x3dc86ed5,0x213c0327,0x99500055}},	//   _калс, waaw_, ġuh_, _ṣū_, 
   {{0x6458db19,0x68e000ca,0x26cc06af,0x7f9418cd}},	//   miti, huod, nsfo_, равх, 
   {{0x442c01e6,0x3164009b,0x62640150,0x68e0db1a}},	//   ljd_, _žoze_, _حاتق, kuod, 
   {{0x6458db1b,0x28c4150d,0x3dc8011f,0x68e0db1c}},	// [129f0] oiti, रीमि, raaw_, juod, 
   {{0x68e00006,0x629c0455,0x00000000,0x00000000}},	//   duod, _hiqo, --, --, 
   {{0x2000db1d,0xb9b4021f,0x629cd02b,0x6458db1e}},	//   meji_, لماع, _épos, iiti, 
   {{0x2000db1f,0x3914db20,0x629c0978,0x76b0002b}},	//   leji_, имер, _jiqo, _jāye, 
   {{0x629c0fec,0x89a802bf,0xb5fc01a6,0x25dc033f}},	//   _miqo, уків_, jnša, _गाजी_, 
   {{0x6458db21,0x629c0f3f,0xb8dc00af,0x64440024}},	//   jiti, _liqo, _आऽ_, ūkij, 
   {{0x6458db22,0xf6242d30,0x9a84db23,0xf74411f7}},	//   diti, идко, _буал, рейо, 
   {{0xceb4159d,0x629cdb24,0x2000db25,0x6458db26}},	//   זיק_, _niqo, heji_, eiti, 
   {{0x2000db27,0xdcec00e2,0xab6000a2,0x32000419}},	//   keji_, _izcē, _çürk, veky_, 
   {{0xe574084c,0x07441945,0xf5380030,0x4d7c008f}},	//   рзь_, рхәм, ryť_, ערזע, 
   {{0x7bd402ce,0x629c047e,0x200002fd,0x32001d55}},	//   _mdzu, _biqo, deji_, teky_, 
   {{0x629c03b4,0x64587801,0x6fb84433,0x00000000}},	//   _ciqo, aiti, ्रभू, --, 
   {{0x629cdb28,0x32000122,0x20000e04,0x442c00d8}},	//   _diqo, reky_, feji_, bjd_, 
   {{0x7bd4db29,0x2000db2a,0x7648db2b,0x645826c2}},	//   _ndzu, geji_, lhey, citi, 
   {{0x2fc800f3,0xe514228d,0x00000000,0x00000000}},	//   rabg_, तिथि_, --, --, 
   {{0x7bd40bd7,0x76b00055,0x612c01d5,0x7648db2c}},	//   _adzu, _gāye, _tеlе, nhey, 
   {{0x648409cc,0x2000db2d,0xec78db2e,0x999c010e}},	// [12a00] iðin, beji_, впа_, _unuň_, 
   {{0x68e002f6,0x629cdb2f,0x7648db30,0x81ac0154}},	//   vuod, _ziqo, hhey, গরণ_, 
   {{0x7988007f,0xeab013d7,0x7648db31,0xf1d89856}},	//   _azew, زعا_, khey, _भयान, 
   {{0xda6c01d9,0x7648047e,0x2be007b6,0x68e00153}},	//   وُل_, jhey, _पाका, tuod, 
   {{0x6458db32,0x7648db33,0x6f7000d1,0xbd8800ec}},	//   yiti, dhey, ﺸﯩﻐﺎ_, _منٽن_, 
   {{0x6458db34,0x79880099,0x68e00153,0x37c40116}},	//   xiti, _dzew, ruod, йғум_, 
   {{0xb864db35,0x798804ba,0x3868007b,0x45d4da68}},	//   حانو, _ezew, éara_, бойс, 
   {{0x68e0db36,0x6458db37,0x648401a8,0x76481368}},	//   puod, witi, gðin, ghey, 
   {{0x6458db38,0x68e0db39,0xd9400414,0x61e80ccc}},	//   titi, quod, _дети, _ögli, 
   {{0x629c0173,0x7e681710,0x7648058a,0x64580393}},	//   _siqo, čepi, ahey, uiti, 
   {{0x7648db3a,0x629c0477,0xa5f001c6,0x2000db3b}},	//   bhey, _piqo, _дүйц, veji_, 
   {{0x7648db3c,0x2000db3d,0x629c022e,0x7388010b}},	//   chey, weji_, _qiqo, ырың_, 
   {{0x6458db3e,0x0f38001f,0x6594129d,0x629c0978}},	//   piti, _ያመለከ, _ئجار, _viqo, 
   {{0x9470db3f,0x147001d9,0x44f0db40,0x6458db41}},	//   _ودوا, _واوج, mà_, qiti, 
   {{0x44f0db42,0x629c036b,0x28c45a17,0xa2640395}},	//   là_, _tiqo, रीति, _въпл, 
   {{0x2000db43,0x92b0b249,0x98ac0153,0x00000000}},	//   seji_, _بحوا, lygą_, --, 
   {{0x0dc8db44,0x44f0db45,0x629c4aee,0x20000e8a}},	// [12a10] руси_, nà_, _époq, peji_, 
   {{0x20000286,0x44f0db46,0x00000000,0x00000000}},	//   qeji_, ià_, --, --, 
   {{0x64840ad9,0x6c6801d3,0x7648014f,0x7988012d}},	//   yðin, دللہ_, yhey, _szew, 
   {{0x44f0b51b,0x00000000,0x00000000,0x00000000}},	//   kà_, --, --, --, 
   {{0xa3d44a76,0xe3dc0011,0x7e7c0200,0x764803b2}},	//   िणा_, ব্যব, _iksp, vhey, 
   {{0x44f0db47,0x7bd4db48,0x81ac015b,0xf1b80051}},	//   dà_, _udzu, গরি_, _đơm_, 
   {{0x7648db49,0xadec012c,0x8704007b,0xab600139}},	//   they, ङ्कन_, قبيل, _çüpk, 
   {{0x7c340369,0x752801c4,0x7ae40477,0x5a44d673}},	//   _hozr, txez, muht, _тэга, 
   {{0x648419cf,0x7648db4a,0x44f0db4b,0x7ae40098}},	//   rðin, rhey, gà_, luht, 
   {{0x7648db4c,0xe0dcdb4d,0xd7f8022e,0xd8740345}},	//   shey, drò_, _шуб_, _ئارب, 
   {{0x78a8015b,0xe0dcdb4e,0x7c34db4f,0x76486a37}},	//   _huev, erò_, _mozr, phey, 
   {{0x78a0db50,0x78a8004c,0x66e800ac,0x44f0db51}},	//   _hilv, _kuev, _təkr, bà_, 
   {{0x78a8db52,0x44f0db53,0xe0dc011c,0x78a0db54}},	//   _juev, cà_, grò_, _kilv, 
   {{0x246c0125,0x78a8db55,0x7e7c0100,0x7c340165}},	//   _ስፖርት_, _muev, _aksp, _nozr, 
   {{0x78a0db56,0xc050044e,0xddc856af,0x7ae4007d}},	//   _milv, _ሃገራው, _šiša, juht, 
   {{0xf8a424c5,0xe0dc011c,0x629c8f75,0x60d8db57}},	//   _يک_, brò_, _épop, šuma, 
   {{0x78a8db58,0x7c34db59,0xe0dcdb5a,0xaec40150}},	// [12a20] _nuev, _bozr, crò_, рбұл, 
   {{0xdd8cdb5b,0xeb98db5c,0x3210db5d,0x09d00574}},	//   رول_, гиз_, _hayy_, हण्य, 
   {{0x765804ba,0x44f019f5,0xbbc400f2,0x00000000}},	//   _omwy, zà_, زآلو, --, 
   {{0x78a804cc,0x321000a2,0x00000000,0x00000000}},	//   _buev, _jayy_, --, --, 
   {{0x78a8db5e,0x44f000cf,0x3210db5f,0x61f80254}},	//   _cuev, xà_, _mayy_, õuli, 
   {{0x78a011f9,0x44f0db60,0x78a807de,0x6b98db61}},	//   _cilv, và_, _duev, _útgo, 
   {{0x81ac03d4,0x7e7c01f4,0x00000000,0x00000000}},	//   গৰি_, _yksp, --, --, 
   {{0x44f0db62,0xc8e01533,0x44b400d6,0x2d800af9}},	//   tà_, _निपट, обис, _kyke_, 
   {{0x78a003cd,0xdb0c005b,0x28d02356,0xe96800db}},	//   _filv, ädös, _सिटि, _саал_, 
   {{0x44f0db63,0xe0dcdb64,0x78a0db65,0x2d800212}},	//   rà_, vrò_, _gilv, _myke_, 
   {{0x44f0db66,0x2d809093,0xfbd4009e,0x78a80139}},	//   sà_, _lyke_, স্কত, _zuev, 
   {{0xe0dcdb67,0x78a00cf9,0x44f0db68,0xe298004d}},	//   trò_, _zilv, pà_, _nsưt_, 
   {{0x321000a2,0x9258011c,0x00000000,0x00000000}},	//   _dayy_, саят_, --, --, 
   {{0xe0dc0e06,0x76b000b8,0x78a001a9,0x229800ef}},	//   rrò_, _hāya, _xilv, _mūki_, 
   {{0x7c348864,0x765800a9,0x2db400b4,0x76b00882}},	//   _rozr, _ymwy, _ọkụ_, _kāya, 
   {{0x76b00882,0xe0dc0395,0x3210002e,0x00000000}},	//   _jāya, prò_, _gayy_, --, 
   {{0x7c340038,0x7cd8034c,0x3f800208,0xc0d401c8}},	// [12a30] _pozr, شواز_, _wyhu_, _بيخب, 
   {{0x4d98467b,0x2d800493,0x5ba4db69,0x2bd801d3}},	//   скую_, _dyke_, сраз, لامک_, 
   {{0x25a4db6a,0x996430cb,0x78a8db6b,0x321000e4}},	//   _ogol_, әтел, _suev, _yayy_, 
   {{0x7ae4251b,0x2d800158,0x7e980532,0xdb140793}},	//   ruht, _fyke_, _خنجر_, maxü, 
   {{0x78a0db6c,0x7ae4db6d,0xdb20036b,0x49c80024}},	//   _pilv, suht, _کوزی, слін_, 
   {{0x78a02bcc,0x76b40114,0x7ae4db6e,0x00000000}},	//   _qilv, ољиц, puht, --, 
   {{0x6484041e,0x00000000,0x00000000,0x00000000}},	//   rðil, --, --, --, 
   {{0x76940432,0x78a000b5,0x76b000dc,0xe89000d0}},	//   _ašyr, _wilv, _cāya, ĺňať_, 
   {{0x78a0db6f,0x76b0002b,0x78a80254,0x00000000}},	//   _tilv, _dāya, _uuev, --, 
   {{0x25a4020c,0x2010db70,0x75b40451,0x7d1c0332}},	//   _egol_, _naxi_, _ڀٽائ, _mrss, 
   {{0x91a801ed,0x321000a2,0x6fb800cd,0x00000000}},	//   ینگے_, _payy_, ्रसू, --, 
   {{0x2010011f,0x28c4db71,0x76b000dc,0x7d1c02d0}},	//   _aaxi_, रीवि, _gāya, _orss, 
   {{0x20100429,0xe81c0073,0x999c0432,0x32100205}},	//   _baxi_, पाचा_, _onuō_, _vayy_, 
   {{0x2d80db72,0x00000000,0x00000000,0x00000000}},	//   _ryke_, --, --, --, 
   {{0x2d80db73,0x7d1c0857,0xa0649d5c,0x3210010e}},	//   _syke_, _arss, цара_, _tayy_, 
   {{0xdcf4107c,0x2d800200,0x00000000,0x00000000}},	//   ुबंध_, _pyke_, --, --, 
   {{0x6bd473c5,0x20100194,0x3074013e,0x2bc800d1}},	// [12a40] قتار, _faxi_, _муос, илап_, 
   {{0xc8e000e1,0x53bc448b,0x648403b2,0x6b64117e}},	//   _निबट, _श्मश, yðim, окза, 
   {{0x6da4db74,0x2d800af9,0x7d1c02d0,0xada401c0}},	//   _мина, _wyke_, _erss, _манл, 
   {{0x2d80db75,0x6f1c02d0,0x00000000,0x00000000}},	//   _tyke_, _irpc, --, --, 
   {{0xa968db76,0x201000e8,0x6e2403ac,0x15e0a064}},	//   шида_, _yaxi_, _inkb, _गाजर_, 
   {{0x25a4db77,0x2010005a,0x6f1c00d7,0x76b000dc}},	//   _sgol_, _xaxi_, _krpc, _sāya, 
   {{0x8cb001d9,0xdca01d39,0xa09808a8,0x76b000cd}},	//   _अंडो, _цари, ביסט, _pāya, 
   {{0xb9e40150,0x00000000,0x00000000,0x00000000}},	//   _ىسقى, --, --, --, 
   {{0x69c0db78,0xe4680120,0x5fbc095f,0x76b000dc}},	//   mboe, ишол_, ्रमल, _vāya, 
   {{0x69c01a78,0x68e0db79,0x6f1c0857,0x6abc0fac}},	//   lboe, mrod, _orpc, oppf, 
   {{0x28c4d3a8,0x06b40154,0x6e2402d0,0x76b000b8}},	//   रीरि, _টিকি, _onkb, _tāya, 
   {{0x69c0db7a,0x64a4db7b,0x68e001c8,0x2010db7c}},	//   nboe, _дада, orod, _saxi_, 
   {{0x1a9804ac,0x68e0db7d,0x20100165,0x69c0d41c}},	//   ייטע, nrod, _paxi_, iboe, 
   {{0x6fe40003,0x7d1c0493,0x6e24127b,0x60d856ce}},	//   _སྐྱའ, _rrss, _ankb, šumo, 
   {{0x69c023f3,0x6448db7e,0x7f84036b,0xe7f007af}},	//   kboe, _ilfi, سلرن, _घाना_, 
   {{0x68e04bc0,0x7d1c01c7,0x20100694,0x69c0282c}},	//   krod, _prss, _waxi_, jboe, 
   {{0xa3ac05f9,0x6b9808a7,0x69c00549,0xdfa4007b}},	// [12a50] _कला_, _útgj, dboe, _وحدي, 
   {{0xb5fc0f8b,0x68e0db7f,0x4c94db80,0x69c0db81}},	//   miše, drod, диус, eboe, 
   {{0x68e0db82,0x6fe4031c,0x69c0017a,0x00000000}},	//   erod, _སྐྲའ, fboe, --, 
   {{0x69c02595,0x0a681638,0x68e0db83,0xde4403e6}},	//   gboe, орчи_, frod, _بیرو_, 
   {{0x68e0068f,0xb5fc0552,0x6448020c,0x7d1c06af}},	//   grod, niše, _olfi, _urss, 
   {{0x7d0cdb84,0xd7f8db85,0x00000000,0x00000000}},	//   mwas, руд_, --, --, 
   {{0x3ce80218,0xb658d00a,0xa3ac02ab,0x69c0017a}},	//   luav_, йших_, कशन_, bboe, 
   {{0x6448db86,0xb5fc000a,0xbcf8025c,0xdb140005}},	//   _alfi, kiše, _ཕྱོཊ_, saxó, 
   {{0x7d0cdb87,0x83fc248d,0xe8141af8,0xa3d400dc}},	//   nwas, ziđe, _धोका_, िणं_, 
   {{0xb5fc000a,0x7d0c22d0,0x27fc0175,0x31b400dc}},	//   diše, iwas, _gbtn_, ूर्ध, 
   {{0x7d0cdb88,0x59cc1ab2,0x3ce80457,0x60d8110c}},	//   hwas, _हजार, huav_, šuml, 
   {{0x7d0cdb89,0x6448db8a,0x83fc0989,0xdb0402d3}},	//   kwas, _elfi, viđe, _agjë, 
   {{0x21640364,0x6f1c0cf4,0x3af40fac,0x7d0cdb8b}},	//   зияи_, _srpc, håp_, jwas, 
   {{0x7d0c0c67,0x3af401e6,0xa3d400dc,0x69c00165}},	//   dwas, kåp_, िणः_, zboe, 
   {{0x15400831,0x76b0002b,0x68e0ad7e,0x00000000}},	//   _хеҙм, _māyo, zrod, --, 
   {{0xb5fcdb8c,0x6f1c041a,0xed580fc0,0x3af403cd}},	//   biše, _vrpc, боб_, dåp_, 
   {{0x7d0cc900,0x6f1c0998,0x229800e2,0x69c00156}},	// [12a60] gwas, _wrpc, _cūku_, vboe, 
   {{0x69c0002d,0x76b000b8,0x00000000,0x00000000}},	//   wboe, _nāyo, --, --, 
   {{0x69c04e06,0xd1d01ee0,0x7d0c1f8b,0xa3ac000d}},	//   tboe, _እሳት_, awas, _कलस_, 
   {{0x7d0cdb8d,0x69c0030a,0xdb040200,0x49640166}},	//   bwas, uboe, _zgjë, мнең, 
   {{0x69c0db8e,0x7d0cdb8f,0x00000000,0x00000000}},	//   rboe, cwas, --, --, 
   {{0x69c0368d,0xe8142aa1,0x76b000b8,0xab2823be}},	//   sboe, _धोखा_, _cāyo, _лога_, 
   {{0x69c0db90,0xa098008f,0x27fc010a,0x6b8c022e}},	//   pboe, זיסט, _vbtn_, _uzbg, 
   {{0x247804c7,0xa3ac3c71,0x69c0022e,0x7d240139}},	//   _አባላት_, _कलह_, qboe, _ütsä, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb5fc2ce2,0x2298002d,0x00000000,0x00000000}},	//   više, _lūkt_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7d0c0986,0xb5fc1ebd,0x3ce80218,0x9258005b}},	//   ywas, tiše, yuav_, зают_, 
   {{0x3ce80070,0xe6940124,0x61401870,0x06b40154}},	//   xuav_, _диҧы, رىسە, _টিটি, 
   {{0xb5fcdb91,0x64480a55,0x00000000,0x00000000}},	//   riše, _ulfi, --, --, 
   {{0x543077c2,0x7d0cdb92,0xa2a4000d,0x3eac00df}},	//   _سرور, wwas, _घंट्, ĉeto_, 
   {{0x7d0cdb93,0xb5fc1a48,0xe1fc0548,0x229800ef}},	//   twas, piše, inók_, _pūku_, 
   {{0xdcec005f,0x00000000,0x00000000,0x00000000}},	// [12a70] _izcī, --, --, --, 
   {{0xe0dc02bd,0xdd903419,0xdb0401ed,0xdef80150}},	//   ryòd_, дағы, _ifjú, _лым_, 
   {{0x7044001f,0x3ce80211,0xdef80352,0x6ff8011a}},	//   _ያለባቸ, suav_, _уып_, _והתפ, 
   {{0x61ecdb94,0x6aac01ab,0x229800b0,0x8c48013d}},	//   ngcl, _dubf, _tūku_, _arğı, 
   {{0x7e6cdb95,0x7d0cdb96,0x76b00055,0x00000000}},	//   mnap, qwas, _pāyo, --, 
   {{0x6aac0393,0x7e6c6fab,0x5fbcdaf5,0x00000000}},	//   _fubf, lnap, ्रिल, --, 
   {{0x7e6c1e5d,0x7bc4db97,0xe73400a7,0x4c947d60}},	//   onap, mbhu, дещ_, _чирс, 
   {{0x7e6cdb98,0x05d42e51,0xb5fc01fa,0x35a4db99}},	//   nnap, ىمىڭ, dišc, майг, 
   {{0x5fbc038e,0x97a4db9a,0xa3ac0210,0x7bc401ab}},	//   ्राल, _ерел, _कलश_, obhu, 
   {{0x7e6cdb9b,0x63a80175,0xb4ac0490,0x19540220}},	//   hnap, _cgfn, _कढी_, _дағы_, 
   {{0x7bc4009a,0xa3ac0141,0x8c1c00d9,0x00000000}},	//   ibhu, _कलर_, מוזי, --, 
   {{0xd9fc023e,0x7bc4007b,0x00000000,0x00000000}},	//   ोजित_, hbhu, --, --, 
   {{0x7e6cdb9c,0x00000000,0x00000000,0x00000000}},	//   dnap, --, --, --, 
   {{0xd498d7b1,0xe50400ec,0xc8e001f9,0x2bb009b2}},	//   _уре_, _آڊيو_, _निसट, _जलधा, 
   {{0xa0a0d471,0x7bc400dc,0x00000000,0x00000000}},	//   тард, dbhu, --, --, 
   {{0x7ae405a1,0x6b98db9d,0x7e6cdb9e,0x7bc4db9f}},	//   drht, _útgi, gnap, ebhu, 
   {{0x6aacdba0,0x2bb0142d,0x00000000,0x00000000}},	// [12a80] _subf, _जलदा, --, --, 
   {{0x7e6cdba1,0x00000000,0x00000000,0x00000000}},	//   anap, --, --, --, 
   {{0xaab88e56,0x5f7400d1,0x00000000,0x00000000}},	//   زدار_, _ياپر, --, --, 
   {{0x8c14009e,0x29840137,0xad2400cf,0x317800df}},	//   সাধন_, мылг, _قىجى, ֿאַד, 
   {{0x83fc01fa,0x7bc411ad,0x7c4801d3,0xe3bc00fd}},	//   hiđa, bbhu, ásró, _çıga_, 
   {{0x888455cb,0x6aac01e4,0x3dcc0220,0x00000000}},	//   ریان, _tubf, _ﯗﮔﯩﺘ, --, 
   {{0xe5c4dba2,0x44200205,0xd6d00116,0x00000000}},	//   мспо, _ği_, پتىغ, --, 
   {{0x442028cf,0xab28014b,0x00000000,0x00000000}},	//   _şi_, _лоҳа_, --, --, 
   {{0x6d540007,0x00000000,0x00000000,0x00000000}},	//   nzya, --, --, --, 
   {{0xb5fc01fa,0x03f80640,0x8c480139,0x83340798}},	//   tišc, чној_, _urğı, енох, 
   {{0x7e6cdba3,0xdee80092,0x00000000,0x00000000}},	//   ynap, _ህፃን_, --, --, 
   {{0xfce4001f,0xb5fc1aff,0x46141d0a,0x3f840327}},	//   ምረጥ_, rišc, _سوتر, żluk_, 
   {{0x6600dba4,0x955000f1,0x7e6c3add,0x00000000}},	//   _ibok, _لخوا, vnap, --, 
   {{0xb5fc000a,0xdec80798,0x229800ef,0xeff80092}},	//   miša, жуал_, _pūks_, _ሊታይ_, 
   {{0x9f5c0ab7,0xb5fc0989,0x7e6cdba5,0x1ee401ed}},	//   _ürün_, liša, tnap, ظوری_, 
   {{0x443cdba6,0x7e6c0108,0xdcec00ef,0x5fbc2c2e}},	//   _hov_, unap, _uzcī, ्रहल, 
   {{0x443cdba7,0x6600dba8,0x4ea4035b,0xb5fcdba9}},	// [12a90] _kov_, _mbok, трра, niša, 
   {{0x7e6cdbaa,0x3f140120,0xbf1000fb,0x00000000}},	//   snap, _здос, _йүгә, --, 
   {{0x443cdbab,0xda78016c,0x7bc4dbac,0x6600dbad}},	//   _mov_, ояд_, rbhu, _obok, 
   {{0x6d540161,0x3a28241c,0xdde83c5b,0x7bc4dbae}},	//   bzya, ñap_, _برده_, sbhu, 
   {{0x443c208d,0xf8b01893,0x00000000,0x00000000}},	//   _oov_, اکر_, --, --, 
   {{0xb5fc1ebd,0x6600dbaf,0x443cdbb0,0x1cdc025c}},	//   diša, _abok, _nov_, _ལྷར_, 
   {{0x3948367e,0x98bc0bcc,0x66000083,0x3868110c}},	//   šas_, ırım_, _bbok, đar_, 
   {{0xb5fc000a,0x83fc08ad,0x443c0b4f,0x00000000}},	//   fiša, viđa, _aov_, --, 
   {{0x443cdbb1,0xd7f8dbb2,0xc8f400a7,0x69c0010b}},	//   _bov_, _муж_, _изтъ, _сөхб, 
   {{0x443c0e37,0x66000d81,0xe454a19b,0x7988004c}},	//   _cov_, _ebok, ежь_, _iyew, 
   {{0x443cdbb3,0x13a4dbb4,0x798825a9,0x00000000}},	//   _dov_, بندی_, _hyew, --, 
   {{0x79880a49,0x660001e1,0xb5fc04a7,0x28c40d2e}},	//   _kyew, _gbok, biša, रीकि, 
   {{0x443c0793,0x79880796,0x321c012c,0x756401ed}},	//   _fov_, _jyew, ěty_, _سیدہ_, 
   {{0x443c3c36,0x653800c8,0x7648dbb5,0x854400ee}},	//   _gov_, _מענד, lkey, _шэхе, 
   {{0x79880083,0x7648062c,0x602000c7,0xe1fc0210}},	//   _lyew, okey, ыдра, jnów_, 
   {{0x443c0070,0x798801e1,0x6da40124,0x26d80022}},	//   _zov_, _oyew, еиба, ápoi_, 
   {{0x1d041d1c,0x7988dbb6,0x443cdbb7,0x76480076}},	// [12aa0] нети_, _nyew, _yov_, ikey, 
   {{0x443c0190,0x6c844418,0x2c780428,0x7648dbb8}},	//   _xov_, رلام, düdû_, hkey, 
   {{0x7988dbb9,0xb5fc110c,0x03f403d4,0xaa440798}},	//   _ayew, ziša, _অসমী_, нежл, 
   {{0x2bb011b1,0xe9d00075,0x79881418,0x66e80213}},	//   _जलवा, اغا_, _byew, _təkz, 
   {{0x7e54084c,0x76480067,0x888401b9,0x00000000}},	//   _ртэц, dkey, вғал, --, 
   {{0x3e84006a,0x98a02f33,0xb5fc570b,0x76480014}},	//   _tëtî_, гиче, viša, ekey, 
   {{0x443c0190,0x7988dbba,0xeb984712,0x76480009}},	//   _rov_, _eyew, _хив_, fkey, 
   {{0x443cdbbb,0xa9680022,0x629c06af,0xb5fcdbbc}},	//   _sov_, _еиба_, _épox, tiša, 
   {{0x443cdbbd,0x7988dbbe,0x09cc5a30,0x692401c0}},	//   _pov_, _gyew, ारीय, _ямаа, 
   {{0xb5fc1ebd,0x1cdc0135,0x443c0978,0x7648062c}},	//   riša, _ལྷས_, _qov_, akey, 
   {{0x443cdbbf,0x2c000882,0xb5fc2ba4,0x7648058a}},	//   _vov_, र्यं_, siša, bkey, 
   {{0x7648dbc0,0xb5fcdbc1,0x66000117,0x35c400c7}},	//   ckey, lišn, _ubok, _аацҳ, 
   {{0x81a803f4,0x443cdbc2,0xe2a800ec,0x1ee4dbc3}},	//   খুন_, _tov_, _کاتن_, کوزی_, 
   {{0xb5fcdbc4,0xe1fc033f,0xdfa41fbe,0x6498004e}},	//   unšv, ynów_, ејбо, _этер_, 
   {{0x14180375,0xbdd401f4,0x00000000,0x00000000}},	//   _מוגב, ковщ, --, --, 
   {{0x2ca8022e,0x648403b2,0x3d941422,0x00000000}},	//   _aibd_, rðiu, вибр, --, 
   {{0x2a6400f3,0xb5fc110c,0xc0c4010b,0x00000000}},	// [12ab0] diob_, kišn, _шәни, --, 
   {{0xb5fc0b91,0x7988020b,0x63b869f0,0x9bd000ec}},	//   jišn, _ryew, nctn, اماڻ, 
   {{0xb5fc04b9,0xd0740f13,0x1fbc146b,0x1fa401c6}},	//   dišn, _حديث, ्रीड, _яриг, 
   {{0x2cb0006a,0xe1fc2634,0x00000000,0x00000000}},	//   ândä_, rnów_, --, --, 
   {{0x3dc80399,0x41d800bc,0x9be400d4,0xb5fc0419}},	//   mbaw_, _भजनस, _півк, inšt, 
   {{0x7648dbc5,0x2ca80548,0x9b6800c7,0xdde82e3e}},	//   wkey, _gibd_, _ешба_, _برگه_, 
   {{0x79c8099f,0x7988013f,0x249c00b5,0x7648dbc6}},	//   _يوسف_, _wyew, dmtm_, tkey, 
   {{0xb7b40051,0x00000000,0x00000000,0x00000000}},	//   _bạc, --, --, --, 
   {{0x7648dbc7,0xe4d4dbc8,0xb5fc0fcf,0x798805b8}},	//   rkey, نويت_, bišn, _uyew, 
   {{0x7648dbc9,0xc98401f0,0x42bc00eb,0x00000000}},	//   skey, _суси, _আয়েশ, --, 
   {{0x35f4dbca,0x3a2c01e3,0x764803b2,0x00000000}},	//   _апер, _knep_, pkey, --, 
   {{0x3ce8143a,0xb5fc0306,0x76b0002b,0x648408a5}},	//   krav_, mišo, _nāyi, fðis, 
   {{0x6484008c,0x94000209,0xb5fc0306,0x61f8067c}},	//   gðis, _болҗ, lišo, òula, 
   {{0xd4980cef,0x1cdc025c,0xa504dbcb,0x854800d4}},	//   _эре_, _ལྷེ_, _реша_, _язів_, 
   {{0xe1fcdbcc,0xb5fcdbcd,0x938801d5,0x00000000}},	//   mión_, nišo, _эсда_, --, 
   {{0x3dc81b26,0x22483e39,0xe1fcdbce,0x3124dbcf}},	//   gbaw_, ckck_, lión_, _адиг, 
   {{0x3ce80b1a,0xe7f00490,0xada4dbd0,0x76b0002b}},	// [12ac0] grav_, _घाला_, таал, _dāyi, 
   {{0xe1fcdbd1,0xb5fc27c4,0x3a2c0194,0x32000306}},	//   nión_, kišo, _anep_, lfky_, 
   {{0xb5fc098d,0x00000000,0x00000000,0x00000000}},	//   višn, --, --, --, 
   {{0xb5fc000a,0xe1fc0124,0x2d9400c0,0x00000000}},	//   dišo, hión_, _аргс, --, 
   {{0xc7b816a3,0xae040046,0x2a64dbd2,0xb5fc0010}},	//   _lađe_, _كوگى, riob_, tišn, 
   {{0x3a2c0dd4,0xac0810a7,0x999c00a2,0x2ca40142}},	//   _enep_, _юнга_, _onuņ_, ïodd_, 
   {{0xc7b8098d,0xb5fc0960,0x2c0000dc,0xe1fc0030}},	//   _nađe_, rišn, र्णं_, dión_, 
   {{0x64840ad9,0x6924dbd3,0xb5fc0153,0x96b40114}},	//   yðis, _имба, sišn, њују_, 
   {{0x2c000882,0xb5fc0b3d,0x3eac0115,0x00000000}},	//   र्थं_, pišn, ĉeti_, --, 
   {{0xe1fc937e,0xb5fc1d55,0x80b8012d,0xee0400eb}},	//   gión_, bišo, _एंबे, _লোমশ_, 
   {{0x8880004b,0x2984008e,0x320000d7,0xd6a40137}},	//   _پیژن, _чыңг, ffky_, رگۅم_, 
   {{0xdd1c01e4,0xa5040d31,0x2c0000cd,0x6484032e}},	//   _aŭŝv, _аякл, र्तं_, gðir, 
   {{0xe1fc172e,0xd6540a7c,0x92580395,0x00000000}},	//   bión_, _ביאת_, таят_, --, 
   {{0xe1fc26c8,0x648426b8,0x5450dbd4,0x14d404ac}},	//   ción_, rðis, _квіт, _יודל_, 
   {{0x3dc8039a,0x8f4401d5,0x76b0002b,0x4fd4003b}},	//   tbaw_, ахтд, _pāyi, ржст, 
   {{0x3ce80100,0x5bc81a3e,0x1cdc0135,0x62640a52}},	//   trav_, िर्व, _ལྷུ_, _جاتق, 
   {{0xa5c0033f,0x8cb80736,0xb5fc0419,0x3dc80327}},	// [12ad0] łówk, ندلس_, dišl, rbaw_, 
   {{0x60600075,0xeff0001f,0x3a2cdbd5,0x4d982e70}},	//   _ئۇسل, ቃቸው_, _snep_, ткую_, 
   {{0x629c00a7,0x5ba4419b,0x2c0000dc,0x3ce801a9}},	//   _èpos, траз, र्धं_, srav_, 
   {{0x3ce80fb7,0x60d8262b,0xb5fc0432,0x00000000}},	//   prav_, šumu, gišl, --, 
   {{0x26dcdbd6,0xb814002b,0x37e4dbd7,0x09e40212}},	//   _avto_, _aṭav, голг, роін, 
   {{0x81d8000e,0xe1fcdbd8,0x628c0306,0x2c0000cd}},	//   ালি_, xión_, hlco, र्दं_, 
   {{0x0b88144d,0x7bd4dbd9,0x64840162,0xe1fc3a6c}},	//   _асти_, _iezu, yðir, vión_, 
   {{0x3a2c9e1e,0xc7b82375,0x7bd401c6,0xb6880131}},	//   _unep_, _rađe_, _hezu, رھال_, 
   {{0xe1fcdbda,0x7bd40083,0x6b9859ec,0x81a8009e}},	//   tión_, _kezu, _útgr, খুত_, 
   {{0x7bd4dbdb,0x38b8180f,0x628c0175,0x21c80150}},	//   _jezu, _ièr_, elco, _ﺒﺘﺭﻭ, 
   {{0x7bd4dbdc,0x3244dbdd,0x38b8180f,0x1dd029d9}},	//   _mezu, генг, _hèr_, तरात, 
   {{0xe1fc26c8,0x7bd4dbde,0x32344109,0x00000000}},	//   sión_, _lezu, ухос, --, 
   {{0x648405f7,0x20000327,0x26d80010,0x00000000}},	//   rðir, ffji_, špot_, --, 
   {{0x7bd405b8,0x628c01f5,0x38b80100,0x836401b9}},	//   _nezu, alco, _mèr_, ادیل, 
   {{0xd204ba84,0x38b84c6e,0x7eb401d5,0x00000000}},	//   _күнк, _lèr_, иётч, --, 
   {{0x8c480139,0x9ca400d1,0x00000000,0x00000000}},	//   _obşç, ۇشلۇ, --, --, 
   {{0x7bd4dbdf,0xe0dc02bd,0x2c00000d,0x32d000a2}},	// [12ae0] _bezu, nyòl_, _रउआं_, lšy_, 
   {{0x09cc11bc,0x00000000,0x00000000,0x00000000}},	//   ार्य, --, --, --, 
   {{0x95000135,0x7bd4dbe0,0x8cb0033f,0xeb9801c0}},	//   _མདའི_, _dezu, _अंको, хиж_, 
   {{0x8c14015b,0x76b00055,0x00000000,0x00000000}},	//   সাইন_, _jāyu, --, --, 
   {{0x76b00055,0x00000000,0x00000000,0x00000000}},	//   _māyu, --, --, --, 
   {{0x7bd4dbe1,0x9870dbe2,0x38b80036,0xd9400640}},	//   _gezu, бліц, _dèr_, сељи, 
   {{0xc8e02e1e,0xb86440b7,0x00000000,0x00000000}},	//   _निकट, جانو, --, --, 
   {{0x7bd4209c,0x386400ca,0x38b8007f,0x76b000b8}},	//   _zezu, _emlr_, _fèr_, _nāyu, 
   {{0xdb0c2776,0x29540801,0x38b8068c,0x7bd4dbe3}},	//   ödör, _съвр, _gèr_, _yezu, 
   {{0xb7b40208,0x00000000,0x00000000,0x00000000}},	//   _hạn, --, --, --, 
   {{0x4394dbe4,0x5c340a7c,0xb7440137,0x4274003b}},	//   ранс, ארין_, _پئلو, игос, 
   {{0xe4505263,0xd6cc7c78,0x76b0002b,0x628c003e}},	//   _گفتگ, _رقه_, _cāyu, ulco, 
   {{0x8cb0093c,0xb7b401fb,0xd4b41cb8,0x00000000}},	//   _अंगो, _mạn, _бліц_, --, 
   {{0xb7b40208,0x6aa0036e,0x76b0002b,0x95800354}},	//   _lạn, hmof, _vāyv, _улче, 
   {{0x9e046275,0x0ee81b0a,0xe0dc007f,0x7e640022}},	//   лчал, льти_, myòm_, ахаҵ, 
   {{0x7bd4dbe5,0x00000000,0x00000000,0x00000000}},	//   _sezu, --, --, --, 
   {{0x7bd4dbe6,0x6b8c022e,0x629c00cf,0x51f4516c}},	// [12af0] _pezu, _aybg, _èpoq, _اسىر, 
   {{0xe0dc033b,0xc0e00240,0x00000000,0x00000000}},	//   nyòm_, ሓየለ_, --, --, 
   {{0x7bd43421,0x5478010f,0x588401ec,0x7b14014b}},	//   _vezu, עטבו, қыда, рдех, 
   {{0x7bd4dbe7,0x38b8dbe8,0xb5fc00d0,0xb7b40208}},	//   _wezu, _pèr_, tišm, _cạn, 
   {{0xe0dcdbe9,0x7bd4dbea,0xb7b4004d,0x8bfc00fe}},	//   nsò_, _tezu, _dạn, ীয়ন_, 
   {{0x38b80100,0x3eac01e4,0x00000000,0x00000000}},	//   _vèr_, ĉetu_, --, --, 
   {{0x38b8020c,0x39b8084c,0xe0dc02e2,0xb8c4129d}},	//   _wèr_, _албэ_, dyòm_, ازچى, 
   {{0x8aa4bbdb,0xb5fc0006,0x38b8007f,0x6704000d}},	//   _груд, mišk, _tèr_, _शहरक_, 
   {{0xb5fcdbeb,0x2c000882,0xc4c4dbec,0x26d80aa6}},	//   lišk, र्वं_, یتیو, ápor_, 
   {{0x58843419,0x73040334,0x76b000cd,0x00000000}},	//   _сыба, апоз, _sāyu, --, 
   {{0xb5fcdbeb,0x07081371,0xc08401f2,0x76b000b8}},	//   nišk, _ميلي_, ịọn_, _pāyu, 
   {{0xd68006ba,0x8c440356,0xb9dc0023,0x00000000}},	//   ﺭﻟﻪﺭ_, ăşit, _ኣን_, --, 
   {{0x76b00882,0xb5fc09a8,0xd5a0dbed,0x2a38010f}},	//   _vāyu, hišk, _الشی, דערמ, 
   {{0xb5fc02d5,0x00000000,0x00000000,0x00000000}},	//   kišk, --, --, --, 
   {{0xb5fcdbee,0x9eb450e5,0xec1401d5,0x00000000}},	//   jišk, иштә, یورد, --, 
   {{0xb5fcdbef,0xb2080022,0xcd500092,0x00000000}},	//   dišk, _реиз_, _የመክፈ, --, 
   {{0xafe4dbf0,0xc7b807f5,0x2d94955d,0x00000000}},	// [12b00] _копл, _lađa_, рөнө_, --, 
   {{0x6f641c03,0x0ca0001f,0xb5fc276e,0xab2801f4}},	//   _ввоз, _ቁጥሮች_, fišk, коза_, 
   {{0xe9d89ada,0xb5fc02d5,0xc7b80cf4,0xe9e40419}},	//   вке_, gišk, _nađa_, _ľúbi_, 
   {{0xa924736a,0x6284a068,0x6aa00a14,0xe94401c6}},	//   идел, čkog, umof, ихло, 
   {{0xed3401c0,0xb5fc00c0,0x00000000,0x00000000}},	//   _тэнэ, aišk, --, --, 
   {{0x5d6000c6,0x6aa0dbf1,0xb5fcdbf2,0xaac402f2}},	//   _єяяσ, smof, bišk, _نترن, 
   {{0xd9ac0490,0xb5fc0024,0x00000000,0x00000000}},	//   टशॉट, cišk, --, --, 
   {{0xadf40d0d,0x270c03b9,0xe9d800d8,0x634803e3}},	//   इलिन_, _ləng_, _јка_, ləng, 
   {{0xe8f84db0,0x953402e8,0x00000000,0x00000000}},	//   _шла_, изът_, --, --, 
   {{0x66e4dbf3,0x2c0403d4,0x244401a9,0x00000000}},	//   _вожа, ৰাকৈ_, рхиг, --, 
   {{0xc7b80e3c,0xe0dc0100,0x00000000,0x00000000}},	//   _gađa_, ryòm_, --, --, 
   {{0x4394dbf4,0x2c040b72,0xe0dc0100,0x24e80798}},	//   _қайс, स्तू_, syòm_, _амди_, 
   {{0xdfd806bb,0xb5fc0153,0x50f40815,0xe5a4030d}},	//   къв_, zišk, озят, _тиди, 
   {{0xd48c02bf,0xe0dc86ed,0x00000000,0x00000000}},	//   _єр_, rsò_, --, --, 
   {{0xe0dcdbf5,0x8cb000af,0x8e3801a9,0x634803b9}},	//   ssò_, _अंजो, turа_, dəng, 
   {{0xb5fc02d5,0xe0dc02e2,0x2164022e,0x9754011a}},	//   višk, nyòk_, _втог, בילו_, 
   {{0x835400f1,0x634803e3,0xf27401e2,0x00000000}},	// [12b10] _خپګا, fəng, _دخوښ, --, 
   {{0xa800dbf6,0xb5fc02d5,0x270c03be,0x64583367}},	//   çıla, tišk, _kənd_, nhti, 
   {{0x0ca8dbf7,0x9ba000d1,0x99d40035,0x0b880114}},	//   ртти_, زەرى, لتشا, асци_, 
   {{0xb5fcdbeb,0xc7b808ad,0x2ec018ce,0x29c81682}},	//   rišk, _rađa_, _хөрм, ṱani_, 
   {{0x63480cc1,0x64580050,0xb5fc02d5,0xe0dc007f}},	//   lənd, khti, sišk, dyòk_, 
   {{0x8934a822,0xb5fcdbf8,0xabb40724,0x7e6cdbf9}},	//   تعما, miši, _гарә, liap, 
   {{0x3668dbfa,0x64580023,0xdb20036b,0x63480213}},	//   лако_, dhti, _بوزی, nənd, 
   {{0x7e6cdbfb,0x7584001f,0xceb40375,0xb8ec0011}},	//   niap, _አሳልፎ_, חיק_, _শট_, 
   {{0xb5fc1ebd,0xaa840014,0x69f001c0,0x6458003e}},	//   niši, _اۆنم_, _хүчт, fhti, 
   {{0x7e6cdbfc,0x6458dbfd,0x63480213,0x270c03e3}},	//   hiap, ghti, kənd, _bənd_, 
   {{0x7e6cdbfe,0xe1fc00dd,0x270c00ac,0xfbd0009e}},	//   kiap, ciók_, _rəng_, াণপত, 
   {{0xc048dbff,0xb5fc1ebd,0x629c01d5,0x7e6c009f}},	//   _אז_, kiši, _chqo, jiap, 
   {{0x7e6cdc00,0xc298084c,0x64580332,0x00000000}},	//   diap, ртэц_, bhti, --, 
   {{0x6458dc01,0x941c013f,0xb5fcdc02,0x270c06be}},	//   chti, _ɛsɛe_, diši, _fənd_, 
   {{0x7e6c0421,0x63480213,0x798c025c,0x00000000}},	//   fiap, gənd, żawh, --, 
   {{0x7e6cdc03,0x00000000,0x00000000,0x00000000}},	//   giap, --, --, --, 
   {{0xb5fc00c0,0x0c6801ec,0x00000000,0x00000000}},	// [12b20] giši, азақ_, --, --, 
   {{0xb304038f,0x7c6404a9,0xb3d4015b,0x598402d3}},	//   _མྱོང_, يالل, _দাঁড়, _ንሓፋሽ_, 
   {{0xdcac3f7b,0xeaf804fb,0xbc180220,0x1d0400d1}},	//   رىم_, طرات_, шіті_, _қери_, 
   {{0xb5fcdc04,0x7e6cdc05,0x6f1c03ac,0x49c86b62}},	//   mišw, ciap, _ispc, рһан_, 
   {{0x645802f6,0xfbd00c50,0x95fc0154,0x6f9400d1}},	//   yhti, ستە_, ্যাম_, ﻘﯩﻐﺎ_, 
   {{0x98700024,0x13ac0154,0x00000000,0x00000000}},	//   пліц, চুয়, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x849402d3,0x2bfc0490,0x4f2c0092,0x00000000}},	//   _ምብራቕ_, _लाडू_, _ሳያደር, --, 
   {{0xb5fc27c4,0x64580200,0xa7f8dc06,0x00000000}},	//   hišw, thti, _معاذ_, --, 
   {{0xb5fc000a,0x63480cc1,0xe7f016f0,0x14b40597}},	//   kišw, yənd, _घाटा_, حديث_, 
   {{0x2450006a,0x6f1c0042,0x270c03b9,0xb5fc00d7}},	//   _wâmo_, _nspc, _qənd_, ziši, 
   {{0x6458dc07,0xb5fc000a,0x2fd80175,0x78c403b2}},	//   shti, dišw, _aepg_, _útvø, 
   {{0x68e0dc08,0x6594dc09,0x6abc0117,0x6f1c02d0}},	//   nsod, _اجار, hqpf, _aspc, 
   {{0x634803be,0x644c01b8,0xb5fcdc0a,0x9580010a}},	//   tənd, öbid, viši, _элче, 
   {{0x7e6cdc0b,0x6fd82a05,0x69c00369,0xde94007b}},	//   tiap, _बजरं, kcoe, مجرب, 
   {{0xb5fc000a,0x68e0dc0c,0xdce86b07,0x634800ac}},	//   tiši, ksod, žičk, rənd, 
   {{0x7e6cdc0d,0x68e00219,0x0dc8dc0e,0x69c00142}},	// [12b30] riap, jsod, суси_, dcoe, 
   {{0x7e6c0020,0xb5fc07f5,0x29c80084,0x68e06448}},	//   siap, riši, ṱali_, dsod, 
   {{0xb5fc009b,0x68e00042,0x9f5c0241,0x00000000}},	//   mišv, esod, _àràn_, --, 
   {{0xb5fc0b3d,0x27fc107d,0x00000000,0x00000000}},	//   piši, _actn_, --, --, 
   {{0xab60864e,0x7e7c01a4,0x127c010f,0x00000000}},	//   _çünk, _ijsp, נאדע, --, 
   {{0x3b880166,0xb5fc0064,0x00000000,0x00000000}},	//   _көеп_, nišv, --, --, 
   {{0x0ddc001f,0xcb440117,0x00000000,0x00000000}},	//   _ሕንፃ_, _ехти, --, --, 
   {{0x248c05da,0x00000000,0x00000000,0x00000000}},	//   _akfm_, --, --, --, 
   {{0x68e001d3,0xe1fc0827,0x00000000,0x00000000}},	//   csod, liów_, --, --, 
   {{0x1cdc0d46,0x00000000,0x00000000,0x00000000}},	//   _ལྷབ_, --, --, --, 
   {{0xe1fc012d,0x7c24952b,0x00000000,0x00000000}},	//   niów_, idhr, --, --, 
   {{0x6f1c0042,0x80b40073,0x7c2401e7,0x00000000}},	//   _rspc, ंदूं, hdhr, --, 
   {{0x73e4036b,0xd548132f,0x04c8009f,0x00000000}},	//   _долз, _حجام_, _هوني_, --, 
   {{0xb5fc000a,0xc48402dd,0x00000000,0x00000000}},	//   tišw, _елік, --, --, 
   {{0x7528dc0f,0x324400ee,0x638000ee,0x68e00219}},	//   lvez, _мекг, _огша, zsod, 
   {{0xb5fc1ebd,0xe1fc0034,0x75280165,0x68e00042}},	//   rišw, diów_, ovez, ysod, 
   {{0x75280dd4,0xdd8cdc10,0x7e7c0076,0x76580368}},	// [12b40] nvez, نوف_, _djsp, _mlwy, 
   {{0x76580cfd,0xa11020d3,0x75280810,0xeb98410a}},	//   _llwy, _کویت, ivez, аиз_, 
   {{0x3bd41de1,0xb5fcdc11,0x76580368,0x6e440798}},	//   яютс, lišu, _olwy, _денз, 
   {{0x634803be,0x68e0dc12,0x7c2400a3,0x7528089e}},	//   lənc, tsod, adhr, kvez, 
   {{0x69c0172e,0x6924dc13,0xb5fc0064,0x27fc0051}},	//   rcoe, юмда, nišu, _pctn_, 
   {{0xab28c7b7,0x7528dc14,0x7658dc15,0x6d5800e4}},	//   _кога_, dvez, _alwy, _ętah, 
   {{0x68e0dc16,0x765800a9,0x66e80490,0x7528030a}},	//   ssod, _blwy, _टिळक_, evez, 
   {{0x76580368,0xb5fcdc17,0xb14c02d3,0x24e401c6}},	//   _clwy, kišu, ምርድዳ, оцог, 
   {{0xe3bc0205,0x752800e5,0x634806be,0x281401e2}},	//   _çıka_, gvez, kənc, _وورس, 
   {{0x290400ec,0x76580042,0x00000000,0x00000000}},	//   mtoa_, _elwy, --, --, 
   {{0x752803bd,0x76580cfd,0x425400c6,0x2904dc18}},	//   avez, _flwy, كندر, ltoa_, 
   {{0x2904dc19,0x7528dc1a,0x765803cb,0xa508010a}},	//   otoa_, bvez, _glwy, _веда_, 
   {{0x2904dc1b,0x389c0432,0x6728365a,0x85040cd6}},	//   ntoa_, _aňry_, lvfj, _روغن, 
   {{0x270c03be,0x95940a1e,0x63480213,0x2904dc1c}},	//   _gənc_, _וכדו_, gənc, itoa_, 
   {{0x2904023a,0xf2340133,0xfbc800bc,0x00000000}},	//   htoa_, زبێک, ाँसम, --, 
   {{0xb304031c,0x290401c4,0xafc00131,0x00000000}},	//   _མྱིང_, ktoa_, _җәрй, --, 
   {{0xb5fc2375,0xe0b400cd,0x00000000,0x00000000}},	// [12b50] mišt, bdāḥ_, --, --, 
   {{0xb5fc04b9,0x3f800211,0x7c240481,0x999c00a2}},	//   lišt, _txhu_, udhr, _anuş_, 
   {{0x7c24dc1d,0x2904005b,0x7f9401c6,0x00000000}},	//   rdhr, etoa_, _ханх, --, 
   {{0xe1fc033f,0x78a00327,0x2904007f,0x752801d3}},	//   riów_, _shlv, ftoa_, yvez, 
   {{0x3ea8dc1e,0x88c40b6c,0xd918bdb2,0xc7b80051}},	//   mmat_, وتول, рье_, _bgđ_, 
   {{0x3ea829a8,0xb5fc151c,0x7d180ac4,0x00000000}},	//   lmat_, hišt, ğası, --, 
   {{0x7bc4dc1f,0x2904dc20,0xc62402f5,0x7d18b8f1}},	//   mchu, atoa_, ভানা_, şası, 
   {{0xb5fc0b9d,0x7bc4dc21,0x7ae4dc22,0x3ea8dc23}},	//   jišt, lchu, msht, nmat_, 
   {{0x1c08038e,0x999c0069,0x7bc4dc24,0x3ea8dc25}},	//   स्थल_, _kauō_, ochu, imat_, 
   {{0x7528dc26,0x3ea8dc27,0x7bc4dc28,0xb7c400c7}},	//   rvez, hmat_, nchu, _храқ, 
   {{0x7ae4dc29,0x3ea88a67,0x7528dc2a,0x7bc4dc2b}},	//   nsht, kmat_, svez, ichu, 
   {{0x7bc40842,0xb5fc0309,0x7ae41368,0x3ea800e8}},	//   hchu, tišu, isht, jmat_, 
   {{0x3ea8001f,0xc0ec0125,0x7bc403f0,0x4ee80154}},	//   dmat_, _ሆቴል_, kchu, _পহেল, 
   {{0x7bc40978,0x81d804c5,0x05741e4a,0xb5fcdc2c}},	//   jchu, ালগ_, _تامد, rišu, 
   {{0xa064dc2d,0x7bc4016d,0x634800ac,0x2904dc2e}},	//   чара_, dchu, rənc, ztoa_, 
   {{0x3ea8dc2f,0xb5fc0e3c,0xa80400e4,0x7bc4dc30}},	//   gmat_, cišt, _kañý, echu, 
   {{0x6bd40150,0xb5fc0784,0xc5e80eac,0x2904005a}},	// [12b60] كتار, qišu, ক্কা_, xtoa_, 
   {{0x3ea8dc31,0x7bc4047e,0x7ae46521,0x602c0064}},	//   amat_, gchu, fsht, gėmė, 
   {{0xc0a8c9a4,0x2c0000dc,0x7ae40200,0x00000000}},	//   _بايل_, र्गं_, gsht, --, 
   {{0x7bc40a55,0x290402f6,0xfbd001d3,0x2bfc0073}},	//   achu, ttoa_, ٹتے_, _लावू_, 
   {{0x7ae40363,0x7bc4016d,0x2904d851,0xa9a46d5f}},	//   asht, bchu, utoa_, чидд, 
   {{0x6e24113c,0x7bc4dc32,0xb5fc1b24,0x2904dc33}},	//   _hakb, cchu, zišt, rtoa_, 
   {{0x2904dc34,0xdca03272,0x270c030a,0x7ae46a7d}},	//   stoa_, _чари, _bəna_, csht, 
   {{0x6e240034,0x67280158,0x99940014,0xe1fc01e7}},	//   _jakb, rvfj, _کھٔر_, mhóg_, 
   {{0x6e24dc35,0xb5fc506e,0xc7b80208,0xa7b400ea}},	//   _makb, višt, _tgđ_, _есеј, 
   {{0x3ea8dc36,0x6e24dc37,0x00000000,0x00000000}},	//   zmat_, _lakb, --, --, 
   {{0x3ea8dc38,0xb5fc83b2,0x270c06be,0x00000000}},	//   ymat_, tišt, _fəna_, --, 
   {{0x3ea85950,0x7bc405d5,0x18540150,0x5340074d}},	//   xmat_, zchu, _ورەڭ, ххьа, 
   {{0xb5fc04b9,0x6600019f,0x7bc4bfbe,0x3ea800d7}},	//   rišt, _icok, ychu, vmat_, 
   {{0x042009bd,0x3ea803a2,0xb5fc107d,0xa2c81078}},	//   বাহী_, wmat_, sišt, _луиз_, 
   {{0x3ea82b92,0xb5fc0316,0x644801e2,0x8f3406a6}},	//   tmat_, pišt, _iofi, нерц, 
   {{0x6448dc39,0xccf4013b,0xdb0403b2,0x3ea8dc3a}},	//   _hofi, frɛ_, _igjø, umat_, 
   {{0x7bc4dc3b,0x6448dc3c,0x628cdc3d,0x6e24dc3e}},	// [12b70] tchu, _kofi, moco, _dakb, 
   {{0x5ba4dc3f,0x6448dc40,0x7bc4dc41,0x6e240857}},	//   през, _jofi, uchu, _eakb, 
   {{0x7bc4dc42,0x6448dc43,0x3ea88d84,0x660000f3}},	//   rchu, _mofi, pmat_, _ocok, 
   {{0x7bc4dc44,0xe1fcdc45,0x6448dc46,0x7ae4dc47}},	//   schu, ngó_, _lofi, rsht, 
   {{0x08c40046,0x6448dc48,0x7bc4016d,0x270c03b9}},	//   ебін, _oofi, pchu, _rəna_, 
   {{0x6448dc49,0x628cdc4a,0x7ae402d3,0xd7f884dc}},	//   _nofi, hoco, psht, суд_, 
   {{0x628cdc4b,0xe1fcdc4c,0x55c06518,0x00000000}},	//   koco, niós_, найғ, --, 
   {{0x6448096b,0x65a001f2,0xab600046,0x39148404}},	//   _aofi, _ọhan, _جۇمى, _омбр, 
   {{0x644829ef,0x628c005c,0x999c0010,0x80b827a6}},	//   _bofi, doco, _fouš_, _एंगे, 
   {{0x6448dc4d,0x66000117,0xb9dc069d,0xe4680254}},	//   _cofi, _ecok, _ብሉ_, veöö_, 
   {{0x6448092e,0x628cdc4e,0xd46c02d3,0x62840427}},	//   _dofi, foco, _ብወገኑ_, čkon, 
   {{0x660000d2,0x6448d8e7,0x628cdc4f,0x33740116}},	//   _gcok, _eofi, goco, згүр, 
   {{0x6448dc50,0x6e24dc51,0x2bfc49fc,0x2164013e}},	//   _fofi, _rakb, _लालू_, дияи_, 
   {{0x6448dc52,0x6e24dc53,0xe1fc004e,0x867800db}},	//   _gofi, _sakb, fiós_, _мөөр_, 
   {{0xe1fcdc54,0xcec400bc,0x00000000,0x00000000}},	//   giós_, daří_, --, --, 
   {{0x64482171,0x628cdc55,0xccf40085,0xa28035cf}},	//   _zofi, coco, trɛ_, _لیپو, 
   {{0x6e242595,0x3cf4068f,0x6448dc56,0x2fb8084c}},	// [12b80] _vakb, एंगे_, _yofi, _мынэ_, 
   {{0x6448022e,0x920800ef,0xe1fc00ae,0x00000000}},	//   _xofi, _drāž, thóg_, --, 
   {{0x6e24dc57,0xe1fcdc58,0xa05400c8,0xccf40134}},	//   _takb, ciós_, _חסיד_, srɛ_, 
   {{0x49a46f78,0xe1fc068f,0x08c8b071,0x6cc424ae}},	//   нылғ, chód_, зғап_, _ойма, 
   {{0x7fe856ee,0xa88882e2,0x00000000,0x00000000}},	//   _ظریف_, ойда_, --, --, 
   {{0x628c014b,0xd9400063,0xe1fc00e5,0x00000000}},	//   zoco, тељи, zgó_, --, 
   {{0x6448dc59,0x628cdc5a,0x00000000,0x00000000}},	//   _rofi, yoco, --, --, 
   {{0x270c03e3,0xf6f40116,0x00000000,0x00000000}},	//   _fənn_, رزىگ, --, --, 
   {{0x628cdc5b,0x6448dc5c,0xc7b801fa,0xa8040209}},	//   voco, _pofi, _lađi_, _озал, 
   {{0x6b800209,0x98a000c7,0x644801a9,0x628c0210}},	//   şogu, _аиуе, _qofi, woco, 
   {{0x628cdc5d,0xd7000124,0x3868002d,0x270c03e3}},	//   toco, _азхи, ëare_, _zənn_, 
   {{0xc7b8dc5e,0x6600090c,0x92580b32,0x6448dc5f}},	//   _nađi_, _ucok, дают_, _wofi, 
   {{0x6448dc60,0xe6940124,0xe1fcdc61,0xa444030d}},	//   _tofi, _еиҧы, rgó_, _ондд, 
   {{0x628cdc62,0xc3300050,0x00000000,0x00000000}},	//   soco, _مٕت_, --, --, 
   {{0x628cdc63,0x56800014,0x3f847225,0x62680118}},	//   poco, _سۯیہ, çlu_, dřov, 
   {{0xe1fc9972,0xeb380092,0x3f840003,0x00000000}},	//   riós_, _የሚጫወ, ħlu_, --, 
   {{0xa0a4dc64,0xce940801,0xe1fcdc65,0x8d7400d1}},	// [12b90] _ошол, татъ, biór_, ناكا, 
   {{0x4cc800bd,0x6d58003a,0x82340214,0x9f400200}},	//   _লিখু, _ętat, _آرژا, najë_, 
   {{0xe908025c,0xb5fc02d1,0x63480213,0x7b8400d1}},	//   _གདུབ_, kišp, zənn, رائە, 
   {{0x9e2000db,0x1da40210,0x00000000,0x00000000}},	//   _جۉرو, _खरपत, --, --, 
   {{0x3eb8dc66,0x3dc80007,0x69a801ad,0x00000000}},	//   _iist_, mcaw_, जेली, --, 
   {{0x3ce8dc67,0x9f400200,0x00000000,0x00000000}},	//   msav_, jajë_, --, --, 
   {{0x3eb8dc68,0x2bac03f8,0x9f400200,0xb9240092}},	//   _kist_, झेदा, dajë_, _ታክሲዎ, 
   {{0x3eb8dc69,0x644c0254,0x8aa40150,0x00000000}},	//   _jist_, öbin, _аруд, --, 
   {{0x245000d2,0x62840010,0x49900244,0x00000000}},	//   _lâmu_, čkol, _پیور, --, 
   {{0x3eb8dc6a,0x6b880036,0xb5fc0309,0x00000000}},	//   _list_, _ëmgë, rišq, --, 
   {{0x3eb81c06,0x3dc80007,0xe3e4036b,0xb5fc0784}},	//   _oist_, kcaw_, رکون_, sišq, 
   {{0xe72c03e6,0xb5fc0784,0x3eb8cc86,0x3ce801bf}},	//   _دڵه_, pišq, _nist_, ksav_, 
   {{0x634800ac,0x9f40036e,0xd5840133,0x00000000}},	//   lənl, bajë_, _زێده_, --, 
   {{0x3eb801ab,0xf6ec031c,0x74a801af,0x00000000}},	//   _aist_, _ལྷོང, _эсең_, --, 
   {{0x3eb8dc6b,0xa0a0ca77,0xb8e0031c,0x86880023}},	//   _bist_, уард, _གཤ_, _ዝህብዎ_, 
   {{0x3eb8dc6c,0x3dc8009a,0xcd6c001f,0x626400b5}},	//   _cist_, gcaw_, _ለመክፈ, をope, 
   {{0x3eb8dc6d,0x6268012c,0x63a4033f,0xfc600092}},	// [12ba0] _dist_, třov, ękne, _መከፋፈ, 
   {{0x3eb8dc6e,0x634803e3,0x00000000,0x00000000}},	//   _eist_, kənl, --, --, 
   {{0xaab8dc6f,0x8eb400c7,0x3eb83af1,0x205400df}},	//   سدار_, _аӡах, _fist_, _ניטל_, 
   {{0x3eb80c86,0x3200dc70,0x63480213,0x9b9001d5}},	//   _gist_, ngky_, dənl, دلمت, 
   {{0x626800bc,0x69a001e0,0xaa040248,0x00000000}},	//   přov, уһаҡ, _ásíà_, --, 
   {{0x3eb81529,0x1864188b,0x6d549108,0xca980150}},	//   _zist_, начи_, myya, _ﺘﻌﻬﺩ_, 
   {{0xb5fc0784,0x9f400783,0xcb940214,0x6d5402d0}},	//   tišp, vajë_, _شهرک, lyya, 
   {{0xcd50001f,0x18a00032,0x3eb80175,0x00000000}},	//   _የመንፈ, _ҡатм, _xist_, --, 
   {{0x06e02017,0xc82400c7,0xb5fc03f0,0x04880139}},	//   _गौरव_, _изақ, rišp, мәки_, 
   {{0x6d54dc71,0xdbdc01a8,0x62842230,0x78f000db}},	//   iyya, níði, čkom, _түшу, 
   {{0xb5fc0309,0x1da4000d,0x9f40036e,0x00000000}},	//   pišp, _खरभत, rajë_, --, 
   {{0xd3a0dc72,0x634800ac,0xb5fc0784,0x3ce80076}},	//   ырып, səno, qišp, ysav_, 
   {{0x9550dc73,0x00000000,0x00000000,0x00000000}},	//   _مخوا, --, --, --, 
   {{0x3eb8dc74,0x634803be,0x94000198,0xd36c0451}},	//   _sist_, lənm, ƙƙaƙ, _ڏهه_, 
   {{0xe810dc75,0x00000000,0x00000000,0x00000000}},	//   ढ्या_, --, --, --, 
   {{0x6458dc76,0x442c01d3,0x4e7801f3,0x1c00000d}},	//   lkti, ldd_, _አብርሃ_, _लाहल_, 
   {{0x3eb800ed,0x442c00a9,0x67000490,0x4f5801ed}},	// [12bb0] _vist_, odd_, रंडक_, وجہد_, 
   {{0x6458dc77,0x3eb851ea,0x634803be,0x3ce84fdf}},	//   nkti, _wist_, yənl, rsav_, 
   {{0x442cdc78,0x6d54022f,0x3eb8dc79,0x634803e3}},	//   idd_, ayya, _tist_, kənm, 
   {{0x7d080311,0x443c01f5,0x442c037e,0x3eb8dc7a}},	//   _ţesu, _lnv_, hdd_, _uist_, 
   {{0x26dcdc7b,0x88c802bf,0x6458dc7c,0x98b00010}},	//   _awto_, елів_, kkti, žečo_, 
   {{0x20000438,0xc7b801fa,0x443c01fa,0x64580d27}},	//   ngji_, _lađu_, _nnv_, jkti, 
   {{0x7d0cdc7d,0x00000000,0x00000000,0x00000000}},	//   ltas, --, --, --, 
   {{0x443c07e4,0x442c0f7b,0x99d4dc7e,0xc7b80552}},	//   _anv_, edd_, _سترا, _nađu_, 
   {{0x443ca08d,0x7d0c64fe,0x442c07a8,0x05680261}},	//   _bnv_, ntas, fdd_, ејќи_, 
   {{0xc62402a6,0x443c01f5,0x9f40007f,0xb2d801ec}},	//   ভাষা_, _cnv_, pajè_, _ﺃﻨﻭﺍ, 
   {{0x7d0cdc7f,0x06f4314e,0x9f400789,0xc864004e}},	//   htas, _مسنج, bajé_, _стти, 
   {{0x6458dc80,0x7d0cdc81,0x443cdc82,0x442c00a9}},	//   akti, ktas, _env_, add_, 
   {{0x7d0cdc83,0x443cdc84,0x3f8c0356,0x442c0139}},	//   jtas, _fnv_, şeul_, bdd_, 
   {{0x7d0c019b,0x05743463,0x443c0798,0x74142c04}},	//   dtas, _حامد, _gnv_, _شوعا, 
   {{0xdee01789,0x7d0cdc85,0xd2040116,0x7648062c}},	//   иори, etas, _йүнк, ojey, 
   {{0x7d0cdc86,0xccf4013b,0x76480363,0x76b00055}},	//   ftas, hyɛe_, njey, _pāyy, 
   {{0x7d0cdc87,0xdbdc09cc,0xccf4013f,0xace801d9}},	// [12bc0] gtas, tíði, kyɛe_, برزل_, 
   {{0x76480076,0xaec4022e,0x00000000,0x00000000}},	//   hjey, _ибол, --, --, 
   {{0xdbdc05f7,0x798802d0,0x63480213,0x7d080356}},	//   ríði, _axew, yənm, _ţest, 
   {{0xdbdc148b,0xed58022e,0x6da400ae,0x00000000}},	//   síði, _жом_, _لمجم, --, 
   {{0x442c1649,0x7d0cdc88,0x64583bb7,0x629c04fe}},	//   ydd_, ctas, ykti, _ūpok, 
   {{0xe7740598,0x98a021b4,0x00000000,0x00000000}},	//   калә_, аиче, --, --, 
   {{0x6ab4035b,0xb8c81a04,0xb864dc89,0x798803ac}},	//   _асах, _गी_, دانو, _exew, 
   {{0x443cdc8a,0x442c0cfd,0x6f0c01ab,0x00000000}},	//   _snv_, wdd_, itbc, --, 
   {{0x443cdc8b,0x634800ac,0x01e003d4,0x9f40dc8c}},	//   _pnv_, rənm, _ভালদ, rajé_, 
   {{0x6458dc8d,0x82d84130,0xd4640114,0x00000000}},	//   ukti, ндос_, киње_, --, 
   {{0x442c0f7b,0x7d0cdc8e,0x38680b45,0xdbdc0241}},	//   rdd_, ztas, ɗar_, _kíòu, 
   {{0x7d0cdc8f,0x6458dc90,0x2ba80034,0x46840055}},	//   ytas, skti, _करना, _aṭṭā, 
   {{0x7d0cdc91,0x443c0724,0x675401d3,0xa1844720}},	//   xtas, _tnv_, _سیکس_, тынл, 
   {{0xa2c8bc82,0x2a64022e,0x7d0c3bb4,0x63480213}},	//   _संप्, hhob_, vtas, nənk, 
   {{0x200002d3,0x9e04bd8c,0x03540166,0xd3a0011c}},	//   rgji_, кчал, _сүнә_, _кръп, 
   {{0x7d0cdc92,0xf02c02d3,0x249c0036,0x3d940108}},	//   ttas, _ብዝርዝ, lltm_, гибр, 
   {{0x16dc1715,0x7d0cdc93,0x0dc83849,0x47c800eb}},	// [12bd0] _नब्ब, utas, туси_, _রজনী, 
   {{0xbbdc03f3,0x00000000,0x00000000,0x00000000}},	//   यरेक, --, --, --, 
   {{0x8bc40107,0xdf44dc94,0xfb880022,0x634803b9}},	//   рсуд, _рэпп, храқ_, dənk, 
   {{0xa2c81788,0x2a64dc95,0x00000000,0x00000000}},	//   _संन्, ghob_, --, --, 
   {{0x7d0cbcc4,0x2024001f,0x38a800e4,0x00000000}},	//   qtas, _ትምሕር, húre_, --, 
   {{0xdb20dc96,0x38a800c7,0x00000000,0x00000000}},	//   _پوری, kúre_, --, --, 
   {{0x38a800e4,0x00000000,0x00000000,0x00000000}},	//   júre_, --, --, --, 
   {{0xf6240c56,0x58000131,0x68f40024,0x59b0728c}},	//   удио, _چۈشك, šyda, _көлс, 
   {{0xe614dc97,0x76480076,0x00000000,0x00000000}},	//   уды_, rjey, --, --, 
   {{0x3a2c49db,0xc984dc98,0xbbe007f7,0x00000000}},	//   _haep_, _туси, _फ़ोक, --, 
   {{0x3a2c0139,0x25080133,0xbbe0012d,0x00000000}},	//   _kaep_, وریی_, _फ़ैक, --, 
   {{0x940002a8,0x649c01a9,0x00000000,0x00000000}},	//   ƙƙoƙ, 惣ich, --, --, 
   {{0x3a2c05da,0x947003e6,0xe0400116,0xb5fc00d7}},	//   _maep_, _نگدا, әнси, lhšo, 
   {{0x3a2c0007,0x00000000,0x00000000,0x00000000}},	//   _laep_, --, --, --, 
   {{0xb8e40135,0xe1fc0332,0xac840022,0x00000000}},	//   _ཉང_, mhón_, ҳгал, --, 
   {{0x2ba800af,0x31240139,0x270c06be,0x634806be}},	//   _करबा, _бдиг, _sənk_, dənh, 
   {{0x9d400209,0xafe401af,0x00000000,0x00000000}},	// [12be0] бетд, _йопл, --, --, 
   {{0xdde000e2,0xa2c8013a,0x00000000,0x00000000}},	//   ārša, _संम्, --, --, 
   {{0x3a2c0139,0x2a64009a,0xceb800d1,0x8eb40150}},	//   _baep_, thob_, _җәң_, _نەست, 
   {{0x3a2c0007,0x1ef80bd9,0x00000000,0x00000000}},	//   _caep_, _אלטע, --, --, 
   {{0x3a2c0007,0xa2c829d9,0x00000000,0x00000000}},	//   _daep_, _संभ्, --, --, 
   {{0xaae496d3,0x628401fa,0x6bd86bcc,0x2a64da19}},	//   _مسرو, čkoi, _سورس_, shob_, 
   {{0x6b64a96e,0x5c7000c0,0x29d4022e,0x00000000}},	//   _сква, _улёт, _бўзс, --, 
   {{0x3a2c0399,0xa03c02d3,0x44f41d5b,0x00000000}},	//   _gaep_, _ኣወንታ, апис, --, 
   {{0x63480cc1,0x270c03be,0x5e54008f,0x00000000}},	//   məni, _məni_, טיקע_, --, 
   {{0x634803be,0x38a8dc99,0xd918008d,0x24500276}},	//   ləni, túre_, _אומל, _câmp_, 
   {{0x3a2c0399,0xf1a001ec,0xb5fc00d7,0x0eb40a8a}},	//   _yaep_, _ﺍﺭﺍﻡ_, chšo, ंगाड, 
   {{0xdbdc066a,0x63480213,0x38a800c7,0x00000000}},	//   _líðu, nəni, rúre_, --, 
   {{0xf380a705,0x25a40419,0x925801ec,0x38a800c7}},	//   йғәм, _uzol_, уаят_, súre_, 
   {{0xe1fc09c2,0x634800ac,0x83f800f3,0x3dcc0327}},	//   chón_, həni, _рекс_, _żew_, 
   {{0x634803be,0x69cc013f,0x2bfc0ce0,0x270c03b9}},	//   kəni, _ɑber, _लाजू_, _bəni_, 
   {{0xbe6401f7,0x5f44009d,0xbbdc1408,0x00000000}},	//   جهري, вүүн_, यर्क, --, 
   {{0x63480cc1,0x9f40012c,0xd01000aa,0xdbdc01a8}},	// [12bf0] dəni, mají_, غلې_, _bíðu, 
   {{0x9f40012c,0x8c440640,0x00000000,0x00000000}},	//   lají_, беђе, --, --, 
   {{0x2ba805ba,0x5ba4035b,0x63480213,0x00000000}},	//   _करणा, ураз, fəni, --, 
   {{0xda641b45,0x9f40012c,0x634803b9,0x00000000}},	//   دائي, nají_, gəni, --, 
   {{0x3a2c0421,0xc86404a9,0x49c81cd0,0x00000000}},	//   _vaep_, әтчи, улін_, --, 
   {{0x9f4000bc,0x7d1c0857,0xa2a40073,0x00000000}},	//   hají_, _ipss, _टीस्, --, 
   {{0xf770bfba,0x3668a8c9,0x270c03be,0x9f40012c}},	//   غات_, како_, _yəni_, kají_, 
   {{0x2ba805ba,0x7d1c1bc5,0xb8640133,0x63480213}},	//   _करता, _kpss, داچو, cəni, 
   {{0x9f400316,0xb4640075,0xa4d40640,0x261400c5}},	//   dají_, икил, адњу_, _भउरी_, 
   {{0xf8b850d8,0x176800f3,0x9a8401d5,0x00000000}},	//   _شهاب_, _преп_, _руҳл, --, 
   {{0xd6d801af,0x9f400118,0x00000000,0x00000000}},	//   _чтз_, fají_, --, --, 
   {{0x7d1c0857,0x00000000,0x00000000,0x00000000}},	//   _opss, --, --, --, 
   {{0xc6a40818,0xb5fc00de,0x00000000,0x00000000}},	//   _урфи, ekšg, --, --, 
   {{0x05a800d6,0x270c03be,0x63480213,0xe4e401e0}},	//   _свій_, _səni_, zəni, _өсәү, 
   {{0x634803be,0x7d1c0857,0xa2a40490,0xdbdc0d12}},	//   yəni, _apss, _टीव्, _ríðu, 
   {{0xdbdcdc9a,0xa2c81a2a,0x2290004b,0xdcec03e0}},	//   _síðu, _संत्, _ولوس, _azcı, 
  
   {{0x9fa002d2,0x6bd4dc9b,0xac080120,0x661400a2}},	// [12c00] _bíói_, لتار, кнаа_, _öyke, 
   {{0x2ba800af,0x1c40dc9c,0x6b58045c,0x00000000}},	//   _करदा, онум, кшер_, --, 
   {{0x628403c6,0x634803be,0x81a8dc9d,0x7d1c127b}},	//   čkov, təni, _لطیف_, _epss, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x634800ac,0xdbdc05f7,0xceb403b9,0x00000000}},	//   rəni, _tíðu, mmə_, --, 
   {{0xceb403be,0x187001ce,0x634800ac,0x38644f1a}},	//   lmə_, огія, səni, _cllr_, 
   {{0xa2c802db,0x6744009d,0xe66400d8,0x634806be}},	//   _संध्, рэлз, итио, pəni, 
   {{0x95d400a7,0xceb40213,0x63480213,0x2bd011a6}},	//   адът_, nmə_, qəni, दुरा, 
   {{0x9f400316,0x6aa005ac,0x3204002e,0x461401e2}},	//   vají_, mlof, _ñoyy_, لوګر, 
   {{0x195401ee,0xb5fc0171,0x00000000,0x00000000}},	//   _тађы_, ekšd, --, --, 
   {{0x6aa007ab,0x4394dc9e,0x9f4000bc,0x1c08216a}},	//   olof, санс, tají_, स्टल_, 
   {{0x6aa00b21,0x95c4008e,0xc4840131,0x41c0012d}},	//   nlof, _куша_, рлүк, _एलओस, 
   {{0x6aa0d2aa,0x5ab40a1e,0x9f4000bc,0xe4a4009b}},	//   ilof, ילטע_, rají_, _крко, 
   {{0x6aa0dc9f,0x7d1c0200,0x9f400118,0x909803c5}},	//   hlof, _rpss, sají_, ивят_, 
   {{0x6f1c009f,0xe80c012c,0x238001d9,0xbed400d8}},	//   _cppc, _साना_, _گٔژِ, собј, 
   {{0x6aa0dca0,0xcdd80063,0x00000000,0x00000000}},	//   jlof, ињу_, --, --, 
   {{0xa2c866eb,0x38a800e4,0x5c04004e,0x6aa00139}},	// [12c10] _सूत्, húra_, ияжа, dlof, 
   {{0x80dc0f22,0x38a83656,0xc0e0001f,0x6e2001e4}},	//   _বিপ্, kúra_, ናከር_, ĵoba, 
   {{0x38a80022,0x7f58010a,0x00000000,0x00000000}},	//   júra_, _санс_, --, --, 
   {{0x6aa0dca1,0x38a80aa6,0xceb406be,0x3eb40790}},	//   glof, dúra_, cmə_, çatı_, 
   {{0x67380bc9,0x8d84dca2,0x497401c0,0x7e98152f}},	//   _artj, _дурд, олцс, _لنگر_, 
   {{0x6aa004c9,0xed54011a,0x00000000,0x00000000}},	//   alof, _הבשר_, --, --, 
   {{0x9f40a4d8,0x6aa00115,0x00000000,0x00000000}},	//   najà_, blof, --, --, 
   {{0x7c24dca3,0x0a940153,0x00000000,0x00000000}},	//   lehr, _дасю, --, --, 
   {{0x78bc011c,0xccf40134,0x67380ea0,0xbb400092}},	//   _èsvo, hyɛn_, _ertj, _የሚበላ, 
   {{0xb4641c31,0x7c2402f0,0xba3c0118,0xe80c0b67}},	//   скол, nehr, _chův, _साया_, 
   {{0x673801f5,0x070807c0,0x38a800d7,0xb5fc0171}},	//   _grtj, _نيلي_, cúra_, ekše, 
   {{0x7c2401d5,0x1da40073,0x00000000,0x00000000}},	//   hehr, _खरंत, --, --, 
   {{0x7c240fad,0xe44c17a0,0xa6140022,0xe80c230e}},	//   kehr, _еж_, _ызцә, _सामा_, 
   {{0x1c00367a,0xa8040005,0x00000000,0x00000000}},	//   _लागल_, muñó, --, --, 
   {{0xceb403be,0x75280921,0xdee0036b,0xafe401b9}},	//   tmə_, lwez, зоси, _қонл, 
   {{0x752801c8,0xb1441c35,0x941001f9,0xbb700150}},	//   owez, _гнил, त्रच_, _ﺴﺒﻘﻪ_, 
   {{0x75280936,0xceb403be,0x62840010,0x00000000}},	// [12c20] nwez, rmə_, čkot, --, 
   {{0x7c2403fa,0x752801f7,0x6f64295d,0x302800cf}},	//   gehr, iwez, _гвоз, _сооп_, 
   {{0x75285975,0x6aa027be,0x6f1c0175,0xe9d8dca4}},	//   hwez, tlof, _uppc, гке_, 
   {{0x6aa0067c,0x629c00c7,0x37e003d4,0x5dc000db}},	//   ulof, _ëpot, _নাগৰ, _ىمپە, 
   {{0x2ba8d024,0x6aa0dca5,0xc8780588,0x7c24dca6}},	//   _करवा, rlof, аҟа_, behr, 
   {{0x38a8dca7,0x6aa0dca8,0xab28667a,0x7528009a}},	//   túra_, slof, _йога_, dwez, 
   {{0xe80c1094,0x6aa0dca9,0x7528009f,0x94080213}},	//   _साठा_, plof, ewez, _ölən_, 
   {{0xbbe8040b,0x26c80798,0x67380841,0x66e401b9}},	//   _مرہم_, _ébom_, _vrtj, _ҳожа, 
   {{0x96143a16,0x7528d0ab,0x9fa008a5,0x96b40114}},	//   صغير_, gwez, _líði_, љују_, 
   {{0x2904dcaa,0x66e400ee,0x20cc00ef,0x00000000}},	//   muoa_, _гожа, _bļin_, --, 
   {{0x290401e0,0x752804ba,0x4e0800bc,0xd7ec007b}},	//   luoa_, awez, षलाई_, _سكن_, 
   {{0x7528055a,0x7c24dcab,0x80dc0154,0x42c800db}},	//   bwez, zehr, _বিব্, лгүн_, 
   {{0x752868d7,0x00000000,0x00000000,0x00000000}},	//   cwez, --, --, --, 
   {{0x27ec0008,0x9fa003f2,0x61a00240,0x00000000}},	//   nafn_, _bíði_, _መዕረፊ_, --, 
   {{0x290400fb,0x7c24013a,0x00000000,0x00000000}},	//   huoa_, vehr, --, --, 
   {{0x7c2403fa,0x290401f7,0x628402fb,0x62640137}},	//   wehr, kuoa_, čkos, _داتق, 
   {{0x40340fe0,0xbc7800c0,0xe1fc0332,0xbadc02dd}},	// [12c30] _депс, абах_, dióx_, _ﺇﻨﺸﺎ, 
   {{0x61ecdcac,0xba3c012c,0x8d74dcad,0xdef8329e}},	//   lacl, _lhůt, ساقا, _йым_, 
   {{0x50d4144c,0x21280cfd,0x99d40597,0x7c24dcae}},	//   _وزیر, lwch_, متشا, rehr, 
   {{0x61ecdcaf,0x75280337,0x7c2491a5,0x19e8007b}},	//   nacl, ywez, sehr, اراً_, 
   {{0x212800a9,0x2904005a,0x7c2401e4,0x7e6c000d}},	//   nwch_, guoa_, pehr, mhap, 
   {{0x7e6c2641,0x49b8027d,0xb900007d,0x61ec00a3}},	//   lhap, حامد_, _दऽ_, hacl, 
   {{0x61ec7bff,0xb5fc00d0,0x212803cb,0x00000000}},	//   kacl, lhši, hwch_, --, 
   {{0x7e6c7de6,0x0f7c0302,0x629c009a,0x7528556c}},	//   nhap, טרול, _nkqo, twez, 
   {{0x77780020,0x61ec0077,0x7e6c06c8,0xd7f80724}},	//   _እንዲሁ_, dacl, ihap, _буе_, 
   {{0x7528dcb0,0x9814dcb1,0x212800a9,0x13a4dcb2}},	//   rwez, _دبرا, dwch_, ینکی_, 
   {{0x7e6cdcb3,0x752800ca,0x63480213,0xe80ca202}},	//   khap, swez, dəns, _साता_, 
   {{0xc048dcb4,0x7e6cd58b,0xd6a8dcb5,0x61ec07de}},	//   _בז_, jhap, _صدام_, gacl, 
   {{0x7e6cdcb6,0x21280368,0x05d40133,0xbadc02dd}},	//   dhap, gwch_, _رزنج, _ﺇﻨﺴﺎ, 
   {{0x61ec0334,0xe4d40345,0x644c0254,0x04f8009f}},	//   aacl, _بووت_, öbit, _اووڊ_, 
   {{0x61ecdcb7,0xa0a0dcb8,0xae782626,0x7e6c01f5}},	//   bacl, фард, асах_, fhap, 
   {{0x7bd40d27,0x61ec01ab,0x2128015d,0x9fa0032e}},	//   _afzu, cacl, bwch_, _víði_, 
   {{0xdcac0075,0x20cc00e4,0x9f4000d8,0x21280042}},	// [12c40] ھىم_, _güi_, rajá_, cwch_, 
   {{0xf8a4dcb9,0x7e6c02b5,0xe80c0490,0x00000000}},	//   _سک_, ahap, _साधा_, --, 
   {{0x7e6cdcba,0xeaf8007b,0x00000000,0x00000000}},	//   bhap, شرات_, --, --, 
   {{0x7e6cdcbb,0x29040184,0x692401d5,0x3cf40064}},	//   chap, tuoa_, жмда, _žavų_, 
   {{0x29100af2,0xb5fc0030,0xe80c3be5,0xaa8000a2}},	//   îya_, chši, _सादा_, _öými, 
   {{0x6e3402d5,0x290401af,0x3a2c016b,0x7e840153}},	//   ldyb, ruoa_, _ɔmpɛ_, vėpi, 
   {{0x44201a4c,0xeb3407a7,0x290401e0,0x61ec6656}},	//   _ĝi_, _بىزد, suoa_, yacl, 
   {{0x44201a4c,0x27ec008c,0x6e34dcbc,0x290401e0}},	//   _ŝi_, safn_, ndyb, puoa_, 
   {{0xccf40134,0x1dbc00dc,0x61ec0022,0x2ba800cd}},	//   kyɛm_, ्शयत, vacl, _करुथ, 
   {{0x6e340175,0x7e6c007f,0x634806be,0x00000000}},	//   hdyb, zhap, dənr, --, 
   {{0x61ecdcbd,0x7e6c0076,0x80dc0011,0x00000000}},	//   tacl, yhap, _বিধ্, --, 
   {{0x212800a9,0x7e6c1cdf,0x394802f0,0x461406c2}},	//   twch_, xhap, ťase_, _روتر, 
   {{0xa2c8dcbe,0x21280042,0x73fc010b,0x6d580241}},	//   _सूर्, uwch_, _ỳaşa, _ńtan, 
   {{0x61ec0395,0x212800a9,0x5494484d,0x00000000}},	//   sacl, rwch_, _وضوح_, --, 
   {{0x7e6cdcbf,0x8f34dcc0,0x21280368,0x00e401d5}},	//   thap, мерц, swch_, _کتبی, 
   {{0x9754011a,0x6e34015d,0x00000000,0x00000000}},	//   חילו_, gdyb, --, --, 
   {{0x7bf8dcc1,0x7e6cdcc2,0xa3b4012c,0x00000000}},	// [12c50] йнар_, rhap, चेर_, --, 
   {{0x7e6cdcc3,0xe0dc19f5,0x5ba4dcc4,0x00000000}},	//   shap, mpò_, орез, --, 
   {{0xf42802f6,0xccf40134,0xc5f0015b,0x998c01d3}},	//   lmää_, asɛ_, _টানা_, vegő_, 
   {{0x7e6c241c,0x00000000,0x00000000,0x00000000}},	//   qhap, --, --, --, 
   {{0xa3c80316,0xe0dcdcc5,0xd92802e8,0x00000000}},	//   लखा_, npò_, рцел_, --, 
   {{0xdb580139,0x00000000,0x00000000,0x00000000}},	//   _кюб_, --, --, --, 
   {{0xf428023a,0x9a84dcc6,0x7c3402d0,0x2d8c05d1}},	//   hmää_, _дуал, _iazr, şfet_, 
   {{0x7c34dcc7,0xfb2400aa,0xe5f00075,0x00000000}},	//   _hazr, _ورځپ, ىكىد, --, 
   {{0x490447ea,0x7c340064,0x2bd007b7,0x63480213}},	//   _يوفق, _kazr, दुका, dənq, 
   {{0x73040124,0xe5740c75,0x00000000,0x00000000}},	//   ппоз, язы_, --, --, 
   {{0x7c34dcc8,0x0a38001f,0x5ed80154,0xa3b469dd}},	//   _mazr, _በምሥራ, _বয়সে, चेल_, 
   {{0x7c340200,0x00000000,0x00000000,0x00000000}},	//   _lazr, --, --, --, 
   {{0x74b839c1,0xee3801e0,0x00000000,0x00000000}},	//   _лукс_, ҙна_, --, --, 
   {{0x653800c8,0x7c34dcc9,0x7e7c127b,0x76580142}},	//   _לענד, _nazr, _amsp, _howy, 
   {{0xdfcc1c43,0xfbd00154,0x2aac0419,0xe43014af}},	//   ايف_, িরাত, hýba_, _سفيد, 
   {{0x644400da,0x7c3400b8,0x7e7c004d,0xee380063}},	//   ēkie, _aazr, _cmsp, љна_, 
   {{0x6e34005c,0x76580076,0x708401b9,0xd1380210}},	// [12c60] rdyb, _mowy, _нгиз, łąb_, 
   {{0xeb980372,0xccf4043b,0x7e7c0036,0x7658dcca}},	//   биз_, rsɛ_, _emsp, _lowy, 
   {{0x7c34263c,0xda6c01d9,0xfe7000f1,0x00000000}},	//   _dazr, گُن_, ردې_, --, 
   {{0x7658068f,0x49a402dd,0x00000000,0x00000000}},	//   _nowy, мылғ, --, --, 
   {{0x7c3405b1,0x63a40034,0x00000000,0x00000000}},	//   _fazr, ękni, --, --, 
   {{0x7c340240,0xddcc0210,0x00000000,0x00000000}},	//   _gazr, _gocł, --, --, 
   {{0xd6d4dccb,0xe1fc0034,0x7658d522,0x3af4013d}},	//   пты_, chów_, _bowy, _оятс, 
   {{0xa9c40214,0xbb7000cf,0x7c341821,0xf428005b}},	//   _رزرو, _جۇمع, _zazr, ymää_, 
   {{0xb5fc005f,0x765800a2,0xbb40001f,0x44b400d8}},	//   ukša, _dowy, _የሚተላ, мбис, 
   {{0xb5fc005f,0x765802d0,0xd4d4007b,0x7c3420c2}},	//   rkša, _eowy, أبيض_, _xazr, 
   {{0xe618d466,0xa3b423ff,0x65940133,0x3860002f}},	//   _где_, चें_, _کجار, öhre_, 
   {{0x7658dccc,0xd374dccd,0xb5fc0064,0x00000000}},	//   _gowy, ячы_, lkšn, --, 
   {{0x26c40093,0x1a98010f,0xf02c0023,0x50380023}},	//   _iioo_, מיטע, _ብምምዝ, _ብምኽባ, 
   {{0x55b802e4,0x7e7c0175,0xf428005b,0x26c401f4}},	//   _המדו, _smsp, rmää_, _hioo_, 
   {{0xa34405f5,0x26c400ec,0xe0dc02e2,0xf4280108}},	//   _хэлл, _kioo_, spò_, smää_, 
   {{0x7c340552,0xe0dc4d72,0x249c00d7,0x00000000}},	//   _sazr, ppò_, lotm_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [12c70] --, --, --, --, 
   {{0xfb84cdc2,0x00000000,0x00000000,0x00000000}},	//   ودای, --, --, --, 
   {{0x78bc011c,0xef3000c7,0x7f9401c4,0x00000000}},	//   _èsvi, _иҭры, _цанх, --, 
   {{0xb5fc005f,0x7e7cdcce,0x00000000,0x00000000}},	//   ekšn, _umsp, --, --, 
   {{0x20d000e1,0x3ea801e6,0x25a4020c,0xd918dccf}},	//   _धूमध, mlat_, _nyol_, сье_, 
   {{0x3ea8dcd0,0x49b82a77,0x765800a2,0x22580200}},	//   llat_, ساند_, _sowy, _loqk_, 
   {{0xe80c0307,0x25a407d6,0x7658dcd1,0x2a64079b}},	//   _सारा_, _ayol_, _powy, bkob_, 
   {{0xd8741060,0x87042e56,0x3ea801d3,0x754400d8}},	//   _کارب, ربىل, nlat_, дниз, 
   {{0x1dbc00dc,0xb81400ea,0xf52800f1,0x3b400092}},	//   ्शित, _одај, تګاه_, _የሚጀመ, 
   {{0x25a4033b,0x249c010a,0x3ea8287c,0x3834109a}},	//   _dyol_, gotm_, hlat_, _інер, 
   {{0x26c40076,0x1768dcd2,0x76580142,0x999c0139}},	//   _fioo_, _урап_, _towy, _yauş_, 
   {{0x1dbc0950,0xc1e00131,0xd694010a,0x00000000}},	//   ्शात, _ﺋﯩﺮﺍ, _хăмп, --, 
   {{0x3ea83f6b,0x13a40214,0xb5fc0064,0x00000000}},	//   dlat_, تنگی_, lkšo, --, 
   {{0x2010003a,0x3ea800d7,0xce34bb12,0x00000000}},	//   _ccxi_, elat_, کورک, --, 
   {{0xe29c05a4,0x3ea8dcd3,0x7544012d,0x245801ef}},	//   boð_, flat_, łrzę, _dámě_, 
   {{0xece8241e,0xe1fc1d55,0x00000000,0x00000000}},	//   ждал_, lkón_, --, --, 
   {{0xe80c1b57,0x7e840153,0x00000000,0x00000000}},	// [12c80] _साला_, vėpt, --, --, 
   {{0x25a0dcd4,0x3ea8dcd5,0x3cf80798,0x00000000}},	//   ükli_, alat_, _dvsv_, --, 
   {{0x2a64007f,0x00000000,0x00000000,0x00000000}},	//   tkob_, --, --, --, 
   {{0xa9680046,0x3ea8dcd6,0x2ef800ca,0x00000000}},	//   يمام_, clat_, _ivpf_, --, 
   {{0xbed8030f,0x05ac000d,0xb5fc0171,0x00000000}},	//   _وهیچ_, _चरइब, ekšo, --, 
   {{0x26c403a0,0x18647991,0x2a640156,0x587401d9}},	//   _sioo_, мачи_, skob_, وٝنس_, 
   {{0xdca0dcd7,0x45d40064,0xdc34010f,0xb5fc0153}},	//   _рари, нойс, _קאלט_, rkšn, 
   {{0x69240166,0xa924041b,0x00000000,0x00000000}},	//   _омба, _одбл, --, --, 
   {{0x248402d3,0x26c401c8,0xc4c80892,0x00000000}},	//   _ክብረት_, _vioo_, रदेख, --, 
   {{0x68e0dcd8,0x25a45138,0x80dc0eac,0x00000000}},	//   mpod, _vyol_, _বিল্, --, 
   {{0x3ea80548,0xe29c01a8,0x0a380092,0xe618005a}},	//   ylat_, toð_, _በምስራ, _мдж_, 
   {{0xb5fc0024,0x26dc0051,0x68e00210,0x95900092}},	//   nkšl, _itto_, opod, _ልጆችን_, 
   {{0x3ea80517,0xa2c8190c,0x37c001af,0x00000000}},	//   vlat_, _संक्, _иҙәб, --, 
   {{0xdbf051b7,0x9f4001f1,0x2904dcd9,0x3ea8dcda}},	//   _işçi, majú_, iroa_, wlat_, 
   {{0x442cdcdb,0x3ea8dcdc,0x490805f9,0x9f400030}},	//   med_, tlat_, _समझो_, lajú_, 
   {{0x442cdcdd,0x3ea8dcde,0x290405da,0xc1140b3e}},	//   led_, ulat_, kroa_, _змиј, 
   {{0x3ea8dcdf,0x442cdce0,0x628cdce1,0x9f400030}},	// [12c90] rlat_, oed_, mnco, najú_, 
   {{0x442cdce2,0x3ea80316,0xb5fc005f,0x2904dce3}},	//   ned_, slat_, ekšl, droa_, 
   {{0x3ea8dce4,0x628cdce5,0x9f40dce6,0x5ba401ca}},	//   plat_, onco, hajú_, фраз, 
   {{0x6448089c,0x9f4001f1,0xde44004b,0xb99404da}},	//   _lnfi, kajú_, _تیرو_, ىلاب, 
   {{0x26dc0801,0x64480c8c,0x628cdce7,0xe1fc0ba1}},	//   _atto_, _onfi, inco, lhós_, 
   {{0x442cdce8,0x7d0cdce9,0x27fc0198,0x9f4001f1}},	//   jed_, muas, _cdtn_, dajú_, 
   {{0x442c0d65,0xb6a4dcea,0xe8502928,0x62680198}},	//   ded_, никл, انىد, nƙos, 
   {{0x442cdceb,0x8b880efb,0x628cdcec,0x9f400aa6}},	//   eed_, _تەمە_, jnco, fajú_, 
   {{0x7d0cdced,0x20cc0135,0x660401ed,0x8934007b}},	//   nuas, _jżid_, ókka, _لعلا, 
   {{0x628c008f,0x442cdcee,0x29180276,0xdb040200}},	//   enco, ged_, ăpat_, _nyjë, 
   {{0x7d0c0113,0xa3dc00e1,0x38a80022,0xe1fc00d7}},	//   huas, तड़_, júri_, rkón_, 
   {{0x7d0c47d8,0x6448dcef,0x442c00c5,0x9f40dcf0}},	//   kuas, _enfi, aed_, bajú_, 
   {{0x7d0cdcf1,0x9f4000d0,0xe56cdcf2,0x00000000}},	//   juas, cajú_, _сз_, --, 
   {{0x442cdcf3,0xba00044e,0x628cdba0,0xa2c808a3}},	//   ced_, _ጌጋ_, anco, _सूक्, 
   {{0x2eb44445,0x35840092,0x7f1889bf,0xf268009b}},	//   есас, _ክትባት_, міту_, _никл_, 
   {{0x7d0cdcf4,0xe450035b,0x68e00076,0x00000000}},	//   fuas, _акәы, ypod, --, 
   {{0x7d0c0588,0xdcac34b1,0x6448dcf5,0x3b40001f}},	// [12ca0] guas, ڭىل_, _ynfi, _የሚገመ, 
   {{0xeb983be4,0xef181a4f,0x2904030a,0x02b800d7}},	//   пиз_, _емо_, vroa_, číňa_, 
   {{0x9f4001f1,0xb5fc005f,0xeb9805f5,0xe1fc00ae}},	//   zajú_, ekšm, чиж_, mhór_, 
   {{0x442cdcf6,0x2904dcf7,0x7d0c017a,0x68e0dcf8}},	//   zed_, troa_, buas, tpod, 
   {{0x442cdcf9,0xd940dcfa,0x290400b0,0x7d0c7339}},	//   yed_, леци, uroa_, cuas, 
   {{0x9f4001a2,0x290405f5,0x442cdcfb,0x2c8401e1}},	//   vajú_, rroa_, xed_, _dídè_, 
   {{0x442cdcfc,0xe6641b88,0xb8640066,0x661401f4}},	//   ved_, етпо, خانو, _öykk, 
   {{0x442cdcfd,0x9f400030,0x68e0dcfe,0x97200592}},	//   wed_, tajú_, ppod, افيو, 
   {{0x442cdcff,0x6aa00ba7,0x00000000,0x00000000}},	//   ted_, moof, --, --, 
   {{0x6aa0225e,0x442cdd00,0x9f4001f1,0x628c0421}},	//   loof, ued_, rajú_, wnco, 
   {{0x442cdd01,0x4394dd02,0x9f400419,0x00000000}},	//   red_, танс, sajú_, --, 
   {{0x442cdd03,0x6aa00ba7,0x6f0c0455,0xf4180327}},	//   sed_, noof, dubc, ྱུུད_, 
   {{0x442cdd04,0xb6380150,0x00000000,0x00000000}},	//   ped_, _ﺘﺔ_, --, --, 
   {{0x6448dd05,0x41a4dd06,0xd5ac02e9,0x442cdd07}},	//   _unfi, _गुणस, _افه_, qed_, 
   {{0x6aa01559,0xcf981fbe,0x5438010f,0xd36c6a24}},	//   koof, ејт_, _מעגא, _сч_, 
   {{0x7d0c9161,0x6aa0022f,0xfd5400dc,0x00000000}},	//   tuas, joof, _khaḍ, --, 
   {{0x6aa09d8f,0xdfd8004e,0x00000000,0x00000000}},	// [12cb0] doof, _нън_, --, --, 
   {{0x7d0cdd08,0x8178014b,0x00000000,0x00000000}},	//   ruas, _нақӣ_, --, --, 
   {{0x7d0cdd09,0x6aa0dd0a,0x00000000,0x00000000}},	//   suas, foof, --, --, 
   {{0x7d0c2831,0x6aa0b3e0,0x63a80129,0x0ba414fb}},	//   puas, goof, _myfn, ушум, 
   {{0xb5fc0024,0x00000000,0x00000000,0x00000000}},	//   ukšm, --, --, --, 
   {{0x9be400e5,0x8c0800eb,0x00000000,0x00000000}},	//   _سورۃ_, র্বন_, --, --, 
   {{0x6aa0208d,0xfac40022,0x63a80142,0xd51401e1}},	//   boof, _ашаҽ, _nyfn, _ọ̀s, 
   {{0xa50404a9,0xfd540055,0x35a4dd0b,0x8aa400d3}},	//   ھىپە_, _bhaḍ, кайг, _бруд, 
   {{0xa2c808ec,0x3834dd0c,0x95040327,0x00000000}},	//   _संज्, _инар, _ཀཀཎི_, --, 
   {{0xb46400d8,0x48e40120,0xb9d00240,0x00000000}},	//   ткол, _соѕв, _ትራ_, --, 
   {{0x63a80cfd,0x8c1c0a7c,0xa92002d2,0x00000000}},	//   _cyfn, לוזי, _íþri, --, 
   {{0x63a803cb,0x68ec00e4,0x00000000,0x00000000}},	//   _dyfn, _êndý, --, --, 
   {{0xdb1c032e,0x90c801a9,0x00000000,0x00000000}},	//   _óvær, нғиз_, --, --, 
   {{0xd34015b4,0x00000000,0x00000000,0x00000000}},	//   _مفتی, --, --, --, 
   {{0x63a800a9,0x6aa0dd0d,0x2ef800db,0x00000000}},	//   _gyfn, yoof, بىزد_, --, 
   {{0xde00dd0e,0xb144dd0f,0x6f0cdd10,0xb22400c7}},	//   ипси, _анил, rubc, _рмил, 
   {{0x6f0cdd11,0x2d94dd12,0x61f81d0e,0xb5fc0171}},	// [12cc0] subc, төнө_, ðule, ekšk, 
   {{0x6ac8dd13,0xf0b80f01,0x14b000cd,0x9d400150}},	//   िद्र, _تابش_, ीषिण, шеуд, 
   {{0x6aa0022f,0x6f0c014f,0x91c4104e,0xc60800cc}},	//   toof, qubc, _шәүл, লভতা_, 
   {{0x29840733,0x00000000,0x00000000,0x00000000}},	//   кылг, --, --, --, 
   {{0x6aa0dd14,0xfe74278f,0x3eac031c,0xc8480166}},	//   roof, _сүт_, ċett_, нҗал_, 
   {{0x6aa0dd15,0x6d44dd16,0xd820316e,0x38a80306}},	//   soof, _irka, идчи, kúru_, 
   {{0x6d4407f5,0x61ac27c6,0x06d001ec,0x00000000}},	//   _hrka, _घर्ष, _ﻗﺎﺗﻪ, --, 
   {{0xe5c4dd17,0x6d4405be,0xcd500092,0xfd540055}},	//   кспо, _krka, _ከመንፈ, _phaḍ, 
   {{0x98bc01ef,0x00000000,0x00000000,0x00000000}},	//   _zruč_, --, --, --, 
   {{0x25e006ab,0x6d4400f3,0xab640036,0x754401b9}},	//   _ट्री_, _mrka, chüü, ایوف_, 
   {{0x8c08015b,0x18740375,0x63b000c7,0x38a8dd18}},	//   র্থন_, _שעבר_, ранӡ, gúru_, 
   {{0x6d44dd19,0x2c7406ea,0x3e7403cd,0x00000000}},	//   _orka, _hædd_, _kåte_, --, 
   {{0x9550034c,0x5184dd1a,0x6600dd1b,0x00000000}},	//   _نخوا, аура, _idok, --, 
   {{0x3e741a82,0x8c0800bd,0x9fa00419,0x38a801e1}},	//   _måte_, র্তন_, síím_, búru_, 
   {{0x5430a822,0x443c0211,0x6d44dd1c,0xd4800014}},	//   _ضرور, _iav_, _arka, _خلوٝ, 
   {{0x443cdd1d,0x6d4407f5,0xdbe82356,0x2284009d}},	//   _hav_, _brka, टर्ड_, _шулг, 
   {{0x80dc6569,0x443c0457,0x6d440552,0x66000200}},	// [12cd0] _বিক্, _kav_, _crka, _mdok, 
   {{0x443cdd1e,0x6d445ed6,0x40340063,0x6458036e}},	//   _jav_, _drka, _сеос, njti, 
   {{0x443cdd1f,0x6d44dd20,0x6600dd21,0xa3b40490}},	//   _mav_, _erka, _odok, चेच_, 
   {{0x443cdd22,0x6600dd23,0x6d44dd24,0xd5a00116}},	//   _lav_, _ndok, _frka, _тaзи, 
   {{0x443c01b9,0x00000000,0x00000000,0x00000000}},	//   _oav_, --, --, --, 
   {{0x443cdd25,0x7e6cdd26,0x6600dd27,0x38a803b2}},	//   _nav_, lkap, _adok, júrt_, 
   {{0x6d4401f1,0xabb400d1,0x7bd00342,0x7e6c9449}},	//   _zrka, _барә, ğduğ, okap, 
   {{0x7e6cdd28,0x443cdd29,0x6d44dd2a,0x3a74010b}},	//   nkap, _aav_, _yrka, _ёлар, 
   {{0x443c2d26,0x3e74143a,0x2c7401a8,0x18b0151e}},	//   _bav_, _gåte_, _fædd_, _кәкр, 
   {{0x443c0070,0x660002e3,0x38a8dd2b,0x7e6cdd2c}},	//   _cav_, _edok, túru_, hkap, 
   {{0x443cdd2d,0x7e6cdd2e,0xe5a00853,0x98bc0306}},	//   _dav_, kkap, _қиши, _hruď_, 
   {{0x443c07de,0x32b800c6,0x7e6cdd2f,0x5fa4000d}},	//   _eav_, عددة_, jkap, _गड़ल, 
   {{0x321c0034,0xc0340023,0x443c0f85,0x6d540076}},	//   ęty_, _ብምምል, _fav_, xxya, 
   {{0x4094a7a3,0x443cdd30,0x66000122,0x2c74037e}},	//   арст, _gav_, _zdok, _kæde_, 
   {{0x3244010b,0x5f0000fd,0x6d440010,0x111400d1}},	//   _бейг, йзра, _srka, _ھېسس, 
   {{0x7e6cdd31,0x443c76ea,0xed58039b,0x6da4005b}},	//   gkap, _zav_, ноб_, гиба, 
   {{0x443cdd32,0x1d04dd33,0x00000000,0x00000000}},	// [12ce0] _yav_, лети_, --, --, 
   {{0x443c0b89,0x7e6cdd34,0x3e7403cd,0xada401e0}},	//   _xav_, akap, _råte_, _ҡанл, 
   {{0x16000490,0x7e6c01e4,0x81c805ac,0x1be000c5}},	//   ळणार_, bkap, _ল্প_, गड़ल_, 
   {{0x6d4417a3,0x3e740158,0x2c740162,0xe8f828a8}},	//   _trka, _påte_, _sædd_, елд_, 
   {{0x503802d3,0x6d44dd35,0x8884dd36,0x9ba40014}},	//   _ብምንባ, _urka, ағал, نگہِ_, 
   {{0x3e7408fb,0xec7005d9,0x98a0dd37,0x994401e2}},	//   _våte_, _اٿس_, биче, الول_, 
   {{0x443cdd38,0x1ae000fd,0x00000000,0x00000000}},	//   _rav_, _госм, --, --, 
   {{0x443cdd39,0x9b90dd3a,0xa3e40709,0x00000000}},	//   _sav_, _الفت, युन_, --, 
   {{0x443cdd3b,0xd940dd3c,0xa9080849,0xbe200154}},	//   _pav_, _лети, _سيال_, _পোঁদ_, 
   {{0x7e6c2457,0x443cdd3d,0xd5f00354,0xfed00ef6}},	//   zkap, _qav_, _цiог, _ﻛﺎﯞﺍ, 
   {{0x443c0978,0x7e6cdd3e,0xd87400ae,0x00000000}},	//   _vav_, ykap, _حملت_, --, 
   {{0x6600dd3f,0x67381e31,0x377401ee,0x00000000}},	//   _udok, _istj, _тыус, --, 
   {{0x443cdd40,0x25780241,0x00000000,0x00000000}},	//   _tav_, _dàlé_, --, --, 
   {{0x443cdd41,0x7e6c0309,0xe1fc00c7,0x66cc0248}},	//   _uav_, wkap, ikói_, bòkè, 
   {{0x7e6cdd42,0x80d41d8a,0x1df400c7,0x00000000}},	//   tkap, _यूरे, лҵны_, --, 
   {{0xe80c06bc,0x228801e1,0xe2a80014,0x53980375}},	//   _साझा_, _dòkè_, _ثاتن_, _ריהו, 
   {{0x7e6cdd43,0x7d1c010a,0xff14015b,0x7d540107}},	// [12cf0] rkap, _qqss, াবেশ_, швах, 
   {{0x7e6cdd44,0xc2100050,0x673800af,0x8c08015b}},	//   skap, _أک_, _ostj, র্সন_, 
   {{0x22880248,0xd1b801ed,0x7e6c236c,0x26d801e4}},	//   _gòkè_, _لایا_, pkap, ŭpoj_, 
   {{0x8bc40108,0xb5fc00c0,0x00000000,0x00000000}},	//   ссуд, lkšv, --, --, 
   {{0x67380327,0x2c7400b5,0x527c008f,0x38340d1d}},	//   _astj, _sæde_, ענדא, индр, 
   {{0xe9640116,0x1a5400cf,0x00000000,0x00000000}},	//   рашл_, _өзгө_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7d0cdd45,0x9a84dd46,0x2c7401bf,0xe1fc012d}},	//   oras, _сугл, _væde_, mków_, 
   {{0x7d0cdd47,0xe80c0490,0xe1fc012d,0x00000000}},	//   nras, _साचा_, lków_, --, 
   {{0x7d0cdd48,0x34840137,0x7c240332,0xe8ec01c8}},	//   iras, ргог, nfhr, _آڻن_, 
   {{0x7d0c006c,0xe1fc068f,0x37c40075,0x00000000}},	//   hras, nków_, _тәдб, --, 
   {{0x80dc7f53,0xb5fc00e2,0x22880241,0x7c2400ae}},	//   _বিজ্, ekšv, _ròkè_, hfhr, 
   {{0xe2949b81,0x7d0cdd49,0x00000000,0x00000000}},	//   рая_, jras, --, --, 
   {{0xd4981429,0xa5040408,0x25780241,0x32d400d8}},	//   _яре_, _теша_, _wàlé_, _кцис, 
   {{0xe1fc012d,0x00000000,0x00000000,0x00000000}},	//   jków_, --, --, --, 
   {{0xe1fc0034,0xc1d4010b,0xf5880023,0x14740345}},	//   dków_, _гөрә, _ንስድራ_, _جاڵج, 
   {{0xac84dd4a,0x2288007f,0xfd9801e0,0xe1fc012d}},	// [12d00] агал, _wòkè_, гөрә_, eków_, 
   {{0x0eb80574,0xe0f8011a,0x00000000,0x00000000}},	//   _आठवड, _שליל, --, --, 
   {{0x7d0cdd4b,0x645c0428,0x8fd40032,0x6b54dd4c}},	//   aras, _òpie, _вәғә, штах, 
   {{0x6da402bf,0x629c0124,0x00000000,0x00000000}},	//   _вима, _êpot, --, --, 
   {{0x7d0cdd4d,0x9f4009d7,0x2c1c00dc,0xe1fc033f}},	//   cras, bajó_, _पापं_, aków_, 
   {{0x644400b0,0x7c2401ab,0x9f40007f,0xe1fc012d}},	//   ēkik, cfhr, majò_, bków_, 
   {{0xe9d8dd4e,0x473401b9,0xe1fc012d,0xd704033a}},	//   _акб_, ёнис, cków_, анје_, 
   {{0x8c08015b,0x3e740267,0x00000000,0x00000000}},	//   র্শন_, _kåta_, --, --, 
   {{0xd5b4dd4f,0x9f500129,0xb92800ae,0x00000000}},	//   ись_, _vexé_, _مثلك_, --, 
   {{0x20cc0327,0x00000000,0x00000000,0x00000000}},	//   _ażin_, --, --, --, 
   {{0x3e74049f,0x673814dc,0xd9400262,0x7d0cdd50}},	//   _låta_, _ustj, _леӂи, zras, 
   {{0xc5f003f4,0x60240022,0x7ae001d3,0x92940006}},	//   _টাকা_, _oĩmí, _élte, жаюц, 
   {{0xe1fc033f,0x4dfc00cc,0x00000000,0x00000000}},	//   zków_, ইলাখ_, --, --, 
   {{0x83f8dd51,0x7d0cdd52,0x20cc0327,0xe1fc033f}},	//   _секс_, vras, _eżin_, yków_, 
   {{0x7d0c0784,0x5e8400c7,0x00000000,0x00000000}},	//   wras, ауаз, --, --, 
   {{0xc034044e,0x5f4401c4,0x00000000,0x00000000}},	//   _ብዝምል, гүүн_, --, --, 
   {{0x61ec05b1,0xdb0400bc,0x9da80395,0xe1fc0210}},	// [12d10] mbcl, _vyjí, тъва_, wków_, 
   {{0xe1fc0034,0xa3a8dd53,0x7ae80118,0x23940023}},	//   tków_, _खडा_, _četb, _ዚስዕብ_, 
   {{0x7d0cdd54,0x2b4805c7,0x1da4a4ea,0x7e9846c6}},	//   sras, _crbc_, _कुरत, _مندر_, 
   {{0xa3e40562,0x7e54dd55,0xb5fc0006,0xe1fc033f}},	//   युत_, _انحص, nkšt, rków_, 
   {{0x394830cf,0x3ea8dd56,0xd9180a8f,0x7d0c00ac}},	//   ías_, moat_, тье_, qras, 
   {{0x3ea8dd57,0x88cc03d4,0x49b80035,0xe1fc0210}},	//   loat_, ৰীসক, جامد_, pków_, 
   {{0x2b480048,0xf74896ec,0x158802dd,0x3948010f}},	//   _grbc_, البي_, _ﯗﻟﺘﯩ, ŭas_, 
   {{0x3ea807d6,0xe734013e,0x00000000,0x00000000}},	//   noat_, сеъ_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x98141622,0xc5b401c6,0x998c0118,0x3ea80051}},	//   _خبرا, өрөө, legů_, hoat_, 
   {{0xa25806ed,0x386401ab,0x3ea8045f,0x00000000}},	//   rmôn, _iolr_, koat_, --, 
   {{0x3ea801d5,0x00000000,0x00000000,0x00000000}},	//   joat_, --, --, --, 
   {{0x3ea8067c,0x95c8dd58,0xa508237e,0x00000000}},	//   doat_, _ружа_, _مىنە_, --, 
   {{0xf8cc01ec,0xb64001ec,0x05a80212,0x00000000}},	//   мнiң_, _ﺁﻴ_, _твій_, --, 
   {{0x45240003,0xe45408a8,0x3ea8dd59,0x00000000}},	//   _འདོར_, _ליסט_, foat_, --, 
   {{0x3e74003b,0x20cc031c,0x00000000,0x00000000}},	//   _påta_, _użin_, --, --, 
   {{0x6bd40150,0xd1cc0023,0xa5d8010f,0xabd46c68}},	// [12d20] متار, በርቲ_, אַבי, مزات, 
   {{0x2b480421,0x629c00c7,0x3e7401e3,0x6a840075}},	//   _prbc_, _êpor, _våta_, әлда, 
   {{0x3ea8dd5a,0x95240135,0x00000000,0x00000000}},	//   boat_, _ཡཱའི_, --, --, 
   {{0x3ea80493,0xef20033f,0x00000000,0x00000000}},	//   coat_, ążę_, --, --, 
   {{0xceb403be,0x92e02aab,0x684430c2,0xa8500166}},	//   mlə_, _ফটো_, йнда, зелә, 
   {{0x6e34dd5b,0xceb400ac,0x98a00828,0x5dc80150}},	//   leyb, llə_, пиче, _ﻓﺭﻀﻴ, 
   {{0xb5fc0024,0xe72805af,0xdb8001af,0x00000000}},	//   ykšt, استو_, _егри, --, 
   {{0x20cc025c,0xceb403be,0x60d801e4,0x6a84009d}},	//   _ażil_, nlə_, ŭumi, _улба, 
   {{0xb5fc00da,0xe4a4dd5c,0xceb406be,0x00000000}},	//   ekšs, йроо, ilə_, --, 
   {{0xb864dd5d,0x03f80114,0x6e34dd5e,0xceb40213}},	//   _والو, шној_, heyb, hlə_, 
   {{0xceb403be,0x61f80174,0x00000000,0x00000000}},	//   klə_, ðulo, --, --, 
   {{0x9c84012c,0x534007d5,0xb5fc0153,0x91c800d1}},	//   _kočá, чхьа, ukšt, ﻨﻘﯩﻼ, 
   {{0xb5fc0024,0x64a4dd5f,0xceb40213,0x6e340009}},	//   rkšt, _лада, dlə_, deyb, 
   {{0x2368007b,0x9c8401ef,0x00000000,0x00000000}},	//   _محبي_, _močá, --, --, 
   {{0x93f825f9,0x4fc4dd60,0xddcc0356,0x2480020c}},	//   _גלוי, зста, _bocş, èkmu_, 
   {{0x6e340009,0xceb406be,0x00000000,0x00000000}},	//   geyb, glə_, --, --, 
   {{0x3ea8dd61,0x7bf8dd62,0x628c7912,0xc8a800bc}},	// [12d30] roat_, инар_, mico, गवाट, 
   {{0xe1fc004e,0xb95800e5,0xd5a40354,0x00000000}},	//   laó_, یلاؤ_, _тiеп, --, 
   {{0xefcc0020,0xb5fc151c,0xddcc0311,0x3ea8002d}},	//   ጣቸው_, ljše, _focş, poat_, 
   {{0x628cdd63,0xdb1c0579,0x38640010,0x6e34058a}},	//   nico, _ávís, _solr_, ceyb, 
   {{0xae1804ac,0xb5fc09a8,0x9be40064,0x00000000}},	//   _דורכ, njše, _гібк, --, 
   {{0xd7f8152d,0x628cdd64,0xc8c800ec,0x00000000}},	//   ууд_, hico, مونن_, --, 
   {{0x45240003,0x628cdd65,0x9b6801b9,0x00000000}},	//   _འདུར_, kico, _ёшга_, --, 
   {{0x628cdd66,0xb4d01361,0xb5fc005f,0xf508319b}},	//   jico, वद्_, ekšr, анил_, 
   {{0x58840500,0x9c8401ef,0x00000000,0x00000000}},	//   _лыжа, _gočá, --, --, 
   {{0xe574dd67,0x730400d6,0xceb400ac,0x248402d3}},	//   юзы_, опоз, zlə_, _ክእለት_, 
   {{0x628c74c3,0xceb403be,0x394c0156,0x070835f9}},	//   fico, ylə_, _hres_, _هيلي_, 
   {{0x394cdd68,0x628cdd69,0xe29421db,0x3554dd6a}},	//   _kres_, gico, жаю_, _وناز, 
   {{0xceb40213,0x2a38008f,0x26d80419,0x00000000}},	//   vlə_, בערמ, ípov_, --, 
   {{0x05741411,0x65980677,0x00000000,0x00000000}},	//   _عاند, _דינק, --, --, 
   {{0x60200323,0xceb403be,0xdee0dd6b,0x6e347caa}},	//   ьдра, tlə_, доси, teyb, 
   {{0x394cdd6c,0x628c026c,0xee3807fa,0x22e40345}},	//   _ores_, cico, јна_, _بتوێ, 
   {{0xceb40cc1,0x394c0070,0x7ae801fa,0x6e34dd6d}},	// [12d40] rlə_, _nres_, _četa, reyb, 
   {{0x3a2c0165,0xab2808b7,0x6fdc02ab,0xceb400ac}},	//   _abep_, иоза_, _मलिं, slə_, 
   {{0xe9d8dd6e,0x6a84dd6f,0xceb403b9,0x00000000}},	//   аке_, олжа, plə_, --, 
   {{0x394c13fd,0x9c84012c,0x6e34058a,0xceb403e3}},	//   _bres_, _počá, qeyb, qlə_, 
   {{0x394cdd70,0xdb04012c,0xac2000d1,0xd1d40023}},	//   _cres_, _vyjá, _оҗақ, _ረኸበ_, 
   {{0x3a2c0005,0x00000000,0x00000000,0x00000000}},	//   _ebep_, --, --, --, 
   {{0x394cdd71,0xd6d46690,0xea5807fa,0x628cdd72}},	//   _eres_, оты_, _крај_, yico, 
   {{0x628cdd73,0x394cdd74,0x395c0218,0x44f40075}},	//   xico, _fres_, bxws_, ппис, 
   {{0x394c6f2d,0x394800fe,0xe4c4005b,0x29000241}},	//   _gres_, åast_, жённ, _ìka_, 
   {{0xe4688cca,0xa2580120,0x628cdd75,0x83a40022}},	//   ршил_, rmôm, wico, зымҵ, 
   {{0x628cdd76,0xd60001e1,0x00000000,0x00000000}},	//   tico, _às̟e, --, --, 
   {{0xd374dd77,0x00000000,0x00000000,0x00000000}},	//   ючы_, --, --, --, 
   {{0x4524038f,0xd6ccdd78,0xe1fcdd79,0x65941e24}},	//   _འདིར_, _شقه_, raó_, _بجار, 
   {{0x44e00428,0x6d480618,0x00000000,0x00000000}},	//   _iò_, āfal, --, --, 
   {{0x628cdd7a,0x44e0dd7b,0xd1cc0240,0x00000000}},	//   pico, _hò_, በይቱ_, --, 
   {{0x44e0dd7c,0xe0140073,0xa3e4043e,0x00000000}},	//   _kò_, _ताकद_, युर_, --, 
   {{0xbe740241,0xf42800cf,0x44e00cad,0x00000000}},	// [12d50] _aṣàl, _ئيۉۉ_, _jò_, --, 
   {{0x44e0dd7d,0x14d4011a,0x00000000,0x00000000}},	//   _mò_, קובל_, --, --, 
   {{0x44e0dd7e,0x394c04d4,0x0b880353,0x00000000}},	//   _lò_, _sres_, осци_, --, 
   {{0x787c0100,0xd1cc02d3,0x44e00241,0x00000000}},	//   _mève, በይቲ_, _oò_, --, 
   {{0x44e0dd7f,0x787c5eb5,0x81cc015b,0x63a4033f}},	//   _nò_, _lève, শুর_, ękny, 
   {{0xbca40597,0x394c0589,0xb5fc005f,0x68400153}},	//   _رمزي, _vres_, ekšp, енша, 
   {{0xdb205aa3,0xd6c0dd80,0x907c010f,0x394c015d}},	//   _توزی, ومتی, שטוי, _wres_, 
   {{0x44e0dd81,0x3a2c0139,0x4f9c011a,0x00000000}},	//   _bò_, _ubep_, יבוצ, --, 
   {{0x44e0dd82,0x394c0200,0xf97800d8,0x754400d4}},	//   _cò_, _ures_, _убај_, їноз, 
   {{0xd874dd83,0x44e0dd84,0xa3e42356,0x12e002dd}},	//   _بارب, _dò_, युल_, _ﺍﻟﻭﺭ, 
   {{0x44e02558,0x964401c0,0x3244dd85,0x00000000}},	//   _eò_, _мэдд, пенг, --, 
   {{0x44e0dd86,0x727808ca,0x24a001f3,0xab640037}},	//   _fò_, ссос_, _ውጥረት_, lküü, 
   {{0x44e0dd87,0x47d00011,0x00000000,0x00000000}},	//   _gò_, _স্পী, --, --, 
   {{0x787c06af,0x00000000,0x00000000,0x00000000}},	//   _fève, --, --, --, 
   {{0x44e0dd88,0xe28c0882,0xa0a0dd89,0x6fb4007b}},	//   _zò_, ṇāma, хард, سمرا, 
   {{0x1fa802a6,0x71a4dd8a,0x44e00cad,0x9d400092}},	//   _গৃহস, _найз, _yò_, _ያላችሁ, 
   {{0x35a0069c,0x32000851,0x44e00395,0xac0801c0}},	// [12d60] _ውድባት_, maky_, _xò_, йнаа_, 
   {{0x3200dd8b,0x00000000,0x00000000,0x00000000}},	//   laky_, --, --, --, 
   {{0xd1d40240,0x00000000,0x00000000,0x00000000}},	//   _ረኸቦ_, --, --, --, 
   {{0x3200d831,0xeab00a52,0x6924dd8c,0x00000000}},	//   naky_, رعا_, змда, --, 
   {{0x2fd805b1,0x09d403d4,0x00000000,0x00000000}},	//   _kgpg_, হুনা, --, --, 
   {{0x44e04e53,0x3200dd8b,0xcc8803e6,0xba3c013a}},	//   _rò_, haky_, _بۆئه_, _skůt, 
   {{0x44e0dd8d,0x320005da,0x00000000,0x00000000}},	//   _sò_, kaky_, --, --, 
   {{0x44e0dd8e,0x32000122,0x45d41b04,0x00000000}},	//   _pò_, jaky_, мойс, --, 
   {{0x320009a5,0x787c007f,0xdb200ca8,0x00000000}},	//   daky_, _sève, _èròj, --, 
   {{0x44e0dd8f,0xa3e400dc,0x3200045a,0x00000000}},	//   _vò_, युं_, eaky_, --, 
   {{0x44e00570,0x320005da,0x782400e3,0x68e0022e}},	//   _wò_, faky_, _تعقل, lqod, 
   {{0x44e0110e,0x26dc0810,0x290497d2,0x787c0100}},	//   _tò_, _iuto_, osoa_, _vève, 
   {{0x44e0067c,0x2904dd90,0x26dc4299,0x6ed40b03}},	//   _uò_, nsoa_, _huto_, _मंजु, 
   {{0x26dcdd91,0x290401af,0x98bc07f5,0xc45801fe}},	//   _kuto_, isoa_, _vruć_, _фикх_, 
   {{0xb5fc5946,0xa3e40882,0xcfa4dd92,0x3200dd93}},	//   ljša, युः_, ешти, baky_, 
   {{0x26dcdd94,0x27fc0010,0x539802e4,0xbd4400c6}},	//   _muto_, _letn_, _ליוו, ونزي, 
   {{0xb5fc151c,0x442cdd95,0xd108dd96,0xbc6800e5}},	// [12d70] njša, ofd_, _فقيه_, يجئے_, 
   {{0x26dcdd97,0x442c0117,0x68e04f40,0x7c5800d1}},	//   _outo_, nfd_, dqod, غلار_, 
   {{0x2000dd98,0x290401ee,0x442c0334,0xf428005b}},	//   maji_, esoa_, ifd_, llää_, 
   {{0x39340006,0x00000000,0x00000000,0x00000000}},	//   дэкс, --, --, --, 
   {{0x61fc016d,0x60d401c4,0x12e00046,0xab64000d}},	//   _meql, _kixm, _ﺍﻟﻤﺭ, tküü, 
   {{0x2000dd99,0x320005da,0x442c01f5,0x89a80212}},	//   naji_, zaky_, jfd_, чків_, 
   {{0x60dcdd9a,0x29040607,0xb6a42235,0x200001f7}},	//   _luqm, asoa_, микл, iaji_, 
   {{0x2000dd9b,0x26dc01b2,0x442c0196,0xa3c038d2}},	//   haji_, _duto_, efd_, ्धन_, 
   {{0x2000dd9c,0x32000170,0x442c9638,0x60dcdd9d}},	//   kaji_, vaky_, ffd_, _nuqm, 
   {{0x2000dd9e,0x26dcdd9f,0x60d456c4,0xba04069d}},	//   jaji_, _futo_, _nixm, _ፎር_, 
   {{0x3200dda0,0x61fc0455,0x26dcdda1,0xa82001e2}},	//   taky_, _beql, _guto_, _شکون, 
   {{0x60dc014f,0x442c2694,0x8c480166,0x7ae80118}},	//   _buqm, afd_, _kişä, _četl, 
   {{0x32000170,0x26dc110c,0x76580af9,0x442c0175}},	//   raky_, _zuto_, _inwy, bfd_, 
   {{0x2000dda2,0x32007794,0xd4c40372,0x7648dda3}},	//   gaji_, saky_, _эсеп, ldey, 
   {{0x7528dda4,0x32002f4a,0x64a00e1d,0xc6240eac}},	//   ltez, paky_, _шаша, _মোটা_, 
   {{0x7648dda5,0x00000000,0x00000000,0x00000000}},	//   ndey, --, --, --, 
   {{0x60d4020c,0xdd8c00aa,0x76485dd8,0x00000000}},	// [12d80] _fixm, ټول_, idey, --, 
   {{0x7e7cdda6,0x7528005a,0x764801f4,0xda6c0014}},	//   _elsp, itez, hdey, یُل_, 
   {{0x0a4c001f,0x7658017a,0xdcac15bf,0x00000000}},	//   _በምርጫ, _onwy, جىل_, --, 
   {{0x2904dda7,0xed58dda8,0x26dcdda9,0x8c480166}},	//   tsoa_, _дом_, _ruto_, _bişä, 
   {{0x7648ddaa,0x61f8022c,0x60d40548,0x7528ddab}},	//   ddey, ðuli, _yixm, jtez, 
   {{0x29040f71,0x26dcddac,0x3eac0219,0x60d4026c}},	//   rsoa_, _puto_, čete_, _xixm, 
   {{0x2904ddad,0x752807de,0x7e7c0175,0x6ec000ab}},	//   ssoa_, etez, _ylsp, लतपु, 
   {{0x200000b2,0x26dc0925,0x7648022e,0xf428005b}},	//   zaji_, _vuto_, gdey, ylää_, 
   {{0x26dc020c,0x68e00ba7,0x2000ddae,0x61fc03b9}},	//   _wuto_, qqod, yaji_, _reql, 
   {{0x26dc0316,0x2a6406af,0x76485dd8,0x7658015d}},	//   _tuto_, ljob_, adey, _enwy, 
   {{0x26dc0280,0x442c0d27,0x60dc016d,0x60d4058a}},	//   _uuto_, rfd_, _suqm, _rixm, 
   {{0x20000451,0x60d4002d,0x2a640e78,0x60dc014f}},	//   waji_, _sixm, njob_, _puqm, 
   {{0x2000ddaf,0x26c40418,0x7528ddb0,0x67280217}},	//   taji_, _ihoo_, ctez, ltfj, 
   {{0x55b8011a,0x00000000,0x00000000,0x00000000}},	//   _ומדו, --, --, --, 
   {{0x26c4ddb1,0xd0d400a7,0x61fcddb2,0x60dc0455}},	//   _khoo_, торъ, _teql, _wuqm, 
   {{0x4ea44170,0x2000ddb3,0x60dc047e,0x450c0327}},	//   вруа, saji_, _tuqm, _གྷོར_, 
   {{0x2000ddb4,0x787c067c,0x60d40548,0x20c413d6}},	// [12d90] paji_, _lèva, _tixm, _осог, 
   {{0x3154025f,0x26c4ddb5,0x2a6401f5,0x76480790}},	//   _ניתן_, _lhoo_, ejob_, zdey, 
   {{0x26c46913,0xdb0400e4,0x7528ddb6,0x7648ddb7}},	//   _ohoo_, _hyjú, ztez, ydey, 
   {{0x7f44aa9d,0x26c40099,0x21280204,0x75280023}},	//   _ishq, _nhoo_, otch_, ytez, 
   {{0xd90c4595,0x764803e0,0x13b400eb,0x00000000}},	//   شیا_, vdey, ঁইয়, --, 
   {{0x26c453a3,0x2fc401e4,0xbe1400cf,0x2128378e}},	//   _ahoo_, _ŝogi_, _توڭع, itch_, 
   {{0x26c40810,0x38c800dd,0x764803b2,0x3ce4012d}},	//   _bhoo_, _ہائی_, tdey, _झंडे_, 
   {{0x26c4ddb8,0x7528ddb9,0x7544ddba,0x787c007f}},	//   _choo_, ttez, ениз, _dèva, 
   {{0x26c4ddbb,0x7648ddbc,0x75280077,0xd7740451}},	//   _dhoo_, rdey, utez, _ڪلاڪ_, 
   {{0x7528ddbd,0x3364617b,0x26c4ddbe,0x7f4401b9}},	//   rtez, евог, _ehoo_, _oshq, 
   {{0xe8d40302,0x2128062c,0x00000000,0x00000000}},	//   _נוער_, etch_, --, --, 
   {{0x26c40363,0x75283c6b,0x95b000fd,0x76580142}},	//   _ghoo_, ptez, _ирлә, _unwy, 
   {{0xb5fc00f3,0x7f448186,0x00000000,0x00000000}},	//   ljšo, _ashq, --, --, 
   {{0xd11c03e5,0x38a80030,0xa92008a5,0x20a00121}},	//   भूषण_, túry_, _íþei, лғың, 
   {{0x21280175,0x04543f9f,0x213c031c,0x00000000}},	//   atch_, _جئند, ħuha_, --, 
   {{0xece8ca40,0x2a6400b5,0x38a800d0,0xe1fc03f2}},	//   здал_, xjob_, rúry_, ljón_, 
   {{0xafe40f1a,0xec78ddbf,0x7f44579a,0xbb380092}},	// [12da0] _попл, ппа_, _eshq, _አላየሁ, 
   {{0x2a64ddc0,0xfca800aa,0xe1fc0077,0x00000000}},	//   wjob_, والو_, njón_, --, 
   {{0x3ce405f9,0xe1fc04d4,0x7f440131,0x9d740014}},	//   _झूठे_, ijón_, _иҗра_, وٕہا_, 
   {{0xa9a40aeb,0xa3c00490,0x2efc2959,0xdce805d1}},	//   ниед, ्धत_, âtfu_, _çiğn, 
   {{0x63843386,0x2a647e42,0xe294008f,0x787c033b}},	//   _kéné, rjob_, עכנט_, _sèva, 
   {{0x6d44ddc1,0x26c4ddc2,0xccf40134,0x6728449c}},	//   _iska, _shoo_, mpɛ_, ttfj, 
   {{0x2a642da6,0xdca0301f,0x26c40218,0x6384ddc3}},	//   pjob_, _сари, _phoo_, _méné, 
   {{0xfd54063f,0x21280204,0x638400e8,0x67282268}},	//   _nkaọ, ytch_, _léné, rtfj, 
   {{0x67280008,0x00000000,0x00000000,0x00000000}},	//   stfj, --, --, --, 
   {{0xfd5402e3,0x63849d97,0x2c740174,0xb5fc0427}},	//   _akaọ, _néné, _bædi_, ljšl, 
   {{0x7ae856af,0x26c40493,0x2c1c00e1,0x6e240c8c}},	//   _četk, _thoo_, _पाईं_, _ockb, 
   {{0x6d44ddc4,0x09d403f4,0x51f8005b,0x00000000}},	//   _oska, _হ্যা, ннюю_, --, 
   {{0x6384ddc5,0x25a40472,0x21280268,0x6d44003b}},	//   _béné, _uxol_, utch_, _nska, 
   {{0x6600ddc6,0x63840066,0x6e2414dc,0x8c080c58}},	//   _heok, _céné, _ackb, ৰ্তন_, 
   {{0x6d44ddc7,0x660018a6,0x64487dcd,0x63840066}},	//   _aska, _keok, _iafi, _déné, 
   {{0x6264ddc8,0xceb80640,0xfe7001d3,0x00000000}},	//   _سابق, ељу_, گدڑ_, --, 
   {{0x6448ddc9,0x660000fb,0x638400e8,0x6d44005a}},	// [12db0] _kafi, _meok, _féné, _cska, 
   {{0x63842047,0x66004d11,0x35a01e38,0x644806d9}},	//   _géné, _leok, _ውድቀት_, _jafi, 
   {{0x6d44152d,0x7f44044e,0xa3c0b500,0x5ba452c0}},	//   _eska, _ushq, ्धि_, храз, 
   {{0x6448ddca,0xed4c0050,0x00000000,0x00000000}},	//   _lafi, _ژھل_, --, --, 
   {{0x63841bce,0x00000000,0x00000000,0x00000000}},	//   _yéné, --, --, --, 
   {{0xa3c092c2,0xfb340323,0x2c1c0034,0x080800d1}},	//   ्धा_, _ингэ, _पाएं_, ىزىي_, 
   {{0x660000f3,0x7ae40175,0xdb040248,0x00000000}},	//   _beok, qqht, _àlàf, --, 
   {{0x6448096b,0x6d44ddcb,0x55c057aa,0x2ae4134e}},	//   _aafi, _yska, лайғ, _जंतु_, 
   {{0x6448ddcc,0x95b0035b,0xa2b4043e,0xa4880023}},	//   _bafi, ыркә, ैतन्, _ንብዘሎ_, 
   {{0x644801d9,0x855404fb,0xe0dc02e2,0xd3441176}},	//   _cafi, ایور_, kwòb_, فیته_, 
   {{0x6448ddcd,0x660006d9,0x00000000,0x00000000}},	//   _dafi, _feok, --, --, 
   {{0x6384ddce,0xe1fc0ad9,0x629c0241,0x00000000}},	//   _séné, sjón_, _ìpol, --, 
   {{0x6448ddcf,0x63845725,0xe56c22c3,0x21640107}},	//   _fafi, _péné, _тз_, вияи_, 
   {{0x6448ddd0,0x450c0327,0x61400063,0x00000000}},	//   _gafi, _གྷིར_, јера, --, 
   {{0x5f00ddd1,0x66000472,0x63849d74,0x6d44022e}},	//   изра, _yeok, _véné, _sska, 
   {{0x6448ddd2,0xed58ddd3,0xb5fc00de,0x00000000}},	//   _zafi, моб_, ekšz, --, 
   {{0x1d04ddd4,0x64489748,0xfd1000dd,0x37d4015b}},	// [12dc0] кети_, _yafi, یجے_, _স্মর, 
   {{0x6448ddd5,0x6bd403e6,0x2bc41a4e,0xe1fc0aab}},	//   _xafi, نتار, _वरदा, hjól_, 
   {{0x6d44068f,0xe1fc1427,0x62840419,0x00000000}},	//   _wska, kjól_, ďkov, --, 
   {{0x6d440198,0xace802a9,0x6e2403ac,0x66e80210}},	//   _tska, _омма_, _uckb, _nęka, 
   {{0x6d44ddd6,0x6600ddd7,0x3d180cb4,0x00000000}},	//   _uska, _reok, _पिये_, --, 
   {{0x6600ddd8,0x3c0401d9,0x3cd401b9,0xa2580af9}},	//   _seok, _مظفّ, _бўст, nmôr, 
   {{0x6448ddd9,0x37d400bd,0x7c6c001f,0xa098010f}},	//   _rafi, _স্বর, _በዛሬው_, ויסט, 
   {{0xdb0401e1,0x57e40304,0x3ab400f3,0x26884cec}},	//   _àláf, ндәм_, _бљут, بختي_, 
   {{0x7ae80bb8,0xd9407de3,0x6448ddda,0x660000c5}},	//   _četi, _кети, _pafi, _veok, 
   {{0x3e740158,0x6600009a,0x545000c9,0x32100332}},	//   _hått_, _weok, авьт, _adyy_, 
   {{0x6600dddb,0xd6ccdddc,0x64481640,0x846800fd}},	//   _teok, _вт_, _vafi, _үзең_, 
   {{0x92581c22,0xa3e44728,0x6aa0dddd,0x00000000}},	//   вают_, युज_, nnof, --, 
   {{0x6448ddde,0x3e7401e6,0xf6081056,0xdb1c02d2}},	//   _tafi, _mått_, _ستنه_, _óvör, 
   {{0x84380597,0x3e7405ac,0x939020e8,0x64980212}},	//   _أكثر_, _lått_, اجیا, _ютер_, 
   {{0x61f8022c,0x6aa0dddf,0xd36c0107,0x00000000}},	//   ðuls, knof, _тч_, --, 
   {{0x3e74049f,0x6aa00115,0x13000116,0x00000000}},	//   _nått_, jnof, _өзәм, --, 
   {{0x6aa0dde0,0x5084004b,0xa3c037bb,0x62300117}},	// [12dd0] dnof, _چاپې, ्धव_, _беқу, 
   {{0x1ac80303,0x041403f4,0x5084004b,0x6738dde1}},	//   िष्ठ, ত্রী_, _ناپې, _optj, 
   {{0x787c0100,0xdef8013d,0x00000000,0x00000000}},	//   _sèvo, _юып_, --, --, 
   {{0x6aa0a368,0x00000000,0x00000000,0x00000000}},	//   gnof, --, --, --, 
   {{0x3eb80472,0x66e80034,0x0d6400a7,0xcca401e4}},	//   _ikst_, _ręka, _кърм, stiց, 
   {{0x7d0cdde2,0x6aa0dde3,0xc8c81e5a,0x3de40154}},	//   msas, anof, نونن_, _ফজিল, 
   {{0x3e74b2e3,0x7d0cdde4,0xca7c01a9,0x4c942c25}},	//   _fått_, lsas, _aprе, _тирс, 
   {{0x3e741121,0x6aa0026c,0x7d0cdde5,0x7c24286e}},	//   _gått_, cnof, osas, lghr, 
   {{0x673800fb,0xb5fc09a8,0x00000000,0x00000000}},	//   _eptj, ljšk, --, --, 
   {{0x7c24dde6,0x7d0cdde7,0x00000000,0x00000000}},	//   nghr, isas, --, --, 
   {{0xb9d00201,0x7c24007b,0x7d0c0066,0x00000000}},	//   _ስራ_, ighr, hsas, --, 
   {{0x7c2401e7,0x00000000,0x00000000,0x00000000}},	//   hghr, --, --, --, 
   {{0xd5b802d5,0x7d0c01f5,0x108401d5,0xe44c01c6}},	//   _ўсе_, jsas, иғиг, _лж_, 
   {{0x20cc0327,0xc484177b,0x65980a1e,0x6aa000d7}},	//   _bżiq_, _клік, _אינק, znof, 
   {{0x6fb4dde8,0xa5c00008,0x37d40154,0x6aa002f0}},	//   امزا, _þórs, _স্তর, ynof, 
   {{0xb2241d83,0x7d0c058a,0xa3c0dde9,0x6aa00175}},	//   _смил, fsas, ्धर_, xnof, 
   {{0x7d0cddea,0x3e7411ad,0x6aa00010,0x61f80de2}},	// [12de0] gsas, _rått_, vnof, ñule, 
   {{0x3e74007c,0xb5fc00c0,0x00000000,0x00000000}},	//   _sått_, rkšy, --, --, 
   {{0x7d0c3510,0xe478008f,0x6aa00175,0x81e40154}},	//   asas, ערעכ, tnof, _পড়ি_, 
   {{0x7d0c0014,0x6aa00433,0x89d812ea,0x7c244230}},	//   bsas, unof, پوتر_, aghr, 
   {{0x7d0cddeb,0x3e7478d0,0x7d740014,0x00000000}},	//   csas, _vått_, _پۅلر_, --, 
   {{0x7ae80bb8,0x81e4015b,0x18640b3e,0x7c243e79}},	//   _četv, _পড়া_, лачи_, cghr, 
   {{0x920400bc,0xd1e801f3,0xb8940092,0x00000000}},	//   लराज_, ማራት_, ግለጫው_, --, 
   {{0x8c081c82,0x00000000,0x00000000,0x00000000}},	//   ৰ্শন_, --, --, --, 
   {{0x2b48045a,0xa9a40166,0x00000000,0x00000000}},	//   _hsbc_, _сиад, --, --, 
   {{0x66e4ddec,0x00000000,0x00000000,0x00000000}},	//   _божа, --, --, --, 
   {{0xd7ec0597,0x7d0c01d3,0x3e6c01d3,0x23cc466d}},	//   _ركن_, zsas, _hűtő_, हेंद, 
   {{0x7d0cdded,0x0cb007af,0x225c2e65,0xeb00000d}},	//   ysas, जकुम, ñuk_, _लबैत_, 
   {{0x51841241,0x7d0c0009,0x00000000,0x00000000}},	//   бура, xsas, --, --, 
   {{0xe8c00327,0x7d0c0162,0x00000000,0x00000000}},	//   _ཞེསག, vsas, --, --, 
   {{0x1ee4034c,0x7d0c3d07,0x322801f4,0x00000000}},	//   اوری_, wsas, ätyö_, --, 
   {{0x7d0cddee,0x3df4ddef,0x24500133,0x66e80210}},	//   tsas, рзас, _ئۆگس, _lęko, 
   {{0x61ecddf0,0x7d0cddf1,0x628c007f,0x4fcc0150}},	// [12df0] mccl, usas, èbou, _ﻓﻜﹼﻤ, 
   {{0x7d0cddf2,0x6f0c0175,0x00000000,0x00000000}},	//   rsas, bsbc, --, --, 
   {{0x7d0cddf3,0x645c01ab,0x9f50005c,0x7c24ddf4}},	//   ssas, _òpiu, _nexø_, rghr, 
   {{0x3eb80472,0x7c2400c6,0x7d0cddf5,0xd3540375}},	//   _ukst_, sghr, psas, טיבי_, 
   {{0x7ae809a8,0x7e6c009f,0x0dc8020f,0x7d0cddf6}},	//   _četu, mjap, _бури_, qsas, 
   {{0x7e6c007d,0x98148e42,0x00000000,0x00000000}},	//   ljap, ابشا, --, --, 
   {{0xb5fc151c,0x7e6c04ce,0xeab0002e,0x00000000}},	//   ljši, ojap, àññi_, --, 
   {{0x7e6cddf7,0x629c01e1,0x38bc00b8,0x00000000}},	//   njap, _ìpoh, _ṣrī_, --, 
   {{0x348407d6,0xb5fc09a8,0xb4a8036b,0x7e6c00e4}},	//   игиг, njši, ккиз_, ijap, 
   {{0x4974ddf8,0xa3c00882,0xe2040005,0x7e6cddf9}},	//   _улус, ्धं_, ñóns_, hjap, 
   {{0x61ec0354,0x06840228,0xc168011a,0x00000000}},	//   fccl, ргөн, _קח_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3eac00bc,0xefe80092,0x7e6cddfa,0x12e00046}},	//   četl_, _ቆመው_, djap, _ﺍﻟﻌﺭ, 
   {{0x057465a2,0x8c480139,0x408401e0,0x25180677}},	//   _دامد, _meşç, йҙым_, _יונא, 
   {{0xa064ddfb,0xb4c02274,0xa3c00882,0x61f80113}},	//   шара_, ंती_, ्धः_, ñulc, 
   {{0x394802fb,0xb7fc009e,0x7e6cddfc,0x00000000}},	//   ťasy_, ীলিত_, gjap, --, 
   {{0xc8780139,0x6cd4007b,0x13a400f1,0xf1d001af}},	// [12e00] _liğa_, لقرا, _جنګی_, _фөнө, 
   {{0x80cc0550,0x7e6c0108,0xabf40108,0xa17800df}},	//   _दीपे, ajap, рчащ, _סטיט, 
   {{0x66e8033f,0x92e403d4,0x7e6c0055,0x00000000}},	//   _ręko, মীৰ_, bjap, --, 
   {{0xb4c034ef,0x7e6cddfd,0x09e40011,0x00000000}},	//   ंतु_, cjap, মর্থ, --, 
   {{0x6844ddfe,0xe6d80321,0xabe801d9,0x12e00220}},	//   инда, ðsíð, _لرزٕ_, _ﺍﻟﻔﺭ, 
   {{0x57f01b6b,0x98b40024,0x98a0011c,0x00000000}},	//   општ, аліт_, оиче, --, 
   {{0xc6f80063,0x00000000,0x00000000,0x00000000}},	//   ћних_, --, --, --, 
   {{0xdb0401a8,0x8ac801b9,0x00000000,0x00000000}},	//   _eyjó, _ёқда_, --, --, 
   {{0xe5c407d5,0xb4c00073,0x09d40154,0x00000000}},	//   шско, ंतू_, _হ্রা, --, 
   {{0xd5f0074d,0x00000000,0x00000000,0x00000000}},	//   _чiог, --, --, --, 
   {{0x947006d5,0x7e6c0054,0x00000000,0x00000000}},	//   تديا, yjap, --, --, 
   {{0x26d001e1,0x00000000,0x00000000,0x00000000}},	//   _òyo_, --, --, --, 
   {{0xc55400f1,0x61ec03ac,0x355400ec,0x00000000}},	//   _دعاګ, rccl, _هروڀ, --, 
   {{0x7e6c0334,0x40340063,0xdfa400d8,0x00000000}},	//   wjap, љевс, ајбо, --, 
   {{0x9e042bbd,0x7e6cddff,0x68280023,0x00000000}},	//   ичал, tjap, ተሓሳስ, --, 
   {{0xdc0ca3c6,0x3d94de00,0x00000000,0x00000000}},	//   ाण्ड_, бибр, --, --, 
   {{0x425400aa,0x7e6cb6a5,0x81c003cc,0x0e08084c}},	// [12e10] _ننګر, rjap, _رەسۇ, рэси_, 
   {{0xfd4c01dc,0x91bc0302,0xe1fc004e,0x7e6c03cd}},	//   _khoả, _במחי, lbó_, sjap, 
   {{0x7e680428,0xd1b83267,0x00000000,0x00000000}},	//   _òepo, _مایا_, --, --, 
   {{0xbe2401d5,0xca7400d1,0x00000000,0x00000000}},	//   _учоқ, يانغ, --, --, 
   {{0x09e403d4,0x3cf000cc,0x00000000,0x00000000}},	//   মৰ্থ, _চিক্_, --, --, 
   {{0x6d9c0327,0xd0f8011a,0x00000000,0x00000000}},	//   _dħaħ, סמות_, --, --, 
   {{0x281000ae,0x00000000,0x00000000,0x00000000}},	//   سويس, --, --, --, 
   {{0x9a840166,0xc6680114,0x00000000,0x00000000}},	//   _тугл, ишње_, --, --, 
   {{0x8508de01,0x3914010b,0x588400cf,0x068400d1}},	//   адың_, _ымар, _кыжа, ﻪﺳﻠﯩ, 
   {{0xb4c0578b,0xd1e8069d,0x81e40154,0x00000000}},	//   ंते_, ማያት_, _পড়ল_, --, 
   {{0x3754004b,0xfd4c0051,0x566400f2,0x35a40022}},	//   _دپاس, _choả, _پداف, раҿг, 
   {{0x05980214,0xeb38008f,0x6b9800a2,0x6d5400e4}},	//   امیک_, נערש, _ýtge, yvya, 
   {{0x61f80de2,0xe29404b1,0x00000000,0x00000000}},	//   ñula, сая_, --, --, 
   {{0xa3b005f9,0xb63001ec,0x00000000,0x00000000}},	//   _झुक_, _ﺑﻪ_, --, --, 
   {{0xe1fc011f,0x437402a9,0x3cf003d4,0x6ec4009a}},	//   bbó_, _муът, _চিগ্_, مترق, 
   {{0x3a2c003e,0x00000000,0x00000000,0x00000000}},	//   _ncep_, --, --, --, 
   {{0xde0001b9,0xe1fc012d,0xe1f40139,0x9320009f}},	// [12e20] япти, ejów_, _угы_, _ارڙن, 
   {{0x7ae8de02,0xada40364,0x3a2cde03,0x7e2006ab}},	//   _četr, _ҳамл, _acep_, यलॉग_, 
   {{0x394c35f5,0xb5fc151c,0x60d80375,0x6d9c031c}},	//   _ases_, ljšu, _תקינ, _sħaħ, 
   {{0xace8de04,0xa25800d2,0x6da42ced,0x29840137}},	//   _مرسل_, hlôn, _гима, йылг, 
   {{0x394c0327,0xb5fc09a8,0x291000d2,0x1e54011a}},	//   _cses_, njšu, éya_, _השכר_, 
   {{0xec1406ad,0x8858de05,0x58340816,0x00000000}},	//   _دوسد, рикс_, йзія_, --, 
   {{0x394c172e,0xe1fc0548,0x00000000,0x00000000}},	//   _eses_, ybó_, --, --, 
   {{0x44f44205,0x33e402dd,0x30f800dc,0x00000000}},	//   опис, _ﺍﺯﺍﻣ, ्ठाः_, --, 
   {{0x7a940244,0x00000000,0x00000000,0x00000000}},	//   _بێنز_, --, --, --, 
   {{0xfd4c0055,0xdd14013d,0x00000000,0x00000000}},	//   _choṣ, _läşt, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa50826b1,0xa6c800ee,0xe5c800fb,0x00000000}},	//   _беда_, _ёлда_, _йылл_, --, 
   {{0x787c0d29,0xe1fcde06,0x5184de07,0xd654011a}},	//   _sèvi, rbó_, пура, _ליאת_, 
   {{0xfd4cde08,0xe1fc011f,0x83f800d8,0xcff402e8}},	//   _thoả, sbó_, _текс_, зпръ, 
   {{0x443c15b2,0x10a4013e,0x249c0175,0x43942cdd}},	//   _ibv_, чиён, mitm_, _файс, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe29c1c38,0x108800f7,0xdd140139,0x7e2000af}},	// [12e30] mið_, рөөк_, _däşt, यलौग_, 
   {{0xe29c19cf,0x3a2c0393,0x443c0fac,0xb5fc0841}},	//   lið_, _scep_, _jbv_, ljšt, 
   {{0xda78242f,0x443c01a4,0xebc00166,0x41b4411c}},	//   ляд_, _mbv_, дәтн, _دمکر, 
   {{0x02c87e7c,0xe29c26b8,0xca740046,0x443c01e4}},	//   रतिभ, nið_, зушы, _lbv_, 
   {{0x3ea8de09,0x443c01f5,0x37e401c6,0x00000000}},	//   mnat_, _obv_, оолг, --, 
   {{0x3ea8de0a,0xdde807d6,0x00000000,0x00000000}},	//   lnat_, _جرگه_, --, --, 
   {{0xe29cb41c,0x3ea876c0,0xf77001eb,0xa6f00116}},	//   kið_, onat_, ظات_, үзәш, 
   {{0x3ea8de0b,0x66e00395,0x00000000,0x00000000}},	//   nnat_, моща, --, --, 
   {{0xe29c09cc,0x3ea8de0c,0x394cde0d,0xe0dc02e2}},	//   dið_, inat_, _uses_, twòl_, 
   {{0x3ea8de0e,0x443c00d8,0xa4d40640,0x628c017a}},	//   hnat_, _cbv_, одњу_, ëbon, 
   {{0xe29c00fc,0x3ea8de0f,0xc86407d6,0x443c0af9}},	//   fið_, knat_, _этти, _dbv_, 
   {{0xe29c19cf,0xe0dc007f,0x3ea8036e,0x00000000}},	//   gið_, swòl_, jnat_, --, 
   {{0x3ea8012c,0x95c8014b,0x00000000,0x00000000}},	//   dnat_, _сужа_, --, --, 
   {{0x3ea8003a,0x0444de10,0x4094009b,0x998c0153}},	//   enat_, _неін, прст, legų_, 
   {{0xc34007d5,0xe29c03b2,0x00000000,0x00000000}},	//   _пĕр_, bið_, --, --, 
   {{0x850007f7,0x437408ca,0xfc5c0092,0xdb040248}},	//   लीकट_, _хушт, _ለማገል, _àlùf, 
   {{0xac08de11,0xada4c8a6,0xad680022,0x00000000}},	// [12e40] инаа_, цаал, шааз_, --, 
   {{0x3ea8de12,0x6b581621,0x00000000,0x00000000}},	//   anat_, ишер_, --, --, 
   {{0x097800f7,0x3ea80334,0xeab801c6,0x00000000}},	//   өрдө_, bnat_, айж_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa8501cd1,0x249c00b5,0xda080412,0x00000000}},	//   делә, yitm_, _हजरत_, --, 
   {{0x9f50011f,0x1d0400d8,0x00000000,0x00000000}},	//   _gexó_, _фери_, --, --, 
   {{0x443c00f3,0xa3dc0b6d,0xc8780139,0x5ebc00eb}},	//   _rbv_, _दृढ_, _wiğo_, ্দরে, 
   {{0xe8f87621,0x443c00cd,0xe29c0162,0x85740395}},	//   _вла_, _sbv_, xið_, злих, 
   {{0xe29c2bde,0x95d400a7,0x00000000,0x00000000}},	//   við_, одът_, --, --, 
   {{0x443c0051,0xdd0000cd,0x00000000,0x00000000}},	//   _qbv_, _śrīk, --, --, 
   {{0xe29c6984,0x249cde13,0x3ea8de14,0x628c00e8}},	//   tið_, ritm_, ynat_, ëboo, 
   {{0xe61046ca,0x0a480092,0x32d801d9,0x3ea801a9}},	//   _آشا_, _መምሪያ, ٝدُک_, xnat_, 
   {{0xe29c08d2,0x3ea80316,0x443c01a4,0x92580395}},	//   rið_, vnat_, _tbv_, цаят_, 
   {{0xe29c1bb0,0xddcc0356,0xfc5c0092,0x00000000}},	//   sið_, _locţ, _ለማጎል, --, 
   {{0x3f8403c6,0x4fc44d56,0xe29c09cc,0x3ea8de15}},	//   álu_, дста, pið_, tnat_, 
   {{0x442cde16,0xce680212,0x3ea8de17,0x3f840135}},	//   lgd_, оруд_, unat_, ġlu_, 
   {{0x442c0196,0x628c0369,0x3f84560e,0x3d9400a8}},	// [12e50] ogd_, mhco, šlu_, чиар, 
   {{0x442cde18,0x4d980006,0x39a000b5,0xc104013e}},	//   ngd_, цкую_, _læsø_, _мӯҳл, 
   {{0x5ba400c7,0x442cde19,0xa25800d2,0x3ea8de1a}},	//   цраз, igd_, hlôm, pnat_, 
   {{0x628c004d,0xf77000e5,0x00000000,0x00000000}},	//   nhco, ہاب_, --, --, 
   {{0x7d0001e1,0xe1fc438d,0x7e980451,0xc87806be}},	//   _dárò, ljós_, _ننگر_, _boğ_, 
   {{0xd8380024,0x00000000,0x00000000,0x00000000}},	//   рэд_, --, --, --, 
   {{0xc8780205,0x00000000,0x00000000,0x00000000}},	//   _doğ_, --, --, --, 
   {{0x442c2d2d,0x672400c7,0x61f80784,0xb89401d3}},	//   egd_, _ẽmív, ñull, _کارڈ, 
   {{0x25f0000d,0xa5f40063,0x00000000,0x00000000}},	//   ीरजी_, чењу_, --, --, 
   {{0x970004a9,0x442c01e6,0xd34401b9,0x278805a2}},	//   _قېتى, ggd_, قیته_, ррәү_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x442c0936,0xe294de1b,0x32000118,0xd5f0074d}},	//   agd_, заю_, ubky_, _чiаг, 
   {{0x76480a81,0x442c00f3,0xd5b80b87,0x80cc00c5}},	//   meey, bgd_, _тсж_, _दीहे, 
   {{0x76487490,0x71680022,0xe1fc02d2,0x00000000}},	//   leey, _ҳаиг_, fjós_, --, 
   {{0x75280311,0x00000000,0x00000000,0x00000000}},	//   luez, --, --, --, 
   {{0x7648de1c,0x75280165,0xab6400d1,0x00000000}},	//   neey, ouez, үвал, --, 
   {{0xdcac1066,0x76480076,0x7528054e,0xb4f8010f}},	// [12e60] گىل_, ieey, nuez, מפּי, 
   {{0x76489fb9,0xddc8de1d,0x720400f2,0x00000000}},	//   heey, şişl, _بوکم, --, 
   {{0x76480050,0xdcac0c50,0x6fd803d4,0x00000000}},	//   keey, دىل_, _ব্ৰে, --, 
   {{0x5f741afc,0xe9d8023a,0x76482215,0xa110411c}},	//   _راپر, бке_, jeey, _تویت, 
   {{0x442cde1e,0x7648c0a0,0x00000000,0x00000000}},	//   ygd_, deey, --, --, 
   {{0x7528005a,0x3b440092,0x9ac00003,0xd9d0129d}},	//   duez, _የጋምቤ, ċċaq, رەلگ, 
   {{0x6b6492b5,0x76480014,0x98100345,0x00000000}},	//   _эква, feey, ربوا, --, 
   {{0x7648de1f,0x00000000,0x00000000,0x00000000}},	//   geey, --, --, --, 
   {{0x7528de20,0x49940214,0xe4c40006,0xd61416ac}},	//   guez, _تیشر, зённ, ستيا_, 
   {{0x6aa0de21,0x442c0d27,0x7ce80024,0x00000000}},	//   liof, ugd_, _užre, --, 
   {{0x442cde22,0x7648de23,0x43940a5b,0xe1fc0174}},	//   rgd_, beey, фанс, djór_, 
   {{0x6aa001e4,0xa25820ef,0x7648de24,0x628c0369}},	//   niof, plôm, ceey, uhco, 
   {{0xd62402bf,0x75280356,0x42c8004e,0x00000000}},	//   _хоче_, cuez, йгүн_, --, 
   {{0x628c0076,0x6aa01682,0xe1fc35f5,0x00000000}},	//   shco, hiof, tjós_, --, 
   {{0x543800c8,0xc01400c5,0x1470085b,0x00000000}},	//   _לעגא, _छलs_, _ساوج, --, 
   {{0xd2580276,0x00000000,0x00000000,0x00000000}},	//   _ець_, --, --, --, 
   {{0x629c01f0,0x22487805,0xbc785159,0x80b40108}},	// [12e70] _imqo, meck_, обах_, _обих, 
   {{0x8d74278f,0x2248de25,0x2128016d,0x787c5725}},	//   راقا, leck_, much_, _lèvr, 
   {{0x2128de26,0x6aa020d6,0x7648de27,0x19a829db}},	//   luch_, fiof, yeey, әтеп_, 
   {{0x76480050,0x21280165,0x00000000,0x00000000}},	//   xeey, ouch_, --, --, 
   {{0x212804c4,0x22480ade,0x76481418,0x5c042bb6}},	//   nuch_, ieck_, veey, _нява, 
   {{0x7648de28,0x3eac0e3c,0xf744026b,0x00000000}},	//   weey, četu_, деко, --, 
   {{0x629c0117,0x7648de29,0x2128de2a,0x9e70001f}},	//   _omqo, teey, huch_, _የሙስና_, 
   {{0x2248039a,0x3a7401b9,0x21280036,0x7528de2b}},	//   jeck_, _ўлар, kuch_, tuez, 
   {{0x7648de2c,0xb34403b7,0x7d2800ac,0x453400c0}},	//   reey, _opçã, əssü, нхэт, 
   {{0x2128de2d,0x7648de2e,0x629c0117,0xdefc003d}},	//   duch_, seey, _amqo, ċċju_, 
   {{0x22480204,0x7648062c,0xa2640153,0x00000000}},	//   feck_, peey, _dėžę_, --, 
   {{0x76480050,0x22480204,0xf7f40014,0x71a4010b}},	//   qeey, geck_, _رٲچھ, дамз, 
   {{0x212801e4,0x00000000,0x00000000,0x00000000}},	//   guch_, --, --, --, 
   {{0x629c2798,0x6aa00099,0x00000000,0x00000000}},	//   _emqo, ziof, --, --, 
   {{0xae78de2f,0xe4d40244,0x5ec400cc,0x714000db}},	//   осах_, _تووت_, লগনে, رۉگۅ, 
   {{0x2128de30,0xee380953,0x712400db,0x00000000}},	//   buch_, ўна_, _قىبم, --, 
   {{0xec78de31,0xb80c05f9,0x6aa001e4,0x00000000}},	// [12e80] опа_, हराम_, viof, --, 
   {{0xdcac6886,0x00000000,0x00000000,0x00000000}},	//   لىق_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfbd01b56,0xb864485f,0xe874210e,0x00000000}},	//   پتە_, کانو, ِاعظ, --, 
   {{0x6aa0de32,0xec14de33,0xf8140131,0x787c59cc}},	//   siof, _زورد, ىسىگ, _sèvr, 
   {{0xe7bc2b1b,0x752c01e4,0x21281a5d,0x61f802d1}},	//   েখ্য, _ĥaza, zuch_, ñulk, 
   {{0x26c0025a,0x59a00092,0x00000000,0x00000000}},	//   ôko_, ላላችሁ_, --, --, 
   {{0xc8780205,0x672801a9,0x2248007c,0xb4b801f9}},	//   _liği_, sufj, veck_, चवू_, 
   {{0x22485cf5,0x200400d8,0x212801a9,0x00000000}},	//   weck_, _ônix_, vuch_, --, 
   {{0x22482ad7,0xe8c80490,0xa2640064,0x78bc0a87}},	//   teck_, ितीच, _vėžę_, _ísva, 
   {{0x2128de34,0x6d44de35,0x15cc0150,0x51f80108}},	//   tuch_, _opka, _ﮔﻪﺩﻩ, мнюю_, 
   {{0x2248de36,0x7ce80306,0x19b800df,0x00000000}},	//   reck_, _ožra, ַמלב, --, 
   {{0x2128de37,0x557404ac,0x3dcc003d,0x7028025c}},	//   ruch_, _קעגן_, _ġew_, _སྐྱུ_, 
   {{0x2128de38,0x6d44de39,0x2248017a,0x32d801d5}},	//   such_, _apka, peck_, تدیک_, 
   {{0x6458de3a,0x6560de3b,0x629c1449,0xad240014}},	//   ldti, _kroh, _umqo, کرٲو, 
   {{0x645805da,0x7dc40736,0x2128016d,0xd48401c6}},	// [12e90] odti, رقطن, quch_, _хөөж_, 
   {{0x450000fe,0x00000000,0x00000000,0x00000000}},	//   _এটাক_, --, --, --, 
   {{0x7028031c,0x00000000,0x00000000,0x00000000}},	//   _སྐྲུ_, --, --, --, 
   {{0x60d402c4,0x6560de3c,0xf8b800dc,0x3eac002e}},	//   _hhxm, _oroh, ेत्प, _ñet_, 
   {{0x7e7c1662,0x0dc823c5,0x00000000,0x00000000}},	//   _iosp, _жури_, --, --, 
   {{0xf7f401b9,0x00000000,0x00000000,0x00000000}},	//   رستد, --, --, --, 
   {{0x6560de3d,0x69c40212,0x7e7c0ea0,0xdb2001a9}},	//   _aroh, _øken, _kosp, _جوزی, 
   {{0x6458002d,0xca240408,0x6560de3e,0x7e7cde3f}},	//   edti, _аффи, _broh, _josp, 
   {{0x7e7c0023,0x87d40214,0x8a6402f2,0x00000000}},	//   _mosp, _یغما, _جێنۆ, --, 
   {{0x7e7cde40,0x6560de41,0xb4b81b57,0x645801a4}},	//   _losp, _droh, चवे_, gdti, 
   {{0x7ae80006,0x7e7c020c,0x6560de42,0x00000000}},	//   _kiet, _oosp, _eroh, --, 
   {{0x7e7c00da,0x656017da,0x64580175,0xb5941d0f}},	//   _nosp, _froh, adti, _пиеш, 
   {{0x7ae8de43,0xdbd801e1,0x00000000,0x00000000}},	//   _miet, _lààk, --, --, 
   {{0x7ae8de44,0x76580042,0xb9f80092,0x3438010f}},	//   _liet, _hawy, _ህጉ_, _זײַע, 
   {{0xd58404d3,0x7ae84fbb,0x00000000,0x00000000}},	//   _رێگه_, _oiet, --, --, 
   {{0x7ae8de45,0xd16407d6,0x00000000,0x00000000}},	//   _niet, _аниқ, --, --, 
   {{0x7e7cdc11,0x3ea4020c,0xa2ac09fa,0x00000000}},	// [12ea0] _dosp, èlta_, ीवर्, --, 
   {{0x3210de46,0x7ae8de47,0x7658de48,0x00000000}},	//   _heyy_, _aiet, _lawy, --, 
   {{0x7ae8de49,0xa09800c8,0x7d080139,0x00000000}},	//   _biet, _זייט, _çesn, --, 
   {{0x7ae8de4a,0x7e7cde4b,0xe9d8de4c,0x78a002d0}},	//   _ciet, _gosp, пке_, _amlv, 
   {{0x8a04010b,0xd8f400d4,0x296000c7,0x9e600024}},	//   езҗе, енії_, ыҭаҭ, _свяд, 
   {{0x7658039a,0x7ae80ea0,0xe8c80073,0x7e7c0419}},	//   _aawy, _eiet, ितेच, _zosp, 
   {{0x7ae8de4d,0xdd8c168d,0x7ce80006,0x7e7c02d0}},	//   _fiet, _نوێ_, _užra, _yosp, 
   {{0x7ae8de4e,0xd6d4c583,0x6560de4f,0x1ae012d7}},	//   _giet, нты_, _proh, _босм, 
   {{0xa9087146,0xe4a40dbb,0xe5707146,0x3d186c95}},	//   _ريال_, ерно, اطع_, _पिछे_, 
   {{0xd918025f,0x7ae8de50,0x02c800dc,0xc3c400cf}},	//   _מומל, _ziet, रत्न, көйл, 
   {{0x6458de51,0x7ae80399,0x00000000,0x00000000}},	//   rdti, _yiet, --, --, 
   {{0x2738044e,0x4ec40154,0x00000000,0x00000000}},	//   mën_, ্দুল, --, --, 
   {{0x7e7cc9a7,0x2738044e,0x26c40270,0x1a9800c8}},	//   _rosp, lën_, _ikoo_, ליטע, 
   {{0x81c400bd,0xdbd80241,0x84c42f89,0x76580210}},	//   ৌশল_, _làák, _шәйд, _zawy, 
   {{0x2738069c,0x7e7cde52,0x7658de53,0xb4b40032}},	//   nën_, _posp, _yawy, _шишә, 
   {{0x7e7cbc0f,0xddcc0210,0x00000000,0x00000000}},	//   _qosp, _racł, --, --, 
   {{0x7ae8de54,0x2738044e,0xd7a400cd,0x7e7c0139}},	// [12eb0] _riet, hën_, _केनच, _vosp, 
   {{0x2738044e,0x7ae8de55,0xe8000316,0xd140012d}},	//   kën_, _siet, रुमा_, żący_, 
   {{0x201002c4,0x2738044e,0x26c40241,0xd90c0133}},	//   _iexi_, jën_, _okoo_, ڵیا_, 
   {{0x273802d3,0xdb04032e,0x00000000,0x00000000}},	//   dën_, _álíf, --, --, 
   {{0x7ae8de56,0x2738de57,0xddcc0210,0x00000000}},	//   _viet, eën_, _wacł, --, 
   {{0x7658de58,0x26c403a0,0x27380eb5,0x49b89f6d}},	//   _sawy, _akoo_, fën_, راند_, 
   {{0x7ae8de59,0x2738044e,0xdbd80248,0x20100798}},	//   _tiet, gën_, _fàák, _mexi_, 
   {{0x20100c11,0x7bd4de5a,0x7ae83c7e,0x0f58011a}},	//   _lexi_, _izzu, _uiet, תיהם_, 
   {{0x78bc02d2,0x00000000,0x00000000,0x00000000}},	//   _ísvo, --, --, --, 
   {{0x2010003a,0x76580af9,0x7804013e,0x2738a814}},	//   _nexi_, _wawy, _рӯда, bën_, 
   {{0x273802d3,0x00000000,0x00000000,0x00000000}},	//   cën_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe29410b6,0x601c0139,0x4974010a,0xe44cb7c8}},	//   тая_, _oçmı, _улăс, _кж_, 
   {{0x326401c6,0x656401bf,0x30a001d5,0x00000000}},	//   хтүв, ækhe, рғоғ, --, 
   {{0x7d1c009a,0x2010002e,0xc0580006,0x7528002f}},	//   _avss, _dexi_, хіў_, lrez, 
   {{0x601c06b9,0x7528de5b,0x00000000,0x00000000}},	//   _açmı, orez, --, --, 
   {{0xdee0de5c,0x7bd48dfb,0x7528de5d,0x2738044e}},	// [12ec0] роти, _azzu, nrez, zën_, 
   {{0xef8400d8,0x2738002e,0x00000000,0x00000000}},	//   _алоп, yën_, --, --, 
   {{0x75283743,0x00000000,0x00000000,0x00000000}},	//   hrez, --, --, --, 
   {{0x2738044e,0x6da40588,0x75280165,0xfa880212}},	//   vën_, _аима, krez, нсій_, 
   {{0x7bd404ba,0xbc7008b0,0x00000000,0x00000000}},	//   _ezzu, _گۇلب, --, --, 
   {{0x2738067d,0x7528de5e,0x1864de5f,0x00000000}},	//   tën_, drez, качи_, --, 
   {{0x7528de60,0x5ca0c712,0x27380036,0x69cc0210}},	//   erez, _тирб, uën_, _तरकी, 
   {{0x2738069c,0x45d40137,0x00000000,0x00000000}},	//   rën_, лойс, --, --, 
   {{0x2738069c,0xdad00131,0x55700139,0x00000000}},	//   sën_, _ئەنھ, игът, --, 
   {{0x2904de61,0x273802d3,0xc45801c6,0x00000000}},	//   mpoa_, pën_, хиох_, --, 
   {{0x7528de62,0x27380023,0xe80000cd,0x00000000}},	//   arez, qën_, रुणा_, --, 
   {{0xe5c480e2,0x26c400ec,0x2010de63,0x8cd4000d}},	//   _исло, _ukoo_, _sexi_, _बीसो, 
   {{0x7528de64,0x2904005a,0x16840345,0x00000000}},	//   crez, npoa_, _جالێ, --, 
   {{0xb60400d0,0xd5ac02f2,0x00000000,0x00000000}},	//   rešň, _بفه_, --, --, 
   {{0x78ac004a,0xd36cde65,0x00000000,0x00000000}},	//   éavi, _وهه_, --, --, 
   {{0xceb80640,0xe0dc007f,0x04c800ec,0xe800de66}},	//   вљу_, twòs_, _توڻي_, रुता_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [12ed0] --, --, --, --, 
   {{0x52740131,0x7d0800a2,0x00000000,0x00000000}},	//   _ماۋز, _çesm, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x752835c0,0xaa940139,0x00000000,0x00000000}},	//   yrez, лгхә, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3ea8de67,0x7528de68,0x0c84de69,0xbe1402dd}},	//   liat_, vrez, _кысм, _جوڭع, 
   {{0xb6a4b9ae,0x29040607,0x9770804b,0x7bd4022e}},	//   ликл, apoa_, ртлә, _uzzu, 
   {{0x7528de6a,0x3ea8de6b,0xcc1400dd,0x00000000}},	//   trez, niat_, _مذہب, --, 
   {{0x59b41533,0x7528adaf,0x00000000,0x00000000}},	//   _आखिर, urez, --, --, 
   {{0x7528de6c,0x3ea8de6d,0xe80007f7,0x97a46c66}},	//   rrez, hiat_, रुदा_, _ирел, 
   {{0x21640364,0x75280732,0x3ea8de6e,0xb6340f11}},	//   ҳияи_, srez, kiat_, _مفاع, 
   {{0x76940085,0x7af426ef,0x3ea8020c,0x753401c6}},	//   _báye, _muzt, jiat_, _бэкх, 
   {{0x3ea8de6f,0xe56cde70,0x2164013e,0xa5e80150}},	//   diat_, _уз_, гияи_, _كومە_, 
   {{0xefe40092,0x00000000,0x00000000,0x00000000}},	//   ዜያዊ_, --, --, --, 
   {{0x2128de71,0x3ea8de72,0x00e00131,0x7f180220}},	//   arch_, fiat_, _ﺋﻮﺗﺘ, кіту_, 
   {{0x3ea8de73,0xb8d40135,0x41c40521,0x30040075}},	//   giat_, _ཛམ_, ụsị_, _өзиг, 
   {{0xcbb00d42,0xcca400c7,0xac08011c,0x00000000}},	// [12ee0] _করেছ, агақ, енза_, --, 
   {{0xeb987d2c,0x7af44eb0,0x219808a8,0x906400cf}},	//   низ_, _buzt, _נביא, _ئندۇ, 
   {{0x3ea8de74,0x00000000,0x00000000,0x00000000}},	//   biat_, --, --, --, 
   {{0x6a1403e6,0xdd8c0014,0x8c8800c7,0x00000000}},	//   ابار, _کڈِ_, хәҭа_, --, 
   {{0xeb341075,0xf41800cc,0x00000000,0x00000000}},	//   _ڭىزد, _দানৰ_, --, --, 
   {{0x6d54083a,0x6e34de75,0xda5400d1,0x61d40375}},	//   mwya, lgyb, врәш_, נוסף_, 
   {{0x7af4152d,0x2904009d,0x00000000,0x00000000}},	//   _guzt, spoa_, --, --, 
   {{0x212800a9,0x67280158,0x250801c0,0x2904005b}},	//   yrch_, rrfj, нхоо_, ppoa_, 
   {{0xa834c842,0x7af4005a,0x44f40e92,0xe5c40108}},	//   _معاش, _zuzt, јпос, ыско, 
   {{0x21280122,0xceb400ac,0x44380428,0x3ea8de76}},	//   vrch_, hnə_, ür_, ziat_, 
   {{0x3ea80d04,0x49a4054a,0x2128015d,0x00000000}},	//   yiat_, _сыңғ, wrch_, --, 
   {{0x92581de1,0x3f84022c,0x4438025c,0x00000000}},	//   гают_, ølum_, żr_, --, 
   {{0x64a4010b,0xdc1c0154,0xd6dc012d,0x00000000}},	//   _йада, ন্টস_, ółem_, --, 
   {{0x3ea8de77,0x6d5403cb,0x40340063,0xd464009b}},	//   wiat_, dwya, јевс, _биље_, 
   {{0xd36cde78,0x3f8400d2,0x15d401d3,0x21280334}},	//   _уч_, âlu_, _لگیں_, srch_, 
   {{0x61fc01a9,0x3ea80165,0x00000000,0x00000000}},	//   _ufql, uiat_, --, --, 
   {{0x7af4005a,0x491400bc,0xe1fc0051,0x7c14003b}},	// [12ef0] _suzt, _नौलो_, mcó_, идає, 
   {{0x3ea8de79,0xe1fcde7a,0x7af4009d,0x60c000d1}},	//   siat_, lcó_, _puzt, ﺮﻟﻪﺷ, 
   {{0x60c4de7b,0x301405f5,0x79f40408,0xceb406be}},	//   mojm, _өдөр, азех, bnə_, 
   {{0xe1fc0407,0x628cde7c,0x60c4de7d,0x5ed00154}},	//   ncó_, nkco, lojm, _দূরে, 
   {{0xdd8479ea,0xe1fc01e7,0x8d84011c,0x092801e2}},	//   _сынп, adóg_, _лурд, هسوي_, 
   {{0x60c402d3,0x628c0175,0xf7707660,0xe0dc02e2}},	//   nojm, hkco, قاب_, stòf_, 
   {{0x3774b610,0x3694de7e,0x10380677,0xe7340395}},	//   рылс, ишис, אטום_, аещ_, 
   {{0x60c4de7f,0xada401f1,0xa3dc00bc,0x628c01f5}},	//   hojm, slúž, _běží_, jkco, 
   {{0x60c4de80,0xaaa401ee,0x00000000,0x00000000}},	//   kojm, _тѳрҙ, --, --, 
   {{0x33f4de81,0x60c40023,0xdb0406ea,0xb4c000dc}},	//   шчис, jojm, _ólóg, ूते_, 
   {{0x60c40023,0x13a44f6f,0xded00b82,0x00000000}},	//   dojm, انجی_, ራምን_, --, 
   {{0x6b98010e,0x00000000,0x00000000,0x00000000}},	//   _ütge, --, --, --, 
   {{0xfd64063f,0x7d080240,0xe8000b98,0x60c40200}},	//   rosọ, _çesh, रुवा_, fojm, 
   {{0xee3000b2,0x60c40023,0x628c01ab,0x00000000}},	//   ڪٽر_, gojm, akco, --, 
   {{0x23743ee6,0xafe4de82,0x04540137,0x00000000}},	//   _نمود_, ровл, _دئند, --, 
   {{0x6d54083a,0x628cde83,0x394c1730,0xccf4013f}},	//   twya, ckco, _opes_, hwɛe_, 
   {{0x394c0211,0x6e34de84,0x60c490bf,0x3eb80356}},	// [12f00] _npes_, rgyb, bojm, _djst_, 
   {{0x6e3400a9,0xb7b401e1,0xc10001c0,0x6d54015d}},	//   sgyb, _gẹg, _хүрл, rwya, 
   {{0xf1a826e4,0x6e4417cd,0x25f80210,0x00000000}},	//   _चेतन, _кенз, ैडमी_, --, 
   {{0x2c14045e,0xe79800bc,0xaa4408da,0x00000000}},	//   ালেই_, těží, редл, --, 
   {{0x09b02ca5,0x92b403d4,0x2954010b,0x00000000}},	//   जपेय, _জীৱ_, ръер, --, 
   {{0xb4c000cd,0x00000000,0x00000000,0x00000000}},	//   ूतो_, --, --, --, 
   {{0x394c0a40,0xa0980a7c,0x69d403e0,0xe80000cd}},	//   _epes_, כיסט, üyeb, रुषा_, 
   {{0xe664de85,0xe5c4de86,0x60c40023,0xe1fc0548}},	//   ртко, испо, zojm, xcó_, 
   {{0xe9a400db,0x28e801af,0x60c45fda,0x00000000}},	//   _таап, _адап_, yojm, --, 
   {{0x60c40240,0xa3dc0118,0x00000000,0x00000000}},	//   xojm, _věží_, --, --, 
   {{0x60c4c97f,0x57f8010f,0x1bf4010f,0x6674009f}},	//   vojm, _סלאו, יציר_, _پدار, 
   {{0xd1f0001f,0xa3dc013a,0x00000000,0x00000000}},	//   ቀርቡ_, _těží_, --, --, 
   {{0x6600de87,0x51840124,0xe1fcde88,0x60c4de89}},	//   _ifok, оура, rcó_, tojm, 
   {{0xe1fcde8a,0x7d0803e0,0x94d000c0,0x00000000}},	//   scó_, _çesi, _доіц, --, 
   {{0x443cde8b,0x60c4de8c,0x9f440793,0xd478008f}},	//   _icv_, rojm, _ünü_, _באגל, 
   {{0x60c402d3,0x443c6fe8,0x00000000,0x00000000}},	//   sojm, _hcv_, --, --, 
   {{0x6600014b,0x40349130,0x00000000,0x00000000}},	// [12f10] _mfok, _лепс, --, --, 
   {{0xcc74026a,0x60c4014f,0x7a4000e5,0x00000000}},	//   огућ, qojm, kátó, --, 
   {{0x394cde8d,0x443c054e,0x7694de8e,0x78bc1427}},	//   _spes_, _mcv_, _láya, _ísvi, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x64487e73,0x00000000,0x00000000,0x00000000}},	//   _obfi, --, --, --, 
   {{0x88c800d6,0x6600de8f,0x98c401e0,0x00000000}},	//   алів_, _afok, шсел, --, 
   {{0xfbe43fa7,0xbb840597,0x76940cad,0x7a4001d3}},	//   _প্রত, _الزي, _aáya, gátó, 
   {{0xd1f01ee0,0xcfb80375,0x64480e78,0xb4c000dc}},	//   ቀርብ_, ילוי_, _abfi, ूत्_, 
   {{0x443c0789,0x056803b7,0x394c2672,0x39480327}},	//   _bcv_, ајќи_, _upes_, ħass_, 
   {{0xe4540124,0x00000000,0x00000000,0x00000000}},	//   бжь_, --, --, --, 
   {{0x6600025c,0x97a40b2c,0x64480175,0xdb080139}},	//   _ffok, _трал, _dbfi, _çiäl, 
   {{0x769401e1,0x6448010a,0x00000000,0x00000000}},	//   _fáya, _ebfi, --, --, 
   {{0x787c02e2,0x443c005c,0xf5040eed,0xe56cde90}},	//   _sèvy, _fcv_, _узло, _эз_, 
   {{0xc4c4168d,0x4094337e,0xba3c0118,0x2978010f}},	//   _وتوو, орст, _smůl, אטשא, 
   {{0xd46401af,0x07440354,0x00000000,0x00000000}},	//   _биҙе_, _юхăм, --, --, 
   {{0xed58016c,0xada407d6,0xce349a79,0xc3040133}},	//   лоб_, бабл, تورک, _ببوو, 
   {{0xf1d005f5,0x6cd400c6,0x1d040395,0x00000000}},	// [12f20] _хөнө, مقرا, йети_, --, 
   {{0x443c0393,0x66dc0240,0xd7a40037,0x09d000cc}},	//   _xcv_, mëke, _कइंच, িধমা, 
   {{0x28e801ec,0xeb280798,0x00000000,0x00000000}},	//   ңдеп_, ужел_, --, --, 
   {{0x6da401b9,0x9a80010b,0x00000000,0x00000000}},	//   _همجم, зушл, --, --, 
   {{0x66cc01e1,0x14c4258d,0x00000000,0x00000000}},	//   _nǹka, रकाण, --, --, 
   {{0xc7b001ed,0x6c84007b,0x7a4000e5,0xbf640066}},	//   وڑا_, _الآم, tátó, _ادیو, 
   {{0xeb984261,0x23c40829,0x3cf00419,0x00000000}},	//   _сив_, _रुंद, žovú_, --, 
   {{0x22ac0118,0x9c8400d0,0x769401e1,0x7a4000e5}},	//   křka_, _vačš, _páya, rátó, 
   {{0x5efc9543,0xa9240022,0x7a4001d3,0x55700166}},	//   _शून्_, _ыдал, sátó, згыт, 
   {{0xc0ec0201,0x64480165,0x32000419,0x00000000}},	//   _ጀምሮ_, _qbfi, ecky_, --, 
   {{0x443c02c4,0xb864de91,0x0ec8107c,0xd87400f1}},	//   _vcv_, _باقو, लवाड, _دملت_, 
   {{0x26d01aac,0x66000270,0x00000000,0x00000000}},	//   _óyo_, _ufok, --, --, 
   {{0x76c401d5,0x00000000,0x00000000,0x00000000}},	//   _بغلل, --, --, --, 
   {{0x443c0789,0x43940032,0xb9d00023,0x32000419}},	//   _ucv_, _малс, _ድያ_, acky_, 
   {{0xd36c0372,0xbc6800dd,0x7ce80153,0x00000000}},	//   _эч_, یجئے_, _užri, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb5fc2774,0x00000000,0x00000000,0x00000000}},	// [12f30] ndša, --, --, --, 
   {{0xdf446e1e,0xde4402f2,0x00000000,0x00000000}},	//   _лэмп, _گیرو_, --, --, 
   {{0x32d000d2,0x1fa40022,0xfb540c75,0xbed801f4}},	//   wáyi_, _ыриг, تپاد, _вднх_, 
   {{0xb9948688,0x80c000c5,0x4fc400d1,0x00000000}},	//   يلاب, लकके, _رەقە, --, 
   {{0x2ef80036,0xf428005b,0xf41800fe,0x00000000}},	//   _zupf_, nnää_, _দাসৰ_, --, 
   {{0x2000068f,0x9f50011f,0x9e6454f0,0x00000000}},	//   ncji_, _agxé_, _ئاگن, --, 
   {{0x7d0c1455,0xcb3402e8,0xf4280108,0x00000000}},	//   lpas, _неръ, hnää_, --, 
   {{0x8b8802dd,0xceb4010f,0xf50426b1,0x00000000}},	//   _دەمە_, ּיץ_, озио, --, 
   {{0x2000006d,0xbbb8000d,0x00000000,0x00000000}},	//   kcji_, _आशुक, --, --, 
   {{0xd6d80046,0xb4a8b3f0,0x8d5c02e4,0x34a801c6}},	//   _өте_, ркоз_, רכזי, рвоо_, 
   {{0x7d0cde92,0xc168011a,0x12940023,0xdb1c007c}},	//   hpas, _שח_, _ዝረክብ_, _övär, 
   {{0x7d0cde93,0x22ac0118,0x28c821bd,0x66dc0200}},	//   kpas, třka_, ाकथि, tëke, 
   {{0x7d0c0d27,0x76480042,0x28a477d7,0x00000000}},	//   jpas, mfey, कोवि, --, 
   {{0x7d0cde94,0xfd780023,0x76480042,0x2bbc00cd}},	//   dpas, _ኣሸጋሪ_, lfey, ्थमा, 
   {{0x7d0c1eff,0x00000000,0x00000000,0x00000000}},	//   epas, --, --, --, 
   {{0x229800b0,0x76480368,0x7d0cde95,0x2000012d}},	//   _pëke_, nfey, fpas, acji_, 
   {{0x7d0cde96,0x6494084c,0x9d40de97,0xac84de98}},	// [12f40] gpas, _mâin, метд, огал, 
   {{0xceb80daf,0xf1a40fdc,0x2000031c,0x764803cb}},	//   рәү_, _грүн, ccji_, hfey, 
   {{0x7d0cde99,0xeb9801c0,0xaec40276,0x2b3800a8}},	//   apas, шиж_, _мбол, рязэ_, 
   {{0x2e680262,0x4ed800fe,0x00000000,0x00000000}},	//   _тимп_, _দূৰল, --, --, 
   {{0x76480368,0xec300131,0xc7b816a3,0x5dc002dd}},	//   dfey, _يۈرگ, _međe_, _يمپە, 
   {{0x769402ea,0x3078008f,0xae040150,0xfb740137}},	//   _báyo, שאַנ, _دوڭى, تپۅگ, 
   {{0x7648102c,0x00000000,0x00000000,0x00000000}},	//   ffey, --, --, --, 
   {{0x64940276,0xc7b801fa,0x3d10000d,0x76480368}},	//   _câin, _neđe_, दीके_, gfey, 
   {{0x20000034,0xe4e400d4,0x7d080139,0x00000000}},	//   ycji_, жінн, _çest, --, 
   {{0xf1dc012c,0x7648058a,0xe7280536,0x23680114}},	//   नेछन, afey, _вожд_, ајмо_, 
   {{0xe644005b,0xd3a0003b,0x1bf800df,0x00000000}},	//   _межп, дряп, יליב, --, 
   {{0x7d0cde9a,0x92940953,0x28a4098a,0x4ecc0154}},	//   ypas, даюц, कोरि, লগুল, 
   {{0xdb040008,0x05d8009f,0x00000000,0x00000000}},	//   _ólög, _اداڪ_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdef80323,0x7d0cde9b,0x439409a5,0x14c4de9c}},	//   рыг_, wpas, _хайс, रकरण, 
   {{0x7d0cde9d,0x53980375,0x00000000,0x00000000}},	//   tpas, _כיוו, --, --, 
   {{0x7d0cde9e,0x2000033f,0x2a64058a,0xdb0401e1}},	// [12f50] upas, pcji_, ddob_, _álúf, 
   {{0x7d0cde9f,0xc0c4506f,0x769400a2,0x81c00131}},	//   rpas, _хәми, _aáyl, _يەھۇ, 
   {{0x7d0cdea0,0x656401bf,0x5f400244,0x00000000}},	//   spas, ækhj, _تۆزل, --, 
   {{0x7d0cdea1,0x00000000,0x00000000,0x00000000}},	//   ppas, --, --, --, 
   {{0x999c00d7,0xed4c00ec,0x00000000,0x00000000}},	//   _obuť_, _مھل_, --, --, 
   {{0xacf80375,0x9848399b,0x00000000,0x00000000}},	//   _להשכ, ряда_, --, --, 
   {{0x2a64079b,0x64940276,0x00000000,0x00000000}},	//   bdob_, _pâin, --, --, 
   {{0xf558007b,0x00000000,0x00000000,0x00000000}},	//   ملعب_, --, --, --, 
   {{0xc7b83341,0x39140b28,0x7648dea2,0x38340166}},	//   _ređe_, _رواز, rfey, _ннар, 
   {{0x8d74001f,0x764803cb,0x23c4012d,0x00000000}},	//   ብሰባው_, sfey, रअंद, --, 
   {{0x69c4003b,0x00000000,0x00000000,0x00000000}},	//   _øker, --, --, --, 
   {{0xd6d801a9,0x00000000,0x00000000,0x00000000}},	//   _ттз_, --, --, --, 
   {{0xe800012c,0x00000000,0x00000000,0x00000000}},	//   रुका_, --, --, --, 
   {{0x66dc036e,0x00000000,0x00000000,0x00000000}},	//   mëka, --, --, --, 
   {{0x66dc02d3,0x09b80490,0xc0580006,0x00000000}},	//   lëka, _अश्य, ціў_, --, 
   {{0xe3c405f5,0x7d08031c,0x8cd41be1,0x00000000}},	//   _эрчү, _ħesr, _बीजो, --, 
   {{0xf53801f1,0xa2b4011a,0x00000000,0x00000000}},	// [12f60] nuť_, _מפקד_, --, --, 
   {{0xe1fc307d,0x00000000,0x00000000,0x00000000}},	//   ndón_, --, --, --, 
   {{0xf5380306,0xdcd80022,0x00000000,0x00000000}},	//   huť_, сутә_, --, --, 
   {{0x2918dea3,0x37d0015b,0xe0dcc375,0x6b50032e}},	//   مقصد_, াধার, ntòn_, _aðgö, 
   {{0x64940129,0x2a64dea4,0x66dc036e,0x00000000}},	//   _bâil, rdob_, jëka, --, 
   {{0x98a0dea5,0x98ac0b23,0x2bbc00dc,0xac981699}},	//   ниче, tugā_, ्थदा, _انسا_, 
   {{0xb86494b9,0xebe40209,0xc7b80051,0x00000000}},	//   بانو, _ховп, _ndđt_, --, 
   {{0xe8f800ea,0xb3400139,0x00000000,0x00000000}},	//   _гла_, _öçya, --, --, 
   {{0x21f403b2,0x5e54010f,0x00000000,0x00000000}},	//   høhø_, ליקע_, --, --, 
   {{0xb86471a8,0x439401d5,0x38700150,0x00000000}},	//   _يالو, даос, _ақшт, --, 
   {{0x27940408,0x00000000,0x00000000,0x00000000}},	//   _эшар, --, --, --, 
   {{0xf5380306,0x73d801c6,0xa6e400cf,0x46b0000d}},	//   buť_, өдөр_, _эжел, _जगिह, 
   {{0xc0c49e04,0x61f82375,0xd66403e6,0x00000000}},	//   дәни, žulo, _رموو_, --, 
   {{0x6560dea6,0xd4649fb7,0x4dc4009e,0xe19000db}},	//   _isoh, _ниче_, ্ধাং, _үлкө, 
   {{0xc7b8004d,0xd8d40677,0x00000000,0x00000000}},	//   _gdđt_, פולט_, --, --, 
   {{0xf4081b4b,0x64581fd8,0xe0dc0ba1,0x46cc07f8}},	//   _གཅོད_, leti, ctòn_, ाविह, 
   {{0x3220012d,0x00000000,0x00000000,0x00000000}},	// [12f70] óryś_, --, --, --, 
   {{0x6560dea7,0x00000000,0x00000000,0x00000000}},	//   _msoh, --, --, --, 
   {{0xdde811fc,0xeff0001f,0x64580076,0xa4940139}},	//   _گرده_, ጃቸው_, ieti, _xuϲa, 
   {{0x65600117,0xb8180183,0xa814004b,0x7bd400d7}},	//   _osoh, _ঠাইত_, ېښنا_, _vyzu, 
   {{0x6560dea8,0x670002e3,0x7e980214,0xdde80ee8}},	//   _nsoh, _ọkpa, _هنگر_, _درده_, 
   {{0xd83801c6,0x00000000,0x00000000,0x00000000}},	//   сэд_, --, --, --, 
   {{0x6458dea9,0x656001b2,0xf650007b,0x67d02377}},	//   deti, _asoh, نئة_, кољу, 
   {{0xe734013e,0xf50827a8,0xe1fc00e8,0x6458deaa}},	//   феъ_, онил_, ddóo_, eeti, 
   {{0x6458deab,0x386400ef,0x00000000,0x00000000}},	//   feti, _talr_, --, --, 
   {{0x970004a9,0x34a800d4,0xb9f80240,0x00000000}},	//   _كېتى, івно_, _ዅሉ_, --, 
   {{0xe1fcdeac,0x65602fad,0x9c840316,0x4584009d}},	//   rdón_, _esoh, _začá, дгөв, 
   {{0xe2941fdf,0x7cf00724,0x49140316,0x35540592}},	//   даю_, lırğ, नीको_, _يناز, 
   {{0xf428dead,0xfec40154,0xb51c010a,0x00000000}},	//   _долл_, ্ষাধ, _тилĕ_, --, 
   {{0xe4500022,0xafe42e8d,0x00000000,0x00000000}},	//   _ҷкәы, догл, --, --, 
   {{0xdb040241,0x00000000,0x00000000,0x00000000}},	//   _òmèt, --, --, --, 
   {{0xdee030d0,0xf1f89924,0x2bbc084d,0x00000000}},	//   воси, _بعثت_, ्थसा, --, 
   {{0x3f840174,0xa2d82c2e,0x00000000,0x00000000}},	// [12f80] ølur_, नतर्, --, --, 
   {{0xc7b8098d,0x3a2c020c,0xd0640134,0x00000000}},	//   _leđa_, _adep_, _ɔsɛn, --, 
   {{0x2ee4005b,0xaa44013d,0x2a640395,0x7cf0008e}},	//   _ожог, деел, дълг, dırğ, 
   {{0x3a2cdeae,0xe9d8deaf,0xa258030a,0x00000000}},	//   _cdep_, оке_, rnôg, --, 
   {{0x6458deb0,0xe1fc0429,0x00000000,0x00000000}},	//   yeti, ddól_, --, --, 
   {{0x6458deb1,0x3a2cdeb2,0xceb403b9,0x248c0240}},	//   xeti, _edep_, liə_, _ዝፈስስ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xcfc000bd,0xf408031c,0x7bc00024,0xceb406be}},	//   _ইরান, _གཅུད_, _žlug, niə_, 
   {{0x6458deb3,0x2bbc3c16,0xe4c407d8,0x6aa0009f}},	//   teti, ्थवा, дённ, mhof, 
   {{0x00d800d1,0x98ac054e,0x2794004e,0x46b00037}},	//   ﯞﺍﺗﻘ, rugă_, _ошер, _जगवह, 
   {{0xc7b801fa,0xadec12eb,0x16280092,0x5740009d}},	//   _feđa_, चेतन_, _ተጀምሯ, _анхб, 
   {{0x6560deb4,0x6aa0deb5,0x66dc0200,0x00000000}},	//   _tsoh, nhof, mëko, --, 
   {{0x656054da,0xe4a40415,0x00000000,0x00000000}},	//   _usoh, _орко, --, --, 
   {{0x6458deb6,0x00000000,0x00000000,0x00000000}},	//   qeti, --, --, --, 
   {{0x6aa029ef,0xceb403be,0x28b4000d,0x66dc0200}},	//   khof, fiə_, _अगनि, nëko, 
   {{0x6aa08c35,0x9f440ca8,0x00000000,0x00000000}},	//   jhof, _àní_, --, --, 
   {{0x629c0548,0xe1fc8aa2,0x00000000,0x00000000}},	// [12f90] _ilqo, ndóm_, --, --, 
   {{0x66dc0023,0x20049c11,0x93f8010f,0x00000000}},	//   këko, _üni_, ַלדי, --, 
   {{0x3dac04c5,0xe0dc033b,0xceb406be,0x00000000}},	//   _কুশল, ntòm_, biə_, --, 
   {{0xda642834,0x6aa00368,0xceb40213,0x9da802e8}},	//   بائي, ghof, ciə_, _дъга_, 
   {{0x49b8034c,0xc7b800f3,0x7cf000fd,0x2ec0013d}},	//   واهد_, _ređa_, tırğ, _сөрм, 
   {{0x2bbc07af,0xf748007b,0x37e400db,0x00000000}},	//   ्थशा, كلتي_, нолг, --, 
   {{0xcb44deb7,0x7c24deb8,0x7cf00724,0xc7b80960}},	//   _ихти, mahr, rırğ, _peđa_, 
   {{0x6aa0deb9,0x76940784,0x7c24deba,0x61f807f5}},	//   chof, _káyi, lahr, žulj, 
   {{0x6aa804e6,0xe1fc0174,0x98480024,0x0a68030d}},	//   ëffe, gdóm_, _мяжа_, _юрри_, 
   {{0xd8743b5f,0x629cdebb,0x7c2442b4,0xb370001f}},	//   _تارب, _alqo, nahr, _ሥራውን_, 
   {{0xe3b40276,0x7694debc,0x00000000,0x00000000}},	//   ебэ_, _láyi, --, --, 
   {{0x629c0a73,0x7c2405b1,0xe0dc0ba1,0x7d1c0c8c}},	//   _clqo, hahr, stòl_, _owss, 
   {{0x34940953,0x46ccc976,0x00000000,0x00000000}},	//   _падр, ावरह, --, --, 
   {{0x7c24debd,0x00000000,0x00000000,0x00000000}},	//   jahr, --, --, --, 
   {{0x7d1c02d0,0x7c240009,0x09dc0073,0xdce8013d}},	//   _awss, dahr, _बर्य, _şiğa, 
   {{0xf1d0debe,0x75281418,0x7c24062c,0x6aa0036e}},	//   _бөгө, osez, eahr, xhof, 
   {{0xdef00201,0x7c2409f0,0x7528debf,0xc50c010f}},	// [12fa0] ፍሪካ_, fahr, nsez, ַלאָ, 
   {{0xb7b401e1,0x7528002f,0x2bbc190c,0x7c2402d2}},	//   _pẹl, isez, ्थला, gahr, 
   {{0x6aa0dec0,0x764c0113,0x7d1c035a,0xe7ac000d}},	//   thof, _ñayw, _ewss, _झेंप, 
   {{0xe9441064,0x7ac000c7,0x58803452,0x6924aca4}},	//   ехко, аҩса, ғыша, емда, 
   {{0xdd8c00e3,0x7c2401a9,0x00000000,0x00000000}},	//   _هوَ_, bahr, --, --, 
   {{0x6aa0dec1,0x6cd40597,0xfbd000dd,0xab2835f2}},	//   shof, _أقسا, اتے_, _нога_, 
   {{0x6aa0dec2,0x2bbc0490,0x75281418,0x00000000}},	//   phof, ्थळा, esez, --, 
   {{0x7d080587,0x6a844caf,0x66dc0240,0x75280166}},	//   _éesc, _ялба, rëko, fsez, 
   {{0x95d40395,0x00000000,0x00000000,0x00000000}},	//   ндът_, --, --, --, 
   {{0xd934044e,0x00000000,0x00000000,0x00000000}},	//   _ኣርባዕ, --, --, --, 
   {{0x5c34008f,0xe1fc148b,0x561c00cc,0x00000000}},	//   ערטן_, sdóm_, _ধাৰক_, --, 
   {{0x68f80115,0x7c240306,0x0324010b,0x6728dec3}},	//   _hitd, zahr, ндүн, msfj, 
   {{0x6728dec4,0x644c000d,0x00000000,0x00000000}},	//   lsfj, õbis, --, --, 
   {{0x65640450,0x00000000,0x00000000,0x00000000}},	//   ækhu, --, --, --, 
   {{0x248c0076,0xd4640640,0x68f8dec5,0xded00092}},	//   _iofm_, _чије_, _mitd, ያምኑ_, 
   {{0x7c2448aa,0x629c011f,0xce680139,0x00000000}},	//   wahr, _ulqo, нруд_, --, 
   {{0x7c24dec6,0xe164007b,0x91e401af,0x00000000}},	// [12fb0] tahr, _أدبي, _бәрһ, --, 
   {{0xc7b801fa,0xdef8dec7,0x2128002f,0xfaf80064}},	//   _neđo_, _ным_, msch_, _siū_, 
   {{0x2128dec8,0x6e400075,0x2be408e6,0x9f440241}},	//   lsch_, _ھۆكم, _करणं_, _ànà_, 
   {{0x672805ac,0xda6400db,0x7c24dec9,0x212804cc}},	//   dsfj, عااي, sahr, osch_, 
   {{0x2128deca,0x68f8decb,0x7c24decc,0x0dc801f0}},	//   nsch_, _bitd, pahr, _зури_, 
   {{0x7e6cdecd,0x2128dece,0x68f800fd,0x23b000dc}},	//   ldap, isch_, _citd, ुपाद, 
   {{0x67280158,0x2128002f,0xb6a401a9,0x00000000}},	//   gsfj, hsch_, кикл, --, 
   {{0x7e6c122d,0x2128002f,0x00000000,0x00000000}},	//   ndap, ksch_, --, --, 
   {{0xe520010b,0x7ae8decf,0x552002dd,0xe97000ec}},	//   адып, _ihet, ыппұ, _پڇند, 
   {{0x97a4ded0,0x68f80209,0x212807de,0xc6d4004e}},	//   _прел, _gitd, dsch_, ксөө, 
   {{0x28b405b7,0x7ae8ded1,0x2128ded2,0x7e7cded3}},	//   _अगति, _khet, esch_, _onsp, 
   {{0x35b40209,0x7528ded4,0x7ae80115,0x68f801f5}},	//   _ибер, psez, _jhet, _zitd, 
   {{0x7ae85a80,0x68f800a2,0xb46401d5,0x00000000}},	//   _mhet, _yitd, _аклл, --, 
   {{0x7e7cded5,0x04c800ae,0x00000000,0x00000000}},	//   _ansp, _كوني_, --, --, 
   {{0x212804cc,0x7ae82386,0x24500137,0x602001c0}},	//   asch_, _ohet, _ئنىس, рдса, 
   {{0xa2580a85,0x7e6c2819,0x7ae8004c,0x212817da}},	//   rnôc, gdap, _nhet, bsch_, 
   {{0xe1fc011f,0x6fd01414,0x00000000,0x00000000}},	// [12fc0] ddóh_, _दुरं, --, --, 
   {{0xeb9843ee,0x7e7cded6,0x7ae8ded7,0xf49002d3}},	//   миз_, _ensp, _ahet, _ዝወሃብ_, 
   {{0x7ae8ded8,0x68f8032e,0xafe496f0,0x7e6c00cd}},	//   _bhet, _ritd, _шоол, bdap, 
   {{0x7ae8ded9,0x78a0deda,0x65ac0084,0x67283619}},	//   _chet, _allv, ṱhis, vsfj, 
   {{0x7ae80192,0x83fc07f5,0x5a3000d3,0xbe8001d5}},	//   _dhet, leđe, рніт, _уқти, 
   {{0x7ae8dedb,0xdd8c0014,0x68f8022e,0x199000ee}},	//   _ehet, _بڈِ_, _qitd, рашя, 
   {{0x7ae80084,0x7e7c0b21,0x8a440050,0xd7ec01ec}},	//   _fhet, _ynsp, _مێان, ру_, 
   {{0x68f80af9,0x61f80024,0x2128dedc,0x7ae81c2e}},	//   _witd, žuli, ysch_, _ghet, 
   {{0xc1e0033f,0x672803cd,0x00000000,0x00000000}},	//   _नरेग, ssfj, --, --, 
   {{0xb8641812,0x68f81aa7,0x7ae80098,0x25e02645}},	//   _مامو, _uitd, _zhet, _परीण, 
   {{0x83fc1f7f,0xe66401af,0x00000000,0x00000000}},	//   jeđe, _атло, --, --, 
   {{0x21281948,0x00000000,0x00000000,0x00000000}},	//   tsch_, --, --, --, 
   {{0x21284df3,0x26c4198f,0x64a400c7,0xe1fc00c7}},	//   usch_, _ijoo_, _иада, ndói_, 
   {{0x2128dedd,0x7e7c054e,0xe3f800cf,0x43740ee8}},	//   rsch_, _snsp, _قىشت_, _مهتر, 
   {{0x7e6c079b,0x22980694,0xc31c00fe,0x00000000}},	//   tdap, _jëkk_, _থমকি_, --, 
   {{0x63b402a8,0x26c40789,0x00000000,0x00000000}},	//   _ƙanƙ, _jjoo_, --, --, 
   {{0x7e6cdede,0x7ae8dedf,0x26c40036,0x2900003e}},	// [12fd0] rdap, _rhet, _mjoo_, _ékah_, 
   {{0x7ae8dee0,0x80c000bd,0x7e6c04e6,0xb5fc0419}},	//   _shet, _শীর্, sdap, rdši, 
   {{0x50b8275a,0x7ae8dee1,0x7f9405f5,0x7e6c0589}},	//   _جديد_, _phet, _санх, pdap, 
   {{0x7e7cdee2,0x7ae801ee,0x26c4dee3,0x83fc00f3}},	//   _unsp, _qhet, _njoo_, ceđe, 
   {{0x7ae806d6,0x5c040228,0xd90c0d23,0x38ac0022}},	//   _vhet, _аяба, زیا_, jórõ_, 
   {{0x26c4002e,0x229800e8,0x7ae8dee4,0xf5380216}},	//   _ajoo_, _bëkk_, _whet, vrť_, 
   {{0x7ae8dee5,0x26c41ebd,0xe8f401ec,0x00000000}},	//   _thet, _bjoo_, ылш_, --, 
   {{0x22981574,0x7ae800ca,0xf4280108,0x00000000}},	//   _dëkk_, _uhet, kiää_, --, 
   {{0xb5fc1f7f,0x59b43cbe,0x00000000,0x00000000}},	//   ješe, _अधिर, --, --, 
   {{0x34844ea8,0x229800e8,0xb4dc0490,0x78a003cd}},	//   угог, _fëkk_, ढते_, _ullv, 
   {{0x98ac054e,0xe1fc012d,0xa56000d1,0x00000000}},	//   argă_, ndów_, لگۈن, --, 
   {{0xc7e80150,0x81b40154,0x59b400b8,0x00000000}},	//   _شىنن_, _ঝড়_, _अधार, --, 
   {{0x0574dee6,0x83fc00f3,0x79980332,0x347400fb}},	//   _پاند, veđe, nyww, _бѳйѳ, 
   {{0xfee00729,0x25b000ee,0x22980de2,0x65980677}},	//   _মূলধ, _ýyla_, _yëkk_, _ריסק, 
   {{0xb4c00cb2,0x83fc05a1,0xae782fc3,0xe1fc012d}},	//   ्की_, teđe, нсах_, jdów_, 
   {{0x324400c7,0xeb980022,0x00000000,0x00000000}},	//   _сеиг, ҭиа_, --, --, 
   {{0x83fc1326,0x394c0070,0xece8dee7,0xdee0dee8}},	// [12fe0] ređe, _nqes_, едал_, соти, 
   {{0xf064dee9,0x65b803b2,0xf28801d3,0x28d00150}},	//   _скоп, _høhø, _آپکو_, _ﺘﻬﺎﺠ, 
   {{0xe9d004a9,0x656c0a28,0xd4380092,0x00000000}},	//   ڭغا_, ābhi, _በአትሌ, --, 
   {{0x6da4deea,0x229800e8,0xba4400d4,0xba540395}},	//   _бима, _rëkk_, ихій, итчъ, 
   {{0x22981bce,0xba04035b,0xe1fc0210,0x00000000}},	//   _sëkk_, рҭуа_, adów_, --, 
   {{0x26c403b2,0xb4dc0073,0x0b440133,0x885800d8}},	//   _sjoo_, ढतो_, _پرسێ, тикс_, 
   {{0xc1e002a0,0xea580798,0x00000000,0x00000000}},	//   _नर्ग, _прај_, --, --, 
   {{0xa3e80037,0x00000000,0x00000000,0x00000000}},	//   _मरब_, --, --, --, 
   {{0x6e24009b,0x2bbc1a2a,0xb4c00ce0,0x782400cf}},	//   _mekb, ्थका, ्कू_, اعۇل, 
   {{0xd5600c04,0x44b4deeb,0xf428023a,0x786400cf}},	//   стъп, рбос, viää_, _ۅدۅك, 
   {{0x6e240166,0xb5fc33e9,0xe61800f3,0xe738010a}},	//   _oekb, veše, _зде_, _чее_, 
   {{0x6e24deec,0x81e80154,0x38ac035b,0xded00092}},	//   _nekb, _বলব_, pórõ_, ያዝና_, 
   {{0x6600deed,0xe1fc0034,0xb5fc0419,0x65940035}},	//   _igok, zdów_, teše, _حجار, 
   {{0x6fd461b8,0x46cc00bc,0x00000000,0x00000000}},	//   _मुहू, ावकह, --, --, 
   {{0x660099df,0xb5fcdeee,0x6e24022e,0x94200063}},	//   _kgok, reše, _bekb, _умје, 
   {{0xfb841a69,0x00000000,0x00000000,0x00000000}},	//   یدای, --, --, --, 
   {{0x6e24deef,0xb5fc09a8,0xdcec00b8,0x40340024}},	// [12ff0] _dekb, peše, _arcā, _кепс, 
   {{0x6e2402d0,0xca4c0150,0x00000000,0x00000000}},	//   _eekb, _ﺃﺴﺭ_, --, --, 
   {{0x66000295,0x70f80375,0x6448002f,0x00000000}},	//   _ogok, _שהתח, _mcfi, --, 
   {{0x66007ea9,0x9a2410e0,0xa3bc03e5,0x00000000}},	//   _ngok, اعان, _ेशन_, --, 
   {{0x3ea8007b,0xe1fc033f,0x2d680139,0xd918def0}},	//   mhat_, rdów_, _иярү_, хье_, 
   {{0x3ea8def1,0x660072f5,0x96d08383,0x19c00150}},	//   lhat_, _agok, әскә, _құлм, 
   {{0x6600009a,0xdb20721b,0x00000000,0x00000000}},	//   _bgok, _دوزی, --, --, 
   {{0x3ea8def2,0xe69000d1,0x00000000,0x00000000}},	//   nhat_, قلىد, --, --, 
   {{0xca480fba,0x3ea8def3,0xc66800d8,0x00000000}},	//   _حلقه_, ihat_, ушје_, --, 
   {{0x55c0a70b,0x66000323,0xb4c01810,0x3ea8011f}},	//   _қалғ, _egok, ्के_, hhat_, 
   {{0x3ea8def4,0x73e4def5,0xa3e80073,0x72c4022e}},	//   khat_, ронз, _मरण_, ибоз, 
   {{0x25b4034c,0x6448031c,0x23a00ca8,0x00000000}},	//   اهید_, _ecfi, _ọjà_, --, 
   {{0x6e24def6,0x3ea8def7,0x7c343493,0x753c00e5}},	//   _rekb, dhat_, _odzr, ászd, 
   {{0xe0d402e8,0x9a801954,0xe5a00d1d,0x65100244}},	//   ивя_, _ኮለኔል_, _фиши, _بووئ, 
   {{0x154001e0,0x2eb469aa,0x6e24007c,0x7bc000c0}},	//   _теҙм, асас, _pekb, _žlun, 
   {{0xa3e8069f,0x3ea8def8,0x7c3405b1,0xed58741b}},	//   _मरत_, ghat_, _adzr, коб_, 
  
   {{0x1d04def9,0x00000000,0x00000000,0x00000000}},	// [13000] иети_, --, --, --, 
   {{0xcdc41171,0x00000000,0x00000000,0x00000000}},	//   _ҳамқ, --, --, --, 
   {{0x6e24defa,0xa25805da,0x2cb8020c,0xee38defb}},	//   _tekb, knôl, ripd_, _инн_, 
   {{0x49a43088,0x3ea80118,0x00000000,0x00000000}},	//   йылғ, chat_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb4c039d7,0x76580042,0x58d400d4,0x00000000}},	//   ्को_, _abwy, адія_, --, 
   {{0xe0dc067c,0xb4c0012c,0xe664004e,0xe78400cf}},	//   luòc_, ्कै_, атпо, руло, 
   {{0x83fc1f7f,0x291404f2,0x00000000,0x00000000}},	//   jeđa, _نورآ, --, --, 
   {{0xe8f8defc,0xc7b80e04,0x00000000,0x00000000}},	//   _ала_, _međi_, --, --, 
   {{0x3ea8defd,0xa3e800af,0xd9180375,0xbb4c0150}},	//   zhat_, _मरद_, _סובל, _ﺃﻤﻥ_, 
   {{0xb5fc01a6,0x3c78010f,0x49a401ec,0x81e800cc}},	//   tešc, אָרב, _тыңғ, _বলধ_, 
   {{0x66000810,0x96040a89,0x3ea80240,0x00000000}},	//   _ugok, _кэша_, xhat_, --, 
   {{0x20d400c6,0xa4e401d5,0x00000000,0x00000000}},	//   لتسج, _кўкк, --, --, 
   {{0x3ea8defe,0x649801af,0x00000000,0x00000000}},	//   what_, _штер_, --, --, 
   {{0x442cdeff,0xb5fcdf00,0x764c00d2,0x3ea8df01}},	//   mad_, meša, _ínyâ, that_, 
   {{0xb5fc000a,0x93f804ac,0x442cdf02,0x2bd805b3}},	//   leša, _בלוי, lad_, _भड़ा, 
   {{0x442c0254,0xd1b8072d,0x00000000,0x00000000}},	// [13010] oad_, _پايا_, --, --, 
   {{0x442cdf03,0x3ea8df04,0x3d1c01e1,0xdd9014d4}},	//   nad_, shat_, _aáwò_, бағы, 
   {{0x3ea8df05,0x3b54df06,0x3d1c0241,0x442cdf07}},	//   phat_, скер, _báwò_, iad_, 
   {{0xe0dc067c,0xdef8586a,0x00000000,0x00000000}},	//   rtòu_, _шып_, --, --, 
   {{0x9964df08,0x3eb8df09,0xca740131,0xe0dc0ba1}},	//   ртел, _imst_, تالغ, stòu_, 
   {{0x442c367a,0xb5fc1f7f,0x81e800bd,0x7d0c2beb}},	//   jad_, ješa, _বলা_, mqas, 
   {{0x442cdf0a,0xb5fc0989,0x9a8402ac,0x7d0c03f0}},	//   dad_, deša, _куал, lqas, 
   {{0x442c1368,0x7d0c013c,0xb4c0687b,0x66dc0240}},	//   ead_, oqas, ्क्_, këku, 
   {{0x442cdf0b,0xcfe407af,0x7d0cdf0c,0xd7640137}},	//   fad_, _गर्भ_, nqas, _چەتى_, 
   {{0x442cdf0d,0x66dc2776,0x3eb805b1,0xd34479af}},	//   gad_, dëku, _lmst_, لیته_, 
   {{0x4874014d,0x17f8007b,0x7d0c0200,0xd3e06646}},	//   _بدقس, _شرطة_, hqas, تقدی, 
   {{0x442cdf0e,0x00000000,0x00000000,0x00000000}},	//   aad_, --, --, --, 
   {{0x83fc17a3,0xc7b800f3,0xd58403e6,0x2900020c}},	//   ređa, _ređi_, _ڕێکه_, _ékat_, 
   {{0x442cdf0f,0x7648df10,0xb5fc3341,0x78f8010f}},	//   cad_, lgey, ceša, רפֿו, 
   {{0x628c004e,0x76480009,0x13a4104c,0xd204004e}},	//   bjco, ogey, _خنثی_, _мүнк, 
   {{0x76482dab,0xb224df11,0xb8c80135,0x2d9400db}},	//   ngey, _умил, _བཞ_, бөгө_, 
   {{0x7d0c0107,0x764800ad,0x2010045a,0x00000000}},	// [13020] gqas, igey, _ffxi_, --, 
   {{0x229800e8,0x3eb801f5,0x00000000,0x00000000}},	//   _dëku_, _emst_, --, --, 
   {{0xe1fc0137,0x7d0c0869,0x00000000,0x00000000}},	//   bdós_, aqas, --, --, 
   {{0x7d0c0429,0xdc640fc0,0xa3e80037,0x00000000}},	//   bqas, _қасд_, _मरस_, --, 
   {{0x442cdf12,0x76480076,0xd940084c,0x5e54009f}},	//   yad_, dgey, зечи, _ائپر, 
   {{0x3cd407d6,0x442c01d9,0x307800c8,0x76485148}},	//   _дўст, xad_, ראַנ, egey, 
   {{0x442cdf13,0x769400e4,0xb5fc00e2,0x66dc036e}},	//   vad_, _páyp, veša, zëku, 
   {{0x442cdf14,0xe6642a30,0xfd4c00b4,0x764847a2}},	//   wad_, стко, _nchị, ggey, 
   {{0x442cdf15,0xb5fc05be,0xdcec0356,0xa9a40022}},	//   tad_, teša, _urcă, _уиад, 
   {{0xfd4c0521,0x7648df16,0x442cdf17,0x98a0035b}},	//   _achị, agey, uad_, _еиуе, 
   {{0x442cdf18,0x2f0c0162,0x76480009,0x93740304}},	//   rad_, _nýg_, bgey, ббэт_, 
   {{0x442cdf19,0xd6243529,0xb5fc0e04,0x5b780a1e}},	//   sad_, _гоце_, mešn, ארטא, 
   {{0x442cdf1a,0xb5fcdf1b,0xd4240183,0x00000000}},	//   pad_, peša, _মাৰি_, --, 
   {{0x442cdf1c,0x24f40276,0x3e7401f2,0x66dc0023}},	//   qad_, _учер, _ụt_, rëku, 
   {{0x6aa00a55,0x3eb8000d,0x94700345,0x00000000}},	//   kkof, _pmst_, _ردوا, --, 
   {{0xd25004a9,0x7d0cdf1d,0x00000000,0x00000000}},	//   _كۆپ_, tqas, --, --, 
   {{0xe1fc9347,0xce9402e8,0x3eb8032e,0x00000000}},	// [13030] rdós_, чатъ, _vmst_, --, 
   {{0x7d0cdf1e,0x42542832,0x6aa001f5,0x823400f2}},	//   rqas, _اچھر, ekof, _ارژا, 
   {{0xb5fc1f7f,0x7d0cdf1f,0x76480009,0xd0180108}},	//   ješn, sqas, ygey, _уфы_, 
   {{0x6aa01308,0x00000000,0x00000000,0x00000000}},	//   gkof, --, --, --, 
   {{0xc7b81326,0x7d0cdf20,0xd7d801f9,0x00000000}},	//   _među_, qqas, मॅनच, --, 
   {{0x6aa00134,0x88c802bf,0x00000000,0x00000000}},	//   akof, блів_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6aa0df21,0x66f02850,0x8aa41436,0x00000000}},	//   ckof, мпју, _еруд, --, 
   {{0x76480a81,0x5fd823ef,0x64440024,0x34a8009b}},	//   rgey, _मुसल, ėkin, ивио_, 
   {{0xb5fc00f3,0x7648df22,0x6b8c02d2,0xe4540108}},	//   bešn, sgey, _öngþ, ожь_, 
   {{0x97a4df23,0x896401d9,0x00000000,0x00000000}},	//   _урал, _وُہن, --, --, 
   {{0x06f40330,0x76480009,0xe94400f1,0x00000000}},	//   _فسنج, qgey, _درېی, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2ee0df24,0x5fd80dad,0x6aa41152,0x493c001f}},	//   पत्त, _मुहल, _खत्र, _አግባብ, 
   {{0xa3c80073,0x70b8000d,0xc2c8211f,0x6aa0007c}},	//   लपण_, _उगील, _گبول_, ykof, 
   {{0xb5fcdf25,0x66dc036e,0x85540244,0x00000000}},	//   nešo, lëkr, _بییر_, --, 
   {{0xe1fc2b76,0xe5f4010f,0x00000000,0x00000000}},	// [13040] león_, ַזער_, --, --, 
   {{0x6c840075,0xdcac0d1f,0x20c00220,0xeb780798}},	//   غلام, نىق_, _ойым, исеј_, 
   {{0x643800c8,0xb5fc013a,0x00000000,0x00000000}},	//   שעענ, kešo, --, --, 
   {{0xb5fc151c,0x66dc036e,0xae580212,0x00000000}},	//   ješo, hëkr, _троє_, --, 
   {{0xe8f805f5,0xb86400f1,0x66dc036e,0x00000000}},	//   алд_, ګانو, këkr, --, 
   {{0x98a08345,0x6aa0df26,0x2a64213f,0x6d540472}},	//   миче, skof, seob_, mtya, 
   {{0xb8640597,0xeb980408,0x6aa001f5,0x6d5400a2}},	//   ثانو, _тив_, pkof, ltya, 
   {{0xb5fcdf27,0x6d5404ba,0xc6f80063,0x236c0200}},	//   rešn, otya, љних_, _rsfj_, 
   {{0x6d54df28,0xf7840139,0x00000000,0x00000000}},	//   ntya, _öçne_, --, --, 
   {{0xb5fcca39,0x81e800bd,0x44380086,0xe1fc0077}},	//   pešn, _বলল_, ûr_, feón_, 
   {{0x66e40354,0x6d546873,0xb5fc8736,0x00000000}},	//   _дожа, htya, bešo, --, 
   {{0x81d40107,0x00000000,0x00000000,0x00000000}},	//   зомх, --, --, --, 
   {{0xf60800f1,0x9924030d,0x00000000,0x00000000}},	//   _اتمه_, _гiел_, --, --, 
   {{0x65600124,0x0458007b,0xd4640139,0x00000000}},	//   _ipoh, _طلبة_, _миче_, --, 
   {{0x6d54009a,0x00000000,0x00000000,0x00000000}},	//   etya, --, --, --, 
   {{0x645808a5,0x73f8010f,0x7f54035a,0x6d542b24}},	//   lfti, _פּסו, rtzq, ftya, 
   {{0x6d549147,0x5fd80027,0xe3bc0139,0xc8bc185d}},	// [13050] gtya, _मुरल, _ğıyl_, ्चाट, 
   {{0x6458df29,0x6560009a,0xefc8001f,0xdd9002dd}},	//   nfti, _mpoh, _በልዩ_, пағы, 
   {{0xd7dc0574,0x6d5404ba,0xcd280131,0x00000000}},	//   _पुढच, atya, مسەن_, --, 
   {{0x656000b0,0x9fbc02fb,0x00000000,0x00000000}},	//   _opoh, nčím_, --, --, 
   {{0x0dc803b7,0x6e20005a,0xdde800f2,0x6d5402d0}},	//   _дури_, ñobe, _خرده_, ctya, 
   {{0x64580196,0xe0dc007f,0x9fbc01ef,0x00000000}},	//   jfti, lròb_, hčím_, --, 
   {{0x6560df2a,0x3b7c0092,0x28100b24,0xb5fc00d7}},	//   _apoh, ጣጫዎች_, رويس, tešo, 
   {{0x6458df2b,0x9fbc0030,0xb5fc01ef,0x00000000}},	//   efti, jčím_, bešl, --, 
   {{0x64580368,0xb5fc02fb,0xfeac00fe,0xd1d41954}},	//   ffti, rešo, _গদাধ, _ሩካቤ_, 
   {{0x3a2c03b2,0x33d401ec,0x80c02cc5,0x26c801e1}},	//   _heep_, зімт, _শীঘ্, _ìbon_, 
   {{0x3a2c0c3e,0x65601050,0xe8700075,0xa3dc0118}},	//   _keep_, _epoh, _سۆيگ, _pěší_, 
   {{0x45dc01f2,0x64580009,0x3a2c123b,0xd1840131}},	//   ịpụ_, afti, _jeep_, дһий, 
   {{0x6aa8257c,0x00000000,0x00000000,0x00000000}},	//   ëffi, --, --, --, 
   {{0x3ce4012d,0x00000000,0x00000000,0x00000000}},	//   कतों_, --, --, --, 
   {{0x0eb8052f,0xa3dc00bc,0xb5fc0118,0x213c031c}},	//   ҡуғы_, _těší_, zešl, ġuha_, 
   {{0x6d54df2c,0x2bc80184,0x3a2cdf2d,0xb2246584}},	//   ttya, ҡлап_, _neep_, _эмил, 
   {{0xa1100597,0x2bc805a2,0x92f401c6,0xf1a805af}},	// [13060] _كويت, әлеп_, _нүүх, _داغه_, 
   {{0x6d54df2e,0xf8a42e07,0xed580116,0xceb800fb}},	//   rtya, _شک_, _һом_, сәү_, 
   {{0x6d54df2f,0xafe401b9,0x2b380276,0x8eb400d1}},	//   stya, _хонл, сязэ_, _قەست, 
   {{0xed340323,0x3a2c031c,0xed58df30,0xaae4007b}},	//   _нэгэ, _ceep_, _лом_, أسطو, 
   {{0x3a2cdf31,0x6f04009a,0x645803b2,0x00000000}},	//   _deep_, _iikc, yfti, --, 
   {{0x6e040014,0xb5fc0010,0x5a900166,0x00000000}},	//   _وِگن, rešl, дрәф, --, 
   {{0x656000ad,0x753c01d3,0xf7840139,0x00000000}},	//   _spoh, ászn, _öçle_, --, 
   {{0xea9400ee,0xd6d4005b,0x5b38011a,0x00000000}},	//   _эшгэ, зть_, _לגלק, --, 
   {{0xd940df32,0x9c8009a8,0x79500133,0xe4e41cd0}},	//   _пети, ščet, _لێنا, зінн, 
   {{0x3a2c0d27,0x656002f0,0x00000000,0x00000000}},	//   _zeep_, _vpoh, --, --, 
   {{0x6458df33,0xb86400ec,0x00000000,0x00000000}},	//   rfti, _زالو, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6560df34,0x518400db,0x00000000,0x00000000}},	//   _upoh, нура, --, --, 
   {{0x7eb0007c,0x24f4008e,0x00000000,0x00000000}},	//   _kåpg, _эчер, --, --, 
   {{0x443cdf35,0x6f040010,0x201c00e4,0x00000000}},	//   _idv_, _bikc, ĝui_, --, 
   {{0xdef805f5,0x00000000,0x00000000,0x00000000}},	//   сыг_, --, --, --, 
   {{0x443c05d1,0x3a2c01f5,0xd01000f1,0x00000000}},	// [13070] _kdv_, _reep_, ئلې_, --, 
   {{0x3a2cdf36,0xd5e80588,0x1cb82d4b,0x5fd80037}},	//   _seep_, _hag̃, حارب_, _मुअल, 
   {{0x6f04df37,0x3a2cdf38,0x7c2817a3,0xebc000d1}},	//   _fikc, _peep_, _đerd, вәтн, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8f840014,0x00000000,0x00000000,0x00000000}},	//   _قلیٖ, --, --, --, 
   {{0x3a2cdf39,0x7d1cdf3a,0x37e41a71,0x00000000}},	//   _weep_, _itss, молг, --, 
   {{0xb8f40d54,0x670001f2,0x8c2400fe,0xf770cf01}},	//   _हद_, _ọkaa, _পাচন_, ئات_, 
   {{0x7c2400c6,0x753c01ed,0xa810008e,0x46f4004e}},	//   lbhr, ászo, ндәш, нчыт, 
   {{0x443cdf3b,0xb5fc5a54,0x7c240332,0x00000000}},	//   _bdv_, mešk, obhr, --, 
   {{0xb5fc9ae3,0x7c24df3c,0x00000000,0x00000000}},	//   lešk, nbhr, --, --, 
   {{0x620011a9,0x443c0fb7,0x3244df3d,0xc8640116}},	//   ətlə, _ddv_, менг, _ятти, 
   {{0x7c244ba3,0x443cdf3e,0xb5fcc68d,0x7d1c0857}},	//   hbhr, _edv_, nešk, _otss, 
   {{0x6f041bb7,0x7d1c05da,0x443cdf3f,0xd5e800db}},	//   _rikc, _ntss, _fdv_, _اعان_, 
   {{0x6f040309,0xc5f40032,0xe6b40150,0x443c0051}},	//   _sikc, _яғы_, _ىلەگ, _gdv_, 
   {{0x6f04df40,0x7d1cdf41,0x7c24df42,0x00000000}},	//   _pikc, _atss, dbhr, --, 
   {{0xb5fc1e31,0x0ef800e1,0x00000000,0x00000000}},	//   ješk, ंगेस_, --, --, 
   {{0x3f8003f9,0xdee073ea,0x601402e3,0xb5fc0010}},	// [13080] _erhu_, тоти, ụmad, dešk, 
   {{0x6f04df43,0x7d1c02d0,0xe0dc180f,0x7c240332}},	//   _wikc, _dtss, rròc_, gbhr, 
   {{0x7d1c0857,0x4a443e28,0x00000000,0x00000000}},	//   _etss, емең, --, --, 
   {{0xada4036b,0x7c249a14,0xd0240150,0xa96801b9}},	//   _жамл, abhr, _توگۋ, жида_, 
   {{0x0d840032,0xfe5401d5,0x888401ec,0x00000000}},	//   _яһан, _سیلب_, нғал, --, 
   {{0xfbd806bc,0xab2806bb,0x61e85522,0x48dc03d4}},	//   _बुकम, _мога_, _øgle, যগ্ৰ, 
   {{0x443cdf44,0xb5fc0219,0x1d040395,0x00000000}},	//   _rdv_, bešk, _цери_, --, 
   {{0x6a841cd1,0x20040030,0x2d8046aa,0x857400a7}},	//   _юлба, _únie_, _krke_, елих, 
   {{0x443c071b,0x7d0810d8,0x7e6800e4,0x00000000}},	//   _pdv_, _éest, _ñepe, --, 
   {{0x83fc07f5,0x0aa40116,0x00000000,0x00000000}},	//   leđi, _юңҗү, --, --, 
   {{0x7eb0964d,0x6f1c02d0,0x675400ae,0x00000000}},	//   _håpe, _ntpc, _زخار, --, 
   {{0xe5c47549,0xa50815a0,0x7eb000d4,0x1618012c}},	//   _осло, _деда_, _kåpe, _नभएर_, 
   {{0x947003e6,0x00000000,0x00000000,0x00000000}},	//   ردیا, --, --, --, 
   {{0x443cdf45,0xca4c02dd,0x00000000,0x00000000}},	//   _udv_, _ﺃﻴﺔ_, --, --, 
   {{0x2d80bec7,0x4fc4df46,0x00000000,0x00000000}},	//   _arke_, вста, --, --, 
   {{0x2d8001fa,0x83fc2804,0xc87803b9,0x00000000}},	//   _brke_, jeđi, _lağ_, --, 
   {{0xb5fc151c,0x81e800cc,0x68e80175,0x00000000}},	// [13090] vešk, _বলক_, klfd, --, 
   {{0x3f800232,0x395800e2,0x7c240332,0xa2b808ec}},	//   _trhu_, _īss_, ubhr, शोर्, 
   {{0x2d80df47,0x7c24df48,0x00000000,0x00000000}},	//   _erke_, rbhr, --, --, 
   {{0x2d8005a1,0x3af403cd,0x7c240332,0x00000000}},	//   _frke_, kåpe_, sbhr, --, 
   {{0x3ea80de2,0xe1fc00dd,0x2d800e3c,0x7e6c5109}},	//   mkat_, deók_, _grke_, meap, 
   {{0x3ea80694,0x7e6cdf49,0x7eb0143a,0xea240137}},	//   lkat_, leap, _dåpe, _үчтү, 
   {{0xc8781ae4,0x83fc009b,0xb5fc3a50,0x00000000}},	//   _dağ_, beđi, pešk, --, 
   {{0x3ea8df4a,0x2d80ce29,0xb5fcaaf3,0x68e80373}},	//   nkat_, _yrke_, leši, alfd, 
   {{0xf504df4b,0x3ea8df4c,0x7d080798,0x39580036}},	//   нзио, ikat_, _éess, _ëss_, 
   {{0xb5fcdf4d,0x97a41d9b,0x7e6c007b,0x3ea80108}},	//   neši, _орел, heap, hkat_, 
   {{0x3ea8df4e,0x7e6cdf4f,0x5fd89a28,0x21a001b9}},	//   kkat_, keap, _मँगल, қирм, 
   {{0xa25806d9,0x3ea80de2,0xc6a401c6,0xeb90010f}},	//   siôn, jkat_, _ирчи, אָש_, 
   {{0x7e6c0276,0xc8780259,0xb5fcb972,0xa3dc00bc}},	//   deap, _yağ_, keši, _měří_, 
   {{0xb5fc1f7f,0x0ef8c725,0xdee002a9,0x3ea8340f}},	//   ješi, ंग्स_, ҳоси, ekat_, 
   {{0xb4bc05ba,0x3ea8df50,0x7e6c014a,0xb5fc0006}},	//   ीची_, fkat_, feap, deši, 
   {{0x3ea8df51,0x7e6c005c,0xdee0668b,0x00000000}},	//   gkat_, geap, госи, --, 
   {{0xac846d5f,0x9d400ce8,0x00000000,0x00000000}},	// [130a0] нгал, летд, --, --, 
   {{0xdd000724,0xe1f40ede,0x5f4001b9,0x7eb000b8}},	//   ırğa, _ягы_, خچیل, _råpe, 
   {{0x3ea80548,0x20540375,0xfe000034,0x09a807d0}},	//   bkat_, _אייל_, लेबस_, कन्य, 
   {{0xc8784a4a,0x3ea8df52,0x2d800384,0x7e6cdf53}},	//   _sağ_, ckat_, _trke_, ceap, 
   {{0x83fc0b91,0xf53801a2,0x7bc0012c,0xa2580268}},	//   ređi, jsť_, _žlut, diôl, 
   {{0x998027e9,0x200400f7,0x7eb003a1,0x6e34df54}},	//   الوو, _únic_, _våpe, layb, 
   {{0x7d08011c,0xf5380030,0x5774007b,0x6aa80036}},	//   _èesa, esť_, فصيح_, ëffs, 
   {{0x6e34df55,0x7eb0143a,0x3af438be,0xba3c01ef}},	//   nayb, _tåpe, _аяус, _slův, 
   {{0xd614004b,0x0cc4015b,0xc87806be,0x00000000}},	//   رتيا_, ্তীত, _tağ_, --, 
   {{0x6e3411f2,0x3ea8009d,0xd4940108,0x27b4009b}},	//   hayb, zkat_, ерю_, _пљес, 
   {{0x3ea80694,0xd6cc00c0,0xca74001f,0x1cb40375}},	//   ykat_, _бт_, _በምንም_, גליל_, 
   {{0x3ea8df56,0x5fd80210,0x00000000,0x00000000}},	//   xkat_, _मुगल, --, --, 
   {{0x64a4df57,0x6e34df58,0x3ea8df59,0x7e6c0418}},	//   _пада, dayb, vkat_, veap, 
   {{0xd48cc97d,0x5574010f,0x3ea8df5a,0xe5c401e0}},	//   _ёр_, _רעגן_, wkat_, _осһо, 
   {{0x3ea8df5b,0x7e6c084c,0x98ac0153,0x5fd82c2e}},	//   tkat_, teap, augė_, _मुखल, 
   {{0x41b4c019,0x3ea8002e,0x7eb0007c,0x6e344f45}},	//   _لمبر, ukat_, _såpb, gayb, 
   {{0x7e6cdf5c,0xb5fcdf5d,0xbc780064,0x00000000}},	// [130b0] reap, teši, мбах_, --, 
   {{0x3ea8df5e,0x7e6cdf5f,0x629c01a9,0x00000000}},	//   skat_, seap, _hoqo, --, 
   {{0x6e34df60,0x3b540598,0x629c4b2a,0xb5fc46aa}},	//   bayb, ткер, _koqo, reši, 
   {{0x60c4df61,0x3ea8df62,0x629c0135,0x6e3462f5}},	//   lijm, qkat_, _joqo, cayb, 
   {{0x629cdf63,0x2ec0df64,0xb224005c,0xa3dc00bc}},	//   _moqo, _төрм, _hjææ, _věří_, 
   {{0xa9a09794,0xf744df65,0x629cdf66,0xa25800d8}},	//   ришд, веко, _loqo, diôm, 
   {{0x3774df67,0x3584001f,0xd7f8df68,0x2c14033f}},	//   тылс, ናይትድ_, чуд_, दुओं_, 
   {{0x629c0a81,0xccf4013f,0x60c40200,0x66b000d8}},	//   _noqo, ntɛn_, hijm, ибју, 
   {{0x60c40113,0x49440209,0x00000000,0x00000000}},	//   kijm, _бэхб, --, --, 
   {{0xb4bc256b,0x8858084c,0x00000000,0x00000000}},	//   ीचे_, _пиус_, --, --, 
   {{0x629cdf69,0x6e34058a,0x00000000,0x00000000}},	//   _boqo, yayb, --, --, 
   {{0x629c022f,0x83fc2804,0x6e340067,0xb5fc013a}},	//   _coqo, jeđu, xayb, dešv, 
   {{0x629c01d9,0x6a380375,0x618c02d3,0x77a401d9}},	//   _doqo, וגרפ, _ቅዋማዊ_, _سێکہ_, 
   {{0x64a0df6a,0x00000000,0x00000000,0x00000000}},	//   _ваша, --, --, --, 
   {{0x8d780201,0xafe49dc2,0x629c01ee,0xfaf806c8}},	//   _ያላቸው_, товл, _foqo, _ohū_, 
   {{0x7c280e04,0xee3806ed,0x00000000,0x00000000}},	//   _đera, ќна_, --, --, 
   {{0xec78d29c,0x6e34df6b,0x60c40477,0x753c00e5}},	// [130c0] мпа_, rayb, bijm, ászh, 
   {{0xb5fc0770,0x629c4b2a,0x2134008f,0x9c8402f0}},	//   sešw, _zoqo, _שטיל_, vyčí, 
   {{0x83fc0114,0x629cdf6c,0xe0dc067c,0xfaf800cd}},	//   beđu, _yoqo, iròl_, _bhū_, 
   {{0x629c0548,0x4420054e,0x200400d0,0x6e340067}},	//   _xoqo, _și_, _únia_, qayb, 
   {{0x3864df6d,0x597001b9,0x00000000,0x00000000}},	//   _bblr_, لدوز, --, --, 
   {{0x48d000bd,0x7d080798,0xb5fc7a23,0x00000000}},	//   িত্র, _éesp, nešu, --, 
   {{0x7eb003d4,0x98a0026a,0x00000000,0x00000000}},	//   _håpa, рије, --, --, 
   {{0x7eb001e3,0x442001ef,0x00000000,0x00000000}},	//   _kåpa, _ři_, --, --, 
   {{0x629cdf6e,0x44200b45,0x395c015d,0x287401af}},	//   _roqo, _ƙi_, ctws_, _аҡлы_, 
   {{0x629c03b4,0xb5fc2630,0x00000000,0x00000000}},	//   _soqo, ješu, --, --, 
   {{0x629c02d1,0x537802d3,0xb74400db,0x00000000}},	//   _poqo, _ይካየድ_, _مئنو, --, 
   {{0x271c00b4,0xd7ec00c6,0x629cdf6f,0x386804a7}},	//   _ọnwa_, _بكم_, _qoqo, đare_, 
   {{0xe5704d1c,0x84c41945,0x60c4df70,0xb6d8010f}},	//   _خطا_, _бәнд, tijm, _אַסט, 
   {{0x629c0014,0xe1fc0210,0x00000000,0x00000000}},	//   _woqo, zeów_, --, --, 
   {{0xcfa4df71,0x629cdf72,0x6da4013f,0x60c4df73}},	//   ашти, _toqo, hɔad, rijm, 
   {{0x3af4050a,0x9c84013a,0xc17400d4,0x00000000}},	//   kåpa_, _občá, _блищ, --, 
   {{0x83fc098d,0xbdf40063,0x3df46d64,0x76340055}},	// [130d0] ređu, упај, узас, _ṭakā, 
   {{0xb5fc026a,0x5b2401c0,0x60c4047e,0x1bb800ae}},	//   mešt, вьда, qijm, واضع_, 
   {{0x656c0882,0x7ed40014,0x9f4401e1,0x00000000}},	//   ābhy, _مٲدا, _ánà_, --, 
   {{0x3ae80330,0x00000000,0x00000000,0x00000000}},	//   ربای_, --, --, --, 
   {{0xb5fc4a52,0x4a4402bf,0x7e7cca7e,0x81e4015b}},	//   nešt, рнів, _iasp, ভের_, 
   {{0xfaf802b5,0xac7c0092,0x00000000,0x00000000}},	//   _whū_, _የፊልም_, --, --, 
   {{0x7e7cdf74,0x68f8009f,0x7c34003a,0x067000d1}},	//   _kasp, _dhtd, _iezr, ﺳﻠﯩﮕ, 
   {{0xe0dc067c,0x7c34010b,0x0f58011a,0x00000000}},	//   dròm_, _hezr, דיהם_, --, 
   {{0xb5fc1727,0x7ae8df75,0xa2d421b8,0x18b000d1}},	//   ješt, _iket, मचन्, _вәйр, 
   {{0x7e7cdf76,0x7c3405da,0xd8745756,0xb5fc00d7}},	//   _lasp, _jezr, _جارب, dešt, 
   {{0xba000201,0x7e7c0276,0x7ae8020c,0x04b801ed}},	//   _ሌላ_, _oasp, _kket, ڑپیں_, 
   {{0x7e7cdf77,0x78a00978,0xd94802d3,0x7c34030a}},	//   _nasp, _holv, _ብተደጋ, _lezr, 
   {{0xd3448db7,0x78a0df78,0xb5fc00d7,0x00000000}},	//   ریکه_, _kolv, tešu, --, 
   {{0x7ae801ee,0x78a00455,0x7e7c0254,0x2290237e}},	//   _lket, _jolv, _aasp, _ۇلىس, 
   {{0x7ae8df79,0x78a0047e,0x7eb0df7a,0x7e7cdf7b}},	//   _oket, _molv, _såpa, _basp, 
   {{0x7e7cdf7c,0x78a01509,0x7ae8dec0,0xb8d4025c}},	//   _casp, _lolv, _nket, _ཝཾ_, 
   {{0x7e7cdf7d,0x7c34df7e,0xa154009b,0x00000000}},	// [130e0] _dasp, _bezr, _бању_, --, 
   {{0x0cc40c58,0x7ae80c8c,0x7e7c00c6,0x7c3400d7}},	//   ্ত্ত, _aket, _easp, _cezr, 
   {{0x7c340489,0x6da4013f,0xc5f001ad,0x7e7c0356}},	//   _dezr, wɔad, _चर्य_, _fasp, 
   {{0xe9d8d979,0xbae410f5,0x7ae80998,0x68f801a9}},	//   нке_, ацій, _cket, _shtd, 
   {{0x78a0df7f,0x5a3002bf,0x9e600c98,0xdfcc0150}},	//   _bolv, сніт, _увяд, _ويۋ_, 
   {{0x7ae8052f,0xe0dc0561,0xf8b40124,0xc8c800ec}},	//   _eket, buòu_, аҩу_, ضوعن_, 
   {{0x7ae80093,0x78a0014f,0x3b0c0327,0x7e7cdf80}},	//   _fket, _dolv, _fieq_, _yasp, 
   {{0x7c3413fd,0x779011fc,0xd6d40132,0xd7c00490}},	//   _zezr, تیما, лты_, _वेळच, 
   {{0x45d40b7f,0x49080022,0x78a0003a,0x7bd80311}},	//   ропс, _адаҟ_, _folv, ăbuţ, 
   {{0xb5fc026a,0xb864df81,0x78a0df82,0xa2580109}},	//   vešt, _نامو, _golv, piôk, 
   {{0x7ae89f4e,0x00000000,0x00000000,0x00000000}},	//   _yket, --, --, --, 
   {{0x78a001c7,0xb5fc00d7,0x00000000,0x00000000}},	//   _zolv, tešt, --, --, 
   {{0x26c4022f,0x15400209,0x63b801d3,0x78a0df83}},	//   _imoo_, _гечм, sztn, _yolv, 
   {{0x7e7cdf84,0x26c40070,0xb5fcdc02,0xe1fc01d3}},	//   _sasp, _hmoo_, rešt, deót_, 
   {{0x7e7cdf85,0xb5fc0427,0x753c00e5,0x00000000}},	//   _pasp, sešt, ászv, --, 
   {{0x4ea47966,0x7e7c0978,0x6d9c0cad,0x00000000}},	//   бруа, _qasp, _ṣaaj, --, 
   {{0x7e7c4beb,0x26c4df86,0x1d8c0092,0x7c34007c}},	// [130f0] _vasp, _mmoo_, _መያያዣ_, _pezr, 
   {{0x7e7c8f0a,0x3b0c0135,0x00000000,0x00000000}},	//   _wasp, _sieq_, --, --, 
   {{0x7f94df87,0x7e7cdf88,0x78a0be79,0x7e6800c7}},	//   _танх, _tasp, _rolv, _ñepo, 
   {{0xfc441893,0xcfbc03d4,0xcb340395,0x00000000}},	//   _چھاپ, _আঁচন, сецъ, --, 
   {{0xd90cdf89,0x7c3401b9,0x00000000,0x00000000}},	//   سیا_, _tezr, --, --, 
   {{0x26c4df8a,0x64dc0574,0x7c3401f0,0x7eb001e3}},	//   _amoo_, नकोश, _uezr, _kåpo, 
   {{0x78a0df8b,0x00000000,0x00000000,0x00000000}},	//   _volv, --, --, --, 
   {{0x7ae80117,0xb6a4084c,0xe3c8008e,0x291401e7}},	//   _uket, риил, _moñı_, údaí_, 
   {{0x78a0df8c,0x00000000,0x00000000,0x00000000}},	//   _tolv, --, --, --, 
   {{0x26c40093,0x3364df8d,0x7988127b,0xa5f40063}},	//   _emoo_, авог, _irew, шењу_, 
   {{0xf798df8e,0x33d40220,0xefc80023,0xd7f8004e}},	//   _جناب_, ріпт, _በልዎ_, _чуа_, 
   {{0x6d740084,0x8b08012c,0x7988df8f,0x00000000}},	//   _ḽiṅ, mořá, _krew, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x75288099,0x442cdf90,0x00000000,0x00000000}},	//   mpez, cbd_, --, --, 
   {{0x9fc47ffa,0x7528010f,0x7eb0143a,0xb9ec0023}},	//   агра_, lpez, _våpn, _ዕጫ_, 
   {{0xee24df91,0x7988df92,0x8cd80456,0x00000000}},	//   рмап, _orew, _मदहो, --, 
   {{0x7528df93,0x2b380276,0xece801f4,0x00000000}},	// [13100] npez, ӂязэ_, вдал_, --, 
   {{0x326001d9,0x7eb02dba,0xceb81cd1,0xef183225}},	//   _اچھہ, _håpl, тәү_, _имо_, 
   {{0x7988df94,0x720404d3,0x2b38084c,0x00000000}},	//   _arew, _حوکم, тязэ_, --, 
   {{0x7988df95,0x80248235,0x1dc408a3,0x15f400bc}},	//   _brew, _پریم, _रेवत, ुधार_, 
   {{0x7988df96,0x3a28094a,0x6fc80a59,0x00000000}},	//   _crew, ñapa_, _हेतू, --, 
   {{0x7988068f,0x26c402a4,0x2ef0017a,0x00000000}},	//   _drew, _smoo_, llyf_, --, 
   {{0x79882f05,0x6a9402bf,0xd75400e3,0xdca00022}},	//   _erew, _крає, لجيا_, _ьари, 
   {{0x386808a4,0xa924021b,0x79880100,0x1ae0df97}},	//   đara_, _вдал, _frew, _досм, 
   {{0x79884d0e,0xdcec054e,0xc94400c7,0x00000000}},	//   _grew, _uscă, _ыдақ, --, 
   {{0x45d4036b,0x1be800af,0x28f800c0,0x00000000}},	//   _қолс, _जुडल_, _рэбэ_, --, 
   {{0xd494010b,0x79880210,0x00000000,0x00000000}},	//   рры_, _zrew, --, --, 
   {{0x26c40280,0x7c2800f3,0x442cdf98,0x00000000}},	//   _umoo_, _đerm, sbd_, --, 
   {{0x442c020b,0xe3c80139,0x753c01d3,0xd13800d8}},	//   pbd_, _soñı_, ászt, ихр_, 
   {{0x104807d6,0xd5ac0133,0x14f00006,0x00000000}},	//   ияси_, _تفه_, _дзіў, --, 
   {{0x937475a6,0x040400bd,0x1ee401b9,0x69dc0205}},	//   _نصير_, _শ্রী_, لوسی_, şpeh, 
   {{0xdef843b6,0x38b83ae2,0xf1a803e6,0x7f94020a}},	//   тыг_, _ière_, _ڕاپه_, _ғамх, 
   {{0x7cd801c0,0xfe0005b3,0x00000000,0x00000000}},	// [13110] гмар_, लेंस_, --, --, 
   {{0x4cb80153,0x00000000,0x00000000,0x00000000}},	//   алую_, --, --, --, 
   {{0xfb8802dd,0x200400a3,0x00000000,0x00000000}},	//   ырақ_, _àni_, --, --, 
   {{0x38b820ef,0x7988df99,0xdb2002d2,0x00000000}},	//   _mère_, _prew, _þrík, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x08c4109a,0xa3b4012d,0x6a8400e5,0x3cc00354}},	//   обін, छना_, véfő, _хιор, 
   {{0x7988c3af,0x7d040175,0xb6a4010b,0x765c0100}},	//   _wrew, mmhs, йикл, òsyo, 
   {{0x7988df9a,0xe6900131,0x00000000,0x00000000}},	//   _trew, كلىد, --, --, 
   {{0x38b80ba1,0x7988df9b,0x9868df9c,0xc98401f0}},	//   _pèrd_, _urew, _لحاف_, _муфи, 
   {{0x8b08012c,0x00000000,0x00000000,0x00000000}},	//   pořá, --, --, --, 
   {{0x7528df9d,0x972001d3,0x7d040332,0x00000000}},	//   spez, _بہبو, imhs, --, 
   {{0x752831ca,0x66dc1d86,0xef1801d5,0x00000000}},	//   ppez, tīke, ғма_, --, 
   {{0x6498499d,0xdce40118,0x2ef00175,0x86c40127}},	//   ттөр_, íměs, vlyf_, _بينن, 
   {{0xe5a001c6,0x00000000,0x00000000,0x00000000}},	//   _хиши, --, --, --, 
   {{0x38b8004a,0x00000000,0x00000000,0x00000000}},	//   _gère_, --, --, --, 
   {{0x6280016b,0x4918000d,0x00000000,0x00000000}},	//   _ɔnok, _पढलो_, --, --, 
   {{0xc1d40209,0x59a401f9,0x00000000,0x00000000}},	// [13120] _дөрә, _कॅलर, --, --, 
   {{0xdd8cdf9e,0xa0640408,0x7c640116,0x00000000}},	//   عول_, _лаьа_, قامل, --, 
   {{0xab64030d,0xe1fc0aa6,0x00000000,0x00000000}},	//   свел, nfón_, --, --, 
   {{0xe0dc0428,0x8eb4313e,0x94f40327,0x00000000}},	//   quòr_, _بەرت, _པེའི_, --, 
   {{0x2054004e,0x7bd8002f,0x00000000,0x00000000}},	//   _ттөр, ßwur, --, --, 
   {{0x6d54df9f,0x2b140022,0xdbb80116,0x00000000}},	//   muya, _гьар, _өтсә_, --, 
   {{0x6d54dfa0,0xb864dfa1,0xe7840fc0,0xe76801f7}},	//   luya, تانو, суло, احتن_, 
   {{0xc6f80640,0x00000000,0x00000000,0x00000000}},	//   јних_, --, --, --, 
   {{0x6d5423e0,0xe8f819c3,0x996800e5,0x00000000}},	//   nuya, _бла_, _مجلہ_, --, 
   {{0x38b8dfa2,0x44389655,0xb5fc00d0,0x54b40166}},	//   _père_, úr_, rešp, йгыя_, 
   {{0x6d54dfa3,0xf7c808b0,0x7aec0311,0x83f8dfa4}},	//   huya, ﻪﺭﻟﻪ, _întî, ренс_, 
   {{0x3f840321,0x68e80072,0x92580108,0x00000000}},	//   ælum_, lofd, бают_, --, 
   {{0x9c800f72,0xe1fc00ae,0x92580395,0x00000000}},	//   ščit, afón_, щаят_, --, 
   {{0x6d541c06,0x200402fb,0x6ec400bc,0x00000000}},	//   duya, _únik_, रोसँ, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d540810,0x68e8017a,0x00000000,0x00000000}},	//   fuya, hofd, --, --, 
   {{0x6d54dfa5,0x925800db,0x645801f5,0x00000000}},	// [13130] guya, _اشىر_, ogti, --, 
   {{0x6458dfa6,0x4254072d,0x00000000,0x00000000}},	//   ngti, _انکر, --, --, 
   {{0x11d40150,0x6458dfa7,0x00000000,0x00000000}},	//   _وتۋد, igti, --, --, 
   {{0xb9b473c5,0xb8840241,0xf1c80419,0x7c28371e}},	//   يماع, _oníì, stáť_, _şerd, 
   {{0x5d3000dd,0xfbd42c2e,0x00000000,0x00000000}},	//   _رہائ, _दशकम, --, --, 
   {{0x77600477,0x6b800210,0x00000000,0x00000000}},	//   _pqlx, łoga, --, --, 
   {{0xab7c001f,0x3eb80008,0xc7640131,0xe7340395}},	//   _የፋይል_, _klst_, كايى, оещ_, 
   {{0x6458dfa8,0x00000000,0x00000000,0x00000000}},	//   egti, --, --, --, 
   {{0x38b8068c,0x3eb80334,0x00000000,0x00000000}},	//   _vèrb_, _mlst_, --, --, 
   {{0xd344168d,0x645801e3,0x00000000,0x00000000}},	//   میته_, ggti, --, --, 
   {{0xdef402d3,0x6d540526,0x3eb84174,0x00000000}},	//   ላምን_, zuya, _olst_, --, 
   {{0x91a002e3,0x64585363,0x00000000,0x00000000}},	//   _ndị_, agti, --, --, 
   {{0x0698007b,0x3f4400e2,0xc0600b82,0x539c0023}},	//   _دخلت_, eķu_, _ድምጽን_, _ውፉያት_, 
   {{0x6d54dfa9,0x628803b2,0x82600023,0x00000000}},	//   vuya, _ógon, _ጉጂለታ, --, 
   {{0x6d540c09,0x82340050,0xe4fc000d,0x00000000}},	//   wuya, _کر٘ا, _उठति_, --, 
   {{0x7f1802dd,0x6d54dfaa,0xdcfc002b,0x25b00210}},	//   сіру_, tuya, _āvās, _żyli_, 
   {{0xed58dfab,0x0dcc001f,0xacc800c7,0x0df80240}},	// [13140] роз_, _በይፋ_, агаз_, ላልፎ_, 
   {{0x6d54dfac,0x3eb8dfad,0xdc480116,0x00000000}},	//   ruya, _elst_, لسمۇ_, --, 
   {{0x3eb8002d,0x6d54dfae,0x00000000,0x00000000}},	//   _flst_, suya, --, --, 
   {{0xed58dfaf,0x613401f2,0xa2580419,0xed3401af}},	//   _ком_, ụleg, chôd, _мэгэ, 
   {{0x7c284252,0x6d54dfb0,0x64587c52,0x68e80b4f}},	//   _şere, quya, ygti, tofd, 
   {{0x5fcc0034,0xceb403be,0x6d4400d7,0x27481d39}},	//   _हेडल, lkə_, _ivka, ачио_, 
   {{0xa098008d,0x68e8dfb1,0xe8a801f9,0x00000000}},	//   ייסט, rofd, _कवीच, --, 
   {{0x8698798c,0x7c2800f3,0x68e8022e,0xceb403e3}},	//   скис_, _đeri, sofd, nkə_, 
   {{0x644c00d8,0x00000000,0x00000000,0x00000000}},	//   óbio, --, --, --, 
   {{0x6aa000f3,0x69c001f7,0x00000000,0x00000000}},	//   ljof, mzoe, --, --, 
   {{0x4394dfb2,0x69c001a4,0x6458dfb3,0xceb403e3}},	//   чанс, lzoe, rgti, kkə_, 
   {{0x38b80ba1,0x69c0009f,0x6d44022e,0x200400d0}},	//   _ièra_, ozoe, _ovka, _únii_, 
   {{0x69c00196,0x38b8180f,0x7e6800e4,0xe4a40114}},	//   nzoe, _hèra_, _ñepi, _мрко, 
   {{0x84380597,0x69c0dfb4,0x3e74004d,0x00000000}},	//   _اكثر_, izoe, _ất_, --, 
   {{0x6d4478c8,0x443cdfb5,0x6448035a,0x752c0327}},	//   _avka, _iev_, _idfi, _ħazi, 
   {{0x443cdfb6,0x1ee40214,0xe2a801b9,0x3f4400e2}},	//   _hev_, آوری_, _خاتن_, rķu_, 
   {{0x443cdfb7,0x6b8c929f,0xdbc41073,0x7d5402e8}},	// [13150] _kev_, _arbg, nöör, явах, 
   {{0x6b8c01ab,0x7c28dfb8,0x69c001f5,0x443cdfb9}},	//   _brbg, _şerb, dzoe, _jev_, 
   {{0x443cdfba,0x6d440010,0x69c0003e,0xdce405d1}},	//   _mev_, _evka, ezoe, çlıd, 
   {{0x443cdfbb,0x3f80b3ae,0xda640451,0xdbc416ca}},	//   _lev_, _ishu_, تائي, köör, 
   {{0x6b8c0003,0x27fc01a6,0x644802f0,0x00000000}},	//   _erbg, _aztn_, _odfi, --, 
   {{0x443cdfbc,0x7d1c0483,0x38b8068c,0x3f800023}},	//   _nev_, _iuss, _bèra_, _kshu_, 
   {{0xdb2004fb,0x6d440810,0xcb442069,0x7c240332}},	//   _آوری, _zvka, _охти, mchr, 
   {{0x7c24dfbd,0x64481730,0x3f800113,0x66dc0f40}},	//   lchr, _adfi, _mshu_, tīka, 
   {{0x443cdfbe,0x7c24dfbf,0xdef4001f,0x3f800200}},	//   _bev_, ochr, ላምና_, _lshu_, 
   {{0x7d1cdfc0,0x443c0190,0x00000000,0x00000000}},	//   _muss, _cev_, --, --, 
   {{0x7d1cdfc1,0x7d140369,0x443c9b1e,0x7c240112}},	//   _luss, _mizs, _dev_, ichr, 
   {{0x7d140399,0x443c0327,0x7c24dfc2,0x66dc00b0}},	//   _lizs, _eev_, hchr, pīka, 
   {{0x3f800084,0x3494109a,0xe56cdfc3,0x443cdfc4}},	//   _ashu_, _надр, _яз_, _fev_, 
   {{0x7d14dfc5,0x443cdfc6,0x7c2415c0,0xc5f400fb}},	//   _nizs, _gev_, jchr, _юғы_, 
   {{0x7d1cdfc7,0x7c24007b,0x6d4400b5,0xe454008f}},	//   _auss, dchr, _svka, _זיצט_, 
   {{0x7d140029,0xb1443a4e,0x644801a6,0x443c834c}},	//   _aizs, _енил, _zdfi, _zev_, 
   {{0x7d1c1675,0x443cdfc8,0x7c24009f,0xc3040133}},	// [13160] _cuss, _yev_, fchr, _تبوو, 
   {{0x7d140007,0x443c0441,0x7038084c,0x7c240332}},	//   _cizs, _xev_, _учис_, gchr, 
   {{0x7d1cdfc9,0x7d140165,0xe0dc0ba1,0xed58013e}},	//   _euss, _dizs, rròt_, роҷ_, 
   {{0x7d1cdfca,0x69c00d27,0x38b800e4,0x6d44afd7}},	//   _fuss, tzoe, _rèra_, _tvka, 
   {{0x7d1cdfcb,0x8884dfcc,0xe0dc004e,0x69c0009f}},	//   _guss, мғал, cròs_, uzoe, 
   {{0x69c00460,0x2d800724,0x7c24dfcd,0x38b804cc}},	//   rzoe, _iske_, cchr, _pèra_, 
   {{0x7d1c0d27,0x69c04174,0x443cdfce,0x00000000}},	//   _zuss, szoe, _rev_, --, 
   {{0x443cdfcf,0x85b844b2,0xdbc4b6a5,0x7d1cdfd0}},	//   _sev_, жлис_, töör, _yuss, 
   {{0x443c01d4,0x7d1c0067,0x6448dfd1,0x00000000}},	//   _pev_, _xuss, _pdfi, --, 
   {{0x443cdfd2,0x7d08011c,0xa8040724,0x38b80561}},	//   _qev_, _èest, _ciñü, _hèrn_, 
   {{0x443cdfd3,0x6f1cdfd4,0x42540244,0xdbc40254}},	//   _vev_, _nupc, وندر, söör, 
   {{0x443c0218,0x2d80dfd5,0x92580c9e,0xdbc400c5}},	//   _wev_, _oske_, пают_, pöör, 
   {{0x443cdfd6,0x2d800589,0x7c24dfd7,0x02ac0073}},	//   _tev_, _nske_, ychr, _चवीन, 
   {{0x443c0076,0x00000000,0x00000000,0x00000000}},	//   _uev_, --, --, --, 
   {{0x7d1cdfd8,0x2d80dfd9,0x7d1401d3,0xd36c00d4}},	//   _suss, _aske_, _rizs, _яч_, 
   {{0x7d1cdfda,0x7d14dfdb,0xd010117d,0x7c240042}},	//   _puss, _sizs, الِ_, wchr, 
   {{0x7c24dfdc,0x7d1cd3c2,0x66dc02b5,0xcd740395}},	// [13170] tchr, _quss, hīko, нгтъ, 
   {{0x3f80dfdd,0x7d1c1b5a,0xe0dc26b7,0x273805c7}},	//   _tshu_, _vuss, rròs_, kūn_, 
   {{0x2d800699,0x7d1400dd,0x7c24dfde,0x7d1c3262}},	//   _eske_, _vizs, rchr, _wuss, 
   {{0x7d1cdfdf,0x7c24dfe0,0x7a400153,0x00000000}},	//   _tuss, schr, kštų, --, 
   {{0x67380227,0x7d1c1b99,0x5ed00154,0x9c8002f0}},	//   _awtj, _uuss, থকদে, áčst, 
   {{0x9ce401ed,0xb7940114,0x5ce401a9,0x00000000}},	//   _روزے_, дрић, _хюма, --, 
   {{0x98a001e0,0xb6a4dfe1,0x00000000,0x00000000}},	//   диҙе, дийл, --, --, 
   {{0x7e6cdfe2,0xa5600214,0x200400d7,0x00000000}},	//   nfap, چگون, _úniu_, --, 
   {{0x7d08011c,0xc64800c6,0xa560dfe3,0x7e6800e4}},	//   _èess, سجيل_, نگون, _ñepu, 
   {{0xf3480484,0x57200137,0x00000000,0x00000000}},	//   опол_, _كۉتك, --, --, 
   {{0x96e8005b,0x7bc40200,0xb38c1954,0x00000000}},	//   _льда_, nzhu, _ህያዋን_, --, 
   {{0x35b45aa6,0x23c00214,0xc04808a8,0xe3c81bce}},	//   _обер, _séjé_, _כז_, _soññ_, 
   {{0x21a0023a,0x81b000fe,0x00000000,0x00000000}},	//   виям, _টেব_, --, --, 
   {{0x6ad80303,0x6f1c047e,0x3cf8033f,0xd5840352}},	//   _भद्र, _pupc, ्गों_, _дәүл_, 
   {{0xa064dfe4,0x7e6cdfe5,0x6e9407d2,0xbef80490}},	//   ьара_, ffap, ولسا, ंतून_, 
   {{0xf8a404d3,0x61340521,0x00000000,0x00000000}},	//   _ڵک_, ụlag, --, --, 
   {{0xac84dfe6,0x9d400440,0x7bc40156,0x2ca80208}},	// [13180] мгал, кетд, ezhu, _pobd_, 
   {{0x6bd4015e,0x6f1c02f0,0x00000000,0x00000000}},	//   وتار, _tupc, --, --, 
   {{0xaf04dfe7,0x8eb457d4,0x00000000,0x00000000}},	//   _опол, _كەست, --, --, 
   {{0xe0dc02e2,0x480800c7,0x00000000,0x00000000}},	//   nsòn_, ҧҵан_, --, --, 
   {{0x07282e56,0x2d80041a,0x7bc40165,0x59340006}},	//   _ﻣﯩﯔ_, _uske_, azhu, дзіў_, 
   {{0x6e340158,0xe7740166,0x8884691d,0x00000000}},	//   lbyb, дакә_, عیان, --, 
   {{0xdb800e58,0xb810009e,0xe0dc007f,0x00000000}},	//   _игри, _স্বত_, ksòn_, --, 
   {{0x66dc00da,0x6d54058a,0x00000000,0x00000000}},	//   rīko, orya, --, --, 
   {{0xe5c41de1,0xe4e402bf,0xe96807a5,0x00000000}},	//   ьско, дінн, _фазл_, --, 
   {{0x29080295,0x7eb00217,0x66dc0270,0x394801e4}},	//   _òba_, _håpt, pīko, ɩas_, 
   {{0xb864dfe8,0x9f28025c,0x38b80ba1,0x00000000}},	//   _سالو, _ཧཕེཀ_, _zèro_, --, 
   {{0x92940953,0x6d540687,0xf98000c7,0x00000000}},	//   ваюц, krya, _рҳәо, --, 
   {{0xf8b80428,0x3a2802d1,0x60cc022e,0x64a40024}},	//   _itũr_, ñapi_, аnmа, _оада, 
   {{0x6600dfe9,0x6d54dfea,0x00000000,0x00000000}},	//   _izok, drya, --, --, 
   {{0xc58801dc,0x6d543ede,0xbd900092,0x00000000}},	//   _hồ_, erya, _ማቋቋም_, --, 
   {{0x386807f5,0x6e340af9,0x6d540175,0xe5002982}},	//   đari_, gbyb, frya, _रीति_, 
   {{0x5fcc00bc,0x00000000,0x00000000,0x00000000}},	// [13190] _हेरल, --, --, --, 
   {{0xd010021a,0xc588001e,0x7bc4002f,0x00000000}},	//   الې_, _mồ_, tzhu, --, 
   {{0xc588001e,0x7e6c0223,0xf428023a,0x50d42161}},	//   _lồ_, pfap, lkää_, _جزير, 
   {{0x6600dfeb,0x6f0401ab,0x527c008f,0x7bc40489}},	//   _ozok, _ghkc, ַנוא, rzhu, 
   {{0x39480597,0x6600dfec,0xf428023a,0x7bc40036}},	//   éas_, _nzok, nkää_, szhu, 
   {{0xb06402f6,0xf4280108,0xf8b01291,0x00000000}},	//   _ikää, ikää_, دکر_, --, 
   {{0x6600dfed,0xf770007b,0xf4280108,0x00000000}},	//   _azok, اات_, hkää_, --, 
   {{0x973074f3,0xf42802f6,0xc588001e,0x00000000}},	//   _یکبا, kkää_, _bồ_, --, 
   {{0xe574dfee,0x38680c09,0xa2a01a3e,0xc5880208}},	//   езы_, ƙar_, गान्, _cồ_, 
   {{0x660005b8,0xc5880051,0x00000000,0x00000000}},	//   _dzok, _dồ_, --, --, 
   {{0x6600a21d,0x38b8007f,0x32c00248,0x00000000}},	//   _ezok, _jèrm_, _lóye_, --, 
   {{0xe7b4008f,0x00000000,0x00000000,0x00000000}},	//   _אהער_, --, --, --, 
   {{0x30740212,0xe0dc067c,0xe294dfef,0xc5880208}},	//   нувс, tròp_, хая_, _gồ_, 
   {{0x73e40c04,0xe0dc067c,0x92e000cc,0x00000000}},	//   _полз, ssòn_, থতে_, --, 
   {{0x66000083,0xf8ac0208,0xd3440345,0x00000000}},	//   _zzok, _đợi_, _تیجه_, --, 
   {{0x6da4dff0,0x6d54dff1,0x1bf00037,0xdfcc007b}},	//   ниба, trya, _अड़ल_, حيف_, 
   {{0xf388001e,0x6e34dff2,0xdee00fc0,0xaab4000d}},	// [131a0] _hả_, rbyb, уоти, _अकबक, 
   {{0x6d541529,0x6c84dff3,0xef84449b,0xe0dc007f}},	//   rrya, علام, _злоп, nsòl_, 
   {{0x6e442369,0x395c0196,0x8fc40022,0xf42003d4}},	//   _пенз, euws_, _ранҵ, _য়াৰ_, 
   {{0x8c480598,0x6da4dff4,0x7eb008fb,0xa968dff5}},	//   _suğı, _зима, _dåps, зида_, 
   {{0xa258dff6,0xa8501cd1,0xf388004d,0x0c7453b2}},	//   khôn, гелә, _lả_, _لگاد, 
   {{0x6c34dff7,0x98a00d5c,0x7d080395,0x38b8007f}},	//   _سفرا, личе, _èesp, _fèrm_, 
   {{0x66005642,0x1d04dff8,0xc5880051,0xbbf401af}},	//   _szok, _чери_, _sồ_, _аїты, 
   {{0x7dc801b9,0xf4280108,0xc5880051,0x00000000}},	//   _bоsh, ykää_, _pồ_, --, 
   {{0xe8c800a8,0x8c48013d,0xa8180133,0x00000000}},	//   _егал_, _tuğı, _فتار_, --, 
   {{0x63742045,0xf388004d,0xc5880208,0x3cf400cd}},	//   _nünö, _bả_, _vồ_, ्तये_, 
   {{0xf38801dc,0x2794086f,0x290c013f,0xe6180108}},	//   _cả_, _яшар, mmfa_, _еде_, 
   {{0xf428023a,0xf3880051,0x94700014,0xc5880208}},	//   tkää_, _dả_, پدیا, _tồ_, 
   {{0x6600dff9,0xe0dc00cf,0x290c00cf,0x6374dffa}},	//   _uzok, bsòl_, omfa_, _bünö, 
   {{0x271c02e3,0xf4280108,0x32c00241,0xa6e000fe}},	//   _ọnya_, rkää_, _róye_, _পঠিয়, 
   {{0xf388004d,0x4fc43f1d,0x7c2803b9,0xf42801f4}},	//   _gả_, гста, _şero, skää_, 
   {{0x7dc8022e,0xb2740166,0x00000000,0x00000000}},	//   _hоsi, _акъә, --, --, 
   {{0x98800030,0xbd18dffb,0x98ac0327,0x00000000}},	// [131b0] víľu_, джах_, qugħ_, --, 
   {{0x9f44145e,0xb93c001f,0x00000000,0x00000000}},	//   _ânï_, ከባሪዎ, --, --, 
   {{0xf388001e,0x7064035b,0xd1b815bf,0x00000000}},	//   _xả_, _рхыҧ, _ياۋا_, --, 
   {{0x38b8067c,0x32c001e1,0x00000000,0x00000000}},	//   _vèrm_, _tóye_, --, --, 
   {{0xd918d64b,0x3ea8910a,0x00000000,0x00000000}},	//   чье_, mjat_, --, --, 
   {{0xe1f400c6,0xdb20dffc,0x3ea8dffd,0x00000000}},	//   _ҳҳح_, _موسی, ljat_, --, 
   {{0xb8d80490,0x74c4033f,0x20480023,0x3ea80500}},	//   _चव_, ाफघृ, _ንዝቐረ, ojat_, 
   {{0x3ea8dffe,0xe6900131,0xf3880208,0xb6f800db}},	//   njat_, للىد, _rả_, بىعا_, 
   {{0xceb413e2,0x4ae4006c,0x3914dfff,0x7dc8022e}},	//   טיק_, _сўра, _амар, _bоsi, 
   {{0x394ce000,0x85080184,0x3ea8023a,0x00000000}},	//   _ives_, ндың_, hjat_, --, 
   {{0x3ea805be,0x61f8031c,0x00000000,0x00000000}},	//   kjat_, żull, --, --, 
   {{0x3ea88139,0xe294115c,0xf388001e,0xe0dc067c}},	//   jjat_, ваю_, _vả_, ssòl_, 
   {{0x3ea8e001,0x7fd401ec,0xf3880051,0x955400ae}},	//   djat_, ңісі, _wả_, _أخصا, 
   {{0xf3880016,0x46a4035b,0x3ea8004e,0xafe400f3}},	//   _tả_, _ашәб, ejat_, вогл, 
   {{0xa0a0e002,0x00000000,0x00000000,0x00000000}},	//   шард, --, --, --, 
   {{0x394ce003,0xa2a002c3,0x3ea8e004,0xbc242d40}},	//   _oves_, गाण्, gjat_, ۇرمى, 
   {{0x394c0fac,0x3f841d0e,0x00000000,0x00000000}},	// [131c0] _nves_, ælur_, --, --, 
   {{0x3ea8023a,0x7ae801e4,0xec3000d1,0xe570010f}},	//   ajat_, _ĉeta, شۈرگ, יַע_, 
   {{0xaa442dbf,0xee3800c7,0x3ea8031c,0xab64011c}},	//   веел, _онн_, bjat_, твел, 
   {{0xe9d8e005,0xda7400a7,0x6ed4012c,0x7e6800e8}},	//   мке_, вяш_, _ठगिँ, _ñepp, 
   {{0xa2a01fe7,0xda6c01d9,0x00000000,0x00000000}},	//   गात्, تُن_, --, --, 
   {{0x2d901446,0x2918e006,0x290ce007,0x48d00154}},	//   mvye_, öpa_, umfa_, াক্র, 
   {{0xe784e008,0x394ce009,0x00000000,0x00000000}},	//   туло, _eves_, --, --, 
   {{0xd6d4e00a,0x1be800c5,0x69d4044b,0x00000000}},	//   кты_, _जुटल_, _मेथी, --, 
   {{0x2d905069,0x6844e00b,0xa9689448,0x394803b2}},	//   nvye_, _анза, _زمام_, áast_, 
   {{0xd05c013f,0x3ea8031c,0x00000000,0x00000000}},	//   korɑ, zjat_, --, --, 
   {{0x3cf40882,0x9f4c046c,0x39480010,0x7dc8022e}},	//   ्तते_, ünüz_, šast_, _vоsi, 
   {{0x394ce00c,0x54d40014,0x7c280139,0x00000000}},	//   _yves_, _یِنس_, _ğerm, --, 
   {{0xe4c400cf,0xd5440798,0x7c28010e,0x3ea8031c}},	//   _ийди, _апче_, _şerm, vjat_, 
   {{0xc1040472,0x00000000,0x00000000,0x00000000}},	//   اوسي, --, --, --, 
   {{0x6d580053,0x442c0175,0x3dc80327,0xa2a000cd}},	//   _ātaa, mcd_, wzaw_, गाद्, 
   {{0x442c0066,0x41b401ed,0x34a4035b,0x6e200030}},	//   lcd_, _ممبر, _агәҳ, žobn, 
   {{0x3ea8e00d,0x629c2798,0x81b00154,0x00000000}},	// [131d0] rjat_, _inqo, _টের_, --, 
   {{0x628c3b4d,0x35d80073,0x66dc00de,0x3dc8025c}},	//   ldco, _बेफ़, lūkd, rzaw_, 
   {{0x3b540137,0x442c037e,0x51f40214,0x3ea80327}},	//   укер, icd_, _مسیر, pjat_, 
   {{0x628ce00e,0xa25800d2,0x2bc00fc8,0x442c0066}},	//   ndco, khôm, वैधा, hcd_, 
   {{0x629c0921,0x99643767,0xf8b801c6,0xc98401f7}},	//   _mnqo, ттел, нөж_, لشوي, 
   {{0xf770937d,0x38b800f2,0xb4b004fa,0xd760036b}},	//   ماب_, _kèri_, _टके_, لنتی, 
   {{0xc7641473,0x629ce00f,0x9a8400c7,0xc86401c0}},	//   لايى, _onqo, _иуал, ртчи, 
   {{0xb5fc00da,0x38b80066,0xe1fc004e,0x628c01f5}},	//   egša, _mèri_, nfós_, jdco, 
   {{0xb99805f5,0x49040131,0x628c0175,0x442c0175}},	//   _явах_, _چوقق, ddco, fcd_, 
   {{0x7988e010,0x629ce011,0xb38405f5,0x27f00209}},	//   _isew, _anqo, глол, şyna_, 
   {{0x32443e28,0x628c01a4,0xc7b80051,0x00000000}},	//   ленг, fdco, _tgđa_, --, 
   {{0x32c001e1,0x64a0023b,0x628c01f5,0x00000000}},	//   _bóya_, _ҳаша, gdco, --, 
   {{0x442c0066,0x7988031c,0x2bd800dc,0x916c00cd}},	//   bcd_, _jsew, _येना, _mṛgā, 
   {{0x629c01f0,0x38b80ba1,0x79880bd7,0x442ce012}},	//   _enqo, _bèri_, _msew, ccd_, 
   {{0x798802c4,0xfaf806c8,0x8d78001f,0x4ed400c7}},	//   _lsew, _okū_, _ካላቸው_, асаӡ, 
   {{0xafe4036b,0xdfcc00c6,0x7988e013,0x7648e014}},	//   воҳл, سيق_, _osew, naey, 
   {{0x7f180220,0x79880327,0xad242099,0xaba8030f}},	// [131e0] тіру_, _nsew, اررو, کهام_, 
   {{0x76480263,0x1c4015bf,0x6218011a,0x6c34114f}},	//   haey, йнум, _אופק, افضا, 
   {{0x7c641916,0x7988e015,0x76480a73,0xf424015b}},	//   شالل, _asew, kaey, _মজার_, 
   {{0xeaf88a4b,0xa258002d,0x442c00b5,0x6d24007b}},	//   ررات_, rkôg, zcd_, _معسك, 
   {{0xa2580a85,0x00000000,0x00000000,0x00000000}},	//   skôg, --, --, --, 
   {{0xb604009b,0x442ce016,0x628c0f91,0x4734e017}},	//   _mišč, xcd_, zdco, анкс, 
   {{0x442c02fa,0x7988633f,0x9cd406a9,0xf1c009a8}},	//   vcd_, _esew, _עולה_, lišč_, 
   {{0x65a8026a,0x18a001e0,0xe6644d56,0x86980137}},	//   етог_, _һаум, утко, ткис_, 
   {{0xa2a0e018,0x442ce019,0xf1c00427,0x9aa000f1}},	//   गास्, tcd_, nišč_, _دڅلو, 
   {{0x3a08e01a,0x42c000cc,0x916c002b,0xe81c134e}},	//   _شکنی_, _উদেশ, _mṛdā, _पलटा_, 
   {{0x5378044e,0x442c020c,0xb3840014,0x7c280139}},	//   _ክካየድ_, rcd_, لێوم_, _şerk, 
   {{0x291ce01b,0x442c0198,0x6d5802b1,0x2a640af9}},	//   _hita_, scd_, _ātan, ngob_, 
   {{0x291ce01c,0x628ce01d,0x38b800f2,0x27280cad}},	//   _kita_, rdco, _sèri_, _hùn_, 
   {{0x4394e01e,0x291ce01f,0xf1c009a8,0x506420c2}},	//   _вакс, _jita_, dišč_, йтса, 
   {{0x291ce020,0x248c0ac5,0x27280241,0x53a000d8}},	//   _mita_, _iafm_, _jùn_, _гајб, 
   {{0x629c379d,0x534001b9,0x27280208,0x35d8023e}},	//   _unqo, _ухша, _mùn_, _बेड़, 
   {{0x22488444,0x291c004c,0x2728e021,0x63b811c0}},	// [131f0] mack_, _oita_, _lùn_, lytn, 
   {{0x2248e022,0x27280241,0x916c00b8,0x7d500023}},	//   lack_, _oùn_, _sṛgā, _ንክልቲ, 
   {{0x63b808d7,0x2728026c,0x711804ae,0x79880337}},	//   nytn, _nùn_, _שותפ, _ssew, 
   {{0x291ce023,0x224801e6,0x68f8e024,0x7988031c}},	//   _aita_, nack_, _aktd, _psew, 
   {{0x291ce025,0x0e080209,0x63b801f4,0x00000000}},	//   _bita_, _бэри_, hytn, --, 
   {{0x2248e026,0x2728e027,0x63b8e028,0x30f800cd}},	//   hack_, _bùn_, kytn, ृतयः_, 
   {{0x291ce029,0x22480036,0x2728e02a,0x00000000}},	//   _dita_, kack_, _cùn_, --, 
   {{0x2248e02b,0xca4806d5,0x291ce02c,0x79885bae}},	//   jack_, _ملفه_, _eita_, _tsew, 
   {{0x291ce02d,0x7648e02e,0x798814dc,0x7ae8e02f}},	//   _fita_, raey, _usew, _ijet, 
   {{0x291ce030,0x7ae80158,0x27280241,0x76480083}},	//   _gita_, _hjet, _fùn_, saey, 
   {{0x7ae8168c,0xd5a004fb,0x27280cad,0xb604107d}},	//   _kjet, _گلشی, _gùn_, _sišč, 
   {{0x291c0e8a,0xb604151c,0x60d4e031,0x66dc00b0}},	//   _zita_, _pišč, _amxm, tūke, 
   {{0x7ae8044e,0x291ce032,0x59d806e3,0x00000000}},	//   _mjet, _yita_, _मेमर, --, 
   {{0x7ae81727,0x6ac0df24,0x63b800b5,0x291c0003}},	//   _ljet, _शत्र, bytn, _xita_, 
   {{0x7ae845bb,0x60d800f2,0xd1cc0092,0x00000000}},	//   _ojet, èuma, ጠይቁ_, --, 
   {{0xf1c00219,0x7ae80240,0xb6040219,0xca2401ec}},	//   tišč_, _njet, _tišč, _ﹼﺨﺫ_, 
   {{0xada4b46d,0xa2a0b702,0x3108010b,0x3074e033}},	// [13200] шаал, गार्, _инип_, _кунс, 
   {{0x7ae8e034,0xeb98e035,0x2a94013f,0xf1c00219}},	//   _ajet, киз_, mɛbɔ_, rišč_, 
   {{0xdcac278f,0xe1fc0ba1,0xab640254,0x00000000}},	//   بىل_, ngón_, dfüü, --, 
   {{0x2bd80574,0x78a002e2,0x2728e036,0x00000000}},	//   _येणा, _anlv, _rùn_, --, 
   {{0x7ae81727,0xa2c4a96d,0xbb7416c3,0x2a64002e}},	//   _djet, ासत्, _қуръ, rgob_, 
   {{0xd8f400d6,0x7ae800d8,0x3dcc025c,0x22480036}},	//   анії_, _ejet, _żewg_, zack_, 
   {{0x3cf428e1,0x7ae80023,0xcdc400d1,0x69d41b76}},	//   ्तरे_, _fjet, _тәңп, _मेरी, 
   {{0x7ae8e037,0x291ce038,0x27280051,0x61f8025c}},	//   _gjet, _wita_, _vùn_, żuli, 
   {{0x291ce039,0x2bd80574,0xe4a4e03a,0x7c28e03b}},	//   _tita_, _येता, арно, _şeri, 
   {{0x291ce03c,0xb86434f7,0xbb240150,0x2728e03d}},	//   _uita_, _هامو, _ﹼﺘﻪ_, _tùn_, 
   {{0x21280054,0xd1cc001f,0xf8ac10ef,0xa68400d8}},	//   wqch_, ጠይቅ_, _سکو_, _влед, 
   {{0x63b8e03e,0x569002bf,0xca600139,0x48f000bc}},	//   rytn, _маєт, _timе, ेतको_, 
   {{0x2248e03f,0x26c4e040,0x3eac0115,0x63b802f0}},	//   rack_, _iloo_, _ĵet_, sytn, 
   {{0x26c40218,0x224817da,0x55b80375,0x63b802f0}},	//   _hloo_, sack_, _במדו, pytn, 
   {{0x22480936,0xd43400c8,0x26c40109,0xc5e8015b}},	//   pack_, _דרוק_, _kloo_, _পরিপ, 
   {{0x09bc04c5,0x2a940134,0x00000000,0x00000000}},	//   _আইনা, bɛbɔ_, --, --, 
   {{0x26c4009f,0x91e40131,0x7dc8022e,0x3cf40404}},	// [13210] _mloo_, _дәрһ, _rоss, ्तले_, 
   {{0x7ae8e041,0xf338001f,0x3b0c0200,0xabb40124}},	//   _sjet, _የተቀና, _sheq_, әацә, 
   {{0x26c47eb8,0x7ae8e042,0x6c6801ed,0x395c0142}},	//   _oloo_, _pjet, المہ_, wrws_, 
   {{0xe1fc00e8,0x395c0142,0x00000000,0x00000000}},	//   ngóo_, trws_, --, --, 
   {{0x7ae8e043,0x3a7401a9,0x00000000,0x00000000}},	//   _vjet, _қлар, --, --, 
   {{0x26c4e044,0xb4d405f9,0x7ae81165,0x00000000}},	//   _aloo_, _सगे_, _wjet, --, 
   {{0x7ae8067d,0x26c4a1ee,0xfb340262,0xab640037}},	//   _tjet, _bloo_, _ынвэ, rfüü, 
   {{0x7ae8e045,0xfa541e2f,0x26c400ef,0xab640254}},	//   _ujet, _درسگ, _cloo_, sfüü, 
   {{0x6eb8069f,0x26c4002d,0x2ea8008f,0x38b801e1}},	//   _एकसु, _dloo_, רשפּ, _sèru_, 
   {{0x26c4e046,0x38b8068c,0x7af8e047,0x78a002d0}},	//   _eloo_, _cèrt_, lowt, _unlv, 
   {{0x33d40046,0x6d581442,0x26c4e048,0x00000000}},	//   сіпт, _ātam, _floo_, --, 
   {{0x15b4052f,0x26c400ad,0xe1fce049,0x00000000}},	//   _ҡыҙы_, _gloo_, rgón_, --, 
   {{0xd05c013f,0xb808009e,0x00000000,0x00000000}},	//   korɔ, _ললিত_, --, --, 
   {{0x7af8e04a,0x71a400c7,0x2d9c0118,0x85340244}},	//   howt, _ҳаиз, _čte_, _بووچ, 
   {{0x66dce04b,0x2d9c02b1,0x73340137,0x3ca002dd}},	//   lūka, _ōte_, _ارتئ, _ﺍﺷﺘﻰ_, 
   {{0x2bc8b392,0x2bc41524,0xc5e803d4,0x00000000}},	//   ңлап_, लनसा, _পৰিপ, --, 
   {{0xec78e04c,0x5e3001d3,0x7dc801a9,0xece801c6}},	// [13220] лпа_, سّلا, _bоsq, гдал_, 
   {{0x30840597,0x81b0015b,0xf0640114,0x00000000}},	//   _الدف, _টেক_, _укоп, --, 
   {{0xc5e800fe,0x6a2400f2,0x00000000,0x00000000}},	//   _পৰাপ, مفام, --, --, 
   {{0x293402d3,0xbe8001d5,0x00000000,0x00000000}},	//   _ብሃይማ, _оқси, --, --, 
   {{0x3eac0428,0x6f140113,0x229c01f4,0x00000000}},	//   _òeta_, mmyc, _häkä_, --, 
   {{0xe0dc067c,0x26c41368,0x30f800dc,0x6f140076}},	//   bsòu_, _sloo_, ृतिः_, lmyc, 
   {{0x26c40493,0x7af8011f,0xda980724,0x2054010f}},	//   _ploo_, bowt, _өстә_, ציקל_, 
   {{0x6d44014b,0x9f5c07ea,0x7af8011f,0xdc900023}},	//   _kwka, érée_, cowt, _መዛሙር_, 
   {{0xd94009a5,0xceb403be,0x7c2801fa,0xa2c400dc}},	//   _нети, mməd_, _đerz, ासस्, 
   {{0xc3540f14,0x31cc0154,0x32d000c0,0x00000000}},	//   окој, রপাশ, kšys_, --, 
   {{0x74a848a0,0x26c401ee,0xa6e001a8,0xe7380902}},	//   рсың_, _tloo_, óðsi, _сее_, 
   {{0x26c40093,0x81b0009e,0x20040327,0x6d440432}},	//   _uloo_, _টেগ_, _ġni_, _owka, 
   {{0x38b80ba1,0x6604010b,0x6f140306,0x543001b9}},	//   _gèrs_, _упда, dmyc, غریر, 
   {{0x6600e04d,0x758007d6,0xab6000a2,0xceb403b9}},	//   _iyok, _کییم, _įünk, hməd_, 
   {{0x6d44e04e,0x6720009f,0x660004ce,0x1ee41272}},	//   _awka, _kioj, _hyok, موسی_, 
   {{0x6600e04f,0x6448e050,0xbe38030d,0xceb80114}},	//   _kyok, _hefi, рзах_, бљу_, 
   {{0x6600037e,0x67201d0f,0xc0c40131,0x7cd8e051}},	// [13230] _jyok, _mioj, _дәви, амар_, 
   {{0x66000097,0x6448e052,0xca7c022e,0x6f1400d0}},	//   _myok, _jefi, _strа, amyc, 
   {{0x6600e053,0x6d440003,0x20040162,0xbab40108}},	//   _lyok, _ewka, _áni_, жёлы, 
   {{0x6448e054,0x6600e055,0x3f800113,0x6f14037e}},	//   _lefi, _oyok, _iphu_, cmyc, 
   {{0x7af8e056,0x00000000,0x00000000,0x00000000}},	//   rowt, --, --, --, 
   {{0x6448e057,0x7ba403e6,0x00000000,0x00000000}},	//   _nefi, _وڵام, --, --, 
   {{0x6600e058,0x6720e059,0x7af8033f,0x00000000}},	//   _ayok, _bioj, powt, --, 
   {{0x64480093,0x3f8001ee,0x6600e05a,0x38b8e05b}},	//   _aefi, _mphu_, _byok, _pèrs_, 
   {{0x6448e05c,0x6600e05d,0x672000df,0x6d580093}},	//   _befi, _cyok, _dioj, _ātak, 
   {{0x6600e05e,0xd874006c,0x38b81497,0x64480042}},	//   _dyok, _دارب, _vèrs_, _cefi, 
   {{0x6720062c,0xc208011a,0x6f14015d,0x644c03b2}},	//   _fioj, _סה_, ymyc, ðbia, 
   {{0x7e7ce05f,0x6448e060,0x67208539,0x09bc00fe}},	//   _nbsp, _eefi, _gioj, _আইতা, 
   {{0x6448e061,0xe56c07d6,0x34942a62,0x66000337}},	//   _fefi, _юз_, _мадр, _gyok, 
   {{0x6448e062,0x7e7c0730,0x6ab408a3,0x66dc0241}},	//   _gefi, _absp, _अक्र, _tàkè, 
   {{0xead001e1,0x2900013b,0x74145734,0x00000000}},	//   _bẹ̀_, _ɔka_, _بوغا, --, 
   {{0xee38e063,0x6448ddf0,0x2bd800dc,0x326001d9}},	//   рна_, _zefi, _येषा, _کچھہ, 
   {{0x229c006a,0x6448e064,0xdee00aac,0x6f14e065}},	// [13240] _wäkä_, _yefi, фоти, rmyc, 
   {{0x7c6400c6,0x7e7c02d0,0x32d00024,0x6f140267}},	//   كامل, _ebsp, pšys_, smyc, 
   {{0x61f8038f,0xead0110e,0x6d44020c,0x9c100241}},	//   żult, _fẹ̀_, _wwka, _mọwo, 
   {{0x7c2809a5,0x59d805b3,0x6da4e066,0xada401b9}},	//   _şert, _मेहर, _дима, _дамл, 
   {{0x6720062c,0xa888344a,0x7c2c00ae,0x00000000}},	//   _rioj, ийда_, íorú, --, 
   {{0x6600e067,0x9c10063f,0x7644013f,0x6d5802b1}},	//   _ryok, _nọwo, _ɑhye, _ātah, 
   {{0xcc8800aa,0x672000eb,0xb3400209,0x75380175}},	//   _پنځه_, _pioj, ýçle, _atwz, 
   {{0x66000204,0x76580175,0xc7b801a9,0x00000000}},	//   _pyok, _cdwy, иёқ_, --, 
   {{0x6720e068,0x765800a9,0x64480793,0x660006be}},	//   _vioj, _ddwy, _pefi, _qyok, 
   {{0x660007a8,0x76580042,0x64480240,0x670801ad}},	//   _vyok, _edwy, _qefi, _हीरक_, 
   {{0x64480008,0x9c100248,0x00000000,0x00000000}},	//   _vefi, _dọwo, --, --, 
   {{0x04fc03f4,0x64482251,0x6600037e,0x00e40220}},	//   ীদের_, _wefi, _tyok, _ﺍﻳﺘﻘ, 
   {{0x6448e069,0xead00570,0x66007ac0,0x66dc005f}},	//   _tefi, _rẹ̀_, _uyok, lūko, 
   {{0x644801a6,0xd48c01a9,0x3f800210,0x00000000}},	//   _uefi, _ўр_, _pphu_, --, 
   {{0x83a400c7,0x765803cb,0xead001e1,0x00000000}},	//   _хылҵ, _ydwy, _pẹ̀_, --, 
   {{0x7e7c2244,0xe1fc00e5,0x00000000,0x00000000}},	//   _qbsp, ngók_, --, --, 
   {{0x7d040455,0xa05c0354,0x00000000,0x00000000}},	// [13250] tlhs, _итнĕ_, --, --, 
   {{0x7f58e06a,0x823402f2,0xa2a007b7,0x00000000}},	//   _лаос_, _برژا, गाक्, --, 
   {{0x2d80e06b,0xd0f876f8,0x23c81fad,0xead00248}},	//   _epke_, ंकरण_, ानिद, _tẹ̀_, 
   {{0x6ff80375,0x6e9401ed,0x7e7c03ac,0x9ce800eb}},	//   _להתפ, _فلپا, _ubsp, কতেন_, 
   {{0x15880150,0xbb480066,0x00000000,0x00000000}},	//   _ﻓﻴﺎﺽ_, _گلزن_, --, --, 
   {{0x3eb8e06c,0x23c800dc,0x7e6c3496,0x00000000}},	//   _host_, ानाद, lgap, --, 
   {{0x6d5802b5,0x00000000,0x00000000,0x00000000}},	//   _ātai, --, --, --, 
   {{0x3eb807de,0x644c03b2,0x3cf407b7,0x00000000}},	//   _jost_, ðbin, ्तके_, --, 
   {{0x3eb8025f,0x38680198,0x00000000,0x00000000}},	//   _most_, ɗarn_, --, --, 
   {{0x3eb8782e,0x7a302131,0xd7f8008e,0x00000000}},	//   _lost_, _fótó, _куе_, --, 
   {{0x3eb8e06d,0x7e6ce06e,0x942000db,0x66dc00ef}},	//   _oost_, kgap, بودۇ, cūko, 
   {{0xc6a40323,0x3eb800e2,0x00000000,0x00000000}},	//   _орчи, _nost_, --, --, 
   {{0x35a4e06f,0x00000000,0x00000000,0x00000000}},	//   _халг, --, --, --, 
   {{0x659805e1,0x942043e8,0x3eb8068c,0x0574b58a}},	//   _לינק, _قوشۇ, _aost_, _زاهد, 
   {{0x3eb8e070,0xee380139,0xa3e0000d,0x00000000}},	//   _bost_, йнв_, _नेप_, --, 
   {{0x7e6c4694,0x00000000,0x00000000,0x00000000}},	//   ggap, --, --, --, 
   {{0xed580c60,0x00000000,0x00000000,0x00000000}},	// [13260] соз_, --, --, --, 
   {{0x3eb80dd4,0x7e6c0280,0xf0643cc5,0xdd8c0966}},	//   _eost_, agap, _экоп, طوم_, 
   {{0x3eb8e071,0x09c41fe7,0xaf0400db,0xa77801ec}},	//   _fost_, वन्य, _нпол, _ﺤﻴﺎﺓ_, 
   {{0x38b8067c,0xfd100116,0x00000000,0x00000000}},	//   _sèrp_, ىجە_, --, --, 
   {{0x2d94e072,0x673805b1,0x6d5802b5,0x00000000}},	//   _эрнс, _sttj, _ātaw, --, 
   {{0x66dc02b5,0x6d54e073,0x3eb800d7,0x00000000}},	//   tūko, msya, _zost_, --, 
   {{0xec1401ec,0xaa440b3e,0x3eb80165,0x66dc00c0}},	//   _ءوزد, _невл, _yost_, būkl, 
   {{0x7a3001e7,0x6d54058a,0x6e3402d0,0x00000000}},	//   _vótó, osya, ncyb, --, 
   {{0x6d54e074,0xd6cc0107,0xe5c40a89,0x58200ce8}},	//   nsya, _ҷт_, яско, ммәб, 
   {{0x7e6c0161,0x6d540014,0x66dc02b5,0x1510010b}},	//   zgap, isya, pūko, ндыя, 
   {{0x6d5456e4,0xd91800c8,0x673801e3,0xd6cc0395}},	//   hsya, _פובל, _uttj, _зт_, 
   {{0x6d54e075,0xc4840116,0x00000000,0x00000000}},	//   ksya, члүк, --, --, 
   {{0x64a4e076,0x3eb8e077,0x7e6c143a,0xc458030d}},	//   _нада, _rost_, vgap, _дилх_, 
   {{0x3eb8011c,0x15400e92,0xc3c40166,0x6d540857}},	//   _sost_, _џејм, _жөмл, dsya, 
   {{0x3eb8025f,0x2b480048,0x69c0020c,0x6d540009}},	//   _post_, _nwbc_, hyoe, esya, 
   {{0x425415b4,0x939000ae,0x00000000,0x00000000}},	//   _کنکر, _أجوا, --, --, 
   {{0x7e6ce078,0x3eb80129,0x6d5402d0,0x8d7400ae}},	// [13270] rgap, _vost_, gsya, فالا, 
   {{0x2b4801ee,0x3eb801c7,0x4cb80500,0x00000000}},	//   _bwbc_, _wost_, плую_, --, 
   {{0x3eb80dd4,0xa3e003f3,0x6d544457,0x32c001e1}},	//   _tost_, _नेम_, asya, _sóyi_, 
   {{0x6d540ac5,0x3eb80c86,0x00000000,0x00000000}},	//   bsya, _uost_, --, --, 
   {{0x3948180f,0x66dc00e2,0x8d8401f0,0x00000000}},	//   èas_, rūkl, _пурд, --, 
   {{0xa9a0036b,0x00000000,0x00000000,0x00000000}},	//   тишд, --, --, --, 
   {{0xb90405f9,0x00000000,0x00000000,0x00000000}},	//   _पग_, --, --, --, 
   {{0x69c00007,0x00000000,0x00000000,0x00000000}},	//   byoe, --, --, --, 
   {{0xbbdc1a2a,0x00000000,0x00000000,0x00000000}},	//   _मधुक, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb4cce079,0x53c001ec,0x63440092,0x00000000}},	//   _रती_, ханұ, _የተጭበ, --, 
   {{0x6d54726c,0xe1fc033f,0x00000000,0x00000000}},	//   ysya, ngów_, --, --, 
   {{0x42540276,0xdeb80240,0x00000000,0x00000000}},	//   этэт, ተናን_, --, --, 
   {{0x7e680171,0x81dc05ac,0x00000000,0x00000000}},	//   _ķepa, _তুহ_, --, --, 
   {{0xdd8c036b,0x6d5402d0,0x00000000,0x00000000}},	//   یوف_, wsya, --, --, 
   {{0x6d5400dc,0x646000e2,0x7c28e07a,0x00000000}},	//   tsya, ētiņ, _şerp, --, 
   {{0xc2c802dd,0x6e340c6a,0x00000000,0x00000000}},	// [13280] _ءبىل_, rcyb, --, --, 
   {{0x6d54e07b,0x69c00451,0x6344001f,0xdd8c4630}},	//   rsya, vyoe, _የተጠበ, ؤول_, 
   {{0xa2a01fbc,0x6d54037e,0x6f180120,0x205400df}},	//   गाच्, ssya, _мцмс_, _קיטל_, 
   {{0x6ab400cc,0x9a8001d5,0x3b800092,0x00000000}},	//   ংসভো, вушл, _ከፋዮች_, --, 
   {{0xe8f80323,0x6d540a2e,0x59700bce,0x00000000}},	//   олд_, qsya, ندوز, --, 
   {{0xfd6400cd,0x916c0055,0x85b80107,0x98a0011c}},	//   _nirṇ, _nṛmā, ҷлис_, киче, 
   {{0x69c02892,0x98a00063,0x00000000,0x00000000}},	//   syoe, тије, --, --, 
   {{0xccf4016b,0xe5c4009d,0x12d000eb,0x00000000}},	//   trɛw_, дсоо, াচুদ, --, 
   {{0x69d40316,0x1ae02fc3,0x940403b9,0x00000000}},	//   _मेची, _ротм, _ianə_, --, 
   {{0x44380428,0x5ec40154,0xd94003c5,0x00000000}},	//   ùr_, রোপে, _рефи, --, 
   {{0x80c001ad,0x00000000,0x00000000,0x00000000}},	//   रॉफे, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe1fc0210,0x00000000,0x00000000,0x00000000}},	//   zgów_, --, --, --, 
   {{0x261801ad,0xc3c435e3,0x00000000,0x00000000}},	//   मेरी_, _чөпл, --, --, 
   {{0x940403b9,0x00000000,0x00000000,0x00000000}},	//   _nanə_, --, --, --, 
   {{0xa3e010f7,0x229c01e1,0x403400f0,0x3f840118}},	// [13290] _नेत_, _ẹkú_, _пепс, ůlu_, 
   {{0xdd901ac1,0xa2c408e6,0x7f940212,0x6d5838af}},	//   нағы, ासक्, _заох, _ātat, 
   {{0xf0900375,0xfaf000f1,0x00000000,0x00000000}},	//   _גני_, هګر_, --, --, 
   {{0x9c10063f,0x6fac038e,0xa9c400d1,0x00000000}},	//   _bọro, ीहरू, ﯩﻠﯩﻴ, --, 
   {{0xe1fc012d,0x00000000,0x00000000,0x00000000}},	//   rgów_, --, --, --, 
   {{0xd5ac01d3,0x8aa40166,0x00000000,0x00000000}},	//   یہا_, ерәд, --, --, 
   {{0x6920e07c,0xe7340395,0xe8900419,0x00000000}},	//   ымша, нещ_, áňať_, --, 
   {{0x77040bce,0xf1c800d7,0xf52c0023,0xf5b41b0a}},	//   رژان, _hráš_, _ተኣማሚ, есою, 
   {{0xb6a4008e,0xceb403e3,0x261828fe,0x00000000}},	//   _җилл, kmən_, मेली_, --, 
   {{0x85080032,0x23c81cc3,0x00000000,0x00000000}},	//   мдың_, ानंद, --, --, 
   {{0x7bc40472,0xe81c02e5,0x940406be,0x00000000}},	//   nyhu, येदा_, _yanə_, --, 
   {{0x394c009a,0x39080244,0x00000000,0x00000000}},	//   _kwes_, _بفڕێ_, --, --, 
   {{0x394c0784,0x21a017b4,0x25e43d1d,0x00000000}},	//   _jwes_, гиям, _जेपी_, --, 
   {{0xb7b000fe,0x6e9401b9,0x63ac0332,0xe1f000ec}},	//   জনীয়, کلرا, óiní, اسٽ_, 
   {{0x394c1529,0x916c0055,0x5f900107,0x039400c0}},	//   _lwes_, _kṛkā, лиёт, _арыя, 
   {{0x3a2c0455,0x602001c0,0x1168230f,0x66cc01e1}},	//   _ngep_, удса, _قلبی_, _kùka, 
   {{0xca240150,0xcfd803d4,0x6d580055,0xc3040345}},	// [132a0] _ﹼﻨﺎ_, _দুখন, _ātas, _جبوو, 
   {{0xfa1400bd,0x00000000,0x00000000,0x00000000}},	//   িশাল_, --, --, --, 
   {{0x394c0204,0x61280135,0xe8f805a2,0x7bc40142}},	//   _awes_, _iżla, үле_, gyhu, 
   {{0xd1d40092,0x00000000,0x00000000,0x00000000}},	//   _ኩራት_, --, --, --, 
   {{0x28bcd793,0x7bc400e4,0xfd4c0241,0x5a300a4a}},	//   ्सलि, ayhu, _oloṣ, уніт, 
   {{0x7bc4007c,0x00000000,0x00000000,0x00000000}},	//   byhu, --, --, --, 
   {{0x394c0b0e,0x597000d1,0x00000000,0x00000000}},	//   _ewes_, ندۈز, --, --, 
   {{0x0708e07d,0xd6d41c22,0x59d80210,0x00000000}},	//   بيعي_, еть_, _मेकर, --, 
   {{0x163400c6,0xe0dc068c,0x45d4e07e,0x00000000}},	//   رسية_, npòc_, топс, --, 
   {{0xb90400fe,0x00000000,0x00000000,0x00000000}},	//   _নৱ_, --, --, --, 
   {{0x24700139,0x00000000,0x00000000,0x00000000}},	//   _aşmí_, --, --, --, 
   {{0x73c00daf,0x00000000,0x00000000,0x00000000}},	//   рәше, --, --, --, 
   {{0x6eb85d4f,0x518401f4,0x154000f3,0x00000000}},	//   _एकजु, лура, _бечм, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4394e07f,0x00000000,0x00000000,0x00000000}},	//   _райс, --, --, --, 
   {{0x6d580a26,0xceb400ac,0x5f4401c6,0xce940395}},	//   _ātar, smən_, мүүн_, ласъ, 
   {{0x628ce080,0x6194069c,0x4ea40588,0xceb40213}},	// [132b0] meco, ሃደራዊ_, ырра, mməl_, 
   {{0x7bc4021a,0x3a2c0077,0xc0c40daf,0x3a38031c}},	//   tyhu, _sgep_, _рәми, _żsp_, 
   {{0x37e400bd,0x628c035a,0x00000000,0x00000000}},	//   _পুনর, oeco, --, --, 
   {{0x394c1c06,0x4a74748c,0xd974010b,0xf428005b}},	//   _pwes_, гышт, еркә_, ljää_, 
   {{0x7bc45e03,0x32f40882,0x443c04cc,0xa3e007af}},	//   syhu, nāya_, _ofv_, _नेस_, 
   {{0x628c0998,0x95b001e0,0x37e41887,0x916c0055}},	//   heco, ғриә, колг, _sṛkā, 
   {{0x628ce081,0x32f40882,0xb064007c,0x25e407f7}},	//   keco, hāya_, _hjää, _जेबी_, 
   {{0x443c01a9,0xf428005b,0xc794010b,0x00000000}},	//   _afv_, hjää_, уршы, --, 
   {{0x443c0109,0x394c00f2,0x916c002b,0xf8d40139}},	//   _bfv_, _uwes_, _gṛhā, _иңдә_, 
   {{0xa3e07a35,0x7988e082,0x00000000,0x00000000}},	//   _नेह_, _ipew, --, --, 
   {{0x97a44681,0x628c676d,0x3244113e,0x33d402dd}},	//   _ярал, feco, кенг, тіпт, 
   {{0x628ce083,0x81dc015b,0x2d900204,0xa3c00f4a}},	//   geco, _তুই_, ywye_, _एअर_, 
   {{0x7648e084,0x443c0212,0xe7c0054e,0xf1d001e0}},	//   mbey, _ffv_, păţâ, рөйө, 
   {{0x6140e085,0x443c0998,0x79880337,0x76480009}},	//   рера, _gfv_, _mpew, lbey, 
   {{0xb4cc121d,0x7648090e,0x7fd401ec,0x00000000}},	//   रसी_, obey, гіті, --, 
   {{0x7648e086,0x7988090c,0x43741b88,0x2d900204}},	//   nbey, _opew, _сушт, twye_, 
   {{0x7648058a,0xc0c40023,0x32f400b8,0x00000000}},	// [132c0] ibey, ጺሮም_, cāya_, --, 
   {{0x48bc0eac,0xb820060c,0x660400c5,0x9610015b}},	//   _অগ্র, मधाम_, ükki, _হলাম_, 
   {{0x7988e087,0x66dc0024,0x2d900af9,0xdcec00ef}},	//   _apew, sūki, swye_, _apcē, 
   {{0xa96849d2,0x2988214f,0x386802a8,0xb4cc0243}},	//   дида_, дско_, ɗari_, रसु_, 
   {{0x8884774d,0x7648058a,0x00000000,0x00000000}},	//   лғал, dbey, --, --, 
   {{0x628c0115,0x8778e088,0x00000000,0x00000000}},	//   zeco, ейкс_, --, --, 
   {{0xd7701c62,0xd754009f,0x00000000,0x00000000}},	//   لايع, نجيا_, --, --, 
   {{0x628c0077,0x2ef003cb,0x85740395,0xa9a4022e}},	//   xeco, nnyf_, глих, _иибд, 
   {{0x628ce089,0xa924e08a,0xf428005b,0xb4cc00dc}},	//   veco, _адал, yjää_, रसू_, 
   {{0x7648062c,0x44b403c5,0x00000000,0x00000000}},	//   abey, убос, --, --, 
   {{0xd4948c72,0x628ce08b,0x7648e08c,0xcfd800fe}},	//   тры_, teco, bbey, _দুঘন, 
   {{0x290c00a9,0xa64401b9,0x76480009,0x7988035a}},	//   llfa_, _شخصن, cbey, _ypew, 
   {{0xc0c40116,0x00000000,0x00000000,0x00000000}},	//   гәни, --, --, --, 
   {{0x443ce08d,0xa2c408df,0x506401d5,0x6d58002b}},	//   _ufv_, ासङ्, итса, _ātap, 
   {{0x628ce08e,0x1ee44f6f,0xf428023a,0x00000000}},	//   peco, نوسی_, rjää_, --, 
   {{0x25a44fa5,0x0b140154,0xc2740114,0x161c01f9}},	//   _krol_, িদুল_, _слиј, मेवर_, 
   {{0xbd182d29,0xa3e00037,0x00000000,0x00000000}},	// [132d0] ежах_, _नइँ_, --, --, 
   {{0xbb6807ad,0x6ea80014,0xa104009f,0x00000000}},	//   _netユ_, ٘نہہ_, _جذبه, --, 
   {{0x79880b1d,0xfa7c0020,0xbf1009a5,0x4c9418c7}},	//   _spew, _የምክር_, _гүвә, рихс, 
   {{0x25a4e08f,0x0e4400c0,0x00000000,0x00000000}},	//   _orol_, _вэрм, --, --, 
   {{0xf984468d,0x497401c6,0x6ed8011a,0x76480205}},	//   угло, илцс, _נחשפ, vbey, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe81c1094,0xdb2004d3,0x3dc80280,0x3868e090}},	//   येला_, _نوسی, lyaw_, ğar_, 
   {{0x25a40687,0x8aa40276,0xccf4016b,0xe69000d1}},	//   _brol_, _круд, nsɛn_, ملىد, 
   {{0x25a4107d,0x3dc8013f,0x7648e091,0x8ae40220}},	//   _crol_, nyaw_, rbey, _тірл, 
   {{0x25a4e092,0xe614e093,0xb4cc08a3,0x58840cab}},	//   _drol_, ыды_, रसे_, _шыба, 
   {{0x25a4e094,0xf3e4bad4,0x69c40139,0x00000000}},	//   _erol_, ужно, _üker, --, 
   {{0x3dc81c06,0x25a40077,0xe294e095,0x86e401d5}},	//   kyaw_, _frol_, гаю_, _кўчд, 
   {{0x7d046fff,0x395c015d,0xa2e00395,0x00000000}},	//   kohs, nsws_, сояд, --, 
   {{0xafe454a0,0xf3941ca9,0x3dc80009,0x00000000}},	//   гогл, _бриџ, dyaw_, --, 
   {{0x7d0402d0,0x916c0055,0x59d8024a,0x00000000}},	//   dohs, _nṛvā, _मेघर, --, 
   {{0xdee0e096,0x261800bc,0x3e880139,0xceb403b9}},	//   боси, मेकी_, кисү_, mmək_, 
   {{0xac84134c,0xceb400ac,0x3dc8e097,0x290c015d}},	// [132e0] лгал, lmək_, gyaw_, ylfa_, 
   {{0x7d040007,0x7c64e098,0x307408ca,0x00000000}},	//   gohs, لامل, _суис, --, 
   {{0x3dc81c06,0xab6400d1,0xceb400ac,0xa098010f}},	//   ayaw_, увел, nmək_, _װיכט, 
   {{0x2d8406ed,0x00000000,0x00000000,0x00000000}},	//   çoes_, --, --, --, 
   {{0x63780139,0x08540138,0xc87800c7,0x00000000}},	//   _känç, авлю, кҟа_, --, 
   {{0x307800c8,0x7d040561,0xceb400ac,0xefec0092}},	//   גאַנ, cohs, kmək_, _ቀልድ_, 
   {{0x25a401ab,0xe78400f7,0xa3e00456,0x9c8002f0}},	//   _srol_, ууло, _नें_, íčet, 
   {{0x25a4e099,0xe29c0ad9,0xd78400f1,0x468401d5}},	//   _prol_, koða_, انيو_, рқда, 
   {{0xe8f8e09a,0x00000000,0x00000000,0x00000000}},	//   _зла_, --, --, --, 
   {{0x26180210,0x00000000,0x00000000,0x00000000}},	//   मेगी_, --, --, --, 
   {{0x25a40142,0x00000000,0x00000000,0x00000000}},	//   _wrol_, --, --, --, 
   {{0x57f80302,0x25a4e09b,0x68e803e3,0x00000000}},	//   _אלבו, _trol_, lifd, --, 
   {{0xe6103004,0x25a4045a,0x94c800f1,0xe29c02d2}},	//   _اشا_, _urol_, _ګانې_, goða_, 
   {{0x68e80213,0x00000000,0x00000000,0x00000000}},	//   nifd, --, --, --, 
   {{0x3dc8013f,0x7d04022e,0x00000000,0x00000000}},	//   wyaw_, vohs, --, --, 
   {{0xdb0403cd,0x41b405d3,0xe29c0bcd,0x00000000}},	//   _åløf, _نمبر, boða_, --, 
   {{0xa18434b1,0xa25800d2,0x645801c6,0x3f840135}},	// [132f0] _сыйл, khôz, oati, ħluq_, 
   {{0xb1340014,0x629c01b9,0x63780139,0x00000000}},	//   _خوٝں, _haqo, _gänç, --, 
   {{0x3dc81c06,0x25e404fa,0x746802d3,0x6458005a}},	//   syaw_, _जेसी_, _ተበጊሱ_, iati, 
   {{0x4c94e09c,0x3dc81c06,0x09bc009e,0x64a40490}},	//   _қисс, pyaw_, _আইজা, _कोसळ, 
   {{0x629ce09d,0x50b8af84,0x00000000,0x00000000}},	//   _maqo, _شدید_, --, --, 
   {{0x6458e09e,0xd8380323,0x629ce09f,0x68404942}},	//   jati, хэд_, _laqo, онша, 
   {{0xc7642002,0x916c002b,0xc8640116,0x00000000}},	//   مايى, _hṛtā, стчи, --, 
   {{0x59042fb5,0x916c0882,0x629ce0a0,0xb4cc0ad7}},	//   _ཆེམས_, _kṛtā, _naqo, रस्_, 
   {{0xba18007b,0x00000000,0x00000000,0x00000000}},	//   _شيئا_, --, --, --, 
   {{0x2ed029d9,0xceb400ac,0xb3846aa2,0x857802e8}},	//   _सत्त, tmək_, алол, усът_, 
   {{0xe3b40276,0x87e411f4,0x00000000,0x00000000}},	//   абэ_, _люце, --, --, 
   {{0xceb40cc1,0x645820ac,0x00000000,0x00000000}},	//   rmək_, aati, --, --, 
   {{0x629ce0a1,0x64a40073,0x63780139,0x00000000}},	//   _daqo, _कोवळ, _pänç, --, 
   {{0x6458e0a2,0xc2f400c7,0x00000000,0x00000000}},	//   cati, _ҳџьы, --, --, 
   {{0x324401e0,0x629ce0a3,0xae78064d,0x00000000}},	//   _кейг, _faqo, ксах_, --, 
   {{0xafe401b9,0x00000000,0x00000000,0x00000000}},	//   гоҳл, --, --, --, 
   {{0xed5801b9,0x1cbc0327,0x00000000,0x00000000}},	// [13300] тоз_, _ཀྭང_, --, --, 
   {{0x3864e0a4,0x5ec40154,0x629ce0a5,0x00000000}},	//   _ndlr_, রোলে, _zaqo, --, 
   {{0x629c23e0,0x00000000,0x00000000,0x00000000}},	//   _yaqo, --, --, --, 
   {{0x629c4091,0xa9c400d8,0x00000000,0x00000000}},	//   _xaqo, ислк, --, --, 
   {{0x6924e0a6,0x6458e0a7,0x7734001f,0x7c2801e4}},	//   амда, yati, _ብሔረሰ, _ĝere, 
   {{0x7c2801e4,0x6d44e0a8,0x6fb81fc4,0x7e6800ef}},	//   _ŝere, _itka, _उपां, _ķepi, 
   {{0x6458e0a9,0xe0b4008f,0xccf40134,0x68e8e0aa}},	//   vati, ילסט_, nsɛm_, rifd, 
   {{0xf1000316,0xccf4013f,0x656400e5,0x00000000}},	//   लकुद_, isɛm_, ákho, --, 
   {{0xd940e0ab,0x3864bf65,0x629c036b,0xd9780022}},	//   _мети, _fdlr_, _raqo, _архә_, 
   {{0x7644013f,0x629c0548,0x6aa0e0ac,0x64580381}},	//   _ɑhyi, _saqo, ldof, uati, 
   {{0x629c353d,0x291c0455,0x18a0013e,0xb8c400cf}},	//   _paqo, _ihta_, _фахм, _ازقى, 
   {{0x6458e0ad,0x6d4404b9,0x6aa0e0ae,0x629c0eda}},	//   sati, _otka, ndof, _qaqo, 
   {{0x629ce0af,0x6458123b,0xf10003f8,0xd05c00ac}},	//   _vaqo, pati, लकूद_, lirə, 
   {{0x6458e0b0,0x629ce0b1,0x656006d9,0xc4580166}},	//   qati, _waqo, _ivoh, _сикх_, 
   {{0x6d44e0b2,0x629ce0b3,0xd83c02fb,0x5464041b}},	//   _atka, _taqo, _účes_, _тајм_, 
   {{0xfd7401c6,0x00000000,0x00000000,0x00000000}},	//   йлбэ, --, --, --, 
   {{0x8d74c9a4,0x6aa0022f,0xd05c0213,0x00000000}},	// [13310] قالا, ddof, hirə, --, 
   {{0x40940491,0x7c580c78,0xd05c03be,0x9f500429}},	//   _الدر, الار_, kirə, _exxá_, 
   {{0xd0080cfc,0x09e404c5,0x6d4401b9,0x69dc01e4}},	//   _веќе_, _ফুলা, _etka, ŝpel, 
   {{0xd05c03be,0x68f800b5,0x291c01c4,0x00000000}},	//   dirə, _ajtd, _ahta_, --, 
   {{0x7e7c7d79,0xf8480107,0x0d640395,0x00000000}},	//   _icsp, гӯед_, _мърм, --, 
   {{0x588477de,0x88c40533,0x63a8031c,0x9cc80153}},	//   рыда, قتىل, _orfn, _рыма_, 
   {{0xca7c022e,0x6560e0b4,0x47580006,0xec1801ee}},	//   _turа, _avoh, арыя_, _берә_, 
   {{0x20cc014a,0x6d44002d,0xab600150,0x6fb817c6}},	//   _büik_, _ytka, _ءۇنى, _उपसं, 
   {{0x7ae8e0b5,0xf508470c,0xca48007b,0xc97400ae}},	//   _imet, лнил_, _خلقه_, _واكث, 
   {{0x7ae805b1,0xd8740a11,0xc98400d8,0x00000000}},	//   _hmet, _خارب, _ќути, --, 
   {{0x7ae80fb7,0x78a0740d,0xd6d80640,0x4904e0b6}},	//   _kmet, _ialv, _итд_, _بولق, 
   {{0x0674010b,0x7ae80254,0x86c456e8,0x00000000}},	//   _душя, _jmet, _ويلن, --, 
   {{0x7ae80521,0xccf40134,0xf52001ec,0x798c0135}},	//   _mmet, wsɛm_, _ендi_, ħaww, 
   {{0x85b895ad,0x7ae80295,0x76580042,0xa3e03885}},	//   _خامس_, _lmet, _hewy, _नेक_, 
   {{0x78a0e0b7,0x7ae8e0b8,0x96d80316,0x7658e0b9}},	//   _malv, _omet, _बताउ, _kewy, 
   {{0xdee008da,0x00000000,0x00000000,0x00000000}},	//   поси, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [13320] --, --, --, --, 
   {{0x7ae8e0ba,0x78a0e0bb,0x7658e0bc,0xd05c03be}},	//   _amet, _nalv, _lewy, yirə, 
   {{0x7ae8011c,0xa09808a8,0x6a8400db,0x00000000}},	//   _bmet, _גייט, йлжа, --, 
   {{0x76580f7b,0xe9d8e0bd,0x78a005ac,0x291c4ca5}},	//   _newy, лке_, _aalv, _shta_, 
   {{0x6aa022a9,0x78a000da,0x7ae80036,0xbe8001d5}},	//   rdof, _balv, _dmet, _юқти, 
   {{0x78a0e0be,0xd05c03be,0x6cd4e0bf,0x6d400356}},	//   _calv, tirə, _اقسا, ţoas, 
   {{0x78a0e0c0,0x76580151,0xe7b40011,0x656008a5}},	//   _dalv, _bewy, জন্য, _svoh, 
   {{0xe81c0034,0x31600472,0x7ae80175,0x7658015d}},	//   येगा_, kskz_, _gmet, _cewy, 
   {{0x48c41248,0x291c003a,0x25a80338,0x78a0e0c1}},	//   _мәка, _thta_, ادبي_, _falv, 
   {{0x78a0e0c2,0xe7380d6f,0x00000000,0x00000000}},	//   _galv, _беж_, --, --, 
   {{0xa6841377,0x66e4e0c3,0x16d400f7,0x183401d3}},	//   _глед, _ложа, ргөө_, _آمد_, 
   {{0x76580660,0x78a0e0c4,0xd2440276,0x20cc03e0}},	//   _gewy, _zalv, зэри, _tüik_, 
   {{0x78a03361,0x673801a4,0x84c402dd,0x2408013d}},	//   _yalv, _hutj, _дәнд, _өнди_, 
   {{0x6738e0c5,0x7e7c01fa,0x95b400c7,0x6fb800bc}},	//   _kutj, _scsp, _ырхә, _उपशं, 
   {{0x6738e0c6,0xfd5c01f2,0x48e000c5,0x00000000}},	//   _jutj, bazị, _कतनो_, --, 
   {{0x161c01ad,0xbdd40d1d,0x00000000,0x00000000}},	//   मेकर_, ообщ, --, --, 
   {{0xd2080323,0xe1641671,0x673802d3,0x7ce806be}},	// [13330] _гээд_, _ادبي, _lutj, _hörə, 
   {{0x673805e4,0x00000000,0x00000000,0x00000000}},	//   _outj, --, --, --, 
   {{0x7ae80175,0x8e8401e4,0x00000000,0x00000000}},	//   _pmet, ŭŝat, --, --, 
   {{0x78a09ff4,0x916c00cd,0x00000000,0x00000000}},	//   _salv, _kṛpā, --, --, 
   {{0x78a00664,0x7658002e,0x4df4022e,0x00000000}},	//   _palv, _rewy, _еяёт, --, 
   {{0x67380184,0x7658002d,0x37dc00cc,0x00000000}},	//   _butj, _sewy, _বশবৰ, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7ae8e0c7,0x78a0e0c8,0x6738e0c9,0x6d3401ec}},	//   _umet, _walv, _dutj, _اۋەس_, 
   {{0x78a0e0ca,0x916c00cd,0x6604000d,0xceb403b9}},	//   _talv, _nṛpā, ükkp, mmət_, 
   {{0x33641830,0x98f4e0cb,0x78a005d5,0x6738e0cc}},	//   овог, _اثرا, _ualv, _futj, 
   {{0xd5b801e0,0x7ce806be,0x00000000,0x00000000}},	//   _әсе_, _cörə, --, --, 
   {{0xc0480bd9,0x00000000,0x00000000,0x00000000}},	//   _יז_, --, --, --, 
   {{0xe60c0c17,0x0638007b,0x070801f7,0x00000000}},	//   _цд_, _اسمع_, _ايني_, --, 
   {{0xceb400ac,0xf4281def,0x2ed000cd,0x69c40241}},	//   hmət_, _колл_, सस्त, _àkee, 
   {{0x7ce803be,0x9fc4e0cd,0xae580212,0xb6180150}},	//   _görə, огра_, ирає_, _ﹼﻬ_, 
   {{0xa3e039de,0x63ac00b5,0xd1640131,0x71581536}},	//   _नेट_, æbne, _ениқ, _крос_, 
   {{0xceb403be,0x7c2801e4,0x1aec00fe,0xace8009d}},	// [13340] dmət_, _ĝera, টকাই_, амаа_, 
   {{0x6bd40e26,0x7ce806be,0x00000000,0x00000000}},	//   يتار, _yörə, --, --, 
   {{0xeb98e0ce,0x7ce80213,0xb5fc010e,0x8d9c0092}},	//   рие_, _xörə, lašd, _ዋጋቸው_, 
   {{0x673801f5,0x00000000,0x00000000,0x00000000}},	//   _rutj, --, --, --, 
   {{0x6738e0cf,0xb5fc00a2,0x00000000,0x00000000}},	//   _sutj, našd, --, --, 
   {{0x6f14e0d0,0x765c008c,0x83fc05ce,0x6738e0d1}},	//   llyc, ðsyn, lađe, _putj, 
   {{0xdb803f07,0xab280229,0xaa4400f3,0x6f1401e3}},	//   _огри, _вова_, _мевл, olyc, 
   {{0x83fc04b9,0x6f140857,0xe72801f7,0x00000000}},	//   nađe, nlyc, جستو_, --, 
   {{0x7c3801d3,0xe5c406a6,0xceb406be,0x00000000}},	//   _ábrá, юско, lməs_, --, 
   {{0x39481709,0x6738e0d2,0x6f1400d7,0x09e4022e}},	//   íase_, _tutj, hlyc, _доғн, 
   {{0x74a82de5,0xe644030d,0xb86400f1,0x2b480051}},	//   ссың_, _дееп, _رالو, _jtbc_, 
   {{0x534007d5,0xdb980a7c,0xaf901954,0x15e8012d}},	//   ьхьа, בסטר, ውነትና_, _जेवर_, 
   {{0x64a4c169,0x6f1402d0,0xb5fc00a2,0x00000000}},	//   _мада, dlyc, gašd, --, 
   {{0x7ce803be,0x00000000,0x00000000,0x00000000}},	//   _törə, --, --, --, 
   {{0x672001af,0xceb403be,0x6f1402d0,0xe81c01f9}},	//   _khoj, ymət_, flyc, येचा_, 
   {{0x83fc2d2b,0xceb80063,0x00000000,0x00000000}},	//   gađe, ољу_, --, --, 
   {{0x6720009f,0x3cd40150,0x00000000,0x00000000}},	// [13350] _mhoj, пжас, --, --, 
   {{0xe3c80724,0x27f00209,0x0098009f,0x00000000}},	//   _tañı_, şyny_, _اَدب_, --, 
   {{0x672000c7,0x2b480798,0x30980375,0xb0980375}},	//   _ohoj, _ctbc_, _השתמ, _היתר, 
   {{0xb5fc0fb7,0x6f140085,0x6600009a,0xbdc00150}},	//   laše, clyc, _oxok, _كەزۋ, 
   {{0xdce41ae4,0xceb400ac,0x00000000,0x00000000}},	//   şlıc, rmət_, --, --, 
   {{0x6720e0d3,0x08c40845,0xed540a1e,0xb5fce0d4}},	//   _ahoj, мбін, _מבשר_, naše, 
   {{0x6720e0d5,0x6600009a,0xd7f80364,0x7b180354}},	//   _bhoj, _axok, шуд_, _говр_, 
   {{0x6720e0d6,0x25b00064,0x00000000,0x00000000}},	//   _choj, _šyla_, --, --, 
   {{0x67200175,0xa2bc00dc,0xb5fc3e9d,0x00000000}},	//   _dhoj, षान्, kaše, --, 
   {{0x248c0004,0xb5fc2804,0xd8080408,0x0618009d}},	//   _cbfm_, jaše, _кхел_, өхөө_, 
   {{0x66000117,0x33f4bb40,0xc2080a7c,0xc564004e}},	//   _exok, ячис, _עה_, пкөк, 
   {{0xf8bc09bd,0x67200842,0x1cb8031c,0xdb200066}},	//   _অতিথ, _ghoj, _མོའ_, érèn, 
   {{0xe29445b3,0x83fc0552,0xc4c4e0d7,0x00000000}},	//   чая_, vađe, ستیو, --, 
   {{0xb5fc05be,0xe5a0010b,0x672001ef,0x8fc40022}},	//   gaše, _чиши, _zhoj, ҿаҳҵ, 
   {{0x60207696,0x6f14035a,0x00000000,0x00000000}},	//   едра, tlyc, --, --, 
   {{0xee38ace8,0xb8dc081f,0xdfcc0691,0xed4400c0}},	//   сна_, _ཆོ_, ديف_, знап, 
   {{0x83fc04b9,0xde00e0d8,0xdee0e0d9,0x6f14e0da}},	// [13360] rađe, епти, хоти, rlyc, 
   {{0x83fc08a4,0x6f14e0db,0xeb98e0dc,0x5f4001b9}},	//   sađe, slyc, йиз_, بچیل, 
   {{0x6f14127b,0xfe70004b,0x2ee40327,0x645c0254}},	//   plyc, عدې_, _ċoff_, _õpie, 
   {{0x8eb40075,0x6da40588,0x63ac00b5,0x37e00154}},	//   _تەرت, _еима, åbni, যপার, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x1cb8003d,0x9c10063f,0x672004ce,0x6c3403e6}},	//   _མོར_, _bọdo, _shoj, _رفرا, 
   {{0x60243386,0xa0980a1e,0x1be424fc,0x00000000}},	//   mémé, מיסט, _едри_, --, 
   {{0x602473a0,0x798c0327,0x00000000,0x00000000}},	//   lémé, ħawr, --, --, 
   {{0xe7a404a9,0xe9d8e0dd,0x84c40116,0x69d40fac}},	//   غۇچى_, _ука_, дәйд, øyed, 
   {{0xbb700137,0x4438e0de,0x03f80063,0xdb20110e}},	//   _سۇۇع, ør_, жној_, _àròk, 
   {{0x1cb8038f,0x6720e0df,0xb5fc107d,0xc6840014}},	//   _མོལ_, _thoj, vaše, _ہێژن_, 
   {{0x290ce0e0,0x660005f5,0xd7ec00c6,0x667402dd}},	//   lofa_, _txok, _حكم_, _ءدار, 
   {{0x660001e2,0xb5fc0427,0xa5940212,0xa5081bc4}},	//   _uxok, taše, _хрещ, _леда_, 
   {{0x290ce0e1,0xd3e000ec,0x00000000,0x00000000}},	//   nofa_, _ڳڻپي, --, --, 
   {{0xb5fc1fe6,0x00000000,0x00000000,0x00000000}},	//   raše, --, --, --, 
   {{0x290c5114,0x80c002ab,0x00000000,0x00000000}},	//   hofa_, रॉजे, --, --, 
   {{0x804400db,0x00000000,0x00000000,0x00000000}},	// [13370] _ۉرگۅ, --, --, --, 
   {{0xdd904ef9,0x1a7000aa,0x00000000,0x00000000}},	//   мағы, ځپاڼ, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb203ee6,0xb5fc01a6,0x9cfc00cc,0x00000000}},	//   روشی, našc, ্গেন_, --, 
   {{0x290ce0e2,0x3ea8e0e3,0x3eb80f85,0xe29c02d2}},	//   fofa_, mdat_, _inst_, goði_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9f4400fd,0xfd5400b8,0x3ea8007f,0x00000000}},	//   _änä_, _anaḍ, odat_, --, 
   {{0x290c0618,0x35b400fd,0x4b240131,0xd5ac01d9}},	//   aofa_, җбүр, _كېلە, ُہا_, 
   {{0x2478001f,0x3ea8e0e4,0x00000000,0x00000000}},	//   _በአራት_, idat_, --, --, 
   {{0x1cb81b4b,0x3ea8e0e5,0x290c2d2f,0x3eb80051}},	//   _མོས_, hdat_, cofa_, _lnst_, 
   {{0xb7d469e7,0x3eb801c7,0x176801ee,0x00000000}},	//   _تقاب, _onst_, _ырап_, --, 
   {{0x3ea80205,0xe9e401ef,0x27f80419,0x00000000}},	//   jdat_, _čúzk_, úpne_, --, 
   {{0x3ea8e0e6,0xbef8012d,0x35a4009d,0x00000000}},	//   ddat_, ्कैन_, _цалг, --, 
   {{0x3eb800df,0xf5040014,0x3ea80561,0x00000000}},	//   _anst_, _تِتُ, edat_, --, 
   {{0xc4c403e6,0x6b9c0334,0x00000000,0x00000000}},	//   _ستوو, xwpg, --, --, 
   {{0x290ce0e7,0xef18063b,0x394c01fa,0x2d940137}},	//   zofa_, іма_, _otes_, мөгө_, 
   {{0x394c0070,0x2ef001f7,0x290c0b01,0x00000000}},	// [13380] _ntes_, riyf_, yofa_, --, 
   {{0xdd8ce0e8,0x921800aa,0x3eb8e0e9,0x6b9c0175}},	//   شوم_, _ورکړ_, _enst_, twpg, 
   {{0xbc242e51,0x8e6400ee,0x394ce0ea,0x6024a8d8}},	//   ىرمى, _пенҗ, _ates_, rémé, 
   {{0xaab81365,0xda6c01d9,0x83fc39ae,0x3ea80051}},	//   غدار_, لُم_, nađa, cdat_, 
   {{0xa2bc08ec,0x290ce0eb,0xd940b3ba,0x00000000}},	//   षात्, tofa_, вечи, --, 
   {{0x83fc05ce,0x27480114,0xb60401d3,0x00000000}},	//   hađa, очио_, zzáá, --, 
   {{0x394ce0ec,0xabd40014,0x2b140022,0xe0dc007f}},	//   _etes_, _غٲرت, _жьар, mpòt_, 
   {{0x1cb80327,0x4eac00cc,0x3f84031c,0x00000000}},	//   _མོོ_, _গকুল, ħlux_, --, 
   {{0xa504010b,0xe8f80353,0x7c443bdc,0xaf7c0092}},	//   дянл, _дла_, _åtrå, _ዕውቅና_, 
   {{0xe0dc0d29,0x38ac00e5,0x00000000,0x00000000}},	//   npòt_, törő_, --, --, 
   {{0xb5fc01a6,0xdb0408a5,0x955002f2,0x3ea8e0ed}},	//   tašc, _hrjá, _یخوا, ydat_, 
   {{0x83fc04b9,0x394c003b,0xa2bcc853,0x00000000}},	//   gađa, _ytes_, षाध्, --, 
   {{0x5184e0ee,0x7c28008f,0xe4c4036b,0x3ea8007c}},	//   кура, _ĝerm, _ойди, vdat_, 
   {{0xf770040b,0x6fb806e3,0x00000000,0x00000000}},	//   _جاے_, _उपखं, --, --, 
   {{0x3ea82595,0x83fc0989,0x6448e0ef,0x443c0789}},	//   tdat_, bađa, _iffi, _igv_, 
   {{0xb5fc1674,0x3ea8e0f0,0xce940395,0x00000000}},	//   laša, udat_, касъ, --, 
   {{0x3ea8e0f1,0x3cb400ee,0x00000000,0x00000000}},	// [13390] rdat_, нйар, --, --, 
   {{0x628ce0f2,0xfcc4053f,0x00000000,0x00000000}},	//   lfco, хәмм, --, --, 
   {{0x3a74e0f3,0x443c002f,0x00000000,0x00000000}},	//   елер, _mgv_, --, --, 
   {{0x443c7d4f,0x628c02e8,0x394c004e,0x3eb80158}},	//   _lgv_, nfco, _ptes_, _unst_, 
   {{0x6448e0f4,0xb5fc0010,0xdb0c00c7,0x996401f4}},	//   _offi, kaša, ñeña, фтел, 
   {{0xf7702781,0x443ce0f5,0xd838009d,0x00000000}},	//   هاب_, _ngv_, цэд_, --, 
   {{0xc76457d7,0xb5fc01a6,0x450403d4,0x00000000}},	//   نايى, daša, উতাক_, --, 
   {{0x443ce0f6,0xdb04008c,0x628c01f5,0x394ca50c}},	//   _agv_, _frjá, jfco, _ttes_, 
   {{0x443c579d,0xe0dc0100,0x00000000,0x00000000}},	//   _bgv_, npòs_, --, --, 
   {{0x443cd58d,0x628c01f5,0xe69001d5,0x69dc01e4}},	//   _cgv_, efco, پلید, ĝpet, 
   {{0x3988e0f7,0x321c033f,0xc7c403f6,0x00000000}},	//   lús_, ętym_, _исци, --, 
   {{0x6448e0f8,0x443c002f,0x00000000,0x00000000}},	//   _effi, _egv_, --, --, 
   {{0x3988e0f9,0x443ce0fa,0x83fc0e3c,0x216401f0}},	//   nús_, _fgv_, rađa, нияи_, 
   {{0x64a0e0fb,0x6288049f,0x83fc9d28,0x4094033a}},	//   _баша, _ögon, sađa, крст, 
   {{0x39882833,0x645c000d,0x9f940022,0xe1202901}},	//   hús_, _õpia, нытә, умри, 
   {{0x7648e0fc,0xc2f40588,0x3f8400db,0x057400db}},	//   ncey, _аџьы, àlua_, _ساۇد, 
   {{0x3988e0fd,0xf1d001c6,0x00000000,0x00000000}},	// [133a0] jús_, _сөнө, --, --, 
   {{0x3988e0fe,0xa15408d8,0xc0bc0092,0x3fd00150}},	//   dús_, _רביה_, ሰታል_, _ﮔﯟﺍﻧ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69c001c6,0x3988067c,0x4b3c0023,0xfaa401ec}},	//   txoe, fús_, _ክነግረ, кшін, 
   {{0xc87800fd,0xb5fc0309,0x9a6401e2,0x00000000}},	//   _alğa_, yaša, رمول_, --, 
   {{0x76480009,0x58d400d4,0x00000000,0x00000000}},	//   ecey, ндія_, --, --, 
   {{0x2078010f,0xbc140395,0x00000000,0x00000000}},	//   לאסא, _афтъ, --, --, 
   {{0xdb0401a8,0xac74215c,0xca2801ec,0x64480142}},	//   _trjá, _تاڭش, _قۋان_, _sffi, 
   {{0x2a640280,0x3988e0ff,0x1a98008f,0xc8780139}},	//   maob_, cús_, _צימע, _elğa_, 
   {{0xd94000d8,0x00000000,0x00000000,0x00000000}},	//   _сефи, --, --, --, 
   {{0xb5fce100,0xd5ac052f,0x2ca80009,0x443c0175}},	//   raša, _өс_, _mabd_, _vgv_, 
   {{0xb5fc0989,0x925800c9,0x15e8007d,0x66140158}},	//   mašn, нают_, _जेकर_, _øyko, 
   {{0x443ce101,0xb5fce102,0x628c0036,0x00000000}},	//   _tgv_, lašn, rfco, --, 
   {{0x6448e103,0xd5ac030f,0x2ca80009,0x439400db}},	//   _uffi, _دفه_, _nabd_, _аакс, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x53980375,0x7bc000a3,0x30380014,0x00000000}},	//   _זיהו, _àlui, بتُک_, --, 
   {{0x781c52be,0x237c007f,0x00000000,0x00000000}},	// [133b0] _फर्क_, lutj_, --, --, 
   {{0xb5fc07f5,0x2ca80009,0x764803e0,0x00000000}},	//   kašn, _cabd_, zcey, --, 
   {{0xb5fc1326,0xf0900375,0x9f48023a,0xe0dc004e}},	//   jašn, _דני_, ömät_, spòs_, 
   {{0xb5fc0bb8,0x76480548,0x3988067c,0x00000000}},	//   dašn, xcey, tús_, --, 
   {{0x4a447a9c,0x00000000,0x00000000,0x00000000}},	//   унів, --, --, --, 
   {{0x3988e104,0x00000000,0x00000000,0x00000000}},	//   rús_, --, --, --, 
   {{0xb6a4e105,0x00000000,0x00000000,0x00000000}},	//   вийл, --, --, --, 
   {{0x7bc40921,0x69dc01e4,0xceb406be,0x00000000}},	//   mxhu, ĝper, hlən_, --, 
   {{0x18b00598,0x7bc40200,0x80d0012d,0xf9600244}},	//   _бәйр, lxhu, _सकूं, _ئۆتێ, 
   {{0x8cc404fa,0x83fc00f3,0xb5fc04a7,0x5fb01408}},	//   रायो, rađn, bašn, ुमाल, 
   {{0x25a4e106,0xa5200166,0x00000000,0x00000000}},	//   _esol_, рмэд, --, --, 
   {{0x645c00c5,0xae20000d,0x00000000,0x00000000}},	//   _õpin, _मरलन_, --, --, 
   {{0x8cc46c5a,0x00000000,0x00000000,0x00000000}},	//   रामो, --, --, --, 
   {{0xb5fc022a,0xfbe01bd6,0x00000000,0x00000000}},	//   lašo, पनाम, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe3c80de2,0x30980150,0xb5fc00c0,0x00000000}},	//   _waññ_, _ﺘﺤﺩﻴ_, našo, --, 
   {{0xa2bc146b,0xac84010b,0x2ca8004e,0x00000000}},	// [133c0] षार्, кгал, мкап_, --, 
   {{0xe29c08ce,0x00000000,0x00000000,0x00000000}},	//   boðs_, --, --, --, 
   {{0x2a641c06,0xa6e001a8,0xdcac1183,0x8cc401ad}},	//   taob_, óðki, تىل_, राबो, 
   {{0xb5fc0010,0x98a40115,0xa7840133,0x00000000}},	//   vašn, ĉiĝi_, ۆشبو, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x1cb80135,0x6d54e107,0x25a40009,0xa00000fe}},	//   _མོག_, mpya, _rsol_, _এৰিব_, 
   {{0x6d5400dc,0x6b64bae4,0x00000000,0x00000000}},	//   lpya, _шква, --, --, 
   {{0x25a40798,0x6d5400e4,0x00000000,0x00000000}},	//   _psol_, opya, --, --, 
   {{0x7950168d,0xe4e402d5,0x6d54007f,0x96b40063}},	//   _هێنا, вінн, npya, тују_, 
   {{0x80d00034,0x7c280115,0x00000000,0x00000000}},	//   _सकें, _ŝeri, --, --, 
   {{0x83fce108,0xf8ac0451,0xd4c001ec,0x18640117}},	//   rađo, _رکو_, рсып, _рахи_, 
   {{0x8cc43b90,0x309801ec,0x00000000,0x00000000}},	//   राडो, _ﺘﺤﺭﻴ_, --, --, 
   {{0xa5d8e109,0x25a40117,0x167402e4,0x645c000d}},	//   _تبار_, _usol_, _יגאל_, _õpio, 
   {{0x6d54022e,0xdeec0092,0x765c0162,0x00000000}},	//   dpya, ቀዱን_, ðsyv, --, 
   {{0x6d540369,0x6458009f,0xdb0401f4,0x4394004e}},	//   epya, mbti, _yrjä, _сайс, 
   {{0x1cb80867,0xf1ec012d,0xa6e003b2,0x645800c0}},	//   _མོང_, _चेक़_, óðhi, lbti, 
   {{0xa4a40248,0x00000000,0x00000000,0x00000000}},	// [133d0] _gbòò, --, --, --, 
   {{0xc0c44eac,0x5fa000d1,0x00000000,0x00000000}},	//   _сәми, _پەرم, --, --, 
   {{0x69d408fb,0x6458e10a,0xebc01206,0x00000000}},	//   øyen, ibti, бәтн, --, 
   {{0xca740046,0x7bc40240,0x5f7400ec,0xcd2800d1}},	//   аушы, rxhu, _ٻاھر, ىسەن_, 
   {{0xd02802f5,0x7f440477,0x00000000,0x00000000}},	//   _মলয়_, _huhq, --, --, 
   {{0x8cc481e9,0x1b74007b,0x00000000,0x00000000}},	//   राणो, _لدرج, --, --, 
   {{0x0b881677,0x7f440455,0x00000000,0x00000000}},	//   _исти_, _juhq, --, --, 
   {{0x6458e10b,0x29000248,0x00000000,0x00000000}},	//   ebti, _ìkan_, --, --, 
   {{0xb5fc3f99,0x00000000,0x00000000,0x00000000}},	//   rašo, --, --, --, 
   {{0x645c007d,0x70d052be,0x7af80142,0x00000000}},	//   _õpil, _हवेल, liwt, --, 
   {{0x33d40046,0xb5fc02f0,0xd1d40092,0x7754014b}},	//   уіпт, pašo, _ያውቁ_, _скеф, 
   {{0x6458e10c,0xe1fce10d,0xafe401d5,0x00000000}},	//   abti, raón_, қобл, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6140e10e,0x386001a9,0x2570009f,0xd7740240}},	//   сера, аhri_, _اهوس, _አርትራ_, 
   {{0xb9cc001f,0x61e006be,0x00000000,0x00000000}},	//   _ሰጡ_, _ənli, --, --, 
   {{0x7e541f85,0xada45c97,0xceb403be,0x7f44014f}},	//   итуц, лабл, lməz_, _duhq, 
   {{0xdb04045f,0x00000000,0x00000000,0x00000000}},	// [133e0] _tsjê, --, --, --, 
   {{0xb5fc0cf4,0xceb40213,0x8cc4033f,0xb28400fb}},	//   vašl, nməz_, राधो, _рыҫк, 
   {{0x98380092,0x6d54007f,0xd17401ec,0xceb40213}},	//   ጠናቀቀ, spya, _сықы, lləm_, 
   {{0xdca0e10f,0x6d54010a,0xa96820c2,0xed581436}},	//   _қаси, ppya, еида_, _пом_, 
   {{0x645801d9,0x1b2000cc,0xa8500304,0xceb403b9}},	//   ybti, _বংশই_, белә, kməz_, 
   {{0xb5fc488c,0x6f14014f,0x00000000,0x00000000}},	//   rašl, loyc, --, --, 
   {{0xebe4a95a,0x1d04010a,0xceb403e3,0x00000000}},	//   _совп, _сери_, hləm_, --, 
   {{0x857402e8,0x6f140477,0x00000000,0x00000000}},	//   алих, noyc, --, --, 
   {{0x6d44e110,0x940406be,0x00000000,0x00000000}},	//   _juka, _ibnə_, --, --, 
   {{0x6d44e111,0x6aa0e112,0x44f400d6,0xe4a403f6}},	//   _muka, leof, рпос, урио, 
   {{0xd49410b6,0x6d44e113,0x4438e114,0x6458e115}},	//   уры_, _luka, är_, rbti, 
   {{0x6aa0a2d2,0x6f14e116,0x6d44e117,0x00000000}},	//   neof, joyc, _ouka, --, 
   {{0x6d44e118,0x00000000,0x00000000,0x00000000}},	//   _nuka, --, --, --, 
   {{0x6560014b,0xf3f4e119,0x6aa003a0,0xb6a000a2}},	//   _iwoh, اتیک, heof, _çâre, 
   {{0x6d44e11a,0x65600099,0x4034d0e2,0xa370009f}},	//   _auka, _hwoh, ревс, _اَبڙ, 
   {{0x6d44e11b,0xf3c82b49,0xdef80323,0x65600230}},	//   _buka, _جبهه_, хыг_, _kwoh, 
   {{0x6d44e11c,0x69d4168c,0xc0e825d2,0xf2940248}},	// [133f0] _cuka, øyel, _لفظن_, _njẹ́_, 
   {{0x6d44e11d,0x656000ca,0x7af80066,0x00000000}},	//   _duka, _mwoh, wiwt, --, 
   {{0x6d44e11e,0xfff832de,0x7f58e11f,0x6f1403ac}},	//   _euka, _شکست_, _шанс_, boyc, 
   {{0x6d44e120,0x65600b6f,0x6aa005e4,0xdb0402d2}},	//   _fuka, _owoh, geof, _hrjú, 
   {{0x6d4401ba,0x09d800bd,0xb5fc01fa,0x3f9001c4}},	//   _guka, _দেবা, tašm, ltzu_, 
   {{0x63a8e121,0xdbe004d4,0x7af80142,0x00000000}},	//   _osfn, séña, siwt, --, 
   {{0x6d44e122,0x65600472,0x3f90e123,0x63a801e4}},	//   _zuka, _awoh, ntzu_, _nsfn, 
   {{0x6d44e124,0x65600526,0x00000000,0x00000000}},	//   _yuka, _bwoh, --, --, 
   {{0x6d449d49,0x00000000,0x00000000,0x00000000}},	//   _xuka, --, --, --, 
   {{0x85084908,0xb4643e1e,0xb5fc02f0,0xf56801ec}},	//   лдың_, школ, lašk, ншүк_, 
   {{0x6560014b,0x73040902,0x00000000,0x00000000}},	//   _ewoh, ипоз, --, --, 
   {{0xaa300241,0x00000000,0x00000000,0x00000000}},	//   _ṣẹ́_, --, --, --, 
   {{0x05641cb8,0xe44c1fce,0x6f14127b,0x6498009d}},	//   _гвін, _мж_, voyc, хтөр_, 
   {{0x63a80724,0x00000000,0x00000000,0x00000000}},	//   ämnä, --, --, --, 
   {{0xb5fc151c,0x6f1805f5,0x6aa0009a,0x136401b9}},	//   kašk, вцас_, yeof, _ёпиқ_, 
   {{0x6d44e125,0xb5fc1fe6,0xdee002e8,0x00000000}},	//   _puka, jašk, ооси, --, 
  
   {{0xee381920,0x82840137,0xb5fce126,0x6d444f96}},	// [13400] тна_, _اجىل, dašk, _quka, 
   {{0x6d4406e4,0xaec402dd,0x7ae80327,0x7c641955}},	//   _vuka, ыбұл, _ċeta, مامل, 
   {{0x6d44e127,0x3dc80429,0x6aa001e7,0x6a8401c0}},	//   _wuka, axaw_, teof, илжа, 
   {{0xe9d8e128,0x6394008f,0x6f14014f,0x8cc408ec}},	//   кке_, ידעא_, qoyc, राहो, 
   {{0x6aa0e129,0x6d44e12a,0xc7b8107d,0x00000000}},	//   reof, _uuka, _srđ_, --, 
   {{0x65600526,0x6aa0007b,0x3078008f,0xe9e0012d}},	//   _rwoh, seof, דאַנ, jaźń_, 
   {{0x656002c4,0xb5fc107d,0x2d900ea0,0x6aa0030a}},	//   _swoh, bašk, ltye_, peof, 
   {{0xd6d4e12b,0xab2810fc,0x00000000,0x00000000}},	//   иты_, _роба_, --, --, 
   {{0x2d90e12c,0x645c00c5,0xf68800d1,0x00000000}},	//   ntye_, _õpik, اڭمۇ_, --, 
   {{0xd1f00125,0xd49418ac,0x83fc05ce,0x8d9c0150}},	//   ጀክት_, арю_, lađi, _ﺇﺴﺤﻕ_, 
   {{0x66e44685,0x2d9001f4,0x00000000,0x00000000}},	//   _кожа, htye_, --, --, 
   {{0x83fc0989,0x2d90e12d,0x65600223,0xd6800d30}},	//   nađi, ktye_, _twoh, _душп, 
   {{0xe4e400d6,0x65606468,0x048804a9,0x24e80139}},	//   _війн, _uwoh, _йәни_, _имди_, 
   {{0xb5fc02f0,0xceb403b9,0x00000000,0x00000000}},	//   zašk, lləh_, --, --, 
   {{0x43840597,0x2d90017a,0xa5080131,0x00000000}},	//   _العق, etye_, _كىچە_, --, 
   {{0x2d90017a,0x3f90009d,0x41b402da,0x1ee410e8}},	//   ftye_, rtzu_, _همبر, جوری_, 
   {{0x1cb8003d,0xb5fc0fb7,0x2d90017a,0xf9740092}},	// [13410] _མོད_, vašk, gtye_, _አልፎም_, 
   {{0xa2bc1a22,0x3e64004d,0x00000000,0x00000000}},	//   षाक्, ặt_, --, --, 
   {{0xb5fce12e,0x2d9004ba,0x0b880063,0xbb940395}},	//   tašk, atye_, исци_, саещ, 
   {{0x83fc1505,0x0b44e12f,0x09d800cc,0x00000000}},	//   gađi, інін, _দেধা, --, 
   {{0x7e6ce130,0x6ee803b2,0x98f40124,0xf8b801c6}},	//   maap, _dýbd, аҭас_, лөж_, 
   {{0x7e6ce131,0xf744d221,0xb5fc0010,0x645c0254}},	//   laap, беко, sašk, _õpih, 
   {{0x48781c26,0xb5fc80b6,0x9ac401d9,0x9a84e132}},	//   рсія_, maši, _پگاہ_, _вузл, 
   {{0xb5fc2d2b,0x7e6ce133,0xa3b80307,0xb89401d3}},	//   laši, naap, घिन_, _گارڈ, 
   {{0x7e6c0194,0x00000000,0x00000000,0x00000000}},	//   iaap, --, --, --, 
   {{0x7e6ce134,0xb5fce135,0x00000000,0x00000000}},	//   haap, naši, --, --, 
   {{0x1cb80867,0x324457aa,0x00000000,0x00000000}},	//   _མོན_, йенг, --, --, 
   {{0xc048008d,0x7e6ce136,0xc6a400d8,0x973005af}},	//   _טז_, jaap, _мрчи, _بکتا, 
   {{0xb5fc0960,0x85b80a81,0x37a803d4,0x00000000}},	//   kaši, _پانس_, _কপিৰ, --, 
   {{0xb5fc39ae,0xd1f0001f,0x00000000,0x00000000}},	//   jaši, ጀክቱ_, --, --, 
   {{0x7e6c0421,0x00000000,0x00000000,0x00000000}},	//   faap, --, --, --, 
   {{0x70140acd,0x7e6c0869,0xdfcce137,0xab600790}},	//   _दुःख_, gaap, ريق_, çüml, 
   {{0xb5fc05ce,0x30e4009e,0x8cc41bd6,0x00000000}},	// [13420] faši, _নদীস, रालो, --, 
   {{0x2d90e138,0xace80588,0xb5fc0e3c,0xfaf800b8}},	//   rtye_, ымза_, gaši, _amū_, 
   {{0xaf0853e2,0x7e6c0083,0x6ee80432,0xe7a4033f}},	//   _مقدم_, baap, _aýbe, _कैंप, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x83fc098d,0xceb403be,0xb5fc2804,0x00000000}},	//   rađi, mdə_, baši, --, 
   {{0xceb403be,0x58d0016c,0x83fc08a4,0x00000000}},	//   ldə_, зошт, sađi, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xceb49f20,0xaae40132,0x85e43ee0,0x26c01bce}},	//   ndə_, _اسسو, يۋان, ñko_, 
   {{0x05a404d3,0x00000000,0x00000000,0x00000000}},	//   ڕشگێ, --, --, --, 
   {{0xceb406be,0x00000000,0x00000000,0x00000000}},	//   hdə_, --, --, --, 
   {{0xceb40cc1,0xd6cce139,0x291c0009,0x7e6ce13a}},	//   kdə_, _ет_, _ikta_, yaap, 
   {{0xceb403b9,0x00000000,0x00000000,0x00000000}},	//   jdə_, --, --, --, 
   {{0x7e6c074d,0xceb403be,0xd9740131,0x00000000}},	//   vaap, ddə_, ﭽﯩﺪﻩ_, --, 
   {{0x7e6c3545,0x00000000,0x00000000,0x00000000}},	//   waap, --, --, --, 
   {{0x7e6ce13b,0xb5fce13c,0x4fc40e92,0xceb40213}},	//   taap, vaši, пста, fdə_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8d740202,0xb5fc0552,0xedd80588,0x7d783e1a}},	// [13430] كالا, taši, алтә_, شمار_, 
   {{0x7e6ce13d,0x9c44e13e,0x4ba80137,0x227000e5}},	//   saap, схал, өөсү_, _بچھڑ, 
   {{0x7e6ce13f,0x7bf80e92,0x40341cc9,0xceb40213}},	//   paap, јнер_, _фенс, bdə_, 
   {{0x291ce140,0xceb400ac,0x68f803ac,0x271000af}},	//   _akta_, cdə_, _amtd, डकोर_, 
   {{0x8d84e141,0xb5fc0b4b,0x60d4005a,0x68f801a9}},	//   _нурд, paši, _koxm, _bmtd, 
   {{0x6ee801a2,0xb3a80724,0x83fc17a3,0x5884034a}},	//   _výbe, _çıgı, lađu, сыда, 
   {{0x28d8375c,0xb78800fd,0x47580006,0x00000000}},	//   _बकरि, рәзе_, брыя_, --, 
   {{0x75d4911b,0x83fc05ce,0x248ce142,0x291ce143}},	//   قيعا, nađu, _acfm_, _ekta_, 
   {{0x7ae8e144,0x8e90044e,0x291c0093,0x60d403ac}},	//   _ilet, _ዝኽእሉ_, _fkta_, _ooxm, 
   {{0x248c009a,0xceb403be,0x69c401a6,0x3a2c0139}},	//   _ccfm_, zdə_, _škeg, _izep_, 
   {{0xceb400ac,0x46e819bb,0x33f402bf,0xc32cb071}},	//   ydə_, рдөн_, ючис, گەي_, 
   {{0xceb40213,0xdb2000f2,0x00000000,0x00000000}},	//   xdə_, èrèn, --, --, 
   {{0x60d40793,0xd624516c,0xceb40213,0x291c010e}},	//   _boxm, _اعاي, vdə_, _ykta_, 
   {{0x7ae8e145,0x64a00372,0xa0646ff7,0x05740046}},	//   _llet, _жаша, жара_, _ءاند, 
   {{0x7ae8e146,0xceb403be,0x60d4968b,0xb0340131}},	//   _olet, tdə_, _doxm, زىرغ, 
   {{0x83fc05a1,0x7ae8045a,0x00000000,0x00000000}},	//   gađu, _nlet, --, --, 
   {{0xceb411a9,0x2c24015b,0x00000000,0x00000000}},	// [13440] rdə_, _বলেই_, --, --, 
   {{0xdd8ce147,0xeb9800c7,0xceb400ac,0xd1300372}},	//   ئول_, ииз_, sdə_, _سۅز_, 
   {{0x7ae8e148,0xa09800c8,0xb5fc9915,0x6e440209}},	//   _blet, _דייט, mašu, _менз, 
   {{0x7ae8e149,0xb5fc151c,0x6398008f,0x645c0037}},	//   _clet, lašu, יסענ, _õpiv, 
   {{0x7ae80010,0xfe9001b9,0x60d403e3,0x00000000}},	//   _dlet, _سیلج, _yoxm, --, 
   {{0x3a2c2625,0xb5fc0006,0xd8f402bf,0x5d64269c}},	//   _dzep_, našu, онії_, _фирм_, 
   {{0x248c19f5,0xbc7000db,0x00000000,0x00000000}},	//   _rcfm_, _سۇنب, --, --, 
   {{0x7ae8014a,0xefc8001f,0x260400d4,0x00000000}},	//   _glet, _አውደ_, жчог, --, 
   {{0xe4a45716,0xdad00075,0x9f9c06af,0x00000000}},	//   орно, _تەنھ, réée_, --, 
   {{0xb5fc00f3,0x7ae876e0,0x291c00cd,0xb8641291}},	//   jašu, _zlet, _ukta_, _فامو, 
   {{0x7ae8005b,0x00000000,0x00000000,0x00000000}},	//   _ylet, --, --, --, 
   {{0x60d403b9,0x680806be,0x00000000,0x00000000}},	//   _soxm, _tәdb, --, --, 
   {{0x26c40050,0x00000000,0x00000000,0x00000000}},	//   _inoo_, --, --, --, 
   {{0x7608010f,0x00000000,0x00000000,0x00000000}},	//   _פּײַ, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdbcc0118,0x7d5402e8,0x00000000,0x00000000}},	//   užíc, звах, --, --, 
   {{0x83fc04b9,0x60d406be,0x00000000,0x00000000}},	// [13450] rađu, _toxm, --, --, 
   {{0xb5fc0b91,0x3d140034,0x83fc110c,0x3a2c0210}},	//   mašt, तकें_, sađu, _rzep_, 
   {{0xf0900d65,0xb5fc1326,0x0a58063f,0x26c4e14a}},	//   _אני_, lašt, _ịnụl, _onoo_, 
   {{0x26c4e14b,0xd90c1c3b,0x5338010f,0xddd0012d}},	//   _nnoo_, ھیا_, ַנגן_, ągły, 
   {{0x19a8053f,0x3ea8e14c,0xc9640212,0x3b0c036e}},	//   ртеп_, meat_, двій, _vjeq_, 
   {{0x3ea8e14d,0x26c4e14e,0xf74400d8,0x7ae8010e}},	//   leat_, _anoo_, пеко, _wlet, 
   {{0xf7700597,0x6ee80306,0x00000000,0x00000000}},	//   ءات_, _hýba, --, --, 
   {{0x3ea8e14f,0x00000000,0x00000000,0x00000000}},	//   neat_, --, --, --, 
   {{0xb5fce150,0x20100393,0xd85002dd,0xc77400cf}},	//   jašt, _lxxi_, _жезө, птөө, 
   {{0x97c45cb5,0x3ea8e151,0xceb400ac,0x394c01e4}},	//   _وتام, heat_, llət_, _iues_, 
   {{0x394c092e,0xd7f84494,0x3ea841a2,0x00000000}},	//   _hues_, _туа_, keat_, --, 
   {{0x26c400e8,0x3944ce46,0x394c0036,0xb5fc0784}},	//   _gnoo_, _hils_, _kues_, wašu, 
   {{0x3ea81730,0x39445177,0xd5a007d6,0x213001fb}},	//   deat_, _kils_, _آلتی, _bhxh_, 
   {{0x3d140034,0xceb403e3,0x555000e5,0x00000000}},	//   तकों_, hlət_, _ٹھکر, --, 
   {{0xb5fc3116,0x394c0a40,0x2010cdcf,0xd9c002f5}},	//   rašu, _lues_, _cxxi_, ্নিম, 
   {{0x3ea8e152,0x394ce153,0xb8dc0327,0x9f4801d3}},	//   geat_, _oues_, _ཇལ_, ájás_, 
   {{0x394ce154,0xec787fe8,0x3944279e,0xb3a8013d}},	// [13460] _nues_, йпа_, _oils_, _çıbı, 
   {{0x3944e155,0x82340050,0x645c00c5,0xb5fce156}},	//   _nils_, _تر٘ا, _õpit, lašs, 
   {{0x3ea8e157,0x394c0393,0xeb98e158,0xceb403b9}},	//   beat_, _aues_, сие_, flət_, 
   {{0x3ea8e159,0x3944039a,0xa3bc05f9,0x394c015d}},	//   ceat_, _ails_, ीमत_, _bues_, 
   {{0xdeb8011a,0x394c0f85,0x39440171,0x69c401ef}},	//   _המכל, _cues_, _bils_, _škeb, 
   {{0x394ce15a,0x3944e15b,0xdb04008c,0xa174010f}},	//   _dues_, _cils_, _brjó, לענד_, 
   {{0x39441675,0xb5fc07f5,0xd870a797,0x97a05b0f}},	//   _dils_, zašt, راوب, ерыл, 
   {{0x4ad0190c,0x394c015d,0x8cc44a01,0xb5fc02f0}},	//   _सचिव, _fues_, राको, jašs, 
   {{0x3944e15c,0x394c0098,0x9f4400b0,0xd5b40276}},	//   _fils_, _gues_, _änö_, псэ_, 
   {{0x6ed80882,0xb5fc16a3,0xdb0401a8,0x00000000}},	//   ṃbha, vašt, _frjó, --, 
   {{0x6e24002d,0xdb0401a8,0xed900023,0x394c0139}},	//   _lykb, _grjó, _ዚግበር_, _zues_, 
   {{0x26c40421,0xb5fc04a7,0x73c02cc8,0xf7080208}},	//   _unoo_, tašt, тәше, lần_, 
   {{0xd6cc05d9,0x3ea8e15d,0x6720e15e,0xd25800a8}},	//   _حقن_, veat_, _ikoj, яцэ_, 
   {{0xb5fc4a52,0x2010020c,0x3ea800b5,0x741400ec}},	//   rašt, _pxxi_, weat_, _ڪوٺا, 
   {{0x3ea8e15f,0x67201418,0x999c0327,0xcfa406ed}},	//   teat_, _kkoj, _sfuż_, ншти, 
   {{0xb5fce160,0x7bc00024,0x3ea8003a,0xa80400a2}},	//   pašt, _šluo, ueat_, _zyñý, 
   {{0xceb40cc1,0x672001c8,0x628ce161,0x3ea89583}},	// [13470] vlət_, _mkoj, mgco, reat_, 
   {{0x61ece162,0x3ea863c6,0x6ee80232,0x6e24002d}},	//   ınlı, seat_, _výba, _dykb, 
   {{0x3ea83af1,0x88c4009e,0x394c045a,0x7e680254}},	//   peat_, ্সাক, _sues_, _õepo, 
   {{0x628ce163,0x394c4e4c,0x394452b3,0xd9c003d4}},	//   ngco, _pues_, _sils_, ্নসম, 
   {{0x39449b2a,0xdde88b4d,0x6144004a,0x7e7c0010}},	//   _pils_, _طرحه_, célè, _idsp, 
   {{0x394c0231,0xa3bc038e,0x6720e164,0xdb040008}},	//   _vues_, ीमा_, _akoj, _prjó, 
   {{0xceb403be,0x394c01c7,0x00000000,0x00000000}},	//   mlər_, _wues_, --, --, 
   {{0x394ce165,0xceb403be,0x06744da8,0x39442d3e}},	//   _tues_, llər_, ىنىڭ, _wils_, 
   {{0x39440c86,0x394c00c5,0x69d40fac,0xe7d0023e}},	//   _tils_, _uues_, øyet, _थपथप, 
   {{0xceb40cc1,0x6604bde3,0x672001f4,0xdb0402d2}},	//   nlər_, úkka, _ekoj, _trjó, 
   {{0xb27403cc,0xd8000354,0x00000000,0x00000000}},	//   үлүш, _чăн_, --, --, 
   {{0xceb403b9,0xa9e00248,0x00000000,0x00000000}},	//   hlər_, _ńjẹ́_, --, --, 
   {{0xceb40cc1,0x61400276,0x21640107,0x00000000}},	//   klər_, ӂера, мияи_, --, 
   {{0x7e7ce166,0xe5a00131,0x628c01a4,0x00000000}},	//   _adsp, _риши, agco, --, 
   {{0xceb403be,0x628c010a,0x7414bd96,0xb5fc0309}},	//   dlər_, bgco, _توغا, mašq, 
   {{0xb5fc0784,0xf25401d5,0x645c0254,0x00000000}},	//   lašq, _غضبد, _õpir, --, 
   {{0xceb403be,0xed4416a4,0xa638010f,0x00000000}},	// [13480] flər_, днап, ַגער, --, 
   {{0xac0808d0,0xb5fc0113,0x7e7c7350,0xceb403b9}},	//   онза_, našq, _edsp, glər_, 
   {{0x6e24000f,0xef1817a0,0x00000000,0x00000000}},	//   _wykb, _ммо_, --, --, 
   {{0x7e7c0998,0xb5fc02d1,0xbae40212,0x6e2401bf}},	//   _gdsp, hašq, нцій, _tykb, 
   {{0xceb40cc1,0xb5fc0309,0x6ee801ef,0xed5803f6}},	//   blər_, kašq, _hýbo, _фог_, 
   {{0x765805e4,0x6720e167,0xceb403e3,0x9f5c0200}},	//   _afwy, _skoj, clər_, ërçe_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x0ec400af,0x69d40fac,0x00000000,0x00000000}},	//   _लोमड, øyes, --, --, 
   {{0xa924234c,0xd560013d,0x00000000,0x00000000}},	//   _ждал, ктэп, --, --, 
   {{0x03f80114,0x00000000,0x00000000,0x00000000}},	//   зној_, --, --, --, 
   {{0xe7280261,0xd494e168,0x76580042,0x225c1bce}},	//   _дожд_, фры_, _ffwy, ñuko_, 
   {{0x6720014b,0x9660e169,0xceb403be,0x9258034b}},	//   _ukoj, _акце, zlər_, мают_, 
   {{0xceb400ac,0x290cc044,0xf66400f7,0x6ee800a2}},	//   ylər_, onfa_, _чечү, _aýbo, 
   {{0xd5ac7380,0x3958026c,0xb5fc0309,0xaa80032e}},	//   _خفه_, _ésse_, mašp, _þýfi, 
   {{0xceb40213,0x76580142,0x00000000,0x00000000}},	//   vlər_, _yfwy, --, --, 
   {{0xd2580276,0xdef801c0,0x00000000,0x00000000}},	//   _оць_, цыг_, --, --, 
   {{0xceb403be,0xb5fc03f0,0x00000000,0x00000000}},	// [13490] tlər_, našp, --, --, 
   {{0x69c007f8,0x5184014b,0x00000000,0x00000000}},	//   लिनी, _руъа, --, --, 
   {{0xceb411a9,0xb5fc0309,0x7e7c0334,0x6ee802f0}},	//   rlər_, hašp, _tdsp, _kýbl, 
   {{0x7e7c037e,0xceb403be,0x2ef0002d,0xb5fc02d1}},	//   _udsp, slər_, chyf_, kašp, 
   {{0x3eb80066,0x9f400240,0xb5fc03f0,0xceb40213}},	//   _iast_, hyjë_, yašq, plər_, 
   {{0xa3bc00af,0x3eb8e16a,0xceb40213,0x97280023}},	//   ँटा_, _hast_, qlər_, _ስቅያት, 
   {{0x25a429b1,0x2a64e16b,0x69d4072b,0xab6003e0}},	//   _apol_, bbob_, øyer, çütl, 
   {{0x3eb8e16c,0x25a40332,0xb5fc0309,0x7d0403e0}},	//   _jast_, _bpol_, wašq, lihs, 
   {{0x9964063b,0x27300131,0x75440131,0x762400ee}},	//   _італ, دىيس, нниз, эмиз, 
   {{0x644c0552,0x7d04009b,0xea14010f,0x00000000}},	//   žbin, nihs, _אַבי_, --, 
   {{0xc2080302,0x25a445a7,0x128801b9,0x3eb81368}},	//   _פה_, _epol_, ومدی_, _oast_, 
   {{0x7af8e16d,0x6d5802b5,0x3eb8e16e,0xf67400df}},	//   _çatı, _ōtam, _nast_, _װײַט_, 
   {{0x35a4e16f,0xb5fc0784,0x056400c0,0x00000000}},	//   _чалг, pašq, _авін, --, 
   {{0x3eb801f5,0xb5fc02d1,0x8cc400bc,0x645c000d}},	//   _aast_, qašq, राछो, _õpip, 
   {{0x9fc4036b,0x7d040066,0x2a640072,0x7520002f}},	//   нгра_, dihs, ybob_, molz, 
   {{0x6ee803c6,0x7520011c,0xceb400ac,0x3eb826e7}},	//   _výbo, lolz, tləq_, _cast_, 
   {{0x3eb8e170,0x7204029e,0x3f54007c,0x290c03cb}},	// [134a0] _dast_, _سودم, _eåu_, ynfa_, 
   {{0xdd8c7cf9,0x3eb8e171,0xdfd001e1,0x799c0042}},	//   صوم_, _east_, _lèṣù_, _âswy, 
   {{0x3eb8e172,0xc1002e51,0xe29c0008,0xdb04007c}},	//   _fast_, _түрл, liða_, _osjä, 
   {{0x3eb8e173,0x75200b70,0xb5fc03f0,0xef18e174}},	//   _gast_, holz, yašp, _хмм_, 
   {{0xda60006c,0xdbe001e1,0xa8a001ec,0xf95800e5}},	//   увчи, _léèm, лғақ, وسوں_, 
   {{0x290c09c2,0x6d540399,0x3eb802f0,0x00000000}},	//   unfa_, mqya, _zast_, --, 
   {{0x25a46075,0x09d811ba,0xb5fc0784,0x75200010}},	//   _spol_, _দেখা, wašp, dolz, 
   {{0xfd4c001e,0x6a6401d5,0xb5fc0784,0x3b0400c7}},	//   _nghị, _سطرل, tašp, _иҵхо_, 
   {{0xe8f86ac1,0x9f44143a,0xd6d000d1,0x00000000}},	//   _ела_, _ånå_, اتىغ, --, 
   {{0xfd4c063f,0xb5fc02d1,0x9f40036e,0x00000000}},	//   _aghị, rašp, tyjë_, --, 
   {{0x833400d8,0x00000000,0x00000000,0x00000000}},	//   кнох, --, --, --, 
   {{0xb5fc0309,0x7bc0013a,0x798c01e1,0xaac46b26}},	//   pašp, _šluk, _únwí, _रोमक, 
   {{0x3eb8e175,0xb5fc0309,0x7520002f,0xb3a8008e}},	//   _rast_, qašp, bolz, _çını, 
   {{0x75200137,0x3eb8e176,0x5914025c,0xe9cca1a1}},	//   colz, _sast_, ློགས_, ркi_, 
   {{0x3eb80c3e,0xc61c00cc,0xd0181606,0x5454011a}},	//   _past_, দেখা_, ефт_, _אסון_, 
   {{0x3eb80200,0x00000000,0x00000000,0x00000000}},	//   _qast_, --, --, --, 
   {{0x7d240d28,0x6d540007,0x3eb80e21,0x64580051}},	// [134b0] نفرن, gqya, _vast_, octi, 
   {{0x3eb80c3a,0x4c940022,0xfa5401d5,0x00000000}},	//   _wast_, лиус, چرشگ, --, 
   {{0x3eb806d4,0xc98404a9,0x6458e177,0x7d04e178}},	//   _tast_, ғучи, icti, rihs, 
   {{0xbf100b65,0xdbe000e8,0x291004fb,0xf99000ae}},	//   _түбә, _jéém, éyan_, لبت_, 
   {{0x75200083,0x660406ea,0x00000000,0x00000000}},	//   yolz, úkkl, --, --, 
   {{0x6458070d,0xb7880166,0x37d800cc,0x00000000}},	//   jcti, дәде_, _ভেগৰ, --, 
   {{0xbb440022,0xeff01ee0,0xc86400d8,0x69c402d2}},	//   _афақ, _ፍቃድ_, утчи, _áken, 
   {{0x6458e179,0x668001d5,0x97a4009d,0x00000000}},	//   ecti, لیمل, _үржл, --, 
   {{0x940800ac,0xc984e17a,0x00000000,0x00000000}},	//   əcə_, _бухи, --, --, 
   {{0x6d580374,0x00000000,0x00000000,0x00000000}},	//   _ōtak, --, --, --, 
   {{0x92bc0183,0x7520005a,0xe794030f,0xdfd001e1}},	//   _আকৌ_, rolz, _لانک, _tèṣù_, 
   {{0xe1fcb9f0,0x3374004e,0x00000000,0x00000000}},	//   rbón_, нгүр, --, --, 
   {{0xdbe00036,0x6b580055,0x00000000,0x00000000}},	//   _déém, _mįga, --, --, 
   {{0x7c34003e,0x64580113,0xe1fc01ed,0x00000000}},	//   _ozzr, ccti, mból_, --, 
   {{0xe1fc01d3,0x00000000,0x00000000,0x00000000}},	//   lból_, --, --, --, 
   {{0x24140375,0x73340137,0xe1fc01e7,0x00000000}},	//   _שחקן_, _جىعا, oból_, --, 
   {{0x6d540399,0x7c3403ac,0x51440116,0xf1d001e0}},	// [134c0] uqya, _azzr, _йдиғ, _төнө, 
   {{0xe1fc00e5,0x00000000,0x00000000,0x00000000}},	//   iból_, --, --, --, 
   {{0xa4f80003,0x2078010f,0x00000000,0x00000000}},	//   ྒྲིག_, _קאטא, --, --, 
   {{0xe1fc00dd,0xed580022,0xbad402d5,0x00000000}},	//   kból_, _оом_, лічы, --, 
   {{0xd994e17b,0x0dc80032,0xe1fc00e5,0x3ec4014b}},	//   نخوا_, _яһай_, jból_, _сияҳ, 
   {{0xefd400b7,0xc87805d1,0xe1fc01d3,0x00000000}},	//   _ካርድ_, _boğa_, dból_, --, 
   {{0xd7f41171,0x769401e1,0x00000000,0x00000000}},	//   куъ_, _ẹyaw, --, --, 
   {{0xc878247e,0x85b8e17c,0x69b803ce,0xd7e0003b}},	//   _doğa_, елис_, _एनपी, рішо, 
   {{0x6aa0016b,0xe1fc01ed,0x1ae0151e,0xe94401ec}},	//   mfof, gból_, _тотм, _ٴناپ, 
   {{0x6458010a,0x69c00549,0xa3bc0037,0xb1380092}},	//   ucti, mvoe, ँटल_, _በቅዱሳ, 
   {{0x6458e17d,0x69c05b5e,0xeff001f3,0xb3a80139}},	//   rcti, lvoe, _ፍቃዱ_, _çılı, 
   {{0x6aa0031c,0x5b7800d9,0x00000000,0x00000000}},	//   nfof, ורטא, --, --, 
   {{0x69c0bdd0,0x00000000,0x00000000,0x00000000}},	//   nvoe, --, --, --, 
   {{0x557404ac,0x6560e17e,0xb4b43c1a,0x814400f2}},	//   _יעדן_, _itoh, _бишә, طنزن, 
   {{0x13b02781,0xd1300014,0xd3d401c8,0x00000000}},	//   _نصيح, زمِ_, _لبيا_, --, 
   {{0x69c01a7c,0x93240014,0xdd9001e0,0x7bc00332}},	//   kvoe, _پر٘ن, һағы, _álui, 
   {{0x8d7408c9,0x69c00d27,0x6000022e,0x6aa0003e}},	// [134d0] لالا, jvoe, _dеma, dfof, 
   {{0xdd90e17f,0x69c00b4f,0x00000000,0x00000000}},	//   лағы, dvoe, --, --, 
   {{0x6aa00b45,0x69c00d47,0x1ae00032,0xe1fc00e5}},	//   ffof, evoe, ғоҙм, zból_, 
   {{0x3f90e180,0x69c0257d,0x6560a8e2,0xdcec1b0d}},	//   muzu_, fvoe, _otoh, ğdır, 
   {{0xdcec0cc1,0x69c00660,0xaee002dd,0x69c403b2}},	//   şdır, gvoe, _اۋقى, _ákel, 
   {{0x5884e181,0x62800129,0xc984011c,0x00000000}},	//   тыда, _œnol, руци, --, 
   {{0xded0044e,0x3f900259,0x6560e182,0x27380023}},	//   _የሎን_, nuzu_, _atoh, kënd_, 
   {{0xe1fc01ed,0x6d5800b0,0x69c00549,0xdb200244}},	//   tból_, _ōtai, bvoe, _ئوری, 
   {{0x3f900107,0x59a4012c,0x7dec01a9,0x00000000}},	//   huzu_, _गहिर, _qўsh, --, 
   {{0x3f90003e,0x89380276,0xe1fce183,0x8508010b}},	//   kuzu_, _апус_, rból_, кдың_, 
   {{0x65600270,0xe1fc01ed,0x3f90e184,0x27380036}},	//   _etoh, sból_, juzu_, fënd_, 
   {{0x656002d3,0x3f909e90,0x1cb0025c,0xd1840131}},	//   _ftoh, duzu_, _དྲལ_, аһий, 
   {{0xdbe400bd,0x21a00104,0x00000000,0x00000000}},	//   _গেমস_, биям, --, --, 
   {{0x3f90e185,0xa2d001ec,0x00000000,0x00000000}},	//   fuzu_, _ۇيىت, --, --, 
   {{0x442418a2,0x3f9005f5,0x3438008f,0x656002f0}},	//   _پروف, guzu_, _אײַע, _ztoh, 
   {{0x69c401a6,0x2d94e186,0x69c0e187,0xe294014b}},	//   _škem, лөгө_, yvoe, _баъ_, 
   {{0xc1d47b80,0xacc801ee,0xe6f80327,0xed3401c6}},	// [134e0] _көрә, нгаз_, ནལྷན_, гэжэ, 
   {{0x69b80034,0xdb040b21,0x59c407f7,0x69c003cd}},	//   _एनबी, _tsjû, लिनर, vvoe, 
   {{0xafe407d6,0x69c001a4,0xea8811f7,0xdca000c7}},	//   _сонл, wvoe, ебел_, сахи, 
   {{0x69c01aa7,0xeff40092,0xaab8e188,0x00000000}},	//   tvoe, ወነው_, عدار_, --, 
   {{0x6ee808a5,0x7d240162,0x00000000,0x00000000}},	//   _nýbi, útsø, --, --, 
   {{0x69c03441,0x2d90e189,0x6d5800b0,0x1cb0031c}},	//   rvoe, muye_, _ōtaw, _དིར_, 
   {{0x6d4c0656,0x69c02a28,0x2d90e18a,0x3a2c017a}},	//   _iiba, svoe, luye_, _eyep_, 
   {{0x6d4ce18b,0x69c0057b,0x473406ed,0xe9740214}},	//   _hiba, pvoe, јнис, _مهرد, 
   {{0x2d90e18c,0x6b80063f,0x44f4e18d,0x42542304}},	//   nuye_, _ọghe, ипис, یندر, 
   {{0x6d4ce18e,0x27380036,0x00000000,0x00000000}},	//   _jiba, wënd_, --, --, 
   {{0x6d4ce18f,0x1cb00d46,0x2d90015c,0x69b82122}},	//   _miba, _དིལ_, huye_, _एनडी, 
   {{0x6d4ce190,0x2d90e191,0x3f90083c,0x273800e8}},	//   _liba, kuye_, vuzu_, fëne_, 
   {{0x3f900526,0x6d4cbdc2,0x27380036,0x59c404aa}},	//   wuzu_, _oiba, rënd_, लियर, 
   {{0x6d4ce192,0x3f9001c0,0x1ee41079,0x2d90e193}},	//   _niba, tuzu_, گوری_, duye_, 
   {{0x39480268,0xa3b8106b,0x24a00153,0xdec80108}},	//   ìasi_, _ساغر_, ėsmę_, нуал_, 
   {{0x2d9001b2,0x6d4ce194,0xe1fc022c,0x3f90e195}},	//   fuye_, _aiba, nbók_, ruzu_, 
   {{0x6d4c3dd4,0x2d900516,0x3c58084c,0x3f9004ce}},	// [134f0] _biba, guye_, визэ_, suzu_, 
   {{0x6d4ce196,0x3f9007a8,0xc0c40131,0x00000000}},	//   _ciba, puzu_, _тәми, --, 
   {{0x6d4ce197,0x2d900810,0xba5406ed,0x628000ef}},	//   _diba, auye_, авеј, _ēnoj, 
   {{0x6d4c05f5,0x3f80006f,0xcb6805af,0x3d94013d}},	//   _eiba, _ivhu_, امنه_, _кимр, 
   {{0x7e6ce198,0x6d4c28c0,0x2d900223,0x00000000}},	//   mbap, _fiba, cuye_, --, 
   {{0x6d4ce199,0xa8840aeb,0x79c800f1,0xaa4c0023}},	//   _giba, айша_, _یوزف_, _ንአምላ, 
   {{0xf65000c6,0xc9840aac,0xad1808a8,0xb8fc00cd}},	//   يئة_, _қути, _יושר, _तच_, 
   {{0x7e6c138f,0xe1fc0ad9,0xd5e800e4,0xb5fc00d7}},	//   nbap, gbók_, _neg̃, lbši, 
   {{0xe57403a5,0x6d4c5936,0x29cc0321,0xa810013d}},	//   азы_, _yiba, rðað_, йдәш, 
   {{0xb3a80365,0x6d4ce19a,0xe1fc011f,0x9f40013a}},	//   _çıkı, _xiba, mbóh_, dyjí_, 
   {{0x2d900516,0xb4e40490,0x80d800dc,0xc8640408}},	//   zuye_, _नवी_, माने, _ытти, 
   {{0xb6c800f8,0x2d9001b2,0x7bc40099,0x88c40055}},	//   _جائے_, yuye_, ivhu, _āśit, 
   {{0x95643993,0x85c401e2,0x00000000,0x00000000}},	//   _съед, _هغوم, --, --, 
   {{0x2d90d765,0xc5f4329e,0x21640408,0x00000000}},	//   vuye_, _ығы_, рири_, --, 
   {{0x6000022e,0x1cb0031c,0x2d90e19b,0x7af80175}},	//   _dеmo, _དྲེ_, wuye_, khwt, 
   {{0x2d90e19c,0x92b40132,0x6bd40424,0xb064007c}},	//   tuye_, _اڭدا, یتار, _blää, 
   {{0xbc2404a9,0x3f800099,0xeb98084c,0x6d4ce19d}},	// [13500] ەرنى, _evhu_, ӂие_, _piba, 
   {{0x2d90015c,0xdd8c007b,0x6d4c0139,0xf8a400f2}},	//   ruye_, بوك_, _qiba, _عک_, 
   {{0xeb984945,0x2d90e19e,0x6d4ce19f,0xef184258}},	//   тие_, suye_, _viba, _амн_, 
   {{0x6d4ce1a0,0xa9686426,0x2d900161,0x29887136}},	//   _wiba, вида_, puye_, вско_, 
   {{0x6f14772f,0x00000000,0x00000000,0x00000000}},	//   mnyc, --, --, --, 
   {{0x6f1490d6,0x6d4c0810,0xd1f80092,0xdc640798}},	//   lnyc, _uiba, _ላፍቶ_, _вард_, 
   {{0x1d04bd1c,0x6f14033f,0x9d14004e,0x00000000}},	//   _тери_, onyc, _тоёт_, --, 
   {{0x6f14e1a1,0xb5fc010e,0xceb403e3,0x00000000}},	//   nnyc, lašy, neə_, --, 
   {{0xd5e800e4,0xe1fc0d12,0x95d40395,0x2f280064}},	//   _reg̃, rbók_, идът_, mėgę_, 
   {{0x44f4b076,0xe1fc148b,0x237c0413,0x3a08141d}},	//   спос, sbók_, tstj_, _حکمی_, 
   {{0x44381347,0xb864e1a2,0x6f149e11,0x42540345}},	//   år_, _طالو, knyc, ینگر, 
   {{0xe5a40b16,0x6f14068f,0x3f842833,0xe5c4023a}},	//   _види, jnyc, álum_, _вско, 
   {{0x6f14772b,0x38740022,0x272007af,0x00000000}},	//   dnyc, _ñarõ_, मवीर_, --, 
   {{0xddcc0276,0x00000000,0x00000000,0x00000000}},	//   _lecţ, --, --, --, 
   {{0xc0c40116,0x40345211,0xdb2000e8,0x228401a9}},	//   _һәви, севс, ërën, _купг, 
   {{0xc2980414,0xb06401f4,0x00000000,0x00000000}},	//   _ских_, _plää, --, --, 
   {{0x225c0113,0x6ee8032e,0x628000ef,0x00000000}},	// [13510] ñuku_, _nýbu, _ēnoh, --, 
   {{0x6d8800dd,0x38bc0022,0x6f14033f,0xdbc40815}},	//   املہ_, _márõ_, anyc, ищеп, 
   {{0x6f14068f,0x814400b2,0xe1fc00e5,0xba5400ae}},	//   bnyc, _پنھن, lzó_, مناع, 
   {{0x6ee803b2,0x6f14e1a3,0x7bc405ac,0x9a8401d5}},	//   _býbu, cnyc, rvhu, ружл, 
   {{0xe1fce1a4,0x8d84408a,0xdde80fb4,0x00000000}},	//   nzó_, _мурд, _شرحه_, --, 
   {{0xb4e40574,0x9f5c01e1,0x00000000,0x00000000}},	//   _नवे_, _èrón_, --, --, 
   {{0xda78e1a5,0xcd340133,0xc8780205,0xd0f8011a}},	//   _аяз_, _گرێب, _değ_, שמות_, 
   {{0x386801e4,0xbf000139,0x00000000,0x00000000}},	//   ŝar_, _çíın, --, --, 
   {{0x87041053,0x00000000,0x00000000,0x00000000}},	//   تبول, --, --, --, 
   {{0x6f143f8e,0xf50469a4,0x58b8a822,0xd808014b}},	//   znyc, ёзно, _جارج_, _ихел_, 
   {{0x347400fb,0x00000000,0x00000000,0x00000000}},	//   _һѳйѳ, --, --, --, 
   {{0x8a149105,0xe2940064,0x00000000,0x00000000}},	//   _اظہا, баю_, --, --, 
   {{0xe294e1a6,0x6f1401f1,0x21a0068e,0xe1fc00e5}},	//   щая_, vnyc, пиям, gzó_, 
   {{0x6f14068f,0xf1a800aa,0x69b825c9,0x273800e8}},	//   wnyc, پاڼه_, _एनसी, mëna_, 
   {{0x339419f9,0x6f14773c,0xa064c783,0x6d9c0166}},	//   _العز, tnyc, саса_, _oçaç, 
   {{0x8364e1a7,0x855401b9,0x00000000,0x00000000}},	//   _بدول, _دییر_, --, --, 
   {{0xee38e1a8,0xac84e1a9,0x6f14773c,0x00000000}},	// [13520] уна_, йгал, rnyc, --, 
   {{0xddcc084c,0xd064013f,0xa2580120,0x6f14489d}},	//   _secţ, _ɑsɛn, ndôn, snyc, 
   {{0xb5fc0953,0x7c645f2e,0xafc40137,0xe478008f}},	//   rašy, تاقل, _ايجى, ררעכ, 
   {{0xaf346676,0x29600022,0x00000000,0x00000000}},	//   _درخت, зҭаҭ, --, --, 
   {{0xed3405f5,0x085402bf,0x9f5c0248,0x99840205}},	//   _гэвэ, овлю, _èròn_, ğişi_, 
   {{0x6ee80122,0x25f407f7,0xaca401d3,0xad241e4a}},	//   _výbu, एनसी_, _دھرے_, _چىڭى, 
   {{0x1cb01b4b,0xad2401ec,0xfb5800f3,0x00000000}},	//   _དྲི_, _نىڭى, _врућ_, --, 
   {{0xab2810f3,0x9c14011a,0xe1fc01d3,0x88c40055}},	//   _соба_, _החלק_, yzó_, _āśut, 
   {{0x2b4405c7,0x273800e8,0x6adc00cc,0x00000000}},	//   mmoc_, gëna_, _মতপো, --, 
   {{0xe29c0ad9,0xbb7000db,0x00000000,0x00000000}},	//   miði_, _رۇۇع, --, --, 
   {{0xe29c0321,0xa6a800db,0xc0d40092,0x00000000}},	//   liði_, _ماشق_, _የሮማ_, --, 
   {{0x290ce1aa,0xe61802bf,0x3f840cf4,0xe1fc00cf}},	//   lifa_, _йде_, šluk_, tzó_, 
   {{0x387c0139,0xe4e400c0,0x00000000,0x00000000}},	//   _öyrä_, _гійн, --, --, 
   {{0xe3b000c6,0x2b440030,0x048800c7,0xe1fc9411}},	//   _فرع_, ňoch_, _тәии_, rzó_, 
   {{0xff2800c6,0xe1fc58a5,0x2b4400e4,0x00000000}},	//   لكسي_, szó_, kmoc_, --, 
   {{0x8c0039db,0x290c006c,0x00000000,0x00000000}},	//   ্থান_, hifa_, --, --, 
   {{0x290ce1ab,0x931401d9,0x707802d3,0x6d5800b0}},	// [13530] kifa_, _روٝش, ጥቀመሉ_, _ōtar, 
   {{0x40942be7,0x290c05da,0x59c402ab,0x9c44010b}},	//   _بلدر, jifa_, लिसर, бхел, 
   {{0x61ece1ac,0xe29c03b2,0x290c025c,0x27380200}},	//   lycl, eiði_, difa_, zëna_, 
   {{0x53980302,0x443c0306,0xe29c08a5,0x00000000}},	//   ריאו, _mzv_, fiði_, --, 
   {{0x443c01f5,0xe1fc0210,0x9a8401a9,0xe29c032e}},	//   _lzv_, rbów_, _қувл, giði_, 
   {{0xf8b01d0a,0x443c01ef,0x00000000,0x00000000}},	//   بکر_, _ozv_, --, --, 
   {{0xf744e1ad,0x3dc8025c,0x487801ca,0x00000000}},	//   оеко, lvaw_, ссія_, --, 
   {{0x59281e81,0x27380240,0xd5e001b9,0x6d9c0139}},	//   _སེམས_, tëna_, зйиқ, _uçaç, 
   {{0x3ea800a9,0x290c04ba,0x443c0208,0x98a40210}},	//   ifat_, bifa_, _azv_, elną_, 
   {{0x290ce1ae,0xb38401c0,0xa25800d8,0xf5040212}},	//   cifa_, олол, udôn, ізно, 
   {{0x63b80369,0x443c00f3,0xe3b005d9,0x3ea8007c}},	//   gwtn, _czv_, ورٽ_, kfat_, 
   {{0x61ec0cea,0x1b0400eb,0x00000000,0x00000000}},	//   fycl, ষককে_, --, --, 
   {{0xb5c80bce,0x98a4033f,0x61ec02d0,0x2738036e}},	//   _خوشم_, alną_, gycl, qëna_, 
   {{0x3ea80393,0x6ee8e1af,0x00000000,0x00000000}},	//   efat_, _nýbr, --, --, 
   {{0x3ea8e1b0,0xc4c40133,0xae7808db,0x6fb4009a}},	//   ffat_, _رتوو, исах_, غمرا, 
   {{0x290ce1b1,0x6e9401d5,0x61ec002f,0x00000000}},	//   zifa_, تلرا, bycl, --, 
   {{0xec78189d,0x61ece1b2,0x290c88da,0x443c0427}},	// [13540] ипа_, cycl, yifa_, _zzv_, 
   {{0x9d400046,0x2ef00ea0,0xac840816,0x290c01a9}},	//   деуд, skyf_, ігел, xifa_, 
   {{0xdcac0131,0x60d4008f,0xab643cc5,0x7c6414fb}},	//   ئىم_, _וויא_, цвел, سالل, 
   {{0x290c014b,0xa2580030,0x6e98010b,0x26180208}},	//   wifa_, jdôl, _өвүр_, ừoi_, 
   {{0x6924e1b3,0x290ce1b4,0x00000000,0x00000000}},	//   омда, tifa_, --, --, 
   {{0x58d0e1b5,0xe29c0008,0x00000000,0x00000000}},	//   дошт, riði_, --, --, 
   {{0x290ce1b6,0x00000000,0x00000000,0x00000000}},	//   rifa_, --, --, --, 
   {{0x78ac05ce,0x65a80063,0xaadc1df0,0x00000000}},	//   đava, атог_, _नचिक, --, 
   {{0x26c001a2,0x00000000,0x00000000,0x00000000}},	//   ľko_, --, --, --, 
   {{0x26c03831,0x32000030,0x6fc805c0,0x00000000}},	//   žko_, dzky_, ाटां, --, 
   {{0x5c58010f,0x00000000,0x00000000,0x00000000}},	//   ידיק, --, --, --, 
   {{0x2d9007ab,0xb9e4001f,0x443c02f0,0x61ece1b7}},	//   krye_, _የተ_, _vzv_, tycl, 
   {{0x45d4e1b8,0x443c0208,0xe0d00633,0x00000000}},	//   _холс, _wzv_, وزس_, --, 
   {{0x443c9fca,0x3f90033f,0xb5fc0153,0x00000000}},	//   _tzv_, trzu_, rbšt, --, 
   {{0x3f84e1b9,0x443c3a4a,0x61ec03ac,0x00000000}},	//   élu_, _uzv_, sycl, --, 
   {{0x1cb00135,0x3ea80010,0x75800244,0x00000000}},	//   _དིང_, ufat_, _تییم, --, 
   {{0x3ea829ef,0xa258b4a2,0x69b83d1d,0x57b400af}},	// [13550] rfat_, ndôm, _शैली, _आन्ह, 
   {{0xa2a42e2a,0x3dc80135,0x3f900210,0xddc400e5}},	//   ट्र्, rvaw_, przu_, ülőd, 
   {{0xb3a805d1,0x3ea8020c,0x6ee802f0,0xf4280108}},	//   _çıtı, pfat_, _výbr, meää_, 
   {{0x68f8e1ba,0x05bc000d,0x273804e6,0x40942e0b}},	//   _altd, ्टाब, wënn_, _بلگر, 
   {{0x7e7c11f9,0xdb0402d2,0x00000000,0x00000000}},	//   _iesp, _ssjó, --, --, 
   {{0x91bc0302,0x7e7ce1bb,0x2c4401ed,0xfaa80451}},	//   ימדי, _hesp, _کیمپ_, _گهري_, 
   {{0x2000ce37,0x9a843461,0xf7704c02,0x47580953}},	//   nzji_, _муал, راث_, орыя_, 
   {{0x7e7ce1bc,0x6b9805ac,0x68f848a2,0x27380036}},	//   _jesp, _åtga, _eltd, sënn_, 
   {{0x7e7ce1bd,0x3b0c0869,0x7ae803ac,0xf4280108}},	//   _mesp, _imeq_, _ioet, keää_, 
   {{0x7e7c159f,0x9f40005b,0x00000000,0x00000000}},	//   _lesp, lyjä_, --, --, 
   {{0x7ae8e1be,0x7e7c017a,0x61380311,0x79980083}},	//   _koet, _oesp, tîln, luww, 
   {{0x3200e1bf,0x7ae8e1c0,0xfa28025c,0xe2941d0b}},	//   tzky_, _joet, _སྙོན_, паю_, 
   {{0x7ae8e1c1,0x79980548,0x26c8013f,0x070812d3}},	//   _moet, nuww, ɛbo_, _بيني_, 
   {{0xa064e1c2,0x2d90e1c3,0x7ae8e1c4,0xafe40dce}},	//   зара_, vrye_, _loet, погл, 
   {{0x7e7ce1c5,0x79982a1f,0x3200e1c6,0xf6b8031c}},	//   _besp, huww, szky_, _དྲོང, 
   {{0x7ae8e1c7,0x232402e8,0x9f40005b,0x2d90e1c8}},	//   _noet, _нощи_, jyjä_, trye_, 
   {{0x7e7ce1c9,0xaac4012c,0xe29c02d2,0x00000000}},	// [13560] _desp, _रोगक, giðu_, --, 
   {{0xdd8cc998,0x3b0c013c,0x79980429,0x7e7c00c5}},	//   اول_, _ameq_, duww, _eesp, 
   {{0x7ae8e1ca,0x7e7c0230,0x799801a4,0x76580042}},	//   _boet, _fesp, euww, _ogwy, 
   {{0x7e7c78fb,0x7ae8e1cb,0x2d908cf6,0x39bc007f}},	//   _gesp, _coet, prye_, _bňs_, 
   {{0x638000dd,0x7ae8e1cc,0x00000000,0x00000000}},	//   _kíná, _doet, --, --, 
   {{0x7e7c068f,0x78a00393,0x600001a9,0x00000000}},	//   _zesp, _cclv, _sеmi, --, 
   {{0x98a00640,0x63800332,0x9d407f5f,0x00000000}},	//   хије, _míná, _черд, --, 
   {{0x7ae8e1cd,0x45d4e1ce,0x79980ac5,0x39bc02e2}},	//   _goet, доис, buww, _fňs_, 
   {{0x68400332,0x20000135,0x00000000,0x00000000}},	//   _bídí, zzji_, --, --, 
   {{0xb864e1cf,0x7ae8e1d0,0x291c0784,0x76580368}},	//   _قامو, _zoet, _ujta_, _egwy, 
   {{0x600001a9,0x3ce40150,0xf42801f4,0x00000000}},	//   _tеmi, _ﺍﻷﺯﻤ, veää_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x26c40093,0x68400241,0xd244084c,0x69c0547d}},	//   _iaoo_, _fídí, еэри, लिटी, 
   {{0x7e7c0c86,0x26c4009f,0x4394030c,0x98a402e2}},	//   _sesp, _haoo_, _жакс, yonč_, 
   {{0x7e7ce1d1,0x638001e1,0xf42801f4,0x9f4001f4}},	//   _pesp, _díná, reää_, yyjä_, 
   {{0x53980302,0x7e7c03f0,0xf8b82c97,0x2000031c}},	//   _היהו, _qesp, _इस्प, rzji_, 
   {{0x26c4089c,0x7ae80660,0x9f40023a,0x79980429}},	// [13570] _maoo_, _roet, vyjä_, xuww, 
   {{0x7ae8e1d2,0x26c41132,0x8d7400f7,0xe29c03f2}},	//   _soet, _laoo_, عاقا, riðu_, 
   {{0x7e7ce1d3,0x26c40093,0x39bc007f,0x9f40005b}},	//   _tesp, _oaoo_, _sňs_, tyjä_, 
   {{0xfa28025c,0x7e7ce1d4,0x7c3402fb,0x39bc0100}},	//   _སྙུན_, _uesp, _vyzr, _pňs_, 
   {{0x7ae81aa7,0x7294044e,0x7998022f,0x69c40010}},	//   _voet, _ቁጠባዊ_, uuww, _šker, 
   {{0x26c40421,0x2cb800d2,0x78ac009b,0x9f40005b}},	//   _aaoo_, cepd_, đavo, syjä_, 
   {{0x7ae8e1d5,0xb8741682,0xec1836e1,0xf6b8031c}},	//   _toet, _nṋe, _дерә_, _དྲུང, 
   {{0x8aa414a3,0xdb04005c,0xdbd4005b,0x00000000}},	//   _пруд, _spjæ, rääv, --, 
   {{0xdbd4005b,0x754406ed,0x38c82418,0x74b802e8}},	//   sääv, мниз, _وائی_, оунс_, 
   {{0x7988035a,0x09b80327,0xe61401ec,0x054400c7}},	//   _ivew, _མགྷ_, ьды_, ндыҟ, 
   {{0x673801a8,0xa5200166,0x00000000,0x00000000}},	//   ðbjö, тмэд, --, --, 
   {{0xc87803ee,0xe29c0008,0x52b805d7,0x638006ea}},	//   _doğu_, ggð_, इजेस, _síná, 
   {{0xe60ce1d6,0x00000000,0x00000000,0x00000000}},	//   _рд_, --, --, --, 
   {{0x836401d5,0x00000000,0x00000000,0x00000000}},	//   بدیل, --, --, --, 
   {{0x225c01fa,0xb9d802d3,0x00000000,0x00000000}},	//   žuka_, _በጃ_, --, --, 
   {{0x98bc0003,0x3944003b,0x798802d0,0xe8d800cd}},	//   _ftuħ_, _lhls_, _ovew, _यच्च, 
   {{0xece8e1d7,0xe1fcb9f0,0x31241b88,0x1b1003d4}},	// [13580] одал_, lcón_, _одиг, িকাই_, 
   {{0xeb9801c6,0x1cb00327,0x25b00139,0x00000000}},	//   жиж_, _དྲད_, _äyle_, --, 
   {{0xe1fcdb52,0x79880857,0xdca00117,0xee78072d}},	//   ncón_, _avew, тахи, _وصحت_, 
   {{0x2d9418d9,0x00000000,0x00000000,0x00000000}},	//   _оргс, --, --, --, 
   {{0x3178010f,0xcfc005ac,0x00000000,0x00000000}},	//   קאַד, _উপিন, --, --, 
   {{0x26c40472,0x61e801c3,0x7c3800e4,0x582c0248}},	//   _saoo_, _àgle, ñarõ, _ṣiṣi, 
   {{0xdca0d3a5,0x7988035a,0x5ca04964,0x00000000}},	//   _шари, _evew, _ширб, --, 
   {{0x442016a3,0x6af802dd,0xcfc00154,0x1ef8010f}},	//   _ći_, _بىرس_, _উপান, ַליע, 
   {{0xd6e400aa,0x26c40093,0x2a3401c6,0xa5c40174}},	//   بډله_, _vaoo_, _цэвр, dróð, 
   {{0x1cb00327,0x26c401bf,0xd5443cc6,0x00000000}},	//   _དིབ_, _waoo_, وليو_, --, 
   {{0x26c40270,0x79880810,0xe738009b,0xa5c408ce}},	//   _taoo_, _zvew, _деж_, fróð, 
   {{0x1cb06d7e,0x3ce401ec,0xa5c409e8,0x00000000}},	//   _དྲན_, _ﺍﻷﺤﻤ, gróð, --, 
   {{0x55701fe2,0xded002d3,0x67200124,0x98a400e2}},	//   _агіт, _ከሎኻ_, _ijoj, lonā_, 
   {{0x98a400bc,0x0458007b,0x00000000,0x00000000}},	//   dlně_, _علبة_, --, --, 
   {{0x2324005b,0x9374007b,0xa5c409e8,0x98a4013a}},	//   _офиг, _قصير_, bróð, elně_, 
   {{0xaf540184,0xceb80640,0x9344033a,0x00000000}},	//   енсә, мљу_, _инје, --, 
   {{0x67200161,0x3cd4e1d8,0x5ec00075,0x5bc4033f}},	// [13590] _mjoj, нжас, ниңғ, रट्व, 
   {{0x4d980108,0x00000000,0x00000000,0x00000000}},	//   ькую_, --, --, --, 
   {{0x6720e1d9,0x5ba40588,0x4ba800f7,0x98a400e2}},	//   _ojoj, ьраз, мөтү_, jonā_, 
   {{0x11d40046,0x6e28003e,0xd1b800d1,0xdeb001ec}},	//   _ستۋد, émbé, _راۋا_, _шұбы, 
   {{0x7f4ce1da,0x3934239a,0x68280023,0x00000000}},	//   mmaq, нэкс, _ድሕረት, --, 
   {{0x7f4c00ac,0xdb040267,0x2ac40153,0x6720e1db}},	//   lmaq, _spjä, _rūbų_, _ajoj, 
   {{0x0b88036b,0xabb40166,0x661401a8,0x1aa400f3}},	//   _ости_, _парә, _þykj, _ојаг, 
   {{0x0c0401d9,0xe7b0a3a9,0x7f4ce1dc,0xb5c4004e}},	//   _شوقُ, اميد, nmaq, ейил, 
   {{0x67203743,0x1ddc00dc,0x2f18008e,0x00000000}},	//   _djoj, नमित, lügä_, --, 
   {{0x67200115,0x7f4c0113,0xcfc000cc,0x98a400ef}},	//   _ejoj, hmaq, _উপসন, bonā_, 
   {{0xbb50019b,0x36d411e5,0xc0d801ec,0xc6100154}},	//   _gooメ_, _пожр, _ﺀﺗﯘﺳ, _হুদা_, 
   {{0xe1fc21fc,0x67200023,0x1ddc102f,0x00000000}},	//   rcón_, _gjoj, नमात, --, 
   {{0xe1fc2815,0xdbd41577,0xa5c40174,0xc4c400e5}},	//   scón_, _häär, rróð, رتیو, 
   {{0xdbd433eb,0x00000000,0x00000000,0x00000000}},	//   _käär, --, --, --, 
   {{0xdbd43110,0x846402e8,0xe1fc0332,0xa2c827a6}},	//   _jäär, _ръче, lcól_, _तोक्, 
   {{0xdbd42053,0x7f4c0357,0xa3bce1dd,0x128804fb}},	//   _määr, gmaq, ुटर_, _کمکی_, 
   {{0x1168e1de,0x98a4005f,0x51440116,0xe45000c7}},	// [135a0] _تلخی_, zonā_, _идиғ, _икәы, 
   {{0xed340139,0xceb8008e,0x00000000,0x00000000}},	//   хэбэ, чәү_, --, --, 
   {{0xdbd4000d,0x207800df,0x2f180139,0x00000000}},	//   _näär, _מאיא, gügä_, --, 
   {{0xed58e1df,0x98a400bc,0x00000000,0x00000000}},	//   _ном_, plně_, --, --, 
   {{0x3eac0086,0xed5801c0,0xceb40213,0x6f14e1e0}},	//   _öeta_, _хог_, nnəm_, miyc, 
   {{0x77600067,0x98a400de,0xde0001d5,0x27380200}},	//   _bulx, tonā_, _ёпри, mëni_, 
   {{0xbc1801ec,0x27f80174,0x1d0400d8,0x00000000}},	//   _жіті_, ápn_, _џеси_, --, 
   {{0xa6a800c6,0x779004fb,0x661401a8,0x6f140205}},	//   سابق_, شیها, _þykk, niyc, 
   {{0xa92401ce,0x69b83885,0x201c0022,0x00000000}},	//   _здал, _एनटी, ̃ui_, --, 
   {{0xdb04000f,0x03f8026a,0xdbd40254,0x7f4c0213}},	//   _opjû, дној_, _fäär, zmaq, 
   {{0xb864e1e1,0x6f140309,0x776001d5,0x69c0045f}},	//   _شالو, kiyc, _gulx, lwoe, 
   {{0x6aa0e1e2,0x6720e1e3,0x00000000,0x00000000}},	//   ngof, _ujoj, --, --, 
   {{0x6aa00607,0x168403e6,0x7760022e,0x00000000}},	//   igof, _سانێ, _zulx, --, 
   {{0xa25800d7,0x00000000,0x00000000,0x00000000}},	//   jdôv, --, --, --, 
   {{0x6560e1e4,0x6aa000fb,0x7f4c00ac,0x403406ed}},	//   _huoh, kgof, tmaq, тевс, 
   {{0x6560e1e5,0x69c002c4,0xef380092,0xceb403b9}},	//   _kuoh, kwoe, _የቴክኖ, bnəm_, 
   {{0x7f4ce1e6,0x6b980158,0x25f40cbf,0x2738002e}},	// [135b0] rmaq, _åtgj, एनटी_, gëni_, 
   {{0x69c0017a,0x69b81bbb,0x00000000,0x00000000}},	//   dwoe, _एनजी, --, --, 
   {{0x69c0017a,0xb0dc8153,0x7f4c03e3,0x00000000}},	//   ewoe, मारग, pmaq, --, 
   {{0x59bc03f8,0x2f180724,0x8bc454be,0x1cb00327}},	//   _एनआर, rügä_, ысуд, _དིམ_, 
   {{0xdbd425e4,0x7760208d,0x65600108,0x0e4400c0}},	//   _säär, _sulx, _nuoh, _бэрм, 
   {{0x6aa00607,0x49b80150,0xb940001f,0xdbd40f23}},	//   agof, عاند_, _ፖሊሲዎ, _päär, 
   {{0xf748d91c,0x37e472a0,0x00000000,0x00000000}},	//   ولتي_, тойг, --, --, 
   {{0xdbd4246f,0x69c0017a,0x15a80131,0x00000000}},	//   _väär, bwoe, _ﻳﻪﺭﺩ, --, 
   {{0xa6e00e76,0xdbd40036,0x28d073d4,0x00000000}},	//   ржыл, _wäär, _धोवि, --, 
   {{0xd90c01ed,0x499015b4,0x28e000cd,0x25f403ce}},	//   _ھیں_, _ایور, पाणि, एनजी_, 
   {{0xf6b41ec7,0x00000000,0x00000000,0x00000000}},	//   _لماج, --, --, --, 
   {{0x86c4e1e7,0x7bd402f0,0x00000000,0x00000000}},	//   _ميمن, _mrzu, --, --, 
   {{0x65600198,0x649800f7,0x35a40124,0xa2580419}},	//   _guoh, чтөр_, _ралг, zdôv, 
   {{0x7bd4036b,0x864400d4,0x00000000,0x00000000}},	//   _orzu, _сніж, --, --, 
   {{0xa06408d0,0x6f140784,0x28e00303,0x00000000}},	//   таса_, tiyc, पाति, --, 
   {{0x7b101d55,0x2d9400f7,0xf1d000cf,0xed5000ec}},	//   sťuj, көгө_, _көгө, ڄپر_, 
   {{0x7bd4442e,0xc1d430cb,0xee387ffa,0xb144769e}},	// [135c0] _arzu, _йөрә, фна_, _инил, 
   {{0xdcac4d2d,0xdd8c54f6,0x7bd40034,0x6f140113}},	//   يىق_, زوم_, _brzu, siyc, 
   {{0xe0f80bd9,0x6a840276,0x6b4803b2,0x6aa0015d}},	//   _חליל, влеа, nýgg, tgof, 
   {{0xa258002d,0x6f140784,0x69c0017a,0x6b9c005c}},	//   rdôv, qiyc, twoe, rupg, 
   {{0x7bd4e1e8,0x80a8015b,0x6aa0032e,0xa2a42ce6}},	//   _erzu, _ছোট্, rgof, ट्ट्, 
   {{0x8884e119,0x69c05b5e,0x66140008,0x6560023a}},	//   ایان, rwoe, _þyki, _ruoh, 
   {{0x97c000cf,0x69c00af9,0x65600108,0x6c34007b}},	//   لقوو, swoe, _suoh, _شفرا, 
   {{0x65600db6,0x9d740014,0x98a4e1e9,0x3eac1bce}},	//   _puoh, _سٕہا_, tonă_, _ñett_, 
   {{0x28e028c6,0xca340131,0x7bd4033f,0xa2b0095f}},	//   पादि, ﺮﯨﺶ_, _zrzu, ेजस्, 
   {{0x6560005b,0x00000000,0x00000000,0x00000000}},	//   _vuoh, --, --, --, 
   {{0xdc98008d,0x63a80334,0xa6c801ec,0x00000000}},	//   וייל, _qqfn, _олжа_, --, 
   {{0x6560e1ea,0xa2640107,0x00000000,0x00000000}},	//   _tuoh, ъъол, --, --, 
   {{0xb0dc0490,0x51840354,0xc5940798,0x00000000}},	//   मांग, иура, _силј, --, 
   {{0x6b4803b2,0x81441291,0xe9cc0024,0x24f400d8}},	//   býgg, انسن, скi_, _шчер, 
   {{0x54300cd2,0xd9bc146c,0xa3c400bc,0xde640395}},	//   _پرور, _एन्ट, _उनि_, възп, 
   {{0x21640a8f,0x78ac01fa,0x1ee4029e,0x98a400c0}},	//   _итог, đavi, خوری_, moną_, 
   {{0x98a4e1eb,0x3cb400ee,0x443c01f4,0x6614010e}},	// [135d0] loną_, лйар, _hyv_, _ýykd, 
   {{0xa3d41152,0x00000000,0x00000000,0x00000000}},	//   सिप_, --, --, --, 
   {{0x3a74e1ec,0x8c640046,0x443c00e4,0x98a40064}},	//   глер, ртуд, _jyv_, noną_, 
   {{0x443ce1ed,0x6ed80b7d,0x00000000,0x00000000}},	//   _myv_, _पोपु, --, --, 
   {{0x7bd4068f,0x7f5c0381,0x7e6c009a,0x0dc800c7}},	//   _wrzu, _iisq, mcap, _иури_, 
   {{0x7e6c3eb9,0x7f5ce1ee,0xa0240037,0x75200175}},	//   lcap, _hisq, _gröö, xnlz, 
   {{0x7bd40ffb,0x98a43ee4,0x443ce1ef,0x6ee80432}},	//   _urzu, joną_, _nyv_, _aýby, 
   {{0x7e6c15a5,0xa3d43f6f,0x36c401d5,0x98a400c0}},	//   ncap, सिन_, убиг, doną_, 
   {{0x25fc2765,0x7f5c8e61,0x36680022,0x00000000}},	//   शैली_, _misq, _ҟало_, --, 
   {{0x7e6ce1f0,0x7f5c0784,0x98a40006,0x443c017a}},	//   hcap, _lisq, foną_, _byv_, 
   {{0xe794e1f1,0x7e6c020b,0x9f98000d,0x98a40064}},	//   _مانک, kcap, _jääv_, goną_, 
   {{0x7f5c4375,0x443c0175,0x6b4803b2,0xc9140154}},	//   _nisq, _dyv_, rýgg, াকৃত_, 
   {{0x7e6ce1f2,0x2164013e,0xd5b4000d,0x54b018c7}},	//   dcap, лияи_, _अहिज, _кәнф, 
   {{0x7e6c01f5,0xea14010f,0x6b4803b2,0x409468eb}},	//   ecap, אַלי_, pýgg, ирст, 
   {{0x7f5ce1f3,0xaf200154,0x443c0153,0x98a4012d}},	//   _bisq, _ভীষণ_, _gyv_, coną_, 
   {{0x7e6ce1f4,0x60200107,0x00000000,0x00000000}},	//   gcap, ёдта, --, --, 
   {{0x7f5ce1f5,0xa2b007f7,0xfd6400cf,0x00000000}},	// [135e0] _disq, ेजर्, интү, --, 
   {{0x6c84185e,0xed5800a6,0xd1f81ee0,0x7e6c86ed}},	//   الام, хоз_, _ዋልታ_, acap, 
   {{0x7f5c0169,0x32d80139,0x7e6c0356,0x00000000}},	//   _fisq, _güyä_, bcap, --, 
   {{0x7e6cc044,0x6a84bbe8,0xe1fc0548,0x00000000}},	//   ccap, улда, xcók_, --, 
   {{0x98a46dd2,0x88840046,0xa3c805f9,0x6a143868}},	//   zoną_, иғал, _रैन_, دبار, 
   {{0xa3d47db3,0x50d400cd,0x00000000,0x00000000}},	//   सिम_, दयिष, --, --, 
   {{0xe66400db,0x00000000,0x00000000,0x00000000}},	//   лтпо, --, --, --, 
   {{0xe5c405f5,0x7f5c17cd,0x3cf00165,0x28e0012d}},	//   гсоо, _xisq, _zozv_, पाहि, 
   {{0xe9d810f5,0x443c0ff7,0x289400f3,0x00000000}},	//   _яка_, _syv_, _бјес, --, 
   {{0x78ac0030,0x98a40153,0xceb403e3,0xa51c01f9}},	//   ľový, toną_, hfə_, यचेच_, 
   {{0xd48c0046,0x78ac02fb,0x499001d3,0xd6cc005a}},	//   _қр_, žový, _ایڈر, _лт_, 
   {{0x98a43d44,0x32d80014,0x461431b1,0x7e6c0332}},	//   roną_, ندُک_, _پوتر, xcap, 
   {{0x7f5ce1f6,0x92582140,0x4f240092,0x00000000}},	//   _risq, лают_, _ተለያይ, --, 
   {{0x443ce1f7,0x98a40006,0x7f5c004e,0x7e6c009a}},	//   _tyv_, poną_, _sisq, wcap, 
   {{0x7f5c0986,0x7e6ce1f8,0xc3c40daf,0x78b4e1f9}},	//   _pisq, tcap, _төпл, _özve, 
   {{0x7f5c07d6,0x656400d2,0x7e74e1fa,0xd5b40183}},	//   _qisq, íkhw, ргах, জিৰঙ, 
   {{0x8d740e26,0x7e6c02b4,0x7f5c56ed,0xf2f80014}},	// [135f0] مالا, rcap, _visq, _شوٝژ_, 
   {{0x7f5c0784,0x3c94e1fb,0x00000000,0x00000000}},	//   _wisq, рижё, --, --, 
   {{0x9c44177b,0x7f5ce1fc,0x00000000,0x00000000}},	//   ухал, _tisq, --, --, 
   {{0xbb3c0952,0x7f5c003a,0xea8801ec,0x00000000}},	//   ﻟﯩﻢ_, _uisq, _ﻗﯩﺮﯞ, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa9642ec9,0x580000fb,0x8aa40139,0x9e64210e}},	//   шиша_, йолғ, арәд, _جاگن, 
   {{0x80ac0c4c,0xd0f8011a,0x00000000,0x00000000}},	//   _जाने, רמות_, --, --, 
   {{0xdb203765,0x7ac801d9,0x00000000,0x00000000}},	//   _اوری, _جورِ_, --, --, 
   {{0xf504e1fd,0x09b8b991,0x2738017a,0x88800014}},	//   изио, _مطلع_, eëns_, _کی٘ن, 
   {{0xb374001f,0x067400d1,0x8a1800f5,0xe1fc033f}},	//   _የሰውን_, _һушя, _соус_, lców_, 
   {{0x3eb8e1fe,0x28e09ed5,0x27380036,0xc8780139}},	//   _obst_, पारि, gëns_, _unğa_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe29443a7,0x347401af,0x86c400ae,0x00000000}},	//   шая_, _кѳйѳ, _دينن, --, 
   {{0x64a009a5,0x00000000,0x00000000,0x00000000}},	//   _даша, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2ca8020b,0x34c407d0,0xe1fc0210,0x00000000}},	//   _scbd_, _वसुद, jców_, --, 
   {{0xada46465,0xac849d5c,0xdddc02d1,0xe1fc012d}},	// [13600] разл, игал, taqš, dców_, 
   {{0x80ace1ff,0xef84e200,0x7c28002b,0x00000000}},	//   _जाये, _клоп, _śera, --, 
   {{0xa098008f,0xdddc0784,0xf8a800cd,0xafe406b4}},	//   _בייט, raqš, च्छय, _тонл, 
   {{0xa3d41152,0x98a40006,0x2ca800f1,0x6da4e201}},	//   सित_, monę_, _wcbd_, _кима, 
   {{0x28e01b2b,0xdddc0784,0xde440014,0x98a400c0}},	//   पालि, paqš, _نیٲو_, lonę_, 
   {{0x1ccc031c,0x32a80406,0xc9140154,0x00000000}},	//   _ྱིར_, _काऽऽ, াক্ত_, --, 
   {{0x6b586683,0x6d4c05d1,0x98a00640,0xd7c40345}},	//   _ашар_, _ihba, ције, لووه_, 
   {{0xd6d4e202,0xd7f4e203,0x43940032,0xb3a80139}},	//   ать_, руш_, ҙамс, _çıyı, 
   {{0x6b9c074d,0xa968ab8e,0x6ed4033f,0x3a28013d}},	//   lrpg, _риза_, _zębó, _бетү_, 
   {{0xf99000e5,0x00000000,0x00000000,0x00000000}},	//   _ڈبے_, --, --, --, 
   {{0x80c4242e,0x1ccc0327,0x98a40153,0x00000000}},	//   ाजसे, _ྱིལ_, jonę_, --, 
   {{0xe618e204,0x2ee00158,0xdec800b7,0xd6cc007b}},	//   _иде_, _nnkf_, ጠቱን_, _يقل_, 
   {{0x27380036,0x2fd80208,0x84c400fb,0x00000000}},	//   sëns_, _arpg_, _ләнд, --, 
   {{0x3eb8014b,0x6f0403ac,0x00000000,0x00000000}},	//   _sbst_, _alkc, --, --, 
   {{0x2d9c0374,0x53a000f3,0x00000000,0x00000000}},	//   _ātea_, _дајб, --, --, 
   {{0x8f08a261,0x6d4ce205,0x05180451,0x7c800092}},	//   ахуа_, _ahba, _جيڪب_, _ይቀራል_, 
   {{0xd13000f1,0x00000000,0x00000000,0x00000000}},	// [13610] سمې_, --, --, --, 
   {{0xc5d80183,0xe1fc068f,0xd6540302,0xc0cc0023}},	//   _তথাপ, wców_, שימת_, _ኣፎም_, 
   {{0x41d40825,0x52382e6b,0x00000000,0x00000000}},	//   दिवस, _مسیح_, --, --, 
   {{0x6e3000bc,0xe20803b2,0x3ce40150,0x00000000}},	//   _žebř, _gróð_, _ﺍﻷﺌﻤ, --, 
   {{0x3ea81028,0xded0044e,0xe1fc033f,0x19a8113e}},	//   mgat_, _ከሎና_, rców_, ттеп_, 
   {{0x64480a73,0x3ea8e206,0xbd340372,0x00000000}},	//   _ozfi, lgat_, _چىڭع, --, 
   {{0xb3a80cc1,0xe1fc033f,0x3a280356,0xfad40120}},	//   _çıxı, pców_, _ţipă_, _ловќ, 
   {{0x3ea8e207,0xb6880131,0xa8680137,0x00000000}},	//   ngat_, اھال_, _ۅلكۅ_, --, 
   {{0x98c453e9,0x00000000,0x00000000,0x00000000}},	//   _всел, --, --, --, 
   {{0x1ccc025c,0xfa900023,0x00000000,0x00000000}},	//   _ྱིས_, _ምበኣር_, --, --, 
   {{0x2bd8068f,0xd838792b,0x20040210,0x3ea8e208}},	//   णिया, _рэа_, _żnin_, kgat_, 
   {{0x3dc80134,0xb5c801d9,0xceb40213,0x00000000}},	//   kwaw_, _موصم_, nnət_, --, 
   {{0x3ea801e3,0x00000000,0x00000000,0x00000000}},	//   dgat_, --, --, --, 
   {{0x2164448f,0xf5040050,0x2bd81223,0x3dc8031c}},	//   сири_, _دِتُ, णिमा, dwaw_, 
   {{0xabe402dd,0x3ea80139,0x00000000,0x00000000}},	//   _ﺍﻧﺎﻋ, fgat_, --, --, 
   {{0x3ea8e209,0x98a4068f,0x23740975,0x6d4ce20a}},	//   ggat_, ronę_, _اميد_, _shba, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [13620] --, --, --, --, 
   {{0xa9681ee3,0x3ea80140,0x645c013a,0x00000000}},	//   ҳида_, agat_, _úpic, --, 
   {{0x290000e2,0x80ac01bc,0x6da4013e,0xeb98084c}},	//   _ēka_, _जाते, риҷа, уие_, 
   {{0xa9680e5c,0xa3c803ce,0x00000000,0x00000000}},	//   гида_, _रईस_, --, --, 
   {{0x5ce02b62,0xe2a40174,0x00000000,0x00000000}},	//   تكەل, óðis_, --, --, 
   {{0x6b9c009a,0x5a30003b,0x00000000,0x00000000}},	//   prpg, чніт, --, --, 
   {{0xab280e46,0xbb741188,0x00000000,0x00000000}},	//   _бова_, _мутъ, --, --, 
   {{0xa3d44d53,0x2450019f,0xc6f8e20b,0x857408da}},	//   सिस_, hûmé_, рних_, олих, 
   {{0x2d90662e,0xa3c83f6f,0x00000000,0x00000000}},	//   nsye_, रौन_, --, --, 
   {{0xbf041b51,0x7c44000f,0x3ea82608,0xe5a401a9}},	//   _रत्न_, _útrû, zgat_, _ҳиди, 
   {{0x1874011a,0x3ea8007c,0x00000000,0x00000000}},	//   _העבר_, ygat_, --, --, 
   {{0xe5a40209,0x2d900100,0x98a40118,0x00000000}},	//   _гиди, ksye_, koně_, --, 
   {{0x3ea8e20c,0x3f900210,0x00000000,0x00000000}},	//   vgat_, wszu_, --, --, 
   {{0x2d900660,0x00000000,0x00000000,0x00000000}},	//   dsye_, --, --, --, 
   {{0x3f84020c,0x3ea8017a,0x64483e9d,0x00000000}},	//   èlu_, tgat_, _uzfi, --, 
   {{0x3ea8084c,0x3f90012d,0x3dc80327,0x80d807af}},	//   ugat_, rszu_, twaw_, _फोरे, 
   {{0x3ea8e20d,0xa3d400e1,0xbd180cc9,0xa8f812eb}},	// [13630] rgat_, सिव_, ажах_, ्साफ_, 
   {{0x628ce20e,0x955c02d3,0x3dc800ca,0x11d402dd}},	//   laco, _ሰባትን_, rwaw_, _ءتيد, 
   {{0xe1fc93e1,0x3ea80ea0,0x60c4014f,0xd0f81b51}},	//   rcóu_, pgat_, mejm, ुसरण_, 
   {{0x628c0c38,0xdec8016c,0xe1fc0ba1,0x91cc0183}},	//   naco, _суол_, scóu_, ামৰ্, 
   {{0xe1fce20f,0x628c0175,0xdb040aab,0xf864022e}},	//   nyó_, iaco, _spjó, овло, 
   {{0x60c4e210,0xf7704c84,0x4fb410e5,0x5c0400c0}},	//   nejm, واب_, _بصیر, _ляба, 
   {{0x628ce211,0xda7802d5,0x907c010f,0x00000000}},	//   kaco, _бяз_, נטהי, --, 
   {{0x60c4e212,0x628ce213,0xab6004a2,0xe1fce214}},	//   hejm, jaco, _قۇلى, ncós_, 
   {{0x628ce215,0xf50863e6,0x60c401ef,0x00000000}},	//   daco, инил_, kejm, --, 
   {{0x60c43bc8,0x85080046,0x387000ac,0x00000000}},	//   jejm, йдың_, _üzr_, --, 
   {{0x60c40034,0xdef4001f,0x98a400bc,0xdbd4013d}},	//   dejm, _ለጎን_, zoně_, _näür, 
   {{0x628ce216,0x98a800c0,0x2bd8043e,0x00000000}},	//   gaco, _ėmęs_, णिता, --, 
   {{0xe1fc01d3,0x60c4013a,0x00000000,0x00000000}},	//   gyó_, fejm, --, --, 
   {{0xc6d40133,0x00000000,0x00000000,0x00000000}},	//   _وتۆت, --, --, --, 
   {{0x628ce217,0xbf040c66,0xb4c4000d,0x00000000}},	//   baco, रसून_, उजी_, --, 
   {{0xa3d48cb2,0xdee001b9,0xca6001a9,0x2d74009f}},	//   सिर_, моси, _ommа, قُرآ, 
   {{0x80a4e218,0xae1801ad,0x60c4047e,0x70b801e0}},	// [13640] _کمپن, _नेशन_, bejm, _кѳнѳ_, 
   {{0x2d90e219,0xdca0e21a,0x61f80e78,0x00000000}},	//   rsye_, дафи, äule, --, 
   {{0x2f0c03b2,0x2bc8e21b,0x2d900100,0x00000000}},	//   _nýgg_, рлеп_, ssye_, --, 
   {{0xe9d8e21c,0xda74013e,0xbb3c00d1,0xcc8801b9}},	//   ике_, ояш_, ﻟﯩﻲ_, شنچه_, 
   {{0x98bc0139,0xc2cc010f,0x00000000,0x00000000}},	//   _atuı_, טמאָ, --, --, 
   {{0x628ce21d,0x9c8402fb,0xed5001ed,0x7f940133}},	//   zaco, ručí, _آپس_, _بهێڵ, 
   {{0x628c601a,0xaac40472,0x00000000,0x00000000}},	//   yaco, _وترن, --, --, 
   {{0xe1fc0548,0x60c4e21e,0xab286bb8,0x9c8402f0}},	//   yyó_, zejm, _тоба_, pučí, 
   {{0x628ce21f,0x2c1c0490,0x60c4036e,0x00000000}},	//   vaco, _येतं_, yejm, --, 
   {{0xa3d419e5,0x2b440dd4,0xd614004b,0x628ce220}},	//   सिल_, lloc_, غتيا_, waco, 
   {{0xb8741682,0x60c48256,0xa3c836c7,0x00000000}},	//   _aṋw, vejm, रौढ_, --, 
   {{0x2b44e221,0x80ac00bc,0x00000000,0x00000000}},	//   nloc_, _जाहे, --, --, 
   {{0x628c2320,0x07240131,0x60c45d49,0x00000000}},	//   raco, _ﭼﻮﯓ_, tejm, --, 
   {{0xefd4001f,0x2b440175,0x00000000,0x00000000}},	//   _ቪዲዮ_, hloc_, --, --, 
   {{0x628ce222,0x60c4e223,0x26d8016b,0x387800ac}},	//   paco, rejm, _ɔpon_, _əsr_, 
   {{0xe7f04425,0x628c23e0,0x2b440276,0x80ac447d}},	//   _अपना_, qaco, jloc_, _जावे, 
   {{0xe1fc00cf,0x230800f1,0x00000000,0x00000000}},	// [13650] rcós_, _متکي_, --, --, 
   {{0xe1fc5d7e,0xb0b0012d,0x00000000,0x00000000}},	//   scós_, _जायग, --, --, 
   {{0x290c01f7,0x51f40133,0x46bc278e,0x00000000}},	//   dhfa_, _فسیر, ्जाह, --, 
   {{0xdd0c0166,0x5454010f,0x00000000,0x00000000}},	//   bışq, קסאן_, --, --, 
   {{0xf5600092,0xfcc400fb,0x0e4400c0,0x00000000}},	//   _መጣጥፎ, _нәжм, _жэрм, --, 
   {{0x7cc40a81,0x1b78007b,0x95240092,0x00000000}},	//   _عٲزم, _نصرة_, _ስፖንሰ, --, 
   {{0x2b44e224,0x00000000,0x00000000,0x00000000}},	//   bloc_, --, --, --, 
   {{0xe6900075,0x2b44e225,0x8aa457c6,0x20200092}},	//   ىلىد, cloc_, _оруд, ደሚታየ, 
   {{0x762401a9,0x00000000,0x00000000,0x00000000}},	//   ямиз, --, --, --, 
   {{0xe614e226,0x7988006f,0x290c015d,0xb6c801d3}},	//   яды_, _iwew, chfa_, _گائے_, 
   {{0x73e40107,0x00000000,0x00000000,0x00000000}},	//   чонз, --, --, --, 
   {{0x79888263,0xf2d0072d,0x67b8011a,0x00000000}},	//   _kwew, رآج_, _למעק, --, 
   {{0x79880770,0x23b00271,0x562400e5,0xd78400ec}},	//   _jwew, ومیس, _برآ, _اچڻو_, 
   {{0x798824be,0x2b440165,0x00000000,0x00000000}},	//   _mwew, zloc_, --, --, 
   {{0x7988e227,0x2b440175,0xb62401ec,0x00000000}},	//   _lwew, yloc_, _ﺭﻑ_, --, 
   {{0x798803ac,0x75200139,0x00000000,0x00000000}},	//   _owew, lilz, --, --, 
   {{0x798804ba,0x3124010b,0xe1fc0332,0xfe70210e}},	// [13660] _nwew, _ндиг, scór_, ئدِ_, 
   {{0xf0a8e228,0x85a400d1,0x644c0037,0x00000000}},	//   _укол_, _ﺋﻪﺯﺍ_, übig, --, 
   {{0x79881dd4,0xe0f802e4,0x00000000,0x00000000}},	//   _awew, _הליל, --, --, 
   {{0x79880337,0xda6c038b,0x2b44030a,0x37e00154}},	//   _bwew, هُم_, uloc_, বহার, 
   {{0x2b44e229,0x752001f7,0xad2462a9,0x290c0042}},	//   rloc_, kilz, _فرسو, thfa_, 
   {{0xed340323,0xa8500032,0x3078010f,0x00000000}},	//   _хэмэ, нелә, זאַנ, --, 
   {{0x798808e7,0x2b44e22a,0xe7840137,0x00000000}},	//   _ewew, ploc_, чуло, --, 
   {{0x32000209,0x290c0451,0x77904c12,0xb3b00154}},	//   kyky_, shfa_, ئینا, জবাড়, 
   {{0x7988e22b,0x7520e22c,0x00000000,0x00000000}},	//   _gwew, filz, --, --, 
   {{0x66140432,0x320000a2,0x3a2800e4,0x00000000}},	//   _ýykm, dyky_, úape_, --, 
   {{0xa848e22d,0x68f802d0,0x291ce22e,0x98a00107}},	//   _الام_, _iotd, _imta_, _чихе, 
   {{0x68f8e22f,0x490400bc,0x00000000,0x00000000}},	//   _hotd, वसको_, --, --, 
   {{0x68f8e230,0x291c0270,0x7520e231,0x07a40166}},	//   _kotd, _kmta_, bilz, _хаҗн, 
   {{0x25700042,0x453400d1,0x00000000,0x00000000}},	//   _iâl_, _تىتر, --, --, 
   {{0x94b80375,0x4f680116,0x68f8007c,0x94c800f1}},	//   _המות, зшум_, _motd, _دانې_, 
   {{0xe3bc00c6,0xc21001d9,0x2b5c0100,0x320000e4}},	//   _ĕɱȫ_, _لٔب_, _ètch_, byky_, 
   {{0x9e300451,0xdef81219,0x5cc4013d,0x0dc8117e}},	// [13670] روئڙ, _ғын_, зсез, зухи_, 
   {{0x291c00ca,0x2570ba54,0x4d981e76,0x68f8e232}},	//   _nmta_, _mâl_, якую_, _notd, 
   {{0x2038001f,0x7988017a,0xba98007b,0x4034010a}},	//   _የኤሌክ, _swew, قناص_, _ценс, 
   {{0x291c0bc9,0xcd2800d1,0x80c402c3,0x00000000}},	//   _amta_, يسەن_, ाजके, --, 
   {{0x68f801a9,0xae180073,0xcc9001ec,0x041800b8}},	//   _botd, _नेऊन_, _ﺗﯘﺭﮔ, _vīṇa, 
   {{0xdb6800d8,0x00000000,0x00000000,0x00000000}},	//   _грал_, --, --, --, 
   {{0xb8d4c6cd,0x60d4e233,0x320082ae,0x68f8037e}},	//   _झा_, _maxm, zyky_, _dotd, 
   {{0x79880337,0x291c0254,0xbae4007b,0x00000000}},	//   _twew, _emta_, _تكري, --, 
   {{0x798802d0,0xd6d801ec,0x00000000,0x00000000}},	//   _uwew, _қтж_, --, --, 
   {{0x291c0048,0x32001705,0x257003cb,0x7ae8e234}},	//   _gmta_, vyky_, _dâl_, _hnet, 
   {{0x7ae8e235,0x00000000,0x00000000,0x00000000}},	//   _knet, --, --, --, 
   {{0x32007247,0x68f801d5,0x00000000,0x00000000}},	//   tyky_, _zotd, --, --, 
   {{0x60d403be,0x291c0158,0x25700042,0x68f8e236}},	//   _baxm, _ymta_, _gâl_, _yotd, 
   {{0x660403a1,0xa5b0033f,0x159c00d1,0x00000000}},	//   økke, _आमतौ, _ﺋﻪﺳﯩ, --, 
   {{0xa064e237,0x7ae8e238,0x60d4427b,0x3b0c06be}},	//   дара_, _onet, _daxm, _oleq_, 
   {{0x7ae8c6ee,0x3cc800f7,0x50480023,0x8fc400c7}},	//   _nnet, үктү_, _መድረኽ, _ҟамҵ, 
   {{0x60d402fa,0x00000000,0x00000000,0x00000000}},	// [13680] _faxm, --, --, --, 
   {{0x3b0c047e,0xafe400f7,0x3bf800ab,0x644ce239}},	//   _aleq_, _жоол, ंहूँ_, żbie, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7ae8e23a,0x2a081066,0x5480001f,0x68f8e23b}},	//   _cnet, يقاپ_, _የጠበቀ_, _sotd, 
   {{0xed600022,0xed580063,0x60d403b9,0x00000000}},	//   _аҭаҩ, _мом_, _yaxm, --, 
   {{0x7ae8e23c,0x68f80f89,0x3dcc025c,0x3cd401d5}},	//   _enet, _qotd, _ġewx_, _пўст, 
   {{0x257003cb,0x9cd4011a,0x00000000,0x00000000}},	//   _sâl_, _קולה_, --, --, 
   {{0x7ae8e23d,0xd75400c6,0xb904610a,0x70c813f7}},	//   _gnet, وجيا_, _बो_, ाजुल, 
   {{0x68f8e23e,0x00000000,0x00000000,0x00000000}},	//   _totd, --, --, --, 
   {{0x25700998,0x7ae81155,0x00000000,0x00000000}},	//   _vâl_, _znet, --, --, 
   {{0x60d4e23f,0x2570045f,0x60c0002d,0x7ae802d0}},	//   _raxm, _wâl_, _űnmo, _ynet, 
   {{0x25700368,0x60d4058a,0x660400d8,0x00000000}},	//   _tâl_, _saxm, _опеа, --, 
   {{0x8c480598,0xd24405f5,0x70c80073,0x60d44831}},	//   _yaşä, вэри, ाजूल, _paxm, 
   {{0xb9e402d3,0xb51c1cd2,0xf0780131,0x00000000}},	//   _ከደ_, योदय_, зирә_, --, 
   {{0x1ee403e6,0x60d40139,0x00000000,0x00000000}},	//   ووسی_, _vaxm, --, --, 
   {{0xdcc41a67,0x44cc016b,0xdc2c0882,0x8d74e240}},	//   रज्ञ, _hכ_, jñāp, چالا, 
   {{0x8d740f78,0xa3d42052,0x60d4e241,0x7d54010a}},	// [13690] نالا, सिक_, _taxm, евах, 
   {{0x7ae8e242,0xa514031c,0x00000000,0x00000000}},	//   _snet, ྲིིག_, --, --, 
   {{0x3b0c0240,0x1da802a0,0x8fd401af,0x5fa00116}},	//   _pleq_, _चमकत, _иҙрә, _جەزم, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7ae8151c,0xa2d40550,0x00000000,0x00000000}},	//   _vnet, _बसन्, --, --, 
   {{0xc984365c,0x88c40131,0x7ae80210,0x00000000}},	//   туци, نتىل, _wnet, --, 
   {{0xf74473d6,0x00000000,0x00000000,0x00000000}},	//   неко, --, --, --, 
   {{0xbb3c23f6,0x6fc000af,0x65c400d1,0xb63c0092}},	//   ﻟﯩﻖ_, _लहसू, ﯩﻤﯩﻠ, _አሳውቀ, 
   {{0xf50402e8,0x00000000,0x00000000,0x00000000}},	//   езпо, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x490400f7,0xb464a10d,0x00000000,0x00000000}},	//   _جولق, экол, --, --, 
   {{0x47840022,0xd9f0a71d,0x00000000,0x00000000}},	//   _рыфб, _आपात_, --, --, 
   {{0xe60ce243,0x00000000,0x00000000,0x00000000}},	//   _сд_, --, --, --, 
   {{0x7bd40034,0x65980677,0x00000000,0x00000000}},	//   _oszu, _זיסק, --, --, 
   {{0x3e7402e3,0x273804e6,0x2f54e244,0xe4d40ada}},	//   _ụta_, vënz_, етас, _سويت_, 
   {{0xb900025c,0x94c8004b,0x15e000e1,0xd9ec00c5}},	//   _ཧལ_, _داچې_, _कछार_, चमात_, 
   {{0xc2e8007b,0x00000000,0x00000000,0x00000000}},	// [136a0] _زعيم_, --, --, --, 
   {{0x02c00562,0xf0a841e5,0x00000000,0x00000000}},	//   ष्ठभ, _экол_, --, --, 
   {{0x10240682,0x09040133,0x00000000,0x00000000}},	//   _شکسپ, ێستێ, --, --, 
   {{0x394400ef,0xfbd000e5,0x7f74010a,0x00000000}},	//   _akls_, گتے_, _шуьц, --, 
   {{0xceb80032,0x7c2806be,0x00000000,0x00000000}},	//   _нәҡ_, _əmrə, --, --, 
   {{0x63b80267,0xac0801a9,0xeb980117,0x00000000}},	//   yttn, _енга_, _ниг_, --, 
   {{0x97a02b95,0x00000000,0x00000000,0x00000000}},	//   грыл, --, --, --, 
   {{0x637c02b5,0xb60402f0,0x00000000,0x00000000}},	//   _hīng, zváš, --, --, 
   {{0x637c0325,0x6d5c00ae,0x34bc07f7,0x200403e0}},	//   _kīng, ompa, ौजूद, _üniv_, 
   {{0x425404d3,0x00000000,0x00000000,0x00000000}},	//   ێندر, --, --, --, 
   {{0x66e4b7ef,0x6d5ce245,0xa3c89417,0xa68400c0}},	//   _пожа, impa, रौं_, _злед, 
   {{0x44cc0134,0x308c0150,0x00000000,0x00000000}},	//   _wכ_, _ﺒﺩﺍﻴ_, --, --, 
   {{0x690400fc,0x672001e1,0x00000000,0x00000000}},	//   _aðei, _imoj, --, --, 
   {{0x6d5c010f,0xf628007b,0x00000000,0x00000000}},	//   jmpa, _تسمى_, --, --, 
   {{0x672000e4,0xcfa4252c,0x00000000,0x00000000}},	//   _kmoj, лшти, --, --, 
   {{0x6d5ce246,0x0f240124,0x00000000,0x00000000}},	//   empa, гьум, --, --, 
   {{0x672000b2,0x3170020c,0x1ccc031c,0x271c09bb}},	// [136b0] _mmoj, _guyz_, _ྱིད_, _बगैर_, 
   {{0x65680003,0x6d5c02d0,0x00000000,0x00000000}},	//   _jifh, gmpa, --, --, 
   {{0x6e2800ac,0x6720e247,0x6568e248,0x5b24702f}},	//   _əlbə, _omoj, _mifh, ньда, 
   {{0x65681682,0x6d5ce249,0xf8d800dc,0x00000000}},	//   _lifh, ampa, _योजय, --, 
   {{0x0ab4b65a,0x0dc89771,0x6448e24a,0x637c002b}},	//   احمد, _пури_, _lyfi, _hīnd, 
   {{0x7f4ce24b,0x67200241,0xbb8400c6,0x65680003}},	//   llaq, _amoj, _للسي, _nifh, 
   {{0x6448e24c,0x3a740305,0x00000000,0x00000000}},	//   _nyfi, _албр, --, --, 
   {{0x59b01952,0x538001b9,0x2bfc00bc,0x67200200}},	//   _бөкс, ққиз, लहरू_, _cmoj, 
   {{0x6448035a,0x656808a5,0xe4e000bc,0x00000000}},	//   _ayfi, _bifh, _कोहि_, --, 
   {{0x6720030d,0x6448002d,0x80ac2052,0x7f4c020c}},	//   _emoj, _byfi, _जागे, hlaq, 
   {{0x7e7c64fc,0x644800a9,0x3f800161,0x1ccc031c}},	//   _ofsp, _cyfi, _nthu_, _ྱིན_, 
   {{0xbb3c2e56,0x6448e24d,0xd6a801ec,0xa2d40073}},	//   ﻟﯩﻚ_, _dyfi, _ءدام_, _बसण्, 
   {{0x3f804907,0x6d5ce24e,0x6448032e,0xe56c004e}},	//   _athu_, ympa, _eyfi, _ъз_, 
   {{0x7e7ce24f,0xdedc044e,0x65684cf1,0xe5a03246}},	//   _afsp, _ሓቀኛ_, _gifh, _тиши, 
   {{0x2eb40116,0x637c02b1,0x64480368,0x6d5c92de}},	//   ксас, _rīng, _gyfi, vmpa, 
   {{0x84640801,0x6d5c015d,0xd7ec0150,0x00000000}},	//   _съче, wmpa, руi_, --, 
   {{0x3f800912,0x637c02b1,0xde0017a2,0x715801c0}},	// [136c0] _ethu_, _pīng, апти, _орос_, 
   {{0x6d5ce250,0x7f4c0194,0x00000000,0x00000000}},	//   umpa, alaq, --, --, 
   {{0x6d5c127b,0x7f4c014b,0x7e7c00d8,0x637c00ef}},	//   rmpa, blaq, _ffsp, _vīng, 
   {{0x620401a8,0x6d5c03ac,0x0d9465dd,0x00000000}},	//   _örlí, smpa, _میرح, --, 
   {{0x6a14e251,0x7bc001b8,0x637c00b0,0xbe8002dd}},	//   خبار, _älun, _tīng, _ықти, 
   {{0x67200301,0xceb40213,0x637c00b8,0x2d800108}},	//   _smoj, lgə_, _hīne, _itke_, 
   {{0xceb40213,0x82400023,0x00000000,0x00000000}},	//   biət_, _ሓድሕዳ, --, --, 
   {{0xceb40213,0x26d8013f,0x6568007c,0xe66400d8}},	//   ciət_, _ɔpow_, _sifh, ктпо, 
   {{0xe9d82123,0xb0b000e1,0x89a801d3,0x78ac01d3}},	//   _юка_, _जांग, _سپاہ_, ánvé, 
   {{0x6ad07db3,0x44f41515,0x03f80640,0x159c00d1}},	//   _ससुर, упос, еној_, _ﺋﻪﺗﯩ, 
   {{0xf89805d9,0xd6cc1d4a,0x49a40220,0x672000d7}},	//   _سمنڊ_, _кт_, _шыңғ, _tmoj, 
   {{0x672000b2,0xdb9825f9,0xb86415eb,0x644802f0}},	//   _umoj, וסטר, _صالو, _vyfi, 
   {{0x644805e4,0x26c401e1,0x9258023a,0x65680135}},	//   _wyfi, _iboo_, кают_, _tifh, 
   {{0x6448015d,0x637c0055,0x00000000,0x00000000}},	//   _tyfi, _pīnd, --, --, 
   {{0x403403b7,0x7f4ce252,0x00000000,0x00000000}},	//   уевс, tlaq, --, --, 
   {{0x82cc0003,0xfcd800dd,0x63c00032,0xa5c401e1}},	//   _ཇིིའ, کارڈ_, _баҫҡ, _gbóó, 
   {{0x7f4c0eda,0x7e5402bf,0x26c401f7,0x637c0055}},	// [136d0] rlaq, уває, _mboo_, _dīne, 
   {{0x0d380107,0x637c0055,0x2054004e,0xd01001e2}},	//   взуъ_, _tīnd, _үтүр, حلې_, 
   {{0x26c400e8,0x7f4c0129,0x6b480022,0x00000000}},	//   _oboo_, plaq, hýgu, --, 
   {{0x6f1412eb,0x1ccc0327,0x5f4000d1,0x7e78010f}},	//   chyc, _ྱིམ_, _ئۆرل, _ראָז, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x26c4e253,0x00000000,0x00000000,0x00000000}},	//   _aboo_, --, --, --, 
   {{0x26c400e8,0x00000000,0x00000000,0x00000000}},	//   _bboo_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3eb801ee,0xa5d00142,0x25c800d7,0xa6e00150}},	//   _mcst_, _wỳnf, _čulý_, сжыл, 
   {{0xe6140cb9,0x9ef0031c,0x00000000,0x00000000}},	//   удь_, _པོའྀ_, --, --, 
   {{0xc20804ae,0xd6d4007b,0x6f1400e4,0x00000000}},	//   _צה_, _لتشغ, yhyc, --, 
   {{0x26c402e3,0xa77800c8,0x88bc0118,0xe3c400e8}},	//   _gboo_, _טרעפ, _jměn, ññat_, 
   {{0x35a4e254,0x637c00b0,0xaf040220,0x98a40166}},	//   _салг, _rīne, қпал, lmnı_, 
   {{0x1c001d15,0x04c801c8,0x44240472,0x00000000}},	//   लहाल_, _لوهي_, اریف, --, 
   {{0x637c00b0,0x8544084c,0x6f1403cb,0x844401e2}},	//   _pīne, _тэце, thyc, _پخول, 
   {{0xfe700447,0x00000000,0x00000000,0x00000000}},	//   ەدە_, --, --, --, 
   {{0xee38e255,0xceb403be,0xece880f1,0x637c0171}},	// [136e0] хна_, rgə_, ндал_, _vīne, 
   {{0x98a40006,0xdd8ce256,0x00000000,0x00000000}},	//   monė_, سوم_, --, --, 
   {{0x7f84004b,0x637c0383,0xa25800d8,0x6f14e257}},	//   _پلټن, _tīne, nfôn, phyc, 
   {{0x2fd800ca,0x6e444d66,0x8fd401e0,0x6b4800e4}},	//   _ispg_, _منجم, _йәғә, yýgu, 
   {{0xceb400ac,0x203010e8,0xdbb80166,0x9f5c013a}},	//   rhəd_, _نفیس, _үтсә_, _írán_, 
   {{0x6b480022,0x00000000,0x00000000,0x00000000}},	//   výgu, --, --, --, 
   {{0xfaf800cd,0x92e000cc,0x00000000,0x00000000}},	//   _bhūd_, _দকৈ_, --, --, 
   {{0xe9d8009b,0x6b4800c7,0xd7c40f17,0x00000000}},	//   _пкб_, týgu, اويه_, --, 
   {{0x98a40024,0xc8dc00bc,0xa80400cf,0x00000000}},	//   jonė_, _यसपट, _өзал, --, 
   {{0x88bc0316,0x28ac033f,0x2b44058a,0x6b4800c7}},	//   _změn, _घाटि, looc_, rýgu, 
   {{0x05740184,0x833401c6,0x6b480022,0x00000000}},	//   ыҙҙы_, инох, sýgu, --, 
   {{0x66740597,0x26c4009f,0xd6804a03,0x6b480124}},	//   _إدار, _uboo_, _лушп, pýgu, 
   {{0x7afc0ba1,0x84c4e258,0xa50801ee,0x9754011a}},	//   _òste, _кәнд, _педа_, _עידו_, 
   {{0x290c0784,0x461400ec,0x00000000,0x00000000}},	//   nkfa_, _ٽوڪر, --, --, 
   {{0x7f9401f0,0x00000000,0x00000000,0x00000000}},	//   рабх, --, --, --, 
   {{0x09c0025c,0xdce40e04,0x8d7402f2,0x6f685f32}},	//   _ཀྱྰ_, _vijč, ڕاما, _ﺳﺎﻧﺎ_, 
   {{0xcec000bc,0x00000000,0x00000000,0x00000000}},	// [136f0] ířat_, --, --, --, 
   {{0xb0b0006d,0xbb843738,0xcda81617,0x88bc00bc}},	//   _जाएग, للطي, اهله_, _směn, 
   {{0x3a74e259,0xfaf001e2,0xd0a801f4,0x00000000}},	//   алер, يګر_, _стыд_, --, 
   {{0xe3b404c5,0x443c003a,0x00000000,0x00000000}},	//   _জনাব, _mxv_, --, --, 
   {{0x443c5727,0x00000000,0x00000000,0x00000000}},	//   _lxv_, --, --, --, 
   {{0x06ac00fe,0x29a40124,0xf8b033ae,0x00000000}},	//   ক্মি, рыцҳ, تکر_, --, 
   {{0xa800d7c2,0x9a848f72,0xb8cc00c5,0x48783981}},	//   şınl, _бузл, _कय_, усія_, 
   {{0x88bc012c,0x3704004e,0x35a40124,0x499003c7}},	//   _uměn, рпиг, ааиг, _کیور, 
   {{0x98a4012d,0x00000000,0x00000000,0x00000000}},	//   enną_, --, --, --, 
   {{0x24e40108,0xf9600244,0x00000000,0x00000000}},	//   амьи_, _بۆتێ, --, --, 
   {{0x4968044e,0x443c003a,0x370401d9,0x136801b9}},	//   _ጎረባብ, _cxv_, _پوشِ, лпоқ_, 
   {{0x25b40066,0x23b417ee,0x00000000,0x00000000}},	//   دهید_, _अमरद, --, --, 
   {{0xbbd04540,0x443c007c,0x00000000,0x00000000}},	//   सबुक, _exv_, --, --, 
   {{0x6604049b,0x273800e2,0xd4980395,0xa50400f3}},	//   äkke, mīna_, _чрд_, _веша_, 
   {{0x63f4e25a,0x04b410e0,0x85340133,0x27381c52}},	//   _نفوس_, _الىڭ, _دووچ, līna_, 
   {{0xa0302dfc,0x09c0025c,0xc2c405d9,0x82340a81}},	//   زىقت, _ཀྱྀ_, _هيٺي, _گر٘ا, 
   {{0xd2500050,0xc87803b9,0x6da400be,0x00000000}},	// [13700] _رۆس_, _lağa_, شمام, --, 
   {{0x637c9db5,0x82340a81,0x6b9c010a,0x00000000}},	//   _hīna, _در٘ا, tspg, --, 
   {{0x443ce25b,0x637c0374,0x60c001ed,0x00000000}},	//   _xxv_, _kīna, _önma, --, 
   {{0x7b640014,0x00000000,0x00000000,0x00000000}},	//   مانٕ, --, --, --, 
   {{0x08c857aa,0x2e00016b,0x637c07d7,0x00000000}},	//   лғап_, mɔfo_, _mīna, --, 
   {{0xb2f4031c,0x61f81196,0xc8784dd9,0x637c002b}},	//   _བོའང_, äuli, _bağa_, _līna, 
   {{0xdca028e5,0xa2d40073,0xeb98009d,0x00000000}},	//   _фаси, _बसल्, _шив_, --, 
   {{0x637c166a,0x85b8452c,0xc8782d1c,0x9b0402e8}},	//   _nīna, глис_, _dağa_, _кнсб_, 
   {{0x443c007c,0x00000000,0x00000000,0x00000000}},	//   _sxv_, --, --, --, 
   {{0x3e7c01e1,0x69c00549,0x00000000,0x00000000}},	//   _kátó_, mtoe, --, --, 
   {{0x2e00016b,0x1878010f,0x00000000,0x00000000}},	//   kɔfo_, _סטאב, --, --, 
   {{0x2688e25c,0x69c00421,0x18640063,0x637c00ef}},	//   _شخصي_, otoe, _ђаци_, _cīna, 
   {{0x69c0e25d,0x168404d3,0x273800e2,0x637c00cd}},	//   ntoe, _ئامێ, cīna_, _dīna, 
   {{0x29c007ae,0x69c0e25e,0xc8789f9f,0x00000000}},	//   _mưa_, itoe, _yağa_, --, 
   {{0x753c066d,0x69c0049b,0x29c00208,0xdce4002b}},	//   észe, htoe, _lưa_, _nijā, 
   {{0x69c0e25f,0x2284010b,0x7e74009d,0x88bc0118}},	//   ktoe, _тукг, сгах, _směl, 
   {{0x29c00208,0x00000000,0x00000000,0x00000000}},	// [13710] _nưa_, --, --, --, 
   {{0x69c00942,0xdce400e2,0xc0c00092,0x106c0116}},	//   dtoe, _bijā, ስቆም_, _ﻳﯜﺭﯨ, 
   {{0x69c00d47,0xf09008c3,0x660452fd,0x00000000}},	//   etoe, _מני_, økkj, --, 
   {{0xf7700075,0x69c00b4f,0x5da00014,0xa80043bc}},	//   ۋاب_, ftoe, _وۅزٕ, ğıll, 
   {{0x69c0057b,0x29c001fb,0x4aa82a55,0xc878029f}},	//   gtoe, _cưa_, ркін_, _sağa_, 
   {{0x88bc0316,0x29c0001e,0xfaf80055,0x7d1402d0}},	//   _uměl, _dưa_, _bhūc_, _ulzs, 
   {{0xe9a408c9,0x69c4014a,0xdb68e260,0x69c0002d}},	//   لگەن_, _äken, _арал_, atoe, 
   {{0x98a402e2,0x940406be,0x00000000,0x00000000}},	//   minč_, _genə_, --, --, 
   {{0x69c0215a,0x263c01f2,0xa5840133,0xc8c40073}},	//   ctoe, ịon_, یدیۆ, ल्हट, 
   {{0x273800e2,0xf7940139,0x637c00b8,0x850801ec}},	//   rīna_, _гажэ, _sīna, идың_, 
   {{0x940403be,0x637ce261,0x00000000,0x00000000}},	//   _yenə_, _pīna, --, --, 
   {{0x59b802ab,0x872801b9,0x753c01d3,0xc6940137}},	//   _ईमार, _кўча_, észb, _ۇشۇع, 
   {{0x29c00016,0xdb2000e4,0xeb38008f,0x637c0171}},	//   _xưa_, _ãrõk, רערש, _vīna, 
   {{0xb0600724,0x70b00490,0x2f0c00a2,0xb0b0033f}},	//   şämb, जलेल, _iýgi_, _जाओग, 
   {{0x09d406e3,0xb4c402ab,0x2334013e,0x69c001c4}},	//   _धन्य, ॉजी_, рхӯр, ztoe, 
   {{0x69c0e262,0x98a4007f,0xdcec0055,0x69300210}},	//   ytoe, dinč_, _rucā, płeg, 
   {{0x2e00013b,0x6da48edf,0xada40116,0xdcec0055}},	// [13720] rɔfo_, сиза, сазл, _sucā, 
   {{0xfca80244,0x00000000,0x00000000,0x00000000}},	//   لامو_, --, --, --, 
   {{0x69c0010a,0x29c0004d,0x2f0c02d2,0x00000000}},	//   wtoe, _sưa_, _lýgi_, --, 
   {{0xeff4044e,0xdce400dc,0xdcec00ef,0x00000000}},	//   ገነይ_, _vijā, _vucā, --, 
   {{0xa8000ac1,0x69c0e263,0x3178010f,0x6b580150}},	//   ğıml, utoe, נאַד, _ұшар_, 
   {{0x69c0e264,0xd9400b32,0xa80003ee,0xdd8c00c6}},	//   rtoe, печи, şıml, _سوف_, 
   {{0x69c0e265,0x6d4c0003,0x98a00640,0x00000000}},	//   stoe, _ikba, чије, --, 
   {{0xdc3400c8,0x69c00b4f,0x6f040010,0xd7f40408}},	//   _האלט_, ptoe, _jokc, суш_, 
   {{0x6f04030a,0x7afc00a3,0x3cec0073,0x00000000}},	//   _mokc, _òsta, घाचे_, --, 
   {{0x6f0403f9,0x18a000f0,0x00000000,0x00000000}},	//   _lokc, _наум, --, --, 
   {{0x06e00f22,0xd90c01ed,0x6f040857,0x937400b1}},	//   ভাবি, _سیٹ_, _ookc, йбэт_, 
   {{0x18640224,0xe2a81410,0x00000000,0x00000000}},	//   _уахи_, دادن_, --, --, 
   {{0xdcec084c,0x6d4c0399,0x67540214,0x628c002f}},	//   _jucă, _okba, _پیکس_, rbco, 
   {{0x88bc0118,0xdfd80395,0x00000000,0x00000000}},	//   _směj, лъб_, --, --, 
   {{0x4ac812eb,0x6f04e266,0x00000000,0x00000000}},	//   रभाव, _bokc, --, --, 
   {{0x6d4ce267,0x637c1d86,0xe2a800e5,0x246c03e3}},	//   _akba, _hīno, _صابن_, məm_, 
   {{0x246c00ac,0x660403b2,0x00000000,0x00000000}},	// [13730] ləm_, økkh, --, --, 
   {{0xe29c26b8,0x00a00133,0x8c0000cc,0x00000000}},	//   lað_, _زیرێ, _এইজন_, --, 
   {{0x2ee005ac,0x246c00ac,0x92dc0183,0xebc00075}},	//   _fakf_, nəm_, ঠাৰ_, мәтн, 
   {{0xe29c19cf,0xdcec0276,0x6d4c0115,0x6f0403e0}},	//   nað_, _bucă, _ekba, _gokc, 
   {{0x99d40597,0x9e6404fb,0x69c40432,0x38540023}},	//   إتصا, _دادن, _äkel, _ምቕራብ, 
   {{0xdb20e268,0x88c802bf,0xe69000d1,0x246c03e3}},	//   _کوری, йлів_, ۈلىد, kəm_, 
   {{0xe29c1bb0,0x88c48ce2,0x4c94e269,0x88bc0118}},	//   kað_, ستول, _хисс, _změk, 
   {{0x7bc4e26a,0xe29c05f7,0x69dc00b0,0xfd500241}},	//   mthu, jað_, āper, _nikẹ, 
   {{0xe5744855,0x46541b49,0x6d4c00ee,0xe29c0ad9}},	//   озы_, _ምስጢራ, _ykba, dað_, 
   {{0x7988e26b,0xe61402dc,0x7bc4e26c,0xb3c80022}},	//   _itew, юды_, othu, алоз_, 
   {{0x7bc4e26d,0xe29c008c,0x6444e26e,0x97a401ee}},	//   nthu, fað_, şkin, _ырал, 
   {{0xe29c2833,0x7bc4e26f,0x32b8007b,0x00000000}},	//   gað_, ithu, جددة_, --, 
   {{0x7bc4e270,0x00000000,0x00000000,0x00000000}},	//   hthu, --, --, --, 
   {{0x7bc4713c,0xd564e271,0x246c03b9,0x00000000}},	//   kthu, _утеп, bəm_, --, 
   {{0x6f0405b1,0x246c0213,0x836407d6,0xe4e02a67}},	//   _pokc, cəm_, تدیل, _कोटि_, 
   {{0xae880124,0x7988127b,0x00000000,0x00000000}},	//   рбаз_, _otew, --, --, 
   {{0x30744009,0x7bc4015d,0x312400db,0x00000000}},	// [13740] _мунс, ethu, _мдиг, --, 
   {{0x27141161,0xf0e804a9,0x7bc40623,0xdcec054e}},	//   _तत्र_, _ئىدى_, fthu, _rucă, 
   {{0x7988e272,0x7bc4aac6,0x6f04e273,0xdcec00de}},	//   _atew, gthu, _tokc, _atcē, 
   {{0xa80003ee,0xb064023a,0xeeb80116,0x7dd000e4}},	//   şıkl, _enää, _өлүш_, _ẽsev, 
   {{0x7bc406a3,0xa968022e,0x29d8009d,0x00000000}},	//   athu, аида_, рьеэ_, --, 
   {{0x6d4c0198,0x246c00ac,0x2bd05b82,0xa8500352}},	//   _ukba, yəm_, _सहपा, мелә, 
   {{0x798804ba,0x7bc49567,0x00000000,0x00000000}},	//   _etew, cthu, --, --, 
   {{0xc6f8e20b,0xaa440f5c,0xdc200154,0xed3400e5}},	//   сних_, _дебл, _বুকস_, _اوڑھ, 
   {{0xe29c1bb0,0xb0c8551c,0xf8ac04d3,0x637c02b5}},	//   vað_, िभाग, _ڵکو_, _pīno, 
   {{0x4cd80183,0x2508022e,0x25b40014,0xd544009a}},	//   ঠাকু, рхио_, ٕنکھ_, يليو_, 
   {{0xe29c1c38,0x26f8004b,0x361801b9,0x637c00de}},	//   tað_, _پراخ_, لریگ_, _vīno, 
   {{0x246c0cc1,0x798802d0,0x00000000,0x00000000}},	//   rəm_, _ytew, --, --, 
   {{0xe29c05a4,0x518466b5,0x246c0213,0x249c007f}},	//   rað_, дуса, səm_, patm_, 
   {{0xe29c1f60,0x7bc40368,0x25a401f5,0x00000000}},	//   sað_, ythu, _ivol_, --, 
   {{0xbbc802f8,0xe29c09cc,0x7bc401e6,0x246c0213}},	//   _रहेक, pað_, xthu, qəm_, 
   {{0x06ac00bd,0x934400f3,0x00000000,0x00000000}},	//   ক্রি, _онје, --, --, 
   {{0xd20805f5,0x7bc406a3,0x865402d3,0xfaf800b8}},	// [13750] _дээд_, wthu, _ምትእስ, _bhūn_, 
   {{0xa3ac0892,0xdc88e274,0x00000000,0x00000000}},	//   _ओटा_, рсал_, --, --, 
   {{0x7bc4e275,0x9b68036b,0xdfd802e8,0x5b1000f1}},	//   uthu, ашда_, _тъп_, وګرځ, 
   {{0x4cd8009e,0x52d8010f,0x00000000,0x00000000}},	//   ঠাগু, ַווע_, --, --, 
   {{0xe1fc00db,0x00000000,0x00000000,0x00000000}},	//   nxó_, --, --, --, 
   {{0x0904177b,0xcff400a2,0x7bc40051,0xdce40210}},	//   мпін, _üşäp_, pthu, _biją, 
   {{0x80cc0b7c,0x38540b82,0x2bd012eb,0x04180055}},	//   द्ये, _ምዕራብ, _सहया, _tūṇa, 
   {{0xab6008b0,0xb6a40276,0x7ac85285,0x00000000}},	//   _كۇلى, чиил, _دورِ_, --, 
   {{0x644441d5,0x7988e276,0x00000000,0x00000000}},	//   şkil, _utew, --, --, 
   {{0x58b81f3c,0xe574e277,0x06ac04c5,0x26c8016b}},	//   _خارج_, язь_, ক্লি, ɑbom_, 
   {{0x97000075,0x76747830,0x1780036b,0x98a400cd}},	//   _يېتى, _елеф, _ўқиг, cinā_, 
   {{0x070800aa,0x81d4009e,0x27f800d4,0x00000000}},	//   _ويلي_, সটন_, åpne_, --, 
   {{0x21a00b32,0x2bd01af8,0x7768011f,0xa1900006}},	//   ниям, _सहभा, mmex, наўч, 
   {{0x321c012d,0x00000000,0x00000000,0x00000000}},	//   ąty_, --, --, --, 
   {{0x6140404b,0x25a4013a,0x00000000,0x00000000}},	//   хера, _zvol_, --, --, 
   {{0x77680789,0x37bc0154,0x98a40064,0x00000000}},	//   nmex, _আনার, konį_, --, 
   {{0x2ca80137,0x0d0801ec,0x00000000,0x00000000}},	// [13760] йкап_, одақ_, --, --, 
   {{0xf4281b4b,0xad580153,0x1e8001c6,0x00000000}},	//   _སྟོད_, ёрах_, _үлэм, --, 
   {{0xceb403b9,0x6b74009f,0x00000000,0x00000000}},	//   lhəm_, سطاط, --, --, 
   {{0x63bc00d6,0x70740214,0x6438010f,0x00000000}},	//   _åpne, _واگذ, זעענ, --, 
   {{0x3eac0086,0x9aa01eeb,0x02c02e35,0x98a400c0}},	//   _ôeta_, رموو, ष्टभ, gonį_, 
   {{0x6f141155,0xdce40210,0x00000000,0x00000000}},	//   lkyc, _piją, --, --, 
   {{0xd7f40572,0x0cd8000d,0x00000000,0x00000000}},	//   зуы_, ड़ीम, --, --, 
   {{0x1ae0e278,0x753c01ed,0x6f14e279,0xf544007c}},	//   _посм, észn, nkyc, åång_, 
   {{0x6aa0e27a,0xe1fc0548,0xa92407d5,0x7d0c0241}},	//   maof, xxó_, _едал, _ànsé, 
   {{0x47d400bd,0x6aa0e27b,0x64440790,0x00000000}},	//   থিবী, laof, şkim, --, 
   {{0x4ae00490,0x6f1400b5,0xa6c80798,0x00000000}},	//   _नसाव, kkyc, _глеа_, --, 
   {{0xf6e400d6,0x6aa0e27c,0x92940006,0x57f8011a}},	//   _оцін, naof, наюц, _ללבו, 
   {{0x9f44020c,0x25a4022e,0x00000000,0x00000000}},	//   _éné_, _uvol_, --, --, 
   {{0x98a4084c,0x6aa01132,0xdc000216,0x66040162}},	//   mină_, haof, _sčít, økku, 
   {{0x6aa0e27d,0x98a40311,0x00000000,0x00000000}},	//   kaof, lină_, --, --, 
   {{0x63b8e27e,0x6aa006d9,0x88d400b8,0x41b45ee9}},	//   mutn, jaof, _hṛdg, _قمبر, 
   {{0x6aa006ed,0x98a40311,0x3f8401e4,0xdc0000d7}},	// [13770] daof, nină_, ƭluo_, _včít, 
   {{0xf1b00034,0x13a40244,0x00000000,0x00000000}},	//   _जितन, _بۆێی_, --, --, 
   {{0x6aa072dc,0x98a40356,0x88d400b8,0x00000000}},	//   faof, hină_, _mṛdg, --, 
   {{0x6aa00e39,0x6f140f91,0xdc0002f0,0x77680175}},	//   gaof, ckyc, _učít, xmex, 
   {{0x4a747196,0x629c00fb,0x63b80122,0xca740220}},	//   нышт, _meqo, hutn, нушы, 
   {{0x63b856e4,0x629ce27f,0x98a450bb,0x77680175}},	//   kutn, _leqo, dină_, wmex, 
   {{0x6aa00109,0x67d00261,0x26e40154,0x63b8e280}},	//   baof, воју, কানো_, jutn, 
   {{0x629ce281,0x63b8003e,0x9f48007f,0xdac400d1}},	//   _neqo, dutn, òmèt_, _رېتى_, 
   {{0x98a4084c,0x3dc8e282,0x63b80098,0xcec00118}},	//   gină_, ntaw_, eutn, ířit_, 
   {{0x6f1400d0,0xf4280327,0x00000000,0x00000000}},	//   zkyc, _སྟུད_, --, --, 
   {{0x629c0944,0xe3b400a8,0x58840022,0xb46400d4}},	//   _beqo, мбэ_, _дыҵа, ькол, 
   {{0x3dc8e283,0x2e00013f,0x98a4054e,0x25b00205}},	//   ktaw_, sɔfi_, bină_, ünlü_, 
   {{0x98a40276,0x60140793,0x3dc80327,0x00000000}},	//   cină_, yümö, jtaw_, --, 
   {{0x63b8e284,0x7bd401f5,0x6da00311,0x05640153}},	//   butn, _opzu, nţaţ, _звін, 
   {{0x80cc0c00,0x06e000bd,0x63b805b1,0x6f140030}},	//   द्धे, ভারি, cutn, tkyc, 
   {{0x9f5c0ca8,0x00000000,0x00000000,0x00000000}},	//   _ìrìn_, --, --, --, 
   {{0x6aa0e285,0xee38e286,0xdcec05d1,0x307800c6}},	// [13780] vaof, цна_, _avcı, _وحدة_, 
   {{0xfe702832,0x5d6407ca,0x6f14e287,0x80cc06ff}},	//   ادِ_, диум_, skyc, द्दे, 
   {{0x6f64e288,0x6aa054bb,0x98a4054e,0x629ce289}},	//   _овоз, taof, zină_, _yeqo, 
   {{0x7c64e28a,0xddc8e28b,0x1e8030c7,0x00000000}},	//   رالل, žišk, _илюм, --, 
   {{0x3dc80784,0x2ba81fe5,0x6aa0e28c,0xad6800c7}},	//   ctaw_, _चटका, raof, _мамз_, 
   {{0x98a40276,0x6aa00607,0xeb982b97,0x273800e2}},	//   vină_, saof, _миг_, mīni_, 
   {{0x6aa00421,0x637c00ef,0x3cf00419,0x00000000}},	//   paof, _vīnk, ťovú_, --, 
   {{0x637c02b1,0x98a40311,0x2d9004ba,0x77909831}},	//   _hūng, tină_, opye_, اینا, 
   {{0x637c00b0,0x2d90033b,0x629c0139,0x5ea80154}},	//   _kūng, npye_, _reqo, ঙ্কে, 
   {{0x63b8e28d,0x98a40311,0x629ce28e,0x26c0033f}},	//   tutn, rină_, _seqo, żko_, 
   {{0x18a01845,0x291c02f6,0x629c014f,0x27387bc9}},	//   _рахм, _ilta_, _peqo, hīni_, 
   {{0x63b83223,0x3dc8011f,0xb74400cf,0x98a40356}},	//   rutn, ytaw_, _كئنو, pină_, 
   {{0x63b81326,0xfaf80055,0xceb40213,0x6b8c0142}},	//   sutn, _bhūj_, kkəb_, _ltbg, 
   {{0x629c01e2,0x637c005f,0x2fc80175,0xe3d00137}},	//   _weqo, _līni, ftbg_, _айкө, 
   {{0x629c0194,0x63b8e28f,0x6b8c0327,0x543001e2}},	//   _teqo, qutn, _ntbg, _ټرور, 
   {{0x3dc8003d,0xdb140005,0x98a43ee4,0xc43401d9}},	//   ttaw_, puxé, miną_, _ٲکھت, 
   {{0x68f8e290,0x98a47502,0x93140014,0x291ce291}},	// [13790] _ontd, liną_, _شوٝش, _olta_, 
   {{0xe1647a3f,0x3dc8e292,0x00000000,0x00000000}},	//   _تدبي, rtaw_, --, --, 
   {{0x3dc84812,0x68e807a8,0x5ea8015b,0x98a44f7e}},	//   staw_, ddfd, ঙ্গে, niną_, 
   {{0x68f80051,0x637c0171,0xd1540240,0x40940066}},	//   _antd, _cīni, _ሃብታው, _تلگر, 
   {{0x3f80e293,0x8d840124,0x7e7c03ac,0x273800b8}},	//   _huhu_, _аусд, _igsp, cīni_, 
   {{0x3f80e294,0xf1b00034,0x52dc01ad,0x98a40153}},	//   _kuhu_, _जिसन, _बस्स, kiną_, 
   {{0x3f80e295,0x81d40154,0x6da00356,0x4c6801c6}},	//   _juhu_, সটি_, rţaţ, _жиён_, 
   {{0x291ce296,0x68f8101d,0x3f80e297,0x98a400c0}},	//   _elta_, _entd, _muhu_, diną_, 
   {{0xb9b4ca3e,0xd6c0009e,0x7ae80142,0x00000000}},	//   _سماع, ্যলয, _iaet, --, 
   {{0x7ae8e298,0x81d40154,0xd7f8014b,0x00000000}},	//   _haet, সটা_, _муе_, --, 
   {{0x3f808e2d,0x7ae8e299,0x4584009d,0x98a400c0}},	//   _nuhu_, _kaet, нгөв, giną_, 
   {{0x78a0e29a,0xe294e29b,0x7ae802f6,0xa80005d1}},	//   _helv, наю_, _jaet, ğıtl, 
   {{0x78a0e29c,0x3f800418,0x7ae8e29d,0xa0640588}},	//   _kelv, _auhu_, _maet, ҵара_, 
   {{0x7ae8e29e,0x3f8003f9,0xafe4e29f,0x04c801c8}},	//   _laet, _buhu_, ногл, _يوني_, 
   {{0x7ae801e0,0x6a7403ee,0xf1b013f7,0x25180a7c}},	//   _oaet, _küfü, _जिवन, _מוסא, 
   {{0xdee0e2a0,0x77780054,0xe45400c8,0x7ae80c3a}},	//   лоси, _jiwx, _איצט_, _naet, 
   {{0x637c04fe,0x83688d1a,0xf8a48a54,0x6b8c0175}},	// [137a0] _pūng, _تصوف_, _پک_, _stbg, 
   {{0x3f801132,0x78a00fac,0x765803cb,0xefe00092}},	//   _fuhu_, _nelv, _mywy, ነሣው_, 
   {{0x7ae80bc8,0x26e4009e,0x7658015d,0x2d90007f}},	//   _baet, কাতো_, _lywy, spye_, 
   {{0x7ae8e2a1,0x291ce2a2,0x2d900660,0x9b9001b9}},	//   _caet, _slta_, ppye_, النت, 
   {{0x637ce2a3,0x7ae800a9,0x78a0e2a4,0x2bd01f13}},	//   _tūng, _daet, _belv, _सहवा, 
   {{0x637c02b5,0x78a0009f,0x7ae8005a,0x3f80e2a5}},	//   _hūne, _celv, _eaet, _yuhu_, 
   {{0x9d40e2a6,0x2d80e2a7,0x637ce2a8,0x7ae80042}},	//   _серд, _huke_, _tīni, _faet, 
   {{0x2d80e2a9,0x76580cfd,0x78a000c5,0x1764010b}},	//   _kuke_, _bywy, _eelv, нрып_, 
   {{0xa848144b,0x78a000dd,0x25a800c6,0xb864315b}},	//   _کلام_, _felv, أدبي_, _یامو, 
   {{0x3c24152d,0x2d80e2aa,0x291ce2ab,0x78a0e2ac}},	//   _vзvv_, _muke_, _ulta_, _gelv, 
   {{0x7ae80098,0x2d800e21,0x1d380092,0x00000000}},	//   _yaet, _luke_, _በየአመ, --, 
   {{0xd48ce2ad,0x78a0e2ae,0x2d800618,0x765800a9}},	//   _әр_, _zelv, _ouke_, _fywy, 
   {{0xd244e2af,0x9268e2b0,0x637c002d,0x7658015d}},	//   гэри, ерра_, _sūnd, _gywy, 
   {{0xba08a38c,0x3f80e2b1,0x1ee4350a,0x98a40153}},	//   _ወደ_, _puhu_, کوری_, piną_, 
   {{0x2d80e2b2,0xf07800d1,0x00000000,0x00000000}},	//   _auke_, дирә_, --, --, 
   {{0x2d80e2b3,0x94d001ec,0x00000000,0x00000000}},	//   _buke_, _ليۇش, --, --, 
   {{0x7ae8e2b4,0x2d8005be,0xe7e00034,0x3f800134}},	// [137b0] _raet, _cuke_, _कैसा_, _wuhu_, 
   {{0x7ae8e2b5,0x2d80b441,0x3f80e2b6,0x273800e2}},	//   _saet, _duke_, _tuhu_, mīnu_, 
   {{0x7ae80053,0x78a000af,0x00000000,0x00000000}},	//   _paet, _relv, --, --, 
   {{0x78a0e2b7,0x26c401d4,0x2d808e31,0x80cc06ff}},	//   _selv, _ncoo_, _fuke_, द्रे, 
   {{0x2d8007a8,0x7ae81140,0x19e8212d,0x753c01d3}},	//   _guke_, _vaet, ثراً_, észk, 
   {{0x88bc012c,0x7ae8e2b8,0x78a0014f,0x6e3c01f3}},	//   _směr, _waet, _qelv, _ተመጣጣ, 
   {{0x7ae8e2b9,0x9e6401ec,0x6a740205,0x00000000}},	//   _taet, _زاڭن, _püfü, --, 
   {{0xf77096b4,0x26c45cca,0x78a01af3,0x00000000}},	//   جات_, _ccoo_, _welv, --, 
   {{0xab600058,0x78a0e2ba,0x850c02a0,0x637ce2bb}},	//   _ئۇنى, _telv, ाउंट_, _mīnu, 
   {{0x26c4011c,0x34bc00cd,0x00000000,0x00000000}},	//   _ecoo_, ्भेद, --, --, 
   {{0xecc41d72,0xa8001d89,0xb6d40133,0x88940354}},	//   र्टफ, şırl, _لقاع, _сихх, 
   {{0x765800a9,0x35b46c9a,0xa25805ac,0xe72c0063}},	//   _tywy, _абдр, vfôr, _ђе_, 
   {{0xe60c58f0,0xe56c003b,0x00000000,0x00000000}},	//   _тд_, _вз_, --, --, 
   {{0x2d8004b9,0x2bd005f9,0x33f40354,0x637c00c0}},	//   _ruke_, _सहला, _ачис, _sūne, 
   {{0x2d804437,0x637c02b5,0x73e40a93,0xa0a000ee}},	//   _suke_, _pūne, _ройз, расд, 
   {{0x2d80e2bc,0xafe401b9,0x273800ef,0x00000000}},	//   _puke_, ноҳл, bīnu_, --, 
   {{0x1e80016c,0xa25805da,0xc90006be,0xdee000ea}},	// [137c0] рлум, sfôr, _etmә, шоти, 
   {{0x2d800286,0xe7e000c5,0x66040821,0x00000000}},	//   _vuke_, _कईला_, äkki, --, 
   {{0xa258145e,0x7c280198,0xc87800fd,0x00000000}},	//   ngôn, _ƙera, _yağu_, --, 
   {{0x2d80e2bd,0x98a43ee4,0x00000000,0x00000000}},	//   _tuke_, minę_, --, --, 
   {{0x98a46dd2,0x00000000,0x00000000,0x00000000}},	//   linę_, --, --, --, 
   {{0xd6c00154,0xc7b0072d,0x00000000,0x00000000}},	//   ্যোপ, مّت_, --, --, 
   {{0x26c40ecf,0x98a40006,0xd7c402f2,0x779033ae}},	//   _pcoo_, ninę_, نووه_, میلا, 
   {{0x6d5cb183,0x44200618,0x2fd805b1,0xca740014}},	//   llpa, _āi_, _mppg_, _منزک, 
   {{0xcfc800fe,0x00000000,0x00000000,0x00000000}},	//   শবিন, --, --, --, 
   {{0xa80003be,0x2fd803cd,0x98a40024,0x00000000}},	//   şıql, _oppg_, kinę_, --, 
   {{0x3948056a,0x98a400c0,0xa85400f3,0x00000000}},	//   éase_, jinę_, _ртај, --, 
   {{0x98a40024,0xe6180063,0xc8780166,0x6d5c002f}},	//   dinę_, _оде_, _qağu_, hlpa, 
   {{0x6720e2be,0x2b440030,0x84c401e0,0x00000000}},	//   _iloj, čoch_, _йәнд, --, 
   {{0x6d5c257d,0x395801c7,0x672000ef,0x98a40153}},	//   jlpa, _ësst_, _hloj, finę_, 
   {{0x98a40024,0x67204a38,0x7f8401b9,0xb0d007b7}},	//   ginę_, _kloj, الرن, द्धग, 
   {{0x20040137,0x6d5ce2bf,0x273800e2,0xb478010f}},	//   _ànim_, elpa, mīns_, _אָפי, 
   {{0x57bc000d,0x637c0171,0x00000000,0x00000000}},	// [137d0] _एम्ह, _vīnu, --, --, 
   {{0x6720e2c0,0x98a47063,0xdb140077,0xe5ac07d2}},	//   _lloj, binę_, ruxí, _ﺳﻪﻟﻜ, 
   {{0x0fe454a2,0x2fd80334,0x98a40024,0xe7e002e5}},	//   _көтү, _gppg_, cinę_, _कैला_, 
   {{0x6d5c127b,0xceb406be,0x00000000,0x00000000}},	//   alpa, lkən_, --, --, 
   {{0x3ea8e2c1,0x6eb80375,0x63b8022e,0x00000000}},	//   maat_, _אזרח, hrtn, --, 
   {{0x3ea8e2c2,0x6720e2c3,0xceb406be,0x00000000}},	//   laat_, _aloj, nkən_, --, 
   {{0x2244016b,0x00000000,0x00000000,0x00000000}},	//   _ɛnka_, --, --, --, 
   {{0x3ea8e2c4,0xf5e81d0f,0x765c03e0,0x00000000}},	//   naat_, емил_, üsyo, --, 
   {{0x3ea820ac,0x656801e7,0x98c45aae,0x98a46dd3}},	//   iaat_, _bhfh, _асел, zinę_, 
   {{0x3ea8e2c5,0x499001ed,0x74e8009d,0x273800ef}},	//   haat_, _بیور, хдог_, fīns_, 
   {{0x3ea8e2c6,0x6720e2c7,0x656800a3,0x69c40139}},	//   kaat_, _floj, _dhfh, _äker, 
   {{0x3ea8e2c8,0x212c063f,0x98a40024,0xd6a80066}},	//   jaat_, _įgha_, vinę_, _آدام_, 
   {{0x63b8e2c9,0xba3c00bc,0x6d5c25d7,0xc32c00f7}},	//   artn, _zdůr, ylpa, بەي_, 
   {{0x98a402d5,0x672001fa,0x629803b2,0xceb406be}},	//   tinę_, _zloj, ðuor, hhət_, 
   {{0x3ea8e2ca,0x7054023f,0x6020151e,0x63b8107d}},	//   faat_, انزا, бдра, crtn, 
   {{0x3ea8e2cb,0x28d806ab,0x98a40006,0x14cc08a3}},	//   gaat_, _मॉनि, rinę_, त्रण, 
   {{0x98a40024,0xbda400c6,0x00000000,0x00000000}},	// [137e0] sinę_, لحلو, --, --, 
   {{0x2290107f,0x98a40153,0xefcc0023,0xad2400d1}},	//   _پلیس, pinę_, ብለይ_, دىئى, 
   {{0xeb98e2cc,0x3ea8e2cd,0x6da4016c,0x637c0024}},	//   хие_, baat_, тиҷа, _kūna, 
   {{0x3ea8e2ce,0x273806c8,0x60d800f3,0xa038010f}},	//   caat_, kūna_, đume, _טעיפ, 
   {{0x99d00597,0x00000000,0x00000000,0x00000000}},	//   متوا, --, --, --, 
   {{0x637c002b,0x63b80076,0x2054004e,0x00000000}},	//   _lūna, yrtn, _штөр, --, 
   {{0x6720e2cf,0xdc6400c0,0xfc04004e,0x786c0022}},	//   _ploj, _бард_, _корү, võvé, 
   {{0xc6f8e2d0,0x63b801a6,0x779004fb,0x637c00dc}},	//   тних_, vrtn, زیها, _nūna, 
   {{0x98a40118,0x67200200,0x394801e7,0x26e400eb}},	//   nině_, _vloj, éasc_, কালো_, 
   {{0x295406bb,0x69c000fb,0x03f80640,0xab600131}},	//   _събр, muoe, вној_, _ئۇچى, 
   {{0x3ea8e2d1,0x69c00368,0x37f4004b,0x637c0153}},	//   yaat_, luoe, _پينځ, _būna, 
   {{0x67200115,0xe5a4e2d2,0x65680175,0x27380024}},	//   _uloj, _биди, _whfh, būna_, 
   {{0xa5940c04,0x3ea8e2d3,0x98a40118,0x00000000}},	//   _срещ, vaat_, jině_, --, 
   {{0x98a4012c,0x63b801a6,0x9690013d,0x3ea80694}},	//   dině_, prtn, _крәш, waat_, 
   {{0x3ea8e2d4,0xceb403be,0x00000000,0x00000000}},	//   taat_, rkən_, --, --, 
   {{0x69c001af,0x644405d1,0x3ea80194,0x93f80375}},	//   kuoe, şkis, uaat_, _טלוי, 
   {{0x3ea8e2d5,0x1af000fe,0x91e40114,0xdcb803c5}},	// [137f0] raat_, _অকলে_, _гоње, еще_, 
   {{0x3ea8e2d6,0x628c009b,0x69c001bf,0x717400f2}},	//   saat_, lcco, duoe, _پهپا, 
   {{0x3ea8e2d7,0x3ce0000d,0xbed40a5b,0x00000000}},	//   paat_, rehv_, _конј, --, 
   {{0x3ea80eda,0x3b54e2d8,0x628c0113,0xec78074d}},	//   qaat_, шкер, ncco, ĕпе_, 
   {{0x18b00184,0x98a401ef,0x00000000,0x00000000}},	//   йҙар, cině_, --, --, 
   {{0x2fd0006a,0x60c40007,0x00000000,0x00000000}},	//   _ângû_, ngjm, --, --, 
   {{0xf770bf41,0xfaf800dc,0x99d000ec,0xc83c0240}},	//   ياب_, _bhūt_, _ڇڪتا, _ክንከላ, 
   {{0x37740166,0x00000000,0x00000000,0x00000000}},	//   шылс, --, --, --, 
   {{0x442c00d0,0x00000000,0x00000000,0x00000000}},	//   ezd_, --, --, --, 
   {{0x637c04fe,0x95c8010b,0x49740153,0x00000000}},	//   _rūna, _җуда_, _глус, --, 
   {{0x612800dd,0x06e0009e,0x637ce2d9,0x49040145}},	//   _külf, ভাজি, _sūna, _دولق, 
   {{0x637c2bae,0x86c4038b,0x6c5408a8,0xc1680375}},	//   _pūna, _هيمن, ייתא_, _חח_, 
   {{0x442c033f,0xf504399b,0x35a4e2da,0x6444002f}},	//   azd_, _взло, _талг, ßkir, 
   {{0x413c0020,0x628c8eed,0x98a4012c,0xa0a08660}},	//   _አቅርቦ, acco, vině_, жард, 
   {{0xd348591c,0x3d085ae4,0x6140e2db,0x00000000}},	//   _میده_, साने_, цера, --, 
   {{0x98a400bc,0xe3d80022,0x637c0064,0x8cd82314}},	//   tině_, _рышә_, _tūna, न्नो, 
  
   {{0xed580b3e,0x32600014,0xacc80818,0x00000000}},	// [13800] воа_, _گچھہ, кгаз_, --, 
   {{0x98a40139,0xabf4011c,0x00000000,0x00000000}},	//   klnı_, ичещ, --, --, 
   {{0xfd980075,0x32600014,0x409401af,0x81cc00eb}},	//   نئەت_, _دچھہ, _урыт, রবণ_, 
   {{0x98a400bc,0xb0d036c3,0x612806be,0x00000000}},	//   pině_, द्रग, _cülf, --, 
   {{0x2bd04a01,0x27280016,0x89d81ec7,0x00000000}},	//   _सहका, _hùng_, اوتر_, --, 
   {{0xfaf800b8,0x00000000,0x00000000,0x00000000}},	//   _bhūs_, --, --, --, 
   {{0xceb40213,0xa13c0023,0x3948e2dc,0xf8a801f7}},	//   hkəm_, _ኣብሪሆ, éasa_, ادهه_, 
   {{0x2728004d,0x61280205,0x00000000,0x00000000}},	//   _mùng_, _gülf, --, --, 
   {{0x2728e2dd,0x636c07c5,0x28e8010b,0xa50400ee}},	//   _lùng_, lùng, _идап_, аянл, 
   {{0x3d089543,0x61281cce,0x2b441155,0x00000000}},	//   साये_, _zülf, lnoc_, --, 
   {{0xb0a80034,0x38680198,0x612800c5,0x8cd80303}},	//   करनग, ƙara_, _hülg, न्यो, 
   {{0x612800af,0x628c0ffb,0x2b4405c7,0x26c000e5}},	//   _külg, ucco, nnoc_, ókod_, 
   {{0x667400cf,0x442c01d3,0xd624e2de,0x6128010b}},	//   _ئدار, szd_, _коце_, _jülg, 
   {{0x628c4f3b,0x442c010a,0x272801fb,0x753c01ed}},	//   scco, pzd_, _bùng_, észt, 
   {{0x272801dc,0xd01869a4,0x035400ee,0xa2cc00bc}},	//   _cùng_, афт_, _гүнә_, _थाप्, 
   {{0x272801dc,0x54780375,0xd4780375,0x9390007b}},	//   _dùng_, _בטוו, _באול, _بجوا, 
   {{0x637c00b0,0xdce86075,0x61280254,0x3cb4e2df}},	// [13810] _hūno, šičk, _nülg, ййар, 
   {{0x637c06c8,0x356c00b7,0x2b44030a,0x3f8401d3}},	//   _kūno, _ስቴትስ_, enoc_, ílus_, 
   {{0x925801d3,0x27380153,0x00000000,0x00000000}},	//   _مشیر_, jūno_, --, --, 
   {{0x6128013d,0xb478008f,0x2b440165,0x3a7421b4}},	//   _bülg, אָני, gnoc_, блер, 
   {{0xfaf8002b,0x00000000,0x00000000,0x00000000}},	//   _bhūr_, --, --, --, 
   {{0x6128e2e0,0x88c800d4,0x27380064,0x49b800ae}},	//   _dülg, илів_, fūno_, شاهد_, 
   {{0xfaf80055,0x249c0175,0x27380153,0x00000000}},	//   _dhūr_, dbtm_, gūno_, --, 
   {{0x7bc43e36,0x6f2c01e1,0x290808c2,0xdb20e2e1}},	//   muhu, _kíkọ, _òban_, _بوری, 
   {{0x6128e2e2,0x7bc4e2e3,0xd8e403c5,0x00000000}},	//   _küld, luhu, _вцеп, --, 
   {{0x7afc0162,0x7d14072d,0x00000000,0x00000000}},	//   _óstb, _jozs, --, --, 
   {{0x7988e2e4,0x7bc4e2e5,0x798000aa,0xe7940ee8}},	//   _huew, nuhu, _iilw, _هانک, 
   {{0x7980e2e6,0x7d140399,0xd58404d3,0x272801fb}},	//   _hilw, _lozs, _پێده_, _rùng_, 
   {{0x7bc4e2e7,0x753c066d,0x7980e2e8,0xc5880016}},	//   huhu, észs, _kilw, _hồn_, 
   {{0x7980950b,0x66044606,0x05640064,0xa504011c}},	//   _jilw, åkke, _двін, _геша_, 
   {{0x7980e2e9,0x8838044e,0x798804e6,0x5f50001f}},	//   _milw, _እንተተ, _luew, _መኖራቸ, 
   {{0x79802784,0x27280016,0xc5880051,0x37b800fe}},	//   _lilw, _vùng_, _mồn_, _আহাৰ, 
   {{0x7d14e2ea,0x3f84022c,0xc58801fb,0xd34804fb}},	// [13820] _bozs, ílur_, _lồn_, _میگه_, 
   {{0x79800921,0x27280016,0x7bc40083,0xb7f801ad}},	//   _nilw, _tùng_, fuhu, ्माम_, 
   {{0x7bc4e2eb,0x7d140007,0x61287bbc,0xa2cc2d2c}},	//   guhu, _dozs, _düld, _थाम्, 
   {{0x7980e2ec,0xf95800e5,0x00000000,0x00000000}},	//   _ailw, یسوں_, --, --, 
   {{0x7980e2ed,0x2b44e2ee,0x6a8400c7,0xd1380023}},	//   _bilw, rnoc_, алҵа, _ኣእታው, 
   {{0x7980002e,0x7bc4e2ef,0xc58801fb,0x6128574b}},	//   _cilw, buhu, _bồn_, _güld, 
   {{0x7980e2f0,0xdca0e2f1,0xe3c81bce,0xc58801fb}},	//   _dilw, _хаси, _meññ_, _cồn_, 
   {{0x63bc00d6,0x798801c7,0xc58801fb,0x7980115d}},	//   _åpni, _fuew, _dồn_, _eilw, 
   {{0x7980e2f2,0x7d14bf68,0x8cd8033f,0x61280166}},	//   _filw, _yozs, न्थो, _yüld, 
   {{0x6128e2f3,0x637c02b1,0x79800142,0x00000000}},	//   _küle, _pūno, _gilw, --, 
   {{0x7824007b,0x3cac00cc,0x00000000,0x00000000}},	//   _وعمل, _চামৱ, --, --, 
   {{0x79800944,0xd0840588,0x8cd81db2,0x753c00e5}},	//   _zilw, ҧыси, न्तो, észr, 
   {{0x79800117,0xd75447ea,0x7bc404ba,0x612805d2}},	//   _yilw, _النت_, zuhu, _lüle, 
   {{0x79800067,0xf60800f1,0xd4100154,0x1674011a}},	//   _xilw, _ختمه_, াছড়ি_, _הגדל_, 
   {{0x7d14489c,0x7bc00793,0x00000000,0x00000000}},	//   _rozs, _älux, --, --, 
   {{0x7d140007,0x2ca80175,0xefc80023,0x612888e9}},	//   _sozs, _aebd_, ኽብዎ_, _süld, 
   {{0x9c840597,0x7bc4e2f4,0x7d1401d3,0x0d3c0092}},	// [13830] مشاه, wuhu, _pozs, _ተከፋፍ, 
   {{0x7bc400b2,0x61280598,0xa0a40276,0x7bc0143a}},	//   tuhu, _büle, _ушил, _åluk, 
   {{0x79880036,0x7980e2f5,0x8cd82314,0x00000000}},	//   _suew, _rilw, न्धो, --, 
   {{0x7980e2f6,0x25a4020c,0x3dc80451,0xf3880051}},	//   _silw, _owol_, _پوسٽ_, _oản_, 
   {{0x7bc4e2f7,0x798006d1,0xf38801fb,0x7988017a}},	//   suhu, _pilw, _nản_, _quew, 
   {{0x7bc4e2f8,0x77940640,0x8cd81562,0x612801d3}},	//   puhu, ојиц, न्दो, _füle, 
   {{0x25a40280,0x6128e2f9,0x7bc402d1,0xdb68005b}},	//   _awol_, _güle, quhu, _брал_, 
   {{0xf38801dc,0x29d0145e,0x7980a21f,0x2be0033f}},	//   _bản_, bâa_, _wilw, _टैटू_, 
   {{0x7980e2fa,0xf388001e,0xe614e2fb,0x6128e2fc}},	//   _tilw, _cản_, жды_, _züle, 
   {{0xc588001e,0x25a40100,0x6adc03d4,0x6128013d}},	//   _tồn_, _dwol_, _নোপো, _yüle, 
   {{0x3eb8e2fd,0x636c04cc,0x00000000,0x00000000}},	//   _odst_, zùne, --, --, 
   {{0x752000d7,0x00000000,0x00000000,0x00000000}},	//   sklz, --, --, --, 
   {{0x21a039b8,0x9f5c01e1,0x00000000,0x00000000}},	//   миям, _ìrùn_, --, --, 
   {{0xd58403e6,0xf8c832ed,0x637c01e1,0x00000000}},	//   _پێگه_, रलिय, _pànì, --, 
   {{0x61283535,0x00000000,0x00000000,0x00000000}},	//   _bülb, --, --, --, 
   {{0xf3880016,0xe3c8002e,0xada496f0,0x00000000}},	//   _hảo_, _weññ_, жаал, --, 
   {{0x2ca800a8,0xdce400b0,0x00000000,0x00000000}},	// [13840] икап_, _ōmāi, --, --, 
   {{0xceb80184,0xa8007a0e,0xafe400cf,0x6fa800f3}},	//   шәү_, ğızl, _доол, _квог_, 
   {{0xea88e2fe,0x612801d3,0x8b0801ef,0x00000000}},	//   абел_, _fülb, jeřá, --, 
   {{0x41b00014,0x6128e2ff,0xf3880208,0x8b0801ef}},	//   _زۅہر, _gülb, _lảo_, deřá, 
   {{0x6f04e300,0x00000000,0x00000000,0x00000000}},	//   _inkc, --, --, --, 
   {{0x25a40003,0xdb04007c,0x612800a2,0x04f40154}},	//   _rwol_, _avjä, _tüle, _চক্র_, 
   {{0xf38801dc,0xaae42d74,0x25a4045f,0x6d4c02d0}},	//   _sản_, _وسرو, _swol_, _ijba, 
   {{0x4b34034c,0x25a4020c,0xd6d4234c,0xf3880208}},	//   _عکاس, _pwol_, оть_, _pản_, 
   {{0xf38801dc,0x6aa0e301,0x7afce302,0x00000000}},	//   _bảo_, mbof, _ósta, --, 
   {{0x6b9c08fb,0xf25c001f,0x6f040175,0x9984054e}},	//   oppg, _ማስፋፊ, _lnkc, şiţi_, 
   {{0xd7ec0597,0x69c0e303,0x961401d5,0x7d0002d2}},	//   _لكل_, lroe, مغیر_, _ólse, 
   {{0xf38801fb,0x6aa0003b,0x69c003ac,0x00000000}},	//   _tản_, nbof, oroe, --, 
   {{0x69c0e304,0x6d4c02d2,0x00000000,0x00000000}},	//   nroe, _ojba, --, --, 
   {{0x6f04035a,0x81cc0154,0x09c803ce,0x00000000}},	//   _ankc, রবল_, _रमैय, --, 
   {{0x28d0069f,0x69c0e305,0xc58801fb,0xd0d400a7}},	//   _सानि, hroe, _mồm_, ьоръ, 
   {{0x6d4ce306,0x3d94035b,0xc5880051,0xfbc81546}},	//   _ajba, зиар, _lồm_, ांसम, 
   {{0x7c5804a9,0xa8007975,0x69c001e4,0xd130004b}},	// [13850] ڭلار_, ğıyl, jroe, رمې_, 
   {{0x6f0401e2,0xf38801fb,0xa8002c78,0x61fc4831}},	//   _enkc, _xảo_, şıyl, _irql, 
   {{0x7f58e307,0x82e8031c,0x69c0257c,0x81cc0154}},	//   _ганс_, _ཧྲོའ, eroe, _রনি_, 
   {{0x6aa00770,0x3a740209,0x69c0e308,0x3eb801bf}},	//   gbof, плер, froe, _udst_, 
   {{0x69c0e309,0x27fc026c,0x8cd8298e,0x4a74dcd2}},	//   groe, _artn_, न्हो, мышт, 
   {{0x3dc802ea,0x6aa00083,0xc5880051,0x00000000}},	//   muaw_, abof, _cồm_, --, 
   {{0x69c0000f,0xc6a8001f,0x6aa0007c,0xf3880208}},	//   aroe, _መቀመጫ_, bbof, _rảo_, 
   {{0xf988a5f4,0x98a862c7,0xf388004d,0x3d08482a}},	//   _هنري_, ılın_, _sảo_, सावे_, 
   {{0x82e80327,0x7aa400fb,0xf3880051,0x00000000}},	//   _ཧྲེའ, _миңз, _pảo_, --, 
   {{0xc5880016,0x00000000,0x00000000,0x00000000}},	//   _gồm_, --, --, --, 
   {{0xd7f800f0,0x00000000,0x00000000,0x00000000}},	//   _њуз_, --, --, --, 
   {{0x216400d1,0x00000000,0x00000000,0x00000000}},	//   җиси_, --, --, --, 
   {{0xf38801fb,0x28d0185d,0x64980137,0x942000db}},	//   _tảo_, _सामि, штөр_, سوڭۇ, 
   {{0x3dc8089c,0x92ac015b,0xe3a400f2,0xc5880051}},	//   duaw_, খলে_, _کشوی, _xồm_, 
   {{0x69c00007,0x09c80b7c,0x739400fb,0x00000000}},	//   zroe, _रम्य, _эшлє, --, 
   {{0x3dc8013f,0xe3f401ec,0x00000000,0x00000000}},	//   fuaw_, _ءىيت_, --, --, 
   {{0x69c00399,0x13d8146b,0x00000000,0x00000000}},	// [13860] xroe, _बहुभ, --, --, 
   {{0x69c00dd4,0xf3880208,0x00000000,0x00000000}},	//   vroe, _lảm_, --, --, 
   {{0x28d00abd,0x6b9ce30a,0xdc2000b0,0x69c0e30b}},	//   _साबि, uppg, _pōāt, wroe, 
   {{0x6f0411b0,0x298818a4,0xf8c8000d,0x00000000}},	//   _unkc, бско_, _राउय, --, 
   {{0x6aa0e30c,0xa9682d2e,0xe8f8e30d,0x9a800131}},	//   rbof, бида_, йлд_, нушл, 
   {{0x6128033d,0x69c0e30e,0x27fc05b1,0xc7b000e5}},	//   _küla, rroe, _prtn_, نّت_, 
   {{0x6d5ce30f,0x636c05d5,0x69c00af9,0x2fc8010a}},	//   mopa, hùna, sroe, nubg_, 
   {{0x6d5ce310,0xf38801dc,0x69c0e311,0x272807de}},	//   lopa, _cảm_, proe, _bùna_, 
   {{0x96b40063,0xaf980023,0x50dc17c6,0x00000000}},	//   чују_, ዋህበና_, यभाष, --, 
   {{0x6d5ce312,0x92ac00eb,0x55700139,0xdb1c01e1}},	//   nopa, খলো_, нгыт, _òwòn, 
   {{0x82e80003,0x637c00b0,0x66e44a1d,0x2d900200}},	//   _ཧྲུའ, _hūni, _ножа, hqye_, 
   {{0x6d5ce313,0x637c139f,0x273800c0,0x6adc00cc}},	//   hopa, _kūni, kūni_, _নোতো, 
   {{0x637c00da,0x048800d1,0xc0c42f8d,0xecb000cc}},	//   _jūni, _мәни_, мәни, _চানড, 
   {{0x7d480092,0x6128e314,0x00000000,0x00000000}},	//   ናወናቸ, _büla, --, --, 
   {{0x6d5ce315,0x6b8c00ca,0x27ec0142,0x6578002f}},	//   dopa, _nubg, nwfn_, mmth, 
   {{0x657801a4,0x42540014,0xc5880208,0x00000000}},	//   lmth, _ٲندر, _rồj_, --, 
   {{0xbf1c2413,0x91e400d1,0x42740139,0x3d0800bc}},	// [13870] _नवीन_, _пәрһ, _югис, साले_, 
   {{0x6d5ca788,0xdc88013e,0x63a80175,0xa0a4001b}},	//   gopa, ссал_, _kwfn, _эшил, 
   {{0x6128274a,0x0ca8e316,0x657801e7,0xa3c0134e}},	//   _güla, ятти_, imth, एंट_, 
   {{0x2900013b,0x6d5c005b,0x961000cc,0x6578e317}},	//   _ɔkae_, aopa, িনতম_, hmth, 
   {{0x0dc81e51,0x6d5ce318,0xe048030f,0x612803e3}},	//   _нури_, bopa, _خشکه_, _züla, 
   {{0x7f4c0455,0x6adc00cc,0x00000000,0x00000000}},	//   lnaq, _নোদো, --, --, 
   {{0x272804cc,0x612800ac,0x00000000,0x00000000}},	//   _sùna_, _xüla, --, --, 
   {{0x7f4ce319,0x28d005d7,0x98a40270,0x7bc401e2}},	//   nnaq, _साथि, tinē_, mrhu, 
   {{0x7f4c013c,0x45d42e80,0x00000000,0x00000000}},	//   inaq, нцэт, --, --, 
   {{0xe91801ed,0x7bc401e2,0x74e801c6,0xfaa401af}},	//   _ورلڈ_, orhu, цдог_, _хаҡо, 
   {{0x7bc42784,0xecb00154,0x7f4c0200,0xf56800cf}},	//   nrhu, _চামড, knaq, йшүк_, 
   {{0x6d5ce31a,0xe294115c,0x272804cc,0x65780051}},	//   zopa, маю_, _tùna_, amth, 
   {{0x6d5ce31b,0x7bc40730,0x7f4c0014,0x63a802d0}},	//   yopa, hrhu, dnaq, _ewfn, 
   {{0x7768e31c,0xafe47c58,0x6d5ce31d,0x7f4c003a}},	//   llex, могл, xopa, enaq, 
   {{0x6d5c002b,0x2164013e,0x58200327,0x250800f1}},	//   vopa, фири_, འགྲོ_, _ذروی_, 
   {{0x7f4c0381,0xf480001f,0x776867b6,0x9f440241}},	//   gnaq, _የሂሳብ_, nlex, _ènì_, 
   {{0x82e8031c,0x7bc401f5,0xf1a80244,0x776800e4}},	// [13880] _ཧྲིའ, erhu, _باعه_, ilex, 
   {{0x7f4c0140,0xefcc001f,0x6d5c005b,0x63a802d0}},	//   anaq, ብለው_, uopa, _ywfn, 
   {{0x6d5ce31e,0xdcac3b5f,0xeb981142,0x61280139}},	//   ropa, شىن_, цие_, _küln, 
   {{0x6d5ce31f,0x637c02b5,0x7f4c0175,0x7afc0332}},	//   sopa, _pūni, cnaq, _óstl, 
   {{0x6d5ce320,0xd99400aa,0x7bc40311,0x99d00133}},	//   popa, وخوا_, arhu, نتوا, 
   {{0xdd840801,0x00000000,0x00000000,0x00000000}},	//   _обяд_, --, --, --, 
   {{0xa258145e,0x06781c5c,0xa2cc012c,0x79500133}},	//   ngôr, ﻧﯩﻨﯩ, _थाल्, دێلا, 
   {{0xc58807ae,0x65780218,0x77680381,0x637ce321}},	//   _hồi_, wmth, glex, _tūni, 
   {{0x4dac00cc,0xe4c4022e,0x00000000,0x00000000}},	//   _চমুৱ, мённ, --, --, 
   {{0x272801ab,0x668001b9,0x24e400d8,0x00000000}},	//   _gùnn_, _ییغل, фциг, --, 
   {{0x7f4ce322,0x3cf00882,0xc588001e,0x776802d0}},	//   ynaq, ीयते_, _mồi_, blex, 
   {{0x3d04006d,0xc588004d,0x657802d0,0x00000000}},	//   _होने_, _lồi_, smth, --, 
   {{0x06b400cc,0x7f4c01b9,0x25700117,0x00000000}},	//   _টাপি, vnaq, _иқис, --, 
   {{0x6600e323,0x09e802f5,0x7f4c0113,0x7bc44867}},	//   _irok, পিপা, wnaq, yrhu, 
   {{0xc588001e,0x39484a16,0x6600e324,0x7f4ce325}},	//   _nồi_, éasi_, _hrok, tnaq, 
   {{0x1ee4e326,0x7bc402fb,0x9ad002e3,0x5344da7c}},	//   بوری_, vrhu, mịgh, _ахьа, 
   {{0x171804ac,0x7f4ce327,0x937812dd,0x7af80477}},	// [13890] קומע, rnaq, _تصور_, vdwt, 
   {{0xc588001e,0x6600e328,0xd01000aa,0x7f4c011f}},	//   _bồi_, _mrok, دلې_, snaq, 
   {{0xe1fc0407,0x386802a8,0x7bc401a4,0xebc00075}},	//   lvó_, ƙari_, urhu, ләтн, 
   {{0x6600e329,0x7bc4e32a,0xc58801fb,0x61280790}},	//   _orok, rrhu, _dồi_, _külo, 
   {{0x13d404c5,0x9ad0063f,0x89a802bf,0xd3380375}},	//   তবয়, hịgh, дків_, וראה_, 
   {{0x644405d1,0xf7700133,0xbca4009f,0x00000000}},	//   şkiy, گات_, _سمري, --, 
   {{0x6600e32b,0x637c0374,0x3d0405f9,0xe7c401ad}},	//   _arok, _hūnu, _होये_, रंगप, 
   {{0xf77096b4,0x6600e32c,0x637c0024,0x27380064}},	//   دات_, _brok, _kūnu, kūnu_, 
   {{0x7768002f,0x33440014,0xc5880051,0x00000000}},	//   rlex, ہندِ, _zồi_, --, 
   {{0xf38807ae,0x6600e32d,0x37f80276,0x969c01ad}},	//   _hải_, _drok, _незэ_, _ग्रॉ, 
   {{0x7768e32e,0x6600e32f,0x6e342d91,0x00000000}},	//   plex, _erok, zzyb, --, 
   {{0x66001455,0x612801b8,0xdce400ef,0x00000000}},	//   _frok, _bülo, _bijī, --, 
   {{0xfaf80421,0xf388004d,0xc5f41219,0x27380064}},	//   _maū_, _mải_, _ағы_, gūnu_, 
   {{0xf9d4037e,0xf3880208,0x828001ec,0x00000000}},	//   _mと_, _lải_, шқыд, --, 
   {{0xf388004d,0x067800d1,0x00000000,0x00000000}},	//   _oải_, ﻧﯩﻠﯩ, --, --, 
   {{0xc58801dc,0x6128bff7,0xe2800166,0x00000000}},	//   _rồi_, _hüll, _әльи, --, 
   {{0xee38343d,0x6128e330,0xc5880208,0xf3880208}},	// [138a0] чна_, _küll, _sồi_, _nải_, 
   {{0x98a4dd77,0x6e34762b,0x7afc08a5,0x00000000}},	//   minė_, rzyb, _óstj, --, 
   {{0x61289cf8,0x98a402d5,0x7c647577,0xf8c807d0}},	//   _müll, linė_, پالل, _राजय, 
   {{0xeab073c5,0x28d0482a,0x298801da,0xb60409a8}},	//   اعا_, _साहि, пско_, _košč, 
   {{0xf3880016,0x98a402d5,0xa9680131,0x5b20007b}},	//   _cải_, ninė_, пида_, طفول, 
   {{0xf38801fb,0xc58801fb,0x66000023,0xa850151e}},	//   _dải_, _tồi_, _rrok, лелә, 
   {{0x6600e331,0xb6040010,0x2d880254,0x0ccc00bc}},	//   _srok, _lošč, _iibe_, ालीम, 
   {{0x28d0590f,0x98a40024,0xf388004d,0x2d88ce76}},	//   _सावि, kinė_, _fải_, _hibe_, 
   {{0x2d88e332,0x2b4402ea,0x6128e333,0x7bc003cd}},	//   _kibe_, mioc_, _büll, _ålur, 
   {{0x2d88a015,0x98a40006,0x66000165,0xdce400ef}},	//   _jibe_, dinė_, _vrok, _rijī, 
   {{0x291c030a,0x386003fa,0x6600017a,0xdce81710}},	//   _iota_, ührt_, _wrok, šićk, 
   {{0x291ce334,0xb60401fa,0x68f80209,0x9ad001f2}},	//   _hota_, _bošč, _hatd, rịgh, 
   {{0x291ce335,0x8c2400bd,0x68f80649,0x6128e336}},	//   _kota_, _যেমন_, _katd, _füll, 
   {{0x2d8838fb,0x291ce337,0x612854de,0xe1fc6428}},	//   _nibe_, _jota_, _güll, rvó_, 
   {{0x291ce338,0x68f8e339,0x637c0006,0xed600024}},	//   _mota_, _matd, _sūnu, _mažą_, 
   {{0x291ce33a,0x637c6661,0x29000134,0x98a40006}},	//   _lota_, _pūnu, _ɔkaa_, binė_, 
   {{0x291c9136,0x5cc4e33b,0x98a40006,0x248c00d8}},	// [138b0] _oota_, есез, cinė_, _kgfm_, 
   {{0x98a41248,0x6128e33c,0xf3880016,0x68f8e33d}},	//   yonı_, _külm, _rải_, _natd, 
   {{0x2d88e33e,0xfaf80618,0x06780e2c,0x3d040490}},	//   _dibe_, _paū_, ﻧﯩﻤﯩ, _होणे_, 
   {{0x291c0421,0x637c02b1,0x2b44067c,0x61280166}},	//   _aota_, _tūnu, gioc_, _mülm, 
   {{0x291ce33f,0x2d88299d,0xdb141709,0x68f8e340}},	//   _bota_, _fibe_, nsxé, _batd, 
   {{0x291ce341,0x8d8405f5,0xf388001e,0x2d88b9be}},	//   _cota_, _бусд, _vải_, _gibe_, 
   {{0x63b88bb3,0x68f84dc3,0x28d006b1,0x4c68023b}},	//   jstn, _datd, _सारि, _зиён_, 
   {{0x3d04e342,0xf38807ae,0x3ea8e343,0x6128e344}},	//   _होते_, _tải_, nbat_, _süll, 
   {{0x291ce345,0x2d88e346,0x68f80369,0xceb40bd9}},	//   _fota_, _yibe_, _fatd, ניץ_, 
   {{0x68f8e347,0x3ea8036b,0x98a40006,0xb60401a6}},	//   _gatd, hbat_, vinė_, _rošč, 
   {{0x3ea80007,0x3dc82679,0x00000000,0x00000000}},	//   kbat_, hraw_, --, --, 
   {{0x98a40953,0xb6040010,0x3dc8e348,0x6128002f}},	//   tinė_, _pošč, kraw_, _dülm, 
   {{0x55c0e349,0x68f80fe8,0x612884cd,0x90b46b62}},	//   _салғ, _yatd, _tüll, ләнш, 
   {{0x6604019b,0x3dc8e34a,0x98a402d5,0x3ea816b8}},	//   ække, draw_, rinė_, ebat_, 
   {{0xa064e34b,0x6128e34c,0x98a4d60d,0x00000000}},	//   вара_, _külj, sinė_, --, 
   {{0xdfcc0691,0xe454008f,0x98a40153,0x3dc8015d}},	//   تيف_, _שיקט_, pinė_, fraw_, 
   {{0x3dc8e34d,0x2d88e34e,0x0d080058,0xe1f4010b}},	// [138c0] graw_, _pibe_, ндақ_, _агы_, 
   {{0x3ea8e34f,0x0ccc0118,0x00000000,0x00000000}},	//   abat_, ालेम, --, --, 
   {{0x3ea8e350,0x3dc81c06,0x33300158,0x2b440165}},	//   bbat_, araw_, _klyx_, tioc_, 
   {{0x291ce351,0x3ea80998,0x68f8e352,0x3dc8e353}},	//   _sota_, cbat_, _satd, braw_, 
   {{0x291ce354,0x2d88e355,0x2b4400c6,0x317801e4}},	//   _pota_, _tibe_, rioc_, _khpz_, 
   {{0x63b80034,0x291c8186,0x68f8427b,0x5ca00395}},	//   ystn, _qota_, _qatd, _вирб, 
   {{0x9d40e356,0xab64014b,0x00000000,0x00000000}},	//   _терд, _аввл, --, --, 
   {{0x291ce357,0x45d40b3e,0x26040212,0x86f80811}},	//   _wota_, гоис, вчог, عکاس_, 
   {{0x291ce358,0x68f80a73,0x15d401d3,0xfe04098a}},	//   _tota_, _tatd, نگوں_, रियस_, 
   {{0x291c42fb,0x5908031c,0xe8f802dd,0x3ea8e359}},	//   _uota_, _ཁོགས_, _іле_, zbat_, 
   {{0x34b40214,0x3ea81eca,0x320000d7,0x00000000}},	//   دمپز, ybat_, evky_, --, 
   {{0x65c40228,0x26d005ac,0x1934037e,0x61280432}},	//   _абда, _øyo_, _ｖｏｖ_, _gülj, 
   {{0x63b8168c,0x9ad001f2,0x3ea801b9,0x00000000}},	//   sstn, lịch, vbat_, --, 
   {{0x154001b9,0xc1043229,0x61280166,0xa2cc2c2e}},	//   _кечм, دوسي, _tülm, _थाक्, 
   {{0x3ea82819,0x9ad0063f,0xa3b400c5,0x45d400d1}},	//   tbat_, nịch, _छबि_, _роһс, 
   {{0x3dc8e35a,0x3ea81f29,0xddc80ae5,0x57f8011a}},	//   traw_, ubat_, _ﺗﻪﺭﺑ, וללו, 
   {{0x3ea8e35b,0x9ad000b4,0xf3880208,0x00000000}},	// [138d0] rbat_, hịch, _cảu_, --, 
   {{0x6128e35c,0x3ea8e35d,0x9c84e35e,0x66e06b9b}},	//   _mülk, sbat_, نشاه, क्तक_, 
   {{0x4fc404a9,0x0b9401c8,0x00000000,0x00000000}},	//   _پەقە, لجند, --, --, 
   {{0x60d801fa,0x3dc8e35f,0xc3240154,0x63ac00d7}},	//   đumu, praw_, মোরি_, ábny, 
   {{0x4aa800d4,0x3dc8df1d,0xb034014b,0x00000000}},	//   ткін_, qraw_, _анӯш, --, 
   {{0xa3b007f7,0x6128000d,0x4fb400f2,0x00000000}},	//   टठा_, _sülj, _حصیر, --, 
   {{0xe5140882,0xe9a43ee0,0xdb680139,0x6840009d}},	//   तानि_, نگەن_, _жрал_, йнша, 
   {{0xde8c01f2,0x320002f0,0x8ae40816,0xff000154}},	//   _aịza_, yvky_, _віфл, _একুশ_, 
   {{0x5a440006,0x2f8800df,0x00000000,0x00000000}},	//   _рэва, ערפּ, --, --, 
   {{0xe294040d,0x6128010e,0xc774009d,0xf79400c0}},	//   ғар_, _dülk, лтөө, _бажэ, 
   {{0xf408005e,0xb384e360,0x88040014,0x8cd80bae}},	//   ريحى_, ллол, _پِنو, न्टो, 
   {{0x399802e2,0x71a4e361,0x64a000d1,0x612800e5}},	//   _kès_, ламз, _һаша, _fülk, 
   {{0xe60c412c,0x3998033b,0x973001b9,0x6128010b}},	//   _уд_, _jès_, _مککا, _gülk, 
   {{0x39982508,0x81f4031c,0x64a0e362,0x2a38010f}},	//   _mès_, _བརྫི_, _лаша, געשמ, 
   {{0x3998e363,0x05740075,0x6128e364,0x71240131}},	//   _lès_, _ئاند, _mülh, نىڭم, 
   {{0x0ccc00cd,0x00000000,0x00000000,0x00000000}},	//   ाल्म, --, --, --, 
   {{0x6da4119e,0x00000000,0x00000000,0x00000000}},	// [138e0] уиза, --, --, --, 
   {{0xad240101,0x00000000,0x00000000,0x00000000}},	//   دررو, --, --, --, 
   {{0x067800d1,0x00000000,0x00000000,0x00000000}},	//   ﻧﯩﻴﯩ, --, --, --, 
   {{0x81f40c99,0xeaf800dd,0x39980100,0x00000000}},	//   _བརྩི_, عرات_, _bès_, --, 
   {{0x3d040307,0x97a002dd,0xe8f80327,0x692401b9}},	//   _होवे_, ұрыл, _ྒྲུབ_, лмда, 
   {{0x3998e365,0x00000000,0x00000000,0x00000000}},	//   _dès_, --, --, --, 
   {{0x69f4010a,0x00000000,0x00000000,0x00000000}},	//   ăншă, --, --, --, 
   {{0x3998e366,0x2cb8089c,0x9ad000b4,0x48f0033f}},	//   _fès_, lapd_, rịch, _इसको_, 
   {{0x6b80e367,0xe664e368,0x39980100,0x3d080490}},	//   mmog, ытко, _gès_, साचे_, 
   {{0x46a407b6,0x59802140,0x61284e7e,0x00000000}},	//   _ग्रह, _глуб, _gülh, --, 
   {{0xd61419bc,0xa8541677,0xd73009a0,0xd90c00e5}},	//   نتیا_, _стај, рдөө, _ریٹ_, 
   {{0x69c40267,0x0514015b,0x3998007f,0x6b800455}},	//   _åkes, িসের_, _yès_, nmog, 
   {{0xde8c063f,0xdc2403ee,0x6b8001f5,0x21300208}},	//   _gịya_, köğr, imog, _plxh_, 
   {{0x98a40989,0x67202878,0x61280037,0x6b80047e}},	//   čići_, _hooj, _küli, hmog, 
   {{0x67200211,0x6b8001f5,0x612884bf,0x32d80133}},	//   _kooj, kmog, _jüli, ردێک_, 
   {{0x6720e369,0x6b80014f,0x00000000,0x00000000}},	//   _jooj, jmog, --, --, 
   {{0x6b8007f5,0x612800af,0x636c0428,0x6720e36a}},	// [138f0] dmog, _lüli, jùni, _mooj, 
   {{0x399802bd,0x6720e36b,0x6b80e36c,0x00000000}},	//   _rès_, _looj, emog, --, 
   {{0x5b24e36d,0x61280254,0x00000000,0x00000000}},	//   льда, _nüli, --, --, 
   {{0x39986f90,0x612800ac,0x67200254,0x2b0000c5}},	//   _pès_, _sülh, _nooj, _रोआँ_, 
   {{0x99d40491,0xf1c80332,0x69cc00de,0x00000000}},	//   اتصا, mháú_, _ābec, --, 
   {{0x6b80011c,0x39986f8d,0x4c94010b,0x00000000}},	//   amog, _vès_, _гирс, --, 
   {{0x6720198f,0x39980100,0x18b00131,0xfb88e36e}},	//   _booj, _wès_, _һәйр, _арақ_, 
   {{0xe6900131,0x399802bd,0x080805af,0x00000000}},	//   يلىد, _tès_, ازوي_, --, 
   {{0x6720e36f,0x7ae8e370,0x6adc00cc,0x00000000}},	//   _dooj, _ibet, _নোকো, --, 
   {{0x66040252,0x7ae800a2,0x75440229,0x596402e8}},	//   ækka, _hbet, рноз, _съба, 
   {{0x7ae8020b,0x69c46afa,0x67200067,0x612875d4}},	//   _kbet, _åker, _fooj, _güli, 
   {{0x6720058a,0x644c004e,0x555001d3,0x97301fb8}},	//   _gooj, úbia, _گھبر, _دکتا, 
   {{0x7ae8e371,0x1ae00c58,0xd5a013f9,0x7afc032e}},	//   _mbet, _নোৱা, _التی, _óstu, 
   {{0x3d04007d,0x6b800072,0x644c0210,0x00000000}},	//   _होले_, zmog, źbia, --, 
   {{0x67200070,0x7ae8e372,0x602073dd,0x2eb428e5}},	//   _yooj, _obet, одра, исас, 
   {{0x672001d9,0x00000000,0x00000000,0x00000000}},	//   _xooj, --, --, --, 
   {{0xed44035b,0xde0000f3,0x1f6012fa,0x623000f3}},	// [13900] анап, опти, ікум, _мећу, 
   {{0x6b8001f5,0x2d8c0112,0x00000000,0x00000000}},	//   wmog, öfe_, --, --, 
   {{0x6b80e373,0x44e805ac,0x00000000,0x00000000}},	//   tmog, _কোডক_, --, --, 
   {{0x78a002d2,0xda6c01d9,0x00000000,0x00000000}},	//   _aflv, ڈُم_, --, --, 
   {{0x6b80e374,0xda6c0a81,0x6720e375,0x6128e376}},	//   rmog, وُم_, _rooj, _süli, 
   {{0x6b80579d,0x7ae8e377,0x6720007d,0xed58798c}},	//   smog, _ebet, _sooj, _рог_, 
   {{0x9ad0063f,0x00000000,0x00000000,0x00000000}},	//   sịah, --, --, --, 
   {{0xe66401af,0x2ad401f7,0xa9a4011c,0x00000000}},	//   итпо, _خيرآ, _виад, --, 
   {{0x66e01b76,0xe8f8036b,0xda6c01d9,0xe9d8009b}},	//   क्षक_, _ила_, _ہُہ_, _шка_, 
   {{0x6128e378,0x7ae80200,0x00000000,0x00000000}},	//   _tüli, _zbet, --, --, 
   {{0x6720e379,0x6128e37a,0x86e800fb,0x00000000}},	//   _tooj, _külv, _булғ_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x15a40801,0xa594023a,0x52240fac,0x00000000}},	//   _къщи_, _трещ, офра, --, 
   {{0xf668e37b,0x3868e37c,0x00000000,0x00000000}},	//   _صحنه_, şare_, --, --, 
   {{0xd48ce37d,0x00000000,0x00000000,0x00000000}},	//   _фр_, --, --, --, 
   {{0x442c0731,0x2b0400bc,0x00000000,0x00000000}},	//   myd_, _सोलु_, --, --, 
   {{0x442ce37e,0x81f846c6,0xe3b0009f,0x00000000}},	// [13910] lyd_, _صفدر_, _ارڻ_, --, 
   {{0xdca40006,0xc0340a5b,0x00000000,0x00000000}},	//   ршап, _гној, --, --, 
   {{0x442c0731,0x26c4198f,0xdc880798,0x00000000}},	//   nyd_, _odoo_, тсал_, --, 
   {{0x26c482f6,0x3eac010e,0x00000000,0x00000000}},	//   _ndoo_, _ýet_, --, --, 
   {{0x7f4c0357,0x442c0368,0x7ae8e37f,0x4ad8000d}},	//   miaq, hyd_, _vbet, _डारव, 
   {{0x3eb839c2,0x7f4cc203,0x9964e380,0x26c4e381}},	//   _hest_, liaq, штел, _adoo_, 
   {{0x25a4e382,0x3eb8e383,0x6ac8007c,0x00000000}},	//   _atol_, _kest_, åpfö, --, 
   {{0x3eb81b13,0x7f4ce384,0x7ae8e385,0x442c00a9}},	//   _jest_, niaq, _ubet, dyd_, 
   {{0x3eb800ed,0x442c0067,0xb8cc05ac,0x00000000}},	//   _mest_, eyd_, _কয_, --, 
   {{0x442c0f7b,0xd7e410f5,0x26c40e14,0xb1840004}},	//   fyd_, _відо, _edoo_, zeåº, 
   {{0x442ce386,0x7f4c0d04,0x3eb81e7b,0x98a40006}},	//   gyd_, kiaq, _oest_, linį_, 
   {{0x3eb80e21,0x14c401b9,0x37dc00cc,0x00000000}},	//   _nest_, دهگی_, _মনপৰ, --, 
   {{0x7f4ce387,0xe60c05f5,0x98a40006,0xa694025d}},	//   diaq, _эд_, ninį_, _הכנה_, 
   {{0x3eb82f55,0x442ce388,0x62600212,0x23c00014}},	//   _aest_, byd_, ївра, _کٕٹہ, 
   {{0x3eb8e389,0x25180302,0x6140e38a,0x7f4c0334}},	//   _best_, _תוצא, чера, fiaq, 
   {{0x7f4ce38b,0x98a40024,0x00000000,0x00000000}},	//   giaq, kinį_, --, --, 
   {{0x3eb8e38c,0x25a401c7,0xb628019b,0x7f1802dd}},	// [13920] _dest_, _xtol_, _ｖｓ_, шіру_, 
   {{0x3eb8033d,0x98a40024,0x612806be,0x77680051}},	//   _eest_, dinį_, _bülu, hoex, 
   {{0xe0f80375,0x7f4ce38d,0x61f80327,0x00000000}},	//   _גליל, biaq, ħule, --, 
   {{0x3eb8e38e,0xfe0430fd,0xef18013e,0x7f4cc528}},	//   _gest_, रिशस_, _смм_, ciaq, 
   {{0x98a40024,0x8a180798,0x00000000,0x00000000}},	//   ginį_, ролс_, --, --, 
   {{0xbab80116,0x00000000,0x00000000,0x00000000}},	//   _ﻧﯩﺸﺎ, --, --, --, 
   {{0x442c04cc,0xa098008f,0x38c802dd,0xe51400cd}},	//   xyd_, ניקט, руін_, तासि_, 
   {{0xed580364,0x25a4003a,0x98a40153,0x00000000}},	//   _роҳ_, _ptol_, binį_, --, 
   {{0x442c0f7b,0x6128e38f,0x98a40024,0x00000000}},	//   wyd_, _kült, cinį_, --, 
   {{0x442ce390,0x7afce391,0x6adc00cc,0x00000000}},	//   tyd_, _óstr, _নোচো, --, 
   {{0x69c0134a,0x61280790,0x00000000,0x00000000}},	//   lsoe, _mült, --, --, 
   {{0x6aa0e392,0x442ce393,0x25a40208,0x644c0210}},	//   ncof, ryd_, _ttol_, źbio, 
   {{0x69c00151,0x25a4e394,0x3eb82517,0x7f4c0869}},	//   nsoe, _utol_, _rest_, viaq, 
   {{0x3eb8033d,0x69c00ea0,0x7f9401c6,0x8eb400d1}},	//   _sest_, isoe, жавх, ۋەپت, 
   {{0x7f4ce395,0x69c00369,0x4034228c,0x3eb8b76c}},	//   tiaq, hsoe, цевс, _pest_, 
   {{0x7f4c0194,0x69c02694,0x7f740212,0xbdb4033a}},	//   uiaq, ksoe, ігає, жбај, 
   {{0x7f4ce396,0x61287225,0x69c00b21,0x528419c5}},	// [13930] riaq, _bült, jsoe, _ىلىك, 
   {{0x7f4c20ac,0x3eb8e397,0x69c0002d,0x527400c6}},	//   siaq, _west_, dsoe, _عايز, 
   {{0x7f4c0357,0x9ff00003,0x3eb8e398,0x4c9405f5}},	//   piaq, _བགྲང_, _test_, чихс, 
   {{0x98a402d5,0x6aa0014b,0x636c07de,0x3a742fc3}},	//   tinį_, gcof, cùnt, олер, 
   {{0x69c00214,0x939c0150,0xdb04032e,0xa5400023}},	//   gsoe, _ﺍﻟﻤﺒ_, _ílíf, _ክጥንቀ, 
   {{0x6128e399,0x527c00c8,0x98a40006,0x7e7c00e2}},	//   _gült, אנדא, rinį_, _izsp, 
   {{0xec1801d2,0xb8f0dc75,0x7f5c0175,0x6128e39a}},	//   _керә_, _वय_, _kjsq, _hüls, 
   {{0x612800dd,0xdb200520,0x5908031c,0x98a400c0}},	//   _küls, öräl, _ཁོམས_, pinį_, 
   {{0x7768e39b,0xfd7001e1,0x00000000,0x00000000}},	//   roex, _ẹṣhi, --, --, 
   {{0x272807c5,0x00000000,0x00000000,0x00000000}},	//   _bùns_, --, --, --, 
   {{0x79801246,0x272807de,0xceb40213,0x7d04e39c}},	//   _ihlw, _pùnt_, rkəz_, idhs, 
   {{0xdb04002d,0x00000000,0x00000000,0x00000000}},	//   _stjê, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x272805d5,0x7640035b,0xd4985d0b,0x99d400cc}},	//   _fùns_, _нҭқа, _срд_, _দৈৱক, 
   {{0x7980e39d,0xb35c0354,0x00000000,0x00000000}},	//   _mhlw, _иккĕ_, --, --, 
   {{0x7d147cf7,0x69c00368,0x60d401e4,0x7d040009}},	//   _anzs, ysoe, _ĝamŝ, edhs, 
   {{0x7980013e,0x7c640075,0x60d401e4,0xd3483bd6}},	// [13940] _ohlw, ۋامل, _ŝamŝ, _نیگه_, 
   {{0x798002d0,0x00000000,0x00000000,0x00000000}},	//   _nhlw, --, --, --, 
   {{0x69c0011a,0x00000000,0x00000000,0x00000000}},	//   wsoe, --, --, --, 
   {{0x79800b6f,0xfa2411ba,0x69c0e39e,0x7d040067}},	//   _ahlw, _মেইল_, tsoe, adhs, 
   {{0x6aa0e39f,0xe8f805f5,0x3d04007d,0x612851c8}},	//   rcof, илд_, _होके_, _güls, 
   {{0x69c00591,0x6aa0e3a0,0x7980015d,0x00000000}},	//   rsoe, scof, _chlw, --, 
   {{0x69c0e3a1,0x17f4007b,0xfca800e5,0x00000000}},	//   ssoe, قرية_, _چاہو_, --, 
   {{0xeb3407a7,0x7980401f,0xd7840228,0x69c00af9}},	//   _بىرد, _ehlw, ينوو_, psoe, 
   {{0x3868e090,0x272804cc,0x84c400d1,0x00000000}},	//   ğara_, _sùns_, пәйд, --, 
   {{0x38680274,0x00000000,0x00000000,0x00000000}},	//   şara_, --, --, --, 
   {{0x66e4e3a2,0xa6c8e3a3,0xdd7800df,0x00000000}},	//   _можа, _نوال_, שטיל, --, 
   {{0xded80b82,0x53340108,0x00000000,0x00000000}},	//   ኖትን_, деют, --, --, 
   {{0xe4d804fb,0x09e80154,0x7d04058a,0x00000000}},	//   _نوشت_, পিকা, ydhs, --, 
   {{0x272805d5,0xe8ec155b,0x10a421f3,0x69cc00de}},	//   _tùns_, елi_, диён, _ābel, 
   {{0x3d0405f9,0x5f2400f3,0x612800a2,0x835400db}},	//   _होगे_, офаз, _süls, _ىپتا, 
   {{0x612805d5,0x00000000,0x00000000,0x00000000}},	//   _püls, --, --, --, 
   {{0x63a80175,0x00000000,0x00000000,0x00000000}},	// [13950] _htfn, --, --, --, 
   {{0xdfd8156b,0x3d04367a,0x01cc02dd,0x00000000}},	//   _към_, _होखे_, _ﺑﻪﻳﻨ, --, 
   {{0x2e240092,0x70f8011a,0x7d040200,0x00000000}},	//   _ተያይዘ, _ההתח, rdhs, --, 
   {{0x3d941d5e,0x6128010e,0x00000000,0x00000000}},	//   _нимр, _gülr, --, --, 
   {{0x3f8804cc,0x9528031c,0x7e7c00e2,0x7980015d}},	//   mmau_, _ཧྭའི_, _uzsp, _phlw, 
   {{0x5ef001f2,0x3f88e3a4,0xf17c00d1,0xa9d000d1}},	//   _ịhọọ, lmau_, ﻣﭙﻴﯘ, رقىغ, 
   {{0x610c0153,0x3f880042,0x48ec000d,0x00000000}},	//   mėlė, omau_, _आउरो_, --, 
   {{0x7bc4e3a5,0x962000bd,0x92c00183,0x905c0375}},	//   mshu, _বেগম_, ুভৱ_, יכות, 
   {{0xe614e3a6,0xca2401c6,0x79800042,0x291400ae}},	//   зды_, _оффи, _thlw, ádaí_, 
   {{0x79800921,0x610c0006,0xd3a001b9,0x3f880142}},	//   _uhlw, nėlė, млоқ, hmau_, 
   {{0x7bc4e3a7,0x3f8805b1,0xd7e4003b,0x00000000}},	//   nshu, kmau_, _фізо, --, 
   {{0x7bc4e3a8,0x00000000,0x00000000,0x00000000}},	//   ishu, --, --, --, 
   {{0x7bc4e3a9,0x610c0024,0x4974010a,0x37ac00cc}},	//   hshu, kėlė, _алăс, _ঘটিৰ, 
   {{0x7bc4e3aa,0x3f880270,0x7af8009a,0x61f8e3ab}},	//   kshu, emau_, hewt, çula, 
   {{0x610c0153,0xadfc0037,0x00000000,0x00000000}},	//   dėlė, _उनहन_, --, --, 
   {{0xada40588,0x7bc4e3ac,0x6e9400c6,0x1dc478bf}},	//   заал, dshu, سلطا, _लिखत, 
   {{0x80a405d9,0x0f1c00c5,0x7bc401f5,0xacc801ec}},	// [13960] _ڪمپن, _पचीस_, eshu, йгаз_, 
   {{0x6cd801d5,0x7bc4e3ad,0x3f880142,0x610c00c0}},	//   صوصآ_, fshu, amau_, gėlė, 
   {{0xc2f000bd,0x7bc417b5,0xa0980a1e,0x0904015b}},	//   য়ারি_, gshu, _לייט, লামু_, 
   {{0x7af80652,0xfbd001d3,0x00000000,0x00000000}},	//   gewt, کتے_, --, --, 
   {{0x7bc4e3ae,0xec140f1c,0x612806be,0x610c00c0}},	//   ashu, _کوزد, _zülq, bėlė, 
   {{0x6f04001f,0x865002d3,0xd940004e,0x7bc4e3af}},	//   _hakc, _ንስኻት, нечи, bshu, 
   {{0x6f040a73,0x7c643484,0xab78009a,0x00000000}},	//   _kakc, _قافل, _همسا_, --, 
   {{0xceb403be,0xed3401ed,0xfbd008df,0x5c5800d9}},	//   nbə_, _بوڑھ, _हितम, _הדלק, 
   {{0x6f04e3b0,0x6d4c020c,0x2bc8012c,0x66a00014}},	//   _makc, _kmba, ाओवा, وٝژم, 
   {{0xd5ace3b1,0x6f04e3b2,0xceb403b9,0x00000000}},	//   _үс_, _lakc, hbə_, --, 
   {{0x6d4ce3b3,0xd6cc5541,0x3f88e3b4,0x1ae00154}},	//   _mmba, _пт_, ymau_, _নোয়া, 
   {{0x66e44cf0,0x6d4ce3b5,0x6f04e3b6,0x9878008f}},	//   _хода, _lmba, _nakc, _פראק, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6600015c,0x7bc4e3b7,0x35a80244,0x00000000}},	//   _isok, yshu, _بنوێ_, --, 
   {{0x6f04e3b8,0x5064bf38,0x7bc401a9,0x3f880051}},	//   _bakc, етта, xshu, tmau_, 
   {{0x6d4ce3b9,0x6f0400d5,0x61e801b8,0x3f88c715}},	//   _amba, _cakc, _äglo, umau_, 
   {{0x6f04e3ba,0x7bc40649,0x3f88e3bb,0x4d9812c4}},	// [13970] _dakc, wshu, rmau_, зкую_, 
   {{0x660002ce,0xdbc408a5,0x61280205,0xd01000f1}},	//   _msok, _böðv, _gülp, خلې_, 
   {{0x7bc4e3bc,0x610c0024,0x7e9800ec,0xebc0134b}},	//   ushu, rėlė, _وندر_, кәтн, 
   {{0x660062e3,0x7bc4e3bd,0x6d4ce3be,0x61280432}},	//   _osok, rshu, _emba, _zülp, 
   {{0x7af80a73,0x66d405d1,0x660001e1,0xfe7001c8}},	//   rewt, zükü, _nsok, _شگر_, 
   {{0x6d4c0a2e,0x88c40075,0x7bc4e3bf,0x6f0401f5}},	//   _gmba, ىتىل, pshu, _zakc, 
   {{0x6600e3c0,0xb6f80075,0x6f04011f,0x7bc401b9}},	//   _asok, قىغا_, _yakc, qshu, 
   {{0xf770e3c1,0x9dc808b0,0x00000000,0x00000000}},	//   خات_, _ﺗﻪﯕﺸ, --, --, 
   {{0x660001ed,0x6d4c6c4b,0x00000000,0x00000000}},	//   _csok, _ymba, --, --, 
   {{0xe5740022,0x62980024,0x00000000,0x00000000}},	//   мзы_, žuol, --, --, 
   {{0xe0e004c5,0x5ea00154,0x00000000,0x00000000}},	//   য়াভ, _ওজনে, --, --, 
   {{0x6128013d,0xe4e0000d,0x61f80327,0x00000000}},	//   _sülp, _खाथि_, ħuln, --, 
   {{0xe56ccaef,0x6f0479bb,0xceb40213,0x00000000}},	//   _аз_, _rakc, vbə_, --, 
   {{0x82805aba,0x00000000,0x00000000,0x00000000}},	//   ыңыз, --, --, --, 
   {{0x6f04e3c2,0x00000000,0x00000000,0x00000000}},	//   _pakc, --, --, --, 
   {{0x63f405d9,0x6d4c3d54,0x66000022,0x26000073}},	//   _آفيس_, _smba, _ysok, वटची_, 
   {{0x6f04e3c3,0x6da408ca,0xceb400ac,0xd05c0213}},	// [13980] _vakc, физа, rbə_, _əzəl, 
   {{0x6f04e3c4,0x1e800024,0x66040174,0x00000000}},	//   _wakc, тлум, ækki, --, 
   {{0xa2580109,0x6f04e3c5,0xb340010e,0xb2ac010e}},	//   naôn, _takc, _üçsa, _üỳtg, 
   {{0xdbc401a8,0xc8e0012d,0x644c00d7,0x00000000}},	//   _vöðv, _नाहट, úbii, --, 
   {{0x6d4c0a2e,0x2988e3c6,0x20040162,0x2ec83c74}},	//   _tmba, оско_, _ánir_, िणीत, 
   {{0xa8500ce8,0x00000000,0x00000000,0x00000000}},	//   келә, --, --, --, 
   {{0x69d805f9,0x2124067c,0x1be400d8,0x798c0548}},	//   _नमकी, _ònhe_, _одри_, ïawa, 
   {{0x77900214,0x98a4031c,0xe9d8011c,0x00000000}},	//   هیلا, rinġ_, _мкб_, --, 
   {{0x6d5c0857,0xd5e80022,0x3b68001f,0x09540150}},	//   onpa, _ryg̃, ታፊዎች_, _كىرڭ, 
   {{0x6d5ce3c7,0xa81803e6,0x992800f1,0x00000000}},	//   nnpa, _وتار_, _وتلې_, --, 
   {{0x6d5ce3c8,0x4438e3c9,0x312000dc,0x9cd40375}},	//   inpa, ár_, मानः_, וויה_, 
   {{0x6600e3ca,0x6d5c1196,0x00000000,0x00000000}},	//   _tsok, hnpa, --, --, 
   {{0x6600e3cb,0xa508e3cc,0x84c40220,0x2b4400d0}},	//   _usok, _меда_, _пәнд, ďoch_, 
   {{0x6d5c01f5,0xf3880208,0x00000000,0x00000000}},	//   jnpa, _mảy_, --, --, 
   {{0x4fc4e3cd,0xd5e800e4,0xdbc40037,0x00000000}},	//   кста, _tyg̃, _hööv, --, 
   {{0x09b400cc,0x00000000,0x00000000,0x00000000}},	//   _ঘিনা, --, --, --, 
   {{0x4254e25c,0xf38801fb,0xadf40022,0x00000000}},	// [13990] _سندر, _nảy_, нотә, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdbc40037,0x657801c3,0x3fc817a5,0xf0b40a7c}},	//   _lööv, ilth, _عددی_, _אלתר_, 
   {{0xf3880016,0xbdc01c5c,0x8b940212,0x6578002f}},	//   _bảy_, _مەرۋ, вріч, hlth, 
   {{0x3ea804fb,0xdb20a97d,0x3f986a83,0x00000000}},	//   mcat_, _یوسی, _iisu_, --, 
   {{0x3ea8e3ce,0x39480395,0x7e980066,0x00000000}},	//   lcat_, язло_, _ونگر_, --, 
   {{0x3f98e3cf,0x3ea80548,0xb6a4e3d0,0x9ba002dd}},	//   _kisu_, ocat_, нийл, _شەشى, 
   {{0x3ea8e3d1,0x3f98e3d2,0x9ac401ed,0x81f4031c}},	//   ncat_, _jisu_, _آگاہ_, _བརྕི_, 
   {{0x3f98e3d3,0x3dc8e3d4,0xf3880208,0x00000000}},	//   _misu_, nsaw_, _gảy_, --, 
   {{0x3f98e3d5,0x00000000,0x00000000,0x00000000}},	//   _lisu_, --, --, --, 
   {{0x3dc80007,0x3f980022,0x1bfc00ab,0x00000000}},	//   hsaw_, _oisu_, ईबिल_, --, 
   {{0x3f981326,0x6578e3d6,0x3ea8511a,0x794c033f}},	//   _nisu_, alth, jcat_, dźwi, 
   {{0xf3880016,0xc32c1a02,0x15f000c5,0x21a04627}},	//   _xảy_, تەي_, _अहिर_, лиям, 
   {{0x25d400c8,0x3f9800e4,0x00000000,0x00000000}},	//   _נוצן_, _aisu_, --, --, 
   {{0x3f98e3d7,0x656401ed,0x2164e3d8,0xb4bc62be}},	//   _bisu_, ékhe, хири_, ेणी_, 
   {{0x3ea8e3d9,0x3f9801bf,0x5f0001c6,0x15f0000d}},	//   gcat_, _cisu_, лзса, _अहार_, 
   {{0x3dc8e3da,0x3f98299d,0xb34003b9,0xed346135}},	// [139a0] gsaw_, _disu_, _üçqa, нэжэ, 
   {{0x6d5ce3db,0xdca000d8,0x00000000,0x00000000}},	//   unpa, гафи, --, --, 
   {{0x3ea8e3dc,0xeb98e3dd,0x6d5c127b,0x3f98008e}},	//   bcat_, чие_, rnpa, _fisu_, 
   {{0x3ea8074d,0x205404ac,0x3dc80007,0x3f980de2}},	//   ccat_, _טייל_, bsaw_, _gisu_, 
   {{0x657802d0,0x00000000,0x00000000,0x00000000}},	//   ylth, --, --, --, 
   {{0xdbc400af,0xf388004d,0x00000000,0x00000000}},	//   _rööv, _vảy_, --, --, 
   {{0xdbc40037,0xad24215c,0xd8a400ec,0xdc6428f3}},	//   _sööv, _قىڭى, رهيو_, _зард_, 
   {{0xf414015b,0xc6f82ff5,0x4aa4134e,0x00000000}},	//   াহার_, фних_, _ओलिव, --, 
   {{0xfd4c002b,0x62980153,0xe4e4003b,0x00000000}},	//   _adoṣ, žuok, нінн, --, 
   {{0x61f80120,0x0904015b,0x293c00d1,0x00000000}},	//   çulm, লাহু_, ﻟﯜﭖ_, --, 
   {{0x3ea8bea3,0x42c800f7,0x65780036,0x4aa40a8a}},	//   ycat_, үгүн_, rlth, _ओलाव, 
   {{0xdbc400af,0x3dc8011f,0x5c58008f,0x666402e8}},	//   _tööv, ysaw_, לדיק, _пълз, 
   {{0x3f98e3de,0xf1c000ef,0x3ea800d7,0x00000000}},	//   _risu_, _nišā_, vcat_, --, 
   {{0x3f98e3df,0xde8c063f,0x660401a8,0x3ea80175}},	//   _sisu_, _dịla_, ækku, wcat_, 
   {{0x3f984f61,0x3ea8e3e0,0x3dc8079b,0x4ad0dc75}},	//   _pisu_, tcat_, wsaw_, हणाव, 
   {{0x3dc89e8d,0x8f080131,0x3f980135,0xf7840790}},	//   tsaw_, нхуа_, _qisu_, _üçte_, 
   {{0x3f98e3e1,0x629c0b6f,0x00000000,0x00000000}},	// [139b0] _visu_, _igqo, --, --, 
   {{0x3dc8e3e2,0xfd600016,0x3f98e3e3,0x0ca80a31}},	//   rsaw_, _huyế, _wisu_, етци_, 
   {{0x42546c16,0x60c40100,0x3f98e3e4,0x3ea8e3e5}},	//   _سنگر, majm, _tisu_, pcat_, 
   {{0x60c4e3e6,0x3f980393,0x6930006c,0x00000000}},	//   lajm, _uisu_, یکلر, --, 
   {{0x4a74e3e7,0xf770e3e8,0xca7402dd,0x93380092}},	//   лышт, یاب_, лушы, _ይከብዳ, 
   {{0x4bb4e3e9,0xfd60004d,0xa9a001b9,0xca740116}},	//   _әйтс, _luyế, шишд, دامغ, 
   {{0x629c0117,0x00000000,0x00000000,0x00000000}},	//   _ogqo, --, --, --, 
   {{0x629c0944,0xbb4008b0,0x60c4047e,0x8b8810e0}},	//   _ngqo, ﻜﻜﻪ_, hajm, _كەلە_, 
   {{0xc7940967,0x3a74e3ea,0xa5e400f1,0x00000000}},	//   ыршы, _рлар, نډول_, --, 
   {{0x629c01f0,0xc7740228,0xe0e0009e,0x60c40010}},	//   _agqo, ктөө, য়ুন, jajm, 
   {{0x60c4e3eb,0x87d42f84,0xb384013e,0xd838004e}},	//   dajm, _مغنا, клол, _ээа_, 
   {{0x6e0006d6,0x00000000,0x00000000,0x00000000}},	//   _ḽoṱ, --, --, --, 
   {{0x939c0150,0x60c400d7,0x00000000,0x00000000}},	//   _ﺍﻟﻌﺒ_, fajm, --, --, 
   {{0x60c4e3ec,0x629c01f0,0xfbd001f9,0x00000000}},	//   gajm, _egqo, _हिंम, --, 
   {{0x84580395,0x00000000,0x00000000,0x00000000}},	//   _прът_, --, --, --, 
   {{0x09b800eb,0x00000000,0x00000000,0x00000000}},	//   ঁওতা, --, --, --, 
   {{0x7648e3ed,0x60c4b2ce,0x7afc08a5,0x00000000}},	// [139c0] nzey, bajm, _ósty, --, 
   {{0x60c4183a,0xc8e01d8a,0x62a000e2,0xc50c010f}},	//   cajm, _नाइट, āvoš, ּלאָ, 
   {{0x40d804ac,0xfba80212,0xab280024,0xebe40395}},	//   _אַרײ, етій_, можа_, тоеп, 
   {{0xfd60004d,0xeaf802c9,0xdb4c009f,0x00000000}},	//   _xuyế, ظرات_, يَل_, --, 
   {{0xe4e010fa,0xbee80205,0x00000000,0x00000000}},	//   _खालि_, ıçtı, --, --, 
   {{0xed340b5e,0x7afc0790,0x5a30004e,0xac840334}},	//   _рэмэ, _ıste, рншт, _аггл, 
   {{0x2d88047e,0x3078008f,0x00000000,0x00000000}},	//   _ihbe_, ואַנ, --, --, 
   {{0x26c0110e,0x60c41591,0x00000000,0x00000000}},	//   úko_, zajm, --, --, 
   {{0xe9a40c04,0xb374044e,0xe8e802f4,0xd5b4084c}},	//   _разп, _ራህዋን_, _омад_, ксэ_, 
   {{0x61e80139,0xa85401ee,0x00000000,0x00000000}},	//   _ägli, _итеј, --, --, 
   {{0x291ce3ee,0x18a0136b,0xe46858e5,0x00000000}},	//   _inta_, _тахм, ьшил_, --, 
   {{0xfd6007ae,0x54500801,0x2b44004d,0x76480205}},	//   _quyế, рвют, nhoc_, bzey, 
   {{0x2d88016d,0xc0c40661,0x45d401d5,0x00000000}},	//   _ohbe_, ләни, _солс, --, 
   {{0x636c04cc,0xe4640037,0x00000000,0x00000000}},	//   nùnz, ööst_, --, --, 
   {{0x60c4e3ef,0xfd6007ae,0x291c0a2e,0xcfa4e3f0}},	//   rajm, _tuyế, _mnta_, ишти, 
   {{0x629c0107,0x64540198,0x88bc012c,0x60c404a7}},	//   _ugqo, _ƙaiƙ, _hněd, sajm, 
   {{0xc29810f5,0x291ce3f1,0x60c40113,0xfaa401b9}},	// [139d0] _яких_, _onta_, pajm, қало, 
   {{0x61ec02fa,0x20b400dc,0x69a4000d,0x7d78e3f2}},	//   mtcl, _अभिध, _चढ़ी, رمار_, 
   {{0x290c00a9,0x61ec0175,0xabb400c7,0x00000000}},	//   ddfa_, ltcl, гахә, --, 
   {{0x291ce3f3,0xbee80724,0x2d88009d,0x764803e0}},	//   _anta_, ıçsı, _ehbe_, yzey, 
   {{0x61ec127b,0x00000000,0x00000000,0x00000000}},	//   ntcl, --, --, --, 
   {{0x291c003e,0x2b440208,0x61f8025c,0x00000000}},	//   _cnta_, ahoc_, ħulh, --, 
   {{0xf7f456b0,0x7e7ce3f4,0xd0f802e4,0x61ec02d0}},	//   استد, _hysp, דמות_, htcl, 
   {{0x291ce3f5,0x2b44e3f6,0x00000000,0x00000000}},	//   _enta_, choc_, --, --, 
   {{0x7ae8e3f7,0x00000000,0x00000000,0x00000000}},	//   _icet, --, --, --, 
   {{0x7e7ce3f8,0xf50801ee,0xca7400d1,0x00000000}},	//   _mysp, хнол_, _ئافغ, --, 
   {{0x7e7c1477,0x36d42c05,0x656401d3,0x6604005c}},	//   _lysp, _боер, ékha, ækkr, 
   {{0xc65482e7,0x61287cd9,0x00000000,0x00000000}},	//   افیک, _gülz, --, --, 
   {{0xde8c05db,0x6128e3f9,0xe294716a,0x55c01ac1}},	//   _dịka_, _hüly, лаю_, _талғ, 
   {{0x3b0c0369,0xafe4e3fa,0x2b4405c7,0x307412fa}},	//   _laeq_, логл, zhoc_, губс, 
   {{0x33d4005e,0xa064e3fb,0x7e7c127b,0x7ae8e3fc}},	//   _сілт, гара_, _aysp, _ocet, 
   {{0xf1c81216,0x3b0c0399,0x43740354,0x00000000}},	//   _كوبى_, _naeq_, _вуьт, --, 
   {{0x0320033f,0xf5980023,0x00000000,0x00000000}},	// [139e0] यारह_, _ወሲድካ_, --, --, 
   {{0x7e7ce3fd,0xa9a400c2,0xf4d403d4,0xe29c0174}},	//   _dysp, ҳидд, ত্ৰব, teðg_, 
   {{0xdd8c0597,0x2b44003a,0xdb0408a5,0x00000000}},	//   أول_, thoc_, _stjá, --, 
   {{0x3b0c0369,0xbae400d6,0xdca00fc0,0x5f24004e}},	//   _caeq_, ицій, _ҳари, _боюм_, 
   {{0x2b440165,0xda740395,0x00000000,0x00000000}},	//   rhoc_, ляш_, --, --, 
   {{0xdca0dabd,0x2b440489,0x6128002f,0x87b4074d}},	//   _гари, shoc_, _sülz, айкх, 
   {{0x2a9c063f,0xb7c40124,0x636c05d5,0x612806be}},	//   _ịbu_, арық, rùnz, _cüly, 
   {{0x3b0c0399,0x29100882,0x4734e3fe,0x290c005a}},	//   _gaeq_, śya_, рнис, sdfa_, 
   {{0xa3e406bc,0xe4c4023a,0xe8f818a4,0x7c280139}},	//   यून_, лённ, _пла_, _ƅerg, 
   {{0x291ce3ff,0xa9740b3e,0x00000000,0x00000000}},	//   _unta_, _субј, --, --, 
   {{0x83180214,0x6128e400,0xe6100066,0x00000000}},	//   نقدر_, _güly, _گشا_, --, 
   {{0xdc38008f,0xa258000f,0xc8c800ec,0x00000000}},	//   געטר, nbôg, _سوچن_, --, 
   {{0xd244009d,0x00000000,0x00000000,0x00000000}},	//   бэри, --, --, --, 
   {{0x61ec0582,0xffb401c0,0x00000000,0x00000000}},	//   rtcl, ийгэ, --, --, 
   {{0x61ece401,0x7e7c002f,0x63c40118,0x612803b9}},	//   stcl, _sysp, ásně, _xüly, 
   {{0x7e7c007c,0xbdd4447e,0x00000000,0x00000000}},	//   _pysp, иобщ, --, --, 
   {{0xf2c40184,0x7d54e402,0xe804033f,0x77f0095f}},	// [139f0] _өсөн, авах, _वैसा_, _अङ्क_, 
   {{0x7ae8e403,0x26c44894,0x7e7c0122,0x9c44e404}},	//   _scet, _leoo_, _vysp, лхел, 
   {{0x7e7c0034,0x00000000,0x00000000,0x00000000}},	//   _wysp, --, --, --, 
   {{0x2130036e,0x00000000,0x00000000,0x00000000}},	//   _hoxh_, --, --, --, 
   {{0xfbd001ad,0x91480139,0x7ae8013a,0x8cc0012d}},	//   _हिकम, _çıñı_, _vcet, _लड़को, 
   {{0x977058c7,0x7c280139,0x00000000,0x00000000}},	//   әткә, _ƅerd, --, --, 
   {{0xd8380323,0x0c84010b,0xa3e40807,0xdec40023}},	//   ээд_, _гытм, यूम_, _ሽሕን_, 
   {{0x7ae8e405,0x25a4e406,0xdb04037e,0xbbd001f9}},	//   _ucet, _buol_, _stjæ, हळीक, 
   {{0xb9980323,0x7544e407,0x25a40561,0x5a44009d}},	//   _авах_, иниз, _cuol_, _сэва, 
   {{0x25a40280,0x82080327,0x612806be,0xd1d80023}},	//   _duol_, _ཏནྟྲ_, _gülx, _ይኣቱ_, 
   {{0x26c40270,0x3944e408,0x33645aa6,0x1fa800cc}},	//   _feoo_, _ills_, ивог, গীতস, 
   {{0x767400f3,0x00000000,0x00000000,0x00000000}},	//   _клеф, --, --, --, 
   {{0xa3e4547d,0x4cd00154,0x00000000,0x00000000}},	//   यूब_, স্টু, --, --, 
   {{0x71981f0d,0x00000000,0x00000000,0x00000000}},	//   ئنسز_, --, --, --, 
   {{0x1e340020,0x9fc4e409,0x2f54e40a,0x2d9800d1}},	//   _የመገና, игра_, атас, _ﭘﯘﻟﻰ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8364004b,0xefc80023,0x00000000,0x00000000}},	// [13a00] _ددول, ጽእዎ_, --, --, 
   {{0xfca812ea,0x7afc2ca8,0xbec40171,0x00000000}},	//   هامو_, _ısta, erīč, --, 
   {{0x6bd4e40b,0x6c483695,0x62980024,0x1d040c69}},	//   شتار, خلاف_, žuot, рехи_, 
   {{0x3944e40c,0xa3e405ba,0x88bc013a,0x00000000}},	//   _alls_, यंत_, _oněc, --, 
   {{0xdeb8011a,0x60c8013d,0x00000000,0x00000000}},	//   _במכל, _ömmä, --, --, 
   {{0xa3e402a0,0x47d4027d,0xd9d00116,0x00000000}},	//   यूड_, ميتر, زەمگ, --, 
   {{0x394406f2,0x25a40048,0xa92401a8,0x4c8401d5}},	//   _dlls_, _suol_, _alþý, _ایاق, 
   {{0x39440228,0x25a40500,0x1ae001ee,0x00000000}},	//   _ells_, _puol_, _мосм, --, 
   {{0x78ac0882,0x2a3401c6,0x6b800175,0x00000000}},	//   śava, _тэвр, mlog, --, 
   {{0x25a400a7,0x98a00262,0x2874013d,0x00000000}},	//   _vuol_, _дифе, _кыер, --, 
   {{0xab78022e,0x0458007b,0x18640117,0x00000000}},	//   _ko鼠a, الجة_, _кафи_, --, 
   {{0x6b80e40d,0xe738005b,0x25a4e40e,0x00000000}},	//   nlog, _шее_, _tuol_, --, 
   {{0x6b80096b,0x672001e4,0x22846418,0x1ee401d3}},	//   ilog, _inoj, рунг, یوسی_, 
   {{0xd5f8025f,0x67200122,0x6b80e40f,0xd25812fa}},	//   _ספור, _hnoj, hlog, рцю_, 
   {{0x6b80e410,0x672001bf,0x43941d0f,0x00000000}},	//   klog, _knoj, _лакс, --, 
   {{0x6b80016d,0x63b800d7,0xceb80114,0x00000000}},	//   jlog, mptn, иљу_, --, 
   {{0x3cd400f7,0x00000000,0x00000000,0x00000000}},	// [13a10] йжас, --, --, --, 
   {{0x27fc0175,0x6b80b36d,0x62980153,0x00000000}},	//   _optn_, elog, žuos, --, 
   {{0x6b8000a9,0x672004ba,0x79d40131,0x8ca401d9}},	//   flog, _onoj, ﻟﺴﯩﻤ, زٕنو, 
   {{0x6b800998,0x1ea8009f,0x00000000,0x00000000}},	//   glog, _جادي_, --, --, 
   {{0xda0410e2,0x394400d7,0xfb880150,0x00000000}},	//   рчеп, _plls_, _ұрақ_, --, 
   {{0xdb0404f3,0x6b80e411,0x6720e412,0x2618012c}},	//   _stjä, alog, _anoj, बिनी_, 
   {{0xa3b40037,0x00000000,0x00000000,0x00000000}},	//   _चढ़ल_, --, --, --, 
   {{0x6b80e413,0x7d0405b1,0x68f80c8c,0xdb04036e}},	//   clog, lehs, _ebtd, _mujë, 
   {{0xdb0400e8,0x8b880131,0xb60402f0,0x00000000}},	//   _lujë, _ئەنە_, kráš, --, 
   {{0x394400f7,0x6720e414,0x7ae8004b,0x893400c6}},	//   _ulls_, _enoj, _جوړې_, _وعلا, 
   {{0xb6040306,0x4990e415,0x57240ed8,0x00000000}},	//   dráš, _تیور, _پراق, --, 
   {{0x6720341a,0xdb040054,0x7d04020c,0x5ec000d1}},	//   _gnoj, _utjä, hehs, _ﺩﻩﯞﺭ, 
   {{0xa6c801e1,0x00000000,0x00000000,0x00000000}},	//   _tọrá, --, --, --, 
   {{0x67200b9b,0xf36464c2,0xb2240022,0xdb040200}},	//   _znoj, ртүн, _ҳмил, _bujë, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x27e804ce,0xf1d08b2d,0xb208022e,0x00000000}},	//   _åbne_, _нөгө, _беиз_, --, 
   {{0xc1d40b8d,0x6b80e416,0x22900150,0x00000000}},	// [13a20] _мөрә, vlog, _ىلىس, --, 
   {{0xc7b80841,0x31084ea0,0x6b80016d,0x7d04002f}},	//   _hrđe_, _сноп_, wlog, gehs, 
   {{0x6b80e417,0x00000000,0x00000000,0x00000000}},	//   tlog, --, --, --, 
   {{0x6b8019f5,0x7e680427,0xaa88030f,0x00000000}},	//   ulog, _žepe, هنام_, --, 
   {{0xb0e4031c,0x00000000,0x00000000,0x00000000}},	//   _སྐོེ, --, --, --, 
   {{0x6b80e418,0xd6d4052f,0x6cc400f7,0xbb400131}},	//   slog, ҡты_, _ыйга, ﻜﻜﻰ_, 
   {{0x6c3413e1,0x6b80e419,0x6d5ce41a,0xdb044e9b}},	//   _افزا, plog, mipa, _stjå, 
   {{0x6d5c18e0,0xa3e40d0a,0x68f80175,0xaa4400d8}},	//   lipa, यंस_, _wbtd, _лебл, 
   {{0xe4a4009d,0xca780150,0x00000000,0x00000000}},	//   йрно, _тәжі_, --, --, 
   {{0x03f80063,0x55700022,0x9f40036e,0xdee40092}},	//   аној_, згьт, tujë_, _ማዳን_, 
   {{0x4394e41b,0xdd78010f,0x00000000,0x00000000}},	//   жанс, רטיל, --, --, 
   {{0xdc9804ac,0x67200117,0xf7b41291,0x00000000}},	//   טייל, _unoj, _بگوش_, --, 
   {{0x6d5ce41c,0xe694007b,0xd2440262,0xf1c801e1}},	//   kipa, _الشد, пэри, _ruáá_, 
   {{0x6d5ce41d,0x7d04009a,0x00000000,0x00000000}},	//   jipa, xehs, --, --, 
   {{0x6d5ce41e,0xd48ce41f,0x6578e420,0x00000000}},	//   dipa, _хр_, moth, --, 
   {{0x6578e421,0x7eb806bb,0x6d5c0b4f,0x94700014}},	//   loth, ргас_, eipa, _ژھێچ, 
   {{0x171804ac,0x6d5c0ca8,0x7d0403be,0x63a80067}},	// [13a30] נומע, fipa, tehs, _hufn, 
   {{0x6578e422,0x6d5c1cf3,0x63a8e423,0xdcec0139}},	//   noth, gipa, _kufn, _pucı, 
   {{0x7d04e424,0x30ec00dc,0xdc88009d,0x00000000}},	//   rehs, _जातः_, усал_, --, 
   {{0x7d0417da,0x6d5ce425,0x50b800f2,0x00000000}},	//   sehs, aipa, _پدید_, --, 
   {{0x65785935,0x7f4c014b,0x6d5ce426,0xf9906bcc}},	//   koth, mhaq, bipa, وبت_, 
   {{0xdb0400e8,0x7f4ce427,0x65780477,0x83080327}},	//   _mujé, lhaq, joth, _ཇིའུ_, 
   {{0x6578e428,0x00000000,0x00000000,0x00000000}},	//   doth, --, --, --, 
   {{0x7f4ce429,0x00000000,0x00000000,0x00000000}},	//   nhaq, --, --, --, 
   {{0x6578e42a,0x63a80730,0xa3e406ab,0x7af80369}},	//   foth, _aufn, यूस_, mfwt, 
   {{0xdb040066,0x63a8054e,0x3dcc03d4,0x00000000}},	//   _sujè, _bufn, _ৰঙাল, --, 
   {{0x7f4c0cfe,0xf6d400d6,0xd844912e,0xe29c0008}},	//   khaq, _діля, _ухап, veða_, 
   {{0x6d5ce42b,0x63a82501,0x95b001af,0x00000000}},	//   zipa, _dufn, _еркә, --, 
   {{0x6578e42c,0x0708e42d,0xdb04002d,0x7f4c9f02}},	//   both, _ديني_, _stjû, dhaq, 
   {{0x6578004b,0xb87406d6,0x63a80ba7,0xa3e40d41}},	//   coth, _eḓe, _fufn, यूह_, 
   {{0xa0a0e42e,0x6d5ce42f,0x4cc82b1b,0x671c0490}},	//   дард, vipa, _লালু, _मोडक_, 
   {{0x7768e430,0x6d5c094a,0x69c801ad,0x7f4c0477}},	//   nnex, wipa, सीडी, ghaq, 
   {{0x6d5ce431,0xc2e81d37,0xecb8007b,0x00000000}},	// [13a40] tipa, _اعىم_, لطات_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d5c2295,0xdb04002d,0x7f4c4b2a,0xac080798}},	//   ripa, _utjû, bhaq, рнеа_, 
   {{0x6d5ce432,0x65780912,0x7f4c8957,0xef180117}},	//   sipa, zoth, chaq, _тмм_, 
   {{0x6578e433,0x6d5ce434,0xceb40213,0x00000000}},	//   yoth, pipa, mcə_, --, 
   {{0x6d5ce435,0xceb400ac,0x6578e436,0x2c2c0023}},	//   qipa, lcə_, xoth, _ተዋሂቡ, 
   {{0xec14e437,0xdc64020a,0x38c80150,0x00000000}},	//   _بوزد, _дард_, суін_, --, 
   {{0x44200745,0x6f14e438,0xceb40cc1,0x6578e439}},	//   _či_, ndyc, ncə_, woth, 
   {{0x6578e43a,0x442002b1,0x7580e43b,0xfb2400db}},	//   toth, _ōi_, کیوم, _эптү, 
   {{0x59001b4b,0x88bc012c,0xc8e401ec,0x77680332}},	//   _ཚིགས_, _zněn, _ءقاۋ, anex, 
   {{0xd6cc6582,0xceb403be,0x7768003a,0x7f4c022e}},	//   _от_, kcə_, bnex, yhaq, 
   {{0x6578e43c,0xe5a4035b,0x36440131,0xb864038b}},	//   soth, _диди, تىۋې, _عالو, 
   {{0xdb980bd9,0x6f1403cb,0xceb40213,0x25700150}},	//   יסטר, ddyc, dcə_, _оқис, 
   {{0x6578016c,0x6600e43d,0x63a800f3,0x7f4c0455}},	//   qoth, _ipok, _tufn, whaq, 
   {{0xd018e43e,0x4034e43f,0x01a805d9,0x7f4c009a}},	//   офт_, чевс, _گڏجي_, thaq, 
   {{0x3cfc038e,0x1ee428b1,0x6600e440,0x00000000}},	//   र्ने_, توری_, _kpok, --, 
   {{0x7f4c01b9,0x7cd8e441,0x4f2c0023,0x00000000}},	// [13a50] rhaq, ймар_, _ተጻዋር, --, 
   {{0x6600e442,0x8d7400c1,0x7f4ce443,0x4154e444}},	//   _mpok, والا, shaq, _хвос, 
   {{0x7f4c02d1,0x6d8801d3,0x7bf8010a,0xfbd000ec}},	//   phaq, حملہ_, снер_, عڪس_, 
   {{0x6600035b,0x7f4c0944,0x9d080154,0xceb403e3}},	//   _opok, qhaq, রাইভ_, ccə_, 
   {{0x7768e445,0xf8a800f2,0x00000000,0x00000000}},	//   vnex, مگاه_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6600e446,0x77680175,0x3a280356,0xb34000a2}},	//   _apok, tnex, ţap_, _üçga, 
   {{0xdb200722,0x671c1fca,0x3e40001f,0x15e000d1}},	//   _توری, _मोदक_, _የመድረ, _ﺋﻪﺭﻩ, 
   {{0x77680003,0x00000000,0x00000000,0x00000000}},	//   rnex, --, --, --, 
   {{0xceb400ac,0x343800c6,0xd7f80798,0xe79401d9}},	//   zcə_, مسجد_, _вуд_, _ہانک, 
   {{0x6600e447,0xa3e445bf,0x7d14e448,0x3cfc0b7c}},	//   _epok, यूल_, _mazs, र्ये_, 
   {{0xd76001d3,0xe794179e,0x00000000,0x00000000}},	//   _تنصی, _فانک, --, --, 
   {{0xef1800fb,0x5664bf4e,0x98a40166,0x00000000}},	//   ҙма_, _بداف, linı_, --, 
   {{0xef1000aa,0xc7b80841,0x3cfc084d,0x00000000}},	//   کټر_, _hrđa_, र्मे_, --, 
   {{0x6020e449,0x94740066,0x00000000,0x00000000}},	//   ндра, _بدشا, --, --, 
   {{0xa258019f,0xa0301473,0x7e6825b4,0x7c280139}},	//   mbôn, رىقت, _žepa, _ƅern, 
   {{0xc7b8009b,0x248c00f3,0xee389842,0xceb40213}},	// [13a60] _mrđa_, _zzfm_, щна_, rcə_, 
   {{0x98a40166,0x00000000,0x00000000,0x00000000}},	//   kinı_, --, --, --, 
   {{0xc608547d,0x3cfc00c5,0xceb403b9,0x00000000}},	//   _वन्य_, _रउरे_, pcə_, --, 
   {{0x6da4e44a,0xada40075,0x2f540845,0x0dec001f}},	//   _нима, _намл, _хтос, ቅረፍ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa3e4033f,0x7d14e44b,0x00000000,0x00000000}},	//   यूँ_, _gazs, --, --, 
   {{0x660024b6,0x17f400c6,0x6c342d4b,0x7af0005b}},	//   _spok, كرية_, _عفرا, ähtö, 
   {{0xf1bc2e35,0xf1cc04ce,0x85b848e5,0x45b8005b}},	//   ्ठान, _o彡_, олис_, огию_, 
   {{0xed600092,0x00000000,0x00000000,0x00000000}},	//   _ተከታይ_, --, --, --, 
   {{0xdb045792,0x368805f5,0x66000427,0x00000000}},	//   _stjø, өсөн_, _vpok, --, 
   {{0x667403e6,0x58b8011a,0xa3e4424e,0x7824007b}},	//   _کدار, _המבצ, यूं_, _يعمل, 
   {{0x7800013e,0x2b440156,0x00000000,0x00000000}},	//   _рӯша, nkoc_, --, --, 
   {{0x7afce44c,0x6600e44d,0x5224e44e,0xd68000d8}},	//   _öste, _upok, нфра, _пушп, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7d140fb7,0x4acc08e6,0xc688009f,0x00000000}},	//   _razs, ाराव, _اَڇن_, --, 
   {{0x35d00c2e,0x8f34e44f,0xb9e4001f,0xa3e42144}},	//   _दौड़, несц, _ሪፖ_, यूः_, 
   {{0xc434066d,0xa508025c,0x3df4e450,0x00000000}},	// [13a70] _رکھت, _ཀྲོག_, ьзас, --, 
   {{0x2b44030a,0x9f400118,0x7d1403b9,0x00000000}},	//   ekoc_, mují_, _qazs, --, 
   {{0x7d1404cc,0x69c81d72,0x9f4000bc,0xa3b0107c}},	//   _vazs, सीसी, lují_, _झूम_, 
   {{0x8c44054e,0x00000000,0x00000000,0x00000000}},	//   _ăşti, --, --, --, 
   {{0x2bcc0b40,0x9f4000bc,0x7d140419,0x4c94013d}},	//   हीबा, nují_, _tazs, _җитс, 
   {{0x3f88e451,0xc7b8110c,0x3eb80ea0,0x00000000}},	//   llau_, _srđa_, _hfst_, --, 
   {{0x3f8800a9,0x9f40012c,0x3eb801bf,0x3cfc00dc}},	//   olau_, hují_, _kfst_, र्णे_, 
   {{0xb6a48fbb,0x9f4000bc,0xafe401bf,0x00000000}},	//   мийл, kují_, ljøø, --, 
   {{0xe61400ee,0x3f880421,0x3cfc00dc,0x9f400118}},	//   дды_, ilau_, र्थे_, jují_, 
   {{0xb8741682,0x9f40012c,0x3f882ad7,0x7afc01e3}},	//   _eḓa, dují_, hlau_, _östb, 
   {{0x3f880598,0x00000000,0x00000000,0x00000000}},	//   klau_, --, --, --, 
   {{0x3cfc0a59,0xa258e452,0x888c010f,0x70c4c126}},	//   र्ते_, rbôn, _פראַ, वर्ल, 
   {{0x20100054,0xdb04019f,0xa3b01533,0x2d98e453}},	//   _asxi_, _kujâ, _झूठ_, ympe_, 
   {{0x3f8803cb,0x7c280139,0x00000000,0x00000000}},	//   elau_, _ƅerl, --, --, 
   {{0x21a0e454,0x3f880c86,0xb4e852f2,0xb60c01ec}},	//   тирм, flau_, यली_, _ﹰﻤ_, 
   {{0x3f88e455,0xdb040407,0x9f40012c,0x2ca80129}},	//   glau_, _bují, bují_, _sgbd_, 
   {{0x88bc012c,0x9f4000bc,0xa698010f,0x2b440010}},	// [13a80] _sněm, cují_, ַשעפ, vkoc_, 
   {{0x3eb8008c,0x3f88e456,0x999c00a2,0x646008a5}},	//   _efst_, alau_, _uruň_, _æviá, 
   {{0x92d0045e,0x3f88e457,0x00000000,0x00000000}},	//   শলী_, blau_, --, --, 
   {{0x3f88e458,0xea880108,0x00000000,0x00000000}},	//   clau_, обел_, --, --, 
   {{0xbaa400d1,0xf32c0092,0x00000000,0x00000000}},	//   нушқ, _እየተና, --, --, 
   {{0x4acc0b7d,0x3cfce459,0x2b44030a,0x4cc800cc}},	//   ारहव, र्दे_, skoc_, _লাকু, 
   {{0x6d4ce45a,0x9f40012c,0x98a4033f,0xdce40055}},	//   _ilba, zují_, yjną_, _ujjā, 
   {{0x261800c5,0x00000000,0x00000000,0x00000000}},	//   बिली_, --, --, --, 
   {{0xe4e402bf,0xa508031c,0x00000000,0x00000000}},	//   мінн, _ཀྲུག_, --, --, 
   {{0x9f40012c,0x00000000,0x00000000,0x00000000}},	//   vují_, --, --, --, 
   {{0x3f88e45b,0x00000000,0x00000000,0x00000000}},	//   ylau_, --, --, --, 
   {{0xe6646eec,0x9f4000bc,0x00000000,0x00000000}},	//   _отло, tují_, --, --, 
   {{0x6d4ce45c,0xa2d80e7d,0x69c00247,0x2bcc01bc}},	//   _olba, पृष्, npoe, हीता, 
   {{0x9f4000bc,0xd25003e6,0x7e680427,0x3f8803cb}},	//   rují_, شۆپ_, _žepo, wlau_, 
   {{0x3f88e45d,0x23b80055,0x1fa46ed2,0x9f400118}},	//   tlau_, _bīje_, драг, sují_, 
   {{0xcebc00ac,0x69c0e45e,0x9f4000bc,0x8f080022}},	//   _şərq_, kpoe, pují_, мхуа_, 
   {{0x3f88e45f,0x88bc012c,0xb8d0031c,0x3d9400c7}},	// [13a90] rlau_, _vněj, _དྔ_, еиар, 
   {{0x3f88e460,0x4d9806a6,0x69c0e461,0x5ba4085c}},	//   slau_, дкую_, dpoe, गद्व, 
   {{0x69c0e462,0x00000000,0x00000000,0x00000000}},	//   epoe, --, --, --, 
   {{0x3098025f,0x6d4ce463,0xfb8404d3,0x3a74e464}},	//   _משתמ, _elba, ردای, нлер, 
   {{0x4ea40588,0x6eb804ae,0xca74013d,0x4a7400db}},	//   _арра, _מזרח, кушы, кышт, 
   {{0xdb0400d8,0x00000000,0x00000000,0x00000000}},	//   _bujã, --, --, --, 
   {{0x17080327,0xb6f800d1,0x00000000,0x00000000}},	//   _ཁྲུམ_, كىغا_, --, --, 
   {{0x5bc80073,0x69c050eb,0x00000000,0x00000000}},	//   ाठीव, bpoe, --, --, 
   {{0x1a6400aa,0x398809f3,0x69c000cf,0xf65000ae}},	//   _کیږی_, húsi_, cpoe, طئة_, 
   {{0xe00c6225,0xb4e80316,0xa258002d,0x39880419}},	//   ाबाद_, यले_, rbôl, kúsi_, 
   {{0xa3e41414,0x6ad000cc,0xa44001c4,0x00000000}},	//   यंग_, _হাতো, гнэд, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x15f00034,0x00000000,0x00000000,0x00000000}},	//   _आमिर_, --, --, --, 
   {{0xceb403b9,0x00000000,0x00000000,0x00000000}},	//   ddəa_, --, --, --, 
   {{0x7fd40220,0x64a00131,0xa3e400ab,0x69c001e4}},	//   кіті, _йаша, _पिय_, zpoe, 
   {{0xb8d00dd4,0x4ec0009e,0x1fa4c2f3,0x69c0062c}},	//   _དཔ_, েল্ল, екси_, ypoe, 
   {{0x26d8013f,0x69c05880,0x437400d8,0x00000000}},	// [13aa0] _ɛpo_, xpoe, _шушт, --, 
   {{0xb8741682,0x9f44025a,0x1e80e465,0x6da46c00}},	//   _nḓo, _ênî_, улум, хиза, 
   {{0xdd8c3e43,0x6c746f42,0x81e400cc,0x00000000}},	//   حول_, хуах, _নহয_, --, 
   {{0x2d640241,0x69c0e466,0x7c9400d8,0x00000000}},	//   _bíeè_, tpoe, труц, --, 
   {{0x6d4c0333,0x05d40490,0x9a8000ee,0x00000000}},	//   _tlba, _धबधब, лушл, --, 
   {{0x9a64c019,0x6d4ce467,0x00000000,0x00000000}},	//   عمول_, _ulba, --, --, 
   {{0x69c0057b,0x00000000,0x00000000,0x00000000}},	//   spoe, --, --, --, 
   {{0x69c0e468,0xd7f407d5,0xe5c43a49,0xaac41541}},	//   ppoe, хуш_, нсоо, _سترن, 
   {{0x6b80e469,0x3cfcd8a4,0x964001c0,0x7afc1355}},	//   moog, र्वे_, гээд, _östa, 
   {{0x6b80033d,0x5a600395,0x636801f4,0xdb0c0248}},	//   loog, _скуб, könä, _ìdòw, 
   {{0x6844010b,0x53e000c7,0x7d000f7d,0x92d000fe}},	//   _янжа, гәыҕ, _ölse, শলৈ_, 
   {{0x290ce46a,0x6b80b643,0x88bc012c,0xa3e40073}},	//   lefa_, noog, _sněh, _पिठ_, 
   {{0x1b0000eb,0x00000000,0x00000000,0x00000000}},	//   _রোডে_, --, --, --, 
   {{0x290ce46b,0x6b80e46c,0x00000000,0x00000000}},	//   nefa_, hoog, --, --, 
   {{0xdb040407,0x6b8011d4,0x00000000,0x00000000}},	//   _lujá, koog, --, --, 
   {{0x290c325f,0x6b80e46d,0xa4a40086,0xfaf80055}},	//   hefa_, joog, _ekòñ, _amūn_, 
   {{0x6b80e46e,0x290c0109,0x9ce401f4,0x00000000}},	// [13ab0] doog, kefa_, ецел, --, 
   {{0x290c0198,0x645406be,0x8de4007b,0x00000000}},	//   jefa_, _əyin, اكله, --, 
   {{0xceb403be,0x290c05da,0x6b800e14,0xa0a4694c}},	//   mdən_, defa_, foog, _яшил, 
   {{0xdb040599,0xceb400ac,0xc0dc0023,0x00000000}},	//   _bujá, ldən_, _ንዂሉ_, --, 
   {{0xdb041c38,0x9f400120,0x290c009a,0x0e080276}},	//   _stjó, cujá_, fefa_, _пэри_, 
   {{0xceb411a9,0xaa408b82,0x6b800421,0x00000000}},	//   ndən_, решл, aoog, --, 
   {{0x6b80607d,0x4c942de8,0x00000000,0x00000000}},	//   boog, _бирс, --, --, 
   {{0x7bc4e46f,0xbb4c1c5c,0x290c0421,0x5900025c}},	//   mphu, ﺍﺭﻯ_, aefa_, _ཚིམས_, 
   {{0x7bc4e470,0xceb403be,0x290c01af,0x3914e471}},	//   lphu, kdən_, befa_, _имар, 
   {{0x2bcc0118,0x00000000,0x00000000,0x00000000}},	//   हीवा, --, --, --, 
   {{0xf3e40801,0x7bc401fb,0xceb40213,0x95b00131}},	//   ъжно, nphu, ddən_, _өрлә, 
   {{0x203802d3,0x7bc40051,0xf69800ae,0x00000000}},	//   _ኣመራር, iphu, _قناع_, --, 
   {{0x7bc4e472,0xe294e473,0xceb400ac,0xaad8011a}},	//   hphu, каю_, fdən_, וחרר, 
   {{0xf8d0375c,0x6b8004ba,0xceb406be,0xafe40fac}},	//   हरिय, zoog, gdən_, когл, 
   {{0x998c0024,0x6b800337,0x00000000,0x00000000}},	//   lygų_, yoog, --, --, 
   {{0xb224e474,0xdb140054,0x290ce475,0x6b800014}},	//   _амил, npxä, zefa_, xoog, 
   {{0x3988043b,0x61ec026c,0xceb400ac,0x6a64022e}},	// [13ac0] lúsu_, cucl, bdən_, _kаfe, 
   {{0xdd8ce476,0x30280372,0x386809a5,0x63ac00c6}},	//   قوق_, _жооп_, şary_, _úiné, 
   {{0x6b80e477,0xdcac1dc8,0x26f8009e,0x290ce478}},	//   toog, زىن_, ্যতো_, vefa_, 
   {{0x6b800421,0xa3e45325,0x00000000,0x00000000}},	//   uoog, यूट_, --, --, 
   {{0x6b80e479,0xfe7400f7,0x290ce47a,0x00000000}},	//   roog, _бүт_, tefa_, --, 
   {{0x7bc4e47b,0x6b80e47c,0x7afc01e3,0xdd140419}},	//   bphu, soog, _östn, _päťs, 
   {{0x9d1800c8,0x97d400b2,0x290ce47d,0xd5f400b5}},	//   _קולט, نظير_, refa_, _aチ_, 
   {{0xceb403be,0xdb047523,0x59cc00bc,0x9c14011a}},	//   zdən_, _tujá, सीहर, _בחלק_, 
   {{0xbb74020a,0xa84805d9,0x6a840014,0xe3f404ce}},	//   _суръ, _ڪلام_, _ششرٕ, _sケ_, 
   {{0x7e680219,0xe7e80490,0x68440408,0x9f640092}},	//   _žepk, _टिपा_, _инза, _ተገደሉ_, 
   {{0x23b800cd,0xceb40213,0x00000000,0x00000000}},	//   _bīja_, vdən_, --, --, 
   {{0xa6a80214,0x6e2402d0,0x00000000,0x00000000}},	//   _قاشق_, _orkb, --, --, 
   {{0xa3e45c0e,0xceb403be,0x6e24003b,0x680806be}},	//   यूज_, tdən_, _nrkb, _bədg, 
   {{0x7bc4e47e,0xc6a401af,0x00000000,0x00000000}},	//   yphu, _ирҙи, --, --, 
   {{0xceb40cc1,0x6e24e47f,0x61ec01fa,0xd0d4020f}},	//   rdən_, _arkb, sucl, росъ, 
   {{0xd4340302,0xceb40213,0x64540213,0xd3a40153}},	//   _ירוק_, sdən_, _əyil, _крып, 
   {{0x680800ac,0x7bc4009a,0x2b8c219b,0x6458002f}},	// [13ad0] _hədd, wphu, mých_, lzti, 
   {{0x2b8c03c6,0xc11400d8,0x4034014b,0xceb403e3}},	//   lých_, _смој, _беос, qdən_, 
   {{0xe1fce480,0xebc00075,0x7bc4e481,0x2bcc0bae}},	//   ltó_, йәтн, uphu, हीला, 
   {{0x2b8c076f,0xc690001f,0x9de40014,0x64582457}},	//   ných_, _ቅድሚያ_, _لہرٕ_, izti, 
   {{0xe1fce482,0x7f4c0309,0x4ba80137,0x13c80154}},	//   ntó_, mkaq, төрү_, লওয়, 
   {{0x2b8c0232,0x7f4ce483,0x7bc40250,0x89a8003b}},	//   hých_, lkaq, pphu, вків_, 
   {{0x2b8c8ea8,0xe1fce484,0xa3b0230e,0x00000000}},	//   kých_, htó_, _झूल_, --, 
   {{0xe1fc011f,0x7f4c50d4,0x3b5409a5,0x34bc00cd}},	//   któ_, nkaq, _ёкар, ोर्द, 
   {{0x47d0045e,0x2b8c0122,0x6458005f,0xe1fc01ed}},	//   সংগী, dých_, ezti, jtó_, 
   {{0xc984e485,0x398802d2,0x00000000,0x00000000}},	//   _кухи, gúst_, --, --, 
   {{0x7f4c0429,0xe1fc004e,0x64580024,0x934400d1}},	//   kkaq, etó_, gzti, لىدۇ, 
   {{0x8c440166,0x00000000,0x00000000,0x00000000}},	//   _öşet, --, --, --, 
   {{0x3988043b,0x00000000,0x00000000,0x00000000}},	//   súsu_, --, --, --, 
   {{0xe00c02ab,0x76480083,0xf8e40154,0x00000000}},	//   ाबंद_, myey, প্রথ, --, 
   {{0x7648e486,0x2b8c02fb,0x6fb4e487,0xaf981553}},	//   lyey, bých_, امرا, етах_, 
   {{0xafe401d5,0x88bc013a,0x00000000,0x00000000}},	//   коҳл, _hnět, --, --, 
   {{0x2374c852,0xe1fc04cf,0xfe440166,0x00000000}},	// [13ae0] _حميد_, ctó_, амтү, --, 
   {{0x76480009,0xbce4007b,0x5d6400d8,0xceb406be}},	//   iyey, لأمو, гиум_, mdəm_, 
   {{0x6000013f,0xb604e488,0xb3e000cc,0x00000000}},	//   _yεmm, _hašč, _বহুও, --, 
   {{0x7afce489,0xb6040010,0x76481418,0xdb040139}},	//   _östl, _kašč, kyey, _nujä, 
   {{0xa968301f,0x29883117,0xceb40213,0x38900b82}},	//   нида_, нско_, ndəm_, _ምሕረቱ_, 
   {{0xb604151c,0xbab80131,0x6d4801b8,0x35dc033f}},	//   _mašč, _ﺧﯩﺘﺎ, öfad, _मिज़, 
   {{0xd5b4005e,0xb6040427,0x76480067,0xf1c00219}},	//   қсы_, _lašč, eyey, lašč_, 
   {{0xe1fc0548,0x4994001f,0x7e680010,0x680806be}},	//   ytó_, ክኖሎጂ_, _žepi, _rədd, 
   {{0x2b8c8ea8,0x7648e48a,0x680803e3,0x00000000}},	//   vých_, gyey, _sədd, --, 
   {{0xa9a4661e,0x64580e78,0x00000000,0x00000000}},	//   _сизд, tzti, --, --, 
   {{0x2b8c03c6,0x291ce48b,0x76480083,0x68f802d0}},	//   tých_, _iata_, ayey, _ictd, 
   {{0x291ce48c,0xe1fce48d,0x764801aa,0xd494e48e}},	//   _hata_, ttó_, byey, ыры_, 
   {{0x291ce48f,0x2b8c03c6,0x6458066d,0x45d4e490}},	//   _kata_, rých_, szti, _толс, 
   {{0x291ce491,0xe1fce492,0x7f4c0113,0xb6040153}},	//   _jata_, rtó_, wkaq, _dašč, 
   {{0x291ce493,0xe1fce494,0x2038044e,0x4fc4e495}},	//   _mata_, stó_, _ኣዘራር, йста, 
   {{0x291ce496,0xe1fc09d7,0x21640131,0x00000000}},	//   _lata_, ptó_, _әтиг, --, 
   {{0x291c0421,0xe1fc011f,0x7f4c0309,0x70740092}},	// [13af0] _oata_, qtó_, rkaq, ተላለፉ_, 
   {{0x291ce497,0x7f4c0309,0x00000000,0x00000000}},	//   _nata_, skaq, --, --, 
   {{0xb6040f72,0x7f4c0cfe,0x4034084c,0xfca802dd}},	//   _zašč, pkaq, _тенс, тсақ_, 
   {{0x291c04fe,0x4c94e498,0xf2940ca8,0x76480429}},	//   _aata_, щихс, _abẹ́_, yyey, 
   {{0x291ce499,0x23b81bce,0x7afc01e3,0xf8a800f2}},	//   _bata_, _lëj_, _östm, چگاه_, 
   {{0x291c5909,0x76481459,0xf8a8d712,0x3dc8025c}},	//   _cata_, vyey, نگاه_, mpaw_, 
   {{0x291ce49a,0xbd040241,0x21fc05da,0x60d401d5}},	//   _data_, _eléè, hîh_, _mexm, 
   {{0x291c0b23,0x25ac00a3,0x59240135,0x3e5c001f}},	//   _eata_, _aifl_, _ཡོམས_, _ለመድረ, 
   {{0x291ce49b,0xab6028f7,0x3dc80652,0x68f80175}},	//   _fata_, _بۇنى, npaw_, _fctd, 
   {{0x291ce49c,0x23b8e49d,0xb6040552,0x60d4020b}},	//   _gata_, _bëj_, _rašč, _nexm, 
   {{0x7bc00129,0x00000000,0x00000000,0x00000000}},	//   _élud, --, --, --, 
   {{0x291c3142,0xb8741aa1,0x23b800e8,0x25ec0490}},	//   _zata_, _nḓi, _dëj_, _आमची_, 
   {{0x291ce49e,0x88d8015b,0xeb38008f,0x90b400d1}},	//   _yata_, _সাতক, דערש, йәнш, 
   {{0x3c0405f9,0xf3f001f2,0xd3480344,0xb6040427}},	//   _रहूँ_, pụ_, ئیکه_, _vašč, 
   {{0xa064e49f,0x23b800e8,0x457400f1,0x51ac02dd}},	//   аара_, _gëj_, _دپوځ, _ﺳﻮﻧﺸ, 
   {{0xb60409a8,0xf1d0e4a0,0xc884008e,0x00000000}},	//   _tašč, _мөгө, leşä_, --, 
   {{0x60d40998,0x3dc80280,0x99980116,0x91a00208}},	// [13b00] _fexm, gpaw_, _дaим_, _trì_, 
   {{0x8c48010e,0xf064011c,0x00000000,0x00000000}},	//   _neşä, _вкоп, --, --, 
   {{0x7e7c1730,0x3dc8079b,0xc10406c5,0xceb406be}},	//   _exsp, apaw_, _اوپي, ndək_, 
   {{0x291ce4a1,0x61b001d9,0x00000000,0x00000000}},	//   _sata_, _دٕیا, --, --, 
   {{0x60d40b6f,0xda60e4a2,0x320002fb,0x63380092}},	//   _yexm, овци, ntky_, _እየጠበ, 
   {{0x291ce4a3,0xa3e401ad,0x28c401ad,0x2d886f35}},	//   _qata_, _पिल_, _र्शि, _ukbe_, 
   {{0x291c601a,0xeab8020a,0xe89000c7,0x00000000}},	//   _vata_, _айб_, әақь, --, 
   {{0x291ce4a4,0xdb040008,0x4734084c,0x45d40107}},	//   _wata_, _stjö, снис, боис, 
   {{0x291ce4a5,0x320002f0,0x00000000,0x00000000}},	//   _tata_, jtky_, --, --, 
   {{0xe4a44fe9,0x291c03a0,0x68f80857,0x81e400cc}},	//   ирно, _uata_, _uctd, _নহল_, 
   {{0x32000030,0x48240131,0x00000000,0x00000000}},	//   etky_, _ھىچق, --, --, 
   {{0x68080cc1,0x7bc00129,0x6db40171,0x00000000}},	//   _tədb, _élue, _kņad, --, 
   {{0x9268035b,0xb7b401e1,0x9440030f,0x3200010b}},	//   арра_, _iṣa, مپین, gtky_, 
   {{0x2248049f,0xa1840953,0x23b80694,0x94d000f7}},	//   ryck_, рымл, _tëj_, _ۇيۇش, 
   {{0x32001d55,0x9f4000d0,0x3dc8b1ee,0x00000000}},	//   atky_, mujú_, wpaw_, --, 
   {{0x28c40882,0x9f400030,0x00000000,0x00000000}},	//   रुति, lujú_, --, --, 
   {{0x91e40131,0x47d00154,0x3200013a,0x00000000}},	// [13b10] _мәрһ, সূচী, ctky_, --, 
   {{0x9f400030,0x7cd803e6,0x91a0004d,0x04f400cc}},	//   nujú_, اواز_, _trí_, _অসুৰ_, 
   {{0x3cfca06f,0x7afc01e3,0x80dc0154,0x5ba40024}},	//   र्गे_, _östk, _বাপ্, ардз, 
   {{0x9f4001f1,0x3dc80003,0x61ec01e7,0x8fa400d8}},	//   hujú_, ppaw_, orcl, _маќе, 
   {{0x9f400030,0xaee001ec,0x7d00007c,0x00000000}},	//   kujú_, _رۋلى, _ölso, --, 
   {{0x3f88e4a6,0x9f4000d0,0x61ec00a3,0x3cfc2c2e}},	//   loau_, jujú_, ircl, र्खे_, 
   {{0x9f400030,0x2000003c,0xcd840ef6,0x67d00120}},	//   dujú_, ntji_, _بۇلۋ, поју, 
   {{0x3f880270,0x320002fb,0x29c80116,0x00000000}},	//   noau_, ytky_, _әттү_, --, 
   {{0xef10010f,0x00000000,0x00000000,0x00000000}},	//   פּה_, --, --, --, 
   {{0xd1d802d3,0x9f4000d0,0xb4e00073,0x28c400cd}},	//   _ክኣቱ_, gujú_, धणे_, रुदि, 
   {{0xb8940491,0x3f8800b0,0xd7f80de7,0xb3400205}},	//   _الاع, koau_, _шуа_, _üçka, 
   {{0xdb04067c,0x0708785c,0x00000000,0x00000000}},	//   _aujú, _نيمي_, --, --, 
   {{0xb0340075,0x9f4001f1,0x54b00daf,0x394403cd}},	//   ڭىزغ, bujú_, _мәнф, _kols_, 
   {{0x32000122,0x39440ba1,0x23b0004b,0x9f400030}},	//   rtky_, _jols_, _کميس, cujú_, 
   {{0x32000232,0x39446d38,0x61ec01ab,0x63c40118}},	//   stky_, _mols_, arcl, ěrné, 
   {{0xb8d876ff,0x3944e4a7,0x7afc01e3,0x00000000}},	//   _ཚུ_, _lols_, _östh, --, 
   {{0x680803b9,0xa2f4011a,0x00000000,0x00000000}},	// [13b20] _məda, _המפה_, --, --, 
   {{0xe120030d,0xafe4009d,0x00000000,0x00000000}},	//   _емьи, _лоол, --, --, 
   {{0xab28a319,0x00000000,0x00000000,0x00000000}},	//   ложа_, --, --, --, 
   {{0x9f4001f1,0xd1043874,0x00000000,0x00000000}},	//   zujú_, श्रण_, --, --, 
   {{0x69244cc4,0x6f14047e,0x93380092,0x00000000}},	//   ймда, meyc, _እየተሳ, --, 
   {{0x3944e4a8,0x6f14e4a9,0x636c02e2,0x58d0e4aa}},	//   _cols_, leyc, _kònè, пошт, 
   {{0xa3f00d42,0x39447704,0x9f4001f1,0x680806be}},	//   _জন্য_, _dols_, vujú_, _bəda, 
   {{0x6f14a2e5,0xf404031c,0x6ef0022e,0x27ec0076}},	//   neyc, _མྱེད_, _xаbа, rrfn_, 
   {{0x39444c18,0x9f4000d0,0xe70801d5,0x00000000}},	//   _fols_, tujú_, نتکن_, --, 
   {{0x3944e4ab,0xc7b8107d,0x7bc006af,0xa3e4000d}},	//   _gols_, _srđu_, _éluc, _पिआ_, 
   {{0x9f400030,0x6a64022e,0x68080213,0x75800014}},	//   rujú_, _kаfo, _fəda, بیوم, 
   {{0x75e0063f,0x9f4000d0,0x00000000,0x00000000}},	//   _ịzer, sujú_, --, --, 
   {{0x9f400030,0x672002d0,0xd704084c,0x2284130f}},	//   pujú_, _iaoj, _ынце_, сунг, 
   {{0x66000921,0x67200165,0x602000bc,0xd25802d5}},	//   _iqok, _haoj, jímá, сцю_, 
   {{0x3f880421,0x6720e4ac,0x656801e7,0xb0d8000d}},	//   toau_, _kaoj, _imfh, _बजरग, 
   {{0x8d740075,0x61ec010a,0x6720e4ad,0xa490104c}},	//   ۋالا, prcl, _jaoj, _ویکت, 
   {{0x672006d9,0xdb0400e4,0x3f8802b5,0x20000010}},	// [13b30] _maoj, _tujú, roau_, stji_, 
   {{0x67200254,0x00000000,0x00000000,0x00000000}},	//   _laoj, --, --, --, 
   {{0x3944e4ae,0x52dc00fe,0x672002d0,0xeaf4a4cd}},	//   _rols_, _ভাতৃ, _oaoj, ीभूत_, 
   {{0x3944e4af,0x6600e4b0,0xba5438eb,0xc10400ec}},	//   _sols_, _oqok, يناع, _اوھي, 
   {{0x3944e4b1,0x66000472,0xda0400a8,0x0dc8026b}},	//   _pols_, _nqok, счеп, _гуси_, 
   {{0x680800ac,0x80dc00eb,0x00000000,0x00000000}},	//   _səda, _বাড্, --, --, 
   {{0x3944e4b2,0x6600401f,0x67200109,0xb6f80075}},	//   _vols_, _aqok, _baoj, لىغا_, 
   {{0x39440036,0xb5c401a9,0x00000000,0x00000000}},	//   _wols_, ойил, --, --, 
   {{0x596402e8,0x394403b2,0xa3e401ad,0x853c0064}},	//   _лъжа, _tols_, _पिउ_, rmėn, 
   {{0x39440ac5,0x3a2c0175,0x3cfc0b27,0x74b8009d}},	//   _uols_, _irep_, र्चे_, шуис_, 
   {{0x66000944,0xdb0c00d2,0x6f140113,0x68080213}},	//   _eqok, _éjóz, yeyc, _təda, 
   {{0x67200218,0x7ae80c5e,0x321c0210,0x00000000}},	//   _gaoj, _jdet, łtym_, --, 
   {{0x057455cb,0x660001f0,0x490000dc,0x6f14035a}},	//   _کاند, _gqok, _रामो_, veyc, 
   {{0xc6a405f5,0xf4280064,0x347401af,0x00000000}},	//   _эрхи, _вокл_, _мѳйѳ, --, 
   {{0x3b0c0477,0x602001c6,0xa3e411e1,0x04c801c8}},	//   _obeq_, мдра, _पिए_, _اوٺي_, 
   {{0x7ae8685c,0xef1810fc,0xa258003a,0x43e8009f}},	//   _ndet, јма_, rbôr, _اروٽ_, 
   {{0xee38e4b3,0x6f140076,0xa3b020f0,0xed502d56}},	// [13b40] шна_, reyc, _झूट_, وپر_, 
   {{0x7ae8e4b4,0x6da41d39,0x00000000,0x00000000}},	//   _adet, циза, --, --, 
   {{0x3a2c0502,0x6f140076,0xeab8e4b5,0x00000000}},	//   _arep_, peyc, айе_, --, 
   {{0x8fd40184,0x7ae80175,0x9c8002fb,0xe478010f}},	//   _мәғә, _cdet, účas, ברעכ, 
   {{0xada4e4b6,0x7ae8e4b7,0x6a14e4b8,0x3a2c00f3}},	//   _мамл, _ddet, تبار, _crep_, 
   {{0xe6d029d9,0xed58e4b9,0x3a2c05ac,0x672000d8}},	//   सर्ज, _тог_, _drep_, _saoj, 
   {{0x7ae8010a,0x3a2c013d,0x6d5c01ab,0xdd8c007b}},	//   _fdet, _erep_, mhpa, _شوف_, 
   {{0x7bc0067c,0x45d4e4ba,0xd7f407d5,0x4bd401b9}},	//   _élua, поис, цуш_, _мўғу, 
   {{0x67200a73,0x3a2ce4bb,0x779004fb,0x00000000}},	//   _vaoj, _grep_, ریها, --, 
   {{0x256401d9,0x3ca403d4,0x7ae80210,0x03f80114}},	//   تابُ, খুওৱ, _zdet, бној_, 
   {{0x43940408,0xd90c00e5,0xf934010a,0x00000000}},	//   занс, _شیٹ_, _эхтю, --, 
   {{0xd1e80023,0x00000000,0x00000000,0x00000000}},	//   ዛረቡ_, --, --, --, 
   {{0x66000921,0x26c40418,0xe578084c,0x256401d9}},	//   _uqok, _ifoo_, _кзд_, _واتُ, 
   {{0xd5ac005e,0x88d802f5,0x1a98010f,0x00000000}},	//   _іс_, _সাঁক, ייכע, --, 
   {{0x80dc0729,0x9f680124,0x65784520,0xab6005d1}},	//   _বাদ্, араз_, mnth, şüyo, 
   {{0x6d5c0280,0xd010004b,0x00000000,0x00000000}},	//   ehpa, کلې_, --, --, 
   {{0xdcb800d6,0x6578e4bc,0x42540066,0x00000000}},	// [13b50] аще_, onth, _رندر, --, 
   {{0x80f43934,0x65780ade,0x3a300010,0x6d5ce4bd}},	//   _эпох, nnth, _čzp_, ghpa, 
   {{0x04080eac,0x65780857,0x88d800fe,0x7ae80175}},	//   ষিকী_, inth, _সাংক, _pdet, 
   {{0x3a2c2558,0x795c020c,0x7ae80455,0x4fc457d4}},	//   _prep_, _mèwe, _qdet, _زەكە, 
   {{0x3dcc03a2,0xa338001f,0x4b1c00fe,0x00000000}},	//   _ïew_, _እየተቃ, ণাংগ_, --, 
   {{0x6d5ce4be,0xf7703135,0x853c0024,0x6920004e}},	//   chpa, کات_, umėl, емша, 
   {{0x853c0153,0x37740132,0x00000000,0x00000000}},	//   rmėl, зыпс, --, --, 
   {{0x6578e4bf,0xd1e8044e,0x3a2ce4c0,0x7ae80055}},	//   enth, ዛረብ_, _trep_, _udet, 
   {{0x3a2c0066,0x680803b9,0x644c005c,0x00000000}},	//   _urep_, _hədl, øbin, --, 
   {{0xb464e4c1,0x321c0210,0x70d8000d,0x853c00c0}},	//   зкол, łtyk_, _बजेल, lmėj, 
   {{0x89640014,0xe7940214,0x4900012c,0x499015b4}},	//   _تُلن, _کالک, _रातो_, _جیور, 
   {{0x65787749,0xa2580120,0x00000000,0x00000000}},	//   anth, rcôn, --, --, 
   {{0x20100bc9,0x66b80375,0xe60c6d57,0xd5b8010a}},	//   _apxi_, _המנה, _яд_, _тсе_, 
   {{0x94200131,0x00000000,0x00000000,0x00000000}},	//   _يوشۇ, --, --, --, 
   {{0x2f540046,0x216401f0,0xceb403b9,0x853c0064}},	//   птас, чири_, hdət_, kmėj, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d5c20a2,0xece805f5,0xace801c6,0x7ec001e1}},	// [13b60] thpa, йдал_, ймаа_, _sápó, 
   {{0xceb400ac,0x00000000,0x00000000,0x00000000}},	//   ddət_, --, --, --, 
   {{0xa3dc0b03,0x6b580055,0xc1000166,0x3074010a}},	//   दीप_, _aïga, _шүрл, _хупс, 
   {{0x6d5ce4c2,0xeb981c22,0x2460003e,0x88d8015b}},	//   shpa, щие_, _hémé_, _সাইক, 
   {{0x657803a2,0xd1e80023,0x6d5c127b,0x00000000}},	//   ynth, ዛረቦ_, phpa, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xab280536,0xa6c80241,0x60c0002d,0x24600129}},	//   _лова_, _fọlá, _ûnme, _mémé_, 
   {{0x97a06d7d,0x795c01e1,0x65780332,0x00000000}},	//   нрыл, _rèwe, wnth, --, 
   {{0xa3dc45bf,0xceb406be,0x00000000,0x00000000}},	//   दीन_, cdət_, --, --, 
   {{0x6578bb91,0x29c002d2,0x00000000,0x00000000}},	//   unth, _iða_, --, --, 
   {{0x6578b736,0x25b40014,0x00000000,0x00000000}},	//   rnth, _کنتھ_, --, --, 
   {{0xe5c48404,0x7afc01e3,0x20040055,0x00000000}},	//   _еско, _östt, _īni_, --, 
   {{0x4614009f,0x00000000,0x00000000,0x00000000}},	//   _آوتر, --, --, --, 
   {{0x80dc0183,0x6d48e4c3,0x00000000,0x00000000}},	//   _বাহ্, öfal, --, --, 
   {{0x24600de2,0x7f9401c6,0xa3e4134e,0x81e400cc}},	//   _démé_, давх, _पिट_, _নহও_, 
   {{0xb5e401e0,0x5478011a,0x93f8011a,0xd478011a}},	//   _эйәһ, _לטוו, _הלהי, _לאול, 
   {{0xceb400ac,0x680806be,0x00000000,0x00000000}},	// [13b70] ddəs_, _sədl, --, --, 
   {{0xa2580129,0xdd98014b,0x00000000,0x00000000}},	//   ncôm, ёша_, --, --, 
   {{0x4254e4c4,0x29c002d2,0x1ea800ec,0x3ce00254}},	//   _رنگر, _aða_, _گادي_, rahv_, 
   {{0x3a74e4c5,0x442c04cc,0x680803e3,0x25500023}},	//   млер, ivd_, _vədl, _ዝገበሩ, 
   {{0x539c0302,0x1ea80769,0x7f5c0139,0x853c00c0}},	//   זיאו, _دادي_, _ilsq, rmėj, 
   {{0x645403b9,0x5c040024,0x00000000,0x00000000}},	//   _əyir, _няба, --, --, 
   {{0x29c00f99,0xb8e41ab2,0x28dc0c2e,0x644c072b}},	//   _eða_, _एल_, _नजरि, øbil, 
   {{0x442c019b,0x75d40150,0x752c0198,0x3e400092}},	//   dvd_, ويعا, _ɗazu, _ከመድረ, 
   {{0x75640014,0x276800f2,0xd9d400ec,0xceb406be}},	//   ٘یشہ_, تشوی_, _رهاڻ_, ldər_, 
   {{0xef3c02d3,0xe57402d5,0xd7f80108,0x00000000}},	//   _ኣየድል, дзь_, _гуд_, --, 
   {{0xceb403be,0x7afc01e3,0x00000000,0x00000000}},	//   ndər_, _östs, --, --, 
   {{0x170400f2,0xfbd400ce,0x00000000,0x00000000}},	//   _رفتی_, डीएम, --, --, 
   {{0x047801b9,0xc6a400f3,0x00000000,0x00000000}},	//   قلیک_, _прљи, --, --, 
   {{0x6db40bc9,0xa3e41d8a,0x41b4e4c6,0xdb0401ef}},	//   _aņan, _पिच_, есст, _kujó, 
   {{0xd49801c0,0x64a00124,0x4900012d,0x21a80150}},	//   _урд_, _иаша, _रासो_, _ﺴﺎﺌﺭ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x80dc03f4,0xe3a42fee,0xc8780139,0xf1d001c6}},	// [13b80] _বার্, _تشوی, _meğa_, _шөнө, 
   {{0xfd640882,0xad240131,0x622000db,0xceb406be}},	//   _karṇ, بىئى, _شوپە, fdər_, 
   {{0x7bc000d2,0xdd8ce4c7,0x00000000,0x00000000}},	//   _élul, جول_, --, --, 
   {{0x25ece4c8,0x610c01d3,0x00000000,0x00000000}},	//   _इटली_, _tőlü, --, --, 
   {{0x6ffc0356,0x25500023,0xccf801ec,0x00000000}},	//   _făcî, _ዝገብሩ, _нқа_, --, 
   {{0x6da4e4c9,0x310c0882,0x9f400789,0x61f800cf}},	//   _цига, िभिः_, bujó_, àuli, 
   {{0x5bc0e4ca,0x48c400c7,0x88bc013a,0x00000000}},	//   _айсб, _ҟәла, _kněz, --, 
   {{0xdca0e4cb,0x1f58008f,0x00000000,0x00000000}},	//   _раси, ַדיא, --, --, 
   {{0xe7e8584e,0x4614cdc2,0x940403e3,0x00000000}},	//   _टिका_, رودر, _iynə_, --, 
   {{0x7afce4cc,0xa6d400eb,0x00000000,0x00000000}},	//   _östr, _ধাওয়, --, --, 
   {{0xd940e4cd,0x2d9801ab,0x44980212,0x58b8011a}},	//   _шефи, ilpe_, явою_, _ומבצ, 
   {{0x35b401c6,0x00000000,0x00000000,0x00000000}},	//   мбөр, --, --, --, 
   {{0x290c05d5,0x442c009d,0x00000000,0x00000000}},	//   offa_, svd_, --, --, 
   {{0x17080156,0xceb403be,0x795c00f2,0x442c01e4}},	//   _གཡོམ_, ydər_, _kèwa, pvd_, 
   {{0xc4580323,0x00000000,0x00000000,0x00000000}},	//   _хийх_, --, --, --, 
   {{0xd378013d,0xf0780116,0x7f9400f3,0xf7a801ec}},	//   _очы_, чисә_, хабх, _ﺷﺎﻟﺪ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [13b90] --, --, --, --, 
   {{0x77a40077,0xdd982626,0x4df000af,0x00000000}},	//   móxe, іша_, _चिरई_, --, 
   {{0x77a40077,0xbf1001af,0x00000000,0x00000000}},	//   lóxe, _йүвә, --, --, 
   {{0xdb040ba1,0x17080135,0x2d9800e4,0x8eb400db}},	//   _aujò, _གཡེམ_, alpe_, رمەش, 
   {{0x77a40005,0xdb04002e,0x7980035a,0xa3dc0a59}},	//   nóxe, _sujó, _pjlw, दीत_, 
   {{0x3d9400d1,0x9f400789,0x00000000,0x00000000}},	//   _чигр, pujó_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7bc4e4ce,0x37040116,0x680806be,0xaff8010f}},	//   mqhu, хпиг, _mədh, פּצי, 
   {{0xe6142075,0xa1d80139,0x00000000,0x00000000}},	//   еды_, _oçış_, --, --, 
   {{0x77a40005,0x49b807d2,0xc9140063,0xfd6400cd}},	//   dóxe, _قالد_, _идућ, _parṇ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7bc40d04,0xfd640882,0xf43401c0,0xa1d80166}},	//   iqhu, _varṇ, _үедэ, _açış_, 
   {{0x39bc02e2,0xa0a001a9,0x6d48007c,0x00000000}},	//   _fňse_, ғатд, öfak, --, 
   {{0x37ec0489,0x35440014,0x7bc4009a,0x680803e3}},	//   _ལྷོད, _سنبٲ, kqhu, _bədh, 
   {{0xe8000303,0x2a64022e,0x00000000,0x00000000}},	//   रूपा_, zzob_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x77a40077,0xe1fc04d4,0xdb04002b,0xacf4007b}},	// [13ba0] cóxe, lzón_, _nujñ, فسات, 
   {{0x1168006c,0x00000000,0x00000000,0x00000000}},	//   _آلدی_, --, --, --, 
   {{0xe1fc21fc,0x60c0000f,0x00000000,0x00000000}},	//   nzón_, _ûnma, --, --, 
   {{0xe1fc0005,0xc0cc001f,0xae5801af,0x6e200135}},	//   izón_, ባዋል_, _ергє_, ħobb, 
   {{0x7bc40357,0xdb040ba1,0x6f04127b,0x00000000}},	//   aqhu, _pujò, _ickc, --, 
   {{0xd940cfae,0x680803be,0x7bc40218,0x6cd42c37}},	//   лечи, _hədi, bqhu, _سقرا, 
   {{0xdca0e4cf,0x6d4ce4d0,0xe29c01a8,0x5ca05a52}},	//   _бари, _ioba, rfði_, _бирб, 
   {{0x6d4c052f,0x290c0175,0x23b800ef,0x4734e4d1}},	//   _hoba, sffa_, _nūja_, тнис, 
   {{0x6d4ce4d2,0x68080213,0xa6c401e2,0xe8f800c0}},	//   _koba, _mədi, ووژل_, _нла_, 
   {{0x6d4ce4d3,0x39340022,0x6e240334,0x7d005853}},	//   _joba, _аҧшь_, _mskb, _ölst, 
   {{0x6d4ce4d4,0x4614e4d5,0x6f040857,0x94400133}},	//   _moba, روگر, _ockc, ۆپین, 
   {{0x6d4ce4d6,0x680800ac,0x77a40005,0x3a38007b}},	//   _loba, _nədi, tóxe, _áspc_, 
   {{0xe1fc0077,0x6e2400b5,0x6d4ce4d7,0xe79401b9}},	//   azón_, _nskb, _ooba, _قاچک, 
   {{0x6d4ce4d8,0x6f04035a,0x77a40077,0x00000000}},	//   _noba, _ackc, róxe, --, 
   {{0x680800ac,0x6e24007c,0x1fa48740,0xdef800c7}},	//   _bədi, _askb, ераг, зыз_, 
   {{0xcf980640,0x4394084c,0x680806be,0x00000000}},	//   еју_, _шайс, _cədi, --, 
   {{0x6d4ce4d9,0x3d9401c6,0x680806be,0x5398009d}},	// [13bb0] _boba, виар, _dədi, _явъя_, 
   {{0x6d4ce4da,0x7bc000d2,0x6f04127b,0x63ac02d0}},	//   _coba, _éluk, _eckc, lmcn, 
   {{0x7bc40357,0xe8000316,0xe1fc0789,0x35900023}},	//   uqhu, रूमा_, luó_, _ምጥቃስ_, 
   {{0x6d4c003a,0x7bc40784,0x680803b9,0xc9840075}},	//   _eoba, rqhu, _gədi, қучи, 
   {{0xe1fc09d7,0x49c802dd,0x6f6000d1,0xed4c00e5}},	//   nuó_, елін_, _ئۇقم, _ڈھل_, 
   {{0x6d4ce4db,0x0a6801c0,0x41d802a0,0x00000000}},	//   _goba, эрхи_, बीएस, --, 
   {{0x3868008f,0x00000000,0x00000000,0x00000000}},	//   ĝaro_, --, --, --, 
   {{0x6d4c006d,0xe9a404a9,0x4c94374e,0xd5140ca8}},	//   _zoba, ىگەن_, _сисс, _ọ̀r, 
   {{0x48c400c7,0x00000000,0x00000000,0x00000000}},	//   тәӡа, --, --, --, 
   {{0xe1fc0789,0x6d4c002e,0xb9b437ba,0x00000000}},	//   duó_, _xoba, _شماع, --, 
   {{0x84583da1,0xd7f801af,0x00000000,0x00000000}},	//   ерят_, _хуз_, --, --, 
   {{0xe1fc09a9,0x795c020c,0x87d4007b,0x23b800b8}},	//   rzón_, _kèwo, _إغلا, _pūja_, 
   {{0x680806be,0x941c03e3,0x88b400fb,0x00000000}},	//   _rədi, _əsəb_, _иҫәр_, --, 
   {{0x07440022,0xe58405a2,0x7428007b,0x680803b9}},	//   _ахәм, _үтәү, _يكشف_, _sədi, 
   {{0x28c40f4c,0x63ac02d0,0x00000000,0x00000000}},	//   रुटि, bmcn, --, --, 
   {{0x6d4c3d78,0x680803be,0xa2c0228d,0x23b800ef}},	//   _soba, _qədi, रखण्, _tūja_, 
   {{0x6d4ce4dc,0x680803b9,0x00000000,0x00000000}},	// [13bc0] _poba, _vədi, --, --, 
   {{0x6d4c01ee,0xe89002d3,0xe610010f,0x321c0210}},	//   _qoba, _ልዕሊኡ_, יִע_, łtys_, 
   {{0x6fa8e4dd,0xa4a40428,0x6d4c014a,0x680806be}},	//   _овог_, _ijòñ, _voba, _tədi, 
   {{0x6d4ce4de,0x2b38084c,0x6f04035a,0x1c100037}},	//   _woba, ьязэ_, _uckc, _ठहरल_, 
   {{0xa968e4df,0x2988e4e0,0x6d4ce4e1,0xee3801b9}},	//   мида_, мско_, _toba, _ўнг_, 
   {{0xa850008e,0x00000000,0x00000000,0x00000000}},	//   иелә, --, --, --, 
   {{0x1d0463dd,0xe8240139,0x00000000,0x00000000}},	//   _шери_, тфло, --, --, 
   {{0x3b9400d8,0x00000000,0x00000000,0x00000000}},	//   _бјут, --, --, --, 
   {{0x69240cfc,0xdb0c01e1,0x85b800d8,0x00000000}},	//   _имаа, _ìdáw, нлис_, --, 
   {{0x6b800301,0xb5940133,0x00000000,0x00000000}},	//   lnog, هێنا_, --, --, 
   {{0x35540214,0x6b80e4e2,0x00000000,0x00000000}},	//   انپز, onog, --, --, 
   {{0xe1fc09d7,0x18740375,0x21f00116,0x7878010f}},	//   tuó_, _בעבר_, аҗис, _אָנו, 
   {{0x2284e4e3,0x6b800099,0x680800ac,0x00000000}},	//   тунг, inog, _cədv, --, 
   {{0x9470397a,0x6b800368,0x26c80134,0x15b00150}},	//   ادیا, hnog, ɛboa_, _پەپس, 
   {{0x4fc4e4e4,0x09d8045e,0xa3dc1cd2,0x6b8001bf}},	//   иста, _সিফা, दीश_, knog, 
   {{0xf2c0010b,0x6b80e4e5,0x00000000,0x00000000}},	//   _гөри, jnog, --, --, 
   {{0x6b80098d,0xe1fc4a1f,0x60c0045f,0xa3dc6bf2}},	// [13bd0] dnog, quó_, _ûnmo, दीर_, 
   {{0x6b800042,0x23b80064,0x00000000,0x00000000}},	//   enog, _kūjo_, --, --, 
   {{0x6b800cfd,0x853c00c0,0x00000000,0x00000000}},	//   fnog, lmės, --, --, 
   {{0x6b80e4e6,0x4c9411ed,0x39bc010e,0xdb1c0432}},	//   gnog, шихс, _aňsa_, _öwün, 
   {{0x3f98e4e7,0x44e800cc,0x00000000,0x00000000}},	//   _iksu_, _খানক_, --, --, 
   {{0x6b80e4e8,0x20040139,0x00000000,0x00000000}},	//   anog, _änis_, --, --, 
   {{0x6b801a48,0x2810451a,0xec1801af,0x3dc80139}},	//   bnog, مووس, _перә_, lqaw_, 
   {{0xb6a4e4e9,0x9f400327,0x01d80154,0x00000000}},	//   лийл, nsjà_, _তিনদ, --, 
   {{0x36340214,0x00000000,0x00000000,0x00000000}},	//   اربس, --, --, --, 
   {{0x7d040399,0x00000000,0x00000000,0x00000000}},	//   nghs, --, --, --, 
   {{0xd1d41e38,0x7d0408c2,0xe57400a8,0xc48400fb}},	//   ራዊት_, ighs, узэ_, ҫлөк, 
   {{0xfce0001f,0x80dc009e,0x27f81155,0x00000000}},	//   _ነዳጅ_, _বাগ্, ápne_, --, 
   {{0x942000cf,0x07a400d4,0x00000000,0x00000000}},	//   _چوتۇ, _таїн, --, --, 
   {{0x09d803d4,0x3f98236c,0x91c4151e,0x00000000}},	//   _সিমা, _aksu_, ләүл, --, 
   {{0x752017da,0x80dc00fe,0x6b800142,0x853c0064}},	//   melz, _বাখ্, ynog, rmėt, 
   {{0xde600020,0x6b801afe,0xd5400241,0x00000000}},	//   _መመዝገ, xnog, bẹ̀f, --, 
   {{0x6db40227,0x6b8005ce,0xf1bc033f,0xfbb8095f}},	// [13be0] _uņak, vnog, _एंटन, ेदनम, 
   {{0x3dcc0154,0x33200327,0x6b800142,0x00000000}},	//   _লিখল, lekx_, wnog, --, 
   {{0x6b800841,0x32000306,0xc61c00cc,0x00000000}},	//   tnog, luky_, তিযা_, --, 
   {{0x95002fb5,0xdcac13d7,0x6b80006f,0x752001f5}},	//   _མཐའི_, سىن_, unog, helz, 
   {{0x320001a2,0x752094f5,0x103001ec,0x00000000}},	//   nuky_, kelz, _ءﯗﺯﯨ, --, 
   {{0x6b801710,0x752000dd,0x7d00002f,0x0854117e}},	//   snog, jelz, _ölsp, ивлю, 
   {{0x6d5c02e3,0x752077d0,0x6b8001a6,0x8884d204}},	//   mkpa, delz, pnog, جیان, 
   {{0x6d5ce4ea,0x3e300023,0x7cf80241,0x32000432}},	//   lkpa, _ብርእይ, _tùrà, kuky_, 
   {{0x59241f21,0xe4e4e4eb,0x752001a4,0x3320031c}},	//   _རྣམས_, лінн, felz, dekx_, 
   {{0xd6141216,0x75201543,0x680806be,0x8574009d}},	//   اتيا_, gelz, _sədu, рлох, 
   {{0xa3dc0d41,0x56900150,0x00000000,0x00000000}},	//   दीं_, _қашт, --, --, 
   {{0x4394e4ec,0x320002fb,0x68e801bf,0x5c34008f}},	//   рамс, fuky_, lafd, ארטן_, 
   {{0xdb18180f,0x27ec011c,0x6d5c08fb,0xd790007b}},	//   _diuè, lsfn_, kkpa, _النخ, 
   {{0x6d5c01f5,0x68e855ad,0xe29c08a5,0x00000000}},	//   jkpa, nafd, ggða_, --, 
   {{0x6578e4ed,0xf2e40129,0xd1d401f3,0x00000000}},	//   mith, ïâce_, ራዊቱ_, --, 
   {{0x6d5c257d,0x823800a7,0x64580072,0x680803e3}},	//   ekpa, _азис_, myti, _həds, 
   {{0x6578679d,0x9f4002d2,0x00000000,0x00000000}},	// [13bf0] oith, gsjá_, --, --, 
   {{0x6578e4ee,0x63bce4ef,0xdc8800fb,0x6458062c}},	//   nith, _hiqn, нсел_, oyti, 
   {{0x6458e4f0,0x92d803d4,0x7d040455,0x3dc80477}},	//   nyti, াণৰ_, rghs, sqaw_, 
   {{0x6578e4f1,0x200007e1,0xbe04066d,0x6d5c01a4}},	//   hith, muji_, _پوسٹ, akpa, 
   {{0x6578e4f2,0xf9905706,0x61ece4f3,0x2000a2e8}},	//   kith, يبت_, nscl, luji_, 
   {{0x6578e4f4,0x64582401,0x63bc036b,0x6d5ce4f5}},	//   jith, kyti, _liqn, ckpa, 
   {{0x6578e4f6,0x2000e4f7,0xdc34001f,0xa964487f}},	//   dith, nuji_, _የሚሆኑ, рища_, 
   {{0x7bd40323,0x63bc011f,0x6dbc0882,0x65780368}},	//   _itzu, _niqn, ṇatv, eith, 
   {{0x7e6c006a,0x7f4c0194,0x75204431,0x68e80009}},	//   nzap, ijaq, telz, bafd, 
   {{0x6578e4f8,0x2000e4f9,0x4a5472c5,0x212000b5}},	//   gith, kuji_, _укус, jejh_, 
   {{0xb9d00020,0x629c0113,0xb384260d,0x2000e4fa}},	//   _ድረ_, _ayqo, илол, juji_, 
   {{0x65a405f7,0x60c0002d,0x65783e7c,0x20000118}},	//   rðha, _ûnmj, aith, duji_, 
   {{0x6578e4fb,0x6458022f,0x6d5c1141,0x00000000}},	//   bith, ayti, ykpa, --, 
   {{0x6578e4fc,0x63bc0007,0x7e6c055a,0x32000ceb}},	//   cith, _eiqn, dzap, ruky_, 
   {{0xafe4e4fd,0x61ec218f,0xb5fc00e2,0x64584ebd}},	//   робл, ascl, dzši, cyti, 
   {{0x77682937,0x9f4401e1,0x00000000,0x00000000}},	//   nhex, _ìnì_, --, --, 
  
   {{0x7bd400db,0xdd000374,0x61ec035a,0xd06406be}},	// [13c00] _atzu, _ōrāk, cscl, _əsən, 
   {{0x6d5c0357,0xddc80209,0x200000bc,0x63bc022e}},	//   ukpa, ňişl, buji_, _ziqn, 
   {{0xf0a8e4fe,0x6d5c7cca,0x80dc0eac,0x776801f0}},	//   _школ_, rkpa, _বাচ্, khex, 
   {{0x65781373,0x6d5ce4ff,0x63bc0548,0xeaf800c6}},	//   zith, skpa, _xiqn, ئرات_, 
   {{0x65786580,0x6d5c0227,0x692407d6,0x7bd4009d}},	//   yith, pkpa, имда, _etzu, 
   {{0x26c00030,0xed3401c6,0x645801f4,0x00000000}},	//   ľkom_, _тэмэ, yyti, --, 
   {{0x75c8005e,0x6578e500,0x68e8e501,0xf7cc17de}},	//   қтың_, vith, rafd, _ﻗﺎﻧﺪ, 
   {{0x6578da7d,0x68e8250a,0xb8fc0034,0xf83801ed}},	//   with, safd, _थ्_, ازوں_, 
   {{0x6578e502,0x2000012c,0x63bc01b9,0x33f0031c}},	//   tith, zuji_, _riqn, eġx_, 
   {{0xa9040502,0xa9a40d31,0x63bce503,0x6458858f}},	//   _خبرن, _тизд, _siqn, tyti, 
   {{0x65780491,0x4438e504,0x776801e2,0xf8ac01c6}},	//   rith, ír_, bhex, _хө_, 
   {{0x6578e505,0x74a81982,0xc7b8004d,0x20000118}},	//   sith, ысың_, _csđt_, vuji_, 
   {{0x6458e506,0xc0c40116,0x6e3402f0,0x2120031c}},	//   syti, йәни, jvyb, tejh_, 
   {{0x61ece507,0x7e6c151c,0x80dc0eac,0x6578004b}},	//   rscl, vzap, _বাঙ্, qith, 
   {{0x7e6c4f3b,0x7f4c0d04,0x31140882,0x6f1400b5}},	//   wzap, tjaq, द्धः_, ffyc, 
   {{0x7e6ce508,0x2000e509,0xf3f40214,0xd010e50a}},	//   tzap, ruji_, _اتوک, بلِ_, 
   {{0xba0000bd,0x26c00de2,0xc8780205,0x91e40063}},	// [13c10] _এন্ড_, ñkoy_, _deği_, _доње, 
   {{0x8d74a67e,0x2000e50b,0xe1fc0174,0xd05c03e3}},	//   يالا, puji_, mró_, harə, 
   {{0x5c040801,0x7f945d4e,0xf34c0023,0xe7a43c71}},	//   ряза, _ганх, _ንረብሓ, खताप, 
   {{0x7e6c4f3b,0x6d480267,0x7e980214,0xabb4035b}},	//   pzap, öfar, _منجر_, бахә, 
   {{0xd05c03e3,0x00000000,0x00000000,0x00000000}},	//   darə, --, --, --, 
   {{0x7bc40661,0x88c404da,0x9cc800fb,0xaa540114}},	//   _граҗ, يتىل, _шыма_, сиљу_, 
   {{0x680803be,0x2d5400b5,0xd5dc01ad,0x588409fc}},	//   _sədr, _tæer_, पीईज, шыда, 
   {{0xbb840491,0xe1fc4e82,0x27f800d7,0x00000000}},	//   _الري, kró_, ápna_, --, 
   {{0xa7600801,0xfa54036b,0x680803e3,0x00000000}},	//   якъд, _ارزگ, _qədr, --, 
   {{0x7ae8e50c,0xe1fce50d,0xd7f8e50e,0x00000000}},	//   _heet, dró_, _ауд_, --, 
   {{0x7ae8e50f,0xd05c03be,0x7bc000d2,0x3a2c0175}},	//   _keet, barə, _élus, _hsep_, 
   {{0xd05c03be,0x680800ac,0x7ae8e510,0xe1fc032e}},	//   carə, _tədr, _jeet, fró_, 
   {{0xe1fce511,0x7ae8e512,0x86746b63,0x00000000}},	//   gró_, _meet, _мышц, --, 
   {{0x92d82158,0x7ae8e513,0x999c0034,0x78a033b4}},	//   াণে_, _leet, _usuń_, _kylv, 
   {{0x05745e79,0xa064e514,0x00000000,0x00000000}},	//   _باند, бара_, --, --, 
   {{0x7ae8e515,0xe1fce516,0x3a2c0280,0xaec458f0}},	//   _neet, bró_, _osep_, сбал, 
   {{0x3a2c1529,0xac841cd1,0xe1fce517,0xeb98142e}},	// [13c20] _nsep_, әгел, cró_, ңиз_, 
   {{0xd05c03be,0x7ae8003a,0xa3dc447d,0x00000000}},	//   zarə, _aeet, दीक_, --, 
   {{0x3a2c3386,0x1168d902,0xd05c03be,0x7ae88bab}},	//   _asep_, _ملکی_, yarə, _beet, 
   {{0x6db40227,0x7ae84f7f,0x00000000,0x00000000}},	//   _aņat, _ceet, --, --, 
   {{0x7ae8413b,0x78a0000f,0xa9a40b01,0x7aec0d12}},	//   _deet, _aylv, бидд, ðata, 
   {{0x7fe8130e,0xdce800f3,0x81dc015b,0x62180375}},	//   _حریف_, _ćića, _ডিম_, רוסק, 
   {{0x7ae8e518,0x07081541,0x2d9800e4,0xc7b01291}},	//   _feet, ليغي_, mope_, وّت_, 
   {{0x2d98e519,0x7ae8e51a,0xe1fce51b,0x176406d3}},	//   lope_, _geet, czów_, йрып_, 
   {{0xfcdc0023,0x00000000,0x00000000,0x00000000}},	//   ንጸጽ_, --, --, --, 
   {{0x2d98e51c,0xd05c00ac,0x7ae8e51d,0x92d800cc}},	//   nope_, sarə, _zeet, াণো_, 
   {{0x680800ac,0x60c0000f,0x7ae8e51e,0x78a003b2}},	//   _tədq, _ûnmi, _yeet, _gylv, 
   {{0x2d98e51f,0xe1fce520,0x6b580022,0x7ae81574}},	//   hope_, tró_, _tïgu, _xeet, 
   {{0x2d98e521,0xe1fc0789,0x84c41c5c,0x9f4005ac}},	//   kope_, uró_, _мәнд, nsjå_, 
   {{0xe1fce522,0x2d98e523,0xd0d402e8,0xb9d00023}},	//   rró_, jope_, зоръ, _ድየ_, 
   {{0x2d980124,0x4e880092,0x00000000,0x00000000}},	//   dope_, _በመረጃ_, --, --, 
   {{0xbed83edb,0x443c0254,0x53f4007b,0xe1fc00e5}},	//   рдах_, _irv_, _اروح_, pró_, 
   {{0x7ae8e524,0x2fc027be,0x443ce525,0xdafc0589}},	// [13c30] _reet, _dikg_, _hrv_, pãºz, 
   {{0x7ae8e526,0x2d98e527,0x26c40589,0x443c3858}},	//   _seet, gope_, _lgoo_, _krv_, 
   {{0x6db40227,0x7ae8e528,0x00000000,0x00000000}},	//   _aņas, _peet, --, --, 
   {{0x443c7dcd,0x26c4009a,0x8d841e4a,0x6b9400e4}},	//   _mrv_, _ngoo_, يشەن, _ñag̃, 
   {{0x7ae8e529,0xe1fc1afd,0x3f8807de,0x39b80276}},	//   _veet, rzów_, mnau_, алдэ_, 
   {{0x7ae8e52a,0x2d98e52b,0xe1fce52c,0x3f880129}},	//   _weet, cope_, szów_, lnau_, 
   {{0x7ae8e52d,0x3f88e52e,0xd0f8011a,0x00000000}},	//   _teet, onau_, זמות_, --, 
   {{0xf770e52f,0x3f880f7b,0x09d800bd,0x78a00076}},	//   بات_, nnau_, _সিরা, _vylv, 
   {{0x443ce530,0x3a2ce531,0x6db400e4,0xa800008e}},	//   _arv_, _usep_, _iņar, _çınb, 
   {{0x26c401e4,0x443c0427,0x78a001bf,0x74e801c6}},	//   _egoo_, _brv_, _tylv, шдог_, 
   {{0x443c0263,0x34a81b50,0x00000000,0x00000000}},	//   _crv_, рвно_, --, --, 
   {{0x443c0427,0x2d9800e4,0x00000000,0x00000000}},	//   _drv_, zope_, --, --, 
   {{0x3dd80218,0xe7947f05,0x443c030a,0x3f887197}},	//   _ntsw_, _بالک, _erv_, dnau_, 
   {{0x3f880368,0x443c01a8,0x473403e6,0xa5040408}},	//   enau_, _frv_, _ورۆز, _деша_, 
   {{0x21a050cb,0x2f54e532,0x3f880368,0xaf78dba2}},	//   фирм, отас, fnau_, асає_, 
   {{0x3f88e533,0x208402bf,0xa3dc00af,0xc61c00eb}},	//   gnau_, ійти_, दीओ_, তিরা_, 
   {{0x2d98e534,0x836402dd,0xece8005b,0xace8725b}},	// [13c40] tope_, _ءدىل, идал_, имаа_, 
   {{0x3f880b23,0x443c05b1,0xa1540114,0x00000000}},	//   anau_, _yrv_, _мању_, --, 
   {{0xaf54001f,0x00000000,0x00000000,0x00000000}},	//   _የፈለገ, --, --, --, 
   {{0xeb98e535,0x9f400158,0x311400dc,0x2d98e536}},	//   шие_, tsjå_, द्रः_, sope_, 
   {{0x2d98e537,0x59d0249f,0x9f440241,0x00000000}},	//   pope_, وغور, _ìná_, --, 
   {{0x39440230,0x7bc004cc,0x9f4005ac,0xbab000db}},	//   _cnls_, _èlun, rsjå_, رۅلب, 
   {{0xdca0e538,0xab280107,0x5ca00166,0x18640063}},	//   _жари, _кова_, _жирб, жаји_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x443ce539,0x00000000,0x00000000,0x00000000}},	//   _srv_, --, --, --, 
   {{0x3f8804cc,0xd88401d9,0x69640066,0x00000000}},	//   znau_, _ژھٹن_, _بدرق, --, 
   {{0x3f880cfd,0x320001f1,0x08a80220,0x291c0009}},	//   ynau_, erky_, _اناۋ_, _ibta_, 
   {{0x443c0427,0x00000000,0x00000000,0x00000000}},	//   _vrv_, --, --, --, 
   {{0xf748009f,0xb5fc0118,0x09cc00eb,0x00000000}},	//   _دجله_, uzšt, রীরা, --, 
   {{0x443c0427,0x3f88015d,0x00000000,0x00000000}},	//   _trv_, wnau_, --, --, 
   {{0x443c00cf,0x291c007f,0x656801e7,0x50440107}},	//   _urv_, _mbta_, _ilfh, меёб, 
   {{0x3f88e53a,0x442ce53b,0x00000000,0x00000000}},	//   unau_, mwd_, --, --, 
   {{0x3f88e53c,0x442c0369,0x43740451,0x00000000}},	// [13c50] rnau_, lwd_, _وهڪر, --, 
   {{0x3f88e53d,0xdca403c5,0x5bc008df,0x00000000}},	//   snau_, ошеп, षद्व, --, 
   {{0xd1b81e4a,0x9c10063f,0xb1180150,0xa3dc0490}},	//   _بايا_, pọmk, _اقپا_, दीच_, 
   {{0x291c102c,0x7f941069,0x00000000,0x00000000}},	//   _abta_, _хамх, --, --, 
   {{0x656802d0,0x00000000,0x00000000,0x00000000}},	//   _olfh, --, --, --, 
   {{0x88bc00bc,0xae5802e4,0xe734013e,0xd91801c6}},	//   _oběd, _הכשר, ҷеъ_, рьд_, 
   {{0x77a40f71,0xb6f80131,0xe800447d,0xa800013d}},	//   lóxi, مىغا_, रंगा_, _çılb, 
   {{0xe7240c99,0x6568127b,0xe1fc0005,0x291c00ef}},	//   _རྒྱན_, _alfh, nzós_, _ebta_, 
   {{0x77a45b84,0x442c282c,0xabb40124,0x75780023}},	//   nóxi, ewd_, _хатә, _ኪህልዎ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc208011a,0x442c015d,0x7738009d,0x00000000}},	//   _תה_, gwd_, _гялс_, --, 
   {{0xc0f802d3,0xdeb8010c,0x320003e0,0x00000000}},	//   ላኸሊ_, ታልን_, trky_, --, 
   {{0x442c015d,0x59c800cd,0xdb08002f,0x23b80171}},	//   awd_, ादिर, mmgä, _nūju_, 
   {{0xe2081f60,0x77a40077,0xe800012c,0x2fd8abd5}},	//   _stóð_, dóxi, रूका_, _ptpg_, 
   {{0x64a0e53e,0xa064e53f,0x2d94070e,0xc32c0137}},	//   _паша, пара_, җрас, اەۋ_, 
   {{0xdfcc0597,0x59c807d0,0x00000000,0x00000000}},	//   طيك_, ादार, --, --, 
   {{0x9de40156,0x77a41709,0x26c0a895,0x20000219}},	// [13c60] _སྦྱེ, góxi, žkov_, arji_, 
   {{0xe294030d,0x00000000,0x00000000,0x00000000}},	//   _хаь_, --, --, --, 
   {{0xdd8ce540,0xa2d000cd,0x78a4000d,0x00000000}},	//   دول_, भुक्, ühvl, --, 
   {{0x8024e541,0x00000000,0x00000000,0x00000000}},	//   _کریم, --, --, --, 
   {{0xf8dc038e,0x442c010a,0xc0e40023,0x00000000}},	//   नुभय, zwd_, ማሚሩ_, --, 
   {{0xfe4410e5,0xc0c00092,0xba040022,0x00000000}},	//   _تکفی, ዴራሉ_, ьҭуа_, --, 
   {{0xdd8c143e,0x25800248,0x832c0327,0xc0f80023}},	//   _صوف_, _lélè_, _ཧྲའུ_, ላኸሉ_, 
   {{0x6a840046,0xbc7002dd,0xebe4014b,0x00000000}},	//   _елба, _جۇمب, _моҳп, --, 
   {{0xe664e542,0x6b80037e,0x6ea017c6,0x29180254}},	//   ятко, miog, _कुमु, õpas_, 
   {{0x84c40075,0x7dc80153,0x55700124,0x20000bcd}},	//   мәйд, _užse, егьт, yrji_, 
   {{0x43944945,0x442c0cf9,0x6fbc00a5,0x6b800421}},	//   данс, uwd_, ्दां, oiog, 
   {{0x6b80e543,0x3634004b,0xc48400d1,0x42c80137}},	//   niog, _ښونځ, злүк, өгүн_, 
   {{0xd244e2af,0xd6144029,0x9f400158,0x21a4013d}},	//   нэри, _فتوا_, msjø_, зәнү_, 
   {{0x25800248,0x290c0042,0x853c0064,0x00000000}},	//   _délè_, ngfa_, olėm, --, 
   {{0x26c00030,0x6b8001f7,0x9f680024,0xd48c36da}},	//   ľkou_, kiog, браз_, _чр_, 
   {{0x26c00122,0x6b8001c8,0xd3780724,0x77a4578d}},	//   žkou_, jiog, _нчы_, tóxi, 
   {{0x25800248,0xe1fc0077,0x00000000,0x00000000}},	// [13c70] _gélè_, rzós_, --, --, 
   {{0xc0c00020,0xdcb807d8,0x77a41dec,0x853c0024}},	//   ዴራል_, бще_, róxi, klėm, 
   {{0x5bc4e544,0x7f58e545,0xe1fc033f,0xc0f80023}},	//   ستاف, _данс_, czór_, ላኸል_, 
   {{0x387806be,0x00000000,0x00000000,0x00000000}},	//   _əsrd_, --, --, --, 
   {{0x99d40127,0x4fc411dc,0xebc00116,0xdb200241}},	//   ستشا, _سەكە, тәрн, _érík, 
   {{0xaa400bd6,0xe29c08a5,0x00000000,0x00000000}},	//   тешл, ggði_, --, --, 
   {{0x999c01ed,0x281019e2,0x00000000,0x00000000}},	//   éről_, نووس, --, --, 
   {{0x6e282776,0x6b80004e,0xcb340395,0x00000000}},	//   _âmbê, ciog, _песъ, --, 
   {{0x61f8098d,0x98c4e546,0x3914e547,0x00000000}},	//   šulj, _فغان, _омар, --, 
   {{0xdce40219,0xdeb80092,0x00000000,0x00000000}},	//   _oljč, ታልና_, --, --, 
   {{0xd1d4010c,0xd7f801af,0x00000000,0x00000000}},	//   ያዊት_, _ыуа_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd6a83cd9,0x2ef005b1,0xb9e40023,0x6fbc081e}},	//   _ادام_, vayf_, _ኪኖ_, ्दसं, 
   {{0xd5b804db,0x6b803e38,0x66b80375,0x00000000}},	//   _усе_, ziog, _ומנה, --, 
   {{0xa0a046e0,0x4094e548,0x853c0024,0x61400139}},	//   вард, ертт, klėj, _sílä, 
   {{0x6b800077,0x25800241,0x03940006,0x00000000}},	//   xiog, _télè_, _прыя, --, 
   {{0x7c283421,0x6b800363,0x290c03cb,0x00000000}},	// [13c80] _ćera, viog, ygfa_, --, 
   {{0xdd8c96d3,0xe0d40276,0x6b80015d,0x00000000}},	//   لوق_, _овь_, wiog, --, 
   {{0x6b801140,0xfe7032db,0xda6c0050,0x0c9400db}},	//   tiog, ندے_, یُم_, ردئگ, 
   {{0xdcac1870,0xe4680037,0x00000000,0x00000000}},	//   جىم_, ltöö_, --, --, 
   {{0xbbc40214,0x1dac00dc,0x9f400fac,0x5ac80133}},	//   رآمو, _जीवत, vsjø_, زانێ_, 
   {{0x6b8002d5,0x99940131,0x7bd40ba1,0xd940004e}},	//   siog, ۋھەر_, ïguè, кечи, 
   {{0x6b800395,0xec1401ec,0x6ea092c2,0x00000000}},	//   piog, _توزد, _कुतु, --, 
   {{0xc6f8ab7e,0x290c015d,0x00000000,0x00000000}},	//   чних_, sgfa_, --, --, 
   {{0x9f400217,0xe8f8009b,0x26c000e4,0xd6d00116}},	//   rsjø_, _мла_, äko_, ختىغ, 
   {{0x6844014b,0x853c0064,0x00000000,0x00000000}},	//   _онза, plėm, --, --, 
   {{0x9f480200,0xee7001ec,0x00000000,0x00000000}},	//   ëjës_, _ﺴﻁﻴﻥ_, --, --, 
   {{0x69c4089a,0x00000000,0x00000000,0x00000000}},	//   ादकी, --, --, --, 
   {{0x37080156,0xe2a8e549,0x67200ca8,0x5a98008f}},	//   _ཁྐྲལ_, تادن_, _iboj, ַשלא, 
   {{0x272001b9,0x644c0e78,0x3eac0327,0xe468000d}},	//   lаn_, äbis, _ġet_, gtöö_, 
   {{0x3eac01fa,0xd0d427a8,0xeaa800fe,0x00000000}},	//   _šet_, тосъ, _ওলোম, --, 
   {{0x93f80375,0x00000000,0x00000000,0x00000000}},	//   _ולהי, --, --, --, 
   {{0x67200588,0xbdb40114,0xc61c00eb,0x00000000}},	// [13c90] _mboj, ебај, তিকা_, --, 
   {{0xc034009b,0x00000000,0x00000000,0x00000000}},	//   _зној, --, --, --, 
   {{0x09d80154,0x19c80ef6,0x00000000,0x00000000}},	//   _সিগা, _ﻗﻮﭘﺎ, --, --, 
   {{0x25700b21,0x765c03cd,0x00000000,0x00000000}},	//   _hâld_, øsyk, --, --, 
   {{0x25700b21,0x272001b9,0xabb4035b,0x00000000}},	//   _kâld_, dаn_, хацә, --, 
   {{0x67200248,0x7f5c047e,0x29d00220,0x680806be}},	//   _aboj, _hosq, ديوس, _hədy, 
   {{0xe9400014,0x00000000,0x00000000,0x00000000}},	//   ان٘پ, --, --, --, 
   {{0x272001b9,0x00000000,0x00000000,0x00000000}},	//   gаn_, --, --, --, 
   {{0x7bc801ab,0xd9a800a7,0x00000000,0x00000000}},	//   _iieu, _дъжд_, --, --, 
   {{0xe574084c,0x7f5c047e,0x7bc8e54a,0x186400f3}},	//   езь_, _losq, _hieu, _оњег, 
   {{0x7bc8e54b,0xc9841eed,0x3cf0030a,0xe468000d}},	//   _kieu, _рути, _mezv_, vtöö_, 
   {{0x7bc8e54c,0x67200241,0x7f5c0393,0x00000000}},	//   _jieu, _gboj, _nosq, --, 
   {{0x7bc8e54d,0x45240154,0x644c000d,0x00000000}},	//   _mieu, বয়ক_, äbir, --, 
   {{0x7bc8e54e,0x77680113,0x6720e54f,0xe4680254}},	//   _lieu, lkex, _zboj, utöö_, 
   {{0x7f5ce550,0x00000000,0x00000000,0x00000000}},	//   _bosq, --, --, --, 
   {{0x7bc83a0e,0x7f5ce551,0xe46800af,0x77683bbd}},	//   _nieu, _cosq, stöö_, nkex, 
   {{0xd1ec0201,0x3cf00165,0xfc40001f,0xa2a400bc}},	// [13ca0] ጅቶች_, _bezv_, _የሚገል, _टुप्, 
   {{0x6da40594,0x7f5c16b8,0xe298011a,0xe29c01a8}},	//   رمام, _eosq, _משפר, ggðu_, 
   {{0x6ab829da,0x7bc8003e,0x7f5c00cf,0x98a40118}},	//   ेश्र, _bieu, _fosq, rdně_, 
   {{0x7bc8bda7,0x798000a9,0x7f5c0023,0x776801a4}},	//   _cieu, _amlw, _gosq, jkex, 
   {{0x7bc8e552,0xd9d402bf,0xcdc400fb,0x00000000}},	//   _dieu, емії_, _аҙап, --, 
   {{0x61f868b1,0x7db00014,0x6da4059f,0x99e00419}},	//   áuli, _نۅقص, _чига, áňan, 
   {{0x7dc802d5,0x7bc805d5,0x61f80327,0x00000000}},	//   _užsa, _fieu, ġuli, --, 
   {{0x7bc80c86,0x2570e553,0xca2801ec,0xdca0a678}},	//   _gieu, _mâle_, _يۋان_, _саси, 
   {{0xb81c00cc,0x00000000,0x00000000,0x00000000}},	//   থিগত_, --, --, --, 
   {{0x7bc805c7,0x2a6401a9,0x2720022e,0x00000000}},	//   _zieu, myob_, sаn_, --, 
   {{0x2570002d,0x6ea00aa2,0x7bc80098,0xfaf800ef}},	//   _nâle_, _कुसु, _yieu, _klūp_, 
   {{0x6720e554,0xd4940006,0x7768e555,0x3860002f}},	//   _uboj, эры_, ckex, ähre_, 
   {{0x2a640211,0x79800042,0x52240305,0x7aec0d12}},	//   nyob_, _ymlw, лфра, ðati, 
   {{0x257006af,0x6b8002e3,0x680803e3,0x79800857}},	//   _bâle_, ọgha, _bədx, _xmlw, 
   {{0x7f5ce556,0xf7cc06ba,0x9f68010b,0x00000000}},	//   _posq, _ﻗﺎﻟﺪ, праз_, --, 
   {{0x7f5c03f0,0x2570000f,0x6ea002c3,0x00000000}},	//   _qosq, _wâld_, _कुहु, --, 
   {{0x7bc8e557,0x2a640218,0x7f5c0381,0x00000000}},	// [13cb0] _rieu, jyob_, _vosq, --, 
   {{0x7bc8e558,0x63b00024,0x409400ae,0x00000000}},	//   _sieu, šenė, _للخر, --, 
   {{0x7bc8e54e,0x7f940124,0x7f5c28ed,0x7bf81eed}},	//   _pieu, _аанх, _tosq, фнер_, 
   {{0x09d8045e,0x7f5c003a,0x798002d0,0xb5fc0118}},	//   _সিজা, _uosq, _smlw, dyšn, 
   {{0x7bc8e559,0xdb08036e,0x798002d0,0xd1ec0092}},	//   _vieu, llgë, _pmlw, ጅቶቹ_, 
   {{0x7bc8002d,0x9ce401d9,0x00000000,0x00000000}},	//   _wieu, _سورے_, --, --, 
   {{0x7bc8e55a,0x4ce8009e,0xb7940063,0x8aa40139}},	//   _tieu, _পাচঁ, крић, крәд, 
   {{0xfd4c0208,0xb6a44eca,0x00000000,0x00000000}},	//   _ngoả, кийл, --, --, 
   {{0x1a5800c6,0xe614010b,0x0a94e55b,0x00000000}},	//   _عشرة_, вды_, _батю, --, 
   {{0x8934304e,0x79800117,0xf9840150,0x84980023}},	//   _معما, _umlw, _جەتۋ_, _ዋዕሮን_, 
   {{0x3d182232,0x482401ec,0x49900472,0x644c0254}},	//   _पाने_, _مىلق, _دیور, äbip, 
   {{0x25700129,0x00000000,0x00000000,0x00000000}},	//   _râle_, --, --, --, 
   {{0x9f4401e1,0x00000000,0x00000000,0x00000000}},	//   _ìnù_, --, --, --, 
   {{0x25704a31,0xb9dc01f2,0xd5b87aea,0xc4840150}},	//   _pâle_, _ụọ_, _эсе_, _өлік, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4374030d,0x00000000,0x00000000,0x00000000}},	//   _буьт, --, --, --, 
   {{0xada401c0,0xaec42e26,0xab2801e2,0x00000000}},	// [13cc0] ваал, тбал, ېستل_, --, 
   {{0xf064e55c,0x00000000,0x00000000,0x00000000}},	//   _акоп, --, --, --, 
   {{0x6ea096e9,0x6db40171,0xafe401a9,0xb5fc0064}},	//   _कुरु, _kņaz, _шонл, kyšo, 
   {{0xea880139,0x645c06af,0xaa880214,0x7dc80064}},	//   мбел_, _àpie, ونام_, _užsn, 
   {{0xdbdc3d64,0xbaa40131,0x66e00118,0x8884e55d}},	//   _bíót, лушқ, níků, گیان, 
   {{0xb9e408b0,0x3d1807c1,0xac08013d,0x5e74011a}},	//   اسنى, _पाये_, _онга_, _יתכן_, 
   {{0x6d4cde20,0x8884e55e,0x1d040114,0x765c01f4}},	//   _inba, دیان, _јеси_, äsyn, 
   {{0x47343e6b,0xeb3401ec,0x98a00114,0x00000000}},	//   унис, _جىرد, јиће, --, 
   {{0xb8c80b7d,0x6d4c0083,0x00000000,0x00000000}},	//   _गु_, _knba, --, --, 
   {{0xb5fc00bc,0x00000000,0x00000000,0x00000000}},	//   myšl, --, --, --, 
   {{0x6ab0c6cd,0x00000000,0x00000000,0x00000000}},	//   _जरुर, --, --, --, 
   {{0x66e4d59f,0x7f54001f,0xa68400db,0xd3a401d5}},	//   _рода, _መሪዎች, _илед, иряп, 
   {{0x6d4cda44,0x2c1c0154,0x13940212,0x00000000}},	//   _onba, ফিয়ে_, рияю, --, 
   {{0x44f40117,0x00000000,0x00000000,0x00000000}},	//   _спкс, --, --, --, 
   {{0x5064e55f,0x84380597,0x1fa47041,0x70440107}},	//   атта, _أكبر_, враг, гӯям_, 
   {{0x6ab0534e,0xdc980023,0xb5fc00a2,0x00000000}},	//   _जरूर, _ፈላማይ_, kyšl, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [13cd0] --, --, --, --, 
   {{0x9be402bf,0x68e80175,0xc0c4013d,0xde4401e2}},	//   відк, jbfd, _бәби, _ییزو_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3a74e560,0x6d4ce561,0x291801ab,0x69c40cad}},	//   ллер, _enba, òpan_, _èkej, 
   {{0x3f88e562,0xb5fce563,0x9e64007b,0xad14e564}},	//   miau_, vyšo, _شاحن, _әпсә, 
   {{0x3f88e565,0x399c006a,0x0d640801,0xfce800e3}},	//   liau_, dâsû_, _късм, _سفري_, 
   {{0x0ca80116,0xb5fc0419,0x00000000,0x00000000}},	//   _атти_, tyšo, --, --, 
   {{0x3f880cfd,0x2c600014,0x6fd4023e,0x704c0092}},	//   niau_, _دۯمُ, _मंसू, ኖርባቸ, 
   {{0x6d4c000f,0x7af8cd03,0x59b0113e,0x35a40022}},	//   _ynba, mawt, _көкс, лаиг, 
   {{0x3f8800a9,0x7af8011f,0x660401ed,0x09cc00fe}},	//   hiau_, lawt, ákka, ৰীবা, 
   {{0x7bd4e566,0x3f880006,0xefdc0023,0x84580395}},	//   _juzu, kiau_, ሕሪዚ_, врят_, 
   {{0x7bd4e567,0x36d40cfc,0x7af8e568,0x00000000}},	//   _muzu, _содр, nawt, --, 
   {{0x3f88e569,0x7bd4e56a,0x836001e1,0x00000000}},	//   diau_, _luzu, _ọrán, --, 
   {{0xd5640276,0x7af80309,0x00000000,0x00000000}},	//   _штеп, hawt, --, --, 
   {{0x3f880042,0x7af80327,0x154001af,0x00000000}},	//   fiau_, kawt, _беҙм, --, 
   {{0x3f884077,0x7af80455,0x25700356,0xcee47d9d}},	//   giau_, jawt, _tâlc_, рбақ, 
   {{0x7bd4e56b,0x6d4c0036,0xe2e000ee,0x7af8058a}},	// [13ce0] _auzu, _pnba, _ужып, dawt, 
   {{0x7bd4e56c,0x3f880421,0xb5fc02fb,0xad644d81}},	//   _buzu, aiau_, vyšl, داره, 
   {{0x3f88c09a,0x7bd4e56d,0x409402bf,0x6d4c0051}},	//   biau_, _cuzu, _врят, _vnba, 
   {{0x3f88e56e,0x7bd405f5,0x6d4c022f,0xf0e800f7}},	//   ciau_, _duzu, _wnba, _تىگى_, 
   {{0x7bd40165,0x765c005b,0x27fc0051,0x00000000}},	//   _euzu, äsyl, _svtn_, --, 
   {{0x6d4ce56f,0xa9040ec9,0x7bd4e570,0x6f140042}},	//   _unba, ابشن, _fuzu, lgyc, 
   {{0x7bd4e571,0x3d1833ee,0x6e340042,0x6fb8e572}},	//   _guzu, _पाते_, lwyb, ्षपू, 
   {{0xa0280023,0x6f14010e,0x00000000,0x00000000}},	//   _ስግኣታ, ngyc, --, --, 
   {{0x7bd4e573,0x853c0024,0x85742143,0x6e340042}},	//   _zuzu, klėt, илих, nwyb, 
   {{0x257000d2,0x7bd4e574,0x3f88e575,0x00000000}},	//   _bâla_, _yuzu, ziau_, --, 
   {{0x7c280640,0xb918063f,0x7bd401a9,0xb864e576}},	//   _ćerk, hafụ_, _xuzu, _پالو, 
   {{0x35b40323,0x00000000,0x00000000,0x00000000}},	//   лбөр, --, --, --, 
   {{0x3f88e577,0x6e340210,0x00000000,0x00000000}},	//   viau_, jwyb, --, --, 
   {{0x3f8800a9,0x5184e578,0x6e341d05,0xd42000cc}},	//   wiau_, буса, dwyb, _বছৰি_, 
   {{0x3f8800a9,0x4034e579,0xd718015b,0x88bc0118}},	//   tiau_, шевс, _দোয়া_, _oběm, 
   {{0x7bd4e57a,0x98a40356,0xe1fc00d7,0x00000000}},	//   _ruzu, lenă_, lyóm_, --, 
   {{0x3f88e57b,0x7bd420f7,0x853c00c0,0x00000000}},	// [13cf0] riau_, _suzu, blėt, --, 
   {{0x3f88e57c,0x7bd40165,0xe1fc00db,0x127c008f}},	//   siau_, _puzu, msó_, _ראזע, 
   {{0xe1fc00dd,0x3f88e57d,0x9c44e57e,0x7c34005b}},	//   lsó_, piau_, ыхал, реех, 
   {{0x25b04466,0x7bd40156,0x00000000,0x00000000}},	//   ुगुण, _vuzu, --, --, 
   {{0x7bd401b2,0xe1fce57f,0xfaa414b7,0x7af80198}},	//   _wuzu, nsó_, јало, rawt, 
   {{0x7bd4e580,0xdb208df6,0xb6f800d1,0x0cd4e581}},	//   _tuzu, _گوری, چىغا_, _горю, 
   {{0xb6f80075,0x6da00137,0x7af80455,0x00000000}},	//   نىغا_, _بۅلم, pawt, --, 
   {{0xee6002d3,0xdb20e582,0x7af8014f,0x853c0153}},	//   _ተራእዩ_, _دوری, qawt, klės, 
   {{0x45d405f5,0x00000000,0x00000000,0x00000000}},	//   йцэт, --, --, --, 
   {{0x98a40356,0x00000000,0x00000000,0x00000000}},	//   genă_, --, --, --, 
   {{0x98086a3b,0x98b0009f,0x00000000,0x00000000}},	//   _ستاف_, _الاڙ, --, --, 
   {{0x58840022,0x00000000,0x00000000,0x00000000}},	//   _иыҵа, --, --, --, 
   {{0xe56ce583,0x95e00228,0x853c00c0,0x00000000}},	//   _дз_, _ايتۇ, glės, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6ab001ad,0xd5840133,0x2634012d,0x00000000}},	//   _जर्र, _لێکه_, _zło_, --, 
   {{0x7fd40220,0x86c40137,0xa064e584,0xdd1c0118}},	//   сірі, _ئيۇن, шаса_, míři, 
   {{0x7de4e585,0xe1fc00dd,0x853c0024,0xee380408}},	// [13d00] مسلم, csó_, plėt, ъна_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3a2c003e,0xc05800c0,0xdca00798,0x00000000}},	//   _apep_, _біў_, оафи, --, 
   {{0xe9e42bbd,0x92d800fe,0xdbdc01a8,0xeeb800cf}},	//   ацко, িৰৰ_, _víðt, _үлүш_, 
   {{0xda740107,0x00000000,0x00000000,0x00000000}},	//   ияш_, --, --, --, 
   {{0xdbdc03b2,0x2d9498c5,0x7aec1427,0x00000000}},	//   _tíðt, _төбө_, ðatr, --, 
   {{0xd7f4c5dc,0x2ee001e1,0x98a4020c,0xc7e800db}},	//   ауы_, _kfkf_, venă_, دىعن_, 
   {{0x764c0309,0x97c00137,0xe1fc0429,0x00000000}},	//   _šaya, يقوو, ysó_, --, 
   {{0xba280933,0x7c2808a4,0xe1fc011f,0x7aece586}},	//   _مسلم_, _ćeri, xsó_, ñate, 
   {{0x7bc004cc,0x37a800f7,0x00000000,0x00000000}},	//   _èlur, ктөн_, --, --, 
   {{0x3d1800c5,0x98a40356,0x9f4001e3,0x00000000}},	//   _पासे_, renă_, msjö_, --, 
   {{0xe1fc01ed,0x63683420,0x22a00118,0x2634012d}},	//   tsó_, трог_, _léků_, _tło_, 
   {{0x5214e587,0xdb18020c,0xe578020f,0x6ea00037}},	//   одят, _dhuè, _изд_, _कँगु, 
   {{0x66000109,0xd5ac02bf,0x6d5c0113,0xe1fce588}},	//   _ivok, _єс_, jjpa, rsó_, 
   {{0xe1fce589,0x65780597,0xa2a474f6,0xd46400f3}},	//   ssó_, mhth, _टुर्, _вије_, 
   {{0x64480135,0x853c0006,0xe1fc0789,0x81600133}},	//   _irfi, plės, psó_, _کۆسۆ, 
   {{0x443ce58a,0x539c02e4,0x98a4762b,0x9f40007c}},	// [13d10] _hsv_, _שיחו, meną_, ksjö_, 
   {{0x657801fb,0xdb180165,0x9ce42bb6,0x98a44632}},	//   nhth, _ihué, рцал, leną_, 
   {{0x0dc8e58b,0x9f4001e3,0x4bd8009a,0x0ca80395}},	//   рути_, dsjö_, لبند_, атци_, 
   {{0x443ce58c,0x3d18007d,0x91a0004d,0x6ea03105}},	//   _msv_, _पावे_, _trị_, _कुकु, 
   {{0x443ce58d,0x6578e58e,0xb5fc0024,0x00000000}},	//   _lsv_, khth, ryšk, --, 
   {{0x443c51dc,0x89a80212,0x9f40007c,0x8ff800f2}},	//   _osv_, аків_, gsjö_, _حریر_, 
   {{0x6600e58f,0x7e6ce590,0x443c2135,0x65780332}},	//   _avok, lyap, _nsv_, dhth, 
   {{0xf770e591,0x9a846140,0xe1fc00e5,0x00000000}},	//   ثات_, _кузл, gyók_, --, 
   {{0x3a74e592,0x443c00da,0x64480af5,0x6d4800d8}},	//   _улар, _asv_, _arfi, ôfag, 
   {{0x657814dc,0x443c005c,0x88bc0118,0x18880166}},	//   ghth, _bsv_, _oběh, _исеп_, 
   {{0x6600e593,0x7e6ce594,0x53c40150,0x00000000}},	//   _evok, hyap, жанұ, --, 
   {{0x3dd00472,0xc1680375,0x98a40064,0x290000de}},	//   _lizw_, _אח_, geną_, _ēkai_, 
   {{0x6448e595,0x657835ab,0x66000165,0x999c0f91}},	//   _erfi, bhth, _gvok, _zruš_, 
   {{0x6578e596,0xdb18020c,0x1dd8068f,0x7e6c00dc}},	//   chth, _dhué, _बढ़त, dyap, 
   {{0xafe407d6,0x66000e8a,0x29000134,0x2fd80214}},	//   собл, _zvok, _ɛka_, اورد_, 
   {{0xf12400c7,0x00000000,0x00000000,0x00000000}},	//   шьҭо, --, --, --, 
   {{0x31e0045e,0x6ea00316,0x7c6c001f,0x7e6ce597}},	// [13d20] _বিকশ, _कुखु, _በሚለው_, gyap, 
   {{0x3200e598,0x5bcc0ef6,0xdefc0135,0x9f40007c}},	//   msky_, _ﺑﺎﺭﻻ, ċċat_, xsjö_, 
   {{0x3200e599,0x7e6c0309,0x9f400267,0x3d18007a}},	//   lsky_, ayap, vsjö_, _पारे_, 
   {{0xeaf8e59a,0x7e6c5abd,0x2cbc0139,0x00000000}},	//   ارات_, byap, _ıydı_, --, 
   {{0xa9683ba6,0x3200e59b,0x2988311b,0xa2c80807}},	//   лида_, nsky_, лско_, सेप्, 
   {{0x32000072,0x6bd83346,0x7c4403b2,0x00000000}},	//   isky_, _موسس_, ðurí, --, 
   {{0x2d88014b,0x6600e59c,0x9f400267,0xeb98bf77}},	//   _imbe_, _svok, rsjö_, _бив_, 
   {{0x3dd80066,0xab9400c6,0x9f400267,0x57a000c7}},	//   _yusw_, _الرغ, ssjö_, зшьа, 
   {{0x6578e59d,0xda60721f,0xe728528e,0x7bc00421}},	//   thth, _евти, نسکو_, _ūlug, 
   {{0x3200e59e,0x00000000,0x00000000,0x00000000}},	//   dsky_, --, --, --, 
   {{0x3200e59f,0x291ce5a0,0x68f80857,0xa2c866c0}},	//   esky_, _icta_, _ietd, सेन्, 
   {{0x12e4005e,0x657800cd,0xf1d80316,0x29f40034}},	//   зірг, shth, _यूहन, oła_, 
   {{0x2d885053,0xe5a4e5a1,0x6578bf0f,0x68f807d6}},	//   _ombe_, _лиди, phth, _ketd, 
   {{0x2d88003e,0x443ce5a2,0x6448003e,0x98a40024}},	//   _nmbe_, _tsv_, _trfi, seną_, 
   {{0x7dc80953,0x92d80183,0x443ce5a3,0x7e6c0986}},	//   _užsi, িৰে_, _usv_, wyap, 
   {{0x7e6ce5a4,0x2d88e5a5,0x68f8014f,0x29f4033f}},	//   tyap, _ambe_, _letd, kła_, 
   {{0x291ce5a6,0x00000000,0x00000000,0x00000000}},	// [13d30] _octa_, --, --, --, 
   {{0x68f8c19f,0x7e6c7022,0x29f40034,0x40340276}},	//   _netd, ryap, dła_, _деос, 
   {{0x29f4033f,0x88bc00bc,0x7e6ce5a7,0x3ed42cc0}},	//   eła_, _uběh, syap, _وقدر, 
   {{0x2d88e5a8,0x3dd80142,0xd46c0092,0x00000000}},	//   _embe_, _tusw_, ሥልጣኑ_, --, 
   {{0x68f8e5a9,0x29f40034,0xbb6400b5,0xe04801d5}},	//   _betd, gła_, _phpソ_, _ششگه_, 
   {{0x6ea0e5aa,0x00000000,0x00000000,0x00000000}},	//   _कुटु, --, --, --, 
   {{0x29f4068f,0x68f818c3,0x76d8013e,0x32000306}},	//   ała_, _detd, қуқӣ_, zsky_, 
   {{0x291c009a,0x7c24e5ab,0x68f80549,0x320002fb}},	//   _ecta_, mthr, _eetd, ysky_, 
   {{0xa2c80316,0xab600952,0x7c24e5ac,0x3af800b5}},	//   सेम्, _تۇنى, lthr, 用pu_, 
   {{0x3200e5ad,0xd7f80aa5,0x68f8e5ae,0x7c240e9e}},	//   vsky_, _буд_, _getd, othr, 
   {{0x3200e5af,0xd8b400cf,0x645c0ca8,0xceb403e3}},	//   wsky_, _اپاچ_, _àpil, nfər_, 
   {{0x7c24e5b0,0x3200e5b1,0x853c0006,0x291c01e4}},	//   ithr, tsky_, slėp, _zcta_, 
   {{0xf1a800aa,0x68f8e5b2,0xeb38008f,0x3200e5b3}},	//   لاسه_, _yetd, בערש, usky_, 
   {{0x3200e5b4,0xb12802d3,0x7c24003c,0x637c036e}},	//   rsky_, _ስምዒታ, kthr, _nënf, 
   {{0x29f4033f,0x764802e2,0xa06423c5,0x00000000}},	//   zła_, lvey, оара_, --, 
   {{0x7c24624d,0x29f40034,0x32001f98,0x00000000}},	//   dthr, yła_, psky_, --, 
   {{0x7648e5b5,0x7c243deb,0x0d0801ec,0x00000000}},	// [13d40] nvey, ethr, йдақ_, --, 
   {{0x64440034,0xceb403b9,0x7c24032e,0x00000000}},	//   łkie, ffər_, fthr, --, 
   {{0xdb080120,0xdd8c007b,0x29f4033f,0x764803e0}},	//   mogê, خول_, wła_, hvey, 
   {{0xab289fc8,0x68f8e5b6,0x7c2800f3,0xdb0800d8}},	//   рода_, _setd, _ćert, logê, 
   {{0x7c240fa3,0x7aec1269,0x98a47063,0x68f8e5b7}},	//   athr, ñata, menę_, _petd, 
   {{0x68f80455,0x2d88e5b8,0xdb0800d8,0x29f4033f}},	//   _qetd, _umbe_, nogê, rła_, 
   {{0x29f4068f,0x307800c8,0x78a00393,0x644402b5}},	//   sła_, יאַנ, _cxlv, ākik, 
   {{0x29f40034,0xeb9802a9,0x88bc01ef,0x00000000}},	//   pła_, _тиб_, _oběv, --, 
   {{0x2b44e5b9,0x68f8022e,0x637c0240,0x20a4012d}},	//   mdoc_, _tetd, _hëng, _गड्ढ, 
   {{0x637ce5ba,0xa2c86b26,0x7c4426b8,0x2b440165}},	//   _këng, _सृष्, _ótrú, ldoc_, 
   {{0x9cd804ac,0x76480076,0x84980023,0xe7382a5e}},	//   יקיפ, avey, _ዋዕላን_, _вее_, 
   {{0x637c8302,0x2b44e5bb,0x00000000,0x00000000}},	//   _mëng, ndoc_, --, --, 
   {{0x637ce5bc,0x4624025c,0xd24412cf,0xaac800bc}},	//   _lëng, _འདྲས_, мэри, िधिक, 
   {{0x7c24e5bd,0x2000003b,0x2b4400e4,0x00000000}},	//   ythr, tsji_, hdoc_, --, 
   {{0x637c24ba,0x1048e5be,0xdfd80395,0xf07804b4}},	//   _nëng, ояти_, ръг_, бирә_, 
   {{0x20000034,0xd3780124,0x00000000,0x00000000}},	//   rsji_, _мчы_, --, --, 
   {{0x7c24e5bf,0xdce401e4,0x20000327,0xceb403e3}},	// [13d50] wthr, _hojĉ, ssji_, ffəq_, 
   {{0x2b44e5c0,0x637c025a,0x7c24e5c1,0xdb080798}},	//   edoc_, _bëng, tthr, cogê, 
   {{0x2fc001ab,0x2b446eee,0x98a40064,0x00000000}},	//   _fhkg_, fdoc_, benę_, --, 
   {{0x7c24e5c2,0x637ce5c3,0x644402b5,0x98a40210}},	//   rthr, _dëng, ākih, cenę_, 
   {{0x0e08e5c4,0x7c24e5c5,0xdb08df62,0x9f9c0036}},	//   _мэри_, sthr, logë, _léën_, 
   {{0x7c24e5c6,0x2b443813,0x19a81075,0x00000000}},	//   pthr, adoc_, штеп_, --, 
   {{0x637ce5c7,0xd0f825f9,0x17240327,0xf77000ae}},	//   _kënd, חמות_, _རྡུམ_, فاة_, 
   {{0x637c1bce,0x0bcc00d1,0x00000000,0x00000000}},	//   _jënd, _ﺑﺎﻳﺮ, --, --, 
   {{0x637ce5c8,0x3a740137,0xa3ac0037,0x6b50022e}},	//   _mënd, _элар, कवन_, mаgа, 
   {{0x637ce5c9,0x7648e5ca,0x34840137,0x6b50022e}},	//   _lënd, rvey, згог, lаgа, 
   {{0x7dc80024,0xb5fc02fb,0xc568007b,0x76d401c8}},	//   _užsu, vyšu, تحيل_, _فياض, 
   {{0x637c0240,0x1dd8000d,0x00000000,0x00000000}},	//   _nënd, _बढंत, --, --, 
   {{0x39440165,0x42d40220,0xe2940ce8,0xded40f7c}},	//   _kals_, діру, зая_, ርካን_, 
   {{0xf3e4024c,0xd5a00244,0x00000000,0x00000000}},	//   _ежко, _تلتی, --, --, 
   {{0x3944e5cb,0xdb08e5cc,0x2b440175,0xf8b4010f}},	//   _mals_, gogë, ydoc_, לפֿי_, 
   {{0xe0400166,0xdb18007b,0x39440142,0xa2a4012c}},	//   энси, _bhuí, _lals_, _टुक्, 
   {{0x637ce5cd,0xdb08e5ce,0xdb1801e7,0x42b80046}},	// [13d60] _dënd, mogè, _chuí, _ونىڭ_, 
   {{0xddc803ee,0xdcac0f78,0xdb0806af,0x6fd40212}},	//   ğişm, گىم_, logè, _німц, 
   {{0x6bd40efb,0x637c0036,0x2b440072,0x00000000}},	//   ستار, _fënd, tdoc_, --, 
   {{0xdcac1a59,0xdb180332,0xdb082ffe,0x00000000}},	//   دىم_, _fhuí, nogè, --, 
   {{0x2b44067c,0x3944e5cf,0xdca0013e,0xd97800fd}},	//   rdoc_, _bals_, _ҷари, әрчә_, 
   {{0x39440d81,0x637c006a,0x2900005f,0x88bc00bc}},	//   _cals_, _tëng, _ēkas_, _obět, 
   {{0x072019e5,0x39441675,0xdca0e5d0,0x637ce5d1}},	//   _यादव_, _dals_, _зари, _hëne, 
   {{0x98a400bc,0x637ca82b,0x29100bbc,0x00000000}},	//   leně_, _këne, şya_, --, 
   {{0x3944e5d2,0x2e240a85,0xdb080129,0x00000000}},	//   _fals_, nôf_, dogè, --, 
   {{0x637c1bce,0x7dc80024,0x3944045a,0x00000000}},	//   _mëne, _užst, _gals_, --, 
   {{0x2e24045f,0x69780150,0x69c8e5d3,0xd494011c}},	//   hôf_, _وﺗﺒﺎ, mmfe, зря_, 
   {{0x18740302,0x00000000,0x00000000,0x00000000}},	//   _מעבר_, --, --, --, 
   {{0x637c0023,0x6fd40d5f,0x2ee0015b,0x69c8e5d4}},	//   _rënd, _मंजू, বরাষ, omfe, 
   {{0xd65400d9,0x83f8005b,0x637ce5d5,0x98a4013a}},	//   _מידת_, _декс_, _sënd, jeně_, 
   {{0xdb180597,0x637c00e8,0x55b8011a,0x00000000}},	//   _shuí, _pënd, _המגו, --, 
   {{0xe3b01d1f,0x637c0240,0xdb080561,0x9f9c01c7}},	//   _ڪرڻ_, _qënd, cogè, _kéén_, 
   {{0x63ac9637,0x637c0023,0xe0e401a9,0xdef80150}},	// [13d70] mocn, _vënd, _нўно, _қын_, 
   {{0xdb08e5d6,0x63ac0030,0x637ce5d7,0x61f80356}},	//   mogé, locn, _wënd, âulu, 
   {{0x656802c4,0x637c02d3,0x3944e5d8,0x9f9c00e8}},	//   _mofh, _tënd, _rals_, _léén_, 
   {{0x3944e5d9,0xdec858a8,0x69c8009a,0x63ace5da}},	//   _sals_, _гугл_, emfe, nocn, 
   {{0x3944e5db,0xdb08e5dc,0x637c1bce,0x656804e6}},	//   _pals_, nogé, _gëne, _oofh, 
   {{0x996434d8,0x67200407,0xfd040014,0xdb08020c}},	//   ятел, _acoj, _زورَ, iogé, 
   {{0x3944e5dd,0xdb080129,0xdb200356,0x00000000}},	//   _vals_, hogé, ărâm, --, 
   {{0x9f9c00e8,0xe1fc9262,0x39440af9,0xf5e84965}},	//   _béén_, nyós_, _wals_, омил_, 
   {{0x3944e5de,0xdb1801fb,0x7ae8e5df,0xed600171}},	//   _tals_, _thuâ, _ifet, bežā_, 
   {{0x6720010f,0x656801c3,0x9f9c04e6,0x394405d5}},	//   _ecoj, _cofh, _déén_, _uals_, 
   {{0x7ae80270,0x5fbc18ea,0xb5fc13d5,0x656800ae}},	//   _kfet, ्षाल, tyšs, _dofh, 
   {{0x7ae80327,0xb8140055,0xb4bc32ed,0x98a400bc}},	//   _jfet, _aṭgu, _आरी_, zeně_, 
   {{0xdb08e5e0,0x9f9ce5e1,0x1c1c033f,0x4254030d}},	//   rogè, _géén_, मंडल_, нтрт, 
   {{0xdb08e5e2,0xe3e40220,0x00000000,0x00000000}},	//   llgä, _ﺍﻟﺩﻓ, --, --, 
   {{0xe5a0e5e3,0xdb08004e,0x6fd40212,0x00000000}},	//   _шиши, pogè, діац, --, 
   {{0x637c02b5,0xe3b40801,0x3b0c0455,0x7ae8025c}},	//   _pëne, _общ_, _ndeq_, _nfet, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [13d80] --, --, --, --, 
   {{0x7ae8e5e4,0x2e24045f,0xf1d81b51,0x00000000}},	//   _afet, rôf_, _यूएन, --, 
   {{0xdcac1b56,0x6ad400a5,0x2e24002d,0x2b4401c6}},	//   لىك_, धश्र, sôf_, дэлг, 
   {{0x637ce5e5,0x00000000,0x00000000,0x00000000}},	//   _tëne, --, --, --, 
   {{0x41b00014,0xa3ac01f9,0x00000000,0x00000000}},	//   _شۅہر, कवत_, --, --, 
   {{0x7ae803b7,0x1954c331,0x00000000,0x00000000}},	//   _efet, дашы_, --, --, 
   {{0x7ae8e5e6,0x65680036,0x9f9c00e8,0x00000000}},	//   _ffet, _rofh, _séén_, --, 
   {{0xdb1801ab,0xf8140131,0xdb080129,0x7ae8007c}},	//   _ghuà, رسىگ, yogé, _gfet, 
   {{0x81b404c5,0x45d4119e,0xa924399f,0xda6ce5e7}},	//   জগত_, ноис, _одал, _پُل_, 
   {{0x6b802784,0x19c03d89,0x7ae801ef,0x00000000}},	//   lhog, _абум, _zfet, --, 
   {{0x63ac181f,0x3d140ca8,0x439422c3,0x6708009d}},	//   tocn, _hùwà_, еанс, _дэлг_, 
   {{0x6b80e5e8,0xdb08e5e9,0xe7381c7b,0x7c20143a}},	//   nhog, togé, _фед_, _ålre, 
   {{0x63ace5ea,0xdbe0003e,0xb6300066,0x00000000}},	//   rocn, réén, _یکیش, --, 
   {{0x454400aa,0x78c40162,0xdb08e5eb,0xdb1c032e}},	//   _سرتې, _ítvø, rogé, _ávör, 
   {{0xdb0804f3,0xd48c02bf,0x4394e5ec,0x9f6800c0}},	//   llgå, _рр_, _пакс, ораз_, 
   {{0x4f940063,0x3cec01ef,0x27f80419,0x00000000}},	//   врђу, _řev_, ápny_, --, 
   {{0xf2c06610,0x6b80ab1a,0x12fc011a,0x86600092}},	// [13d90] _бөри, dhog, _והחב, ፍጋኒስ, 
   {{0x7ae8b900,0xdcb800c9,0x00000000,0x00000000}},	//   _sfet, още_, --, --, 
   {{0x7ae80810,0x009401c6,0x6b8000ae,0x00000000}},	//   _pfet, _чинэ, fhog, --, 
   {{0xa3ac5b29,0xf7cc02dd,0x00000000,0x00000000}},	//   कवि_, _ﺗﺎﻋﺪ, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbf1400db,0xa3dc00dc,0x66c4022e,0x00000000}},	//   _توڭب, तदा_, rаkl, --, 
   {{0xa3ace5ed,0xb4bc2de3,0x6b800882,0x88bc012c}},	//   कवा_, _आरे_, bhog, _sběr, 
   {{0x7d04de03,0x3eb828b3,0x8bc46264,0xdce40010}},	//   lahs, _kyst_, _асуд, _mojč, 
   {{0xf6505dda,0x3eb800ad,0xe8c40327,0xdb0801bf}},	//   ائب_, _jyst_, གཟུག, glgå, 
   {{0x3eb800d8,0xd58403e6,0x7d04e333,0x75441188}},	//   _myst_, بێته_, nahs, хноз, 
   {{0x5fd81d8a,0x3eb86ab9,0x00000000,0x00000000}},	//   _मंगल, _lyst_, --, --, 
   {{0x3eb803b2,0xa2a400bc,0x00000000,0x00000000}},	//   _oyst_, _टुङ्, --, --, 
   {{0xa0a0036b,0x7d040205,0xa2c807af,0x00000000}},	//   ҳард, kahs, सेल्, --, 
   {{0x7d0402d0,0x3d18012d,0x75c801af,0x00000000}},	//   jahs, दलों_, _этең_, --, 
   {{0xa0a0e5ee,0x6b8001ed,0x644c007c,0x00000000}},	//   гард, yhog, åbit, --, 
   {{0x6180044e,0xdce401f1,0x3eb81967,0x644402b5}},	//   _ሓፈሻዊ_, _dojč, _byst_, ākit, 
   {{0x6b801682,0x7d0400ca,0x7fd40220,0x59ac0d2b}},	// [13da0] vhog, fahs, тірі, टवार, 
   {{0xdd8c282b,0xfe7001d9,0x3eb8e5ef,0x7d044c8f}},	//   موق_, جدِ_, _dyst_, gahs, 
   {{0x6b80e5f0,0x3eb80162,0xb4bc00c5,0x3074030d}},	//   thog, _eyst_, _आरो_, _чупс, 
   {{0x637c044e,0x3eb80158,0xe29c09f3,0x61f80356}},	//   _këna, _fyst_, laða_, ţule, 
   {{0x6b800ae3,0x7d04e5f1,0xd9e000fe,0x5fbc276a}},	//   rhog, bahs, নীসম, ्षरल, 
   {{0x6b80e5f2,0xe29c2833,0x637c1bce,0x7dc80153}},	//   shog, naða_, _mëna, _užsp, 
   {{0x2c840241,0x178802d3,0x69040171,0x00000000}},	//   _dídé_, _ንህዝቡ_, _ārdī, --, 
   {{0x18940597,0xe6640b3b,0x3eb80076,0x3a4401f4}},	//   عضوة_, етоо, _yyst_, äppä_, 
   {{0x637c0023,0x26c00158,0x77900214,0xe9a40153}},	//   _nëna, åko_, جینا, _заап, 
   {{0x3d1805f9,0xe29c0d12,0xdb040241,0xdefc0327}},	//   _पाछे_, jaða_, _àlòg, ċċit_, 
   {{0x42ac02f5,0x69d8e5f3,0x38600e78,0x26c00419}},	//   _গণেশ, _iite, ährt_, ťko_, 
   {{0x69d8e5f4,0xf3f4328a,0xa6840d1d,0x24a400dc}},	//   _hite, کتیک, _плед, _ātmā_, 
   {{0x69d8e5f5,0x7d04020c,0x42a400d1,0xe29c032e}},	//   _kite, yahs, тунғ, faða_, 
   {{0x69d8e5f6,0x637c002e,0x3eb8005c,0xbd740092}},	//   _jite, _dëna, _ryst_, _በፊትም_, 
   {{0x9fc4016a,0x27fc05b1,0xceb403b9,0x00000000}},	//   ещал, _jwtn_, lgəh_, --, 
   {{0xa03402d3,0x65786b41,0x3eb80042,0xdce400d7}},	//   _ኣካይዶ, lkth, _pyst_, _vojč, 
   {{0x69d8e5f7,0x2570002d,0x442ca38d,0x637c1bce}},	// [13db0] _oite, _fâlt_, ltd_, _gëna, 
   {{0x69d8e5f8,0xcb5c00a2,0x00000000,0x00000000}},	//   _nite, _durэ, --, --, 
   {{0x7d04e5f9,0xf9901208,0x7c580131,0x0388002b}},	//   rahs, یبت_, بلار_, _śeṣe, 
   {{0x3a7409a5,0x69d8e5fa,0x3eb8e5fb,0x3ad40a11}},	//   клер, _aite, _tyst_, نياز, 
   {{0x69d8e5fc,0xce580c98,0x2ebc0882,0x7f4c01a9}},	//   _bite, _заяц_, ्धृत, mdaq, 
   {{0x69d8e5fd,0x7f4ce5fe,0xb90c00c7,0x37e4015b}},	//   _cite, ldaq, _hokẽ_, _নববর, 
   {{0xdb08e5ff,0x5ba4242f,0xa96400a7,0x668001d5}},	//   logí, _зраз, тища_, ییمل, 
   {{0x70dc375c,0x69d8e600,0x442c0175,0x2be401f9}},	//   _मल्ल, _eite, dtd_, _जंतू_, 
   {{0x69d80851,0x7bc800b0,0x27fc039a,0x00000000}},	//   _fite, _iheu, _ewtn_, --, 
   {{0x69d8e601,0x17f800c6,0xe79402f2,0xa7c80055}},	//   _gite, _فرصة_, _یانک, _vṛṇv, 
   {{0x79802f05,0xc984e602,0xd6a804fb,0x7bc800e8}},	//   _illw, _сути, _کدام_, _kheu, 
   {{0x69d8e603,0x2570045f,0xe690006c,0x6578e604}},	//   _zite, _sâlt_, الید, akth, 
   {{0x69d830b6,0xe29c066a,0x7f4c0548,0x7bc80e89}},	//   _yite, taða_, ddaq, _mheu, 
   {{0x6578e605,0x69d80564,0x7bc8e606,0x7f4c003a}},	//   ckth, _xite, _lheu, edaq, 
   {{0xafe407d6,0x442ce607,0x25b400ae,0x00000000}},	//   тобл, ctd_, _جهود_, --, 
   {{0x7bc81ae3,0x637c04e6,0x645c0e04,0x00000000}},	//   _nheu, _hënn, _špig, --, 
   {{0x637c092e,0xdb08982b,0x2ebc07b6,0x7980015d}},	// [13dc0] _kënn, gogí, ्धेत, _ollw, 
   {{0x7bc8e608,0x91a801d3,0xed5800d4,0x00000000}},	//   _aheu, _سنجے_, ьоз_, --, 
   {{0x69d8e609,0xe6bc1ab2,0x7bc80192,0x637c0de2}},	//   _rite, _ऊर्ज, _bheu, _mënn, 
   {{0x69d8e60a,0x7980e60b,0x7bc8e60c,0x888402dd}},	//   _site, _allw, _cheu, ңғал, 
   {{0x7bc8e60d,0xdb080789,0x999c0427,0xae1ce60e}},	//   _dheu, cogí, _druž_, यूशन_, 
   {{0x69d820ac,0x6da44f33,0x637c94f5,0x6cc44530}},	//   _qite, _рига, _nënn, _айга, 
   {{0xeb9821fa,0x7bc80013,0x6ed405d7,0x798003ac}},	//   _жив_, _fheu, _मृतु, _dllw, 
   {{0x69d8e60f,0x798014dc,0xdca03c00,0x7bc8e610}},	//   _wite, _ellw, _таси, _gheu, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69d8e611,0x84c40131,0x442c3ed6,0xabbc00d1}},	//   _uite, ләйд, ttd_, ﺭﯨﻐﺎ, 
   {{0x6578044e,0x637ce612,0x443856eb,0x00000000}},	//   rkth, _dënn, ïr_, --, 
   {{0xc8842ed0,0x442c98e4,0x61a800dc,0xc7b80051}},	//   ışı_, rtd_, चक्ष, _cqđt_, 
   {{0x637c0a40,0xb90c0022,0x442c00ef,0xdce40171}},	//   _fënn, _rokẽ_, std_, _lojā, 
   {{0xb9ec044e,0x637c00e8,0x442ca309,0x16840244}},	//   _ሒዙ_, _gënn, ptd_, _جامێ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x637c0036,0xdce400bc,0xd84c00b8,0x8d7400f1}},	//   _zënn, _pojď, _jñāṇ, یالا, 
   {{0xd50c0296,0x6ed4e613,0xdb0c0129,0x637c036e}},	// [13dd0] lɛ́t, _मृदु, _àdév, _hëno, 
   {{0x7bc8e614,0xdce4005f,0x05140c58,0x5bc800dc}},	//   _sheu, _bojā, ত্ৰৰ_, िष्व, 
   {{0x7bc801ab,0xb5e80150,0x80d000cc,0x5c0401f4}},	//   _pheu, _ﺎﻟﻤﻌ, _ত্ৰৈ, тяза, 
   {{0xdd00538f,0x637c1bce,0x7f4c0477,0x01cc0150}},	//   ırın, _mëno, qdaq, _ﻓﻌﻠﻨ, 
   {{0x798002d0,0x41a002dd,0x69f000cf,0x00000000}},	//   _pllw, _ﺍﻳﮕﯩ, йүтт, --, 
   {{0x7bc804fe,0x527c0a1e,0xaa5400c6,0x3d940a5b}},	//   _wheu, ונדא, الوا_, _сигр, 
   {{0x26c4e615,0x637ca82b,0xdb08cca2,0x00000000}},	//   _azoo_, _rënn, rogâ, --, 
   {{0x637c04e6,0x386808a4,0x7bc800d8,0xdb208c9e}},	//   _sënn, ćar_, _uheu, _خوری, 
   {{0x999c0327,0xdb0800db,0xe6140a89,0xdb0c010e}},	//   _kruż_, mogà, гды_, _ýeñe, 
   {{0x8934e616,0x81d803d4,0xd7603c5a,0xd7f8022e}},	//   _نعما, াৱত_, انکی, _жуд_, 
   {{0x26c40472,0x637c0240,0x00000000,0x00000000}},	//   _ezoo_, _cëno, --, --, 
   {{0x637ce617,0x888c008f,0x066403e6,0xdb08004e}},	//   _dëno, _קראַ, _چاوپ, nogà, 
   {{0xed4c022e,0x00000000,0x00000000,0x00000000}},	//   ydо_, --, --, --, 
   {{0xd50c0085,0x00000000,0x00000000,0x00000000}},	//   bɛ́t, --, --, --, 
   {{0x637c0694,0x98a400e2,0xa5d8008f,0x3438008f}},	//   _gëno, menē_, _אַהי, _טײַע, 
   {{0x32440022,0x128801d3,0x00000000,0x00000000}},	//   _беиг, _لمبی_, --, --, 
   {{0x1fa4e618,0xada401c0,0x637c002e,0xdb0835f5}},	// [13de0] укти_, гаал, _mënl, dogà, 
   {{0x61e80165,0xb14401af,0x00000000,0x00000000}},	//   _égla, _снол, --, --, 
   {{0xe1fc0005,0x00000000,0x00000000,0x00000000}},	//   nxón_, --, --, --, 
   {{0xa09800c8,0xe1fc056a,0x637c0240,0xa2c801ad}},	//   _טייט, ixón_, _nënl, सेक्, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d4c5a25,0x26c400b5,0x6f040010,0xc7b0009f}},	//   _iaba, _szoo_, _kekc, يّت_, 
   {{0x6d4ce619,0xdcac0150,0x8624036b,0x00000000}},	//   _haba, _رىق_, لکتل, --, 
   {{0x6d4ce61a,0xf1b400dc,0xd7c40691,0xa50400ee}},	//   _kaba, ृतान, دويه_, лянл, 
   {{0x6d4ce61b,0x16340597,0x6f04e61c,0x637c002e}},	//   _jaba, اسية_, _lekc, _pëno, 
   {{0xa8182761,0xd7ec00ae,0x00000000,0x00000000}},	//   _ستار_, _فكل_, --, --, 
   {{0x6d4ce61d,0x66e4e61e,0x2d98e61f,0x6f04009a}},	//   _laba, _сода, hipe_, _nekc, 
   {{0x2d98e620,0x6d4c01af,0x98a40171,0xdef800c7}},	//   kipe_, _oaba, benē_, ҵыз_, 
   {{0x6600e621,0x2d98009f,0x00000000,0x00000000}},	//   _iwok, jipe_, --, --, 
   {{0x660005b8,0x2d98c4f9,0x6f042681,0xdb08e622}},	//   _hwok, dipe_, _bekc, hogá, 
   {{0x6448e623,0x6600e624,0x6d4ce625,0x6f040e02}},	//   _isfi, _kwok, _aaba, _cekc, 
   {{0x75ec0419,0x00000000,0x00000000,0x00000000}},	// [13df0] _kĺza, --, --, --, 
   {{0xf1a804d3,0x6600e626,0x637c002e,0x6f04035a}},	//   _لاپه_, _mwok, _mënm, _eekc, 
   {{0x66000a49,0x9ba01473,0x443c02d2,0x3a2c0200}},	//   _lwok, مەسى, _jpv_, _sqep_, 
   {{0x443ce627,0x6600513c,0x6d4c0086,0xdb0801ed}},	//   _mpv_, _owok, _eaba, fogá, 
   {{0x443c009a,0x660000b4,0xdb08004e,0x0ae800d4}},	//   _lpv_, _nwok, rogà, удій_, 
   {{0x3f88e628,0x6f04014b,0x8ff8072d,0x00000000}},	//   lhau_, _zekc, _جریر_, --, 
   {{0x6600e629,0x3f8802b5,0xc9840640,0x6f0406be}},	//   _awok, ohau_, ључи, _yekc, 
   {{0xf770e62a,0x660051a9,0x3f88e62b,0x9a840209}},	//   تات_, _bwok, nhau_, _йузл, 
   {{0x443ce62c,0x9a84e62d,0xb6a4bd24,0x3f880368}},	//   _apv_, _сувл, рипл, ihau_, 
   {{0x6d4ce62e,0x3f8801f0,0xe574e62f,0x00000000}},	//   _xaba, hhau_, изы_, --, 
   {{0x443ce630,0xd7f80107,0x2fd003cb,0xf8b000f2}},	//   _cpv_, _чуз_, ymyg_, _بکش_, 
   {{0xe72c4b87,0x443ce631,0x3f880007,0xf6d40024}},	//   _ќе_, _dpv_, jhau_, _кіля, 
   {{0x443c030d,0x3f88e632,0x66000a49,0x36d405f5}},	//   _epv_, dhau_, _gwok, _тодр, 
   {{0x6f04e633,0x80b0033f,0x3bf003b9,0x49c8010a}},	//   _sekc, _आँखे, _eşqə_, _улĕн_, 
   {{0x6fb412e3,0x637c0023,0xd498010a,0x04780ee8}},	//   لمسا, _mënj, _ярд_, _ملوک_, 
   {{0x6d4ce634,0x7278039b,0x1fa4e635,0xb4d00073}},	//   _saba, _асос_, акси_, वधी_, 
   {{0xacf4e636,0x2fd00042,0x00000000,0x00000000}},	// [13e00] لسات, rmyg_, --, --, 
   {{0x6d4ce637,0x645c1dec,0x3f8800d8,0xdb0800d8}},	//   _qaba, _ápic, ahau_, vogá, 
   {{0x2d98e638,0x6d4ce639,0xef180276,0x6f04e63a}},	//   ripe_, _vaba, _имн_, _tekc, 
   {{0x2d98e63b,0x3f88e63c,0x9bc800f1,0x00000000}},	//   sipe_, chau_, ندنې_, --, 
   {{0x2d98e63d,0xa9685ab0,0x637c0200,0x9b4001d9}},	//   pipe_, кида_, _bënj, زنوو, 
   {{0x2d98e63e,0x6600e63f,0x59d016ac,0x00000000}},	//   qipe_, _rwok, يغور, --, 
   {{0xdc640aa5,0x765800a9,0x660002b9,0x00000000}},	//   _кард_, _arwy, _swok, --, 
   {{0x76580368,0x6600033b,0x443c0175,0xb5fc010e}},	//   _brwy, _pwok, _rpv_, lyšy, 
   {{0xe9d8e640,0x76580368,0xaaa84709,0x962400ae}},	//   _ака_, _crwy, _कशिक, لكيك_, 
   {{0x765800a9,0x637c8302,0x443c045a,0x96b40114}},	//   _drwy, _gënj, _ppv_, јућу_, 
   {{0x76580142,0x272800db,0x3f88015d,0x00000000}},	//   _erwy, _ажеп_, yhau_, --, 
   {{0x6600e641,0x76580368,0xe61801c4,0x00000000}},	//   _twok, _frwy, _адд_, --, 
   {{0x6600019f,0x7658015d,0xe5a4e642,0x443c0208}},	//   _uwok, _grwy, _киди, _wpv_, 
   {{0x3f8804fe,0x5184e643,0xdce40210,0x00000000}},	//   whau_, оуса, _koją, --, 
   {{0x3f880f7b,0x443ce644,0x644801f0,0x00000000}},	//   thau_, _upv_, _usfi, --, 
   {{0x3f88166a,0x637c00e8,0x7658015d,0x00000000}},	//   uhau_, _mënk, _yrwy, --, 
   {{0x3f8800a9,0x637ce645,0x9ce40d30,0x753c01d3}},	// [13e10] rhau_, _lënk, ацел, ősze, 
   {{0x78ac47af,0x628c0007,0x21240fac,0x00000000}},	//   şavi, mzco, _ønh_, --, 
   {{0x637c0240,0x00000000,0x00000000,0x00000000}},	//   _nënk, --, --, --, 
   {{0x8b940212,0xb14401d9,0x3ce8012d,0x00000000}},	//   оріч, _پیہم_, _जलवे_, --, 
   {{0x30900020,0x628c0007,0x00000000,0x00000000}},	//   ረጋገጥ_, nzco, --, --, 
   {{0xe8a00023,0xfd740166,0x00000000,0x00000000}},	//   _ዝቕመጡ_, _улгэ, --, --, 
   {{0x26c02045,0x00000000,0x00000000,0x00000000}},	//   ükon_, --, --, --, 
   {{0xf9345945,0x7c240477,0x475873f6,0x00000000}},	//   _گذرگ, muhr, арья_, --, 
   {{0x7c2402fb,0x3f9801a6,0xceb406be,0x853c00c0}},	//   luhr, _mmsu_, lgər_, rnėn, 
   {{0xc9740597,0x00000000,0x00000000,0x00000000}},	//   _والث, --, --, --, 
   {{0x637c002e,0xd1f80f7c,0x7c24e646,0x321c0210}},	//   _gënk, ላዊት_, nuhr, ątym_, 
   {{0x765800a9,0xdeb81954,0x00000000,0x00000000}},	//   _trwy, ዳልን_, --, --, 
   {{0x7664e647,0xc0f0001f,0xe56c2fc3,0x637c0240}},	//   _دُشم, ቃዋሚ_, _ез_, _zënk, 
   {{0x3f980198,0x7648bc2e,0x00000000,0x00000000}},	//   _amsu_, mwey, --, --, 
   {{0x64a0e648,0x7648021a,0x91c401e0,0xd5840133}},	//   _наша, lwey, йәүл, _مێکه_, 
   {{0x45240003,0x3f9801c3,0x7648090e,0x00000000}},	//   _འཐོར_, _cmsu_, owey, --, 
   {{0x7648e649,0x00000000,0x00000000,0x00000000}},	// [13e20] nwey, --, --, --, 
   {{0x3f980036,0x7648009a,0x7c240112,0xdb080254}},	//   _emsu_, iwey, fuhr, algü, 
   {{0x98a40006,0x5fc001ad,0x76480067,0xe9d802dd}},	//   menė_, _वीकल, hwey, ңке_, 
   {{0xdcaccf33,0x637ce64a,0x764802ea,0xfc5807a5}},	//   رىن_, _rënk, kwey, шруъ_, 
   {{0x7648e64b,0x00000000,0x00000000,0x00000000}},	//   jwey, --, --, --, 
   {{0x76480050,0x7c240092,0x984c0166,0x3aec0248}},	//   dwey, buhr, _aşıt_, _pópó_, 
   {{0x6c840491,0x3078008f,0x3f9806ea,0x637c036e}},	//   _الأم, טאַנ, _ymsu_, _qënk, 
   {{0x7648058a,0x9c14011a,0x4778014b,0x981000ae}},	//   fwey, _לחלק_, рбию_, أبوا, 
   {{0x6a840323,0x7648e64c,0x637c0036,0xe4e402dd}},	//   _улаа, gwey, _wënk, йінн, 
   {{0x6b80467c,0x637c1bce,0x2b4400a3,0x598001ec}},	//   lkog, _tënk, leoc_, _елуб, 
   {{0x290ce64d,0x7aece64e,0x7648058a,0x9ac0031c}},	//   mafa_, žate, awey, _ċċit, 
   {{0x6b80e64f,0x290ce650,0xe29c2242,0x2b440dd4}},	//   nkog, lafa_, laði_, neoc_, 
   {{0x76488891,0x150403d4,0x7c24022e,0x853c0153}},	//   cwey, _শাৰী_, zuhr, lnėm, 
   {{0xe29c2242,0xdb1800e4,0x637c002e,0x23086ea9}},	//   naði_, _ekuè, _mëni, ختگي_, 
   {{0xe0e401b9,0x637c0240,0x6b800254,0x955002f2}},	//   _қўпо, _lëni, kkog, _رخوا, 
   {{0x290ce651,0x53a41614,0x00000000,0x00000000}},	//   hafa_, _најб, --, --, 
   {{0x41b495ad,0x290ce652,0xe29c09f3,0x6b800037}},	// [13e30] _ومبر, kafa_, kaði_, dkog, 
   {{0xae1c068f,0xdb180124,0xdc34008e,0x290ce653}},	//   यंजन_, _ikué, _cäğr, jafa_, 
   {{0xe29c08a7,0x290ce654,0x764800ca,0x0dc89648}},	//   daði_, dafa_, zwey, сути_, 
   {{0x3f98020b,0x637c02d3,0xe3a804c5,0x7648009a}},	//   _umsu_, _bëni, _গীতব, ywey, 
   {{0x76480a81,0xe29c008c,0xdf00010b,0x637c0200}},	//   xwey, faði_, _мүңй, _cëni, 
   {{0x637c02d3,0x6b800607,0x290ce655,0xe29c0ad9}},	//   _dëni, akog, gafa_, gaði_, 
   {{0x0fd83b7a,0xe94400e5,0x00000000,0x00000000}},	//   _خبیث_, زروی, --, --, 
   {{0xcb340801,0x76481418,0x00000000,0x00000000}},	//   _несъ, twey, --, --, 
   {{0x290ce656,0x7e6c014b,0xe29c032e,0xfa540066}},	//   bafa_, nxap, baði_, _برزگ, 
   {{0x290ce657,0x764801d9,0xae1c0406,0xdb080793}},	//   cafa_, rwey, यूटन_, sogä, 
   {{0xdb1800c7,0x7648e64b,0x637c036e,0x00000000}},	//   _akué, swey, _zëni, --, 
   {{0xc168008d,0x76b854e7,0xdb08072b,0x31e028e0}},	//   _בח_, _клер_, bogå, पद्ध, 
   {{0xc7c40139,0xf1b80051,0x00000000,0x00000000}},	//   _эсфи, _ươ_, --, --, 
   {{0xb0f800f2,0x78ac0205,0x00000000,0x00000000}},	//   شفرض_, şavu, --, --, 
   {{0xaf98e085,0xdb1807dd,0x853c0024,0x00000000}},	//   атах_, _ekué, knėj, --, 
   {{0x290ce658,0xb8140055,0xb0640254,0x00000000}},	//   zafa_, _aṭku, _afää, --, 
   {{0x290c5b49,0x853c00c0,0x03a800f1,0x00000000}},	// [13e40] yafa_, dnėj, _ددوو_, --, 
   {{0xdd8c00f7,0x637c02d3,0xc50c008f,0x853c0064}},	//   نوق_, _rëni, ָלאָ, enėj, 
   {{0xe29c08a7,0x290c01fa,0x637c0200,0x6b80e659}},	//   vaði_, vafa_, _sëni, tkog, 
   {{0xdb180124,0x290ce65a,0x00000000,0x00000000}},	//   _ykué, wafa_, --, --, 
   {{0x290c4d71,0xad24e65b,0x5f000953,0xe9240135}},	//   tafa_, _ورسو, _ізра, _རྐུབ_, 
   {{0x2d9c51bb,0x26c0014a,0x637c0240,0x80d0000d}},	//   _öte_, ükom_, _vëni, _धरमे, 
   {{0xe29c09cc,0xda080c2e,0x2d880477,0x58d0e65c}},	//   raði_, सीबत_, _ilbe_, мошт, 
   {{0x290ce65d,0xbe2c001f,0xe29c041e,0x645ce65e}},	//   safa_, _ድርጅታ, saði_, _špio, 
   {{0xe29c08a7,0x290c0418,0x853c0153,0xa9a4020f}},	//   paði_, pafa_, snėm, _диад, 
   {{0x61ec0175,0x00000000,0x00000000,0x00000000}},	//   vqcl, --, --, --, 
   {{0xdb180165,0x25b40014,0x00000000,0x00000000}},	//   _skué, ٝنکھ_, --, --, 
   {{0x78ac02fb,0x21ec0037,0x6e340153,0x7dd002d2}},	//   ťový, _püh_, ktyb, _kósý, 
   {{0x753c00dd,0x2d88014f,0x12e402dd,0x45f8007b}},	//   ősza, _olbe_, дірг, _افتح_, 
   {{0x637c0023,0x7d000356,0x7a4002d2,0x00000000}},	//   _nënv, _mârâ, _hátö, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2d880276,0x7e6ce65f,0x6e34037e,0xb06426bb}},	//   _albe_, txap, ftyb, _sfää, 
   {{0x6458e660,0xdb180124,0x5ab40327,0x2d880306}},	// [13e50] lvti, _ukué, _བཙེམ, _blbe_, 
   {{0x9c840592,0x6d582507,0x5cc400f3,0xe1fc429f}},	//   يشاه, _ótal, осез, mpó_, 
   {{0xe1fc0789,0x5274036b,0x00000000,0x00000000}},	//   lpó_, _فایز, --, --, 
   {{0x2d884794,0xca480451,0x00000000,0x00000000}},	//   _elbe_, ڪلهه_, --, --, 
   {{0x645ce661,0x6f000077,0xdb180254,0x64580254}},	//   _špil, ñoce, _ihuü, hvti, 
   {{0xfd7401c6,0x853c0153,0x246c06be,0x00000000}},	//   _элгэ, snėj, ləmu_, --, 
   {{0xdb680c56,0x98a4005f,0x5ba4e662,0x64580306}},	//   _крал_, menī_, _драз, jvti, 
   {{0xe9a41a59,0xe29c0436,0x00000000,0x00000000}},	//   يگەن_, laðu_, --, --, 
   {{0x7ae801b8,0xbac80014,0x8f9c008f,0xe72c0133}},	//   _iget, _اژان_, ייהי, اڵم_, 
   {{0xd838170a,0xdce40034,0x637c0694,0xe29c0d12}},	//   _вэд_, _poję, _mënu, naðu_, 
   {{0x7ae83207,0x06840137,0x00000000,0x00000000}},	//   _kget, згөн, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3b0c0194,0x7ae801f7,0xe29c0ad9,0x637c036e}},	//   _meeq_, _mget, kaðu_, _nënu, 
   {{0x321c0122,0xdb080162,0xe29c0162,0xc5f802f2}},	//   čty_, gogú, jaðu_, _بووڵ_, 
   {{0x0574e663,0x7ae8e664,0x98a400e2,0x61400276}},	//   _تاند, _oget, denī_, эера, 
   {{0x7ae8e665,0x09a83be5,0x7304e666,0x637c002e}},	//   _nget, _औद्य, _эпиз, _bënu, 
   {{0x71a43591,0x6e3401f5,0xe29c01a8,0x6aa807f7}},	// [13e60] _наиз, utyb, faðu_, _कशेर, 
   {{0x637c02d3,0x6e345172,0x7bd8000f,0xddc0084c}},	//   _dënu, rtyb, emwu, ебуи, 
   {{0x9be40ed9,0x6e34e667,0xaab815c3,0xdca0e668}},	//   _སྤྱོ, styb, ڭدار_, нафи, 
   {{0x3b0c511b,0x7d000276,0x9cb0114f,0x00000000}},	//   _ceeq_, _pârâ, رمنت, --, 
   {{0xdcac00aa,0x3b0c01d9,0x637c0de2,0x6d4801e4}},	//   نډې_, _deeq_, _gënu, ĵfab, 
   {{0x7ae8e669,0x2d88000f,0xdb08030a,0x00000000}},	//   _eget, _ulbe_, nngê, --, 
   {{0xfd6802e3,0x88482ab4,0xdb180332,0xc7b000e5}},	//   hepụ, تیاق_, _chuó, پڑا_, 
   {{0x7d00054e,0x0b440133,0x00000000,0x00000000}},	//   _târâ, _ترسێ, --, --, 
   {{0x637c1bce,0xea8800db,0xa92400fb,0x00000000}},	//   _mënt, _убал_, _ндал, --, 
   {{0x61e8e66a,0x637c01c7,0xed94001f,0xcfc40154}},	//   _égli, _lënt, _መከበር_, ্দিন, 
   {{0xa6e40220,0x25a800c0,0x00000000,0x00000000}},	//   _ежел, _čilė_, --, --, 
   {{0x637c044e,0xd494e66b,0x3b0c002e,0xc7980451}},	//   _nënt, яры_, _xeeq_, _گھڻا_, 
   {{0x6458074d,0x27e4003a,0xdeb80257,0xa6c801af}},	//   svti, _iion_, ዳውና_, _улда_, 
   {{0x26c4e66c,0x27e401ab,0x00000000,0x00000000}},	//   _iyoo_, _hion_, --, --, 
   {{0x27e404ac,0x637c02d3,0xe29c06ea,0x00000000}},	//   _kion_, _bënt, vaðu_, --, 
   {{0x4fc4e66d,0xdb089632,0xdb040162,0x8cc0012d}},	//   есуа, llgö, _áløg, _वड़ो, 
   {{0xf4080156,0x27e414d0,0xe3bc0428,0xe29c0321}},	// [13e70] _གཆོད_, _mion_, moñ_, taðu_, 
   {{0x27e49427,0xe3bc1bce,0x7ae8015d,0x00000000}},	//   _lion_, loñ_, _sget, --, 
   {{0x645c0989,0xe29c041e,0x00000000,0x00000000}},	//   _špij, raðu_, --, --, 
   {{0x27e401c6,0xe3bc030a,0xe29c68f1,0x00000000}},	//   _nion_, noñ_, saðu_, --, 
   {{0xdde862cd,0x26c4e66e,0x637c01c7,0xe29c0bcd}},	//   _درجه_, _nyoo_, _hëns, paðu_, 
   {{0xd90ce66f,0x637c0221,0xbd4400c6,0x9928023a}},	//   ایا_, _zënt, _تنسي, сюда_, 
   {{0x26c4e670,0x27e4dedc,0x7ae805d5,0x00000000}},	//   _ayoo_, _bion_, _tget, --, 
   {{0x637ce671,0x7ae8e672,0xe3bc0428,0x27e4e673}},	//   _mëns, _uget, joñ_, _cion_, 
   {{0xa3c0230e,0x637c0221,0x1ad803d4,0x7d0436f4}},	//   ्तन_, _lëns, _ড্ৰা, obhs, 
   {{0x391406d0,0x26c40810,0x637c0ea0,0x4a540212}},	//   _آواز, _dyoo_, _oëns, _якус, 
   {{0x27e4e674,0x637c02d3,0x753c01ed,0x77780067}},	//   _fion_, _nëns, őszo, _towx, 
   {{0x27e41570,0xf2a4399f,0x00000000,0x00000000}},	//   _gion_, димп, --, --, 
   {{0xe294e675,0x7c2401c7,0xe60c01c6,0x00000000}},	//   дая_, hrhr, _шд_, --, 
   {{0x27e405f5,0x00000000,0x00000000,0x00000000}},	//   _zion_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x637c0a40,0xe29c032e,0x00000000,0x00000000}},	//   _dëns, gaðs_, --, --, 
   {{0x26c40190,0x1b1000fe,0x6d5808a5,0x00000000}},	// [13e80] _xyoo_, হলাই_, _ótak, --, 
   {{0x637c04e6,0x2910013f,0x00000000,0x00000000}},	//   _fëns, ɔyaw_, --, --, 
   {{0x637c01c7,0x2cec00ab,0x2fc0002f,0x320000d7}},	//   _gëns, _जलील_, _tkkg_, lpky_, 
   {{0x7d0400c6,0x7e68e676,0xdb18e677,0xaa880116}},	//   abhs, _šepe, _bhuñ, ينام_, 
   {{0xdb180309,0x25bcbb80,0x637c04e6,0xda740395}},	//   _chuñ, yotl_, _zëns, дящ_, 
   {{0x7c24010a,0xd9940214,0x00000000,0x00000000}},	//   brhr, وننت_, --, --, 
   {{0x27e4e678,0xa3c09ad9,0xab34033a,0x7f7401e2}},	//   _pion_, ्तम_, _охај, _غږېږ, 
   {{0x97a043a7,0xe3bc0de2,0x00000000,0x00000000}},	//   крыл, xoñ_, --, --, 
   {{0x77900424,0x7f480784,0x27e4e679,0x00000000}},	//   دینا, _ñeqe, _vion_, --, 
   {{0x26c401c8,0x44980212,0x786400d1,0x637c0200}},	//   _vyoo_, звою_, بدۇك, _nënr, 
   {{0x27e4e67a,0x291c5a6d,0x68f803ac,0xe7380138}},	//   _tion_, _idta_, _iftd, _меж_, 
   {{0x69c8b446,0xdb1800c7,0xa7141291,0x00000000}},	//   llfe, _ikuã, _آباؤ, --, 
   {{0xdb0801bf,0xdb1c00e4,0x95501291,0x00000000}},	//   rogø, ävév, رخیا, --, 
   {{0x9580b4f8,0x637c0036,0x00000000,0x00000000}},	//   _илче, _pëns, --, --, 
   {{0x65680597,0x55b8011a,0x69c801e7,0x154000d8}},	//   _infh, _ומגו, ilfe, _рејм, 
   {{0x442ce67b,0x69c80e78,0xdb08002e,0x9378007b}},	//   mud_, hlfe, rngë, _يصير_, 
   {{0x442ce67c,0x637c0221,0x6f000077,0x00000000}},	// [13e90] lud_, _wëns, ñoca, --, 
   {{0x7d0401ab,0xfd7401c6,0xc0c401ee,0x00000000}},	//   ubhs, элзэ, _зәби, --, 
   {{0x442ce67d,0x7d040332,0x2c0801f9,0x00000000}},	//   nud_, rbhs, हीलं_, --, 
   {{0x61f80276,0x68f80857,0x291c01d3,0x69c80e78}},	//   ţulu, _aftd, _adta_, elfe, 
   {{0xdb180113,0x656801ab,0x7f4ce67e,0x80b4000d}},	//   _qhuñ, _onfh, meaq, _उखडे, 
   {{0x442ce67f,0xdb08e680,0x7f4c003a,0xa3c028fe}},	//   kud_, ingé, leaq, ्तड_, 
   {{0x442c07e2,0x27fc0204,0x00000000,0x00000000}},	//   jud_, _cttn_, --, --, 
   {{0x442ce681,0x656800a3,0xdb1802d1,0x69c825a3}},	//   dud_, _anfh, _thuñ, alfe, 
   {{0x442c1570,0x637c036e,0x00000000,0x00000000}},	//   eud_, _nënq, --, --, 
   {{0x63ac01e4,0x20f81b76,0x48c40022,0x00000000}},	//   encn, ्रोश_, хәӡа, --, 
   {{0x442ce682,0x98a40024,0xa6e00162,0xd800010a}},	//   gud_, menį_, æðri, _шăн_, 
   {{0xf47002d3,0x7f4c00d8,0x765c007c,0x00000000}},	//   _ብካልእ_, jeaq, åsys, --, 
   {{0x95b01945,0x3668030d,0x32000118,0x589401af}},	//   _иркә, _хало_, upky_, _эшҡу, 
   {{0x6654030d,0x00000000,0x00000000,0x00000000}},	//   _чашă, --, --, --, 
   {{0x1be83eaf,0xa064e683,0x442ce684,0xe0d42d1f}},	//   _जंगल_, нара_, cud_, евр_, 
   {{0x3f8815a5,0x63ac0200,0x61f80115,0x00000000}},	//   gkau_, cncn, ŭula, --, 
   {{0xade8036b,0x88bc0118,0x69c80042,0xa3840037}},	// [13ea0] سفام_, _zděd, ylfe, srõõ, 
   {{0x3f8803a0,0x00000000,0x00000000,0x00000000}},	//   akau_, --, --, --, 
   {{0x98a40006,0x00000000,0x00000000,0x00000000}},	//   denį_, --, --, --, 
   {{0x3f88203d,0xae1c0073,0xfe7000f1,0x853c0064}},	//   ckau_, _पिऊन_, ددې_, lnėt, 
   {{0x442c07ab,0xdb20007b,0x6f140309,0xfa8000d1}},	//   zud_, órál, mayc, ақтм, 
   {{0x2828069c,0x442ce685,0x6f14e686,0x4cdc03d4}},	//   _ደሞክራ, yud_, layc, মুগু, 
   {{0x442ce687,0xa3780798,0x9d40010b,0x69c8007c}},	//   xud_, lmõe, _щерд, rlfe, 
   {{0x442ce688,0x637c0240,0x6f14e689,0x260457bf}},	//   vud_, _nënp, nayc, нчог, 
   {{0x442ce68a,0x98a40153,0x853c0153,0x00000000}},	//   wud_, benį_, knėt, --, 
   {{0x442c3174,0xdb180022,0x28940063,0x2900371e}},	//   tud_, _ikuá, _пјес, _şkaf_, 
   {{0x80a400fe,0x6f140986,0x4aa46ab8,0x442c0067}},	//   _খুন্, kayc, _खेतव, uud_, 
   {{0x9f94e68b,0xa6b000cc,0xe738003b,0x00000000}},	//   rçë_, _চৰণট, _хед_, --, 
   {{0x442ce68c,0xdb980375,0x63b000e2,0xd244084c}},	//   sud_, לסטר, _ģenē, лэри, 
   {{0x442ce68d,0x7aec005a,0x00000000,0x00000000}},	//   pud_, ñatz, --, --, 
   {{0xd48ce68e,0x104802bf,0xae1c0bae,0x442c025c}},	//   _ср_, няти_, _पिउन_, qud_, 
   {{0x3f88e68f,0xdb180022,0x69c402d2,0x6e20025c}},	//   ukau_, _okuá, _íkef, ġobn, 
   {{0x3f88391d,0xa18400c7,0x7f4ce690,0x9f940129}},	// [13eb0] rkau_, _зынл, reaq, nçé_, 
   {{0x3f88e691,0x20000135,0xd4c0004e,0x00000000}},	//   skau_, ppji_, _шөөк, --, 
   {{0x6f149f20,0x7c9426c0,0xe0240124,0x1ad0000d}},	//   bayc, خلاص, _џьоп, _तरहथ, 
   {{0xa3c0448b,0x0c040014,0x00000000,0x00000000}},	//   ्ति_, اونُ, --, --, 
   {{0x5edc015b,0xdc1005d1,0x8b88107b,0x00000000}},	//   _ফ্রে, rşıt, رەكە_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa3c06d58,0x55c03e25,0x0cd40138,0x00000000}},	//   ्ता_, ғанғ, _борю, --, 
   {{0x9ff003f4,0xf770a554,0x00000000,0x00000000}},	//   _জবাব_, شاب_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb46400d6,0xa56003cc,0xca4815f2,0x00000000}},	//   вкол, لگىن, _سلمه_, --, 
   {{0x6f1403f0,0x13a80066,0x00000000,0x00000000}},	//   yayc, فندی_, --, --, 
   {{0xdb1800e4,0xd90c00e5,0xdb04013d,0xdb080210}},	//   _ykuá, _ئیں_, _ömäs, mogó, 
   {{0x26c001b8,0xdb08033f,0x00000000,0x00000000}},	//   ükot_, logó, --, --, 
   {{0x35a40323,0x6f147cc7,0x00000000,0x00000000}},	//   _шалг, wayc, --, --, 
   {{0x5edc045e,0xed50034c,0x0574021f,0x6f14e692}},	//   _ফ্লে, یپر_, _حاند, tayc, 
   {{0x7e68e693,0x00000000,0x00000000,0x00000000}},	//   _šepa, --, --, --, 
   {{0xee38e694,0xed5807d6,0x1e80e695,0x7fd40220}},	// [13ec0] ьна_, моа_, алтм, уірі, 
   {{0x6e2000f3,0x6f140784,0xa37800d8,0xc8f00037}},	//   šobo, sayc, rmõe, _चलेम_, 
   {{0x6f149b55,0x7db400d4,0x00000000,0x00000000}},	//   payc, устц, --, --, 
   {{0xbc24185e,0x6a840b3e,0x6f141181,0x00000000}},	//   ارلى, клеа, qayc, --, 
   {{0xeab052c8,0x7f480784,0x2a34084c,0x00000000}},	//   جعا_, _ñeqa, тэер, --, 
   {{0xdb0800e5,0x00000000,0x00000000,0x00000000}},	//   fogó, --, --, --, 
   {{0x57bc0131,0x9ba40014,0x00000000,0x00000000}},	//   ﺭﻟﯩﺮ, رگہِ_, --, --, 
   {{0x44201a4c,0xa2d00073,0x00000000,0x00000000}},	//   _ĉi_, _ठरल्, --, --, 
   {{0x6d5c0c8c,0xa50400ee,0x1ae00395,0xa3c000cd}},	//   odpa, кянл, _вотм, ्तस_, 
   {{0x6d5c2bab,0xdb0801d3,0x00000000,0x00000000}},	//   ndpa, bogó, --, --, 
   {{0x6d5c03ac,0x69d801f4,0x00000000,0x00000000}},	//   idpa, _ihte, --, --, 
   {{0x7aec0227,0x00000000,0x00000000,0x00000000}},	//   ñatx, --, --, --, 
   {{0x6720e696,0x7cf808a5,0x66740b73,0x00000000}},	//   _idoj, _júró, _جدار, --, 
   {{0x6600e697,0x6d5c01f5,0x61f8010f,0x00000000}},	//   _itok, jdpa, ŭulo, --, 
   {{0xdb18001e,0x6d5c02d2,0x00000000,0x00000000}},	//   _khuô, ddpa, --, --, 
   {{0x64481682,0x660073cb,0x93140014,0xdb18010e}},	//   _ipfi, _ktok, _پوٝش, _ikuç, 
   {{0x6d5c0d27,0xeeb829db,0x4ce002f5,0x93b80375}},	// [13ed0] fdpa, ектә_, _প্লু, _שלחו_, 
   {{0x5c046345,0xa3c0e698,0x660001f7,0x6d5c037e}},	//   вяда, ्तव_, _mtok, gdpa, 
   {{0x0dc82f00,0xd138035b,0xbc6400c7,0x00000000}},	//   тути_, _рхы_, ыхақ, --, 
   {{0x66004a13,0x6448e699,0x67200588,0x69d8e69a}},	//   _otok, _mpfi, _ndoj, _ahte, 
   {{0x660002b9,0x69d80b4b,0xa3a828f5,0x38ac0022}},	//   _ntok, _bhte, _गगन_, kórô_, 
   {{0x69d8e69b,0x6448e69c,0x7cf80248,0x38580108}},	//   _chte, _opfi, _dúró, ерию_, 
   {{0x6600e69d,0x7f5c0bf1,0xbc940063,0x4c840500}},	//   _atok, _kasq, _савј, _клёв, 
   {{0x7d140369,0xdb18001e,0x69d800af,0x66000175}},	//   _hezs, _chuô, _ehte, _btok, 
   {{0x7f5ce69e,0x6448e69f,0xcf940375,0x61f80077}},	//   _masq, _apfi, יטק_, íull, 
   {{0x394401af,0xdb0815b0,0x69d8547d,0x65780200}},	//   _ubls_, ingí, _पीपी, gjth, 
   {{0x6600e17e,0xc984e6a0,0x7d14e6a1,0x98c40276}},	//   _etok, _тути, _mezs, _рсал, 
   {{0x7980e6a2,0x7f5ce6a3,0xa820104c,0x7cf801e1}},	//   _holw, _nasq, _اکون, _yúró, 
   {{0x69d8426d,0x7980e6a4,0x60940020,0x645c0306}},	//   _yhte, _kolw, ዘጋጀት_, _špit, 
   {{0x41b42eca,0xe04000d1,0x00000000,0x00000000}},	//   асст, әнти, --, --, 
   {{0x7bc80098,0x7980e6a5,0x7f5ce6a6,0xd5cc012d}},	//   _okeu, _molw, _basq, _सीएज, 
   {{0x0fc40729,0x7f5c20ef,0x7980e6a7,0xd138033f}},	//   ্দ্ধ, _casq, _lolw, żą_, 
   {{0x7d14e6a8,0x798015df,0x261425c9,0x00000000}},	// [13ee0] _bezs, _oolw, पीपी_, --, 
   {{0x7980016e,0x7bc8e6a9,0x7f5c0381,0x6d5c01f5}},	//   _nolw, _akeu, _easq, udpa, 
   {{0x6d5c127b,0x7f5c78aa,0xdb040306,0x7d1400e5}},	//   rdpa, _fasq, šlýc, _dezs, 
   {{0x69d8067d,0x2f5400d6,0x207800c8,0x7980035a}},	//   _shte, _стос, _נאכא, _aolw, 
   {{0x7980e6aa,0x00000000,0x00000000,0x00000000}},	//   _bolw, --, --, --, 
   {{0xada4b9d7,0x7980d522,0x6da4e6ab,0x7d1456f8}},	//   _сагл, _colw, _сига, _gezs, 
   {{0x79800514,0xe7e8005b,0x889401c6,0xab2801af}},	//   _dolw, нфик_, рийх, _пова_, 
   {{0xdca000c7,0x7cf801d3,0x00000000,0x00000000}},	//   _уаси, _túró, --, --, 
   {{0x7980e6ac,0x853c0006,0xb81004c5,0x85b82083}},	//   _folw, siėm, সংগত_, клис_, 
   {{0x79804db1,0x23ac01f4,0xdaa4009b,0x00000000}},	//   _golw, köjä_, _свуд_, --, 
   {{0xe5780598,0xdb18004d,0x7ea8022e,0x00000000}},	//   _үзе_, _thuô, _tоpg, --, 
   {{0xd494e6ad,0x7980e6ae,0x4ab80073,0x00000000}},	//   урь_, _zolw, _अशाव, --, 
   {{0x6600e6af,0x79806e0e,0x7f5ce6b0,0xe4c40116}},	//   _utok, _yolw, _rasq, _өйди, 
   {{0xc10431ed,0x7f5c045a,0x00000000,0x00000000}},	//   شوري, _sasq, --, --, 
   {{0x7f5ce6b1,0xdb180598,0x439402d5,0x7d1401ed}},	//   _pasq, _ukuç, _вайс, _rezs, 
   {{0x7d140007,0x7f5c1fc6,0x00000000,0x00000000}},	//   _sezs, _qasq, --, --, 
   {{0x7f5ce6b2,0x442ce6b3,0x4aa44ca3,0x7d1401d3}},	// [13ef0] _vasq, lrd_, _खेलव, _pezs, 
   {{0x442c0917,0x7bc803bd,0x7f5c92ba,0x00000000}},	//   ord_, _skeu, _wasq, --, 
   {{0x7f5c00f7,0x7980e6b4,0x70f80375,0x271805ac}},	//   _tasq, _rolw, _בהתח, _ধানো_, 
   {{0x7980e6b5,0x442ce6b6,0xca60022e,0x8fa40120}},	//   _solw, ird_, _demо, _гаџе, 
   {{0x7980e6b7,0xfe3400c8,0x5c740184,0x442c003e}},	//   _polw, _דאָך_, _әҙер_, hrd_, 
   {{0xfcc4010b,0xa80000fd,0x644c0003,0x00000000}},	//   _кәем, _ğıra, ħbij, --, 
   {{0x79800e29,0xa8000205,0x8aa40166,0x00000000}},	//   _volw, _şıra, ирәд, --, 
   {{0x7980e6b8,0x6e28025a,0x762407d6,0x6d580162}},	//   _wolw, _ömbë, амиз, _ótar, 
   {{0xe614e6b9,0x442ce6ba,0x7980e6bb,0x00000000}},	//   ады_, erd_, _tolw, --, 
   {{0xd7f8e6bc,0x442c031c,0x23ac0108,0x8aa4009d}},	//   _зуд_, frd_, yöjä_, _урсд, 
   {{0xa3c00a28,0x645ce6bd,0x49e40014,0x442c0175}},	//   ्तं_, _špir, _آلٕ, grd_, 
   {{0x1704036b,0x047801b9,0xe1f000ec,0x00000000}},	//   _صفتی_, چلیک_, ڪسٽ_, --, 
   {{0xf1a804d3,0x066404d3,0x0478006c,0x69d80d0a}},	//   ناسه_, _هاوپ, نلیک_, _पीडी, 
   {{0x48dc038e,0x23ac02f6,0x33f400db,0xd5b80139}},	//   गेको_, töjä_, _кчис, _ясе_, 
   {{0x0cb003f4,0x64a03e27,0x442c00d8,0x00000000}},	//   _কর্ত, _маша, crd_, --, 
   {{0xa3c00a28,0x28d80034,0xaf040354,0xb4c00c4c}},	//   ्तः_, येटि, рпал, ंथी_, 
   {{0x0ee002ab,0x92e40183,0x23ac01f4,0xacf400d8}},	// [13f00] पेंड, _প্ৰ_, söjä_, ачеј, 
   {{0x6da41f5a,0x23ac0108,0x00000000,0x00000000}},	//   шиза, pöjä_, --, --, 
   {{0x6c340271,0x00000000,0x00000000,0x00000000}},	//   شفشا, --, --, --, 
   {{0xab285fb2,0xdb0806ed,0x6614010b,0x00000000}},	//   тода_, ligê, _çykg, --, 
   {{0x3b080309,0x00000000,0x00000000,0x00000000}},	//   ñaqa_, --, --, --, 
   {{0x442ce6be,0x1d041f5a,0x2fd00042,0xe82400d8}},	//   yrd_, _вери_, llyg_, афио, 
   {{0xceb800d1,0x2d9800a3,0x761400b8,0x00000000}},	//   _рәң_, mhpe_, _āsaṃ, --, 
   {{0x6da402a9,0x6f00867c,0x3a280113,0xd7f4e6bf}},	//   _сиҳа, ñoch, šapa_, шуш_, 
   {{0xd6d4224f,0xc3c40032,0xf1c4085c,0x8ad400ec}},	//   ить_, ҙөкл, लकान, _اڪائ, 
   {{0x80f4228d,0x442c1617,0x2d980175,0x2fd00042}},	//   _आलेख_, trd_, nhpe_, hlyg_, 
   {{0x442c0cf9,0x61801772,0x88bc00bc,0x3c0000c0}},	//   urd_, _ዓለማዊ_, _zděn, _tėve_, 
   {{0x2b440165,0x442c01e4,0xd7540137,0xdb080332}},	//   nfoc_, rrd_, _ۅلۅت_, ongá, 
   {{0x637c01c7,0x66e4030d,0xc60000cc,0x00000000}},	//   _kënz, _тода, _এটকা_, --, 
   {{0x6af40003,0x442ce6c0,0xdb0408a5,0x00000000}},	//   _བུའོ_, prd_, _álög, --, 
   {{0x1fa4e6c1,0x637c01c7,0x50640408,0x2fd00267}},	//   араг, _mënz, отта, flyg_, 
   {{0xcf9830ba,0xdb08014a,0x0cb00183,0x00000000}},	//   ају_, logö, _কৰ্ত, --, 
   {{0x66140209,0xbed801c0,0x3cb400fb,0x34e801af}},	// [13f10] _çykd, удах_, әйер, _игәү_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2fd003cb,0xccf80063,0x00000000,0x00000000}},	//   blyg_, рћу_, --, --, 
   {{0x3a74e6c2,0x644c0327,0x00000000,0x00000000}},	//   йлер, ħbih, --, --, 
   {{0x637c0036,0x39980100,0xdcf81410,0xc2e800eb}},	//   _bënz, _lèse_, _لرزش_, কুরি_, 
   {{0x49c8e6c3,0x00000000,0x00000000,0x00000000}},	//   алін_, --, --, --, 
   {{0x7c940491,0x637c0036,0xdb082618,0xb78800fd}},	//   _الأص, _dënz, dogö, ләде_, 
   {{0x9f940137,0x4ba800cf,0x00000000,0x00000000}},	//   nçà_, _көчү_, --, --, 
   {{0x0a5801f0,0x00000000,0x00000000,0x00000000}},	//   _катъ_, --, --, --, 
   {{0x18b000d1,0x5bb400bc,0x98c401af,0x00000000}},	//   _қәһр, _अदुव, _ксел, --, 
   {{0xd7f8016c,0x845800a7,0x70d4000d,0x00000000}},	//   _руз_, арят_, _धरेल, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdef002d3,0x80cc01ad,0x0cd41b76,0xf1d000cf}},	//   ልካን_, _दुबे, _थर्म, зөнө, 
   {{0x637c069c,0x2eb401e0,0x3d20012d,0x66800101}},	//   _mëny, ҡсас, मणों_, _ریپل, 
   {{0x21a005bc,0x00000000,0x00000000,0x00000000}},	//   чирм, --, --, --, 
   {{0xe4d05706,0x43740354,0x00000000,0x00000000}},	//   _عقيد, _дуьт, --, --, 
   {{0xdd8ce6c4,0xdee036ca,0xdb080129,0x3244007b}},	// [13f20] کول_, зоти, migè, _انخف, 
   {{0x6278008f,0xdb0800cf,0x88bc013a,0xdb4c0014}},	//   _ענינ, ligè, _bděl, ہَم_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf3f803f4,0x637c025a,0x00000000,0x00000000}},	//   _আবার_, _sënz, --, --, 
   {{0x5ba4010b,0x00000000,0x00000000,0x00000000}},	//   щкцм_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x42780020,0x290c01c3,0xdca00354,0x00000000}},	//   _ቢያንስ_, rbfa_, _еари, --, 
   {{0xc6f85882,0xfaf80421,0x637c01c7,0x00000000}},	//   шних_, _taūa_, _wënz, --, 
   {{0xdb08e6c5,0x9f9400d8,0xfa3401ec,0xe9d80153}},	//   digè, nçá_, _ۇرەد, _бка_, 
   {{0x3998e6c6,0x704c0092,0x7e680419,0x00000000}},	//   _pèse_, ዕነታቸ, _šepk, --, 
   {{0x69c8e6c7,0x6844010b,0xf8ac00f1,0x00000000}},	//   mofe, _ынжа, _ټکو_, --, 
   {{0x69c8df79,0x39980100,0x1874011a,0x787001c8}},	//   lofe, _vèse_, _לעבר_, _آڏوا, 
   {{0x31c41c5c,0x6584008e,0x00000000,0x00000000}},	//   ﺮﻟﯩﻜ, _гыйз, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc0e00023,0x00000000,0x00000000,0x00000000}},	//   _ጓይላ_, --, --, --, 
   {{0x69c8e6c8,0x69d802a0,0x00000000,0x00000000}},	//   hofe, _पीसी, --, --, 
   {{0x63ac9a64,0x88bc0316,0xcfd800fe,0x9f9400db}},	// [13f30] micn, _sděl, _দংশন, rçà_, 
   {{0x63ac1326,0x628ce6c9,0xa3c002ab,0x229000d1}},	//   licn, myco, ्तक_, _миқя, 
   {{0xdb08e6ca,0x3af4005b,0xd1b80131,0x02fc000d}},	//   ligé, оялс, _ھاۋا_, _एलाह_, 
   {{0x63ac1225,0x24880023,0x00000000,0x00000000}},	//   nicn, _ሕጉሳት_, --, --, 
   {{0x0e08e1d8,0xc91402a0,0x69d8000d,0x00000000}},	//   _гэси_, डरूम_, _पीही, --, 
   {{0x69c81ebd,0x63ac0010,0x9f480332,0xbd840133}},	//   gofe, hicn, _micí_, _گۆڕن_, 
   {{0x88bc0316,0x2614858c,0x00000000,0x00000000}},	//   _uděl, पीसी_, --, --, 
   {{0xc864e6cb,0xe1fc011f,0x63ac0427,0xab6000d1}},	//   ятчи, kqó_, jicn, _يۇلى, 
   {{0x69c8e6cc,0x00000000,0x00000000,0x00000000}},	//   bofe, --, --, --, 
   {{0xdb08e6cd,0x628c4a1d,0x8aa401c0,0x2ea8010f}},	//   digé, dyco, _эрсд, ישפּ, 
   {{0xb858e6ce,0x9f48180f,0x49046d69,0x63ace6cf}},	//   _خلاص_, _aicí_, _رونق, ficn, 
   {{0x3ce014cf,0x9f480118,0xe1fc0162,0xa378000d}},	//   _करने_, _bicí_, rvón_, lmõj, 
   {{0x9f4800d2,0xdb086320,0x5fe00131,0xb920002b}},	//   _cicí_, rigè, _ﺋﺎﭘﺘ, _śrṛ_, 
   {{0x3f98008e,0xdb0800f2,0x850400e5,0x00000000}},	//   _alsu_, sigè, _ٹوٹن, --, 
   {{0x63ac08ad,0x74140137,0xfbc81d27,0xe1fc0548}},	//   bicn, _بوعا, िकाम, aqó_, 
   {{0x69c8e6d0,0x628c00b5,0xdb080ba1,0x00000000}},	//   zofe, byco, bigé, --, 
   {{0x3f980280,0x9f500429,0x69c80117,0x628c003e}},	// [13f40] _dlsu_, _buxâ_, yofe, cyco, 
   {{0xdcac69f9,0x3f980a87,0x307401f4,0x00000000}},	//   چىك_, _elsu_, _думс, --, 
   {{0xdcac0725,0x69c801e4,0xdca00395,0xe2c80133}},	//   نىك_, vofe, мафи, _مایۆ_, 
   {{0x69c8014b,0x9c1400d1,0xae0400db,0x98a40037}},	//   wofe, ючуә, _ووجى, _केइए, 
   {{0xaab8de04,0x69c8e6d1,0x2aa0022e,0xe9e40556}},	//   جدار_, tofe, _kаbi_, оцко, 
   {{0x63ac16a3,0x2918e6d2,0x00000000,0x00000000}},	//   zicn, úpa_, --, --, 
   {{0x69c8e6d3,0x6d4c0003,0xd7f400fb,0x628c0210}},	//   rofe, _ibba, оуы_, zyco, 
   {{0x7e6801a6,0x63ac02d0,0x00000000,0x00000000}},	//   _šepi, xicn, --, --, 
   {{0x63ac3421,0x00000000,0x00000000,0x00000000}},	//   vicn, --, --, --, 
   {{0x6b80b737,0x9f48004e,0xdb080036,0x9f50013d}},	//   ljog, _ricí_, vigé, _ruxí_, 
   {{0x63ac05a1,0x6aa0002f,0x628c012d,0x6d4c0051}},	//   ticn, lzof, wyco, _mbba, 
   {{0x6b80e6d4,0xd4942f6a,0x64580142,0xa6c800d8}},	//   njog, юры_, rwti, _клеа_, 
   {{0x7f480113,0x6aa0004c,0x6d4ce6d5,0xf7e80150}},	//   _ñeqi, nzof, _obba, _ارلى_, 
   {{0x628ce6d6,0x63ac08ad,0xdb08e6d7,0x04e8015b}},	//   ryco, sicn, rigé, _গভীর_, 
   {{0xdb080438,0x628ce6d8,0x3d94035b,0x00000000}},	//   sigé, syco, ҿиар, --, 
   {{0x6d4ce6d9,0x628c030d,0x6b8004ba,0x3ce000c5}},	//   _abba, pyco, jjog, _करबे_, 
   {{0xdb0811ad,0x6b80e6da,0x98bc00de,0x3d940108}},	// [13f50] nngå, djog, _ērču_, пиар, 
   {{0x69d80034,0x6aa00810,0xc7b80051,0xdb08007c}},	//   _पीली, dzof, _bvđk_, ingå, 
   {{0x7f58011c,0x00000000,0x00000000,0x00000000}},	//   _ланс_, --, --, --, 
   {{0x6d4c2f99,0x00000000,0x00000000,0x00000000}},	//   _ebba, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x89a802bf,0xdd1c02fb,0x00000000,0x00000000}},	//   оків_, líži, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3998020c,0x7d04e6db,0x7c240e89,0xdd1c02f0}},	//   _dèsa_, lchs, mshr, níži, 
   {{0xdac40131,0x6d48004e,0x4cb000cc,0x00000000}},	//   _بېشى_, òfag, _জুপু, --, 
   {{0x38c4025a,0x7d04e6dc,0x3998007f,0x754464cd}},	//   gêrë_, nchs, _fèsa_, чноз, 
   {{0x7c2403a2,0x7d049cfd,0xc8640353,0x00000000}},	//   nshr, ichs, _отци, --, 
   {{0x9f940598,0x7398b6c2,0x00000000,0x00000000}},	//   nçä_, стос_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x661409a5,0x7c24e6dd,0x80cc0073,0x00000000}},	//   _çyka, kshr, _दुहे, --, 
   {{0x6aa00dab,0x251806a9,0xafe40139,0x9f94008e}},	//   zzof, _הוצא, зовл, kçä_, 
   {{0xfaf802b1,0x7d04e6de,0xb2244961,0x6fb4007b}},	//   _ngū_, echs, _емил, أمرا, 
   {{0x59c81025,0x6d4c0332,0xdfcce6df,0xfc340023}},	// [13f60] िवार, _pbba, ايق_, _ብቐጻል, 
   {{0x75206ccb,0x7c24e6e0,0x00000000,0x00000000}},	//   nalz, fshr, --, --, 
   {{0x3ce00574,0xa3c00574,0xc104004b,0xf0e80131}},	//   _करणे_, ्तच_, _توپي, _دىدى_, 
   {{0x94f8003d,0x33200054,0x7d04000f,0x00000000}},	//   _ནུའི_, nakx_, achs, --, 
   {{0x6d4c0998,0x5b20e6e1,0x7c24e6e2,0xa9682310}},	//   _tbba, رفول, ashr, йида_, 
   {{0x6b80e6e3,0xb6041fe6,0x6d4c03c4,0x7c4801bf}},	//   sjog, _mešč, _ubba, øpræ, 
   {{0x2d88e6e4,0xec140150,0x3078008f,0x7c240332}},	//   _iobe_, _ءورد, מאַנ, cshr, 
   {{0x3ce014cf,0xaa4458f0,0x2d88e6e5,0x9cd4011a}},	//   _करते_, _небл, _hobe_, _זולה_, 
   {{0x7520a11b,0xc94402dd,0xb6040064,0x3eac032e}},	//   falz, _одақ, _nešč, _þett_, 
   {{0x2d88e6e6,0x5a60e6e7,0x7520e6e8,0x795003e6}},	//   _jobe_, _якуб, galz, _لێها, 
   {{0x2d8800fb,0x291c00e4,0x83181b45,0xdb0401ef}},	//   _mobe_, _ieta_, يقدر_, _šlég, 
   {{0x291c07dd,0x03bc04c5,0x57f80375,0x2d880f85}},	//   _heta_, ৃষ্ণ, _הלאו, _lobe_, 
   {{0x291ce6e9,0x7520e6ea,0x4cb02b1b,0x2d880332}},	//   _keta_, balz, _জুমু, _oobe_, 
   {{0x2d88bbab,0x291c044e,0x7520e6eb,0xb6040010}},	//   _nobe_, _jeta_, calz, _dešč, 
   {{0x291ce6ec,0x94d00153,0x00000000,0x00000000}},	//   _meta_, _пошц, --, --, 
   {{0x9f50011f,0xbfd802bf,0x94b8011a,0x00000000}},	//   _buxá_, ідає_, _למות, --, 
   {{0x2d88e6ed,0x291c0086,0xdd1c00d7,0x3df400d8}},	// [13f70] _bobe_, _oeta_, ríži, дзас, 
   {{0x7d042155,0xa3780254,0x7c2401e7,0x00000000}},	//   uchs, dmõi, tshr, --, 
   {{0x7d04e6ee,0x2d88e6ef,0x61fc0477,0x7c580131}},	//   rchs, _dobe_, _huql, تلار_, 
   {{0x291c0280,0x7d04e6f0,0xdcf400fd,0x7c246a41}},	//   _aeta_, schs, rixı, rshr, 
   {{0x6e2005ce,0x291ce6f1,0x3c000024,0xed4c0050}},	//   šobr, _beta_, _tėvo_, _چھم_, 
   {{0x2d88e6f2,0x7e6ce6f3,0x7f4ce6f4,0x61f40327}},	//   _gobe_, mvap, lfaq, _jixl, 
   {{0x291ce6f5,0xb9044244,0x7e6ce6f6,0x61fc0784}},	//   _deta_, _नर_, lvap, _luql, 
   {{0x291c01e1,0x2d88e6f7,0x7f4c0548,0x61f4058a}},	//   _eeta_, _zobe_, nfaq, _lixl, 
   {{0x291c7318,0x2d880c09,0x752002c1,0x61fc014f}},	//   _feta_, _yobe_, talz, _nuql, 
   {{0x291ce6f8,0x1dbc043e,0x7e6c004c,0x7bd81196}},	//   _geta_, ्वित, ivap, llwu, 
   {{0xdb08019f,0x7e6c980d,0xf8e01d8a,0x75200083}},	//   migâ, hvap, _फरिय, ralz, 
   {{0x7e6c0232,0x61fc014f,0xb6045946,0x75200b8b}},	//   kvap, _buql, _pešč, salz, 
   {{0x1dbc0a28,0x291ce6f9,0x61fc0327,0x61f40076}},	//   ्वात, _yeta_, _cuql, _bixl, 
   {{0x61f40369,0x61fcccb5,0xb60409a8,0x77680267}},	//   _cixl, _duql, _vešč, ldex, 
   {{0x7f4c036b,0x2d88e6fa,0x76481368,0x00000000}},	//   ffaq, _robe_, ltey, --, 
   {{0xb6040427,0x76480076,0x00000000,0x00000000}},	//   _tešč, otey, --, --, 
   {{0x2d8801e4,0x61f40051,0x720402f2,0xdb200241}},	// [13f80] _pobe_, _fixl, _توخم, _ìrùk, 
   {{0x2d88e6fb,0x2254034c,0x6fac02f5,0x3cec01e4}},	//   _qobe_, _کلید_, ককেই, _ŝeva_, 
   {{0x291ce6fc,0x7648e6fd,0x7f4c0023,0x013400c8}},	//   _reta_, htey, bfaq, _אָרט_, 
   {{0x291ce6fe,0x39980100,0x2d88d578,0x764803ee}},	//   _seta_, _bèso_, _wobe_, ktey, 
   {{0x2d88e6ff,0x77680050,0x61fc0e14,0x88841afc}},	//   _tobe_, ddex, _xuql, کیان, 
   {{0x291c0032,0x80241291,0x00000000,0x00000000}},	//   _qeta_, _تریم, --, --, 
   {{0x291ce700,0xeb982cc9,0x7648062c,0x9d40e701}},	//   _veta_, _див_, etey, _шерд, 
   {{0x291c02e3,0xc2e804c5,0x6f1400a9,0x88bc00bc}},	//   _weta_, কুটি_, nbyc, _oděv, 
   {{0x76485dd8,0xfa4802dd,0x80a400cc,0x00000000}},	//   gtey, _ىشكى_, _খুঞ্, --, 
   {{0x6e340024,0x291ce702,0x61fc022e,0x00000000}},	//   iryb, _ueta_, _ruql, --, 
   {{0x7e6c05b8,0x61fc092a,0x7648062c,0xd78401e2}},	//   zvap, _suql, atey, سنیو_, 
   {{0x6e340034,0x6cfc031c,0xf980035b,0x61fc0978}},	//   kryb, _ཟུའེ_, _аҳәо, _puql, 
   {{0x61f4e703,0x27e42bf3,0x61fc014f,0x76480363}},	//   _pixl, _ihon_, _quql, ctey, 
   {{0x61fc014f,0x6e34e704,0x00000000,0x00000000}},	//   _vuql, dryb, --, --, 
   {{0x27e4e705,0x104800c9,0x1dbc0882,0xd0d400a7}},	//   _khon_, мяти_, ्वसत, воръ, 
   {{0x27e4e706,0x7e6c00dc,0x7dd8026c,0x61fce707}},	//   _jhon_, tvap, mìsi, _tuql, 
   {{0x7f4c044e,0x27e40263,0x2ec022fd,0x6e34e708}},	// [13f90] rfaq, _mhon_, гөрм, gryb, 
   {{0x7e6c0882,0xdb08e709,0xaad00c2e,0x27e4062c}},	//   rvap, rigí, _तड़क, _lhon_, 
   {{0x7e6ce70a,0x27e42819,0xdce401e4,0xdb080311}},	//   svap, _ohon_, _kajĉ, vigâ, 
   {{0x27e4004d,0x76480076,0x00000000,0x00000000}},	//   _nhon_, ytey, --, --, 
   {{0xd52801e1,0xd980010e,0x3ce001ad,0xdb080162}},	//   _jọ̀w, _güỳç, _करवे_, ingø, 
   {{0x27e4e70b,0x6b7c054e,0xae18011a,0x00000000}},	//   _ahon_, _păgâ, _מושכ, --, 
   {{0x27e40013,0xdb080356,0x7b18030d,0x00000000}},	//   _bhon_, rigâ, _новр_, --, 
   {{0xd0f81203,0x7648e70c,0x7dd80268,0x27e4e70d}},	//   ומות_, ttey, dìsi, _chon_, 
   {{0x6808002d,0x39480198,0x7a3401ed,0x76480076}},	//   _ręde, ƙas_, _سٹائ, utey, 
   {{0xa6e03c1f,0x7648e70e,0x8938e70f,0x27e401ab}},	//   ыжыл, rtey, _опус_, _ehon_, 
   {{0x7648e710,0xbb180ae5,0x6f1400bc,0xd89400ec}},	//   stey, ﺰﮔﻪ_, ybyc, _تماڪ_, 
   {{0x96d0e711,0xdb0800db,0x6e3420cc,0x76480205}},	//   _ислә, nigà, yryb, ptey, 
   {{0xeb38010f,0x42d412fa,0xa80006be,0x00000000}},	//   הערש, віру, _şıxa, --, 
   {{0x04c800ec,0x00000000,0x00000000,0x00000000}},	//   _ڪوٺي_, --, --, --, 
   {{0x0574e712,0xaf980dce,0x44200150,0x00000000}},	//   _جاند, птах_, _шi_, --, 
   {{0x27382fbe,0x27e40240,0x6e3402d0,0xad640271}},	//   münü_, _xhon_, tryb, کاره, 
   {{0xee38e713,0x27387225,0xd1300014,0x6c840133}},	// [13fa0] яна_, lünü_, _پۅز_, کلام, 
   {{0x5d64152a,0x9d4002dd,0x00000000,0x00000000}},	//   ниум_, леуд, --, --, 
   {{0x27381ae4,0x6fc8003a,0x88bc0118,0x00000000}},	//   nünü_, _sǽcu, _jdět, --, 
   {{0x6e340153,0xa8a00150,0x00000000,0x00000000}},	//   pryb, ңғақ, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x27e4e714,0xa9040014,0x27383361,0x00000000}},	//   _shon_, ربتن, künü_, --, 
   {{0x27e4e715,0x6b54e716,0x1dbc1a55,0x58d0e717}},	//   _phon_, _птах, ्वरत, лошт, 
   {{0x6d5ce718,0x3864e719,0x273806be,0x691c0ca8}},	//   lepa, _dslr_, dünü_, _ṣedu, 
   {{0x44200de2,0x00000000,0x00000000,0x00000000}},	//   _ňi_, --, --, --, 
   {{0x6d5ce71a,0x66140209,0xbd0401e1,0xdb0800d8}},	//   nepa, _çykm, _ibéè, pigã, 
   {{0x27e4e71b,0xd4940262,0x27380342,0xd71c03d4}},	//   _thon_, еря_, günü_, _ধাৰা_, 
   {{0x6d5ce71c,0x27e4409c,0x7dd82b1d,0x00000000}},	//   hepa, _uhon_, rìsi, --, 
   {{0x6d5ce71d,0x00000000,0x00000000,0x00000000}},	//   kepa, --, --, --, 
   {{0x6d5c2630,0x660001e4,0x25640014,0x1a98008f}},	//   jepa, _iuok, _ساتُ, ליכע, 
   {{0x273806b9,0x6600e71e,0x80d800eb,0x154000f3}},	//   cünü_, _huok, ণেন্, _сејм, 
   {{0x6600e71f,0x65680084,0x987804ac,0x6720033b}},	//   _kuok, _hafh, האלט, _jeoj, 
   {{0x6600e720,0x6d5c1132,0x2448003a,0xf2c4004e}},	// [13fb0] _juok, fepa, lùm_, _үсөн, 
   {{0x6d5ce721,0x6600049b,0x6720007f,0x6568031c}},	//   gepa, _muok, _leoj, _jafh, 
   {{0x65681aa1,0x6600049b,0xbd0401e1,0x3944009a}},	//   _mafh, _luok, _abéè, _rcls_, 
   {{0x65680b4f,0x8c649d86,0x5438010f,0x37e400eb}},	//   _lafh, ытуд, לעבא, _পূনর, 
   {{0x27384a4a,0x66001e76,0x00000000,0x00000000}},	//   zünü_, _nuok, --, --, 
   {{0x6d5ce722,0x3ea8e723,0x866402d3,0xbd4408e8}},	//   cepa, mzat_, ፋይነት, _جنسي, 
   {{0x3ea8847c,0xf770007b,0x6614010b,0x3f8800c0}},	//   lzat_, لاة_, _çykj, ojau_, 
   {{0x3f88e724,0x66000086,0x8b040198,0xdce40135}},	//   njau_, _buok, ƙƙab, _lajċ, 
   {{0xb6a4e725,0x3ea8e726,0xabb40022,0x672403b2}},	//   типл, nzat_, _ратә, ðkja, 
   {{0xd5a00e3f,0x3ea8e727,0x2738029f,0x6600e728}},	//   الدی, izat_, tünü_, _duok, 
   {{0x981400c6,0x2edc00dc,0x69d80c70,0x9c80010e}},	//   _أبطا, _मर्त, _पीटी, _öōde, 
   {{0x67200066,0x2738029f,0x6d5ce729,0xb4e03337}},	//   _geoj, rünü_, zepa, _दरी_, 
   {{0x3ea802d3,0x6d5ce72a,0x27383535,0x66000165}},	//   jzat_, yepa, sünü_, _guok, 
   {{0x6d5c009d,0x3ea8e488,0x3f880064,0x00000000}},	//   xepa, dzat_, ejau_, --, 
   {{0x6d5c9316,0x67200490,0x6020e72b,0x66000024}},	//   vepa, _yeoj, идра, _zuok, 
   {{0xa06403b7,0x3a2c013c,0x00000000,0x00000000}},	//   њата_, _ovep_, --, --, 
   {{0x6d5c0fe3,0xde00e72c,0xdb08011f,0x3ea80a08}},	// [13fc0] tepa, ипти, xigá, gzat_, 
   {{0xdb0856b1,0xd1300014,0xc10000ee,0x30040d1d}},	//   vigá, _دۅس_, _гүрл, _изог, 
   {{0x49a401e0,0x3ea8036e,0x00000000,0x00000000}},	//   ҫылғ, azat_, --, --, 
   {{0x6d5ce72d,0x99d0034c,0xefdc0023,0x88bc013a}},	//   sepa, یتوا, ዓዝያ_, _oděr, 
   {{0x6d5ce72e,0x1148044e,0x67200789,0x015802d3}},	//   pepa, _ዝምድና, _reoj, _ህዝቦም, 
   {{0x6600c2bc,0x59dc00ab,0x6d5c0309,0xa2c021f2}},	//   _ruok, _पीआर, qepa, रपत्, 
   {{0xea60121e,0x765803cb,0xdb08011f,0x6cd4007b}},	//   _چھتی, _apwy, sigá, _شقرا, 
   {{0x66000024,0x65680790,0x971002e8,0x18640114}},	//   _puok, _safh, амъц, таћи_, 
   {{0x660003fa,0x69240022,0x6720000d,0xa3780254}},	//   _quok, _амза, _veoj, kmõr, 
   {{0x66000664,0x99840356,0x24880092,0x00000000}},	//   _vuok, ăiţi_, ዕግሥት_, --, 
   {{0x3ea8e72f,0xd7ec07d5,0x5d3808a8,0x26140412}},	//   zzat_, _ву_, ותיא, पीजी_, 
   {{0x6600822d,0x24480428,0x3ea801ed,0x00000000}},	//   _tuok, rùm_, yzat_, --, 
   {{0xe5c4df65,0x161800af,0x6568031c,0x7ea8022e}},	//   _иско, पीआर_, _tafh, _tоpi, 
   {{0x656804ce,0x3ea8e730,0xf1f40133,0x00000000}},	//   _uafh, vzat_, ێکیش_, --, 
   {{0xdef0e731,0xd48ce732,0x3f88004e,0x80cc00bc}},	//   ውያን_, _тр_, tjau_, _दुखे, 
   {{0x3ea895de,0x442c00b5,0x62040107,0xa2c0043e}},	//   tzat_, msd_, _ичоз, रपद्, 
   {{0x71a4001f,0x71800092,0x3ea8027e,0x4cb000eb}},	// [13fd0] _ላለፉት_, _ካለፉት_, uzat_, _জুলু, 
   {{0x3ea8e733,0x3f8803cd,0x442c0e89,0x91e400f3}},	//   rzat_, sjau_, osd_, _коње, 
   {{0xd1b81075,0x442c01f5,0x3ea801ed,0x3a2c01e3}},	//   _جايا_, nsd_, szat_, _svep_, 
   {{0x442ce734,0x201001c0,0x3998007f,0x38780306}},	//   isd_, _itxi_, _tèsk_, _čsr_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2cb0006a,0xf2d8010f,0x00000000,0x00000000}},	//   ûndû_, ײַנל, --, --, 
   {{0x442c0d27,0x23d03507,0x8ae401ec,0x3774004e}},	//   jsd_, सवाद, ліәл, гыпс, 
   {{0x69d4019f,0xdce409a8,0xf7709448,0x97701cd1}},	//   îyer, _jajč, صاب_, рткә, 
   {{0x38c8006a,0xf7704c12,0x442c282c,0xab600046}},	//   _bîrï_, لاک_, esd_, _دۇنى, 
   {{0x7dd80ffb,0xdce4e735,0xceb4011a,0x00000000}},	//   mìss, _lajč, ייפ_, --, 
   {{0xe2945540,0x20100218,0x57a4036b,0xdb200ca8}},	//   қар_, _ntxi_, _ишда, _ìrók, 
   {{0xe72c30ba,0x31a400d7,0xd90c00e5,0x00000000}},	//   _ће_, _môze_, _ایں_, --, 
   {{0x442ce736,0x2010005a,0xe56c0452,0xc38400c7}},	//   asd_, _atxi_, _лз_, рҩыз_, 
   {{0xaab41152,0x6d10000d,0x00000000,0x00000000}},	//   _आइसक, _ढ्ंग_, --, --, 
   {{0xa0a0e737,0x442c0098,0x8f840116,0x2f54e738}},	//   бард, csd_, ақнл, лтас, 
   {{0xd11401ad,0xe7440254,0x3cac0150,0x00000000}},	//   _त्रण_, _õõts_, _ﺴﺒﺘﻤ, --, 
   {{0xd9e00574,0xc2600023,0x6e4401b9,0x00000000}},	// [13fe0] गतात_, ሳተፍዎ_, طنام, --, 
   {{0x7dd80268,0x24640022,0x00000000,0x00000000}},	//   dìss, _рхәҳ, --, --, 
   {{0xdce401f1,0xdb0402fb,0x307407b5,0xdef00092}},	//   _fajč, _šlág, _супс, ውያኑ_, 
   {{0x09dc0b7c,0x20540a7c,0x00000000,0x00000000}},	//   यत्य, _גיטל_, --, --, 
   {{0x7dd8026c,0x63780139,0xfe4400e5,0xdb08010e}},	//   tìst, _hänä, _نکلی, digä, 
   {{0xdce40219,0x6378013d,0x286818a4,0x8024030f}},	//   _zajč, _känä, ерио_, _حریم, 
   {{0x6af40489,0x7dd80268,0x00000000,0x00000000}},	//   _བུམོ_, rìst, --, --, 
   {{0xe6640323,0x97a00228,0x442c0048,0x63780139}},	//   гтоо, йрыл, vsd_, _mänä, 
   {{0x9b9000c6,0x63780139,0xdb0402d2,0x5ba400d8}},	//   _القت, _länä, _álág, _сктм_, 
   {{0x442c01ed,0xdb200241,0x00000000,0x00000000}},	//   tsd_, _ìròk, --, --, 
   {{0x69d8e739,0x63780166,0x00000000,0x00000000}},	//   _ikte, _nänä, --, --, 
   {{0xdc980302,0x2b44004d,0x88340137,0xdb080139}},	//   גיטל, ngoc_, _مةچئ, cigä, 
   {{0xdce4e73a,0x39980066,0x561000ec,0xa6100166}},	//   _rajč, _sèsi_, _هونء, _узлә, 
   {{0x7afc00bc,0xe45004fb,0x39980100,0xdce4007f}},	//   _úste, _هفتگ, _pèsi_, _sajč, 
   {{0xd08434d8,0x63780139,0xdce40010,0xdedc0023}},	//   быти, _cänä, _pajč, ሓውን_, 
   {{0x3f14e73b,0x31a4000f,0x6378e73c,0x161823ef}},	//   рдас, _rôze_, _dänä, पीकर_, 
   {{0x69d876ea,0x3f6800d1,0xf2840139,0xe6e00037}},	// [13ff0] _okte, ниңо_, _көрд_, _परोज, 
   {{0x39980ba1,0x63780139,0x9f9403b9,0x00000000}},	//   _tèsi_, _fänä, lçü_, --, 
   {{0x20100bc9,0xdce4107d,0x9ce4a8dc,0x00000000}},	//   _utxi_, _tajč, уцал, --, 
   {{0x69d8e73d,0x3a74765f,0xdb0803b2,0x853c00c0}},	//   _akte, илер, vngó, lkėd, 
   {{0x3ce0068f,0x637801b8,0x2ba400bc,0xdb2002d2}},	//   _करके_, _zänä, _खतरा, _írík, 
   {{0x6378013d,0x853c0064,0xdd840153,0x00000000}},	//   _yänä, nkėd, _сымп, --, 
   {{0x4c94399f,0x63780166,0x00000000,0x00000000}},	//   _лирс, _xänä, --, --, 
   {{0x69d803a1,0xc0bc001f,0x98a40003,0x00000000}},	//   _ekte, _ታክስ_, lanċ_, --, 
   {{0x69d803a0,0x4638001f,0x00000000,0x00000000}},	//   _fkte, _በነገራ, --, --, 
   {{0x7ae8e73e,0xe5740024,0x00000000,0x00000000}},	//   _izet, азь_, --, --, 
   {{0x9f9400f7,0xe978011a,0x3c000153,0x2d100037}},	//   nçó_, _שנעש, _tėvu_, _ढ्ोल_, 
   {{0xdb180139,0x36d404f0,0x69c402d2,0x00000000}},	//   _djuç, _коер, _íker, --, 
   {{0x63780724,0x8c4803e0,0x00000000,0x00000000}},	//   _sänä, _kuşç, --, --, 
   {{0xdb1ce73f,0xdce40419,0xa5040835,0x00000000}},	//   _åvær, _najď, _кеша_, --, 
   {{0x7ae801fa,0x7bc800c7,0x6378008e,0xc3240154}},	//   _lzet, _ojeu, _qänä, _ভারি_, 
   {{0x7ae80699,0xa2c0227c,0x7bc8e740,0x720400f2}},	//   _ozet, रपश्, _njeu, _پودم, 
  
   {{0x7ae80296,0x7aec0209,0xa3d00490,0x93940023}},	// [14000] _nzet, ýatl, ववर_, _ዝረሓቐ_, 
   {{0x6378049b,0x7bc8e741,0xa2c0215d,0x1dbc00cd}},	//   _tänä, _ajeu, रपर्, ्वगत, 
   {{0xdd8ce742,0x7ae8e743,0xe6e001bc,0xafe401a9}},	//   بول_, _azet, _पर्ज, _вонл, 
   {{0x79800042,0x2ce401f9,0xe45400df,0x00000000}},	//   _anlw, _करील_, ייעט_, --, 
   {{0x7bc81bce,0x8c440209,0xf1b80210,0x00000000}},	//   _djeu, реҗе, _उगान, --, 
   {{0x7ae8006f,0x7bc8003e,0xada46bd5,0x2d9c9ec6}},	//   _dzet, _ejeu, _тагл, _ôte_, 
   {{0xfca8040b,0x7c8403b7,0x7ae8e744,0x8f900055}},	//   _یاہو_, _луѓе, _ezet, _gṛñj, 
   {{0x48c400c7,0x9c14011a,0xdb0801bf,0x853c0064}},	//   _қәла, _כחלק_, tigå, chėj, 
   {{0x07040022,0xb88402d2,0x00000000,0x00000000}},	//   аҧҵо, _plíí, --, --, 
   {{0xcba4016c,0x9f94004e,0x8c48010e,0x69d800cd}},	//   _тағй, nçò_, _guşç, _ukte, 
   {{0x59dc06ab,0xc8e4005e,0x03f80640,0xfa380092}},	//   _पीटर, _اقاۋ, лној_, _አልሰማ, 
   {{0x58b80375,0xdce4002b,0xf3f40133,0x9cd4011a}},	//   _במבצ, _jajā, یتێک, שוטה_, 
   {{0x4614e745,0x4394013e,0x8c48013d,0xdce400de}},	//   _اوتر, _ҳайс, _yuşç, _majā, 
   {{0x14b4dbb4,0x61100118,0x9f940205,0x00000000}},	//   ادیث_, dělí, sçü_, --, 
   {{0x06d8000e,0x4394e746,0x81e8009e,0x5f2408da}},	//   দেশি, _гайс, যদল_, ифаз, 
   {{0xd01000f1,0x14cc0073,0x00000000,0x00000000}},	//   ړلې_, _सुटण, --, --, 
   {{0xdc0c00bc,0xc0bc01f3,0xdedc0023,0x8f9000cd}},	// [14010] _věčn, _ታክሲ_, ሓፍን_, _sṛñj, 
   {{0x7ae8033f,0x00000000,0x00000000,0x00000000}},	//   _rzet, --, --, --, 
   {{0x7ae801ed,0xdce40171,0x00000000,0x00000000}},	//   _szet, _bajā, --, --, 
   {{0xd14400c6,0x5fa00aaf,0x60d8083c,0x9f94004e}},	//   _įąɱ_, _بەرم, ğumd, rçó_, 
   {{0x39981497,0x80d800cc,0x6808012d,0x539c011a}},	//   _oèst_, ণেশ্, _wędl, כיאו, 
   {{0x7ae809a8,0x4aa8e747,0x8c4803e3,0xca7400d1}},	//   _vzet, шкін_, _quşç, غانغ, 
   {{0xa3e40d41,0x7ea801a9,0x00000000,0x00000000}},	//   भता_, _tоps, --, --, 
   {{0x7ae8e748,0x7bc801f7,0xdce400cd,0x81bc0154}},	//   _tzet, _ujeu, _gajā, ইকি_, 
   {{0x7ae82ce2,0x24840023,0x7bd8e749,0xe614004e}},	//   _uzet, _ንመለስ_, mowu, бды_, 
   {{0xc9843075,0x7bd802d0,0x69c402d2,0xda0401e2}},	//   _мухи, lowu, _íkep, _ميړه_, 
   {{0x7bd80083,0x81bc0154,0x5fc40cba,0xdce4002b}},	//   oowu, ইকা_, रचाल, _yajā, 
   {{0x06b80dc4,0x7bd8e74a,0xc8780139,0x00000000}},	//   انیک_, nowu, _uyğa_, --, 
   {{0x87d4678a,0x047801d5,0x56640066,0x00000000}},	//   _بغلا, هلیک_, _خداف, --, 
   {{0x3998e74b,0x7bd8004b,0x3d200034,0xf504005b}},	//   _gèst_, howu, यरों_, _узко, 
   {{0x7bd8e74c,0xa0a0e74d,0x2ce40073,0x947401d3}},	//   kowu, пард, _करेल_, _خدشا, 
   {{0xaf04e74e,0x7bd800e8,0x6fb4007b,0x3ce0000d}},	//   спал, jowu, حمرا, _करजे_, 
   {{0xada4e74f,0xb62804ce,0xdce400b8,0xed5803f6}},	// [14020] баал, _ｗｄ_, _rajā, лоа_, 
   {{0xefb0036b,0xdce4002b,0x00000000,0x00000000}},	//   _کیرگ, _sajā, --, --, 
   {{0x7bd8004b,0xaab80244,0xdce4002b,0xb0bc0354}},	//   fowu, گدار_, _pajā, _ченĕ_, 
   {{0xcaa408b0,0x5d64023b,0x7f1800d4,0x7bd8012d}},	//   يلاۋ, _қисм_, _віру_, gowu, 
   {{0xaab8e750,0xdce400de,0x00000000,0x00000000}},	//   ددار_, _vajā, --, --, 
   {{0x1d042b97,0x3178010f,0x00000000,0x00000000}},	//   _гери_, ראַד, --, --, 
   {{0x7bd8e751,0x3998007f,0xdce400e2,0xdb18e752}},	//   bowu, _rèst_, _tajā, _sjuå, 
   {{0xada41d56,0xf4c000fe,0x7bd80210,0x00000000}},	//   _таҳл, _উৰ্ব, cowu, --, 
   {{0x5eb800c8,0xa504010b,0x00000000,0x00000000}},	//   ָזיק, йянл, --, --, 
   {{0x85b8732e,0x7afc0232,0x7c300139,0x00000000}},	//   рлос_, _ústa, _äkrä, --, 
   {{0x04880598,0xe73800d8,0x6ff8012d,0xbb4002dd}},	//   рәли_, _бее_, ्दाख_, _ﻛﻪﻥ_, 
   {{0x3ce405ac,0x00000000,0x00000000,0x00000000}},	//   _ølve_, --, --, --, 
   {{0xa6100598,0x6674dcb1,0x3998068c,0x6d4c02d0}},	//   _эзлә, _ددار, _tèst_, _ocba, 
   {{0x7bd80944,0xc60402ab,0xd1480014,0x5690e753}},	//   zowu, रदीय_, ٝشِن_, _хашт, 
   {{0xdd98e754,0x7bd801f0,0xb4b4151e,0x93240014}},	//   қша_, yowu, _мишә, _کر٘ن, 
   {{0xdef8e755,0x6614010b,0x00000000,0x00000000}},	//   гыз_, _çyks, --, --, 
   {{0x7bd82784,0xe3bce756,0xf1a8a675,0xdb2000ae}},	// [14030] vowu, miñ_, _چاپه_, írío, 
   {{0x80081893,0xdb08365a,0x7bd80083,0xe3bce757}},	//   _پردہ_, ligø, wowu, liñ_, 
   {{0x7bd8433e,0xf8e80022,0xa8000139,0x00000000}},	//   towu, hẽrã_, _ğına, --, 
   {{0xe3bce758,0xdb08006a,0x6d4c003a,0xe1fc033f}},	//   niñ_, hngö, _ecba, zwól_, 
   {{0x6d4ce759,0x98a42e31,0x7bd80210,0x6f6000d1}},	//   _fcba, ranč_, rowu, _زۇلم, 
   {{0xe3cc03f4,0xe3bc0156,0x7bd8012d,0x49c828f6}},	//   রতিব, hiñ_, sowu, блін_, 
   {{0xe3bc153b,0x00000000,0x00000000,0x00000000}},	//   kiñ_, --, --, --, 
   {{0xdc5c044e,0xe3bc0156,0x588402dd,0x24880023}},	//   _ሳልሳይ_, jiñ_, _қыза, _ዕሉላት_, 
   {{0xe3bc0dd4,0x4e1c0037,0xdb08032e,0x00000000}},	//   diñ_, _पढ़ाई_, fngö, --, 
   {{0xe3bc0165,0x48a80304,0x1db800cd,0x00000000}},	//   eiñ_, ртәм_, ोचित, --, 
   {{0xe3bc030a,0x84580395,0x00000000,0x00000000}},	//   fiñ_, брят_, --, --, 
   {{0xe8d404ac,0xe3bce75a,0x644c0ba1,0xd7f83ae4}},	//   _ווער_, giñ_, àbia, _суз_, 
   {{0xef1000f1,0x4094009d,0x00000000,0x00000000}},	//   ېټر_, үрст, --, --, 
   {{0xd37814cf,0x7f5c1730,0x00000000,0x00000000}},	//   ść_, _absq, --, --, 
   {{0xe3bc0156,0x00000000,0x00000000,0x00000000}},	//   biñ_, --, --, --, 
   {{0x1fa407d6,0xe3bc0077,0x00000000,0x00000000}},	//   окси_, ciñ_, --, --, 
   {{0xdee032b1,0xdcfc00b8,0x00000000,0x00000000}},	// [14040] доти, _āvār, --, --, 
   {{0xace8e75b,0x7e7c02d0,0x3028e75c,0x116801b9}},	//   амза_, _drsp, _кооп_, _الدی_, 
   {{0x7e7c9316,0xc2c801ed,0xfe7000e5,0x60d80205}},	//   _ersp, _نبیل_, ودے_, ğumc, 
   {{0x31a4145e,0x68080034,0x7d080139,0x00000000}},	//   _kôzo_, _wędk, _şest, --, 
   {{0x7d0c00c6,0x29881575,0x6af4009a,0x00000000}},	//   íosú, иско_, آثار, --, 
   {{0xe3bce75d,0x0ff800e1,0x6d4c03e3,0xec780a5b}},	//   ziñ_, ंगवश_, _ucba, _кпг_, 
   {{0xe3bc0054,0x7afc0308,0x00000000,0x00000000}},	//   yiñ_, _ústn, --, --, 
   {{0xaa4402bf,0x7e7c0270,0xdcac030c,0x998c0153}},	//   _мебл, _yrsp, _شىق_, fugų_, 
   {{0x9f48004a,0x25bc030a,0xe3bc0156,0xdb080200}},	//   ômés_, titl_, viñ_, zhgë, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x0b740020,0xe3bce75e,0x2ec40882,0x00000000}},	//   _በምድር_, tiñ_, लपुत, --, 
   {{0xe3bc03bd,0x249c0210,0x00000000,0x00000000}},	//   uiñ_, rytm_, --, --, 
   {{0xe3bce75f,0xdce80e04,0x69c80072,0x00000000}},	//   riñ_, _čiča, onfe, --, 
   {{0xe3bc0bc9,0x518401f0,0x00000000,0x00000000}},	//   siñ_, муса, --, --, 
   {{0x69c8e760,0x843800c6,0x83f800a7,0xe3bce761}},	//   infe, _اكبر_, _лекс_, piñ_, 
   {{0xe2a83ee6,0xc5f800e2,0x69c8002f,0x00000000}},	//   _ناخن_, lmē_, hnfe, --, 
   {{0xdce40034,0xdef8023a,0x00000000,0x00000000}},	// [14050] _mają, рыв_, --, --, 
   {{0xe1fc0034,0x9f489223,0x9ce401f4,0x225c0200}},	//   zwój_, _picó_, оцел, çuku_, 
   {{0x9b6807d6,0x98a4e762,0xde440244,0x00000000}},	//   ишда_, kanā_, _ژیرو_, --, 
   {{0xcc8801d5,0x2d8c002f,0x69c40241,0x00000000}},	//   تنمه_, öfer_, _ìkej, --, 
   {{0x7e7ce763,0x7f4c021a,0xc5f8005f,0x3f9801c4}},	//   _ursp, mgaq, kmē_, _iosu_, 
   {{0x7e6c01f7,0x3f980356,0x69c8007c,0x7af003e0}},	//   mwap, _hosu_, gnfe, _ıhtı, 
   {{0x3f9807f5,0x7e6ce764,0xa3c80073,0x00000000}},	//   _kosu_, lwap, ळचा_, --, 
   {{0x7f4ce765,0x3f9801c0,0x98a4e766,0x17f401ad}},	//   ngaq, _josu_, ganā_, ुदेव_, 
   {{0x7e6ce767,0x3f988fc6,0x73e4013e,0xdce4033f}},	//   nwap, _mosu_, ҷонз, _dają, 
   {{0x3f98e768,0xc32400fe,0xda300150,0x00000000}},	//   _losu_, _ভাগি_, _неғы, --, 
   {{0x7e6ce769,0x00000000,0x00000000,0x00000000}},	//   hwap, --, --, --, 
   {{0x3f98e76a,0x7e6c6f82,0x628c0175,0xdedc0023}},	//   _nosu_, kwap, fxco, ዓልን_, 
   {{0x24507380,0x776802f0,0x00000000,0x00000000}},	//   ونیس, meex, --, --, 
   {{0x77688eed,0x7e6c0bd7,0xdce4033f,0x7f4c0334}},	//   leex, dwap, _zają, egaq, 
   {{0x85b8e76b,0xde080131,0x3dc00142,0x657c0332}},	//   _بانس_, ەرمۇ_, dihw_, _ópha, 
   {{0x3f980268,0x776800e8,0x3eac0327,0x853c0153}},	//   _cosu_, neex, _żeta_, nkėn, 
   {{0x7e6ce76c,0xacc80724,0x60d80790,0x69c803cb}},	// [14060] gwap, әгез_, ğuma, ynfe, 
   {{0x7f4c0eda,0x3f9801c7,0x76480076,0x77680175}},	//   agaq, _eosu_, iuey, heex, 
   {{0x3f9801e4,0xafe401c0,0xa8000790,0x2198011a}},	//   _fosu_, _ноол, _şıma, _הביא, 
   {{0x7648c385,0x7e6c406d,0x7768058a,0x3f980208}},	//   kuey, bwap, jeex, _gosu_, 
   {{0x77680014,0x6a8410a6,0xd88c0150,0x69c803b2}},	//   deex, ялда, _ﯙﻳﻨﯟ, tnfe, 
   {{0xe0e80295,0x69c80e14,0x3f9800ef,0x6e340064}},	//   _ñòñ_, unfe, _zosu_, msyb, 
   {{0x88841056,0xac9800db,0x3f98002e,0xdce4012d}},	//   بیان, _انزا_, _yosu_, _pają, 
   {{0x6f1470a9,0x69c8e76d,0x77689e91,0x63ac0051}},	//   ncyc, snfe, geex, xhcn, 
   {{0x7648e76e,0xf1c000ef,0xceb406be,0x00000000}},	//   guey, _košā_, nzə_, --, 
   {{0xe94402dd,0x00000000,0x00000000,0x00000000}},	//   _ءناپ, --, --, --, 
   {{0xc5f8005f,0xd9180375,0x7648062c,0x80c000eb}},	//   rmē_, _הובל, auey, _শুন্, 
   {{0x7e6c0309,0x64a40022,0x00000000,0x00000000}},	//   ywap, _ҭада, --, --, 
   {{0x6aa0e76f,0x3f98e770,0x7f4c0cfe,0x92580395}},	//   nyof, _rosu_, vgaq, паят_, 
   {{0x3f98e771,0x7e6c0af2,0x2bbc01f2,0x6f140142}},	//   _sosu_, vwap, ọcha_, ecyc, 
   {{0x5064e772,0x3f98bb9d,0x55740bd9,0x1fa4e773}},	//   нтта, _posu_, _מעגן_, праг, 
   {{0x94700491,0x7f4c0140,0xd3780276,0x98a4e1e9}},	//   _أدوا, ugaq, _ечь_, lană_, 
   {{0x7f4c011f,0x5d64008e,0x98a40311,0x00000000}},	// [14070] rgaq, зтез, oană_, --, 
   {{0x7e6ce774,0x7768022f,0x22480e78,0x3f9800e8}},	//   rwap, zeex, muck_, _wosu_, 
   {{0x3f980ffb,0xa53c0092,0x98a40356,0xd00800d8}},	//   _tosu_, _በአንቀ, iană_, _неќе_, 
   {{0xff24444b,0x776801d9,0x98a40356,0x00000000}},	//   _تبدی, xeex, hană_, --, 
   {{0x1ee41bf3,0x261000d8,0x2248045a,0x26c000d7}},	//   _روسی_, _nâo_, nuck_, úkol_, 
   {{0xf8a80214,0x830c0327,0x00000000,0x00000000}},	//   يگاه_, _གུའུ_, --, --, 
   {{0x644ce775,0x5c04004e,0xbb481e24,0x00000000}},	//   àbil, _хяга, _ولسن_, --, 
   {{0xd52801e1,0x22480036,0xa2c000dc,0x6aa00205}},	//   _bò̟w, kuck_, रपञ्, byof, 
   {{0x6d4825e6,0x77680014,0x205002d3,0x98a40356}},	//   ófag, reex, _ዝግበረ, fană_, 
   {{0x224826ff,0x77682aff,0xa56000d1,0xdedc0023}},	//   duck_, seex, نگىن, ዓልና_, 
   {{0x95b005a2,0x00000000,0x00000000,0x00000000}},	//   _үрлә, --, --, --, 
   {{0x80c00011,0xdb0800a2,0x00000000,0x00000000}},	//   _শুভ্, jigü, --, --, 
   {{0x98a40311,0x4914012c,0x36240014,0xdb089e11}},	//   bană_, नुको_, _کوڈہ, ligó, 
   {{0x98a40311,0xc7b8004d,0xf428011c,0x853c0064}},	//   cană_, _gtđb_, _докл_, nkėl, 
   {{0xafe4e776,0x6f14005b,0xaf985541,0x00000000}},	//   довл, tcyc, отах_, --, 
   {{0x224806f2,0x2fd80214,0xdb2001e1,0x00000000}},	//   buck_, آورد_, _ìrèk, --, 
   {{0x6e3402d5,0xee380137,0x6f14e777,0x22900592}},	// [14080] usyb, юна_, rcyc, _لليس, 
   {{0x6f14e778,0x6aa00451,0x6ec0e079,0xad640a8e}},	//   scyc, vyof, _रेणु, باره, 
   {{0x6f14e779,0xdb08e77a,0x6c8401d5,0x00000000}},	//   pcyc, bigü, بلام, --, 
   {{0xa73001e1,0x6e3403ac,0x00000000,0x00000000}},	//   _lọrù, psyb, --, --, 
   {{0x38640048,0xf1d0b658,0x00000000,0x00000000}},	//   _aplr_, _सदान, --, --, 
   {{0x2b500210,0x00000000,0x00000000,0x00000000}},	//   życ_, --, --, --, 
   {{0xec14034c,0x26100022,0xaadc01ad,0x6b540b01}},	//   _آورد, _sâo_, _फुरक, _отах, 
   {{0x5880e77b,0x6d5c5487,0x17f400c6,0x9cd405d0}},	//   тыша, lfpa, ورية_, _חולה_, 
   {{0x98a4054e,0x6d5c017a,0xc80800f1,0xc8480023}},	//   tană_, ofpa, _کښته_, _ዘይምን, 
   {{0xd9400124,0x5a98011a,0x00000000,0x00000000}},	//   _аефи, _ושמא, --, --, 
   {{0x44380098,0xf8ac0032,0x98a40311,0x6d5c002f}},	//   ér_, _сө_, rană_, ifpa, 
   {{0xb864e77c,0xdb08067c,0xc32403d4,0x2248045a}},	//   _سامو, ligò, _ভাঙি_, tuck_, 
   {{0x47701884,0xc7b80051,0x57f8011a,0x853c0153}},	//   _аққу, _ttđb_, _ולאו, lkėm, 
   {{0x2248e77d,0x6d5c01f5,0xaa3c0023,0x00000000}},	//   ruck_, jfpa, _ኣይሰላ, --, 
   {{0xdb081709,0x2248020b,0xdedc0023,0x853c0153}},	//   tigü, suck_, ዓውን_, nkėm, 
   {{0x65780857,0x6d5c1543,0xe1fc0210,0x00000000}},	//   ldth, efpa, ywów_, --, 
   {{0x3df4657c,0x6458e77e,0xdb087ba4,0x98a4762b}},	// [14090] езас, ltti, rigü, maną_, 
   {{0x6578035a,0xdce40034,0x6458e77f,0xd654011a}},	//   ndth, _zaję, otti, וימת_, 
   {{0x64580664,0x69c403b2,0xa3b0000d,0xa378000d}},	//   ntti, _íkey, _टता_, elõi, 
   {{0x6458e780,0x3af4005b,0x98a43d44,0x70f8011a}},	//   itti, нялс, naną_, _מהתח, 
   {{0x6458e781,0x4fc40c75,0xd1b80066,0x00000000}},	//   htti, _شەكە, _رایا_, --, 
   {{0x7d242101,0x64581f53,0xe1fc0210,0x00000000}},	//   _سفرن, ktti, rwów_, --, 
   {{0x853c0024,0xa3780254,0xa7300241,0x98a43d44}},	//   rkėl, alõi, _rọrù, kaną_, 
   {{0xc84802d3,0xa73001e1,0x00000000,0x00000000}},	//   _ዘይመን, _sọrù, --, --, 
   {{0x6458e782,0xdb0804d4,0x98a43d44,0x00000000}},	//   etti, sigó, daną_, --, 
   {{0x7ae8b2f1,0xdb0804d4,0x657801f5,0x853c0153}},	//   _iyet, pigó, gdth, lkėj, 
   {{0x7ae800cd,0x6458005c,0x35a4013d,0xdce4012d}},	//   _hyet, gtti, _җайг, _paję, 
   {{0xc8c84bf3,0x7ae82252,0x61f401ab,0x853c0006}},	//   _تومن_, _kyet, _ahxl, nkėj, 
   {{0x6458e783,0xda0c5b99,0x60d80790,0x00000000}},	//   atti, ादित_, şuml, --, 
   {{0x55c008b0,0x9a4801f3,0x00000000,0x00000000}},	//   _шалғ, _ዓይነቱ, --, --, 
   {{0xceb400ac,0x7ae8e784,0x6458010a,0x78b406be}},	//   hbət_, _lyet, ctti, _üzvd, 
   {{0x3b0c0455,0xd25001d9,0x7ae8e785,0xda0c0073}},	//   _ngeq_, _پۆس_, _oyet, ादात_, 
   {{0x80c002a6,0x7ae8e786,0x68082634,0x6f880014}},	// [140a0] _শুদ্, _nyet, _jędr, _ہندِ_, 
   {{0x6d5c002f,0x68080210,0x00000000,0x00000000}},	//   ufpa, _mędr, --, --, 
   {{0xdca0016c,0x7ae8e787,0x628800cf,0xa154011a}},	//   лафи, _ayet, _àgor, _אביה_, 
   {{0x7ae8e788,0xd1b800ec,0x00000000,0x00000000}},	//   _byet, _راڌا_, --, --, 
   {{0xda140131,0x5b100212,0x6d5c002f,0x61e800c0}},	//   ۈزۈش_, уміт, pfpa, _ūgli, 
   {{0x7ae8e789,0x6458b1a0,0x6ab40124,0x291800a3}},	//   _dyet, ytti, _ҧсах, ùpa_, 
   {{0xab281515,0x7ae8816a,0xdb08068c,0x64580334}},	//   _нова_, _eyet, rigò, xtti, 
   {{0x7ae80100,0xceb400ac,0xd7f420b0,0xdb0826b7}},	//   _fyet, bbət_, нуы_, sigò, 
   {{0xe5c4ca40,0x7ae80a49,0x98a40024,0x45d4e78a}},	//   есно, _gyet, vaną_, коис, 
   {{0x98a40034,0xe9d8e78b,0x00000000,0x00000000}},	//   waną_, _экз_, --, --, 
   {{0x6458e78c,0x65780334,0x98a44f7e,0x00000000}},	//   utti, rdth, taną_, --, 
   {{0x6458e78d,0x00000000,0x00000000,0x00000000}},	//   rtti, --, --, --, 
   {{0x27e4e78e,0x6458e78f,0x98a43ee4,0xe5c4e790}},	//   _ikon_, stti, raną_, _пско, 
   {{0x049400c6,0xfcf002d3,0x98a4033f,0xceb406be}},	//   _للتح, ፍላጥ_, saną_, hbəs_, 
   {{0x2fc0008b,0x32100098,0x00000000,0x00000000}},	//   _bmkg_, _euyy_, --, --, 
   {{0x660894ea,0xc2100050,0x00000000,0x00000000}},	//   _hifk, _پٔد_, --, --, 
   {{0x3210df5a,0x443c28dc,0xe37001ec,0x7d5410e4}},	// [140b0] _guyy_, _hvv_, _алқы, квах, 
   {{0x443c01f5,0x7afc0419,0x00000000,0x00000000}},	//   _kvv_, _ústi, --, --, 
   {{0x8d740137,0x9bc412d7,0x443c004e,0x660800d5}},	//   داقا, нёдк, _jvv_, _mifk, 
   {{0x7ae8e791,0x31a4025a,0x6e28145e,0x443c01a4}},	//   _pyet, _rôzi_, îmbî, _mvv_, 
   {{0x853c0006,0xb3400724,0x3210002e,0x7ae8036e}},	//   rkėj, _öçen, _xuyy_, _qyet, 
   {{0x201002c4,0x7ae8e792,0x89a800d6,0x25800790}},	//   _kuxi_, _vyet, нків_, nçlı_, 
   {{0x7ae8e793,0xceb400ac,0x2008e794,0x00000000}},	//   _wyet, sbət_, _kici_, --, 
   {{0x7c24e795,0xceb40213,0xca240139,0x7ae8e796}},	//   mphr, mbər_, _әфти, _tyet, 
   {{0x200800a8,0x443ce797,0x7ae80117,0xbd040036}},	//   _mici_, _avv_, _uyet, _fréë, 
   {{0x2008e798,0x7c240381,0x3ce400bc,0x96b0012d}},	//   _lici_, ophr, _कडाइ_, इनबॉ, 
   {{0x7c24e799,0x777856df,0x50400092,0xceb403b9}},	//   nphr, _tawx, _ክልሎች, nbər_, 
   {{0x20080262,0xe72c026a,0x443c01f5,0xb6040306}},	//   _nici_, _ње_, _dvv_, dušň, 
   {{0xe2942b41,0xe56ce79a,0x2010003a,0x443c017a}},	//   вая_, _кз_, _auxi_, _evv_, 
   {{0x2008e79b,0xe5a0e79c,0x660801f5,0x443c0219}},	//   _aici_, _виши, _gifk, _fvv_, 
   {{0x20082d4f,0x2f54dfe6,0x2ea800dc,0xbfa001e1}},	//   _bici_, ктас, छन्त, _àpọn_, 
   {{0x200819a2,0x613c3279,0x2010919d,0x9f4c01a8}},	//   _cici_, _açlı, _duxi_, ögð_, 
   {{0x2008e79d,0x443c01f5,0x7648e79e,0xaf04e79f}},	// [140c0] _dici_, _zvv_, nrey, тпал, 
   {{0x2008003a,0x76483424,0xf1f8007b,0xcc14009d}},	//   _eici_, irey, _تعبت_, гчдө, 
   {{0x2008e7a0,0x7648e7a1,0x6bd41dc8,0xe0d40064}},	//   _fici_, hrey, پتار, _авэ_, 
   {{0xab280364,0x2008002e,0x09bc078a,0x7648033b}},	//   фода_, _gici_, ्च्य, krey, 
   {{0x98a4003a,0xda7402e8,0xaab433ae,0x00000000}},	//   manę_, вящ_, خصات, --, 
   {{0xdb08008c,0x20081271,0xec700451,0x27e417e2}},	//   rigð, _zici_, _پٿر_, _skon_, 
   {{0x2008e7a2,0x6608e7a3,0x7648e7a4,0x6b581180}},	//   _yici_, _rifk, erey, _ошар_, 
   {{0x7648e7a5,0x443c01f5,0x6a84104e,0x2fd00142}},	//   frey, _rvv_, _илба, nnyg_, 
   {{0xb8e81b37,0x27e40108,0x00000000,0x00000000}},	//   _ले_, _vkon_, --, --, 
   {{0x443c96eb,0x2fd00036,0x0578007b,0x449800d4}},	//   _pvv_, hnyg_, رمجة_, евою_, 
   {{0x7648e7a6,0x291c022f,0xa8541fbe,0xd6640150}},	//   arey, _ifta_, _штај, _ﺳﻴﻼﺭ_, 
   {{0x27e4e7a7,0x7648e7a8,0xa73835e6,0x660804ce}},	//   _ukon_, brey, _آثار_, _wifk, 
   {{0x66080135,0x7648e7a9,0x00000000,0x00000000}},	//   _tifk, crey, --, --, 
   {{0x2008e7aa,0xd6cc1ec7,0x7c2400b5,0x91a80208}},	//   _sici_, _بقه_, yphr, _địt_, 
   {{0x2008e7ab,0x035400fb,0xa4900244,0x68500240}},	//   _pici_, _йүнә_, _ئیجت, _ዘይሃስ, 
   {{0xdb0801b8,0xa34402d5,0xc3540e92,0x987800df}},	//   migö, _рэкл, _скиј, ואלט, 
   {{0x291ce7ac,0x7c2403a2,0x2008e7ad,0x80c0009e}},	// [140d0] _ofta_, wphr, _vici_, _শুশ্, 
   {{0x2008e7ae,0xeb9401b9,0x00000000,0x00000000}},	//   _wici_, ғиш_, --, --, 
   {{0x2008e7af,0x7648e7b0,0x7c240810,0x6ea801d9}},	//   _tici_, zrey, uphr, ونہہ_, 
   {{0x291c0bed,0xabb407dd,0x2008003a,0xfb34e7b1}},	//   _afta_, лахә, _uici_, ундэ, 
   {{0x8f080022,0xe85000d1,0x7c24035a,0x00000000}},	//   _ахра_, ەنىد, sphr, --, 
   {{0x661409a5,0x7648e7b2,0xdb180112,0x3ea80946}},	//   _çyky, vrey, _fluß, myat_, 
   {{0x4c944a2f,0x3ea80100,0x7648e7b3,0xceb406be}},	//   _кирс, lyat_, wrey, ncən_, 
   {{0x7648e7b4,0x291ce7b5,0xdb0803e0,0x00000000}},	//   trey, _efta_, digö, --, 
   {{0x3ea8e7b6,0x76481368,0xa378000d,0x7534009d}},	//   nyat_, urey, toõn, лэнх, 
   {{0x76489fbe,0x44cc013b,0x98c40f5c,0xceb4010f}},	//   rrey, _bɛ_, _исел, שיץ_, 
   {{0xf7544ce4,0xd774103c,0x7648e7b7,0x3ea8003e}},	//   _مناج, _لاشع, srey, hyat_, 
   {{0xc2083d99,0x3ea85101,0x44cc0134,0x824802d3}},	//   _זה_, kyat_, _dɛ_, _ኤውሮጳ, 
   {{0x29080077,0x76480113,0x80c00154,0xd6a80244}},	//   _ºbac_, qrey, _শুল্, _تدام_, 
   {{0x3ea8e7b8,0x44cc0134,0x7afc0306,0x91c400fb}},	//   dyat_, _fɛ_, _ústu, рҙол, 
   {{0xa064e7b9,0xe0403f07,0xe1fc012d,0x9fbc00fe}},	//   лара_, йнри, twór_, _আৱেগ, 
   {{0x224801ab,0x00000000,0x00000000,0x00000000}},	//   brck_, --, --, --, 
   {{0x3ea8e7ba,0x7f1802dd,0xdd8c00f1,0xdfcc00ae}},	// [140e0] gyat_, тісу_, ګول_, سيك_, 
   {{0x44cc1958,0x00000000,0x00000000,0x00000000}},	//   _yɛ_, --, --, --, 
   {{0xacf41614,0xdce401e4,0x291c007f,0xbc180212}},	//   учај, _tajĝ, _rfta_, вічі_, 
   {{0x7c64007b,0xdc5401d9,0xdca01d39,0xeb340633}},	//   شامل, ارٕک, љаци, اراخ, 
   {{0xa9a400c2,0xfe74e7bb,0x8cd039bc,0x0a940153}},	//   лидд, _күт_, _दशको, ралю, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xefbc0020,0x7c28e7bc,0x00000000,0x00000000}},	//   ሰጠው_, _čerg, --, --, 
   {{0xc7f40114,0x00000000,0x00000000,0x00000000}},	//   јзић, --, --, --, 
   {{0x44cce7bd,0xe96800d1,0xd7ec0454,0x00000000}},	//   _sɛ_, _паал_, _ҳу_, --, 
   {{0x24880201,0x44cc0605,0xa424010b,0x00000000}},	//   ንግሥት_, _pɛ_, льмл, --, 
   {{0xd7eca8e5,0xe1fc01e7,0xda6c00e5,0x00000000}},	//   _гу_, ltóg_, _وُہ_, --, 
   {{0x3ea8e7be,0x78b4013d,0x00000000,0x00000000}},	//   yyat_, _üzva, --, --, 
   {{0xd244010b,0x98a40118,0xa6c81de6,0xc59400d8}},	//   йэри, kaně_, _ялда_, _вилј, 
   {{0x44cc0085,0x069405d9,0xdf5021cb,0x00000000}},	//   _tɛ_, _ماڻھ, өнгө, --, 
   {{0xd48ce7bf,0x3ea8e7c0,0x2bf40882,0x104802bf}},	//   _ур_, wyat_, ेषां_, ляти_, 
   {{0x1adc009e,0x88440023,0x1b0803d4,0x00000000}},	//   বেয়া, _ከይተሰ, হঁতে_, --, 
   {{0x69c8e7c1,0x3ea80d04,0xcfe88b4d,0xde440023}},	// [140f0] kife, uyat_, افقه_, _ንክኸው, 
   {{0x3ea8e7c2,0x3f440208,0x00000000,0x00000000}},	//   ryat_, ỷu_, --, --, 
   {{0x3ea80a2e,0x61e4047e,0x00000000,0x00000000}},	//   syat_, mojl, --, --, 
   {{0x63ac02fb,0x61e4022e,0x545400df,0x00000000}},	//   nkcn, lojl, רסאן_, --, 
   {{0xceb403b9,0x00000000,0x00000000,0x00000000}},	//   ncəl_, --, --, --, 
   {{0x61e40960,0x69c8e7c3,0x98a40427,0x00000000}},	//   nojl, gife, žiču_, --, 
   {{0xb0640724,0x0a64001f,0x49b8e7c4,0x0b88013d}},	//   _itäç, _መግለጫ, داند_, _өсти_, 
   {{0x31d00b7c,0x69c8002d,0x81bc009e,0x61e4014f}},	//   _सद्ध, aife, েকি_, hojl, 
   {{0x69c8e7c5,0xf7700330,0x00000000,0x00000000}},	//   bife, ماک_, --, --, 
   {{0x69c8e7c6,0xb464e7c7,0x9f4801f1,0xc7641178}},	//   cife, акол, _chcú_, لاۋى, 
   {{0x81bc04c5,0x188800fd,0x00000000,0x00000000}},	//   েকা_, _ясап_, --, --, 
   {{0xb4d44802,0xb4e40248,0xbef40141,0x73e40107}},	//   _सखी_, _alàà, _आरंभ_, ромз, 
   {{0x0574e7c8,0x11440023,0x409401ec,0x00000000}},	//   _گاند, _ንምውዓ, ұртт, --, 
   {{0xb9dc069c,0x09ac02f5,0x61e4e7c9,0x66b8011a}},	//   _ኢኻ_, কোঠা, gojl, _במנה, 
   {{0x98a400bc,0x0574d204,0xfbb40b98,0x67d8031c}},	//   vaně_, _داند, ंसाम, lċja, 
   {{0x63ac0175,0x7e680356,0x3234030d,0x00000000}},	//   ckcn, _ţepa, _кхос, --, 
   {{0x69c89c78,0x6e44e7ca,0xed5806ed,0x9ea40334}},	// [14100] yife, شنام, коа_, авта_, 
   {{0x644c0005,0xdd1c00d7,0xf8140208,0x00000000}},	//   ábig, _píšu, _ước_, --, 
   {{0x98a40316,0xdd8c0532,0x69c81f47,0x30740354}},	//   raně_, ظوم_, vife, _тупс, 
   {{0xefb00517,0x6b641a71,0x69c802d0,0xeb500137}},	//   _بیرگ, ркда, wife, تۉرگ, 
   {{0x7c2800d0,0x5f7425ba,0xaab835cf,0x00000000}},	//   _čere, _ئاپر, خدار_, --, 
   {{0x39440223,0x2c7443bb,0x853c0153,0xceb406be}},	//   _cdls_, _پُرس, nkėt, ncəm_, 
   {{0xa378000d,0x00000000,0x00000000,0x00000000}},	//   klõp, --, --, --, 
   {{0x69c8e7cb,0xe7847fcc,0x4420031c,0xe66400cf}},	//   sife, руко, _ċi_, атоо, 
   {{0x61e46eb3,0x69c8e7cc,0x6b8003cb,0x00000000}},	//   yojl, pife, mdog, --, 
   {{0x6b80e7cd,0x996002fb,0xa504457e,0x00000000}},	//   ldog, píšu_, иянл, --, 
   {{0x61e4006c,0x7afc0313,0x00000000,0x00000000}},	//   vojl, _ústr, --, --, 
   {{0x6b80e7ce,0x561000ec,0x00000000,0x00000000}},	//   ndog, _ڀونء, --, --, 
   {{0x6674c0a1,0x6b8028a0,0x67200ca8,0x776c00e8}},	//   _خدار, idog, _ifoj, _ñaxa, 
   {{0x6488084c,0x05b4004b,0x00000000,0x00000000}},	//   _асиг_, _دمتح, --, --, 
   {{0xd5f80375,0x9fc48334,0x61e40455,0x00000000}},	//   _שפור, ащал, rojl, --, 
   {{0x200ce7cf,0x50400092,0x61e401e4,0xd3700e56}},	//   ögi_, _ክፍሎች, sojl, _قۇپ_, 
   {{0x61e4014f,0x00000000,0x00000000,0x00000000}},	// [14110] pojl, --, --, --, 
   {{0x75f0022e,0x6e2001e7,0x7aec0210,0x6b800171}},	//   _jаzо, íoba, żatk, edog, 
   {{0xdc0c00b8,0xe2a83345,0x5b34007b,0xfb141095}},	//   _aśān, _ساکن_, لعشر, مواج, 
   {{0xbab4010b,0x6b8000a2,0x00000000,0x00000000}},	//   йёлы, gdog, --, --, 
   {{0x60d80259,0x853c0024,0x00000000,0x00000000}},	//   ğumu, nkės, --, --, 
   {{0x67200241,0x7e7ce7d0,0x60d87225,0xa9a001b9}},	//   _afoj, _issp, şumu, зишд, 
   {{0x7e7c0175,0xb4d401bc,0x67d8031c,0x8cc4030d}},	//   _hssp, _सखे_, wċja, _мĕшĕ_, 
   {{0x69d800e5,0xdac400d1,0x00000000,0x00000000}},	//   _ejte, _پېتى_, --, --, 
   {{0x7bc8e7d1,0xa86800db,0x5a38030d,0x1ac800c0}},	//   _imeu, _ۅللۅ_, _шывă, _рувп_, 
   {{0x24880020,0x6720009a,0xb5789d3e,0x67d8003d}},	//   ንግስት_, _efoj, ущих_, rċja, 
   {{0x13a807d6,0xd90c01ed,0x98a800e2,0xe50800dc}},	//   لندی_, _کیں_, ēlēm_, _हृदि_, 
   {{0x7980e7d2,0x7e7c02d0,0x00000000,0x00000000}},	//   _halw, _ossp, --, --, 
   {{0x7980e7d3,0x7bc8009f,0x00000000,0x00000000}},	//   _kalw, _mmeu, --, --, 
   {{0x7980e7d4,0x41b40474,0x6ec01414,0x00000000}},	//   _jalw, осст, _रेगु, --, 
   {{0x7980e7d5,0x7e7ce7d6,0x29dc063f,0x6b800142}},	//   _malw, _assp, nịọs_, ydog, 
   {{0x79805f79,0x6434010f,0x44247b8f,0x00000000}},	//   _lalw, _פאפא_, _بروف, --, 
   {{0xd2048ef8,0x7f5c0175,0x59b401ad,0x798003ac}},	// [14120] _мүмк, _dcsq, _अतंर, _oalw, 
   {{0x7bc8e7d7,0x7980e7d8,0x00000000,0x00000000}},	//   _ameu, _nalw, --, --, 
   {{0x7e7c127b,0x3084007b,0x7c2801ef,0x00000000}},	//   _essp, _الجف, _čerc, --, 
   {{0x80c009bd,0x7980e7d9,0x332001a4,0xceb403b9}},	//   _শুক্, _aalw, nckx_, ncək_, 
   {{0x7980e7da,0xfd4c00a2,0x00000000,0x00000000}},	//   _balw, nilỳ, --, --, 
   {{0x7980011f,0x7bc80156,0x6b800ffb,0xa2f40375}},	//   _calw, _emeu, sdog, זמנה_, 
   {{0x78b403be,0x7980e7db,0x18a00b3e,0xa850010b}},	//   _üzvl, _dalw, зајм, чейә, 
   {{0x7980002d,0x77b40077,0x67fc0023,0x78a40037}},	//   _ealw, _páxa, këje, ähva, 
   {{0x7980bb16,0xa784249f,0x9a68004b,0x685002d3}},	//   _falw, لشکو, _مجلې_, _ዘይምስ, 
   {{0x7980e7dc,0xb8643c5b,0x7bc80311,0xe98815b4}},	//   _galw, _ژانو, _zmeu, _حضرو_, 
   {{0xe7841086,0x00000000,0x00000000,0x00000000}},	//   _гуло, --, --, --, 
   {{0x7980542c,0x6720e7dd,0xa804100b,0x75fc007f}},	//   _zalw, _ufoj, _узел, vèze, 
   {{0x7980e7de,0x600c0248,0x00000000,0x00000000}},	//   _yalw, _lòmì, --, --, 
   {{0x7e7ce7df,0x79800067,0x7aec068c,0x6808012d}},	//   _rssp, _xalw, üati, _nędz, 
   {{0xd48c444e,0xc1042abb,0xe9cc109a,0xdda80150}},	//   _эр_, زوري, ькi_, қтал_, 
   {{0xfd5801f2,0x7e7c05b1,0x23b80023,0x442c007f}},	//   _febụ, _pssp, _bëje_, mpd_, 
   {{0x6808006d,0xa28029e0,0x3d28036b,0x38540240}},	// [14130] _będz, _عیسو, لتای_, _ዘይቕበ, 
   {{0x81c801ed,0xdcb80108,0x00000000,0x00000000}},	//   _خطبہ_, лще_, --, --, 
   {{0x7980e7e0,0xd1b835ea,0x442c020c,0xbc74e7e1}},	//   _ralw, _دايا_, npd_, تهاب, 
   {{0x7980e7e2,0xba742dfc,0xdce40171,0x00000000}},	//   _salw, قاتت, _sajē, --, 
   {{0x4a440006,0x7980e7e3,0x00000000,0x00000000}},	//   знів, _palw, --, --, 
   {{0x798000fb,0xd23c011a,0x00000000,0x00000000}},	//   _qalw, נגול, --, --, 
   {{0x442c0098,0x7980ae99,0x00000000,0x00000000}},	//   jpd_, _valw, --, --, 
   {{0x7d4c0882,0x76240131,0x7bc8e7e4,0xf624e7e5}},	//   ṣyām, омиз, _umeu, одио, 
   {{0xe6143a22,0x7980e7e6,0xf0f4033f,0x66e001f0}},	//   оды_, _talw, _इर्द_, моъа, 
   {{0x35c80228,0x7980009a,0x00000000,0x00000000}},	//   ргоо_, _ualw, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7bd8016b,0x00000000,0x00000000,0x00000000}},	//   nnwu, --, --, --, 
   {{0x776802c4,0x332001f5,0x13a806ce,0x162402dd}},	//   mfex, rckx_, لنگی_, _ايتۋ_, 
   {{0x7aec0209,0xe69031f3,0x77680077,0x644c1ada}},	//   ýaty, _آلود, lfex, ábic, 
   {{0xfd580521,0x7dc806be,0xd0040150,0x00000000}},	//   _webụ, _gösə, зовқ, --, 
   {{0xfd58063f,0x6808033f,0x7768031c,0x00000000}},	//   _tebụ, _sędz, nfex, --, 
   {{0x7c280427,0x65b40356,0x6808033f,0xde2401a9}},	// [14140] _čera, _mâhn, _pędz, жжуд_, 
   {{0x7bd80204,0xd13001d9,0xf1d0009d,0x00000000}},	//   enwu, _سۅر_, _цөмө, --, 
   {{0xec981b88,0x645c00b0,0xec78e7e7,0xceb406be}},	//   штај_, _äpit, рпе_, nbəz_, 
   {{0x23b80de2,0x6808012d,0x00000000,0x00000000}},	//   _tëje_, _wędz, --, --, 
   {{0xceb801e0,0x888400f1,0x00000000,0x00000000}},	//   _уҙа_, ګیان, --, --, 
   {{0x776801f5,0x00000000,0x00000000,0x00000000}},	//   efex, --, --, --, 
   {{0xc7b80841,0xceb80131,0x7790009a,0x00000000}},	//   _luđe_, _тәң_, کینا, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x442ce7e8,0x28940640,0x42a400d1,0x996800e5}},	//   tpd_, _мјес, җумғ, _نجمہ_, 
   {{0x4614e7e9,0xd5b40212,0xb8c400cf,0x00000000}},	//   _کوتر, ісь_, _ىزمى, --, 
   {{0x8224025c,0x00000000,0x00000000,0x00000000}},	//   _འཕྱི_, --, --, --, 
   {{0x2a64003e,0x05940023,0x6e2000ae,0x00000000}},	//   ntob_, _ክገልጾ_, íobl, --, 
   {{0x442c089c,0x67542c26,0xfdb8000d,0x00000000}},	//   ppd_, _ایکس_, _इतेफ, --, 
   {{0x65b4025a,0x1fa4e7ea,0x5064009d,0xceb406be}},	//   _yâhn, ораг, мтта, mbəy_, 
   {{0xcf9815ed,0x7cd801e0,0x00000000,0x00000000}},	//   оју_, ҡмар_, --, --, 
   {{0x82240135,0x00000000,0x00000000,0x00000000}},	// [14150] _འཕྲི_, --, --, --, 
   {{0xdc8807b5,0x4d980500,0x9d2800c7,0xceb403b9}},	//   исел_, окую_, рцаз_, nbəy_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x307800c8,0xbbb42aa1,0x00000000,0x00000000}},	//   _פארנ, ंसेक, --, --, 
   {{0x720801ed,0x9e64e7eb,0x00000000,0x00000000}},	//   _خفیہ_, _باجن, --, --, 
   {{0x49c8109a,0xc9840063,0x527c010f,0x00000000}},	//   олін_, дући, ינדא, --, 
   {{0xbca486bf,0x00000000,0x00000000,0x00000000}},	//   _عمري, --, --, --, 
   {{0x09ac04c5,0x2a640ecf,0xb6a4084c,0x75fc0100}},	//   কোলা, btob_, зиил, dèza, 
   {{0x3868002e,0xf650007b,0x00000000,0x00000000}},	//   ŋar_, رئة_, --, --, 
   {{0x48a80b8d,0xe6140229,0x00000000,0x00000000}},	//   стәм_, ядь_, --, --, 
   {{0x845813f3,0xc7b81710,0x5edc00cc,0x00000000}},	//   орят_, _suđe_, _মৰমে, --, 
   {{0xd7f8e7ec,0x00000000,0x00000000,0x00000000}},	//   _туз_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7c280316,0x45400022,0x25bc116e,0x00000000}},	//   _čern, _иҕьа, chtl_, --, 
   {{0x65980a7c,0x00000000,0x00000000,0x00000000}},	//   _ליסק, --, --, --, 
   {{0xef18e7ed,0x65b400d2,0xc7b805ce,0x753000de}},	//   сма_, _lâhl, _tuđe_, ūdzē, 
   {{0x7a18007f,0x00000000,0x00000000,0x00000000}},	// [14160] _lňtb, --, --, --, 
   {{0x8cb81b87,0xf064e7ee,0x7de4e7ef,0x00000000}},	//   ऊनलो, _екоп, وسلم, --, 
   {{0xc7b8004d,0x00000000,0x00000000,0x00000000}},	//   _ktđt_, --, --, --, 
   {{0x161809d9,0xe1fce7f0,0x1af40154,0x2a64e7f1}},	//   नदार_, ntón_, েশনে_, ttob_, 
   {{0x32080109,0xa970013d,0x00000000,0x00000000}},	//   omby_, евлә, --, --, 
   {{0xfd9800fb,0x00000000,0x00000000,0x00000000}},	//   _мөхә_, --, --, --, 
   {{0xd78401e2,0x00000000,0x00000000,0x00000000}},	//   ړنيو_, --, --, --, 
   {{0x6d5c007d,0x2a64020c,0x7b0400e5,0x00000000}},	//   lgpa, ptob_, öttü, --, 
   {{0xe1fc02f0,0x00000000,0x00000000,0x00000000}},	//   dtón_, --, --, --, 
   {{0x6d5ce7f2,0x98a40421,0x273801fb,0xe1fc04d4}},	//   ngpa, ganē_, ẫn_, etón_, 
   {{0x44389b4c,0x7aec031c,0x00000000,0x00000000}},	//   èr_, żatt, --, --, 
   {{0x23b80240,0xa8048087,0x00000000,0x00000000}},	//   _bëja_, _эзел, --, --, 
   {{0xc0bc069d,0x00000000,0x00000000,0x00000000}},	//   _ተሾመ_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6578dcf3,0x10a40107,0x00000000,0x00000000}},	//   meth, ниён, --, --, 
   {{0x6578e7f3,0x32080109,0x6d5c0af9,0xc5f800e2}},	//   leth, amby_, egpa, llē_, 
   {{0x65780204,0xdb1800d8,0x6fc407f7,0x13f40354}},	// [14170] oeth, _fluê, रोइं, _язъя, 
   {{0x65780944,0xdce40055,0x6d5c0423,0x64580175}},	//   neth, _abjā, ggpa, outi, 
   {{0x6458e7f4,0x03c400dc,0xbc640022,0x00000000}},	//   nuti, _śeṣa, ьхақ, --, 
   {{0x65781253,0x64589c81,0xdb2001b9,0x00000000}},	//   heth, iuti, روتی, --, 
   {{0x6578136f,0xc5f800da,0xe1fc002e,0xb7b40051}},	//   keth, klē_, ntóo_, _bụn, 
   {{0x64588362,0x6578e7f5,0x3f88e7f6,0x81bc00fe}},	//   kuti, jeth, ldau_, েকক_, 
   {{0x6458e7f7,0x657859fc,0x0ca83946,0xb7b401fb}},	//   juti, deth, _етти_, _dụn, 
   {{0x3f88e7f8,0x6458e7f9,0x58000131,0xceb40213}},	//   ndau_, duti, رۈشك, tbəx_, 
   {{0x6578e7fa,0xdce40006,0x3f880142,0x00000000}},	//   feth, _pajė, idau_, --, 
   {{0x6578e7fb,0x6458e7fc,0x3a2c0598,0x363c0023}},	//   geth, futi, _itep_, _ሓደገኛ, 
   {{0x6458e7fd,0x9f48012c,0x3f98e7fe,0x3f880064}},	//   guti, _akcí_, _onsu_, kdau_, 
   {{0x657803cb,0x00000000,0x00000000,0x00000000}},	//   aeth, --, --, --, 
   {{0x65780928,0x3f880cfd,0xe1fce7ff,0x6458e800}},	//   beth, ddau_, rtón_, auti, 
   {{0x65780214,0xe1fcb9f0,0x3f8804cc,0x3f98e801}},	//   ceth, stón_, edau_, _ansu_, 
   {{0xc7b80016,0x7afc168c,0xe1fc01d3,0x645c0139}},	//   _ttđt_, _østf, mtól_, _äpip, 
   {{0xee380111,0x3a2c079b,0xe1fc00e5,0x00000000}},	//   жна_, _otep_, ltól_, --, 
   {{0xe80c00cd,0x00000000,0x00000000,0x00000000}},	// [14180] ागता_, --, --, --, 
   {{0x3f880f7b,0x3f9804ba,0xe1fc01d3,0x2c7c01ef}},	//   adau_, _ensu_, ntól_, _půd_, 
   {{0x3a2c0e4f,0xab84a440,0xab640229,0x3f88e802}},	//   _atep_, дулк, двел, bdau_, 
   {{0x3a2c03a2,0x00000000,0x00000000,0x00000000}},	//   _btep_, --, --, --, 
   {{0x6578e803,0xe1fc01ed,0x6458cd3e,0xee0801ec}},	//   yeth, któl_, zuti, _мемл_, 
   {{0x64580cfe,0x291800fe,0x00000000,0x00000000}},	//   yuti, øpa_, --, --, 
   {{0xab281c26,0x3a2c0139,0x6d4c0857,0x6458005a}},	//   _мова_, _etep_, _idba, xuti, 
   {{0x6458e804,0x6578e805,0xd7f40220,0x6d4c0208}},	//   vuti, weth, муы_, _hdba, 
   {{0x6578e806,0x6e200491,0x6458e807,0xe9d800a7}},	//   teth, íobh, wuti, _дка_, 
   {{0xdb18067c,0xe1fc01d3,0x1ae03866,0x00000000}},	//   _aluè, gtól_, _роум, --, 
   {{0xd7ec28cf,0x6458e808,0x3f8800a9,0x6d4c05b1}},	//   _ау_, uuti, ydau_, _mdba, 
   {{0x6458e809,0x6578e80a,0xa3780254,0x3a2c0166}},	//   ruti, seth, knõe, _ytep_, 
   {{0x6d4c1326,0x64580af5,0xe5c4e80b,0x7a18007f}},	//   _odba, suti, _оско, _kňta, 
   {{0x31a406d9,0x5ec40154,0x7f8407d6,0x3f8803cb}},	//   _kôzy_, লপমে, کلرن, wdau_, 
   {{0x6458e80c,0x69c40006,0xe1fc00e8,0x00000000}},	//   quti, _įkel, stóo_, --, 
   {{0x98a408a4,0x6d4c127b,0x7afcce46,0x53440022}},	//   žiću_, _adba, _østg, _ихьа, 
   {{0x443c0211,0x3f88e80d,0x4cdc00cc,0x00000000}},	// [14190] _hwv_, rdau_, _ভৰলু, --, 
   {{0x443c0457,0x6d4c030d,0xa1440014,0x3f8805d5}},	//   _kwv_, _cdba, _زیرٕ_, sdau_, 
   {{0x3a2ce80e,0x8d7433d2,0xfff80066,0x00000000}},	//   _step_, خاقا, _فکرت_, --, 
   {{0x3f9802a8,0x6d4c0857,0x7a180432,0x628c00d7}},	//   _unsu_, _edba, _aňta, ovco, 
   {{0x443c01d4,0xdce40171,0x00000000,0x00000000}},	//   _lwv_, _kajī, --, --, 
   {{0x644803b2,0xdce400b8,0xd2b8011a,0x89a800d4}},	//   _ovfi, _jajī, ולדת_, мків_, 
   {{0xc7b8107d,0x62880142,0xe85000f1,0x4c1400f7}},	//   _suđa_, _âgof, هنود, ربۅس, 
   {{0x31a40109,0x3a2c020b,0x5c040006,0x00000000}},	//   _dôzy_, _ttep_, _цяга, --, 
   {{0x443c0175,0xf77028c4,0xe1fc01d3,0xe72c01e0}},	//   _awv_, ناک_, ttól_, _ҙе_, 
   {{0x77b474c3,0x443c05ac,0x49740b3e,0xdedc0092}},	//   _máxi, _bwv_, _илус, ናልና_, 
   {{0xdb18180f,0xe1fce80f,0xceb403b9,0x00000000}},	//   _pluè, rtól_, ncər_, --, 
   {{0xceb40cc1,0xc7b807f5,0xfaf8003e,0xe1fc50aa}},	//   yyə_, _tuđa_, _kyū_, stól_, 
   {{0x7afc01bf,0xe1fc01d3,0xe3b0178c,0x453000db}},	//   _østd, ptól_, ارپ_, دۉۉر, 
   {{0x443c0211,0x764803ee,0x260404af,0x00000000}},	//   _fwv_, msey, _सीपी_, --, 
   {{0x7648e7a9,0xafe4399f,0xaf9400d8,0x00000000}},	//   lsey, еовл, ншај, --, 
   {{0x1fa40353,0x7648062c,0x00000000,0x00000000}},	//   нкси_, osey, --, --, 
   {{0x7648e810,0x2bb405dc,0xed5807a5,0x00000000}},	// [141a0] nsey, _अकबा, зоз_, --, 
   {{0x443c01d4,0xcf480150,0xefc80092,0x00000000}},	//   _ywv_, _ءدﯨﻨ, በቂያ_, --, 
   {{0x443c0211,0x527406b3,0x35840023,0x98a40153}},	//   _xwv_, _чуқу, ክሮታት_, manė_, 
   {{0x7c640131,0x6aa0005a,0xd1e8001f,0xf3e003d4}},	//   ئالل, txof, ዙዎች_, _গীতৰ_, 
   {{0x6d4c0175,0xdb080036,0x62880525,0xdce400cd}},	//   _tdba, chgü, _ágot, _yajī, 
   {{0x31a40109,0x7a180100,0x6aa000cf,0x00000000}},	//   _pôzy_, _pňta, rxof, --, 
   {{0x32180109,0x307800c8,0x764800ad,0xca2801ec}},	//   _mipy_, לאַנ, esey, _ﺤﺸﺩ_, 
   {{0x2d88e811,0x32185f0b,0x764802d2,0x00000000}},	//   _habe_, _lipy_, fsey, --, 
   {{0x2d88e812,0x32180124,0xd6d4084c,0x64480254}},	//   _kabe_, _oipy_, етэ_, _svfi, 
   {{0xb5fc7483,0x2d8801c0,0x443c009a,0x80b4012d}},	//   ntšh, _jabe_, _pwv_, ोईमे, 
   {{0x2d883d81,0xb8640fb4,0xf8ace813,0x46d000e1}},	//   _mabe_, _لانو, _тө_, _तेरह, 
   {{0x2d88e814,0x443c020c,0x7648e815,0xdce400b8}},	//   _labe_, _vwv_, bsey, _sajī, 
   {{0x2d8804cc,0xdb080ade,0x76480076,0x12e401ec}},	//   _oabe_, ckgä, csey, гірг, 
   {{0x7afc11c0,0x443c0070,0x628ce816,0x04f428e8}},	//   _øste, _twv_, rvco, _излю, 
   {{0x443c0d27,0x98b007f5,0x32180866,0x68f800a2}},	//   _uwv_, čeća_, _dipy_, _jytd, 
   {{0x77b46bf8,0x2d880014,0xb60002d2,0x78a40254}},	//   _páxi, _aabe_, _íárb, ähvi, 
   {{0x2d88e817,0x80d002ab,0x2b44030a,0xbe1800d4}},	// [141b0] _babe_, _डेरे, daoc_, джає_, 
   {{0x9ce405f1,0xe8800020,0xfaf80165,0x291c0208}},	//   нцел, ረተሰቡ_, _ryū_, _ngta_, 
   {{0x2d88e818,0x68f80481,0xdce4012d,0xd0d401f0}},	//   _dabe_, _nytd, _obją, _боэъ, 
   {{0x8c540f1b,0x291c0280,0x77b40798,0x2b440165}},	//   ائلا, _agta_, _táxi, gaoc_, 
   {{0x68f83946,0x933c0023,0x0fe40f15,0xab6000d1}},	//   _aytd, _ጠንቅታ, _сөрү, شۇلى, 
   {{0x2d880323,0x6ab40158,0x764c03e3,0x76480205}},	//   _gabe_, øyfa, _çiyə, vsey, 
   {{0x7e6ce819,0xda9001c6,0x00000000,0x00000000}},	//   ltap, _өгвө, --, --, 
   {{0x2d8823db,0x7648e81a,0xaad01223,0x7e6c00b0}},	//   _zabe_, tsey, _देवक, otap, 
   {{0x7e6ce81b,0x97a41945,0xe1fc03b2,0x26c80115}},	//   ntap, _үрел, gtók_, ŝbon_, 
   {{0x7648e81c,0x7e6ce81d,0xe1fc0210,0xf428009d}},	//   rsey, itap, stój_, моол_, 
   {{0x7648e81e,0x7afc00ed,0x2bf403d4,0xca240150}},	//   ssey, _østb, েদৰে_, _ﹼﺩﺕ_, 
   {{0x7e6ce81f,0xdb0408a5,0x00000000,0x00000000}},	//   ktap, _ámót, --, --, 
   {{0x32180109,0x7ae8002e,0x7e6c0309,0x76480784}},	//   _pipy_, _jxet, jtap, qsey, 
   {{0xdb180137,0xb8840241,0xe1fc011f,0xa52000db}},	//   _lluï, _gríì, ntóh_, _кмшд, 
   {{0xa064e820,0x2d88e821,0x21a09f91,0x7e6c000d}},	//   кара_, _rabe_, ширм, etap, 
   {{0x2d881a36,0x7ae80356,0x7e6ce822,0x00000000}},	//   _sabe_, _oxet, ftap, --, 
   {{0x7e6c1089,0x321803c6,0xdd8c05d9,0x2b4401fa}},	// [141c0] gtap, _tipy_, ڪول_, vaoc_, 
   {{0x2d88e823,0x00000000,0x00000000,0x00000000}},	//   _qabe_, --, --, --, 
   {{0xdd8ce824,0xf8a4db01,0x628825e6,0x7e6c0113}},	//   تول_, _اک_, _ágor, atap, 
   {{0x9bc800aa,0x2d880173,0xe1fc011f,0xdca007b5}},	//   ودنې_, _wabe_, ytók_, јаци, 
   {{0xaad037e3,0x7e6ce825,0x2d88e826,0x46d00ce0}},	//   _देशक, ctap, _tabe_, _तेंह, 
   {{0x2d8801e4,0x6e340fac,0x26040037,0x00000000}},	//   _uabe_, mpyb, _सीढी_, --, 
   {{0xdca0e827,0x7ae8e828,0x25ace829,0x83fc2220}},	//   _кари, _exet, _rofl_, luđe, 
   {{0xe7b00490,0xe1fce82a,0x98a00114,0x752c008e}},	//   _जवळप, ttók_, риће, _ğaza, 
   {{0xb5fc1ebd,0x83fc0989,0x7c28549d,0x752c010b}},	//   ntšw, nuđe, _čeri, _şaza, 
   {{0x291c0548,0x787005d9,0xe1fce82b,0x00000000}},	//   _ugta_, _ڇڏيا, rtók_, --, 
   {{0xd78400aa,0x7e6c01c6,0xa764810e,0x00000000}},	//   رنیو_, ztap, _акед, --, 
   {{0x83fc05be,0x232401b9,0x7e6c0986,0xf8ac00e5}},	//   kuđe, ъфог, ytap, _ءکو_, 
   {{0x27e40086,0x83fc96c0,0xf7481ec7,0xa6c80daf}},	//   _ijon_, juđe, _سجنه_, _юлда_, 
   {{0x1674011a,0x00000000,0x00000000,0x00000000}},	//   _סגול_, --, --, --, 
   {{0x4394152d,0xb5fc27c4,0x2fc03223,0x7e6ce82c}},	//   _байс, etšw, _blkg_, wtap, 
   {{0x7e6ce82d,0x64580960,0x776c0de2,0x9f5c00e5}},	//   ttap, mrti, _ñaxt, _örül_, 
   {{0x7e6ce82e,0xe1fc011f,0x3e3400db,0x53f8007b}},	// [141d0] utap, ytóh_, افئر, _جروح_, 
   {{0x7e6ce82f,0x64580eda,0x11f800f1,0x75fc007f}},	//   rtap, orti, _ټوپک_, vèzk, 
   {{0x27e401e4,0xf42801f4,0x00000000,0x00000000}},	//   _ojon_, myää_, --, --, 
   {{0x7e6ce830,0x64581c1d,0x83fc1b24,0x27e401a6}},	//   ptap, irti, buđe, _njon_, 
   {{0xb5fc03c6,0x7e6c1bb7,0xe1fc011f,0x64580112}},	//   luše, qtap, ttóh_, hrti, 
   {{0x27e4005b,0xda6000ec,0x00000000,0x00000000}},	//   _ajon_, هاڙي, --, --, 
   {{0xdb680220,0x3ea80311,0x2604033f,0x49b8158b}},	//   _орал_, ţită_, _सीधी_, خاند_, 
   {{0x7ae864cb,0xda6405d9,0x64580010,0x8ee403d4}},	//   _txet, _لائي, drti, _মৰিগ, 
   {{0x9964e831,0x6458e832,0x0a6801c0,0x7878032e}},	//   _ател, erti, _архи_, _búvö, 
   {{0xb5fc4d3c,0x7bd8e833,0x27e400df,0x4ae401b9}},	//   kuše, liwu, _ejon_, _тўса, 
   {{0x27e40158,0xd8742088,0xddc800b8,0x00000000}},	//   _fjon_, _جاذب, _śiśa, --, 
   {{0xdb1800f7,0xe1fc0034,0xb5fc1b5c,0x27e40023}},	//   _lluí, otów_, duše, _gjon_, 
   {{0x64580af5,0xe1fc068f,0x39442045,0xe294e834}},	//   arti, ntów_, _kels_, гая_, 
   {{0x7bd8090c,0xf1cc0034,0x200402b1,0x394401bf}},	//   hiwu, होंन, _īnia_, _jels_, 
   {{0x057427ba,0x3944e835,0x7bd8e836,0xb5fc07f5}},	//   _خاند, _mels_, kiwu, guše, 
   {{0xe1fc068f,0x20080316,0x3944e837,0x75fc007f}},	//   któw_, _chci_, _lels_, dèzi, 
   {{0xaf04188c,0x394401f7,0x76540034,0xdb1800c7}},	// [141e0] упал, _oels_, ązyw, _omuñ, 
   {{0x5d645211,0xe28000c7,0x00000000,0x00000000}},	//   лиум_, _ульи, --, --, 
   {{0x83fc041a,0x6e3402d0,0x0c780092,0xe1fc0210}},	//   suđe, spyb, _አጋሮች_, etów_, 
   {{0xdb181bce,0xab2812b4,0x6e34e838,0x7bd8e839}},	//   _amuñ, хода_, ppyb, giwu, 
   {{0xdb18e83a,0x3944e83b,0x752c013d,0xeab801c4}},	//   _fluí, _bels_, _ğazn, эйд_, 
   {{0x7c2803c6,0xfcf002d3,0x6458e83c,0xed500014}},	//   _červ, ግላጽ_, yrti, _دپس_, 
   {{0x3944e83d,0x1d0439f4,0xb5fc000a,0x6e24113c}},	//   _dels_, _бери_, ntšu, _hukb, 
   {{0x3944039a,0x6e24e83e,0x64582e31,0x7bd80210}},	//   _eels_, _kukb, vrti, ciwu, 
   {{0x39440086,0x6b800998,0x6e2401f5,0x64580009}},	//   _fels_, meog, _jukb, wrti, 
   {{0x6b80b9fc,0x45d4e83f,0x645809a8,0x7afc12ed}},	//   leog, роос, trti, _østa, 
   {{0x6e24b35f,0x64580067,0x4aa4000d,0xd4940395}},	//   _lukb, urti, _गऊँव, гря_, 
   {{0x6b80e840,0x6458e841,0x27e4e842,0x5c94010f}},	//   neog, rrti, _ujon_, אכטע_, 
   {{0x39442045,0x64580113,0xa574592e,0x75d400ec}},	//   _yels_, srti, _مُشت, _ھيٺا, 
   {{0xb5fc1ebd,0x6b800280,0x6458151c,0x7bd8e843}},	//   tuše, heog, prti, ziwu, 
   {{0x67200770,0x23b8002e,0x7bd801f0,0x83fc01a6}},	//   _kgoj, _lëji_, yiwu, ruđb, 
   {{0xb5fc04bf,0x6e24020c,0xfd6802e3,0x6b80e844}},	//   ruše, _bukb, bapụ, jeog, 
   {{0x6b80e845,0x141c0302,0xb5fc19d6,0x00000000}},	// [141f0] deog, _אוהב, suše, --, 
   {{0x21642d1f,0x7bd80086,0xb5fc0e04,0x5cc4008e}},	//   _стиг, wiwu, puše, лсез, 
   {{0x39440175,0x8de8e846,0x6720917b,0x3cd400d8}},	//   _rels_, уфта_, _ogoj, јжес, 
   {{0x6720e847,0x39440225,0x7f9405f5,0x23b80200}},	//   _ngoj, _sels_, _тамх, _bëji_, 
   {{0x3944e848,0x98a4e849,0x7ea40075,0xb5fc0841}},	//   _pels_, panī_, _тунҗ, nušc, 
   {{0x6720010f,0x2c5c02e3,0x7e7c00e4,0xe1fc0034}},	//   _agoj, _ọdee_, _ipsp, rtów_, 
   {{0xe1fc006d,0xfb8806ba,0x5b340d17,0x394400f3}},	//   stów_, _ирақ_, _معذر, _vels_, 
   {{0x3944e84a,0x1b340020,0x656808c2,0x7c3402d0}},	//   _wels_, ርስቲያ, _acfh, _itzr, 
   {{0x3944e84b,0x3ea8905e,0x9aa001d9,0xb5c404a9}},	//   _tels_, nxat_, _دۅشو, ийил, 
   {{0xca74021a,0x7e7c05b1,0x3ea800db,0x67200200}},	//   _دافغ, _mpsp, ixat_, _egoj, 
   {{0xd774129d,0xfd6802e3,0x656c08c2,0xf5040a5b}},	//   _ماشع, wapụ, òbha, рзно, 
   {{0x7e7ce84c,0x3ea80054,0xb60000bc,0xf21c033f}},	//   _opsp, kxat_, _řáde, _यूज़_, 
   {{0x75d4e84d,0xe7940214,0xc2c400ec,0x35a40153}},	//   _پيغا, _خالک, ميٽي, _валг, 
   {{0x321c005b,0x6b8068f2,0x6140011c,0x6654010a}},	//   öty_, zeog, жера, _ташă, 
   {{0x6e24e84e,0x7e7c005f,0x6b80009f,0xe0d4e84f}},	//   _sukb, _apsp, yeog, авр_, 
   {{0xa0640a16,0x6b80a7b1,0xcf2401ec,0x4374010a}},	//   јата_, xeog, спақ, _луьт, 
   {{0xef18b849,0x83640eff,0xed4400f3,0xad6800c7}},	// [14200] тма_, _ادىل, инап, кааз_, 
   {{0xdd8ce850,0x0b68001f,0x6b80020c,0x80d028fe}},	//   ووق_, ተዳድር_, weog, _डेके, 
   {{0x6b80e851,0xac841952,0x7e7c02d0,0xddf800fd}},	//   teog, ргел, _epsp, тьтә_, 
   {{0x7c2802fb,0x22900066,0x00000000,0x00000000}},	//   _čert, _الیس, --, --, 
   {{0x83fc041a,0x6e240472,0x0a940006,0x00000000}},	//   nuđa, _uukb, салю, --, 
   {{0x2bc00490,0xe294008f,0xed5801c6,0x00000000}},	//   _शतका, יכנט_, _шог_, --, 
   {{0x7afc0fac,0x2918e852,0xae040150,0x6b800254}},	//   _østn, äpa_, _موڭى, peog, 
   {{0xcdc402f4,0x656800b5,0xb7c402dd,0x389400ef}},	//   _таҳқ, _scfh, йрық, _dār_, 
   {{0xe9a4a6d1,0xa9a401ee,0x00000000,0x00000000}},	//   _каап, _киад, --, --, 
   {{0x28740c98,0x9c6000f1,0x06e80154,0x00000000}},	//   _выдр, _دهېو, _পরদি, --, 
   {{0x4394e853,0xc7b8107d,0x00000000,0x00000000}},	//   банс, _luđi_, --, --, 
   {{0xe738e854,0xa258025a,0x6720009b,0xbb3c0023}},	//   _ред_, nyôg, _ugoj, _ስቱትጋ, 
   {{0xe1fc011f,0x3ea8e855,0x00000000,0x00000000}},	//   któt_, xxat_, --, --, 
   {{0x7f940588,0x69c80007,0x6db8008f,0x61401183}},	//   әаах, nhfe, nĝaĵ, تىسە, 
   {{0x7e7c0175,0x6ab40217,0x521400d3,0x00000000}},	//   _spsp, øyfj, ідст, --, 
   {{0xb5fce856,0x6d4801a8,0x3ea800db,0x0b28015b}},	//   muša, ðfan, txat_, মরুল_, 
   {{0x0b680201,0x00000000,0x00000000,0x00000000}},	// [14210] ተዳደር_, --, --, --, 
   {{0xc0c42123,0x3ea81999,0x8d74027d,0x00000000}},	//   _ләби, rxat_, قاما, --, 
   {{0x40940597,0x7c280232,0x69c80158,0x1724031c}},	//   _الجر, _čers, dhfe, _ལྔའམ_, 
   {{0xdc5c02d3,0x0c24e857,0x0b58443f,0xa2c8e858}},	//   _ዳግማይ_, імін, аршы_, हनप्, 
   {{0x7f4ce859,0x442c0175,0x7e7c035a,0xdb2008a5}},	//   maaq, hqd_, _upsp, _þríh, 
   {{0xb5fc05ce,0x7f4ce85a,0x3894005f,0x69c800ae}},	//   kuša, laaq, _pār_, ghfe, 
   {{0xb5fc00da,0x61e803b2,0x00000000,0x00000000}},	//   juša, _íglu, --, --, 
   {{0x7f4ce85b,0xf770e85c,0x7afc0ec3,0xb5fc0171}},	//   naaq, ساب_, _østo, duša, 
   {{0xe1fce85d,0x7f4c0194,0xb38401e0,0xc76419c5}},	//   ntós_, iaaq, ҡлол, زايى, 
   {{0x7f4c0d04,0x69c8e85e,0xe1fc381a,0x2edc01e1}},	//   haaq, chfe, itós_, _jíjẹ_, 
   {{0xe294052f,0x7f4c2ece,0x69f800c8,0xb5fc005f}},	//   ҙар_, kaaq, _עלעק, guša, 
   {{0x490401d5,0x7f4ce85f,0xe29400c7,0x00000000}},	//   _بومق, jaaq, әар_, --, 
   {{0x7768014b,0x7f4c4091,0xe1fc30f9,0x1af4015b}},	//   mgex, daaq, ytót_, েশকে_, 
   {{0x38680227,0xb5fc16a3,0x00000000,0x00000000}},	//   ńaru_, buša, --, --, 
   {{0x4094e860,0x2f548715,0x63ac0175,0x7f4c0067}},	//   ортт, йтас, bjcn, faaq, 
   {{0x7768e861,0x7f4ce862,0x29c001a8,0x644c031c}},	//   ngex, gaaq, _aðal_, ġbit, 
   {{0xafc401ec,0x00000000,0x00000000,0x00000000}},	// [14220] _ۇيدى, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdaf00003,0x7f4c2521,0xa73001e1,0xe1fc31b7}},	//   _བཙུཌ_, baaq, _fọhù, rtót_, 
   {{0xc7b807f5,0xe1fc004e,0x80241fcb,0x29c0032e}},	//   _tuđi_, btós_, _گریم, _eðal_, 
   {{0xaad02aa1,0x7afce863,0x69c8e864,0x2e4001d3}},	//   _देखक, _østl, thfe, _رہاہ, 
   {{0xa37800d8,0x80241fb8,0x00000000,0x00000000}},	//   miõe, _دریم, --, --, 
   {{0x88841416,0xa3780798,0x313c0023,0x00000000}},	//   تیان, liõe, ክታቶር, --, 
   {{0x7768011f,0x69c8e865,0x7d002b96,0x6b640209}},	//   ggex, shfe, _ølsa, _ыкба, 
   {{0xa3780261,0xb63012ea,0x999c010e,0x779035cf}},	//   niõe, وکوش, _utuş_, بینا, 
   {{0xfcf0044e,0xa9e401b9,0xb5fc00e2,0xadf805dc}},	//   ግጋጽ_, _اثرن, tuša, ्तिन_, 
   {{0x26c0e866,0x69d8e867,0x7f4ce868,0xf8ac05d9}},	//   ško_, _imte, yaaq, _لکي_, 
   {{0x442c0175,0x7f4c0009,0x67000ca8,0x00000000}},	//   rqd_, xaaq, _ọkun, --, 
   {{0x7f4c0cfe,0xadf8141f,0xb5fc0010,0x00000000}},	//   vaaq, ्तान_, mušn, --, 
   {{0xb5fc0232,0x7f4c0050,0x4614e869,0xd55000a7}},	//   lušn, waaq, _بوتر, _екшъ, 
   {{0x7f4ccad7,0x2a6405d5,0xa18401e0,0x0488013d}},	//   taaq, huob_, _һынл, _тәпи_, 
   {{0x543804ac,0x00000000,0x00000000,0x00000000}},	//   _געהא, --, --, --, 
   {{0x7f4ce86a,0xa3780261,0xa5240135,0x69d803cd}},	// [14230] raaq, giõe, _རྔོག_, _omte, 
   {{0x7f4ce86b,0xe1fc01d3,0xeae003d4,0xdca400db}},	//   saaq, rtós_, _বৰ্ম, йшеп, 
   {{0xb5fc0f72,0x7f4c0194,0xe1fc67c1,0xd13800c7}},	//   kušn, paaq, stós_, _ухы_, 
   {{0xf8a8034c,0x7f4c0050,0x69d8e86c,0x7bf812c1}},	//   یگاه_, qaaq, _amte, шнер_, 
   {{0x69d80175,0x1ee43267,0x00000000,0x00000000}},	//   _bmte, _طوسی_, --, --, 
   {{0xdb180137,0x3858e1fb,0x8328031c,0x7afc00d4}},	//   _lluç, арию_, _རུའུ_, _østm, 
   {{0xa2d80a8a,0xe1fc0008,0x00000000,0x00000000}},	//   _पेस्, próf_, --, --, 
   {{0xb5fc01a6,0xdeb80092,0xf98800f1,0x984801ec}},	//   gušn, _ሰሞን_, انګي_, _ұяда_, 
   {{0xb7b401f2,0x8b88516c,0x69d801f4,0x00000000}},	//   _bụr, _دەنە_, _fmte, --, 
   {{0xb5fc1fe6,0x7bc805c7,0xdb1800fd,0x8a1800d8}},	//   krše, _hleu, _aluç, _гоус_, 
   {{0x7bc8c55f,0xb5fc2aac,0x13a808cf,0x98c41b55}},	//   _kleu, bušn, مندی_, _усал, 
   {{0xc0ec001f,0x248c04cc,0xe7945226,0xab640254}},	//   ቀነስ_, _dsfm_, _وانک, mtüü, 
   {{0x09bc00cc,0x00000000,0x00000000,0x00000000}},	//   _অগতা, --, --, --, 
   {{0x83fc098d,0x7bc8e86d,0xa37800d8,0x0708009f}},	//   vrđe, _lleu, viõe, _ايهي_, 
   {{0x7bc8e86e,0x550401d5,0xab640254,0xb5fc00c0}},	//   _oleu, _учда, ntüü, lušo, 
   {{0x7c280232,0x6fd8012c,0x00000000,0x00000000}},	//   _čerp, můck, --, --, 
   {{0xb5fc702b,0x0ec40456,0x00000000,0x00000000}},	// [14240] nušo, लैंड, --, --, 
   {{0xad642f84,0x71580276,0xb5fc0010,0xed588f47}},	//   تاره, _трис_, brše, рож_, 
   {{0x7bc8e86f,0x6c842aa5,0xa37806ed,0x7afc037e}},	//   _bleu, تلام, siõe, _østj, 
   {{0x2d080574,0x7bc8062c,0x69d80334,0xa3780798}},	//   _वरील_, _cleu, _smte, piõe, 
   {{0xb5fc00e2,0x00000000,0x00000000,0x00000000}},	//   jušo, --, --, --, 
   {{0x7bc8e870,0xd9d40212,0x657c0205,0xe1fc00ae}},	//   _eleu, омії_, _ıpho, rróg_, 
   {{0x7bc8e871,0x98a00063,0x00000000,0x00000000}},	//   _fleu, дије, --, --, 
   {{0x7bc8e872,0x17f400c6,0x78a400d4,0x00000000}},	//   _gleu, يرية_, åhva, --, 
   {{0xa968e873,0xb7b4063f,0xb5fce874,0xa9740114}},	//   _виза_, _pụr, rušn, _мужј, 
   {{0xb5fc16a3,0xe80816f0,0x69d8009f,0xdb180139}},	//   sušn, _हीरा_, _umte, _sluç, 
   {{0x4438e875,0xb5fc24dd,0x96b400f2,0xc0ec0092}},	//   ër_, pušn, مایز_, ቀነሰ_, 
   {{0xb5fce876,0x18640120,0x00000000,0x00000000}},	//   vrše, _фаци_, --, --, 
   {{0x671419e5,0xa2d800bc,0xa694033a,0x04fc00eb}},	//   देशक_, _पेश्, _фреј, ুখের_, 
   {{0x56800014,0x00000000,0x00000000,0x00000000}},	//   _کۯیہ, --, --, --, 
   {{0xc10400c6,0x10a43edf,0xb61802dd,0x00000000}},	//   سوري, миён, _ﹼﺭ_, --, 
   {{0xc7b81050,0xe1fc01e7,0xdb180205,0xbbb8000d}},	//   _tuđu_, atóp_, _uluç, _आवेक, 
   {{0x6578127b,0x00000000,0x00000000,0x00000000}},	// [14250] ofth, --, --, --, 
   {{0x7bc8e877,0x629c0113,0x9e041cd0,0x00000000}},	//   _sleu, _irqo, ічал, --, 
   {{0x7bc8e878,0xb5fc7edf,0x051c00fe,0x00000000}},	//   _pleu, dušl, পুৰৰ_, --, 
   {{0x70f80302,0x5fa0192c,0x7afc08cb,0xe8080406}},	//   _להתח, _تەرم, _østk, _हीला_, 
   {{0x7bc8e879,0xda1004d3,0x3f88e87a,0x539c08a8}},	//   _vleu, وستک, meau_, ייאו, 
   {{0x3f882a78,0xb5fc01a6,0x956c0023,0x00000000}},	//   leau_, gušl, ባታትን_, --, 
   {{0x4c680364,0x5fbc05c0,0xa9640395,0x00000000}},	//   _миён_, _एकाल, чища_, --, 
   {{0x3f88e87b,0x629c02d1,0x7bc801f7,0x9a842c11}},	//   neau_, _orqo, _uleu, _музл, 
   {{0xb5fc09a8,0xab6400af,0xa2d8190e,0x00000000}},	//   vršb, stüü, _पेल्, --, 
   {{0xb5fc268d,0x49b8e87c,0xc0d00023,0x3f880254}},	//   dršc, _والد_, _ጥጡሕ_, heau_, 
   {{0x629c571b,0x92e8015b,0xe99013ef,0x00000000}},	//   _arqo, _ভরে_, _سۇيگ, --, 
   {{0x3a2c008e,0xb5c8e87d,0xdc0002f0,0x3f880356}},	//   _kuep_, _گوتم_, _očís, jeau_, 
   {{0x3f88e87e,0xb6a48c75,0x3a240254,0x00000000}},	//   deau_, _хилл, _kilp_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa0a0e87f,0x629c013c,0x3f88b452,0xa9c00116}},	//   нард, _erqo, feau_, ﯩﺰﯨﺴ, 
   {{0x09b8043e,0x3f8850bb,0x3a2c0129,0x225c0010}},	//   _अव्य, geau_, _ouep_, šuka_, 
   {{0xf1d001c0,0x7afc2b96,0x00000000,0x00000000}},	// [14260] _зөвө, _østh, --, --, 
   {{0xb0e80154,0xf1d001c4,0x00000000,0x00000000}},	//   _গরীব_, _чөмө, --, --, 
   {{0x3f880129,0xec78e880,0xb4e81546,0x00000000}},	//   beau_, спе_, _यशो_, --, 
   {{0x3f88e881,0x00000000,0x00000000,0x00000000}},	//   ceau_, --, --, --, 
   {{0x5b200a89,0x00000000,0x00000000,0x00000000}},	//   ньша, --, --, --, 
   {{0x3d040073,0x00000000,0x00000000,0x00000000}},	//   _वरचे_, --, --, --, 
   {{0x83fc0301,0xeb9800d8,0x6d4c00de,0x00000000}},	//   hrđa, _лив_, _ieba, --, 
   {{0x6d4c50f9,0x6f0400b5,0x83fc01a6,0xe66400cf}},	//   _heba, _kykc, tuđm, птоо, 
   {{0x6d4ca14d,0x3a24e882,0x45d4e883,0x00000000}},	//   _keba, _filp_, допс, --, 
   {{0x3f88e884,0x65a86799,0x3a2400a3,0x6e2001ab}},	//   zeau_, стиг_, _gilp_, ìobh, 
   {{0x6d4ce885,0x9f5001ed,0xa9080228,0x69d4007f}},	//   _meba, ődés_, _ايال_, èyeu, 
   {{0x6d4ce886,0xecbc00cc,0x00000000,0x00000000}},	//   _leba, _আধাড, --, --, 
   {{0x3f88e887,0xe3d00228,0x6d4c0393,0xe5c4781e}},	//   veau_, _үйлө, _oeba, _нско, 
   {{0x17183d99,0x6d4ce888,0x3f8802b5,0xd6900063}},	//   _הודע, _neba, weau_, _чишћ, 
   {{0x3f88e889,0x439404b3,0xba3c013a,0x00000000}},	//   teau_, _жайс, _zrůd, --, 
   {{0xdef8e88a,0x6d4c01c4,0xb5fc0e04,0x53440408}},	//   быз_, _aeba, mrša, _пхьа, 
   {{0x3f88e88b,0x6d4ce88c,0x443ce88d,0xb5fc09a8}},	// [14270] reau_, _beba, _htv_, dušj, 
   {{0x3f880231,0x443ce88e,0x6d4ce88f,0x3fcc015b}},	//   seau_, _ktv_, _ceba, রচেষ, 
   {{0x3f88e890,0x3a2c0139,0x00000000,0x00000000}},	//   peau_, _suep_, --, --, 
   {{0x6d4ce891,0x7d0000b5,0x443c2238,0x00000000}},	//   _eeba, _ølsm, _mtv_, --, 
   {{0x6d4ce892,0x443c143f,0xfaa400f2,0x00000000}},	//   _feba, _ltv_, بجای, --, 
   {{0x6d4ce893,0xb5fc0989,0x443c0311,0xa3780037}},	//   _geba, krša, _otv_, mnõu, 
   {{0xa37800c5,0x3ce401e3,0x00000000,0x00000000}},	//   lnõu, _älv_, --, --, 
   {{0x6d4ce894,0x99d4e895,0x3a2401f5,0xb6a4084c}},	//   _zeba, _کترا, _wilp_, диил, 
   {{0x6d4c2959,0x64480618,0x397401b9,0x443c2238}},	//   _yeba, _awfi, _олаё, _atv_, 
   {{0x443ce896,0x6d4c0694,0x49744d87,0xb9c400ae}},	//   _btv_, _xeba, _плус, _تقطي, 
   {{0x443c579b,0xb5fc245e,0xd7f8311b,0x55c00116}},	//   _ctv_, lušk, _луд_, _җайғ, 
   {{0xe72ce897,0x798002d0,0xd7f8004e,0x00000000}},	//   _је_, _hblw, _ууз_, --, 
   {{0xe56cd979,0xb5fc11ce,0x443ce898,0xd378033f}},	//   _из_, nušk, _etv_, ęć_, 
   {{0x443ce899,0xa378000d,0xb51c010a,0x78f800df}},	//   _ftv_, dnõu, _килĕ_, ַפּו, 
   {{0x33f47651,0x9f880008,0xb5fc0fcf,0x2604166d}},	//   _очис, töðu_, hušk, _सीटी_, 
   {{0x6d4ce89a,0x6f040064,0x06d00154,0x00000000}},	//   _seba, _pykc, াপরি, --, 
   {{0xdee0e89b,0x6d4ce89c,0x764c3361,0x443c0051}},	// [14280] воти, _peba, _çayd, _ztv_, 
   {{0x1e803461,0xb5fce89d,0x6d4c0200,0x443c01f4}},	//   ълум, dušk, _qeba, _ytv_, 
   {{0xeb98e89e,0x6d4ce89f,0x443c022e,0x656c01ab}},	//   жие_, _veba, _xtv_, òbhi, 
   {{0x6d4ce8a0,0xb5fc01a6,0x3d1801ed,0x320801e3}},	//   _weba, fušk, سٹنگ_, llby_, 
   {{0x6d4ce8a1,0x798002d0,0xa3780254,0x301400db}},	//   _teba, _bblw, kiõn, _ндүр, 
   {{0xb5fc1e31,0xe2a401a8,0x00000000,0x00000000}},	//   sušj, æðis_, --, --, 
   {{0x1d0400f7,0x7a1802e2,0xde0000c7,0xa3780254}},	//   _жери_, _pňtr, _рпри, diõn, 
   {{0xb5fc2d2b,0x443ce8a2,0x210000d0,0xba3c00bc}},	//   vrša, _rtv_, _učiť_, _drůb, 
   {{0x443ce8a3,0x2b44e8a4,0x80b407f7,0xb5fc00d7}},	//   _stv_, mboc_, _उपभे, cušk, 
   {{0x443ce8a5,0x160801ad,0x3208005c,0x2d9800e4}},	//   _ptv_, _सीआर_, jlby_, ndpe_, 
   {{0xd90c01ed,0x628c00f1,0x83fc107d,0x443c0208}},	//   _پیٹ_, wwco, luđi, _qtv_, 
   {{0x443c001e,0x626c02a8,0x00000000,0x00000000}},	//   _vtv_, lɗoɗ, --, --, 
   {{0x83fc17a3,0x628c01f5,0xc2c40ada,0xd7c40133}},	//   nuđi, uwco, ريسي, _زووه_, 
   {{0x443ce8a6,0x8c1409bd,0x5184e8a7,0xb5fce8a8}},	//   _ttv_, িদিন_, куса, prša, 
   {{0x7afc2b96,0x2a6401a9,0x00000000,0x00000000}},	//   _østv, hrob_, --, --, 
   {{0x2a6405b1,0xbe38036b,0x4274004e,0x00000000}},	//   krob_, ззах_, _згис, --, 
   {{0x4428e8a9,0xa17c030d,0x00000000,0x00000000}},	// [14290] _iia_, _кунĕ_, --, --, 
   {{0x4428e8aa,0x2a640327,0x764c03e0,0x5bc409fa}},	//   _hia_, drob_, _çaye, लस्व, 
   {{0x4428e8ab,0xb5fc151c,0xa37800c5,0x798002d0}},	//   _kia_, kršn, snõu, _rblw, 
   {{0x442806a3,0x7c340020,0xb5fc3831,0x4bd83695}},	//   _jia_, _እነርሱ, tušk, وبند_, 
   {{0x4428e8ac,0xf984003b,0x64c800cd,0x00000000}},	//   _mia_, егло, ानुश, --, 
   {{0x4428e8ad,0xba3c012c,0x0ba40724,0x7e6c006f}},	//   _lia_, _průb, ешәм, muap, 
   {{0x44284774,0x3f98e8ae,0x7e6ce8af,0xb5fc01a6}},	//   _oia_, _kasu_, luap, sušk, 
   {{0x83fc16a3,0xb5fce8b0,0x3f98e8b1,0x00000000}},	//   buđi, muši, _jasu_, --, 
   {{0x3f98e8b2,0x2a64e8b3,0x7c280036,0x798003ac}},	//   _masu_, crob_, _iier, _tblw, 
   {{0x7c28e8b4,0x4428e8b5,0xe6143a21,0x3f98e8b6}},	//   _hier, _aia_, нды_, _lasu_, 
   {{0x4428e8b7,0x7c28e8b8,0xf3e43a61,0xd3700075}},	//   _bia_, _kier, ежно, لۇغ_, 
   {{0x4428e8b9,0x7c280385,0x3f98e8ba,0xc7c4e8bb}},	//   _cia_, _jier, _nasu_, _исчи, 
   {{0x4428e8bc,0x7c28e8bd,0xd6c02c26,0xa0a001b9}},	//   _dia_, _mier, _جمشی, қатд, 
   {{0x4428e8be,0x3f980618,0xb5fc3e9d,0x7e6c0254}},	//   _eia_, _aasu_, kuši, duap, 
   {{0x4428e8bf,0x3f98e8c0,0xf50410f5,0xb5fc00da}},	//   _fia_, _basu_, _язко, juši, 
   {{0x4428e8c1,0x3f98e8c2,0xee38554f,0x7c28e8c3}},	//   _gia_, _casu_, зна_, _nier, 
   {{0x3f980c09,0xcf2402dd,0xada49aa1,0x7e6c0588}},	// [142a0] _dasu_, тпақ, наал, guap, 
   {{0x4428e8c4,0x7c28009d,0x00000000,0x00000000}},	//   _zia_, _aier, --, --, 
   {{0x44280bed,0xab643b2e,0x3f980de2,0xb5fce8c5}},	//   _yia_, евел, _fasu_, guši, 
   {{0x7c28e8c6,0x4428067c,0xdb180165,0xe1fc0789}},	//   _cier, _xia_, _kouè, nrón_, 
   {{0xb5fce8c7,0x7c28e8c8,0xe1fc0005,0x7a180100}},	//   vršn, _dier, irón_, _pňtp, 
   {{0x7c28e8c9,0x3f9823db,0x6bd8e8ca,0x89d8009a}},	//   _eier, _zasu_, _کورس_, بوتر_, 
   {{0x83fc07f5,0x7c28e8cb,0xdca000d1,0x3f98e8cc}},	//   suđi, _fier, _йари, _yasu_, 
   {{0x7c28e8cd,0x81c804c5,0xad240131,0x2a64003a}},	//   _gier, লোপ_, _يىڭى, prob_, 
   {{0xc6f810f5,0xe1fce8ce,0xba280131,0xe9d8ca08}},	//   ьних_, drón_, سسۇم_, _ека_, 
   {{0xa3e020f0,0x7c28e8cf,0xd5b40153,0x00000000}},	//   फोन_, _zier, есю_, --, 
   {{0x4428e8d0,0x461400e5,0x00000000,0x00000000}},	//   _pia_, ٹوگر, --, --, 
   {{0x442801d4,0x7c28003d,0x69c8007c,0x1fbc0cf1}},	//   _qia_, _xier, lkfe, _एकेड, 
   {{0x2afc00c6,0x3f98e8d1,0x4428e8d2,0x92580209}},	//   _ऋँऋँ_, _rasu_, _via_, наят_, 
   {{0x45f8495f,0x4428e8d3,0x69c8e8d4,0x80b41b61}},	//   _تفتح_, _wia_, nkfe, _उपदे, 
   {{0x4428e8d5,0x3f98e8d6,0x5064af55,0xe1fc21fc}},	//   _tia_, _pasu_, лтта, brón_, 
   {{0x4428e8d7,0x7e6ce8d8,0xdef81411,0xb5fc597b}},	//   _uia_, tuap, пыз_, vuši, 
   {{0x7c280228,0x6458b934,0x3f9888b5,0x69c8143a}},	// [142b0] _rier, lsti, _vasu_, kkfe, 
   {{0x3f984437,0x7c28e8d9,0x6458e8da,0x63bc0113}},	//   _wasu_, _sier, osti, _hoqn, 
   {{0x7c281605,0x3f98e8db,0x7e6c0134,0x61e4054e}},	//   _pier, _tasu_, suap, mijl, 
   {{0x6458e8dc,0x7c280407,0x69c8017a,0x7e6c02b1}},	//   isti, _qier, ekfe, puap, 
   {{0x7c28e8dd,0x7e6c0395,0xa30c00ab,0x6458e8de}},	//   _vier, quap, _सरोज_, hsti, 
   {{0x7c28e8df,0xdb18004a,0x00000000,0x00000000}},	//   _wier, _joué, --, --, 
   {{0xdd8c00aa,0x6458e8e0,0x83fc04a7,0x00000000}},	//   _پوځ_, jsti, luđu, --, 
   {{0xdb20e8e1,0x61e40bc9,0x63bc0014,0x7c280af9}},	//   _موزی, hijl, _noqn, _uier, 
   {{0x6458e8e2,0x3a7401d5,0x60c40200,0xa378000d}},	//   esti, _шлар, hyjm, riõl, 
   {{0x6458e8e3,0xc7641df2,0xdb180129,0x61e40455}},	//   fsti, ناۋى, _noué, jijl, 
   {{0xe1fcb9f0,0x63bc058a,0xa3780254,0x00000000}},	//   trón_, _boqn, piõl, --, 
   {{0x7afc0ec3,0x00000000,0x00000000,0x00000000}},	//   _østs, --, --, --, 
   {{0x6458e8e4,0xe1fce8e5,0x3cf46bcf,0xdb1806af}},	//   asti, rrón_, ्थडे_, _boué, 
   {{0xf50402d7,0x75fc0268,0x645818a8,0x00000000}},	//   _изло, hèzz, bsti, --, 
   {{0x6458015d,0xdb1806af,0xe1fc01d3,0x25fc23e9}},	//   csti, _doué, mról_, रकरी_, 
   {{0x7414005e,0xa1100a2c,0xe1fc01ed,0x00000000}},	//   _جوعا, شوقت, lról_, --, 
   {{0x69c8cafe,0xed58016c,0xf1c0005f,0x61e4014f}},	// [142c0] ykfe, доз_, _pašā_, bijl, 
   {{0xa2d810dc,0xdb180165,0xe1fc01d3,0x00000000}},	//   _पेट्, _goué, nról_, --, 
   {{0x49a43419,0xe7f4012c,0x63bc8e61,0xb5fc0427}},	//   ғылғ, ुकमा_, _yoqn, vršl, 
   {{0xdcac0c50,0xfdbc03f3,0x7c648b29,0x83fc07f5}},	//   تىم_, ोसॉफ, االل, buđu, 
   {{0xe1fc00dd,0x6458e8e6,0x00000000,0x00000000}},	//   król_, zsti, --, --, 
   {{0x9d40e8e7,0x00000000,0x00000000,0x00000000}},	//   _верд, --, --, --, 
   {{0x69c82167,0xe1fc01d3,0x6458e8e8,0xf95800e5}},	//   rkfe, dról_, xsti, رسوں_, 
   {{0x57a00588,0x97480023,0xe7840b3b,0x69c80165}},	//   ашьа, _ዓበይት, туко, skfe, 
   {{0x6458e8e9,0x60c40034,0x63bc022e,0x00000000}},	//   wsti, zyjm, _roqn, --, 
   {{0x6458943a,0x63bc95bd,0xb5fc0309,0x6844e8ea}},	//   tsti, _soqn, kušu, _анжа, 
   {{0x81c82f8b,0x7afc26ff,0xb8642651,0x6b801140}},	//   লোড_, _østr, _مانو, ofog, 
   {{0x68f80327,0x63bc014f,0xb5fc95d8,0x78ac0306}},	//   _ixtd, _qoqn, dušu, šový, 
   {{0x6b800421,0x61e4e8eb,0x63bc0455,0x7564010e}},	//   ifog, tijl, _voqn, _ỳaşy, 
   {{0x63bc014f,0x2c4800c0,0xe4a400f3,0x764c294f}},	//   _woqn, _kėdę_, _арио, _çaya, 
   {{0xd49480fd,0x61e4e8ec,0x25ac01e1,0xdb1806af}},	//   _ары_, rijl, _infl_, _voué, 
   {{0x8f440a93,0x61e4014f,0xaad00118,0x00000000}},	//   ихуд, sijl, थनाक, --, 
   {{0x3f14e8ed,0x8e38014d,0x61e401f5,0xa2d8000d}},	// [142d0] удас, نسلر_, pijl, _पेच्, 
   {{0x61e40455,0x0dc8014b,0x5cc4013d,0x78a400d7}},	//   qijl, кухи_, ксез, ťhvi, 
   {{0x8d740222,0xb5fc0024,0x83fc07f5,0xadf806b1}},	//   شالا, mušt, suđu, ्तजन_, 
   {{0x3af41064,0x6b8001ed,0x6d480d12,0xc30800eb}},	//   лялс, gfog, ðfar, রেণি_, 
   {{0x0fe44f41,0x8fe401e0,0xe1fc00e5,0x00000000}},	//   _төрү, _тәрҙ, yról_, --, 
   {{0xcd2800d1,0x00000000,0x00000000,0x00000000}},	//   رسەن_, --, --, --, 
   {{0x6010036e,0x00000000,0x00000000,0x00000000}},	//   nçmo, --, --, --, 
   {{0x25ac07c5,0x88c41884,0x2c480064,0xe1fc0332}},	//   _anfl_, شتىل, _dėdę_, dróm_, 
   {{0x6fc80122,0x25ac0076,0x68f802d0,0xe1fc01d3}},	//   _dých, _bnfl_, _extd, tról_, 
   {{0xb5fc1050,0x040c00fe,0xca4801e2,0x46c817ee}},	//   jušt, _সংগী_, _شلمه_, ाईजह, 
   {{0xe1fc01d3,0x00000000,0x00000000,0x00000000}},	//   rról_, --, --, --, 
   {{0xe1fc01ed,0xb9dc00b7,0x87d4249f,0x3244e8ee}},	//   sról_, _ኤም_, _پغما, лемг, 
   {{0xe60ce8ef,0xe1fc01d3,0xdce40419,0x00000000}},	//   _гд_, pról_, _najľ, --, 
   {{0x26580375,0xb5fc0010,0x6b8000e5,0x00000000}},	//   _טכנא, gušt, zfog, --, 
   {{0x74c01df2,0x63ac00ae,0x00000000,0x00000000}},	//   ﺭﻣﻪﻳ, áiní, --, --, 
   {{0xb5fc6041,0x00000000,0x00000000,0x00000000}},	//   rušu, --, --, --, 
   {{0x6ec4013f,0xe7f40a8a,0xb5fce8f0,0x6b8001bf}},	// [142e0] kɔbe, ुकता_, vršj, vfog, 
   {{0xb5fce8f1,0x7c3401d5,0xba3c013a,0x00000000}},	//   dršk, _buzr, _průn, --, 
   {{0xe1fc012d,0xaab83fb8,0x6b8000e5,0x00000000}},	//   krój_, کدار_, tfog, --, 
   {{0x7c340007,0x6b54e8f2,0x05140055,0x00000000}},	//   _duzr, اضائ, _āṇḍa, --, 
   {{0x160046fb,0x6fc80038,0x427c044e,0xb5fc0010}},	//   रकार_, _rých, _እዋናት_, gršk, 
   {{0x7c340175,0x6aa06c84,0x8e280150,0x6b80e8f3}},	//   _fuzr, rvof, _شۋاق_, sfog, 
   {{0xd6d40032,0x6fc80306,0xa3780254,0x00000000}},	//   ҫты_, _pých, biõh, --, 
   {{0xd7f47cbb,0x6e2c4dc9,0x47341955,0x1d0400ee}},	//   луы_, _hibb, шнис, _сеси_, 
   {{0x6fc803c6,0x6e2ce8f4,0x7afc01bf,0x28b42802}},	//   _vých, _kibb, _østp, _अपवि, 
   {{0x6e2ce8f5,0xda6c0050,0x067c2d40,0x8bd4000d}},	//   _jibb, _رُم_, _ﻣﻪﻧﯩ, _दतुअ, 
   {{0xb8e80c58,0xe784e8f6,0x6fc801a2,0x6e2c1c1d}},	//   _লে_, _було, _tých, _mibb, 
   {{0x6e2ce8f7,0xdb180077,0x77780208,0xf8ac04f2}},	//   _libb, _gluó, _gcwx, _آکو_, 
   {{0x6e2c0218,0x27e4e8f8,0xb5fc0024,0xa3780254}},	//   _oibb, _imon_, tušt, niõi, 
   {{0x6e2ce8f9,0x814401d5,0x25b8000d,0x00000000}},	//   _nibb, شنرن, _õpl_, --, 
   {{0xd0d400a7,0xf0780075,0xa3780037,0x853c0064}},	//   боръ, кирә_, hiõi, rdėd, 
   {{0x7c340007,0x60100200,0xb5fc01ef,0x00000000}},	//   _ruzr, rçmo, bušs, --, 
   {{0x6e2ce8fa,0xb5fc04b9,0x2284e8fb,0x7d540cb6}},	// [142f0] _bibb, pušt, _суйг, ивах, 
   {{0xc0c4e8fc,0xdeb00220,0xa3780254,0x00000000}},	//   _кәби, _құзы, diõi, --, 
   {{0x6e2ce8fd,0x27e4e8fe,0x4a7401e0,0x7cd80133}},	//   _dibb, _omon_, ҡышт, خواز_, 
   {{0xba740075,0xd7a00dba,0x92b803d4,0x00000000}},	//   لاتت, _खोंच, চনৰ_, --, 
   {{0x7f4c30d7,0x34e00490,0x628801e3,0xa3780254}},	//   mbaq, _पध्द, _ägod, giõi, 
   {{0x27e4e8ff,0x7f4c0548,0x7e6ce900,0x28b4033f}},	//   _amon_, lbaq, mrap, _अपशि, 
   {{0x7e6ce901,0xe1fce902,0xbe14021f,0x00000000}},	//   lrap, luós_, _موڭع, --, 
   {{0x6e2c006a,0x28b441ac,0xda643738,0xb5fc0e04}},	//   _zibb, _अपरि, _مائي, pršk, 
   {{0x7e6c034c,0x27e40100,0x6e2c0429,0xe1fc004e}},	//   nrap, _dmon_, _yibb, nuós_, 
   {{0x27e4e903,0xdb180561,0x3484009b,0x6e2c00e8}},	//   _emon_, _fluò, агог, _xibb, 
   {{0x7e6ce904,0xda18000d,0xe614013d,0x00000000}},	//   hrap, _पीयत_, рдэ_, --, 
   {{0x7e6ce905,0x45180006,0xe1fc02d2,0x00000000}},	//   krap, ыцыя_, brók_, --, 
   {{0xe72c86de,0xe29401c0,0xb810033f,0x41d02886}},	//   _фе_, аая_, _डीएम_, हसंस, 
   {{0x7e6ce906,0x76480502,0xb5fc39ca,0x2008012c}},	//   drap, mpey, krši, _akci_, 
   {{0x2f54ad95,0x6e2ce907,0x7e6ccc6f,0x764801f4}},	//   итас, _ribb, erap, lpey, 
   {{0x3eac05a1,0xb5fc02d1,0xba3c0118,0x00000000}},	//   _šeta_, mušq, _průl, --, 
   {{0xb8d0031c,0x6e2c00ad,0xf8a4179e,0x7648007f}},	// [14300] _ྟན_, _pibb, _کک_, npey, 
   {{0x83fc098d,0x3074e908,0x27440118,0x00000000}},	//   vrđi, _кумс, mínů_, --, 
   {{0x2fc0e909,0xc10001fb,0x7f4c0548,0xec78e90a}},	//   _tokg_, _mượt_, bbaq, тпе_, 
   {{0xc10007ae,0xcc144251,0x92b80eac,0x6e2c04e6}},	//   _lượt_, িদ্ধ_, চনী_, _wibb, 
   {{0x6e2ce90b,0xdb180165,0x27e4e90c,0x00000000}},	//   _tibb, _bluñ, _rmon_, --, 
   {{0xb5fc02d1,0xa37800c5,0xfa480131,0x3ec400d1}},	//   kušq, riõi, اشنى_, _уқум_, 
   {{0x2d8801e3,0xa378000d,0x00000000,0x00000000}},	//   _ibbe_, siõi, --, --, 
   {{0x7bd8e90d,0x00000000,0x00000000,0x00000000}},	//   chwu, --, --, --, 
   {{0x764c3535,0x00000000,0x00000000,0x00000000}},	//   _çayl, --, --, --, 
   {{0xe1fc0548,0xe4a46a27,0x99e097d0,0x45b80212}},	//   cróh_, армо, _джуд, угою_, 
   {{0xd494e90e,0xd5b48a63,0xc1000051,0x00000000}},	//   аря_, рсы_, _dượt_, --, 
   {{0x7e6ce90f,0x96b4085b,0x00000000,0x00000000}},	//   yrap, _چاوز_, --, --, 
   {{0x22846be1,0xb9fc0092,0x00000000,0x00000000}},	//   шунг, _ፆታ_, --, --, 
   {{0x7e6c00a7,0x00000000,0x00000000,0x00000000}},	//   vrap, --, --, --, 
   {{0x7e6ce910,0xb5fc03f0,0x55b8011a,0x7f4c0327}},	//   wrap, mušp, _במגו, tbaq, 
   {{0x7e6ce911,0x2d88e912,0x25e002a0,0xe1fc004e}},	//   trap, _abbe_, टोरी_, tuós_, 
   {{0xba3c0316,0x7f4ce913,0x00000000,0x00000000}},	// [14310] _prům, rbaq, --, --, 
   {{0x7e6ce914,0xca940201,0x040c0183,0x69a4012c}},	//   rrap, _መልካም_, _সূচী_, _टोली, 
   {{0x09a4000d,0x21240051,0x00000000,0x00000000}},	//   _गोइठ, _ành_, --, --, 
   {{0x2d88e915,0x7e6ce916,0x2ca8031c,0xde4404fb}},	//   _ebbe_, prap, _drbd_, _نیرو_, 
   {{0xfaa40fd7,0xdb1805c7,0xb5fc03f0,0x5ab48abc}},	//   сало, _pluñ, kušp, шқар_, 
   {{0x81c800bd,0xb5fc0010,0x0dc80798,0x00000000}},	//   লোর_, prši, _куси_, --, 
   {{0x39481a4c,0x6fc80122,0xc100004d,0x3cf40073}},	//   ĝas_, _výcv, _rượt_, ्थळे_, 
   {{0xd0f806a9,0x3948008f,0x8b880137,0xe73408ca}},	//   ימות_, ŝas_, _نەمە_, беъ_, 
   {{0x27f8003e,0x76480100,0xa80000e4,0x00000000}},	//   épna_, upey, õñai, --, 
   {{0x58846feb,0xca6001a9,0x25e000e1,0xf5b40107}},	//   _выда, _izmа, टोली_, ссию, 
   {{0xc328159d,0xc1000016,0x391400f1,0x764801ab}},	//   _נו_, _vượt_, _اواز, spey, 
   {{0x7648062c,0xe1fc012d,0x00000000,0x00000000}},	//   ppey, orów_, --, --, 
   {{0x35a4e917,0xe4d404fb,0xd600004b,0x3668e918}},	//   _галг, لویت_, _وېبپ, _сало_, 
   {{0xd3480b28,0x6140c8cb,0xb5fc0784,0xba3c00bc}},	//   دیکه_, зера, pušq, _průj, 
   {{0x92b800bd,0xd3e4036b,0xb5fc0309,0x00000000}},	//   চনে_, _وقتی, qušq, --, 
   {{0x84440345,0x64a00354,0x643800df,0x00000000}},	//   _بخول, _хаъа, _געקנ, --, 
   {{0xef18e919,0xdfcc007b,0x63a808a5,0x00000000}},	// [14320] ума_, ريك_, _ógna, --, 
   {{0x4918000d,0x00000000,0x00000000,0x00000000}},	//   _फरलो_, --, --, --, 
   {{0xac8400ee,0x00000000,0x00000000,0x00000000}},	//   сгел, --, --, --, 
   {{0x32082320,0x7c6400d1,0x960001ad,0x00000000}},	//   loby_, زامل, रकुट_, --, 
   {{0xe1fc0210,0x00000000,0x00000000,0x00000000}},	//   grów_, --, --, --, 
   {{0x2d88e91a,0xe1fc0120,0x1954e91b,0x2eb400dc}},	//   _ubbe_, trói_, башы_, ृहीत, 
   {{0xe1fc012d,0xd88401c8,0x29184cab,0x00000000}},	//   arów_, مپون_, åpa_, --, 
   {{0x6d5ce91c,0x29100a28,0x320806d9,0x98800166}},	//   lapa, āya_, hoby_, _cíıp_, 
   {{0x52b402f8,0x96000034,0x32080ebb,0x262801c0}},	//   ुहोस, रकूट_, koby_, лцоо_, 
   {{0x6d5ce91d,0x32087429,0x9ac801ed,0x5ac408ca}},	//   napa, joby_, _صدقہ_, _улум_, 
   {{0x3208a3f5,0x25a8765c,0x81c80c58,0x6d5c0789}},	//   doby_, ندگي_, লোঁ_, iapa, 
   {{0x6d5ce91e,0xa3e0033f,0xe73818a4,0x00000000}},	//   hapa, फों_, _сед_, --, 
   {{0xb5fc0784,0x00000000,0x00000000,0x00000000}},	//   pušp, --, --, --, 
   {{0x83fc05ce,0x32080083,0x4034e91f,0x00000000}},	//   vrđu, goby_, жевс, --, 
   {{0xba3c012c,0x104801a9,0xd0d4011c,0x00000000}},	//   _průk, йяти_, поръ, --, 
   {{0x1ee40214,0x657801e7,0x4fc40022,0x00000000}},	//   موزی_, lgth, псуа, --, 
   {{0x6d5ce920,0x1ab801e1,0x65780332,0x9ba015bf}},	// [14330] fapa, _fóṣì_, ogth, ۋەسى, 
   {{0x6578e921,0x6d5ce922,0x32080036,0x629ce923}},	//   ngth, gapa, coby_, _isqo, 
   {{0x657800ae,0xfbd000ec,0x00000000,0x00000000}},	//   igth, وڪر_, --, --, 
   {{0x649c0384,0xe1fc1afd,0x7b8400d1,0x26000174}},	//   mšić, trów_, تائە, rðoy_, 
   {{0x9a840124,0x7e7800c8,0x649c00f3,0xc5f800e2}},	//   суел, _דאָז, lšić, knē_, 
   {{0x3ea8e924,0x00000000,0x00000000,0x00000000}},	//   mvat_, --, --, --, 
   {{0x3ea8e925,0xe72c0133,0xfa4815bf,0xc5f80171}},	//   lvat_, ۆڵه_, اشچى_, dnē_, 
   {{0x3ea8e926,0xfbdc01bc,0xc5f800e2,0x764c0ab5}},	//   ovat_, _मतिम, enē_, _çayk, 
   {{0xb6a4e927,0xb5fc05a1,0x79f400c7,0xead0110e}},	//   ципл, kršt, _дзах, _jẹ́_, 
   {{0x3ea8049b,0x649c0552,0xe614023a,0x869800a7}},	//   ivat_, kšić, ждь_, стът_, 
   {{0x649c0b4b,0x629ce928,0xead00248,0x00000000}},	//   jšić, _asqo, _lẹ́_, --, 
   {{0xbb240075,0xba3c00bc,0x3ea8e929,0x981496b4}},	//   ﭼﯜﻥ_, _průh, kvat_, _ابطا, 
   {{0x320806d9,0x42d41cb8,0x46a400d4,0x00000000}},	//   toby_, піру, _наїв, --, 
   {{0x6d5ce92a,0x05440020,0xb5fc01fa,0x317c0112}},	//   xapa, _የአሜሪ, gršt, ütz_, 
   {{0x6d5ce92b,0x3208e92c,0xa0a0e92d,0x629c0309}},	//   vapa, roby_, мард, _esqo, 
   {{0x6d5ce92e,0xead001e1,0x32088864,0x2fd805af}},	//   wapa, _bẹ́_, soby_, جورد_, 
   {{0x6d5ce92f,0x6e445530,0x81c8015b,0x3ea8e930}},	// [14340] tapa, زنام, লোই_, gvat_, 
   {{0x604001f2,0x3f88e931,0xab60010e,0x00000000}},	//   ọmat, afau_, _ýüzi, --, 
   {{0x6d5ce932,0x3ea8e933,0xfa8402d3,0xac080153}},	//   rapa, avat_, _ዓርከይ_, анжа_, 
   {{0xefb014c3,0xead00248,0x3944e934,0xc50c010f}},	//   _تیرگ, _fẹ́_, _afls_, נלאָ, 
   {{0x3ea8084c,0xeaf800c6,0xa3b836c7,0xdddc0213}},	//   cvat_, جرات_, घात_, quqş, 
   {{0xaa50001f,0x286810fc,0x6d5c3d07,0x3130001f}},	//   _ይደረጋ, арио_, qapa, _በቤተክ, 
   {{0xa37803b7,0xdc6400c2,0x1894007b,0xeb98010a}},	//   lhõe, _мард_, قضية_, _кив_, 
   {{0xa92402d2,0x7b140432,0x18380023,0xe66464cb}},	//   _afþý, _sýuž, _ኣቐዲሞ, отоо, 
   {{0xa37806ed,0xc5f800da,0x5a60014b,0x00000000}},	//   nhõe, tnē_, _октб, --, 
   {{0xdb1801b8,0xe5e4007b,0x6010036e,0x1a9800df}},	//   _pluö, تثبي, rçmi, _דימע, 
   {{0x69d8e935,0xd7ece936,0x6578007b,0x3ea8314f}},	//   _ilte, _жу_, rgth, zvat_, 
   {{0xdb180254,0x3ea800d7,0x67fc00cd,0x00000000}},	//   _eluõ, yvat_, bīja, --, 
   {{0xe5a4e937,0x00000000,0x00000000,0x00000000}},	//   _миди, --, --, --, 
   {{0x3ea8036b,0x345401ed,0xead001e1,0x00000000}},	//   vvat_, _کروڑ, _rẹ́_, --, 
   {{0xe50011b1,0x9fc465cb,0x69d801ab,0x00000000}},	//   _रुचि_, ощал, _mlte, --, 
   {{0x3f880421,0x3ea802c3,0x649c0e04,0xead001e1}},	//   ufau_, tvat_, ršić, _pẹ́_, 
   {{0x69d8e938,0x443c0457,0x3ea8e939,0xd3580a7c}},	// [14350] _olte, _huv_, uvat_, _ויחי_, 
   {{0x443c0e37,0x291c009d,0xdd980063,0x3fcc03d4}},	//   _kuv_, _ozta_, јша_, ৰচেষ, 
   {{0x3ea8e93a,0xb19808a8,0x00000000,0x00000000}},	//   svat_, _היתכ, --, --, 
   {{0x69d8e93b,0x00000000,0x00000000,0x00000000}},	//   _alte, --, --, --, 
   {{0x443ce93c,0x29f40034,0x2900013f,0xa37800d8}},	//   _luv_, kład_, _ɛkae_, chõe, 
   {{0xdb1806ed,0x69d80076,0x908801d9,0x443c6ede}},	//   _louç, _clte, _دۅہے_, _ouv_, 
   {{0x443c0842,0x81ac00fe,0x00000000,0x00000000}},	//   _nuv_, _ককা_, --, --, 
   {{0x69d8e93d,0x7f5c014f,0x656c01ab,0x00000000}},	//   _elte, _jesq, ųbhl, --, 
   {{0x443caa48,0x7f5c57d8,0x291c05f5,0x644806ea}},	//   _auv_, _mesq, _ezta_, _atfi, 
   {{0x99d4e93e,0x7bc80069,0x7f5c4aee,0x443ce93f}},	//   _بترا, _hoeu, _lesq, _buv_, 
   {{0xa560e940,0x7bc803a0,0x443c0356,0xd7f81f5a}},	//   رگون, _koeu, _cuv_, _куд_, 
   {{0x443ce941,0x7f5ce942,0xb464001f,0x7bc8007f}},	//   _duv_, _nesq, _መደረጉ, _joeu, 
   {{0x98a445a5,0x7bc8e943,0x846ce944,0x443c07c5}},	//   manı_, _moeu, _በሰሜን_, _euv_, 
   {{0x98a4e945,0x443c07c5,0x853c0006,0xe1fc004e}},	//   lanı_, _fuv_, ndėl, drós_, 
   {{0x443ce946,0x6ec4013f,0x33f41eec,0x853c00c0}},	//   _guv_, tɔbo, _нчис, idėl, 
   {{0xe1fc0034,0xc32c0efb,0x98a49d5d,0x7bc84056}},	//   wrót_, دەۋ_, nanı_, _noeu, 
   {{0x2d94011c,0x00000000,0x00000000,0x00000000}},	// [14360] зрес, --, --, --, 
   {{0x443ce947,0x98a4e948,0xa37800c5,0x75d8007f}},	//   _yuv_, hanı_, liõp, tňzy, 
   {{0x98a41ae6,0x443c0218,0x7bc806af,0x7f5c0076}},	//   kanı_, _xuv_, _boeu, _fesq, 
   {{0x7bc8e949,0x798002d0,0xe454008f,0xe1fc004e}},	//   _coeu, _aclw, פינט_, brós_, 
   {{0xbe8025f8,0x98a4e94a,0x00000000,0x00000000}},	//   _иқти, danı_, --, --, 
   {{0xed50e94b,0xfd5801f2,0x291c005a,0x69d801f5}},	//   _سپر_, _mgbụ, _pzta_, _qlte, 
   {{0x81c82158,0x2d98e94c,0x7bc80b23,0x69d80393}},	//   লোক_, mepe_, _foeu, _vlte, 
   {{0x2d98e94d,0x443ce94e,0x98a462c7,0x798002d0}},	//   lepe_, _ruv_, ganı_, _eclw, 
   {{0x443ce94f,0x00000000,0x00000000,0x00000000}},	//   _suv_, --, --, --, 
   {{0x69d8e950,0x2d98e951,0x443ce952,0xba3c012c}},	//   _ulte, nepe_, _puv_, _prův, 
   {{0x443ce953,0xfd580521,0x291c009d,0x98a40ac1}},	//   _quv_, _agbụ, _uzta_, banı_, 
   {{0x2d98e954,0x98a41b0d,0x443c0455,0xa3780254}},	//   hepe_, canı_, _vuv_, giõp, 
   {{0x7f5ce955,0x2a640395,0x443c047e,0xe5c80139}},	//   _resq, nsob_, _wuv_, _гыйл_, 
   {{0x2d98e956,0x7f5ce957,0x443ce958,0xd6cc40c7}},	//   jepe_, _sesq, _tuv_, _حقه_, 
   {{0x7f5ce959,0xd48ce95a,0x850400aa,0x6448000f}},	//   _pesq, _яр_, _توغن, _utfi, 
   {{0xd1301374,0x7f5c0455,0xba3c0118,0xf49400e5}},	//   امِ_, _qesq, _krůt, _کھیت_, 
   {{0xce940395,0x00000000,0x00000000,0x00000000}},	// [14370] натъ, --, --, --, 
   {{0x7bc8e95b,0x98a48eac,0x4df402bf,0x2d98e95c}},	//   _soeu, zanı_, няєт, gepe_, 
   {{0x98a49f96,0x7f5c003a,0xb308031c,0x0dc800d4}},	//   yanı_, _tesq, _གཙོང_, чути_, 
   {{0x98a46656,0x67fc0171,0x00000000,0x00000000}},	//   xanı_, dījo, --, --, 
   {{0x98a4722d,0x7bc89f25,0x7980035a,0x2d980332}},	//   vanı_, _voeu, _pclw, bepe_, 
   {{0x2d9800a8,0x60100200,0x00000000,0x00000000}},	//   cepe_, rçmu, --, --, 
   {{0x4c94e95d,0x98a4538f,0x7bc80270,0x38282077}},	//   _пирс, tanı_, _toeu, ожко_, 
   {{0x2a644cd3,0xdb1802b5,0x00000000,0x00000000}},	//   bsob_, _pouä, --, --, 
   {{0x98a49d58,0x70b801ad,0x00000000,0x00000000}},	//   ranı_, _उप्ल, --, --, 
   {{0xe614e95e,0x98a44a4a,0x798002d0,0x853c0153}},	//   мды_, sanı_, _uclw, ldėj, 
   {{0x98a4e94a,0x95c801d5,0xc6a40de7,0xa3780037}},	//   panı_, _қуда_, _үрчи, tiõp, 
   {{0x98a40213,0x853c0153,0x2d98e95f,0xb4cc4f71}},	//   qanı_, ndėj, zepe_, _रथी_, 
   {{0xe60c4077,0x2d980810,0xa37800c5,0xd6a80133}},	//   _ад_, yepe_, riõp, _ددام_, 
   {{0x940c06be,0xa3780254,0x66e00114,0x00000000}},	//   _ələm_, siõp, _јоша, --, 
   {{0xa50400fd,0x2d980022,0x6590009b,0x6fb40472}},	//   _оеша_, vepe_, _рају, ومسا, 
   {{0x39480134,0x624800de,0x6020009d,0x00000000}},	//   ɛase_, _bļod, вдса, --, 
   {{0x2d98e960,0xada400cf,0xa3b82052,0x00000000}},	// [14380] tepe_, маал, घार_, --, 
   {{0xe1fc0789,0xab640254,0xacf40472,0x00000000}},	//   lsón_, krüü, وسات, --, 
   {{0xafe4036b,0xb0bc0408,0x00000000,0x00000000}},	//   _жонл, _тенĕ_, --, --, 
   {{0x2d98e961,0x00000000,0x00000000,0x00000000}},	//   sepe_, --, --, --, 
   {{0xa3e0130b,0x2d98e962,0x2b4400db,0x81c80154}},	//   फोट_, pepe_, rcoc_, লোও_, 
   {{0x2b440472,0x67fc00e2,0x3a2400d7,0x298800d4}},	//   scoc_, tījo, _chlp_, ісло_, 
   {{0x272001a9,0x2a64e963,0x6b640a5b,0x00000000}},	//   mаni_, ssob_, _оква, --, 
   {{0x6bd8034c,0xba3c00bc,0x98a00063,0xb82000cc}},	//   _بورس_, _průt, тиће, _পূবত_, 
   {{0xc6f80212,0xe9680137,0x00000000,0x00000000}},	//   яних_, _маал_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb3080327,0x1864003b,0xcae400cc,0x00000000}},	//   _གཙུང_, _жахи_, _ফুচফ, --, 
   {{0x2720022e,0x5ef000cd,0x00000000,0x00000000}},	//   hаni_, ूपम्_, --, --, 
   {{0x65c4e964,0xfd64001e,0x966000a8,0x16a4e965}},	//   _обда, _chuỗ, _акче, _овци_, 
   {{0xe7e810f7,0x6720d489,0x23ac5345,0x5690e966}},	//   जोरा_, _izoj, _जोरद, _рашт, 
   {{0x50640184,0x1fa401c0,0x644c00d8,0x4394e967}},	//   ктта, мраг, íbid, _зайс, 
   {{0x66180054,0x14c8e968,0xe1fc01ed,0x00000000}},	//   lltk, ाहरण, csón_, --, 
   {{0xc308015b,0x2900016b,0x00000000,0x00000000}},	// [14390] রেজি_, _ɛkaa_, --, --, 
   {{0xd130004b,0x2720022e,0xbe14072d,0x00000000}},	//   امې_, gаni_, رواع, --, 
   {{0x3154025d,0xf1b0008f,0xe3c80139,0x00000000}},	//   _איתן_, _עסט_, _yañа_, --, 
   {{0x814405d9,0x853c0153,0x00000000,0x00000000}},	//   _تنھن, udėj, --, --, 
   {{0x853c0024,0xcb3402e8,0x00000000,0x00000000}},	//   rdėj, вецъ, --, --, 
   {{0x8d74e969,0x20184f6b,0xba3c01ef,0x00000000}},	//   _لافا, llqi_, _srůs, --, 
   {{0x5fd019e5,0x6720e96a,0xba3c0118,0xdd000153}},	//   _सवाल, _azoj, _průs, _įrėm, 
   {{0x81e400fe,0x00000000,0x00000000,0x00000000}},	//   পচি_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xab6000af,0xd83805f5,0x672000f3,0x98b80724}},	//   _üüri, _дэд_, _dzoj, şqı_, 
   {{0xfc380115,0x3f8c00e8,0x81e40154,0x28a40456}},	//   _kiŭ_, _ñeuw_, পচা_, _कैपि, 
   {{0x7bd8e96b,0xc3080154,0x00000000,0x00000000}},	//   nkwu, রেছি_, --, --, 
   {{0xf1d001c6,0xdb04007c,0xe1fce96c,0xd178009d}},	//   гөнө, _åläg, rsón_, мөнх_, 
   {{0xe5a0e96d,0x69c00037,0x00000000,0x00000000}},	//   _биши, लायी, --, --, 
   {{0x25a82c26,0xe1f0004b,0x85440276,0x66043980}},	//   _رضوی_, اسټ_, _рэче, ékke, 
   {{0x2728110e,0x00000000,0x00000000,0x00000000}},	//   _ẹni_, --, --, --, 
   {{0xdee0e96e,0xb8d00135,0x69c00709,0x00000000}},	// [143a0] готи, _ཟན_, लामी, --, 
   {{0xe1fc5e4f,0x00000000,0x00000000,0x00000000}},	//   nsól_, --, --, --, 
   {{0xeb981fb7,0x20180175,0xb5d40150,0x00000000}},	//   зие_, blqi_, _ﺘﺠﻤﻌ, --, 
   {{0xfc380100,0xe8f805f5,0x8a1400f1,0x00000000}},	//   _ciŭ_, үлд_, چېرت, --, 
   {{0x271c00bc,0x00000000,0x00000000,0x00000000}},	//   _परेर_, --, --, --, 
   {{0xa8a43500,0x7bd802e3,0x28a400ee,0xba3c013a}},	//   ерик, akwu, ешиг, _průr, 
   {{0xde00e96f,0x1d04016c,0xa17800df,0x00000000}},	//   _спри, _зери_, לטסט, --, 
   {{0x6c3400c6,0x7bd8002f,0xbfc80051,0x999c01ef}},	//   _أفرا, ckwu, _kháổ, _rtuť_, 
   {{0x6b80e970,0x63a8032e,0x59a8166d,0x00000000}},	//   mgog, _ógni, _टोकर, --, 
   {{0xc0e0069c,0x6b80e971,0x45d40137,0xa96802e8}},	//   _ሓይሊ_, lgog, тоос, _хижа_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6b80e972,0x982801ed,0xa3780254,0x97a000d8}},	//   ngog, _فتنہ_, ahõn, _бршл, 
   {{0x6720e973,0xdb1800d8,0xd7c41e4b,0x00000000}},	//   _uzoj, _anuê, _سووه_, --, 
   {{0xbbdc00cd,0x00000000,0x00000000,0x00000000}},	//   _मत्क, --, --, --, 
   {{0x6b80b123,0xc60c185b,0x10a40818,0x28a4012d}},	//   kgog, सकीय_, лиён, _कैमि, 
   {{0x4394085a,0x69c0012c,0x6aa00100,0xd01800c0}},	//   _раис, लाडी, kwof, ефу_, 
   {{0x4428e974,0xbb68037e,0xf2c00131,0xdd980150}},	// [143b0] _iha_, _netで_, _көри, зше_, 
   {{0x12fc0375,0x6b80e975,0xfcc80092,0x0f1400d4}},	//   _מהחב, egog, _በነጻ_, умую, 
   {{0x442853ed,0x00000000,0x00000000,0x00000000}},	//   _kha_, --, --, --, 
   {{0x4428e976,0x6b80d988,0x00000000,0x00000000}},	//   _jha_, ggog, --, --, 
   {{0x4428e977,0xc0e002d3,0x28a4033f,0x7bd89553}},	//   _mha_, _ሓይሉ_, _कैबि, rkwu, 
   {{0x4428034c,0xc0e80201,0xab60e978,0x6e407242}},	//   _lha_, _መልስ_, çürm, _ئۆلم, 
   {{0x4428e979,0xb8100022,0xfb8801ec,0xefe80023}},	//   _oha_, аҧжә, _орақ_, _መጽዩ_, 
   {{0x4428e97a,0xe7b00075,0x6b80026c,0x00000000}},	//   _nha_, لمىد, cgog, --, 
   {{0x7c28e97b,0x356800f7,0x44dc0208,0xa3b8473c}},	//   _iher, үрүн_, ẻ_, घाई_, 
   {{0x4428e97c,0x69f01e49,0x00000000,0x00000000}},	//   _aha_, _күчт, --, --, 
   {{0x4428e97d,0x7c28e97e,0x69d400dc,0xe1fc1427}},	//   _bha_, _kher, _भवती, rsól_, 
   {{0xc20800d9,0x32440166,0x00000000,0x00000000}},	//   _וה_, кемг, --, --, 
   {{0x4428e97f,0x7c28e980,0x35a4004e,0x2634012d}},	//   _dha_, _mher, _аалг, _złom_, 
   {{0x4428e981,0x7c28304b,0x764c0166,0x00000000}},	//   _eha_, _lher, _çayq, --, 
   {{0x7c28e982,0x703802d5,0x4428e983,0x69c0041c}},	//   _oher, дчас_, _fha_, लाती, 
   {{0x4428e984,0x7c28e985,0xada401e1,0x28d000bc}},	//   _gha_, _nher, _ojúù, तहति, 
   {{0xee38e986,0xb224a9c2,0xef18e987,0xfe7001ed}},	// [143c0] дна_, _имил, фма_, یدے_, 
   {{0x7c28e988,0xdd8c129d,0x4428e989,0x3eac031c}},	//   _aher, يوق_, _zha_, _ġett_, 
   {{0x4428e98a,0xfe7007a7,0xc0e80020,0x7c28e98b}},	//   _yha_, لدە_, _መልሶ_, _bher, 
   {{0xdcac0131,0x4428e98c,0x6aa002e2,0xba3c013a}},	//   غىن_, _xha_, twof, _průp, 
   {{0x6b80e98d,0x7c28e98e,0xaab8e98f,0xceb80032}},	//   rgog, _dher, بدار_, _яҙа_, 
   {{0x7c28e990,0x2d9c012c,0x6b800042,0xbc2410e0}},	//   _eher, _úte_, sgog, _ەركى, 
   {{0x7c2800a3,0x6d4ce991,0x98c000a7,0x67fc00e2}},	//   _fher, _ifba, исъл, līji, 
   {{0x4a700491,0x7c28e992,0xab280220,0x6aa00100}},	//   _ɱęḏǭ, _gher, _жоба_, pwof, 
   {{0xe9a40022,0x67fc00e2,0xaa440a5b,0xada002d2}},	//   _иаап, nīji, _резл, _þúsk, 
   {{0x4428e993,0xc1d0033f,0x7c280200,0xc45800c7}},	//   _sha_, _सकेग, _zher, ниох_, 
   {{0xd82ce994,0xdb181f3f,0x4428e995,0xd94004a9}},	//   _вэ_, _anuè, _pha_, _техи, 
   {{0x4428e996,0x7c28e997,0x27280ca8,0x00000000}},	//   _qha_, _xher, _ẹnu_, --, 
   {{0x4428e998,0x6d4c01c7,0xc59406ed,0x6ed8002b}},	//   _vha_, _ofba, _билј, _jābā, 
   {{0x4428e999,0x27100ca8,0x69c80369,0x67fc005f}},	//   _wha_, _e̟nì_, njfe, dīji, 
   {{0x4428da40,0xc0e8069c,0xdb18067c,0x5118e99a}},	//   _tha_, _መልሲ_, _enuè, ворю_, 
   {{0x4428e99b,0x6d4c3e1d,0x43940022,0xf5241cb8}},	//   _uha_, _afba, _ёапс, _сфін, 
   {{0x3d945cfa,0x6ed80055,0x00000000,0x00000000}},	// [143d0] лиар, _nābā, --, --, 
   {{0x7c28e99c,0x8d74c9a4,0xada000d7,0x00000000}},	//   _sher, لاما, _žúrk, --, 
   {{0x7c28e99d,0xd01000dd,0x628ce99e,0x00000000}},	//   _pher, صلے_, ltco, --, 
   {{0xbf1426c6,0x628c0051,0x67fc00ef,0x00000000}},	//   _موجب, otco, bīji, --, 
   {{0x628c560b,0x3b080598,0x9a841b88,0xe89402d3}},	//   ntco, çaq_, туел, _መርገም_, 
   {{0x7c28e99f,0x628ce9a0,0x7e6cdc41,0xd88001d5}},	//   _wher, itco, msap, لهتی, 
   {{0x7c28e9a1,0xc984e9a2,0x7e6ce9a3,0xc5f8003a}},	//   _ther, ручи, lsap, diē_, 
   {{0x63bc003e,0x7c28e9a4,0x7f4c0213,0x7e6c000d}},	//   _nnqn, _uher, ncaq, osap, 
   {{0xd76001e2,0x00000000,0x00000000,0x00000000}},	//   هنګی, --, --, --, 
   {{0x7e6c0810,0x0a5801f0,0x00000000,0x00000000}},	//   isap, _рафъ_, --, --, 
   {{0xa3dc0574,0x660401d3,0x2450029e,0x00000000}},	//   णसं_, ékka, ینیس, --, 
   {{0x628ce9a5,0xa938010f,0x644c00e4,0x00000000}},	//   ftco, _װײני, íbia, --, 
   {{0x7e6c9915,0x48240131,0x59c40825,0x00000000}},	//   jsap, _ئىنق, लापर, --, 
   {{0x61e4026c,0x7e6c01f5,0x05600092,0x00000000}},	//   ghjl, dsap, _ለአሜሪ, --, 
   {{0x85b801d9,0xe4d41ec7,0x7648e483,0x7e6c0066}},	//   _جانس_, _مووت_, lqey, esap, 
   {{0x6d4c00ca,0xdce4012c,0x67fc005f,0xb38426b1}},	//   _sfba, ůměr, tīji, _слил, 
   {{0x7e6ce9a6,0x628ce9a7,0xdd8c00aa,0x76480014}},	// [143e0] gsap, ctco, ړول_, nqey, 
   {{0xc1d40032,0x7a2c002d,0xefec001f,0x67fc00e2}},	//   _көсә, lútf, ቀቂያ_, rīji, 
   {{0xf8a4a55b,0xc100e9a8,0xe5f400c8,0x69c0073d}},	//   _بک_, _дүрл, נזער_, लासी, 
   {{0x80a0068f,0x7f4c003a,0x6d4c0334,0xe4f40ebb}},	//   खबरे, ccaq, _wfba, ुपति_, 
   {{0xfb242002,0x7e6c01ed,0x77680789,0x94f0031c}},	//   ۇرۇپ, csap, daex, _བཟའི_, 
   {{0x9d400395,0x00000000,0x00000000,0x00000000}},	//   _герд, --, --, --, 
   {{0x77680007,0x853c0153,0x270c00fe,0xceb406be}},	//   faex, ndėt, াইছো_, lvə_, 
   {{0x7790107f,0x2ca8e9a9,0x27e009f3,0x6abc02f5}},	//   قیما, _isbd_, ókn_, ্নবো, 
   {{0x23ac069f,0x628ce9aa,0x779020ad,0x62480171}},	//   _जोगद, xtco, تینا, _aļon, 
   {{0x1a98008f,0x77680175,0xb86400ec,0x00000000}},	//   _אימע, aaex, _چانو, --, 
   {{0xb86446ae,0x63b00022,0xceb40213,0x84c404b4}},	//   _نانو, банӡ, hvə_, рәлд, 
   {{0x291c0784,0x7e6c4c27,0x7768007c,0x7c780023}},	//   _iyta_, ysap, caex, _ብቐሊል_, 
   {{0x2e240109,0x291c00a2,0x7e6c0175,0xd49401ec}},	//   zôfa_, _hyta_, xsap, _ұры_, 
   {{0x291c0124,0xe4a400f3,0x00000000,0x00000000}},	//   _kyta_, _брио, --, --, 
   {{0x628ce9ab,0x7e6c02d1,0x00000000,0x00000000}},	//   stco, wsap, --, --, 
   {{0x7e6ce9ac,0x63bc0007,0x9470e9ad,0x291c03b2}},	//   tsap, _unqn, _ادوا, _myta_, 
   {{0x7e6c013c,0x7f4c003a,0x3df4e9ae,0x93780108}},	// [143f0] usap, rcaq, азас, _сбыт_, 
   {{0x2d88e9af,0x291c00e4,0x7f4c003a,0x00000000}},	//   _ccbe_, _oyta_, scaq, --, 
   {{0x7e6c32ff,0x8d745230,0x291ce9b0,0x67fc005f}},	//   ssap, صالا, _nyta_, līju, 
   {{0xa3b82ef1,0x7850005f,0x7e6c2fb8,0x9f48e9b1}},	//   घाट_, _jāve, psap, ämät_, 
   {{0xdef87bac,0x291c6eb3,0x3f980a55,0x2d88004e}},	//   _чын_, _ayta_, _ibsu_, _fcbe_, 
   {{0x291c04f3,0x3eb80230,0x764800ac,0x25ac01d5}},	//   _byta_, _irst_, vqey, _nafl_, 
   {{0x3eb8013a,0xbc4801f0,0x7768007c,0x00000000}},	//   _hrst_, _рӯза_, taex, --, 
   {{0x3eb85797,0x291c0023,0x78501a5a,0x00000000}},	//   _krst_, _dyta_, _nāve, --, 
   {{0x291ce9b2,0x7a3800c7,0x7a2c00d2,0x00000000}},	//   _eyta_, _апар_, vútf, --, 
   {{0x67fc0029,0x09dc031c,0x00000000,0x00000000}},	//   dīju, རྒྱ_, --, --, 
   {{0x3f98022f,0xfd54002b,0x00000000,0x00000000}},	//   _obsu_, _draḍ, --, --, 
   {{0x672c01ed,0x785000b8,0xceb40213,0x7a2c02d2}},	//   önjü, _cāve, yvə_, fútg, 
   {{0x25ac0175,0xf678008f,0xe1fc033f,0x29f4033f}},	//   _fafl_, _סאַמ, nsów_, złam_, 
   {{0x3f980204,0x29f4033f,0xdce4012d,0x00000000}},	//   _absu_, yłam_, _zdją, --, 
   {{0x2164e9b3,0x78500270,0x3eb8e9b4,0xa0640588}},	//   риси_, _fāve, _arst_, иара_, 
   {{0x3168036b,0xf10402ab,0x853c0024,0xe1fc012d}},	//   sabz_, _रशीद_, rdėt, ksów_, 
  
   {{0x67fc00da,0xaec4e9b5,0x643000cf,0x00000000}},	// [14400] cīju, шбал, _بىيئ, --, 
   {{0xed5801c4,0x00000000,0x00000000,0x00000000}},	//   тож_, --, --, --, 
   {{0x3eb80639,0xc30400e5,0x00000000,0x00000000}},	//   _erst_, _نبیو, --, --, 
   {{0x291ce9b6,0x2ea401d9,0x29f40210,0x00000000}},	//   _ryta_, _پھری_, rłam_, --, 
   {{0x291c2201,0x9b9007d6,0x853c00c0,0x29f40210}},	//   _syta_, تلنت, ndėr, słam_, 
   {{0x291ce9b7,0xa8a4249f,0xee0801af,0x00000000}},	//   _pyta_, لصبو, _регл_, --, 
   {{0xfd641682,0x67fc00da,0x00000000,0x00000000}},	//   vhuḓ, zīju, --, --, 
   {{0x98105f8e,0xec143832,0xfa6001d9,0x00000000}},	//   يبيا, _ئورد, _کۯوٝ, --, 
   {{0x28a445bf,0x26040212,0x00000000,0x00000000}},	//   _कैरि, ичог, --, --, 
   {{0xd940e9b8,0x291c0200,0x78500055,0x00000000}},	//   _дефи, _tyta_, _sāve, --, 
   {{0x291c0309,0x785000e2,0x00000000,0x00000000}},	//   _uyta_, _pāve, --, --, 
   {{0x67fc0029,0x69cc0295,0x248c0175,0x7a2c1427}},	//   tīju, _òbeb, _vqfm_, tútg, 
   {{0x06540517,0x27e4e9b9,0x386807f5,0x785000de}},	//   _انتح, _ilon_, ćare_, _vāve, 
   {{0x67fc00da,0x7a2ce9ba,0xe4e8007b,0x00000000}},	//   rīju, rútg, _لعبه_, --, 
   {{0x10483b9f,0x67fc00da,0x3eb8022a,0x785000b8}},	//   ияти_, sīju, _srst_, _tāve, 
   {{0x6e2ce9bb,0xa2640354,0xe1fc0210,0x00000000}},	//   _ahbb, _къол, ysów_, --, 
   {{0x6458e9bc,0x27e403a2,0x2284e9bd,0x752c01e4}},	// [14410] lpti, _mlon_, _туйг, _ĝazi, 
   {{0x3eb8151c,0x27e43c0f,0xd654011a,0x00000000}},	//   _vrst_, _llon_, יימת_, --, 
   {{0x27e40851,0x7a2ce9be,0x9ba01a50,0x38bc00e4}},	//   _olon_, núte, يەسى, _márô_, 
   {{0xba740372,0x6458e9bf,0x3eb846aa,0xa53c0092}},	//   ماتت, ipti, _trst_, _አጠናቀ, 
   {{0xdb0401b8,0xdd0091fc,0x00000000,0x00000000}},	//   _ämüt, ğrıl, --, --, 
   {{0x27e4e9c0,0xba3c00bc,0xe1fc033f,0x3f88e9c1}},	//   _alon_, _hrůz, rsów_, lgau_, 
   {{0x3ea8e9c2,0x27e4e9c3,0xdb180194,0x644ce9c4}},	//   lwat_, _blon_, _inuí, íbil, 
   {{0x3f88e9c5,0x27e40789,0xda640451,0x629c022e}},	//   ngau_, _clon_, _نائي, _opqo, 
   {{0x27e400a3,0x3a74e9c6,0x501c0375,0x644c01e4}},	//   _dlon_, _ылар, כוהו, ŭbil, 
   {{0xe9400014,0x3324031c,0x3f88002f,0x00000000}},	//   _ٹھوٝ, _ġox_, hgau_, --, 
   {{0x3944060a,0x3ea8e9c7,0x3f8800fb,0x27e4e9c8}},	//   _igls_, hwat_, kgau_, _flon_, 
   {{0x3ea8e9c9,0x27e40165,0xc7b42ed7,0x795002f2}},	//   kwat_, _glon_, _وصنع, _بێژا, 
   {{0x13a8cf73,0xe72ce9ca,0xe294e9cb,0x3ea8045f}},	//   هنگی_, _хе_, бая_, jwat_, 
   {{0x629c0175,0x3ea8e9cc,0x7a2c0174,0xda040073}},	//   _dpqo, dwat_, lútb, वचित_, 
   {{0x3ea8089c,0x7a2c00db,0xe0000d79,0x1c1402db}},	//   ewat_, cúte, रचंद_, तवाल_, 
   {{0x7414e9cd,0x00000000,0x00000000,0x00000000}},	//   _دوعا, --, --, --, 
   {{0x3ea8025c,0x79300092,0x00000000,0x00000000}},	// [14420] gwat_, ችሉበት, --, --, 
   {{0xb224084c,0x00000000,0x00000000,0x00000000}},	//   _ымпл, --, --, --, 
   {{0xec78e9ce,0xdca0e9cf,0x7c645026,0x61d4010f}},	//   упе_, захи, قانل, _הויף_, 
   {{0x3ea81c06,0x39440c86,0x7c640137,0x67fc0241}},	//   bwat_, _agls_, تاكل, _màjè, 
   {{0xeaf8e9d0,0xdb1800e8,0x6e2c02d0,0xda6c0014}},	//   درات_, _bouñ, _thbb, فُن_, 
   {{0x27e4e9d1,0xdb180077,0x6458e9d2,0x00000000}},	//   _slon_, _couñ, ypti, --, 
   {{0x27e4e9d3,0x26340210,0x00000000,0x00000000}},	//   _plon_, _młot_, --, --, 
   {{0x394407de,0x7bcc0e03,0x7a2c089f,0xaa440153}},	//   _egls_, öaut, gútb, _геал, 
   {{0x6994e9d4,0x0ec83c71,0x23bc005b,0x27e4036e}},	//   _грех, रमिड, _läjä_, _vlon_, 
   {{0xe5c4e9d5,0x7d24045f,0x44980212,0x00000000}},	//   ссио, _útsû, авою_, --, 
   {{0xd4941c22,0x7a2c000f,0x799400a2,0x70d009ab}},	//   бря_, bútb, _özwa, सहोल, 
   {{0x27e4e9d6,0x6458e9d7,0x67fc0171,0x00000000}},	//   _ulon_, rpti, būja, --, 
   {{0x645802b9,0xdce401e4,0xdb1800e8,0x9f580240}},	//   spti, _vejĉ, _youñ, siqë_, 
   {{0xcb0401dc,0x84c402dd,0x64581876,0x9c8004a7}},	//   _ۣۜ_, _дәмд, ppti, ščis, 
   {{0x661800b8,0xba3c012c,0x6720037e,0x3ea83ce5}},	//   motk, _průz, _hyoj, wwat_, 
   {{0x6720e9d8,0x7f5805f5,0x3ea8057b,0x7f84036b}},	//   _kyoj, раас_, twat_, تلرن, 
   {{0x6448e9d9,0x3f88e9da,0x7850e9db,0x6720037e}},	// [14430] _hufi, rgau_, _māva, _jyoj, 
   {{0xdce4006d,0x3ea8e9dc,0x6618e9dd,0x5cc400fd}},	//   _zdję, rwat_, notk, йсез, 
   {{0x21240016,0x65682892,0x3ea8002e,0x59c46fe9}},	//   _ánh_, _mefh, swat_, लासर, 
   {{0x3ea8079b,0x6618e9de,0xdb1800e8,0x785000dc}},	//   pwat_, hotk, _souñ, _nāva, 
   {{0x6448e9df,0xf42802f6,0x66180ff3,0x39440175}},	//   _lufi, lvää_, kotk, _pgls_, 
   {{0x5ce4e9e0,0xdd1800e8,0x201801d5,0x656802d2}},	//   _люба, _jàŋk, loqi_, _nefh, 
   {{0x6448e9e1,0x6618e9e2,0x672090be,0xe85000f1}},	//   _nufi, dotk, _ayoj, ونود, 
   {{0x59c40316,0x785000dc,0xbaa401d5,0x00000000}},	//   लाहर, _cāva, _музқ, --, 
   {{0x785000da,0x6448e9e3,0xf5e80120,0x661800c0}},	//   _dāva, _aufi, имил_, fotk, 
   {{0x644839aa,0x7a2c0579,0x661805ce,0x20180240}},	//   _bufi, sútb, gotk, hoqi_, 
   {{0x6448e9e4,0x81c0009e,0x00000000,0x00000000}},	//   _cufi, ্ঘা_, --, --, 
   {{0x64482da1,0x59c40833,0xd838094e,0x785000cd}},	//   _dufi, लावर, _сэз_, _gāva, 
   {{0xe56c0510,0x64480421,0x572438eb,0x672004ba}},	//   _оз_, _eufi, _اراق, _gyoj, 
   {{0x6448e9e5,0x6618020c,0x2164e9e6,0xe5a001c6}},	//   _fufi, cotk, жири_, _жиши, 
   {{0x78500a28,0x6448e9e7,0x2018036b,0x00000000}},	//   _yāva, _gufi, foqi_, --, 
   {{0x73e416c3,0x6568003e,0xa378000d,0xe1fc032e}},	//   _фоиз, _zefh, lkõn, fsós_, 
   {{0x29f4068f,0xed585f2e,0x26340034,0x6448e9e8}},	// [14440] cław_, لشات_, _głos_, _zufi, 
   {{0x644801b8,0x2738001f,0x2d8c0112,0x2be000dc}},	//   _yufi, _የኢህአ, üfe_, पस्थ, 
   {{0x6448e9e9,0x2ca8e9ea,0xdd8c1a9b,0x5fd00037}},	//   _xufi, ркеп_, ضون_, _सवचल, 
   {{0xeb98e9eb,0x661805ce,0xeab8010b,0x60100327}},	//   рид_, zotk, ийе_, għmd, 
   {{0x785000dc,0x6618e9ec,0x5f741291,0x00000000}},	//   _rāva, yotk, _باپر, --, 
   {{0x764c03e0,0x785000dc,0x6618022e,0x3208007c}},	//   _çayy, _sāva, xotk, nnby_, 
   {{0xe7841173,0xe7e8e9ed,0x76580334,0x1d0400ee}},	//   оупо, ифик_, _atwy, _дери_, 
   {{0x6448e9ee,0xbb58037e,0x00000000,0x00000000}},	//   _rufi, _eyeゴ_, --, --, 
   {{0x09c400bd,0x66187dec,0x62480327,0x77780175}},	//   ্সবা, totk, _iżog, _ddwx, 
   {{0x7e6800ee,0x44f402bf,0xf428023a,0xa3780254}},	//   _çepe, зпос, yvää_, gkõn, 
   {{0x78500a28,0xe7a80b7e,0x48c4013d,0x656808a5}},	//   _tāva, _ввел_, _хәла, _vefh, 
   {{0x77780175,0x6618e9ef,0xd9180677,0xdb0800e5}},	//   _gdwx, sotk, _דובל, ldgá, 
   {{0x6448013f,0x672001f0,0xffb405f5,0x534400a7}},	//   _wufi, _uyoj, үйгэ, дхра, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x29f40034,0x64480ba7,0xd48cba0e,0x7a2ce9f0}},	//   sław_, _uufi, _юр_, núta, 
   {{0x187800c8,0x316401fa,0xe1fc0162,0xc2740a5b}},	//   יטלב, _đoze_, tsós_, _елиј, 
   {{0x5434e9f1,0x7a2c00e4,0x3ebc0042,0x20180200}},	// [14450] _ترور, húta, íwt_, roqi_, 
   {{0xdcb8e9f2,0x4438e9f3,0x2018208d,0xe0480133}},	//   ище_, lms_, soqi_, _پشده_, 
   {{0x8d743ccf,0xe1fc0ba1,0x00000000,0x00000000}},	//   باقا, ssós_, --, --, 
   {{0x20180117,0xdb1800d8,0x38780115,0x0b58346d}},	//   qoqi_, _anuá, _ĉsr_, оршы_, 
   {{0x6010038f,0x75ec002d,0x4438e9f4,0xa3e002a0}},	//   għme, _húze, ims_, _धवन_, 
   {{0xa9640cfc,0x69c0012c,0xaea042c6,0x75ec00d0}},	//   пиша_, लागी, _سەمي, _kúze, 
   {{0x44380009,0x7e6800a2,0x00000000,0x00000000}},	//   kms_, _çepb, --, --, 
   {{0x75ec56b1,0x4438e9f5,0x00000000,0x00000000}},	//   _múze, jms_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x443802d5,0x98c426c0,0x996400d8,0xf1980150}},	//   ems_, _وغان, _фтал, _ﺘﻤﺎﻡ_, 
   {{0x7a2c0077,0x5edc0011,0xe75401d5,0x394c0165}},	//   cúta, _নেমে, غلیغ_, ālsā_, 
   {{0xdce40316,0x471c01f2,0x44380f85,0x76f4009d}},	//   _nejč, ịvụ_, gms_, _нялх, 
   {{0x75ec01f1,0xe2944a1a,0xab64000d,0x00000000}},	//   _púzd, пая_, lsüü, --, 
   {{0xd58404d3,0x4438e9f6,0x07080451,0x66b802e4}},	//   _بێده_, ams_, _بيهي_, _למנה, 
   {{0x3114069f,0x32082611,0xf8bc3d1d,0x0544001f}},	//   _दुखः_, rnby_, ्मिय, _ከአሜሪ, 
   {{0xe040e9f7,0xb4c8012d,0x4438833a,0x2fc4002e}},	//   енси, ोही_, cms_, ñog_, 
   {{0x6e4403e6,0x5edc0154,0x00000000,0x00000000}},	// [14460] سنام, _নেবে, --, --, 
   {{0xb63c037e,0xf8bc4f3c,0xab640254,0x00000000}},	//   _ａｉ_, ्माय, ksüü, --, 
   {{0xdd8ce9f8,0x360c015b,0x71f8bfb2,0x00000000}},	//   اوم_, _হঠাৎ_, _نرگس_, --, 
   {{0x20540bd9,0x5f14000d,0x68fc03e3,0xe45400df}},	//   _מיטל_, _भुक्_, _üzdə, ליעט_, 
   {{0xddc80153,0xda60146a,0x00000000,0x00000000}},	//   šišk, евчи, --, --, 
   {{0x785000b8,0x7a2c00c7,0x28682b2e,0x00000000}},	//   _cāvo, túta, брио_, --, 
   {{0x4438e9f9,0x00000000,0x00000000,0x00000000}},	//   yms_, --, --, --, 
   {{0x1a644e5c,0x7a2c00c7,0x699c0037,0x00000000}},	//   _کیوی_, rúta, _खउवी, --, 
   {{0xd7ec016c,0x00000000,0x00000000,0x00000000}},	//   _ҷу_, --, --, --, 
   {{0x7a2c00d0,0x21ec0112,0xb4c80037,0xf8ac2c37}},	//   lútn, _kühe_, ोहू_, _چکي_, 
   {{0xd7ece9fa,0x69d8035a,0x443878ed,0xa34401c6}},	//   _зу_, _iote, tms_, зэгл, 
   {{0x21ec03fa,0x4db800cc,0x00000000,0x00000000}},	//   _mühe_, _আকোৱ, --, --, 
   {{0x69d8e9fb,0x4438e9fc,0xdce4009b,0xdebc0092}},	//   _kote, rms_, _rejč, ዱባን_, 
   {{0x4438e9fd,0x69d8e9fe,0x4614e9ff,0xdb2006af}},	//   sms_, _jote, _توتر, éréo, 
   {{0x69d89024,0xdce40e04,0x4438ea00,0xd598011a}},	//   _mote, _pejč, pms_, _הבול, 
   {{0x0ec8e60e,0x3ce403e3,0x00000000,0x00000000}},	//   रमंड, _ülvi_, --, --, 
   {{0x69d8ea01,0x20040e04,0xdce401ef,0x00000000}},	// [14470] _oote, đni_, _vejč, --, 
   {{0x69d8ea02,0x2738001f,0x00000000,0x00000000}},	//   _note, _የኢሕአ, --, --, 
   {{0xdce40010,0x9918012d,0x00000000,0x00000000}},	//   _tejč, _पुंछ_, --, --, 
   {{0x69d80325,0x00000000,0x00000000,0x00000000}},	//   _aote, --, --, --, 
   {{0x69d8ea03,0x7c380042,0x00000000,0x00000000}},	//   _bote, rmwr, --, --, 
   {{0xbde4020c,0x3858ea04,0xa9a007d6,0xce581058}},	//   _dhèè, орию_, вишд, _харц_, 
   {{0x69d8ea05,0x00000000,0x00000000,0x00000000}},	//   _dote, --, --, --, 
   {{0x69d8005a,0xec180131,0xab640254,0xee4400e4}},	//   _eote, _десә_, rsüü, ñývo_, 
   {{0x7bc8ea06,0x91d00034,0x6d48ea07,0xab640254}},	//   _ineu, दामै, şlaş, ssüü, 
   {{0x69d8ea08,0xa37800af,0x00000000,0x00000000}},	//   _gote, skõl, --, --, 
   {{0x7bc823f3,0xb4c81546,0x00000000,0x00000000}},	//   _kneu, ोहे_, --, --, 
   {{0x69d8ea09,0x798c0198,0x28a4012d,0x00000000}},	//   _zote, ɗawa, _कैटि, --, 
   {{0x69d8ea0a,0x7a2c0030,0xe98400db,0x29f4012d}},	//   _yote, núto, _راەۋ, płat_, 
   {{0xdddc0784,0xf50438d4,0x65c00024,0x00000000}},	//   yuqš, _озло, _абша, --, 
   {{0x33d401ec,0x3cf8012d,0x7a2c0419,0x48a8010a}},	//   _жіпт, ्पों_, húto, _ятăм_, 
   {{0x7a2c3afd,0xd5840133,0x00000000,0x00000000}},	//   kúto, _بێگه_, --, --, 
   {{0x2d94ea0b,0xdb08002f,0x00000000,0x00000000}},	// [14480] дрес, ndgä, --, --, 
   {{0xfa4c0023,0x00000000,0x00000000,0x00000000}},	//   _ንሰላማ, --, --, --, 
   {{0xd34404fb,0x5edc03d4,0x00000000,0x00000000}},	//   _تفکی, _নেদে, --, --, 
   {{0x69d8ea0c,0x7bc80142,0x00000000,0x00000000}},	//   _sote, _cneu, --, --, 
   {{0x69d8ea0d,0xfe701291,0x34c81546,0x00000000}},	//   _pote, _مدّ_, िमुद, --, 
   {{0x7bc80c3a,0x69d80ba7,0x245800b8,0x7e6806be}},	//   _eneu, _qote, _hīme_, _çepa, 
   {{0x69d8e1b2,0x9d400f15,0x98a00063,0x00000000}},	//   _vote, _аерд, вије, --, 
   {{0x69d8ea0e,0x7a2cea0f,0x7bc8015d,0xdca00484}},	//   _wote, búto, _gneu, _шаси, 
   {{0x24d00150,0xdce40171,0xb8d42c2e,0x00000000}},	//   _ﯕﻌﯘﻟ, _iejā, _चै_, --, 
   {{0x7bc80232,0x69d8127b,0x245800de,0x7afc00a2}},	//   _zneu, _uote, _līme_, _ýsta, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x186400d8,0x00000000,0x00000000,0x00000000}},	//   _цаци_, --, --, --, 
   {{0xf60800aa,0xc17c0023,0x00000000,0x00000000}},	//   _کتنه_, _ንምልኪ_, --, --, 
   {{0xd84c063f,0x00000000,0x00000000,0x00000000}},	//   pọtu_, --, --, --, 
   {{0xc10405e6,0x00000000,0x00000000,0x00000000}},	//   روري, --, --, --, 
   {{0xdb0801bf,0xa4240354,0x00000000,0x00000000}},	//   ldgå, _юьлл, --, --, 
   {{0x2e2400d2,0xf2c0ea10,0x60100327,0x00000000}},	// [14490] hôfu_, _йөри, għma, --, 
   {{0x7bc8ea11,0xdb086130,0x785000ef,0xbfd000fb}},	//   _sneu, ndgå, _dāvj, _өҙгө, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69dc29a8,0x7a2c473a,0x77ec0037,0x00000000}},	//   öpen, túto, _जतेक_, --, 
   {{0xdce400de,0x624800de,0x00000000,0x00000000}},	//   _dejā, _gļot, --, --, 
   {{0x7bc80cfd,0xdb080023,0x245800e2,0x00000000}},	//   _wneu, legë, _zīme_, --, 
   {{0x7a34010e,0xd90c0133,0x49b8c35c,0xa9d00116}},	//   _aýtý, جیا_, باند_, اقىغ, 
   {{0x7bc80481,0xbb5801c0,0x2bc40b4c,0xf7380092}},	//   _uneu, _хаах_, _रोपा, _የሳይን, 
   {{0x3c3403d4,0x98bc03e0,0x00000000,0x00000000}},	//   gåve_, ırık_, --, --, 
   {{0xb464bdd4,0x09b8007b,0x75ec00e5,0xc0c80023}},	//   нкол, _يطلع_, _búza, ጠቐሰ_, 
   {{0x46e800f7,0xe5740276,0x06e8004e,0x00000000}},	//   здөн_, эзэ_, змөк_, --, 
   {{0x8ca80406,0xf8bc23c1,0x00000000,0x00000000}},	//   _घनघो, ्मीप, --, --, 
   {{0xd9e000e1,0xb6a40408,0x24940214,0xe60c1c35}},	//   _औकात_, _чилл, ونید_, _бд_, 
   {{0xe2a42880,0x2bc41152,0x75ec00d7,0x00000000}},	//   óðar_, _रोना, _fúza, --, 
   {{0x1c1c1f14,0x00000000,0x00000000,0x00000000}},	//   यकाल_, --, --, --, 
   {{0x60200323,0x942400cf,0xc7b80055,0x00000000}},	//   гдса, _جوبۇ, _khīṇ, --, 
   {{0x644c01e4,0xc340010a,0x00000000,0x00000000}},	// [144a0] ŭbit, _вĕт_, --, --, 
   {{0xd1d4001f,0xdce40171,0xaec40150,0x00000000}},	//   ረታች_, _sejā, мбұл, --, 
   {{0x7e68496e,0x7a2c03f2,0x00000000,0x00000000}},	//   _çepn, rútl, --, --, 
   {{0x7a2c03b2,0x00000000,0x00000000,0x00000000}},	//   sútl, --, --, --, 
   {{0x5b203a22,0xdb08381a,0x00000000,0x00000000}},	//   льша, negè, --, --, 
   {{0x286801df,0x5a300111,0xe3bc0588,0x59c40b67}},	//   прио_, гніт, moñe_, लागर, 
   {{0x6d4cea12,0xdce400b8,0x3d1001f9,0x00000000}},	//   _igba, _tejā, थपणे_, --, 
   {{0xa730010b,0xe664ea13,0xdc9800df,0x00000000}},	//   лдйә, нтоо, _מילל, --, 
   {{0xa9a4329e,0x00000000,0x00000000,0x00000000}},	//   _пиад, --, --, --, 
   {{0x6d4c0332,0x00000000,0x00000000,0x00000000}},	//   _jgba, --, --, --, 
   {{0x6d4c05db,0xa37800af,0x0458007b,0x26c00115}},	//   _mgba, lkõi, بلجة_, ŭko_, 
   {{0x2bc45360,0x988801ed,0xb86401f7,0xca8c0023}},	//   _रोमा, _رحمہ_, _شامو, _ዓይኖም_, 
   {{0x6d4c02e3,0xa3780254,0x00000000,0x00000000}},	//   _ogba, nkõi, --, --, 
   {{0x6d4cea14,0x368814d4,0xdb0403cd,0x75ec01d3}},	//   _ngba, _ісін_, _åmåt, _húzn, 
   {{0xb7bc054e,0x86e4004b,0xdb080200,0x55b8011a}},	//   soţe, _سړکو, tegë, _ממגו, 
   {{0x6d4cea15,0xb7bc054e,0xd1d40092,0x00000000}},	//   _agba, poţe, ረታቻ_, --, 
   {{0x4fc40124,0x00000000,0x00000000,0x00000000}},	// [144b0] ысра, --, --, --, 
   {{0x628cea16,0x63ac0bb3,0xf4f4010e,0x69dc0108}},	//   muco, lecn, _öýüm_, öpel, 
   {{0x628cea17,0x557404ac,0xe0e401d5,0xdb0800e5}},	//   luco, געבן_, _чўпо, megé, 
   {{0xba741473,0x63ac0122,0x6d4c4c43,0xda9405a2}},	//   ناتت, necn, _egba, ескә_, 
   {{0x628cea18,0x00000000,0x00000000,0x00000000}},	//   nuco, --, --, --, 
   {{0x8d747092,0xdb086428,0xc9840063,0xa3780254}},	//   _مافا, negé, гући, skõh, 
   {{0x5ba41f5c,0x2df80014,0x628cea19,0xade401d3}},	//   _праз, _آبُک_, huco, _جہلم_, 
   {{0x63ac1e31,0xc8880075,0x628c48b5,0x88c40e31}},	//   jecn, رخىل_, kuco, اتول, 
   {{0x628cea1a,0x63ac02f0,0x78500055,0x7a2c0419}},	//   juco, decn, _māvi, nútk, 
   {{0x628cea1b,0xd1d436d7,0x316405be,0x74e805f5}},	//   duco, ረታት_, _đozo_, ддог_, 
   {{0x98c4ea1c,0xd7e402bf,0x628c01ab,0x00000000}},	//   _ясал, _підо, euco, --, 
   {{0x798002d0,0xe8700131,0xdb08067c,0xe69001d5}},	//   _hdlw, _ئۆيگ, tegè, دلید, 
   {{0x7768ea1d,0x21ec0205,0x00000000,0x00000000}},	//   mbex, _süha_, --, --, 
   {{0x21ec00c5,0x00000000,0x00000000,0x00000000}},	//   _püha_, --, --, --, 
   {{0x7e7cea1e,0x07440022,0x63acea1f,0x75ec00e5}},	//   _avsp, _ихәм, becn, _húzo, 
   {{0x628cea20,0x72c40124,0x785000cd,0x00000000}},	//   buco, _абиз, _cāvi, --, 
   {{0xdee802d3,0x79800472,0x7850005f,0x7e6800a2}},	// [144c0] _ዘርኢ_, _odlw, _dāvi, _çepl, 
   {{0x79800564,0xbc240131,0xe3bc035b,0x6274011a}},	//   _ndlw, ۇرنى, roñe_, _שגיא_, 
   {{0xeb987c0c,0x21ec0086,0xdcac0e76,0xc2c817a5}},	//   дие_, _kühn_, يىك_, _قبیل_, 
   {{0x79800b6f,0x7a2c007b,0x6aa400cc,0xf8c400cd}},	//   _adlw, lúth, _গছবো, विनय, 
   {{0x1cd00489,0x9eb40116,0x1e800064,0x776803b9}},	//   ེདཔ_, _ишрә, _клям, dbex, 
   {{0xa8a40958,0x28a401c0,0x645c0129,0x6d4c5ad0}},	//   врик, вшиг, _épig, _ugba, 
   {{0xa37800af,0x99d003e6,0x6248031c,0x628c012d}},	//   skõi, شتوا, _ożon, zuco, 
   {{0x61dcea21,0xdcf4a822,0xdb0801d3,0x7a2c0332}},	//   _नक्ष, _شفقت_, zegé, húth, 
   {{0x63ac310a,0x2ca80051,0x00000000,0x00000000}},	//   vecn, _hpbd_, --, --, 
   {{0xe5c4013e,0x628c0051,0x2a340064,0x00000000}},	//   тсио, vuco, _рэбр, --, 
   {{0x6248038f,0x2ca805b1,0x21ec0221,0x628c003c}},	//   _bżon, _jpbd_, _bühn_, wuco, 
   {{0x628c58ee,0x6010038f,0xa68401c6,0x75ec00d7}},	//   tuco, għml, _алдд, _fúzo, 
   {{0x63ac596b,0x880000aa,0x75ec00d0,0x2f280153}},	//   recn, _پېښو, _kúzl, _jėgą_, 
   {{0x63ac08a4,0x26c4011f,0x785000cd,0x5184aec3}},	//   secn, _iroo_, _sāvi, иуса, 
   {{0x628cea22,0x15b00131,0xdbcc00d7,0x785019ae}},	//   suco, _ئەپس, _vľúd, _pāvi, 
   {{0x5064ea23,0x26c40254,0x26c00306,0x58b80375}},	//   ртра, _kroo_, ťkou_, ומלצ, 
   {{0x4428ea24,0x2ca8ea25,0x386808a4,0xdd980212}},	// [144d0] _ika_, _apbd_, ćari_, дше_, 
   {{0x4428ea26,0x2ca80263,0x25bc007f,0x00000000}},	//   _hka_, _bpbd_, ndtl_, --, 
   {{0x645cea27,0x4428ea28,0x270c37d0,0xa1300451}},	//   _épid, _kka_, ापुर_, _خودڪ, 
   {{0x4428007f,0x2d9cea29,0x8b940212,0x7980035a}},	//   _jka_, _öten_, иріч, _sdlw, 
   {{0x4428ac09,0x26c40211,0x3c3403d4,0x7a2c003a}},	//   _mka_, _nroo_, gåva_, lúti, 
   {{0x442801a9,0xd0748235,0x3eb80e78,0x00000000}},	//   _lka_, _حدیث, _isst_, --, 
   {{0x4428ea2a,0x9c44ea2b,0x7a2c00d0,0x0cd4117e}},	//   _oka_, _ахал, núti, _корю, 
   {{0x26c464d7,0xa3d405f9,0xe7b00131,0xd1d40092}},	//   _broo_, साफ_, ممىد, ረታታ_, 
   {{0x7c28ea2c,0xa3d422e3,0x4a5467b5,0x26c41368}},	//   _iker, सान_, _вкус, _croo_, 
   {{0x79800921,0x26c45543,0x7c280165,0xc98400f3}},	//   _udlw, _droo_, _hker, _вуци, 
   {{0x44282a17,0x7c2804ba,0x26c4ea2d,0xd3e4ea2e}},	//   _bka_, _kker, _eroo_, لقدی, 
   {{0xd1d40020,0x442802d3,0x26c404e6,0x3694004e}},	//   ረዳት_, _cka_, _froo_, _бшкс, 
   {{0xe2c415e4,0x26c4ea2f,0x7c2801f7,0x35a4ea30}},	//   гляд_, _groo_, _mker, _балг, 
   {{0x4428b42a,0x7c280589,0x7a2c03b2,0x00000000}},	//   _eka_, _lker, fúti, --, 
   {{0x49fc0dd4,0x245804fe,0x442803a0,0x7c28ea31}},	//   ྐྲིལ_, _tīma_, _fka_, _oker, 
   {{0x4428073c,0x7c28ea32,0x9c10063f,0x20a00023}},	//   _gka_, _nker, _sọnl, _ምግላጹ_, 
   {{0xaec4ea33,0xada4ea34,0x7fd40220,0x21ec0e78}},	// [144e0] ыбал, лаал, шірі, _kühl_, 
   {{0x7c28ea35,0xc1040451,0x2a64014f,0xe1fc3a6c}},	//   _aker, _چوٿي, vpob_, lpón_, 
   {{0xfe7020ea,0x3eb8ea36,0x3f9807ab,0x32080158}},	//   مدە_, _esst_, _fcsu_, miby_, 
   {{0xa3d41b76,0x3208239b,0x645c0129,0xa3780254}},	//   साय_, liby_, _épie, skõv, 
   {{0xa1100345,0xbb700137,0x00000000,0x00000000}},	//   _نویت, زۇلع, --, --, 
   {{0x7c28ea37,0x09c40183,0x00000000,0x00000000}},	//   _eker, ্স্থ, --, --, 
   {{0x26c4016b,0xf9680212,0x00000000,0x00000000}},	//   _sroo_, трій_, --, --, 
   {{0x78500093,0x7c2805c7,0x7b0801b8,0x7aec00e5}},	//   _nāvu, _gker, üptä, önté, 
   {{0xdb18067c,0x21ec002f,0x44280055,0x00000000}},	//   _nauè, _bühl_, _rka_, --, 
   {{0x44289c56,0xa9680597,0x26c4062c,0xaa440139}},	//   _ska_, _أمام_, _vroo_, _сезл, 
   {{0xd82cea38,0x7c280022,0x1634007b,0x4428045a}},	//   _гэ_, _yker, دسية_, _pka_, 
   {{0x442802d3,0x26c4ea39,0x00000000,0x00000000}},	//   _qka_, _troo_, --, --, 
   {{0xa3d419e5,0xe3bcea3a,0x4428ea3b,0x21ec0112}},	//   साब_, goña_, _vka_, _fühl_, 
   {{0x44280004,0xbfe000b5,0x3eb8062c,0x00000000}},	//   _wka_, _ios版_, _rsst_, --, 
   {{0x657815e6,0x5064ea3c,0x00000000,0x00000000}},	//   math, йтта, --, --, 
   {{0x6578ea3d,0x44281269,0xdef8ea3e,0x42545220}},	//   lath, _uka_, ныз_, _پندر, 
   {{0x320803d1,0x6578009f,0xdb0408fb,0xe7a401bc}},	// [144f0] biby_, oath, _åmøt, क्यप, 
   {{0x63bcea3f,0x5fa01411,0x4d980108,0x00000000}},	//   _haqn, _گەرم, лкую_, --, 
   {{0x24583d27,0x63bc03f0,0x40341c01,0x3b54ea40}},	//   _jëm_, _kaqn, _венс, акер, 
   {{0x6578ea41,0x6ed80882,0x63bc0477,0x64581444}},	//   hath, ṃban, _jaqn, iqti, 
   {{0x63bcea42,0x6578ea43,0x245800e8,0x00000000}},	//   _maqn, kath, _lëm_, --, 
   {{0x6578ea44,0xf864ea45,0xa3d401ad,0x5338008f}},	//   jath, авко, साड_, אנדן_, 
   {{0x6578ea46,0x75ec045f,0x6248025c,0x2bc40037}},	//   dath, _fúzj, _nżom, _रोवा, 
   {{0x7c28ea47,0xdb0801d3,0x629c022e,0x657801c3}},	//   _uker, legí, _oqqo, eath, 
   {{0x6578ea48,0xe7e4367a,0x8f9c0a7c,0x00000000}},	//   fath, _ओकरा_, גיחי, --, 
   {{0x65784b5d,0x75540640,0xf1b8004d,0x78500055}},	//   gath, шњиц, _ươm_, _sāvu, 
   {{0x68e8009a,0x629cea49,0x63bc0009,0x7640035a}},	//   cyfd, _aqqo, _baqn, rmly, 
   {{0x24588a60,0xe3bc056a,0x0fc401f9,0x00000000}},	//   _dëm_, toña_, _लोंढ, --, 
   {{0x65781253,0x6458ea4a,0x63bc014f,0xdb080356}},	//   bath, aqti, _daqn, legâ, 
   {{0x6578ea4b,0xe1fc1709,0xe3bc25e6,0x7a2c002d}},	//   cath, spón_, roña_, rútw, 
   {{0x629c0eda,0x9f48004e,0x24581574,0x320806d9}},	//   _eqqo, _alcà_, _gëm_, riby_, 
   {{0x2fd8221d,0x6f64ea4c,0xe3bc056a,0xa324063f}},	//   خورد_, рваз, poña_, ụkọt, 
   {{0x75ec000f,0x6d5c0175,0x71000124,0x00000000}},	// [14500] _rúzj, tcpa, сҧҟа, --, 
   {{0xa3d406bc,0x645c06af,0x00000000,0x00000000}},	//   साथ_, _épic, --, --, 
   {{0x7a2c008c,0x245800e8,0x63bc013d,0x6d5cea4d}},	//   nútu, _xëm_, _yaqn, rcpa, 
   {{0x65783824,0x63bc726c,0xc50c008f,0x6d5c035a}},	//   zath, _xaqn, עלאָ, scpa, 
   {{0x65787abf,0xeab00a2c,0xa3d402db,0xefd00023}},	//   yath, تعا_, सात_, የናይ_, 
   {{0x65780117,0x28840114,0x00000000,0x00000000}},	//   xath, аћив, --, --, 
   {{0xfbd00c50,0x6578ea4e,0x4bc4ea4f,0xeb9801b9}},	//   تتە_, vath, _гөлг, _иив_, 
   {{0x24580a40,0x21ec0037,0x68e8ea50,0x57a000c7}},	//   _rëm_, _rühm_, ryfd, ошьа, 
   {{0x6578ea51,0x63bc0548,0xd6d41142,0x8b3400e5}},	//   tath, _raqn, атэ_, _اڑات, 
   {{0x63bc014f,0xe7a4033f,0xb86400ec,0x6aa0ea52}},	//   _saqn, _कॉरप, _ڇانو, mtof, 
   {{0xd7ecea53,0x64580d04,0x6aa0ea54,0x63bc0455}},	//   _ду_, uqti, ltof, _paqn, 
   {{0x6578ea55,0x386801fa,0x63bc0455,0x81e8009e}},	//   sath, ćart_, _qaqn, _মগধ_, 
   {{0x6aa0ea56,0x3074044e,0x7a2c0008,0x6578ea57}},	//   ntof, _ጸብጻብ_, rútv, path, 
   {{0x657800aa,0x7a2c012b,0x6aa0004c,0x7e68010e}},	//   qath, sútv, itof, _çepi, 
   {{0xa3d47c33,0x63bc636d,0xe6b4193d,0x614053f0}},	//   साद_, _taqn, _अनुज, زىرە, 
   {{0x6aa0ea58,0x2bc407f7,0xab601432,0xe1fc1bce}},	//   ktof, _रोला, çülm, ppóo_, 
   {{0xdb2047af,0xe7ec367a,0xe3bc0077,0x2bd800dc}},	// [14510] ürül, _जवना_, loño_, णाना, 
   {{0x5d64ea59,0x1fb40220,0xe7a41a2a,0x5cc401fc}},	//   ртаз, ылғы_, क्तप, исез, 
   {{0x8d7416a0,0xdcb80801,0x00000000,0x00000000}},	//   زالا, ъща_, --, --, 
   {{0x61f402c4,0x6aa00334,0x1fa4ea5a,0xdb08ea5b}},	//   _hlxl, ftof, _трог, segí, 
   {{0xdef828a4,0xab600131,0x6aa001bf,0x78500055}},	//   _рын_, سۇلى, gtof, _nāvr, 
   {{0x99840270,0x683c01c7,0x7a2c0174,0x69ac0210}},	//   monū_, hëdd, jútt, ंजगी, 
   {{0x6aa00421,0x683c01c7,0xaa8400d1,0x00000000}},	//   atof, këdd, لچەم_, --, 
   {{0xe3bc0005,0x88c40b38,0x2cc001d3,0xba5400d8}},	//   doño_, زتىل, ürdő_, _гвај, 
   {{0x291cea5c,0x6010003d,0x6aa0030d,0xd7040131}},	//   _exta_, għmi, ctof, شىدۇ_, 
   {{0x160401b9,0x75ec00d7,0x628c00d7,0x00000000}},	//   рмоқ_, _kúzi, drco, --, 
   {{0x628cd2f7,0x00000000,0x00000000,0x00000000}},	//   erco, --, --, --, 
   {{0x2bd8bc82,0x75ec02f0,0xd6940354,0x4374004e}},	//   णाया, _múzi, _кăмп, журт, 
   {{0x75ec00d2,0x38a0ea5d,0x7afcea5e,0x7664009f}},	//   _lúzi, lór_, _üstd, _اُتم, 
   {{0x7a2cc364,0x66e00116,0xdb081d0e,0x00000000}},	//   múts, _хоша, ldgó, --, 
   {{0x216449c7,0x38a0ea5f,0x2bd8215d,0x00000000}},	//   сиси_, nór_, णामा, --, 
   {{0x7658013f,0x2d9400f7,0x61f402d0,0xa3780037}},	//   _kuwy, өөгө_, _elxl, skõr, 
   {{0x38a00597,0xca340952,0x6aa0b61d,0x7a2c002d}},	// [14520] hór_, ﺮﻩﺭ_, xtof, núts, 
   {{0x38a0ea60,0x75ec0798,0x6aa001bf,0x00000000}},	//   kór_, _búzi, vtof, --, 
   {{0xe66001f2,0x41d40490,0xc0d0001f,0x38a00321}},	//   _mọọb, दारस, ብብር_, jór_, 
   {{0x6aa0ea61,0x38a00008,0xdcac0dd8,0x75ec0798}},	//   ttof, dór_, عىن_, _dúzi, 
   {{0x62882d8b,0xe3bc0077,0x3e88013d,0x7a2cea62}},	//   _ågot, zoño_, _кияү_, júts, 
   {{0x6aa0ea63,0xe2a409cc,0x2bf82aab,0x7a2c045f}},	//   rtof, óðir_, েকেই_, dúts, 
   {{0x6aa0ea64,0xf8c453c3,0xd7d00490,0x99800592}},	//   stof, विषय, थांच, سليو, 
   {{0xec146f43,0x7a2c00d2,0x00000000,0x00000000}},	//   _اورد, fúts, --, --, 
   {{0xa3d4924b,0x6a8400db,0xa968022e,0x00000000}},	//   सास_, _ылаа, _биза_, --, 
   {{0x38a00034,0xe3bc04d4,0x00000000,0x00000000}},	//   bór_, toño_, --, --, 
   {{0xdb0800e5,0x00000000,0x00000000,0x00000000}},	//   megá, --, --, --, 
   {{0x7a2c00d2,0xe3bc528b,0xdb0828c8,0x753403e0}},	//   búts, roño_, legá, üzza, 
   {{0x628cb55f,0x27e42301,0xd61440be,0xdee8069d}},	//   urco, _ioon_, شتیا_, ዘቡን_, 
   {{0x7afcea65,0xe3bc1709,0xa3d4045b,0x80c40073}},	//   _üste, poño_, साह_, ाटले, 
   {{0x27e4005b,0x546400d8,0x83f800c0,0xd46400f3}},	//   _koon_, _лајм_, _вейс_, _лије_, 
   {{0x27e4ea66,0xdb08056a,0x777800e8,0x7a2c19cd}},	//   _joon_, hegá, _xewx, nútr, 
   {{0x27e4d999,0x21ec0254,0x38a00210,0x254c03e3}},	// [14530] _moon_, _lühi_, zór_, ləl_, 
   {{0xa3d42e1e,0x27e4ea67,0x4ea401c6,0x00000000}},	//   साव_, _loon_, ярса, --, 
   {{0x7a2c03b2,0x81f80ed8,0x254c06be,0x00000000}},	//   kútr, _مفکر_, nəl_, --, 
   {{0x38a0ea68,0x27e4ea69,0xd138012d,0x00000000}},	//   vór_, _noon_, żąc_, --, 
   {{0xb4d40b7d,0x38a00034,0x21ec0254,0x254c03e3}},	//   _सप्_, wór_, _pühh_, həl_, 
   {{0x200801ab,0xe7a40709,0xca4800f1,0x38a0148b}},	//   _hmci_, क्सप, ملنه_, tór_, 
   {{0x7e6cea6a,0x0fe001ad,0x27e40f85,0x76580432}},	//   lpap, _पचमढ, _boon_, _suwy, 
   {{0x27e40363,0x9ba00220,0xab6001ec,0xda6400ec}},	//   _coon_, _رەتى, _قۇمى, _هائي, 
   {{0xa3bc19ec,0x7e6cea6b,0x27e4ea6c,0xcd9c013f}},	//   ीयन_, npap, _doon_, _nkrכ, 
   {{0x27e4007f,0x38c801ed,0x7a2cea6d,0x34844fe1}},	//   _eoon_, _پائی_, rúts, огог, 
   {{0xca48152b,0x27e4ea6e,0x66080036,0x7e6c0113}},	//   _الله_, _foon_, _dmfk, hpap, 
   {{0x38840029,0x7e6cea6f,0x27e4ea70,0x7a2c002d}},	//   mēr_, kpap, _goon_, púts, 
   {{0xe72c090b,0x645c07ea,0x3178003e,0xe60cea71}},	//   _це_, _épin, _pepz_, _жд_, 
   {{0x27e40cf9,0x200800e8,0x250804d3,0x254c06be}},	//   _zoon_, _amci_, اریی_, bəl_, 
   {{0x27e43d27,0x85b8ea72,0x2fc00099,0xa504ea73}},	//   _yoon_, _دانس_, _pakg_, _меша_, 
   {{0xb4d4ea74,0xbb5001ec,0x609400ae,0x00000000}},	//   समी_, _ﺎﻟﻡ_, تنفس_, --, 
   {{0x7e6cea75,0xa3d43644,0xdb1800a2,0x657406be}},	// [14540] gpap, सार_, _onuñ, _şahə, 
   {{0xf2380139,0x00000000,0x00000000,0x00000000}},	//   _әпүш_, --, --, --, 
   {{0x9f440296,0xe6b40b6d,0xdb08021c,0x7c6400d1}},	//   ɔní_, _अन्ज, vegá, كانل, 
   {{0x83dc0118,0x00000000,0x00000000,0x00000000}},	//   यायआ, --, --, --, 
   {{0x27e4ea76,0x254c03be,0x6010003d,0xda7402e8}},	//   _roon_, zəl_, għmu, оящ_, 
   {{0x27e4ea77,0x908802d3,0x21ec000d,0x00000000}},	//   _soon_, _ንልዕሊ_, _pühi_, --, 
   {{0x27e4ea78,0xdb080306,0x98c000fb,0x00000000}},	//   _poon_, regá, дсыл, --, 
   {{0x254c0cc1,0x27e4058a,0xdb08005c,0x00000000}},	//   vəl_, _qoon_, degæ, --, 
   {{0xe7a41a2a,0x27e405b1,0x7a2c65a1,0x00000000}},	//   क्षप, _voon_, rútr, --, 
   {{0x27e41105,0x245802b5,0x1a6400dd,0x21ec00af}},	//   _woon_, _hīmi_, _بیوی_, _tühi_, 
   {{0x27e4ea79,0xa3d40cb4,0x75c8ea7a,0xf1dc1fe7}},	//   _toon_, साल_, стың_, मानन, 
   {{0x3fc4015b,0x7e6cea7b,0x00000000,0x00000000}},	//   _এক্ষ, ypap, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x14b401ed,0x18540150,0xdb08005c,0x7e6c01bf}},	//   حدیث_, _ارەڭ, begæ, vpap, 
   {{0xba3c0316,0x7e6c03f0,0x04c800ec,0x00000000}},	//   _způs, wpap, _چوڻي_, --, 
   {{0x7e6caf95,0xdb1800d8,0x7f5801c0,0x5f74129e}},	//   tpap, _sauí, саас_, تاسر, 
   {{0x8f340022,0x626400be,0x00000000,0x00000000}},	// [14550] детц, _بابق, --, --, 
   {{0xe2a409f3,0xf2d000c8,0xdb080432,0x00000000}},	//   óður_, _װעט_, legç, --, 
   {{0x7e6cea7c,0x40346ff7,0x66180165,0x00000000}},	//   spap, _неос, intk, --, 
   {{0x7e6cea7d,0x75ec00e5,0x46bc1810,0xad4400db}},	//   ppap, _húzt, ्टाह, سىنۉ, 
   {{0x7e6c0309,0x9f5c002e,0x00000000,0x00000000}},	//   qpap, _ñuñ_, --, --, 
   {{0xb7bc0276,0xa3d401ad,0xc0d4001f,0xf1dccc41}},	//   moţi, साँ_, ረጣል_, मायन, 
   {{0xb7bc054e,0x00000000,0x00000000,0x00000000}},	//   loţi, --, --, --, 
   {{0xe7a430a4,0xe3bc030a,0x69dcea7e,0x6618ea7f}},	//   क्लप, soñj_, öper, entk, 
   {{0xf77080c2,0x9a840108,0x00000000,0x00000000}},	//   واک_, _фубл, --, --, 
   {{0x245800e2,0x00000000,0x00000000,0x00000000}},	//   _zīmi_, --, --, --, 
   {{0xc3280302,0x645c07ea,0xa3d400dc,0xb4d42144}},	//   _עו_, _épil, सां_, समे_, 
   {{0x3d18012c,0x2164013e,0x00000000,0x00000000}},	//   _दशैं_, ҷири_, --, --, 
   {{0xf748007b,0x977001af,0x00000000,0x00000000}},	//   _الشي_, _етһә, --, --, 
   {{0x216473e3,0xded00092,0xb4644130,0xe5a0022e}},	//   зири_, ረጃና_, _еккл, _зиши, 
   {{0x99840118,0xdb080432,0x00000000,0x00000000}},	//   honů_, legä, --, --, 
   {{0x998400bc,0xa3d400cd,0x00000000,0x00000000}},	//   konů_, साः_, --, --, 
   {{0xdb08025a,0x2bd80073,0x2bc4078a,0xfe700014}},	// [14560] negä, णासा, _रोगा, ندٕ_, 
   {{0x7ce0063f,0xad584ed4,0x27380092,0x6444031c}},	//   _ịrah, срах_, _ከኢህአ, ċkie, 
   {{0xdd8cea80,0x21740a1e,0x2ca82309,0xfd4c00b8}},	//   طون_, _מתיר_, скеп_, _kroṣ, 
   {{0xeb98016c,0x5f040034,0x60d80375,0x998400bc}},	//   сид_, _सेक्_, _הקטנ, fonů_, 
   {{0x2e240109,0xa3bc5572,0x998401ef,0x00000000}},	//   zôfy_, ीयत_, gonů_, --, 
   {{0xdb08ea81,0x14d80882,0x195000b5,0x00000000}},	//   zegç, यमाण, _ｉｔｋ_, --, 
   {{0x29e00032,0x62480327,0x6144aeea,0xed5801a9}},	//   _үҙең, _iżot, mélé, _воҳ_, 
   {{0x6144ea82,0xab64ea83,0xc6f8ea84,0x1d0400ee}},	//   lélé, _хвал, жних_, _эеси_, 
   {{0x6b800421,0xf420015b,0x683c036e,0xe1fc0332}},	//   maog, নতার_, gëda, spói_, 
   {{0x6b8006d9,0x7afc51bb,0x25840118,0x661801bf}},	//   laog, _üsta, dílí_, untk, 
   {{0x6b800b23,0xc4b4015b,0x3a0804f2,0x53440022}},	//   oaog, টিভঙ, _بکنی_, ҵхра, 
   {{0x6b80ea85,0x67200070,0x6144ad72,0x7d000790}},	//   naog, _txoj, hélé, _ülse, 
   {{0xa7381002,0x61440085,0x6b800421,0x534473ef}},	//   _اثار_, kélé, iaog, ехра, 
   {{0x17180302,0x6b80ea86,0xb7bc0356,0x1664010a}},	//   _פוגע, haog, voţi, _хĕрӳ, 
   {{0x6b80ea87,0x61440129,0x40345211,0x3fc40116}},	//   kaog, délé, девс, мрағ, 
   {{0xdb0848a1,0x62480327,0x3d1800bc,0xdf5000cf}},	//   legå, _ażot, _दशौं_, енбө, 
   {{0x6b80ea88,0xa3d07662,0x614401d3,0x57f8011a}},	// [14570] daog, _होय_, félé, צלמו, 
   {{0x61447c70,0xdb0800b5,0x0e341b0a,0x00000000}},	//   gélé, negå, еную, --, 
   {{0x4438ea89,0x271c001e,0x6b801140,0xb7bc0276}},	//   ols_, ịnh_, faog, soţi, 
   {{0xa3d01d72,0x44cc038e,0x6248025c,0xdb0801b8}},	//   _होम_, _mě_, _eżot, yegä, 
   {{0x4438ea8a,0xd90c00dd,0xfaa4688a,0xb5fcea8b}},	//   ils_, گیا_, фало, opšt, 
   {{0x3ea8ea8c,0x614407ea,0x6b800421,0x00000000}},	//   mtat_, célé, aaog, --, 
   {{0xd90cc6b3,0x44cc012c,0x4438005f,0xdb0812e8}},	//   دیا_, _ně_, kls_, degå, 
   {{0x4438ea8d,0x69cc03b2,0xe7b000d1,0x683c0200}},	//   jls_, _óben, نمىد, tëda, 
   {{0x9f4845a7,0xc76412b7,0x44380042,0xb4d400dc}},	//   _alcú_, رايى, dls_, सम्_, 
   {{0x4438e1b2,0x683c0200,0x00000000,0x00000000}},	//   els_, rëda, --, --, 
   {{0x3ea8e175,0xdb080036,0xfd4c002b,0x7c380142}},	//   htat_, segä, _proṣ, olwr, 
   {{0x4438060a,0x3ea8ea8e,0x7d040165,0x44cc01ef}},	//   gls_, ktat_, izhs, _dě_, 
   {{0x3ea8044e,0x35a40228,0xe7943253,0xfc243cd9}},	//   jtat_, _жалг, _زانک, _ەڭ_, 
   {{0x4254ea8f,0x4438ea90,0x6b800099,0xa3d000e1}},	//   етст, als_, zaog, _होठ_, 
   {{0xa0a0ea91,0x4438ea92,0x61449d74,0x3ea835f5}},	//   кард, bls_, vélé, etat_, 
   {{0xa0640261,0x7eb000e4,0x00000000,0x00000000}},	//   ќата_, _ẽpav, --, --, 
   {{0xb224ea93,0x6b80ea94,0x6144ea95,0xee300451}},	// [14580] _омил, vaog, télé, نٽر_, 
   {{0x7c380421,0x6b8001c8,0x2bc487ee,0xaab801d9}},	//   elwr, waog, _रोजा, ۪دار_, 
   {{0xfe700447,0x61447d35,0x3ea8ea96,0xa3d005dc}},	//   ندە_, rélé, atat_, _होड_, 
   {{0x7c6419db,0xa3d405d7,0x3ea800db,0xdca00640}},	//   ءالل, साए_, btat_, ђачи, 
   {{0xaab8df81,0x6144003e,0x6b80ea97,0x00000000}},	//   تدار_, pélé, raog, --, 
   {{0x5f040a28,0x6b80ea98,0x28680063,0xec98009b}},	//   _सेट्_, saog, орио_, _мтбј_, 
   {{0x6b800618,0x00000000,0x00000000,0x00000000}},	//   paog, --, --, --, 
   {{0xab28ea99,0x9b90007b,0xc78400cf,0x00000000}},	//   _доба_, _للفت, رابۉ, --, 
   {{0xdb08005c,0x00000000,0x00000000,0x00000000}},	//   tegå, --, --, --, 
   {{0x4438ea9a,0x645c00c7,0x00000000,0x00000000}},	//   wls_, _épik, --, --, 
   {{0x69d8ea9b,0x4438ea9c,0xdb0800ed,0x3ea8ea9d}},	//   _inte, tls_, regå, ztat_, 
   {{0x3ea8ea9e,0x4438ea9f,0x69c8eaa0,0x69d8003e}},	//   ytat_, uls_, ldfe, _hnte, 
   {{0x4438eaa1,0xdb0808fb,0xa490030f,0x69c8eaa2}},	//   rls_, pegå, ریکت, odfe, 
   {{0x69c8eaa3,0x62480327,0x44cc012c,0x69d8003e}},	//   ndfe, _ażor, _tě_, _jnte, 
   {{0x69c8002d,0x683c0240,0x69d80129,0x00000000}},	//   idfe, nëdo, _mnte, --, 
   {{0x3ea8eaa4,0x69d8eaa5,0x200ceaa6,0x853c0064}},	//   ttat_, _lnte, ògi_, rgėd, 
   {{0x69d8eaa7,0x3ea8eaa8,0xda1ccd66,0x00000000}},	// [14590] _onte, utat_, _बदलत_, --, 
   {{0x3ea8eaa9,0xa3d08fa7,0x8d74eaaa,0x6248031c}},	//   rtat_, _होत_, ناما, _eżor, 
   {{0xdb18eaab,0x69c845dc,0x21ec002f,0x066c0023}},	//   _kauç, ddfe, _führ_, _ተኣኪቡ_, 
   {{0x3ea8eaac,0x69c8eaad,0x6aa400fe,0x00000000}},	//   ptat_, edfe, _গছজো, --, 
   {{0x3ea80d04,0x1ea800e3,0xbb5002dd,0x00000000}},	//   qtat_, _باجي_, _ﺎﻟﻲ_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x5ba4eaae,0x28c04d53,0x69d8003e,0xc9840108}},	//   _ораз, _वैदि, _dnte, тучи, 
   {{0x69d8eaaf,0x61c800dc,0xa7a4074d,0x2d9c56f8}},	//   _ente, ायुष, екъа_, _öter_, 
   {{0xe7340107,0x00000000,0x00000000,0x00000000}},	//   неъ_, --, --, --, 
   {{0x7bc80226,0x99d41095,0x00000000,0x00000000}},	//   _haeu, _تترا, --, --, 
   {{0x7bc80c6a,0x79800036,0xdb1845d8,0xc9840f81}},	//   _kaeu, _ielw, _bauç, _шути, 
   {{0x9f480a16,0xdb183c3c,0x79800142,0xa25800e4}},	//   _você_, _cauç, _helw, yvôt, 
   {{0x69d8eab0,0x7bc80369,0x828002dd,0xc5b4009d}},	//   _ynte, _maeu, аңыз, хрөө, 
   {{0x7980073c,0x7bc80097,0xe7d40150,0x00000000}},	//   _jelw, _laeu, _يمەگ, --, 
   {{0x7980073c,0xdb1800b0,0x7e7ceab1,0xa3d429c8}},	//   _melw, _hauä, _awsp, साख_, 
   {{0x7bc80207,0x7980eab2,0x00000000,0x00000000}},	//   _naeu, _lelw, --, --, 
   {{0xa3bc0490,0x602001c0,0x69c803cb,0x00000000}},	// [145a0] ीयर_, удта, ydfe, --, 
   {{0x7980003c,0xdce400de,0xf0a800f3,0x00000000}},	//   _nelw, _nejē, _екол_, --, 
   {{0x7bc80226,0x7e7c0857,0x5e5401d5,0xdb180139}},	//   _baeu, _ewsp, رلمس_, _yauç, 
   {{0x7bc80207,0x2b4405f5,0x798003cb,0x6a840209}},	//   _caeu, нэлг, _aelw, елда, 
   {{0x7bc80207,0x7980eab3,0x7afceab4,0x48bc0154}},	//   _daeu, _belw, _üstl, _অপের, 
   {{0x7bc80086,0x7980015d,0x683c036e,0x00000000}},	//   _eaeu, _celw, tëdo, --, 
   {{0x9d40eab5,0x69c8eab6,0x7980eab7,0x7bc80165}},	//   _берд, rdfe, _delw, _faeu, 
   {{0x7bc80399,0x77907f05,0x7980eab8,0x785000dc}},	//   _gaeu, لیما, _eelw, _kāvy, 
   {{0x6018578c,0x09c400c7,0x6b5403e0,0xd61400f1}},	//   lämä, _иааҟ, _dügü, کتيا_, 
   {{0x69d891e1,0x79800368,0xdb180363,0x00000000}},	//   _unte, _gelw, _sauç, --, 
   {{0x7bc80399,0x84c4723c,0x9f48004e,0x6018248c}},	//   _yaeu, тәлд, _eocè_, nämä, 
   {{0x1cbc0327,0xc4840131,0x00000000,0x00000000}},	//   _ཀརལ_, нлүк, --, --, 
   {{0x798076bd,0x7850002b,0x60180108,0x00000000}},	//   _yelw, _nāvy, hämä, --, 
   {{0x26c4eab9,0x1754011a,0x00000000,0x00000000}},	//   _isoo_, _נסגר_, --, --, 
   {{0x60180108,0xdb18eaba,0xa6e00162,0x2f6c0241}},	//   jämä, _tauç, íðfi, _ọnọ_, 
   {{0x9c4c0150,0x60180166,0x00000000,0x00000000}},	//   _ﺑﺎﻋﯟ_, dämä, --, --, 
   {{0x7bc80226,0x644c0198,0x785000cd,0x60000037}},	// [145b0] _raeu, mmci, _cāvy, _nõme, 
   {{0x7bc8eabb,0x4df402bf,0x606003cc,0x644c3e7c}},	//   _saeu, ляєт, _مۇسل, lmci, 
   {{0x7bc80098,0xe29c0008,0xe1fc056a,0xdb080158}},	//   _paeu, luð_, spós_, legø, 
   {{0xe3bceabc,0x7980092e,0x26c4eabd,0xb074010f}},	//   neñ_, _selw, _osoo_, _שׂרה_, 
   {{0x7980eabe,0xe29c0008,0x7bc803a0,0xe3bc0489}},	//   _pelw, nuð_, _vaeu, loñs_, 
   {{0x79805705,0xb7bc0311,0xa3d0060c,0x6b540139}},	//   _qelw, inţe, _होस_, _sügü, 
   {{0x79800a73,0x7bc8eabf,0xbb1c0952,0x99800006}},	//   _velw, _taeu, ﻴﺎﻥ_, _ųjų_, 
   {{0x7980eac0,0xe29c0008,0xe3bc00a2,0x00000000}},	//   _welw, kuð_, jeñ_, --, 
   {{0x7980eac1,0xa68009a5,0x0ab407d6,0xba5400f3}},	//   _telw, алыд, _محلد, _авај, 
   {{0x245804fe,0xdb08037e,0xe61400ee,0x798002d0}},	//   _rūma_, degø, кды_, _uelw, 
   {{0xb7bc0311,0xa3bc00dc,0xe3bc002e,0x6b540166}},	//   enţe, ीयं_, feñ_, _tügü, 
   {{0x26c40354,0xe3bc0428,0xe29c0008,0x17f800ae}},	//   _fsoo_, geñ_, fuð_, _عرضة_, 
   {{0xa3d40406,0xe29c01a8,0x25bc0139,0x00000000}},	//   साज_, guð_, betl_, --, 
   {{0xe3bc030a,0x1648008e,0x25bceac2,0x00000000}},	//   foñs_, _эчеп_, cetl_, --, 
   {{0x3eb80054,0x2164548a,0xb7bc0276,0x66e4002e}},	//   _apst_, тиси_, anţe, _tékë, 
   {{0x601802f6,0x602014a8,0xa3bc00dc,0x00000000}},	//   vämä, адса, ीयः_, --, 
   {{0x1f60eac3,0x32440022,0xb8ec0327,0xbf64009a}},	// [145c0] ркум, _иеиг, _ྷག_, ادفو, 
   {{0xf1d04276,0x60180664,0xde2407d6,0x9c10063f}},	//   _төмө, tämä, вжуд_, _sọpl, 
   {{0x48bc0eac,0x60000037,0xb1440353,0x2bc80117}},	//   _অপ্র, _sõme, _шнол, дуло_, 
   {{0x645c011c,0xc05800c0,0x00000000,0x00000000}},	//   _èpie, _піў_, --, --, 
   {{0x601801f4,0x00000000,0x00000000,0x00000000}},	//   sämä, --, --, --, 
   {{0x5a3002bf,0xdbdc032e,0x6bd800ec,0x644c0205}},	//   аніт, _bíós, _ڪورس_, zmci, 
   {{0x6b642a65,0x28c01fbc,0x6218008f,0x00000000}},	//   _акба, _वैशि, ווסק, --, 
   {{0x6bd8eac4,0x00000000,0x00000000,0x00000000}},	//   _تورس_, --, --, --, 
   {{0x66040de2,0x28c01db2,0x00000000,0x00000000}},	//   ëkko, _वैरि, --, --, 
   {{0x2bd807f8,0x00000000,0x00000000,0x00000000}},	//   णाका, --, --, --, 
   {{0xa5c401e1,0xd7c431d6,0xe3bc0428,0x3a2800e4}},	//   _abóò, رویه_, teñ_, éape_, 
   {{0xd7ec0597,0x26c40070,0xe29c0008,0xa3d002fe}},	//   _وكل_, _tsoo_, tuð_, _होश_, 
   {{0x26c40050,0x25bceac5,0xe3bceac6,0xf1dc0073}},	//   _usoo_, petl_, reñ_, मांन, 
   {{0x5690e3e7,0xe29c0008,0xe3bceac7,0xa3d4012c}},	//   _ташт, ruð_, señ_, साङ_, 
   {{0x925801c0,0x50646f5a,0x1fa401d5,0x00000000}},	//   тарт_, итта, краг, --, 
   {{0xdef8eac8,0x443c033f,0xdb085522,0xe29c01a8}},	//   мыз_, _ów_, pegø, puð_, 
   {{0x53145fab,0x657800ae,0x00000000,0x00000000}},	// [145d0] _پذير, obth, --, --, 
   {{0x69cc0162,0x00000000,0x00000000,0x00000000}},	//   _óbeh, --, --, --, 
   {{0xb3a80dba,0xfbf401e1,0x5fa82052,0x00000000}},	//   _कामख, _àáké_, _छापल, --, 
   {{0x683c036e,0xfb8402f2,0x7afc00a2,0xdbb0004e}},	//   sëdj, ادای, _üstk, радө, 
   {{0x600000af,0x3f88eac9,0x683c0240,0xca4801d5}},	//   _tõmb, maau_, mëdh, چلنه_, 
   {{0x3f88eaca,0xdcec0213,0xca4801b9,0x00000000}},	//   laau_, şdıq, نلنه_, --, 
   {{0x0ca8eacb,0x5fd4000d,0x00000000,0x00000000}},	//   _итти_, _डफाल, --, --, 
   {{0x3f880069,0x683c0240,0xf77000c6,0x6578002f}},	//   naau_, nëdh, حاث_, ebth, 
   {{0xacb000db,0xcb680769,0x9a8401d5,0xab640254}},	//   _نەەب, _شمله_, _шувл, spüü, 
   {{0x6ea4000d,0xc864035b,0x00000000,0x00000000}},	//   _चमसु, ытәи, --, --, 
   {{0x3f880418,0xc8c801d9,0x683c036e,0xe614084c}},	//   kaau_, _لولن_, këdh, удэ_, 
   {{0x6578eacc,0x683c036e,0x245825ad,0x00000000}},	//   abth, jëdh, _dūmo_, --, 
   {{0xa82000f1,0x00000000,0x00000000,0x00000000}},	//   _دکون, --, --, --, 
   {{0x720401ed,0xe6905668,0x74040154,0x00000000}},	//   اہدہ_, _الود, োকেট_, --, 
   {{0x1cac025c,0x7c280115,0xd4640b82,0x00000000}},	//   ྐངས_, _ĉern, _ተቃዉሞ_, --, 
   {{0x3f880607,0x85440276,0x00000000,0x00000000}},	//   gaau_, _тэче, --, --, 
   {{0xdee01d83,0xb8e4031c,0x853c0064,0x00000000}},	// [145e0] боти, _ཎར_, ngėn, --, 
   {{0x645ceacd,0x116837f7,0xfe7400d1,0x00000000}},	//   _èpic, _جلدی_, рүр_, --, 
   {{0x7c640131,0x683c0240,0x69cc0321,0x00000000}},	//   لانل, bëdh, _óbei, --, 
   {{0x290002b5,0xdde000e2,0x2aa8eace,0x683c0200}},	//   _āka_, āršo, етко_, cëdh, 
   {{0xe1fc011f,0xeb98013d,0x00000000,0x00000000}},	//   kqól_, _җиз_, --, --, 
   {{0xba0400c7,0x683c0200,0xa8a4022e,0x00000000}},	//   аҭуа_, mëdi, грик, --, 
   {{0xbe3000db,0xde00a30d,0x00000000,0x00000000}},	//   _بۉلب, _упри, --, --, 
   {{0xa3d01533,0xabd401d9,0x9c801155,0x00000000}},	//   _हों_, _حٲرت, íčes, --, 
   {{0x6994eacf,0xdce40153,0x683c0200,0xaa44014b}},	//   _брех, _bejė, nëdi, _беал, 
   {{0xe4e401ec,0xe5c40cb6,0x00000000,0x00000000}},	//   гімн, усио, --, --, 
   {{0xd5b4ead0,0x75c8c5dc,0x657836f4,0xe8f8009d}},	//   усы_, ттың_, rbth, _ялж_, 
   {{0xd494ac51,0xf98000c7,0x684401b9,0xb8640133}},	//   ырь_, _лҳәо, _ёнда, _ئالو, 
   {{0x3f880618,0xddcc0356,0x6aa00175,0x98340115}},	//   vaau_, _nucş, nuof, _גראף_, 
   {{0xb6440014,0xdb1c00c7,0x00000000,0x00000000}},	//   _پٹى۪, ãvév, --, --, 
   {{0x2f7001f2,0x3f8803a0,0x683c0240,0x6618ead1}},	//   _ọtọm, taau_, tëdh, mitk, 
   {{0x4e900020,0x7c2800df,0x82d822cb,0xddcc0356}},	//   _እርምጃ_, _ĉero, _адис_, _bucş, 
   {{0xdd98ead2,0x4428ead3,0x42a4bf78,0x7f5801c6}},	// [145f0] еше_, _ija_, _туйғ, таас_, 
   {{0x628cead4,0x4428ead5,0x645cead6,0x4eb803d4}},	//   msco, _hja_, _hiqi, ীমূল, 
   {{0x628cead7,0x645c20ef,0x3f88ead8,0x661801f4}},	//   lsco, _épis, paau_, iitk, 
   {{0x44281418,0x6aa01132,0x645c016d,0x3d180490}},	//   _jja_, fuof, _jiqi, _येणे_, 
   {{0x628cead9,0x4428eada,0x645ceadb,0xf9844166}},	//   nsco, _mja_, _miqi, агло, 
   {{0x3d1805ba,0x628c011c,0x1e000050,0x645ceadc}},	//   _येथे_, isco, _آسہ, _liqi, 
   {{0x4428eadd,0x628ceade,0xb7bc0311,0x9f48013a}},	//   _oja_, hsco, enţa, _mocí_, 
   {{0x4428eadf,0x645ceae0,0x201889b9,0xdbdc03b2}},	//   _nja_, _niqi, niqi_, _gíðs, 
   {{0x0ab8bfb2,0x3d180574,0x628c068f,0x7c28eae1}},	//   _مطلب_, _येते_, jsco, _ijer, 
   {{0x7c287eb1,0x4428eae2,0x66180357,0x0f580bd9}},	//   _hjer, _aja_, gitk, ניזם_, 
   {{0x44285723,0x628ceae3,0x7c28eae4,0x645ceae5}},	//   _bja_, esco, _kjer, _biqi, 
   {{0x645c0a73,0x7c2804ba,0x628c0036,0xe454084c}},	//   _ciqi, _jjer, fsco, ижэ_, 
   {{0x7c28eae6,0x645ceae7,0x628ceae8,0x9f4800db}},	//   _mjer, _diqi, gsco, _bocí_, 
   {{0x4428eae9,0x6618eaea,0x7c28eaeb,0x6e94eaec}},	//   _eja_, citk, _ljer, یلزا, 
   {{0x645ceaed,0x7c280588,0x76400042,0x853c00c0}},	//   _fiqi, _ojer, mlly, ngėl, 
   {{0x7c28eaee,0xa3d00574,0x683c02d3,0xdb08eaef}},	//   _njer, _होऊ_, tëdi, negó, 
   {{0x645c0395,0x628c01ab,0xc0e0069d,0x66d00205}},	// [14600] _èpia, csco, _ናይል_, mıkç, 
   {{0xdbdc1125,0x7c28eaf0,0x645c1cdf,0x66d00e51}},	//   _síðs, _ajer, _ziqi, lıkç, 
   {{0x7c28ddfd,0x645ceaf1,0xad5852f5,0xab64a372}},	//   _bjer, _yiqi, трах_, авел, 
   {{0x6618eaf2,0x645c35a3,0x6aa00418,0x7c280200}},	//   zitk, _xiqi, tuof, _cjer, 
   {{0x66180cfe,0x7c28eaf3,0xe9e492ec,0xdb0825e6}},	//   yitk, _djer, ицко, degó, 
   {{0xa3d0367a,0x00000000,0x00000000,0x00000000}},	//   _होई_, --, --, --, 
   {{0x7c28708a,0x6618eaf4,0x18840220,0xdbdc0174}},	//   _fjer, vitk, асып_, _tíðs, 
   {{0x7c28eaf5,0x76409c60,0x6618020c,0xa09808a8}},	//   _gjer, elly, witk, דיקט, 
   {{0x645ceaf6,0x66d005d1,0x44280427,0x76400076}},	//   _riqi, dıkç, _rja_, flly, 
   {{0xaa44eaf7,0x7c280200,0x628c007c,0x00000000}},	//   _тезл, _zjer, vsco, --, 
   {{0x6618eaf8,0x442801fa,0x645c5431,0x394803f9}},	//   ritk, _pja_, _piqi, ƙasa_, 
   {{0x6618eaf9,0x645ceafa,0x76400c8c,0x628ceafb}},	//   sitk, _qiqi, ally, tsco, 
   {{0x628cc5bf,0x6618eafc,0x2fd00368,0x45d4eafd}},	//   usco, pitk, ddyg_, _голс, 
   {{0x628ceafe,0x2018009a,0x645c1fc6,0x3e7c0241}},	//   rsco, wiqi_, _wiqi, _látò_, 
   {{0x0494eaff,0x628c1c4b,0x645ceb00,0x1cb00327}},	//   _البح, ssco, _tiqi, _དཱེ_, 
   {{0xa3b8eb01,0x14706e9a,0x4428eb02,0x628ceb03}},	//   _شاعر_, _باوج, _uja_, psco, 
   {{0x60d00953,0x2018c56c,0x645c06af,0xa3d000c5}},	// [14610] _žemė, riqi_, _épiq, _होए_, 
   {{0x2018eb04,0x7c286df9,0x7cfc03b2,0xdb080210}},	//   siqi_, _sjer, _nærú, zegó, 
   {{0x8d74eb05,0xd01000dd,0x4438eb06,0x7c28eb07}},	//   تاقا, سلے_, oos_, _pjer, 
   {{0xe29c0579,0x9ba02ba5,0x201800ac,0x28d800dc}},	//   orð_, تەرى, qiqi_, भिनि, 
   {{0x7c28036f,0x4438eb08,0x7640eb09,0x6d5803b2}},	//   _vjer, ios_, ylly, _útan, 
   {{0x4438eb0a,0x89a810f5,0x7c280b21,0xf990eb0b}},	//   hos_, иків_, _wjer, سبت_, 
   {{0x4438eb0c,0x7c28067d,0xdb08eb0d,0x7e6c2b34}},	//   kos_, _tjer, tegó, lqap, 
   {{0x4438eb0e,0x7c28eb0f,0x5c041468,0x76400042}},	//   jos_, _ujer, _тяга, wlly, 
   {{0xdb08eb10,0x7e6c03f0,0x7c380165,0x00000000}},	//   regó, nqap, mowr, --, 
   {{0x44380381,0x7640062c,0x7c3803ac,0x00000000}},	//   eos_, ully, lowr, --, 
   {{0x4438eb11,0x3dd0009a,0x34a8005b,0x76400042}},	//   fos_, _mazw_, ывно_, rlly, 
   {{0x7c38017a,0xe7ac0073,0xa2bc190c,0x00000000}},	//   nowr, _टायप, _लैङ्, --, 
   {{0x1dc43be5,0xdb0c87b0,0x853c0024,0x1da401ad}},	//   रजात, édèr, ngėj, खलात, 
   {{0xe69402dd,0x7c38090e,0x3dd0033f,0xe7340063}},	//   _اپوش_, howr, _nazw_, _ћеш_, 
   {{0x44385c82,0x85b801d9,0xafe46cc1,0xe10400d8}},	//   bos_, _خانس_, бовл, берд_, 
   {{0x9eb4eb12,0x645ca8d8,0xed5808ca,0x00000000}},	//   әштә, _épip, ҳоз_, --, 
   {{0x7c380042,0xdee028a8,0x84540e56,0xf8a400ec}},	// [14620] dowr, поти, _بىيچ, _ڪک_, 
   {{0xa4c003a2,0xed58eb13,0x3e7c0241,0x00000000}},	//   _iãƒâ_, гоз_, _sátò_, --, 
   {{0xf8a4eb14,0x00000000,0x00000000,0x00000000}},	//   _تک_, --, --, --, 
   {{0x7c380009,0x7cfc032e,0x00000000,0x00000000}},	//   gowr, _særú, --, --, 
   {{0xa4c00100,0x99d000f1,0xaa440798,0x7f700150}},	//   _jãƒâ_, ړتيا, бедл, _ﺘﺎل_, 
   {{0x4438eb15,0xdb087491,0xf1c401e1,0x5d64014b}},	//   zos_, tegò, _àádo_, _гирм_, 
   {{0x4438eb16,0xdca0eb17,0xd97800d1,0x5ca000d8}},	//   yos_, _нари, урчә_, _нирб, 
   {{0x4438eb18,0xdb08068c,0xbb7000db,0x8698014b}},	//   xos_, regò, _قۇمع, акис_, 
   {{0x2d88eb19,0xceb400ac,0xbc180220,0xa3d002e5}},	//   _kebe_, ntə_, _тірі_, _होग_, 
   {{0xa968495f,0x4438eb1a,0x00000000,0x00000000}},	//   _إمام_, wos_, --, --, 
   {{0x44381e13,0x2d88eb1b,0xd7eccd77,0xdb081427}},	//   tos_, _mebe_, _еу_, legð, 
   {{0x2d88eb1c,0x32180851,0xceb403be,0xc0d4001f}},	//   _lebe_, _ampy_, ktə_, ከባሪ_, 
   {{0xb3a813e0,0x7afc05d1,0x69cc03b2,0x00000000}},	//   _कारख, _üstt, _óbes, --, 
   {{0xdb0c6c80,0x2d88eb1d,0x175405d0,0xc55801ee}},	//   édér, _nebe_, _הסדר_, _килє_, 
   {{0x7e6c0113,0x55e00124,0x059802dd,0xdb08032e}},	//   wqap, _хәыҷ, _ﻛﯘﺷﭙ, hegð, 
   {{0xceb403be,0x3218039a,0x403402d5,0x4438047e}},	//   ftə_, _empy_, цебс, qos_, 
   {{0x3df4eb1e,0xbe1802bf,0x7c3802d0,0x7a2c00d7}},	// [14630] озас, ажає_, vowr, hĺta, 
   {{0x5d640a15,0x7e6c03f0,0x2d8808a9,0x2bd800e5}},	//   стаз, rqap, _cebe_, یانک_, 
   {{0x2d88eb1f,0x8d74c947,0x7e6c1bb7,0x6d5803b2}},	//   _debe_, سالا, sqap, _útal, 
   {{0xed6400c6,0x2d880014,0x9f48004e,0x61f4022e}},	//   _ĝłřĺ_, _eebe_, _tocà_, _hoxl, 
   {{0x2d88eb20,0xfe7001d9,0x7e6c0140,0x6000000d}},	//   _febe_, _آگر_, qqap, _jõmm, 
   {{0x2d88eb21,0x61f40de2,0xd84c01f2,0x60000037}},	//   _gebe_, _joxl, pọku_, _mõmm, 
   {{0x1cb00327,0xb3a87220,0x386801e4,0x04fc00eb}},	//   _དཱི_, _कालख, ĉaro_, ুপুর_, 
   {{0x88c40131,0x2d880427,0x00000000,0x00000000}},	//   ستىل, _zebe_, --, --, 
   {{0x2d88eb22,0x600000af,0x27f4007b,0x28100137}},	//   _yebe_, _nõmm, تفيد_, بويس, 
   {{0xf7988d1a,0x18880153,0x00000000,0x00000000}},	//   _چناب_, _бсдп_, --, --, 
   {{0x047807d6,0x00000000,0x00000000,0x00000000}},	//   یلیک_, --, --, --, 
   {{0xe3b0004b,0x43740022,0x7afc03e0,0xc794030d}},	//   ورټ_, зурт, _üsts, _ершы, 
   {{0x61f40170,0x00000000,0x00000000,0x00000000}},	//   _boxl, --, --, --, 
   {{0x6724002d,0x61f403b9,0x00000000,0x00000000}},	//   úkje, _coxl, --, --, 
   {{0x61f40097,0x2d8801af,0x6350002b,0x95540214}},	//   _doxl, _rebe_, _aśnī, _اخشا, 
   {{0xceb400ac,0x00000000,0x00000000,0x00000000}},	//   ttə_, --, --, --, 
   {{0x61f40cf9,0x8d28053f,0x643000cf,0xe430007b}},	// [14640] _foxl, әнең_, _تىيئ, _تفيد, 
   {{0x3f98009a,0xd250eb23,0x00000000,0x00000000}},	//   _edsu_, _سۆز_, --, --, 
   {{0xceb400ac,0xacc800db,0x00000000,0x00000000}},	//   stə_, ргез_, --, --, 
   {{0x2d8801f1,0x2ab00109,0x6d580332,0x00000000}},	//   _webe_, tâb_, _útam, --, 
   {{0x2d8808ad,0x61f400ac,0x9f4800d8,0xab28013e}},	//   _tebe_, _yoxl, _tocá_, шода_, 
   {{0xce3401d9,0x2020033f,0x61f40f89,0xdb0803b2}},	//   _روزک, ąpił_, _xoxl, regð, 
   {{0x9d4013d7,0xf1b0d857,0xec70009f,0x00000000}},	//   _жерд, _जानन, _آٿر_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6b80eb24,0xf1c8078a,0x00000000,0x00000000}},	//   mbog, ाजान, --, --, 
   {{0x6b800978,0x3eac0158,0x7c2800df,0x6aa0000f}},	//   lbog, _åete_, _ĉeri, mrof, 
   {{0x61f40007,0xefd00023,0x00000000,0x00000000}},	//   _roxl, ከሓድ_, --, --, 
   {{0x6b80eb25,0x387000f2,0x61f41574,0x60000254}},	//   nbog, _ézra_, _soxl, _põmm, 
   {{0x27e40428,0xe5180316,0x961401d3,0x442c0115}},	//   _inon_, _फेरि_, صغیر_, ĵe_, 
   {{0x6b800842,0x6d4c00a2,0x6000000d,0x45d40107}},	//   hbog, _ozba, _võmm, _хокс, 
   {{0x6aa0eb26,0x0f200092,0x660400e8,0x6b8000a2}},	//   hrof, _ተመለከ, ëkku, kbog, 
   {{0x6b800978,0x600000af,0xb128001f,0x00000000}},	//   jbog, _tõmm, ደሚያሳ, --, 
   {{0x6b80b364,0x6d4c0946,0x6aa00115,0x61f406be}},	// [14650] dbog, _azba, jrof, _toxl, 
   {{0xb7bc0356,0xf1b000cd,0xddcc0118,0xe50c00cd}},	//   miţe, _जायन, řeže, ानपि_, 
   {{0x9258774e,0x27e4eb27,0x6b80eb28,0x6aa001ab}},	//   _بشير_, _onon_, fbog, erof, 
   {{0x44cc09b4,0x6b80eb29,0x3b541dc8,0x6aa0003e}},	//   _mś_, gbog, пкер, frof, 
   {{0x6aa00194,0xc31c02f5,0x6d4c90ee,0xb7bc0311}},	//   grof, _ধুতি_, _ezba, niţe, 
   {{0x27e41590,0x3ea8eb2a,0x6b8004cc,0x44cc012d}},	//   _anon_, muat_, abog, _oś_, 
   {{0x3ea8eb2b,0x200805b1,0x49b80345,0x6b80016d}},	//   luat_, _klci_, تاند_, bbog, 
   {{0x6aa0eb2c,0xdb080267,0x66140432,0x00000000}},	//   brof, degö, _įyka, --, 
   {{0x44cc033f,0xab605f32,0x657400a2,0x00000000}},	//   _aś_, _كۇمى, _şyha, --, 
   {{0x27e4eb2d,0x00000000,0x00000000,0x00000000}},	//   _enon_, --, --, --, 
   {{0x0ee80034,0xe5740262,0x3ea80208,0x00000000}},	//   _ऐप्स_, язэ_, huat_, --, 
   {{0x3ea83a97,0xdb1800e4,0x27e40076,0xb7bc0356}},	//   kuat_, _abué, _gnon_, fiţe, 
   {{0xe72ceb2e,0x3ea8eb2f,0xe60c005a,0x00000000}},	//   _че_, juat_, _зд_, --, 
   {{0x3ea800db,0x3944007c,0x00000000,0x00000000}},	//   duat_, _kyls_, --, --, 
   {{0xdb180055,0x6b80047e,0xafe4009b,0x00000000}},	//   _mauñ, ybog, повл, --, 
   {{0x6aa0eb30,0x3ea801c8,0xf3c80fb4,0x00000000}},	//   yrof, fuat_, _طبعه_, --, 
   {{0x3ea8eb31,0xdfcceb32,0x6b800978,0x00000000}},	// [14660] guat_, ديق_, vbog, --, 
   {{0x27380016,0x13a801ed,0x91a801ed,0xd1b80451}},	//   ừng_, _انکی_, _بندے_, _ڏاڍا_, 
   {{0xdbdc01e1,0x6b80047e,0x00000000,0x00000000}},	//   _kíès, tbog, --, --, 
   {{0x3ea815a5,0x6aa0eb33,0x69240137,0x22900345}},	//   buat_, trof, үмда, _تلیس, 
   {{0x6b800978,0x3ea8eb34,0xe8f801c0,0xdb0804fb}},	//   rbog, cuat_, өлд_, nggè, 
   {{0xec141af6,0x6b800978,0x6aa000db,0xed5873bc}},	//   _کورد, sbog, rrof, _гог_, 
   {{0x6b800978,0xe3bc00e4,0x6d4c25ad,0x00000000}},	//   pbog, liñe_, _uzba, --, 
   {{0xdb080793,0x6b800978,0x6e3c8060,0x00000000}},	//   vegö, qbog, lopb, --, 
   {{0xd77000cf,0xd6d4084c,0x28d800cd,0x00000000}},	//   رايع, птэ_, भिहि, --, 
   {{0x449802bf,0x6e3ceb35,0xb7bc054e,0x00000000}},	//   овою_, nopb, viţe, --, 
   {{0x69c8eb36,0xa764010b,0x3ea80200,0x00000000}},	//   mefe, _екед, zuat_, --, 
   {{0x27e4089c,0xb7bc0311,0xe3bc005a,0xb0b8031c}},	//   _unon_, tiţe, kiñe_, _བྱེེ, 
   {{0x69c8057b,0x612001d5,0x6e3c257c,0x3ea80200}},	//   oefe, _kеlg, kopb, xuat_, 
   {{0xb7bc0311,0x168403e6,0xd5ac0345,0xdb080205}},	//   riţe, _راهێ, _مفه_, pegö, 
   {{0x55b8011a,0xd5b8011a,0x00000000,0x00000000}},	//   _למגו, _הזול, --, --, 
   {{0x3ea8eb37,0x69c8eb38,0x9878008f,0x60000254}},	//   tuat_, hefe, מאלט, _kõmi, 
   {{0x69c80184,0xdb18008c,0x4ea49369,0x20080306}},	// [14670] kefe, _nauð, ерха, _vlci_, 
   {{0xdb04eb39,0x3ea8eb3a,0x92b4007b,0x60000254}},	//   _élég, ruat_, _أحيا, _mõmi, 
   {{0x3ea8eb3b,0xde4401d3,0x21240051,0x00000000}},	//   suat_, _ہیرو_, _ãnh_, --, 
   {{0xdb18032e,0xf090011a,0x63ac0051,0x00000000}},	//   _bauð, _בנט_, ngcn, --, 
   {{0x3ea8eb3c,0x69c8eb3d,0xf428049b,0x612001d5}},	//   quat_, fefe, ltää_, _bеlg, 
   {{0xdb180008,0x7e7c2656,0x50b80214,0xdb0854ba}},	//   _dauð, _itsp, _بدید_, nggé, 
   {{0xf428049b,0x00000000,0x00000000,0x00000000}},	//   ntää_, --, --, --, 
   {{0x6568003e,0xb8d423ef,0x00000000,0x00000000}},	//   _agfh, _जम_, --, --, 
   {{0x69c8eb3e,0x3944002d,0xf428023a,0xe734023b}},	//   befe, _wyls_, htää_, меъ_, 
   {{0x35680e26,0xb7bc0276,0x5fdc1b57,0x612001a9}},	//   өрүн_, inţi, _पोसल, _kеld, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc2080375,0x7e7c0857,0x7bd8002f,0x00000000}},	//   _דה_, _otsp, ndwu, --, 
   {{0xd37403e6,0x00000000,0x00000000,0x00000000}},	//   وێژک, --, --, --, 
   {{0x998400c0,0x00000000,0x00000000,0x00000000}},	//   monų_, --, --, --, 
   {{0x6140eb3f,0x7e7c47c0,0x216458c9,0xb7bc0276}},	//   вера, _atsp, дири_, enţi, 
   {{0x69c84653,0xe3bc00e4,0x00000000,0x00000000}},	//   zefe, tiñe_, --, --, 
   {{0x69c8eb40,0x6e3c44b6,0x95200014,0xffa4009d}},	// [14680] yefe, topb, _زکھم, элтү, 
   {{0x643c0020,0xdb18008c,0xe3bc2e48,0x00000000}},	//   ደገለጹ, _rauð, riñe_, --, 
   {{0xdd8ceb41,0x69c81477,0xdb180008,0x6e3c01f5}},	//   شون_, vefe, _sauð, ropb, 
   {{0x69c827be,0xbc240131,0x7e7c002f,0x99840153}},	//   wefe, ىرنى, _ftsp, konų_, 
   {{0x69c8eb42,0x7e7c037e,0x99840006,0x7c641955}},	//   tefe, _gtsp, jonų_, رامل, 
   {{0x3eac0158,0x99840153,0xed5801a9,0x00000000}},	//   _åeta_, donų_, _ҳоҳ_, --, 
   {{0x19544660,0xeb740064,0x853c00c0,0x00000000}},	//   машы_, _жызэ, ngėt, --, 
   {{0x69c8eb43,0xc6f8e20b,0xed5800c2,0x99840006}},	//   sefe, зних_, _гоҳ_, fonų_, 
   {{0x69c804c9,0xafe00158,0x1ef8010f,0x998400c0}},	//   pefe, åøya, ַלטע, gonų_, 
   {{0x44f4b4be,0xf42802f6,0x69c8036e,0xf988007b}},	//   епос, ytää_, qefe, _فخمه_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb37001f3,0xc4842f89,0x00000000,0x00000000}},	//   _ቦታውን_, млүк, --, --, 
   {{0xb9cc044e,0x534401c6,0x00000000,0x00000000}},	//   _ታት_, вхра, --, --, 
   {{0xf4280664,0xb7bc0356,0x6f140210,0x00000000}},	//   ttää_, miţa, dzyc, --, 
   {{0xd6400050,0x4034db80,0xd48c717e,0xd2580006}},	//   _جنوٝ, еевс, _шр_, ьцю_, 
   {{0x26c402e3,0xf42802f6,0x00000000,0x00000000}},	//   _kpoo_, rtää_, --, --, 
   {{0xf428049b,0x506401af,0xce9402e8,0x12d400c0}},	// [14690] stää_, ттра, катъ, _ажыя, 
   {{0xb9002fb5,0x0e340108,0x00000000,0x00000000}},	//   _སླ_, вную, --, --, 
   {{0x997000bc,0x00000000,0x00000000,0x00000000}},	//   těži_, --, --, --, 
   {{0x2d9c0086,0x7e7c0267,0x00000000,0x00000000}},	//   _ôten_, _ttsp, --, --, 
   {{0x6f14068f,0x26c40211,0xfaa4eb44,0x7e7c0efa}},	//   czyc, _npoo_, хало, _utsp, 
   {{0x853c0024,0x00000000,0x00000000,0x00000000}},	//   ngės, --, --, --, 
   {{0x26c40418,0xa9640114,0x3b0803f0,0xf4240108}},	//   _apoo_, ниша_, šaq_, ääke_, 
   {{0xc7640075,0x99840153,0x7d0400a2,0x00000000}},	//   ھايى, tonų_, myhs, --, 
   {{0xc7641473,0x3b5400d8,0x00000000,0x00000000}},	//   پايى, _чкар, --, --, 
   {{0xe6141301,0x4a545bc5,0x348401c0,0x99840153}},	//   едь_, _акус, нгог, ronų_, 
   {{0x3b7802d3,0xc31c009e,0x13a8eb45,0xdb1801e7}},	//   _ብሓድሽ_, _ধুলি_, وندی_, _mbuí, 
   {{0x99840006,0x1cb00327,0x6000000d,0xddc400c0}},	//   ponų_, _དཱན_, _kõmu, _bijū, 
   {{0xe294b78a,0xd6100228,0xa800eb46,0x35a45ce3}},	//   ная_, _издө, ğıtm, _залг, 
   {{0x20c8eb47,0xd58403e6,0xb1440982,0xe518000d}},	//   ाबंध, _تێده_, енгл, _फेकि_, 
   {{0x7640eb48,0x225c00e4,0x00000000,0x00000000}},	//   moly, ïuka_, --, --, 
   {{0xdb180005,0x764001e6,0x853c00c0,0x00000000}},	//   _abuí, loly, rgėt, --, 
   {{0xef18eb49,0xee0806ed,0x00000000,0x00000000}},	// [146a0] чма_, пеал_, --, --, 
   {{0x6e44eb4a,0xe3bc5893,0x6f14a735,0x7640eb4b}},	//   رنام, miña_, rzyc, noly, 
   {{0x6f14006d,0xe3bc1709,0x00000000,0x00000000}},	//   szyc, liña_, --, --, 
   {{0xe7ac228d,0x7640eb4c,0x2078008f,0xdca00798}},	//   _टाइप, holy, _מאטא, ѓачи, 
   {{0x7640eb4d,0xe3bc056a,0xdb805dbe,0x6574010b}},	//   koly, niña_, угчи, _şyhm, 
   {{0xec700451,0x00000000,0x00000000,0x00000000}},	//   _مٿس_, --, --, --, 
   {{0xed586bd5,0x764073b0,0x26c40036,0x00000000}},	//   _хов_, doly, _spoo_, --, 
   {{0xe3bceb4e,0x00000000,0x00000000,0x00000000}},	//   kiña_, --, --, --, 
   {{0x764000dd,0xe3bc08e7,0x00000000,0x00000000}},	//   foly, jiña_, --, --, 
   {{0x7640eb4f,0xe3bc056a,0x00000000,0x00000000}},	//   goly, diña_, --, --, 
   {{0xd82c05f5,0x69d8eb50,0xa258000f,0x18a0eb51}},	//   _бэ_, _iate, ltôg, _бахм, 
   {{0x47d400cc,0x00000000,0x00000000,0x00000000}},	//   থাহী, --, --, --, 
   {{0xe3bc01c4,0x57f8011a,0x1a98010f,0x00000000}},	//   giña_, _מלאו, ּילע, --, 
   {{0x69d8da12,0x9268eb52,0x7640003a,0x47d405d9}},	//   _jate, ерса_, coly, _سيڪر, 
   {{0xd1381606,0xf07800d1,0x00000000,0x00000000}},	//   ехт_, дисә_, --, --, 
   {{0x50f40e26,0x69d8eb53,0xe3bc0005,0x6578007b}},	//   ызст, _late, biña_, lcth, 
   {{0xe3bc172e,0x69d80857,0xe7c008e6,0x6578004d}},	// [146b0] ciña_, _oate, व्यप, octh, 
   {{0xe45c04f3,0x3208007c,0x8d7412d3,0x00000000}},	//   lmö_, ckby_, هاما, --, 
   {{0x02b01715,0xdbdc0241,0x6578007b,0xfab4037e}},	//   _जमुन, _fíìs, icth, _sに_, 
   {{0x764054a0,0x69d8eb54,0x6120022e,0x27140154}},	//   zoly, _aate, _tеlb, _তখনো_, 
   {{0x69d8eb55,0x3f880cf2,0x764004ba,0x040801e1}},	//   _bate, mbau_, yoly, _ńkọj, 
   {{0x69d8eb56,0x3ea8eb57,0x3f88eb58,0x0b880209}},	//   _cate, mrat_, lbau_, _үсти_, 
   {{0x69d8eb59,0x7640eb5a,0xbc64035b,0xacd400d1}},	//   _date, voly, _ахақ, _ибрә, 
   {{0x3ea80137,0x3f880730,0xe3bc0bc9,0x60d4010a}},	//   orat_, nbau_, yiña_, _msxm, 
   {{0x69d8eb5b,0xe3bc056a,0x3ea8eb5c,0xf1b0041c}},	//   _fate, xiña_, nrat_, _जालन, 
   {{0x3ea8eb5d,0xe3bceb5e,0x69d8eb5f,0x60000254}},	//   irat_, viña_, _gate, _kõms, 
   {{0x3ea8eb60,0xa8001ae4,0xe3bc87b9,0x6d5803b2}},	//   hrat_, ğırm, wiña_, _útat, 
   {{0x3ea8eb61,0xe3bc094a,0x7640eb62,0xa800c6da}},	//   krat_, tiña_, soly, şırm, 
   {{0x69d844c8,0x764085a3,0x60d403ac,0x13a8eb63}},	//   _yate, poly, _asxm, ونگی_, 
   {{0xe3bceb64,0x69d83e30,0xe2800116,0x3a9000d1}},	//   riña_, _xate, рлри, ﻟﺴﯘﻥ_, 
   {{0x3ea8eb65,0x3f8848aa,0xe3bc094a,0xb7bc0356}},	//   erat_, fbau_, siña_, niţo, 
   {{0x3ea8eb66,0x3f88eb67,0xd58403e6,0xe3bceb68}},	//   frat_, gbau_, _تێگه_, piña_, 
   {{0x3ea8eb69,0x7c28010f,0xe3bc0113,0x2d94010b}},	// [146c0] grat_, _ĉerp, qiña_, врес, 
   {{0x955802d3,0x00000000,0x00000000,0x00000000}},	//   _ታሕትን_, --, --, --, 
   {{0xdcac2dc3,0x3ea81ee0,0x69d8eb6a,0x3f880ade}},	//   قىل_, arat_, _rate, bbau_, 
   {{0x3ea8eb6b,0x69d8eb6c,0x645c0066,0xfbf40241}},	//   brat_, _sate, _èpit, _áálé_, 
   {{0x69d8eb6d,0x20040085,0xafc40150,0x2f54b971}},	//   _pate, ɔni_, _كيگى, _штос, 
   {{0x6da448bc,0x69d8eb6e,0xc13c0051,0x7a2401ef}},	//   _шига, _qate, _nượp_, jčtě, 
   {{0x69d8eb6f,0x4bc4eb70,0x612001d5,0xeb9801a9}},	//   _vate, _бөлг, _kеla, _оив_, 
   {{0x69d88e86,0x779026a6,0x00000000,0x00000000}},	//   _wate, میما, --, --, 
   {{0xa3780798,0x6578003e,0x31280092,0x00000000}},	//   ndõe, tcth, ደሚቀር, --, 
   {{0x3f880369,0x69d8eb71,0x00000000,0x00000000}},	//   zbau_, _uate, --, --, 
   {{0x3ea8eb72,0xbb1c1df2,0x657801e7,0x00000000}},	//   zrat_, ﺴﺎﻡ_, rcth, --, 
   {{0x3ea80209,0x657800c6,0x97206786,0x00000000}},	//   yrat_, scth, افیو, --, 
   {{0x186436b1,0x3ea801a9,0x26d001e1,0x00000000}},	//   _раци_, xrat_, _èyo_, --, 
   {{0xf7e00210,0x00000000,0x00000000,0x00000000}},	//   ążeń_, --, --, --, 
   {{0xdfd800c2,0x3f880e78,0x3ea8eb73,0x04a400c7}},	//   мъа_, tbau_, wrat_, _сулҭ, 
   {{0x3ea8eb74,0xe3bc0f71,0xdc106656,0xd084084c}},	//   trat_, miño_, yğıs, рыри, 
   {{0x3f88eb75,0x3ea8eb76,0xe3bc1709,0x4e9401b9}},	// [146d0] rbau_, urat_, liño_, لشلر, 
   {{0x644c511a,0x3f88eb77,0xfd7401c0,0x60000254}},	//   llci, sbau_, улжэ, _põms, 
   {{0x3ea8eb78,0x3f880a40,0xe3bc056a,0x645c020c}},	//   srat_, pbau_, niño_, _èpis, 
   {{0x3ea8eb79,0x24480295,0xe7c01098,0x04040154}},	//   prat_, rùmw_, _वॉलप, শোরী_, 
   {{0xe3bc0077,0x7e54012f,0x644c0332,0x00000000}},	//   hiño_, _منحص, ilci, --, 
   {{0xe3bc005a,0x4a440212,0x00000000,0x00000000}},	//   kiño_, анів, --, --, 
   {{0x37743004,0x4c94eb7a,0xe3a800eb,0x00000000}},	//   лыпс, _висс, গ্যব, --, 
   {{0xe3bceb7b,0x1db001bc,0x00000000,0x00000000}},	//   diño_, ुभवत, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xba54eb7c,0x160401d5,0x18880150,0x644c0210}},	//   _صناع, тмоқ_, _жсдп_, elci, 
   {{0x644c003a,0xf1880131,0x00000000,0x00000000}},	//   flci, _ﺑﯘﻟﯘ, --, --, 
   {{0x9f48003e,0x00000000,0x00000000,0x00000000}},	//   _encé_, --, --, --, 
   {{0xd90c066d,0x6fa000dc,0xb6a407a5,0x00000000}},	//   _دیں_, गणसू, _силл, --, 
   {{0x2fd8eb7d,0xe3bc6d50,0x37e400eb,0x00000000}},	//   کورد_, biño_, _ফকির, --, 
   {{0xe3bc1709,0xa0a079ea,0x55e001af,0xd2940124}},	//   ciño_, йард, _боҙб, ырҟь, 
   {{0xffa4009d,0x00000000,0x00000000,0x00000000}},	//   илсү, --, --, --, 
   {{0xb8e4003d,0xea100241,0x00000000,0x00000000}},	// [146e0] _ཏཱ_, _ọ̀rẹ, --, --, 
   {{0xa3780120,0x7afc0205,0xb1d80108,0x00000000}},	//   rdõe, _üsty, _чьих_, --, 
   {{0xeaf8eb7e,0xed58eb7f,0xc0d402d3,0xaba800d8}},	//   کرات_, хож_, ከኣለ_, евез_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdca01955,0xe3bc01c4,0x00000000,0x00000000}},	//   _қати, ziño_, --, --, 
   {{0x2fd00162,0xdb0c010e,0x00000000,0x00000000}},	//   leyg_, _çeýe, --, --, 
   {{0xe3bc0077,0x60000254,0x2d9800c7,0x00000000}},	//   xiño_, _kõmp, mape_, --, 
   {{0xe3bc6bdf,0xdce4003d,0x6d4c01d5,0x60000254}},	//   viño_, _sejħ, _iyba, _jõmp, 
   {{0xe6642be5,0x2d980311,0x6d4ceb80,0x00000000}},	//   лтоо, oape_, _hyba, --, 
   {{0x2d98eb81,0xe3bceb82,0x6d4ceb83,0x7afc00d8}},	//   nape_, tiño_, _kyba, _àsta, 
   {{0x25a80832,0x6d4c00a2,0xa50c0073,0x00000000}},	//   ودگي_, _jyba, ानेच_, --, 
   {{0xe3bceb84,0x2d98eb85,0x6d4c005c,0x1b180011}},	//   riño_, hape_, _myba, _ফুটে_, 
   {{0x2d98eb86,0xe3bceb87,0x6d4c010b,0x979800df}},	//   kape_, siño_, _lyba, _טשאק, 
   {{0xe3bc056a,0x6d4c0857,0x2d9800c7,0xdb0803b2}},	//   piño_, _oyba, jape_, nggá, 
   {{0x2d9832bc,0x8f0800d1,0x9e0401a9,0x00000000}},	//   dape_, ңхуа_, қчал, --, 
   {{0xc2740063,0x00000000,0x00000000,0x00000000}},	//   _клиј, --, --, --, 
   {{0x6d4ceb88,0xa3c806ab,0x645c004e,0xdda8eb89}},	// [146f0] _ayba, _रॉय_, _èpiq, етел_, 
   {{0x6d4c08fb,0x62980153,0x2d98eb8a,0x00000000}},	//   _byba, šuos, gape_, --, 
   {{0x5c04242f,0x3cd4c80b,0x00000000,0x00000000}},	//   ляда, ржес, --, --, 
   {{0xc0d402d3,0x6d4c0142,0x2d980022,0x00000000}},	//   ከኣል_, _dyba, aape_, --, 
   {{0x6d4c0009,0x2d98eb8b,0x3a2400de,0x34d00b9a}},	//   _eyba, bape_, _pmlp_, _तन्द, 
   {{0x2d98eb8c,0x956c0023,0x00000000,0x00000000}},	//   cape_, ጣታትን_, --, --, 
   {{0x3b78084c,0xf77000c6,0x6d4c010b,0xdb180139}},	//   _айбэ_, ياة_, _gyba, _obuç, 
   {{0xba3c0118,0x2b500210,0x00000000,0x00000000}},	//   _svůd, życa_, --, --, 
   {{0x6d4ceb8d,0x8ad40451,0xe72c0133,0x00000000}},	//   _zyba, _هڪٻئ, وڵه_, --, 
   {{0x7ae8eb8e,0xd1f8044e,0x7624eb8f,0xf62496f0}},	//   _iret, ለታት_, рмоз, рдоо, 
   {{0x7ae885fa,0x34a800a7,0xc8c8a392,0x00000000}},	//   _hret, ъвно_, _مولن_, --, 
   {{0x2d98007f,0x00000000,0x00000000,0x00000000}},	//   zape_, --, --, --, 
   {{0x7bc800e8,0xa3c4033f,0xe60c7676,0x2d98eb90}},	//   _mbeu, ैज़_, _дд_, yape_, 
   {{0x7ae8eb91,0x2bd02c2e,0x00000000,0x00000000}},	//   _mret, _सस्थ, --, --, 
   {{0x2d980588,0x7bc80381,0x798003ac,0xd34801b9}},	//   vape_, _obeu, _mflw, ضیگه_, 
   {{0x7ae8eb92,0x6d4c132c,0x2d983f5d,0x32c82d40}},	//   _oret, _ryba, wape_, ﻪﻧﮕﻪ, 
   {{0xa064eb93,0x2d98eb94,0x6d4c98a6,0xdee01925}},	// [14700] рата_, tape_, _syba, ооти, 
   {{0x7bc8c315,0x6d4c0fac,0x798003ac,0x6cc40354}},	//   _abeu, _pyba, _nflw, ийза, 
   {{0x2d98eb95,0xeb98eb96,0xa3c801ad,0x716800f0}},	//   rape_, вие_, _रॉड_, _јанг_, 
   {{0x7ae8eb97,0x6d4c0e96,0x2d98eb98,0x5c701fe2}},	//   _bret, _vyba, sape_, іліт, 
   {{0x2d98eb99,0x5fdc0764,0x6d4c033f,0x00000000}},	//   pape_, _पोटल, _wyba, --, 
   {{0x7ae8eb9a,0xa8a4eb9b,0x6d4ceb9c,0x7bc805c7}},	//   _dret, арик, _tyba, _ebeu, 
   {{0x7ae8eb9d,0x5ca0365f,0x6d4c127b,0x00000000}},	//   _eret, _мирб, _uyba, --, 
   {{0x7ae8eb9e,0x7bc801ab,0x00000000,0x00000000}},	//   _fret, _gbeu, --, --, 
   {{0x7ae82045,0xe9d824a9,0x7980015d,0x249c0356}},	//   _gret, _ика_, _fflw, wstm_, 
   {{0x2604eb9f,0xb7c00055,0x00000000,0x00000000}},	//   рчиг, _ũãte, --, --, 
   {{0xc5d8009e,0x7ae800d0,0x81d40154,0x00000000}},	//   তালপ, _zret, _সচল_, --, 
   {{0x84c404a9,0x46140133,0x7ae80139,0x00000000}},	//   _һәмд, _گوتر, _yret, --, 
   {{0xb8640a2c,0xc5f800e2,0xdb2000e5,0x00000000}},	//   _االو, lmēm_, őrök, --, 
   {{0xc1040451,0x798003ac,0x8574010a,0xd62400f3}},	//   ٽوري, _xflw, _улкх, _коче_, 
   {{0xe4502dd0,0x691c01a6,0x4394eba0,0x00000000}},	//   _وضع_, _ušeć, _лайс, --, 
   {{0xd01814a3,0x683c00ef,0x00000000,0x00000000}},	//   афу_, bīde, --, --, 
   {{0x787402d5,0xdd98eba1,0x00000000,0x00000000}},	// [14710] _išve, вше_, --, --, 
   {{0x7ae8069c,0x9ce4eba2,0x442801d4,0x7cf00ad9}},	//   _rret, ицел, _hma_, jórð, 
   {{0x7ae83d67,0x35681b49,0x612001a9,0x0eac02e5}},	//   _sret, _ሰዓታት_, _kеlm, _चिथड, 
   {{0x5fdc0490,0x54780a7c,0xb47800df,0x00000000}},	//   _पोचल, דטאו, אָסי, --, 
   {{0x4428eba3,0x3f98eba4,0x644c05da,0x7ac801d3}},	//   _mma_, _iesu_, ïbiy, اوتِ_, 
   {{0x7ae8eba5,0x14040490,0x4428eba6,0xd1840055}},	//   _vret, _लव्ह_, _lma_, _bāṭī_, 
   {{0x4428eba7,0xb7bc00a8,0x7ae8eba8,0x3f980124}},	//   _oma_, liţi, _wret, _kesu_, 
   {{0x44280521,0x3a740395,0x00000000,0x00000000}},	//   _nma_, _глар, --, --, 
   {{0x7ae8eba9,0x7c28ebaa,0x3f98ebab,0x7b1405f5}},	//   _uret, _imer, _mesu_, _удах, 
   {{0xe614ebac,0x3f9803b4,0x0f580a7c,0xf624030d}},	//   йды_, _lesu_, סיזם_, ёдно, 
   {{0x4428ebad,0x7c28cb86,0xea6417a5,0x7e6400a3}},	//   _bma_, _kmer, _اپلی, imhp, 
   {{0x3f98ebae,0x645c022e,0x00000000,0x00000000}},	//   _nesu_, _chqi, --, --, 
   {{0x4428b7ad,0x7c28ebaf,0xa854011a,0xb604032e}},	//   _dma_, _mmer, _פינה_, guáæ, 
   {{0x6618ebb0,0xb7bc084c,0xa3080014,0xc87806be}},	//   chtk, diţi, ارَے_, _yuğ_, 
   {{0x3f98ebb1,0xee3800c2,0x756401ed,0x70780214}},	//   _besu_, ҳна_, _دیدہ_, امرز_, 
   {{0x3f9806af,0x4428df02,0x00000000,0x00000000}},	//   _cesu_, _gma_, --, --, 
   {{0xee38ebb2,0x3f98ebb3,0x6678010f,0xdb08007c}},	// [14720] гна_, _desu_, ָטעק, nggä, 
   {{0x99840118,0x00000000,0x00000000,0x00000000}},	//   dinů_, --, --, --, 
   {{0x4428ebb4,0x3f980421,0xad58ebb5,0xada4013e}},	//   _yma_, _fesu_, урах_, _қавл, 
   {{0xeb98ebb6,0xa3c800ab,0x3f98ebb7,0xb7bc0311}},	//   اضات_, र्प_, _gesu_, biţi, 
   {{0xcc88cae0,0xb7bc0356,0xa9c80166,0x998401ef}},	//   انچه_, ciţi, гыйз_, ginů_, 
   {{0x7c28ebb8,0x00000000,0x00000000,0x00000000}},	//   _emer, --, --, --, 
   {{0x7c280334,0x1d040120,0x7cf003b2,0x106c01ec}},	//   _fmer, _лери_, rórð, _ﺳﯟﺩﯨ, 
   {{0x6c342c6c,0xa9c40014,0x00000000,0x00000000}},	//   _افرا, _گزرو, --, --, 
   {{0xe8f80348,0xa3c86495,0xa9a40139,0xdb64001f}},	//   _әле_, र्फ_, _гизд, ታቸውም_, 
   {{0x645c07db,0xa3c8095f,0x4428ebb9,0x6aa0ebba}},	//   _shqi, र्न_, _sma_, msof, 
   {{0xb7bc00a8,0xdb181497,0x7c28ebbb,0xa908007b}},	//   ziţi, _acuè, _ymer, _حيال_, 
   {{0x6b805930,0x6aa0ebbc,0x4428037e,0x661801f7}},	//   ncog, osof, _qma_, shtk, 
   {{0x6aa0ebbd,0x4428ebbe,0x3f9808e5,0x491000bc}},	//   nsof, _vma_, _resu_, तनको_, 
   {{0x3f98ebbf,0xf66400db,0x00000000,0x00000000}},	//   _sesu_, _дечү, --, --, 
   {{0x9580006d,0x3f98ebc0,0x1fa4ebc1,0xa484ebc2}},	//   łącz, _pesu_, йраг, _اجتن, 
   {{0x4428ebc3,0xb7bc084c,0x00000000,0x00000000}},	//   _uma_, tiţi, --, --, 
   {{0x3f9819a2,0x2c7c06af,0x6aa001f5,0xf1c000ef}},	// [14730] _vesu_, _aïd_, jsof, _bešā_, 
   {{0x4438ebc4,0x201807d6,0xb7bc084c,0x6aa001e3}},	//   lns_, shqi_, riţi, dsof, 
   {{0x7cd8ebc5,0xfcd400c6,0x6aa09cbb,0x3f98ebc6}},	//   рмер_, تياج, esof, _tesu_, 
   {{0x4438ebc7,0x3b545378,0x6b802572,0x200c00c5}},	//   nns_, окер, gcog, ögid_, 
   {{0xa3c806ab,0x4438ebc8,0xe3bc010e,0x00000000}},	//   र्य_, ins_, giñi_, --, 
   {{0x0f24068e,0x00000000,0x00000000,0x00000000}},	//   _хьюм, --, --, --, 
   {{0xf8a80502,0x7c2802d3,0x6d4800ac,0xf864ebc9}},	//   شگاه_, _tmer, üfat, овко, 
   {{0xa3c81d97,0x6b800801,0x4438ebca,0xdb202f4d}},	//   र्म_, ccog, jns_, _فوزی, 
   {{0x6aa0e481,0x0a9400f5,0x3948012d,0x00000000}},	//   csof, _натю, łas_, --, 
   {{0xf62400d6,0x00000000,0x00000000,0x00000000}},	//   ідно, --, --, --, 
   {{0xa3c839d7,0xf4040798,0x443801a8,0xe3e00154}},	//   र्भ_, çãoe_, fns_, যানব, 
   {{0xdb18ebcb,0x4438ebcc,0x7c38015d,0x00000000}},	//   _acué, gns_, nnwr, --, 
   {{0x35a400c7,0xaae000bc,0x0618009d,0x00000000}},	//   _далг, पिएक, рхөө_, --, 
   {{0x4438ebcd,0xa3c827a6,0x00000000,0x00000000}},	//   ans_, र्ब_, --, --, 
   {{0x6b80ebce,0x4438003a,0xc0ec02d3,0xaf9822c3}},	//   ycog, bns_, _ቅቡል_, итах_, 
   {{0x644404a7,0x44380334,0x6fb4ebcf,0x6aa0013a}},	//   čkic, cns_, تمرا, ysof, 
   {{0xb2240116,0x116801d5,0xd1240092,0x00000000}},	// [14740] _ммил, _گلدی_, ደላቸው, --, 
   {{0x237c0030,0xe81400cd,0x00000000,0x00000000}},	//   ľuje_, _तत्थ_, --, --, 
   {{0x237cebd0,0x640003e6,0x0eac0073,0xa8000205}},	//   žuje_, _رژێم, _चिवड, ğızm, 
   {{0x6aa08e9b,0x00000000,0x00000000,0x00000000}},	//   tsof, --, --, --, 
   {{0x6aa005b1,0x6b8003ef,0x00000000,0x00000000}},	//   usof, rcog, --, --, 
   {{0x6aa0ebd1,0xfd54063f,0x628002b5,0xe3bcebd2}},	//   rsof, nlaị, _ōnok, riñi_, 
   {{0xa3c8072a,0x0f38001f,0xeb98011c,0x00000000}},	//   र्ड_, _በመሠረ, _виб_, --, 
   {{0xec14ebd3,0x6aa0df5f,0x290c0210,0x6fb80210}},	//   _بورد, psof, ryfa_, इलिं, 
   {{0x4438ebd4,0x26c000d2,0x6aa00175,0x47340cc9}},	//   vns_, îko_, qsof, янис, 
   {{0x4438ebd5,0x699410a7,0xe8f406c2,0x00000000}},	//   wns_, _фрах, _وساخ, --, 
   {{0xb864004b,0x4438ebd6,0xa96849f6,0xd82c22cb}},	//   _ځانو, tns_, _ئمام_, _жэ_, 
   {{0x44381675,0xb864ebd7,0xd7ec0597,0x3218013a}},	//   uns_, _فانو, _لكم_, _alpy_, 
   {{0x787402d5,0xe1f001d9,0x4438ebd8,0x91e400fe}},	//   _išva, وسس_, rns_, মানখ, 
   {{0x482400db,0x44380171,0x69c80042,0x00000000}},	//   _بىچق, sns_, nffe, --, 
   {{0x612001d5,0xd9280023,0x99840356,0x7c380042}},	//   _kеli, _እንተን, linţ_, ynwr, 
   {{0xd9180a7c,0xcff40395,0x00000000,0x00000000}},	//   בולל, мпсъ, --, --, 
   {{0xa3c82ce6,0xe3bc05c7,0xdce4007f,0xaad8000d}},	// [14750] र्ण_, fiñv_, čmčt, _मैलक, 
   {{0xc0c44cf3,0x69c801f5,0x628c73a5,0x200c0254}},	//   _нәби, jffe, mpco, ögib_, 
   {{0x628c560b,0xa2584056,0x69c80142,0x00000000}},	//   lpco, ntôm, dffe, --, 
   {{0x628c01f5,0xa5c81116,0xed4c01d9,0xbe0400e5}},	//   opco, त्तौ, چھہ_, _کوسٹ, 
   {{0xdef876d0,0x4f8401d9,0x9a8440c4,0x7c38015d}},	//   _тын_, _تاپہ, цуел, rnwr, 
   {{0x628c010a,0x7e7ca0ec,0xe3bc002e,0xab6000d1}},	//   ipco, _iusp, miñu_, رۇلى, 
   {{0x5ba43529,0x7e7c2611,0xe00c0406,0x00000000}},	//   _мраз, _husp, _सवाद_, --, 
   {{0x69c820ac,0x7e7c6d1c,0x7e7401c0,0xd1c0010c}},	//   affe, _kusp, _hizp, _ስዓት_, 
   {{0x7e7c014f,0x7bd8ebd9,0xd70400d1,0xe9a41456}},	//   _jusp, mewu, زىدۇ_, زگەن_, 
   {{0xca7404a9,0x7e7cebda,0x7bd8ebdb,0x15c40150}},	//   _قالغ, _musp, lewu, _ﺒﻤﺒﺩ, 
   {{0x7e7c047e,0x7e74ebdc,0xca48129e,0x628c0076}},	//   _lusp, _mizp, _بلله_, epco, 
   {{0x7bd8ebdd,0x7e7c05c7,0x00000000,0x00000000}},	//   newu, _ousp, --, --, 
   {{0x55c0005e,0x7e7cebde,0x5ed000bd,0xa7c42756}},	//   _жалғ, _nusp, সিডে, _رژيم_, 
   {{0x7bd8209c,0xbfa000d8,0xa18424fc,0x6d400356}},	//   hewu, ãªnc, збра_, şoai, 
   {{0x7e7cebdf,0x628c34b9,0x7bd8ebe0,0x81c40124}},	//   _ausp, apco, kewu, ьарҧ, 
   {{0x7e7cebe1,0x7e74ebe2,0xa3c8c126,0xf3f4031c}},	//   _busp, _aizp, र्द_, _བོིད_, 
   {{0x7e7cebe3,0x7bd8014b,0x7e74ebe4,0x69c8ebe5}},	// [14760] _cusp, dewu, _bizp, yffe, 
   {{0x7e7c0841,0xb62c04ce,0x5de0014b,0x00000000}},	//   _dusp, _ｓｍ_, нжуа, --, 
   {{0xf8a45311,0x7e74083a,0x7e7cebe6,0x7bd8ebe7}},	//   _جک_, _dizp, _eusp, fewu, 
   {{0x7bd8d909,0xca500150,0xbc2400d1,0x00000000}},	//   gewu, _ﺎﺭﺽ_, ورنى, --, 
   {{0x1e801fe2,0x7e7c004e,0x93501ee0,0xfb2400d1}},	//   _плям, _gusp, _መንቀሳ, ۋرۇپ, 
   {{0x7e74005a,0x88c8031c,0xceb40213,0x00000000}},	//   _gizp, _གྱུར, mrə_, --, 
   {{0x69c80cfd,0x9d40681b,0x7e7c0e78,0x998031b1}},	//   rffe, _зерд, _zusp, رليو, 
   {{0x7e7c0054,0x7790ebe8,0xe784ebe9,0x69c803cb}},	//   _yusp, نیما, чуко, sffe, 
   {{0xba3c0316,0x69c8ebea,0x00000000,0x00000000}},	//   _kvůl, pffe, --, --, 
   {{0x1dcc2886,0x645c007f,0xadf04a01,0xaa581e24}},	//   स्पत, _èpiz, घाटन_, _الطا_, 
   {{0x9f44012c,0xa3c8033d,0x6e2c037e,0x68440150}},	//   ěné_, _रउआ_, _mmbb, _енжа, 
   {{0x3ce4000f,0xf7e80046,0x765c0022,0xceb403e3}},	//   _âlve_, _ورنى_, ïsyr, krə_, 
   {{0x27e40418,0xa25800d8,0x6e2c035a,0x628c0f53}},	//   _iaon_, stôm, _ombb, upco, 
   {{0x7e7cebeb,0x27e400c6,0x7bd802c4,0x46140244}},	//   _rusp, _haon_, zewu, _زوبر, 
   {{0x7e7cebec,0x27e4ebed,0x7bd8aa1b,0x2b50033f}},	//   _susp, _kaon_, yewu, żych_, 
   {{0x7e7c060a,0xceb400ac,0x628c037e,0x7bd800e8}},	//   _pusp, frə_, ppco, xewu, 
   {{0x644cebee,0x7e7c0309,0x27e4030a,0x2ec00c75}},	// [14770] moci, _qusp, _maon_, көрм, 
   {{0x7e7c0477,0x7bd80337,0x5d64084c,0xe3bc0694}},	//   _vusp, wewu, птез, riñu_, 
   {{0x27e40418,0x7bd8ebef,0x00000000,0x00000000}},	//   _oaon_, tewu, --, --, 
   {{0x644cebf0,0x27e4ebf1,0x7e7c01fa,0x3ddc009e}},	//   noci, _naon_, _tusp, ঠাইল, 
   {{0xc5b404c5,0x20080393,0x7e7c3110,0x660801c7}},	//   জ্যপ, _ioci_, _uusp, _oofk, 
   {{0x7bd8abe0,0x644c003c,0x200801f1,0x66080240}},	//   sewu, hoci, _hoci_, _nofk, 
   {{0x644cebf2,0x27e422d0,0xa964036b,0x08d402d5}},	//   koci, _baon_, миша_, ецыя, 
   {{0xd0f80302,0x2008ebf3,0x27e4054e,0xdbd4013d}},	//   למות_, _joci_, _caon_, _täñq, 
   {{0x644cebf4,0x27e42b92,0x2008ebf5,0x660801f5}},	//   doci, _daon_, _moci_, _bofk, 
   {{0xa3c8107c,0xe6900b43,0x66080427,0x4e0000dc}},	//   र्स_, کلید, _cofk, रायै_, 
   {{0x1dcc08df,0x39140532,0x644c003a,0x6444ebf6}},	//   स्यत, _تواز, foci, čkin, 
   {{0x20080e8b,0x78740064,0x6eb0012d,0xf7180153}},	//   _noci_, _išvo, ेंमु, _мілы_, 
   {{0xe2942f45,0xe72c16e4,0x00000000,0x00000000}},	//   мая_, _ре_, --, --, 
   {{0x047804fb,0x00000000,0x00000000,0x00000000}},	//   _کليک_, --, --, --, 
   {{0x2008ebf7,0x27e4113c,0x644cebf8,0x3cf82e05}},	//   _boci_, _yaon_, boci, ूहों_, 
   {{0x644cebf9,0x20080b45,0xdb18ebfa,0x2164ebfb}},	//   coci, _coci_, _acuí, фиси_, 
   {{0x20080b91,0x6da458a8,0x00000000,0x00000000}},	// [14780] _doci_, диза, --, --, 
   {{0x1f600276,0x00000000,0x00000000,0x00000000}},	//   ткум, --, --, --, 
   {{0x2008ebfc,0xa3c842e3,0xed5801c0,0xf0642472}},	//   _foci_, र्व_, цож_, _окоп, 
   {{0x20080114,0x814400f1,0xc0580064,0xceb406be}},	//   _goci_, _سپټم, _ніў_, prə_, 
   {{0x27e4ebfd,0xb3c406ab,0x00000000,0x00000000}},	//   _raon_, _वानख, --, --, 
   {{0x2bac07ae,0x27e41509,0x644c463d,0xd5cc00dc}},	//   ộc_, _saon_, zoci, त्मज, 
   {{0x27e4ebfe,0x644cebff,0x98c001e0,0x787000c7}},	//   _paon_, yoci, всыл, _ẽvap, 
   {{0xe77400d1,0x00000000,0x00000000,0x00000000}},	//   майә_, --, --, --, 
   {{0x644cec00,0x6608ec01,0x27e40109,0xc5f800e2}},	//   voci, _pofk, _vaon_, kmēt_, 
   {{0x66080a81,0x27e4022f,0x7b6401d9,0x612001a9}},	//   _qofk, _waon_, _ساقٕ, _kеlt, 
   {{0x27e4ec02,0x1a64030f,0x843400d4,0x00000000}},	//   _taon_, _تیوی_, еннє, --, 
   {{0xf8ac07d6,0xe3bc0489,0x684401d5,0xc0c400c7}},	//   _اکو_, viñs_, _ўнда, ҕәои, 
   {{0xa3c822e3,0x2008054e,0x00000000,0x00000000}},	//   र्ष_, _roci_, --, --, 
   {{0x2008ec03,0x1fa40b98,0x00000000,0x00000000}},	//   _soci_, गण्ड, --, --, 
   {{0x20080066,0x00000000,0x00000000,0x00000000}},	//   _poci_, --, --, --, 
   {{0x644c0481,0xca501c5c,0xa3c81fc4,0x00000000}},	//   qoci, ﺎﺩﺍ_, र्श_, --, 
   {{0xc6bc2158,0x2008ec04,0x2464001f,0x3df4792b}},	// [14790] _অনুচ, _voci_, _ታህሳስ_, нзас, 
   {{0x78640261,0xa3c81889,0x00000000,0x00000000}},	//   móve, र्र_, --, --, 
   {{0x9444004b,0x786459de,0x00000000,0x00000000}},	//   _سپین, lóve, --, --, 
   {{0x7124036b,0x3fd80304,0x48f400cd,0x00000000}},	//   _سرپل, _эммэ_, ्मनो_, --, 
   {{0x1dc40c2e,0x1e706f78,0xd1080811,0x00000000}},	//   _लापत, _ағас, _فقیه_, --, 
   {{0x0d8411db,0x3f880a14,0x00000000,0x00000000}},	//   _алён, lcau_, --, --, 
   {{0x0f380092,0x00000000,0x00000000,0x00000000}},	//   _በመሰረ, --, --, --, 
   {{0x3f88ec05,0x9ba001ec,0x3ea8005b,0x3e6c0064}},	//   ncau_, _شەتى, osat_, _ežtt_, 
   {{0x3ea8ec06,0xf7707146,0x1dcc3885,0x64440010}},	//   nsat_, داث_, स्थत, čkil, 
   {{0x3ea8a865,0xc9a800f3,0x00000000,0x00000000}},	//   isat_, _овђе_, --, --, 
   {{0x3ea8ec07,0x068496da,0x98b00064,0x00000000}},	//   hsat_, нгөн, _įdėt_, --, 
   {{0x3ea8ec08,0x1dcc0882,0xa3c81b76,0x79540023}},	//   ksat_, स्तत, र्ल_, _ምሕታት, 
   {{0x3ea8007c,0x00000000,0x00000000,0x00000000}},	//   jsat_, --, --, --, 
   {{0x3ea8ec09,0x25acec0a,0x2908004e,0x200c01a8}},	//   dsat_, _gdfl_, _àbac_, ögin_, 
   {{0x386c1590,0x3ea8ec0b,0x6ff4ec0c,0xa3c806ab}},	//   omer_, esat_, нчах, _रॉक_, 
   {{0x386c2622,0x09dc0882,0x3ea8ec0d,0x73e401f0}},	//   nmer_, _यस्य, fsat_, _чоиз, 
   {{0x3ea800ee,0xe0401513,0xcdc400c7,0x00000000}},	// [147a0] gsat_, унти, каақ, --, 
   {{0x386c0730,0xda0000e1,0xbe481f0d,0x00000000}},	//   hmer_, लाफत_, وشلم_, --, 
   {{0x3ea8ec0e,0x386c01a2,0xfe740145,0x7c6400d1}},	//   asat_, kmer_, түр_, چانل, 
   {{0xc5f800da,0x3ea8014a,0x3f8807de,0x386cec0f}},	//   nmēr_, bsat_, ccau_, jmer_, 
   {{0x386c0c86,0xddcc00bc,0x2984013d,0x7b800116}},	//   dmer_, řeše, ныйг, рғуд, 
   {{0xda6c01d9,0x386cec10,0xa3780037,0x00000000}},	//   مُن_, emer_, rdõi, --, 
   {{0xeb9803b7,0x2918ec11,0xf1d000dc,0x3c84013e}},	//   _нив_, ápa_, द्यन, _аксҳ, 
   {{0xc6f8ec12,0x386c072b,0x00000000,0x00000000}},	//   дних_, gmer_, --, --, 
   {{0x29180bf1,0xe5c404b0,0xf72c0240,0x00000000}},	//   špa_, нсно, _እትውን, --, 
   {{0x386cec13,0x6444107d,0x9bdc0165,0xbbbc010b}},	//   amer_, čkim, _zhuǀ_, _çärý, 
   {{0x4394c5d1,0xd5b40209,0x75c83e64,0x00000000}},	//   канс, хсы_, фтың_, --, 
   {{0xd49400a8,0x3ea80072,0x786400e5,0xa3c80037}},	//   эрь_, ysat_, tóve, _रउओ_, 
   {{0x3ea87071,0xe3e0015b,0x628000d7,0x00000000}},	//   xsat_, যালব, _čnos, --, 
   {{0x171804ac,0xa37800d8,0xda00dadd,0x00000000}},	//   _צוגע, deõe, लायत_, --, 
   {{0x9f44038e,0xb9fc001f,0x3ea80009,0x403400d8}},	//   ění_, _ቆዳ_, wsat_, вевс, 
   {{0x7afc02d2,0x3f880051,0x79340240,0x00000000}},	//   _ástg, ucau_, _ክንብድ, --, 
   {{0x5064ec14,0x3f881570,0x3ea8180f,0xdc106656}},	// [147b0] утра, rcau_, usat_, xşıs, 
   {{0x3ea8ec15,0x3f88ec16,0x386cb515,0x661802ed}},	//   rsat_, scau_, zmer_, nktk, 
   {{0x3ea8ec17,0x00940323,0xdcb80801,0x00000000}},	//   ssat_, _шинэ, яща_, --, 
   {{0xdb1830cf,0x3ea80316,0xbf1029db,0x00000000}},	//   _acuá, psat_, _күбә, --, 
   {{0x7c280327,0xd1340092,0x00000000,0x00000000}},	//   _ċerd, _አስተው, --, --, 
   {{0xdc10e16d,0x386c0204,0x7054001f,0xf8b8009d}},	//   rşıs, wmer_, _መብታቸ, дөд_, 
   {{0x6d40084c,0xf86825a7,0x9cb8031c,0x6444107d}},	//   şoar, ومتي_, _པའིས, čkij, 
   {{0x386cec18,0x20180472,0x5884035b,0x66180166}},	//   umer_, nkqi_, _ҷыда, ektk, 
   {{0x3a74ec19,0xe7f000e1,0xc0440092,0x00000000}},	//   _алар, _अफरा_, _የእስል, --, 
   {{0x386cec1a,0xb0640108,0x00000000,0x00000000}},	//   smer_, _krää, --, --, 
   {{0x386c0526,0xcec000bc,0xceb40213,0x48f400dc}},	//   pmer_, ěřit_, nzər_, ्मणो_, 
   {{0x28940677,0x200c0254,0xf7940153,0x00000000}},	//   _ידען_, ögil_, _радэ, --, 
   {{0xa3c8012c,0x42d400d4,0x00000000,0x00000000}},	//   र्इ_, ліру, --, --, 
   {{0x95c84483,0x998800d0,0x75d4009f,0xf504009f}},	//   _худа_, álňa_, _شيعا, _لِتُ, 
   {{0x9f480c95,0x200c01d5,0x00000000,0x00000000}},	//   _incù_, аgi_, --, --, 
   {{0xe040ec1b,0x2fd8314e,0x764001e3,0xa06400f3}},	//   анси, بورد_, lnly, васа_, 
   {{0x9f801513,0x81c80154,0x00000000,0x00000000}},	// [147c0] ргуд, োয়_, --, --, 
   {{0x7640e279,0x00000000,0x00000000,0x00000000}},	//   nnly, --, --, --, 
   {{0xfca800f1,0xad580229,0x5de0009d,0x03e400eb}},	//   فانو_, фрах_, ржха, গারী_, 
   {{0xd1340201,0x76400334,0x62880129,0xeb98ec1c}},	//   _አስታው, hnly, _égoc, фид_, 
   {{0xeaf8ec1d,0xb06402f6,0xf3f4031c,0x00000000}},	//   برات_, _erää, _བོནད_, --, 
   {{0xda602f59,0x249c001f,0x7c280135,0xd1d8069d}},	//   авчи, ቀጥሉት_, _ċere, _ክበብ_, 
   {{0x6c7400c7,0xed5801af,0x00000000,0x00000000}},	//   _ауах, _цов_, --, --, 
   {{0x9f480268,0x764000ad,0xa73000ee,0xca500150}},	//   _ancù_, enly, идйә, _ﺎﺭﺉ_, 
   {{0x1dcc08ec,0xe6640228,0x28ac00e1,0xca641188}},	//   स्वत, ктоо, _टिकि, _беақ, 
   {{0xf4280108,0xe8f8009d,0x00000000,0x00000000}},	//   yrää_, _олз_, --, --, 
   {{0xd940ec1e,0x6618c304,0x7afc0129,0xd5440014}},	//   _кефи, rktk, _àstr, ہلیو_, 
   {{0x7640a0be,0x00000000,0x00000000,0x00000000}},	//   anly, --, --, --, 
   {{0x45d4ec1f,0x07a4013d,0x7d040175,0x16a40117}},	//   _болс, _ааҗн, zxhs, _авчи_, 
   {{0x752c00bc,0x7864ec20,0xca500150,0x7afc02d2}},	//   _řaze, móva, _ﺎﺭﺏ_, _áste, 
   {{0x955015fa,0x2fd00368,0xf1d0193d,0xff1c00b5}},	//   _پخوا, ffyg_, द्धन, mのip_, 
   {{0x6614010e,0xf4280108,0x200c0162,0x00000000}},	//   _įyky, rrää_, ðgi_, --, 
   {{0x7864ec21,0xa3d001a9,0x00000000,0x00000000}},	// [147d0] nóva, _боқч, --, --, 
   {{0xeb941607,0xb064000d,0xe45c3b22,0x70500137}},	//   қиш_, _prää, llö_, _ۇچقا, 
   {{0x8d84a6e6,0x3a7400ee,0x4034022e,0x00000000}},	//   рууд, ңлер, _бенс, --, 
   {{0x78640124,0xdfcc0451,0xca500150,0x00000000}},	//   kóva, _ڏيڍ_, _ﺎﺭﺍ_, --, 
   {{0x443809ad,0x1ea800db,0x78643239,0x9f480694}},	//   iis_, _تاجي_, jóva, _macë_, 
   {{0x4438ec22,0x78740006,0x7864ec23,0x6120022e}},	//   his_, _išvi, dóva, _yеlp, 
   {{0x4438ec24,0x00000000,0x00000000,0x00000000}},	//   kis_, --, --, --, 
   {{0x4438ec25,0x764003cb,0xa3e0000d,0x00000000}},	//   jis_, wnly, _नक़ल_, --, 
   {{0x7bc8003e,0x786400e5,0x00000000,0x00000000}},	//   _iceu, góva, --, --, 
   {{0x7f5cec26,0x7ae8ec27,0x4438ec28,0xceb40375}},	//   _mysq, _iset, eis_, ביץ_, 
   {{0xe2940184,0x9f480200,0x7640072b,0x2fd00142}},	//   ғас_, _bacë_, rnly, yfyg_, 
   {{0x4438ec29,0x7ae800b8,0x00000000,0x00000000}},	//   gis_, _kset, --, --, 
   {{0x63b80008,0x87040244,0x00000000,0x00000000}},	//   óuna, _نبول, --, --, 
   {{0x4438ec2a,0x7ae800ec,0x05940408,0xd5840133}},	//   ais_, _mset, _вăрм, _جێده_, 
   {{0x4438ec2b,0x7ae800d2,0x28c4ec2c,0x3d1c033f}},	//   bis_, _lset, रूपि, पनों_, 
   {{0x4438ec2d,0x7ae8ec2e,0xd5cc53b7,0xc4c40244}},	//   cis_, _oset, त्रज, _ئتوو, 
   {{0x2d94e514,0x7ae801f2,0x7c38015d,0x00000000}},	// [147e0] грес, _nset, diwr, --, 
   {{0x7bc80c6a,0x683c00e2,0x00000000,0x00000000}},	//   _aceu, mūde, --, --, 
   {{0x7ae8ec2f,0xa3c82765,0x9f44012c,0xdcac0873}},	//   _aset, र्क_, ěná_, كىل_, 
   {{0x7ae8003e,0x2ef0017a,0xfa5401d5,0x2b44009d}},	//   _bset, pvyf_, یروگ, лэлг, 
   {{0x1b14015b,0xfc58001f,0x28c4072a,0x7ae800e5}},	//   _দেবে_, ያረጋግ, रंभि, _cset, 
   {{0x4438ec30,0xb88401f1,0x2d980175,0x00000000}},	//   zis_, zlíš, qbpe_, --, 
   {{0x7ae8ec31,0x4438ec32,0x98a00640,0x69e000bc}},	//   _eset, yis_, бије, _čteč, 
   {{0x4814ec33,0x798000a9,0x955802d3,0x786401ed}},	//   рмис, _eglw, _ሳዕቤን_, tóva, 
   {{0x98b00115,0x9f48036e,0x57f00153,0xe9d800d8}},	//   _ĉeĥe_, _racë_, спыт, _пка_, 
   {{0x4438ec34,0xdb2019db,0xba5000cf,0x21d001ec}},	//   wis_, _órái, _وچوع, _ﺘﻤﺎﺭ, 
   {{0x4438ec35,0xd7ecacf8,0x200c01b8,0x28ac0dba}},	//   tis_, _лу_, ögik_, _टिटि, 
   {{0x4438ec36,0x387c0165,0xf8b4ec37,0x2a7c022e}},	//   uis_, _giwr_, _төш_, _hitb_, 
   {{0x44380d63,0xa3c8547d,0x21a400fd,0xe618005b}},	//   ris_, र्ग_, ләнү_, _пдд_, 
   {{0x450c031c,0x00000000,0x00000000,0x00000000}},	//   གྱུར_, --, --, --, 
   {{0x44387f93,0x4394cb23,0xd250040b,0xd48cec38}},	//   pis_, _кайс, سنِ_, _ыр_, 
   {{0x4438ec39,0x9f4800eb,0xc024005e,0x7f9405f5}},	//   qis_, _hacé_, جىري, раах, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [147f0] --, --, --, --, 
   {{0x7bc81db0,0x7ae803b2,0x81d4009d,0x00000000}},	//   _sceu, _rset, _тоох, --, 
   {{0x7ae8ec3a,0x7c380113,0x9f480129,0x042c00cd}},	//   _sset, tiwr, _macé_, _śuṣk, 
   {{0x7ae80e3c,0x1dc40490,0x2c7c0118,0xe3e000eb}},	//   _pset, _लावत, _půda_, যাকব, 
   {{0x4c94039b,0x7980035a,0x7c380142,0xf1d000cd}},	//   _ҳисс, _pglw, riwr, द्वन, 
   {{0x7ae86b07,0x44c401e1,0x387c00a9,0x09d802f5}},	//   _vset, _akọṣ, _siwr_, _ধোবা, 
   {{0x55c00032,0xa8001432,0x4c94004e,0x78740419}},	//   ҙанғ, ğınm, _гисс, _mšvv, 
   {{0xb8cc09d9,0x7ae825f0,0xc8880597,0xa80047af}},	//   _कब_, _tset, دخول_, şınm, 
   {{0x76240da6,0x7ae80028,0x9f48019f,0xf6240474}},	//   имиз, _uset, _bacé_, идио, 
   {{0xe614ec3b,0xca500150,0xceb40677,0x28ac0118}},	//   иды_, _ﺎﺭﺓ_, זיץ_, _टिचि, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xda00a4ea,0x377400f7,0x00000000,0x00000000}},	//   लावत_, _кылс, --, --, 
   {{0x2a7c009a,0x87ac008f,0x28c421f2,0x00000000}},	//   _yitb_, _טשאַ, रंथि, --, 
   {{0x78400171,0x00000000,0x00000000,0x00000000}},	//   dēvi, --, --, --, 
   {{0x70541532,0xc0c800d8,0x00000000,0x00000000}},	//   لنسا, луѓе_, --, --, 
   {{0xdb080008,0xd58404d3,0x245035cf,0x8cc405c0}},	//   yggð, _جێگه_, _ونوس, ांसो, 
  
   {{0x84444630,0xa3780254,0xa3e00e49,0xf34800d8}},	// [14800] _دخول, leõn, नजर_, _шпил_, 
   {{0x2d94016c,0xbda400c6,0x7c28025c,0xd2500133}},	//   ррас, محمو, _ċera, _رۆز_, 
   {{0xfaf80064,0x00000000,0x00000000,0x00000000}},	//   _arū_, --, --, --, 
   {{0x102404fb,0x2a7c0334,0xf1d01c54,0x00000000}},	//   _اکسپ, _sitb_, द्रन, --, 
   {{0xa3c817cb,0xf1a8033f,0x00000000,0x00000000}},	//   र्ट_, _क़ान, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9d40ec3c,0x1d041575,0x9d140137,0xebe400d4}},	//   _дерд, _кери_, _коёт_, _ковп, 
   {{0x237c00bc,0xaae410e8,0x00000000,0x00000000}},	//   žuji_, _پسرو, --, --, 
   {{0x9f48026c,0x670801c6,0x00000000,0x00000000}},	//   _pacé_, тэйг_, --, --, 
   {{0xc0e4044e,0x7afc008c,0x29540354,0x00000000}},	//   _ዝደሊ_, _ásta, _къер, --, 
   {{0x752c02a8,0x00000000,0x00000000,0x00000000}},	//   _ƙaza, --, --, --, 
   {{0x68f8035a,0x35c400c7,0xd918011a,0x00000000}},	//   _irtd, аҳәо_, _שואל, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa3c86620,0x6d4cdb94,0x55e000ee,0xd6240063}},	//   र्ज_, _oxba, _мочб, _воље_, 
   {{0x1fa4ce06,0x69d80263,0xdb1c02d2,0x00000000}},	//   ираг, _mbte, _ívör, --, 
   {{0x79340201,0xcf9830ba,0x62880798,0x0f380092}},	//   _እንቅስ, ију_, _égoo, _በመምረ, 
   {{0x6d4c7d85,0x00000000,0x00000000,0x00000000}},	// [14810] _axba, --, --, --, 
   {{0x68f801b9,0x00000000,0x00000000,0x00000000}},	//   _ortd, --, --, --, 
   {{0x5274dbc8,0x05240154,0xe0e401d5,0xd654011a}},	//   _بايز, _পশুর_, _тўпо, סיבת_, 
   {{0xa3c81d68,0x69d8ec3d,0xccf80640,0xfaf80064}},	//   र्च_, _abte, шћу_, _prū_, 
   {{0x68f8ec3e,0xa800719a,0x6d4c02d0,0x853c0153}},	//   _artd, ğılm, _exba, lbėd, 
   {{0xa8000ba5,0x9ce400dd,0xa9a001b9,0xdb080200}},	//   şılm, _پورے_, пишд, lagë, 
   {{0x0a3400db,0x00000000,0x00000000,0x00000000}},	//   تووڭ, --, --, --, 
   {{0xfaa8143e,0xe7a400d1,0x07f8035b,0x7d2803e0}},	//   _مهري_, مۇمى_, ахьы_, ıssı, 
   {{0xa3c80316,0x68f800b5,0x0a94ec3f,0x00000000}},	//   र्छ_, _ertd, _матю, --, 
   {{0xa3c8ec40,0x00000000,0x00000000,0x00000000}},	//   र्घ_, --, --, --, 
   {{0x2494034c,0x68f80175,0x00000000,0x00000000}},	//   ینید_, _grtd, --, --, 
   {{0x8458ec41,0x00000000,0x00000000,0x00000000}},	//   ирят_, --, --, --, 
   {{0x85440064,0x00000000,0x00000000,0x00000000}},	//   _akėč, --, --, --, 
   {{0xa378000d,0xb3400139,0x00000000,0x00000000}},	//   meõl, _íçma, --, --, 
   {{0xa1c0ec42,0x14d80490,0xd348036b,0x89380092}},	//   ябрд, _बहिण, طیگه_, _እንደቻ, 
   {{0x6140084c,0xd34801b9,0x6f880451,0x00000000}},	//   чеса, _نیجه_, انءِ_, --, 
   {{0xa064ec43,0x6d4c058a,0x1e80059f,0x9b480165}},	// [14820] сата_, _sxba, злум, ʷłtł, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa63800c8,0xfc3801e4,0xeb98ec44,0xc10800fb}},	//   נגער, _bmŭ_, гие_, _күрh, 
   {{0x69d80175,0xb2f40327,0x00000000,0x00000000}},	//   _sbte, _བློང_, --, --, 
   {{0x5c503306,0xdb08004a,0x69cc0205,0x00000000}},	//   أَنذ, nagè, _öbek, --, 
   {{0xee38ec45,0x2d9c00c7,0xa3780254,0x00000000}},	//   _снг_, _ýte_, deõl, --, 
   {{0x99d016ac,0xbe3000db,0x98a00114,0x00000000}},	//   ستوا, _تۉلب, пије, --, 
   {{0xc6200a28,0x98a00640,0xf3e800eb,0x00000000}},	//   यस्य_, чиће, গাঁর_, --, 
   {{0x8938001f,0xd1d001f3,0x00000000,0x00000000}},	//   _እንዲቻ, እስት_, --, --, 
   {{0xd6d41e76,0x69d86e99,0x00000000,0x00000000}},	//   ёты_, _ubte, --, --, 
   {{0xba3c00bc,0x68f800a2,0xf8a80133,0x00000000}},	//   _tvůr, _urtd, _ندنه_, --, 
   {{0x6e3c01f5,0xc37801c6,0x683c139f,0x00000000}},	//   hipb, ийнх_, būda, --, 
   {{0xfbd400cc,0x85440153,0x00000000,0x00000000}},	//   _সোঁত, _skėč, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdfd8059f,0x05840b01,0x69c800ae,0x00000000}},	//   лъа_, _луқм, igfe, --, 
   {{0x0a000154,0x443c00a2,0xff9800d8,0x00000000}},	//   ্সিং_, _öw_, ркај_, --, 
   {{0x257000d2,0x63ac0034,0xbe38716a,0x66f805d7}},	// [14830] bûlé_, macn, азах_, ौमिक_, 
   {{0x4428ec46,0x389402b1,0xb9100055,0xb0600139}},	//   _hla_, _hāre_, _evaṁ_, _çänl, 
   {{0x38940053,0x4428ec47,0xe05401d5,0x61e4ec48}},	//   _kāre_, _kla_, _هیآت_, mejl, 
   {{0x237c0b91,0x61e4ec49,0x4428ec4a,0xfaf80055}},	//   žuju_, lejl, _jla_, _dyūn_, 
   {{0x4428ec4b,0xd90c5022,0x1ea825a7,0xf984ec4c}},	//   _mla_, کیا_, _حاجي_, огло, 
   {{0x4428ec4d,0x69c803cd,0xdb08d8b9,0xce9401c0}},	//   _lla_, ggfe, nagé, _харъ, 
   {{0x4428ec4e,0x1b1400bd,0xe0d404c5,0x228c03e0}},	//   _ola_, _দেশে_, হিকভ, _lük_, 
   {{0x4428110e,0xdb087cda,0x61e4014f,0x7afc0162}},	//   _nla_, hagé, hejl, _ásto, 
   {{0x7c28ec4f,0x61e4031c,0x816c0150,0x00000000}},	//   _iler, kejl, _ﺴﻭﻴﺔ_, --, 
   {{0x4428ec50,0x7c28ec51,0x9f483eba,0x3618005b}},	//   _ala_, _hler, _nací_, рцию_, 
   {{0x4428ec52,0xf3e42dc1,0x63ac0009,0x73d80116}},	//   _bla_, ожно, facn, ңдүр_, 
   {{0x4428ec53,0xc2080302,0x60c401a6,0xfe04012c}},	//   _cla_, _בה_, dujm, राँस_, 
   {{0x442814cf,0x7c2802ce,0x60c40007,0x61e401ed}},	//   _dla_, _mler, eujm, fejl, 
   {{0x4428ec54,0xf8dc07b7,0x228c01b8,0x7c285cca}},	//   _ela_, _महाय, _dük_, _ller, 
   {{0x317cec55,0x7c28ec56,0x717400c6,0x25ec0490}},	//   ätz_, _oler, زهرا, _असती_, 
   {{0x4428ec57,0x7c280521,0x00000000,0x00000000}},	//   _gla_, _nler, --, --, 
   {{0xfe04298e,0xdb08255a,0x61e4047e,0x69c803cb}},	// [14840] रांस_, bagé, bejl, ygfe, 
   {{0x26c01326,0x442805a1,0xd1d0044e,0xc0d40023}},	//   škog_, _zla_, እስቲ_, ርሖም_, 
   {{0x7c28ec58,0x6e3c34b9,0x4428ec59,0xece80798}},	//   _bler, ripb, _yla_, рдел_, 
   {{0xab64ec5a,0x228c47af,0x94e40134,0x7c28ec5b}},	//   овел, _yük_, nɑɑ_, _cler, 
   {{0x6da4007b,0x7afc02d2,0xceb801ee,0x00000000}},	//   _ومحم, _ástl, _ыҙа_, --, 
   {{0x7c28ec5c,0xceb400ac,0x7bd8002d,0x6e3c014f}},	//   _eler, msə_, afwu, qipb, 
   {{0x7c28ec5d,0x69c889b7,0xceb400ac,0x63ac308e}},	//   _fler, rgfe, lsə_, yacn, 
   {{0x7c28ec5e,0x7d00011f,0xc5b4015b,0x69c80142}},	//   _gler, _álsa, জ্ঞপ, sgfe, 
   {{0x699406bb,0x442807ab,0x63ac0cf4,0xceb400ac}},	//   _дрех, _rla_, vacn, nsə_, 
   {{0x4428ec5f,0x19c00212,0xdb080129,0x6ec000bc}},	//   _sla_, _обум, xagé, _लिनु, 
   {{0x4428ec60,0x61e4037e,0xb8640608,0x92cc03d4}},	//   _pla_, vejl, _کالو, ৰটো_, 
   {{0x228c014a,0x1e14024a,0x9f480306,0xceb40213}},	//   _pük_, _दक्ष_, _sací_, ksə_, 
   {{0x4428ec61,0x48f4012c,0x533427a8,0x389400b8}},	//   _vla_, ्मको_, деят, _vāre_, 
   {{0x44281187,0x63ac00d0,0x7c28031c,0x72d015bf}},	//   _wla_, sacn, _ċerm, رەپچ, 
   {{0x44282d32,0xdb08ec62,0x389400b0,0x00000000}},	//   _tla_, ragé, _tāre_, --, 
   {{0x4428ec63,0xdb0cd644,0xdb08ec64,0x61e45c68}},	//   _ula_, _çeçe, sagé, sejl, 
   {{0x628c010a,0xdb080129,0x7c28010e,0x60c4014f}},	// [14850] qqco, pagé, _rler, sujm, 
   {{0xdd98d48e,0x60c4ec65,0x13b00eac,0x7c2803b2}},	//   рша_, pujm, _কায়, _sler, 
   {{0x7c280483,0x200c00c5,0x1278007b,0x60c4014f}},	//   _pler, ögis_, _بحيث_, qujm, 
   {{0xceb40213,0xabb40022,0x00000000,0x00000000}},	//   bsə_, зацә, --, --, 
   {{0xfaa40c04,0x7c28ec66,0x6fe40135,0x93fc0375}},	//   чало, _vler, _སྒྲའ, ילאי, 
   {{0x786498fa,0x7e7800c8,0xf990034e,0x986006be}},	//   móvi, _לאָז, ربت_, _bığ_, 
   {{0x7c28ec67,0x80d80154,0xf8b83947,0x786400e5}},	//   _tler, ডিক্, сөз_, lóvi, 
   {{0x7c28ec68,0x8bc4ec69,0xe7b00131,0x99840024}},	//   _uler, _осуд, ىمىد, tinų_, 
   {{0xa628044e,0xdcf40213,0x00000000,0x00000000}},	//   _ስለዝተ, maxı, --, --, 
   {{0x9f480ffb,0xae0c00ab,0x55f8015b,0x588400c0}},	//   _macà_, सायन_, েস্ক_, _дыда, 
   {{0x9f4819f5,0x2554012c,0xceb400ac,0x5fc8012c}},	//   _lacà_, vělé_, zsə_, िलाल, 
   {{0xda0000ab,0xdcf406be,0x99840153,0x00000000}},	//   लाकत_, naxı, pinų_, --, 
   {{0x94e4016b,0x986003e3,0x28100244,0xb60401a8}},	//   rɑɑ_, _zığ_, _سووس, gsáæ, 
   {{0x1dc4256b,0xf67400c8,0x986006be,0x00000000}},	//   _लागत, _צײַט_, _yığ_, --, 
   {{0x7640de96,0x9554e4c4,0x845c0092,0xc88400a2}},	//   mily, _بخشا, ደለምን_, _üşü_, 
   {{0x7640ec6a,0x80dc76f8,0xa11000db,0xb6440220}},	//   lily, _पहरे, روقت, _ﺎﻡ_, 
   {{0xdee0ec6b,0x9f4819f5,0x32441ca9,0x7640062c}},	// [14860] ноти, _cacà_, _неиг, oily, 
   {{0xceb403be,0xed588b1d,0xa3780254,0x00000000}},	//   rsə_, боз_, deõh, --, 
   {{0xceb400ac,0xe1f4010b,0x2adc000d,0x7afc08ce}},	//   ssə_, _эгэ_, _गहहु_, _ástj, 
   {{0xfe700058,0x29001155,0x764006be,0x00000000}},	//   ىدە_, _čka_, hily, --, 
   {{0x7640e6f5,0x3218ec6c,0x290000b0,0x786400d8}},	//   kily, _kopy_, _ōka_, cóvi, 
   {{0xa8a41b39,0x3218ec6d,0xceb80022,0x7640037e}},	//   прик, _jopy_, _гәҧ_, jily, 
   {{0x2d88ec6e,0xc0c002d3,0x321805d6,0x76405991}},	//   _igbe_, _ድቃስ_, _mopy_, dily, 
   {{0x25ec069f,0xab280329,0xa3780254,0x00000000}},	//   _असही_, _лоба_, beõh, --, 
   {{0xfbd00b40,0x7640ec6f,0xda000073,0xdce400de}},	//   _हातम, fily, लाखत_, _izjā, 
   {{0x764045b4,0x62885fe6,0x98600790,0xc5f8bef0}},	//   gily, _égoi, _tığ_, ्ञेय_, 
   {{0x2d8844fc,0x18a0013e,0xd9b00050,0xd82c8b0a}},	//   _mgbe_, _захм, _سٕند, _зэ_, 
   {{0x76400334,0x9f4400a2,0x00000000,0x00000000}},	//   aily, _üiçn_, --, --, 
   {{0x7640926a,0x2d880521,0xa6f80aaa,0x968000f1}},	//   bily, _ogbe_, _دعاء_, _ګټون, 
   {{0x32180c30,0xdcf400ac,0x7640cd03,0x3894002b}},	//   _copy_, zaxı, cily, _hāra_, 
   {{0x752001f5,0xf3f403e6,0x88d40055,0xc5f800e2}},	//   cylz, ستێک, _dṛgd, mdē_, 
   {{0x09e80729,0x248cec70,0x2d880ca8,0x9f480268}},	//   পাটা, _iufm_, _agbe_, _pacà_, 
   {{0x3894ec71,0x88d400b8,0xbdf400f0,0x00000000}},	// [14870] _māra_, _hṛdd, мпај, --, 
   {{0x9f48ec72,0x78643b7b,0xc5f800e2,0xa3780254}},	//   _cacá_, róvi, ndē_, veõh, 
   {{0x4034a230,0x8cc402ab,0x25ac0142,0xa378000d}},	//   _женс, ांगो, _mefl_, deõi, 
   {{0x22403a0e,0x8d741fd6,0x7640ec73,0x2d88ec74}},	//   lijk_, رالا, zily, _egbe_, 
   {{0xdcf403be,0x20d4ec75,0x48cc0154,0x00000000}},	//   raxı, lçi_, লবোর, --, 
   {{0x61f4b75f,0x00000000,0x00000000,0x00000000}},	//   _jaxl, --, --, --, 
   {{0x23bcec76,0x61f4ec77,0x1cc40135,0x7640ec78}},	//   ्लाद, _maxl, _ཉའི_, vily, 
   {{0x88c412b7,0x7640ec79,0x389400b8,0x61f406be}},	//   رتىل, wily, _cāra_, _laxl, 
   {{0x22400460,0x7640ec7a,0x248c0e78,0x3894002b}},	//   kijk_, tily, _aufm_, _dāra_, 
   {{0x20d4ec7b,0x88d40055,0x61f4058a,0x00000000}},	//   kçi_, _bṛdd, _naxl, --, 
   {{0xa25803b7,0x2240ec7c,0x32182f53,0x20d40200}},	//   trôn, dijk_, _ropy_, jçi_, 
   {{0x7640ec7d,0xdb0800d2,0x3218d934,0x20d40213}},	//   sily, magâ, _sopy_, dçi_, 
   {{0x7640ec7e,0x61f4022e,0x55c06518,0x00000000}},	//   pily, _baxl, _залғ, --, 
   {{0x672400cc,0xa5f40063,0x66e0011c,0x20d44dd9}},	//   økje, _жељу_, _роша, fçi_, 
   {{0x61f4ec7f,0x3eb8020c,0xb0600209,0xd3481272}},	//   _daxl, _avst_, _çäkl, تیکه_, 
   {{0x98a4068f,0xd174ec80,0x00000000,0x00000000}},	//   czną_, дығы, --, --, 
   {{0x61f4ab53,0x7afc032e,0xdfcc4706,0x00000000}},	// [14880] _faxl, _ásth, شيل_, --, 
   {{0xae0c1d72,0xd2580214,0xfe0401f9,0xd05c0213}},	//   साधन_, _ریزش_, रागस_, _əzəm, 
   {{0xdcac2374,0x4094005b,0xc10001af,0x00000000}},	//   لىل_, _прят, _йүрл, --, 
   {{0x6fb00034,0xfca831b1,0x00000000,0x00000000}},	//   _ज़िं, سامو_, --, --, 
   {{0x25ec3eaf,0x61f401b9,0xa92400e2,0x8a0401f0}},	//   _असली_, _yaxl, igžņ, нҷае, 
   {{0x89d8007b,0x38943da0,0x6cc401a9,0x00000000}},	//   سوبر_, _sāra_, _ойга, --, 
   {{0x06d800fe,0x152800b8,0x3894ec81,0xa3780254}},	//   তিছি, _tūṇī, _pāra_, reõi, 
   {{0xa3780254,0xc7b000e5,0x00000000,0x00000000}},	//   seõi, اڑا_, --, --, 
   {{0x78ac2d2b,0x389419ae,0x00000000,0x00000000}},	//   ćava, _vāra_, --, --, 
   {{0x6aa0ec82,0x389400b0,0x7c280135,0x3eac9c11}},	//   mpof, _wāra_, _ċeri, _çete_, 
   {{0x3894ec83,0x61f40166,0x00000000,0x00000000}},	//   _tāra_, _raxl, --, --, 
   {{0x61f40cc1,0x2240ec84,0x69d8ec85,0x88d40882}},	//   _saxl, wijk_, प्री, _vṛdd, 
   {{0x25ac4f1a,0xf9800124,0x3f9801e3,0x98a4012d}},	//   _tefl_, _иҳәо, _rfsu_, rzną_, 
   {{0x20d4ec86,0x2bdc01ad,0x29080129,0x98a40210}},	//   tçi_, फ्ता, _àbas_, szną_, 
   {{0x22400936,0xe45c0421,0xe7c000fe,0x2b58012d}},	//   rijk_, poö_, ্জীয, ępcy_, 
   {{0x1ea805d4,0x20d4ec87,0x61f41dd0,0x6e2c7350}},	//   قائي_, rçi_, _waxl, _albb, 
   {{0x644c6580,0x20d40c3c,0x61f40169,0xaf540124}},	// [14890] mnci, sçi_, _taxl, ентә, 
   {{0xb7d40ca8,0x7afc0252,0x20d42ac2,0x733453f0}},	//   _iṣet, _ásti, pçi_, _سىپا, 
   {{0x644c0395,0xdb08ec88,0x12d00349,0x925800ae}},	//   onci, ragí, িবৃদ, _تشير_, 
   {{0xdfa40597,0xb7d40882,0x209800b4,0xdb0400e8}},	//   _تحدي, _kṣet, _ụkwụ_, _ëlëg, 
   {{0x644c00c6,0xf428005b,0x98b015b7,0x00000000}},	//   inci, lsää_, _ıdır_, --, 
   {{0x644c010a,0x6288004a,0xd1f40092,0x00000000}},	//   hnci, _égou, _ውበት_, --, 
   {{0x1b145d2d,0x6a80ec89,0xe94400dd,0x4c940022}},	//   _দেখে_, ылша, ٹروی, _аисс, 
   {{0xa25800d8,0xb0640108,0x00000000,0x00000000}},	//   drôm, _isää, --, --, 
   {{0xf62461ff,0x0b04004b,0x47a800fe,0x00000000}},	//   едпо, _ټولټ, _গাখী, --, 
   {{0x69dc00af,0xab880023,0xe5a0010b,0xf42801f4}},	//   õpet, _ንበዓል_, лиьи, ksää_, 
   {{0xb7d40241,0x0a68041b,0xd7f80117,0x00000000}},	//   _aṣet, _црти_, _муд_, --, 
   {{0xc2e82158,0x38941d77,0x644c0334,0x69cc01e3}},	//   খিনি_, _hāro_, gnci, _öber, 
   {{0xe72c0577,0x629c0a73,0x42d4b4c7,0x38943da0}},	//   _се_, _ctqo, кіру, _kāro_, 
   {{0x200823db,0x644ca82c,0x682c00a3,0x38940055}},	//   _anci_, anci, _iùda, _jāro_, 
   {{0xafe44d0b,0x12d000bd,0x9f44012c,0xa25800d8}},	//   новл, িবেদ, ěný_, crôm, 
   {{0x6e2c0165,0x2084011c,0x00000000,0x00000000}},	//   _slbb, ейси_, --, --, 
   {{0xb8d0025c,0x15f0012c,0x33440014,0x2e440248}},	// [148a0] _ཐས_, _असार_, _سندِ, _nífè_, 
   {{0x2008ec8a,0x20040069,0x682c01ab,0xed5800f7}},	//   _enci_, ēnia_, _mùda, поз_, 
   {{0x61d430fb,0x682c00a3,0x63b801a8,0x8fc400c7}},	//   _אויף_, _lùda, ðung, _ианҵ, 
   {{0xdb182b76,0xa09800df,0x00000000,0x00000000}},	//   _acuñ, _מיטט, --, --, 
   {{0xeaf858c5,0xdb080109,0x00000000,0x00000000}},	//   ثرات_, gagà, --, --, 
   {{0x78ac0cf4,0x38940055,0x49040075,0x6e2c03ac}},	//   ćavn, _cāro_, күзг, _ulbb, 
   {{0x885877f7,0x38940055,0x7c28025c,0x2ef003cb}},	//   микс_, _dāro_, _ċerv, lwyf_, 
   {{0x683c0029,0x2e440241,0x2c7c0118,0x00000000}},	//   līdz, _fífè_, _půdu_, --, 
   {{0xc5f80029,0x682c00a3,0xf414015b,0xd6d400a8}},	//   klēt_, _cùda, াসার_, нтэ_, 
   {{0x682c01ab,0xe7e000c5,0xf4280108,0x00000000}},	//   _dùda, _कउवा_, ysää_, --, 
   {{0xdb0801ed,0x25a857fb,0x00000000,0x00000000}},	//   magá, يدگي_, --, --, 
   {{0xdb08ec8b,0x644c01af,0x682c00a3,0xc604009d}},	//   lagá, unci, _fùda, хзүй, 
   {{0x644c01a4,0x78640174,0x683c0153,0x00000000}},	//   rnci, róvt, jūdi, --, 
   {{0xf428005b,0x2ef00142,0xdb080332,0x853c0064}},	//   tsää_, dwyf_, nagá, lbėm, 
   {{0x7afc08a5,0x92586ed2,0x00000000,0x00000000}},	//   _ástv, харт_, --, --, 
   {{0x786400d0,0xdb0801e7,0xd4680114,0x00000000}},	//   lóvr, hagá, _пије_, --, 
   {{0xe7e0ec8c,0x427400d1,0xc2740b3e,0xf1f4158b}},	// [148b0] क्या_, _игис, _илиј, رکیش_, 
   {{0x713c0020,0xa6e003b2,0xf4280108,0x00000000}},	//   _አትሌቶ, _æðus, psää_, --, 
   {{0x0ca8010a,0xdb080332,0x6fb803ce,0xc2e401a9}},	//   етчи_, dagá, ेलखं, _чўқи, 
   {{0x683c0024,0x65680332,0x3894002b,0x98a4012d}},	//   būdi, _myfh, _sāro_, cznę_, 
   {{0xec109fcb,0x00000000,0x00000000,0x00000000}},	//   شوود, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9a680020,0x47a8015b,0x26c001d3,0x00000000}},	//   ስለኛል_, _গাজী, ákon_, --, 
   {{0x682c00a3,0xc5f800e2,0x00000000,0x00000000}},	//   _pùda, klēs_, --, --, 
   {{0x8b880c75,0x2fb4010f,0x38940055,0x00000000}},	//   _كەمە_, כּים_, _tāro_, --, 
   {{0x853c0024,0xd1e40023,0x6724d142,0x00000000}},	//   mbėj, ምቆት_, økja, --, 
   {{0x853c02d5,0x98a40210,0x00000000,0x00000000}},	//   lbėj, yznę_, --, --, 
   {{0x7ae80472,0xa258002d,0xb9cc0b82,0x6734012d}},	//   _kpet, nsôf, _ዳስ_, _żyje, 
   {{0x386c51bb,0x00000000,0x00000000,0x00000000}},	//   mler_, --, --, --, 
   {{0x7ae8ec8d,0x668000dd,0x9ad001f2,0x7afcec8e}},	//   _mpet, _پیپل, lịsi, _ástu, 
   {{0x25b400b2,0x386cec8f,0x2164448f,0x55f00116}},	//   _شهيد_, oler_, вири_, _ачқу, 
   {{0x386cec90,0x7ae8049b,0x70e0ec91,0x78a00076}},	//   nler_, _opet, _पहील, _mtlv, 
   {{0xa0647939,0x7ae81529,0x63b8008c,0x8e08010b}},	// [148c0] тата_, _npet, ðune, нмаң_, 
   {{0x386cec92,0xdee025f1,0x6da4006c,0x683c0024}},	//   hler_, рофи, тижа, rūdi, 
   {{0x386c2ba3,0xf8a47500,0x853c0024,0x9cb0007b}},	//   kler_, _دک_, ybėm, لملت, 
   {{0x386c1474,0x683c0006,0x628806af,0x8eb40145}},	//   jler_, pūdi, _égor, _مەرت, 
   {{0x386cec93,0x7c28038f,0x7ae80077,0xfb1801d3}},	//   dler_, _ċert, _cpet, فروں_, 
   {{0x386cec94,0x787402d5,0xadb863d8,0x3eac036e}},	//   eler_, _išvy, _زهرا_, _çeta_, 
   {{0x386cec95,0x7ae8ec96,0x61e003ee,0xac980214}},	//   fler_, _epet, _önle, _آنرا_, 
   {{0xc6f8d328,0x386cec97,0xe78431fd,0xad9800a2}},	//   ених_, gler_, купо, _baºg, 
   {{0xdb08ec98,0xe9d8468b,0x6a842be5,0xab641220}},	//   pagá, _ока_, _алаа, _рвал, 
   {{0x2bdc01ad,0x69242de8,0x00000000,0x00000000}},	//   फ्रा, _имза, --, --, 
   {{0x386c17f9,0xd7ecec99,0x48c40724,0x75c814d4}},	//   bler_, _ку_, _сәла, хтың_, 
   {{0x7ae80c8c,0x386cec9a,0x65680af9,0x853c0024}},	//   _ypet, cler_, _vyfh, lbėk, 
   {{0x27e4ec9b,0x5344ec9c,0xb9cc02d3,0x7afc03b2}},	//   _ibon_, ахра, _ዳት_, _ástt, 
   {{0xb7d40248,0xd8400419,0x84c401af,0x00000000}},	//   _iṣat, _tečú_, _йәмд, --, 
   {{0x6f040857,0x00000000,0x00000000,0x00000000}},	//   _arkc, --, --, --, 
   {{0xceb411a9,0xb7d40882,0x853c0024,0x00000000}},	//   yyət_, _kṣat, ybėj, --, 
   {{0x27e4ec9d,0x7f5801c0,0x2ec00137,0x3ebc0036}},	// [148d0] _mbon_, хаас_, йөрм, éwt_, 
   {{0xe7e007f8,0x27e41730,0x386cec9e,0x0e343334}},	//   क्ता_, _lbon_, zler_, аную, 
   {{0x7ae8ec9f,0x386c0365,0x27e400d5,0x6f0403ac}},	//   _spet, yler_, _obon_, _erkc, 
   {{0xd5e00084,0xb7d40055,0x00000000,0x00000000}},	//   _riṋ, _oṣat, --, --, 
   {{0xbae402dd,0x386ceca0,0xa258002d,0x39e803c5}},	//   اكتي, vler_, rsôf, едло_, 
   {{0x386ceca1,0x27e4eca2,0x853c0006,0x7ae80219}},	//   wler_, _abon_, rbėj, _vpet, 
   {{0x386ceca3,0xb7d40241,0xed4c0014,0x7e64014f}},	//   tler_, _aṣat, _ٹھل_, mohp, 
   {{0xe70031d9,0x1bb82352,0x386cbcf6,0xf770872b}},	//   _ཙནྡན_, _زارع_, uler_, یاک_, 
   {{0x386ceca4,0x3b54eca5,0x7ae8eca6,0x291800cc}},	//   rler_, _скар, _upet, øpar_, 
   {{0x386ceca7,0x27e40086,0x6680036b,0x00000000}},	//   sler_, _ebon_, مینل, --, 
   {{0xc3281229,0x3484eca8,0xb7d40055,0x70e00456}},	//   _צו_, лгог, _eṣat, _पहेल, 
   {{0xf2a4eca9,0x27e40248,0x7e64016d,0xe7e0012c}},	//   лимп, _gbon_, hohp, क्दा_, 
   {{0xe2940ec6,0xbec40882,0xe1880092,0xa2e002e8}},	//   лая_, _śūny, ኒስቴሩ_, бояд, 
   {{0x42545c9e,0xe5a00229,0xbf0c012d,0x00000000}},	//   атст, _лиши, समैन_, --, 
   {{0xdb08007c,0x4094a654,0x00000000,0x00000000}},	//   lagä, иртт, --, --, 
   {{0xdb0c00ee,0xa0640c5c,0x490407b6,0x00000000}},	//   _şeýd, гаса_, वितो_, --, 
   {{0x31c40050,0xfaf80055,0xaf040500,0xdb08010b}},	// [148e0] _یتھُ, _nsū_, ыпал, nagä, 
   {{0xa3780254,0x9f800166,0x00000000,0x00000000}},	//   meõp, сгуд, --, --, 
   {{0x2bc8ab8e,0xdee0036b,0x6cd4484d,0xa3780037}},	//   елеп_, _қори, اقصا, leõp, 
   {{0xeab8ecaa,0xeb98ecab,0x00000000,0x00000000}},	//   ейд_, хид_, --, --, 
   {{0x4af805b0,0x682c00a3,0x7c6401b9,0xa378000d}},	//   телю_, _dùdl, جالل, neõp, 
   {{0x24480100,0x27e403cb,0x26c01de4,0xa9c46ea9}},	//   _kòmè_, _sbon_, ákom_, ازشو, 
   {{0xdca067f0,0x1d040116,0xed580354,0x26c0031c}},	//   _гаси, _йери_, _чов_, ġkom_, 
   {{0x26c004b9,0x27e4208d,0x3ce4007c,0xdb08013d}},	//   škom_, _qbon_, _älva_, fagä, 
   {{0xa9a4bd75,0xda6c0d83,0x60080139,0x00000000}},	//   _бизд, _کُل_, _hömä, --, 
   {{0x6008145e,0x27e4208d,0x9f480022,0x00000000}},	//   _kömä, _wbon_, _pacú_, --, 
   {{0x7afc01a8,0x00000000,0x00000000,0x00000000}},	//   _ástr, --, --, --, 
   {{0xd7f44a4e,0x68f8ecac,0x7178001f,0xe7383529}},	//   _буш_, _istd, _በስፋት_, _пее_, 
   {{0x051403f4,0x12c4036b,0xadf4190c,0x00000000}},	//   ানের_, йёрг, ीयान_, --, 
   {{0x9f4800c6,0x65f000db,0x6b5c0153,0x1c0806e3}},	//   _tacú_, _اۋدئ, _išgą, _सोनल_, 
   {{0x43440092,0x6008009d,0x6d4800d7,0x00000000}},	//   _ከንቲባ, нхаг_, úfal, --, 
   {{0x7e640455,0xdb08007c,0x00000000,0x00000000}},	//   wohp, lagå, --, --, 
   {{0xdb040579,0xf2c001c0,0x69c402b5,0x7e64003e}},	// [148f0] _íløg, _мөри, _ēken, tohp, 
   {{0x44382508,0x68f84431,0x00000000,0x00000000}},	//   lhs_, _ostd, --, --, 
   {{0x60080166,0x8de87bca,0x043c0055,0x00000000}},	//   _cömä, ыфта_, _śeṣi, --, 
   {{0x4438180f,0x69d8ecad,0x8d844f41,0xbed400f0}},	//   nhs_, _acte, сууд, _комј, 
   {{0x26c0071b,0x389402b1,0x69d80334,0x3d9402bf}},	//   škoj_, _iāri_, _bcte, _вигр, 
   {{0x3ea88590,0x44380472,0xab24050b,0x389400b8}},	//   mpat_, hhs_, роша_, _hāri_, 
   {{0x3ea8ecae,0x38940374,0x69dc067c,0xdb0826cc}},	//   lpat_, _kāri_, òpea, dagå, 
   {{0x68f80175,0x69d8b4b7,0x36c4927f,0xe7a4011c}},	//   _dstd, _ecte, абиг, авъл_, 
   {{0x7d04074d,0x0514015b,0x68f802d0,0x3ea8003e}},	//   lvhs, ানোর_, _estd, npat_, 
   {{0x3ea8847c,0x46f000d1,0xdb0801e3,0x00000000}},	//   ipat_, سۋىر, gagå, --, 
   {{0x3ea80649,0x24580024,0x197000db,0x795002f2}},	//   hpat_, kšmę_, _اپاڭ, _گێژا, 
   {{0x4438ecaf,0x3ea8ecb0,0x07d8ecb1,0x05543c85}},	//   ghs_, kpat_, _مذهب_, стья, 
   {{0x63b80008,0x18b0ecb2,0x737401c6,0xd72000cc}},	//   ðuna, _тәһр, рынх, _বেৰা_, 
   {{0x3ea804fb,0xc5e82b1b,0xa3780254,0x7aec025c}},	//   dpat_, _কোঠা_, reõp, ħath, 
   {{0x443801c3,0x389400de,0xa3780037,0x00000000}},	//   bhs_, _bāri_, seõp, --, 
   {{0xc4c400cf,0x00000000,0x00000000,0x00000000}},	//   _اتوو, --, --, --, 
   {{0x2d941188,0xd37000d1,0x00000000,0x00000000}},	// [14900] арес, _رۇس_, --, --, 
   {{0x35dc0927,0xa2b8008f,0x00000000,0x00000000}},	//   _माफ़, _שמיט, --, --, 
   {{0x3ea822d0,0x649c00b0,0xa258002d,0xafe401d5}},	//   apat_, _kīia, trôv, _конл, 
   {{0xc0d402d3,0x26c001d3,0x7c380042,0xa098010f}},	//   ይኖም_, ákok_, ghwr, _שיכט, 
   {{0x69d80205,0x3ea8013a,0x00000000,0x00000000}},	//   _pcte, cpat_, --, --, 
   {{0xce34249f,0x600800fd,0x00000000,0x00000000}},	//   _اوسک, _tömä, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x48143b2e,0xdd8c0116,0x7c380cea,0x00000000}},	//   смис, _زوق_, chwr, --, 
   {{0xe7e00d0d,0xea8800f7,0xdb0801e3,0x577c0092}},	//   क्षा_, _абал_, tagå, _የታክሲ_, 
   {{0xc61402f5,0x00000000,0x00000000,0x00000000}},	//   িস্থ_, --, --, --, 
   {{0xd82cecb3,0x2a7c014b,0x4438ecb4,0xdb080158}},	//   _дэ_, _ihtb_, ths_, ragå, 
   {{0x66e4d5fa,0xe784ecb5,0xa6c8ecb6,0xe7e0443a}},	//   _вода, _куло, _алда_, क्शा_, 
   {{0xa6940f5c,0x4438ecb7,0xc5940120,0x00000000}},	//   _треј, rhs_, _лилј, --, 
   {{0x7aec00d8,0xe7e0095f,0xd5440451,0xc2e800cc}},	//   çati, क्रा_, _ھليو_, খিলি_, 
   {{0x3894005f,0xd25802bf,0x4438ecb8,0xdfd8074d}},	//   _pāri_, рця_, phs_, къа_, 
   {{0x3ea8ecb9,0x6ec005dc,0x00000000,0x00000000}},	//   tpat_, _लिखु, --, --, 
   {{0x3ea8ecba,0x06f8033f,0xe8b40327,0x38946991}},	// [14910] upat_, ्टिव_, _ནསའག, _vāri_, 
   {{0x3ea80af5,0x8e14311b,0xdb1801e7,0x00000000}},	//   rpat_, одуц, _nduá, --, 
   {{0x7c38ecbb,0x8d680261,0x50c80139,0xf1b0011a}},	//   thwr, ајца_, _кыям_, _מסי_, 
   {{0x3ea8ecbc,0xaca801d3,0x06ac00fe,0xaba80220}},	//   ppat_, اپنے_, _খিনি, _ﺷﯩﺮﻋ, 
   {{0x3ea80357,0x682c08c2,0xd9dc009e,0xdde001ee}},	//   qpat_, _iùdh, _যোগম, _мәжү, 
   {{0x44c40248,0x50b8036b,0x387c0142,0xaaf000d1}},	//   _ajọṣ, _حدید_, _shwr_, سكىغ, 
   {{0xd90c2e07,0x26187f90,0xdc88023b,0x29080162}},	//   بیا_, बानी_, _асал_, _ábal_, 
   {{0x8ccca05b,0xec180116,0xe7e02ac3,0x00000000}},	//   _हितो, _йесә_, क्ला_, --, 
   {{0x1dc80cb3,0xdb0804d4,0x2e34032e,0xd76400db}},	//   ाणपत, hagú, _hæfa_, جەشى_, 
   {{0x63b8008c,0x9964084c,0x2e34032e,0x00000000}},	//   ðunn, _ктел, _kæfa_, --, 
   {{0x81cc00eb,0x46e8009d,0x00000000,0x00000000}},	//   রভা_, гдөн_, --, --, 
   {{0x3a24000f,0x7414015b,0x00000000,0x00000000}},	//   _holp_, াস্ট_, --, --, 
   {{0xd3484bf3,0x3a24025c,0x686401d3,0xd76000f2}},	//   شیده_, _kolp_, _اپنے, _بنشی, 
   {{0x21a000d1,0x00000000,0x00000000,0x00000000}},	//   зирм, --, --, --, 
   {{0x41a8012c,0x00000000,0x00000000,0x00000000}},	//   _कभरस, --, --, --, 
   {{0x35dc00e1,0x00000000,0x00000000,0x00000000}},	//   _माड़, --, --, --, 
   {{0xdb08002d,0x6d940736,0x714000db,0x00000000}},	// [14920] ragû, مشائ, زۉڭۅ, --, 
   {{0xc1d4104e,0xada400d7,0x2d94022e,0x00000000}},	//   _мөсә, krúž, срас, --, 
   {{0xb7f81a3e,0x38940055,0x2bc800db,0x1da4012d}},	//   ्याम_, _kāru_, гуло_, गड़त, 
   {{0xad98010e,0xfcb40108,0x853c00c0,0x00000000}},	//   _daºa, ющую, mbėt, --, 
   {{0x853c02d5,0x2004013f,0x7f1802dd,0x389400ef}},	//   lbėt, ɛni_, _кіру_, _māru_, 
   {{0x3a240721,0x5f7401e2,0x00000000,0x00000000}},	//   _colp_, _داپر, --, --, 
   {{0x3a24269e,0xe8e801a9,0x2e34032e,0x4bc401c6}},	//   _dolp_, ارتو_, _gæfa_, _дөлг, 
   {{0x4734ecbd,0x06800ae5,0x00000000,0x00000000}},	//   жнис, ﺮﯨﻨﯩ, --, --, 
   {{0x26c0ecbe,0x69d815f8,0x00000000,0x00000000}},	//   éko_, _مباح_, --, --, 
   {{0x3a2464c4,0x26c809a8,0x1ae00064,0x7afc0142}},	//   _golp_, čbo_, _хофм, _âsta, 
   {{0x38940171,0x00000000,0x00000000,0x00000000}},	//   _bāru_, --, --, --, 
   {{0x3894002b,0x00000000,0x00000000,0x00000000}},	//   _cāru_, --, --, --, 
   {{0xb8649cba,0x3894002b,0x63ac0010,0x00000000}},	//   _بالو, _dāru_, rbcn, --, 
   {{0x9f4801ed,0x00000000,0x00000000,0x00000000}},	//   ámít_, --, --, --, 
   {{0x644cecbf,0x00000000,0x00000000,0x00000000}},	//   ébis, --, --, --, 
   {{0x25bcecc0,0x3eac0139,0x00000000,0x00000000}},	//   latl_, _çetk_, --, --, 
   {{0xe3bcecc1,0x637c0241,0x200400bc,0x00000000}},	// [14930] mañ_, _dàní, ěni_, --, 
   {{0xe3bc0dd4,0xdce80030,0x2004033f,0x25bc0112}},	//   lañ_, žiči, śni_, natl_, 
   {{0xd74002d3,0xe0f0031c,0xdb040248,0x00000000}},	//   _ንድሕነ, _བགྲད_, _àmús, --, 
   {{0xe3bcecc2,0xa2580109,0x637c01e1,0x6284002d}},	//   nañ_, prôs, _gàní, lmjo, 
   {{0x644c0393,0xe3bc0489,0x4fc400db,0x00000000}},	//   iici, iañ_, _رەلە, --, 
   {{0x644cecc3,0xe3bcecc4,0x7a3c068c,0x7c2c0267}},	//   hici, hañ_, _mètg, öarb, 
   {{0x644c3142,0xe3bcecc5,0x3a24ecc6,0x7a3c07c5}},	//   kici, kañ_, _volp_, _lètg, 
   {{0x644cecc7,0xe3bcecc8,0xfaa80592,0x3c580139}},	//   jici, jañ_, _نهري_, _тибэ_, 
   {{0x7bc8ecc9,0xe3bc0dd4,0xba5403b7,0x3a240010}},	//   _ideu, dañ_, _двај, _tolp_, 
   {{0x3a2407c5,0x7aececca,0xe3bc0165,0x74e80114}},	//   _uolp_, çatu, eañ_, адог_, 
   {{0x644c26c2,0xe3bceccb,0x389400de,0x7aec025c}},	//   fici, fañ_, _pāru_, ħatu, 
   {{0x644ceccc,0xe3bc03bd,0x9f480798,0xdb0403b2}},	//   gici, gañ_, _jacó_, _ílóg, 
   {{0x23d807d0,0x38688bbb,0xdb200108,0x389400ef}},	//   _भारद, čard_, _äräh, _vāru_, 
   {{0x7a3c05d5,0x25bceccd,0x637c01e1,0x644cecce}},	//   _dètg, catl_, _sàní, aici, 
   {{0x7bc807ea,0xd348006c,0xe3bceccf,0x26c000d0}},	//   _odeu, شیگه_, bañ_, ákov_, 
   {{0x7bc8ecd0,0x068024ae,0x68ec013d,0xe3bc0055}},	//   _ndeu, ﺮﯨﻠﯩ, _äbde, cañ_, 
   {{0x26c0389c,0xef18ecd1,0xee3005d9,0x321c01f4}},	// [14940] škov_, шма_, وٽر_, ötys_, 
   {{0x672405ac,0x00000000,0x00000000,0x00000000}},	//   økji, --, --, --, 
   {{0x3b0c0784,0xaba81ec7,0x9f4800db,0x7a3c0100}},	//   _areq_, لهام_, _bacó_, _mètd, 
   {{0x2aa86145,0x00000000,0x00000000,0x00000000}},	//   атко_, --, --, --, 
   {{0x7bc800a9,0x0d640014,0x00000000,0x00000000}},	//   _ddeu, _کۯاپ, --, --, 
   {{0xe3bc07e4,0x7bc80098,0xa8a4e91f,0x3b0c0240}},	//   zañ_, _edeu, орик, _dreq_, 
   {{0x644cecd2,0xe3bcecd3,0xca5001ec,0x00000000}},	//   yici, yañ_, _ﺎﮭﺘ_, --, 
   {{0x9f48011f,0xab280139,0x25bc0784,0xe3bcecd4}},	//   _gacó_, _коба_, watl_, xañ_, 
   {{0xe3bc03bd,0xa258000f,0x389400de,0x3b0c0200}},	//   vañ_, dsôn, _bārs_, _greq_, 
   {{0x644c068f,0xe3bc0086,0x7a3c04cc,0x7bc801d5}},	//   wici, wañ_, _rètg, _zdeu, 
   {{0xe3bcecd5,0x644ceb56,0x7a3c068c,0xd7300137}},	//   tañ_, tici, _sètg, здөө, 
   {{0xfa3401ec,0xdb0803b2,0x00000000,0x00000000}},	//   _ورەد, tagø, --, --, 
   {{0x67546568,0xe3bcecd6,0xb86407d6,0x26180358}},	//   _بخار, rañ_, _عامو, बादी_, 
   {{0x38680989,0xe3bcecd7,0xe46808a5,0x3eac010e}},	//   čare_, sañ_, _blöð_, _çeti_, 
   {{0x644cecd8,0x59dc0b68,0x69c0ecd9,0x6284045f}},	//   pici, प्टर, _रजनी, rmjo, 
   {{0xe3bc0bc9,0x26c00122,0xd0181606,0x644cecda}},	//   qañ_, škou_, офу_, qici, 
   {{0xdd9853fe,0x4428123c,0x9f4800f7,0xdce40210}},	// [14950] аше_, _ioa_, _racó_, _myją, 
   {{0x4428ecdb,0x9f4809d7,0x8ccc0073,0x00000000}},	//   _hoa_, _sacó_, _हिशो, --, 
   {{0x4428ecdc,0x8d7442b5,0xba740046,0xe46808a5}},	//   _koa_, واما, ۋاتت, _glöð_, 
   {{0x8ccc0acd,0x7a3c0214,0x1c082ce1,0x06800131}},	//   _हिरो, _mète, _सोशल_, ﺮﯨﻤﯩ, 
   {{0x4428ecdd,0x3b082c08,0x3f980356,0xe81c012d}},	//   _moa_, село_, _igsu_, भाना_, 
   {{0x4428ecde,0x52d8008f,0x00000000,0x00000000}},	//   _loa_, קווע_, --, --, 
   {{0x4428ecdf,0x5d3001d3,0x8d7401d3,0x00000000}},	//   _ooa_, _تہائ, _ہاہا, --, 
   {{0x4428ece0,0x59d43eaf,0x3b0c020b,0x7bc8ece1}},	//   _noa_, _ठाकर, _treq_, _udeu, 
   {{0x389400ef,0x291801e3,0x00000000,0x00000000}},	//   _pārs_, äpar_, --, --, 
   {{0x7c28ece2,0x4428ece3,0x3eb80730,0xd1f8044e}},	//   _hoer, _aoa_, _mwst_, ፈታት_, 
   {{0x7c28ece4,0x81c000cc,0x00000000,0x00000000}},	//   _koer, ঁলা_, --, --, 
   {{0x442836ed,0x7c28ece5,0x00000000,0x00000000}},	//   _coa_, _joer, --, --, 
   {{0x4428ece6,0x386cece7,0xad9800a2,0xa800002e}},	//   _doa_, moer_, _baºl, ññew, 
   {{0x386cece8,0x2494034c,0x44280295,0x7c28ece9}},	//   loer_, _کنيد_, _eoa_, _loer, 
   {{0x4428ecea,0x3eb800a9,0xe7e004af,0x942400cf}},	//   _foa_, _awst_, क्का_, _يوتۇ, 
   {{0x386ceceb,0x7c28ecec,0x60206d5f,0x4428045a}},	//   noer_, _noer, ндса, _goa_, 
   {{0xa03012b7,0xee382461,0x6ab8000d,0x00000000}},	// [14960] رىكت, бна_, _उबेर, --, 
   {{0x386c7c8c,0x9f4801ed,0x00000000,0x00000000}},	//   hoer_, ámát_, --, --, 
   {{0x7c28eced,0x4428ecee,0x386cecef,0xb7d400b8}},	//   _boer, _yoa_, koer_, _eṣit, 
   {{0x386c193f,0x7c28ecf0,0x442801fb,0x00000000}},	//   joer_, _coer, _xoa_, --, 
   {{0x386cecf1,0xa1100214,0x7f5801af,0x80b000cc}},	//   doer_, _قویت, _дјрт_, _জয়প্, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x386c0036,0x26c4ecf2,0x261800bc,0x29180124}},	//   foer_, _svoo_, बासी_, ãpa_, 
   {{0x7aec025c,0x00000000,0x00000000,0x00000000}},	//   ħatr, --, --, --, 
   {{0x4428ecf3,0x7a3c02bd,0x6994010a,0x56380240}},	//   _roa_, _sète, _ерех, _ስለዝጠ, 
   {{0xba28ecf4,0x4428ecf5,0xdce40034,0x61340793}},	//   _وسلم_, _soa_, _wyją, nülö, 
   {{0x386cecf6,0xa90821ec,0x7c2801f5,0xdcec0e04}},	//   boer_, _ديال_, _yoer, čeće, 
   {{0xd9180a1e,0x7a3c0100,0x261813f7,0x2c7c00bc}},	//   _לובל, _vète, बाही_, _půdy_, 
   {{0x4428ecf7,0x26d0bb68,0xd05000ac,0x613401d3}},	//   _voa_, _íyo_, _ödəy, külö, 
   {{0x4428ecf8,0x26c002d5,0xa01805d5,0x672406ea}},	//   _woa_, škos_, _chön, økju, 
   {{0x4428ecf9,0xae080316,0x00000000,0x00000000}},	//   _toa_, _होइन_, --, --, 
   {{0xdef4001f,0xdef8516c,0xd72003d4,0x645c0200}},	//   _ዋነኛ_, йыз_, _বেয়া_, _ujqi, 
   {{0x7c28ecfa,0xd010c67c,0x613401b8,0x920800e2}},	// [14970] _roer, ھلے_, fülö, _brāļ, 
   {{0x7c280793,0xd3580302,0x937800c6,0x46d4012c}},	//   _soer, _משחק_, _عصير_, _दिनह, 
   {{0x7c28ecfb,0x00000000,0x00000000,0x00000000}},	//   _poer, --, --, --, 
   {{0x6294ecfc,0x629cecfd,0x317c0e78,0xfb54ecfe}},	//   _hixo, _kuqo, ütze_, وپاد, 
   {{0x7c287890,0x386cecff,0x6294ed00,0x63bc0477}},	//   _voer, voer_, _kixo, _meqn, 
   {{0xae080574,0x7c28ed01,0x629c358d,0x6294ed02}},	//   _होऊन_, _woer, _muqo, _jixo, 
   {{0x7c28ed03,0x386ced04,0xbca400b2,0x9c440962}},	//   _toer, toer_, _آمري, _ехал, 
   {{0x77f8185b,0x6294ed05,0x7a3c0100,0x00000000}},	//   ्येक_, _lixo, _bètc, --, 
   {{0x386ced06,0xd5e40135,0x629c014f,0xdb20e9b1}},	//   roer_, _འཁྱག, _nuqo, äräl, 
   {{0x60c40158,0x386c0142,0x00000000,0x00000000}},	//   ksjm, soer_, --, --, 
   {{0x386ced07,0xa018002f,0xb92400ae,0x00000000}},	//   poer_, _rhön, _تفضي, --, 
   {{0x629400db,0x629c022e,0xae0813f7,0x00000000}},	//   _aixo, _buqo, _होईन_, --, 
   {{0x6294ed08,0x2618ad78,0x26c0009b,0xa0181196}},	//   _bixo, बाशी_, škor_, _phön, 
   {{0x629c6895,0xdb080bcd,0xd5e4031c,0x068400c0}},	//   _duqo, lagó, _འཁྲག, _згін, 
   {{0xafe400d6,0x261800ce,0x76400142,0x00000000}},	//   мовл, बारी_, mhly, --, 
   {{0x6294660f,0x629c01a9,0xdb08ed09,0x00000000}},	//   _eixo, _fuqo, nagó, --, 
   {{0xd1380006,0xa01807c5,0xae080073,0xe81c0950}},	// [14980] šą_, _thön, _होउन_, भाता_, 
   {{0x6294005a,0x7c2c0267,0xdb0837b5,0xae781cb8}},	//   _gixo, öarn, hagó, ісах_, 
   {{0x62181a4c,0x613401d3,0x708401f0,0x00000000}},	//   _וויק, rülö, _огоз, --, 
   {{0x629c006c,0x9408013f,0x62940944,0x3e7c011c}},	//   _yuqo, _kunɑ_, _zixo, bìto_, 
   {{0xdb08ed0a,0xaa440c9e,0xb5d4009e,0xf1c00010}},	//   dagó, медл, ত্যচ, pušč_, 
   {{0x6294ed0b,0x6d481427,0x00000000,0x00000000}},	//   _xixo, úfas, --, --, 
   {{0xd1c0044e,0x6b4401a9,0x00000000,0x00000000}},	//   _ኵናት_, _mаgi, --, --, 
   {{0xec141a59,0xeb340a52,0x683c00de,0xdb080162}},	//   _تورد, _قىزد, lūdz, gagó, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x38681326,0x78680213,0x7640e6d5,0x44b400cf}},	//   čara_, _rövş, ghly, нбос, 
   {{0x629c014f,0x61e00790,0x00000000,0x00000000}},	//   _suqo, _önli, --, --, 
   {{0x62941cdf,0xb86400c6,0x629c0477,0x63bc014f}},	//   _sixo, _كانو, _puqo, _qeqn, 
   {{0x629c022e,0x12e402dd,0xb0600166,0x00000000}},	//   _quqo, кірг, _çäyl, --, 
   {{0x7640ed0c,0xdb0801b8,0x00000000,0x00000000}},	//   chly, vagü, --, --, 
   {{0xa3e40acd,0x62940005,0x63bc0477,0x629c0009}},	//   _पाप_, _vixo, _teqn, _wuqo, 
   {{0x7a3c3040,0x629c0455,0xa2d404af,0x00000000}},	//   _mèta, _tuqo, _बिप्, --, 
   {{0xe2a806f6,0x83540050,0xbed82e01,0x6294ed0d}},	// [14990] _بابن_, _سپدا, ядах_, _tixo, 
   {{0x4438ed0e,0x8d740131,0xdb08ed0f,0x629402d0}},	//   lks_, ھالا, ragü, _uixo, 
   {{0x4438ed10,0x7a3c02e2,0xdb080077,0x7bf8cbbc}},	//   oks_, _nèta, sagü, знер_, 
   {{0x44380c18,0x8d847bb3,0xdb08ed11,0x93fc00df}},	//   nks_, тууд, dagò, ַלוי, 
   {{0xa3e405ba,0x4438ed12,0xfb345225,0x4ea4ed13}},	//   _पान_, iks_, эндэ, _арса, 
   {{0xd338025f,0x7a3c007f,0xa2d41b61,0xf98421e9}},	//   ורדה_, _bèta, _बिन्, нгло, 
   {{0xdb080491,0x4438ed14,0x88c41884,0x098801d5}},	//   tagó, kks_, پتىل, машқ_, 
   {{0x44380936,0x682c00a3,0xca74036b,0x23d80ebb}},	//   jks_, _sùdr, _یالغ, _भागद, 
   {{0x9f480122,0x4438020c,0x98a48327,0x76407799}},	//   _obcí_, dks_, dyną_, thly, 
   {{0x4438ed15,0x8af8ed16,0xbae00150,0x00000000}},	//   eks_, _юнус_, _ﺍﻻﺳﺎ, --, 
   {{0xa0181196,0x3ae80419,0x00000000,0x00000000}},	//   _diöz, lúp_, --, --, 
   {{0x7640ed17,0x6b8801c7,0x977004b4,0x00000000}},	//   shly, _ëmgé, _итлә, --, 
   {{0x73340131,0x78a0ed18,0x7640015d,0x00000000}},	//   رىسا, _hulv, phly, --, 
   {{0x4438ed19,0x78a0128b,0xdce4012d,0x645c0ca8}},	//   aks_, _kulv, _wyję, _ìpin, 
   {{0x78a0004e,0x32083c02,0x44380fac,0x2b440165}},	//   _julv, rdby_, bks_, zzoc_, 
   {{0x4438ed1a,0xa3e40490,0x3ae80aa6,0xe12000c7}},	//   cks_, _पाय_, kúp_, ымси, 
   {{0xdfcc2781,0x8d74001f,0x2e3401a8,0xdb08007f}},	// [149a0] صيل_, _እሳቸው_, _hæfi_, zagò, 
   {{0xb82402f5,0x5f000022,0x00000000,0x00000000}},	//   বসিত_, ызуа, --, --, 
   {{0xdcac1c5c,0x78a0005c,0xa3e407af,0xaad0000d}},	//   مىل_, _nulv, _पाम_, _सिहक, 
   {{0xdd8c9717,0x09c853c3,0x7e7401e4,0x683c005f}},	//   حوم_, रण्य, _ekzp, sūdz, 
   {{0x824803e6,0xdca00032,0x7a3c033b,0x2b440165}},	//   _رشیف_, _ҡари, _sèta, uzoc_, 
   {{0x78a0ed1b,0x7a3c00db,0x6f0405c7,0xdb08381a}},	//   _bulv, _pèta, _iskc, tagò, 
   {{0x78a0ed1c,0x4438ed1d,0xa2d400cd,0x9e6000f3}},	//   _culv, yks_, _बिभ्, _сврд, 
   {{0x4814ed1e,0x68e80175,0x98d42309,0x188492fe}},	//   тмис, rtfd, ربىز_, нсып_, 
   {{0x6e2ced1f,0x7a3c00f2,0xa3bc0d0d,0x69f0ed20}},	//   _kobb, _wèta, इरस_, _бүлт, 
   {{0x6e2ced21,0x4438ed22,0x78a0ed23,0x7a3c0100}},	//   _jobb, wks_, _fulv, _tèta, 
   {{0x78a017c1,0xdb0801a8,0xd7ec0354,0x98a4bfb6}},	//   _gulv, lagð, _йу_, tyną_, 
   {{0xf8aca3a9,0x00000000,0x00000000,0x00000000}},	//   _بکو_, --, --, --, 
   {{0xa3e44d53,0x27e4ed24,0xe73000ec,0xe45c007c}},	//   _पाठ_, _icon_, _حصا_, rnö_, 
   {{0x4438ed25,0x85240597,0x6e2ced26,0x17180302}},	//   sks_, _ᶰᵉʷ_, _nobb, _מודע, 
   {{0x443801fa,0x2e34032e,0xa65002f2,0x00000000}},	//   pks_, _gæfi_, _لێکت, --, 
   {{0xd6f000fe,0x00000000,0x00000000,0x00000000}},	//   জিৰা_, --, --, --, 
   {{0x6e2ced27,0x63b81f60,0x7f94009d,0x00000000}},	// [149b0] _bobb, ðunu, таах, --, 
   {{0x6e2ced28,0x074c0150,0x00000000,0x00000000}},	//   _cobb, _ﺍﻳﯟ_, --, --, 
   {{0x6608ed29,0x27e4ed2a,0x1318036b,0x7ae8036e}},	//   _mafk, _ocon_, _قتیغ_, _sqet, 
   {{0x78a001e4,0xfff804fb,0xa25800d0,0x660801f4}},	//   _rulv, _تکست_, jrôz, _lafk, 
   {{0x78a0ed2b,0x2008003a,0x6ea4035b,0x6e2c01f4}},	//   _sulv, _iaci_, _аусҧ, _fobb, 
   {{0x78a0ed2c,0x6e2ced2d,0x66085101,0x27e40072}},	//   _pulv, _gobb, _nafk, _acon_, 
   {{0x20089497,0x78a00455,0xa964b15a,0xcdc800db}},	//   _kaci_, _qulv, киша_, _سۇنۇ_, 
   {{0x78a0ed2e,0xe81ced2f,0x200808ad,0x66084fa5}},	//   _vulv, भाषा_, _jaci_, _aafk, 
   {{0x2008ed30,0x7ae819a2,0x6e2c0694,0x00000000}},	//   _maci_, _uqet, _yobb, --, 
   {{0x660823db,0x78a0ed31,0x39900165,0x6e2ced32}},	//   _cafk, _tulv, _t͡s_, _xobb, 
   {{0x6608002e,0x20080561,0xa68001c0,0x2c140073}},	//   _dafk, _oaci_, рлэд, णाचं_, 
   {{0x200805a1,0x27e40332,0x645c0241,0x00000000}},	//   _naci_, _gcon_, _ìpil, --, 
   {{0xe72ced33,0x3360001f,0x00000000,0x00000000}},	//   _те_, ተካሄደ_, --, --, 
   {{0xe2942b41,0xe5a0ed34,0x7a3ced35,0xf678008f}},	//   кая_, _киши, _mèto, _קאַמ, 
   {{0xe294ed36,0x2008ed37,0x85340133,0x00000000}},	//   тар_, _baci_, _مووچ, --, 
   {{0x6e2ced38,0x2008ed39,0x00000000,0x00000000}},	//   _sobb, _caci_, --, --, 
   {{0x2008ed3a,0x6da4ed3b,0x6608011f,0xa3e40acd}},	// [149c0] _daci_, виза, _yafk, _पात_, 
   {{0x2008031c,0x3c8408b0,0x6d94ed3c,0x6e2c014f}},	//   _eaci_, ﺭﯨﺸﻰ_, نشائ, _qobb, 
   {{0x2008ed3d,0xfaf800b0,0xd7b00073,0x6e2c01e3}},	//   _faci_, _apū_, ीराच, _vobb, 
   {{0x6e2ced3e,0x200803f9,0x7a3c0100,0x92e40154}},	//   _wobb, _gaci_, _bèto, নবী_, 
   {{0x6e2ced3f,0x27e401e7,0x7d1401d3,0xea880066}},	//   _tobb, _rcon_, _erzs, وختن_, 
   {{0x200802a8,0xdb0801a8,0x60c80958,0x98a40153}},	//   _zaci_, ragð, _ämmä, lynę_, 
   {{0x98c04077,0x20080b45,0xe81c4142,0x3e880139}},	//   асыл, _yaci_, भाला_, _чирү_, 
   {{0x6608ed40,0x2008013d,0x00000000,0x00000000}},	//   _safk, _xaci_, --, --, 
   {{0x66080115,0xeb98ed41,0xb8c800c5,0x27e40334}},	//   _pafk, _циа_, _गू_, _vcon_, 
   {{0x66080009,0x98d400cf,0x00000000,0x00000000}},	//   _qafk, ربۉز_, --, --, 
   {{0xda6c0014,0xa3e407d0,0xd570035b,0xa3bc09ab}},	//   _بُل_, _पाद_, иуџь, इरल_, 
   {{0x6608014b,0xdce801fa,0xf2940241,0xa2d41b90}},	//   _wafk, žići, _isẹ́_, _बिद्, 
   {{0x66080c09,0x2e3402d2,0x403401b9,0x98a400c0}},	//   _tafk, _hæfu_, қеас, dynę_, 
   {{0x3c840952,0x2008ed42,0x6608005c,0x7dd801e1}},	//   ﺭﯨﺴﻰ_, _saci_, _uafk, _mùsà, 
   {{0x2008ed43,0x6008009d,0x63b81427,0x00000000}},	//   _paci_, мхаг_, ðuns, --, 
   {{0x261804fa,0xaad002ab,0x8ccc00bc,0x54440228}},	//   बाकी_, _सिंक, _हिजो, _ۅنۉك, 
   {{0x4ea4ed44,0x7a3c32aa,0x2008ed45,0x0d380092}},	// [149d0] арха, _bètl, _vaci_, _በሚፈል, 
   {{0x4dd419b6,0x20080a63,0x7a3c00cf,0xf2d800df}},	//   لتمس, _waci_, _rèto, _אַטל, 
   {{0x2008ed46,0x3cd46582,0x7a3c02e2,0x42540066}},	//   _taci_, ужес, _sèto, _لنکر, 
   {{0x48c000cc,0x98a40210,0x00000000,0x00000000}},	//   _এমূৰ, cynę_, --, --, 
   {{0x25ac0fac,0x00000000,0x00000000,0x00000000}},	//   _offl_, --, --, --, 
   {{0xdb040ca8,0x00000000,0x00000000,0x00000000}},	//   _òmír, --, --, --, 
   {{0x3ea8022e,0x00000000,0x00000000,0x00000000}},	//   lqat_, --, --, --, 
   {{0x3ea8013c,0x81b80183,0x1c0800c5,0xdb0802d2}},	//   oqat_, ঙণি_, _सोचल_, dagö, 
   {{0x68f802d0,0x59b00166,0xc8240022,0x00000000}},	//   _eptd, _көйс, рзық, --, 
   {{0x9a8489f1,0x06b803ff,0x9a94010a,0x00000000}},	//   _рубл, کنیک_, _шăпл, --, 
   {{0x2e34032e,0xdb086ae3,0x3afc01e1,0x00000000}},	//   _gæfu_, gagö, bápò_, --, 
   {{0xc2080d65,0xb9cc0020,0x0684ed47,0xb808007b}},	//   _מה_, _ኳስ_, лгөн, _سيتم_, 
   {{0xdb080158,0x2e3400b5,0x21640c60,0xe60c01c6}},	//   bbgå, _kæft_, ҳири_, _лд_, 
   {{0x3ea80548,0x86440006,0x00000000,0x00000000}},	//   dqat_, _кніж, --, --, 
   {{0x2164ed48,0x7a3c007f,0x6ff40354,0x92e40154}},	//   гири_, _nètm, лчах, নবে_, 
   {{0xfcf00020,0x3ea854a0,0x04940024,0x73e401f4}},	//   _ፍለጋ_, fqat_, _крыў, _соиз, 
   {{0x332411a9,0xee14009d,0x98a40210,0xa0646bb6}},	// [149e0] _çox_, льжэ, rynę_, уата_, 
   {{0x536c0201,0x6398011a,0xdd8c00ec,0x00000000}},	//   ተያየት_, _אספנ, ڳون_, --, 
   {{0xafe40166,0x8eb400f7,0x98a40064,0x00000000}},	//   _йонл, _چەرت, pynę_, --, 
   {{0xdd8ced49,0x46d4000d,0x00000000,0x00000000}},	//   سون_, _दिलह, --, --, 
   {{0xa3e44103,0xa09800c8,0x00000000,0x00000000}},	//   _पास_, _ריכט, --, --, 
   {{0xa2d4000b,0xfd9800d1,0x00000000,0x00000000}},	//   _बिस्, رئەت_, --, --, 
   {{0x38c4010b,0x35dc01ad,0x321c0108,0x9c14013d}},	//   ашың, _माज़, ötyy_, _өчтә, 
   {{0xc6f8504f,0x7b0800fd,0x9d1805d0,0x00000000}},	//   вних_, äptä, _אולט, --, 
   {{0xab64ed4a,0xe5c401c6,0x00000000,0x00000000}},	//   _свал, лсно, --, --, 
   {{0x45d406ed,0x44f4c3cb,0x00000000,0x00000000}},	//   јонс, апос, --, --, 
   {{0x69c8ed4b,0x9e740302,0x92e400eb,0x00000000}},	//   mafe, רגיה_, নবো_, --, 
   {{0x69c8ed4c,0x2b98046c,0x4394ed4d,0xa84004d3}},	//   lafe, _gücü_, ианс, _دکتۆ, 
   {{0x54543b2b,0xdb080793,0x98a400bc,0x9778010a}},	//   свят, sagö, kyně_, _пушă_, 
   {{0x69c8ed4e,0xaf08015b,0xa3e452f2,0x3ea86064}},	//   nafe, রমাণ_, _पाव_, vqat_, 
   {{0xbe0401ed,0x403401e0,0x3ea80135,0x98a401ef}},	//   یورٹ, аевс, wqat_, dyně_, 
   {{0x69c8ed4f,0x9f4400bc,0x83f800f3,0x00000000}},	//   hafe, řní_, _реис_, --, 
   {{0x69c8ed50,0x3ed40372,0x7a3c02e2,0xa018007c}},	// [149f0] kafe, شقار, _sètm, _ohöv, 
   {{0x44fc031c,0x92b4007b,0x69c8ed51,0x3ea8ed52}},	//   _ྐྱོར_, _احيا, jafe, rqat_, 
   {{0x69c8ed53,0xe7e8012c,0x50c801ee,0x329800df}},	//   dafe, _टाढा_, _йыям_, _שבתד, 
   {{0xf42802f6,0x38680010,0x751400df,0xc5f800ef}},	//   mpää_, čark_, יַנע_, dnēm_, 
   {{0x34c0712e,0x3ea8ed54,0xf2180dad,0x69c80b45}},	//   _शब्द, qqat_, _फोड़_, fafe, 
   {{0x50b8ed55,0xc0d0001f,0x61e40007,0xdb080109}},	//   _جدید_, ጥጥር_, ngjl, dagô, 
   {{0xf428ed56,0x00000000,0x00000000,0x00000000}},	//   npää_, --, --, --, 
   {{0xf4280108,0x00000000,0x00000000,0x00000000}},	//   ipää_, --, --, --, 
   {{0x99d4ed57,0x69c86578,0xf7706520,0xa2d4012c}},	//   _متضا, bafe, غاب_, _बिष्, 
   {{0xe6142405,0x69c8ed58,0x68f001bf,0x996401af}},	//   адь_, cafe, øjdæ, _йтел, 
   {{0xb7d4ed59,0xb464ed5a,0x26186225,0xc32806a9}},	//   _نقاب, икол, बाजी_, _קו_, 
   {{0xa2d40316,0x00000000,0x00000000,0x00000000}},	//   _बिश्, --, --, --, 
   {{0xa3e41889,0x0ec400e1,0x00000000,0x00000000}},	//   _पार_, _लौंड, --, --, 
   {{0xa2d44108,0x63801fe2,0x95c811e5,0xb144036b}},	//   _बिर्, ігра, _чуда_, англ, 
   {{0x733400f4,0x425402bf,0x63b80113,0x00000000}},	//   _چىعا, стят, ñunc, --, 
   {{0xe0403afa,0x92e4009e,0x69c8ed5b,0x30040798}},	//   онси, _ননী_, zafe, јзаг, 
   {{0x69c8ed5c,0x649c00b0,0xdfcc12fc,0x26180073}},	// [14a00] yafe, _kūin, بيق_, बाची_, 
   {{0x69c8004e,0x389400b8,0x00000000,0x00000000}},	//   xafe, _vāry_, --, --, 
   {{0xece8010a,0x98a40118,0x61d8011a,0x836402f2}},	//   тдел_, ryně_, _בקיד, _ندیل, 
   {{0x69c8ed5d,0x6fa80f4a,0x15c80150,0x00000000}},	//   wafe, _कलिं, _ﻓﻘﻴﻬ, --, 
   {{0x69c8ed5e,0xac9407dd,0x6da4ed5f,0x1be401a9}},	//   tafe, гаҧш, _вига, рдчи_, 
   {{0xda6007d6,0xc5f800e2,0x00000000,0x00000000}},	//   овчи, tnēm_, --, --, 
   {{0x69c8ed60,0xa3e408e9,0x28680063,0xec780114}},	//   rafe, _पाल_, крио_, _апв_, 
   {{0xa2d41fe5,0x69c8ed61,0xdca0ed62,0x2d880030}},	//   _बिल्, safe, _фати, _izbe_, 
   {{0xe78402bf,0x2ef0002d,0xf1c411a6,0x69c8ed63}},	//   шуко, ntyf_, वरान, pafe, 
   {{0x648c030a,0xf428005b,0x7c2c0821,0x00000000}},	//   oùig, ypää_, öarv, --, 
   {{0x09b43ee1,0xa80400a7,0x00000000,0x00000000}},	//   ुरीय, _взел, --, --, 
   {{0x2ef00a85,0x068000d1,0xf8a83918,0x00000000}},	//   ktyf_, ﺮﯨﻜﯩ, _صدمه_, --, 
   {{0x7a3c0ba1,0x48c40166,0x5c94010f,0x7e640051}},	//   _bèth, _тәһа, יכטע_, ynhp, 
   {{0x81c002f5,0xf6640075,0x92686f5a,0xe4a403c5}},	//   ুলভ_, _лечү, арса_, _крио, 
   {{0xd138ed64,0xa2a4033f,0xb9f00023,0x2f3c0171}},	//   ахт_, _टूर्, _ሓድ_, _lāgā_, 
   {{0xf42801f4,0x00000000,0x00000000,0x00000000}},	//   rpää_, --, --, --, 
   {{0xfbdc009e,0x2f3c002b,0xf42801f4,0xcf980798}},	// [14a10] ণ্ডত, _nāgā_, spää_, ајф_, 
   {{0x38681326,0x74bced65,0x7a3c0066,0xf42802f6}},	//   čari_, वीकृ, _gèth, ppää_, 
   {{0x2ef0045f,0xe7a401ad,0x00000000,0x00000000}},	//   atyf_, _ऑलंप, --, --, 
   {{0xa0185f3e,0x7a3c007f,0x00000000,0x00000000}},	//   _chöt, _tètk, --, --, 
   {{0xfaa4005b,0xaab4210e,0x00000000,0x00000000}},	//   щало, مگلر_, --, --, 
   {{0x26140ebb,0xdb180200,0x539c00d9,0x3d940108}},	//   _भोली_, _leuç, דידו, _гигр, 
   {{0x9c0800c7,0xa3e41d94,0x9be4003b,0x00000000}},	//   _ихаз_, _पां_, _візк, --, 
   {{0xe8f42401,0x00000000,0x00000000,0x00000000}},	//   ёлы_, --, --, --, 
   {{0x649c00b0,0x39a00014,0xa2a402a0,0xa3e8000d}},	//   _pūin, _ٹیبہ, _टूल्, मलन_, 
   {{0x7bc80098,0xb8cc03d4,0xca4800f1,0xf508009d}},	//   _heeu, _কব_, _پلمه_, гнол_, 
   {{0x7bc8003e,0x39142a77,0x704c01e1,0xc9840114}},	//   _keeu, _دواز, _líjọ, _дуци, 
   {{0x7bc8003e,0xb9dc0092,0x85340014,0x00000000}},	//   _jeeu, _ጥላ_, زوُچ, --, 
   {{0x7bc869d0,0x649c02b1,0x79808b89,0xe69001d5}},	//   _meeu, _tūin, _hylw, تلید, 
   {{0x7bc8ed66,0xdb200022,0x672403cd,0xd5b80114}},	//   _leeu, _ãrõh, åkje, _рсд_, 
   {{0x6140ed67,0xf8c400fe,0x00000000,0x00000000}},	//   пера, _এমুঠ, --, --, 
   {{0x7bc8004c,0x6f1400d0,0x76400139,0x00000000}},	//   _neeu, tvyc, lkly, --, 
   {{0xef18ed68,0xa80000e8,0x00000000,0x00000000}},	// [14a20] ыма_, ññiw, --, --, 
   {{0x7a3c0100,0xfe700ed1,0x2d940a8f,0x7640072b}},	//   _fèti, ۋدە_, брес, nkly, 
   {{0xfca8004b,0x81c801c0,0x00000000,0x00000000}},	//   لانو_, _өгөв_, --, --, 
   {{0x09e0202e,0xf1ec00c5,0x0bf400d4,0x00000000}},	//   नल्य, _जाड़_, іплю, --, 
   {{0x764003cd,0xa2c8076e,0x7ed40816,0x463c0092}},	//   kkly, तीप्, _мірч, _ይፈጠራ, 
   {{0x8a1800d8,0xfaa40150,0x00000000,0x00000000}},	//   рокс_, ішін, --, --, 
   {{0x7bc800ad,0x2918ed69,0x7640007c,0xaa6000db}},	//   _feeu, ípa_, dkly, _ۉچتۉ, 
   {{0xdd8ced6a,0x7bc801f5,0xec7807e6,0x798003cb}},	//   _سوق_, _geeu, _спб_, _dylw, 
   {{0x17f4007b,0x00000000,0x00000000,0x00000000}},	//   صرية_, --, --, --, 
   {{0x7bc8ed6b,0x649c02b5,0xba0800db,0xaa8800f2}},	//   _zeeu, _pūio, _ۅتۅك_, _صنام_, 
   {{0x1a64ed6c,0x00000000,0x00000000,0x00000000}},	//   _دیوی_, --, --, --, 
   {{0x7a3c1f3f,0x66e4c9fd,0xf6f401d9,0x00000000}},	//   _bètw, _года, _ژٲنگ, --, 
   {{0x7a3ced6d,0xd874009a,0xc48400db,0x00000000}},	//   _sèti, _امنت_, йлүк, --, 
   {{0x76407ae4,0x7afced6e,0x7a3c007f,0xc0d40092}},	//   ckly, _äste, _pèti, ርገህ_, 
   {{0xd258160b,0xc104027d,0x00000000,0x00000000}},	//   сця_, غوري, --, --, 
   {{0x7a3c02e2,0x93140014,0x96bc02a0,0x00000000}},	//   _vèti, _کوٝش, लीकॉ, --, 
   {{0x7bc8ed6f,0xe45c2f12,0x648c00a3,0x00000000}},	// [14a30] _reeu, miö_, rùid, --, 
   {{0xbfec01f2,0x7bc8ed70,0x7a3c007f,0xe45c023a}},	//   _ṅụọ_, _seeu, _tèti, liö_, 
   {{0x4034ed71,0x11f8104c,0x92b40101,0x00000000}},	//   _денс, _اوپک_, _وحیا, --, 
   {{0xd1b80405,0x69dc00e4,0xabcc0220,0x00000000}},	//   _پایا_, ópen, _ﻗﯩﺮﻋ, --, 
   {{0x7980b687,0xa3e41533,0xba743baf,0x764000ee}},	//   _sylw, _पाई_, ياتت, ykly, 
   {{0x7bc8009a,0x463c001f,0xb8b40114,0xe45c01f4}},	//   _weeu, _ይፈጥራ, осић, hiö_, 
   {{0x26c4013f,0x7bc801a4,0xe45c0108,0x00000000}},	//   _awoo_, _teeu, kiö_, --, 
   {{0xe8f402d5,0x00000000,0x00000000,0x00000000}},	//   ілы_, --, --, --, 
   {{0x7980015d,0xdb200108,0x00000000,0x00000000}},	//   _wylw, öräm, --, --, 
   {{0xe81c0574,0x8f9c008f,0xe6900691,0x7640017a}},	//   _मोठा_, ניזי, وليد, ukly, 
   {{0x26c4063f,0x13a8ed72,0x7640a9cc,0x81c00154}},	//   _ewoo_, ینگی_, rkly, ুলা_, 
   {{0x7640ed73,0x01e0015b,0x00000000,0x00000000}},	//   skly, ম্মদ, --, --, 
   {{0x26c4063f,0x684002d5,0x00000000,0x00000000}},	//   _gwoo_, _інша, --, --, 
   {{0x38682220,0x15a802e8,0x4d8402dd,0x00000000}},	//   čaru_, _съди_, _ﺩﺍﯞﯨ, --, 
   {{0x21a005bc,0x3eb8002d,0x4ae00037,0xdbc400a2}},	//   дирм, _atst_, _निभव, _söýu, 
   {{0xa3e406bc,0xaec4119e,0x15c80150,0x00000000}},	//   _पाए_, жбал, _ﻓﺘﻅﻬ, --, 
   {{0x2ca8ed74,0x3eb8007f,0x5f140243,0xd1240014}},	// [14a40] _subd_, _ctst_, निष्_, زکھى, 
   {{0x2254157c,0x01e000cc,0xdcac2374,0x00000000}},	//   _وليد_, ম্বদ, چىل_, --, 
   {{0xe7e805f9,0x8b080118,0x00000000,0x00000000}},	//   _टाला_, kuřá, --, --, 
   {{0x7a3c0268,0x09b40b7c,0x00000000,0x00000000}},	//   _mètu, ुर्य, --, --, 
   {{0xb60409a8,0x3eb801a4,0xa0180267,0xdca000f3}},	//   _kršč, _gtst_, _thör, фаци, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa92801ec,0xf3e000fe,0xe5d002dd,0x00000000}},	//   ріле_, গ্যৰ_, _ﻛﯘﻟﻜ, --, 
   {{0x4734147e,0x3eb800cc,0xe7e80073,0x00000000}},	//   знис, _ytst_, _टाळा_, --, 
   {{0xe45c0108,0x00000000,0x00000000,0x00000000}},	//   viö_, --, --, --, 
   {{0x1f58010f,0x00000000,0x00000000,0x00000000}},	//   ידפא, --, --, --, 
   {{0xa9082834,0xe45c02f6,0x798c0b45,0x69d802d0}},	//   _خيال_, tiö_, ƙawa, _idte, 
   {{0x26c46c69,0x80b01098,0xd8140212,0xc4e401ec}},	//   _twoo_, _आंबे, _моєї_, ожүй, 
   {{0x649c00b0,0xe45ced75,0x86b81e2f,0xdc980a7c}},	//   _hūik, riö_, _اُتر_, ייטל, 
   {{0xa3e456e9,0x649c0069,0x4614e750,0xf22000e1}},	//   _पाक_, _kūik, _روبر, माग़_, 
   {{0xa2d40918,0x15b00075,0x00000000,0x00000000}},	//   _बिक्, _تەپس, --, --, 
   {{0x1ea805d9,0x291c0784,0xca3800df,0xdef80022}},	//   لائي_, _mrta_, _loĝ_, иыз_, 
   {{0xdda847bf,0x69d88bb3,0xd250004b,0x644c00a3}},	// [14a50] ател_, _odte, رنې_, mhci, 
   {{0x291ced76,0x80f46830,0xb6040427,0x9fbc02f0}},	//   _orta_, _епох, _gršč, mčík_, 
   {{0x62842ce2,0xdb040077,0x527400db,0x9fbc0306}},	//   mljo, _ámús, _تايز, lčík_, 
   {{0x69d8ed77,0x7a3c0268,0x644c0399,0x00000000}},	//   _adte, _lètt, nhci, --, 
   {{0x69d800e4,0x644c0369,0x9fbc0306,0xabd001d9}},	//   _bdte, ihci, nčík_, رٲوت, 
   {{0x62840158,0xfc7c0118,0x00000000,0x00000000}},	//   nljo, _žádá_, --, --, 
   {{0xa3e809d9,0x291c05ce,0x69d800b5,0xa9a03946}},	//   मला_, _crta_, _ddte, нишд, 
   {{0xbc680014,0xff400092,0x00000000,0x00000000}},	//   _امرن_, _የመስመ, --, --, 
   {{0x291ced78,0x0c040014,0x4b240131,0xa2d400bc}},	//   _erta_, _زولُ, _يېمە, _बिग्, 
   {{0xdbc80086,0x7a3c0066,0x3a240789,0x1dc800dc}},	//   mòñi, _pètu, _unlp_, िरित, 
   {{0x06780116,0x00000000,0x00000000,0x00000000}},	//   ﻧﻮﻣﯩ, --, --, --, 
   {{0x644c00ae,0xe7946103,0x00000000,0x00000000}},	//   ghci, _کامک, --, --, 
   {{0x38b009f3,0x1dc8090a,0x20d4025c,0x68ec0139}},	//   _hár_, िरात, eħi_, _äbdr, 
   {{0xe734013e,0x38b001d3,0x00000000,0x00000000}},	//   _хеш_, _kár_, --, --, 
   {{0x20d4038f,0x38b001ed,0xb604009b,0xdecc0023}},	//   għi_, _jár_, _vršč, _ኣባኻ_, 
   {{0x38b000f8,0x2164275b,0x628480c3,0x644c033f}},	//   _már_, чиси_, aljo, chci, 
   {{0x38b00597,0x62847b11,0x00000000,0x00000000}},	// [14a60] _lár_, bljo, --, --, 
   {{0x7a3c007f,0x1f601171,0x00000000,0x00000000}},	//   _mèts, хкум, --, --, 
   {{0x38b00597,0x2d8c00cc,0x9c800010,0x3208007c}},	//   _nár_, åfe_, _ščav, meby_, 
   {{0xeb98ed79,0x30a00131,0x69d80175,0x00000000}},	//   бие_, _ﺋﺎﻣﯧ, _sdte, --, 
   {{0x291ced7a,0x511c00c5,0xa064009d,0x00000000}},	//   _srta_, _पछुआ_, _хаяа_, --, 
   {{0x38b000dd,0xee38ed7b,0x3208007c,0x00000000}},	//   _bár_, _унг_, neby_, --, 
   {{0x38b01463,0x99d00244,0xb91000cd,0xa2800023}},	//   _cár_, رتوا, _khaṃ_, _ሓጥኣን_, 
   {{0x291c1a48,0x38b000c6,0x7a3c020c,0x98a00640}},	//   _vrta_, _dár_, _sètt, није, 
   {{0x7a3c04cc,0x63b80784,0xc1680023,0x1ae000f3}},	//   _pètt, ñunm, _ደድሕሪ_, _потм, 
   {{0xaa840209,0x291c9a64,0xa9689c0b,0x9fbc0306}},	//   _diýý, _trta_, _лиза_, včík_, 
   {{0x291ced7c,0x38b0011f,0xdb200108,0x00000000}},	//   _urta_, _gár_, äröl, --, 
   {{0x09ac000d,0xa3e40456,0x00000000,0x00000000}},	//   _चलुय, _पाओ_, --, --, 
   {{0x6284ed7d,0x38b001d3,0xadfc0e49,0x798802dd}},	//   tljo, _zár_, ैजान_, _ﺯﺍﯕﻰ_, 
   {{0xb9100882,0x9fbc02fb,0xdbc402d2,0x00000000}},	//   _ahaṃ_, rčík_, _löðu, --, 
   {{0xd5f80302,0x6284ed7e,0xb91000b8,0x83f8004e}},	//   _הפור, rljo, _bhaṃ_, _дейс_, 
   {{0xd46830ba,0x9fbc02f0,0x20d4031c,0xd1300956}},	//   _није_, pčík_, rħi_, دمِ_, 
   {{0x4428ed7f,0x7a3ced80,0xa2d42017,0x649c00b0}},	// [14a70] _ina_, _mètr, _बिट्, _rūih, 
   {{0xdda8ed81,0x42540502,0x4428ed82,0xa3e80f44}},	//   стал_, _آندر, _hna_, मलव_, 
   {{0x649c02b5,0x317c0e78,0xdbc402d2,0x00000000}},	//   _pūih, ützt_, _böðu, --, 
   {{0x44280b91,0xa3bc05b5,0x00000000,0x00000000}},	//   _jna_, ेरि_, --, --, 
   {{0x4428ed83,0x38b021c2,0x93fc011a,0x4c94009d}},	//   _mna_, _sár_, מלאי, хицс, 
   {{0x38b05ced,0x442802c4,0x00000000,0x00000000}},	//   _pár_, _lna_, --, --, 
   {{0x4428ed84,0x7a3c0100,0xa3bc00e1,0xdbc401a8}},	//   _ona_, _bètr, ेरा_, _föðu, 
   {{0x4428ed85,0x38b0ed86,0x32080034,0xb9040490}},	//   _nna_, _vár_, zeby_, _भट_, 
   {{0x7c28ed87,0x61f805a1,0x291805ac,0x1b000139}},	//   _iner, đulj, åpar_, _чүлн, 
   {{0x4428ed88,0x645c0117,0x38b0ed89,0xa2d40316}},	//   _ana_, _amqi, _tár_, _बिज्, 
   {{0x4428ed8a,0x7c28ed8b,0x98c400f1,0x00000000}},	//   _bna_, _kner, _رغان, --, 
   {{0x31c4de66,0x2b500790,0x320802f0,0x00000000}},	//   वर्ध, _öncü_, weby_, --, 
   {{0x386ced8c,0x64b80135,0x4428ed8d,0x3208ed8e}},	//   mner_, _aċid, _dna_, teby_, 
   {{0x4428ed8f,0xb9f8069c,0x386ced90,0x645c014b}},	//   _ena_, _መን_, lner_, _emqi, 
   {{0x386c51dc,0x3208ed91,0x7c28ed92,0xa3e40574}},	//   oner_, reby_, _oner, _पाच_, 
   {{0x4428ed93,0xa2d40358,0x7c28ed94,0x3208ed95}},	//   _gna_, _बिच्, _nner, seby_, 
   {{0xa064584f,0xdbc408a5,0x69dc00e4,0x00000000}},	// [14a80] фата_, _röðu, ópek, --, 
   {{0x442804b9,0x7c28ed96,0x386ced97,0x00000000}},	//   _zna_, _aner, hner_, --, 
   {{0x44280cfd,0x7c28020b,0x386c0ec3,0xa2a40037}},	//   _yna_, _bner, kner_, _टूट्, 
   {{0xdd8ced98,0x44280109,0xa2c807b7,0xab841188}},	//   جوم_, _xna_, तीव्, мулк, 
   {{0x386c2307,0x649800df,0x00000000,0x00000000}},	//   dner_, קסנד, --, --, 
   {{0x386ced99,0xed58074d,0xa6e00008,0xedd40ccb}},	//   ener_, _дог_, _æðis, _زيرد, 
   {{0x7a3c020c,0x8eb00154,0x63b80309,0x9fbc02f0}},	//   _pètr, _ছবিগ, ñunk, lčák_, 
   {{0x386ced9a,0x7c28ed9b,0xbb5c037e,0xc31400eb}},	//   gner_, _gner, _dayコ_, ামতি_, 
   {{0xceb40213,0x9fbc02f0,0x68e8022e,0x00000000}},	//   nqə_, nčák_, sufd, --, 
   {{0x44287e9f,0xe81c00af,0xe7e80490,0x386c0d63}},	//   _sna_, _मोरा_, _टाका_, aner_, 
   {{0x62480793,0xd7eced9c,0x386ced9d,0x7a3c004e}},	//   _büon, _иу_, bner_, _tètr, 
   {{0x386ced9e,0x44280334,0x97c00153,0x00000000}},	//   cner_, _qna_, _айце, --, 
   {{0x4a0c1b4b,0x44287749,0x5b78010f,0x9fbc0419}},	//   _གྲོལ_, _vna_, ַרלא, jčák_, 
   {{0xaac400bc,0x442803cb,0x0f380092,0xabcc01ec}},	//   रीएक, _wna_, _አመራረ, _ﻗﯩﺰﻋ, 
   {{0x4428045a,0xb1940139,0x00000000,0x00000000}},	//   _tna_, елрә, --, --, 
   {{0x44f8ed9f,0x645c0921,0x4394eda0,0x661801bf}},	//   mé_, _umqi, _пайс, ldtk, 
   {{0x44f8eda1,0x7c28eda2,0x672000e4,0x5058001f}},	// [14a90] lé_, _rner, _jroj, _ሀገራች, 
   {{0x7c28eda3,0xb6a4001e,0x386c070a,0x6720eda4}},	//   _sner, _nhậ, zner_, _mroj, 
   {{0x44f8eda5,0xa2c80c00,0x4a0c031c,0x00000000}},	//   né_, तीर्, _གྲེལ_, --, 
   {{0x67205594,0xe81c02e5,0x00000000,0x00000000}},	//   _oroj, _मोला_, --, --, 
   {{0x386ceda6,0x44f8eda7,0x67200218,0xa92002dd}},	//   vner_, hé_, _nroj, ғдыл, 
   {{0x44f8eda8,0x387c0023,0xdb20036b,0x62480254}},	//   ké_, _ኣባላቱ_, _یوزی, _müoo, 
   {{0x386ceda9,0x6720edaa,0x7e640649,0xf8a811e6}},	//   tner_, _aroj, mihp, سگاه_, 
   {{0x67201326,0x44f8edab,0x7c28edac,0xbca400c6}},	//   _broj, dé_, _uner, _أمري, 
   {{0xebc018ce,0xb6a4084c,0x0c8400c7,0xefcc0023}},	//   _сәхн, ниил, _рырм, _ኣታዊ_, 
   {{0x44f8edad,0x7c9002d3,0x67203fea,0xceb403e3}},	//   fé_, _ዝባሃል_, _droj, dvəl_, 
   {{0x44f8edae,0x386c03cd,0x6720edaf,0xa3e800cd}},	//   gé_, pner_, _eroj, मलं_, 
   {{0xa01804f3,0x6720edb0,0x00000000,0x00000000}},	//   _skön, _froj, --, --, 
   {{0x6720edb1,0x64b8025c,0x482400cf,0xf1d0717e}},	//   _groj, _rċie, _جىنق, лөнө, 
   {{0x44f8edb2,0x00000000,0x00000000,0x00000000}},	//   bé_, --, --, --, 
   {{0x44f8edb3,0x25a8970b,0xc1740014,0xe5a0edb4}},	//   cé_, _عضوی_, ندِت, _йиши, 
   {{0x9870005f,0xb4bc012d,0x09ac190c,0x00000000}},	//   mžēl_, ेठी_, _चल्य, --, 
   {{0xdee00f32,0x660401d3,0x59dc01f9,0x00000000}},	// [14aa0] лоти, őkke, नणार, --, 
   {{0x2d9c00d0,0x9fbc0306,0x66e0012d,0x514401a9}},	//   _útek_, rčák_, _खिसक_, _адоғ, 
   {{0x09d800bd,0xad58009d,0x00000000,0x00000000}},	//   সলমা, чрах_, --, --, 
   {{0x32180022,0xeb98edb5,0x98a400c0,0x00000000}},	//   _hapy_, пие_, mynė_, --, 
   {{0xeb980323,0x44f8edb6,0x98a40006,0x2054010f}},	//   чид_, zé_, lynė_, _טיטל_, 
   {{0x44f8edb7,0xee38006c,0x67200240,0x00000000}},	//   yé_, _энг_, _rroj, --, 
   {{0x3218a3f5,0x44f8edb8,0x649c0374,0x7ea80024}},	//   _mapy_, xé_, _kūit, _užpa, 
   {{0x44f8edb9,0x9400013f,0xb6000cc3,0x00000000}},	//   vé_, _ohiɑ_, ñánd, --, 
   {{0xe664edba,0x44f8edbb,0xb6a401fb,0x2d8800d7}},	//   етно, wé_, _thậ, _hybe_, 
   {{0x44f8edbc,0x67200240,0xb864082a,0xe4e401ec}},	//   té_, _vroj, _یانو, німн, 
   {{0x44f8004a,0x15d401d3,0x00000000,0x00000000}},	//   ué_, رگوں_, --, --, 
   {{0x44f8edbd,0xefc0067d,0xe7e806ab,0xe7380b32}},	//   ré_, ትራዊ_, _टाटा_, _нее_, 
   {{0x44f8edbe,0x6720edbf,0xc2240214,0x06140006}},	//   sé_, _uroj, نکدو, _адлю, 
   {{0x44f8edc0,0x8bcc00af,0xae001100,0x00000000}},	//   pé_, ारुअ, र्मन_, --, 
   {{0x9400013f,0xf3f403e6,0x98a400c0,0x00000000}},	//   _ehiɑ_, رتێک, gynė_, --, 
   {{0x321800e4,0x3dcc0154,0x00000000,0x00000000}},	//   _eapy_, _লাইল, --, --, 
   {{0x3f1401d5,0x00000000,0x00000000,0x00000000}},	// [14ab0] ъдас, --, --, --, 
   {{0x4438049f,0xdd98edc1,0x3218010b,0xcfa400d1}},	//   ljs_, пше_, _gapy_, ушси, 
   {{0x63b80784,0x44dc01e4,0xbc180212,0x00000000}},	//   ñunw, nĉ_, ділі_, --, 
   {{0x5fa004a9,0x2d8800b5,0xae001f13,0xd9b803ce}},	//   _مەزم, _dybe_, र्बन_, ॉर्ट, 
   {{0x2d880455,0x38b00327,0x443801a4,0x7e640455}},	//   _eybe_, _iġri_, ijs_, pihp, 
   {{0xd2b802e4,0xab2400a7,0xc0380092,0x25ac0142}},	//   עלות_, тоша_, _አለበለ, _ngfl_, 
   {{0x5d48074d,0xd218011a,0x00000000,0x00000000}},	//   _хăйĕ, גקוק_, --, --, 
   {{0x3c74010f,0x0c8401af,0x61bc07b7,0x00000000}},	//   _סתּם_, _быум, ्रुष, --, 
   {{0x394811f9,0xd70404a9,0xc2200c2e,0xa3e801ad}},	//   ņas_, رىدۇ_, मयाब_, मलई_, 
   {{0xe9a416a0,0x8704edc2,0xa018c5e2,0xd00c03d4}},	//   رگەن_, ابيل, _sköl, ৱায়_, 
   {{0x5dd00046,0x00000000,0x00000000,0x00000000}},	//   _ﺟﯘﻣﺴ, --, --, --, 
   {{0x3d081a22,0x3218035b,0x00000000,0x00000000}},	//   _सहने_, _sapy_, --, --, 
   {{0x3218edc3,0xae0025fe,0x737401c6,0x87c000c7}},	//   _papy_, र्डन_, тынх, _уҩыз, 
   {{0x61f40393,0x146400c7,0xf504014b,0x66e001a9}},	//   _ccxl, _әеиҭ, _азко, _тоша, 
   {{0x32f4013f,0x00000000,0x00000000,0x00000000}},	//   _mɛyɛ_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2d88000f,0xdfcc00c6,0xa0a0edc4,0xa3b4000d}},	// [14ac0] _sybe_, زيل_, ратд, _जलत_, 
   {{0xaf0401e1,0xf2a4b27b,0x98a40064,0x00000000}},	//   _ajùú, _шипп, pynė_, --, 
   {{0x649c00b0,0x77780327,0xdee0084c,0x3084007b}},	//   _tūit, _lxwx, лоӂи, _للدف, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x32f4013b,0x2d88002d,0x0df00023,0xfca80ee8}},	//   _bɛyɛ_, _wybe_, _ሃጓፍ_, رامو_, 
   {{0x29840598,0xc4bc0eac,0x2d880200,0xddc00798}},	//   кыйг, _আয়োজ, _tybe_, _вбри, 
   {{0x9e602424,0xae0001ad,0xd9d00131,0x4cac00cc}},	//   _тврд, र्णन_, شەنگ, _চবকু, 
   {{0x4814edc5,0x00000000,0x00000000,0x00000000}},	//   умис, --, --, --, 
   {{0xae00228d,0xe5c41f99,0xdef00023,0x47c800f1}},	//   र्थन_, ксно, _ሃባን_, واکۍ_, 
   {{0xfd4c0ca8,0xcaa4001f,0x3d0800e1,0x49b401ec}},	//   _awoṣ, ገባኝም_, _सहमे_, _сәду, 
   {{0xe1f000dd,0xbd0400e8,0xa0180008,0xa3b4590f}},	//   یسس_, _iméé, _sköm, _जलद_, 
   {{0xae000cf1,0x442c07dd,0xa7640166,0x69c8002f}},	//   र्तन_, ñe_, _икед, lbfe, 
   {{0x32f40134,0xd614004b,0x00000000,0x00000000}},	//   _yɛyɛ_, رتیا_, --, --, 
   {{0x61bcedc6,0x06c82b1b,0x44380066,0xaf0803d4}},	//   ्रेष, _শিপি, sjs_, ৰমাণ_, 
   {{0x44389638,0xaf54001f,0x69c80112,0x765c036e}},	//   pjs_, _ለመለወ, ibfe, ësye, 
   {{0xc0c401e0,0x09d800eb,0x00000000,0x00000000}},	//   _ҡәби, _সাফা, --, --, 
   {{0x2d8c03fa,0xb04800cf,0x00000000,0x00000000}},	// [14ad0] üfen_, رككۅ_, --, --, 
   {{0x1d6846c9,0x8fa40063,0x00000000,0x00000000}},	//   وصاً_, рађе, --, --, 
   {{0xae0028a2,0xa3b409bb,0x47b800cc,0x2d8c031c}},	//   र्धन_, _जला_, _ইজনী, żfen_, 
   {{0x60c40ffb,0x3b5401df,0x40340150,0x00000000}},	//   mpjm, лкер, _семс, --, 
   {{0x32f4013f,0xc0f00023,0x00000000,0x00000000}},	//   _pɛyɛ_, _ውዒሉ_, --, --, 
   {{0xfe70edc7,0xae000358,0x00000000,0x00000000}},	//   _اگر_, र्दन_, --, --, 
   {{0xd90cedc8,0x08d402d5,0x00000000,0x00000000}},	//   تیا_, ацыя, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7bd8edc9,0x69c800e5,0x00000000,0x00000000}},	//   mawu, bbfe, --, --, 
   {{0x7bd8edca,0x99640348,0x95b00032,0x5ee80c6f}},	//   lawu, _ител, шриә, _चिन्_, 
   {{0xe81c130b,0x5fd00b02,0x00000000,0x00000000}},	//   _मोका_, तराल, --, --, 
   {{0x7bd8edcb,0x00000000,0x00000000,0x00000000}},	//   nawu, --, --, --, 
   {{0xe72cedcc,0x649c02b1,0xafe401d5,0xca9c0023}},	//   _уе_, _pūir, ғозл, ልለኩም_, 
   {{0x7bd82935,0x41a4de66,0xb46400d1,0x853400cf}},	//   hawu, _गृहस, _әкил, _چووچ, 
   {{0xe294edcd,0xafe4343e,0x70b40214,0x766401e2}},	//   уар_, ловл, امرض, _لیکې_, 
   {{0x3dcc00bd,0x64b80003,0x7bd82252,0x63b80784}},	//   _লাগল, _kċin, jawu, ñunt, 
   {{0x7fd40046,0x649c00b0,0x7afc0ade,0x7bd8edce}},	// [14ae0] рісі, _tūir, _ästh, dawu, 
   {{0xdb1805c7,0x09d8015b,0x6da44965,0xada42123}},	//   _neuñ, _সাভা, гиза, газл, 
   {{0xdd8c112d,0x2d94acb9,0x71681086,0x00000000}},	//   كوك_, урас, _чанг_, --, 
   {{0x7bd8edcf,0xabd42e67,0xa2c80bca,0xdca034cb}},	//   gawu, ازات, तीक्, бахи, 
   {{0x09d80154,0x6b640209,0xe81c0456,0x00000000}},	//   _সাবা, ыкда, _मोगा_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x64b80327,0xdb18030a,0x7bd8edd0,0xdecc02d3}},	//   _aċin, _deuñ, bawu, _ኣባና_, 
   {{0x06c800bd,0x6f140034,0x3d0808ec,0x00000000}},	//   _শিবি, owyc, _सहते_, --, 
   {{0x97a000fd,0xd6d400a8,0x4ab4013d,0xa018032e}},	//   йрьл, лтэ_, _төер, _skök, 
   {{0x6ac800bd,0x45d400f7,0x00000000,0x00000000}},	//   _রিপো, шоос, --, --, 
   {{0x26c00024,0x6f14012d,0x80a40073,0x00000000}},	//   ūko_, hwyc, _कळले, --, 
   {{0x6f140175,0x00000000,0x00000000,0x00000000}},	//   kwyc, --, --, --, 
   {{0x4e1405f9,0xf1c4013a,0x00000000,0x00000000}},	//   ड़ाई_, _čára_, --, --, 
   {{0xa5442ad5,0x7bd807a9,0xd624026a,0xe5c401c0}},	//   _مضبو, zawu, _боље_, _ёсло, 
   {{0x7bd8edd1,0x00000000,0x00000000,0x00000000}},	//   yawu, --, --, --, 
   {{0x7bd800e8,0x0fdc07f7,0xae001025,0x00000000}},	//   xawu, यणगढ, र्सन_, --, 
   {{0xe80453c3,0x7bd8edd2,0x947400f1,0x902800c7}},	// [14af0] व्या_, vawu, _ددوا, ыцра_, 
   {{0x7bd8edd3,0x539c02e4,0x00000000,0x00000000}},	//   wawu, _איחו, --, --, 
   {{0x7bd813c4,0x425497d1,0x6284edd4,0x00000000}},	//   tawu, _منکر, mojo, --, 
   {{0x3d043bca,0x21740022,0x2d94010a,0x00000000}},	//   _रहीं_, _ауҭр, ăрас, --, 
   {{0xcf9800f3,0xfc7c02d2,0x00000000,0x00000000}},	//   _бјр_, _þámá_, --, --, 
   {{0x6284262b,0x00000000,0x00000000,0x00000000}},	//   nojo, --, --, --, 
   {{0x7bd8edd5,0x393401c6,0x645c0064,0x00000000}},	//   pawu, рэлс, _įpin, --, 
   {{0x644c01a4,0x7bd801e2,0x628400e4,0x00000000}},	//   jkci, qawu, hojo, --, 
   {{0x6284edd6,0x00000000,0x00000000,0x00000000}},	//   kojo, --, --, --, 
   {{0x9a847c0c,0x672401a8,0x6284edd7,0x644cedd8}},	//   _субл, ækja, jojo, ekci, 
   {{0x34800075,0x391404d3,0x6284143f,0x6f140034}},	//   يۇتې, _خواز, dojo, zwyc, 
   {{0x38680267,0xeba8072b,0x656c0332,0x00000000}},	//   _öar_, _æøå_, úbha, --, 
   {{0xd6c02444,0x6284edd9,0xe81c7db3,0x00000000}},	//   _امتی, fojo, _मोटा_, --, 
   {{0x35a4edda,0x80b0033f,0x3d0400e1,0x6ac800eb}},	//   _калг, _आंखे, _रहूं_, _রিমো, 
   {{0x798c03f9,0xefd4001f,0x614000d8,0x00000000}},	//   ƙawu, _ይሄው_, оера, --, 
   {{0x6f140210,0x00000000,0x00000000,0x00000000}},	//   twyc, --, --, --, 
   {{0x6284d74c,0xee300451,0xef183ed6,0xe2e00153}},	// [14b00] bojo, يٽر_, ъма_, _джып, 
   {{0xe16402f2,0x628400ef,0x00000000,0x00000000}},	//   اڵیه_, cojo, --, --, 
   {{0xd6f00154,0x00000000,0x00000000,0x00000000}},	//   ড়িয়া_, --, --, --, 
   {{0xfe706923,0x00000000,0x00000000,0x00000000}},	//   يدە_, --, --, --, 
   {{0x2b14eddb,0xf1d805f9,0xfe9001b9,0x00000000}},	//   рьер, _बजान, _کیلج, --, 
   {{0x5ee80882,0x00000000,0x00000000,0x00000000}},	//   _चित्_, --, --, --, 
   {{0xbd88044e,0x09d8015b,0x00000000,0x00000000}},	//   _ንሳቶም_, _সাদা, --, --, 
   {{0x62840810,0x9d1805d0,0x48180108,0x00000000}},	//   zojo, _בולט, ужию_, --, 
   {{0xeaf820ad,0x7d08107d,0xd8a405d9,0x6d5c002f}},	//   _جرأت_, _ćesi, جهيو_, lzpa, 
   {{0x8654eddc,0xe5c406ed,0x2a685380,0x2d9c02f0}},	//   скох, јспо, _öbb_, _útes_, 
   {{0x62848529,0x6d5c0112,0xf1c401ef,0x00000000}},	//   vojo, nzpa, _čápa_, --, 
   {{0x7aeceddd,0xbb7000db,0x644c01a6,0x6284012d}},	//   šate, _بۇۇع, ukci, wojo, 
   {{0x6284edde,0x27e4b024,0x5344822f,0x644c00c0}},	//   tojo, _idon_, охра, rkci, 
   {{0x2284eddf,0x00000000,0x00000000,0x00000000}},	//   румг, --, --, --, 
   {{0x3d041533,0x6284ede0,0xd5acede1,0x5698011a}},	//   _रहें_, rojo, _фс_, _שיוצ, 
   {{0x5ee800dc,0x6d5c0171,0x00000000,0x00000000}},	//   _चिद्_, dzpa, --, --, 
   {{0x628495d8,0x503c001f,0x2fc0058a,0xff9800d8}},	// [14b10] pojo, _አገራች, _dfkg_, укај_, 
   {{0x7d0004f3,0x6284009a,0xc5f802b5,0x0e340212}},	//   _älsk, qojo, ngē_, оную, 
   {{0x8d74ede2,0xc0f80020,0x27e4ede3,0x127c008f}},	//   ياما, ገባም_, _odon_, _באזע, 
   {{0x26c4198f,0x823c00b7,0x9be40212,0x00000000}},	//   _otoo_, _ኢየሩሳ, ріжк, --, 
   {{0x26c40457,0xa2c80574,0x645c0153,0x4ee40024}},	//   _ntoo_, तीच्, _įpil, _мірз, 
   {{0x27e40b45,0x3eb80381,0x2008002f,0x00000000}},	//   _adon_, _iust_, _hbci_, --, 
   {{0x3eb8ede4,0x26c4198f,0x7f4c0009,0xcdc800d1}},	//   _hust_, _atoo_, lyaq, _ئۇمۇ_, 
   {{0x3eb8ede5,0x27e43167,0x00000000,0x00000000}},	//   _kust_, _cdon_, --, --, 
   {{0x3eb8025f,0x2d9c00db,0x3b54ede6,0xc86400c6}},	//   _just_, _úter_, _укар, تطوي, 
   {{0x3eb8ede7,0x27e4ede8,0xdaa00150,0x00000000}},	//   _must_, _edon_, _بەتپ, --, 
   {{0xb994ede9,0x20080232,0x3eb8edea,0xb4a802e8}},	//   _الاب, _obci_, _lust_, лкоз_, 
   {{0x7f4c0309,0x63b80784,0x87b80107,0x00000000}},	//   kyaq, ñunp, _кушт_, --, 
   {{0x3eb8edeb,0x95b005f5,0xe72c00ee,0xe7b006c2}},	//   _nust_, _мөнх, _эе_, _عمود, 
   {{0x7afc014a,0x42543db7,0xa7c401e0,0x7f4c06be}},	//   _ästu, отст, _крәҫ, dyaq, 
   {{0x3eb80183,0x2008edec,0x386c0b4f,0xceb403b9}},	//   _aust_, _bbci_, oier_, hvət_, 
   {{0x3eb80408,0xa06407ee,0x503c001f,0x7a3c0100}},	//   _bust_, баса_, _አገሮች, _vèty, 
   {{0x3eb8eded,0x7f4c0369,0x3eb0009d,0xe4540677}},	// [14b20] _cust_, gyaq, _bizt_, _ליקט_, 
   {{0x386cedee,0x3eb8771c,0x1fa40022,0x00000000}},	//   hier_, _dust_, скуи_, --, 
   {{0x386cedef,0xece80835,0x00000000,0x00000000}},	//   kier_, удел_, --, --, 
   {{0xaae40491,0x3eb8edf0,0xa01801e6,0x386c0b21}},	//   مستو, _fust_, _sköv, jier_, 
   {{0x386c665b,0x6d5c0034,0xfb1800e5,0x00000000}},	//   dier_, szpa, لروں_, --, 
   {{0x09d82f8b,0x386cedf1,0xfe44030f,0x48c401e0}},	//   _সাহা, eier_, _وکلی, ошиғ, 
   {{0x386cedf2,0x26c41368,0x5e5400c8,0xed58074d}},	//   fier_, _stoo_, _פילע_, _сов_, 
   {{0x3eb0005a,0xa3780254,0x00000000,0x00000000}},	//   _zizt_, rgõz, --, --, 
   {{0x2bcc05ba,0xdca0edf3,0x2ca445a7,0x468407d6}},	//   _ह्या, _хати, mmod_, оқда, 
   {{0x59cc2d6b,0x386c32e2,0x2ca4863d,0xa01801a8}},	//   _स्पर, aier_, lmod_, _gjöf, 
   {{0x69d8edf4,0x4614a320,0x386cedf5,0xe4a4009d}},	//   _iete, موکر, bier_, йрмо, 
   {{0x69d8edf6,0x386cedf7,0x7f4cedf8,0xdc340139}},	//   _hete, cier_, yyaq, _mäğq, 
   {{0x69d8edf9,0x26c403a0,0xd18c0092,0x00000000}},	//   _kete, _utoo_, _መስፈን_, --, 
   {{0x3eb83b08,0x69d8edfa,0x291c0112,0x178001c4}},	//   _rust_, _jete, _ksta_, _эгчм, 
   {{0xf608edfb,0x3eb8edfc,0x7ea80006,0xf4e40022}},	//   _ختنه_, _sust_, _užpi, _дсыҟ, 
   {{0x69d8edfd,0x3eb8edfe,0x25ec0073,0x00000000}},	//   _lete, _pust_, _आयडी_, --, 
   {{0x2ca41c06,0x69d8edff,0xeeb80075,0x2284ee00}},	// [14b30] dmod_, _oete, иктә_, _гунг, 
   {{0x291cee01,0x386cee02,0x7f4c0986,0xd3580375}},	//   _osta_, zier_, ryaq, _לשחק_, 
   {{0x386c03a2,0x9378ad7b,0x7f4c0784,0x55b800df}},	//   yier_, _نصیر_, syaq, אמבו, 
   {{0x3eb8ee03,0x69d80483,0xbb540137,0xa01836d5}},	//   _tust_, _aete, يناب, _sjöf, 
   {{0x291cee04,0x24582568,0x9f4c0724,0x7f4c42b2}},	//   _asta_, _gëme_, ügä_, qyaq, 
   {{0x69d8ee05,0x291c1c06,0x386c8a45,0x245800e8}},	//   _cete, _bsta_, wier_, _jëmb_, 
   {{0x386cee06,0x26c002fb,0xa9a001b9,0xe9a06f9f}},	//   tier_, íkon_, мишд, машп, 
   {{0x69d8ee07,0x36c401d5,0xda78013d,0x00000000}},	//   _eete, обиг, _өяз_, --, 
   {{0x291cee08,0x69d8ee09,0x69c812eb,0x09d800bd}},	//   _esta_, _fete, _स्वी, _সারা, 
   {{0x69d8ee0a,0xb668ee0b,0xa0180008,0x386cee0c}},	//   _gete, риоз_, _fjög, sier_, 
   {{0xe80405ba,0xa01802d2,0x7d0403ac,0x00000000}},	//   व्हा_, _gjög, nths, --, 
   {{0x69d8ee0d,0x7d040332,0x00000000,0x00000000}},	//   _zete, iths, --, --, 
   {{0x69d8ee0e,0x888c008f,0xf74400f3,0xc3540395}},	//   _yete, _גראַ, _фело, пъръ, 
   {{0x59cc28e0,0x068402dd,0xd5b800f3,0x69d80139}},	//   _स्मर, _егін, _ссд_, _xete, 
   {{0xafe42e36,0x43800092,0x7d040200,0x2ca40042}},	//   жобл, _የዕርቀ_, jths, ymod_, 
   {{0x62480793,0xefc805f5,0x7d0403ac,0x6ac80154}},	//   _büos, рлал_, dths, _রিসো, 
   {{0xc61c015b,0x2ca40fac,0x91a800e5,0x00000000}},	// [14b40] তারা_, vmod_, _گندے_, --, 
   {{0xa0184a3c,0x2d9452db,0x63b40205,0x00000000}},	//   _sköt, орес, ğanş, --, 
   {{0x09d800bd,0xa0180267,0x648c01ab,0x6ed829d9}},	//   _সালা, _bjöd, cùis, _पौरु, 
   {{0x69d8ee0f,0xfca800aa,0xeb281d0f,0x6fa001f9}},	//   _sete, مانو_, ижел_, _खरपू, 
   {{0x2ca4ee10,0x69d86c01,0xa0180267,0x6a84ee11}},	//   rmod_, _pete, _sjög, олда, 
   {{0x69d8052f,0x2ca40483,0x06c802f5,0x7cf00124}},	//   _qete, smod_, _শিলি, _ẽret, 
   {{0x69d82b9d,0xbab000cf,0x00000000,0x00000000}},	//   _vete, رۅمب, --, --, 
   {{0x69d8ee12,0x98a00063,0x2fd001bf,0xdca001a9}},	//   _wete, мије, nbyg_, _жаси, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69d8ee13,0x44f486e5,0xdb0401e1,0xa9a400f3}},	//   _uete, ппос, _ìlág, _дизд, 
   {{0x68000316,0x00000000,0x00000000,0x00000000}},	//   _půjč, --, --, --, 
   {{0x2ef005e4,0x00000000,0x00000000,0x00000000}},	//   kryf_, --, --, --, 
   {{0x2fd0005c,0x98780677,0xf8a80066,0x00000000}},	//   dbyg_, _דראק, _ادله_, --, 
   {{0x2488070d,0x2ef00151,0x7afc08fb,0xd1dc0023}},	//   socm_, dryf_, _åste, _ንሓቂ_, 
   {{0x403400d8,0x00000000,0x00000000,0x00000000}},	//   певс, --, --, --, 
   {{0x38a00165,0x6aa407f7,0xdce80135,0xd46800f3}},	//   córd_, गगुर, żiċi, _мије_, 
   {{0x245800e8,0x427401b9,0x6ad00154,0x00000000}},	// [14b50] _tëmb_, _нгис, _সমঝো, --, 
   {{0x69c806ab,0xa01801e3,0x00000000,0x00000000}},	//   _स्ली, _sjöd, --, --, 
   {{0x8d6806ed,0x7d04ee14,0x38a00022,0x00000000}},	//   ојца_, uths, lóre_, --, 
   {{0x7d04ee15,0x00000000,0x00000000,0x00000000}},	//   rths, --, --, --, 
   {{0x38a000e4,0x00000000,0x00000000,0x00000000}},	//   nóre_, --, --, --, 
   {{0xdcf8034c,0x01d8015b,0xa2580109,0x4a440212}},	//   _پرسش_, _তাঁদ, mpôs, мнів, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd6c0034c,0xb88002d3,0x769c0066,0xa018032e}},	//   ومبی, _ይቅጽል_, dèya, _hjöb, 
   {{0xf77006d5,0x3ad40150,0x7ad4cfad,0x00000000}},	//   عاب_, _رياز, _رقاص, --, 
   {{0x38b00010,0x00000000,0x00000000,0x00000000}},	//   _išrm_, --, --, --, 
   {{0x7ea80006,0x769c00f2,0xa3d4012d,0xb3580092}},	//   _užpu, gèya, ाऐं_, _ሲመዘን_, 
   {{0x3a2408cd,0x59cc0bae,0x14d400cd,0x00000000}},	//   _halp_, _स्तर, भीषण, --, 
   {{0x78a85b47,0x3a2403ee,0xd348036b,0x2898008f}},	//   mmev, _kalp_, زیده_, _פינא, 
   {{0x78a8ee16,0x3a2401a4,0x2ef00af9,0x6d4803cd}},	//   lmev, _jalp_, vryf_, øfak, 
   {{0x624800b0,0x753401c6,0x2ef00142,0x00000000}},	//   _püor, _хэлх, wryf_, --, 
   {{0x24800020,0xa064ee17,0xaec40220,0xa018ee18}},	//   _ሪፖርት_, паса_, збал, _skör, 
   {{0xb8dc0f50,0x78a80158,0x2fd001bf,0x37bc00eb}},	// [14b60] _ཀང_, imev, rbyg_, _ইজার, 
   {{0x78a8ee19,0x00000000,0x00000000,0x00000000}},	//   hmev, --, --, --, 
   {{0xafc400cf,0xae001cd2,0x2bc898e0,0x00000000}},	//   _ىيدى, र्गन_, було_, --, 
   {{0xdd8c9717,0x78a8044e,0x7c6407d6,0xc50c008f}},	//   دوم_, jmev, وانل, שלאָ, 
   {{0x200403be,0x3a24030a,0x78a8bc8a,0x00000000}},	//   əni_, _balp_, dmev, --, 
   {{0x26c001a2,0x3a24004e,0xf1bc2802,0x24580200}},	//   íkom_, _calp_, ्डिन, _mëma_, 
   {{0xada450da,0x6da401d5,0x00000000,0x00000000}},	//   _хавл, _хива, --, --, 
   {{0x5d780375,0x47340305,0x00000000,0x00000000}},	//   _האלק, днис, --, --, 
   {{0x757002d3,0x769c020c,0xf1bc00cd,0xbab000db}},	//   _ብመገዲ_, wèya, ्डान, رۅۅب, 
   {{0x3a24010b,0xd6cc18c7,0x38a00022,0x00000000}},	//   _galp_, _үт_, vóre_, --, 
   {{0xd7ecee1a,0xca3801e4,0x55700276,0xb8640451}},	//   _пу_, _inĝ_, егэт, _ڪالو, 
   {{0x24580200,0x38a000e4,0x00000000,0x00000000}},	//   _bëma_, tóre_, --, --, 
   {{0xb864ee1b,0xe45c0108,0x2bcc00cd,0x00000000}},	//   _تالو, rhö_, हुया, --, 
   {{0x6720ee1c,0xd24400ee,0x7d0001bf,0x38a00124}},	//   _isoj, нэси, _ålsg, róre_, 
   {{0x6618ee1d,0x38a00022,0x6098007b,0x24880092}},	//   metk, sóre_, مخرج_, _ማህሙድ_, 
   {{0x6618ee1e,0xa018ee1f,0x55940375,0x03540131}},	//   letk, _sjöb, _מדוע_, _жүмә_, 
   {{0x1ea80451,0xfe701a4d,0x2458002e,0x00000000}},	// [14b70] مائي_, نگس_, _gëma_, --, 
   {{0xa5080135,0x66188fd0,0x67200200,0xe37001ec}},	//   _ཀྱོག_, netk, _msoj, _олқы, 
   {{0x229c019f,0xa25801f1,0x9c1000fd,0x00000000}},	//   cîka_, spôs, ечлә, --, 
   {{0x66181073,0x5f400131,0x00000000,0x00000000}},	//   hetk, _كۆزل, --, --, 
   {{0x3a240076,0xdef002d3,0xf0000107,0x700400eb}},	//   _palp_, ልየካ_, _шӯри, _লোকজ_, 
   {{0x20180327,0x00000000,0x00000000,0x00000000}},	//   leqi_, --, --, --, 
   {{0xed4c0d83,0x67200ca8,0x6618ee20,0x3a24ee21}},	//   _پھل_, _asoj, detk, _valp_, 
   {{0x2bdc9c14,0x00000000,0x00000000,0x00000000}},	//   मरणा, --, --, --, 
   {{0x661824e7,0x3a24ee22,0x00000000,0x00000000}},	//   fetk, _talp_, --, --, 
   {{0x6618ee23,0x74e805f5,0xacb000f7,0x366800d4}},	//   getk, одог_, _كەەب, іано_, 
   {{0x7ae8ee24,0xf42003d4,0xae003d1d,0xa25800e4}},	//   _hvet, যাসৰ_, र्टन_, ypôr, 
   {{0x7ae8ee25,0x00000000,0x00000000,0x00000000}},	//   _kvet, --, --, --, 
   {{0x6618ee26,0x67200022,0x00000000,0x00000000}},	//   betk, _аҟыҧ, --, --, 
   {{0x66180b91,0x7ae80161,0xa01801a8,0x64b8031c}},	//   cetk, _mvet, _sköp, _rċiv, 
   {{0xe29483f9,0xdb0403b2,0xd34807d6,0x00000000}},	//   фар_, _ímæt, زیگه_, --, 
   {{0x7ae8ee27,0xcf600020,0x229c24ba,0x2018014b}},	//   _ovet, _ለመፍታ, rîka_, geqi_, 
   {{0x229c00d2,0x7ae80055,0x6aa8015d,0x00000000}},	// [14b80] sîka_, _nvet, ymff, --, 
   {{0x7bc80618,0x2f040165,0xed58642c,0x00000000}},	//   _afeu, rôg_, يشات_, --, 
   {{0x7ae8ee28,0xdd8c0372,0x7aec0cf4,0x00000000}},	//   _avet, لوك_, šatl, --, 
   {{0xae001025,0x539402d3,0x6aa41788,0x00000000}},	//   र्जन_, _መቕደስ_, गग्र, --, 
   {{0x7ae8565b,0xdc540014,0xafc400f7,0x2aa801e5}},	//   _cvet, برٕک, _ىيگى, отко_, 
   {{0x7bc80270,0x2bcc0b9a,0x923c0023,0x7ae80419}},	//   _efeu, _ह्रा, _ኣወሃሃ, _dvet, 
   {{0x6618ee29,0x7ae8ee2a,0x28a401c0,0x7c3000d7}},	//   vetk, _evet, мшиг, ýkrá, 
   {{0x3330ee2b,0x6618134e,0x7ea800c0,0xdd8c0133}},	//   _oryx_, wetk, _užpr, _ئوف_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7afca2ec,0x09d800eb,0x00000000,0x00000000}},	//   _åsta, _সাকা, --, --, 
   {{0x7ae8006f,0x00000000,0x00000000,0x00000000}},	//   _zvet, --, --, --, 
   {{0x672000b5,0xe738004e,0x00000000,0x00000000}},	//   _tsoj, _мее_, --, --, 
   {{0xe664ee2c,0x67544667,0x6618ee2d,0x67200010}},	//   _отко, _تخار, petk, _usoj, 
   {{0x6cfc76f8,0x38a00553,0x388402b5,0x00000000}},	//   _उमंग_, móra_, rēre_, --, 
   {{0x33300393,0xa490004b,0x38a0ee2e,0xd5f8011a}},	//   _eryx_, _لیدت, lóra_, _ופור, 
   {{0x3cec01e4,0xd01801ca,0x2bcc0303,0x00000000}},	//   _ĉev_, мфу_, _ह्ला, --, 
   {{0x44281132,0x64b8031c,0x3f840034,0x20180200}},	// [14b90] _iaa_, _eċit, _ślub_, reqi_, 
   {{0x4428ee2f,0x800800dd,0x7bc80393,0xdd980063}},	//   _haa_, _کردہ_, _sfeu, оше_, 
   {{0x7ae89955,0x4428ee30,0x52742756,0x38a000ae}},	//   _svet, _kaa_, _جايز, hóra_, 
   {{0x4428ee31,0x260c2052,0xbed40114,0x31540677}},	//   _jaa_, त्ती_, _помј, _נירן_, 
   {{0x4428ee32,0x38a009f3,0x2d8c0e78,0xdee4007b}},	//   _maa_, jóra_, üfer_, _تأجي, 
   {{0x4428ee33,0x38a0ee34,0x81dc0154,0x00000000}},	//   _laa_, dóra_, ডলক_, --, 
   {{0x442881a5,0x645c01b9,0xcd04ee35,0x09d800eb}},	//   _oaa_, _olqi, _ичти, _সাখা, 
   {{0xa378000d,0x38a001ef,0x00000000,0x00000000}},	//   vaõn, fóra_, --, --, 
   {{0x7ae8ee36,0x38a0ee37,0x69c81f13,0x5bc805c0}},	//   _uvet, góra_, _स्की, ाडीव, 
   {{0x7c281243,0x645c4091,0xa68000fd,0x3fcc0131}},	//   _haer, _alqi, ллыд, _ﺑﯩﺰﻧ, 
   {{0x4428ee38,0x7c28ee39,0xc0680882,0xb5784676}},	//   _baa_, _kaer, ṣṭo_, ящих_, 
   {{0x4428ee3a,0xc2080302,0x7c28ee3b,0x75700023}},	//   _caa_, _לה_, _jaer, _ብዘለዎ_, 
   {{0x7c28ee3c,0x4428ee3d,0xc76401d9,0xabb00055}},	//   _maer, _daa_, _لاوى, _kṣaṃ_, 
   {{0x7c28ee3e,0x66f40302,0xb9f80023,0x00000000}},	//   _laer, _נמצא_, _ዘን_, --, 
   {{0xa01801e6,0x31e00154,0xdbc400a2,0x3f984e7e}},	//   _sjöa, _বাদশ, _göçu, _aysu_, 
   {{0x4428ee3f,0x7c28ee40,0x81dc015b,0x602001c0}},	//   _gaa_, _naer, _ডাঃ_, лдса, 
   {{0x78b8016d,0xa064ee41,0xa378000d,0x00000000}},	// [14ba0] _miwv, хата_, naõl, --, 
   {{0x4428ee42,0x7c280076,0x3124ee43,0x23a40166}},	//   _zaa_, _aaer, _здог, _явып_, 
   {{0x4428ee44,0x7c28ee45,0x38a000e5,0x932400f1}},	//   _yaa_, _baer, zóra_, _سرښن, 
   {{0x7c28ee46,0x4428ee47,0xefb01158,0xeb04e91f}},	//   _caer, _xaa_, _میزگ, ечко, 
   {{0x7c282c3e,0x6fb401d9,0x15ec01f9,0x00000000}},	//   _daer, _سمسا, चणार_, --, 
   {{0x7c28ee48,0xdce803e0,0x00000000,0x00000000}},	//   _eaer, _çiğl, --, --, 
   {{0x7c28ee49,0x199000ee,0x49040139,0x00000000}},	//   _faer, лашя, түег, --, 
   {{0x7c28ee4a,0xe97402d3,0x7b08023a,0xabb00055}},	//   _gaer, _ክንርኢ_, östö, _eṣaṃ_, 
   {{0x4428ee4b,0x00000000,0x00000000,0x00000000}},	//   _raa_, --, --, --, 
   {{0x4428ee4c,0xfd4c0055,0x7c280165,0x38a06d6c}},	//   _saa_, _atoṣ, _zaer, róra_, 
   {{0x4428ee4d,0xdb181497,0x83f8084c,0x7c28004c}},	//   _paa_, _aguè, менс_, _yaer, 
   {{0xe7840cdb,0x4428ee4e,0x38a0ec21,0x229c00d2}},	//   _пуло, _qaa_, póra_, tîko_, 
   {{0x4428ee4f,0x6ab80585,0x00000000,0x00000000}},	//   _vaa_, _kitf, --, --, 
   {{0x44282f2a,0x67240008,0x6ab80003,0x388400e2}},	//   _waa_, ækju, _jitf, mēra_, 
   {{0x4428ee50,0x6ab8ee51,0x229c00d2,0xa0a46af2}},	//   _taa_, _mitf, sîko_, ешал, 
   {{0x6ab8192e,0x4428ee52,0x645c02d3,0x8334084c}},	//   _litf, _uaa_, _ulqi, _аних, 
   {{0x7c28ee53,0x24580694,0xdf7401d5,0x00000000}},	// [14bb0] _raer, _jëmm_, ردرب, --, 
   {{0x38a01873,0x7c28c006,0x4154023a,0x6ab8025c}},	//   jórn_, _saer, _авос, _nitf, 
   {{0x7c28ee54,0x24580de2,0x61e41ef7,0x4094007b}},	//   _paer, _lëmm_, majl, _للدر, 
   {{0x61e48b93,0x7c28036b,0x3b54ee55,0x769c007f}},	//   lajl, _qaer, ккер, vèym, 
   {{0x7c28bcf0,0x6ab800b5,0x09d8015b,0x20c40051}},	//   _vaer, _bitf, _সাজা, _hõi_, 
   {{0x7c28ee56,0x61e4ee57,0x20c40022,0x50d448dc}},	//   _waer, najl, _kõi_, _جزیر, 
   {{0x7c28ee58,0x78b80477,0x20c4000d,0x00000000}},	//   _taer, _piwv, _jõi_, --, 
   {{0x61e4ee59,0x6ab803ac,0x7afc3402,0x769c007f}},	//   hajl, _eitf, _åsto, rèym, 
   {{0x6ab8ee5a,0x20c4ee5b,0xdb1800c7,0xa6e05316}},	//   _fitf, _lõi_, _ogué, ажыл, 
   {{0x2458002e,0xdb181b67,0x61e42630,0xdcfc0024}},	//   _dëmm_, _ngué, jajl, _švęs, 
   {{0x1cbc1b4b,0x69c80027,0x61e40477,0x2bcc000d}},	//   _གངས_, _स्टी, dajl, हुवा, 
   {{0xa01801e6,0x388400ef,0x00000000,0x00000000}},	//   _sjön, bēra_, --, --, 
   {{0x245800e8,0xa8540375,0x61e4031c,0x998400e5}},	//   _gëmm_, _שינה_, fajl, menő_, 
   {{0x61e4e684,0x998401ed,0x0b440023,0x00000000}},	//   gajl, lenő_, _ሙዚቀኛ, --, 
   {{0x26c001a2,0x20c401fb,0xafe486e5,0xc6a41fbe}},	//   íkov_, _cõi_, ковл, _срци, 
   {{0x20c40016,0x4e1411b1,0x246c0118,0xdfcc0338}},	//   _dõi_, न्नै_, yřmi_, قيف_, 
   {{0x61e40455,0x6e9401d5,0x00000000,0x00000000}},	// [14bc0] bajl, نلرا, --, --, 
   {{0xed5816c3,0xa018032e,0x6ffc0356,0x38a000e4}},	//   моз_, _hjöl, făcâ, kóro_, 
   {{0xa0180008,0xe43001b9,0x998401d3,0x68e80175}},	//   _kjöl, _صفید, kenő_, xsfd, 
   {{0x68e845a7,0x6ab8192e,0xaae4009a,0xfd9400d4}},	//   vsfd, _sitf, نستو, ушую, 
   {{0xa018ee5c,0xdb180022,0x6ab80f85,0x7af80142}},	//   _mjöl, _ygué, _pitf, grwt, 
   {{0xada4035b,0xe9b40014,0x00000000,0x00000000}},	//   _аагл, نچاں_, --, --, 
   {{0x9d40ee5d,0x3fc800e5,0x6ab8032e,0x00000000}},	//   _керд, _آگہی_, _vitf, --, 
   {{0x6ab80036,0x38840374,0x7c94404b,0x69c8ee5e}},	//   _witf, tēra_, _бруц, scfe, 
   {{0x6ab8ee5f,0xa0980375,0x6a140fb4,0x666400a7}},	//   _titf, ויקט, _لبار, вънз, 
   {{0x2bcc1fb2,0x6ab8ee60,0x46240116,0x00000000}},	//   हुरा, _uitf, учиғ, --, 
   {{0x44b40228,0x61e40114,0x4e140882,0xa01808a5}},	//   лбос, vajl, न्यै_, _bjöl, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x61e4ee61,0x20c40037,0xa018007c,0xb864009a}},	//   tajl, _sõi_, _sjöo, _حالو, 
   {{0x17540375,0x973408a8,0x25640014,0x78ac0327}},	//   _בסדר_, _שרגא_, _لابُ, ċave, 
   {{0xa0180f99,0x61e4ee62,0x1c109201,0x648800f3}},	//   _fjöl, rajl, ण्डल_, _осиг_, 
   {{0x20c4367a,0x61e40ab7,0xa01801a8,0x506454e7}},	//   _või_, sajl, _gjöl, атуа, 
   {{0xdb1800e4,0x00000000,0x00000000,0x00000000}},	// [14bd0] _aguî, --, --, --, 
   {{0x81dc09bd,0x20c400af,0xab3c0de2,0x386800d0}},	//   _ডাক_, _tõi_, _nàññ_, ďari_, 
   {{0x77680ba7,0xb7bc054e,0x41d800bc,0x00000000}},	//   zzex, leţe, _ब्यस, --, 
   {{0x3084030d,0x00000000,0x00000000,0x00000000}},	//   _йăхс, --, --, --, 
   {{0x6d480a64,0xb7bc0356,0xc5e800eb,0x00000000}},	//   øfar, neţe, _খানা_, --, 
   {{0x3d940724,0x00000000,0x00000000,0x00000000}},	//   _бигр, --, --, --, 
   {{0xa3e0acd2,0xf4bc0eac,0xca74ee63,0xf98800db}},	//   धरा_, _আব্ব, جانغ, رچئي_, 
   {{0x39480552,0xc9540220,0x9e000037,0xbc940120}},	//   ćas_, ртшы, _लाँघ_, _сабј, 
   {{0x2368037e,0x00000000,0x00000000,0x00000000}},	//   jzcj_, --, --, --, 
   {{0xb7bc084c,0xab3c00e8,0xa01836d5,0xa3780037}},	//   deţe, _gàññ_, _sjöl, maõh, 
   {{0xf3e4229d,0x73e401b9,0x98484964,0xa01802d2}},	//   лжно, лонз, _ояда_, _pjöl, 
   {{0xb7bc0311,0x388400e2,0xd7640150,0xa01800e5}},	//   feţe, mēro_, _لەبى_, _eköz, 
   {{0x81d4ee64,0xa3780254,0x00000000,0x00000000}},	//   _হয়_, naõh, --, --, 
   {{0x43742d22,0x272c0790,0xa01802d2,0xf678010f}},	//   руют, sınç_, _djöm, _ראַמ, 
   {{0x7bc40118,0xa01801a8,0x00000000,0x00000000}},	//   ěhuj, _tjöl, --, --, 
   {{0xe4d001ec,0x91d4033f,0x705401b9,0x00000000}},	//   _اقيد, _ब्रै, دنرا, --, 
   {{0xee388c75,0xef18ee65,0xa5600133,0xa0a001b9}},	// [14be0] нна_, эма_, _نگێن, сатд, 
   {{0xb224ee66,0x00000000,0x00000000,0x00000000}},	//   _смол, --, --, --, 
   {{0x7afc0fac,0xc0c0001f,0x200c00cf,0x4144004e}},	//   _åstj, ስቻል_, ògic_, _күрп_, 
   {{0xfca8021a,0x16100d0b,0xab3c00e8,0x5c7400c7}},	//   نانو_, त्तर_, _sàññ_, гәур_, 
   {{0x95200003,0x00000000,0x00000000,0x00000000}},	//   _འགའི_, --, --, --, 
   {{0xe3bc0077,0x31e0015b,0x91a80118,0x388400ef}},	//   meñe_, _বাঁশ, _गराई, fēro_, 
   {{0xfe9000e5,0x00000000,0x00000000,0x00000000}},	//   _بیلج, --, --, --, 
   {{0x6e2cee67,0x6da407dd,0x290c0311,0x80b800dc}},	//   _habb, _аиҳа, rtfa_, ्दये, 
   {{0x205404ac,0x6e2cee68,0x6a640008,0x59cc3507}},	//   טיקל_, _kabb, _aðfe, _स्कर, 
   {{0x6e2cee69,0x91d41533,0x00000000,0x00000000}},	//   _jabb, _ब्लै, --, --, 
   {{0x6e2cee6a,0xa0180267,0xd82cbe67,0xa3780254}},	//   _mabb, _sjöm, _лэ_, maõi, 
   {{0x66e4ee6b,0x4e14012c,0x2bb802c3,0xa3780037}},	//   _бода, न्तै_, ेशपा, laõi, 
   {{0x229c025a,0xd8900050,0x6e2c0076,0xb7bc0311}},	//   lîki_, _أند, _oabb, teţe, 
   {{0x6e2cee6c,0x25ec0490,0x27e40051,0xa378000d}},	//   _nabb, _आयटी_, _heon_, naõi, 
   {{0x27e4089c,0x26c40093,0x154006ed,0xb7bc054e}},	//   _keon_, _huoo_, _гејм, reţe, 
   {{0x6e2c36b7,0xb7bc0311,0x27e40051,0x00000000}},	//   _aabb, seţe, _jeon_, --, 
   {{0x6e2cee6d,0x7e74035b,0xaf5407dd,0x27e4ee6e}},	// [14bf0] _babb, агах, антә, _meon_, 
   {{0xe45c049f,0x6e2c0afa,0xa378000d,0x2bb80aa2}},	//   lkö_, _cabb, jaõi, ेशना, 
   {{0x6e2cee6f,0x00000000,0x00000000,0x00000000}},	//   _dabb, --, --, --, 
   {{0xa6d82158,0x6e2c062c,0xe45c023a,0x388400e2}},	//   _দিনট, _eabb, nkö_, vēro_, 
   {{0x6e2cee70,0xbb4422e9,0x200800a3,0xe45c0108}},	//   _fabb, релк, _icci_, ikö_, 
   {{0x6e2c0bc1,0x27e4ee71,0xe45c023a,0x24580240}},	//   _gabb, _aeon_, hkö_, _dëmi_, 
   {{0xe45c02f6,0xaa54026a,0xdb1800e4,0x5d3001ed}},	//   kkö_, рију_, _iguí, _دہائ, 
   {{0x6e2c0a49,0xbd040248,0x7cc40024,0x2458036e}},	//   _zabb, _eléé, _nėri, _fëmi_, 
   {{0x27e405e4,0x245800e8,0x6e2c0429,0x36c40e92}},	//   _deon_, _gëmi_, _yabb, јбог, 
   {{0x6e2c47ad,0xe45c005b,0x00000000,0x00000000}},	//   _xabb, ekö_, --, --, 
   {{0x20080998,0x27e40170,0x35a4ee72,0x55c0a705}},	//   _occi_, _feon_, ранг, _һалғ, 
   {{0xdb1800e4,0x2008017a,0x69cc0427,0x31e000eb}},	//   _iguâ, _ncci_, čnež, _বাইশ, 
   {{0x915c0241,0xe72c0139,0x29240210,0x00000000}},	//   _ọ́n_, _ье_, ętał_, --, 
   {{0x20080393,0x27e4005a,0x00000000,0x00000000}},	//   _acci_, _zeon_, --, --, 
   {{0xefc0069c,0x200803a2,0x27e4ee73,0x6e2cee74}},	//   ስያዊ_, _bcci_, _yeon_, _rabb, 
   {{0x6e2cee75,0x7cc40006,0x20840075,0x25180375}},	//   _sabb, _gėri, айси_, _יוצא, 
  
   {{0x6e2cee76,0x1ec4010b,0xc5e80154,0xf2d0009a}},	// [14c00] _pabb, илти_, _খাতা_, _بآب_, 
   {{0x2bdc543b,0x6e2cee77,0x2008003a,0xd0e82e07}},	//   मर्थ, _qabb, _ecci_, _مکرم_, 
   {{0x6e2cee78,0xe3bc00e8,0xa3780254,0x00000000}},	//   _vabb, reñe_, vaõi, --, 
   {{0x6e2cee79,0x20080048,0xe3bc04d4,0x49a401e0}},	//   _wabb, _gcci_, señe_, ҙылғ, 
   {{0x6e2cee7a,0x27e40072,0xc0f00023,0xe3bc00e4}},	//   _tabb, _reon_, ልገለ_, peñe_, 
   {{0xda6c0a81,0xdee099a4,0x6e2c02d0,0x00000000}},	//   وُن_, _фори, _uabb, --, 
   {{0x27e40109,0xe45c023a,0xa92801ec,0x98c001ee}},	//   _peon_, ykö_, тіле_, осыл, 
   {{0x6b2400f1,0x9cd405d0,0xbc44014b,0x00000000}},	//   _نښتې_, _כולה_, _гӯша_, --, 
   {{0xeb9870df,0x27e4067c,0xa0180267,0xeab8030d}},	//   _риа_, _veon_, _sjök, _айа_, 
   {{0x27e40789,0x69944316,0xc0f00240,0x00000000}},	//   _weon_, _крех, ልገሉ_, --, 
   {{0x27e4d293,0xe45c049b,0xda6c0050,0xe4a4036b}},	//   _teon_, tkö_, _تُل_, ирмо, 
   {{0xd4980262,0x291cee7b,0x06840b38,0x00000000}},	//   иря_, _ipta_, ргүн, --, 
   {{0xc61807d5,0x7cc40153,0xe45c3b22,0x00000000}},	//   _болх_, _vėri, rkö_, --, 
   {{0xe45c33b4,0xa1280092,0x00000000,0x00000000}},	//   skö_, _ትልልቆ, --, --, 
   {{0x20080589,0xb7bc0356,0x00000000,0x00000000}},	//   _pcci_, peţc, --, --, 
   {{0xfe180490,0x1ea80451,0x00000000,0x00000000}},	//   न्नस_, چائي_, --, --, 
   {{0x1ea8384b,0x644c0369,0x95200327,0x20080208}},	// [14c10] نائي_, mjci, _འགོི_, _vcci_, 
   {{0x644c05ce,0x291cee7c,0x7afc08fb,0x00000000}},	//   ljci, _opta_, _åsti, --, 
   {{0xc2e4036b,0xdb180022,0x628408a4,0x92b4007b}},	//   _тўқи, _oguã, mnjo, _بحيا, 
   {{0x644c0007,0x0ca8ee7d,0x606007d2,0x3d943452}},	//   njci, атчи_, _بۇرل, _ғибр, 
   {{0x291cee7e,0xdd34001f,0xfca802dd,0x9b24a372}},	//   _apta_, _የሚሌኒ, _ұсақ_, рфел, 
   {{0x6284ee7f,0xc0f0069d,0xa3ac03ba,0xa01801e3}},	//   nnjo, ልገል_, _करन_, _sjöh, 
   {{0x5c0402f6,0x628401e2,0x20f001a6,0x9c440354}},	//   _вяза, injo, nći_, _кхал, 
   {{0x245802b5,0x7d04014b,0x38280640,0x00000000}},	//   _këmu_, muhs, ужио_, --, 
   {{0xf7483047,0x62840e04,0xf770007b,0x00000000}},	//   اجعه_, knjo, ثاث_, --, 
   {{0x628407f5,0x20f001fa,0x00000000,0x00000000}},	//   jnjo, kći_, --, --, 
   {{0x62841326,0xc32825f9,0x245800e8,0x1acc015b}},	//   dnjo, _רו_, _lëmu_, _রিয়া, 
   {{0x15f0d44d,0x491c5690,0x6284004b,0x06840137}},	//   _आयकर_, _महतो_, enjo, йгөн, 
   {{0x38a02242,0xb864004b,0xa3d42e05,0x7d040112}},	//   jóri_, _پاڅو, िड़_, huhs, 
   {{0x9ad0063f,0x7d04020c,0x62840165,0x14cc0073}},	//   yịnw, kuhs, gnjo, _संपण, 
   {{0x2164759a,0x5378001f,0x65900114,0x7ea800c0}},	//   бири_, _አንዲት_, _наљу, _užpy, 
   {{0x6284ee80,0x387000fd,0x00000000,0x00000000}},	//   anjo, _çorı_, --, --, 
   {{0x628401fa,0xa3ac0037,0xefcc0092,0x00000000}},	// [14c20] bnjo, _करय_, _እንይ_, --, 
   {{0x31e00154,0x00000000,0x00000000,0x00000000}},	//   _বাকশ, --, --, --, 
   {{0x8d280598,0xe3bc0615,0x00000000,0x00000000}},	//   рнең_, meña_, --, --, 
   {{0xdd8c8958,0xe3bc0615,0xa3ac032c,0x6598008f}},	//   رون_, leña_, _करम_, איעק, 
   {{0x245800e8,0x6a6401a8,0x7c6401d5,0xdd3800c0}},	//   _gëmu_, _aðfa, غامل, _vąše, 
   {{0x3208ee81,0xcdc400c2,0xec1407d6,0x00000000}},	//   ngby_, _фавқ, _گورد, --, 
   {{0xc0d4001f,0xfca80ca5,0xa018007c,0x00000000}},	//   ክፈል_, _چاقو_, _sjöi, --, 
   {{0xc6f8504f,0xb88001f1,0xec14ee82,0x62840fcf}},	//   аних_, _šíre, _دورد, znjo, 
   {{0x6d5cee83,0x254c03be,0x2ef0000f,0xab64361e}},	//   lypa, məli_, nsyf_, _увал, 
   {{0xa3ac007d,0x44f42f59,0x8a6400f7,0x5a60014b}},	//   _करब_, опос, _بئرۅ, _екуб, 
   {{0xd940ee84,0xdb180022,0xe3bcee85,0x628401a6}},	//   _нефи, _iguá, deña_, vnjo, 
   {{0x644c0007,0xb7bc054e,0x6fd80456,0x254c03e3}},	//   ujci, seţa, युमं, nəli_, 
   {{0xb9f00020,0x628408ad,0x6d5c09a5,0xa3b025c9}},	//   _ናት_, tnjo, hypa, झें_, 
   {{0xa6b40801,0xdd140724,0x26b4034b,0x6d5c03ac}},	//   _усещ, _näşr, _ущер, kypa, 
   {{0xd5ac00d8,0xdef00023,0x6d5c01f4,0x254c03b9}},	//   _хс_, ልየን_, jypa, kəli_, 
   {{0x41d800dc,0x32080076,0x1b1c0154,0x00000000}},	//   _ब्रस, agby_, পিতে_, --, 
   {{0x3ed4ee86,0x6284107d,0xe3bc5781,0xdb180022}},	// [14c30] زقار, pnjo, beña_, _oguá, 
   {{0x7d04ee87,0xe3bc0789,0x6d5c02d0,0x9cc8004e}},	//   tuhs, ceña_, fypa, гыда_, 
   {{0x6d5cee88,0x254c0213,0xdda803f5,0xc8c4000d}},	//   gypa, fəli_, утал_, _लंगट, 
   {{0xdb1800e4,0xc1b403e5,0x254c06be,0x00000000}},	//   _aguá, ंधीग, gəli_, --, 
   {{0x6d5c0334,0x7d0400d8,0x59a8033f,0x0fe4009d}},	//   aypa, suhs, _छरहर, _хөсү, 
   {{0x7f4c011f,0x388400e2,0xaa400209,0x00000000}},	//   mxaq, mēri_, дешл, --, 
   {{0xe72c04d3,0x6d5c0c8c,0x254c03e3,0x00000000}},	//   ێڵه_, cypa, bəli_, --, 
   {{0x8c640220,0x1fe4015b,0x254c0213,0x00000000}},	//   _етуд, _ফাঁস, cəli_, --, 
   {{0xdd14013d,0x00000000,0x00000000,0x00000000}},	//   _yäşr, --, --, --, 
   {{0xf674ee89,0xb3400209,0xb658ee8a,0xe6145ff9}},	//   تابخ, _üçin, рших_, одь_, 
   {{0xe3bc0077,0x996423be,0x00000000,0x00000000}},	//   veña_, _утал, --, --, 
   {{0xdb040579,0x2078044e,0x00000000,0x00000000}},	//   _ímót, _ተገሊጹ_, --, --, 
   {{0xd6d8ee8b,0x6d5c068f,0xa3ac25c9,0xe3bc25e6}},	//   _сте_, zypa, _करण_, teña_, 
   {{0x386cee8c,0x95c8ee8d,0x254c0213,0x7afc143a}},	//   lher_, _суда_, zəli_, _åstu, 
   {{0xe3bcee8e,0x6d5cee8f,0x254c0213,0x320801bf}},	//   reña_, xypa, yəli_, rgby_, 
   {{0xe3bc00bd,0x386cee90,0x6d5cdc3a,0x41b40006}},	//   seña_, nher_, vypa, ясят, 
   {{0xa064529e,0x386c0732,0xe3bc04d4,0x6d5c012d}},	// [14c40] цата_, iher_, peña_, wypa, 
   {{0xa3ac8fa7,0x6d5c0c8c,0x63800022,0x7c6400d1}},	//   _करत_, typa, _цгьа, ۋانل, 
   {{0x2ef0000f,0x38a00ab9,0xafc401ec,0x00000000}},	//   ssyf_, lóru_, _ويدى, --, 
   {{0x6d5cee91,0x6ac01889,0xc50c008f,0xa0180267}},	//   rypa, शद्र, רלאָ, _sjöv, 
   {{0x6d5c035b,0x386c003d,0xeab8ee92,0x254c00ac}},	//   sypa, dher_, айд_, rəli_, 
   {{0x6f14ee93,0x386c0e78,0x6d5cb636,0xb88001ef}},	//   mtyc, eher_, pypa, _šípe, 
   {{0x6f14ee94,0xed58ee95,0xa850010b,0xc5e80154}},	//   ltyc, _тов_, дейә, _খালা_, 
   {{0x386cee96,0x254c0213,0x6f14012d,0x00000000}},	//   gher_, qəli_, otyc, --, 
   {{0x6f14ee97,0xdb88001f,0x66880023,0x00000000}},	//   ntyc, ናቸውም_, _ዕብለላ_, --, 
   {{0x2ca485b5,0x6f14012d,0x38a0032e,0x00000000}},	//   llod_, ityc, dóru_, --, 
   {{0x386cee98,0xa0180008,0x1fb46a60,0x2bb85b82}},	//   bher_, _kjöt, _अण्ड, ेशवा, 
   {{0x386cee99,0x6f14068f,0x2ca4ee9a,0xa3e80022}},	//   cher_, ktyc, nlod_, шьоз_, 
   {{0xdef0044e,0x7f4c0429,0x0af80154,0xf8ac79d1}},	//   ልየና_, xxaq, _আঙুল_, _حکو_, 
   {{0x65840372,0x67201ca9,0x2ca4014f,0x6f1401e3}},	//   _мыйз, _ipoj, hlod_, dtyc, 
   {{0x2ca422d0,0x7f4c0227,0xd138013e,0x80b8012d}},	//   klod_, wxaq, охт_, ्दले, 
   {{0x6720063f,0x200cee9b,0x43940826,0x7f4c00cf}},	//   _kpoj, ügi_, _найс, txaq, 
   {{0xe3bc2760,0xa3ac00af,0xa8000790,0x2ca4005c}},	// [14c50] meño_, _करि_, çıyo, dlod_, 
   {{0xe3bc2d86,0xa01801b8,0x386c0489,0x2ca403cb}},	//   leño_, _omög, zher_, elod_, 
   {{0x2ca43c02,0xa018d802,0x6f140419,0x00000000}},	//   flod_, _sjöu, atyc, --, 
   {{0xa3ac2d6c,0x6fd802ab,0x386c0240,0xe3bc0165}},	//   _करा_, युदं, xher_, neño_, 
   {{0x7d000436,0x386c05d1,0x5274029e,0xb7e800cc}},	//   _bárð, vher_, _رایز, _গালত_, 
   {{0x386c010b,0x9ad0063f,0x00000000,0x00000000}},	//   wher_, lịkw, --, --, 
   {{0x386c0052,0x67200241,0xe3bc0789,0x8d8409a5}},	//   ther_, _apoj, keño_, _жутд, 
   {{0xe3bc0789,0x9ad002e3,0xbb4402dd,0x59c4000d}},	//   jeño_, nịkw, _ﺘﻠﻙ_, _ललकर, 
   {{0x386c0639,0xe3bcee9c,0x3a74ee9d,0x77840276}},	//   rher_, deño_, _елар, ялиз, 
   {{0x7ae8ee9e,0x386cee9f,0x9ad00521,0xdb1801df}},	//   _iwet, sher_, hịkw, _aguç, 
   {{0x7ae8eea0,0x386ceea1,0x188800cf,0x6720013a}},	//   _hwet, pher_, _ксдп_, _epoj, 
   {{0x7ae8eea2,0x6f14033f,0x656c0e89,0x38a01427}},	//   _kwet, ytyc, ùbha, tóru_, 
   {{0x87042966,0x7bc801f7,0x7ae8eea3,0x888c008f}},	//   _قبول, _mgeu, _jwet, _דראַ, 
   {{0x7ae8eea4,0x46c81d8a,0x6d580248,0x00000000}},	//   _mwet, रदरह, _àtag, --, 
   {{0x7ae82747,0xa01801b8,0x2164eea5,0xe3bc04d4}},	//   _lwet, _omöd, пири_, beño_, 
   {{0x7bc81dd4,0x7ae8eea6,0xe3bc0407,0x6a64032e}},	//   _ngeu, _owet, ceño_, _aðfl, 
   {{0x7ae805db,0x387c0175,0xaf040064,0x00000000}},	// [14c60] _nwet, _mmwr_, япал, --, 
   {{0x7bc80438,0x3884005f,0xa0189632,0x6f14eea7}},	//   _ageu, mēru_, _sjöt, rtyc, 
   {{0x6f14006d,0x7ae813ab,0xdd8c0451,0x00000000}},	//   styc, _awet, ٿون_, --, 
   {{0x7ae82252,0x6f14eea8,0x2bb810fa,0x00000000}},	//   _bwet, ptyc, ेशला, --, 
   {{0x2ca46c17,0x35740092,0xa01826bc,0x00000000}},	//   rlod_, ችልበት_, _smög, --, 
   {{0x7ae8eea9,0x5a30eeaa,0xa3ac007d,0xa01802d2}},	//   _dwet, еншт, _करस_, _fjös, 
   {{0x6720abea,0x7ae83e5e,0x7bc800a3,0x2ca4014f}},	//   _spoj, _ewet, _fgeu, plod_, 
   {{0xdca01cc9,0x7ae8007f,0xa0180008,0xe3bceeab}},	//   _заси, _fwet, _hjör, xeño_, 
   {{0x7ae8eeac,0x387c0618,0xa018008c,0x7c64eead}},	//   _gwet, _dmwr_, _kjör, _غافل, 
   {{0x67200427,0x7bc80342,0x37a88083,0x00000000}},	//   _vpoj, ğmuş, өтөн_, --, 
   {{0x7ae8eeae,0x7afc3be7,0xe3bc04d4,0x7bc81b0d}},	//   _zwet, _åstr, teño_, şmuş, 
   {{0xefcc0020,0xb38802d3,0x7ae800d7,0x388400ef}},	//   _እንዴ_, _ዘሕዝን_, _ywet, fēru_, 
   {{0xf7481564,0xe3bc0bf2,0x97a00798,0x073400d4}},	//   _وجهه_, reño_, _пршл, _целю, 
   {{0xe3bc28f2,0x7afc00b5,0xddc4033f,0xa018032e}},	//   seño_, _æste, _dojś, _njör, 
   {{0xe3bc30cf,0xceb400ac,0x9ad0063f,0xc10401f7}},	//   peño_, ktəb_, tịkw, ظوري, 
   {{0x7e640175,0x388400ef,0x00000000,0x00000000}},	//   wkhp, bēru_, --, --, 
   {{0xa018eeaf,0x443800f1,0x3ed800c6,0x9ad001f2}},	// [14c70] _björ, mds_, زواج_, rịkw, 
   {{0x7bc80013,0x4438eeb0,0x7ae8eeb1,0x9ad002e3}},	//   _sgeu, lds_, _rwet, sịkw, 
   {{0x4438eeb2,0x7ae8eeb3,0x6fa00490,0xa01808a5}},	//   ods_, _swet, _कुठू, _djör, 
   {{0x4438eeb4,0x7ae8eeb5,0x8d84009d,0x00000000}},	//   nds_, _pwet, хууд, --, 
   {{0xa0180008,0x00000000,0x00000000,0x00000000}},	//   _fjör, --, --, --, 
   {{0xa0180008,0xefcc0023,0x1b1c00cc,0x0b946ea9}},	//   _gjör, _እንዶ_, পিলে_, رجند, 
   {{0x7bc807c5,0x7ae800b5,0xdfa801b9,0x443800b5}},	//   _tgeu, _wwet, _خطگه_, kds_, 
   {{0xefcc2295,0x4438eeb6,0x7ae8eeb7,0x7bc8009f}},	//   _እንደ_, jds_, _twet, _ugeu, 
   {{0x44382c18,0x7ae859fc,0xbb8411f0,0xfb14007b}},	//   dds_, _uwet, _غلطي, _زواج, 
   {{0x4438eeb8,0xa68009a5,0x31340023,0xa3780254}},	//   eds_, клыд, _ብግብር, vaõp, 
   {{0xb5781c65,0x44380175,0xa01800a2,0x7c380210}},	//   ющих_, fds_, _mmöb, odwr, 
   {{0x7c38eeb9,0x5fbc66c0,0x00000000,0x00000000}},	//   ndwr, ्शाल, --, --, 
   {{0xd34800f9,0xe60ceeba,0x78a84cab,0xdb1800a2}},	//   سیده_, _ид_, mlev, _uguä, 
   {{0x4438eebb,0x42545788,0x09c000cc,0x25a8031c}},	//   ads_, нтст, _উভতা, żbla_, 
   {{0x78a8eebc,0x245804cc,0x44380051,0x38840171}},	//   olev, _tëmp_, bds_, bērt_, 
   {{0x388400de,0xa01801e3,0x04940153,0x00000000}},	//   mērs_, _sjör, _прыў, --, 
   {{0xaec41b6b,0x78a86fc4,0x7c380042,0x714000db}},	// [14c80] дбал, ilev, ddwr, رۉڭۅ, 
   {{0x78a8eebd,0xe28000c7,0x52b40137,0x6fdc0027}},	//   hlev, _альи, _سەزئ, _फ्रं, 
   {{0x78a8cdc8,0x00000000,0x00000000,0x00000000}},	//   klev, --, --, --, 
   {{0x78a8012c,0x2bb0033f,0x00000000,0x00000000}},	//   jlev, _जरदा, --, --, 
   {{0x78a8eebe,0xa018e4c3,0x35880092,0x529c002b}},	//   dlev, _tjör, ኖሩበት_, _ṛṣir, 
   {{0x78a8eebf,0x7c38015d,0x5a3000d4,0x00000000}},	//   elev, adwr, кніт, --, 
   {{0xddc0eec0,0xefcc069c,0x4438eec1,0x78a8009f}},	//   _абри, _እንዳ_, yds_, flev, 
   {{0x78a8eec2,0x4734eec3,0xa3ac0037,0x5d78011a}},	//   glev, енис, _करल_, _ואלק, 
   {{0x3884005f,0x44380fac,0x262801c6,0x00000000}},	//   vērt_, vds_, оцно_, --, 
   {{0x4438eec4,0x78a84b35,0x44f8035b,0x38840171}},	//   wds_, alev, tĩ_, fērs_, 
   {{0x78a8eec5,0x69d80857,0xf8ac00ec,0x25780023}},	//   blev, _ifte, _ڏکي_, _ኣዕጋቢ_, 
   {{0x78a8127b,0x320402a8,0xca3800e4,0x443875c6}},	//   clev, _ɓoye_, _haĝ_, uds_, 
   {{0x44380c18,0x48f8012c,0x00000000,0x00000000}},	//   rds_, ैंको_, --, --, 
   {{0xd370425b,0x44380109,0xa13400f2,0x00000000}},	//   شۇپ_, sds_, ورزش, --, 
   {{0x6aa80368,0x56901367,0x44380051,0x51840395}},	//   ilff, _шашт, pds_, вута, 
   {{0x70281b4b,0xbed8030d,0x00000000,0x00000000}},	//   _སྒྱུ_, здах_, --, --, 
   {{0x69d8eec6,0x7f941fce,0x00000000,0x00000000}},	// [14c90] _ofte, хаах, --, --, 
   {{0x78a805c7,0xdda88404,0x7c38015d,0xcfb401f0}},	//   zlev, отел_, wdwr, тбуъ, 
   {{0x4f086923,0x78a80166,0xabb400c7,0x00000000}},	//   كتەپ_, ylev, ҭахә, --, 
   {{0x1ddceec7,0x69d8eec8,0xbb9400a7,0x78a801f5}},	//   _प्रत, _afte, наещ, xlev, 
   {{0x78a800fd,0x4fc4eec9,0x9c1000b4,0x7028031c}},	//   vlev, _асра, họgh, _སྒྲུ_, 
   {{0xdcf80502,0x9c1001f2,0x00000000,0x00000000}},	//   _ورزش_, kọgh, --, --, 
   {{0xa9a007d6,0x78a8eeca,0xb7bc054e,0x656c08c2}},	//   лишд, tlev, meţi, ùbhl, 
   {{0x69d8eecb,0x78a84174,0xb7bc054e,0xeb3c0092}},	//   _efte, ulev, leţi, ተነጋገ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9964eecc,0xb7bc0311,0xf650007b,0xcb0801f7}},	//   _отел, neţi, ائة_, _آيلن_, 
   {{0x78a81511,0xfc3800df,0x998400bc,0xd83801c6}},	//   plev, _kaŭ_, menů_, _мэд_, 
   {{0xc864004e,0x36d40107,0xe8d4010f,0x00000000}},	//   _итчи, _зодр, _טוער_, --, 
   {{0x3ea0033d,0x81d8015b,0x7af80455,0x00000000}},	//   koht_, ারন_, nswt, --, 
   {{0xfc381a4c,0x9c1002e3,0xa018007c,0xa064035b}},	//   _laŭ_, bọgh, _sjöp, ҭара_, 
   {{0xe294eecd,0x02c40137,0xd34807d6,0x00000000}},	//   хар_, тирү, سیگه_, --, 
   {{0xfc38010f,0xa0a001c4,0x00000000,0x00000000}},	//   _naŭ_, гасд, --, --, 
   {{0xb7bc054e,0x6e443cc5,0x7fd402dd,0x63b0586a}},	// [14ca0] feţi, неаз, тісі, _бәрх, 
   {{0x1e8000ee,0x2d949cb8,0xb7bc0356,0x8cd406e3}},	//   глум, нрес, geţi, _बंदो, 
   {{0xfc3801e4,0x9e40022a,0xf40403d4,0xe7f000bc}},	//   _baŭ_, áďat, ষ্ণৰ_, घरमा_, 
   {{0xca380115,0xccb40022,0x00000000,0x00000000}},	//   _saĝ_, тәгь, --, --, 
   {{0x69d80334,0xcb3400a7,0x2ac40241,0x70bc190e}},	//   _pfte, телъ, _níbì_, ्दील, 
   {{0x9b401afc,0x9984013a,0x00000000,0x00000000}},	//   انوو, genů_, --, --, 
   {{0xdb200118,0x19340092,0x00000000,0x00000000}},	//   ěrák, _ኮሚሢዮ, --, --, 
   {{0x9d1806a9,0x98a00063,0x7b040205,0x00000000}},	//   _מולט, лије, üttü, --, 
   {{0xd1d40b82,0x998401ef,0x00000000,0x00000000}},	//   ራላት_, benů_, --, --, 
   {{0x9b9000c6,0x70bc0f90,0x69d802d0,0x69f00166}},	//   _إلكت, ्दुल, _ufte, _сүкт, 
   {{0x1a980a7c,0x44b441e5,0x00000000,0x00000000}},	//   _ציבע, кбос, --, --, 
   {{0x290c014a,0xd90c00e5,0x00000000,0x00000000}},	//   mufa_, _ایٹ_, --, --, 
   {{0x4e10038e,0x290cc8c9,0xb864eece,0x6a6402d2}},	//   ालाई_, lufa_, _جالو, _aðfi, 
   {{0x1ee400dd,0xb910002b,0x9c1002e3,0x00000000}},	//   ہوری_, _ajaṃ_, pọgh, --, 
   {{0xe4a478cd,0xe29c008c,0x290c0c09,0xb7bc0311}},	//   _прио, nuði_, nufa_, veţi, 
   {{0xd4980953,0x4384007b,0x1ee4179e,0xa6a80244}},	//   _пры_, _للعق, فوری_, _باڵق_, 
   {{0x9e049803,0x20040724,0x290c0e78,0xe3bc005a}},	// [14cb0] ечел, ğni_, hufa_, keñi_, 
   {{0x290ce4d9,0x4fc401c0,0x73340145,0x753c0210}},	//   kufa_, усса, _شىپا, łsze, 
   {{0x62840c98,0x645c009a,0xb7bc0311,0x3ea00200}},	//   mijo, _koqi, reţi, roht_, 
   {{0x6284eecf,0x3ea04abe,0xdef801c6,0xb7bc054e}},	//   lijo, soht_, _ныг_, seţi, 
   {{0x645c014f,0xb7bc054e,0x82340023,0x00000000}},	//   _moqi, peţi, _ብምሕሳ, --, 
   {{0x62846dac,0x290ceed0,0x645ceed1,0xc0dc02d3}},	//   nijo, fufa_, _loqi, ቕጻል_, 
   {{0x290c0eb4,0x38680198,0x0ba40032,0x00000000}},	//   gufa_, _ƴar_, кшәм, --, 
   {{0x6284eed2,0x00000000,0x00000000,0x00000000}},	//   hijo, --, --, --, 
   {{0x62844b2c,0x00000000,0x00000000,0x00000000}},	//   kijo, --, --, --, 
   {{0xada001f1,0x75442bb7,0xc70400c7,0x00000000}},	//   čúva, вноз, ыжьқ, --, 
   {{0x6284eed3,0x645c100f,0xc8b401d5,0xf8040166}},	//   dijo, _boqi, ضلیک, _җчҗн, 
   {{0xf650179e,0x00000000,0x00000000,0x00000000}},	//   ائک_, --, --, --, 
   {{0x62844a52,0x1b1c0154,0x00000000,0x00000000}},	//   fijo, পিকে_, --, --, 
   {{0x628402d5,0x3944004e,0xa2e01086,0x35a400c7}},	//   gijo, _krls_, рорд, _иалг, 
   {{0x78b80218,0x5fa401ad,0x53840092,0x00000000}},	//   _khwv, _कुबल, _የኦዲት_, --, 
   {{0x39440327,0x70540330,0x6ac800fe,0x00000000}},	//   _mrls_, خنرا, _ৰিছো, --, 
   {{0x6284eed4,0xef187694,0xb4ac547d,0xa3ac0037}},	// [14cc0] bijo, ьма_, कती_, _करए_, 
   {{0x62840006,0x645c009a,0xa2f40115,0x1dc01777}},	//   cijo, _zoqi, _שמיה_, _वृहत, 
   {{0x5fa40574,0x645c4667,0x39440fac,0xefb001d5}},	//   _कुठल, _yoqi, _nrls_, _چیزگ, 
   {{0xb50804fa,0x764c02a8,0x81d8015b,0xb7bc054e}},	//   _विनय_, _ɗaya, ারণ_, leţu, 
   {{0xabd00150,0xc0c00023,0x00000000,0x00000000}},	//   _ﯞﻻﻧﺎ, ድኻም_, --, --, 
   {{0x290ceed5,0x00000000,0x00000000,0x00000000}},	//   tufa_, --, --, --, 
   {{0x5bb001d2,0x3a24045a,0x291800e4,0x32d00150}},	//   лсәф, _dblp_, îpa_, _ﻛﻮﮔﻪ, 
   {{0x628402d5,0x290c003d,0xab2800f7,0x00000000}},	//   zijo, rufa_, _ооба_, --, 
   {{0x6284eed6,0x290c1bce,0xeac40024,0x81d800eb}},	//   yijo, sufa_, _абап, ারত_, 
   {{0xaa441c50,0x645ceed7,0x26c80267,0xdd8c01d3}},	//   _шезл, _soqi, öbo_, _اوہ_, 
   {{0xa9682e2e,0xb7bc084c,0x645c0194,0xd82c1142}},	//   _تمام_, deţu, _poqi, _кэ_, 
   {{0x70bc6f11,0x62840428,0x645c01d5,0x9f4801ef}},	//   ्दोल, wijo, _qoqi, _secí_, 
   {{0x6284eed8,0x764c01ed,0x7cf80241,0x9f480306}},	//   tijo, ányí, _kùrá, _pecí_, 
   {{0xc04c001f,0x645c009a,0x00000000,0x00000000}},	//   _አለመግ, _woqi, --, --, 
   {{0x6284eed9,0x9f4801f1,0x6d48a2ec,0x645c022e}},	//   rijo, _vecí_, åfal, _toqi, 
   {{0x6284eeda,0xc5f80421,0x88bc01ef,0x00000000}},	//   sijo, laē_, _spěj, --, 
   {{0x62844a52,0xd498eedb,0x7eb801a9,0x8d74030f}},	// [14cd0] pijo, _שכחת_, егас_, یاما, 
   {{0xa3dc0316,0xb0600037,0x5d64010b,0x6284022e}},	//   दुर_, äära, ктез, qijo, 
   {{0xc04c2295,0x5bc80aa2,0x7874eedc,0x6578002f}},	//   _አገልግ, िश्व, _háve, nzth, 
   {{0x9f480589,0xd5740375,0x8cb80014,0x00000000}},	//   _cecã_, כתבה_, ندنس_, --, 
   {{0x78740789,0x81d803d4,0xb96401e1,0xabb400c7}},	//   _jáve, াৰণ_, _omìí, гацә, 
   {{0x394400a3,0xb0d0023e,0xdeb00150,0x00000000}},	//   _prls_, _दूँग, _тұзы, --, 
   {{0xb6a41638,0xb8140055,0x9b4000e5,0x00000000}},	//   ғинл, _aṭat, انڈو, --, 
   {{0x81d803f4,0xf8a8eedd,0xfcc400d1,0xe94465dc}},	//   ারি_, رگاه_, _сәзм, اروی, 
   {{0xe29c0008,0x0c849adc,0x78740306,0xb6a4084c}},	//   luðu_, _тырм, _náve, лиил, 
   {{0x9c10063f,0x81d80183,0x00000000,0x00000000}},	//   bọch, াৰত_, --, --, 
   {{0x81d800bd,0xe29c01a8,0xb0d0033f,0x394402b7}},	//   ারা_, nuðu_, _दूंग, _urls_, 
   {{0xa3dc2ba2,0xb4ac2c33,0x00000000,0x00000000}},	//   दुल_, कते_, --, --, 
   {{0xf1d001e0,0x82340023,0x00000000,0x00000000}},	//   йөнө, _ብምምሳ, --, --, 
   {{0x70bc02ab,0x787400bc,0xa6e000ec,0x942400db}},	//   ्द्ल, _dáve, _اڻيه, دوڭۇ, 
   {{0xb7bc0311,0x386c0afa,0x53e400d1,0x00000000}},	//   reţu, oker_, _ﺋﯩﭽﻜ, --, 
   {{0xdfcc0302,0x179002d3,0x0594010a,0xe29c08a5}},	//   كيف_, _ዝስዕቡ_, _тăсм, duðu_, 
   {{0x386c08f7,0xee24b071,0x78740798,0x09cc00eb}},	// [14ce0] iker_, лмап, _gáve, রুপা, 
   {{0x386c000d,0xa01808a5,0x64480248,0xd2500244}},	//   hker_, _umön, _ògir, _بۆس_, 
   {{0x386ceede,0x787401a2,0xfe140037,0x61280092}},	//   kker_, _záve, _ढारस_, _ስልቶች, 
   {{0xeb982f33,0x386c0936,0xe3bc030a,0xac742586}},	//   ние_, jker_, reñv_, دائش, 
   {{0xab60eedf,0x386c00b5,0x9c1001f2,0x09cc01bc}},	//   _şübh, dker_, wọch, ाश्य, 
   {{0x386ceee0,0xada409a5,0x6da40d34,0xcfdc0150}},	//   eker_, _багл, _бига, _ﺃﻏﻠﺒ, 
   {{0xd6d40efb,0x14cc0574,0xdb1800c7,0x386c045f}},	//   қты_, _संगण, _iguý, fker_, 
   {{0x386ceee1,0xa3780120,0x4bc4eee2,0xe72c031c}},	//   gker_, lcõe, _көлг, _ཨརྱན_, 
   {{0x2ca44ddd,0xd50c02ea,0x1dd82e1e,0xe66401c0}},	//   mood_, vɛ́s, मुकत, гтно, 
   {{0x386ceee3,0x2ca4eee4,0xe4e40220,0x9c1002e3}},	//   aker_, lood_, лімн, pọch, 
   {{0x290802d2,0x00000000,0x00000000,0x00000000}},	//   _íba_, --, --, --, 
   {{0x2ca4eee5,0x386ceee6,0x291c0113,0xd83400ee}},	//   nood_, cker_, _iqta_, _бэш_, 
   {{0x657800dd,0x81d8015b,0x00000000,0x00000000}},	//   szth, ারস_, --, --, 
   {{0x2ca4eee7,0xdec00020,0x42a46518,0xdb180051}},	//   hood_, ቻችን_, румғ, _nguý, 
   {{0x2ca4cd75,0xd50c0085,0x9f4800db,0x69cc09a9}},	//   kood_, pɛ́s, _secà_, _úbed, 
   {{0x26cc08f5,0xdb18035b,0x9c1001f2,0x78740174}},	//   _hifo_, _aguý, kọah, _táve, 
   {{0x26cceee8,0x4428eee9,0x2ca4eeea,0x2284eeeb}},	// [14cf0] _kifo_, _iba_, dood_, _бунг, 
   {{0xdd98eeec,0xc2100014,0xe29c01a8,0x26cc058a}},	//   нше_, _بٔد_, tuðu_, _jifo_, 
   {{0x4428eeed,0x386ceeee,0xbc1801ce,0xe3bc005a}},	//   _kba_, yker_, вілі_, reñu_, 
   {{0x2ca4eeef,0x4428033b,0x23b801e1,0x26cc0042}},	//   good_, _jba_, _gàjí_, _lifo_, 
   {{0x4428eef0,0x291ceef1,0xdfa800f1,0x09cc0154}},	//   _mba_, _aqta_, _سطحه_, রুমা, 
   {{0x61f401f9,0x26cceef2,0x386c0afa,0xada00419}},	//   _jexl, _nifo_, wker_, čúra, 
   {{0x4428eef3,0x386c0086,0x60cc05a1,0xe6dc02e3}},	//   _oba_, tker_, _kicm, _rịọ_, 
   {{0x786404a9,0x26cc0618,0x248800f3,0x4428eef4}},	//   ркиз, _aifo_, jicm_, _nba_, 
   {{0x26cceef5,0x60cc020c,0x37742477,0x23c466c0}},	//   _bifo_, _micm, рыйс, रेमद, 
   {{0x386ceef6,0xa018032e,0x00000000,0x00000000}},	//   sker_, _smöl, --, --, 
   {{0x4428eef7,0x25ac0142,0xc9840c17,0x00000000}},	//   _bba_, _cyfl_, _луци, --, 
   {{0x4428eef8,0x26cc0093,0x60cc012c,0x7c28031c}},	//   _cba_, _eifo_, _nicm, _jber, 
   {{0x7c2866af,0x26cc0248,0x61f40522,0x4428045a}},	//   _mber, _fifo_, _bexl, _dba_, 
   {{0x4428eef9,0x60cc00c6,0xd378033f,0x60d40139}},	//   _eba_, _aicm, ąć_, _buxm, 
   {{0x7c28eefa,0xa184035b,0x44282679,0x78740165}},	//   _ober, абра_, _fba_, _gávc, 
   {{0x44280570,0x60cc9fab,0x2ca40014,0x26cc4b2a}},	//   _gba_, _cicm, xood_, _zifo_, 
   {{0x60cc01a6,0xceb400ac,0x45340014,0x7640017a}},	// [14d00] _dicm, stəm_, _نى۪ر, odly, 
   {{0x60cc011c,0x26cc02b9,0x7640eefb,0x7afc08fb}},	//   _eicm, _xifo_, ndly, _åsty, 
   {{0x2ca4eefc,0x7c280083,0x6be4007b,0xf1b80118}},	//   tood_, _bber, لكام, _इरिन, 
   {{0x7c28009a,0x60cc011f,0xfca8004b,0x1d0455c3}},	//   _cber, _gicm, هانو_, реци_, 
   {{0x2ca4eefd,0xa018049f,0x7c28eefe,0x7c440306}},	//   rood_, _omöj, _dber, _štrú, 
   {{0x7c28acac,0x2ca4eeff,0x60d40166,0xf1b8013a}},	//   _eber, sood_, _yuxm, _इरान, 
   {{0x26ccef00,0x2ca400c5,0xe2a40ad9,0x76400042}},	//   _rifo_, pood_, úðir_, ddly, 
   {{0x26cc124c,0xec146112,0x7c280cad,0x76401829}},	//   _sifo_, _خورد, _gber, edly, 
   {{0x29003266,0x26ccef01,0x76400175,0x98700212}},	//   _ākau_, _pifo_, fdly, ільц, 
   {{0x4428ef02,0x7c28ef03,0xe5c4ef04,0xe664ef05}},	//   _sba_, _zber, исно, ртио, 
   {{0x44288c70,0xa2b4038e,0x26cc0451,0x7c44022c}},	//   _pba_, ोगस्, _vifo_, _átrú, 
   {{0xca74e17f,0x7c280ac5,0x4428020c,0x60d40009}},	//   _туғы, _xber, _qba_, _ruxm, 
   {{0x26ccef06,0x4428ef07,0x2b440165,0xfd5c0023}},	//   _tifo_, _vba_, nvoc_, _ተዋስኦ_, 
   {{0x248805be,0xe29c0162,0x62300022,0x787400e5}},	//   sicm_, vuðs_, цҵоу, _távc, 
   {{0x78740252,0x9294cffc,0x442823bd,0x00000000}},	//   _háva, царц, _tba_, --, 
   {{0x4428ef08,0x38a00034,0x787420d2,0x00000000}},	//   _uba_, wórz_, _káva, --, 
   {{0xe2a87611,0x5fa40882,0x60cc01e4,0x7c280139}},	// [14d10] _لادن_, _कुशल, _vicm, _rber, 
   {{0x7c28172e,0xe45c049f,0x7874035b,0x3aec0241}},	//   _sber, ljö_, _máva, _lópò_, 
   {{0x60cc058a,0x40342fc3,0xdb180051,0x00000000}},	//   _ticm, _ленс, _nguò, --, 
   {{0x88bc012c,0x6fa0982f,0x5c04005b,0x7f940672}},	//   _zpěv, _कुकू, ряжа, _гамх, 
   {{0xbb440251,0x7c286a89,0x78740216,0x291801ab}},	//   селк, _vber, _náva, àpan_, 
   {{0x5338008f,0x00000000,0x00000000,0x00000000}},	//   ינדן_, --, --, --, 
   {{0x303804d3,0xaa540640,0x7c280135,0x00000000}},	//   _شتێک_, сију_, _tber, --, 
   {{0x78740561,0x1e500020,0xd198011a,0x76400142}},	//   _báva, _ለማጠና, יכוי_, wdly, 
   {{0xbb840597,0x9ba01e87,0x290c01ab,0xa6e001ec}},	//   _الذي, _بەشى, arfa_, пжыл, 
   {{0x78740232,0x7ae8004b,0x152401b9,0x00000000}},	//   _dáva, _لوړې_, аноқ_, --, 
   {{0x35a4ef09,0x9f580240,0xd91800c7,0x31340023}},	//   санг, faqë_, _шьа_, _ብፍቕር, 
   {{0x76b83f6e,0x753c012d,0x88bc01ef,0x00000000}},	//   _өлер_, łszo, _spěv, --, 
   {{0x78740174,0x00000000,0x00000000,0x00000000}},	//   _gáva, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x78740232,0x3e30001f,0xceb400ac,0x25a80308}},	//   _záva, _አማካይ, stək_, čilé_, 
   {{0x0fe82b8d,0x64a000d4,0x40780108,0x00000000}},	//   рлақ_, _наща, ащую_, --, 
   {{0xb8f80135,0x200c1315,0x00000000,0x00000000}},	// [14d20] _འང_, ógia_, --, --, 
   {{0x78a80196,0xe29c0008,0xada4010b,0x6da41d39}},	//   hoev, yrði_, базл, биза, 
   {{0xa3dce079,0x7168ef0a,0xab600790,0x61d4010f}},	//   दुक_, _санг_, ğüml, _לויף_, 
   {{0xdb1800e4,0x78a80cf4,0x6da402dd,0x7c640131}},	//   _aguñ, joev, _ғиба, يانل, 
   {{0x78a8ef0b,0x3aec01e1,0xdca0119e,0x00000000}},	//   doev, _rópò_, чаци, --, 
   {{0xdee0ef0c,0x6f14ef0d,0x92cc0183,0x7874089f}},	//   _хори, muyc, ৱীৰ_, _ráva, 
   {{0xb508447d,0x88bc00bc,0x3eac00e4,0x290c03e0}},	//   _विषय_, _opět, _êeta_, urfa_, 
   {{0xe45c049f,0x78a8ef0e,0x7874089f,0x290c025c}},	//   xjö_, goev, _páva, rrfa_, 
   {{0xa018032e,0x3f840210,0x00000000,0x00000000}},	//   _smök, _śluz_, --, --, 
   {{0x8c44084c,0x16d400ae,0x00000000,0x00000000}},	//   ăşur, حذية_, --, --, 
   {{0xd7ecef0f,0xa968ef10,0x6f140784,0x6aa80042}},	//   _ну_, _حمام_, huyc, moff, 
   {{0x6aa8ef11,0x75c86f78,0x6f1403f0,0x78740588}},	//   loff, штың_, kuyc, _táva, 
   {{0x7c7c0092,0x00000000,0x00000000,0x00000000}},	//   _ጨምሯል_, --, --, --, 
   {{0xe45c01e6,0x1718008f,0x09cc00eb,0x00000000}},	//   sjö_, _עווע, _র্যা, --, 
   {{0x2250004d,0x787402f0,0x84c40352,0x00000000}},	//   _vnxk_, _mávn, _мәмд, --, 
   {{0x4394ef12,0xb9d0069c,0x6aa8ef13,0x81d8015b}},	//   _майс, _ድዩ_, hoff, ারই_, 
   {{0x6aa8ef14,0x1ea805d9,0x555000db,0x7f94009d}},	// [14d30] koff, هائي_, _وپۇر, цаах, 
   {{0x88bc012c,0x7afcef15,0x78740306,0x6aa80036}},	//   _zpět, _æsti, _návn, joff, 
   {{0xe2a801ed,0xe2a40321,0x78a8022e,0xbfd4007b}},	//   _لاگن_, úður_, yoev, _ويدع, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6aa8ef16,0xdef8010b,0x78a8ef17,0x5ee000eb}},	//   foff, _щын_, voev, _পিকে, 
   {{0x6aa8ef18,0xb50861ef,0x6fa00073,0x00000000}},	//   goff, _विलय_, _कुटू, --, 
   {{0x78a8ef19,0x78740122,0xbd4442f4,0x00000000}},	//   toev, _dávn, _بنزي, --, 
   {{0x201800aa,0x00000000,0x00000000,0x00000000}},	//   ngqi_, --, --, --, 
   {{0x78a8282c,0x6aa88786,0xf7440f06,0x00000000}},	//   roev, boff, цепо, --, 
   {{0x6aa8ef1a,0x7ae8ef1b,0x78a8035a,0xf504005a}},	//   coff, _itet, soev, озоо, 
   {{0x7ae8009b,0x00000000,0x00000000,0x00000000}},	//   _htet, --, --, --, 
   {{0x36d40107,0x6f140113,0xf7740166,0x3754ef1c}},	//   _додр, yuyc, _мулю, _وپاس, 
   {{0x656c00a3,0x398c0092,0x00000000,0x00000000}},	//   ùbhr, _እንጦጦ_, --, --, 
   {{0xd620081f,0x7ae8ef1d,0x78740122,0x200c022c}},	//   _འཁྲབ_, _mtet, _kávo, ógin_, 
   {{0xe294ef1e,0xe45c005b,0x00000000,0x00000000}},	//   цар_, mmön_, --, --, 
   {{0x7ae8ef1f,0xed5800f2,0xe45c0847,0x00000000}},	//   _otet, یشات_, lmön_, --, 
   {{0x6aa8ef20,0x7ae8ef21,0x787402fb,0x8e08010b}},	// [14d40] yoff, _ntet, _lávo, ймаң_, 
   {{0x6aa804ce,0xab600790,0xdd8c00ec,0xf1dc0303}},	//   xoff, şükl, ھون_, _मलिन, 
   {{0x7ae8ef22,0x787403c6,0xdd8cef23,0xad9800a2}},	//   _atet, _návo, پون_, _meºg, 
   {{0x61400316,0x6aa8010a,0x7ae80175,0x6598010f}},	//   sílá, woff, _btet, ביעק, 
   {{0x6aa8ef24,0xeb98ef25,0x88bc00bc,0x89d80451}},	//   toff, шид_, _opěr, ٽوبر_, 
   {{0xfe780153,0x00000000,0x00000000,0x00000000}},	//   _лёсы_, --, --, --, 
   {{0x7ae8ef26,0x1d04228e,0x00000000,0x00000000}},	//   _etet, _мери_, --, --, 
   {{0x6aa82611,0x6d4cef27,0x58d00801,0xc6f8b834}},	//   soff, _irba, мощт, бних_, 
   {{0x6aa8ef28,0x97a001c0,0x6d4c1eff,0x54e001ec}},	//   poff, дрэл, _hrba, _ﺍﻟﺨﺼ, 
   {{0x6d4cb9b7,0x70c401ad,0xcd5c0023,0x63a801bf}},	//   _krba, लगुल, _ሰሚዕና_, _øgni, 
   {{0x6b8005d5,0x00000000,0x00000000,0x00000000}},	//   lzog, --, --, --, 
   {{0x442c00ee,0x7ae800e4,0xbb700228,0x36440116}},	//   ýe_, _ytet, _تۇۇع, قىۋې, 
   {{0x6b80ef29,0x27e402bd,0x78740316,0x53442386}},	//   nzog, _ifon_, _závo, мхра, 
   {{0x6b80004c,0xe29c01a8,0xd6ccef2a,0xd6240114}},	//   izog, yrðu_, _іт_, _доље_, 
   {{0x6f040427,0x6b806144,0x91485016,0xd5ac2b2e}},	//   _avkc, hzog, очта_, _цс_, 
   {{0xd13000aa,0x787402fb,0x00000000,0x00000000}},	//   کمې_, _návl, --, --, 
   {{0x3ed4ef2b,0x752c2625,0xfe7406ed,0x6d5c0175}},	// [14d50] سقار, _ćazi, плаќ, expa, 
   {{0x6b8000d7,0x2ee400ae,0x57bc00d1,0x00000000}},	//   dzog, íofa_, ﮬﺮﯨﺮ, --, 
   {{0x66080036,0x27e4007f,0x443800d8,0x00000000}},	//   _mdfk, _ofon_, oes_, --, 
   {{0x7ae80129,0x00000000,0x00000000,0x00000000}},	//   _ptet, --, --, --, 
   {{0x4438ef2c,0x44f800e4,0xddc40064,0x3058011a}},	//   ies_, hũ_, _kojū, _הדרד, 
   {{0x44387d6a,0x27e400a9,0x81d80154,0x44f800e4}},	//   hes_, _afon_, ারক_, kũ_, 
   {{0x6d4c1225,0x9f480048,0xf40400fe,0x00000000}},	//   _grba, _necú_, ষ্টৰ_, --, 
   {{0x4438ef2d,0xdb380214,0x00000000,0x00000000}},	//   jes_, _پسرش_, --, --, 
   {{0x7ae805d9,0x3e40001f,0x00000000,0x00000000}},	//   _utet, _የማድረ, --, --, 
   {{0x7874ef2e,0xb65807d8,0x27e40ca8,0xdac40131}},	//   _távo, сших_, _efon_, _بېتى_, 
   {{0x7d04ef2f,0x649c00bc,0x27e403cb,0x20d82c30}},	//   nshs, zšiř, _ffon_, _मूलध, 
   {{0x4438ef30,0x7c384036,0x64480aab,0xd88400ec}},	//   ges_, newr, _ógil, _گھڻن_, 
   {{0xe72c0953,0xe60c54fa,0x232401f0,0x00000000}},	//   _яе_, _пд_, пояи_, --, 
   {{0x443800e4,0xe874030c,0x7afc8c89,0xe4d401e2}},	//   aes_, _ونەگ, _æstu, _کويت_, 
   {{0x6b8000a7,0x95c8b1d0,0x59c8726b,0x30740064}},	//   zzog, _туда_, ाधिर, пуас, 
   {{0x44384e9c,0x73040861,0x9ccc02dd,0x00000000}},	//   ces_, _епиз, _ﺑﺎﻻﻋ, --, 
   {{0x6d4c58af,0x93c801d9,0xa064189d,0xfc7c0241}},	// [14d60] _srba, _باغہ_, чата_, _àáyá_, 
   {{0x59c808ec,0xddc4003e,0xada4ef31,0x6da4119e}},	//   ाधार, _gojū, пазл, пиза, 
   {{0x82e8031c,0x61d8011a,0xafe401a9,0x00000000}},	//   _འཕོའ, _לקיד, _нонл, --, 
   {{0x6d4c597f,0x2c7c026c,0x6b80ef32,0xdca0ef33}},	//   _vrba, _oïde_, tzog, нахи, 
   {{0xa018014a,0x25800241,0x7c641291,0x00000000}},	//   _blöf, _kélé_, بالل, --, 
   {{0x4438ef34,0x6b80ef35,0x6d5c0bc9,0xed580b3b}},	//   zes_, rzog, pxpa, _лог_, 
   {{0x4438ef36,0x61e0002d,0x81d800fe,0xdd84009b}},	//   yes_, _ûnle, াৰক_, _ебрд_, 
   {{0x4438ef37,0x1cb8025c,0x2580ef38,0x98c00032}},	//   xes_, _ངེར_, _lélé_, нсыл, 
   {{0x4438ef39,0xdca0022e,0x00000000,0x00000000}},	//   ves_, _чати, --, --, 
   {{0x4438ef3a,0xd7ec00cf,0x44f800e4,0xdb78011a}},	//   wes_, _ەكن_, tũ_, _הנמכ, 
   {{0x388803b2,0x00000000,0x00000000,0x00000000}},	//   ðurá_, --, --, --, 
   {{0x6fbc189a,0x43946b01,0x44f8ef3b,0x27f000a2}},	//   ्धां, дамс, rũ_, _ýyn_, 
   {{0xf8a8004b,0x23c40c4c,0xddc40024,0x44f800e4}},	//   _بدله_, रेंद, _pojū, sũ_, 
   {{0x7c38012d,0x00000000,0x00000000,0x00000000}},	//   zewr, --, --, --, 
   {{0x4438ef3c,0x25800cad,0x200824a6,0x53440124}},	//   pes_, _délé_, _pdci_, _ҧхьа, 
   {{0x4438ef3d,0x69d80175,0xcfc400d1,0x00000000}},	//   qes_, _lgte, ﯩﯟﺍﺗ, --, 
   {{0x357c044e,0x00000000,0x00000000,0x00000000}},	// [14d70] _ኣቦታት_, --, --, --, 
   {{0x2244002d,0x258001e1,0x7d04009a,0xdbf49f23}},	//   _ûnk_, _gélé_, tshs, ुण्ड_, 
   {{0x810800aa,0x24e402dd,0x7eb00022,0x00000000}},	//   _برخې_, _ﺍﻟﻪﻣ, ẽpor, --, 
   {{0x69d80591,0x81d8015b,0xde44004b,0x0c8400c7}},	//   _agte, ারও_, _ډیرو_, нычм, 
   {{0x7c381730,0xdb1801fb,0x6d48143a,0x54e002dd}},	//   rewr, _nguô, åfar, _ﺍﻟﺤﺼ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7c384671,0x7f4c41ec,0x3c94005b,0xa964054d}},	//   pewr, lvaq, _живё, дища_, 
   {{0x69d80591,0x6d5801a6,0x787400e5,0x00000000}},	//   _egte, _štag, _távm, --, 
   {{0x6e28006a,0x373800d4,0x36c4004e,0x00000000}},	//   _âmbë, ічию_, мбиг, --, 
   {{0x9964084c,0x0b88010b,0xa0183720,0x00000000}},	//   _нтел, _эсси_, _flög, --, 
   {{0xa018ef3e,0x2580007f,0xfbe0095f,0x8ca4012d}},	//   _glög, _rélé_, _फलाम, _कदमो, 
   {{0x950400dd,0xb9dc001f,0x2d7004a7,0xc20804ae}},	//   _ہفتے_, _ብላ_, _uđeš_, _כה_, 
   {{0xf7447d11,0xae1c21bd,0x7874022a,0x00000000}},	//   _цело, _पालन_, _lávk, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xafe40111,0xd5b8119e,0x00000000,0x00000000}},	//   добл, _усд_, --, --, 
   {{0x61400114,0x25540055,0x00000000,0x00000000}},	//   њета, _āpṛṣ, --, --, 
   {{0xe4c41c67,0xdfcc2781,0x2580ef3f,0x60200107}},	// [14d80] _تصوی, ليف_, _télé_, ъдта, 
   {{0xb88000bc,0x2d94dba2,0x7f880092,0x00000000}},	//   _šíle, мрес, _በጉራጌ_, --, 
   {{0xa0180634,0xceb403b9,0x00000000,0x00000000}},	//   _blöd, ftər_, --, --, 
   {{0x78740232,0x00000000,0x00000000,0x00000000}},	//   _dávk, --, --, --, 
   {{0x6d5801f1,0x7c644630,0xa01802d2,0x00000000}},	//   _štad, عامل, _slög, --, 
   {{0x6da4ef40,0x996400c0,0xa018032e,0xfe040139}},	//   _жига, _dėže_, _plög, _öçеn_, 
   {{0xa01801e6,0x6f14ef41,0xa8000205,0xa2b80677}},	//   _flöd, lryc, _çıkc, חמסט, 
   {{0xa0183683,0xc87803e3,0xc6f84c04,0x00000000}},	//   _glöd, _buğa_, пних_, --, 
   {{0x69d8011c,0x6f1400a9,0x61e40309,0x7c2c01e4}},	//   _tgte, nryc, ycjl, ĵart, 
   {{0x69d80548,0x779004fb,0xa95842b5,0x6a8401d5}},	//   _ugte, دیها, _وجار_, _ўлжа, 
   {{0x6d5801ed,0x6f1403cb,0x00000000,0x00000000}},	//   _átad, hryc, --, --, 
   {{0x6f140034,0xe3b001d9,0x00000000,0x00000000}},	//   kryc, ٖرس_, --, --, 
   {{0x888003e6,0x6f1400bc,0x0734ef42,0xc5a80014}},	//   _لیژن, jryc, _челю, تُھن_, 
   {{0x78ac4ca5,0x6f14ef43,0x00000000,0x00000000}},	//   čave, dryc, --, --, 
   {{0x4034ef44,0xd63001d9,0xe4a41b50,0x00000000}},	//   невс, _شِٹھ, _орио, --, 
   {{0xd4980139,0x6f140142,0x00000000,0x00000000}},	//   _оры_, fryc, --, --, 
   {{0x73c00cef,0x568001d9,0x7f4c0194,0x228400db}},	// [14d90] _бәре, _سۯێہ, uvaq, _жунг, 
   {{0x2a7c0333,0xa018007c,0x7f4cef45,0x00000000}},	//   _nltb_, _slöd, rvaq, --, 
   {{0xa01829ef,0xebc001e0,0xa184005b,0x00000000}},	//   _plöd, ғәтн, _цыпл, --, 
   {{0x6f140034,0x2a7c0334,0xdef800ee,0xcb680753}},	//   bryc, _altb_, _мыг_, ژمنه_, 
   {{0xceb40213,0x5fa4012d,0x0ae800f1,0x1dac000d}},	//   rtər_, _कुचल, وروي_, _जुरत, 
   {{0xceb400ac,0xab24074d,0x539c05d0,0xaa440114}},	//   stər_, хоша_, חידו, епша_, 
   {{0xc878013d,0x37e400cf,0x00000000,0x00000000}},	//   _suğa_, нойг, --, --, 
   {{0x3948008f,0xcd840150,0x78740f91,0x00000000}},	//   ĉas_, _جۇمۋ, _kávi, --, 
   {{0x4bb4e48e,0x6d58ef46,0x00000000,0x00000000}},	//   _айтс, _àtar, --, --, 
   {{0x2a7c01c4,0xab600205,0x00000000,0x00000000}},	//   _gltb_, ğütl, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x394428b5,0x7874765a,0x7374009d,0x00000000}},	//   _hsls_, _návi, хынх, --, 
   {{0x437402bf,0x98140133,0xe6404c79,0x00000000}},	//   туют, _ربڵا, _бешп, --, 
   {{0x21a04cd0,0x1dac012d,0x4f8400e5,0x00000000}},	//   гирм, _जुलत, ھارہ, --, 
   {{0x6f14ef47,0xa018049f,0x2c7c00cf,0xa064ef48}},	//   tryc, _smör, _oïda_, наса_, 
   {{0xaec41614,0xef182e01,0x1fa4189d,0x78740005}},	// [14da0] ебал, яма_, екти_, _cávi, 
   {{0x7874ef49,0x6e44107f,0x80c02b1b,0xb640037e}},	//   _dávi, عنام, _শূদ্, _ｍｐ_, 
   {{0x2c7c004e,0x6d58ef4a,0x00000000,0x00000000}},	//   _aïda_, _štab, --, --, 
   {{0x2a7c07a8,0xab2802f4,0x1be48ab1,0x787409e8}},	//   _sltb_, зода_, едци_, _fávi, 
   {{0x787403b2,0xdc0400db,0xcee8009f,0x20bc3337}},	//   _gávi, رقوو_, _آڱرن_, ्षरध, 
   {{0x6df4007b,0x00000000,0x00000000,0x00000000}},	//   _سكرا, --, --, --, 
   {{0x1888069c,0x78740232,0x6da4209b,0x4ee800cc}},	//   _ንህዝቢ_, _závi, _чива, _পিয়ল, 
   {{0x6da407d6,0xdd8c866a,0x602400b0,0x9f58011f}},	//   _жиҳа, _طوق_, _tūmō, laqá_, 
   {{0xab6005d1,0x200c00d7,0x00000000,0x00000000}},	//   ğüsl, ógii_, --, --, 
   {{0x45d426c7,0x6e3c0455,0xa018002f,0x66e40107}},	//   копс, nepb, _klöc, _ҷода, 
   {{0xd82cef4b,0xf5480051,0x7c2c0241,0xae1c06b1}},	//   _йэ_, _cấ_, _únrì, _पाईन_, 
   {{0x66e40c60,0x78ac01a6,0xa34401c6,0x6e3c00a2}},	//   _зода, čavc, нэгл, hepb, 
   {{0xa6c81248,0x6e3c0432,0x00000000,0x00000000}},	//   _елда_, kepb, --, --, 
   {{0x6e3c010e,0x00000000,0x00000000,0x00000000}},	//   jepb, --, --, --, 
   {{0x51846179,0x787400d8,0x4fc401e0,0x9b2c01f3}},	//   гута, _sávi, ғста, _ሳይንቲ, 
   {{0xae1c0316,0x795802d3,0x78744eb4,0xd25000f1}},	//   _पाउन_, ቀሰባት, _pávi, ټنې_, 
   {{0x9870054e,0x9fe00eff,0x1ac802dd,0x00000000}},	// [14db0] lţă_, _ەۋرو, _ﺗﺮﯞﺑ, --, 
   {{0xa0180b70,0x00000000,0x00000000,0x00000000}},	//   _blöc, --, --, --, 
   {{0x98700262,0x00000000,0x00000000,0x00000000}},	//   nţă_, --, --, --, 
   {{0xfda40588,0x7b9803e6,0x6d5814b2,0x787401d3}},	//   ныҵҟ, وپاس_, _štac, _távi, 
   {{0xbb44721f,0x6e3c014f,0x8cf41884,0xfb841bf4}},	//   телк, bepb, نكەش, خدای, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa0180112,0xaa540114,0x2d24014b,0x00000000}},	//   _glöc, тију_, _иятҳ, --, 
   {{0xf5480051,0xe8500116,0x00000000,0x00000000}},	//   _rấ_, لنىد, --, --, 
   {{0xb6a4084c,0x3f8805d5,0xab608af8,0xfaa801c8}},	//   киил, nzau_, şürl, _قهري_, 
   {{0x66c40174,0x00000000,0x00000000,0x00000000}},	//   yðke, --, --, --, 
   {{0x35a4af8e,0x857801ca,0xe5040451,0x00000000}},	//   танг, есят_, نڊيو_, --, 
   {{0x13a800f2,0x00000000,0x00000000,0x00000000}},	//   فنجی_, --, --, --, 
   {{0x98700276,0xf46c0023,0x98a4007f,0x24e40220}},	//   aţă_, _ትዛረብ_, ntnč_, _ﺍﻟﺼﻬ, 
   {{0x55c00131,0xe73421ee,0x00000000,0x00000000}},	//   _йалғ, _реш_, --, --, 
   {{0x998402d5,0x00000000,0x00000000,0x00000000}},	//   menų_, --, --, --, 
   {{0x4094399f,0x606000d1,0x99840153,0x00000000}},	//   грут, لۇپل, lenų_, --, 
   {{0x9c1001f2,0x2494143e,0x72c42db7,0x00000000}},	// [14dc0] họsh, _جنيد_, _ибиз, --, 
   {{0x91fc0327,0x00000000,0x00000000,0x00000000}},	//   _དབྲག_, --, --, --, 
   {{0x5ce00372,0x787403b2,0x0cdc033f,0xa2ac09fa}},	//   ۇكەل, _hávu, यदेम, ंकर्, 
   {{0xeb98ef4c,0xafe40bd6,0x74040055,0x4ea4030d}},	//   мие_, _шомл, _ṛgjā, ăрта, 
   {{0xb91000dc,0x6e3c28e9,0xbc241183,0xdae400f1}},	//   _imaṃ_, pepb, ارمى, نځلو_, 
   {{0x787402d2,0xdce80327,0x00000000,0x00000000}},	//   _mávu, żiġi, --, --, 
   {{0xa8a4ef4d,0x00000000,0x00000000,0x00000000}},	//   крик, --, --, --, 
   {{0x7aec00df,0x5ed400fe,0x00000000,0x00000000}},	//   ŭata, ধৱদে, --, --, 
   {{0x24e401ec,0x00000000,0x00000000,0x00000000}},	//   _ﺍﻟﺸﻬ, --, --, --, 
   {{0x78ac1326,0x99840024,0xe4e41ac3,0x9b9000db}},	//   čava, genų_, кімн, _ئلكت, 
   {{0x3f88ef4e,0x98700356,0x1a980a7c,0xd940010a}},	//   zzau_, uţă_, _קיבע, _вехи, 
   {{0x98700276,0xfc7c0248,0xd7e000d4,0x00000000}},	//   rţă_, _áátá_, _кішо, --, 
   {{0xa2ac01bc,0x99840064,0xf1bc00d1,0x00000000}},	//   ंकल्, benų_, ﻠﯩﻘﻘ, --, 
   {{0x787406ea,0x00000000,0x00000000,0x00000000}},	//   _dávu, --, --, --, 
   {{0xe0d00592,0x7cf801e1,0x00000000,0x00000000}},	//   لزر_, _múrò, --, --, 
   {{0x3f88ef4f,0xd4980276,0x438400c6,0x00000000}},	//   tzau_, _арь_, _ملعق, --, 
   {{0x4428ef50,0x645cef51,0x7874022c,0x44e800e4}},	// [14dd0] _ica_, _inqi, _gávu, _hû_, 
   {{0x44e800d2,0x3f8807c5,0xdd9802dd,0x00000000}},	//   _kû_, rzau_, мше_, --, 
   {{0x44280798,0x05800055,0x00000000,0x00000000}},	//   _kca_, _pūṇy, --, --, 
   {{0x44e824ba,0x4428515a,0x9f48ef52,0x644cef53}},	//   _mû_, _jca_, _decò_, ndci, 
   {{0x4428ef54,0x7ac4004e,0x200c0419,0x00000000}},	//   _mca_, гөжа, ógiu_, --, 
   {{0xba180046,0x5f44001f,0x44e80129,0x628401bf}},	//   ريعا_, _የራሳቸ, _oû_, nhjo, 
   {{0x06e02158,0x44e8000f,0x9c4400c7,0x98a40427}},	//   _মৌলি, _nû_, _ихал, šiču_, 
   {{0x4428ef55,0xa2b829ea,0x754408ca,0x00000000}},	//   _nca_, _शीघ्, ҳноз, --, 
   {{0x7c28ef56,0xb6000118,0x00000000,0x00000000}},	//   _icer, _ďábe, --, --, 
   {{0x4428ef57,0x44e800d2,0x7c284b16,0x645cef58}},	//   _aca_, _bû_, _hcer, _anqi, 
   {{0x4428ef59,0x7c281505,0x55c0054a,0x46e80228}},	//   _bca_, _kcer, ранғ, ндөн_, 
   {{0x44285cd5,0x44e8ef5a,0x3d040490,0x477000c7}},	//   _cca_, _dû_, हीये_, сқәу, 
   {{0x7bdc0306,0x99840024,0x4428045a,0x25080133}},	//   _úsud, penų_, _dca_, ورێی_, 
   {{0x4428ef5b,0x645c014b,0x62840c95,0x7c28107d}},	//   _eca_, _enqi, ghjo, _lcer, 
   {{0x7640ef5c,0x7c28035a,0x719801d3,0xa018007c}},	//   mely, _ocer, رنرز_, _slöa, 
   {{0x4428ef5d,0x9f48011c,0x7c280356,0x6adc00fe}},	//   _gca_, _recò_, _ncer, নীটো, 
   {{0xb4c02894,0x00000000,0x00000000,0x00000000}},	// [14de0] ्गी_, --, --, --, 
   {{0x7c28ef5e,0x6284ef5f,0x74040055,0x00000000}},	//   _acer, chjo, _ṛghā, --, 
   {{0x8d2800fd,0x8d44010b,0x020400cf,0x00000000}},	//   тнең_, рдеҗ, _өзөн, --, 
   {{0x7640ef60,0x3208ef61,0x2bc8ef62,0x66c40174}},	//   hely, laby_, нуло_, iðka, 
   {{0x7c28ef63,0x7520ba17,0xe45c005b,0xa01801f4}},	//   _dcer, hulz, mmöt_, _klön, 
   {{0x7c28ef64,0x764000fe,0x636c022e,0x3208ef65}},	//   _ecer, jely, _mеnе, naby_, 
   {{0xd91407dd,0x78ac09a8,0x7874013a,0x2bf40064}},	//   гьы_, čavn, _návs, _бязр, 
   {{0x75206428,0x1af00154,0xac84010b,0xee840022}},	//   dulz, _ঘিরে_, _ёгал, _рыҭо, 
   {{0x44e82776,0x612800a2,0xa018007c,0x7640ef66}},	//   _sû_, _kölç, _olön, fely, 
   {{0x7640ef67,0x3208089c,0xa9680166,0xe9689919}},	//   gely, jaby_, _пиза_, _пазл_, 
   {{0xddc40030,0x7c2803ac,0x7544036b,0x45c00150}},	//   _kojš, _ycer, لیوف_, _ﺭﺍﻗﺼ, 
   {{0xa018145e,0x461446ca,0x25540055,0x00000000}},	//   _alön, دوگر, _āpṛṇ, --, 
   {{0x4428ef68,0xa0180008,0xd4980262,0xddc400d7}},	//   _vca_, _blön, урэ_, _mojš, 
   {{0x7640ef69,0x44e8ef6a,0x442804cc,0x75200356}},	//   cely, _tû_, _wca_, bulz, 
   {{0x44283801,0x6d58ef6b,0x237cef6c,0x20c80063}},	//   _tca_, _štan, šuj_, ећао_, 
   {{0x4428ef6d,0x645c014b,0x44440014,0xd510280f}},	//   _uca_, _unqi, _ضربہ, _ابوغ, 
   {{0x3208ef6e,0x6ef80086,0x00000000,0x00000000}},	// [14df0] baby_, _rùbò, --, --, 
   {{0x7c28502a,0xa2802580,0x3af400e4,0xdda8011c}},	//   _scer, _ایسو, _ẽpor_, нтел_, 
   {{0x6578ef6f,0x2240009b,0x7c2801bf,0xe45c007c}},	//   nyth, mejk_, _pcer, rlöf_, 
   {{0x7640ef70,0x8d1801b9,0x6ab8ef71,0x00000000}},	//   zely, ازلر_, _aktf, --, 
   {{0xae1c1d8a,0x7c28ebd0,0xe45c0267,0x6d5803b2}},	//   _पाचन_, _vcer, lmös_, _átan, 
   {{0x787403c6,0x65780522,0x6128013d,0xfaa416a4}},	//   _návr, kyth, _gölç, јако, 
   {{0x7640ef72,0xf864bef7,0x6d480393,0x00000000}},	//   vely, ивко, æfat, --, 
   {{0x764000a9,0x7af402bf,0x78ac0e3c,0xb0640108}},	//   wely, _взає, čavo, _itää, 
   {{0x3e5c0201,0x7640ef73,0xe0dc19f5,0x9a2401eb}},	//   _ለማድረ, tely, _miò_, _معان, 
   {{0xe0dc026c,0xf5e8039b,0x66b000ec,0x00000000}},	//   _liò_, ъмол_, يٽيء, --, 
   {{0x7640ef74,0x49e401d9,0x65780368,0xaadc07f7}},	//   rely, _آمٕ, gyth, _फूटक, 
   {{0x62940117,0x7640ef75,0xb4c0228a,0x55c0ef76}},	//   _amxo, sely, ्गे_, _қайғ, 
   {{0x386c1f7f,0x764051bc,0x320800ee,0x752000ac}},	//   mjer_, pely, taby_, sulz, 
   {{0x386cef77,0xe0dc08e5,0x36680f14,0x6578127b}},	//   ljer_, _aiò_, _јако_, byth, 
   {{0xe0dc067c,0x3d040cb4,0x386c062c,0x34a800f3}},	//   _biò_, _हौले_, ojer_, _ивко_, 
   {{0xe0dc4ef6,0x64a000a7,0x78740306,0x00000000}},	//   _ciò_, _маща, _závr, --, 
   {{0x386c282c,0x7aec0077,0x224001ef,0x6fd4003b}},	// [14e00] ijer_, íatl, bejk_, рівц, 
   {{0x7c3c05d1,0x386c003e,0xdd8c0214,0xa01802d2}},	//   _ısra, hjer_, ژول_, _hlöl, 
   {{0x386cef78,0x7bc80156,0xed440b7e,0x00000000}},	//   kjer_, _azeu, рнеп, --, 
   {{0xe0dcef79,0x386c003d,0xe53400c8,0x90640150}},	//   _giò_, jjer_, יטעט_, _انحۇ, 
   {{0x386cef7a,0xddc40010,0xd1f00023,0xb0640108}},	//   djer_, _vojš, _ቁሸት_, _etää, 
   {{0x7bc8006f,0xad247611,0x386c005c,0x00000000}},	//   _dzeu, _پرسو, ejer_, --, 
   {{0x7bc80198,0xddc40b4b,0x386c01bf,0x1d04011c}},	//   _ezeu, _tojš, fjer_, _веси_, 
   {{0x386c03d4,0xb4c01fe7,0xdd8c01d3,0xf95800e5}},	//   gjer_, ्गो_, _کوہ_, اسوں_, 
   {{0x657800a9,0xdce80024,0xee44032e,0x00000000}},	//   wyth, čiąj, _þýsk_, --, 
   {{0xd6d40262,0x65780857,0x2ca4ef7b,0xe8f8009d}},	//   итэ_, tyth, lnod_, _алж_, 
   {{0xd7ec1b10,0x699434f5,0x44b43740,0xe4c4005b}},	//   _му_, _трах, йбос, иёмн, 
   {{0x6578ef7c,0x2ca40368,0x7bc80129,0x00000000}},	//   ryth, nnod_, _yzeu, --, 
   {{0x6d5807f5,0xb864ef7d,0x6578005b,0x9cd4011a}},	//   _štal, _دالو, syth, יוטה_, 
   {{0x1cdc0489,0x65783471,0x2ca40142,0xa01800e5}},	//   སམོ_, pyth, hnod_, _elöl, 
   {{0x20d8063f,0x22400267,0xc0e800ec,0x20d40127}},	//   ụime_, rejk_, افرن_, لترج, 
   {{0x2c54016b,0xdb18008e,0xe45c00e5,0x00000000}},	//   bɛdɔ_, _uzuç, rmös_, --, 
   {{0xb064014a,0xbe3801c0,0x986000b8,0x3ef8084c}},	// [14e10] _stää, лзах_, _jñā_, унзэ_, 
   {{0x62940921,0x00000000,0x00000000,0x00000000}},	//   _umxo, --, --, --, 
   {{0x1cb8003d,0x2ca40cfd,0xab6003ee,0xbc180220}},	//   _ངེད_, fnod_, _şüph, гілі_, 
   {{0x2ca4c22e,0x225c03f9,0x8d740a11,0x8d280212}},	//   gnod_, ɓuka_, غالا, роїв_, 
   {{0xdef80220,0xb7c0015b,0x386c0158,0x00000000}},	//   _шын_, _উল্ট, vjer_, --, 
   {{0x7ce0010e,0x2ca4ef7e,0x00000000,0x00000000}},	//   _eŷra, anod_, --, --, 
   {{0x3e5c001f,0x394401b9,0xe8c40022,0x00000000}},	//   _ለማዳረ, ёниг, әгыл_, --, 
   {{0xbca4ef7f,0x00000000,0x00000000,0x00000000}},	//   _امري, --, --, --, 
   {{0x7bc80117,0x386cef80,0x99840421,0x3a74086f}},	//   _uzeu, rjer_, manō_, _ллар, 
   {{0x386cef81,0xca740597,0x0f580a7c,0x160401a9}},	//   sjer_, _والغ, שיזם_, шмоқ_, 
   {{0x7ae0009a,0x54e00150,0x00000000,0x00000000}},	//   _iilt, _ﺍﻟﺒﺼ, --, --, 
   {{0x7ae80069,0x07084b13,0x1bec0316,0x00000000}},	//   _kuet, _چيني_, _छलफल_, --, 
   {{0x7ae0ef82,0x7ae8009a,0x998402b5,0x888c008f}},	//   _kilt, _juet, ianō_, _בראַ, 
   {{0x6d58b485,0x7ae0ef83,0x7ae8ef84,0x00000000}},	//   _štam, _jilt, _muet, --, 
   {{0x7ae0ef85,0x7ae8049b,0xd58404d3,0xe45c5bf6}},	//   _milt, _luet, _ڕێگه_, rmör_, 
   {{0x7ae00493,0x7ae8ef86,0xd1743452,0xe45c01e3}},	//   _lilt, _ouet, бығы, smör_, 
   {{0xee38ef87,0xa018ef88,0x7ae80a40,0x7ae04695}},	// [14e20] лна_, _glöm, _nuet, _oilt, 
   {{0xdfcc082e,0xdd8cef89,0xb224e498,0x7ae0ef8a}},	//   ريل_, کوم_, _умол, _nilt, 
   {{0x7ae8ef8b,0xdb9c02dd,0x00000000,0x00000000}},	//   _auet, _ﺃﺒﺭﺯ_, --, --, 
   {{0xac08ef8c,0x1d04214f,0x7ae0ef8d,0x00000000}},	//   унда_, сеци_, _ailt, --, 
   {{0x205406a9,0x7ae826b6,0x2ca436db,0xa0a001c6}},	//   _היכל_, _cuet, rnod_, _хаяд, 
   {{0x7ae0ef8e,0xbae400d6,0x2ca4be27,0x00000000}},	//   _cilt, іцій, snod_, --, 
   {{0x7ae0ef8f,0x7ae8004e,0x00000000,0x00000000}},	//   _dilt, _euet, --, --, 
   {{0x6d4cef90,0x7ae8ef91,0x245c00b0,0x7ae00e89}},	//   _isba, _fuet, _mämä_, _eilt, 
   {{0x7ae80588,0xa01801e6,0x05240154,0xceb403b9}},	//   _guet, _blöj, _বনের_, hrəm_, 
   {{0x7ae0ef92,0xe664ef93,0x8698ef94,0x7d1001f4}},	//   _gilt, стио, ркос_, _äksä, 
   {{0x245cef95,0x6d588e70,0x7ae8009d,0xe8f89040}},	//   _nämä_, _štaj, _zuet, _сле_, 
   {{0x6d4c0067,0x7ae0ef96,0xd7f4074d,0x00000000}},	//   _msba, _zilt, _луш_, --, 
   {{0x27e4ef97,0x68e00472,0x7ae8d829,0xdc980375}},	//   _igon_, _iiod, _xuet, ריכל, 
   {{0x6e2c0333,0x442c0034,0x6d4cef98,0x68e0ef99}},	//   _ncbb, że_, _osba, _hiod, 
   {{0x7e74489c,0x660801f5,0x24880051,0xd1640395}},	//   _rozp, _iefk, phcm_, пъти, 
   {{0xc0240075,0xbf100032,0x1ae002f5,0x6d580241}},	//   تىري, мүмә, নীয়া, _àtay, 
   {{0x68e0ef9a,0x6608ef9b,0x60cc0175,0x4438037e}},	// [14e30] _miod, _kefk, _vhcm, mfs_, 
   {{0x4438292b,0x6f040369,0x68e02654,0xc4340014}},	//   lfs_, _dwkc, _liod, _اکھت, 
   {{0x4438ec46,0x7ae8ef9c,0x7e740789,0x245c00a2}},	//   ofs_, _suet, _vozp, _gämä_, 
   {{0x7ae0ef9d,0x27e4ef9e,0x7ae82b1d,0x8d8405f5}},	//   _silt, _ngon_, _puet, чууд, 
   {{0x7ae0ef9f,0x6d4cefa0,0x443804e6,0x291803b2}},	//   _pilt, _esba, ifs_, ápan_, 
   {{0x27e4efa1,0x7ae819a2,0x6608d869,0x3d94014b}},	//   _agon_, _vuet, _nefk, _дигр, 
   {{0x68e0efa2,0x200800b8,0xc87806be,0x00000000}},	//   _biod, _keci_, _luğu_, --, 
   {{0x7ae0efa3,0x68e00ffb,0xa01801e6,0x44380d27}},	//   _wilt, _ciod, _slöj, jfs_, 
   {{0x68e0efa4,0x2008084c,0xf62400c7,0x7ae8000d}},	//   _diod, _meci_, одпо, _uuet, 
   {{0x2008efa5,0x27e40323,0xfaf80b23,0x7ae0127b}},	//   _leci_, _egon_, _itū_, _uilt, 
   {{0x4438efa6,0x68e0efa7,0x66080de2,0x2008003a}},	//   ffs_, _fiod, _defk, _oeci_, 
   {{0x68e00c86,0x6608efa8,0x6d58041a,0x2008efa9}},	//   _giod, _eefk, _štak, _neci_, 
   {{0xe60c4672,0x66080093,0x78a8efaa,0x97c40eff}},	//   _од_, _fefk, mnev, _اتام, 
   {{0x78a8efab,0x4438257c,0x66080067,0xa01808a5}},	//   lnev, afs_, _gefk, _flök, 
   {{0x2008efac,0x7f5c00a3,0x78a80023,0xa2ac033f}},	//   _beci_, _arsq, onev, ंकज्, 
   {{0x2008efad,0xef18084c,0x32600055,0x00000000}},	//   _ceci_, имб_, _ṛcām_, --, 
   {{0x2008efae,0xa0a0efaf,0x7c380142,0x78a80108}},	// [14e40] _deci_, фатд, dfwr, inev, 
   {{0x245c0664,0x6d580ad9,0x78a8efb0,0x6da47055}},	//   _tämä_, _átak, hnev, оиза, 
   {{0x2008efb1,0xfaf80421,0x78a8efb2,0x3d041af8}},	//   _feci_, _atū_, knev, हीले_, 
   {{0x9cb000f1,0xdca014b3,0x00000000,0x00000000}},	//   وملت, махи, --, --, 
   {{0x6d4c02c4,0x00000000,0x00000000,0x00000000}},	//   _wsba, --, --, --, 
   {{0x2008084c,0x78a8cdc8,0xed58eec3,0x68e0efb3}},	//   _zeci_, enev, _ког_, _siod, 
   {{0x660801fa,0x6d4c127b,0xcb1c0490,0x68e00142}},	//   _refk, _usba, _निवड_, _piod, 
   {{0xdd8c43bb,0x78a8e344,0x98c001e0,0xd8b4007b}},	//   _شوق_, gnev, мсыл, يديا_, 
   {{0xa0180008,0x66080114,0x4438005a,0xeb980798}},	//   _slök, _pefk, vfs_, _тиа_, 
   {{0x78a8036e,0x68e0012d,0x00000000,0x00000000}},	//   anev, _wiod, --, --, 
   {{0x2868026a,0x68e008c2,0x6608efb4,0xa0180112}},	//   _врло_, _tiod, _vefk, _flöh, 
   {{0x66e4efb5,0xe784085a,0x4438efb6,0x1864014b}},	//   _дода, _муло, ufs_, _махи_, 
   {{0x20081326,0x4438efb7,0x36880323,0x8d940092}},	//   _reci_, rfs_, рсөн_, ቀርበው_, 
   {{0xaac80316,0x4438002d,0x7aec0162,0x00000000}},	//   ितिक, sfs_, íati, --, 
   {{0xd25802d5,0x4438002f,0xab600205,0x00000000}},	//   цця_, pfs_, ğüyl, --, 
   {{0x94740150,0x69a000c5,0xab6003e0,0x00000000}},	//   _يديا, _कइनी, şüyl, --, 
   {{0x200801a2,0x0fe40228,0x8fe40184,0x8f340022}},	// [14e50] _veci_, дөрү, дәрҙ, метц, 
   {{0x78ac17a3,0x2128003b,0x2164022e,0x00000000}},	//   čavi, _кімн_, _дтмг, --, 
   {{0x92b40597,0xe2a80014,0x78a801d3,0x29180306}},	//   _تحيا, _ماگن_, ynev, ápal_, 
   {{0x60600e2c,0x0ca8efb8,0x6aa80042,0x00000000}},	//   _تۇرل, отчи_, enff, --, 
   {{0xdb040fb9,0x78a80450,0xec10efb9,0x6aa8015d}},	//   _ömür, vnev, روود, fnff, 
   {{0x3f4c01a6,0x7c380042,0xa3d0012d,0xebc00166}},	//   _ižu_, sfwr, _वरन_, хәсн, 
   {{0x7f4c003d,0x78a8efba,0x7c380142,0x00000000}},	//   lwaq, tnev, pfwr, --, 
   {{0x78a8d3b2,0xcdc800d1,0x00000000,0x00000000}},	//   unev, _بۇمۇ_, --, --, 
   {{0xeb3c0092,0xf74404c2,0x00000000,0x00000000}},	//   ደነገገ, чепо, --, --, 
   {{0x78a8efbb,0x6d5802f0,0x06b805af,0x00000000}},	//   snev, _štai, ينيک_, --, 
   {{0x7f4c0117,0x78a8efbc,0x4990073e,0xd9b000d1}},	//   hwaq, pnev, _لیور, _تەغد, 
   {{0x3f4c3a4a,0xc8646582,0x7f4c01e2,0x35b463eb}},	//   _ožu_, _отчи, kwaq, жбүр, 
   {{0xc32c1b92,0x608c0023,0x3ea00037,0x00000000}},	//   لەي_, _ሓረጋት_, kiht_, --, 
   {{0x3948012d,0x860800f7,0x200c06ea,0x00000000}},	//   łasu_, _ۇقۇق_, ðgin_, --, 
   {{0xe45c007c,0x551c00c5,0x00000000,0x00000000}},	//   mlön_, _मटिए_, --, --, 
   {{0xe45c023a,0xb4b82586,0x00000000,0x00000000}},	//   llön_, _دُعا_, --, --, 
   {{0x7f4c016c,0x6aa80042,0x00000000,0x00000000}},	// [14e60] gwaq, ynff, --, --, 
   {{0x3f4c0064,0x7c900092,0x00000000,0x00000000}},	//   _džu_, _ጀምረው_, --, --, 
   {{0xe45c01b8,0xe80c012c,0x72d801d9,0x7f4c0009}},	//   ilön_, सरमा_, _پِھر_, awaq, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3be81cd1,0x7f183981,0x6b64010b,0xe45c007c}},	//   әләү_, _міру_, якда, klön_, 
   {{0x3ea00036,0x291802d1,0x753c033f,0x00000000}},	//   ciht_, špam_, łszy, --, 
   {{0x9d404a3f,0xa018007c,0x00000000,0x00000000}},	//   _перд, _slöi, --, --, 
   {{0xc6f87b17,0x34d401ad,0x7f6400fd,0xed58014b}},	//   оних_, ठगोद, _ütqä, _коҳ_, 
   {{0x49080034,0x0d2400ee,0x785412ea,0x24e40150}},	//   _सबको_, _хүҗү, بینز_, _ﺍﻟﺘﻬ, 
   {{0x9f940302,0x6b80efbd,0x228c0139,0x00000000}},	//   פדיה_, myog, _küke_, --, 
   {{0x6b80efbe,0xa0180042,0x00000000,0x00000000}},	//   lyog, _glöw, --, --, 
   {{0x6b801418,0x6f14012d,0x741402f2,0x00000000}},	//   oyog, ksyc, ووپا, --, 
   {{0x6b80efbf,0xa0180267,0x38300124,0x7c3c01e3}},	//   nyog, _klöv, _рҽыр, _ösre, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd5ac2bd0,0x3ea00010,0x39480115,0x7f4c0327}},	//   _чс_, viht_, ʈas_, wwaq, 
   {{0x6b800337,0x9550007b,0x7f4c0135,0x00000000}},	//   kyog, _أخوا, twaq, --, 
   {{0x98a405ce,0xdde80a8e,0x00000000,0x00000000}},	// [14e70] šiću_, مراه_, --, --, 
   {{0xe2a81046,0x753c0210,0xdef80150,0x00000000}},	//   _دابن_, ńsze, _қым_, --, 
   {{0x7f4c013f,0x127c010f,0x98d40150,0x00000000}},	//   swaq, _לאזע, _ﺟﺎﯞﻻ, --, 
   {{0x317c2155,0x62840327,0xbd50035b,0x3ea0efc0}},	//   ätze_, lkjo, нҭҳә, siht_, 
   {{0x69a002ab,0x7f4c014b,0x6b80efc1,0x6fd00241}},	//   _केबी, qwaq, gyog, _ọgọ́, 
   {{0xbb2c7a32,0x4ba800f7,0x5f60001f,0xaa40008e}},	//   ﯩﺴﻰ_, чөсү_, _ለራሳቸ, вешл, 
   {{0x6d582625,0x6b800337,0x4d980395,0x00000000}},	//   _štav, ayog, _екрю_, --, 
   {{0x6b80767d,0xa018007c,0x08d40006,0x00000000}},	//   byog, _elöv, нцыя, --, 
   {{0x6b8000ca,0x3e40001f,0x3b540166,0x00000000}},	//   cyog, _ከማድረ, _юкар, --, 
   {{0x04f80154,0x228c0205,0x00000000,0x00000000}},	//   _আয়ের_, _yüke_, --, --, 
   {{0xe850036b,0xe45c01e3,0x9f8800a2,0x00000000}},	//   رنید, rlön_, lıär_, --, 
   {{0xf770bce4,0xe45c01e3,0x00000000,0x00000000}},	//   _لات_, slön_, --, --, 
   {{0x6d5800e4,0xa3d01b87,0x00000000,0x00000000}},	//   _átav, _वरण_, --, --, 
   {{0x69a01524,0xd6d80276,0xa2e0130f,0x69dc0022}},	//   _केडी, _уте_, кояд, ýpeg, 
   {{0xa2e08d17,0x41b42628,0x00000000,0x00000000}},	//   торд, естт, --, --, 
   {{0xa064efc2,0x00000000,0x00000000,0x00000000}},	//   маса_, --, --, --, 
   {{0xef1821d0,0xe45c01b8,0x7278003b,0x00000000}},	// [14e80] юма_, ilöl_, _дснс_, --, 
   {{0xc3c8efc3,0x6b8001c8,0x6f1403ac,0x00000000}},	//   _عظيم_, vyog, rsyc, --, 
   {{0xf7d408b0,0x3de00154,0xfe780108,0x00000000}},	//   ﻟﯩﻤﻪ, মুসল, чёты_, --, 
   {{0x6b800525,0x00000000,0x00000000,0x00000000}},	//   tyog, --, --, --, 
   {{0xa01807c5,0xeab848d4,0xdca00114,0x00000000}},	//   _plöv, ойд_, њачи, --, 
   {{0x6b80efc4,0xe45c29ef,0x228c0166,0x00000000}},	//   ryog, elöl_, _tüke_, --, 
   {{0x5de007d6,0x9f480008,0x6b80037e,0xc60c00eb}},	//   _ажра, élög_, syog, _শালা_, 
   {{0xab2876cd,0x00000000,0x00000000,0x00000000}},	//   _моба_, --, --, --, 
   {{0xdca0efc5,0x6d5c03a1,0x62840113,0x5bc004b3}},	//   _рати, lvpa, ykjo, _айтб, 
   {{0xceb400ac,0x00000000,0x00000000,0x00000000}},	//   qsəd_, --, --, --, 
   {{0xe9dc0004,0x98a400bc,0xf85000d0,0xa0180112}},	//   _àº_, ntně_, šľať_, _klöt, 
   {{0x25fc098b,0xa34401c0,0xbb7000cf,0x499001d3}},	//   _श्री_, мэгл, _جۇۇع, _لیڈر, 
   {{0x787402fb,0x6d5c0254,0x628401bf,0x00000000}},	//   _návy, hvpa, tkjo, --, 
   {{0x32280135,0xe1f80882,0x98a400bc,0x649802dd}},	//   _སྐྱར_, ्रेण_, ktně_, стүр_, 
   {{0x1708031c,0xb37008dc,0xb6080116,0x00000000}},	//   _གསོམ_, نگیش, _ﻳﺎ_, --, 
   {{0xc5f800e2,0xb1440014,0xd0d402e8,0x753c0210}},	//   lcē_, ریُم_, восъ, ńszc, 
   {{0x10e400f5,0xff9800d8,0x00000000,0x00000000}},	// [14e90] тюрм, чкај_, --, --, 
   {{0xc5f8005f,0xd2940022,0x7e54007b,0x00000000}},	//   ncē_, _арџь, عناص, --, 
   {{0xa01801e6,0xc5f800e2,0xaf0001e1,0x11f801e2}},	//   _blöt, icē_, _òùnk, _توپک_, 
   {{0x009405f5,0xc0c400ee,0x28cc05d7,0x00000000}},	//   _чимэ, _чәги, _हीलि, --, 
   {{0x909806bb,0x6d58efc6,0x3b08c18e,0xdfd800a7}},	//   _цвят_, _štat, чело_, _фън_, 
   {{0xa01800e5,0xb9540114,0x00000000,0x00000000}},	//   _elöt, етић, --, --, 
   {{0xfaf8000f,0xbc94009b,0x00000000,0x00000000}},	//   _grūn_, _завј, --, --, 
   {{0x7bf80022,0xa018032e,0x60940092,0xc5f800de}},	//   _хнар_, _glöt, _መወጣት_, ecē_, 
   {{0x186401ec,0x00000000,0x00000000,0x00000000}},	//   зақи_, --, --, --, 
   {{0x7bc80098,0x768c00a2,0xa01840fc,0xddc40306}},	//   _iyeu, _aºyr, _klös, _mojž, 
   {{0x6ed403b9,0x00000000,0x00000000,0x00000000}},	//   ləbü, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf744efc7,0x00000000,0x00000000,0x00000000}},	//   _чело, --, --, --, 
   {{0x7bc8009f,0xa01801e3,0xf77000ec,0x6d5c007c}},	//   _myeu, _olös, _لاڪ_, yvpa, 
   {{0x21642763,0x7bc8007f,0xf1a80691,0xdb1806be}},	//   нири_, _lyeu, ساسه_, _fyuç, 
   {{0xafe4efc8,0xfbc40451,0xb63801ec,0xceb40213}},	//   еобл, _نڪ_, _ﺘﻪ_, hrət_, 
   {{0x7bc8efc9,0x387c0142,0xceb40213,0x00000000}},	// [14ea0] _nyeu, _mowr_, krət_, --, 
   {{0xa01836b2,0x00000000,0x00000000,0x00000000}},	//   _blös, --, --, --, 
   {{0xa018efca,0x7bc8ebf1,0xdd8c05d9,0xceb40213}},	//   _plöt, _ayeu, ٽون_, drət_, 
   {{0x7bc849db,0x6d5c00af,0x6d580306,0x00000000}},	//   _byeu, rvpa, _štas, --, 
   {{0x98a4012c,0xceb40213,0x6d5c02d0,0xdcac1066}},	//   stně_, frət_, svpa, حىن_, 
   {{0xada434da,0x6da40116,0xa01801a8,0x00000000}},	//   _загл, _зига, _flös, --, 
   {{0x17080ed9,0x2918efcb,0x2ebc28e1,0x7bc8003e}},	//   _གསུམ_, épa_, ्तीत, _eyeu, 
   {{0x291800e4,0xdb1c00e5,0x00000000,0x00000000}},	//   ĩpa_, ővár, --, --, 
   {{0xda6ccea8,0x0ae40124,0x66c8efcc,0x387c058a}},	//   _گُل_, _абаҟ, зунг_, _dowr_, 
   {{0x69948a6b,0xa018023a,0xc5f800e2,0xddc4033f}},	//   _прех, _ylös, ucē_, _najś, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2ebc4eaa,0x00000000,0x00000000,0x00000000}},	//   ्तुत, --, --, --, 
   {{0x5344035b,0x8654014b,0x00000000,0x00000000}},	//   лхра, _аклх, --, --, 
   {{0x03a400c7,0x26b40108,0x00000000,0x00000000}},	//   еиҭо, _ящер, --, --, 
   {{0xe45c007c,0x23080271,0x00000000,0x00000000}},	//   nlök_, _کتبي_, --, --, 
   {{0xd018040e,0xceb400ac,0x74c40022,0xe0d00014}},	//   ефф_, zrət_, _ишыҧ, ازس_, 
   {{0xa0186916,0xe4500022,0x2a7c0036,0x69a00ebb}},	// [14eb0] _slös, _акқы, _ootb_, _केसी, 
   {{0x644cefcd,0xa01801b8,0x0e34005b,0x92940354}},	//   leci, _plös, лную, _баьц, 
   {{0x6d58efce,0xa18400ee,0x64a80118,0xf7d400d1}},	//   _štar, _чыпл, přid, ﻟﯩﻴﻪ, 
   {{0x4a743c24,0x5cc4267c,0xca740220,0xddc4012d}},	//   ғышт, رغاق, ғушы, _zajś, 
   {{0x3ba4001f,0xa018efcf,0xdbe00248,0x644c0381}},	//   ዋሚዎች_, _flör, _kéék, ieci, 
   {{0x9f4800d2,0x2ebc0a94,0x644c003a,0x7bc8009f}},	//   _ngcé_, ्तृत, heci, _vyeu, 
   {{0x644cefd0,0xae000075,0x8a14009f,0x00000000}},	//   keci, _ئۈمى, اظها, --, 
   {{0x644cefd1,0x2ee800f3,0xceb40213,0x7864094f}},	//   jeci, _zibf_, srət_, ткиз, 
   {{0x6d580077,0x7bc8efd2,0x7d0401c7,0xda0400d4}},	//   _átar, _uyeu, lphs, _зчеп, 
   {{0x69a001ad,0x95040107,0x00000000,0x00000000}},	//   _केवी, ндоғ_, --, --, 
   {{0x644cefd3,0x9964efd4,0x00000000,0x00000000}},	//   feci, _ятал, --, --, 
   {{0x644c0407,0x59a404af,0x46e800cf,0x00000000}},	//   geci, _केयर, мдөн_, --, 
   {{0xd3480517,0x2898010f,0x00000000,0x00000000}},	//   ریده_, _קינא, --, --, 
   {{0x228c014a,0xd6d8efd5,0x60dc0175,0xb6a42cdd}},	//   _püka_, _эте_, emqm, _шилл, 
   {{0x7640b6c9,0x59a407f7,0x00000000,0x00000000}},	//   mfly, _केमर, --, --, 
   {{0x644cefd6,0x7640efd7,0x00000000,0x00000000}},	//   ceci, lfly, --, --, 
   {{0x13a8e109,0xafe4c3cd,0xaec401a9,0x00000000}},	// [14ec0] _سندی_, тоал, вбал, --, 
   {{0x764091d0,0x2ebc043e,0x69a00037,0xdef00023}},	//   nfly, ्तेत, _कइली, ግረካ_, 
   {{0xe29400c0,0x00000000,0x00000000,0x00000000}},	//   _раэ_, --, --, --, 
   {{0x6ac81221,0x1d040063,0xab280107,0x00000000}},	//   ित्र, теци_, дода_, --, 
   {{0x7fd4005e,0x2ca4efd8,0x7640007c,0xac94035b}},	//   _бірі, riod_, kfly, наҧш, 
   {{0x644c006d,0x6da4013e,0xe45c0267,0xf1d4012c}},	//   zeci, _ҷиҳа, tlök_, _धरान, 
   {{0x764004ce,0x6da4efd9,0x4de00c58,0x644c4903}},	//   dfly, _рива, _প্ৰৱ, yeci, 
   {{0x644c0005,0xdd8c0035,0x4734014b,0x6be001af}},	//   xeci, _بوف_, гнис, _көлғ, 
   {{0x98b402e8,0x7b4400db,0x468401d5,0x00000000}},	//   ълът_, _مئلل, лқда, --, 
   {{0xe6640120,0x00000000,0x00000000,0x00000000}},	//   ттио, --, --, --, 
   {{0x644cefda,0x00000000,0x00000000,0x00000000}},	//   teci, --, --, --, 
   {{0x64a800bc,0x3fac00cc,0xd90c00e5,0x00000000}},	//   dřic, _খৰোষ, _بیٹ_, --, 
   {{0x4ccc00fe,0x00000000,0x00000000,0x00000000}},	//   িষপু, --, --, --, 
   {{0x7afcefdb,0xd3701e87,0xc6900050,0x45d400d1}},	//   _éste, زۇپ_, _دِت_, _йолс, 
   {{0xb6d800c8,0x20c4009d,0x51840121,0x52144130}},	//   _אַקט, всаг, аута, рдст, 
   {{0xc3c401c0,0xf07800b1,0x00000000,0x00000000}},	//   _бөгл, нисә_, --, --, 
   {{0x6d58098d,0xbed8a319,0xe9e402d2,0x00000000}},	// [14ed0] _štap, едах_, _þúfu_, --, 
   {{0x14741d00,0x772c0092,0x64a8013a,0x00000000}},	//   _ماۋج, _ተነሥተ, břic, --, 
   {{0x291c05d5,0x69a00073,0xdd0000ef,0x00000000}},	//   _nvta_, _केली, _īrēj, --, 
   {{0xe45c145e,0xa01801b8,0x7d04efdc,0xbb9400a7}},	//   ndö_, _glöp, rphs, лаещ, 
   {{0x0c241c26,0x291c09a8,0x7d0400d2,0x46b41899}},	//   рмін, _avta_, sphs, ुवाह, 
   {{0x1bec000d,0xceb40213,0x00000000,0x00000000}},	//   _छलकल_, lsən_, --, --, 
   {{0xa9a0036b,0xaee00150,0x0d840153,0x127c010f}},	//   йишд, _اۋلى, _клён, ואגע, 
   {{0x3a28efdd,0xceb40213,0x572000d1,0x9ba000d1}},	//   şap_, nsən_, апиғ, _پەتى, 
   {{0x3f88efde,0x76403bdc,0x36c401d5,0xe45c007c}},	//   nyau_, tfly, лбиг, ddö_, 
   {{0x64a800bc,0x672400e5,0x25f80210,0x00000000}},	//   yřic, ákja, ऊँगी_, --, 
   {{0x34a86145,0xceb4efdf,0x3f880007,0xf1ac015b}},	//   евно_, ייץ_, hyau_, _গর্ভ, 
   {{0xe29401ec,0x98a40055,0x00000000,0x00000000}},	//   қас_, bunā_, --, --, 
   {{0x3cec54fc,0x3af8067c,0x3f88efe0,0x78a8efe1}},	//   _miev_, _jèp_, jyau_, miev, 
   {{0x32cc006a,0x78a8efe2,0x6b580158,0x3cec0166}},	//   döyê_, liev, _høgå, _liev_, 
   {{0xd34878dd,0xfaf800ef,0xa5c83f6f,0xe120009d}},	//   ریگه_, _brūk_, _सुपौ, ймри, 
   {{0x3cec1570,0x2ebc87ea,0x78a8efe3,0x9ee400d1}},	//   _niev_, ्त्त, niev, ۇزلۇ, 
   {{0xb9dc001f,0x3208037e,0x0fe80aac,0x5f0001c6}},	// [14ee0] _ሥጋ_, pbby_, тлақ_, йзта, 
   {{0x88bc00bc,0x2d940150,0x00000000,0x00000000}},	//   _zvěd, лрес, --, --, 
   {{0x78a8efe4,0x13a8efe5,0xceb403b9,0x00000000}},	//   kiev, _سنگی_, bsən_, --, 
   {{0x78a8efe6,0x3cec0419,0x3d1800e5,0x00000000}},	//   jiev, _ciev_, ئٹنگ_, --, 
   {{0x7f741142,0x6a84af83,0xa5c80118,0x00000000}},	//   _курц, ллда, _सुनौ, --, 
   {{0xba040022,0xdb2001e7,0x00000000,0x00000000}},	//   иҭуа_, árál, --, --, 
   {{0x3cec0139,0x20d4036e,0x78a801fc,0x00000000}},	//   _fiev_, lçia_, fiev, --, 
   {{0x3cec0048,0x78a804cc,0x8e84010a,0x9944007b}},	//   _giev_, giev, _йӳçе, اليل_, 
   {{0x3af80100,0x58800108,0x63b8025c,0x00000000}},	//   _gèp_, сыща, żunz, --, 
   {{0x9b900491,0x88bc012c,0x3cec1358,0x98a4005f}},	//   _الكت, _svěd, _ziev_, runā_, 
   {{0xc0dc1540,0x45d47ee1,0x78a8efe7,0x3f880007}},	//   ንጻሩ_, ронс, biev, zyau_, 
   {{0x6aa80af5,0xceb40213,0xf1ac03d4,0x00000000}},	//   liff, xsən_, _গৰ্ভ, --, 
   {{0x691c0882,0xb86401e2,0xe8b00073,0x00000000}},	//   ṣedh, _خالو, ुकीच, --, 
   {{0x6aa8efe8,0xb91000cd,0x7d18012d,0x880001e2}},	//   niff, _alaṃ_, ąwsz, _اېښو, 
   {{0x6618efe9,0x45340131,0x11280212,0x3f88015d}},	//   matk, _ئىبر, люти_, wyau_, 
   {{0x661858a5,0x6aa8efea,0x98a40311,0x88bc00bc}},	//   latk, hiff, mună_, _uvěd, 
   {{0xceb403be,0x6aa8efeb,0xa3440139,0x00000000}},	// [14ef0] rsən_, kiff, _сэйл, --, 
   {{0x645c0517,0x78a8efec,0x3cecefed,0x6618efee}},	//   _haqi, ziev, _siev_, natk, 
   {{0x13b4b9ff,0x3af80100,0x6aa81e3d,0x98a40356}},	//   _نصیح, _sèp_, diff, nună_, 
   {{0x3af811c1,0x6618efef,0x645c2e95,0x00000000}},	//   _pèp_, hatk, _jaqi, --, 
   {{0x66182113,0x78a8eff0,0x645ceff1,0x2018eff2}},	//   katk, viev, _maqi, maqi_, 
   {{0x6aa820ac,0x6618eff3,0x645ceff4,0xd1b802dd}},	//   giff, jatk, _laqi, _جاۋا_, 
   {{0x6618eff5,0x78a8eff6,0xc0dc02d3,0x00000000}},	//   datk, tiev, ንጻር_, --, 
   {{0x20180054,0x645c0af5,0x9cc8748c,0x3af8007f}},	//   naqi_, _naqi, _чыга_, _tèp_, 
   {{0x78a8eff7,0x6618eff8,0x6aa84032,0x19d00150}},	//   riev, fatk, biff, _ﯞﯨﻨﺠ, 
   {{0x645c0cfe,0x2018eff9,0x78a8effa,0x0f58008f}},	//   _aaqi, haqi_, siev, ריזם_, 
   {{0x645ceffb,0x78a800e2,0x2918a7ab,0x20180309}},	//   _baqi, piev, špar_, kaqi_, 
   {{0x645c0014,0xf3e4c601,0xa56003cc,0x6d340a7c}},	//   _caqi, ижно, زگىن, סטרא_, 
   {{0x66184aa5,0x645ceffc,0x6c78008f,0x6eb800cd}},	//   batk, _daqi, דארפ, ्वमु, 
   {{0x6618effd,0x98a4054e,0x00000000,0x00000000}},	//   catk, bună_, --, --, 
   {{0xe5a00640,0xd7640150,0x20181366,0x00000000}},	//   _миши, _شەگى_, faqi_, --, 
   {{0x7bcc00da,0x645c011f,0x6aa80112,0x3004effe}},	//   ļauj, _gaqi, ziff, рзаг, 
   {{0xee384a03,0x6aa8022f,0x59a4efff,0xb9ec0092}},	// [14f00] кна_, yiff, _केसर, _ዕጩ_, 
   {{0xa5c802ab,0x772c001f,0x645c8c2b,0x00000000}},	//   _सुडौ, _ተነስተ, _zaqi, --, 
   {{0x645cbe48,0x04780214,0xaf340133,0x6eb800dc}},	//   _yaqi, _شلیک_, اوڕژ, ्वबु, 
   {{0xdd8cf000,0xab64f001,0x645cf002,0xeb04516a}},	//   بوم_, ивел, _xaqi, ачко, 
   {{0x6618f003,0x7d08151c,0xf1c802dd,0x6aa8f004}},	//   yatk, _čese, _سوڭى_, tiff, 
   {{0xca480f1c,0x6aa8013c,0xe45c0108,0x7c0400d1}},	//   الغه_, uiff, llöt_, لبۇك, 
   {{0x6aa8f005,0x6618f006,0x9f58011f,0x20d40205}},	//   riff, vatk, saqô_, için_, 
   {{0x6618f007,0x6aa8f008,0x6d4c6d30,0xd5e801f2}},	//   watk, siff, _ipba, ̣ịr, 
   {{0x645cf009,0xe45c01b8,0x6aa80869,0x00000000}},	//   _raqi, foön_, piff, --, 
   {{0x645c1bb7,0x7afcf00a,0x26c8006a,0x6aa80140}},	//   _saqi, _ésta, ôbo_, qiff, 
   {{0x6618b1c4,0x645c6ea6,0x201802d1,0x31500023}},	//   ratk, _paqi, yaqi_, ዝነበር, 
   {{0x6618f00b,0x69d84db8,0x45d42d40,0x36440131}},	//   satk, _izte, _қойс, لىۋې, 
   {{0x66185589,0x1cdc031c,0x645cf00c,0x98a40356}},	//   patk, _ྤེལ_, _vaqi, sună_, 
   {{0x6d4cf00d,0x66180357,0x171806a9,0x645cf00e}},	//   _opba, qatk, _יודע, _waqi, 
   {{0x645cf00f,0xa0a415bd,0x20180309,0xe45c032e}},	//   _taqi, ашал, taqi_, flöt_, 
   {{0x228c000d,0x00000000,0x00000000,0x00000000}},	//   _kükk_, --, --, --, 
   {{0x2018c56c,0x4438ddf6,0x6d4cf010,0x4fc40fac}},	// [14f10] raqi_, mgs_, _apba, осфа, 
   {{0x42540cd2,0x9e04f011,0x4438f012,0x6f0000c6}},	//   _اندر, рчал, lgs_, íoca, 
   {{0x60c00048,0x44380789,0x6294022e,0x39480210}},	//   _ínmo, ogs_, _ilxo, łasz_, 
   {{0x4438f013,0x315400c8,0x6720f014,0x2018f015}},	//   ngs_, _פירן_, _ovoj, qaqi_, 
   {{0x69d8f016,0x4438f017,0xe0dc0241,0xbb4800ec}},	//   _azte, igs_, _ihò_, التن_, 
   {{0xe60c02dd,0x5a440006,0xdce40205,0x00000000}},	//   _едi_, рэда, ılıc, --, 
   {{0x29c81682,0x69d80034,0x67200f12,0x4438f018}},	//   ṱanu_, _czte, _avoj, kgs_, 
   {{0x49b8027d,0x228c00e5,0x00000000,0x00000000}},	//   جاهد_, _bükk_, --, --, 
   {{0x9a24db35,0x44381730,0x69d8f019,0xe0dc00a3}},	//   _نعان, dgs_, _ezte, _mhò_, 
   {{0x19a80348,0xf668f01a,0x4438f01b,0x1dd800cd}},	//   _итеп_, احظه_, egs_, _भरात, 
   {{0x74e805f5,0x4ac400cf,0xe0dc01ab,0x00000000}},	//   лдог_, _بيلق, _ohò_, --, 
   {{0x7c385f00,0xb4d0f01c,0x6294022e,0x37f80276}},	//   ngwr, वते_, _alxo, _седэ_, 
   {{0xe60cf01d,0x64a80118,0x00000000,0x00000000}},	//   _нд_, přin, --, --, 
   {{0xb384069c,0xe0dc026c,0x44383a12,0x2920030a}},	//   _ዝኸውን_, _ahò_, ags_, ńsań_, 
   {{0x7f5c0113,0xe0dc01c3,0x51900023,0x2a94033f}},	//   _assq, _bhò_, ሞርኮሰ_, głby_, 
   {{0xe0dcf01e,0x62940166,0x2c6c022e,0xacd000d1}},	//   _chò_, _elxo, jаdа_, ﯘﺭﯗﺷ, 
   {{0xa0640c04,0xef84010b,0x00000000,0x00000000}},	// [14f20] щата_, щлап, --, --, 
   {{0xe45c0267,0x1e8001f0,0xdfe401f0,0x758c0023}},	//   slöt_, плум, сдуд_, _ዝመስሎ_, 
   {{0x7bc4002f,0xceb403b9,0x00000000,0x00000000}},	//   ßhun, lsək_, --, --, 
   {{0xeb98f01f,0x321800c7,0xe0dc00a3,0xa5d8008f}},	//   лие_, _hepy_, _ghò_, אַדי, 
   {{0x7c640075,0x69d801ed,0x6cd442c6,0x64a80118}},	//   تالل, _szte, _ۇقسا, dřil, 
   {{0x6e94f020,0x32180124,0xed580354,0x00000000}},	//   _السا, _jepy_, _йог_, --, 
   {{0x7d140369,0x3e840316,0x44380267,0x2d9c03cd}},	//   _gwzs, _dítě_, ygs_, _åte_, 
   {{0xceb403be,0xb4d0412f,0xcc380014,0x69d80118}},	//   ksək_, वतो_, _خٲرچ_, _vzte, 
   {{0x443805ac,0x207800df,0x00000000,0x00000000}},	//   vgs_, ראפא, --, --, 
   {{0x69d801fa,0x2a94033f,0x4438045a,0xc5f80154}},	//   _tzte, yłby_, wgs_, _আজহা_, 
   {{0x4438060a,0x69d8f021,0x699402bf,0x9b4001e2}},	//   tgs_, _uzte, _урах, _ونېو, 
   {{0x6720f022,0x4438f023,0x228c00c5,0x7b0406ea}},	//   _tvoj, ugs_, _tükk_, _úttø, 
   {{0x68f8950b,0xd05c0213,0xc5f800e2,0x00000000}},	//   _hutd, _özəl, ldēm_, --, 
   {{0x65780227,0x68f801d5,0x65680175,0x228cf024}},	//   pxth, _kutd, _trfh, _küki_, 
   {{0x20d40b73,0xe0dc0208,0xc104007b,0xe50401f7}},	//   مترج, _phò_, توزي, _ابتي, 
   {{0xe3a8009e,0xd0180a42,0xd50400ec,0xe45c343a}},	//   _গুণব, йфу_, _اٺين_, rlös_, 
   {{0x68f8047e,0xe45c0267,0xaab81bd6,0x00000000}},	// [14f30] _lutd, slös_, ेवाक, --, 
   {{0x4154f025,0x68f86e16,0x3f8c0327,0x7ea803e3}},	//   _двос, _outd, _żeus_, _köpə, 
   {{0x7bf8f026,0xe0dc004d,0x44289a62,0x7218004e}},	//   анер_, _thò_, _kda_, _өжөр_, 
   {{0x4254cea5,0xe68c044e,0x3e84012c,0x00000000}},	//   _انگر, _ዝገበሮ_, _sítě_, --, 
   {{0x7c380042,0x2c6c022e,0xc5f800de,0x00000000}},	//   rgwr, rаdа_, edēm_, --, 
   {{0x4428f027,0x68f800a2,0xe7b003d4,0xbba80073}},	//   _lda_, _butd, _চৰ্য, _कधीक, 
   {{0xfce802eb,0x64a800bc,0x00000000,0x00000000}},	//   _نفسي_, třil, --, --, 
   {{0x4428f028,0x7afc04cf,0x00000000,0x00000000}},	//   _nda_, _ésto, --, --, 
   {{0x7c28f029,0x68f8004e,0x00000000,0x00000000}},	//   _ider, _eutd, --, --, 
   {{0x4428f02a,0xb4d00a28,0xaa4000d1,0x09c4000d}},	//   _ada_, वत्_, _يۆنى, _लुकठ, 
   {{0x4428f02b,0xaf48001f,0x3218f02c,0x68f8f02d}},	//   _bda_, _አያስፈ, _repy_, _gutd, 
   {{0xe8ecc10e,0x69a0012c,0x7c280356,0x00000000}},	//   _іл_, _केटी, _jder, --, 
   {{0x4428f02e,0x26cc0418,0x7c2802ce,0x972001d3}},	//   _dda_, _fkfo_, _mder, _عہدو, 
   {{0x4428601a,0x68f801a9,0x069407d2,0x00000000}},	//   _eda_, _yutd, _ﯞﺍﻳﯩ, --, 
   {{0x4428f02f,0x7c28f030,0xa1840261,0xe45c0790}},	//   _fda_, _oder, обра_, rlör_, 
   {{0x7c28f031,0x4428f032,0x7ae00109,0xdfcc00ec}},	//   _nder, _gda_, _lhlt, ھيل_, 
   {{0x7d081156,0xdfcc3ed4,0x88bc01ef,0x00000000}},	// [14f40] _česa, پيل_, _ověn, --, 
   {{0x4428f033,0x00000000,0x00000000,0x00000000}},	//   _zda_, --, --, --, 
   {{0xed5812b4,0x4428f034,0x128800f2,0x116800f2}},	//   рое_, _yda_, _نمکی_, _الجی_, 
   {{0x44280a40,0x7c281529,0x00000000,0x00000000}},	//   _xda_, _cder, --, --, 
   {{0xe68c044e,0x7c2800a9,0x7ae001ab,0x68f8047e}},	//   _ዝገብሮ_, _dder, _bhlt, _sutd, 
   {{0x7c28f035,0x6da40aa5,0x228c014a,0x7ae001ab}},	//   _eder, _дига, _püki_, _chlt, 
   {{0x68f80194,0x7c2800b5,0x8894009d,0xe2a40174}},	//   _qutd, _fder, зийх, øðir_, 
   {{0x6fdc00e1,0x00000000,0x00000000,0x00000000}},	//   _मरां, --, --, --, 
   {{0x4428f036,0xda080574,0xa09800d9,0x00000000}},	//   _rda_, _स्वत_, ייקט, --, 
   {{0x4428f037,0x68f8f038,0x7c28033f,0x228c0037}},	//   _sda_, _tutd, _zder, _tüki_, 
   {{0x7c28019b,0xa80402d5,0x2b440356,0x212c0055}},	//   _yder, _дзел, ltoc_, _āgho_, 
   {{0xe45c014a,0xe4a402bf,0x7768003a,0x4428f039}},	//   glöp_, ірно, bvex, _qda_, 
   {{0x442812c1,0x2b440dd4,0x68e0f03a,0xa0180142}},	//   _vda_, ntoc_, _ihod, _glöy, 
   {{0x44280042,0xddc800c0,0x00000000,0x00000000}},	//   _wda_, _čiža, --, --, 
   {{0x68e0f03b,0x69dc00e4,0x00000000,0x00000000}},	//   _khod, ýpeh, --, --, 
   {{0x4428f03c,0xceb406be,0x20d4010e,0x00000000}},	//   _uda_, mrəy_, mçik_, --, 
   {{0x68e0f03d,0x22840228,0xe2a801d9,0x7c28002f}},	// [14f50] _mhod, _дунг, _نادن_, _rder, 
   {{0xe2a880a5,0x7c28f03e,0x64a80118,0x00000000}},	//   _خابن_, _sder, křik, --, 
   {{0x68e00232,0x2b440165,0x81d401c6,0x20d425a8}},	//   _ohod, etoc_, _хонх, nçik_, 
   {{0x55b8011a,0x00000000,0x00000000,0x00000000}},	//   סמאו, --, --, --, 
   {{0xbd04003e,0x3f78008f,0x00000000,0x00000000}},	//   _baéé, _האָס, --, --, 
   {{0x68e00134,0x2ec407b6,0x5338011a,0x00000000}},	//   _ahod, ववृत, קנון_, --, 
   {{0x68e0f03f,0x63a006be,0x6eb841ac,0x00000000}},	//   _bhod, _ənna, ्वरु, --, 
   {{0x7c28f040,0x778402e8,0x20d40166,0x00000000}},	//   _uder, злиз, dçik_, --, 
   {{0x68e00066,0xfb14f041,0x7ae00076,0x64a800bc}},	//   _dhod, _رواج, _thlt, přij, 
   {{0x77681709,0xd04401e4,0x68e000d7,0xa6e01367}},	//   rvex, rmiɩ, _ehod, нжыл, 
   {{0x68e003d5,0x80bc3105,0xf50407e6,0x00000000}},	//   _fhod, ्काइ, язно, --, 
   {{0x68e0f042,0x00000000,0x00000000,0x00000000}},	//   _ghod, --, --, --, 
   {{0x97000075,0xb8642764,0xe7940014,0x98a40356}},	//   _تېخى, _واچو, _ٹانک, arnă_, 
   {{0x68e02195,0x7d08f043,0x35a400f7,0x00000000}},	//   _zhod, _česn, _налг, --, 
   {{0xd7c400f1,0xa694011a,0x00000000,0x00000000}},	//   _اوږه_, _מכסה_, --, --, 
   {{0xc50896d3,0xaf04311c,0xe7e04a18,0x68341432}},	//   _بتول_, зпал, _परमप, müdü, 
   {{0x6834f044,0xa0a001d5,0x161c0210,0x00000000}},	// [14f60] lüdü, хатд, _मजार_, --, 
   {{0x53a40107,0x00000000,0x00000000,0x00000000}},	//   _нақб, --, --, --, 
   {{0x68347236,0xacf4027d,0x2b444f74,0x00000000}},	//   nüdü, سسات, wtoc_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x68e0f045,0x00000000,0x00000000,0x00000000}},	//   _rhod, --, --, --, 
   {{0x68e0f046,0xdb8005f5,0x64a800bc,0x2b44f047}},	//   _shod, эгчи, třik, rtoc_, 
   {{0x2004006d,0x68e0f048,0xfd6402e3,0x2b44f049}},	//   śnie_, _phod, _masị, stoc_, 
   {{0x6da4016c,0x05840023,0x64b80d2b,0xada4024c}},	//   _диҳа, ዝግባእ_, _उदेश, _даҳл, 
   {{0x68e003c6,0x00000000,0x00000000,0x00000000}},	//   _vhod, --, --, --, 
   {{0x39480054,0x7bcc005f,0x245401fb,0x59a4007d}},	//   ńasa_, ļaut, _ầm_, _केकर, 
   {{0x68e0f04a,0xd82c170a,0x28681fbe,0xa9681291}},	//   _thod, _пэ_, _грло_, _دمام_, 
   {{0xe8e8013e,0x76b800cf,0x18a000c0,0x00000000}},	//   _умед_, йлөр_, _пахм, --, 
   {{0x368801c6,0x6d5c015d,0x00000000,0x00000000}},	//   ссөн_, hwpa, --, --, 
   {{0xcfc41c82,0x4adc0b98,0x68340205,0xc8c801f7}},	//   ্ধান, यतिव, büdü, _اوچن_, 
   {{0x68342ca8,0x7d080064,0x00000000,0x00000000}},	//   cüdü, _česo, --, --, 
   {{0x0cb800bc,0x228c03b9,0x55b8011a,0x50640150}},	//   ेकोम, _rüku_, _למוו, нтуа, 
   {{0xe3bc0789,0xfaf80055,0x00000000,0x00000000}},	// [14f70] fañe_, _asūn_, --, --, 
   {{0xefe401f3,0xe3bc00c7,0xaa1400c0,0x00000000}},	//   ማልያ_, gañe_, _дзiц, --, 
   {{0x317c1021,0xe2a40579,0xe2a8040b,0x95940023}},	//   ätzt_, øður_, _ناگن_, _ጎይታን_, 
   {{0x8d7442c6,0x00000000,0x00000000,0x00000000}},	//   عالا, --, --, --, 
   {{0x1f7001e0,0x00000000,0x00000000,0x00000000}},	//   _яһая, --, --, --, 
   {{0x88bc012c,0x6834029f,0xe06003e6,0x0ca80124}},	//   _dvěm, yüdü, _زێڕی, жтәи_, 
   {{0xbd4400c6,0xdca40276,0x64a800bc,0xaa540063}},	//   _تنزي, _ешап, přih, фију_, 
   {{0x05d000af,0xb0600432,0x00000000,0x00000000}},	//   _हड़ब, _įäkl, --, --, 
   {{0xcb3406bb,0xb6a44d87,0x363402f2,0x00000000}},	//   _петъ, дипл, وردس, --, 
   {{0xa3c00aff,0x683403e0,0x00000000,0x00000000}},	//   ्थन_, tüdü, --, --, 
   {{0x442c02bf,0x228c083c,0x35a4d1ac,0x00000000}},	//   лe_, _lüks_, фанг, --, 
   {{0x6834029f,0x7d080153,0x00000000,0x00000000}},	//   rüdü, _česl, --, --, 
   {{0xfd64063f,0xc32c3ee0,0x228c0205,0x68342ca8}},	//   _pasị, مەي_, _nüks_, südü, 
   {{0x321c00d0,0x00000000,0x00000000,0x00000000}},	//   úty_, --, --, --, 
   {{0x6140bcf8,0x2164f04b,0x00000000,0x00000000}},	//   кера, мири_, --, --, 
   {{0x25d400c8,0xf8dc00c5,0x250800f2,0x00000000}},	//   _קוקן_, मतिय, _بروی_, --, 
   {{0x1b00015b,0x6e94036b,0xf268f04c,0x00000000}},	// [14f80] রীতে_, ولرا, _дипл_, --, 
   {{0x9eb40022,0xed34009d,0x00000000,0x00000000}},	//   мшхә, дэдэ, --, --, 
   {{0x3b0c0af5,0x6d5c01f5,0xe1f000ec,0xe3bcf04d}},	//   _ateq_, uwpa, _لسٽ_, rañe_, 
   {{0x6d5c0036,0xda6c01d9,0x00000000,0x00000000}},	//   rwpa, یُن_, --, --, 
   {{0xaae4f04e,0x6b74007b,0x8eb4107b,0xd5cc28d4}},	//   وستو, بطاط, _كەرت, _सुसज, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2918f04f,0xc7b001d3,0x00000000,0x00000000}},	//   èpa_, گڑا_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6f0074bb,0x97a0009d,0xaae435b6,0x00000000}},	//   íoch, врэл, _قسطو, --, 
   {{0x69943580,0x06940873,0x29840022,0x428c0092}},	//   _орех, _ﯞﺍﻗﯩ, _ҭыҧг, ነኛነት_, 
   {{0x46140133,0xd884104c,0x00000000,0x00000000}},	//   ووکر, سپین_, --, --, 
   {{0x59a403ce,0x00000000,0x00000000,0x00000000}},	//   _केटर, --, --, --, 
   {{0xe7e01b61,0x7d080552,0xa6841d4d,0x00000000}},	//   _परिप, _česm, _олдд, --, 
   {{0xc3c400fd,0x00000000,0x00000000,0x00000000}},	//   _җөмл, --, --, --, 
   {{0xd5acf050,0xd56000cf,0x16840244,0x00000000}},	//   _рс_, _атып, _تانێ, --, 
   {{0xbf100598,0x228c2045,0xe7e01a3e,0x41e40150}},	//   лүмә, _püks_, _पराप, діға, 
   {{0x7e7401c0,0xb1441888,0x4394f051,0x5e680114}},	// [14f90] нгах, وییم_, _чапс, жјег_, 
   {{0x2bd000ab,0x00000000,0x00000000,0x00000000}},	//   _तड़ा, --, --, --, 
   {{0xfd7401c0,0x21240208,0xfb840133,0x35900023}},	//   элжэ, _ình_, کدای, _ምዉታት_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x660800e8,0x59a402a0,0xdfe0012c,0xfcd801d3}},	//   _offk, _केजर, _खरिद_, _ہارڈ_, 
   {{0x09b00154,0x00000000,0x00000000,0x00000000}},	//   _ছড়া, --, --, --, 
   {{0x393401c0,0xefdc001f,0xc0dc0023,0x00000000}},	//   хэлс, ንያው_, ንጻል_, --, 
   {{0x660802d0,0x00000000,0x00000000,0x00000000}},	//   _affk, --, --, --, 
   {{0xbb18d82e,0x60c00998,0xf6240107,0x00000000}},	//   _رياض_, _ínmu, ндпо, --, 
   {{0xda00073d,0x00000000,0x00000000,0x00000000}},	//   _ललित_, --, --, --, 
   {{0x55c017de,0xdef002d3,0xca4807d6,0xe624004b}},	//   танғ, ግረና_, _آلمه_, رګون_, 
   {{0xf77047ed,0x6284208d,0x66080200,0x00000000}},	//   _مات_, ejjo, _effk, --, 
   {{0xe72cf052,0xd5cc2e05,0x00000000,0x00000000}},	//   _ще_, _सुरज, --, --, 
   {{0x24500150,0x4254004e,0x00000000,0x00000000}},	//   _ەنيس, ктст, --, --, 
   {{0x76400334,0x00000000,0x00000000,0x00000000}},	//   mgly, --, --, --, 
   {{0x20d40200,0x00000000,0x00000000,0x00000000}},	//   kçiu_, --, --, --, 
   {{0x442450a3,0x764002d0,0x6b800327,0x00000000}},	// [14fa0] _شريف, ogly, xxog, --, 
   {{0x7640f053,0x2008004e,0x00000000,0x00000000}},	//   ngly, _efci_, --, --, 
   {{0xe3bcf054,0x2004068f,0x6e2c02d0,0x8d280139}},	//   maña_, śnia_, _vdbb, фнең_, 
   {{0xe3bc4c27,0xfca8f055,0x6b8001c4,0x9a800116}},	//   laña_, وانو_, txog, ғушл, 
   {{0xc5f80029,0x64a80118,0xddc4002b,0x00000000}},	//   ldēt_, přiv, _yajū, --, 
   {{0xe3bc03f0,0x29640640,0x00000000,0x00000000}},	//   naña_, ењив, --, --, 
   {{0x920800e2,0x98a40139,0x00000000,0x00000000}},	//   _itāļ, ewnı_, --, --, 
   {{0x1cdc0135,0xe3bc0784,0xd9d00131,0x98c00032}},	//   _ཤེར_, haña_, دەمگ, лсыл, 
   {{0xe3bc0bc9,0x00000000,0x00000000,0x00000000}},	//   kaña_, --, --, --, 
   {{0xe3bc0bc9,0x7640f056,0xa968df65,0x00000000}},	//   jaña_, ggly, _низа_, --, 
   {{0x7d08f057,0xe3bc04d4,0xd8700133,0x00000000}},	//   _česk, daña_, _ڕاوب, --, 
   {{0xddc400da,0x28e8010b,0x20d40200,0x00000000}},	//   _sajū, _эдеп_, nçit_, --, 
   {{0xddc42e03,0xc5f80171,0x00000000,0x00000000}},	//   _pajū, edēt_, --, --, 
   {{0x7afcf058,0x76400076,0x69d887b5,0xe3bc9a63}},	//   _èste, cgly, _kyte, gaña_, 
   {{0x81d400d4,0x3db400cc,0x00000000,0x00000000}},	//   товх, _জুনল, --, --, 
   {{0x69d87c1d,0x9550007b,0xf0780116,0x00000000}},	//   _myte, _إخوا, мисә_, --, 
   {{0xe3bc98fa,0x00000000,0x00000000,0x00000000}},	// [14fb0] baña_, --, --, --, 
   {{0x6eb8f059,0x00000000,0x00000000,0x00000000}},	//   ्वगु, --, --, --, 
   {{0x69d81f53,0x200801e7,0xdda827a8,0x64a8013a}},	//   _nyte, _tfci_, чтал_, břit, 
   {{0xa0180267,0xc5f800e2,0x8d7400d1,0xd1380354}},	//   _snöf, ldēs_, داكا, _яхь_, 
   {{0x69d8f05a,0xa3c00b67,0x658806be,0x00000000}},	//   _ayte, ्थि_, dəhm, --, 
   {{0x69d8f05b,0xab900131,0x7f4c02d1,0x1ee4f05c}},	//   _byte, شلىغ, mtaq, _سوزی_, 
   {{0x7f4cf05d,0xa964d266,0x291c0042,0x69d80042}},	//   ltaq, вища_, _cwta_, _cyte, 
   {{0xa3c01b6e,0xe3bc09c2,0xdbd800e8,0x69d80240}},	//   ्था_, zaña_, _wàñi, _dyte, 
   {{0x7f4cf05e,0xe3bc0bc9,0x69d802d0,0xa018007c}},	//   ntaq, yaña_, _eyte, _enög, 
   {{0x7c2c09cc,0x7f4c0113,0x76400153,0x0b882c25}},	//   ðarf, itaq, ugly, _ясси_, 
   {{0x8934f05f,0x69d8f060,0x0934b226,0x7f4c0309}},	//   _معنا, _gyte, _مرنج, htaq, 
   {{0xe7b0f061,0xe3bc5d55,0x7f4cf062,0xf4941429}},	//   امید, waña_, ktaq, трою, 
   {{0xe3bcf063,0x386cf064,0x7f4c0309,0xe45c007c}},	//   taña_, mder_, jtaq, dnöd_, 
   {{0x7afc00d5,0x18b01a98,0x69d80108,0xe3600a5b}},	//   _éstu, _шәһр, _yyte, јкри, 
   {{0xe3bc094a,0x386cf065,0xa018049f,0xe5a002bf}},	//   raña_, oder_, _onöd, _вищи, 
   {{0xfbc41d1f,0xe3bc001c,0xafe4036b,0xc5f800e2}},	//   _هڪ_, saña_, вобл, rdēt_, 
   {{0xe3bc26ce,0x386c1072,0x6fd400d4,0x5f000454}},	// [14fc0] paña_, ider_, тівц, изта, 
   {{0xe3bc094a,0x386c5086,0x2d944d75,0x00000000}},	//   qaña_, hder_, крес, --, 
   {{0x386cf066,0x7f4c013c,0xe45c04cc,0xec480006}},	//   kder_, ataq, vlöz_, дзел_, 
   {{0x386cf067,0x6ac8f068,0xdcac3baf,0x69d83167}},	//   jder_, ाक्र, يىل_, _ryte, 
   {{0x69d8f069,0x7f4c16b8,0x386cf06a,0x0d8401e0}},	//   _syte, ctaq, dder_, _әһен, 
   {{0x69d80118,0x5a30651e,0x00000000,0x00000000}},	//   _pyte, аншт, --, --, 
   {{0x69d8069c,0x7bc816b8,0x386cf06b,0x3ec4014b}},	//   _qyte, _exeu, fder_, _сирҳ, 
   {{0x386c48bb,0x69d83f99,0xed74001f,0x48d00154}},	//   gder_, _vyte, _የሚታይ_, াগ্র, 
   {{0xc6f81830,0x4734026a,0xa0186df9,0x69d8039a}},	//   нних_, ћнос, _koör, _wyte, 
   {{0x69d803cd,0xdd8c01d3,0xac1801e0,0xa0480b82}},	//   _tyte, _اڈے_, _хоҡу_, _ነጻነታ, 
   {{0x2a7c00d2,0x7c2c05f7,0xa9240124,0x386c072b}},	//   _intb_, ðarg, _рдел, bder_, 
   {{0x7f4c0986,0x76400124,0x753400e5,0x00000000}},	//   ytaq, аҭәа, ázza, --, 
   {{0x699403e6,0x7f4c0393,0x07341d1b,0x00000000}},	//   _سێکس_, xtaq, _селю, --, 
   {{0x28ac007d,0xd1f80092,0x439400fb,0x44b4013d}},	//   जोरि, ዋጋት_, _ҡайс, _әбис, 
   {{0x4034f06c,0xc1042e67,0x7f4c0784,0x206800cf}},	//   левс, اوري, wtaq, мшап_, 
   {{0x7f4c7e99,0x26dcf06d,0x4e94036b,0xa49002f2}},	//   ttaq, llto_, یشلر, _ئیحت, 
   {{0xe3bc28f2,0x1ea8092f,0x26dc1214,0x7f4cf06e}},	// [14fd0] maño_, وائي_, olto_, utaq, 
   {{0x7f4c0af5,0xe3bc1709,0xac940131,0x24880175}},	//   rtaq, laño_, ۇچقا_, ljcm_, 
   {{0x386cf06f,0x7f4cf070,0xc5d4015b,0x8634001f}},	//   yder_, staq, হেরপ, _በአንድ, 
   {{0xe7e02274,0xe3bc0113,0x7f4c0381,0x2ca4025c}},	//   _परंप, naño_, ptaq, ghod_, 
   {{0x386c02bf,0x6f00007b,0x7f4cf071,0x3ae80124}},	//   vder_, íoct, qtaq, húpe_, 
   {{0x539c0a1e,0x386cf072,0x26c0020c,0x3ae800c7}},	//   וידו, wder_, ékol_, kúpe_, 
   {{0x27e4f073,0x99840421,0xf8b801c0,0x3ae800c7}},	//   _azon_, manū_, нөд_, júpe_, 
   {{0x386cf074,0x2ca4f075,0xe614c5dc,0x7c2c05f7}},	//   uder_, chod_, ңды_, ðard, 
   {{0x386cf076,0x6d58145e,0xe3bc0077,0x00000000}},	//   rder_, _âtar, daño_, --, 
   {{0x27e400f3,0x386cf077,0xf8c001d9,0x00000000}},	//   _dzon_, sder_, _گۅبێ, --, 
   {{0x39149702,0x00000000,0x00000000,0x00000000}},	//   _смер, --, --, --, 
   {{0xe3bc09d7,0xc8940063,0x26dcf078,0x299800df}},	//   gaño_, _вршњ, alto_, _אסעמ, 
   {{0x69cc0194,0x649c00b0,0x200400bc,0x3a2401f4}},	//   _øber, _tëin, ěnil_, _kelp_, 
   {{0x2ca40010,0x00000000,0x00000000,0x00000000}},	//   zhod_, --, --, --, 
   {{0xe3bc0cc3,0x3ae800e4,0x00000000,0x00000000}},	//   baño_, cúpe_, --, --, 
   {{0x0c780020,0xa064f079,0xe3bc04d4,0xe0408fa3}},	//   _በሌሎች_, ласа_, caño_, йнси, 
   {{0x69d80b67,0x00000000,0x00000000,0x00000000}},	// [14fe0] _पुनी, --, --, --, 
   {{0x3a24020b,0xa3c038d2,0x98a400bc,0x20e4037e}},	//   _nelp_, ्थर_, trně_, のiny_, 
   {{0x88bc0316,0x2ca4f07a,0x00000000,0x00000000}},	//   _květ, thod_, --, --, 
   {{0xdd8cc009,0x00000000,0x00000000,0x00000000}},	//   ثوم_, --, --, --, 
   {{0x3a2404cc,0xc2c810e5,0x2ca4f07b,0x3ae800e4}},	//   _belp_, _سبیل_, rhod_, zúpe_, 
   {{0xdca00131,0xda6001c6,0x3a240205,0x6d24007b}},	//   _һаси, йвчи, _celp_, _معرك, 
   {{0x6f041bb7,0x2ca403a2,0xa018002d,0xada4f07c}},	//   _hukc, phod_, _koöp, _савл, 
   {{0x6d4cf07d,0x6f040301,0xdca0022e,0x5ca0014b}},	//   _iqba, _kukc, _ласи, _лисб, 
   {{0x6f040309,0x7c2c08a7,0xa01800c7,0x7bc4e978}},	//   _jukc, ðare, _moöp, şhur, 
   {{0xfcd40023,0xa0180112,0x45d40305,0x3ae8035b}},	//   _ክወጹ_, _knöc, иопс, túpe_, 
   {{0x7afcf07e,0xe3bc2b76,0x6d5801b8,0x2688104e}},	//   _èsta, taño_, _ätad, _үбеп_, 
   {{0x26dc0a73,0xa3c00fc8,0xa34405f5,0x7afc003e}},	//   slto_, ्थल_, лэгл, _éstr, 
   {{0x68440022,0x27e4010f,0x3a243046,0xe3bcf07f}},	//   _анҵа, _uzon_, _yelp_, raño_, 
   {{0xd3701e87,0xe3bc0789,0x2d9807a5,0x3ae800c7}},	//   سۇپ_, saño_, kype_, púpe_, 
   {{0x6f04f080,0x5184f081,0x6d4c0327,0x00000000}},	//   _aukc, бута, _nqba, --, 
   {{0x6f047929,0x2d98003b,0xa018aa9a,0x43940114}},	//   _bukc, dype_, _snöb, _ваис, 
   {{0x73c0dcc1,0x6d4c01d9,0x6f04003e,0xa3c00490}},	// [14ff0] _дәре, _aqba, _cukc, ्थळ_, 
   {{0x88bc012c,0x6f0401a9,0xe2a800ae,0x00000000}},	//   _zvět, _dukc, _ساخن_, --, 
   {{0x672004ba,0x7cd801d3,0x6f000332,0x69dc0037}},	//   _lwoj, نڈرز_, íocr, üpel, 
   {{0x3a240048,0xb1980375,0x672001e1,0x00a002f2}},	//   _selp_, _ייתכ, _owoj, _بیرێ, 
   {{0x672001e1,0x00000000,0x00000000,0x00000000}},	//   _nwoj, --, --, --, 
   {{0xeb94d729,0x7c2c05f7,0x00000000,0x00000000}},	//   риш_, ðarb, --, --, 
   {{0x0dc810f5,0x67200241,0x3a2401a4,0x00000000}},	//   _бути_, _awoj, _velp_, --, 
   {{0x67201556,0x4df40316,0x7d1403ac,0xb7c000d8}},	//   _bwoj, ्खरै_, _itzs, çãof, 
   {{0x8b58f082,0x3a240490,0x188800fd,0x3704033a}},	//   _مجلس_, _telp_, _үсеп_, јпог, 
   {{0x88bc038e,0x87e800ee,0x6720033f,0x369467ba}},	//   _svět, ылың_, _dwoj, ршис, 
   {{0x3cec0218,0xa82400d1,0x855401d5,0x00000000}},	//   _khev_, اۋۇل_, میور_, --, 
   {{0xa3c00882,0x3cec05b1,0x2004012d,0x88bc01ef}},	//   ्थं_, _jhev_, śnij_, _dvěs, 
   {{0x78a8168c,0xe3bc0165,0x28980a7c,0x00000000}},	//   mhev, lañj_, _שינא, --, 
   {{0x78a8f083,0xe7345a82,0xe64000db,0xf1a80345}},	//   lhev, _теш_, _дешп, نازه_, 
   {{0x6f04f084,0xb9dc0023,0x64a800bc,0x0594010a}},	//   _sukc, _ኢኺ_, přip, _лăрм, 
   {{0x78a8f085,0x7398f086,0x66f800b8,0x00000000}},	//   nhev, _атос_, _vākś, --, 
  
   {{0xa0644170,0xa3c00a28,0x88bc013a,0x00000000}},	// [15000] шата_, ्थः_, _zvěs, --, 
   {{0x2d98f087,0x6f0401fa,0xf1d00cab,0xc3a401ee}},	//   type_, _vukc, _дөбө, _ылыҫ, 
   {{0x69d80574,0xdd1c1f98,0x00000000,0x00000000}},	//   _पुढी, _píšt, --, --, 
   {{0x7d0804b9,0xeb985402,0x3cec0455,0xce340014}},	//   _čest, кие_, _chev_, _گوسک, 
   {{0x3cec0218,0x26c001d3,0x2d9802f0,0x78a8e3ad}},	//   _dhev_, ékok_, sype_, dhev, 
   {{0x78a800e4,0x2d980124,0xed5801c4,0x00000000}},	//   ehev, pype_, _иог_, --, 
   {{0x6720006d,0x298430c8,0xa8a4f088,0x6d4c2a1f}},	//   _swoj, рылг, ирик, _uqba, 
   {{0x67200699,0x78a802e8,0xe8940032,0x00000000}},	//   _pwoj, ghev, рбиә_, --, 
   {{0x6d5801b8,0x6a8400c0,0x57f00395,0xaa44be81}},	//   _ätab, _клаа, опът, _везл, 
   {{0x7d0c00d2,0x78a800e4,0x6ee000d7,0x00000000}},	//   _ínsî, ahev, dôbk, --, 
   {{0xe5c401f4,0x47840150,0x78a8f089,0x00000000}},	//   рспо, рықб, bhev, --, 
   {{0x6720006d,0x78a8f08a,0x00000000,0x00000000}},	//   _twoj, chev, --, --, 
   {{0x6720019f,0x2004033f,0x3688009d,0x69d828fe}},	//   _uwoj, śnik_, тсөн_, _पुती, 
   {{0x1b00015b,0xd6d001e2,0x00000000,0x00000000}},	//   রীকে_, _وتوغ, --, --, 
   {{0x454401ed,0x154000d8,0xcfb400eb,0x00000000}},	//   _انعق, _дејм, _ঝুলন, --, 
   {{0xd5f8025f,0x6ee00af2,0x3f88005a,0xd0180107}},	//   _בפור, lôbh, txau_, ифу_, 
   {{0x4428f08b,0x9e040f14,0x6d48004e,0xa3443f1b}},	// [15010] _iea_, ачел, àfan, _тэйл, 
   {{0x4428f08c,0x78a88d48,0x4fc4f08d,0xdd98f08e}},	//   _hea_, zhev, іста, кше_, 
   {{0x4428f08f,0x3cec0218,0xbb2c0075,0x4ea416a4}},	//   _kea_, _phev_, ﯩﺪﻩ_, црта, 
   {{0x3cec0211,0x4428f090,0x78a80200,0x00000000}},	//   _qhev_, _jea_, xhev, --, 
   {{0x4428f091,0x5ab40107,0x9f8401af,0x658806be}},	//   _mea_, ақар_, _тѳнд, məhu, 
   {{0x4428f092,0x0b880063,0x800801d3,0x00000000}},	//   _lea_, јсци_, _جرگہ_, --, 
   {{0x4428f093,0x3cec0211,0xb7bc0276,0x69d806ab}},	//   _oea_, _thev_, maţi, _पुदी, 
   {{0xc31c2f8b,0x44281958,0xb7bc00a8,0x7e640ac5}},	//   _তিনি_, _nea_, laţi, lehp, 
   {{0x78a8f094,0xbb2c0131,0x00000000,0x00000000}},	//   rhev, ﯩﺪﻯ_, --, --, 
   {{0x78a8f095,0x7c28f096,0x4428f097,0xb7bc084c}},	//   shev, _heer, _aea_, naţi, 
   {{0x4428f098,0x7c28f099,0x78a8168c,0xf770015e}},	//   _bea_, _keer, phev, زاک_, 
   {{0x4428f09a,0x7c28f09b,0x46e821cb,0xc20805d0}},	//   _cea_, _jeer, лдөн_, _טה_, 
   {{0xc32c0ed1,0xd7f82bb6,0xfd4c0208,0x00000000}},	//   نەي_, _руж_, _choạ, --, 
   {{0x7c28f09c,0x4428f09d,0xf1d00228,0x7e64020b}},	//   _leer, _eea_, зөмө, jehp, 
   {{0x4428f09e,0xb7bc0276,0x26c0013f,0x77680472}},	//   _fea_, daţi, ɑko_, lwex, 
   {{0x7c28f09f,0x4428f0a0,0x6ee00109,0x00000000}},	//   _neer, _gea_, môbi, --, 
   {{0x733400cf,0xe0d40117,0x60206171,0x998401ef}},	// [15020] _اربئ, ёву_, ядта, kanů_, 
   {{0xb8e8ce91,0xb7bc084c,0x4428f0a1,0xe45c023a}},	//   _ིམ_, gaţi, _zea_, nnön_, 
   {{0x7c28f0a2,0xe45c01b8,0xa0180790,0x4428f0a3}},	//   _beer, inön_, _inön, _yea_, 
   {{0x7c286928,0x308400c6,0x77680472,0x14d801f9}},	//   _ceer, _الحف, kwex, ठविण, 
   {{0x7c28f0a4,0x7c2c2880,0x6bd4f0a5,0xb7bc0311}},	//   _deer, ðara, حتار, baţi, 
   {{0xb7bc00a8,0x753c012d,0x3ae80022,0xf3e800eb}},	//   caţi, ńszy, túpa_, _গলার_, 
   {{0x7c2881f1,0xbdc401af,0x00000000,0x00000000}},	//   _feer, _дарҫ, --, --, 
   {{0x7c28f0a6,0x3ae800c6,0x5ba44701,0x00000000}},	//   _geer, rúpa_, ркәм_, --, 
   {{0x1830007b,0x00000000,0x00000000,0x00000000}},	//   سريح, --, --, --, 
   {{0x7c28f0a7,0xdc5400aa,0x44280c30,0xaac46a0e}},	//   _zeer, _پرېک, _sea_, _اترن, 
   {{0x4428f0a8,0x7c28f0a9,0x0dc40092,0xa3a80456}},	//   _pea_, _yeer, _ጸሐፊ_, कैन_, 
   {{0x7c28cd24,0xb7bc084c,0x442800fb,0x782400f7}},	//   _xeer, zaţi, _qea_, _ۇعۇل, 
   {{0x4428f0aa,0xddc40427,0x7cf00fac,0x56240183}},	//   _vea_, _majš, bårf, _মাৰক_, 
   {{0x44281028,0xddc409a8,0x6ab400c5,0x00000000}},	//   _wea_, _lajš, _अगोर, --, 
   {{0xb7bc0311,0x29400131,0x44280c18,0xd6540375}},	//   vaţi, _ﻛﯚﭖ_, _tea_, _ליגת_, 
   {{0xfd4c07ae,0x4428f0ab,0xddc4f0ac,0xd01001ed}},	//   _thoạ, _uea_, _najš, فلِ_, 
   {{0x59dc11bc,0x7c28f0ad,0xb7bc084c,0x1ee47254}},	// [15030] _पुनर, _reer, taţi, موری_, 
   {{0x7c28f0ae,0x8108004b,0xdde811e6,0x2b440051}},	//   _seer, _پردې_, هراه_, duoc_, 
   {{0xb7bc00a8,0x7c28f0af,0xa3c008f2,0x0dc803fb}},	//   raţi, _peer, ्थक_, буци_, 
   {{0x3ea00054,0x7c28f0b0,0xb7bc054e,0x7e640112}},	//   skht_, _qeer, saţi, sehp, 
   {{0x7c28f0b1,0x6294f0b2,0x9f4c0598,0xb7bc0311}},	//   _veer, _koxo, ägä_, paţi, 
   {{0x7c28a6e7,0x62941bce,0x6ab80175,0xea58ecb2}},	//   _weer, _joxo, _cmtf, изчә_, 
   {{0x7c286fe5,0x6294f0b3,0x9a2400db,0x3c4401f7}},	//   _teer, _moxo, _ۇعان, _وَسِ, 
   {{0x62940694,0x6ab82959,0xddc40010,0x7c2803ac}},	//   _loxo, _emtf, _gajš, _ueer, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6294f0b4,0xa6e00137,0xc0bc0023,0x8af80395}},	//   _noxo, мжыл, _ተኽሊ_, _гнус_, 
   {{0xe45c014a,0xe0dc0248,0xf50400f5,0x00000000}},	//   rnön_, _okò_, юзно, --, 
   {{0xe0dc0241,0xe45c007c,0xf8bc0950,0x00000000}},	//   _nkò_, snön_, _ऋषिय, --, 
   {{0x6294f0b5,0x5bb4012d,0x00000000,0x00000000}},	//   _boxo, _अधोव, --, --, 
   {{0xe0dcf0b6,0x62940de2,0x35a430ab,0xa29c0073}},	//   _akò_, _coxo, _малг, _ऐकण्, 
   {{0x6294f0b7,0x00000000,0x00000000,0x00000000}},	//   _doxo, --, --, --, 
   {{0x6ab408ec,0xc0bc02d3,0x26c000d0,0x00000000}},	//   _अग्र, _ተኽለ_, ékov_, --, 
   {{0x62940077,0xddc40219,0xe0d40111,0xa03000db}},	// [15040] _foxo, _rajš, іву_, بىقت, 
   {{0xed58f0b8,0x7c2c05f7,0x629401c6,0x53a4023b}},	//   иоз_, ðarn, _goxo, _мақб, 
   {{0xa0185b00,0xac080120,0x00000000,0x00000000}},	//   _knöl, анеа_, --, --, 
   {{0x237419d2,0xb864001f,0x629401e2,0xc31c00cc}},	//   _امید_, ዲቀጥል_, _zoxo, _তিতি_, 
   {{0x49c80184,0x629401e2,0x3094001f,0x00000000}},	//   әһен_, _yoxo, መዝገብ_, --, 
   {{0x6294f0b9,0x5f243e2e,0x2ea401ed,0x00000000}},	//   _xoxo, _форм_, _بھری_, --, 
   {{0xe3bc0428,0xddc40010,0x00000000,0x00000000}},	//   rañi_, _tajš, --, --, 
   {{0x7cf01506,0x290004f3,0xe45c04cc,0x00000000}},	//   gård, öka_, gnöl_, --, 
   {{0x5ebc015b,0x2b440208,0x69940014,0x69d816ae}},	//   ্তরে, quoc_, _ژێتس_, _पुरी, 
   {{0x6ab8003c,0x00000000,0x00000000,0x00000000}},	//   _umtf, --, --, --, 
   {{0x29180308,0x290c0135,0x00000000,0x00000000}},	//   ípad_, qqfa_, --, --, 
   {{0x06c805f5,0x62941bce,0xe3bc05c7,0xf6f40014}},	//   ргүй_, _soxo, iañv_, _ہٲنگ, 
   {{0x62945b7f,0xa018007c,0x00000000,0x00000000}},	//   _poxo, _snöo, --, --, 
   {{0xf15823c9,0xdee4001f,0x4abc0490,0xe0dc0100}},	//   әптә_, ማችን_, ्चिव, _skò_, 
   {{0x7cf001e3,0x5bb400dc,0x00000000,0x00000000}},	//   låre, _अध्व, --, --, 
   {{0x261410f7,0x6294f0ba,0x0b38001f,0x26c80306}},	//   पुरी_, _woxo, _ከፍተኛ, čbou_, 
   {{0x6294f0bb,0x7cf03402,0x4abc0b3c,0x65780162}},	// [15050] _toxo, nåre, ्चाव, lvth, 
   {{0xa1840bd6,0x06cc0154,0x00000000,0x00000000}},	//   _дымл, _রীতি, --, --, 
   {{0x1cdc0003,0xbc181fe2,0x7cf0f0bc,0x4c1802e3}},	//   _ཤེད_, білі_, håre, _ịtụk, 
   {{0x257800e2,0x7f58014b,0x00000000,0x00000000}},	//   _mīl_, _ламс_, --, --, 
   {{0x65640882,0x7cf0049f,0x6d5801e3,0xdb682cdd}},	//   ākhy, vård, _ätan, ррел_, 
   {{0x7cf000ed,0x6f6000db,0x00000000,0x00000000}},	//   dåre, _سۇمم, --, --, 
   {{0x81dc03f4,0xa3a800ab,0x2004033f,0x00000000}},	//   তের_, कैत_, śniu_, --, 
   {{0x7e7401a1,0xe3bc002e,0x00000000,0x00000000}},	//   _hazp, lañu_, --, --, 
   {{0xb3440139,0xe45c002f,0x661400a2,0xbae400ae}},	//   _miçç, rnöl_, _şyka, _فكري, 
   {{0xca74f0bd,0x7e7401c4,0xe3bc0694,0xa018007c}},	//   _يالغ, _jazp, nañu_, _snöl, 
   {{0x47dc04c5,0xe614f0be,0x7e7400de,0xd5840133}},	//   মেলী, ядэ_, _mazp, ڵێکه_, 
   {{0x7cf00ec3,0x49040150,0x06c80137,0x00000000}},	//   båre, _قولق, йгөй_, --, 
   {{0x1cdc025c,0xe3bc0156,0x87b8059f,0x59dc0037}},	//   _ཤེན_, zañv_, _мушт_, _पुतर, 
   {{0x7e74f0bf,0x1da829d9,0x311408da,0x26c000e5}},	//   _nazp, चनात, зфас, ékot_, 
   {{0x7038f0c0,0x35a401c0,0xd76000f1,0x00000000}},	//   йчас_, _хайг, _رنګی, --, 
   {{0x7c2c09cc,0xa6e001a8,0x673402d2,0xe53800d9}},	//   ðarl, öðvu, _ógjö, _התקר, 
   {{0xee38f0c1,0x81dc04c5,0x7e748489,0xa3a80456}},	// [15060] йна_, তেল_, _bazp, कैद_, 
   {{0xb8cc031c,0x9f4801d3,0xee38f0c2,0xe3bc030a}},	//   _པཾ_, émát_, ёне_, tañv_, 
   {{0xe2980302,0xdcac1cbf,0x00000000,0x00000000}},	//   _השיר, گىن_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdcacf0c3,0x2004012c,0xac080124,0x00000000}},	//   دىن_, ěnit_, анҵа_, --, 
   {{0x7cf099c0,0x5bc0009a,0xa1100345,0x00000000}},	//   våre, عقول, _توێت, --, 
   {{0x9960013d,0xdd2c01ef,0x00000000,0x00000000}},	//   етыл, _těšn, --, --, 
   {{0x6e2c3a0e,0x7e7405f5,0x7cf00726,0x00000000}},	//   _hebb, _zazp, tåre, --, 
   {{0x981071a8,0x6e2cf0c4,0xaa44f0c5,0xea5800f0}},	//   ربيا, _kebb, _неал, _греј_, 
   {{0x7cf0ad6a,0x61040109,0x6e2cf0c6,0xfd6802e3}},	//   råre, _lŕla, _jebb, jupụ, 
   {{0x6e2c1c1d,0x7cf011ad,0xa01801e3,0x8cb0012d}},	//   _mebb, såre, _snöm, ंसपो, 
   {{0x8ec41d4c,0x7cf00267,0xa01803e0,0x2ca4007c}},	//   ্তিগ, påre, _pnöm, nkod_, 
   {{0x68e0f0c7,0xd61400aa,0xd7e002bf,0x998400f3}},	//   _ikod, غتیا_, _пішо, manš_, 
   {{0x27e4357f,0x6e2cf0c8,0x2904f0c9,0x00000000}},	//   _iyon_, _nebb, _hioa_, --, 
   {{0x26dcf0ca,0x7e740f72,0x27e400ca,0x29040093}},	//   moto_, _razp, _hyon_, _kioa_, 
   {{0x26dcf0cb,0xbf10beb4,0x213c0841,0x98a40064}},	//   loto_, күмә, čuh_, psną_, 
   {{0x6e2cf0cc,0x68e002ce,0x2ca40280,0x644c4b26}},	// [15070] _bebb, _mkod, dkod_, mgci, 
   {{0x27e4f0cd,0x4254109c,0x29040208,0xa018007c}},	//   _myon_, _کنگر, _lioa_, _knök, 
   {{0x27e4f0ce,0x68e0f0cf,0x29040093,0x81d405f5}},	//   _lyon_, _okod, _oioa_, _цонх, 
   {{0x644cf0d0,0x6e2c7361,0x26dcf0d1,0x3b0402d1}},	//   ngci, _eebb, hoto_, _silq_, 
   {{0x26dcf0d2,0x6e2c06bb,0x27e4f0d3,0xe3bc05c7}},	//   koto_, _febb, _nyon_, mañs_, 
   {{0xfe7075e4,0x29040418,0x68e0f0d4,0x26dcefd2}},	//   _جگر_, _aioa_, _akod, joto_, 
   {{0x27e4357f,0x26dcf0d5,0x2d9c00fd,0x291400ae}},	//   _ayon_, doto_, _ütep_, وقود_, 
   {{0x27e402c4,0xf7707092,0x6e2cf0d6,0xe3bc0165}},	//   _byon_, ناخ_, _zebb, nañs_, 
   {{0xa8043eba,0x6e2c3699,0xba5403f6,0x00000000}},	//   _riñó, _yebb, _овај, --, 
   {{0x26dcf0d7,0x68e0f0d8,0x95b00daf,0xe3bc0165}},	//   goto_, _ekod, ермә, hañs_, 
   {{0xa80409c2,0x60dc0113,0xc98400a8,0xe3bc030a}},	//   _piñó, koqm, _пуци, kañs_, 
   {{0x2008f0d9,0xfd680521,0x79800857,0xe3bc0156}},	//   _ngci_, wupụ, _irlw, jañs_, 
   {{0x26dcf0da,0xe72cf0db,0x39a00014,0xe3bc0165}},	//   boto_, _ше_, _سیکہ, dañs_, 
   {{0x26dcf0dc,0xb91000cd,0x2904005a,0xaf3400d1}},	//   coto_, _bhoḥ_, _zioa_, ېرات, 
   {{0x6e2cf0dd,0x27e41529,0x644c009a,0x74b801c0}},	//   _rebb, _zyon_, bgci, _муис_, 
   {{0x6e2cf0de,0xe3bc05c7,0xa364031c,0x753400e5}},	//   _sebb, gañs_, żaġġ_, ázzu, 
   {{0x6e2cf0df,0xaf04ba4c,0x27e4022e,0x00000000}},	// [15080] _pebb, дпал, _xyon_, --, 
   {{0xee38f0e0,0x6da4f0e1,0x38b00332,0x79800142}},	//   іне_, миза, _hárd_, _orlw, 
   {{0xe3bc0165,0x6e2c0477,0xb91000b8,0x60dc014f}},	//   bañs_, _vebb, _ghoḥ_, boqm, 
   {{0x6e2cf0e2,0x26dc0170,0x6d580054,0x102453b2}},	//   _webb, zoto_, _ätam, _سکرپ, 
   {{0x99840960,0x798003cb,0x6e2cf0e3,0x26dcf0e4}},	//   vanš_, _arlw, _tebb, yoto_, 
   {{0x2ca4f0e5,0x29040bba,0x26dc0798,0x798002d0}},	//   skod_, _sioa_, xoto_, _brlw, 
   {{0xde001e80,0x27e423ee,0x00000000,0x00000000}},	//   _апри, _syon_, --, --, 
   {{0x88bc0316,0x27e402e2,0x6da4035b,0x80c0190c}},	//   _hvěz, _pyon_, _еиҳа, रोपे, 
   {{0x26dcf0e6,0x69bc01ad,0xa0181876,0xa29c0073}},	//   toto_, _वेरी, _snök, _ऐकल्, 
   {{0x29040175,0xe3bc0156,0xe5c400f5,0x00000000}},	//   _wioa_, zañs_, дсмо, --, 
   {{0x29040618,0x99800014,0x38b00332,0x60dc03f0}},	//   _tioa_, _للٕو, _bárd_, yoqm, 
   {{0x291c81f1,0x68e0009f,0x2b44054e,0x00000000}},	//   _itta_, _ukod, oroc_, --, 
   {{0x80c00807,0x27e4f0e7,0xe3bc05c7,0x60dc014f}},	//   रोफे, _uyon_, vañs_, voqm, 
   {{0x26dc01d9,0x45d4f0e8,0x80c005d7,0x00000000}},	//   qoto_, _полс, रोने, --, 
   {{0x7c2c09f3,0xe3bc0165,0xe9cc43a2,0x00000000}},	//   ðark, tañs_, лкi_, --, 
   {{0xb9f81954,0xd4c40153,0x00000000,0x00000000}},	//   _ህዋ_, _асьп, --, --, 
   {{0xe3bcf0e9,0x2bdcf0ea,0xd434009f,0x60dc01a9}},	// [15090] rañs_, _फुला, _شعيب, roqm, 
   {{0x291cf0eb,0x2b44f0ec,0xe3bc030a,0x60dc047e}},	//   _otta_, droc_, sañs_, soqm, 
   {{0x4034f0ed,0x38b000c7,0x6ee00109,0x2b440165}},	//   _пенс, _háre_, tôbr, eroc_, 
   {{0x60dc0477,0xfb342ec5,0x6614010e,0x7f94009d}},	//   qoqm, ендэ, _şykl, _замх, 
   {{0x291cf0ee,0x38b001e1,0x2d8c1196,0x00000000}},	//   _atta_, _járe_, äfer_, --, 
   {{0x7f4c0bc9,0xdcec0c3c,0xa018007c,0x0ca8035b}},	//   muaq, ıdır, _snöh, зтәи_, 
   {{0x7f4cc203,0xcd2801d9,0xaa540063,0x0dc80556}},	//   luaq, _ٲسِن_, хију_, _жути_, 
   {{0x2b44f0ef,0x8c640139,0x97300271,0x69bc0073}},	//   broc_, _итуд, نکتا, _वेळी, 
   {{0x291cf0f0,0x7f4c0140,0x2b445dae,0x9ba000db}},	//   _etta_, nuaq, croc_, _جەشى, 
   {{0x499001b9,0x3ae80419,0x4b500345,0xa9200419}},	//   _چیور, kúpi_, _ئێور, šľan, 
   {{0x7f4c0357,0x4990072d,0x00000000,0x00000000}},	//   huaq, _نیور, --, --, 
   {{0x7c2c1f60,0xdd2c00b8,0xa6e001a8,0x7d08f0f1}},	//   ðarh, _aśūn, öðru, _jies, 
   {{0x7d08f0f2,0x386cf0f3,0x96d001d2,0x7f4c0194}},	//   _mies, meer_, _искә, juaq, 
   {{0x7d08f0f4,0x386c1af3,0x78a8f0f5,0x55c00166}},	//   _lies, leer_, lkev, _җәүз, 
   {{0x2908003e,0x7afcbb33,0x7d0803ac,0x00000000}},	//   _ébat_, _èstu, _oies, --, 
   {{0xef18f0f6,0x7d08f0f7,0x78a8f0f8,0xd174678d}},	//   зма_, _nies, nkev, нығы, 
   {{0x7f4c20ac,0xe4d001d5,0x21d80150,0xdfcc00ec}},	// [150a0] guaq, _حقيد, _ﺃﻜﺜﺭ, ٽيل_, 
   {{0x386cf0f9,0x7d08f0fa,0x7cf00267,0xa38000d8}},	//   heer_, _aies, våra, ções, 
   {{0x7d08f0fb,0x386cf0fc,0x13a83e66,0x00000000}},	//   _bies, keer_, _رنگی_, --, 
   {{0x7d083903,0x2b44030a,0x291c01b9,0x386cf0fd}},	//   _cies, troc_, _rtta_, jeer_, 
   {{0x7d08f0fe,0x386cf0ff,0x7c640131,0x2b44030a}},	//   _dies, deer_, ئامل, uroc_, 
   {{0x2b44f100,0x7d08f101,0xd1d00092,0x88bc013a}},	//   rroc_, _eies, _ጥሰት_, _uvěz, 
   {{0x7d08f102,0x8cb0033f,0x2f14032e,0xa018007c}},	//   _fies, ंसदो, _hæg_, _snöi, 
   {{0x386c9b80,0x2b44f103,0x81dc03d4,0x78a801d3}},	//   geer_, proc_, তেক_, gkev, 
   {{0xc6f88171,0x962400cc,0x00000000,0x00000000}},	//   мних_, _মাজম_, --, --, 
   {{0x78a8b85f,0x7d0802c1,0x38b001e1,0x1618012d}},	//   akev, _zies, _ráre_, पुलर_, 
   {{0x386c292b,0x2f1404ce,0x45d455d9,0x7e600112}},	//   beer_, _læg_, тонс, _ölpe, 
   {{0xe8f800f4,0x7f4c0357,0xb864511e,0x7d0802b9}},	//   _эле_, yuaq, _لاهو, _xies, 
   {{0x7c2c2833,0x46581cb8,0x7cf001bf,0x2f1408a5}},	//   ðari, _жалю_, kårn, _næg_, 
   {{0x58900022,0x1718008f,0x57f000d4,0x3ae80419}},	//   _ашәу, _צווע, _спіт, túpi_, 
   {{0xd5acf104,0x403400d8,0x00000000,0x00000000}},	//   _сс_, кевс, --, --, 
   {{0x7f4cb0b3,0x00000000,0x00000000,0x00000000}},	//   tuaq, --, --, --, 
   {{0x439404b1,0x00000000,0x00000000,0x00000000}},	// [150b0] _рапс, --, --, --, 
   {{0x7d08f105,0x7f4c3209,0x752c068f,0x386cf106}},	//   _sies, ruaq, _łazi, zeer_, 
   {{0x7d08f107,0x7f4c0869,0x386ca121,0x5634010f}},	//   _pies, suaq, yeer_, גאבע_, 
   {{0x38b001ed,0x7d08025c,0x386c0009,0x20d40327}},	//   _márc_, _qies, xeer_, sħib_, 
   {{0x7d08f108,0x386c1aa7,0x7f4c1730,0x7cf0072b}},	//   _vies, veer_, quaq, bårn, 
   {{0x386cf109,0x4bd8a44e,0x00000000,0x00000000}},	//   weer_, ربند_, --, --, 
   {{0x7d08f10a,0x386cf10b,0x78a80006,0x00000000}},	//   _ties, teer_, tkev, --, 
   {{0x7d084d25,0xadf40116,0x386c003e,0x6680036b}},	//   _uies, _росә, ueer_, یینل, 
   {{0x386c8d9d,0x3a74f10c,0x78a8f10d,0x3b54f10e}},	//   reer_, _илар, rkev, _шкар, 
   {{0xa680f10f,0x386cf110,0x78a8f111,0xc7a8007b}},	//   альд, seer_, skev, عديل_, 
   {{0x386c0af9,0xf77003e6,0xb994007b,0x188800d8}},	//   peer_, _چات_, _جلاب, _нсдп_, 
   {{0xf770315f,0x00000000,0x00000000,0x00000000}},	//   _نات_, --, --, --, 
   {{0x95b09dd6,0x6d580022,0x00000000,0x00000000}},	//   _әрлә, _ãtav, --, --, 
   {{0x69d00427,0x00000000,0x00000000,0x00000000}},	//   šješ, --, --, --, 
   {{0x64a80b45,0xe45c005b,0x00000000,0x00000000}},	//   rƙir, miön_, --, --, 
   {{0xe040baa7,0xe45c005b,0xb38400f3,0x00000000}},	//   инси, liön_, _алил, --, 
   {{0xb224f112,0x7cf02d75,0xb4dca4cd,0x8364036b}},	// [150c0] _импл, tårn, तकी_, _یدیل, 
   {{0xd0f40574,0x2f14f113,0xdb08324c,0xa2e00408}},	//   _आठवण_, _væg_, nzgä, _воьд, 
   {{0xc1d40184,0x73c40150,0xe4d4158f,0x00000000}},	//   _бөтә, _سيگم, _سویت_, --, 
   {{0xdd8c993d,0xa4a40086,0xa01801e3,0xef180117}},	//   توم_, _iròñ, _snöv, _омм_, 
   {{0x6b540408,0xdca0399f,0xe45c0108,0xc2e89c1d}},	//   ттех, јачи, kiön_, _زعیم_, 
   {{0xda60f114,0xe45c01e3,0x00000000,0x00000000}},	//   ивчи, lnöt_, --, --, 
   {{0x6c740022,0x00000000,0x00000000,0x00000000}},	//   _иуах, --, --, --, 
   {{0xdca0f115,0xe45c0108,0x6d5c343a,0x5fc409ab}},	//   _каси, nnöt_, mtpa, _रेडल, 
   {{0xdca0f116,0xeb04004e,0xc78400db,0x00000000}},	//   _тати, _апап, اابۉ, --, 
   {{0x7c2c09f3,0x857401c6,0x6d5cf117,0x6b80030a}},	//   ðarv, глох, otpa, mvog, 
   {{0x6d5cf118,0x6b800ffb,0xa018f119,0x364400d1}},	//   ntpa, lvog, _knöt, چىۋې, 
   {{0x249cb41c,0x69d8f11a,0x36440075,0xe4a46f86}},	//   ðum_, _ixte, نىۋې, троо, 
   {{0x6b800395,0x6d5cf11b,0x7cf05522,0x18640114}},	//   nvog, htpa, dårl, _јачи_, 
   {{0x67200ca8,0x6d5c18a9,0x48c40139,0x35dc0210}},	//   _itoj, ktpa, _шәһа, _नुक़, 
   {{0x38b000c7,0x92947621,0x6d5c007c,0xb62c01ec}},	//   _hára_, шарц, jtpa, _ﻓﺎ_, 
   {{0x38b0f11c,0x6b800841,0x559402e4,0x6d5c35ee}},	//   _kára_, kvog, _ידוע_, dtpa, 
   {{0xa4a40086,0x38b00124,0x6d5c0af9,0x1ee41bf4}},	// [150d0] _eròñ, _jára_, etpa, نوری_, 
   {{0x4438f11d,0x6d5c1600,0x69d8039a,0x38b001d3}},	//   las_, ftpa, _oxte, _mára_, 
   {{0x38b0110e,0x44380077,0x69d8031c,0x6d5c01bf}},	//   _lára_, oas_, _nxte, gtpa, 
   {{0x4438f11e,0x656818f7,0x8d845229,0x67200083}},	//   nas_, _mpfh, шууд, _otoj, 
   {{0x4438f11f,0x6d5c2112,0x38b03d64,0x00000000}},	//   ias_, atpa, _nára_, --, 
   {{0x2c8001d3,0x4fc400d1,0x395400d8,0x00000000}},	//   védő_, _ئەكە, гњит, --, 
   {{0x4438f120,0x6d5cf121,0x67200241,0x5f140882}},	//   kas_, ctpa, _atoj, _भूत्_, 
   {{0x44386c85,0xdb20f122,0xddc40010,0x2bdc0892}},	//   jas_, _نوری, _kajž, _फुका, 
   {{0x7d140369,0xa01801b8,0xe45c02f6,0x7c2c0bcd}},	//   _huzs, _taöf, tiön_, ðaru, 
   {{0x1ab4228d,0x4438f123,0x38b00cad,0x7c380040}},	//   _अतिथ, eas_, _dára_, lawr, 
   {{0x4438f124,0x67200083,0xe45c023a,0x89340035}},	//   fas_, _etoj, riön_, _نعنا, 
   {{0x4438f125,0x38b0f126,0xb4dc00a5,0x67200023}},	//   gas_, _fára_, तके_, _ftoj, 
   {{0xf744f127,0x38b002d2,0x216404a9,0x00000000}},	//   _село, _gára_, һири_, --, 
   {{0x80c047b8,0x85c401d5,0x7c38058a,0xafe401d5}},	//   रोसे, اغیم, hawr, ҳобл, 
   {{0x4438f128,0x21640058,0xf1a8f129,0x6d5c30c6}},	//   bas_, лири_, راسه_, xtpa, 
   {{0x7c38020c,0xb2240116,0xafe41262,0x38b00ca8}},	//   jawr, _өмил, гобл, _yára_, 
   {{0xa4f80302,0x387c0cfd,0x7c38025c,0x00000000}},	// [150e0] _אלקט, _mawr_, dawr, --, 
   {{0x387c00a9,0x7d1451ca,0x6b80030a,0xa01801e3}},	//   _lawr_, _buzs, vvog, _snöt, 
   {{0x6d5cf12a,0x2494552d,0xec480798,0xe7680150}},	//   utpa, _شنید_, езел_, _ﺳﻴﻤﯚ, 
   {{0x6d5cf12b,0x7d140007,0x387c00a9,0xa3a80243}},	//   rtpa, _duzs, _nawr_, कैक_, 
   {{0x6b8001c7,0x09dc0073,0x00000000,0x00000000}},	//   uvog, यथ्य, --, --, 
   {{0x4438f12c,0x9b8419bc,0xed5817a0,0x38b00241}},	//   zas_, انول_, _пог_, _rára_, 
   {{0x4438f12d,0x67209273,0x38b0f12e,0x6b80f12f}},	//   yas_, _stoj, _sára_, svog, 
   {{0xb4dc038e,0xace80597,0x38b0f130,0x9f440085}},	//   तको_, _أرسل_, _pára_, ́ní_, 
   {{0x4438f131,0xa01804cc,0x387c0009,0x00000000}},	//   vas_, _knör, _dawr_, --, 
   {{0x69d80175,0x7d14022e,0x20d4025c,0x00000000}},	//   _txte, _yuzs, jħin_, --, 
   {{0xa924722e,0x387c0cfd,0x692406ed,0xdb0401e1}},	//   _сдел, _fawr_, _смеа, _álád, 
   {{0xd5b4f132,0x387c0042,0x4438f133,0xa78402f2}},	//   усь_, _gawr_, uas_, _مشتو, 
   {{0x53440de7,0x00000000,0x00000000,0x00000000}},	//   йхра, --, --, --, 
   {{0x5690016c,0x8da4001f,0x6f0c0455,0xca6001a9}},	//   _гашт, ለክታል_, _nibc, _lumо, 
   {{0x4438f134,0xd6dc033f,0x00000000,0x00000000}},	//   pas_, ółek_, --, --, 
   {{0x4438f135,0xd468026a,0x0354586a,0x00000000}},	//   qas_, _биће_, _күмә_, --, 
   {{0xbec400e8,0xa0180267,0xb340013d,0x00000000}},	// [150f0] _ndëë, _snös, _öçpo, --, 
   {{0x6f0c0007,0x0e34177b,0x60600150,0x00000000}},	//   _cibc, йную, _گۇرل, --, 
   {{0x9cc800ee,0xbcc40022,0x00000000,0x00000000}},	//   ныда_, аӡал, --, --, 
   {{0xcc14027d,0x00000000,0x00000000,0x00000000}},	//   مذهب, --, --, --, 
   {{0x7c3803f0,0x00000000,0x00000000,0x00000000}},	//   rawr, --, --, --, 
   {{0x7f4c0309,0x80c0000d,0x7c38ed26,0x6f0c489a}},	//   mraq, रोरे, sawr, _gibc, 
   {{0x7c2c09cc,0x59dc007d,0xaee00150,0x7c346135}},	//   ðars, _पुखर, _بۋلى, _вебх, 
   {{0x7f4c0393,0x00000000,0x00000000,0x00000000}},	//   oraq, --, --, --, 
   {{0x7f4c02d1,0xe45c04cc,0xdb1c01f4,0x00000000}},	//   nraq, riöl_, övät, --, 
   {{0x36c4bd80,0x387c03cb,0x2bdcc0fb,0x00000000}},	//   рбог, _wawr_, _फुटा, --, 
   {{0x5fc401ad,0x7f4cf136,0xceb408c3,0x69d40205}},	//   _रेसल, hraq, מיץ_, şyer, 
   {{0x7f4c0309,0x00000000,0x00000000,0x00000000}},	//   kraq, --, --, --, 
   {{0x36d4e0a5,0xdd2c0118,0x7f4c0200,0x00000000}},	//   _кодр, _něžn, jraq, --, 
   {{0x23241b74,0x6d580267,0x890000b8,0xd6d8003b}},	//   рори_, _åtag, _iṣṭo_, _яте_, 
   {{0x7f4c013c,0xe45c01e3,0x98a40166,0x00000000}},	//   eraq, rnör_, ltnı_, --, 
   {{0xdd2c0316,0x7f4cf137,0xa018691c,0xe0d40c60}},	//   _běžn, fraq, _snör, авс_, 
   {{0x1fa4f138,0xaec4f139,0x7f4c003a,0x00000000}},	// [15100] акти_, абал, graq, --, 
   {{0x27f00212,0x6f0c01a9,0x00000000,0x00000000}},	//   _øyne_, _qibc, --, --, 
   {{0xed58e277,0x2a7c0311,0xdd8c007b,0x00000000}},	//   тое_, _ratb_, ووك_, --, 
   {{0x6f0c014f,0x10a406ba,0x7f4cf13a,0x657c0042}},	//   _wibc, ﺎﻳﺪﯨ, braq, _âphe, 
   {{0x1be44727,0x9b7400db,0x7f4c0393,0xabd4009a}},	//   адци_, لحوز_, craq, جزات, 
   {{0x7c2c09f3,0x332400ac,0x6120063f,0x2c140154}},	//   ðarr, _çoxu_, ọlet, ারেই_, 
   {{0xa018245f,0xada4f13b,0x9d409e47,0x6da401af}},	//   _knöp, _тавл, _мерд, _тива, 
   {{0x7afc00da,0xdd8c0244,0x2d8800de,0xa904007b}},	//   _īste, _توف_, _irbe_, جبتن, 
   {{0x7c2cf13c,0xca580133,0x20d4031c,0x00000000}},	//   ñare, _مساڵ_, dħil_, --, 
   {{0xe3cc0154,0x2d8800d7,0x25f8000d,0xaaa8024a}},	//   রথমব, _krbe_, _उरदी_, _कविक, 
   {{0x7f4c0066,0x00000000,0x00000000,0x00000000}},	//   zraq, --, --, --, 
   {{0x7f4cf13d,0xd7c41a69,0xe7840f14,0x00000000}},	//   yraq, اویه_, _вуко, --, 
   {{0xefdc02d3,0x598401c0,0x35c400c7,0x93781422}},	//   ጕራዊ_, _бөөн_, иҳәо_, абят_, 
   {{0x2d881730,0xbb68037e,0x1754008f,0xddc40327}},	//   _orbe_, _youカ_, _כסדר_, _pajż, 
   {{0x20c454a0,0x7f4c0113,0xfde000fe,0x00000000}},	//   асаг, wraq, _বণ্ড, --, 
   {{0x7f4cf13e,0xca3801e4,0x439400c7,0xf078f13f}},	//   traq, _leĝ_, _гаис, лисә_, 
   {{0x5e241c3e,0xbed805f5,0x2d88f140,0x543c010f}},	// [15110] لعاق, гдах_, _arbe_, _סעזא, 
   {{0x7f4cf141,0xca3801e4,0xdda80f5c,0xdd2c01ef}},	//   rraq, _neĝ_, ктел_, _věžn, 
   {{0x7cf005ac,0xb7bc054e,0x88bc0118,0xebc000d1}},	//   låri, rbţi, _rtěn, җәтн, 
   {{0x40940491,0x88bc012c,0x7f4c5727,0x7cf0007c}},	//   _الحر, _stěn, praq, oåri, 
   {{0x2d88f142,0x7cf02ff9,0x2d98005a,0x7f4c0309}},	//   _erbe_, nåri, axpe_, qraq, 
   {{0xeb94f143,0xe8f401e0,0x38b00241,0x0ae800d4}},	//   сиш_, ҙлы_, _páro_, адій_, 
   {{0x7cf038aa,0x2c1403d4,0x00000000,0x00000000}},	//   håri, াৰেই_, --, --, 
   {{0x3948f144,0x52a405d7,0x7cf02b96,0x00000000}},	//   čas_, _ऐक्स, kåri, --, 
   {{0x6d58007c,0x88c400db,0xf77000ae,0x4ddc00cc}},	//   _ätar, تتول, ساة_, _ভৰপূ, 
   {{0xa49800db,0x36940395,0x00000000,0x00000000}},	//   umòn, сшис, --, --, 
   {{0x857800a7,0xa49800cf,0x00000000,0x00000000}},	//   асят_, rmòn, --, --, 
   {{0x2bbc146c,0xf8c4013a,0xe3bc00a2,0x00000000}},	//   ौपचा, _šéfe_, lañy_, --, 
   {{0x3668f145,0xe2940124,0x00000000,0x00000000}},	//   _бало_, әас_, --, --, 
   {{0xa49800db,0xf1a80345,0xa01801e3,0x216400d1}},	//   lmòl, هازه_, _snöp, әити_, 
   {{0xe29400f0,0x00000000,0x00000000,0x00000000}},	//   љас_, --, --, --, 
   {{0x69cc01ef,0x00000000,0x00000000,0x00000000}},	//   _žbek, --, --, --, 
   {{0x2d88597f,0x99840010,0xe3bc00c7,0x00000000}},	// [15120] _srbe_, janž_, kañy_, --, 
   {{0xe74400d8,0x2d9401ec,0xe3b401af,0x00000000}},	//   _ções_, йрес, _ыбы_, --, 
   {{0xca3800df,0xa638008f,0x70900092,0x00000000}},	//   _reĝ_, רגער, _ከፈለጉ_, --, 
   {{0x7c2c0bcd,0x2d88003a,0x00000000,0x00000000}},	//   ðarp, _vrbe_, --, --, 
   {{0x6a84f146,0x09b0694b,0x99900e04,0x7fd41219}},	//   йлда, जन्य, _češe_, _дірі, 
   {{0x9c5400c7,0xdb800108,0xe3bc00a2,0x1ae0008e}},	//   ашәу_, ягчи, gañy_, почм, 
   {{0x9f4c006a,0x2d88f147,0x2984dfe6,0x98600166}},	//   ägö_, _urbe_, сылг, _añı_, 
   {{0x6cd4f148,0x22000098,0xa2840257,0x6e3c14cb}},	//   _اقرا, léhé_, _ሚዛንን_, lapb, 
   {{0x20d40327,0x7cf001e3,0x00000000,0x00000000}},	//   xħim_, xåri, --, --, 
   {{0x39480227,0x6e3cf149,0x7cf001e3,0x8cb0f14a}},	//   ņasa_, napb, våri, ंसको, 
   {{0xd82c7314,0xe5c465cb,0x9f5c01d3,0x98a40171}},	//   _нэ_, сспо, _öröm_, gsnē_, 
   {{0x2200003e,0x7cf03b3b,0x6e3c0477,0xe738f14b}},	//   héhé_, tåri, hapb, _бед_, 
   {{0x6e3c017a,0xaa8400ee,0xb91000b8,0x66e4bbb8}},	//   kapb, _goýý, _nnaṃ_, _лода, 
   {{0x7cf01506,0x00000000,0x00000000,0x00000000}},	//   råri, --, --, --, 
   {{0xe8e4031c,0x20680022,0xdec00023,0xa5f0009d}},	//   _སྩོག, лшап_, ጻጽኣ_, _хүнц, 
   {{0x7cf0007c,0x00000000,0x00000000,0x00000000}},	//   påri, --, --, --, 
   {{0xa3440c82,0x00000000,0x00000000,0x00000000}},	// [15130] _уэйл, --, --, --, 
   {{0x4254a9da,0x3cec01e3,0x00000000,0x00000000}},	//   _بندر, _skev_, --, --, 
   {{0x257800da,0xb91000dc,0xd1c80107,0x00000000}},	//   _jūl_, _enaṃ_, _гуяд_, --, 
   {{0x7f940022,0xd018f14c,0xdb040205,0x00000000}},	//   _дамх, _гфр_, şlüo, --, 
   {{0xfaa40ca4,0x211c0490,0x69dc000f,0xdb0800e5}},	//   жало, _मंडळ_, ûpen, lygé, 
   {{0x93fc008f,0x3b080835,0x00000000,0x00000000}},	//   אלדי, шело_, --, --, 
   {{0xaa5415ed,0x3f8807c5,0xce6802bf,0x9f480118}},	//   цију_, lvau_, _уряд_, _mycí_, 
   {{0xf8a8ca08,0x9cc801af,0x00000000,0x00000000}},	//   рвик_, _сыга_, --, --, 
   {{0xcb3400a7,0x3f8805d5,0x00000000,0x00000000}},	//   _нетъ, nvau_, --, --, 
   {{0xaa840014,0x76b80432,0x00000000,0x00000000}},	//   _وۆنم_, lňyz, --, --, 
   {{0x65780649,0xa2ac37e3,0x64a803f9,0x35a401c6}},	//   gwth, ुसन्, lƙiy, цанг, 
   {{0x38b000e5,0x00000000,0x00000000,0x00000000}},	//   _márk_, --, --, --, 
   {{0x6e3c0477,0x98600139,0x00000000,0x00000000}},	//   yapb, _uñı_, --, --, 
   {{0x27f00158,0x00000000,0x00000000,0x00000000}},	//   _øyna_, --, --, --, 
   {{0xffa40137,0x9f880112,0x99840153,0x00000000}},	//   үлсү, tößt_, manų_, --, 
   {{0x6e3c020b,0x657c0042,0x8d700092,0x00000000}},	//   wapb, _âpha, ጠይቀው_, --, 
   {{0xee38f14d,0x00000000,0x00000000,0x00000000}},	// [15140] ина_, --, --, --, 
   {{0xe294030d,0x998400c0,0x00000000,0x00000000}},	//   _даь_, nanų_, --, --, 
   {{0x6e3cf14e,0x92080055,0x3f88f14f,0x38b000e5}},	//   rapb, _bhāų, avau_, _várj_, 
   {{0xe3bc0227,0x7afc005f,0x5924031c,0x0cd80011}},	//   tañx_, _īsta, _ལྕེས_, তত্ত, 
   {{0xaae4f150,0x7c2c0428,0xeb04234c,0x99840024}},	//   يستو, ñara, очко, kanų_, 
   {{0x7b0c0084,0x3a24007f,0x6e3c014f,0x25f801f9}},	//   ṱung, _cflp_, qapb, _उरली_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xca3800df,0x00000000,0x00000000,0x00000000}},	//   _loĝi_, --, --, --, 
   {{0x9984f151,0xa49800db,0x16540022,0x00000000}},	//   ganų_, rmòm, орџь_, --, 
   {{0x092800b2,0x6ab801bf,0x3a14030d,0x00000000}},	//   _اڳتي_, _iltf, _хьус, --, 
   {{0x16d405f5,0xd5b41507,0x63ac1155,0x00000000}},	//   йгөө_, юсы_, tycn, --, 
   {{0x53340276,0x7cf00165,0x00000000,0x00000000}},	//   меят, mårt, --, --, 
   {{0x9f480589,0x00000000,0x00000000,0x00000000}},	//   _lycã_, --, --, --, 
   {{0x80d82b1b,0xa0a4030d,0xa3e40c22,0x00000000}},	//   _ভীষ্, ошал, _भडक_, --, 
   {{0xf4a40023,0x00000000,0x00000000,0x00000000}},	//   _ዚፈልጥ_, --, --, --, 
   {{0x200c00c5,0x3f88f152,0x50642c68,0xbf141ec7}},	// [15150] ägi_, uvau_, ьтра, سواب, 
   {{0xd1f80020,0x3f88f153,0x00000000,0x00000000}},	//   _ገጾች_, rvau_, --, --, 
   {{0x6294009a,0x69dc002d,0xdd98f154,0x3a24045a}},	//   _inxo, ûpel, шша_, _rflp_, 
   {{0x6ab8f155,0x317800c8,0x99840153,0x42540066}},	//   _altf, _פארד, zanų_, _بنگر, 
   {{0xe0dc01e1,0x3868002e,0xfbd00451,0x00000000}},	//   _ijò_, _ñari_, رڪر_, --, 
   {{0xf8b801c6,0x00000000,0x00000000,0x00000000}},	//   өөе_, --, --, --, 
   {{0x99840006,0x38b01d1d,0xc01c0154,0x00000000}},	//   vanų_, _hári_, তরীণ_, --, 
   {{0x38b008a7,0x6ab80857,0x5fdc000d,0x00000000}},	//   _kári_, _eltf, _नखाल, --, 
   {{0xca6001d5,0x00000000,0x00000000,0x00000000}},	//   _tumа, --, --, --, 
   {{0x67240579,0x4a54f156,0x00000000,0x00000000}},	//   íkja, _окус, --, --, 
   {{0xaa840014,0x99840024,0x588400ee,0x88bc0118}},	//   _رچوم_, ranų_, _мыда, _otěh, 
   {{0x6294f157,0x6284017a,0x7980f158,0x7cf011ad}},	//   _anxo, edjo, _islw, mårs, 
   {{0x81a80729,0x798002d0,0x99840153,0x2a780248}},	//   _খেল_, _hslw, panų_, _ùgbò_, 
   {{0x0cb81221,0xe0dc0241,0x628401f5,0x02180212}},	//   _आत्म, _ajò_, gdjo, жіть_, 
   {{0x7640f159,0x7cf0b4cd,0xf55800c6,0xa2e0022e}},	//   maly, nårs, _العب_, хорд, 
   {{0x6294f15a,0x7640e794,0x00000000,0x00000000}},	//   _enxo, laly, --, --, 
   {{0xe0dc007f,0x00000000,0x00000000,0x00000000}},	// [15160] _djò_, --, --, --, 
   {{0xe0dc0ca8,0x7c2c09c2,0x38b003b2,0x7cf02dba}},	//   _ejò_, ñarn, _dári_, kårs, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfca800aa,0x13b000bd,0x7640f15b,0x1d04082d}},	//   يانو_, _চেয়, haly, пехи_, 
   {{0x7640f15c,0xe45c023a,0x8f8400d1,0xcf240451}},	//   kaly, miöt_, _юқал, _آڱري, 
   {{0x76400209,0xeb9802af,0xb6040010,0xe45c005b}},	//   jaly, _қиз_, _kušč, liöt_, 
   {{0xfe542580,0x7cf0b6a6,0x00000000,0x00000000}},	//   _زینب_, gårs, --, --, 
   {{0x798003ac,0x76401368,0xaac403e6,0x2cb00142}},	//   _dslw, ealy, _کترن, öydd_, 
   {{0x80c0584e,0xb6040219,0x76400042,0x98640014}},	//   रोटे, _lušč, faly, سیوے_, 
   {{0x7640f15d,0xe45c0108,0x38c400e4,0x00000000}},	//   galy, hiöt_, tèrõ_, --, 
   {{0xc5f403d4,0xe45c4268,0x00000000,0x00000000}},	//   ঙেনা_, nhög_, --, --, 
   {{0x06c805f5,0x291c0b23,0xb8640691,0x00000000}},	//   сгүй_, _iuta_, _يانو, --, 
   {{0x291cf15e,0x7640f15f,0x3f8c0129,0x557001ec}},	//   _huta_, baly, _àeux_, _үгіт, 
   {{0x88bc00bc,0x991800e1,0x657c015d,0x97c002e8}},	//   _stěh, _पूँछ_, _âpho, _яйче, 
   {{0x291c355e,0x00000000,0x00000000,0x00000000}},	//   _juta_, --, --, --, 
   {{0x557400c8,0x00000000,0x00000000,0x00000000}},	//   _זעהן_, --, --, --, 
   {{0x4428f160,0x291cf161,0xef640323,0x3f14f162}},	// [15170] _ifa_, _luta_, дэхү, ддас, 
   {{0x80c01f13,0x291cf163,0x9e0400fd,0x38b03168}},	//   रोजे, _outa_, пчел, _vári_, 
   {{0x7c2c2d7b,0x2bd013f5,0x7d78f164,0x2b440156}},	//   ñaro, _देबा, تمار_, esoc_, 
   {{0xe45cf165,0x44285100,0x00000000,0x00000000}},	//   ngö_, _jfa_, --, --, 
   {{0x44280134,0xca380115,0x6d580267,0x798003ac}},	//   _mfa_, _loĝu_, _åtan, _sslw, 
   {{0x28c80dad,0x7cf000b5,0x1ee4f166,0xe45c04cc}},	//   ़ोसि, tårs, _روزی_, gnöz_, 
   {{0x442873f4,0x7640f167,0x291c0c09,0x0d84f168}},	//   _ofa_, valy, _cuta_, _плён, 
   {{0x291cf169,0x4428f16a,0x7cf017c1,0xba9405d9}},	//   _duta_, _nfa_, rårs, _ڪارڪ, 
   {{0xc0240020,0x7c28f16b,0x7640f16c,0x61f401e3}},	//   ዳስታወ, _ifer, taly, _lyxl, 
   {{0x4428f16d,0x7cf0007c,0x00000000,0x00000000}},	//   _afa_, pårs, --, --, 
   {{0x291cf16e,0x44283beb,0x657c0042,0xdd9c00ee}},	//   _guta_, _bfa_, _âphl, _öňde_, 
   {{0x59241b4b,0x7640f16f,0x44285182,0x7c28031c}},	//   _ལྕགས_, saly, _cfa_, _jfer, 
   {{0x4428f170,0x7640f171,0x7c28f172,0x0708004b}},	//   _dfa_, paly, _mfer, _ځيني_, 
   {{0x4428f173,0x386cf174,0x291cf175,0x77680334}},	//   _efa_, lfer_, _yuta_, mtex, 
   {{0x7768f176,0xa184026a,0x291c004e,0xe45cc9d9}},	//   ltex, мбра_, _xuta_, tiöt_, 
   {{0x4428f177,0x7c2c09d7,0x60cc02d0,0x7c280327}},	//   _gfa_, ñarl, _cmcm, _nfer, 
   {{0x386cf178,0xe45c023a,0x00000000,0x00000000}},	// [15180] ifer_, riöt_, --, --, 
   {{0x7c28f179,0xb6040006,0x4428f17a,0xe354011a}},	//   _afer, _tušč, _zfa_, _קשיח_, 
   {{0x7768f17b,0xe2980375,0x7c280332,0x4428f17c}},	//   htex, _ושיר, _bfer, _yfa_, 
   {{0x386c0cf9,0x44280789,0x7768f17d,0x62800162}},	//   jfer_, _xfa_, ktex, _ónor, 
   {{0x7768f06d,0x7c28005a,0x2b4400d8,0x386cf17e}},	//   jtex, _dfer, usoc_, dfer_, 
   {{0x291cf17f,0x77680d6b,0x7c28f180,0x386cf181}},	//   _puta_, dtex, _efer, efer_, 
   {{0x291c241c,0x7c2800a9,0x7768f182,0xe2a409f3}},	//   _quta_, _ffer, etex, æðir_, 
   {{0x291cf183,0x7768008e,0x2c840024,0x22400327}},	//   _vuta_, ftex, _būdų_, zajk_, 
   {{0x4428f184,0x291cf185,0x7768f186,0x26c0002e}},	//   _rfa_, _wuta_, gtex, ëkoo_, 
   {{0x291c04ac,0x442802fa,0x2ca40158,0x92c000cc}},	//   _tuta_, _sfa_, ljod_, ংচু_, 
   {{0x4428f187,0x2bd09c21,0x7c3402d2,0x00000000}},	//   _pfa_, _देता, _ígrí, --, 
   {{0x77687636,0x38b009e8,0x75c8010b,0x00000000}},	//   btex, _báru_, ятың_, --, 
   {{0x68e007d6,0x77680334,0x29041e7f,0x00000000}},	//   _ijod, ctex, _ihoa_, --, 
   {{0x26cc00f1,0x5690009d,0xe45c01e3,0x00000000}},	//   _umfo_, _аашт, tiös_, --, 
   {{0x290407ae,0x4428011c,0x00000000,0x00000000}},	//   _khoa_, _tfa_, --, --, 
   {{0x4428f188,0xe45cf189,0x6afc031c,0x2ca48761}},	//   _ufa_, riös_, _ཞེའོ_, jjod_, 
   {{0x1ea8f18a,0x7c28f18b,0x7c2cf18c,0x26dcf18d}},	// [15190] يائي_, _rfer, ñarm, onto_, 
   {{0x68e0a934,0x26dc007f,0x22400327,0x00000000}},	//   _ljod, nnto_, qajk_, --, 
   {{0x7c28f18e,0x6d58049f,0x26dcf18f,0x386c1829}},	//   _pfer, _åtal, into_, yfer_, 
   {{0x68e0f190,0x77682076,0xf1a839b1,0x27e4003a}},	//   _njod, ytex, _راپه_, _oxon_, 
   {{0x7768030d,0x00000000,0x00000000,0x00000000}},	//   xtex, --, --, --, 
   {{0x4aa8005e,0x68e00248,0x2904f191,0x7768010a}},	//   мкін_, _ajod, _ahoa_, vtex, 
   {{0x77680354,0x7c28031c,0x00000000,0x00000000}},	//   wtex, _tfer, --, --, 
   {{0x26dcf192,0x7c28f193,0x7768f194,0xa3dc0b7d}},	//   ento_, _ufer, ttex, थपा_, 
   {{0x386cf195,0x68e00098,0x29040076,0xda6401c8}},	//   rfer_, _djod, _dhoa_, _يائي, 
   {{0x386cf196,0x7768f197,0x6bd005d9,0xa800f198}},	//   sfer_, rtex, _حڪمر, ызыл, 
   {{0x0a681638,0x386cf199,0x38b003b2,0x27e40f85}},	//   _юрти_, pfer_, _sáru_, _exon_, 
   {{0x77683627,0x38b0f19a,0x6d480332,0x00000000}},	//   ptex, _páru_, áfai, --, 
   {{0x7c2c03f2,0x00000000,0x00000000,0x00000000}},	//   ðary, --, --, --, 
   {{0x3ae800e4,0x00000000,0x00000000,0x00000000}},	//   túpy_, --, --, --, 
   {{0xd1f8001f,0xd724015b,0xe45c0267,0x066400db}},	//   ፋፋት_, _মিয়া_, riör_, _شاوپ, 
   {{0x3ce8033f,0x25d4010f,0x2518010f,0x00000000}},	//   टकों_, _רוקן_, _צופא, --, 
   {{0xefc801c0,0xd2500050,0x2ca4030a,0x00000000}},	// [151a0] члал_, _پۆز_, vjod_, --, 
   {{0x38b001ed,0x2f04045f,0x5c1c00eb,0x00000000}},	//   _zárt_, kôge_, দরোগ_, --, 
   {{0xad580408,0xf0b8020c,0x00000000,0x00000000}},	//   ярах_, _فاحش_, --, --, 
   {{0xacf401a9,0x65c40098,0x653800df,0xb4bc00cd}},	//   رسات, _héhé, פענד, _इतो_, 
   {{0x65c4003e,0x2904045a,0xfca81bf4,0x5f24014b}},	//   _kéhé, _rhoa_, بالو_, _поям_, 
   {{0x29040032,0x27e4022e,0xe9840063,0xd1e80092}},	//   _shoa_, _rxon_, ећин, _ሙላት_, 
   {{0xdee0f19b,0x3ea407c5,0x2d9c01a6,0x26c00af9}},	//   _сори, _òlta_, _štef_, ëkom_, 
   {{0x6d5cf19c,0x200400ac,0xa498007f,0xdb040306}},	//   mupa, ənib_, nmòt, člán, 
   {{0x6d5cf19d,0x7aec020c,0x2874013d,0x2078010f}},	//   lupa, èntè, _җыер, לאקא, 
   {{0xa9a4f19e,0x26dc00a7,0x6b80f19f,0xa4981e7b}},	//   _пизд, unto_, mwog, ològ, 
   {{0x6d5cf1a0,0x26dc010a,0x290401fb,0x6b8004ba}},	//   nupa, rnto_, _thoa_, lwog, 
   {{0x588000db,0x00000000,0x00000000,0x00000000}},	//   _быша, --, --, --, 
   {{0xd7f40354,0x38b01ac9,0x3de000cc,0x00000000}},	//   _пуш_, _várt_, _ভৰাল, --, 
   {{0x3868002e,0x17980a7c,0x00000000,0x00000000}},	//   _ñarr_, _מידב, --, --, 
   {{0x65c4003e,0x6d5cf1a1,0x2bd01b87,0x7c2c0309}},	//   _déhé, jupa, _देसा, ñark, 
   {{0x6d5cf1a2,0xd5f802e4,0x6b800337,0x672000c0}},	//   dupa, _מפור, kwog, _kuoj, 
   {{0x0fe4a6e6,0x4438c2ea,0x63b80194,0x8fe401e0}},	// [151b0] гөрү, mbs_, øund, гәрҙ, 
   {{0x65c4893a,0x44380839,0x6b800009,0x6d5c032e}},	//   _géhé, lbs_, dwog, fupa, 
   {{0xe2a4008c,0x4438f1a3,0x6720005b,0xdce00022}},	//   æður_, obs_, _luoj, гӡақ, 
   {{0x2bd00da0,0x00000000,0x00000000,0x00000000}},	//   _देहा, --, --, --, 
   {{0x6b800083,0x44381ba6,0x67200153,0x0c24003b}},	//   gwog, ibs_, _nuoj, умін, 
   {{0xeb9456ff,0x6d5cf1a4,0xfd7405f5,0x2f04002d}},	//   тиш_, bupa, _илгэ, tôge_, 
   {{0x6d5cf1a5,0x6b800083,0x00000000,0x00000000}},	//   cupa, awog, --, --, 
   {{0x2bd0f1a6,0x6b8004ba,0x0c8401af,0x00000000}},	//   _देवा, bwog, _йыум, --, 
   {{0x7d08f1a7,0x38b00332,0x7c38015d,0x7b14f1a8}},	//   _ihes, _bárr_, mbwr, _адах, 
   {{0x4ab807b7,0x44380112,0x7c380042,0xdb0c0241}},	//   _अवयव, ebs_, lbwr, _ìjày, 
   {{0x7d08f1a9,0x2d9c0086,0x20b0012c,0xca4800f1}},	//   _khes, _àtet_, ीसाध, _سلنه_, 
   {{0x89340597,0x38b003b2,0x7c38015d,0x281000db}},	//   _إعلا, _várs_, nbwr, دوۋس, 
   {{0x7d0805d9,0x78a8f1aa,0x6d5c0112,0xd1e801f3}},	//   _mhes, mjev, zupa, _ሙጋቤ_, 
   {{0xd5e00084,0x480410f5,0x6d5c9c9c,0x7d0800ad}},	//   _haṋ, _спів, yupa, _lhes, 
   {{0x4438f1ab,0xd5e01682,0x7d08035b,0x2164f1ac}},	//   bbs_, _kaṋ, _ohes, кири_, 
   {{0x78a85946,0x4438003e,0x6b8003cb,0x00000000}},	//   njev, cbs_, ywog, --, 
   {{0x6d5c009a,0x65c406af,0x4c9401a9,0xae881078}},	// [151c0] wupa, _téhé, ғилс, мбаз_, 
   {{0x7d08f1ad,0x6d582dba,0xb0c405d7,0x78a80240}},	//   _ahes, _åtak, रोजग, hjev, 
   {{0x7d080810,0x78a8f1ae,0x00000000,0x00000000}},	//   _bhes, kjev, --, --, 
   {{0x6d5cf1af,0x7d080746,0x6b8018cb,0xbaa40116}},	//   rupa, _ches, twog, ғушқ, 
   {{0x2bd00a59,0x7d08f1b0,0x88bc013a,0xceb403b9}},	//   _देशा, _dhes, _otěr, fqət_, 
   {{0x7d08f1b1,0x6d5cf1b2,0x6b800d27,0xda600063}},	//   _ehes, pupa, rwog, ављи, 
   {{0x6720049b,0x6df40597,0x2984807e,0x6d5c02d1}},	//   _suoj, _شكرا, тылг, qupa, 
   {{0x78a80c58,0x7d08f1b3,0x3a08141b,0x2d14030f}},	//   gjev, _ghes, رکلی_, _شکاک_, 
   {{0x38b0568e,0xab6400f0,0x44383fd6,0x00000000}},	//   _párr_, _швал, vbs_, --, 
   {{0x612002e3,0x78a800e4,0x672001f4,0x00000000}},	//   ọlit, ajev, _vuoj, --, 
   {{0xb5d4009e,0x78a80118,0x44380010,0xe5c401ee}},	//   _সুবচ, bjev, tbs_, тспо, 
   {{0xb864f1b4,0x78a80841,0x69c80165,0x7d08036e}},	//   _ماهو, cjev, mzfe, _xhes, 
   {{0x4438f1b5,0x3178f1b6,0x7c2c03f0,0x534400f0}},	//   rbs_, _appz_, ñari, ихра, 
   {{0x44380175,0xa498067c,0x00000000,0x00000000}},	//   sbs_, tmòs, --, --, 
   {{0x69c8f1b7,0xd5e006d6,0xd5ac0108,0x1718008f}},	//   nzfe, _yaṋ, _тс_, _קווע, 
   {{0x408800c7,0x00000000,0x00000000,0x00000000}},	//   хәом_, --, --, --, 
   {{0x7d080cfd,0x317801c7,0x25b401d9,0x4394f1b8}},	// [151d0] _rhes, _eppz_, _سنکھ_, _сапс, 
   {{0x7d08dc29,0x78a82da4,0x7c38015d,0x75800244}},	//   _shes, zjev, wbwr, _ئیێم, 
   {{0x7d08f1b9,0xc21001d9,0x78a80022,0x90640116}},	//   _phes, _دٔد_, yjev, _ھۆكۇ, 
   {{0x8d74f1ba,0x7d0803f0,0xcd048eea,0x00000000}},	//   شاما, _qhes, аччи, --, 
   {{0x7d084b56,0x752c107d,0x6d4cf1bb,0x7c380142}},	//   _vhes, _čazm, _evba, rbwr, 
   {{0x7f4c0113,0x7d080076,0xfa540214,0x657c0142}},	//   msaq, _whes, ارشگ, _âphw, 
   {{0x7d08f1bc,0x78a802d3,0x7f4c5727,0x8d8401d5}},	//   _thes, tjev, lsaq, _кутд, 
   {{0xcdc80131,0x7d08f1bd,0x88bc00bc,0x00000000}},	//   _جۇمۇ_, _uhes, _stěr, --, 
   {{0x78a8f1be,0x7f4cf1bf,0x3dc400cc,0x9b400244}},	//   rjev, nsaq, _এখিল, _ئۆتو, 
   {{0xb7bc00a8,0xd5e006d6,0xceb403be,0x78a8f1c0}},	//   ncţi, _waṋ, qqət_, sjev, 
   {{0x33300076,0x78a88185,0x211c0490,0x9964033a}},	//   _styx_, pjev, _मंगळ_, _штал, 
   {{0xf770308f,0x7f4c0194,0x20c4000d,0xd6c0030f}},	//   _هات_, ksaq, _jõid_, امگی, 
   {{0x36d4013d,0xe72c03cf,0x00000000,0x00000000}},	//   _йодр, _ые_, --, --, 
   {{0xa4980ba1,0xd6d80276,0x20c40037,0x63ac0356}},	//   glòb, _юте_, _lõid_, _ţinî, 
   {{0x41b4f1c1,0x6e2c05c7,0x63b0134b,0xa49801ab}},	//   астт, _rfbb, _һәрх, rmòr, 
   {{0xada41cd1,0xb7bc054e,0x20c4000d,0xb4641214}},	//   һазл, ecţi, _nõid_, _скил, 
   {{0xee380395,0x00000000,0x00000000,0x00000000}},	// [151e0] енз_, --, --, --, 
   {{0x6e441896,0x00000000,0x00000000,0x00000000}},	//   انام, --, --, --, 
   {{0x2d94f1c2,0x7f4c0eda,0xc24400f7,0x98a40166}},	//   ырас, asaq, _өнөк, hunı_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6bd46cb9,0x00000000,0x00000000,0x00000000}},	//   دتار, --, --, --, 
   {{0x69c8f1c3,0x29880305,0x00000000,0x00000000}},	//   tzfe, есио_, --, --, 
   {{0x49a44d50,0xdb0800ee,0x48c40131,0x69c8030a}},	//   рылғ, dygä, ишиғ, uzfe, 
   {{0x98c0f1c4,0x7c9444b4,0x69c8002f,0x00000000}},	//   йсыл, _круц, rzfe, --, 
   {{0x3cd4036b,0x468401b9,0x98a40139,0x00000000}},	//   _тўрт, иқда, gunı_, --, 
   {{0x4ab80b8f,0xe3cc03d4,0x5b780a7c,0x798c0210}},	//   _अविव, ৰথমব, _ארמא, ława, 
   {{0xdef4008f,0x00000000,0x00000000,0x00000000}},	//   רמיט_, --, --, --, 
   {{0xf8ac0214,0xe4a400cf,0x249cf1c5,0x98a40166}},	//   _يکي_, уроо, ñum_, bunı_, 
   {{0x9cd40375,0x00000000,0x00000000,0x00000000}},	//   רוכה_, --, --, --, 
   {{0x2d88f1c6,0xe45c0e78,0x2688f1c7,0x01c801ed}},	//   _osbe_, chön_, _سختي_, پورٹ_, 
   {{0x7f4c03f0,0x5a98010f,0x00000000,0x00000000}},	//   wsaq, עשלא, --, --, 
   {{0x7f4c013c,0x4034055f,0xc800020c,0xc03400d8}},	//   tsaq, реас, èèwè, рнај, 
   {{0x1ee40e83,0x7f4c0140,0x00000000,0x00000000}},	// [151f0] هوری_, usaq, --, --, 
   {{0x7f4cf1c8,0x4ea401c6,0x20c4000d,0x21300051}},	//   rsaq, йрха, _sõid_, _ttxh_, 
   {{0x7f4c32ff,0x9e041220,0x7e64047e,0x00000000}},	//   ssaq, учал, rghp, --, 
   {{0x20040cc1,0x7f4c003a,0x00000000,0x00000000}},	//   ənin_, psaq, --, --, 
   {{0x90980c9b,0x20c400af,0x6d48041e,0x00000000}},	//   _свят_, _võid_, áfar, --, 
   {{0x39541f5a,0xb9540114,0xab9000d1,0x00000000}},	//   ањит, атић, زلىغ, --, 
   {{0x20c400c5,0xa96402e8,0x5d50010a,0x00000000}},	//   _tõid_, аища_, çкĕт, --, 
   {{0xdb200330,0x7afc0171,0x00000000,0x00000000}},	//   _هوری, _īstu, --, --, 
   {{0x36c4267c,0xa8007225,0x69dc002d,0x9ba00137}},	//   ибиг, _şırn, ûper, _دەشى, 
   {{0x3f9801fa,0x98a40006,0x00000000,0x00000000}},	//   _mrsu_, psnį_, --, --, 
   {{0xdb1c00c5,0xc7a801ec,0x00000000,0x00000000}},	//   övõt, _ەدىل_, --, --, 
   {{0x3f9808e5,0x74b80276,0x00000000,0x00000000}},	//   _orsu_, туос_, --, --, 
   {{0xf744f1c9,0xb4e40241,0xe79428c4,0x00000000}},	//   _тело, _alàá, _پانک, --, 
   {{0x617002d3,0xdb0801bf,0x880401f7,0x00000000}},	//   _ኣካላዊ_, bygå, _اِهو, --, 
   {{0x3f980b45,0xe29416a4,0x7cdc00ef,0x3a380051}},	//   _arsu_, јас_, _kārķ, _đspl_, 
   {{0x656c00a3,0x21640114,0x00000000,0x00000000}},	//   àbhe, јити_, --, --, 
   {{0xb4e401e1,0xa498067c,0x4de400fb,0x81e80154}},	// [15200] _elàá, slòc, әйең, _বরণ_, 
   {{0xfae401e2,0x6e3401c4,0x00000000,0x00000000}},	//   _رګ_, рхах, --, --, 
   {{0x7204a9da,0x71a4f1ca,0x00000000,0x00000000}},	//   _خودم, _танз, --, --, 
   {{0x20c40254,0x9a9401d9,0x00000000,0x00000000}},	//   _põie_, یٖنا_, --, --, 
   {{0x60c00311,0x6a8472a0,0xff1400fe,0x00000000}},	//   _înma, илда, িৱেশ_, --, 
   {{0x5a304472,0x8c180451,0x15d001ec,0x00000000}},	//   оншт, پيڪر_, _ﺘﺒﺎﺩ, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7c2c00fd,0x38c4010b,0xeb9801b9,0x3f98032e}},	//   ñart, йшың, _ииб_, _yrsu_, 
   {{0xc6f8026a,0x47340114,0x00000000,0x00000000}},	//   лних_, љнос, --, --, 
   {{0x6d5c0eda,0x6a6401d5,0x295c010c,0x00000000}},	//   orpa, _خطرل, ለሃይማ, --, 
   {{0x7aec20ef,0xd82c0262,0xf1d407f7,0x66040210}},	//   éate, _мэ_, _डेलन, ękko, 
   {{0x98a00415,0xe45c04cc,0x06c801c0,0x6d5c01ab}},	//   _михе, chöl_, тгүй_, irpa, 
   {{0x66e4f1cb,0x6d5c0e78,0x782400ae,0x00000000}},	//   _кода, hrpa, _اعمل, --, 
   {{0x6d5c107d,0x03a400c7,0x22a400f1,0x57e4013d}},	//   krpa, аиҭо, جنسۍ_, _әдәм_, 
   {{0x6b780618,0x604400d8,0x11280395,0x206804f0}},	//   lāgā, ихаз, июти_, кшап_, 
   {{0x3f980118,0x00000000,0x00000000,0x00000000}},	//   _prsu_, --, --, --, 
   {{0x6d5cf1cc,0x98ac0cf4,0x10480131,0x00000000}},	// [15210] erpa, žaće_, ряси_, --, 
   {{0xc0d40023,0x93fc011a,0x81e800fe,0x00000000}},	//   ረበላ_, _בלחי, _বৰণ_, --, 
   {{0x20c4367a,0x00000000,0x00000000,0x00000000}},	//   _võib_, --, --, --, 
   {{0x61f83535,0x9c6000cf,0x00000000,0x00000000}},	//   ğuld, تۇرو, --, --, 
   {{0x6d5c0eda,0x307800c8,0x61f8f1cd,0x69dc01f1}},	//   arpa, _גארנ, şuld, úpen, 
   {{0x200803e0,0x00000000,0x00000000,0x00000000}},	//   _izci_, --, --, --, 
   {{0x7c2c2b76,0xd5400248,0xca740116,0x3f880042}},	//   ñars, _mẹ́t, تانغ, lwau_, 
   {{0xc0d4044e,0x32c400d2,0xbb4801d9,0x00000000}},	//   ረበሉ_, _môya_, _ملرن_, --, 
   {{0x81ac04c5,0xb99466df,0x3f880368,0x6c6801ed}},	//   কনি_, _گلاب, nwau_, _حلقہ_, 
   {{0x37e4006c,0xe94001d9,0x00000000,0x00000000}},	//   _қолг, _کھوٝ, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe9900150,0x2da40139,0x942400db,0xdb2002d2}},	//   _ءۇيگ, _äweş_, توحۇ, _þrói, 
   {{0x71a4035b,0x00000000,0x00000000,0x00000000}},	//   әабз, --, --, --, 
   {{0x6d5c03a2,0xe75401d5,0x55c014d4,0x00000000}},	//   yrpa, _الوغ_, _малғ, --, 
   {{0x317c067c,0x7bdc02d2,0x00000000,0x00000000}},	//   ïtz_, _ýsuf, --, --, 
   {{0x71a41246,0x00000000,0x00000000,0x00000000}},	//   _ғамз, --, --, --, 
   {{0x657c0042,0xe040f1ce,0x6d5c015d,0x20080210}},	// [15220] _âphr, янти, wrpa, _czci_, 
   {{0xd2500272,0x3944f1cf,0x6d5c07f5,0xab281171}},	//   _زۆر_, _owls_, trpa, ҳода_, 
   {{0x6d5c0373,0x00000000,0x00000000,0x00000000}},	//   urpa, --, --, --, 
   {{0xab28f1d0,0x6d5c0334,0xafe40024,0x00000000}},	//   года_, rrpa, _гомл, --, 
   {{0x2bd01b77,0x00000000,0x00000000,0x00000000}},	//   _देखा, --, --, --, 
   {{0x7c2c5f34,0x61f80356,0xad241410,0xada400c0}},	//   ñarr, şule, _هررو, _лагл, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4734f1d1,0x6b78e849,0x00000000,0x00000000}},	//   онис, tāgā, --, --, 
   {{0x81e80183,0xea5800d8,0x00000000,0x00000000}},	//   _বৰা_, _бреј_, --, --, 
   {{0x2ef80112,0xcb000037,0x00000000,0x00000000}},	//   nopf_, _लीचड_, --, --, 
   {{0x7c2cf1d2,0x39440327,0x33800150,0x00000000}},	//   žare, _gwls_, _ﺩﻴﻨﻲ_, --, 
   {{0x92e8009e,0x2ef802c1,0xe4c801b9,0x00000000}},	//   বতো_, hopf_, ابدن_, --, 
   {{0x2ef8f1d3,0x20c40254,0x00000000,0x00000000}},	//   kopf_, _nõia_, --, --, 
   {{0xd370302a,0xe1f000db,0xa498004e,0x600c0248}},	//   رۇپ_, كسز_, clòn, _lòmí, 
   {{0xdef8472d,0x26dcf1d4,0x225c03ee,0x16840133}},	//   ңыз_, mito_, ğuk_, _دانێ, 
   {{0x26dcf1d5,0x00000000,0x00000000,0x00000000}},	//   lito_, --, --, --, 
   {{0x228450ae,0xbed8f1d6,0x26dc0077,0x00000000}},	// [15230] _лунг, адах_, oito_, --, 
   {{0xc1a40150,0xe3bc010b,0x00000000,0x00000000}},	//   _дымқ, myñ_, --, --, 
   {{0xdd9840b6,0x6284f1d7,0x60c00276,0x26dc1d19}},	//   ыша_, mejo, _înmo, iito_, 
   {{0x26dcf1d8,0xd5f800c8,0x00a00345,0x00000000}},	//   hito_, נפאר, _تیرێ, --, 
   {{0xe3bc09a5,0x26dcf1d9,0xfb84221d,0x7c2c0309}},	//   nyñ_, kito_, تدای, ñarq, 
   {{0x26dcf1da,0x644cf1db,0x6284f1dc,0x8f340713}},	//   jito_, haci, nejo, _херц, 
   {{0xe814000d,0xe3bc0432,0x00000000,0x00000000}},	//   देसा_, hyñ_, --, --, 
   {{0x60dc0357,0x62840165,0x26dc00c0,0xe3bc010e}},	//   niqm, hejo, eito_, kyñ_, 
   {{0x26dcf1dd,0x6284c623,0xe3bc010e,0x00000000}},	//   fito_, kejo, jyñ_, --, 
   {{0x95400020,0x60dcf1de,0x6284f1df,0xe3bc010b}},	//   _የተከሰ, hiqm, jejo, dyñ_, 
   {{0x34a8368e,0x6284f1e0,0x6abcf1e1,0x80c81d8a}},	//   авно_, dejo, öpfe, रसाइ, 
   {{0x644cf1e2,0x26dc02c4,0x798002d0,0x52b41684}},	//   gaci, aito_, _iplw, ुस्स, 
   {{0x62846f10,0x60dc06be,0xe3bc00ee,0x00000000}},	//   fejo, diqm, gyñ_, --, 
   {{0x26dcf1e3,0x6284f1e4,0x644c0175,0x43740212}},	//   cito_, gejo, aaci, чуют, 
   {{0x7640127b,0x321c0108,0x00000000,0x00000000}},	//   mbly, äty_, --, --, 
   {{0x644cf1e5,0x33646be2,0xa0a007d6,0x76400142}},	//   caci, _двиг, масд, lbly, 
   {{0x6284f1e6,0x2ef80112,0x72780395,0x00000000}},	// [15240] bejo, topf_, _кснс_, --, 
   {{0x6284f1e7,0xe3b001ed,0x63b80112,0x00000000}},	//   cejo, _آرٹ_, äune, --, 
   {{0x79801529,0x28d807f7,0x61f80205,0x00000000}},	//   _nplw, _बगलि, ğulc, --, 
   {{0x49740075,0x69dc0419,0x00000000,0x00000000}},	//   җлис, úpem, --, --, 
   {{0x26dcf1e8,0x8e38022e,0x76400af9,0xdce40171}},	//   yito_, _ijrо_, kbly, _apjē, 
   {{0x20c4000d,0x98a40139,0x00000000,0x00000000}},	//   _jõin_, drnı_, --, --, 
   {{0x644cf1e9,0x798002d0,0xa2a800dc,0x7aec00ae}},	//   yaci, _cplw, ञात्, éata, 
   {{0x644cf1ea,0x6284f1eb,0x3cec0183,0x798002d0}},	//   xaci, zejo, _gjev_, _dplw, 
   {{0xe8d817cb,0x38b001ef,0x00000000,0x00000000}},	//   _बगीच, _járy_, --, --, 
   {{0x644c23db,0x26dc0798,0x94f80327,0x98a800e2}},	//   waci, uito_, ྔོའི_, ālām_, 
   {{0x26dcf1ec,0x798003ac,0x60dc01a9,0x00000000}},	//   rito_, _gplw, yiqm, --, 
   {{0x26dcf1ed,0x46e80228,0x764003ac,0x588000cf}},	//   sito_, рдүн_, ably, _жыша, 
   {{0x26dca09f,0x6284f1ee,0x7640f1ef,0x2d9c0427}},	//   pito_, tejo, bbly, _štel_, 
   {{0xe3bc0209,0x26dc0286,0xe570bd62,0x25bc0022}},	//   ryñ_, qito_, _قطع_, pytl_, 
   {{0x6284f1f0,0x644c6a3a,0x60dce483,0xc0c401ec}},	//   rejo, paci, tiqm, пшақ, 
   {{0x6284f1f1,0x644cecda,0x38b001ef,0x00000000}},	//   sejo, qaci, _báry_, --, 
   {{0x4428f1f2,0x6284f1f3,0x3cec0139,0x60dcc329}},	// [15250] _iga_, pejo, _rjev_, riqm, 
   {{0xdd98f1f4,0x60dc014f,0x9e040395,0xa2801291}},	//   ише_, siqm, очел, _تیسو, 
   {{0x442801af,0x955c037e,0x3cec0841,0x60dc0113}},	//   _kga_, _ch全a, _pjev_, piqm, 
   {{0x442841d0,0x60dcf1f5,0x00000000,0x00000000}},	//   _jga_, qiqm, --, --, 
   {{0x4428f1f6,0xfaa48d4f,0xa3c8007d,0x76400042}},	//   _mga_, зало, लनि_, ybly, 
   {{0x442807d6,0xda7855ee,0x7980035a,0xa49801e1}},	//   _lga_, ряд_, _pplw, boòg, 
   {{0x4428f1f7,0x6d5803cd,0x527c08a8,0xaa540063}},	//   _oga_, _åtap, ינגא, чију_, 
   {{0x4428f1f8,0xa3c809bb,0xe8500075,0x8c640063}},	//   _nga_, लना_, ىنىد, _отуд, 
   {{0x76400cfd,0xb910001e,0xe814256a,0x6abc0112}},	//   tbly, _khoẻ_, देला_, öpfc, 
   {{0x4428f1f9,0x7c2805c7,0x76400142,0x0ab8007b}},	//   _aga_, _hger, ubly, _وطلب_, 
   {{0x44288f67,0x7c284d11,0x7640f1fa,0xc8b44667}},	//   _bga_, _kger, rbly, سلیک, 
   {{0xa5600058,0x4428f1fb,0x81e8015b,0x7c28031c}},	//   رگىن, _cga_, _বরং_, _jger, 
   {{0x7c28f1fc,0x386c04cc,0xfbbc00dc,0x00000000}},	//   _mger, mger_, ्निम, --, 
   {{0x4428f1fd,0x386c501b,0xf67400c8,0x7c280139}},	//   _ega_, lger_, _זײַט_, _lger, 
   {{0x44280077,0x20c400af,0x7c28f1fe,0xd5a0036b}},	//   _fga_, _võin_, _oger, _آلبی, 
   {{0x386c7eb1,0x7c28f1ff,0x4428f200,0x38b002fb}},	//   nger_, _nger, _gga_, _páry_, 
   {{0x9f48011f,0x386cf201,0x61f83235,0x7768003a}},	// [15260] _axcâ_, iger_, ğula, nuex, 
   {{0x7c28f202,0x61f8f203,0x4428036b,0x91d8015b}},	//   _ager, şula, _zga_, _দুঃখ, 
   {{0x7c2807de,0xac84008e,0x4428c78a,0x386c05c7}},	//   _bger, згел, _yga_, kger_, 
   {{0x386c01a4,0x7aec003e,0x00000000,0x00000000}},	//   jger_, éatn, --, --, 
   {{0x6604033f,0x386c0e21,0x00000000,0x00000000}},	//   ękki, dger_, --, --, 
   {{0x386cf204,0x236c00cc,0x00000000,0x00000000}},	//   eger_, _ågje_, --, --, 
   {{0x7c2c0960,0x00000000,0x00000000,0x00000000}},	//   žara, --, --, --, 
   {{0x200c0e78,0x00000000,0x00000000,0x00000000}},	//   ügig_, --, --, --, 
   {{0x7b08008c,0x4428f13a,0x2bc81952,0xa84800f7}},	//   ðstö, _rga_, _улап_, _ۇلام_, 
   {{0x692802f8,0x4428f205,0x386cf206,0xb6a00356}},	//   _před, _sga_, ager_, _ţârc, 
   {{0x45d45bd7,0xd94000ee,0x7cf80139,0xa2a800dc}},	//   фонс, _зехи, _färğ, ञास्, 
   {{0x6ab8f207,0xa498068c,0xd5ac01d3,0x6928013a}},	//   _hotf, plòm, اہٹ_, _vřed, 
   {{0x6ab80112,0xb86447e7,0x81e800fe,0x00000000}},	//   _kotf, _زانو, _বৰং_, --, 
   {{0x442802fa,0x91d8009e,0x97100845,0xd37800d4}},	//   _wga_, _দুইখ, _зміц, ччю_, 
   {{0x2730f208,0x63c40724,0x5184f209,0x6928012c}},	//   _hân_, _şunı, нута, _hřeb, 
   {{0x4428f20a,0x6ab8f20b,0xd498084c,0x00000000}},	//   _uga_, _lotf, _ерь_, --, 
   {{0x92bc0183,0x6ab80857,0x7f5c0092,0x7eb800d8}},	// [15270] _আগৰ_, _ootf, ቃሴዎች, огас_, 
   {{0x20040a28,0x27307a2d,0x6ab8f20c,0x7c282a13}},	//   āni_, _mân_, _notf, _sger, 
   {{0x2730f20d,0x7c580075,0x386cf20e,0x6440013f}},	//   _lân_, قلار_, yger_, _ɑnin, 
   {{0x629402c4,0x8c940046,0xd01001ed,0x00000000}},	//   _haxo, ерші, ئلے_, --, 
   {{0x7aecf20f,0x6ab80076,0xe0dc0248,0x6294f210}},	//   éato, _botf, _imò_, _kaxo, 
   {{0x6ab82959,0xed4c2832,0x629426ec,0x00000000}},	//   _cotf, _چھن_, _jaxo, --, 
   {{0x629463ce,0x386cf211,0x27300295,0x7c28f212}},	//   _maxo, tger_, _aân_, _tger, 
   {{0x7c28f213,0xbca44b15,0x386cf214,0x2730f215}},	//   _uger, _تمري, uger_, _bân_, 
   {{0x3a74d081,0x2730f216,0x386cf217,0x6ab8c424}},	//   _олар, _cân_, rger_, _fotf, 
   {{0x273001dc,0x6ab803b2,0x78b8010a,0xd6e00154}},	//   _dân_, _gotf, _wowv, _নীড়প, 
   {{0x386c01e6,0xca740131,0x55c00417,0x00000000}},	//   pger_, _سالغ, ханғ, --, 
   {{0x273039ea,0x2d9c0219,0x00000000,0x00000000}},	//   _fân_, _štek_, --, --, 
   {{0x6294f218,0x2730f219,0xc8b4438b,0x00000000}},	//   _baxo, _gân_, _سلوک, --, 
   {{0xe0dcf21a,0xa5600137,0x00000000,0x00000000}},	//   _amò_, رگۉن, --, --, 
   {{0x62940129,0xdb0801d3,0x00000000,0x00000000}},	//   _daxo, lygó, --, --, 
   {{0x62940332,0xdce403e0,0x00000000,0x00000000}},	//   _eaxo, _orjı, --, --, 
   {{0x629402f0,0xe0d40212,0x00000000,0x00000000}},	// [15280] _faxo, єву_, --, --, 
   {{0x6294005a,0x7f180212,0xe45c00e5,0x00000000}},	//   _gaxo, піху_, nkön_, --, 
   {{0xad580816,0xe4d43267,0xc0f80023,0x8d28013d}},	//   юрах_, _رویت_, ሊሎም_, чнең_, 
   {{0x6ab8f21b,0x7c2c1a48,0x6294014b,0xe45c023a}},	//   _sotf, žarn, _zaxo, hkön_, 
   {{0x6ab8f21c,0x6294738c,0x6b541f0a,0xa2a0012c}},	//   _potf, _yaxo, фтех, _छोड्, 
   {{0xfa540075,0x2ea401d3,0x27300051,0x00000000}},	//   ىرىگ, _تھری_, _rân_, --, 
   {{0x2730f21d,0x6ab800f3,0xed58005b,0xab640210}},	//   _sân_, _votf, _фоб_, wożą, 
   {{0x2730ba97,0x6928012c,0x2900f21e,0x00000000}},	//   _pân_, _přeb, ôka_, --, 
   {{0x692800bc,0x4ba4010b,0xdc7400df,0x7c300419}},	//   _břec, _ялаң, _קעמפ_, ťkrá, 
   {{0x27300016,0x00000000,0x00000000,0x00000000}},	//   _vân_, --, --, --, 
   {{0x6294f21f,0x7afc0436,0xd73021cb,0x20c40254}},	//   _raxo, _ísta, ндөө, _sõim_, 
   {{0x6928038e,0x27307a2b,0x6294f220,0xca68022e}},	//   _třeb, _tân_, _saxo, _vidе, 
   {{0x6294da87,0x60c00356,0x7aec01e1,0x00000000}},	//   _paxo, _înmi, _ántí, --, 
   {{0x629401d9,0x20c400c5,0x30880137,0x16a401a9}},	//   _qaxo, _võim_, үштү_, _овчи_, 
   {{0x6294f221,0x26cc007f,0xb86401ec,0xa800013d}},	//   _vaxo, _ilfo_, _زاۆو, _ğıyn, 
   {{0x6294f222,0x9f480548,0x55e00022,0x00000000}},	//   _waxo, _axcá_, _шәыҷ, --, 
   {{0x62949a13,0xf2c00323,0x13f411ed,0x3f1400f3}},	// [15290] _taxo, _өөри, _изъя, едас, 
   {{0x20c4367a,0x443801ed,0x00000000,0x00000000}},	//   _kõik_, lcs_, --, --, 
   {{0x3d28598b,0xdb08012d,0xad5400e5,0x200c0254}},	//   ستای_, zygó, فرنڈ, ügib_, 
   {{0x4438f223,0x8d740131,0xdcec0171,0x00000000}},	//   ncs_, ئالا, _ēdēt, --, 
   {{0x4438f224,0x7c2c5a54,0xa49801ab,0x20c40037}},	//   ics_, žaro, glòi, _lõik_, 
   {{0x443801fa,0xe80000e1,0x9e640137,0x4ea40354}},	//   hcs_, _लड़ा_, _تاحن, _ирса, 
   {{0xa3cc4e8f,0xc8300092,0x00000000,0x00000000}},	//   वैत_, _በሳምን, --, --, 
   {{0xda600451,0xf8a805dc,0x6578002f,0xb86401f7}},	//   راڙي, काइय, dtth, راعو, 
   {{0x69280316,0x443801e2,0x69cc002f,0xe45c01f4}},	//   _přec, dcs_, _üben, tkön_, 
   {{0xb6580a8f,0x65780100,0xbbbc7ef5,0x999c00e5}},	//   чших_, ftth, ्नीक, űrűk_, 
   {{0x4aac1fbc,0xe574084c,0x497401c4,0x00000000}},	//   चारव, нзэ_, _алхс, --, 
   {{0x92bc2f8b,0x26cc1e0b,0x61f80db1,0x80c801ad}},	//   _আগে_, _elfo_, ğull, रसों, 
   {{0x61f80365,0x692800bc,0x4374014b,0xa854011a}},	//   şull, _třec, курт, _ניסה_, 
   {{0x60ccf225,0xf678008f,0xc7040022,0xe45c007c}},	//   _alcm, _זאַמ, _иҭыз_, lköl_, 
   {{0x6578867c,0xbbbc012c,0x5bc800cd,0x35a400db}},	//   ctth, ्नुक, ऽनुव, _чайг, 
   {{0x4438f226,0xf3e000cc,0xd3a4322f,0x00000000}},	//   ccs_, _গুণৰ_, _алиқ, --, 
   {{0x6fd402bf,0x39900064,0xe45c01f4,0x00000000}},	// [152a0] хівц, _lšs_, rhöt_, --, 
   {{0x6440013f,0x1288004b,0x2d2c0023,0xed584130}},	//   _ɑnim, _ځمکی_, _ብኣማኢ, зож_, 
   {{0x9e701b45,0x00000000,0x00000000,0x00000000}},	//   اهمت, --, --, --, 
   {{0x66e40ca8,0x00000000,0x00000000,0x00000000}},	//   _kékè, --, --, --, 
   {{0x26040c2e,0x09a83d1d,0xeb0401d5,0xce30030d}},	//   _सुनी_, कम्य, нчко, _вогι, 
   {{0xed582dc0,0x657863fb,0xdbc80241,0x63a801d3}},	//   _ног_, ytth, _pòòm, _ágne, 
   {{0xa3e40882,0x9c809a64,0x2d9c0085,0x4c84f227}},	//   _येन_, ščar, _éte_, _لیاق, 
   {{0x6d4c011c,0x7ae00327,0x99803c19,0x1cb00327}},	//   _iwba, _emlt, اليو, _ྟོག_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x20c4000d,0x00000000,0x00000000,0x00000000}},	//   _põik_, --, --, --, 
   {{0x6e2c03a2,0x6d4c020b,0x6578127b,0x00000000}},	//   _mgbb, _jwba, utth, --, 
   {{0x657800b8,0x4438067c,0x20c40254,0x00000000}},	//   rtth, ucs_, _võik_, --, 
   {{0x4438f228,0x68e01b33,0x29040093,0x61f83535}},	//   rcs_, _imod, _ikoa_, ğulm, 
   {{0x5690f229,0x61f85556,0x26cc0ba7,0xd1f8001f}},	//   _башт, şulm, _ulfo_, ጋጋት_, 
   {{0xa0a40220,0x44388d3f,0x00000000,0x00000000}},	//   ншал, pcs_, --, --, 
   {{0xc0c400c7,0x00000000,0x00000000,0x00000000}},	//   тәои, --, --, --, 
   {{0x290400b2,0x68e0055a,0x6d4c5ad0,0x356801c4}},	// [152b0] _mkoa_, _mmod, _awba, _ерөн_, 
   {{0x6d4c0142,0x1cb0031c,0x6abc002f,0x63b80162}},	//   _bwba, _ྟོང_, öpfl, øunu, 
   {{0x68e0f22a,0x2904123c,0xd01000f1,0x5ce40139}},	//   _omod, _okoa_, للې_, нюда, 
   {{0x2904f22b,0x672805ac,0x39900010,0x00000000}},	//   _nkoa_, _lifj, _ršs_, --, 
   {{0x6608017a,0x6d4cf22c,0xbbbc92c1,0x7c380042}},	//   _lyfk, _ewba, ्नेक, rcwr, 
   {{0x2904f22d,0x68e0f22e,0x2128f22f,0x6d4c0334}},	//   _akoa_, _amod, _hich_, _fwba, 
   {{0x2128f230,0x69cc0e78,0x68e0f231,0x2d9c0427}},	//   _kich_, _übel, _bmod, _štev_, 
   {{0x200400ac,0x2128012c,0x68e00175,0x3990f232}},	//   ənir_, _jich_, _cmod, _všs_, 
   {{0x2128f233,0x60c00311,0x53e041d8,0x6f28010e}},	//   _mich_, _înmu, _पेंश, _üpcü, 
   {{0x6608000f,0x68e0f234,0x2128f235,0x2904ed20}},	//   _byfk, _emod, _lich_, _ekoa_, 
   {{0xb9b4f236,0x68e00175,0x212801c3,0x7bd8002f}},	//   _جماع, _fmod, _oich_, lzwu, 
   {{0x21282f53,0xb96401e1,0x6928013a,0x798c012d}},	//   _nich_, _ebìí, _hřen, ławs, 
   {{0x7564066d,0x69280118,0x00000000,0x00000000}},	//   ریکہ_, _křen, --, --, 
   {{0x212801c3,0x68e00034,0x672801f5,0xd5a0f237}},	//   _aich_, _zmod, _gifj, _ملتی, 
   {{0xe45c5b00,0x68e00076,0x31780334,0x21280208}},	//   rhör_, _ymod, _qqpz_, _bich_, 
   {{0x7c2c09a8,0x6d4c015d,0xc1c80014,0xa3a80037}},	//   žarj, _rwba, ڈبہٕ_, _गपच_, 
   {{0x2128f238,0x9f4c0008,0x6d4c0175,0xe45c0267}},	// [152c0] _dich_, ægð_, _swba, phör_, 
   {{0x21280f7b,0x6da4f239,0xada400fd,0xc32c00db}},	//   _eich_, киза, казл, _رەف_, 
   {{0x21281570,0xe1f40276,0x91c464b6,0xb13800ae}},	//   _fich_, _агэ_, _санҗ, _تأخذ_, 
   {{0x776801e2,0x2128f23a,0x00000000,0x00000000}},	//   krex, _gich_, --, --, 
   {{0x6bd42099,0x00000000,0x00000000,0x00000000}},	//   ختار, --, --, --, 
   {{0x21280460,0x5bc004a9,0x29042d8b,0x68e00427}},	//   _zich_, شقىل, _skoa_, _smod, 
   {{0xdee0f23b,0x6728244a,0x2128007f,0x3ea400ae}},	//   _тори, _rifj, _yich_, _ólta_, 
   {{0x7768f23c,0x0798026a,0x2d880455,0x98c035c7}},	//   frex, евић_, _ipbe_, исыл, 
   {{0x2904005b,0x00000000,0x00000000,0x00000000}},	//   _vkoa_, --, --, --, 
   {{0x2b4400f7,0x68e0010a,0x00000000,0x00000000}},	//   mpoc_, _wmod, --, --, 
   {{0xd5b410f5,0x1e540302,0x29040109,0xeb0c0073}},	//   вся_, כשיר_, _tkoa_, ितीत_, 
   {{0x68e0055a,0x9ad0063f,0x7768056a,0x00000000}},	//   _umod, _jịnj, brex, --, 
   {{0x53e4f23d,0x6608045f,0x2128f23e,0x20c40037}},	//   ацра, _wyfk, _rich_, _kõiv_, 
   {{0x21282d65,0x00000000,0x00000000,0x00000000}},	//   _sich_, --, --, --, 
   {{0x7aec0231,0x2128f23f,0x24f40124,0xd5ac02f2}},	//   éati, _pich_, _аҽны_, _وفه_, 
   {{0x439400c7,0x21280978,0x20c40254,0x7f9421b5}},	//   _баис, _qich_, _lõiv_, лабх, 
   {{0x2128f240,0x26040ce0,0x73c005a2,0x7c2c0219}},	// [152d0] _vich_, _सुती_, _ләре, žark, 
   {{0x20f005be,0x4ea4f241,0x2128f242,0x8cc401b9}},	//   pćio_, ирха, _wich_, یقله, 
   {{0x2128f243,0xa3e405ba,0xa3cc041c,0xce940395}},	//   _tich_, _येत_, वैर_, рахъ, 
   {{0x7bf8f244,0xbc180006,0x0ca800c7,0x00000000}},	//   ннер_, нілі_, ҵтәи_, --, 
   {{0x69280316,0xda9005f5,0x4fc40131,0x81e800cc}},	//   _přen, игдө, _پەلە, _বৰচ_, 
   {{0x3f980c95,0x2d880589,0x3d940209,0x00000000}},	//   _issu_, _fpbe_, _йигр, --, 
   {{0xa018006a,0x00000000,0x00000000,0x00000000}},	//   _mböm, --, --, --, 
   {{0xc0f802d3,0x00000000,0x00000000,0x00000000}},	//   ሊፎም_, --, --, --, 
   {{0x7d08f245,0xca3800df,0x69280118,0xdb08010b}},	//   _ikes, _saĝe_, _třen, dygö, 
   {{0x7768f246,0x3f98058a,0x9a840353,0x00000000}},	//   rrex, _mssu_, _шубл, --, 
   {{0xf8740722,0x95b001c0,0x260432ed,0x692801ef}},	//   _مهاج, рөлх, _सुदी_, _křel, 
   {{0xc328025f,0x3f9819f5,0x7d08031c,0x69d8008f}},	//   _זו_, _ossu_, _jkes, _אַדו, 
   {{0x7d08f247,0xf4880023,0x00000000,0x00000000}},	//   _mkes, _ንዛረብ_, --, --, 
   {{0xd1740032,0x1608000d,0x00000000,0x00000000}},	//   һығы, _सँपर_, --, --, 
   {{0x3f98f248,0xa49835f5,0x7d08f249,0x668057be}},	//   _assu_, glòs, _okes, _ایپل, 
   {{0xd1744d50,0x7d08f24a,0x00000000,0x00000000}},	//   лығы, _nkes, --, --, 
   {{0xa4980ba1,0xcee44942,0x251801e4,0x00000000}},	// [152e0] rlòt, абақ, _אוקא, --, 
   {{0xed3405f5,0x7d08f24b,0xb8d4025c,0xaf0893d2}},	//   гэдэ, _akes, _ཝོ_, رقام_, 
   {{0x3f98026c,0x6df8013e,0xa4980100,0xd8d801ec}},	//   _essu_, ххас_, plòt, _ﺀﺑﻮﻟ, 
   {{0x7afc032e,0x00000000,0x00000000,0x00000000}},	//   _ístj, --, --, --, 
   {{0x2b440165,0x0bb41309,0x692801ef,0x00000000}},	//   upoc_, рблю, _dřel, --, 
   {{0x7d08f24c,0x8c600220,0x6928013a,0xeb0c01f9}},	//   _ekes, дiң_, _přeo, ितेत_, 
   {{0x2b440230,0x2d880455,0x13d00118,0xcdc41188}},	//   spoc_, _upbe_, हनुभ, _тавқ, 
   {{0x6d5cf24d,0xeb98a44d,0x1cb0025c,0xe45c007c}},	//   mspa, _пиб_, _ཟོར_, rkök_, 
   {{0x6d5c07d5,0x2a7404fb,0xaa444b7e,0x4734147e}},	//   lspa, _مداح, _безл, јнос, 
   {{0xfa3402dd,0x5bc0004e,0x00000000,0x00000000}},	//   _күші_, _уйуб, --, --, 
   {{0x6d5cf24e,0x18980023,0x44f400f3,0xe5c42b2e}},	//   nspa, _ቁጽጽር_, ипос, успо, 
   {{0x6d5cf24f,0x69280118,0xe8f86d4f,0xb8640345}},	//   ispa, _křem, _яле_, _ناهو, 
   {{0x6d5cf250,0x1cb00135,0xa3cc39a1,0x368801c6}},	//   hspa, _ཟོལ_, वैं_, хсөн_, 
   {{0x6d5ca4f3,0x26c8007c,0x00000000,0x00000000}},	//   kspa, öbod_, --, --, 
   {{0xd5acf251,0x34d00a28,0x160823ef,0x4034f252}},	//   _ус_, ṣaḥ_, _सुपर_, иевс, 
   {{0x6d5cf253,0x7c2c04a7,0x443c00a2,0x00000000}},	//   dspa, žari, _üw_, --, 
   {{0x43940046,0x7e5402bf,0xd108036b,0x69c80042}},	// [152f0] _тапс, иває, اققه_, hyfe, 
   {{0x6d5cf254,0x7d0801a8,0x4aa407f7,0x57f80375}},	//   fspa, _skes, _गोलव, תלמו, 
   {{0x3d94f255,0x6928012c,0x325401c0,0x940c013f}},	//   риер, _přel, _өвөр, ɛdɑ_, 
   {{0xda7800c6,0x69c80158,0x69280118,0x00000000}},	//   ʂяƴ_, dyfe, _břem, --, 
   {{0x6d5cf256,0x8d840075,0x692800bc,0xfcd800e5}},	//   aspa, _қурд, _vřel, _یارڈ_, 
   {{0xfaa4f257,0xc0e002d3,0x4aa8f258,0x00000000}},	//   рако, ናዮም_, лкін_, --, 
   {{0xfc140729,0x6d5c0c8c,0x69c83a9f,0xf770004b}},	//   িশেষ_, cspa, gyfe, ښاد_, 
   {{0x7d08f259,0x69280118,0x00000000,0x00000000}},	//   _ukes, _hřej, --, --, 
   {{0x9b400220,0x4cfc0208,0xb7b8013d,0x00000000}},	//   _اۆتو, _ýđến_, тыйх_, --, 
   {{0xa680f25a,0x4644001f,0xaab400ec,0x00000000}},	//   ольд, _የአገራ, _پگهر_, --, 
   {{0x7aec004a,0xb9941d93,0x3ea000a3,0x00000000}},	//   éatu, _خلاب, idht_, --, 
   {{0x1cb00003,0xb6040cad,0x20c400c5,0xa3e403e5}},	//   _ཟོས_, _aláà, _mõis_, _येह_, 
   {{0x200c00c5,0x1cb0031c,0x6d5c0036,0x4904104c}},	//   ügil_, _ྟོན_, zspa, _اونق, 
   {{0x6d5cf25b,0xb14444f0,0xe5e403e6,0x247c0521}},	//   yspa, ингл, ازیی, ọmpi_, 
   {{0x0674113e,0x6e9401b9,0x6abc0112,0x25b4007b}},	//   _انىڭ, یلرا, öpfi, _نهود_, 
   {{0x6d5cbac0,0x92f4009d,0xe808134e,0x00000000}},	//   vspa, рүүх, _हुडा_, --, 
   {{0xb604063f,0x6d5cf25c,0x2ee40209,0xa4980561}},	// [15300] _fláà, wspa, ажаг, plòr, 
   {{0x6d5cf25d,0xdb904be7,0x20c400c5,0x00000000}},	//   tspa, _ማርያም_, _sõit_, --, 
   {{0x6d5cf25e,0x6c3400c6,0x00000000,0x00000000}},	//   uspa, لفضا, --, --, 
   {{0x6d5c65e0,0x6928012c,0xeb0c9a09,0x00000000}},	//   rspa, _přem, ित्त_, --, 
   {{0x6d5cf25f,0x20c400c5,0x69c81829,0x00000000}},	//   sspa, _võit_, wyfe, --, 
   {{0x728c693c,0x6d5cf260,0x2004054e,0x29640063}},	//   _ህዝባዊ_, pspa, şnic_, ањив, 
   {{0x49a40220,0xed58f261,0x8c88013d,0x00000000}},	//   сылғ, _шов_, _бәла_, --, 
   {{0x692800bc,0x69c83bb5,0xec14029e,0xddc401ef}},	//   _zřej, ryfe, _نوزد, _nejř, 
   {{0xeb28f262,0x69c8f263,0x00000000,0x00000000}},	//   _ажал_, syfe, --, --, 
   {{0x1ae00120,0xa2601954,0x00000000,0x00000000}},	//   _доум, ስታንን_, --, --, 
   {{0x6b80f264,0xe80000e1,0xd940d33a,0x00000000}},	//   ltog, _लडका_, _дехи, --, 
   {{0x6b800b23,0xd834f265,0x8a400345,0x00000000}},	//   otog, _кэш_, _بێژن, --, 
   {{0x6b801570,0xd7e0003b,0xc3c4013d,0x00000000}},	//   ntog, _мішо, сөйл, --, 
   {{0x6b80c713,0x926867ba,0x00000000,0x00000000}},	//   itog, ирса_, --, --, 
   {{0x171804ac,0x9258f266,0x691c002e,0x2b800051}},	//   _שווע, раст_, rëef, _lưc_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69280316,0x2284f267,0xfc3800df,0x200c01a8}},	// [15310] _přej, _кунг, _naŭa_, ægi_, 
   {{0x539c0302,0x42740b3e,0xc1b81e76,0x20c40254}},	//   _ייחו, _угос, _блох_, _põis_, 
   {{0x20040034,0x628411c0,0x3ea00098,0x00000000}},	//   łni_, mfjo, rdht_, --, 
   {{0x20c400af,0x62840217,0x6b800af9,0x3d94024c}},	//   _võis_, lfjo, ftog, _қибр, 
   {{0xca38008f,0x61f80c3c,0x2b800208,0xb6680092}},	//   _saĝa_, ğulu, _cưc_, _ተጠቅሞ_, 
   {{0x61f8f268,0xca3800df,0x62840217,0x9a84651e}},	//   şulu, _paĝa_, nfjo, рудл, 
   {{0x6b8080c9,0xa96412e6,0x62840158,0xd6bc00fe}},	//   atog, бища_, ifjo, ইসময, 
   {{0x1be4036b,0xf4b00154,0xa3b407f7,0x22a80153}},	//   _кўзг, _চত্ব, छमा_, lėkė_, 
   {{0xa4980699,0x6b80f269,0x628405ac,0xe80800bc}},	//   vlòp, ctog, kfjo, _हुदा_, 
   {{0x394400ad,0xdac400d1,0x00000000,0x00000000}},	//   _ttls_, _خېتى_, --, --, 
   {{0x628403d4,0x14c801d5,0xd1cc0b82,0xd8740345}},	//   dfjo, لهدی_, በባት_, _ناشب, 
   {{0x3980f26a,0x7c2c5c82,0x00000000,0x00000000}},	//   mós_, žaru, --, --, 
   {{0x3980f26b,0xb6a4030d,0x853c0153,0x00000000}},	//   lós_, _гилл, lvėl, --, 
   {{0x8704f26c,0x62840158,0x00000000,0x00000000}},	//   _وبول, gfjo, --, --, 
   {{0x98d80918,0x3980f26d,0x692800bc,0x00000000}},	//   _बताए, nós_, _břeh, --, 
   {{0x3980067c,0xafe401b9,0x92e80011,0x6b8003cd}},	//   iós_, бобл, যকে_, ytog, 
   {{0x39808a8f,0x00000000,0x00000000,0x00000000}},	// [15320] hós_, --, --, --, 
   {{0x69280316,0xfca800aa,0xe45c0008,0xec1400fb}},	//   _přek, یانو_, gjöf_, ҙелә_, 
   {{0x3980f26e,0x6b800142,0xa5440092,0x00000000}},	//   jós_, wtog, _የተንቀ, --, 
   {{0xdd8cf26f,0x6b80f270,0x3980f271,0x853c00c0}},	//   عون_, ttog, dós_, dvėl, 
   {{0xf1fc00e1,0x6b80f272,0x00000000,0x00000000}},	//   _उखड़_, utog, --, --, 
   {{0x398066e5,0x2b800208,0x00000000,0x00000000}},	//   fós_, _vưc_, --, --, 
   {{0x6b80f273,0x48c40588,0x644c033f,0x3980f274}},	//   stog, жәла, ybci, gós_, 
   {{0x160805f9,0x7aecf275,0xe18c0b82,0x999402e8}},	//   _सुधर_, éatr, _ምግባሩ_, скът_, 
   {{0x628400cc,0x691c0036,0xab640139,0x97a00139}},	//   yfjo, jëee, _ывал, прэл, 
   {{0x3980f276,0x798001f2,0xe45c023a,0x00000000}},	//   bós_, _ịwet, hköt_, --, 
   {{0x3980f277,0xe7b462a9,0x628403cd,0x6abc002f}},	//   cós_, _گمشد, vfjo, öpfu, 
   {{0xca3800df,0xa92415ab,0x06c801c0,0x2a7c0142}},	//   _kaĝo_, _удел, угүй_, _hctb_, 
   {{0x62847e78,0x00000000,0x00000000,0x00000000}},	//   tfjo, --, --, --, 
   {{0xadf8f278,0x490401b9,0x45d40798,0x853c0153}},	//   ्थान_, _اوچق, _молс, lvėm, 
   {{0x6928038e,0xd5acf279,0x6284f27a,0xe4e4109a}},	//   _přeh, _эс_, rfjo, _гіпн, 
   {{0x628413ce,0x00000000,0x00000000,0x00000000}},	//   sfjo, --, --, --, 
   {{0x62840158,0x398001d3,0x2ee8002f,0xe45c01d3}},	// [15330] pfjo, zós_, _bmbf_, khöz_, 
   {{0x63b8002f,0x80a8000d,0xa2c00037,0x00000000}},	//   äunu, _चोरइ, _रकट्, --, 
   {{0x40340953,0x9cc8010b,0x3980004e,0xc0d40092}},	//   _менс, лыда_, xós_, ከበረ_, 
   {{0x39804da9,0x81c009bd,0x61f8cdf0,0xddc4012d}},	//   vós_, ্ছদ_, şuls, _zejś, 
   {{0x2ee80175,0x79800857,0x853c0064,0x00000000}},	//   _fmbf_, _sqlw, dvėm, --, 
   {{0xd1b804d3,0x3980f27b,0xba742dfc,0x7f4cf27c}},	//   _ئایا_, tós_, زاتت, mpaq, 
   {{0xe63c0023,0x9a8402dd,0x18b00139,0x7f4cf27d}},	//   _ተሓጋጋ, _қуал, зәлр, lpaq, 
   {{0x3980f27e,0xc0d40092,0x00000000,0x00000000}},	//   rós_, ከበሩ_, --, --, 
   {{0x7f4c0bf1,0x81c00154,0x00000000,0x00000000}},	//   npaq, ্ছি_, --, --, 
   {{0x3980f27f,0xcbe401c0,0x36680f5c,0x8f9c0a1e}},	//   pós_, _эцси, јано_, ריזי, 
   {{0xcb280050,0x6d580393,0xceb404ae,0x59b001c0}},	//   _آلو_, _ætat, ליץ_, _хөлс, 
   {{0xe80802ab,0x7f4c03f0,0xa2600023,0x853c0153}},	//   _हुवा_, kpaq, ድዳእን_, ovėj, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4094b071,0xa2340022,0xe81c0073,0x00000000}},	//   үртт, жьтә, _परता_, --, 
   {{0x216400d1,0x61400cb6,0x21a0010b,0x7afc08ce}},	//   жиси_, деса, мирм, _ístu, 
   {{0xddc40034,0xe0d40408,0x20040213,0x70f400d4}},	//   _wejś, овс_, əniz_, іївц, 
   {{0xa3e40574,0x00000000,0x00000000,0x00000000}},	// [15340] _येऊ_, --, --, --, 
   {{0xdb040ffb,0xca380115,0xd25001d9,0x853c0024}},	//   _èmès, _raĝo_, _سۆر_, dvėj, 
   {{0xa2a00574,0xca38010f,0xc044001f,0xb2240276}},	//   _छोट्, _saĝo_, ያስችለ, _фмнл, 
   {{0xca3804ac,0xc0d4001f,0x2ee8031c,0x63b803cd}},	//   _paĝo_, ከበር_, _wmbf_, åung, 
   {{0x1608069f,0x00000000,0x00000000,0x00000000}},	//   _सुसर_, --, --, --, 
   {{0xad6442b5,0xe45c0205,0x00000000,0x00000000}},	//   _وازه, nkör_, --, --, 
   {{0x853c0153,0xa3e40073,0xa2b80677,0x00000000}},	//   tvėm, _येई_, ימסט, --, 
   {{0x1cb00003,0xe81c007d,0x1d046bed,0x6cd400c6}},	//   _ཟོག_, _परदा_, _деси_, _بقرا, 
   {{0xfbcc0451,0x2ca401d5,0x00000000,0x00000000}},	//   _مڪو_, mdod_, --, --, 
   {{0x8574f280,0xfc3801e4,0x09d0025c,0xa9680107}},	//   плох, _laŭl_, ུརྱ_, _вижа_, 
   {{0xd6d410f5,0x1da40092,0xb9e400db,0xdb2008a5}},	//   іть_, ፈርቶች_, _ىسمى, _þrái, 
   {{0x2ca4f281,0x7f4c03f0,0xa3e40073,0x7bcc0254}},	//   ndod_, ypaq, _येउ_, äaug, 
   {{0x4614f282,0x6928013a,0x9378011c,0x00000000}},	//   توگر, _břev, обят_, --, 
   {{0x56900372,0xe45c01f4,0x37440354,0x00000000}},	//   _жашт, tkös_, _хĕрт, --, 
   {{0xe0d0f283,0x69280316,0x5184f284,0x7f4c0986}},	//   وزر_, _dřev, мута, wpaq, 
   {{0xd50800ec,0x00000000,0x00000000,0x00000000}},	//   _وٺون_, --, --, --, 
   {{0x2ca4015d,0x00000000,0x00000000,0x00000000}},	// [15350] ddod_, --, --, --, 
   {{0xdda847bf,0x7f4cf285,0x1cb0025c,0x93940451}},	//   ител_, rpaq, _ཟོང_, _آجيا, 
   {{0x26dc023a,0x7f4c0986,0xf2d0010f,0x00000000}},	//   ihto_, spaq, _נעט_, --, 
   {{0x853c0006,0xd5f8008f,0x7f4c0140,0x2ca40142}},	//   tvėj, ספאר, ppaq, gdod_, 
   {{0x7f4c02d1,0xc0c80092,0x00000000,0x00000000}},	//   qpaq, በናል_, --, --, 
   {{0x539c008d,0x2ca40254,0xc31c00cc,0x0ae8003b}},	//   יידו, adod_, _ধূতি_, одій_, 
   {{0x2ca4022e,0x853c0153,0x26dc0332,0x23a400bc}},	//   bdod_, svėj, dhto_, खिँद, 
   {{0x26dc02f6,0x52c8012c,0x00000000,0x00000000}},	//   ehto_, _रक्स, --, --, 
   {{0xacd8008f,0xf770007b,0x3a747577,0x00000000}},	//   _פֿלי, راة_, _нлар, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8578023a,0xe614b7e2,0xe45c007c,0x00000000}},	//   осят_, здэ_, vkör_, --, 
   {{0x656c00c6,0x26dc01f4,0x00000000,0x00000000}},	//   ábha, ahto_, --, --, 
   {{0x69cc91e1,0xf74806d5,0x69280316,0xd11c1f13}},	//   _über, _التي_, _přev, _भीषण_, 
   {{0x26dc03c6,0xddc40115,0x2bbc01bc,0xdce40205}},	//   chto_, _sejŝ, ्हता, _msjı, 
   {{0xaa840432,0x2ca4f286,0xe45c01e3,0x00000000}},	//   _haýý, ydod_, rkör_, --, 
   {{0xa50406bb,0xa3e40401,0x00000000,0x00000000}},	//   _неща_, _येक_, --, --, 
   {{0xb4c805d7,0xe45c01e3,0xb2240150,0x00000000}},	// [15360] ोसी_, mköp_, імұл, --, 
   {{0xaa8400a2,0x2ca40042,0xe45c01e3,0x00000000}},	//   _maýý, wdod_, lköp_, --, 
   {{0xddc401e4,0x692801ef,0x00000000,0x00000000}},	//   _tejŝ, _křet, --, --, 
   {{0x6538010f,0xe45c01e3,0x00000000,0x00000000}},	//   צענד, nköp_, --, --, 
   {{0x2ca4f287,0x3cdc0034,0x1d041fbe,0xfca8785c}},	//   rdod_, _खतरे_, чеци_, تالو_, 
   {{0xdc480372,0x00000000,0x00000000,0x00000000}},	//   لسۇۇ_, --, --, --, 
   {{0xdb8001c6,0x7cf400e4,0x6d4801e4,0xda3001ec}},	//   _үгси, _ỹrem, ŭfab, нешы, 
   {{0xa018007c,0xe45c007c,0xf8b400db,0x00000000}},	//   _ibör, jköp_, дөш_, --, 
   {{0x25ac0161,0x26dc014b,0x00000000,0x00000000}},	//   _srfl_, thto_, --, --, 
   {{0x45d4f288,0xdbc4000d,0x00000000,0x00000000}},	//   доос, tööp, --, --, 
   {{0x2604f289,0x48c4035b,0x75801272,0xe81c0073}},	//   _सुखी_, _жәпа, نیوم, _परवा_, 
   {{0x7afcf28a,0x61e000a2,0xdbc40254,0x692801ef}},	//   _ístr, _ýnli, rööp, _přeu, 
   {{0xaa8400a2,0xa818f28b,0xd7f4014b,0x00000000}},	//   _gaýý, _اتار_, _нуш_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6578f28c,0xd5f80302,0x75340139,0x3fd80276}},	//   muth, _לפור, _giyz, омбэ_, 
   {{0x6578f28d,0x00000000,0x00000000,0x00000000}},	// [15370] luth, --, --, --, 
   {{0x692800bc,0x645cf28e,0x00000000,0x00000000}},	//   _křes, _heqi, --, --, 
   {{0xf408025c,0x645c0023,0x65789da5,0xae340166}},	//   _གཙོད_, _keqi, nuth, дүрт_, 
   {{0x645cf28f,0x5574010f,0x00000000,0x00000000}},	//   _jeqi, לעבן_, --, --, 
   {{0xa0180086,0x0b44eeec,0x6f0007ea,0x0ba8007b}},	//   _ebör, енін, éocc, كاوى_, 
   {{0x6578835f,0x645c01f0,0xbe6400ec,0x98ac007f}},	//   kuth, _leqi, _زهري, _vigč_, 
   {{0x3f88f290,0xaa840432,0xbd4401f7,0x00000000}},	//   ltau_, _saýý, _آنري, --, 
   {{0x6578b567,0x645cf291,0xe45c01e3,0x00000000}},	//   duth, _neqi, xköp_, --, 
   {{0x3f88f292,0x7c2c00ee,0x65780208,0xb8f43cc3}},	//   ntau_, ýard, euth, _सक_, 
   {{0x6578f293,0x3f88f294,0x692801ef,0x75440fac}},	//   futh, itau_, _břes, мноз, 
   {{0x645cf295,0x65780b6f,0x6928012c,0xa74001e0}},	//   _beqi, guth, _přet, ндөҙ, 
   {{0x3f88f296,0xaa8409a5,0xb4c851a5,0x3774004e}},	//   ktau_, _taýý, ोसे_, _жыкс, 
   {{0x3668f297,0xd7f801c0,0x78a8f298,0x645c9003}},	//   _дало_, _ууж_, mdev, _deqi, 
   {{0x65788cdb,0xc72400d6,0x78a8f299,0x160805f9}},	//   buth, _здій, ldev, _सुअर_, 
   {{0x69280316,0x6578f29a,0x3f8804cc,0xe45c007c}},	//   _třet, cuth, etau_, pköp_, 
   {{0x78a8f29b,0x128804fb,0xd9ac0011,0x260401f9}},	//   ndev, _کمدی_, _কথাম, _सुटी_, 
   {{0x3f880589,0x00000000,0x00000000,0x00000000}},	// [15380] gtau_, --, --, --, 
   {{0x645c02d3,0x78a8005b,0x2eec007f,0x00000000}},	//   _zeqi, hdev, òff_, --, 
   {{0x3f880421,0x645cf29c,0x78a80115,0x312468ba}},	//   atau_, _yeqi, kdev, _одог, 
   {{0xeb9801c0,0xe81c000d,0x00000000,0x00000000}},	//   жид_, _परला_, --, --, 
   {{0xab986568,0x78a8f29d,0x3f88f29e,0x6ea000c7}},	//   تخار_, ddev, ctau_, _иҳаҕ, 
   {{0xed58f29f,0x6578f2a0,0x78a800a7,0xfa8001a9}},	//   _мог_, yuth, edev, лқум, 
   {{0x78a81af3,0x65780472,0xedd405af,0x2d9c0248}},	//   fdev, xuth, _غيرد, _ète_, 
   {{0x65787fa2,0x6d4c127b,0x311c00dc,0x60d8010f}},	//   vuth, _itba, पतिः_, ַקינ, 
   {{0x47343eb8,0x65780912,0x645cf2a1,0xaa4400f3}},	//   ннис, wuth, _reqi, _жезл, 
   {{0x6928038e,0x6578f2a2,0x645cb708,0xea5800d8}},	//   _přes, tuth, _seqi, _фрај_, 
   {{0x645cf2a3,0x9e74025f,0x78a8f2a4,0x6ab8192e}},	//   _peqi, וגיה_, bdev, _intf, 
   {{0x6578f2a5,0xca380115,0x3e7401e1,0xe73835c7}},	//   ruth, _naĝi_, _kùtà_, _дед_, 
   {{0xb8641e2f,0x764c0790,0x645c036e,0x17500024}},	//   _سانو, _şaye, _veqi, _авія, 
   {{0x645c013e,0xa61000d1,0x6d4c03ac,0x6578036e}},	//   _weqi, _излә, _otba, puth, 
   {{0x5334f2a6,0xa0a41411,0x65781449,0x6d4c025c}},	//   терт, мшал, quth, _ntba, 
   {{0x3f88f2a7,0xe7d0193d,0x00000000,0x00000000}},	//   ttau_, _तथाप, --, --, 
   {{0x6d4c0029,0x3f88f2a8,0x6ab8f2a9,0x4fc400d8}},	// [15390] _atba, utau_, _ontf, ксфа, 
   {{0x8c142158,0x3f88f2aa,0xbf140597,0x78a8005f}},	//   িধান_, rtau_, رواب, zdev, 
   {{0x3f88f2ab,0x78a8f2ac,0x1cb00327,0x00000000}},	//   stau_, ydev, _ཟོད_, --, 
   {{0xd010066d,0x200cf2ad,0x3f88f2ae,0x9f84067c}},	//   الے_, ügis_, ptau_, _nòça_, 
   {{0x6d4c035a,0x78a80158,0x7cf000d0,0x00000000}},	//   _etba, vdev, sťro, --, 
   {{0xd37c00df,0x00000000,0x00000000,0x00000000}},	//   קרוט, --, --, --, 
   {{0x98ac0421,0xf990f2af,0x7e640263,0xe0dc007f}},	//   _aigā_, ابت_, mahp, _klò_, 
   {{0x6ab8f2b0,0x7e64f2b1,0x78a8011c,0x092801e2}},	//   _entf, lahp, udev, وسيي_, 
   {{0x78a8f2b2,0x6928012c,0xdb180e78,0x78ac0162}},	//   rdev, _přer, _gruß, _óavm, 
   {{0xb4c802f8,0xb6a40323,0x78a80784,0x7e640113}},	//   ोस्_, хиол, sdev, nahp, 
   {{0x78a8f2b3,0x9f840ba1,0x47c003d4,0xe0dc01e1}},	//   pdev, _fòça_, শৈলী, _olò_, 
   {{0xc31c009e,0x7e640455,0x88b80327,0x3f4c0419}},	//   _ধূলি_, hahp, _ཐོགར, _kľud_, 
   {{0x1cb00135,0xa8540131,0x7e64003e,0x00000000}},	//   _ཟོན_, _чечә, kahp, --, 
   {{0xe0dc1e69,0x7768004d,0x7e640477,0x59b0012d}},	//   _alò_, msex, jahp, ंटपर, 
   {{0xe0dc026c,0x7e642a1f,0x021802bf,0x6928013a}},	//   _blò_, dahp, діть_, _křep, 
   {{0xe45cf2b4,0xe0dc0192,0xa0a0010b,0x00000000}},	//   ljön_, _clò_, ласд, --, 
   {{0x7768f2b5,0xe0dcf2b6,0xc3a40032,0x6aa8015d}},	// [153a0] nsex, _dlò_, _алыҫ, ydff, 
   {{0xa2e00354,0x00000000,0x00000000,0x00000000}},	//   _боьд, --, --, --, 
   {{0xe0dc007f,0x7cf40124,0x77680208,0x020400db}},	//   _flò_, _ỹram, hsex, _үзөн, 
   {{0x63f404fb,0x21a00a93,0x8fc400c7,0x2d68010f}},	//   _آفیس_, _сиюм, _ҟаҳҵ, rĝe_, 
   {{0x32180124,0x7bdc00ac,0x776800d0,0x6b540354}},	//   _hypy_, _üsul, jsex, хтех, 
   {{0x321800c7,0xe164035c,0xad680107,0x7768007c}},	//   _kypy_, _تضیی, _нагз_, dsex, 
   {{0x6d4c14dc,0x49a4774d,0xfe44036b,0x8c880022}},	//   _utba, тылғ, _شکلی, _жәла_, 
   {{0xed580364,0xe87400aa,0x2d88014f,0xa4980ba1}},	//   _моҳ_, راعظ, _iqbe_, inòc, 
   {{0x1d04f2b7,0xa0980a1e,0x66d400a2,0x7768007c}},	//   _чети_, ליקט, _hâki, gsex, 
   {{0x6ab80b21,0x5ba40107,0x00000000,0x00000000}},	//   _untf, _якум_, --, --, 
   {{0xd90c01d3,0xa96800d8,0x272002d2,0x00000000}},	//   _گیٹ_, _ѕида_, gðna_, --, 
   {{0x98ac0607,0x12e402dd,0x6fb017c6,0x00000000}},	//   _tigā_, ңірг, ीमां, --, 
   {{0x98ac0618,0x7e640455,0x977001c8,0x00000000}},	//   _uigā_, yahp, _مُنش, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa498f2b8,0x201c00f3,0xd6240640,0x02d005d7}},	//   gnòc, _šui_, _поље_, _सकीन, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3f140209,0x26cc00d7,0x73c0190b,0xf42800db}},	// [153b0] вдас, _kofo_, _кәре, _ۉيۉۉ_, 
   {{0x26cc0109,0x9e04f2b9,0x4ed40212,0x00000000}},	//   _jofo_, нчел, люєт, --, 
   {{0x26cc0170,0xa498004e,0x7e64037e,0xa2f00451}},	//   _mofo_, cnòc, rahp, _ليکڪ, 
   {{0x8d74282b,0x3154011a,0x00000000,0x00000000}},	//   االا, _שירן_, --, --, 
   {{0x98ac054e,0x691c002e,0x00000000,0x00000000}},	//   _ligă_, rëel, --, --, 
   {{0x26ccf2ba,0x1cb0025c,0x3f98f2bb,0x60cc0208}},	//   _nofo_, _ཟོམ_, _ipsu_, _hocm, 
   {{0x69280316,0xd2b8011a,0x60cc01ef,0x00000000}},	//   _přep, תלות_, _kocm, --, 
   {{0x26cc0421,0x3f980115,0x77680112,0xda640451}},	//   _aofo_, _kpsu_, tsex, _ڳائي, 
   {{0x8c980014,0xcc8807d6,0x98c401e0,0x60cc0200}},	//   _سپٕز_, _سنله_, _үсел, _mocm, 
   {{0xda6416cb,0x8f9c011a,0x00000000,0x00000000}},	//   _سائي, ליחי, --, --, 
   {{0x66d4145e,0x77680d19,0x26cc0099,0xb89400c6}},	//   _lâkw, ssex, _dofo_, _للاع, 
   {{0xe45c01e6,0x6e38f2bc,0x32180022,0x73c400ec}},	//   sjön_, _útbe, _rypy_, نيجم, 
   {{0xe72cf2bd,0x26ccf2be,0xd6100228,0x06b000bd}},	//   _ве_, _fofo_, _өздө, _চকরি, 
   {{0xf1a82c1f,0x70800201,0x26cc0618,0x00000000}},	//   وازه_, _ይችላሉ_, _gofo_, --, 
   {{0x3f9800cd,0xf50400a7,0xe71400ec,0x00000000}},	//   _apsu_, _изко, _جيوت_, --, 
   {{0x2ed8227c,0x00000000,0x00000000,0x00000000}},	//   णस्त, --, --, --, 
   {{0x60ccf2bf,0x7ae0f2c0,0x7fd428f6,0xa0a001d5}},	// [153c0] _docm, _ollt, ліфі, шатд, 
   {{0xed580323,0x3218b7f9,0xf1d00228,0xdfcc0597}},	//   дож_, _typy_, _көбө, غيل_, 
   {{0x5f740014,0xb208011c,0x00000000,0x00000000}},	//   _یمَس_, _ценз_, --, --, 
   {{0x7ae0ee18,0x60ccf2c1,0x00000000,0x00000000}},	//   _allt, _gocm, --, --, 
   {{0xab28004b,0x2054010f,0x00000000,0x00000000}},	//   وستل_, _ביכל_, --, --, 
   {{0x5b100006,0x00000000,0x00000000,0x00000000}},	//   аміт, --, --, --, 
   {{0x889401c6,0xc9b400db,0x00000000,0x00000000}},	//   гийх, امبة, --, --, 
   {{0x26ccf2c2,0x7ae0127b,0x682401a9,0xe8e80035}},	//   _sofo_, _ellt, lаdi, برتو_, 
   {{0x20c40254,0x26cc01e1,0x764c2c3c,0xea8801ec}},	//   _võix_, _pofo_, _şaya, _обал_, 
   {{0xdd8c01d9,0x9a5400c7,0x02d03105,0x6824022e}},	//   _دوہ_, _ахцә, _सकेन, nаdi, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x26cc0198,0x00000000,0x00000000,0x00000000}},	//   _wofo_, --, --, --, 
   {{0x26cc0607,0x853c0024,0x68e00ca8,0xd884004b}},	//   _tofo_, tvės, _ilod, _شپون_, 
   {{0x60ccf2c3,0x05b40c4f,0x00000000,0x00000000}},	//   _socm, _ممتح, --, --, 
   {{0x68e0f2c4,0xc6a404a9,0x60cc01a6,0x95c00592}},	//   _klod, _арқи, _pocm, _نيوه, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x50643edb,0x68e0f2c5,0x3f4c00d0,0x7eb801c4}},	// [153d0] ртса, _mlod, _sľub_, нгас_, 
   {{0x657801e7,0x00000000,0x00000000,0x00000000}},	//   orth, --, --, --, 
   {{0x60cc084c,0x29044db4,0x90e00248,0xd010004b}},	//   _tocm, _ojoa_, _kọ̀, ملې_, 
   {{0x65784695,0x90e001e1,0x00000000,0x00000000}},	//   irth, _jọ̀, --, --, 
   {{0xabb40588,0x90e00241,0x6578002f,0x00000000}},	//   лацә, _mọ̀, hrth, --, 
   {{0x68e00393,0x90e00241,0x2904b1be,0x00000000}},	//   _alod, _lọ̀, _ajoa_, --, 
   {{0x29040158,0xb6a40131,0x98ac0153,0x3ea001c7}},	//   _bjoa_, қинл, _ligą_, meht_, 
   {{0xe9440502,0x3ea0033d,0x68e0f2c6,0x7784f2c7}},	//   دروی, leht_, _clod, глиз, 
   {{0x68e0015d,0x6578002f,0x00000000,0x00000000}},	//   _dlod, erth, --, --, 
   {{0xeb0c1d8a,0x7ae003cd,0xa6e0010b,0xa5601456}},	//   ाकृत_, _ullt, йжыл, ڭگون, 
   {{0x90e00241,0xc984026a,0xb9540801,0xe45c0790}},	//   _bọ̀, _вучи, _свещ, lköy_, 
   {{0x68e0092e,0xc7240228,0x3ea00200,0x00000000}},	//   _glod, лдөй, heht_, --, 
   {{0x6578f2c8,0x90e00241,0x7bd8970f,0x394401f5}},	//   arth, _dọ̀, nywu, _huls_, 
   {{0x68e0f2c9,0x69dc0fac,0x00000000,0x00000000}},	//   _zlod, øpeg, --, --, 
   {{0x2008011f,0x90e00241,0x98ac0153,0x7bd80042}},	//   _axci_, _fọ̀, _eigą_, hywu, 
   {{0x3944014a,0x25d4008d,0x3d0c0034,0xe45cf2ca}},	//   _muls_, _תוקן_, िकों_, zköz_, 
   {{0x394401b8,0x212801ab,0xaf2002f5,0xc5b4004e}},	// [153e0] _luls_, _dhch_, _ভূষণ_, _брөө, 
   {{0x3ea003fa,0xa498067c,0x7fd402dd,0xca4c0150}},	//   geht_, nnòn, шісі, _ﺃﺨﺫ_, 
   {{0xed58ae27,0x3944f2cb,0xec78f2cc,0x682401a9}},	//   хое_, _nuls_, епе_, rаdi, 
   {{0xccb40022,0x00000000,0x00000000,0x00000000}},	//   шәгь, --, --, --, 
   {{0x4e1400af,0x16080037,0x764c013d,0x7c640116}},	//   _तुरई_, _सुघर_, _ğayn, شانل, 
   {{0x6d9800df,0x68e0f2cd,0x290403cd,0x65786ab0}},	//   _aĥaŝ, _slod, _sjoa_, yrth, 
   {{0x39441570,0xfd6401f2,0x7744001f,0x853c0153}},	//   _culs_, _mesị, _የሁለተ, kvėp, 
   {{0x02d0038e,0x00000000,0x00000000,0x00000000}},	//   _सक्न, --, --, --, 
   {{0xe664009b,0x657803cb,0x64ac01f9,0x00000000}},	//   лтно, wrth, _जोगळ, --, 
   {{0x394400e4,0x6b80f2ce,0x90e00248,0x85b800d8}},	//   _fuls_, muog, _sọ̀, влос_, 
   {{0x68e031c7,0x6b80f2cf,0xd5b44ea5,0x9e78008f}},	//   _tlod, luog, гся_, ענטפ, 
   {{0x65780597,0x68e0014b,0xe784470d,0x00000000}},	//   rrth, _ulod, _буко, --, 
   {{0x6b800024,0xd83401af,0x00000000,0x00000000}},	//   nuog, _йэш_, --, --, 
   {{0x25b40014,0xb9d80092,0x90e00248,0x00000000}},	//   _منتھ_, _ጠቅ_, _wọ̀, --, 
   {{0xe45c0790,0xe7e000c5,0x90e00241,0x00000000}},	//   zköy_, गनवा_, _tọ̀, --, 
   {{0x9400013f,0x6b8001f7,0x7d0800df,0xe4c800ec}},	//   _ebiɑ_, kuog, _ĉeso, _سببن_, 
   {{0x425402e1,0x81cc00bd,0x3ea02155,0x8fe40032}},	// [153f0] _پنجر, _শেখ_, teht_, бәрҙ, 
   {{0x4428f2d0,0x26dcf2d1,0x929407d5,0x0ee80408}},	//   _iza_, nkto_, _лаьц, льхи_, 
   {{0x644cf2d2,0x3ea00112,0x00940166,0x628401e3}},	//   occi, reht_, _кинэ, mgjo, 
   {{0x628401e6,0x644cf2d3,0xe45c0790,0x7bd8012d}},	//   lgjo, ncci, tköy_, tywu, 
   {{0x442802b9,0x3944180f,0x644c0ffb,0xfb340006}},	//   _jza_, _suls_, icci, андэ, 
   {{0x6284f2d4,0x38680427,0xe81c61f2,0xe45c05d1}},	//   ngjo, _žar_, _परजा_, rköy_, 
   {{0xbdd40212,0x44280171,0xe45c0205,0x00000000}},	//   _товщ, _lza_, sköy_, --, 
   {{0x4428f2d5,0x6e38f2d6,0x39446f7b,0x3b540801}},	//   _oza_, _útba, _vuls_, _вкар, 
   {{0x7d08f2d7,0x4428f2d8,0x082400ec,0xe8c4f2d9}},	//   _ijes, _nza_, ٽريٽ, ргыл_, 
   {{0x58006788,0x7c28f2da,0x59640c04,0xf548004d}},	//   _қолғ, _izer, _бъда, _nấc_, 
   {{0x4428f2db,0x2d9c0086,0xf62476cd,0xf504f2dc}},	//   _aza_, _âtet_, рдно, изоо, 
   {{0x38680f99,0x26dc0280,0x4428003e,0xc328025d}},	//   _þar_, akto_, _bza_, _חו_, 
   {{0x7d08f2dd,0x6284037e,0xf5480208,0x4374004e}},	//   _mjes, fgjo, _bấc_, йурт, 
   {{0x644cf2de,0x44280dc9,0x628411c0,0x7d08f2df}},	//   acci, _dza_, ggjo, _ljes, 
   {{0x4428f2e0,0x70f402bf,0x7d08035b,0x39b400ef}},	//   _eza_, ачає, _ojes, _jās_, 
   {{0x7d080023,0x682001f2,0x7c280166,0xaf040241}},	//   _njes, _ọdin, _ozer, _odùú, 
  
   {{0x7c28f2e1,0x7c2c0209,0x2518010f,0xef1806b4}},	// [15400] _nzer, ýarl, _בוקא, вма_, 
   {{0xa4f00489,0x7d08f2e2,0x6b800c86,0xf5480208}},	//   _བཏོག_, _ajes, vuog, _gấc_, 
   {{0x7c28f2e3,0xada4e4a2,0x7d08f2e4,0x4428f2e5}},	//   _azer, раел, _bjes, _zza_, 
   {{0x7e740115,0xd7b4002e,0x6b80009f,0x442800ee}},	//   _edzp, _l胃q_, tuog, _yza_, 
   {{0x7c28f2e6,0xfe70f2e7,0x7d0802d3,0xdcac1cbf}},	//   _czer, زدە_, _djes, بىن_, 
   {{0x7c28f2e8,0xaf3401b9,0x6b800198,0x7d08f2e9}},	//   _dzer, _خرجت, ruog, _ejes, 
   {{0x7c28a9df,0x7d08143a,0x7bcc00cc,0x00000000}},	//   _ezer, _fjes, øaur, --, 
   {{0x7d08f2ea,0xa4f0031c,0xa498004e,0x9cbc031c}},	//   _gjes, _བཏེག_, gnòl, _ཚོགས, 
   {{0xa01804cc,0x69dc0158,0x00000000,0x00000000}},	//   _sböz, øpeb, --, --, 
   {{0x4428106e,0x7d08e475,0xbc1801af,0x00000000}},	//   _rza_, _zjes, _сісі_, --, 
   {{0x6284a2ec,0x39b400b8,0x26dc394d,0x7d08036e}},	//   vgjo, _gās_, rkto_, _yjes, 
   {{0x644c026c,0xa498004e,0x7c280ea0,0x5880005b}},	//   ucci, cnòl, _yzer, _дыша, 
   {{0x644c0789,0x628438aa,0xf8ac3090,0x6928013a}},	//   rcci, tgjo, _سکي_, _ořez, 
   {{0x44280175,0x644c004e,0x39b400b8,0x00000000}},	//   _vza_, scci, _yās_, --, 
   {{0xc10400c6,0x914836b1,0x00000000,0x00000000}},	//   موسي, ичта_, --, --, 
   {{0x955036bd,0x4428f2eb,0x656c00d2,0x34440117}},	//   _بخوا, _tza_, ábhu, _гӯри_, 
   {{0x4428f2ec,0x7d08f2ed,0x69280316,0x43940261}},	// [15410] _uza_, _rjes, _břez, _уапс, 
   {{0xe2a82264,0x7d081e31,0xdb203361,0x4e78007b}},	//   _شاخن_, _sjes, ürüm, لحمد_, 
   {{0x7c2855b4,0x7d08f2ee,0x3d9400a8,0x69280118}},	//   _szer, _pjes, сиер, _dřez, 
   {{0x8d74f2ef,0x0c7802dd,0x00000000,0x00000000}},	//   زاما, асшы_, --, --, 
   {{0x7d08f2f0,0xbb440108,0xf8c40303,0x764c0139}},	//   _vjes, щелк, वासय, _şaym, 
   {{0xfaa40410,0x4fc40dd8,0x7f4c009a,0x2d8c004e}},	//   сако, _بەكە, mqaq, àfec_, 
   {{0x7d081711,0x3eb0009a,0x7f4c0784,0x00000000}},	//   _tjes, _iazt_, lqaq, --, 
   {{0x7d080aa5,0x7c28f2f1,0x39b40055,0x0d640395}},	//   _ujes, _tzer, _vās_, _фърм, 
   {{0x7c28f2f2,0x7f4c02d1,0xabb40022,0x7d180210}},	//   _uzer, nqaq, _латә, mows, 
   {{0x39b40029,0x7d18f2f3,0xddc400e2,0x46440092}},	//   _tās_, lows, _nejū, _ከአገራ, 
   {{0x98c401b9,0x00000000,0x00000000,0x00000000}},	//   _پغان, --, --, --, 
   {{0x7d18f2f4,0x422c0b82,0xadf800c5,0x33d400d4}},	//   nows, _ተስፋሚ, _एइसन_, бігт, 
   {{0x386c17c1,0xd8380064,0x00000000,0x00000000}},	//   maer_, _рэж_, --, --, 
   {{0x386c0dd4,0x7d18f2f5,0xd6d8f2f6,0x36680484}},	//   laer_, hows, _ште_, _сако_, 
   {{0x41b40c04,0x95c80364,0x7d180034,0xe3e420d3}},	//   остт, _шуда_, kows, لکین_, 
   {{0x386ca20f,0xb4640e46,0x7d18012d,0x31241171}},	//   naer_, _укил, jows, ёдаг, 
   {{0x7d1860e0,0x6928012c,0x7f4c0472,0xb9d8001f}},	// [15420] dows, _přez, gqaq, _ጠጅ_, 
   {{0x66240113,0xdd8c00f1,0x386c0142,0xf4840244}},	//   _ñukñ, ځول_, haer_, _ئاژی, 
   {{0x386c0156,0x7f4c0194,0xdd8c2073,0x00000000}},	//   kaer_, aqaq, فول_, --, 
   {{0x7d18f2f7,0x237c3831,0xada4013e,0xfb1801ed}},	//   gows, šuje_, _қабл, یروں_, 
   {{0xf1a800ec,0x692801ef,0x00000000,0x00000000}},	//   _شاھه_, _třez, --, --, 
   {{0x3eb0009d,0x6e38f2f8,0x00000000,0x00000000}},	//   _gazt_, _útbo, --, --, 
   {{0x7d184a1f,0x386c08cb,0xedd408f0,0x2bc40825}},	//   bows, faer_, _ايزد, लमहा, 
   {{0x7d18012d,0x9944007b,0x00000000,0x00000000}},	//   cows, حليل_, --, --, 
   {{0xd87000cf,0xac080120,0x2ca40254,0x00000000}},	//   سايب, _снаа_, meod_, --, 
   {{0xdc901540,0x2ca4f2f9,0x85741bbc,0x00000000}},	//   _መዝሙር_, leod_, олох, --, 
   {{0x386cf2fa,0x2a6c020b,0x2b900356,0xda6c210e}},	//   baer_, mafb_, lâc_, _سُن_, 
   {{0xe4e80128,0x386c04d4,0x499001ed,0x48c4008e}},	//   اعده_, caer_, _فیڈر, _фәка, 
   {{0x5eac00eb,0xd9180115,0x00000000,0x00000000}},	//   ঘাতে, _גואל, --, --, 
   {{0x7d18033f,0x7824007b,0x00000000,0x00000000}},	//   zows, _بعمل, --, --, 
   {{0x305401f2,0xf5480208,0x00000000,0x00000000}},	//   _ọlụ_, _hấn_, --, --, 
   {{0x7f4c0357,0x7d180009,0x41840150,0x00000000}},	//   tqaq, xows, йтұғ, --, 
   {{0xa498f2fb,0x7f4cf2fc,0x2ca400af,0x7d180076}},	// [15430] riòd, uqaq, deod_, vows, 
   {{0x7f4cf2fd,0x386c0165,0x20040356,0x7958013d}},	//   rqaq, zaer_, ăni_, läwş, 
   {{0x7c5804a9,0x7f4c1bb7,0x6e38a58d,0xf54801fb}},	//   للار_, sqaq, _útbl, _lấn_, 
   {{0x386c01bf,0x25ac01ef,0x00000000,0x00000000}},	//   xaer_, _msfl_, --, --, 
   {{0x25ac04cc,0xdfd800a7,0x7f4cf2fe,0x00000000}},	//   _lsfl_, _сън_, qqaq, --, 
   {{0xe0dc00a2,0x7d18012d,0x386c03cb,0xb4c416ae}},	//   _diòe_, sows, waer_, _उच्_, 
   {{0x386c0dd4,0x25ac0175,0xf8c417c6,0x7d180210}},	//   taer_, _nsfl_, वालय, pows, 
   {{0x4c9457a8,0xf5480208,0x6e28002f,0x00000000}},	//   _нисс, _bấn_, üfbe, --, 
   {{0xdb2004fb,0xf54801fb,0x3a7401d5,0x00000000}},	//   _فوری, _cấn_, _млар, --, 
   {{0xf548004d,0x0a68399f,0x386c05c7,0x00000000}},	//   _dấn_, _грци_, saer_, --, 
   {{0xca48f2ff,0x386c0165,0xf508014b,0x14c80214}},	//   _المه_, paer_, инол_, مهدی_, 
   {{0x7bdc06be,0x00000000,0x00000000,0x00000000}},	//   _üsus, --, --, --, 
   {{0x65b00022,0x741400e5,0x00000000,0x00000000}},	//   tÿhá, زوسا, --, --, 
   {{0xa4980086,0xe75426c6,0x27e00158,0x00000000}},	//   giòb, _بلوغ_, økne_, --, 
   {{0xd01c00eb,0x00000000,0x00000000,0x00000000}},	//   _দৃঢ়_, --, --, --, 
   {{0xdb180036,0xafe4f300,0xb3840108,0xa5a00118}},	//   _bruë, ообл, _длил, _छैटौ, 
   {{0x9f80001f,0xb4e412eb,0x2ca4000d,0x00000000}},	// [15440] _ይይዛሉ_, फसी_, veod_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6da4f301,0x2ca40037,0x6678010f,0x00000000}},	//   تمام, teod_, שטעק, --, 
   {{0x272003b2,0xfa5400d1,0x00000000,0x00000000}},	//   rðni_, ۋرىگ, --, --, 
   {{0x92cc04c5,0x00000000,0x00000000,0x00000000}},	//   লসী_, --, --, --, 
   {{0x5f24014b,0x00000000,0x00000000,0x00000000}},	//   _моям_, --, --, --, 
   {{0x0a6800d1,0xf5480051,0x2ca40037,0x00000000}},	//   арқи_, _sấn_, peod_, --, 
   {{0x6d5c48b7,0x3be81cd1,0xe45c007c,0x00000000}},	//   mppa, рләү_, njöt_, --, 
   {{0xd834152d,0x6d5cf302,0xc6f800d6,0x00000000}},	//   жээ_, lppa, йних_, --, 
   {{0xf54807ae,0x6b80a324,0xab281ee3,0x7d08008f}},	//   _vấn_, mrog, _тоза_, _ĉesi, 
   {{0x6b80004e,0xe45c01a8,0x47d44754,0x00000000}},	//   lrog, kjöt_, زيگر, --, 
   {{0xf5480016,0x6d5cdfe5,0x9c802b57,0xa4980ba1}},	//   _tấn_, ippa, _účtu, diòc, 
   {{0xdb18067c,0xd7f41f0f,0x6b8001e7,0x00000000}},	//   _bruè, _муш_, nrog, --, 
   {{0x6b800005,0x04fc0154,0x00000000,0x00000000}},	//   irog, ীতের_, --, --, 
   {{0x6b80062c,0x6d5c0327,0x00000000,0x00000000}},	//   hrog, jppa, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6e38022c,0xdb0800d4,0xd8d4008f,0x6b8001e4}},	// [15450] _útbj, lvgå, קומט_, jrog, 
   {{0x336000db,0x00000000,0x00000000,0x00000000}},	//   _سۇفف, --, --, --, 
   {{0x6b80f303,0x00000000,0x00000000,0x00000000}},	//   erog, --, --, --, 
   {{0x3cd47111,0x6d580327,0x00000000,0x00000000}},	//   яжес, _ħtat, --, --, 
   {{0x6b80f304,0x6d5cf305,0x69dc003b,0x61f80115}},	//   grog, appa, øpen, ŝuld, 
   {{0xba742dfc,0xe80c0b4c,0x00000000,0x00000000}},	//   ساتت, ापना_, --, --, 
   {{0x3f8804cc,0xaa4000fd,0xa49801ab,0x6f340354}},	//   luau_, нешл, anòi, _хӳтĕ, 
   {{0xf8c407f7,0x00000000,0x00000000,0x00000000}},	//   वाइय, --, --, --, 
   {{0x3f8807c5,0x97303bdb,0x0f000154,0x37d000cc}},	//   nuau_, وکتا, ্তরঃ_, _তেজৰ, 
   {{0x6e2003f9,0xbb4c0150,0x97400092,0x00000000}},	//   ƙobt, _ﺃﺘﻰ_, _የዲያስ, --, 
   {{0x7bd801f2,0x00000000,0x00000000,0x00000000}},	//   ̣bụ, --, --, --, 
   {{0xdb0803b2,0x00000000,0x00000000,0x00000000}},	//   ðiæv, --, --, --, 
   {{0x59b0033f,0xd34807d6,0x00000000,0x00000000}},	//   ंटकर, غیده_, --, --, 
   {{0x78a8f306,0xa49802e2,0xbba002dd,0x7c780023}},	//   leev, tiòc, _ﺍﺴﻤﻪ_, _ኣኽሊል_, 
   {{0x2164f307,0xdb1800d8,0x2508072d,0x00000000}},	//   зиси_, _crué, _گروی_, --, 
   {{0x6b800072,0x78a8f308,0xb4641a71,0x00000000}},	//   yrog, neev, _экил, --, 
   {{0x6f000248,0xb6240150,0x00000000,0x00000000}},	// [15460] _níbè, _ﺭﻓ_, --, --, 
   {{0x78a80218,0x6b80f309,0xf5480208,0xd1d00023}},	//   heev, vrog, _lấm_, _ብደቂ_, 
   {{0x6d5cf30a,0x3f8804c9,0x6b800368,0x72040244}},	//   uppa, auau_, wrog, _روحم, 
   {{0xf548001e,0x6d5cf30b,0x78a80427,0x2bc810de}},	//   _nấm_, rppa, jeev, йлеп_, 
   {{0x6d5cf30c,0x78a8f30d,0x61f801e4,0xbbe8007b}},	//   sppa, deev, ĝule, يرهم_, 
   {{0xe45c01e6,0x69dc0fac,0x00000000,0x00000000}},	//   njör_, øpeo, --, --, 
   {{0xf5480016,0x6b80003e,0x78a80166,0x00000000}},	//   _bấm_, srog, feev, --, 
   {{0x6f1cf30e,0xf548001e,0xace800c6,0xfbcc05d9}},	//   lopc, _cấm_, _ارسل_, _چڪو_, 
   {{0x6d4cf30f,0x7b440075,0xe45c01a8,0xf548004d}},	//   _huba, سئۇل, kjör_, _dấm_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d4cf310,0x78a8f311,0xe45c01e3,0xd6d4003b}},	//   _juba, beev, xjös_, їть_, 
   {{0x6aa8f312,0x6d4cf313,0x78a80204,0x249c00ee}},	//   leff, _muba, ceev, ýum_, 
   {{0x6d4cf314,0x613003ee,0x3f880ba1,0xe45c02d2}},	//   _luba, nçle, xuau_, fjör_, 
   {{0x56906fbd,0x6aa8f315,0xdb1800eb,0x6d4cf316}},	//   _зашт, neff, _prué, _ouba, 
   {{0x6d4c7442,0x56980375,0x00000000,0x00000000}},	//   _nuba, _היוצ, --, --, 
   {{0x6aa8f317,0xdb0429ef,0x3f88180f,0xd0d402e8}},	//   heff, _älöd, tuau_, носъ, 
   {{0x6d4cf318,0x443c0086,0x00000000,0x00000000}},	// [15470] _auba, _àw_, --, --, 
   {{0x6d4ccd3a,0x6aa8a88d,0x3f8805d5,0x05b00e49}},	//   _buba, jeff, ruau_, _जनाब, 
   {{0x6d4cf319,0x6aa8324c,0x3f881f40,0xe18c0023}},	//   _cuba, deff, suau_, _ዝፍጽሞ_, 
   {{0x6d4cf31a,0xa018025a,0x78a8f31b,0x6f000109}},	//   _duba, _ndög, xeev, éocr, 
   {{0x6d4c8191,0x3f8804cc,0x78a80254,0x00000000}},	//   _euba, quau_, veev, --, 
   {{0x7b3801f2,0x6aa8f31c,0x7d080115,0xf548004d}},	//   _aňur, geff, _ĉesu, _sấm_, 
   {{0x6d4cf31d,0xbe640023,0xf5480051,0x00000000}},	//   _guba, _ጎስጓሳ, _pấm_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d4cf31e,0x78a8f31f,0x3a24002d,0x9a440214}},	//   _zuba, reev, _wylp_, _فضاه, 
   {{0x6d4cf320,0x3cecf321,0x6aa87691,0x78a8cc2f}},	//   _yuba, _hlev_, ceff, seev, 
   {{0x34a84705,0xf5480016,0x3cecf322,0x6d4cf323}},	//   овно_, _tấm_, _klev_, _xuba, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x99800023,0xa854123b,0x00000000,0x00000000}},	//   _ነይሩኒ_, _חינה_, --, --, 
   {{0x6d5820ef,0x00000000,0x00000000,0x00000000}},	//   _étag, --, --, --, 
   {{0x3cec00af,0x2324034f,0xdeb80b82,0xf1dc0073}},	//   _olev_, фори_, ተንን_, _नॅशन, 
   {{0x6d4cf324,0x6aa819f5,0xa01801e3,0x00000000}},	//   _ruba, zeff, _odöd, --, 
   {{0x6aa8f325,0x776c06be,0x00000000,0x00000000}},	// [15480] yeff, _çaxd, --, --, 
   {{0x6d4cf326,0x1ae02baf,0x3cecf327,0xca4c01ec}},	//   _puba, কোতে_, _alev_, _ﺃﻨﺎ_, 
   {{0x3cecdd30,0x6f1c014f,0x6d4cf328,0x6aa8f329}},	//   _blev_, ropc, _quba, veff, 
   {{0x25d41a4c,0x3cec04cc,0x6d4c0223,0x9cc43546}},	//   ווען_, _clev_, _vuba, дыша_, 
   {{0x6d4cf32a,0x6aa835de,0xdb180137,0x6f1c0072}},	//   _wuba, teff, _cruï, popc, 
   {{0x3cecf32b,0x8884004b,0x6aa801f5,0x6f1c014f}},	//   _elev_, ځیان, ueff, qopc, 
   {{0x6aa87585,0x6d4cf32c,0x77600092,0xb0600254}},	//   reff, _uuba, _ለሁለተ, _ääsm, 
   {{0xdd8cf32d,0xdb18004e,0x3cec05c7,0xe0dc01ab}},	//   _خوف_, _fruï, _glev_, _liòn_, 
   {{0x387c015d,0xeb9803cf,0x00000000,0x00000000}},	//   _ddwr_, _физ_, --, --, 
   {{0x98a000da,0x6aa80a55,0x00000000,0x00000000}},	//   ējā_, qeff, --, --, 
   {{0x776c0327,0x00000000,0x00000000,0x00000000}},	//   _ħaxe, --, --, --, 
   {{0xbbe82832,0xe784f32e,0x7534f32f,0x764c013d}},	//   _برہم_, _жуко, _chyz, _şayt, 
   {{0xd940f330,0xca4c01ec,0x18a00798,0x00000000}},	//   _реци, _ﺃﻨﺕ_, _јачм, --, 
   {{0xe1f0072d,0x00000000,0x00000000,0x00000000}},	//   نسز_, --, --, --, 
   {{0xc0c401ec,0x8c480139,0x00000000,0x00000000}},	//   ншақ, loğı, --, --, 
   {{0x43945663,0xe4a406ed,0x00000000,0x00000000}},	//   _заис, _црко, --, --, 
   {{0x1ee404d3,0x69dc003b,0x764c01e1,0x73c001ee}},	// [15490] ووری_, øpej, _ányá, _йәре, 
   {{0x3cecf331,0x4428f332,0xe0dc01fb,0x55f000a2}},	//   _slev_, _iya_, _giòn_, _öñüñ, 
   {{0x3cecf333,0xebc000d1,0xfaa400c7,0x00000000}},	//   _plev_, қәтн, ҵало, --, 
   {{0x44280c8a,0xdb18004e,0x3154010f,0x00000000}},	//   _kya_, _pruï, _רירן_, --, 
   {{0x44280796,0x3cec05c7,0xaa4001a9,0xd150022e}},	//   _jya_, _vlev_, қеъл, _дeҳқ, 
   {{0x44280296,0x2a7c070d,0xb06000af,0xeb94013e}},	//   _mya_, _cdtb_, _äärm, хиш_, 
   {{0x4428f334,0xce94023b,0x6da000cf,0x00000000}},	//   _lya_, _шаръ, _مۅلم, --, 
   {{0x4428f335,0x00000000,0x00000000,0x00000000}},	//   _oya_, --, --, --, 
   {{0xad4400db,0x00000000,0x00000000,0x00000000}},	//   _سىكۉ, --, --, --, 
   {{0x7c28f336,0x8ac40046,0xf7707771,0x468002dd}},	//   _iyer, _ақша_, پاک_, ақша, 
   {{0x4428f337,0x7c28f338,0xe0dc0295,0xb8f4015b}},	//   _aya_, _hyer, _riòn_, _হত_, 
   {{0x4428f339,0x7c281958,0xc764198a,0x23c804fa}},	//   _bya_, _kyer, راۋى, ामंद, 
   {{0x4428685c,0x77780175,0xded40023,0xb83c0092}},	//   _cya_, _uvwx, _ኮምኡ_, _የኢፌዴ, 
   {{0x7c28f33a,0x4428f33b,0x6ef000b5,0x00000000}},	//   _myer, _dya_, _kæbe, --, 
   {{0x4428f33c,0x7c28f33d,0x3f980784,0xa4980137}},	//   _eya_, _lyer, _aqsu_, gnòs, 
   {{0x7c2802ce,0x78b8047e,0x739800f3,0x00000000}},	//   _oyer, _jawv, _етос_, --, 
   {{0x7c28f33e,0x4428f33f,0xaec4da96,0x6ef0037e}},	// [154a0] _nyer, _gya_, нбал, _læbe, 
   {{0x78b80218,0xa56001d5,0xdb1801e7,0x69dc143a}},	//   _lawv, _جگین, _bruí, øpek, 
   {{0x7c28f340,0xac84f341,0xa498004e,0x00000000}},	//   _ayer, егел, pnòt, --, 
   {{0x7c28f342,0xdb180077,0xeb981069,0x442801f4}},	//   _byer, _druí, зид_, _yya_, 
   {{0x7c280796,0x0a941fe2,0x44280211,0xab283f07}},	//   _cyer, валю, _xya_, пода_, 
   {{0x940400ac,0x7c28f343,0x00000000,0x00000000}},	//   ümə_, _dyer, --, --, 
   {{0x7c28f344,0x19a40166,0x5f0001d5,0xee2800ae}},	//   _eyer, етып_, _ёзса, _رأسه_, 
   {{0x7c28f345,0xad68013e,0x7cf800e4,0xeb9801a9}},	//   _fyer, _маҳз_, rúrõ, _ниб_, 
   {{0x7c28066d,0x6d58e365,0x6130509e,0x2a7c010e}},	//   _gyer, _étab, nçla, _tdtb_, 
   {{0x44280537,0xd6d400d4,0x00000000,0x00000000}},	//   _rya_, етю_, --, --, 
   {{0x4428f346,0x78b80204,0xa81800f1,0x7ae4002f}},	//   _sya_, _fawv, _کتار_, öhte, 
   {{0xa49800db,0x44280588,0xab7c0023,0xdb1c01e1}},	//   ciòl, _pya_, _ከልዕል_, _ìwòn, 
   {{0x66e4f347,0x4428020c,0x05a40133,0xa3c80037}},	//   _пода, _qya_, رشگێ, _रऊओ_, 
   {{0x4428f348,0x1adc0183,0xd6cc01d5,0x00000000}},	//   _vya_, _ভগৱা, _ёт_, --, 
   {{0x4fc40efb,0x51845660,0x20c41f10,0xc1040472}},	//   қста, лута, нсаг, نوسي, 
   {{0x28a406ab,0x6ab8f349,0x657800dc,0xddc40118}},	//   _कॉमि, _latf, msth, _nejš, 
   {{0x4428f34a,0xdb044252,0x6ab803ac,0x00000000}},	// [154b0] _uya_, _ölçe, _oatf, --, 
   {{0x7c288aa7,0x4154119e,0x00000000,0x00000000}},	//   _ryer, _ивос, --, --, 
   {{0x3d94f34b,0x4ea4ae78,0x00000000,0x00000000}},	//   тиер, ырта, --, --, 
   {{0x7c28007f,0x6578030a,0x3178010f,0x00000000}},	//   _pyer, isth, _קארד, --, 
   {{0x6ab8003c,0x6ef01b25,0x78b80175,0xca4c0150}},	//   _batf, _sæbe, _rawv, _ﺃﺨﺒ_, 
   {{0x6ab8b0e7,0x7c285975,0xfaa4f34c,0x6578465f}},	//   _catf, _vyer, тако, ksth, 
   {{0xd2b800d9,0x00000000,0x00000000,0x00000000}},	//   גלות_, --, --, --, 
   {{0x6578f34d,0x7c28f34e,0x6ab802d0,0xddc40010}},	//   dsth, _tyer, _eatf, _gejš, 
   {{0x6578f34f,0x7c28f350,0x764c0166,0xdef00240}},	//   esth, _uyer, _şayq, _ሎምን_, 
   {{0x0ab4121b,0xcf940677,0xf5e8009d,0x00000000}},	//   _محمد, אטץ_, дмол_, --, 
   {{0x940c0cc1,0x6578127b,0x87c00022,0xe0dc01e1}},	//   ədə_, gsth, _ҳҩыз, _ooò_, 
   {{0x55c00184,0x3f88f351,0xa9540115,0x00000000}},	//   _ҡалғ, krau_, _סינק_, --, 
   {{0x3f880218,0x6c78008f,0x2ca0010b,0x2a780241}},	//   jrau_, וארפ, _ökde_, _ìgbó_, 
   {{0x3f8803b4,0xa6c4010b,0x6578f352,0x00000000}},	//   drau_, _алша_, bsth, --, 
   {{0xa8202c26,0x3f880142,0x65789108,0x00000000}},	//   _مکین, erau_, csth, --, 
   {{0x3f88f353,0x00000000,0x00000000,0x00000000}},	//   frau_, --, --, --, 
   {{0x6140e21a,0x3f88f354,0xe3b4f355,0xdfcc3997}},	// [154c0] рета, grau_, _абы_, ييف_, 
   {{0x613054ee,0x9e60f356,0xddc40e04,0x00000000}},	//   rçla, ивуд, _sejš, --, 
   {{0xdd8c08de,0x3f8802b5,0x00000000,0x00000000}},	//   قول_, arau_, --, --, 
   {{0x7afc0953,0x6ab82959,0x3f88f357,0x00000000}},	//   _įsta, _satf, brau_, --, 
   {{0x6ab80204,0x3f880c1f,0xe454008f,0x7c2c033f}},	//   _patf, crau_, דינט_, żarn, 
   {{0x6e940f84,0xfbe02b1b,0xa498004e,0x92e40183}},	//   _جلسا, _মেহত, viòm, পোৰ_, 
   {{0x5ef40a28,0xf548004d,0x7bc400b0,0x49a40961}},	//   _एतत्_, _hấu_, āhua, уылғ, 
   {{0x6ab8f358,0xef200210,0x00000000,0x00000000}},	//   _watf, _ważą_, --, --, 
   {{0x6ab8f359,0xe6c40597,0x65780054,0xe6643dab}},	//   _tatf, نتدي, wsth, ктно, 
   {{0x6578f35a,0x7984073c,0x310030a4,0xf548004d}},	//   tsth, šhwa, रोतः_, _mấu_, 
   {{0x65780363,0xf5480051,0x00000000,0x00000000}},	//   usth, _lấu_, --, --, 
   {{0x65787421,0xd73019bb,0xe824023b,0xa80439c6}},	//   rsth, лдөө, _ифло, _изел, 
   {{0x6578f35b,0xf5480016,0xd7ec007b,0x96b400f2}},	//   ssth, _nấu_, _وكم_, رایز_, 
   {{0xc2c4038b,0x3f880c86,0x776c03e3,0x00000000}},	//   ديسي, vrau_, _çaxa, --, 
   {{0x61f8010f,0xd5b43452,0xdc1c00c5,0x92580117}},	//   ĝulo, _асы_, _बड्ड_, таст_, 
   {{0x5064f35c,0x3f88f35d,0x99b80302,0xf5480208}},	//   итуа, trau_, וזלט, _bấu_, 
   {{0xf5480016,0x3f8807c5,0x5ef400dc,0x310000cd}},	// [154d0] _cấu_, urau_, _एतद्_, रोधः_, 
   {{0xf54807ae,0x3f88f35e,0x918400d1,0x00a00133}},	//   _dấu_, rrau_, _ھۇقۇ, _گیرێ, 
   {{0xdd980212,0x00000000,0x00000000,0x00000000}},	//   ьша_, --, --, --, 
   {{0x506400d6,0x3f8804cc,0x425401b9,0x00000000}},	//   _втра, prau_, _جنگر, --, 
   {{0x4c843334,0xf548001e,0xb9280ca8,0x00000000}},	//   рлів, _gấu_, _titẹ_, --, 
   {{0xd9d4015b,0xf548004d,0x7c2c012d,0x853c0064}},	//   তনসম, _hất_, żaro, ltėd, 
   {{0xdb1801e7,0xb9c4007b,0xd33808c3,0x00000000}},	//   _cruá, اقبي, דרגה_, --, 
   {{0x6d58003e,0xfd8801d5,0x00000000,0x00000000}},	//   _étaa, _оёғи_, --, --, 
   {{0xf5480016,0xf77025ef,0x6e38f35f,0x3b88013d}},	//   _mất_, حاب_, _útbr, _чөеп_, 
   {{0xf5480051,0x00000000,0x00000000,0x00000000}},	//   _lất_, --, --, --, 
   {{0x7e74f360,0x7544f361,0xb8940f2b,0x14c801d5}},	//   _mezp, лноз, _ملاع, نهدی_, 
   {{0x7ae0f362,0x26cc0699,0x30bc00cc,0x3868010b}},	//   _holt, _enfo_, _ইক্স, _ýar_, 
   {{0x7ae0f363,0xe72c4c6a,0xb6a4f364,0x69cc0129}},	//   _kolt, _ге_, _билл, _àber, 
   {{0x7ae01978,0x437402bf,0x7e740118,0x02c40124}},	//   _jolt, шуют, _nezp, ақьи_, 
   {{0x7ae0f365,0xf548001e,0x26c0013f,0x35a4f366}},	//   _molt, _bất_, ɛko_, _сайг, 
   {{0x7ae0f367,0xf548001e,0x33d400d4,0xda18000d}},	//   _lolt, _cất_, _біот, _पुछत_, 
   {{0x7e74489c,0x26cc0225,0x25180375,0x7ae0f368}},	// [154e0] _bezp, _ynfo_, _רופא, _oolt, 
   {{0x7ae0f369,0xf36400fd,0x7e7400d7,0xf5480051}},	//   _nolt, _итүн, _cezp, _vấu_, 
   {{0xc0f80240,0x00000000,0x00000000,0x00000000}},	//   ፊሎም_, --, --, --, 
   {{0xf54801fb,0x26c000b0,0x00000000,0x00000000}},	//   _tấu_, ēkoi_, --, --, 
   {{0x7ae0f36a,0x7fd40046,0xeb040b7e,0x5c701cb8}},	//   _bolt, _кірі, лчко, сліт, 
   {{0x7ae023bd,0x28a40141,0x00000000,0x00000000}},	//   _colt, क्नि, --, --, 
   {{0x7ae00363,0x00000000,0x00000000,0x00000000}},	//   _dolt, --, --, --, 
   {{0x7ae000c0,0x999402e8,0x00000000,0x00000000}},	//   _eolt, укът_, --, --, 
   {{0x6e2c007c,0x2bc8104e,0x98d40228,0x6d40f36b}},	//   _hybb, _ялап_, ابىز_, mmoa, 
   {{0x7ae0f36c,0x6d40005a,0x00000000,0x00000000}},	//   _golt, lmoa, --, --, 
   {{0xa018145e,0x97d4f36d,0x95c401c0,0x1d04084c}},	//   _ndön, نظیر_, гуяа_, _реӂи_, 
   {{0x06c8152d,0x7ae0f36e,0x6d40002d,0x26c00210}},	//   хгүй_, _zolt, nmoa, śko_, 
   {{0xf54801dc,0x2904f36f,0x6d40f370,0x7ae003e0}},	//   _rất_, _imoa_, imoa, _yolt, 
   {{0x68e0f371,0x6d400036,0x7ae00327,0xf5480051}},	//   _hood, hmoa, _xolt, _sất_, 
   {{0x7e74020b,0x00000000,0x00000000,0x00000000}},	//   _rezp, --, --, --, 
   {{0x68e0f372,0x6d40002d,0xa2801079,0xcfa400d1}},	//   _jood, jmoa, _گیسو, әшти, 
   {{0x68e0f373,0x29040605,0xf54801fb,0x7f94bf29}},	// [154f0] _mood, _mmoa_, _vất_, разх, 
   {{0x68e0f374,0x7afc0006,0x629808a4,0x09b4000d}},	//   _lood, _įsto, đuos, _अईंठ, 
   {{0xf54807ae,0xb2740184,0x7ae0f375,0x290400e4}},	//   _tất_, _өлөш, _rolt, _omoa_, 
   {{0x68e0f376,0xf548004d,0x60cc0175,0x6e2c005c}},	//   _nood, _uất_, _uncm, _dybb, 
   {{0x6d58f377,0x7e74022e,0x92b803d4,0x3f7800df}},	//   _étan, _tezp, ছাৰ_, _באָס, 
   {{0x2904f378,0x6d4000b0,0xdef802d5,0x7ae003e3}},	//   _amoa_, amoa, _чым_, _qolt, 
   {{0x68e0f379,0x2c5c01f2,0x3c580276,0x68381954}},	//   _bood, _ịde_, _аибэ_, _ብስለት, 
   {{0x7ae0f37a,0x68e01368,0xe8500131,0xdb180790}},	//   _wolt, _cood, ينىد, _oruç, 
   {{0x68e0f37b,0x7ae0f37c,0x8b8805a9,0x21280419}},	//   _dood, _tolt, _مەنە_, _mkch_, 
   {{0x29040270,0x7bc801ab,0x7ae0e913,0x00000000}},	//   _emoa_, _ireu, _uolt, --, 
   {{0x68e0f37d,0x7bc805c7,0x69dc003b,0x6b84007c}},	//   _food, _hreu, øpet, _åkgr, 
   {{0x68e0f37e,0xdb18f37f,0x38c82099,0xd9180092}},	//   _good, _bruç, _جائی_, ቶቻችን, 
   {{0xd760f380,0xe0dc0051,0x00000000,0x00000000}},	//   _انتی, _giòi_, --, --, 
   {{0x386cf381,0xdb180139,0x68e000e2,0x81f40327}},	//   lber_, _druç, _zood, _པཎྡི_, 
   {{0xc4e40649,0x68e0f382,0x65900114,0x00000000}},	//   ãƒâ_, _yood, _дају, --, 
   {{0x20845026,0x386cf383,0x6e2c0076,0x68e0058a}},	//   ийси_, nber_, _rybb, _xood, 
   {{0x386cf384,0xaf04f385,0x79807823,0x7c2c0003}},	// [15500] iber_, апал, _lvlw, żarj, 
   {{0x386c05d1,0xe378011a,0x27e00174,0x00000000}},	//   hber_, _שריר, økni_, --, 
   {{0x386c0385,0x7bc8f386,0xdcfc012c,0x6d40f387}},	//   kber_, _areu, _úvěr, tmoa, 
   {{0x23742263,0x386cf388,0xa9e001e1,0x00000000}},	//   _حمید_, jber_, _àjẹ́_, --, 
   {{0x7bc8f389,0x6d40f38a,0x68e08feb,0x386cf38b}},	//   _creu, rmoa, _rood, dber_, 
   {{0x7bc8f38c,0x68e0f38d,0x386c0732,0x6d4005f5}},	//   _dreu, _sood, eber_, smoa, 
   {{0x68e0f38e,0x386c6081,0x7bc8f38f,0x00000000}},	//   _pood, fber_, _ereu, --, 
   {{0x7bc8f390,0x68e00752,0x00000000,0x00000000}},	//   _freu, _qood, --, --, 
   {{0x7bc8f391,0x68e0f392,0xee800952,0xeb9812d7}},	//   _greu, _vood, ﻧﮕﻪﻥ_, _шиа_, 
   {{0x69dc168c,0x68e0f393,0x28a402ab,0x5ac4f394}},	//   øpes, _wood, _कॉरि, _клум_, 
   {{0xd5b4f395,0x386cf396,0x68e0007d,0x7bc805c7}},	//   ася_, bber_, _tood, _zreu, 
   {{0x2ca400a9,0x6fd42356,0x00000000,0x00000000}},	//   nfod_, ठमां, --, --, 
   {{0x25a80451,0xdb18007c,0x98a0011c,0x00000000}},	//   ردگي_, _fruä, _фиче, --, 
   {{0x569044fb,0xdb180139,0x00000000,0x00000000}},	//   _дашт, _vruç, --, --, 
   {{0xe0d00ada,0x00000000,0x00000000,0x00000000}},	//   يزر_, --, --, --, 
   {{0x26dc01fa,0x00000000,0x00000000,0x00000000}},	//   ljto_, --, --, --, 
   {{0x9e6400db,0x6ef000b5,0xdb18f37f,0x63b80790}},	// [15510] لاان, _væbn, _uruç, çund, 
   {{0x28a4f397,0xf5480016,0x7c2c033f,0x3ef80276}},	//   क्ति, _hấp_, żark, ынзэ_, 
   {{0x386cf398,0x8d740eff,0x6d5807ea,0x7bc800a3}},	//   yber_, قانا, _étal, _sreu, 
   {{0x237c07f5,0x28a402a0,0x0ca82077,0x7bf80798}},	//   šuju_, _कॉलि, итчи_, лнер_, 
   {{0x2a6c0175,0x3ff8010f,0xf5480208,0x00000000}},	//   fbfb_, _עפֿע, _mấp_, --, 
   {{0x7bc8f399,0xf54801fb,0xdd9002dd,0x386c0100}},	//   _vreu, _lấp_, _қағы, wber_, 
   {{0x386c0a85,0x25ac00b0,0x00000000,0x00000000}},	//   tber_, _npfl_, --, --, 
   {{0x4c94f39a,0x7bc8f39b,0x386cf39c,0xa4980ba1}},	//   _мисс, _treu, uber_, lhòf, 
   {{0x7d08f39d,0xbb540014,0x69dc2c95,0x7bc80af9}},	//   _imes, _طناب, øper, _ureu, 
   {{0xdb180158,0x386cf39e,0x776c03b9,0x9b400244}},	//   _bruå, sber_, _çaxm, _بۆتو, 
   {{0x7768f39f,0x25ac00d8,0xf5480208,0x00000000}},	//   spex, _cpfl_, _bấp_, --, 
   {{0xf54801dc,0x23c002ab,0xf7940166,0x776800e4}},	//   _cấp_, शिंद, _гадэ, ppex, 
   {{0x7d08f3a0,0xa8540302,0x383401c0,0xf5480208}},	//   _mmes, _הינה_, _ундр, _dấp_, 
   {{0x6260b7ef,0x66100118,0x00000000,0x00000000}},	//   звра, ádká, --, --, 
   {{0x7d0814dc,0xf59400c6,0x629800f3,0xe69400cf}},	//   _omes, _العج, đuop, _اپىش_, 
   {{0xf5480016,0xd1743e64,0x16b4791c,0x00000000}},	//   _gấp_, йығы, _असुब, --, 
   {{0x683802d3,0x66ec256a,0xa758008f,0x09e00154}},	// [15520] _ብትሕት, _चकमक_, ָדער, বনযা, 
   {{0x7d08f3a1,0xdfcc0f13,0x44247ae6,0xddc8f3a2}},	//   _ames, عيل_, _ظريف, _šišl, 
   {{0xee380063,0x02d41bd6,0x955c0240,0x00000000}},	//   ћне_, दारभ, _ደቡብን_, --, 
   {{0x6d5800d8,0xf548004d,0x8d28008e,0x00000000}},	//   _étam, _xấp_, шнең_, --, 
   {{0x2ca40cfd,0x00000000,0x00000000,0x00000000}},	//   rfod_, --, --, --, 
   {{0x7d08f3a3,0xe760f3a4,0x39580306,0x00000000}},	//   _emes, _nọọs, _čssr_, --, 
   {{0xde000276,0x7d080175,0x99604c17,0x8884f3a5}},	//   _епри, _fmes, птыл, قیان, 
   {{0x5ca02dc4,0xa49826b7,0x00000000,0x00000000}},	//   _нисб, niòt, --, --, 
   {{0xe760063f,0xe9d80220,0xc6f8f3a6,0x9d4000ee}},	//   _bọọs, _әке_, иних_, _хетд, 
   {{0xf424003d,0x7d080030,0x6b8001f7,0x09e0009e}},	//   _རྙེད_, _zmes, msog, বনবা, 
   {{0x6b800c86,0x67fc0241,0x69f005f5,0x7d080368}},	//   lsog, _bàjé, _хүйт, _ymes, 
   {{0xdb18180f,0x6b80f3a7,0x00000000,0x00000000}},	//   _asuè, osog, --, --, 
   {{0x6b80f3a8,0xf54801fb,0xa834f3a9,0x66c801c6}},	//   nsog, _vấp_, _اعاش, _буйг_, 
   {{0x27e003b2,0x00000000,0x00000000,0x00000000}},	//   øknu_, --, --, --, 
   {{0x79547483,0xf548004d,0x61304498,0x00000000}},	//   _tšwe, _tấp_, lçli, --, 
   {{0x8cdc033f,0x6b800254,0x00000000,0x00000000}},	//   फाफो, ksog, --, --, 
   {{0x6130f3aa,0x2d5c06af,0xe50400f1,0x6d5c0327}},	// [15530] nçli, _aïe_, _پيښو_, eqpa, 
   {{0x4e78f3ab,0x7d08f3ac,0x6b8005ac,0xd0180107}},	//   محمد_, _smes, dsog, ёфт_, 
   {{0xe0dc0ba1,0x2c5c02e3,0xa49800cf,0xd654011a}},	//   _biòt_, _ịda_, biòt, ציאת_, 
   {{0x8d74f3ad,0x00000000,0x00000000,0x00000000}},	//   ساما, --, --, --, 
   {{0x6d5c0cfe,0x7d08151c,0x0c700092,0x00000000}},	//   aqpa, _vmes, ስትሮች_, --, 
   {{0x28a458c1,0xce5801c0,0x00000000,0x00000000}},	//   क्सि, _гарц_, --, --, 
   {{0x6b8004ba,0x69dc03cd,0x0dc80120,0x5ca000db}},	//   asog, øpep, _лути_, _ىلسە, 
   {{0x7d08f3ae,0xe76001f2,0x5ce400db,0x00000000}},	//   _umes, _sọọs, _уюга, --, 
   {{0xe8f404db,0x69cc09f3,0x7d180066,0x17dc0154}},	//   іль_, _áben, mnws, _বেড়ি, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x152801b9,0x79586c15,0x00000000,0x00000000}},	//   йноқ_, _тиер_, --, --, 
   {{0xf7700228,0x00000000,0x00000000,0x00000000}},	//   _قات_, --, --, --, 
   {{0xe0dc08c2,0x2b5005d1,0x78a800b5,0x7ccc00e2}},	//   _mhòd_, _üncü_, mfev, mērķ, 
   {{0x366815ed,0x7c2c0209,0x7bc400b0,0x78a8002f}},	//   _тако_, ýary, āhuh, lfev, 
   {{0x28a409b2,0x00000000,0x00000000,0x00000000}},	//   क्वि, --, --, --, 
   {{0x6b800142,0x69dc01f4,0x00000000,0x00000000}},	//   ysog, äpei, --, --, 
   {{0xa498068c,0x9fc42de5,0x00000000,0x00000000}},	// [15540] riòt, огта_, --, --, 
   {{0x23b011ec,0xa3e42aa1,0x63a801e6,0x6b800174}},	//   _کمیس, पहर_, _ägna, vsog, 
   {{0x6d5c0d04,0x906400db,0x00000000,0x00000000}},	//   uqpa, _ىندۇ, --, --, 
   {{0xe0dc08c2,0x6b80f3af,0x2bc8f3b0,0x8d74f3b1}},	//   _chòd_, tsog, илеп_, قاچا, 
   {{0xeab801c0,0xa04401ec,0x7e680139,0x00000000}},	//   ийд_, _وكپە_, _şepe, --, 
   {{0x6b80f3b2,0xe0dc01c3,0x29880063,0x00000000}},	//   rsog, _phòg_, асио_, --, 
   {{0x6b80f3b3,0xe0dc00a3,0x78a801bf,0xed58010a}},	//   ssog, _fhòd_, ffev, _ъов_, 
   {{0x272800bc,0xa8500209,0x00000000,0x00000000}},	//   zóně_, мейә, --, --, 
   {{0x28a408d1,0x00000000,0x00000000,0x00000000}},	//   क्षि, --, --, --, 
   {{0x6ef04a21,0x00000000,0x00000000,0x00000000}},	//   _sæbj, --, --, --, 
   {{0xa01803fa,0xf81401d5,0x00000000,0x00000000}},	//   _geöf, قسیگ, --, --, 
   {{0x7afc00c0,0xb3e400eb,0x00000000,0x00000000}},	//   _įsti, _পেইজ, --, --, 
   {{0x69c89f1c,0xb8644dec,0x00000000,0x00000000}},	//   lvfe, _رانو, --, --, 
   {{0x28a44433,0x86540408,0x00000000,0x00000000}},	//   क्रि, _эккх, --, --, 
   {{0xc0d001e1,0xa8ec0316,0x86f80014,0x776c0135}},	//   _akíọ, _जवाफ_, _نکھس_, _ħaxi, 
   {{0x157401d9,0xc5f800e2,0xd0d40395,0x00000000}},	//   _بٔٹھ_, ncēm_, мосъ, --, 
   {{0xe0dc004d,0xd9b407f7,0x00000000,0x00000000}},	// [15550] _nhòe_, _आन्ट, --, --, 
   {{0xf424031c,0xde941622,0x9ce400fe,0x7e6800a2}},	//   _རྙིད_, تجرب, _খগেন_, _şepb, 
   {{0x7c580075,0xb2b8011a,0x14d001f9,0x00000000}},	//   ملار_, _המתר, _तोडण, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3af42d35,0xe0dcda31,0x8d9400d1,0x00000000}},	//   зяйс, _fiòr_, كلەش, --, 
   {{0x79540309,0x7f5c0393,0xab9000d1,0xc5f800de}},	//   _ašwa, _iusq, رلىغ, ecēm_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7f5c0309,0x28a407d0,0x78a8004c,0xddc40010}},	//   _kusq, क्लि, ufev, _kejž, 
   {{0x7f5c0231,0x2d9c049f,0xdb20006c,0x78a8f3b4}},	//   _jusq, _äter_, _قوری, rfev, 
   {{0x7f5cf3b5,0x78a803b2,0x0a5801fe,0x00000000}},	//   _musq, sfev, _дафъ_, --, 
   {{0x8aa469db,0x78a80810,0x7e64002f,0xa2cc00cd}},	//   _юртд, pfev, ichp, दयन्, 
   {{0xe56c0598,0x00000000,0x00000000,0x00000000}},	//   _үз_, --, --, --, 
   {{0x7f5cf3b6,0x7414708e,0x87c0035b,0xddc40118}},	//   _nusq, سوسا, _аҩыз, _nejž, 
   {{0x853c0024,0x00000000,0x00000000,0x00000000}},	//   ltėl, --, --, --, 
   {{0xe29401c0,0xa498067c,0xfbc40451,0x00000000}},	//   яар_, riòr, _ڌڪ_, --, 
   {{0x6d586a08,0x7f5cf3b7,0x7e640036,0xe45c01d3}},	//   _étai, _busq, echp, ldön_, 
   {{0xe45c01b8,0x60200117,0x853c0064,0x00000000}},	// [15560] odön_, едта, itėl, --, 
   {{0xb8dc0135,0x7f5c0139,0xdfcc00c6,0xe45c007c}},	//   _ཆི_, _dusq, ديك_, ndön_, 
   {{0xf8bc3f55,0x7f540789,0x7f5c01c4,0x7e680356}},	//   ्याय, _dizq, _eusq, _şepc, 
   {{0x7e64f3b8,0x7f5c021c,0xe45c0108,0xfd9400d4}},	//   achp, _fusq, hdön_, ьшую, 
   {{0x205404ae,0x09b40073,0x61f801e4,0xfe7000e5}},	//   _מיכל_, ंब्य, ŝult, عدے_, 
   {{0xe9a802cb,0xad5802e8,0x00000000,0x00000000}},	//   مدبن_, _грах_, --, --, 
   {{0x6f0c02d0,0x00000000,0x00000000,0x00000000}},	//   _imbc, --, --, --, 
   {{0x1cb80003,0x2d98004c,0x92b80154,0x69c80165}},	//   _མིར_, mupe_, ছায়_, rvfe, 
   {{0x2d98f3b9,0xd83405f5,0x387c015d,0xca6402dd}},	//   lupe_, зээ_, _dewr_, _жезқ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x387c0477,0x2d98013c,0xc48400f7,0x7c2c0210}},	//   _fewr_, nupe_, үлүк, żart, 
   {{0x79541ebd,0xa4980ba1,0xfaa40022,0x69dc01f4}},	//   _tšwa, tiòq, _наӡо, äpeu, 
   {{0x6f0c03ac,0x2d980588,0x00000000,0x00000000}},	//   _ombc, hupe_, --, --, 
   {{0x28d8190c,0x6d580066,0x69cc0327,0xddc401ef}},	//   भावि, _étaw, _ġbej, _rejž, 
   {{0x7f54f3ba,0xd5ac01c6,0x7f5c06be,0xdb200098}},	//   _rizq, _яс_, _susq, érél, 
   {{0x6e38022c,0xd250f3bb,0x7f5c047e,0x45480244}},	//   _útby, انِ_, _pusq, _بستێ_, 
   {{0x7f5c0bf1,0x853c0153,0x434401af,0x00000000}},	// [15570] _qusq, ntėm, _офоғ, --, 
   {{0x2a7cf3bc,0x853c0024,0x81d401c0,0x7bdc06af}},	//   _netb_, itėm, _жоох, _àsui, 
   {{0x7e64f3bd,0x2d98020c,0x00000000,0x00000000}},	//   rchp, gupe_, --, --, 
   {{0x7e64f3be,0x521400d4,0x00000000,0x00000000}},	//   schp, _їдят, --, --, 
   {{0xa0180c86,0x6f60215c,0xd13801c6,0xe45c01f4}},	//   _adöv, _لۇقم, _ххэ_, ydön_, 
   {{0x613041b5,0x7f54035a,0x00000000,0x00000000}},	//   rçlu, _uizq, --, --, 
   {{0x2d98f3bf,0x853c00c0,0x8de8384f,0xf41c05ac}},	//   cupe_, etėm, _ефта_, _নৰাৰ_, 
   {{0x28d85cac,0x7afc0064,0x8d746c6e,0x00000000}},	//   भाषि, _įstu, _سافا, --, 
   {{0x7b1800a8,0xddc4031c,0x00000000,0x00000000}},	//   _доар_, _lejż, --, --, 
   {{0x09bc03f4,0xca485175,0xda645759,0xc70400c7}},	//   _অপরা, _کلمه_, _رائي, ежьқ, 
   {{0xe45c01b8,0x69dc01b8,0xf21005b3,0x99280251}},	//   rdön_, äpet, _डेढ़_, _люда_, 
   {{0x1cb8003d,0x2a7c009a,0x853c0064,0x00000000}},	//   _མིས_, _zetb_, ltėj, --, 
   {{0xb4e401e1,0xe72c00fd,0x6d580022,0x2d98f3c0}},	//   _apàà, _ае_, _étav, zupe_, 
   {{0x853c0006,0x2d98020c,0x00000000,0x00000000}},	//   ntėj, yupe_, --, --, 
   {{0x21643b9f,0xb7680451,0x853c00c0,0x41b4004e}},	//   диси_, _اٽڪل_, itėj, нстт, 
   {{0x69cca36b,0x6140011c,0x00000000,0x00000000}},	//   थिती, веса, --, --, 
   {{0x7e680432,0x8cc400cd,0x00000000,0x00000000}},	// [15580] _şepa, _रसबो, --, --, 
   {{0x2d98096b,0xe28098a4,0xe0dc01ab,0x00000000}},	//   tupe_, _ильи, _phòc_, --, 
   {{0xb144f3c1,0x2918003e,0xdcfc002b,0x00000000}},	//   _онол, épak_, _śvāp, --, 
   {{0x2d9826f4,0xdd8cf3c2,0x1fe4004b,0x853c0153}},	//   rupe_, شوه_, _ښکلي_, etėj, 
   {{0x2d98f3c3,0xab28004b,0x896401e1,0x00000000}},	//   supe_, يستل_, _ìsẹ̀, --, 
   {{0x2d9800ca,0x2aa80212,0x00000000,0x00000000}},	//   pupe_, ітло_, --, --, 
   {{0x2d98009a,0xcfe400cc,0xddc0011c,0x00000000}},	//   qupe_, _নেচন, _ибри, --, 
   {{0x6cd4038b,0x98a00640,0xfcc001e0,0x00000000}},	//   _تقرا, виће, _бәшм, --, 
   {{0xea8802e8,0xca940023,0x7e9402f2,0x00000000}},	//   _мбал_, _ዘሎኹም_, _زۆۆر_, --, 
   {{0xe45c01b8,0x1cb80327,0x443c0135,0x69dc01f4}},	//   adöl_, _མིོ_, _ġw_, äpes, 
   {{0xa6dc0051,0x5eb8011a,0x00000000,0x00000000}},	//   _chưa, חזיק, --, --, 
   {{0x43942e39,0x06c801c0,0xcfe400cc,0x00000000}},	//   намс, цгүй_, _নেছন, --, 
   {{0xe0dc004d,0x66e40137,0x00000000,0x00000000}},	//   _nhòa_, _оода, --, --, 
   {{0xf54807ae,0x06ac015b,0x2d88014f,0x00000000}},	//   _mấy_, _কোরি, _ovbe_, --, 
   {{0xf54807ae,0x9258f3c4,0x518401dd,0x57540375}},	//   _lấy_, дарт_, кута, _קבוע_, 
   {{0xd25801ce,0xeeb800d1,0xa680008e,0x6738007c}},	//   ьця_, үктә_, _яһүд, lltj, 
   {{0xf54801fb,0x6738057b,0x80a4102f,0x00000000}},	// [15590] _nấy_, oltj, ङ्गे, --, 
   {{0xd250021a,0xc7c80051,0xddc40210,0x00000000}},	//   انې_, _mố_, _tejż, --, 
   {{0xe2a42200,0xc7c8004d,0x673801f5,0x4ea402e8}},	//   áður_, _lố_, iltj, ърта, 
   {{0xf54801fb,0xd1b84c0e,0x91e41fbe,0x3cf80210}},	//   _bấy_, _کایا_, _роџе, ंसें_, 
   {{0x4fc4f3c5,0xecb00032,0xf54801fb,0x79440210}},	//   _исра, ыҡты, _cấy_, nówe, 
   {{0xdb1800c6,0x539c0a1e,0x673801a4,0x3f88003b}},	//   _tsuí, קסוא, jltj, msau_, 
   {{0x853c0024,0xa96400a7,0xb9540063,0x3f88002f}},	//   rtėj, нища_, нтић, lsau_, 
   {{0x6738f3c6,0xc7c807ae,0x853c0006,0xdd0000e2}},	//   eltj, _bố_, stėj, ērēj, 
   {{0xc7c807ae,0x5fdc0316,0x3f88cdfb,0x3ea0062c}},	//   _cố_, नमिल, nsau_, oght_, 
   {{0x3ea0f3c7,0x6e280023,0x3f88067c,0x8a100131}},	//   nght_, _ëmbë, isau_, _ھېيت, 
   {{0x3ea0f3c8,0x6d587c71,0xe614a5c1,0x3618005b}},	//   ight_, _état, едэ_, яцию_, 
   {{0x6738f3c9,0x76440014,0x13a8335b,0x5fdc0b02}},	//   altj, ٘یڈِ_, ونجی_, नमाल, 
   {{0x394cf3ca,0xf5480051,0x00000000,0x00000000}},	//   mmes_, _xấy_, --, --, 
   {{0x394cf3cb,0xb6a40724,0x81b82b1b,0x3f8800a3}},	//   lmes_, _чикл, চিন_, dsau_, 
   {{0x394c8d22,0x28a42efd,0x23240107,0x3f88f3cc}},	//   omes_, क्कि, хори_, esau_, 
   {{0x4094255b,0xafe45c97,0x64a0014b,0x3cf8012d}},	//   крут, нобл, _баъа, ंसों_, 
   {{0x3f880369,0x3ea00076,0x7944012d,0xc7c80051}},	// [155a0] gsau_, fght_, cówe, _xố_, 
   {{0xf8bc0882,0xa01805d5,0x394cf3cd,0xd16401a9}},	//   ्युप, _adös, hmes_, _иноқ, 
   {{0x394c1494,0x3f880618,0xf54801fb,0x62780a7c}},	//   kmes_, asau_, _sấy_, _מנינ, 
   {{0xa6dc01dc,0x3ea002a4,0x69cc0077,0xece80108}},	//   _nhưn, aght_, _ábei, ядел_, 
   {{0x7afc0024,0x70541a90,0x6738017a,0x394c000d}},	//   _įstr, _سنسا, yltj, dmes_, 
   {{0xada402d5,0xa9c40395,0x3f4c013a,0xf5480051}},	//   _пагл, есик, _džus_, _vấy_, 
   {{0xc7c801dc,0x7954000a,0x7944012d,0x00000000}},	//   _số_, _tšwl, zówe, --, 
   {{0x394cf3ce,0x99d0004b,0xa9a404a9,0xa6dc01fb}},	//   gmes_, اتوا, _җидд, _chưn, 
   {{0x0df802d3,0x67380083,0xdb180332,0x00000000}},	//   _ገዲፉ_, tltj, _cruó, --, 
   {{0x394c2fc3,0x45d4f3cf,0xdbdc0248,0xc7c80051}},	//   ames_, воос, _míìr, _vố_, 
   {{0xb908063f,0x6d580165,0xa2cc01bc,0xe708036b}},	//   nchọ_, _étas, दयस्, قتگن_, 
   {{0xc7c80016,0x3f8800a9,0x81b8009e,0x99940214}},	//   _tố_, ysau_, চিম_, _سپهر_, 
   {{0x9f4c2776,0xe0dc01ab,0x2584012c,0x69cc00dc}},	//   âgë_, _bhòn_, _bílá_, थिवी, 
   {{0xb90801f2,0x7944012d,0x00000000,0x00000000}},	//   kchọ_, rówe, --, --, 
   {{0x65b401d3,0x3958013a,0x00000000,0x00000000}},	//   _dühö, _čssz_, --, --, 
   {{0xd1381ff1,0x00000000,0x00000000,0x00000000}},	//   еху_, --, --, --, 
   {{0x645c00aa,0x7f5805f5,0xe0dc01ab,0x741400e5}},	// [155b0] _igqi, даас_, _fhòn_, _لوٹا, 
   {{0x3f88f3d0,0x3ea0f3d1,0x4428a0f0,0x81b80011}},	//   rsau_, ught_, _ixa_, চিব_, 
   {{0x3f88f3d2,0x394c0e21,0xdd98f3d3,0x5bb8012d}},	//   ssau_, ymes_, яша_, ोट्व, 
   {{0x44280227,0x4a7402dd,0xdb040241,0xca740150}},	//   _kxa_, қышт, _ìmús, қушы, 
   {{0x645c014b,0xfaa45aa6,0x7d08031c,0xfbc40108}},	//   _mgqi, вало, _ċesd, тбло, 
   {{0x38680e5e,0x6da000db,0x00000000,0x00000000}},	//   _żar_, _چۅلم, --, --, 
   {{0x645c01e2,0x394cf3d4,0x44280798,0x499400ee}},	//   _ogqi, tmes_, _lxa_, гшыт, 
   {{0x645c0944,0x62847816,0x49fc025c,0x3958f3d5}},	//   _ngqi, hajo, ྐྱེལ_, öss_, 
   {{0x394cf3d6,0xf770f3d7,0x6284f3d8,0x3b540022}},	//   rmes_, جاب_, kajo, _акар, 
   {{0x645c0944,0x6284f3d9,0xdb1800cf,0xf7440640}},	//   _agqi, jajo, _usuà, ђено, 
   {{0x4428094a,0x394c0af9,0xdbdc0241,0xa6dc0051}},	//   _axa_, pmes_, _míír, _thưn, 
   {{0xc32825f9,0xdb1801c0,0xb8141614,0x281001a9}},	//   _וו_, _iruñ, _идеј, اویس, 
   {{0x7c28025c,0xa498f3da,0xe0dc0051,0x6284f3db}},	//   _jxer, phòn, _phòn_, fajo, 
   {{0x6284f3dc,0x645c004b,0xa4980ba1,0x7c28025c}},	//   gajo, _egqi, lhòl, _mxer, 
   {{0x44281529,0x317c1497,0x7158f3dd,0x7c280051}},	//   _exa_, ètz_, драс_, _lxer, 
   {{0xa4981497,0x7c2802d0,0xf558007b,0xe12001a9}},	//   nhòl, _oxer, _تلعب_, амси, 
   {{0x6284f3de,0x44280472,0x28a41f13,0x7c28f3df}},	// [155c0] bajo, _gxa_, क्टि, _nxer, 
   {{0x691c00b0,0x00000000,0x00000000,0x00000000}},	//   tīek, --, --, --, 
   {{0x7c28f3e0,0xac840261,0xceb829dc,0x00000000}},	//   _axer, вгел, мәң_, --, 
   {{0xeb98013e,0xdb1c004a,0x26ec07af,0xdcac06ba}},	//   дид_, _évêq, _चक्र_, قىم_, 
   {{0xdcac12b7,0xdca0f3e1,0x81f40135,0x00000000}},	//   تىن_, рачи, _པཎྜི_, --, 
   {{0x69cc7a35,0xdb1804d4,0xb908063f,0x2c140073}},	//   थिली, _bruñ, pchọ_, _देणं_, 
   {{0xdb180077,0x7c28f3e2,0x2d9c0022,0xb7841de6}},	//   _cruñ, _exer, _ête_, ңәше_, 
   {{0xada41086,0xc5fc00fe,0x6284f3e3,0x00000000}},	//   _паҳл, ুপমা_, zajo, --, 
   {{0xaae0f3e4,0x4734f3e5,0x628401b9,0xcab400d1}},	//   पादक, лнис, yajo, _مەشخ, 
   {{0xaa8801d5,0x6284005a,0x99400139,0xd6d00124}},	//   _آنام_, xajo, _nıņ_, ажьы, 
   {{0xdb18f3e6,0x09bc04c5,0x6284f3e7,0x81f4031c}},	//   _usuá, _অপকা, vajo, _པཎྚི_, 
   {{0x26c80fb7,0x6284c277,0x320800d0,0x6ff800b8}},	//   žbo_, wajo, dzby_, _kācā, 
   {{0xf8ac00b2,0x6284f3e8,0x7c280327,0xc0c40131}},	//   _رکي_, tajo, _xxer, қәни, 
   {{0x2d9800f3,0x6ff800e2,0x00000000,0x00000000}},	//   krpe_, _mācā, --, --, 
   {{0x5bbc02ab,0x4428058a,0x52140022,0xa0a400cf}},	//   _एन्व, _wxa_, адрт, кшал, 
   {{0x62842207,0x4428f3e9,0x645c004b,0x9104004e}},	//   sajo, _txa_, _ugqi, ачуд, 
   {{0x6284f3ea,0xbed8f3eb,0x6ff81c52,0x00000000}},	// [155d0] pajo, ндах_, _nācā, --, 
   {{0x6ef008a5,0x00000000,0x00000000,0x00000000}},	//   _sæbr, --, --, --, 
   {{0x32080034,0x3b543007,0x0c0401d9,0x00000000}},	//   czby_, ңкер, یومُ, --, 
   {{0x5f740691,0xc0e00092,0x00000000,0x00000000}},	//   _لاسر, ነቱም_, --, --, 
   {{0x2d985bd9,0x6ff8002b,0xdb18032e,0x63ac0175}},	//   arpe_, _cācā, _bruð, ntcn, 
   {{0x93fc0bd9,0x00000000,0x00000000,0x00000000}},	//   ולדי, --, --, --, 
   {{0x2d9800f3,0x00000000,0x00000000,0x00000000}},	//   crpe_, --, --, --, 
   {{0x6d5820ef,0x7c2801c0,0x28d8f3ec,0x20040198}},	//   _étap, _txer, भागि, مni_, 
   {{0x7b9836bd,0x7c28545b,0xe0dc004d,0xd5840133}},	//   _سپاس_, _uxer, _nhòm_, چێته_, 
   {{0x7bc8f3ed,0xd58404d3,0xdb180789,0x7d186b95}},	//   _iseu, نێته_, _truñ, liws, 
   {{0xe0dc00a3,0x00000000,0x00000000,0x00000000}},	//   _phòl_, --, --, --, 
   {{0x7bc802e2,0x69f8010f,0x6ff80055,0xc5f800de}},	//   _kseu, _אלעק, _yācā, ecēs_, 
   {{0x48e03bec,0xe0dc01fb,0xc38400c7,0x00000000}},	//   कारो_, _chòm_, аҩыз_, --, 
   {{0xe3607327,0x66e06aa8,0x798002d0,0x27e00fac}},	//   скри, _гоша, _kwlw, åkne_, 
   {{0x021800d6,0x2c180316,0xdb0804cc,0xdb18000d}},	//   віть_, _मेनू_, rtgè, _isuä, 
   {{0x386cf3ee,0x9f4c006a,0x49fc025c,0xe0dc00a3}},	//   ncer_, âgî_, ྐྱིལ_, _cnò_, 
   {{0x61401677,0x35d80210,0x00000000,0x00000000}},	// [155e0] сета, _बछड़, --, --, 
   {{0x28d8072a,0x798002d0,0x9c1001e1,0x00000000}},	//   _मोनि, _owlw, _pọnm, --, 
   {{0x7bc80c6a,0x386c008b,0xfd6401c6,0xaae00b98}},	//   _aseu, kcer_, анхү, पासक, 
   {{0x1d042ec9,0x386c00d7,0x00000000,0x00000000}},	//   лехи_, jcer_, --, --, 
   {{0x79800076,0x95880023,0x00000000,0x00000000}},	//   _awlw, _መደብን_, --, --, 
   {{0xb9100a28,0x386cf3ef,0x6ff800cd,0xe4540115}},	//   _idaṃ_, ecer_, _vācā, אינט_, 
   {{0x7bc80311,0x7980015d,0x5f00f3f0,0x6c74014b}},	//   _eseu, _cwlw, _узра, _бузх, 
   {{0x2900f3f1,0x79800042,0x853c0153,0x7d18033f}},	//   óka_, _dwlw, ntėt, ciws, 
   {{0x1d04f3f2,0x7bdc00d8,0x9944007b,0x853c0064}},	//   _сети_, _àsup, دليل_, itėt, 
   {{0x386c003a,0x00000000,0x00000000,0x00000000}},	//   acer_, --, --, --, 
   {{0x291806af,0x79800142,0x6a840117,0x00000000}},	//   épas_, _gwlw, _алҷа, --, 
   {{0x386cf3f3,0x2ca4f3f4,0x7bc80165,0xd940f3f5}},	//   ccer_, ngod_, _yseu, _лехи, 
   {{0x63ac0334,0x8afc0210,0xc6940240,0x00000000}},	//   utcn, _cięg, _ቀጠልያ_, --, 
   {{0xe6b0152f,0x45d40117,0x00000000,0x00000000}},	//   _طلبگ, _вокс, --, --, 
   {{0x75c83452,0x00000000,0x00000000,0x00000000}},	//   _атың_, --, --, --, 
   {{0xb9100055,0xf3f403e6,0x26cc01ef,0xe4c00244}},	//   _bdaṃ_, اتێک, _hafo_, _اڵدی, 
   {{0x26ccf3f6,0x2ca4037e,0x1cb8031c,0xa0180112}},	// [155f0] _kafo_, dgod_, _མིཏ_, _geöl, 
   {{0x79700374,0x26ccf3f7,0x9e048dfe,0x00000000}},	//   _hāwe, _jafo_, лчел, --, 
   {{0x8afc068f,0x797002b1,0xb9100055,0x00000000}},	//   _międ, _kāwe, _edaṃ_, --, 
   {{0x26ccf3f8,0x7c580075,0x52740133,0xbc180150}},	//   _lafo_, نلار_, _پایز, кілі_, 
   {{0x26cc00fb,0x2b5c01ab,0x797002b5,0x69dc168c}},	//   _oafo_, _bitc_, _māwe, åpen, 
   {{0x9a840323,0x26ccf3f9,0x60ccf3fa,0x386c0042}},	//   уудл, _nafo_, _hacm, wcer_, 
   {{0x5338008f,0x395c0042,0x8cdc07f7,0x60cc03e0}},	//   אנגן_, _piws_, फाखो, _kacm, 
   {{0x386cf3fb,0x60cc24bc,0x26cc058a,0x2c1400dc}},	//   ucer_, _jacm, _aafo_, _देवं_, 
   {{0x386cf3fc,0x60ccf3fd,0x26cc01ee,0x18b0446e}},	//   rcer_, _macm, _bafo_, _ғәйр, 
   {{0x386cf3fe,0x2a6c0175,0x00000000,0x00000000}},	//   scer_, ccfb_, --, --, 
   {{0x26ccf3ff,0xe0dc02e2,0x8afc033f,0x69f0013e}},	//   _dafo_, _chòk_, _sięg, _мӯът, 
   {{0xc8c8446a,0x60cc0332,0x00000000,0x00000000}},	//   _مومن_, _nacm, --, --, 
   {{0x26cc096b,0x888c00c8,0x994004d3,0x7ae001f5}},	//   _fafo_, _טראַ, _پێکه, _knlt, 
   {{0x26cc0142,0x2ca40010,0x41d000cd,0x00000000}},	//   _gafo_, zgod_, हिंस, --, 
   {{0x3114036b,0x60cc0139,0xa18402e8,0xe68400fb}},	//   афас, _bacm, ибра_, _өҙөк_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xccf8c9d1,0x853c0024,0xafe40c60,0x06ac0154}},	// [15600] ққа_, rtėt, шоал, _কোটি, 
   {{0xbe840597,0x7d08031c,0x0ee007f7,0xa2e0030d}},	//   مجمو, _ċesa, नाइड, _доьд, 
   {{0xe2980375,0xed5801d5,0x00000000,0x00000000}},	//   _בשיר, вож_, --, --, 
   {{0x60cc01d9,0x2b5c0194,0x00000000,0x00000000}},	//   _gacm, _sitc_, --, --, 
   {{0xaae0038e,0x2ca498a1,0xcc180133,0x7f7400c0}},	//   पालक, rgod_, دراڵ_, _гусц, 
   {{0x6d900309,0x2ca40368,0x81b80154,0x5b1000d4}},	//   _añaš, sgod_, চির_, оміт, 
   {{0x7944006d,0x2ca40280,0x89d8004b,0x26cc0356}},	//   równ, pgod_, اوبر_, _rafo_, 
   {{0xdca0f400,0x26ccf401,0x940c00ac,0x6040063f}},	//   _маси, _safo_, şdə_, ọmes, 
   {{0x797002b1,0x26cc86b1,0xdcac1075,0x75240175}},	//   _rāwe, _pafo_, _تىق_, dnkz, 
   {{0x6d40f402,0xe6640120,0x00000000,0x00000000}},	//   lloa, штио, --, --, 
   {{0x3ed800c8,0x797002b5,0x6d40f403,0x08a801ec}},	//   אַרא, _pāwe, oloa, _مناۋ_, 
   {{0x6d404df6,0x69d805f5,0xdb18068c,0x9f4c01d3}},	//   nloa, _irte, _apuè, ágú_, 
   {{0x2904f404,0x442cf405,0x68e005b8,0x60cc0429}},	//   _iloa_, çe_, _inod, _racm, 
   {{0x290401ee,0x6d4001e0,0x6564026a,0x28d81428}},	//   _hloa_, hloa, _књиж, _मोति, 
   {{0x60ccf406,0x6d40f407,0x79700374,0x2904739c}},	//   _pacm, kloa, _tāwe, _kloa_, 
   {{0x6ab802c4,0x65780227,0x6d40084c,0x69d814b2}},	//   _lbtf, mpth, jloa, _mrte, 
   {{0x6d40f408,0x94440150,0x28ac000d,0x60cc00b8}},	// [15610] dloa, _وپىن, _टानि, _vacm, 
   {{0x290400cf,0x71740451,0x73f8010f,0x65780332}},	//   _lloa_, _گهٽا, _תּקו, opth, 
   {{0x290404c9,0xdce8248d,0x6d40f409,0x1cb8025c}},	//   _oloa_, šiči, floa, _མིད_, 
   {{0x5c74052f,0xdb1800e4,0xcdd80640,0x657800ae}},	//   рҙар_, _ipué, шњу_, ipth, 
   {{0x69d82e8d,0xaae002ab,0xcb68027d,0xb478010f}},	//   _arte, पांक, لمنه_, אָצי, 
   {{0x68e0f40a,0x2904f40b,0x69d8003e,0x6d401140}},	//   _anod, _aloa_, _brte, aloa, 
   {{0x69d81591,0x397c02d3,0x29040165,0x5ca001ec}},	//   _crte, _ጥቅምቲ_, _bloa_, _ولسە, 
   {{0x7784f40c,0x1ba801d3,0x7d241291,0x5fb80118}},	//   близ, _لائٹ_, _افرن, _उहाल, 
   {{0x69d8f40d,0xe0dc004d,0xd76000f1,0xe4e800cd}},	//   _erte, _chòi_, غندی, टानि_, 
   {{0x68e08741,0x95940276,0x29044627,0x370400f3}},	//   _enod, аӂиу_, _eloa_, спог, 
   {{0x29041509,0x21280036,0xd7d000c7,0x737c00d1}},	//   _floa_, _ojch_, сцқь, ﯩﺸﯩﺶ_, 
   {{0xb0d41152,0xe45c01f4,0xb954011c,0x00000000}},	//   _ढोंग, ydöt_, _увещ, --, 
   {{0x1cb80ed9,0x78a80af4,0xd1c002d3,0x657800ae}},	//   _མིན_, mgev, _ስዒቡ_, apth, 
   {{0x78a8f40e,0x69d80108,0x8afc0210,0x00000000}},	//   lgev, _yrte, _zięb, --, 
   {{0x6d402819,0x00000000,0x00000000,0x00000000}},	//   yloa, --, --, --, 
   {{0xf064f40f,0xb3c800f5,0x6d400051,0xb14401a9}},	//   скап, _близ_, xloa, ёнал, 
   {{0x6d400165,0xb6400150,0x24500c75,0xa92002d2}},	// [15620] vloa, _ﺍﻓ_, _ىنىس, _áþet, 
   {{0x6d400208,0x8afc0210,0x00000000,0x00000000}},	//   wloa, _mięc, --, --, 
   {{0x78a805e4,0xdf5801e1,0x6d4024b6,0x906400cf}},	//   kgev, _jàǹj, tloa, _وندۇ, 
   {{0xfd4c02e3,0x78a80196,0x6d40054e,0x6e9400f2}},	//   _ichọ, jgev, uloa, _گلسا, 
   {{0x78a80d47,0xfc340023,0x6538010f,0x7c640116}},	//   dgev, _እናፈለ, נענד, زانل, 
   {{0x3160020b,0x78a8f410,0x6d40f411,0xa2b8000d}},	//   _hikz_, egev, sloa, श्प्, 
   {{0x2df40014,0x78a8257c,0x49c801e0,0x7bdc032e}},	//   _آزر, fgev, рһен_, _ásun, 
   {{0x78a8f412,0x69d8151c,0xa2bc0034,0xab640006}},	//   ggev, _vrte, _लॉन्, _гвал, 
   {{0x29040481,0xcc8800aa,0x8afc033f,0x69d80142}},	//   _vloa_, _منځه_, _cięc, _wrte, 
   {{0x78a80175,0xbcfc00b8,0x45b800d4,0x00000000}},	//   agev, _viũe, агою_, --, 
   {{0xd6d4f413,0x69d8152d,0x290401af,0xfd4c0521}},	//   сты_, _urte, _tloa_, _nchọ, 
   {{0x68e0f414,0x290403a0,0xe0dc004d,0x6f1c035a}},	//   _unod, _uloa_, _thòi_, hipc, 
   {{0x6844f415,0xfd4c00b4,0xdb180051,0x6f1c0205}},	//   _унда, _achọ, _truô, kipc, 
   {{0x797002b1,0x48e0012c,0x6f1c020c,0x54540eed}},	//   _hāwa, काको_, jipc, явят, 
   {{0x79700325,0x6738f416,0x1718008f,0x8afc0210}},	//   _kāwa, motj, _גוגע, _zięc, 
   {{0x673800f7,0x807841e5,0x40880124,0xd574011a}},	//   lotj, рбас_, шәом_, _פתחה_, 
   {{0x65681682,0x797002b5,0x9e6400cf,0x673801a4}},	// [15630] _hufh, _māwa, ماان, ootj, 
   {{0x6f1c067c,0x67380427,0x78a80200,0x00000000}},	//   gipc, notj, zgev, --, 
   {{0x6fb80135,0x0444001f,0xbcfc00b8,0x41b400ae}},	//   _པདྨའ, _ማስጠን, _niũc, _بمجر, 
   {{0x65681682,0x673800fb,0x79701e27,0x00000000}},	//   _mufh, hotj, _nāwa, --, 
   {{0x6738f417,0x65681682,0x69c80175,0x78a803b2}},	//   kotj, _lufh, ewfe, vgev, 
   {{0x0ca803a5,0xe0dc0100,0x21380477,0x3dc800ec}},	//   атәи_, _chòv_, loqh_, _پورٽ_, 
   {{0x78a83441,0x28d81a47,0x64b00118,0x00000000}},	//   tgev, _मोहि, _křič, --, 
   {{0x8afc033f,0x7944012d,0x48e028d4,0x1cb800ae}},	//   _pięc, mówk, कागो_, _حاسب_, 
   {{0x78a8f418,0x7d08f419,0x65680730,0xa498068c}},	//   rgev, _iles, _aufh, nhòu, 
   {{0x78a82a28,0x7d0801ef,0x00000000,0x00000000}},	//   sgev, _hles, --, --, 
   {{0x8afc14cf,0x5ed0045e,0x78a8f41a,0x7944012d}},	//   _więc, সাপে, pgev, nówk, 
   {{0x97700184,0x7d084ac8,0x17045598,0x6f1c010a}},	//   _еткә, _jles, _گفتی_, zipc, 
   {{0xc8c8f41b,0x7d080066,0x6738f41c,0x36d4a15c}},	//   _دونن_, _mles, botj, _модр, 
   {{0x7d08f41d,0x67382959,0x7944012d,0x853c0064}},	//   _lles, cotj, kówk, grėb, 
   {{0x7d08f41e,0xb284010b,0x7944012d,0x2c140037}},	//   _oles, йыңк, jówk, _देईं_, 
   {{0xb1441c26,0xa0640a83,0x7d080066,0x7944033f}},	//   інал, жата_, _nles, dówk, 
   {{0x6f1c04a7,0x5ed000eb,0x00000000,0x00000000}},	// [15640] tipc, সানে, --, --, 
   {{0x7d08f41f,0xae78d4d5,0x34940022,0x69c80142}},	//   _ales, рсах_, _уаҩр, ywfe, 
   {{0x6f1cf420,0xa2b808a8,0x7944012d,0x00000000}},	//   ripc, _דמיט, gówk, --, 
   {{0x7d08f421,0xdd8c00b2,0x0eac0574,0xafe4036b}},	//   _cles, ئون_, _चावड, _домл, 
   {{0x79700374,0x7d08f422,0xa098008f,0x00000000}},	//   _rāwa, _dles, _דיכט, --, 
   {{0x7d08b07e,0xa018006a,0xc0f800b7,0xa498067c}},	//   _eles, _ndöy, ፈጠረ_, lhòt, 
   {{0x797002b5,0xe908f423,0x7778010a,0x7944033f}},	//   _pāwa, ихик_, _atwx, cówk, 
   {{0x7d08f424,0xd1c002d3,0xa498067c,0x6738020c}},	//   _gles, _ስኒት_, nhòt, wotj, 
   {{0xc0f0044e,0xb81c04fa,0x67380549,0x99e00419}},	//   _ፍቕሪ_, _बेदम_, totj, ĺňal, 
   {{0x7970166a,0x28d80358,0xeaa80451,0x8b8800f7}},	//   _wāwa, _मोरि, _خطرو_, _نەچە_, 
   {{0x6738f425,0x79700374,0xc0f8001f,0x7d08127b}},	//   rotj, _tāwa, ፈጠሩ_, _yles, 
   {{0x1c1c0034,0x67382959,0xe784f426,0x00000000}},	//   _मेडल_, sotj, _дуко, --, 
   {{0x673801a4,0x7944033f,0x61300327,0x00000000}},	//   potj, zówk, nħle, --, 
   {{0x9940ca2c,0x673801f0,0xd6cc036b,0x57f0109a}},	//   _kış_, qotj, _ўт_, _юпіт, 
   {{0x64b000bc,0x8c480205,0x00000000,0x00000000}},	//   _přič, liğı, --, --, 
   {{0x69a002ab,0x99404682,0xb4e00241,0x00000000}},	//   _गिनी, _mış_, _áàpa, --, 
   {{0x6d5806af,0x99400139,0x7f440978,0x73c0190b}},	// [15650] _étay, _lış_, tlhq, _пәре, 
   {{0x79440034,0x9e64f427,0x00000000,0x00000000}},	//   tówk, زائن, --, --, 
   {{0xe0dc08c2,0x57b401ad,0x64b0013a,0xfdb8011c}},	//   _bhòt_, _अह्ह, _třič, слещ_, 
   {{0xe0dc4079,0xd124001f,0x79440034,0xa498180f}},	//   _chòt_, _ተገቢው, rówk, chòt, 
   {{0x7d08f428,0x7944012d,0x61300135,0x5bc400db}},	//   _vles, sówk, għle, تتاف, 
   {{0x7944033f,0xeb94f429,0x4fc42dfc,0xbcfc002b}},	//   mówi, чиш_, _تەكە, _diũa, 
   {{0x7d08f42a,0xdb0804cc,0xc0f8001f,0x00000000}},	//   _tles, rtgà, ፈጠር_, --, 
   {{0x25dc2e1e,0x7d08f42b,0x994003ee,0x3ea80276}},	//   गिनी_, _ules, _dış_, şită_, 
   {{0xe8f400d4,0x00000000,0x00000000,0x00000000}},	//   їль_, --, --, --, 
   {{0xdce401fa,0x00000000,0x00000000,0x00000000}},	//   _mujč, --, --, --, 
   {{0x99400139,0x00000000,0x00000000,0x00000000}},	//   _gış_, --, --, --, 
   {{0x38c8150e,0x8c480166,0x00000000,0x00000000}},	//   _دائی_, biğı, --, --, 
   {{0x37e4444e,0x00000000,0x00000000,0x00000000}},	//   _холг, --, --, --, 
   {{0x9940008e,0x00000000,0x00000000,0x00000000}},	//   _yış_, --, --, --, 
   {{0xcaf40490,0x748c0131,0xaaac0073,0xe6400117}},	//   _अवघड_, _ﻛﯩﭽﯩ, _घासक, _пешп, 
   {{0x04b40228,0xb4d41359,0xf0280092,0x00000000}},	//   _قلىڭ, _رغبت, _ተመርም, --, 
   {{0x853400db,0x6f640b24,0x00000000,0x00000000}},	// [15660] _تويچ, سهام, --, --, 
   {{0xe0dc0100,0x9f5c0ad9,0xdb0800b5,0x6130025c}},	//   _akòd_, órða_, ltgæ, għlb, 
   {{0x6ce40220,0x00000000,0x00000000,0x00000000}},	//   зіле, --, --, --, 
   {{0x656c00c6,0xa498068c,0x99400139,0xdb08005c}},	//   íbhi, lhòr, _rış_, ntgæ, 
   {{0xdc2000b0,0x5eb003d4,0xa3dc28fe,0x00000000}},	//   _pōār, ীয়ে, णिय_, --, 
   {{0x28ac000d,0x00000000,0x00000000,0x00000000}},	//   _टाहि, --, --, --, 
   {{0x994043bc,0x99d000c6,0x00000000,0x00000000}},	//   _qış_, فتيا, --, --, 
   {{0x0eac012c,0x7e6002d2,0x00000000,0x00000000}},	//   _चाँड, _úlpa, --, --, 
   {{0xd87000db,0xac081c13,0x9f5c067c,0xe45c002f}},	//   رايب, _унаа_, òrça_, geöl_, 
   {{0x99400724,0x9f9803fa,0x47340120,0x00000000}},	//   _tış_, _läßt_, ќнос, --, 
   {{0xd90c0953,0xe0dc0013,0xa49801ab,0xd5b4084c}},	//   _зь_, _mhòr_, dhòr, пся_, 
   {{0x2900369a,0xdb040108,0x00000000,0x00000000}},	//   ökad_, ölön, --, --, 
   {{0x66e407d6,0x6844f42c,0xe7386e27,0x0eac07af}},	//   _нода, _энда, _лед_, _चांड, 
   {{0x782400ae,0x00000000,0x00000000,0x00000000}},	//   _تعمل, --, --, --, 
   {{0xa498007f,0x622000d1,0x00000000,0x00000000}},	//   lkòm, رورە, --, --, 
   {{0xdce4013a,0xc39001af,0x26840345,0x00000000}},	//   _pujč, _иҫмә, _بڕکێ_, --, 
   {{0x8fe401e0,0x8334011c,0x0fe441b9,0x00000000}},	// [15670] нәрҙ, _оних, нөрү, --, 
   {{0xa280034d,0x4274f42d,0xdce4107d,0xe0dc08c2}},	//   _سیرو, _югос, _vujč, _phòs_, 
   {{0x415400f3,0x06a001ec,0x00000000,0x00000000}},	//   _овос, _ﻋﯘﻣﯩ, --, --, 
   {{0xed4c036b,0xdb2001b9,0x20c87427,0x00000000}},	//   stоn_, کوتی, _ابدي_, --, 
   {{0xab9000d1,0x9f4c398f,0x00000000,0x00000000}},	//   پلىغ, ágó_, --, --, 
   {{0x4fc40136,0x3978014b,0xfaa40139,0x00000000}},	//   _سەمە, осию_, фако, --, 
   {{0x630c03d4,0xdb800023,0x929c011a,0x00000000}},	//   _সদায়_, ርእዮም_, זיות, --, 
   {{0xbacc0729,0xb7e4f42e,0xa3bc04fa,0x09ac00fe}},	//   লাইছ, джик, ीबा_, _কৈহা, 
   {{0x2d9c049f,0x941c23ef,0x00000000,0x00000000}},	//   _åter_, _पेंच_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7c2c0d12,0x00000000,0x00000000,0x00000000}},	//   úarf, --, --, --, 
   {{0xb92475a6,0xf3e40aac,0x00000000,0x00000000}},	//   _تفصي, дқиқ_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf624f42f,0xdb080388,0x00000000,0x00000000}},	//   _одло, stgæ, --, --, 
   {{0xe3602082,0x25dc578b,0x00000000,0x00000000}},	//   ткри, गिणी_, --, --, 
   {{0xe4c0030d,0x00000000,0x00000000,0x00000000}},	//   _айъи, --, --, --, 
   {{0x6140f430,0xc508005e,0xe0dc00a3,0x2eb4e55b}},	// [15680] тета, _ءتىل_, _phòr_, дсес, 
   {{0x253802e3,0x81b800cc,0x00000000,0x00000000}},	//   ụntụ_, চিজ_, --, --, 
   {{0xdd8c4e2e,0x28ac07f7,0x00000000,0x00000000}},	//   لول_, _टालि, --, --, 
   {{0xb80c54cb,0x00000000,0x00000000,0x00000000}},	//   िनाम_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa3dc80a0,0x437c00d1,0x00000000,0x00000000}},	//   णित_, ﻣﺪﯨﻦ_, --, --, 
   {{0x853c0064,0x00000000,0x00000000,0x00000000}},	//   drėn, --, --, --, 
   {{0xdcac00cf,0xace801e2,0x00000000,0x00000000}},	//   _پىك_, _برسل_, --, --, 
   {{0xd834152d,0xeb3400f7,0xfd64002b,0x1c4001ee}},	//   дээ_, _قىرد, _nirṛ, _антм, 
   {{0x6b80f431,0x98c000e2,0x00000000,0x00000000}},	//   mpog, īvās_, --, --, 
   {{0x78b00158,0x6b80022e,0x00000000,0x00000000}},	//   åkvå, lpog, --, --, 
   {{0x6b800b23,0xa8045a31,0x2ee800d8,0x257800b8}},	//   opog, _озел, _lnbf_, _nīle_, 
   {{0x690c0428,0x81b800fe,0x28141b40,0x6b80017a}},	//   _tùeb, চিছ_, _توشس, npog, 
   {{0xd700f432,0x6b8004c9,0x00000000,0x00000000}},	//   _изчи, ipog, --, --, 
   {{0xa1640063,0xdce400ef,0x21640139,0x00000000}},	//   дњак, _lujā, дтаг, --, 
   {{0xa2bc06ab,0x09a80327,0x656c00ae,0x00000000}},	//   _लॉर्, _བཀླ_, íbhu, --, 
   {{0x6b80151c,0xb03429db,0xd16402e8,0xdce40055}},	// [15690] jpog, емтә, търи, _nujā, 
   {{0x7414168d,0x3ed400c6,0x6b8067e9,0x1ee4e1a2}},	//   _سوپا, عقار, dpog, بوطی_, 
   {{0xdd988b11,0x62840327,0x6f0c01ef,0xdb0801e3}},	//   юша_, mbjo, _dlbc, ntgå, 
   {{0xe084642c,0xa2b81df0,0x1fa4010a,0x00000000}},	//   _تجدي, श्र्, _оргг, --, 
   {{0x5064f433,0x3f78008f,0xfcc40166,0x30780a7c}},	//   _атра, _מאָס, _җәем, _מארנ, 
   {{0x2ee80048,0xba7416a0,0xdb080fac,0xe56c02dd}},	//   _gnbf_, راتت, ktgå, _өзi_, 
   {{0xa018002d,0x8d74f434,0xaa401cd1,0x6b800124}},	//   _geör, _لاقا, лешл, apog, 
   {{0x4f840050,0x06d80154,0xdb085f03,0x00000000}},	//   _سٔہل, তাফি, dtgå, --, 
   {{0x4c940022,0xd9e800c5,0x8cd80456,0x06d800eb}},	//   _шитс, _झपकत_, _नोटो, তানি, 
   {{0xdb08007c,0x00000000,0x00000000,0x00000000}},	//   ftgå, --, --, --, 
   {{0xdb0801bf,0x628402d2,0x00000000,0x00000000}},	//   gtgå, dbjo, --, --, 
   {{0xe45c01b8,0x17f800c6,0xe8ec09a5,0xc98404b4}},	//   iföf_, _ورشة_, _ёл_, _руфи, 
   {{0xe72cf435,0x2be01152,0xe5f000db,0xb6a401fe}},	//   _бе_, पिया, _ەكىد, _зилл, 
   {{0x62840158,0xe0dc0100,0xdb0801bf,0x628c01e1}},	//   gbjo, _shòp_, btgå, _àkó, 
   {{0x317c092e,0x6b800427,0x25780171,0x8ed800eb}},	//   ëtz_, zpog, _pīle_, সামগ, 
   {{0x1cd8025c,0x6b80023d,0x00000000,0x00000000}},	//   ྡབས_, ypog, --, --, 
   {{0xb4bc2ce1,0x9fc4f436,0x257800ef,0x2ee41d4d}},	// [156a0] ीजी_, нгта_, _vīle_, нжаг, 
   {{0xdd8c0133,0xdce400b8,0x752406be,0x00000000}},	//   ڵوه_, _rujā, likz, --, 
   {{0x6e340353,0x942400db,0x85340330,0xdce400cd}},	//   ххах, _سوگۇ, _سویچ, _sujā, 
   {{0xe57000c8,0xdce40171,0x6b80031c,0xc10001af}},	//   אַס_, _pujā, tpog, _күсл, 
   {{0x79700374,0xd0440124,0x98ac0139,0x7fd401ec}},	//   _hāwh, _рҭак, _nigı_, _иірі, 
   {{0x797004fe,0x6b8001e4,0x00000000,0x00000000}},	//   _kāwh, rpog, --, --, 
   {{0x6b80f437,0x7db4005b,0x00000000,0x00000000}},	//   spog, _истц, --, --, 
   {{0x79700374,0xa85009a5,0x98b402e8,0x00000000}},	//   _māwh, лейә, елът_, --, 
   {{0x2f2401e1,0x7524005a,0x6d40062c,0xeab003af}},	//   _gígè_, dikz, mooa, _معا_, 
   {{0x8afc0034,0x6d400636,0xdb2003b2,0xdb08713c}},	//   _mięk, looa, _árði, ttgå, 
   {{0xdb08f438,0x7524005a,0x1a98008f,0xe9a40108}},	//   dugè, fikz, _זיבע, _чаеп, 
   {{0xdb080267,0x6d40f439,0x06c8009d,0x00000000}},	//   rtgå, nooa, чгүй_, --, 
   {{0xdce80552,0xd498f43a,0xdb0801e3,0x06d80011}},	//   šići, эрэ_, stgå, তাবি, 
   {{0x6d4034a6,0xdb0803cd,0x61300327,0x00000000}},	//   hooa, ptgå, għln, --, 
   {{0x6d40005a,0x00000000,0x00000000,0x00000000}},	//   kooa, --, --, --, 
   {{0xd0d40395,0x00000000,0x00000000,0x00000000}},	//   лосъ, --, --, --, 
   {{0xdbdc02d2,0xc35400f3,0x00000000,0x00000000}},	// [156b0] _síþr, _икиј, --, --, 
   {{0x63ac0fcf,0xdb1805d1,0xd5480014,0xdb2001d3}},	//   mucn, _ipuç, _ٲلیو_, érül, 
   {{0x80d80154,0xdda80395,0x00000000,0x00000000}},	//   ডাব্, ятал_, --, --, 
   {{0x9d44f43b,0x6d4000db,0x7f940022,0xdbb42cc8}},	//   رئان, gooa, _иамх, еткә_, 
   {{0x90980395,0x00000000,0x00000000,0x00000000}},	//   _явят_, --, --, --, 
   {{0x797002b1,0xfaa84630,0x00000000,0x00000000}},	//   _hāwi, ذهبي_, --, --, 
   {{0x7970f43c,0x8f3400d6,0xae1c0574,0x7c2c0008}},	//   _kāwi, _серц, _येऊन_, úarb, 
   {{0x69a09856,0x6d400c6a,0x63ac0010,0x98ac0139}},	//   _गिरी, cooa, kucn, _pigı_, 
   {{0xabb40124,0xbab8014b,0x00000000,0x00000000}},	//   _иатә, _огах_, --, --, 
   {{0x7bc8014b,0xdb0800d2,0x3cec00d0,0x7608009d}},	//   _ipeu, kugé, _hnev_, деог_, 
   {{0x044802d3,0xc9840353,0x69dc00d7,0x00000000}},	//   _መቕጻዕ, _бучи, ťper, --, 
   {{0x79700053,0x798016e3,0xb4bc41d8,0x00000000}},	//   _rāwh, _itlw, ीजे_, --, 
   {{0x63ac0b91,0x394cf43d,0x7524b4b6,0x798003ac}},	//   gucn, mles_, rikz, _htlw, 
   {{0x394cf43e,0x79700053,0x2be000dc,0xdb080129}},	//   lles_, _pāwh, पिता, fugé, 
   {{0xdb080066,0x324402e8,0xe734d877,0x6130031c}},	//   rugè, тевг, _шеш_, għlo, 
   {{0x25dc069f,0x8afc068f,0x394cf43f,0x63ac0276}},	//   गिरी_, _pięk, nles_, bucn, 
   {{0x394cf440,0x797000b0,0xf0646179,0x6d40062c}},	// [156c0] iles_, _wāwh, ткап, vooa, 
   {{0x79700053,0x394c91a5,0x798001e0,0x6d400076}},	//   _tāwh, hles_, _otlw, wooa, 
   {{0x8afc068f,0x798027be,0x6b54025a,0xe0dc0100}},	//   _więk, _ntlw, yâgb, _ikòn_, 
   {{0x394cf441,0x6144001f,0x2d9800b5,0x00000000}},	//   jles_, _የሴቶች, rspe_, --, 
   {{0x394cf442,0x7d08031c,0x6d4000ad,0xdce400ef}},	//   dles_, _ċest, rooa, _atjē, 
   {{0x394cf443,0xa01804cc,0x28d8033f,0x3cec0112}},	//   eles_, _sfög, _मोजि, _enev_, 
   {{0x394cf444,0x6c84007b,0xdbdc02d2,0x6d4000e8}},	//   fles_, _للأم, _bíór, pooa, 
   {{0x3cec009b,0x394cf445,0x28c00c4c,0xf8b401e0}},	//   _gnev_, gles_, _वॉशि, гөш_, 
   {{0xb9780943,0xab64f446,0x6b6489d2,0x9944007b}},	//   roﬁt, _авал, _акаа, خليل_, 
   {{0x394cf447,0x9bb40a1e,0x387c0042,0x28c00412}},	//   ales_, _בהמה_, _efwr_, _वॉरि, 
   {{0xd6d47bf7,0x394cf448,0x387c0042,0x29180ba1}},	//   тты_, bles_, _ffwr_, èpas_, 
   {{0x394cf449,0x98a00e91,0x63ac00d7,0x00000000}},	//   cles_, _вице, tucn, --, 
   {{0x79700374,0xe0d00214,0x892401d3,0x6938031c}},	//   _rāwi, یزر_, _لڑکو, rċed, 
   {{0x63ac0b91,0x27e40d8b,0xd704074d,0x00000000}},	//   rucn, _iron_, _инче_, --, 
   {{0x57540302,0x4ac40b8f,0x9294f44a,0x61400ae5}},	//   _שבוע_, ल्यव, расц, لىسە, 
   {{0x518400c2,0xd4980276,0x75340200,0xc1043592}},	//   рура, _ирь_, _gjyz, دوري, 
   {{0x27e4020c,0xfce40032,0x63ac003a,0x3f9c00e8}},	// [156d0] _jron_, ғоло, qucn, éwu_, 
   {{0x9e040724,0x25f402ab,0x9e646418,0x3cec143a}},	//   кчел, एमपी_, ناان, _snev_, 
   {{0x7bc8f44b,0x8d74f44c,0x797002b5,0xfaa401b9}},	//   _speu, لانا, _tāwi, ҳало, 
   {{0x27e4f44d,0x394c037e,0xee7c0023,0x853c00c0}},	//   _oron_, xles_, _ብዳርባ_, drėk, 
   {{0xfaa4f44e,0x394cf44f,0xbb3c0131,0xe3bc0165}},	//   гало, vles_, ﺑﯘﻝ_, ntñ_, 
   {{0x394c5657,0xa49800cf,0x0b443981,0x29000267}},	//   wles_, ckòv, анін, ökan_, 
   {{0x27e4c267,0x394cf450,0xed4c32db,0x7f44014f}},	//   _aron_, tles_, _کھل_, mohq, 
   {{0x27e4f451,0x394cf452,0x00000000,0x00000000}},	//   _bron_, ules_, --, --, 
   {{0x27e4f453,0x7bc80421,0xdb0805d5,0x853c0153}},	//   _cron_, _upeu, ztgù, prėj, 
   {{0x27e4f454,0x394cf455,0x7f44014f,0x25780055}},	//   _dron_, sles_, nohq, _sīla_, 
   {{0xc76476b9,0x7980f456,0x27e49224,0x394cf457}},	//   جايى, _utlw, _eron_, ples_, 
   {{0x27e4f458,0x394c0227,0x7f44016d,0xdc400118}},	//   _fron_, qles_, hohq, _léčk, 
   {{0x27e4f459,0x673000e5,0x2898011a,0x00000000}},	//   _gron_, ódjá, _ניסא, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x25bc0408,0x71742010,0x27e40165,0x7f440455}},	//   cttl_, اهرا, _zron_, dohq, 
   {{0x74141ec7,0x25a800d0,0xa0740166,0x00000000}},	//   _موعا, áble_, гъфә, --, 
   {{0x2f1404ce,0xaec4f45a,0xdc400c5e,0xa3dc00cd}},	// [156e0] _læge_, лбал, _béčk, णिः_, 
   {{0xdc4002f0,0x00000000,0x00000000,0x00000000}},	//   _céčk, --, --, --, 
   {{0xc1d41cd1,0xdc4001ef,0x00000000,0x00000000}},	//   _көтә, _déčk, --, --, 
   {{0xdcac08c9,0x69b8547d,0x4c84f45b,0x00000000}},	//   كىم_, _एमबी, рғаз, --, 
   {{0x3208f45c,0xab28f45d,0xdca00305,0xac080a89}},	//   lyby_, нода_, сачи, энда_, 
   {{0xe4540a1e,0xeef4084c,0x27e4036e,0xf1a8012d}},	//   ניסט_, _сямэ, _rron_, _ज़मान, 
   {{0x27e400a3,0x888445cc,0xfaa40150,0x00000000}},	//   _sron_, لیان, ршін, --, 
   {{0x27e4f45e,0x5e4400d8,0x00000000,0x00000000}},	//   _pron_, _спсм_, --, --, 
   {{0xaba82088,0x320802fb,0x7b0800e5,0x00000000}},	//   _سهام_, hyby_, üstö, --, 
   {{0x0fc80156,0xded0001f,0x00000000,0x00000000}},	//   ཅཆཇཉ, _የቀን_, --, --, 
   {{0xd7f400fb,0x98100101,0x27200051,0x320800a2}},	//   _ҡуш_, لبیا, hưng_, jyby_, 
   {{0x69d8f3fa,0x27e4f45f,0xdb180ba1,0xa8480597}},	//   _iste, _tron_, _aquè, _كلام_, 
   {{0x27e418be,0x6618295c,0x69b8012d,0x00000000}},	//   _uron_, sztk, _एमडी, --, 
   {{0xe0dc007f,0x25bc0175,0xf99000e5,0x45f800ae}},	//   _ekòl_, pttl_, _دبے_, _لفتح_, 
   {{0x20c454a0,0xdb080158,0x00000000,0x00000000}},	//   лсаг, rtgø, --, --, 
   {{0xdb18067c,0xdb0800b5,0x00000000,0x00000000}},	//   _equè, stgø, --, --, 
   {{0x200cf460,0x6368b3bc,0x659001ec,0xd7600133}},	// [156f0] ági_, _прог_, _тақу, _خۆیی, 
   {{0xa2bc000d,0x00000000,0x00000000,0x00000000}},	//   _लउट्, --, --, --, 
   {{0x69d80327,0xeb8402d3,0x25781574,0xdc40012c}},	//   _nste, _ዝሰፈና_, _jël_, _véčk, 
   {{0x6294f461,0x6ab8127b,0x98bc0118,0x5f7400f1}},	//   _hexo, _actf, touč_, _ماسر, 
   {{0x69d8f462,0x257800e8,0x00000000,0x00000000}},	//   _aste, _lël_, --, --, 
   {{0x3f88f463,0x69d80036,0xdbdc03b2,0x257800b8}},	//   mpau_, _bste, _díðr, _nīlo_, 
   {{0xd2b80302,0x62940139,0x78b80051,0x60d802d2}},	//   אלות_, _mexo, _pcwv, _óums, 
   {{0x6294044e,0x69d80036,0xb9040276,0x3f880093}},	//   _lexo, _dste, рзик, opau_, 
   {{0xe8f4f464,0x7750693c,0xf7180953,0x3208033f}},	//   рлы_, _ሕብረተ, віны_, zyby_, 
   {{0x6294f465,0x99d41d93,0x3f880421,0xbfcc0241}},	//   _nexo, _متصا, ipau_, _káṣọ_, 
   {{0xcb08036b,0x28c00490,0x853c0064,0x00000000}},	//   _ёхуд_, व्हि, ksėd, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x629408ca,0xdb18f466,0x6448022c,0xbfcc01e1}},	//   _bexo, _aqué, _øgil, _láṣọ_, 
   {{0x69d8f467,0x24580241,0x00000000,0x00000000}},	//   _yste, _sàmí_, --, --, 
   {{0x395c0211,0xe0dc0428,0xd5a013de,0xdb080036}},	//   _khws_, _ekòm_, _البی, ergë, 
   {{0x7084f468,0x4094f469,0x58a40183,0x3328031c}},	//   ргаз, йрут, ক্ৰী, sibx_, 
   {{0x06d803f4,0x2164f46a,0x3f88003e,0x245001ec}},	// [15700] তারি, рити_, gpau_, _ونىس, 
   {{0xe0dc0086,0x6294011f,0xa3780254,0x00000000}},	//   _eaò_, _gexo, ivõl, --, 
   {{0x3f881132,0x6c8400d1,0x25780de2,0x8afc012d}},	//   apau_, للام, _xël_, _mięt, 
   {{0x69d8f46b,0xbfcc0241,0x823c0092,0xfcd40092}},	//   _rste, _dáṣọ_, _የድሬዳ, _የበግ_, 
   {{0x6b6405bc,0x62940de2,0x1d040063,0x00000000}},	//   акда, _yexo, јечи_, --, 
   {{0x37bc0183,0x69d80fac,0xdbdc02d2,0x81a800cc}},	//   ্টাৰ, _pste, _víðr, _খঙত_, 
   {{0x99d08dca,0x6ab800b5,0xfe705821,0xa2b801ad}},	//   قتيا, _vctf, _ردّ_, श्ट्, 
   {{0xed586a0a,0x29000bcd,0x1d04b6d1,0xd1d8001f}},	//   _роб_, ðka_, _кеси_, ርብቶ_, 
   {{0xe0dc0100,0xc680001f,0x69d8033f,0x382c0023}},	//   _chòy_, _የአማራ_, _wste, _እትርእ, 
   {{0xa9a4f46c,0xe664f46d,0x257800e8,0x7c300118}},	//   _вижд, итно, _pël_, škrá, 
   {{0x69d8f46e,0x3af4f46f,0x84c4010b,0xf81401b9}},	//   _uste, _уятс, бәпд, لسیگ, 
   {{0x7c3401a8,0x00000000,0x00000000,0x00000000}},	//   _áfrý, --, --, --, 
   {{0x6294f470,0x2b5c0051,0x00000000,0x00000000}},	//   _pexo, _khtc_, --, --, 
   {{0x20e0004d,0x8afc012d,0x00000000,0x00000000}},	//   _ổi_, _gięt, --, --, 
   {{0x53340124,0x00000000,0x00000000,0x00000000}},	//   церт, --, --, --, 
   {{0xd5f8011a,0x00000000,0x00000000,0x00000000}},	//   _יפור, --, --, --, 
   {{0x25dc1533,0xa4a40086,0x3f880618,0x62940139}},	// [15710] गिकी_, _etòñ, upau_, _texo, 
   {{0x7c5867d1,0x8afc0034,0x3f88f471,0xe4e8000d}},	//   ۇلار_, _mięs, rpau_, _जोति_, 
   {{0xa3dc10dc,0x00000000,0x00000000,0x00000000}},	//   णिक_, --, --, --, 
   {{0xdb0804cf,0x3f8807de,0x0dc80107,0x71d4011a}},	//   rugí, ppau_, руфи_, _פורד_, 
   {{0x2bd806e3,0x395c0142,0x00000000,0x00000000}},	//   _मैदा, _rhws_, --, --, 
   {{0xd90c03e6,0x7d18009f,0x63ac01c3,0xa2b807b7}},	//   ژیا_, shws, ircn, श्च्, 
   {{0x4dd40553,0x00000000,0x00000000,0x00000000}},	//   _وتفس, --, --, --, 
   {{0xdb080332,0x00000000,0x00000000,0x00000000}},	//   irgé, --, --, --, 
   {{0x6130003d,0x8afc0034,0xb89410de,0x2f1402d2}},	//   għli, _pięt, _ۇلاع, _hæga_, 
   {{0x8c200183,0x970000d1,0x00000000,0x00000000}},	//   _ফুকন_, تېتى, --, --, 
   {{0xba5401ec,0x395c0218,0x7544b610,0x7ae0f472}},	//   _اناع, _thws_, йноз, _ialt, 
   {{0x7ae0f473,0xed8c044e,0x25a8027a,0x7e6008ce}},	//   _halt, _ዝነብር_, ábla_, _úlpu, 
   {{0x7ae0f474,0x63ac01fa,0x310800d1,0xc8c87500}},	//   _kalt, grcn, қнап_, _خونن_, 
   {{0xf67800c8,0x2bf80490,0x69380003,0x2d4c00a2}},	//   _גאַמ, ्हतं_, nċen, lýet_, 
   {{0x7ae01f21,0x2f14032e,0x6ec800cd,0xa5f4009b}},	//   _malt, _næga_, स्फु, _геју_, 
   {{0x7ae0f475,0x69b8858c,0x6ec8190c,0x00000000}},	//   _lalt, _एमसी, स्नु, --, 
   {{0xceb80032,0x00000000,0x00000000,0x00000000}},	// [15720] һәң_, --, --, --, 
   {{0x7ae0f476,0x69cc01b8,0x00000000,0x00000000}},	//   _nalt, _äbeg, --, --, 
   {{0xed5801c0,0x6e4424ad,0xceb804b4,0x00000000}},	//   гож_, حنام, ләң_, --, 
   {{0x7ae0b0bf,0xe45c0793,0xa5c000e4,0x1168072d}},	//   _aalt, ifön_, ñóit, _خلجی_, 
   {{0x7ae0c33a,0x5c940953,0x20c0010b,0x2e4001d3}},	//   _balt, скія_, _эйям, _کہاہ, 
   {{0x7ae0f477,0x2f1401f7,0x00000000,0x00000000}},	//   _calt, _اِسر, --, --, 
   {{0x7ae0f478,0xfd280ffb,0x00000000,0x00000000}},	//   _dalt, _quìè_, --, --, 
   {{0x7ae00c8c,0x25f403ce,0x00000000,0x00000000}},	//   _ealt, एमसी_, --, --, 
   {{0xaab8140f,0x7d0c0e03,0x00000000,0x00000000}},	//   _مدار_, öase, --, --, 
   {{0x7ae0f479,0x75800014,0x00000000,0x00000000}},	//   _galt, ڈیوم, --, --, 
   {{0x853c0024,0x1ef808a8,0x18d40014,0x5ef8010f}},	//   krėt, אליע, _گِند_, אפיד, 
   {{0x7ae001a4,0x9484010b,0x00000000,0x00000000}},	//   _zalt, зырд, --, --, 
   {{0xfbbc00cd,0x00000000,0x00000000,0x00000000}},	//   ोऽयम, --, --, --, 
   {{0xdc3404ac,0x290400fb,0x68e0f47a,0x7ae00429}},	//   מאכט_, _hooa_, _haod, _xalt, 
   {{0x68e0f47b,0x2bd807f7,0x6d5800ef,0x00000000}},	//   _kaod, _मैसा, _ītan, --, 
   {{0x26b00046,0x6d5802b5,0x7f8401b9,0x41540006}},	//   _بەگز, _ūtan, قلرن, івас, 
   {{0x2904f47c,0x68e0f47d,0x67280175,0x00000000}},	// [15730] _mooa_, _maod, _kmfj, --, 
   {{0x4fc402a9,0x00000000,0x00000000,0x00000000}},	//   ясса, --, --, --, 
   {{0xc0f81772,0x2d4c00ee,0xdb0803b2,0x7d2801a9}},	//   ገበረ_, yýet_, jugá, аssа, 
   {{0x24a8015b,0x68e000a3,0xe054109c,0x290401f4}},	//   গ্রহ, _naod, _هیأت_, _nooa_, 
   {{0x7ae0f47e,0xdbc40108,0x00000000,0x00000000}},	//   _palt, сщеп, --, --, 
   {{0x3d94f47f,0x29040418,0x539c00c8,0x3178194f}},	//   _мигр, _aooa_, ניוו, _yupz_, 
   {{0x7ae0f480,0x290400ad,0x68e0f481,0x69380135}},	//   _valt, _booa_, _baod, rċen, 
   {{0x7ae0f482,0x8d8461b4,0x6280002d,0x98bc054e}},	//   _walt, _хурд, _ûnof, două_, 
   {{0x68e0f483,0x7ae0f484,0x00000000,0x00000000}},	//   _daod, _talt, --, --, 
   {{0xe3bc03d4,0x7ae00c86,0x853c0024,0x00000000}},	//   ইবাব, _ualt, krės, --, 
   {{0xcb68021a,0x68e00013,0xd7f802dd,0xf650007b}},	//   _امله_, _faod, _әуе_, بئة_, 
   {{0x39a4005f,0x68e001c3,0xf1a8158b,0xef600208}},	//   mēs_, _gaod, یازه_, _đọan_, 
   {{0xe72cf485,0x317801a6,0xb6a42772,0x39a400e2}},	//   _же_, _supz_, _дилл, lēs_, 
   {{0x2a5002d3,0xf7bc00d1,0x19540166,0x6b780a7c}},	//   _ምንባሮ, _ﻣﻪﻳﺪ, _таҗы_, ירשנ, 
   {{0x39a4005f,0x66e001ad,0xd7c400f1,0xddcc0432}},	//   nēs_, _कोटक_, _خوږه_, _ýeňd, 
   {{0xf8d82871,0x212800b5,0x1cb00327,0x5a280240}},	//   ढ़िय, _cmch_, དུས_, _እንትኾ, 
   {{0xaf04f486,0xef10004b,0xc0f80023,0x649839af}},	// [15740] опал, وټر_, ገበሮ_, _өтөр_, 
   {{0x212801c7,0x27e00321,0x6130031c,0xfbc000cc}},	//   _emch_, ækni_, dħlu, োটাত, 
   {{0xec78736a,0xab28004b,0x853c00c0,0x00000000}},	//   апе_, یستل_, prėt, --, 
   {{0x260802ab,0x39a400e2,0xfe7001d9,0xdb080162}},	//   ाहती_, dēs_, ردٕ_, vugá, 
   {{0x6bd4f487,0x68e00099,0x6538008f,0x61300003}},	//   تتار, _raod, סענד, għlu, 
   {{0x7c641607,0x68e06b31,0xca3800df,0xc0300092}},	//   سانل, _saod, _leĝe_, _በመቃወ, 
   {{0x68e0f488,0xddc0f489,0x21280042,0x9b400345}},	//   _paod, _обри, _ymch_, بنوو, 
   {{0x984c2c6f,0x2d880455,0x7e6001c3,0x685c0240}},	//   _ağır_, _itbe_, _ùlpa, _ቅትለት, 
   {{0x68e0b596,0x290400ad,0xdcac0131,0x8afc033f}},	//   _vaod, _vooa_, _جىق_, _chęc, 
   {{0xe5c4f48a,0x60c0013f,0x39a400de,0x00000000}},	//   осмо, ɑnmu, bēs_, --, 
   {{0xd5b46c88,0x29040e39,0xe3cc04c5,0xfaf80014}},	//   ося_, _tooa_, িয়াব, _دِلک_, 
   {{0x6ec807b6,0xb8647f05,0xa3780037,0x00000000}},	//   स्तु, _کامو, lvõi, --, 
   {{0x66e40364,0x257800de,0x00000000,0x00000000}},	//   _мода, _mīli_, --, --, 
   {{0x67280008,0x394800bc,0xd6cc0133,0xd7840244}},	//   _umfj, čase_, _لقه_, _بنوو_, 
   {{0x5a28067d,0x24e0015b,0xa6440cd2,0x00000000}},	//   _እንተኾ, যাবহ, _بخشن, --, 
   {{0x6e2001e4,0x673801e3,0xd54800f2,0xa3780022}},	//   ĝobl, lntj, _ولوو_, yvõh, 
   {{0xb7ecf48b,0x67386357,0xa37800c5,0x39a400e2}},	// [15750] जियम_, ontj, kvõi, zēs_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x57b42413,0x67382a28,0x0dc80212,0x212800ee}},	//   _आम्ह, intj, жучи_, _tmch_, 
   {{0x39a400e2,0xbca400e3,0xa378000d,0x00000000}},	//   vēs_, سمتي, evõi, --, 
   {{0x4fc4052f,0x6938025c,0x81bc00eb,0x00000000}},	//   _осра, rċel, _ইনি_, --, 
   {{0x6738f48c,0x39a4005f,0x00000000,0x00000000}},	//   jntj, tēs_, --, --, 
   {{0x3d940b96,0x3ea00037,0x00000000,0x00000000}},	//   _хибр, maht_, --, --, 
   {{0x6738f48d,0x39a400da,0xb7d80832,0x20c800dc}},	//   entj, rēs_, موعا_, ाभिध, 
   {{0x39a400e2,0x9a841fbe,0x7d0803ac,0x69dc01bf}},	//   sēs_, _дуел, _ioes, æper, 
   {{0x7d08f48e,0xa76000ee,0x3ea0002f,0xf62400db}},	//   _hoes, нкыд, naht_, здоо, 
   {{0x7d08f48f,0x80e000fe,0x59bc01ad,0x00000000}},	//   _koes, _পচন্, _एमिर, --, 
   {{0x673823f5,0x5ecc00fe,0x7d0801f4,0xc32800d9}},	//   antj, _হোমে, _joes, _גו_, 
   {{0x7d08f490,0xa878011a,0xde580092,0x94440022}},	//   _moes, _האנר, _ውሳኔው, ьҭиж, 
   {{0xe79404fb,0x3ea01d13,0x60cc00ef,0x984c008e}},	//   _راهک, jaht_, _abcm, _uğır_, 
   {{0x6260f491,0xe2a409f3,0xe71401ec,0x2324f492}},	//   евра, íðar_, _ءيىت_, чори_, 
   {{0x394c1590,0x7d08f493,0x64400034,0x00000000}},	//   noes_, _noes, _śnie, --, 
   {{0x80dc069f,0xee3846e8,0xa064ec43,0xa11000db}},	// [15760] _पसरे, әне_, зата_, روكت, 
   {{0xae780108,0x8eb400cf,0x00000000,0x00000000}},	//   ссах_, بەست, --, --, 
   {{0x7d0803bd,0xe1f4adae,0xee380640,0x394c9e7a}},	//   _boes, _егэ_, љне_, koes_, 
   {{0xdb180137,0x41d4012d,0x00000000,0x00000000}},	//   _aquà, _डैटस, --, --, 
   {{0x394c34b6,0x7054872b,0x7d080302,0xdbd425e4}},	//   does_, _رنسا, _does, jäät, 
   {{0xada4d6df,0xfe706886,0x6da4016c,0xab7800db}},	//   _нагл, ردە_, _нига, _ۇمرا_, 
   {{0x394c00a9,0xdb080793,0x2d88047e,0x7d08015d}},	//   foes_, dugä, _utbe_, _foes, 
   {{0x394c920e,0xa37800af,0x7d087f17,0x09dc0037}},	//   goes_, svõi, _goes, _मनीय, 
   {{0x9d4001b9,0x257800cd,0xac040b24,0x2a741291}},	//   _четд, _mūle_, _عذرو, _فداح, 
   {{0x673801a4,0xa0f000ef,0x00000000,0x00000000}},	//   untj, _sāļā_, --, --, 
   {{0x6738003b,0x394c01f5,0x00000000,0x00000000}},	//   rntj, boes_, --, --, 
   {{0x394c06ed,0xe8240276,0x00000000,0x00000000}},	//   coes_, _нфло, --, --, 
   {{0xdb180086,0x00000000,0x00000000,0x00000000}},	//   _ipuò, --, --, --, 
   {{0xa438001f,0x0cc81bd6,0x00000000,0x00000000}},	//   _የንግድ, रभुम, --, --, 
   {{0xe5f400e8,0x40e401ec,0x3ea00037,0x5fa402dd}},	//   _tëñë, мсағ, vaht_, _ﺷﻪﭘﺘ, 
   {{0x55b8011a,0x00000000,0x00000000,0x00000000}},	//   _המהו, --, --, --, 
   {{0x7d08f494,0x60cc4a43,0x93b400c0,0xd3a400c0}},	// [15770] _roes, _vbcm, _збыц, _прэп, 
   {{0x7d08f495,0xd4380375,0x2538063f,0x394c00d8}},	//   _soes, _מרחק_, ụndụ_, zoes_, 
   {{0x3ea0f496,0x9e641291,0x00000000,0x00000000}},	//   raht_, سائن, --, --, 
   {{0xdb080e78,0x394c00d8,0x3ea00036,0x7948010e}},	//   zugä, xoes_, saht_, _köwş, 
   {{0x3b08f497,0xdb1806ed,0x6b800472,0x7d080156}},	//   жело_, _aquá, gqog, _voes, 
   {{0x7d08f498,0x6284033f,0x6e3001ef,0x6ff8011a}},	//   _woes, ncjo, _řebř, _והשפ, 
   {{0x7d08f499,0x394cf49a,0xaa4000ee,0xfbbc00dc}},	//   _toes, toes_, кешл, ोऽहम, 
   {{0x7d0801ee,0xdb080267,0x9be402d5,0x00000000}},	//   _uoes, dugå, _нізк, --, 
   {{0xb8d40307,0x6284033f,0x257800e2,0x00000000}},	//   _जय_, kcjo, _mīlu_, --, 
   {{0x394c00a9,0xa680f49b,0xdbd4340f,0x00000000}},	//   soes_, кльд, räät, --, 
   {{0xdbd4023a,0x394c5886,0xf7701a4b,0x00000000}},	//   säät, poes_, _یات_, --, 
   {{0xdbd402f6,0x7948010e,0x290001e3,0xb8140798}},	//   päät, _böwş, ökat_, _одеј, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4374f40c,0xa37800e4,0x00000000,0x00000000}},	//   еуст, yvõv, --, --, 
   {{0x853c0064,0x00000000,0x00000000,0x00000000}},	//   prėp, --, --, --, 
   {{0xb7f0012c,0x00000000,0x00000000,0x00000000}},	//   _अछाम_, --, --, --, 
   {{0xb4d800c5,0x6130025c,0x00000000,0x00000000}},	// [15780] ठजी_, għlq, --, --, 
   {{0xdb180077,0xca3800df,0xee3802e8,0xdfcc06c2}},	//   _opuñ, _leĝa_, онз_, شيم_, 
   {{0xada400c7,0x6ce4454e,0xdce801e4,0x00000000}},	//   фаел, діле, ŭiĝi, --, 
   {{0xdcac5841,0xca380115,0x00000000,0x00000000}},	//   لىم_, _neĝa_, --, --, 
   {{0xdb1809c2,0xe0dc02e2,0xdca0300e,0x7bcc0ba1}},	//   _apuñ, _ekòs_, тачи, çaup, 
   {{0x29881d39,0xa3780254,0x00000000,0x00000000}},	//   осио_, mvõt, --, --, 
   {{0x18340092,0x29640063,0xb90c01e1,0x2b4c0200}},	//   _እስከማ, мњив, _àlọ_, rofc_, 
   {{0xec140132,0xa3dc0037,0x5d6401a9,0x6da401fe}},	//   _قوزد, _धईल_, _жисм_, _ниҳа, 
   {{0x6b8401d5,0xdca000d8,0xbcfc0051,0xa3780254}},	//   _آشرل, _шати, _khũn, nvõt, 
   {{0x7c640058,0x79480432,0x39480010,0xa3780254}},	//   _ساقل, _röwş, časa_, ivõt, 
   {{0x6fc8015b,0x290011ab,0xdb08007c,0x7c2c1427}},	//   রিয়ে, ökas_, ttgö, úarv, 
   {{0x1cb0025c,0x249c0008,0xad600150,0x00000000}},	//   དུག_, úum_, ндiк, --, 
   {{0x69c8f49c,0x00000000,0x00000000,0x00000000}},	//   ltfe, --, --, --, 
   {{0xbcfc01fb,0xdb0801e6,0x61200254,0x00000000}},	//   _nhũn, stgö, _kõlg, --, 
   {{0x8654074d,0x6284012d,0x00000000,0x00000000}},	//   _яккх, rcjo, --, --, 
   {{0x6d580374,0x628404cc,0x6120000d,0x69c8002f}},	//   _ëtah, scjo, _mõlg, itfe, 
   {{0x246400aa,0x69c8f49d,0x34440117,0x00000000}},	// [15790] _ډاکټ, htfe, _зӯри_, --, 
   {{0x69c803cd,0xbcfc0208,0x00000000,0x00000000}},	//   ktfe, _chũn, --, --, 
   {{0x7cd82e3f,0xb9000003,0x200c00af,0x3d941fbd}},	//   змер_, _སྲ_, ägib_, хиер, 
   {{0x80d8015b,0x69c8f49e,0xddcc00a2,0x0ca80124}},	//   ডাঙ্, dtfe, _ýeōd, ҿтәи_, 
   {{0xca38008f,0xfc1401c6,0x6b5400e4,0xcbc4131e}},	//   _reĝa_, эмдэ, hâgu, نزوي, 
   {{0x69c8f49f,0xa3d421bd,0xfaa4f4a0,0x4fc42ba5}},	//   ftfe, _सहन_, хако, _جەكە, 
   {{0xdb20006c,0x69380327,0x00000000,0x00000000}},	//   _یوری, nċew, --, --, 
   {{0x2bd804af,0x00000000,0x00000000,0x00000000}},	//   _मैका, --, --, --, 
   {{0xb6a400d1,0xdb080332,0x00000000,0x00000000}},	//   нипл, argá, --, --, 
   {{0x7c90069c,0x29000267,0xf98402dd,0xfd480055}},	//   _ዝበሃል_, ökar_, _كەتۋ_, _romṇ, 
   {{0x6d5800b0,0x69c80175,0x853c00c0,0x00000000}},	//   _ūtai, ctfe, msėj, --, 
   {{0x88940124,0x64400034,0x853c00c0,0x00000000}},	//   _аицх, _śnia, lsėj, --, 
   {{0x79800032,0x74142073,0xfbcc00fe,0xc2e80154}},	//   _hulw, روسا, লিকত, খানি_, 
   {{0x66e0f4a1,0x5ecc00bd,0x7980f4a2,0x00000000}},	//   _боша, _হোসে, _kulw, --, 
   {{0x06a00075,0xdbd4023a,0xe1f4030d,0x24880332}},	//   _ﺋﯘﻧﯩ, _hääp, нгр_, éimí_, 
   {{0x7980f4a3,0x45340124,0x6ec0012c,0xdbd416ca}},	//   _mulw, _ахьт, _लाहु, _kääp, 
   {{0x313c0201,0x7bdc025a,0x09dc0882,0x7980f4a4}},	// [157a0] _የእግዚ, _âsuh, _मन्य, _lulw, 
   {{0xb9006d7e,0x69380327,0xdd8c00f1,0x00000000}},	//   _སི_, rċei, څول_, --, 
   {{0xe0dc033b,0x69c8893b,0x160c1d8a,0x387c03cb}},	//   _djòb_, xtfe, ाहिर_, _ogwr_, 
   {{0xfa24009e,0x387c0142,0x6ec00073,0x6d240276}},	//   যপাল_, _ngwr_, _लावु, эдез, 
   {{0xfb84d968,0x80c80574,0x257800cd,0x2f1408a5}},	//   نگلی, _हॉटे, _mūla_, _lægi_, 
   {{0x7980d121,0x853c02d5,0x69c8168c,0x160c1fc4}},	//   _bulw, gsėj, ttfe, ाहार_, 
   {{0x69c80158,0x2f1402d2,0x6f0c01ef,0x00000000}},	//   utfe, _nægi_, _iobc, --, 
   {{0x7980073c,0x61380724,0x612000af,0xad640214}},	//   _dulw, mälä, _võlg, _سازه, 
   {{0x61380598,0xeb34525b,0x6f0c0014,0x0ae40124}},	//   lälä, _كىرد, _kobc, _ибаҟ, 
   {{0x79802b92,0x2ca494da,0x6f0c3586,0x612000af}},	//   _fulw, laod_, _jobc, _tõlg, 
   {{0x6138578c,0x798004ba,0x6f0cf4a5,0x69b803ba}},	//   nälä, _gulw, _mobc, _एमटी, 
   {{0xca3800df,0x6f0c014f,0x61200254,0xa3780254}},	//   _heĝo_, _lobc, _kõle, dvõr, 
   {{0x61200254,0xa3780254,0x257800ef,0x853c0064}},	//   _jõle, evõr, _dūla_, lsėk, 
   {{0x61380891,0x6120007d,0x27e4f4a6,0x6f0c0455}},	//   kälä, _mõle, _ison_, _nobc, 
   {{0x15f0900f,0x2164004e,0x2ca40254,0x613801f4}},	//   _مسيح, етаг, kaod_, jälä, 
   {{0xca38008f,0x6138008e,0x8afc0210,0x00000000}},	//   _leĝo_, dälä, _cięz, --, 
   {{0x27e4f4a7,0xdb1800fd,0x3f9c0066,0x656c1ba6}},	// [157b0] _json_, _uquç, èwu_, mmch, 
   {{0x26dcf4a8,0x20040bb8,0x6f0c0421,0xca38010f}},	//   neto_, ćni_, _cobc, _neĝo_, 
   {{0xd3580375,0x612000c5,0x656c009f,0xf2d0010f}},	//   _איזי_, _põld, omch, _דעי_, 
   {{0x26dcf4a9,0x27e4622a,0x6f0c02f0,0x5fa007d2}},	//   heto_, _oson_, _eobc, _مەرم, 
   {{0x26dcf4aa,0x27e4016b,0x4b880220,0x49044709}},	//   keto_, _nson_, ейін_, वानो_, 
   {{0x26dcf4ab,0x3ce80fb7,0x60dc0784,0x6f0c0427}},	//   jeto_, žav_, leqm, _gobc, 
   {{0x27e40134,0x26dc96c9,0x61380724,0x853c0024}},	//   _ason_, deto_, cälä, rsėj, 
   {{0x8d741e0e,0x61200037,0xdbd4005b,0xf56c0092}},	//   _ماقا, _hõlb, _pääp, በለዚያ_, 
   {{0x26dcf4ac,0x7980014b,0x612000c5,0x853c0064}},	//   feto_, _wulw, _kõlb, psėj, 
   {{0x26dcf4ad,0x79801418,0x60dc0455,0xdbd401f4}},	//   geto_, _tulw, heqm, _vääp, 
   {{0xc7640aaf,0x27e4f4ae,0xa37800e4,0x00000000}},	//   دايى, _eson_, yvõr, --, 
   {{0x3834f4af,0xc984f4b0,0x2f1408a5,0xdc1003b9}},	//   _инер, _суфи, _vægi_, lğır, 
   {{0x26dcf4b1,0xfd580ca8,0xd83805f5,0x6ec00406}},	//   beto_, _bibẹ, _ээж_, _लालु, 
   {{0x26dcf4b2,0x656c0218,0x61380724,0x36040133}},	//   ceto_, amch, yälä, _لوتف, 
   {{0x69380135,0xa3780254,0x00000000,0x00000000}},	//   rċev, tvõr, --, --, 
   {{0x6f0cf4b3,0x21640484,0xddc40034,0x2578f4b4}},	//   _sobc, виси_, _wyjś, _tūla_, 
   {{0xa3780254,0x442400ec,0x2ca40254,0xaec400d8}},	// [157c0] rvõr, _ٽريف, vaod_, кбал, 
   {{0x6138f4b5,0xb60401e1,0x8afc0034,0xa3780037}},	//   tälä, _gbáà, _więz, svõr, 
   {{0xca3800c8,0xdee0f4b6,0x60dc0455,0x61200254}},	//   _reĝo_, рохи, beqm, _sõle, 
   {{0x26dcf4b7,0x6120007d,0x61380724,0xca3800df}},	//   zeto_, _põle, rälä, _seĝo_, 
   {{0x61380598,0xab2806dc,0x26dc003c,0x6f0c047e}},	//   sälä, мода_, yeto_, _tobc, 
   {{0x27e41529,0x26dcf4b8,0x656c022e,0x61380958}},	//   _rson_, xeto_, zmch, pälä, 
   {{0x7b1c0ba1,0x613800fd,0x27e40072,0x6da40a0e}},	//   _tèun, qälä, _sson_, _шива, 
   {{0x26dcf4b9,0x27e41529,0xdb080798,0x00000000}},	//   weto_, _pson_, nsgê, --, 
   {{0x26dcf4ba,0x6d40054e,0x27e401a9,0x97c0e42d}},	//   teto_, mnoa, _qson_, لقيو, 
   {{0x6d4000f3,0x00000000,0x00000000,0x00000000}},	//   lnoa, --, --, --, 
   {{0x5eb80375,0x85741086,0xb0e00037,0x00000000}},	//   וזיק, ллох, _पसंग, --, 
   {{0x1ccc4933,0x69d8f4bb,0x439455d9,0xe3bc0054}},	//   ྱུར_, _ipte, ламс, tuñ_, 
   {{0x26dcf4bc,0x656cf4bd,0x6d40f4be,0x27e40115}},	//   peto_, rmch, inoa, _uson_, 
   {{0x26dc0184,0x6d400254,0xa49000f2,0x2a6802d2}},	//   qeto_, hnoa, دیکت, _úbbs_, 
   {{0x09e0031c,0x20c4361e,0x925801c0,0x45d40026}},	//   _སརྦ_, ксаг, варт_, _сойс, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa27c02d3,0x1ccc031c,0xa3d45373,0x00000000}},	// [157d0] ካሕክሕ_, ྱུལ_, _सहि_, --, 
   {{0x4fc41677,0x5fb4012d,0x00000000,0x00000000}},	//   јста, ेंबल, --, --, 
   {{0xb8e40135,0x81bc02f5,0x6d400270,0x2f14032e}},	//   _ཏྰ_, _ইনক_, fnoa, _nægu_, 
   {{0xa3d40490,0xa3c45219,0x6d40002d,0x60dc047e}},	//   _सहा_, _उमा_, gnoa, qeqm, 
   {{0x69cc0793,0x00000000,0x00000000,0x00000000}},	//   _äbej, --, --, --, 
   {{0x6d40f4bf,0x00000000,0x00000000,0x00000000}},	//   anoa, --, --, --, 
   {{0x1cb82ab5,0x69d800d8,0x397835c7,0x97301d0a}},	//   _يارب_, _cpte, нсию_, یکتا, 
   {{0xa964f4c0,0x2dd8010f,0x6d4015c0,0x00000000}},	//   лища_, _אַמב, cnoa, --, 
   {{0x9ba00075,0x69d8127b,0x6ec800e1,0x7bf80166}},	//   _ئەتى, _epte, स्कु, _янар_, 
   {{0x3cec039a,0x00000000,0x00000000,0x00000000}},	//   _haev_, --, --, --, 
   {{0x1fcc015b,0x9f986775,0x3cec000d,0x18b001af}},	//   রিটস, _häät_, _kaev_, _кәпр, 
   {{0x2f1400fc,0x38b807c5,0x3cec01d5,0xb4bc05dc}},	//   _hægt_, _dürà_, _jaev_, आले_, 
   {{0x78a8876a,0x9f980108,0x6938031c,0x00000000}},	//   maev, _jäät_, rċet, --, 
   {{0x6380f4c1,0xb6a4052f,0x78a8f4c2,0xf74407d8}},	//   сгра, _сикл, laev, _щело, 
   {{0x321c0232,0x7b1c067c,0x200c0037,0x55c0f4c3}},	//   áty_, _rèul, ägin_, _тайғ, 
   {{0x1ccc1efe,0x78a8f4c4,0xafe4f4c5,0x61980023}},	//   ྱུས_, naev, лобл, _ጉጅላዊ_, 
   {{0x321c0232,0x1cb0031c,0x9f9801f4,0xdb0c00a2}},	// [157e0] šty_, དུན_, _näät_, _şeýe, 
   {{0x6938003d,0x75340122,0x78a8003a,0x2f14032e}},	//   nċer, _hmyz, haev, _nægt_, 
   {{0x78a8f4c6,0x6d40f4c7,0xdef00023,0x63b8031c}},	//   kaev, tnoa, _ሃበኒ_, ġune, 
   {{0xe45c04f3,0xdee073e3,0xed582db0,0xa018002f}},	//   mför_, _қоси, رشات_, _pföt, 
   {{0x6d40f4c8,0x28a40116,0x6938025c,0x78a80205}},	//   rnoa, ңшиг, kċer, daev, 
   {{0x68380158,0x6d48f4c9,0xdb0800cf,0x7c640a11}},	//   _lødø, éfab, nsgè, جامل, 
   {{0xe45c04f3,0xe2a408a7,0xbdc801ed,0xd7f402dd}},	//   nför_, íðir_, _لگنے_, ғуы_, 
   {{0x612000af,0x3cec0139,0xfcc0008e,0xa01801e3}},	//   _kõla, _gaev_, _дәшм, _iför, 
   {{0xeb98013e,0x2b9001b9,0x00000000,0x00000000}},	//   _чиз_, _ایتس, --, --, 
   {{0x47342b39,0x3cec0200,0xe45c007c,0x00000000}},	//   рнос, _zaev_, kför_, --, 
   {{0x6aa80d8d,0x78a828e5,0x00000000,0x00000000}},	//   maff, baev, --, --, 
   {{0x6aa80af5,0x9e740302,0xdb08f4ca,0xe45c01e6}},	//   laff, טגיה_, rrgå, dför_, 
   {{0xaa840432,0x7d0c005b,0x00000000,0x00000000}},	//   _geýý, öasi, --, --, 
   {{0x6aa8f4cb,0xa01801e6,0x56907de7,0xc0e00023}},	//   naff, _oför, _лашт, _ሓቢራ_, 
   {{0x67386c9a,0x212400f1,0x9f4c00ae,0x614000d1}},	//   mitj, هيسی_, ígí_, مىسە, 
   {{0x6738f4cc,0x6aa8f4cd,0x5184f4ce,0x95c43e4f}},	//   litj, haff, сура, _суша_, 
   {{0x66180998,0x3cecf4cf,0x67380549,0xf28401d9}},	// [157f0] lytk, _raev_, oitj, _چھِو_, 
   {{0x6738f4d0,0x6aa8f4d1,0x78a85a7e,0x9e4817a0}},	//   nitj, jaff, zaev, нчез_, 
   {{0x6aa8198f,0xc0c45b87,0x61f405b1,0xddc400e2}},	//   daff, _вәзи, _urxl, _izjū, 
   {{0xc0e0044e,0x657c094a,0x6738f4d2,0x66182a1f}},	//   _ሓቢሩ_, _jiqh, hitj, iytk, 
   {{0x6aa8f4d3,0x63ac00c6,0x78a8f4d4,0x6618f4d5}},	//   faff, nscn, vaev, hytk, 
   {{0x6aa8f4d6,0x657cf4d7,0xab600131,0x67380023}},	//   gaff, _liqh, قۇقى, jitj, 
   {{0x2f14f4d8,0xdb08f4d9,0x6738f4da,0x6d48004a}},	//   _vægt_, nsgé, ditj, éfac, 
   {{0x657c401f,0x6aa80869,0xdb0801b8,0x645c022e}},	//   _niqh, aaff, lugü, _oyqi, 
   {{0x78a81fc0,0x6738f4db,0x6aa804ba,0x683803cd}},	//   raev, fitj, baff, _rødø, 
   {{0x673800d2,0x6618002d,0x78a8f4dc,0x996402dd}},	//   gitj, fytk, saev, _өтел, 
   {{0x75440474,0xf5048372,0x645c02d1,0x657c047e}},	//   иноз, азно, _ayqi, _biqh, 
   {{0x7bdc025a,0x67380af9,0xe574084c,0xaa8400a2}},	//   _âsus, aitj, изэ_, _teýý, 
   {{0x657c00fb,0x289800c8,0x67380023,0x00000000}},	//   _diqh, _סיסא, bitj, --, 
   {{0x66189637,0xa3c40c2e,0xdc7802d3,0xa3d40550}},	//   bytk, _उमर_, እስሳር_, _सहर_, 
   {{0x657cf4dd,0x71580107,0x00000000,0x00000000}},	//   _fiqh, врас_, --, --, 
   {{0xe45c0628,0x6aa8f4de,0x6120000d,0x6938031c}},	//   rför_, zaff, _põla, nċep, 
  
   {{0x63b01cd1,0x94740014,0x6aa80a49,0xa01801e3}},	// [15800] _мәрх, _دگدا, yaff, _sför, 
   {{0x657c0912,0x612000af,0xe45c0267,0x63b80784}},	//   _ziqh, _võla, pför_, šunc, 
   {{0x6aa807d6,0x657cf4df,0xac8400c0,0xa2b8011a}},	//   vaff, _yiqh, агел, _במיט, 
   {{0xeb98f4e0,0x657c02b9,0x6aa895e9,0x67389b34}},	//   вид_, _xiqh, waff, zitj, 
   {{0x6aa82252,0x6738f4e1,0xeb04f4e2,0x0bf40a89}},	//   taff, yitj, ичко, сплю, 
   {{0x6d8802d3,0x1ccc0327,0x2f1401bf,0x853c0153}},	//   _ንጐይታ_, ྱུུ_, _vægs_, lsėt, 
   {{0x19a4f4e3,0x8884dd55,0x6738f4e4,0xfe90a268}},	//   атып_, میان, vitj, _رینج, 
   {{0xa3d41094,0x040c009e,0x6738f4e5,0x66180108}},	//   _सहल_, হনতী_, witj, vytk, 
   {{0x6738f4e6,0x6aa8013c,0x4734f4e7,0x2fd00267}},	//   titj, paff, йнис, ntyg_, 
   {{0x657c0912,0xd7f40107,0x00000000,0x00000000}},	//   _siqh, руъ_, --, --, 
   {{0x6738f4e8,0x9810034c,0x61e401d4,0x994001d9}},	//   ritj, مبیا, xwjl, _ژہى۪, 
   {{0x6738f4e9,0x2d9801c7,0x66180210,0xd7c435aa}},	//   sitj, ippe_, rytk, دویه_, 
   {{0xc0c4052f,0x6738f4ea,0xe0dc0100,0x3fd40220}},	//   ҙәни, pitj, _djòl_, _ﺟﻴﺎﻧ, 
   {{0x3cfc05f9,0x673802d3,0x6618f4eb,0x6ec0202e}},	//   _रोने_, qitj, pytk, _लागु, 
   {{0xc2e80183,0x657c0455,0xb87c01e4,0xa0a40798}},	//   খালি_, _tiqh, meŭa, ишал, 
   {{0x43940139,0x2018036e,0x853c0064,0x9104004e}},	//   _лаис, tyqi_, gsėt, очуд, 
   {{0x115402bf,0xbed801c0,0xd01001d3,0x73c002dd}},	// [15810] ікую, лдах_, ولِ_, _нәре, 
   {{0x33280354,0x3948151c,0x64a405f9,0x6ebc012d}},	//   chbx_, časi_, _ख़ुश, शलगु, 
   {{0xe2a409f3,0x2d98037e,0x9e040006,0x00000000}},	//   íður_, gppe_, шчал, --, 
   {{0xe45c025a,0x0d849d2c,0x00000000,0x00000000}},	//   ngöo_, ілін, --, --, 
   {{0x5f7404d3,0x2d980bdf,0x06ac0154,0x00000000}},	//   _ناسر, appe_, _খানি, --, 
   {{0x51f40e3f,0x8ccc1d15,0xdb0803b2,0x00000000}},	//   _اسیر, _हाथो, vugó, --, 
   {{0xd2b80375,0x00000000,0x00000000,0x00000000}},	//   בלות_, --, --, --, 
   {{0xe0dc02bd,0xccec036b,0xbd4400db,0x00000000}},	//   _akòz_, _ўқ_, _اپرى, --, 
   {{0x2bd8424b,0xe8f4f4ec,0x3cfc033f,0x6938031c}},	//   _مالک_, слы_, _रोये_, rċep, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdce40055,0x46d8000d,0x00000000,0x00000000}},	//   _nujī, _बउरह, --, --, 
   {{0xe45c007c,0x00000000,0x00000000,0x00000000}},	//   rgön_, --, --, --, 
   {{0xca3801e4,0x00000000,0x00000000,0x00000000}},	//   _reĝi_, --, --, --, 
   {{0x2d9821e3,0xded00092,0x00000000,0x00000000}},	//   yppe_, _ከቀኑ_, --, --, 
   {{0xe294f4ed,0x7164007b,0x473404f2,0xd9f40456}},	//   сас_, مارك, _برنز, ंटित_, 
   {{0xb0340131,0x00000000,0x00000000,0x00000000}},	//   مىزغ, --, --, --, 
   {{0x2164f4ee,0xed58020a,0xa4a0067c,0x09d401bc}},	// [15820] сити_, қод_, _çòap, _दह्य, 
   {{0xd9f410f7,0x2fd001e6,0x395c002f,0xe818000d}},	//   ंटात_, rtyg_, _lkws_, _फअसा_, 
   {{0x2fd005e4,0x6120000d,0x200c03b2,0xa73800df}},	//   styg_, _kõll, øgir_, נגעכ, 
   {{0x395c0211,0xf3f4025c,0x07440046,0x6120000d}},	//   _nkws_, _བློད_, ﺘﯩﯔ_, _jõll, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa4980086,0xe7e8000d,0x18b40124,0x00000000}},	//   ijòr, _जईहा_, әгьы_, --, 
   {{0x2d880381,0x6cd400f1,0x984c06be,0x6cc400db}},	//   _iube_, _دقرا, _aşır_, _ыйба, 
   {{0x5ecc0f22,0xdb0801bf,0xc6203f7e,0x290008a9}},	//   _হোটে, yrgø, मन्य_, ıka_, 
   {{0x2d88124c,0x8afc0034,0x96d00d0a,0xf3fc00eb}},	//   _kube_, _chęt, ब्लॉ, ঁহার_, 
   {{0x2d889dce,0x0df40092,0x00000000,0x00000000}},	//   _jube_, _ግብፅ_, --, --, 
   {{0x1ccc003d,0x2d886466,0x00000000,0x00000000}},	//   ྱུག_, _mube_, --, --, 
   {{0x2b5c0790,0x2d880f85,0xdce40055,0x00000000}},	//   _kktc_, _lube_, _sujī, --, 
   {{0xb864f4ef,0x9294f4f0,0xb1440014,0xf7d00220}},	//   _بامو, зарц, ےیَم_, _ﻛﻪﻣﻪ, 
   {{0x2d88f4f1,0x5334f4f2,0x00000000,0x00000000}},	//   _nube_, черт, --, --, 
   {{0x15441fbe,0xa4240395,0x00000000,0x00000000}},	//   _нејм, _гьол, --, --, 
   {{0x2d88f4f3,0xa05800dd,0x3f14f4f4,0x00000000}},	// [15830] _aube_, اؤزر_, одас, --, 
   {{0x2d88f4f5,0x5e840022,0x00000000,0x00000000}},	//   _bube_, суаз, --, --, 
   {{0xd010021a,0xe7e8068f,0x612000af,0x99840cf4}},	//   ولې_, _जैसा_, _hõlm, _žiži_, 
   {{0x2d88f4f6,0x7bf80137,0x00c80145,0x20c406ed}},	//   _dube_, инер_, _өлүк_, _усог, 
   {{0x60cc7acd,0x00000000,0x00000000,0x00000000}},	//   _iccm, --, --, --, 
   {{0x1ccc0c99,0x3f98009d,0x6d8800e4,0x9f2400e5}},	//   ྱུང_, _itsu_, _ẽkũj, _ايسے_, 
   {{0x60cc02d0,0x395c002f,0x4994004e,0x00000000}},	//   _kccm, _pkws_, пшыт, --, 
   {{0xf8b8009d,0x00000000,0x00000000,0x00000000}},	//   рөж_, --, --, --, 
   {{0x26cc01ee,0x3f980a73,0xe0dc007f,0x3b880139}},	//   _bcfo_, _jtsu_, _ajòk_, _төеп_, 
   {{0x3cfc06ab,0xdb2001b9,0xab60313e,0x8f9c0677}},	//   _रोते_, _عوضی, _قۇنى, איזי, 
   {{0x36686145,0x6120007d,0x6d585e94,0x3ea001ab}},	//   рано_, _põll, _ítac, ibht_, 
   {{0xe0dc007f,0xf3f4031c,0xc8c80214,0x3f980205}},	//   _djòk_, _བླུད_, _هومن_, _otsu_, 
   {{0x3f98f4f7,0x87c000c7,0xe4540212,0x61200037}},	//   _ntsu_, _зҩыз, жжя_, _võll, 
   {{0x60cc1635,0x998400e5,0x00000000,0x00000000}},	//   _accm, lynő_, --, --, 
   {{0x61200037,0xf67800df,0x00000000,0x00000000}},	//   _tõll, _דאַמ, --, --, 
   {{0x2d88f4f8,0x61200037,0x00000000,0x00000000}},	//   _rube_, _hõlj, --, --, 
   {{0x2d88f4f9,0x3158001f,0x6eb4007b,0x47340345}},	// [15840] _sube_, _ለእግዚ, قصائ, _برۆز, 
   {{0xdfcc2781,0xdd8c0acb,0x2d88003a,0x69cc1445}},	//   ئيل_, چول_, _pube_, _åbeg, 
   {{0x3f980265,0xdd8ca413,0xee38026a,0x716800f0}},	//   _etsu_, نول_, јне_, _ванг_, 
   {{0xed581de1,0x2d880a73,0xdca06c4d,0x1ccc0327}},	//   шое_, _vube_, даци, ྱུཊ_, 
   {{0x0a9400d4,0x00000000,0x00000000,0x00000000}},	//   палю, --, --, --, 
   {{0x2d88f4fa,0xada4f4fb,0x6da43f77,0x7c2c030a}},	//   _tube_, _магл, _мига, ùara, 
   {{0x60cc02d0,0xe9700014,0xace80117,0x00000000}},	//   _yccm, ونتھ, _кмва_, --, 
   {{0x48147858,0x9960021f,0xf1e0033f,0xeb9804c2}},	//   змис, мтыл, _पहनन, _виа_, 
   {{0xfbd00316,0xaad000bc,0x00000000,0x00000000}},	//   _समयम, _सापक, --, --, 
   {{0x764c00dc,0x00000000,0x00000000,0x00000000}},	//   _śaya, --, --, --, 
   {{0x6120007d,0x7ccc00e5,0xc3240240,0x00000000}},	//   _sõlm, sőrő, _ታሪኻዊ, --, 
   {{0xe4e410f5,0xda6c0014,0xe708036b,0x00000000}},	//   ціон, _شُن_, اتکن_, --, 
   {{0x29040751,0x9484f4fc,0x39480552,0xf40c03e6}},	//   _inoa_, дырд, čast_, ۆڤی_, 
   {{0x69cc0793,0x98a00024,0xe1f06f04,0xd70001d5}},	//   _äbes, ėją_, وسز_, _озчи, 
   {{0x69cc003b,0x00000000,0x00000000,0x00000000}},	//   _åbed, --, --, --, 
   {{0x7e740124,0x00000000,0x00000000,0x00000000}},	//   ҧгах, --, --, --, 
   {{0x2284f4fd,0x00000000,0x00000000,0x00000000}},	// [15850] _мунг, --, --, --, 
   {{0xdb080793,0x5e2400db,0x21c8084c,0x61200254}},	//   lugö, يعاق, _кымп_, _kõlk, 
   {{0x290403a0,0x0c98063f,0x937847ed,0x61200254}},	//   _onoa_, _ịhụl, _بصير_, _jõlk, 
   {{0x29040418,0x6120000d,0x00000000,0x00000000}},	//   _nnoa_, _mõlk, --, --, 
   {{0xe0dc0086,0x3a300419,0x853c00c0,0x00000000}},	//   _ibò_, _ťzp_, mpėd, --, 
   {{0x2904f4fe,0xdef8f4ff,0xdb180086,0x7b1c0ba1}},	//   _anoa_, _тым_, _aquò, _nèut, 
   {{0x38680cf4,0x00000000,0x00000000,0x00000000}},	//   _šar_, --, --, --, 
   {{0x1ba801d3,0x61300064,0x00000000,0x00000000}},	//   _نائٹ_, _užlė, --, --, 
   {{0x853c0953,0x01d02158,0xdb080793,0xe0dc0241}},	//   ipėd, াবিদ, dugö, _mbò_, 
   {{0xc61400bd,0x29049e0d,0xaad071a3,0x00000000}},	//   াননা_, _enoa_, _सायक, --, 
   {{0xf9f8024e,0x00000000,0x00000000,0x00000000}},	//   _دفاع_, --, --, --, 
   {{0x39480784,0x67282c6a,0xe0dc01e1,0x85940124}},	//   _ñas_, _elfj, _nbò_, ьшьц, 
   {{0xe72ceec3,0x399002d2,0x249c59aa,0x69cc0a43}},	//   _зе_, _hás_, ñuma_, _äber, 
   {{0xe294f500,0xe0dc02e2,0x21280c86,0xd5a001b9}},	//   зар_, _abò_, _alch_, _قلتی, 
   {{0xd0043276,0x00000000,0x00000000,0x00000000}},	//   रम्भ_, --, --, --, 
   {{0x3990f501,0xf8bc3cc3,0x2d9c0055,0x00000000}},	//   _más_, ोलिय, _įte_, --, 
   {{0x212801c3,0x26ec015b,0x3990f502,0x00000000}},	// [15860] _dlch_, জারো_, _lás_, --, 
   {{0x1f600120,0x21281196,0x25780171,0x00000000}},	//   екум, _elch_, _dūlu_, --, 
   {{0x39900745,0x3da400d4,0xd0e800e5,0x757800b8}},	//   _nás_, дріб, _وکرم_, _ṣṭha, 
   {{0xe0dc0cad,0x9f9800a2,0x8afc0210,0x7d0c007c}},	//   _gbò_, _häýt_, _okęc, öasp, 
   {{0x06ac00eb,0x6b64004e,0x00000000,0x00000000}},	//   _খাসি, пкда, --, --, 
   {{0x5bc004a9,0x39900597,0xe7f0000d,0x00000000}},	//   رقىل, _bás_, _अनबा_, --, 
   {{0x2d9c025a,0xfd4c01f2,0x399000c6,0x3c1400b8}},	//   _ïte_, _jehọ, _cás_, _aśvā_, 
   {{0x079815ed,0x3990f503,0xd0200154,0xada40b01}},	//   овић_, _dás_, _নেয়_, _маҳл, 
   {{0x6d4012cf,0x00000000,0x00000000,0x00000000}},	//   mioa, --, --, --, 
   {{0x6d40f504,0x399000c6,0xaae00248,0x85b800d4}},	//   lioa, _fás_, _àjàò_, олос_, 
   {{0x3990f505,0x09e00327,0x26ec00cc,0xab6000d1}},	//   _gás_, _སརྒ_, জালো_, _قۇچى, 
   {{0xdef0044e,0x6d40f506,0x69c80083,0x00000000}},	//   _ግድን_, nioa, mufe, --, 
   {{0x69c8f507,0x602001e1,0x5efc00dc,0x83a400c7}},	//   lufe, _mímú, रयम्_, ьынҵ, 
   {{0x612000af,0xfc3801e4,0xd6cc1ec7,0x490492c1}},	//   _tõlk, _zeŭs_, _مقه_, वाको_, 
   {{0xd6d80375,0x69c8f508,0x6d400108,0x41846171}},	//   _החול, nufe, kioa, дтағ, 
   {{0x9f48026c,0x46d80882,0x6d40009d,0x638406af}},	//   _escì_, ब्रह, jioa, génè, 
   {{0x6d40f509,0x69c8f50a,0xca3808b0,0xb60002d2}},	// [15870] dioa, hufe, ﺗﺎﺭ_, _óára, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d4075ac,0x69c81d0e,0x00000000,0x00000000}},	//   fioa, jufe, --, --, 
   {{0x3990f50b,0x6d400a27,0x69c802d2,0x00000000}},	//   _rás_, gioa, dufe, --, 
   {{0x39900332,0x00000000,0x00000000,0x00000000}},	//   _sás_, --, --, --, 
   {{0x39900122,0x69c8022f,0x614001e1,0x6d40000f}},	//   _pás_, fufe, _fìlè, aioa, 
   {{0x6d408ed6,0x29d00d2f,0xdb081d0e,0x69c802d2}},	//   bioa, نيوس, gsgá, gufe, 
   {{0x3990076f,0x6d4000a8,0xc2e8015b,0x63b80327}},	//   _vás_, cioa, খাটি_, ġunj, 
   {{0x69c80175,0x69dc003a,0x00000000,0x00000000}},	//   aufe, çper, --, --, 
   {{0x69c8f50c,0xa3d42052,0x7d080165,0x624001a9}},	//   bufe, _सहज_, _hnes, _gеog, 
   {{0x69cc0793,0xdb180309,0x7bd8002f,0xaad00bae}},	//   _äbep, _uquñ, ltwu, _सातक, 
   {{0xc328f50d,0x46380006,0xe45c03e0,0xd1c00092}},	//   _דו_, ячыя_, lföy_, ስገባ_, 
   {{0x394cf50e,0x7bd8f50f,0xd90c00dd,0x7d08f510}},	//   mnes_, ntwu, _لیں_, _mnes, 
   {{0x6d40152d,0x394cf511,0x81c800cc,0x00000000}},	//   zioa, lnes_, োবন_, --, 
   {{0x394cf512,0x7bd80036,0x7c3403b9,0x00000000}},	//   ones_, htwu, _əzra, --, 
   {{0x394cf513,0x7d0804ba,0x7ae00175,0x73e401b9}},	//   nnes_, _nnes, _lblt, _жоиз, 
   {{0xef18f514,0x1ccc08ea,0xa0644170,0x394cf515}},	// [15880] ома_, ྱུན_, дата_, ines_, 
   {{0x7d08f516,0x394cf517,0x9f48f518,0xaad007b7}},	//   _anes, hnes_, _uscì_, _साधक, 
   {{0x394cf519,0x6d40f51a,0xf1e000af,0x88d4002b}},	//   knes_, tioa, _पहिन, _kṛte, 
   {{0x7d080129,0x394c016d,0x69c80162,0x00000000}},	//   _cnes, jnes_, vufe, --, 
   {{0x6d40f51b,0x394c95d8,0x7d08f51c,0x69c83917}},	//   rioa, dnes_, _dnes, wufe, 
   {{0x394cf51d,0x7d08f51e,0x6d40f51f,0x69c80112}},	//   enes_, _enes, sioa, tufe, 
   {{0x6d40f520,0x7d0807c5,0x889401c0,0x394c0036}},	//   pioa, _fnes, нийх, fnes_, 
   {{0x394cf521,0x69c80639,0x7d08f522,0x61e004e6}},	//   gnes_, rufe, _gnes, _änle, 
   {{0x69c8f523,0x2ca4030a,0x18640063,0x203c01f3}},	//   sufe, mbod_, маћи_, _ኮንሰር, 
   {{0x394cf524,0x2ca40183,0x7d08151c,0x63b802d1}},	//   anes_, lbod_, _znes, šunk, 
   {{0xd6d4f525,0x7d089ff5,0x2730004d,0x394cf526}},	//   фты_, _ynes, _lâng_, bnes_, 
   {{0x2ca4f527,0x394cf528,0x00000000,0x00000000}},	//   nbod_, cnes_, --, --, 
   {{0x273007ae,0x183007d6,0x68e0f529,0x88d40055}},	//   _nâng_, _لروح, _ibod, _dṛte, 
   {{0x27e4f52a,0x57f00006,0x00000000,0x00000000}},	//   _ipon_, _шпіт, --, --, 
   {{0xd5ac00a8,0x2ca401d5,0x92940006,0x00000000}},	//   _шс_, kbod_, тасц, --, 
   {{0xd49800a8,0xe74401c6,0x27300208,0x88e000cc}},	//   _орь_, _хүүе_, _bâng_, _মোতক, 
   {{0xa2d40490,0x2ca40158,0x68e0f52b,0x26dc0009}},	// [15890] _बाप्, dbod_, _mbod, ofto_, 
   {{0x7d08f52c,0x27e4013f,0x273001fb,0x626400d1}},	//   _snes, _mpon_, _dâng_, _يادق, 
   {{0x68e005db,0x27e401d5,0x88b400cc,0x00000000}},	//   _obod, _lpon_, _টানক, --, 
   {{0x6d580008,0x27e4f52d,0x394c03cd,0x7bd8002f}},	//   _ítal, _opon_, xnes_, ttwu, 
   {{0x7d080fb7,0x394cf52e,0x3b0803f6,0x00000000}},	//   _vnes, vnes_, зело_, --, 
   {{0x68e0f52f,0x394cf530,0x7bd8688b,0x80ac00e1}},	//   _abod, wnes_, rtwu, जरवे, 
   {{0x394cf531,0xa2d41fb2,0x7bd8000f,0x27b000fb}},	//   tnes_, _बान्, stwu, ңәшс, 
   {{0x7d08f532,0x394cf533,0xa63c02d3,0x98bc031c}},	//   _unes, unes_, _ኣሕዋተ, fluġ_, 
   {{0x394c6fac,0xca7401b9,0x49040243,0x5fb403ce}},	//   rnes_, _یامغ, वाजो_, ेंटल, 
   {{0x394cf534,0x68e002c4,0x59cc1fbc,0x7f440477}},	//   snes_, _ebod, संदर, nihq, 
   {{0x394cf535,0x27e40086,0xdb0801bf,0x00000000}},	//   pnes_, _epon_, tsgæ, --, 
   {{0x68e00cad,0x26dc0067,0x61200254,0x394c014f}},	//   _gbod, afto_, _kõlu, qnes_, 
   {{0x37e4376d,0x5ec4015b,0x29140419,0x00000000}},	//   _чолг, র্যে, úcať_, --, 
   {{0x27300262,0x68e00b3d,0x6d5800e4,0x70b80b02}},	//   _când_, _zbod, _êtav, ेल्ल, 
   {{0x2ca40cfd,0x6fc00490,0x2730054e,0x7760f536}},	//   ybod_, _लिहू, _dând_, molx, 
   {{0xf8ac045e,0x5ec4015b,0x7760022e,0xdd0c00ef}},	//   _গাঁথ, র্মে, lolx, _džūd, 
   {{0xdb080008,0x409460c6,0x00000000,0x00000000}},	// [158a0] yrgð, трст, --, --, 
   {{0xb8d02eab,0x2730f537,0xe7f0000d,0x00000000}},	//   _དབ_, _vâng_, _अनसा_, --, 
   {{0xece8165d,0x6280002d,0x324402e8,0x5ec40154}},	//   здел_, _ûnop, _ченг, র্ভে, 
   {{0xdcac12b7,0x8d2800fd,0x27300208,0xec784130}},	//   مىم_, ьнең_, _tâng_, ппе_, 
   {{0x2ca4f538,0x4af805cc,0x8f8407dd,0x6120007d}},	//   rbod_, делю_, _ақал, _põlv, 
   {{0x68e079c8,0x27e401ab,0x5ec4015b,0x2ca401f5}},	//   _sbod, _rpon_, র্বে, sbod_, 
   {{0x68e00175,0x2ca4f539,0x6120000d,0x63b80003}},	//   _pbod, pbod_, _võlv, ġuni, 
   {{0x8884b184,0xec140220,0xaad0078a,0x9dd8011a}},	//   نیان, _كوزد, _सावक, _מקלח, 
   {{0x2730002d,0x3cd4036b,0x68e0f53a,0xaba81e71}},	//   _lâne_, _шўрт, _vbod, _رهام_, 
   {{0x77600009,0xdb08007c,0x00000000,0x00000000}},	//   golx, gsgä, --, --, 
   {{0x68e00408,0x27300276,0x63840248,0x95d401c6}},	//   _tbod, _rând_, _lénì, ндэт_, 
   {{0x69d80cf9,0x68e007f5,0x4394ea23,0x48c401ec}},	//   _iqte, _ubod, камс, _рәка, 
   {{0x27e40c3e,0x6844f53b,0x5880d52c,0x00000000}},	//   _upon_, _янда, _йыша, --, 
   {{0x93880ce7,0xc2c4007b,0xe3bc00a2,0x06b800f1}},	//   есса_, ضيري, gyña_, _کنډک_, 
   {{0x27300276,0x5ec4015b,0x00000000,0x00000000}},	//   _vând_, র্ডে, --, --, 
   {{0x63840241,0x24dc0154,0x212c0332,0x00000000}},	//   _bénì, _বোরহ, ógh_, --, 
   {{0x8fe4052f,0x0fe40228,0x83340022,0x00000000}},	// [158b0] ләрҙ, лөрү, _анпх, --, 
   {{0xdc100724,0x69c40374,0x69d801a9,0x13a80133}},	//   xşır, _āken, _oqte, _سۆفی_, 
   {{0xdb0801e3,0x443800e2,0x00000000,0x00000000}},	//   nsgå, lzs_, --, --, 
   {{0xffb44090,0xc0c400ee,0x61200254,0x009401c6}},	//   _иймэ, _шәги, _põlu, _шимэ, 
   {{0x443807de,0x2d8c004e,0x27300356,0x7f44014f}},	//   nzs_, ífer_, _zâne_, pihq, 
   {{0xbbd01b76,0x612000c5,0x0c2402d5,0x7f440455}},	//   _समीक, _võlu, ымін, qihq, 
   {{0x0dc800c9,0x00000000,0x00000000,0x00000000}},	//   _пути_, --, --, --, 
   {{0xdb080267,0xe45c007c,0x00000000,0x00000000}},	//   dsgå, ngös_, --, --, 
   {{0xe8f452c6,0xdc101565,0x69cc019b,0xdb08002f}},	//   тлы_, pşır, _åben, tsgä, 
   {{0xe7c00c22,0x00000000,0x00000000,0x00000000}},	//   _शिरप, --, --, --, 
   {{0xd1d8001f,0xdb084bc1,0x25ac0142,0xb6580212}},	//   ክብት_, gsgå, _cwfl_, ьших_, 
   {{0xdb081ba6,0x2730045f,0x1cac031c,0xfaa400c7}},	//   ssgä, _râne_, _ནབས_, _чаҧо, 
   {{0x78a8f53c,0x59cc043e,0xdb08007c,0x00000000}},	//   mbev, संवर, psgä, --, 
   {{0x78a8f53d,0x5ec40154,0xf7440354,0x6d90010e}},	//   lbev, র্তে, _шело, lýaň, 
   {{0xe294f53e,0x1adc0183,0x21640276,0x88d40055}},	//   тас_, _যোৱা, ӂити_, _kṛpe, 
   {{0x78a808f7,0x44380810,0x332800d7,0x00000000}},	//   nbev, bzs_, skbx_, --, 
   {{0x313c0020,0x2164f53f,0x6020f540,0xcee400d1}},	// [158c0] _ከእግዚ, тити_, адта, лбақ, 
   {{0x6120007d,0x730400c7,0xa3780254,0xb224022e}},	//   _sõlt, _рпоз, gtõd, _амол, 
   {{0x78a8f541,0x612000c5,0xb89002dd,0x638401e1}},	//   kbev, _põlt, _өкiл, _wénì, 
   {{0x88d4002b,0xddc0a158,0x00000000,0x00000000}},	//   _nṛpe, рбци, --, --, 
   {{0x612000c5,0x8d7401d3,0x9b9001d5,0x6ad800cc}},	//   _võlt, ناچا, للنت, _যোগো, 
   {{0x70b0012d,0x7c648fda,0x00000000,0x00000000}},	//   _ज़ुल, دامل, --, --, 
   {{0x3cfc007d,0xe45c57bb,0x99d00fb4,0x78a80942}},	//   _रोके_, ngör_, لتيا, fbev, 
   {{0x5ec400bd,0x78a8f542,0x00000000,0x00000000}},	//   র্দে, gbev, --, --, 
   {{0x25ac026c,0x57b00024,0xd834009d,0x6ec43f7e}},	//   _swfl_, абыт, вээ_, ाणपु, 
   {{0xa2d4255c,0xb7d8f543,0xdb08376e,0x00000000}},	//   _बाध्, روپا_, tsgå, --, 
   {{0xe8f805f5,0xa78403e6,0xdb080158,0xa3780798}},	//   _олж_, _یشتو, usgå, ntõe, 
   {{0xdb0801e3,0x64bc00cd,0x44380036,0xa7a800db}},	//   rsgå, ्लेश, tzs_, _жкда_, 
   {{0x23600054,0xd04403f9,0xa2d405dc,0x254c033f}},	//   tojj_, mfiɗ, _बाद्, nęli_, 
   {{0x4438f544,0x569002d5,0x69c80140,0xdb0801e3}},	//   rzs_, _кашт, orfe, psgå, 
   {{0x442c0552,0x6378006a,0x23600054,0x5224f545}},	//   še_, hîng, rojj_, афта, 
   {{0x69c800c6,0xd04402a8,0xd25000e5,0xa378000d}},	//   irfe, nfiɗ, آنِ_, dtõe, 
   {{0xaad01533,0x656c0036,0x69c80112,0x4fb401b9}},	// [158d0] _सांक, mlch, hrfe, لصلر, 
   {{0x656cf546,0xd3a402e8,0x764c002b,0x00000000}},	//   llch, _тръп, _śayi, --, 
   {{0x656cf547,0x78a801d3,0xa3780254,0xd358010f}},	//   olch, ybev, gtõe, _ביזי_, 
   {{0x7c58192c,0x7bdc0793,0xd01001ed,0xe7c00073}},	//   ىلار_, _äsuk, حلے_, _शिंप, 
   {{0x69c8f548,0x656cf549,0xb87c0115,0xcf9800d8}},	//   erfe, ilch, neŭt, _ајс_, 
   {{0x656c2305,0xdde001af,0x00000000,0x00000000}},	//   hlch, _вәдү, --, --, 
   {{0x8d7400f7,0xaa400032,0xf9908b29,0x69cc0fac}},	//   _چاقا, йешл, حبت_, _åbel, 
   {{0x8d74bd8e,0x6378006a,0x17c000c7,0x00000000}},	//   _ناقا, bîng, ааиҭ, --, 
   {{0x637800d2,0x69c80869,0xc6200154,0x26ec0154}},	//   cîng, arfe, _ফেলা_, ড়ানো_, 
   {{0x656cf54a,0xb87c00df,0x63780356,0x00000000}},	//   elch, deŭt, nînd, --, 
   {{0x78a8168c,0x59b04cb2,0x09e40212,0x78d400ec}},	//   pbev, _төлс, _воєн, _مٺائ, 
   {{0xf77000ec,0xc5080014,0x00000000,0x00000000}},	//   _ڏات_, نتُل_, --, --, 
   {{0xc9840276,0x312401b9,0x58840eed,0x6cd800df}},	//   _туфи, қдаг, _рыжа, ײַכצ, 
   {{0x656cf54b,0xd3480330,0xe3e401d3,0x39dc012d}},	//   alch, ئیده_, اکين_, _महफ़ि, 
   {{0x6d580421,0x683c0023,0xa234035b,0x5f1400cd}},	//   _ìtag, _ክትሓስ, гьтә, नान्_, 
   {{0x415807d8,0x21646bce,0xe45c007c,0x00000000}},	//   вшую_, гиси_, rgör_, --, 
   {{0xe0dc01ab,0x6e446ea9,0x2ee400ee,0x3f800327}},	// [158e0] _smòc_, گنام, лжаг, fmhu_, 
   {{0x6f0c0204,0xaad04c19,0x5ec4015b,0x69c8058a}},	//   _qnbc, _साइक, র্সে, yrfe, 
   {{0xacc80598,0x6e4480de,0x200400b0,0x63b80784}},	//   егез_, دنام, ānia_, šunt, 
   {{0x03f42b88,0xa3780261,0x27302da2,0xdd8c9304}},	//   _བརྩམ_, rtõe, _mâna_, سوه_, 
   {{0xa37803b7,0x92c8009e,0x63780356,0xf8b80055}},	//   stõe, োজী_, bînd, daũ_, 
   {{0x81c803f4,0x612000c5,0x98c001e0,0x63780356}},	//   োবর_, _hõlp, ҡсыл, cînd, 
   {{0x6378145e,0x656c00a9,0xa2d44728,0x6d4801a8}},	//   sîng, ylch, _बास्, éfas, 
   {{0xbb2c0131,0x63780356,0xed50e5e7,0x98a00114}},	//   ﻧﻜﻰ_, mîne, _اپر_, биће, 
   {{0x473403a5,0x3d1005ba,0xf8d40882,0xfbd001ec}},	//   инис, णारे_, _धारय, _ۇتە_, 
   {{0x583402f6,0x7c2c0158,0xd1f40023,0x908c0150}},	//   узья_, øare, ልእታ_, _ﻓﺭﺤﺔ_, 
   {{0x48c40124,0x00000000,0x00000000,0x00000000}},	//   _кәпа, --, --, --, 
   {{0xa2d44c83,0x7bcc01a8,0xe4a40137,0x2cb001d5}},	//   _बाह्, áaug, ыроо, аydi_, 
   {{0x5f140a28,0x78bc05f7,0x7d1c0ba1,0x656c0112}},	//   नाम्_, ðsve, _òsse, rlch, 
   {{0x57f8011a,0x656c01a9,0x00000000,0x00000000}},	//   _נלוו, slch, --, --, 
   {{0x5fc4033d,0xaad0375c,0x9258a902,0x3744030d}},	//   _लिहल, _साईक, гарт_, _тĕрт, 
   {{0xddc8038f,0x00000000,0x00000000,0x00000000}},	//   ċiżj, --, --, --, 
   {{0xdb08002d,0x2730054e,0x73c002dd,0x7f84036b}},	// [158f0] rsgú, _zâna_, _мәре, للرن, 
   {{0x3cfc6407,0x543c010f,0x853c0064,0x00000000}},	//   _रोजे_, _רעזא, ipėm, --, 
   {{0x8d74005e,0xb87c01e4,0x63780356,0x3d100118}},	//   ڭالا, neŭr, rînd, णाले_, 
   {{0xdb080162,0x00000000,0x00000000,0x00000000}},	//   lsgø, --, --, --, 
   {{0x5c740184,0x814400b2,0x8d740966,0x00000000}},	//   уҙар_, _منھن, حالا, --, 
   {{0xeb9443f7,0x4fc400f7,0xdb080174,0xc98c0150}},	//   шиш_, _دەكە, nsgø, _ﺗﺎﺭﻙ_, 
   {{0x7c2c143a,0x6f601870,0x6d500bcd,0x52d8010f}},	//   øarb, _بۇلم, ðkað, אווע_, 
   {{0x55c00032,0x5ec4015b,0x683c0240,0x00000000}},	//   ҙамғ, র্শে, _ክትመስ, --, 
   {{0x25bc05c7,0x1b008580,0xdb0803b2,0x87b8005b}},	//   estl_, _гүлн, ksgø, луэт_, 
   {{0x27300311,0xa2d401bc,0xc5ec00cc,0x00000000}},	//   _pâna_, _बाष्, _ওপজা_, --, 
   {{0x7ae400af,0x9178004d,0xe614084c,0x7bcc2ba4}},	//   õhtu, _lớn_, адэ_, šaud, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe72cf54c,0x6b8c07c5,0x97a40114,0x00000000}},	//   _де_, _üngü, _срел, --, 
   {{0xb6a4f54d,0x46480046,0x00000000,0x00000000}},	//   _тикл, _өзін_, --, --, 
   {{0xa2d4433a,0xa6e008a5,0x00000000,0x00000000}},	//   _बार्, _æðar, --, --, 
   {{0xd3a40116,0x97000131,0x1ccc031c,0x00000000}},	//   _ллиқ, _ئېگى, ཱུས_, --, 
   {{0x63f400ec,0xf4080150,0x853400f1,0xae940395}},	// [15900] _نفيس_, _شيدى_, _دويچ, ашещ, 
   {{0xdfcc007b,0x908c0150,0x00000000,0x00000000}},	//   بيك_, _ﻓﺭﺼﺔ_, --, --, 
   {{0xca68022e,0x00000000,0x00000000,0x00000000}},	//   _nodа, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xec1424ce,0xb87c0115,0x00000000,0x00000000}},	//   релә_, zeŭr, --, --, 
   {{0xa9c41a72,0x69cc33b8,0x3da8008e,0x25bc0142}},	//   асик, _åbek, _әйтү_, ystl_, 
   {{0xd6b8015b,0x3958022e,0x00000000,0x00000000}},	//   ংলায, еss_, --, --, 
   {{0xed340323,0x998000f7,0x298450c0,0xf8b400cf}},	//   _тэгэ, يلوو, шылг, бөш_, 
   {{0xa2d42894,0x0c7401d9,0x63780356,0x00000000}},	//   _बाल्, _اگاد, nînc, --, 
   {{0x753400a2,0xaa4401d5,0xb87c0115,0x45d400db}},	//   _alyz, _кезл, teŭr, боос, 
   {{0x5f140882,0x295402e8,0x9f480129,0xe7f000c5}},	//   नात्_, _къдр, îmés_, _अनका_, 
   {{0x28484990,0xb87c00df,0x25bc002f,0x00000000}},	//   _изеп_, reŭr, rstl_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x782400f1,0x00000000,0x00000000,0x00000000}},	//   _دعمل, --, --, --, 
   {{0x624001a9,0xdb0806ea,0xd6240114,0x00000000}},	//   _gеol, rsgø, _воје_, --, 
   {{0xd138f54e,0x44b41b88,0x75340036,0x95c401d5}},	//   аху_, _убис, _glyz, _туша_, 
   {{0x7f5805f5,0xc0c400d1,0x00000000,0x00000000}},	// [15910] гаас_, _қәви, --, --, 
   {{0x9e04f54f,0x4fc402d5,0x00000000,0x00000000}},	//   ичел, ўста, --, --, 
   {{0xc0c4052f,0x69cc33b8,0x00000000,0x00000000}},	//   _гәзи, _åbeh, --, --, 
   {{0x29ec06be,0xfce4009d,0x00000000,0x00000000}},	//   _məad_, ёоло, --, --, 
   {{0xfc0405c5,0xfaa42e01,0xf0900302,0x92b40046}},	//   спло, бало, _מנכ_, _احۋا, 
   {{0xee4400ee,0xdb04010e,0x0b4428f6,0x3ce8002b}},	//   şýan_, _ümür, онін, _śivā_, 
   {{0x3f985b5c,0x853c0153,0x4e2800db,0x9f5c010e}},	//   _husu_, rpėj, _коён_, _çuñ_, 
   {{0x853c0024,0x3ea001c7,0x3f986ff5,0x00000000}},	//   spėj, lcht_, _kusu_, --, 
   {{0x3f90983f,0x3ea000c6,0x3f98f550,0x9c6000db}},	//   _kizu_, ocht_, _jusu_, _بۇشو, 
   {{0x3f98f551,0x49b8f552,0x660801bf,0x3ea001c7}},	//   _musu_, _چاند_, _brfk, ncht_, 
   {{0x3ea05651,0x3f90f553,0x3f98f554,0xcfa80154}},	//   icht_, _mizu_, _lusu_, _ওয়ান, 
   {{0xc3280d65,0xb8940491,0x20080483,0xd3c816c3}},	//   _או_, _الإع, _orci_, ақил_, 
   {{0x394cf555,0x3f98f556,0x78b80c8c,0x660802d0}},	//   mies_, _nusu_, _iewv, _erfk, 
   {{0x6738f557,0x00000000,0x00000000,0x00000000}},	//   chtj, --, --, --, 
   {{0x2008f558,0x75d4113e,0xa5cc0f44,0xdb2000e4}},	//   _arci_, _ايعا, _थियौ, _ãrõi, 
   {{0x3ea004c4,0x3f9001c6,0x6240022e,0x97400210}},	//   echt_, _aizu_, _gеom, śćdz, 
   {{0x3f9007ab,0x00000000,0x00000000,0x00000000}},	// [15920] _bizu_, --, --, --, 
   {{0x394cf559,0x3f980384,0xa49805da,0xeb98020a}},	//   hies_, _dusu_, ndòn, ҳид_, 
   {{0x3f9001c0,0x66080158,0xae78d010,0x26181be1}},	//   _dizu_, _xrfk, усах_, यमयी_, 
   {{0x3ea00491,0x394cf55a,0xecb8179c,0x3f98f55b}},	//   acht_, jies_, اطات_, _fusu_, 
   {{0x200808ad,0x3f98f55c,0x394cf55d,0xab28f55e}},	//   _grci_, _gusu_, dies_, лода_, 
   {{0x2ee80048,0x3ea001c7,0x2d94030d,0x00000000}},	//   _ubbf_, ccht_, _грас, --, 
   {{0x394cf55f,0x2b9001b9,0xee3800f3,0x00000000}},	//   fies_, _کیتس, _снв_, --, 
   {{0xad680107,0x00000000,0x00000000,0x00000000}},	//   _сабз_, --, --, --, 
   {{0x78b81529,0xdd8c0a2c,0x98a00063,0x0ebc000d}},	//   _dewv, _سوك_, чиње, _ऊजाड, 
   {{0xcafc1d8a,0xbb700150,0xe4a401c6,0xd1e40023}},	//   _एसिड_, _قۇنع, өрмо, _ምሃቡ_, 
   {{0x2d84166a,0x6ab803ac,0x6d5803b2,0xa2d4041c}},	//   omoe_, _ietf, _ítas, बलस्, 
   {{0x6738069c,0x394cf560,0x5994011a,0x5e74011a}},	//   shtj, cies_, _הכאב_, מתין_, 
   {{0xe78463e6,0x02ec000d,0xe72401ee,0x00000000}},	//   _луко, _चउदह_, _гєйн, --, 
   {{0x3f98f561,0xd7c4004b,0x2d84020c,0x98ac00de}},	//   _rusu_, _اووه_, hmoe_, _ilgā_, 
   {{0x3f90f562,0x5a98008f,0x78ac054e,0x6e2801bf}},	//   _rizu_, רשלא, _învâ, øfbl, 
   {{0x3f98f563,0x6ab8192e,0x3f9001a9,0x200802f0}},	//   _pusu_, _letf, _sizu_, _prci_, 
   {{0x3ea00204,0x3f980113,0x2d8401f5,0x63780356}},	// [15930] tcht_, _qusu_, dmoe_, aîna, 
   {{0x394cf564,0x3ea04ea6,0x2d8404c9,0x3dc001e2}},	//   zies_, ucht_, emoe_, tshw_, 
   {{0x3f9008ad,0x3ea0f565,0x683c0248,0x0094ea71}},	//   _vizu_, rcht_, _yàdé, _минэ, 
   {{0x3ea01859,0x394cf566,0x20082220,0x3f98026c}},	//   scht_, xies_, _trci_, _tusu_, 
   {{0x6ab8003c,0xca6801a9,0x2008054e,0x5bc80114}},	//   _betf, _modе, _urci_, ућег_, 
   {{0xd1e402d3,0x394cf567,0x99c40014,0xe7f00037}},	//   _ምሃብ_, wies_, مُتے_, _अनजा_, 
   {{0x394cf568,0x98ac00ef,0x00000000,0x00000000}},	//   ties_, _algā_, --, --, 
   {{0x9ce401ed,0x6ab8127b,0xdb0807c5,0x321c005b}},	//   _دورے_, _eetf, lsgü, ätyi_, 
   {{0x394cf569,0xdcfc0024,0xf71802d5,0x6ab8c902}},	//   ries_, _žvėr, аіны_, _fetf, 
   {{0x394cf56a,0x6ab8030d,0x6294676c,0x6d580008}},	//   sies_, _getf, _ngxo, _ítar, 
   {{0x394cf56b,0xdb080e78,0x00000000,0x00000000}},	//   pies_, isgü, --, --, 
   {{0x62940472,0x6ab801f5,0x39a00014,0xf7940153}},	//   _agxo, _zetf, _ٹیکہ, _дадэ, 
   {{0x4ae00574,0x6ab8192e,0x6ccc0150,0x00000000}},	//   _नामव, _yetf, _ﻗﺩﺴﻴ, --, 
   {{0xe0dc067c,0xa3780254,0xe3b000ec,0x00000000}},	//   _acò_, stõn, برٽ_, --, 
   {{0xb9e4010c,0x21a0020f,0x021800d4,0x00000000}},	//   _ራእ_, дисм, біть_, --, 
   {{0x6294009a,0xf0a816a8,0xa4980ba1,0xc6680798}},	//   _egxo, ркал_, ndòl, _ушче_, 
   {{0xe24c001f,0x69cc33b8,0x00000000,0x00000000}},	// [15940] _አድርጓ, _åbev, --, --, 
   {{0x49100034,0xa378000d,0xe7f001f9,0x00000000}},	//   _दोनो_, ntõl, _अनघा_, --, 
   {{0xe4d02fc0,0xc86802d3,0x6ab8037e,0xdcac2002}},	//   _عقید, _ምድንጋ, _retf, چىم_, 
   {{0xdcac4d2d,0x6ab8003c,0xe6b40073,0x00000000}},	//   نىم_, _setf, _आज्ज, --, 
   {{0x6ab8002d,0x2d840ea0,0x6b6401b9,0x6004f56c}},	//   _petf, rmoe_, окда, _дням_, 
   {{0xa01801d3,0xdd140139,0x00000000,0x00000000}},	//   _szög, _täşq, --, --, 
   {{0x6cd4f56d,0x5f14041c,0x00000000,0x00000000}},	//   _وقسا, नार्_, --, --, 
   {{0x2bd016f0,0x6ab8192e,0x20040034,0xed580117}},	//   _सिपा, _wetf, łnie_, _тоб_, 
   {{0x6ab8192e,0x290001f1,0xd7f4084c,0x32080334}},	//   _tetf, ľka_, оуэ_, hvby_, 
   {{0x29005e64,0x6a144210,0xb0600166,0x45d400db}},	//   žka_, _وبار, _ğäll, поос, 
   {{0x5ec400bd,0x5e98010f,0xb0600139,0x00000000}},	//   র্কে, יביק, _şäll, --, 
   {{0x06c801c0,0x61e0002f,0x00000000,0x00000000}},	//   шгүй_, _änli, --, --, 
   {{0x2bd014df,0xf31805a2,0x44ec022e,0x98a8012d}},	//   _सिफा, әнсә_, rо_, ócą_, 
   {{0xd1c0001f,0x48f4012c,0x2bd0190e,0x00000000}},	//   ድገት_, ्यको_, _सिना, --, 
   {{0x92948cbf,0xe45c0205,0x00000000,0x00000000}},	//   дарц, ngöz_, --, --, 
   {{0xa2d41e61,0x00000000,0x00000000,0x00000000}},	//   _बाक्, --, --, --, 
   {{0xdb08002f,0x00000000,0x00000000,0x00000000}},	// [15950] tsgü, --, --, --, 
   {{0x62940472,0xe45c0bbc,0x00000000,0x00000000}},	//   _ugxo, kgöz_, --, --, 
   {{0x2d9c01ed,0x3b180051,0xe1f800fb,0x00000000}},	//   _étel_, _đsq_, _тѳп_, --, 
   {{0x2fd0037e,0x7f94009d,0x59cc01ef,0x00000000}},	//   bryg_, _намх, संघर, --, 
   {{0xfaa4f56e,0x5ec40154,0x00000000,0x00000000}},	//   пало, র্গে, --, --, 
   {{0x764009a5,0x628002fb,0xfaa400d8,0x93fc011a}},	//   yzly, _únos, чако, ילדי, 
   {{0xa92000d0,0xd2b8011a,0xce58030d,0x78bc03b2}},	//   _šľac, חלות_, _дарц_, ðsvo, 
   {{0x69c400b0,0xf8b801c6,0xed4c022e,0xf7700244}},	//   _āket, сөж_, ssоr_, کاب_, 
   {{0x2bd01533,0x00000000,0x00000000,0x00000000}},	//   _सिया, --, --, --, 
   {{0xab600ed1,0xa2d4012c,0x7bd8f56f,0x9f4801ef}},	//   _كۇنى, _बाग्, muwu, _opcí_, 
   {{0x36684705,0x7bd8f570,0x4ae00401,0xe45c06be}},	//   сано_, luwu, _नातव, mgöy_, 
   {{0x3b0401b9,0x2bd0012c,0x2d8c004e,0xa3780254}},	//   _halq_, _सिमा, ífex_, stõl, 
   {{0x29080134,0x7bd89544,0xe574f571,0xa49801ab}},	//   ɛba_, nuwu, язю_, cdòm, 
   {{0x0708004b,0x7988007f,0x765c002f,0x033800d4}},	//   _ويني_, lmew, ßsys, оїсь_, 
   {{0xa018006a,0x69cc08fb,0x7bd804fb,0x37bc0154}},	//   _nzöb, _åbet, huwu, _আমির, 
   {{0x25a804cf,0x5fc4033d,0x7bd8abfb,0x79880042}},	//   íble_, _लिखल, kuwu, nmew, 
   {{0xc6d402dd,0xed4c022e,0x6140074d,0x00000000}},	// [15960] _ءتۇت, lpоg_, хета, --, 
   {{0xdfccacdc,0x37bc015b,0x7bd8f572,0x5f0000f0}},	//   ايل_, _আমার, duwu, нзуа, 
   {{0xe2980375,0xceb8010b,0xab640116,0x44241291}},	//   _לשיר, йәң_, үвел, _فریف, 
   {{0xdca0d92d,0x65c00241,0xdd8ce4c7,0xd2dc12eb}},	//   еаци, _híhá, هول_, _बाँझ, 
   {{0xa8040005,0x6280012c,0x7bd80bfa,0x30744ae5}},	//   _mañó, _únor, guwu, _хунс, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8afc0153,0x9aa001f7,0x00000000,0x00000000}},	//   _skęs, رميو, --, --, 
   {{0xeb980716,0x65c000d2,0x7bd8f573,0xa80400e4}},	//   _гиа_, _líhá, buwu, _nañó, 
   {{0x853c0064,0x00000000,0x00000000,0x00000000}},	//   ipėt, --, --, --, 
   {{0x1ae02119,0x2908012d,0x00000000,0x00000000}},	//   _поум, śba_, --, --, 
   {{0x3d100490,0xe81c000d,0x00000000,0x00000000}},	//   णाचे_, _बपवा_, --, --, 
   {{0x7bd8025a,0xa8043d57,0x2ca4f574,0xbbe801d3}},	//   _âbuä, _cañó, ncod_, _درہم_, 
   {{0x5ec4015b,0xa5d000a2,0x68e002d0,0xa3780254}},	//   র্টে, _aỳtd, _icod, stõm, 
   {{0x3b04f575,0x2904f576,0x65b4006a,0x27e4037e}},	//   _xalq_, _haoa_, gûhî, _iqon_, 
   {{0x2904f577,0xd5b40024,0x00000000,0x00000000}},	//   _kaoa_, _есы_, --, --, 
   {{0x672801a4,0xd674011a,0x7bd8f578,0x925818a4}},	//   _hofj, _מתוק_, yuwu, част_, 
   {{0x656cf579,0x67280b21,0x2904f57a,0x68e0010a}},	// [15970] moch, _kofj, _maoa_, _mcod, 
   {{0x26dc7dcc,0x29040b23,0x2ef8009a,0x68e00334}},	//   ngto_, _laoa_, gepf_, _lcod, 
   {{0x7bd8f57b,0xf2d008d8,0x321c0108,0x00000000}},	//   wuwu, _בעי_, ätyt_, --, 
   {{0x656cf57c,0x7bd8f57d,0x2904f57e,0x1a540137}},	//   noch, tuwu, _naoa_, үздө_, 
   {{0x2204012c,0x88d40055,0x656c00ae,0x00000000}},	//   bíhá_, _mṛde, ioch, --, 
   {{0x212827cc,0x656cf57f,0x68e0f580,0x7bd8f581}},	//   _hoch_, hoch, _acod, ruwu, 
   {{0x656cf582,0xa3dc06ab,0x2128f583,0x68e00175}},	//   koch, दंड_, _koch_, _bcod, 
   {{0x656cf584,0x26dcf585,0x2128014f,0x60dc0007}},	//   joch, egto_, _joch_, ngqm, 
   {{0x656ce0a0,0x79880a2e,0x2128f586,0x68e0f587}},	//   doch, rmew, _moch_, _dcod, 
   {{0x2128f588,0x68e0f589,0x2bd04fd3,0x35c801c6}},	//   _loch_, _ecod, _सिता, огоо_, 
   {{0x29040b23,0x656cf58a,0x7a340597,0x68e00175}},	//   _faoa_, foch, _تفاص, _fcod, 
   {{0x2128f58b,0x656cf58c,0x29040618,0x68e000ae}},	//   _noch_, goch, _gaoa_, _gcod, 
   {{0x69cc2b27,0xad180375,0xc1b40150,0x7bc80129}},	//   _åber, קושר, _اﻟﺘﯩ, _jveu, 
   {{0xf1a8f58d,0x2768129e,0x00000000,0x00000000}},	//   قاره_, _وشوی_, --, --, 
   {{0xe294f58e,0x656c00b4,0x2128016d,0xd04800ac}},	//   дар_, boch, _boch_, ələs, 
   {{0x656cf58f,0x2ca40354,0x21280368,0x0cd80011}},	//   coch, xcod_, _coch_, _সস্ত, 
   {{0x2128f590,0x27300311,0xaf045855,0x98a80210}},	// [15980] _doch_, _sâni_, мпал, ócę_, 
   {{0x321c005b,0x52b400db,0x00000000,0x00000000}},	//   ätys_, _سەرئ, --, --, 
   {{0xdee0026a,0x9f4800cf,0x7bc8f591,0x2128f592}},	//   тохи, _ascó_, _aveu, _foch_, 
   {{0x2128f593,0xec78f594,0x8d280724,0x2004033f}},	//   _goch_, опе_, янең_, łnia_, 
   {{0x2ca4e53b,0xac080137,0x5bc01870,0x00000000}},	//   rcod_, юнда_, پقىل, --, 
   {{0x656cf595,0x68e0f596,0x29040270,0x7c64267c}},	//   zoch, _scod, _saoa_, رانل, 
   {{0x656cf597,0x2904f598,0x9f4800db,0x7bc80165}},	//   yoch, _paoa_, _escó_, _eveu, 
   {{0x67280240,0x212801d5,0xa3780037,0x63b8031c}},	//   _sofj, _xoch_, atõh, ġunz, 
   {{0x656cf599,0x29040418,0xa49801ab,0x6d400208}},	//   voch, _vaoa_, leòg, mhoa, 
   {{0x656cf59a,0x796000b0,0xd78435f9,0x6d40f59b}},	//   woch, rēwa, ونيو_, lhoa, 
   {{0x656cf59c,0x2904f59d,0xd5b443a7,0x7bc8006f}},	//   toch, _taoa_, мся_, _zveu, 
   {{0x2bd00574,0x68e0738c,0x6d40b965,0xb864004b}},	//   सळपा, _ucod, nhoa, _ګامو, 
   {{0x2128f59e,0x6d40d018,0x57b000d3,0xd6cc01b9}},	//   _roch_, ihoa, _абіт, _چقه_, 
   {{0x656c0385,0x2128016d,0xd6cc0133,0x6d400051}},	//   soch, _soch_, _نقه_, hhoa, 
   {{0x6d40a852,0x2128f59f,0xc808001e,0xdbf800bc}},	//   khoa, _poch_, _hở_, _एन्ड_, 
   {{0x6d40002d,0x2128f5a0,0x521402e8,0x656cf5a1}},	//   jhoa, _qoch_, ъдст, qoch, 
   {{0x8fe4052f,0x0fe40372,0x3f14f5a2,0x6d40f5a3}},	// [15990] кәрҙ, көрү, ндас, dhoa, 
   {{0x212804d1,0xc80807ae,0x6d580248,0x00000000}},	//   _woch_, _mở_, _ìtaj, --, 
   {{0x21280460,0x7bc82375,0x3cd4f5a4,0x0dc816ab}},	//   _toch_, _sveu, ежес, дучи_, 
   {{0x6d407974,0x00000000,0x00000000,0x00000000}},	//   ghoa, --, --, --, 
   {{0xc808001e,0x10040139,0x5c0000cf,0x00000000}},	//   _nở_, _иярм, ئكتە, --, 
   {{0x6d4000b0,0x39900064,0x00000000,0x00000000}},	//   ahoa, _išsi_, --, --, 
   {{0xab6008b0,0x6d40006f,0xa49801ab,0xb060008e}},	//   دۇلى, bhoa, ceòg, _ğäil, 
   {{0x6d40f5a5,0xc808004d,0x00000000,0x00000000}},	//   choa, _bở_, --, --, 
   {{0x8d7400db,0xc8080208,0x5ec400fe,0x00000000}},	//   _شافا, _cở_, ৰ্ণে, --, 
   {{0x7d08f5a6,0xc808001e,0x64a0f5a7,0x0c84f5a8}},	//   _haes, _dở_, ғара, _рысм, 
   {{0x03f40327,0xd5880133,0x6a98010f,0xdb0808a5}},	//   _བརྔམ_, وێته_, _זשענ, fsgö, 
   {{0x35b400d1,0xdb08032e,0x52b80c22,0x00000000}},	//   мбүр, gsgö, अर्स, --, 
   {{0xd90c55c1,0x3de404c5,0x7998198f,0xc8080208}},	//   _میں_, নবিল, _iiww, _gở_, 
   {{0x7d082908,0xa8540302,0x799804e6,0x73e4013e}},	//   _laes, _אינה_, _hiww, _ҷоиз, 
   {{0x79980036,0x638013d6,0x6d400208,0x311400c7}},	//   _kiww, угра, yhoa, нфас, 
   {{0x78a8f5a9,0x7d08f5aa,0x799800e8,0x6d400472}},	//   ncev, _naes, _jiww, xhoa, 
   {{0x79986ff6,0xa064f5ab,0x87ac010f,0xf2a401af}},	// [159a0] _miww, еата_, ַשאַ, _пипп, 
   {{0x7998f5ac,0xdee002e8,0xf1700133,0x00000000}},	//   _liww, лоуи, _ڕێزگ, --, 
   {{0x6d40f5ad,0x7d08f5ae,0x2bd00254,0xfe74010b}},	//   thoa, _baes, _सिहा, вүр_, 
   {{0x7d080de4,0x79980221,0xa49800db,0xd9840131}},	//   _caes, _niww, reòg, ﺯﯨﺮﻩ_, 
   {{0x7d08f5af,0xe0dc02e2,0x2730002d,0x6d40f5b0}},	//   _daes, _blòf_, _kânt_, rhoa, 
   {{0x6d40f5b1,0x29ec00ac,0xfe7001d3,0xee38f5b2}},	//   shoa, _fəal_, ادے_, _енг_, 
   {{0xc80807ae,0x9f940ffb,0x395801e4,0x7d086330}},	//   _sở_, jàùn_, _ĉssr_, _faes, 
   {{0xfbc801d9,0x5ec40c58,0x1d042b95,0x99606b28}},	//   _रिचम, ৰ্দে, _песи_, лтыл, 
   {{0xab64f5b3,0x7998226d,0x2e440241,0x788800e4}},	//   _звал, _diww, _fífé_, vêvé, 
   {{0x4734f5b4,0x78a8db64,0xc80801fb,0x00000000}},	//   тнос, acev, _vở_, --, 
   {{0x7d0802fa,0xa01824ba,0xb8640b28,0x69f0e06f}},	//   _yaes, _nzön, _یاهو, _сүйт, 
   {{0x98a01fbd,0x398000d8,0xc8080051,0x00000000}},	//   _бице, pósa_, _tở_, --, 
   {{0x6b9804ba,0x69c8f5b5,0xd5e400e5,0x00000000}},	//   _kitg, lsfe, وٹین_, --, 
   {{0xdc84044e,0x6b980003,0x2730af37,0x69c8004e}},	//   _ዝዓበየ_, _jitg, _cânt_, osfe, 
   {{0x6b9809f0,0x9268b7df,0x569000d1,0x54d800f1}},	//   _mitg, ерта_, _йашт, _ګېټس_, 
   {{0x6b98ba3a,0x69c89df3,0xab64033f,0xdc100356}},	//   _litg, isfe, leżą, nşăr, 
   {{0x7d08f5b6,0x51844f41,0x78bc041e,0x7d1c00db}},	// [159b0] _raes, уура, ðsvi, _òssi, 
   {{0x7d08f5b7,0x7bcc0006,0x69c8f5b8,0xa4980086}},	//   _saes, šauk, ksfe, reòd, 
   {{0x7d084ef6,0x3170f5b9,0x9e6400cf,0x2730045f}},	//   _paes, boyz_, رائن, _hâns_, 
   {{0x69c8f5ba,0x27300a85,0x6b9805d5,0x24780092}},	//   dsfe, _kâns_, _aitg, _በሦስት_, 
   {{0x6b98f5bb,0x79980221,0xdeb00220,0x7d08f5bc}},	//   _bitg, _riww, _бұзы, _vaes, 
   {{0xe0dc1497,0x6b98f5bd,0x7d08f5be,0x2bd039d7}},	//   _blòg_, _citg, _waes, _सिरा, 
   {{0x27300b21,0x78a8084c,0x6b9807c5,0x7d080332}},	//   _lâns_, tcev, _ditg, _taes, 
   {{0x7d08003a,0x2e440014,0xfc14084c,0x6b9802d0}},	//   _uaes, _شفقہ, _имбэ, _eitg, 
   {{0x78a8f5bf,0x6b9807c5,0xa9200d31,0xa3780254}},	//   rcev, _fitg, рдыл, ltõu, 
   {{0x78a85909,0x69c8002f,0x6b98f5c0,0x6d9800a2}},	//   scev, bsfe, _gitg, _uįar, 
   {{0x78a8070d,0x8d74040b,0x9a840724,0xa680f5c1}},	//   pcev, _شاہا, _чуал, ильд, 
   {{0xe8500517,0x6b98e0c9,0x27300356,0x398000e4}},	//   انید, _zitg, _sânt_, móso_, 
   {{0xc7a40220,0x6b9800a2,0xe7040133,0x37e4f5c2}},	//   _биік, _yitg, رسیی, _ролг, 
   {{0x6738007c,0x00000000,0x00000000,0x00000000}},	//   cktj, --, --, --, 
   {{0x27300311,0x3170003e,0xe7940811,0x00000000}},	//   _vânt_, toyz_, _شاهک, --, 
   {{0x2bd00cf1,0x00000000,0x00000000,0x00000000}},	//   _सिला, --, --, --, 
   {{0xc50825aa,0xe0dc0100,0x27300b21,0xa0a06ef4}},	// [159c0] _ستيل_, _amòs_, _gâns_, рауд, 
   {{0x4094f5c3,0xdfcc45d7,0xb8ec031c,0x764c00cd}},	//   урст, زيم_, _ྱབ_, _śayy, 
   {{0x6b98f5c4,0x7bd8f5c5,0x6e442162,0x6ce45e82}},	//   _ritg, erwu, خنام, віле, 
   {{0x6b98f5c6,0x69c8f5c7,0x1d8402f2,0x00000000}},	//   _sitg, vsfe, ندنێ, --, 
   {{0x69c8f5c8,0x6b980c86,0x48c40116,0x3e88013d}},	//   wsfe, _pitg, ңшиғ, _җитү_, 
   {{0x69c8f5c9,0xdb8005f5,0xe0dc0100,0x6b98022e}},	//   tsfe, агчи, _plòg_, _qitg, 
   {{0x6b980c86,0xed5802bf,0x69c80036,0xfaa401ec}},	//   _vitg, _жов_, usfe, ушін, 
   {{0x69c8f5ca,0xc4bc045e,0x6b9827bb,0x88840214}},	//   rsfe, _আঞ্জ, _witg, هیان, 
   {{0x69c8f5cb,0x1be4034b,0x3eb0003e,0x6b98f5cc}},	//   ssfe, _идти_, _énté_, _titg, 
   {{0x6b98bbd7,0x00000000,0x00000000,0x00000000}},	//   _uitg, --, --, --, 
   {{0x690400f7,0x6738017a,0x00000000,0x00000000}},	//   _аялз, rktj, --, --, 
   {{0x48c40166,0x6738007c,0x249c0162,0xad600150}},	//   _сәка, sktj, øum_, лдiк, 
   {{0x2748f5cd,0x7f440175,0x00000000,0x00000000}},	//   _очко_, yhhq, --, --, 
   {{0x4614006c,0x6d880432,0x00000000,0x00000000}},	//   _موتر, lýad, --, --, 
   {{0x164401e2,0x00000000,0x00000000,0x00000000}},	//   _لټوي_, --, --, --, 
   {{0x6d8800ee,0x00000000,0x00000000,0x00000000}},	//   nýad, --, --, --, 
   {{0x4ab4f5ce,0x00000000,0x00000000,0x00000000}},	// [159d0] ुराव, --, --, --, 
   {{0x4438f5cf,0x8c080011,0x03540166,0x6d8800a2}},	//   mys_, লমান_, _сүгә_, hýad, 
   {{0x4438f5d0,0xa3dc375c,0x13b8015b,0xc3300014}},	//   lys_, दूर_, _জিয়, _نٕک_, 
   {{0x4438f5d1,0xba2400d1,0x3ea800de,0x00000000}},	//   oys_, ғдик, _šitā_, --, 
   {{0x4438f5d2,0x8d747486,0xa498642b,0x8d940124}},	//   nys_, جالا, cdòt, рқтә, 
   {{0x0ca80588,0x443800ad,0xe8144ead,0x00000000}},	//   нтәи_, iys_, तिना_, --, 
   {{0x44381368,0xdce80618,0xf8b010e5,0xb6a400d1}},	//   hys_, aogā, مکش_, һипл, 
   {{0x4438f5d3,0x98a00024,0xb904119e,0xcce40150}},	//   kys_, ėjį_, узик, _ەسەي, 
   {{0xb6a4f5d4,0xcd840075,0x4438f5d5,0x00000000}},	//   липл, _ئۇنۋ, jys_, --, 
   {{0x4438f5d6,0xf3e40c60,0x1da40073,0x00000000}},	//   dys_, ҳқиқ_, गदपत, --, 
   {{0xa018049b,0x44381368,0x068000d1,0x00000000}},	//   _hyöd, eys_, ﮬﺎﻳﯩ, --, 
   {{0x4438d522,0x18b000d1,0xa2e000fe,0x00000000}},	//   fys_, _тәкр, য়োখ, --, 
   {{0x4438f5d7,0x7c78044e,0x2004033f,0x2bc4f5d8}},	//   gys_, _እናበለ_, łnij_, रीपा, 
   {{0x36680114,0xa0180108,0x98e0000d,0x6ee00118}},	//   _пало_, _myöd, _गाँछ_, _पाइँ, 
   {{0xb5c401b9,0x44380363,0xa018005b,0x942400db}},	//   _ёйил, ays_, _lyöd, _چوبۇ, 
   {{0x4438f5d9,0x6680760d,0xdce80882,0x00000000}},	//   bys_, _دیپل, yogā, --, 
   {{0xe814d59c,0xa01804cc,0xef18f5da,0x21a002dd}},	// [159e0] तिया_, _uzöl, нма_, _қиям, 
   {{0x7304b6c2,0x2bc401ad,0x00000000,0x00000000}},	//   _споз, रीफा, --, --, 
   {{0x2bc49518,0xed3401c0,0x06c80154,0x00000000}},	//   रीना, лэдэ, _শামি, --, 
   {{0xe8140316,0xa37800c5,0xdce800e2,0x6cd4f5db}},	//   तिमा_, stõt, togā, اقشا, 
   {{0x7c380142,0x00000000,0x00000000,0x00000000}},	//   gywr, --, --, --, 
   {{0xe0dc02e2,0x9d4000d1,0x00000000,0x00000000}},	//   _glòb_, _һесд, --, --, 
   {{0x99d026c0,0x4438f5dc,0xa498067c,0x6378054e}},	//   متيا, zys_, ndòr, mînt, 
   {{0x4438f5dd,0xbb34005e,0xdce8d657,0x6f0cbe27}},	//   yys_, ﺯﺍﻕ_, pogā, _habc, 
   {{0xd8340323,0x6b44008c,0x44388023,0x5f740014}},	//   гээ_, _aðge, xys_, _شمہس_, 
   {{0x17f40491,0xf3f8015b,0xdb08022c,0x4438f5de}},	//   ارية_, ইটার_, ppgá, vys_, 
   {{0x4438b4f9,0x6f0c014f,0x2d9c0129,0x279404a9}},	//   wys_, _mabc, _étes_, кшүр, 
   {{0x4438f5df,0x6f0c0369,0x6d88010e,0x00000000}},	//   tys_, _labc, lýab, --, 
   {{0x443800ad,0xf1c40150,0x00000000,0x00000000}},	//   uys_, _ﺩﯨﻤﻘ, --, --, 
   {{0x4438f5e0,0x2bc406ff,0x6f0c0455,0x00000000}},	//   rys_, रीया, _nabc, --, 
   {{0x4438f5e1,0xd5acf5e2,0x7c38033f,0x6754bbed}},	//   sys_, _ыс_, zywr, _لیکس_, 
   {{0x80b4566d,0x6ee0012c,0xc0c40124,0x270c06be}},	//   рбах, _पाउँ, шәои, lәn_, 
   {{0x2bc4b8a8,0x6f0cf5e3,0x00000000,0x00000000}},	// [159f0] रीमा, _babc, --, --, 
   {{0x6f0c0007,0xe0dc068c,0x4ae04466,0x6d4800e8}},	//   _cabc, _blòc_, _नागव, ëfan, 
   {{0xa01802f6,0xd01000aa,0x6f0c5148,0x6ef801bf}},	//   _syöd, يلې_, _dabc, _søbæ, 
   {{0xd1dc0092,0x55b800d9,0x2bc400b8,0x00000000}},	//   ንኖች_, גמאו, रीभा, --, 
   {{0x50f45928,0x6f0cf5e4,0x41c0a6cd,0xccc400d4}},	//   _узят, _fabc, षीरस, сбій, 
   {{0xbe0401d3,0x7c380175,0xd1b857be,0x63780356}},	//   _پورٹ, rywr, _جایا_, cînt, 
   {{0x765c0209,0x2bc40fe6,0x69cc01bf,0x270c06be}},	//   şsyz, रीबा, _æbel, dәn_, 
   {{0x7c38f5e5,0x8cc8f5e6,0xf8b801c6,0x3f80025c}},	//   pywr, _موفق_, төж_, llhu_, 
   {{0xed4c68e7,0x6f0c0455,0x00000000,0x00000000}},	//   _تھل_, _yabc, --, --, 
   {{0x6f0c011f,0xdce80311,0xda480b87,0xddc800e2}},	//   _xabc, bogă, _пчел_, ļiņi, 
   {{0x366857a4,0x81c4015b,0x00000000,0x00000000}},	//   тано_, _উৎস_, --, --, 
   {{0x872402dd,0x00000000,0x00000000,0x00000000}},	//   _ۇعىم, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9af003f9,0x66e0f5e7,0x2b1c033f,0xb6f802dd}},	//   _ƙeƙe_, _доша, पाएँ_, _شىعا_, 
   {{0xf67800c8,0x2324013e,0x6378054e,0x6f0c15c0}},	//   _באַמ, шори_, vînt, _rabc, 
   {{0x2bc40b7c,0x6f0c014f,0x645400b8,0x00000000}},	//   रीडा, _sabc, _śaiś, --, 
   {{0xb4e0069f,0x6f0c0070,0xaec4f5e8,0x1fa40228}},	// [15a00] दली_, _pabc, ибал, икти_, 
   {{0x200801ab,0x6f0c014f,0x2eb401b9,0xb4e40037}},	//   _dsci_, _qabc, рсас, _काँय_, 
   {{0x386800fc,0x2008f5e9,0x2d942e80,0x23ac00de}},	//   _þarf_, _esci_, ардс, _iļja_, 
   {{0x09b4045e,0xe5f4008f,0xefdc0240,0x00000000}},	//   _টিলা, יזער_, ሕረይ_, --, 
   {{0x6f0c88a0,0xe0840014,0x1be413d6,0x00000000}},	//   _tabc, _نێٲو_, идци_, --, 
   {{0xdb4c1698,0x00000000,0x00000000,0x00000000}},	//   وَن_, --, --, --, 
   {{0x3e880598,0x2bd00316,0xce3401d5,0x29341884}},	//   _бирү_, _सिका, _اوزک, ﺮﺍﭖ_, 
   {{0x98b400a7,0xdce80356,0x2988033a,0xfca8007b}},	//   алът_, rogă, њско_, _ماكو_, 
   {{0xa01802f6,0x4dd8015b,0x00000000,0x00000000}},	//   _työe, _সহিং, --, --, 
   {{0xaae404fb,0x2bc400dc,0xa01801d3,0x42780092}},	//   _خسرو, रीणा, _szök, _በሆኑት_, 
   {{0x764c02a8,0x28e8366d,0x7bcc3d4f,0xe66404f0}},	//   _ƙaya, _адеп_, šaut, ртпо, 
   {{0xa37800d8,0x00000000,0x00000000,0x00000000}},	//   irõe, --, --, --, 
   {{0x7d1c0120,0xe784f5ea,0xd8840014,0x00000000}},	//   _ósse, _куко, _پھٹن_, --, 
   {{0x20080334,0xb3840023,0xe1f0f5eb,0x565400f2}},	//   _rsci_, _ዞባውን_, يسز_, اشیح_, 
   {{0x925801c6,0x2bc411bc,0x00000000,0x00000000}},	//   аарт_, रीता, --, --, 
   {{0xa37806ed,0xe4e88316,0x203402d3,0x00000000}},	//   drõe, _شعبه_, _የመልክ, --, 
   {{0x0f480020,0x7f84f5ec,0x3f80047e,0x2bd02072}},	// [15a10] _መከላከ, ملرن, tlhu_, _सिगा, 
   {{0x9f6000a2,0x00000000,0x00000000,0x00000000}},	//   _övüt_, --, --, --, 
   {{0x7b0403b9,0x00000000,0x00000000,0x00000000}},	//   _örtə, --, --, --, 
   {{0x2bd02aa1,0x4dd401d5,0x00000000,0x00000000}},	//   _सिखा, زتمس, --, --, 
   {{0x644c0399,0xa6dc0154,0x00000000,0x00000000}},	//   nzci, ব্যট, --, --, 
   {{0x7f58009d,0x0ae8003b,0x00000000,0x00000000}},	//   _сагс_, идій_, --, --, 
   {{0xdd98f5ed,0x0e08f5ee,0x00000000,0x00000000}},	//   _аша_, _кэти_, --, --, 
   {{0xb908010b,0x00000000,0x00000000,0x00000000}},	//   униз_, --, --, --, 
   {{0x2bc41788,0x00000000,0x00000000,0x00000000}},	//   रीदा, --, --, --, 
   {{0xbb840597,0x7bccf5ef,0x186400d1,0x644cf5f0}},	//   _الطي, šaus, лақи_, dzci, 
   {{0x6b78010f,0x00000000,0x00000000,0x00000000}},	//   _ערענ, --, --, --, 
   {{0x0684f5f1,0xb4e0c119,0xc95801a9,0x73340116}},	//   өгөн, दले_, _кўч_, ڭىسا, 
   {{0xe72c169c,0xa3dc2017,0xb6a4927e,0xc974007b}},	//   _ее_, दंग_, _лилл, _بالث, 
   {{0xe7440254,0x733400db,0x00000000,0x00000000}},	//   õõtu_, حىسا, --, --, 
   {{0xa498b153,0x00000000,0x00000000,0x00000000}},	//   leòl, --, --, --, 
   {{0xa3780798,0x466805a2,0x00000000,0x00000000}},	//   vrõe, _әрәм_, --, --, 
   {{0x644c033f,0x30ec00dc,0xa49800a3,0x00000000}},	// [15a20] czci, ङ्गः_, neòl, --, 
   {{0xa37800d8,0x753401e3,0x00000000,0x00000000}},	//   trõe, _hoyz, --, --, 
   {{0xa7581a4c,0x0f480092,0xe3bc00a2,0x42c88b0a}},	//   נדער, _መከልከ, dyñy_, _өгөн_, 
   {{0xa3780798,0xa3dc23ef,0x9cc47a71,0x00000000}},	//   rrõe, दूक_, быша_, --, 
   {{0x06c8045e,0x6b44008c,0xec14d22b,0x75340419}},	//   _শাসি, _aðga, селә_, _moyz, 
   {{0xe3bc010e,0x00000000,0x00000000,0x00000000}},	//   gyñy_, --, --, --, 
   {{0xa378000d,0x00000000,0x00000000,0x00000000}},	//   duõl, --, --, --, 
   {{0x321c005b,0xdbb80166,0x00000000,0x00000000}},	//   ätyy_, _әттә_, --, --, 
   {{0x6d40002d,0xe5a00150,0x66c80798,0x00000000}},	//   mkoa, _ﺍﻟﺘﻭ_, лунг_, --, 
   {{0xeb98f5f2,0x6d40f5f3,0x06c80154,0xe7a400d1}},	//   _сиз_, lkoa, _শাহি, لۇچى_, 
   {{0x6d40005a,0xe81409ae,0x7af403e0,0x2b580210}},	//   okoa, तिहा_, _özta, ęzcą_, 
   {{0x6d4001c0,0xdcf800e4,0x38680010,0xda6c009f}},	//   nkoa, _ohuĝ, _žare_, _ثُم_, 
   {{0x6d4001c6,0x4aac00af,0xa49801ab,0xdb08007c}},	//   ikoa, _चलाव, ceòl, spgå, 
   {{0xdb08b0aa,0x644cf5f0,0x6d400108,0x2794004e}},	//   ppgå, rzci, hkoa, _ушер, 
   {{0x6fa001b0,0x644cf5f4,0x6d40f5f5,0xc10400ec}},	//   _कंजू, szci, kkoa, يوسي, 
   {{0x88d400b8,0x6ef00162,0xc6140210,0x00000000}},	//   _sṛje, yðbó, तटीय_, --, 
   {{0xdd9802dd,0xd9180115,0x00000000,0x00000000}},	// [15a30] ңше_, נומל, --, --, 
   {{0x2918013f,0x6d40f5f6,0x4fd40108,0x1ee404f2}},	//   _ɔpaa_, ekoa, яжут, صوصی_, 
   {{0x23ac00a2,0x2bc40b72,0xec380014,0xc0f801af}},	//   _hüj_, रीसा, یقٔژ_, _кенє_, 
   {{0x6d40020c,0x61e40477,0xb06400d7,0xae2400db}},	//   gkoa, mujl, _späť, تومۉ, 
   {{0x39b4002b,0xd59c010f,0xdef80408,0xada000d7}},	//   _māse_, אבאל, _йыв_, _šúch, 
   {{0x6d40f5f7,0x6ef00008,0x614003b2,0xd97400ee}},	//   akoa, rðbó, bílæ, әркә_, 
   {{0x6d8800a2,0x00000000,0x00000000,0x00000000}},	//   mýan, --, --, --, 
   {{0x6d880209,0xa3780254,0x6d5801e1,0x2bd0912c}},	//   lýan, duõm, _ìtap, _सिचा, 
   {{0x61e40113,0xabb4f5f8,0x2710015b,0x00000000}},	//   hujl, _матә, ়ানো_, --, 
   {{0xf7708fcb,0x6d8800ee,0xa498067c,0x00000000}},	//   باب_, nýan, reòl, --, 
   {{0xf5041553,0x6d8800a2,0x49b8f5f9,0x00000000}},	//   озно, iýan, _هاند_, --, 
   {{0xc328025f,0x2bc4d967,0x2f08033f,0x69dc00d0}},	//   _בו_, रीवा, mógł_, špec, 
   {{0x61e40369,0x39b40055,0x6d88010b,0x2bd0000d}},	//   eujl, _dāse_, kýan, _सिछा, 
   {{0x394cf5fa,0x6d400323,0xa3c80037,0x00000000}},	//   lhes_, zkoa, _लबर_, --, 
   {{0x7158f5fb,0x95b00139,0x6d8800ee,0x00000000}},	//   арас_, _эрлә, dýan, --, 
   {{0x394c068c,0x99840024,0x6d40005a,0x2fd001bf}},	//   nhes_, mynų_, xkoa, tsyg_, 
   {{0x99840153,0x00000000,0x00000000,0x00000000}},	// [15a40] lynų_, --, --, --, 
   {{0xdee0f5fc,0x2eec04cc,0x6d88010e,0x00000000}},	//   дофи, üff_, gýan, --, 
   {{0x6d40f5fd,0x2fd0005c,0xe2940354,0x998400c0}},	//   tkoa, ssyg_, _маь_, nynų_, 
   {{0x88d4002b,0xac84026b,0x00000000,0x00000000}},	//   _gṛhe, огел, --, --, 
   {{0x394cf5fe,0xa018f5ff,0x6d40f600,0xeb98f601}},	//   dhes_, _szöv, rkoa, аид_, 
   {{0x6d40f602,0x00000000,0x00000000,0x00000000}},	//   skoa, --, --, --, 
   {{0x6d400d04,0xb53801e1,0xee38013d,0xfb1801d3}},	//   pkoa, _akọ́, _тнв_, صروں_, 
   {{0x394cf603,0xa018049b,0xad24f604,0x88b001d5}},	//   ghes_, _myön, _برسو, ریتچ, 
   {{0xa018005b,0x39b40055,0x2bc43c74,0x929002dd}},	//   _lyön, _rāse_, रीशा, _ﻓﻜﻴﻑ_, 
   {{0x2d840032,0xd1e40240,0x00000000,0x00000000}},	//   lloe_, _ዝሃቡ_, --, --, 
   {{0x2bc41b6e,0x394c014f,0xea580a5b,0x998400c0}},	//   रीरा, bhes_, _трај_, gynų_, 
   {{0x394c64a2,0xa3d40dba,0xe728297d,0x00000000}},	//   ches_, ाओल_, اسکو_, --, 
   {{0xd7ec0597,0x2d8400fb,0x249c2305,0x39b40055}},	//   _لكن_, iloe_, äum_, _vāse_, 
   {{0x2d84f605,0xddc80419,0xa6a874dd,0x00000000}},	//   hloe_, _čižn, _ئاشق_, --, 
   {{0x572000cf,0x782400db,0x00000000,0x00000000}},	//   _زىيك, _وعۇل, --, --, 
   {{0xdce8025c,0x61e401b9,0x910400db,0x00000000}},	//   mmgħ, rujl, мчуд, --, 
   {{0x61e4014f,0x98ac00ef,0x543400e5,0xbed8005a}},	// [15a50] sujl, _jogā_, _ہریر, йдах_, 
   {{0x394c0240,0x61e40334,0x00000000,0x00000000}},	//   zhes_, pujl, --, --, 
   {{0xa01800dd,0x6d880209,0x2d840076,0x61e40455}},	//   _gyön, rýan, floe_, qujl, 
   {{0x394c0023,0xd5f8008f,0x2d840166,0x00000000}},	//   xhes_, שפאר, gloe_, --, 
   {{0x2bc40316,0xdb08005c,0x00000000,0x00000000}},	//   रीला, opgø, --, --, 
   {{0x2d8400fb,0x9b2422c3,0x3f8402d2,0x6d880432}},	//   aloe_, юфел, _ólu_, lýal, 
   {{0x98ac0b23,0x394c378c,0x5d48030d,0xf0a801e1}},	//   _aogā_, thes_, _вăйĕ, _áàá_, 
   {{0xe0dc007f,0x39800008,0x77c86741,0x00000000}},	//   _amòz_, jóst_, блиг_, --, 
   {{0x3b54010b,0x394c01d3,0xed1401d3,0x7af40205}},	//   _екар, rhes_, _رہوں_, _özto, 
   {{0xbb54f606,0x394cf607,0x99840024,0xdb1802d2}},	//   _عناب, shes_, tynų_, _gvuð, 
   {{0x7bc8004c,0x394c07ea,0x6d88010e,0x00000000}},	//   _hweu, phes_, kýal, --, 
   {{0xa3d4006d,0x7bc8f608,0xdcf8107d,0x99941a90}},	//   ाओं_, _kweu, _okuč, _بھتر_, 
   {{0xb9c8001f,0xa018023a,0xe7e04ca3,0x6d880432}},	//   _ሳለ_, _syön, _खिया_, dýal, 
   {{0x7bc800ec,0xe3c4056a,0xdce80064,0x00000000}},	//   _mweu, íñas_, rogę, --, 
   {{0x321c0306,0xb9e40023,0x00000000,0x00000000}},	//   íty_, _ያእ_, --, --, 
   {{0x9f4c006a,0xf0a8f609,0xe28001d5,0xa01801f4}},	//   îgî_, скал_, хлси, _vyön, 
   {{0x764000ee,0x7bc80142,0xd13001d9,0x00000000}},	// [15a60] lyly, _nweu, _یۅس_, --, 
   {{0xa018049b,0x76400076,0xab780150,0x00000000}},	//   _työn, oyly, _ﺠﻬﺎﻟ_, --, 
   {{0x2d849181,0xd1e4044e,0x7bc80c6a,0x764000ee}},	//   tloe_, _ዝሃቦ_, _aweu, nyly, 
   {{0x66e001e1,0x7640062c,0xace801d5,0x00000000}},	//   _kíkà, iyly, смда_, --, 
   {{0xfca8314c,0x2d84cc26,0x7c6401d5,0x28a40116}},	//   زانو_, rloe_, واهل, үшиг, 
   {{0x7bc80cfd,0x764000ee,0x2d840072,0x98ac00b8}},	//   _dweu, kyly, sloe_, _rogā_, 
   {{0x7bc80c6a,0x395c0fac,0x66e001e1,0x20040356}},	//   _eweu, _bmws_, _líkà, ănie_, 
   {{0x764000ee,0x38680010,0xb9600248,0x00000000}},	//   dyly, _žara_, _àìle, --, 
   {{0x7bc87c48,0x764000ad,0xe78407ee,0xb4c800ab}},	//   _gweu, eyly, зуно, _लड़े_, 
   {{0x205400df,0xf968004e,0xe8f8010a,0x00000000}},	//   פייל_, йрөй_, _ӳле_, --, 
   {{0xaa88046f,0xfcf0044e,0xe8f80114,0xe87400e5}},	//   _انام_, _ፍሉጥ_, _гле_, _کااظ, 
   {{0xe0dc007f,0xb8640451,0x6d8800a2,0x00000000}},	//   _elòj_, _ڪامو, kýam, --, 
   {{0x4ad02c35,0xa88844f0,0x7640062c,0x58808984}},	//   _सजाव, _уйда_, ayly, _пыша, 
   {{0xd3a4035b,0x764055e3,0x39b40055,0xb86491e5}},	//   ерсп, byly, _hāsa_, _تامو, 
   {{0xb9080016,0x398001a8,0xa3780037,0xd6f8011a}},	//   _nghề_, póst_, nuõi, _הפוכ, 
   {{0xc1047427,0xd6240640,0x26cc0368,0x00000000}},	//   بوري, _хоће_, _hefo_, --, 
   {{0x3f14f60a,0x26cc01e4,0x39b41a14,0xe19000cf}},	// [15a70] мдас, _kefo_, _māsa_, _үлпө, 
   {{0x7bc8004c,0x26ccf60b,0xa3780254,0xd08400c7}},	//   _rweu, _jefo_, kuõi, хыси, 
   {{0xc5f8005f,0xa018005b,0xbf0c012d,0x00000000}},	//   ntē_, _työo, _हसीन_, --, 
   {{0xfbd00f87,0x4e9401b9,0x39b40055,0xa3780254}},	//   نتت_, رشلر, _nāsa_, duõi, 
   {{0x764000ee,0x69dc5956,0x6b4408a5,0xbb740408}},	//   zyly, ápen, _iðgj, мукъ, 
   {{0x98bc01a6,0xa49801ab,0x592c0327,0x0c740133}},	//   rkuč_, geòi, _ྨོངས_, ردند, 
   {{0x60ccf60c,0x7d1c00db,0x61f403e3,0xa378000d}},	//   _kecm, _ósso, _çalğ, ruõh, 
   {{0x23600113,0x60cc0356,0xa018005b,0xa3780254}},	//   hijj_, _jecm, _lyöm, suõh, 
   {{0x25ac0e78,0x39b400b8,0x3774a9e4,0x60ccf60d}},	//   _aufl_, _dāsa_, дынс, _mecm, 
   {{0xb4e41ab2,0xe0dc033b,0x0c040014,0x70a80fe3}},	//   कल्प_, _blòk_, _سومُ, _कल्ल, 
   {{0x26ccf60e,0xf77001d3,0x00000000,0x00000000}},	//   _defo_, ٹاک_, --, --, 
   {{0x76400209,0x637c00bc,0x60cc0790,0x09b400eb}},	//   ryly, háně, _necm, _টিচা, 
   {{0x26cc0421,0x79880327,0xbf0c0073,0x580001d5}},	//   _fefo_, mlew, _हसून_, _чолғ, 
   {{0x7988f60f,0x26cc0009,0xa0180108,0x8afc0210}},	//   llew, _gefo_, _vyöl, _ujęt, 
   {{0x59080135,0x798801c8,0x60cc003a,0x69cc0fac}},	//   _ཁྲོས_, olew, _becm, _æbet, 
   {{0xa01802f6,0xe294f610,0x26ccf611,0xefc801c6}},	//   _työl, фас_, _zefo_, жлал_, 
   {{0x79880a73,0x21643129,0xa01801ed,0xcbe80154}},	// [15a80] ilew, фити_, _ször, _গন্ধ_, 
   {{0xa01800e5,0xb35400e5,0x79880a43,0x00000000}},	//   _gyöm, _کیڑا_, hlew, --, 
   {{0xed5801c0,0x7988f612,0xd04c03b9,0x7298010a}},	//   оож_, klew, _əhən, _фонĕ, 
   {{0x2b5c0ba1,0x60cc2ba3,0x00000000,0x00000000}},	//   _smtc_, _gecm, --, --, 
   {{0xdca0f613,0x7988f614,0x5908031c,0x9b9001b9}},	//   ваци, dlew, _ཁྲེས_, چلنت, 
   {{0x7988f615,0xe454008f,0x0a9400d4,0x00000000}},	//   elew, וינט_, налю, --, 
   {{0xdee0147e,0x26cc01f5,0x99d0027d,0xacf40b3e}},	//   _јоси, _refo_, نتيا, _очај, 
   {{0x4814f616,0x26ccf617,0x996029a3,0x79885337}},	//   емис, _sefo_, ктыл, glew, 
   {{0x26cc01ee,0x25ac01ab,0x0f380092,0x1b000011}},	//   _pefo_, _sufl_, _በማስረ, লয়ে_, 
   {{0x7c2c0158,0x7988002e,0x00000000,0x00000000}},	//   åare, alew, --, --, 
   {{0x798814dc,0x6ab8020c,0x26cc0165,0xa0180108}},	//   blew, _iftf, _vefo_, _ryöm, 
   {{0xe3c41709,0xc5f800da,0xa01802f6,0x79880c8c}},	//   íños_, rtē_, _syöm, clew, 
   {{0x26ccf618,0xc5f8005f,0x60cc0010,0x2738013a}},	//   _tefo_, stē_, _recm, _páně_, 
   {{0xc5f800e2,0x06c80154,0x21f400ad,0x60cc0bbc}},	//   ptē_, _শাকি, tçh_, _secm, 
   {{0xe814095f,0x442c084c,0x6728025c,0x5ba8000d}},	//   तिका_, ţe_, _infj, _चढ्व, 
   {{0x21f40363,0xded40023,0x00000000,0x00000000}},	//   rçh_, _ርድኡ_, --, --, 
   {{0xa01802f6,0x60cc005f,0xe2a80014,0xefd40023}},	// [15a90] _työm, _vecm, _وادن_, _ካባይ_, 
   {{0x1ea805d4,0xa01802f6,0x29d802b1,0xf61000a2}},	//   زائي_, _hyök, kīa_, _çüýi_, 
   {{0x79880100,0x637c012c,0xa280f619,0x656c0f09}},	//   ylew, ráně, _شیرو, onch, 
   {{0x656c679d,0x40340ee1,0x00000000,0x00000000}},	//   nnch, _земс, --, --, 
   {{0x656cf61a,0xdb8c02d3,0xe0dc004e,0x69d80427}},	//   inch, _ዝቃወም_, _idò_, _avte, 
   {{0x98ac006d,0x656c0e78,0x8d9415bf,0xcbe00303}},	//   _mogą_, hnch, ىلەش, _निरञ, 
   {{0x3f80f61b,0x533800c8,0x656c0113,0x9510031c}},	//   mohu_, ונגן_, knch, _ཏྲའི_, 
   {{0x3f80f61c,0xa0180108,0x00000000,0x00000000}},	//   lohu_, _nyök, --, --, 
   {{0x7988f61d,0xa0e0005f,0x69d80205,0xa0180108}},	//   rlew, dēļā_, _evte, _syöj, 
   {{0x656cf61e,0x4c700184,0x27e00122,0x3f80f61f}},	//   ench, _әҫәр, ákna_, nohu_, 
   {{0x79880857,0x63bc003a,0x2128067c,0xcb3400a7}},	//   plew, _atqn, _onch_, _шефъ, 
   {{0x2bc41fc4,0x672802d0,0x29a400c7,0xe0dc0241}},	//   रीका, _enfj, _зычҳ, _ndò_, 
   {{0x3f80f620,0x977046e8,0x7bd8f621,0x428c0150}},	//   kohu_, _иткә, nswu, _ﺼﺭﺍﷲ_, 
   {{0x2128f622,0x656cf623,0x1cbc031c,0x3f80036e}},	//   _anch_, anch, _གཅའ_, johu_, 
   {{0x39b400b8,0xe29401af,0xaac400bc,0xf1ac0116}},	//   _māso_, еар_, _र्फक, _ﻳﺎﻗﺘ, 
   {{0x41e0256a,0x1f6002a9,0xa01801d3,0xdbc40205}},	//   _फिरस, ҳкум, _gyök, _göçt, 
   {{0xa11000db,0x00000000,0x00000000,0x00000000}},	// [15aa0] دوقت, --, --, --, 
   {{0xa018049b,0x212802e2,0x7bd8002d,0x3f80036e}},	//   _myöh, _ench_, dswu, gohu_, 
   {{0xd25004a9,0xb640010a,0x3b7c001f,0x6d8800a2}},	//   _ئۆز_, _ｍｓ_, _እቃዎች_, lýai, 
   {{0xfd4c063f,0xe45c01b8,0x69dc0306,0x00000000}},	//   _ighọ, ibön_, ápem, --, 
   {{0x69d801c4,0xa498004e,0x3f801155,0x6b6401d5}},	//   _svte, mfòc, bohu_, нкда, 
   {{0x9510025c,0x29d800b0,0xa37800e4,0x2bc4024a}},	//   _ཏིའི_, tīa_, yrõm, रीगा, 
   {{0x656cf624,0x39b400b8,0xad5800c0,0x00000000}},	//   ynch, _dāso_, _ерах_, --, 
   {{0x1cbc0135,0x69d800d7,0x00000000,0x00000000}},	//   _གཅར_, _vvte, --, --, 
   {{0x4ba40046,0x64c002e3,0x0ccc012c,0x65c400d1}},	//   _алаң, ọikw, ारीम, ﯩﺘﯩﻠ, 
   {{0xc0d40020,0x76b80228,0x69d800b5,0xa018023a}},	//   _ርዕስ_, үлөр_, _tvte, _syök, 
   {{0xa3d00b4c,0xfd4c0521,0xa0180108,0x00000000}},	//   हीन_, _nghọ, _pyök, --, 
   {{0x656c8350,0x75f4008e,0x26c00115,0x3f800200}},	//   unch, _süzç, ŝko_, zohu_, 
   {{0x1cbc31d9,0xfd4c0521,0xd4044705,0x656cf625}},	//   _གཅལ_, _aghọ, ляри, rnch, 
   {{0x98a0010a,0xb9fc0092,0x18a02083,0xf4d002dd}},	//   _сиче, _ሀቅ_, _сачм, _ﻛﯩﺸﻜ, 
   {{0xa018049b,0x656c0113,0x8afc033f,0x00000000}},	//   _työk, pnch, _zmęc, --, 
   {{0x7f8407d6,0x00000000,0x00000000,0x00000000}},	//   چلرن, --, --, --, 
   {{0x3f800325,0xa184010b,0x21280208,0x7f8407d6}},	// [15ab0] tohu_, _җынл, _vnch_, نلرن, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3f8002d3,0x00000000,0x00000000,0x00000000}},	//   rohu_, --, --, --, 
   {{0xf4280030,0x3f80bbaa,0xe2a800f2,0x00000000}},	//   späť_, sohu_, _واگن_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x63780af2,0x6d480023,0x7bd8000f,0xa3d001f9}},	//   tîny, ëfar, rswu, हीय_, 
   {{0x7bd804d1,0xce94013e,0xddc80024,0xc1c401ec}},	//   sswu, _баръ, čiųj, _ﯨﻤﺪﺍ, 
   {{0x8d844ecc,0x7bd8000f,0x6cb002dd,0x00000000}},	//   _бууд, pswu, _көшт, --, 
   {{0xc0d4001f,0x1b000139,0x28b007f7,0xa3d00073}},	//   _ርዕሰ_, _бүлн, ीड़ि, हीम_, 
   {{0xa018005b,0x00000000,0x00000000,0x00000000}},	//   _vyöh, --, --, --, 
   {{0xbe6002d3,0x00000000,0x00000000,0x00000000}},	//   _ጋዜጣታ, --, --, --, 
   {{0xa01802f6,0x98c400c6,0xa378000d,0x53c40150}},	//   _työh, _أغان, lrõh, ламұ, 
   {{0xd90c00e5,0x00000000,0x00000000,0x00000000}},	//   _نیں_, --, --, --, 
   {{0x56f001f0,0x00000000,0x00000000,0x00000000}},	//   _сӯис, --, --, --, 
   {{0x764c0198,0x00000000,0x00000000,0x00000000}},	//   _ƙayu, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa06423b3,0xe040ed7b,0x4f0401ec,0x00000000}},	// [15ac0] вата_, анти, лжағ, --, 
   {{0xdfcc00c6,0x69dc00e4,0xa03000db,0x00000000}},	//   تيك_, ápek, جىكت, --, 
   {{0xada4d035,0xfe740137,0x00000000,0x00000000}},	//   важл, гүр_, --, --, 
   {{0x69dcb515,0x95100327,0xe7e0012d,0x00000000}},	//   špek, _ཏིསི_, _खिला_, --, 
   {{0xec140cef,0x103400f2,0x00000000,0x00000000}},	//   телә_, _صبحگ, --, --, 
   {{0x7c2c00cc,0x31700432,0x00000000,0x00000000}},	//   åara, lnyz_, --, --, 
   {{0x65bcf626,0x5b30103c,0x9ea4030d,0x00000000}},	//   _kīhe, شعور, _авра_, --, 
   {{0x27e00308,0xc0d40092,0x88947125,0xd9e000c5}},	//   ákno_, ርፉር_, лийх, _गिरत_, 
   {{0xdca03f12,0x5d64273d,0xac8400c7,0x7aec01e7}},	//   _вати, _ритм_, _ргал, ánté, 
   {{0x98ac0034,0x4734f627,0x1cbc031c,0xc6900014}},	//   _mogę_, унос, _གཅོ_, یِک_, 
   {{0x69f0f628,0xf52c0092,0x00000000,0x00000000}},	//   _түйт, _እረኝነ, --, --, 
   {{0x6b980051,0x00000000,0x00000000,0x00000000}},	//   _hhtg, --, --, --, 
   {{0x68e053dd,0xa018005b,0x98ac012d,0xe7380117}},	//   _idod, _työi, _nogę_, _оед_, 
   {{0xc4340014,0xe76800f2,0x00000000,0x00000000}},	//   ٖکھت, _تحصن_, --, --, 
   {{0x96f436fe,0xf1c40022,0x00000000,0x00000000}},	//   _شعور_, ñápa_, --, --, 
   {{0x44f41064,0x1cbc031c,0x660000fb,0x00000000}},	//   _спис, _གཅེ_, _боҫҡ, --, 
   {{0x2904013f,0x68e0009f,0xdef8034b,0xf0780124}},	// [15ad0] _mboa_, _mdod, дые_, еитә_, 
   {{0x3ed4f629,0x68e0000f,0x57f8011a,0x00000000}},	//   اقار, _ldod, ולמו, --, 
   {{0xe0dc0ba1,0x29040295,0xc0c40131,0x68e00cad}},	//   _blòt_, _oboa_, _бәзи, _odod, 
   {{0x68e0f62a,0xe0dc067c,0x6b98005a,0x20c8038b}},	//   _ndod, _clòt_, _ahtg, _تبدي_, 
   {{0x2b9000d2,0x7eb800ae,0x0c7801ec,0x3b080798}},	//   gâco_, _cúpó, ксшы_, еело_, 
   {{0x2904013b,0x68e0f62b,0x660802d0,0x875001ec}},	//   _aboa_, _adod, _opfk, _ﯗﺭﻻﭖ_, 
   {{0xa3d005ba,0xe0dc007f,0x4ea40120,0x6ea00073}},	//   हीत_, _flòt_, _врта, केदु, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x778448bd,0x68e003cb,0x00000000,0x00000000}},	//   ллиз, _ddod, --, --, 
   {{0x68e00472,0x200800ca,0x35c8009d,0x00000000}},	//   _edod, _mpci_, нгоо_, --, 
   {{0x9a840124,0x68ec0332,0x00000000,0x00000000}},	//   _руал, áidé, --, --, 
   {{0x67380240,0xb4bc07f7,0x332406be,0x00000000}},	//   ajtj, इडे_, _şox_, --, 
   {{0xe2940046,0x394c0b21,0x37e4f62c,0xf1d001c6}},	//   ғат_, mkes_, _солг, өөнө, 
   {{0x6d580006,0x2d6801e4,0xd1dc069d,0xda14000d}},	//   _įtam, nĝer_, ዕለቱ_, _दनात_, 
   {{0x41b4f62d,0x65bc02b5,0xd58804d3,0xe2781cd1}},	//   истт, _pīhe, _لێده_, ештә_, 
   {{0x394cf62e,0xa498f62f,0xe29400d8,0x00000000}},	//   nkes_, mfòn, ѓат_, --, 
   {{0xe0dcf630,0x394c002d,0xa3d001ad,0x00000000}},	// [15ae0] _alòs_, ikes_, हीद_, --, 
   {{0xdfcc86bf,0xa0a00220,0x1cbc031c,0xa498004e}},	//   سيم_, сауд, _གཅུ_, meòp, 
   {{0x394c5d16,0x32440fae,0x6ce456a4,0xece8f631}},	//   kkes_, _сенг, гіле, едел_, 
   {{0x6b9801a9,0x3218f632,0xa0180108,0x394cf633}},	//   _shtg, _ispy_, _ryöv, jkes_, 
   {{0xa018023a,0x7fd40a4a,0xfca80244,0x00000000}},	//   _syöv, _вісі, ناهو_, --, 
   {{0x256802bd,0x394c002d,0xaae40214,0x00000000}},	//   _kòlè_, ekes_, اسشو, --, 
   {{0x394c0b21,0x2d94f634,0xbae402bf,0xed586af5}},	//   fkes_, _брас, рцій, _зов_, 
   {{0x49a43e64,0xabd40014,0x2d680115,0x00000000}},	//   шылғ, _مٲرت, rĝes_, --, 
   {{0xa378f635,0xa3d00550,0x00000000,0x00000000}},	//   lsõe, _हौं_, --, --, 
   {{0xa01802f6,0x1c4001b9,0x6128013d,0x2d840129}},	//   _työv, _унум, _kölä, looe_, 
   {{0xd5b477c6,0xa378f636,0xa01802f6,0x9f480098}},	//   лся_, nsõe, _hyöt, émés_, 
   {{0x29040117,0x23ac025c,0x394c11a1,0x1a98010f}},	//   _uboa_, _ażja_, ckes_, _װידע, 
   {{0x07340251,0xb8c400cf,0xe78401d5,0x6d880432}},	//   _велю, _ئزمى, _йуко, lýas, 
   {{0xa01802f6,0x461433ae,0x00000000,0x00000000}},	//   _myöt, _نوتر, --, --, 
   {{0xa018005b,0x0d0438d2,0x00000000,0x00000000}},	//   _lyöt, रभाष_, --, --, 
   {{0x386809a8,0x6d8800a2,0x00000000,0x00000000}},	//   _žari_, iýas, --, --, 
   {{0x32180076,0xd4e40108,0x6d88010e,0x0fe400db}},	// [15af0] _espy_, _ующи, hýas, йөрү, 
   {{0x4428f637,0x61280139,0xc1b801a9,0x0354586a}},	//   _ira_, _bölä, _илох_, _түгә_, 
   {{0x442804bf,0x394c00b5,0x94740133,0xa3780254}},	//   _hra_, ykes_, _ندیا, rsõd, 
   {{0x4428f638,0x2e4800d2,0xa37800c5,0x77340023}},	//   _kra_, _sîfú_, ssõd, _ክወስደ, 
   {{0x4428493a,0x44382370,0xa378000d,0x5c200154}},	//   _jra_, nxs_, msõb, বঙ্গ_, 
   {{0x9f5cf639,0xdcf8353f,0xe0dc01c3,0x386802d2}},	//   örän_, _okuć, _glòr_, _þari_, 
   {{0x442821b6,0x06700131,0x394cf63a,0x3ea401ab}},	//   _lra_, ﻼﺭﻧﯩ, tkes_, _àlt_, 
   {{0x4428f63b,0x3944016c,0xb7e4004e,0x00000000}},	//   _ora_, рниг, ажик, --, 
   {{0x394cf63c,0x4428f63d,0x3ab004a9,0x4c94010b}},	//   rkes_, _nra_, _һәқт, _гитс, 
   {{0x394cf63e,0x7c28f63f,0x443804d4,0x75c00171}},	//   skes_, _irer, dxs_, _lēze, 
   {{0x394cf640,0x499000f1,0xa3d01d94,0xa0180108}},	//   pkes_, _ډیور, हीस_, _kyös, 
   {{0x4428f641,0x6d580006,0x6d880209,0x7c280023}},	//   _bra_, _įtak, lýar, _krer, 
   {{0x7d08f642,0xa01802f6,0xd1dc0023,0x00000000}},	//   _mbes, _myös, ዕወት_, --, 
   {{0x4428f643,0x6d880209,0xb6a448bd,0xdcf80055}},	//   _dra_, nýar, _килл, _bhuī, 
   {{0x4428f644,0x48a81945,0x80ac009e,0xe79402f2}},	//   _era_, _итәм_, টুম্, _ئانک, 
   {{0x44281578,0x7c28f645,0x7d08020c,0x39b4002b}},	//   _fra_, _orer, _nbes, _cāsi_, 
   {{0x4428f646,0x7c2801e1,0xf0a8f647,0x612800fd}},	// [15b00] _gra_, _nrer, ткал_, _sölä, 
   {{0x7d0849b3,0x65bc02b5,0x612801f4,0xdd1c00d7}},	//   _abes, _hīha, _pölä, _ríšs, 
   {{0x7c28f648,0x65bc0053,0xa018049b,0x7d08009a}},	//   _arer, _kīha, _syöt, _bbes, 
   {{0x44284077,0x7c28f649,0xa37806ed,0x2cb0f64a}},	//   _yra_, _brer, rsõe, øyd_, 
   {{0xa3780261,0x65bc04fe,0x7c28021c,0x7d080010}},	//   ssõe, _mīha, _crer, _dbes, 
   {{0x7d08f64b,0x65bc0093,0xa018023a,0x6b4408a5}},	//   _ebes, _līha, _vyöt, _aðgr, 
   {{0x7c2808e7,0x8c600046,0xdee0cbbe,0x6da411f7}},	//   _erer, нiң_, _фоси, _вива, 
   {{0x7c28f64c,0xa018049b,0x7d080cad,0x1cbc031c}},	//   _frer, _työt, _gbes, _གཅག_, 
   {{0xaba854a2,0x7c28037e,0xdcf800f3,0x6d8803b2}},	//   _аваз_, _grer, _skuć, býar, 
   {{0x4428f64d,0x7d0800d7,0xb8fc000d,0x00000000}},	//   _rra_, _zbes, _तड़_, --, 
   {{0xe8f8f64e,0x4428f64f,0xe9d800d8,0x05d001f9}},	//   _але_, _sra_, _рке_, थींब, 
   {{0x4428f650,0x69c8f651,0x44380175,0x7d0001d3}},	//   _pra_, mpfe, txs_, máró, 
   {{0x75c0005f,0x69c8b915,0x7d00f652,0x00000000}},	//   _rēze, lpfe, láró, --, 
   {{0x44280591,0x69c8000f,0xe7440254,0x00000000}},	//   _vra_, opfe, õõdu_, --, 
   {{0xe16415ed,0xdcf80552,0x539002d3,0x67545022}},	//   ађан, _ukuć, _ሓጥያት_, _میکس_, 
   {{0x461405d9,0x69c8f653,0xaac4190c,0x00000000}},	//   _نوڪر, ipfe, रुतक, --, 
   {{0xa018023a,0xc2100014,0x0f380092,0x39b40055}},	// [15b10] _ryös, _کٔج_, _በማምረ, _vāsi_, 
   {{0x7d08f654,0x1cbc0327,0xa498033b,0x69c8002f}},	//   _sbes, _གཅང_, nfòm, kpfe, 
   {{0xa3d00490,0xf2d0008d,0x7d0001d3,0x75c00171}},	//   हीर_, _מעי_, járó, _tēze, 
   {{0x69c80175,0x00000000,0x00000000,0x00000000}},	//   dpfe, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x1b78007b,0xfdd80451,0x7c28036e,0x00000000}},	//   خصصة_, _مارڻ_, _vrer, --, 
   {{0xa018a72c,0x6d880209,0xdda8f655,0x7d0001d3}},	//   _työs, rýar, _атал_, gáró, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x65bc02b5,0x7c28f656,0x00000000,0x00000000}},	//   _rīha, _urer, --, --, 
   {{0x9a840724,0x9ba034b1,0x6d580024,0x160401d5}},	//   _куел, _بەتى, _įtai, амоқ_, 
   {{0x65bc02b1,0x37a800f7,0x69dc02f0,0x00000000}},	//   _pīha, ктүн_, ápet, --, 
   {{0x38681a48,0x6e340375,0x00000000,0x00000000}},	//   _žaru_, צטרף_, --, --, 
   {{0xa3d00490,0x889400c7,0x798800b0,0x00000000}},	//   हील_, _дицх, moew, --, 
   {{0x65bc02b5,0x00000000,0x00000000,0x00000000}},	//   _wīha, --, --, --, 
   {{0x450c2f8b,0x65bc0374,0x00000000,0x00000000}},	//   ষয়ক_, _tīha, --, --, 
   {{0x2164566d,0x7c2c0115,0x00000000,0x00000000}},	//   биси_, ĥarj, --, --, 
   {{0x6140f657,0x25a80137,0x7d0001ed,0x59d40490}},	// [15b20] чета, ïble_, záró, णीतर, 
   {{0xa018049b,0x7988f658,0x2eb4b4d3,0x00000000}},	//   _pyör, hoew, ссас, --, 
   {{0xdd8c004b,0xa2b40375,0x71682cdd,0x00000000}},	//   ډول_, _לפיד_, _банг_, --, 
   {{0xd13000cf,0xa0180108,0x00000000,0x00000000}},	//   _تۅر_, _vyör, --, --, 
   {{0xdd8c27a1,0x39b400e2,0xdb1800ae,0x79880327}},	//   روه_, _māsu_, _stuá, doew, 
   {{0xa018023a,0xdfcc0f13,0xadb80214,0x7d0001d3}},	//   _työr, _سيف_, _مهسا_, táró, 
   {{0xda44011c,0x00000000,0x00000000,0x00000000}},	//   йчъл_, --, --, --, 
   {{0xa51405ba,0x69c80e78,0x22a0003e,0xa3d04ca3}},	//   _तसेच_, rpfe, léké_, हीँ_, 
   {{0x64a40574,0xeaf80597,0xec782c08,0x7d0001ed}},	//   _गणेश, _مرات_, _спа_, sáró, 
   {{0x69c82305,0x1ae002a9,0x00000000,0x00000000}},	//   ppfe, _ноум, --, --, 
   {{0x38680419,0x5690013d,0xdce80064,0x00000000}},	//   _žart_, заэт, gogė, --, 
   {{0x9f440745,0x39b40055,0x6b88022e,0xd940026b}},	//   čné_, _cāsu_, lofg, _нехи, 
   {{0xa3d0367a,0xa01801e3,0x00000000,0x00000000}},	//   हीं_, _nyöp, --, --, 
   {{0x69cc0327,0x24900092,0x00000000,0x00000000}},	//   _ħbej, _ማድረስ_, --, --, 
   {{0xe5c46bed,0x1794123b,0x9258761e,0x00000000}},	//   _усло, _הדגל_, барт_, --, 
   {{0x26dcf659,0x39b400b8,0xf1ac07d2,0xd1b80066}},	//   lato_, _tāsv_, _ﺳﺎﻧﺘ, صافا_, 
   {{0x200c025a,0x1b1c0011,0xbed8005a,0x00000000}},	// [15b30] ïgi_, পাতে_, идах_, --, 
   {{0x656cf65a,0x26dcf65b,0x358c02d3,0xb87c00df}},	//   lich, nato_, _ሓቅታት_, baŭf, 
   {{0x69c400b0,0x644c00c0,0x39b400b8,0xa2440066}},	//   _ōken, lyci, _yāsu_, _ایزل_, 
   {{0x656cf65c,0x26dcf65d,0xd5f8010f,0xe0840133}},	//   nich, hato_, רפאר, _هێزو_, 
   {{0x070813e0,0x506400d1,0x60dc6b88,0xcc081867}},	//   वभाव_, _етра, maqm, مزون_, 
   {{0x656cf65e,0x26dcf65f,0x60dc0784,0x00000000}},	//   hich, jato_, laqm, --, 
   {{0x656cf660,0x644c0368,0x798801f5,0xaa540114}},	//   kich, hyci, toew, жију_, 
   {{0x656cf661,0x60dcbff1,0xb87c0115,0x644c0153}},	//   jich, naqm, naŭg, kyci, 
   {{0x26dcf662,0x65bc06c8,0xe9a42f7c,0x79880ea0}},	//   fato_, _bīho, ڭگەن_, roew, 
   {{0x26dcf663,0x7bc80438,0x7988f664,0x60dc047e}},	//   gato_, _iteu, soew, haqm, 
   {{0xdb180166,0x60dc0309,0x69dc5752,0xf40c03d4}},	//   _atuç, kaqm, šper, িয়াৰ_, 
   {{0x656c1290,0x60dc014f,0xca485598,0x75c00171}},	//   gich, jaqm, _دلمه_, _cēza, 
   {{0x60dc014f,0xf4941291,0x00000000,0x00000000}},	//   daqm, تشدد, --, --, 
   {{0x26dcf665,0x7bc8b34c,0x656cf666,0xb87c010f}},	//   cato_, _mteu, aich, taŭf, 
   {{0x656cf667,0xa01802f6,0xf1a84fe0,0x22440276}},	//   bich, _syöp, لاره_, опри_, 
   {{0x656cf668,0x644c0034,0x22a000f2,0xb87c00df}},	//   cich, byci, wéké_, raŭf, 
   {{0x7b1000d0,0xa3780254,0xf1b40210,0x00000000}},	// [15b40] _kľuč, msõn, _आंकन, --, 
   {{0xa3780254,0x00000000,0x00000000,0x00000000}},	//   lsõn, --, --, --, 
   {{0x7bc8f669,0xb87c010f,0x00000000,0x00000000}},	//   _ateu, laŭd, --, --, 
   {{0xa018049b,0x26dcf66a,0x60dc03e3,0x00000000}},	//   _työp, zato_, caqm, --, 
   {{0x26dcf66b,0x6b88257c,0xb87c01e4,0x6dbc00d0}},	//   yato_, tofg, naŭd, _zďal, 
   {{0x656cf66c,0x26dc4f40,0xb91000dc,0x5c9402d5}},	//   zich, xato_, _iyaṃ_, цкія_, 
   {{0x26dcf66d,0x7bc81140,0x644c068f,0xde00f66e}},	//   vato_, _eteu, zyci, _опри, 
   {{0x26dcf66f,0x795401e1,0x2c6001a9,0x893800f3}},	//   wato_, _dáwo, _lаdi_, спис_, 
   {{0x656c0588,0x26dcf670,0x65bc9388,0x6d400561}},	//   vich, tato_, _pīho, mjoa, 
   {{0x69f00a52,0x656cf671,0x59d40316,0xd78407c0}},	//   _жүкт, wich, णीहर, ينيو_, 
   {{0x656cf672,0xf1b405f9,0x60dc0784,0xdeb808a8}},	//   tich, _आंगन, yaqm, ימיל, 
   {{0x26dcf673,0x6d40f674,0x656c037e,0x644c6dd3}},	//   sato_, njoa, uich, tyci, 
   {{0x656cf675,0xaadc256a,0x65bc02b1,0xb910002b}},	//   rich, _नजाक, _tīho, _nyaṃ_, 
   {{0xd7c4168d,0x27e45362,0x26dc01d9,0x6e2c01ab}},	//   _بووه_, _ivon_, qato_, _orbb, 
   {{0x656c07dd,0xb9100882,0xc0d402d3,0xd1c801c0}},	//   pich, _ayaṃ_, _ይቕረ_, жууд_, 
   {{0xa2c80a94,0x27e4022e,0x656cf676,0xb87c0115}},	//   _त्र्, _kvon_, qich, baŭd, 
   {{0x60dc0986,0x100402e8,0xb87c01e4,0x6d40031c}},	// [15b50] raqm, дяхм, raŭg, djoa, 
   {{0x6f0c0175,0xb91000b8,0x60dcbff1,0x8318007b}},	//   _cbbc, _dyaṃ_, saqm, _اقدر_, 
   {{0x1cbc025c,0x60dc0986,0x27e40162,0x9da80818}},	//   _གཅད_, paqm, _lvon_, аъда_, 
   {{0x27e40115,0x60dc34dd,0xd1b8150e,0x00000000}},	//   _ovon_, qaqm, _گایا_, --, 
   {{0x6e2c002f,0xcbc4027d,0x1b1c00eb,0x00000000}},	//   _erbb, وزوي, পাসে_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x27e4f677,0xf77000e5,0x00000000,0x00000000}},	//   _avon_, ہاد_, --, --, 
   {{0x27e40100,0xa2c801bc,0x8d840026,0x00000000}},	//   _bvon_, तुत्, _жууд, --, 
   {{0x7bc8f678,0xf77000ae,0xe7d401f9,0x00000000}},	//   _uteu, فاد_, ढीलप, --, 
   {{0x7d18033f,0x79540241,0x0978004e,0x8bc40150}},	//   lews, _táwo, йрөө_, _ісуд, 
   {{0xa37800c5,0xc7643ed0,0x6b78008f,0x2c60022e}},	//   tsõn, بايى, _פרענ, _rаdi_, 
   {{0x7d18f679,0xb87c010f,0x53c801d5,0x00000000}},	//   news, taŭd, оҳим_, --, 
   {{0x1cbc0003,0x09000022,0x00000000,0x00000000}},	//   _གཅན_, _рҿын, --, --, 
   {{0xa3780037,0xb87c010f,0xfbdc00cd,0x00000000}},	//   ssõn, raŭd, नीयम, --, 
   {{0xded40b82,0xb87c00df,0x63800064,0x9740012d}},	//   ርኩን_, saŭd, хгра, ęćdz, 
   {{0x27e4f67a,0x21648148,0x6140f67b,0x7d18033f}},	//   _yvon_, писи_, неса, jews, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [15b60] --, --, --, --, 
   {{0xa3780254,0x00000000,0x00000000,0x00000000}},	//   nsõl, --, --, --, 
   {{0xddc805d1,0x6d4095a2,0xa2b8011a,0x9f4800e5}},	//   ğişk, tjoa, _למיט, émás_, 
   {{0x7d1806a3,0xcad8015b,0xb91000b8,0x00000000}},	//   gews, _সাইফ, _tyaṃ_, --, 
   {{0x5ce0f67c,0x6d40049b,0xeb980117,0x00000000}},	//   ركول, rjoa, бид_, --, 
   {{0xa098008f,0x0a94187f,0x20040356,0xee3800f3}},	//   _ליכט, малю, ănit_, _лнг_, 
   {{0xab2802dd,0x27e402d2,0x90740092,0x00000000}},	//   _қожа_, _svon_, _በመቀሌ_, --, 
   {{0x1d04004e,0x29880114,0x6da401af,0x00000000}},	//   _неси_, љско_, _эҙең_, --, 
   {{0x48140212,0xab641920,0x3d10000d,0x00000000}},	//   ємос, _евал, _धउते_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd6d4f67d,0x4298069d,0x1b1c00eb,0x00000000}},	//   чты_, _መስኮት_, পাশে_, --, 
   {{0xd5b40a8f,0x19b8011a,0x9e74011a,0x7e6000a2}},	//   ясь_, _המאב, לגיה_, _ülpe, 
   {{0x1b1c00bd,0xb87c008f,0x27e4014b,0x8ca40034}},	//   পারে_, taŭe, _uvon_, _औरफो, 
   {{0xb9e407db,0x7c2c03be,0x7d18033f,0x00000000}},	//   _ካብ_, çirə, zews, --, 
   {{0x56900006,0x9258a8d7,0xb87c0115,0xe7e0000d}},	//   _пашт, парт_, raŭe, _गबडा_, 
   {{0x9f4402f8,0xbfd800d4,0xded41954,0x00000000}},	//   ční_, ждає_, ርዩን_, --, 
   {{0x51842d7f,0xdce80003,0xd1300014,0x00000000}},	// [15b70] хура, llgħ, ھمے_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d5802d5,0x63bc0784,0xc0c400d1,0x7d18012d}},	//   _įtar, _huqn, _жәзи, tews, 
   {{0x7c581ee2,0x3c1c0100,0x7c9c0023,0xd01001d3}},	//   يلار_, _pňv_, _ዝሓልፍ_, خلے_, 
   {{0x69d80135,0x63bc0309,0xc5f800de,0x00000000}},	//   _awte, _juqn, dzēm_, --, 
   {{0xb34000a2,0x7d180210,0x00000000,0x00000000}},	//   _üçto, sews, --, --, 
   {{0x1b1c045e,0xe0dc08e7,0x63b4f67e,0x69d80142}},	//   পালে_, _keò_, _mixn, _cwte, 
   {{0x62940066,0xdcf80010,0x77c8009d,0x0dc81503}},	//   _myxo, _kjuč, олиг_, _хури_, 
   {{0x69d8031c,0x63bc016d,0x1e340092,0x00000000}},	//   _ewte, _nuqn, _የሚጠና, --, 
   {{0xf5e8e813,0xe0dc01c3,0x6294022e,0xb87c00df}},	//   омол_, _leò_, _oyxo, taŭb, 
   {{0xdb00007b,0x69d80042,0x00000000,0x00000000}},	//   nmní, _gwte, --, --, 
   {{0xe0dc00a3,0xb87c010f,0xdb000332,0xa2c81a75}},	//   _neò_, raŭb, imní, तुस्, 
   {{0xc9744116,0xb9280241,0x00000000,0x00000000}},	//   _ثالث, _ootẹ_, --, --, 
   {{0x63b40369,0xe0dc0295,0x63bc014f,0x629401e6}},	//   _cixn, _aeò_, _duqn, _byxo, 
   {{0x6dbc01a2,0xe0dc0192,0xa2b00490,0x3cec00d0}},	//   _vďak, _beò_, _आणण्, _odev_, 
   {{0x3cec009a,0xe0dc01c3,0x63bc025c,0x92c004c5}},	//   _ndev_, _ceò_, _fuqn, ুণে_, 
   {{0xe0dc0086,0xb4e8185d,0x63b4f67f,0x0084004e}},	// [15b80] _deò_, मणी_, _fixn, ектү, 
   {{0xa0a00220,0x3cec0356,0x44a40166,0xaf98003b}},	//   тауд, _adev_, _ягың, ітах_, 
   {{0x764c02a8,0x00000000,0x00000000,0x00000000}},	//   _ƙayy, --, --, --, 
   {{0xdcf800f3,0xc10402dd,0x6d88010b,0x00000000}},	//   _fjuč, _كوپي, lýaz, --, 
   {{0x6c181f3c,0x2d800220,0x00000000,0x00000000}},	//   تتاح_, _ﯨﺸﻜﻰ_, --, --, 
   {{0xfca8352e,0x29d800b0,0x3cec000d,0x63b40139}},	//   سانو_, tūa_, _edev_, _xixn, 
   {{0x6e942be7,0xed586bb8,0x320833b8,0xc0d4069d}},	//   _آلزا, _дов_, ntby_, ርጉም_, 
   {{0x98780023,0x6cbc0150,0x00000000,0x00000000}},	//   _ይስምዑ_, _ﺠﺯﺃﻴ, --, --, 
   {{0xe78400c0,0x395c0042,0x7c2c0158,0xa49802e2}},	//   дуно, _dlws_, åart, nfòt, 
   {{0x45d4f680,0x29000034,0x6a14007b,0xdc5400f1}},	//   ноос, żka_, _يبار, _کرېک, 
   {{0x65bc02b1,0xdce800da,0x395c00d8,0x63bc047e}},	//   _kīhi, ligā, _flws_, _suqn, 
   {{0x63bc014f,0x395c0042,0x3208005c,0x00000000}},	//   _puqn, _glws_, dtby_, --, 
   {{0x65bc0374,0x69c400b0,0x00000000,0x00000000}},	//   _mīhi, _ōkeh, --, --, 
   {{0x59080135,0xe0dc00a3,0x9f5c05d1,0x623000c7}},	//   _གཡོས_, _seò_, örün_, вҵоу, 
   {{0xa2c826e4,0x268846bc,0x63bc0477,0x43940661}},	//   तुष्, _بخشي_, _wuqn, _җанс, 
   {{0x63bcf681,0x4544004b,0x61400131,0x759c0023}},	//   _tuqn, _سربې, خىرە, ገብርዎ_, 
   {{0x5ee000bd,0x43940a0e,0x63b400b8,0x320800d7}},	// [15b90] _পাবে, _паис, _tixn, atby_, 
   {{0xe0dc0295,0x00000000,0x00000000,0x00000000}},	//   _weò_, --, --, --, 
   {{0xfce402d3,0xb7d40248,0x4c9c01ec,0xdbc401f4}},	//   _ማዕጾ_, _iṣes, _ﺁﺭﺍﺀ_, _jööt, 
   {{0xa2c87922,0x4ea40902,0x4a0c0327,0xdbc40254}},	//   तुर्, труа, _གྱེལ_, _mööt, 
   {{0xa3d00574,0x8d7401d5,0x4fc400d1,0x00000000}},	//   हीच_, خالا, _لەقە, --, 
   {{0xfaa43da1,0x1ee4030f,0xbc640022,0x00000000}},	//   нало, _زوری_, _ҧхақ, --, 
   {{0x395c0142,0x8de801af,0x00000000,0x00000000}},	//   _plws_, _офта_, --, --, 
   {{0xd2b8025f,0xaa5400c6,0x3cecf682,0xa49802bd}},	//   ולות_, عليا_, _udev_, nfòs, 
   {{0xe8f4d5de,0x8afc002d,0x395c00d8,0x88c40131}},	//   хлы_, _blęd, _vlws_, ختىل, 
   {{0xa37800c5,0x8ca4033f,0xdb20007c,0x00000000}},	//   ssõj, _औरतो, åräm, --, 
   {{0xf6506bd8,0x395c03cb,0x00000000,0x00000000}},	//   ائخ_, _tlws_, --, --, 
   {{0xb7d401e1,0xc8c805d9,0xb4e801bc,0xef500023}},	//   _aṣes, _قومن_, मणे_, _ዘየድል, 
   {{0x7ae0f683,0x580000fb,0x00000000,0x00000000}},	//   _kelt, _ролғ, --, --, 
   {{0x7ae0f684,0xa2c8146b,0x32082d8b,0xf1d000db}},	//   _jelt, तुल्, ttby_, лөмө, 
   {{0xf67800c8,0x7ae0f685,0x00000000,0x00000000}},	//   _מאַמ, _melt, --, --, 
   {{0xe294f686,0x3208030d,0x85940022,0xddc80139}},	//   хас_, rtby_, _ишыц, _şişo, 
   {{0x65bc02b1,0x32088fee,0x0424035b,0xe43000c6}},	// [15ba0] _rīhi, stby_, _азыҟ, _مفيد, 
   {{0xdce81a5a,0x00000000,0x00000000,0x00000000}},	//   vigā, --, --, --, 
   {{0x65bc00b0,0xfcf00023,0x9be002dd,0x00000000}},	//   _pīhi, _ግሉጽ_, ңішк, --, 
   {{0x9f44b7f2,0x6c84198a,0xb87c0115,0x37d400fe}},	//   čná_, ىلام, zaŭa, _দিনৰ, 
   {{0xdca0f687,0x7ae0f688,0xa498067c,0x3074030d}},	//   гаци, _belt, lfòr, _чунс, 
   {{0x59080dd4,0x7ae0982e,0x8cd03885,0x00000000}},	//   _གཡུས_, _celt, _ड्रो, --, 
   {{0x65bc166a,0xa498180f,0xa6dc0154,0x69ac0118}},	//   _kūhe, nfòr, _মালয়, ुदली, 
   {{0x6f1c0276,0x7ae0f689,0xaa8400a2,0xa498067c}},	//   lepc, _eelt, _akýü, ifòr, 
   {{0x7ae0f68a,0xb87c008f,0x5ee02b1b,0xdbc400c5}},	//   _felt, taŭa, _পাতে, _sööt, 
   {{0x7ae0f68b,0x3a240175,0x9810f68c,0x65bc0055}},	//   _gelt, _fslp_, ابيا, _lūhe, 
   {{0xa9f805f5,0xb87c008f,0x00000000,0x00000000}},	//   _ххзх_, raŭa, --, --, 
   {{0x7ae0f68d,0xd6ccf68e,0xd7c40330,0x9f58036e}},	//   _zelt, _әт_, بویه_, tuqë_, 
   {{0x94a816a8,0xe738d75f,0x7ae00166,0x94841df9}},	//   етра_, _нед_, _yelt, гырд, 
   {{0xdbc4033d,0xb8649beb,0x68e0f68f,0x6f1c0841}},	//   _tööt, _جامو, _heod, jepc, 
   {{0x68e00489,0xc694010f,0x00000000,0x00000000}},	//   _keod, _באַ_, --, --, 
   {{0x6728003b,0x91040137,0x68e00205,0x5698011a}},	//   _hafj, лчуд, _jeod, _מיוצ, 
   {{0xa498067c,0xd010004b,0x6728036e,0x68e00051}},	// [15bb0] rfòs, یلې_, _kafj, _meod, 
   {{0x68e0f690,0xa3780254,0xd47c011a,0x00000000}},	//   _leod, ksõi, _מאחל, --, 
   {{0x29040589,0x1ea83738,0x7ae00072,0x672861af}},	//   _ocoa_, سائي_, _relt, _mafj, 
   {{0x7ae0f691,0x3a24010a,0xe67800bc,0xdb000118}},	//   _selt, _rslp_, _něčí, dmná, 
   {{0x7ae0f692,0x212800a9,0xa3780037,0xd0180108}},	//   _pelt, _iach_, esõi, _пфр_, 
   {{0x2128f693,0x65bc02b5,0x7ae07443,0x00000000}},	//   _hach_, _hīhu, _qelt, --, 
   {{0x7ae0f694,0x2128f695,0x3f800099,0x4e28013e}},	//   _velt, _kach_, mnhu_, _поён_, 
   {{0x7ae0f696,0x21281269,0x2904067c,0x672801f5}},	//   _welt, _jach_, _ccoa_, _aafj, 
   {{0x2128f697,0x7784f698,0xe678d400,0x8d84f699}},	//   _mach_, клиз, _děčí, _сурд, 
   {{0xd76012ea,0x3f80d740,0x8b880150,0xe7a40131}},	//   اندی, nnhu_, _كەنە_, نۇنى_, 
   {{0x3914a9dc,0x212800a3,0x2d6801e4,0x69dc00e4}},	//   _لواز, _oach_, mŝer_, âpet, 
   {{0x5908031c,0x98ac00c0,0x75c000ef,0x3f800051}},	//   _གཡིས_, _angą_, _jēzi, hnhu_, 
   {{0xa018023a,0x00000000,0x00000000,0x00000000}},	//   _työy, --, --, --, 
   {{0x1b1c0154,0xc5f800ef,0x00000000,0x00000000}},	//   পাকে_, brē_, --, --, 
   {{0x2128f69a,0x65bc02b1,0x021802bf,0x68e0030a}},	//   _bach_, _pūhe, ніть_, _yeod, 
   {{0x2128f69b,0x68e00005,0xf1ac0046,0x8afc0210}},	//   _cach_, _xeod, _ﺳﺎﻗﺘ, _klęc, 
   {{0x2128f69c,0xafe401b9,0x98ac0064,0x00000000}},	// [15bc0] _dach_, тозл, _vogė_, --, 
   {{0x2128f69d,0xe454008f,0x1f60f69e,0x6eb400ae}},	//   _each_, _סייט_, акум, نصائ, 
   {{0x2128f69f,0x65bc02b5,0xa4980109,0x716801b9}},	//   _fach_, _tūhe, ngòn, _жанг_, 
   {{0x21283c76,0x3218025a,0x202402f6,0xec78074d}},	//   _gach_, _ippy_, äviä_, мпе_, 
   {{0xf13400cf,0xac389448,0xadec01f9,0x00000000}},	//   _كةڭة, بساط_, _चटकन_, --, 
   {{0x68e001e7,0x21280f85,0xb87c00df,0xdb4c01f7}},	//   _seod, _zach_, taŭn, يَن_, 
   {{0x2128f6a0,0x6cc41952,0x79540241,0x7b640014}},	//   _yach_, _айба, _láwu, دانٕ, 
   {{0xb4bc01d9,0x6da4f6a1,0xa37800c5,0x2128004d}},	//   ेडो_, _риба, rsõi, _xach_, 
   {{0x59600801,0x290405b1,0x68e006af,0xa37800c5}},	//   ръща, _vcoa_, _veod, ssõi, 
   {{0x5ba40262,0xc5f800e2,0xa2b00073,0x00000000}},	//   _акум_, trē_, _आणल्, --, 
   {{0x84c4010b,0x3e3c0092,0x00000000,0x00000000}},	//   ләпд, _የዩናይ, --, --, 
   {{0xd5b81e76,0x00000000,0x00000000,0x00000000}},	//   кся_, --, --, --, 
   {{0x2128f6a2,0x67282d8b,0x321800a2,0x37f400f1}},	//   _rach_, _tafj, _appy_, _مينځ, 
   {{0x21280bf1,0x04880116,0x672801bf,0x98a027a8}},	//   _sach_, _җәми_, _uafj, _тиче, 
   {{0x92b42885,0x2128047e,0xc5f00050,0x65bc02b1}},	//   لحفا, _pach_, _آب_, _pīhu, 
   {{0xfba845c7,0x25ac05d5,0x2128016d,0xb87c01e4}},	//   _चीनम, _ògl_, _qach_, kaŭl, 
   {{0x2128f6a3,0x3218003e,0x3f14f6a4,0x461402f2}},	// [15bd0] _vach_, _eppy_, лдас, _شوکر, 
   {{0x4428f6a5,0x2128dce7,0x3f80004c,0xef64009d}},	//   _isa_, _wach_, unhu_, лэхү, 
   {{0x733800c8,0x2128f6a6,0x0dc868eb,0xdb0401e1}},	//   _װערס, _tach_, вучи_, _ìléd, 
   {{0x6e88004b,0x2128f6a7,0xb87c00df,0x2618000d}},	//   رمنې_, _uach_, faŭl, _बहनी_, 
   {{0x75c000e2,0xbb740395,0x00000000,0x00000000}},	//   _vēzi, лукъ, --, --, 
   {{0x4428f6a8,0x4fc404a9,0x386800a2,0x6d4401e1}},	//   _msa_, _ئەلە, _ýari_, _òkan, 
   {{0x4428006c,0xb87c0115,0x00000000,0x00000000}},	//   _lsa_, taŭo, --, --, 
   {{0x4428246f,0xb87c01e4,0x3d940408,0x38280114}},	//   _osa_, baŭl, _сибр, ежио_, 
   {{0x44280605,0x7d08f6a9,0xb87c0115,0xaac400bc}},	//   _nsa_, _ices, raŭo, रुङक, 
   {{0x7c28f6aa,0xf624009d,0x427004b2,0x00000000}},	//   _iser, гдоо, ሹራንስ_, --, 
   {{0x7d080e14,0xe72c01e0,0x167c0023,0x25f80210}},	//   _kces, _һе_, _ዓቕምኻ_, ऊंगी_, 
   {{0x26ccf6ab,0xd760f6ac,0x4428f6ad,0x7c28f6ae}},	//   _effo_, انگی, _bsa_, _kser, 
   {{0xe72ce95a,0x7c280003,0x7d08031c,0x3868007c}},	//   _ле_, _jser, _mces, _åar_, 
   {{0xb6a4055d,0x4428f6af,0x7c28f6b0,0xc3340124}},	//   _йилл, _dsa_, _mser, аҕь_, 
   {{0x4428e550,0x2f540046,0x7d0814dc,0xe6545220}},	//   _esa_, қтас, _oces, _ملوث_, 
   {{0x4428f6b1,0x7c28f6b2,0xdb00f6b3,0x35a4011c}},	//   _fsa_, _oser, lmnä, _щайг, 
   {{0x4428f6b4,0x7c28f6b5,0xa0641515,0xa498c96d}},	// [15be0] _gsa_, _nser, гата_, ngòl, 
   {{0x7d08f6b6,0x324415ed,0x65bc02b5,0x37c4015b}},	//   _aces, _беог, _hūha, _এবার, 
   {{0x27741a4c,0x7c28f6b7,0x67041b37,0x5ee0015b}},	//   נגען_, _aser, _शासक_, _পাশে, 
   {{0x17000156,0x7d080077,0x7c28107d,0x442815ce}},	//   _མཐའམ_, _cces, _bser, _ysa_, 
   {{0x5ee003f4,0x7c28f6b8,0x65bc00b0,0xc7c801fb}},	//   _পারে, _cser, _mūha, _mốc_, 
   {{0xb87c00c8,0x7d080c8c,0x7c280036,0xc7c801fb}},	//   raŭl, _eces, _dser, _lốc_, 
   {{0x7c28f6b9,0x6ed80b40,0xdc941945,0xd9d00131}},	//   _eser, _प्यु, ктәш_, مەلگ, 
   {{0x65bc0374,0x7c28010a,0x893807b5,0x75c000e2}},	//   _nūha, _fser, тпис_, _jēzu, 
   {{0x7b0802f6,0xc7b80055,0xb87c01e4,0x00000000}},	//   ästö, _arīṇ, baŭm, --, 
   {{0xd9400075,0x39b40055,0x6ac4007b,0xfb2400db}},	//   _қечи, _māsy_, _إقام, _ۅرۅپ, 
   {{0x4428f6ba,0xc7c8001e,0x8b880228,0x183000db}},	//   _ssa_, _bốc_, _كەچە_, _ۇروح, 
   {{0x06c80323,0xc5f800da,0xc7c8001e,0x09b8031c}},	//   эгүй_, dzēt_, _cốc_, _མངྒ_, 
   {{0xc7c801fb,0x39587148,0x442801a9,0x29c80208}},	//   _dốc_, össe_, _qsa_, _hùa_, 
   {{0x4428f6bb,0x26cc058a,0xb7d4002b,0xe72800ec}},	//   _vsa_, _uffo_, _uṣas, _سستو_, 
   {{0x5ee003d4,0xd6240063,0x237c0841,0x84c40139}},	//   _পালে, _боје_, đuj_, _вәгд, 
   {{0x4428f6bc,0x29c807ae,0xc7c80016,0x7e6801ef}},	//   _tsa_, _mùa_, _gốc_, _řepo, 
   {{0x4428f6bd,0x3ff40131,0x7d080076,0x29c8004d}},	// [15bf0] _usa_, شكار, _rces, _lùa_, 
   {{0x7d08f6be,0x00000000,0x00000000,0x00000000}},	//   _sces, --, --, --, 
   {{0x539c0375,0x7c286941,0x139c010f,0x00000000}},	//   _איזו, _sser, _אבזע, --, 
   {{0x7c28009d,0xc7c80208,0x6b98036e,0x81600133}},	//   _pser, _xốc_, _aktg, _بۆرۆ, 
   {{0x3b0864b3,0xb87c010f,0x9a780092,0x00000000}},	//   вело_, taŭm, ሥራኤል_, --, 
   {{0x29c801fb,0x4cd400d1,0xdf440108,0x3f78010f}},	//   _bùa_, لغۇز, _сэмп, _יאָס, 
   {{0x7d080472,0xb87c00df,0x29c8f6bf,0x8b8800db}},	//   _tces, raŭm, _cùa_, دەلە_, 
   {{0x7c28f6c0,0x7d082625,0x8e84007b,0x0a18104c}},	//   _tser, _uces, _الفه, افيک_, 
   {{0x7c28f6c1,0xf770f6c2,0xc7c80051,0x00000000}},	//   _user, قاد_, _rốc_, --, 
   {{0xf770f6c3,0xc7c8001e,0x6368002f,0xdb1c005b}},	//   تاب_, _sốc_, _hünf, öväs, 
   {{0xcb68f6c4,0x636803fa,0xc5f8005f,0x9a84f6c5}},	//   _حمله_, _künf, dzēs_, _суал, 
   {{0xc984445a,0x65bc9388,0x1a6401d3,0xf2e005ac}},	//   _лучи, _pūha, _لیڈی_, _বাইণ, 
   {{0xf770f6c6,0x37e44ecc,0x394c0023,0x6448004e}},	//   _وات_, _толг, mjes_, _àgil, 
   {{0x394cf6c7,0x386c0dd4,0x4374f6c8,0x57a4036b}},	//   ljes_, mzer_, буст, _ёшда, 
   {{0x386cf6c9,0xc7c80016,0xb87c01e4,0x31740798}},	//   lzer_, _tốc_, kaŭk, аѓат, 
   {{0x394cf6ca,0x65bc0374,0x3e40001f,0x386c05c7}},	//   njes_, _tūha, _የሚያረ, ozer_, 
  
   {{0x386cf6cb,0x6fb4007b,0x1e340092,0x00000000}},	// [15c00] nzer_, لمرا, _የሚገና, --, 
   {{0xe0dc007f,0x386cf6cc,0x394c02d3,0xdb1800e4}},	//   _anòd_, izer_, hjes_, _otuñ, 
   {{0x394cf6cd,0x3244f6ce,0xdd8c01ed,0x71a4426c}},	//   kjes_, _тенг, ڈول_, _ванз, 
   {{0x29c801fb,0xb87c01e4,0x394c0003,0xa3780254}},	//   _rùa_, raŭj, jjes_, ssõt, 
   {{0x394cf6cf,0x386cf6d0,0xdd10f6d1,0x1d0407b5}},	//   djes_, jzer_, تونخ, речи_, 
   {{0xdb8005f5,0x386c00de,0x7df400d1,0xe468032e}},	//   огчи, dzer_, شقۇچ, _hröð_, 
   {{0x394cf6d2,0xca4824c5,0x636803fa,0xb87c01e4}},	//   fjes_, العه_, _fünf, baŭk, 
   {{0x394c816d,0xb4b40490,0x29c80051,0x00000000}},	//   gjes_, _जणू_, _vùa_, --, 
   {{0x6af4c83e,0x00000000,0x00000000,0x00000000}},	//   _نثار, --, --, --, 
   {{0x394c09d7,0x63680112,0x9b9000ec,0x37d400fe}},	//   ajes_, _zünf, _وڇوڙ, _দিশৰ, 
   {{0x394c01f5,0x386c0165,0x636803e0,0x69c80135}},	//   bjes_, azer_, _hüng, qqfe, 
   {{0x394c01a4,0xd94040f8,0x636821c6,0x7c3003b2}},	//   cjes_, _мехи, _küng, _ókrú, 
   {{0x6368c08d,0x9f4401a2,0x47d400b2,0xb76405a2}},	//   _jüng, čnú_, _ايتر, ртөй, 
   {{0x9388f6d3,0x6368145e,0x25a86ea9,0x00000000}},	//   асса_, _müng, عدگي_, --, 
   {{0x6368025a,0x26dc070d,0x96b40063,0x00000000}},	//   _lüng, mbto_, _кућу_, --, 
   {{0x9258013e,0x26dc0064,0x2d840139,0x00000000}},	//   шаст_, lbto_, jnoe_, --, 
   {{0x200c025a,0x5184035b,0x2d840139,0x00000000}},	// [15c10] îgi_, цура, dnoe_, --, 
   {{0x394c456e,0x00000000,0x00000000,0x00000000}},	//   zjes_, --, --, --, 
   {{0x386c1570,0x26dc0067,0xb87c010f,0x00000000}},	//   zzer_, ibto_, taŭk, --, 
   {{0x6368025a,0x65bc00b0,0x394c01f5,0x91e40139}},	//   _büng, _mūho, xjes_, _фәрһ, 
   {{0xa6bc00bd,0xdcf801a6,0xdb180165,0xb87c010f}},	//   োরিয়, _ljuć, _stuñ, raŭk, 
   {{0x6368f6d4,0x00000000,0x00000000,0x00000000}},	//   _düng, --, --, --, 
   {{0x394cf6d5,0x65bc0069,0x7bd80077,0x6e20033f}},	//   tjes_, _nūho, spwu, łobr, 
   {{0x386c3262,0x6368f6d6,0xd6e000eb,0x2d8406be}},	//   tzer_, _hünd, _মাইয, cnoe_, 
   {{0x394cf6d7,0x6368f6d8,0x87e800ee,0x81b00011}},	//   rjes_, _künd, алың_, টআপ_, 
   {{0x394c428b,0x386cf6d9,0x9f48013a,0x6b900205}},	//   sjes_, rzer_, _ovcí_, ıkgö, 
   {{0x386c066d,0x394cf6da,0x7bc00280,0x6368002f}},	//   szer_, pjes_, _iilu, _züng, 
   {{0x6368f6db,0x394c02d3,0x7bc8004c,0x26dc0009}},	//   _yüng, qjes_, _kueu, abto_, 
   {{0x7bc80137,0x383400a8,0x00000000,0x00000000}},	//   _jueu, _ындр, --, --, 
   {{0x7bc8004c,0x7bc0047e,0x80d41b76,0xdce8031c}},	//   _mueu, _jilu, युसे, bogħ, 
   {{0x7bc806af,0xf77000ec,0x00000000,0x00000000}},	//   _lueu, _واڪ_, --, --, 
   {{0x7bc0f6dc,0xb87c00df,0xe51409b2,0x00000000}},	//   _lilu, taŭh, ध्दि_, --, 
   {{0x7bc00cf9,0x6368f6dd,0x321c0118,0x7f5403b9}},	// [15c20] _oilu, _bünd, ůty_, _bozq, 
   {{0x7bc0f6de,0x752401c0,0x7304026a,0xb87c0115}},	//   _nilu, lekz, _упоз, raŭh, 
   {{0x6368f6df,0x7bc80618,0xc1d40166,0xe468032e}},	//   _süng, _aueu, _мөтә, _tröð_, 
   {{0xdb18f6e0,0xace8f6e1,0x7bc800d5,0x7bc0f6e2}},	//   _stuð, умда_, _bueu, _ailu, 
   {{0x7bc0f6e3,0x7bc8f6e4,0x63680e78,0x7524009d}},	//   _bilu, _cueu, _fünd, iekz, 
   {{0x6368025a,0x7bc0f6e5,0xc7c8001e,0x2d84f6e6}},	//   _vüng, _cilu, _bốn_, snoe_, 
   {{0x6368145e,0x7bc80c6a,0xce3401d9,0xdee0f6e7}},	//   _wüng, _eueu, _بوزک, _хоси, 
   {{0xe0dc068c,0x6368f6e8,0x752401c4,0x7bc0f6e9}},	//   _inòc_, _zünd, jekz, _eilu, 
   {{0x7bc8f6ea,0x7bc0f6eb,0x752477ad,0x6368c8d8}},	//   _gueu, _filu, dekz, _hüne, 
   {{0xd1f42295,0x7bc0f6ec,0x65bc0374,0xc690004b}},	//   ግሥት_, _gilu, _pūho, وېش_, 
   {{0xe9d808e4,0x9f4c5f5e,0x7524009d,0x63680432}},	//   _ске_, égé_, fekz, _jüne, 
   {{0x7bc03824,0x63682e11,0x752401e4,0x7e680118}},	//   _zilu, _müne, gekz, _řepk, 
   {{0x6368203d,0x58803c1f,0x97401050,0x7bc0013e}},	//   _lüne, _ныша, _šćep, _yilu, 
   {{0x65bc0053,0x7bc00564,0x27e40241,0xd1dc069d}},	//   _tūho, _xilu, _iwon_, ንገት_, 
   {{0xdef80046,0x461405d9,0x636800af,0x69c001c8}},	//   ғыз_, _ڇوڪر, _ründ, _kioe, 
   {{0x6368f6ed,0xc10415eb,0xdb18013d,0x5214011c}},	//   _sünd, توري, _tuuç, ядст, 
   {{0xb87c008f,0x6f0c0175,0x63680036,0x00000000}},	// [15c30] taŭi, _bcbc, _pünd, --, 
   {{0x80d82052,0x69c0002d,0x4438f6ee,0x7bc80c86}},	//   _फ्रे, _lioe, mvs_, _rueu, 
   {{0x7bc003a2,0x4438f6ef,0x7bc8f6f0,0xb6040248}},	//   _rilu, lvs_, _sueu, _ifáà, 
   {{0x02b402ab,0xdce80150,0xc7c8004d,0x6368f6f1}},	//   ंधीन, اءان_, _rốn_, _düne, 
   {{0x7bc0f6f2,0x7bc8025f,0x636801ed,0x44380393}},	//   _pilu, _queu, _tünd, nvs_, 
   {{0x69c00270,0x7bc007d6,0xc1ec00af,0x76440008}},	//   _aioe, _qilu, _जबाब_, _áhyg, 
   {{0x27e44e53,0x636843eb,0x7a680323,0x7bc02acf}},	//   _awon_, _güne, рийг_, _vilu, 
   {{0x7bc0f6f3,0xc7c80016,0x27e4f6f4,0x7bc8f6f5}},	//   _wilu, _vốn_, _bwon_, _tueu, 
   {{0x7bc0f6f6,0x69c0f6f7,0x6f0c003e,0x7c2cf6f8}},	//   _tilu, _dioe, _ycbc, çard, 
   {{0x70c471a3,0xc7c8001e,0x7bc00140,0x4438003a}},	//   _वल्ल, _tốn_, _uilu, dvs_, 
   {{0x69c0000f,0xcb4400c2,0xc7c801fb,0x27e4f6f9}},	//   _fioe, _эхти, _uốn_, _ewon_, 
   {{0x80d803f3,0x69c00395,0x4438011c,0x27e4033b}},	//   _फ्ले, _gioe, fvs_, _fwon_, 
   {{0xe9900150,0x4438003a,0x00000000,0x00000000}},	//   _تۇيگ, gvs_, --, --, 
   {{0x7988f6fa,0xd1f4001f,0x69c001c6,0x7524f6fb}},	//   lnew, ግሥቱ_, _zioe, sekz, 
   {{0x443805d5,0x7988325a,0x00000000,0x00000000}},	//   avs_, onew, --, --, 
   {{0x7988f6fc,0x61400c17,0x44380381,0xa288001f}},	//   nnew, меса, bvs_, _መሆኗን_, 
   {{0x44380393,0x21643acc,0x6368f6fd,0x798802d0}},	// [15c40] cvs_, цити_, _süne, inew, 
   {{0x798801ab,0x200c004e,0x00000000,0x00000000}},	//   hnew, àgia_, --, --, 
   {{0x79886085,0x00000000,0x00000000,0x00000000}},	//   knew, --, --, --, 
   {{0x63680209,0xdd8c004b,0xc1d40352,0x2ea823e9}},	//   _günb, پوه_, _хөрә, _करीत, 
   {{0x4e080034,0x69c0f6fe,0xab2803c5,0x00000000}},	//   ांहै_, _rioe, иода_, --, 
   {{0x798823f3,0x6368f6ff,0x69c0f700,0x00000000}},	//   enew, _tüne, _sioe, --, 
   {{0x79880368,0x69c0257c,0x6bd800ec,0xdce80139}},	//   fnew, _pioe, _چورس_, algı, 
   {{0xa3780120,0x1d04f701,0x79880067,0x98ac1f02}},	//   mpõe, _меси_, gnew, _algı_, 
   {{0x9cc00156,0x27482f34,0x25b804cc,0x69c000ad}},	//   _ཞུགས, ачно_, _èpli_, _vioe, 
   {{0xa2882295,0x6368f702,0x64e00c00,0x7988054e}},	//   _መሆኑን_, _münc, पर्श, anew, 
   {{0xd77010fe,0x69c001e4,0x7c2c025c,0x00000000}},	//   بايع, _tioe, ħare, --, 
   {{0x6844f703,0x69d8f704,0x44380393,0xe45c02f6}},	//   _وَال, _itte, tvs_, työ_, 
   {{0xd5b82607,0x00000000,0x00000000,0x00000000}},	//   юсь_, --, --, --, 
   {{0x6ed800dc,0xb87c008f,0x636845d8,0x00000000}},	//   _प्लु, taŭv, _sünb, --, 
   {{0xf8ac5a9d,0x00000000,0x00000000,0x00000000}},	//   _لکی_, --, --, --, 
   {{0x4438ebe6,0xd5cc00c5,0x78b00174,0xb87c00df}},	//   pvs_, _संतज, _íkvø, raŭv, 
   {{0x656c0597,0x71980092,0xd46800f3,0x00000000}},	// [15c50] mhch, _መጥፋት_, _миће_, --, 
   {{0x69d8f705,0x61780020,0x8ca40034,0x7988f706}},	//   _otte, _ተፈላጊ_, _औरजो, znew, 
   {{0x7988f707,0xe7fc02ab,0xb87c0115,0xc0280092}},	//   ynew, ोंडा_, laŭt, ስተላል, 
   {{0x79880175,0x656c004d,0xd1f40023,0x00000000}},	//   xnew, nhch, ግብቲ_, --, 
   {{0x63680365,0x7988f708,0xb87c010f,0x00000000}},	//   _günc, vnew, naŭt, --, 
   {{0x7988f709,0xc7c8004d,0xc0700092,0x00000000}},	//   wnew, _cốm_, _ለመታገ, --, 
   {{0x7988f70a,0xb7d401e1,0xb87c0115,0x656c0165}},	//   tnew, _iṣis, haŭt, khch, 
   {{0x3f80f70b,0xfd7401c0,0xb87c0115,0x5fac0037}},	//   lihu_, _элбэ, kaŭt, _जीतल, 
   {{0x69d8f70c,0x656c65f2,0xfce401e0,0xb87c01e4}},	//   _ette, dhch, _моңо, jaŭt, 
   {{0x3cec0190,0x7988f70d,0xc7c801fb,0x3f8002e3}},	//   _heev_, snew, _gốm_, nihu_, 
   {{0x35a40724,0xd84c0241,0x00000000,0x00000000}},	//   занг, _pọsi_, --, --, 
   {{0x3f8005be,0x656cf70e,0xdb00022a,0xe5741cb8}},	//   hihu_, ghch, dlné, ззю_, 
   {{0x3f80f70f,0xb87c008f,0xe7d00137,0x00000000}},	//   kihu_, taŭu, _كۅيگ, --, 
   {{0x69d84e97,0x3cec0218,0xd76020d3,0x3f8002a8}},	//   _ytte, _leev_, _زنبی, jihu_, 
   {{0xf1a81e4b,0x3f800427,0x161c2d8f,0xa29c5d9c}},	//   ماره_, dihu_, _बहिर_, _खुद्, 
   {{0x9f44b7f2,0x656cf710,0x3cec0218,0x41b400d6}},	//   čný_, chch, _neev_, дсут, 
   {{0x3f800418,0xae880724,0x6020f711,0x644c003a}},	// [15c60] fihu_, әбез_, ндта, cxci, 
   {{0x161cf712,0x3f8000ca,0x7534022e,0x00000000}},	//   _बहार_, gihu_, _hayz, --, 
   {{0x7534f713,0x00000000,0x00000000,0x00000000}},	//   _kayz, --, --, --, 
   {{0x3cec0070,0x69d80ecf,0x2bc849c4,0x00000000}},	//   _ceev_, _rtte, буко_, --, 
   {{0x3cec0211,0x3f80f714,0x753405b1,0xd6c0015b}},	//   _deev_, bihu_, _mayz, োরিয, 
   {{0x6368002f,0xe9e47758,0xf3ec00cc,0x00000000}},	//   _küna, пцио, _জমাৰ_, --, 
   {{0xb87c00df,0xad58010a,0xf1d0000d,0x00000000}},	//   kaŭs, _лрах_, _दूमन, --, 
   {{0x63680cc1,0x888458c2,0xf1bcdf24,0x753401a9}},	//   _müna, ویان, ्दिन, _nayz, 
   {{0x3e400020,0xf8b40032,0xb87c01e4,0x32081155}},	//   _የሚደረ, мөш_, daŭs, huby_, 
   {{0x45d4f715,0xab6002dd,0x23c0110e,0x00000000}},	//   моос, _سۇعى, _méjì_, --, 
   {{0x656c65f2,0x2ea80882,0xf1bc11bc,0x65bc00b0}},	//   thch, _करोत, ्दान, _hūhi, 
   {{0x3cec0070,0x068400ee,0xb87c010f,0x00000000}},	//   _xeev_, згүн, taŭt, --, 
   {{0x6d440086,0x644c0007,0x38300022,0x75340432}},	//   _òkau, uxci, _аҽыр, _dayz, 
   {{0x656cf716,0x65bc00b0,0x4acc08a3,0xc1c407b7}},	//   shch, _mūhi, ाशिव, वद्ग, 
   {{0x753401b9,0x656c0113,0xb87c01e4,0x216464c2}},	//   _fayz, phch, baŭs, птаг, 
   {{0x6368f717,0x656c0784,0x75340166,0x31040248}},	//   _düna, qhch, _gayz, _àmìọ, 
   {{0x3f80f718,0xb87c00df,0x60600116,0x4acc1546}},	// [15c70] tihu_, laŭr, رۇسل, ाशाव, 
   {{0x3cec0070,0x23c001e1,0xfe70f427,0xdb0002f0}},	//   _seev_, _déjì_, نگز_, plné, 
   {{0x6368418f,0x3cec0457,0x23c001e1,0x3f8039e2}},	//   _güna, _peev_, _eéjì_, rihu_, 
   {{0x3f80f719,0x249c0327,0x00000000,0x00000000}},	//   sihu_, żumu_, --, --, 
   {{0x3f802630,0x00000000,0x00000000,0x00000000}},	//   pihu_, --, --, --, 
   {{0xfaa4f71a,0x3cec063f,0xd7a80037,0x2900f71b}},	//   мало, _weev_, _घींच, ókan_, 
   {{0x3cec0190,0x657c014b,0xce940395,0xf1c801ec}},	//   _teev_, _omqh, _заръ, _ﻓﺎﻟﺘ, 
   {{0xb87c00c8,0x7d540006,0x00000000,0x00000000}},	//   daŭr, _ўвах, --, --, 
   {{0xa29c0b4c,0x320800d7,0x7b14009b,0x00000000}},	//   _खुस्, zuby_, _одах, --, 
   {{0x657c014b,0x3208003e,0x753400a2,0x00000000}},	//   _amqh, yuby_, _sayz, --, 
   {{0xb87c010f,0x37a80150,0xa5f400d8,0x00000000}},	//   taŭs, йтүн_, меќу_, --, 
   {{0x636800b0,0x7534022e,0x9d080154,0x00000000}},	//   _rüna, _qayz, _রসুন_, --, 
   {{0x2ea81a3e,0x7534010a,0x200c00db,0xb87c010f}},	//   _कर्त, _vayz, àgil_, raŭs, 
   {{0x36680d84,0x657c0117,0x636878b0,0xf1d0045c}},	//   _мало_, _emqh, _püna, көмө, 
   {{0x7534022e,0xb87c01e4,0x66f00456,0x00000000}},	//   _tayz, paŭs, _आजतक_, --, 
   {{0x3208f71c,0x74140046,0x00000000,0x00000000}},	//   ruby_, _قوعا, --, --, 
   {{0xb4e8023e,0x0594010a,0x5ed400eb,0x00000000}},	// [15c80] यरी_, _чăтм, ধরনে, --, 
   {{0xdee01d56,0x65bc02b5,0x8fc40022,0x00000000}},	//   вофи, _rūhi, хазҵ, --, 
   {{0x8d281248,0x63680037,0x6e44bd92,0x00000000}},	//   знең_, _künn, بنام, --, 
   {{0x65bc04fe,0x6c840b6c,0xdb0000d7,0xac840166}},	//   _pūhi, ولام, rmný, мгел, 
   {{0x3a2401e4,0xd064016b,0x271c02e3,0xb87c0115}},	//   _aplp_, _ɔsɛm, ọnik_, zaŭr, 
   {{0x7c2cf71d,0x94040213,0xce30030d,0x00000000}},	//   çara, çmə_, _йогι, --, 
   {{0xfb1801ed,0xe3dc0011,0x8c1800f1,0x7c2c025c}},	//   سروں_, _ভয়াব, زيګر_, ħara, 
   {{0xc7c8001e,0x65bc02b1,0x19a4f71e,0x298400c7}},	//   _hối_, _tūhi, мтып_, ьылг, 
   {{0x26c805ce,0xdca000c7,0xfcc001ee,0x00000000}},	//   žbom_, _аати, _йәшм, --, 
   {{0xe0dc007f,0xb9048bb5,0xb87c00df,0x47343b8f}},	//   _anòl_, _ब्_, taŭr, хнос, 
   {{0xc7c80016,0xaa880cd2,0xb50801f9,0x00000000}},	//   _mối_, _بنام_, वलंय_, --, 
   {{0xc7c8001e,0xa8480345,0xb87c00df,0x00000000}},	//   _lối_, _ولام_, raŭr, --, 
   {{0xe738554f,0x636803fa,0xd8700345,0xb87c00df}},	//   _мед_, _dünn, _لاوب, saŭr, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc7c80016,0xef38001f,0x1b78010f,0xa29c134e}},	//   _nối_, _የማያው, קטלע, _खुश्, 
   {{0x657c1cdf,0x6738017a,0x6368002f,0x9104004e}},	//   _umqh, ldtj, _günn, кчуд, 
   {{0x443c020c,0xa29c9ed5,0x00000000,0x00000000}},	// [15c90] _éw_, _खुर्, --, --, 
   {{0x6738049f,0xc7c8001e,0x73c00220,0xd25000aa}},	//   ndtj, _bối_, _бәсе, دنې_, 
   {{0xc7c801fb,0xc5f800de,0x63680166,0xdec40023}},	//   _cối_, nsē_, _yünn, ሽፋን_, 
   {{0xc7c801fb,0x62940327,0xdcf80139,0x81e400fe}},	//   _dối_, _ixxo, _djuğ, _নিপ_, 
   {{0x7118010f,0x00000000,0x00000000,0x00000000}},	//   _צושפ, --, --, --, 
   {{0xc5f800e2,0x98ac0055,0x00000000,0x00000000}},	//   ksē_, _nagā_, --, --, 
   {{0x4ea4f71f,0x65bc02b5,0xc7c8001e,0x6d4808de}},	//   _арта, _hūhu, _gối_, ámaí, 
   {{0xe0dc067c,0xcdc800db,0xa6e002dd,0x7cd800d4}},	//   _onòm_, _قۇلۇ_, ңжыл, _хмар_, 
   {{0x636800af,0x5b30084c,0x00000000,0x00000000}},	//   _rünn, _имаӂ, --, --, 
   {{0x81e403f4,0x6368f720,0x62940548,0x9a24007b}},	//   _নিন_, _sünn, _oxxo, _يعان, 
   {{0xa29c0b68,0xe614f721,0xc7c80208,0x00000000}},	//   _खुल्, ндэ_, _xối_, --, 
   {{0xb87c01e4,0xb4e860d3,0x00000000,0x00000000}},	//   baŭp, यरे_, --, --, 
   {{0xda08012d,0xe80403ba,0xd5cc012d,0x00000000}},	//   सूरत_, _शिया_, _सूरज, --, 
   {{0x395c045a,0x00000000,0x00000000,0x00000000}},	//   _hows_, --, --, --, 
   {{0xe7b043f6,0x7bdc021c,0x63680ef5,0x021800d4}},	//   _حمود, _ésuf, _tünn, міть_, 
   {{0xc7c8001e,0x92d0015b,0x00000000,0x00000000}},	//   _rối_, শরে_, --, --, 
   {{0x6368f722,0x395c0204,0xef380092,0x00000000}},	// [15ca0] _güno, _mows_, _የማይው, --, 
   {{0x395c0f85,0x9f940022,0x00000000,0x00000000}},	//   _lows_, ныхә, --, --, 
   {{0x636800a2,0x5f0000d1,0x00000000,0x00000000}},	//   _münl, узха, --, --, 
   {{0xafe406ed,0xc7c80051,0x7c2c0135,0xf9bc0064}},	//   _помл, _vối_, ħarn, _кнiг_, 
   {{0xdd8cf723,0x9cc45cda,0xffd40153,0x00000000}},	//   حون_, ныша_, _аўся, --, 
   {{0xc7c807ae,0x66181141,0x00000000,0x00000000}},	//   _tối_, yttk, --, --, 
   {{0x395cf724,0x78c40213,0x9f880037,0x2d940064}},	//   _bows_, ərvə, töös_, _зрас, 
   {{0xb4e86407,0x395c0afa,0xb87c010f,0xd8a400ec}},	//   यरो_, _cows_, taŭp, ڙهيو_, 
   {{0x98ac0421,0x395c00d7,0x9a5c0092,0x00000000}},	//   _pagā_, _dows_, ዳልከው_, --, 
   {{0x63680139,0xb87c00df,0x00000000,0x00000000}},	//   _cünl, raŭp, --, --, 
   {{0xc0f0067d,0x2b5c009a,0x67380267,0x6368162a}},	//   _ልዕሊ_, _iotc_, rdtj, _süno, 
   {{0xe4a462d9,0xe0dc007f,0x395c0009,0xc5f800de}},	//   ерго, _pnòm_, _gows_, rsē_, 
   {{0xe7840063,0x00000000,0x00000000,0x00000000}},	//   _пуко, --, --, --, 
   {{0x6368f725,0x81e4045e,0x27940724,0x63b40175}},	//   _günl, _নিব_, _яшер, _qhxn, 
   {{0xdcf80fb7,0x81d400c2,0x9294e404,0x00000000}},	//   _smuč, тобх, гарц, --, 
   {{0x65bc0374,0xd1b802da,0x8afc012d,0x00000000}},	//   _pūhu, فاقا_, _klęs, --, 
   {{0xe4a410d9,0x55bc011a,0xdd98010b,0x63687aa0}},	// [15cb0] _ярко, _צמחו, үше_, _yünl, 
   {{0x4428f726,0x201801b9,0x00000000,0x00000000}},	//   _ipa_, rtqi_, --, --, 
   {{0x4428f727,0xe0300323,0xc1b801c0,0x00000000}},	//   _hpa_, _өмнө, _олох_, --, 
   {{0x4428138f,0x65bc04fe,0x7c2c0120,0x63680432}},	//   _kpa_, _tūhu, çaro, _münm, 
   {{0x5bc84d21,0x4428f728,0x395c3af1,0xdcf802f0}},	//   ादेव, _jpa_, _rows_, _umuč, 
   {{0xdb0002fb,0x1ee4f729,0x395c43a9,0x00000000}},	//   plní, _سوری_, _sows_, --, 
   {{0x2b5c0c67,0x395c039a,0x53380375,0x4fa401f0}},	//   _dotc_, _pows_, גנון_, _сиёв, 
   {{0x44280588,0x395c0009,0x3944f72a,0xc0540023}},	//   _opa_, _qows_, тниг, _ከመስግ, 
   {{0x4428f72b,0x395c1957,0x28100137,0xdb180254}},	//   _npa_, _vows_, لويس, _kuuü, 
   {{0xab603712,0xb4e8076e,0x00000000,0x00000000}},	//   şürm, यर्_, --, --, 
   {{0x3914f72c,0x4428f72d,0x98ac0311,0xcb08007b}},	//   _амер, _apa_, _bagă_, _أيمن_, 
   {{0x4428f72e,0x7c2802e3,0x281003e6,0xdb18000d}},	//   _bpa_, _kper, دویس, _luuü, 
   {{0xe72cf72f,0x7c280221,0xe0dc02e2,0x5800054a}},	//   _ке_, _jper, _enòk_, _солғ, 
   {{0x7c28f730,0x4428f731,0x636800a2,0xf6240064}},	//   _mper, _dpa_, _hünj, _адко, 
   {{0x7c280286,0x636800ee,0xa3780254,0x00000000}},	//   _lper, _künj, mpõl, --, 
   {{0xa3780254,0x35a40408,0x00000000,0x00000000}},	//   lpõl, _шайг, --, --, 
   {{0x4428f732,0x2fc82a1f,0xefc801c0,0x452c0327}},	// [15cc0] _gpa_, _pibg_, длал_, _ཧྲིར_, 
   {{0xf3c828fa,0xc0f002d3,0xd37000cf,0x00000000}},	//   _تبعه_, _ልዕል_, _اۇس_, --, 
   {{0x2b5cf733,0x60cc0077,0x44280477,0xc7c80051}},	//   _rotc_, _fgcm, _zpa_, _iốt_, 
   {{0x7c280221,0xc7c801fb,0x44280124,0x3e4000c0}},	//   _bper, _hốt_, _ypa_, _dėt_, 
   {{0x62a0012d,0x3be8004e,0x00000000,0x00000000}},	//   ętoś, елчү_, --, --, 
   {{0xdee00364,0x7c280036,0xdb000798,0x5b1002bf}},	//   _вори, _dper, lonê, иміт, 
   {{0xbd8c00b5,0xc7c801fb,0x3e400092,0x00000000}},	//   _a用us, _mốt_, _የሚኖር, --, 
   {{0x16600020,0x7c28003a,0xc7c8004d,0xa378000d}},	//   ሌክትሪ, _fper, _lốt_, epõl, 
   {{0xa5c409cc,0x999402e8,0x6368013d,0xd9400114}},	//   _ljóð, ъкът_, _sünm, рењи, 
   {{0x4428f734,0xc7c801fb,0x320802f0,0xe890035b}},	//   _rpa_, _nốt_, krby_, лақь, 
   {{0x4428f735,0x57b0084c,0x92040055,0x00000000}},	//   _spa_, рбэт, _śāny, --, 
   {{0x29100183,0x7c28f736,0xdb00002d,0xe8240107}},	//   _øya_, _yper, jonê, _афко, 
   {{0x7c28f737,0x94a89db1,0x44280784,0xc7c8004d}},	//   _xper, втра_, _qpa_, _bốt_, 
   {{0xa5c405a4,0x4428014a,0xc7c8001e,0xe4e0f3ec}},	//   _bjóð, _vpa_, _cốt_, _क्रि_, 
   {{0xc7c8004d,0x63680f7d,0x29fc025c,0xf49c0092}},	//   _dốt_, _hünk, nċa_, ቀራረብ_, 
   {{0xc6a40e46,0x5924031c,0x6368000d,0x4428045a}},	//   _ирқи, _ཡིབས_, _künk, _tpa_, 
   {{0x4428f738,0xd4980276,0x42c400eb,0x7f94009d}},	// [15cd0] _upa_, _арэ_, ্রেশ, гаах, 
   {{0x9c10a63c,0xa5c40162,0x6368f739,0xdb00007c}},	//   kọri, _fjóð, _münk, lmnö, 
   {{0x4fc41248,0x7c282b00,0x6368000d,0x1ea8009f}},	//   рста, _sper, _lünk, ذائي_, 
   {{0x5bc8bd93,0xd68001e4,0x7c280135,0x3d0c0037}},	//   ाद्व, _kanϲ, _pper, हलें_, 
   {{0x7c28004e,0xe0dc01e1,0x31780375,0x70200011}},	//   _qper, _ifò_, _נרשמ, নিউজ_, 
   {{0xc7c8004d,0x9f840241,0x9ac401d9,0x7c280166}},	//   _xốt_, _lòún_, نگاہ_, _vper, 
   {{0xdb000023,0xdcf800e2,0x00000000,0x00000000}},	//   lonë, _emuā, --, --, 
   {{0x7c28f73a,0xd2b80375,0x385800d4,0x0a680395}},	//   _tper, כלות_, ерою_, ърчи_, 
   {{0x7c28f73b,0x8d84f73c,0x6f7400db,0x1bb8f73d}},	//   _uper, _турд, _جەەر_, _قاطع_, 
   {{0x9c1002e3,0x6368f73e,0x9730030f,0xa3780254}},	//   sọsi, _dünk, شکتا, upõl, 
   {{0xcb68f73f,0x3dcc06a3,0x8f9c0302,0xc7c801fb}},	//   _جمله_, _kiew_, ויזי, _rốt_, 
   {{0xc7c8001e,0xc98431a7,0xe0dc01e1,0x3868025c}},	//   _sốt_, _кучи, _nfò_, _żaru_, 
   {{0xe29407d6,0x6368f740,0xa5c40008,0xba081772}},	//   ҳар_, _günk, _sjóð, _ጋሻ_, 
   {{0x66e0f741,0xe7345e7f,0xe0dc0cad,0x7988f742}},	//   _лоша, _беш_, _afò_, liew, 
   {{0xe294f743,0x7c2c0023,0x6798008f,0xc9d00131}},	//   гар_, çarj, _אױסג, _ﻗﺎﻟﻐ, 
   {{0x3dcc06a3,0x7988f744,0xe2c40014,0xdb000200}},	//   _niew_, niew, اوِو_, fonë, 
   {{0xc7c801dc,0x6da407d6,0x7168013e,0xdb00f428}},	// [15ce0] _tốt_, қида, _ҷанг_, ronê, 
   {{0xa5c40579,0xe0dc02bd,0x7988f745,0xdb0001a8}},	//   _tjóð, _efò_, hiew, llnæ, 
   {{0xdb0006ed,0x7168f746,0x7988f747,0xdce80153}},	//   ponê, _занг_, kiew, nigė, 
   {{0xdb00f748,0x7988017a,0x00000000,0x00000000}},	//   lonè, jiew, --, --, 
   {{0x2d9cf749,0x7988f74a,0xab8400f7,0x6b640209}},	//   _ítem_, diew, лукк, лкда, 
   {{0xdb1800e8,0x63680254,0x5bb40a4a,0xdfcc007b}},	//   _buuñ, _rünk, глія_, _ريف_, 
   {{0x79880036,0x63680037,0xda0821bd,0x00000000}},	//   fiew, _sünk, संगत_, --, 
   {{0x6da4f74b,0x7988f74c,0x5e903adf,0x6368f74d}},	//   _сиба, giew, _الفط, _pünk, 
   {{0xdb000699,0x29080342,0x1d0402e8,0xabf40790}},	//   konè, ğba_, _щети_, _şöfö, 
   {{0x2ef80112,0x9f840248,0x00000000,0x00000000}},	//   napf_, _sòún_, --, --, 
   {{0x7988f74e,0xdb00f74f,0xd84c0241,0x3868012d}},	//   biew, donè, _mọyi_, _żart_, 
   {{0x1a981a4c,0xb4c002c3,0x3958002f,0x798880d6}},	//   _איבע, ्खू_, össt_, ciew, 
   {{0x69d8007d,0xdb000ba1,0xc0d40023,0x2a8c03b9}},	//   _पंडी, fonè, _ክንሱ_, _həb_, 
   {{0xa664c5a5,0x25b87cea,0xdb000137,0x54e40131}},	//   _مطبو, _whql_, gonè, _ﺋﯩﺸﻼ, 
   {{0x46140131,0xe7fc01ad,0x98ac0064,0x00000000}},	//   _ئوبر, ोंका_, _vagą_, --, 
   {{0x6368f750,0x210c0034,0x39800024,0xdb00036e}},	//   _müni, िलेश_, tųsi_, tonë, 
   {{0x3dcc0652,0xdb00004e,0x26c800d0,0x43940798}},	// [15cf0] _riew_, bonè, ľbou_, _вапс, 
   {{0x26dcf751,0x3dcc0652,0xdb00f752,0x26c80122}},	//   ncto_, _siew_, conè, žbou_, 
   {{0x73340075,0x63680793,0x63a4f753,0x26dc003a}},	//   _ئىپا, _nüni, mojn, icto_, 
   {{0x656cf754,0x63a4044e,0xf1c40b7c,0xdb000c6a}},	//   nkch, lojn, लगणन, moné, 
   {{0x3dcc97a2,0x7988f755,0x9c8400b2,0xfb347314}},	//   _view_, view, دشاه, индэ, 
   {{0x7988f756,0x63a4044e,0xbb44f757,0x200c026c}},	//   wiew, nojn, рекк, àgiu_, 
   {{0x79880151,0x3dcc03a2,0xbea805d9,0xdd9802d5}},	//   tiew, _tiew_, _شهرن_, _зша_, 
   {{0xd0440198,0x63a4f758,0x26dc16b8,0x3d94f759}},	//   cciɓ, hojn, ecto_, _тибр, 
   {{0x63a4f75a,0x7988f75b,0xdb00033b,0x00000000}},	//   kojn, riew, yonè, --, 
   {{0x7988f75c,0x63a402d3,0x54e40075,0xdb00003e}},	//   siew, jojn, _ﺋﯩﺴﻼ, koné, 
   {{0x63a402d3,0xdb00f75d,0x6368010b,0x79880210}},	//   dojn, joné, _güni, piew, 
   {{0xdb005d1a,0x35a4f75e,0x00000000,0x00000000}},	//   doné, рамг, --, --, 
   {{0x636800a2,0x63a4036e,0x37740024,0xb4c01c54}},	//   _züni, fojn, _выйс, ्खे_, 
   {{0x63a4f75f,0xdb00f760,0xb87c0115,0x63680139}},	//   gojn, foné, kaŭz, _yüni, 
   {{0xdb00f761,0x62603db7,0xf1a80753,0x4880001f}},	//   goné, овра, ناره_, ርጋለሁ_, 
   {{0xdb00f762,0x656cf763,0xe89c001f,0x9ac01418}},	//   sonè, ckch, _ውስጥም_, ŋŋwa, 
   {{0xe040f764,0x63a40f03,0xe0d4f765,0xdb007172}},	// [15d00] онти, bojn, рву_, ponè, 
   {{0x63a4036e,0x00000000,0x00000000,0x00000000}},	//   cojn, --, --, --, 
   {{0xdb00068c,0xa378000d,0x6cd4007b,0xfe740f15}},	//   coné, dpõh, لقضا, бүр_, 
   {{0xe298025f,0xc7c801fb,0xa29c012c,0xece408b0}},	//   _ישיר, _lốp_, _खुट्, рғақ_, 
   {{0xabcc01ec,0x3ce80022,0x00000000,0x00000000}},	//   _ﺗﻮﺭﻋ, ñava_, --, --, 
   {{0x636801b8,0xd84c0248,0xa3780254,0xfca801e2}},	//   _püni, _kọfi_, gpõh, دامو_, 
   {{0x6b88f766,0x00000000,0x00000000,0x00000000}},	//   rifg, --, --, --, 
   {{0x63a402d3,0xa378000d,0x5d640b01,0xec4800f3}},	//   zojn, apõh, _кисм_, _избл_, 
   {{0xc7c80208,0x3e5c0092,0x2bc8030d,0x63a401d5}},	//   _bốp_, _ለሚደረ, _алап_, yojn, 
   {{0x63a40023,0x6d40f767,0xc7c8004d,0x6368f768}},	//   xojn, ldoa, _cốp_, _tüni, 
   {{0x2d9c0231,0x00000000,0x00000000,0x00000000}},	//   _êtes_, --, --, --, 
   {{0xb86400ec,0x537c0023,0x81e40154,0xc0d40240}},	//   _گامو, _ጥምየት_, _নিল_, _ክሕሎ_, 
   {{0x63a4044e,0x68e007d6,0x656cf769,0x6d40005a}},	//   tojn, _ifod, rkch, idoa, 
   {{0x7c2cf76a,0x27e44ba8,0x656cf76b,0xb864f76c}},	//   çari, _iton_, skch, _دامو, 
   {{0x63a4f76d,0x656c0227,0x27e401a9,0x6d40000f}},	//   rojn, pkch, _hton_, kdoa, 
   {{0xdb00f76e,0x63a4f76f,0x44f41677,0x27e400b5}},	//   roné, sojn, _упис, _kton_, 
   {{0xdef8169c,0x63a42a6d,0x6d40f770,0xdb0001c7}},	// [15d10] вые_, pojn, ddoa, soné, 
   {{0xdb004e72,0xd9d4015b,0xc7c801fb,0x27e40142}},	//   poné, _সবসম, _xốp_, _mton_, 
   {{0xdec8f771,0x68e0f772,0x44380042,0x00000000}},	//   туал_, _ofod, lws_, --, 
   {{0x2904f773,0x6b9800df,0x27e4f774,0x400800ec}},	//   _ndoa_, _ajtg, _oton_, _ٽيسٽ_, 
   {{0x4438f775,0x8d74066d,0x27e4003e,0x77bc068c}},	//   nws_, غاما, _nton_, lèxe, 
   {{0x68e00161,0x5b24b8d1,0x443804e6,0xdf440006}},	//   _afod, рьда, iws_, _тэмп, 
   {{0x27e4f776,0x44386303,0x77bc0ba1,0x81d80154}},	//   _aton_, hws_, nèxe, ঠীর_, 
   {{0x8d8405f5,0x21280194,0x2d8c33a2,0xa3d44e8f}},	//   _дууд, _jbch_, éfet_, िदा_, 
   {{0xb4b4690c,0x21280142,0xd5440248,0x00000000}},	//   _झरे_, _mbch_, _lẹ́s, --, 
   {{0x68e0f777,0x69cc011c,0x3cfc0218,0x44380142}},	//   _efod, _èben, lawv_, dws_, 
   {{0x9a84f778,0xb8dc00bd,0xc764278f,0xb6a4086f}},	//   _туал, _আল_, تايى, синл, 
   {{0x290001ed,0xf1bc0316,0x77bc067c,0x27e40023}},	//   ókat_, ्दछन, dèxe, _fton_, 
   {{0x64480789,0xf744237b,0xc7c8004d,0x44380042}},	//   _ágil, _гело, _tốp_, gws_, 
   {{0x386cf779,0x3cfc0211,0x43742218,0xa2e0a2d8}},	//   myer_, hawv_, оуст, зорд, 
   {{0x386cf77a,0xe71404b3,0xdef00023,0xf674010f}},	//   lyer_, _ايىت_, ልኩን_, _לײַט_, 
   {{0x659007fa,0x74f84889,0x4438f77b,0xe5a01318}},	//   _нају, _сэкс_, bws_, _нищи, 
   {{0x386cf77c,0xaf04f77d,0x443803cb,0x47340133}},	// [15d20] nyer_, йпал, cws_, _درۆز, 
   {{0x636801b8,0x3cd401ec,0x64a0030d,0x00000000}},	//   _bünu, _ﺘﺯﺍﻤ, _хаьа, --, 
   {{0xdfcc0979,0x386c044e,0x6ce4f77e,0x6d400589}},	//   ريم_, hyer_, біле, tdoa, 
   {{0x386c016b,0xec787e09,0x98ac012d,0xde0800db}},	//   kyer_, лпе_, _wagę_, ارلۇ_, 
   {{0x386cf77f,0x00000000,0x00000000,0x00000000}},	//   jyer_, --, --, --, 
   {{0x68e00395,0x386cf780,0x27e40327,0x7afc0129}},	//   _sfod, dyer_, _rton_, _œstr, 
   {{0x27e4f781,0x63a80077,0x6368010e,0x00000000}},	//   _ston_, _ígne, _günu, --, 
   {{0x1720025c,0x386c0200,0x44380142,0x1e9405d0}},	//   _འཁུམ_, fyer_, yws_, _הכלל_, 
   {{0x25781574,0x63680254,0x00000000,0x00000000}},	//   _jële_, _künt, --, --, 
   {{0x473400d4,0x00000000,0x00000000,0x00000000}},	//   цнос, --, --, --, 
   {{0x386c011f,0xa9281ac3,0x6368f782,0x443800b5}},	//   ayer_, _біле_, _münt, wws_, 
   {{0x27e41529,0xd5b86690,0x44380368,0x68e002e3}},	//   _tton_, йся_, tws_, _ufod, 
   {{0x4438ed6b,0x69d8f783,0x6844bb60,0x2578002e}},	//   uws_, _hute, _ында, _nële_, 
   {{0x69d8f784,0x3a280227,0x443803cb,0x57f0010a}},	//   _kute, ńape_, rws_, _эпшт, 
   {{0x5690f785,0x44380070,0x00000000,0x00000000}},	//   _нашт, sws_, --, --, 
   {{0xdcf805a1,0x3cfc0218,0x071800e1,0xdef00023}},	//   _imuć, xawv_, _दाँव_, ልዩን_, 
   {{0x69d8f786,0x84c402d9,0x636801ed,0x00000000}},	// [15d30] _lute, _фәнд, _bünt, --, 
   {{0xe2a80014,0x257804e6,0x69d8f787,0xa4980100}},	//   _ماجن_, _wëld_, _oute, raòd, 
   {{0x7cd8f788,0x386c64d3,0x69d8f789,0x3cfc01d4}},	//   амер_, zyer_, _nute, tawv_, 
   {{0x257800e8,0xbcb407d8,0x386c0205,0x00000000}},	//   _fële_, обещ, yyer_, --, 
   {{0x69d8f78a,0x071809bb,0x7de40153,0x00000000}},	//   _aute, _दांव_, _sėsd, --, 
   {{0x69d89390,0x386c2035,0x3cfc0218,0x6368f78b}},	//   _bute, vyer_, sawv_, _günt, 
   {{0xd90c552d,0x386cde48,0x69d8ea7b,0x7cf000e4}},	//   فیا_, wyer_, _cute, _ẽrus, 
   {{0x69d8f78c,0xdb00b9f0,0xf7c004a2,0x6368101c}},	//   _dute, moní, ﺮﯨﻨﺪ, _küns, 
   {{0x7d08f78d,0xb9000d0d,0xdb18000d,0xded40257}},	//   _ides, _दल_, _suuõ, _ክስን_, 
   {{0x386c14ed,0x69d8f78e,0x6368f78f,0x378800cf}},	//   ryer_, _fute, _müns, рбоо_, 
   {{0x69d8f790,0x386c2035,0x7bc06210,0x7be00eac}},	//   _gute, syer_, _ihlu, _নিয়ো, 
   {{0xe9ccf791,0x00000000,0x00000000,0x00000000}},	//   _ік_, --, --, --, 
   {{0x69d80323,0x37a00046,0x7bc003a2,0x386c036e}},	//   _zute, _оқиғ, _khlu, qyer_, 
   {{0x2898008d,0xdb0000bc,0x69d8f792,0x00000000}},	//   _דינא, koní, _yute, --, 
   {{0x7d08f793,0x7bc0014b,0x6d4c0134,0x5924031c}},	//   _odes, _mhlu, _ɔbab, _རྡོས_, 
   {{0x7d08f794,0x6368f2ad,0xc6a405f5,0xd73405f5}},	//   _ndes, _sünt, _эрчи, _түүх_, 
   {{0x7bc0f795,0xfbc86236,0xe51c00dc,0x6f640024}},	// [15d40] _ohlu, िगाम, _भाति_, оваз, 
   {{0x7d08f796,0xdb0039b3,0x7bc006e4,0x59dc0073}},	//   _ades, foní, _nhlu, _पंढर, 
   {{0xee38f797,0xdb0004d4,0x00000000,0x00000000}},	//   рне_, goní, --, --, 
   {{0x257800e8,0xec480835,0x00000000,0x00000000}},	//   _tële_, изел_, --, --, 
   {{0x69d8f798,0x6368f799,0x7d08f79a,0x59240327}},	//   _sute, _güns, _ddes, _རྡེས_, 
   {{0x69d8f79b,0x09b492c2,0x7d08f79c,0xe9e4f79d}},	//   _pute, ुष्य, _edes, оцио, 
   {{0x69d800fb,0x7bc000a3,0xad58e91f,0x2d940b96}},	//   _qute, _dhlu, _крах_, _драс, 
   {{0x7bc06b9d,0x69d8f79e,0x7d0800f3,0x0a680131}},	//   _ehlu, _vute, _gdes, ирқи_, 
   {{0x69d802e3,0x998006f6,0x7bc000a3,0xbdc801ed}},	//   _wute, بليو, _fhlu, _اگلے_, 
   {{0x69d8f79f,0x7bc00fa3,0x00000000,0x00000000}},	//   _tute, _ghlu, --, --, 
   {{0x69d816b5,0xe8040490,0x00000000,0x00000000}},	//   _uute, _शिका_, --, --, 
   {{0x7d080098,0xbc7000db,0x7bc002f0,0x48c40150}},	//   _xdes, _تۇۇب, _zhlu, _нәпа, 
   {{0xa78400f7,0xdb000407,0x7cd403e3,0x00000000}},	//   _وشتو, zoní, _hərç, --, 
   {{0x81c00c58,0xdef01ef7,0x00000000,0x00000000}},	//   ুৱা_, ልዩና_, --, --, 
   {{0x69c0a852,0xdcf839ae,0xe1640063,0x6ea800bc}},	//   _khoe, _umuć, ођан, _जुलु, 
   {{0xd1b801ec,0x00000000,0x00000000,0x00000000}},	//   قاقا_, --, --, --, 
   {{0x439406bb,0x77bc068c,0x69c00042,0x2614202e}},	// [15d50] _наис, lèxa, _mhoe, पूरी_, 
   {{0xdb000c5e,0x7d080129,0x00000000,0x00000000}},	//   toní, _sdes, --, --, 
   {{0x63680639,0x9e04c07f,0x59dc0490,0x77bc0ba1}},	//   _wüns, ючал, _पंधर, nèxa, 
   {{0xb23804ac,0x7bc00192,0x8afc002d,0x69c00208}},	//   _פערז, _shlu, _glęz, _nhoe, 
   {{0x7d0802d3,0xdee000b7,0xc0c40075,0xdb00004e}},	//   _vdes, ምላክ_, _хәви, soní, 
   {{0x69c00270,0xdb00ebee,0x00000000,0x00000000}},	//   _ahoe, poní, --, --, 
   {{0x7a6801c0,0x8e38007b,0x00000000,0x00000000}},	//   сийг_, _وسفر_, --, --, 
   {{0x7d08f7a0,0x69c0f7a1,0xb3440724,0x8d749afc}},	//   _udes, _choe, _kiçä, _قاقا, 
   {{0x9c1001f2,0xa3a8012c,0xe8f42123,0x7c2c025c}},	//   họzi, गका_, члы_, ħars, 
   {{0x69c00270,0x1b7469d2,0x9ba012b7,0x7bc06985}},	//   _ehoe, _بدرج, _تەتى, _uhlu, 
   {{0xdde006be,0xabd00150,0x00000000,0x00000000}},	//   _ərşi, _ﺟﻮﻣﺎ, --, --, 
   {{0xa3d40882,0x69c00b4f,0x7cd403b9,0x00000000}},	//   िदं_, _ghoe, _gərç, --, 
   {{0xe794f7a2,0xb344013d,0x7d1c01a8,0x00000000}},	//   _کانک, _niçä, _össu, --, 
   {{0x6b500166,0x2bdc012d,0x00000000,0x00000000}},	//   _iñgä, _फंसा, --, --, 
   {{0xf67800df,0x00000000,0x00000000,0x00000000}},	//   _לאַמ, --, --, --, 
   {{0xb3440432,0xe294f7a3,0x7cd40213,0x4158003b}},	//   _biçä, час_, _xərç, ошую_, 
   {{0x2164e20b,0x15e002dd,0xd3a4014b,0x00000000}},	// [15d60] чити_, _ﺍﻟﺠﺩ, _олиқ, --, 
   {{0xb8fc0ed9,0xa3bc038e,0x6fb4007b,0x00000000}},	//   _ཡུ_, ेषण_, أمطا, --, 
   {{0x172c07e4,0xdb00f7a4,0x4a28031c,0x1fb800fe}},	//   _ཨིནམ_, donà, _རཱེལ_, _অংশস, 
   {{0x71a4d6e8,0x00000000,0x00000000,0x00000000}},	//   _хамз, --, --, --, 
   {{0x2578002e,0x69c06330,0xc10001c6,0x00000000}},	//   _jëla_, _rhoe, _шүтл, --, 
   {{0x69c0f7a5,0xdb803be4,0xbcc001e0,0x7cd403b9}},	//   _shoe, нгчи, тҡул, _sərç, 
   {{0x7cd406be,0x00000000,0x00000000,0x00000000}},	//   _pərç, --, --, --, 
   {{0x69c001ee,0xa378000d,0x7c2c0003,0x00000000}},	//   _qhoe, npõr, ħarr, --, 
   {{0xeaf89ce2,0xec7819c9,0xd820026a,0x00000000}},	//   _هرات_, _упа_, едњи, --, 
   {{0x3a280054,0x25b41d03,0x69c0123b,0xaa44f7a6}},	//   ńapa_, ृष्ण, _whoe, _незл, 
   {{0x69c0f7a7,0x00000000,0x00000000,0x00000000}},	//   _thoe, --, --, --, 
   {{0x76b800f7,0xdb0003da,0x00000000,0x00000000}},	//   өлөр_, moná, --, --, 
   {{0x59240327,0xa378000d,0x7de40153,0xdee00023}},	//   _རྡིས_, dpõr, _mėsa, ምላእ_, 
   {{0x6d4c016b,0x2908013f,0xd138009d,0x00000000}},	//   _ɔbaa, ɔbaa_, үхт_, --, 
   {{0xf8ac20e8,0x00000000,0x00000000,0x00000000}},	//   _مکی_, --, --, --, 
   {{0x6618f7a8,0x6738f7a9,0xc0d00241,0xc1b801ce}},	//   mutk, letj, _abíọ, ілах_, 
   {{0x6618f7aa,0xdb000306,0x71680023,0x00000000}},	// [15d70] lutk, honá, _ደገፋት_, --, 
   {{0xdb004be9,0x38680241,0x831808de,0x00000000}},	//   koná, _àare_, _بقدر_, --, 
   {{0x8d7410e8,0x00000000,0x00000000,0x00000000}},	//   کالا, --, --, --, 
   {{0xdcf801e4,0x7bdc00f2,0x6738f7ab,0xd84c004d}},	//   _kluĉ, _ésuk, hetj, _lọai_, 
   {{0x6738f7ac,0xbb44f7ad,0x6618f7ae,0xdb00004e}},	//   ketj, делк, hutk, tonà, 
   {{0x66183223,0x6738a46c,0xdb0026f6,0x00000000}},	//   kutk, jetj, foná, --, 
   {{0x66182831,0x4e2801c0,0xdb0000cf,0xaa540063}},	//   jutk, _ноён_, ronà, дију_, 
   {{0xdb00067c,0x6618f7af,0x98bc0419,0x00000000}},	//   sonà, dutk, rkuľ_, --, 
   {{0xa82000aa,0xb8e42017,0xa3bc0c93,0x00000000}},	//   نکون, _एर_, ेषा_, --, 
   {{0x378800d6,0x673804ce,0xdb0000e5,0x00000000}},	//   ібно_, getj, boná, --, 
   {{0x35a4f7b0,0x3668009b,0x661800c0,0xe614013d}},	//   данг, цано_, gutk, мдэ_, 
   {{0x6abc0e78,0x2018f7b1,0xe57493e4,0x00000000}},	//   üpfe, kuqi_, дзю_, --, 
   {{0x6738ad6a,0x0f080154,0x00000000,0x00000000}},	//   betj, র্টঃ_, --, --, 
   {{0x66183fa0,0x3f9c002e,0xe73400db,0x2a240023}},	//   butk, éwul_, _жеш_, _ደርብዮ, 
   {{0x6618f7b2,0x7bdc0395,0x232400a7,0x200c03b2}},	//   cutk, _èsuf, ьори_, ágin_, 
   {{0x41b4003b,0x00000000,0x00000000,0x00000000}},	//   есут, --, --, --, 
   {{0x25780200,0xdb00f7b3,0x00000000,0x00000000}},	// [15d80] _këln_, zoná, --, --, 
   {{0x3f80014f,0x64a40036,0x9f940022,0xa3780254}},	//   ghhu_, séië, мыхә, spõr, 
   {{0xa3a803ce,0x543401f7,0x00000000,0x00000000}},	//   गकर_, _آرڊر, --, --, 
   {{0xdb0001d3,0xdb4c01d9,0x67380a08,0x81e400eb}},	//   voná, یَن_, zetj, _নিচ_, 
   {{0xdee0069c,0xdd8cf7b4,0x9cc41def,0xe4e0000d}},	//   ምላኽ_, جون_, мыша_, कुटि_, 
   {{0xdb005955,0x00000000,0x00000000,0x00000000}},	//   toná, --, --, --, 
   {{0x6738151c,0xdfcc007b,0x00000000,0x00000000}},	//   vetj, _ضيف_, --, --, 
   {{0x6738f7b5,0xdb00f7b6,0x48c402dd,0x6618f7b7}},	//   wetj, roná, нәла, vutk, 
   {{0xaf54001f,0x6738f7b8,0x75fc0055,0x5ed000eb}},	//   _ለማስወ, tetj, _āhaṃ, দুদে, 
   {{0x6618f7b9,0xdb001ab0,0xdca00032,0x5ca000c7}},	//   tutk, poná, _рауи, _риуб, 
   {{0x6738f7ba,0x6d4c016b,0x00000000,0x00000000}},	//   retj, _ɔban, --, --, 
   {{0x6618f7bb,0x6738f7bc,0x20180113,0x00000000}},	//   rutk, setj, yuqi_, --, 
   {{0x673801e0,0x8858f7bd,0x00000000,0x00000000}},	//   petj, _хилс_, --, --, 
   {{0x6618f7be,0x00000000,0x00000000,0x00000000}},	//   putk, --, --, --, 
   {{0xa6a819c5,0x968000f1,0x3db400cc,0xd7c40345}},	//   _باشق_, _لټون, _জংঘল, _تووه_, 
   {{0x20180227,0x200c0120,0xd1c801c0,0xdb000306}},	//   tuqi_, ágio_, дууд_, dlný, 
   {{0xe4a42fc3,0x1004011c,0x00000000,0x00000000}},	// [15d90] _юрко, вяхм, --, --, 
   {{0x4428f7bf,0x2ee80334,0x7de40024,0x8574009f}},	//   _iqa_, _cfbf_, _dėsn, _آگھئ, 
   {{0x644c01bf,0xdb0027ac,0x00000000,0x00000000}},	//   lvci, lonç, --, --, 
   {{0x62840165,0x00000000,0x00000000,0x00000000}},	//   mzjo, --, --, --, 
   {{0x2018f7c0,0xdb0033a2,0x44280076,0x00000000}},	//   quqi_, nonç, _jqa_, --, 
   {{0x44280ac5,0x29000162,0x00000000,0x00000000}},	//   _mqa_, ðkan_, --, --, 
   {{0x6284038f,0xba740046,0x00000000,0x00000000}},	//   nzjo, عاتت, --, --, 
   {{0x44280869,0xdb00013d,0x00000000,0x00000000}},	//   _oqa_, konç, --, --, 
   {{0x44280457,0x427c02d3,0xb4ac0490,0x15e001ec}},	//   _nqa_, _ጥፍኣት_, _कडे_, _ﺍﻟﺸﺩ, 
   {{0xe8ecf7c1,0x46e800f7,0x00000000,0x00000000}},	//   _әл_, үдөн_, --, --, 
   {{0x44284f6b,0x3c280030,0x7de40006,0xe70400ec}},	//   _aqa_, lúv_, _mėso, رڪون_, 
   {{0xc328025f,0x2008107d,0xa498004e,0x093401d5}},	//   _לו_, _ovci_, raòn, _لرهج, 
   {{0x200cdd69,0x69dc01e4,0xe72c4130,0x00000000}},	//   ágil_, ŭpet, _йе_, --, 
   {{0xdecc1e38,0x257801c7,0xb6a4f7c2,0x57a401d5}},	//   ባርን_, _hëll_, _пилл, _ўшда, 
   {{0x4428014b,0x257800e8,0x20080205,0x069401d3}},	//   _eqa_, _këll_, _avci_, _لاٹھ, 
   {{0x216405c2,0x61403348,0xdb000793,0xdee0013e}},	//   ниси_, леса, lonä, ҳофи, 
   {{0x257804e6,0x7c28031c,0x81d4010b,0x00000000}},	// [15da0] _mëll_, _nqer, тцрц, --, 
   {{0x98bc0153,0x24c4013d,0x00000000,0x00000000}},	//   ūrėk_, _ягып_, --, --, 
   {{0x7c280869,0x2774008f,0x52b400d1,0x00000000}},	//   _aqer, עגען_, _شەرئ, --, 
   {{0x2ac40316,0xc0cc001f,0xd84c01e1,0x00000000}},	//   _líbí_, ባልም_, _rọni_, --, 
   {{0x44280548,0xdb00f7c3,0x4f3401ed,0x3208f7c4}},	//   _xqa_, konä, _لڑائ, lsby_, 
   {{0xaae430fe,0x2ac40248,0xdb00f7c5,0x7de400c0}},	//   رستو, _níbí_, plný, _kėsl, 
   {{0x3208005c,0x7c28036e,0xd7f400c7,0xaf540092}},	//   nsby_, _eqer, ҕуы_, _ለማሳወ, 
   {{0x1cdc025c,0x29880108,0x00000000,0x00000000}},	//   _ལུར_, ясло_, --, --, 
   {{0x6284f7c6,0xdca08d2f,0x2ac40ca8,0xdb0001b8}},	//   zzjo, _бати, _bíbí_, fonä, 
   {{0x6d600989,0x4428022e,0xda6c132f,0x00000000}},	//   štač, _rqa_, _گُم_, --, 
   {{0x4428f7c7,0x2ab4010b,0xdbc801e1,0x00000000}},	//   _sqa_, _яңкы_, _tòòj, --, 
   {{0x4428020c,0x257801c7,0x320805ac,0x5e98010f}},	//   _pqa_, _gëll_, dsby_, לביק, 
   {{0x44282312,0x69c800b8,0xd96400ec,0x6284025c}},	//   _qqa_, _gṛṇh, _سٽون_, wzjo, 
   {{0xe72805d9,0x644c00e2,0x00000000,0x00000000}},	//   _رستو_, rvci, --, --, 
   {{0x44280083,0x3208f7c8,0x97c01ec7,0x9258f7c9}},	//   _wqa_, gsby_, _حقوو, нарт_, 
   {{0xa4980100,0x4428022e,0x62840003,0xb6380150}},	//   laòm, _tqa_, rzjo, _ﺘﺫ_, 
   {{0x4428f7ca,0xbfd800d4,0x00000000,0x00000000}},	// [15db0] _uqa_, ддає_, --, --, 
   {{0x42740124,0x506402dd,0xc27400f3,0x00000000}},	//   _агос, ытса, _алој, --, 
   {{0xcfa4f7cb,0x7de400c0,0x00000000,0x00000000}},	//   ушти, _vėso, --, --, 
   {{0x63bc00bc,0x6448032e,0x00000000,0x00000000}},	//   ůzně, _ágis, --, --, 
   {{0x69d80034,0xdbb400d1,0x00000000,0x00000000}},	//   _पंजी, нткә_, --, --, 
   {{0x257801c7,0xfaa800f2,0x00000000,0x00000000}},	//   _sëll_, وهشي_, --, --, 
   {{0xdcf80122,0x25780036,0x88c40055,0x00000000}},	//   _hluč, _pëll_, _īśap, --, 
   {{0xdcf8c1b4,0x8c6402dd,0x2ac40241,0xbd4401c8}},	//   _kluč, _өтуд, _síbí_, _جنري, 
   {{0xa8002f26,0x99641945,0xdb003110,0x7c280208}},	//   азыл, _үтел, tonä, _uqer, 
   {{0x257804c4,0x61bc00dc,0xd5180248,0xf7ac1870}},	//   _wëll_, ्षुष, _ọ̀p, ﻴﺎﻣﻪ, 
   {{0x7bdc011c,0xcfe8015b,0x2578002e,0x69dc01e4}},	//   _èsub, _পিছন, _tëll_, ŭper, 
   {{0x1cdc1efe,0x70401682,0xe0dc0208,0xf50402e8}},	//   _ལུས_, _ḽiṱ, _ngò_, ъзмо, 
   {{0x394cf7cc,0x7de40064,0xa9c800b8,0xa3bc00cd}},	//   mdes_, _sėsl, _uṣṇi, ेषं_, 
   {{0x394cf7cd,0x32083b85,0x66e010f6,0xe0dc01e1}},	//   ldes_, tsby_, _коша, _agò_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6024166a,0x32081e10,0xe614004e,0x79e801ec}},	//   kūmā, rsby_, _рдъ_, _ﻏﺎﻤﻀ, 
   {{0x394cf7ce,0x6140f7cf,0x32480240,0x70bc01f9}},	// [15dc0] ides_, шета, _ብውሽጣ, ्धेल, 
   {{0x13a8f7d0,0x32080158,0x394c4a41,0xd13000cf}},	//   _سنجی_, psby_, hdes_, _گۅر_, 
   {{0x704006d6,0x394c0e02,0x644802d2,0x954001f3}},	//   _ḓiṱ, kdes_, _ágir, _ክሊንተ, 
   {{0xdd8cf7d1,0x394cf7d2,0xd13000db,0x3004022e}},	//   يول_, jdes_, _دۅر_, _измг, 
   {{0x394cf7d3,0x00000000,0x00000000,0x00000000}},	//   ddes_, --, --, --, 
   {{0xfca8021a,0x395c0142,0x394c00de,0x6fc000d0}},	//   رانو_, _anws_, edes_, môco, 
   {{0x394c05e4,0xada801d9,0xbc240150,0xdcf80419}},	//   fdes_, _قطرٕ_, _ەرمى, _zluč, 
   {{0x2900f7d4,0x394cf7d5,0xec14742b,0x7fe80345}},	//   úka_, gdes_, _لورد, _ترێف_, 
   {{0xebe410f5,0xf8b40184,0x6ab8000f,0xdc540014}},	//   _розп, лөш_, _wytf, _لرٕک, 
   {{0x394cf7d6,0x753400a2,0x00000000,0x00000000}},	//   ades_, _abyz, --, --, 
   {{0xa9240588,0xe944136b,0x1ae01cd6,0x45d43a49}},	//   _адел, _ахло, _тохм, лоос, 
   {{0x7bdc0395,0x569029e4,0x00000000,0x00000000}},	//   _èsuc, рают, --, --, 
   {{0xe3b001d9,0x261402ab,0xa2bc00fe,0x76440142}},	//   لرس_, पूजी_, _আলেখ, _âhyn, 
   {{0x06540736,0x21e40254,0x62300124,0x00000000}},	//   _منتح, _põh_, аҵоу, --, 
   {{0xdcf804b9,0x2d8402c4,0x1644f7d7,0x63687a78}},	//   _sluč, khoe_, _ачып_, _künz, 
   {{0xdcf801a6,0x00000000,0x00000000,0x00000000}},	//   _pluč, --, --, --, 
   {{0x7f580323,0x2d840194,0x636803fa,0xbbe0012c}},	// [15dd0] наас_, dhoe_, _münz, _पढेक, 
   {{0x7fb800f1,0x7e640477,0x00000000,0x00000000}},	//   رهار_, txhp, --, --, 
   {{0x394cf7d8,0xe2a80014,0xdcf80cf4,0xabd00046}},	//   ydes_, _زادن_, _smuđ, _ﺟﻮﻋﺎ, 
   {{0xa1440014,0x6024b1a8,0x2d840175,0x317c0221}},	//   _جیرٕ_, tūmā, ghoe_, ëtzt_, 
   {{0xbf1016c8,0x91840075,0x394cd95f,0xe4fc00bc}},	//   _гүзә, _ئۇقۇ, vdes_, _štěň, 
   {{0xdb1c010e,0xdb200139,0x4fc400d1,0xab24009b}},	//   _öwül, _üsüg, _نەقە, гоша_, 
   {{0xfa34f7d9,0xdeb00220,0xaee002dd,0xb7bc0356}},	//   ارتد, _тұжы, _اۋمى, nuţe, 
   {{0x4a74f7da,0x394cf7db,0x2d840005,0xca749684}},	//   рышт, udes_, choe_, рушы, 
   {{0xdcf800de,0x3774004e,0xdef004b2,0x00000000}},	//   _skuķ, гынс, _ውስን_, --, 
   {{0xdd903088,0x9c10063f,0xf7440063,0x00000000}},	//   _сағы, pọbi, ћено, --, 
   {{0xf7700502,0x00000000,0x00000000,0x00000000}},	//   لاگ_, --, --, --, 
   {{0x636834eb,0x394c031c,0xca7401af,0x00000000}},	//   _günz, qdes_, _туђы, --, 
   {{0x7bdc00d2,0x58001c5c,0x04780014,0x823400e5}},	//   _ésus, _толғ, ٖلُک_, یرِا, 
   {{0x636805d1,0x2898008f,0xc64400cf,0x281001e2}},	//   _küny, _אינא, _چئيى, _اووس, 
   {{0x2d840109,0xb7bc0356,0xdb0003b2,0xc0f00023}},	//   yhoe_, guţe, fonú, _ውዕሎ_, 
   {{0x636800a2,0x2d840175,0x00000000,0x00000000}},	//   _müny, xhoe_, --, --, 
   {{0xefc80a8f,0x00000000,0x00000000,0x00000000}},	// [15de0] елал_, --, --, --, 
   {{0xc0f0044e,0xa8040588,0xd54401e1,0x00000000}},	//   _ውዕል_, _heñó, bẹ̀d, --, 
   {{0x2d841fc0,0x2b5c007f,0xb7bc054e,0xabb000fb}},	//   thoe_, _rntc_, cuţe, ҙакә, 
   {{0xac08ef4d,0xac840598,0xd04405d9,0xdee001b9}},	//   енда_, лгел, _پھري, _ҳори, 
   {{0xdca0f7cf,0xeb98f7dc,0x3074004e,0x00000000}},	//   баци, нид_, _сунс, --, 
   {{0x2d849e2b,0x7ae00048,0x63682fbe,0x3b8400c7}},	//   shoe_, _cglt, _büny, аҩуп_, 
   {{0x6da4f7dd,0xee38f7de,0x7ed402bf,0x1fa40cb6}},	//   _бива, _янв_, _вітч, _скри_, 
   {{0x6368f7df,0x48140131,0x2d8401ee,0x661802fb}},	//   _düny, амис, qhoe_, vrtk, 
   {{0x6d40009f,0xa61000fd,0xa2b81221,0x02c001ad}},	//   meoa, әзмә, _शुन्, _एर्न, 
   {{0x661809a8,0xe66401c0,0x63680205,0x00000000}},	//   trtk, гтмо, _füny, --, 
   {{0xe8f8f7e0,0x6368453a,0x00000000,0x00000000}},	//   _зле_, _güny, --, --, 
   {{0xefe002d3,0x6d40009d,0x29d401d5,0x00000000}},	//   ምማዕ_, neoa, _сўзс, --, 
   {{0x68e00521,0x25781bce,0x9484f7e1,0x00000000}},	//   _igod, _jëli_, бырд, --, 
   {{0xb864f7e2,0x00000000,0x00000000,0x00000000}},	//   _خامو, --, --, --, 
   {{0x68e098b8,0x27e40489,0x6d4001c4,0x63682b93}},	//   _kgod, _huon_, keoa, _münx, 
   {{0x290400fb,0x27e4009f,0x38880213,0x6dac010f}},	//   _jeoa_, _kuon_, _ötrü_, nĝad, 
   {{0x6d40f7e3,0x200c00dd,0x27e4f7e4,0x68e04180}},	// [15df0] deoa, égi_, _juon_, _mgod, 
   {{0x2904f7e5,0x27e4001e,0x5f741eeb,0x00000000}},	//   _leoa_, _muon_, دارر, --, 
   {{0x4fc4cf02,0x1ea805d9,0x68e00428,0x6d400421}},	//   сста, رائي_, _ogod, feoa, 
   {{0x68e0f7e6,0x290400fb,0x7ae001ab,0x3b040175}},	//   _ngod, _neoa_, _sglt, _selq_, 
   {{0x27e4f7e7,0x7de40153,0x00000000,0x00000000}},	//   _nuon_, _mėsi, --, --, 
   {{0xab603559,0x68e0f7e8,0x3b04036e,0x00000000}},	//   şünm, _agod, _qelq_, --, 
   {{0x290401ee,0x7a6805f5,0x00000000,0x00000000}},	//   _beoa_, тийг_, --, --, 
   {{0x27e4f7e9,0x00000000,0x00000000,0x00000000}},	//   _buon_, --, --, --, 
   {{0x7784170a,0xff5c001f,0x8d8400f7,0xa80400c7}},	//   илиз, _ለማስመ, _уурд, _reñó, 
   {{0x27e4f7ea,0x68e07d3b,0xa2b81a2a,0x00000000}},	//   _duon_, _egod, _शुभ्, --, 
   {{0x39146568,0x29041140,0xa80409c2,0x3dcc00e8}},	//   _نواز, _feoa_, _peñó, _khew_, 
   {{0xd54401e1,0x27e40042,0x28d008df,0x00000000}},	//   _dé̟s, _fuon_, देहि, --, 
   {{0x27e40a85,0x7de400c0,0xa97800df,0x00000000}},	//   _guon_, _dėsi, _שאנכ, --, 
   {{0x68e0f7eb,0x88c802bf,0x6d40009d,0x98ac0153}},	//   _zgod, _слів_, zeoa, _sagė_, 
   {{0xe294152d,0x021802bf,0x27e401c4,0x3244036b}},	//   аар_, літь_, _zuon_, шевг, 
   {{0x6d40005a,0x79880042,0x9d340064,0x6590009b}},	//   xeoa, nhew, _афiц, _мају, 
   {{0xaf0432b0,0x656801ab,0x79880042,0xdb000254}},	// [15e00] ипал, _ògha, ihew, llnõ, 
   {{0x1f60f7ec,0x6fc001f1,0x7988014b,0x00000000}},	//   окум, môck, hhew, --, 
   {{0x7988f7ed,0x6e44023a,0xdcf8025c,0xf1b42c2e}},	//   khew, реез, _xjuħ, ंवदन, 
   {{0x3dccf7ee,0xbcfc0086,0xec78f7ef,0x245013de}},	//   _chew_, _anũb, кпе_, _انیس, 
   {{0x7988f7f0,0x5c006eec,0xc0d4001f,0x7afc01ed}},	//   dhew, ояща, _ጨርሶ_, _ősta, 
   {{0x290401e0,0x5bb41fe2,0x6d4001c0,0xe454008f}},	//   _seoa_, алія_, seoa, יינט_, 
   {{0x27e4f7f1,0x29040798,0xc0e40092,0xace800f3}},	//   _suon_, _peoa_, ምራሉ_, _амба_, 
   {{0x3dcc016d,0xda7402e8,0x6da46584,0x00000000}},	//   _ghew_, ряш_, _тиба, --, 
   {{0xab64f7f2,0x1cdc003d,0x7aec0882,0xe8700214}},	//   _квал, _ལུག_, śata, زندگ, 
   {{0x7bdc0798,0x27e4004d,0x7de40064,0x18b4035b}},	//   _ésup, _vuon_, _sėsi, ргьы_, 
   {{0x68e005d5,0xe5c426b1,0x546c0092,0x1a64a541}},	//   _tgod, исмо, _ትላለህ_, _نیوی_, 
   {{0xd5b8090b,0xd6d4f7f3,0x68e02481,0x7988f7f4}},	//   ися_, шты_, _ugod, chew, 
   {{0x28d09201,0xd9180a1e,0x7de40153,0xb86400ec}},	//   देशि, _יואל, _vėsi, _ٿانو, 
   {{0x6dac00df,0x00000000,0x00000000,0x00000000}},	//   nĝab, --, --, --, 
   {{0x4614f7f5,0x5690386f,0xdcec28b5,0x8afc0210}},	//   _اوبر, _машт, _šeče, _znęc, 
   {{0x9ac004ba,0xd6d80375,0x00000000,0x00000000}},	//   ŋŋga, _בחול, --, --, 
   {{0x3dcc015d,0x567c0092,0x00000000,0x00000000}},	// [15e10] _rhew_, _ጦርነቱ_, --, --, 
   {{0x7d1c00f8,0x5ea803f4,0x3dcc0204,0x20f00882}},	//   _össz, _করবে, _shew_, ṇi_, 
   {{0xc0e4001f,0x42540736,0xcc88023f,0x00000000}},	//   ምራል_, _انجر, ینمه_, --, 
   {{0x8d742aaf,0xb6d800c8,0xab601cce,0xb4dc01e1}},	//   يانا, אַנט, şülm, _àṣef, 
   {{0x6adc00eb,0x00000000,0x00000000,0x00000000}},	//   নুমো, --, --, --, 
   {{0x7f840491,0x3dcc0280,0xdb007575,0x7988f7f6}},	//   _السن, _whew_, onné, whew, 
   {{0x79880364,0x3dcc0649,0x5338010f,0x00000000}},	//   thew, _thew_, ינגן_, --, 
   {{0xadf80165,0xcd281411,0x00000000,0x00000000}},	//   _ʔɓɐ̤_, _ەسەن_, --, --, 
   {{0xa3b4561f,0x798805e4,0x2578002e,0x00000000}},	//   जवा_, rhew, _jëlu_, --, 
   {{0x7d08f7f7,0x7988f7f8,0x3f80f7f9,0xf0900375}},	//   _hees, shew, nkhu_, פני_, 
   {{0xd90c55b4,0x7d088928,0x7988f7fa,0x6ae400cf}},	//   _ہیں_, _kees, phew, _اقمۅ, 
   {{0x7d08f7fb,0xa2b8e698,0x224401ef,0x00000000}},	//   _jees, _शुध्, _ánky_, --, 
   {{0x3774013d,0x24e40150,0x81bc00eb,0x00000000}},	//   _гыйс, _ﺍﯞﻻﻣ, ইগা_, --, 
   {{0x7d08f7fc,0x656c0113,0xa8540375,0x00000000}},	//   _lees, ajch, _לינה_, --, 
   {{0xa2b8041c,0xf1a8f7fd,0x60c000ac,0x7f44022e}},	//   _शुद्, هاره_, ənmi, dehq, 
   {{0x7d08f7fe,0x2578002e,0x3f800014,0x00000000}},	//   _nees, _bëlu_, ekhu_, --, 
   {{0xa064f7ff,0x1cdc025c,0xfbb800dc,0x2bc80303}},	// [15e20] бата_, _ལུཊ_, ेताम, ितमा, 
   {{0xdfcc0f13,0xe45408a8,0xf2684130,0x00000000}},	//   فيق_, _פייט_, _биол_, --, 
   {{0x7d08f800,0xed5801c6,0x00000000,0x00000000}},	//   _bees, лож_, --, --, 
   {{0x7d08f801,0x9c1002e3,0xccf8abb5,0xfbb801d3}},	//   _cees, rọni, рқа_, یضوں_, 
   {{0x7d08f802,0xe3bc29ac,0xdca021ca,0x7d0c01a8}},	//   _dees, luña_, паци, ðasa, 
   {{0xd1cc001f,0x25780221,0x3ce80419,0x90980023}},	//   ቢዎች_, _hëlt_, ľava_, _ፍርዳዊ_, 
   {{0x3ce80552,0x7d08f803,0xe3bc0227,0x799803ac}},	//   žava_, _fees, nuña_, _bmww, 
   {{0x7d08f804,0x5c8401e0,0xa49802e2,0x00000000}},	//   _gees, рйәм_, nbòc, --, 
   {{0x3cfc00dc,0x2ca80120,0xbc2400db,0x6708009d}},	//   _लभते_, _скап_, _وركى, лэнг_, 
   {{0x7d08f805,0x5ea800bd,0x27480063,0xe3bcf806}},	//   _zees, _করতে, учио_, kuña_, 
   {{0x7d08f807,0x6ac4473f,0x99800014,0x26c801e3}},	//   _yees, _اقام, زلیو, åbo_, 
   {{0x26c0005f,0xe3bc01c4,0x7d086ed1,0xb7bc0356}},	//   āko_, duña_, _xees, ruţa, 
   {{0xef6402d3,0x77bc067c,0xb864143e,0x94846465}},	//   _ተዛዚሙ_, tèxt, _واهو, пырд, 
   {{0xdb0000a2,0x00000000,0x00000000,0x00000000}},	//   koný, --, --, --, 
   {{0x1b78008f,0x9798011a,0x00000000,0x00000000}},	//   נטלע, _תשוק, --, --, 
   {{0x309c0241,0x72d000cf,0x00000000,0x00000000}},	//   _sílẹ_, بەپچ, --, --, 
   {{0x7d080731,0xff980114,0x4394011c,0x00000000}},	// [15e30] _rees, акај_, _маис, --, 
   {{0x7d08f808,0x2d8c0023,0x00000000,0x00000000}},	//   _sees, ëfen_, --, --, 
   {{0x7d08f809,0x3f8006a3,0xc21001d9,0xe3bc30de}},	//   _pees, rkhu_, _تٔج_, cuña_, 
   {{0x05c84438,0x3f800054,0x7d080ba7,0x257804e6}},	//   रतिब, skhu_, _qees, _gëlt_, 
   {{0x7d08f80a,0x25780036,0x6b98022e,0xc0e40023}},	//   _vees, _hëls_, _bmtg, ዝካር_, 
   {{0x7d08f80b,0x7f440455,0xbe6400ec,0x450000eb}},	//   _wees, qehq, _وڇاي, ্লিক_, 
   {{0x7d08f80c,0x05c80c22,0x00000000,0x00000000}},	//   _tees, रताब, --, --, 
   {{0x7de40006,0x6e380267,0xf990007b,0x00000000}},	//   _dėst, _ätba, ببت_, --, 
   {{0x6f7400db,0x15e002dd,0x7de40064,0x00000000}},	//   _دەەر_, _ﺍﻟﺘﺩ, _vėsu, --, 
   {{0x6b980998,0xdb00000d,0x00000000,0x00000000}},	//   _gmtg, nonü, --, --, 
   {{0x1cdc0003,0x1b0c03d4,0x55c4f80d,0x0f580677}},	//   _ལུཌ_, _সাপে_, занғ, מיזם_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2ec4dcbe,0x98c40491,0xf770f80e,0xe3bc03f0}},	//   _वर्त, _اغان, _يات_, wuña_, 
   {{0xc18c0023,0x27a002dd,0x27440092,0xdb00f80f}},	//   _መለለዪ_, _оқың, ያቀርበ, monó, 
   {{0xe794d52d,0xa2e0f810,0x31740120,0xdb00012d}},	//   _بانک, дорд, оѓат, lonó, 
   {{0xe3bc36ed,0x65c02f33,0x9c1002e3,0x0674004e}},	//   ruña_, _обща, tọli, _хушя, 
   {{0x909c001f,0x386c0077,0x737400c7,0x1b0c00cc}},	// [15e40] _ጊዜያዊ_, nxer_, _дынх, _সানে_, 
   {{0xe3bc0005,0x386c00db,0x25780036,0xfbc40451}},	//   puña_, ixer_, _wëlt_, _سڪ_, 
   {{0xece8209b,0xa3b40073,0x00000000,0x00000000}},	//   адел_, जवर_, --, --, 
   {{0x3028f811,0xe0dc067c,0x9c1001f2,0x6c84837a}},	//   _комп_, _caòs_, pọli, يلام, 
   {{0x9c1001f2,0xefb001d5,0x7de40153,0x4af8117e}},	//   lọji, _قیرگ, _sėst, белю_, 
   {{0xdb9402d5,0x7de40024,0x00000000,0x00000000}},	//   овіч_, _pėst, --, --, 
   {{0x7c980023,0x98bc00b8,0x69c40709,0xbfd401af}},	//   ሓላለፍ_, _ārāt_, ातली, _хәтө, 
   {{0x2d80006a,0xdb00f5f4,0x99d0007b,0xec782401}},	//   _ôke_, fonó, وتيا, _кпб_, 
   {{0xab2831e2,0xdca00150,0x00000000,0x00000000}},	//   _воза_, _жати, --, --, 
   {{0x47340b16,0xa2b81d8a,0x00000000,0x00000000}},	//   чнос, _एडल्, --, --, 
   {{0x295400a7,0xb4b400d1,0x00000000,0x00000000}},	//   _мъдр, җирә, --, --, 
   {{0xa2b84a18,0x00000000,0x00000000,0x00000000}},	//   _शुष्, --, --, --, 
   {{0xdb00f812,0x00000000,0x00000000,0x00000000}},	//   conó, --, --, --, 
   {{0xfec40131,0xdce80e04,0x7cf03bed,0x93883cc5}},	//   _ﺩﺍﯞﺍ, _čičo, _kóró, осса_, 
   {{0x6d4c013b,0x418414d4,0xa2b800dc,0xd62400f3}},	//   _ɔbar, птағ, _शुश्, _доје_, 
   {{0xdb000109,0x7cf00332,0x3ea40419,0x98bc0205}},	//   nonò, _móró, _žlto_, nduğ_, 
   {{0xdb0001b8,0x84c40131,0x7dd033b8,0x6aa4041c}},	// [15e50] tonü, _хәнд, nåse, गपुर, 
   {{0x645cf813,0xe3bc5893,0xa3b40490,0x39a400e2}},	//   _irqi, muño_, जवळ_, rēsi_, 
   {{0x7d0c01a8,0xdcec00f3,0xa2801968,0xdb00012d}},	//   ðaso, šeča, _غیرو, zonó, 
   {{0x1cdc0135,0x7dd02d8b,0xe9c400ec,0x5bc0043e}},	//   _ལུད_, kåse, _سٺ_, षत्व, 
   {{0xdfd80c04,0x8d742ba5,0x3ce8151c,0xdb000005}},	//   _във_, بالا, žavo_, xonó, 
   {{0x9f40044e,0x7dd05522,0xa0380092,0x6aa40a59}},	//   _mijë_, dåse, _ሥርዓቶ, गपूर, 
   {{0x4ea40063,0x4e280117,0x00000000,0x00000000}},	//   _жрта, _моён_, --, --, 
   {{0xdb00f814,0x386c00f7,0x98ac08ad,0x7c9802d3}},	//   tonó, txer_, šače_, ሓላልፍ_, 
   {{0x5b300276,0x7dd0713c,0x386c00d8,0x00000000}},	//   _омаӂ, gåse, uxer_, --, 
   {{0xdb00f815,0x386c0005,0x6dac010f,0x29000d12}},	//   ronó, rxer_, nĝan, ðkar_, 
   {{0xa2b8c853,0x98a807c4,0x645c0023,0xdb00007f}},	//   _शुल्, ıcı_, _arqi, bonò, 
   {{0xdb00f816,0x9f400240,0x7dd00250,0x00000000}},	//   inní, _bijë_, låsb, --, 
   {{0x49b800db,0xe2943ad0,0x00000000,0x00000000}},	//   _بالد_, җат_, --, --, 
   {{0x1cdc031c,0x9f400240,0x87c0035b,0x6dac00df}},	//   _ལུན_, _dijë_, _иҩыз, jĝan, 
   {{0x645c0194,0xd6c08dff,0x00000000,0x00000000}},	//   _erqi, _تمثی, --, --, 
   {{0x94240075,0x59c82e35,0x00000000,0x00000000}},	//   _قوبۇ, ातिर, --, --, 
   {{0xef18f817,0x3074f818,0xa064721f,0x64a00131}},	// [15e60] йма_, чувс, пата_, _паъа, 
   {{0x7bc0025c,0xef180a93,0x1bec00c5,0x161c0073}},	//   _nklu, ёме_, _चढ़ल_, _मटार_, 
   {{0xdd8cd103,0xee38107a,0xe1f40276,0x59c808df}},	//   گون_, сне_, _нгэ_, ातार, 
   {{0xafe4f819,0x7dd00158,0xdb00004e,0xe5f4010f}},	//   _номл, yåse, xonò, לזער_, 
   {{0xdd8cf81a,0xf1f00037,0x00000000,0x00000000}},	//   دون_, _आंड़_, --, --, 
   {{0x9f40007f,0xdb0002e2,0x7dd05794,0x00000000}},	//   _nijè_, wonò, gåsb, --, 
   {{0xdb0066ce,0xed58e4e0,0x2d9400ee,0x00000000}},	//   tonò, _лов_, _ерас, --, 
   {{0x9de4003d,0x7bc0f81b,0x6f0c00a3,0xc9540882}},	//   _སྤྲེ, _eklu, _hebc, _bhīṣ, 
   {{0x7bc003a0,0xdb00f81c,0xac8407d6,0xdcf81710}},	//   _fklu, ronò, _эгал, _sluć, 
   {{0x1b0c0d42,0xdcf80989,0x7dd0e155,0xc9540055}},	//   _সাথে_, _pluć, råse, _dhīṣ, 
   {{0x6f0c0477,0x2d843545,0x78ac00d0,0x7dd00efa}},	//   _mebc, okoe_, _ľave, såse, 
   {{0x2bc83bec,0x78ac0153,0x9f40036e,0x6abc002f}},	//   ितवा, _žave, _pijë_, üpfu, 
   {{0x6fbcf81d,0x69c000fb,0x28d0202e,0xe78401f0}},	//   ्तां, _ikoe, देखि, _нуко, 
   {{0x9f400023,0xe3bc0077,0x6f0c058a,0x2d8c036e}},	//   _vijë_, ruño_, _nebc, ëfej_, 
   {{0x20041b24,0x69c00093,0xd24401c6,0x00000000}},	//   ćnim_, _kkoe, нэти, --, 
   {{0x5ea800bd,0x9f40036e,0xe7940244,0x00000000}},	//   _করলে, _tijë_, _باچک, --, 
   {{0x6f0cc2bf,0x7f8401b9,0x00000000,0x00000000}},	// [15e70] _bebc, ولرن, --, --, 
   {{0x4438f81e,0x2d840093,0x244c0327,0x00000000}},	//   mts_, ekoe_, _iżm_, --, 
   {{0x4438f81f,0x71f007dd,0x69c00165,0x6f0cf820}},	//   lts_, _аҧсу, _okoe, _debc, 
   {{0x69c01cfb,0x7bc0f821,0x8d54004e,0x00000000}},	//   _nkoe, _sklu, етшч, --, 
   {{0x4438f822,0x8d7400e5,0x5fa01c3e,0x00000000}},	//   nts_, عاما, _كەرم, --, 
   {{0x4438605b,0x69c0f823,0x00000000,0x00000000}},	//   its_, _akoe, --, --, 
   {{0x4438f824,0x1cdc0135,0x7bc00010,0x7dd001e3}},	//   hts_, _ལུམ_, _vklu, råsb, 
   {{0x44380029,0x9f400699,0x6dac01e4,0x6f0c00d7}},	//   kts_, _sijè_, nĝal, _zebc, 
   {{0x44380003,0x98ac0064,0x00000000,0x00000000}},	//   jts_, _vagį_, --, --, 
   {{0x7bc0f825,0x69c00793,0x59c8012c,0x7c380142}},	//   _uklu, _ekoe, ातहर, mtwr, 
   {{0x7c38015d,0x6abc0112,0xe66c0205,0xcb441422}},	//   ltwr, üpft, rüşş, _яхти, 
   {{0x4438eaa1,0xa49856ed,0xc32400eb,0x00000000}},	//   fts_, rbòn, ম্মি_, --, 
   {{0x4438f826,0xe72c0046,0xb328025c,0x7c380042}},	//   gts_, _ие_, _སྐུང_, ntwr, 
   {{0xa49866ce,0x9f400789,0xa760f827,0x437460c6}},	//   mbòl, _fijé_, _акшд, нуст, 
   {{0x4438f828,0x6fbc193d,0x7c3803ac,0x2d840108}},	//   ats_, ्तसं, htwr, ykoe_, 
   {{0x21642928,0x97000131,0x4438f829,0x7054015e}},	//   миси_, _تېگى, bts_, ونزا, 
   {{0x4438f82a,0x6f0c0218,0x2008015d,0xa0a001d5}},	// [15e80] cts_, _pebc, _cwci_, ватд, 
   {{0xef1820eb,0x00000000,0x00000000,0x00000000}},	//   іме_, --, --, --, 
   {{0x6f0c0477,0x7cf000e4,0xed580500,0x00000000}},	//   _vebc, _ẽras, жое_, --, 
   {{0x6f0c7156,0x1d04011c,0x00000000,0x00000000}},	//   _webc, деци_, --, --, 
   {{0x6f0c0457,0x6aa4f82b,0x2bc835e0,0x00000000}},	//   _tebc, गप्र, ितला, --, 
   {{0x69c06254,0x399001ed,0xdb002694,0xaa648ca0}},	//   _skoe, _lásd_, linê, дтик, 
   {{0x6da43b2e,0x443800de,0xada44c91,0x00000000}},	//   _жива, zts_, _жавл, --, 
   {{0x4438f82c,0xafe4036b,0x7c2c0332,0x00000000}},	//   yts_, _хоҳл, ónré, --, 
   {{0x4438f82d,0x274834d8,0x9f480129,0xdd8c00d1}},	//   xts_, очно_, _sucé_, _ئوق_, 
   {{0x443801e3,0x9f480129,0x00000000,0x00000000}},	//   vts_, _pucé_, --, --, 
   {{0x443806f2,0x7dd04cab,0x9f5000e5,0x00000000}},	//   wts_, låsa, ödés_, --, 
   {{0x4438f82e,0x386808a4,0xb36c02d3,0x00000000}},	//   tts_, _šare_, _ኣለወን_, --, 
   {{0x44380385,0x20040989,0x3fc40131,0x1cb8010f}},	//   uts_, ćnik_, ﯩﻼﺭﻧ, ַמלע, 
   {{0xf8ac00dd,0x00000000,0x00000000,0x00000000}},	//   _چکی_, --, --, --, 
   {{0x4438f82f,0x9258f830,0x7d0c08a7,0x20080042}},	//   sts_, март_, ðask, _swci_, 
   {{0x4438f831,0x16840244,0x00000000,0x00000000}},	//   pts_, _تاهێ, --, --, 
   {{0x24b48bee,0x00000000,0x00000000,0x00000000}},	// [15e90] _زندگ_, --, --, --, 
   {{0xdce80122,0xdb00014a,0x228400f7,0x69cc00ef}},	//   čičk, lonö, _жумг, _ūbel, 
   {{0x4fc40598,0x246400f1,0xe45c0847,0x6adc05ac}},	//   тста, _راکټ, lvö_, _ন্সো, 
   {{0xdb000793,0xbbb800dc,0x00000000,0x00000000}},	//   nonö, ेत्क, --, --, 
   {{0x3af40108,0x7dd001e3,0x00000000,0x00000000}},	//   няйс, gåsa, --, --, 
   {{0x7c389b7d,0xdb000023,0x399001e1,0x6dac01e4}},	//   rtwr, minë, _máse_, nĝaj, 
   {{0xdb00f832,0x6fbc4da1,0x8f340353,0xdb0c00e5}},	//   konö, ्तरं, _шерц, _üdít, 
   {{0xdb0001b8,0xd8cc0150,0x00000000,0x00000000}},	//   jonö, _ﮔﻪﻭﻟ, --, --, 
   {{0xb7bc00a8,0xdb00f833,0x26c80793,0xe8c402e8}},	//   luţi, donö, übon_, нгъл_, 
   {{0x2004098d,0x9ba010e0,0x0c9400e5,0x00000000}},	//   ćnih_, _جەتى, _جگمگ, --, 
   {{0xdb00f834,0xa68001c0,0xb7bc054e,0x3668f835}},	//   fonö, глэд, nuţi, чано_, 
   {{0x8a1004a9,0x399001e1,0xdb000023,0xc0b801f3}},	//   _ئېيت, _báse_, kinë, ዲሞስ_, 
   {{0x394c033d,0x7988090c,0xcb6000e8,0xd5a40214}},	//   mees_, mkew, _k茜pp_, فلگی, 
   {{0x394cf836,0x3990056a,0xdb000023,0xa878010f}},	//   lees_, _dáse_, dinë, _מאנר, 
   {{0x798800b0,0x00000000,0x00000000,0x00000000}},	//   okew, --, --, --, 
   {{0x394cf837,0x79884b77,0xcb6000e8,0x3cec014f}},	//   nees_, nkew, _l茜pp_, _ngev_, 
   {{0xdb00f838,0x00000000,0x00000000,0x00000000}},	// [15ea0] ginë, --, --, --, 
   {{0x394cc52d,0x6fb40597,0xcb60002e,0xafe401d5}},	//   hees_, رمضا, _n茜pp_, хозл, 
   {{0x7988f839,0x394c851a,0xdb00f83a,0xdfcc9edc}},	//   kkew, kees_, minè, حيل_, 
   {{0xdb00f83b,0x394c12ce,0xdce80166,0x00000000}},	//   linè, jees_, figı, --, 
   {{0x394cf83c,0xcb6000e8,0xac8405f5,0xa06401c0}},	//   dees_, _b茜pp_, эгдл, _заяа_, 
   {{0xb7bc084c,0x798804ba,0xde0000d1,0x7dd00267}},	//   buţi, ekew, _әпти, råsa, 
   {{0x394cf83d,0xcb60002e,0xb7bc0276,0xe9e40801}},	//   fees_, _d茜pp_, cuţi, нцио, 
   {{0xdb00020c,0xfcd40023,0x7dd093e0,0xdce8008e}},	//   hinè, _ርጉጽ_, påsa, bigı, 
   {{0xdcec04b9,0xd83405f5,0x99e000d7,0x00000000}},	//   _šeće, нээ_, áňal, --, 
   {{0x65a802f6,0xdb000100,0x798803ac,0x00000000}},	//   köhä, jinè, akew, --, 
   {{0x394cf83e,0xdb00f83f,0x47d400e5,0x00000000}},	//   bees_, tonö, ٹيگر, --, 
   {{0x394c0441,0x79880036,0x39900f91,0x00000000}},	//   cees_, ckew, _páse_, --, 
   {{0xcb6000e8,0xc5040014,0x186401af,0x00000000}},	//   _y茜pp_, ى۪ژل_, _паци_, --, 
   {{0xbd040036,0x7bdc04cc,0xdb00f840,0x00000000}},	//   _kréé, _èsut, ginè, --, 
   {{0x6dac00df,0x25e80412,0x00000000,0x00000000}},	//   rĝaj, _घंटी_, --, --, 
   {{0xdb0002d3,0x0494007b,0x6618007c,0x00000000}},	//   tinë, _للبح, mstk, --, 
   {{0x7f5805f5,0xdb004c6e,0xd6dc033f,0x00000000}},	// [15eb0] маас_, binè, ąłem_, --, 
   {{0xb7bc00a8,0xdb00f841,0x6618000d,0x00000000}},	//   tuţi, cinè, ostk, --, 
   {{0x1b0c00bd,0x657c0fec,0x63a4f842,0x394cf843}},	//   _সালে_, _koqh, mijn, yees_, 
   {{0x63a4f844,0xfc30f845,0xdb00f846,0x6618f847}},	//   lijn, لحت_, miné, istk, 
   {{0xdb00f848,0xbde401e1,0x657cf849,0x6284f84a}},	//   liné, _abèé, _moqh, lyjo, 
   {{0x63a4f84b,0x394c0151,0x6618f84c,0x657c00f1}},	//   nijn, wees_, kstk, _loqh, 
   {{0xbd0420ef,0x7988017a,0x66182589,0x31780133}},	//   _créé, tkew, jstk, _رجێک_, 
   {{0x63a46ae2,0x657c0921,0x4998005b,0xaa540063}},	//   hijn, _noqh, етья_, тићу_, 
   {{0x798820af,0x3b54f84d,0x7dd0007c,0x66180210}},	//   rkew, _икар, låso, estk, 
   {{0xfd4c07ae,0xdb000120,0xbd040036,0x7988000f}},	//   _ngoạ, gonô, _fréé, skew, 
   {{0x394cf84e,0x657cf84f,0x63a40122,0xdb00be6d}},	//   pees_, _boqh, dijn, jiné, 
   {{0xdb00f850,0x35a44964,0x00000000,0x00000000}},	//   diné, тамг, --, --, 
   {{0x657c0477,0xdb00506b,0xc76400d1,0x6618012d}},	//   _doqh, tinè, ئاۋى, astk, 
   {{0xb7d8f851,0xdb0004e6,0xc35400a7,0x63a4f852}},	//   _غوغا_, finé, лъсъ, gijn, 
   {{0xdb00f853,0x489c0092,0x00000000,0x00000000}},	//   giné, ልጋለሁ_, --, --, 
   {{0x3f900268,0x75d400cf,0x24500451,0xdb00004e}},	//   _alzu_, _جيعا, _چنيس, sinè, 
   {{0xe45446e5,0x63a401a4,0xdb000036,0x00000000}},	// [15ec0] _ажы_, bijn, onnä, --, 
   {{0xdfcc0979,0xe0d4f854,0x63a40196,0x5f000139}},	//   قيق_, тву_, cijn, изуа, 
   {{0x8d286833,0xdb002b1d,0x657c01e2,0x00000000}},	//   енең_, ciné, _yoqh, --, 
   {{0x1ae00183,0xac84010b,0x00000000,0x00000000}},	//   নুৱা, кгел, --, --, 
   {{0xdcac0aaf,0xeb9810f9,0x63b80036,0x00000000}},	//   يىم_, мид_, éung, --, 
   {{0x6618f855,0xdca01d0f,0xbd040129,0x00000000}},	//   ystk, шачи, _préé, --, 
   {{0x38680003,0x00000000,0x00000000,0x00000000}},	//   _ġara_, --, --, --, 
   {{0xcdc40364,0x63a40196,0x38680fcf,0x9a805cdd}},	//   _сабқ, zijn, _šara_, рушл, 
   {{0xe5740006,0x6d40000f,0x2d8c036e,0x00000000}},	//   _nėšč, mfoa, ëfeu_, --, 
   {{0x6d40f856,0x657cf857,0xe97001d9,0x00000000}},	//   lfoa, _soqh, انکھ, --, 
   {{0xdb000120,0x6dac010f,0xa49800e4,0xd6d00022}},	//   ronô, rŝaf, mbòi, ижьы, 
   {{0x661836fc,0x63a4f858,0x7bdc04cc,0xcfd8009e}},	//   rstk, wijn, _èsur, তদিন, 
   {{0xd87016e6,0x63a4f859,0x545410d9,0x26c00034}},	//   _ناوب, tijn, авят, łko_, 
   {{0xdb00f85a,0x657c01e2,0x656801ab,0xdbcc00d0}},	//   tiné, _woqh, _ųghd, _sľúb, 
   {{0x63a4a162,0x6d40f85b,0x30940092,0xd7c40244}},	//   rijn, kfoa, _መመገብ_, _جووه_, 
   {{0x25780036,0xdb002056,0x6d40002d,0xb3582440}},	//   _lëlz_, riné, jfoa, _ዲዛይን_, 
   {{0xdb000597,0x63a4f85c,0xdcf8008e,0x6d40002d}},	// [15ed0] siné, pijn, _aluğ, dfoa, 
   {{0xdb005fe6,0x63a4014f,0x62840022,0xbf140244}},	//   piné, qijn, pyjo, اواب, 
   {{0xdd4c02d3,0xb7bc054e,0x399001e7,0x9984054e}},	//   _መምርሒ, cuţu, _lása_, nunţ_, 
   {{0xfcd4001f,0xa49800db,0x9f8c010e,0x00000000}},	//   ርግጥ_, rcòf, küç_, --, 
   {{0x78ac00d0,0xdb00005b,0x00000000,0x00000000}},	//   _ľavo, ynnä, --, --, 
   {{0x28c4007d,0x06d803d4,0xdce400ef,0x00000000}},	//   _लड़ि, _সলনি, _šlēg, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x1db4b627,0xdcf802f0,0x39901427,0xe3bc1bce}},	//   _अदित, _kouč, _bása_, muñu_, 
   {{0x7d180280,0xf770f85d,0xe3bc00e8,0x9f8c0205}},	//   maws, ماد_, luñu_, güç_, 
   {{0xdcf800bc,0x00000000,0x00000000,0x00000000}},	//   _mouč, --, --, --, 
   {{0xdcf800bc,0xe6147bf1,0xe3bc1bce,0x00000000}},	//   _louč, лдэ_, nuñu_, --, 
   {{0x3ce80b91,0x7d180054,0x78b80218,0x1db04668}},	//   žavu_, naws, _txwv, ंचित, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x395c4e0b,0x1c0803ce,0x7d18f85e,0x2ba4024a}},	//   _haws_, सीएल_, haws, कोपा, 
   {{0x395c0211,0x321cf85f,0xe3bc002e,0x7d18f860}},	//   _kaws_, éty_, juñu_, kaws, 
   {{0x9f4424ba,0x7d18a735,0xe3bc00e8,0x395c2517}},	//   önî_, jaws, duñu_, _jaws_, 
   {{0x9f48026c,0x7d187d19,0x395cf861,0xb3c8005b}},	// [15ee0] _bucà_, daws, _maws_, _плиз_, 
   {{0xdcf802fb,0x395cf862,0xe3bc0de2,0x00000000}},	//   _douč, _laws_, fuñu_, --, 
   {{0xc4c40014,0x7dd0050a,0x6d406c03,0x78ac0010}},	//   _متیو, påsl, tfoa, _žavl, 
   {{0x7d180589,0x395c03cb,0x2ba40073,0x00000000}},	//   gaws, _naws_, कोना, --, 
   {{0x6d400a85,0x25180375,0x61f801e4,0x4dd40116}},	//   rfoa, תונא, ĉule, ﯘﭼﯩﻨ, 
   {{0x6d40045f,0xe3bc002e,0x399001e7,0xee380798}},	//   sfoa, buñu_, _rása_, _пнг_, 
   {{0x7d18f863,0x00000000,0x00000000,0x00000000}},	//   baws, --, --, --, 
   {{0x395cf864,0x7d0c008c,0xec14eead,0x6a480213}},	//   _caws_, ðast, _مورد, _rəfd, 
   {{0x395c0190,0xe78408ca,0x6dac00df,0x6a4806be}},	//   _daws_, гуно, rŝad, _səfd, 
   {{0x7bdc011c,0x6ab8f865,0x39900332,0x00000000}},	//   _èsup, _txtf, _vása_, --, 
   {{0x395c039a,0x9f4800d8,0x81bc00cc,0x00000000}},	//   _faws_, _jucá_, েগত_, --, 
   {{0xd6d4f866,0x6d4401e6,0x395c0492,0x25700131}},	//   ыты_, _ökad, _gaws_, сқис, 
   {{0xe4a43967,0x5ea800bd,0xd4480131,0xe3b035b6}},	//   урно, _করছে, лярд_, مرس_, 
   {{0x395c0211,0x7d180034,0xe3bc00e8,0x00000000}},	//   _zaws_, zaws, yuñu_, --, 
   {{0xdcf8038e,0x395c0218,0x45d4f867,0x92946c43}},	//   _souč, _yaws_, _кокс, барц, 
   {{0xd138f868,0x395c0211,0x225c01e4,0x7d180067}},	//   лху_, _xaws_, ĉuk_, xaws, 
   {{0x3f1446ed,0xe3bc1bce,0x00000000,0x00000000}},	// [15ef0] идас, wuñu_, --, --, 
   {{0xd3240474,0x7d18089c,0x98ac009b,0xe3bc1bce}},	//   _льюи, waws, šaće_, tuñu_, 
   {{0xe2a80531,0xe0dc0248,0x98ac0327,0x7d180784}},	//   _سادن_, _gbòn_, _tagħ_, taws, 
   {{0x4034f869,0xe3bc1bce,0x25a80042,0x00000000}},	//   _кемс, ruñu_, nicl_, --, 
   {{0x395c0190,0x61f400e4,0x7d18f86a,0xe3bc0de2}},	//   _raws_, _huxl, raws, suñu_, 
   {{0x395cf86b,0x7d181c06,0x38680010,0x527402f2}},	//   _saws_, saws, _šaro_, _ئایز, 
   {{0x395cf86c,0xe3bc00e8,0xeb940cc9,0x7d18031c}},	//   _paws_, quñu_, рищ_, paws, 
   {{0x395c098f,0x61f4036b,0x7d180054,0xca740220}},	//   _qaws_, _muxl, qaws, сушы, 
   {{0x3d040490,0x61f404e6,0x61ecf86d,0x8fc80014}},	//   हुणे_, _luxl, _micl, _شِہل_, 
   {{0x395c039a,0xdd901669,0x61ec004e,0x6a4803b9}},	//   _waws_, _тағы, _licl, _səfe, 
   {{0x395c0457,0x61ec01ab,0x8b340150,0xca4802f2}},	//   _taws_, _oicl, _اۋىر_, _ملله_, 
   {{0x61ecf86e,0x8afc068f,0xca2c008f,0x00000000}},	//   _nicl, _wnęt, _טובֿ, --, 
   {{0x61f445a7,0xdb00f86f,0x059801d9,0xe454009d}},	//   _auxl, minâ, امُک_, ажя_, 
   {{0x39900124,0x00000000,0x00000000,0x00000000}},	//   _káso_, --, --, --, 
   {{0xd348f870,0x3114023b,0x14d80073,0xa5f400f3}},	//   نیکه_, ифас, _ठरवण, _кеју_, 
   {{0x6fb80882,0x6dac00df,0xfc24129d,0x00000000}},	//   ्वभू, nĝat, _ىڭ_, --, 
   {{0x208402bf,0x33d41cb8,0x39900241,0xe4d001ec}},	// [15f00] айти_, _вінт, _láso_, _وقىد, 
   {{0xdb00f871,0x61ec00a3,0x00000000,0x00000000}},	//   finí, _eicl, --, --, 
   {{0xed5810f5,0x764014dc,0xee38f872,0x61ecf873}},	//   кож_, ntly, тне_, _ficl, 
   {{0x61ec81f1,0x76409cf6,0x224401e3,0xac080139}},	//   _gicl, itly, _änka_, внда_, 
   {{0xdb00f874,0x3ad40208,0xa5c402d2,0x76400857}},	//   dinâ, _áp_, _hlóð, htly, 
   {{0x61ec04cc,0x7640002d,0xa49835f5,0x1b4406dc}},	//   _zicl, ktly, mbòt, изчи_, 
   {{0x61ec0af2,0x399000c7,0xbc240132,0xad2405d3}},	//   _yicl, _cáso_, _ۇرلى, _پرزو, 
   {{0x497449de,0x39900241,0x61ec00db,0x9974054e}},	//   слис, _dáso_, _xicl, văţ_, 
   {{0x7d0c0077,0x3ad40208,0x57f00108,0x00000000}},	//   ñase, _ép_, опыт, --, 
   {{0x7640f875,0xe664f876,0x00000000,0x00000000}},	//   ftly, атмо, --, --, 
   {{0x2c0c0f22,0x7640010b,0x2ba41c54,0x00000000}},	//   _সময়ে_, gtly, कोणा, --, 
   {{0x7c2c1505,0xe4a40107,0x61f4008e,0x7dd0007c}},	//   šare, ҳрҳо, _ruxl, våsk, 
   {{0x94a8f877,0x61ecf878,0x00000000,0x00000000}},	//   атра_, _ricl, --, --, 
   {{0x61ecf879,0xa5c42833,0x24880076,0xa6e0032e}},	//   _sicl, _blóð, rycm_, _íðor, 
   {{0x61ec05d5,0x76400c8c,0xb060023a,0xe9e4032e}},	//   _picl, ctly, äänn, _þúst_, 
   {{0xdb00352a,0x7dd00158,0x80f4f87a,0x95c401f7}},	//   viní, råsk, спах, _ويوه, 
   {{0x61ec054e,0x04880139,0x7f940022,0xd4680798}},	// [15f10] _vicl, _сәни_, баах, _виње_, 
   {{0xc0c40032,0x61ec003a,0xa5c40aab,0xdcf801d5}},	//   _ғәби, _wicl, _flóð, چرشش_, 
   {{0x61ecf87b,0x4ea40024,0x7dd003cd,0xa5c42507}},	//   _ticl, орца, låsi, _glóð, 
   {{0x91e40120,0xdb000332,0xd0500150,0xd5f8010f}},	//   _моќе, riní, _ﺗﻴﯩﭗ_, דפאר, 
   {{0x399001e1,0x00000000,0x00000000,0x00000000}},	//   _sáso_, --, --, --, 
   {{0xdef8799e,0x399000e4,0xcb0801c8,0x00000000}},	//   _шым_, _páso_, ليهن_, --, 
   {{0xfee403f4,0xb2200008,0x4fc40a52,0x8fc400db}},	//   _প্রধ, _áætl, _بەلە, _بۅلۇ, 
   {{0xd2b81203,0x3a280e04,0x00000000,0x00000000}},	//   ילות_, čap_, --, --, 
   {{0xf8a80502,0xdb00006a,0x941002a8,0x6dac01e4}},	//   دگاه_, rinâ, ɗaɗa_, rĝat, 
   {{0xda640451,0x76404867,0x973001d5,0x39900241}},	//   _پائي, ttly, زکتا, _táso_, 
   {{0x3ad4f87c,0xdb00f87d,0x6dac0115,0x391406c2}},	//   _اياز, minà, mĝar, _هواز, 
   {{0x7640f87e,0xdb00642b,0x00000000,0x00000000}},	//   rtly, linà, --, --, 
   {{0xa5c42880,0x7640f87f,0xc79801d3,0x00000000}},	//   _slóð, stly, _چھپا_, --, 
   {{0xb9e40023,0x6dac00df,0x76400857,0x00000000}},	//   _ራሻ_, nĝar, ptly, --, 
   {{0x6f740150,0x2bb8090a,0x290c02d2,0x00000000}},	//   _ﱠﺸﻨﺎ_, ेवता, _ímaí_, --, 
   {{0xdb004ee5,0x21a016a4,0x00000000,0x00000000}},	//   hinà, писм, --, --, 
   {{0x2164c172,0x61f80115,0x00000000,0x00000000}},	// [15f20] щити_, ĉula, --, --, 
   {{0xe478025f,0x00000000,0x00000000,0x00000000}},	//   _עריכ, --, --, --, 
   {{0xdb0035fb,0x3dcc0327,0x6ab40073,0xc0c80092}},	//   dinà, _bkew_, _अखेर, ጽራረ_, 
   {{0xdcf802b1,0xc0b802d3,0xa498068c,0xdefc025c}},	//   _pouā, ዲሞም_, mbòr, ċċar_, 
   {{0x1b0c045e,0x653800c8,0x9f4000a2,0x00000000}},	//   _সাজে_, רענד, _bijä_, --, 
   {{0x7c64044c,0xdb0056ed,0x5bb412fa,0x00000000}},	//   غانل, ginà, блія_, --, 
   {{0x7d0c04d4,0x00000000,0x00000000,0x00000000}},	//   ñasc, --, --, --, 
   {{0xed5810f5,0x6f1c2195,0xad2400f1,0x6a4803b9}},	//   _щоб_, lapc, _درسو, _cəfa, 
   {{0x187000fd,0x00000000,0x00000000,0x00000000}},	//   згыя, --, --, --, 
   {{0x6f1cf063,0x7c2c0384,0x3a280227,0x17f400c6}},	//   napc, šarc, ņapa_, حرية_, 
   {{0xd90c4e90,0x7b6401d9,0x45b800d4,0x00000000}},	//   _нь_, _باقٕ, игою_, --, 
   {{0x69d800c6,0x601c01e1,0x6f1c014f,0x250801c6}},	//   _صباح_, _jàmá, hapc, ыхоо_, 
   {{0xdb001d91,0x6f1c00dd,0xe4c40a89,0x94140073}},	//   liná, kapc, сённ, तीलच_, 
   {{0x7dd00fac,0xe1f0007b,0x25a80055,0x60440022}},	//   råsi, كسر_, _śilī_, ҩхаз, 
   {{0xdb0002fb,0x78ac00d0,0x28cc0037,0x9294f880}},	//   niná, _ľavi, _हँडि, парц, 
   {{0x7dd00158,0x78ac0024,0x6dac01e4,0xbb3801ec}},	//   låsv, _žavi, zĝar, _ﺒﺴﻁ_, 
   {{0xa4980ba1,0x93c801d9,0xfe700014,0x00000000}},	// [15f30] rbòs, _گاٹہ_, ژگر_, --, 
   {{0x1ae000bd,0x645cf881,0x3dcca9e9,0x67380728}},	//   নুয়া, _isqi, _skew_, ngtj, 
   {{0xdb000313,0xdcf80356,0x00000000,0x00000000}},	//   jiná, _nouă, --, --, 
   {{0x3cd41413,0xdb00f882,0xdb2001e1,0x00000000}},	//   ожес, diná, _òrúw, --, 
   {{0xdb0000db,0x0c241e32,0x6a4803b9,0x00000000}},	//   tinà, змін, _rəfa, --, 
   {{0xeb941f87,0xdb001ab0,0xfed80451,0xbb84027d}},	//   жиш_, finá, _نازڪ_, تلتي, 
   {{0xdb00f883,0x6dac0115,0x0ca80124,0x00000000}},	//   giná, mŝan, итәи_, --, 
   {{0xdcf80311,0x38280063,0x6dac0115,0xcb0800d1}},	//   _două, ажио_, lŝan, ليۇن_, 
   {{0x6a4800ac,0xdb0000db,0x5fbc3f7e,0x00000000}},	//   _vəfa, pinà, ्वपल, --, 
   {{0x76246ff7,0xdb000518,0xf624f884,0x6dac010f}},	//   омоз, biná, одоо, nŝan, 
   {{0xdb00f885,0x00000000,0x00000000,0x00000000}},	//   ciná, --, --, --, 
   {{0xfe1003ba,0x00000000,0x00000000,0x00000000}},	//   डीएस_, --, --, --, 
   {{0x25a400f2,0xfa300092,0x00000000,0x00000000}},	//   تگوي_, _አርበኞ, --, --, 
   {{0xe0dc08e7,0xf770a957,0x98900075,0x6dac01e4}},	//   _ebòk_, _زات_, _муһә, jŝan, 
   {{0x6f1c01fa,0x00840137,0x645c06be,0xf678010f}},	//   vapc, үксү, _esqi, _כאַמ, 
   {{0x3108b132,0x00000000,0x00000000,0x00000000}},	//   рнап_, --, --, --, 
   {{0xef18f886,0xdb00f887,0xa4980ba1,0x6f1cf888}},	// [15f40] има_, ziná, sbòr, tapc, 
   {{0x55c40ce8,0x24500101,0xd244022e,0x00000000}},	//   _фәүз, _کنیس, _емоқ, --, 
   {{0x2eec049f,0xdb000005,0x6f1c0419,0x09d000cc}},	//   äff_, xiná, rapc, াগতা, 
   {{0xccf8f889,0xdb0047f5,0x6ab4000d,0x4ac4000d}},	//   сқа_, viná, _अखौर, _लुगव, 
   {{0xdd8c6762,0x7d0c094a,0x847c0023,0xcb6801d5}},	//   خون_, ñasa, _ብቋንቋ_, یمچه_, 
   {{0xdb0003f7,0x6a4803e3,0x6f1c25de,0xbcfc0055}},	//   tiná, _dəfn, qapc, _paũc, 
   {{0xed580354,0xdfcc1359,0x00000000,0x00000000}},	//   _ков_, _شيف_, --, --, 
   {{0xdb00ce10,0x6d980142,0x481400d1,0x80240345}},	//   riná, _dïac, пмис, _برێم, 
   {{0xdb00f88a,0xf72c0092,0x00000000,0x00000000}},	//   dinæ, _ተጠቁሟ, --, --, 
   {{0x2d800086,0xdb002358,0x2ba407b7,0x00000000}},	//   _òkeb_, piná, कोशा, --, 
   {{0x45d4f88b,0x6b9802d0,0xe97001d9,0x5ef8010f}},	//   зонс, _iltg, _ٲنتھ, יפיד, 
   {{0x16d40323,0x6560013f,0xdb000b1a,0x65a8f88c}},	//   өгөө_, _ɔnhw, ginæ, ртог_, 
   {{0xe784f88d,0x46143cde,0x00000000,0x00000000}},	//   _муко, _کوبر, --, --, 
   {{0x8c48887f,0x00000000,0x00000000,0x00000000}},	//   mağı, --, --, --, 
   {{0x8c481d89,0xd6cc0a89,0x61f8010f,0x1b78010f}},	//   lağı, _цт_, ĉulo, סטלע, 
   {{0xd250021a,0x25ac07de,0x1a98008f,0xa498067c}},	//   کنې_, _ögl_, בילע, sbòq, 
   {{0x3ff4f88e,0x8c481d89,0x6b9803ac,0x6dac0115}},	// [15f50] سكار, nağı, _oltg, tŝan, 
   {{0x4438f88f,0x5e680640,0xf410011a,0xdb140205}},	//   mus_, ијег_, _רפי_, ücüy, 
   {{0x4438f890,0x6dac008f,0xdb00f891,0x00000000}},	//   lus_, rŝan, linç, --, 
   {{0x44387785,0x6b98738e,0xc3240014,0x8c480790}},	//   ous_, _altg, _بٹھى, kağı, 
   {{0x4438f892,0x6b980334,0x3b081575,0x672803cd}},	//   nus_, _bltg, бело_, _odfj, 
   {{0x29041140,0x4438f893,0x8c483bc1,0xbcfc002b}},	//   _afoa_, ius_, dağı, _daũa, 
   {{0x6fb8f894,0x539c0a1e,0xbd4400db,0x00000000}},	//   ्वरू, שיוו, _ىپسى, --, 
   {{0x6b98022e,0x7dd001e3,0x8c480205,0x5ce40395}},	//   _eltg, gåst, fağı, _дюза, 
   {{0x4438f895,0xbb4c105c,0xdb0000a2,0x00000000}},	//   jus_, _comホ_, jinç, --, 
   {{0x1ac800fd,0x6a4803b9,0x00000000,0x00000000}},	//   _куеп_, _kəfl, --, --, 
   {{0x4438f896,0xca740131,0x41bc35e0,0x35c801c0}},	//   eus_, _يامغ, ्कास, йгоо_, 
   {{0x9f480998,0x8c487236,0x4ac4000d,0x29000de2}},	//   _cucú_, bağı, _लुटव, ñkat_, 
   {{0x8c480baf,0xe72c28cf,0xdb00f897,0x9f400241}},	//   cağı, _пе_, rinæ, _dijú_, 
   {{0xf748038b,0x4374014b,0xdb0002f0,0x00000000}},	//   _طلبي_, муст, ynný, --, 
   {{0x44380953,0xe2941cd6,0xe0dc02e2,0xdb00f898}},	//   aus_, пар_, _azò_, minä, 
   {{0x4438f899,0x39900162,0xdb00f89a,0x28e00e5b}},	//   bus_, _bási_, linä, _परमि, 
   {{0x4438f89b,0xe5380375,0xa498004e,0x2fd82bd8}},	// [15f60] cus_, _התפר, ncòl, مورد_, 
   {{0x80c00eac,0x7c3801f5,0x7d0c0784,0xdb00f89c}},	//   _শৃঙ্, duwr, ñasn, ninä, 
   {{0xa13401ed,0x7c3801f5,0x14c8036b,0xbcfc00b8}},	//   _کرپش, euwr, _دهکی_, _saũa, 
   {{0x8c480ac4,0xdb001057,0xfa280327,0x2d940137}},	//   yağı, hinä, _ལྷེན_, чөгө_, 
   {{0xdb00005b,0x7dd003cd,0x00d4022e,0x00000000}},	//   kinä, våst, _жўрў, --, 
   {{0x94fc0003,0x8c480205,0xfc3400c7,0x00000000}},	//   _དཔའི_, vağı, ьҭу_, --, 
   {{0x9ea46997,0xdb00f89d,0x7df40131,0xabd40014}},	//   _евра_, dinä, سقۇچ, _ہٲرت, 
   {{0x8c4847af,0x9c7c01e1,0xa8a40114,0x1e80010a}},	//   tağı, _lóṣò, зрок, _ялсм, 
   {{0x44386947,0xdca07b17,0x9ac0025c,0x2d380092}},	//   xus_, _зати, _ċċer, _የምናየ, 
   {{0xdb00f89e,0x8c48c5d2,0x06300092,0xdc98011a}},	//   ginä, rağı, _በሰውነ, _הסמכ, 
   {{0x4438f89f,0x6a1404d3,0x9f48bd61,0x9b600131}},	//   wus_, _ربار, _cucù_, _سۆيۈ, 
   {{0xdb00f8a0,0x8c48029f,0xa88400db,0x25bc0254}},	//   tinç, pağı, _ىلاى, õul_, 
   {{0xf8ac25a7,0x2bb4033f,0x443809ad,0x998002cb}},	//   _پکي_, ałce_, uus_, _سلوو, 
   {{0xdb00f8a1,0x26c8031c,0x00000000,0x00000000}},	//   rinç, żboq_, --, --, 
   {{0x4438f8a2,0xc778044e,0x9f400241,0x00000000}},	//   sus_, ይኮይኑ_, _tijú_, --, 
   {{0x244402e8,0x6a4803b9,0x00000000,0x00000000}},	//   _ехог, _rəfl, --, --, 
   {{0x4438f8a3,0x9f9c0d27,0x6dac00df,0x6a4806be}},	// [15f70] qus_, _héél_, rŝal, _səfl, 
   {{0x4428f8a4,0x4fd4e99a,0x39900162,0x00000000}},	//   _iva_, ежут, _vási_, --, 
   {{0x4428090b,0x7d0c0077,0x6a4803e3,0x6d440205}},	//   _hva_, ñaso, _qəfl, _ıkar, 
   {{0x7cd8f8a5,0x44280c58,0x7c3803f0,0x0ee801d3}},	//   омер_, _kva_, tuwr, سٹنٹ_, 
   {{0xdb000793,0x2008005a,0x986c00d0,0x5fbc0cf1}},	//   yinä, _utci_, túče_, ्वदल, 
   {{0xdb202be7,0x4428f8a6,0x9f8c00c5,0x9f44023a}},	//   روبی, _mva_, nüü_, önä_, 
   {{0x4428bc4c,0xdb00f8a7,0x95800092,0x00000000}},	//   _lva_, vinä, _ንረቱን_, --, 
   {{0xe45c063f,0x7dd0007c,0x00000000,0x00000000}},	//   kwö_, råss, --, --, 
   {{0xf77017b9,0x4428f8a8,0x7d08f8a9,0xdb0016ca}},	//   ناد_, _nva_, _ifes, tinä, 
   {{0x7c28035a,0x5fbc3599,0x25e03885,0x00000000}},	//   _iver, ्विल, _टीबी_, --, 
   {{0x7c28f8aa,0xdb00f8ab,0xa498067c,0xcb3402e8}},	//   _hver, rinä, scòl, _чехъ, 
   {{0x44281aa1,0x7c28f8ac,0x9f9c0036,0xdb006935}},	//   _bva_, _kver, _déél_, sinä, 
   {{0x89340597,0x5fbc243c,0x7aec012c,0xdb00023a}},	//   _أعما, ्वाल, žitě, pinä, 
   {{0x394c5d7e,0x7c28d78f,0x28e000dc,0x386cf8ad}},	//   lfes_, _mver, _परति, mver_, 
   {{0x4428f8ae,0x7d08f8af,0x0eac02ab,0x7c280175}},	//   _eva_, _ofes, _टेंड, _lver, 
   {{0x386c030d,0x394c55a5,0x442802d2,0x00000000}},	//   over_, nfes_, _fva_, --, 
   {{0x4428f8b0,0x386cf8b1,0x7c28002f,0x7c2c0162}},	// [15f80] _gva_, nver_, _nver, áarl, 
   {{0x7d08f8b2,0x386c0c86,0xdd8c61fa,0x13a803e6}},	//   _afes, iver_, یول_, _رنجی_, 
   {{0xdfcc06d5,0x386c8784,0x7c28f8b3,0x44283b7f}},	//   جيل_, hver_, _aver, _zva_, 
   {{0x4428035b,0x7bc00204,0x7c280e78,0x91dc03d4}},	//   _yva_, _ajlu, _bver, _মূৰ্, 
   {{0xa3e011b1,0x386c0cf9,0x41bc0b98,0x7c2800d7}},	//   _फीड_, jver_, ्करस, _cver, 
   {{0x7c2801a2,0x386c12e8,0x394ca1cd,0xafe4009d}},	//   _dver, dver_, efes_, _цогл, 
   {{0x7c28af02,0x394cf8b4,0x7bc00a40,0x7d080368}},	//   _ever, ffes_, _djlu, _ffes, 
   {{0xdee0f8b5,0xb2fc0003,0x7c280175,0x7d0803b2}},	//   _роси, _དུའང_, _fver, _gfes, 
   {{0x7c28003d,0x26140cb4,0xd83401c6,0x386c16b1}},	//   _gver, _भौजी_, мээ_, gver_, 
   {{0x9f400268,0x2ca4036b,0x442801a9,0x2d84f8b6}},	//   _chjè_, mzod_, _rva_, ljoe_, 
   {{0x386cf8b7,0x7c28f8b8,0x386801fa,0x6a4803b9}},	//   aver_, _zver, _šart_, _məfk, 
   {{0x56906880,0x7c28befd,0xdab443cd,0x9f9c0d27}},	//   тают, _yver, _تهمت_, _véél_, 
   {{0x4428020c,0xb2fc0327,0xf40c0133,0xb76400fb}},	//   _qva_, _དུཡང_, یڤی_, фтөй, 
   {{0x69c00225,0x9f400c95,0x68e001f0,0x44280083}},	//   _hjoe, _ghjè_, _izod, _vva_, 
   {{0x6dac00c8,0x216400cf,0x2d8401bf,0x2ca401b9}},	//   rŝaj, мтаг, kjoe_, hzod_, 
   {{0xd5b80efb,0x4428f8b9,0x2ca401a9,0x7bdc00de}},	//   _осы_, _tva_, kzod_, _īsum, 
   {{0x4428edd9,0x7d0c0227,0x2d84020c,0x00000000}},	// [15f90] _uva_, ñasm, djoe_, --, 
   {{0x7c280522,0x7d08f8ba,0x9c10063f,0xecd0000d}},	//   _rver, _sfes, lọgw, _तड़फ, 
   {{0x7c2833f3,0x7d080084,0x69c000c7,0x00000000}},	//   _sver, _pfes, _ojoe, --, 
   {{0x386cf8bb,0x68e007d6,0x0ca80092,0xabb40124}},	//   yver_, _ozod, _ፋይሎች_, ҭацә, 
   {{0x39901bd1,0xdb00f8bc,0x3b08009b,0x394c0165}},	//   _mást_, minú, пело_, vfes_, 
   {{0x386c1c1d,0x69c0f8bd,0x3f840037,0x7c28025c}},	//   vver_, _ajoe, _õlu_, _vver, 
   {{0x68e0f8be,0x00000000,0x00000000,0x00000000}},	//   _azod, --, --, --, 
   {{0x69c0009a,0x7c28f8bf,0x7d08f8c0,0x4a740228}},	//   _cjoe, _tver, _ufes, тышт, 
   {{0x386c2047,0x7c28f8c1,0x69c0f8c2,0xa3dc2677}},	//   uver_, _uver, _djoe, तता_, 
   {{0xbf1c17cb,0x5dd40150,0x00000000,0x00000000}},	//   _फ़ोन_, _ﺘﻌﻠﻴ, --, --, 
   {{0x69c00b21,0x68e0f8c3,0x386cf8c4,0xc7a800c6}},	//   _fjoe, _ezod, sver_, بديل_, 
   {{0xb8e40d42,0x3990f8c5,0x69c0f8c6,0x386c010a}},	//   _এর_, _pásu_, _gjoe, pver_, 
   {{0x399008a5,0xa2e001d5,0xf79400c0,0x00000000}},	//   _dást_, ғотд, _падэ, --, 
   {{0xf7440261,0x3af005c7,0x272000fe,0x9f8c00a2}},	//   _чеко, _k͡p_, _মাথো_, küñ_, 
   {{0x9f4019f5,0x8658043b,0xa0a0036b,0x399001a8}},	//   _ghjé_, nsɔ́, ҳатд, _fást_, 
   {{0xf1a80344,0xeee40037,0x3d18012d,0x00000000}},	//   سازه_, _करबऽ_, दरों_, --, 
   {{0xc2f01c82,0xd0540198,0x6d980165,0x752401f5}},	// [15fa0] জুলি_, _ɗaɗa, _dïal, makz, 
   {{0x752451ca,0x00000000,0x00000000,0x00000000}},	//   lakz, --, --, --, 
   {{0x7dd00158,0x59cc9d35,0x00000000,0x00000000}},	//   tåsp, हकार, --, --, 
   {{0xde00f8c7,0xeab801c0,0x51781411,0xc0dc0023}},	//   упци, үйд_, _تەرس_, ቒሞም_, 
   {{0x2d840221,0x9ac0025c,0x2604012d,0xb4bc0210}},	//   rjoe_, _ċċar, _सूनी_, _आशो_, 
   {{0x69c0f8c8,0x2d84f8c9,0x2ca401d5,0x68e00210}},	//   _sjoe, sjoe_, rzod_, _rzod, 
   {{0xdee0f8ca,0xfcc8001f,0xada41149,0x2ca401d3}},	//   _бори, _ሽያጭ_, _завл, szod_, 
   {{0x49741180,0x68e00327,0x3868025c,0x2ebc28e0}},	//   тлис, _pzod, _ġarr_, ्थीत, 
   {{0xeaf8f8cb,0x752401c6,0x6bd81374,0xdd8c07d6}},	//   _فرات_, dakz, _فورس_, _اوق_, 
   {{0x999c00da,0xbd04043b,0x39900ad9,0x86980276}},	//   ārši_, _tséé, _sást_, дкос_, 
   {{0xe8f8f8cc,0x7524f8cd,0x69c01a78,0x98ac0166}},	//   _еле_, fakz, _tjoe, _dagı_, 
   {{0x6d40f8ce,0x69c0379d,0xe93802dd,0x6a4803b9}},	//   ngoa, _ujoe, _ءسات_, _nəfi, 
   {{0x58902ab4,0x68e001f0,0x6d400b23,0x19b4008f}},	//   _مجوز, _uzod, igoa, _אפאר_, 
   {{0x63e00131,0x6e3c0857,0x86540408,0x00000000}},	//   ايسە, kupb, _аккх, --, 
   {{0x6d40b171,0x7d0c0227,0x00000000,0x00000000}},	//   kgoa, ñask, --, --, 
   {{0x17800124,0x6d40009b,0x00000000,0x00000000}},	//   _агәм, jgoa, --, --, 
   {{0x6a4803b9,0x200c0de2,0xc0c40116,0x98ac00fd}},	// [15fb0] _dəfi, ëgi_, тәни, _yagı_, 
   {{0x200c0029,0x44380270,0xdb003eba,0xdebc0092}},	//   īgi_, mrs_, sinú, _ቱርክ_, 
   {{0x4fc4f8cf,0x4438f5e4,0x00000000,0x00000000}},	//   уста, lrs_, --, --, 
   {{0x4438f8d0,0x6d40f8d1,0x00000000,0x00000000}},	//   ors_, ggoa, --, --, 
   {{0x44380171,0xdd1000f1,0x00000000,0x00000000}},	//   nrs_, نوڅخ, --, --, 
   {{0x6d4001c0,0x44380dee,0x25e001ad,0x0eac0073}},	//   agoa, irs_, _टीसी_, _टेकड, 
   {{0x44386688,0x98ac0139,0xe7f4012d,0x539c011a}},	//   hrs_, _ragı_, ीदना_, היגו, 
   {{0x443839ae,0xa3e00c2e,0x98ac0139,0x596000d1}},	//   krs_, _फीस_, _sagı_, униғ, 
   {{0x4438f8d2,0x00000000,0x00000000,0x00000000}},	//   jrs_, --, --, --, 
   {{0x93e00c2e,0x4438f8d3,0xb8e80b02,0x10c40150}},	//   _खींच_, drs_, _ईश_, _ﺭﺃﺴﻨ, 
   {{0x70dc07f7,0x869813f3,0x35a4f8d4,0x29000113}},	//   _मर्ल, етят_, ванг, žkaa_, 
   {{0x44380333,0x7d0c02d1,0x00000000,0x00000000}},	//   frs_, ñash, --, --, 
   {{0x9f4001e1,0x7524f8d5,0x6a480213,0x98ac013d}},	//   _jijó_, rakz, _rəfi, _tagı_, 
   {{0x6a4803be,0x752400f3,0x798808c8,0xdb00f5b8}},	//   _səfi, sakz, ljew, ginø, 
   {{0x25e009d9,0x9f400077,0xb6a4f8d6,0x6d402770}},	//   _टीवी_, _lijó_, _шикл, ygoa, 
   {{0x7988f8d7,0x99840153,0x6e3c014f,0x6a480213}},	//   njew, munų_, vupb, _qəfi, 
   {{0x78a8006f,0x9f4001e1,0x56f0009d,0x00000000}},	// [15fc0] nzev, _nijó_, _шүүс, --, 
   {{0xca4400d1,0x00000000,0x00000000,0x00000000}},	//   ﭘﻪﺭ_, --, --, --, 
   {{0xa3cc033f,0x452400cc,0x00000000,0x00000000}},	//   षकर_, _ভাতক_, --, --, 
   {{0x9f4001e1,0x6e3c047e,0xfca80ee8,0xdce400de}},	//   _bijó_, rupb, کامو_, _šlāg, 
   {{0x6d40f8d8,0xdb000221,0x9cc40022,0x00000000}},	//   rgoa, chnë, кыша_, --, 
   {{0x9f4001e1,0x6d400165,0x78a8f8d9,0x9b540107}},	//   _dijó_, sgoa, dzev, вишт_, 
   {{0xa9c4f8da,0x26040490,0xdb00023a,0x6d400076}},	//   ксик, _संधी_, ynnö, pgoa, 
   {{0x4438f8db,0x9f400407,0x798801f5,0x00000000}},	//   yrs_, _fijó_, gjew, --, 
   {{0x6b640022,0xab6400fb,0x00000000,0x00000000}},	//   _икаа, _ивал, --, --, 
   {{0x6ea402c3,0xeee4000d,0x18b40022,0x86d00150}},	//   चनपु, _कराऽ_, тгьы_, _ﺠل_, 
   {{0x443800a9,0xf1e001f9,0x00000000,0x00000000}},	//   wrs_, पतान, --, --, 
   {{0x443800da,0x62800798,0xd614249f,0x7c6401d3}},	//   trs_, _ànoi, کتیا_, _جاہل, 
   {{0x44389083,0x442c0231,0x998400c0,0xfaf400fb}},	//   urs_, ée_, aunų_, _иҫә_, 
   {{0x4438f8dc,0xd49800f5,0x00000000,0x00000000}},	//   rrs_, трю_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7c2cf8dd,0xc0bc4be7,0x4438f8de,0xc7b800f3}},	//   šari, _ዶላር_, prs_, liđ_, 
   {{0xb9ec02d3,0x260400e1,0x00000000,0x00000000}},	// [15fd0] _ሒዛ_, _सूती_, --, --, 
   {{0x6f0c0004,0x656c7e42,0xdcf800df,0x8d74f8df}},	//   _cfbc, ldch, _unuĉ, یانا, 
   {{0xb06000c5,0xdb0c0129,0x656c035a,0xcc880133}},	//   äärn, _àdét, odch, ێنمه_, 
   {{0x656cf8e0,0xecac00fe,0x9f4001e1,0x00000000}},	//   ndch, _ছুইড, _pijó_, --, 
   {{0x644cf8e1,0x656c002f,0x09cc03ce,0x00000000}},	//   ntci, idch, ावैय, --, 
   {{0xdd000bfc,0x644c0175,0x7e740210,0x5fa40118}},	//   ırıl, itci, _trzp, _गतिल, 
   {{0x798801a4,0x2bd800f2,0x00000000,0x00000000}},	//   tjew, راهک_, --, --, 
   {{0xaa54f8e2,0x656c01f5,0x9f400241,0x69cc02d2}},	//   اليا_, jdch, _tijó_, _íbel, 
   {{0x3f9005ce,0x656c01c7,0xb4d00073,0x2b480200}},	//   _kozu_, ddch, _वडे_, çicë_, 
   {{0x78a8f8e3,0x49b804d3,0xa3e00c4c,0x7988f8e4}},	//   rzev, _یاند_, _फील_, sjew, 
   {{0x3f9000d0,0x78a801d3,0x7d0c0784,0x00000000}},	//   _mozu_, szev, ñasw, --, 
   {{0x8aa47863,0xe81c22e3,0xc8b406ce,0x3f90110c}},	//   _труд, _मौका_, الیک, _lozu_, 
   {{0x258400db,0xddc800b8,0x06d400eb,0x00000000}},	//   اچىپ_, _śiśo, হেলি, --, 
   {{0x63a419f5,0x3f905dbf,0x64e457aa,0x6dac010f}},	//   ghjn, _nozu_, ығың_, lŝat, 
   {{0xdb0000c6,0x31bc0118,0xa23400c7,0x00000000}},	//   ghné, hůze_, льтә, --, 
   {{0x7640f8e5,0x216404a9,0xd2e423ef,0x7544023a}},	//   muly, лиси_, _गरीब_, _сниз, 
   {{0x6a4803be,0x7640f8e6,0x15b40075,0x3f90008e}},	// [15fe0] _həft, luly, _مەھس, _bozu_, 
   {{0x3364e20b,0xa3dc09b4,0xe0d4f8e7,0xcee400c7}},	//   _свог, ततः_, уву_, абзқ, 
   {{0x3f90f8e8,0x7640f8e9,0xdee0014b,0x8d28013d}},	//   _dozu_, nuly, бофи, внең_, 
   {{0xad980432,0x6a4803b9,0x3328031c,0xdb00032e}},	//   _guºl, _məft, labx_, ginþ, 
   {{0xccf876b9,0xa3a800af,0xfb1801d3,0x00000000}},	//   тқа_, _खतम_, ھروں_, --, 
   {{0x7640f8ea,0x95040156,0x09ccf8eb,0xe4540bd9}},	//   kuly, _ཚུའི_, ाव्य, ריסט_, 
   {{0x64480793,0xad58f8ec,0xbb700137,0x77600166}},	//   _ägiv, _прах_, تۇلع, delx, 
   {{0x935c044e,0xe94473c7,0x9a80188c,0x2bb4012d}},	//   _ህዝብታ, ухко, сушл, _अगवा, 
   {{0x981019bc,0x628000d8,0xdb00010b,0x00000000}},	//   یبیا, _ànov, liný, --, 
   {{0x3cf000d0,0x57140408,0x764002d0,0x6a4803e3}},	//   ňovú_, лжья_, fuly, _səfu, 
   {{0x7640f8ed,0x58d00952,0x69f0004e,0x00000000}},	//   guly, _қошт, _лүкт, --, 
   {{0x6a480213,0x45d401f4,0xc604009d,0x7ae4002f}},	//   _dəft, ромс, лзүй, ühte, 
   {{0x656cf8ee,0xd87004d3,0x249c09f3,0xe0bc0154}},	//   rdch, _هاوب, áum_, _আর্ন, 
   {{0xa27002d3,0x7640f8ef,0x5344009d,0xdb000432}},	//   _ብልክዕ_, buly, йхса, kiný, 
   {{0x3f90f8f0,0xdb94008f,0x1b78008f,0x6dac0115}},	//   _rozu_, נדלט_, עטלע, nŝas, 
   {{0xdb000122,0x86e401b9,0xcf88024c,0x3f904dd9}},	//   diný, _йўқд, қсуд_, _sozu_, 
   {{0xf5240184,0x798c0086,0x6e440092,0x00000000}},	// [15ff0] _өфөн, _òawe, _ያልገባ, --, 
   {{0x7a100374,0xdec828eb,0x4ea401c6,0x3f9006be}},	//   _hāte, нуел_, өрха, _qozu_, 
   {{0x6264f8f1,0x7a1002b1,0x3f90801c,0x7f44016d}},	//   _صادق, _kāte, _vozu_, rghq, 
   {{0x53146112,0x3f90f8f2,0x2164f8f3,0x7a100b13}},	//   _پذیر, _wozu_, _стог, _jāte, 
   {{0x7a10f8f4,0xda9001c0,0x3f90029f,0xacd400c7}},	//   _māte, өгдө, _tozu_, абцә, 
   {{0xbe6400b2,0x0ed00574,0xe0dc0ca8,0x6a480213}},	//   _پهري, _तुकड, _iyò_, _nəfs, 
   {{0xfaa41875,0x98bc0b4b,0xf990007b,0x2bb4000d}},	//   райо, rguč_, قبة_, _अगरा, 
   {{0x7a1002b5,0x8304025c,0x6280004a,0x6a480213}},	//   _nāte, _ཙུའུ_, _ànou, _rəft, 
   {{0xf09000c8,0x23600bc9,0xe1fc0579,0x0dc80131}},	//   ַנט_, kejj_, _mió_, _сури_, 
   {{0x7640f8f5,0xe8f4f8f6,0xe1fc00cf,0xdb002045}},	//   tuly, шлы_, _lió_, ninü, 
   {{0xf5e80139,0x9a94030d,0x00000000,0x00000000}},	//   кмол_, _сăнл, --, --, 
   {{0x349407dd,0x7640f8f7,0x6dac00df,0xe0dc0241}},	//   ҳаҭр, ruly, lŝar, _oyò_, 
   {{0x76404e8e,0xe0dc010e,0x3328025c,0x74740092}},	//   suly, _nyò_, tabx_, _ሊያጋጥ, 
   {{0x7640f8f8,0x6dac0115,0xdb00f8f9,0x6a4803e3}},	//   puly, nŝar, minó, _təft, 
   {{0xe0dc0cad,0x2324f8fa,0x3668f8fb,0x35a40354}},	//   _ayò_, роси_, _райо_, _вайг, 
   {{0xe1fc00db,0x00000000,0x00000000,0x00000000}},	//   _ció_, --, --, --, 
  
   {{0x2164e20b,0xdb000793,0x2fd80214,0xe1fcf8fc}},	// [16000] шити_, finü, نورد_, _dió_, 
   {{0x9f802897,0xfbc400ec,0x91c4013d,0x00000000}},	//   огуд, _رڪ_, рәүл, --, 
   {{0xe8e01d8a,0x3eac03f9,0xa498067c,0x61f800e8}},	//   _पर्च, _ƙeta_, scòt, ňula, 
   {{0xe1fc0016,0xdb00f8fd,0xed340166,0xada400d8}},	//   _gió_, kinó, рэжэ, јадл, 
   {{0x6b64036b,0xdb000793,0x00000000,0x00000000}},	//   икда, binü, --, --, 
   {{0x9f4008e5,0x649805d0,0x1be47577,0x3170010b}},	//   _ghjà_, כסנד, адчи_, ldyz_, 
   {{0x6280004a,0xa498642b,0x29003c49,0x6a4806be}},	//   _ànot, ncòr, žkam_, _rəfs, 
   {{0x29000579,0x99d00597,0x7d0c0054,0xec14afbd}},	//   øka_, يتيا, ñast, _نورد, 
   {{0xdb00f8fe,0xf81401d5,0x7c2c03b2,0x19b000db}},	//   ginó, یسیگ, áart, تحوج, 
   {{0x473461ff,0xa638001f,0x00000000,0x00000000}},	//   щнос, _በተወሰ, --, --, 
   {{0x7a1004fe,0xd90c0262,0x3f78008f,0x45d400cf}},	//   _pāte, _мь_, אָרע, йоос, 
   {{0xe4a4f8ff,0x87e80220,0xa2b400cd,0x00000000}},	//   арго, _өлең_, ोपस्, --, 
   {{0xe1fc0789,0xdb00f900,0xe4e402bf,0x6a480213}},	//   _rió_, cinó, рінн, _təfs, 
   {{0x7a100053,0x9f4405d1,0x3d0c0241,0x00000000}},	//   _wāte, önü_, _kówó_, --, 
   {{0xe5c400c9,0xe1fc0113,0x7a101da6,0x57200150}},	//   _вспо, _pió_, _tāte, _بىىك, 
   {{0x61400aaf,0x200c0120,0x3d0c0248,0xa4240395}},	//   تىرە, ígio_, _mówó_, _кьол, 
   {{0x88d800bd,0x7f5805f5,0xe1fc0407,0x3d0c0ca8}},	// [16010] দেরক, лаас_, _vió_, _lówó_, 
   {{0xc0f802d3,0xbc1802dd,0x00000000,0x00000000}},	//   _ገይረ_, ңілі_, --, --, 
   {{0xe1fc00cf,0xdcf82e31,0xaad4000d,0x8f080022}},	//   _tió_, _vnuč, _ढुलक, рхуа_, 
   {{0xc0f02440,0x3d280345,0x00000000,0x00000000}},	//   ቃውሞ_, اتای_, --, --, 
   {{0x8d741fd6,0x6dac01e4,0x00000000,0x00000000}},	//   تالا, tŝar, --, --, 
   {{0xdcf807f5,0x3d0c01e1,0xdb000798,0x628000d8}},	//   _unuč, _bówó_, vinó, _ànos, 
   {{0xc0f8044e,0x6dac01e4,0xdb000210,0x00000000}},	//   _ገይሩ_, rŝar, winó, --, 
   {{0xdb00f901,0x39580162,0x00000000,0x00000000}},	//   ginò, ýss_, --, --, 
   {{0x3774329e,0xbcfc00b8,0x00000000,0x00000000}},	//   бынс, _paũu, --, --, 
   {{0x7c2c01fa,0x3d0c0248,0xf7440640,0xdd9002dd}},	//   šars, _fówó_, љено, _уағы, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb0000db,0x6a4806be,0x00000000,0x00000000}},	//   cinò, _təfr, --, --, 
   {{0x7ae07328,0xdb000113,0x18b018c7,0x3ce4012d}},	//   _hylt, linñ, _фәйр, _औरों_, 
   {{0xa018008c,0x7ae037e9,0xc0e80092,0x00000000}},	//   _kröf, _kylt, ሚክስ_, --, 
   {{0x61ec05be,0x1db40034,0x628801e1,0x00000000}},	//   _bhcl, _आगंत, _ńgor, --, 
   {{0xb4b874d7,0x25a800a3,0xc8080051,0x00000000}},	//   _ماخذ_, chcl_, _mởn_, --, 
   {{0x61ec01ab,0xa498381a,0xefc801c6,0xc8080051}},	// [16020] _dhcl, scòr, глал_, _lởn_, 
   {{0xdb000309,0xe8086c5a,0x00000000,0x00000000}},	//   kinñ, _हंसा_, --, --, 
   {{0xee38f902,0x60cc25e6,0x644800ee,0xdb00007b}},	//   уне_, _excm, _ägir, ghní, 
   {{0xac84f4e3,0x3d0c0248,0xabc00150,0x00000000}},	//   йгел, _rówó_, _ﺩﻳﻘﺎ, --, 
   {{0x32000204,0xa5d8010f,0x69cc02d2,0xe58400ef}},	//   _iiky_, אַגי, _íbei, _čeļā, 
   {{0x7ae001a8,0x00000000,0x00000000,0x00000000}},	//   _bylt, --, --, --, 
   {{0x6e94f903,0x3200f4bb,0xdb0002fb,0xed587f52}},	//   _الزا, _kiky_, chní, _йов_, 
   {{0x4814f904,0x19a41388,0xa01808a5,0x7c2c025c}},	//   омис, йтып_, _dröf, ġarr, 
   {{0xa0180730,0xaa8400a2,0x257c415b,0x00000000}},	//   _eröf, _boýü, _lälä_, --, 
   {{0x7ae0f905,0xc300015b,0x613c01e1,0xdb00067c}},	//   _fylt, ্রতি_, _kàlà, sinò, 
   {{0x7ae00174,0xa01808a5,0x00000000,0x00000000}},	//   _gylt, _gröf, --, --, 
   {{0x320002f0,0x00000000,0x00000000,0x00000000}},	//   _niky_, --, --, --, 
   {{0x2904096b,0x88941a92,0x613cb7b4,0x9ac00327}},	//   _igoa_, _филх, _làlà, _ċċir, 
   {{0x68e02beb,0x7a101da6,0xe4a40364,0x32000109}},	//   _iyod, _hāta, арҳо, _aiky_, 
   {{0x7a100325,0xd7c404d3,0xa018f906,0x320000d7}},	//   _kāta, _دووه_, _krög, _biky_, 
   {{0x7a100882,0x67280008,0x257c010e,0xbf2001ad}},	//   _jāta, _hefj, _dälä_, यर्न_, 
   {{0x7a10f907,0x3200f908,0x00000000,0x00000000}},	// [16030] _māta, _diky_, --, --, 
   {{0x613c0248,0xdb0000c6,0x66080009,0x7a100055}},	//   _bàlà, thní, _kufk, _lāta, 
   {{0x32000204,0x66082630,0x00000000,0x00000000}},	//   _fiky_, _jufk, --, --, 
   {{0x68e0014b,0x29040208,0x7a1025fa,0x00000000}},	//   _oyod, _ngoa_, _nāta, --, 
   {{0x2128092e,0x7ae00ac8,0x68e0f909,0x66080fa4}},	//   _iech_, _sylt, _nyod, _lufk, 
   {{0x2128f90a,0x2904f90b,0xed4c121e,0x7ae005e4}},	//   _hech_, _agoa_, ٹھہ_, _pylt, 
   {{0x7a1001ab,0xdcf800b0,0x68e0f90c,0x539c008f}},	//   _bāta, _pouē, _ayod, ריוו, 
   {{0x2000ebf1,0x200805a1,0x68e0007f,0x2128047e}},	//   _hiji_, _kuci_, _byod, _jech_, 
   {{0x212804d1,0x6728002d,0x66080730,0x9f44001e}},	//   _mech_, _befj, _aufk, _điên_, 
   {{0x2000f90d,0x6d4807c4,0x200816a3,0x68e002e2}},	//   _jiji_, ılaş, _muci_, _dyod, 
   {{0xcb08f90e,0x68e00912,0x2000f90f,0x0b883298}},	//   _ايمن_, _eyod, _miji_, _усти_, 
   {{0x212801f1,0x2000208d,0x6728cdd3,0x68e06064}},	//   _nech_, _liji_, _eefj, _fyod, 
   {{0xe72cf910,0x20080276,0x257c0166,0x00000000}},	//   _ое_, _nuci_, _sälä_, --, 
   {{0x6728000f,0x32000083,0xc1dc0150,0xb8640451}},	//   _gefj, _siky_, _ءﻟﯘﭘ, _هاڻو, 
   {{0x2128f911,0x320000e4,0xe2944961,0xa4985b80}},	//   _bech_, _piky_, оар_, scòp, 
   {{0x2008002e,0x21280210,0x00000000,0x00000000}},	//   _buci_, _cech_, --, --, 
   {{0x2128f912,0x200047d8,0x200887d3,0xaf34f913}},	// [16040] _dech_, _biji_, _cuci_, قرات, 
   {{0x2008f914,0x200008ad,0x21280221,0x3200002d}},	//   _duci_, _ciji_, _eech_, _wiky_, 
   {{0x21280204,0x20000100,0x2fd800b5,0xa3e0023e}},	//   _fech_, _diji_, ropg_, _फीट_, 
   {{0xa018049f,0x7d0c5d55,0xec78074d,0x2008f915}},	//   _bröd, ñasp, ипе_, _fuci_, 
   {{0x7a100325,0x2000f916,0x2008f917,0xe0dc0100}},	//   _rāta, _fiji_, _guci_, _obòy_, 
   {{0x2000f918,0x68e0037e,0x2128f919,0x613c0241}},	//   _giji_, _ryod, _zech_, _tàlà, 
   {{0xada4f91a,0x6da4f91b,0x7a10f91c,0x68e00004}},	//   _давл, _дива, _pāta, _syod, 
   {{0x2128f91d,0x200800e8,0xa0180267,0x9f40005b}},	//   _xech_, _yuci_, _fröd, _ehjä_, 
   {{0x5ac4151e,0x7640017a,0xa0185b00,0x99d01fb8}},	//   йләм_, erly, _gröd, بتوا, 
   {{0x7a100374,0x20000009,0x7c64a39b,0x00000000}},	//   _wāta, _xiji_, _عاقل, --, 
   {{0x7a10f91e,0x7aec0c09,0xa0180267,0x66080009}},	//   _tāta, ƙata, _trög, _qufk, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd6cc2be7,0x68e001f0,0x76409ff5,0x7a1000de}},	//   _یقه_, _uyod, arly, _jātn, 
   {{0x212804d1,0x25a81410,0x00000000,0x00000000}},	//   _sech_, ادگي_, --, --, 
   {{0x2128f91f,0xf6f400db,0x00000000,0x00000000}},	//   _pech_, _ىزىگ, --, --, 
   {{0x2008083a,0x20000502,0x21280978,0xc808004d}},	//   _puci_, _siji_, _qech_, _lởm_, 
   {{0x2000dd10,0x1b000154,0xa6c400f1,0x00000000}},	// [16050] _piji_, রুপে_, _دوژل_, --, 
   {{0x4428f920,0x2128b173,0xdb000112,0x22500051}},	//   _iwa_, _wech_, minö, _tqxk_, 
   {{0x4428f921,0x2000f922,0x20080198,0x2128f923}},	//   _hwa_, _viji_, _wuci_, _tech_, 
   {{0x4428f924,0x21280ba1,0x200004fb,0xd2580276}},	//   _kwa_, _uech_, _wiji_, _ьць_, 
   {{0x4428f925,0x2a7c0048,0x0c2400d6,0x800800dd}},	//   _jwa_, _artb_, дмін, _درجہ_, 
   {{0x4428f926,0xb0980302,0xeb94f927,0x8afcf928}},	//   _mwa_, _הישר, зиш_, _obęd, 
   {{0x4428f929,0x260400e1,0xc8080208,0xdb0001f4}},	//   _lwa_, _संगी_, _dởm_, hinö, 
   {{0x4428f92a,0xdb00f92b,0x3dcc0327,0xa0180112}},	//   _owa_, ghná, _ujew_, _tröd, 
   {{0x4428f92c,0xa3d80c2e,0x2c5c00e2,0xadf40075}},	//   _nwa_, ़वा_, gādā_, _хотә, 
   {{0x7c28f92d,0x8de80156,0x9c1002e3,0xad9800a2}},	//   _iwer, _འཚོལ, họkw, _duºu, 
   {{0x7d0800fb,0x7c28f92e,0xe72c04d3,0x8f9c0a7c}},	//   _kges, _hwer, اڵه_, ייזי, 
   {{0x7c28f92f,0x7a1000b0,0x46e800f7,0xe5300022}},	//   _kwer, _hāto, өдөн_, неџь, 
   {{0x442807ab,0x7a10f930,0x27f415b4,0xa6e00174}},	//   _cwa_, _kāto, تفید_, øðru, 
   {{0x4428f931,0xf770f932,0x394cf933,0x7c28f934}},	//   _dwa_, _سات_, lges_, _mwer, 
   {{0x4428f935,0x7a101f4c,0x386cf936,0x66e0026a}},	//   _ewa_, _māto, lwer_, _поша, 
   {{0x7d082935,0x44288e75,0x7c28f937,0x394cf938}},	//   _nges, _fwa_, _ower, nges_, 
   {{0x7c2844fc,0x4428f939,0x9088001f,0x394cf93a}},	// [16060] _nwer, _gwa_, _አዘጋጅ_, iges_, 
   {{0xe45404ac,0x7d08f93b,0x7a100418,0x79980548}},	//   _צייט_, _ages, _nāto, _loww, 
   {{0xdfcc530d,0x44280dc9,0x7c28013b,0x386c0730}},	//   ديل_, _zwa_, _awer, hwer_, 
   {{0x7c28f93c,0x24680020,0x44280066,0xdd8c5085}},	//   _bwer, ሳሰሉት_, _ywa_, ُول_, 
   {{0x442802b9,0x7d080036,0x394c279e,0x7c280142}},	//   _xwa_, _dges, dges_, _cwer, 
   {{0x7d08f93d,0x7c28f93e,0xd1f0001f,0x394c17da}},	//   _eges, _dwer, ቂዎች_, eges_, 
   {{0x7c28f93f,0x2b5c1509,0xf4080589,0x89d81375}},	//   _ewer, _vbtc_, ndãº_, يوتر_, 
   {{0x394cf940,0x7d080083,0x386c05b1,0x9f44007c}},	//   gges_, _gges, fwer_, önö_, 
   {{0x7c28f941,0x79980ea0,0x8a78013e,0xcd38001f}},	//   _gwer, _doww, сиқӣ_, _አምናለ, 
   {{0x44280537,0x2c5c00da,0x5ba40276,0x799802d0}},	//   _rwa_, rādā_, _екум_, _eoww, 
   {{0x4428f942,0x45d40a16,0x31b40882,0x7c28f943}},	//   _swa_, донс, ṣṭha_, _zwer, 
   {{0x4428f944,0x47d400b2,0x386c0c67,0x79980a55}},	//   _pwa_, _ڪيتر, bwer_, _goww, 
   {{0x4428f945,0x387000c7,0x1864f946,0x94840139}},	//   _qwa_, _ақыт, _наци_, нырд, 
   {{0x44280bd1,0x77ac0077,0xdb0001b8,0x799800a2}},	//   _vwa_, _púxe, rinö, _zoww, 
   {{0xd6ccaecb,0xecdc00c5,0x6b983402,0xdb000f23}},	//   _чт_, _फुसफ, _motg, sinö, 
   {{0x4428f947,0x6b980373,0xdb000108,0x461400e5}},	//   _twa_, _lotg, pinö, _ٹوکر, 
   {{0x9c1002e3,0x4394a975,0x00000000,0x00000000}},	// [16070] rọkw, _жапс, --, --, 
   {{0x6b980ccc,0xdef802f6,0x7c28f948,0x1ea80451}},	//   _notg, бые_, _rwer, ٽائي_, 
   {{0x7a101243,0xa018f178,0x00000000,0x00000000}},	//   _rāto, _bröc, --, --, 
   {{0x7c28f949,0x386c05e4,0x00000000,0x00000000}},	//   _pwer, ywer_, --, --, 
   {{0x7a1002b1,0x6b98f94a,0x79980ea0,0x3b080120}},	//   _pāto, _botg, _roww, оело_, 
   {{0xbd0401e1,0x6b9807c5,0x79980694,0x9258b4a9}},	//   _apéé, _cotg, _soww, _بشیر_, 
   {{0x394cf94b,0x386c04c4,0x7d080c86,0x7c280036}},	//   tges_, wwer_, _tges, _wwer, 
   {{0x7c28013b,0x394cf94c,0x7d08f94d,0x64401d77}},	//   _twer, uges_, _uges, _ānin, 
   {{0x7a101f4c,0x386cd3e1,0x7c28f94e,0x6b98713c}},	//   _tāto, uwer_, _uwer, _fotg, 
   {{0x7998f94f,0x87b8656c,0x394cf950,0x386cf951}},	//   _woww, зуют_, sges_, rwer_, 
   {{0x0f5825f9,0x386c0c3e,0x394c3672,0xba5452d1}},	//   ליזם_, swer_, pges_, _цвеј, 
   {{0x386c079b,0x80dc00af,0x6b9801a9,0x00000000}},	//   pwer_, _मडूं, _zotg, --, 
   {{0x6b98036b,0x7a1000b8,0x093402f2,0xdb00000d}},	//   _yotg, _mātm, _سرنج, rinõ, 
   {{0x28c800dc,0xdef001f3,0xdb00000d,0x1608012d}},	//   ापरि, ግሩን_, sinõ, _सूअर_, 
   {{0xe7941547,0xa2e0f952,0x00000000,0x00000000}},	//   _تانک, ворд, --, --, 
   {{0x25b4027d,0xf8e00073,0x7a1000cd,0x00000000}},	//   _يهود_, _पडाय, _nātm, --, 
   {{0x300433e0,0x00000000,0x00000000,0x00000000}},	// [16080] дзаг, --, --, --, 
   {{0xdfcc530d,0x249c03fa,0x63a40051,0xb3d0000d}},	//   ليق_, äume_, ckjn, _सदिख, 
   {{0x6b98f953,0xefb007d6,0x1b000154,0x00000000}},	//   _rotg, _ییرگ, রুতে_, --, 
   {{0x7a1000dc,0x6b98f954,0x6ce401ec,0x7d0c02f0}},	//   _cātm, _sotg, міле, žasn, 
   {{0x6b980926,0x25fcd04e,0x00000000,0x00000000}},	//   _potg, रगती_, --, --, 
   {{0x9f4c025a,0x6b9816a5,0xdca00063,0x7f740153}},	//   êgô_, _qotg, ђаји, _пусц, 
   {{0x5f005183,0xe468032e,0xdb2001d3,0x00000000}},	//   _азра, _kvöð_, úráj, --, 
   {{0xc8080208,0x9a8035e3,0x28a400d4,0x00000000}},	//   _hởi_, тушл, дшог, --, 
   {{0x6b98f955,0xd1f8001f,0x2900007c,0x00000000}},	//   _totg, _ገጽታ_, äka_, --, 
   {{0x260405f9,0xab60237e,0x00000000,0x00000000}},	//   _सूजी_, _شۇعى, --, --, 
   {{0x9f40026c,0xae0c4c19,0x6a4806be,0xc8080051}},	//   _chjù_, िदिन_, _ləfz, _mởi_, 
   {{0xa96839c6,0xc8080051,0x00000000,0x00000000}},	//   _фида_, _lởi_, --, --, 
   {{0x04c8131e,0x26c00210,0xa85001ee,0x00000000}},	//   سوسي_, ńko_, _релә, --, 
   {{0x29000006,0xae0c07af,0x00000000,0x00000000}},	//   žkas_, िदान_, --, --, 
   {{0x26d8006a,0x9f4019f5,0xc2c436ac,0xdb002305}},	//   _âpo_, _ghjù_, ريري, chnä, 
   {{0x260437f3,0x8bbc5325,0x00000000,0x00000000}},	//   _सूची_, ्चुअ, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [16090] --, --, --, --, 
   {{0xc80801dc,0xa05c02d3,0x4438f956,0x2004f957}},	//   _bởi_, _ህይወቶ, mss_, öni_, 
   {{0x4438f958,0xc808001e,0x00000000,0x00000000}},	//   lss_, _cởi_, --, --, 
   {{0x44380221,0x3cd43f6e,0xfcd40131,0x00000000}},	//   oss_, нжес, ىياج, --, 
   {{0x4438f959,0xe05400aa,0xc1040691,0x0204004e}},	//   nss_, _زیات_, _سوسي, _озүн, 
   {{0xec1003e6,0x00000000,0x00000000,0x00000000}},	//   دوود, --, --, --, 
   {{0xc80807ae,0x80e0009e,0xbed40063,0xf7cc02dd}},	//   _gởi_, পেশ্, _човј, _ﮔﯘﻟﺪ, 
   {{0x4438f95a,0xe7a40135,0x1fbc00c5,0x69cc0055}},	//   kss_, _ħeġġ, _एगुड, _āneñ, 
   {{0xf7709dc7,0x44380286,0x00000000,0x00000000}},	//   هاد_, jss_, --, --, 
   {{0x44380004,0xf6242063,0x06c000eb,0x00000000}},	//   dss_, ндоо, _উড়ি, --, 
   {{0x64a0e538,0x4438f95b,0x7bc04fe7,0x75f4012c}},	//   қара, ess_, _imlu, háze, 
   {{0x75f40118,0xecdc00bc,0x443802d2,0x00000000}},	//   káze, _फुँफ, fss_, --, 
   {{0xb60401e1,0xf7440276,0x49b80150,0x7c38017a}},	//   _akáá, _зело, _تالد_, nswr, 
   {{0x28980a1e,0x4cd400eb,0x00000000,0x00000000}},	//   _מינא, _তরমু, --, --, 
   {{0x4438f95c,0x6d440086,0x7bc0f95d,0x00000000}},	//   ass_, _ôkag, _mmlu, --, 
   {{0x15e80d0a,0x7c3802d0,0x50640150,0x443800ef}},	//   _टीचर_, kswr, кебұ, bss_, 
   {{0xa06448c8,0x4438010a,0x25d4008f,0x7bc000bc}},	// [160a0] ната_, css_, _רופן_, _omlu, 
   {{0xdd9002dd,0x00000000,0x00000000,0x00000000}},	//   ғашы, --, --, --, 
   {{0x6da4f95e,0x71a400d8,0x63b800e8,0x3f1c0241}},	//   нижа, _занз, ëune, _ọrùn_, 
   {{0x7bc0209c,0xe2940138,0x42500133,0x62180677}},	//   _amlu, _чаю_, _خۆفر, _מוטק, 
   {{0xa0a06135,0xa01808a5,0x7c3802d0,0x00000000}},	//   _баяд, _hrön, gswr, --, 
   {{0xa018049f,0xa0280003,0x7984016b,0x7a100055}},	//   _krön, _སྦྲང_, _ɔhwe, _kāth, 
   {{0x4438003e,0x644000b8,0x00000000,0x00000000}},	//   zss_, _ānim, --, --, 
   {{0x4438f95f,0xdee0412c,0x7bc0e044,0x75f401ed}},	//   yss_, _соси, _emlu, házb, 
   {{0x61e00998,0x7c380334,0x3958068c,0xac840166}},	//   _ínle, cswr, òssa_, _ягал, 
   {{0x67e401a8,0x2ca401d5,0x00000000,0x00000000}},	//   yðju, myod_, --, --, 
   {{0xa9240fbe,0xbbe801d5,0x9f4806af,0xcd500092}},	//   _здел, _آرقم_, ûlée_, _የምንፈ, 
   {{0x7bc001a2,0xd6d46feb,0xa684009d,0x06c8009d}},	//   _zmlu, эты_, _үлдд, згүй_, 
   {{0x443804c4,0x2ca4f960,0x7bc00042,0x00000000}},	//   uss_, nyod_, _ymlu, --, 
   {{0x4438b7fb,0x27440241,0x75f400bc,0xa01808a5}},	//   rss_, _dínà_, váze, _brön, 
   {{0x81c809bd,0x7a10002b,0xf200012d,0x00000000}},	//   _লীগ_, _cāth, लगढ़_, --, 
   {{0xe1f0004e,0xa018c9df,0x7c380142,0x00000000}},	//   اسس_, _drön, yswr, --, 
   {{0x656cf961,0xdecc02d3,0x9f683da1,0x00000000}},	// [160b0] mech, ኣይን_, зрез_, --, 
   {{0x656cf962,0x644cf963,0x75f40316,0xa0189628}},	//   lech, muci, ráze, _frön, 
   {{0xa01804f3,0x69c00165,0x7a1000dc,0x50c80166}},	//   _grön, _omoe, _gāth, _җыям_, 
   {{0x656cf964,0xdb000227,0x7bc0012c,0x2eec05d5}},	//   nech, wknï, _smlu, üffa_, 
   {{0x798c0428,0x7a100055,0xc0c401af,0x00000000}},	//   _òawi, _tātk, _рәви, --, 
   {{0x656cf965,0x69c0f966,0xb96401e1,0x200c0115}},	//   hech, _amoe, _orìí, ŭgis_, 
   {{0x644cf967,0x7a100b10,0xdeec10de,0xd90cf968}},	//   huci, _kāti, _اۋا_, میا_, 
   {{0x644c6580,0x7a107204,0x656cf969,0x4a74678d}},	//   kuci, _jāti, jech, уышт, 
   {{0x644c1505,0x7a10c73a,0x00000000,0x00000000}},	//   juci, _māti, --, --, 
   {{0x7bc0f96a,0x69c0f96b,0x644cf96c,0xe85007d6}},	//   _umlu, _emoe, duci, گنید, 
   {{0x656cf96d,0xb7840184,0x00000000,0x00000000}},	//   fech, еҙҙе_, --, --, 
   {{0x656c7635,0x644c026c,0x7a10002b,0x00000000}},	//   gech, fuci, _nāti, --, 
   {{0xd76001d3,0xddc40171,0x7a100055,0xf868009f}},	//   _منشی, _apjū, _sāth, _آمتي_, 
   {{0x43740228,0x026003e6,0x7a10002b,0x00000000}},	//   луст, ڕێپێ, _pāth, --, 
   {{0xf1a83028,0x656cf96e,0x00000000,0x00000000}},	//   واره_, bech, --, --, 
   {{0x656cf96f,0x2164f970,0x7a10002b,0x2ca431c5}},	//   cech, киси_, _cāti, yyod_, 
   {{0x644c4c25,0xa0a001b9,0xb63801ec,0xdb0001e7}},	// [160c0] cuci, аатд, _ﭘﻪ_, ghnú, 
   {{0xc61000c5,0xa018f971,0x7a1000b8,0x00000000}},	//   _ठूँठ_, _trön, _tāth, --, 
   {{0xed58f972,0xee38f973,0xdb000419,0x00000000}},	//   дое_, фне_, ahnú, --, 
   {{0x71a45e7f,0xdee00107,0x00000000,0x00000000}},	//   _рамз, шохи, --, --, 
   {{0xdb0082e3,0xc1d40304,0xdd8c009a,0x1d040395}},	//   chnú, _сөрә, غوه_, веци_, 
   {{0xbc2404a9,0x656c006d,0x2ca4f974,0x69c001a4}},	//   ارنى, zech, ryod_, _smoe, 
   {{0x656cf975,0x644c0034,0x7a1000b8,0xad58009b}},	//   yech, zuci, _yāti, _орах_, 
   {{0x4974617b,0x656c056a,0x8fd401ee,0x00000000}},	//   улис, xech, _рәғә, --, 
   {{0x656cf976,0x6b54a19b,0x7c64f977,0x6bd80133}},	//   vech, _атех, _مالل, _قورس_, 
   {{0x656cf978,0x644cf979,0xeaf87cf6,0x00000000}},	//   wech, vuci, _قرات_, --, 
   {{0x644cf97a,0x69f02cc8,0x00000000,0x00000000}},	//   wuci, _күкт, --, --, 
   {{0x6844f97b,0xa018049f,0x69c0014b,0x7c2c0311}},	//   _анда, _bröl, _umoe, ţare, 
   {{0x656cf97c,0x7a103a2f,0xddc40153,0x00000000}},	//   rech, _rāti, _spjū, --, 
   {{0x656cf97d,0xa4f00490,0x534401c0,0xc7b001d3}},	//   sech, _घरीच_, ихса, _چڑھ_, 
   {{0x5334f97e,0x656cf97f,0x644cf980,0x7a10f981}},	//   рест, pech, suci, _pāti, 
   {{0xa018f982,0x656c0309,0x15b400d1,0x11d4007b}},	//   _fröl, qech, _نەپس, لتقد, 
   {{0x7e980722,0xc2100014,0x7a10002b,0x80f40395}},	// [160d0] کنار_, _گٔج_, _vāti, упах, 
   {{0x7a1000b0,0xdec83756,0x29180139,0xdb00dd18}},	//   _wāti, муел_, _şpal_, rhnú, 
   {{0xe45c049b,0x75f47009,0x00000000,0x00000000}},	//   ltö_, láza, --, --, 
   {{0xbd448073,0x00000000,0x00000000,0x00000000}},	//   انشي, --, --, --, 
   {{0xe45c023a,0xd0180022,0xbb4400d8,0x00000000}},	//   ntö_, _афс_, гелк, --, 
   {{0x69cc0ca8,0x00000000,0x00000000,0x00000000}},	//   _ìbej, --, --, --, 
   {{0x7a680323,0xac040046,0xce946128,0x75f401ed}},	//   хийг_, ынша_, _каръ, háza, 
   {{0x75f403c6,0x77ac056a,0x8d8400cf,0x00000000}},	//   káza, _púxo, _кууд, --, 
   {{0x35a40c60,0x64c001e4,0xb7e4010b,0x9b9000ec}},	//   ҳанг, nʈiĝ, лжик, _پهاڙ, 
   {{0x7e680022,0x1b00013d,0x9ba000d1,0x6c6800e5}},	//   _ņepy, _күлн, _خەتى, _سلمہ_, 
   {{0x35a47122,0x00000000,0x00000000,0x00000000}},	//   ганг, --, --, --, 
   {{0xd2f803e6,0xa018002f,0x38540395,0x75440022}},	//   ێکدا_, _pröl, _бъкс, ынмз, 
   {{0x7a100055,0xa0185804,0xbcfc002b,0x00000000}},	//   _cātv, _bröm, _paũy, --, 
   {{0x78a8f983,0x00000000,0x00000000,0x00000000}},	//   myev, --, --, --, 
   {{0xa01804f3,0x78a806be,0x00000000,0x00000000}},	//   _dröm, lyev, --, --, 
   {{0x41b401f0,0xa01801a8,0x75f400d7,0x00000000}},	//   асут, _tröl, báza, --, 
   {{0x78a8f984,0x75f409c2,0xa52000ee,0xa018f985}},	// [160e0] nyev, cáza, _умыд, _fröm, 
   {{0x7534f986,0x64940375,0xb4c007af,0x7a1025fa}},	//   _heyz, _עדיף_, ्पी_, _hātu, 
   {{0x7a10f987,0x7e6004cc,0xc8f01db2,0x00000000}},	//   _kātu, _älpl, _चर्म_, --, 
   {{0x517800db,0x7a100a2f,0x00000000,0x00000000}},	//   _جەرس_, _jātu, --, --, 
   {{0x7a10f988,0x75340129,0x78a8014f,0x6cc40f15}},	//   _mātu, _meyz, jyev, ыйда, 
   {{0xc6240154,0x9b4001d9,0x9b540107,0xce300354}},	//   _ভিসা_, ٕنوو, гишт_, _могι, 
   {{0x2ba80ce0,0x9fc400ee,0xb4c00b4c,0x160401ad}},	//   _कवठा, _ёгса_, ्पु_, रगार_, 
   {{0x6e3c0ea0,0xe45c005b,0xbaa40131,0x75340205}},	//   mspb, ytö_, рушқ, _neyz, 
   {{0xd834152d,0x8c980451,0xaa9001b9,0x5f1800cd}},	//   лээ_, _جھاز_, риқч, _बलम्_, 
   {{0x98b412c1,0x47340b95,0x75f400bc,0x18b400c7}},	//   ульт_, шнос, váza, угьы_, 
   {{0x17f400c6,0x75340342,0x17640209,0xc564010b}},	//   درية_, _beyz, урып_, ңкүк, 
   {{0xe9d8f989,0xe45c049b,0xa01801e6,0x62800077}},	//   _яке_, ttö_, _dröj, _ánoi, 
   {{0x7534083a,0x7a1000cd,0x6aa80142,0xa0180205}},	//   _deyz, _dātu, lyff, _pröm, 
   {{0xa0180267,0x75f41a74,0x00000000,0x00000000}},	//   _fröj, ráza, --, --, 
   {{0x6738f98a,0x7a100618,0xe45c049b,0x171800c8}},	//   matj, _fātu, stö_, _אווע, 
   {{0x6738af18,0xd1c801c0,0x5ebc009e,0x75f41ab0}},	//   latj, гууд_, ্থমে, lázn, 
   {{0xe7d41c82,0x644002b1,0x6aa87e1a,0x00000000}},	// [160f0] হতীয, _āniw, hyff, --, 
   {{0x6738f98b,0xe0dc180f,0xa01808a5,0x00000000}},	//   natj, _adòc_, _hrök, --, 
   {{0x65ac1682,0xa018553f,0x7a10002b,0x00000000}},	//   ṱhup, _krök, _yātu, --, 
   {{0x657c0bc9,0x6738f98c,0xbc387611,0xd654011a}},	//   _jaqh, hatj, نستا_, ריאת_, 
   {{0x6738f98d,0x657cf98e,0xf364004e,0x55bc011a}},	//   katj, _maqh, _стөн, עמדו, 
   {{0xfaa4f98f,0x657cf990,0x6738f991,0xba74007b}},	//   иало, _laqh, jatj, لابت, 
   {{0x3f900516,0xc0dc02d3,0x6aa8015d,0x245c0142}},	//   _inzu_, ሒዞም_, gyff, hîm_, 
   {{0x9f4019f5,0x645c0194,0x78a800dc,0x657c014f}},	//   _ghjò_, _oqqi, tyev, _naqh, 
   {{0x7534030a,0x20180472,0x6738003e,0x00000000}},	//   _reyz, nqqi_, fatj, --, 
   {{0x6738f992,0x3f800502,0x3894043b,0xf09002e4}},	//   gatj, ndhu_, nɛrɛ_, קני_, 
   {{0x645c3209,0x657c0912,0x7534f993,0x78a800dc}},	//   _aqqi, _baqh, _peyz, syev, 
   {{0xf5043acc,0xd34807d6,0x753406be,0x00000000}},	//   изно, گیده_, _qeyz, --, 
   {{0x6738f994,0x657c014f,0xb4c0a06f,0x21380083}},	//   batj, _daqh, ्पे_, daqh_, 
   {{0x67382959,0xf770f995,0xa01801e6,0xd3483e66}},	//   catj, _ذات_, _tröj, دیده_, 
   {{0x645c0eda,0x3f80f996,0x753405d1,0xa018ee18}},	//   _eqqi, ddhu_, _teyz, _frök, 
   {{0x3124f997,0x3f90f998,0xa01801f4,0x00000000}},	//   рдаг, _anzu_, _kröh, --, 
   {{0x4908d9e5,0x310829dc,0x64a01188,0x00000000}},	// [16100] ाइयो_, тнап_, _маъа, --, 
   {{0xee0c1b57,0xa064f999,0x657c0921,0x7c3c0158}},	//   िद्ध_, рафа_, _zaqh, _åsry, 
   {{0x657c1269,0x75f43af6,0x2eecf8c6,0x7a10002b}},	//   _yaqh, názo, æff_, _māts, 
   {{0x3f80198f,0x673804d7,0xdcf8008e,0x75f42358}},	//   adhu_, zatj, _aluı, zázn, 
   {{0x27200316,0xeb9852db,0xccf821f3,0x3f804e40}},	//   nční_, кид_, уқа_, bdhu_, 
   {{0x7fb400c0,0x00000000,0x00000000,0x00000000}},	//   _лёсі, --, --, --, 
   {{0x2d94f99a,0x6738f99b,0x75f402f0,0x00000000}},	//   _крас, vatj, vázn, --, 
   {{0x3868084c,0x2720012c,0x67380af2,0x6aa8771b}},	//   _ţara_, kční_, watj, ryff, 
   {{0x6738f99c,0x62800077,0x1d040120,0xb4c000cd}},	//   tatj, _ánov, _вети_, ्पो_, 
   {{0x07b806d5,0x657c379d,0xaa44f99d,0x75f40518}},	//   اهدة_, _saqh, _вежл, fázo, 
   {{0x6738f99e,0x657c014f,0x9f440129,0x75f4f99f}},	//   ratj, _paqh, ôné_, rázn, 
   {{0x6738f9a0,0xa01803fa,0xdce8005f,0x657c0455}},	//   satj, _fröh, legā, _qaqh, 
   {{0x5454023a,0x6738f9a1,0x3f800009,0xa01839fa}},	//   овят, patj, ydhu_, _gröh, 
   {{0x67382784,0x657c1449,0x53341318,0x7a10002b}},	//   qatj, _waqh, жерт, _tātt, 
   {{0x272000bc,0xa6a800db,0xd7f8011a,0x00000000}},	//   ační_, _جاشق_, _שהול, --, 
   {{0xd25000f1,0x00000000,0x00000000,0x00000000}},	//   ګنې_, --, --, --, 
   {{0x7a100171,0x00000000,0x00000000,0x00000000}},	// [16110] _jātr, --, --, --, 
   {{0x7a100882,0x5f2401d5,0x00000000,0x00000000}},	//   _mātr, рфаз, --, --, 
   {{0x3f80f9a2,0x41b4f9a3,0x61e00048,0xdce800ef}},	//   rdhu_, _همدر, _ínlo, degā, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7a103a71,0xcfc400cc,0x4d4801ec,0xbc6800ec}},	//   _nātr, ্তজন, рпін_, امتن_, 
   {{0x644c03d5,0x00000000,0x00000000,0x00000000}},	//   irci, --, --, --, 
   {{0xe1fc07ae,0xa0180c86,0xf990007b,0x7a1000de}},	//   _khó_, _bsög, كبة_, _rāts, 
   {{0x52d8008f,0xdb000419,0x00000000,0x00000000}},	//   יווע_, chný, --, --, 
   {{0x0dc8f9a4,0xe1fc007b,0x7a1000dc,0x00000000}},	//   _тури_, _mhó_, _cātr, --, 
   {{0xdcf80006,0x7a10002b,0x00000000,0x00000000}},	//   _jauč, _dātr, --, --, 
   {{0x644cf9a5,0x7a1000cd,0xda6c009f,0x00000000}},	//   erci, _vāts, _آڏت_, --, 
   {{0xe1fcf9a6,0x75f4f9a7,0xdcf80064,0x00000000}},	//   _nhó_, rázo, _lauč, --, 
   {{0x6ecc2314,0x00000000,0x00000000,0x00000000}},	//   _धेनु, --, --, --, 
   {{0xe1fcf9a8,0x2720012c,0x7a10002b,0xd34801d5}},	//   _ahó_, rční_, _gātr, گیگه_, 
   {{0x644cf9a9,0x35a47314,0x2324f9aa,0x97c401d9}},	//   arci, _гайг, соси_, _مژھٕ_, 
   {{0xe1fc001e,0xd3480ec9,0x27200118,0x00000000}},	//   _chó_, دیگه_, pční_, --, 
   {{0xe1fc00c6,0x764001a8,0x25b40214,0x97000131}},	// [16120] _dhó_, lsly, _دهيد_, _دېگى, 
   {{0x63800022,0xd37002dd,0xa6e003b2,0x00000000}},	//   _егьа, _تۇس_, øðgu, --, 
   {{0xdd8c5311,0xa06476b9,0x7640f9ab,0xe1fc0332}},	//   کون_, _қара_, nsly, _fhó_, 
   {{0x395c0198,0xed14015b,0x76400042,0x2ba8000d}},	//   _ncws_, ার্স_, isly, _कवहा, 
   {{0xfd9801e0,0xfca800f1,0x2bc898e0,0x2d9003e0}},	//   шөрә_, ټانو_, луко_, ıye_, 
   {{0x3218f9ac,0x6fb4bfba,0xdcf8f9ad,0x09d00073}},	//   _kupy_, _امسا, _gauč, तच्य, 
   {{0x395c01ee,0x37cc00bd,0x7a100882,0xdb00f9ae}},	//   _bcws_, রকার, _rātr, dhnó, 
   {{0x7640072b,0xdcf802f0,0x7a100055,0xec140244}},	//   dsly, _zauč, _sātr, _هورد, 
   {{0xab28f9af,0x387c0175,0x321805d6,0x30f800dc}},	//   _боза_, _cswr_, _lupy_, ्धिः_, 
   {{0x2fc81505,0xdb00007b,0x6be400cf,0x764002d2}},	//   _jmbg_, ghnó, _اكئم, fsly, 
   {{0x2b5c03a2,0xdcf80171,0x98ac00b8,0x7a100055}},	//   _ictc_, _bluķ, _vegā_, _vātr, 
   {{0xd6d47724,0x30f800dc,0x644c0113,0xa3a80401}},	//   сть_, ्धाः_, trci, कॉन_, 
   {{0xe4e4f9b0,0xf8ac004b,0xdb0001e7,0x2c1803d4}},	//   сінн, _ټکي_, bhnó, নীৰে_, 
   {{0x2d88013b,0x764001bf,0xdce8054e,0xdb0000ae}},	//   _ɔbea_, bsly, legă, chnó, 
   {{0xe1fc0016,0x6624007b,0x00000000,0x00000000}},	//   _phó_, _ارتك, --, --, 
   {{0xdcf84beb,0x168404d3,0x270c0213,0x62840165}},	//   _sauč, _داهێ, mən_, rvjo, 
   {{0x270c11a9,0xe1fc0943,0xdcf816a3,0x00000000}},	// [16130] lən_, _vhó_, _pauč, --, 
   {{0x4428f9b1,0x100402e8,0x00000000,0x00000000}},	//   _ita_, пяхм, --, --, 
   {{0x270c03be,0xdcf82220,0xe1fc0051,0x02600244}},	//   nən_, _vauč, _thó_, _تێزێ, 
   {{0x4428f9b2,0x0094013d,0x00000000,0x00000000}},	//   _kta_, _димэ, --, --, 
   {{0x4428020b,0x2b5cf9b3,0x3218012d,0xdcf80064}},	//   _jta_, _bctc_, _zupy_, _tauč, 
   {{0x270c03be,0x62800077,0x395c058a,0x4428f9b4}},	//   kən_, _ános, _scws_, _mta_, 
   {{0x4428f9b5,0xb16c0008,0x2a7c0129,0x4ea4f9b6}},	//   _lta_, _þýði, _cstb_, _ерта, 
   {{0x270c11a9,0x76405522,0xd2b8011a,0x00000000}},	//   dən_, vsly, מלות_, --, 
   {{0x44280537,0x960405f5,0xa0180267,0x7e64045a}},	//   _nta_, үүлж, _eröv, lthp, 
   {{0x2cb02c95,0xe7a40075,0x6e28020c,0xa3a802a0}},	//   øyde_, يۇنى_, _èmbè, कॉम_, 
   {{0x2a7c070d,0x36680261,0xa0180267,0x7640127b}},	//   _gstb_, шано_, _gröv, usly, 
   {{0x7c2802f8,0x8aa45b0f,0x960406ab,0x44283e9d}},	//   _kter, _эруд, रगेट_, _bta_, 
   {{0x4428f9b7,0xf7440faa,0x764033e4,0x18b00cef}},	//   _cta_, _дело, ssly, _хәйр, 
   {{0x7c28c53d,0x270c0213,0x00000000,0x00000000}},	//   _mter, bən_, --, --, 
   {{0x4428f9b8,0x62800306,0x270c0213,0xe7fc17cb}},	//   _eta_, _šnor, cən_, _उठता_, 
   {{0x7c28f9b9,0x2fc805b1,0xb5c800f2,0x00000000}},	//   _oter, _smbg_, _خوبم_, --, 
   {{0x7c28f9ba,0x2084224f,0xdcf801e4,0x44285f5c}},	// [16140] _nter, ойти_, _kluĵ, _gta_, 
   {{0x68f403d4,0x75f4012c,0xe0dc0100,0xa4400139}},	//   _øyde, kázk, _idòl_, _юньд, 
   {{0x7c28f9bb,0xdfcc0f54,0x71a4009d,0xdcec00b8}},	//   _ater, خيل_, _данз, _ādāt, 
   {{0x4428f9bc,0x7c2828b5,0x00000000,0x00000000}},	//   _yta_, _bter, --, --, 
   {{0xdca07b68,0x7c2807ab,0x270c03be,0x2a7c0327}},	//   маци, _cter, zən_, _sstb_, 
   {{0x270c0cc1,0xa018049f,0x7c280165,0x8a181d0f}},	//   yən_, _pröv, _dter, бокс_, 
   {{0x7c28f9bd,0x6d98030d,0x5e54014b,0x00000000}},	//   _eter, _къар_, _миёя_, --, 
   {{0x29885c9e,0x7c28829c,0x270c0213,0x2868004e}},	//   рско_, _fter, vən_, ароо_, 
   {{0xdcf8010f,0x7c28062c,0xeb98f9be,0x00000000}},	//   _bluĵ, _gter, _киа_, --, 
   {{0x4428f9bf,0x261800b0,0x270c03be,0x2d8401f5}},	//   _rta_, _hīoi_, tən_, ldoe_, 
   {{0x7a1000cd,0x00000000,0x00000000,0x00000000}},	//   _tātp, --, --, --, 
   {{0x270c0cc1,0xdcf804fe,0x2d84f9c0,0xe5c402bf}},	//   rən_, _hauā, ndoe_, існо, 
   {{0x270c0cc1,0x7c280327,0x44280263,0xdcf800b0}},	//   sən_, _xter, _qta_, _kauā, 
   {{0x98a00640,0x2d84852a,0x270c06be,0x00000000}},	//   _циље, hdoe_, pən_, --, 
   {{0xdcf83b28,0x580000db,0x611801e1,0x00000000}},	//   _mauā, _تووك, _ǹlá, --, 
   {{0x44280429,0x00000000,0x00000000,0x00000000}},	//   _tta_, --, --, --, 
   {{0x4428f9c1,0x60d8107d,0x00000000,0x00000000}},	// [16150] _uta_, _žumb, --, --, 
   {{0x2d8401e4,0x00000000,0x00000000,0x00000000}},	//   edoe_, --, --, --, 
   {{0xdb04f9c2,0x7e6402d0,0x00000000,0x00000000}},	//   ülün, uthp, --, --, 
   {{0x7c28f9c3,0xa018f9c4,0x7e640afa,0xdbd4005b}},	//   _pter, _bröt, rthp, näös, 
   {{0x50642e3f,0xa01804cc,0x24882852,0x00000000}},	//   _отра, _cröt, nvcm_, --, 
   {{0x7c289903,0xfbc406a6,0x75f402f0,0xdb000419}},	//   _vter, ябло, tázk, mknú, 
   {{0x4fc4525b,0x00000000,0x00000000,0x00000000}},	//   _تەلە, --, --, --, 
   {{0x75f403c6,0x7c28f9c5,0x2d84007f,0xa018007c}},	//   rázk, _tter, cdoe_, _fröt, 
   {{0x7c28f9c6,0xdcf80421,0x564402d3,0xcdc800f7}},	//   _uter, _fauā, _መተካእ, _بۇنۇ_, 
   {{0x36c4f9c7,0x00000000,0x00000000,0x00000000}},	//   због, --, --, --, 
   {{0x68e0f9c8,0x391401e0,0xf5e8020a,0x2c0801d3}},	//   _exod, _емер, ймол_, _اٹلی_, 
   {{0x232401f0,0x00000000,0x00000000,0x00000000}},	//   ҷори_, --, --, --, 
   {{0x888021f7,0x20000ffb,0x62800010,0x29141095}},	//   _ағыл, _ohji_, _šnop, _عقود_, 
   {{0x2324f9c9,0x00000000,0x00000000,0x00000000}},	//   зори_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x07080451,0xf1a80244,0xdb0002d2,0x00000000}},	//   _بيٺي_, حاسه_, fknú, --, 
   {{0xaf34f9ca,0x92ac015b,0x2f48f9cb,0x00000000}},	// [16160] كرات, কছে_, йпап_, --, 
   {{0x09b403d4,0x9f80014b,0x2744007b,0x00000000}},	//   জোপা, нгуд, míní_, --, 
   {{0xa018049f,0x274400c6,0x261800b0,0x2e14007b}},	//   _brös, líní_, _pīoi_, سباح, 
   {{0xed581b74,0xdcf80607,0xe80002ab,0x00000000}},	//   сод_, _sauā, _रीना_, --, 
   {{0x2d8400d8,0xa01808a5,0xdbb80116,0x2744007b}},	//   rdoe_, _drös, әтчә_, níní_, 
   {{0x20000ffb,0x6fd800fe,0x00000000,0x00000000}},	//   _ghji_, _বীৰে, --, --, 
   {{0xdee0152d,0xa01826bc,0x274400ae,0x68e006be}},	//   _зори, _frös, híní_, _sxod, 
   {{0xa018363f,0x4974f9cc,0x4908012c,0x32480240}},	//   _tröt, флис, ाइलो_, _ዝኾንኩ, 
   {{0x6d4004c9,0x1b18015b,0xdcf80374,0x6ca401b9}},	//   maoa, _নজরে_, _tauā, _عصرل, 
   {{0x6d40f9cd,0x65bc036e,0x274401e7,0xd82c01c6}},	//   laoa, _mëhe, díní_, _үэ_, 
   {{0xcc8403e6,0xc4d800eb,0x00000000,0x00000000}},	//   _رۆژه_, _সরেজ, --, --, 
   {{0x6d40f9ce,0x1a9800c8,0x7bdc0162,0xf96800d4}},	//   naoa, _ליבע, _ísur, _мрій_, 
   {{0x27440332,0x00000000,0x00000000,0x00000000}},	//   gíní_, --, --, --, 
   {{0x6d40f9cf,0xa0180267,0x7664005b,0x7c2c01e4}},	//   haoa, _orör, ötyö, ŭarg, 
   {{0x6d40f9d0,0xd37800d6,0x418400fb,0x00000000}},	//   kaoa, ччя_, мтағ, --, 
   {{0x65bc069c,0xdb0000d0,0x2744f9d1,0xd6d8011a}},	//   _bëhe, tknú, bíní_, _לחול, 
   {{0x6d4001c4,0xf1c407c1,0x274400ae,0xded80092}},	// [16170] daoa, रोइन, cíní_, ኔውን_, 
   {{0x3dcc0076,0x14d8010f,0x75f437b5,0x92bc03d4}},	//   _smew_, _מוחל_, vázi, _আখৰ_, 
   {{0xdb0020ab,0x00000000,0x00000000,0x00000000}},	//   sknú, --, --, --, 
   {{0x6d400618,0xdb0406af,0x81d401c0,0x00000000}},	//   gaoa, _émér, _цомх, --, 
   {{0x0c24f9d2,0xa0180112,0x8e0800d4,0xe1f8276a}},	//   емін, _erör, їнів_, ्षीण_, 
   {{0xeb941575,0x69dcf9d3,0x00000000,0x00000000}},	//   диш_, épen, --, --, 
   {{0xa0185df7,0x7a6801c6,0x26c001e4,0xbe64009f}},	//   _trös, цийг_, ŝkoj_, _تهزي, 
   {{0xddc4002d,0x75f40798,0x98bc0327,0x38280114}},	//   _tsjű, pázi, nfuħ_, ожио_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9ba015bf,0xf62460a1,0xdb00032e,0x00000000}},	//   _سەبى, мдоо, dhnö, --, 
   {{0x6d58054e,0x00000000,0x00000000,0x00000000}},	//   şcaţ, --, --, --, 
   {{0x2744007b,0xe80001ad,0xf87400ae,0x00000000}},	//   tíní_, _रीठा_, _يهاج, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf1c40ce0,0x274400ae,0x00000000,0x00000000}},	//   रोईन, ríní_, --, --, 
   {{0xb5c8bd87,0x274400ae,0x26c803b2,0x00000000}},	//   _ووتم_, síní_, úbot_, --, 
   {{0x7988f9d4,0x60d81674,0x65bc02b1,0x2744007b}},	//   ndew, _žuma, _pëhe, píní_, 
   {{0xa064f9d5,0xa7c4926f,0x6d4005da,0x249c0e78}},	// [16180] мата_, _رژیم_, vaoa, äumt_, 
   {{0xe4540bd9,0x7988020c,0xa6c00254,0x00000000}},	//   _קייט_, hdew, _ööül, --, 
   {{0x79880a73,0x63a00295,0x6d40f9d6,0x00000000}},	//   kdew, _ònna, taoa, --, 
   {{0x65bc02b1,0x3158007b,0x00000000,0x00000000}},	//   _tëhe, _بجدة_, --, --, 
   {{0x7988f9d7,0x9d40010b,0xe7fc01f9,0x00000000}},	//   ddew, течд, _उठला_, --, 
   {{0x6d40f9d8,0x798801c7,0xdca00114,0x60d808a5}},	//   saoa, edew, таљи, _þuma, 
   {{0x6d400421,0xcdc421f3,0x00000000,0x00000000}},	//   paoa, _завқ, --, --, 
   {{0xa018f119,0x00000000,0x00000000,0x00000000}},	//   _kröp, --, --, --, 
   {{0x48141955,0xac840724,0xab641d5b,0x7aecc6da}},	//   нмис, _югал, _овал, ğata, 
   {{0xa098008f,0x79880810,0x7aec2737,0x00000000}},	//   קייט, adew, şata, --, 
   {{0x6b98f9d9,0x79880327,0xdce800c0,0x75f400e5}},	//   _intg, bdew, degę, házu, 
   {{0xd6d400c0,0x00000000,0x00000000,0x00000000}},	//   ьты_, --, --, --, 
   {{0x18a00022,0x442c017a,0xe784004e,0x00000000}},	//   _иацм, ëe_, _жуйо, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd6ccf9da,0xe1f096d3,0x67280327,0xadec2982}},	//   _рт_, نسر_, _iffj, जवान_, 
   {{0x7c2c0356,0xdb0003b2,0xe8000456,0xe1f800cd}},	//   ţari, rknø, _रीता_, ्षेण_, 
   {{0xc3c40323,0x6b982a28,0xd0d400a7,0x00000000}},	// [16190] _зөвл, _ontg, вотъ, --, 
   {{0x656c00b5,0x3ff400be,0x00000000,0x00000000}},	//   lfch, ركار, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6b98f9db,0xa018007c,0x7d2402c9,0x00000000}},	//   _antg, _fröp, رفتن, --, 
   {{0x7e740175,0x672802d2,0x8d74f9dc,0x00000000}},	//   _wpzp, _offj, ئاما, --, 
   {{0xf7880120,0x63a40175,0x79880009,0x75f400e5}},	//   _maçã_, njjn, wdew, lázt, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6b98f9dd,0x6728005c,0x7f44f9de,0x00000000}},	//   _entg, _affj, lahq, --, 
   {{0x79884011,0xf744f9df,0xdb800aac,0x00000000}},	//   rdew, непо, _аҳли, --, 
   {{0x87b8005b,0x1b0000fe,0x00000000,0x00000000}},	//   дуют_, ৰুষে_, --, --, 
   {{0x656c02c1,0x27e000d5,0x55c4190b,0x38c80244}},	//   ffch, ékna_, ванғ, تاژی_, 
   {{0x6728035a,0x3d1c033f,0x00000000,0x00000000}},	//   _effj, _फलों_, --, --, 
   {{0xa2e00b01,0xf9802cdd,0xdce80064,0x00000000}},	//   ҳорд, _аҳқо, rdgė, --, 
   {{0x4374ee8b,0xa3a806ab,0x7f44014f,0x00000000}},	//   куст, कॉल_, jahq, --, 
   {{0xe294e9b5,0x42d4187f,0x00000000,0x00000000}},	//   нар_, віту, --, --, 
   {{0x2c1800fe,0xa80006be,0x75f400e5,0x00000000}},	//   নীয়ে_, _şıxo, gázt, --, 
   {{0x2f54f9e0,0x98bc01a6,0xc0580212,0x7b6c02dd}},	// [161a0] етес, kauč_, діє_, _ﺴﺤﺎﺏ_, 
   {{0x0478f9e1,0x1f60f9e2,0x63b8003a,0x00000000}},	//   _کلیک_, лкум, ëunt, --, 
   {{0x63000014,0x63ac054e,0x75f400e5,0x00000000}},	//   _موٝل, ţinâ, bázt, --, 
   {{0xa018f9e3,0xf1d022fd,0x715858e5,0x00000000}},	//   _tröp, _сөгө, _эрос_, --, 
   {{0x7f440477,0xbaac00cc,0x69dc03df,0x00000000}},	//   bahq, _কেলছ, épem, --, 
   {{0x888403e6,0x65bc036e,0x00000000,0x00000000}},	//   ێیان, _mëha, --, --, 
   {{0x6b88074d,0x00000000,0x00000000,0x00000000}},	//   rdfg, --, --, --, 
   {{0x6b884a1f,0xc5f800da,0x7a10002b,0x77901888}},	//   sdfg, ntēt_, _kāty, یینا, 
   {{0x29003402,0x3be800fd,0xc808004b,0x7a1000dc}},	//   åka_, яләү_, وښته_, _jāty, 
   {{0x6b9807de,0x7a10002b,0xdb0006ea,0x92bc00cc}},	//   _untg, _māty, lkný, _আখৈ_, 
   {{0x290002fb,0x00000000,0x00000000,0x00000000}},	//   ťka_, --, --, --, 
   {{0x45d4390e,0x00000000,0x00000000,0x00000000}},	//   томс, --, --, --, 
   {{0x6d440086,0xa85001e0,0xdb0401d3,0x656c324c}},	//   _ôkau, _селә, ülön, rfch, 
   {{0x47d405d9,0xc2c43bd7,0xf1dc0118,0x00000000}},	//   _جيتر, پيري, _नआउन, --, 
   {{0x656c0e78,0x4908012c,0x1718010f,0x00000000}},	//   pfch, ाइको_, _צוהע, --, 
   {{0x637001d3,0x00000000,0x00000000,0x00000000}},	//   _bűnü, --, --, --, 
   {{0x7a10002b,0x7f440477,0x75f400e5,0x00000000}},	// [161b0] _cāty, tahq, rázt, --, 
   {{0x2a70033f,0x4394283c,0x00000000,0x00000000}},	//   łyby_, _раос, --, --, 
   {{0x88d4015b,0x00000000,0x00000000,0x00000000}},	//   _হুমক, --, --, --, 
   {{0xca540131,0x410400d1,0xdbd401c7,0x7f44014f}},	//   _ﺋﯚﺯ_, _үзүв, päës, sahq, 
   {{0x7f440784,0xb6041427,0xecb001e0,0x00000000}},	//   pahq, _hjáá, аҡты, --, 
   {{0xb91000b8,0x7f440455,0xacb000d1,0x00000000}},	//   _graṃ_, qahq, شمىغ, --, 
   {{0xf99000c6,0xc5f8406a,0x59cc00cd,0x00000000}},	//   لبة_, ntēs_, तोऽर, --, 
   {{0xdcf801a6,0xca74129e,0x7a1000b8,0x80d4000d}},	//   _nauć, انيک, _yāty, _धधाइ, 
   {{0x75f401d3,0xae0000d1,0x2ba807b7,0x18180c22}},	//   zázs, _ئۈنى, _कवचा, नदेव_, 
   {{0xdbdc0ca8,0x00000000,0x00000000,0x00000000}},	//   _kìín, --, --, --, 
   {{0x7bc0f9e4,0x888401c6,0x00000000,0x00000000}},	//   _illu, влөж, --, --, 
   {{0x5284059f,0x00000000,0x00000000,0x00000000}},	//   ҳҳоб, --, --, --, 
   {{0xe800012d,0x644808a5,0x00000000,0x00000000}},	//   _रीवा_, _ægil, --, --, 
   {{0x386c11ad,0x0904177b,0x95b40116,0x00000000}},	//   mter_, _спін, _әркә, --, 
   {{0x232422ff,0xe794136e,0x7a1000cd,0x00000000}},	//   тоси_, _جانک, _sāty, --, 
   {{0x75f401ed,0x386cf9e5,0x7a1000b8,0x00000000}},	//   rázs, oter_, _pāty, --, 
   {{0x386cf9e6,0x7bc00664,0xc5f8005f,0x6020f9e7}},	// [161c0] nter_, _ollu, rtēt_, идта, 
   {{0x386cf9e8,0xc5f800e2,0xad2401b9,0x7a100055}},	//   iter_, stēt_, چرشو, _vāty, 
   {{0x386cf9e9,0x75f45e45,0x69dc01d3,0x26c001e4}},	//   hter_, lázq, épek, ŝkov_, 
   {{0x386c3d7a,0xe2941fdf,0x00000000,0x00000000}},	//   kter_, _раю_, --, --, 
   {{0x386c538a,0x5d5002dd,0xc1040451,0x00000000}},	//   jter_, ркіт, _موٽي, --, 
   {{0x7d0c0209,0x386c67c4,0x00000000,0x00000000}},	//   ýasa, dter_, --, --, 
   {{0xe9e41b8c,0xc95400b8,0x386c0d63,0xee381cb8}},	//   кцио, _amīṣ, eter_, _іна_, 
   {{0x7bc0f9ea,0x7c2c01e4,0xdee0010a,0x00000000}},	//   _ellu, ŭara, _тоси, --, 
   {{0x386cf9eb,0x7bc0036e,0xdd8cf9ec,0xd8347c3f}},	//   gter_, _fllu, _بوق_, кээ_, 
   {{0x57b035c7,0x7aec0098,0x7bc00200,0x47340024}},	//   ибыт, énté, _gllu, ынос, 
   {{0x386cf9ed,0x1f5804ae,0x97a000ee,0x00000000}},	//   ater_, ודיא, ррыл, --, 
   {{0x386cf9ee,0x06c805f5,0xa90802dd,0x00000000}},	//   bter_, дгүй_, _قيال_, --, 
   {{0x386cf9ef,0x7bc0045f,0xe4e4753d,0x5834109a}},	//   cter_, _yllu, тінн, _азія_, 
   {{0x69c0f9f0,0x290405da,0x660c02d0,0x00000000}},	//   _hloe, _izoa_, smck, --, 
   {{0x26041b6d,0x69c004c4,0x2164807e,0xe5c4035b}},	//   _ичиг, _kloe, ктаг, _аспо, 
   {{0xc5f800e2,0x607c0092,0x00000000,0x00000000}},	//   rtēs_, _ሥርጭት_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [161d0] --, --, --, --, 
   {{0x69c000a9,0xa01801b8,0xa28048dc,0xfe7001d9}},	//   _lloe, _isök, _پیرو, ٝگر_, 
   {{0x29040109,0x386cf9f1,0x81d4009d,0x92e000cc}},	//   _lzoa_, zter_, _бонх, _তৰী_, 
   {{0x386c0445,0xdb0003fa,0x6294025c,0x98bc02b5}},	//   yter_, rknü, _irxo, hauā_, 
   {{0x386cf9f2,0xc0c40131,0x7bc0036e,0x00000000}},	//   xter_, _сәви, _pllu, --, 
   {{0x69c0f9f3,0x7aecf9f4,0x3b080c17,0xb3440166}},	//   _aloe, şatm, нело_, _imçä, 
   {{0x69c0f9f5,0x386cf9f6,0x7bc0003a,0x3f800108}},	//   _bloe, wter_, _vllu, mehu_, 
   {{0x3f80123c,0x69c0f9f7,0xfbd000e1,0xff040116}},	//   lehu_, _cloe, तफहम, _аяғн, 
   {{0x386c2047,0x09280131,0x00000000,0x00000000}},	//   uter_, خسىي_, --, --, 
   {{0x3f80f9f8,0x7bc00af5,0x6294008e,0x00000000}},	//   nehu_, _ullu, _orxo, --, 
   {{0x69c0f9f9,0xdb0003b2,0x00000000,0x00000000}},	//   _floe, rknó, --, --, 
   {{0x69c0f9fa,0x386cf9fb,0x6008509e,0x3f800023}},	//   _gloe, pter_, lümd, hehu_, 
   {{0xe294e09c,0x3a247890,0xa01800dd,0x3f800374}},	//   қат_, _hulp_, _csök, kehu_, 
   {{0xf744f9fc,0x3f80f9fd,0x3a24f9fe,0xd34801b9}},	//   _секо, jehu_, _kulp_, خیده_, 
   {{0x3f80013f,0x00000000,0x00000000,0x00000000}},	//   dehu_, --, --, --, 
   {{0xaec40220,0xe1f40166,0xf1a8032f,0xe3b00137}},	//   ңбал, ггс_, رازه_, _ۇرپ_, 
   {{0xa0a025a1,0x60080209,0x3f801132,0xda180037}},	// [161e0] батд, kümd, fehu_, _पूछत_, 
   {{0x728815ed,0x6008010e,0x00000000,0x00000000}},	//   _због_, jümd, --, --, 
   {{0xee38074d,0xa01801b8,0x00000000,0x00000000}},	//   хне_, _opöf, --, --, 
   {{0x6ce4311f,0xece80835,0x00000000,0x00000000}},	//   ліле, ндел_, --, --, 
   {{0x3f800134,0xc1d400d1,0x6538008f,0x00000000}},	//   behu_, _төрә, גענד, --, 
   {{0x69c085db,0xa8a401b9,0x2ca401a9,0x00000000}},	//   _sloe, ғрик, rxod_, --, 
   {{0x69c0f9ff,0x3a24fa00,0xed5800d6,0xfe4404fb}},	//   _ploe, _culp_, _пов_, _نکنی, 
   {{0x8fd40184,0x00000000,0x00000000,0x00000000}},	//   _сәғә, --, --, --, 
   {{0x69c07890,0x98bc02b5,0x60080790,0x00000000}},	//   _vloe, tauā_, bümd, --, 
   {{0x2bf402d5,0xae000131,0xb6a40208,0x60080166}},	//   _сябр, _ئۈچى, _trậ, cümd, 
   {{0x3a24f84a,0x00000000,0x00000000,0x00000000}},	//   _gulp_, --, --, --, 
   {{0x9f5c0008,0xa80400fd,0x00000000,0x00000000}},	//   ðrún_, _өзел, --, --, 
   {{0x2904063f,0x3f80022f,0x60080037,0x00000000}},	//   _uzoa_, yehu_, lüme, --, 
   {{0x7d1c000f,0x78bc05ac,0x052400eb,0x00000000}},	//   _ússe, øsve, পরের_, --, 
   {{0x57f80375,0x7f8407d6,0x53340835,0x9bb4011a}},	//   _רלוו, یلرن, сест, נהלה_, 
   {{0x6008d814,0x11d400c6,0xe79401d3,0x212c01ab}},	//   zümd, متقد, _جاچک, ùgh_, 
   {{0x3f8002b5,0x00000000,0x00000000,0x00000000}},	// [161f0] tehu_, --, --, --, 
   {{0x6008fa01,0x44387d6a,0xd25000aa,0x644c95bb}},	//   küme, mps_, تنې_, msci, 
   {{0x4438fa02,0x3f80fa03,0x644cfa04,0xa29001f7}},	//   lps_, rehu_, lsci, _اُجڙ, 
   {{0x81c00150,0x44388b32,0x80d80210,0x644c0064}},	//   _بەرۇ, ops_, _नेथे, osci, 
   {{0x3f80fa05,0x9e4801ec,0x44380113,0x60084a0f}},	//   pehu_, _اﻳﻤﺎ, nps_, tümd, 
   {{0x443800f7,0x644c1552,0x600801b8,0xd01802e8}},	//   ips_, isci, füme, _бфс_, 
   {{0x6008e2fc,0x3a2406be,0x00000000,0x00000000}},	//   rümd, _qulp_, --, --, 
   {{0x661c0113,0x3a2405d5,0x644c0024,0x6b640240}},	//   _niqk, _vulp_, ksci, ተሓለለ_, 
   {{0x19a829db,0x4c94013e,0x644c033f,0x44380327}},	//   _үтеп_, _литс, jsci, jps_, 
   {{0xe8f45b0f,0x3a24382c,0x7d080c8c,0x7c3803cb}},	//   рль_, _tulp_, _izes, mpwr, 
   {{0x4438fa06,0x35a45258,0x644cfa07,0x0a581291}},	//   eps_, аанг, esci, _مؤنث_, 
   {{0xe614084c,0xf8b800e4,0x00000000,0x00000000}},	//   идэ_, pyũ_, --, --, 
   {{0xe72c1377,0x4438005c,0x28080006,0x661c1f25}},	//   _ме_, gps_, _šunų_, _diqk, 
   {{0x3e50012d,0x72c401ec,0x69dc00e4,0x00000000}},	//   kąt_, қбұз, épev, --, 
   {{0x644cfa08,0x78a81b08,0x6008fa09,0x00000000}},	//   asci, lxev, kümb, --, 
   {{0x7d08014b,0x27200093,0x644c004e,0x00000000}},	//   _ozes, pōní_, bsci, --, 
   {{0x44380810,0x78a80005,0xa6480092,0xfbc40aa2}},	// [16200] cps_, nxev, _መተዳደ, वसाम, 
   {{0xd1bc2295,0x600805d1,0xf36400f7,0x06cc0154}},	//   _ሰዎች_, yüme, _өтүн, _রুটি, 
   {{0x7d08fa0a,0x6d2401f4,0x00000000,0x00000000}},	//   _azes, адез, --, --, 
   {{0xed58fa0b,0x00000000,0x00000000,0x00000000}},	//   тод_, --, --, --, 
   {{0x4c9450d3,0xdd8cfa0c,0x7d08fa0d,0x00000000}},	//   силс, بون_, _czes, --, 
   {{0x7d08fa0e,0xec1400fb,0x6008002f,0x00000000}},	//   _dzes, шелә_, tüme, --, 
   {{0xdee0fa0f,0xa3a802ab,0xda440137,0xbbe800d1}},	//   _дори, कॉट_, ачыл_, ھرۇم_, 
   {{0x443806ea,0x600805d1,0x644cfa10,0x6c340214}},	//   yps_, rüme, ysci, _نفرا, 
   {{0x661c0784,0xe0dcfa11,0x6008fa12,0xfe70004b}},	//   _riqk, _leòn_, süme, _ودې_, 
   {{0x3a0803e6,0xa0180142,0x44380356,0x62840175}},	//   نکۆی_, _bröy, vps_, ywjo, 
   {{0x4438039a,0x9f9402e4,0x29880aac,0x00000000}},	//   wps_, בדיה_, _асло_, --, 
   {{0x4438fa13,0x00000000,0x00000000,0x00000000}},	//   tps_, --, --, --, 
   {{0x644c011c,0x4438fa14,0x3e500034,0x37a80137}},	//   usci, ups_, ząt_, ттөн_, 
   {{0x644cfa15,0xb274fa16,0x00000000,0x00000000}},	//   rsci, әктә, --, --, 
   {{0xd62430ba,0x4438fa17,0x88e800bd,0x00000000}},	//   _које_, sps_, _পরিক, --, 
   {{0x4438fa18,0x644cfa19,0xd138e78a,0x1718011a}},	//   pps_, psci, иху_, _בווע, 
   {{0x2d8003f2,0x00000000,0x00000000,0x00000000}},	// [16210] _ókey_, --, --, --, 
   {{0xa3b8fa1a,0x4428fa1b,0x7d08fa1c,0xa224009f}},	//   _अकि_, _iua_, _rzes, _پرده, 
   {{0x3ed80502,0x4428fa1d,0x4420003e,0x7d08295c}},	//   دواج_, _hua_, _iih_, _szes, 
   {{0x4428fa1e,0x4420fa1f,0xbe240022,0x7c2c01e4}},	//   _kua_, _hih_, _ҳчақ, ŭarm, 
   {{0x4428fa20,0x4420fa21,0x3178008d,0xed4cfa22}},	//   _jua_, _kih_, _גארד, رپو_, 
   {{0x4428fa23,0x4420dfb9,0x7d0800bc,0xd1bc0092}},	//   _mua_, _jih_, _vzes, _ሰዎቹ_, 
   {{0x4428fa24,0x4420138f,0x00000000,0x00000000}},	//   _lua_, _mih_, --, --, 
   {{0x44280924,0x499809fe,0x4420fa25,0x3f90107d}},	//   _oua_, атья_, _lih_, _hazu_, 
   {{0x4428fa26,0x4420123c,0x60d8010e,0x00000000}},	//   _nua_, _oih_, _ýumd, --, 
   {{0xbb2404a2,0x7c28003a,0x4420fa27,0x31ac00d7}},	//   ﻠﺪﻯ_, _iuer, _nih_, _dýzy_, 
   {{0x4428fa28,0x7c28fa29,0x3f90fa2a,0x1da80490}},	//   _aua_, _huer, _mazu_, छापत, 
   {{0x4428fa2b,0x4420fa2c,0xc32825f9,0x7c28fa2d}},	//   _bua_, _aih_, _טו_, _kuer, 
   {{0x4428fa2e,0x4420fa2f,0x7c200a40,0x3f9007f5}},	//   _cua_, _bih_, _kilr, _oazu_, 
   {{0x4428fa30,0x7c28fa31,0xf7700310,0x44200399}},	//   _dua_, _muer, _رات_, _cih_, 
   {{0x4420fa32,0x4428fa33,0x3634db35,0x7c28fa34}},	//   _dih_, _eua_, _ارتس, _luer, 
   {{0x44286b39,0x7c280151,0x442001e4,0x394c06f2}},	//   _fua_, _ouer, _eih_, naes_, 
   {{0x4428fa35,0x4420fa36,0x76440076,0x00000000}},	// [16220] _gua_, _fih_, _çhyb, --, 
   {{0x3f900356,0x00000000,0x00000000,0x00000000}},	//   _cazu_, --, --, --, 
   {{0x7c28fa37,0x3f9009f0,0x4428fa38,0x7e642a1f}},	//   _auer, _dazu_, _zua_, guhp, 
   {{0x237c04b9,0x7c28fa39,0xdb20025a,0x4428fa3a}},	//   đuje_, _buer, _âsêg, _yua_, 
   {{0x3f9005ce,0x7c28fa3b,0x89d80502,0x394c1028}},	//   _fazu_, _cuer, یوتر_, daes_, 
   {{0x7c281859,0x3f90033f,0x29d802b5,0x600803e0}},	//   _duer, _gazu_, tūao_, rümc, 
   {{0x7c28fa3c,0x394cfa3d,0x7c2001a9,0x29400092}},	//   _euer, faes_, _dilr, _የሀይማ, 
   {{0x7c28fa3e,0x3f90d756,0x7c20a4fd,0xf8d800e1}},	//   _fuer, _zazu_, _eilr, _बेहय, 
   {{0xbb2404a9,0x7c200fac,0xece80108,0x3f9000fd}},	//   ﻠﻪﻥ_, _filr, _сдал_, _yazu_, 
   {{0x4428fa3f,0x7c200a73,0x2d840421,0x7d1c0162}},	//   _rua_, _gilr, leoe_, _ússa, 
   {{0x4428fa40,0x7c280730,0x4420fa41,0x81c003d4}},	//   _sua_, _zuer, _rih_, ্চত_, 
   {{0x4428fa42,0x442005ba,0x7c2800a2,0x65a80114}},	//   _pua_, _sih_, _yuer, утог_, 
   {{0x4428fa43,0x4420047e,0xe0dc0192,0xe1900228}},	//   _qua_, _pih_, _ceòl_, үлгө, 
   {{0x4428601a,0x6008fa44,0x4420016d,0x65bc036e}},	//   _vua_, küma, _qih_, _mëhi, 
   {{0x4420fa45,0x2d8406c8,0x44280221,0x3f900034}},	//   _vih_, keoe_, _wua_, _razu_, 
   {{0x4420fa46,0x3f900427,0x2d8400e4,0x563800df}},	//   _wih_, _sazu_, jeoe_, _געהײ, 
   {{0x442008ad,0x4428fa47,0xc3c409a5,0xbfd80212}},	// [16230] _tih_, _uua_, _дөвл, адає_, 
   {{0x7c28fa48,0x600801b8,0x442000d5,0x3f900166}},	//   _ruer, füma, _uih_, _qazu_, 
   {{0x7c28fa49,0xa2440214,0x600803e0,0x2bbcfa4a}},	//   _suer, _دیزل_, güma, ्सना, 
   {{0x7c28fa4b,0x2c70002d,0xac60004d,0x7e64003e}},	//   _puer, fâd_, _đôrê, ruhp, 
   {{0x7c28748d,0x7c200d04,0x394cfa4c,0xe1fc0248}},	//   _quer, _pilr, vaes_, _ikó_, 
   {{0xfaa406a6,0x5274527d,0x3f8401ef,0x00000000}},	//   жако, _بایز, _úlu_, --, 
   {{0x7c287884,0x394c0204,0x63b403cd,0xe1fc01e1}},	//   _wuer, taes_, _moxn, _kkó_, 
   {{0x7c28fa4d,0x7c2001a4,0xaee00150,0x00000000}},	//   _tuer, _wilr, _تۋمى, --, 
   {{0x394cfa4e,0x7c20fa4f,0x2c70015d,0x00000000}},	//   raes_, _tilr, câd_, --, 
   {{0x394c08cd,0x69dc00e5,0x00000000,0x00000000}},	//   saes_, éper, --, --, 
   {{0x6d5c0024,0xe0dc08c2,0x394c525e,0xf5e801c6}},	//   ėpav, _seòl_, paes_, имол_, 
   {{0xe1fc0241,0x00000000,0x00000000,0x00000000}},	//   _nkó_, --, --, --, 
   {{0x63b4fa50,0xf7940006,0x8a1800f1,0x89347f51}},	//   _boxn, _мадэ, _اتلس_, _رعنا, 
   {{0xe1fccc50,0x60080793,0xdb000254,0xdecc1ef7}},	//   _akó_, yüma, sknõ, ጣርን_, 
   {{0x63b40007,0x28100137,0xb668009d,0xe8000210}},	//   _doxn, _تووس, _тийз_, _रीटा_, 
   {{0xca3800df,0xf42801f0,0xb0340116,0x00000000}},	//   _urĝe_, _коил_, قىرغ, --, 
   {{0xf8c82356,0xe1f41fe2,0xaa6402d3,0x2bbc00cd}},	// [16240] िनिय, ігу_, _ዘይሕጋ, ्समा, 
   {{0xe1fc0241,0x65bc02b5,0xb92800c7,0x28240092}},	//   _ekó_, _rëhi, _petỹ_, _ሰባኪያ, 
   {{0xae880cb5,0x2c700042,0x00000000,0x00000000}},	//   рбез_, wâd_, --, --, 
   {{0x2c7000a9,0x6008fa51,0x51780131,0xf8c821b8}},	//   tâd_, rüma, _دەرس_, िनाय, 
   {{0x600804cc,0x00000000,0x00000000,0x00000000}},	//   süma, --, --, --, 
   {{0x290001b8,0x2ac40063,0x64980a7c,0x00000000}},	//   ükam_, жљив, יסנד, --, 
   {{0x2c706729,0x2b4c0327,0x6e940244,0x00000000}},	//   sâd_, rafc_, _بلزا, --, 
   {{0x261800b0,0x3cc829db,0x4dd400ec,0x00000000}},	//   _tūoi_, ркәү_, _عڪاس, --, 
   {{0x6d40fa52,0x6e3c030d,0xa3b800e1,0xe78401f4}},	//   mboa, lppb, _अकल_, оуно, 
   {{0x6e3c03cd,0x00000000,0x00000000,0x00000000}},	//   oppb, --, --, --, 
   {{0x63b40097,0x600800af,0x00000000,0x00000000}},	//   _roxn, kümn, --, --, 
   {{0x6d40fa53,0x63b40694,0xe4a4668b,0x4db800fe}},	//   nboa, _soxn, орго, _আগুৱ, 
   {{0x7aec0e2d,0x2adc1bbb,0x00000000,0x00000000}},	//   şatt, _केतु_, --, --, 
   {{0xe1fc01a8,0x00000000,0x00000000,0x00000000}},	//   _skó_, --, --, --, 
   {{0x9294fa54,0x63b4007c,0x6d40b7c5,0x3744030d}},	//   марц, _voxn, kboa, _хĕст, 
   {{0xc0341b88,0x60080037,0x00000000,0x00000000}},	//   знај, gümn, --, --, 
   {{0x657c0457,0x7c2c01e4,0x00000000,0x00000000}},	// [16250] _ibqh, ƭari, --, --, 
   {{0x6d409007,0x5ebc00cc,0x48e800cc,0x00000000}},	//   eboa, _এইবে, _পৰৱর, --, 
   {{0x88d002f5,0x6d40fa55,0xc0c80023,0x00000000}},	//   াপিক, fboa, _በዞም_, --, 
   {{0x6d40fa56,0xe1fc01e1,0xa01800e5,0x644808a5}},	//   gboa, _ukó_, _csör, _ægis, 
   {{0xc104fa57,0xd59c00c8,0x91842374,0x9c8401c8}},	//   _روسي, יבאל, _زۇلۇ, تشاه, 
   {{0x6d400109,0xfa60001f,0xf08003ff,0xd328009d}},	//   aboa, _ፍቅረማ, _سیمپ, гvйт, 
   {{0x6d400100,0x60080793,0xf8b801c0,0x75f401d3}},	//   bboa, lümo, өөд_, rázz, 
   {{0x3e74049f,0x7c380139,0x2a3400ae,0x00000000}},	//   måt_, _ƅarı, أكيد_, --, 
   {{0x3e74007c,0x00000000,0x00000000,0x00000000}},	//   låt_, --, --, --, 
   {{0xf770042a,0x77c8fa58,0x00000000,0x00000000}},	//   راخ_, слог_, --, --, 
   {{0xd70404a9,0x657c00b5,0x3e7410d1,0xe9a40137}},	//   تىدۇ_, _bbqh, nåt_, تگەن_, 
   {{0xd1f004b2,0x00000000,0x00000000,0x00000000}},	//   ቀበት_, --, --, --, 
   {{0xe8ecfa59,0x7988fa5a,0x78182179,0xc8c82e0b}},	//   _чл_, meew, _люкс_, _وومن_, 
   {{0x3e7401e6,0xe4680008,0x7988fa5b,0x6d400311}},	//   kåt_, _stöð_, leew, zboa, 
   {{0x6d40fa5c,0xdbd4005b,0x00000000,0x00000000}},	//   yboa, määs, --, --, 
   {{0x3e740267,0x54c402dd,0x65bc0240,0x6d400129}},	//   dåt_, _жұмб, _bëhu, xboa, 
   {{0x3de004c5,0x61ec0036,0xc4cc0014,0x64300228}},	// [16260] যকাল, _djcl, _نےَ_, _كىيئ, 
   {{0x6d40fa5d,0x7988009a,0xfbc405d9,0xa110036b}},	//   wboa, heew, _شڪ_, رولت, 
   {{0x6d40fa5e,0xdee0fa5f,0x0cc400dc,0xb63c037e}},	//   tboa, нофи, वन्म, _ａｋ_, 
   {{0x600854ee,0x7988fa60,0x6d40002d,0xdbd401f4}},	//   lüml, jeew, uboa, hääs, 
   {{0x79880083,0xeb98fa61,0xa0a028e8,0xdbd40108}},	//   deew, йид_, _заяд, kääs, 
   {{0x6d40fa62,0x3e745243,0x6008029f,0x60d80432}},	//   sboa, båt_, nüml, _ýuma, 
   {{0x6d40fa63,0x7988002e,0x9eb401ee,0x00000000}},	//   pboa, feew, _ештә, --, 
   {{0x89d8dd5d,0x298892ec,0x7988fa64,0x7df40153}},	//   توبر_, сско_, geew, gąsd, 
   {{0x4814fa65,0x600803ee,0x249c0092,0xdce800c0}},	//   ммис, küml, _ሊካሄድ_, degė, 
   {{0x6e2cfa66,0x60080432,0xc60400b8,0x00000000}},	//   _kubb, jüml, रत्य_, --, 
   {{0x6e2cfa67,0x3200fa68,0x7988fa69,0xa92468eb}},	//   _jubb, _okky_, beew, _едел, 
   {{0xd6d4fa6a,0x6e2cfa6b,0x6008014a,0x569000d4}},	//   яты_, _mubb, yümo, хают, 
   {{0x6e2cfa6c,0xd9400372,0xb53801e1,0x76440363}},	//   _lubb, _чечи, _gbọ́, _çhyn, 
   {{0x3200000f,0x6e2cfa6d,0xe4a4013e,0x4424f178}},	//   _akky_, _oubb, орҳо, öl_, 
   {{0x6e2c007c,0x00000000,0x00000000,0x00000000}},	//   _nubb, --, --, --, 
   {{0x225c05be,0x3e7403cd,0x4614009a,0x00000000}},	//   čuk_, våt_, _توبر, --, 
   {{0x81c0000e,0x600805d1,0x98ac0153,0x50640150}},	// [16270] ্চল_, büml, _degė_, етха, 
   {{0xfd540521,0x6e2cfa6e,0x3e74fa6f,0x79880a49}},	//   bsaị, _bubb, tåt_, zeew, 
   {{0x6e2cfa70,0x6b880042,0x7988fa71,0x00000000}},	//   _cubb, defg, yeew, --, 
   {{0x6e2c0a4d,0x656cf710,0x2164169c,0x3e74fa72}},	//   _dubb, ngch, _этог, råt_, 
   {{0x798804ba,0x61fc01b9,0x00000000,0x00000000}},	//   veew, moql, --, --, 
   {{0x61fca67c,0x6e2c19f5,0x3e7401e6,0x2adc007d}},	//   loql, _fubb, påt_, _केहु_, 
   {{0x6e2cfa73,0xdbd4005b,0x7988fa74,0x00000000}},	//   _gubb, vääs, teew, --, 
   {{0x6008e03b,0xd90c0330,0x17f408f2,0x61fc01d5}},	//   züml, هیا_, ुत्व_, noql, 
   {{0x7988fa75,0xf8a80212,0xdce8025c,0x60080205}},	//   reew, івок_, ddgħ, hümm, 
   {{0x6008fa76,0x79880a49,0x6e2c0009,0x61fc01b9}},	//   kümm, seew, _yubb, hoql, 
   {{0x79881418,0x6e2c0009,0x27e000f2,0x00000000}},	//   peew, _xubb, èkna_, --, 
   {{0x3dcc03a2,0xca380115,0xdbd41073,0x6abc0065}},	//   _jlew_, _urĝa_, sääs, äpfe, 
   {{0xdcf80989,0xdbd405a7,0x27fcfa77,0x3dcc0327}},	//   _obuč, pääs, botn_, _mlew_, 
   {{0x3dcc03cb,0x59240327,0xa018032e,0x98ac0064}},	//   _llew_, _ལྔགས_, _spön, _segė_, 
   {{0x2324fa78,0x3dcc0368,0x60d802fb,0x60082ac2}},	//   дори_, _olew_, _žump, rüml, 
   {{0x7640fa79,0x6e2c53b0,0xd76400db,0x23a40118}},	//   mply, _rubb, _بەگى_, खाउद, 
   {{0x6e2cfa7a,0xe45c01ed,0x7640c847,0x00000000}},	// [16280] _subb, ször_, lply, --, 
   {{0x6e2c692e,0x3dcc0100,0x764000b5,0x409402d5}},	//   _pubb, _alew_, oply, эрст, 
   {{0x3dccfa7b,0x6e2c5705,0xee38a30d,0xa1340451}},	//   _blew_, _qubb, цне_, _ڪرپش, 
   {{0x3dcc0204,0x047801d3,0x80d801ad,0xfe700014}},	//   _clew_, _بلیک_, _नेके, ادٕ_, 
   {{0x6e2c0582,0x2f5402e8,0x1b4001d9,0xed600064}},	//   _wubb, _отвс, چھمُ, _rožę_, 
   {{0x6e2cfa7c,0x59a00490,0x00000000,0x00000000}},	//   _tubb, _खोबर, --, --, 
   {{0xed340139,0x3dcc2517,0xad6400ec,0x6b88fa7d}},	//   _жэзэ, _flew_, _ياره, refg, 
   {{0x395ce607,0x49744b1b,0x3dcc18b8,0x00000000}},	//   _cdws_, хлис, _glew_, --, 
   {{0x3cf000d0,0x00000000,0x00000000,0x00000000}},	//   čovú_, --, --, --, 
   {{0xdcf435b6,0x61fc01d5,0x9cb8011a,0x3dcc0210}},	//   _غفلت_, zoql, _וצמח, _zlew_, 
   {{0x61fcfa7e,0x00000000,0x00000000,0x00000000}},	//   yoql, --, --, --, 
   {{0x2bbc1fbc,0x5e5400df,0x00000000,0x00000000}},	//   ्सवा, ויטע_, --, --, 
   {{0xdeb80023,0x61fce236,0x00000000,0x00000000}},	//   _ተሐኤ_, voql, --, --, 
   {{0x80d805d7,0xb86401c8,0x60080112,0x00000000}},	//   _नेगे, _ساهو, tümm, --, 
   {{0x5334fa7f,0xd7f80375,0x580000f7,0x61fc01a9}},	//   тест, _והגל, _جووك, toql, 
   {{0x2b5c003e,0x60080112,0x00000000,0x00000000}},	//   _ldtc_, rümm, --, --, 
   {{0x61fcfa80,0x2c0c4668,0x60080254,0xc0140395}},	// [16290] roql, ितां_, sümm, емащ, 
   {{0x3dccfa81,0x61fcfa82,0x25d819cc,0xa4240354}},	//   _slew_, soql, खोरी_, _юьйл, 
   {{0xa5b80077,0x212803cb,0x61fc014f,0x00000000}},	//   rmóf, _tgch_, poql, --, 
   {{0x699c4fed,0x61fcfa83,0x60d8010e,0x00000000}},	//   _खोली, qoql, _ýumo, --, 
   {{0x764002f0,0x48d00154,0x0ca80124,0xa5b800e5}},	//   zply, াপুর, ҧтәи_, mmód, 
   {{0xcfa4fa84,0x00000000,0x00000000,0x00000000}},	//   _ишси, --, --, --, 
   {{0x7a6805f5,0x4fc42309,0xab24030d,0x00000000}},	//   чийг_, _جەلە, ноша_, --, 
   {{0x76400419,0x00000000,0x00000000,0x00000000}},	//   vply, --, --, --, 
   {{0xb4bc05ba,0xe7c8687b,0xa3cc00dc,0x00000000}},	//   _इथे_, िसंप, _शतं_, --, 
   {{0x1cdc0135,0x7d08fa85,0xe8f40a89,0xf090011a}},	//   _སྟར_, _iyes, элы_, נני_, 
   {{0x7d081df0,0x2bbc07b7,0xfcbc001f,0xca7400be}},	//   _hyes, ्सरा, _ተሰጠ_, _لانغ, 
   {{0x7d080337,0x4ad813f7,0x76441368,0x667438b5}},	//   _kyes, _भेटव, _çhym, ردپر, 
   {{0x7d080055,0x52c8276a,0x00000000,0x00000000}},	//   _jyes, रन्स, --, --, 
   {{0x7998fa86,0x764077d4,0x7d080022,0x386c06af}},	//   _haww, pply, _myes, muer_, 
   {{0x386cfa87,0x7d081418,0x14e00073,0x25a80332}},	//   luer_, _lyes, _पेरण, áilí_, 
   {{0x7d08014b,0x7998fa88,0x386c0156,0xda0c04aa}},	//   _oyes, _jaww, ouer_, ातित_, 
   {{0x7d08fa89,0x386cfa8a,0x7998fa8b,0xb02802ef}},	// [162a0] _nyes, nuer_, _maww, سكام_, 
   {{0xe4780302,0x7998fa8c,0x00000000,0x00000000}},	//   _צריכ, _laww, --, --, 
   {{0x7d08fa8d,0xfe74fa8e,0xc8ec00e1,0x386c01bf}},	//   _ayes, күр_, _जख्म_, huer_, 
   {{0x7d080337,0x386cfa8f,0xb1d80354,0x00000000}},	//   _byes, kuer_, _хьох_, --, 
   {{0xdca0b6c2,0x7d0800ca,0x386cd95f,0x4c94fa90}},	//   лаци, _cyes, juer_, тилс, 
   {{0x7d08fa91,0x79980ba7,0x386c030a,0xfe701870}},	//   _dyes, _aaww, duer_, ادە_, 
   {{0x799807ab,0xd9d01b56,0x386c003e,0x7d086460}},	//   _baww, گەنگ, euer_, _eyes, 
   {{0x386c0a40,0x7998022f,0x7d080240,0xbaa400d1}},	//   fuer_, _caww, _fyes, тушқ, 
   {{0x386cfa92,0x7d08016b,0x7998fa93,0xd9d021ef}},	//   guer_, _gyes, _daww, دەنگ, 
   {{0x4734036b,0xca3801e4,0x57f001ec,0x18b400c7}},	//   ънос, _urĝo_, лпыт, хгьы_, 
   {{0x799881aa,0x98100fb4,0x2c1401ad,0x45d40024}},	//   _faww, دبيا, _पीयू_, вонс, 
   {{0x386cfa94,0x7998fa95,0x46e800f7,0x6b9803cb}},	//   buer_, _gaww, здүн_, _hatg, 
   {{0x94a8f854,0x386c45a7,0x26c80219,0x6b98013d}},	//   нтра_, cuer_, šbo_, _katg, 
   {{0x79980198,0x6b980455,0x2918033f,0x00000000}},	//   _zaww, _jatg, ązać_, --, 
   {{0xd6ccfa96,0x6b98fa97,0x79980198,0xa5b801d3}},	//   _ст_, _matg, _yaww, tmód, 
   {{0x6b98005f,0x9b140375,0x00000000,0x00000000}},	//   _latg, תחלה_, --, --, 
   {{0x600800ee,0xe61c0548,0x6b9803ac,0x1ea80451}},	// [162b0] lümi, mmô_, _oatg, ڻائي_, 
   {{0x6b98fa98,0x25b401ed,0x78bc0b1a,0x7d08005c}},	//   _natg, _آنکھ_, øsvi, _ryes, 
   {{0x7000031c,0x925802d5,0xef180354,0x00000000}},	//   _མཉྫུ_, _паэт_, çма_, --, 
   {{0x7d08fa99,0x41a40412,0x6294022e,0xe61c007f}},	//   _pyes, _ऑफिस, _isxo, nmô_, 
   {{0x8d74fa9a,0x79980ba7,0x6b98fa9b,0x6008010e}},	//   ااما, _raww, _batg, hümi, 
   {{0x6b98fa9c,0x7998fa9d,0x6b60fa9e,0x7d080200}},	//   _catg, _saww, акша, _vyes, 
   {{0x6b980cfd,0x386c0a40,0x79980099,0x69cc0153}},	//   _datg, wuer_, _paww, _įber, 
   {{0x386cfa9f,0x7998faa0,0x6b980c8c,0xcd34007b}},	//   tuer_, _qaww, _eatg, _مركب, 
   {{0x7d0800aa,0x6b981570,0x6d4800ee,0xed4c132f}},	//   _uyes, _fatg, ýlaş, _ذھن_, 
   {{0x386cfaa1,0x7998f706,0x6b98067c,0xb6a4084c}},	//   ruer_, _waww, _gatg, виол, 
   {{0x7998faa2,0x3e50013f,0x386c0f85,0x55c401ec}},	//   _taww, fɑtɑ_, suer_, ганғ, 
   {{0x1cdc025c,0x6b980c86,0x386c01c7,0x799802d0}},	//   _སྟོ_, _zatg, puer_, _uaww, 
   {{0x386cfaa3,0x88c404fb,0x96d00131,0x7664004b}},	//   quer_, _متول, _әслә, ریکې_, 
   {{0x6b98022e,0x37e40408,0x3668011c,0x00000000}},	//   _xatg, _шолг, _жако_, --, 
   {{0x7df4012d,0x00000000,0x00000000,0x00000000}},	//   ząsa, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe57403a5,0x3124f819,0x3170faa4,0x60080086}},	// [162c0] _рзы_, тдаг, rgyz_, nümw, 
   {{0xe0dc01ab,0x72c400c0,0x69dc00e5,0xe454011a}},	//   _reòt_, _абоз, épez, _שייט_, 
   {{0x6b980730,0x630001d9,0xe45c01f4,0xdce40055}},	//   _ratg, _نوٝل, nyön_, _āmāv, 
   {{0x6b98faa5,0x6ce40220,0xf1d04f41,0x6b4c033f}},	//   _satg, кіле, _төгө, _mógł, 
   {{0xccf806ba,0x6b98faa6,0x600800ee,0x2c0c0490}},	//   хқа_, _patg, zümi, ितलं_, 
   {{0x6b98faa7,0xdb8001c0,0xce3400f1,0x00000000}},	//   _qatg, игчи, _موسک, --, 
   {{0x6b98faa8,0xa50c1f13,0x00000000,0x00000000}},	//   _vatg, _सर्च_, --, --, 
   {{0x600801b8,0x6b980036,0xa8a4faa9,0x80d800eb}},	//   vümi, _watg, врок, _ভুট্, 
   {{0x6b98faaa,0x48d00154,0xe6c800bc,0x00000000}},	//   _tatg, াপ্র, ान्ज, --, 
   {{0x6b9804cc,0xdc3000d1,0x99e000d7,0x00000000}},	//   _uatg, _ئىلخ, ľňam, --, 
   {{0xa01801e6,0x00000000,0x00000000,0x00000000}},	//   _spök, --, --, --, 
   {{0x25bc0579,0xa49001d5,0xa6440066,0x00000000}},	//   ðul_, لیبت, _یخبن, --, 
   {{0xa8500348,0xe0dc0192,0x04c87286,0xdcec0055}},	//   _телә, _leòr_, روسي_, _ādīt, 
   {{0x985000d1,0xa61000c7,0x00000000,0x00000000}},	//   _өтәш, ыҷқә, --, --, 
   {{0x12c4006c,0x418401ec,0x00000000,0x00000000}},	//   аётг, лтағ, --, --, 
   {{0xa3cc2232,0xd244084c,0x9f4000e5,0x1a98010f}},	//   _शतक_, рэри, _ujjú_, וילע, 
   {{0x21f4038f,0x84c41c5c,0xc11400d8,0x00000000}},	// [162d0] għha_, _сәнд, умај, --, 
   {{0x4fd40138,0x4394009b,0x00000000,0x00000000}},	//   ажут, _саос, --, --, 
   {{0x42543b89,0x00000000,0x00000000,0x00000000}},	//   _حنجر, --, --, --, 
   {{0x1cdc025c,0x00000000,0x00000000,0x00000000}},	//   _སྟུ_, --, --, --, 
   {{0x50f47724,0x4d6402bf,0x660c0363,0x00000000}},	//   _взят, рків, ilck, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbed40640,0x2dc800cf,0xff2000cc,0x00000000}},	//   _совј, باەۋ_, _প্ৰশ_, --, 
   {{0xab700022,0xe45c0108,0x00000000,0x00000000}},	//   агәш, vyön_, --, --, 
   {{0x4c94008e,0x499001d5,0x9d5000f1,0x00000000}},	//   _китс, زیور, _منځت, --, 
   {{0x81e8015b,0xe45c023a,0x00000000,0x00000000}},	//   মকি_, työn_, --, --, 
   {{0x7f5409c2,0xf6240228,0xa5600116,0xac880092}},	//   _mezq, лдоо, ڭگىن, _መልሰኝ_, 
   {{0x64a00588,0x3948010b,0x7df40210,0x00000000}},	//   әара, _ýas_, ząsn, --, 
   {{0x7bc0faab,0x57a00184,0x29fc0327,0x00000000}},	//   _kolu, _ҡыҫҡ, fċaf_, --, 
   {{0x7414969f,0x9f980254,0xd1d4001f,0x2a7801e1}},	//   اوسا, _jääs_, ረዱት_, _ígbò_, 
   {{0x35a44e90,0x3c38007f,0x869800a8,0xb81800e1}},	//   _байг, _lèv_, _атыт_, _नीयम_, 
   {{0x443800c6,0x7bc0faac,0x51440220,0xdfe4013e}},	//   bqs_, _lolu, рдағ, ҳдуд_, 
   {{0xa064faad,0x7bc0198f,0xe0dc01ab,0xef8403d0}},	// [162e0] лата_, _oolu, _seòr_, ллап, 
   {{0x7bc0faae,0xa4b404ae,0x9f983b22,0xdb0c010e}},	//   _nolu, _עליה_, _nääs_, _şeýb, 
   {{0xad1081fc,0x25b453be,0xdd8c00f1,0xed4400d4}},	//   әплә, _شهید_, ګون_, гнеп, 
   {{0x2bbc1b61,0xa0640022,0xc1040451,0x00000000}},	//   ्स्थ, _әара_, _چوٽي, --, 
   {{0x7bc0faaf,0x72040014,0xc1040451,0xe7a400dc}},	//   _bolu, _لوگم, _نوٽي, _कोऽप, 
   {{0xafe40e84,0x3c380100,0x80b001ec,0x996001e0}},	//   _согл, _dèv_, _بەكش, ҡтыл, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x684800d8,0x00000000,0x00000000,0x00000000}},	//   нџов_, --, --, --, 
   {{0x7bc0fab0,0xeda401ee,0x682400d4,0x00000000}},	//   _folu, _ишҡо, льоз, --, 
   {{0x7e70025a,0xa09400c8,0x1cdc025c,0x1c181bbb}},	//   _âkpä, נדיק_, _སྟི_, _पीपल_, 
   {{0x3c3802bd,0x6f0804cc,0x298400db,0x97a000c7}},	//   _zèv_, üfch, _былг, срыл, 
   {{0xd6d4fab1,0x7bc0fab2,0xf9ec002b,0x00000000}},	//   уть_, _zolu, _ṣaḍā, --, 
   {{0x7bc0fab3,0x29100241,0x6e20ce3e,0x00000000}},	//   _yolu, _áya_, imob, --, 
   {{0x69c0fab4,0x7bc000e8,0x00000000,0x00000000}},	//   _hooe, _xolu, --, --, 
   {{0x45d48727,0x798c0309,0x666400a7,0xc5f800ef}},	//   _войс, _ñawc, _сълз, frēt_, 
   {{0xc5f80171,0x00000000,0x00000000,0x00000000}},	//   grēt_, --, --, --, 
   {{0x69c0062c,0x80b4013e,0x00000000,0x00000000}},	// [162f0] _mooe, шбах, --, --, 
   {{0xdef8870a,0x3c3802bd,0x0fe400cf,0x00000000}},	//   ные_, _rèv_, бөсү, --, 
   {{0x7bc0fab5,0x3c380100,0xfd7401c6,0x57f80115}},	//   _rolu, _sèv_, илжэ, עלבו, 
   {{0x6e20fab6,0x8f340022,0x00000000,0x00000000}},	//   gmob, _ҳерц, --, --, 
   {{0x7bc00552,0xbf6404d3,0x9f981057,0xe45c007c}},	//   _polu, _نگاو, _pääs_, nsö_, 
   {{0x6e2030e8,0x7bc02994,0x3c38033b,0xe45c023a}},	//   amob, _qolu, _vèv_, isö_, 
   {{0x7bc0fab7,0x69c006f2,0x5ebc00fe,0x00000000}},	//   _volu, _booe, _এইকে, --, 
   {{0x7bc0fab8,0x6e20fab9,0x69c0faba,0xf864368e}},	//   _wolu, cmob, _cooe, авио, 
   {{0xa9200c04,0x69c0fabb,0x00000000,0x00000000}},	//   одъл, _dooe, --, --, 
   {{0x7bc01730,0x37e42063,0xc888027d,0xa82000f1}},	//   _uolu, роог, اخيل_, يکون, 
   {{0x1cd00156,0x600806b9,0x61f80e04,0x00000000}},	//   ེནམ_, lüms, čulj, --, 
   {{0x69c0045a,0xc5f800ef,0x00000000,0x00000000}},	//   _gooe, drēs_, --, --, 
   {{0x394cfabc,0x00000000,0x00000000,0x00000000}},	//   mbes_, --, --, --, 
   {{0x394cfabd,0xb6a410f5,0xf74403b7,0x386c4e9b}},	//   lbes_, _викл, _теко, mrer_, 
   {{0x960401c6,0x66e00e4e,0x7d0c000d,0x00000000}},	//   _гүнж, _моша, üasj, --, 
   {{0x386cfabe,0xa5b8056a,0x34a873ef,0x600815b7}},	//   orer_, lmón, _авио_, küms, 
   {{0x386cfabf,0xc66c0092,0xc044bbff,0x00000000}},	// [16300] nrer_, _በተሳካ_, مخلو, --, 
   {{0x386cfac0,0xb4c00574,0x6e200f85,0x00000000}},	//   irer_, ंही_, wmob, --, 
   {{0x386cfac1,0xed58fac2,0x394c07ab,0x2d94009d}},	//   hrer_, вое_, kbes_, ирдс, 
   {{0x386c17c1,0x1cdc025c,0x7bc4fac3,0x00000000}},	//   krer_, _སྟང_, öhun, --, 
   {{0x6e20fac4,0x386c037e,0x3ea4001f,0xa0a000db}},	//   rmob, jrer_, _ለዋልታ_, _даяд, 
   {{0x386c8784,0x7fd43334,0x69c0fac5,0x394cfac6}},	//   drer_, _лісі, _sooe, ebes_, 
   {{0x15f8069f,0x386c3c34,0x69c00204,0xf1c8c8aa}},	//   ीवार_, erer_, _pooe, _रवान, 
   {{0x386c0261,0x29885205,0x8fd40184,0xdd8c01d9}},	//   frer_, тско_, _тәғә, _ٲول_, 
   {{0xdd8c01d9,0x386cfac7,0x3cec09bb,0x98b402e8}},	//   _زول_, grer_, _आइये_, илът_, 
   {{0x69c0039a,0xbab000db,0x00000000,0x00000000}},	//   _wooe, تۅۅب, --, --, 
   {{0x386cfac8,0x394cfac9,0x69c00a73,0xab280a89}},	//   arer_, bbes_, _tooe, _рожа_, 
   {{0x386c0372,0x69c00194,0xe8e80276,0xfbd00046}},	//   brer_, _uooe, _имед_, _وتە_, 
   {{0x386c7f70,0x798c59aa,0x6ab45d9c,0xc8b4104c}},	//   crer_, _ñawa, _अपुर, _دلشک, 
   {{0xe45ca6e1,0x00000000,0x00000000,0x00000000}},	//   rsö_, --, --, --, 
   {{0xe45c3b22,0x6008496e,0xb80400ae,0x00000000}},	//   ssö_, kümr, _ابنه, --, 
   {{0xe45c00e5,0x00000000,0x00000000,0x00000000}},	//   nyök_, --, --, --, 
   {{0x7a340006,0x00000000,0x00000000,0x00000000}},	// [16310] _ište, --, --, --, 
   {{0x6ab42432,0x2d840421,0x2ca402fb,0xa5b8011f}},	//   _अपूर, efoe_, dvod_, omóo, 
   {{0x649002bf,0x394c0024,0x2ca4054e,0x00000000}},	//   _iнiц, ybes_, evod_, --, 
   {{0x237c04b9,0x386cfaca,0xf2d000c8,0x26dc005a}},	//   đuju_, yrer_, _זעט_, izto_, 
   {{0xbb442bb6,0xdbb400d1,0x7bc4005b,0x00000000}},	//   белк, иткә_, öhuo, --, 
   {{0x386cfacb,0x69c4facc,0x2d80007c,0xba2400d1}},	//   vrer_, öken, _öken_, әдик, 
   {{0x7a340bb8,0xdcf80bb8,0xaa54026a,0xdd9800c7}},	//   _ošte, _obuć, бију_, _иша_, 
   {{0x386cfacd,0x26dc0327,0x7c340064,0x00000000}},	//   trer_, dzto_, _геах, --, 
   {{0x394cface,0x3cd4447e,0x386cfacf,0x5ebc009e}},	//   rbes_, _ужас, urer_, _এইটে, 
   {{0x386cfad0,0x394cfad1,0xe8f4023a,0x7df4033f}},	//   rrer_, sbes_, сль_, kąsk, 
   {{0xa5b8fad2,0x8698fad3,0x35a4a902,0xfb14027d}},	//   rmón, атят_, банг, _اواج, 
   {{0x386cfad4,0x394c0327,0xc8380092,0x1c180456}},	//   prer_, qbes_, _የሁሉን, _पीतल_, 
   {{0xb4c0fad5,0xb92400f2,0x9da001ec,0x00000000}},	//   ंहे_, _افشي, стiк, --, 
   {{0xa5b804d4,0x3b1c0f7c,0x7a3400d0,0x00000000}},	//   lmól, _ትንሳኤ, _ešte, --, 
   {{0xe794082a,0x00000000,0x00000000,0x00000000}},	//   _دانک, --, --, --, 
   {{0xf1a8dd6a,0x41b400f3,0x00000000,0x00000000}},	//   داسه_, осут, --, --, 
   {{0xaf34fad6,0xdfccfad7,0x0fe8fad8,0xdecc0cad}},	// [16320] مرات, کيل_, алақ_, _wọ́n_, 
   {{0xdd8c01ed,0x00000000,0x00000000,0x00000000}},	//   ہوم_, --, --, --, 
   {{0xb8c82fb5,0x44241b45,0x73c400f1,0xa758010f}},	//   _བན_, _بريف, _نيکم, רדער, 
   {{0xed58ca26,0xca380115,0x6e340022,0xa018002f}},	//   اشات_, _ruĝ_, _ҳхах, _spöt, 
   {{0x78ac00f3,0xabb00139,0x00000000,0x00000000}},	//   _šavn, залә, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xada405f5,0x2ca41440,0xeab4015b,0xea8800f2}},	//   _лавл, svod_, জন্ম, اختن_, 
   {{0xf6e4031c,0x60080037,0x00000000,0x00000000}},	//   _སྟེང, lümp, --, --, 
   {{0xeab80724,0x6d4001f5,0x6930023b,0x00000000}},	//   _әйе_, mcoa, онқу, --, 
   {{0x6d40fad9,0x7534010b,0x00000000,0x00000000}},	//   lcoa, _agyz, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x0dc4044e,0x00000000,0x00000000,0x00000000}},	//   _ጸሓፊ_, --, --, --, 
   {{0x7a34fada,0x6d40005a,0x02d000dc,0x3e4000c0}},	//   _všte, icoa, सन्न, _mėta_, 
   {{0xfa340150,0x3e4000c0,0x7bdc00c0,0x00000000}},	//   _ارەد, _lėta_, _įsuk, --, 
   {{0x21643c25,0x00000000,0x00000000,0x00000000}},	//   йтаг, --, --, --, 
   {{0x7a34071b,0x04c806c2,0xd1c8009d,0x00000000}},	//   _ušte, _نوعي_, бууд_, --, 
   {{0x9f4802f0,0xaa8400a2,0x00000000,0x00000000}},	// [16330] šmír_, laýı, --, --, 
   {{0xdb1c01ed,0x7df40153,0x0dc40240,0x0fe400db}},	//   űvés, mąsi, _ጸሓፈ_, пөсү, 
   {{0x44200205,0xd3d801e2,0x00000000,0x00000000}},	//   _ihh_, _دبيا_, --, --, 
   {{0x69c40295,0x00000000,0x00000000,0x00000000}},	//   ökel, --, --, --, 
   {{0x716402dd,0x30380014,0x4420005b,0x3e400064}},	//   _باپك, _پتُک_, _khh_, _dėta_, 
   {{0x78ac07f5,0x00000000,0x00000000,0x00000000}},	//   _šavo, --, --, --, 
   {{0x4420fadb,0x6d4001f5,0x00000000,0x00000000}},	//   _mhh_, bcoa, --, --, 
   {{0x68f40153,0xf9c87fa5,0x00000000,0x00000000}},	//   _žyda, ргик_, --, --, 
   {{0xf7709c01,0x9be402bf,0x29180115,0x7df40064}},	//   واد_, _ліжк, _ŝpar_, jąsi, 
   {{0x442003cd,0x7df40064,0xb7880166,0x00000000}},	//   _nhh_, dąsi, рәде_, --, 
   {{0x798c0086,0x5f0c2ca5,0xf62402e8,0x1608024c}},	//   _ñawo, _तुम्_, ждно, ймоқ_, 
   {{0x60080205,0x00000000,0x00000000,0x00000000}},	//   zümp, --, --, --, 
   {{0xdff81d34,0x9770010b,0x00000000,0x00000000}},	//   ्वाद_, _етйә, --, --, 
   {{0x7d0c09a5,0x1cdc031c,0x6d40fadc,0x00000000}},	//   ýasy, _སྟབ_, zcoa, --, 
   {{0x44206144,0xf5040107,0x78a8fadd,0x00000000}},	//   _dhh_, ёзҳо, lvev, --, 
   {{0x415842cd,0x6d40007c,0x71741bf4,0x144801f0}},	//   йшую_, xcoa, تهرا, _лоиқ_, 
   {{0x741400f7,0x78a8fade,0x65140150,0x6fb408f0}},	// [16340] _ووعا, nvev, _وقىس_, يمرا, 
   {{0x44200477,0x6d400076,0xa01836b2,0x92e800cc}},	//   _ghh_, wcoa, _spör, _বডী_, 
   {{0xb4e815e0,0x60080112,0x8e2c01d5,0x78ac013a}},	//   _मधु_, rümp, аlаr_, _šavl, 
   {{0x78a8030a,0x2ca8041b,0x60080254,0x00000000}},	//   kvev, икеп_, sümp, --, 
   {{0xb390010c,0x932400f1,0x39400051,0x00000000}},	//   _ልምድን_, _برښن, _đhsp_, --, 
   {{0x6d40fadf,0xe0f80302,0x2004488c,0x6fb400c6}},	//   scoa, _כלכל, čnic_, _بمسا, 
   {{0x7c2000a3,0x24c800cc,0x60d8010b,0x00000000}},	//   _dhlr, _লোহ, _ýumr, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7c2001ab,0xb86c0092,0xab64014b,0x00000000}},	//   _fhlr, _በነገው_, _мвал, --, 
   {{0xd7f44e0c,0xa5b80a90,0x18b40022,0xe0b4011a}},	//   жую_, rmóm, цгьы_, קליט_, 
   {{0x21240016,0x26c8025a,0x78a80022,0x00000000}},	//   ̀nh_, âbo_, avev, --, 
   {{0x7a0002b1,0x7df40024,0xd6d40a89,0x00000000}},	//   tēte, tąsi, юты_, --, 
   {{0x4420070d,0xba28823d,0x7a340006,0x6fd80490}},	//   _phh_, _اسلم_, _išta, णसां, 
   {{0x3cec000d,0xd75400f7,0x00000000,0x00000000}},	//   _आइसे_, _ۇلۇت_, --, --, 
   {{0x1cdc0135,0x7a000093,0x53344881,0x4420fae0}},	//   _སྟན_, sēte, дерт, _vhh_, 
   {{0xf6e40327,0xd6d8011a,0x7a00fae1,0x00000000}},	//   _སྟིང, _כחול, pēte, --, 
   {{0x1fa4fae2,0x41b401ed,0x4058fae3,0x00000000}},	// [16350] жрег, _ہمدر, صلاح_, --, 
   {{0x644cfae4,0x00000000,0x00000000,0x00000000}},	//   mpci, --, --, --, 
   {{0x7a34110c,0x78a80433,0xb0800131,0x00000000}},	//   _ošta, zvev, _ﻧﻪﭼﭽ, --, 
   {{0xd1302e51,0x40340801,0x644c01f5,0x78a8fae5}},	//   رمە_, _немс, opci, yvev, 
   {{0x32d804d3,0x26f40034,0x91840228,0xe1fc0ca8}},	//   _ندێک_, ँपुर_, _تۇقۇ, _ijó_, 
   {{0x7a340309,0xe1fc0413,0xbb84007b,0x8b940395}},	//   _ašta, _hjó_, سلبي, дръч, 
   {{0x6284fae6,0xaa540063,0x6f600116,0x00000000}},	//   ntjo, пију_, _سۇنم, --, 
   {{0x7e640023,0x78a8fae7,0xaa540063,0x6284002f}},	//   mshp, tvev, чићу_, itjo, 
   {{0xb4e80574,0x7c2002c4,0x7cd8a92d,0x6284009b}},	//   _मधे_, _thlr, _умар_, htjo, 
   {{0x78a8fae8,0x628401e3,0x00000000,0x00000000}},	//   rvev, ktjo, --, --, 
   {{0x7e640113,0x78a80158,0x291003cd,0xe1fc0ca8}},	//   nshp, svev, _øyan_, _ojó_, 
   {{0x8b340150,0x6284143a,0xe1fc0248,0x75f400e2}},	//   _تۋىر_, dtjo, _njó_, kšze, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe1fc01e1,0x395c0204,0xb9e40023,0x7bc401f4}},	//   _ajó_, _hews_, _ክም_, öhuh, 
   {{0xe1fc01a8,0xdce8031c,0x00000000,0x00000000}},	//   _bjó_, begħ, --, --, 
   {{0x395cfae9,0xb464084c,0x010801e2,0x00000000}},	//   _jews_, _екил, ښتلو_, --, 
   {{0x395cfaea,0x845400db,0xe4540024,0x00000000}},	// [16360] _mews_, _قىيچ, _ежы_, --, 
   {{0xe1fc0241,0x395c00a3,0xe0d435a2,0x00000000}},	//   _ejó_, _lews_, чву_, --, 
   {{0xe35425f9,0xa0300e56,0x00000000,0x00000000}},	//   _משיח_, رىمت, --, --, 
   {{0x395cfaeb,0x20040419,0x00000000,0x00000000}},	//   _news_, čnia_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfca8004b,0x98a4013d,0x00000000,0x00000000}},	//   غانو_, _şiği_, --, --, 
   {{0x80d003f4,0x7e640354,0x395c0327,0x9b4000f1}},	//   _সেপ্, cshp, _bews_, رنيو, 
   {{0x3cc818ce,0x9a8001d5,0xdce8031c,0x7d240254}},	//   скәү_, хушл, xegħ, ötsü, 
   {{0x2900faec,0x395c0204,0xeb34faed,0x9d740014}},	//   çka_, _dews_, _فراخ, _ژٕہا_, 
   {{0x0144001f,0xdb000306,0x5834030d,0x9cd8011a}},	//   ያስተም, zdné, язья_, _הקמפ, 
   {{0x04f8015b,0x69f00116,0x6fd001bf,0xdce8025c}},	//   _ঘরের_, _пүкт, _cæci, tegħ, 
   {{0x26c00552,0x0b5801af,0x00000000,0x00000000}},	//   ćko_, _ырғы_, --, --, 
   {{0x80d000bd,0x6d5c013f,0x7df40024,0xa5b800ae}},	//   _সেন্, ɔpat, mąst, nmói, 
   {{0xe66403a6,0xe1fc0252,0x7df40153,0x77600112}},	//   _етио, _sjó_, ląst, calx, 
   {{0x96f40276,0x7a0000e2,0x00000000,0x00000000}},	//   _нешт_, lēta, --, --, 
   {{0x3cec000d,0xd2340395,0xdce8031c,0x6284e280}},	//   _आइले_, енсъ, qegħ, rtjo, 
   {{0x6284faee,0x660cfaef,0x7a00005f,0xe0dc01e1}},	// [16370] stjo, mock, nēta, _efòn_, 
   {{0xe9e0068f,0x628401e0,0x7e640200,0xefc80092}},	//   leźć_, ptjo, tshp, _በቀይ_, 
   {{0x7f44faf0,0x23600309,0x7a0002b1,0x3f8400a2}},	//   rchq, majj_, hēta, _ölum_, 
   {{0x7a0004fe,0x7e640023,0x660cfaf1,0x00000000}},	//   kēta, rshp, nock, --, 
   {{0x0db80597,0x91840372,0xfd1000ec,0xe45c01f4}},	//   ثالث_, _سۇلۇ, ڙجڪ_, myös_, 
   {{0x660cfaf2,0x2a8c03b9,0x7a0000de,0x00000000}},	//   hock, _səba_, dēta, --, 
   {{0x2b5c02fa,0xab24006c,0x660cfaf3,0x798c0784}},	//   _detc_, моша_, kock, _ñawk, 
   {{0x23600113,0xd2b802e4,0x660c6b56,0x1fbc00cc}},	//   hajj_, ללות_, jock, _ইতিস, 
   {{0x2b5c0b6f,0x23600054,0x37741e76,0x660c007c}},	//   _fetc_, kajj_, мынс, dock, 
   {{0x2b5c0fec,0xe85013f9,0x660c00ad,0xb8f40037}},	//   _getc_, کنید, eock, _हथ_, 
   {{0x660ce279,0xb3400166,0xdb200108,0x00000000}},	//   fock, _öçil, äräj, --, 
   {{0x776001b9,0xf8b821e7,0x96d000fd,0x06b801d9}},	//   salx, _وهاب_, _үскә, سنُک_, 
   {{0x7a00005f,0x5f0c000d,0x00000000,0x00000000}},	//   cēta, _तुस्_, --, --, 
   {{0xedb8202e,0xe45c0108,0x00000000,0x00000000}},	//   _ईच्छ, vyöt_, --, --, 
   {{0x35a40228,0x281000db,0xc644075e,0x07180150}},	//   _жайг, _جووس, _كئيى, _ﺳﺎﯓ_, 
   {{0x660cfaf4,0xe45cdf4c,0xe50c01f2,0xe29400c7}},	//   cock, työt_, ụmụn, ьас_, 
   {{0x3eb00730,0x2004151c,0x69c402fc,0x00000000}},	// [16380] _arzt_, čnin_, ökei, --, 
   {{0x24941060,0xe36000c7,0x00000000,0x00000000}},	//   _کنید_, _икьи, --, --, 
   {{0x7a00005f,0xb224faf5,0x00000000,0x00000000}},	//   zēta, _омол, --, --, 
   {{0x8d280166,0x00000000,0x00000000,0x00000000}},	//   пнең_, --, --, --, 
   {{0xac08faf6,0xdca0368e,0x958802d5,0x21f40327}},	//   онда_, каци, _grąž, għhu_, 
   {{0x660cde30,0x7a0000e2,0x7b8000d1,0xa5b801e7}},	//   zock, vēta, лғуд, rmói, 
   {{0x1600060c,0x7a3000e4,0x00000000,0x00000000}},	//   ोकार_, _ẽtap, --, --, 
   {{0x286801c0,0x7a0000e2,0xec7800d8,0x6d9c0cad}},	//   ороо_, tēta, _мпб_, _ṣafi, 
   {{0xbc700058,0x7a34faf7,0x660c00d7,0x6d5415b7}},	//   _مۇنب, _ešto, vock, ıyad, 
   {{0xab28554f,0x7a0000da,0x660c0210,0x00000000}},	//   _доза_, rēta, wock, --, 
   {{0xa5b80120,0x29840228,0xfd6800e4,0x7a0000e2}},	//   imóv, _жылг, _ropẽ, sēta, 
   {{0xd6d40b14,0x00000000,0x00000000,0x00000000}},	//   фть_, --, --, --, 
   {{0xd940faf8,0x23600054,0x9484b590,0x61ec0327}},	//   _речи, tajj_, кырд, _rmcl, 
   {{0x660cfaf9,0x61ec0175,0x78bc03cd,0x7aec01e4}},	//   sock, _smcl, åsve, ŝate, 
   {{0x26041b88,0x23600113,0xca4c0150,0xd370215c}},	//   _очиг, rajj_, _ﺃﺩﺏ_, جۇپ_, 
   {{0x23600054,0x42980023,0x00000000,0x00000000}},	//   sajj_, _ህውከት_, --, --, 
   {{0x23600784,0x00000000,0x00000000,0x00000000}},	// [16390] pajj_, --, --, --, 
   {{0x7a2465fa,0x7a100118,0xa0740124,0x1ea800ec}},	//   móte, mětř, зыҧш, ٺائي_, 
   {{0x61ec0327,0x81d401c6,0x1ea8009f,0x00000000}},	//   _tmcl, _зонх, غائي_, --, 
   {{0xc0c40131,0x00000000,0x00000000,0x00000000}},	//   _пәзи, --, --, --, 
   {{0x798c0986,0x644806af,0x00000000,0x00000000}},	//   _ñawi, _égid, --, --, 
   {{0xb600032e,0x00000000,0x00000000,0x00000000}},	//   _þáva, --, --, --, 
   {{0x2000022f,0x6fd0003a,0xb60402fd,0x38b40022}},	//   _ijji_, _cæcu, _hláš, _oúrô_, 
   {{0xb6040122,0x3f80031c,0x7a2401d3,0x00000000}},	//   _kláš, lghu_, kóte, --, 
   {{0xcdc800db,0x7c5800cf,0x1ba801d3,0x4c1400cf}},	//   _تۇنۇ_, _رلار_, _وائٹ_, ربۇس, 
   {{0x8b8804a9,0x3f800369,0x3dcc0042,0x36c40354}},	//   _يەنە_, nghu_, _hoew_, ебог, 
   {{0x7a3401a6,0x00000000,0x00000000,0x00000000}},	//   _ušto, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3dcc0036,0x7a0000e2,0xca4c01ec,0x00000000}},	//   _moew_, lēto, _ﺃﺩﺕ_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x200402fb,0x59d000af,0x3f800455,0x7a0000e2}},	//   čnil_, _तवार, dghu_, nēto, 
   {{0x21a0ab45,0x3a2c0455,0x3f80031c,0x659000f3}},	//   лисм, nmep_, eghu_, _баћу, 
   {{0x4dc80183,0x3f80031c,0x00000000,0x00000000}},	// [163a0] লসমূ, fghu_, --, --, 
   {{0xe45408a8,0xa5b8fafa,0x9f801a71,0x00000000}},	//   _רייט_, glóf, лгуд, --, 
   {{0xee383e0c,0x63b000fd,0x6b9c03e3,0xae786c9c}},	//   чне_, _сәях, _özgə, ясах_, 
   {{0x20001418,0xa5b80332,0x6458054e,0xdd8000db}},	//   _ejji_, alóf, ţuie, гышп, 
   {{0x6fd00381,0x66e4caff,0x6e9401e2,0x00000000}},	//   _sæcu, _kéké, _ګلزا, --, 
   {{0x66e4fafb,0xa5b801e7,0x00000000,0x00000000}},	//   _jéké, clóf, --, --, 
   {{0xed581b10,0x2d946c8c,0x6240010f,0x7a2400e5}},	//   _нов_, _прас, _aĵoj, zóte, 
   {{0xff50021a,0x66e4003e,0xa5b81427,0x00000000}},	//   _مخې_, _léké, nmót, --, 
   {{0xa5b8fafc,0x7a240d12,0x00000000,0x00000000}},	//   llóg, fótb, --, --, 
   {{0xa5b8fafd,0x98701e76,0x7a0000e2,0x7cf800e4}},	//   ológ, ыльц, bēto, súrô, 
   {{0xd6d4206e,0x7a00005f,0x00000000,0x00000000}},	//   етя_, cēto, --, --, 
   {{0xc8a802e5,0x7a2400e5,0x3f800327,0x00000000}},	//   _कनपट, tóte, zghu_, --, 
   {{0x66e401ed,0x2904005a,0x00000000,0x00000000}},	//   _béké, _uxoa_, --, --, 
   {{0x66e40c6a,0xdb0000bc,0x00000000,0x00000000}},	//   _céké, zdní, --, --, 
   {{0x1cc8025c,0x92940408,0xa5b802d2,0x41846171}},	//   ྲའོ_, ларц, fmót, ктағ, 
   {{0x7a24fafe,0xb6040122,0x46140244,0x00000000}},	//   póte, _pláš, _جوبر, --, 
   {{0x66e400e8,0x52240276,0x3f80025c,0x00000000}},	// [163b0] _féké, уфра, tghu_, --, 
   {{0xcdc40046,0xa5b80162,0x50d400f2,0x00000000}},	//   ғашқ, flóg, دزفر, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x73340137,0x4ea40124,0x00000000,0x00000000}},	//   _جىپا, ыруа, --, --, 
   {{0x4d1402d5,0x8d740691,0xdb0000bc,0x66e40248}},	//   льшт, طانا, rdní, _yéké, 
   {{0xeb94de5f,0x3f80025c,0x00000000,0x00000000}},	//   виш_, qghu_, --, --, 
   {{0x9ad001f2,0xab600131,0x2e3400db,0x00000000}},	//   _bịak, شۇنى, ربۅڭ, --, 
   {{0x6d540342,0x7a0000e2,0x2010045a,0x00000000}},	//   ıyac, rēto, loxi_, --, 
   {{0x9c4400d4,0x00000000,0x00000000,0x00000000}},	//   _їхал, --, --, --, 
   {{0x7d08021a,0xf090011a,0xc0d40092,0xa5b801e7}},	//   _ixes, סני_, _የክስ_, hlód, 
   {{0x66e4003e,0x88c4faff,0x16c80073,0xb994007b}},	//   _réké, _ەتىل, ाहेब, _للاب, 
   {{0x75e4033f,0x66e4585c,0xd3480271,0x00000000}},	//   _mózg, _séké, کیده_, --, 
   {{0x3e400006,0x200401fa,0xa5b803b2,0x9da001ec}},	//   _dėti_, čnij_, vmót, ттiк, 
   {{0x2a7801e1,0x0c240408,0x00000000,0x00000000}},	//   _ìgbò_, _умĕн, --, --, 
   {{0xe360fb00,0x2010003a,0x626000f3,0x00000000}},	//   ркси, doxi_, ивра, --, 
   {{0x7d08035a,0x68f40153,0x68240174,0x00000000}},	//   _oxes, _žydi, rðde, --, 
   {{0xa064fb01,0xe040fb02,0x7d0888e0,0xef847a94}},	// [163c0] ката_, инти, _nxes, клап, 
   {{0xa5b801a8,0x556400cf,0xe478010f,0xdd8c01d9}},	//   smót, _جۇڭك, _קריכ, ۪ون_, 
   {{0x7d08fb03,0xdd8c0451,0x4374fb04,0xb60002d2}},	//   _axes, ڪون_, _суыт, _þása, 
   {{0xa5b8dbda,0xdd8cfae3,0x00000000,0x00000000}},	//   rlóg, قوم_, --, --, 
   {{0x7d08002e,0xa5b8022c,0x20101577,0x00000000}},	//   _cxes, slóg, boxi_, --, 
   {{0xbf64bf4e,0xabb0a8f1,0x00000000,0x00000000}},	//   _مدفو, ракә, --, --, 
   {{0xfe740323,0x7d08fb05,0x6e340f12,0x9aa0240f}},	//   _бүх_, _exes, _ахах, لموو, 
   {{0x2d80fb06,0x00000000,0x00000000,0x00000000}},	//   _øke_, --, --, --, 
   {{0xdca0fb07,0x48140075,0x6b640124,0xad240131}},	//   _кати, лмис, _акза, _شىئى, 
   {{0x78bc4bc1,0x7ba4007b,0x7aec00df,0x3e4000c0}},	//   åsva, _مصمم, ŝata, _sėti_, 
   {{0x69c425e4,0x45d41de8,0x260c01f9,0x1c180037}},	//   ökes, гонс, ठवली_, _पीटल_, 
   {{0x7a240034,0x00000000,0x00000000,0x00000000}},	//   rótc, --, --, --, 
   {{0xa504010b,0x00000000,0x00000000,0x00000000}},	//   тянл, --, --, --, 
   {{0x2010379d,0x7a240321,0xd7ec0063,0xd40400cf}},	//   xoxi_, móta, _ђу_, аяси, 
   {{0x7a2415b0,0x17980375,0xdc2c00cd,0x3e400064}},	//   lóta, _חיוב, _jñāy, _tėti_, 
   {{0xdb000321,0x798cfb08,0xa5b800d8,0x00000000}},	//   ndná, _ñawt, rmós, --, 
   {{0x65909a52,0x7f9401c6,0xa5b8027a,0xb19400c7}},	// [163d0] _бақу, лаах, rlód, ылтә, 
   {{0xa5b80491,0xdef81c22,0xe61c003a,0x673400a2}},	//   slód, мые_, llô_, _şyjy, 
   {{0xe61c0208,0x8f440117,0x00000000,0x00000000}},	//   olô_, рхуд, --, --, 
   {{0x63b80198,0x443051f7,0x7a2400c7,0xa5b800e5}},	//   ɓuna, lmz_, kóta, llób, 
   {{0x7a24fb09,0xbc180953,0xdb0002d2,0x1048022e}},	//   jóta, нікі_, ddná, _аяси_, 
   {{0x7a3402d5,0xd9d801ad,0x00000000,0x00000000}},	//   _išti, बस्ट, --, --, 
   {{0xbcfc00b8,0x6da00050,0xfa380063,0x7a3401ef}},	//   _deũa, _گۅنم, нчић_, _uštk, 
   {{0xf8a8fb0a,0x1dc41be1,0x7a240a87,0x3e68030d}},	//   евик_, _रचित, fóta, ăшĕн_, 
   {{0x75e4033f,0xf744233a,0x7d0803ac,0xfb84030f}},	//   _józe, лепо, _uxes, _مدای, 
   {{0x87b81de1,0x1cb00135,0x69c400e5,0x75e400e5}},	//   вуют_, _ཟླར_, öker, _móze, 
   {{0x20045946,0xba540114,0x5a440006,0xa3e40210}},	//   čnih_, _свеј, _рэза, पसन_, 
   {{0x44300399,0x7a2401a8,0x7a3400d7,0x00000000}},	//   emz_, bóta, _ošti, --, 
   {{0x1cc8003d,0x4ab401c0,0xe2940131,0x00000000}},	//   ྲའི_, _бөөр, һар_, --, 
   {{0x394cfb0b,0x386cfb0c,0x366801e0,0x49180490}},	//   lces_, mser_, _зако_, _पडतो_, 
   {{0x386c9c48,0xa2e0322f,0x798c0309,0xb80401ed}},	//   lser_, борд, _ñaws, _لکھے_, 
   {{0x394cfb0d,0x386cfb0e,0x6458054e,0xdc0c04af}},	//   nces_, oser_, ţuia, िवुड_, 
   {{0x3124fb0f,0x394cfb10,0x300404b1,0x04940024}},	// [163e0] удаг, ices_, гзаг, _крэў, 
   {{0x1f600026,0xb62c0150,0xac6c0092,0x00000000}},	//   йкум, _ﺒﻜ_, _አልማዝ_, --, 
   {{0x394c033f,0x72040066,0x00000000,0x00000000}},	//   kces_, _مودم, --, --, 
   {{0x386cfb11,0x9ad001f2,0xbe800131,0x6278011a}},	//   kser_, _pịnk, юқси, _אנטנ, 
   {{0x386c019b,0xacf4fb12,0xdb0001bf,0xdc0c00bc}},	//   jser_, دسات, ndnæ, िवूड_, 
   {{0x386c019b,0x7fd40220,0x394cfb13,0x2aa80640}},	//   dser_, _кісі, eces_, етио_, 
   {{0x386cfb14,0xe61c011f,0x7a340010,0x33980150}},	//   eser_, ylô_, _zšti, _ﺘﺤﻤﻲ_, 
   {{0xbf6468e7,0x386c08fb,0x65b8fb15,0x00000000}},	//   _مدہو, fser_, _mähä, --, 
   {{0xfca8fb16,0x1d04fb17,0x386c0158,0x78ac0427}},	//   _لالو_, _бети_, gser_, _šavr, 
   {{0x18940597,0x7a24fb18,0x394cfb19,0xdc9801e4}},	//   اضية_, róta, aces_, _אימל, 
   {{0x2ca40042,0x65b801f4,0x70b00456,0xac9400fb}},	//   lwod_, _nähä, ीमुल, _шаҡш, 
   {{0x394cfb1a,0x2d84fb1b,0x386c05e4,0x21e40254}},	//   cces_, ngoe_, bser_, _kõhe_, 
   {{0xe61c00d8,0xa85416a4,0x95d8020f,0xe468fb1c}},	//   rlô_, _стеј, удят_, эшнл_, 
   {{0x1cb0025c,0x798c02d1,0x65b8415b,0x00000000}},	//   _ཟླས_, _ñawr, _bähä, --, 
   {{0x2d8405ac,0x65b8008e,0x2688007b,0x21e40037}},	//   kgoe_, _cähä, _أختي_, _lõhe_, 
   {{0x7a00005f,0xd24400a8,0x415401c0,0x70b011a0}},	//   vētk, сэри, рвас, ीमूल, 
   {{0xb9ec044e,0x84c4ad0e,0x2a8c03b9,0x3e5006be}},	// [163f0] _ዕዮ_, _тәнд, _dəbi_, _iştə_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x394cfb1d,0x7a344031,0xe0dc01ab,0x75e4033f}},	//   yces_, _ištv, _sgòd_, _wóze, 
   {{0x0dc810ea,0x00000000,0x00000000,0x00000000}},	//   лучи_, --, --, --, 
   {{0xd2640029,0x5578008f,0x2b4c0175,0x4fc40137}},	//   _viņš_, רעדן_, fcfc_, _گەلە, 
   {{0x386cfb1e,0x49180037,0xacb000d1,0xafc001af}},	//   vser_, _पड़ो_, زمىغ, _мәхй, 
   {{0x7a0000da,0x386cfb1f,0x1cc8025c,0x543c008f}},	//   lēti, wser_, ྲའང_, געגא, 
   {{0x386cfb20,0x39443eeb,0xa9d000d1,0x00000000}},	//   tser_, шниг, ققىغ, --, 
   {{0x394cfb21,0x7a00005f,0x499033ae,0x00000000}},	//   rces_, nēti, سیور, --, 
   {{0x394cfb22,0x69c8013d,0x00000000,0x00000000}},	//   sces_, _ıleş, --, --, 
   {{0x94000085,0x7bc01d4f,0xf1200034,0x7a0002b1}},	//   _mpiɔ_, _inlu, _मर्द_, hēti, 
   {{0x1cb049a6,0x386c04c4,0x7a000b10,0x68240d12}},	//   _ཟློ_, pser_, kēti, rðda, 
   {{0xb6040248,0x798c0113,0xa5b80077,0xc95801d5}},	//   _aláá, _ñawq, rmóp, _сўх_, 
   {{0xdb002ab7,0x6d3400df,0xb600013a,0x7a0000de}},	//   rdnæ, יטרא_, _řádc, dēti, 
   {{0x65b80166,0x0ea412eb,0x7a24072d,0x00000000}},	//   _qähä, _गैंड, nóto, --, 
   {{0x65b80664,0x614003fb,0x2ca40042,0x7a000171}},	//   _vähä, жета, ywod_, fēti, 
  
   {{0x7bc0fb23,0xe0dc007f,0xd73405f5,0x3d140490}},	// [16400] _onlu, _agòb_, _шүүх_, _फुले_, 
   {{0x65b80664,0x2f54fb24,0x28d807f7,0x7a340153}},	//   _tähä, ртас, मैटि, _ištu, 
   {{0xdfccfb25,0x2d8401c7,0xfe740137,0x2a8c06be}},	//   بيل_, tgoe_, йүр_, _təbi_, 
   {{0x7bc02d6d,0x7a0000e2,0xc2c4009f,0x00000000}},	//   _anlu, bēti, _ايٽي, --, 
   {{0xe0dc0086,0x7a0000e2,0xa5b801d3,0x2d840036}},	//   _egòb_, cēti, nlóa, rgoe_, 
   {{0xafe40323,0x635000bc,0x00000000,0x00000000}},	//   _тогл, mění, --, --, 
   {{0x7eb4fb26,0x6da40fbe,0xada402a9,0x00000000}},	//   _лётч, _кива, _кавл, --, 
   {{0x7bc08f24,0xb90c0241,0x00000000,0x00000000}},	//   _enlu, _ìlọ_, --, --, 
   {{0xdd8cf629,0x6e200107,0xaba8013e,0x635000bc}},	//   _توق_, mlob, _иваз_, nění, 
   {{0x387801ed,0x6c3000e5,0x00000000,0x00000000}},	//   ásra_, _بہتا, --, --, 
   {{0x7a340006,0x7a00005f,0x00000000,0x00000000}},	//   _aštu, zēti, --, --, 
   {{0x798c0bf1,0xe8f8b592,0x06c801c6,0xd89001d9}},	//   _ñawp, _иле_, вгүй_, _ژٔند, 
   {{0x69c0006f,0x7bc0000f,0xb7b401f2,0x00000000}},	//   _inoe, _ynlu, fọd, --, 
   {{0x981024e0,0x63500118,0x00000000,0x00000000}},	//   _وبوا, dění, --, --, 
   {{0x69c0fb27,0x5ed803d4,0x6e20fb28,0x3c2800d7}},	//   _knoe, _যেনে, klob, núva_, 
   {{0x7a240008,0xd25000aa,0x291003cd,0x7a0000e2}},	//   jótl, ړنې_, _øyas_, tēti, 
   {{0x6e200b6f,0x6b9807de,0xdb000165,0xf0780116}},	// [16410] dlob, _obtg, genê, литә_, 
   {{0x7a0000da,0x6ab80c8c,0x22840137,0x3c280124}},	//   rēti, _ortf, _кумг, kúva_, 
   {{0x3c280124,0x00000000,0x00000000,0x00000000}},	//   júva_, --, --, --, 
   {{0x7cfcfa77,0xdb000158,0x7a0000e2,0x3c28fb29}},	//   _nærø, ndnå, pēti, dúva_, 
   {{0x6ab8fb2a,0xaa4001e0,0x4c840024,0x75e400e5}},	//   _artf, үешл, жлів, _józa, 
   {{0x69c0fb2b,0x6e20fb2c,0x3b080a0e,0x92b43321}},	//   _anoe, alob, лело_, _احیا, 
   {{0xbab411db,0x539c08a8,0x6e2001e4,0xdda80354}},	//   сёлы, דיוו, blob, _итал_, 
   {{0x6e207dcc,0xf99000c6,0xdb000240,0xbe0400e5}},	//   clob, سبب_, lenë, _اورٹ, 
   {{0x6ab802d0,0x68f40024,0x5ba4005b,0x00000000}},	//   _ertf, _žydr, _врез, --, 
   {{0x7bc006f2,0x69c00165,0x37e4499d,0x00000000}},	//   _unlu, _enoe, соог, --, 
   {{0x7cfcfb2d,0x3c280419,0x5aa801f7,0x64a00124}},	//   _færø, cúva_, _جاءَ_, ҟара, 
   {{0xa2c80864,0xdb0001e3,0x00000000,0x00000000}},	//   हमन्, rdnä, --, --, 
   {{0x49b8fb2e,0x7988fb2f,0xe2940032,0xe9cc05d9}},	//   _خالد_, mgew, ҙат_, _سٺو_, 
   {{0x798840e9,0x78a80810,0x6e20013a,0xdce80205}},	//   lgew, mwev, zlob, negı, 
   {{0x86c40451,0x291000fe,0x63800006,0x00000000}},	//   _ويهن, _øyar_, ягра, --, 
   {{0xb144c100,0xa5b80f71,0x63500118,0xd76001e2}},	//   снал, llón, tění, _انګی, 
   {{0xed58016c,0x00000000,0x00000000,0x00000000}},	// [16420] ҳое_, --, --, --, 
   {{0xe0dc0100,0xb640005e,0x798817da,0x6d5405d1}},	//   _afòs_, _ﺃﻭ_, hgew, ıyam, 
   {{0x6e20fb30,0x79881f9e,0x78a80099,0xed587b0a}},	//   tlob, kgew, hwev, гое_, 
   {{0x79880cf9,0x78a8fb31,0xdb002561,0x49180073}},	//   jgew, kwev, menè, _पडलो_, 
   {{0x7988fb32,0x6e20fb33,0xa5b80cde,0x5c700816}},	//   dgew, rlob, klón, зліт, 
   {{0x69c0fb34,0x80d000bd,0xef18010b,0x79883ce6}},	//   _snoe, _সেক্, _бмг_, egew, 
   {{0x798809db,0xb7b4063f,0x7cd0002b,0x200c06af}},	//   fgew, kọb, _aśrā, égie_, 
   {{0x7988fb35,0x2bd81414,0x49d80b01,0x3c280588}},	//   ggew, _बकवा, рдию_, rúva_, 
   {{0xdd8cfb36,0x16f003bd,0x3c28dc99,0x78a80564}},	//   _سول_, _བཟུམ_, súva_, gwev, 
   {{0x38a8045f,0x79889da5,0x3c2800c7,0xdce803e0}},	//   _dźr_, agew, púva_, cegı, 
   {{0xfd4c01f2,0xdb00007f,0xf3fc0154,0x7988fb37}},	//   _nshọ, jenè, ংকার_, bgew, 
   {{0x56903f51,0x69c0fb38,0xdb000ba1,0x6a1400db}},	//   чают, _unoe, denè, _ابئر, 
   {{0x999c4a4a,0x692407cf,0xa5b80030,0x8cb0012d}},	//   lmuş_, _умда, blón, _आईफो, 
   {{0xa5b829d3,0x78bc01bf,0x06d00011,0x69940345}},	//   clón, æsve, ানবি, _ئێکس_, 
   {{0x999c07b3,0xdb00fb39,0x7a340006,0xc32000fe}},	//   nmuş_, genè, _ištr, ফেনি_, 
   {{0x2a8c03be,0xd674009f,0x00000000,0x00000000}},	//   _həbs_, _احوا_, --, --, 
   {{0x656cfb3a,0x26dc003a,0xa5b8002e,0x3ff806ed}},	// [16430] mach, lyto_, llóo, анаќ_, 
   {{0x656cfb3b,0x999c05d2,0x27fcfb3c,0x4fd4004e}},	//   lach, kmuş_, nitn_, пжут, 
   {{0x543c04ac,0x61e00276,0xdb0083c5,0x656c009f}},	//   _געזא, _înlo, cenè, oach, 
   {{0x63a4fb3d,0x6284fb3e,0xbd8400db,0xf5300092}},	//   lejn, mujo, تەرۇ_, _በፕሬዚ, 
   {{0x7a34098d,0x6284fb3f,0x656cb5f6,0xdb00fb40}},	//   _oštr, lujo, iach, mené, 
   {{0xdb00fb41,0x61fcfb42,0x9b68086f,0x26dc13aa}},	//   lené, liql, ушда_, kyto_, 
   {{0x7988fb43,0x6284fb44,0xd90c01e2,0xc94401e1}},	//   tgew, nujo, ډیا_, _ẹbọr, 
   {{0x61fcfb45,0x63a4fb46,0x656cfb47,0x7a340024}},	//   niql, hejn, jach, _aštr, 
   {{0x656cfb48,0x798885de,0x244c29ef,0x8c5400cf}},	//   dach, rgew, _nüm_, _فئلا, 
   {{0x6284fb49,0x7988fb4a,0x61fc01b9,0x63a4fb4b}},	//   kujo, sgew, hiql, jejn, 
   {{0x656c22a9,0x63a4aaca,0xcbc80050,0x38a8002d}},	//   fach, dejn, _دِلو_, _wźr_, 
   {{0x656cfb4c,0x628408e7,0xdb00fb4d,0x61fc01a9}},	//   gach, dujo, jené, jiql, 
   {{0xdb00edbd,0xf1a804d3,0x63a4b9bd,0x244c06be}},	//   dené, یاره_, fejn, _cüm_, 
   {{0x3ea402d3,0x656c01ab,0x4cdc00cc,0xdb000100}},	//   _ወጋሕታ_, aach, _মেডু, tenè, 
   {{0x656cfb4e,0xc744179c,0x61fc036b,0x0fe80220}},	//   bach, _عضوي, fiql, ұлақ_, 
   {{0x61fc0357,0x244c05d5,0xb224fb4f,0xb7b401f2}},	//   giql, _füm_, імал, bọc, 
   {{0x63a4fb50,0x826002d3,0x7e7400b5,0x244c496e}},	// [16440] bejn, _ጉጅለታ, _avzp, _güm_, 
   {{0x6284fb51,0xb4e42122,0x13a820d3,0xa5b800d2}},	//   bujo, पनी_, _اندی_, hlól, 
   {{0xdb002358,0x61fc2bcc,0x7f480166,0x59bc04af}},	//   bené, biql, _ğeqt, _शोभर, 
   {{0x244c29ef,0xdb00fb52,0x61fc0139,0x00000000}},	//   _yüm_, cené, ciql, --, 
   {{0xa6dc001e,0x21e40254,0x0dcc0092,0x244c0139}},	//   _ngưn, _kõhn_, _በአፍ_, _xüm_, 
   {{0x656c0161,0x2714012c,0x999c3535,0x7c38004b}},	//   zach, něné_, tmuş_, مينځ_, 
   {{0x656cfb53,0xee9003e6,0xf1340137,0x75e4012d}},	//   yach, _زگاک, _دةگة, _rózn, 
   {{0x999cfb54,0x7a2400c6,0xbd7c02d3,0x63a4fb55}},	//   rmuş_, nóth, _ከምቶም_, zejn, 
   {{0x656cfb56,0x63a402d3,0x9b040032,0x7a340306}},	//   vach, yejn, йнәб_, _pštr, 
   {{0xc7b8b485,0xdb00fb57,0x7a24007b,0xa09808a8}},	//   kođe_, zené, hóth, סייט, 
   {{0x656cfb58,0x61fc439e,0x7a340010,0x628401c4}},	//   tach, yiql, _vštr, xujo, 
   {{0x68e4036b,0xdb000005,0x656c5a50,0x27fc03b2}},	//   _мўлж, xené, uach, sitn_, 
   {{0x63a4fb59,0xdb000122,0x8504014d,0x628401e2}},	//   tejn, vené, سوسن, wujo, 
   {{0x656cfb5a,0x6284fb5b,0x9c80012c,0xb86446bc}},	//   sach, tujo, _účet, _راهو, 
   {{0x656cd7a7,0x63a40038,0x61fca67c,0xdcf800e2}},	//   pach, rejn, tiql, _sauļ, 
   {{0x244c079d,0x656cfb5c,0x5334c23f,0x63a42a6d}},	//   _tüm_, qach, фест, sejn, 
   {{0xdb00fb5d,0x61fcfb5e,0xc0c40131,0x27140118}},	// [16450] rené, riql, чәни, běné_, 
   {{0x61fcfa80,0x62840789,0xe45c023a,0x3868fb5f}},	//   siql, pujo, mpö_, _çare_, 
   {{0xdb002358,0x61fc01a9,0x249c031c,0x00000000}},	//   pené, piql, ħumu_, --, 
   {{0x61fc1571,0x3c2800e4,0x00000000,0x00000000}},	//   qiql, túvo_, --, --, 
   {{0x69cc7df0,0xbcfc0055,0xfbc4234c,0x4420002f}},	//   थानी, _keũi, збло, _kkh_, 
   {{0x7a2409e8,0x442002d2,0x3c280124,0xd01800f3}},	//   móti, _jkh_, rúvo_, _дфс_, 
   {{0xd9ac0183,0x539c008f,0x2a8c0213,0x3c280022}},	//   কাসম, יסגא, _səbr_, súvo_, 
   {{0xddc00014,0x4420002f,0x3c280022,0x00000000}},	//   _تٍری, _lkh_, púvo_, --, 
   {{0x0e440276,0x2a8c03b9,0x7a2406ea,0x00000000}},	//   _цэрм, _qəbr_, nóti, --, 
   {{0xe8f4fb60,0xfc1401c0,0x75e41a1f,0x00000000}},	//   ялы_, _эмзэ, _pózo, --, 
   {{0x98a8046c,0x2714012c,0xf62407d8,0x1cc8031c}},	//   ımız_, věné_, здно, ྲའམ_, 
   {{0x4420fb61,0x7a0000e2,0xc7b807f5,0xe85001b9}},	//   _akh_, rēts, vođe_, بنید, 
   {{0xe690fb62,0xb4e421f2,0x7a24041e,0x3f90033f}},	//   ولید, पने_, jóti, _oczu_, 
   {{0x75e402ea,0xd11c17e6,0x442001bf,0x3eb000e5}},	//   _tózo, _भुषण_, _ckh_, _oszt_, 
   {{0x44200280,0x00000000,0x00000000,0x00000000}},	//   _dkh_, --, --, --, 
   {{0x44201992,0x69cc0fe6,0xe294009d,0x7a2402d2}},	//   _ekh_, थायी, яас_, fóti, 
   {{0x7a245178,0x4420fb63,0xa0a0023b,0x2450007b}},	// [16460] góti, _fkh_, натд, _كنيس, 
   {{0x054400db,0x00000000,0x00000000,0x00000000}},	//   _تئىپ, --, --, --, 
   {{0x200cfb64,0x7c8c0092,0x00000000,0x00000000}},	//   égia_, _ዘልለው_, --, --, 
   {{0x5ed8015b,0x442001f5,0x13a80066,0x00000000}},	//   _যেহে, _zkh_, _انگی_, --, 
   {{0x7a247917,0x2254fb65,0x4c9428a8,0x1d040114}},	//   cóti, _ولید_, филс, пеци_, 
   {{0xaa64fb66,0xe2c80244,0x00000000,0x00000000}},	//   птик, _ئایۆ_, --, --, 
   {{0xed5800d8,0x00000000,0x00000000,0x00000000}},	//   _гоб_, --, --, --, 
   {{0x644804cc,0xe0dc007f,0x00000000,0x00000000}},	//   _ègig, _ogòl_, --, --, 
   {{0xed3401c0,0xf8ac004b,0x00000000,0x00000000}},	//   _хэвэ, لکو_, --, --, 
   {{0xd7f47fb5,0xc6140bc0,0xc7f800d4,0x00000000}},	//   зую_, णक्य_, іннє_, --, 
   {{0x47347724,0x2124001e,0xdc3800c8,0xb6a0054e}},	//   ьнос, ́nh_, _פעבר, ţând, 
   {{0x442001a6,0xa5b8fb67,0x00000000,0x00000000}},	//   _skh_, plóm, --, --, 
   {{0x442001f9,0xe4c4005b,0x81dc03d4,0xa5b801d3}},	//   _pkh_, чённ, থোঁ_, llók, 
   {{0x29200327,0x00000000,0x00000000,0x00000000}},	//   ċpaċ_, --, --, --, 
   {{0xe45c0c86,0x3170022e,0x9798011a,0x48e40118}},	//   spö_, fayz_, _השוק, टनको_, 
   {{0x7a248607,0xb8840118,0xdb00353e,0xe45c01f4}},	//   tóti, spíš, rdnø, ppö_, 
   {{0xa5b800d2,0x442001f4,0xbfd800d4,0x00000000}},	// [16470] hlók, _tkh_, одає_, --, 
   {{0x4420fb68,0xb0340116,0x8fa40063,0x73c001ee}},	//   _ukh_, дмуә, нађе, _иәсе, 
   {{0xbef807b6,0x00000000,0x00000000,0x00000000}},	//   ्पेन_, --, --, --, 
   {{0xd0100014,0x8db40150,0x00000000,0x00000000}},	//   ٖلے_, есші, --, --, 
   {{0xd59c010f,0x00000000,0x00000000,0x00000000}},	//   מבאל, --, --, --, 
   {{0xfaa4016c,0x9f5001f4,0x00000000,0x00000000}},	//   дако, ädät_, --, --, 
   {{0x34a8085c,0xaa54007b,0x00000000,0x00000000}},	//   _छन्द, ولوا_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf8a8034c,0xdb000ab9,0xdcf80166,0x57900022}},	//   تگاه_, mení, _tauı, нынӡ, 
   {{0xdb0028cb,0x63b40009,0x7bf800db,0x62400142}},	//   lení, _naxn, _بىئز_, _sŵol, 
   {{0xa64402d3,0x79580166,0xda6416ac,0xd7607aaf}},	//   _ፕረዝደ, _диер_, _رااي, ونکی, 
   {{0xdb000030,0x28ac0bc0,0xd1d40092,0x00000000}},	//   není, _जैवि, ከቱት_, --, 
   {{0x63b40014,0x41d007f7,0x77a401d9,0x00000000}},	//   _baxn, हानस, _ہێکہ_, --, 
   {{0xf7707146,0xe1fc0429,0x3170037e,0x68e42ab7}},	//   _شات_, _amó_, wayz_, økde, 
   {{0x63b40007,0xe818000d,0x994002f2,0x00000000}},	//   _daxn, नकरा_, _تێکه, --, 
   {{0xdb000122,0x290c05be,0x00000000,0x00000000}},	//   jení, šmaš_, --, --, 
   {{0xdb000232,0x63b4fb69,0x3170003e,0x312401b9}},	// [16480] dení, _faxn, rayz_, фдаг, 
   {{0x7a240008,0x00000000,0x00000000,0x00000000}},	//   mótu, --, --, --, 
   {{0x442c02a8,0x00000000,0x00000000,0x00000000}},	//   ɓe_, --, --, --, 
   {{0xa644044e,0x2d900e2d,0x63b401a9,0xdb000525}},	//   _ፕረዚደ, üye_, _zaxn, gení, 
   {{0x3eac04b9,0x998c0006,0x798c0113,0x63b4022e}},	//   _ćete_, _ligų_, _ñawy, _yaxn, 
   {{0x2ac4026a,0xdcf800ef,0x3074014b,0x00000000}},	//   дљив, _lauķ, _нуҳс, --, 
   {{0x2d9407d6,0xdb0002fb,0xed5802bf,0x59bc924b}},	//   _орас, bení, _мов_, _शोहर, 
   {{0x80b40034,0xdb0000bc,0xa5b801d3,0x41d000cd}},	//   _उनमे, cení, rlók, हायस, 
   {{0x1d040228,0xad24f05c,0x7a240321,0xec140137}},	//   _жети_, _آرزو, jótu, _قورد, 
   {{0xa5c40077,0x61d828b8,0xa29002d3,0xa5b80332}},	//   _opóñ, _यक्ष, _ውግእን_, mlói, 
   {{0xa5b8007b,0x63b401a9,0x17f4007b,0xdce81a14}},	//   llói, _raxn, برية_, magā, 
   {{0x63b42db1,0x9f4801a8,0xa5b80332,0xc7b80051}},	//   _saxn, _ólöf_, olói, sdđ_, 
   {{0x2fc80175,0xa5b80332,0x00000000,0x00000000}},	//   _onbg_, nlói, --, --, 
   {{0xdb00012c,0x38680724,0x63b40009,0x57a001d5}},	//   zení, _çara_, _qaxn, _ашъа, 
   {{0x9258fb6a,0x482419c5,0x63b401e3,0xa5b80332}},	//   даст_, _قىچق, _vaxn, hlói, 
   {{0x63b4fb6b,0x7a2408a5,0x00000000,0x00000000}},	//   _waxn, bótu, --, --, 
   {{0xdb00fb6c,0xd2440262,0x63b41dd0,0x28b400e1}},	// [16490] vení, тэри, _taxn, _अनफि, 
   {{0x645c0d04,0x00000000,0x00000000,0x00000000}},	//   _itqi, --, --, --, 
   {{0xdb00fb6d,0xdce83da0,0x00000000,0x00000000}},	//   tení, dagā, --, --, 
   {{0x2fc40421,0x6284000f,0xe8ec01ec,0x00000000}},	//   ēoga_, mrjo, _әлi_, --, 
   {{0x11289416,0xdb000030,0x660c0113,0x6284002d}},	//   _жюри_, rení, inck, lrjo, 
   {{0xdb000122,0x7a240162,0x4fc4022e,0x00000000}},	//   sení, hótt, _исса, --, 
   {{0xdb0c01b8,0xe7d0fb6e,0xdb00fb6f,0x3ce85160}},	//   _ädüt, तानप, pení, šav_, 
   {{0xc7b808ad,0xa5b8007b,0x030c004d,0x7a240bcd}},	//   vođa_, blói, _đều_, jótt, 
   {{0x7a24fb70,0x1cb00dd4,0x81b80729,0xa5b80597}},	//   dótt, _ཟླཝ_, চাপ_, clói, 
   {{0x6284045f,0x998c00c0,0x00000000,0x00000000}},	//   krjo, _pigų_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe9cc0510,0x560401ec,0x00000000,0x00000000}},	//   _ёк_, томұ, --, --, 
   {{0xe8ecfb71,0x8ee00011,0x34200116,0x00000000}},	//   _сл_, _যোগ, лҗиғ, --, 
   {{0x61ec0072,0x7d1c06ea,0xb60000bc,0x6284000f}},	//   _alcl, _øssu, _žáda, frjo, 
   {{0xd34807d6,0x35a43163,0x00000000,0x00000000}},	//   بیده_, _зайг, --, --, 
   {{0x23240672,0x00000000,0x00000000,0x00000000}},	//   хоси_, --, --, --, 
   {{0x69c80724,0x6284fb72,0xa3fc0118,0x850401d3}},	// [164a0] _öleş, arjo, řeší_, _لوٹن, 
   {{0x61ec0789,0x76940432,0x00000000,0x00000000}},	//   _elcl, _güyç, --, --, 
   {{0x28b41d03,0x64580311,0x35d000cc,0xdee001fe}},	//   _अनभि, ţuit, াসীহ, лофи, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb20145e,0xfa14015b,0xd0440124,0xdb000030}},	//   îrîm, াতাল_, _аҭак, rdný, 
   {{0xa5b8fb73,0x68040ca8,0xb0340116,0x00000000}},	//   rlói, _méjè, _سىزغ, --, 
   {{0xa6e40208,0xe9e40d1d,0x00000000,0x00000000}},	//   _chử, ецпо, --, --, 
   {{0x9aa00592,0x21e40037,0xad64009f,0x99940395}},	//   اميو, _rõhk_, _ساره, екът_, 
   {{0x6c84fb74,0x7d2000e5,0x00000000,0x00000000}},	//   _سلام, _پہون, --, --, 
   {{0x6e20fb75,0xdbc40037,0x00000000,0x00000000}},	//   loob, _söös, --, --, 
   {{0x41e007f7,0x97a05443,0x7aec01e4,0xdb4c009f}},	//   _नवलस, урыл, ŝatr, _اَم_, 
   {{0x6e20fb76,0x00000000,0x00000000,0x00000000}},	//   noob, --, --, --, 
   {{0x7a241bb0,0xdb002b57,0x6fb01fbc,0x00000000}},	//   rótt, mená, ीयां, --, 
   {{0xd940c1cd,0x6e20fb77,0x660c00ca,0xdb0028cb}},	//   _сечи, hoob, snck, lená, 
   {{0xdbc4007d,0xa5b843f9,0x6e20fb78,0x00000000}},	//   _töös, dlóv, koob, --, 
   {{0x6284045f,0xdb0000e4,0x6e20fb79,0xd628009b}},	//   rrjo, nená, joob, _поје_, 
   {{0x6e200050,0x62840a85,0xe5b00046,0xc61c1f14}},	// [164b0] doob, srjo, _айқы, नवीय_, 
   {{0x94d40354,0x00000000,0x00000000,0x00000000}},	//   _соьц, --, --, --, 
   {{0x6e20fb7a,0x628400b5,0x81b800cc,0x12e40006}},	//   foob, qrjo, চাব_, _біяг, 
   {{0x6e20fb7b,0x216400d4,0x5e2400f7,0x00000000}},	//   goob, _ятог, رعاق, --, 
   {{0x6728008c,0xdb000122,0x06e4009e,0x00000000}},	//   _lyfj, dená, _ফেমি, --, 
   {{0x67280158,0x3dc805d9,0xe0dc004d,0xdb0000db}},	//   _oyfj, _ڪورٽ_, _ngòi_, tenà, 
   {{0x2248fb7c,0x6e20fb7d,0xdcf801a6,0x8f342fc3}},	//   _kick_, boob, _iduč, _берц, 
   {{0x25b801d5,0xa82000f1,0x4cd800cc,0x00000000}},	//   _naql_, یکون, _দেওঁ, --, 
   {{0x3dcc0921,0x9ba01c5c,0x2248045a,0x00000000}},	//   _inew_, _مەشى, _mick_, --, 
   {{0x391400aa,0x37e4fb7e,0x672803cd,0x113c0375}},	//   _یواز, тоог, _byfj, התחל, 
   {{0x3a746f32,0x8f9c008f,0xa0180008,0x3dcc0375}},	//   _рлер, ליזי, _tvöf, _knew_, 
   {{0x2248fb7f,0xd1cc0092,0xdb00022a,0x7a240210}},	//   _nick_, ጠበት_, cená, róts, 
   {{0x1cac0d46,0x08e401d9,0x672802d2,0xa018032e}},	//   _ཐགས_, _مسوَ, _eyfj, _kvöd, 
   {{0x6e201418,0x00000000,0x00000000,0x00000000}},	//   zoob, --, --, --, 
   {{0x23241920,0x3dcc0073,0x6e20fb80,0x55c43e25}},	//   вори_, _onew_, yoob, _байғ, 
   {{0x2128038e,0xd764021f,0x22480051,0x6e200009}},	//   _bych_, _تەگى_, _cick_, xoob, 
   {{0x6e200306,0x64580311,0x2248fb81,0xb14421cc}},	// [164c0] voob, ţuir, _dick_, тнал, 
   {{0xa0a0fb82,0x3dcc30c3,0x1f60fb83,0x2128fb84}},	//   рафд, _anew_, икум, _dych_, 
   {{0x22480628,0x6e20fb85,0x395c0004,0x3dcc0135}},	//   _fick_, toob, _ofws_, _bnew_, 
   {{0x22480628,0x00000000,0x00000000,0x00000000}},	//   _gick_, --, --, --, 
   {{0x6e20fb86,0x00000000,0x00000000,0x00000000}},	//   roob, --, --, --, 
   {{0x3dccfb87,0x75e40085,0x5ce00075,0x7a340153}},	//   _enew_, _tózw, شكىل, _išty, 
   {{0x63a0fb88,0xbd0406af,0xdb000118,0x6e200219}},	//   _önne, théâ, tená, poob, 
   {{0xada42820,0x6e208ebb,0x29883acc,0x6da4fb89}},	//   _шабл, qoob, фско_, _шиба, 
   {{0xdb00fb8a,0x7a243b82,0x6d240a11,0x98700022}},	//   rená, tótr, _شعرك, алыц, 
   {{0xdb0021e3,0x00000000,0x00000000,0x00000000}},	//   denæ, --, --, --, 
   {{0x81b802f5,0x7a240077,0x395c0142,0x49a401ec}},	//   চাত_, rótr, _ffws_, _былғ, 
   {{0xe7e003d4,0x67280ea0,0x3a2c003e,0x00000000}},	//   মফেয, _vyfj, clep_, --, 
   {{0x22485909,0xdb001cf3,0x2a8c06be,0x75340210}},	//   _rick_, genæ, _nəbz_, _czyz, 
   {{0x2248fb8b,0x21280142,0x00000000,0x00000000}},	//   _sick_, _rych_, --, --, 
   {{0xaad0084a,0x1cc80135,0x2248fb8c,0xd6cc02f2}},	//   थमिक, ིའོ_, _pick_, _وقه_, 
   {{0x52140953,0xdb000162,0xd68000db,0x96b400f3}},	//   адст, benæ, _тушп, _руљу_, 
   {{0x11540d30,0xdb0003cd,0xc0d40023,0x91b40037}},	// [164d0] ркую, cenæ, _ከርሲ_, _उघरै, 
   {{0x2248fb8d,0x25fc38d2,0x3dcc00b5,0x4fc47c20}},	//   _wick_, शोरी_, _snew_, исха, 
   {{0xdb00fb8e,0x2248fb8f,0x21280368,0xa5b808a5}},	//   menç, _tick_, _wych_, blót, 
   {{0x2128772b,0xdb001497,0x6060192c,0x729402d3}},	//   _tych_, lenç, _نۇرل, _ውልቃዊ_, 
   {{0x8f0c044e,0xbca42085,0x0d841fe2,0x7e6400d8}},	//   _иdя_, امتي, рлін, sphp, 
   {{0x2b5c814b,0x0c2401ce,0xdb0056ed,0xeb94fb90}},	//   _cftc_, амін, nenç, гиш_, 
   {{0x37740184,0xab24fb91,0xca3c00d1,0xdd98024c}},	//   һынс, лоша_, ﻐﯘﺭ_, _оша_, 
   {{0x427c0020,0xb6a40075,0xc5f8005f,0x53380375}},	//   _እውነት_, қимл, spēj_, כנון_, 
   {{0x3774fb92,0x3cf805ac,0x3a2c017a,0x6f0001e4}},	//   лынс, _åsv_, rlep_, ĝoce, 
   {{0xe8f40323,0x69dc06af,0x4cdc00fe,0xa5b802cc}},	//   уль_, êper, _মেকু, klós, 
   {{0xb9940597,0xdb00fb93,0xd1cc001f,0x3a2c003e}},	//   _ملاب, denç, ጠበቀ_, plep_, 
   {{0x3834005e,0x21e40037,0x00000000,0x00000000}},	//   _өнер, _kõhu_, --, --, 
   {{0xdb00067c,0x98bc0003,0x00000000,0x00000000}},	//   fenç, bbuġ_, --, --, 
   {{0x8704249f,0x44140816,0xdb00699d,0xdc2c00ef}},	//   ابیل, афст, renæ, džīn, 
   {{0xd1740032,0xb6a41563,0x21e40254,0x28100753}},	//   ҫығы, _сийл, _lõhu_, _دووس, 
   {{0xaf342002,0xd16402dd,0x75e402f0,0xdb00fb94}},	//   ۇرات, рнақ, _pózu, menä, 
   {{0x2a8c06be,0xdb000166,0x00000000,0x00000000}},	// [164e0] _qəbz_, lenä, --, --, 
   {{0xdb0003b7,0x6448067c,0xb02802ef,0x52b400db}},	//   cenç, _égip, ركام_, _پەرئ, 
   {{0xa0a0fb95,0xdb001057,0xdfcc16a2,0x2c18012d}},	//   _қард, nenä, ثيل_, _बदबू_, 
   {{0x2010fb96,0xa5b83b82,0x2fd800b5,0xdd8cfb97}},	//   anxi_, llór, sjpg_, كوم_, 
   {{0x0cd4fb98,0xdb00000d,0x41d00303,0x00000000}},	//   ролю, henä, हारस, --, 
   {{0xdb00007c,0x00000000,0x00000000,0x00000000}},	//   kenä, --, --, --, 
   {{0x1cc80135,0xdb00014a,0x75e401ed,0xdee01069}},	//   ིའུ_, jenä, _józs, _лори, 
   {{0x2c7401d3,0xdb000108,0x3ea401e3,0x00000000}},	//   _مُرس, denä, _älta_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x37500075,0xdb000137,0x799802d0,0x00000000}},	//   يھىس, xenç, _ecww, --, 
   {{0xdb00fb99,0x21e400c5,0xe968011c,0x00000000}},	//   venç, _kõht_, _заел_, --, 
   {{0xd1cc0020,0x244c0327,0xa5b80120,0x7ae4fb9a}},	//   ጠበቅ_, _ażma_, coól, ähte, 
   {{0xdb0003b7,0xa5b802d2,0x9484113e,0xd7c40133}},	//   tenç, flór, йырд, _ڕووه_, 
   {{0xe19030af,0xdb00fb9b,0xf8ac01f7,0x00000000}},	//   өлгө, uenç, _آکي_, --, 
   {{0xdb00fb9c,0xd6ccfb9d,0x4ab40073,0x41d00118}},	//   renç, _ут_, ंबिव, हालस, 
   {{0xdb00fb9e,0x6ab80205,0x75e400e5,0x00000000}},	//   senç, _mstf, _dózs, --, 
   {{0x15a800a7,0xd6cc00cf,0x00000000,0x00000000}},	// [164f0] _същи_, _وقۇ_, --, --, 
   {{0x21e40037,0x78bc003b,0xa5b801e7,0x4ab40073}},	//   _rõhu_, æsvi, clór, ंबाव, 
   {{0x4ea401c6,0x7d540395,0x183400df,0x00000000}},	//   йрца, авех, נאבל_, --, 
   {{0x4430fb9f,0x00940150,0x00000000,0x00000000}},	//   llz_, _кимэ, --, --, 
   {{0x6ab8fba0,0x3178010f,0xdb0001e3,0xddc800c0}},	//   _astf, _בארד, ndnö, _šiųm, 
   {{0xa3c83f6f,0x1dd40032,0x35840023,0x00000000}},	//   _रोम_, _өлгө_, ሬታታት_, --, 
   {{0xdb000158,0xa2d807f7,0xff2800ae,0x00000000}},	//   kenå, नहट्, _شكري_, --, 
   {{0x44300369,0xdb00005b,0x386803e0,0x00000000}},	//   hlz_, venä, _çark_, --, 
   {{0xf7707427,0xe9d4fba1,0x6ab89b9b,0xfb8402f2}},	//   ياد_, ркы_, _estf, _ندای, 
   {{0xdb00fba2,0x59d00316,0xb788013d,0x00000000}},	//   tenä, थाहर, тәде_, --, 
   {{0x1ac80184,0xb6a4036b,0x55c401e0,0xdb000112}},	//   _яуап_, шинл, банғ, uenä, 
   {{0x78b80070,0x75e401ed,0x00000000,0x00000000}},	//   _tswv, _rózs, --, --, 
   {{0x1cc81e81,0xdb00fba3,0xf8a800af,0xe6147e7e}},	//   ིའི_, senä, _कहिय, рдя_, 
   {{0x4430030d,0xe70404d3,0xdb00014a,0xf74401d5}},	//   glz_, اسیی, penä, _кело, 
   {{0xa2e0fba4,0x41d00d41,0xe7b00451,0xe7d01fc4}},	//   оорд, हांस, _ذميد, तारप, 
   {{0x71640597,0xe294147e,0x443068a9,0x26c80fac}},	//   شارك, јат_, alz_, æboe_, 
   {{0x3004fba5,0x4430020c,0x2f544ae5,0x00000000}},	// [16500] азаг, blz_, атес, --, 
   {{0x44300354,0xdb000254,0xe538011a,0x00000000}},	//   clz_, ldnõ, _בתפר, --, 
   {{0xdfcc0979,0x4e8c02d3,0xf8d000cd,0x00000000}},	//   ظيم_, _ኣውራጃ_, तमुप, --, 
   {{0x6da4fba6,0x28b402ab,0x00000000,0x00000000}},	//   рида, _अनलि, --, --, 
   {{0xa3c806ab,0x61e8012b,0x7e680122,0x386800a2}},	//   _रोड_, ögle, _čepe, _çarh_, 
   {{0xd1f0001f,0x00000000,0x00000000,0x00000000}},	//   ጂዎች_, --, --, --, 
   {{0x81b803f4,0x6e440408,0x00000000,0x00000000}},	//   চার_, _вевз, --, --, 
   {{0xa8a4fba7,0x7bcc00b0,0x00000000,0x00000000}},	//   арок, ēaua, --, --, 
   {{0xfca8fba8,0x290005da,0xca7002f2,0xec480454}},	//   _مالو_, àka_, _کۆبک, _азал_, 
   {{0x3a3c009a,0xdcf80135,0xdcac13bd,0x00000000}},	//   _ehwp_, _sbuħ, _تىك_, --, 
   {{0x6ab8fba9,0xdb0005ac,0x52e00118,0x00000000}},	//   _ustf, tenå, नहोस, --, 
   {{0xa8880116,0xa9688726,0x260400d4,0xa5b802d2}},	//   _айда_, _рида_, рчог, glóp, 
   {{0x98a0fbaa,0x00000000,0x00000000,0x00000000}},	//   _мице, --, --, --, 
   {{0xdb00e155,0x25bc107d,0x9388030d,0xd90c5598}},	//   senå, žul_, исса_, _زیپ_, 
   {{0xe8b474c8,0xe2900014,0x418400fb,0x00000000}},	//   _अनुच, غذس_, йтағ, --, 
   {{0xc10452c8,0x42a40032,0x41540aac,0x46140066}},	//   موزي, _һумғ, свас, _دوبر, 
   {{0x80d006ab,0x44300076,0x4394f3f5,0x81b80154}},	// [16510] समें, plz_, _лапс, চাল_, 
   {{0x4fd40212,0x2004068c,0x656c022e,0xb8840139}},	//   ожут, òni_, lbch, lmíç, 
   {{0x656c0232,0x10480212,0x00000000,0x00000000}},	//   obch, ряти_, --, --, 
   {{0x66e803be,0x00000000,0x00000000,0x00000000}},	//   məkd, --, --, --, 
   {{0x71d4011a,0x656c002f,0xa6ac00fe,0x66e803e3}},	//   _הורד_, ibch, য়মিয়, ləkd, 
   {{0xdb000030,0xacb000d1,0xf8c800d7,0x00000000}},	//   menú, سمىغ, ntéš_, --, 
   {{0xd90c066d,0x1cc8025c,0xdb20035c,0xaf4801d9}},	//   ڈیا_, ིའང_, غوبی, _مشٲل_, 
   {{0x9f400023,0xd90c5297,0x00000000,0x00000000}},	//   _lojë_, ویا_, --, --, 
   {{0xb7b401f2,0x628c01e1,0x00000000,0x00000000}},	//   kọt, _ńkò, --, --, 
   {{0x7ba400cc,0x00000000,0x00000000,0x00000000}},	//   _গোৰো, --, --, --, 
   {{0x7bc003a2,0x290076ad,0x5bb00c6e,0xf624004e}},	//   _ialu, úkar_, ंजीव, йдоо, 
   {{0x7bc0fbab,0x66e806be,0x00000000,0x00000000}},	//   _halu, dəkd, --, --, 
   {{0x9f40036e,0xab78022e,0x00000000,0x00000000}},	//   _bojë_, _yo鼠l, --, --, 
   {{0xe360fbac,0x093400c6,0xdb00004e,0xa854011a}},	//   зкри, _برمج, denú, _פיצה_, 
   {{0x7bc0fbad,0x9f400240,0x656c01e3,0xfba800cd}},	//   _malu, _dojë_, bbch, च्यम, 
   {{0x7bc0fbae,0xd3780210,0x00000000,0x00000000}},	//   _lalu, źć_, --, --, 
   {{0xe0dc00a3,0xe45c01e3,0xa064004e,0x00000000}},	// [16520] _sgòr_, lvön_, йата_, --, 
   {{0x7bc032ff,0x9f400023,0x2f54fbaf,0x76440af9}},	//   _nalu, _gojë_, стас, lmky, 
   {{0x66e803be,0x00000000,0x00000000,0x00000000}},	//   cəkd, --, --, --, 
   {{0x7bc0fbb0,0xa698010f,0x00000000,0x00000000}},	//   _aalu, טשעפ, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x80b01823,0x68f4033f,0xab78022e,0x3ebc01f4}},	//   _تەكش, _żydo, _qo鼠l, äytä_, 
   {{0x7bc0fbb1,0x09bc00cc,0x00000000,0x00000000}},	//   _dalu, _আচবা, --, --, 
   {{0x7bc00421,0x6aa804c5,0x7ae40037,0x00000000}},	//   _ealu, কিলো, ähta, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7bc0fbb2,0x6c34193a,0xdca0728c,0x60b800df}},	//   _galu, _افطا, _хафи, נציד, 
   {{0x69f00220,0xe9a40724,0xbb2c0131,0xe784020a}},	//   _нүкт, _гаеп, ﺩﯨﻦ_, _ғуло, 
   {{0x7bc0fbb3,0x06c80323,0x00000000,0x00000000}},	//   _zalu, ггүй_, --, --, 
   {{0x7bc0fbb4,0x656c0112,0x26c800df,0x00000000}},	//   _yalu, rbch, ŭbo_, --, 
   {{0x69c0fbb5,0x77600381,0x7bc0fbb6,0x183000cf}},	//   _haoe, cclx, _xalu, _ىروح, 
   {{0x6fd010f7,0xd6cc9b0f,0x69c0a28f,0x37c0035b}},	//   साईं, _эт_, _kaoe, _цәыб, 
   {{0xe8c40135,0xdb00002d,0x66e80213,0x00000000}},	//   _ཀློག, tenú, rəkd, --, 
   {{0x660c03c6,0x69c0fbb7,0xd0d40395,0x00000000}},	// [16530] mick, _maoe, потъ, --, 
   {{0xdef80b32,0x69c0030a,0x00000000,0x00000000}},	//   лые_, _laoe, --, --, 
   {{0x7bc0fbb8,0x7eb800fb,0x66e806be,0x9754011a}},	//   _ralu, ргес_, ləkb, ציאו_, 
   {{0x660c0745,0x69c008e7,0x6444045f,0x00000000}},	//   nick, _naoe, lmji, --, 
   {{0x7bc0fbb9,0xdb000158,0xd3fc00fe,0x53f810e8}},	//   _palu, lenø, ঁচৰি_, _ضریح_, 
   {{0xdfd80c04,0x660cfbba,0x547c008f,0xb7b4063f}},	//   _съм_, hick, נטוו, họr, 
   {{0x7bc00fa9,0x69c00086,0xb7b4063f,0xce9400a7}},	//   _valu, _baoe, kọr, _наръ, 
   {{0x7bc0fbbb,0x39e87696,0xb9e8ee7d,0x3e180276}},	//   _walu, рдио_, рмиз_, _тобэ_, 
   {{0x660c0232,0x6444002d,0x05dc11a0,0x5ba40108}},	//   dick, kmji, यानब, _грез, 
   {{0x69c00295,0x7bc0fbbc,0xdb0003cd,0xaf7400df}},	//   _eaoe, _ualu, kenø, ֿערס_, 
   {{0x660c03c6,0x55c401ec,0x9a8401ee,0x00000000}},	//   fick, панғ, _ыуал, --, 
   {{0x660c03c6,0x69c027be,0x188000d1,0x5ef8009e}},	//   gick, _gaoe, _еңин, _আশাও_, 
   {{0x5fb804af,0x00000000,0x00000000,0x00000000}},	//   ैयाल, --, --, --, 
   {{0x386cfbbd,0x070800ec,0xa01808a5,0x00000000}},	//   mper_, _ڏيهي_, _svön, --, 
   {{0xe8b40156,0x660cfbbe,0x69c00165,0x386cfbbf}},	//   _དགོག, bick, _yaoe, lper_, 
   {{0x660c13d5,0x64440009,0x386cc606,0x716801c6}},	//   cick, amji, oper_, рааг_, 
   {{0x386c1529,0xa0a000c2,0x7e680064,0x2c1801f9}},	// [16540] nper_, матд, _čepa, _बदलू_, 
   {{0x386c06af,0x1dcc0490,0xe3b001d5,0xd370075e}},	//   iper_, _सोबत, _قرپ_, _سۇر_, 
   {{0x386c0240,0x200c068c,0x92e800cc,0x00000000}},	//   hper_, ègia_, _মেৰ_, --, 
   {{0x386c05b1,0xacc8fbc0,0xec680276,0xa01802d2}},	//   kper_, игез_, аркк_, _hvöl, 
   {{0xa01800fc,0x5c7002bf,0x69c0fa55,0x2bc400bc}},	//   _kvöl, дліт, _raoe, लयला, 
   {{0x660c0e8b,0x69c00b4f,0x653800df,0xe45c032e}},	//   zick, _saoe, בענד, dvöl_, 
   {{0x69c005c7,0x386c1382,0x98a401e4,0x6d980395}},	//   _paoe, eper_, ĝiĝu_, _възр_, 
   {{0x660c0122,0x98a40115,0x6fcc0073,0x00000000}},	//   xick, ŝiĝu_, _होतं, --, 
   {{0x660cdbcd,0xdd8c3cd9,0x69c00618,0xeb98fbc1}},	//   vick, _جوق_, _vaoe, _виз_, 
   {{0x27481e80,0x660cfbc2,0x00000000,0x00000000}},	//   ично_, wick, --, --, 
   {{0x660cfbc3,0x1f5825f9,0x4734fbc4,0x69c00165}},	//   tick, ידיא, янос, _taoe, 
   {{0xc7b808a4,0xdb003c02,0x00000000,0x00000000}},	//   vođu_, venø, --, --, 
   {{0x660cfbc3,0xf8ac0502,0x2ca4fbc5,0x6444000f}},	//   rick, _یکی_, ntod_, tmji, 
   {{0x660cfbc6,0x6d5403e0,0x00000000,0x00000000}},	//   sick, ıyay, --, --, 
   {{0x3d10006d,0x660cfbc7,0x6444fbc8,0xa01808a5}},	//   _देने_, pick, rmji, _dvöl, 
   {{0x2ca4409c,0x6444002d,0x00000000,0x00000000}},	//   ktod_, smji, --, --, 
   {{0xdcf8098d,0x26c00374,0xdb0001bf,0xc8bc0a8a}},	// [16550] _iduć, ākou_, senø, ्टिट, 
   {{0x2ca422d0,0xdb00383d,0xe450007b,0x00000000}},	//   dtod_, penø, _تضع_, --, 
   {{0xb3b80375,0xbdb416a4,0x2ca4000d,0x00000000}},	//   _המתכ, збеј, etod_, --, 
   {{0xc0c4fbc9,0x7cd81d5b,0xdef800c7,0x7bf80150}},	//   _нәзи, ймер_, лыҵ_, өнер_, 
   {{0xb7b4063f,0x28b42982,0x27fc0051,0x00000000}},	//   kọp, _अनगि, khtn_, --, 
   {{0x26ccfbca,0xbe0400e5,0x00000000,0x00000000}},	//   _orfo_, _کورٹ, --, --, 
   {{0x3f801442,0x386cfbcb,0x3cf40139,0x999c00a2}},	//   mahu_, wper_, _şavı_, gluş_, 
   {{0x3f80fbcc,0x81b80729,0x60cc00d7,0x00000000}},	//   lahu_, চাক_, _krcm, --, 
   {{0x386cfbcd,0x38680327,0x06b40011,0x25dc1b76}},	//   uper_, _ħars_, টিফি, गानी_, 
   {{0x386cfbce,0x3f80fbcf,0xa3c823ef,0x26dc037e}},	//   rper_, nahu_, _रोल_, fxto_, 
   {{0x80cc0c22,0x86980395,0x00000000,0x00000000}},	//   सिडे, отят_, --, --, 
   {{0x386cfbd0,0x60cc02d0,0xa5b80332,0xa01808a5}},	//   pper_, _orcm, hnóf, _svöl, 
   {{0x3f80fbd1,0xf8680592,0x00000000,0x00000000}},	//   kahu_, _امتي_, --, --, 
   {{0x3f808b9a,0x27fc0036,0x3a2c037e,0x81a80011}},	//   jahu_, chtn_, loep_, _গোল_, 
   {{0x55c42d40,0x73340131,0xa778011a,0x02c400db}},	//   _жайғ, سىرا, _הרצפ, мирү, 
   {{0xef180032,0x41b40166,0x6590009b,0x00000000}},	//   ҙме_, мсут, _заћу, --, 
   {{0xef1801d2,0x3f8003a0,0x479401ec,0xc7940150}},	// [16560] әме_, fahu_, _ءجۇس, _ءشۇب, 
   {{0x7654198f,0xa854011a,0x09b800cd,0x00000000}},	//   _hiyy, פיעה_, _आस्य, --, 
   {{0x2ec40597,0x76540a55,0x60cc01e4,0x3d10007d}},	//   ثقاف, _kiyy, _ercm, _देबे_, 
   {{0x76540b45,0x00000000,0x00000000,0x00000000}},	//   _jiyy, --, --, --, 
   {{0x3f80fbd2,0x6f000248,0x76540429,0x3a2c020c}},	//   bahu_, _bíbé, _miyy, doep_, 
   {{0xa064fbd3,0xa3dc00dc,0xae580212,0x30740b01}},	//   _хара_, णाय_, _грає_, _муҳс, 
   {{0x2ca4fbd4,0x25dc9a09,0x00000000,0x00000000}},	//   stod_, गामी_, --, --, 
   {{0x7654fbd5,0xb600032e,0x321006be,0x00000000}},	//   _niyy, _þáha, niyy_, --, 
   {{0x6b54fbd6,0xdb000306,0x9f50005b,0xa3dc00cd}},	//   _فضائ, mený, ädöt_, णाम_, 
   {{0xdb00fbd7,0x765403f9,0xa3c8012d,0x00000000}},	//   lený, _aiyy, _रों_, --, 
   {{0x49a4005e,0x76540a4d,0x06b40154,0xa5b8007b}},	//   _жылғ, _biyy, টিভি, nnóg, 
   {{0xaac0bd11,0xdb0001f1,0xa9a4300e,0x00000000}},	//   _वैयक, nený, _хидд, --, 
   {{0x7654fbd8,0x87e401ec,0x3f800124,0x00000000}},	//   _diyy, _يتتە, yahu_, --, 
   {{0x69a0d04e,0x00000000,0x00000000,0x00000000}},	//   _गाडी, --, --, --, 
   {{0x3f800122,0x26c00aea,0x462401d5,0xa7300166}},	//   vahu_, ākos_, _очиғ, _ядкә, 
   {{0xdb000232,0xbbb80358,0x53340032,0x00000000}},	//   jený, _इस्क, хест, --, 
   {{0x3f80fbd9,0xdb000232,0x657c0472,0x3ad401e1}},	// [16570] tahu_, dený, _ieqh, _ḿpa_, 
   {{0x321000e4,0x61fc01b9,0x0fe400db,0x00000000}},	//   aiyy_, shql, нөсү, --, 
   {{0x3f80fbda,0x645c02d1,0xe7ac2977,0x60cc0175}},	//   rahu_, _huqi, ज्यप, _wrcm, 
   {{0x3f8003c6,0x645c0912,0x6454fbdb,0x44200ac5}},	//   sahu_, _kuqi, _hixi, _hjh_, 
   {{0x645c0455,0x657c047e,0x3f80fbdc,0x8d2800d4}},	//   _juqi, _meqh, pahu_, поїв_, 
   {{0x645c8f17,0x657c01e0,0x4420090c,0x3d100574}},	//   _muqi, _leqh, _jjh_, _देणे_, 
   {{0x6284fbdd,0x64540a5c,0xdb0003c6,0x64480395}},	//   nsjo, _mixi, bený, _ègiu, 
   {{0x657c0944,0xdb00fbde,0x39582147,0x20100254}},	//   _neqh, menü, øss_, lixi_, 
   {{0x3a2c2041,0xdb00fbdf,0x645c0455,0x9f400118}},	//   roep_, lenü, _nuqi, _mojí_, 
   {{0x6284fbe0,0x7654208d,0x3a2c01a4,0x64544cbd}},	//   ksjo, _siyy, soep_, _nixi, 
   {{0x3d106225,0x657c2798,0x1cc8025c,0x3a2c017a}},	//   _देते_, _beqh, ིའམ_, poep_, 
   {{0x645c0117,0x4420e9c3,0x64545e94,0x7654022f}},	//   _buqi, _ajh_, _aixi, _qiyy, 
   {{0x64540a81,0x657c0477,0x66e800ac,0x76540455}},	//   _bixi, _deqh, rəka, _viyy, 
   {{0x4420020b,0xdb0004bf,0x78a80b4f,0x645c51ab}},	//   _cjh_, zený, mtev, _duqi, 
   {{0xdb00fbe1,0x7654198f,0x9f4002fb,0x2010003a}},	//   menó, _tiyy, _bojí_, dixi_, 
   {{0x645c044e,0x442003a2,0x64540137,0x76540e14}},	//   _fuqi, _ejh_, _eixi, _uiyy, 
   {{0x78a8fbe2,0xdb000232,0x645c0113,0x628408fb}},	// [16580] ntev, vený, _guqi, asjo, 
   {{0x657c379d,0x64547aac,0x6284002d,0x32100784}},	//   _zeqh, _gixi, bsjo, siyy_, 
   {{0x78a8fbe3,0xdb00fbe4,0x657c0117,0xdee00117}},	//   htev, genü, _yeqh, кофи, 
   {{0xdd8cfbe5,0x78a8044e,0x6454009a,0x645c01a9}},	//   لوم_, ktev, _zixi, _yuqi, 
   {{0x64549e4e,0x645c0e14,0xdb00fbe6,0x2010058a}},	//   _yixi, _xuqi, rený, bixi_, 
   {{0x6454fbe7,0x6fb4fbe8,0xdb00fbe9,0x78a8017a}},	//   _xixi, _تمسا, sený, dtev, 
   {{0xa3dc0490,0xe0dc007f,0x9fc4fbea,0xdb0002fb}},	//   णात_, _ezòd_, _югра_, pený, 
   {{0x78a8fbeb,0xa3c813f5,0x00000000,0x00000000}},	//   ftev, _रोई_, --, --, 
   {{0xed3405f5,0x78a84bfa,0x88b013f9,0xa5b81315}},	//   _цэвэ, gtev, ایتچ, plóz, 
   {{0x657ccdf9,0x1c4000a8,0x645c679e,0xd7f4d822}},	//   _seqh, _анум, _ruqi, дую_, 
   {{0xa5b8172e,0x78a886ed,0x061411ed,0x6454fbec}},	//   olóx, atev, едню, _rixi, 
   {{0x6454fbed,0x657c0455,0x6a143b7a,0xea1400f2}},	//   _sixi, _qeqh, _غبار, _غذاخ, 
   {{0x6454fbee,0x7afc003a,0x3e7401e1,0x2be01788}},	//   _pixi, _ęsti, _kútò_, पापा, 
   {{0xdb000077,0x2010fbef,0x6454058a,0x657c0455}},	//   cenó, xixi_, _qixi, _weqh, 
   {{0x6454fbf0,0x54542424,0x6aa80142,0x9f40013a}},	//   _vixi, тврт, ntff, _pojí_, 
   {{0x645489fe,0x6284fbf1,0x645c2e95,0xc0c40139}},	//   _wixi, rsjo, _tuqi, нәги, 
   {{0x62841f21,0x6454fbf2,0x1c1c00c5,0x4058221c}},	// [16590] ssjo, _tixi, _बदलल_, سلاح_, 
   {{0xdb00fbf3,0x6284168c,0x64540393,0xa5b801e7}},	//   tenü, psjo, _uixi, snód, 
   {{0x2010fbf4,0x4430fbf5,0xa3c875be,0xe7a4060c}},	//   rixi_, moz_, _रोए_, _खानप, 
   {{0x4430fbf6,0xdb00fbf7,0x78a8fbf8,0xd13001ed}},	//   loz_, renü, ytev, امے_, 
   {{0xe1fc03a0,0xe61c011f,0x644804cc,0x5064113e}},	//   _iló_, inô_, _ègis, _атса, 
   {{0x4430fbf9,0x6cd05220,0x28d007b7,0xe1fc08a5}},	//   noz_, اقوا, तिनि, _hló_, 
   {{0xdb0002f0,0xe1fc032e,0x4ea4030d,0x00000000}},	//   venó, _kló_, _ирта, --, 
   {{0x78a8fbfa,0x4430066d,0xaa540640,0x00000000}},	//   ttev, hoz_, нију_, --, 
   {{0x4430fbfb,0x78a8010a,0x00000000,0x00000000}},	//   koz_, utev, --, --, 
   {{0x7b8404a9,0x4430fbfc,0xdac400d1,0x776c0139}},	//   _سائە, joz_, _يېشى_, _şaxb, 
   {{0x78a8fbfd,0xdb00fbfe,0x4430fbff,0x35a4fc00}},	//   stev, renó, doz_, нанг, 
   {{0xf770168d,0xa2d00316,0x66e800ac,0x8bb40124}},	//   _ڵات_, डिन्, məkl, _зқәу_, 
   {{0xc9845a52,0xdb004a2e,0x66e800ac,0x08c414d4}},	//   _рухи, cenò, ləkl, _ағып_, 
   {{0xe1fcfc01,0x4430fc02,0x2be001bc,0xdcf88256}},	//   _aló_, goz_, पाया, _neuč, 
   {{0xe7340364,0xe1fc0174,0x66e80213,0x00000000}},	//   _пеш_, _bló_, nəkl, --, 
   {{0xe1fc00c6,0x80c80154,0x00000000,0x00000000}},	//   _cló_, রমন্, --, --, 
   {{0xa3c8d054,0x4430fc03,0x2be012eb,0x3124d021}},	// [165a0] _रोक_, boz_, पामा, хдаг, 
   {{0x4430fc04,0x66e803b9,0x00000000,0x00000000}},	//   coz_, kəkl, --, --, 
   {{0xc5b40154,0x71680117,0x00000000,0x00000000}},	//   য়ারপ, _нанг_, --, --, 
   {{0x60d8892f,0xc2f40124,0xe1fc02d2,0x3d1000cd}},	//   _šume, _рџьы, _gló_, _देहे_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb00067c,0x7fd401ec,0x00000000,0x00000000}},	//   venò, _иісі, --, --, 
   {{0x28d000dc,0x2be028fe,0x00000000,0x00000000}},	//   तिभि, पाबा, --, --, 
   {{0x4430fc05,0x3d10007d,0xda440137,0x6aa803cb}},	//   zoz_, _देवे_, нчыл_, rtff, 
   {{0xec14fc06,0x4430fc07,0x2d840607,0xd7d80490}},	//   _كورد, yoz_, maoe_, बांच, 
   {{0x2d8400fb,0x4430528b,0x06b40154,0x66e803b9}},	//   laoe_, xoz_, টিসি, bəkl, 
   {{0xa3c812eb,0x44307f81,0xa3dc0574,0x66e803be}},	//   _रोग_, voz_, णास_, cəkl, 
   {{0x4430fc08,0x00000000,0x00000000,0x00000000}},	//   woz_, --, --, --, 
   {{0x4430fc09,0xe61c06ed,0xd8900014,0x00000000}},	//   toz_, rnô_, _مٔند, --, 
   {{0x2d840270,0xe1fc0321,0xa3c801f9,0x674400c0}},	//   haoe_, _sló_, _रोख_, _пэйз, 
   {{0xe1f00116,0xd7c401e2,0x00000000,0x00000000}},	//   гүнъ, _سويه_, --, --, 
   {{0x4430fc0a,0xd1c805f5,0x75206c3c,0x7ae40108}},	//   soz_, нууд_, _žoze, ähti, 
   {{0x4430fc0b,0x83840092,0xc0e80023,0x60d801ef}},	// [165b0] poz_, ይታወቅ_, መሃሮ_, _šumb, 
   {{0x2fc8045a,0x25dc01f9,0x503801f4,0x00000000}},	//   _cabg_, गावी_, епую_, --, 
   {{0xf2c000d1,0x93f402d5,0x985c0240,0x00000000}},	//   _көти, _спэц, _ተኣሚኑ_, --, 
   {{0x2eec049f,0x2d84037e,0x4e9407d6,0xc0e80023}},	//   äffa_, gaoe_, اشلر, መሃር_, 
   {{0x61ec01ab,0x3d103996,0x9f4001e1,0x4d6400d4}},	//   _iocl, _देशे_, _wojà_, уків, 
   {{0xbf100598,0x52743418,0x66e80213,0x61ecda31}},	//   _күзә, _جایز, təkl, _hocl, 
   {{0x63a0008c,0x8d780020,0x61ec003e,0x2d840156}},	//   _önnu, ከታቸው_, _kocl, baoe_, 
   {{0x2b5c031c,0x66e80213,0xf8680472,0xa9d00116}},	//   _egtc_, rəkl, ومبي_, لقىغ, 
   {{0x3944024c,0xcda8007b,0x3774013d,0x2bd0000d}},	//   ъниг, _سهله_, кынс, _धोवा, 
   {{0xdd900046,0x61ec0656,0xb8e808f2,0x1c5400ae}},	//   _шағы, _locl, _ऊन_, _أخرج, 
   {{0xfdf47039,0x05dc0073,0x92bc00cc,0xbaa401ec}},	//   _आवास_, यांब, _আপ্_, _шуақ, 
   {{0x61ecfc0c,0x3914004e,0xc8c80451,0x27ec0142}},	//   _nocl, _имер, _ڳوٺن_, _eofn_, 
   {{0xb6040241,0x00000000,0x00000000,0x00000000}},	//   _aráà, --, --, --, 
   {{0x90b400c7,0x00000000,0x00000000,0x00000000}},	//   қәмш, --, --, --, 
   {{0x61ec5c99,0x2fc801a9,0x2be001bc,0xc6a400f3}},	//   _bocl, _rabg_, पाता, _брњи, 
   {{0x61ec003a,0x0708030d,0x00000000,0x00000000}},	//   _cocl, _яхчи_, --, --, 
   {{0x22980570,0x61ecfc0d,0x3d10007d,0x51440220}},	// [165c0] tàkì_, _docl, _देले_, удағ, 
   {{0x61ecfc0e,0x75980023,0x00000000,0x00000000}},	//   _eocl, _ጎዳጉዲ_, --, --, 
   {{0xa3dc05ba,0x61ec0597,0x2f54fc0f,0x442431b1}},	//   णार_, _focl, ттас, _حريف, 
   {{0x61ecfc10,0x35a8033f,0x8d2800fd,0x37c00327}},	//   _gocl, _काफ़, ннең_, _མིའད, 
   {{0xdca0fc11,0x32000493,0x30741de6,0xebe400d8}},	//   иаци, _ilky_, _шунс, кодп, 
   {{0x61ec04cc,0x67f400a2,0xa018032e,0x00000000}},	//   _zocl, _tâji, _svöv, --, 
   {{0xdee0fc12,0x9a80054a,0x2d8402b5,0x81a803d4}},	//   _кори, ауыл, paoe_, _গোট_, 
   {{0xfb1800e5,0x49040166,0x00000000,0x00000000}},	//   عروں_, лүег, --, --, 
   {{0x6e2001f2,0x61e8fc13,0x7e68fc14,0xeb90fc15}},	//   mnob, ögli, _čepi, _نظا_, 
   {{0x6e20fc16,0xd9400114,0x00000000,0x00000000}},	//   lnob, шењи, --, --, 
   {{0x25dc1b57,0x6e2001e2,0x86541f91,0x96e4009d}},	//   गाली_, onob, лкох, вьяа_, 
   {{0xa3c88d42,0x6e20fc17,0xe8f8fc18,0xa01808a5}},	//   _रोज_, nnob, _оле_, _hvöt, 
   {{0xa3dc0c66,0x61ec05d5,0x6e200099,0x88b001b9}},	//   णाल_, _rocl, inob, _ایخچ, 
   {{0x61ecfc19,0x6e2001bf,0x01c801ed,0xdcf806be}},	//   _socl, hnob, کورٹ_, _lduğ, 
   {{0x45d49fc7,0x61ec003a,0xe5b002dd,0xdcf806be}},	//   _бойс, _pocl, _ұйқы, _oduğ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x5184fc1a,0x50646ee8,0x6e200bb3,0xf4b401b9}},	// [165d0] руса, атха, dnob, _یشیگ, 
   {{0x9e646d6c,0x6e20fc1b,0xdb00002f,0x00000000}},	//   ناؤن, enob, menö, --, 
   {{0x4fc4151e,0x92000248,0x61ec0175,0x630000d1}},	//   шста, _kọ́, _tocl, _ئۈزل, 
   {{0x6e20fc1c,0x8d740214,0xa2fc012d,0x00000000}},	//   gnob, لاها, ईनीज_, --, 
   {{0x6ab8020b,0xab900075,0x66e80213,0x92000241}},	//   _aptf, ڭلىغ, fəkk, _mọ́, 
   {{0x3f900bd7,0x30d800c8,0x6e20004c,0x92000cad}},	//   _udzu_, _אַלע, anob, _lọ́, 
   {{0x6e2001e4,0x4918033f,0xdb00002f,0xf1a81bd6}},	//   bnob, _बेबो_, henö, ङ्कन, 
   {{0x6e2000d8,0x98ac00c0,0xdb0001f4,0x00000000}},	//   cnob, _lygą_, kenö, --, 
   {{0x7cd80323,0x9ba00075,0xdb00014a,0xdd00005f}},	//   _ямар_, _نەشى, jenö, ārēj, 
   {{0x66e806be,0xf7880166,0x00000000,0x00000000}},	//   cəkk, diçä_, --, --, 
   {{0x92000241,0x3dcc020c,0xa01802d2,0x00000000}},	//   _bọ́, _kaew_, _hvös, --, 
   {{0x15e40490,0x7c2c007b,0x7ae4000d,0x00000000}},	//   गाधर_, éarf, ähtu, --, 
   {{0xa3dc0a28,0x79880069,0x92000241,0x2324013e}},	//   णां_, maew, _dọ́, ҳори_, 
   {{0xd8e80085,0xb6a42cc8,0x00000000,0x00000000}},	//   ́bɛ́, _бикл, --, --, 
   {{0x3ea000af,0x92000248,0x2324fc1d,0x6e2026ec}},	//   juht_, _fọ́, гори_, ynob, 
   {{0x79880069,0x920001e1,0x6e20022e,0x35a4009b}},	//   naew, _gọ́, xnob, _саиг, 
   {{0x6e20b964,0x320002f0,0xf1a800dc,0xa5b801e7}},	// [165e0] vnob, _vlky_, ङ्गन, onón, 
   {{0xa3dc0882,0x9f80010b,0xdb000254,0xdce80064}},	//   णाः_, йгуд, lenõ, lagė, 
   {{0x798802b5,0x2be001bc,0x66e80213,0xdd8c01e2}},	//   kaew, पासा, vəkk, ړون_, 
   {{0x2d9007a8,0xa5b800c6,0x6e20004c,0x9074215c}},	//   ûye_, hnón, unob, _نۇرش, 
   {{0x6ab80356,0x798802d0,0x00000000,0x00000000}},	//   _sptf, daew, --, --, 
   {{0x6e202b5d,0xdb00000d,0x2d980356,0x00000000}},	//   snob, henõ, şpe_, --, 
   {{0x35a80cb4,0x66e80213,0xb60400d0,0xe454010f}},	//   _काढ़, rəkk, _znáš, ניצט_, 
   {{0x200c005f,0x798862af,0x50600092,0x6ca403af}},	//   īgie_, gaew, _ፈረንሣ, _مصطل, 
   {{0xdd8cfc1e,0xe784ebe9,0x92000241,0x00000000}},	//   _رول_, луно, _rọ́, --, 
   {{0xdb00fc1f,0x79880175,0xa01802d2,0x6e4000d1}},	//   venö, aaew, _hvör, _ئۆچم, 
   {{0xdab4fc20,0x92000248,0xa01801a8,0x98ac00c0}},	//   _مهلت_, _pọ́, _kvör, _rygą_, 
   {{0xdb0001b8,0x56905aa2,0x1a9808a8,0x6b88005c}},	//   tenö, щают, _טיבע, lafg, 
   {{0x287400fd,0xe87000f2,0x7c2c00ae,0x7bc40254}},	//   _сыер, _انتگ, éarg, õhug, 
   {{0xdb00002f,0x92000ca8,0x00000000,0x00000000}},	//   renö, _wọ́, --, --, 
   {{0x28d0102f,0xb6040118,0xdb001d13,0x92000241}},	//   तिवि, _snáš, benõ, _tọ́, 
   {{0x44f4fc21,0x57e4fc22,0xdb0029ef,0x00000000}},	//   _впис, _адәм_, penö, --, 
   {{0x40940075,0xe45cfc23,0x66e803e3,0x00000000}},	// [165f0] شلار, rvös_, dəki, --, 
   {{0x94746ac4,0x27fc0036,0xb6040306,0x11540229}},	//   _اديا, nktn_, _vnáš, скую, 
   {{0x656c0622,0x03180451,0x6b8801bf,0x00000000}},	//   occh, _شڪست_, dafg, --, 
   {{0x656c026c,0x3ea00e78,0x00000000,0x00000000}},	//   ncch, ruht_, --, --, 
   {{0xfce4fc24,0xce941ee3,0xfc303090,0xb6040306}},	//   роло, _қатъ, يحت_, _unáš, 
   {{0xb098025f,0x79883266,0x63a40007,0xdec8c172}},	//   _בישר, waew, ngjn, _публ_, 
   {{0x60340724,0x66e80213,0xec10fc25,0x7988b236}},	//   _eşmä, bəki, توود, taew, 
   {{0xa5b80005,0x7e7402d0,0x66e806be,0x00000000}},	//   lióf, _itzp, cəki, --, 
   {{0xdb00df44,0x79880368,0x39584abe,0x28d02435}},	//   igné, raew, äss_, तिषि, 
   {{0x9a8485f2,0x7c2c0332,0x7ae40254,0x00000000}},	//   _будл, éard, ähts, --, 
   {{0xb4dc0a28,0x7624fc26,0xdb00002d,0x798800b0}},	//   णम्_, имоз, genô, paew, 
   {{0x28d092c1,0x7614003b,0x00000000,0x00000000}},	//   तिशि, рьох, --, --, 
   {{0x37e4fc27,0xdce80006,0x60d80427,0x3774008e}},	//   _волг, ragė, _šumn, _кыйс, 
   {{0x656cb3cb,0x28d0228a,0xd90c01ed,0xbef40073}},	//   acch, तिरि, _ویں_, _इथून_, 
   {{0x98a00032,0x5884035b,0xa5b801e7,0xdb000037}},	//   _тиҙе, _рыҵа, onól, penõ, 
   {{0x20b03166,0x00000000,0x00000000,0x00000000}},	//   ुबंध, --, --, --, 
   {{0xe4640790,0x6b8801bf,0x00000000,0x00000000}},	// [16600] şört_, yafg, --, --, 
   {{0x15e40490,0xa0180008,0xdfcccbdb,0xd3a401d5}},	//   गावर_, _svör, ويق_, _улоқ, 
   {{0x3244af80,0xaec4fc28,0x6398011a,0xfba800cd}},	//   _венг, рбел, _בסינ, च्छम, 
   {{0x80c0012d,0xb7e000eb,0x00000000,0x00000000}},	//   _रैके, _ফতোয়, --, --, 
   {{0x6b88005c,0x2be00404,0x00000000,0x00000000}},	//   tafg, पाला, --, --, 
   {{0xbf64182f,0x3868010b,0xd89c00d1,0x00000000}},	//   _هدفو, _çary_, _ﺋﻪﻫﯟ, --, 
   {{0x6b88fc29,0x00000000,0x00000000,0x00000000}},	//   rafg, --, --, --, 
   {{0x3d10007d,0x6b8800b5,0x6cc40014,0x7a1c0208}},	//   _देके_, safg, _پزرٕ, ệtna, 
   {{0x2bc801e0,0xe51800bc,0x6b8801bf,0x00000000}},	//   _илап_, नपछि_, pafg, --, 
   {{0xe7d001ed,0xdb00002d,0x00000000,0x00000000}},	//   آمدگ, tenô, --, --, 
   {{0x45d40064,0xbb5000db,0x7c2c0332,0x00000000}},	//   бонс, _ىچىب, éare, --, 
   {{0xa5b867ca,0xf1d40037,0x00000000,0x00000000}},	//   cnól, _ढोलन, --, --, 
   {{0xd940b6c2,0xd1e81ee0,0x5e54008f,0x00000000}},	//   _деци, መናት_, ייטע_, --, 
   {{0x60d8041a,0xa2d007b6,0x66640408,0x00000000}},	//   _šumo, डिल्, _къиз, --, 
   {{0x926827a8,0x545400d4,0x31d400d1,0x00000000}},	//   ирта_, івст, ﻟﻠﯩﻜ, --, 
   {{0x53341422,0x8ff8036b,0x96e800f1,0xb0d00f4a}},	//   цест, یرلر_, _جبهې_, सिंग, 
   {{0xdb0006af,0x00000000,0x00000000,0x00000000}},	// [16610] rgné, --, --, --, 
   {{0xc7b80e3c,0xc0c40075,0x00000000,0x00000000}},	//   biđe_, _қәби, --, --, 
   {{0x4f6813d6,0x00000000,0x00000000,0x00000000}},	//   ршум_, --, --, --, 
   {{0x9f400241,0x0d9801ec,0x0e640150,0x00000000}},	//   _kojú_, атшы_, ікін, --, 
   {{0x3d10d44d,0xbc180953,0x0dc8fc2a,0x200c180f}},	//   _देखे_, лікі_, рухи_, ègis_, 
   {{0x0fe400ee,0x9f400241,0x3154011a,0x00000000}},	//   _мөхү, _mojú_, _לירן_, --, 
   {{0xa5b8baa9,0x9f400241,0x7e7402d0,0x00000000}},	//   cióg, _lojú_, _utzp, --, 
   {{0x1dcc1d15,0x8d8401c0,0x00000000,0x00000000}},	//   _सोचत, _мууд, --, --, 
   {{0xfb84fc2b,0xc7b80cf4,0x2bd02052,0x00000000}},	//   _هدای, ziđe_, _धोका, --, 
   {{0x30d800c8,0xb6a40150,0x00000000,0x00000000}},	//   אַטע, биол, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9f400241,0x00000000,0x00000000,0x00000000}},	//   _bojú_, --, --, --, 
   {{0xa454e090,0xe1fc012d,0x2bac01f9,0x00000000}},	//   çağı_, _miód_, _घामा, --, 
   {{0x9f400241,0x68e401e3,0x00000000,0x00000000}},	//   _dojú_, åkde, --, --, 
   {{0xe294fc2c,0x62940241,0x00000000,0x00000000}},	//   йар_, _àbò, --, --, 
   {{0x63b81326,0x9f400ca8,0x00000000,0x00000000}},	//   đuna, _fojú_, --, --, 
   {{0xcaa40020,0xe574040e,0x00000000,0x00000000}},	// [16620] _ወይንም_, _узы_, --, --, 
   {{0x7e680fb7,0xfb0400e8,0x30740672,0x00000000}},	//   _čepr, _ñëwe_, _қумс, --, 
   {{0xddc804a7,0x6d4402f0,0x05dc0073,0x00000000}},	//   _šišm, _úkaz, याचब, --, 
   {{0x6da43461,0x3a3c063f,0xa5b89262,0x249c110c}},	//   сида, _nkwp_, ciód, šume_, 
   {{0xdca01eed,0xe1fcfc2d,0xddc40064,0x00000000}},	//   зачи, _sióg_, _zujū, --, 
   {{0x9f4001e1,0x2bd0033f,0x5a30035b,0x00000000}},	//   _lojù_, _धोखा, ҟныт, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xed58fc2e,0x9a6400c6,0xfca8fc2f,0xee38498b}},	//   _боб_, حميل_, _چالو_, _снб_, 
   {{0xf8ac021a,0xfca800b2,0x29001897,0x7c2c007b}},	//   نکو_, _نالو_, áka_, éarc, 
   {{0xdd8c00f1,0x9f400248,0xca300150,0x00000000}},	//   _يوۀ_, _rojú_, _ﺭﺼﺩ_, --, 
   {{0x2124004d,0x9f400241,0x1b3c0092,0x00000000}},	//   ̃nh_, _sojú_, _ሬስቶራ, --, 
   {{0xa968146a,0x2848008e,0x00000000,0x00000000}},	//   _сида_, _өзеп_, --, --, 
   {{0x2ca41ff6,0xe4c4005b,0x00000000,0x00000000}},	//   nuod_, щённ, --, --, 
   {{0x66c8010b,0x1954011a,0xd90c00e5,0xa5b8012d}},	//   _буиг_, _הבדל_, _سیپ_, wiód, 
   {{0x461402f2,0x9f4001e1,0x00000000,0x00000000}},	//   _ووتر, _wojú_, --, --, 
   {{0x9f400ca8,0x00000000,0x00000000,0x00000000}},	//   _tojú_, --, --, --, 
   {{0xa5b8fc30,0x321c007f,0x660001af,0x7588009d}},	// [16630] riód, ètya_, _моҫҡ, _өсөв_, 
   {{0x2004fc31,0x0fe0012d,0x00000000,0x00000000}},	//   óni_, नागढ, --, --, 
   {{0x7d780b6c,0x104877c1,0x147401d5,0xf8a40118}},	//   لمار_, сяти_, _وایج, _खम्प, 
   {{0xb9100a28,0xa01803fa,0x78ac03cd,0x05c801ad}},	//   _evaṃ_, _zwöl, _åavg, िजिब, 
   {{0x69a01533,0x2ca40b21,0xd25800a8,0x00000000}},	//   _गाजी, guod_, _ыць_, --, 
   {{0x3a98fc32,0x60cc02d0,0x00000000,0x00000000}},	//   атию_, _iscm, --, --, 
   {{0x3f80fc33,0x93fc00c8,0x39e802bf,0xfd940116}},	//   mbhu_, רלוי, идко_, _дөлә_, 
   {{0x2ca41c06,0x3f800472,0x05d81414,0x00000000}},	//   buod_, lbhu_, _बोलब, --, 
   {{0x49900b43,0xe61c0109,0xf988004b,0xe8f404b4}},	//   ریور, diô_, هنګي_, жлы_, 
   {{0x115c00c8,0xac80001f,0xb75800d4,0xcb08013d}},	//   נדזע, _ይሰጣሉ_, ишнє_, рхәд_, 
   {{0xaaa800db,0xdb040241,0xa5b800e5,0x00000000}},	//   _ەنۅۅ_, _ìmàr, diób, --, 
   {{0x361400d6,0x60cc03ac,0xdb0001e7,0x00000000}},	//   ієнт, _oscm, ngní, --, 
   {{0x25dc76f8,0x4ab4004e,0x386c06be,0x00000000}},	//   गाजी_, _дөөр, qqer_, --, 
   {{0x3a2800f3,0x999c025c,0x3ea00327,0xa5b800e5}},	//   čapu_, hmuż_, krht_, giób, 
   {{0xe36010f5,0xe294fc34,0xd8740345,0x00000000}},	//   дкри, жас_, _ئاڵب, --, 
   {{0x21641363,0x26080073,0x3f800327,0xb91000dc}},	//   жити_, ासणी_, ebhu_, _svaṃ_, 
   {{0x61400798,0x78ac03cd,0x00000000,0x00000000}},	// [16640] дета, _åavd, --, --, 
   {{0x66e800ac,0xa5b801d3,0x3f840254,0x76440feb}},	//   cəks, ciób, _õlul_, llky, 
   {{0xee38fc35,0x25dc0490,0xef180a5b,0x00000000}},	//   анж_, गाची_, јме_, --, 
   {{0xee38f079,0xe0dc02e2,0x2d940046,0x2ca40004}},	//   шне_, _dyòb_, ірес, tuod_, 
   {{0xb9100a28,0xd6cc009e,0x00000000,0x00000000}},	//   _tvaṃ_, িমিয, --, --, 
   {{0xe7acfc36,0x00000000,0x00000000,0x00000000}},	//   ज्ञप, --, --, --, 
   {{0x7c2c007b,0x5f24774c,0x00000000,0x00000000}},	//   éara, _дорм_, --, --, 
   {{0x26cc0175,0xddc0054d,0x05d80073,0xa5b800e5}},	//   _rsfo_, _обси, _बोंब, ziób, 
   {{0x1d04d31d,0x2ca41730,0x00000000,0x00000000}},	//   _дети_, quod_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x45d406ed,0x6b980129,0x00000000,0x00000000}},	//   понс, _idtg, --, --, 
   {{0x06c80323,0xa5b8fc37,0x1b10015b,0x2be004e4}},	//   агүй_, dióc, _ঢুকে_, पाका, 
   {{0xa5b801e7,0x00000000,0x00000000,0x00000000}},	//   nnói, --, --, --, 
   {{0x63b82220,0xe61c05da,0x7644045a,0x3f80031c}},	//   đuno, siô_, alky, xbhu_, 
   {{0xa5b800ae,0xc1a400c7,0x00000000,0x00000000}},	//   hnói, зызқ, --, --, 
   {{0x76440076,0x9618007b,0x1a98010f,0x66e806be}},	//   clky, _وغير_, יילע, bəkr, 
   {{0xc0f8069c,0x9f680798,0x776c0166,0x00000000}},	// [16650] _ወርሒ_, арез_, _şaxi, --, 
   {{0x0fe400f7,0xbde401e1,0x454401e2,0x00000000}},	//   мөсү, _oyèé, _ورکې, --, 
   {{0x200c0153,0x3f800327,0x00000000,0x00000000}},	//   ūgio_, rbhu_, --, --, 
   {{0xdc1c063f,0x6444062c,0xe19001ee,0x00000000}},	//   _ụ̀ch, llji, _юлмө, --, 
   {{0xdb00007b,0xa5b8007b,0x4c840006,0x810800f1}},	//   rgní, gnói, длів, _طرحې_, 
   {{0x6444e8a2,0xe0dc0248,0x547c0a1e,0xe1f80073}},	//   nlji, _irò_, סטוו, _एकुण_, 
   {{0xca74004b,0xa5b801e7,0xceb4009b,0x00000000}},	//   ونوک, anói, _обрћ, --, 
   {{0x644409a8,0x8d740b8c,0x499400c7,0x00000000}},	//   hlji, _ياقا, мшьт, --, 
   {{0x64440f03,0x4c9401d5,0xa5b800ae,0x2be00118}},	//   klji, _оитс, cnói, पाखा, 
   {{0x1cb80327,0x7998035a,0xdce800a2,0x00000000}},	//   _མྱར_, _wdww, lagį, --, 
   {{0xe1f80574,0xd76001ed,0xd5a404fb,0x00000000}},	//   _एकूण_, بندی, ولدی, --, 
   {{0xe0dc0ca8,0xed700023,0x62500205,0x00000000}},	//   _orò_, _ብናተይ_, nçod, --, 
   {{0x64440219,0x60d80413,0xe0dc0241,0xe87000d1}},	//   flji, _áumh, _nrò_, _كۆيگ, 
   {{0x64440fb7,0x78a804cf,0xd7c4e1fb,0x00000000}},	//   glji, muev, _фёдо, --, 
   {{0xe0dc0241,0x78a8af5f,0xd3480517,0xa2e041b9}},	//   _arò_, luev, تیده_, норд, 
   {{0x249c00da,0x6444000f,0x62600022,0x165800f2}},	//   šuma_, alji, евса, _بستک_, 
   {{0x78a8fc38,0xe0dc00a3,0xf8bc04aa,0x68f4012d}},	// [16660] nuev, _crò_, ्बिय, _żydz, 
   {{0x13a85a0a,0x2f549e47,0xc4c4009f,0x91c4013d}},	//   _بندی_, птес, _آتيو, чәүл, 
   {{0xe0dc08e7,0x3244fc39,0xb8dc025c,0x00000000}},	//   _erò_, _неог, _ཆཱ_, --, 
   {{0xe7e0007d,0xed586690,0x78a800c7,0x7c2c01e7}},	//   _कोना_, бое_, kuev, éarn, 
   {{0xdd8c0272,0x94000b9c,0x5ce0005b,0x5c701cb8}},	//   اوه_, _उवाच_, еюща, еліт, 
   {{0x9b900131,0xa5b8007b,0x80b000cf,0x78a80205}},	//   ىشىش, rnói, _جەكش, duev, 
   {{0x39600213,0x671809bb,0xde7401d3,0xa5b800ae}},	//   ərsə_, _फेंक_, _فیلڈ_, snói, 
   {{0x60d81ebd,0x64441fe6,0x688c0023,0xa8a4b68c}},	//   _šumi, zlji, _ሓሰውቲ_, прок, 
   {{0x78a80124,0xdca0c5fa,0x1cb8025c,0x5ca007c6}},	//   guev, _пати, _མཱར_, _питб, 
   {{0x6e20fc3a,0xa5b80077,0xab2800f0,0x2054010f}},	//   liob, nnóv, _лоза_, ּיטל_, 
   {{0x660c02d3,0x1b780375,0x00000000,0x00000000}},	//   thck, _הטבע, --, --, 
   {{0x6a14fc3b,0x6e20fc3c,0x78a80124,0x00000000}},	//   _عبار, niob, buev, --, 
   {{0x6aa820ac,0xa6100724,0x78a80789,0x625000d8}},	//   luff, _үзлә, cuev, nçoe, 
   {{0x2a640134,0x625000d8,0x6e20fc3d,0x2be00b4c}},	//   _hiob_, içoe, hiob, पाटा, 
   {{0xd7b80375,0x6aa8257c,0x45d4f46f,0x200c036e}},	//   _הצור, nuff, _жойс, ëgim_, 
   {{0x6444151c,0xe0dc08e5,0xe1f011c7,0x6aa808e5}},	//   slji, _prò_, رسز_, iuff, 
   {{0x2a6401ab,0x6aa805d5,0x6e20fc3e,0x225c00e8}},	// [16670] _miob_, huff, diob, ňuko_, 
   {{0xff241927,0x4fd400f5,0x00000000,0x00000000}},	//   وبای, нжут, --, --, 
   {{0x6aa8b98d,0xcfa40276,0xb3b8011a,0x6ac404aa}},	//   juff, эшти, _ומתכ, लबोर, 
   {{0xe0dc07ae,0x6e206548,0x6aa8011f,0x00000000}},	//   _trò_, giob, duff, --, 
   {{0x1ee44bcf,0x3cf80034,0xdfd800a7,0x00000000}},	//   _کوزی_, ्नें_, _лъв_, --, 
   {{0x78a80a73,0x6aa80b45,0xbb44bd5d,0xa01808a5}},	//   vuev, fuff, мелк, _stöf, 
   {{0x6e20025a,0x6aa8013c,0xa2d00210,0x00000000}},	//   biob, guff, डिट्, --, 
   {{0xdb0004cc,0xaa540063,0x78a8035a,0x7cf40241}},	//   rgnà, мију_, tuev, _ẹruj, 
   {{0x2a64007f,0xdcf875a7,0xdea001e2,0x00000000}},	//   _diob_, _ارزش_, _زیږی, --, 
   {{0x78a84f3b,0x77c801c0,0x00000000,0x00000000}},	//   ruev, цлог_, --, --, 
   {{0x7bc0fc3f,0x6aa806f2,0x35a4ba63,0x78a80381}},	//   _iblu, cuff, манг, suev, 
   {{0x1cb8025c,0xcc0802dd,0xe7e0302b,0x00000000}},	//   _མྱོ_, _وزەن_, _कोठा_, --, 
   {{0x78a8fc40,0x05542077,0x1cb80327,0x65c002d2}},	//   quev, етря, _མཱས_, _síhæ, 
   {{0x6e20fc41,0xb6a40108,0x00000000,0x00000000}},	//   ziob, _жикл, --, --, 
   {{0xb7b401f2,0xa5b8fc42,0x7bc0fc43,0xf6d40212}},	//   hịk, mión, _mblu, _ціля, 
   {{0xa5b801a2,0x28d01408,0x00000000,0x00000000}},	//   lión, तिचि, --, --, 
   {{0x2bac0574,0x3cf80034,0xe7e00cb4,0x6aa80268}},	// [16680] _घाला, ्नों_, _कोडा_, zuff, 
   {{0xa5b8fc44,0x7c2c00c6,0x1cb8025c,0x7bc4000d}},	//   nión, éarl, _མྱེ_, õhul, 
   {{0x6e20fc45,0x3a2c007c,0xcb1c000d,0x00000000}},	//   tiob, knep_, _भेंड_, --, 
   {{0x7bc0fc46,0x13a801d5,0x3a2c01a6,0xa5b800e4}},	//   _ablu, _بنگی_, jnep_, hión, 
   {{0x09bc03f4,0x6e20436e,0x7bc00175,0x7ae002d0}},	//   _অফলা, riob, _bblu, _arlt, 
   {{0x753402fa,0x6aa8fc47,0x7fd40220,0x5ba00395}},	//   _mxyz, tuff, _пісі, връз, 
   {{0x9f400241,0x7bc001c7,0xa018b44b,0xa5b8fc48}},	//   _dojó_, _dblu, _stög, dión, 
   {{0x6aa8fc49,0xe1fc0077,0x7bc0fc4a,0x1a54007b}},	//   ruff, _lión_, _eblu, وشية_, 
   {{0x2d84fc4b,0xeb980798,0x00000000,0x00000000}},	//   mboe_, _миа_, --, --, 
   {{0x2ca4fc4c,0xa5b8fc4d,0x6b542824,0x6aa8fc4e}},	//   mrod_, gión, _قضائ, puff, 
   {{0x7c3c08a7,0x6aa80194,0xdca00262,0x1cb8031c}},	//   _ísra, quff, _паӂи, _མཱོ_, 
   {{0x776c43bc,0x6fc800eb,0x00000000,0x00000000}},	//   _şaxt, রায়ে, --, --, 
   {{0x2ca4fc4f,0x85045e75,0x69c0072b,0xa5b83df9}},	//   nrod_, روسن, _iboe, bión, 
   {{0xa5b86bf8,0x68e0fc50,0xe1fc09c2,0x073400d4}},	//   ción, _irod, _ción_, _пелю, 
   {{0x69dc016b,0x2ca40042,0x00000000,0x00000000}},	//   _ɔpen, hrod_, --, --, 
   {{0x68e07204,0xd1c801c6,0xa5b802d2,0x00000000}},	//   _krod, мууд_, gnót, --, 
   {{0x69c00369,0x68e0031c,0x1cb8031c,0xdb04032e}},	// [16690] _mboe, _jrod, _མཱེ_, _ímör, 
   {{0x68e0fc51,0x2ca4c006,0x00000000,0x00000000}},	//   _mrod, drod_, --, --, 
   {{0xc0f82295,0xe0dc1f3f,0x69c016b8,0x7c2c00c6}},	//   _ወይም_, _azòt_, _oboe, éarm, 
   {{0x68e0fc52,0xa018ee5c,0xdd98fc53,0x1cb80135}},	//   _orod, _stöd, іше_, _མྱུ_, 
   {{0x68e00327,0x2fd80175,0xfbc40353,0x9f4001e1}},	//   _nrod, bdpg_, ебло, _pojó_, 
   {{0xa5b8fc54,0x9c10063f,0x44200072,0xfc1c009e}},	//   xión, _sọbj, _jmh_, দক্ষ_, 
   {{0x4420fc55,0x2900022c,0x68e0fc56,0x387c0142}},	//   _mmh_, økan_, _arod, _stwr_, 
   {{0x4420fc57,0x2ca401f7,0x00000000,0x00000000}},	//   _lmh_, brod_, --, --, 
   {{0x442003d5,0x68e0fc58,0xa5b8fc59,0x6abc04c5}},	//   _omh_, _crod, tión, ্মগো, 
   {{0x7bc00cfe,0x69c005e4,0x68e0fc5a,0x3f90fc5b}},	//   _ublu, _eboe, _drod, _jezu_, 
   {{0xf624fc5c,0x68e0fc5d,0x3f90fc5e,0xa5b804d4}},	//   едно, _erod, _mezu_, rión, 
   {{0x68e0fc5f,0xa5b8fc60,0x4420fc61,0xe1fc0789}},	//   _frod, sión, _amh_, _sión_, 
   {{0x44200109,0x7e68fc62,0x26dc022e,0xa49802e2}},	//   _bmh_, _miep, avto_, syòn, 
   {{0x7e685914,0x38b8fc63,0x49180037,0x45400124}},	//   _liep, mèr_, _बेटो_, рҕьа, 
   {{0xa5b84dce,0x44200660,0x68e02320,0x38b8fc64}},	//   gnós, _dmh_, _zrod, lèr_, 
   {{0x7e68068f,0x4420fc65,0x69c0017a,0xe1f41536}},	//   _niep, _emh_, _xboe, нгс_, 
   {{0xa0a0039b,0x38b8fc66,0xf4280c60,0xafe4004e}},	// [166a0] латд, nèr_, _ноил_, ноал, 
   {{0x3f900117,0xaf342e51,0x38b8067c,0x357001d3}},	//   _cezu_, ىرات, ièr_, _جھگڑ, 
   {{0x3f90009d,0xa5b85b84,0xdb000267,0x38b8fc67}},	//   _dezu_, pnót, ngnä, hèr_, 
   {{0xdd8cfc68,0x7e68fc69,0x8d280724,0x2ca40171}},	//   موم_, _ciep, мнең_, trod_, 
   {{0x7e68fc6a,0x2d84fc6b,0xa5b80789,0x2a7c003e}},	//   _diep, rboe_, diól, _sttb_, 
   {{0x3f9004e6,0x38b8068c,0x68e0036e,0x7b8000d1}},	//   _gezu_, dèr_, _rrod, иғуд, 
   {{0x68e008a4,0x7e681132,0x2ca41a56,0xdee000ee}},	//   _srod, _fiep, srod_, _йори, 
   {{0x2ca4fc6c,0x683c00b7,0x7e68017a,0x38b8fc6d}},	//   prod_, _አባላት, _giep, fèr_, 
   {{0x3f903d81,0x62500120,0x38b8fc6e,0x200417da}},	//   _yezu_, nçoa, gèr_, önig_, 
   {{0x1cb80003,0x2b14fc6f,0x62500120,0x7e6800e2}},	//   _མྱི_, _пьер, içoa, _ziep, 
   {{0xddc40fb7,0x442006df,0xd8b4020e,0xdc38010f}},	//   _hujš, _rmh_, ودیا_, _צעבר, 
   {{0x68e0665b,0xa5b82cd7,0x38b8fc70,0xd7f40116}},	//   _trod, ciól, bèr_, _җуш_, 
   {{0x68e0068f,0x38b800f2,0x26dc0810,0x44200051}},	//   _urod, cèr_, svto_, _pmh_, 
   {{0xe0dc02e2,0x78ac0122,0x7c200175,0x186400d8}},	//   _dyòl_, ňový, _xmlr, _зачи_, 
   {{0x5334005e,0xe1fc03b2,0x4908012c,0xb86400ec}},	//   герт, _fiól_, िनको_, _شاهو, 
   {{0x0cc0000d,0xa5b800e5,0x00000000,0x00000000}},	//   _एहूम, rnós, --, --, 
   {{0x7e68fc71,0x3f90209c,0x1fa4fc72,0x4420020c}},	// [166b0] _riep, _pezu_, ерег, _tmh_, 
   {{0x60d805a1,0x4420fc73,0xa0182ba9,0x6a60063f}},	//   _šums, _umh_, _stöb, _ọfla, 
   {{0x7e68fc74,0x4fc49684,0x3f9004b9,0x54341d57}},	//   _piep, ыста, _vezu_, _حرير, 
   {{0x7c94fc75,0x8e84fc76,0xddc401a6,0x38b81f5d}},	//   نشتا, النه, _bujš, yèr_, 
   {{0x3f901505,0x7e6807de,0x44300d7d,0x656801e7}},	//   _tezu_, _viep, onz_, _úghd, 
   {{0xfaa4fc77,0xfbd07a1f,0x38b86397,0x4430fc78}},	//   вако, شتت_, vèr_, nnz_, 
   {{0xf77077c2,0x7e68fc79,0x7e640124,0x38b81801}},	//   یاد_, _tiep, _ахаҵ, wèr_, 
   {{0x8d747b70,0xbca4004b,0x63b401ab,0x38b8fc7a}},	//   _ماكا, _لمري, _lcxn, tèr_, 
   {{0xf8b032db,0xade401d3,0xe9d450c0,0xbf200073}},	//   شکش_, _جہنم_, ткы_, _मधुन_, 
   {{0xa5b804d4,0x1cb8031c,0x443000f3,0x38b8068c}},	//   siól, _མྱག_, jnz_, rèr_, 
   {{0xd6cc02a6,0x38b8fc7b,0x08c401ec,0xb6a401d5}},	//   িম্প, sèr_, _ұғып_, ъинл, 
   {{0x44300226,0x4374301f,0xc3240f22,0x38b8068c}},	//   enz_, ғурт, _মুভি_, pèr_, 
   {{0x7988fc7c,0xc984fc7d,0x06b83451,0xe7e0000d}},	//   mbew, _сухи, ونیک_, _कोवा_, 
   {{0x7988fc7e,0xbf200490,0xe0dc0100,0x4430fc7f}},	//   lbew, _मधून_, _vyòl_, gnz_, 
   {{0x78a8fc80,0xd2046073,0xf62800ae,0xd71c00cc}},	//   lrev, гүнк, _يسعى_, _নুৰা_, 
   {{0x4430fc81,0x79886067,0x00000000,0x00000000}},	//   anz_, nbew, --, --, 
   {{0xfbe000dc,0x60d80427,0x0cac0011,0x00000000}},	// [166c0] पयाम, _šumr, _গন্ত, --, 
   {{0xa0300222,0x73040124,0x78a8fc82,0x7988002f}},	//   لىقت, _апоз, irev, hbew, 
   {{0x78a80936,0xc32402f5,0xa018fc83,0x798827b5}},	//   hrev, _মুঠি_, _stöc, kbew, 
   {{0x6da49098,0x1cb80003,0x79880196,0x6250004e}},	//   тида, _མྱང_, jbew, lçon, 
   {{0x7988045f,0x77f010eb,0x78a86296,0xa0a0013d}},	//   dbew, _अचूक_, jrev, _каяд, 
   {{0x78a8601a,0x6250fc84,0xe0dc0100,0x2ac40640}},	//   drev, nçon, _izòp_, вљив, 
   {{0x79880e78,0x9eb4cffe,0x00000000,0x00000000}},	//   fbew, _иштә, --, --, 
   {{0x7988fc85,0x78a80113,0x4430009f,0x2ab81bce}},	//   gbew, frev, znz_, rëb_, 
   {{0x78a8fc86,0x290087e5,0xed440588,0xe78400a8}},	//   grev, âka_, _рнап, куно, 
   {{0x6a84fc87,0xe45c0086,0xa5b801ed,0x3f840037}},	//   _алжа, hwör_, ciój, _õlut_, 
   {{0xe3b0fc88,0x87e400cf,0xe9e400d7,0x00000000}},	//   یرس_, _ەتبە, ľúbi_, --, 
   {{0xa924fc89,0xe7e00406,0x569016ab,0x44300399}},	//   _идел, _कोरा_, шают, wnz_, 
   {{0x78a80cfc,0x00000000,0x00000000,0x00000000}},	//   crev, --, --, --, 
   {{0x3cf40574,0x443007c5,0x00000000,0x00000000}},	//   ्हते_, unz_, --, --, 
   {{0xd6d40a52,0x442c04b9,0x27ec011c,0x33380077}},	//   _аты_, đe_, _infn_, _cxpx_, 
   {{0xa5b8fc8a,0x3f1402dd,0xd2340395,0x44300205}},	//   cnóp, ңдас, ансъ, snz_, 
   {{0x92680588,0x94740014,0x65780113,0xdce8025c}},	// [166d0] трра_, _پھُچ, ñuhu, magħ, 
   {{0xf07800fd,0xdce80003,0x00000000,0x00000000}},	//   хифә_, lagħ, --, --, 
   {{0x5064fc8b,0x62647677,0xe1fc011f,0x84140022}},	//   ртта, _لاحق, _toó_, _амҿх, 
   {{0x78a8fc8c,0x6284003d,0xdce80327,0x00000000}},	//   yrev, mpjo, nagħ, --, 
   {{0x61ecfc8d,0x6aa80142,0x7988002f,0x5f740345}},	//   _incl, erff, vbew, _لازر, 
   {{0xe7e000e1,0x78a8030a,0x6aa8015d,0x61ec00d7}},	//   _कोला_, vrev, frff, _hncl, 
   {{0x798813ee,0x9970020a,0x625000d8,0x78a80113}},	//   tbew, қуқш, nçoo, wrev, 
   {{0x798801a4,0x5fb0044b,0xca7400ee,0x00000000}},	//   ubew, ुभवल, шушы, --, 
   {{0x7988fc8e,0x6e400014,0x6aa8fc8f,0x3ea40166}},	//   rbew, _اۆنم, arff, _шиңг, 
   {{0x78a8fc90,0x798878fb,0x270c000d,0x06b80014}},	//   rrev, sbew, ानूर_, ھنُک_, 
   {{0x61ecfc91,0x7988fc92,0xa5b801d3,0xdb040267}},	//   _oncl, pbew, ciók, ålän, 
   {{0xca740075,0xda6400db,0x00000000,0x00000000}},	//   _ئالغ, _شااي, --, --, 
   {{0xe8ec79c2,0xc5f40046,0x867801c6,0xd8742309}},	//   _ул_, рғы_, нөөр_, _شاشب, 
   {{0x61ecfc93,0x7e74030a,0x9420013f,0xe1fc01d3}},	//   _ancl, _ouzp, ɛsɛe_, _fiók_, 
   {{0xdce8003d,0x6250fc94,0x60d8fc95,0xe7b000cf}},	//   bagħ, rçon, _šump, _امىد, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7644fc96,0x6250004a,0x00000000,0x00000000}},	// [166e0] moky, pçon, --, --, 
   {{0x65e401d9,0x764400dc,0xe0d40c98,0xf6c0025c}},	//   स्à_, loky, ыву_, _མྱོང, 
   {{0x47b83fae,0xf1c800d1,0x7fd40220,0x2f540024}},	//   _অসমী, _كودى_, шіті, утас, 
   {{0x7644b985,0x6250fc97,0x6d942586,0x0d840166}},	//   noky, nçol, اشائ, рһан, 
   {{0x4094026a,0x00000000,0x00000000,0x00000000}},	//   _врст, --, --, --, 
   {{0x320000c7,0x7644f3c0,0x00000000,0x00000000}},	//   _hoky_, hoky, --, --, 
   {{0xa11004d3,0x9a800220,0x764412c4,0x32000064}},	//   _نوێت, буыл, koky, _koky_, 
   {{0x497438e0,0x76440083,0x3be800fd,0x249c00e2}},	//   шлис, joky, еләү_, šumi_, 
   {{0x4814fc98,0x712802d3,0x7e74005a,0x76440790}},	//   имис, _ተመሊሶ, _zuzp, doky, 
   {{0x7e74004e,0x2bac2ce6,0x98ac00c0,0xdcac0145}},	//   _yuzp, _घाटा, _lygė_, _رىم_, 
   {{0x6fc405ba,0x76441418,0xa9a40b83,0xdce8025c}},	//   र्यं, foky, _биед, tagħ, 
   {{0x764404ba,0x3ea401bf,0x320001ef,0x00000000}},	//   goky, _ælte_, _noky_, --, 
   {{0x18a000ee,0x889401d5,0x98a001f4,0x00000000}},	//   _гачм, _тилх, _гиче, --, 
   {{0x4424fc99,0xddd80210,0x00000000,0x00000000}},	//   òl_, _biuś, --, --, 
   {{0x32000851,0x179406a9,0x764404ba,0x00000000}},	//   _boky_, _גדול_, boky, --, 
   {{0x7644037e,0xdce8031c,0x91580241,0x62840064}},	//   coky, qagħ, _ọ́_, rpjo, 
   {{0x5184f162,0x00000000,0x00000000,0x00000000}},	// [166f0] суса, --, --, --, 
   {{0x628401e3,0x00000000,0x00000000,0x00000000}},	//   ppjo, --, --, --, 
   {{0x09ac00bd,0x6444fc9a,0x0ee84ed4,0x00000000}},	//   ক্যা, moji, льци_, --, 
   {{0x6444fc9b,0xca3c1df2,0x61ecfc9c,0x8d7400f2}},	//   loji, ﺑﯩﺮ_, _uncl, ماها, 
   {{0x563800c8,0x1aa40037,0x00000000,0x00000000}},	//   נאדע_, _गिहथ, --, --, 
   {{0x6444fc9d,0x320003d1,0x76440083,0xde94007b}},	//   noji, _zoky_, zoky, _مجرب, 
   {{0x3d9453ef,0xfe780364,0x200c0024,0x76440a49}},	//   _вибр, _рӯз_, ūgis_, yoky, 
   {{0x6444fc9e,0x2000fc9f,0x78ac03cd,0x0ae800f1}},	//   hoji, _hoji_, _åavk, اروي_, 
   {{0x20001326,0x5ba46e27,0xa5b801d3,0xf090010f}},	//   _koji_, _брез, ciói, ֿנט_, 
   {{0x64443142,0x2000009f,0x7644b9b9,0x28a40037}},	//   joji, _joji_, woky, _खिरि, 
   {{0x6444fca0,0x7644fca1,0xc02c0092,0xa5b80210}},	//   doji, toky, _ተከትለ, niów, 
   {{0x20000092,0x00000000,0x00000000,0x00000000}},	//   _loji_, --, --, --, 
   {{0x3200fca2,0x7644fca3,0x644400d2,0x260801ad}},	//   _roky_, roky, foji, ासजी_, 
   {{0x644487da,0xb4d40d0a,0xa018e4c3,0x320000a2}},	//   goji, _सनी_, _stön, _soky_, 
   {{0xe294fca4,0x32000076,0x764400c7,0x00000000}},	//   иар_, _poky_, poky, --, 
   {{0x660cfca5,0x2248020b,0xa5f40063,0xa92402d2}},	//   ckck, _ckck_, _већу_, _umþó, 
   {{0x6444fca6,0x320003d1,0x48e83f6f,0x00000000}},	// [16700] boji, _voky_, जियो_, --, 
   {{0x6444fca7,0xc7b801fa,0x2000b71a,0x63b00bd6}},	//   coji, biđu_, _coji_, _мәсх, 
   {{0x32000170,0x23f806a9,0x8180001f,0x74d81a22}},	//   _toky_, _ספטמ, ያስችሉ_, _पैतृ, 
   {{0x6278011a,0x00000000,0x00000000,0x00000000}},	//   _שנכנ, --, --, --, 
   {{0xf1c80150,0x00000000,0x00000000,0x00000000}},	//   _كوگى_, --, --, --, 
   {{0x5bb4003b,0x5ce00137,0x00000000,0x00000000}},	//   илія_, زكىل, --, --, 
   {{0xa5b8012d,0xa038010f,0x00000000,0x00000000}},	//   ciów, _סעלפ, --, --, 
   {{0x644400ec,0xce3410ac,0x49d868dd,0xe94400f3}},	//   zoji, _اورک, удию_, ихпо, 
   {{0x6444fca8,0x9a6400c6,0x200000b5,0xc7b80cf4}},	//   yoji, جميل_, _yoji_, ziđu_, 
   {{0x9cd40375,0x2000022e,0x644401a9,0x7c2c7471}},	//   _דומה_, _xoji_, xoji, éart, 
   {{0xd6d4fca9,0xf1d40034,0xd7f425a2,0x2fc8004d}},	//   атя_, डजान, руы_, _mbbg_, 
   {{0xa01805d1,0xea6001d3,0x00000000,0x00000000}},	//   _atöl, _بھتی, --, --, 
   {{0x6444fcaa,0x0ca40034,0xe7840137,0xc1c800d1}},	//   toji, _ऑटोम, _куйо, һтаҗ_, 
   {{0x2248020b,0x00000000,0x00000000,0x00000000}},	//   _skck_, --, --, --, 
   {{0xe1f000b2,0x2000003e,0x43940150,0x00000000}},	//   يسر_, _roji_, _қанс, --, 
   {{0x52140d5c,0x200023db,0x644467e9,0x26cc0393}},	//   одст, _soji_, soji, _ipfo_, 
   {{0x6444fcab,0x00000000,0x00000000,0x00000000}},	// [16710] poji, --, --, --, 
   {{0x73c000fd,0x27fc0175,0x00000000,0x00000000}},	//   _нәсе, njtn_, --, --, 
   {{0xde4400aa,0x00000000,0x00000000,0x00000000}},	//   لیسو_, --, --, --, 
   {{0x09ac09bd,0x249c005f,0xe45c01e6,0xc7b80208}},	//   ক্তা, šumu_, stöd_, hgđ_, 
   {{0x3cc802f4,0x8d7403e6,0xfce4fcac,0x2000fcad}},	//   улло_, زانا, соло, _toji_, 
   {{0x9550067d,0xd9dc00af,0x0c240212,0xa5b801d3}},	//   _መንእሰ, _खोजत_, омін, cióv, 
   {{0x60cc0066,0xba7401ec,0x3f80016d,0xa5b80332}},	//   _hpcm, حاتت, mchu_, mhóf, 
   {{0x3f80fcae,0x5338011a,0x3ea0036e,0x00000000}},	//   lchu_, ינון_, msht_, --, 
   {{0x37740831,0x395817c0,0x7c2c01e7,0x7bc40037}},	//   йынс, åss_, éars, õhus, 
   {{0x3f80636d,0x9610547d,0x6fc80490,0xa21000b8}},	//   nchu_, ास्ट_, स्पू, _pāśā_, 
   {{0x26cc007f,0xf744fcaf,0x37e401d5,0x62500200}},	//   _cpfo_, сено, _ҳолг, rçoj, 
   {{0xa018691c,0x3ea01368,0x3f800842,0x00000000}},	//   _stöl, isht_, hchu_, --, 
   {{0xe8ecbd75,0x26cc015c,0x3f800986,0xe7e005d7}},	//   _эл_, _epfo_, kchu_, _कोका_, 
   {{0x1cb849a6,0x3a2c4190,0x7998198f,0x63801149}},	//   _མཱན_, liep_, _heww, згра, 
   {{0x3f80016d,0x960401c6,0x3ea00200,0x00000000}},	//   dchu_, _дүнж, jsht_, --, 
   {{0x3f804d90,0xf9a401e1,0x00000000,0x00000000}},	//   echu_, _èède_, --, --, 
   {{0x2878008f,0x3ea00076,0x3158007b,0x00000000}},	// [16720] ָנעמ, esht_, اجأة_, --, 
   {{0x3a2c001e,0x79980ba7,0x60cc03ac,0x3f80047e}},	//   hiep_, _leww, _dpcm, gchu_, 
   {{0x3a2c002d,0xaec401ec,0xa854011a,0x00000000}},	//   kiep_, сбел, ציעה_, --, 
   {{0x7998030d,0xee38cb43,0x3f80208d,0xcfd80154}},	//   _neww, ыне_, achu_, সাইন, 
   {{0xccf86287,0x3a2cfcb0,0xa5b8fcb1,0x3f80047e}},	//   шқа_, diep_, miót, bchu_, 
   {{0x3f80fcb2,0x00000000,0x00000000,0x00000000}},	//   cchu_, --, --, --, 
   {{0x7998009a,0x602c0153,0xfba80212,0xee900133}},	//   _beww, _dėmė, ртій_, _رگاک, 
   {{0xf3fc0154,0xa5b801e7,0x70500244,0x00000000}},	//   ঁসির_, mhóg, _بۆڕا, --, 
   {{0x84680882,0x79980327,0x9f5c01b8,0x26cc0327}},	//   dṛṣṭ, _deww, ürön_, _spfo_, 
   {{0x47341bb8,0x6b6000e5,0x00000000,0x00000000}},	//   жнос, gígé, --, --, 
   {{0x09e0009e,0xe66401b9,0x321001f4,0x6fc81be1}},	//   ভাবা, йтмо, kkyy_, स्यू, 
   {{0x6b98fcb3,0x79980135,0x3a2c0810,0x3f800210}},	//   _hetg, _geww, ciep_, zchu_, 
   {{0x3f80bfbe,0x6b9807d6,0xa01801c7,0xe774070e}},	//   ychu_, _ketg, _stöm, _лалә_, 
   {{0x4adc19ec,0x39580730,0x39c4063f,0xd94000ee}},	//   _मनाव, üsse_, ịsti_, _эечи, 
   {{0x6b98fcb4,0x79981574,0xdc34008f,0x54540212}},	//   _metg, _yeww, צאלט_, ївст, 
   {{0x5334165d,0x63b404ac,0x6b9807de,0x799800e8}},	//   чест, _ŝanĝ, _letg, _xeww, 
   {{0x6250fcb5,0x3f80047e,0x93140014,0xa5b800ae}},	// [16730] nçoi, tchu_, _ہوٝش, thóf, 
   {{0x6b980006,0x249c005f,0xa5b80332,0x00000000}},	//   _netg, šums_, fhóg, --, 
   {{0x3ed4fcb6,0x3f80fcb7,0xa5b8748d,0x6018fcb8}},	//   تقار, rchu_, biót, _nîme, 
   {{0x3f80fcb9,0xcd800023,0x602c0064,0x7c6400f1}},	//   schu_, _ንበይና_, _sėmė, ښاغل, 
   {{0x6b981570,0x0dc8013e,0x7998fcba,0x3f80016d}},	//   _betg, сухи_, _reww, pchu_, 
   {{0x3ea00023,0xe0dc01e1,0x92cc0183,0x7998003d}},	//   psht_, _isò_, লিৰ_, _seww, 
   {{0xb4d40aff,0xf9900597,0x6b9807de,0x3a2cfcbb}},	//   _सन्_, وبة_, _detg, tiep_, 
   {{0x8e746d6c,0x6b98fcbc,0x2eec00b5,0x00000000}},	//   _رافض, _eetg, æffe_, --, 
   {{0x6b98fcbd,0x4c940276,0x95b40075,0x78380120}},	//   _fetg, _нитс, үрмә, иџот_, 
   {{0x3a2c0369,0x7998014f,0x50dc010f,0x00000000}},	//   siep_, _weww, רקזא, --, 
   {{0xe0dc007f,0x3a2c01a4,0x00000000,0x00000000}},	//   _kyòs_, piep_, --, --, 
   {{0x3cecfcbe,0xe0dc033b,0x0ab4fcbf,0x00000000}},	//   _krev_, _osò_, _رحمد, --, 
   {{0x6b98036b,0xe1fc0332,0x00000000,0x00000000}},	//   _yetg, _mhód_, --, --, 
   {{0xa5b800e4,0x00000000,0x00000000,0x00000000}},	//   fiós, --, --, --, 
   {{0xe0dc0248,0xe7e03812,0x601800c7,0xd76402de}},	//   _asò_, _कोटा_, _oîmb, _دەدى_, 
   {{0x87040220,0x32040162,0xa5b800e5,0x00000000}},	//   _ءبول, ðoy_, ghód, --, 
   {{0xa5b80005,0x3004665a,0x200401a9,0x321001f4}},	// [16740] riót, озаг, аni_, rkyy_, 
   {{0xab600790,0xb3180327,0xd5c400ef,0xa5b800ae}},	//   çükk, ུནདང_, _drāž_, thóg, 
   {{0x6da4fcc0,0x6b9807de,0xdfcc0451,0x668c0092}},	//   قمام, _retg, ئيم_, _የተስፋ_, 
   {{0xdd8cfcc1,0x6b98fcc2,0xece8fcc3,0xe1fcfcc4}},	//   نوم_, _setg, идел_, _chód_, 
   {{0x4c94fcc5,0xce3400dd,0xdca02763,0x6b9807de}},	//   чилс, _ہوسک, дачи, _petg, 
   {{0x3cecfcc6,0x2aa80640,0xe1fc01e7,0x7bc40037}},	//   _drev_, атио_, _phóg_, õhup, 
   {{0x6b980373,0x3cec0165,0xe1fc01e7,0x00000000}},	//   _vetg, _erev_, _fhód_, --, 
   {{0x6b98fcc7,0xa8a4468b,0xe0dc007f,0x5ba40139}},	//   _wetg, орок, _tyòt_, бкәм_, 
   {{0x3cecfcc8,0x6b9807de,0x00000000,0x00000000}},	//   _grev_, _tetg, --, --, 
   {{0x6250004a,0xe1fc00c6,0x6018054e,0x00000000}},	//   rçoi, _thóg_, _zîmb, --, 
   {{0xa018b625,0x24cc009e,0x9f4405d1,0xbad40064}},	//   _stök, িয়াহ, ınç_, _ніцы, 
   {{0x6fc8e698,0xe1fc004d,0x270c0213,0xdb0001e7}},	//   स्तू, _khóe_, həng_, agnó, 
   {{0xa92400c6,0xa968030d,0x00000000,0x00000000}},	//   _بعضه, _тида_, --, --, 
   {{0x1864fcc9,0x25bc0003,0xe72805af,0x8798009f}},	//   _дачи_, żul_, _پستو_, _اَثر_, 
   {{0xa5b801e7,0x26d8fcca,0x00000000,0x00000000}},	//   thód, _èpo_, --, --, 
   {{0x09ac00bd,0xe1fc0005,0xd6280640,0xa5b8003a}},	//   ক্রা, _riós_, _моје_, riós, 
   {{0xa018049f,0x78ac03cd,0xe1fc0208,0xff18010e}},	// [16750] _utök, _åavt, _nhóe_, _òäzå_, 
   {{0x200409cc,0xe1fc067c,0xdb0005d5,0x6018054e}},	//   ðni_, _piós_, tgnü, _sîmb, 
   {{0x4430fccb,0xf4100375,0xa2800066,0x00000000}},	//   miz_, _נפט_, _آیرو, --, 
   {{0xc17404d3,0x3cfc01d4,0xdb0003fa,0x3cec8d10}},	//   _رگرت, txwv_, rgnü, _prev_, 
   {{0xe0dc011c,0xfe78013e,0xe1fc0208,0xf8d800bc}},	//   _usò_, рӯҳ_, _chóe_, _भनेप, 
   {{0x4430fccc,0xeb949b63,0xacb00131,0x00000000}},	//   niz_, пиш_, رمىغ, --, 
   {{0x4ea4fccd,0x601800d2,0x9f400240,0x00000000}},	//   _орта, _tîmb, _majë_, --, 
   {{0x4430fcce,0x3cecfccf,0xa01832e9,0x28a40406}},	//   hiz_, _trev_, _stöh, _खिखि, 
   {{0xe8f4fcd0,0x270c06be,0x00000000,0x00000000}},	//   злы_, hənd_, --, --, 
   {{0x443001b9,0xcaf40451,0x999c0327,0x270c03e3}},	//   jiz_, _ڊسمب, lluż_, kənd_, 
   {{0x6c6800f8,0x443001c6,0x7bc0014b,0x290005ac}},	//   _اللہ_, diz_, _iclu, økar_, 
   {{0xa5b80210,0xd1f80092,0x00000000,0x00000000}},	//   wiór, ፈቱት_, --, --, 
   {{0x4430fcd1,0xbabc03d4,0x6fbc00dc,0x9f400200}},	//   fiz_, _আনিছ, शलमू, _bajë_, 
   {{0x37e4010b,0x00000000,0x00000000,0x00000000}},	//   _хокг, --, --, --, 
   {{0xe3b41d18,0x36680640,0xe360399f,0x9f40036e}},	//   ябр_, _лако_, екри, _dajë_, 
   {{0xe238044e,0x443005c7,0x78ac03cd,0x6b6000e5}},	//   _የብልና, aiz_, _åavs, _hígí, 
   {{0x7bc00936,0x2164fcd2,0xd76400f7,0xe1fc0210}},	// [16760] _oclu, зити_, _دەگى_, _piór_, 
   {{0x443081d7,0x9f4001e1,0x98ac0024,0x270c06be}},	//   ciz_, _kajè_, _lygį_, bənd_, 
   {{0x7ae0007f,0x84443226,0x00000000,0x00000000}},	//   _nslt, _تخيل, --, --, 
   {{0x7bc066c5,0x9f4002e2,0xe45c0108,0x00000000}},	//   _aclu, _majè_, ntön_, --, 
   {{0x2014066d,0x9f40033b,0x4b3401d3,0x846c0240}},	//   áció_, _lajè_, ڈکاس, በረሉን_, 
   {{0x2918002b,0x4b344992,0x00000000,0x00000000}},	//   _āpa_, وکاس, --, --, 
   {{0x62500240,0x4f740150,0x00000000,0x00000000}},	//   rçov, _ﺟٶﺑﺎ, --, --, 
   {{0x7bc04380,0xc85802d3,0x8afc033f,0xec786885}},	//   _eclu, _ምብራቕ, _rzęd, _гпа_, 
   {{0x4430fcd3,0x00000000,0x00000000,0x00000000}},	//   yiz_, --, --, --, 
   {{0xe1fc0016,0x7bc000c6,0x625000cf,0x395804cc}},	//   _khóc_, _gclu, lçot, üssa_, 
   {{0x7ae00998,0x9548001f,0x2eb8000d,0xbbe8007b}},	//   _gslt, _ያስከተ, _उमोत, _برقم_, 
   {{0x4430fcd4,0x2d84007f,0x9f400023,0xe45c01d3}},	//   wiz_, ncoe_, _sajë_, gtön_, 
   {{0x2ca4113c,0x7bc00076,0xd56407b5,0x9f400200}},	//   nsod_, _yclu, етрп, _pajë_, 
   {{0x68e0fcd5,0x601800c7,0x2a7c00a2,0x443005c7}},	//   _isod, _oîma, _kutb_, uiz_, 
   {{0x268800c6,0xe1fc01fb,0xd6ccfcd6,0xd7c412ea}},	//   _اختي_, _nhóc_, _ят_, _رويه_, 
   {{0x4430fcd7,0x2ca4000d,0x2bfc01f9,0x00000000}},	//   siz_, ksod_, लाडू_, --, 
   {{0x4430fcd8,0x69dc0134,0xd0d40395,0x00000000}},	// [16770] piz_, _ɔpep, нотъ, --, 
   {{0x68e00161,0x2ca41c06,0x4430df83,0x00000000}},	//   _msod, dsod_, qiz_, --, 
   {{0x36240014,0xe1fc004d,0xa5b801e7,0x601003e0}},	//   _رویہ, _chóc_, chóc, _rımı, 
   {{0x68e0fcd9,0x7bc0fcda,0xfd580ca8,0x60180142}},	//   _osod, _sclu, _igbẹ, _dîma, 
   {{0x68e001e1,0x3cfc01f9,0x00000000,0x00000000}},	//   _nsod, लमधे_, --, --, 
   {{0x30a401d9,0x69c000d8,0x60102b93,0x00000000}},	//   _زلفہ, _acoe, _qımı, --, 
   {{0xd9c00729,0x69c00354,0x68e00bd7,0xe45c02f6}},	//   ্যসম, _bcoe, _asod, ytön_, 
   {{0x2ca4037e,0x00000000,0x00000000,0x00000000}},	//   bsod_, --, --, --, 
   {{0x68e000dd,0x9f40007f,0x60100166,0x37e000eb}},	//   _csod, _sajè_, _tımı, বাসর, 
   {{0x09e00729,0xb904081e,0x69c05cca,0x7bc006be}},	//   ভাষা, _पन_, _ecoe, _uclu, 
   {{0x9f402e3d,0x3668fcdb,0xfb1400c6,0x5fcc012c}},	//   _bajé_, жано_, _تواج, स्यल, 
   {{0xf93400a7,0xe61400d4,0x391401f4,0x28a400bc}},	//   _охлю, ддю_, _омер, _खिचि, 
   {{0xfd580248,0xe45c01d3,0x00000000,0x00000000}},	//   _agbẹ, rtön_, --, --, 
   {{0xb4cc1b4c,0xe45c02f6,0x00000000,0x00000000}},	//   _रही_, stön_, --, --, 
   {{0x9f40002e,0x09e0015b,0xf6240120,0x69c002d0}},	//   _fajé_, ভারা, _одко, _ycoe, 
   {{0x42540276,0x00000000,0x00000000,0x00000000}},	//   етут, --, --, --, 
   {{0xa0a005bc,0x6280004a,0xafe4036b,0xf42801f0}},	// [16780] катд, _énon, моал, _моил_, 
   {{0x2ca4151c,0xe4d440ec,0x290002b5,0xe0cc0014}},	//   vsod_, _کویت_, äkai_, شٲم_, 
   {{0x2f54059f,0xd7cc081e,0xe2940108,0x00000000}},	//   фтас, त्यच, _оаэ_, --, 
   {{0xf1e0302b,0x2ca40254,0x00000000,0x00000000}},	//   _पसिन, tsod_, --, --, 
   {{0x2ca40280,0xd04400c7,0xd5e40208,0x00000000}},	//   usod_, _зҭак, _chỉ, --, 
   {{0xa0180267,0xe1fc004d,0x60180142,0x2ca401d3}},	//   _stöv, _thóc_, _tîma, rsod_, 
   {{0x2a7cfcdc,0x68e0025c,0xaaac0073,0xaa64fcdd}},	//   _qutb_, _ssod, _टिळक, мтик, 
   {{0xe1fc07ae,0x31600211,0xb4cc05f9,0x6df4007b}},	//   _khóa_, _kzkz_, _रहू_, _تكرا, 
   {{0x781c069c,0x6e200332,0x00000000,0x00000000}},	//   _ስለዝኾ, mhob, --, --, 
   {{0x6e20fcde,0xeaf824e0,0x7c640131,0x9b90007b}},	//   lhob, _ورات_, _كالل, _للكت, 
   {{0x5c3427af,0x1be416da,0x00000000,0x00000000}},	//   _קרבן_, _टोटल_, --, --, 
   {{0xa018049f,0x6e20d3ff,0x68e0fcdf,0x27ec012d}},	//   _utöv, nhob, _tsod, _żoną_, 
   {{0x68e0fce0,0xd90c00dd,0xc8c804fb,0xf988030f}},	//   _usod, _نیٹ_, _روغن_, _رخنه_, 
   {{0xd7f002dd,0x6e2001a9,0x58d04f0c,0x270c03b9}},	//   _азшы, hhob, _рошт, gənc_, 
   {{0x2a640211,0x6e20fce1,0x9f400241,0x00000000}},	//   _khob_, khob, _tajé_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x48bc00bd,0x2a640368,0xd49800a8,0xe1fc0208}},	// [16790] _অনুর, _mhob_, _орэ_, _chóa_, 
   {{0xefd402d3,0x716400d1,0xaaac134e,0x00000000}},	//   _ካበይ_, رپلە, _टिंक, --, 
   {{0x4fc40395,0xd13000f1,0x00000000,0x00000000}},	//   ъста, همې_, --, --, 
   {{0xdb000798,0x62503756,0x6e20fce2,0xf2d0010f}},	//   banê, rços, ghob, _געט_, 
   {{0x65680192,0x00000000,0x00000000,0x00000000}},	//   _ùghd, --, --, --, 
   {{0x75f40724,0x7d180724,0xb0980375,0x48bc00eb}},	//   _küzä, _ğası, _מישר, _অনূর, 
   {{0xdb0002d3,0x6e20cf3e,0x60200118,0x00000000}},	//   manë, bhob, růmě, --, 
   {{0x2a64fce3,0x6e20fce4,0x75f40166,0xdb000200}},	//   _chob_, chob, _müzä, lanë, 
   {{0xb4cc8d8b,0x5fcc21b8,0x05200154,0xe45c007c}},	//   _रहे_, स्थल, নপুর_, ttöl_, 
   {{0xb8f800c6,0x3704026b,0x1a6401e2,0x7d2003e0}},	//   _ॡई_, епог, سیږی_, ızsı, 
   {{0x98a80ab7,0xdce80724,0xe7a401c6,0x00000000}},	//   ğlık_, magı, эвэл_, --, 
   {{0x98a81918,0x2a64016d,0x601800e4,0xdb00036e}},	//   şlık_, _ghob_, _oîmo, hanë, 
   {{0xdb0002d3,0x79880198,0xe61000db,0x00000000}},	//   kanë, mcew, اشپ_, --, 
   {{0xf744119e,0xc8f801d5,0xdb00036e,0x489801d3}},	//   _пело, _آووچ_, janë, _آئند_, 
   {{0x78a80228,0x8d7402d3,0xfd640051,0xdb00036e}},	//   lsev, እትታው_, _chuẫ, danë, 
   {{0x7988fce5,0x6e20021a,0x56f0009d,0x00000000}},	//   ncew, xhob, _зүүс, --, 
   {{0xb144fce6,0x888c008f,0x146400c7,0x09ac0eac}},	// [167a0] хнал, ַראַ, _иеиҭ, ক্কা, 
   {{0xf42805f5,0x78a8fce7,0xdb000023,0x00000000}},	//   _хоол_, isev, ganë, --, 
   {{0x6e20e4ed,0x75f400fd,0x7988012d,0xe39800d9}},	//   thob, _güzä, kcew, _משיכ, 
   {{0xa018049f,0x6fc00490,0xa5b800d2,0xdb00fce8}},	//   _stöt, _लावू, hhón, manè, 
   {{0x6e2002c4,0xa5b800d2,0x78a8005c,0xb4cc08e9}},	//   rhob, khón, jsev, _रहो_, 
   {{0x6e20633d,0xb4cc0927,0x78a8fce9,0x2a640076}},	//   shob, _रहै_, dsev, _shob_, 
   {{0x6e20fcea,0x63a0033d,0xa06459b7,0x79880198}},	//   phob, _õnne, _чара_, fcew, 
   {{0x2a640218,0x6e2077e8,0x27f000a2,0x00000000}},	//   _qhob_, qhob, _şyn_, --, 
   {{0xdd8c7c3c,0x7a0800aa,0x78a84bc1,0x58d40006}},	//   _طول_, بډلې_, gsev, едыя_, 
   {{0x26c006c8,0x2f240248,0xdce805d1,0xc61800dc}},	//   ̄kou_, _gígé_, cagı, दस्य_, 
   {{0x78a800e4,0x2a640055,0x4ad401f9,0x69f00150}},	//   asev, _thob_, _दहिव, _бүйт, 
   {{0x5fc40490,0xdb000240,0x78a82bcc,0x75f40166}},	//   _लाभल, zanë, bsev, _rüzä, 
   {{0xba2800c6,0xe70801d5,0x75f40139,0xa5b80332}},	//   _تسلم_, زتگن_, _süzä, bhón, 
   {{0xe45c0008,0xdb000ba1,0x4ad40490,0x290002b1}},	//   mtök_, fanè, _दहाव, äkau_, 
   {{0x81c400bd,0xdb00fceb,0xb9cc02d3,0x75f40139}},	//   _এসব_, ganè, _ሱቕ_, _qüzä, 
   {{0x7eb0035b,0xd2580556,0x44f400f3,0x00000000}},	//   _ẽpot, ецу_, _апис, --, 
   {{0xdb000240,0xe1fc01e7,0x00000000,0x00000000}},	// [167b0] tanë, _fhón_, --, --, 
   {{0x9f680276,0xfd6401fb,0xdb00180f,0x0fe400f7}},	//   през_, _thuẫ, banè, лөсү, 
   {{0x63a404ac,0xdb00fcec,0x4420180f,0xfc302fc0}},	//   majn, ranë, _ilh_, یحت_, 
   {{0x63a4fced,0x442002d2,0x9f4001a8,0x00000000}},	//   lajn, _hlh_, _snjó_, --, 
   {{0x93340201,0x4420fcee,0xdb00fcef,0x6aa8015d}},	//   _አስተዳ, _klh_, mané, esff, 
   {{0x63a4fcf0,0x7118011a,0x00000000,0x00000000}},	//   najn, _חושפ, --, --, 
   {{0x1ce00489,0x4420020b,0x0ba8007b,0x00000000}},	//   _ཨནམ_, _mlh_, راوى_, --, 
   {{0x78a8fcf1,0x657c009a,0xdb000306,0x4420fcf2}},	//   tsev, _ngqh, nané, _llh_, 
   {{0x9f400316,0x7988576c,0x63a405be,0xa6e0022c}},	//   _mají_, rcew, kajn, áðnu, 
   {{0x63a4fcf3,0x4420fcf4,0x9a8401b9,0xdb0042b4}},	//   jajn, _nlh_, _зудл, hané, 
   {{0x63a48c08,0xf7443849,0x7e68014b,0x2bd80014}},	//   dajn, тено, _khep, _زالک_, 
   {{0x4420fcf5,0x78a800af,0xa5b800d2,0xdb0002e2}},	//   _alh_, psev, shón, vanè, 
   {{0x4420970d,0x66d401b8,0x7e680433,0xdb00fcf6}},	//   _blh_, _pükö, _mhep, dané, 
   {{0x63a4fcf7,0x442001ab,0xdb000214,0x867830ab}},	//   gajn, _clh_, tanè, мөөр_, 
   {{0x7e680124,0x44206a3c,0xfbc80073,0xdce80327}},	//   _ohep, _dlh_, _रानम, bbgħ, 
   {{0xdb00fcf8,0x4420fcf9,0x7e68006f,0x00000000}},	//   gané, _elh_, _nhep, --, 
   {{0xe3e4571d,0x63a4fcfa,0x9f4000bc,0xdb0000f2}},	// [167c0] رکین_, bajn, _dají_, sanè, 
   {{0xa018fcfb,0x7e6800e4,0x44200175,0xdb001801}},	//   _stör, _ahep, _glh_, panè, 
   {{0xa5b8fcfc,0xdb00a597,0xaec443a2,0x80c400cf}},	//   khól, bané, тбел, _ەڭمە, 
   {{0x7c20fcfd,0x7e68fcfe,0xdb003df9,0x00000000}},	//   _allr, _chep, cané, --, 
   {{0x7e68c2d7,0x442000a2,0x6aa8015d,0x7334179e}},	//   _dhep, _ylh_, wsff, _سرگئ, 
   {{0x7e68fcff,0x1d040640,0x99c00154,0x0c380e56}},	//   _ehep, тељи_, ্যোক, ةكتة_, 
   {{0xdbdc0321,0xee3800c0,0xa5b802d2,0x00000000}},	//   ríðu, _жнв_, fhól, --, 
   {{0xdbdc09cc,0x7e68fd00,0xbb340020,0xdce80327}},	//   síðu, _ghep, _እንችላ, xbgħ, 
   {{0xace801c0,0xefb80092,0x3c4001d9,0x63a4047e}},	//   _юмаа_, _ሲሄድ_, _گێوِ, yajn, 
   {{0xd7f445b3,0xfbc800bc,0xdb000646,0x98a000d8}},	//   вую_, _रायम, zané, јиќе, 
   {{0x1cbc0135,0xda6c0276,0xe45c0008,0xdb00020c}},	//   _ཀའོ_, _вя_, stök_, yané, 
   {{0xeac80086,0x7e680023,0xa5b80306,0x63a40113}},	//   arùò_, _xhep, lióz, wajn, 
   {{0xdb000232,0x9f4401a2,0x44200175,0xfbc8146b}},	//   vané, ľné_, _plh_, _रामम, 
   {{0x9f440745,0xdb000c6a,0x73c00139,0x00000000}},	//   žné_, wané, бәюе, --, 
   {{0xdb00fd01,0xbd900023,0xa1840139,0x00000000}},	//   tané, _ዝጠቅም_, вызл, --, 
   {{0x63a4fd02,0xb76402bf,0x56900fc0,0x44200009}},	//   sajn, _стій, _таът, _wlh_, 
   {{0xe4680372,0xdb00fd03,0x44200978,0x1fa47738}},	// [167d0] _ошол_, rané, _tlh_, врег, 
   {{0x4420003e,0xdb0002f0,0x63a4fd04,0x00000000}},	//   _ulh_, sané, qajn, --, 
   {{0x7e6898ac,0x9f40fd05,0xa5b800d2,0xdb009c9b}},	//   _phep, _tají_, hhóm, pané, 
   {{0x7e6803f0,0xe1fc0208,0xf8b80022,0x00000000}},	//   _qhep, _khóm_, yrũ_, --, 
   {{0x2164fd06,0xcce4007b,0x4254e750,0x2004000d}},	//   _штог, لسوي, _لنگر, önis_, 
   {{0xfbc40c69,0xb7bc015b,0xfaa40351,0xbb4413d6}},	//   убко, _অস্ট, гако, лелк, 
   {{0x7e680184,0xfcc80023,0x00000000,0x00000000}},	//   _thep, በለጸ_, --, --, 
   {{0xaa540063,0x00000000,0x00000000,0x00000000}},	//   лију_, --, --, --, 
   {{0xe1fc07ae,0xa5b801a8,0x00000000,0x00000000}},	//   _nhóm_, rhól, --, --, 
   {{0x1cb0025c,0xa5b81a85,0x8d9401e2,0x515c011a}},	//   _དྷར_, cióz, _ملېش, וכחו, 
   {{0x35a4f610,0xe1fc0270,0x59b0b071,0xe69001b9}},	//   ланг, _onó_, _көпс, یلید, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xefb80092,0xe6140395,0xc984205a,0x00000000}},	//   _ሲሄዱ_, удя_, _тухи, --, 
   {{0xdb000227,0x7ab8012d,0xa93800df,0x00000000}},	//   nanï, ैंपअ, _אײני, --, 
   {{0x9f4007de,0x00000000,0x00000000,0x00000000}},	//   _najà_, --, --, --, 
   {{0xa018fd07,0xe69000c6,0xe1fc007b,0xd7cc01bc}},	//   _stöp, _اليد, _cnó_, त्रच, 
   {{0x00840e26,0x00000000,0x00000000,0x00000000}},	// [167e0] иктү, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x290001f2,0x1cbc031c,0xbe84007b,0x00000000}},	//   ̣ka_, _ཀའུ_, لجنو, --, 
   {{0xe1fc0597,0x249401d3,0x6da401a9,0xa5b80210}},	//   _gnó_, _جنید_, уида, wióz, 
   {{0xfe704d2d,0xa5b80ad9,0x321c0153,0x00000000}},	//   ڭدە_, skóg, ūtys_, --, 
   {{0xa0180793,0x9eb40139,0x00000000,0x00000000}},	//   _utöp, _әшрә, --, --, 
   {{0xc984472b,0xa5b83656,0xb9100055,0x602000d8}},	//   қуқи, rióz, _itaṃ_, _удра, 
   {{0xd5e4004d,0xca1402e8,0x1d20ae3e,0x88d800cc}},	//   _nhì, рдиъ, рмәм, তিসক, 
   {{0x02e02007,0x4aa409fa,0xed44fd08,0x59d000c6}},	//   _पन्न, _गौरव, _снап, صغير, 
   {{0x7aec012d,0x00000000,0x00000000,0x00000000}},	//   łata, --, --, --, 
   {{0xfbc800bc,0x00000000,0x00000000,0x00000000}},	//   _रातम, --, --, --, 
   {{0xd1043eb6,0x9f4001e1,0x06840131,0xd5e40051}},	//   रमाण_, _jajá_, лгүн, _chì, 
   {{0xb9100055,0x00000000,0x00000000,0x00000000}},	//   _otaṃ_, --, --, --, 
   {{0xd90c1968,0x9f4001e1,0xb910002b,0x26000073}},	//   _ریپ_, _lajá_, _ntaṃ_, षाही_, 
   {{0xbb3402d3,0x2bd41fbc,0x7d180210,0x15d002dd}},	//   _እንተላ, ढ्या, zyws, _ﻛﯚﺍﺩ, 
   {{0xd1c805f5,0xb9100055,0x923c001f,0x27ec02d2}},	//   лууд_, _ataṃ_, _አብርሃ, _hafn_, 
   {{0xbf1c0cb4,0x2fc8fd09,0xb2740022,0x00000000}},	// [167f0] पन्न_, _bcbg_, рктә, --, 
   {{0x73c04d50,0x27ec0008,0x9f4007c5,0x395804cc}},	//   _мәсе, _jafn_, _pajà_, üssi_, 
   {{0x5064fd0a,0xb0500014,0xbb4c0150,0x81d42cdd}},	//   стта, تھَت, _ﺍﺬﻫ_, _конх, 
   {{0x5184fd0b,0x5fc40574,0xbdd4d7b1,0xb91000cd}},	//   _гура, _लावल, родщ, _etaṃ_, 
   {{0x21040014,0x00000000,0x00000000,0x00000000}},	//   _صبحَ, --, --, --, 
   {{0x27ec008c,0x3dc8003d,0x61ec0042,0x9f4001e1}},	//   _nafn_, żaw_, _hacl, _tajà_, 
   {{0x61ecfd0c,0x00000000,0x00000000,0x00000000}},	//   _kacl, --, --, --, 
   {{0x61ec0009,0xbd8400d1,0x1c0009b2,0x00000000}},	//   _jacl, _ئەشۇ_, लाहल_, --, 
   {{0xbb340201,0x61ecfd0d,0x1cbc081f,0x6d880583}},	//   _እንዲሁ, _macl, _ཀའི_, _شملہ_, 
   {{0xcd340375,0xaaac0574,0x1ba800dd,0x27ec0042}},	//   _طرقب, _टिचक, _سائٹ_, _cafn_, 
   {{0x99d46d6c,0x27ec01b9,0x00000000,0x00000000}},	//   _متشا, _dafn_, --, --, 
   {{0x1c0004fa,0x61ecfd0e,0xdb004eb7,0xe734011b}},	//   लावल_, _nacl, naní, рею_, 
   {{0x59640801,0xd5e401fb,0x1dd45444,0x00000000}},	//   _съжа, _chí, ण्यत, --, 
   {{0x61ec0139,0xdb000419,0xc8b40101,0x00000000}},	//   _aacl, haní, _الوک, --, 
   {{0xdb00e9f0,0x323401f0,0xd5e40051,0x63b000c7}},	//   kaní, ахас, _thì, цәых, 
   {{0x61ec01ab,0xdb00fd0f,0xb91000b8,0x00000000}},	//   _cacl, janí, _staṃ_, --, 
  
   {{0x20843f36,0xdb00fd10,0x61ecfd11,0x26000073}},	// [16800] ийти_, daní, _dacl, षारी_, 
   {{0x1cb0025c,0xaf941f5a,0xe430007b,0x00000000}},	//   _དྷེ_, ршај, _وفيد, --, 
   {{0x61ec0013,0x442c02a8,0xdb00fd12,0x9fa00321}},	//   _facl, ɗe_, faní, ríði_, 
   {{0x61ec01c3,0xdb00fd13,0x7644fd14,0xee386a7c}},	//   _gacl, ganí, nnky, ъне_, 
   {{0x32000072,0x7644fd15,0x5ea000d1,0x2a340014}},	//   _inky_, inky, ممەل, یقتھ_, 
   {{0x61ec043b,0xa0a0013e,0x245c0022,0x00000000}},	//   _zacl, _фард, tîmi_, --, 
   {{0xdb00fd16,0x7aec0034,0x0c680220,0x6da40212}},	//   baní, łatn, _ұзақ_, _виба, 
   {{0x999402e8,0x61ec0139,0x27ecfd17,0xdb000419}},	//   акът_, _xacl, _safn_, caní, 
   {{0xec78fd18,0x245c00d2,0x628000d8,0xfe701f0d}},	//   _апа_, sîmi_, _énov, _ردِ_, 
   {{0x47d421ec,0x1b400014,0xa5b800ae,0x764401f4}},	//   حيدر, _ژھٹُ, mhói, enky, 
   {{0xe66401d5,0xdcf800ef,0x00000000,0x00000000}},	//   итмо, _iguā, --, --, 
   {{0xd5e4004d,0xfd10004b,0x7644032e,0x00000000}},	//   _phí, _بجې_, gnky, --, 
   {{0x61ec5dae,0xa5b810d8,0x4614fd19,0x25a801ab}},	//   _racl, nhói, لوگر, racl_, 
   {{0x3200fd1a,0xddd800b8,0x61ec2ca8,0x6fc0044b}},	//   _anky_, _bhuś, _sacl, _लागू, 
   {{0xddd81100,0x2d0000ab,0x1dd484b8,0xdb0000e5}},	//   _chuś, लमुल_, ण्डत, yaní, 
   {{0xe1fc001e,0xd5e401fb,0x75d40451,0xe4a401a9}},	//   _khói_, _thí, _هيٺا, _кроо, 
   {{0x60cc0408,0xdb0001a2,0x9f440030,0x00000000}},	// [16810] _qqcm, vaní, ľní_, --, 
   {{0x9f440316,0x61ec0ffb,0x9f5c01c7,0xdb201bce}},	//   žní_, _wacl, _ërëm_, ërëm, 
   {{0xa1842ecc,0x61ec7dcc,0x64440bb8,0x38680198}},	//   _выгл, _tacl, mnji, _ɗar_, 
   {{0x1cb0025c,0x6294009d,0x64440010,0xa5b80332}},	//   _དྷུ_, _itxo, lnji, fhói, 
   {{0xdb000588,0x9ce4fd1b,0x53f80a98,0xe1fc004d}},	//   raní, рцел, _صریح_, _nhói_, 
   {{0xdb003c80,0x1ee4fd1c,0xd1c002d3,0xe0dc0cad}},	//   saní, _پوری_, _ትሕተ_, _ipò_, 
   {{0x2000fd1d,0x60100316,0xa5b80af2,0x644443cc}},	//   _inji_, _výmě, phóh, inji, 
   {{0x39e8e4e0,0xa5b8007b,0x64440427,0xb9e8010b}},	//   удио_, bhói, hnji, умиз_, 
   {{0x64441a48,0xa5b8007b,0xe1fc01fb,0x4c94119e}},	//   knji, chói, _chói_, _митс, 
   {{0x644407f5,0x6294444e,0x08d402d5,0x8ccc05c0}},	//   jnji, _otxo, іцыя, _समतो, 
   {{0x62940070,0x9f400200,0xc5f000eb,0x00000000}},	//   _ntxo, _dajç_, টানা_, --, 
   {{0x6444009a,0xe0dc01e1,0xd9981c43,0x22480051}},	//   enji, _opò_, _شخصا_, _njck_, 
   {{0x92c439db,0x6294009d,0xe45c005b,0x00000000}},	//   _এনে_, _atxo, ytöt_, --, 
   {{0x64440cf4,0x00000000,0x00000000,0x00000000}},	//   gnji, --, --, --, 
   {{0x232486a1,0xe0dc0100,0xdb000109,0x00000000}},	//   бори_, _apò_, nanà, --, 
   {{0xd1c0069c,0x9fd40729,0x20007ddb,0x6444058a}},	//   _ትሕቲ_, সযোগ, _anji_, anji, 
   {{0x6294009d,0xe4d40fa2,0x644401a6,0x00000000}},	// [16820] _etxo, _هويت_, bnji, --, 
   {{0x262c0198,0xb14402dd,0x00000000,0x00000000}},	//   nƙon_, анұл, --, --, 
   {{0xe0dc0248,0x6294005a,0xdee0fd1e,0x00000000}},	//   _epò_, _gtxo, зохи, --, 
   {{0x3200089c,0xa5b80597,0xe45cfd1f,0xadb800f2}},	//   _unky_, thói, stöt_, اهشا_, 
   {{0x2d000b26,0x1cb0031c,0x80c401ec,0x7d0c0fac}},	//   लमेल_, _དྷཱ_, _وڭكە, øasp, 
   {{0xdb0005da,0x6448003a,0x5ce01870,0x6fb40769}},	//   fanà, _ígit, سكىل, _دمسا, 
   {{0xa5b8fd20,0x65d000d1,0xac9401d3,0x00000000}},	//   chów, _ﻛﯚﯕﻠ, جنڈا_, --, 
   {{0xe45c57bb,0x644405a1,0x00000000,0x00000000}},	//   ntör_, znji, --, --, 
   {{0xdca0fd21,0x270c03be,0x6e20004c,0x18240023}},	//   _нати, məni_, mkob, _ስለዝሞ, 
   {{0x6e20e0de,0x270c00ac,0xab280354,0x00000000}},	//   lkob, ləni_, _йоза_, --, 
   {{0xe45cfd22,0x644401fa,0xd7f49d86,0xad7401e1}},	//   ktör_, vnji, суы_, _ṣẹ̀k, 
   {{0x6e20fd23,0xe1fc001e,0xe45c023a,0xe4a401c0}},	//   nkob, _thói_, ytös_, йрго, 
   {{0x644438bb,0x99801ec7,0x6e20fd24,0xdb00fd25}},	//   tnji, _علوو, ikob, maná, 
   {{0xdb00fd26,0x64440161,0x7d0c02f6,0x270c0213}},	//   laná, unji, äasi, həni_, 
   {{0x45d4084c,0xe0dc033b,0x6e20fd27,0x270c0213}},	//   _дойс, _spò_, kkob, kəni_, 
   {{0x64441225,0x8c0000fe,0x27e80153,0x00000000}},	//   snji, ্সিন_, šinį_, --, 
   {{0x9400013f,0x40940075,0x270c00ac,0x228401d5}},	// [16830] _etiɑ_, زلار, dəni_, руҳг, 
   {{0x6e200083,0xe45c007c,0xb60002d2,0x9cc801ec}},	//   ekob, atör_, _áára, ғыда_, 
   {{0x270c0213,0xbc38030f,0xdb001bbf,0x9f683ab6}},	//   fəni_, یستا_, kaná, ураз_, 
   {{0x6e200fac,0xdb0076cf,0x00000000,0x00000000}},	//   gkob, janá, --, --, 
   {{0x245c00d2,0xdb0001f6,0xaac40118,0xdcb8026b}},	//   sîmu_, daná, रूसक, уще_, 
   {{0x8d7400aa,0x9f400589,0xddd80337,0x10a4020a}},	//   سانا, _pajä_, _kkuŋ, _хиён, 
   {{0x628000d8,0xc21c0412,0x270c0213,0x84700023}},	//   _énos, _नवाब_, bəni_, _ባእስን_, 
   {{0x3cec0190,0x7f5802f4,0x6e2001e3,0xf90001ec}},	//   _tsev_, _баҳс_, ckob, _ﺎﻤﮭُ_, 
   {{0x3cec009b,0xbd440451,0xd01001e2,0x00000000}},	//   _usev_, _بچاي, _غلې_, --, 
   {{0xddd81418,0xe45c01e3,0x37e4009d,0x23d827c6}},	//   _okuŋ, nröd_, цоог, म्मद, 
   {{0xddd81418,0xe3bc0154,0x00000000,0x00000000}},	//   _nkuŋ, ইভাব, --, --, 
   {{0xdb0010d8,0x7ae00175,0x00000000,0x00000000}},	//   caná, _iplt, --, --, 
   {{0xddd80337,0xa2a4070f,0x00000000,0x00000000}},	//   _akuŋ, टीस्, --, --, 
   {{0x270c0213,0x7adc024a,0x00000000,0x00000000}},	//   zəni_, _महाअ, --, --, 
   {{0x36684672,0x63800a31,0xe45c01e3,0x437441e5}},	//   _како_, дгра, ttör_, зутт, 
   {{0x9fa005a4,0xa5b80313,0x23d8102f,0x56f0009d}},	//   _síðu_, lkón, म्बद, _дүүс, 
   {{0xddd804ba,0xe45c49a2,0xb144011c,0x00000000}},	// [16840] _ekuŋ, rtör_, цнал, --, 
   {{0xd5e406d6,0xaf98d011,0x3a2c0175,0xe45c03e0}},	//   _muṋ, ртах_, hhep_, stör_, 
   {{0x270c0213,0x1c0000c5,0x9fa01427,0xe45c0790}},	//   təni_, लाईल_, _víðu_, ptör_, 
   {{0xf3e40014,0x62500135,0x6f1c0210,0x00000000}},	//   _آگُ, għod, rypc, --, 
   {{0x6e209877,0x9f4401f1,0xe45c01e6,0x3a2c0214}},	//   rkob, ľná_, bröd_, dhep_, 
   {{0x9f4403c6,0x3ce8fd28,0x628020ef,0xa2a40490}},	//   žná_, çava_, _énor, टीव्, 
   {{0xdb00fd29,0x6e20ce46,0xfba80212,0x0d8400fb}},	//   taná, pkob, стій_, _еһен, 
   {{0xa2c852f2,0xbae402bf,0x7bd44560,0x00000000}},	//   तंत्, яцій, _özun, --, 
   {{0xdd8c15fa,0x68400023,0x2bd0e858,0x00000000}},	//   _شول_, _ክብረት, _सापा, --, 
   {{0x5bc0004e,0x00000000,0x00000000,0x00000000}},	//   _ойуб, --, --, --, 
   {{0x5fcc58fc,0x00000000,0x00000000,0x00000000}},	//   स्टल, --, --, --, 
   {{0x248002d3,0x3a2ca2c1,0x28c00b67,0x69c400e5}},	//   _ኩቡራት_, chep_, _शिपि, óked, 
   {{0xdb000158,0xbb700137,0xa5b80332,0x00000000}},	//   ganæ, _قۇۇع, dhót, --, 
   {{0x9fac864e,0x68e032be,0x23940118,0x07342c90}},	//   _işçi_, _ipod, dějí_, _нелю, 
   {{0xd6cc0354,0x04fc0154,0xa1a8005b,0x2bd02d81}},	//   _ют_, ুনের_, итаз_, _साना, 
   {{0xe1fc0208,0xa5b8002e,0x2c700142,0x00000000}},	//   _nhót_, mkóo, lâdd_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [16850] --, --, --, --, 
   {{0x68e001fa,0x3a2c05d2,0x923c0092,0x00000000}},	//   _mpod, zhep_, _በወልቃ, --, 
   {{0xdb00fd2a,0xa5b801e7,0x00000000,0x00000000}},	//   manç, bhót, --, --, 
   {{0xdb00fd2b,0xa5b800d2,0x3a2c0023,0x7aec0034}},	//   lanç, chót, xhep_, łatk, 
   {{0xfc044316,0xd5fc0a7c,0x00000000,0x00000000}},	//   зпло, יפאר, --, --, 
   {{0xdb005ada,0x9f4001a2,0x64880135,0x8ccc02c3}},	//   nanç, _majú_, _iżid, _समरो, 
   {{0xfb8400dd,0x4bd804fb,0x9f400248,0x00000000}},	//   _ہدای, تبند_, _lajú_, --, 
   {{0x68e001e7,0x00000000,0x00000000,0x00000000}},	//   _bpod, --, --, --, 
   {{0x64880135,0xfb8419bc,0xad1400fb,0x68280092}},	//   _jżid, _فدای, _ептә, _ስለምት, 
   {{0xdb00068c,0x69d4013d,0x2bd0578b,0x9a84022e}},	//   janç, _öyen, _साया, _дудл, 
   {{0xdb00fd2c,0x68e00428,0x55c4fd2d,0xe5940ac1}},	//   danç, _epod, манғ, _açığ, 
   {{0x8afc0083,0x00000000,0x00000000,0x00000000}},	//   _kyęn, --, --, --, 
   {{0x2bd00cf1,0x2804012c,0xdb00180f,0x6488031c}},	//   _सामा, ávní_, fanç, _nżid, 
   {{0x5fc405ba,0xdb00fd2e,0xe574fd2f,0x9f400030}},	//   _लागल, ganç, язя_, _dajú_, 
   {{0x070805d9,0x23245aea,0xa018007c,0x68e001ef}},	//   _ويهي_, пори_, _utöy, _zpod, 
   {{0x2394012c,0x7c2c002d,0xdb0026bb,0x00000000}},	//   tějí_, ëarj, manä, --, 
   {{0xdb00fd30,0x00000000,0x00000000,0x00000000}},	// [16860] lanä, --, --, --, 
   {{0xdb00fd31,0xe45c0793,0x6250025c,0x00000000}},	//   canç, nuöl_, għob, --, 
   {{0xa5b80332,0xdb000254,0x93540066,0x00000000}},	//   mhór, nanä, _زردچ, --, 
   {{0x09e00011,0xe4d40133,0x9f400241,0x00000000}},	//   _মোনা, _بویت_, _yajú_, --, 
   {{0xdd80030c,0xe1fc2507,0x65980115,0x270c06be}},	//   нышп, _skóg_, ציסק, lənt_, 
   {{0xdb00fd32,0x28c0041c,0x00000000,0x00000000}},	//   kanä, _शिबि, --, --, 
   {{0x68e0fd33,0xdee0262e,0xada4fd34,0xe1fc004d}},	//   _spod, _пори, _навл, _thót_, 
   {{0x8cc402fe,0xdb0005d2,0x00000000,0x00000000}},	//   _रिपो, zanç, --, --, 
   {{0x7d0c005b,0x00000000,0x00000000,0x00000000}},	//   äast, --, --, --, 
   {{0x6b64fd35,0x64880327,0x18700276,0xfc2c00cf}},	//   _екза, _jżie, нгыя, _ۅڭۉ_, 
   {{0xe1fc0597,0xdb00fd36,0x63a000c5,0x9f4001e1}},	//   _mhór_, ganä, _õnni, _sajú_, 
   {{0xae000a8a,0x00000000,0x00000000,0x00000000}},	//   _रोमन_, --, --, --, 
   {{0x68e0fd37,0xdb00fd38,0xb8f0035b,0xa5b800ae}},	//   _upod, tanç, _аҧыш, fhór, 
   {{0x3d2400b5,0xe3d001c6,0x987000c0,0x00000000}},	//   のweb_, эйгө, _зліц, --, 
   {{0xdb00fd39,0x96b407fc,0x00000000,0x00000000}},	//   ranç, _فايز_, --, --, 
   {{0xdb00fd3a,0x80e00f22,0x5214fd3b,0x3e50012d}},	//   sanç, নিস্, ндст, kąta_, 
   {{0xa6ac11ba,0x6488025c,0xdb00fd3c,0x55bc0375}},	// [16870] _কমিট, _bżie, panç, _המחו, 
   {{0x6018054e,0xe1fc1748,0x2004fd3d,0xa5b801e7}},	//   _cîmp, _phós_, ñni_, chór, 
   {{0x44300fac,0x4ea4030d,0x91ac03d4,0x4fc40006}},	//   mhz_, ерча, _ছাৰ্, эста, 
   {{0xee440432,0x00000000,0x00000000,0x00000000}},	//   _öýli_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x44300051,0x00000000,0x00000000,0x00000000}},	//   nhz_, --, --, --, 
   {{0x2bd88bee,0xdb000724,0x1cbc0327,0x7bd400a2}},	//   تانک_, xanä, _ཀའམ_, _özum, 
   {{0xa6d0015b,0x41dc00dc,0xdb001577,0x69d40139}},	//   তবায়, मभिस, vanä, _öyel, 
   {{0xd8c0031c,0xe8f404b4,0x9be400d4,0x8cc40210}},	//   _ཀཀཎི, длы_, _ніжк, _रियो, 
   {{0xb8d4fd3e,0xa5b8fd3f,0x8afc068f,0xdb00023a}},	//   _जब_, skól, _częs, tanä, 
   {{0x2bd0d04e,0x28c007d0,0xca4800f1,0xf7701699}},	//   _साता, _शिथि, _کلنه_, کاک_, 
   {{0xdb00340f,0x8cc40f4a,0x00000000,0x00000000}},	//   ranä, _रिमो, --, --, 
   {{0xa5b800ae,0xdb0001f4,0x00000000,0x00000000}},	//   thór, sanä, --, --, 
   {{0x06700075,0x00000000,0x00000000,0x00000000}},	//   _ﭼﯩﻘﯩ, --, --, --, 
   {{0x463c044e,0xe294fd40,0x00000000,0x00000000}},	//   _ኣህጉራ, дас_, --, --, 
   {{0x7aec033f,0x00000000,0x00000000,0x00000000}},	//   łatw, --, --, --, 
   {{0x2164d328,0x614034be,0x754400d6,0x6488031c}},	// [16880] дити_, вета, _іноз, _eżib, 
   {{0x2bd02677,0xa030198a,0x64880327,0x00000000}},	//   _साधा, نىقت, _qżie, --, 
   {{0x260001f9,0xa3d801f9,0x00000000,0x00000000}},	//   षाची_, ठभर_, --, --, 
   {{0x6da4036b,0xf1b0033f,0x6cc4010b,0x8d9401d5}},	//   фида, _ज़िन, дйда, رلتش, 
   {{0x60180356,0x8c040139,0x00000000,0x00000000}},	//   _tîmp, нҗал, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4f8401d9,0x8afc012d,0x00000000,0x00000000}},	//   _ساسہ, _rzęs, --, --, 
   {{0x80e0015b,0xed5801f4,0x00000000,0x00000000}},	//   নির্, _доб_, --, --, 
   {{0x69d40166,0x00000000,0x00000000,0x00000000}},	//   _öyem, --, --, --, 
   {{0x20040112,0x00000000,0x00000000,0x00000000}},	//   önix_, --, --, --, 
   {{0x45d4fd41,0x6b980857,0x00000000,0x00000000}},	//   нонс, _iftg, --, --, 
   {{0x06c805f5,0xa924fd42,0xe1fc0051,0x89d802da}},	//   огүй_, _одел, _nhóp_, _روتر_, 
   {{0x956400a7,0x4430020c,0x00000000,0x00000000}},	//   върд, thz_, --, --, 
   {{0x3e74168c,0xe71800f1,0xd820009d,0x00000000}},	//   måte_, _ويشت_, _идчи, --, 
   {{0x98a002d5,0xd2f80798,0x00000000,0x00000000}},	//   ąją_, мерц_, --, --, 
   {{0x09e0015b,0xe1fc0208,0x1648008e,0x00000000}},	//   _মোতা, _chóp_, _очып_, --, 
   {{0x4394fd43,0x6b980036,0xd4c40166,0x41540cc9}},	// [16890] _папс, _oftg, _исэп, хвас, 
   {{0x9f682bbd,0x0fe40137,0x6da0059f,0xdc800023}},	//   орез_, көсү, қиша, ንእሰይ_, 
   {{0x463c02d3,0x09b40154,0x00000000,0x00000000}},	//   _ኣህጕራ, _টানা, --, --, 
   {{0x6b98035a,0x3d941d83,0xb900031c,0x037800ec}},	//   _aftg, хидр, _སྱ_, _وجھڻ_, 
   {{0x5184fd44,0x614000d1,0x2fd0007c,0x00000000}},	//   _аура, _شىسە, ångå_, --, 
   {{0xdb0001a8,0xd90c02f2,0xa9d000d1,0x999c0055}},	//   manú, ییا_, ۇقىغ, bhuś_, 
   {{0x999c01f1,0x00000000,0x00000000,0x00000000}},	//   hnuť_, --, --, --, 
   {{0x999c0030,0x00000000,0x00000000,0x00000000}},	//   knuť_, --, --, --, 
   {{0x820000cc,0x00000000,0x00000000,0x00000000}},	//   _একাপ_, --, --, --, 
   {{0x999c0030,0xe6180427,0x9b240fac,0x00000000}},	//   dnuť_, _češč, _офел, --, 
   {{0x3668339e,0x64a001e0,0xda60001f,0xdb000332}},	//   зано_, ғаса, ድረግና_, hanú, 
   {{0x1ddc00bc,0xb9340798,0x00000000,0x00000000}},	//   नभित, _пееј, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa92001a8,0xa5b801a8,0xb6a4054e,0xdb0008a5}},	//   _óþar, shóp, _atâţ, danú, 
   {{0xa2e034b1,0x27f438b7,0x2bd04328,0x67d00261}},	//   лорд, _سفيد_, _सासा, _соју, 
   {{0xe45c0254,0x00000000,0x00000000,0x00000000}},	//   rröa_, --, --, --, 
   {{0x2bd023ef,0x09b400cc,0x61e8000d,0x30046c9c}},	// [168a0] सलमा, _টামা, õgla, нзаг, 
   {{0x13a856a7,0xe5740166,0xa06400d8,0x00000000}},	//   _تندی_, _язы_, еауа_, --, 
   {{0xfbc80acd,0xb9000135,0x2f5481b9,0xe1fc0208}},	//   _राजम, _སཱ_, хтас, _thóp_, 
   {{0x2bd0a3a7,0xe2980375,0x00000000,0x00000000}},	//   _साहा, _משטר, --, --, 
   {{0xc3c8424b,0x4094f156,0xda000073,0xfe700050}},	//   _عظیم_, _арст, _शोधत_, جدٕ_, 
   {{0x41b001d9,0x7644fd45,0x09c80073,0x3e7403cd}},	//   _مۅہر, hiky, ळल्य, våte_, 
   {{0xddc80724,0x7644fd46,0x00000000,0x00000000}},	//   _çişm, kiky, --, --, 
   {{0xd044013f,0x7c6401b9,0x2d94004e,0x764400a2}},	//   mtiɑ, _یالل, _чөжө_, jiky, 
   {{0x290040db,0xfd64004e,0x00000000,0x00000000}},	//   íka_, _антү, --, --, 
   {{0x2c70025a,0x7a3400d2,0x2c840248,0x3e740fac}},	//   bâda_, _nátf, _dídì_, råte_, 
   {{0x28c006bc,0xd870fd47,0xd044013f,0xdb000306}},	//   _शिवि, دايب, ntiɑ, ybné, 
   {{0x26c005ce,0x76441418,0xdb0001d3,0x999c00d0}},	//   čko_, giky, yanú, tnuť_, 
   {{0x26c000b0,0x98a000f3,0xe504007b,0x00000000}},	//   ōko_, _биче, ربحي, --, 
   {{0x7a3400d2,0x9f440030,0x15a00131,0xa5b80022}},	//   _cátf, ľnú_, _ﺋﯩﺸﯩ, ikói, 
   {{0x81c802f5,0x76441418,0x9f440030,0x892401ed}},	//   ল্ফ_, biky, žnú_, _سڑکو, 
   {{0xa2a401d9,0x23d00882,0xddcc91aa,0xe45c04cc}},	//   टीग्, _तावद, _žeže, ntöz_, 
   {{0x42d0015b,0xf1200055,0x00000000,0x00000000}},	// [168b0] াবেশ, _īṣan_, --, --, 
   {{0x661c0784,0x5184133a,0xd4d8007b,0xdfe80124}},	//   _hoqk, ууса, _أبيض_, џьал_, 
   {{0x6444fd48,0xae004707,0x257801e1,0x00000000}},	//   miji, _रोहन_, bàlé_, --, 
   {{0x6444fd49,0x9e640137,0xdb000b1a,0x09e00154}},	//   liji, راان, manø, _মোসা, 
   {{0x8d7470cb,0x02b0000d,0x00000000,0x00000000}},	//   هاها, _जबुन, --, --, 
   {{0x64443aaf,0x661c0023,0x9a98001f,0x76441418}},	//   niji, _loqk, _ዋነኛው_, ziky, 
   {{0x2bd0038e,0xe45c01f4,0x00000000,0x00000000}},	//   _सारा, yrön_, --, --, 
   {{0x6444fd4a,0x28c009fa,0xaa540114,0x00000000}},	//   hiji, _शिशि, кију_, --, 
   {{0x6444fd4b,0x09e000bd,0xbc9410fc,0x00000000}},	//   kiji, _মোহা, _разј, --, 
   {{0x6444fd4c,0x15a000d1,0x00000000,0x00000000}},	//   jiji, _ﺋﯩﺴﯩ, --, --, 
   {{0x6444fd4d,0x7644fd4e,0x7bc0fd4f,0x810c0034}},	//   diji, tiky, _idlu, समुख_, 
   {{0x9f4001d3,0xa6800166,0x00000000,0x00000000}},	//   _hajó_, илэд, --, --, 
   {{0x7644fd50,0x49b8fd51,0x6444fd52,0x3834009d}},	//   riky, _ساند_, fiji, _индр, 
   {{0x6444fd53,0x733412b7,0x764402f6,0xa80005d1}},	//   giji, پىرا, siky, şırk, 
   {{0x9cfc09bd,0x9f40fd54,0x7bc09327,0x91c400ee}},	//   ্নয়ন_, _majó_, _mdlu, лавҗ, 
   {{0x62500327,0x00000000,0x00000000,0x00000000}},	//   sħon, --, --, --, 
   {{0x7bc004b9,0x6444fd55,0x2bd05ae4,0xfbc400ec}},	// [168c0] _odlu, biji, _साला, _ٿڪ_, 
   {{0x25e02871,0x7bc0fd56,0x00000000,0x00000000}},	//   ट्ठी_, _ndlu, --, --, 
   {{0x661c022e,0x2d8801e1,0x00000000,0x00000000}},	//   _yoqk, _ńbe_, --, --, 
   {{0x7bc0fd57,0xd2500014,0x13a80f01,0xae00121d}},	//   _adlu, _اۆر_, _تنگی_, _रोशन_, 
   {{0xdcac1a59,0x9f4000eb,0x3084007b,0x00000000}},	//   قىن_, _bajó_, _للحف, --, 
   {{0x9f40033b,0x2a640165,0xdca00063,0x00000000}},	//   _objè_, _skob_, шаљи, --, 
   {{0xfe701c02,0x49c80032,0xfe6c0117,0x00000000}},	//   جدە_, еһен_, _гӯ_, --, 
   {{0x7bc01717,0x6444fd58,0xd6d4015b,0xa2a43885}},	//   _edlu, ziji, তবায, टीट्, 
   {{0xac84fd59,0x6444fd5a,0x6250031c,0x27200419}},	//   _агал, yiji, dħol, _očná_, 
   {{0x6c48fd5b,0x1be400c7,0x2ca40098,0x09e00154}},	//   _غلاف_, _идуи_, mpod_, _মোশা, 
   {{0xd7f420b0,0xdecc0023,0xa5b800e4,0x2ca4045a}},	//   туы_, _ኣቡን_, ikóv, lpod_, 
   {{0x6444fd5c,0x426c02d3,0xa9a4f87a,0x62500003}},	//   wiji, _ሰብኡት_, _ридд, għol, 
   {{0xe1f0fd5d,0x69c0003e,0x6488012d,0x00000000}},	//   یسر_, _idoe, _dżin, --, 
   {{0x2904fd5e,0x9f4002e2,0x2ca4009a,0xa5b8033f}},	//   _iroa_, _majò_, ipod_, yków, 
   {{0x6444fd5f,0x29040076,0x8ccc02ab,0x69c001bf}},	//   riji, _hroa_, _समझो, _kdoe, 
   {{0x6444fd60,0x29040217,0xd2580640,0xe5c42bbd}},	//   siji, _kroa_, вцу_, _рско, 
   {{0x64440003,0xeabc03d4,0x26dc005b,0xd658011a}},	// [168d0] piji, _আহোম, ltto_, _שיחת_, 
   {{0x2ca48c70,0x26dc020f,0xa5b8033f,0x64440009}},	//   dpod_, otto_, tków, qiji, 
   {{0x4420b032,0x4254fd61,0xd084023a,0xfe701997}},	//   _ioh_, _مندر, рыти, مگر_, 
   {{0x4420fd62,0x69c00097,0x13b8015b,0x26dc023a}},	//   _hoh_, _ndoe, _জায়, itto_, 
   {{0x44206494,0x290401f4,0x3e74007c,0xa5b8012d}},	//   _koh_, _nroa_, gåta_, sków, 
   {{0x44200842,0x69c0fd63,0x8d74069b,0x00000000}},	//   _joh_, _adoe, جاما, --, 
   {{0xe81405ba,0x4420fd64,0x2904fd65,0x7a34d703}},	//   ताना_, _moh_, _aroa_, _láte, 
   {{0x4420fd66,0x998c01a2,0x2904067c,0xa3e009fd}},	//   _loh_, ťaže_, _broa_, फ्त_, 
   {{0x4420bed5,0x26dc00a7,0x7e68fd67,0x23d00490}},	//   _ooh_, etto_, _ikep, _तांद, 
   {{0x4420b032,0x7bc0fd68,0x2904fd69,0x69c0fd6a}},	//   _noh_, _udlu, _droa_, _edoe, 
   {{0x2904fd6b,0x7c200e9e,0x2bd88dff,0x00000000}},	//   _eroa_, _iolr, _سالک_, --, 
   {{0x4420fd6c,0xb634007b,0x7c20fd6d,0xdec40023}},	//   _aoh_, اعدت, _holr, _ጽገና_, 
   {{0x37e485f5,0x4420fd6e,0x26dc011c,0x7a34fd6f}},	//   _болг, _boh_, atto_, _cáte, 
   {{0x4420fd70,0x00000000,0x00000000,0x00000000}},	//   _coh_, --, --, --, 
   {{0x4420fd71,0x69c003cb,0x999c0356,0xf7440108}},	//   _doh_, _ydoe, ciuţ_, _щеко, 
   {{0x4420fd72,0xd1f4001f,0x2ca4fd73,0x802401b9}},	//   _eoh_, _ግቦች_, ypod_, یرلم, 
   {{0xc5b44ecc,0x4420fd74,0x2ca4005c,0x40940387}},	// [168e0] _өрөө, _foh_, xpod_, архт, 
   {{0x7e68166a,0x4420fd75,0xe814448b,0xdb0001a8}},	//   _akep, _goh_, ताया_, danþ, 
   {{0xac84c2db,0x80d4012c,0x63e000cf,0xaec40064}},	//   ңгел, यूबे, _ايپە, убел, 
   {{0xed585402,0x8d2800fd,0x44201155,0x7a34032e}},	//   ное_, кнең_, _zoh_, _látb, 
   {{0x4420fd76,0x2ca46129,0xe8140316,0x0bb4fd77}},	//   _yoh_, upod_, तामा_, аблю, 
   {{0x7e68fd78,0x7c2001a4,0x442065e8,0x7bcc02a8}},	//   _ekep, _colr, _xoh_, ɗauk, 
   {{0xaae450a2,0x7e680093,0x2ca4fd79,0x00000000}},	//   استو, _fkep, spod_, --, 
   {{0x290409a9,0xa5b802ea,0x7c2c002d,0xdae4009f}},	//   _proa_, nkót, ëarr, افيو_, 
   {{0x7c200137,0x6bd4086e,0xdb0002f0,0xed34009d}},	//   _folr, _متار, maný, _сэвэ, 
   {{0x7c200280,0xe45cfd7a,0xdb0000ee,0x28740032}},	//   _golr, tröm_, laný, ыҡлы_, 
   {{0x9b9006d5,0x26dc3da1,0xc7b80e04,0xd1e00023}},	//   _المت, utto_, rađ_, _ሓሳቡ_, 
   {{0x44200978,0x7a340316,0x6488025c,0x1a98008f}},	//   _soh_, _páte, _eżil, _נידע, 
   {{0x4420fd7b,0x673801ed,0x290400cc,0xd9400354}},	//   _poh_, sztj, _uroa_, _леци, 
   {{0x4420016d,0xdb0002fb,0x00000000,0x00000000}},	//   _qoh_, haný, --, --, 
   {{0x53340262,0xdb0002fb,0x4420fd7c,0x00000000}},	//   берт, kaný, _voh_, --, 
   {{0x53342dc1,0x4420fd7d,0xb060006a,0xa18400fd}},	//   щест, _woh_, ïänn, гызл, 
   {{0x4420fd7e,0xdb000232,0x6834003a,0xb6a4004d}},	// [168f0] _toh_, daný, _eâde, _luậ, 
   {{0x7e68fd7f,0xe1300184,0x00000000,0x00000000}},	//   _skep, анғы, --, --, 
   {{0x68340356,0xa5b80174,0xf8c000cd,0x00000000}},	//   _gâde, gjóg, _षट्प, --, 
   {{0x2d7c0943,0xdb0000a2,0x00000000,0x00000000}},	//   _ṋea_, ganý, --, --, 
   {{0x7c20fd80,0x628c01e2,0x7a3401ef,0x41a4084d}},	//   _polr, _iico, _látc, गुणस, 
   {{0x62941cdf,0xe1fc0270,0x628c0ac5,0xc1b000fb}},	//   _kuxo, _haó_, _hico, _ыҙғы, 
   {{0xd1e0069c,0xa5b850e2,0xf9902ab5,0x628c0083}},	//   _ሓሳብ_, nkós, يبة_, _kico, 
   {{0xba240017,0x7c20fd81,0x6294036b,0x6a7c0221}},	//   рдик, _wolr, _muxo, hëff, 
   {{0x628cfd82,0xe1fc00cf,0x7c20004e,0x7bf80022}},	//   _mico, _maó_, _tolr, _инар_, 
   {{0x3a2c0660,0xe1fcb44a,0xed4c0583,0x684002d3}},	//   skep_, _laó_, _تھم_, _ክእለት, 
   {{0x7d08fd83,0x69a41f14,0x79f400a7,0x290010d1}},	//   _hres, _ट्वी, _взех, åkar_, 
   {{0x628cfd84,0x7d08fd85,0x6308015b,0x9a84377b}},	//   _nico, _kres, রহাট_, _сузл, 
   {{0x99800006,0x7d080135,0x62940129,0x97c40014}},	//   ėjų_, _jres, _auxo, _یژھٕ_, 
   {{0x78a8fd86,0x629407d6,0xdb00fd87,0x170400dd}},	//   mpev, _buxo, zaný, _مفتی_, 
   {{0x78a8fd88,0xdb00fd89,0x35a4748c,0x6294056a}},	//   lpev, manó, _кайг, _cuxo, 
   {{0x7d080c8c,0xdb00fd8a,0x62941eca,0x63b40009}},	//   _ores, danü, _duxo, _eexn, 
   {{0x628cfd8b,0xdb0003c6,0xc0e0044e,0x9f4401a2}},	// [16900] _dico, vaný, _ሓባር_, ľný_, 
   {{0x9f440232,0x628c015d,0xa5b8fd8c,0x00000000}},	//   žný_, _eico, skót, --, 
   {{0x7d08fd8d,0x628cfd8e,0xdb00fd8f,0x62940023}},	//   _ares, _fico, taný, _guxo, 
   {{0x628c04cc,0x2d90168c,0x80e0015b,0xfec80451}},	//   _gico, øye_, নিজ্, ابلو_, 
   {{0xdb00fd90,0xac8401c0,0x78a802f0,0xfe7430ab}},	//   raný, агдл, jpev, сүт_, 
   {{0x628c0b6f,0xc0c00023,0xdb00fd91,0x2ac40063}},	//   _zico, ትኹም_, saný, аљив, 
   {{0x628c0513,0xb6a40208,0xdb00dde0,0xa5b802f0}},	//   _yico, _quậ, paný, rhóz, 
   {{0x628c0137,0x6280011c,0x2bd080a0,0x298801af}},	//   _xico, _ènot, _साका, кспо_, 
   {{0xdca0fd92,0x00000000,0x00000000,0x00000000}},	//   _мати, --, --, --, 
   {{0x69a456e9,0xdb00012d,0xe8242b97,0x9cd8011a}},	//   _ट्री, ganó, рфио, _בקמפ, 
   {{0xcfcc00bd,0xbc243b5f,0x7d080034,0xdc380375}},	//   র্থন, _ارقى, _zres, _שעבר, 
   {{0x2984ad24,0xd6d40262,0x63b41654,0x6aa80112}},	//   _кылг, шть_, _sexn, mpff, 
   {{0x628cfd93,0xe1fc00f7,0x7d080946,0x62940166}},	//   _rico, _raó_, _xres, _suxo, 
   {{0x628cfd94,0xcfcc00bd,0xdb00fd95,0x62940798}},	//   _sico, র্তন, canó, _puxo, 
   {{0xdb000561,0x765401ed,0x86e4004b,0xc5f00183}},	//   lanò, ógyá, _اړخو, য়াবা_, 
   {{0x92580aa5,0x629407a9,0xbc8402d3,0x6a7c0036}},	//   ааст_, _vuxo, _ምዃንና_, sëff, 
   {{0x63b4fd96,0x6aa80175,0x7a3401a8,0xb2740124}},	// [16910] _texn, hpff, _játa, сктә, 
   {{0x7d08044e,0x7d781a50,0x25e00412,0x7a34fd97}},	//   _rres, ۇمار_, ट्री_, _máta, 
   {{0x628cfd98,0x7a34fd99,0x7d0808ad,0x3cec00d0}},	//   _tico, _láta, _sres, _spev_, 
   {{0x628c82be,0x7870022e,0xddc8007f,0x2ea801d3}},	//   _uico, _lаvо, yogŕ, اپنی_, 
   {{0x787cfd9a,0x3c38004a,0xfce80451,0xdb00fd9b}},	//   lève, _lève_, افتي_, janò, 
   {{0x7d08fd9c,0x7870022e,0x9be40212,0x5f740133}},	//   _vres, _nаvо, рідк, _نازر, 
   {{0x628002e8,0x3c380100,0x7d08fd9d,0x906400d1}},	//   _ènos, _nève_, _wres, _بۆلۇ, 
   {{0x7a342880,0xdb00012d,0x00000000,0x00000000}},	//   _báta, wanó, --, --, 
   {{0x7d08fd9e,0x4430014b,0x082405d9,0xdb00fd9f}},	//   _ures, kkz_, ڪريٽ, tanó, 
   {{0x7a34fda0,0x78a8ec61,0x00000000,0x00000000}},	//   _dáta, rpev, --, --, 
   {{0x78a80f72,0xdb00fda1,0x787001a9,0xf74800e3}},	//   spev, ranó, _dаvо, الجي_, 
   {{0xb9940597,0xe7341fdf,0x7a340162,0x64880327}},	//   _الإب, сею_, _fáta, _użij, 
   {{0x53dc0412,0xfccc02d3,0x09e00eac,0xdb00ae4f}},	//   _बादश, _ባህጊ_, _মোকা, manñ, 
   {{0xe69019bc,0x3c380129,0x867801c6,0x69d4415b}},	//   _کليد, _fève_, лөөр_, _öyer, 
   {{0xf77003e6,0xf48401ed,0x80d407f7,0xa5b8c469}},	//   _عات_, لاڑی, यूसे, rkór, 
   {{0x984c00ac,0xdb000309,0xa5b8fda2,0x00000000}},	//   _işıq_, nanñ, skór, --, 
   {{0x1ce00135,0x13a80330,0x00000000,0x00000000}},	// [16920] ྫངས_, _پنجی_, --, --, 
   {{0x9588068f,0x3ae001ed,0xa92008a5,0x00000000}},	//   _ciąż, kóp_, _áþes, --, 
   {{0x59c40490,0xdb0002d1,0xe18c00a2,0x00000000}},	//   ळणार, kanñ, _aỳda_, --, 
   {{0x3ae003b2,0x00000000,0x00000000,0x00000000}},	//   dóp_, --, --, --, 
   {{0xf3f4025c,0xc15401af,0x00000000,0x00000000}},	//   _བྲོད_, _дњрњ, --, --, 
   {{0xa0a00e3b,0x7fd4063b,0x7a34fda3,0x6280011c}},	//   _хард, _місі, _ráta, _ènor, 
   {{0x3200dd93,0xada4fda4,0x7a340162,0x6da403f6}},	//   _kaky_, _габл, _sáta, _гиба, 
   {{0x3200fda5,0xdb001f3f,0x3c380129,0x7870022e}},	//   _jaky_, tanò, _rève_, _sаvо, 
   {{0xad242756,0x1d04fda6,0x984c0213,0x3c3806af}},	//   _ارزو, _лети_, _aşıq_, _sève_, 
   {{0x6834025a,0x32000122,0x7a340174,0xbc240150}},	//   _bâda, _laky_, _váta, _ورلى, 
   {{0xf3f4031c,0xdca0084c,0xdb000ba1,0x3ae00332}},	//   _བྲེད_, _маӂи, sanò, cóp_, 
   {{0x7a3400ae,0x320001ef,0x00000000,0x00000000}},	//   _táta, _naky_, --, --, 
   {{0xf9182be7,0xddd800cd,0x4614fda7,0xda7800df}},	//   _نروژ_, _akuś, موگر, _ענדר, 
   {{0x68e00139,0xe4a4013e,0x7a3408a5,0x787c02e2}},	//   _iqod, ирҳо, _játn, tève, 
   {{0x320000ee,0x49100118,0x00000000,0x00000000}},	//   _baky_, तमको_, --, --, 
   {{0x7a34fda8,0x44300472,0xddd80024,0x320000d7}},	//   _látn, skz_, _siuž, _caky_, 
   {{0x3200fda9,0x00000000,0x00000000,0x00000000}},	// [16930] _daky_, --, --, --, 
   {{0x9f5006d9,0xcfcc0154,0x7d0c00d7,0x00000000}},	//   lexé_, র্সন, ťask, --, 
   {{0xe7e838db,0x8c940150,0x00000000,0x00000000}},	//   ज्या_, үрші, --, --, 
   {{0x9588033f,0x9f500129,0x6264075e,0x00000000}},	//   _wiąż, nexé_, _چاڭق, --, 
   {{0x9ce40153,0x7ae000e4,0x68e00009,0x7a3408a5}},	//   сцел, _sqlt, _nqod, _bátn, 
   {{0xdb0002d1,0xe7e804af,0x00000000,0x00000000}},	//   wanñ, ज्मा_, --, --, 
   {{0xe1fc0124,0xfa380063,0x2bb805dc,0x00000000}},	//   _akói_, ичић_, _ईजरा, --, 
   {{0x2000fdaa,0x00000000,0x00000000,0x00000000}},	//   _haji_, --, --, --, 
   {{0x2000fdab,0xccec00d1,0x9f5006af,0x00000000}},	//   _kaji_, _яқ_, dexé_, --, 
   {{0x2000fdac,0xdb000784,0x36c4fdad,0x00000000}},	//   _jaji_, sanñ, обог, --, 
   {{0x2000fdae,0xbb540edf,0xdb000113,0x00000000}},	//   _maji_, _بناب, panñ, --, 
   {{0x36680640,0x2000fdaf,0x00000000,0x00000000}},	//   рамо_, _laji_, --, --, 
   {{0x320000d7,0xa5b803b2,0x66240210,0x7a3400e5}},	//   _raky_, rkóp, _łukó, _háto, 
   {{0x2000fdb0,0x47d000cc,0x320000a2,0x4b88030d}},	//   _naji_, ত্বী, _saky_, _ейĕн_, 
   {{0xe81413e0,0x09e00eac,0x320002f0,0x00000000}},	//   तारा_, _মোটা, _paky_, --, 
   {{0xf1a8fdb1,0x394c0023,0x7a34013a,0x00000000}},	//   شاره_, _ንስድራ, _máto, --, 
   {{0x7a345f5b,0x3200635e,0xafe401b9,0x80d401ad}},	// [16940] _láto, _vaky_, жозл, यूले, 
   {{0xaf340eff,0x20003ace,0x00000000,0x00000000}},	//   يرات, _caji_, --, --, 
   {{0x32000316,0x2000fdb2,0x200406ed,0x224805ac}},	//   _taky_, _daji_, ônia_, _fmck_, 
   {{0xee3800d8,0x00000000,0x00000000,0x00000000}},	//   јнд_, --, --, --, 
   {{0xca3801e4,0x6ea800dd,0xed58039b,0x2000fdb3}},	//   _juĝe_, انچہ_, шод_, _faji_, 
   {{0x2000fdb4,0x7a340e33,0x4974010b,0xc0f8010f}},	//   _gaji_, _báto, үлкс, _פּרט, 
   {{0xada400c2,0xdee0009d,0x00000000,0x00000000}},	//   _мавл, _оори, --, --, 
   {{0x80ac2f04,0xcfcc015b,0x7a340030,0x2fc800a2}},	//   _চিত্, র্শন, _dáto, _hdbg_, 
   {{0x20000b45,0xd1c0001f,0xe8140490,0x00000000}},	//   _yaji_, _ስንት_, ताला_, --, 
   {{0x18700598,0x2b14084c,0x20000067,0x7b9401d3}},	//   мгыя, _мьер, _xaji_, _ٹھوس_, 
   {{0x7a343df9,0xa9a400f3,0x00000000,0x00000000}},	//   _kátl, _диед, --, --, 
   {{0x6e20fdb5,0x09b400bd,0x75a400c7,0x48b800cc}},	//   njob, _টাকা, зырҧ, _আমীৰ, 
   {{0x78ac0122,0x7a341ab0,0x37a80137,0x98a000d8}},	//   čový, _záto, штөн_, _жиче, 
   {{0x6d400005,0x7a341686,0x3948010e,0x15a000d1}},	//   izoa, _látl, _ýasa_, _ﺋﯩﺘﯩ, 
   {{0x2000fdb6,0xddd800df,0xddc80064,0xdb200162}},	//   _raji_, _akuŝ, _čižo, ðrøk, 
   {{0x200006df,0x6e2004ba,0x7a340ab9,0x00000000}},	//   _saji_, jjob, _nátl, --, 
   {{0x3c38067c,0x6e2005be,0x2000fdb7,0x787c067c}},	// [16950] _lèva_, djob, _paji_, lèva, 
   {{0xdb00fdb8,0x20000200,0xe45c01e3,0xa92002d2}},	//   manö, _qaji_, gröt_, _óþur, 
   {{0xe7e019e5,0xf3f40135,0x09e0015b,0xdb000793}},	//   _खाना_, _བྲིད_, _মোছা, lanö, 
   {{0x6e2000dd,0x023800aa,0x20000014,0xd718008f}},	//   gjob, _اګست_, _waji_, יץבר, 
   {{0x2000fdb9,0x60600952,0x6f0c0076,0x61ec017a}},	//   _taji_, _قۇرل, _erbc, _ibcl, 
   {{0x47d002f5,0xb0980375,0x200001f7,0xcd04109a}},	//   ত্তী, _לישר, _uaji_, ьпій, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6e200354,0x787c026c,0x7a3402cc,0xab6000d1}},	//   cjob, dèva, _gátl, رۇنى, 
   {{0x9be400d3,0xa3a8fdba,0x53dc1fd2,0x00000000}},	//   _міжк, खडा_, _बालश, --, 
   {{0x097805f5,0xca380115,0x7a34fdbb,0xdb0002d2}},	//   өрөө_, _ruĝe_, _táto, danö, 
   {{0xdb200502,0x98a80ab5,0xb80800f1,0x00000000}},	//   _توضی, ılım_, ليکم_, --, 
   {{0xca7400d1,0x00000000,0x00000000,0x00000000}},	//   _قانغ, --, --, --, 
   {{0xe8ecfdbc,0x7bcc03f9,0xca48004b,0x4a4402d5}},	//   _ял_, ɗaur, _بلنه_, _ўнів, 
   {{0xf74408bf,0xe7e0033f,0x14d800cd,0xe7e800bc}},	//   _нело, _खाया_, भूषण, ज्दा_, 
   {{0x63801dbc,0x6d40011c,0xa3a800e1,0x6fe0033f}},	//   егра, zzoa, खड़_, _पाबं, 
   {{0x61ec0076,0xa5b8148b,0x00000000,0x00000000}},	//   _cbcl, ljón, --, --, 
   {{0xb14414a4,0x6f0c0b4b,0xb38401ec,0x6e20007c}},	// [16960] чнал, _srbc, ілұл, vjob, 
   {{0x6e209af9,0x61ec010a,0xdb0000c5,0x3ce401ec}},	//   wjob, _ebcl, lanõ, _ﺍﺴﺘﻤ, 
   {{0x6e20fdbd,0x430000d1,0xdfcc0f13,0xc5f000eb}},	//   tjob, _иҗра, طين_, য়ারা_, 
   {{0x6d4001c4,0x6a7c0200,0xa5b808a5,0x00000000}},	//   tzoa, këfa, hjón, --, 
   {{0x6e20fdbe,0x274004fb,0xec1400fd,0x2fc80334}},	//   rjob, _kéné_, зелә_, _tdbg_, 
   {{0x6e203bdc,0x3c380022,0x6f0c01ab,0x80b000d1}},	//   sjob, _pèva_, _trbc, _شەمش, 
   {{0x2740020c,0x63a0000f,0x48b80183,0x6e200175}},	//   _méné_, _ûnne, _আমেৰ, pjob, 
   {{0xada431a8,0xe45c01e3,0x26c800d7,0x00000000}},	//   _хаал, nrör_, ábom_, --, 
   {{0xfe4420bf,0x286809a0,0xd8e00006,0x00000000}},	//   _تکلی, йроо_, нцэп, --, 
   {{0x4734fdbf,0xc87c02d3,0x787c033b,0x00000000}},	//   днос, _ብብዝሒ_, tèva, --, 
   {{0x9c140724,0x4e000034,0x69f001c0,0xe45c01e3}},	//   _эчтә, _ईसाई_, _зүйт, krör_, 
   {{0x7a3401ed,0xdb00fdc0,0x63840129,0x80ac00cc}},	//   _látj, tanö, héné, _চিস্, 
   {{0x63847c70,0x787c5b42,0xc5f00154,0xe4a45bc5}},	//   kéné, sèva, য়ালা_, ярно, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2740034c,0x7c24002f,0x00000000,0x00000000}},	//   _déné_, öhri, --, --, 
   {{0xa498007f,0xe45c007c,0x00000000,0x00000000}},	//   twòd, grör_, --, --, 
   {{0x20040120,0xddd8013d,0x7654007f,0x00000000}},	// [16970] ônio_, _akuş, èzye, --, 
   {{0x6384f85a,0x27400129,0x50646a24,0x00000000}},	//   géné, _géné_, нтха, --, 
   {{0xfe7000b2,0xbf1400c6,0x7a3403b2,0xa064010a}},	//   نگر_, بواب, _sátm, çата_, 
   {{0x6488025c,0x61ec127b,0x00000000,0x00000000}},	//   _eżit, _ubcl, --, --, 
   {{0x76a000a2,0x6384003e,0x274000e8,0x925839af}},	//   _aēyl, béné, _yéné_, _хаят_, 
   {{0x2de002dd,0xcbc415bf,0x00000000,0x00000000}},	//   _ﺇﻋﻼﻤ, ىزىي, --, --, 
   {{0xdcf80e3c,0x4fc48337,0xb4c800dc,0x5f74004b}},	//   _izuč, _سەنە, _लट्_, _راسر, 
   {{0xf8a824ab,0x00000000,0x00000000,0x00000000}},	//   овик_, --, --, --, 
   {{0x3dcc007f,0x6ab00115,0xdb000254,0x6d5c0bbc}},	//   _idew_, _ĉefŝ, vanõ, şpar, 
   {{0xdaa0021f,0x00000000,0x00000000,0x00000000}},	//   _كەتپ, --, --, --, 
   {{0xe3e02158,0x3dcc06a3,0xf77096d3,0x2740020c}},	//   য়াব, _kdew_, ضاد_, _réné_, 
   {{0xa5b81f60,0x27400129,0x00000000,0x00000000}},	//   sjón, _séné_, --, --, 
   {{0x7a342195,0x37e400f7,0xe45c007c,0x2b580419}},	//   _látk, _жолг, vrör_, ĺpce_, 
   {{0x88c8031c,0xe1fc03b2,0x63840129,0x18880139}},	//   _གྷིར, _ljód_, xéné, _усеп_, 
   {{0xe7e073c6,0x7b2003f9,0x3dcc007f,0x787c004e}},	//   _खाता_, rɓuw, _odew_, lèvo, 
   {{0x2740020c,0x5f20009e,0x6384a507,0x00000000}},	//   _wéné_, পনাও_, wéné, --, 
   {{0xca3800df,0x787c0561,0xdcf802f0,0xb46408ca}},	// [16980] _juĝa_, nèvo, _bzuč, _окил, 
   {{0x3dcc0142,0x78ac083c,0xe45c0267,0x2f540815}},	//   _adew_, _çavu, srör_, мтес, 
   {{0x6384fdc1,0x3dcc0003,0x26c08185,0x64880003}},	//   réné, _bdew_, ćkog_, _eżis, 
   {{0x1614012d,0x638400e5,0xf1d001af,0x00000000}},	//   _तोमर_, séné, _шөгө, --, 
   {{0x25e03eaf,0xdca0214f,0xe45c023a,0x63845f5e}},	//   ट्टी_, вачи, isön_, péné, 
   {{0x3dcc02e2,0x787c004e,0x7a3401d3,0x00000000}},	//   _edew_, dèvo, _háth, --, 
   {{0x5f000fcb,0x26c8038f,0xa3e03d60,0xe454008d}},	//   _изра, ġbok_, फ्ट_, ויסט_, 
   {{0x80d407f7,0x999c0205,0xe804000d,0x00000000}},	//   यूके, rkuş_, _वोजा_, --, 
   {{0x6b98074d,0xb0600598,0x7a34e4dc,0xfca801d3}},	//   _tgtg, _şäym, _máth, _فالو_, 
   {{0x7a34fdc2,0x6fdc02ab,0x00000000,0x00000000}},	//   _láth, मलिं, --, --, 
   {{0xda6cfdc3,0x81c80eac,0x7d0c02f0,0x00000000}},	//   _ая_, ল্ট_, ťast, --, 
   {{0x7a3400e5,0x00000000,0x00000000,0x00000000}},	//   _náth, --, --, --, 
   {{0x3e740267,0x8a400133,0xd4e40395,0x6a7c0200}},	//   mått_, _لێژن, кюри, lëfo, 
   {{0x3e7478d0,0x260cb340,0xf8ac80de,0xe8e800ec}},	//   lått_, _तोरी_, _اکي_, _هرڪو_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe8140316,0xed7404ce,0x268831b1,0x85b803cf}},	//   ताका_, teﾌ_, _بختي_, _элис_, 
   {{0x7a34007b,0x55bc011a,0x00000000,0x00000000}},	// [16990] _dáth, _ומחו, --, --, 
   {{0xe2a82df0,0x47d000bd,0x7a340f57,0x6a7c036e}},	//   _واجن_, ত্রী, _pátk, këfo, 
   {{0x3c3802bd,0x200400d0,0x7a3400ae,0x00000000}},	//   _sèvo_, ľni_, _fáth, --, 
   {{0x64880003,0xc234010f,0xc5f000cc,0xfaa400c7}},	//   _gżir, _נאָז_, _জোতা_, ҭало, 
   {{0xddd80113,0x2dc000d1,0x00000000,0x00000000}},	//   _chuš, ﮬﻪﻣﻤ, --, --, 
   {{0xca38008f,0x00000000,0x00000000,0x00000000}},	//   _ruĝa_, --, --, --, 
   {{0xeb94fdc4,0x7e6400c7,0xfaf07f51,0x1ee40330}},	//   ниш_, _зхаҵ, اثت_, _توزی_, 
   {{0x3e74fdc5,0x7a34a5c7,0xb90400f3,0x8e1400d8}},	//   gått_, _káti, език, _идсц, 
   {{0xe8f47798,0x4f380092,0x00000000,0x00000000}},	//   елы_, _በሚደር, --, --, 
   {{0x8d84010b,0x7a3468f1,0xe5a001d5,0x00000000}},	//   _русд, _máti, ғири, --, 
   {{0x7a34fdc6,0xf40c0183,0x7bc000ef,0xddc80210}},	//   _láti, _সকলৰ_, _ielu, migł, 
   {{0x7bc0123c,0x00000000,0x00000000,0x00000000}},	//   _helu, --, --, --, 
   {{0x7bc060e7,0x7a34fdc7,0x787c007f,0x28100133}},	//   _kelu, _ráth, lèvm, _ڕووس, 
   {{0x7bc00363,0x7d1c004e,0xd7f800f3,0xe8d4011a}},	//   _jelu, _àssu, _фуд_, _נוצר_, 
   {{0xf9fc0135,0xa498007f,0x25a801e7,0x00000000}},	//   _དྲོན_, twòc, éilí_, --, 
   {{0x7bc0fdc8,0xfbc400b2,0xfee4015b,0x7a34041e}},	//   _lelu, _ھڪ_, নবাধ, _báti, 
   {{0x7964044e,0x70840a15,0x41e00a8a,0x7a3400d8}},	// [169a0] _ውድባት, егаз, _फारस, _cáti, 
   {{0x7bc048b5,0x7a3404d4,0x600407a5,0x00000000}},	//   _nelu, _dáti, ннум_, --, 
   {{0xe7e0032c,0x7a34007b,0x63a0002d,0xa498033b}},	//   _खासा_, _táth, _ûnna, pwòc, 
   {{0x7a34fdc9,0x6da441e4,0xace8fdca,0x6cc4022e}},	//   _fáti, хида, змда_, ейда, 
   {{0x7bc0fdcb,0x470400b8,0xf9fc031c,0x5004010b}},	//   _belu, _bhṛṣ, _དྲེན_, _иҗаз, 
   {{0x37d40154,0x6fb4007b,0x00000000,0x00000000}},	//   ত্তর, _سمرا, --, --, 
   {{0x3e742ff9,0x61ec00c6,0x470400dc,0x7a340306}},	//   tått_, _éilí, _dhṛṣ, _záti, 
   {{0xddd87483,0xda14c853,0x7bc0000d,0xa5b80306}},	//   _thuš, थागत_, _eelu, skóz, 
   {{0x7bc0fdcc,0x2da00607,0x61f800e8,0x3e741f53}},	//   _felu, āseā_, _ñule, rått_, 
   {{0x7bc0fdcd,0xdca0d1ac,0x7aec0bc9,0x470400b8}},	//   _gelu, _сафи, ńata, _ghṛṣ, 
   {{0xaab80133,0xf7080051,0xa5b80413,0x461401e2}},	//   _ردار_, _cầ_, sjóm, نودر, 
   {{0x7bc0fdce,0xab640254,0x00000000,0x00000000}},	//   _zelu, _eküü, --, --, 
   {{0xda6ccea5,0x7bc0c6f8,0x69c00327,0x9564011c}},	//   _اُن_, _yelu, _ieoe, гърд, 
   {{0x2904fdcf,0x69c0005a,0x7bc01bce,0x81e40154}},	//   _isoa_, _heoe, _xelu, পড়া_, 
   {{0xca38010f,0x1368e4ae,0x201c0051,0xe2840798}},	//   _juĝo_, ешти_, _đui_, еѓан, 
   {{0x26dcfdd0,0x7a340120,0xca380115,0x00000000}},	//   muto_, _páti, _muĝo_, --, 
   {{0xd0d402e8,0x00000000,0x00000000,0x00000000}},	// [169b0] лотъ, --, --, --, 
   {{0xb8800316,0x69c003cb,0x833400c0,0x7a340166}},	//   _říze, _leoe, _анох, _váti, 
   {{0x26dcfdd1,0x50640372,0x69c00286,0x6fe0353b}},	//   nuto_, утта, _oeoe, _पारं, 
   {{0x7bc0fdd2,0x290405f5,0xefe8044e,0x7a340120}},	//   _selu, _osoa_, _መዳይ_, _táti, 
   {{0x7bc0dede,0x5184fdd3,0x26dcfdd4,0xf1a801b9}},	//   _pelu, _бура, huto_, _تاپه_, 
   {{0x8d74fdd5,0x26dcfdd6,0x60dc0113,0x27fc4b16}},	//   داما, kuto_, muqm, jetn_, 
   {{0x26dcfdd7,0x7bc0fdd8,0x29041140,0x69c075e2}},	//   juto_, _velu, _asoa_, _beoe, 
   {{0x26dc0a16,0x7bc0fdd9,0x7a3401ed,0xefc00023}},	//   duto_, _welu, _látv, _ስስዐ_, 
   {{0x7bc0fdda,0x29040077,0x7864036b,0xf86406ed}},	//   _telu, _csoa_, ккиз, квио, 
   {{0x7bc016b8,0xca3800df,0xd9e000c5,0x1ba801d3}},	//   _uelu, _fuĝo_, _गावत_, _رائٹ_, 
   {{0x55c4cacd,0x3668fddb,0x2904004e,0x41e00034}},	//   ланғ, дано_, _esoa_, _फांस, 
   {{0x69c0fddc,0xdcf800c7,0xbbd038b0,0x60dc02d1}},	//   _geoe, _aguĩ, _सयुक, kuqm, 
   {{0x26dcfddd,0xdb0000ae,0xe45c002f,0x6a7c0200}},	//   auto_, icní, psöl_, këfj, 
   {{0x26dcfdde,0x188898ec,0xe1fc02d2,0x7bf8010f}},	//   buto_, _эсеп_, _skóp_, ופֿצ, 
   {{0x26dc003a,0x42d41cb8,0x1b1c0154,0xf7440354}},	//   cuto_, літу, বনকে_, _шеко, 
   {{0x69c00077,0x00000000,0x00000000,0x00000000}},	//   _xeoe, --, --, --, 
   {{0x21a0fddf,0xe8140073,0xd76000f1,0xafe403fb}},	// [169c0] риум, ताचा_, _جنګی, коал, 
   {{0x33f40276,0x68340142,0xa1840116,0x68f40166}},	//   _рчис, _pâdi, тбуа_, _äyde, 
   {{0x7a3401d3,0xf1a8000d,0x00000000,0x00000000}},	//   _hátu, _कलपन, --, --, 
   {{0xee38fde0,0xed5834d8,0xca3800df,0x7a34fde1}},	//   ьне_, мое_, _ruĝo_, _kátu, 
   {{0x5ce00c9e,0xe7e010dd,0x26dcfde2,0x37d803d4}},	//   ающа, _खाला_, zuto_, ব্যৰ, 
   {{0x69c0fde3,0x5c70242f,0x7a342507,0xaae40633}},	//   _seoe, аліт, _mátu, نسبو, 
   {{0x7a34fde4,0x6da40588,0x15f402e5,0x26dc021c}},	//   _látu, _аиба, ेजार_, xuto_, 
   {{0x26dcfde5,0x3b0002d1,0xd9d02374,0x31c400c0}},	//   vuto_, çhqa_, لەمگ, būzų_, 
   {{0x6c04026a,0x26dc0099,0x7a3403b2,0x69c00254}},	//   _изаз, wuto_, _nátu, _veoe, 
   {{0xe1fc02d2,0x00000000,0x00000000,0x00000000}},	//   _mjóa_, --, --, --, 
   {{0xc01400c8,0x161400c5,0xca3c00d1,0x00000000}},	//   אַרק_, _तोहर_, ﻟﻼﺵ_, --, 
   {{0x26dcfde6,0x2904fde7,0xfbd0121e,0x7a340436}},	//   ruto_, _tsoa_, _پتے_, _bátu, 
   {{0xf9fc0867,0x26dcfde8,0x2a644ff5,0x2904fde9}},	//   _དྲིན_, suto_, _ijob_, _usoa_, 
   {{0x7a34fdea,0x58d04b3e,0x60dc0477,0xe45c007c}},	//   _dátu, _тошт, vuqm, msök_, 
   {{0xf8ac7f05,0x16140073,0x61fc014f,0x60dc014f}},	//   _وکی_, _तोवर_, teql, wuqm, 
   {{0x1fc8fdeb,0x533462bd,0xd3701823,0x45444028}},	//   ाण्ड, шест, تۇپ_, _منعق, 
   {{0x63a0045f,0x7a340aab,0xe45c007c,0x92940108}},	// [169d0] _ûnno, _gátu, nsök_, ратц, 
   {{0x7a34fdec,0x35180375,0x60dc0009,0x00000000}},	//   _hátt, _נותנ, ruqm, --, 
   {{0x60dcfded,0x7a3400d7,0x00000000,0x00000000}},	//   suqm, _zátu, --, --, 
   {{0x7a340579,0x60dc0477,0x61fc014f,0x73880166}},	//   _játt, puqm, qeql, _ярың_, 
   {{0x7a3409cc,0x8c3c0205,0x4df400d4,0x00000000}},	//   _mátt, _miğf, ряєт, --, 
   {{0x2a6402fa,0x69c42880,0x7a34d787,0x7f58fdee}},	//   _ajob_, ðken, _látt, _загс_, 
   {{0x3a98005b,0x7644005b,0x00000000,0x00000000}},	//   нтию_, yhky, --, --, 
   {{0x7a3405a4,0xb90806d3,0x539c008f,0x84f400bc}},	//   _nátt, ениз_, ויוו, ेबाट_, 
   {{0x2a6402e2,0xddd80122,0xe9cc01ec,0xd5a401d5}},	//   _djob_, _chuť, _қк_, یلدی, 
   {{0xc5f0009e,0x20cc00e2,0x59b0012c,0x1a6400f1}},	//   _জোলা_, iļi_, ीरहर, ریږی_, 
   {{0xe2000490,0x7a34fdef,0x7654007f,0xbb3400d1}},	//   _लसूण_, _bátt, èzyo, ﻗﭽﻰ_, 
   {{0x20cc00da,0x63080c58,0x09e40212,0x59b0fdf0}},	//   kļi_, ৰহাট_, _воїн, _төкс, 
   {{0x7d080354,0x7a3403b2,0xe45c01d3,0xb7bc030d}},	//   _jses, _dátt, csök_, _енлĕ_, 
   {{0x64440c95,0x6fe000e1,0x38a80332,0x7a340162}},	//   ghji, _पाइं, _iúr_, _vátu, 
   {{0x7a34002e,0xdb000306,0x7d0812e8,0x525400c7}},	//   _fátt, ybný, _lses, ахаӡ, 
   {{0x41b4516a,0x7d08fdf1,0x3c380ffb,0xf5040022}},	//   исут, _oses, _dèvi_, _бзио, 
   {{0x7d08c626,0x7a3401ed,0x20cc00e2,0x00000000}},	// [169e0] _nses, _háts, gļi_, --, 
   {{0x6444fdf2,0x38a84eb7,0x76540175,0x13a8030f}},	//   chji, _múr_, _hmyy, _جندی_, 
   {{0x7a3400dd,0xef1801c0,0x38a80413,0x00000000}},	//   _játs, эмж_, _lúr_, --, 
   {{0x2774008f,0xe1fc08a5,0x20cc0171,0x00000000}},	//   אגען_, _hjón_, bļi_, --, 
   {{0xdcac0c50,0x7a3401ed,0x6fe002ab,0x61f80de2}},	//   كىن_, _láts, _पाऊं, _ñula, 
   {{0x6a7c0240,0x6ec40fa2,0x4c94fdf3,0x00000000}},	//   mëfi, _مترق, шилс, --, 
   {{0xa064fdf4,0x7d08fdf5,0x00000000,0x00000000}},	//   _сара_, _eses, --, --, 
   {{0x38a809e8,0xe1fc08a5,0x64480153,0x3e500210}},	//   _búr_, _ljón_, _įgim, kąty_, 
   {{0x2d8000e4,0xf8ac06c5,0x38a801e7,0xfe7401c6}},	//   _áke_, وکو_, _cúr_, _түц_, 
   {{0x7a340436,0xe45c049f,0xdd140724,0xab28fdf6}},	//   _sátt, rsök_, läşt, _поза_, 
   {{0xcfcc03d4,0x00000000,0x00000000,0x00000000}},	//   ৰ্থন, --, --, --, 
   {{0xd6d40b32,0xa8600184,0x06c805f5,0xaa840432}},	//   ыть_, реүҙ, нгүй_, _duýý, 
   {{0x3c3811c1,0x7a34022c,0x64443998,0x00000000}},	//   _sèvi_, _vátt, thji, --, 
   {{0xcfcc0183,0xa5b80210,0x00000000,0x00000000}},	//   ৰ্তন, yjów, --, --, 
   {{0x43944558,0x2aa80295,0xaa840432,0x7a3406ea}},	//   равс, _jùb_, _guýý, _tátt, 
   {{0x539802bf,0x7a34fdf7,0x7e6801e4,0x1718008f}},	//   увся_, _hátr, _ĉepo, _טווע, 
   {{0x673801a8,0x2aa801c3,0xe1fc03b2,0x6444009a}},	// [169f0] lytj, _lùb_, _fjón_, phji, 
   {{0x79640b82,0x7a340118,0x425462a9,0x787c0100}},	//   _ውድቀት, _játr, _چندر, tèvi, 
   {{0x64540941,0x7d080337,0x4420fdf8,0x2c1c2d8f}},	//   _imxi, _sses, _inh_, पाईं_, 
   {{0x7d080770,0x7a3403f2,0xcee801d9,0x78a8036e}},	//   _pses, _látr, ارٕن_, yqev, 
   {{0x44200098,0x64480024,0x787c0100,0x8f340166}},	//   _knh_, _įgij, sèvi, _һерц, 
   {{0xe29c0008,0x7d0809a8,0x44200076,0x6fe0033f}},	//   _hið_, _vses, _jnh_, _पाएं, 
   {{0x6454067c,0x44205b37,0x38a81427,0xeaac00e5}},	//   _mmxi, _mnh_, _súr_, وٹو_, 
   {{0x7d08fdf9,0x6ea80d2c,0x44200129,0xfd942cc8}},	//   _tses, _जंतु, _lnh_, _көлә_, 
   {{0xe29c09f3,0x7d08fdfa,0x7e680124,0x44200098}},	//   _mið_, _uses, _ijep, _onh_, 
   {{0xb8fc1533,0xe29c09cc,0x44200076,0x78a80240}},	//   _तट_, _lið_, _nnh_, rqev, 
   {{0xf6241357,0x7c200af2,0x7e68fdfb,0x787c02e2}},	//   адно, _inlr, _kjep, zèvw, 
   {{0x442001dc,0x38a8fdfc,0xe1fc148b,0xe29c032e}},	//   _anh_, _túr_, _sjón_, _nið_, 
   {{0x3a2c016d,0x3af00208,0x4ab4004e,0x78a80200}},	//   mjep_, _hơp_, _көөр, qqev, 
   {{0x7e681727,0x394cfdfd,0xc96402bf,0x4420fdfe}},	//   _ljep, mzes_, _увій, _cnh_, 
   {{0xb77804ac,0x36681b6b,0x7e6807dd,0xe29c05f7}},	//   _באַש, _иако_, _ojep, _bið_, 
   {{0x7e685b4e,0x64540051,0x6a7c0200,0x9578009d}},	//   _njep, _emxi, tëfi, _бөгс_, 
   {{0x394cfdff,0x31247390,0xe1fc01a8,0xe69001c8}},	// [16a00] nzes_, шдаг, _tjón_, _بليد, 
   {{0x7e680124,0x2450004b,0xe538008d,0x6a7c0023}},	//   _ajep, _ونيس, _סתיר, rëfi, 
   {{0xaf04a43c,0x91a0063f,0xe1fc08a5,0xaf980408}},	//   рпел, ghị_, _kjól_, ттах_, 
   {{0x13a861f4,0x7e68f2df,0x3a2c025c,0xa5b80162}},	//   _جنگی_, _cjep, jjep_, sjóv, 
   {{0x394c0240,0x7e68036e,0x442006be,0x00000000}},	//   jzes_, _djep, _ynh_, --, 
   {{0xe7e82314,0x394c00da,0xec30035c,0x70540228}},	//   ज्ञा_, dzes_, توتگ, _ئنسا, 
   {{0x0b1800c6,0x7e68022c,0x787c026c,0x5f247927}},	//   اقبة_, _fjep, nèvu, _корм_, 
   {{0xfb18066d,0x3210fe00,0x7e68036e,0x3a2c0200}},	//   اروں_, ndyy_, _gjep, gjep_, 
   {{0x7a34969a,0x3eac01fa,0xca3800df,0xe45c0793}},	//   _pátr, _četi_, _juĝi_, msöv_, 
   {{0x7d1c0194,0x67380240,0xeab801c6,0x00000000}},	//   _ássa, tytj, _айж_, --, 
   {{0x4420070d,0x8c3c0790,0xa5b80d12,0x7a3401a8}},	//   _rnh_, _ciğe, kjót, _vátr, 
   {{0x8c3c0ab7,0xe7e832ed,0x787c0ffb,0xe45c01b8}},	//   _diğe, ज्जा_, dèvu, nsöv_, 
   {{0x4420033b,0xf9b429db,0xdd0c0139,0xe29c02d2}},	//   _pnh_, _уңыш_, _mışy, _rið_, 
   {{0xd7ec00c6,0x8c3c0166,0xd8700133,0x5dc80131}},	//   _يكن_, _fiğe, _واوب, _ﻗﯩﻠﺴ, 
   {{0x25bc1427,0x00000000,0x00000000,0x00000000}},	//   ðuls_, --, --, --, 
   {{0x86040271,0xd6280114,0x9798011a,0xc8780166}},	//   _اژده, _воће_, _בשוק, loğ_, 
   {{0xe29cfe01,0x3ddc0729,0x4420007f,0xd13058c5}},	// [16a10] _við_, ণ্ডল, _tnh_, ومِ_, 
   {{0x26dc3877,0xd5e40208,0x8c3c03e0,0x6a7c0200}},	//   orto_, _thị, _yiğe, mëfu, 
   {{0x7e685ece,0xe29c0162,0x394cfe02,0xd25001d3}},	//   _pjep, _tið_, zzes_, سنے_, 
   {{0xca3800df,0x26dc005b,0x00000000,0x00000000}},	//   _fuĝi_, irto_, --, --, 
   {{0x425407d6,0xa5b80321,0x11283802,0xfc14009d}},	//   _ننگر, ljós, _кюри_, ймдэ, 
   {{0xfbd0034d,0xfaa4fe03,0xa92002d2,0x00000000}},	//   ستت_, бако, _óþyr, --, 
   {{0x8b9406bb,0xe45c0793,0x7e684b55,0x3a2c003e}},	//   оръч, bsöv_, _tjep, tjep_, 
   {{0x394c0730,0x7e6800e4,0x3a2401b9,0xba2446dd}},	//   tzes_, _ujep, смиг, сдик, 
   {{0x26dc524a,0x394c3ae2,0xa9203c1f,0x98a002d5}},	//   erto_, uzes_, здыл, ąjį_, 
   {{0x394cfe04,0x7e78a2e5,0x00000000,0x00000000}},	//   rzes_, lowp, --, --, 
   {{0x394c066d,0xfb142d8d,0x3a2c01f4,0x00000000}},	//   szes_, _دواج, pjep_, --, 
   {{0x7e780309,0x9a84fe05,0xa5b802d2,0x088800cf}},	//   nowp, _тузл, djós, лбөй_, 
   {{0xca74fe06,0x26dcfe07,0x00000000,0x00000000}},	//   _بالغ, arto_, --, --, 
   {{0x628c0327,0x999c0784,0x7e780784,0x787c026c}},	//   _ahco, chuš_, howp, tèvu, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x628c01ab,0x00000000,0x00000000,0x00000000}},	//   _chco, --, --, --, 
   {{0x998c0153,0x25bc002e,0x00000000,0x00000000}},	// [16a20] _ilgų_, ñule_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfae4004b,0x00000000,0x00000000,0x00000000}},	//   _تګ_, --, --, --, 
   {{0x1afc03d4,0xd5c800ab,0x98bc012d,0x00000000}},	//   ্মাই_, लरिज, czuć_, --, 
   {{0xabb00075,0x6da4035b,0xa5c00022,0x00000000}},	//   палә, аиҵа, ñóis, --, 
   {{0x628000b0,0xc0c00023,0x2ac40114,0x00000000}},	//   _īnoi, ስኹም_, бљив, --, 
   {{0xdee08c21,0x00000000,0x00000000,0x00000000}},	//   _нори, --, --, --, 
   {{0xcfcc0183,0x00000000,0x00000000,0x00000000}},	//   ৰ্শন, --, --, --, 
   {{0x99d043ec,0xed44fe08,0x26c01505,0xde7401ed}},	//   ستيا, _унап, ćkom_, _اینڈ_, 
   {{0x1c400276,0x26dc0219,0x998c00c0,0x0854003b}},	//   _енум, trto_, _algų_, івню, 
   {{0xa5b806ea,0x26dc0067,0xe45c01f4,0x00000000}},	//   djór, urto_, isöt_, --, 
   {{0x27ec0024,0xd89001d9,0x6a7c0200,0x00000000}},	//   _šoną_, _ۂند, tëfu, --, 
   {{0x6aa00472,0x628c0a40,0xa5b80174,0x62300124}},	//   _iiof, _rhco, fjór, ҧҵоу, 
   {{0x26dc0fb7,0x628cfe09,0x6aa005da,0x6600016b}},	//   prto_, _shco, _hiof, _ɔnky, 
   {{0x6aa001f7,0xe7000327,0x00000000,0x00000000}},	//   _kiof, _མགྲན_, --, --, 
   {{0xc1b801c0,0x925801f0,0x2010025c,0x00000000}},	//   рлах_, баст_, wdxi_, --, 
   {{0x6aa047c8,0xc03403b7,0x31c401d9,0xa5b802d2}},	// [16a30] _miof, онај, زملہ, bjór, 
   {{0x6aa0fe0a,0x3ff400db,0x00000000,0x00000000}},	//   _liof, تكئر, --, --, 
   {{0xdcf80122,0x628c010a,0x5e8402d5,0xd13000f1}},	//   _vyuč, _thco, будз, ومې_, 
   {{0x6aa006d9,0x62400254,0x00000000,0x00000000}},	//   _niof, _kõom, --, --, 
   {{0xca380115,0x7e784ebd,0xa1c001ec,0xcfcc0220}},	//   _juĝu_, rowp, _мұңд, _ﺗﯘﺭﺗ, 
   {{0x26c00960,0x6a7c036e,0xe45c00e5,0x9be400d4}},	//   ćkoj_, këfs, csöt_, сідк, 
   {{0xae74002e,0xe7e03507,0x00000000,0x00000000}},	//   àñña, _खाजा_, --, --, 
   {{0x6aa0fe0b,0x3944010b,0x00000000,0x00000000}},	//   _ciof, жниг, --, --, 
   {{0x6aa0fe0c,0xa6e006ea,0x00000000,0x00000000}},	//   _diof, íðnu, --, --, 
   {{0xbc640014,0x00000000,0x00000000,0x00000000}},	//   _گۅڈن_, --, --, --, 
   {{0x06b84bcf,0x61ecfe0d,0x6aa0fe0e,0x787c06af}},	//   ینیک_, _occl, _fiof, fèvr, 
   {{0x6aa0fe0f,0xe1fc08a5,0x00000000,0x00000000}},	//   _giof, _djók_, --, --, 
   {{0xa5b81c38,0xe8ec46e8,0x80a800e1,0x6a7c04e6}},	//   tjór, _юл_, _झूले, rëft, 
   {{0xb2f46d7e,0xf7448d61,0x2dcc040d,0x00000000}},	//   _བྱུང_, _мело, _ﻗﯩﻠﻤ, --, 
   {{0x32340354,0xe3b000f1,0x00000000,0x00000000}},	//   охас, برټ_, --, --, 
   {{0xb06400a2,0x00000000,0x00000000,0x00000000}},	//   kläý, --, --, --, 
   {{0x61ec003a,0x8c3c0139,0xefc801c6,0xd62801fe}},	// [16a40] _dccl, _liğa, илал_, _воқе_, 
   {{0x61ecfe10,0xddd80113,0xe430007b,0x00000000}},	//   _eccl, _chuž, _يفيد, --, 
   {{0xeda4fe11,0x71a42c1d,0x61ec00b5,0x0f0405dc}},	//   ошло, _манз, _fccl, रबेस_, 
   {{0xd1300228,0xdb040248,0x8d28104e,0x00000000}},	//   _كۅز_, _àlùb, йнең_, --, 
   {{0xac0807d6,0x6aa00589,0xe45c00e5,0xefe80092}},	//   инда_, _riof, csös_, ቆመው_, 
   {{0x6aa01132,0xefe0001f,0xb1c401af,0x00000000}},	//   _siof, _ነቢዩ_, _ыңға_, --, 
   {{0x6aa006d9,0x6e440354,0xcdc4024c,0x00000000}},	//   _piof, _девз, _навқ, --, 
   {{0x4df4012c,0xe45cfe12,0xde0000d8,0xbb7000cf}},	//   _एउटै_, nsör_, _опси, رۇنع, 
   {{0xed580a16,0x999400a7,0xdcac00d1,0x00000000}},	//   _тоа_, окът_, _لىق_, --, 
   {{0xddd8002e,0x44300175,0xdd0c00d7,0x80dc0709}},	//   _amuň, xjz_, _užše, _पिसे, 
   {{0x6aa00270,0xe45c03e0,0x00000000,0x00000000}},	//   _tiof, ksör_, --, --, 
   {{0xe9d09717,0xfd6800e4,0x00000000,0x00000000}},	//   _آغا_, _repẽ, --, --, 
   {{0xb864583d,0x44300369,0xe4a4026b,0x00000000}},	//   _کانو, tjz_, юрно, --, 
   {{0x61ec02fa,0xb3e40003,0x06ac009e,0xfd6800e4}},	//   _sccl, _སྐྱུ, _কৌণি, _pepẽ, 
   {{0xb9e40020,0x00000000,0x00000000,0x00000000}},	//   _የት_, --, --, --, 
   {{0x80b40022,0x00000000,0x00000000,0x00000000}},	//   збах, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [16a50] --, --, --, --, 
   {{0x4394aa4e,0xe2a801d9,0x2dcc00d1,0x00000000}},	//   _напс, _پادن_, _ﻗﯩﻤﻤ, --, 
   {{0x14740aa0,0x10480212,0x00000000,0x00000000}},	//   _تايج, цяти_, --, --, 
   {{0xb2f40135,0x62200228,0x61ec0129,0x3d94084c}},	//   _བྱིང_, _تۉرل, _uccl, пиер, 
   {{0x5184fe13,0xc0c41cd1,0x6ab8143a,0x72a001ec}},	//   _жура, _хәби, _attf, _سەكن, 
   {{0xfaa47ecf,0x5578010f,0x00000000,0x00000000}},	//   пако, קעגן_, --, --, 
   {{0x6bd4007b,0x7f947d60,0x00000000,0x00000000}},	//   سويس_, _хавх, --, --, 
   {{0x29d00075,0xa9d00131,0xf77001ed,0x00000000}},	//   ىيىس, ىقىغ, ہاج_, --, 
   {{0xe1fc01e7,0xbd8800ec,0xdcfc0064,0x00000000}},	//   _mbó_, _اچان_, _įvėr, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xebc00139,0x6e280241,0x00000000,0x00000000}},	//   _чәчн, _ámbé, --, --, 
   {{0xe1fc0241,0x366828a8,0xb0600139,0xfd900023}},	//   _nbó_, само_, _ğämm, _ዝሓስቦ_, 
   {{0x3dcc00e8,0x01d00154,0xdd8c02dd,0x25bc0de2}},	//   _meew_, িলাদ, ншi_, ñula_, 
   {{0xe1fc0ca8,0xe29400c7,0x00000000,0x00000000}},	//   _abó_, ҧар_, --, --, 
   {{0x281041c1,0x22480334,0xd7741e2f,0x00000000}},	//   _سويس, _blck_, _باشع, --, 
   {{0x3dcc0694,0x00000000,0x00000000,0x00000000}},	//   _neew_, --, --, --, 
   {{0xafe49db2,0x24c40166,0x9eb40124,0x00000000}},	// [16a60] зозл, _егып_, ҧшцә, --, 
   {{0x5ed009bd,0xe0d4fe14,0xe45c0267,0xe4540209}},	//   _সহজে, яву_, ssör_, _нжы_, 
   {{0xe45404ac,0x2f546eda,0x6438011a,0x00000000}},	//   _זייט_, чтас, _העינ, --, 
   {{0xe1fc0570,0xd0ac016b,0x7644005b,0x00000000}},	//   _gbó_, _wɔɑb, nkky, --, 
   {{0x15e40150,0x00000000,0x00000000,0x00000000}},	//   _ﻋﺩﻤﻬ, --, --, --, 
   {{0x5ce01456,0x3074fe15,0x6140033a,0x2ac40114}},	//   ركىل, _хумс, _џера, пљив, 
   {{0x60202e80,0x00000000,0x00000000,0x00000000}},	//   _ядра, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x29002a59,0xebe4084c,0x00000000,0x00000000}},	//   ïka_, _ноап, --, --, 
   {{0x6d400083,0x244c0790,0x00000000,0x00000000}},	//   myoa, _küme_, --, --, 
   {{0xab78f7a2,0x3dcc0de2,0x00000000,0x00000000}},	//   _امضا_, _yeew_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d40fe16,0x636001d5,0x6d5c01e4,0x75a400c7}},	//   nyoa, _kеng, ŝpaf, дырҧ, 
   {{0xe1f001d3,0xd7ec007b,0x00000000,0x00000000}},	//   کسس_, _مكه_, --, --, 
   {{0x57f806a9,0x86b80014,0x636001a9,0x1fe00154}},	//   _הלוו, _بُبر_, _mеng, ন্ডস, 
   {{0x62800093,0x201c00a2,0x00000000,0x00000000}},	//   _īnos, _şui_, --, --, 
   {{0x3dcc3d27,0x00000000,0x00000000,0x00000000}},	// [16a70] _reew_, --, --, --, 
   {{0x50f400a8,0x6d4003e0,0x00000000,0x00000000}},	//   эзут, dyoa, --, --, 
   {{0x9f4404cc,0x88d40055,0x33f8011a,0x543c00d9}},	//   ünà_, _hṛdb, _והתנ, _לעזא, 
   {{0xf2d000c8,0x4fc40131,0x244c00a2,0x00000000}},	//   _בעט_, _ۋەقە, _düme_, --, 
   {{0xd5fc008f,0x7c94030f,0x61e801ab,0x00000000}},	//   מפאר, وشتا, òglu, --, 
   {{0x8d74fe17,0x64440158,0x00940276,0x3dcc01ab}},	//   رانا, nkji, _цигэ, _weew_, 
   {{0xeb945881,0x6360022e,0x7644023a,0x3dcc1bce}},	//   миш_, _dеng, ykky, _teew_, 
   {{0x3d9401a9,0x00000000,0x00000000,0x00000000}},	//   _жибр, --, --, --, 
   {{0x23bc0882,0x64443a26,0xc5c400eb,0x00000000}},	//   ्राद, kkji, ্লাপ, --, 
   {{0x32c40131,0xda6405d9,0xf7442f34,0x37a80137}},	//   _ﺩﯨﮕﻪ, _کائي, деоо, өтүн_, 
   {{0xdb0c01e1,0x00000000,0x00000000,0x00000000}},	//   _òdàr, --, --, --, 
   {{0xb994fe18,0x00000000,0x00000000,0x00000000}},	//   _قلاب, --, --, --, 
   {{0x49b80451,0x7644023a,0x6360022e,0x00000000}},	//   _راند_, rkky, _yеng, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x64a026c4,0x6380b576,0x00000000,0x00000000}},	//   тара, вгра, --, --, 
   {{0xd04811a9,0x00000000,0x00000000,0x00000000}},	//   ələr, --, --, --, 
   {{0x716801c0,0x00000000,0x00000000,0x00000000}},	// [16a80] цааг_, --, --, --, 
   {{0x6e44168d,0x6d400451,0x644400b5,0x1ae003d4}},	//   ژنام, vyoa, ckji, _কৈছে_, 
   {{0x0ed801ad,0xf2d800f2,0x8c3c03e3,0x287800df}},	//   _डिओड, _ببخش_, _siğo, קנעמ, 
   {{0x6360022e,0x00000000,0x00000000,0x00000000}},	//   _sеng, --, --, --, 
   {{0xdcac0222,0x1fe00183,0x1dcc01ad,0x30a00150}},	//   لىن_, ন্ধস, _हजरत, _ағағ, 
   {{0xeb4800d4,0x00000000,0x00000000,0x00000000}},	//   жчик_, --, --, --, 
   {{0x7d0c0327,0x00000000,0x00000000,0x00000000}},	//   ħasa, --, --, --, 
   {{0x893821d7,0x5ce000db,0x00000000,0x00000000}},	//   зпис_, ركۉل, --, --, 
   {{0x636001a9,0x644403b2,0x00000000,0x00000000}},	//   _tеng, ykji, --, --, 
   {{0x4734334a,0x7a3401d3,0x00000000,0x00000000}},	//   енос, _máty, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8c3c0139,0x00000000,0x00000000,0x00000000}},	//   _miğm, --, --, --, 
   {{0x981004fb,0x15a802e8,0xdb7c0092,0x00000000}},	//   ربیا, дъри_, ይዘውም_, --, 
   {{0xa3dc202e,0xe1fc0aab,0x00000000,0x00000000}},	//   दृढ_, _ljót_, --, --, 
   {{0xd6ccfe19,0x8c3c008e,0x6444fe1a,0x00000000}},	//   _шт_, _niğm, rkji, --, 
   {{0xd5b800d6,0xe1fc03b2,0x929402d5,0x6444fe1b}},	//   _ось_, _njót_, васц, skji, 
   {{0x69dc0093,0x55740724,0xd0d402e8,0x237c012d}},	// [16a90] _ēpel, _игът, котъ, łuj_, 
   {{0xff18037e,0x00000000,0x00000000,0x00000000}},	//   _arcと, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb7d40248,0x53440022,0x00000000,0x00000000}},	//   _iṣer, _рхьа, --, --, 
   {{0xb8a40020,0xfce4fe1c,0xfc040ff1,0x00000000}},	//   _መጣጥፍ_, холо, епло, --, 
   {{0x3154010f,0x6360022e,0x4fc40150,0x7b1400d8}},	//   _טירן_, _tеnd, _لەكە, еќиц, 
   {{0x2904fe1d,0x7a3402f0,0x45140011,0x00000000}},	//   _apoa_, _záty, ামিক_, --, 
   {{0xf8d4151e,0xfda400c7,0x00000000,0x00000000}},	//   еңдә_, _зызҟ, --, --, 
   {{0xd1c0001f,0x7a340208,0x00000000,0x00000000}},	//   _ድንቅ_, _mátx, --, --, 
   {{0x271c0327,0x4c9400c7,0x36c4dd5c,0xb7d40ca8}},	//   _bċn_, _аиус, нбог, _oṣer, 
   {{0x29040086,0x2a6c043b,0x6fb05ae4,0x00000000}},	//   _epoa_, ómbá_, _जलसं, --, 
   {{0xf650fe1e,0xb8d400eb,0x00000000,0x00000000}},	//   ائد_, _জব_, --, --, 
   {{0xe1fc2242,0xb7d40241,0xaba4001f,0x37e401c6}},	//   _ljós_, _aṣer, _ማሳደግ_, _золг, 
   {{0x3a3cfe1f,0xa938011a,0xe27800c7,0x00000000}},	//   _howp_, _מתנפ, ҧштә_, --, 
   {{0x2324013e,0xe1fc0162,0xa854011a,0x6f00012d}},	//   нори_, _njós_, _ריצה_, łocz, 
   {{0xdbd801e1,0x3634460e,0x672c01bf,0x00000000}},	//   _lààw, _سربس, åbje, --, 
   {{0xddc8083c,0xd76401ec,0x33d40153,0x00000000}},	// [16aa0] _şişl, _رەڭى_, _пінт, --, 
   {{0x3a3c0493,0xb880012c,0xfbe402f5,0x7c2c03f9}},	//   _lowp_, _říje, প্তত, ɓarg, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xee38fe20,0x5f7422d4,0xa5b800ae,0x00000000}},	//   яне_, رمنس_, adóf, --, 
   {{0xdd800137,0x425002f2,0x00000000,0x00000000}},	//   лышп, _ئۆقر, --, --, 
   {{0xe1fc03f2,0xdca048d4,0xee900133,0xcfcc00fe}},	//   _fjós_, гачи, _ڵگاک, ৰ্জন, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3a3c039a,0xdcf80139,0x00000000,0x00000000}},	//   _cowp_, _uzuğ, --, --, 
   {{0x3a3c039a,0xfe9003e6,0xa9c401d5,0xda6c01ec}},	//   _dowp_, _ئینج, وزکو, _ұя_, 
   {{0x2a6801ed,0x9f44452e,0xfbd00b98,0xfca81359}},	//   őbb_, ünç_, हरणम, _قالو_, 
   {{0xd6d4084c,0xe1fc02d2,0xda6c009d,0x2bc404e4}},	//   нтя_, _mjór_, _бя_, _र्या, 
   {{0x496401af,0x00000000,0x00000000,0x00000000}},	//   _инең, --, --, --, 
   {{0x3864fe21,0x00000000,0x00000000,0x00000000}},	//   bilr_, --, --, --, 
   {{0xf74816cb,0x00000000,0x00000000,0x00000000}},	//   _ڪجهه_, --, --, --, 
   {{0x825c0240,0x00000000,0x00000000,0x00000000}},	//   _ሃረርታ, --, --, --, 
   {{0x244c06be,0x00000000,0x00000000,0x00000000}},	//   _düma_, --, --, --, 
   {{0x660c03c6,0xe4a4fe22,0xe1fc1d1d,0x84c400d1}},	// [16ab0] meck, _проо, _bjór_, _шәнд, 
   {{0x660cfe23,0x372400d1,0xcdc42b8d,0x00000000}},	//   leck, _سوۋې, қашқ, --, 
   {{0x0f24008e,0xe1fc06ea,0xddd88969,0xdb2003b2}},	//   льцм, _djór_, _akuš, _ísøg, 
   {{0x660c0232,0x2480036e,0xab8c0023,0xee7001ec}},	//   neck, lojm_, _ምሕያል_, аңсы, 
   {{0x54340014,0x660c1196,0xd4340214,0x00000000}},	//   _شریر, ieck, _شعیب, --, 
   {{0x660cfe24,0x62800998,0x3a3c0204,0xdcac2002}},	//   heck, _ínob, _sowp_, لىچ_, 
   {{0x4fa401f0,0x9e040153,0x00000000,0x00000000}},	//   _биёв, _пчал, --, --, 
   {{0x3a2400d1,0xe7980118,0xba24344a,0x00000000}},	//   тмиг, _běží, тдик, --, 
   {{0x660cfe25,0x24800240,0xe8f4010b,0x20cc0327}},	//   deck, kojm_, влы_, nżi_, 
   {{0x7d08fe26,0x940002ab,0x24800200,0x00000000}},	//   _ipes, _लॉंच_, jojm_, --, 
   {{0xddd80316,0x660cfe27,0xd90c01ed,0xf0900375}},	//   _zkuš, feck, شیں_, שני_, 
   {{0x660c06f2,0x7d0801f2,0x244c02b5,0x00000000}},	//   geck, _kpes, _rüma_, --, 
   {{0x580024a7,0xd24400d1,0x20040115,0x00000000}},	//   _болғ, қмақ, ĵnij_, --, 
   {{0xd7f80aa5,0x7d08fe28,0x24800200,0x00000000}},	//   _худ_, _mpes, gojm_, --, 
   {{0x2a9c063f,0xb50400db,0x00000000,0x00000000}},	//   _ọbia_, رۉگۅ_, --, --, 
   {{0x7d08fe29,0x7c2c0198,0xe2946811,0xe1fc032e}},	//   _opes, ɓare, вас_, _sjór_, 
   {{0x2164fe2a,0x7d0801e1,0xc0e00092,0x2480036e}},	// [16ac0] вити_, _npes, _ዓባል_, bojm_, 
   {{0x52b40075,0x244c0254,0xa5b801f6,0x95f400eb}},	//   _مەسئ, _hümn_, adód, _জসিম_, 
   {{0x7d08fe2b,0xddd80f03,0x5264014b,0x00000000}},	//   _apes, _skuš, _бенғ, --, 
   {{0x470400b8,0xe4d007d6,0x6da433d2,0x00000000}},	//   _akṛṣ, _حقید, نمام, --, 
   {{0x9cb00597,0x999c0113,0x00000000,0x00000000}},	//   لمنت, ykuš_, --, --, 
   {{0x660c02fb,0xa498004e,0x09bc00dc,0x39480432}},	//   zeck, rtòg, ैर्य, _ýasy_, 
   {{0x7d081aac,0xfe4400ee,0x62400037,0x00000000}},	//   _epes, _өмрү, _tõot, --, 
   {{0x2480036e,0x4f941188,0x00000000,0x00000000}},	//   zojm_, _арғу, --, --, 
   {{0x660cfe2c,0x8c3c0205,0x00000000,0x00000000}},	//   veck, _liği, --, --, 
   {{0x660cfe2d,0x9c200166,0x24800200,0xeb9800f2}},	//   weck, _кдуд, xojm_, _قضات_, 
   {{0x660cfe2e,0x999c0113,0x7d080118,0x69e001ec}},	//   teck, chuž_, _zpes, _көпұ, 
   {{0x26f01533,0x3ce85a11,0x06c801c0,0xb0e0fe2f}},	//   _अमीर_, šave_, мгүй_, _पिंग, 
   {{0x24800240,0x00000000,0x00000000,0x00000000}},	//   tojm_, --, --, --, 
   {{0x842400d1,0x00000000,0x00000000,0x00000000}},	//   دىسن, --, --, --, 
   {{0xe5c48ed7,0x660cfe30,0x387801ed,0x3d180d0a}},	//   _испо, peck, ésre_, _मैने_, 
   {{0xb7d40241,0x24800240,0x8c3c0205,0xe45c03e0}},	//   _iṣar, sojm_, _diği, nsöz_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [16ad0] --, --, --, --, 
   {{0xb7d400cd,0x20cc031c,0xa3dc07b7,0x00000000}},	//   _kṣar, rżi_, दृश_, --, 
   {{0x7d08fe31,0x1fa4fe32,0xc17403e6,0xe45c0205}},	//   _spes, траг, _ڵگرت, ksöz_, 
   {{0xe61c025a,0x6d1cfe33,0xa4987172,0xcf980120}},	//   ndô_, पिंग_, stòd, тју_, 
   {{0x514400e5,0x00000000,0x00000000,0x00000000}},	//   _پہلے, --, --, --, 
   {{0x8c3c05d1,0x32d801d5,0x4c84109a,0xac780023}},	//   _yiği, _تدیک_, алів, _እጃሞም_, 
   {{0x4fc40058,0x1ee4072d,0x00000000,0x00000000}},	//   _ئەمە, _جوزی_, --, --, 
   {{0x5a4000d1,0x00000000,0x00000000,0x00000000}},	//   рмиғ, --, --, --, 
   {{0xb7d40ca8,0x7d08fe34,0xe61c0548,0xb3440a43}},	//   _aṣar, _upes, ddô_, _keçä, 
   {{0x3eacfe35,0xc9840063,0x00000000,0x00000000}},	//   _hiet_, јући, --, --, 
   {{0x3eac0208,0x36680120,0xb6a4d70a,0x27e80210}},	//   _kiet_, еано_, лиол, óbna_, 
   {{0x795859df,0x3eac0135,0xdb0001e7,0x00000000}},	//   _пиер_, _jiet_, scnó, --, 
   {{0x3eacfe36,0x2324016c,0x8c3c2ca8,0x324401d5}},	//   _miet_, қоти_, _siği, қеаг, 
   {{0x3eacfe37,0xfbe403f4,0x2bc4085c,0x636001a9}},	//   _liet_, প্রত, रुपा, _sеna, 
   {{0xc8a80801,0x84581422,0x00000000,0x00000000}},	//   _ръце_, трят_, --, --, 
   {{0x3eac45eb,0x425494ba,0x152807d6,0xf65035ea}},	//   _niet_, атут, _аниқ_, _دئت_, 
   {{0x312464c2,0x61e80332,0x3004009d,0x00000000}},	// [16ae0] ыдаг, ógla, лзаг, --, 
   {{0xe4540022,0x787c033b,0x674001d3,0x00000000}},	//   _бжь_, tèvy, _évjá, --, 
   {{0x3eac001e,0xaf9410fc,0x00000000,0x00000000}},	//   _biet_, ушај, --, --, 
   {{0xd25001d9,0x3eacfe38,0x00000000,0x00000000}},	//   _بۆر_, _ciet_, --, --, 
   {{0xdee0039b,0x3eacfe39,0x6dc40419,0x00000000}},	//   _қоти, _diet_, vďač, --, 
   {{0x3eac0fac,0xb344010e,0x84ec3be5,0x00000000}},	//   _eiet_, _geçä, _जमघट_, --, 
   {{0x3eac16b8,0x91b80073,0x7c6400d1,0x999c0432}},	//   _fiet_, _अलाई, جانل, lduň_, 
   {{0x3eacfe3a,0x6da4fe3b,0xada414a3,0xafe401d5}},	//   _giet_, _биба, _бабл, _шоҳл, 
   {{0xa2b841ac,0x286862bd,0x4bc4f229,0xc7b000c6}},	//   _शून्, ерно_, _көйг, يّة_, 
   {{0x3eac0936,0x00000000,0x00000000,0x00000000}},	//   _ziet_, --, --, --, 
   {{0xda6c0a81,0x3eac0295,0xe70801b9,0xd90c00e5}},	//   _کُن_, _yiet_, رتدن_, _ہیٹ_, 
   {{0xdb0401e1,0x00000000,0x00000000,0x00000000}},	//   _áláb, --, --, --, 
   {{0x2a64054e,0xe61c00d8,0x00000000,0x00000000}},	//   _imob_, rdô_, --, --, 
   {{0x2a640218,0x00000000,0x00000000,0x00000000}},	//   _hmob_, --, --, --, 
   {{0x0514015b,0x00000000,0x00000000,0x00000000}},	//   ামের_, --, --, --, 
   {{0xb64401d9,0x3cf405ac,0x2bc400bc,0xc0300051}},	//   _نٹى۪, _ইনস্_, _र्सा, _áhậu_, 
   {{0x3eacfe3c,0x26dcfe3d,0xb34400fd,0x00000000}},	// [16af0] _riet_, lsto_, _peçä, --, 
   {{0x3eacfe3e,0x26dcfe3f,0x2bc40b8f,0x00000000}},	//   _siet_, osto_, रुमा, --, 
   {{0x3eacfe40,0x661c0986,0x26dc13a5,0xb7f80183}},	//   _piet_, _kaqk, nsto_, _অসমত_, 
   {{0x26dcfe41,0xde44315b,0x3eac0200,0x4ec801e2}},	//   isto_, دیرو_, _qiet_, اونټ_, 
   {{0x3eac0016,0x661c0113,0x9ce4fe42,0x2bc46c5a}},	//   _viet_, _maqk, уцел, रुभा, 
   {{0x26dcfe43,0x3eac8d28,0x00000000,0x00000000}},	//   ksto_, _wiet_, --, --, 
   {{0x26dc3116,0x3eacfe44,0x2010004e,0xbdd4034b}},	//   jsto_, _tiet_, mexi_, _вобщ, 
   {{0x2bc4012c,0x2010fe45,0x6e400014,0xb0600432}},	//   रुबा, lexi_, _وۆلم, _çärj, 
   {{0x26dcfe46,0xbf0407f7,0x88c4036b,0x00000000}},	//   esto_, _रहुन_, یتیل, --, 
   {{0x7864fe47,0xf864fe48,0x2010003a,0x37040600}},	//   ркоз, рвоо, nexi_, апог, 
   {{0x7bc0035a,0xcb0800ec,0xbbd00118,0xdb1c4268}},	//   _iflu, _ميلن_, हरीक, övär, 
   {{0x20104a2b,0x3668cde5,0x00000000,0x00000000}},	//   hexi_, тамо_, --, --, 
   {{0x2d80003b,0x756401d3,0xf5040120,0x26dc012d}},	//   _øket_, شیدہ_, јзго, asto_, 
   {{0x244c04cc,0xb7d40cad,0x8c3c0139,0x00000000}},	//   _fümm_, _iṣor, _fiğu, --, 
   {{0x2010fe49,0x3244576f,0x00000000,0x00000000}},	//   dexi_, аевг, --, --, 
   {{0xbbd0038e,0x7ae0003a,0x754435dd,0xa5b800d8}},	//   हरुक, _mvlt, _вниз, rdóc, 
   {{0x7bc0fe4a,0x6360022e,0x7ae000ef,0xf064fe4b}},	// [16b00] _oflu, _fеno, _lvlt, акап, 
   {{0x999c0209,0xf34800c7,0x7bc00327,0xa498068c}},	//   rduň_, _апол_, _nflu, rtòc, 
   {{0xa4f031d9,0x661c00e8,0xa49800db,0xf4700131}},	//   _བཀོག_, _yaqk, stòc, _ﭼﯜﺷﯜ, 
   {{0x7bc0fe4c,0xfee8007b,0x00000000,0x00000000}},	//   _aflu, اعلى_, --, --, 
   {{0xdd8cfe4d,0xbbd0038e,0x3dc80bc9,0xa5b801d3}},	//   ووم_, हरूक, ñawa_, ndóa, 
   {{0x26dc0050,0x3ce80022,0x00000000,0x00000000}},	//   ysto_, áava_, --, --, 
   {{0xdee0fe4e,0x2078010f,0x6e34010a,0x00000000}},	//   _мори, _סאלא, _кхах, --, 
   {{0x3ce80bb8,0x6f0c0113,0x7bc003ac,0xc0e40240}},	//   šava_, _ipbc, _eflu, ምረሉ_, 
   {{0x7bc003cb,0x00000000,0x00000000,0x00000000}},	//   _fflu, --, --, --, 
   {{0x26dcfe4f,0xe7240212,0x085400d4,0x00000000}},	//   tsto_, аємн, свою, --, 
   {{0xe6dc063f,0x81cc015b,0x26dcfe50,0x2bc400dc}},	//   _ohụụ_, রণত_, usto_, रुणा, 
   {{0x6e20fe51,0xe1fc0077,0x2a640066,0x2d801445}},	//   ndob, _amón_, _umob_, _økes_, 
   {{0x1ce0031c,0xe708036b,0x7694fe52,0x068400db}},	//   ྩེར_, رتگن_, páyn, игүн, 
   {{0x18640c56,0x661c0309,0x26dc1445,0x2010011f}},	//   _качи_, _waqk, psto_, xexi_, 
   {{0x590031d9,0x80780107,0x765401f4,0x43940452}},	//   _མདོས_, ҳбас_, _flyy, савс, 
   {{0xd25802d5,0x6e2000f3,0x2bc401bc,0xe5c400f3}},	//   ацу_, jdob, रुता, _тско, 
   {{0x91b8fe53,0x6e202f1d,0xc3c40139,0x2d700131}},	// [16b10] ргут_, ddob, _гөбл, ﻻﺭﻧﻰ_, 
   {{0x758002f2,0x2368119e,0x00000000,0x00000000}},	//   _ژیێم, _ајмо_, --, --, 
   {{0x6d5c01e4,0x20108504,0xe81c000d,0x2d900205}},	//   ŝpal, rexi_, _भसना_, üyen_, 
   {{0x4420fe54,0x6e20fe55,0x7bc004cc,0x4ed400d4}},	//   _hah_, gdob, _sflu, іюєт, 
   {{0x4420fe56,0x6f0c03ac,0x20100393,0x7bc08c58}},	//   _kah_, _epbc, pexi_, _pflu, 
   {{0x4420fe57,0x69c00b23,0xb7d40882,0x6e20009a}},	//   _jah_, _afoe, kṣav, adob, 
   {{0x4420fe58,0x68e0067c,0xde440811,0xceb8009b}},	//   _mah_, _avod, _پیشو_, _вљу_, 
   {{0x4420fe59,0xae3401f0,0xbaa801ec,0x00000000}},	//   _lah_, _гӯшт_, _ﺷﺎﺷﺎ, --, 
   {{0x7e68fe5a,0x44206ecc,0x7d540006,0x596000d1}},	//   _imep, _oah_, _увах, юниғ, 
   {{0x4420fe5b,0xf1c802dd,0xdd8c00f1,0x00000000}},	//   _nah_, _ﺑﯩﻠﺘ, _فوځ_, --, 
   {{0x2d8002bf,0xa4f00135,0xbb8400c6,0x69c00142}},	//   _øker_, _བཀུག_, _الضي, _ffoe, 
   {{0x4420fe5c,0x6454fe5d,0x2128fe5e,0x377401ec}},	//   _aah_, _alxi, _orch_, _қылс, 
   {{0x7e6837da,0x44206e7a,0xe1fc002e,0x81cc015b}},	//   _mmep, _bah_, _amóo_, রণা_, 
   {{0x6e203c52,0x4420fe5f,0x64540393,0x00000000}},	//   zdob, _cah_, _clxi, --, 
   {{0x4420fe60,0x7c20fe61,0x394c00dd,0x7e68fe62}},	//   _dah_, _malr, lyes_, _omep, 
   {{0x44200066,0xf558007b,0xe3b00137,0x00000000}},	//   _eah_, _ملعب_, _ۉرپ_, --, 
   {{0x394cfe63,0xe294fe64,0x4420fe65,0x1ce0025c}},	// [16b20] nyes_, сат_, _fah_, ྩེས_, 
   {{0x4420fe66,0x7e68fe67,0xa5b8fe68,0xa498004e}},	//   _gah_, _amep, ndón, ltòn, 
   {{0x2128fe69,0xaf04fe6a,0xb8f8031c,0xc0a800c6}},	//   _erch_, спел, _འཆ_, شاكل_, 
   {{0xed58fe6b,0x6e20777d,0x44200170,0x212801a6}},	//   лое_, udob, _zah_, _frch_, 
   {{0x4420fe6c,0x4bb401c6,0x7c20fe6d,0x98e00116}},	//   _yah_, ойлс, _balr, _ﺋﻪﯞﻻ, 
   {{0x6e20fe6e,0x7e6800b4,0x7c20fe6f,0x4420011f}},	//   sdob, _emep, _calr, _xah_, 
   {{0x7c20fe70,0xcdc400c2,0xaa64004e,0xabd41c3e}},	//   _dalr, _мавқ, йтик, _ۇزات, 
   {{0x7c20127b,0xac040214,0xa8a400d1,0x394c0200}},	//   _ealr, _گذرو, әрик, fyes_, 
   {{0x68e0003a,0x394c01ed,0xdd8c00ec,0x7c2000e5}},	//   _qvod, gyes_, _ٻول_, _falr, 
   {{0xe1fc011f,0x7c20fe71,0xd7f44f35,0xe008af6c}},	//   _amól_, _galr, бую_, स्पद_, 
   {{0x4420fe72,0xa81801d9,0x00000000,0x00000000}},	//   _rah_, نتھر_, --, --, 
   {{0x4420fe73,0x2918fe74,0x9f940375,0x7c20022e}},	//   _sah_, _مقصد_, מדיה_, _zalr, 
   {{0x6924273e,0x9f5c01d3,0x1fe00011,0x00000000}},	//   _ымда, _örök_, ন্টস, --, 
   {{0x3870005e,0x6ab81cea,0xf480001f,0x44200842}},	//   _оқыт, _kutf, _የቅርብ_, _qah_, 
   {{0x44200097,0xb86424cc,0x2128030d,0x4df800bc}},	//   _vah_, _بانو, _srch_, ँलाई_, 
   {{0x4420fe75,0x2128070d,0x6ab80365,0xa49866e5}},	//   _wah_, _prch_, _mutf, ctòn, 
   {{0x4420fe76,0x6ab8fe77,0xbfd8003b,0x00000000}},	// [16b30] _tah_, _lutf, идає_, --, 
   {{0x212802fb,0x4420fe78,0x1fa4e89b,0x00000000}},	//   _vrch_, _uah_, брег, --, 
   {{0x73d8152d,0x41b400ae,0xf0780166,0x00000000}},	//   _өдөр_, _ومدر, шифә_, --, 
   {{0x394c020c,0x0c880023,0x3d940108,0x00000000}},	//   yyes_, _ንሃገሩ_, оиер, --, 
   {{0x7c2001e4,0x00000000,0x00000000,0x00000000}},	//   _palr, --, --, --, 
   {{0x6ab82959,0x394c0218,0x78b801a4,0x3ce813f1}},	//   _butf, vyes_, _ruwv, šavo_, 
   {{0x7c20fe79,0x6ab80810,0x9f5c02f6,0x394c0204}},	//   _valr, _cutf, ärän_, wyes_, 
   {{0x7c20fe7a,0x7e680451,0xef200034,0xab9000d1}},	//   _walr, _umep, _dużą_, بلىغ, 
   {{0x7c20fe7b,0x00000000,0x00000000,0x00000000}},	//   _talr, --, --, --, 
   {{0x6ab800d2,0xa5b86bdf,0x7c2000a3,0xf8640212}},	//   _futf, udón, _ualr, івно, 
   {{0xa5b8fe7c,0x7784fe7d,0xf744fe7e,0x394c0240}},	//   rdón, юлоз, цено, syes_, 
   {{0xf504fe7f,0x68ec07b3,0xdef40023,0x76b8013d}},	//   озмо, ündü, _ዋኒን_, ллүр_, 
   {{0x37e4fe80,0x2bc42ce6,0xb88401e4,0xbae00150}},	//   _долг, रुवा, taŭĉ, _ﺍﻹﺠﺎ, 
   {{0xe1fc0077,0xdb1c01e1,0x170405af,0x00000000}},	//   _acó_, _áwól, _هفتی_, --, 
   {{0x628c0175,0x00000000,0x00000000,0x00000000}},	//   _bkco, --, --, --, 
   {{0x628c010a,0x165800e5,0x00000000,0x00000000}},	//   _ckco, _دستک_, --, --, 
   {{0x3d18038e,0x13a8fe81,0x363400f2,0x03d800cc}},	// [16b40] _मैले_, _گندی_, _هرکس, _তাৰণ, 
   {{0xa49800db,0xa0a002dd,0x00000000,0x00000000}},	//   ntòl, дауд, --, --, 
   {{0x32447aeb,0xc100009d,0x13a801e2,0x00000000}},	//   _денг, _үүсл, _دندی_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe568001f,0x6ab8002d,0xc1d40daf,0xac8401c6}},	//   _አንደኛ_, _sutf, _хөсә, огдл, 
   {{0x3cd80006,0x2ac40114,0x00000000,0x00000000}},	//   сьцю_, ољив, --, --, 
   {{0x2bc428e1,0x26180073,0x5f00119e,0x00000000}},	//   रुषा, _बसली_, _озра, --, 
   {{0x29880798,0xa5b802d2,0x00000000,0x00000000}},	//   испо_, gdól, --, --, 
   {{0xec14fe82,0x290024ba,0xad68009d,0x00000000}},	//   _وورد, îka_, _тааз_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf1a8227c,0x28d800e1,0xe45c00e5,0x5fb800df}},	//   चेतन, _मौरि, spök_, יצינ, 
   {{0xe66402bf,0x60d80166,0x00000000,0x00000000}},	//   ітно, _çumg, --, --, 
   {{0xc4b40709,0x00000000,0x00000000,0x00000000}},	//   ंदेख, --, --, --, 
   {{0x61d000cd,0x00000000,0x00000000,0x00000000}},	//   तर्ष, --, --, --, 
   {{0x9f446f30,0x6aa088fe,0x671c033f,0xa5b80413}},	//   ünü_, _khof, _बनिक_, ldóm, 
   {{0xc1b805f5,0x00000000,0x00000000,0x00000000}},	//   слах_, --, --, --, 
   {{0xa5b83fa6,0x6aa00099,0x6360022e,0x6af80327}},	// [16b50] ndóm, _mhof, _mеni, _དཀའོ_, 
   {{0xae3401c6,0x78bc0162,0x00000000,0x00000000}},	//   үүрт_, ísvi, --, --, 
   {{0xdef80fb5,0x6aa01132,0x4394fe83,0x2bdc012d}},	//   рыз_, _ohof, _ханс, _नज़ा, 
   {{0xa5b801a8,0x00000000,0x00000000,0x00000000}},	//   kdóm, --, --, --, 
   {{0x28d81b97,0x8d740271,0x00000000,0x00000000}},	//   _मौलि, واها, --, --, 
   {{0x6aa0fe84,0x2bc40316,0xa5b80162,0x00000000}},	//   _ahof, रुला, ddóm, --, 
   {{0x59000003,0x00000000,0x00000000,0x00000000}},	//   _མདངས_, --, --, --, 
   {{0x6aa0fe85,0x952c031c,0xb7d40ca8,0x7d0c00d8}},	//   _chof, _སླའི_, _iṣir, çass, 
   {{0xa5b80579,0x6aa0022f,0xe9d40228,0x64b40073}},	//   gdóm, _dhof, чкы_, _इंगळ, 
   {{0x6aa018f7,0xb7d40055,0x00000000,0x00000000}},	//   _ehof, _kṣir, --, --, 
   {{0xdb680b3b,0x00000000,0x00000000,0x00000000}},	//   _трал_, --, --, --, 
   {{0x6aa030b5,0xa498381a,0xda640451,0xca48fe86}},	//   _ghof, stòl, _بائي, _ولله_, 
   {{0xdb1c006a,0xddd8151c,0x81c0015b,0x58000220}},	//   _âwâl, _okuž, ঁরা_, _жолғ, 
   {{0x2dcc0150,0xb9c80092,0xf7880166,0x00000000}},	//   _ﺗﯩﻠﻤ, _ሳሉ_, geçä_, --, 
   {{0xa498004e,0x00000000,0x00000000,0x00000000}},	//   ctòm, --, --, --, 
   {{0x998c0024,0x11f8158b,0x031c0037,0x00000000}},	//   _uogų_, تورک_, _पनरह_, --, 
   {{0xb7d40ca8,0x66180254,0x00000000,0x00000000}},	// [16b60] _aṣir, õuke, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa92408a5,0xac8401e0,0xfae400f1,0x2d98012d}},	//   _kaþó, үгел, _جګ_, ępem_, 
   {{0xd25801b9,0x3e7402f0,0xc48401af,0x00000000}},	//   _بیرش_, yťte_, _нлөк, --, 
   {{0x20040137,0x6da4fc00,0x9b4001d9,0x5764002b}},	//   ònic_, чида, ہنوو, _vīṇā_, 
   {{0xe1fc011f,0x6aa0fe87,0x6360022e,0x3cec012d}},	//   _amóh_, _shof, _sеni, _घिरे_, 
   {{0x6aa0fe88,0xa0a02472,0x5f90014b,0x00000000}},	//   _phof, _чард, _зиёт, --, 
   {{0xce34fe89,0x6aa0014b,0xed58f56c,0x7d0c031c}},	//   _تورک, _qhof, _лоб_, ħasr, 
   {{0x6aa00084,0x61e8fe8a,0x2ef8002f,0xe1fc02d2}},	//   _vhof, ógli, lupf_, _smók_, 
   {{0xe784fe8b,0xa5b809f3,0x7aec0bc9,0xdcac0137}},	//   зумо, rdóm, ņata, _مىق_, 
   {{0x6aa0fe8c,0x212401fb,0x2ef80810,0x3e74022a}},	//   _thof, ̉nh_, nupf_, sťte_, 
   {{0x95c8035b,0x6aa0014b,0x17641de6,0x00000000}},	//   зура_, _uhof, ярып_, --, 
   {{0xc0d00241,0x00000000,0x00000000,0x00000000}},	//   _oríọ, --, --, --, 
   {{0x9418013f,0x213c0135,0xd5940023,0x81c000fe}},	//   mmrɛ_, _ħuh_, _መንሽሮ_, ঁৰা_, 
   {{0x53340c82,0xa2740092,0xb9e40092,0xa5b800e5}},	//   нерт, _የእኛን_, _ከት_, ndók, 
   {{0xddd83a4a,0xc29801ce,0x00000000,0x00000000}},	//   _skuž, іках_, --, --, 
   {{0x66e001e1,0x9af00115,0x212c007b,0x80b40c60}},	// [16b70] _fíká, _ĉeƭe_, ígh_, дбах, 
   {{0x32000204,0x1fa42b39,0x27fc0051,0x00000000}},	//   _ecky_, прег, ngtn_, --, 
   {{0x7f1824cf,0x506401f0,0x00000000,0x00000000}},	//   تياز_, хтта, --, --, 
   {{0x7d9801f4,0x00000000,0x00000000,0x00000000}},	//   овес_, --, --, --, 
   {{0x5184fe8d,0xccc400d4,0x212401e2,0x00000000}},	//   _зура, ебій, _عيسی_, --, 
   {{0x22480ac5,0x00000000,0x00000000,0x00000000}},	//   _hock_, --, --, --, 
   {{0x2248fe8e,0x7a6805f5,0x998c0432,0x3c2c00e5}},	//   _kock_, жийг_, _bagş_, jövő_, 
   {{0x22481c1d,0x61fc0007,0xce940395,0xbaa80150}},	//   _jock_, ngql, _засъ, _ﺷﺎﺗﺎ, 
   {{0x22480e21,0x00000000,0x00000000,0x00000000}},	//   _mock_, --, --, --, 
   {{0x9ba0fe8f,0x22480f5a,0xa2ac01f9,0x00000000}},	//   _كەشى, _lock_, ंगड्, --, 
   {{0x0c84010b,0xbb540271,0x00000000,0x00000000}},	//   _чытм, _تناب, --, --, 
   {{0x3914021a,0x2248039a,0x66e002d2,0x672c03b2}},	//   _يواز, _nock_, _síká, æbja, 
   {{0x244c014a,0x25dc00af,0x00000000,0x00000000}},	//   _nüms_, _कजरी_, --, --, 
   {{0xe8d40375,0xddc801ec,0x00000000,0x00000000}},	//   _חוסר_, _ﺗﯩﺰﺑ, --, --, 
   {{0x2248fe90,0x232406c4,0x69c40205,0x00000000}},	//   _bock_, мори_, ıkev, --, 
   {{0x5908025c,0x77500023,0x00000000,0x00000000}},	//   _ཁྱོས_, _ዝመሳሰ, --, --, 
   {{0xf1a858fb,0x2248fe91,0x15b400db,0x70540345}},	// [16b80] زاره_, _dock_, _سەسس, ونرا, 
   {{0xe1fc0210,0x00000000,0x00000000,0x00000000}},	//   _omów_, --, --, --, 
   {{0x2004381a,0xdee00818,0x00000000,0x00000000}},	//   ònia_, вохи, --, --, 
   {{0x2248fe92,0xee380139,0xa2ac0490,0xb7d40241}},	//   _gock_, юне_, ंगण्, _iṣur, 
   {{0xc8f80729,0x5ce01df2,0xc7b801a6,0xbe8000d1}},	//   _অন্ত_, پكىل, leđe_, уқти, 
   {{0x224802c1,0xb7d400cd,0x00000000,0x00000000}},	//   _zock_, _kṣur, --, --, 
   {{0x443c013f,0x7984013f,0x5ac400fd,0x00000000}},	//   _ɑw_, _ɛhwe, үләм_, --, 
   {{0x244c29ef,0x5bc001e0,0x00000000,0x00000000}},	//   _yüms_, нйәб, --, --, 
   {{0xec78fe93,0x00000000,0x00000000,0x00000000}},	//   _дпа_, --, --, --, 
   {{0x5ca00124,0x00000000,0x00000000,0x00000000}},	//   _аиуб, --, --, --, 
   {{0xc7b88185,0x8c24015b,0xa5b8007b,0x9a2000e5}},	//   jeđe_, পাদন_, ldói, رٹین, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x68449db8,0x2248fe94,0xe6b001d5,0x3dc803f0}},	//   _онда, _rock_, _یلتگ, ñawi_, 
   {{0x6d400005,0xddd80135,0x22482517,0x00000000}},	//   ixoa, _skuż, _sock_, --, 
   {{0x22480493,0xa5b80332,0xe4e80037,0xd7f873cd}},	//   _pock_, hdói, _झटकि_, _והול, 
   {{0xef380020,0x3ce816a3,0xa5b800e5,0x00000000}},	//   _የሚያው, šavi_, deóg, --, 
   {{0xe4a405f5,0x22480076,0xa308012c,0x00000000}},	// [16b90] _ороо, _vock_, _हङकङ_, --, 
   {{0x4094278f,0xd9b81b37,0x6d40005a,0x048801af}},	//   رلار, _उल्ट, dxoa, _хәми_, 
   {{0x833404ac,0x22480010,0x00000000,0x00000000}},	//   _װאָס_, _tock_, --, --, 
   {{0x78ac0395,0x64440e14,0xffb4009d,0x76940241}},	//   _èavv, ljji, _үймэ, báyu, 
   {{0x64440ba7,0x99e0010e,0xf1d401ec,0x00000000}},	//   ojji, _öňin, _ﺘﺘﻠﻘ, --, 
   {{0x009401c6,0x00000000,0x00000000,0x00000000}},	//   _чигэ, --, --, --, 
   {{0x60ccfe95,0x26cc0af2,0xa5b8007b,0xbd8803e6}},	//   _htcm, _ntfo_, adói, _کچان_, 
   {{0x4ea452d9,0x9420013f,0x13b8011a,0x00000000}},	//   _аруа, _ɔsɑn_, והול_, --, 
   {{0x39582880,0x61ec003a,0x7cd802f2,0x9e980092}},	//   áss_, _mdcl, _رواز_, ላከልና_, 
   {{0x7d080472,0x60cc010a,0xddd804ba,0xcc3401d5}},	//   _iqes, _mtcm, _oluŋ, _لرمع, 
   {{0xe1fc033f,0xf09002e4,0x4ae40064,0x00000000}},	//   _umów_, רני_, _аўча, --, 
   {{0x64440ba7,0x00000000,0x00000000,0x00000000}},	//   ejji, --, --, --, 
   {{0xddd81418,0xc7b801a6,0xca740137,0xe72c013d}},	//   _aluŋ, veđe_, _جەيت_, _өе_, 
   {{0x61ecfe96,0x7d0800f1,0x00000000,0x00000000}},	//   _adcl, _mqes, --, --, 
   {{0x64a0fe97,0x437400d1,0xb778008f,0xb82400fe}},	//   уара, вутт, _מאַש, বাদত_, 
   {{0x35a4fe98,0x7d08004b,0x60cc00b5,0x6444fe99}},	//   _пайг, _oqes, _btcm, ajji, 
   {{0xe1f405f5,0x60cc004e,0xe280311b,0xc7b801a6}},	// [16ba0] эгт_, _ctcm, улти, ređe_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7d0801e2,0x91fc0296,0xdfcc0597,0xb900031c}},	//   _aqes, ɔ́ns, صين_, _ཧས_, 
   {{0x6d4001c0,0xa5b85b84,0xb640037e,0x87ac010f}},	//   txoa, reóg, _ｍｒ_, קשאַ, 
   {{0xe45c01b8,0x201400cf,0xed34009d,0x00000000}},	//   mpör_, ïció_, ээжэ, --, 
   {{0xdcac0f78,0xdd8cad99,0x31c40014,0xeb48fe9a}},	//   مىن_, حوه_, _تتھُ, зчик_, 
   {{0x7d08fe9b,0x98c00220,0xe9e406a6,0x9510031c}},	//   _eqes, қсыл, нцпо, _ཏཱའི_, 
   {{0x8938e58b,0xad640451,0x8a1801d5,0x6280032e}},	//   дпис_, _ٻاره, фоис_, _ínot, 
   {{0x27ec009d,0x28d8257b,0xa49800a3,0xada400db}},	//   _pdfn_, _मौखि, stòi, _чаал, 
   {{0x47342082,0xf8ac00aa,0xa5b80022,0x00000000}},	//   внос, يکو_, ndóv, --, 
   {{0xd1d00023,0x56580023,0x7c8400d8,0x6b58030d}},	//   ብራቕ_, _ዝረኽብ, _руѓе, _эшар_, 
   {{0xa3d01af8,0xa86001e0,0x00000000,0x00000000}},	//   हुन_, теүҙ, --, --, 
   {{0x04880724,0x15a802e8,0xa2ac298e,0x00000000}},	//   дәни_, еъри_, ंगस्, --, 
   {{0x5908031c,0x87780395,0x00000000,0x00000000}},	//   _ཁྱིས_, _ойлс_, --, --, 
   {{0x4394fe9c,0xb4b40daf,0x18b40209,0xf7e000d1}},	//   тавс, тирә, _ягшы_, _ﺋﯘﻧﺪ, 
   {{0x1798011a,0x9798123b,0x00000000,0x00000000}},	//   _מיוב, _משוק, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [16bb0] --, --, --, --, 
   {{0xe1fc0548,0x659000c7,0x46a4302b,0xa344009d}},	//   _amót_, _иақу, _गीतह, _зэмл, 
   {{0xf4100375,0x271c0037,0x00000000,0x00000000}},	//   _דפי_, _बनोर_, --, --, 
   {{0xe61c073c,0xd13001ed,0x534407d5,0xfcb80092}},	//   neô_, جمے_, _схьа, _ሲወጡ_, 
   {{0x6b9807d6,0xddd80356,0x7c2806ed,0xf1240166}},	//   _aytg, _ajuţ, долг_, _иярү, 
   {{0xe0dc01e1,0x4fc410e0,0x00000000,0x00000000}},	//   _iwò_, _مەكە, --, --, 
   {{0xbb4400fd,0x6b98015d,0x6b600a93,0x00000000}},	//   тейк, _cytg, икша, --, 
   {{0x6d5c01e4,0xd01000f1,0x00000000,0x00000000}},	//   ĝpar, _پلې_, --, --, 
   {{0x7d0800f1,0xb82400cc,0x6d5c0115,0x3cb4010a}},	//   _uqes, বাসত_, ŝpar, _айар, 
   {{0x565802d3,0x00000000,0x00000000,0x00000000}},	//   _ዝረኸብ, --, --, --, 
   {{0xf770106b,0x44ec00d0,0x26c801e4,0x00000000}},	//   شاد_, eľ_, ŭbon_, --, 
   {{0x69c4002d,0x3ce8107d,0xe97084d2,0x8cd800ce}},	//   űker, šavu_, اهید, नीको, 
   {{0x3a2c0208,0xe0dc01e1,0x64e000fb,0xd918030d}},	//   mdep_, _nwò_, аҡығ, _хье_, 
   {{0xf770fe9d,0xe1fc0332,0xfcb80092,0x00000000}},	//   _پات_, _omós_, _ሲወጣ_, --, 
   {{0xc5e0015b,0xab70001f,0x44ec0419,0x72940408}},	//   _ভারপ, _እንደው_, aľ_, вшах, 
   {{0x3a2c0652,0xe280fe9e,0xd8740244,0x00000000}},	//   ndep_, алси, _تاڵب, --, 
   {{0xe294fe9f,0xe1fc00e4,0x69cc013f,0x3a2c0208}},	// [16bc0] тат_, _amós_, ɛbed, idep_, 
   {{0x2f540046,0x3dcc0810,0xc7b8107d,0xa4f8011a}},	//   ктес, _afew_, leđa_, _קליט, 
   {{0x3cec05d5,0xe0dc01e1,0x3a2c00ee,0xaf98dba2}},	//   _avev_, _ewò_, kdep_, фтах_, 
   {{0x81e40729,0xe61c0dd4,0x7534fea0,0x6cd40736}},	//   _নাথ_, rnôg_, _kryz, نقصا, 
   {{0x3a2c00ca,0x42540276,0x7c64036b,0xe1fc0162}},	//   ddep_, _стэт, گانل, _slóg_, 
   {{0xdca001c0,0xe1fc02d2,0x62802507,0x00000000}},	//   аачи, _plóg_, _ínor, --, 
   {{0x7c64fea1,0xdee02c1d,0xcfe804c5,0x2eb4fea2}},	//   دانل, _воси, _পাপন, _асас, 
   {{0x7534fea3,0xc7b81e31,0xddc40311,0x2bc41546}},	//   _oryz, jeđa_, ălţa, रुजा, 
   {{0xfe900502,0x6b98000f,0xac0806ed,0xc5e00183}},	//   _اینج, _wytg, _онаа_, _ভালপ, 
   {{0x44ec00d7,0x00000000,0x00000000,0x00000000}},	//   vľ_, --, --, --, 
   {{0x6b9800ee,0x20540677,0x66180037,0x00000000}},	//   _uytg, דייל_, õuko, --, 
   {{0x49a4052f,0x7b78008f,0x5fa40bae,0x3a2c0051}},	//   _йылғ, _אָנצ, केटल, cdep_, 
   {{0xd04803be,0xe61c0109,0xda040271,0x95d80395}},	//   şlər, reô_, _شيوه_, ъдят_, 
   {{0x6278001f,0x75340064,0x94d400c7,0x00000000}},	//   _አብያተ_, _dryz, рорц, --, 
   {{0x200400f7,0xa2ac0490,0xddd807f5,0x12c4036b}},	//   ònim_, ंगल्, _ljuš, иётг, 
   {{0x75340034,0x26880ccb,0xc878c8d8,0x00000000}},	//   _fryz, _تختي_, liğ_, --, 
   {{0xddd80d0f,0x7534fea4,0xd1300592,0xd2440276}},	// [16bd0] _njuš, _gryz, يمِ_, шэри, 
   {{0x200409a5,0x00000000,0x00000000,0x00000000}},	//   üni_, --, --, --, 
   {{0x6d5400fe,0x3a2c0051,0xa3440153,0x00000000}},	//   øyan, ydep_, _рэпл, --, 
   {{0xe0dc0699,0x3a2c0998,0x4ea4e017,0x2004033f}},	//   _twò_, xdep_, арча, żni_, 
   {{0xa5b809c2,0xeb940116,0x00000000,0x00000000}},	//   cdót, һиш_, --, --, 
   {{0x3df40131,0x769400e4,0xfc044db0,0x7f9400f3}},	//   _әзас, háyp, упко, _багх, 
   {{0xeb94fea5,0xac940075,0x705000f7,0xc0cc0092}},	//   лиш_, اچقا_, _اچقا, ብዛም_, 
   {{0xba240116,0xa3d05b82,0xf1c40764,0xa5b801d3}},	//   удик, हुत_, वशयन, ndós, 
   {{0xe8f4fea6,0xa4980ba1,0xc7b801a6,0x3cf80162}},	//   глы_, ntòs, veđa_, _ísv_, 
   {{0xdd907601,0xe8f4fea7,0x8d844eb0,0x00000000}},	//   _бағы, ыль_, _тусд, --, 
   {{0x7bc0fea8,0x1b000150,0xbb54114f,0x00000000}},	//   _iglu, _түйн, _حناب, --, 
   {{0x3a2c047e,0x75340210,0x00000000,0x00000000}},	//   qdep_, _pryz, --, --, 
   {{0x9f400200,0x603800ef,0x24ac0150,0x00000000}},	//   _bejë_, _kāmē, _ﺳﻮﻝﻣ, --, 
   {{0x32100175,0xf1d001c6,0x603800de,0xe8d4011a}},	//   wfyy_, өөмө, _jāmē, _עוצר_, 
   {{0x87240c8b,0x21643edf,0x00000000,0x00000000}},	//   _نعيم, ҳити_, --, --, 
   {{0xe29405f5,0xf77005d9,0xd734009d,0xc6a400f3}},	//   гас_, _پاڪ_, _зүүх_, _крњи, 
   {{0x7bc00209,0xcfe80eac,0x2164cec6,0x61400902}},	// [16be0] _oglu, _পাবন, гити_, бета, 
   {{0x7bc0314e,0xa5b809f3,0xb63c0046,0x00000000}},	//   _nglu, rdót, _ﺇﻥ_, --, 
   {{0xa5b81873,0x00000000,0x00000000,0x00000000}},	//   sdót, --, --, --, 
   {{0xa4981f40,0x1ec40798,0x32440108,0xace80114}},	//   stòt, улци_, _семг, емда_, 
   {{0x9f4002e2,0xa498067c,0xa5b8089f,0x5d1005af}},	//   _lejè_, ctòs, ldór, مبوز, 
   {{0xa49800db,0x56200154,0xd1dc0023,0x00000000}},	//   ltòr, ধায়ক_, _ዕቕባ_, --, 
   {{0x6fd81152,0x2d9400db,0x00000000,0x00000000}},	//   _प्यू, _өөдө_, --, --, 
   {{0x4a54fea9,0x7bc0feaa,0xa49800cf,0x7e78033f}},	//   ркис, _eglu, cròf, ciwp, 
   {{0x5a300588,0x00000000,0x00000000,0x00000000}},	//   сныт, --, --, --, 
   {{0xc5e02b1b,0x7b0806d9,0x00000000,0x00000000}},	//   _ভাইপ, ôstô, --, --, 
   {{0x81cc0183,0xd7ec2bcb,0x9cb0009f,0x7c64feab}},	//   ৰণত_, _қу_, _املت, _ئاقل, 
   {{0xe7380323,0x246c001f,0x46e800f7,0xa504109a}},	//   _үед_, _አህመድ_, ндүн_, лягл, 
   {{0x69c001c0,0x9f400240,0x17e00183,0xda7800df}},	//   _igoe, _pejë_, _মাৰি, _אנאר, 
   {{0xd7ec0640,0xb77400e5,0x00000000,0x00000000}},	//   _ћу_, ائیڈ, --, --, 
   {{0x69c04d11,0x68e00810,0x45d4405c,0x3744074d}},	//   _kgoe, _hwod, _койс, _кĕрт, 
   {{0x359402e3,0x6728143a,0x81e40154,0x00000000}},	//   ọbụ_, _isfj, _নাহ_, --, 
   {{0xd250004b,0xc1b801c0,0xa5b80332,0x00000000}},	// [16bf0] ښنې_, тлах_, adór, --, 
   {{0x68e007a8,0xa498642b,0x00000000,0x00000000}},	//   _mwod, atòr, --, --, 
   {{0x69c00428,0x1fa4feac,0xa4987704,0xd130004b}},	//   _ogoe, ураг, tròf, يمې_, 
   {{0xa4989022,0x0204e77b,0xcf9815ed,0x69c00226}},	//   ctòr, _өзүн, ују_, _ngoe, 
   {{0x68e00198,0x7ae00042,0x00000000,0x00000000}},	//   _nwod, _swlt, --, --, 
   {{0x69c0fead,0xed54feae,0x21280b70,0xc0c400f1}},	//   _agoe, рош_, _isch_, _مېړه_, 
   {{0x68e0ef21,0x6e20feaf,0x443000de,0x26c80115}},	//   _awod, beob, idz_, ŭboj_, 
   {{0x68e002e2,0x9f400100,0xe9d40354,0x5a4000d1}},	//   _bwod, _rejè_, акъ_, смиғ, 
   {{0x28e4010b,0xcfe803d4,0xf8640120,0x603800ef}},	//   адып_, _পাতন, ивио, _tāmē, 
   {{0x69c00323,0x68e0013f,0x81cc0183,0x4430033f}},	//   _egoe, _dwod, ৰণি_, jdz_, 
   {{0x36681bf6,0x3eac03a2,0x68e08a1e,0x66e0000d}},	//   вано_, _khet_, _ewod, _कौआक_, 
   {{0x443000da,0xb82400cc,0xf9780798,0x393400c0}},	//   edz_, বাইত_, _ибеј_, _вэкс, 
   {{0x9f4000eb,0x81cc0183,0x64e46518,0x00000000}},	//   _dejé_, ৰণা_, ағың_, --, 
   {{0x6e200210,0x00000000,0x00000000,0x00000000}},	//   zeob, --, --, --, 
   {{0xf668feb0,0x2128feb1,0x845802e8,0xa3e400f3}},	//   _لحظه_, _asch_, урят_, рдса_, 
   {{0xc0d41ee0,0xb2240261,0xe69042b5,0x56f00137}},	//   ርጊስ_, јмал, _ولود, _күүс, 
  
   {{0xa5b80005,0x81e4009e,0xa498180f,0xf0a41574}},	// [16c00] león, _নাশ_, rtòr, _ñàkk_, 
   {{0xa4980372,0x5908031c,0xa0640124,0xc05800d4}},	//   stòr, _ཁྱབས_, аауа_, ліє_, 
   {{0x2128feb2,0x78a00076,0x1ec40408,0xf2a40395}},	//   _esch_, illv, алхи_, _винп, 
   {{0xed58729a,0x3eacfeb3,0xa49800db,0x00000000}},	//   кое_, _chet_, tròg, --, 
   {{0x6e2079d7,0xa5b800d8,0x3eac0200,0xe8040f90}},	//   reob, ndóp, _dhet_, _शाला_, 
   {{0x5c7000d6,0x705004d3,0x68e0cf1a,0x80240327}},	//   оліт, _گۆڕا, _rwod, _ཤིརྵ_, 
   {{0xaa64beeb,0x5ba400d1,0xbbe87286,0x2b44009d}},	//   итик, һкәм_, ارهم_, рэлг, 
   {{0x68e00d29,0x70500133,0x3eac0208,0xad24dd55}},	//   _pwod, _دۆڕا, _ghet_, _پررو, 
   {{0x95ec0154,0xd9400114,0x00000000,0x00000000}},	//   কলাম_, жењи, --, --, 
   {{0xe8040490,0xdd8c6c6e,0xacb0129d,0x5834010a}},	//   _शाळा_, _غول_, _بەتب, азья_, 
   {{0xe7842a24,0x443001f5,0x3eac01f4,0xf1c4feb4}},	//   рупо, vdz_, _yhet_, लखान, 
   {{0x68e00334,0xaab803e6,0x69c001c7,0x4430012d}},	//   _twod, _شدار_, _ugoe, wdz_, 
   {{0x2a64089c,0x81e4009e,0x25700116,0x68e0c0cb}},	//   _ilob_, _নাল_, юқис, _uwod, 
   {{0x2a640457,0x41840032,0x21280175,0x00000000}},	//   _hlob_, ҡтағ, _rsch_, --, 
   {{0x4df8038e,0x4430feb5,0x00000000,0x00000000}},	//   ुलाई_, rdz_, --, --, 
   {{0xd7b80302,0xa498067c,0x37a80212,0xf8ac1bf4}},	//   _בצור, rtòq, _стін_, _يکی_, 
   {{0x21a40724,0x3eac003a,0x17200327,0x00000000}},	// [16c10] рәнү_, _rhet_, _འགོམ_, --, 
   {{0x3eacfeb6,0xa440105d,0x46140244,0x00000000}},	//   _shet_, _بێسو, _ئوکر, --, 
   {{0x3eacfeb7,0x741400f1,0x656c002f,0x0b0800eb}},	//   _phet_, _اوپا, lzch, লবুল_, 
   {{0xf2d00302,0x212807de,0xa3d0feb8,0x656c04cc}},	//   _מעט_, _tsch_, हुर_, ozch, 
   {{0x5184feb9,0x656c0c86,0x21280267,0xedd80131}},	//   _дура, nzch, _usch_, улчә_, 
   {{0x315400d9,0x00000000,0x00000000,0x00000000}},	//   _הישן_, --, --, --, 
   {{0xd54401e1,0x3eac045a,0x00000000,0x00000000}},	//   _kẹ́r, _thet_, --, --, 
   {{0xd54401e1,0x98ac0356,0xf1d800cd,0x00000000}},	//   _jẹ́r, _orgă_, युपन, --, 
   {{0x9f4003cd,0xd5440241,0x00000000,0x00000000}},	//   _adjø_, _mẹ́r, --, --, 
   {{0x2a6401fa,0x35f804fb,0x786411f4,0xd5440241}},	//   _elob_, گردد_, скоз, _lẹ́r, 
   {{0xcc34211f,0xa3e8012d,0xe798013a,0x00000000}},	//   _برقع, मरन_, _pěší, --, 
   {{0x2a64feba,0x6b7800c8,0xabb40022,0x64a0010b}},	//   _glob_, _גרענ, _уахә, җаса, 
   {{0x055410d9,0xa5b80077,0x81e400cc,0x98c4239a}},	//   отря, udóp, _নাং_, _тсел, 
   {{0xa3d049fc,0x43f80b32,0xa498004e,0x00000000}},	//   हुल_, ихся_, eròb, --, 
   {{0xe798012c,0x487404fb,0xa5b804d4,0x4e0800bc}},	//   _těší, _بدنس, leól, _हालै_, 
   {{0x6d5408fb,0x00000000,0x00000000,0x00000000}},	//   øyak, --, --, --, 
   {{0x6140febb,0x00000000,0x00000000,0x00000000}},	// [16c20] пета, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd5440241,0x765400b5,0xc1c80014,0x2878010f}},	//   _fẹ́r, _koyy, ابہٕ_, ננעמ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7654022f,0xde080131,0x4cd80183,0x00000000}},	//   _moyy, ارمۇ_, _সিহঁ, --, 
   {{0x2a645880,0x9f40110e,0x0b800023,0x25180677}},	//   _slob_, _kejì_, _ክቕየር_, רוסא, 
   {{0x2a6401d4,0xa0640124,0x00000000,0x00000000}},	//   _plob_, _уара_, --, --, 
   {{0x76540de2,0x9f400241,0x1e8000f3,0x00000000}},	//   _noyy, _mejì_, _елсм, --, 
   {{0x6d448c2c,0x9c8009a8,0xa3d073ca,0x92e4009e}},	//   _škaf, _ščet, हुँ_, _নমো_, 
   {{0x47a401ec,0x00000000,0x00000000,0x00000000}},	//   жымұ, --, --, --, 
   {{0xa09825f9,0xab9400c6,0xf7400022,0x00000000}},	//   רייט, _الضغ, ҧҵәо, --, 
   {{0xe1fc01e1,0x59080135,0x06c805f5,0xe784036b}},	//   _alón_, _ཁྱམས_, лгүй_, _қуло, 
   {{0x32cc010b,0x9644009d,0xa95806c2,0x84700240}},	//   _aýy_, чээд, _حجار_, _ኣእማን_, 
   {{0x81e4febc,0x92d403f4,0x656c068f,0xa3d02d3b}},	//   _নাই_, _হয়ে_, rzch, हुं_, 
   {{0x7654427c,0x201c010f,0x6d4401a8,0xa4980ba1}},	//   _foyy, _ĝui_, _ákaf, tròb, 
   {{0xe5c431de,0x76540209,0xd258005b,0x96f4009f}},	//   _уско, _goyy, бцу_, _اعور_, 
   {{0xc0d415c9,0x807800db,0xf1580022,0x10d8007b}},	// [16c30] زياب, абас_, аптә_, مبلغ_, 
   {{0x1b1c015b,0xd4d8007b,0x00000000,0x00000000}},	//   ভিতে_, _ابيض_, --, --, 
   {{0x6454035a,0xa3d000dc,0xa28000e5,0x00000000}},	//   _ioxi, हुः_, _فیسو, --, 
   {{0x645418f7,0x76540548,0x8e380133,0xd1c8014b}},	//   _hoxi, _xoyy, یسۆر_, _гурд_, 
   {{0x64545693,0xfbc4febd,0x1ee401d5,0xa17c030d}},	//   _koxi, обло, _گوزی_, _чунĕ_, 
   {{0x6454005a,0xda94febe,0xbb44010b,0x5c042bb6}},	//   _joxi, әскә_, жекк, сяда, 
   {{0x6454febf,0xf07829db,0x9f400241,0x1ee40214}},	//   _moxi, _тирә_, _kejí_, _دوزی_, 
   {{0x9f400316,0x6454fec0,0xff2801b9,0x00000000}},	//   _její_, _loxi, _йўғи_, --, 
   {{0x7654003e,0x7e68fec1,0xdc2405d1,0xc94402dd}},	//   _royy, _ilep, _göğs, здық, 
   {{0x7e68fec2,0x6454fec3,0x7654010b,0x00000000}},	//   _hlep, _noxi, _soyy, --, 
   {{0xf6242e82,0xdb1c049b,0x81c0015b,0x05180183}},	//   одно, äväs, ুরি_, ধটোৰ_, 
   {{0xa3bcfec4,0x7654020b,0x65680327,0x9f40013a}},	//   ेशन_, _qoyy, _żgha, _nejí_, 
   {{0x6454fec5,0x7e68020c,0xe86c0023,0x81c000fe}},	//   _boxi, _mlep, _ብሙሉኡ_, ুৰত_, 
   {{0x6454fec6,0x81c0015b,0x7654fec7,0x7e6800cf}},	//   _coxi, ুরা_, _woyy, _llep, 
   {{0x7e68fec8,0x6454fec9,0x64a0013e,0x7654feca}},	//   _olep, _doxi, фара, _toyy, 
   {{0xa49835f5,0x7e6801e1,0x52b40456,0x00000000}},	//   nuòj, _nlep, ंगेस, --, 
   {{0x394cfecb,0x78f8010f,0x26c800d7,0x00000000}},	// [16c40] nxes_, יפּו, íbov_, --, 
   {{0x7e68fecc,0x394c00f7,0xa3e86d65,0xa3d005f9}},	//   _alep, ixes_, मरण_, हुआ_, 
   {{0x8fd40184,0x00000000,0x00000000,0x00000000}},	//   жәғә, --, --, --, 
   {{0x64540472,0x741405d9,0xa4980ba1,0x6fd8230e}},	//   _zoxi, _اوھا, pròc, _प्रू, 
   {{0x7e6800d2,0x64540472,0xdcac0b38,0xe29401af}},	//   _dlep, _yoxi, چىن_, _фая_, 
   {{0xdcacafa0,0x6538008f,0x64542cdd,0x00000000}},	//   نىن_, יענד, _xoxi, --, 
   {{0x7e6807de,0xa2ac0073,0x00000000,0x00000000}},	//   _flep, ंगच्, --, --, 
   {{0x7e680214,0x1fa402bf,0xed5800f3,0x48c40166}},	//   _glep, _єкти_, _коб_, пәка, 
   {{0xc7b801fa,0x5ecc0154,0xde7401d3,0x00000000}},	//   međi_, হীদে, _بینڈ_, --, 
   {{0x7e680232,0x25e029d9,0xe1fc01d3,0x3ad40171}},	//   _zlep, पर्ण, _alól_, _sāpe_, 
   {{0x6454fecd,0xd87000f7,0x2a3405f5,0x394c056a}},	//   _roxi, بايب, _мэдр, axes_, 
   {{0x64541617,0x81c003d4,0x00000000,0x00000000}},	//   _soxi, ুৰি_, --, --, 
   {{0xa25800d8,0x00000000,0x00000000,0x00000000}},	//   _biôn, --, --, --, 
   {{0xf48000b7,0x6fd815c0,0x00000000,0x00000000}},	//   _ከቅርብ_, _प्लू, --, --, 
   {{0x53340ad6,0x6454022e,0x81c003d4,0x00d40150}},	//   мерт, _voxi, ুৰা_, _ﺘﻨﺘﻘ, 
   {{0x44f4fece,0x26dcfecf,0xc7b801a6,0x00000000}},	//   _епис, mpto_, jeđi_, --, 
   {{0x81600133,0x6618000d,0x61d8000d,0x00000000}},	// [16c50] رۆسۆ, õuku, _बभीष, --, 
   {{0x7e68fed0,0x1fa4bef7,0xa258004d,0xdfd801d5}},	//   _slep, орег, _giôn, ръа_, 
   {{0x7e68fed1,0xd2509105,0x7eb00fac,0x6d5402d1}},	//   _plep, رنے_, håpe, äyan, 
   {{0x7eb00250,0xe1fc032e,0x26dc0064,0x00000000}},	//   kåpe, _klóm_, ipto_, --, 
   {{0xa5b801d3,0x2004067c,0xfce400cf,0x9474029e}},	//   deók, ònis_, чоло, _ردیا, 
   {{0xfbd0fed2,0x7eb003cd,0x06e000fe,0xf1a800f1}},	//   رتت_, dåpe, _ভিনি, _داپه_, 
   {{0x7e68fed3,0xa3d00037,0x93fc0677,0x27380171}},	//   _tlep, हुए_, בלוי, _nīn_, 
   {{0x394c00f7,0x98ac05ce,0x67780023,0x7e68fed4}},	//   txes_, đače_, _ኣሕዋቱ_, _ulep, 
   {{0xe8043174,0xa3e844ab,0x527c0a1e,0xccec0150}},	//   _शाखा_, मरा_, ינהא, _шқ_, 
   {{0x394cfed5,0xcc880051,0x3ea40244,0xc8b401e2}},	//   rxes_, lớn_, _بێڵێ_, وليک, 
   {{0x786c2833,0xf744fed6,0x0c040050,0x628c012d}},	//   _núve, чено, _زونُ, _ojco, 
   {{0xeaac02bf,0x2738fed7,0xe1fc01a8,0x088800db}},	//   _їй_, _dīn_, _blóm_, йбөй_, 
   {{0xe79800bc,0x00000000,0x00000000,0x00000000}},	//   _měří, --, --, --, 
   {{0x53980092,0x52b40412,0xf86800ae,0x00000000}},	//   _መቆየት_, ंग्स, _دمتي_, --, 
   {{0x69d00490,0x033802bf,0x77a401d9,0x00000000}},	//   णुकी, оїть_, _ڈێکہ_, --, 
   {{0x7c3c0134,0xf5e80276,0x068c06ba,0xcfe41100}},	//   _ɔsra, _умил_, ﻗﺎﻟﯩ, गर्भ_, 
   {{0xe7f000e1,0xf0b84028,0xc7b801a6,0xf064004e}},	// [16c60] _आजमा_, مائش_, veđi_, пкап, 
   {{0xd3e4fed8,0x28cc0d2e,0xb9dc0092,0x00000000}},	//   _تقدی, _हंसि, _ጥግ_, --, 
   {{0xef18fed9,0x5f0001ec,0x261009ab,0x00000000}},	//   сме_, езха, _थामी_, --, 
   {{0x9f40180f,0x8ca4033f,0x7054114f,0x00000000}},	//   _dejà_, _चीजो, _کنسا, --, 
   {{0x6d44107d,0xa3d04709,0x00000000,0x00000000}},	//   _škab, हुक_, --, --, 
   {{0x26dcfeda,0x7eb0168c,0xa49801ab,0xcb9400f2}},	//   ypto_, våpe, hròn, وهشک, 
   {{0x20040419,0x00000000,0x00000000,0x00000000}},	//   ónie_, --, --, --, 
   {{0xdb0c0008,0x00000000,0x00000000,0x00000000}},	//   _ódýr, --, --, --, 
   {{0x99d045ff,0xa4980109,0x68000248,0x00000000}},	//   رتيا, dròn, _níjà, --, 
   {{0x98701de1,0x3958369a,0x7eb033b8,0x7d1c0254}},	//   ельц, ässa_, råpe, _ässa, 
   {{0xda6c0491,0xd1d00020,0x9f4001e1,0x7eb003cd}},	//   _зя_, ሥራት_, _kejá_, såpe, 
   {{0x4268001f,0x00000000,0x00000000,0x00000000}},	//   ተኝነት_, --, --, --, 
   {{0x6aa001b3,0x2fc8020c,0x786cfedb,0xd940fedc}},	//   _ikof, _ogbg_, _súve, _пеци, 
   {{0xfd6401e1,0x3ad400b0,0xa5b80332,0x19b800d9}},	//   _aisọ, _hāpa_, neói, _המדב, 
   {{0x55ec03d4,0x3ad40171,0x6744009d,0x00000000}},	//   _কাৰক_, _kāpa_, _хэлз, --, 
   {{0xe5c4fedd,0xa49800db,0xd2580114,0x21380208}},	//   _эско, cròn, пцу_, tvqh_, 
   {{0x51840064,0x00000000,0x00000000,0x00000000}},	// [16c70] нуфа, --, --, --, 
   {{0x26cc01e4,0xe1fc0162,0x3ad40a88,0xcfe800eb}},	//   _kufo_, _klók_, _lāpa_, _পাউন, 
   {{0x06e02f8b,0x6aa00085,0x442003d5,0x26cc0067}},	//   _ভিডি, _okof, _ibh_, _jufo_, 
   {{0x44200c6a,0x26cc0134,0x6aa00161,0x8d7401ed}},	//   _hbh_, _mufo_, _nkof, کاما, 
   {{0xc7b81326,0x4420fede,0x9f400789,0xe79800bc}},	//   među_, _kbh_, _dejá_, _věří, 
   {{0x6aa0abab,0x629c036b,0x81e400fe,0x61ec00a3}},	//   _akof, loqo, _নাট_, _hecl, 
   {{0x60cc0784,0xe0dc00a3,0x61ec0c6a,0xdcac1e87}},	//   _hucm, _bròg_, _kecl, نىچ_, 
   {{0x61ecfedf,0x44202c3e,0x60c4fee0,0x3eb8067c}},	//   _jecl, _lbh_, _hijm, _òst_, 
   {{0x44205c7f,0xe0dc02e2,0x61ec03ee,0x5bc4007b}},	//   _obh_, _dròg_, _mecl, _فتاف, 
   {{0x61ec6320,0x6aa0fee1,0xdd900046,0x26ccfee2}},	//   _lecl, _ekof, _жағы, _bufo_, 
   {{0xdb68fee3,0x629cfee4,0x6aa01132,0x60cc07de}},	//   _урал_, koqo, _fkof, _lucm, 
   {{0x60c4fee5,0x61ecfee6,0xc7b81710,0xe9ccef93}},	//   _lijm, _necl, jeđu_, _јк_, 
   {{0x4420090d,0x629c02d3,0xe57402d5,0x26c80306}},	//   _bbh_, doqo, дзя_, íbor_, 
   {{0x4420070d,0x60c4fee7,0x61ec0393,0x27ec0368}},	//   _cbh_, _nijm, _aecl, _gefn_, 
   {{0x26ccfee8,0x442001c6,0x61ec7925,0x00000000}},	//   _gufo_, _dbh_, _becl, --, 
   {{0x60cc01a6,0x629c0fec,0x7c200175,0x00000000}},	//   _bucm, goqo, _lblr, --, 
   {{0x4420020b,0x60c4014f,0x261000c5,0x00000000}},	// [16c80] _fbh_, _bijm, _थाती_, --, 
   {{0x60c40399,0x26cc03f9,0xb46400c7,0x60cc0208}},	//   _cijm, _yufo_, _цкол, _ducm, 
   {{0xee38fee9,0x61ec05d5,0xa4980ba1,0x60c4feea}},	//   жне_, _fecl, iròl, _dijm, 
   {{0x61ec1543,0xc1d405a2,0x00000000,0x00000000}},	//   _gecl, _зөфә, --, --, 
   {{0x81e402a6,0x44200882,0xddd800f3,0xb14401d5}},	//   _নাচ_, _ybh_, _fjuž, _ўнгл, 
   {{0x6aa0feeb,0x60c40097,0x61ec0472,0xddd801ef}},	//   _skof, _gijm, _zecl, _louň, 
   {{0x61ec009a,0xa498004e,0xa5b80798,0x27ec01bf}},	//   _yecl, dròl, reói, _refn_, 
   {{0x26ccfeec,0x6d540158,0xe61c0165,0xa5b80332}},	//   _rufo_, øyas, rnôk_, seói, 
   {{0x7f280014,0xdcac075e,0xad640066,0x00000000}},	//   _وسہِ_, _چىق_, _غاره, --, 
   {{0x629c4242,0xe78400d3,0xab28030d,0x91b000cc}},	//   zoqo, думо, _моза_, _কলাখ, 
   {{0x629c0117,0x442001bf,0xeaf8da67,0x3ad400b8}},	//   yoqo, _rbh_, _ذرات_, _tāpa_, 
   {{0x6aa0014b,0x2364010e,0x00000000,0x00000000}},	//   _ukof, _ünji_, --, --, 
   {{0x95c812c1,0x44200208,0x629c022e,0x7afc00b8}},	//   дура_, _pbh_, voqo, _āsti, 
   {{0x61ecfeed,0x26ccfeee,0xb7d800e5,0x00000000}},	//   _secl, _tufo_, _ٹوٹا_, --, 
   {{0xb8646640,0x60c40d27,0x61ecfeef,0x5b78010f}},	//   _ثانو, _rijm, _pecl, ַרמא, 
   {{0xe5c498cc,0x442005b1,0x96f80375,0x2480037e}},	//   _оспо, _wbh_, _ולהת, sijm_, 
   {{0x44200e89,0x629c0481,0x60c49851,0xdbc80248}},	// [16c90] _tbh_, roqo, _pijm, _mòòk, 
   {{0x629cfef0,0x786c2959,0x61ec014b,0x60c4014f}},	//   soqo, _kúva, _wecl, _qijm, 
   {{0x61ecfef1,0x1fa45b0f,0x91c00cb4,0x60c40240}},	//   _tecl, фраг, लेबै, _vijm, 
   {{0x5fdc243c,0x3d9408bf,0xd13001ed,0x629c00aa}},	//   _प्रल, ниер, دمے_, qoqo, 
   {{0x3228025c,0x60c4014f,0x167800df,0x00000000}},	//   _སྒྲར_, _tijm, וגאל_, --, 
   {{0x8fc4185e,0xa3d002e5,0x786c0124,0x7d180142}},	//   رزەن, हुच_, _oúva, rtws, 
   {{0xbacc040d,0xfaa44294,0x6bd426c0,0xdbc80248}},	//   _ﻗﺎﺗﺎ, нако, رويس_, _sòók, 
   {{0xa4981f40,0x5a400116,0x00000000,0x00000000}},	//   dròm, тмиғ, --, --, 
   {{0xa498068c,0xf86400d4,0x7b9800e5,0x00000000}},	//   tròl, евпо, _کپاس_, --, 
   {{0x8d740228,0x786c02d2,0x6d8801d3,0x00000000}},	//   _شاقا, _búva, _عملہ_, --, 
   {{0x44ecfef2,0x3cec0165,0xd1d0001f,0xe1fc0ca8}},	//   ež_, _hwev_, ሥራቅ_, _odó_, 
   {{0x7e78029f,0x786c03b2,0xb9040154,0x00000000}},	//   _çapı, _dúva, _ফি_, --, 
   {{0xe1fc02d2,0xe0dc0241,0x6c740051,0xaa541291}},	//   _glói_, _ntò_, _hànộ, _سلوا_, 
   {{0xe1fc5f48,0xd88001b9,0x3a2cfef3,0xa854008e}},	//   _adó_, _جهتی, leep_, _печә, 
   {{0xe0dc5eb0,0x3cec009a,0xa49835f5,0x161801ad}},	//   _atò_, _lwev_, cròm, _थापर_, 
   {{0x668001b9,0x3ad4f4b4,0x47580212,0xf5e8001b}},	//   _میپل, _lāpo_, _юрія_, _эмил_, 
   {{0xf1a81d0a,0xbacc02dd,0x00000000,0x00000000}},	// [16ca0] ساره_, _ﻗﺎﺑﺎ, --, --, 
   {{0x72d00131,0xfe0c012d,0x3a2c037e,0x999c031c}},	//   _مەسچ, _हाउस_, heep_, djuż_, 
   {{0xb4bc38bf,0x3a2c34b6,0xe0dc01e1,0x09ac2bf1}},	//   ेदी_, keep_, _etò_, _चर्य, 
   {{0x78a001f5,0x923400db,0x999c0327,0x2dd40014}},	//   holv, _جۉرش, fjuż_, رُتھ_, 
   {{0x3a2c00b5,0xefe80020,0x78a01de4,0x999c031c}},	//   deep_, ቅላይ_, kolv, gjuż_, 
   {{0x3ad40055,0x321000b5,0x9e540166,0x06e00154}},	//   _cāpo_, lgyy_, дрәф_, _ভিসি, 
   {{0x7eb0007c,0xec1400d1,0xae7800c0,0x7c640116}},	//   såpa, _ۋورد, _есах_, خانل, 
   {{0xa5b800d8,0x7eb0003b,0xdee00063,0x4d8400fb}},	//   nfóc, låpn, _љоти, _иҫег, 
   {{0x1d042826,0xec781575,0x786c0419,0x00000000}},	//   _пети_, _епа_, _súva, --, 
   {{0x78a0fef4,0xe870193a,0x7eb0003b,0x44ec0219}},	//   golv, اندگ, nåpn, vž_, 
   {{0xdbc801e1,0xaae4007b,0xbae4003b,0x00000000}},	//   _tòòk, _أسطو, _ацій, --, 
   {{0xeab80184,0x08f400cc,0xab28014b,0x00000000}},	//   _эйе_, _আমঠু_, _моҷа_, --, 
   {{0xb110015b,0x43ac0131,0xcc880051,0x00000000}},	//   হবুব_, ﺳﺘﯩﺪ, vớj_, --, 
   {{0x786c00c7,0x98b400d4,0xa5b800e5,0xf9880066}},	//   _túva, _зліт_, deót, _تخمه_, 
   {{0xe0dcfef5,0x2c0c033f,0xe4e8104c,0x00c802dd}},	//   _stò_, _साईं_, _کعبه_, _ﺒﺎﺨﺘ, 
   {{0x7580030f,0x925801f0,0x409400d1,0x00000000}},	//   اییم, наст_, ھلار, --, 
   {{0x6d4454b0,0x4094620a,0x61480092,0x44b4011c}},	// [16cb0] _škan, پلار, _መያያዣ, _ибис, 
   {{0x249411c7,0x3a2c01f5,0x9f500129,0x00000000}},	//   _سمجھ_, zeep_, laxé_, --, 
   {{0x3f1402e8,0x3df401d5,0x3ad400ef,0x00000000}},	//   тдес, взес, _rāpo_, --, 
   {{0x78a0fef6,0xe0dc0561,0x3cec007f,0xf1c40419}},	//   zolv, _cròc_, _pwev_, _čávo_, 
   {{0xa1846733,0x3ad4002b,0x00000000,0x00000000}},	//   _чынл, _pāpo_, --, --, 
   {{0x3a2c0ea0,0x26e400cc,0x999c025c,0xcf2400db}},	//   weep_, _কিনো_, rjuż_, ئرەي, 
   {{0xeb94fef7,0x3a2c003e,0x9f4001e3,0xcfe800cc}},	//   киш_, teep_, _adjö_, _পাচন, 
   {{0x0b8800c6,0x78a0045a,0x06d400d1,0xa5b80332}},	//   عضوي_, wolv, ﻘﻪﺗﻪ, neós, 
   {{0x3a2cfef8,0xad1429db,0xe1fc03b2,0x3ad40055}},	//   reep_, _иптә, _flóv_, _tāpo_, 
   {{0x2010e044,0xf770fef9,0x78640063,0x3a2c2301}},	//   ngxi_, لاج_, ткоз, seep_, 
   {{0x25c403be,0xbb54006c,0x37740026,0x78a0ce26}},	//   ətlə_, _جناب, тыпс, rolv, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x78a0fefa,0x261000e1,0xdebc0b82,0x00000000}},	//   polv, _थारी_, ትምና_, --, 
   {{0x3d08b4a8,0xa3bc00dc,0x7ae006be,0x7eb0007c}},	//   _सिने_, ेशं_, _ktlt, kåpo, 
   {{0x63800953,0x786c00e4,0x00000000,0x00000000}},	//   агра, _húvo, --, --, 
   {{0x200408a7,0xddd801e4,0xd7840014,0xb6a40354}},	//   ónin_, _pluŝ, _ٲچھو_, _шийл, 
   {{0x7ae000c6,0x7eb00fac,0x514401ec,0x75340153}},	// [16cc0] _ltlt, tåpn, ыдағ, _рэйх, 
   {{0xdef002d3,0xa5b80798,0x00000000,0x00000000}},	//   _ግሪኽ_, reót, --, --, 
   {{0xa3bc0882,0xdfccfefb,0x7eb033b8,0x409400cf}},	//   ेशः_, زين_, råpn, уртт, 
   {{0xcc8801fb,0x786c00e4,0xa3b400c5,0x7eb0003b}},	//   mới_, _oúvo, _जरत_, såpn, 
   {{0xdd8c0491,0x786c00f7,0x7eb00fac,0x00000000}},	//   يوم_, _núvo, påpn, --, 
   {{0xeb480108,0x3ce800e4,0x3084010a,0x00000000}},	//   дчик_, ãava_, _шăлс, --, 
   {{0x26101e61,0x9fc41a6d,0x00000000,0x00000000}},	//   _थाली_, _агра_, --, --, 
   {{0xddd80356,0x89383dc8,0x3ad400de,0x00000000}},	//   _iluş, епис_, _kāpj_, --, 
   {{0x6da40022,0xac940124,0x00000000,0x00000000}},	//   _риаа, _ҟаҧш, --, --, 
   {{0x4734fefc,0x290004a7,0x6e2000e4,0xb4bc00cd}},	//   гнос, škao_, lfob, ेदो_, 
   {{0x6d400109,0x2b1400c7,0xa2b001f9,0x98a00798}},	//   lvoa, _шьар, _आठल्, риќе, 
   {{0xe66400f7,0x2988fefd,0x26100490,0xdb0400d8}},	//   ттоо, _осло_, _थाळी_, _àmáq, 
   {{0xe61c00d0,0x6d40fefe,0x15a802e8,0x66dc0171}},	//   dnôt_, nvoa, въри_, _sīkd, 
   {{0xddd80ab7,0xd40407d6,0x68e005da,0xd7ec0f14}},	//   _oluş, ияси, _itod, _њу_, 
   {{0x47c000bd,0x6d440010,0x800801d3,0xd6cc0395}},	//   _শ্রী, _škal, ہراہ_, _ът_, 
   {{0x9754010f,0xc31400eb,0xf4e000cc,0x00000000}},	//   _ייוו_, াবলি_, _বিৰব, --, 
   {{0x03c4015b,0xddd80166,0xfba8000d,0x6ef0002b}},	// [16cd0] ্রেণ, _aluş, _चुनम, _ātiṣ, 
   {{0x3ff40220,0x200c0024,0xf40800eb,0x00000000}},	//   اكار, ėgio_, শ্বর_, --, 
   {{0xd378084c,0x6b980175,0xe1fc02d2,0x6e20015d}},	//   _ачя_, _nxtg, _blót_, ffob, 
   {{0x4430feff,0x38b8004a,0x68e0ff00,0x5344030d}},	//   lez_, mère_, _otod, _тхьа, 
   {{0x68e00943,0x38b8ff01,0x9258ff02,0x4430005a}},	//   _ntod, lère_, _раят_, oez_, 
   {{0x4430ff03,0xa3b43af7,0x4fc400db,0x040400eb}},	//   nez_, _जरा_, _چەكە, শ্রী_, 
   {{0x4fc4ff04,0x6d4000a8,0x68e0ff05,0x38b8004a}},	//   _вста, avoa, _atod, nère_, 
   {{0x4430ff06,0x212801e4,0x38b80129,0x6d5001e7}},	//   hez_, _kpch_, ière_, ódaí, 
   {{0x4430ff07,0x38b859c6,0x81d403d4,0x3b540139}},	//   kez_, hère_, _সজা_, _әкер, 
   {{0x44308f78,0x68e001e7,0xdcf8013d,0x00000000}},	//   jez_, _dtod, _uzuı, --, 
   {{0x4430ff08,0x36c49bb1,0x68e001fa,0xf7705214}},	//   dez_, лбог, _etod, صاد_, 
   {{0x38b8ff09,0xb4bc0882,0x44300489,0xcc880051}},	//   dère_, ेद्_, eez_, với_, 
   {{0x4430ff0a,0x69d800c8,0xa6803334,0x66dc02b5}},	//   fez_, _אַוו, сляд, _rīke, 
   {{0x4430ff0b,0x38b8ff09,0xe1fc0241,0x9f406abf}},	//   gez_, fère_, _olós_, _dejú_, 
   {{0x38b8ff0c,0x2324013e,0x00000000,0x00000000}},	//   gère_, лори_, --, --, 
   {{0x20003743,0x6d442230,0x81bc03d4,0x00000000}},	//   _adji_, _škam, ইখন_, --, 
   {{0xe294ff0d,0x44300598,0xe1fc004e,0x7eb00b1a}},	// [16ce0] уат_, bez_, _alós_, råpl, 
   {{0x4430ff0e,0x38b8503f,0x20000427,0x6d400158}},	//   cez_, bère_, _cdji_, vvoa, 
   {{0xa5b8ff0f,0xa80400e4,0x6e20003c,0x66dc02b1}},	//   nfón, _heñò, tfob, _tīke, 
   {{0x37c40154,0x00000000,0x00000000,0x00000000}},	//   _এভার, --, --, --, 
   {{0xdee0136b,0x953802d3,0xc15401ee,0xdd8000db}},	//   _ҳоси, _እዚኣተ, _књрњ, йышп, 
   {{0x200001fa,0xdca000d6,0xa498026c,0x6d4403b2}},	//   _gdji_, бачи, tròi, _ákam, 
   {{0x68e0ff10,0x6e200230,0x33380175,0xdee001f4}},	//   _stod, pfob, _jspx_, _госи, 
   {{0x4430ff11,0x33380334,0xbb5003e6,0xcdc40116}},	//   zez_, _mspx_, تۆمب, _кәлп, 
   {{0x4430ff12,0x38b8004a,0xebe4013e,0xdd8c00e5}},	//   yez_, zère_, _бозп, _ٹول_, 
   {{0x4430ff13,0x38b84056,0x00000000,0x00000000}},	//   xez_, yère_, --, --, 
   {{0x4430ff14,0x9ad0063f,0x597001b9,0x00000000}},	//   vez_, sịru, لدیز, --, 
   {{0x1ef800c8,0x38b8276b,0x6a7c0270,0x4430ff15}},	//   עלכע, vère_, tūfu, wez_, 
   {{0x4430ff16,0x3338ff17,0xe0dc0428,0x9c80151c}},	//   tez_, _aspx_, _aròn_, _ščit, 
   {{0xddd80f8b,0x443003bd,0xe0dc08c2,0x38b8ff18}},	//   _mmuš, uez_, _bròn_, tère_, 
   {{0x4430bb87,0x05a40cb4,0x4e1400bc,0x00000000}},	//   rez_, _गुरब, डलाई_, --, 
   {{0x4430ff19,0xe61c0798,0x38b806af,0xe03001c0}},	//   sez_, rnôs_, rère_, өмбө, 
   {{0x4430097a,0x38b8ff1a,0xd54805d9,0xd3f400fe}},	// [16cf0] pez_, sère_, _مليو_, _জাৰি_, 
   {{0x38b8ff1b,0x3fc823cf,0x7d1c16ca,0x395801f4}},	//   père_, ندای_, _ässi, ässi_, 
   {{0x69dc013f,0x00000000,0x00000000,0x00000000}},	//   _ɑper, --, --, --, 
   {{0x4fc4049b,0x3cfc0218,0xf1a40107,0x00000000}},	//   ссуа, tswv_, урӣн, --, 
   {{0xa3bc6b9b,0xf28401c0,0x00000000,0x00000000}},	//   ेशक_, _төрд_, --, --, 
   {{0xac04ff1c,0x20000cf4,0xe1fc007b,0x3b080353}},	//   анша_, _udji_, _glór_, веко_, 
   {{0x3ad400b8,0x00000000,0x00000000,0x00000000}},	//   _kāpi_, --, --, --, 
   {{0xb90400c7,0xa9d000d1,0x00000000,0x00000000}},	//   азик, يقىغ, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x970000d1,0x8c4400f3,0x00000000,0x00000000}},	//   مېتى, _леђе, --, --, 
   {{0x3a3c05b1,0xd90c01ed,0x3a2800c7,0x9bb0009f}},	//   _tawp_, زیں_, _ñapo_, _الاڪ, 
   {{0xb6a468e0,0xa6dc0016,0x3ad400dc,0x1ae80154}},	//   римл, _trưn, _nāpi_, _টিপে_, 
   {{0xe9cc8cff,0xd8e410d9,0xe0dc01c3,0xca740228}},	//   _фк_, _сцеп, _sròn_, _دەيت_, 
   {{0xf74405c5,0x6d4404a7,0x441400a7,0x9f40005c}},	//   _веко, _škak, йфст, _fejø_, 
   {{0xd13c0020,0xe360562a,0x07d800c6,0xa56001d5}},	//   _ያላቸው, окри, _إذهب_, مگین, 
   {{0xe294152d,0x3ad40882,0x42d402dd,0x00000000}},	//   аас_, _cāpi_, сіру, --, 
   {{0x7084ff1d,0x1fe4015b,0xa5b8041e,0x25d400d9}},	// [16d00] агаз, _পয়স, nfól, _דופן_, 
   {{0x66dc0374,0xe0dcff1e,0xa4f802e4,0x1ae8009e}},	//   _hīka, _tròn_, _שליט, _টিনে_, 
   {{0xef1855e7,0x2f540132,0xef840640,0x66dc00b8}},	//   тме_, штас, јлеп, _kīka, 
   {{0xa258ff1f,0x4704002b,0xa5b83168,0xed44009b}},	//   _diôs, _amṛṣ, kfól, инеп, 
   {{0x66dc02b5,0x63b80198,0x00000000,0x00000000}},	//   _mīka, ƙunc, --, --, 
   {{0xa5b803f2,0xeb0400c7,0x66dc00ef,0x61400798}},	//   dfól, ачио, _līka, _ќера, 
   {{0xe45400c8,0xa498068c,0x3ad400b8,0x25c000cd}},	//   ייסט_, pròv, _yāpi_, _षण्ण, 
   {{0x66dc02b1,0x4a5400a8,0xddd800f3,0x6d5402d1}},	//   _nīka, скис, _tmuš, äyas, 
   {{0xacc800c7,0xa5b8041e,0xe1fc0208,0xda740395}},	//   _агаз_, gfól, _hoóc_, рящ_, 
   {{0xa3b40037,0x00000000,0x00000000,0x00000000}},	//   _जरल_, --, --, --, 
   {{0xda6c084c,0x3a7400f7,0x45d4ff20,0x00c802dd}},	//   _дя_, рлөр, йонс, _ﺒﺎﺴﺘ, 
   {{0x56942164,0xe1fc0051,0xe7f00118,0xa9a40150}},	//   жают, _moóc_, _आजका_, _киед, 
   {{0x953812e7,0x81d40154,0xe1f001d9,0x200400d7}},	//   азят_, _সজল_, ۪سس_, ónik_, 
   {{0xd498ff21,0xa784ff22,0xe0dc0100,0x3ad43db2}},	//   арс_, _پشتو, _dròl_, _sāpi_, 
   {{0xe28403b7,0x1368ff23,0x53440107,0x237c01e4}},	//   аѓан, ашти_, охта, ĝujo_, 
   {{0x38b8180f,0x00000000,0x00000000,0x00000000}},	//   mèra_, --, --, --, 
   {{0xc1b80323,0x38b8ff24,0xd258010b,0xdb840023}},	// [16d10] улах_, lèra_, шцр_, _ንዕድም_, 
   {{0xa5b80789,0xa498067c,0x9f68084c,0x00000000}},	//   nfóm, gròt, крез_, --, 
   {{0x3ad400b0,0x38b8068c,0x29000427,0xdef876b8}},	//   _tāpi_, nèra_, škah_, тыз_, 
   {{0x4254b1d7,0xb6d8008f,0x2ba8000d,0x00000000}},	//   _انحر, אַסט, _छड़ा, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4c840212,0xed540e92,0x1ca40133,0x00000000}},	//   олів, сош_, گێڕی_, --, 
   {{0x81b84251,0x6d540309,0xbb4800ec,0x00000000}},	//   _চলি_, äyar, البن_, --, 
   {{0x38b8180f,0xa5b8ff25,0x00000000,0x00000000}},	//   dèra_, tfól, --, --, 
   {{0x3eac8075,0x28e400db,0x9f8401ee,0x00000000}},	//   _iket_, бдып_, _саңҡ_, --, 
   {{0xa5b808a7,0x5ba4084c,0x786c20d2,0x38b8068c}},	//   rfól, _крез, _kúvi, fèra_, 
   {{0xa5b805a4,0x66dc0374,0x366832cf,0xe0dc01ab}},	//   sfól, _pīka, гано_, _sròl_, 
   {{0xa6802bb7,0x00000000,0x00000000,0x00000000}},	//   злюд, --, --, --, 
   {{0xd7600214,0x5800022e,0x00000000,0x00000000}},	//   _ژنتی, _долғ, --, --, 
   {{0x38b80ba1,0xe29401e0,0xf7481867,0x81bc0154}},	//   bèra_, ҡар_, _ملتي_, ইখা_, 
   {{0x66dcff26,0x786cff27,0x38b8067c,0x00000000}},	//   _tīka, _núvi, cèra_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe1fc0208,0x2fd4007b,0x00000000,0x00000000}},	// [16d20] _soóc_, متاح, --, --, 
   {{0x2f54b19d,0x33f4170a,0xe574e91b,0x00000000}},	//   йтес, _учис, _ызы_, --, 
   {{0xdfcc495f,0xb8d82fb5,0x3eac0280,0xacc800fd}},	//   فيك_, _ཙེ_, _bket_, ңгез_, 
   {{0x29000953,0x786c0cfc,0x3eac05b1,0xe354011a}},	//   škai_, _dúvi, _cket_, _השטח_, 
   {{0x3eac020b,0x3ad402b5,0x2244013f,0xdb8001c0}},	//   _dket_, _māpu_, ɛnk_, үгчи, 
   {{0x3eacff28,0xdca0084c,0x6538008f,0x3d08033f}},	//   _eket_, пачи, טענד, _सिरे_, 
   {{0xbb5000b5,0xbc1802bf,0x6e44010a,0x2b44009d}},	//   _proで_, річі_, _левз, сэлг, 
   {{0x6e940491,0x497425a1,0x38b8068c,0x00000000}},	//   _الرا, жлис, vèra_, --, 
   {{0x2900ff29,0x6c1800c6,0xa8a4ff2a,0x00000000}},	//   éka_, _متاح_, йрок, --, 
   {{0x7c64ff2b,0x29086041,0x1b04015b,0x38b8068c}},	//   _والل, čba_, _শহরে_, tèra_, 
   {{0xe7840107,0x20040419,0x00000000,0x00000000}},	//   супо, ónii_, --, --, 
   {{0xe0dc01ab,0x38b80561,0x28b80073,0xe9d800f3}},	//   _sròm_, rèra_, _उठवि, _скд_, 
   {{0x9f4400c6,0x395803fa,0x1a40004b,0x38b8067c}},	//   únú_, ässt_, _رپوټ, sèra_, 
   {{0x2a6401d4,0xd9180a1e,0x38b8068c,0x7b0000fd}},	//   _hoob_, _עוול, pèra_, _äytä, 
   {{0x2a640457,0xdedc0023,0x00000000,0x00000000}},	//   _koob_, _ንብኡ_, --, --, 
   {{0x66dc04fe,0x2a64ff2c,0x5f0c0037,0x680001ef}},	//   _hīko, _joob_, _डिब्_, bíjí, 
   {{0x786c01a2,0x2a640211,0xe0dc01ab,0x81b00011}},	// [16d30] _súvi, _moob_, _tròm_, টেন_, 
   {{0x2a64ff2d,0x3eacff2e,0x46148ca8,0x20040af2}},	//   _loob_, _sket_, _اوکر, ûni_, 
   {{0x656cff2f,0x2738005f,0xfe7004fb,0xa3b81bf4}},	//   lych, _jūn_, وگر_, _حاظر_, 
   {{0x2a64ff30,0xc0e80092,0x00000000,0x00000000}},	//   _noob_, ቅማል_, --, --, 
   {{0x656c0368,0x61fcff31,0x51840220,0x38b8ff32}},	//   nych, maql, _еура, dèrn_, 
   {{0x1ef8b745,0x61fcff33,0x66dc00b0,0x656c003e}},	//   _معرة_, laql, _nīko, iych, 
   {{0x2a64074d,0x38b8067c,0x656c0042,0x66dc00ef}},	//   _boob_, fèrn_, hych, _sīkn, 
   {{0x20dc145e,0x2a640457,0x61fca090,0x1aac0154}},	//   _kîi_, _coob_, naql, _চূড়া, 
   {{0x7c5800aa,0x2a64058a,0x38581cb8,0x00000000}},	//   _پلار_, _doob_, арню_, --, 
   {{0x656cff34,0x06e0015b,0x61fcff35,0x00000000}},	//   dych, _ভিজি, haql, --, 
   {{0x2a640211,0x3f8003f9,0xfdfc000d,0x5fac19cc}},	//   _foob_, nzhu_, _उजास_, _जुमल, 
   {{0x2a6401d9,0xe7340212,0x61fc022e,0x00000000}},	//   _goob_, цею_, jaql, --, 
   {{0xe7f00073,0x61fcff36,0x656c0042,0x00000000}},	//   _आजचा_, daql, gych, --, 
   {{0x2738002d,0x3ad402b1,0x38b8068c,0x98c4ff37}},	//   _fūn_, _wāpu_, mèro_, _усел, 
   {{0x81b009bd,0x3244ff38,0x3ad402b5,0x2a6400e8}},	//   টেম_, оевг, _tāpu_, _yoob_, 
   {{0x2a6401d4,0x656c94f0,0x31e80228,0xf74805d9}},	//   _xoob_, bych, рмап_, _ملڪي_, 
   {{0x25dc1533,0xf064009b,0x5fac00e1,0x15b400d1}},	// [16d40] _गलती_, окап, _जुबल, _رەسس, 
   {{0x7644017a,0x00000000,0x00000000,0x00000000}},	//   ldky, --, --, --, 
   {{0xb5c80133,0x61fcff39,0x2878010f,0xb4b40b27}},	//   _حوکم_, baql, סנעמ, जती_, 
   {{0x61fc03be,0x87ac008f,0xa498004e,0x7644017a}},	//   caql, נשאַ, nsòn, ndky, 
   {{0x2a64ff3a,0x27fc0066,0x38b82508,0x7dec00c0}},	//   _roob_, yatn_, vèrn_, dėsč, 
   {{0x786c00d2,0x2a64ff3b,0x4094ff3c,0xf91c00cc}},	//   _kúvu, _soob_, _ерст, _বৈভৱ_, 
   {{0x9f40204e,0x66dc00da,0x27fc0a32,0x2a640457}},	//   _dejó_, _rīko, vatn_, _poob_, 
   {{0x2a640070,0x2738000f,0x27fc00d5,0xed346135}},	//   _qoob_, _rūn_, watn_, _мэзэ, 
   {{0x66dc02b5,0x6c0400c7,0x656c045a,0x204c0023}},	//   _pīko, _мзаз, xych, _መማህር, 
   {{0x3b840020,0x656c02fb,0x38b8067c,0xecb001e0}},	//   ርያዎች_, vych, sèrn_, _юҡлы, 
   {{0x67380196,0x656ce0bc,0x2a64ff3d,0x00000000}},	//   uwtj, wych, _toob_, --, 
   {{0x656cff3e,0x27fc0198,0x7e94012d,0x5b1012fa}},	//   tych, satn_, tąpi, _іміт, 
   {{0x66dcff3f,0x9f4001e1,0x61fc0477,0x00000000}},	//   _tīko, _jejò_, vaql, --, 
   {{0x656cff40,0x29040a73,0x81b009bd,0x7d1c00d4}},	//   rych, _ivoa_, টেড_, _åsse, 
   {{0x61fc723e,0x9da8013f,0x9f4001e1,0x6fa823ef}},	//   taql, _ɔtɑɑ_, _lejò_, _जुलू, 
   {{0x656cff41,0xa4984d74,0x09d8015b,0x29000006}},	//   pych, rròq, সরকা, škau_, 
   {{0x61fcff42,0x7414179e,0x1b000154,0x00000000}},	// [16d50] raql, _کوپا, রূপে_, --, 
   {{0xfd7401c0,0xa49800db,0x00000000,0x00000000}},	//   үлжэ, cròp, --, --, 
   {{0x4420ff43,0x64540472,0x3cfc0490,0x61fca062}},	//   _ich_, _inxi, रीने_, paql, 
   {{0x4420ff44,0x64440ea0,0x61fc0784,0x7338010f}},	//   _hch_, ldji, qaql, _פערס, 
   {{0x644405e4,0x260001ad,0xf2c04bb6,0x00000000}},	//   odji, _वजनी_, _чөри, --, 
   {{0x64440660,0xbb44593a,0x4420ff45,0x5ca80640}},	//   ndji, зекк, _jch_, шњег_, 
   {{0x4420ff46,0x6d448bb3,0x2904056a,0x6444957c}},	//   _mch_, _škat, _avoa_, idji, 
   {{0x442000c6,0x9f4001e1,0x539c008f,0xe61c002d}},	//   _lch_, _fejò_, ייוו, lhôf_, 
   {{0x4420ff47,0xc1b805ba,0x645401e2,0x00000000}},	//   _och_, _आरोग, _onxi, --, 
   {{0x4420ff48,0x7e68ff49,0x66dc00da,0xe8ec0451}},	//   _nch_, _hoep, _tīkl, اڻن_, 
   {{0x29040165,0x6444000f,0x7d1801a4,0xf090011a}},	//   _evoa_, ddji, luws, תני_, 
   {{0x4420ff4a,0xe0dc068c,0x7e6801a4,0x64440ea0}},	//   _ach_, _eròi_, _joep, edji, 
   {{0x7e68ff4b,0x290000dd,0x25e80307,0x7d18ff4c}},	//   _moep, ákat_, चड़ी_, nuws, 
   {{0x3cfc29da,0xb4b4206b,0x7e6801f5,0xa498067c}},	//   रीये_, जते_, _loep, uròp, 
   {{0x64a097ed,0x442004e6,0x00000000,0x00000000}},	//   хара, _dch_, --, --, 
   {{0x4420423a,0x64540472,0x644405e4,0x2ee8004a}},	//   _ech_, _enxi, adji, _rtbf_, 
   {{0xe0d4063b,0xa498004e,0xe1f401c6,0x00000000}},	// [16d60] зву_, pròp, ягт_, --, 
   {{0xa4980ba1,0x7eb001e3,0x05a404af,0x00000000}},	//   nsòl, kåps, _गुटब, --, 
   {{0x7d18ff4d,0x7e680af9,0x643800df,0x00000000}},	//   euws, _boep, _פעטנ, --, 
   {{0x7e680483,0x38b80561,0xdcf80139,0xad24007b}},	//   _coep, dèrm_, _ayuı, كرتو, 
   {{0xa258431d,0x41b803f8,0x44205cf8,0x7e680af9}},	//   _khôn, _आरएस, _ych_, _doep, 
   {{0xdd8c168d,0x4420010a,0x81d400bd,0x6f58010a}},	//   دوه_, _xch_, _সড়ক_, _лигă, 
   {{0x20780a1e,0xa5b800ae,0x00000000,0x00000000}},	//   _פאלא, rfói, --, --, 
   {{0xf8acff4e,0xa5b802f0,0x00000000,0x00000000}},	//   یکو_, reóz, --, --, 
   {{0x2d8001e6,0xac8400a8,0x6bd403e6,0xf1bc043e}},	//   _åke_, _егал, _فتار, ्धिन, 
   {{0x6c8405c6,0xa2580208,0xb4b40a59,0x00000000}},	//   _علام, _nhôn, जतो_, --, 
   {{0xf4203fae,0xc1b8098a,0xabc006ba,0x23c00248}},	//   য়াৰ_, _आर्ग, _ﺯﺍﻣﺎ, _méjí_, 
   {{0xd6d45aa2,0x4420060a,0xf1bc0882,0x6a140046}},	//   ять_, _sch_, ्धान, _ءبار, 
   {{0x6444002d,0xf3ec00cc,0x00000000,0x00000000}},	//   tdji, _জয়ৰ_, --, --, 
   {{0x290002d5,0x64440d04,0xa258004d,0x885866b4}},	//   škas_, udji, _chôn, _фикс_, 
   {{0x6444af58,0x81b004c5,0x44200334,0xb8640244}},	//   rdji, টো_, _vch_, _تانو, 
   {{0x1798008f,0x6444ff4f,0x44200042,0xbbd80118}},	//   _ליוב, sdji, _wch_, _ढल्क, 
   {{0x4420ff50,0xd250066d,0x7e680ae3,0x63740793}},	// [16d70] _tch_, ھنے_, _roep, fünö, 
   {{0x4420ff51,0x7e688c63,0x6454ff52,0xd25001d3}},	//   _uch_, _soep, _unxi, پنے_, 
   {{0x7e6818a6,0x00000000,0x00000000,0x00000000}},	//   _poep, --, --, --, 
   {{0xe61cff53,0x3d0801f9,0x00000000,0x00000000}},	//   ngô_, सळले_, --, --, 
   {{0x6d44341a,0x628c0076,0xe3bc00fe,0x20040393}},	//   _škar, _imco, _আলিব, ónis_, 
   {{0x7e68017a,0x00000000,0x00000000,0x00000000}},	//   _woep, --, --, --, 
   {{0x7e681aa7,0x8f345192,0x57b8000d,0x00000000}},	//   _toep, _перц, _उरेह, --, 
   {{0xb3400166,0x00000000,0x00000000,0x00000000}},	//   _üçel, --, --, --, 
   {{0x8d740e5a,0x61e803b2,0x00000000,0x00000000}},	//   _كاكا, ðgly, --, --, 
   {{0x7d08ff54,0xad240014,0x3cec0010,0xe1fcff55}},	//   _ives, _ترٲو, _itev_, _leó_, 
   {{0xa258ff56,0xb6a42097,0x0c040014,0x7d081427}},	//   _rhôn, динл, _سونُ, _hves, 
   {{0x9770bcf5,0x7bc01b24,0x95b40cef,0xe61c0548}},	//   _үткә, _izlu, ергә, ggô_, 
   {{0xa25801fb,0x00000000,0x00000000,0x00000000}},	//   _phôn, --, --, --, 
   {{0x628c07ab,0x74142942,0x7d08036e,0x98c492fe}},	//   _amco, بوسا, _mves, _эсел, 
   {{0x394cf450,0x80a8015b,0xe1fc0332,0x00000000}},	//   lves_, কগঞ্, _beó_, --, 
   {{0x7d08ff57,0x55c4ff58,0xf7885b80,0x068c1c5c}},	//   _oves, _пайғ, _ençà_, ﺗﺎﻟﯩ, 
   {{0xa25801dc,0xe294ff59,0x3cec0457,0x394c5f5e}},	// [16d80] _thôn, фат_, _ntev_, nves_, 
   {{0xe0dc067c,0x394c139f,0x2294031c,0x00000000}},	//   _duò_, ives_, dħku_, --, 
   {{0x72c4415e,0x628c0334,0xdce8010f,0x200401a9}},	//   _обоз, _fmco, ĝiĝi, аnib_, 
   {{0x20040579,0xddd8012c,0x3d0800e1,0xdce800df}},	//   ónir_, _kouř, _सिखे_, ŝiĝi, 
   {{0x2cac007f,0x00000000,0x00000000,0x00000000}},	//   tofd_, --, --, --, 
   {{0x394c00dd,0x00000000,0x00000000,0x00000000}},	//   dves_, --, --, --, 
   {{0x394cff5a,0x7d08ff5b,0x2ac40640,0x47dc00cc}},	//   eves_, _eves, мљив, _মজলী, 
   {{0x7d080309,0x998c0024,0x701c00c5,0x00000000}},	//   _fves, _nagų_, _पाँख_, --, 
   {{0x7d080022,0x394c01e3,0x66dc00ef,0x00000000}},	//   _gves, gves_, _tīkk, --, 
   {{0xa258006a,0x66dcff5c,0x291800b8,0x00000000}},	//   _ahôl, _hīki, _āpad_, --, 
   {{0x7d08ff5d,0x66dc02b5,0x00000000,0x00000000}},	//   _zves, _kīki, --, --, 
   {{0xddd8012c,0xd89001d9,0x394c00ef,0x00000000}},	//   _bouř, _یٔند, bves_, --, 
   {{0x7d08026c,0xf1ac0037,0x286800f3,0x00000000}},	//   _xves, _झुलन, _мрко_, --, 
   {{0x6aa0037e,0xe1fc007b,0x628c0175,0xd940009b}},	//   _hjof, _seó_, _smco, _рељи, 
   {{0x94d4ff5e,0xe1fc004e,0x6aa00200,0x00000000}},	//   торц, _peó_, _kjof, --, 
   {{0xe0dc0c04,0x6d0c0073,0x92581503,0x81d411f7}},	//   _può_, _सिंग_, маст_, еобх, 
   {{0xba00206f,0xe0dcff5f,0x9f880254,0x00000000}},	// [16d90] _ግዜ_, _quò_, nöör_, --, 
   {{0x6b940209,0x69c001f7,0xf79401d5,0x6ac8070f}},	//   şygy, _mzoe, _آچیب_, ागुर, 
   {{0x7d08ff60,0x7a1400ac,0x3cecff61,0x439401c6}},	//   _sves, nətç, _stev_, _чанс, 
   {{0x6aa0044e,0xa25800d2,0x628c003c,0x9f880254}},	//   _njof, _khôm, _umco, köör_, 
   {{0x629cff62,0xfd7405f5,0x81b800fe,0x24800092}},	//   mnqo, элдэ, _চলক_, _ከሶስት_, 
   {{0x6aa00311,0x5f740220,0xbd8801d9,0x5578010f}},	//   _ajof, _قازر, _ہنزن_, ועדן_, 
   {{0x69c0ff63,0x1ee404fb,0x00000000,0x00000000}},	//   _azoe, _آوری_, --, --, 
   {{0x629c01af,0x394cff64,0x38b80ba1,0x3944b215}},	//   nnqo, tves_, mèri_, ениг, 
   {{0x81b003f4,0x7d08ff65,0x394c07ea,0x7d5401c0}},	//   টের_, _uves, uves_, _явах, 
   {{0xe8f4ff66,0x69c00099,0x394cff67,0x7a140213}},	//   эль_, _dzoe, rves_, fətç, 
   {{0x394cff68,0xf624ff69,0xe7ec05f9,0x7bc001b9}},	//   sves_, ндно, छड़ा_, _uzlu, 
   {{0xda6416cb,0x60c40129,0x0ba400f3,0x00000000}},	//   _تائي, _lhjm, _ршум, --, 
   {{0xa258ff6a,0x7ae0ff6b,0x6db000b5,0xd528002b}},	//   _chôm, _hult, 期aid, _mṛgā_, 
   {{0x629c0472,0xd760006c,0x981452d4,0x4b88030d}},	//   enqo, _لنتی, _آبشا, _ийĕн_, 
   {{0xc7640075,0x7ae0ff6c,0xa56001d5,0x00000000}},	//   _لايى, _jult, نگین, --, 
   {{0x7ae0ff6d,0x38b8067c,0xf50800ee,0x00000000}},	//   _mult, dèri_, _енил_, --, 
   {{0x7ae004cc,0xa6980375,0x42d40220,0x66dc0171}},	// [16da0] _lult, _משקפ, тіру, _rīki, 
   {{0x7ae08191,0xa5b803f2,0x66dc0171,0x00000000}},	//   _oult, rfót, _sīki, --, 
   {{0xee38ff6e,0x15f40d79,0x2eec0221,0x66dccf1c}},	//   зне_, _आभार_, ëff_, _pīki, 
   {{0xdfcc23bb,0xe5140ebb,0x94200037,0x6da400d1}},	//   حيم_, _तिमि_, _बाँच_, ىمام, 
   {{0x7ae0ff6f,0xd0440022,0x00000000,0x00000000}},	//   _ault, _иҭак, --, --, 
   {{0x7ae0ff70,0x66dc00b0,0x38b8ff71,0x69c001f5}},	//   _bult, _hūke, bèri_, _rzoe, 
   {{0xa0a066b5,0x66dc04fe,0xa5b80077,0xd52800b8}},	//   _сард, _tīki, nfór, _hṛdā_, 
   {{0xe0dc068c,0x7ae034b0,0xdb0400bc,0x0d900014}},	//   _gròs_, _dult, ílán, _پۯتھ, 
   {{0x6e200175,0x94200037,0xd924009d,0x7958010a}},	//   mgob, _बांच_, нцэл_, çийĕ, 
   {{0xd7f44734,0x7ae0ff72,0x3200ff73,0x66dc0024}},	//   ную_, _fult, _leky_, _lūke, 
   {{0x7ae0ff74,0xe9d809a5,0x6e200083,0x6aa0007c}},	//   _gult, _еке_, ogob, _tjof, 
   {{0x6e20ff75,0x7a1400ac,0xf6f4036b,0xd7ec01ec}},	//   ngob, rətç, کزیگ, _әу_, 
   {{0x69c00451,0x7ae001a4,0x9a6400f1,0x7a140213}},	//   _uzoe, _zult, _سمول_, sətç, 
   {{0x799c000f,0x4734ff76,0xd7ec0114,0x7ae00166}},	//   úswe, _анкс, _љу_, _yult, 
   {{0x6e207e24,0x68e0002d,0x7ae000e8,0x6d40ff77}},	//   kgob, _huod, _xult, hwoa, 
   {{0x6d40063f,0x2728ff78,0x38b8067c,0xd7b802e4}},	//   kwoa, mùn_, vèri_, _מצור, 
   {{0x68e05067,0x320002fb,0x272804cc,0xd13000f1}},	// [16db0] _juod, _deky_, lùn_, یمې_, 
   {{0x68e0049b,0x6e2004ba,0x38b8ff79,0xa5b8295a}},	//   _muod, egob, tèri_, bfór, 
   {{0x68e0023a,0x26d84a16,0x00000000,0x00000000}},	//   _luod, _épos_, --, --, 
   {{0x7ae0ff7a,0x38b8067c,0x00000000,0x00000000}},	//   _rult, rèri_, --, --, 
   {{0x2728ff7b,0x68e00006,0x31b40032,0x1dc8033f}},	//   hùn_, _nuod, _аҫты_, ़ेंत, 
   {{0xed54ff7c,0x6e201418,0x2248029d,0x26d80009}},	//   тош_, agob, _hack_, _liqo_, 
   {{0x7a680323,0x6f1c0369,0xe0dc0561,0x22481ba6}},	//   дийг_, cupc, _tròs_, _kack_, 
   {{0x68e0ff7d,0xa2580129,0x7ae0ff7e,0x00000000}},	//   _buod, _shôj, _vult, --, 
   {{0x20000cad,0x2248045a,0xccec0150,0xfdb8009f}},	//   _keji_, _mack_, _ық_, _آئزڪ_, 
   {{0x7ae0ff7f,0x68e0ff80,0x2000d3f8,0xd8802756}},	//   _tult, _duod, _jeji_, اهدی, 
   {{0x2000110e,0x26d80286,0x7ae016b8,0x1ae80154}},	//   _meji_, _biqo_, _uult, _টিকে_, 
   {{0x26d80a73,0xa800029f,0x224801ab,0x68e00042}},	//   _ciqo_, çırm, _nack_, _fuod, 
   {{0x27280ffb,0x7d180368,0x6f1c0810,0x68e0ff81}},	//   aùn_, nrws, zupc, _guod, 
   {{0x2728b507,0x32000109,0x00000000,0x00000000}},	//   bùn_, _seky_, --, --, 
   {{0x2248771c,0x66dc0053,0x23245f5d,0xe5147039}},	//   _back_, _pūke, кори_, _तिथि_, 
   {{0x22480208,0x6f1c0477,0x81bc00fe,0x32000200}},	//   _cack_, vupc, েখন_, _qeky_, 
   {{0x2000ff82,0x224801c7,0x28c401ad,0x79883024}},	// [16dc0] _beji_, _dack_, _रीडि, nzew, 
   {{0x21280036,0x26d8315a,0x6f1c009b,0xbacc02dd}},	//   _dqch_, _épor_, tupc, _ﺗﺎﺑﺎ, 
   {{0xa5b8ff83,0x2248ff84,0x66dc00b0,0x2000ff85}},	//   ngón, _fack_, _tūke, _deji_, 
   {{0x81b02158,0x200001e1,0x6e20030a,0x00000000}},	//   টেই_, _eeji_, ugob, --, 
   {{0x6e20ff86,0x3cfc0316,0x272807c5,0x2bdc033f}},	//   rgob, रीले_, zùn_, मशला, 
   {{0x6ac807b7,0xefcc010c,0x6d40000f,0x6ca401d5}},	//   ाग्र, እላይ_, rwoa, خصصل, 
   {{0xa0341203,0x6d4002c4,0x68e0023a,0x6fb406f6}},	//   _שאלה_, swoa, _suod, _شمرا, 
   {{0x68e00006,0x00000000,0x00000000,0x00000000}},	//   _puod, --, --, --, 
   {{0x68e00483,0x9d4007d6,0x00000000,0x00000000}},	//   _quod, _кетд, --, --, 
   {{0x68e00664,0x26300055,0x00000000,0x00000000}},	//   _vuod, _ṇo_, --, --, 
   {{0xdcac2002,0xdc980302,0x69f03769,0x79880036}},	//   _بىل_, _קיבל, _күйт, azew, 
   {{0x26d80481,0x68e0023a,0xb7c402dd,0xf98000c7}},	//   _qiqo_, _tuod, ырық, рҳәо, 
   {{0xe0dc0241,0x7988396d,0x2248ea77,0x66dc0171}},	//   _asòn_, czew, _rack_, _rīku, 
   {{0x2248ff87,0x272804cc,0x66dc00e2,0x65e40220}},	//   _sack_, pùn_, _sīku, _ﺍﯞﯨﻠ, 
   {{0x22480dee,0x2000007f,0xb8648ee7,0x25ac0153}},	//   _pack_, _reji_, _حانو, _žolę_, 
   {{0x28c4ff88,0x442c0316,0x200009a8,0x7c2c07f5}},	//   _रीति, ře_, _seji_, đari, 
   {{0xb9ec02d3,0x2000006f,0xe4a4ff89,0x442c03f9}},	// [16dd0] _ሓዉ_, _peji_, _арно, ƙe_, 
   {{0x2248ff8a,0x00000000,0x00000000,0x00000000}},	//   _wack_, --, --, --, 
   {{0x2248ff8b,0xe0dc02e2,0xa498004e,0x20000010}},	//   _tack_, _eròp_, dròx, _veji_, 
   {{0x20000067,0xa5b81bce,0xf1ac012d,0x204c0240}},	//   _weji_, ngóo, _झुकन, _መዛምር, 
   {{0x721823e4,0x20000010,0xcd28ff8c,0x914801b9}},	//   _אורח, _teji_, نسون_, _ичра_, 
   {{0x0c2400d6,0x61ec0477,0xf428023a,0x8c4805d1}},	//   имін, _hfcl, _ikää_, vaşç, 
   {{0x66dc005f,0xd438008f,0x00000000,0x00000000}},	//   _mīks, דרוק_, --, --, 
   {{0x66dc00de,0x79881196,0x00000000,0x00000000}},	//   _līks, tzew, --, --, 
   {{0x580000d1,0x00000000,0x00000000,0x00000000}},	//   لۈشك, --, --, --, 
   {{0x0dc8ff8d,0x7988068f,0x91bc0302,0x78642ccb}},	//   _руси_, rzew, ומחי, укоз, 
   {{0x7988f744,0x00000000,0x00000000,0x00000000}},	//   szew, --, --, --, 
   {{0x89b4063f,0xa5b8002e,0x4a7400c0,0x00000000}},	//   ịtọs_, ggóo, _вышт, --, 
   {{0xe8ec00a8,0x66dc0171,0x00000000,0x00000000}},	//   _ыл_, _sīkt, --, --, 
   {{0x66dc0171,0x76940064,0x19c00116,0x00000000}},	//   _cīks, mšym, ﺯﻩﻟﻠ, --, 
   {{0x66dc0171,0x00000000,0x00000000,0x00000000}},	//   _dīks, --, --, --, 
   {{0x768402ea,0xe0dc204d,0x00000000,0x00000000}},	//   _bóye, _pròp_, --, --, 
   {{0xa5b8ff8e,0x9418013f,0x38b81497,0xa2e00220}},	// [16de0] ngól, forɔ_, bèrt_, _қояд, 
   {{0x66dc02b5,0x38b8068c,0xa8000790,0x39580108}},	//   _hūka, mèrs_, _çıta, ässy_, 
   {{0x8eb441fa,0x38b880e1,0x61ec0142,0x2f5447c5}},	//   لەست, lèrs_, _ffcl, ытас, 
   {{0xdfccbd0e,0xe0dc180f,0xbe8001d5,0x00000000}},	//   سين_, _tròp_, оқси, --, 
   {{0x38b8067c,0xa4981f40,0xa5b800d0,0x66dc00b8}},	//   nèrs_, rsòv, jgól, _mūka, 
   {{0x1ae803f4,0xaff80014,0xb1c4cc0d,0x38b8067c}},	//   _টিজে_, _سفرا_, _аңға_, ièrs_, 
   {{0x80b00150,0x09dc4709,0x00000000,0x00000000}},	//   _بەلش, मख्य, --, --, 
   {{0x3be80032,0xc9140063,0xad24141d,0x93480092}},	//   нләү_, адић, _مرطو, _ያካትታ, 
   {{0xada430ab,0x99940395,0xfe900101,0x00000000}},	//   _саал, лкът_, _بینج, --, 
   {{0x4734ff8f,0x38b80ba1,0xb86401b9,0x80b800cd}},	//   анос, dèrs_, لاپو, ्तये, 
   {{0x6b5806f7,0xdcac0137,0x66dc0171,0x00000000}},	//   _яшар_, _عىم_, _rīks, --, 
   {{0x45d42b97,0x38b8068c,0x66dc0171,0xa2580051}},	//   ионс, fèrs_, _cūka, _thôi, 
   {{0x80b800dc,0x38b8067c,0x15a800fd,0x3ad400cd}},	//   ्तमे, gèrs_, гъри_, _nāpy_, 
   {{0x98a0ff90,0x93f8013f,0x2ab81bce,0x395801bf}},	//   _личе, korε_, rëbu_, æsse_, 
   {{0x2284000d,0xf8ac01c8,0x66dc0171,0x00000000}},	//   _lõke_, _تکي_, _vīks, --, 
   {{0x5fac02ab,0x12e402dd,0x38b8180f,0x00000000}},	//   _जुगल, сірг, sèrt_, --, 
   {{0x3ad400dc,0x00000000,0x00000000,0x00000000}},	// [16df0] _cāpy_, --, --, --, 
   {{0xa5b80085,0x66dc00ef,0x00000000,0x00000000}},	//   ngóm, _tīks, --, --, 
   {{0x9f640023,0x9fc40229,0x00000000,0x00000000}},	//   _ተላዒሉ_, ущал, --, --, 
   {{0x7684043b,0x7d1c0158,0xe2a8ba15,0xb72c0139}},	//   _tóye, _åssk, _ساجن_, _çäşk, 
   {{0xa258030a,0xd1c8013e,0xa4980ba1,0xdc3c0139}},	//   _shôw, _бурд_, ssòu, _síıq, 
   {{0x1ee428b1,0x5c040137,0x00000000,0x00000000}},	//   _موسی_, уяда, --, --, 
   {{0x26c0002e,0x229c0139,0x00000000,0x00000000}},	//   ňkoy_, cäkä_, --, --, 
   {{0x0ae812ea,0x00000000,0x00000000,0x00000000}},	//   دروي_, --, --, --, 
   {{0x7cd801c0,0xd90c01d5,0x3d9401c4,0xe61c0051}},	//   _амар_, سیغ_, _тиар, thôn_, 
   {{0xe9d4ff91,0x66dcc462,0x76940024,0x38b81497}},	//   шкы_, _rūka, ršym, vèrs_, 
   {{0xf7707d5a,0x5ba434d8,0x66dc3da0,0x00000000}},	//   زاد_, _сраз, _sūka, --, 
   {{0x66dcff92,0xc4c802e4,0x38b80ba1,0x369400d4}},	//   _pūka, _חג_, tèrs_, ршос, 
   {{0x9208005f,0x38b80ba1,0xd5d023ef,0xd9180108}},	//   ntāž, uèrs_, सेंज, _чье_, 
   {{0x38b80ba1,0x69c40254,0x00000000,0x00000000}},	//   rèrs_, ükee, --, --, 
   {{0x64a0ff93,0x38b8067c,0x729421b5,0x3ad400b8}},	//   цара, sèrs_, ашах, _sāpy_, 
   {{0x66dc0374,0xa8003bc1,0x38b8067c,0x8e24022e}},	//   _tūka, _çıra, pèrs_, _nimа_, 
   {{0x3004ff94,0x00000000,0x00000000,0x00000000}},	// [16e00] изаг, --, --, --, 
   {{0x2f541413,0x04c800ec,0x3ad400cd,0x00000000}},	//   итес, _ٽوپي_, _vāpy_, --, 
   {{0xb4b02017,0xee085211,0xd9f410eb,0xe6c000d1}},	//   टकी_, веел_, ीरात_, ﺩﯨﮕﺎ, 
   {{0x69d401ad,0xee1401c6,0x00000000,0x00000000}},	//   मेडी, рьжэ, --, --, 
   {{0x6da42c1d,0x62800356,0xafe40120,0x00000000}},	//   шида, _înoa, _вогл, --, 
   {{0xddd80356,0x63b80112,0xce342e0b,0x00000000}},	//   _sluţ, ßung, _گورک, --, 
   {{0xe454010f,0x00000000,0x00000000,0x00000000}},	//   שיצט_, --, --, --, 
   {{0xdee01d3e,0xa498e0fd,0xce34ff95,0x22840254}},	//   _фоти, nsòr, _دورک, _tõke_, 
   {{0xa8a4cf36,0x7d0c0174,0x29840166,0x76940064}},	//   ирок, áast, рыйг, pšyj, 
   {{0x491c00bc,0x2cd000e5,0x00000000,0x00000000}},	//   _मिठो_, _بےتر, --, --, 
   {{0xda6c00ec,0xdce80064,0x2054011a,0x80b807b7}},	//   _ڪُن_, dygę, בייל_, ्तते, 
   {{0x5ce002dd,0x7cf00124,0xddd8560e,0x48b800eb}},	//   _اكەل, _ẽrir, _hluš, ীদের, 
   {{0xe5c40452,0x41b4000d,0x49040137,0xddd800ef}},	//   рсно, _अँइस, _چوچق, _kluš, 
   {{0x656800a3,0x94a8ff96,0xe3b001d9,0x04a40124}},	//   _àghm, атса_, ٲرس_, сумҭ, 
   {{0xe3b08eef,0x00000000,0x00000000,0x00000000}},	//   زرس_, --, --, --, 
   {{0xa5b800e5,0x00000000,0x00000000,0x00000000}},	//   ngók, --, --, --, 
   {{0x66dc00b0,0x84c40131,0xddd80010,0x81b00154}},	// [16e10] _hūko, _гәвд, _oluš, য়েন_, 
   {{0xb4f001c0,0x2004ff97,0x7d1c143a,0x786c00d7}},	//   _хүрч, úni_, _åssi, _súvz, 
   {{0xa498ff98,0xdfd808ca,0xdb200205,0x00000000}},	//   ssòs, тъа_, ürük, --, 
   {{0x63b807c4,0x4ea402d5,0x20040034,0x27fc0334}},	//   ğund, орча, źni_, hbtn_, 
   {{0x63b8d9d4,0x66dc00de,0x81b000eb,0x80b800cd}},	//   şund, _lūko, টেজ_, ्तदे, 
   {{0x920800e2,0x00000000,0x00000000,0x00000000}},	//   rtāž, --, --, --, 
   {{0xeb9484cc,0xa3d4060c,0xe8f40046,0xdb0401b8}},	//   йиш_, िधि_, ұлы_, _älüb, 
   {{0x76940006,0x9f5000db,0x2eb000dc,0x66dc00de}},	//   ršyk, saxó_, जवृत, _sūkn, 
   {{0xe8f40352,0xbb5400f2,0x02940051,0x39580413}},	//   блы_, _گناب, _đếm_, íss_, 
   {{0x7c2c2d2b,0x9cc86cea,0x4c940022,0xa3d4012a}},	//   đars, _рыба_, _диус, िधा_, 
   {{0xf7440212,0xd90c00e5,0x00000000,0x00000000}},	//   щено, سیں_, --, --, 
   {{0xb6a42097,0x00000000,0x00000000,0x00000000}},	//   симл, --, --, --, 
   {{0xe9cc01c0,0x7bc003f2,0x11440023,0x1824104c}},	//   _хк_, _hylu, _ሚልዮና, _نقشی_, 
   {{0xa95405e1,0x27fc0175,0xd7f8117e,0x00000000}},	//   _לינק_, cbtn_, _руд_, --, 
   {{0x7bc00076,0xe9a43c5b,0xf7180006,0x00000000}},	//   _jylu, _نگین_, _сілы_, --, 
   {{0x7bc000b5,0xd7840451,0xef1801e0,0x81b000cc}},	//   _mylu, _ٽنڊو_, ҫма_, টেছ_, 
   {{0x2164a948,0x7644037e,0x00000000,0x00000000}},	// [16e20] бити_, meky, --, --, 
   {{0x71a402f4,0xa49826b7,0xaff80214,0xb81803d4}},	//   _ҳамз, ssòr, افضا_, ত্রত_, 
   {{0xef18ff99,0x7bc0ff9a,0x32446c66,0x752401f5}},	//   уме_, _nylu, _ленг, lukz, 
   {{0xddd808ad,0x7644ff9b,0x59d401ad,0x71a42ec9}},	//   _sluš, neky, डधार, _гамз, 
   {{0x7bc00113,0xa258045f,0xf1d001c6,0x2bd800cd}},	//   _aylu, _skôg, _хөвө, येना, 
   {{0x7644ff9c,0x7bc001e3,0x63b80356,0x00000000}},	//   heky, _bylu, şune, --, 
   {{0x76442dba,0x66dc0006,0xc05c001f,0x27fc0334}},	//   keky, _būkl, _ለማቃለ, vbtn_, 
   {{0x7bc000a9,0x7644ff9d,0x66dc139f,0x15e4000d}},	//   _dylu, jeky, _rūko, _गलगर_, 
   {{0x7bc003e0,0x66dc00ef,0x764401f4,0xda740395}},	//   _eylu, _dūkl, deky, сящ_, 
   {{0xb4b073ca,0x752401c0,0x66dc0374,0x35a402d3}},	//   टको_, dukz, _pūko, ለጺታት_, 
   {{0x3a7401e0,0xda6c022e,0x00000000,0x00000000}},	//   слөр, _ея_, --, --, 
   {{0x46e800f7,0x76440ea0,0x27fc0175,0x42680092}},	//   лдүн_, geky, sbtn_, ደኝነት_, 
   {{0x7bc00064,0x00000000,0x00000000,0x00000000}},	//   _zylu, --, --, --, 
   {{0x69c0030a,0x66dc02b1,0x81b0015b,0xa5b8ff9e}},	//   _iyoe, _tūko, য়েড_, ngói, 
   {{0x7644ff9f,0x00000000,0x00000000,0x00000000}},	//   beky, --, --, --, 
   {{0x2bd801bc,0xd1380116,0x00000000,0x00000000}},	//   येया, әхт_, --, --, 
   {{0x660c05a1,0x9fe40597,0xf8ac8ec1,0x1b000183}},	// [16e30] mack, مساه, _سکی_, ৰূপে_, 
   {{0x9f4001d3,0x00000000,0x00000000,0x00000000}},	//   _ifjú_, --, --, --, 
   {{0x64440451,0xdef80967,0xbe14007b,0xabc000d1}},	//   meji, уыз_, قواع, _ﺯﺍﻛﺎ, 
   {{0x6444ffa0,0x46c84196,0x8afc000f,0xa6a80183}},	//   leji, रतिह, _kręf, _গীতট, 
   {{0x629c0944,0x69c0020c,0x7bc00393,0x00000000}},	//   miqo, _nyoe, _sylu, --, 
   {{0x6444ffa1,0x629cffa2,0x7644013f,0x66dc0171}},	//   neji, liqo, zeky, _sūkl, 
   {{0x7644013b,0x660cea7f,0xabd00014,0x547c00df}},	//   yeky, kack, ٘ٲوت, רטוו, 
   {{0x69c00399,0x539c00c8,0x629c0a73,0x7bc00122}},	//   _byoe, טיוו, niqo, _vylu, 
   {{0x3eac0428,0x660c0306,0xa498067c,0x66dc0171}},	//   _ijet_, dack, opòd, _cūkm, 
   {{0x76442252,0xdd90ffa3,0x629c022e,0x7bc000c0}},	//   weky, _дағы, hiqo, _tylu, 
   {{0x6444ffa4,0x660c007c,0x7bc00205,0xac9400e5}},	//   deji, fack, _uylu, _بچنا_, 
   {{0x660c110c,0xe8a401e0,0xb34006be,0x00000000}},	//   gack, йбөҙ_, _üçil, --, 
   {{0x69c00207,0x3eacffa5,0x3cfc0490,0x76440134}},	//   _gyoe, _mjet_, रीचे_, reky, 
   {{0x76440522,0x752401c0,0xb4b4012d,0x00000000}},	//   seky, rukz, ड़ते_, --, 
   {{0xdb0c00a2,0x834801d9,0x629cffa6,0x00000000}},	//   _ödär, یشہِ_, fiqo, --, 
   {{0x629c01f0,0x35a4ffa7,0xf1d0499d,0x69c00175}},	//   giqo, _майг, дөгө, _yyoe, 
   {{0x6444ffa8,0x716801c0,0xefe8007b,0x00000000}},	// [16e40] beji, шааг_, لعضو_, --, 
   {{0x3eacffa9,0x212c01c3,0x66dc0241,0xd5a401e2}},	//   _ajet_, àgha_, _tàkì, _ولګی, 
   {{0x63b80790,0x1288004b,0x3eac0051,0x00000000}},	//   ğunc, _همدی_, _bjet_, --, 
   {{0x629c0481,0x853401b9,0xee3801a9,0x63b803e0}},	//   ciqo, _بویچ, рнд_, şunc, 
   {{0x395cffaa,0x8afc0034,0x42540276,0x768401e1}},	//   _nrws_, _kręg, _этэт, _lóyo, 
   {{0xdd8c24e0,0x4974016c,0x3eac00b5,0x6ab00892}},	//   خوه_, ҷлис, _ejet_, ँक्र, 
   {{0x80b853c7,0x3eac036e,0xa5b800ae,0xdd8c0633}},	//   ्तरे, _fjet_, rgói, _یوف_, 
   {{0x4974e937,0x38680198,0x3eac0023,0x395c0142}},	//   злис, _ɗare_, _gjet_, _brws_, 
   {{0x644400ec,0x26d8011c,0xaed4010b,0x7aec0115}},	//   yeji, _èpoi_, _гоңш, ĉata, 
   {{0x629c1cdf,0x395c0368,0x660cffab,0xeb98ffac}},	//   ziqo, _drws_, wack, _киз_, 
   {{0x3eac0023,0x660cc963,0x629cd059,0x64440153}},	//   _yjet_, tack, yiqo, veji, 
   {{0x395c0230,0x629c0e14,0x69c001f4,0x00000000}},	//   _frws_, xiqo, _tyoe, --, 
   {{0xd6d8090b,0x8afc045f,0x1fb40456,0x6444ffad}},	//   ють_, _bręg, _अड्ड, teji, 
   {{0x629c0472,0x58b40014,0xd8b40133,0x2bd800dc}},	//   wiqo, _واوج_, _ودوا_, येथा, 
   {{0x6444ffae,0x629cffaf,0x57b000a8,0x00000000}},	//   reji, tiqo, _обшт, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x629cffb0,0x2688004b,0x2bd800dc,0x00000000}},	// [16e50] riqo, _مخکي_, येता, --, 
   {{0x629c013e,0x8334030d,0x3eac01ef,0x00000000}},	//   siqo, _енох, _sjet_, --, 
   {{0x3cb402dd,0x1fa401c6,0x937801c4,0x00000000}},	//   үйер, цраг, _дбэт_, --, 
   {{0x629c0a73,0xfe7002f2,0xb3b8011a,0xa2240066}},	//   qiqo, رگز_, _למתכ, _برده, 
   {{0x3eac069c,0x5fb40073,0xa5b80210,0x76940064}},	//   _vjet_, _अडकल, rgów, mšyt, 
   {{0xe3dc8961,0x3178025f,0xf4280166,0xa3ac0073}},	//   _ব্যব, _הרשמ, _igäç_, _कशा_, 
   {{0x7dd40036,0x66dc0171,0x3eacffb1,0x6cc00006}},	//   füsé, _cūkk, _tjet_, эйша, 
   {{0x7f9400c7,0x3eacffb2,0x00000000,0x00000000}},	//   _даҳх, _ujet_, --, --, 
   {{0xe8f4ffb3,0xefe80023,0x769400c0,0x00000000}},	//   плы_, ህላዉ_, išyt, --, 
   {{0x7d08ffb4,0xbb4c00b5,0x9604134e,0x00000000}},	//   _iwes, _comペ_, लर्ट_, --, 
   {{0x7d08ffb5,0xf090011a,0x00000000,0x00000000}},	//   _hwes, גני_, --, --, 
   {{0xc9bc02e3,0x76940113,0xe73400d4,0x00000000}},	//   ịkụl_, yšyu, чею_, --, 
   {{0x7d08ffb6,0x8afc0210,0x756400e5,0x00000000}},	//   _jwes, _pręg, سیدہ_, --, 
   {{0x7d0851a9,0x394c00ca,0x3a2c0194,0xa3d400cd}},	//   _mwes, mwes_, lgep_, िधं_, 
   {{0x8704099f,0x7d08136f,0x394c017a,0x67d01f5a}},	//   _قبيل, _lwes, lwes_, _пољу, 
   {{0x7d08ffb7,0x3a2cffb8,0x3af01dfd,0x00000000}},	//   _owes, ngep_, _máp_, --, 
   {{0x2164ffb9,0x3124ffba,0x3cec0789,0x7d0804ba}},	// [16e60] пити_, ядаг, _nuev_, _nwes, 
   {{0x7654ffbb,0x78a00789,0x394c01c7,0x63b80205}},	//   _hayy, nilv, iwes_, şuna, 
   {{0x7654ffbc,0x9ad40882,0x7d08ffbd,0x53c0012d}},	//   _kayy, śeṣā, _awes, _एडिश, 
   {{0xddcc1357,0x7d08ffbe,0x491c05f9,0xd25003e6}},	//   _šeše, _bwes, _मिलो_, _جۆر_, 
   {{0x78a0008c,0x7d0800a9,0x7654d11d,0x12880214}},	//   kilv, _cwes, _mayy, _همگی_, 
   {{0x7d080004,0x653800c8,0x7654ffbf,0x3cec04cc}},	//   _dwes, מענד, _layy, _duev_, 
   {{0x3af0001e,0x5f24ffc0,0x7d08ffc1,0x78a001e4}},	//   _cáp_, _норм_, _ewes, dilv, 
   {{0x3210089c,0x6da40588,0x3a2cffc2,0x3dc80210}},	//   nayy_, _еиба, ggep_, żawa_, 
   {{0x7d0800a9,0xdd8c01d3,0xbe9c010e,0x1d040395}},	//   _gwes, _یوہ_, _üçaý, _нети_, 
   {{0xb0bc3806,0x8afc0034,0x18b40124,0x00000000}},	//   ्तिग, _pręd, згьы_, --, 
   {{0x7654ffc3,0x66dc02b5,0xf4280135,0x7d080221}},	//   _bayy, _hūki, _སྐེད_, _zwes, 
   {{0x7654011f,0x394c072b,0x18d40014,0xaa400108}},	//   _cayy, bwes_, _ہِند_, äsää_, 
   {{0x76548eb8,0x78a0ffc4,0x06c801c0,0x3af00f91}},	//   _dayy, bilv, йгүй_, _záp_, 
   {{0x95d8034b,0x78a000de,0x00000000,0x00000000}},	//   ядят_, cilv, --, --, 
   {{0x7654991f,0x66dc0069,0xbcfc00e4,0xc0440092}},	//   _fayy, _lūki, _irũe, _ማምሻው, 
   {{0x765423db,0x4614ffc5,0x00000000,0x00000000}},	//   _gayy, _کوکر, --, --, 
   {{0x66dc02b5,0xd24401c0,0x76940024,0x44b4ffc6}},	// [16e70] _nūki, ээри, ršyt, _обис, 
   {{0x76540b45,0x7d08ffc7,0x9e9000ec,0x00000000}},	//   _zayy, _rwes, ڙهاڪ, --, 
   {{0x7d080c11,0x7654ffc8,0xa5b80077,0x7afc054e}},	//   _swes, _yayy, rgóu, _ăsto, 
   {{0x7d08ffc9,0x7654102c,0x6454ffca,0x3af001fb}},	//   _pwes, _xayy, _haxi, _ráp_, 
   {{0x3af001fb,0x6454ffcb,0x3ce40037,0x7d08045a}},	//   _sáp_, _kaxi, _pilv_, _qwes, 
   {{0x64543d20,0xfbc40798,0xbf680133,0xa22400f2}},	//   _jaxi, мбло, _وڵام_, _برگه, 
   {{0x76b00882,0x00000000,0x00000000,0x00000000}},	//   hāya, --, --, --, 
   {{0x7d0801ba,0x394c08cd,0x2010ffcc,0x6454ffcd}},	//   _twes, twes_, laxi_, _laxi, 
   {{0x81b003f4,0x78a0ffce,0x7e68ffcf,0x7654ffd0}},	//   য়ের_, tilv, _inep, _rayy, 
   {{0x7654ffd1,0x645427a2,0x394c0ea0,0x7e68032e}},	//   _sayy, _naxi, rwes_, _hnep, 
   {{0x7e6893e0,0x394c0098,0x7654ffd2,0x00000000}},	//   _knep, swes_, _payy, --, 
   {{0x78a0ffd3,0x76540a55,0x6454102c,0x20100564}},	//   silv, _qayy, _aaxi, haxi_, 
   {{0x6d44025a,0x6454ffd4,0xf4280135,0x78a06775}},	//   _âkat, _baxi, _སྐུད_, pilv, 
   {{0x6454ffd5,0x7654c0dc,0xa804002b,0x2bd8d8eb}},	//   _caxi, _wayy, _viññ, येवा, 
   {{0x7654ffd6,0x64540cc1,0x7e68ffd7,0x2010740e}},	//   _tayy, _daxi, _onep, daxi_, 
   {{0x7e68016b,0xa5b802d2,0x00000000,0x00000000}},	//   _nnep, ggós, --, --, 
   {{0x6454ffd8,0x8afc033f,0x316401e4,0x7694010e}},	// [16e80] _faxi, _kręc, ĥozo_, bšyr, 
   {{0x2010014b,0x7e68ffd9,0xb924063f,0x66dc0064}},	//   gaxi_, _anep, wkwọ_, _rūki, 
   {{0xdd8cffda,0xa258019f,0x81b0015b,0x6f640b24}},	//   یوم_, _ikôn, য়েল_, بهام, 
   {{0x6600013f,0x6454036b,0xdfcc12fc,0x66dcffdb}},	//   _ɑnko, _zaxi, جيم_, _pūki, 
   {{0x26c4013b,0x6d5c0421,0x66f8025c,0x6454ffdc}},	//   _ɔno_, āpao, _iċke, _yaxi, 
   {{0x6454ffdd,0x6fd406e3,0x7e68ffde,0x20100120}},	//   _xaxi, _भरपू, _enep, caxi_, 
   {{0x6e94129d,0x4df000bc,0x00000000,0x00000000}},	//   _قلسا, ुँदै_, --, --, 
   {{0x66dc0053,0x76b00882,0x7e6800e8,0x2bd800cd}},	//   _tūki, yāya, _gnep, येषा, 
   {{0xcfb00154,0xd92401c6,0x48c412b9,0x00000000}},	//   _করিন, мцэл_, нәка, --, 
   {{0xd7f489f1,0x6c3001ed,0x7e6802fb,0x6bd4516c}},	//   мую_, _شہبا, _znep, _قتار, 
   {{0x8afc0210,0x00000000,0x00000000,0x00000000}},	//   _dręc, --, --, --, 
   {{0x6454ffdf,0xc5f8007d,0xcfb00154,0xa5b8012d}},	//   _saxi, ंडेय_, _করান, dgór, 
   {{0x6454ffe0,0x00000000,0x00000000,0x00000000}},	//   _paxi, --, --, --, 
   {{0x76b00a28,0x645403d9,0xd7eca4e3,0x8afc003a}},	//   rāya, _qaxi, _ју_, _gręc, 
   {{0x5334ffe1,0x59080135,0x6454ffe2,0x183000c6}},	//   керт, _གསོས_, _vaxi, _شروح, 
   {{0x6454ffe3,0x76b00882,0x8afc012d,0xc05c0092}},	//   _waxi, pāya, _zręc, _ለማመል, 
   {{0x12e40046,0x6454ffe4,0x673801e3,0x00000000}},	// [16e90] тірг, _taxi, lttj, --, 
   {{0x7e68ffe5,0x26c8036e,0xd54800f1,0x7f940022}},	//   _snep, llco_, _کلیو_, назх, 
   {{0x67380fac,0x2010ffe6,0x93b40064,0x00000000}},	//   nttj, raxi_, _абэц, --, 
   {{0x44300077,0xd1300131,0x20100009,0xde4402f2}},	//   lgz_, امە_, saxi_, بیرو_, 
   {{0x6738045f,0x20100784,0x628cffe7,0xc1a400c7}},	//   httj, paxi_, _ilco, _чынқ, 
   {{0x4430ffe8,0x67387c1d,0x00000000,0x00000000}},	//   ngz_, kttj, --, --, 
   {{0x4fc4ffe9,0x66dc00b0,0xb0bc18cc,0xa8000205}},	//   _аста, _hūku, ्तरग, _çıya, 
   {{0x66dc170b,0x7e6808e5,0x63b4022e,0x00000000}},	//   _kūku, _unep, _mxxn, --, 
   {{0x8afcf928,0x44300175,0xf990007b,0xcaf4009d}},	//   _pręc, kgz_, طبة_, нцөө, 
   {{0x81b0015b,0x3b6001d9,0xf090008f,0x26c80009}},	//   _ওরা_, _مێتہ, ָנט_, elco_, 
   {{0x66dc00c0,0x00000000,0x00000000,0x00000000}},	//   _lūku, --, --, --, 
   {{0x63b8046c,0x8afc0034,0xc4c80375,0x00000000}},	//   ğunl, _wręc, _הג_, --, 
   {{0x63b8ffea,0x05980014,0xa2c00b98,0x00000000}},	//   şunl, ِمُک_, लवन्, --, 
   {{0xa97800df,0x00000000,0x00000000,0x00000000}},	//   _מאנכ, --, --, --, 
   {{0x32d40276,0x768401e1,0xe714007b,0xb6a4011c}},	//   ецас, _lóyi, _كيوت_, _пикл, 
   {{0x81d80729,0x69d4ffeb,0x8e2000fa,0x00000000}},	//   াশন_, मेकी, зiн_, --, 
   {{0xe294ffec,0xf0644bb1,0xc5b400db,0x00000000}},	// [16ea0] хат_, нкап, _үрөө, --, 
   {{0x628cffed,0xc10000d1,0xf8b02314,0x8ca42052}},	//   _elco, рүрл, ीकिय, _औषधो, 
   {{0xee2400ea,0x6020009d,0x00000000,0x00000000}},	//   емеп, удха, --, --, 
   {{0x76840248,0x2bb40abd,0x20040008,0x9188022e}},	//   _bóyi, _अखबा, ðnir_, _жамғ_, 
   {{0xdcf40075,0xc2900345,0x00000000,0x00000000}},	//   ۈرۈش_, _ئیقب, --, --, 
   {{0xa8000cc1,0x6738ffee,0xabb00166,0x00000000}},	//   _çıxa, yttj, лалә, --, 
   {{0x5908031c,0x70bc5d9c,0x0d1c0073,0x00000000}},	//   _གསུས_, ्तील, _निकष_, --, 
   {{0xdee0ffef,0x9b4075a6,0x66dc002d,0x22840254}},	//   _боси, انيو, _jūkt, _rõkk_, 
   {{0x2918002b,0x00000000,0x00000000,0x00000000}},	//   _āpas_, --, --, --, 
   {{0x7c64004b,0xdd9001af,0x00000000,0x00000000}},	//   _لامل, _сађы, --, --, 
   {{0x597056a7,0x4910000d,0x00000000,0x00000000}},	//   ندیز, _दौरो_, --, --, 
   {{0x9bb40302,0x70bc63a5,0x7d180166,0x67381141}},	//   _אהבה_, ्तुल, _äbsä, rttj, 
   {{0x6738392d,0x637800fd,0x00000000,0x00000000}},	//   sttj, känç, --, --, 
   {{0x66dc0064,0x1dd0012d,0xd94000f3,0x00000000}},	//   _rūku, _तरसत, _сељи, --, 
   {{0xd324fe7d,0xb8640e6b,0x66dc0153,0x00000000}},	//   льти, _جانو, _sūku, --, 
   {{0xd2582add,0x66dcfff0,0x9778030d,0x00000000}},	//   нцу_, _pūku, _хушă_, --, 
   {{0xa25800d2,0x4430030d,0x6aa0013b,0x2b50068f}},	// [16eb0] _khôz, pgz_, _mmof, łych_, 
   {{0xd91825f9,0x68e8025c,0x11540153,0x9e6400e5}},	//   פובל, _jifd, ыкую, کائن, 
   {{0x6aa00395,0x442008c2,0x68e80327,0x1dd0000d}},	//   _omof, _idh_, _mifd, _तरहत, 
   {{0xe0dc0ba1,0x66dc00b0,0x4420fff1,0x00000000}},	//   _esòp_, _tūku, _hdh_, --, 
   {{0x44200030,0x63780139,0x00000000,0x00000000}},	//   _kdh_, bänç, --, --, 
   {{0x6aa00241,0x4420003e,0x68e8031c,0x00000000}},	//   _amof, _jdh_, _nifd, --, 
   {{0x4420036b,0xd528002b,0xf1c800d7,0x3f8402d2}},	//   _mdh_, _hṛtā_, _vráť_, _ælu_, 
   {{0x4420070d,0x9ac401d3,0xd52800dc,0x3944fff2}},	//   _ldh_, رگاہ_, _kṛtā_, вниг, 
   {{0x61ec02d0,0x442001e7,0x00000000,0x00000000}},	//   _mgcl, _odh_, --, --, 
   {{0x442005ce,0x6aa0fff3,0xd528002b,0xe82000c7}},	//   _ndh_, _emof, _mṛtā_, аҧшҩ, 
   {{0xc5e80729,0x6c7800c8,0x61ec02d0,0x9a840798}},	//   কুমা_, _קרעד, _ogcl, _пудл, 
   {{0x4420fff4,0xb6a4825e,0xe7040133,0x55200037}},	//   _adh_, тимл, کسیی, _बिआए_, 
   {{0xaa4000db,0x44200051,0xe8ec004e,0x00000000}},	//   _ئچىى, _bdh_, _ъл_, --, 
   {{0x4420fff5,0xf7440588,0xd83805f5,0xf7700214}},	//   _cdh_, _аеко, _хэд_, _ناب_, 
   {{0xc7643ed0,0x6aa003cb,0xe81801f7,0x00000000}},	//   _مايى, _ymof, _آرهڙ_, --, 
   {{0x4420fff6,0x00000000,0x00000000,0x00000000}},	//   _edh_, --, --, --, 
   {{0xa2e001b9,0xf1d0955d,0x44200200,0x66180d12}},	// [16ec0] ротд, рөнө, _fdh_, ðuke, 
   {{0x68e80067,0xb4640022,0xddd80064,0x00000000}},	//   _xifd, _ркол, _bluž, --, 
   {{0xee383e0c,0x8eb400c7,0x66dc002b,0xe3b4022e}},	//   дне_, гӡах, _tūkt, _абэ_, 
   {{0x26c004b9,0x8c1402a6,0xddd800bc,0xa2c00073}},	//   čkog_, _সাধন_, _dluž, लवण्, 
   {{0xa8000724,0xa2bc1b61,0xca78022e,0x00000000}},	//   _çıga, वकर्, tuvо, --, 
   {{0x9980010e,0x659800df,0x00000000,0x00000000}},	//   _iňňe_, וינק, --, --, 
   {{0xddd8005f,0xa0a0fff7,0x00000000,0x00000000}},	//   _gluž, _тард, --, --, 
   {{0xbcfc00c7,0x6280054e,0x00000000,0x00000000}},	//   _irũn, _înot, --, --, 
   {{0x7c20007f,0xda740395,0x00000000,0x00000000}},	//   _fdlr, тящ_, --, --, 
   {{0x81b00f22,0x00000000,0x00000000,0x00000000}},	//   য়েক_, --, --, --, 
   {{0x442001ab,0x00000000,0x00000000,0x00000000}},	//   _rdh_, --, --, --, 
   {{0x4420fff8,0x6924fff9,0x81d800fe,0x66dc0064}},	//   _sdh_, _амда, াশত_, _rūks, 
   {{0xa2d0fffa,0xd994021a,0x68e8031c,0x66dc00ef}},	//   _भीष्, _لخوا_, _tifd, _sūks, 
   {{0x98a0fffb,0xe3b06f04,0xddd800dc,0x18a0fffc}},	//   _киче, لرز_, _anuś, _качм, 
   {{0xd498fffd,0x60c4037e,0x94180213,0x4420002f}},	//   тря_, _rkjm, nirə_, _vdh_, 
   {{0x92b400c6,0x2c0000dc,0x4420002f,0x1dd006b1}},	//   لحقا, रुतं_, _wdh_, _तरलत, 
   {{0x4420010b,0xf8ac036b,0x941803e3,0x00000000}},	// [16ed0] _tdh_, _ذکی_, hirə_, --, 
   {{0x66dc5c07,0x44200490,0x941803be,0xddd8310a}},	//   _tūks, _udh_, kirə_, _pluž, 
   {{0xa2c000bc,0x8d7400f2,0x00000000,0x00000000}},	//   लवद्, یاها, --, --, 
   {{0x94180213,0x3d9424fc,0xd05c03e3,0x00000000}},	//   dirə_, лиер, _mirə, --, 
   {{0xbd44fffe,0xd05c06be,0x918414fb,0x00000000}},	//   اپتى, _lirə, _پۇلۇ, --, 
   {{0xc0c40220,0xed4c04da,0x3bd4010a,0xed540395}},	//   _сәби, سپى_, люйс, уош_, 
   {{0xace4ec89,0xfaa42090,0xdd00e16d,0x7a6801c6}},	//   ымша_, лако, ırım, еийг_, 
   {{0x64880793,0x3978003b,0x00000000,0x00000000}},	//   _büik, есою_, --, --, 
   {{0x13c000bc,0xc5e800cc,0x3cd40064,0x00000000}},	//   _एड्भ, কুতা_, _бжас, --, 
   {{0xe9d450d5,0x5ba40022,0x37740137,0xd05c06be}},	//   ыкы_, _ирез, гымс, _birə, 
   {{0x3dcc016b,0x7a348958,0xda780107,0x81d80154}},	//   _hyew_, _مفاص, _ояд_, াশি_, 
   {{0x3dcc0134,0xd05c0213,0x393400c0,0xda642b9f}},	//   _kyew_, _dirə, _бэкс, _جائي, 
   {{0x07e801d3,0xc9841f5a,0x69a807af,0x00000000}},	//   ٹریٹ_, _вуји, _जेपी, --, 
   {{0x92b0015b,0xe2943d48,0x79880337,0xd05c03b9}},	//   _ওঠে_, ңар_, myew, _firə, 
   {{0x7988ffff,0xd05c0213,0x3dc8025c,0x00000000}},	//   lyew, _girə, żawh_, --, 
   {{0xd1740220,0x12c404c5,0xafe401b9,0x12f40131}},	//   қығы, ্দ্দ, ҳозл, лҗүр, 
   {{0x79890000,0xd05c03b9,0x5574030d,0x00000000}},	// [16ee0] nyew, _zirə, _тӳнт, --, 
   {{0xafe43298,0x65680332,0x00000000,0x00000000}},	//   гозл, _ágha, --, --, 
   {{0xe45404ac,0x3dcc0198,0x94180213,0xdfcc007b}},	//   _גייט_, _ayew_, xirə_, كيك_, 
   {{0xf40801ec,0x79880a49,0x00000000,0x00000000}},	//   _تيگى_, kyew, --, --, 
   {{0x798800ca,0x6df41075,0x0c8400fb,0x1e1000d4}},	//   jyew, _ەكرا, ғыҙм, смія, 
   {{0xdce40724,0x7c2c0198,0x941800ac,0xadb00220}},	//   ılğa, ɗark, tirə_, _құлш, 
   {{0x64880793,0x9b40009a,0x00000000,0x00000000}},	//   _süik, منوو, --, --, 
   {{0x3dcc0204,0x7684003a,0x81b00eac,0xf3e400fe}},	//   _fyew_, _móys, য়েও_, _কভাৰ_, 
   {{0x79881418,0x6c34072d,0xd05c06be,0x6a1001d5}},	//   gyew, _معاذ, _sirə, амқу, 
   {{0x26d8022e,0xd05c06be,0x63b80356,0x00000000}},	//   _shqo_, _pirə, şuni, --, 
   {{0xda9031ee,0x29001c52,0xee680092,0x00000000}},	//   ргөө, ūka_, ተጀርባ_, --, 
   {{0x79881418,0xb78405a2,0x81b00154,0xf98000c7}},	//   byew, рәше_, য়েট_, сҳәо, 
   {{0xe1fc0034,0xe9d000f1,0xd90c00e5,0x00000000}},	//   _znów_, _اغا_, _ٹیپ_, --, 
   {{0x260405f5,0x6f1c0175,0xd05c06be,0x00000000}},	//   _өчиг, kspc, _tirə, --, 
   {{0xc2c40451,0x00000000,0x00000000,0x00000000}},	//   ليسي, --, --, --, 
   {{0x925876ac,0xa80003e0,0x26cc0248,0x00000000}},	//   ласт_, _çıba, _ógo_, --, 
   {{0x926807dd,0x00000000,0x00000000,0x00000000}},	// [16ef0] ырра_, --, --, --, 
   {{0xc0d4001f,0x04880032,0x00000000,0x00000000}},	//   ራችሁ_, _рәми_, --, --, 
   {{0x14b8099f,0x5c001dc8,0xfe7000ec,0x33f8011a}},	//   _حديث_, ەكتە, يگر_, _בהתנ, 
   {{0xdbfc02a0,0xd528002b,0x6288007c,0x00000000}},	//   ॉर्ड_, _kṛpā_, ögod, --, 
   {{0xa1843e1f,0xcd2800f2,0xe1fc012d,0x5184010a}},	//   _сынл, هسون_, _snów_, _лура, 
   {{0xfce40a42,0x009401af,0x00000000,0x00000000}},	//   шоло, _тигэ, --, --, 
   {{0xab600209,0x8ed000fe,0x92d803d4,0x00000000}},	//   şünj, িদজগ, াদৰ_, --, 
   {{0xa8000342,0x00000000,0x00000000,0x00000000}},	//   çınm, --, --, --, 
   {{0xaea00150,0x8e84007b,0x682c022e,0xd52800b8}},	//   _بەني, _القه, _pеdа, _nṛpā_, 
   {{0x798803f9,0x22840254,0x00000000,0x00000000}},	//   ryew, _kõks_, --, --, 
   {{0xf744b863,0x22840037,0x9bd00451,0xb8dc08dd}},	//   шено, _jõks_, _اماڻ, _इद_, 
   {{0x6b7804ac,0x7cf000c7,0x7988007f,0x00000000}},	//   _ברענ, _ẽryr, pyew, --, 
   {{0xc9f50001,0xc8b4e01a,0x22840254,0x00000000}},	//   _اسمع, _گلوک, _lõks_, --, 
   {{0x37e50002,0x2ab8005f,0xa5040354,0x067407d2}},	//   _колг, mība_, рера_, _ۇنىڭ, 
   {{0x249caf5b,0x2ab8005f,0xe0dc02bd,0x2284000d}},	//   _ሃገራት_, lība_, _epòk_, _nõks_, 
   {{0x58840022,0x69a8012d,0x00000000,0x00000000}},	//   _шыҵа, _जेडी, --, --, 
   {{0x2ab800da,0xe1f47e7a,0x502401ec,0xa1844990}},	// [16f00] nība_, ргу_, йзағ, абта_, 
   {{0xa11000db,0x00000000,0x00000000,0x00000000}},	//   توكت, --, --, --, 
   {{0x324407d6,0x41d42aa1,0x8eb40131,0x00000000}},	//   _кенг, _दरअस, مەست, --, 
   {{0xdfcc0597,0x7c2c02a8,0xa234054e,0xd2940a81}},	//   ذين_, ɗari, răţă_, _چُھک, 
   {{0xa2c029d9,0x00000000,0x00000000,0x00000000}},	//   लवर्, --, --, --, 
   {{0xc7b805ce,0x2ab8005f,0xddd801e4,0x798c00a2}},	//   lađe_, dība_, _unuŝ, _ýawy, 
   {{0xee3800f3,0x2c0000dc,0xee300451,0x00000000}},	//   _инв_, रुषं_, _وٽس_, --, 
   {{0xc7b80552,0x7f8401d9,0xb14c02d3,0xad680022}},	//   nađe_, _الٲن, _ምርድዳ, _иабз_, 
   {{0xada50003,0xece90004,0xace801c6,0xac38022e}},	//   _таал, _адал_, _амаа_, _ачех_, 
   {{0x4734537c,0x6d40e1e9,0x00000000,0x00000000}},	//   бнос, mtoa, --, --, 
   {{0xb8fc14cf,0x6d410005,0x98cc07f7,0x1bf80677}},	//   _थी_, ltoa, _सीओए, _סלאב, 
   {{0x38680c09,0x79980882,0x2ab80171,0x00000000}},	//   _ɗari_, ṇānā, bība_, --, 
   {{0x2ab800da,0x6d410006,0x7cd8010b,0x7c2c01e7}},	//   cība_, ntoa, _aňry, _íoró, 
   {{0x442c0639,0xd1f00020,0x29040421,0x6d409172}},	//   ße_, ግኘት_, _itoa_, itoa, 
   {{0x93885042,0xd7ed0007,0x442c6648,0xa5b804d7}},	//   аста_, _фу_, ğe_, ngóz, 
   {{0x442d0008,0x29040421,0x6d410009,0xa6a800db}},	//   şe_, _ktoa_, ktoa, _جاتق_, 
   {{0x51f83c1b,0x00000000,0x00000000,0x00000000}},	// [16f10] рную_, --, --, --, 
   {{0x6d41000a,0x29040451,0xddd8010e,0x3d0c0241}},	//   dtoa, _mtoa_, _anuş, _lówò_, 
   {{0xb6580241,0x44fd000b,0x2ab8005f,0x6d40054e}},	//   _akẹ́, _hì_, zība_, etoa, 
   {{0x44fd000c,0x29040e39,0x6444000f,0x00000000}},	//   _kì_, _otoa_, lfji, --, 
   {{0x44fd000d,0x63b807c4,0x29049e0d,0x4e1804fb}},	//   _jì_, ğunu, _ntoa_, شتند_, 
   {{0x44fd000e,0x8d7415c3,0x64440b21,0xcce46cb9}},	//   _mì_, تاما, nfji, يسوي, 
   {{0x44fd000f,0x29050010,0x6d410011,0x6d44014a}},	//   _lì_, _atoa_, atoa, _äkan, 
   {{0x13b80302,0x2ab800da,0x3d950012,0x246800c0}},	//   יהול_, tība_, _либр, lėmė_, 
   {{0x44fc110e,0x1c0873c6,0x6d40084c,0xcaa40597}},	//   _nì_, _स्थल_, ctoa, تصوي, 
   {{0x2ab800da,0x6d5c0882,0xb4e40490,0x385801f0}},	//   rība_, āpat, _फळे_, урию_, 
   {{0xf7708971,0x29040086,0x6444002d,0x2ab800e2}},	//   ساد_, _etoa_, dfji, sība_, 
   {{0x44fd0013,0x8cf40150,0xaf74008f,0x2ab800e2}},	//   _bì_, _اكەش, צערס_, pība_, 
   {{0x44fc0268,0xddc80034,0x23a4022e,0x7bcc0112}},	//   _cì_, legł, _rеja_, ßauf, 
   {{0x44fc0c95,0x375800d8,0x00000000,0x00000000}},	//   _dì_, _бриџ_, --, --, 
   {{0x64a00588,0x6d40009d,0x24680153,0xf650007b}},	//   чара, ztoa, dėmė_, _فئة_, 
   {{0x44fc0248,0x8704027d,0x6d40e481,0x00000000}},	//   _fì_, _ببول, ytoa, --, 
   {{0x44fd0014,0xc7b8110c,0x6d40005a,0x80b000eb}},	// [16f20] _gì_, rađe_, xtoa, জকন্, 
   {{0x92d80f22,0xfbb800dc,0x4e1000bc,0xe1fc02d2}},	//   াদে_, ेथाम, ार्इ_, _snót_, 
   {{0x44fd0015,0x63b8002f,0xfbc4009f,0x00000000}},	//   _zì_, ßunt, _آڪ_, --, 
   {{0x8c14015b,0x6d410016,0x20cc00db,0xdd8c00ec}},	//   _সাইন_, ttoa, düiu_, ڙون_, 
   {{0x44fc0016,0x0bf40212,0x00000000,0x00000000}},	//   _xì_, оплю, --, --, 
   {{0x6ab06236,0x290403d1,0xa4f800df,0x00000000}},	//   ुक्र, _rtoa_, אלסט, --, 
   {{0x6d410017,0x29041028,0xeb48004b,0x00000000}},	//   stoa, _stoa_, اشتو_, --, 
   {{0x6d410018,0x3e88013d,0x00000000,0x00000000}},	//   ptoa, _кисү_, --, --, 
   {{0xdee030d0,0xab6004a9,0x395c058a,0x497400d4}},	//   _хоти, غۇچى, _csws_, ілос, 
   {{0x44fc0cad,0x48b80154,0x6cc401af,0x00000000}},	//   _rì_, ুগ্র, _уйза, --, 
   {{0x44fd0019,0x7c6402c9,0x00000000,0x00000000}},	//   _sì_, _باقل, --, --, 
   {{0x44fc026c,0x395c0327,0x2b5c0142,0x2cac0175}},	//   _pì_, _fsws_, _istc_, lifd_, 
   {{0x2904009f,0xe5c40108,0xddd801ef,0x25bc0205}},	//   _utoa_, ссно, _kouš, çul_, 
   {{0xfb0800c6,0x44fc01dc,0x92d8009e,0x25bc031c}},	//   _èëè_, _vì_, াদো_, ħul_, 
   {{0x6444000f,0x9ac01418,0x44fc0248,0x00000000}},	//   rfji, ŋŋen, _wì_, --, 
   {{0x44fd001a,0x7c2c0198,0x6444000f,0x00000000}},	//   _tì_, ɗaru, sfji, --, 
   {{0x26c804ce,0xd54805d9,0xd1b80131,0x69d40fac}},	// [16f30] moco_, _هليو_, ماكا_, _øyed, 
   {{0x59ac01d9,0x26c9001b,0x65900131,0x8e24022e}},	//   _जेफर, loco_, _мақу, _shmа_, 
   {{0x1f58005e,0x69a802ab,0x24680153,0x9cc801ec}},	//   _ءﺑﯩﺮ_, _जेसी, rėmė_, қыда_, 
   {{0x26c9001c,0x38780023,0x22480051,0x00000000}},	//   noco_, _ክወስዱ_, _ubck_, --, 
   {{0xb238008f,0xddd801ef,0x00000000,0x00000000}},	//   _דערז, _bouš, --, --, 
   {{0x26c8037e,0xfca800ec,0x3b940798,0x00000000}},	//   hoco_, ڏاڻو_, жјит, --, 
   {{0x3a9811ed,0x26c9001d,0x543c00c8,0x290005f7}},	//   итию_, koco_, טעגא, íkan_, 
   {{0x6d5c0882,0x00000000,0x00000000,0x00000000}},	//   āpar, --, --, --, 
   {{0xe8f5001e,0xddd80010,0x290001e4,0x00000000}},	//   олы_, _fouš, ŭkan_, --, 
   {{0x7d080c8c,0x00000000,0x00000000,0x00000000}},	//   _ites, --, --, --, 
   {{0x26c9001f,0xe4f00406,0x26c00010,0x00000000}},	//   foco_, _इंजि_, čkon_, --, 
   {{0x395c0218,0xa8002258,0x26c800df,0x00000000}},	//   _tsws_, _çına, goco_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7d08009f,0x4ab400cf,0x4c880241,0x00000000}},	//   _mtes, _мөөр, _ṣúgà_, --, 
   {{0xded40020,0x26c90020,0x43741d09,0x00000000}},	//   ሬሽን_, boco_, путт, --, 
   {{0x7d090021,0x26c90022,0x648806be,0x07d8007b}},	//   _otes, coco_, _süit, _اذهب_, 
   {{0x61405267,0x7d090023,0xe294084c,0xf0a90024}},	// [16f40] мета, _ntes, цат_, акал_, 
   {{0xfe7405f5,0x2ed00c00,0xc7b807f5,0x00000000}},	//   үүр_, तत्त, lađa_, --, 
   {{0x7d090025,0xddd8013a,0xf4b40116,0x00000000}},	//   _ates, _rouš, _ﭼﯜﺷﻜ, --, 
   {{0x0ddc044e,0x12d803d4,0xfee8007b,0xddd801ef}},	//   _ሕሉፍ_, _দূৰদ, معنى_, _souš, 
   {{0x7d08d6a6,0xddd800bc,0x442440ec,0x2cac007f}},	//   _ctes, _pouš, _ظریف, tifd_, 
   {{0xc7b805a1,0x59240327,0x7d080118,0xafe401d5}},	//   hađa_, _ལྗེས_, _dtes, _ҳоҳл, 
   {{0x7d090026,0x26c90027,0xaae4007b,0x00000000}},	//   _etes, yoco_, يسبو, --, 
   {{0x7d080023,0x2c08015b,0xffa401c6,0xdee0022e}},	//   _ftes, রণেই_, _элсү, _жоси, 
   {{0x26c90028,0x386400ca,0x1d050029,0xad6400f2}},	//   voco_, fdlr_, _мети_, _بازه, 
   {{0xa4980699,0x47342cfe,0x26c800f2,0xab281b11}},	//   npòt, пнос, woco_, _вожа_, 
   {{0xaa440209,0x26c8037e,0x00000000,0x00000000}},	//   _межл, toco_, --, --, 
   {{0xc7b8071b,0x56949e78,0x7d080857,0x49a401af}},	//   gađa_, дают, _ytes, _нылғ, 
   {{0x26c9002a,0x95386988,0x06c8009d,0x00000000}},	//   roco_, озят_, игүй_, --, 
   {{0xfbd000dd,0xd4982db7,0x26c9002b,0x47bc00cc}},	//   _آتے_, орс_, soco_, _উৰণী, 
   {{0xc7b81505,0x69d4e73f,0x1368016c,0x26c804ce}},	//   bađa_, _øyeb, ошти_, poco_, 
   {{0x7df406be,0x00000000,0x00000000,0x00000000}},	//   _məsç, --, --, --, 
   {{0xd130009f,0x6d540205,0x00000000,0x00000000}},	// [16f50] َمِ_, çyal, --, --, 
   {{0x84c40304,0x4614015e,0x6008009d,0xd13000e5}},	//   _хәмд, _بوکر, рхаг_, کمے_, 
   {{0x7d09002c,0xded4001f,0x3ae00022,0x00000000}},	//   _stes, ሬሽኑ_, lópe_, --, 
   {{0xe0dc02bd,0x92580c9e,0x7f45002d,0x1ea800ec}},	//   _apòt_, _дают_, rthq, جائي_, 
   {{0x69a802ab,0x00000000,0x00000000,0x00000000}},	//   _जेली, --, --, --, 
   {{0x4c840953,0xa49835f5,0x20cc04cc,0x6d5c3e16}},	//   млів, mpòs, rüis_, āpap, 
   {{0xb1840267,0x88c00183,0x3ae000e4,0x00000000}},	//   _tvåå, উতাক, hópe_, --, 
   {{0x7d08025c,0xed1401d3,0x3ae0035b,0x00000000}},	//   _ttes, _کہوں_, kópe_, --, 
   {{0x3ead002e,0x7d084e97,0x3ea4053f,0x2eec0204}},	//   _imet_, _utes, _диңг, ïffe_, 
   {{0xe8f44cf9,0x3eac00a2,0x8d7402f2,0xa80073d8}},	//   яль_, _hmet_, _تافا, _çıla, 
   {{0xa820004b,0x3eac0427,0x36680354,0xd6c40075}},	//   رکون, _kmet_, бано_, динқ, 
   {{0xdb0c0588,0xfaa412e9,0xa6800f06,0x00000000}},	//   _ñeña, _عجای, елюд, --, 
   {{0xc7b808a4,0xe9441bf4,0x00000000,0x00000000}},	//   rađa_, _فروی, --, --, 
   {{0x3eac0175,0x6288007c,0x00000000,0x00000000}},	//   _lmet_, ögon, --, --, 
   {{0x67002208,0x3ead002f,0xe4d50030,0xe2783ad0}},	//   _रूपक_, _omet_, سوفت_, әшсә_, 
   {{0x7ae90031,0xe61c01f1,0x66e0311c,0x629c047e}},	//   nmet, skôr_, _поща, ghqo, 
   {{0x27e00034,0x7ae90032,0xd5b00014,0xb9d80092}},	// [16f60] ękne_, imet, _شہس_, _ቼክ_, 
   {{0x7ae90033,0x3ead0034,0xc32c0131,0x69c800a2}},	//   hmet, _amet_, _ھەق_, _üleş, 
   {{0x7ae90035,0x00000000,0x00000000,0x00000000}},	//   kmet, --, --, --, 
   {{0xde00b16f,0x7ae90036,0xdfcc12e3,0xe0dc007f}},	//   епци, jmet, ديم_, _spòt_, 
   {{0x7ae90037,0xa498180f,0x752404cc,0x00000000}},	//   dmet, mpòr, nskz, --, 
   {{0x3ead0038,0x7ae90039,0xdca073da,0x00000000}},	//   _emet_, emet, начи, --, 
   {{0x7c64006c,0xafe48fa3,0x00000000,0x00000000}},	//   بانل, _ховл, --, --, 
   {{0x7ae9003a,0x00000000,0x00000000,0x00000000}},	//   gmet, --, --, --, 
   {{0x6cd5003b,0x8c880139,0x6e200327,0x00000000}},	//   _فقرا, _мәка_, maob, --, 
   {{0x26c004b9,0x7ae9003c,0x7c65003d,0x6e20f6a7}},	//   čkom_, amet, _يالل, laob, 
   {{0x7ae9003e,0x97200598,0x868c02d3,0x9ac00337}},	//   bmet, ньяд, _ዕረፍቲ_, ŋŋan, 
   {{0x6e2001f7,0x7ae9003f,0x7b6401d9,0x96080006}},	//   naob, cmet, _زامٕ, зэра_, 
   {{0x84c4070e,0x8e2001ec,0x00000000,0x00000000}},	//   дәнд, дiк_, --, --, 
   {{0x3ae10040,0x6fbc1fbc,0xefd40092,0x6e204230}},	//   rópe_, ्थां, ያርድ_, haob, 
   {{0x6e2001f7,0x2a6400c5,0xf8a804fb,0x4ab0482a}},	//   kaob, _kaob_, _بدنه_, _जगाव, 
   {{0xd7b80375,0x6e210041,0xba3c0118,0xe21400dc}},	//   _לצור, jaob, chůd, तरेण_, 
   {{0xdce90042,0xc1b801c6,0x00000000,0x00000000}},	// [16f70] _žičk, цлах_, --, --, 
   {{0x66dc0006,0x3eac4087,0x2a640254,0xa49800e4}},	//   _rūky, _smet_, _laob_, apòr, 
   {{0x7ae90043,0x6e2005da,0x661c0023,0xa4980ba1}},	//   ymet, faob, _keqk, spòs, 
   {{0x98bc00b0,0xcf980063,0xd548335b,0x00000000}},	//   ituā_, чју_, _بلیو_, --, 
   {{0x673883ad,0x7ae8004e,0x00000000,0x00000000}},	//   hutj, vmet, --, --, 
   {{0x67390044,0xd1f0001f,0x657803cd,0x00000000}},	//   kutj, _ጀርባ_, øuhy, --, 
   {{0x26c004b9,0x67390045,0x6e200419,0x89140022}},	//   čkoj_, jutj, baob, ҕьыц, 
   {{0xb3a800bd,0x2a6400a3,0x6e20c50b,0x00000000}},	//   _খুঁজ, _caob_, caob, --, 
   {{0x6ef80316,0x8afc0153,0x00000000,0x00000000}},	//   _vůbe, _bręs, --, --, 
   {{0x20bc00dc,0xf86801f7,0x8afc012d,0xbb58014b}},	//   ्विध, آمدي_, _pręt, _мазх_, 
   {{0x6e2800d2,0x67390046,0x2c00033f,0xe7f4033f}},	//   _úmbî, gutj, रुओं_, ूँगा_, 
   {{0x7ae80175,0xa9b400ec,0x00000000,0x00000000}},	//   qmet, _ڪشمڪ, --, --, 
   {{0x20bc12eb,0x00000000,0x00000000,0x00000000}},	//   ्वाध, --, --, --, 
   {{0x67390047,0x59240135,0x8afc0064,0x00000000}},	//   butj, _ལྗགས_, _gręs, --, 
   {{0x67390048,0x00000000,0x00000000,0x00000000}},	//   cutj, --, --, --, 
   {{0x15280131,0x25e80073,0x27b00022,0x6fbc041c}},	//   _ениқ_, घेही_, _шәыс, ्थसं, 
   {{0x6e209597,0xa498067c,0x847c001f,0x5eb000cc}},	// [16f80] vaob, rpòr, ፖሬሽን_, টকাই, 
   {{0xd5c40055,0xa498067c,0x00000000,0x00000000}},	//   _ekāü_, spòr, --, --, 
   {{0xb4d80034,0xdfcc00c6,0x6e210049,0xe478011a}},	//   ़ती_, ليك_, taob, _וריכ, 
   {{0xed58013e,0xffa4009d,0x00000000,0x00000000}},	//   жод_, элхү, --, --, 
   {{0xfee80491,0x6e2014d0,0xfe780316,0xed5840bb}},	//   أعلى_, raob, _dnů_, تشات_, 
   {{0xabb00598,0x6e2000f3,0x00000000,0x00000000}},	//   калә, saob, --, --, 
   {{0x5f0000d1,0x9b401e4b,0x6e200419,0x00000000}},	//   _азса, ننوو, paob, --, 
   {{0x63a000dd,0x26c000f3,0x00000000,0x00000000}},	//   _ünne, čkok_, --, --, 
   {{0xa8000ab7,0xdd8c3c22,0x8afd004a,0xddd8013a}},	//   _çıka, _پول_, _pręs, _pouť, 
   {{0x67380240,0xacb000f7,0xe7e401ef,0x00000000}},	//   tutj, _جەتب, _věžá, --, 
   {{0x2a65004b,0x2dd401ec,0x2a08009b,0xdc24009f}},	//   _taob_, _ﺘﻜﻠﻤ, _дееп_, _آڳهه_, 
   {{0xbcfc00e4,0x00000000,0x00000000,0x00000000}},	//   _irũr, --, --, --, 
   {{0x9ac801d3,0x67380010,0x2b90335b,0x00000000}},	//   _بدلہ_, sutj, _سیکس, --, 
   {{0x67380023,0x3ae000c7,0x00000000,0x00000000}},	//   putj, mópa_, --, --, 
   {{0x88b001d3,0x042000eb,0x00000000,0x00000000}},	//   _لیکچ, _বাদী_, --, --, 
   {{0xd2580556,0xa49800e4,0x00000000,0x00000000}},	//   мцу_, apòp, --, --, 
   {{0xe4a4009b,0x00000000,0x00000000,0x00000000}},	// [16f90] _жрно, --, --, --, 
   {{0xfe780118,0xc0d5004c,0x00000000,0x00000000}},	//   _snů_, ያችሁ_, --, --, 
   {{0x442006a3,0x2d9008fb,0x3ae001a8,0x00000000}},	//   _ieh_, øyen_, hópa_, --, 
   {{0x4421004d,0x3ae00022,0x00000000,0x00000000}},	//   _heh_, kópa_, --, --, 
   {{0x44202b10,0x13e400fe,0x00000000,0x00000000}},	//   _keh_, _মলয়, --, --, 
   {{0x44209d34,0xdb20036b,0x00000000,0x00000000}},	//   _jeh_, نوتی, --, --, 
   {{0x44200842,0x00000000,0x00000000,0x00000000}},	//   _meh_, --, --, --, 
   {{0x4421004e,0xd024000e,0x00000000,0x00000000}},	//   _leh_, _পায়_, --, --, 
   {{0x3f8c01f2,0x4421004f,0x9ac004ba,0x656c022e}},	//   ̣kụ_, _oeh_, ŋŋon, jvch, 
   {{0x44210050,0x7e690051,0x778400f3,0xf77016a2}},	//   _neh_, _haep, елоз, هاج_, 
   {{0x7c20002d,0x69d42c95,0x7e690052,0x3668188b}},	//   _ielr, _øyen, _kaep, пано_, 
   {{0xeb941a4c,0x44200438,0xa5b90053,0x7e680254}},	//   _אדער_, _aeh_, raón, _jaep, 
   {{0x7e6802ce,0x94745b2c,0x27e00034,0x7c200064}},	//   _maep, نگدا, ękna_, _kelr, 
   {{0x44200399,0x7e680007,0xb4d82aa1,0x8afc0210}},	//   _ceh_, _laep, ़ते_, _kręp, 
   {{0x44200574,0x7c210054,0xa3e401af,0x3cf8012d}},	//   _deh_, _melr, едра_, _ोंने_, 
   {{0x75440212,0x38c80244,0x66ec0055,0x00000000}},	//   _зниз, _باڤی_, _ṛkva, --, 
   {{0x44210055,0x85640022,0x00000000,0x00000000}},	// [16fa0] _feh_, _аныҧ, --, --, 
   {{0x44210056,0xe0d50057,0x92080055,0xddd800de}},	//   _geh_, еву_, _bhāñ, _kauņ, 
   {{0x7e681a83,0xd1d4001f,0xceb8010b,0x00000000}},	//   _baep, ያውቁ_, җәң_, --, 
   {{0x7e680e17,0x7af90058,0x4420002f,0x00000000}},	//   _caep, _niwt, _zeh_, --, 
   {{0xccf81884,0x7c20014f,0xe2950059,0xe0400131}},	//   дқа_, _belr, _чая_, _әнси, 
   {{0x7c2000cf,0xcb3400a7,0x9c540114,0x00000000}},	//   _celr, векъ, ешћу_, --, 
   {{0x7e69005a,0x9fc4009b,0xd9140022,0x00000000}},	//   _faep, _згра_, ҕьы_, --, 
   {{0x7e69005b,0x7c21005c,0x00000000,0x00000000}},	//   _gaep, _eelr, --, --, 
   {{0x7c205013,0x7af8015d,0x63a4031c,0x00000000}},	//   _felr, _diwt, zzjn, --, 
   {{0x7c204fa5,0x3ae1005d,0xb8641617,0x88943eae}},	//   _gelr, rópa_, ناپو, тиох, 
   {{0x44200842,0x7e680007,0x8cc40075,0xddd80171}},	//   _reh_, _yaep, _كەچۈ, _cauņ, 
   {{0x4421005e,0xa9a5005f,0x3ae000e4,0xc72400db}},	//   _seh_, _пиед, pópa_, ндүй, 
   {{0xa850eabc,0x44200134,0x1ae00212,0x56940150}},	//   _белә, _peh_, _соцм, уаят, 
   {{0x4420e0a1,0x00000000,0x00000000,0x00000000}},	//   _qeh_, --, --, --, 
   {{0xd7710060,0x44210061,0xd1d4001f,0x00000000}},	//   _مايع, _veh_, ያውቅ_, --, 
   {{0x44203386,0x85745735,0x00000000,0x00000000}},	//   _weh_, _алих, --, --, 
   {{0x44210062,0x25b4066d,0x7e7c0268,0x7e690063}},	// [16fb0] _teh_, _سندھ_, _òspi, _raep, 
   {{0x7e690064,0x44210065,0x2ab8005f,0x518400fb}},	//   _saep, _ueh_, mību_, ыуса, 
   {{0x7e690066,0x2ab8005f,0x7aec00d0,0x00000000}},	//   _paep, lību_, ňati, --, 
   {{0x1ee400f2,0xe2a81f0d,0x00000000,0x00000000}},	//   روشی_, _راجن_, --, --, 
   {{0x4fc4005e,0x2ab800da,0x7c20beaa,0x7e690067}},	//   _ұста, nību_, _pelr, _vaep, 
   {{0x7e68a538,0x7af8015d,0x00000000,0x00000000}},	//   _waep, _siwt, --, --, 
   {{0x9f450068,0x628d0069,0xfaa463e3,0x7e68ff5c}},	//   änä_, _koco, како, _taep, 
   {{0x7c20017a,0x7520010e,0xfd74009d,0x00000000}},	//   _welr, _çozg, _илбэ, --, 
   {{0x628d006a,0x69d40212,0xa920ea10,0xaa540114}},	//   _moco, _øyel, адыл, тињу_, 
   {{0x628d006b,0x2ab8005f,0xb90801ad,0x00000000}},	//   _loco, dību_, _मठ_, --, 
   {{0xe8c40323,0x7af9006c,0xbb9800e5,0xda7800c0}},	//   тгэл_, _tiwt, _تناؤ_, _няд_, 
   {{0xe1fd006d,0xc4c80375,0x00000000,0x00000000}},	//   _ngó_, _וג_, --, --, 
   {{0x29d0182f,0xf864039b,0xe8ed006e,0xae200037}},	//   _پيوس, _авло, _вл_, मरतन_, 
   {{0xe1fc01e7,0x98c4026b,0x00000000,0x00000000}},	//   _agó_, _ясел, --, --, 
   {{0x394d006f,0x628c008b,0x32d405f5,0xefd40023}},	//   ltes_, _boco, вцас, ያይዳ_, 
   {{0x628d0070,0x394d0071,0xa2800101,0x2ab80171}},	//   _coco, otes_, لیپو, bību_, 
   {{0x2ab80029,0x628c07ad,0x042000eb,0x00000000}},	// [16fc0] cību_, _doco, _বারী_, --, 
   {{0xe1fc032e,0xd2500050,0x00000000,0x00000000}},	//   _egó_, _گۆر_, --, --, 
   {{0x6498b4a1,0x394d0072,0x26c0994e,0xc6240154}},	//   _חסיד, htes_, čkov_, _ভাতা_, 
   {{0x394d0073,0x628d0074,0xd25001d9,0x00000000}},	//   ktes_, _goco, _دۆر_, --, 
   {{0x394d0075,0x11f800f2,0x752000a2,0x00000000}},	//   jtes_, _سوسک_, _çozd, --, 
   {{0xdd910076,0x394d0077,0x628c0077,0x645801a6}},	//   рашы, dtes_, _zoco, đuig, 
   {{0x2ab8005f,0x628d0078,0x91c400d1,0x00000000}},	//   zību_, _yoco, _рәңл, --, 
   {{0x394d0079,0x628c00f7,0x00000000,0x00000000}},	//   ftes_, _xoco, --, --, 
   {{0x394d007a,0x2900006a,0xec4800ee,0x8d680092}},	//   gtes_, êka_, _озал_, _ታይቷል_, 
   {{0xa784034c,0xc7b80552,0x7c640228,0x9871007b}},	//   نشجو, lađi_, _مامل, альц, 
   {{0x394d007c,0x27e0033f,0x6a8401a9,0x00000000}},	//   ates_, ękno_, _илжа, --, 
   {{0xc7b87238,0x394d007d,0x2ab800da,0xaab836fe}},	//   nađi_, btes_, tību_, _غدار_, 
   {{0x394d007e,0x628d007f,0x6aa10080,0xd9410081}},	//   ctes_, _roco, _ilof, _вечи, 
   {{0x628d0082,0x2ab8005f,0x98a00114,0x00000000}},	//   _soco, rību_, _виље, --, 
   {{0x628d0083,0x2ab800da,0x6d5c0882,0x6aa10084}},	//   _poco, sību_, āpay, _klof, 
   {{0x92590085,0xc7b8036b,0x67380010,0x3f840327}},	//   каст_, _оёқ_, mrtj, _ħlu_, 
   {{0x628c0393,0x626400f2,0x80790086,0x00000000}},	// [16fd0] _voco, _یاحق, нбас_, --, 
   {{0x26c00232,0x673827bb,0x6aa00368,0x628c1bf4}},	//   čkou_, ortj, _llof, _woco, 
   {{0x6aa10087,0x628d0088,0x4394c066,0x25b401ed}},	//   _olof, _toco, _санс, _سنگھ_, 
   {{0x394c7a9c,0x76540175,0x3b8401b9,0x673803b2}},	//   ytes_, _xbyy, ғлиг, irtj, 
   {{0x394d0089,0x5185008a,0x69c4000f,0x644000e5}},	//   xtes_, _кура, ûkel, _önis, 
   {{0x6aa0f404,0x00000000,0x00000000,0x00000000}},	//   _alof, --, --, --, 
   {{0x6aa1008b,0x394c0204,0x00000000,0x00000000}},	//   _blof, wtes_, --, --, 
   {{0x394d008c,0x6aa00142,0x67380010,0x00000000}},	//   ttes_, _clof, drtj, --, 
   {{0x394d008d,0x66f8002e,0x67380af4,0x43480023}},	//   utes_, _aŋko, ertj, _ዝግበኣ, 
   {{0x6aa017b5,0xba3c01ef,0x00000000,0x00000000}},	//   _elof, chůn, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x394d008e,0x6aa1008f,0x8c3c0139,0x64882ca8}},	//   ptes_, _glof, _ilğa, _güiz, 
   {{0x67381af3,0x3b04022e,0xaa4000db,0xddd8013a}},	//   artj, _hulq_, _اچىى, _louž, 
   {{0xf74416c3,0xf770158b,0xc76419c5,0x00000000}},	//   _беко, _هاب_, _چايى, --, 
   {{0xc8b40014,0x00000000,0x00000000,0x00000000}},	//   _خلوک, --, --, --, 
   {{0xb3d033ff,0x3dc80210,0x3634104c,0x00000000}},	//   _दुःख, żawy_, _صربس, --, 
   {{0x307407e6,0xf1d05bc9,0xdb0000d7,0xc8780139}},	// [16fe0] лужс, сөнө, dzní, llğa_, 
   {{0xb464034b,0x00000000,0x00000000,0x00000000}},	//   _скол, --, --, --, 
   {{0xee3853cb,0xef1806bb,0x6ee801ef,0x00000000}},	//   ене_, хме_, hýbe, --, 
   {{0x7644138f,0xb8e40003,0xe7f405d7,0x2ab801e1}},	//   ngky, _ཉམ_, ुखता_, _màbè_, 
   {{0x8c3c0724,0xc7b8009b,0x3af00064,0xaa8000e4}},	//   _alğa, rađi_, _lšps_, ñými, 
   {{0xdb8005f5,0x40941614,0x6aa10090,0x20040419}},	//   өгчи, _крст, _slof, ľnic_, 
   {{0x6aa10091,0xddd80882,0x2004488c,0xbc7000cf}},	//   _plof, _kauś, žnic_, تۇلب, 
   {{0x69d400d4,0xaae400c6,0x6738107d,0x43480023}},	//   _øyek, دستو, vrtj, _ዝግባኣ, 
   {{0x5e900597,0xacc80124,0xa5b800c7,0xd92401c6}},	//   _القط, _згаз_, mbóg, лцэл_, 
   {{0x434802d3,0xe7841171,0x00000000,0x00000000}},	//   _ዝግብኣ, гумо, --, --, 
   {{0xd7f42ecc,0xda6c68cc,0x6d4001ee,0x6738d2aa}},	//   лую_, _ля_, luoa, urtj, 
   {{0x59ac033d,0x6aa00418,0xa3b8000d,0xd1d001f3}},	//   _जेकर, _ulof, _आइब_, ጥራት_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x290406c8,0x673809a8,0x442400c6,0xe3b01079}},	//   _iuoa_, prtj, úl_, مرز_, 
   {{0x3b0401d5,0x3dc8025c,0x00000000,0x00000000}},	//   _xulq_, żawx_, --, --, 
   {{0xadf41533,0x6d4001ee,0x290400ec,0x3f8406af}},	//   ेशान_, kuoa, _kuoa_, _àlui_, 
   {{0xbbe00316,0xf8ad0092,0x961802eb,0x80b40408}},	// [16ff0] _फर्क, _رکی_, _صغير_, абах, 
   {{0xddd80745,0x55ac008f,0xfe7801ef,0x00000000}},	//   _použ, _נייַ, _lhůt_, --, 
   {{0x7cecdd69,0x00000000,0x00000000,0x00000000}},	//   lúrg, --, --, --, 
   {{0xc2440228,0x64440023,0x75e001f2,0xddd80055}},	//   _өнүк, lgji, ịzes, _gauś, 
   {{0x69d403cd,0x8e080212,0x00000000,0x00000000}},	//   _øyeh, унів_, --, --, 
   {{0x64450093,0xc0c50094,0xc7b800f3,0xddd800bc}},	//   ngji, _тәби, lađu_, _touž, 
   {{0x29040421,0xd4980302,0x7a6801c0,0x7f946da0}},	//   _auoa_, רכות_, вийг_, _тавх, 
   {{0x290400fb,0x6d40079b,0xc7b80552,0x26d801e2}},	//   _buoa_, buoa, nađu_, _nkqo_, 
   {{0xedd80116,0x5c740166,0xf4240154,0xada000d7}},	//   _алтә_, _бәйр_, _বাসর_, čúco, 
   {{0x0ba40724,0x6444002d,0x2bd4012c,0x88c80209}},	//   ршәм, jgji, _ढुवा, лкың_, 
   {{0x29001f60,0x37e50095,0x00000000,0x00000000}},	//   íkar_, ронг, --, --, 
   {{0x29040032,0x2248009f,0x60d802d2,0xcfb80150}},	//   _fuoa_, _ncck_, _íumf, _ﺤﺒﻴﺒ, 
   {{0x6444036e,0xd3480066,0x00000000,0x00000000}},	//   fgji, گیجه_, --, --, 
   {{0x49b8528e,0x74150096,0x6444cade,0xdbcc00bc}},	//   _حامد_, شورا, ggji, _lžíc, 
   {{0xd348141b,0xe3b406a6,0x60d402d0,0xb6a4030d}},	//   دیجه_, абр_, doxm, _вийл, 
   {{0xf1a8004b,0x74240f22,0x00000000,0x00000000}},	//   پاره_, বলেট_, --, --, 
  
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [17000] --, --, --, --, 
   {{0x659808a8,0x6d400108,0xc56401c8,0x00000000}},	//   _סייק, vuoa, _اُٿي, --, 
   {{0xa06423c5,0x643802e4,0x2e482081,0xe45400d9}},	//   раха_, _בעינ, вяло_, _דייט_, 
   {{0x6d410097,0xa3b80b26,0x200400d7,0x7ed4003b}},	//   tuoa, _आइत_, ľnia_, бічч, 
   {{0x20040419,0x00000000,0x00000000,0x00000000}},	//   žnia_, --, --, --, 
   {{0x290401ee,0x6d410098,0x69d40fac,0x1db44709}},	//   _ruoa_, ruoa, _øyei, _अधरत, 
   {{0x6d4001af,0xfca8004b,0x00000000,0x00000000}},	//   suoa, دانو_, --, --, 
   {{0x290406c8,0x6d4001af,0x64440023,0x5bc02374}},	//   _puoa_, puoa, zgji, تقىل, 
   {{0x6d40036e,0x64440200,0xc62400eb,0x994400ae}},	//   quoa, ygji, _ভালা_, لليل_, 
   {{0xeb9800c7,0x994401d5,0x9d1800df,0x00000000}},	//   _ииз_, گلیل_, _סובט, --, 
   {{0xdcac1823,0xa098010f,0x6444036e,0x00000000}},	//   _تىل_, דייט, vgji, --, 
   {{0x7ced0099,0x2b5c067c,0xd6d8084c,0xd7f4008e}},	//   túrg, _iptc_, итя_, шуы_, 
   {{0xb86401d3,0x7e7c032e,0x00000000,0x00000000}},	//   _گانو, _óspe, --, --, 
   {{0x7cecfef1,0x00000000,0x00000000,0x00000000}},	//   rúrg, --, --, --, 
   {{0x6444067d,0x09d80729,0x53340d5c,0xb865009a}},	//   rgji, দেশা, жест, _دانو, 
   {{0x64440200,0x00000000,0x00000000,0x00000000}},	//   sgji, --, --, --, 
   {{0xe4e42626,0xc7b808a4,0x246c0092,0x00000000}},	// [17010] _вінн, rađu_, ስቀረት_, --, 
   {{0x042002a6,0x80d00574,0x75200432,0x2ab800c0}},	//   _বাকী_, तकें, _çoza, kūbo_, 
   {{0x7fb9009b,0xddc801ed,0xfd74009d,0x00000000}},	//   دهار_, vegő, өлжэ, --, 
   {{0xdb000122,0x01d801d5,0xe61c011f,0x00000000}},	//   jzná, _موجع_, nbô_, --, 
   {{0x2b5c0607,0xa1841945,0x79880327,0xc02401e2}},	//   _aptc_, _тынл, xxew, _هډاي, 
   {{0x8d74021a,0x4094007b,0x7cec00d7,0x00000000}},	//   غانا, _الآر, kúre, --, 
   {{0x6c303be1,0x8f3407c6,0x7988002e,0x8b643769}},	//   سفيا, _мерц, wxew, قايم, 
   {{0x8d7401d9,0x38a9009c,0x7f44014f,0x00000000}},	//   _ژالا, _múre_, muhq, --, 
   {{0x2b5c00d8,0xba7402f2,0x00000000,0x00000000}},	//   _eptc_, لاکت, --, --, 
   {{0xcd5002d3,0x0c84010b,0x3ebc0042,0x00000000}},	//   _ዘልኣለ, _мыхм, liwt_, --, 
   {{0x7d09009d,0x7ced009e,0x00000000,0x00000000}},	//   _hues, gúre, --, --, 
   {{0x7d0017c1,0x7d0830b5,0x81ac015b,0x3ae800f2}},	//   _hils, _kues, _কখন_, _صبای_, 
   {{0x7d01009f,0x98900131,0xe29c03b2,0x7f440455}},	//   _kils, _мукә, _miðd_, huhq, 
   {{0x7d08db58,0xa5041768,0x3a2c0399,0x7d000139}},	//   _mues, сера_, laep_, _jils, 
   {{0x6ee802fb,0x9ac004ba,0x7d0900a0,0xf504013e}},	//   hýba, ŋŋun, _lues, рзҳо, 
   {{0x7d0900a1,0x55c4054a,0xf6240276,0x386455ef}},	//   _oues, _майғ, _удио, lelr_, 
   {{0x7d084888,0x7d000857,0xe80c00e1,0x00000000}},	// [17020] _nues, _oils, _सलमा_, --, 
   {{0x7d003402,0x200401a6,0x00000000,0x00000000}},	//   _nils, žnin_, --, --, 
   {{0x7d0900a2,0x69d4003b,0x00000000,0x00000000}},	//   _aues, _øyev, --, --, 
   {{0xdfcd00a3,0xdd8c59d4,0x7d0100a4,0x78a00175}},	//   رين_, کوه_, _ails, hklv, 
   {{0x7d0828f2,0x2b5c37b6,0x3a2c0369,0x225c02d1}},	//   _cues, _sptc_, daep_, _ñuka_, 
   {{0x7d0900a5,0x7d00cae1,0x999c00a2,0x00000000}},	//   _dues, _cils, mbuň_, --, 
   {{0x7d0100a6,0x3ebc0142,0x00000000,0x00000000}},	//   _dils, biwt_, --, --, 
   {{0x7d0900a7,0x7d0100a8,0x3a2c0399,0xa3b802ab}},	//   _fues, _eils, gaep_, _आइस_, 
   {{0x7d00046b,0xfe9001d5,0x3be81de6,0x00000000}},	//   _fils, _تینج, лләү_, --, 
   {{0xdb0000f8,0x4734ff8f,0x8afc0034,0x2b5c0100}},	//   szná, онос, _spęd, _tptc_, 
   {{0x7d0900a9,0x7cec0798,0xddd80166,0x00000000}},	//   _zues, búrb, _kauş, --, 
   {{0xaae42bd8,0x7d0001c7,0x38a800d0,0x00000000}},	//   _اسطو, _zils, _rúre_, --, 
   {{0xe61c003a,0xd6d80262,0x7d0001d5,0xdbe008a5}},	//   rbô_, стэ_, _yils, _héði, 
   {{0x7d000014,0xe61c0548,0x7cec00cf,0x00000000}},	//   _xils, sbô_, múrc, --, 
   {{0xd7ed00aa,0x321405db,0xa7300510,0xd8701fb8}},	//   _ху_, _ọnụ_, _эдйә, _راوب, 
   {{0xf7080051,0x00000000,0x00000000,0x00000000}},	//   _kần_, --, --, --, 
   {{0x38a801e1,0x00000000,0x00000000,0x00000000}},	// [17030] _wúre_, --, --, --, 
   {{0x51f8b0b9,0xf708004d,0x1ea80451,0x6ee802f0}},	//   сную_, _mần_, گائي_, výba, 
   {{0xf70801dc,0x7d08096b,0xb65801e1,0x3a2c0369}},	//   _lần_, _sues, _ajẹ́, yaep_, 
   {{0x7d0900ab,0x7d0100ac,0x1ea830bf,0x3f84025c}},	//   _pues, _sils, دائي_, _ġlud_, 
   {{0x7d0900ad,0x7d000029,0xfc0458a8,0xf708004d}},	//   _ques, _pils, опло, _nần_, 
   {{0x7d08204e,0x7d0100ae,0xa6cc09bd,0xdcf800df}},	//   _vues, _qils, রতিট, _kruĉ, 
   {{0x7d080221,0x9cc800c7,0x6d44007c,0x00000000}},	//   _wues, _ҩыза_, _åkan, --, 
   {{0x7d0900af,0x7f84001f,0xf708004d,0xcea400d8}},	//   _tues, _አሸናፊ_, _bần_, _ејуп, 
   {{0xf70801dc,0x7d0100b0,0x7d08007d,0x2d90119a}},	//   _cần_, _tils, _uues, øyet_, 
   {{0xf7080016,0xfb8402f2,0x7d0100b1,0x00000000}},	//   _dần_, _ودای, _uils, --, 
   {{0x5ba500b2,0xe8f40024,0xbb2800d1,0xddd80166}},	//   _ураз, юль_, ﻣﻤﻪ_, _yauş, 
   {{0x38a80332,0xda6500b3,0xf7080051,0xaf74010f}},	//   _búrc_, _دائي, _fần_, קערס_, 
   {{0xf70807ae,0x6ecc01e4,0x00000000,0x00000000}},	//   _gần_, nĝba, --, --, 
   {{0x80b80c58,0x2ea40709,0x00000000,0x00000000}},	//   _অৱস্, _खत्त, --, --, 
   {{0x20040419,0x7784003b,0x00000000,0x00000000}},	//   ľnil_, _єлиз, --, --, 
   {{0x20040306,0x312401b9,0xa5b803b2,0x00000000}},	//   žnil_, ждаг, gaós, --, 
   {{0x514402dd,0x69d40fac,0x1538fb65,0xddd8013d}},	// [17040] ядағ, _øyet, _ازبک_, _rauş, 
   {{0x3364516a,0x3448004e,0x00000000,0x00000000}},	//   _двог, _өчүн_, --, --, 
   {{0xb4d4084a,0xdd8c105d,0x00000000,0x00000000}},	//   िकी_, ێوم_, --, --, 
   {{0x6da4a482,0xa758008f,0xad64007b,0xd25800f1}},	//   يمام, ידער, قاته, _دیرش_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdca100b4,0xf7080208,0x61e8002f,0x00000000}},	//   мачи, _rần_, ügle, --, 
   {{0xf708004d,0xddd80139,0xa5b800c7,0x2aa80114}},	//   _sần_, _tauş, naór, итио_, 
   {{0x2d900fac,0x00000000,0x00000000,0x00000000}},	//   øyes_, --, --, --, 
   {{0x6e2100b5,0x2ee401f5,0x7e7c08ce,0x00000000}},	//   mbob, mlof_, _óspa, --, 
   {{0xa3b8033d,0xf70801fb,0x6e20dedc,0x1c400209}},	//   _आइल_, _vần_, lbob, _онум, 
   {{0x6d4100b6,0x66181bce,0x999c00d7,0x75a400c7}},	//   lroa, ñuko, rguš_, ҿырҧ, 
   {{0xf708001e,0x6d4100b7,0x6e2100b8,0x93e401f9}},	//   _tần_, oroa, nbob, _गरजच_, 
   {{0x6d4100b9,0x9aa003e6,0x2ee40af9,0x98bc0115}},	//   nroa, _زموو, ilof_, zruĉ_, 
   {{0x2ee404e6,0x18640120,0x00000000,0x00000000}},	//   hlof_, _мачи_, --, --, 
   {{0x6d4100ba,0x82240327,0x43940212,0xb4b4010b}},	//   hroa, _འབྱི_, чавс, чирә, 
   {{0x69d500bb,0xc10400c6,0x00000000,0x00000000}},	//   _øyes, كوري, --, --, 
   {{0x200407f5,0xed640020,0x6f1d00bc,0x23d829c8}},	// [17050] žnim_, ደነበር_, eppc, _मुरद, 
   {{0x6d4100bd,0x7cec0321,0x20040174,0x00000000}},	//   droa, kúra, øni_, --, 
   {{0xd9d8013f,0x6d4100be,0x225c0de2,0x7cec0022}},	//   _ɔbɑɑ, eroa, _ñuko_, júra, 
   {{0x443100bf,0x6e2100c0,0xa2801927,0x9f400023}},	//   laz_, gbob, _تیرو, _hyjë_, 
   {{0x6d4100c1,0x443001c4,0x38a80413,0x6d44713c}},	//   groa, oaz_, _lúra_, _åkal, 
   {{0x443100c2,0x6f1c0066,0x50640ce1,0x3b9400d8}},	//   naz_, bppc, _отса, зјит, 
   {{0x6e2100c3,0x7cec2760,0x6d4100c4,0x2d9000ed}},	//   bbob, gúra, aroa, øyer_, 
   {{0x44300097,0x6d4100c5,0x4fc40efb,0xdcf80003}},	//   haz_, broa, _تەمە, _kruċ, 
   {{0x443100c6,0x00000000,0x00000000,0x00000000}},	//   kaz_, --, --, --, 
   {{0x38a80248,0x78a815ed,0x26c800c8,0xddd80e3c}},	//   _búra_, ског_, enco_, _gnuš, 
   {{0xd90c066d,0x7cec0077,0x00000000,0x00000000}},	//   ریں_, cúra, --, --, 
   {{0x3eb405d1,0x55c401ec,0x00000000,0x00000000}},	//   _çatı_, дамғ, --, --, 
   {{0x443100c7,0x69cc0112,0x00000000,0x00000000}},	//   faz_, ßbet, --, --, 
   {{0x443100c8,0xb4d43a37,0x3ae0e59c,0x26c900c9}},	//   gaz_, िके_, rópu_, anco_, 
   {{0x2324036b,0x69d4003b,0xb6a4119e,0x6d400165}},	//   зоси_, _øyer, _никл, zroa, 
   {{0xa5b80077,0x4430020c,0x76244cd0,0x00000000}},	//   mbón, aaz_, _эмиз, --, 
   {{0x44301d59,0xe294355a,0xf708001e,0xb1440953}},	// [17060] baz_, чат_, _mầm_, янал, 
   {{0x443100ca,0xf708001e,0x6360013f,0x92ac00cc}},	//   caz_, _lầm_, _sεne, কচে_, 
   {{0x6e2008cd,0xee840046,0xc1000ed1,0x61ec0175}},	//   tbob, зыло, түрл, _ezcl, 
   {{0x6d4100cb,0x6f1c004e,0x8c3c0205,0xe3b000f1}},	//   troa, rppc, _ilği, _سرپ_, 
   {{0x2ee500cc,0x71f80014,0x6278011a,0x00000000}},	//   rlof_, _دردس_, _הנכנ, --, 
   {{0x6d400323,0x7ced00cd,0xc10400ec,0x00000000}},	//   rroa, túra, _يوٽي, --, 
   {{0x62980077,0x2eb4010b,0xf708004d,0x7f1800c0}},	//   _écoñ, _есас, _bầm_, _міту_, 
   {{0x443100ce,0xf7080016,0xb5380241,0x2aa801e1}},	//   zaz_, _cầm_, _arọ́, _bùba_, 
   {{0x443100cf,0x2aa800a3,0x6f0c0477,0xf708004d}},	//   yaz_, _cùba_, _hubc, _dầm_, 
   {{0xb4d500d0,0x38a8022c,0xe29c2200,0x443100d1}},	//   िको_, _púra_, _miða_, xaz_, 
   {{0x443100d2,0xb4d4012c,0x23d801ad,0x97a0005b}},	//   vaz_, िकै_, _मुंद, ерял, 
   {{0xf70801fb,0x64400790,0x69cc002f,0x00000000}},	//   _gầm_, _öniz, ßbes, --, 
   {{0xe8b40327,0xa5b800e4,0xa42400d4,0x46e800cf}},	//   ྒྲུག, gaóp, зьбл, йдүн_, 
   {{0x684001e1,0x38a900d3,0x44300165,0x200400d7}},	//   _dídà, _túra_, uaz_, ľnik_, 
   {{0x443100d4,0xe7841ee3,0x20041109,0xee14037e}},	//   raz_, _хуло, žnik_, ckｇ_, 
   {{0x44302005,0x92944077,0xe29c1d0e,0x37c00022}},	//   saz_, насц, _biða_, _шәыб, 
   {{0x443100d5,0x657c0309,0x00000000,0x00000000}},	// [17070] paz_, _urqh, --, --, 
   {{0x443003e3,0x00000000,0x00000000,0x00000000}},	//   qaz_, --, --, --, 
   {{0x9f9c002e,0x7b140124,0x741500d6,0x2258020c}},	//   _kéém_, _oġua, _توپا, pfqk_, 
   {{0x6f0c014f,0x9f9c00e8,0xeaa401d3,0xcd000055}},	//   _dubc, _jéém_, _شٹ_, _īśas_, 
   {{0xf708004d,0x7aec00e8,0x00000000,0x00000000}},	//   _rầm_, ŋatk, --, --, 
   {{0x7b140022,0xc6ec025c,0xf708004d,0x00000000}},	//   _aġua, _ལེའུ, _sầm_, --, 
   {{0x212900d7,0xb3d4033f,0x7e7c03b2,0x656ce456}},	//   _hwch_, _मुफ़्, _óspo, hwch, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x5ec0015b,0x3eac0205,0xd2540240,0x00000000}},	//   ষকদে, _ilet_, _ዝኽእሉ, --, 
   {{0x7b1400e4,0x00000000,0x00000000,0x00000000}},	//   _eġua, --, --, --, 
   {{0x3ead00d8,0x69c40b21,0xf7080016,0xb8e40882}},	//   _klet_, ûker, _tầm_, _एष_, 
   {{0x2aa80086,0xb4d4146b,0x00000000,0x00000000}},	//   _tùba_, िक्_, --, --, 
   {{0xd52c0241,0x9f9c0036,0x3eac0010,0xdbe00036}},	//   _dó̟g, _déém_, _mlet_, déém, 
   {{0xa5b900d9,0x7ae900da,0x3eac00f7,0xdcf801fa}},	//   mból, llet, _llet_, _oruč, 
   {{0x3eac049b,0x2128015d,0xa5b80174,0xe29c0a87}},	//   _olet_, _awch_, lból, _siða_, 
   {{0x7ae900db,0x21280042,0x38a801e1,0x7cec02f0}},	//   nlet, _bwch_, _kúro_, kúro, 
   {{0x7ae900dc,0xa2e00d6f,0x212803cb,0x656c0175}},	// [17080] ilet, тотд, _cwch_, cwch, 
   {{0x61402119,0x7ae900dd,0x3eac2c4c,0x21280142}},	//   тефа, hlet, _alet_, _dwch_, 
   {{0xe8b4081f,0xb4c834f8,0x212800a9,0x6f0c014f}},	//   ྒྲིག, लची_, _ewch_, _qubc, 
   {{0x3eac0072,0x29000122,0xa5b806ea,0x7ae900de}},	//   _clet_, íkaz_, kból, jlet, 
   {{0x2128015d,0xd18401e0,0x7ced00df,0x00000000}},	//   _gwch_, _яһай, gúro, --, 
   {{0x7ae900e0,0x3ead00e1,0x6ad406b1,0xa3e00e49}},	//   elet, _elet_, डक्र, _फुड_, 
   {{0x3eac044e,0xdcf80010,0x00000000,0x00000000}},	//   _flet_, _gruč, --, --, 
   {{0x3eac0356,0xdfcc00ae,0x00000000,0x00000000}},	//   _glet_, _ضيق_, --, --, 
   {{0x2868368e,0x3a3c007f,0xa5b8022c,0xdcf82b57}},	//   орно_, _ddwp_, gból, _zruč, 
   {{0x38a801e1,0x451c02f5,0x00000000,0x00000000}},	//   _dúro_, _তিলক_, --, --, 
   {{0x499001d3,0x784400c7,0x2ce801f9,0x00000000}},	//   ئیڈر, хьыҧ, टतील_, --, 
   {{0xc6240154,0x00000000,0x00000000,0x00000000}},	//   _ভাঙা_, --, --, --, 
   {{0xe4e400d6,0xe3b06f04,0x00000000,0x00000000}},	//   дівн, چرز_, --, --, 
   {{0xe3b100e2,0x656c0142,0x85b4013d,0x00000000}},	//   نرز_, rwch, дәүч, --, 
   {{0x7cec0518,0x225c002e,0x21280142,0x6f0c06be}},	//   zúro, _ñukk_, _swch_, _əncü, 
   {{0x7f440175,0xaadc043e,0x00000000,0x00000000}},	//   vrhq, मविक, --, --, 
   {{0x1708025c,0xdcf80e3c,0xc1b801c0,0x557400db}},	// [17090] _གཤོམ_, _sruč, члах_, _агыт, 
   {{0x3eac019b,0x7ae900e3,0xdcf80010,0x00000000}},	//   _slet_, zlet, _pruč, --, 
   {{0x7ae900e4,0x3eac005c,0xd4d8007b,0x00000000}},	//   ylet, _plet_, _تبيض_, --, 
   {{0x64400261,0xdcf8107d,0x7cec1de4,0xdef80022}},	//   _ônib, _vruč, túro, цыз_, 
   {{0x7ae900e5,0x212800a9,0x38b40241,0x7218011a}},	//   vlet, _uwch_, _jùrù_, _מורח, 
   {{0x7ae809a5,0xdfd802e8,0x3eac010b,0x00000000}},	//   wlet, _дъб_, _wlet_, --, 
   {{0xdcf80b91,0xa5b8012d,0xdd8c00ec,0x7cec00d7}},	//   _uruč, wból, اوڙ_, súro, 
   {{0xa5b81125,0x3ead00e6,0x517c0023,0x00000000}},	//   tból, _ulet_, _ብርእሰ_, --, 
   {{0x7ae805ac,0xf98800ec,0xa5b80162,0x00000000}},	//   rlet, سندي_, uból, --, 
   {{0xe8f500e7,0x7ae872a5,0xa5b8041e,0xa3dc00dc}},	//   нлы_, slet, rból, तथा_, 
   {{0x7ae900e8,0xe5a00019,0xa5b806ea,0x3d140412}},	//   plet, қири, sból, _फंडे_, 
   {{0x38b40241,0xcbc80014,0xd6c40075,0x00000000}},	//   _bùrù_, _تِمو_, тимқ, --, 
   {{0x0ab8007b,0x00000000,0x00000000,0x00000000}},	//   _تطلب_, --, --, --, 
   {{0x394d00e9,0x38b401e1,0xb4c80490,0xa5b80210}},	//   mues_, _dùrù_, लचे_, obój, 
   {{0x394d00ea,0x04400023,0x00000000,0x00000000}},	//   lues_, _ንዝጸን, --, --, 
   {{0xe29500eb,0x00000000,0x00000000,0x00000000}},	//   нас_, --, --, --, 
   {{0x614100ec,0x216500ed,0x7cec06ea,0x38b401e1}},	// [170a0] лета, нити_, túrl, _gùrù_, 
   {{0xd3a40fab,0x23d8951e,0xb63801ec,0x00000000}},	//   _алоқ, _मुकद, _ﺘﻨ_, --, 
   {{0x394ca82b,0xdfcc007b,0xe0404965,0x6e440244}},	//   hues_, ميك_, унхи, فنام, 
   {{0x394d00ee,0x74140451,0xed5802a9,0xd25003e6}},	//   kues_, _توھا, зод_, _خۆر_, 
   {{0x394c0023,0x00000000,0x00000000,0x00000000}},	//   jues_, --, --, --, 
   {{0x394d00ef,0x653800c8,0x5d800691,0x00000000}},	//   dues_, לענד, الول, --, 
   {{0x394c06af,0x2b44009d,0xe514000d,0xfe6c014b}},	//   eues_, хэлг, _धूनि_, _кӯ_, 
   {{0xdfcc05d9,0xa3e000e1,0xed5900f0,0x394c0200}},	//   _ايف_, _फँस_, _ноб_, fues_, 
   {{0x394d00f1,0x00000000,0x00000000,0x00000000}},	//   gues_, --, --, --, 
   {{0x98b40166,0x18b400c7,0x00000000,0x00000000}},	//   ельт_, егьы_, --, --, 
   {{0x7b180e78,0x3170002f,0xda90009d,0x00000000}},	//   räuß, hwyz_, тгөө, --, 
   {{0xb78405a2,0x394c0200,0x7b180112,0xf9800022}},	//   тәше_, bues_, säuß, уҳәо, 
   {{0xda6c01d9,0x394d00f2,0x96340006,0x00000000}},	//   _دُن_, cues_, ыняц, --, 
   {{0xa5b80413,0x00000000,0x00000000,0x00000000}},	//   lbók, --, --, --, 
   {{0xe2840120,0xc2c4007b,0x2be000fe,0x00000000}},	//   нѓан, نيسي, গেৰে_, --, 
   {{0x673900f3,0x0cdc06b1,0xa5b81427,0xd25001d9}},	//   mstj, मकुम, nbók, ٝنِ_, 
   {{0x673900f4,0xfe702ab4,0x45d4013e,0x4254105d}},	// [170b0] lstj, یگر_, _шоис, _یندر, 
   {{0xc0d40092,0x6738000d,0x3fc80244,0x00000000}},	//   ካችሁ_, ostj, ودای_, --, 
   {{0x394c0023,0x50649e92,0xd10801d5,0x00000000}},	//   zues_, ытта, رقمه_, --, 
   {{0x94000073,0x00000000,0x00000000,0x00000000}},	//   ोखरच_, --, --, --, 
   {{0xf2c00323,0x69c400d2,0x394c0240,0xe3e000fe}},	//   _төри, úkel, xues_, _মণিব, 
   {{0xada0edf3,0x394d00f5,0x6da0ee7d,0x67380ad9}},	//   рашл, vues_, риша, kstj, 
   {{0x67380cf9,0x394c04e6,0xdb008745,0xa5b8032e}},	//   jstj, wues_, lyné, fbók, 
   {{0x394d00f6,0x67385629,0x2ec06073,0xaa540063}},	//   tues_, dstj, _көчм, вићу_, 
   {{0x673809b6,0x63a40240,0x8c3c2ca8,0x9f4001ef}},	//   estj, hyjn, _boğd, _myjí_, 
   {{0x394d00f7,0x673801a8,0x79a4008e,0x00000000}},	//   rues_, fstj, ерүе, --, 
   {{0x394d00f8,0x8c3c029f,0x67383720,0x00000000}},	//   sues_, _doğd, gstj, --, 
   {{0x35a401c6,0x6454a270,0x4a7400cf,0x63a4012d}},	//   вамг, _acxi, _бышт, dyjn, 
   {{0x394d00f9,0x00000000,0x00000000,0x00000000}},	//   ques_, --, --, --, 
   {{0xc5f500fa,0x6454003a,0xa88404b3,0x66c801f4}},	//   ығы_, _ccxi, _айша_, tökä, 
   {{0xe29c2880,0x705403e6,0xe02001e1,0x00000000}},	//   _boð_, ێنرا, _è́yí_, --, 
   {{0x1b1000bd,0x7b14031c,0xaa80010e,0x92b40eff}},	//   _সবাই_, _rġul, _öýts, اڭدا, 
   {{0xe57407dd,0xefd402d3,0x7cec00d0,0x310800d8}},	// [170c0] _азы_, ካይድ_, gúrk, днап_, 
   {{0x602000d8,0x00000000,0x00000000,0x00000000}},	//   идуа, --, --, --, 
   {{0x63a4006d,0x625401e1,0x00000000,0x00000000}},	//   cyjn, _kùò, --, --, 
   {{0x7af80142,0xe29c02d2,0xfe740304,0x00000000}},	//   _nhwt, _goð_, лүс_, --, 
   {{0xe294020f,0x00000000,0x00000000,0x00000000}},	//   _рая_, --, --, --, 
   {{0x237c033f,0x4f3c02d3,0x673801e3,0x705401c8}},	//   łuje_, _ኣፍወር, ystj, _جنسا, 
   {{0xf7080016,0x7fd40046,0xdca00640,0x2078008f}},	//   _hầu_, _біті, раји, _קאלא, 
   {{0x7af80142,0xbc241d00,0x673803b2,0x00000000}},	//   _chwt, _ەرنى, vstj, --, 
   {{0x63a40034,0xece8005b,0x20040118,0xa5b8148b}},	//   zyjn, _ждал_, žnit_, rbók, 
   {{0xdd8d00fb,0x6738c743,0xf70801fb,0xa5b80ad9}},	//   _بوك_, tstj, _mầu_, sbók, 
   {{0xd7f500fc,0xf708001e,0xda6c0276,0xa5b900fd}},	//   кую_, _lầu_, _кя_, mbói, 
   {{0x6738193f,0xa9680150,0x443c0034,0xa2580798}},	//   rstj, _يمام_, _św_, _amôn, 
   {{0x67381873,0xba5000cf,0x2a6401bf,0xe29c02d2}},	//   sstj, _اچىع, _ibob_, _roð_, 
   {{0x7d1c00f7,0x673900fe,0x3d14033f,0x63a40240}},	//   _ésse, pstj, _फंसे_, tyjn, 
   {{0xd3a40150,0x58f40115,0x00000000,0x00000000}},	//   артп, _שמוע_, --, --, 
   {{0xf7080016,0x63a40034,0x857400f3,0x00000000}},	//   _bầu_, ryjn, _блих, --, 
   {{0xf70807ae,0x3f840798,0x63a40034,0x0ebc0220}},	// [170d0] _cầu_, _àluz_, syjn, _دﻮﻨﺟ_, 
   {{0xf7080016,0x51f8100e,0xdb0000d7,0x4394014b}},	//   _dầu_, тную_, dzný, _баос, 
   {{0xf410025f,0x200500ff,0x1ee40e3f,0x4254036b}},	//   _לפי_, äni_, پوشی_, _ینگر, 
   {{0xa5b80077,0x0ef800be,0x00000000,0x00000000}},	//   rcóf, نعنع_, --, --, 
   {{0x7cec04d4,0x2aa801c3,0xf7080208,0xa5b80332}},	//   lúri, _iùbh_, _gầu_, scóf, 
   {{0x80d00011,0x00000000,0x00000000,0x00000000}},	//   _তীর্, --, --, --, 
   {{0x7cec3756,0x38bc00c7,0xdb200139,0x8f340024}},	//   núri, hárõ_, _üsüd, _весц, 
   {{0xed4c01d9,0x38bc0022,0xef980166,0x00000000}},	//   تھہ_, kárõ_, _яйсә_, --, 
   {{0x628c009a,0x6af40131,0xa9203740,0xb9e800ee}},	//   _mnco, دىيس_, бдыл, эмиз_, 
   {{0x38740640,0xee840022,0x38a80744,0x6d5c0356}},	//   ућит, _иыӡо, _kúri_, ăpat, 
   {{0xe7a405f5,0x38a80120,0xa3e013e0,0xfb8800d1}},	//   гвэл_, _júri_, _फुल_, _ярақ_, 
   {{0x2a640174,0xba38008f,0x3a280432,0xe8ec010a}},	//   _gbob_, _װײַט, _ýap_, _ӳл_, 
   {{0xe8ec0953,0xe7e40118,0xe7b0036b,0x00000000}},	//   _гл_, _věšá, لمید, --, 
   {{0x628d0100,0xf708004d,0xe29402dd,0x60d80413}},	//   _anco, _rầu_, қау_, _íumh, 
   {{0xf70801fb,0x3d1802e2,0x7cec004e,0x2d3c0240}},	//   _sầu_, _lèw_, gúri, _ኣይንረ, 
   {{0x60640116,0x00000000,0x00000000,0x00000000}},	//   ңҗяң_, --, --, --, 
   {{0x2aa800a3,0x46e007f7,0xd1300a81,0xca3c07d2}},	// [170e0] _dùbh_, नवरह, زمؔ_, _ﺑﻪﺯ_, 
   {{0x628d0101,0x7ced0102,0x38a90103,0x8c3c013d}},	//   _enco, búri, _búri_, _moğc, 
   {{0x7f180d30,0x6ff4299f,0xac8400fb,0x7cec0419}},	//   вічу_, учах, ғѳлл, cúri, 
   {{0xf708004d,0xdcac3ee0,0x6d4c00b8,0xe294068e}},	//   _tầu_, ۋىن_, _ābab, _баю_, 
   {{0x395c0218,0x2ce85477,0xf3f400fe,0x00000000}},	//   _nqws_, нько_, _আলিৰ_, --, 
   {{0xafe43946,0x1d04004e,0xd1cc0092,0xdb000419}},	//   _богл, гечи_, _በርታ_, rzný, 
   {{0x200c09a5,0xa5b8007b,0xe0d40120,0xfca84fca}},	//   üniň_, rbói, _свр_, خانو_, 
   {{0x0e04016c,0x3d180100,0xacb000cf,0xa5b800e5}},	//   _кӯло, _fèw_, _گەتب, mbóv, 
   {{0x6f010104,0x2ee4198f,0x2d800022,0xac840166}},	//   mmoc, moof_, _éke_, _йгал, 
   {{0xa258006a,0x2ee4225e,0x7c641f71,0x6f0002f0}},	//   _amôl, loof_, _نامل, lmoc, 
   {{0x2a64156b,0x7cec28ed,0xa2880023,0x00000000}},	//   _бълг, xúri, _መጻእን_, --, 
   {{0x2a640b6f,0xd7f40184,0x6f010105,0x6d4403cd}},	//   _ubob_, ыуы_, nmoc, _åkas, 
   {{0xd94009a5,0xe5c4a401,0x176402dd,0x88940c17}},	//   _гечи, усно, _ұрып_, _вилх, 
   {{0x6aa0bbd7,0x7ced0106,0x2ee50107,0x6f000036}},	//   _hoof, túri, hoof_, hmoc, 
   {{0xb8645896,0x6aa10108,0xa0a402dd,0x30bc0183}},	//   _خانو, _koof, қшал, _অৱ্স, 
   {{0x290d0109,0x6f000609,0x38bc0022,0x00000000}},	//   _hifa_, jmoc, párõ_, --, 
   {{0x6aa1010a,0x290d010b,0x2ee40af9,0x6ecc01e4}},	// [170f0] _moof, _kifa_, doof_, nĝbu, 
   {{0x6aa09380,0x290c02a8,0x7cec0137,0xdfd8010b}},	//   _loof, _jifa_, púri, нъе_, 
   {{0x290c0109,0xe29c0ad9,0xe1fc0241,0x4395010c}},	//   _mifa_, _liði_, _gbón_, _танс, 
   {{0x26c9010d,0x290d010e,0x1e0c0574,0x6aa004ba}},	//   nico_, _lifa_, िशेष_, _noof, 
   {{0xddd8002b,0x00000000,0x00000000,0x00000000}},	//   _kauũ, --, --, --, 
   {{0x6f01010f,0x290c0134,0x26c90028,0x38a83168}},	//   amoc, _nifa_, hico_, _túri_, 
   {{0x6aa10110,0x26c80219,0xab74007b,0x00000000}},	//   _boof, kico_, لموا_, --, 
   {{0x290c067c,0x6aa10111,0x39450112,0x26c809a8}},	//   _aifa_, _coof, аниг, jico_, 
   {{0x290c0a55,0x6aa10113,0x36340214,0x6f7400db}},	//   _bifa_, _doof, یرحس, _مەەر_, 
   {{0xdb0003a2,0x988400dd,0x6ce0004b,0x442001bf}},	//   pynï, احظہ_, _وړون, _nfh_, 
   {{0x6aa10114,0xe29c041e,0x6d44369d,0x290d0115}},	//   _foof, _eiði_, _åkar, _difa_, 
   {{0x26c90116,0x6aa10117,0x44210118,0xe7340815}},	//   gico_, _goof, _afh_, шею_, 
   {{0x44200112,0xe57402e8,0x06b801d9,0xdb0001d3}},	//   _bfh_, азя_, انُک_, sznó, 
   {{0x442002fa,0x290c0083,0x394c0023,0x6f000306}},	//   _cfh_, _gifa_, mres_, zmoc, 
   {{0x394d0119,0x61ec035a,0x7e69011a,0xb60402d2}},	//   lres_, _aycl, _obep, _bláæ, 
   {{0x394d011b,0x26c9001c,0x290d011c,0x6aa1011d}},	//   ores_, cico_, _zifa_, _xoof, 
   {{0x394d011e,0x3d141889,0x61ec7d6a,0x290c0117}},	// [17100] nres_, _फूले_, _cycl, _yifa_, 
   {{0x394d011f,0x7e690120,0x21650121,0xe00405d7}},	//   ires_, _abep, рифи_, _वृहद_, 
   {{0xee390122,0x394c0730,0x3e4002d3,0x2ee40ea0}},	//   вне_, hres_, _ከምዝረ, toof_, 
   {{0xeda4d700,0x394d0123,0x7c2002d2,0x3254010b}},	//   ишло, kres_, _aflr, _өвүр, 
   {{0x6aa10124,0x2ee50125,0x394d0126,0x44200175}},	//   _roof, roof_, jres_, _yfh_, 
   {{0x394d0127,0x7e68014b,0x8c3c046c,0x26c90128}},	//   dres_, _ebep, _boğa, zico_, 
   {{0x394c03f4,0x6aa00a73,0xe29c03f2,0x26c90129}},	//   eres_, _poof, _siði_, yico_, 
   {{0x394d012a,0x8c3c0ab7,0x290c05d9,0xdee04409}},	//   fres_, _doğa, _sifa_, _доси, 
   {{0x26c9012b,0x99940801,0x290c05da,0x3be81cd1}},	//   vico_, икът_, _pifa_, кләү_, 
   {{0xa8a5012c,0x61e80e78,0x7d1c0129,0x26c8003a}},	//   ррик, ügli, _éssa, wico_, 
   {{0x6aa00290,0x7cec08ce,0xa92402d2,0x00000000}},	//   _toof, túrv, fnþö, --, 
   {{0x394d012d,0xbad402d5,0xe5c40107,0x386001e3}},	//   bres_, _лічы, ҳсҳо, _öhrn_, 
   {{0x26c9012e,0x394d012f,0x290d0130,0x2d840165}},	//   rico_, cres_, _tifa_, nvoe_, 
   {{0x290c0270,0xe4e402dd,0x8c3c0139,0x00000000}},	//   _uifa_, рімн, _yoğa, --, 
   {{0x26c8c31a,0x61ec00b5,0xe5140037,0x7cec01e7}},	//   pico_, _sycl, _धूरि_, múrt, 
   {{0xded402d3,0x2b4c01ab,0x7cec0162,0x00000000}},	//   ይኮነ_, irfc_, lúrt, --, 
   {{0x26d80477,0x5bd005dc,0xe7e40118,0x51840395}},	// [17110] _ijqo_, _तश्व, _děťá, жуха, 
   {{0xba00001f,0xe4e804fb,0x274c001f,0xb9dc0023}},	//   _ሃያ_, _جعبه_, _በተሰጠ, _ኣያ_, 
   {{0x61ed0131,0xd0190132,0x98bc002b,0x02d80066}},	//   _wycl, рфу_, _śrīr_, _مودب_, 
   {{0x394c3c02,0x7cec0332,0x81d4010a,0x00000000}},	//   yres_, húrt, _гомх, --, 
   {{0xa5b80085,0x8c3c029f,0x27e0033f,0x394c0175}},	//   mbós, _soğa, ękny_, xres_, 
   {{0x394d0133,0xed4c21ef,0xa6cc0183,0xbe640451}},	//   vres_, رپى_, ৰতিট, _گهري, 
   {{0x7a680323,0x7cec00c6,0x3f8407ea,0x2d800010}},	//   гийг_, dúrt, _élu_, _šket_, 
   {{0x394d0134,0x7e690135,0xdd900032,0x38a803b2}},	//   tres_, _ubep, _һағы, _lúrt_, 
   {{0x394d0136,0xe51407f7,0x0e440139,0x00000000}},	//   ures_, _धूलि_, _фэсм, --, 
   {{0x7cec0bcd,0xdd906518,0x86f801d3,0x8c3c03b9}},	//   túru, _лағы, یکٹس_, _toğa, 
   {{0x394d0137,0x37e50138,0x00000000,0x00000000}},	//   sres_, сонг, --, --, 
   {{0x394cd8f2,0x7b14012c,0x7fd400bc,0x38a80419}},	//   pres_, _všud, _दशैँ, _rúru_, 
   {{0x7ae90139,0x4548005b,0xb6a401d5,0x38a802d2}},	//   moet, ичём_, _ҳийл, _súru_, 
   {{0x7ae9013a,0xe8a002d3,0x00000000,0x00000000}},	//   loet, _ዝፈልጡ_, --, --, 
   {{0x38a80332,0xe29c08ce,0x7cec1d0e,0x98a000fb}},	//   _dúrt_, _liðu_, lúrs, _гиҙе, 
   {{0x7ae9013b,0xd17401e0,0x00000000,0x00000000}},	//   noet, ҙығы, --, --, 
   {{0x7ae8005a,0x6b6806be,0x00000000,0x00000000}},	// [17120] ioet, _məga, --, --, 
   {{0x7ae9013c,0x3ae001f1,0xdfcc05d9,0xafe401b9}},	//   hoet, rópy_, ڙيل_, бозл, 
   {{0x7ae805f5,0x7cec007b,0xa06400a7,0xe478008f}},	//   koet, húrs, саха_, _גריכ, 
   {{0x7ae85c70,0xee39013d,0x52b40137,0xe29c08a5}},	//   joet, унд_, _بەرئ, _biðu_, 
   {{0x7ae9013e,0x20200f91,0xccc821f3,0xf1c801ef}},	//   doet, érií_, ағал_, fláž_, 
   {{0x42980092,0xba3c013a,0x00000000,0x00000000}},	//   _መሪነት_, chůz, --, --, 
   {{0x7c64006c,0x7ae80368,0xe29c022c,0x638000bc}},	//   تانل, foet, _viðv_, míná, 
   {{0x7ae9013f,0xed3401c0,0x6d90032e,0x00000000}},	//   goet, _гэжэ, gðað, --, 
   {{0x45240135,0xe298008f,0xed44084c,0x7cec00ae}},	//   _འཕེར_, רשפר, _ынап, túrt, 
   {{0x6e200309,0x6d40002d,0xa178010f,0x00000000}},	//   lcob, msoa, נטיט, --, 
   {{0x6d410140,0x7ae90141,0x7cec0162,0x00000000}},	//   lsoa, boet, rúrt, --, 
   {{0x6e200574,0xdcf800f3,0x7ae8003a,0x6d40005a}},	//   ncob, _pruć, coet, osoa, 
   {{0x6d410142,0x38a80162,0x00000000,0x00000000}},	//   nsoa, _púrt_, --, --, 
   {{0xdcf804b9,0x66cc01e1,0x8c3c456f,0x75340175}},	//   _vruć, _bòkè, _moğo, _dwyz, 
   {{0x5334084c,0xa3b000af,0xe00401ad,0x8c3c0205}},	//   зест, जैं_, _वृंद_, _loğo, 
   {{0x6d40045f,0x45d41436,0x6d4c0055,0x00000000}},	//   ksoa, _мойс, _āban, --, 
   {{0x6d40002d,0x24900051,0xa6e00174,0x00000000}},	// [17130] jsoa, _tnxm_, øðut, --, 
   {{0xc0f80020,0x657c0309,0x7ae801c6,0x6d40e47f}},	//   ላችሁ_, _isqh, zoet, dsoa, 
   {{0x613c01e1,0xff2403e6,0xe29c08a5,0xddc80171}},	//   _bàlá, زبای, _siðu_, degš, 
   {{0x6e204b26,0x8c3c0139,0x7ae8005a,0xbdf4119e}},	//   gcob, _boğo, xoet, опеј, 
   {{0x5d6406bb,0x7ae80af4,0x6d400175,0xc8780790}},	//   стез, voet, gsoa, loğu_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7ae90143,0xfc3006d6,0x6d400607,0x2020012d}},	//   toet, _nṋe_, asoa, ąpią_, 
   {{0x6e20c7cc,0x394818a4,0xc0f80240,0x00000000}},	//   ccob, азио_, ላኽሲ_, --, 
   {{0x7ae90144,0x6d900ad9,0xbdc00131,0x6d40054e}},	//   roet, rðað, _تەشۋ, csoa, 
   {{0x7ae801c6,0x7cec148b,0xd1380210,0x00000000}},	//   soet, rúrs, _łąk_, --, 
   {{0x657c0113,0x7ae801f5,0xdb00011f,0x28a80243}},	//   _asqh, poet, ayná, _चकरि, 
   {{0x7d000076,0xc87805d1,0x3d1c00bc,0xb99400ae}},	//   _hhls, doğu_, _पढाइ_, _ولاب, 
   {{0xe29c01a8,0x97800066,0x00000000,0x00000000}},	//   _liðs_, زیکه, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb6a48f3a,0x79880857,0xe1fc0210,0x00000000}},	//   _микл, lvew, _ubój_, --, 
   {{0xcfc40154,0x15e80037,0x6d400076,0x4dd400fe}},	//   ্থমন, _टुअर_, ysoa, _তৰোৱ, 
   {{0x7d010145,0x06940583,0xa5b80005,0x00000000}},	// [17140] _ohls, _راٹھ, lcón, --, 
   {{0x25e000af,0xdfcc0451,0x613c01e1,0x66cc1ed9}},	//   _टुटी_, ھين_, _sàlá, _tòkè, 
   {{0xf42802f6,0xa5b80077,0xdfcceb32,0xd4c40116}},	//   _elää_, ncón, نيك_, _дөңк, 
   {{0x6d410146,0xa3e002ab,0x0ec40490,0x7d00007c}},	//   tsoa, _फुट_, लोंड, _ahls, 
   {{0x6e210147,0x4c950148,0x80b80eac,0xcc88036b}},	//   rcob, зилс, _আদর্, ینچه_, 
   {{0x6d410149,0x6e21014a,0x64b400fd,0x7b140327}},	//   rsoa, scob, mğiä, _nġus, 
   {{0x6d400cfc,0x70c407f7,0x00000000,0x00000000}},	//   ssoa, लफील, --, --, 
   {{0xe94401c0,0x6d40005a,0x20cc0327,0x8c3c06be}},	//   охоо, psoa, nżin_, _zoğl, 
   {{0xdd8c15fa,0x73f40154,0xaa9001d5,0x00000000}},	//   _ټول_, _আলোয়_, зиқч, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdcac0a52,0x798802d0,0xccb401af,0x00000000}},	//   _جىل_, avew, _мәҫь, --, 
   {{0xa968d77e,0x00000000,0x00000000,0x00000000}},	//   _вида_, --, --, --, 
   {{0x7c3800e4,0x44300165,0x2b903224,0x8c3c03e3}},	//   _ñarõ, tbz_, _ریکس, _loğm, 
   {{0x7b140309,0x18640114,0x00000000,0x00000000}},	//   _ušuc, _даљи_, --, --, 
   {{0x9388207d,0x44300099,0xd7ec07d5,0x8c3c0166}},	//   оста_, rbz_, _цу_, _noğm, 
   {{0x442c010f,0x92940024,0xdb0000e5,0x00000000}},	//   ŝe_, масц, sznö, --, 
   {{0x657c02d1,0xe29c02d2,0xaab0000d,0xb3400327}},	// [17150] _usqh, _siðs_, _जवनक, ċħad, 
   {{0x8b0402a8,0x8c3c4e7e,0x00000000,0x00000000}},	//   ƙƙwa, _boğm, --, --, 
   {{0xb6580248,0xe1fc0124,0x79880099,0x260400ab}},	//   _amẹ́, _mbói_, zvew, सेरी_, 
   {{0xf8c80248,0x8c3c47af,0x7d000158,0xeff80023}},	//   _alẹ́_, _doğm, _shls, ዋርያ_, 
   {{0x9148035b,0xdb00010e,0x00000000,0x00000000}},	//   _мчра_, lynç, --, --, 
   {{0xae000131,0xad500131,0x2129014b,0x00000000}},	//   رۈلى, رنىغ, _itch_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xddd80311,0x09cc0154,0x00000000,0x00000000}},	//   _cauţ, _লড়া, --, --, 
   {{0xcced014c,0x42a4044e,0x9bb00451,0x00000000}},	//   _ақ_, _ወገናት_, _ڪلاڪ, --, 
   {{0xf8682e6f,0x79881401,0xdb0000a2,0x00000000}},	//   حمدي_, rvew, kynç, --, 
   {{0xf771014d,0xc5e81203,0x6e280098,0x28c800ab}},	//   راد_, _עד_, _émbé, ाफ़ि, 
   {{0x7e781c06,0x4a740372,0xe72c05f5,0xe1fc00db}},	//   newp, _жышт, _үе_, _ozó_, 
   {{0x75d40fa2,0x260400bc,0xa5b9014e,0x00000000}},	//   سيسا, सेली_, scón, --, 
   {{0xa5b800d2,0x7f440309,0xd11c107c,0x26d801e1}},	//   mcól, kshq, _भूषण_, _ìpon_, 
   {{0xa5b80332,0xf748007b,0xdb00010e,0x00000000}},	//   lcól, _البي_, gynç, --, 
   {{0xdbd40d77,0x3124265b,0x00000000,0x00000000}},	//   määr, здаг, --, --, 
   {{0x9a8800b7,0xa5b85178,0x437c0023,0x85340228}},	// [17160] ናሽናል_, ncól, _ብውልቀ_, _قويچ, 
   {{0xaf98010a,0x00000000,0x00000000,0x00000000}},	//   йтех_, --, --, --, 
   {{0x21280b1d,0xdbd4b6a5,0x00000000,0x00000000}},	//   _etch_, näär, --, --, 
   {{0x7e7803a2,0xdee02cdd,0x22480051,0x602400e4}},	//   gewp, нохи, _gdck_, tĩmí, 
   {{0xdbd40254,0x999c0210,0x00000000,0x00000000}},	//   häär, rbuś_, --, --, 
   {{0xdbd46775,0x99842791,0x00000000,0x00000000}},	//   käär, _şişi_, --, --, 
   {{0x47d00154,0xdb00005b,0x7fd401ec,0xdbd401f4}},	//   _সুনী, kynä, _жіті, jäär, 
   {{0x5fd80375,0x00000000,0x00000000,0x00000000}},	//   _החלק, --, --, --, 
   {{0xdea064ec,0xdee000d6,0xe1fc00ae,0xed3404b4}},	//   _سیوی, _чоти, _gcód_, _хэбэ, 
   {{0xfca8021a,0xdbd4000d,0x00000000,0x00000000}},	//   _والو_, fäär, --, --, 
   {{0x3d140cb4,0x2004022e,0x00000000,0x00000000}},	//   _फूटे_, оniy_, --, --, 
   {{0x45d5014f,0xa9a406ed,0x57a000c7,0x00000000}},	//   домс, _ниед, хшьа, --, 
   {{0x7c400724,0xddd80fda,0x26dc01e4,0x00000000}},	//   _öyrä, _kauš, ĵuo_, --, 
   {{0xb8f00022,0x98a00408,0xddd80171,0x18a0030d}},	//   _иҧыш, _пиче, _jauš, _пачм, 
   {{0xe1fc00dd,0xe3b00101,0xf8ac0133,0x53e401ee}},	//   _szó_, ررس_, _ڕکێ_, ецта, 
   {{0x69dc013f,0xddd90150,0xd1d40092,0x070800ec}},	//   _ɛpen, _lauš, ረሰቡ_, _ڏيڻي_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [17170] --, --, --, --, 
   {{0xddd8b964,0xdcf80115,0x55bc0375,0x39580268}},	//   _nauš, _bruĝ, _למחו, àssi_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9f6006ea,0x7f440200,0x00000000,0x00000000}},	//   _ávís_, rshq, --, --, 
   {{0xddd8597b,0x00000000,0x00000000,0x00000000}},	//   _bauš, --, --, --, 
   {{0x8d750151,0x3d1c000d,0x00000000,0x00000000}},	//   عانا, _पढीं_, --, --, 
   {{0x7f44022e,0x00000000,0x00000000,0x00000000}},	//   qshq, --, --, --, 
   {{0xdbd405a7,0x3f900010,0x3d080153,0x00000000}},	//   väär, _irzu_, _žuvį_, --, 
   {{0x385400a7,0xddd80010,0x18980023,0xada400d7}},	//   мънс, _fauš, _ንለውጢ_, _cmúľ, 
   {{0xd90c066d,0xe8f50152,0x82fc025c,0x499004fb}},	//   ھیں_, млы_, _དེའུ_, ایور, 
   {{0xd90c00e5,0x00000000,0x00000000,0x00000000}},	//   پیں_, --, --, --, 
   {{0xd1d41ee0,0x00000000,0x00000000,0x00000000}},	//   ረሰብ_, --, --, --, 
   {{0xe8ed0153,0xf77001d9,0xe9cc57c6,0xdbd426bb}},	//   _ал_, راگ_, _рк_, säär, 
   {{0x3f910154,0x798c025c,0xdbd401f4,0x00000000}},	//   _orzu_, _ġawh, päär, --, 
   {{0x43750155,0x23250156,0xd7f801c6,0x00000000}},	//   нутт, доси_, _ууд_, --, 
   {{0x6904032e,0x00000000,0x00000000,0x00000000}},	//   gðef, --, --, --, 
   {{0x21650157,0x3f9047af,0xf0a80c56,0xe70400f2}},	// [17180] мити_, _arzu_, окал_, _تسوی, 
   {{0x3f900552,0xc0580212,0xb62007d2,0xf5040024}},	//   _brzu_, зії_, _ﯩﻚ_, _ізно, 
   {{0xdb880153,0xddd85563,0x00000000,0x00000000}},	//   šąjį_, _rauš, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xddd8cc1a,0x4ea40032,0x3f900036,0xace90158}},	//   _pauš, дрҙа, _erzu_, омда_, 
   {{0xdd910159,0x61400114,0x00000000,0x00000000}},	//   ташы, _јера, --, --, 
   {{0xfd65015a,0xc6240154,0x6fb401e2,0x00000000}},	//   _үнсү, পরতা_, _غمرا, --, 
   {{0xed59015b,0x9c200139,0x00000000,0x00000000}},	//   _моб_, ндәд, --, --, 
   {{0xddd80166,0xad6412ea,0xc9140114,0x00000000}},	//   _ibuş, _تازه, ндић, --, 
   {{0x4734453f,0x7b1400f3,0x00000000,0x00000000}},	//   ннос, _ušun, --, --, 
   {{0x205400c8,0xdca0239a,0x6a85015c,0x7c641d37}},	//   וייל_, _шафи, _олжа, _سالل, 
   {{0x56943f51,0x00000000,0x00000000,0x00000000}},	//   вают, --, --, --, 
   {{0xe9d84352,0x0488010b,0x95640395,0x6578031c}},	//   _بذات_, пәни_, кърд, ħuho, 
   {{0x28141e4a,0xf7080208,0xd90c179e,0x7aed015d}},	//   _قوشس, _mầy_, _پیپ_, čate, 
   {{0xca3c040d,0xf708004d,0x00000000,0x00000000}},	//   _ﺑﻪﺕ_, _lầy_, --, --, 
   {{0xae0c07f7,0xd6d801ec,0x00000000,0x00000000}},	//   िधान_, _оты_, --, --, 
   {{0xf70801fb,0x44f40116,0x3d1c2e05,0xe80801f9}},	// [17190] _nầy_, _ппис, _पढें_, हेरा_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf70801fb,0x00000000,0x00000000,0x00000000}},	//   _bầy_, --, --, --, 
   {{0xcd2896ec,0xf708004d,0x00000000,0x00000000}},	//   وسون_, _cầy_, --, --, 
   {{0xf708004d,0xc1041913,0x00000000,0x00000000}},	//   _dầy_, _سوزي, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf9840588,0x4fc42e51,0x3200010e,0xdb0000d7}},	//   егио, _جەمە, _yzky_, lynú, 
   {{0xf70801fb,0x0ae82162,0x600001a9,0xfa3401d5}},	//   _gầy_, بروي_, dеmi, ورکد, 
   {{0x77c84c7f,0x9ba01870,0x00000000,0x00000000}},	//   злог_, _لەتى, --, --, 
   {{0xe80800c5,0x3eac0108,0x00000000,0x00000000}},	//   हेला_, _koet_, --, --, 
   {{0xb6a400ee,0x3eacea7e,0x00000000,0x00000000}},	//   химл, _joet_, --, --, 
   {{0x3ead015e,0x3b0c0140,0x042c002b,0x00000000}},	//   _moet_, mmeq_, _hāṭa, --, 
   {{0x37e5015f,0xe2780131,0xf74454d9,0x00000000}},	//   _полг, үштә_, _зеко, --, 
   {{0xd5b800da,0xa8540375,0x27b0008e,0x00000000}},	//   ņā_, _טיסה_, _бәяс, --, 
   {{0x3ead0160,0x52bc012d,0x4254004e,0x00000000}},	//   _noet_, ोफेस, ктут, --, 
   {{0x76447d05,0xa2e001b9,0x2000012d,0x00000000}},	// [171a0] maky, уотд, _azji_, --, 
   {{0x76450161,0xdcf81505,0xf708004d,0x00000000}},	//   laky, _oruđ, _rầy_, --, 
   {{0x3ead0162,0x042c002b,0x9f98000d,0xef1826bf}},	//   _boet_, _nāṭa, jääv_, чме_, 
   {{0x3ead0163,0x212c063f,0x76450164,0x71a40454}},	//   _coet_, ̣ghi_, naky, _замз, 
   {{0x3eac0936,0x68f8007c,0x00000000,0x00000000}},	//   _doet_, yltd, --, --, 
   {{0xdca0b076,0xf708004d,0x5ca01608,0x00000000}},	//   лачи, _vầy_, личб, --, 
   {{0x76450165,0x3ead0166,0x042c0055,0xee381a5c}},	//   kaky, _foet_, _cāṭa, _ннв_, 
   {{0x76450167,0x7b1401a6,0xfe7001d9,0x497401b9}},	//   jaky, _ušul, _پدِ_, влис, 
   {{0xf7080051,0xed580108,0x76450168,0x00000000}},	//   _uầy_, _хоз_, daky, --, 
   {{0x3eac0d27,0x274401e1,0x68f8127b,0x2b900271}},	//   _zoet_, _níná_, ultd, _میتس, 
   {{0x6000022e,0xdb4c01f7,0x00000000,0x00000000}},	//   tеmi, _هَل_, --, --, 
   {{0x9a810169,0x3b0c009a,0x76441418,0xa5b9016a}},	//   _бушл, cmeq_, gaky, lcói, 
   {{0x274401e1,0x84c40131,0x6aa4007c,0x160c0709}},	//   _bíná_, вәнд, ökfu, सेलर_, 
   {{0x7d1c2508,0x00000000,0x00000000,0x00000000}},	//   _èsse, --, --, --, 
   {{0xd884004b,0x7645016b,0x7664005b,0x382c0023}},	//   _سپين_, baky, ätyö, _ተሓባበ, 
   {{0xa5b8007b,0x764400e4,0x57f8011a,0x00000000}},	//   hcói, caky, _מלוו, --, 
   {{0x3eac03bd,0x6b6806be,0x00000000,0x00000000}},	// [171b0] _roet_, _dəgi, --, --, 
   {{0x90284077,0xa258002d,0x3eac05e4,0x7b14009b}},	//   ецца_, _blôc, _soet_, _ršum, 
   {{0x6445016c,0x3ead016d,0x09d4015b,0x00000000}},	//   maji, _poet_, _হুমা, --, 
   {{0x6445016e,0x5ba01638,0x02040137,0xbe14007b}},	//   laji, ғлиғ, _үзүн, نواع, 
   {{0x3eac0e29,0xd5c40055,0x00000000,0x00000000}},	//   _voet_, _imāü_, --, --, 
   {{0x6445016f,0x71d400d9,0x042c00cd,0x00000000}},	//   naji, _יורד_, _pāṭa, --, 
   {{0x3ead0170,0x76450171,0x6b6803b9,0xdb2000e5}},	//   _toet_, yaky, _yəgi, دوبی, 
   {{0xce680108,0x042c00b8,0x00000000,0x00000000}},	//   _пруд_, _vāṭa, --, --, 
   {{0x64450172,0x76450173,0x3b0c0140,0x09dc0327}},	//   kaji, vaky, rmeq_, _རྨྱ_, 
   {{0x6444d879,0x8c3c47af,0x2a6401ab,0x76450174}},	//   jaji, _boğu, _ecob_, waky, 
   {{0x76450175,0x64450176,0x37e4036b,0x691c0055}},	//   taky, daji, тонг, _ṣetr, 
   {{0x8c3c4ba9,0x2a6400d8,0x27b001e0,0x27440241}},	//   _doğu, _gcob_, рәшс, _síná_, 
   {{0x76450177,0x64441a4d,0xb89400c6,0xf2140456}},	//   raky, faji, _للإع, _दृढ़_, 
   {{0x76450178,0x58000075,0x7b14013a,0x00000000}},	//   saky, _йолғ, _ošuk, --, 
   {{0x76450179,0x64a097ed,0x744c0023,0x00000000}},	//   paky, шара, _ንዝገብ, --, 
   {{0x81bc02f5,0x83dc00c7,0x98bc0003,0x00000000}},	//   েপন_, _ẽrõi, ftuħ_, --, 
   {{0x6445017a,0x7b0c0084,0xe1201171,0xf06400db}},	// [171c0] baji, ṱuwe, имти, ккап, 
   {{0x8c3c0365,0x888c00c8,0x8eb4005e,0xa25800d0}},	//   _yoğu, ּראַ, گەرت, _plôc, 
   {{0xa064665a,0x0684004e,0x00000000,0x00000000}},	//   таха_, _ргөн, --, --, 
   {{0xf1d00228,0xed59017b,0x8c4800a2,0x8eb400db}},	//   _көзө, дод_, kişä, دەرت, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdcac1a59,0x2a640076,0xc04401d3,0xa5c4032e}},	//   يىن_, _scob_, _مخفو, _hróð, 
   {{0xa065017c,0xab8400d1,0x2a6401f5,0xa5b8007b}},	//   _шара_, тулк, _pcob_, rcói, 
   {{0x66182375,0xa5b8007b,0x6445017d,0x9f4002d2}},	//   žuki, scói, zaji, _eyjó_, 
   {{0x8c3c0365,0x6445017e,0x6c75017f,0x2d801ed9}},	//   _soğu, yaji, _لطائ, _èke_, 
   {{0xfe7000aa,0x6c745980,0x7aec01fa,0x6c48007b}},	//   _پدې_, _шубх, čata, _آلاف_, 
   {{0x64450180,0xc98400d1,0x8c3c03e0,0x37d400eb}},	//   vaji, туқи, _doğt, _সুবর, 
   {{0x38a800d0,0x00000000,0x00000000,0x00000000}},	//   _múry_, --, --, --, 
   {{0x64450181,0x9a64004b,0xa9a48343,0x67542099}},	//   taji, _شمول_, _шидд, ریکس_, 
   {{0x68900345,0x00000000,0x00000000,0x00000000}},	//   _ئیدئ, --, --, --, 
   {{0x64450182,0xa5c409f3,0xa2640408,0xe8300064}},	//   raji, _bróð, къал, _šmėž, 
   {{0x64450183,0x7b300421,0xf3180184,0xd6d80108}},	//   saji, _fāuf, енсә_, _ать_, 
   {{0x237c02f0,0x00000000,0x00000000,0x00000000}},	// [171d0] ňuj_, --, --, --, 
   {{0x656c030a,0x64440009,0x4e9401b9,0x00000000}},	//   mtch, qaji, یشنر, --, 
   {{0xa5c41f60,0x15f4c73b,0x442023bd,0x60d50184}},	//   _fróð, _مسیح, _igh_, rixm, 
   {{0x656c02ce,0xa5c409f3,0x7cec0005,0x4420045a}},	//   otch, _gróð, lúrx, _hgh_, 
   {{0x656c055a,0x44210185,0x26040073,0x00000000}},	//   ntch, _kgh_, सेची_, --, 
   {{0x656d0186,0x4420032e,0xbb4400cf,0x00000000}},	//   itch, _jgh_, гекк, --, 
   {{0x8b641a59,0x44205058,0x656d0187,0xbb7401c6}},	//   لايم, _mgh_, htch, уулъ, 
   {{0x7b300607,0xab740451,0x44210188,0x656c2611}},	//   _lāug, اميا_, _lgh_, ktch, 
   {{0x7e680c8c,0x44210189,0xba740330,0x7c3421d7}},	//   _icep, _ogh_, ناکت, _безх, 
   {{0xe0dc02bd,0x44200208,0x8c3c0205,0x656c002f}},	//   _dwòg_, _ngh_, _doğs, dtch, 
   {{0x5800ac30,0x656d018a,0x3668cb3d,0x1b00013d}},	//   ронғ, etch, нано_, _күкн, 
   {{0x44209d34,0x656c93c1,0xaf74010f,0xc9d4029e}},	//   _agh_, ftch, נערס_, امیک, 
   {{0xb908045e,0x7e680472,0xe0dc02e2,0x4421018b}},	//   _মঠ_, _mcep, _gwòg_, _bgh_, 
   {{0x9f980254,0x88c400db,0x64e46171,0x9874586a}},	//   _käär_, _ۅتۉل, лғың_, _рәиф_, 
   {{0x394d018c,0xd5e401f2,0x442006e8,0x7e680010}},	//   lses_, _baị, _dgh_, _ocep, 
   {{0x3b1c0227,0x3a2c020c,0x7b300418,0x44200978}},	//   _jiwq_, ncep_, _tāuf, _egh_, 
   {{0x394c7d6a,0x74b8009b,0x00000000,0x00000000}},	// [171e0] nses_, _зунс_, --, --, 
   {{0xe1f5018d,0x7e69018e,0xd05c013f,0xe8080316}},	//   угу_, _acep, _nkrɔ, हेका_, 
   {{0x37d4015b,0xe838001f,0xb4c01f13,0xb1440131}},	//   _সুতর, _የአብነ, ्फी_, _әнгл, 
   {{0x394d018f,0x712401ed,0x7e68003a,0x00000000}},	//   kses_, _مرسل, _ccep, --, 
   {{0xe2940323,0x394c780b,0xccf802dd,0x00000000}},	//   _сая_, jses_, вқа_, --, 
   {{0x13d80183,0x7e680857,0x38a80306,0x4c950190}},	//   _দুয়, _ecep, _túry_, рикс, 
   {{0x394d0191,0x09dc00dc,0x00000000,0x00000000}},	//   eses_, मप्य, --, --, 
   {{0x8c3c4a4a,0xe0dc033b,0x394c0fac,0x798c0327}},	//   _coğr, _ewòd_, fses_, _ġawr, 
   {{0x8c3c0baf,0xe0dc007f,0x63680724,0x394d0192}},	//   _doğr, _fwòd_, _könç, gses_, 
   {{0x7c6400d1,0x28840114,0x3c902d56,0x00000000}},	//   _پاكل, ућив, _وینز, --, 
   {{0x290000da,0x7d1c0ffb,0x394c0c30,0xdb00010b}},	//   ēka_, _èssa, ases_, lyný, 
   {{0x44210193,0x656d0194,0xe808012d,0x00000000}},	//   _sgh_, ttch, हेगा_, --, 
   {{0x656d0195,0x25bc00dd,0x44210196,0x97c10197}},	//   utch, ául_, _pgh_, لقیو, 
   {{0x656d0198,0x776001a9,0x20cc031c,0x00000000}},	//   rtch, bulx, nżit_, --, 
   {{0x7cec056a,0x4420002f,0x8c3c4e7e,0xb2300241}},	//   rúrx, _vgh_, _yoğr, _ọjọb, 
   {{0xa6a8806b,0xdb00010e,0x6b640023,0xc2c41359}},	//   _سابق_, kyný, _ዘይተጻ, جيري, 
   {{0x44200092,0x3f840077,0xd25001ed,0x13a80133}},	// [171f0] _tgh_, _áluz_, ںنے_, نۆیی_, 
   {{0x44210199,0x3a2c0010,0x00000000,0x00000000}},	//   _ugh_, zcep_, --, --, 
   {{0xc21001d9,0x09e800fe,0x00000000,0x00000000}},	//   _ژٔج_, _পৰমা, --, --, 
   {{0x66f4084a,0x394c98b2,0xd13001ed,0x7c2001ab}},	//   ीतिक_, yses_, تمے_, _sglr, 
   {{0x628d019a,0x7b3000b0,0x7c65019b,0x7e680010}},	//   _iaco, _māue, لاغل, _vcep, 
   {{0x3b1c0113,0x628c68c8,0x394d019c,0x7f8401e2}},	//   _siwq_, _haco, vses_, _پلرن, 
   {{0xfaa5019d,0xab6000d1,0x20040254,0x00000000}},	//   иако, قۇلى, ünid_, --, 
   {{0x394ce530,0x628c58b7,0x248000df,0x9f98000d}},	//   tses_, _jaco, hejm_, _väär_, 
   {{0x628c13c4,0x394d019e,0xf1b0008f,0x3a2d019f}},	//   _maco, uses_, ַסט_, rcep_, 
   {{0x3a2c00f3,0xb7c000d8,0x30f800cd,0x8bc4008e}},	//   scep_, çãod, ्तयः_, рсәд, 
   {{0x394cf448,0xeaac00dd,0xbb2c0046,0x4aa800f7}},	//   sses_, سٹی_, ﯩﻨﻪ_, ткөн_, 
   {{0x5800a70b,0x628d01a0,0xe1fc0789,0x00000000}},	//   _қойғ, _naco, _oyó_, --, 
   {{0xf50501a1,0x30f800dc,0x00000000,0x00000000}},	//   измо, ्तमः_, --, --, 
   {{0xb4c01d94,0x79980254,0xe8800092,0x00000000}},	//   ्फे_, _irww, ያቀርቡ_, --, 
   {{0xe1fc0248,0xded402d3,0x628c1fd8,0x00000000}},	//   _ayó_, ክሮን_, _baco, --, 
   {{0x628d01a2,0xa5b800d2,0x63680166,0x00000000}},	//   _caco, gcós, _sönç, --, 
   {{0x628d01a3,0x69040008,0x20cc0327,0xa224022e}},	// [17200] _daco, iðen, jżis_, ржуа_, 
   {{0xe4d00150,0x628c0192,0xbebc0006,0xa5b824c8}},	//   _وقيد, _eaco, _liūd, rcót, 
   {{0x628d01a4,0xb4c04142,0xe1fc01e1,0x68280023}},	//   _faco, ंसी_, _eyó_, _ተቓሊስ, 
   {{0x628d01a5,0x277400c8,0xad64007b,0xc87803e0}},	//   _gaco, יגען_, لاته, miğe_, 
   {{0x7aec08ad,0xc87805d1,0xb340025c,0xac84009d}},	//   čatl, liğe_, ċħud, игдл, 
   {{0x628d01a6,0x61402b97,0xcb541532,0x6c7401f0}},	//   _zaco, _фера, منتظ, рудх, 
   {{0x628c03b4,0xa5b85d7e,0x91c40116,0x202400d0}},	//   _yaco, ncór, _тәңл, áviť_, 
   {{0x628c1709,0xeff402d3,0x49c801e0,0x8fd4013d}},	//   _xaco, _ፈቐዶ_, лһен_, _кәҗә, 
   {{0x682802d3,0xad680022,0xa8a40022,0x998000ae}},	//   _ተቓለስ, _шааз_, арнк, قليو, 
   {{0x99d08b4d,0x20040034,0x7c6442b5,0x23600113}},	//   غتيا, żnie_, _هامل, yujj_, 
   {{0x753400a2,0x2d3c0023,0xeb980798,0x00000000}},	//   _atyz, _ይተኣረ, _јие_, --, 
   {{0x6f0101a7,0xe9d80348,0x98a800da,0x59d0004b}},	//   nloc, _ике_, īcā_, _ژغور, 
   {{0x6aa005b8,0x6d440200,0xa85001af,0x8894014b}},	//   _inof, _çkad, _делә, _гилх, 
   {{0x628d01a8,0x6f0101a9,0xd8900014,0xc8780790}},	//   _saco, hloc, _ؤند, fiğe_, 
   {{0x628d01aa,0x6aa101ab,0x290c011f,0x6f0101ac}},	//   _paco, _knof, _ihfa_, kloc, 
   {{0x6f00084c,0x628c0333,0x673800fb,0x57440116}},	//   jloc, _qaco, mptj, _өзәм_, 
   {{0xc104037b,0x628d01ad,0x807800db,0x00000000}},	// [17210] موري, _vaco, лбас_, --, 
   {{0x628d01ae,0x3d08043b,0x6b9901af,0x6b04031c}},	//   _waco, kúwa_, _ortg, _ཅེའོ_, 
   {{0x6aa101b0,0xa25800d2,0x6f0101b1,0x00000000}},	//   _onof, _hlôm, floc, --, 
   {{0x2eb400dc,0x4430b2fe,0x26c80051,0x6f0101b2}},	//   _अकृत, lcz_, nhco_, gloc, 
   {{0x6b98aca0,0xdb00012d,0x7c840092,0x2004000d}},	//   _artg, zynó, _በጽሑፍ_, ünib_, 
   {{0x6aa101b3,0x443101b4,0x00000000,0x00000000}},	//   _anof, ncz_, --, --, 
   {{0xde6406bb,0x3b8401d5,0x00000000,0x00000000}},	//   _възп, ёлиг, --, --, 
   {{0x6f0101b5,0x6aa00142,0x7f94014b,0x00000000}},	//   cloc, _cnof, _каҳх, --, 
   {{0xc8780790,0x69040162,0x443001ef,0x00000000}},	//   ziğe_, rðen, kcz_, --, 
   {{0xb92c02d3,0x6aa101b6,0x44300010,0x77380395}},	//   _ተባሂሎ, _enof, jcz_, лямс_, 
   {{0x30f816d1,0xf62401d5,0x00000000,0x00000000}},	//   ्ततः_, йдно, --, --, 
   {{0x6aa00158,0x00000000,0x00000000,0x00000000}},	//   _gnof, --, --, --, 
   {{0x290c0327,0xddd82ba4,0x6738017a,0x60c402d0}},	//   _fhfa_, _lauž, aptj, _oljm, 
   {{0xb4c00b7d,0x798901b7,0xd8380024,0xc8780790}},	//   ंसे_, mwew, _рэд_, tiğe_, 
   {{0xddd80010,0x798804ba,0x2ee40200,0x00000000}},	//   _nauž, lwew, ynof_, --, 
   {{0xfaf80421,0x60c401a6,0xc87805d1,0xb22501b8}},	//   noū_, _aljm, riğe_, смал, 
   {{0x6f00a1d6,0xe294241e,0x443001ef,0x00000000}},	// [17220] vloc, щат_, bcz_, --, 
   {{0xb464026a,0xf8b80fc8,0x6f0001f5,0xddd80064}},	//   _укол, ेसिय, wloc, _bauž, 
   {{0xee386145,0x61ecbb99,0x7988004c,0xe0900023}},	//   гне_, _excl, hwew, _መዛዘሚ_, 
   {{0x79880337,0xddd80153,0x3f5c02d2,0x00000000}},	//   kwew, _dauž, _sáuð_, --, 
   {{0x6f0101b9,0x63a001ab,0x00000000,0x00000000}},	//   rloc, _ànnr, --, --, 
   {{0x798802ce,0x6da401b9,0x5d8000d1,0x00000000}},	//   dwew, _қиза, سلىل, --, 
   {{0x6f0101ba,0xddd80171,0x00000000,0x00000000}},	//   ploc, _gauž, --, --, 
   {{0x290c04ba,0x320101bb,0x2004012d,0x4430012d}},	//   _shfa_, _kyky_, żnic_, zcz_, 
   {{0xfc3006d6,0x798901bc,0xddd901bd,0xa3dc0d2e}},	//   _aṋu_, gwew, _zauž, _देन_, 
   {{0x30f80a28,0xab2901be,0x48c80183,0xe78406ed}},	//   ्तिः_, _божа_, ৰক্ৰ, бумо, 
   {{0x6b9804cc,0x2078010f,0xbbc40066,0x00000000}},	//   _urtg, נאטא, _وآمو, --, 
   {{0x6aa005b8,0x79880337,0xa3dc000d,0x00000000}},	//   _unof, bwew, _दइब_, --, 
   {{0xd7f4825e,0x30f80882,0xd7c4591c,0x95c84a1d}},	//   _қуш_, ्ताः_, لویه_, бура_, 
   {{0x7b3002b5,0x26c901bf,0x44240158,0x67380fac}},	//   _hāua, shco_, øl_, pptj, 
   {{0x7b3000b0,0x18740375,0x443101c0,0x68f801d5}},	//   _kāua, _העור_, rcz_, motd, 
   {{0x7b141710,0x68f801b9,0x05080154,0x00000000}},	//   _ušut, lotd, লদের_, --, 
   {{0x51840064,0xe4e8028e,0x320002f0,0x1a98010f}},	// [17230] зуха, _معده_, _cyky_, נימע, 
   {{0x68f804fd,0xdef0010c,0x1fa4030c,0x11540006}},	//   notd, ልዮን_, йрег, якую, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x57f80375,0xd7f8008f,0xa2b0033f,0xbebc0064}},	//   נלאו, נהאל, _इकट्, _siūb, 
   {{0x68f80649,0x07440150,0xd13800d8,0x00000000}},	//   kotd, _ﭘﻴﯔ_, _гхс_, --, 
   {{0x60c400f3,0x212801ab,0xe1fc012d,0xec100133}},	//   _uljm, _iuch_, _obóz_, ژوود, 
   {{0x212901c1,0x224901c2,0x68f82244,0xa3dc00c5}},	//   _huch_, _keck_, dotd, _देम_, 
   {{0x2128036b,0x7b1405be,0xf988384b,0x22480036}},	//   _kuch_, _ašur, لنبي_, _jeck_, 
   {{0x9b4004d3,0x2128e942,0x224901c3,0x97040075}},	//   _کۆبو, _juch_, _meck_, ۋېتى, 
   {{0xf77101c4,0x21280c3b,0xb80c032c,0x79880099}},	//   واج_, _much_, _हरदम_, rwew, 
   {{0x212901c5,0x798901c6,0xfd240345,0x0ca8030d}},	//   _luch_, swew, _اوڕێ, _утти_, 
   {{0x09e8015b,0x22480c18,0xb4c03409,0x00000000}},	//   _পররা, _neck_, ंस्_, --, 
   {{0x2128047e,0xa3dc00af,0x798800b5,0x68f8ada3}},	//   _nuch_, _देब_, qwew, botd, 
   {{0x2eb40e7d,0x26d80477,0x68f80477,0x00000000}},	//   _अक्त, _emqo_, cotd, --, 
   {{0x21282d65,0x7ae8055a,0xa5b8748d,0x22486c79}},	//   _auch_, onet, scóp, _beck_, 
   {{0x212901c7,0x00840228,0x00000000,0x00000000}},	//   _buch_, үктү, --, --, 
   {{0x2248c6e6,0x7ae901c8,0x21280142,0xd16401ec}},	// [17240] _deck_, inet, _cuch_, янақ, 
   {{0x212901c9,0x22481368,0x7ae901ca,0xd5e0033f}},	//   _duch_, _eeck_, hnet, _पेयज, 
   {{0x21280639,0x2248039a,0xaf3400f2,0x00000000}},	//   _euch_, _feck_, زرات, --, 
   {{0x224833ec,0x1dd859c9,0x32004132,0x7ae901cb}},	//   _geck_, _मेहत, _tyky_, jnet, 
   {{0x7ae901cc,0x68f8036b,0x00000000,0x00000000}},	//   dnet, yotd, --, --, 
   {{0xd0e81d10,0x7ae801c0,0x65980a1e,0x22480036}},	//   _اکرم_, enet, יינק, _zeck_, 
   {{0x21280a40,0x7b3002b5,0x7ae901cd,0x68f901ce}},	//   _zuch_, _pāua, fnet, votd, 
   {{0x2128047e,0x6728022e,0x4a54cec6,0x52b81cd2}},	//   _yuch_, _rufj, чкис, _इकोस, 
   {{0x68f8084c,0x672901cf,0xbd7c0023,0x9960009d}},	//   totd, _sufj, _ኩላቶም_, мтэл, 
   {{0xa258002d,0x7ae901d0,0xa17800df,0x00000000}},	//   _plôk, anet, סטיט, --, 
   {{0x7ae901d1,0x7b3004fe,0xa09800c8,0x68f901d2}},	//   bnet, _hāun, בייט, rotd, 
   {{0x7b3000b0,0x68f8022e,0x00000000,0x00000000}},	//   _kāun, sotd, --, --, 
   {{0x224901d3,0x2bdc2983,0x68f80158,0x00000000}},	//   _reck_, _केतू_, potd, --, 
   {{0x2248222c,0x7b3002b1,0xd5b80953,0x212901d4}},	//   _seck_, _māun, іся_, _ruch_, 
   {{0x57f06fbd,0x533501d5,0x212901d6,0x224901d7}},	//   _општ, дест, _such_, _peck_, 
   {{0x33380175,0x00000000,0x00000000,0x00000000}},	//   _dtpx_, --, --, --, 
   {{0x7b3003a0,0xf8ac350a,0x2128016d,0x841402dd}},	// [17250] _nāun, _شکی_, _quch_, імұх, 
   {{0x7ae901d8,0x212801a6,0x7aec3858,0x22482305}},	//   znet, _vuch_, čati, _weck_, 
   {{0x7ae901d9,0x224901da,0xeff402d3,0x00000000}},	//   ynet, _teck_, _ፈነወ_, --, 
   {{0x2128a2b2,0x33f80375,0x00000000,0x00000000}},	//   _tuch_, _להתנ, --, --, 
   {{0xa3dcd825,0x7ae901db,0xd01001d3,0x00000000}},	//   _देत_, vnet, فلے_, --, 
   {{0xe7c807b6,0x7ae87def,0x00000000,0x00000000}},	//   ानाप, wnet, --, --, 
   {{0xdcf80841,0x30f8043e,0x00000000,0x00000000}},	//   _upuč, ्तरः_, --, --, 
   {{0xe7fc0c2e,0x1fc000cc,0xd13000f1,0x00000000}},	//   _उड़ा_, ্পদস, _سمې_, --, 
   {{0x7964007b,0x00000000,0x00000000,0x00000000}},	//   أطعم, --, --, --, 
   {{0x7ae901dc,0x00000000,0x00000000,0x00000000}},	//   snet, --, --, --, 
   {{0x7ae901dd,0x00000000,0x00000000,0x00000000}},	//   pnet, --, --, --, 
   {{0x7b14010b,0xca7400d1,0x7ae8a3ff,0x00000000}},	//   _эдех, _يانغ, qnet, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe614005b,0x490400cf,0xdb0000e5,0x00000000}},	//   ядя_, _قونق, gynö, --, 
   {{0xb9f80092,0xc4080014,0xf4800023,0x00000000}},	//   _ህል_, ۅتہٕ_, _ኪዛረብ_, --, 
   {{0x1da81be1,0x00000000,0x00000000,0x00000000}},	//   चमात, --, --, --, 
   {{0x224407d6,0xc40801d9,0x00000000,0x00000000}},	// [17260] япти_, متہٕ_, --, --, 
   {{0x7b3002b1,0x8fc400c7,0x00000000,0x00000000}},	//   _rāun, мазҵ, --, --, 
   {{0x7b300b23,0x00000000,0x00000000,0x00000000}},	//   _sāun, --, --, --, 
   {{0x7b300374,0x9dc01870,0x6ad8000d,0xa75800df}},	//   _pāun, ﯩﻠﯩﺸ, _बगेर, מדער, 
   {{0x4c9501de,0xe2980375,0x2c44001f,0x65c00055}},	//   дилс, _השכר, _ያቀረቡ, _gįhā, 
   {{0xeb481b0a,0xd68001ec,0x00000000,0x00000000}},	//   бчик_, _ﺩﻤﻴﺭ_, --, --, 
   {{0x6fb41de7,0x930002f5,0x96cc05d7,0x6e447579}},	//   _عمرا, ্দীপ_, ासाउ, _невз, 
   {{0x950c0003,0x7b3000b0,0x893828a8,0x49380a93}},	//   _གེའི_, _tāun, опис_, озию_, 
   {{0xbb2c6788,0x3be80daf,0x00000000,0x00000000}},	//   ﯩﻨﻰ_, йләү_, --, --, 
   {{0x1ca81b4b,0x02c8085c,0x47346ff7,0x3c3000d8}},	//   _བོར_, _रत्न, мнос, _vôvó_, 
   {{0xa098008f,0xf8ac8863,0x00000000,0x00000000}},	//   זייט, شکو_, --, --, 
   {{0xe0dc007f,0xbebc00c0,0xa96801f4,0x00000000}},	//   _awòl_, _liūn, _гида_, --, 
   {{0x5ce000f7,0x69c405ac,0x95c800d8,0xe72800ec}},	//   _تكەل, øked, пура_, _ڏسبو_, 
   {{0xbebc0064,0x00000000,0x00000000,0x00000000}},	//   _niūn, --, --, --, 
   {{0xe0dc033b,0x18780302,0xd7ec07d5,0x1ca8031c}},	//   _dwòl_, _הטוב, _чу_, _བོལ_, 
   {{0x2c1c00cd,0x00000000,0x00000000,0x00000000}},	//   येयं_, --, --, --, 
   {{0x44f48af4,0x3cdc0073,0x80a80073,0x0738009f}},	// [17270] _опис, कोडे_, घाले, _ايڊڊ_, 
   {{0xdb000129,0xbebc0064,0x00000000,0x00000000}},	//   lynô, _ciūn, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x0eb80220,0xc2100050,0x7d1c00e5,0x00000000}},	//   зушы_, _لٔج_, _éssz, --, 
   {{0x3d080574,0x9404013f,0x518460a9,0x00000000}},	//   ितले_, ɛmɑ_, _пура, --, 
   {{0x2bdc033d,0x4e1804fb,0x6da0036b,0x93788dff}},	//   _केहू_, ستند_, тиша, _بصیر_, 
   {{0xada000d8,0x4fc400db,0xfe54005b,0x3f90012d}},	//   _éúni, _كەكە, _оквэ, _uszu_, 
   {{0xab240395,0x00000000,0x00000000,0x00000000}},	//   моща_, --, --, --, 
   {{0xa3dc007d,0x7c780092,0xfde802f2,0xf7700116}},	//   _देस_, ከበረው_, _بکاو_, ھاد_, 
   {{0xf7700214,0x00000000,0x00000000,0x00000000}},	//   پاد_, --, --, --, 
   {{0xbb401c5c,0x0ca8094f,0x00000000,0x00000000}},	//   _ﻛﯩﻢ_, _этти_, --, --, 
   {{0xabf80375,0xc4c80375,0xca480244,0x00000000}},	//   _והער, _דג_, _فلمه_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa3dc2017,0x1ca80003,0x18244e5d,0x00000000}},	//   _देह_, _བོས_, _عقبی_, --, 
   {{0xdee81b49,0xe85050d8,0x00000000,0x00000000}},	//   _ህጻን_, _شنيد, --, --, 
   {{0x71a40124,0x00000000,0x00000000,0x00000000}},	//   мабз, --, --, --, 
   {{0x312501df,0xf1dc4ff1,0x85640022,0x74b8004e}},	// [17280] ддаг, _नेशन, _зныҧ, _дунс_, 
   {{0xdcf80bb8,0xa3dc9e3f,0x7b300421,0x25bc0e78}},	//   _osuđ, _देव_, _pāul, äule_, 
   {{0xe8540092,0x00000000,0x00000000,0x00000000}},	//   _ለአብነ, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x1be004aa,0x00000000,0x00000000,0x00000000}},	//   _केबल_, --, --, --, 
   {{0xdca09100,0x7b300421,0x409414b7,0x273800b8}},	//   качи, _tāul, _прст, _hīne_, 
   {{0x602002d5,0x09b80d2c,0xee38009b,0x00000000}},	//   _адра, ेन्य, _мнв_, --, 
   {{0x260c0073,0x5fd8011a,0x00000000,0x00000000}},	//   _ठरली_, _וחלק, --, --, 
   {{0xadb800c6,0xdee0a20e,0xde000354,0xa020032e}},	//   _بهذا_, _роти, _апти, _óöry, 
   {{0x6d4101e0,0x273800b8,0xbea40145,0x889401c4}},	//   mpoa, _līne_, _يۇەن_, хиох, 
   {{0xda6d01e1,0xeb980262,0xf9680240,0x00000000}},	//   _ия_, _фие_, _ተነቢቡ_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d4001c0,0xd6d80276,0x25bc054e,0x75a400c7}},	//   npoa, фтэ_, âul_, нырҧ, 
   {{0xe3b101e2,0x29180241,0x01c40022,0x00000000}},	//   پرس_, _òpa_, ҭраҭ, --, 
   {{0xa3dc509f,0x4904129d,0x4914000d,0x00000000}},	//   _देश_, _قوچق, _नीयो_, --, 
   {{0x7d04006a,0x2bb42db8,0xa25800e4,0x83a40022}},	//   _kîrî, _अपना, _moôg, _ҧынҵ, 
   {{0xa3dc09fd,0x6d40002d,0xc11400d8,0x00000000}},	// [17290] _देर_, jpoa, емај, --, 
   {{0x439411e5,0x395876ad,0x6d40000f,0x75d501e3}},	//   _заос, ássi_, dpoa, _سيپا, 
   {{0x6d54025a,0x38540092,0x00000000,0x00000000}},	//   âyan, _መጠባበ, --, --, 
   {{0xa25807ea,0x3ea80428,0xe0dc02e2,0x00000000}},	//   _clôt, ñat_, _kwòk_, --, 
   {{0x522501e4,0x6d440139,0x00000000,0x00000000}},	//   _афра, _çkal, --, --, 
   {{0xe0542580,0x3dc80327,0x00000000,0x00000000}},	//   _آیات_, ġaw_, --, --, 
   {{0x780d01e5,0x7b300418,0x6d400b23,0xe1fc0332}},	//   _हरेक_, _tāum, apoa, _gcór_, 
   {{0xfcd801ed,0xdb180139,0x00000000,0x00000000}},	//   _کارڈ_, _özüg, --, --, 
   {{0x7b3000b0,0x395807de,0x6d540113,0xe8c804aa}},	//   _kāuk, éss_, áyat, िसूच, 
   {{0xb4bc033d,0xb8800122,0x00000000,0x00000000}},	//   _आवे_, _číse, --, --, 
   {{0x7b3000b0,0xdcf807f5,0xa3dc00af,0xe8ec0220}},	//   _māuk, _usuđ, _देल_, _ұл_, 
   {{0xa5b8937c,0xeaac02d5,0x55c400d1,0x00000000}},	//   lcóy, _ёй_, вамғ, --, 
   {{0xe9cc412c,0xe8ec6576,0xa92000d0,0x00000000}},	//   _ск_, _бл_, šľal, --, 
   {{0xbebc0953,0x2bb405d7,0x00000000,0x00000000}},	//   _siūl, _अपमा, --, --, 
   {{0x638101e6,0x2004012d,0x00000000,0x00000000}},	//   лгра, żnij_, --, --, 
   {{0x7b040077,0xca280131,0xb224011c,0x00000000}},	//   móus, ﻣﻪﺱ_, ембл, --, 
   {{0xe1fc00c6,0x27380171,0x00000000,0x00000000}},	// [172a0] _scór_, _vīne_, --, --, 
   {{0xc05800d6,0x92e00eac,0xe61406a6,0x00000000}},	//   дії_, দকে_, _яды_, --, 
   {{0xb9f80020,0xdfcc0451,0x273800ef,0x00000000}},	//   _ህግ_, ٽين_, _tīne_, --, 
   {{0xf1d001af,0x3de000eb,0x00000000,0x00000000}},	//   _йөзө, _বড়ল, --, --, 
   {{0x4ea40184,0x00000000,0x00000000,0x00000000}},	//   ерҙа, --, --, --, 
   {{0x6d4101e7,0xec14151e,0x9ac0031c,0x9eb400c7}},	//   rpoa, нелә_, _ċċaq, _ҧштә, 
   {{0x7d04145e,0xa2580770,0x6d4101e8,0x00000000}},	//   _sîrî, _tlôt, spoa, --, 
   {{0x3190007f,0xe94401c0,0x6d4080c3,0x30f800cd}},	//   _kņz_, нхоо, ppoa, ्तकः_, 
   {{0xb8800419,0x6f0101e9,0x00000000,0x00000000}},	//   _číre, mooc, --, --, 
   {{0xeb9901ea,0x61d80375,0x00000000,0x00000000}},	//   _низ_, פקיד, --, --, 
   {{0xa3dc006d,0xdcac0372,0x7b040077,0x97a00395}},	//   _दें_, _دىل_, góus, грял, 
   {{0x569501eb,0xfaf40032,0x6f00009a,0x14c800c7}},	//   гают, _үҫә_, nooc, ҭыри_, 
   {{0x3eb8068c,0xc6080154,0x69cc0115,0x00000000}},	//   _òste_, রেনা_, ĝbes, --, 
   {{0x6f000175,0x98a0009b,0x20040254,0x00000000}},	//   hooc, _биље, ünik_, --, 
   {{0x2cbcd2e6,0x7b040077,0xe78501ec,0x291d01ed}},	//   _motd_, cóus, _чуло, mmta_, 
   {{0xe77400b5,0x2004033f,0x92940006,0xdecc04b2}},	//   _iサ_, żnik_, ласц, ባቢን_, 
   {{0x69d403ee,0x6f003204,0x2ee4002d,0xa088008e}},	// [172b0] _üyed, dooc, diof_, зсез_, 
   {{0x656d01ee,0xd1b81eeb,0x00000000,0x00000000}},	//   much, راقا_, --, --, 
   {{0x291d01ef,0x6f00007c,0xb60002d2,0x00000000}},	//   imta_, fooc, _íára, --, 
   {{0xf4100302,0x656c009f,0x26c8004b,0x6f0001f5}},	//   _כפי_, ouch, nkco_, gooc, 
   {{0x656d01f0,0x2cbc0ac5,0x7b3002b5,0x00000000}},	//   nuch, _botd_, _tāuk, --, 
   {{0x656c01ab,0xcd0400d8,0x00000000,0x00000000}},	//   iuch, лчји, --, --, 
   {{0x656d01f1,0xeb940815,0x543c010f,0x6f0001ef}},	//   huch, вищ_, לעגא, booc, 
   {{0x656d01f2,0xada401f1,0x291c208d,0x6f00011f}},	//   kuch, _slúž, emta_, cooc, 
   {{0x7b3031cf,0x3ead01f3,0x656d01f4,0x9a840166}},	//   _māui, _inet_, juch, _җуел, 
   {{0x656d01f5,0x7b040077,0x4d9802d5,0xddc80115}},	//   duch, tóus, _якую_, nggŭ, 
   {{0x366901f6,0x3a741d16,0x5724036b,0x3ead01f7}},	//   мано_, _алер, лпоғ, _knet_, 
   {{0x656d01f8,0x32cc010e,0x28a432ed,0xa3dc0037}},	//   fuch, _aýyn_, _कोठि, _देइ_, 
   {{0x656c105c,0x3ead01f9,0xa6e00165,0xf98802da}},	//   guch, _mnet_, æðat, _آنتي_, 
   {{0x3b0c0eda,0x55c40184,0x7b3000b0,0x2c1c00cd}},	//   lleq_, _ҡайғ, _pāuh, येवं_, 
   {{0xe7b02cb0,0x3ead01fa,0x656c02d0,0x00000000}},	//   _نمود, _onet_, auch, --, 
   {{0x35a4035b,0x3190007f,0x00000000,0x00000000}},	//   _ааиг, _pņz_, --, --, 
   {{0x656d01fb,0xb22501fc,0x00000000,0x00000000}},	// [172c0] cuch, тмал, --, --, 
   {{0xe040dc3f,0x7b3002b1,0x3ead01fd,0x273800b8}},	//   инуи, _tāuh, _anet_, _hīna_, 
   {{0x273806c8,0xa3dc1804,0x2ee4014b,0x6f00004e}},	//   _kīna_, _देऊ_, tiof_, tooc, 
   {{0x3ead01fe,0xbf6501ff,0xe3540375,0x00000000}},	//   _cnet_, ادلو, _בשטח_, --, 
   {{0x6f0004c4,0xfca8004b,0x6c349924,0x27380055}},	//   rooc, کانو_, نفشا, _mīna_, 
   {{0xdd8c04d3,0x3ead0200,0x3cdc012c,0x6f00058a}},	//   توه_, _enet_, कोले_, sooc, 
   {{0x656d0201,0x6f000004,0x3eac00d8,0xb88001ef}},	//   zuch, pooc, _fnet_, _čípe, 
   {{0x49750202,0x16cc0490,0xada400c7,0x656d0203}},	//   глис, ासोब, _иабл, yuch, 
   {{0xc8780365,0xa3dcccc0,0xec78036b,0xb5002144}},	//   liği_, _देई_, _опа_, लकाय_, 
   {{0xa8a4d4d0,0x1be10204,0xe77400b5,0x656d0205}},	//   трик, _केवल_, _pサ_, vuch, 
   {{0x656d0206,0xc87805d1,0x2d480023,0x00000000}},	//   wuch, niği_, _ዝተኣከ, --, 
   {{0x4f342440,0x27380055,0x00000000,0x00000000}},	//   ርቶዶክ, _cīna_, --, --, 
   {{0x84c46d45,0x28a40490,0xd90c01ed,0x273800b8}},	//   гәнд, _कोथि, _ڈیٹ_, _dīna_, 
   {{0xa3dcfeb4,0xc2c40ccb,0x74f400c7,0xe4e401ec}},	//   _देउ_, گيري, лҵыр_, тімн, 
   {{0x656d0207,0x69c401f4,0x00000000,0x00000000}},	//   such, äkef, --, --, 
   {{0x656d0208,0xc8780365,0x8c3c0139,0x534403fb}},	//   puch, diği_, _inğu, рхра, 
   {{0x656d01c1,0x3ea407d6,0x3eac0036,0xddd80306}},	// [172d0] quch, ғилг, _rnet_, _obuš, 
   {{0xc87805d1,0x2744001f,0xe0d0007b,0x835400ec}},	//   fiği_, _የተሰበ, جزر_, _مھرا, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x1ca83ae9,0x3ead0209,0xcc880133,0x00000000}},	//   _བོང_, _qnet_, ێننه_, --, 
   {{0x0e65020a,0x8c3c03e0,0x6d5400e4,0x00000000}},	//   ркін, _mağf, áyap, --, 
   {{0x3ead020b,0xbc39020c,0x6930033f,0x629c0477}},	//   _wnet_, رستا_, _złeg, ldqo, 
   {{0x69c44673,0xc8780205,0x3b0800f3,0x00000000}},	//   øken, ciği_, неко_, --, 
   {{0x8d75020d,0x4ea40064,0x59600131,0x3eac0108}},	//   _چالا, _круа, аниғ, _unet_, 
   {{0x8d74156d,0x1be00034,0x3b0d020e,0xf9880451}},	//   _نالا, _केरल_, rleq_, رندي_, 
   {{0xe8f5020f,0x32cc0432,0x6fd80154,0xdd9001af}},	//   ллы_, _aýyl_, _বুয়ে, _йағы, 
   {{0xdee00b82,0x27380055,0xb3700023,0x00000000}},	//   _ዜማን_, _pīna_, ብባዕን_, --, 
   {{0x4ae407d6,0x1db42a67,0x69300210,0x00000000}},	//   _кўча, _आपात, _błed, --, 
   {{0x7ae90210,0x3a740022,0xc87805d1,0x273800e2}},	//   miet, _алҵр, ziği_, _vīna_, 
   {{0x7ae90211,0x81e8015b,0xf5044df8,0xc8780205}},	//   liet, যথা_, узго, yiği_, 
   {{0xb6a40e26,0x7ae8005a,0x21640116,0x98a001af}},	//   _бийл, oiet, һити_, _биҙе, 
   {{0x7ae90212,0xd2450213,0xa2e0024c,0x00000000}},	//   niet, рмақ, босд, --, 
   {{0x21650214,0x98a4110c,0x7b3002b5,0x70850215}},	// [172e0] лити_, _linč_, _tāuw, лгаз, 
   {{0x76540a55,0xc8780365,0x65980a7c,0x00000000}},	//   _heyy, tiği_, _טיפק, --, 
   {{0x7ae90216,0x7654022f,0xb4c000e1,0x8c3c0166}},	//   kiet, _keyy, ूसी_, _yağf, 
   {{0xc87803ee,0x0ccc0882,0x7ae90217,0x76540205}},	//   riği_, ऽस्म, jiet, _jeyy, 
   {{0xd1f0001f,0xc8780790,0x765403b9,0x00000000}},	//   _ቀርቦ_, siği_, _meyy, --, 
   {{0x7654011f,0x3d1801d3,0x7534010e,0xe8540092}},	//   _leyy, نٹنگ_, _muyz, ለቤትነ, 
   {{0x7ae80373,0x799802d0,0x00000000,0x00000000}},	//   fiet, _asww, --, --, 
   {{0x7ae90218,0x76540548,0xca2800d1,0x00000000}},	//   giet, _neyy, نۋان_, --, 
   {{0xac74282b,0x2bb44a76,0x8d290219,0x3eb80e89}},	//   _مااش, _अपवा, _анаң_, _òsta_, 
   {{0x2b5c5e71,0x00000000,0x00000000,0x00000000}},	//   _tvtc_, --, --, --, 
   {{0x7ae9021a,0x32cc010e,0x76542791,0x00000000}},	//   biet, _aýym_, _beyy, --, 
   {{0x6b9804fb,0x7ae9021b,0x391405f5,0xa8600032}},	//   _istg, ciet, лмөр, шеүҙ, 
   {{0x765400a2,0x97a000c7,0x953802e8,0xa884022e}},	//   _deyy, _ҳрыл, лзят_, _билð_, 
   {{0x76540a55,0x68900b43,0xa7d45ab5,0x00000000}},	//   _eeyy, _ایدئ, _متعص, --, 
   {{0xa3dc534e,0x765403e0,0x4394b154,0x939400e5}},	//   _देख_, _feyy, шавс, یجہا, 
   {{0x76543ce5,0x273800b8,0x00000000,0x00000000}},	//   _geyy, _hīno_, --, --, 
   {{0xdcf81326,0x27380240,0x753400a2,0x20680ce8}},	// [172f0] _upuć, _hën_, _guyz, ешеп_, 
   {{0x7ae9021c,0x7b3002b1,0x95840034,0x6b989108}},	//   ziet, _kāut, żący, _ostg, 
   {{0x27381bce,0x8c3c05d1,0xca281df2,0x1fa5021d}},	//   _jën_, _mağd, ﻣﺪﺍ_, ыраг, 
   {{0x7ae9021e,0x27381574,0x6454026c,0xa280034c}},	//   xiet, _mën_, _hexi, _دیرو, 
   {{0x7ae9021f,0x4e790220,0x6b981570,0x69c4964d}},	//   viet, احمد_, _astg, økel, 
   {{0x7ae8068f,0x4c843981,0x8c3c03b9,0x4fc400cf}},	//   wiet, йлів, _nağd, _گەمە, 
   {{0x7ae90221,0x2738044e,0x8b6406ba,0x64550222}},	//   tiet, _nën_, مايم, _mexi, 
   {{0x64550223,0x2bb4060c,0x4fc410e0,0x48b40154}},	//   _lexi, _अपरा, _دەمە, টসোর, 
   {{0x8c3c9d58,0x6b990224,0xc9440220,0x273801c7}},	//   _bağd, _estg, бдық, _aën_, 
   {{0x7ae90225,0x2738e5c7,0xed4c00b2,0xe0dc02e2}},	//   siet, _bën_, _آھن_, _gwòt_, 
   {{0x3f810226,0xf0900302,0x273800b8,0x8c3c1b0d}},	//   nthu_, חני_, _dīno_, _dağd, 
   {{0xf6243c85,0x3f800368,0x27380221,0x765406be}},	//   идно, ithu_, _dën_, _qeyy, 
   {{0x64550227,0xaa8400db,0xd6c401d3,0x76540055}},	//   _bexi, _ئچىم_, لمگی, _veyy, 
   {{0x7654007f,0xa9640eba,0x69c40108,0xe9647de7}},	//   _weyy, _тиша_, äkee, _ташл_, 
   {{0x27383d27,0x64550228,0xe29c05f7,0xd7600403}},	//   _gën_, _dexi, _bað_, _انبی, 
   {{0x6454127b,0x32445d88,0x00000000,0x00000000}},	//   _eexi, реаг, --, --, 
   {{0xe2950229,0x2738006a,0x2325022a,0x3f8000a9}},	// [17300] шат_, _zën_, роти_, ethu_, 
   {{0xe0d5022b,0x6ad00882,0xe3e4066d,0x6454102c}},	//   аву_, _तत्र, اکین_, _gexi, 
   {{0x6e45022c,0x3f800165,0xe29c02d2,0x010800db}},	//   لنام, gthu_, _fað_, اتقو_, 
   {{0xe0dc0100,0xf2a40262,0xaf0402dd,0x72d00137}},	//   _bwòs_, _тимп, шпел, _بەرچ, 
   {{0x2d95022d,0x3f8003a2,0xe294784b,0x6454009a}},	//   ррес, athu_, _тая_, _yexi, 
   {{0x7054592e,0x9c540063,0x48b00154,0x00000000}},	//   _خنسا, ашћу_, _ছত্র, --, 
   {{0xee3810a7,0x3f800051,0xdb54a5de,0x00000000}},	//   _анб_, cthu_, аюы_, --, 
   {{0x8c3c029f,0xef1801af,0xfbe400cc,0x00000000}},	//   _sağd, _рмб_, _পুহত, --, 
   {{0xee09022e,0xe0dc0100,0x2739022f,0x00000000}},	//   _реал_, _gwòs_, _sën_, --, 
   {{0xdd8c2aa5,0x28a42122,0x0a500092,0x8c3c0205}},	//   _توك_, _कोशि, _መጀመራ, _bağe, 
   {{0x645436ed,0x48440020,0xdca00166,0x27380200}},	//   _rexi, _የአውሮ, _фахи, _qën_, 
   {{0x28a42cce,0x8c3c0166,0x27380200,0x00000000}},	//   _कोरि, _wağd, _vën_, --, 
   {{0xe29c06ea,0x96f80395,0x00000000,0x00000000}},	//   _rað_, реят_, --, --, 
   {{0x7b310230,0xe29c0162,0x2738036e,0x00000000}},	//   _tāut, _sað_, _tën_, --, 
   {{0x6454e63d,0x7b300374,0xd3a41fd4,0xd82c084c}},	//   _vexi, _hāur, ортп, _фэ_, 
   {{0x7b300374,0x470400cd,0x48f00118,0x00000000}},	//   _kāur, _daṃṣ, ीकको_, --, 
   {{0x64550231,0x225802d1,0x57240137,0x94440014}},	// [17310] _texi, raqk_, _بىيك, _ژھٲن, 
   {{0x44989dc2,0x7b3002b5,0x64540393,0xbebc0024}},	//   _свою_, _māur, _uexi, _liūt, 
   {{0xe29c8c07,0xd3a400a8,0x39b4016b,0x2a6401b9}},	//   _tað_, _дряп, rɛsɛ_, _odob_, 
   {{0x3f8000a9,0x7414e582,0xa14401d9,0x92940024}},	//   rthu_, _دوپا, _نیرٕ_, _даюц, 
   {{0x1ca8f7c6,0x98acd657,0x39b40085,0xd1f0001f}},	//   _བོད_, _lugā_, pɛsɛ_, _ቀርቶ_, 
   {{0x2a650232,0x23a401e4,0x28a477ca,0x20040254}},	//   _adob_, _kĵj_, _कोलि, ünis_, 
   {{0x8c9402dd,0x656c0112,0x8c3c4dd9,0x00000000}},	//   ірші, hrch, _bağb, --, 
   {{0xa2580022,0xba3c013a,0x00000000,0x00000000}},	//   _moôo, ddůc, --, --, 
   {{0x98a46845,0xf9900597,0x2e440014,0x8c3c06be}},	//   _ainā_, سبة_, _طفلہ, _dağb, 
   {{0x2a640295,0xbebc0055,0xdff801f9,0x8c4400f3}},	//   _edob_, _bhūg, _एखाद_, _међе, 
   {{0x656d0233,0x69d405d1,0xb6a401b9,0xbc4401af}},	//   erch, _üyen, бинл, _күҙа_, 
   {{0xc4c80375,0x98a400b8,0xca7400c0,0x00000000}},	//   _אג_, _dinā_, _душы, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x984811ed,0x2a640356,0xe800012d,0x00000000}},	//   _ряда_, _zdob_, _रुका_, --, 
   {{0x656d0234,0x1ca81b4b,0xf7880129,0x24800092}},	//   arch, _བོན_, _deçà_, _ርዝመት_, 
   {{0x3d080574,0x23a401e4,0x38c80244,0x00000000}},	//   ाकडे_, _dĵj_, _جاڤی_, --, 
   {{0x8e2002dd,0xf06400cf,0xe0cc0014,0x00000000}},	// [17320] гiн_, йкап, کٲل_, --, 
   {{0x311401b9,0x00000000,0x00000000,0x00000000}},	//   ёфас, --, --, --, 
   {{0xef844ea0,0xa858010f,0x00000000,0x00000000}},	//   слеп, רדעכ, --, --, 
   {{0x85340acb,0xad64007b,0xa778010f,0x00000000}},	//   _دویچ, ماته, טרעפ, --, 
   {{0x2ce85402,0x63f40405,0x38a000b0,0x20040ba1}},	//   лько_, _نفیس_, _kōrē_, ünir_, 
   {{0x614055d9,0x659808a8,0x66e800bc,0xbebc00c0}},	//   _хера, טינק, yřko, _siūt, 
   {{0xbebc00cd,0x6090001f,0xceb80139,0xaff8020c}},	//   _bhūd, _ማምጣት_, _вәл_, _صفرا_, 
   {{0x656c0cfd,0xbebc00b8,0x8c3c05d1,0xfe740107}},	//   yrch, _chūd, _bağc, _дӯш_, 
   {{0x7b3002b5,0xdea02099,0x00000000,0x00000000}},	//   _pāur, _ریوی, --, --, 
   {{0xdd8d0235,0x656c2195,0xe1fc04d4,0x8c3c0790}},	//   _سوم_, vrch, _odón_, _dağc, 
   {{0xa2d8227c,0xe0dc02e2,0x6a840120,0x656c0142}},	//   नसम्, _otòn_, _глеа, wrch, 
   {{0x79e801d3,0x656c01a9,0x98a400dc,0x00000000}},	//   اویہ_, trch, _vinā_, --, 
   {{0x9aa003e6,0x7b300374,0x7c4800d8,0x00000000}},	//   _رموو, _tāur, _àprá, --, 
   {{0x98a10236,0x6aa00093,0x7b3000b0,0x98a40b23}},	//   _ниче, _haof, _hāup, _tinā_, 
   {{0xddd84baa,0x6aa00184,0xdce80311,0x656c0175}},	//   _zduń, _kaof, lugă, srch, 
   {{0x656d0237,0x6aa006d9,0xd258030d,0x8c3c03e0}},	//   prch, _jaof, йцу_, _yağc, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [17330] --, --, --, --, 
   {{0x6aa10238,0x43950239,0x88bc00bc,0xbebc0153}},	//   _laof, _даос, změn, _niūr, 
   {{0xa2240214,0xd918123b,0x00000000,0x00000000}},	//   _گرده, נובל, --, --, 
   {{0xe0dc02bd,0x6aa0b56e,0xbbe800f2,0x00000000}},	//   _ewòp_, _naof, یرغم_, --, 
   {{0xdb040724,0xa5240327,0xa2240214,0xd25000e3}},	//   ğlüm, _རྫོག_, _درده, _سنّ_, 
   {{0x98a4054e,0xf1b0011a,0x00000000,0x00000000}},	//   _mină_, _קסם_, --, --, 
   {{0x6aa008cd,0x4fc475b3,0x98a40356,0x8c3c03e0}},	//   _baof, _еста, _lină_, _sağc, 
   {{0x60c4014f,0x290c01a9,0x394401b9,0x1ca8031c}},	//   _hojm, _akfa_, ониг, _བོམ_, 
   {{0x69d40ab7,0x7e69023a,0x6aa1023b,0x00000000}},	//   _üyel, _idep, _daof, --, 
   {{0xd76431f0,0x69c4005b,0x378800db,0x00000000}},	//   مەتى_, äkea, абоо_, --, 
   {{0xb8d018ef,0x60c5023c,0x6aa1023d,0x7e69023e}},	//   _ऑफ_, _mojm, _faof, _kdep, 
   {{0x60c5023f,0x6aa00332,0x00000000,0x00000000}},	//   _lojm, _gaof, --, --, 
   {{0x290c0093,0x98a4054e,0xe574011c,0x00000000}},	//   _fkfa_, _cină_, озя_, --, 
   {{0xf7701fc2,0x60c40477,0x6aa0033f,0x8c3c03e0}},	//   _قاب_, _nojm, _zaof, _kağa, 
   {{0x7e690240,0x69203a32,0x57a4010b,0x59a415c0}},	//   _odep, _юмша, _ышда, कटवर, 
   {{0x8c3c07c4,0x7e690241,0x51440220,0x98ac054e}},	//   _mağa, _ndep, здағ, _fugă_, 
   {{0xe0dc0699,0xf1a90242,0x394c0263,0x60c40200}},	// [17340] _pwòp_, جازه_, npes_, _bojm, 
   {{0x394d0243,0x0ef42a27,0x60c40200,0xd6cc00cc}},	//   ipes_, ेक्स_, _cojm, _লগিয, 
   {{0xee390244,0x60c50245,0x7304084c,0x8c3c8411}},	//   ане_, _dojm, _мпоз, _nağa, 
   {{0xe294bbdb,0x394c00b5,0x7d1c00ef,0x00000000}},	//   _даю_, kpes_, _īssa, --, 
   {{0x7e690246,0x6aa005da,0xbebc00b8,0xe0dc02bd}},	//   _ddep, _raof, _bhūb, _twòp_, 
   {{0xafe50247,0x7e690248,0x6aa01140,0xbebc003e}},	//   _догл, _edep, _saof, _chūb, 
   {{0x9b410249,0x394d024a,0x8c3c08a9,0x3d08012d}},	//   ونوو, epes_, _cağa, ाक़े_, 
   {{0x2aa9024b,0x8c3c0b97,0x7c240306,0x00000000}},	//   ртко_, _dağa, ýhra, --, 
   {{0x6aa1024c,0xfe7405f5,0xfe4401ed,0x60c4014f}},	//   _vaof, _хүч_, _رکنی, _yojm, 
   {{0x69d405d1,0x2d84009f,0x98ac0356,0xdce80356}},	//   _üyem, mtoe_, _rugă_, rugă, 
   {{0x6aa0096b,0x2a6406bb,0x273800b0,0x7b309334}},	//   _taof, _дълг, _kīni_, _tāup, 
   {{0xda74010a,0xd1f80092,0x2d480023,0x00000000}},	//   _дяш_, ፋልት_, _ዝሰንከ, --, 
   {{0x2d840660,0x6d44003e,0x26040212,0x95c80022}},	//   ntoe_, _ékad, ючог, оура_, 
   {{0x98a40276,0x8c3c3535,0x00000000,0x00000000}},	//   _vină_, _yağa, --, --, 
   {{0x60c4014f,0x00000000,0x00000000,0x00000000}},	//   _rojm, --, --, --, 
   {{0x60c4045d,0x2d84020c,0x00000000,0x00000000}},	//   _sojm, ktoe_, --, --, 
   {{0x60c40b9d,0x39487b25,0x33200175,0x5185024d}},	// [17350] _pojm, _çast_, _dhkx_, духа, 
   {{0xd25000dd,0x60c40477,0xd4981422,0x00000000}},	//   ٹنے_, _qojm, _дрю_, --, 
   {{0x60c401e4,0x5064074d,0x68f803ac,0x00000000}},	//   _vojm, ьтта, intd, --, 
   {{0x394d024e,0x57f8010f,0xcfc400fe,0x00000000}},	//   ypes_, סלאו, _এইখন, --, 
   {{0xdd99024f,0x8c3c1ae4,0x628c02d0,0x60c4047e}},	//   рше_, _sağa, _ibco, _tojm, 
   {{0xcd290250,0xc104038b,0xbebc00b8,0x3154010f}},	//   يسون_, _روزي, _bhūc, _מישן_, 
   {{0x54580302,0x26d80455,0x32cc00a2,0x5fbc01ad}},	//   חסון_, _olqo_, _eýyu_, _एपिल, 
   {{0x93fc0302,0x68f8035a,0xe8900022,0x00000000}},	//   ילוי, entd, ҕаџь, --, 
   {{0x394c20ef,0x39480135,0x98a40064,0x8c3c0139}},	//   upes_, _ħass_, _liną_, _wağa, 
   {{0x26d80784,0xa92042c6,0xdea000dd,0x8c3c0166}},	//   _alqo_, ндыл, _ریڈی, _tağa, 
   {{0x394d0251,0x1874001f,0x628cc098,0x8c3c0205}},	//   spes_, _በአጭር_, _obco, _kağn, 
   {{0x394d0252,0x68f8119f,0x482400db,0x00000000}},	//   ppes_, antd, بىپق, --, 
   {{0xe0dc6f90,0x28a409fa,0xb8d00011,0x8c3c0139}},	//   _atòm_, _कोकि, _টক_, _mağn, 
   {{0x628d0253,0x26d8014f,0x00000000,0x00000000}},	//   _abco, _elqo_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x36341812,0x6fe000d2,0xb1446830,0x00000000}},	//   _عربس, _lícé, знал, --, 
   {{0x31640129,0x59d811bc,0x90a4013d,0x00000000}},	// [17360] éoz_, यनिर, мгаҗ, --, 
   {{0x628d0254,0x7418015b,0xa0a10255,0x317004ce}},	//   _ebco, _দলীয়_, науд, rryz_, 
   {{0xa5240135,0x273802b1,0xd37001ec,0x8c3c03e0}},	//   _རྫིག_, _pīni_, _جۇز_, _bağn, 
   {{0xb8cc081f,0x4508025c,0x59d90256,0x628c0175}},	//   _ཕལ_, _གཉོར_, यनार, _gbco, 
   {{0x27380171,0x00000000,0x00000000,0x00000000}},	//   _vīni_, --, --, --, 
   {{0x2d842595,0xeaf428d4,0x7b0c0943,0x273800b0}},	//   rtoe_, ुक्त_, ṱule, _hūne_, 
   {{0x2d850257,0x27390258,0x6440002d,0xb60002d2}},	//   stoe_, _tīni_, _ûnie, _íáfa, 
   {{0x69c401f4,0x764401ef,0x00000000,0x00000000}},	//   äkeo, jcky, --, --, 
   {{0x2b4c00d8,0xaac401b9,0xb86400e5,0x00000000}},	//   spfc_, قتکن, ڈاپو, --, 
   {{0x45081b4b,0xb864004b,0x68f80334,0x00000000}},	//   _གཉེར_, واپو, untd, --, 
   {{0xd7f411ed,0x6d400194,0xda6c93fb,0x47c800f1}},	//   зуя_, lqoa, _пя_, زادۍ_, 
   {{0x1ae02d29,0x5b54010f,0xd1d40092,0x68f803ac}},	//   _похм, _זשאן_, ከሰት_, sntd, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x26d8022f,0x7644003e,0x00000000,0x00000000}},	//   _wlqo_, acky, --, --, 
   {{0xf8ac168d,0xd8840451,0x98a00063,0xddc800a2}},	//   _ڵکی_, _رپين_, _чије, kagş, 
   {{0x533418d9,0xba3c00bc,0xd7f8011a,0x00000000}},	//   еест, jdůl, _להול, --, 
   {{0x3cec068f,0x628c00d8,0x00e40214,0x00000000}},	// [17370] _अगले_, _vbco, وتئی, --, 
   {{0xcfc4045e,0x8c3c1ea0,0x55ac010f,0x00000000}},	//   _এইজন, _sağn, _פייַ, --, 
   {{0xee48063f,0xc608015b,0x201c010f,0x00000000}},	//   _ịdịn, রেখা_, _ĝuis_, --, 
   {{0x628c035a,0x44200064,0xe03000db,0xddd801ef}},	//   _ubco, _izh_, _үммө, _zduř, 
   {{0x69c4023a,0x00000000,0x00000000,0x00000000}},	//   äkel, --, --, --, 
   {{0x442002c4,0xd05c013f,0x1ee41fcb,0x8c3c0139}},	//   _kzh_, _mmrɛ, _کوری_, _dağo, 
   {{0x786801ed,0xddc800a2,0x60c001f4,0x00000000}},	//   _jövő, bagş, önmu, --, 
   {{0x394800f0,0x00000000,0x00000000,0x00000000}},	//   озио_, --, --, --, 
   {{0xc8c806ab,0xb9e80116,0x3958007f,0xd6e0012d}},	//   ाउंट, юмиз_, èss_, ółmi_, 
   {{0x7bc40217,0xfd240133,0xe1fc00e5,0x00000000}},	//   øhus, _کوڕێ, _adók_, --, 
   {{0x4420014b,0x37e400fd,0x7d000582,0x8c3c05d1}},	//   _nzh_, фонг, _ijls, _mağl, 
   {{0x8c3c06be,0xa3c00a59,0x00000000,0x00000000}},	//   _lağl, ्हन_, --, --, 
   {{0x44200165,0x00000000,0x00000000,0x00000000}},	//   _azh_, --, --, --, 
   {{0x44200489,0x798805e4,0x45340108,0x00000000}},	//   _bzh_, mtew, ехст, --, 
   {{0x28a400e0,0x64a0074d,0x7d1c00ef,0x00000000}},	//   _कोटि, ъара, _īssl, --, 
   {{0x32cc0432,0x2bb40490,0xd1d40092,0x00000000}},	//   _aýyr_, _अपघा, ከሰቱ_, --, 
   {{0x8c3cf7df,0x79890259,0x442005c7,0xdec80023}},	// [17380] _bağl, ntew, _ezh_, ቢናን_, 
   {{0x79880113,0xe6140139,0x395800e5,0x00000000}},	//   itew, _юды_, ássy_, --, 
   {{0x8c3c47af,0xf67800df,0x00000000,0x00000000}},	//   _dağl, ַאַמ, --, --, 
   {{0xf428049b,0x79880373,0xa8000790,0x00000000}},	//   _enää_, ktew, _şıkl, --, 
   {{0xad24541e,0x4c940022,0xdce4013a,0x00000000}},	//   ورتو, еилс, _úměr, --, 
   {{0x69c433b4,0x25fc9725,0xec141de6,0x00000000}},	//   äkem, रपती_, мелә_, --, 
   {{0x8c3c0139,0x00000000,0x00000000,0x00000000}},	//   _wağo, --, --, --, 
   {{0xaae400f2,0x1c4004b4,0x0e0401f0,0x00000000}},	//   بستو, ннәм, _пӯло, --, 
   {{0x8c3c0259,0x798805e4,0xa9280150,0x00000000}},	//   _yağl, gtew, жіне_, --, 
   {{0xa3c0000d,0xeb981188,0x00000000,0x00000000}},	//   ्हम_, _миз_, --, --, 
   {{0xdcac04a9,0x79880c8c,0xe0dc007f,0x00000000}},	//   _خىل_, atew, _stòk_, --, 
   {{0x442002c4,0xb8d443de,0x9f480129,0x98ac00c0}},	//   _rzh_, _चो_, êlée_, _mugę_, 
   {{0xe8e9025a,0x2bac0381,0x5ac400ee,0xdb0c0332}},	//   _ورتو_, _hęc_, _юлцм_, _údár, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd7ec0716,0x97a1025b,0x9388177b,0x8c3c03e0}},	//   _ру_, _арыл, мста_, _nağm, 
   {{0x8c3d025c,0x929402d5,0x0e540023,0x00000000}},	//   _sağl, касц, ምትእም, --, 
   {{0xbebc00b8,0x80b401f0,0x273800de,0x00000000}},	// [17390] _bhūn, нбах, _vīnu_, --, 
   {{0xbebc0055,0x00000000,0x00000000,0x00000000}},	//   _chūn, --, --, --, 
   {{0xbebc0055,0x44200064,0x69c40108,0xbed400d8}},	//   _dhūn, _uzh_, äkej, ножј, 
   {{0x79880042,0x00000000,0x00000000,0x00000000}},	//   ytew, --, --, --, 
   {{0xdb20022c,0x8c3c03b9,0x273800ef,0x200c012d}},	//   ørík, _tağl, _kīns_, łgi_, 
   {{0x2244016b,0xdcb80108,0x00000000,0x00000000}},	//   ɛnka_, юще_, --, --, 
   {{0x8b641d00,0x6600013f,0xd6e00034,0xb3900023}},	//   نايم, _ɛnka, ółki_, _ምውዳቕ_, 
   {{0x79880694,0x7f5801d5,0x00000000,0x00000000}},	//   ttew, _маҳс_, --, --, 
   {{0xa3c00ce0,0x89a8010b,0x00000000,0x00000000}},	//   ्हड_, дйың_, --, --, 
   {{0x8c3c0259,0x37741411,0xa3dc0f4a,0x79880582}},	//   _yağm, нымс, थना_, rtew, 
   {{0x5801025d,0x69c4003b,0x6b6c002b,0x00000000}},	//   тонғ, øker, _ṛgve, --, 
   {{0xca484caa,0x00000000,0x00000000,0x00000000}},	//   _قلمه_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x32cc0432,0x00000000,0x00000000,0x00000000}},	//   _aýyp_, --, --, --, 
   {{0xa5040354,0x273800ef,0x00000000,0x00000000}},	//   хера_, _dīns_, --, --, 
   {{0x8c3c0365,0x00000000,0x00000000,0x00000000}},	//   _rağm, --, --, --, 
   {{0x069401d9,0x3124fe9c,0x8c3c2ca8,0x7614030d}},	// [173a0] _شاٹھ, едаг, _sağm, _яькх, 
   {{0x22440118,0xf10817ee,0x059800f2,0x010800f1}},	//   ěnka_, ववेद_, _کمیک_, وتلو_, 
   {{0x43700131,0xadf00037,0xa92001a8,0x2e48011c}},	//   _پۇقر, _आइहन_, _íþes, пяло_, 
   {{0x752c0810,0xdee1025e,0x69c4005b,0x00000000}},	//   lmbz, лохи, äkek, --, 
   {{0x273800b0,0x98a40210,0x00000000,0x00000000}},	//   _mūna_, _winę_, --, --, 
   {{0x66dc02d3,0x27380055,0xdc840395,0x00000000}},	//   _mëka, _lūna_, есъл_, --, 
   {{0xfca8004b,0x66dc00e8,0xffa401c0,0x3028010b}},	//   بانو_, _lëka, _илрү, _ховп_, 
   {{0xada44bb1,0xa3c00a59,0xa9c400d8,0x00000000}},	//   _пабл, ्हत_, есок, --, 
   {{0xdee047b3,0xec78094e,0x99940276,0x66dc0200}},	//   _соти, _нпа_, екыт_, _nëka, 
   {{0x2570023b,0x00000000,0x00000000,0x00000000}},	//   ққос, --, --, --, 
   {{0x27380006,0x48600092,0x00000000,0x00000000}},	//   _būna_, _ለአውሮ, --, --, 
   {{0x486c0092,0x98a40118,0xf1b00b02,0x560801e1}},	//   _ተጠመቁ_, _kině_, ीमान, _ìjọ́_, 
   {{0x1af400c8,0x99d0c009,0x95d8082d,0xd784187c}},	//   _אמאל_, _متوا, едят_, ونیو_, 
   {{0xa490036b,0xe88400ef,0x61f80c5e,0x98b4003b}},	//   چیکت, _žeņš, _žulo, _пліт_, 
   {{0x25bc00a8,0xbebc00b8,0x273800e2,0x00000000}},	//   ţul_, _bhūl, _vīns_, --, 
   {{0xbebc00b8,0xc2c4007b,0x8c3c03e0,0xe0d0210e}},	//   _chūl, خيري, _bağk, گزر_, 
   {{0xbebc002b,0xed7c00b7,0x69c4005b,0x9c8400d7}},	// [173b0] _dhūl, _የፍቅር_, äkeh, načá, 
   {{0xd56406bb,0x52140815,0x00000000,0x00000000}},	//   _стъп, удут, --, --, 
   {{0x7fb848cd,0xf534011a,0x98bc025c,0xb4f0004e}},	//   بهار_, _שנתי_, nsuġ_, _түрч, 
   {{0x66dc002e,0x00000000,0x00000000,0x00000000}},	//   _yëka, --, --, --, 
   {{0x2ec001e0,0x00000000,0x00000000,0x00000000}},	//   шөрм, --, --, --, 
   {{0xd37804b9,0x3ea88bdf,0xe0dc0381,0x629c25a8}},	//   šće_, žat_, _quòd_, leqo, 
   {{0xa3c1025f,0x6aa80154,0xfc040395,0x00000000}},	//   ्हि_, কানো, ъпко, --, 
   {{0x629c01e2,0x29000264,0x8f345d88,0x00000000}},	//   neqo, ékan_, _бесц, --, 
   {{0x8e84009f,0x00000000,0x00000000,0x00000000}},	//   _حلقه, --, --, --, 
   {{0xe8f50260,0xa3c00b03,0xa258002d,0x999c00b5}},	//   клы_, ्हा_, _unôf, d版ti, 
   {{0x3eb8067c,0xa920747c,0x273824cb,0x00000000}},	//   _òsts_, рдэл, _sūna_, --, 
   {{0xd1f80092,0x00000000,0x00000000,0x00000000}},	//   ለሰብ_, --, --, --, 
   {{0xe7b000f2,0x00000000,0x00000000,0x00000000}},	//   همید, --, --, --, 
   {{0x96d40075,0x00000000,0x00000000,0x00000000}},	//   _әскә, --, --, --, 
   {{0xe3610261,0x43746c68,0x67d0041b,0x8c3c0205}},	//   икри, лутт, _воју, _dağh, 
   {{0xe2950262,0xbebc0882,0x273802b5,0x66dc00e8}},	//   кас_, _bhūm, _tūna_, _tëka, 
   {{0x21640075,0x614002e8,0xded004b2,0x00000000}},	// [173c0] кити_, иета, ያኑን_, --, 
   {{0xbebc0882,0x69c4023a,0x62300640,0x32600014}},	//   _dhūm, äkei, ређу, دچھہ, 
   {{0xaa1c0316,0x4094728c,0x629c0117,0xa0a001c6}},	//   _पर्छ_, ыртт, beqo, рахд, 
   {{0xad6400ae,0x00000000,0x00000000,0x00000000}},	//   ناته, --, --, --, 
   {{0xf1d001c0,0xdcf8025c,0x6aa800cc,0x61280205}},	//   _төвө, _ssuġ, কামো, dülf, 
   {{0x2b5c2a1f,0xe7f400bc,0x8c3c4e7e,0xeb4801d5}},	//   _pwtc_, ुपमा_, _kaği, وشبو_, 
   {{0xfb1801d3,0x00000000,0x00000000,0x00000000}},	//   کروں_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6f010263,0x9980030c,0x2ee50264,0x4938005b}},	//   mnoc, لليو, mhof_, нзию_, 
   {{0x2ee42506,0x6f010265,0x8afc012d,0x998000e5}},	//   lhof_, lnoc, _swęd, گلیو, 
   {{0x47345777,0x88bc012c,0x98c10266,0x629c379d}},	//   лнос, dmět, рсыл, yeqo, 
   {{0x2ee50267,0x6f010268,0xb34071d5,0xbaa400d1}},	//   nhof_, nnoc, ıçla, _бушқ, 
   {{0xbebc0055,0x6f002d54,0x0488010b,0x8894014b}},	//   _bhūj, inoc, нәни_, _билх, 
   {{0xa8501a98,0x672c037e,0x04c830a7,0x2ee4002f}},	//   _текә, smcj, روزي_, hhof_, 
   {{0x629c03be,0xe0dc1497,0x2ee40af9,0xe78453e8}},	//   teqo, _luòc_, khof_, _руло, 
   {{0x291d0269,0x69d403ee,0x2ee40582,0x50d401d5}},	//   llta_, _üyes, jhof_, یزلر, 
   {{0xc1042266,0x6f01026a,0x5335026b,0x291d026c}},	// [173d0] هوري, dnoc, ретт, olta_, 
   {{0x273802d5,0x6f01026d,0x6b98010a,0x629c01f0}},	//   _kūno_, enoc, _optg, seqo, 
   {{0x291c02f6,0x2ee5026e,0xe1fc01d3,0x61280254}},	//   ilta_, fhof_, _adót_, hülg, 
   {{0x8f14063b,0x6f00026c,0x1ea805d9,0x612800af}},	//   афіч, gnoc, بائي_, külg, 
   {{0x6d440c6a,0x9148de69,0xe9c40451,0x27380055}},	//   _ékal, _ачса_, _اٺ_, _lūno_, 
   {{0xa2d80316,0x6f01026f,0xfc043cc5,0xe7c00b02}},	//   नसक्, anoc, лпло, षमाप, 
   {{0x8c3c4dd9,0x6f000419,0x27280051,0x290800d7}},	//   _yaği, bnoc, cùng_, čbal_, 
   {{0x6f0001e5,0xe0dc068c,0x3f810270,0x291d0271}},	//   cnoc, _fuòc_, muhu_, elta_, 
   {{0x496495a3,0x3f802264,0x61f84b16,0x9ba00137}},	//   аның, luhu_, _žulj, _چەتى, 
   {{0x3ead0272,0x9ba00075,0x1cb80132,0x88bc0118}},	//   _haet_, _نەتى, _تارب_, dměs, 
   {{0x3eac020c,0x3f810273,0x3b54f765,0xe8f40276}},	//   _kaet_, nuhu_, _скер, улэ_, 
   {{0x291d0274,0xa6810275,0xf67431b1,0x612803e0}},	//   alta_, блюд, دادخ, lüld, 
   {{0x3f810276,0x3eac0c3a,0x291c01ab,0xe4c000d1}},	//   huhu_, _maet_, blta_, әйси, 
   {{0x3eac08cd,0xbebc0055,0x3f810277,0x61290278}},	//   _laet_, _bhūk, kuhu_, nüld, 
   {{0x78a10279,0x7414fc68,0x94a401ad,0x69c4005b}},	//   melv, اوزا, _ओसीआ, äkev, 
   {{0x3ead027a,0x3f8001d9,0xe280b5f5,0xf1d1027b}},	//   _naet_, duhu_, йлси, бөгө, 
   {{0x612800dd,0xb225027c,0x6f000306,0x00000000}},	// [173e0] küld, умал, vnoc, --, 
   {{0x63b40789,0x3f800009,0x6f00012d,0x8c3c0166}},	//   _frxn, fuhu_, wnoc, _waği, 
   {{0x3eac0399,0x2ee49e35,0xfaf80421,0x6f000cf4}},	//   _baet_, thof_, kiū_, tnoc, 
   {{0xa3c019ec,0x3eac0399,0x0d54044e,0xad101cd1}},	//   ्हर_, _caet_, _ዝተፈል, әпкә, 
   {{0x6f01027d,0x2ee5027e,0x291c007c,0x636c0051}},	//   rnoc, rhof_, ylta_, ếnth, 
   {{0x2ee4fc85,0x3f81027f,0x78a008fb,0x4f840014}},	//   shof_, buhu_, jelv, _پاسہ, 
   {{0x3ead0280,0xafe40ce4,0x00000000,0x00000000}},	//   _faet_, _совл, --, --, 
   {{0x5fb80302,0xdee00a70,0x3eac0166,0xddd803b9}},	//   _אצלנ, _лоси, _gaet_, _uduş, 
   {{0xa2580022,0x88bc00bc,0x78a10281,0xba3c0118}},	//   _moôp, dměr, felv, zdův, 
   {{0x78a011ad,0x18740020,0x61140209,0x291d0282}},	//   gelv, _በአገር_, _işlä, ulta_, 
   {{0x291c0054,0x38c4010b,0x00000000,0x00000000}},	//   rlta_, ршың, --, --, 
   {{0x7c240639,0xa924010b,0x61290283,0x63e01870}},	//   ühre, _өдел, müle, ەيسە, 
   {{0x78a10284,0x61290285,0xd7c43c5b,0x5a34074d}},	//   belv, lüle, نویه_, _йышă, 
   {{0xa3c0069f,0x3f8001d9,0x78a00158,0xfbd80073}},	//   ्हल_, yuhu_, celv, _बॅडम, 
   {{0x612805d1,0x69c405ac,0x3f80058a,0x68f800a2}},	//   nüle, åkef, xuhu_, mitd, 
   {{0x612841b5,0xc2540212,0x490c00bc,0x85b90286}},	//   züld, ркащ, ठकको_, _алис_, 
   {{0x3eac2af2,0x61290287,0x80f50288,0x91e401e0}},	// [173f0] _raet_, hüle, апах, бәрһ, 
   {{0x656cdbdf,0xd3782ce2,0x3f810289,0x3ead028a}},	//   msch, šća_, tuhu_, _saet_, 
   {{0x656d028b,0x3f800270,0x6d44003e,0x3ead028c}},	//   lsch, uuhu_, _ékaj, _paet_, 
   {{0x656c0c86,0xd24405f5,0x68f8cb22,0x6129028d}},	//   osch, _гэри, hitd, düle, 
   {{0x656d028e,0x0e65020a,0x673c0327,0x78a001d3}},	//   nsch, скін, _miqj, yelv, 
   {{0x656d028f,0x3eac1509,0x88bc0316,0x673c014f}},	//   isch, _waet_, změr, _liqj, 
   {{0x61141248,0x61287c27,0x3eac1509,0x656d0290}},	//   _eşlä, rüld, _taet_, hsch, 
   {{0xd1cc001f,0x78a00942,0x6b60074d,0x8d7400ec}},	//   _አርብ_, welv, цкъа, _ڇالا, 
   {{0x9c850291,0x78a10292,0x8d741564,0x656c0196}},	//   _مشاه, telv, _هالا, jsch, 
   {{0x656d0293,0xf7700597,0x78a001a4,0x68f90294}},	//   dsch, ياج_, uelv, gitd, 
   {{0x656d0295,0x612805d1,0x8c3c0166,0x78a10296}},	//   esch, cüle, _bağu, relv, 
   {{0x656d0297,0x78a10298,0xe61c0217,0xd1cc0092}},	//   fsch, selv, vfôr_, _አይቪ_, 
   {{0x656d0299,0x7ae9029a,0x69c402f6,0x68f800ee}},	//   gsch, mhet, äket, bitd, 
   {{0x7ae9029b,0x88bc00bc,0x78a00477,0x68f9029c}},	//   lhet, směr, qelv, citd, 
   {{0x656d029d,0x7ae801ee,0x3244374e,0xc60800cc}},	//   asch, ohet, иевг, ৰেলা_, 
   {{0x7ae9029e,0x1fb8045e,0x656d029f,0xe61c0158}},	//   nhet, ংহাস, bsch, rfôr_, 
  
   {{0xf064118f,0x5fa80034,0x656d02a0,0x612902a1}},	// [17400] икап, _टैबल, csch, züle, 
   {{0x6140be9c,0x703869a6,0x612902a2,0xe0dc0e89}},	//   цефа, نساس_, yüle, _stòr_, 
   {{0x7ae84ec2,0xe4780375,0x8c3c008e,0x70380d1d}},	//   khet, _בריכ, _yağu, тчас_, 
   {{0x7ae801e4,0x612902a3,0x00000000,0x00000000}},	//   jhet, vüle, --, --, 
   {{0x7ae902a4,0x661c037e,0x3b840022,0x00000000}},	//   dhet, _xyqk, ҩҩуп_, --, 
   {{0x7ae801ee,0x612902a5,0x48b0015b,0x2a640037}},	//   ehet, tüle, _চক্র, _seob_, 
   {{0x656d02a6,0xadf00456,0x00000000,0x00000000}},	//   zsch, _आइकन_, --, --, 
   {{0x7ae902a7,0x612902a8,0x656d02a9,0x61f805be}},	//   ghet, rüle, ysch, _žuli, 
   {{0xe1fc30cf,0x612902aa,0xc0f802d3,0x3eb800ae}},	//   _león_, süle, _ፈጢሩ_, _ósta_, 
   {{0x7ae801ee,0x61280790,0x18b40588,0x656d02ab}},	//   ahet, püle, агьы_, vsch, 
   {{0x68f902ac,0xe1fc04d4,0xe72402bf,0x99d00d23}},	//   ritd, _neón_, иємн, متیا, 
   {{0x656d02ad,0x7ae902ae,0xe66400f7,0x69c4023a}},	//   tsch, chet, штоо, äkes, 
   {{0x656d02af,0xeb1001f9,0x00000000,0x00000000}},	//   usch, डकीत_, --, --, 
   {{0xd7c403e6,0x98a0460c,0x555800a8,0xc8880166}},	//   _چووه_, _миче, раря_, _сәид_, 
   {{0x656cdfe0,0xa3440323,0x66dc0694,0x673c0455}},	//   ssch, рэгл, _jëkk, _tiqj, 
   {{0xd25902b0,0x656d02b1,0x044400fd,0x00000000}},	//   ицу_, psch, реңн, --, 
   {{0x66dc1574,0x00000000,0x00000000,0x00000000}},	// [17410] _lëkk, --, --, --, 
   {{0x7ae800dd,0x8c3c0205,0xa2d80b98,0x612806be}},	//   zhet, _yağt, नसङ्, dülc, 
   {{0x2ba40db3,0x7ae85210,0xd7bc01ad,0x29080219}},	//   _कैला, yhet, एमएच, čbah_, 
   {{0x7ae802d3,0xb1400023,0x00000000,0x00000000}},	//   xhet, ኣእያታ, --, --, 
   {{0x7ae902b2,0x6e9001e2,0x612801d3,0xd1c821f3}},	//   vhet, سلوا, rülb, _курд_, 
   {{0x7ae804fe,0x66dc002e,0x442102b3,0xbb4502b4}},	//   whet, _bëkk, _kyh_, бекк, 
   {{0x7ae902b5,0x0a64001f,0x00000000,0x00000000}},	//   thet, _መቀመጫ, --, --, 
   {{0x66dc1574,0x7ae8005b,0x442000a2,0xde440244}},	//   _dëkk, uhet, _myh_, _ئیشو_, 
   {{0x7ae8ed21,0x7e680789,0xbebc002b,0xabb40022}},	//   rhet, _ieep, _bhūv, _қацә, 
   {{0x7ae902b6,0x7e68002d,0x66dc00e8,0x1c184328}},	//   shet, _heep, _fëkk, _पुथल_, 
   {{0x69c502b7,0x36687336,0x7e680c30,0x8c3c013d}},	//   äker, лано_, _keep, _dağs, 
   {{0x7e6902b8,0x7ae902b9,0x00000000,0x00000000}},	//   _jeep, qhet, --, --, 
   {{0x7e6902ba,0x49b82e44,0x00000000,0x00000000}},	//   _meep, _پاند_, --, --, 
   {{0x88b8043b,0x7e6902bb,0xe1fc29d3,0x66dc00e8}},	//   ngɛ́, _leep, _peón_, _yëkk, 
   {{0x6aa800eb,0x00000000,0x00000000,0x00000000}},	//   কারো, --, --, --, 
   {{0x7e6902bc,0x44200205,0xf1d000cf,0x00000000}},	//   _neep, _dyh_, пөгө, --, 
   {{0xf1a88117,0x2324a17b,0xf4e4009e,0x310800ee}},	// [17420] دازه_, соти_, _নদীব, гнап_, 
   {{0x960441d8,0x8c3c03e0,0xa5b40115,0x00000000}},	//   रपीट_, _mağr, _פליק_, --, 
   {{0x7e688b19,0x6e4502bd,0x7c20017a,0x00180006}},	//   _beep, منام, _nylr, аўцы_, 
   {{0x7e6902be,0x91c4010b,0xa03000cf,0x00000000}},	//   _ceep, _дамҗ, سىنت, --, 
   {{0xccf81b74,0x26c4013f,0x66dc002e,0x00000000}},	//   ақа_, _ɑno_, _sëkk, --, 
   {{0xaf6801d9,0xed440022,0xabb00166,0x612803e0}},	//   _مصرٕ_, _ҳнап, закә, rülc, 
   {{0x7e6902bf,0x272807c5,0xcb6832f7,0xad6400f2}},	//   _feep, hùna_, جمعه_, _گازه, 
   {{0x95280867,0x612829ef,0xee3800a7,0x8c3c1432}},	//   _རེའི_, müla, _бнб_, _bağr, 
   {{0x7d0c007b,0xdb1c01d3,0xccf8013a,0x1ec4030d}},	//   éasc, ívás, _tmě_, _улти_, 
   {{0x7e6902c0,0x19a40801,0x66dc0de2,0xacb000d1}},	//   _zeep, стъп_, _tëkk, _رەبب, 
   {{0x2d8401af,0x7e6800f1,0x4844001f,0x69c4143a}},	//   luoe_, _yeep, _ከአውሮ, åkeb, 
   {{0xa25806ed,0x38ac00e4,0x394c0455,0xa96800d8}},	//   _anôn, _pórõ_, bqes_, _бида_, 
   {{0x442102c1,0xe1fc0332,0x00000000,0x00000000}},	//   _syh_, _ceól_, --, --, 
   {{0x612902c2,0x442102c3,0x00000000,0x00000000}},	//   küla, _pyh_, --, --, 
   {{0xd82ce2af,0x2d8401af,0x7af80042,0x8964009f}},	//   _хэ_, huoe_, _ymwt, _اُڻن, 
   {{0x612902c4,0x61400ed1,0x3fc840be,0x00000000}},	//   düla, كىرە, یدای_, --, 
   {{0x7e682963,0x5eb400cc,0x31700432,0xe5d40248}},	// [17430] _reep, _অকলে, gsyz_, _ìwàá, 
   {{0x7e6902c5,0xc05802d3,0x4498011b,0x61280037}},	//   _seep, _ልዑላው, _твою_, füla, 
   {{0x506413bd,0x61280790,0x95541291,0x00000000}},	//   ятта, güla, _وخیا, --, 
   {{0x27380064,0xed4c01d9,0xeff801f3,0x00000000}},	//   _būni_, چھل_, ጋርያ_, --, 
   {{0x5c74052f,0x7c20000f,0x7e6902c6,0x317000a2}},	//   йҙар_, _sylr, _veep, csyz_, 
   {{0x7e6902c7,0x6b140327,0x7c2001bf,0x00000000}},	//   _weep, ྲོའོ_, _pylr, --, 
   {{0xbebc0a28,0x00000000,0x00000000,0x00000000}},	//   _bhūt, --, --, --, 
   {{0xce9400a7,0x3f8000aa,0x93fc008f,0x9cf800cc}},	//   _насъ, mrhu_, טלוי, েতেন_, 
   {{0x98a4002b,0xbebc002b,0x69c40108,0x00000000}},	//   _ahnā_, _dhūt, äkep, --, 
   {{0xa9200220,0x61f8032e,0x00000000,0x00000000}},	//   мдыл, _þulu, --, --, 
   {{0x628c9933,0xeaac066d,0x6ce0004b,0x8c3c0139}},	//   _occo, رٹی_, _زړون, _wağr, 
   {{0xc4c802e4,0xeaac01d5,0x6e340ca8,0xbf1c0241}},	//   _בג_, _ўй_, _ògbó, _ṣejọ, 
   {{0x9a2448e8,0x940403be,0xe6140cc9,0x00000000}},	//   _اعان, əmə_, ждя_, --, 
   {{0x628d02c8,0xc5f43e25,0x272808c2,0x98480395}},	//   _acco, яғы_, rùna_, _сяда_, 
   {{0x61280793,0x3ce000af,0x272804cc,0xb4e8cd66}},	//   xüla, _कवने_, sùna_, _मती_, 
   {{0x3f800327,0xb1e000cd,0x00000000,0x00000000}},	//   drhu_, _ṛṣiḥ_, --, --, 
   {{0xceb80184,0x70240154,0x00000000,0x00000000}},	// [17440] ҙҙа_, _বলেও_, --, --, 
   {{0x6ab4acfa,0x628c00a7,0x612801b8,0xa0a00572}},	//   _अफ्र, _ecco, tüla, мауд, 
   {{0x324407d6,0xef1805f5,0xb3746e0c,0x8458084c}},	//   _менг, амж_, _بدخش, _урыт_, 
   {{0x2d8401ee,0x6da45665,0xef1902c9,0x57f00327}},	//   tuoe_, жида, шме_, _བཟློ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbebc0055,0xd9cc009e,0x61280790,0xd1cc0092}},	//   _akūd, িনাম, püla, _አይቼ_, 
   {{0x2d8401e0,0x7d0c00c6,0x6140074d,0xe9e801e1}},	//   suoe_, éasa, _цера, _olúó_, 
   {{0xbebc00b8,0xe0400212,0xed581fce,0x7dc400cf}},	//   _dhūs, _інти, _воа_, تتۅك, 
   {{0xdcf80139,0x00000000,0x00000000,0x00000000}},	//   _uquğ, --, --, --, 
   {{0x20040034,0x2198010f,0x00000000,0x00000000}},	//   źnie_, סביא, --, --, 
   {{0xda6d02ca,0x6fb80406,0x4bc401c6,0xbebc0055}},	//   _оя_, ईटिं, _хөлг, _thūt, 
   {{0xe5c401c6,0x00000000,0x00000000,0x00000000}},	//   осго, --, --, --, 
   {{0x964401c6,0xe3b000e5,0x65780327,0x00000000}},	//   дэрд, ڈرز_, ġuho, --, 
   {{0x99f80302,0xe3b057c1,0x39580798,0x00000000}},	//   _דפדפ, ورز_, ísse_, --, 
   {{0x628c0789,0x84240131,0x00000000,0x00000000}},	//   _pcco, سىرن, --, --, 
   {{0x3f800122,0x1b78008f,0x941803b9,0x859401e2}},	//   vrhu_, יטלע, nerə_, _فټبا, 
   {{0x628c004d,0xd25000f1,0x69c80166,0xca280150}},	// [17450] _vcco, ځنې_, _äleğ, _ﺣﺮﺏ_, 
   {{0x3f8000bc,0x00000000,0x00000000,0x00000000}},	//   trhu_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x628c0334,0x20500023,0x3f800327,0xdef800c7}},	//   _ucco, _ዝጀመር, rrhu_, шыз_, 
   {{0xbebc00dc,0xdda8119e,0x3f800327,0x941803b9}},	//   _bhūr, ртел_, srhu_, derə_, 
   {{0xbebc00b8,0x22440118,0xdfd8004e,0x00000000}},	//   _chūr, ěnku_, _къб_, --, 
   {{0x81ac0f22,0xbebc00cd,0x52940023,0x612803e0}},	//   _কপি_, _dhūr, _ውሽጥኻ_, lülo, 
   {{0x68e902cb,0x98a40010,0x27380153,0x1ee4a797}},	//   _alfd, čiču_, _kūnu_, _بوری_, 
   {{0x6128014a,0xaa540063,0x39580221,0x784c01d3}},	//   nülo, чињу_, ëss_, _nővé, 
   {{0xa3c8038e,0xb4e80574,0xbebc002b,0x77840fac}},	//   लमा_, _मते_, _ghūr, плоз, 
   {{0x66dc02d3,0xfcb80092,0x00000000,0x00000000}},	//   _lëku, ቲንግ_, --, --, 
   {{0xe0dc0086,0x612801b8,0x68e80430,0x3b0800e8}},	//   _buòk_, külo, _elfd, _ñaq_, 
   {{0x60c40369,0x6d4400e4,0xf8640395,0xe8ec011c}},	//   _onjm, _ékat, _евло, _зл_, 
   {{0x290102cc,0x612806be,0x00000000,0x00000000}},	//   ékat_, dülo, --, --, 
   {{0xc7642dfc,0xd83805f5,0x798902cd,0x37e4009d}},	//   _قايى, _тэд_, luew, _хойг, 
   {{0x9ad00521,0x6128014a,0x73740124,0x273800c0}},	//   _dịgh, fülo, _ҭынх, _būnu_, 
   {{0x6454105c,0xe28005f5,0x612801ed,0xa5f40063}},	// [17460] _ffxi, элти, rüln, _нећу_, 
   {{0x66dc00e8,0xfbbc012a,0x612801d3,0x273800ef}},	//   _dëku, ्माम, süln, _dūnu_, 
   {{0x09a878bf,0x7c2403fa,0x612902ce,0x79880221}},	//   _कन्य, ührl, müll, huew, 
   {{0xee3902cf,0x612902d0,0x79880036,0xe354011a}},	//   бне_, bülo, kuew, _משטח_, 
   {{0xb928063f,0x6ab402d2,0x7bc401e3,0xa1c000c0}},	//   untụ_, _óyfi, åhun, _збяд, 
   {{0x612806b9,0x798803ac,0x659800df,0xd0e81a4b}},	//   nüll, duew, מינק, _بکرم_, 
   {{0xb6040427,0x00000000,0x00000000,0x00000000}},	//   lošč, --, --, --, 
   {{0xd1cc001f,0x61280e78,0x2aa81631,0x98a40153}},	//   _አይቶ_, hüll, стко_, _kinė_, 
   {{0x798902d1,0x612853b5,0xb6040e04,0xe9e40024}},	//   guew, küll, nošč, яцко, 
   {{0x6f0102d2,0x47780212,0x98ac0024,0xabd400cf}},	//   lioc, обою_, _mugė_, _ىزات, 
   {{0xdce805be,0x612902d3,0x00000000,0x00000000}},	//   _šićk, düll, --, --, 
   {{0x6f0008a4,0xda740276,0xb6040010,0xd7f46171}},	//   nioc, _еяш_, košč, яуы_, 
   {{0x61280639,0x64540175,0xcfe00154,0x25bc01e7}},	//   füll, _pfxi, _যেমন, íul_, 
   {{0x6f00011c,0x612902d4,0xd9400276,0xb6040219}},	//   hioc, vülo, _зечи, došč, 
   {{0x577406f6,0x9418013f,0x2ee4208d,0xdce80153}},	//   _فصيح_, merɛ_, kkof_, augė, 
   {{0x273800b0,0x612801b8,0x53980212,0x00000000}},	//   _pūnu_, tülo, явся_, --, 
   {{0x291c022f,0x2b4401a6,0x66dc036e,0x461400f2}},	// [17470] oota_, _mioc_, _qëku, _زودر, 
   {{0x2b44003a,0xa344009d,0x612806be,0x00000000}},	//   _lioc_, _нэмл, cüll, --, 
   {{0x26d902d5,0x6f00011c,0xbebc00dc,0x00000000}},	//   _koqo_, fioc, _bhūp, --, 
   {{0x291d02d6,0x6f000801,0x612902d7,0xfbbc11a6}},	//   hota_, gioc, pülo, ्मसम, 
   {{0x26d80784,0x291c9024,0xbebc00dc,0xdd9902d8}},	//   _moqo_, kota_, _dhūp, сше_, 
   {{0x69d403ee,0x26d80548,0x31d400eb,0x00000000}},	//   _üyey, _loqo_, _সেকশ, --, 
   {{0x291d02d9,0x6128029f,0x3af4084c,0x8d740131}},	//   dota_, nülm, дяпс, _ۋاكا, 
   {{0x6f00d015,0x26d80014,0x2b44054e,0x79880036}},	//   cioc, _noqo_, _cioc_, tuew, 
   {{0x2b44030a,0x291d02da,0x6b88002f,0x00000000}},	//   _dioc_, fota_, aufg, --, 
   {{0x291d02db,0xd378098d,0x37e431ee,0x612902dc}},	//   gota_, šći_, доог, külm, 
   {{0x26d902dd,0xb9045612,0x6700063f,0x79880c8c}},	//   _boqo_, _नव_, _ọkam, suew, 
   {{0x2b440048,0x6d440066,0x2900003e,0xdb20005b}},	//   _gioc_, _ékar, ékar_, äräk, 
   {{0x291d02de,0xca740116,0x798902df,0x00000000}},	//   bota_, _سانغ, quew, --, 
   {{0x291d02e0,0x6f00011c,0xb604151c,0xd1f80023}},	//   cota_, zioc, vošč, ወደበ_, 
   {{0x386502e1,0x99e000d0,0x61280254,0x00000000}},	//   mblr_, ľňuj, rüll, --, 
   {{0x3b0c0af5,0x99e02195,0x6f000077,0xa7a4074d}},	//   nneq_, žňuj, xioc, _цкъа_, 
   {{0x3b0c0eda,0xb14502e2,0x61280205,0x13a8072d}},	// [17480] ineq_, днал, püll, _کنجی_, 
   {{0xb604151c,0x7bc0013c,0xafe4036b,0x6f000142}},	//   rošč, _orlu, мозл, wioc, 
   {{0x6f0102e3,0x2e483417,0x7bdc0241,0x00000000}},	//   tioc, ояло_, _ńsun, --, 
   {{0x63440109,0x291c009f,0xeda40212,0x2004004e}},	//   _tŕna, zota_, дшко, únia_, 
   {{0x6f0102e4,0x291d02e5,0x395c0070,0x94180605}},	//   rioc, yota_, _ntws_, yerɛ_, 
   {{0x6f00597f,0x291d02e6,0x2ee40af9,0x2b4502e7}},	//   sioc, xota_, skof_, _sioc_, 
   {{0x291c00d0,0x6128007d,0x395c017a,0x2b4400ae}},	//   vota_, külj, _atws_, _pioc_, 
   {{0x63a0092e,0x291d02e8,0x9418016b,0x00000000}},	//   _änne, wota_, werɛ_, --, 
   {{0x291d02e9,0x612902ea,0x26d8ccec,0x7bc0013c}},	//   tota_, zülm, _roqo_, _erlu, 
   {{0x3b0c0eda,0x26d823e0,0x5ca000c7,0xa8a463dd}},	//   aneq_, _soqo_, _ииуб, фрик, 
   {{0x2b4400a3,0xd7f40108,0x00000000,0x00000000}},	//   _tioc_, дуя_, --, --, 
   {{0x291d02eb,0x26d902ec,0xdc3000d1,0xdce80135}},	//   sota_, _qoqo_, _شىنخ, ttgħ, 
   {{0x291d02ed,0x09a80327,0x00000000,0x00000000}},	//   pota_, _བགྲ_, --, --, 
   {{0x69c0009a,0x61281432,0x291d02ee,0x2aa001d5}},	//   _iroe, tülm, qota_, lаb_, 
   {{0xdce81f21,0x69c00165,0x98a00640,0xd4042d29}},	//   stgħ, _hroe, _рије, вяти, 
   {{0x69c102ef,0xbd801e38,0x00000000,0x00000000}},	//   _kroe, _ካርቱም_, --, --, 
   {{0x6aa102f0,0xde8c001e,0x25ac07de,0x28d011bc}},	// [17490] _mbof, hịch_, _ègl_, तापि, 
   {{0xbcfc0086,0xa2bc00e1,0x2d8404e6,0x61280205}},	//   _itũg, _लोर्, droe_, mülk, 
   {{0x2b5c01ee,0x3af00124,0x2d840373,0xddc801e4}},	//   _nttc_, _hápe_, eroe_, ragŭ, 
   {{0xff2502f1,0x69c008e7,0x80cc0490,0x2d840036}},	//   ربای, _oroe, साहे, froe_, 
   {{0x2d8403eb,0x0e6502f2,0xa3b801d3,0xba0800eb}},	//   groe_, ткін, _طاھر_, _লর্ড_, 
   {{0x6aa00134,0x7bc0003e,0x00000000,0x00000000}},	//   _abof, _prlu, --, --, 
   {{0x28d008ec,0x00000000,0x00000000,0x00000000}},	//   तानि, --, --, --, 
   {{0x69c102f3,0x3b0c20ac,0x7bc001a6,0x4ea40124}},	//   _broe, uneq_, _vrlu, _ируа, 
   {{0x3b0c0680,0x69c00cfd,0xeb300e56,0xab600254}},	//   rneq_, _croe, دىيد, öüri, 
   {{0xe8f502f4,0xf1b025f9,0x69c102f5,0x6aa00810}},	//   ель_, נסי_, _droe, _ebof, 
   {{0x69c102f6,0x37e4cdc1,0x2aa0022e,0xf7700244}},	//   _eroe, хонг, bаb_, داخ_, 
   {{0x69c102f7,0x9ad001f2,0xbbbc193d,0x6aa001e1}},	//   _froe, _dịch, ्मीक, _gbof, 
   {{0x69c102f8,0x7ae80b21,0x61287b35,0x2d80007c}},	//   _groe, mket, rülj, _åket_, 
   {{0x399902f9,0x7ae88cf8,0x612800e5,0x00000000}},	//   mès_, lket, sülj, --, 
   {{0x399902fa,0x69c00165,0x7ae801c4,0x00000000}},	//   lès_, _zroe, oket, --, 
   {{0x7f480135,0xe7340395,0x59c001f9,0x00000000}},	//   _nieq, _пещ_, वटपर, --, 
   {{0x399902fb,0x7ae801c0,0xbbbc0146,0xd5a4033d}},	// [174a0] nès_, iket, ्मुक, _ओहिज, 
   {{0x7ae83110,0x2d840165,0x00000000,0x00000000}},	//   hket, vroe_, --, --, 
   {{0x7ae902fc,0x40940801,0xe0dc068c,0xa1100691}},	//   kket, ъртт, _nuòu_, دولت, 
   {{0x7ae8009b,0xee3902fd,0x7d000142,0x2d84005a}},	//   jket, пне_, _amls, troe_, 
   {{0x7f4902fe,0x4c94023a,0x39985eb0,0x94240137}},	//   _dieq, вилс, jès_, _سوڭۇ, 
   {{0xd37804b9,0x399902ff,0xe0dc0ba1,0x7ae90300}},	//   šću_, dès_, _buòu_, eket, 
   {{0x7f48031c,0x6128cdf0,0x80cc0303,0x00000000}},	//   _fieq, dülh, सारे, --, 
   {{0x69c10301,0x2d8405e4,0x39990302,0x28d008df}},	//   _proe, proe_, fès_, ताभि, 
   {{0x39990303,0xa92856a4,0xfb1801d3,0x2aa0022e}},	//   gès_, зіне_, بروں_, rаb_, 
   {{0x69c07890,0x8d940020,0x7ae90304,0x8afc002d}},	//   _vroe, _ዘግቧል_, aket, _stęd, 
   {{0x28d009d9,0xfca88bee,0x69c00942,0x99d10305}},	//   ताबि, _زالو_, _wroe, نتیا, 
   {{0x69c10306,0x39990307,0x7ae853b0,0x38c402b5}},	//   _troe, bès_, cket, _përä_, 
   {{0x3998c735,0x69c00450,0x95c82503,0x048800ee}},	//   cès_, _uroe, нура_, мәни_, 
   {{0x7d003c36,0xddd80356,0x00000000,0x00000000}},	//   _xmls, _leuş, --, --, 
   {{0xd7ed0308,0x9f440232,0x272804cc,0x97a000c0}},	//   _су_, šné_, hùni_, _брыл, 
   {{0x38c402b1,0x61280793,0x8c3c0205,0x5694014b}},	//   _tërä_, müli, _bağz, _баът, 
   {{0x7f48502a,0x02e010eb,0x61290309,0x45d410fc}},	// [174b0] _rieq, _नवीन, lüli, _ропс, 
   {{0x7ae80323,0x7f48025c,0x200400d8,0xca500150}},	//   zket, _sieq, únio_, _ﳎﻠﺔ_, 
   {{0x612801b8,0x7f48003a,0x7ae801f4,0xd25000e5}},	//   nüli, _pieq, yket, ؤنے_, 
   {{0x7ae801c4,0x3998359e,0x320c007f,0x200c0356}},	//   xket, yès_, èmyé_, ăgi_, 
   {{0x7c2c0198,0x39980ffb,0xb274008f,0x7ae80205}},	//   ƙark, xès_, _בערג_, vket, 
   {{0x3999030a,0x7f480135,0x7ae801f5,0xac80009d}},	//   vès_, _wieq, wket, агшл, 
   {{0x7ae9030b,0x7f480003,0xbbbc012c,0x39981f5d}},	//   tket, _tieq, ्मेक, wès_, 
   {{0x3999030c,0x6129030d,0x7ae8005a,0xa804013d}},	//   tès_, düli, uket, _moñı, 
   {{0x7ae9030e,0x39980ba1,0x28c0000d,0x00000000}},	//   rket, uès_, _वोहि, --, 
   {{0x39981e47,0x7ae9030f,0x6d8800e5,0x00000000}},	//   rès_, sket, _آملہ_, --, 
   {{0x39990310,0x2d8017c0,0x7ae80522,0x61286a5a}},	//   sès_, _åker_, pket, rülh, 
   {{0x389402bf,0x39990311,0x97340b43,0x612801d3}},	//   sсr_, pès_, دکتا, sülh, 
   {{0xca48007b,0x00000000,0x00000000,0x00000000}},	//   _كلمه_, --, --, --, 
   {{0x612801b8,0x7c24002f,0x00000000,0x00000000}},	//   büli, ührw, --, --, 
   {{0xb4b10312,0xbb2c0131,0xf7700131,0x00000000}},	//   _ऐसी_, ﺩﻩﻡ_, _ئات_, --, 
   {{0xb6a40276,0xe61c05d5,0xe2806bce,0x27e8005c}},	//   _риил, tgôt_, илси, øbne_, 
   {{0xddd8084c,0x31246f34,0xe2940c60,0x2324d255}},	// [174c0] _reuş, вдаг, ъат_, тоти_, 
   {{0xa1100a2c,0xe61c05d5,0xf3e4004e,0x21a10313}},	//   لوقت, rgôt_, _ажоо, рифм, 
   {{0xe8f8031c,0xaf981429,0xe0400107,0x79880142}},	//   ྒྲིབ_, ьтах_, анфи, hrew, 
   {{0x82cc0597,0x6e446caa,0x7988033f,0xdfcc02c9}},	//   _ঔღঔ_, ننام, krew, تيم_, 
   {{0x2d940861,0x00000000,0x00000000,0x00000000}},	//   трес, --, --, --, 
   {{0x61e81600,0xdca10314,0x5b200633,0x00000000}},	//   øgle, иачи, یفول, --, 
   {{0x6b98030d,0x612801b8,0x79880036,0x1b74007b}},	//   _qqtg, xüli, erew, نصية_, 
   {{0x64dc1dd1,0x79890315,0x00000000,0x00000000}},	//   _नक्श, frew, --, --, 
   {{0xed4407dd,0xbda475b0,0xdee039b8,0xada40120}},	//   _анап, _محلو, _тоти, _јазл, 
   {{0xdca00352,0x6b6441e5,0xd68c0150,0x28d000cd}},	//   _вафи, _акжа, _ﻓﺩﻭﺭ_, ताधि, 
   {{0xbb2c0ed1,0x7988045f,0x00000000,0x00000000}},	//   ﺩﻩﻥ_, arew, --, --, 
   {{0x79880a85,0x6128e723,0x80c8b7b0,0x00000000}},	//   brew, rüli, _होने, --, 
   {{0x61290316,0x798876d1,0x59600801,0x99d04111}},	//   süli, crew, _къща, _نتوا, 
   {{0x8c3c00c6,0x61290317,0x439401c6,0x00000000}},	//   _sağy, püli, лагс, --, 
   {{0x53e401c6,0xc8785043,0x00000000,0x00000000}},	//   ацта, mağ_, --, --, 
   {{0x98a40118,0x3af0032e,0xc87825a8,0x00000000}},	//   _ohně_, _kápa_, lağ_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [174d0] --, --, --, --, 
   {{0xc87806be,0x00000000,0x00000000,0x00000000}},	//   nağ_, --, --, --, 
   {{0x7c2c0c09,0x3fc41ac1,0x40880116,0x73c001af}},	//   ƙari, ырағ, _җәзм_, _ләте, 
   {{0x975404ae,0x4ea41a51,0x6b8800d7,0x00000000}},	//   דיאו_, ирча, drfg, --, 
   {{0x2fc40421,0x6b880036,0x612806be,0xce940395}},	//   āoga_, erfg, dülv, рачъ, 
   {{0x3e70004d,0xe0e401b9,0xdcec00d7,0x00000000}},	//   ạt_, _рўмо, ťeľo, --, 
   {{0xc8780259,0x4fc40150,0x00000000,0x00000000}},	//   dağ_, _پەنە, --, --, 
   {{0x79880af9,0x2eec0221,0x8afc0210,0x00000000}},	//   trew, ëfft_, _rtęc, --, 
   {{0x79880810,0x7e78014f,0xc8780139,0x00000000}},	//   urew, mawp, fağ_, --, 
   {{0xb4b0006d,0x7e78009a,0xf8cc00e1,0x04f40154}},	//   _ऐसे_, lawp, ़ाइय, ঙচুর_, 
   {{0x81d80f22,0x09b4031c,0xa92001c0,0x79880066}},	//   ়নি_, _ཝརྨ_, сдэл, srew, 
   {{0x7c250318,0x7e7803f0,0x7f5401d5,0x7988017a}},	//   ühru, nawp, _muzq, prew, 
   {{0xe9cd0319,0xc8780cc1,0xf9840801,0xfbbc043e}},	//   _ук_, bağ_, _сгло, ्मकम, 
   {{0xdc40012c,0x7e7803f0,0x232401b9,0x81d8015b}},	//   _léči, hawp, ҳоси_, ়না_, 
   {{0xc2600521,0x63800024,0x2934008f,0x2898010f}},	//   _ụdịr, йгра, _גאסן_, _ניקא, 
   {{0xfd4800cd,0x1c180037,0x00000000,0x00000000}},	//   _vimṛ, _पुछल_, --, --, 
   {{0x42d40220,0x00000000,0x00000000,0x00000000}},	// [174e0] шіру, --, --, --, 
   {{0xdfcc05d9,0x7f54036e,0xc05800d4,0x64a00354}},	//   ڻين_, _buzq, вії_, _лаьа, 
   {{0xae880724,0xee84035b,0xa2bc590f,0x00000000}},	//   ебез_, гыло, _लोक्, --, 
   {{0xe0dc0428,0x273c0023,0xe3b001c8,0x00000000}},	//   _quòr_, ተፈልጠ, _ارٿ_, --, 
   {{0xc8780342,0x00000000,0x00000000,0x00000000}},	//   yağ_, --, --, --, 
   {{0xb4b002e5,0x00000000,0x00000000,0x00000000}},	//   _ऐसो_, --, --, --, 
   {{0xeb49031a,0x3af01427,0xe45400df,0xaab00118}},	//   нчик_, _sápa_, ניקט_, ूएलक, 
   {{0x3af1031b,0xce3401d9,0xf8ac00f1,0x00000000}},	//   _pápa_, _نوزک, ېکي_, --, 
   {{0xe94401c6,0x99803092,0x612800e5,0xa9c402f2}},	//   лхоо, مليو, rülv, ازبو, 
   {{0xdd8c1410,0x1cb0031c,0x00000000,0x00000000}},	//   _روم_, _ཟིར_, --, --, 
   {{0x98c00948,0xab642bbd,0x7c240112,0x6a840108}},	//   ссыл, _свел, ührt, _блеа, 
   {{0x28d0185b,0xbebc0882,0x569400d4,0x00000000}},	//   ताहि, _bhūy, бают, --, 
   {{0x15a800a7,0xa85004b4,0xa2bc0ebb,0x00000000}},	//   лъри_, _лелә, _लोग्, --, 
   {{0x64400122,0xbebc0055,0x61f8010e,0x8af803b9}},	//   _únik, _dhūy, _ýuli, _şəhz, 
   {{0x1cb00003,0x93886d66,0x2cbc0139,0xe7843e54}},	//   _ཟིལ_, лста_, _matd_, _суло, 
   {{0x28d0085c,0xfbc400dc,0x2004033f,0x00000000}},	//   तावि, वितम, źnik_, --, 
   {{0x9f4402f8,0x6129031c,0x5335031d,0xa08800fd}},	// [174f0] ání_, kült, сетт, есез_, 
   {{0x98a5031e,0xc69001d3,0x00000000,0x00000000}},	//   čiću_, _اِک_, --, --, 
   {{0x9f440316,0x78a4007c,0x00000000,0x00000000}},	//   šní_, _öhve, --, --, 
   {{0xf1c80030,0x00000000,0x00000000,0x00000000}},	//   _stáť_, --, --, --, 
   {{0x272804cc,0x7e7802d1,0x7d1c01a8,0x00000000}},	//   lùns_, rawp, _íssk, --, 
   {{0x61288357,0xed5400f7,0x5578008f,0xbd44007b}},	//   gült, шош_, רעגן_, جنتي, 
   {{0xd49808a8,0x7e78014f,0x24d400eb,0xd8680150}},	//   אכות_, pawp, _হতাহ, _ﺳﯘﻟﯟ, 
   {{0x80c80073,0x00000000,0x00000000,0x00000000}},	//   _होते, --, --, --, 
   {{0x272807c5,0xe9d44e73,0x00000000,0x00000000}},	//   hùns_, икъ_, --, --, 
   {{0xbebc06c8,0xb9040120,0x6128002f,0x7c24002f}},	//   _okūk, рзок, pülu, ührs, 
   {{0x36681cc9,0x6ec80073,0x00000000,0x00000000}},	//   кано_, _सोडु, --, --, 
   {{0xa68003c5,0x00000000,0x00000000,0x00000000}},	//   олюд, --, --, --, 
   {{0xe8ec4143,0x996447c3,0x61280b97,0x00000000}},	//   _дл_, _стел, nüls, --, 
   {{0x1cb0031c,0x00000000,0x00000000,0x00000000}},	//   _ཟིས_, --, --, --, 
   {{0x3775031f,0x272804cc,0x28d021b8,0x69c40158}},	//   _тылс, gùns_, तारि, åkev, 
   {{0x61290320,0x00000000,0x00000000,0x00000000}},	//   zült, --, --, --, 
   {{0x008400f7,0xd5a4136e,0x30540114,0x61280205}},	// [17500] өктү, _الخی, ађет, yült, 
   {{0x61e80158,0xc0f80092,0x055401af,0x00000000}},	//   øgla, _ገቢር_, _утъя, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x1ae800cc,0x00000000,0x00000000,0x00000000}},	//   জোতে_, --, --, --, 
   {{0x3af00241,0x9db413f9,0xa2bc4709,0x623000d8}},	//   _aápo_, لدوز_, _लोट्, _меџу, 
   {{0xa0650321,0x00000000,0x00000000,0x00000000}},	//   _вара_, --, --, --, 
   {{0xafe50322,0x6128f6ff,0x3af00174,0x00000000}},	//   _товл, rült, _vápn_, --, 
   {{0x9b410323,0x497424e5,0xdbd0148b,0x612800e5}},	//   ينوو, блис, rúðg, sült, 
   {{0xdcf804b9,0xed58651f,0x41c81a3e,0x28740032}},	//   _zvuč, _роз_, रियस, аҡлы_, 
   {{0x7d0c007b,0x612801d3,0x00000000,0x00000000}},	//   éast, lülr, --, --, 
   {{0xfaf8002b,0x186400d8,0x00000000,0x00000000}},	//   bhū_, јаџи_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x84c4053f,0x8b640244,0x00000000,0x00000000}},	//   бәнд, _ئاڕم, --, --, 
   {{0xd9410324,0x04c86762,0x7c2c0198,0x067c0131}},	//   _дечи, دوسي_, ƙart, _ﻣﯩﻨﯩ, 
   {{0x6600016b,0x00000000,0x00000000,0x00000000}},	//   _ɛnky, --, --, --, 
   {{0x4df805f9,0xc2540395,0x0684009f,0x00000000}},	//   ्छाई_, скащ, _الظُ, --, 
   {{0xddd804b9,0x612803b9,0x00000000,0x00000000}},	// [17510] _oduš, dülr, --, --, 
   {{0xe04871f1,0x20640063,0xaaa41b61,0x00000000}},	//   نشاه_, рђав, क्तक, --, 
   {{0x83190325,0x90280953,0x00000000,0x00000000}},	//   _مقدر_, ацца_, --, --, 
   {{0x3ea80209,0xcd28781d,0xfbc4012c,0x21b40014}},	//   ýat_, یسون_, विसम, _پھرک_, 
   {{0x51842f0d,0x94740150,0xdd990326,0x00000000}},	//   _мура, _ادۋا, тше_, --, 
   {{0xbb8400ae,0x00000000,0x00000000,0x00000000}},	//   ملتي, --, --, --, 
   {{0x3b080d84,0x69c50327,0xdcf807f5,0xef0c004b}},	//   леко_, æken, _uvuč, _ګڼل_, 
   {{0xce9483f9,0x3f800af2,0x42c4015b,0xd9dc0154}},	//   _масъ, mshu_, _একুশ, _বেগম, 
   {{0x3df50328,0x00000000,0x00000000,0x00000000}},	//   _узас, --, --, --, 
   {{0xe8f50329,0x68f89108,0xfaf8003e,0x7bc4007c}},	//   йлы_, ghtd, shū_, åhus, 
   {{0x3f81032a,0x224400bc,0x3b800092,0x00000000}},	//   nshu_, ěnky_, ረጃዎች_, --, 
   {{0xddd804a7,0x3f806a83,0x0674003b,0x00000000}},	//   _zduš, ishu_, журя, --, 
   {{0xe9cc084c,0x7c2c03f9,0x69c403cd,0x3ce401e3}},	//   _эк_, ƙars, åket, _kolv_, 
   {{0x68f9032b,0xc5b8025c,0x75d40150,0x00000000}},	//   chtd, _བརྫི, _ۇيعا, --, 
   {{0xf7441679,0x3944009a,0x00000000,0x00000000}},	//   _леко, mmls_, --, --, 
   {{0x610c0153,0x612806be,0xe294004e,0x00000000}},	//   _lėlė, dülq, йас_, --, 
   {{0x21640058,0x612801d3,0x7085032c,0x3f800171}},	// [17520] йити_, vülr, йгаз, eshu_, 
   {{0xed5800c2,0xd5c40055,0x00000000,0x00000000}},	//   ҳод_, _enāü_, --, --, 
   {{0xe4540bd9,0x2878008f,0x3f8000ef,0x00000000}},	//   _לייט_, רנעמ, gshu_, --, 
   {{0xed582e80,0xee78007b,0xef180024,0x00000000}},	//   год_, اصات_, ыме_, --, 
   {{0x470400dc,0x3f80058a,0xace801d5,0x5ea00b6c}},	//   _adṛṣ, ashu_, лмда_, سمول, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xef189771,0x9f440232,0x3b0c031c,0x00000000}},	//   _бмв_, šná_, fieq_, --, 
   {{0x76540421,0x6014011a,0x7d0c007b,0x00000000}},	//   _ngyy, _החלף_, éasr, --, 
   {{0xaac401d5,0x00000000,0x00000000,0x00000000}},	//   لتکن, --, --, --, 
   {{0x3ce400bf,0x610c0006,0x50c800dc,0xfca85fb1}},	//   _golv_, _gėlė, रयिष, _نامو_, 
   {{0xda6c0953,0xabf41ab7,0x00000000,0x00000000}},	//   _ня_, _учащ, --, --, 
   {{0xdc3800c8,0x798001f2,0x7c2c0198,0xfbd001d3}},	//   _געבר, _ịwer, ƙarr, _کتے_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x5559032d,0xbb440150,0x3f80058a,0xf96402f2}},	//   саря_, _ﺄﺯﻕ_, yshu_, _بنوێ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3f800140,0x2d74012d,0xa344009d,0x3e7c0064}},	//   vshu_, kłe_, сэгл, oštų_, 
   {{0xf1581b15,0x9c800010,0x3f800067,0x04440139}},	// [17530] иптә_, ščip, wshu_, сеңн, 
   {{0x46a4085c,0x3f81032e,0x3b0c020b,0x3e7c0153}},	//   ग्रह, tshu_, zieq_, ištų_, 
   {{0x64540944,0x3ce408cb,0x425446c1,0xf4880023}},	//   _igxi, _rolv_, _وندر, _ንምሃብ_, 
   {{0x3e7c0006,0x3ce40175,0x8e740006,0x81d4014b}},	//   kštų_, _solv_, пушч, _домх, 
   {{0x72a00150,0x2d74033f,0xfce5032f,0x44200051}},	//   _تەقن, głe_, жоло, _hxh_, 
   {{0xaaa400bc,0xee9c01ec,0x00000000,0x00000000}},	//   क्सक, _ﺇﻋﻼﻥ_, --, --, 
   {{0x4ac40d2c,0x7cfc00cf,0x3ce404cc,0x0b64001f}},	//   वयंव, _lèrg, _volv_, _ሲኒየር_, 
   {{0x4420001e,0xd1b80345,0x00000000,0x00000000}},	//   _mxh_, _ئاێا_, --, --, 
   {{0x64540921,0x3ce42ff9,0x3eac004d,0xde4400e5}},	//   _ogxi, _tolv_, _ibet_, _ایشو_, 
   {{0x6454009a,0x77840861,0x395004cc,0x00000000}},	//   _ngxi, олоз, özs_, --, 
   {{0xf0901203,0xf74473da,0x69c411ad,0x7cfc0100}},	//   וני_, жено, åker, _pèrf, 
   {{0x64550330,0xa8040de2,0x3dcd0331,0xc5b8031c}},	//   _agxi, _soññ, _krew_, _བརྡི, 
   {{0x7c2cfb54,0x3eac0240,0x00000000,0x00000000}},	//   şard, _mbet_, --, --, 
   {{0x44210332,0x80c805dc,0x00000000,0x00000000}},	//   _bxh_, _होले, --, --, 
   {{0xb6a50333,0x64a00588,0x28c005f9,0x3ead0334}},	//   _дийл, ьара, _वोटि, _obet_, 
   {{0x64540944,0xa8040de2,0x2bac0213,0xdb200166}},	//   _egxi, _woññ, _həcc_, _äsäd, 
   {{0x4420045a,0x941806be,0xa5f400f3,0x00000000}},	// [17540] _exh_, _əzəl_, _мећу_, --, 
   {{0xe0d50335,0x3ead0336,0x00000000,0x00000000}},	//   ову_, _abet_, --, --, 
   {{0xe6900b43,0x7cfc02e2,0x00000000,0x00000000}},	//   _علید, _mèrd, --, --, 
   {{0x3dcc47b4,0x46dc0118,0x00000000,0x00000000}},	//   _brew_, यायह, --, --, 
   {{0x7e6c2e95,0xccf81870,0x6d2402d5,0x00000000}},	//   ñapa, бқа_, оддз, --, 
   {{0x3eac03bd,0x7af8007f,0x6440026c,0x9c540640}},	//   _ebet_, _alwt, _ùnic, ошћу_, 
   {{0x46dc00dc,0x2d74033f,0x00000000,0x00000000}},	//   यामह, słe_, --, --, 
   {{0x7af80142,0x2d74033f,0xdb000100,0x00000000}},	//   _clwt, płe_, ntnè, --, 
   {{0xada50337,0x3dcc0c18,0x23880023,0x8d7400ec}},	//   _фазл, _grew_, _ንውድብ_, _ڀاڄا, 
   {{0x6bd50338,0x1cb00135,0xd9140b7e,0x3e7c0024}},	//   _وتار, _ཟིག_, жью_, rštų_, 
   {{0xdca05ded,0x7cfc068c,0xe0b4011a,0xfbcc00ec}},	//   _цахи, _sèrg, חליט_, _مڪي_, 
   {{0x4420009a,0x7cfcfd51,0x7af80042,0x63a00254}},	//   _rxh_, _pèrg, _glwt, _änni, 
   {{0x6a150339,0x9f440af2,0x88ac00cc,0xfa5c0241}},	//   _ببار, âné_, _কোণক, _tọrẹ_, 
   {{0x7c2c19b2,0x00000000,0x00000000,0x00000000}},	//   şare, --, --, --, 
   {{0x4420020c,0xd77010e0,0xbb300150,0xd82c01c4}},	//   _qxh_, _قايع, _ﺭﻭﻥ_, _цэ_, 
   {{0x6ec80316,0x00000000,0x00000000,0x00000000}},	//   _सोलु, --, --, --, 
   {{0x7cfc1e54,0x572400cf,0xe4e402dd,0x5bb400cd}},	// [17550] _hère, _تىيك, _дінн, _आन्व, 
   {{0x64540944,0x7cfc0066,0x656d033a,0x20680417}},	//   _ugxi, _kère, mpch, ршап_, 
   {{0x656d033b,0x985c0240,0x93e401a9,0x00000000}},	//   lpch, _ተቓሊዑ_, _жўял, --, 
   {{0x1cb0081f,0x3dcc0ffb,0x7cfd033c,0xdcb000dc}},	//   _ཟིང_, _prew_, _mère, ंज्ञ, 
   {{0x3ead033d,0x656c02d0,0x00000000,0x00000000}},	//   _vbet_, npch, --, --, 
   {{0x6cc00c98,0xbea805d9,0xbebc411e,0x6da008ca}},	//   ейша, _گهرن_, _akūt, хиша, 
   {{0x3dcc025c,0x5e840b01,0xdb000332,0x00000000}},	//   _wrew_, _муаз, ltné, --, 
   {{0x3dcc9c28,0xdb201b2c,0xef6401c6,0x00000000}},	//   _trew_, بوبی, _хэрү, --, 
   {{0x7cfd033e,0xf9900597,0x38680198,0xdb001315}},	//   _pèrd, ربة_, _ƙar_, ntné, 
   {{0x7cfc067c,0x28d00307,0x00000000,0x00000000}},	//   _bère, तागि, --, --, 
   {{0xf0901a4c,0x7cfc5051,0xd7080131,0x656c0036}},	//   ענט_, _cère, قىدۇ_, epch, 
   {{0x7cfc067c,0x7bc1033f,0xa25807ea,0xdb0000d0}},	//   _dère, _islu, _saôn, ktné, 
   {{0x7bc000d8,0x9c8016a3,0x00000000,0x00000000}},	//   _hslu, ščup, --, --, 
   {{0x7bc0089c,0x7cfc004e,0xd7e40137,0x00000000}},	//   _kslu, _fère, _ووشۇ_, --, 
   {{0xa5050340,0x7cfc06af,0x395c03cb,0xefc80023}},	//   чера_, _gère, _huws_, በቅዕ_, 
   {{0xd34801d5,0x9f4c0150,0x00000000,0x00000000}},	//   تیجه_, _ﺑﺎﻻﯞ_, --, --, 
   {{0xe7140375,0x8e2001ec,0x3de00154,0x00000000}},	// [17560] _מחקר_, бiн_, _মেঘল, --, 
   {{0x7bc007f5,0x9f44006a,0x00000000,0x00000000}},	//   _oslu, ânî_, --, --, 
   {{0xb028007b,0x2cb806be,0x13a81d0a,0x00000000}},	//   حكام_, _özdə_, _بنجی_, --, 
   {{0x42a0044e,0x794c0034,0x6da50341,0x61e80200}},	//   _ውጽኢት_, _dźwi, зида, ëllë, 
   {{0x237c04b9,0x7bc10342,0x46dc0490,0x200401a8}},	//   ćuje_, _aslu, यातह, únir_, 
   {{0x4c950343,0x2bb8007b,0xd7d8041c,0xbebd0344}},	//   фикс, ماعة_, यमाच, _skūt, 
   {{0xfca82764,0x00000000,0x00000000,0x00000000}},	//   تانو_, --, --, --, 
   {{0xada47863,0x37d00154,0x6da4013d,0xdfcc1541}},	//   _набл, াহার, _ниба, _حيف_, 
   {{0x7cfc0066,0x7cf400e4,0xef9000f1,0x00000000}},	//   _sère, _ỹrek, _زیږد, --, 
   {{0x7cfc4056,0x7c6400d1,0x2d8401bf,0x00000000}},	//   _père, _قامل, msoe_, --, 
   {{0x068400f7,0x7c2c2ca8,0x00000000,0x00000000}},	//   үгүн, ğarc, --, --, 
   {{0xdb000306,0x656c00e4,0x2bc000cd,0x05b80118}},	//   ytné, tpch, _वैया, इबलब, 
   {{0x6d490345,0xa25805da,0x60d803f9,0x00000000}},	//   omfa, _daôl, _ɗumb, --, 
   {{0x69c10346,0x656c05b1,0x7cfc02e2,0xd4e401a9}},	//   _isoe, rpch, _tère, нюси, 
   {{0xd8a416cb,0x290c0bd7,0x7cfc00db,0x6d4801e2}},	//   _رهيو_, _imfa_, _hèrc, imfa, 
   {{0xdec836bc,0x656d0347,0x68e8017a,0x3af006ea}},	//   በትን_, ppch, _hofd, _pápi_, 
   {{0x442c068f,0x672c068f,0x752c0334,0xdbc402d2}},	// [17570] łe_, mocj, bobz, _löðr, 
   {{0x51f83c1b,0x7cfd0348,0xdb010349,0x6d4801e4}},	//   чную_, _mèrc, rtné, jmfa, 
   {{0xe3b40135,0x290c0270,0xdb002195,0x6aa0009a}},	//   _བགྲང, _mmfa_, stné, _ocof, 
   {{0x6d4801e2,0x69c0009d,0x644000cf,0x2480036e}},	//   emfa, _osoe, _úniq, lajm_, 
   {{0xdda88739,0x629d034a,0x68e801c7,0x00000000}},	//   стел_, mgqo, _oofd, --, 
   {{0x7cfc1f40,0x2fc4012d,0x5d3000e5,0x00000000}},	//   _sèrb, łoga_, رہائ, --, 
   {{0x672c0210,0x3f8401e1,0x00000000,0x00000000}},	//   kocj, _ìlu_, --, --, 
   {{0x629c8cdb,0x290c013f,0x60c5034b,0x752c110c}},	//   ngqo, _amfa_, _hajm, zobz, 
   {{0x7cfc180f,0x752c00ca,0x38640175,0x39440139}},	//   _cèrc, yobz, tclr_, мниг, 
   {{0xc944005e,0x60c5034c,0x0e0800f7,0x7bc012ef}},	//   ндық, _jajm, _ээси_, _tslu, 
   {{0x60c5034d,0x69c1034e,0x7cfc00cf,0x00000000}},	//   _majm, _esoe, _tèrb, --, 
   {{0x60c5034f,0x7cfc067c,0x3864010a,0xf7710350}},	//   _lajm, _fèrc, sclr_, _یاب_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x764003a5,0xb9249f9c,0x05540108,0x00000000}},	//   нҭқа, _تفتي, ется, --, 
   {{0xe4fc00c5,0x19c40150,0x00000000,0x00000000}},	//   _उतरि_, _ﻓﻴﻠﺠ, --, --, 
   {{0x41c82ca5,0x00000000,0x00000000,0x00000000}},	//   रिंस, --, --, --, 
   {{0x60c50351,0x00000000,0x00000000,0x00000000}},	// [17580] _bajm, --, --, --, 
   {{0x7e680421,0x61e801e6,0x60c40009,0x00000000}},	//   _afep, ägla, _cajm, --, 
   {{0x60c50352,0x8d2800fd,0x00000000,0x00000000}},	//   _dajm, үнең_, --, --, 
   {{0x2d84052f,0x3af009e8,0x5d800116,0x00000000}},	//   tsoe_, _kápu_, ھلىل, --, 
   {{0xccf82e56,0x00000000,0x00000000,0x00000000}},	//   пқа_, --, --, --, 
   {{0x6d490353,0x6aa10354,0x2b5c0098,0x628800d0}},	//   umfa, _scof, _putc_, ógov, 
   {{0xa0a10355,0xa2d00490,0x6aa001bf,0x2d8401c7}},	//   _шард, डाच्, _pcof, ssoe_, 
   {{0x60c4068f,0x69c001c6,0x298801c0,0x68e801a9}},	//   _zajm, _psoe, осоо_, _sofd, 
   {{0x7c2d0356,0x60c4047e,0x6da405af,0x386800a2}},	//   ğara, _yajm, _زمام, _şara_, 
   {{0x7c2c3630,0x940400ac,0x60c48b17,0x6c8402c9}},	//   şara, şmə_, _xajm, _آلام, 
   {{0x98c00032,0xa09400df,0x00000000,0x00000000}},	//   тсыл, ודיק_, --, --, 
   {{0x69c00184,0x6f010357,0x7c9c001f,0x6aa000f1}},	//   _tsoe, nhoc, ፈጠረው_, _ucof, 
   {{0x7cfc004e,0x69c0005a,0x2bc02d6b,0x5a40010a}},	//   _hèra, _usoe, _वैता, _иэша, 
   {{0xdeb8044e,0x672c0e5e,0xdec80020,0x9f450358}},	//   _ተሓኤ_, socj, በትና_, ánú_, 
   {{0x60c50359,0x6f01035a,0x672c1710,0x7cfc01e1}},	//   _rajm, khoc, pocj, _jèra, 
   {{0x272805d5,0x9f440030,0x2ba400cd,0x00000000}},	//   hùnz_, šnú_, _गमना, --, 
   {{0x461401d9,0x291d035b,0x5335035c,0x9f4400d2}},	// [17590] _سودر, onta_, тетт, âní_, 
   {{0x46dc0a5a,0x291d035d,0x80c8007d,0x60c48ad5}},	//   यावह, nnta_, _होखे, _qajm, 
   {{0x291d035e,0x6f000597,0x60c501cb,0xdbc4007c}},	//   inta_, fhoc, _vajm, _höör, 
   {{0x60c40784,0x2bc01152,0x26c80129,0x2b44004d}},	//   _wajm, _वैधा, ndco_, _nhoc_, 
   {{0x60c5035f,0x291c0198,0x4cc8009e,0x00000000}},	//   _tajm, knta_, লানু, --, 
   {{0xc5b80135,0x6f000208,0x2614000d,0x00000000}},	//   _བརླི, ahoc, _पइनी_, --, 
   {{0xcfa50360,0x2b4400a3,0x6f00014b,0x291c0009}},	//   _ишти, _bhoc_, bhoc, dnta_, 
   {{0x2b450361,0x6f010362,0x88bc0118,0x88ac00eb}},	//   _choc_, choc, hněd, _কোলক, 
   {{0x628c030d,0x291c0083,0xdbc40037,0x00000000}},	//   _mdco, fnta_, _nöör, --, 
   {{0xa920b132,0x7cfc067c,0x78a8026a,0x0e440166}},	//   лдыл, _fèra, чког_, _рэсм, 
   {{0x7cfc0066,0x628c02d0,0x3af003f2,0x1dc406b1}},	//   _gèra, _odco, _sápu_, लिकत, 
   {{0x291d0363,0x60d802a8,0x00000000,0x00000000}},	//   anta_, _ɗuma, --, --, 
   {{0x291c00fb,0xdb0000bc,0x88c4036b,0x00000000}},	//   bnta_, ntní, رتیل, --, 
   {{0x628d0364,0xb0cc068f,0x79880bd7,0x25bc0798}},	//   _adco, _होंग, msew, çula_, 
   {{0x1cb01efe,0xb600038e,0x74150365,0x798829d0}},	//   _ཟིན_, _žádn, رورا, lsew, 
   {{0x628c0158,0x35a4277c,0xdb0000bc,0x6f000472}},	//   _cdco, _заиг, ktní, xhoc, 
   {{0x79890366,0x46dc1a22,0x52e000ab,0xa22402e8}},	// [175a0] nsew, यारह, _पचीस, ежта_, 
   {{0xa0a10367,0x628c80c4,0x1c1c1bf9,0x79880072}},	//   лауд, _edco, यपाल_, isew, 
   {{0x6f010368,0xaf981fac,0xa520010b,0x4cc80154}},	//   thoc, ятах_, _сүрҗ, লামু, 
   {{0xeda4a15c,0x7cfc00e4,0xa8540375,0xaf340a12}},	//   ешко, _rèra, גיעה_, ررات, 
   {{0x291d0369,0x63a001c7,0x6f000112,0xc508030f}},	//   ynta_, _ännr, rhoc, _رتیل_, 
   {{0x6f01036a,0x68040098,0x7cfc0066,0x291c0009}},	//   shoc, _jéjé, _pèra, xnta_, 
   {{0x6f01036b,0x99600046,0x2b4401c3,0x80c81152}},	//   phoc, қтыл, _phoc_, _होटे, 
   {{0x63a00158,0xdee02a3b,0x00000000,0x00000000}},	//   _ånne, _йоси, --, --, 
   {{0x25a8eefe,0x7a480022,0x00000000,0x00000000}},	//   xtcl_, vêté, --, --, 
   {{0x291d036c,0x7cfc0f87,0x6804003e,0xdd8c18fd}},	//   unta_, _hèrn, _néjé, _دوك_, 
   {{0x7c64a482,0x6d59036d,0x79880c8c,0x3af000d8}},	//   _شالل, _iita, asew, _cáps_, 
   {{0x6d59036e,0xdbc4007d,0xe5c401c6,0x798800a2}},	//   _hita, _pöör, нсго, bsew, 
   {{0x68040098,0x7a4807ea,0x26c80204,0x06b400eb}},	//   _béjé, rêté, rdco_, য়ালি, 
   {{0x6d59036f,0x291c0113,0x4394531d,0xdbc4000d}},	//   _jita, qnta_, кагс, _vöör, 
   {{0x7e6c0054,0x628c00a3,0x9cd40375,0xb7c402dd}},	//   ñapk, _pdco, עולה_, _арық, 
   {{0x6d590370,0x5334074d,0xdbc400af,0x5454470c}},	//   _lita, гест, _töör, увст, 
   {{0x6d590371,0xdcf80841,0x628c01a6,0x534400d8}},	// [175b0] _oita, _uvuć, _vdco, ухра, 
   {{0x6d590372,0x55ac008f,0xb6380150,0xa6e000cc}},	//   _nita, _צייַ, _ﺄﺓ_, _পতিয়, 
   {{0x7cfc067c,0x628c0334,0x73c001ee,0x00000000}},	//   _bèrn, _tdco, _кәте, --, 
   {{0xfe7004fb,0xafe401bf,0x4fc40124,0x7020000d}},	//   شگر_, _skøø, ысуа, _मशरख_, 
   {{0x6d5837c7,0xd24412cf,0x00000000,0x00000000}},	//   _bita, _бэри, --, --, 
   {{0x6d5861f8,0x8d741b06,0xdb000118,0x009401c6}},	//   _cita, اانا, rtní, _шигэ, 
   {{0xdb000e96,0xbb4805d9,0x6d9c0055,0x00000000}},	//   stní, ولتن_, _ṣatv, --, 
   {{0x79890373,0x6d590374,0x8e840597,0x1cb0025c}},	//   tsew, _eita, _ملفه, _ཟིམ_, 
   {{0x6d590375,0xa2580086,0x7d54352d,0x79890376}},	//   _fita, _baôi, _авах, usew, 
   {{0x6d590377,0x79890378,0x2bc00562,0xe8f40958}},	//   _gita, rsew, _वैवा, вль_, 
   {{0x7d000c8c,0x8afc003a,0x00000000,0x00000000}},	//   _ills, _quęc, --, --, 
   {{0x68041dd4,0x7e6c0309,0x97800214,0x798802d0}},	//   _séjé, ñaph, پیکه, psew, 
   {{0x6d590379,0x7ae9037a,0x59b00166,0x437400d1}},	//   _yita, mjet, _сөйс, ғуст, 
   {{0x6d59037b,0x7ae9037c,0xddd81050,0x5885037d}},	//   _xita, ljet, _oduž, _чыда, 
   {{0x28a44c21,0xd83801c6,0xd8000354,0xca500150}},	//   _खाति, _ээд_, _сăв_, _ﻌﺎﺕ_, 
   {{0x7ae83954,0x05c8033f,0x02c40139,0x00000000}},	//   njet, िटखब, лисү, --, 
   {{0x7d01037e,0x6260dab7,0x76240120,0x75445e0c}},	// [175c0] _olls, рвуа, _шмиз, _иниз, 
   {{0x7ae9037f,0x4254d466,0x04c800ec,0x53440354}},	//   hjet, утст, _ٻوٽي_, ăхра, 
   {{0xa0304d2d,0x7fd400d6,0x7c2c0198,0xdfcc0451}},	//   لىكت, ліці, ƙary, ٺين_, 
   {{0x7f490380,0x7d00e047,0x7ae80a4d,0x92b00183}},	//   _cheq, _alls, jjet, _টোৰ_, 
   {{0x6d581326,0x7ae85835,0xf5200020,0x7c2cf1cd}},	//   _pita, djet, _ደህንነ, şarl, 
   {{0x1d303334,0xde000114,0x7ae80210,0x00000000}},	//   анія, рпљи, ejet, --, 
   {{0x9fc4055f,0x2f54e254,0x09bcb2b5,0x7cfc0ba1}},	//   _игра_, _атас, ्ट्य, _ièrl, 
   {{0x6d590381,0x4cc800bd,0x7d000c8c,0x7ae8f1ae}},	//   _wita, লাধু, _ells, gjet, 
   {{0x6d590382,0xada50383,0x2bc017c6,0x2ca80209}},	//   _tita, _шаал, _वैरा, _окап_, 
   {{0x6d590384,0x48c40131,0x7ae80108,0x88bc013a}},	//   _uita, ушиғ, ajet, dněc, 
   {{0xa09804ac,0x7ae90385,0xf8acba0b,0xfca8216b}},	//   וייט, bjet, سکو_, _سالو_, 
   {{0x7ae80003,0x00000000,0x00000000,0x00000000}},	//   cjet, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa85039c7,0x9810a2ee,0x47d40a12,0xbcfc002b}},	//   _келә, ابیا, _ميتر, _kuũa, 
   {{0xd7ed0386,0x9388e41b,0x55580262,0x58b8011a}},	//   _ту_, кста_, таря_, _חמוצ, 
   {{0x2a94016b,0x00000000,0x00000000,0x00000000}},	//   _bɛbɔ_, --, --, --, 
   {{0x45d41b6b,0x04444990,0x12e401ec,0x80b4022e}},	// [175d0] _сопс, теңн, шірг, лбах, 
   {{0x7f4802d3,0x5f74007b,0x00000000,0x00000000}},	//   _sheq, ناصر, --, --, 
   {{0x9f880254,0x7ae800e4,0x9fc4011c,0x00000000}},	//   _lööv_, yjet, ъщал, --, 
   {{0x1e700220,0xdb200037,0x00000000,0x00000000}},	//   рғас, örüh, --, --, 
   {{0x7ae90387,0x5184109a,0x1ee43a56,0x38680139}},	//   vjet, _вуса, _یوسی_, _şarm_, 
   {{0x7c2ca697,0x403473e6,0x7ae90388,0x9258010b}},	//   şarm, _бегс, wjet, _шаят_, 
   {{0x7a680323,0x4fc50389,0x7ae9038a,0x80b00073}},	//   нийг_, _кста, tjet, ीजीं, 
   {{0x2a94016b,0x7cfc020c,0xaad80864,0x00000000}},	//   _yɛbɔ_, _tèro, भागक, --, 
   {{0x7ae9038b,0x7cfc020c,0x5d10004b,0xeab401e0}},	//   rjet, _hèrm, _پېغا, уйы_, 
   {{0x7ae9038c,0x7d0085f7,0x3775038d,0xabb40022}},	//   sjet, _ulls, лымс, _әацә, 
   {{0x7ae9038e,0x7cfc0066,0x69c49f5c,0xca480345}},	//   pjet, _jèrm, æker, _یلمه_, 
   {{0xc4c8011a,0xabf8010f,0x00000000,0x00000000}},	//   _מג_, _אהער, --, --, 
   {{0x59b44802,0x685002d3,0x383401c6,0x00000000}},	//   _अहिर, _መዓልት, _өндр, --, 
   {{0x090400c0,0x00000000,0x00000000,0x00000000}},	//   _кпін, --, --, --, 
   {{0x312401d5,0x00000000,0x00000000,0x00000000}},	//   ҳдаг, --, --, --, 
   {{0x473401d9,0x87b8014b,0x00000000,0x00000000}},	//   _پر٘ز, _рушт_, --, --, 
   {{0xf1a824e0,0x232400c2,0x7cfc6f8d,0x3125038f}},	// [175e0] عاره_, уоти_, _pèrl, гдаг, 
   {{0xc5b80003,0xa11000f7,0x386805d1,0x73e4004e}},	//   _བརྗི, موقت, _şarj_, _бооз, 
   {{0x9f44674e,0x28a41889,0xf9f80183,0xfbc40451}},	//   šný_, _खासि, ইছিল_, _بڪ_, 
   {{0x7164112d,0x6e440e4a,0x6e941867,0x66d80108}},	//   _ماسك, هنام, الشا, _iäkä, 
   {{0xa3080014,0x66d80108,0x06a000d1,0x00000000}},	//   _سرَے_, _häkä, _ﺋﯚﻳﯩ, --, 
   {{0x7cfc068c,0x5d800472,0x00000000,0x00000000}},	//   _fèrm, حلول, --, --, 
   {{0x7cfc004e,0xf5200092,0x66d80108,0xfe6c014b}},	//   _gèrm, _ደኅንነ, _jäkä, _мӯ_, 
   {{0x200c0209,0x66d90390,0x8cd407f7,0xdca021f3}},	//   äniň_, _mäkä, _योरो, _ҳафи, 
   {{0x996001c0,0xdb0003cd,0x66d801f4,0x00000000}},	//   йтэл, ktnæ, _läkä, --, 
   {{0x22980248,0xdca0013d,0xed34104e,0x19b4007b}},	//   _kàkà_, _гафи, _сэбэ, اطية_, 
   {{0xdb000232,0xeb9858d8,0xb8e40150,0x00000000}},	//   stná, _чие_, рсық, --, 
   {{0xa9680114,0x00000000,0x00000000,0x00000000}},	//   _зида_, --, --, --, 
   {{0xe970211f,0xe9d0132f,0x00000000,0x00000000}},	//   _انتھ, _دغا_, --, --, 
   {{0xf814036b,0x00000000,0x00000000,0x00000000}},	//   اسیگ, --, --, --, 
   {{0x994400c6,0x66d80139,0x00000000,0x00000000}},	//   _حلول_, _cäkä, --, --, 
   {{0x42750391,0x98a40118,0x47d400ec,0x6b680210}},	//   ргас, _okně_, _ميڪر, _lęgo, 
   {{0x161c13b4,0xc1140063,0x00000000,0x00000000}},	// [175f0] _पेपर_, амај, --, --, 
   {{0x7cfc007f,0xddd80306,0x52240107,0x6d440064}},	//   _pèrm, _neuš, ёфта, _ūkan, 
   {{0x386803e0,0x4ab407b7,0x7c2c03e0,0x00000000}},	//   _şark_, ंभाव, ğark, --, 
   {{0x2fc805b1,0x7c2c7b4e,0x7cfc067c,0xf1f40133}},	//   _dsbg_, şark, _vèrm, اکێش_, 
   {{0x66d8013d,0x00000000,0x00000000,0x00000000}},	//   _zäkä, --, --, --, 
   {{0x7cfc2508,0x6da0084c,0x4ea400c7,0x8afc0210}},	//   _tèrm, циша, арәа, _stęp, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4034014b,0x00000000,0x00000000,0x00000000}},	//   _беҳс, --, --, --, 
   {{0xb9050392,0x7e6c0784,0xdb00005c,0x0b5800c7}},	//   изик, ñapu, ytnæ, ыршы_, 
   {{0x8de8013e,0xf774001f,0xe8f4005b,0xca740352}},	//   _ёфта_, _የተገኘ_, илы_, _һушы, 
   {{0x28a41533,0xd7641e4a,0xfce401e0,0xd688010b}},	//   _खारि, دەبى_, _йоҡо, линҗ_, 
   {{0x66d8005b,0xb6a400d1,0x4a742519,0x00000000}},	//   _räkä, шимл, _лышт, --, 
   {{0x66d829ef,0xe724013e,0x88bc0118,0xd8540139}},	//   _säkä, рояд_, mněn, _өчкә_, 
   {{0x88bc012c,0xc0d000b7,0x7afc0267,0x2fc4012d}},	//   lněn, _ኦሮሞ_, östf, łogi_, 
   {{0x73341884,0x00000000,0x00000000,0x00000000}},	//   لىسا, --, --, --, 
   {{0xe294c862,0xb22448d9,0x236800bc,0xdb00383d}},	//   иас_, амбл, _žijí_, stnæ, 
   {{0xe1f4d391,0x71a408ca,0x66d8008e,0xf0a80b01}},	// [17600] агт_, разз, _wäkä, ккал_, 
   {{0x34490393,0xdb0000c5,0xb05800c6,0x307402dd}},	//   _үчүн_, ltnä, نشاط_, руас, 
   {{0xc05800d6,0x7298010a,0x73e40f06,0xbddc01ec}},	//   гії_, _ионĕ, _тонз, _ﺘﺤﻭل_, 
   {{0x88bc012c,0xdb00007c,0x00000000,0x00000000}},	//   jněn, ntnä, --, --, 
   {{0x4ea4052f,0x88bc012c,0xae14033d,0x6cc50394}},	//   арҙа, dněn, _देशन_, ийда, 
   {{0x260400ab,0xfa5c01e1,0xdc7002dd,0x2bb8007b}},	//   हनती_, _mọdẹ_, огшы, ناعة_, 
   {{0xdb0001e3,0xeb0400d8,0x00000000,0x00000000}},	//   ktnä, ичио, --, --, 
   {{0x6b680210,0x00000000,0x00000000,0x00000000}},	//   _węgo, --, --, --, 
   {{0x6c94b23e,0x0d7401b9,0x9c200166,0x5e98123b}},	//   _نشاط, _ایتک_, йдәд, _שבמק, 
   {{0xb1840589,0x61e89023,0xbb7000f7,0x00000000}},	//   _koåº, ägli, زۇۇع, --, 
   {{0x47346ea5,0xda6c00a8,0xd05c016b,0xdb00007c}},	//   йнос, _мя_, _korɑ, ftnä, 
   {{0x88bc012c,0xda6c009f,0x00000000,0x00000000}},	//   cněn, _قُم_, --, --, 
   {{0x26140807,0x04880661,0x96342081,0x2a340166}},	//   _पेशी_, ләни_, жняц, _тэжр, 
   {{0xd4990395,0x3e6c0241,0x00000000,0x00000000}},	//   ирс_, _kótó_, --, --, 
   {{0xe7850396,0x13690397,0x261402ab,0x00000000}},	//   _туло, ишти_, _पेरी_, --, 
   {{0x48f0012c,0xe1fc0208,0x00000000,0x00000000}},	//   ेसको_, _ngóc_, --, --, 
   {{0x20640640,0xae14000d,0x00000000,0x00000000}},	// [17610] ађев, _देलन_, --, --, 
   {{0x88bc00bc,0x43941429,0x81880137,0x37240116}},	//   zněn, _лаос, _ەچاق_, _پوۋې, 
   {{0x83f90398,0xa26400a7,0x00000000,0x00000000}},	//   _сенс_, _въгл, --, --, 
   {{0xf8c80241,0x00000000,0x00000000,0x00000000}},	//   _abẹ́_, --, --, --, 
   {{0x88bc012c,0x6b680034,0x7f8400f2,0x3cf42d81}},	//   vněn, _węgl, _گلزن, ्सले_, 
   {{0xfbd00597,0xc104352e,0xab78022e,0x8d7400f2}},	//   كتب_, _اوسي, _bo鼠m, زاها, 
   {{0xe9a40efb,0x7e6c0054,0x88bc012c,0xdb0001e3}},	//   ەگىن_, ñaps, tněn, ytnä, 
   {{0xdb010399,0x7cfc00cf,0x8f340276,0xaad808a3}},	//   munë, _mèri, _десц, _मोदक, 
   {{0x7cfc020c,0x88bc012c,0x3ead039a,0xabb40022}},	//   _lèri, rněn, _icet_, _ҳахә, 
   {{0x88bc012c,0xf8c80241,0x77c9039b,0x7f6001ec}},	//   sněn, _gbẹ́_, глог_, _ﺯﻭل_, 
   {{0x88bc00bc,0xdb00002f,0xfcb80092,0x00000000}},	//   mněl, ttnä, ዲንግ_, --, 
   {{0x0a180502,0x3dcc06a3,0x00000000,0x00000000}},	//   افیک_, _ksew_, --, --, 
   {{0xe8ed039c,0xdb006186,0x7cfc0137,0x00000000}},	//   _ел_, rtnä, _aèri, --, 
   {{0xdb000267,0x628806ea,0x6994009f,0x00000000}},	//   stnä, ðgon, _اَوس_, --, 
   {{0x64a046ce,0x3eac05d7,0x87c807fc,0x00000000}},	//   яара, _ocet_, _نظيف_, --, 
   {{0x7cfc00db,0xfdf80073,0x71a401d5,0x00000000}},	//   _dèri, ्नास_, йабз, --, 
   {{0x3dcc0327,0x00000000,0x00000000,0x00000000}},	// [17620] _nsew_, --, --, --, 
   {{0x3439039d,0x7cfc020c,0xd0640085,0x3ead039e}},	//   _مسجد_, _fèri, ɛsɛn, _acet_, 
   {{0x9420013f,0xdb000023,0xdd8c00e5,0x00000000}},	//   _ɛsɛn_, gunë, ہون_, --, 
   {{0xa0640588,0x3e6c0248,0x517800cf,0xdce80139}},	//   _ҳара_, _rótó_, _نەرس_, dugı, 
   {{0x7cfc007f,0x7bc40113,0xdb000129,0xc1d401af}},	//   _zèri, çhun, munè, _мөфә, 
   {{0xa065039f,0xb6040427,0xdb00036e,0x00000000}},	//   _гара_, mišč, bunë, --, 
   {{0xb6040fb7,0x3eac0108,0x00000000,0x00000000}},	//   lišč, ähtö_, --, --, 
   {{0x497503a0,0x00000000,0x00000000,0x00000000}},	//   олис, --, --, --, 
   {{0xb60409a8,0x6f001de4,0x2bc47ef5,0x88bc01ef}},	//   nišč, mkoc, लबहा, bněl, 
   {{0xdd8c0597,0xed5903a1,0x3e6c0ca8,0x88bc013a}},	//   _أول_, _соз_, _tótó_, cněl, 
   {{0xdb00020c,0x6c3400e5,0x00000000,0x00000000}},	//   kunè, _افضا, --, --, 
   {{0x6f0103a2,0xe70801b9,0x00000000,0x00000000}},	//   nkoc, اتدن_, --, --, 
   {{0x7cfd03a3,0x7afd03a4,0xb604151c,0x889435c9}},	//   _sèri, öste, jišč, _дилх, 
   {{0xb6040f72,0x94a903a5,0x7cfcf9ec,0xbebc0024}},	//   dišč, йтса_, _pèri, _pjūk, 
   {{0x249c07c4,0x290103a6,0x00000000,0x00000000}},	//   ğum_, ūkas_, --, --, 
   {{0x249c4a98,0x88bc0118,0x00000000,0x00000000}},	//   şum_, zněl, --, --, 
   {{0x36880831,0x291c049b,0x6f000030,0xbbb416d1}},	// [17630] _өсөн_, oita_, dkoc, _अङ्क, 
   {{0x831804fb,0xdb000023,0x7cfc4ceb,0x88bc0118}},	//   _چقدر_, tunë, _tèri, kněm, 
   {{0x291c05b8,0x6f0003fa,0x656c01a9,0xd9b40154}},	//   iita_, fkoc, lqch, জিএম, 
   {{0x291d03a7,0x2a640218,0x63a40810,0xb6040427}},	//   hita_, _ngob_, mujn, bišč, 
   {{0x291c18e0,0xdd9903a8,0x7cfc007f,0x00000000}},	//   kita_, уше_, _mèrv, --, 
   {{0x291d03a9,0x2a6405d5,0xdb0103aa,0xcce42374}},	//   jita_, _agob_, muné, كسىي, 
   {{0x92cc0c58,0x6f0000d0,0x256c00a2,0x63a40010}},	//   লাৰ_, bkoc, _lül_, nujn, 
   {{0x6f0001fa,0x7cfc0ba1,0x3eac1d55,0x291d03ab}},	//   ckoc, _nèrv, _ucet_, eita_, 
   {{0x291d03ac,0xae140574,0xb9080cdd,0x88bc00bc}},	//   fita_, _देऊन_, иниз_, mněj, 
   {{0x291d03ad,0x88bc012c,0x7afc01e3,0x00000000}},	//   gita_, lněj, östb, --, 
   {{0xb60409a8,0x7118011a,0x00000000,0x00000000}},	//   zišč, שותפ, --, --, 
   {{0x7cfc56eb,0x291d03ae,0x88bc00bc,0x256c25a8}},	//   _cèrv, aita_, nněj, _bül_, 
   {{0xca7400f1,0x672c00d7,0xdb200254,0x00000000}},	//   _رانغ, _žijé, örõh, --, 
   {{0xca4843f3,0xb60409a8,0x6f0103af,0x7bc002d2}},	//   _الهه_, višč, zkoc, _kplu, 
   {{0x5ac4025c,0x256c0254,0xae140073,0x9770008e}},	//   _ཁྲོམ, _eül_, _देईन_, _этлә, 
   {{0xb604151c,0x7bc00077,0xc0e00023,0x256c00e5}},	//   tišč, _mplu, _ሓበሻ_, _fül_, 
   {{0x256c0c44,0x88bc012c,0x87040046,0x6f0079eb}},	// [17640] _gül_, dněj, _ءبىل, vkoc, 
   {{0xb6040fb7,0x7bc001f5,0x63a41710,0x888c010f}},	//   rišč, _oplu, bujn, ָראַ, 
   {{0x7bc00070,0x256c0793,0x39440204,0xb60409a8}},	//   _nplu, _zül_, ills_, sišč, 
   {{0x291d03b0,0x87ac008f,0xb6040010,0xae140073}},	//   zita_, רשאַ, pišč, _देउन_, 
   {{0x6f0103b1,0x7bc011ce,0x291c3cd4,0x3074014b}},	//   rkoc, _aplu, yita_, _мувс, 
   {{0x291d03b2,0x6f0103b3,0x7bc00332,0x28ac0303}},	//   xita_, skoc, _bplu, ज्ञि, 
   {{0x88bc00bc,0x6f0001d3,0x2bd800dc,0xa5c408ce}},	//   bněj, pkoc, भिधा, _kvóð, 
   {{0x291d03b4,0x39440228,0xada422f7,0x7f7401c6}},	//   wita_, ells_, _мабл, _хурц, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xeb980c04,0x7cfd03b5,0x291cefd2,0x18b400c7}},	//   _виж_, _sèrv, uita_, огьы_, 
   {{0x291c3aad,0x395866ce,0x256c1570,0xa538001f}},	//   rita_, ïssa_, _sül_, _በሶማሊ, 
   {{0x3b0c0784,0x38680e51,0xab6002dd,0x2bac03b9}},	//   cheq_, _şart_, _تۇعى, _fəcr_, 
   {{0xdb000030,0x62f00349,0xe81808e9,0xdb0401e1}},	//   ytnú, ঘসময়_, _फेरा_, _ìláb, 
   {{0x291c8957,0x88bc00bc,0xe70801b9,0x00000000}},	//   qita_, zněj, اتگن_, --, 
   {{0x98780bd9,0xfe7801ef,0x00000000,0x00000000}},	//   _דרוק, _snům_, --, --, 
   {{0x63a408ad,0x256c0342,0x2bc0012d,0x00000000}},	//   rujn, _tül_, _शहना, --, 
   {{0x88bc0316,0x656c0113,0x00000000,0x00000000}},	// [17650] vněj, qqch, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69c001e4,0x88bc00bc,0x63a4014f,0xdb0000d7}},	//   _lpoe, tněj, qujn, rtnú, 
   {{0xdb001060,0x00000000,0x00000000,0x00000000}},	//   puné, --, --, --, 
   {{0x237c098d,0x88bc012c,0x3944007c,0x69c807f7}},	//   ćuju_, rněj, ylls_, _तैली, 
   {{0x88bc012c,0xbcfc00b8,0xa2a000cd,0x00000000}},	//   sněj, _kuũi, गलक्, --, 
   {{0x69c103b6,0xcfb40801,0x5ac4031c,0xe818012c}},	//   _apoe, _обръ, _ཁྲུམ, _फेला_, 
   {{0xb60402fb,0x7bc00010,0x4cc800eb,0x00000000}},	//   _hráš, _vplu, লাগু, --, 
   {{0x7cfc004e,0x3b0c0023,0xb60401ef,0xaa4001a9}},	//   _sèru, rheq_, _kráš, неъл, 
   {{0x7cfd03b7,0xdd900220,0x8d7404da,0x23c808f2}},	//   _cèrt, _нағы, _زاكا, ाबाद, 
   {{0xefbc02d3,0x7bc00098,0xf744041b,0xdb00072b}},	//   _ተባዕ_, _uplu, зено, ktnø, 
   {{0xdb2103b8,0x7c2c1934,0x00000000,0x00000000}},	//   _توصی, şars, --, --, 
   {{0xe7b0036b,0x7cfc00db,0x6d4402b1,0x00000000}},	//   ومید, _fèrt, _ūkai, --, 
   {{0x7af903b9,0xc984361e,0xb794009b,0x00000000}},	//   _howt, _цуци, _ерић, --, 
   {{0x7af903ba,0x00000000,0x00000000,0x00000000}},	//   _kowt, --, --, --, 
   {{0xe3603849,0xfe649105,0xe734010b,0xa2a0095f}},	//   екси, _لگ_, _нещ_, गलग्, 
   {{0xe64c054e,0xb604013a,0x659000d8,0xac340023}},	// [17660] ăgăş, _bráš, _зању, _ኣዳዕዲ, 
   {{0x7af8a287,0x7e6903bb,0x7cfc007f,0x6b68033f}},	//   _lowt, _agep, _mèrs, _węgi, 
   {{0xaec41fd4,0xa0640395,0x00180006,0x00000000}},	//   збел, чаха_, оўцы_, --, 
   {{0x7af85b4f,0xa0302374,0xdef400cf,0xabb00022}},	//   _nowt, رىنت, зыш_, ҵакә, 
   {{0xccf81621,0xae1413f5,0x0cd42f59,0x00000000}},	//   оқа_, _देखन_, долю, --, 
   {{0x7e680b58,0xd05c016b,0xe80c012c,0x00000000}},	//   _egep, _borɔ, ानमा_, --, 
   {{0x69c01a7c,0x7af903bc,0xaff8106b,0x7e6c00e2}},	//   _spoe, _bowt, _افزا_, žapa, 
   {{0x7cfc020c,0x7af8039a,0x38980092,0x00000000}},	//   _bèrs, _cowt, _መሠረቱ_, --, 
   {{0x7cfc56ec,0x7afd03bd,0xbebc0153,0xfb1800e5}},	//   _pèrt, östa, _pjūv, تروں_, 
   {{0x290903be,0xfbcc05d9,0xd91401f4,0x00000000}},	//   óba_, _چڪي_, зью_, --, 
   {{0x7af80327,0x7cfc3efc,0xfbcc0451,0x6c48007b}},	//   _fowt, _vèrt, _نڪي_, _الاف_, 
   {{0xa610008e,0x00000000,0x00000000,0x00000000}},	//   езмә, --, --, --, 
   {{0xbcfc0055,0x00000000,0x00000000,0x00000000}},	//   _suũi, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x58b80302,0x54540f5c,0xb63001d3,0x00000000}},	//   _המוצ, еврт, فکیش, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x26c903bf,0xb6040122,0xd2340801,0x00000000}},	// [17670] meco_, _práš, ентъ, --, 
   {{0x26c800c8,0x7e680142,0x00000000,0x00000000}},	//   leco_, _sgep, --, --, 
   {{0x200503c0,0xd25000d1,0x92bc00cc,0xc35400f3}},	//   áni_, پنە_, _আফৰ_, _окој, 
   {{0x26c903c1,0x200c033f,0x2004003d,0x00000000}},	//   neco_, ągi_, ġni_, --, 
   {{0x2004341a,0x7af80493,0x628d03c2,0x6cf85325}},	//   šni_, _rowt, _ieco, ्संग_, 
   {{0x26c903c3,0x7af903c4,0x628c0042,0x00000000}},	//   heco_, _sowt, _heco, --, 
   {{0x628c60e7,0xb8740084,0x26c8008f,0x7af80034}},	//   _keco, nḓe, keco_, _powt, 
   {{0x7e6903c5,0x7cfd03c6,0x3f8103c7,0x26c903c8}},	//   _ugep, _pèrs, mphu_, jeco_, 
   {{0x26c903c9,0xbb440e2c,0x59600116,0x8f3402e8}},	//   deco_, ﻘﺘﻰ_, нниғ, _четц, 
   {{0x628d03ca,0xdb0103cb,0x7cfc034c,0x798c0327}},	//   _leco, muní, _vèrs, _ħawd, 
   {{0xb6a4301f,0x628d03cc,0x26c903cd,0x7cfc180f}},	//   минл, _oeco, feco_, _fèrr, 
   {{0x628d03ce,0xba54cf9e,0x7cfc020c,0x26c800df}},	//   _neco, _قناع, _tèrs, geco_, 
   {{0xe6140212,0xbebc0171,0x00000000,0x00000000}},	//   ддя_, _hjūs, --, --, 
   {{0x628c004e,0x7d0c0200,0x00000000,0x00000000}},	//   _aeco, ëash, --, --, 
   {{0x628ccc9d,0x26c903cf,0x2900016b,0xddd800e2}},	//   _beco, beco_, ɔka_, _uguņ, 
   {{0x628d03d0,0x7cfc0ba1,0xdb000113,0x26c903d1}},	//   _ceco, _mèrq, kuní, ceco_, 
   {{0x628c3af1,0x232400c2,0x74f858e5,0x00000000}},	// [17680] _deco, фоти_, _дэнс_, --, 
   {{0xa520152d,0xa11000f7,0xc0a800c6,0x26140141}},	//   _амьд, نوقت, كامل_, _पेटी_, 
   {{0x628d03d2,0xef1801c0,0x9c1001e1,0x00000000}},	//   _feco, омж_, _mọsk, --, 
   {{0x6da503d3,0xe80c0cb4,0x628c0cf9,0x3ebc0369}},	//   дида, ानता_, _geco, gfwt_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7cfc0ba1,0x7afc369a,0x26c8010f,0x998c00c0}},	//   _sèrr, östn, zeco_, _lygų_, 
   {{0x7cfc067c,0x628cf3bc,0xbebc0064,0x6140026b}},	//   _cèrq, _yeco, _pjūt, _рера, 
   {{0xdee103d4,0x26c8004e,0xee38009d,0xdd1400d7}},	//   _иоси, xeco_, _днб_, väťs, 
   {{0x26c903d5,0xbebc0006,0x9b4000f1,0x00000000}},	//   veco_, _smūg, خنيو, --, 
   {{0x26c87dec,0x9ba8003a,0x88bc01ef,0x00000000}},	//   weco_, ĭārē, hněv, --, 
   {{0x26c804ac,0x7c6503d6,0x7cfc2508,0x4bc400db}},	//   teco_, _كامل, _tèrr, _чөлг, 
   {{0xa968016c,0x951c0327,0x00000000,0x00000000}},	//   _дида_, ྴིའི_, --, --, 
   {{0x26c903d7,0xdb000030,0x386002f0,0x6d4800ae}},	//   reco_, ntný, _úhrn_, olfa, 
   {{0x628d03d8,0x26c903d9,0xfa5c0248,0x4dc800cc}},	//   _seco, seco_, _mọlẹ_, লিপূ, 
   {{0x628d03da,0x26c800df,0x6d4803ac,0x00000000}},	//   _peco, peco_, ilfa, --, 
   {{0xe66503db,0x80c03507,0x6d480e78,0x628c00d8}},	//   _отпо, र्ने, hlfa, _qeco, 
   {{0x41540114,0xc0c40166,0x00000000,0x00000000}},	// [17690] евас, нәви, --, --, 
   {{0x628c6f46,0x6b9803ac,0x00000000,0x00000000}},	//   _weco, _ovtg, --, --, 
   {{0x73c000fb,0xaaac134e,0x00000000,0x00000000}},	//   _йәте, _टांक, --, --, 
   {{0xe0cc015b,0x628c003a,0x6d4903dc,0xbebc0171}},	//   রাইভ, _ueco, elfa, _ajūr, 
   {{0x290c0219,0x527400d8,0x46c01223,0x00000000}},	//   _olfa_, _шуќу, ष्यह, --, 
   {{0x787000dd,0x6d4805ac,0x4d6400d4,0x00000000}},	//   _művé, glfa, вків, --, 
   {{0xbb4447db,0x7afc01e3,0x53d8134e,0x00000000}},	//   некк, östo, डिएश, --, 
   {{0x6d480c8c,0x1ee4182f,0x4ea40024,0x00000000}},	//   alfa, _توری_, _арфа, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb0000ae,0x00000000,0x00000000,0x00000000}},	//   irné, --, --, --, 
   {{0x80c000dc,0x00000000,0x00000000,0x00000000}},	//   र्ये, --, --, --, 
   {{0x35a4c78c,0x290c34c5,0x00000000,0x00000000}},	//   намг, _elfa_, --, --, 
   {{0xdb00054e,0x00000000,0x00000000,0x00000000}},	//   punâ, --, --, --, 
   {{0x80c029ea,0x49b814a0,0xe8180406,0x00000000}},	//   र्मे, _زاهد_, _फेका_, --, 
   {{0xddd8c593,0x37e503dd,0x00000000,0x00000000}},	//   _neuž, _чойг, --, --, 
   {{0xdb0002fb,0xd5e406dc,0x6d480010,0xe61c0142}},	//   ytný, _айиқ, zlfa, mbôn_, 
   {{0x290c032e,0x63a800cd,0x00000000,0x00000000}},	// [176a0] _ylfa_, _āgne, --, --, 
   {{0x46c0038e,0x61e801e3,0xe0d4005a,0x00000000}},	//   ष्ठह, ågla, нву_, --, 
   {{0x24b4008f,0xa4b40375,0xe12001e0,0x270000fe}},	//   _אהין_, _אליה_, ымфи, _লগতো_, 
   {{0x8fd40184,0x7cfc0ba1,0x63b8054e,0x7afc3b52}},	//   нәғә, _sèrp, ăunt, östl, 
   {{0xdb0007de,0xca2401ec,0xfd7801d3,0xa2e01171}},	//   dunà, _ﹼﻬﺎ_, وشوں_, _сояд, 
   {{0xdb0103de,0x3d1801ed,0x65980a1e,0xb4cc00cd}},	//   rtný, وٹنگ_, לינק, _रसो_, 
   {{0xdb004be9,0xceb80166,0x5ba01f39,0xd71000bc}},	//   stný, _жәл_, грыз, ासाथ_, 
   {{0xa064eb89,0xa6d808a7,0x88bc00bc,0x00000000}},	//   _часа_, koða, hnět, --, 
   {{0xb538110e,0x88bc012c,0x0d640124,0x1ec40354}},	//   _atọ́, knět, _анаҟ, _ялти_, 
   {{0x92cc00bd,0x7b1404d4,0x00000000,0x00000000}},	//   লায়_, _náuf, --, --, 
   {{0x98c03c24,0x88bc00bc,0xeb9806ed,0x00000000}},	//   усыл, dnět, _ѕид_, --, 
   {{0x7800013e,0x98e000db,0x57a00124,0x97a04990}},	//   рӯша, _ەكوو, ышьа, ырьл, 
   {{0xa258019f,0x9928004b,0x80c00562,0x7bcc0210}},	//   _abôn, _کتنې_, र्डे, łaut, 
   {{0x290cbad2,0xdb000122,0x58d00137,0x63b00124}},	//   _ulfa_, muná, _бошт, лагӡ, 
   {{0xdce8025c,0x00000000,0x00000000,0x00000000}},	//   ssgħ, --, --, --, 
   {{0xa6d80436,0xefd0001f,0x48e8012c,0x00000000}},	//   boða, _የሐዋ_, जाको_, --, 
   {{0xa0a503df,0x657c0309,0xaac01a3e,0xdb000129}},	// [176b0] ешел, _utqh, व्यक, urné, 
   {{0xd05c01e4,0x75d40220,0xdb0803b2,0xf12400c7}},	//   _korɨ, _شيپا, ðiút, ҕьӡо, 
   {{0xd250021a,0x26d80286,0xb8740084,0x2308bd5e}},	//   لنې_, _kaqo_, nḓa, _فتحي_, 
   {{0x3168005a,0xd05c01e4,0x00000000,0x00000000}},	//   _eibz_, _morɨ, --, --, 
   {{0x26d903e0,0x4ea4b3de,0x7afc0267,0x00000000}},	//   _maqo_, урха, östm, --, 
   {{0x26d8011f,0xe1fc004d,0xaaac012c,0x7f84007b}},	//   _laqo_, _ngói_, _टाउक, _للسن, 
   {{0x7f9414a8,0xf0800133,0xb6041155,0x4fc419c5}},	//   _шавх, _ئیمپ, _kráá, _مەلە, 
   {{0x2bc00574,0x7a6801c0,0x26d80009,0xb4cc0037}},	//   _शहरा, мийг_, _naqo_, _रस्_, 
   {{0x80c000dc,0x2a7801e1,0x00000000,0x00000000}},	//   र्थे, _ńgbò_, --, --, 
   {{0x8afc003a,0x37740166,0x37e4009d,0x00000000}},	//   _quęr, кымс, воог, --, 
   {{0xabb40022,0x26d8350e,0x1be8000d,0x00000000}},	//   _аахә, _baqo_, _झपटल_, --, 
   {{0x1880010b,0x6b68033f,0x80c0012a,0xdb0002f0}},	//   _өңин, _węgr, र्ते, buná, 
   {{0x26d8047e,0x7e6c00c7,0x9fac013d,0x00000000}},	//   _daqo_, ñapy, lğät_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x671c1025,0x91b80154,0x82300092,0x00000000}},	//   मोहक_, ুয়াখ, _በመረዳ, --, 
   {{0x26d82937,0x88bc0118,0x00000000,0x00000000}},	//   _gaqo_, snět, --, --, 
   {{0xe360ac00,0x4918012c,0x88bc00bc,0x716801c6}},	// [176c0] ркти, योको_, pnět, дааг_, 
   {{0x22480522,0x7afc007c,0x00000000,0x00000000}},	//   _dyck_, östj, --, --, 
   {{0xf9f800bd,0xaf3503e1,0x224903e2,0x00000000}},	//   েছিল_, پرات, _eyck_, --, 
   {{0xdee04881,0xa8540375,0x00000000,0x00000000}},	//   иохи, דיעה_, --, --, 
   {{0xdd8c8fe3,0x9db503e3,0xdb0003cb,0x00000000}},	//   قون_, ندوز_, ernï, --, 
   {{0x80c01428,0xa2580109,0x30740b3e,0xaad80073}},	//   र्दे, _mbôl, _шумс, _मोजक, 
   {{0xa0640124,0x798c0327,0x333000d7,0x00000000}},	//   _аара_, _ħawa, onyx_, --, 
   {{0x49d80108,0x00000000,0x00000000,0x00000000}},	//   едию_, --, --, --, 
   {{0x26d801a9,0x0cb41f0d,0x00000000,0x00000000}},	//   _raqo_, _مجاھ, --, --, 
   {{0x2d84017a,0x7d0c002d,0xdb000306,0x00000000}},	//   mpoe_, ëast, runá, --, 
   {{0x6d583923,0x26d80784,0xa85002d9,0xd7f40108}},	//   _ihta, _paqo_, ренә, вуя_, 
   {{0x7e6c0054,0xc84c001f,0x00000000,0x00000000}},	//   ñapx, _ማዕከላ, --, --, 
   {{0x26d80481,0xe8f89100,0x2d8400d5,0xb7c402dd}},	//   _vaqo_, _олд_, npoe_, _ұрық, 
   {{0x88940139,0x224801e3,0x00000000,0x00000000}},	//   _сикх, _ryck_, --, --, 
   {{0x18a016a4,0x98a00063,0x636882e5,0x3dc80135}},	//   _тајм, _тије, драг_, ħawi_, 
   {{0x45d402f4,0x7b14003a,0x53340063,0x82300092}},	//   _боис, _gáud, аест, _በመርዳ, 
   {{0x2fc80083,0x6d5903e4,0x5ed80154,0x00000000}},	// [176d0] _apbg_, _ohta, ণামে, --, 
   {{0x40940c78,0x00000000,0x00000000,0x00000000}},	//   الار, --, --, --, 
   {{0xd26000e2,0x914903e5,0x3958067c,0x7afc0267}},	//   ļņas_, тчта_, ïssi_, östk, 
   {{0x6d5903e6,0x3b84036b,0x224801e6,0xafe4003b}},	//   _ahta, қлиг, _tyck_, _sjøø, 
   {{0x6d5801ab,0x3cc8be9c,0x92680124,0xdde80ccb}},	//   _bhta, елло_, _арра_, براه_, 
   {{0x6aa002d0,0x6d5801e7,0x00000000,0x00000000}},	//   _adof, _chta, --, --, 
   {{0xdb0000ee,0x0c64001f,0xdcf816a3,0x8b9402d5}},	//   nunç, _ሲናገሩ_, _utuč, арыч, 
   {{0x6d5839ed,0x00000000,0x00000000,0x00000000}},	//   _ehta, --, --, --, 
   {{0x6d5903e7,0x7f48013c,0x6aa0015d,0x00000000}},	//   _fhta, _ikeq, _ddof, --, 
   {{0x5ba4022e,0x00000000,0x00000000,0x00000000}},	//   _ардз, --, --, --, 
   {{0x25a8009a,0x9c4400c7,0x00000000,0x00000000}},	//   ercl_, _рхал, --, --, 
   {{0xa3e410f7,0x4a7503e8,0xca740724,0x7d0024b6}},	//   पिन_, _кышт, _кушы, _hols, 
   {{0x7d005b32,0x6d5801f4,0x3b0c0200,0x5bd00118}},	//   _kols, _yhta, mkeq_, _दनुव, 
   {{0x588503e9,0x7d00a280,0xdb00f874,0x01b800cc}},	//   _рыда, _jols, funç, ঁবাদ, 
   {{0x7d0103ea,0x394404c4,0xdb000120,0x15b40131}},	//   _mols, mols_, gunç, _ھەسس, 
   {{0x7d0103eb,0x80c00bc0,0x2d84017a,0x00000000}},	//   _lols, र्से, ypoe_, --, 
   {{0x7d000c8c,0x91240588,0x200406ea,0x00000000}},	// [176e0] _ools, апаҵ, ønin_, --, 
   {{0x7f480eda,0x7d0006ea,0xdb0103ec,0x7038022e}},	//   _akeq, _nols, bunç, нчес_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d5903ed,0xee3903ee,0x7d000334,0x394503ef}},	//   _shta, нне_, _aols, hols_, 
   {{0x7d003cce,0x6d580129,0x272c005b,0x00000000}},	//   _bols, _phta, lönä_, --, 
   {{0x7d0007d5,0x7f48014b,0x394400db,0x27280100}},	//   _cols, _ekeq, jols_, _kònè_, 
   {{0x394503f0,0x2d84d19d,0xbebc00de,0xdb0026bb}},	//   dols_, spoe_, _imūn, kunä, 
   {{0x3b0c0175,0x5bb401c6,0x6020009d,0x00000000}},	//   gkeq_, улъя_, _удса, --, 
   {{0x7d00334b,0x80c007b7,0x88d800fe,0x394400db}},	//   _fols, र्वे, তাসক, fols_, 
   {{0x39442549,0xe78408ca,0x2004002f,0x272c01f4}},	//   gols_, лумо, änig_, könä_, 
   {{0x473503f1,0x6abc04c5,0x132402d3,0xb0c417c6}},	//   инос, ্যবো, _ተገንዚ, र्यग, 
   {{0x7d000175,0xdb000254,0x6a64022e,0x00000000}},	//   _zols, gunä, vаff, --, 
   {{0x394503f2,0x160c05d7,0x7d001432,0xca4000d1}},	//   bols_, हनगर_, _yols, ﯞﺍﺏ_, 
   {{0x394503f3,0x27280100,0x7d00022e,0x5a3028f6}},	//   cols_, _bònè_, _xols, _уніт, 
   {{0xd7ec152d,0xd498e2cc,0xed8802d3,0x55580276}},	//   _уу_, ыря_, ሕብባር_, уаря_, 
   {{0xbebc00b8,0xb86402f2,0xdb000205,0x3854011c}},	//   _amūn, _ئاهو, runç, _тъчс, 
   {{0xdb000120,0x8fe40032,0x7afc1b99,0x45d503f4}},	// [176f0] sunç, ҙәрҙ, östi, _топс, 
   {{0x926903f5,0x00000000,0x00000000,0x00000000}},	//   урса_, --, --, --, 
   {{0x7d002a28,0x5184039b,0xd1380d99,0xe46801b9}},	//   _rols, _ҳуса, ухт_, _яшил_, 
   {{0x7db400e5,0x00000000,0x00000000,0x00000000}},	//   لصتا, --, --, --, 
   {{0x7d0003f8,0x5184f5b3,0xd25800c0,0x00000000}},	//   _pols, _гуса, _бцр_, --, 
   {{0xfc0503f6,0x7d0103f7,0x7b20004a,0x394400db}},	//   ипло, _qols, nœuv, xols_, 
   {{0x7d0103f8,0x394503f9,0x6bd400e5,0x3b0c036e}},	//   _vols, vols_, لووس_, tkeq_, 
   {{0x7d00334b,0x7bc40309,0x3dcc03d4,0xdb00000d}},	//   _wols, çhuq, লিবল, htnö, 
   {{0x394419c6,0xf8d40116,0xa3e407af,0xdb0001f4}},	//   tols_, иңдә_, पिड_, vunä, 
   {{0x7d0005b1,0x3b0c0194,0x63740521,0x272c005b}},	//   _uols, skeq_, ụnye, yönä_, 
   {{0x7b1503fa,0x394503fb,0xdb001b99,0x00000000}},	//   _cáuc, rols_, tunä, --, 
   {{0xf74503fc,0x394503fd,0xe7b45b82,0x28c80150}},	//   ремо, sols_, _अमरप, _ﺒﻤﺼﻠ, 
   {{0x394503fe,0xdb000254,0x00000000,0x00000000}},	//   pols_, runä, --, --, 
   {{0x2ed035e8,0x798804ba,0x272c0108,0xdb000254}},	//   _सस्त, mpew, tönä_, sunä, 
   {{0xdb0000c5,0x00000000,0x00000000,0x00000000}},	//   punä, --, --, --, 
   {{0xf5e80116,0x27e800b5,0x798801c8,0xc79400c7}},	//   _амил_, æbne_, opew, _уршы, 
   {{0x312503ff,0xf8d80490,0x153805af,0x88d800eb}},	// [17700] адаг, _बघाय, _مزدک_, তারক, 
   {{0x79880083,0x1cac0327,0x386800a2,0x970400d1}},	//   ipew, ནཔས_, _şary_, _ئېڭى, 
   {{0xd174e17f,0x33d40046,0xe69001ec,0xe040010a}},	//   рығы, _тіпт, _الۋد, онфи, 
   {{0x6398011a,0xff740023,0xbf6403c7,0x00000000}},	//   _בסטנ, _ብኣዝዩ_, مدنو, --, 
   {{0x80c006ab,0x398800d8,0x79880210,0x00000000}},	//   _रॉके, _nºs_, jpew, --, 
   {{0x61e800b5,0xa8040139,0x5ec400eb,0x00000000}},	//   ægle, _yañı, _রোদে, --, 
   {{0x7bc40113,0x1d040114,0x3eb00022,0xb0c407b7}},	//   çhup, реји_, ñotÿ_, र्णग, 
   {{0xa3e419e5,0x15f80d2b,0x099400c7,0x5fd800d9}},	//   पित_, ुहार_, баиџ, _בחלק, 
   {{0x99948dc7,0x798c010e,0x1e80011c,0x00000000}},	//   акыт_, _çawl, _флум, --, 
   {{0x7b140113,0xac080139,0x00000000,0x00000000}},	//   _páuc, _инза_, --, --, 
   {{0xeb98084c,0x00000000,0x00000000,0x00000000}},	//   _рие_, --, --, --, 
   {{0xb0c50400,0x6b80063f,0x6b8817da,0xea8801c8}},	//   र्तग, _ọgwa, mpfg, _شخصن_, 
   {{0x95d812e7,0xab640171,0x00000000,0x00000000}},	//   адят_, _vaļī, --, --, 
   {{0xbebc00b8,0x7afc0267,0x998002f2,0x94a889b6}},	//   _amūl, östv, _بلوو, итса_, 
   {{0x97d4a44e,0x97a00124,0x00000000,0x00000000}},	//   _نظير_, _дрыл, --, --, 
   {{0x42747314,0x7cfc007f,0x1cac031c,0x2bac000d}},	//   сгас, _dèry, ནཔོ_, _टिना, 
   {{0xc0e8001f,0xe80c012c,0x00000000,0x00000000}},	// [17710] _መሀል_, ानका_, --, --, 
   {{0xe4a40cb6,0xa8040166,0xd498030d,0x75d4009f}},	//   _трио, _tañı, _крю_, _ايٿا, 
   {{0x20050401,0x7cfc02e2,0x39480077,0x3dcc0076}},	//   âni_, _gèry, _íase_, _spew_, 
   {{0xbea800ec,0x798802d0,0x680803e3,0x00000000}},	//   اهشن_, ypew, mədd, --, 
   {{0xc0c40022,0x3d180248,0x68080213,0x00000000}},	//   _гәеи, _lèwe_, lədd, --, 
   {{0x212401d5,0x00000000,0x00000000,0x00000000}},	//   _ئيسی_, --, --, --, 
   {{0x9f68322f,0x68080213,0x00000000,0x00000000}},	//   _араз_, nədd, --, --, 
   {{0xd438011a,0xdb200244,0x00000000,0x00000000}},	//   יטוי_, توبی, --, --, 
   {{0x68080213,0x00000000,0x00000000,0x00000000}},	//   hədd, --, --, --, 
   {{0x795c020c,0xca5401c6,0x9c44074d,0xf7740092}},	//   kèwe, өхөө, _кхел, _ከተገኘ_, 
   {{0xd7080058,0x4c142f84,0x3828233a,0xdb000332}},	//   لىدۇ_, _وبمس, ужно_, arná, 
   {{0x79887efe,0x3d1801e1,0x680803b9,0x00000000}},	//   ppew, _dèwe_, dədd, --, 
   {{0xf7700272,0x7afcc7e3,0xf98416df,0x00000000}},	//   _کات_, östu, _угло, --, 
   {{0xdb000254,0xb424007b,0xd87402f2,0x00000000}},	//   rtnõ, معزو, _ئاشب, --, 
   {{0xd7f80aa5,0xbebc0055,0xa504241e,0x73341183}},	//   _шуд_, _amūm, щера_, مىسا, 
   {{0x23241086,0x00000000,0x00000000,0x00000000}},	//   боси_, --, --, --, 
   {{0xe57400c7,0xe714011a,0xdb0002d2,0x00000000}},	// [17720] _лзы_, _לחקר_, funú, --, 
   {{0x7cfc007f,0x74b818cd,0x680803b9,0xd36c01ec}},	//   _tèry, _суис_, bədd, _ﺳﯟﯨﻖ_, 
   {{0xee8402d5,0xe7e8228d,0x6b5c002e,0x680803b9}},	//   было, टिया_, lëge, cədd, 
   {{0xdfcc5dda,0x9e840023,0x8eb4215c,0x00000000}},	//   عين_, _ዝበልና_, تەرت, --, 
   {{0xc0e8001f,0x24d80154,0x8f8401ec,0xc32c6c68}},	//   _መቀሌ_, দারহ, сқұл, _شەك_, 
   {{0x649c010e,0xdb0002f0,0xe7e800bc,0x00000000}},	//   _içiñ, vrná, टिमा_, --, 
   {{0xeb4802e8,0x8af803c5,0x00000000,0x00000000}},	//   лчик_, инкс_, --, --, 
   {{0xa0340375,0x8ac801d5,0xa6d80162,0x00000000}},	//   _האלה_, рқда_, roðk, --, 
   {{0xee382c75,0xaae44d66,0xed58005a,0x00000000}},	//   _сна_, لسکو, _боа_, --, 
   {{0xe29c02d2,0xa6d803b2,0x00000000,0x00000000}},	//   _moða_, moði, --, --, 
   {{0x6d490402,0x8858084c,0xd7845b74,0x00000000}},	//   mofa, ринс_, ینیو_, --, 
   {{0x6d490403,0xab640d5c,0xa3e400e1,0x20540302}},	//   lofa, _увел, पिस_, מייל_, 
   {{0x636c01e1,0x96340153,0x69b001f9,0x00000000}},	//   _lònì, зняц, _आमटी, --, 
   {{0x6d481cbd,0x00000000,0x00000000,0x00000000}},	//   nofa, --, --, --, 
   {{0x938809fe,0xa7850404,0xe78400db,0xf1d001ec}},	//   йста_, _اشتو, _ууло, _ﺟﻴﻨﺘ, 
   {{0x6d490405,0xe29c08a7,0xadf85d9c,0xe8b000cf}},	//   hofa, _boða_, ्हान_, _بەگج, 
   {{0x3f840327,0xe5c841e5,0xb4380092,0xdbfc01ef}},	// [17730] _ħluq_, _сыйл_, ተላለፉ, _mňág, 
   {{0x29c005a4,0x672c068f,0x660c7f9d,0x6d4801a6}},	//   iða_, licj, myck, jofa, 
   {{0x660c04f3,0x6d48036b,0x680800ac,0xafc001e0}},	//   lyck, dofa, qədd, мәтй, 
   {{0xb6580ca8,0x636c01e1,0x672c033f,0xdb0000d0}},	//   _abẹ́, _dònì, nicj, sunú, 
   {{0x6d490406,0x629c3e4c,0xefcc02d3,0xa6e0015b}},	//   fofa, maqo, _ኣደይ_, যাপট, 
   {{0x6d48b123,0x9ce401ed,0x629c1180,0x00000000}},	//   gofa, صوبے_, laqo, --, 
   {{0xfd5801e1,0xe05405af,0x00000000,0x00000000}},	//   _kubẹ, _ایات_, --, --, 
   {{0x3eb8fb11,0x6d480618,0xa6d805f7,0x6d4403b2}},	//   _øst_, aofa, boði, _íkan, 
   {{0x6d490407,0x29c001a8,0xb0c406ff,0xa78c0092}},	//   bofa, gða_, र्वग, _የተጻፈ_, 
   {{0xdd901ac1,0x660c012c,0x6d490408,0x60d402d0}},	//   _мағы, dyck, cofa, nexm, 
   {{0x672c48ba,0xb8740084,0x629d0409,0xad440137}},	//   ficj, nḓi, kaqo, _بىلۉ, 
   {{0x366848bd,0x6b5c0036,0xe73400d4,0x34b0012d}},	//   иано_, tëge, жею_, जल्द, 
   {{0x629d040a,0xc5f40220,0x00000000,0x00000000}},	//   daqo, зғы_, --, --, 
   {{0x47c42b1b,0x0a687d60,0xe29c02d2,0x2a38010f}},	//   ষিজী, _урхи_, _roða_, _דענמ, 
   {{0x60d5040b,0x629c0240,0x672d040c,0xf1a80133}},	//   dexm, faqo, bicj, ڤاره_, 
   {{0x6d483b54,0x629c0944,0x8c48013d,0x00000000}},	//   zofa, gaqo, leşä, --, 
   {{0x6d49040d,0x00000000,0x00000000,0x00000000}},	// [17740] yofa, --, --, --, 
   {{0x5654021a,0xe29c0008,0xeb140243,0x6d4801a9}},	//   _ورکړ, _voða_, _तत्त_, xofa, 
   {{0x60c00699,0x629d040e,0x2460a8d8,0x6d49040f}},	//   ònma, baqo, rémé_, vofa, 
   {{0x29c0022c,0xdfcc3226,0xb2b80139,0x00000000}},	//   yða_, ضيه_, _өлүф_, --, 
   {{0xd13000f7,0xde000022,0x8c480139,0x00000000}},	//   _كۅر_, мпци, keşä, --, 
   {{0xa6d803b2,0x672c0200,0x00000000,0x00000000}},	//   roði, zicj, --, --, 
   {{0xa4f8010f,0x660c012d,0x00000000,0x00000000}},	//   ילסט, zyck, --, --, 
   {{0x6d490410,0x8af80276,0x00000000,0x00000000}},	//   sofa, снис_, --, --, 
   {{0x6d490411,0x80c00807,0x2cbc0208,0x6cd4007b}},	//   pofa, र्के, _tctd_, _وقرا, 
   {{0x29c10412,0xdd8c7735,0xed590413,0x6f00000f}},	//   rða_, _شوم_, _тоз_, ljoc, 
   {{0x629c1cdf,0x9f40032e,0x00000000,0x00000000}},	//   yaqo, _hrjá_, --, --, 
   {{0x660d0414,0x3f84004a,0x00000000,0x00000000}},	//   tyck, _élue_, --, --, 
   {{0x6e210415,0x28c0878d,0x00000000,0x00000000}},	//   nzob, _शापि, --, --, 
   {{0x660c049f,0x6f010416,0x629c379d,0x6e210417}},	//   ryck, hjoc, waqo, izob, 
   {{0x629d0418,0x9c800122,0x8a700133,0xdb000174}},	//   taqo, _účes, _تێکچ, tunø, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd1b80e76,0x629d0419,0x2ee40142,0x4614cdcc}},	// [17750] قالا_, raqo, ddof_, _رودر, 
   {{0x629d041a,0x6e21041b,0xb6180150,0x48b800fe}},	//   saqo, dzob, _ﹼﺠ_, _অসুৰ, 
   {{0x80c01d03,0x6f00045f,0x60d40332,0x00000000}},	//   र्गे, fjoc, rexm, --, 
   {{0x5ac4031c,0x00000000,0x00000000,0x00000000}},	//   _གཡེམ, --, --, --, 
   {{0x291c7f0b,0x8d85041c,0xb96001e1,0x9758011a}},	//   khta_, وشون, _ììgb, קידו_, 
   {{0x9cc9041d,0x2ee4014a,0x80c00316,0x61ec0857}},	//   рыда_, adof_, र्खे, _ircl, 
   {{0x61ec0998,0x6f0000d8,0x291d041e,0x80e000cc}},	//   _hrcl, bjoc, dhta_, নাদ্, 
   {{0x6f601d00,0x9f4002d2,0x00000000,0x00000000}},	//   _كۇلم, _frjá_, --, --, 
   {{0xa258025a,0x9e2000db,0xe594013d,0x29800150}},	//   _gbôt, _تۉشو, _oçış, еңім, 
   {{0x8d741473,0x291c047e,0x6ef001a9,0x0dc80798}},	//   _قالا, ghta_, lаbа, _ќути_, 
   {{0x7c5838eb,0xd90c01ed,0x3f8002d1,0x3a741952}},	//   _الار_, ٹیں_, nqhu_, _елер, 
   {{0xa6d80008,0xe594013d,0x61ec0042,0xdb58004e}},	//   koðu, _açış, _orcl, _тюз_, 
   {{0xe9cd041f,0x291c1552,0xf98808e8,0x61ec01f5}},	//   _як_, bhta_, _انتي_, _nrcl, 
   {{0x291cb231,0x81c000bd,0x88c40150,0x00000000}},	//   chta_, ংবা_, _قتىل, --, 
   {{0x61ed0420,0x6e20022e,0x00000000,0x00000000}},	//   _arcl, zzob, --, --, 
   {{0xd764130e,0xe858009f,0x00000000,0x00000000}},	//   _تنبی, _اسهڻ_, --, --, 
   {{0x28c0534e,0xa110249f,0xe29401c0,0xefb01079}},	// [17760] _शामि, کولت, яат_, کیزگ, 
   {{0xa7c40133,0x24e4010a,0x680806be,0x00000000}},	//   _بژیم_, _емьи_, ləda, --, 
   {{0xee845aa7,0x6f010421,0xa5b80599,0xefc813d6}},	//   пыло, tjoc, nzón, слел_, 
   {{0x78a10422,0xa6d80ad9,0xddd801a6,0x6f0004cc}},	//   halv, boðu, _sfuš, ujoc, 
   {{0x6f00428b,0x5ea010ef,0xed581ee3,0x78a10423}},	//   rjoc, رمول, бод_, kalv, 
   {{0x6f000225,0x3ce40561,0xb11800db,0x5cc002e8}},	//   sjoc, _calv_, _اقسا_, есъз, 
   {{0xe7b400bd,0x78a10424,0x3ce40489,0x6e2001ed}},	//   _জন্য, dalv, _dalv_, szob, 
   {{0xdee10425,0xa03800c8,0x77740113,0x7afc01e3}},	//   _поси, _העלפ, _niyx, östp, 
   {{0xc95400b8,0x291c0023,0x78a031b7,0x6c7400ae}},	//   _apīṣ, thta_, falv, _فطائ, 
   {{0x78a047c0,0x3ce40489,0x4814d150,0xebe4014b}},	//   galv, _galv_, дмос, _нозп, 
   {{0xab2800f0,0x80c00807,0xdb000432,0x00000000}},	//   _ложа_, र्टे, luný, --, 
   {{0x291d0426,0x56950427,0x3ce404cc,0x246001e1}},	//   shta_, нают, _zalv_, _lémí_, 
   {{0x78a10428,0x25700b01,0xca380244,0x00000000}},	//   balv, нқис, _بزاڤ_, --, 
   {{0x78a10429,0x00000000,0x00000000,0x00000000}},	//   calv, --, --, --, 
   {{0x8d800075,0xccf8012c,0xd379042a,0x68080213}},	//   ﻧﺪﺍﻕ_, _mně_, зчу_, bəda, 
   {{0x89340020,0xd7b80375,0xdb01042b,0x7c2c0115}},	//   _ኢህአዴ, _הצהר, kuný, ŝarg, 
   {{0x25a9042c,0x9f45042d,0xdb000162,0x80e00011}},	// [17770] _ادبي_, íní_, juný, নাস্, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3ff43009,0x46146d69,0x73c000fb,0x00000000}},	//   بكار, _روگر, _иәте, --, 
   {{0x657c0928,0x3ce5042e,0x6575042f,0x6e9000f1}},	//   _kuqh, _salv_, _hixh, پلوا, 
   {{0xa2580086,0x3ce40165,0xd244084c,0x0d8410da}},	//   _ebôr, _palv_, _зэри, елін, 
   {{0x78580882,0x6574025c,0x6ef001a9,0x78a00332}},	//   ṃvid, _jixh, sаbа, xalv, 
   {{0x78a025c6,0x657c676c,0xbb450430,0x3ce4dc90}},	//   valv, _luqh, мекк, _valv_, 
   {{0x7b1401a2,0x65742d2f,0x6454067c,0xbdd4023a}},	//   _záuj, _lixh, _myxi, _ообщ, 
   {{0xe29c427e,0x78a10431,0x3eac0ff7,0x645401e6}},	//   _með_, talv, _idet_, _lyxi, 
   {{0xdb010432,0x36e405f9,0x65750433,0x9c1001f2}},	//   isné, _जोड़ी_, _nixh, _pọdk, 
   {{0xa8041bce,0x8d7400be,0x00000000,0x00000000}},	//   _raññ, _ساكا, --, --, 
   {{0x78a10434,0x657c0921,0xa5b83afd,0x8c3c0790}},	//   salv, _buqh, rzón, _değd, 
   {{0x7ae90435,0x78a10436,0x65740240,0xa804002b}},	//   mdet, palv, _bixh, _paññ, 
   {{0x7ae90437,0xfe6400f7,0x00000000,0x00000000}},	//   ldet, _ۅگ_, --, --, 
   {{0x3eac524c,0x65740023,0x7ae80037,0xe29c02d2}},	//   _odet_, _dixh, odet, _beð_, 
   {{0x7ae90438,0x680803be,0x657c0003,0xa804f1c5}},	//   ndet, qəda, _fuqh, _waññ, 
   {{0x7ae90439,0xb80400dd,0x27300137,0xf1cc03d4}},	// [17780] idet, _رکھے_, _جىيس, ৰম্ভ, 
   {{0x3eac0365,0x7ae8049b,0xa6d82833,0x6574036e}},	//   _adet_, hdet, boðs, _gixh, 
   {{0x3365043a,0x7ae80334,0xa4f80375,0x00000000}},	//   _овог, kdet, _וליט, --, 
   {{0x7ae9043b,0xa25820ef,0xdef408e2,0x8fd40184}},	//   jdet, _icôn, дыш_, мәғә, 
   {{0x7ae9043c,0x8c3c0790,0xc878294f,0x00000000}},	//   ddet, _meğe, leğe_, --, 
   {{0x09bc2f8b,0x7ae9043d,0x3eac007c,0x8c3c03e0}},	//   _অনলা, edet, _edet_, _leğe, 
   {{0x7ae8007f,0xc87803e0,0xccf8013a,0x00000000}},	//   fdet, neğe_, _vně_, --, 
   {{0x7ae9043e,0x00000000,0x00000000,0x00000000}},	//   gdet, --, --, --, 
   {{0xddc01086,0x49740120,0x80e00154,0x28c05c8e}},	//   _ибти, нлис, নার্, _शादि, 
   {{0x7ae9043f,0x795004d3,0x657c0477,0xc8780790}},	//   adet, هێنا, _ruqh, keğe_, 
   {{0x8c3c0ab7,0xdb4d0440,0x9c80031d,0x657c0455}},	//   _beğe, _аю_, _účas, _suqh, 
   {{0x65750441,0x657c014f,0x7ae800db,0xab600150}},	//   _sixh, _puqh, cdet, _جۇعى, 
   {{0x8c3c0ab7,0x84c43d09,0x6a150442,0x657c0477}},	//   _değe, нәнд, _تبار, _quqh, 
   {{0x64545d04,0x85050443,0x8e200024,0x7c4000a2}},	//   _pyxi, روزن, нiк_, _çyrç, 
   {{0xd82c084c,0x680800ac,0x657c0455,0x58b80375}},	//   _рэ_, mədo, _wuqh, _ומוצ, 
   {{0x657c047e,0x6abc0011,0x00000000,0x00000000}},	//   _tuqh, ্যকো, --, --, 
   {{0x67d00075,0x6574025c,0xe29c03f2,0x051c03d4}},	// [17790] _чоқу, _tixh, _veð_, _নদীৰ_, 
   {{0x7ae800dd,0xbebc00ef,0x9878010f,0x00000000}},	//   zdet, _klūg, ַרדק, --, 
   {{0x7ae90444,0x8c3c0790,0xc8780790,0x5ec40154}},	//   ydet, _yeğe, beğe_, _রোগে, 
   {{0xd25000f8,0xc8780790,0x3d180241,0x00000000}},	//   انے_, ceğe_, _pèwo_, --, 
   {{0xa3e43874,0xbfd4037e,0x518400c7,0xdeb80051}},	//   पिक_, _arc用_, _ауса, _chuơ, 
   {{0x7ae80334,0x00000000,0x00000000,0x00000000}},	//   wdet, --, --, --, 
   {{0x4fc49d4f,0x7f58007f,0x00000000,0x00000000}},	//   _иста, plwq, --, --, 
   {{0x795c0100,0x00000000,0x00000000,0x00000000}},	//   tèwo, --, --, --, 
   {{0x7ae90445,0xbb4408b0,0x9f5000e4,0x3d940107}},	//   rdet, ﺘﺘﻰ_, _ñeñe_, _чизр, 
   {{0xccf48a5b,0x7ae90446,0xf8b00543,0x6c6801ed}},	//   _ақш_, sdet, اکش_, _کلمہ_, 
   {{0xefcc02d3,0xa5b801d3,0x7ae80175,0x8cc41b51}},	//   _ኣደዳ_, szól, pdet, _रातो, 
   {{0xc4c8011a,0xf62400f3,0x680803e3,0x00000000}},	//   _לג_, едмо, mədl, --, 
   {{0xe6147863,0x680806be,0x00000000,0x00000000}},	//   едя_, lədl, --, --, 
   {{0xdb000784,0xb4b8012c,0x34c800cd,0x00000000}},	//   munñ, ङले_, िभेद, --, 
   {{0x680803be,0xc8780790,0x281002f2,0x8c3c03e0}},	//   nədl, teğe_, _مووس, _teğe, 
   {{0x0cdc0882,0x00000000,0x00000000,0x00000000}},	//   _यस्म, --, --, --, 
   {{0x23250447,0x22450448,0x2ab803ee,0x43745aae}},	// [177a0] хоти_, епти_, lübü_, турт, 
   {{0xefcc02d3,0xeff00023,0x00000000,0x00000000}},	//   _ኣተወ_, _ሃሰው_, --, --, 
   {{0x8554fc15,0x28c03156,0x61f8031c,0xa3e4012d}},	//   _شیفر_, _शासि, _ġule, _मैप_, 
   {{0xdb000113,0xda1c02ab,0x61f90449,0x7f280014}},	//   kunñ, यनात_, _šule, وسنِ_, 
   {{0xed58026a,0x2d95044a,0x7658012d,0x200406ea}},	//   под_, хрес, ętyw, ønir_, 
   {{0x09d800bd,0xe3a40214,0xaf3c0023,0x5d800472}},	//   তিমা, _تشیی, ኣረመለ, دلول, 
   {{0x614002d5,0x21640116,0xefcc0023,0x00000000}},	//   _сера, _чири_, _ኣተዉ_, --, 
   {{0x28c034ef,0x3578001f,0xdeb80208,0x2b444530}},	//   _शाहि, በረበት_, _thuơ, ээлг, 
   {{0xed440124,0xa3e407c1,0x795c007f,0xbebc0064}},	//   _знап, _मैन_, mèwj, _slūg, 
   {{0x7c940022,0x99d1044b,0xbebc00c0,0x18b4035b}},	//   _арцц, اتيا, _plūg, нгьы_, 
   {{0x4bc40150,0x00000000,0x00000000,0x00000000}},	//   _рөлг, --, --, --, 
   {{0x09d809bd,0xbebc4a38,0x8d7400ec,0x948401ec}},	//   তিবা, _glūd, _ساڃا, ғырд, 
   {{0xd7c403e6,0xdb4cba15,0x69f001ee,0x00000000}},	//   وویه_, _اَن_, _сүпт, --, 
   {{0x2004014a,0x84240131,0x00000000,0x00000000}},	//   änik_, پىرن, --, --, 
   {{0x290c01ab,0x9fa80eac,0x62800210,0x00000000}},	//   _iofa_, _গঙ্গ, śnom, --, 
   {{0xb9cc067d,0x290c0109,0x68e801a8,0xcfb800cc}},	//   _ሰብ_, _hofa_, _hafd, ীবান, 
   {{0x290d044c,0x680803be,0xdcf801a6,0x64400427}},	// [177b0] _kofa_, zədl, _suuč, _žnid, 
   {{0x6aa04d11,0x68e8025c,0x44f40124,0xdfa400d8}},	//   _leof, _jafd, _рпос, ејдо, 
   {{0x43945cf0,0x51840184,0xc4342b7e,0x290d044d}},	//   _шанс, _ҡура, _شکست, _mofa_, 
   {{0xbebd044e,0x290d044f,0x68e80067,0x8ff801b9}},	//   _amūr, _lofa_, _lafd, عرلر_, 
   {{0x64600bb8,0x290c0248,0x00000000,0x00000000}},	//   štić, _oofa_, --, --, 
   {{0x68e90450,0x290d0451,0x00000000,0x00000000}},	//   _nafd, _nofa_, --, --, 
   {{0xfaf000c6,0xbebc143f,0xa3e400ab,0x626400cf}},	//   لثة_, _plūd, _मैम_, _زاڭق, 
   {{0x290c1140,0xe29c066a,0xdb000309,0x00000000}},	//   _aofa_, _boði_, tunñ, --, 
   {{0x290c0ba7,0x394431fd,0x28c0000d,0x00000000}},	//   _bofa_, книг, _शाशि, --, 
   {{0x290c004b,0xc9440220,0xcda800ae,0x00000000}},	//   _cofa_, лдық, _أهله_, --, 
   {{0x97808117,0x6aa04894,0x28c0228a,0x00000000}},	//   دیبه, _feof, _शारि, --, 
   {{0x6aa10452,0x68e803ac,0xdb000784,0xef4c0023}},	//   _geof, _eafd, punñ, _ንባዕል, 
   {{0x290d0453,0x0430001f,0xdb000561,0xe29c02d2}},	//   _fofa_, _አስገን, nsní, _goði_, 
   {{0x290c0770,0x6aa00472,0x8578009d,0xab6000a2}},	//   _gofa_, _zeof, есст_, _ýürt, 
   {{0x6aa00472,0x6ed029c7,0xf74400c7,0x37e40107}},	//   _yeof, ण्डु, _иеко, _ройг, 
   {{0x290d0454,0x00000000,0x00000000,0x00000000}},	//   _zofa_, --, --, --, 
   {{0x68e8011f,0xf1a80133,0xf1d001e0,0x942003b9}},	// [177c0] _yafd, بازه_, шөнө, _əsən_, 
   {{0x80e800d1,0xf0e800d1,0x61f825ad,0xb38401f0}},	//   нгуң_, بىئى_, _šulc, _илол, 
   {{0x06640244,0x8e2001ec,0x00000000,0x00000000}},	//   _لایپ, нiп_, --, --, 
   {{0xee390455,0x8cc40d41,0xef180a89,0x69b0ffeb}},	//   мне_, _राहो, ьме_, _इटली, 
   {{0x6aa001e4,0x28c02894,0x24500330,0x00000000}},	//   _reof, _शालि, _منیس, --, 
   {{0x25bc026c,0xe29c032e,0x22b401ef,0x00000000}},	//   àuli_, _roði_, _věků_, --, 
   {{0xb9840220,0x290d0456,0xddd8033f,0x68e802d2}},	//   қтық, _rofa_, _czuł, _rafd, 
   {{0x68e801d5,0xfd68030a,0x290c2238,0x29887c3f}},	//   _safd, _maqṣ, _sofa_, мсоо_, 
   {{0x2bad0457,0x7c2c00df,0x00000000,0x00000000}},	//   _टिका, ĝara, --, --, 
   {{0xe784016c,0x290c22a9,0xbce4e9d0,0x00000000}},	//   кумо, _qofa_, _مأمو, --, 
   {{0x6aa10458,0x290d0459,0x09d800cc,0xdae40014}},	//   _teof, _vofa_, তিধা, رفیو_, 
   {{0xb8f83eaf,0x68e801d9,0x9c10a63c,0x9a80086a}},	//   _डॉ_, _wafd, _kọnk, _кушл, 
   {{0x290d045a,0x95c80415,0x68e9045b,0xdb0c0248}},	//   _tofa_, кура_, _tafd, _ìdás, 
   {{0x47341cd1,0x2bc40490,0xdeec00b7,0xda1c09ab}},	//   _әнис, रंपा, ቀትና_, यनरत_, 
   {{0x6d4402d2,0x294c0023,0x999c0210,0x00000000}},	//   _íkau, _ምእዙዛ, czuł_, --, 
   {{0xae0005d7,0xbb4c0150,0xed880240,0x941803e3}},	//   लमान_, _ﺍﺭﻟ_, ዝብተይ_, narə_, 
   {{0xe4e80302,0x2f1c067c,0xe7e81db2,0x6b5c0240}},	// [177d0] _قعده_, _aïgo_, टिका_, tëgj, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x44e800cc,0xd25000f1,0x00000000,0x00000000}},	//   খাদক_, منې_, --, --, 
   {{0x9c10063f,0x4254009f,0xdef80124,0x00000000}},	//   _bọnk, _منجر, ьыз_, --, 
   {{0x3d180066,0x4ed402bf,0x62880165,0x7b140051}},	//   _hèwi_, рюєт, ñgou, _máut, 
   {{0x91840075,0x4fc400cf,0x00000000,0x00000000}},	//   _ئۇلۇ, _چەلە, --, --, 
   {{0x0ba81a50,0x2a6401b9,0xf0801bf3,0x00000000}},	//   نايى_, _azob_, _ایمپ, --, 
   {{0x7b145fd9,0x1ee40214,0x39e80063,0xdb000118}},	//   _náut, _جوری_, едио_, brný, 
   {{0x3d1800f2,0x5cc400c7,0xdb1000e4,0x00000000}},	//   _lèwi_, _асез, ñañe, --, 
   {{0x37e401c0,0xa921045c,0x38680139,0x00000000}},	//   гоог, йдыл, _ƅar_, --, 
   {{0xd05c0cc1,0x628d045d,0xb6a444b2,0xdb000793}},	//   _barə, _ofco, линл, dunö, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x628c01f0,0x3dc4045e,0x26cc049f,0xdb4c01f7}},	//   _afco, _এনাল, _ögon_, _اَچ_, 
   {{0x3988790f,0x2bc40b7c,0x2b44020c,0x79880113}},	//   _hús_, रूपा, _yjoc_, lqew, 
   {{0x3d18034c,0xa45c0020,0x61f800a2,0x00000000}},	//   _dèwi_, ተሚያዎ_, _šula, --, 
   {{0x8cc402ab,0x8e20443f,0x7afc01f4,0xa34400d8}},	// [177e0] _रालो, нiн_, östy, узта_, 
   {{0xdcf805ce,0xf8b405f9,0x72d00131,0x39881d1d}},	//   _otuđ, ूलिय, _گەرچ, _mús_, 
   {{0x3d180214,0x33440014,0x3989045e,0xd05c06be}},	//   _gèwi_, _مندِ, _lús_, _yarə, 
   {{0xdb00022a,0xd05c06be,0x6438011a,0x00000000}},	//   trný, _xarə, _טעינ, --, 
   {{0xdd8d045f,0x5bc000d1,0x00000000,0x00000000}},	//   كون_, ەقىل, --, --, 
   {{0x1d050460,0x2fa400c6,0x8c3c03e0,0xbebc0171}},	//   лечи_, _مصرّ, _değn, _plūc, 
   {{0xa0650461,0xe120036b,0x3fc801b9,0xfb84006c}},	//   _бара_, _умри, _لگنی_, لگنی, 
   {{0x09d802f5,0xdb000037,0xa5b8012d,0xe9e4009d}},	//   তিসা, kunõ, czów, гцоо, 
   {{0x680800ac,0xe378010f,0xb6040064,0x00000000}},	//   mədi, ערפר, nkšč, --, 
   {{0x680803be,0xdb00000d,0xb60400c0,0x398800e5}},	//   lədi, dunõ, ikšč, _dús_, 
   {{0x6d58038f,0x6ac4a397,0x7b1400e4,0xa8500032}},	//   _ikta, _مقام, _cáus, сенә, 
   {{0x680800ac,0x39881427,0x9bb00451,0xd05c0213}},	//   nədi, _fús_, _اڄوڪ, _qarə, 
   {{0x398801e1,0x6d4406ea,0xdb0000ae,0x69cc054e}},	//   _gús_, _íkas, arnó, ăbes, 
   {{0x7e7c01a2,0xd9402f5c,0x628c0334,0xba2800ec}},	//   _úspe, _лечи, _sfco, _جسمم_, 
   {{0x6d580936,0x60e003b9,0xd4040108,0x680803e3}},	//   _mkta, _ötmə, бяти, kədi, 
   {{0x57f8025f,0x53350462,0x57a00116,0x2bc400dc}},	//   _טלוו, бест, _ушша, रूया, 
   {{0x6d590463,0x680800ac,0x41b400f2,0x00000000}},	// [177f0] _okta, dədi, شمار, --, 
   {{0x291d0464,0x7b140789,0x0fe40137,0x94d4030d}},	//   nkta_, _jáur, өөсү, _лоьц, 
   {{0xfa64001f,0x914814fb,0x2bc427a6,0x680803e3}},	//   ስቸኳይ_, учта_, रूमा, fədi, 
   {{0x6d590465,0xa6e00154,0xbdf40798,0x00000000}},	//   _akta, যাকট, ипеј, --, 
   {{0xdd980107,0xdb0001ef,0x00000000,0x00000000}},	//   хше_, jsná, --, --, 
   {{0x398803b2,0xa6a800cc,0xdb200248,0xa5b80210}},	//   _rús_, কলিয়, _èrúw, szów, 
   {{0x798800b5,0x39889162,0x59b4302b,0x7c2c00df}},	//   wqew, _sús_, _इटहर, ĝaro, 
   {{0x1df4b226,0x6d590466,0x68080213,0x7c2c01e4}},	//   _مکتب_, _ekta, cədi, ŝaro, 
   {{0x6d5803c1,0x2918031c,0x2bc400bc,0x7b14032e}},	//   _fkta, _ċpar_, रूबा, _sáus, 
   {{0xd01000aa,0x7e68035a,0xf8b8009d,0x00000000}},	//   _بلې_, _izep, төд_, --, 
   {{0xf8641f99,0x95b401e0,0x977400d1,0xbab40066}},	//   рвно, әрмә, йтмә, _نماب, 
   {{0x39880597,0x9b400014,0x80e0009e,0xb6040024}},	//   _tús_, _دۆبو, নাট্, ykšč, 
   {{0x2bc40490,0x00000000,0x00000000,0x00000000}},	//   रंथा, --, --, --, 
   {{0x4a444dba,0xc8c84957,0x291c01e6,0x64a10467}},	//   _унів, _موهن_, ckta_, жара, 
   {{0xc1dc005e,0xa95402e4,0xa50423be,0xede021b8}},	//   _ﺇﺴﺭﺍ, _דיסק_, шера_, _गन्ध_, 
   {{0xf7710468,0x7f48036e,0x00000000,0x00000000}},	//   _بات_, _njeq, --, --, 
  
   {{0x7174009f,0xdfcc01e2,0x00000000,0x00000000}},	// [17800] لهرا, ېيم_, --, --, 
   {{0xb6040024,0x00000000,0x00000000,0x00000000}},	//   rkšč, --, --, --, 
   {{0x680803be,0xdb00143a,0x83c002dd,0x00000000}},	//   tədi, msnæ, _нұрж, --, 
   {{0xe8041b76,0xbe84007b,0xdce800df,0x5fd40037}},	//   षमता_, مجهو, ĉiĝi, _ठहरल, 
   {{0x291d0469,0x680800ac,0x4c95046a,0x3d1801e1}},	//   ykta_, rədi, билс, _lèwu_, 
   {{0x21a00d08,0x7e6805b8,0xdb00143a,0x00000000}},	//   _фирм, _dzep, nsnæ, --, 
   {{0x237c0232,0x7e69046b,0x00000000,0x00000000}},	//   ňuje_, _ezep, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x291c0054,0x6d580270,0xace806ed,0xdb00dd74}},	//   tkta_, _tkta, _имаа_, ksnæ, 
   {{0x6d580a28,0x09d802f5,0x291c2ba4,0x2bc402db}},	//   _ukta, তিলা, ukta_, रंदा, 
   {{0x80e0015b,0xdb00005c,0x2b900244,0x00000000}},	//   নাচ্, dsnæ, _بیبس, --, 
   {{0x291c0bc9,0xdc380375,0xbc241075,0xeaf84fca}},	//   skta_, _בעבר, _اركى, _جرئت_, 
   {{0xe66452f7,0x291c0054,0x3a2c012d,0xc994007b}},	//   ртно, pkta_, czep_, _التظ, 
   {{0x7b1402d2,0x47d400ec,0x00000000,0x00000000}},	//   _háup, _هيتر, --, --, 
   {{0x9389046c,0xa6d80162,0x00000000,0x00000000}},	//   иста_, viðf, --, --, 
   {{0x1cb80327,0x9878011a,0xbebd046d,0x439401ec}},	//   _མྰན_, _באוט, _alūn, _қамс, 
   {{0x26d80218,0x9258007b,0x5344035b,0x00000000}},	// [17810] _ibqo_, لشكر_, цхра, --, 
   {{0x3afc006a,0x7e68033f,0xc21001d9,0xc8f403d4}},	//   _kâpä_, _rzep, _ۂج_, _চকুত_, 
   {{0x7e6800dd,0x00000000,0x00000000,0x00000000}},	//   _szep, --, --, --, 
   {{0x0eb80220,0xa5b801d3,0xa3b80451,0x00000000}},	//   аушы_, gyóg, _ٻاھر_, --, 
   {{0x7f480240,0x8c3c05d1,0x7c2c01e4,0x88ac0154}},	//   _vjeq, _değm, ĝarm, _খানক, 
   {{0xfce40126,0xef9818ce,0x7e6801ef,0x680803e3}},	//   соко, _әйтә_, _vzep, lədu, 
   {{0x80ac009e,0x00000000,0x00000000,0x00000000}},	//   _চাপ্, --, --, --, 
   {{0x7a680323,0x3c04036b,0xfbd804c5,0x629c0175}},	//   лийг_, _қўзғ, থিলত, nbqo, 
   {{0x3d180214,0x89a83e64,0x4ab80037,0x00000000}},	//   _sèwu_, айың_, _इयरव, --, 
   {{0x35a400c7,0x00000000,0x00000000,0x00000000}},	//   ҩанг, --, --, --, 
   {{0xbb840491,0x377439fb,0x61f80113,0xe1fc01ed}},	//   _الصي, йымс, _šull, _szól_, 
   {{0xf74401ee,0xb0640166,0x00000000,0x00000000}},	//   семо, lmäü, --, --, 
   {{0xe734652e,0x98a00032,0x95040327,0xdb000fac}},	//   сея_, _һиҙе, ངྐའི_, tsnæ, 
   {{0xa5c409f3,0x7f580784,0xf1c80306,0xc96400d4}},	//   _stóð, howq, ndáž_, _двій, 
   {{0x09341547,0xdb005522,0xb6a4030d,0x668000f1}},	//   _برنج, rsnæ, _лийл, _ډیپل, 
   {{0xa6d8022c,0x00000000,0x00000000,0x00000000}},	//   viðg, --, --, --, 
   {{0x6b5c00e8,0x31246be1,0xdb0001e3,0x00000000}},	// [17820] cëgu, бдаг, msnä, --, 
   {{0xb06001f4,0xdb0001e3,0xf6c801af,0x00000000}},	//   _ääkk, lsnä, _рыҫк_, --, 
   {{0xfbc400ec,0xdfcc9f9c,0xa6d802d2,0x00000000}},	//   _تڪ_, فيل_, biðd, --, 
   {{0x2e481a21,0xd174054a,0xdb000267,0x62040332}},	//   ляло_, сығы, nsnä, órlí, 
   {{0xee380262,0x60d40334,0x00000000,0x00000000}},	//   ынд_, bfxm, --, --, 
   {{0xa3e4012d,0x00000000,0x00000000,0x00000000}},	//   _मैँ_, --, --, --, 
   {{0xfc3400b7,0xefb001d5,0x8c3c0790,0xdb0001e3}},	//   _እንገል, _ریشگ, _teğm, ksnä, 
   {{0xd54401e1,0x00000000,0x00000000,0x00000000}},	//   _yẹ̀n, --, --, --, 
   {{0xdb000267,0xad6801c6,0x00000000,0x00000000}},	//   dsnä, _бааз_, --, --, 
   {{0xa258019f,0x3afc006a,0x933c001f,0x9f4002d2}},	//   _icôt, _pâpä_, _በወቅታ, _frjó_, 
   {{0xa3e414cf,0xdcac0aaf,0xeb98447e,0x00000000}},	//   _मैं_, _سىن_, _сие_, --, 
   {{0x06840137,0xdb0001e3,0x00000000,0x00000000}},	//   өгүн, gsnä, --, --, 
   {{0x2bc40a59,0x00000000,0x00000000,0x00000000}},	//   रंवा, --, --, --, 
   {{0xf83801d3,0x0a300092,0x00000000,0x00000000}},	//   ازیں_, _እድሜያ, --, --, 
   {{0xd404005b,0x23240139,0x1ae800eb,0x00000000}},	//   пяти, бфаг, কারই_, --, 
   {{0xc2989702,0x6b81046e,0xc2c42dd0,0x00000000}},	//   рках_, _jiog, تيري, --, 
   {{0x608400c6,0x6b81046f,0x2ee4004e,0x59240327}},	// [17830] مشاك, _miog, deof_, རྣམས_, 
   {{0x6b800165,0xdb0001e3,0x00000000,0x00000000}},	//   _liog, msnå, --, --, 
   {{0xd49801af,0x20681de6,0x3e4c01e1,0x00000000}},	//   _уры_, ушап_, _ọ̀bà_, --, 
   {{0x01c8066d,0x2ee40175,0x7c2c0115,0x258001e1}},	//   _پوسٹ_, geof_, ŝark, bélè_, 
   {{0xa2242f84,0x0ea81cb8,0xdb00007c,0x00000000}},	//   _طرحه, скій_, nsnå, --, 
   {{0x6b800421,0x61ed0470,0x1128020f,0xc1044d81}},	//   _aiog, _iscl, _люси_, _بوسي, 
   {{0x9f680116,0xcfa40276,0xdb0001f4,0x00000000}},	//   _браз_, _ншти, ysnä, --, 
   {{0x2ee401a4,0x61f8025c,0xbebc00ef,0xfc340092}},	//   ceof_, _ġulj, _klūm, _እንግል, 
   {{0x6b810471,0x61f80960,0xdb0001e3,0x00000000}},	//   _diog, _šulj, vsnä, --, 
   {{0x78a80640,0xe970027d,0x85340023,0x23a8012d}},	//   шког_, وهيد, _ኣጥፊእ, _ज़िंद, 
   {{0xfbdc7e7c,0x6b8000ad,0xd70800d1,0xdb0001e3}},	//   _महिम, _fiog, مىدۇ_, tsnä, 
   {{0x6b810472,0x61ec007b,0xddd801a6,0x98a80051}},	//   _giog, _oscl, _zguš, đcđ_, 
   {{0xe9cc0598,0xdb000267,0x443001f5,0x74cc00dc}},	//   _юк_, rsnä, ezz_, _तादृ, 
   {{0xfbdc243c,0x2bc43644,0x6b810473,0x1da800bc}},	//   _महाम, रूवा, _ziog, घीयत, 
   {{0x61ed0474,0x6b8000ad,0x00000000,0x00000000}},	//   _ascl, _yiog, --, --, 
   {{0xa3b800e1,0x069401d9,0xbebc00de,0xb22400f3}},	//   _घिर_, _ٹاٹھ, _blūm, омбл, 
   {{0xf0a90475,0x61ec010a,0xe1f401c0,0xa5b801ed}},	// [17840] икал_, _cscl, огт_, szór, 
   {{0xb09800d4,0x00000000,0x00000000,0x00000000}},	//   ртає_, --, --, --, 
   {{0x61ed0476,0xa1100214,0x2ee401ab,0xc05800d4}},	//   _escl, بولت, teof_, бії_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6b810477,0xace807d6,0x4ea40032,0x2ee4011a}},	//   _riog, имда_, орҙа, reof_, 
   {{0x6b801359,0x4c940818,0xab60010e,0x00000000}},	//   _siog, чикс, _ýüzt, --, 
   {{0x6b802ce3,0x2ee4030d,0x79980175,0x6d440248}},	//   _piog, peof_, _atww, _ìkam, 
   {{0x81bc00bd,0x6b8000b4,0x7998035a,0xe61c0429}},	//   _আহত_, _ọgba, _btww, yyô_, 
   {{0xc87805d1,0x6b8000ad,0xdd8c00be,0xd71c00fe}},	//   meği_, _viog, _لوق_, দোৱা_, 
   {{0xddd81050,0xc8780790,0xad240214,0x58d43cc5}},	//   _uguš, leği_, _بررو, одья_, 
   {{0xab284685,0x6b80aea6,0x99e000d0,0x200401bf}},	//   _кожа_, _tiog, ĺňaj, ønix_, 
   {{0xd1d04be7,0xc87803ee,0x6b800421,0x56941830}},	//   ብረት_, neği_, _uiog, мают, 
   {{0x6d490478,0x79980175,0xd1e002d3,0x96342991}},	//   onfa, _gtww, _ሓቲቱ_, дняц, 
   {{0x6d480910,0xe73c0022,0xe7282e0b,0x00000000}},	//   nnfa, siõ_, اسگو_, --, 
   {{0x44250479,0xc87805d1,0xdb000158,0x00000000}},	//   ál_, keği_, ssnå, --, 
   {{0x6d480e78,0xbebc00de,0x00000000,0x00000000}},	//   hnfa, _plūm, --, --, 
   {{0x8c3c079d,0xe7282756,0xfdc4015b,0xb2740022}},	// [17850] _deği, _مسکو_, _এন্ড, зктә, 
   {{0x6b08031c,0x00000000,0x00000000,0x00000000}},	//   _ཀོའོ_, --, --, --, 
   {{0x73c00220,0x8cc4cc41,0xc87803e0,0x9e7c01f3}},	//   _пәте, _राजो, feği_, ንድስና_, 
   {{0xd9c0045e,0x63000075,0x6d49047a,0x8c3c0205}},	//   ্বতম, _تۈرل, enfa, _geği, 
   {{0x6b9800cc,0x8e7400f7,0x61ec0857,0x563c0092}},	//   _attg, мушч, _uscl, _አንደበ, 
   {{0x6b980083,0xe1fc0ca8,0xc0d40023,0x78a00334}},	//   _bttg, _iró_, ረቦም_, xblv, 
   {{0x2bc40316,0x81bc0c58,0xc87805d1,0x8c3c0205}},	//   रूला, _আহি_, beği_, _yeği, 
   {{0xc8780365,0x6d49047b,0x7e7c0232,0xe1fc03b2}},	//   ceği_, anfa, _úspo, _kró_, 
   {{0xbea40166,0x3ea40166,0x00000000,0x00000000}},	//   _маңк, _миңг, --, --, 
   {{0x3ead047c,0x81e40eac,0xdb00002d,0x77c80024}},	//   _heet_, পটপ_, ernô, блог_, 
   {{0x3eac6df9,0xdeb8044e,0x3f8407ea,0xe1fc032e}},	//   _keet_, _ደሓን_, _élus_, _lró_, 
   {{0xd5b800da,0x3eac1368,0xf771047d,0x3ae801ed}},	//   ņām_, _jeet_, عاد_, _دبئی_, 
   {{0x7ae9047e,0xe1fc4a1f,0x3ead047f,0xbebc00e2}},	//   meet, _nró_, _meet_, _alūk, 
   {{0x7ae90480,0x3ead0481,0x8c3c0205,0x00000000}},	//   leet, _leet_, _seği, --, 
   {{0xe1fc0cad,0x2e4c063f,0xc0d40092,0x74080154}},	//   _aró_, lọtọ_, _የቢሮ_, রন্ট_, 
   {{0x2444016b,0x3ead0482,0xd1d0001f,0xe1fc032e}},	//   _dεm_, _neet_, ብረቱ_, _bró_, 
   {{0x7ae80083,0xe1fc01e7,0x067400db,0x6d486729}},	// [17860] ieet, _cró_, _ۉنۉڭ, ynfa, 
   {{0x7ae90483,0xe1fc0321,0x785001e4,0xa3e4012d}},	//   heet, _dró_, nցvo, _मैक_, 
   {{0xc87805d1,0xa6d801a8,0x21a000d1,0x6d480158}},	//   teği_, liða, _җисм, vnfa, 
   {{0x3eac1bce,0x7ae8005a,0xdfcc15eb,0x6d4850eb}},	//   _ceet_, jeet, طيه_, wnfa, 
   {{0x3ead0484,0x7ae90485,0xc87803ee,0x6d483619}},	//   _deet_, deet, reği_, tnfa, 
   {{0x6d480a55,0x9d14016c,0x00000000,0x00000000}},	//   unfa, зошт_, --, --, 
   {{0x3ead0486,0xceb90487,0x7ae90488,0x6d485df7}},	//   _feet_, _дәл_, feet, rnfa, 
   {{0x3eac092e,0xca2841fa,0x7ae90489,0x6d48009a}},	//   _geet_, يۋان_, geet, snfa, 
   {{0x497406dc,0x00000000,0x00000000,0x00000000}},	//   млис, --, --, --, 
   {{0xfe442172,0xdd8cc975,0xe90800d1,0x6e20022e}},	//   _تکمی, _صوم_, схик_, myob, 
   {{0x99d002f2,0x98c000fb,0x00000000,0x00000000}},	//   وتیا, хсыл, --, --, 
   {{0x3eac1574,0xdee802d3,0xa6d80008,0x38b8010e}},	//   _xeet_, _ዘበን_, fiða, _aýrı_, 
   {{0x6e2001b2,0x84c43a0a,0xd05c0c09,0xa7841f70}},	//   nyob, мәнд, _karɓ, _کشتو, 
   {{0x58d00cfc,0xd78405d9,0xa85004b4,0xda78011a}},	//   _зошт, _کنيو_, _пелә, _הנדר, 
   {{0xe3b09a3e,0xd8d80375,0x53e4003b,0x00000000}},	//   عرس_, _הקור, нцта, --, 
   {{0xe1fc315a,0x6e21048a,0xe72801f7,0x00000000}},	//   _pró_, kyob, _دستو_, --, 
   {{0x3ead048b,0x5334b2ee,0xf4080154,0x00000000}},	// [17870] _reet_, хетт, রনগর_, --, 
   {{0x3ead048c,0x2a64020b,0x6e204429,0x7ae9048d}},	//   _seet_, _myob_, dyob, zeet, 
   {{0x3eac200c,0xd49811db,0x7ae9048e,0x0fe400f7}},	//   _peet_, _эры_, yeet, нөтү, 
   {{0x683c044e,0xe6bc00dc,0xe1fc00d8,0x7ae9048f}},	//   _ኣንስት, ्लिङ, _tró_, xeet, 
   {{0x2a640b89,0x6e20066d,0x7ae90490,0x00000000}},	//   _nyob_, gyob, veet, --, 
   {{0x3eacbbd7,0x7ae90491,0x9cc90492,0xdb0000cc}},	//   _weet_, weet, сыда_, lsnø, 
   {{0xdbf4032c,0x2a6405b1,0x3ead0493,0xabd001d9}},	//   ंटेड_, _ayob_, _teet_, نٲوت, 
   {{0xcbc40075,0xba1801ec,0x2a640334,0x6e210494}},	//   رزىي, قيعا_, _byob_, byob, 
   {{0x3df407d6,0x6e2000ca,0xf988004b,0x00000000}},	//   _юзас, cyob, غندي_, --, 
   {{0x2a6402e2,0x00000000,0x00000000,0x00000000}},	//   _dyob_, --, --, --, 
   {{0x7ae90495,0xdb58188c,0xdee8010c,0x00000000}},	//   peet, _люд_, _ዘበነ_, --, 
   {{0x7ae874fa,0x00000000,0x00000000,0x00000000}},	//   qeet, --, --, --, 
   {{0xdb002b96,0xd1d00092,0x00000000,0x00000000}},	//   dsnø, ብከተ_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa6d80413,0x00000000,0x00000000,0x00000000}},	//   miðn, --, --, --, 
   {{0x75d402dd,0x82f40801,0xa6d80ad9,0x00000000}},	//   _قيعا, нчуц, liðn, --, 
   {{0x2a640218,0x2e4c00b4,0x9f400108,0x05b40024}},	// [17880] _xyob_, họrọ_, _yrjö_, _псэў, 
   {{0x69c40fb7,0x6e2000ec,0x2e4c0521,0x09d80154}},	//   škeg, vyob, kọrọ_, তিচা, 
   {{0xa258025a,0x2e4c01f2,0xc0580212,0x6e200210}},	//   _adôd, jọrọ_, пії_, wyob, 
   {{0x2e4c01f2,0x6e2031ab,0x6e4426c6,0xae4402f2}},	//   dọrọ_, tyob, ونام, وپاو, 
   {{0xdd8d0496,0xed580323,0x80ac00bd,0x00000000}},	//   لون_, оод_, _চার্, --, 
   {{0x2e4c01f2,0x6e20022e,0x00000000,0x00000000}},	//   fọrọ_, ryob, --, --, 
   {{0xa0650497,0x6e210498,0xcfa800f1,0x00000000}},	//   _жара_, syob, _ژاړم_, --, 
   {{0x1b740597,0xa030021f,0x00000000,0x00000000}},	//   وصية_, _شىقت, --, --, 
   {{0x46ac012c,0xdeec0118,0xa6d8032e,0x00000000}},	//   चरसह, áčům_, fiðn, --, 
   {{0x4814094d,0x2e4c01f2,0xa9bc547d,0x00000000}},	//   емос, bọrọ_, _एटीए, --, 
   {{0xa8500032,0x00000000,0x00000000,0x00000000}},	//   тенә, --, --, --, 
   {{0xa9a447b3,0x00000000,0x00000000,0x00000000}},	//   _жидд, --, --, --, 
   {{0x2bc40764,0xe8f80026,0x743c0092,0xdb005522}},	//   रंका, _млд_, _አስገብ, vsnø, 
   {{0x25bc0010,0x81bc00cc,0xbdd00150,0x00000000}},	//   šulo_, _আহল_, _ﺒﺩﻴل_, --, 
   {{0x80ac00cc,0xeac000fe,0x00000000,0x00000000}},	//   _চাল্, ্জীম, --, --, 
   {{0xa9cc0046,0x00000000,0x00000000,0x00000000}},	//   _ﻛﻪﯕﺴ, --, --, --, 
   {{0xe4a4a6e6,0x73c001e0,0xdb00072b,0x21240066}},	// [17890] _орно, _ҙәре, rsnø, ويری_, 
   {{0xdb0003cd,0x00000000,0x00000000,0x00000000}},	//   ssnø, --, --, --, 
   {{0xa3e4068f,0xc0c46b62,0x00000000,0x00000000}},	//   _मैच_, _җәзи, --, --, 
   {{0x6454102c,0x00000000,0x00000000,0x00000000}},	//   _ixxi, --, --, --, 
   {{0x2e4c063f,0xdd980334,0x65740051,0xa28000f2}},	//   wọrọ_, цше_, _khxh, _شیطو, 
   {{0x0d8410f5,0xcce42374,0x00000000,0x00000000}},	//   влін, نسىي, --, --, 
   {{0x50650499,0x2bc4a9ec,0x00000000,0x00000000}},	//   _атта, रंगा, --, --, 
   {{0x20000198,0x00000000,0x00000000,0x00000000}},	//   _irji_, --, --, --, 
   {{0x6455049a,0x2010003a,0xf9844965,0x0bb8004e}},	//   _lxxi, lxxi_, нгио, птөө_, 
   {{0x2e4c0521,0x9870005f,0x6455049b,0x3f91049c}},	//   pọrọ_, ežāk_, _oxxi, _kuzu_, 
   {{0x3f91049d,0x7e68035b,0x8c3c0205,0x81e40154}},	//   _juzu_, _hyep, _değs, পটি_, 
   {{0x3f91049e,0x00000000,0x00000000,0x00000000}},	//   _muzu_, --, --, --, 
   {{0xa6d82242,0x3f91049f,0x281025da,0x645402d0}},	//   miðl, _luzu_, نویس, _axxi, 
   {{0x200001e1,0x65740208,0x81e400eb,0x00000000}},	//   _orji_, _chxh, পটা_, --, 
   {{0x3944354d,0x645504a0,0x7af8025c,0xf7440f5c}},	//   mils_, _cxxi, _kawt, _пеко, 
   {{0xfe640272,0x7af8dd07,0x7e680022,0xf1d104a1}},	//   _نگ_, _jawt, _oyep, лөгө, 
   {{0x7e6904a2,0x7af80649,0x200104a3,0xa5b800d2}},	// [178a0] _nyep, _mawt, _arji_, nyól, 
   {{0x7af904a4,0x394504a5,0x3f9003f9,0x25ec0037}},	//   _lawt, nils_, _buzu_, ेटरी_, 
   {{0x7e682798,0xaec504a6,0xe1fc01d3,0x00000000}},	//   _ayep, ебел, _szót_, --, 
   {{0x3f900323,0x7af8bcd4,0xef1904a7,0x39440204}},	//   _duzu_, _nawt, яме_, hils_, 
   {{0x20000327,0x394504a8,0x00000000,0x00000000}},	//   _erji_, kils_, --, --, 
   {{0x13d400fe,0xabb00022,0xb1c401ec,0x88c40055}},	//   _হৈয়, гакә, _оңға_, _āśop, 
   {{0x394503f2,0x3f91031e,0x7af904a9,0x7e6904aa}},	//   dils_, _guzu_, _bawt, _eyep, 
   {{0x7af904ab,0x2900005f,0x5fd80375,0x39440129}},	//   _cawt, ēkam_, _מחלק, eils_, 
   {{0x3f9104ac,0x394504ad,0x7af8039a,0xdce80205}},	//   _zuzu_, fils_, _dawt, _çiğk, 
   {{0x56943007,0x3f90010e,0x00000000,0x00000000}},	//   ғарт, _yuzu_, --, --, 
   {{0xdca104ae,0xea8800d8,0x5ca0010a,0x29080205}},	//   _сахи, _ебел_, _сихб, ıba_, 
   {{0x46140f1c,0x7af80208,0xe6640835,0x00000000}},	//   نوجر, _gawt, етго, --, 
   {{0x394504af,0xa3d005ba,0xdb000162,0xe4e400d4}},	//   bils_, हून_, nsný, нівн, 
   {{0x394504b0,0x53343007,0x21300200,0x00000000}},	//   cils_, ңерт, xhxh_, --, 
   {{0xd82c28cf,0x555800d4,0x00000000,0x00000000}},	//   _сэ_, харя_, --, --, 
   {{0xd05c0198,0xdb0003b2,0x00000000,0x00000000}},	//   _harɗ, ksný, --, --, 
   {{0x20c40026,0x009401c6,0x78ac03b9,0xe66400d4}},	// [178b0] есег, визэ, _şivə, _ятко, 
   {{0x7e680588,0x00000000,0x00000000,0x00000000}},	//   _ryep, --, --, --, 
   {{0x3f9003b9,0xa28001e2,0x00000000,0x00000000}},	//   _quzu_, _څیزو, --, --, 
   {{0x7c3c0213,0x2010004e,0x5ba00116,0x00000000}},	//   _əsrd, rxxi_, қлиғ, --, 
   {{0x628c0af2,0x3f9004ba,0x7af8002e,0x3cfc012c}},	//   _igco, _wuzu_, _rawt, लयले_, 
   {{0x51845ded,0xfce444b5,0x7af8d6ff,0x7e68009f}},	//   _буса, токо, _sawt, _vyep, 
   {{0x394504b1,0x7af802d1,0x6bd402f2,0x00000000}},	//   vils_, _pawt, نووس_, --, 
   {{0x7af8014f,0x7e680022,0x48b00051,0x3944025c}},	//   _qawt, _tyep, _đitừ_, wils_, 
   {{0x394504b2,0x628c0117,0x7e680117,0x7cd904b3}},	//   tils_, _mgco, _uyep, _омар_, 
   {{0x39440129,0x00000000,0x00000000,0x00000000}},	//   uils_, --, --, --, 
   {{0xb6a44af0,0x39444f1e,0xf09006a9,0x628c01f0}},	//   кинл, rils_, יני_, _ogco, 
   {{0xd6b0000e,0x3944014a,0x628c1928,0xf74417a0}},	//   কল্প, sils_, _ngco, темо, 
   {{0x394504b4,0xe8eca4c9,0xe734487f,0xdee80092}},	//   pils_, _кл_, тея_, _ዘጠና_, 
   {{0x628d04b5,0xe5a0084c,0x00000000,0x00000000}},	//   _agco, рири, --, --, 
   {{0x628c07d5,0x28100272,0xd348036b,0x00000000}},	//   _bgco, _نووس, فیده_, --, 
   {{0x628c02a8,0xa85408c3,0x00000000,0x00000000}},	//   _cgco, _ביצה_, --, --, 
   {{0x6380013e,0x8e2002dd,0x00000000,0x00000000}},	// [178c0] ргта, мiн_, --, --, 
   {{0x628c01f0,0x00000000,0x00000000,0x00000000}},	//   _egco, --, --, --, 
   {{0x628c0334,0x2d1c00e1,0xe454004e,0x6ff40395}},	//   _fgco, _बकौल_, _ажэ_, ъчах, 
   {{0xd1743419,0xb2740137,0xb78400a2,0x3ce40171}},	//   тығы, _үлүш, _inỳä, _ablv_, 
   {{0xe1fc033f,0xa6dc00eb,0x00000000,0x00000000}},	//   _wzór_, _বোঁট, --, --, 
   {{0xa0a104b6,0xfaf800c0,0xe6ac0210,0x00000000}},	//   _вард, klūs_, _झज्ज, --, 
   {{0x614060b2,0xdee80020,0x3ce40171,0x88940116}},	//   _тера, _ዘጠኝ_, _dblv_, һипх, 
   {{0x7bc40407,0xdcf80139,0xdbdc03b2,0x00000000}},	//   áhua, _tuuğ, ríðt, --, 
   {{0xa6d80162,0x19a40139,0x00000000,0x00000000}},	//   biðj, ктэп_, --, --, 
   {{0xfe447aaf,0x680803e3,0x00000000,0x00000000}},	//   _حکمی, mədz, --, --, 
   {{0x98700138,0x4bc4013d,0x237c0118,0x338c0220}},	//   ильц, _сөлг, ňuji_, _ﻓﺎﻛﺲ_, 
   {{0xea600014,0xa50400d1,0x00000000,0x00000000}},	//   _پھبی, ھىزە_, --, --, 
   {{0x69f053f0,0x5ac803e6,0x6a146e1d,0xfaf80153}},	//   _түпт, _زانێ_, _جبار, alūs_, 
   {{0xd940f73c,0x00000000,0x00000000,0x00000000}},	//   _кечи, --, --, --, 
   {{0x290d04b7,0x9f5c0023,0x195504b8,0xd7f40961}},	//   _infa_, ërën_, _шашы_, _ауы_, 
   {{0xc864022e,0x00000000,0x00000000,0x00000000}},	//   _итқи, --, --, --, 
   {{0x427504b9,0x00000000,0x00000000,0x00000000}},	// [178d0] угас, --, --, --, 
   {{0xe084009f,0x03f800f3,0x00000000,0x00000000}},	//   نجاي, _зној_, --, --, 
   {{0x628c02e8,0x5184e07f,0x257001ec,0xdce80135}},	//   _tgco, рута, _مۇڭس, lqgħ, 
   {{0x628cb2f1,0x026003e6,0x00000000,0x00000000}},	//   _ugco, _هێزێ, --, --, 
   {{0xf07800fd,0x3ce40129,0xdce00115,0x81bc00fe}},	//   _җитә_, _pblv_, lonĉ, _আহক_, 
   {{0xbebc143f,0x4d6400d4,0x00000000,0x00000000}},	//   _plūs, аків, --, --, 
   {{0xbb44ed36,0x403401a9,0xd0840108,0x7afc00d7}},	//   лекк, _севс, _выти, ôsto, 
   {{0x290c016b,0xa5b801ed,0x37e401a9,0x00000000}},	//   _anfa_, gyók, қомг, --, 
   {{0xed4c0014,0xaa540063,0xdda8109a,0x00000000}},	//   _کھن_, лићу_, _італ_, --, 
   {{0x3f8c001e,0xdce001e4,0xd70800d1,0x673c0064}},	//   _hieu_, konĉ, چىدۇ_, _įpja, 
   {{0x3f8c1dd4,0xd7080075,0x7ad41208,0xdb202c26}},	//   _kieu_, نىدۇ_, _مقاص, _پوشی, 
   {{0x3f8c0a73,0x35a504ba,0x290d04bb,0xcb08009f}},	//   _jieu_, ламг, _enfa_, _ليمن_, 
   {{0x3f8d04bc,0x2b580165,0x00000000,0x00000000}},	//   _mieu_, épce_, --, --, 
   {{0x3f8d04bd,0xdce001e4,0xee7400df,0xfaf80064}},	//   _lieu_, fonĉ, טערז_, plūs_, 
   {{0x64a104be,0x2900016b,0x37e40209,0x00000000}},	//   саса, ɛka_, _сойг, --, 
   {{0x3f8d04bf,0x4990036b,0xdce80003,0x160801f0}},	//   _nieu_, _دییر, bqgħ, _амиқ_, 
   {{0x51441ac1,0x31080166,0x00000000,0x00000000}},	// [178e0] адағ, ннап_, --, --, 
   {{0xd5b8005f,0x7980015d,0xefcc0092,0xe1f4b689}},	//   ņās_, nmlw, _ጥለው_, ыгу_, 
   {{0x3f8d04c0,0x79800042,0x00000000,0x00000000}},	//   _bieu_, imlw, --, --, 
   {{0x3fb800dd,0xa2580798,0xfcc80092,0x798003ac}},	//   ئپنگ_, _idôn, _በሕገ_, hmlw, 
   {{0x3f8d04c1,0x00000000,0x00000000,0x00000000}},	//   _dieu_, --, --, --, 
   {{0x8f8402dd,0x00000000,0x00000000,0x00000000}},	//   уқұл, --, --, --, 
   {{0x3f8c07de,0x5ba001f4,0x00000000,0x00000000}},	//   _fieu_, брыз, --, --, 
   {{0x3f8c1570,0xe040694c,0xa0640798,0x00000000}},	//   _gieu_, _унси, _саса_, --, 
   {{0xddd816a3,0xfcc80092,0x00000000,0x00000000}},	//   _zguž, _በሕጉ_, --, --, 
   {{0xa6d8066a,0x7be80254,0x3e5002f2,0x00000000}},	//   miði, äsuõ, _بێهز, --, 
   {{0x6d4904c2,0xa6d82833,0xbebc0064,0x6c54003b}},	//   mifa, liði, _klūp, _стає, 
   {{0x7c240732,0x2900012d,0xa5b801d3,0xb6a00356}},	//   ähre, śka_, lyói, şând, 
   {{0x290c070d,0x2c4c03b9,0x30f400cd,0x25bc0332}},	//   _tnfa_, _həd_, ीयाः_, éul_, 
   {{0x6d4904c3,0x6b80063f,0xa50400d1,0xda6001a9}},	//   nifa, _ọgha, دىسە_, _увчи, 
   {{0x6d480421,0x00000000,0x00000000,0x00000000}},	//   iifa, --, --, --, 
   {{0xb9e00092,0x2c4c06be,0x461400f2,0x228400cf}},	//   _ሩቅ_, _məd_, _نوبر, гузг, 
   {{0x6d4904c4,0x3f84011c,0x80b4ad85,0xdce80135}},	// [178f0] kifa, _èlui_, ибах, qqgħ, 
   {{0x3f8d04c5,0x6d4904c6,0x51844ea5,0xc6a401b9}},	//   _sieu_, jifa, буха, _ёрқи, 
   {{0x200504c7,0x6d4904c8,0x25640014,0x3f8c0129}},	//   íni_, difa, _لاگُ, _pieu_, 
   {{0x672c068f,0x6d480549,0x6d540066,0x03540ce8}},	//   nkcj, eifa, éyan, _түбә_, 
   {{0xa3000348,0xfcc8001f,0x3f8cea9f,0x80dc00cd}},	//   _күңе, _በሕግ_, _vieu_, _पापे, 
   {{0x2c4c03e3,0x798003ac,0x00000000,0x00000000}},	//   _bəd_, xmlw, --, --, 
   {{0x3f8d04c9,0x3af401d5,0xfb580063,0xbae4007b}},	//   _tieu_, аяпс, крић_, لكثي, 
   {{0x6d4904ca,0xcc0828ec,0xa6d80174,0xfca800ec}},	//   aifa, ازون_, biði, راڻو_, 
   {{0x6d4904cb,0xcdc8167e,0x17c00588,0xedd80bd6}},	//   bifa, _مۇنۇ_, әамҭ, _илтә_, 
   {{0x39444e87,0x6d4904cc,0xf8641fbe,0x672c0210}},	//   рног, cifa, ивпо, ekcj, 
   {{0x37e4897a,0x00000000,0x00000000,0x00000000}},	//   шонг, --, --, --, 
   {{0x45f4031c,0xa2a4bde7,0xdce00135,0xcb0800ec}},	//   _བརྡས_, टुम्, konċ, _ٽيهن_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xddd80055,0xb79400f3,0x00000000,0x00000000}},	//   _syuś, _крић, --, --, 
   {{0xb6a504cd,0x29f4033f,0x98a001e0,0x67d0009b}},	//   _кийл, _zła_, _киҙе, _доју, 
   {{0x6d483ae4,0x733405a9,0xa7a407d5,0x00000000}},	//   zifa, جىرا, _ткъа_, --, 
   {{0xe2947196,0x6d482dab,0x7c3c03b9,0x644002d2}},	// [17900] рау_, yifa, _əsra, _ýnin, 
   {{0x7bc0013c,0x6d4904ce,0x00000000,0x00000000}},	//   _ovlu, xifa, --, --, 
   {{0x6d48d627,0x3d1862a8,0xeef40166,0x20840395}},	//   vifa, पाने_, иядэ, айфи_, 
   {{0xf1a800aa,0xeda504cf,0x6d4904d0,0xa8540375}},	//   _لاسه_, ашко, wifa, ביעה_, 
   {{0x3ea904d1,0x6d4904d2,0x7bc003e0,0x2c4c03b9}},	//   ñata_, tifa, _avlu, _səd_, 
   {{0x80dc2c07,0x2b4400a3,0xa6d80ad9,0xebc40063}},	//   _पाये, _smoc_, riði, аљин, 
   {{0x6d4904d3,0xb6040219,0x80ac015b,0x2c4c06be}},	//   rifa, ljšč, _চাচ্, _qəd_, 
   {{0x6d4904d4,0x3ce807f5,0x78ac01a6,0x2c4c0213}},	//   sifa, đava_, _đava, _vəd_, 
   {{0xb6041dd5,0x6d4904d5,0x80dc00e1,0x6f0400e5}},	//   njšč, pifa, _पामे, gébő, 
   {{0x273904d6,0xd05c01e4,0x6d48022f,0x9d4001ec}},	//   _këng_, _parɨ, qifa, _деуд, 
   {{0x6d58047e,0xa5b80af2,0xe8b40073,0xa09400df}},	//   _ijta, nyóv, _आजीच, ידיק_, 
   {{0x6f0104d7,0x27380036,0xa76000a2,0x29f4012d}},	//   ndoc, _mëng_, _ötüň_, _tła_, 
   {{0x6aa104d8,0x7aed04d9,0x6994034b,0x6d5800b5}},	//   _ifof, _ñata, _трех, _kjta, 
   {{0x58d00364,0x3d18fad5,0xc5e8009e,0x590c0327}},	//   _дошт, पाये_, খিলা_, _ཏོགས_, 
   {{0x6f0001f5,0xf84401f0,0x00000000,0x00000000}},	//   kdoc, _гӯяд_, --, --, 
   {{0x29000374,0x00000000,0x00000000,0x00000000}},	//   ēkau_, --, --, --, 
   {{0x6f0104da,0xe4e40212,0x228401d5,0x00000000}},	// [17910] ddoc, _кінн, рувг, --, 
   {{0x6f0104db,0x291c0023,0x04880139,0x00000000}},	//   edoc, njta_, _бәби_, --, 
   {{0x6f00009f,0x80dc095f,0x6aa104dc,0x2ee401a9}},	//   fdoc, _पाठे, _ofof, ffof_, 
   {{0x273904dd,0x80b4012c,0x9f9c0036,0x6f0001ab}},	//   _dëng_, इरहे, léën_, gdoc, 
   {{0xa2580109,0xa3d002db,0x00000000,0x00000000}},	//   _kdôm, हूर_, --, --, 
   {{0x6aa104de,0x6f000268,0x68e80158,0x1fa504df}},	//   _afof, adoc, _nbfd, _враг, 
   {{0xf07818ce,0x6f0001a4,0xa6d80321,0x27380240}},	//   _бирә_, bdoc, liðu, _kënd_, 
   {{0x8ee80075,0x27380694,0x545800d9,0x6f0401d3}},	//   _نېمە_, _jënd_, יסון_, tébő, 
   {{0x7f480869,0x3ebc0309,0x394401b9,0x2738036e}},	//   _imeq, mawt_, йниг, _mënd_, 
   {{0xe8f504e0,0x9be410f5,0x2738002e,0x69c00301}},	//   бль_, _відк, _lënd_, _dvoe, 
   {{0x7bc00357,0x37880323,0xc68804ae,0xba4401ed}},	//   _uvlu, лбоо_, _נא_, شنگٹ, 
   {{0x29180086,0x291c036e,0x81bc0154,0xdb080244}},	//   _òpan_, ajta_, _ইমন_, _جزئه_, 
   {{0x61ec0205,0x00000000,0x00000000,0x00000000}},	//   _npcl, --, --, --, 
   {{0xdce023e2,0x7d000bfa,0x6f0000d0,0xdb00007c}},	//   konč, _jals, zdoc, gsnö, 
   {{0x7d0104e1,0x69c00099,0x61ec03ac,0x799904e2}},	//   _mals, _zvoe, _apcl, _huww, 
   {{0xdce02f61,0x7d000083,0x799800ee,0x3d1801ad}},	//   donč, _lals, _kuww, पाडे_, 
   {{0x7d00ef74,0x2738226d,0x3a2c065c,0x06740150}},	// [17920] _oals, _sëng_, nyep_, _ونىڭ, 
   {{0x7d000455,0x7998017a,0x6f0000a3,0xdb0000d7}},	//   _nals, _muww, wdoc, dpní, 
   {{0x27380036,0xa4f80a1e,0xdce00010,0x04a400b8}},	//   _fënd_, _גליט, gonč, _nāṭi, 
   {{0xee3904e3,0x7d0104e4,0x80dc27c6,0x00000000}},	//   лне_, _aals, _पाथे, --, 
   {{0x7d0104e5,0x7998011f,0xf17004d3,0x4c940108}},	//   _bals, _nuww, _فێرگ, оилс, 
   {{0xcab40729,0x7f4904e6,0x6f0001a4,0x8c3c013d}},	//   _টাইফ, _emeq, sdoc, _afğa, 
   {{0x4adc5cea,0xa134008f,0x80dc0a59,0x69c00139}},	//   _यादव, _פאלק_, _पाते, _svoe, 
   {{0x7d00127b,0x69c40219,0xa2c808ec,0xdcac0150}},	//   _eals, škem, तृप्, _ۋىق_, 
   {{0x7d0104e7,0xa9280046,0xdcec0115,0xce5400e5}},	//   _fals, гіне_, _ŝeĥe, _بھاب, 
   {{0x7d0104e8,0xa3d0007d,0x7998198f,0x6d580784}},	//   _gals, हूँ_, _duww, _ujta, 
   {{0x6aa001af,0xab940597,0xdb00007c,0x00000000}},	//   _tfof, _الصغ, vsnö, --, 
   {{0x6aa104e9,0x00000000,0x00000000,0x00000000}},	//   _ufof, --, --, --, 
   {{0xe6641342,0x2a7400db,0x291c0309,0x799800a2}},	//   стно, _اداح, pjta_, _guww, 
   {{0xa6d80436,0x7d00011f,0x2900005f,0x27380036}},	//   viðu, _xals, ēkas_, _sënd_, 
   {{0xa3d00bb2,0x6b9835fb,0x0ed81715,0x273800e8}},	//   हूं_, _jutg, _डांड, _pënd_, 
   {{0x6b9804cc,0xdb0001e6,0x45d4781e,0x788000e4}},	//   _mutg, ssnö, _доис, sãvé, 
   {{0x6b9904ea,0x3c7c0131,0x27380240,0xd05c0213}},	// [17930] _lutg, ﻤﯩﺴﻰ_, _vënd_, _ibrə, 
   {{0xa6d80321,0xdce04b16,0x6b986460,0x9f9d04eb}},	//   riðu, tonč, _outg, léén_, 
   {{0x273802d3,0x3ea804d4,0xdd3003b9,0x7d0001ef}},	//   _tënd_, ñato_, _aşşu, _rals, 
   {{0xa6d809f3,0x9f9c0de2,0xdce00010,0x00000000}},	//   miðs, néén_, ronč, --, 
   {{0x7d0104ec,0x2738002e,0xdce104ed,0x00000000}},	//   _pals, _gëne_, sonč, --, 
   {{0xc3000d42,0x78ac0552,0x6b9904ee,0x799801f5}},	//   _একটি_, _đavo, _butg, _ruww, 
   {{0x7d0104ef,0x6b9805d5,0x79980429,0x61380356}},	//   _vals, _cutg, _suww, _cîle, 
   {{0x7d0104f0,0x6b9805d5,0x7f480194,0xf9c816c0}},	//   _wals, _dutg, _umeq, агик_, 
   {{0x7d0104f1,0x79980a2e,0xce94011c,0x00000000}},	//   _tals, _quww, _хауъ, --, 
   {{0xae400014,0x0dc80114,0x00000000,0x00000000}},	//   _تھٔو, _ћути_, --, --, 
   {{0x4aa80228,0x6b980e78,0x0ca8074d,0x00000000}},	//   шкөн_, _gutg, _ытти_, --, 
   {{0x78a0074d,0x7c3c00ac,0x9f9c002e,0xe1fc01e1}},	//   sclv, _əsrl, géén_, _osó_, 
   {{0x7ae854d9,0x6b9805d5,0xcb682e6f,0xe1fc01e1}},	//   mfet, _zutg, _امنه_, _nsó_, 
   {{0x6b5c005f,0x896402dd,0x6b9801d5,0x00000000}},	//   mīga, _екіж, _yutg, --, 
   {{0x6b5c005f,0xa2c800cd,0x00000000,0x00000000}},	//   līga, तृभ्, --, --, 
   {{0xe29504f2,0x7ae904f3,0x09ac00fe,0x00000000}},	//   жат_, nfet, _খিতা, --, 
   {{0x312504f4,0x6b5c005f,0xbb9c02dd,0xb064013d}},	// [17940] одаг, nīga, _ﺇﻟﻴﻪ_, kläü, 
   {{0x7ae904f5,0x63c0005c,0x00000000,0x00000000}},	//   hfet, ævnæ, --, --, 
   {{0xb4d41533,0x7ae904f6,0x78ac107d,0x7f580175}},	//   हली_, kfet, _đavl, fnwq, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6b9807de,0x6df8013d,0xad64007b,0x21fc037e}},	//   _sutg, рхес_, ياته, のhp_, 
   {{0x6b9805d5,0x6b5c00e2,0x00000000,0x00000000}},	//   _putg, dīga, --, --, 
   {{0x7ae904f7,0x6b98022e,0x39340092,0x00000000}},	//   ffet, _qutg, _ይለያያ, --, 
   {{0x7df40075,0xddd803ee,0xf3f801e1,0x9b84009a}},	//   تقۇچ, _uyuş, _rẹ̀_, ينول_, 
   {{0x06d80154,0xddc00f06,0x00000000,0x00000000}},	//   _তসলি, _обти, --, --, 
   {{0x6b9904f8,0x7ae904f9,0x998031ed,0xa29802d3}},	//   _tutg, afet, وليو, ዋትናን_, 
   {{0xeb980cfc,0xca740f1c,0xfa5401d5,0x00000000}},	//   _тие_, _کنشک, قریگ, --, 
   {{0x84ec000d,0x57a000c7,0x6b5c00de,0x00000000}},	//   _चउहट_, ьшьа, bīga, --, 
   {{0x95d805cc,0x6b800223,0xa504224f,0x6b5c005f}},	//   одят_, _ihog, оявл, cīga, 
   {{0xdce00118,0xb86504fa,0xa6d803b2,0x00000000}},	//   dlně, _کاهو, tiðs, --, 
   {{0x99801d0a,0x5558026b,0xdd0000cd,0x00000000}},	//   _تلوو, царя_, _śrīv, --, 
   {{0xc2981220,0xa34401c6,0x3d10012d,0x5ab4010f}},	//   сках_, цэгл, _धोने_, ַלבע_, 
   {{0x2be4015b,0x6b8000e3,0xd78801c8,0xa6d803b2}},	// [17950] কিয়ে_, _mhog, _بنيو_, siðs, 
   {{0xe1fc02d2,0x00000000,0x00000000,0x00000000}},	//   _vsó_, --, --, --, 
   {{0x7e98742b,0x0fe400f7,0x6b8000e4,0xd1080fb4}},	//   منار_, мөтү, _ohog, تقله_, 
   {{0x443009a5,0x80dc00af,0x00000000,0x00000000}},	//   myz_, _पावे, --, --, 
   {{0xe1fc0407,0x2284011c,0xd1c801f0,0xfaa400c7}},	//   _usó_, _фунг, _мурд_, ҟапо, 
   {{0x6b8000dd,0xd658011a,0x518401ec,0x00000000}},	//   _ahog, חידת_, _жуса, --, 
   {{0x6b8104fb,0x44300209,0xe0542a77,0xdce00171}},	//   _bhog, nyz_, _بیات_, gonā, 
   {{0x6b8104fc,0xba2504fd,0x6b5c00e2,0x4fc401ec}},	//   _chog, здик, tīga, _ісса, 
   {{0x7ae88a3a,0x6b80058a,0x644003e0,0xa2a00037}},	//   rfet, _dhog, _ünif, _छ्छ्, 
   {{0xa2c81152,0x7ae82bb3,0x6b5c005f,0x3988002d}},	//   तृत्, sfet, rīga, _nźst_, 
   {{0x6b800fa3,0x7ae904fe,0x9be40111,0x00000000}},	//   _fhog, pfet, _фізк, --, 
   {{0x3d1810f7,0x6b800978,0x46f00131,0x6b5c00e2}},	//   पावे_, _ghog, نۋىر, pīga, 
   {{0x613104ff,0xa6e00321,0xbebc00de,0x393400c0}},	//   _kılı, óðas, _blūz, _нэкс, 
   {{0xb4d50500,0xdce000bc,0x4430010e,0x00000000}},	//   हले_, vlně, fyz_, --, 
   {{0x443000ee,0x2934008f,0xb9d00023,0xd348006c}},	//   gyz_, _מאסן_, _ጻማ_, قیده_, 
   {{0xc7a83669,0xe86401c0,0xe73c0022,0xb5c401d5}},	//   _بدول_, _эхчү, chõ_, _ейил, 
   {{0x63b805be,0x6260ad0e,0xd5a4136e,0x00000000}},	// [17960] ćuna, евта, _تلخی, --, 
   {{0xb0980212,0xa680010b,0x64640036,0x443000a2}},	//   стає_, _ялыд, érié, byz_, 
   {{0x80dc012c,0x27380240,0x7c240e78,0xf408007b}},	//   _पारे, _hëna_, ährl, _ايجى_, 
   {{0xdce00316,0x98a4012c,0xe040009d,0x00000000}},	//   plně, _plně_, энхи, --, 
   {{0xddc80365,0x26c4013b,0x61300790,0xfe7400b1}},	//   ğişi, _ɛno_, _bılı, дүт_, 
   {{0x6b810501,0xf1a8021a,0x61302523,0x27381574}},	//   _shog, _پاڼه_, _cılı, _mëna_, 
   {{0x6b80062c,0xa6c40154,0x61300205,0x2738036e}},	//   _phog, ষ্টট, _dılı, _lëna_, 
   {{0xb0e00073,0x9b6400c7,0x602001c4,0x00000000}},	//   _पाडग, зшьа_, _ядса, --, 
   {{0x273802d3,0xee38798c,0xda740276,0x61300205}},	//   _nëna_, _уна_, зяэ_, _fılı, 
   {{0xdca03f1c,0x88580276,0x6cd41291,0x00000000}},	//   _зафи, жиос_, _رقصا, --, 
   {{0x6b805da8,0xe29c08ce,0xbb7000f7,0x00000000}},	//   _thog, _laða_, رۇۇع, --, 
   {{0x32000419,0x4d8801f7,0x00000000,0x00000000}},	//   _osky_, _اَڄُ_, --, --, 
   {{0x613104ff,0x80dc28a2,0xa96803c5,0xa2c81408}},	//   _yılı, _पाले, _лида_, तःस्, 
   {{0xd90c0022,0x00000000,0x00000000,0x00000000}},	//   _џь_, --, --, --, 
   {{0x189400c6,0xd7ec0daf,0xdce00356,0x00000000}},	//   _عضوة_, _яу_, lonă, --, 
   {{0x44300408,0x68f8e73c,0xe29c032e,0xc1b8009d}},	//   ryz_, letd, _baða_, жлах_, 
   {{0x44300209,0x27381574,0x61400ca8,0x6d440153}},	// [17970] syz_, _gëna_, _nílù, _įkan, 
   {{0x257c00d2,0x32000175,0x55bc02e4,0x68f8371e}},	//   bîla_, _dsky_, _המזו, netd, 
   {{0x32000356,0x4adc0829,0x27380200,0x00000000}},	//   _esky_, _यांव, _zëna_, --, 
   {{0xac7802d3,0x61300205,0x68f87cd9,0x212401e2}},	//   _ኣቢሎም_, _sılı, hetd, _کيسی_, 
   {{0x68f90502,0xc0c40022,0x3d18012c,0xceac00fb}},	//   ketd, _жәеи, पाले_, _ҙҙ_, 
   {{0x6130467d,0xceac0032,0x147402dd,0xc0d40023}},	//   _qılı, _әҙ_, _تاۋج, _ከቢሩ_, 
   {{0x8d740214,0xbb840b24,0x68f88021,0x00000000}},	//   راها, ولتي, detd, --, 
   {{0xdc700022,0x00000000,0x00000000,0x00000000}},	//   мықь, --, --, --, 
   {{0xfaf800b0,0xa9e0004b,0xe9a401d5,0x68f8a75a}},	//   reū_, نګون, وگون_, fetd, 
   {{0x9ba02ba5,0x2738036e,0x4c1400d1,0x6b5c00ef}},	//   _كەتى, _rëna_, ببۇس, bīgo, 
   {{0xb9040acd,0x6d6800f1,0x6b5c0171,0x00000000}},	//   _फा_, _بللې_, cīgo, --, 
   {{0xa5b800e4,0xe7340108,0x3d100210,0x00000000}},	//   tyóp, дею_, _धोते_, --, 
   {{0x68f86590,0xa25800d0,0xca740064,0x00000000}},	//   betd, _zdôv, _пушы, --, 
   {{0x2738036e,0xe29c01a8,0x68f8008e,0xf98800ae}},	//   _vëna_, _raða_, cetd, _بنتي_, 
   {{0x64a10503,0xf7f401d5,0xe970007b,0xa5b80022}},	//   таса, _آستد, _جهود, syóp, 
   {{0x9f9c002e,0x27390504,0xf1d0004e,0x00000000}},	//   _gééj_, _tëna_, көгө, --, 
   {{0x273804e6,0x69c42ba4,0x59280327,0xd3481550}},	// [17980] _kënn_, škev, _ཧྭོས_, قیگه_, 
   {{0x64400327,0xdb00000d,0xe29c08a5,0x00000000}},	//   _żnie, lpnä, _vaða_, --, 
   {{0x251804ac,0xb3850505,0x27380de2,0xa3b800ec}},	//   _וויא, _олол, _mënn_, _واٽر_, 
   {{0xef187f54,0x68f90506,0xe29c03b2,0xdfcc2372}},	//   юме_, zetd, _taða_, شيه_, 
   {{0x68f90507,0xf1d801ad,0xeba803b2,0x00000000}},	//   yetd, यूशन, kløð_, --, 
   {{0x9d14013e,0xdc1003e0,0x00000000,0x00000000}},	//   дошт_, _ağıt, --, --, 
   {{0x68f90508,0x7fd40220,0x00000000,0x00000000}},	//   vetd, _піті, --, --, 
   {{0x4f8401d3,0x00000000,0x00000000,0x00000000}},	//   _سازہ, --, --, --, 
   {{0x273800e8,0x7c3c00ac,0x68f90509,0xfe74014b}},	//   _bënn_, _əsri, tetd, _пӯш_, 
   {{0x2d880295,0x764400d7,0xd1d00092,0x7bdc00cc}},	//   _òbe_, dzky, ሥረታ_, _মনৰো, 
   {{0x2738d909,0x68f9050a,0x00000000,0x00000000}},	//   _dënn_, retd, --, --, 
   {{0x274802bf,0x45d416a4,0xc8840139,0xcfc000cc}},	//   ічно_, номс, _ışı_, _উমান, 
   {{0x3ea9050b,0x68f800ee,0xeba806ea,0xe4e400d4}},	//   ñati_, petd, bløð_, мівн, 
   {{0x27380de2,0x85b4013d,0x68f806be,0x00000000}},	//   _gënn_, мәүч, qetd, --, 
   {{0x7af401ed,0x63b80960,0x6d440024,0x6e2001d5}},	//   őzte, ćuno, _įkal, hxob, 
   {{0xf8ad050c,0x00000000,0x00000000,0x00000000}},	//   _پکی_, --, --, --, 
   {{0xa2c80303,0x91e400fb,0x00000000,0x00000000}},	// [17990] तृष्, кәрһ, --, --, 
   {{0x86b80014,0x01d400d1,0xa3d43507,0x00000000}},	//   _بُکر_, _ﺟﻪﻧﻨ, _सिप_, --, 
   {{0xd250004b,0x3ed5050d,0x7f1801ec,0x00000000}},	//   هنې_, فقار, зілу_, --, 
   {{0x273800e8,0x934406ed,0xca4c02dd,0x00000000}},	//   _mëno_, _анџе, _ﺍﺳﺎ_, --, 
   {{0x6e20401f,0x7aec0784,0xa1e8007b,0xfe7001d3}},	//   gxob, _ñati, _برجك_, اگز_, 
   {{0xf8dc000d,0x00000000,0x00000000,0x00000000}},	//   _माइय, --, --, --, 
   {{0xfaa5050e,0x0ca8036b,0x3154010f,0x27380200}},	//   найо, фтчи_, _טישן_, _nëno_, 
   {{0x27380a40,0xd498025d,0x8d740244,0xa3d47ef5}},	//   _sënn_, וכות_, _یالا, _सिन_, 
   {{0xfaa4035b,0x00000000,0x00000000,0x00000000}},	//   _ҟало, --, --, --, 
   {{0x5d14009a,0x00000000,0x00000000,0x00000000}},	//   _تبرز, --, --, --, 
   {{0x0c040050,0x45f4031c,0x698801e1,0x00000000}},	//   _لولُ, _བརྔས_, _ẹnúg, --, 
   {{0xf0900375,0x69b808e9,0x764401f4,0x395800e5}},	//   טני_, _शौकी, tzky, őss_, 
   {{0xf650158a,0xc0c802d3,0xd9f0000d,0xe8ec01c6}},	//   ائج_, ጠቕሰ_, _अहित_, _йл_, 
   {{0x682802d3,0x00000000,0x00000000,0x00000000}},	//   _ስጉምት, --, --, --, 
   {{0xba04067d,0x6c540248,0x00000000,0x00000000}},	//   _ገለ_, _kàlẹ, --, --, 
   {{0x2325050f,0xa854011a,0x5fa00037,0x00000000}},	//   носи_, _ריקה_, _ओढ़ल, --, 
   {{0x98a4007f,0x00000000,0x00000000,0x00000000}},	// [179a0] _lonč_, --, --, --, 
   {{0xddc805d1,0x26840bd6,0xc0c80023,0x00000000}},	//   _şişm, _ябып_, ጠቕሱ_, --, 
   {{0xa3d40243,0xe934010f,0xf8dc000d,0x00000000}},	//   _सिय_, ענעץ_, _माईय, --, 
   {{0x6844003e,0x888c008f,0x9ea47180,0xee840022}},	//   _hédé, קראַ, евца_, ныло, 
   {{0xdd8c004b,0x00000000,0x00000000,0x00000000}},	//   څون_, --, --, --, 
   {{0xdd8c1efa,0xafe4399f,0x98a402e2,0xa3d4547d}},	//   مون_, _погл, _bonč_, _सिम_, 
   {{0xa0641ece,0x6844a8d8,0x7e6c0135,0x00000000}},	//   _зара_, _médé, żapp, --, 
   {{0xeaf80214,0x39bc007f,0xfb84036b,0x00000000}},	//   سرعت_, fňs_, نگنی, --, 
   {{0x3d1000c5,0x00000000,0x00000000,0x00000000}},	//   _धोवे_, --, --, --, 
   {{0xa9a4013e,0x273800e8,0x00000000,0x00000000}},	//   _ҷидд, _pëno_, --, --, 
   {{0x6bd402e1,0xdd8c41ff,0x2d8c0165,0x2c8402d2}},	//   _ستار, _اول_, mmfe_, _dídí_, 
   {{0xa9a47075,0x2a640070,0xaa440798,0xdc38123b}},	//   _зидд, _txob_, _пеел, _מעבר, 
   {{0xe1fc0077,0x68440129,0x56941468,0x412c0023}},	//   _axón_, _bédé, лают, _ተዛሪቦ, 
   {{0x68450510,0x69c40024,0x00000000,0x00000000}},	//   _cédé, škes, --, --, 
   {{0xe6dc0521,0x68450511,0x3958180f,0x9980007b}},	//   _agụụ_, _dédé, èsse_, _حلوو, 
   {{0xd378074d,0x7c2403fa,0x6444002d,0x98780375}},	//   ечу_, ähri, rzji, _מרוק, 
   {{0x68450512,0x45f4031c,0x00000000,0x00000000}},	// [179b0] _fédé, _བརྒས_, --, --, 
   {{0x68440241,0xc0d400db,0xa088013d,0x00000000}},	//   _gédé, ئياب, псез_, --, 
   {{0xb0e03f2c,0x8f0001ec,0x00000000,0x00000000}},	//   _पारग, зiр_, --, --, 
   {{0x6374145e,0xa5b80694,0x80dc0acd,0x00000000}},	//   _dûnî, nxóo, _पाके, --, 
   {{0xdd9834d8,0xfce40f4e,0x8e7400cf,0x00000000}},	//   чше_, воло, лушч, --, 
   {{0xada00131,0x6e340158,0x6c5401e1,0x6da00b01}},	//   шашл, øyba, _sàlẹ, шиша, 
   {{0x6c500063,0xbb443004,0x2c8401e1,0x00000000}},	//   икљу, кекк, _rídí_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3eac0472,0xa2580030,0x80c4000d,0x00000000}},	//   _ifet_, _zdôr, _लजाइ, --, 
   {{0x45f4025c,0x6d5c00b0,0x00000000,0x00000000}},	//   _བརྟས_, ōpar, --, --, 
   {{0xf74476ac,0x00000000,0x00000000,0x00000000}},	//   вено, --, --, --, 
   {{0x7a390513,0x684400e8,0x39bc007f,0xda10bb12}},	//   _опер_, _sédé, pňs_, _مستک, 
   {{0x69c40316,0x6844a8d8,0x00000000,0x00000000}},	//   šker, _pédé, --, --, 
   {{0xa3bc0034,0x0d84030d,0x66000a5b,0x00000000}},	//   ुओं_, _улĕн, јпра, --, 
   {{0x3eac1529,0xa96407a5,0x00000000,0x00000000}},	//   _ofet_, _шиша_, --, --, 
   {{0xe29c02d2,0x00000000,0x00000000,0x00000000}},	//   _faðm_, --, --, --, 
   {{0xf558007b,0x00000000,0x00000000,0x00000000}},	// [179c0] _يلعب_, --, --, --, 
   {{0x309402dd,0xe0d50514,0xe57400c7,0x3eac0790}},	//   نشاس, кву_, _изы_, _afet_, 
   {{0x3dcc02e2,0xb4bc0307,0xfc240eff,0xafe468eb}},	//   _avew_, आरी_, _اڭ_, тоел, 
   {{0xa3d40316,0xdef40724,0x3eac0332,0x00000000}},	//   _सित_, выш_, _cfet_, --, 
   {{0xdee10515,0x0cd4a4c9,0x00000000,0x00000000}},	//   рочи, голю, --, --, 
   {{0x3ead0516,0x6fb400c6,0xabb00022,0x2d8d0517}},	//   _efet_, _لمسا, аакә, umfe_, 
   {{0x7e690518,0x1fa402a9,0x70dc924b,0x6b5c00e2}},	//   _exep, _акси_, मलील, līgi, 
   {{0xf9a80241,0x9f900150,0x7f74009d,0x00000000}},	//   _tiẹ̀_, _ﺑﺎﻳﻞ_, _бууц, --, 
   {{0xada42b39,0x6da41914,0x49750519,0x6cc40f15}},	//   _разл, _риза, ллис, _айза, 
   {{0xd914023a,0x5ce000db,0x69dc00b8,0x00000000}},	//   вью_, _ەكەل, _āped, --, 
   {{0x1890001f,0xdca1051a,0x29080030,0x63b801a6}},	//   _መናገር_, _тахи, ľba_, ćunk, 
   {{0x2908ceba,0xdc240451,0x5c34010f,0x00000000}},	//   žba_, _جڳهه_, _שטאב_, --, 
   {{0x84c4804b,0x9f444056,0xb0e0044b,0x09ac00cc}},	//   ләнд, îné_, _पांग, _খিকা, 
   {{0x8e200220,0x6b5c00e2,0xe4c4005b,0x38680055}},	//   лiк_, dīgi, ъёмн, _śare_, 
   {{0xd82d051b,0xd8040022,0x00000000,0x00000000}},	//   _тэ_, _ахыл_, --, --, 
   {{0x7aec1574,0x534400c7,0xd7f4014b,0x00000000}},	//   _ñatt, ахуа, _руш_, --, 
   {{0x20c4023a,0x9259051c,0x3ea401b9,0xd23402e8}},	// [179d0] всег, ватт_, қилг, антъ, 
   {{0x98a404fe,0x00000000,0x00000000,0x00000000}},	//   _konā_, --, --, --, 
   {{0xa28001ed,0x83f80798,0x4614072d,0x00000000}},	//   _چیزو, _џемс_, _شوگر, --, 
   {{0x45f40135,0x98a400b0,0xe29c02d2,0x6d54007f}},	//   _བརྙས_, _monā_, _maðk_, èyan, 
   {{0x918403cc,0x9e0400db,0x6b5c00de,0x00000000}},	//   _چۇقۇ, ئفتە_, cīgi, --, 
   {{0x80dc21bd,0x00000000,0x00000000,0x00000000}},	//   _पाटे, --, --, --, 
   {{0xbbf400c6,0x6bd402f2,0x00000000,0x00000000}},	//   استث, هووس_, --, --, 
   {{0x7e6801c4,0x6ca400f7,0x00000000,0x00000000}},	//   _txep, _ۅلكۅ, --, --, 
   {{0xdd900184,0x3b0c013c,0x2bac033f,0xef6401c0}},	//   _ҡағы, rdeq_, _ręce_, _сэрү, 
   {{0xd90c04fb,0x3b0c0477,0xe9d400c7,0x00000000}},	//   زیع_, sdeq_, ыкь_, --, 
   {{0xe7b0036b,0x00000000,0x00000000,0x00000000}},	//   یمید, --, --, --, 
   {{0xd1ec0020,0xf744656c,0x6d440006,0x7c2417da}},	//   ቅረብ_, уемо, _įkai, ähru, 
   {{0x6fa800e1,0x00000000,0x00000000,0x00000000}},	//   _जूनू, --, --, --, 
   {{0xf5043596,0xe5a1051d,0x7334525b,0xa25800d8}},	//   ызго, сири, گىرا, _peôn, 
   {{0x7aec0086,0x611800ef,0xb6a4010a,0x53c40150}},	//   _ñats, _mālē, _йийл, рабұ, 
   {{0xe7b016ef,0x73341178,0x836401d5,0x87f80153}},	//   _اميد, دىرا, لدقل, _рэшт_, 
   {{0x98a400e2,0xd7dc0073,0x00000000,0x00000000}},	// [179e0] _zonā_, पूरच, --, --, 
   {{0x6da402a9,0x6b5c00e2,0x6ea400c5,0x00000000}},	//   ҳида, rīgi, _छलहु, --, 
   {{0xdfcc00c6,0xd00400c7,0x00000000,0x00000000}},	//   كيل_, роеқ, --, --, 
   {{0x6da407d6,0xd1740032,0xada401c0,0x27380de2}},	//   гида, уығы, гадл, _rënk_, 
   {{0xee380323,0xed58b15a,0x00000000,0x00000000}},	//   энд_, нод_, --, --, 
   {{0xa0a1051e,0x3ec80421,0xbebc002b,0x611800ef}},	//   _гард, _āutū_, _anūd, _cālē, 
   {{0x2165051f,0x00000000,0x00000000,0x00000000}},	//   _сири_, --, --, --, 
   {{0x7c64007b,0x00000000,0x00000000,0x00000000}},	//   جاهل, --, --, --, 
   {{0x65680241,0x00000000,0x00000000,0x00000000}},	//   _ìghg, --, --, --, 
   {{0x6f010520,0x98a40618,0x27380694,0x18b400c7}},	//   leoc, _ponā_, _tënk_, лгьы_, 
   {{0xfca831f6,0x2d9d0521,0x7bc00036,0x39580ba1}},	//   _شالو_, _iite_, _gwlu, èssa_, 
   {{0x2d9d0522,0x2ee405e4,0x18840220,0x611800e2}},	//   _hite_, ngof_, ысып_, _zālē, 
   {{0x2d9d0523,0x58c00183,0x3d180073,0x96440139}},	//   _kite_, _শাৰী, पाचे_, бэрд, 
   {{0x273800e8,0x6f010524,0x2d9c0055,0xdce001ef}},	//   _mëni_, heoc, _jite_, doně, 
   {{0x6aa000fb,0xe3881214,0xa6e003b2,0x00000000}},	//   _kgof, ещал_, íðst, --, 
   {{0x2d9c6afa,0x290d0525,0x00000000,0x00000000}},	//   _lite_, _hafa_, --, --, 
   {{0x290d0526,0x26c90527,0xc298e29b,0x257c025a}},	// [179f0] _kafa_, maco_, тках_, hîli_, 
   {{0x2d9d0528,0x26c846bb,0xf1d82ba2,0xa4fc0327}},	//   _nite_, laco_, यंजन, _ཞིིག_, 
   {{0x290d0529,0x31f4031c,0x6b5c00e2,0x6aa1052a}},	//   _mafa_, _པདྨར_, līgu, _ogof, 
   {{0x290cc0dc,0x2d9d052b,0x6aa1052c,0x273802d3}},	//   _lafa_, _aite_, _ngof, _bëni_, 
   {{0x2d9d052d,0x00000000,0x00000000,0x00000000}},	//   _bite_, --, --, --, 
   {{0x6aa0013f,0x290d052e,0x2d9d052f,0xb0e0033f}},	//   _agof, _nafa_, _cite_, _पाएग, 
   {{0x2d9d0530,0x26c90531,0x7c2801c6,0x00000000}},	//   _dite_, kaco_, тойг_, --, 
   {{0x60c400c8,0x290d0532,0x2d9c12ef,0xcb58022e}},	//   _hejm, _aafa_, _eite_, tuvс, 
   {{0x2d9d0533,0x290c6f16,0xe29c148b,0x39442c11}},	//   _fite_, _bafa_, _baði_, иниг, 
   {{0x6aa00421,0x290cc0b7,0x2d9d0534,0x60c50535}},	//   _egof, _cafa_, _gite_, _jejm, 
   {{0x290c3d27,0x3ad50536,0x60c4047e,0xe29c08a5}},	//   _dafa_, _نياز, _mejm, _daði_, 
   {{0x3a750537,0x2d9d0538,0x26c801e4,0xf7706d69}},	//   _клер, _zite_, gaco_, تاخ_, 
   {{0x290d0539,0xb5201df1,0x2d9d053a,0x35a401c6}},	//   _fafa_, मालय_, _yite_, рагг, 
   {{0x290d053b,0x60c5053c,0x6f000210,0xe9d40150}},	//   _gafa_, _nejm, zeoc, _ткш_, 
   {{0x37e5053d,0x69c00d27,0xf771053e,0xf6d40064}},	//   _тойг, _zwoe, _واب_, _кіпя, 
   {{0xa3d41d15,0x26c80798,0x290c0117,0xa25805da}},	//   _सिर_, caco_, _zafa_, _teôl, 
   {{0x60c5053f,0xb2250540,0x290c0a49,0x6b5c0171}},	// [17a00] _bejm, шмал, _yafa_, cīgu, 
   {{0xa6380375,0x290c01b9,0x798003cb,0x6fb4007b}},	//   _סגיר, _xafa_, nllw, لمطا, 
   {{0x2d9c0325,0x60c50541,0x3f8c01ab,0x98a40276}},	//   _rite_, _dejm, _bheu_, _zonă_, 
   {{0x2d9d0542,0xee390543,0x3f8d0544,0xbebc00b8}},	//   _site_, кне_, _cheu_, _anūb, 
   {{0x2d9d0545,0x257c00d2,0xdcf80166,0x77640472}},	//   _pite_, wîli_, _atuı, inkx, 
   {{0x3f8d0546,0x60c4009b,0x26c8e7f6,0x2d9c036e}},	//   _eheu_, _gejm, zaco_, _qite_, 
   {{0x2d9d0547,0x26c90548,0xcc2400bd,0x69c00af9}},	//   _vite_, yaco_, বন্ধ_, _swoe, 
   {{0x290d0549,0x2d9d054a,0xdee000e4,0x7981054b}},	//   _safa_, _wite_, _моси, ellw, 
   {{0x2d9d054c,0x26c9054d,0x290d054e,0x442401f2}},	//   _tite_, vaco_, _pafa_, ̣l_, 
   {{0x2d9d054f,0x290d0550,0x26c90551,0x7764009a}},	//   _uite_, _qafa_, waco_, enkx, 
   {{0x290d0552,0xe7840ce4,0xdebc0131,0xeb3400db}},	//   _vafa_, иумо, ﮬﻪﺑﺒ, _پىشد, 
   {{0x77640175,0x6b5c00e2,0xdea80051,0xe9d8022e}},	//   gnkx, tīgu, nngư, _акд_, 
   {{0x26c90553,0x290d0554,0x842404a9,0x2b440ffb}},	//   raco_, _tafa_, ڭىزن, _iloc_, 
   {{0xe3b02885,0x26c90555,0x290d0556,0x6d480007}},	//   قرر_, saco_, _uafa_, nhfa, 
   {{0x26c90557,0x6d480007,0x2b4405c7,0x60c40455}},	//   paco_, ihfa, _kloc_, _rejm, 
   {{0x442c04b9,0x60c50558,0x26c80481,0x9f501ae4}},	//   će_, _sejm, qaco_, üdür_, 
   {{0xa0a4084c,0x3f8c030a,0x7538002f,0x00000000}},	// [17a10] ашел, _rheu_, ötzc, --, 
   {{0x2b440372,0x60c4014f,0x3f8c062c,0x21ec002f}},	//   _lloc_, _qejm, _sheu_, rüh_, 
   {{0x60c50559,0x6d49055a,0x00000000,0x00000000}},	//   _vejm, dhfa, --, --, 
   {{0x81a802f5,0x60c4016d,0x00000000,0x00000000}},	//   _গৌণ_, _wejm, --, --, 
   {{0x60c5055b,0x9e05055c,0xbebc00b8,0xcda801b9}},	//   _tejm, рчел, _anūc, لهنه_, 
   {{0x6d49055d,0x25dc05d7,0xe1fc01e1,0x4b1800e5}},	//   ghfa, _कटनी_, _ipó_, یکنگ_, 
   {{0x2b45055e,0x81b800fe,0x3f8d055f,0x81e8015b}},	//   _bloc_, _ঘটি_, _theu_, _মনি_, 
   {{0x1ee48a54,0x386800f3,0x2b450560,0xdcf47225}},	//   _خوری_, _ćar_, _cloc_, ıcıy, 
   {{0x2738002e,0x6d48007b,0xdb0c0248,0x00000000}},	//   _jënu_, bhfa, _àdír, --, 
   {{0x39447da1,0x6d490561,0xe1fc0085,0x81b804c5}},	//   сног, chfa, _mpó_, _ঘটা_, 
   {{0xb6a41b6d,0x2b450562,0xe7a401c6,0x79800042}},	//   йинл, _floc_, йвэл_, rllw, 
   {{0x2bf404ae,0x2b444e18,0xe1fc0248,0x79800142}},	//   _למען_, _gloc_, _opó_, sllw, 
   {{0x3a290563,0x7ae826be,0x20280092,0x00000000}},	//   _çap_, mget, _ተዋቅረ, --, 
   {{0x2e4c063f,0x00000000,0x00000000,0x00000000}},	//   wọkọ_, --, --, --, 
   {{0xe1fc0248,0xe29c0413,0xb86400ec,0x00000000}},	//   _apó_, _maðu_, _ھاڻو, --, 
   {{0x7ae90564,0x273800e8,0x762400f3,0x00000000}},	//   nget, _bënu_, _гмиз, --, 
   {{0x716805f5,0x7ae80cf0,0xb1441d0f,0x86e90565}},	// [17a20] гааг_, iget, бнал, _ضعيف_, 
   {{0xe2940046,0x7ae8b188,0x98a40064,0x1da8012d}},	//   сау_, hget, _foną_, _चढ़त, 
   {{0x7ae809f6,0x00000000,0x00000000,0x00000000}},	//   kget, --, --, --, 
   {{0xceb8052f,0xb8f8025c,0x7ae801f5,0x87ac010f}},	//   рҙа_, _འཇ_, jget, דשאַ, 
   {{0x6d490566,0x2738002e,0xb638019b,0xdce001e4}},	//   thfa, _gënu_, _ｄｓ_, sonĝ, 
   {{0x273801c7,0x2b450567,0x6da40022,0xebc40063}},	//   _hënt_, _sloc_, _ҳиаа, бљин, 
   {{0x7ae803fa,0x273804e6,0x2b450568,0xfd9801e0}},	//   fget, _kënt_, _ploc_, рөтә_, 
   {{0x6d490569,0x7ae89ff4,0xada401c0,0x95080327}},	//   shfa, gget, _гаал, _ཆིའི_, 
   {{0x2b4405c7,0x27380200,0x00000000,0x00000000}},	//   _vloc_, _mënt_, --, --, 
   {{0x273800e8,0x3cf00030,0x7ae80334,0x984c08a9}},	//   _lënt_, ľový_, aget, _aşıp_, 
   {{0x6c8493d2,0x6d59056a,0x3cf002fb,0x7ae80175}},	//   _الام, _imta, žový_, bget, 
   {{0xf3f43aaf,0xa098008f,0x2b440165,0xa3c8447d}},	//   _བྱེད_, טייט, _uloc_, रीफ_, 
   {{0xa3c8068f,0x6a840032,0x6a148863,0x5fac0b4c}},	//   रीन_, _улда, _دبار, _जूनल, 
   {{0x98a400c0,0xa85001ee,0xdec801f3,0x00000000}},	//   _poną_, _нелә, ጠትና_, --, 
   {{0x753804cc,0x00000000,0x00000000,0x00000000}},	//   ötza, --, --, --, 
   {{0x8e2002dd,0xb86450d8,0xdce0013d,0x00000000}},	//   лiм_, _باهو, konğ, --, 
   {{0x6d581477,0x5335056b,0x6680179e,0xf3f40327}},	// [17a30] _omta, четт, _ریسل, _བྱཻད_, 
   {{0x21000cb4,0x98a46dd3,0x7ae800e5,0x00000000}},	//   रजेश_, _toną_, zget, --, 
   {{0x3f14223a,0x27380036,0x7ae9056c,0x00000000}},	//   ждес, _fënt_, yget, --, 
   {{0x6d582e95,0xdce00166,0x00000000,0x00000000}},	//   _amta, fonğ, --, --, 
   {{0xd01001ed,0x3cc8030d,0x6d4400c0,0x00000000}},	//   ولے_, алло_, _įkar, --, 
   {{0x27380036,0x6d580332,0x1fa40798,0x00000000}},	//   _këns_, _cmta, _граг, --, 
   {{0x7ae9056d,0x4fc42519,0x00000000,0x00000000}},	//   tget, _нста, --, --, 
   {{0x6d59056e,0x7ae8037e,0x386800b8,0x00000000}},	//   _emta, uget, _śaro_, --, 
   {{0x7f480eda,0x273804e6,0x5ec000d1,0x39480c54}},	//   _ileq, _lëns_, _миңғ, изио_, 
   {{0x7ae84d7c,0xd01001e2,0x6e400244,0x00000000}},	//   sget, _تلې_, _تۆهم, --, 
   {{0xa3c813b4,0xc6880a1e,0xabb400c7,0x7ae8d000}},	//   रीम_, _סא_, _дахә, pget, 
   {{0x7f48025c,0x00000000,0x00000000,0x00000000}},	//   _jleq, --, --, --, 
   {{0x6d580158,0x18640022,0x49c80064,0x39340153}},	//   _ymta, раҟи_, _глін_, _мэкс, 
   {{0x7f480113,0x00000000,0x00000000,0x00000000}},	//   _lleq, --, --, --, 
   {{0x64a1056f,0xf3581fbe,0x00000000,0x00000000}},	//   дара, ашај_, --, --, 
   {{0xf7706ea9,0x106800d1,0x7afc022e,0x00000000}},	//   _تات_, ەڭرى_, еsti, --, 
   {{0xa3c8033f,0x27380200,0x3a2c0051,0x13a8114f}},	// [17a40] रीब_, _vënt_, nxep_, _گنجی_, 
   {{0x7f490570,0x00000000,0x00000000,0x00000000}},	//   _aleq, --, --, --, 
   {{0x273801c7,0xd4c40121,0xf2a401f4,0xa3d40037}},	//   _tënt_, _мөңк, _минп, _सिए_, 
   {{0xdfcc1d1f,0x6e450571,0x63b00308,0x0cb400dc}},	//   ئين_, ينام, žené, ुर्म, 
   {{0xdd8c5c81,0x00000000,0x00000000,0x00000000}},	//   چون_, --, --, --, 
   {{0x7f490572,0x00000000,0x00000000,0x00000000}},	//   _eleq, --, --, --, 
   {{0x7f482e27,0xa0650573,0x00000000,0x00000000}},	//   _fleq, _дара_, --, --, 
   {{0xee384b1c,0xdd040166,0x00000000,0x00000000}},	//   _кнб_, _töşs, --, --, 
   {{0xa9280006,0x7af800d7,0x00000000,0x00000000}},	//   аіне_, _šatô, --, --, 
   {{0x6d590574,0xa3d8000d,0x00000000,0x00000000}},	//   _umta, _डटल_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb1c01e1,0xa968014b,0x00000000,0x00000000}},	//   _àwám, _кида_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd7ec0323,0xa2c80022,0x00000000,0x00000000}},	//   _юу_, иуаз_, --, --, 
   {{0xbebc00b8,0xdc840092,0x00000000,0x00000000}},	//   _anūn, _ሜትሪክ_, --, --, 
   {{0x25ac05d5,0xa3d401ef,0x00000000,0x00000000}},	// [17a50] _îgl_, _सिक_, --, --, 
   {{0x98a4003a,0x741400ec,0x00000000,0x00000000}},	//   _bonę_, _کوٽا, --, --, 
   {{0x7f480023,0x53700023,0x00000000,0x00000000}},	//   _pleq, _ጻዊዒት_, --, --, 
   {{0xf3f4031c,0xa3c80073,0xcf580212,0xe7f0000d}},	//   _བྱིད_, रीण_, оріч_, _अमना_, 
   {{0x63700327,0x74540092,0x00000000,0x00000000}},	//   għne, ረጋገጥ, --, --, 
   {{0xdd8c00ec,0x00000000,0x00000000,0x00000000}},	//   کوڙ_, --, --, --, 
   {{0xbc190575,0x7f48025c,0x4fc400d1,0x7e6c0356}},	//   сілі_, _tleq, _يەكە, _ţipă, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa3c81d34,0xeb8c013d,0x7d54010a,0xb0b004af}},	//   रीत_, _җи_, _евах, _जलमग, 
   {{0xa3a800af,0x6440010e,0x37e400cf,0x00000000}},	//   खदा_, _üniw, поог, --, 
   {{0x17c000c7,0x00000000,0x00000000,0x00000000}},	//   ьанҭ, --, --, --, 
   {{0xc6140154,0xabf8011a,0x00000000,0x00000000}},	//   ামনা_, _להער, --, --, 
   {{0xf5b402bf,0xe0e000cc,0x00000000,0x00000000}},	//   ясню, ন্যভ, --, --, 
   {{0xa3d409bb,0x00000000,0x00000000,0x00000000}},	//   _सिख_, --, --, --, 
   {{0xf7450576,0xd8750577,0x89340244,0x00000000}},	//   _неко, _باشب, _تعنا, --, 
   {{0xf77000ec,0x00000000,0x00000000,0x00000000}},	//   _ڪاڪ_, --, --, --, 
   {{0xb1440484,0x00000000,0x00000000,0x00000000}},	// [17a60] пнал, --, --, --, 
   {{0xf8bc1715,0x00000000,0x00000000,0x00000000}},	//   ोरिय, --, --, --, 
   {{0x2000067c,0x316405be,0xa3c80c70,0x628d0578}},	//   _cpji_, đoz_, रीद_, _ezco, 
   {{0x71a40d52,0x00000000,0x00000000,0x00000000}},	//   _намз, --, --, --, 
   {{0xf2e4021a,0x628800e4,0x75780055,0x06e001ec}},	//   _وکړه_, ýgot, _ṛṣka, _ﻋﺩﻴﺩ, 
   {{0xdc100166,0x172c0327,0x7eb00248,0xebc40114}},	//   _aşıt, _སོའམ_, _pópó, пљин, 
   {{0xe12000d1,0x2f54022e,0x6bd400ae,0x00000000}},	//   _ямри, _етас, ستغر, --, 
   {{0x394400ef,0x00000000,0x00000000,0x00000000}},	//   ekls_, --, --, --, 
   {{0x64400365,0x00000000,0x00000000,0x00000000}},	//   _üniv, --, --, --, 
   {{0x75380730,0x6b5c00c0,0x00000000,0x00000000}},	//   ötzl, pūgo, --, --, 
   {{0x1aa800cc,0xd7f400cf,0x00000000,0x00000000}},	//   _গজৰা, пуя_, --, --, 
   {{0x98a4012c,0xdce000ef,0x00000000,0x00000000}},	//   _koně_, bonē, --, --, 
   {{0x6b810579,0x95c8156c,0x6a8401d5,0x00000000}},	//   _ikog, зуса_, _элда, --, 
   {{0x6b800165,0x1a9808c3,0x69940408,0x00000000}},	//   _hkog, _הידע, _эрех, --, 
   {{0xd4040dbb,0xb7940451,0x00000000,0x00000000}},	//   няти, _ڪاوڙ, --, --, 
   {{0x9810007b,0x00000000,0x00000000,0x00000000}},	//   _أبوا, --, --, --, 
   {{0xddc800bc,0xe6c016d1,0x85742c31,0x883400e5}},	// [17a70] _žižk, _व्यङ, _олих, _رکھئ, 
   {{0x6b4c0241,0xdbf001e1,0xb6240150,0x00000000}},	//   _jùgb, _s̟ís, _ﺭﺕ_, --, 
   {{0x39580ba1,0xa3d47ef5,0x7c3403b9,0x00000000}},	//   èssi_, _सिट_, _üzrx, --, 
   {{0x6b80013f,0x6b4c0248,0x00000000,0x00000000}},	//   _nkog, _lùgb, --, --, 
   {{0x2284141c,0x00000000,0x00000000,0x00000000}},	//   _хунг, --, --, --, 
   {{0x6b81057a,0xc10421ec,0xfce4036b,0xa1c400fd}},	//   _akog, _توسي, фоко, _uñış_, 
   {{0x3b940261,0x33a80150,0x00000000,0x00000000}},	//   мјит, _ﻋﺎﻟﻲ_, --, --, 
   {{0x2bdc01ad,0xba245e7f,0x44200205,0x00000000}},	//   _नटरा, ддик, _mrh_, --, 
   {{0x2f200014,0x4420107d,0xdcc401af,0x6da000db}},	//   _جہنِ, _lrh_, _еңле_, رۅۅم, 
   {{0x6b81057b,0x44200165,0x443000b5,0xbd4401f7}},	//   _ekog, _orh_, kxz_, _تنطي, 
   {{0x6b800093,0x6b4c0248,0xb8d407f7,0xd7644a6a}},	//   _fkog, _dùgb, _झल_, فندی, 
   {{0xd90c00f8,0x5edc0154,0xb75800d4,0xf7440108}},	//   ئیں_, ফ্রে, ішнє_, фемо, 
   {{0xe8ed057c,0xe9ccbb62,0xa3c9057d,0x7afc0254}},	//   _ил_, _шк_, रीस_, õstu, 
   {{0x4420007f,0xa5b800d2,0x69200124,0x44300175}},	//   _brh_, dvód, _амша, fxz_, 
   {{0xe5a0cd5f,0x00000000,0x00000000,0x00000000}},	//   тири, --, --, --, 
   {{0xa5d41524,0x4421057e,0x7d000175,0x2324023b}},	//   _बिचौ, _drh_, _lbls, моси_, 
   {{0xf2687a50,0x7d00037e,0x69dc00b8,0xfaf800c0}},	// [17a80] циал_, _obls, _āpek, lnūs_, 
   {{0xa3c8375c,0x442002d2,0xe2340092,0x00000000}},	//   रीह_, _frh_, _የዘመና, --, 
   {{0xdfcc16a2,0xf3e4ed5a,0x44200129,0x00000000}},	//   ليل_, _южно, _grh_, --, 
   {{0x32440209,0x409800ec,0x00000000,0x00000000}},	//   _жемг, سٽنگ_, --, --, 
   {{0x71f80014,0xa5d402e5,0x00000000,0x00000000}},	//   _برجس_, _बिछौ, --, --, 
   {{0x6b81057f,0xa3c90580,0x4c950581,0x00000000}},	//   _skog, रीव_, нилс, --, 
   {{0x644005d1,0x91b00183,0x4420003a,0xefb001b9}},	//   _ünit, _ছবিখ, _xrh_, _شیشگ, 
   {{0x6b4c0ca8,0x00000000,0x00000000,0x00000000}},	//   _sùgb, --, --, --, 
   {{0x1e80213a,0x816400db,0xdd8c0214,0x00000000}},	//   _алтм, _تەەك_, _چوق_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3a280e3c,0x6b80fd5a,0x2bac002d,0xab64064d}},	//   _šape_, _ukog, _ręch_, _ювел, 
   {{0x5694021b,0xf1ac00ab,0xda74014b,0x00000000}},	//   кают, _झूलन, _ояш_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x44200175,0x39580036,0x74cc07d2,0x00000000}},	//   _qrh_, ësse_, _ﺑﯘﻻﻳ, --, 
   {{0x44210582,0x44300175,0xb0600139,0xc1b90583}},	//   _vrh_, rxz_, _çäyk, злах_, 
   {{0xb2740b8d,0x00000000,0x00000000,0x00000000}},	// [17a90] ектә, --, --, --, 
   {{0x44200232,0x00000000,0x00000000,0x00000000}},	//   _trh_, --, --, --, 
   {{0x4420ac43,0xa3c90584,0x009401c6,0x51840153}},	//   _urh_, रीश_, хижэ, тута, 
   {{0x91b80086,0xa24401b9,0x7e7460a9,0x00000000}},	//   öñòñ_, _قیزل_, нгех, --, 
   {{0xa3c81100,0x1fa412eb,0x81e800cc,0x00000000}},	//   रीर_, गदौड, _মনক_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6e340158,0x00000000,0x00000000,0x00000000}},	//   øybr, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf1e00037,0x00000000,0x00000000,0x00000000}},	//   _पिसन, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa820021a,0x7f580724,0x3dcc007f,0xa8010585}},	//   اکون, _çaqı, _kwew_, ññat, 
   {{0x3b0c0194,0x0b5801d5,0xbebd0586,0xdce00166}},	//   meeq_, _تشلب_, _anūk, lmnı, 
   {{0xdb1c2b96,0xfaf800c0,0x00000000,0x00000000}},	//   øvær, pnūs_, --, --, 
   {{0x79810587,0xa3c80574,0x3eac0086,0x8e2001ec}},	//   molw, रील_, _oget_, кiл_, 
   {{0xf7700efb,0x79810588,0x3eac5ab3,0x3b0c013c}},	//   _حات_, lolw, _nget_, neeq_, 
   {{0x31250589,0x37e00154,0x00000000,0x00000000}},	// [17aa0] ндаг, _বহির, --, --, 
   {{0x3eac0086,0x7981058a,0xdce002d5,0x7764022e}},	//   _aget_, nolw, monė, likx, 
   {{0x2ee5058b,0x3eac020b,0xdce00024,0x76440108}},	//   ежег, _bget_, lonė, lyky, 
   {{0x7981058c,0x60c0956f,0xb900031c,0xdfcc1c43}},	//   holw, ınma, _ཧཧ_, صيه_, 
   {{0x7981058d,0x753c01f5,0x3b0c7aac,0x00000000}},	//   kolw, _kopz, deeq_, --, 
   {{0x3ead058e,0xa2580109,0x98a401e4,0xe7d400d1}},	//   _eget_, _teôr, _sonĝ_, ﯞﻩﺭﻟ, 
   {{0x3dcc0428,0x79800368,0x3b0c0175,0x00000000}},	//   _ewew_, dolw, feeq_, --, 
   {{0x3b0c013c,0xa5b8056a,0x76446c0f,0x1ae0015b}},	//   geeq_, nvóc, kyky, ক্সে_, 
   {{0x4974450b,0x79808926,0xdce00024,0xa2b000ab}},	//   клис, folw, jonė, _अलस्, 
   {{0x7981058f,0x6aa00c58,0xccf800bc,0x9e600063}},	//   golw, ওঁলো, _změn_, _свуд, 
   {{0x068808b0,0x3100102f,0x00000000,0x00000000}},	//   ﺑﯩﻨﯩ, र्यः_, --, --, 
   {{0x6d48000f,0x00000000,0x00000000,0x00000000}},	//   lkfa, --, --, --, 
   {{0x798027be,0x84c46d45,0xe7f0000d,0xbebc0171}},	//   bolw, кәнд, _अमवा_, _snūk, 
   {{0x79810590,0x9b300124,0x310000cd,0x00000000}},	//   colw, _ахәш, र्मः_, --, 
   {{0xa3c82429,0x23240166,0x00000000,0x00000000}},	//   रीं_, нфаг, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d490591,0x3eac1529,0x8ca0012d,0x00000000}},	// [17ab0] kkfa, _rget_, गेतो, --, 
   {{0xccf801ef,0x00000000,0x00000000,0x00000000}},	//   _směn_, --, --, --, 
   {{0x22a4006a,0x0fe40228,0x3dcc0327,0x7f180212}},	//   _bêkü_, лөтү, _swew_, ділу_, 
   {{0x79800944,0xd498a4c3,0x83540451,0xa3c85a17}},	//   zolw, _яры_, _شھزا, रीः_, 
   {{0x79810592,0xa3b90593,0x00000000,0x00000000}},	//   yolw, _ظاھر_, --, --, 
   {{0x6564002d,0xdb0c0ca8,0x00000000,0x00000000}},	//   nijh, _àdúr, --, --, 
   {{0x3b0c013c,0x7644002d,0x79800d47,0xdce0031c}},	//   teeq_, zyky, volw, linċ, 
   {{0x3eb84953,0x79810594,0x3eacec0a,0x6d490595}},	//   _üst_, wolw, _uget_, akfa, 
   {{0x7980b6da,0xbdf400d8,0x00000000,0x00000000}},	//   tolw, _шпај, --, --, 
   {{0x7cd90596,0x6d490597,0x39444d0b,0x3b0c0194}},	//   _آواز_, ckfa, тног, seeq_, 
   {{0x798099df,0x673c014f,0x753c04e6,0x00000000}},	//   rolw, _boqj, _ropz, --, 
   {{0x79810598,0x36690599,0x55c43007,0xe7f0000d}},	//   solw, дамо_, ламғ, _अमरा_, 
   {{0x7981059a,0x00000000,0x00000000,0x00000000}},	//   polw, --, --, --, 
   {{0x76440af9,0xd3c80150,0x756400e5,0xdce00064}},	//   ryky, нқол_, ئیدہ_, ronė, 
   {{0x29a4035b,0x7bc001f4,0x64440064,0x00000000}},	//   _рыцҳ, _jtlu, gyji, --, 
   {{0x762401a9,0xdce000c0,0x00000000,0x00000000}},	//   _амиз, ponė, --, --, 
   {{0x65640d27,0xe6140209,0xa2b01bf9,0x753c0064}},	// [17ac0] bijh, _ады_, _अलर्, _topz, 
   {{0x25d41a4c,0xe295059b,0x22a4025a,0xf8e0068f}},	//   _שוין_, тау_, _sêkü_, पणिय, 
   {{0x7bc1059c,0x06880952,0xc05802bf,0x1710031c}},	//   _ntlu, ﺑﯩﻠﯩ, нії_, _ཏྲོམ_, 
   {{0xdce00327,0xc61400eb,0x00000000,0x00000000}},	//   binċ, ামরা_, --, --, 
   {{0xed59059d,0x7bc000b5,0xbfa80014,0x00000000}},	//   мод_, _atlu, رامٕ_, --, 
   {{0xde900640,0xe7f02982,0x00000000,0x00000000}},	//   јашњ, _अमला_, --, --, 
   {{0x6d480ad9,0x310000dc,0x09bc01f9,0x00000000}},	//   rkfa, र्णः_, ोठ्य, --, 
   {{0x3a2816a3,0xdb64023a,0xa2580142,0x6d49059e}},	//   _šapa_, крыл_, _ffôd, skfa, 
   {{0x31000882,0xe8e800f7,0x6da40588,0x7f74009d}},	//   र्थः_, وردو_, _аиаа, _сурц, 
   {{0x673c014f,0xa384000d,0x18b40124,0x644401f4}},	//   _soqj, _krõõ, кгьы_, yyji, 
   {{0x12c40150,0x6e20007c,0x00000000,0x00000000}},	//   _ﯨﺴﻮﺭ, lvob, --, --, 
   {{0x2d8c0489,0x00000000,0x00000000,0x00000000}},	//   llfe_, --, --, --, 
   {{0x3b080309,0x65640455,0x7bc08ead,0x00000000}},	//   _ñaqa_, tijh, _ztlu, --, 
   {{0x69c003d1,0x6e200793,0x64bc07af,0x09c800fe}},	//   _itoe, ivob, ्रेश, _শিপা, 
   {{0x6564282c,0x4424007b,0x273801c7,0x2d8c01e7}},	//   rijh, íl_, _mënz_, ilfe_, 
   {{0x97a43c1b,0x291c3bdc,0xd6d84684,0xd37800d4}},	//   _крыл, ldta_, _ить_, вчу_, 
   {{0x44240115,0x228401d5,0x00000000,0x00000000}},	// [17ad0] ŭl_, тувг, --, --, 
   {{0x291c00dd,0xc0d400cf,0x6f00003a,0x11549785}},	//   ndta_, اياب, efoc, акую, 
   {{0x6f01059f,0x60d505a0,0xa0a4074d,0x6b5c005f}},	//   ffoc, raxm, тшал, lūgu, 
   {{0x8228031c,0x291c00a3,0x69c002d0,0x60d40009}},	//   སཀྱི_, hdta_, _otoe, saxm, 
   {{0xfce421f0,0x69c001e0,0x00000000,0x00000000}},	//   голо, _ntoe, --, --, 
   {{0x0d8505a1,0x6f000ffb,0xccf8013a,0x00000000}},	//   алін, afoc, _uměl_, --, 
   {{0x69c105a2,0x1fa45b35,0x3998004a,0xf0780116}},	//   _atoe, _араг, nèse_, _зирә_, 
   {{0xe4e01b37,0xdce105a3,0xeb9505a4,0xa3c80037}},	//   कृति_, minč, лищ_, रीए_, 
   {{0x399807ea,0x3d940116,0xdce105a5,0xf98485f2}},	//   hèse_, _биар, linč, лгио, 
   {{0x172c0489,0x657401e2,0xf8b805f5,0x273801c7}},	//   _སོངམ_, _njxh, хөд_, _gënz_, 
   {{0x69c105a6,0x9e5401a9,0x7bc105a7,0xeb5000db}},	//   _etoe, _o奏ka, _utlu, _گۉيگ, 
   {{0xf0900302,0x291c0efe,0x00000000,0x00000000}},	//   מני_, adta_, --, --, 
   {{0xd064013f,0xdb08df62,0xd9740bd6,0xaf74010f}},	//   _ɔsɑk, _ligë, _иркә_, רערס_, 
   {{0xdce00153,0x00000000,0x00000000,0x00000000}},	//   kinč, --, --, --, 
   {{0x5fac0f4a,0xc98400a8,0xdce00427,0x49180073}},	//   _जंगल, _туци, jinč, _बघतो_, 
   {{0xbbd0012c,0xdce105a8,0x27e80306,0x25bc0115}},	//   _सबैक, dinč, ábne_, ŭula_, 
   {{0xb22505a9,0x066400d1,0x42d40150,0xc6d4009d}},	// [17ae0] ымал, _پايپ, рісу, _өсөө, 
   {{0x3b1c0007,0xe62400d8,0x3d1c012d,0x00000000}},	//   _lawq_, çôes_, पयों_, --, 
   {{0xdb080120,0x3998503f,0xdce00153,0x6f000175}},	//   _vigê, cèse_, ginč, tfoc, 
   {{0xdef4748c,0xdb080de2,0x00000000,0x00000000}},	//   гыш_, _digë, --, --, 
   {{0x6f0105aa,0xdee105ab,0xccf81870,0xde000b00}},	//   rfoc, сочи, кқа_, йпци, 
   {{0xa3c806e3,0x6f000798,0xdce00064,0x7bdc002b}},	//   रीक_, sfoc, binč, _āsur, 
   {{0x69c0d9fc,0x6e2105ac,0xdce00841,0xdbe00de2}},	//   _stoe, svob, cinč, féñj, 
   {{0x19540150,0x00000000,0x00000000,0x00000000}},	//   ғаюы_, --, --, --, 
   {{0xdd8d05ad,0x7afd05ae,0x399802e2,0x00000000}},	//   _کول_, òsta, zèse_, --, 
   {{0xdb080137,0x291c01ab,0xada42b95,0x6da4022e}},	//   _ligè, udta_, _сазл, _сиза, 
   {{0x6ae40354,0x88946afd,0x6c74010a,0x57b00139}},	//   _бжез, ринх, _суах, йбэт, 
   {{0x3b1c0369,0xdb081f40,0x3998033b,0xe78400d8}},	//   _gawq_, _nigè, vèse_, ѓуно, 
   {{0x69c00198,0xe66473da,0x2b900bce,0xe4e400d4}},	//   _utoe, утно, _پیکس, лівн, 
   {{0x85b400fd,0x00000000,0x00000000,0x00000000}},	//   ләүч, --, --, --, 
   {{0xf1e000bc,0xf8140150,0x03d400d4,0x00000000}},	//   _पिउन, _ەسۋگ, ржбю, --, 
   {{0xdce000c0,0x39980129,0x00000000,0x00000000}},	//   vinč, rèse_, --, --, 
   {{0xdb0887ef,0x67d00075,0x3744030d,0x5224117e}},	// [17af0] _digè, _тоқу, _тĕтт, йффа, 
   {{0xdce105af,0xc0c401ec,0x00000000,0x00000000}},	//   tinč, ршақ, --, --, 
   {{0xa3c83eaf,0x73c105b0,0x439400f3,0xd4c40108}},	//   रीख_, _мәте, _ванс, _усып, 
   {{0xdce0fd06,0x00000000,0x00000000,0x00000000}},	//   rinč, --, --, --, 
   {{0x3ea801b8,0xd13000d1,0x00000000,0x00000000}},	//   äat_, تمە_, --, --, 
   {{0x3b1c0007,0xdce009a8,0xbebc00b8,0x999c0784}},	//   _sawq_, pinč, _anūt, kyuš_, 
   {{0x8d74005e,0x64400086,0x63ac0548,0x0fe400ee}},	//   حانا, _ànid, _kicn, _гөчү, 
   {{0x69dc04fe,0x05b406ab,0xab600131,0xe3b40154}},	//   _āper, ंदाब, يۇلى, _জবাব, 
   {{0x63ac01d9,0xdb081574,0xe9d505b1,0x310000dc}},	//   _micn, _jigé, акы_, र्वः_, 
   {{0x628d05b2,0x63ac1467,0xd90c01ed,0x3d94008e}},	//   _myco, _licn, سیع_, _тизр, 
   {{0x628d05b3,0xdb081574,0xb8cc07af,0x00000000}},	//   _lyco, _ligé, _कण_, --, 
   {{0x63ac00a3,0x25a00175,0x628c03ac,0xa5b803b2}},	//   _nicn, emjl_, _oyco, rvón, 
   {{0x0ab505b4,0xdb0905b5,0x628c0072,0x99d4007b}},	//   _احمد, _nigé, _nyco, _إتصا, 
   {{0x1cd0025c,0x63ac3a77,0x00000000,0x00000000}},	//   _ེབས_, _aicn, --, --, 
   {{0xdb08007b,0x32d40cb5,0x63ac0142,0x00000000}},	//   _aigé, ицас, _bicn, --, 
   {{0x63ad05b6,0x72c505b7,0x09c803d4,0x00000000}},	//   _cicn, рбаз, _শিতা, --, 
   {{0xdb0800cf,0xa5b8056a,0x2244466e,0x8e200150}},	// [17b00] _vigè, nvól, апти_, кiн_, 
   {{0xb4640f06,0x00000000,0x00000000,0x00000000}},	//   _вкол, --, --, --, 
   {{0x63acf863,0x628c02d0,0x850505b8,0x5e5401b9}},	//   _ficn, _eyco, _اوپن, یلمس_, 
   {{0x628c0fac,0xdb0806af,0x00000000,0x00000000}},	//   _fyco, _figé, --, --, 
   {{0x6da40139,0xee14009d,0x00000000,0x00000000}},	//   аида, рьеэ, --, --, 
   {{0x4094010a,0x00000000,0x00000000,0x00000000}},	//   _ӳртт, --, --, --, 
   {{0x21644df8,0x00000000,0x00000000,0x00000000}},	//   _тири_, --, --, --, 
   {{0xc60c03d4,0xa3c80c4c,0xdb0403e3,0x00000000}},	//   শিতা_, रीट_, _əlça, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9980188d,0xe94400c7,0x00000000,0x00000000}},	//   يليو, рхио, --, --, 
   {{0xeb3400aa,0xcca40150,0xdc540014,0xdb4c030d}},	//   _پراخ, _اڭشى, _پرٕک, _дю_, 
   {{0xdce00029,0x63b40166,0x6a8400c0,0x00000000}},	//   minā, _ruxn, _клеа, --, 
   {{0xdce04424,0xca9002d3,0xe31401d5,0x00000000}},	//   linā, _ምስኦም_, یبرب, --, 
   {{0x63ad05b9,0x1a98010f,0x25bc010f,0x00000000}},	//   _sicn, _סיגע, ŭulo_, --, 
   {{0x628d05ba,0xdce048e1,0x233400c7,0x543400ae}},	//   _syco, ninā, аҿны_, يرفر, 
   {{0x63b4049f,0x8e2000fa,0x00000000,0x00000000}},	//   _vuxn, кiм_, --, --, 
   {{0xa3c806ab,0x964401c0,0xc7a40032,0xdcec00bc}},	// [17b10] रीज_, _дээд, _киҫк, _řeče, 
   {{0xdb0905bb,0x24f40228,0x25640014,0x20c505bc}},	//   _vigé, _өчүр, _خابُ, рсаг, 
   {{0x628c033f,0xdfa40e92,0x63ac01e3,0x00000000}},	//   _wyco, ајдо, _ticn, --, 
   {{0xdce105bd,0x73c0b392,0x2d9c0098,0xe81c0034}},	//   dinā, _хәре, _ahte_, _बनना_, 
   {{0xe2340092,0x8ee800d4,0x00000000,0x00000000}},	//   _ከመሆና, рмів_, --, --, 
   {{0x518505be,0xc1742f4d,0x2d9c002f,0xbebc00de}},	//   _дуса, _اگرت, _chte_, _saūd, 
   {{0x91843955,0xa3c80490,0xeb001d68,0x7afc67c1}},	//   _بۇلۇ, रीच_, लभूत_, òsto, 
   {{0x2d9cac2c,0x5478011a,0x00000000,0x00000000}},	//   _ehte_, יגוע_, --, --, 
   {{0xdce00421,0x3f8c0098,0x6370031c,0xcdf4007b}},	//   ainā, _ikeu_, għni, _وأكث, 
   {{0xdce000da,0x6b4c01c3,0x79f400c7,0xc0e40023}},	//   binā, _lùgh, азҩх, _ምስሪ_, 
   {{0x1b1c2f8b,0xdce00029,0x1b000372,0x7c940597}},	//   ভাবে_, cinā, _дүйн, _الاص, 
   {{0xa2b000bc,0x27e800d7,0x00000000,0x00000000}},	//   _अलग्, ábna_, --, --, 
   {{0x0a9401af,0x2d9c0254,0xf34802dd,0x7e78010f}},	//   _дацю, _yhte_, қпал_, ראָז, 
   {{0x240400d1,0x00000000,0x00000000,0x00000000}},	//   әнти_, --, --, --, 
   {{0xd348006c,0x85780801,0xd7680150,0xf7440395}},	//   لیده_, рсят_, _نەدى_, _гейо, 
   {{0xf77105bf,0xfaf80374,0x75300356,0x00000000}},	//   _ژاک_, ngū_, _şeză, --, 
   {{0xdce00029,0x6b4c08c2,0x672802d2,0x1c180037}},	// [17b20] zinā, _dùgh, _ógja, _भईऽल_, 
   {{0x3f8c003e,0x05b402ab,0x1afc015b,0xe2500092}},	//   _akeu_, ंदरब, ্যিই_, _ለዘመና, 
   {{0x2518010f,0x35bc012d,0x0664085b,0x6ea801f9}},	//   _גויא, _एंड़, _هایپ, जेनु, 
   {{0x27f802bf,0xdce01991,0x2d9c036e,0xdee000d8}},	//   _åpne_, vinā, _shte_, зоци, 
   {{0x1afc009e,0xece40150,0x00000000,0x00000000}},	//   ্যাই_, йғақ_, --, --, 
   {{0xdce04424,0x3f8c00e4,0x64400129,0xec9401ec}},	//   tinā, _ekeu_, _ànic, _ﺘﻭﺍﺠ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdce000da,0xa0640276,0x00000000,0x00000000}},	//   rinā, _уаса_, --, --, 
   {{0xdce00029,0xed4400c7,0xfbd400fe,0x00000000}},	//   sinā, _лнап, সংগত, --, 
   {{0x290905c0,0xdce01a14,0x5e5400ae,0x00000000}},	//   ýba_, pinā, _الكس_, --, 
   {{0xd7c40133,0x2bc8033a,0x29000210,0x00000000}},	//   یویه_, _слеп_, ęka_, --, 
   {{0x2900012c,0x39980ba1,0x207800df,0x00000000}},	//   řka_, rèsa_, ראטא, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdce00311,0x04c80592,0x6b4c00a3,0xe3b0007b}},	//   mină, شوري_, _sùgh, كرر_, 
   {{0xd82cb144,0x225c01ef,0xfaf8002b,0x00000000}},	//   _ээ_, _ťuk_, bhūd_, --, 
   {{0x6b4c0086,0x5b78008f,0x22840137,0x1874123b}},	//   _bùgi, ָרמא, бузг, _לעור_, 
   {{0x26d800db,0xb06000ee,0xdce00356,0x00000000}},	// [17b30] _ieqo_, ýänl, nină, --, 
   {{0x2b44c227,0x68f803a2,0xbebc00b8,0x189000b7}},	//   _looc_, ngtd, _anūp, _ሚስጥር_, 
   {{0x691c0135,0x00000000,0x00000000,0x00000000}},	//   _għeż, --, --, --, 
   {{0xddd80745,0x2b4401d9,0xd7f8010f,0x5c7400fb}},	//   _využ, _nooc_, רהאל, ҙҙер_, 
   {{0x9e040276,0x98a4033f,0xb0600139,0x00000000}},	//   счел, _inną_, _çänk, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2b440009,0x9b8400e5,0x00000000,0x00000000}},	//   _booc_, ینڈل_, --, --, 
   {{0xb9e807d6,0x39e905c1,0xdce00356,0xf078013d}},	//   амиз_, адио_, fină, _тисә_, 
   {{0xfaf8005f,0xb88802d3,0x499001ed,0x2b440009}},	//   rgū_, _ሓንጎል_, کیور, _dooc_, 
   {{0xbda40133,0x00000000,0x00000000,0x00000000}},	//   _بۆتۆ_, --, --, --, 
   {{0x9ab00451,0x00000000,0x00000000,0x00000000}},	//   _فلاڻ, --, --, --, 
   {{0xdce00356,0xdd8c00f1,0xdb1c0108,0x00000000}},	//   bină, _غوڅ_, ävär, --, 
   {{0xdce0054e,0xdb8c0023,0x4a74190b,0x00000000}},	//   cină, _ምህዳም_, _нышт, --, 
   {{0xfa880023,0xb86401e2,0x00000000,0x00000000}},	//   _ምስናይ_, _واغو, --, --, 
   {{0xf74505c2,0x81f4031c,0x37a00116,0xb118036b}},	//   _меко, _པཀྴི_, _оқоғ, یقرا_, 
   {{0xe81c0c2e,0x64a063dd,0xd76800f7,0x00000000}},	//   _बनता_, фаса, _چەگى_, --, 
   {{0xc878654f,0xd34807d6,0xd76800db,0x00000000}},	// [17b40] mağa_, لیگه_, _نەگى_, --, 
   {{0x21a003b7,0xc8788eac,0x26d8036e,0xbebc00ef}},	//   диум, lağa_, _zeqo_, _snūp, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x25b4034c,0xc87905c3,0x69d801ad,0x047801d5}},	//   _دهید_, nağa_, पीडी, _چلیک_, 
   {{0xeda505c4,0x71a4035b,0xf1a803e6,0xceb80075}},	//   ошко, _мамз, _ناسه_, _һәл_, 
   {{0x09c80729,0x2b4505c5,0xceb81321,0x6ad000bc}},	//   _শিলা, _sooc_, рәң_, सर्र, 
   {{0xc878e090,0x2b440477,0x70d400bc,0x00000000}},	//   kağa_, _pooc_, धरील, --, 
   {{0xe9e401c0,0x00000000,0x00000000,0x00000000}},	//   оцоо, --, --, --, 
   {{0xc8785aeb,0x5f0001a9,0xfe74014b,0x00000000}},	//   dağa_, _юзта, _нӯш_, --, 
   {{0x26d80032,0xdce00356,0x00000000,0x00000000}},	//   _seqo_, rină, --, --, 
   {{0x6d58049b,0x57f0ede6,0xc8780166,0x38b40248}},	//   _ilta, мпэт, fağa_, _ẹrù_, 
   {{0x6d580306,0xc8780166,0x00000000,0x00000000}},	//   _hlta, gağa_, --, --, 
   {{0xc0e4069c,0x1ae0009d,0x5ac80244,0x00000000}},	//   _ምድሪ_, _цочм, _ئامێ_, --, 
   {{0xd5b80953,0x78ac01e4,0x7c4800d8,0xc60c00fe}},	//   ўся_, _ŝave, _éprá, শিলা_, 
   {{0xc8780213,0x21200010,0x23680063,0xa2b008df}},	//   bağa_, _rajh_, ајао_, _अलङ्, 
   {{0x533505c6,0x88bc0183,0xc8782d1c,0x93a401f0}},	//   мест, _আজিক, cağa_, дшуд, 
   {{0x6d5905c7,0xf8ac004b,0x20c80228,0x92940124}},	// [17b50] _olta, _ټکی_, لباي_, датц, 
   {{0x44f505c8,0x6d580083,0x7dd00241,0xc8bc2cfd}},	//   _эпос, _nlta, _lósò, ोडिट, 
   {{0x3f140046,0xc0e41b49,0xc5a80014,0x43944e8b}},	//   здес, _ምድረ_, _پُھن_, _наос, 
   {{0x442105c9,0x38c002d2,0xa2640395,0x00000000}},	//   _ish_, _kæró_, _дъгл, --, 
   {{0xfe7105ca,0x442105cb,0x733808a8,0x06ac0154}},	//   رگر_, _hsh_, _הערס, কুরি, 
   {{0xdb0905cc,0xa2880092,0x442105cd,0xee2c00ec}},	//   _vigí, _ሙስናን_, _ksh_, اٽو_, 
   {{0x10a4009d,0x00000000,0x00000000,0x00000000}},	//   _жиён, --, --, --, 
   {{0x442105ce,0x6d5905cf,0x547c010f,0x88bc0118}},	//   _msh_, _elta, יטוו, uděn, 
   {{0x442105d0,0x290c0334,0x0dc8234c,0x671c141f}},	//   _lsh_, _bbfa_, _духи_, यजनक_, 
   {{0x442001b9,0x0a9801c0,0x52b81025,0x00000000}},	//   _osh_, өсөө_, _अल्स, --, 
   {{0x6d540882,0x442004cc,0xc8790356,0xdce00210}},	//   īyat, _nsh_, tağa_, giną, 
   {{0x9ba04da8,0x7c20068c,0x6d5800d7,0xd7680137}},	//   _تەبى, _islr, _zlta, تەبى_, 
   {{0x64a007dd,0xe8ed05d1,0xc87905c3,0x68e80175}},	//   ҵара, _пл_, rağa_, _fdfd, 
   {{0x88bc012c,0x4420036e,0xccf80118,0xca7400d1}},	//   nděl, _bsh_, _umět_, _تامغ, 
   {{0x44200042,0x00000000,0x00000000,0x00000000}},	//   _csh_, --, --, --, 
   {{0x7f480113,0x27f8143a,0x240401a9,0x8338011c}},	//   _noeq, _åpna_, янси_, очут_, 
   {{0x442105d2,0x37bc0154,0x00000000,0x00000000}},	// [17b60] _esh_, _আবির, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x249c0198,0x442105d3,0x310000dc,0x88bc013a}},	//   ƙuma_, _gsh_, र्गः_, dděl, 
   {{0xee3905d4,0xc0e40020,0x37bc00bd,0x7f4905d5}},	//   йне_, _ምድር_, _আবার, _coeq, 
   {{0xad1000fd,0x44200072,0x2bdc01ad,0xa0640124}},	//   еплә, _zsh_, फीना, _ҵара_, 
   {{0xdd8cefc3,0x4c94d706,0xb144084c,0xd6c400cc}},	//   هون_, милс, _энгл, ্ণিয, 
   {{0x6d58012c,0xccf800bc,0x21a0694c,0x4420022e}},	//   _vlta, _směs_, _чирм, _xsh_, 
   {{0xad6485d4,0x68e80393,0x2078008f,0x504802d3}},	//   _کاره, _sdfd, _האלא, ዘይከኣ, 
   {{0x63a0092e,0x6c842868,0xa9280220,0x88bc01ef}},	//   _ënne, _کلام, біне_, bděl, 
   {{0x6d5905d6,0x237c012c,0x00000000,0x00000000}},	//   _ulta, čuji_, --, --, 
   {{0x06e02158,0x1ad803d4,0x7dd00241,0x00000000}},	//   _ভাবি, _ধাৰা, _tósò, --, 
   {{0xdb0804cc,0x44200200,0xdc38011a,0x00000000}},	//   _gigà, _rsh_, _לעבר, --, 
   {{0x442105d7,0x9b4004d3,0x9f5006af,0xe81c0490}},	//   _ssh_, _سنوو, édés_, _बनवा_, 
   {{0x5e5404ac,0x2d8c073c,0x442002d3,0xd94105d8}},	//   ליכע_, nofe_, _psh_, _печи, 
   {{0x439400d6,0x4420022e,0x1b1c0154,0xb4b40166}},	//   давс, _qsh_, ভারে_, дирә, 
   {{0x2d8c01af,0x88bc012c,0xdc34010f,0xc39800d4}},	//   hofe_, zděl, האלט_, ікає_, 
   {{0x7afc0137,0x2d8d05d9,0xc0c40166,0x00000000}},	// [17b70] òsti, kofe_, дәби, --, 
   {{0x04880139,0x00000000,0x00000000,0x00000000}},	//   _дәби_, --, --, --, 
   {{0xc1680201,0xdb0801d3,0x00000000,0x00000000}},	//   _ተጨማሪ_, _ligá, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe2a8034c,0xd1380075,0xa5280327,0x00000000}},	//   _دادن_, تكەش_, _སྣོག_, --, 
   {{0x2d8c0093,0xccf800bc,0xdb8c0023,0x00000000}},	//   gofe_, _směr_, _ምቅዋም_, --, 
   {{0xbb441422,0x7f5801c6,0x69d803ce,0x69c505da}},	//   дейк, _давс_, पीसी, íken, 
   {{0xf9c905db,0x4af40124,0x00000000,0x00000000}},	//   огик_, нџьу, --, --, 
   {{0x80e00034,0xdb0905dc,0x7bc80118,0xea8402e8}},	//   _फ़ाइ, _cigá, _žluč, мбъл_, 
   {{0xdb0804d4,0x00000000,0x00000000,0x00000000}},	//   _digá, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3a2801a6,0xdb2105dd,0x80a4033f,0xf7700133}},	//   _šapu_, _سوتی, _करने, ئاد_, 
   {{0x80dc00e1,0x00000000,0x00000000,0x00000000}},	//   यराइ, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa50480b2,0x0928004b,0xa88505de,0x00000000}},	//   ьера_, _رسوي_, _ойша_, --, 
   {{0xf77105df,0x220002b1,0x40e400cd,0x00000000}},	//   _جات_, kūhā_, _āśaṃ, --, 
   {{0xe2943529,0x3dcc016b,0x312505e0,0x2d8c002e}},	// [17b80] дат_, _ntew_, мдаг, yofe_, 
   {{0xe1f40354,0xf0b81f0d,0x00000000,0x00000000}},	//   ьгу_, زائش_, --, --, 
   {{0x65380375,0xdc3c00d7,0x00000000,0x00000000}},	//   _ועיד, díďt, --, --, 
   {{0xdce03f05,0x00000000,0x00000000,0x00000000}},	//   minę, --, --, --, 
   {{0xdee03246,0x2d8c009a,0x71640150,0xdce000c0}},	//   точи, tofe_, _قاسك, linę, 
   {{0xe81c1094,0x00000000,0x00000000,0x00000000}},	//   _बनला_, --, --, --, 
   {{0x2d8d05e1,0xdb08102c,0x00000000,0x00000000}},	//   rofe_, _sigá, --, --, 
   {{0x2d8d05e2,0x8e84010a,0x00000000,0x00000000}},	//   sofe_, _пӳле, --, --, 
   {{0xde0000d1,0x78ac0115,0x298400fd,0x2b980036}},	//   _ипти, _ĝava, дынг, lëck_, 
   {{0xdb0800d8,0xdce00024,0x80a402c3,0x91b003d4}},	//   _vigá, kinę, _करमे, টৱৰ্, 
   {{0x9cd40302,0x99d003e6,0xdce00064,0x9f440205}},	//   _חובה_, _یتوا, jinę, çiçi_, 
   {{0xdb200162,0xdce00153,0x00000000,0x00000000}},	//   _ørðv, dinę, --, --, 
   {{0x6b8105e3,0x6360000d,0xe664026b,0x95c8009b}},	//   _ijog, _hõng, фтно, дуса_, 
   {{0x6aa00117,0x88bc0316,0x48ac015b,0xdce001a6}},	//   _izof, zděj, _গভীর, rinć, 
   {{0x38680b45,0x39980ba1,0x63600254,0xd8a400ec}},	//   _ƙare_, dèsh_, _jõng, _ٺهيو_, 
   {{0x64408d22,0xe3b01374,0x310000cd,0x80a40037}},	//   _ànim, ئرس_, र्घः_, _करबे, 
   {{0x06ac00bd,0x636000c5,0x20e83b89,0x00000000}},	// [17b90] _ক্রি, _lõng, قعاً_, --, 
   {{0x51f845b3,0xdce000c0,0x60606c68,0x00000000}},	//   ьную_, binę, پۇرل, --, 
   {{0x3dcc3b08,0x6b8105e4,0x2004054e,0xfd4800b8}},	//   _stew_, _ojog, îni_, _gomṛ, 
   {{0x6b8105e5,0x6aa00117,0x171c008f,0xd4980024}},	//   _njog, _ozof, ַווע, _юры_, 
   {{0xc60c0729,0x522405a2,0x00000000,0x00000000}},	//   শিকা_, _ифра, --, --, 
   {{0x237c098d,0x6b8105e6,0x2b980221,0xd5fc08a8}},	//   čuju_, _ajog, lëch_, קפור, 
   {{0x6aa105e7,0x00000000,0x00000000,0x00000000}},	//   _azof, --, --, --, 
   {{0xba2505e8,0x6b4c01c3,0x39980100,0x73f8010f}},	//   едик, _sùgr, mèsi_, פּצו, 
   {{0x39980100,0x661803e0,0xfaf800b8,0x00000000}},	//   lèsi_, çukl, bhūn_, --, 
   {{0x6b8000e4,0x09c80154,0x00000000,0x00000000}},	//   _ejog, _শিখা, --, --, 
   {{0x6b800158,0x636000c5,0x3998068c,0x8d741d00}},	//   _fjog, _kõnd, nèsi_, _شاكا, 
   {{0x7bc019a2,0xdc0002f0,0x6b8105e9,0xdce00153}},	//   _iulu, nčít, _gjog, vinę, 
   {{0xb90404c5,0x64a06d96,0x636000af,0x00000000}},	//   _ফা_, ғата, _mõnd, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7bc105ea,0xe944034c,0x2c0000dc,0xb794009b}},	//   _julu, _سروی, रूपं_, _прић, 
   {{0x7bc105eb,0xdc0001f1,0x636000c5,0xf5e905ec}},	//   _mulu, jčít, _nõnd, _емил_, 
   {{0xa25805da,0xf7704ce4,0xdc0002f0,0x00000000}},	// [17ba0] _ngôd, _لاک_, dčít, --, 
   {{0x7bc105ed,0x39980066,0xe8140ebb,0xdce000c0}},	//   _oulu, fèsi_, _तहमा_, pinę, 
   {{0xdfcd05ee,0xef1905ef,0x7bc105f0,0xc05802bf}},	//   ميل_, зме_, _nulu, мії_, 
   {{0x636000c5,0x1ec4a641,0x2b9804e6,0x88d400dc}},	//   _rõng, елци_, rëck_, _kṛcc, 
   {{0x7bc105f1,0xee380364,0x62800112,0x00000000}},	//   _aulu, янд_, ßnot, --, 
   {{0x7bc105f2,0x6b8105f3,0xb60409a8,0xac2505f4}},	//   _bulu, _sjog, mešč, ефик, 
   {{0x4094b671,0xa0a105f5,0x7bc105f6,0x6aa001ed}},	//   _артт, _бард, _culu, _szof, 
   {{0x7bc105f7,0x6fb400c6,0x80a40412,0xdb08013d}},	//   _dulu, _أمرا, _करते, _nigä, 
   {{0x7bc00356,0x0d0802dd,0x5b10010b,0xa92801ec}},	//   _eulu, _одақ_, умыт, піне_, 
   {{0x7bc01aa1,0x6e20339b,0x6f0105f8,0xb8f00124}},	//   _fulu, mwob, lgoc, аҧшш, 
   {{0x7bc105f9,0xdb0800a2,0x6e201418,0x46e80137}},	//   _gulu, _bigä, lwob, үдүн_, 
   {{0x6f0105fa,0x6360007d,0x6b8001e4,0xdb080166}},	//   ngoc, _kõne, _ujog, _cigä, 
   {{0x7bc105fb,0xdb080598,0x9f44034c,0x6aa0d9f2}},	//   _zulu, _digä, éné_, _uzof, 
   {{0xd5b905fc,0x6360007d,0x7bc105fd,0xdce00118}},	//   есс_, _mõne, _yulu, dině, 
   {{0x7bc00014,0x2b980036,0xd90cdbed,0x637801f4}},	//   _xulu, tëch_, _ایپ_, jänä, 
   {{0x291d05fe,0x6e2000ca,0xbebc00c0,0x63780958}},	//   leta_, kwob, _paūm, dänä, 
   {{0x60d8041a,0xc1b801c0,0x2b9804e6,0x5ec00131}},	// [17bb0] _đumb, длах_, rëch_, қилғ, 
   {{0x3998180f,0x84c4586a,0x00000000,0x00000000}},	//   tèsi_, _шәмд, --, --, 
   {{0x26c80395,0x4ae02894,0x69c0015d,0x291c00e4}},	//   occo_, नराव, _luoe, ieta_, 
   {{0x291d05ff,0x7eb401ed,0x26c80113,0x399804fb}},	//   heta_, نماؤ, ncco_, rèsi_, 
   {{0x291d0600,0x7bc10601,0x26c8011c,0x39980066}},	//   keta_, _sulu, icco_, sèsi_, 
   {{0x291c2804,0x3998007f,0x6d6800f1,0x6378013d}},	//   jeta_, pèsi_, ولنې_, bänä, 
   {{0x7bc10602,0x78ac01e4,0x44300112,0xd0849d9e}},	//   _qulu, _ĝavo, nvz_, _быти, 
   {{0x6e20015c,0x7bc10603,0xae4001d9,0xe7f401f9}},	//   bwob, _vulu, _چھوو, ूंना_, 
   {{0xdcb8169c,0xdb08014a,0x7bc10604,0xf478001f}},	//   _еще_, _rigä, _wulu, ደሚሰጥ_, 
   {{0x7bc10605,0x291c271e,0x9f00021a,0x69c00ac8}},	//   _tulu, geta_, _جوړو, _duoe, 
   {{0x7bc00869,0x61fc31c5,0x6d6800f1,0xa5b80022}},	//   _uulu, huql, _تللې_, yvór, 
   {{0x69c001ee,0x8c3c0724,0x3a750606,0x61fc0309}},	//   _fuoe, _uzğa, _илер, kuql, 
   {{0x291d0607,0x3b0800e8,0xabb4035b,0xa680117e}},	//   beta_, _ñaqq_, _рацә, илюд, 
   {{0x291d0608,0xb6040fb7,0x26c8011c,0x61fd0609}},	//   ceta_, vešč, acco_, duql, 
   {{0xa258006a,0xc0e402d3,0x978404fb,0x3d08482a}},	//   _ngôb, _ምስላ_, _میده, _साने_, 
   {{0x6e200175,0x63780108,0x88a00133,0x6380009d}},	//   ywob, vänä, _دیپۆ, агса, 
   {{0xb7cc00d1,0xb5c80345,0x00000000,0x00000000}},	// [17bc0] ﯖﯩﺰﻏ, _توخم_, --, --, 
   {{0xe57400a8,0xb6040010,0x6f000042,0x637801f4}},	//   _азь_, rešč, wgoc, tänä, 
   {{0x63600254,0xb6040010,0x6fb40066,0x00000000}},	//   _sõne, sešč, نمطا, --, 
   {{0x291d060a,0x2004af07,0xdfcc188d,0x636000af}},	//   zeta_, ània_, زيه_, _põne, 
   {{0x6f01060b,0x291d060c,0xdd000882,0x61fc06be}},	//   rgoc, yeta_, _śrāv, cuql, 
   {{0x291d060d,0x6f000042,0x00000000,0x00000000}},	//   xeta_, sgoc, --, --, 
   {{0x3368069c,0xcc8801d5,0x00000000,0x00000000}},	//   _ሰለስተ_, عنعه_, --, --, 
   {{0x291d060e,0xe4680036,0x69c000e4,0x00000000}},	//   weta_, _hpöö_, _puoe, --, 
   {{0x291c08ad,0x442c0208,0x7d2401d3,0xdce00139}},	//   teta_, ̉e_, ítsü, alnı, 
   {{0x98a5060f,0x1b1c0f22,0x291d0610,0x7afc004e}},	//   _ganċ_, ভাগে_, ueta_, òstr, 
   {{0x291d0611,0xdd8d0612,0x38680c09,0x013400c8}},	//   reta_, _بول_, _ƙara_, אָרט_, 
   {{0x61fc1444,0x45d4f266,0xfb8800db,0x00000000}},	//   yuql, ломс, _كئنو_, --, 
   {{0x7afd0613,0x00000000,0x00000000,0x00000000}},	//   óste, --, --, --, 
   {{0x291c19a2,0x6d480007,0x98a400fd,0x61fd0614}},	//   qeta_, njfa, _elnı_, vuql, 
   {{0x26c800ca,0x0354010b,0x00000000,0x00000000}},	//   pcco_, гүнә_, --, --, 
   {{0x442c00c8,0x61fc100f,0x44306144,0x3f9c002e}},	//   ĉe_, tuql, rvz_, xlwu_, 
   {{0xc7b000dd,0xc0e4001f,0x00000000,0x00000000}},	// [17bd0] _پڑھ_, _ምስል_, --, --, 
   {{0xdce001e4,0x44300334,0x61fd0615,0x00000000}},	//   finĝ, pvz_, ruql, --, 
   {{0x61fcc329,0xf0780ce8,0x5db80150,0x00000000}},	//   suql, нифә_, _ﺸﺎﻨﻴ, --, 
   {{0x39980ba1,0xcfa4267c,0x6110013a,0x932c0023}},	//   lèst_, ашчи, _bělí, _ትጽቢታ, 
   {{0x61fd0616,0x9e04008e,0xd2440661,0xedd8008e}},	//   quql, тчел, _кэри, елчә_, 
   {{0x0e650617,0x3998067c,0xcdc40116,0x61100118}},	//   шкін, nèst_, шашқ, _dělí, 
   {{0x8d74e636,0x3d080073,0xc87806be,0xe5ac0150}},	//   جانا, _साठे_, baği_, _ﺳﻮﻟﻜ, 
   {{0xfaa46ee2,0x2908180f,0xc10400ec,0xc8784dd9}},	//   лайо, òban_, _جوڳي, caği_, 
   {{0xcc14009d,0x00000000,0x00000000,0x00000000}},	//   гчөө, --, --, --, 
   {{0x3944361e,0x00000000,0x00000000,0x00000000}},	//   уног, --, --, --, 
   {{0x39980ba1,0x8c540228,0x00000000,0x00000000}},	//   dèst_, _پئلا, --, --, 
   {{0xdb0800d2,0x3ce50618,0xca7428c4,0x3d0801f9}},	//   _ligú, _helv_, انیک, _साडे_, 
   {{0x7ae90619,0xf770278f,0x3998067c,0x86740022}},	//   maet, لاڭ_, fèst_, аырц, 
   {{0x7ae9061a,0x65c00276,0xda6000ec,0x00000000}},	//   laet, сбра, _ماڙي, --, 
   {{0x5801061b,0x49b842f4,0xee980150,0x00000000}},	//   _тойғ, _شاهد_, _ﺘﻜﻤﻥ_, --, 
   {{0x7ae80f7b,0xc95400b8,0xece40150,0x00000000}},	//   naet, _itīṣ, _ﺍﭘﻪﻛ, --, 
   {{0x796c00e8,0xd244448f,0x3d080ebb,0x00000000}},	// [17be0] _gёwé, шмақ, _साढे_, --, 
   {{0x7ae9061c,0xd78805d9,0x00000000,0x00000000}},	//   haet, _سنڌو_, --, --, 
   {{0x7ae9061d,0x409412b9,0x00000000,0x00000000}},	//   kaet, арцт, --, --, 
   {{0x42d42626,0xa80400a2,0x7ae80108,0xd1640022}},	//   _віру, _heññ, jaet, ынҷқ, 
   {{0x7ae80f7b,0xdb080030,0x00000000,0x00000000}},	//   daet, _figú, --, --, 
   {{0xa80400a2,0x2aa0022e,0x753400df,0x00000000}},	//   _jeññ, kаbr_, ראַד_, --, 
   {{0x7ae80368,0xa8041bce,0x9d400a5b,0x00000000}},	//   faet, _meññ, сејд, --, 
   {{0x7ae80cfd,0x3d08367a,0xeb04468b,0x3ce406af}},	//   gaet, _साथे_, учко, _eelv_, 
   {{0xee39061e,0x7f74326d,0xada40228,0x64400129}},	//   _яна_, _турц, _баал, _àniv, 
   {{0x2d940640,0x3eb802fb,0x4814d820,0x7ae80175}},	//   _србс, _ústa_, амос, aaet, 
   {{0x7ae9061f,0x249c02a8,0x88bc00bc,0xe0f8008f}},	//   baet, ƙumi_, jdět, עלטל, 
   {{0x7ae800d8,0x2d740210,0x00000000,0x00000000}},	//   caet, iłem_, --, --, 
   {{0x9b900597,0x00000000,0x00000000,0x00000000}},	//   _النت, --, --, --, 
   {{0xa8040de2,0x98a40010,0x58d000d8,0x2d740210}},	//   _ceññ, _zanč_, _лошт, kłem_, 
   {{0x87e400db,0x3998068c,0x7d140205,0x00000000}},	//   _ئتتە, rèst_, _özse, --, 
   {{0x870801ed,0x2d74033f,0xdce00139,0x00000000}},	//   _شعبہ_, dłem_, kinğ, --, 
   {{0x39980ba1,0x368800db,0x2d740210,0x31b801e1}},	// [17bf0] pèst_, _үсөн_, ełem_, _ọbẹ̀_, 
   {{0x3d080b03,0xa088008e,0x45340116,0x00000000}},	//   _साधे_, нсез_, _ئىدر, --, 
   {{0x3ed42544,0x6574009a,0xa0a407c6,0x7ae80368}},	//   لقار, _imxh, ушал, yaet, 
   {{0x3ce4501b,0x058402d3,0x8ff8036b,0xdce00166}},	//   _selv_, _ያእቆብ_, ارلر_, finğ, 
   {{0x7ae90620,0x2d740034,0xb0600209,0x98a45160}},	//   vaet, ałem_, ýärl, _ranč_, 
   {{0xe3bc0489,0x0d8401ce,0xc0240150,0x00000000}},	//   _hiñ_, блін, _پىري, --, 
   {{0xe0550621,0x7ae90622,0xe3bd0623,0x1fa50624}},	//   _حیات_, taet, _kiñ_, _браг, 
   {{0x7ae800a9,0xe3bc002e,0x00000000,0x00000000}},	//   uaet, _jiñ_, --, --, 
   {{0x7ae90625,0x6574009a,0xe3bd0626,0xde6400a7}},	//   raet, _omxh, _miñ_, _съвп, 
   {{0x1874069c,0x7ae90627,0xe3bc0de2,0x88bc01ef}},	//   _ኣንጻር_, saet, _liñ_, jděs, 
   {{0x7ae90628,0xe3bc01c4,0xa804002e,0x77840b3e}},	//   paet, _oiñ_, _reññ, илоз, 
   {{0x6574009a,0xe814007d,0xe3bd0629,0x2bd80014}},	//   _amxh, _तहरा_, _niñ_, _شامک_, 
   {{0xded00020,0x2d74033f,0xd6c40116,0xe85007d6}},	//   _ያንን_, złem_, _қипқ, منید, 
   {{0xe3bc0649,0x2d74033f,0x29d0c665,0x2cb00248}},	//   _aiñ_, yłem_, _بيوس, _òndó_, 
   {{0x6360007d,0xe3bc0de2,0x98b4022e,0x06700023}},	//   _sõna, _biñ_, _o倉it, ትርከቡ_, 
   {{0x657401e2,0xe3bc013d,0x2d74012d,0xe734010a}},	//   _emxh, _ciñ_, głej_, _веъ_, 
  
   {{0x8704030c,0xfcbc0092,0x232401f0,0x00000000}},	// [17c00] _ابىل, ደራጀ_, шоти_, --, 
   {{0xe0d5062a,0x6e4404fb,0xe3bc01c4,0x69d801ad}},	//   иву_, ینام, _eiñ_, पीटी, 
   {{0xaec5062b,0xe3bc00e8,0xb4e01b51,0xe29c0d12}},	//   абел, _fiñ_, दरी_, _eyð_, 
   {{0xe3bd062c,0xa3c80073,0xa3c0012d,0x2d740210}},	//   _giñ_, _लढत_, एआर_, rłem_, 
   {{0x957802d3,0x636000c5,0xa5b8033f,0x2d74033f}},	//   _ካብተን_, _kõnn, dwój, słem_, 
   {{0xfcbc0092,0x3ea001e4,0x21a001a9,0xa1900024}},	//   ደራጁ_, ցht_, _миям, _маўч, 
   {{0x3210023a,0xe3bc1bce,0x63600254,0xb91000b8}},	//   ltyy_, _yiñ_, _mõnn, _udaṅ_, 
   {{0x33300076,0x2d740210,0x00000000,0x00000000}},	//   ndyx_, ołek_, --, --, 
   {{0x49741206,0x321002f6,0xdb080023,0xe94417a0}},	//   йлис, ntyy_, _zhgë, ахно, 
   {{0x6da40276,0x63600254,0xaa880014,0x88f800db}},	//   _тиза, _nõnn, _ینام_, دىدر_, 
   {{0x3210023a,0xa258004d,0x7afc0153,0x98a00798}},	//   htyy_, _ngôn, ųsta, жиќе, 
   {{0x6d4c0086,0xe664059f,0x2908012d,0x00000000}},	//   _òbab, атго, żba_, --, 
   {{0xe3bc0295,0x29889efe,0x84c41719,0xeabc030d}},	//   _riñ_, _иско_, йәнд, _цιа_, 
   {{0xdb080ac8,0xe29c032e,0x19540024,0x00000000}},	//   _sigø, _ryð_, _вашы_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd7f5062d,0x2004004e,0x58b800d9,0xe2200023}},	//   _туш_, ànim_, _במוצ, _ስርርዓ, 
   {{0x40940075,0xd251062e,0xe7f400af,0xded00092}},	// [17c10] ڭلار, ونِ_, ूंवा_, _ያንኑ_, 
   {{0x6574d059,0xe3bc0784,0xdfd802e8,0xa2b800cd}},	//   _umxh, _wiñ_, въд_, _शृण्, 
   {{0x2d74033f,0x4395062f,0xe3bc008e,0x03f000fe}},	//   ałek_, _ганс, _tiñ_, _চহকী_, 
   {{0x98a4002b,0x2d74012d,0x00000000,0x00000000}},	//   _janā_, błek_, --, --, 
   {{0x98a40f40,0x929402d5,0x00000000,0x00000000}},	//   _manā_, _маюц, --, --, 
   {{0xa3c80073,0x3ea801e4,0x00000000,0x00000000}},	//   _लढा_, ĥat_, --, --, 
   {{0xf1b00302,0xb1440424,0x8cb40395,0x00000000}},	//   _מסך_, _دیلم_, осъч, --, 
   {{0xe8f4052f,0xdce40724,0x98a400b0,0x5f740131}},	//   ҡлы_, ılın, _nanā_, _ئاسر, 
   {{0xcced0630,0xbe54004b,0x3a380306,0x0ae800cf}},	//   _оқ_, _ارزګ, ísp_, جرىي_, 
   {{0x628c005a,0x9da800a7,0xf1b0008f,0x00000000}},	//   _mxco, _ръба_, ּסט_, --, 
   {{0x2010009d,0x9b6801b9,0xe7e006e3,0x00000000}},	//   ntxi_, _ишда_, कीला_, --, 
   {{0x32100664,0x63600037,0xe5a02f8d,0x00000000}},	//   ytyy_, _sõnn, җиси, --, 
   {{0x6360000d,0x4a740352,0xca740064,0x00000000}},	//   _põnn, _мышт, _мушы, --, 
   {{0xdce0005f,0xb4e02368,0x00000000,0x00000000}},	//   minē, दरे_, --, --, 
   {{0x26e4015b,0xe2940032,0x6360000d,0xe8d4011a}},	//   _কারো_, ҡас_, _võnn, _פוקר_, 
   {{0x321002f6,0xb4640022,0x00000000,0x00000000}},	//   ttyy_, _ҳкол, --, --, 
   {{0xa1c10631,0x64400135,0x63600254,0x66180205}},	// [17c20] збуд, _ġnie, _tõnn, çukt, 
   {{0x3210023a,0x00000000,0x00000000,0x00000000}},	//   rtyy_, --, --, --, 
   {{0x628d0632,0x321002f6,0xd37002dd,0xb6400046}},	//   _exco, styy_, _قۇس_, _ﺍﻕ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xed590633,0x6da412d7,0x00000000,0x00000000}},	//   лод_, бида, --, --, 
   {{0xdce000ef,0x00000000,0x00000000,0x00000000}},	//   dinē, --, --, --, 
   {{0x3d0813b4,0x70544e77,0x00000000,0x00000000}},	//   _सारे_, _انزا, --, --, 
   {{0xc0400020,0x59000135,0xdce000e2,0xdb64004e}},	//   _የሚባለ, _མཐུས_, finē, йрыл_, 
   {{0x26e4015b,0x273c0139,0xdb0c02d2,0x00000000}},	//   _কালো_, _länä_, _ádýr, --, 
   {{0xfaa40032,0xb4e00243,0x98a400b8,0x3ea80254}},	//   өшөн, दरो_, _sanā_, üate_, 
   {{0x98a402b5,0xdb4c35c7,0x2d9c0240,0x7d140205}},	//   _panā_, _ею_, _ikte_, _özsa, 
   {{0xada4013e,0xd9b00014,0x00000000,0x00000000}},	//   _таҷл, _ہٕند, --, --, 
   {{0x1dc80a28,0x63a00036,0x98a40055,0x00000000}},	//   ादयत, _ënni, _vanā_, --, 
   {{0x6aa001f0,0xe664016c,0x64400327,0x94d50634}},	//   _iyof, атҳо, _ġnib, зорц, 
   {{0x6aa0003a,0x70d4000d,0x00000000,0x00000000}},	//   _hyof, _ढ्ेल, --, --, 
   {{0x273c0139,0x82d90635,0x68e802d2,0x4aac0037}},	//   _dänä_, рдас_, _hefd, _चराव, 
   {{0x3d0851a5,0x2d9c02e2,0x41542c27,0xf1c000e2}},	// [17c30] _साले_, _okte_, овас, košā_, 
   {{0x6aa00b1d,0x20c40209,0xf1c0005f,0xb64002dd}},	//   _myof, ссаг, jošā_, _ﺍﺕ_, 
   {{0xd25000aa,0xf1c000e2,0x00000000,0x00000000}},	//   ونې_, došā_, --, --, 
   {{0x66f805d7,0x6aa0002e,0x68e8143a,0xdb0808a5}},	//   ्लिक_, _oyof, _lefd, _sigþ, 
   {{0x6aa01682,0x44206085,0x80a4012d,0x00000000}},	//   _nyof, _hph_, _करके, --, 
   {{0x4420117e,0x0d84177b,0x5bb044af,0xf1c000e2}},	//   _kph_, плін, ुद्व, gošā_, 
   {{0x7afd0636,0x6aa10637,0x98a40356,0x00000000}},	//   ósto, _ayof, _mană_, --, 
   {{0x2d9c03a1,0x88bc012c,0x6aa00175,0x00000000}},	//   _ekte_, vděp, _byof, --, 
   {{0x2d9c0270,0x4420003a,0x98a40356,0x3eb80129}},	//   _fkte_, _lph_, _oană_, _àst_, 
   {{0x582007e4,0x3ead0638,0x80cc012d,0x442001f4}},	//   _འགྱོ_, _izet_, दुचे, _oph_, 
   {{0x68e81509,0x6aa0209c,0x44210639,0x3d04000d}},	//   _defd, _eyof, _nph_, रलीं_, 
   {{0xb6a43298,0x68e801f5,0xfe0c0b02,0x00000000}},	//   жимл, _eefd, _समास_, --, 
   {{0xe8ed063a,0x4420004b,0x290c06af,0xe73403c5}},	//   _ол_, _aph_, _fcfa_, цея_, 
   {{0xdb4c0014,0x98a4054e,0xdb1c00cc,0x0d840354}},	//   _تَچ_, _cană_, åvær, _ялĕн, 
   {{0x58201efe,0xd3484bf3,0x4421063b,0xe5a03ddc}},	//   _འགྲོ_, میده_, _cph_, фири, 
   {{0x44200745,0x64400331,0x8c484dd9,0x00000000}},	//   _dph_, _šnic, luşç, --, 
   {{0x3b1c0399,0x98a40356,0x850401e2,0x00000000}},	// [17c40] _mbwq_, _fană_, _کوپن, --, 
   {{0xefcc0201,0xdb088d22,0xc0400020,0x273c02f6}},	//   _ብለው_, _aigü, _የሚችለ, _tänä_, 
   {{0x3eac01a2,0xdb09063c,0xdfcceb32,0xfaf8000f}},	//   _azet_, _bigü, نيل_, nhūs_, 
   {{0xee39063d,0xd2500075,0xdb080166,0x7c9c0023}},	//   ине_, _كۆز_, _cigü, _ምሕላፍ_, 
   {{0xe2941fe2,0x7c20007f,0xf1c000e2,0xd008010b}},	//   _маю_, _aplr, tošā_, реҗе_, 
   {{0xafe40d84,0xa1c002e8,0x00000000,0x00000000}},	//   _могл, _обяд, --, --, 
   {{0xa0a00372,0xdb09063e,0xcc080183,0x68e86eee}},	//   _жард, _figü, লব্ধ_, _refd, 
   {{0x4a54004e,0x00000000,0x00000000,0x00000000}},	//   зкис, --, --, --, 
   {{0x7af80175,0xa5b802fb,0x3a3c0142,0xf000010b}},	//   _ddwt, rvóz, _crwp_, _хүҗи, 
   {{0x2dcc0952,0xad642a77,0xc6900014,0x2d9c00cd}},	//   _ﻗﻮﻳﻤ, _باره, ہِج_, _ukte_, 
   {{0x6c843ee6,0x68e801a8,0x98a40356,0x8fac0ca8}},	//   _بلام, _vefd, _rană_, _ṣayẹ, 
   {{0x44200a2e,0xdb08067c,0x06e004c5,0x68e80014}},	//   _rph_, _digó, _ভাঙি, _wefd, 
   {{0x2b44067c,0x6aa00107,0x3a3c0368,0x89d8249f}},	//   _inoc_, _uyof, _grwp_, _اوتر_, 
   {{0x4420020b,0xfaf80055,0x00000000,0x00000000}},	//   _pph_, bhūs_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x44200789,0xe04801b9,0xc040001f,0xdce80419}},	//   _vph_, یشاه_, _የሚቻለ, _čičm, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [17c50] --, --, --, --, 
   {{0xdb081b08,0x83540050,0xa0a5063f,0x00000000}},	//   _sigü, _کھسا, ошел, --, 
   {{0x38680b45,0x44210640,0xced802e3,0x6360000d}},	//   _ƙari_, _uph_, _ịzụr, _jõnk, 
   {{0x43940bc4,0xc17404d3,0x00000000,0x00000000}},	//   _хамс, _کگرت, --, --, 
   {{0x8e080212,0x5e2400ae,0x7afc0162,0x00000000}},	//   жнів_, تعاق, óstm, --, 
   {{0x6ed81e4a,0x3eac0219,0x1fd8007b,0x00000000}},	//   لدۇڭ_, _vzet_, _نظرة_, --, 
   {{0x6cd052c8,0x81cc00bd,0xe7c469dd,0x4dcc00eb}},	//   رقيا, _রবি_, _रंगप, রীলং, 
   {{0xa258025a,0x2b4414d0,0xd1e402d3,0x4fc40131}},	//   _ngôk, _cnoc_, _ዝህብ_, _قەلە, 
   {{0x8cd802f8,0xdb08180f,0x3eac8185,0x256c01d3}},	//   नुहो, _bigò, _uzet_, _küld_, 
   {{0x2b440142,0xf990007b,0x3f9d0641,0x00000000}},	//   _enoc_, عبة_, lowu_, --, 
   {{0xed1400e5,0x00000000,0x00000000,0x00000000}},	//   _رہيں_, --, --, --, 
   {{0x0dbc0020,0x3f9cac86,0x00000000,0x00000000}},	//   ደጻፈ_, nowu_, --, --, 
   {{0x1dc90642,0xd05c03b9,0xeacc00e4,0xc4a80150}},	//   ादित, _derə, tỹve_, _ﺴﺭﺍﺌ, 
   {{0x9f6002d2,0x00000000,0x00000000,0x00000000}},	//   _þvær_, --, --, --, 
   {{0x70a8033d,0x7980b567,0x3dcc04e6,0x3f9c0083}},	//   _करेल, milw, _luew_, kowu_, 
   {{0x1dc83347,0x79810643,0x3b0c0194,0x3bd00798}},	//   ादात, lilw, ngeq_, _máq_, 
   {{0x8e2002dd,0x33440050,0xd34807d6,0x98a4012d}},	// [17c60] йiн_, _ہندِ, میگه_, _daną_, 
   {{0xdce0dd77,0xe1f4242f,0x79800770,0xe7e000bc}},	//   minė, ягу_, nilw, कीका_, 
   {{0xdce002d5,0x256c0254,0xd05c06be,0x00000000}},	//   linė, _sülg_, _yerə, --, 
   {{0x79810644,0x3b0c0369,0x3f9c002e,0x00000000}},	//   hilw, jgeq_, gowu_, --, 
   {{0xdce002d5,0x7980d4fa,0x6da4023b,0xd1e40023}},	//   ninė, kilw, пида, _ዝህቦ_, 
   {{0x237c13d5,0xdce0008e,0x00000000,0x00000000}},	//   ďuje_, fonı, --, --, 
   {{0xb3282b88,0x79810645,0xc0e402d3,0xdb080100}},	//   _སྒོང_, dilw, ምኩም_, _rigò, 
   {{0x952c0003,0xdce002d5,0x3b0c0007,0x3dcc0036}},	//   _སིའི_, kinė, ggeq_, _fuew_, 
   {{0x79810646,0xdce00006,0x20200023,0x00000000}},	//   filw, jinė, _ሳልሰይ, --, 
   {{0x79804d37,0xdce00006,0x256d0647,0xc0bc0023}},	//   gilw, dinė, _küle_, ታይሲ_, 
   {{0x6d590648,0xb3bc27c6,0x00000000,0x00000000}},	//   _iota, ्दाख, --, --, 
   {{0x6d590649,0x2900d304,0x3a2c0194,0x2b44020c}},	//   _hota, şka_, bwep_, _unoc_, 
   {{0x6d59064a,0xd05c0cc1,0x7981064b,0xdce00006}},	//   _kota, _verə, bilw, ginė, 
   {{0x6d59064c,0xdeec0092,0x00000000,0x00000000}},	//   _jota, ጀትና_, --, --, 
   {{0x764003b2,0x00000000,0x00000000,0x00000000}},	//   _áoyn, --, --, --, 
   {{0x6d59064d,0xdce00006,0xd3a4c1ef,0x26e400fe}},	//   _lota, binė, еруп, _কাকো_, 
   {{0x6d59064e,0xdce1064f,0x20c87d5d,0x00000000}},	// [17c70] _oota, cinė, مباي_, --, 
   {{0xdce00598,0x636000af,0x51f80500,0x3eb800d7}},	//   yonı, _mõni, яную_, _ústi_, 
   {{0x7afd0650,0x3f140ed0,0x5bf40011,0x00000000}},	//   óstk, ддес, _অঙ্গ_, --, 
   {{0x79800928,0x6d590651,0x3b0c0399,0xfe7000f2}},	//   zilw, _aota, xgeq_, پگر_, 
   {{0x7980676c,0xd0840022,0xd208009d,0x3cc8bb61}},	//   yilw, _ҧыси, _нэрд_, олло_, 
   {{0x4d6402bf,0x0ba800d1,0xa2580051,0x00000000}},	//   нків, ۋايى_, _ngôi, --, 
   {{0x6d590652,0x256c51bb,0xdef80209,0x3f9c0472}},	//   _dota, _güle_, _гыз_, powu_, 
   {{0x29d02776,0x6d580428,0x3b0c0369,0x8f340a89}},	//   _bâa_, _eota, ugeq_, _песц, 
   {{0x7f480eda,0x79810653,0x00000000,0x00000000}},	//   _ineq, tilw, --, --, 
   {{0xdce00006,0xdb0802d2,0x39441b0a,0x00000000}},	//   vinė, _eigð, фног, --, 
   {{0x79810654,0xe7f4033f,0x59700022,0x00000000}},	//   rilw, ूंगा_, дыҟу, --, 
   {{0xdce00953,0x29d0006a,0x6d590655,0x79802ffc}},	//   tinė, _fâa_, _zota, silw, 
   {{0x6d590656,0xd05c016b,0x79810657,0x70a80709}},	//   _yota, _berɛ, pilw, _कर्ल, 
   {{0xdce002d5,0x82e8025c,0xaa540640,0x1cc80327}},	//   rinė, _འབུའ, _циљу_, _ཊུས_, 
   {{0x64a10658,0xdce06dd2,0x38680b45,0x7f490659}},	//   вара, sinė, _ƙaru_, _oneq, 
   {{0x7f48013c,0x70a805f9,0xdce00006,0x84541e4a}},	//   _nneq, _करौल, pinė, رىقچ, 
   {{0x5144b3a2,0x256c00c5,0x60d40175,0x6441065a}},	// [17c80] ндағ, _süle_, fcxm, _ánin, 
   {{0x7f49065b,0x15b407d2,0x2ed000cc,0x970400d1}},	//   _aneq, _سەزس, াৰাষ, _تېڭى, 
   {{0x50940022,0x00000000,0x00000000,0x00000000}},	//   хуаӡ, --, --, --, 
   {{0x6d59065c,0x00000000,0x00000000,0x00000000}},	//   _sota, --, --, --, 
   {{0x6d59065d,0x87ac008f,0xe1ac0073,0x00000000}},	//   _pota, זשאַ, _जीवघ, --, 
   {{0x7f48014b,0x6d59065e,0xdb0803b2,0x00000000}},	//   _eneq, _qota, _sigð, --, 
   {{0x86500023,0x00000000,0x00000000,0x00000000}},	//   ዕርነት, --, --, --, 
   {{0x6d59065f,0x00000000,0x00000000,0x00000000}},	//   _wota, --, --, --, 
   {{0x6d590660,0xada496f0,0x00000000,0x00000000}},	//   _tota, _жаал, --, --, 
   {{0x6d585f10,0x7e7c00a2,0x1d20014b,0x00000000}},	//   _uota, _ýspa, _имум, --, 
   {{0x4f380092,0x00000000,0x00000000,0x00000000}},	//   _በምድር, --, --, --, 
   {{0x6d0c069f,0xd7cc1428,0x6af50661,0x636000af}},	//   _साँग_, _संरच, _آثار, _tõni, 
   {{0x2d8c1529,0x9f4400f2,0x2908067c,0xa5b8012d}},	//   onfe_, èné_, òbas_, dwór, 
   {{0x2d8c05c7,0x7c380162,0x00000000,0x00000000}},	//   nnfe_, _óbrú, --, --, 
   {{0xd7ed0662,0x44240494,0xbb780244,0x27f400e5}},	//   _шу_, ïl_, _بلۆچ_, _تہجد_, 
   {{0x97a40588,0xe0c8009e,0x57f80375,0xdc340115}},	//   _ирыл, _লজেন, _ולהו, ואלט_, 
   {{0x2eb80574,0xd05c0134,0x7f48013c,0x6d0c52f2}},	// [17c90] ेशोत, _terɛ, _rneq, _सांग_, 
   {{0x8ca4012d,0x587000a2,0x00000000,0x00000000}},	//   _चुभो, _öýüñ, --, --, 
   {{0xe7e00073,0x60d4045a,0x00000000,0x00000000}},	//   कीचा_, rcxm, --, --, 
   {{0x20dc060c,0x6d5c0821,0xdce802f0,0x27e800d7}},	//   _प्रध, öpan, čiči, ábny_, 
   {{0xc2c40035,0x98a40064,0x925800db,0x0eb801ec}},	//   _سيسي, _danę_, _жаят_, мушы_, 
   {{0xddd4037e,0x7c64007b,0x00000000,0x00000000}},	//   rト_, فاعل, --, --, 
   {{0xe5140882,0x44300369,0x77b40077,0xad500131}},	//   _तानि_, nwz_, láxe, انىغ, 
   {{0xe51c0316,0xb9e801b9,0x291c058a,0x7f490663}},	//   म्ति_, пмиз_, efta_, _uneq, 
   {{0x3d94084c,0xeacc00e4,0x00000000,0x00000000}},	//   _зиар, tỹre_, --, --, 
   {{0x7d787677,0x37e40228,0xa3cc0490,0x00000000}},	//   _عمار_, ноог, शदा_, --, 
   {{0xc2f402f5,0xe8f43fe9,0xf8a8011b,0xc6880a7c}},	//   _ছানি_, элэ_, явок_, _פא_, 
   {{0x44300007,0x9ba007d2,0x291d0664,0xa5b80332}},	//   dwz_, _جەبى, afta_, ntóf, 
   {{0xdb0801b8,0x44300175,0x00000000,0x00000000}},	//   _bigö, ewz_, --, --, 
   {{0x636000af,0xd94000c7,0xa5b80332,0x00000000}},	//   _mõnu, _рҵои, htóf, --, 
   {{0x44300399,0xa5b8033f,0x7afc033f,0xd8743be4}},	//   gwz_, twór, óstw, _تاشب, 
   {{0xdce000de,0x00000000,0x00000000,0x00000000}},	//   finī, --, --, --, 
   {{0xb2248715,0xe2940c2f,0x249c1432,0x42d402dd}},	// [17ca0] эмал, еат_, ğuma_, тісу, 
   {{0x249c029f,0xe7f401f9,0x00000000,0x00000000}},	//   şuma_, ूंचा_, --, --, 
   {{0x44300097,0xaf040276,0xa1103918,0x00000000}},	//   cwz_, епел, اومت, --, 
   {{0xc64400db,0xf1d000cf,0xaf3400be,0x6094132f}},	//   _سئۋى, _бөжө, عرات, رننس_, 
   {{0x6d4c0086,0x291c01e3,0xdce00055,0x00000000}},	//   _òbak, yfta_, cinī, --, 
   {{0x256c00af,0xdcf40725,0x00000000,0x00000000}},	//   _küla_, ىرىش_, --, --, 
   {{0x6b240489,0x00000000,0x00000000,0x00000000}},	//   _རྒཔོ_, --, --, --, 
   {{0x93e805d7,0x65c401e1,0x7a3400e4,0x09c817c6}},	//   टीएच_, _kéhì, _ỹtav, रद्य, 
   {{0x3d080073,0xaae40271,0x00000000,0x00000000}},	//   _साचे_, وسکو, --, --, 
   {{0x291c0009,0x1ab000fb,0xe9701f0d,0x00000000}},	//   ufta_, ыбыя, اندھ, --, 
   {{0xab2822c3,0xdce000e2,0x65c40241,0x1d04030d}},	//   _ножа_, zinī, _léhì, _чехи_, 
   {{0xded40023,0x08e800cc,0x7c8400f3,0x00000000}},	//   _ጭካነ_, _খাওঁ_, _руђе, --, 
   {{0x6a850665,0xa5b800ae,0x00000000,0x00000000}},	//   _ялда, ntóg, --, --, 
   {{0x2bbc0521,0x46a4012c,0x98a4013a,0xdb0401e1}},	//   _ọcha_, _गुणह, _janě_, _àmòp, 
   {{0x69c800f1,0xd4042f34,0x00000000,0x00000000}},	//   _iife, ляти, --, --, 
   {{0xe3b10666,0x64410667,0x69c803d1,0x57f002e8}},	//   ارس_, _ánim, _hife, _спът, 
   {{0x69c90668,0x6b80014c,0x752c009a,0x44300007}},	// [17cb0] _kife, _mmog, bebz, swz_, 
   {{0x69c80009,0xdce01d76,0x6d5c005b,0x00000000}},	//   _jife, rinī, öpal, --, 
   {{0x6b802a57,0x6360007d,0x69c90669,0xdce00210}},	//   _omog, _sõnu, _mife, chnę, 
   {{0x69c9066a,0x672c012d,0x00000000,0x00000000}},	//   _life, necj, --, --, 
   {{0x660d066b,0x8d740424,0x69c800a3,0xa5b801f6}},	//   nuck, گانا, _oife, rtóf, 
   {{0x69c80cfd,0xdf500323,0x6b81066c,0xa5b9066d}},	//   _nife, _өнгө, _amog, stóf, 
   {{0x8d75066e,0x98a4012c,0xa5b80077,0x27ec0142}},	//   دانا, _daně_, ptóf, _nwfn_, 
   {{0x660c04d1,0xd010e647,0x69c8b26d,0x672c0841}},	//   kuck, _دلِ_, _aife, jecj, 
   {{0x660c08ad,0x69c9066f,0xbdd4003b,0x00000000}},	//   juck, _bife, _розщ, --, 
   {{0x69c90670,0x6b810671,0x61ec0042,0xa5b801f6}},	//   _cife, _emog, _mwcl, ntód, 
   {{0x9c44010a,0x00000000,0x00000000,0x00000000}},	//   _яхал, --, --, --, 
   {{0x69c8c396,0x660c06f2,0x8c24015b,0x27ec03cb}},	//   _eife, fuck, ভিশন_, _dwfn_, 
   {{0x7ae90672,0x69c90673,0x660d0674,0x7afc066a}},	//   mbet, _fife, guck, óstu, 
   {{0x7ae893e0,0x6b810675,0x00000000,0x00000000}},	//   lbet, _zmog, --, --, 
   {{0xf8a50676,0x61ec02d0,0x7ae837cd,0x67d000f3}},	//   _ऑडिय, _awcl, obet, _коју, 
   {{0x2324384f,0x61ec0042,0x752c009a,0x69c90677}},	//   коси_, _bwcl, sebz, _zife, 
   {{0x69c80b6f,0x60d800f3,0x62600d4d,0x7ae80112}},	// [17cc0] _yife, _đumr, авта, ibet, 
   {{0x7ae837be,0xb4650678,0x69c8855d,0x00000000}},	//   hbet, _акол, _xife, --, 
   {{0x61ec0142,0x6d4c01c3,0x63600254,0x7ae90679}},	//   _ewcl, _òbai, _põnt, kbet, 
   {{0x93600131,0xae885016,0xee840124,0x98a401ef}},	//   ﺎﻳﺪﯗ_, мбез_, кыло, _saně_, 
   {{0x61ec0165,0x40940150,0x00000000,0x00000000}},	//   _gwcl, _ұртт, --, --, 
   {{0x6b81067a,0x4c95067b,0x717425a7,0xa5b80077}},	//   _smog, лилс, _شهزا, rtóg, 
   {{0x69c9067c,0x2fd804fb,0x7ae80cf0,0x660cd866}},	//   _rife, _آورد_, fbet, zuck, 
   {{0x2004488c,0x7ae9067d,0x00000000,0x00000000}},	//   šnic_, gbet, --, --, 
   {{0x69c9067e,0xd9d00ae5,0xdea00133,0xee381bbc}},	//   _pife, لەنگ, _پیوی, _юна_, 
   {{0x7ae80142,0x9d4002dd,0xaa90267c,0x672c012d}},	//   abet, _кеуд, лиқч, wecj, 
   {{0x7ae80bbc,0x186400d8,0x00000000,0x00000000}},	//   bbet, ваќи_, --, --, 
   {{0x69c81c1d,0x660c03ac,0x6b81067f,0xbebc0055}},	//   _wife, tuck, _umog, _mbūn, 
   {{0x69c90680,0x25706191,0x877801c6,0x96340153}},	//   _tife, иқис, _үйлс_, аняц, 
   {{0x58d10681,0x660d0682,0x981005af,0x00000000}},	//   _кошт, ruck, دبیا, --, 
   {{0x660d0683,0xd83400c7,0x998002e9,0x60d80139}},	//   suck, _аэы_, _خلوو, _şumo, 
   {{0xd3700075,0x6d5c005b,0xe6640137,0xe3b00956}},	//   قۇپ_, öpaj, _атоо, شرز_, 
   {{0xc1b90684,0x98a40115,0x51f401d5,0x53341367}},	// [17cd0] елах_, _manĝ_, لسلر, шетт, 
   {{0xa088013d,0x00000000,0x00000000,0x00000000}},	//   мсез_, --, --, --, 
   {{0x7ae80365,0x77b40077,0xe61c0548,0x00000000}},	//   ybet, láxa, ltô_, --, 
   {{0xfe78016c,0xa5b80798,0x8f140212,0x12e40816}},	//   нӯз_, stód, ифіч, _вірг, 
   {{0x7ae800fe,0x626400db,0xdce00118,0x00000000}},	//   vbet, _شاحق, chně, --, 
   {{0x7ae80368,0x6360000d,0xd16402e8,0x914801d5}},	//   wbet, _tõns, _къси, _ичса_, 
   {{0xe3e40154,0xa3b4012d,0x7c28009d,0xe0540345}},	//   _ফিডব, _छठा_, хойг_, _جیات_, 
   {{0x7ae8002f,0x00000000,0x00000000,0x00000000}},	//   ubet, --, --, --, 
   {{0x7ae90685,0xc0bc0092,0x00000000,0x00000000}},	//   rbet, ታይም_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x37882082,0xfb14314e,0xa3b0134e,0x8d750686}},	//   ебно_, _مواج, टता_, _ئاقا, 
   {{0x1dc83d1d,0x07e800e5,0x60d82d9a,0xa5b800e5}},	//   ादकत, کریٹ_, _şuml, jtób, 
   {{0xc5f4b3a2,0x00000000,0x00000000,0x00000000}},	//   ағы_, --, --, --, 
   {{0xd3484bf3,0xdb1c00b5,0x2b9800e2,0xf7700133}},	//   چیده_, ævær, rīce_, _گات_, 
   {{0xe1fd0687,0xd3480517,0xf7450688,0x7d140205}},	//   _avó_, نیده_, _бейо, _özsu, 
   {{0xf7710689,0x3eac0083,0xa2b816d1,0x35780092}},	//   _دات_, _oyet_, _शृङ्, ጠየቁት_, 
   {{0x3125068a,0x256c033d,0xc7a82004,0x3eac0369}},	// [17ce0] лдаг, _küll_, _جدول_, _nyet_, 
   {{0x716418fd,0x00000000,0x00000000,0x00000000}},	//   دارك, --, --, --, 
   {{0x256c0ade,0xfaf9068b,0x3eac05d1,0x13a8036b}},	//   _müll_, kaū_, _ayet_, _لندی_, 
   {{0xdfcc9fb1,0xd370568c,0x2005068c,0x00000000}},	//   سيه_, _بۇر_, ánia_, --, 
   {{0x63a00048,0x98a40724,0x00000000,0x00000000}},	//   _ínna, _monı_, --, --, 
   {{0x3eac02ce,0xae780022,0x00000000,0x00000000}},	//   _dyet_, _ҧсах_, --, --, 
   {{0x50b80bca,0x2518011a,0x00000000,0x00000000}},	//   _अरिष, תוצא, --, --, 
   {{0xe61c102c,0x00000000,0x00000000,0x00000000}},	//   ytô_, --, --, --, 
   {{0x4975068d,0x298807b5,0x8ca400bc,0x24a801ec}},	//   илис, есно_, _चुरो, _ﺴﻼﺤﻬ, 
   {{0x753c020b,0x7c6400d1,0x4ac000cd,0x7afc76cf}},	//   _napz, _ھالل, शेषव, óstr, 
   {{0x0f380092,0x00000000,0x00000000,0x00000000}},	//   _በምሕረ, --, --, --, 
   {{0xe51409ae,0xe61c102c,0x60d80139,0x00000000}},	//   _ताहि_, ttô_, _ğumm, --, 
   {{0x7afc1f60,0xa96800ee,0xeab010e0,0xd90c1079}},	//   ðste, _пида_, _اعا_, _کیپ_, 
   {{0xda78025f,0x257001ec,0x00000000,0x00000000}},	//   _אנדר, сқос, --, --, 
   {{0x5f040882,0x753c4a43,0x9cd4011a,0x216401d5}},	//   हणम्_, _dapz, רולה_, қтаг, 
   {{0x68f8a3b0,0x3ea80003,0x00000000,0x00000000}},	//   latd, żati_, --, --, 
   {{0xc0400092,0x00e401b9,0x80f40395,0xa5b800e5}},	// [17cf0] _የሚመል, لتای, ипах, rtób, 
   {{0x3eac0158,0x68f9068e,0x256c00c5,0x40e457aa}},	//   _ryet_, natd, _külm_, рсағ, 
   {{0x3ead068f,0x4034084c,0x491c5c8e,0xc0340e92}},	//   _syet_, реес, _मानो_, рнеј, 
   {{0x673c0054,0x68f90690,0x3eac02d3,0x00000000}},	//   _jaqj, hatd, _pyet_, --, 
   {{0x68f90691,0x673c031c,0xc1040451,0xbea4041b}},	//   katd, _maqj, _پوزي, јалк, 
   {{0x673c0113,0x3da80801,0x68f85063,0xae0000d1}},	//   _laqj, ъкло_, jatd, زۈمى, 
   {{0xfaf80421,0x68f90692,0x626400cf,0xbc3800db}},	//   taū_, datd, _شاڭق, ئستا_, 
   {{0x673d0693,0x290800dd,0x256c07c5,0xcd280372}},	//   _naqj, óban_, _süll_, نسۉن_, 
   {{0x20100564,0x68f90694,0x26141810,0x00000000}},	//   luxi_, fatd, भूमी_, --, 
   {{0xf98430af,0xdea001d3,0xf98800ec,0x68f90695}},	//   ргоо, _پیڈی, ئندي_, gatd, 
   {{0xb8dc0807,0x20100037,0x00000000,0x00000000}},	//   _आर_, nuxi_, --, --, 
   {{0xf77018fd,0x2a9c02e3,0x36680640,0x7dd00124}},	//   زاج_, ịba_, вамо_, _ẽsyr, 
   {{0x68f809a5,0x136801ec,0xf7701183,0x093400f2}},	//   batd, қпақ_, ماڭ_, _گرنج, 
   {{0x3ea800ee,0xf9890696,0xa9642377,0x68f806be}},	//   ýaty_, _جنتي_, _виша_, catd, 
   {{0x673c044e,0x6d5c049b,0xb9e0069d,0x00000000}},	//   _faqj, öpai, _የለ_, --, 
   {{0x20100381,0x28980a7c,0xd348036b,0x00000000}},	//   duxi_, _שיקא, چیگه_, --, 
   {{0x2b9800e2,0xd34807d6,0x256c03e3,0xd78800f1}},	// [17d00] nīca_, نیگه_, _zülm_, _لنډو_, 
   {{0x69dc00b0,0x00000000,0x00000000,0x00000000}},	//   _ōpek, --, --, --, 
   {{0xa5b804d4,0xc05802bf,0x00000000,0x00000000}},	//   stóc, лії_, --, --, 
   {{0x888c008f,0xf2a45bc6,0x68f80f89,0x00000000}},	//   עראַ, _вимп, zatd, --, 
   {{0xee790697,0x68f90698,0xceb80184,0x9ea402ee}},	//   خصات_, yatd, уҙа_, авца_, 
   {{0x68f8022e,0x00000000,0x00000000,0x00000000}},	//   xatd, --, --, --, 
   {{0x68f90699,0x2010020b,0x5cc0011c,0x00000000}},	//   vatd, cuxi_, осъз, --, 
   {{0xe45400c8,0x68f8cb5b,0xceb800fb,0x01c801ec}},	//   שיקט_, watd, _йәл_, _ﺒﺎﻵﺨ, 
   {{0x68f86064,0x00000000,0x00000000,0x00000000}},	//   tatd, --, --, --, 
   {{0x6e2087c3,0x673c014f,0x497400f5,0xfba800db}},	//   mtob, _saqj, слос, ктөй_, 
   {{0x68f87aae,0x6e20010f,0x673c0023,0x60d80139}},	//   ratd, ltob, _paqj, _şumk, 
   {{0x68f80982,0x673c014f,0xed600153,0x4b240154}},	//   satd, _qaqj, sažą_, _মোরগ_, 
   {{0x68f9069a,0x20100564,0x6d44016b,0x3cf400e4}},	//   patd, zuxi_, _ɔkan, _ñavõ_, 
   {{0x68f8036b,0x00000000,0x00000000,0x00000000}},	//   qatd, --, --, --, 
   {{0x87e4030c,0x55580276,0x00000000,0x00000000}},	//   _اتتە, шаря_, --, --, 
   {{0x6e200472,0xd3788c75,0x539800d6,0x8c3c03be}},	//   ktob, ачу_, ався_, _uyğu, 
   {{0x201002c4,0xdb180e78,0xd7bc00d9,0x04440166}},	// [17d10] wuxi_, hluß, _בצהר, шеңн, 
   {{0x256d069b,0x20c8cf33,0x6e200175,0x115400d4}},	//   _mülk_, نباي_, dtob, окую, 
   {{0xc0e4044e,0xd4980276,0xb4f001c6,0x3ed4007b}},	//   _ዝድለ_, _вря_, _хүсч, مقار, 
   {{0xc0c4a705,0x3ef8084c,0x2011069c,0x00000000}},	//   _ғәзи, ундэ_, ruxi_, --, 
   {{0xfce4dd33,0x00000000,0x00000000,0x00000000}},	//   боло, --, --, --, 
   {{0x2909069d,0xc10400f1,0xdb180112,0x0d8412fa}},	//   óbal_, _دوسي, fluß, олін, 
   {{0x25480024,0x10a40b01,0x00000000,0x00000000}},	//   mėlė_, _диён, --, --, 
   {{0xd4980bd4,0x6e200589,0x254800c0,0x00000000}},	//   יכות_, btob, lėlė_, --, 
   {{0x64400042,0x00000000,0x00000000,0x00000000}},	//   _ânif, --, --, --, 
   {{0x25480006,0x44200165,0xb9540640,0x8c64013d}},	//   nėlė_, _oqh_, стић, стәд, 
   {{0xf74425fc,0x00000000,0x00000000,0x00000000}},	//   бено, --, --, --, 
   {{0xf0900375,0xabb400c7,0x00000000,0x00000000}},	//   לני_, _лахә, --, --, 
   {{0x25480006,0x44200175,0xe8ec0064,0x00000000}},	//   kėlė_, _aqh_, _нл_, --, 
   {{0x0ab5069e,0xc888f237,0xb8cc00fe,0x69f4030d}},	//   _بحمد, اخیل_, _কণ_, _уншă, 
   {{0xa3b00574,0x20040306,0xb9dc0092,0x25480064}},	//   टतं_, ánil_, _ጥሎ_, dėlė_, 
   {{0x660c01fa,0x00000000,0x00000000,0x00000000}},	//   brck, --, --, --, 
   {{0x7af80135,0x4420030a,0x6440107d,0x2000022e}},	// [17d20] _mewt, _eqh_, _šnit, _avji_, 
   {{0x3a3c0ac5,0x6e20022e,0xe3e400eb,0x254800c0}},	//   _mswp_, vtob, _ফিরব, gėlė_, 
   {{0x311c00cd,0x2bc807b7,0x00000000,0x00000000}},	//   _पाठः_, ागमा, --, --, 
   {{0x6e21069f,0xa5b81d5d,0xdef506a0,0x733400db}},	//   ttob, ntón, быш_, _اردئ, 
   {{0xb628037e,0x6e200784,0xccf906a1,0x25480153}},	//   _ｖｗ_, utob, иқа_, bėlė_, 
   {{0x2d9800c5,0x00000000,0x00000000,0x00000000}},	//   õpe_, --, --, --, 
   {{0x6e2106a2,0x7af80204,0x6fb42010,0xa06506a3}},	//   stob, _bewt, _همسا, _лара_, 
   {{0x6e20157b,0x6f94642c,0xa094011a,0x60d80139}},	//   ptob, _الرض, _הדלק_, _ğumi, 
   {{0x3a3c0204,0x7afc09f3,0x2fc40165,0x00000000}},	//   _cswp_, ðsta, mmog_, --, 
   {{0x660c01fa,0x684c001f,0xdce0012d,0x2fc401b9}},	//   vrck, ንግሥት, tkną, lmog_, 
   {{0x2d8c0161,0xd90c01ed,0xec980798,0xfbcc00ec}},	//   mife_, ریٹ_, _стај_, _ڌڪي_, 
   {{0x2d8d06a4,0x06ac02f5,0x2fc401a9,0x00000000}},	//   life_, _গণবি, nmog_, --, 
   {{0x9b402d8d,0xdce00327,0xa9a40117,0x00000000}},	//   _رنوو, linġ, _лидд, --, 
   {{0xd940033a,0xdce82804,0x231400f7,0x256c010e}},	//   _нечи, čići, өнгө_, _küli_, 
   {{0x7aec00a8,0x00000000,0x00000000,0x00000000}},	//   _întâ, --, --, --, 
   {{0xa5b83a9c,0x7af8002e,0x2d8c03e3,0x20040419}},	//   ctón, _xewt, hife_, ánim_, 
   {{0x2fc408a4,0x2d8c02a8,0x256c000d,0xdecc0023}},	// [17d30] dmog_, kife_, _lüli_, _ኣቦኡ_, 
   {{0xb9e00092,0x00000000,0x00000000,0x00000000}},	//   _የወ_, --, --, --, 
   {{0x610800da,0x93e00490,0xa6b8015b,0x2d8c03e0}},	//   vēlē, _खूपच_, _ইলিয়, dife_, 
   {{0xcce40075,0x256c00ac,0x00000000,0x00000000}},	//   ۋسىي, _sülh_, --, --, 
   {{0xdc241ea0,0x8f3402d5,0x2d8c03e0,0x254800c0}},	//   _böğr, яецц, fife_, pėlė_, 
   {{0xdd98034b,0x2d8c0175,0xd5fc011a,0xc1740345}},	//   ыше_, gife_, נפור, _بگرت, 
   {{0x4a24081f,0x7af8232c,0xb60c0131,0xfbc40138}},	//   _འདུལ_, _pewt, _ﺷﯘ_, обко, 
   {{0xd9b0090a,0xf4240154,0x00000000,0x00000000}},	//   ीष्ट, ময়কর_, --, --, 
   {{0x256c0254,0x3d942203,0x1cc80327,0x8f08030d}},	//   _eüli_, _диар, _ཊུམ_, _ыхра_, 
   {{0x2d8cf1f1,0xd90c04f2,0x6d5c0821,0x00000000}},	//   cife_, ریع_, öpat, --, 
   {{0x256c2057,0xdecc0023,0x86740022,0x00000000}},	//   _güli_, _ኣቦኣ_, ҿырц, --, 
   {{0x1cc00327,0x02b837bb,0x00000000,0x00000000}},	//   ཏྟཾ_, _आरंभ, --, --, 
   {{0x99d47b63,0xa5b839d1,0xe6142077,0x79580354}},	//   _اتصا, rtón, одя_, _вилĕ, 
   {{0x63ac02f0,0x80fc00fe,0xdec40092,0x00000000}},	//   _akcn, ুভুজ_, ችልና_, --, 
   {{0xa5b80de2,0x2fc4f286,0x00000000,0x00000000}},	//   atóo, ymog_, --, --, 
   {{0x96d402d9,0xf7700345,0xc8b4a9f1,0x2d8c03e0}},	//   _эскә, _زاب_, _عليک, zife_, 
   {{0xe474001f,0x2bc800dc,0x2d8c009a,0x623000d8}},	// [17d40] ከላከያ_, ागता, yife_, меѓу, 
   {{0xa5b83a6c,0xa1c002bf,0x00000000,0x00000000}},	//   ntól, дбуд, --, --, 
   {{0xa0d40014,0x2fc401a9,0x00000000,0x00000000}},	//   زِنا_, tmog_, --, --, 
   {{0x2d8cbed5,0xdce00210,0x00000000,0x00000000}},	//   wife_, mknę, --, --, 
   {{0x2fc4036b,0x64400162,0x256c0254,0xf1d0004e}},	//   rmog_, _ánir, _süli_, _жөжө, 
   {{0x98a402e2,0x442453b2,0xefe80451,0x7afc03b2}},	//   _abnč_, _بریف, _نعرو_, ðstn, 
   {{0x602106a5,0x2fc4022e,0x00000000,0x00000000}},	//   _одра, pmog_, --, --, 
   {{0x2d8d06a6,0x2fc4022e,0xdce0025c,0x00000000}},	//   sife_, qmog_, rinġ, --, 
   {{0xed5806ed,0x3fc801d3,0x17e00150,0x6d5c01f4}},	//   _коа_, _اگلی_, _ﺍﻟﺨﺯ, öpas, 
   {{0x91cc0c58,0x256d06a7,0xdce0031c,0x00000000}},	//   িৱৰ্, _tüli_, pinġ, --, 
   {{0x256c0254,0x00000000,0x00000000,0x00000000}},	//   _külv_, --, --, --, 
   {{0xdb4c0592,0x00000000,0x00000000,0x00000000}},	//   _لَم_, --, --, --, 
   {{0xc0d4001f,0x00000000,0x00000000,0x00000000}},	//   ርጋሉ_, --, --, --, 
   {{0xa5b8002e,0xd94000f3,0x00000000,0x00000000}},	//   rtóo, _жељи, --, --, 
   {{0x9f44e5ba,0xe38802e8,0x46140101,0x947405af}},	//   ënë_, ащал_, _کوخر, ودفا, 
   {{0xe51409d9,0x200415ad,0x00000000,0x00000000}},	//   _ताकि_, šnik_, --, --, 
   {{0xc1740801,0xd7c80fb4,0x00000000,0x00000000}},	// [17d50] плащ, _بويه_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc0d40020,0xdec4001f,0xdfa452d1,0xb6000118}},	//   ርላማ_, ችውን_, ојдо, řáte, 
   {{0x2d9c0e04,0xf410008f,0x81d45a09,0x4fa40014}},	//   _ajte_, _אפט_, _номх, وٕلٕ, 
   {{0x249c029f,0x81f4031c,0x73c000ee,0xdb180200}},	//   ğumu_, _བསྲི_, _чәре, lmuç, 
   {{0x6e902d4b,0x249c0342,0xa5b80419,0x4d6400d4}},	//   علوا, şumu_, któm, мків, 
   {{0x7afc0008,0x918404da,0x01cc1d00,0xa5b800e5}},	//   ðsto, _تۇلۇ, _ﺑﻮﻳﻨ, jtóm, 
   {{0x6d5d06a8,0xcfcc0150,0x00000000,0x00000000}},	//   öpar, _ﺑﺎﻳﺒ, --, --, 
   {{0x7e682e56,0x3eb801a8,0x3944037e,0x38c00166}},	//   ﺰﻣﻪﺕ_, _ást_, tdls_, _oçrí_, 
   {{0xc0d40020,0xc8b802ab,0x00000000,0x00000000}},	//   ርጋል_, ॉइंट, --, --, 
   {{0x6aa0ffcc,0x77b410d8,0xf7440a5b,0xfaa40214}},	//   _exof, láxi, пено, _کجای, 
   {{0xa5b865aa,0xb6a41607,0x8d840228,0x5ecc00fe}},	//   stól, зимл, _ىشەن, _হ্যে, 
   {{0x7bc8a09e,0xa5b80077,0x64400024,0x41bc185d}},	//   mmeu, ptól, _šnip, ्गास, 
   {{0x7bc90253,0xdce00210,0xaa400798,0x00000000}},	//   lmeu, tknę, _чешл, --, 
   {{0x6aa00175,0xe5a106a9,0xf71800c0,0x5fc80118}},	//   _zxof, хири, _ліпы_, िषाल, 
   {{0xb6a405f5,0x7bc80d27,0x98a001e0,0xe3600117}},	//   _нийл, nmeu, _ниҙе, нкси, 
   {{0x310906aa,0x51441ac1,0x17e002dd,0x00000000}},	// [17d60] йнап_, мдағ, _ﺍﻟﺠﺯ, --, 
   {{0x0f1403f3,0xc0d4044e,0x4cd002f5,0x3eb8013a}},	//   डल्स_, ርጋሕ_, _স্ফু, _ústy_, 
   {{0x7bc80c6a,0xdecc0023,0x00000000,0x00000000}},	//   kmeu, _ኣቦኻ_, --, --, 
   {{0xdfccefc3,0x77b40077,0x2d9c003e,0xdee0084c}},	//   هيل_, fáxi, _sjte_, еоци, 
   {{0x31a40109,0x7bc801a4,0x14c801b9,0x705401d3}},	//   zôzy_, dmeu, _دهگی_, _کنزا, 
   {{0x68000241,0x7bc87d9b,0xf1d000db,0x00000000}},	//   _jíjá, emeu, _чөбө, --, 
   {{0xa0a106ab,0x20840354,0xd04400ec,0x00000000}},	//   _зард, _ейри_, _تھذي, --, 
   {{0x3168031c,0xa2b01524,0x7bc8017a,0xd924009d}},	//   _hobz_, _आडम्, gmeu, үцэл_, 
   {{0x6f00c781,0x49a40032,0x256c03e0,0xad68009d}},	//   maoc, дынғ, _kült_, _лааз_, 
   {{0x29080086,0x6f00007b,0x3f8c0356,0x68000241}},	//   ûba_, laoc, _zmeu_, _níjá, 
   {{0xac748bf0,0xf3e003d4,0x98a40153,0x2e3401e1}},	//   _عائش, গীতৰ_, _manė_, bùfò_, 
   {{0x6f0106ac,0x6aa001c4,0x2ee4003a,0x200402f0}},	//   naoc, _txof, ncof_, ánii_, 
   {{0xaab8009f,0x2a340166,0x00000000,0x00000000}},	//   _ادار_, _хэер, --, --, 
   {{0x2b44030a,0x225c031c,0x4cd00154,0x671c000d}},	//   _haoc_, _ħuk_, _স্যু, _भावक_, 
   {{0x6f0106ad,0x2b440156,0x04c84f4e,0x680001d3}},	//   kaoc, _kaoc_, زوري_, _díjá, 
   {{0x53440131,0x97a402d5,0x57c800dc,0x62800115}},	//   нхуа, _прыл, रगृह, ŝnom, 
   {{0x6f0106ae,0x2b440165,0x822c0023,0x291c058a}},	// [17d70] daoc, _maoc_, _ስርሒታ, ogta_, 
   {{0x291d06af,0x7bc80165,0xf5400092,0x96b8007b}},	//   ngta_, zmeu, ኖሎጂዎ, _عايز_, 
   {{0x20040296,0x7bc801f5,0xe2780150,0x98a40064}},	//   éni_, ymeu, _ﹼﻁﻬﻡ_, _danė_, 
   {{0x6f0001fa,0x00000000,0x00000000,0x00000000}},	//   gaoc, --, --, --, 
   {{0xa3e003f3,0xa5b801d3,0x17e0005e,0x00000000}},	//   _फंड_, jtók, _ﺍﻟﺤﺯ, --, 
   {{0xed5506b0,0x41c4036b,0xc1042abb,0x00000000}},	//   дош_, _آقسق, _زوري, --, 
   {{0x6f0001f2,0xa6d80008,0x7bc801a4,0x7f9401c6}},	//   baoc, meðf, tmeu, _жавх, 
   {{0x26d8d059,0x6f000481,0xaa300020,0x291d06b1}},	//   _ngqo_, caoc, _ጠቁመዋ, egta_, 
   {{0x7bc906b2,0x69dc00b0,0x9e7c010a,0xa5b800e5}},	//   rmeu, _ōper, _сывă_, rtój, 
   {{0x7bc8091f,0x291c05b1,0x37e421cb,0xd1d00023}},	//   smeu, ggta_, моог, _እቶት_, 
   {{0xf77106b3,0x385800d4,0x23bc2e35,0xb8f400cd}},	//   ناح_, ірою_, ्षाद, _ाः_, 
   {{0x291c058a,0x00000000,0x00000000,0x00000000}},	//   agta_, --, --, --, 
   {{0xdb18000d,0x2bc81546,0x671c000d,0x00000000}},	//   rmuä, ागरा, _भारक_, --, 
   {{0x6f000219,0x06ac015b,0x00000000,0x00000000}},	//   zaoc, _গণশি, --, --, 
   {{0x79800921,0xe9a00c75,0x33d40212,0x34dc0037}},	//   mhlw, _шашп, діат, _मलीद, 
   {{0xddcc0115,0x79800083,0x6f0000d8,0x256c01d3}},	//   _ĥeŝb, lhlw, xaoc, _sült_, 
   {{0x6f004beb,0x717400c6,0x71e800c6,0xb144e174}},	// [17d80] vaoc, وهرا, زفاف_, мнал, 
   {{0x79800117,0xd5a401d5,0x414400d1,0x7afc148b}},	//   nhlw, _سلجی, ндуң, ðstj, 
   {{0x6f004beb,0xb4e86173,0xdce00118,0x00000000}},	//   taoc, मडी_, skně, --, 
   {{0x200406ed,0xb804230e,0xdb2001e1,0x00000000}},	//   ânia_, _शबनम_, _ìsèd, --, 
   {{0x6f0106b4,0x62880022,0xc2f400cc,0x00000000}},	//   raoc, úgot, _ছাচি_, --, 
   {{0xa3e00412,0x00000000,0x00000000,0x00000000}},	//   _फूड_, --, --, --, 
   {{0x5dc80ef6,0xebc40114,0x00000000,0x00000000}},	//   _ﺗﻮﻗﺴ, мљин, --, --, 
   {{0xa5b80174,0x00000000,0x00000000,0x00000000}},	//   ttók, --, --, --, 
   {{0x6d240114,0x2d2c0023,0xdce00139,0x00000000}},	//   _одаз, _ተጎልቢ, annı, --, 
   {{0x798003cb,0x01c801ec,0x8f000006,0xddc0014b}},	//   ghlw, _ﺒﺎﻟﺨ, вiч_, _абуи, 
   {{0x6d5906b5,0xab28b8eb,0x9b40438b,0x2b440841}},	//   _inta, _можа_, رنیو, _taoc_, 
   {{0x6d480c8c,0xc5e8025c,0xbc78008f,0xa5b801e7}},	//   ldfa, _འཕྱི, _צװײט, mtói, 
   {{0x6a845dc9,0xa5b80597,0xe4e400d6,0x6d480042}},	//   _юлда, ltói, дібн, odfa, 
   {{0x6d4906b6,0x7980015d,0x00000000,0x00000000}},	//   ndfa, chlw, --, --, 
   {{0xa5b80597,0x6d5800aa,0x256c07de,0xca4801fb}},	//   ntói, _mnta, _süls_, _hờ_, 
   {{0x6d58020c,0x2c4c000f,0x4a0c031c,0xc2c400c6}},	//   _lnta, _męd_, _གྷོལ_, فيزي, 
   {{0x6d5814dc,0xb784010b,0xa5b800ae,0xca480051}},	// [17d90] _onta, _edỳä, htói, _jờ_, 
   {{0x41b46884,0xca48001e,0xa6d802d2,0x48dc00cc}},	//   رمار, _mờ_, feðg, _মজুৰ, 
   {{0x6d480368,0xca4801fb,0x939400e5,0x00000000}},	//   ddfa, _lờ_, رجہا, --, 
   {{0xc7b805be,0x00000000,0x00000000,0x00000000}},	//   buđe_, --, --, --, 
   {{0x427804ac,0x68e8b75f,0xf3240220,0x27ec0205}},	//   _זאָג, _offd, _سۋلى_, _ltfn_, 
   {{0x2c4c000f,0x61ec022e,0x4a0c0327,0x00000000}},	//   _będ_, _itcl, _གྷེལ_, --, 
   {{0x69dc00b0,0x8d7401f7,0xec100345,0x7e78294f}},	//   _ōpep, خانا, هوود, _şapı, 
   {{0x6d4906b7,0x6c30384b,0xca48001e,0xfa6816a4}},	//   adfa, افيا, _bờ_, заик_, 
   {{0xc6900201,0xca480016,0x63a00048,0x6d480009}},	//   ጀመሪያ_, _cờ_, _ínnu, bdfa, 
   {{0xf9900597,0xca480051,0x66e06090,0x00000000}},	//   طبخ_, _dờ_, ғора, --, 
   {{0x7d0106b8,0xa800009d,0x9c4495a2,0x00000000}},	//   _iels, лзэл, _юхал, --, 
   {{0x7980009a,0x61ec02d0,0x3078010f,0x00000000}},	//   shlw, _otcl, פארנ, --, 
   {{0x7d0106b9,0x64a00588,0xae0007f7,0xca480208}},	//   _kels, ҳара, रीपन_, _gờ_, 
   {{0x7d0106ba,0x7ae906bb,0x7bd80455,0x98a40055}},	//   _jels, lcet, _hiwu, _janī_, 
   {{0x64a106bc,0x7bd80337,0xe9d4036b,0x7d0106bd}},	//   гара, _kiwu, _якш_, _mels, 
   {{0x7bd906be,0xa6d8032e,0x883400c0,0x00000000}},	//   _jiwu, geðd, _рэшц, --, 
   {{0x7bd8a2d3,0x290c0142,0x7d00002f,0xca480051}},	// [17da0] _miwu, _ydfa_, _oels, _xờ_, 
   {{0x7bd906bf,0x98a400b0,0xe29401c0,0xa6d80174}},	//   _liwu, _nanī_, хау_, teðg, 
   {{0xc7b81b24,0x2518008f,0x9f4002d2,0x00000000}},	//   suđe_, _צוטא, _stjá_, --, 
   {{0x5eb8015b,0x7ae800f3,0x59dc0401,0x00000000}},	//   েশনে, jcet, नदार, --, 
   {{0x7d0106c0,0x2de4004b,0x00000000,0x00000000}},	//   _bels, روغۍ_, --, --, 
   {{0x7bd801e1,0x7f48003a,0x7d002f86,0x6d480367}},	//   _aiwu, _eaeq, _cels, udfa, 
   {{0x6d489256,0x7bd906c1,0xca4801fb,0x290c0789}},	//   rdfa, _biwu, _sờ_, _rdfa_, 
   {{0x7f480369,0x7bd80198,0xa3e005f9,0x7d0106c2}},	//   _gaeq, _ciwu, _फंस_, _eels, 
   {{0x7d0106c3,0xa5b80597,0xada506c4,0x290c005a}},	//   _fels, stói, _заал, _pdfa_, 
   {{0x7d0106c5,0x7ae85e23,0xca4801fb,0xa2580798}},	//   _gels, acet, _vờ_, _ozôn, 
   {{0x7bd8022f,0x6c5400d4,0xd91400c7,0x00000000}},	//   _fiwu, _ятає, хьы_, --, 
   {{0x7ae906c6,0xca480016,0xab28337e,0xa098010f}},	//   ccet, _tờ_, _хода_, לייט, 
   {{0x7d0106c7,0x6c300014,0x683400e5,0x00000000}},	//   _yels, _شہکا, _büdö, --, 
   {{0xae00069f,0x7bd8542c,0x7d00344a,0x68e802d0}},	//   रीयन_, _ziwu, _xels, _uffd, 
   {{0x94a906c8,0x7bd83142,0x439402bf,0x78440022}},	//   етта_, _yiwu, вавс, _аьыҧ, 
   {{0x58b80375,0x86540139,0x22841a71,0x18680023}},	//   _ממוצ, _аких, нузг, ስግጋር_, 
   {{0xdb1906c9,0x7afc148b,0x00000000,0x00000000}},	// [17db0] fluê, ðsti, --, --, 
   {{0x7f480369,0x20040120,0x45d421fa,0xc0c40075}},	//   _saeq, ânio_, _шопс, вәби, 
   {{0xd01001ed,0xb7d800a2,0x3d0c00bc,0x00000000}},	//   یلے_, _üçüň, _सयौं_, --, 
   {{0x3ed433d2,0x00000000,0x00000000,0x00000000}},	//   نقار, --, --, --, 
   {{0x7d0106ca,0xd0100075,0x00000000,0x00000000}},	//   _pels, للە_, --, --, 
   {{0x7ae906cb,0x7bd906cc,0x4ea40588,0x7d000200}},	//   wcet, _siwu, ырха, _qels, 
   {{0xae0005f9,0x7bd906cd,0x7ae8020c,0xbb4401ca}},	//   रीबन_, _piwu, tcet, вейк, 
   {{0x7bd803f0,0x7d0106ce,0x0cd00183,0xc0540092}},	//   _qiwu, _wels, ৱৰ্ত, _የሚታገ, 
   {{0x7ae80311,0x7d0106cf,0xa3e02ba2,0x7bd8047e}},	//   rcet, _tels, _फूस_, _viwu, 
   {{0x7ae906d0,0x7d006fb2,0x6d840162,0x7bd906d1}},	//   scet, _uels, _aðaf, _wiwu, 
   {{0x7bd906d2,0x8d8401a9,0x00000000,0x00000000}},	//   _tiwu, _сутд, --, --, 
   {{0x68340112,0xe1fc110e,0x35d8012d,0xb8d80118}},	//   _südö, _owó_, _यूज़, _अँ_, 
   {{0xe9cc21ae,0xe1fc0ca8,0xabdc0150,0x00000000}},	//   _вк_, _nwó_, _ﺇﻟﻐﺎ, --, 
   {{0x81f40135,0x9774891e,0x00000000,0x00000000}},	//   _བསྟི_, _әткә, --, --, 
   {{0xe1fc0248,0xb4bc00dc,0xc7b80051,0x3a2c0166}},	//   _awó_, ेधे_, ttđt_, ltep_, 
   {{0xf7700133,0x671c000d,0xabe40150,0x00000000}},	//   _خات_, _भाएक_, _ﻏﺎﻴﺎ, --, 
   {{0xe29506d3,0x3a2c9d36,0xb5c406d3,0x312401b9}},	// [17dc0] ват_, ntep_, _ийил, кдаг, 
   {{0x6d44016b,0x3074084c,0x00000000,0x00000000}},	//   _ɔkas, куес, --, --, 
   {{0xe040ca08,0x6140b3eb,0x308506d4,0x00000000}},	//   инфи, реха, خلاف, --, 
   {{0x3a2c496e,0x00000000,0x00000000,0x00000000}},	//   ktep_, --, --, --, 
   {{0xae0000e1,0x20040162,0x00000000,0x00000000}},	//   _रौशन_, ánir_, --, --, 
   {{0xa5b80798,0x00000000,0x00000000,0x00000000}},	//   stóv, --, --, --, 
   {{0xe1fc0943,0x6598008f,0xe0d42bbd,0x29c002d2}},	//   _zwó_, ויסק, _авр_, fðan_, 
   {{0xa0a016c3,0x3a2c013c,0xfd4800b8,0xab6400ef}},	//   _тасд, ftep_, _mamṛ, _ogļū, 
   {{0xed440588,0xcdc40022,0x49d80a93,0x92d400fe}},	//   _инап, _баақ, ндию_, সুৰ_, 
   {{0x1e80063b,0x00000000,0x00000000,0x00000000}},	//   _тлум, --, --, --, 
   {{0x99601075,0xdca0f266,0xc81c0092,0xbda8007b}},	//   ртыл, _кафи, _ዶክመን, _أطقم_, 
   {{0x7c840640,0x38c4728c,0x6bd400db,0xfa80010b}},	//   _суђе, ышың, _شتار, рңәп, 
   {{0x6b8004c9,0x3a2c0077,0xdecc0023,0xcc888074}},	//   _ilog, ctep_, _ኣቦን_, _غنچه_, 
   {{0x6b80000a,0x491c00bc,0xa5b801d3,0x00000000}},	//   _hlog, _माटो_, jtót, --, 
   {{0x6b8004ce,0xdb180137,0x798c03a2,0xd4980f5c}},	//   _klog, fluè, _ïawa, врт_, 
   {{0x64400798,0x26180118,0x00000000,0x00000000}},	//   _ânim, _बिपी_, --, --, 
   {{0x28cc069f,0x6b8000f3,0xd250143e,0x00000000}},	// [17dd0] हेरि, _mlog, ينِ_, --, 
   {{0x6b8106d5,0x00000000,0x00000000,0x00000000}},	//   _llog, --, --, --, 
   {{0x6b8106d6,0x4394140e,0x409506d7,0x29c006ea}},	//   _olog, _банс, دلار, yðan_, 
   {{0x25a00472,0xdb180036,0xd1c800d1,0x00000000}},	//   lnjl_, rluë, ىبەم_, --, 
   {{0x3ea9033e,0x9f400240,0x3fc402dd,0x00000000}},	//   çat_, _hujë_, _ұрағ, --, 
   {{0x6b8106d8,0x3ea8003d,0x925801d9,0x2618000d}},	//   _alog, ħat_, _ششُر_, _बिनी_, 
   {{0x6b8106d9,0xcc0825aa,0x6ab400cc,0xdb1806af}},	//   _blog, نزين_, _øyfj, llué, 
   {{0x6b8106da,0xe8f44494,0x9f400200,0xa2700023}},	//   _clog, ңлы_, _mujë_, _የመንን_, 
   {{0x69c80491,0x29c009f3,0x00000000,0x00000000}},	//   _bhfe, rðan_, --, --, 
   {{0x6b8106db,0xe8f40139,0x3a2c00fd,0x64544831}},	//   _elog, лль_, rtep_, _orxi, 
   {{0xa3e01715,0x6b801125,0x3a2d06dc,0xb7b4063f}},	//   _फूल_, _flog, step_, bụl, 
   {{0x6b8106dd,0xdeb80b45,0x64400784,0x0c8401e0}},	//   _glog, _sauƙ, _ániy, _тыум, 
   {{0x645506de,0xda6400db,0xfd4800dc,0xa5b800e5}},	//   _arxi, _جااي, _samṛ, jtós, 
   {{0x9f40036e,0x69c803ce,0xa5b801e7,0x00000000}},	//   _bujë_, _सीपी, hróf, --, 
   {{0xc7b81b24,0x6b8002d0,0x00000000,0x00000000}},	//   suđa_, _ylog, --, --, 
   {{0xf77106df,0xdb181497,0x2898010f,0xb9dc0240}},	//   _چاک_, flué, _ריקא, _ኣረ_, 
   {{0xa5b83b82,0xf7701d10,0x2d90020c,0x71a40022}},	// [17de0] dróf, _ناک_, èyek_, гааз, 
   {{0xf77000ec,0xfd4800b8,0x00000000,0x00000000}},	//   _خاڪ_, _tamṛ, --, --, 
   {{0xdb180561,0x161c01ad,0xa5b808a5,0x00000000}},	//   pluè, भंकर_, fróf, --, 
   {{0xb904003d,0xa5b8c6bf,0xe0cc0014,0x00000000}},	//   _ཨུ_, stót, سٲن_, --, 
   {{0x6b8000a3,0x00000000,0x00000000,0x00000000}},	//   _rlog, --, --, --, 
   {{0x00d804a2,0xa5b906e0,0x7dcc1427,0xdee00b01}},	//   ربەت_, ltór, húsf, _ғофи, 
   {{0x6b8106e1,0x6c6400dd,0x25d4010f,0xef1800d8}},	//   _plog, العہ_, נוצן_, _пмв_, 
   {{0xa5b906e2,0xe454008f,0x1e800bd6,0x71a4014b}},	//   cróf, ריקט_, рләм, _раҳз, 
   {{0x6b80151c,0xa9280046,0xe29c0162,0x00000000}},	//   _vlog, ніне_, _keða_, --, 
   {{0xdd8cc850,0xb928063f,0xc878007f,0x00000000}},	//   _فوق_, matụ_, tyğ_, --, 
   {{0x6b8106e3,0xdb4c0131,0xa5b8068f,0xdecc02d3}},	//   _tlog, _лю_, któr, _ኣቦና_, 
   {{0x6b800bb8,0x3b000208,0x00000000,0x00000000}},	//   _ulog, _đhqg_, --, --, 
   {{0xb60400ef,0x6e2106e4,0x00000000,0x00000000}},	//   _nišā, nuob, --, --, 
   {{0x2bc00490,0x65840022,0x00000000,0x00000000}},	//   शतवा, уымз, --, --, 
   {{0x6e2005d5,0xa5b81941,0x3ea80327,0x04880139}},	//   huob, hróg, żatx_, тәпи_, 
   {{0x671c000d,0x00000000,0x00000000,0x00000000}},	//   _भाटक_, --, --, --, 
   {{0xc1b801c0,0x6e2003cd,0xb27400c7,0x00000000}},	// [17df0] влах_, juob, актә, --, 
   {{0xa5b906e5,0x2c44001f,0x61f800fd,0x6e200064}},	//   dróg, ረተሰቡ, _çulm, duob, 
   {{0xd25000aa,0x5fa00131,0xa5b906e6,0x7dcc01e7}},	//   ينې_, مەسم, tróf, lúsg, 
   {{0xa5b82137,0x443001c8,0xc7b801fa,0x8fe401e0}},	//   ctór, mtz_, brđe_, сәрҙ, 
   {{0x443106e7,0x8ee80212,0x0eb802dd,0x9d5000e5}},	//   ltz_, умів_, лушы_, ینچت, 
   {{0x9f40002e,0x443106e8,0x00000000,0x00000000}},	//   _mujé_, otz_, --, --, 
   {{0x443106e9,0x8bf000bd,0xa5b801a8,0xe80400bc}},	//   ntz_, _টিউন_, próf, वीमा_, 
   {{0x443001c0,0x69c80d0a,0x543c00c8,0x5c0401ec}},	//   itz_, _सीबी, געהא, _ұяда, 
   {{0xfaa506ea,0x44300334,0xc0bc0092,0x8b8800cf}},	//   рапо, htz_, ሳይም_, دەنە_, 
   {{0x8e8400c6,0x0bb80228,0x9f40007f,0xa5b801e7}},	//   _الكه, ктөө_, _sujè_, nród, 
   {{0xd764221d,0x00000000,0x00000000,0x00000000}},	//   مندی, --, --, --, 
   {{0x9ba00150,0x443012e8,0xa5b801e7,0x00000000}},	//   _دەبى, dtz_, hród, --, 
   {{0x443106eb,0xe8ec2cfe,0xdb1800db,0xe9cc00ec}},	//   etz_, _мл_, lluï, _ڪٺو_, 
   {{0x44303ddd,0xa5b8033f,0xca7400f2,0x00000000}},	//   ftz_, wtór, _دامغ, --, 
   {{0xa5041639,0xb4e42e1e,0xa5b803b2,0x00000000}},	//   реса_, _फली_, ttór, --, 
   {{0xb4b4012d,0x437400db,0x00000000,0x00000000}},	//   _जडी_, буут, --, --, 
   {{0x443106ec,0xa5b906ed,0x87240eff,0xe574013e}},	// [17e00] atz_, rtór, _اعىم, уҷӯ_, 
   {{0xa5b906ee,0x6e2002f0,0xc644009f,0x00000000}},	//   stór, vuob, _اَٿي, --, 
   {{0x13a82c26,0xc7b8107d,0x00000000,0x00000000}},	//   _مندی_, srđe_, --, --, 
   {{0xa5b809c2,0x113801e0,0xa0640063,0x00000000}},	//   tróg, ъяғы_, јаца_, --, 
   {{0x3a3c008b,0xc32c03cc,0xdfcc2bd8,0x0d840139}},	//   _npwp_, _سەل_, ذيه_, бһан, 
   {{0xdd8d06ef,0xdb1800db,0xa5b80332,0x00000000}},	//   وون_, fluï, cród, --, 
   {{0xa06506f0,0xa0a025ee,0x98a40139,0x3eac01e3}},	//   _кара_, _дард, _onnı_, _exet_, 
   {{0xa5b80bcd,0x00000000,0x00000000,0x00000000}},	//   próg, --, --, --, 
   {{0xdd8c00ec,0x00000000,0x00000000,0x00000000}},	//   _ڪول_, --, --, --, 
   {{0xec9801ee,0x4430007c,0x00000000,0x00000000}},	//   _итеј_, ytz_, --, --, 
   {{0x3a3d06f1,0xdd8d06f2,0x9f40002e,0xb3880023}},	//   _epwp_, _تول_, _sujé_, _መገድን_, 
   {{0xdc980bd9,0x20040276,0x9870177b,0x443001f7}},	//   _ביבל, ânii_, іляц, vtz_, 
   {{0xaad0197c,0xb958001f,0x29840024,0x00000000}},	//   देशक, _ገበሬዎ, _выйг, --, 
   {{0xe4a506f3,0xd94000f7,0xa6d8032e,0x00000000}},	//   арбо, _мечи, beðn, --, 
   {{0x443106f4,0x25e00456,0xbb2c01ec,0x98a0009b}},	//   utz_, _टंकी_, _ﺩﻴﻥ_, _миље, 
   {{0x3a3c0334,0xd8d8011a,0x938800c7,0x61f80139}},	//   _ypwp_, _בקור, асуа_, _çulk, 
   {{0xa78506f5,0x60e40212,0xd5b000f1,0xa5b8012d}},	// [17e10] _مشکو, ацез, سفې_, tród, 
   {{0xba0002d3,0xb6140150,0x40e46171,0x00000000}},	//   _ሃየ_, _ﹸﺩ_, ссағ, --, 
   {{0xb9dc02d3,0xf07800fb,0x00000000,0x00000000}},	//   _ኣየ_, лифә_, --, --, 
   {{0xe61c00e4,0xcfa401a9,0x00000000,0x00000000}},	//   orô_, ошчи, --, --, 
   {{0xb7b401f2,0x00000000,0x00000000,0x00000000}},	//   wụk, --, --, --, 
   {{0xb7b4063f,0x7dcc00d7,0x00000000,0x00000000}},	//   tụk, kúse, --, --, 
   {{0xbc3906f6,0x00000000,0x00000000,0x00000000}},	//   استا_, --, --, --, 
   {{0xa6d80008,0x7dcc0ba1,0x28b800e1,0xfe08027d}},	//   veðn, dúse, _उड़ि, _مقري_, 
   {{0x3f9c055a,0xf36800df,0x00000000,0x00000000}},	//   miwu_, רדפּ, --, --, 
   {{0x8d7406d5,0xf98800aa,0x3f9d06f7,0xf984009d}},	//   _والا, اندي_, liwu_, сгоо, 
   {{0x6d8800dd,0xdb181941,0xccf801ef,0x00000000}},	//   _حملہ_, lluí, _mněl_, --, 
   {{0x34c00882,0x3f9c0113,0x00000000,0x00000000}},	//   jñaḥ_, niwu_, --, --, 
   {{0x6fd8012c,0xa5b8012d,0x61f80205,0x8698009d}},	//   _důch, drób, _çulh, атрт_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3f9c0161,0x88c402dd,0xe81c1a04,0x00000000}},	//   kiwu_, _وتىل, _भिया_, --, 
   {{0x394401b8,0x5924031c,0x64a001fe,0x25e0000d}},	//   lels_, ྡུམས_, часа, _टूकी_, 
   {{0xe3b40415,0xd78800f1,0x00000000,0x00000000}},	// [17e20] ёбу_, _منډو_, --, --, 
   {{0x394506f8,0xa3e0000d,0x2bcc00cd,0xdce0008e}},	//   nels_, _फूक_, _हीना, kinı, 
   {{0xa998008f,0x55f401d5,0xdce00205,0xa5b80210}},	//   נבער, _учқу, jinı, brób, 
   {{0x35800020,0x394506f9,0xdb18056a,0x3f9c003a}},	//   _ያለበት_, hels_, fluí, giwu_, 
   {{0x394506fa,0xe294010b,0x162000e1,0x00000000}},	//   kels_, _гая_, _बिफर_, --, 
   {{0x425401d9,0x394404cc,0x7774022e,0x60d801e4}},	//   _بچٲر, jels_, _loyx, _ŝume, 
   {{0x30840597,0x394506fb,0xe4f8255c,0x61f80327}},	//   _الأف, dels_, ्रति_, _ħuli, 
   {{0x138c001f,0x3944017a,0x2078010f,0x0e040107}},	//   _ማረፊያ_, eels_, _גאלא, _дӯко, 
   {{0xdb185b7d,0x394506fc,0x6e940597,0x8eb4075e}},	//   cluí, fels_, _الذا, _بەشت, 
   {{0x394506fd,0x481506fe,0xdce00139,0x00000000}},	//   gels_, омос, binı, --, 
   {{0x777506ff,0x00000000,0x00000000,0x00000000}},	//   _boyx, --, --, --, 
   {{0xe61c06ed,0x7c640b8c,0x3210005b,0x7dcc0419}},	//   trô_, _باكل, ksyy_, rúse, 
   {{0x39443344,0x273c0023,0x6fd8013a,0x00000000}},	//   bels_, _ክዛረበ, _vůch, --, 
   {{0x3f9c02ce,0x39450700,0xa5b801e7,0x00000000}},	//   ziwu_, cels_, dróc, --, 
   {{0x3f9c0198,0xa2d8190c,0x5f0800dc,0x53440107}},	//   yiwu_, पेन्, ारम्_, ӯхта, 
   {{0xfa840092,0x00000000,0x00000000,0x00000000}},	//   ኮራኩር_, --, --, --, 
   {{0x7dcc7a26,0x16201b76,0x00000000,0x00000000}},	// [17e30] núsc, _बियर_, --, --, 
   {{0x3eb803b2,0xd7d40133,0xe4a400d8,0xa088008e}},	//   _østi_, _وڵێک, _грмо, лсез_, 
   {{0xa5b8514a,0x3f9d0701,0xd498084c,0x7dcc0332}},	//   prób, tiwu_, _гря_, húsc, 
   {{0x6574044e,0x39450702,0x69c838d2,0x00000000}},	//   _hoxh, zels_, _सीसी, --, 
   {{0x7dcc00f7,0xfce47bb3,0x39442045,0x3f9c00e8}},	//   júsc, ооло, yels_, riwu_, 
   {{0xdbb447da,0x0094008e,0x00000000,0x00000000}},	//   әткә_, _дигэ, --, --, 
   {{0x39450703,0x657401ab,0x3f9c0113,0xdef8e7bb}},	//   vels_, _moxh, piwu_, _быз_, 
   {{0x3f9c0117,0x1ee417a5,0x3944ed19,0x6574d347}},	//   qiwu_, _طوطی_, wels_, _loxh, 
   {{0x39450704,0x7774022e,0x6d8402d2,0x17e002dd}},	//   tels_, _royx, _iðan, _ﺍﻟﺘﺯ, 
   {{0x65740921,0x39790705,0x3cf000ac,0x3944f110}},	//   _noxh, рсию_, _üzv_, uels_, 
   {{0x39450706,0xa6d80436,0xf74457c6,0x00000000}},	//   rels_, seðl, оено, --, 
   {{0x39450707,0xf98800ec,0x8d8400f7,0x366808ca}},	//   sels_, انگي_, _وشەن, қаҳо_, 
   {{0x39450708,0x70c40d5f,0x65746445,0x29d00451}},	//   pels_, _वर्ल, _boxh, _ڪيوس, 
   {{0xa5050709,0x4cd0015b,0x00000000,0x00000000}},	//   жера_, _স্টু, --, --, 
   {{0x65740399,0xa5b80034,0xc7b8107d,0x7399070a}},	//   _doxh, wróc, srđa_, атас_, 
   {{0xf3480120,0x778457c6,0x00000000,0x00000000}},	//   јпал_, _флиз, --, --, 
   {{0xe3b41cd0,0xccf8013a,0xf2a40022,0x00000000}},	// [17e40] ібу_, _sněm_, циап, --, 
   {{0x65740023,0x00000000,0x00000000,0x00000000}},	//   _goxh, --, --, --, 
   {{0x25e00c2e,0xf21c068f,0xb6000118,0x321001f4}},	//   _टूटी_, यूज़_, řáde, ssyy_, 
   {{0x7dcc2760,0xaec458f0,0x6574009a,0x80d401b9}},	//   yúsc, обел, _zoxh, سمنچ, 
   {{0xa3e00b03,0x00000000,0x00000000,0x00000000}},	//   _फूट_, --, --, --, 
   {{0x2d9800e4,0x00000000,0x00000000,0x00000000}},	//   òpe_, --, --, --, 
   {{0x705402e9,0x2004054e,0x00000000,0x00000000}},	//   _بنزا, ânit_, --, --, 
   {{0xfb8802dd,0x261801ad,0x00000000,0x00000000}},	//   йрық_, _बिली_, --, --, 
   {{0xada401c0,0xe944023a,0x7afc0165,0x2fc4022e}},	//   _даал, охно, ñsta, mlog_, 
   {{0x09e004c5,0x2fc5070b,0x2909070c,0x7afc43bc}},	//   _মৌজা, llog_, úba_, ısta, 
   {{0x6c486449,0x2fc5070d,0x65740327,0x38680139}},	//   _خلاف_, olog_, _roxh, _ƅara_, 
   {{0x6f01070e,0x2fc40113,0x69c80034,0xe664588c}},	//   nboc, nlog_, _सीरी, отго, 
   {{0x6e2001a9,0x7dcc0332,0x569400db,0x66c8022e}},	//   nrob, lúsa, даят, рунг_, 
   {{0x6e2061b5,0x2fc401e2,0x6f001f5d,0x8894030d}},	//   irob, hlog_, hboc, _нилх, 
   {{0x6e21070f,0x7dcc00c6,0x99442abb,0x657401bf}},	//   hrob, núsa, _ذليل_, _voxh, 
   {{0x09e0045e,0x27fc01f9,0x2fc46085,0x00000000}},	//   _মৌচা, mptn_, jlog_, --, 
   {{0x51f83c1b,0x4f2c0020,0xcfd002f5,0x3988438d}},	// [17e50] жную_, ተዳደር, িদান, _húsa_, 
   {{0x6e20389e,0x6f0001c7,0x162000e1,0x2fc40142}},	//   drob, eboc, _बितर_, elog_, 
   {{0x6e210710,0x2fc40368,0x2f0001a9,0x20050711}},	//   erob, flog_, _bаg_, èni_, 
   {{0x4fe856a4,0xa1440014,0x398802d2,0xdb1801f4}},	//   імін_, _ڈیرٕ_, _músa_, lmuö, 
   {{0x6e210712,0x398803b2,0x4e040006,0x975c010f}},	//   grob, _lúsa_, дзіб, ידאט, 
   {{0xf2d00bd9,0x7dcc03b2,0xd5fc011a,0x00000000}},	//   _נעם_, fúsa, ספור, --, 
   {{0x2fc50713,0x1fa50714,0xe9cc177b,0x9f68026b}},	//   blog_, _драг, _якi_, _краз_, 
   {{0x9d080154,0x00000000,0x00000000,0x00000000}},	//   রলেন_, --, --, --, 
   {{0x539c010f,0x00000000,0x00000000,0x00000000}},	//   יסהא, --, --, --, 
   {{0x2d8c0165,0x7dcc00ae,0x61f800a2,0x6e440240}},	//   chfe_, búsa, _çulu, _መልኣኽ, 
   {{0x7c583e58,0xd7080131,0xe8f4084c,0x7dcc01e7}},	//   _دلار_, يىدۇ_, ялэ_, cúsa, 
   {{0x6e44069c,0x29180086,0xeaac01ed,0x398802d2}},	//   _መልእኽ, _ôpan_, ئٹی_, _dúsa_, 
   {{0x987409a8,0xeaac01f0,0x00000000,0x00000000}},	//   _išče_, _чй_, --, --, 
   {{0x7c2c0227,0x398802d2,0xa2ac01bc,0x33f401a9}},	//   ńaru, _fúsa_, ंपन्, зчас, 
   {{0x2fc50715,0x6e20033f,0x715800fb,0x00000000}},	//   ylog_, zrob, ҙрас_, --, 
   {{0x6d8426b8,0x6e200009,0x37046f65,0xf7710716}},	//   _aðal, yrob, _эпиг, _ساب_, 
   {{0xc76457d4,0x2f00022e,0x75d40137,0x35a40108}},	// [17e60] _زايى, _rаg_, _ىيعا, _наиг, 
   {{0x9f4405bb,0xf17004d3,0x2fc50717,0x733400e5}},	//   ênî_, رێزگ, wlog_, _کردئ, 
   {{0x2fc4193f,0x6f000076,0x00000000,0x00000000}},	//   tlog_, tboc, --, --, 
   {{0x2fc4089c,0xe81c0316,0x6d84032e,0x00000000}},	//   ulog_, _भिसा_, _eðal, --, 
   {{0x2fc4225e,0xde00004e,0xa6d802d2,0x00000000}},	//   rlog_, епчи, geðh, --, 
   {{0x2fc40385,0x6f010718,0x5ea00740,0xdee0c7cb}},	//   slog_, sboc, عمول, хочи, 
   {{0x6e200072,0x5d100f87,0xa5b803f2,0x30840408}},	//   srob, ربوز, krón, _хăйс, 
   {{0x7dcd0719,0x1fa45d9f,0x398803b2,0x6e94028e}},	//   rúsa, _екси_, _rúsa_, _فلزا, 
   {{0xa5b81e14,0xfe6c2a77,0x00000000,0x00000000}},	//   drón, _نگو_, --, --, 
   {{0xf1bca5b3,0x64400166,0x999c56a3,0x00000000}},	//   ्तिन, _änig, rtuş_, --, 
   {{0xdd8c0597,0x6d480451,0xa5b8056a,0xec146071}},	//   _حول_, mefa, frón, _روشد, 
   {{0xd1f01ee0,0x00000000,0x00000000,0x00000000}},	//   ልማት_, --, --, --, 
   {{0xf1bc32fd,0x00000000,0x00000000,0x00000000}},	//   ्तान, --, --, --, 
   {{0x6d49071a,0xe97001ed,0xe664013e,0x00000000}},	//   nefa, _سنبھ, отҳо, --, 
   {{0x69d82155,0xa5b80077,0xb7b401f2,0x98d400db}},	//   mmte, brón, tụt, _ىبىز_, 
   {{0x6d480851,0x290c0e39,0xa5b9071b,0xd37800db}},	//   hefa, _hefa_, crón, пчу_, 
   {{0x290d071c,0x6d49071d,0x2d9c017a,0x69d9071e}},	// [17e70] _kefa_, kefa, _omte_, omte, 
   {{0x290c23db,0x6d49071f,0xa6d803b2,0x2068004e}},	//   _jefa_, jefa, veðh, йшеп_, 
   {{0x69d827bb,0x9f40004e,0xa5b81ab0,0xb7b401f2}},	//   imte, _pujà_, któz, pụt, 
   {{0x290c9d8d,0x69d81a80,0x90d400f2,0x51a83769}},	//   _lefa_, hmte, رآلا, يدەپ_, 
   {{0xd24400a8,0x2bb000c5,0x63bc01a9,0xbdc00116}},	//   _пэри, ुकना, moqn, نەرۋ, 
   {{0x6d490720,0x290c1311,0xe1fc0008,0x162000e1}},	//   gefa, _nefa_, _próf_, _बिसर_, 
   {{0x61ec04cc,0xff280150,0xe8e8025c,0xdb1806af}},	//   _hucl, _وكسي_, _རྔེག, loué, 
   {{0x61ec0810,0x61e4014f,0x958002d3,0x69d800e8}},	//   _kucl, _hijl, _ዓወትን_, emte, 
   {{0x6d490721,0x290d0722,0x3f8c7691,0x61ec0113}},	//   befa, _befa_, _ileu_, _jucl, 
   {{0x6d490723,0x61ed0724,0x290c0332,0x63bc01a9}},	//   cefa, _mucl, _cefa_, hoqn, 
   {{0x61e400a8,0x290d0725,0x61ec0548,0xa5b90726}},	//   _mijl, _defa_, _lucl, trón, 
   {{0xb6a41b6d,0x69d90727,0x61e50728,0x3eb800b5}},	//   димл, amte, _lijl, _østs_, 
   {{0x290d0729,0xa5b84da9,0x7bc801f5,0xdb180129}},	//   _fefa_, rrón, mleu, joué, 
   {{0x7bc82047,0x61e5072a,0x290c008c,0x3f8d072b}},	//   lleu, _nijl, _gefa_, _lleu_, 
   {{0xf8d044ab,0x04b44263,0x61ec0334,0x2ea802ab}},	//   _हरिय, естя, _aucl, _कश्त, 
   {{0x6d4801c7,0x290d072c,0x61ed072d,0x7bc9072e}},	//   zefa, _zefa_, _bucl, nleu, 
   {{0x61e5072f,0x6d490730,0x61ec009b,0x290c01f0}},	// [17e80] _bijl, yefa, _cucl, _yefa_, 
   {{0x61ed0731,0xf8d011b1,0x3f8d0732,0x452404c5}},	//   _ducl, _हराय, _aleu_, ম্বক_, 
   {{0x61ed0733,0x3f8d0734,0xa6d8008c,0x61e400f2}},	//   _eucl, _bleu_, veði, _dijl, 
   {{0x6d490735,0xe1fc007b,0x7bc8003e,0x733401d3}},	//   wefa, _bród_, jleu, _کرگئ, 
   {{0x6d490736,0x61e40286,0x7bc800a9,0x69d81529}},	//   tefa, _fijl, dleu, ymte, 
   {{0x3f8c0069,0x61e40399,0xa6940375,0x6d480418}},	//   _eleu_, _gijl, וכנה_, uefa, 
   {{0x6d490737,0x7bc8a64c,0x290d0738,0xa5b80005}},	//   refa, fleu, _refa_, dról, 
   {{0x7bc90739,0x4a55073a,0xb5080892,0x61e48d28}},	//   gleu, екис, वरुप_, _zijl, 
   {{0x6d49073b,0xa5b801ed,0x61ec00cf,0xb7b4063f}},	//   pefa, rtóz, _xucl, yụr, 
   {{0x2d9c0472,0xa2acc770,0x2bcc1428,0xadb400cf}},	//   _umte_, ंपत्, _हीरा, _تۇتا_, 
   {{0x290d073c,0x69d81543,0x7bc9073d,0x7af80042}},	//   _vefa_, rmte, bleu, _ffwt, 
   {{0x7bc9073e,0x290c014b,0x29c00008,0x69d80548}},	//   cleu, _wefa_, gðar_, smte, 
   {{0xb5081ab2,0x25a00196,0x290c0135,0x63bc8e61}},	//   वरूप_, tijl_, _tefa_, voqn, 
   {{0xdb185eb5,0x61ed073f,0x33e400d1,0x5ac80244}},	//   voué, _rucl, _ﺋﺎﺭﻣ, _بامێ_, 
   {{0x61e40d27,0x04c800c6,0x61ec03e0,0x63bc022e}},	//   _rijl, سوري_, _sucl, toqn, 
   {{0xd3710393,0x57a40588,0xdb181e54,0x228400db}},	//   لۇپ_, _ашьа, rluç, музг, 
   {{0xe4e853f3,0x61e4b19c,0xb7b4063f,0xdec40023}},	// [17e90] _وعده_, _pijl, pụr, ሽውና_, 
   {{0xd1b90740,0x649002d5,0x61ec07de,0x61e4014f}},	//   والا_, ežiū, _vucl, _qijl, 
   {{0xc7b808a4,0x61e4a1d6,0x63bc0113,0x00000000}},	//   suđu_, _vijl, poqn, --, 
   {{0x61e401a4,0x60c400bc,0xd25000e5,0x00000000}},	//   _wijl, _vyjm, دنے_, --, 
   {{0x8fe40184,0x61e40211,0x0fe40228,0x7bc80549}},	//   тәрҙ, _tijl, төрү, vleu, 
   {{0xc1050741,0x90e407a7,0xe1fc01e1,0x39880022}},	//   _سوري, رسەن, _itó_, _rúso_, 
   {{0x7bc8b188,0x6fc82b57,0x7f9401c0,0x5578008f}},	//   tleu, kých, _завх, ועגן_, 
   {{0x7bc8525e,0xa25800d2,0xa5b804d4,0xf0900375}},	//   uleu, _nyôk, dróm, _ענן_, 
   {{0x7bc90742,0x6fc82b57,0x00000000,0x00000000}},	//   rleu, dých, --, --, 
   {{0xe9d50743,0x7bc90744,0xa4f802ab,0xcdc800cf}},	//   нкы_, sleu, ्रोच_, _قۇنۇ_, 
   {{0xf8b10745,0x7bc90746,0xed4c00e5,0xa5b800e4}},	//   دکش_, pleu, _دھن_, rról, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x29c01c38,0xfa68ab6c,0x3dc405b1,0xe6150747}},	//   rðar_, _халк_, _kklw_, ндя_, 
   {{0x2bb0033f,0xc5d41cd0,0x00000000,0x00000000}},	//   ुकथा, вісь, --, --, 
   {{0xe1fc0cad,0xa5b804d4,0x28c43105,0x5fbc00bc}},	//   _ató_, cróm, _रुपि, एकाल, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe7b10748,0x2bb027c6,0x00000000,0x00000000}},	// [17ea0] _حميد, ुकता, --, --, 
   {{0x63b88847,0x7654023a,0xe8042c2e,0x21a000d8}},	//   čuna, _isyy, वीका_, гиум, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe1fc0210,0x00000000,0x00000000,0x00000000}},	//   _drób_, --, --, --, 
   {{0x6da43461,0x649002d5,0x63b03ad0,0xbe800131}},	//   нида, ržiū, _сәрх, ақти, 
   {{0x7dcc0b21,0x6fac00af,0x00000000,0x00000000}},	//   lúsj, ंचहू, --, --, 
   {{0xe1fc0210,0x00000000,0x00000000,0x00000000}},	//   _grób_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6fc90749,0xe1fc033f,0x00000000,0x00000000}},	//   vých, _zrób_, --, --, 
   {{0x9b4001ed,0x7dcc0162,0x69c8000d,0x00000000}},	//   پنیو, húsj, _सीखी, --, 
   {{0x6d59074a,0x7dcc002d,0xfe34037e,0x399401e1}},	//   _iata, kúsj, _zは_, _sùsù_, 
   {{0x290001e4,0xa5b803b2,0x00000000,0x00000000}},	//   ŝka_, rróm, --, --, 
   {{0xa9680853,0x94840220,0x6fc800d0,0x96443f1d}},	//   _нида_, қырд, rých, лэрд, 
   {{0x6d581574,0xd9d400d4,0x00000000,0x00000000}},	//   _jata, _змії_, --, --, 
   {{0xa6d80321,0xe1fc03b2,0x862401d5,0x00000000}},	//   veðu, _stó_, رککل, --, 
   {{0xb7c40124,0xd3a4026b,0xf1c00064,0x00000000}},	//   _ирық, груп, _lašą_, --, 
   {{0xe1f0115a,0x6d59074b,0x85b801d5,0x26cc01e1}},	// [17eb0] اسر_, _oata, _олис_, _ágo_, 
   {{0x00e411fc,0x37bc01f2,0x68f80857,0xe1fc012d}},	//   نتای, ọstụ_, nctd, _prób_, 
   {{0x7dcc000f,0xfe3404ce,0x24dc0154,0xc3b40395}},	//   búsj, _sは_, _ব্রহ, _айнщ, 
   {{0x6d58074d,0x64542878,0xfe34037e,0x9098009d}},	//   _aata, _isxi, _pは_, эвхт_, 
   {{0xe1fc0270,0x7dcc0113,0x6288005c,0x00000000}},	//   _utó_, súsm, øgod, --, 
   {{0x6d58f560,0x00000000,0x00000000,0x00000000}},	//   _cata, --, --, --, 
   {{0x6d59074c,0xe73c00af,0xa5b8012d,0x00000000}},	//   _data, lnõu_, trój, --, 
   {{0x6d59074d,0x4f580108,0x00000000,0x00000000}},	//   _eata, _писю_, --, --, 
   {{0x6d59074e,0x00000000,0x00000000,0x00000000}},	//   _fata, --, --, --, 
   {{0x261805f9,0xdd9801c4,0x00000000,0x00000000}},	//   _बिजी_, _эшб_, --, --, 
   {{0xca740184,0x7dcd074f,0xdcc400d1,0x37d40154}},	//   _ҡушы, húsk, _яңке_, _সংবর, 
   {{0xf0ec068f,0x7dcc01f1,0x7654023a,0x68f801ab}},	//   _जल्द_, kúsk, _psyy, actd, 
   {{0xaf74008f,0x68f80175,0xb9b400a7,0x00000000}},	//   דערס_, bctd, _искъ, --, 
   {{0x6d590750,0x66000064,0xa5b808a5,0x00000000}},	//   _xata, рпра, duós, --, 
   {{0x64a10751,0x69c805d7,0x7dcc000f,0x00000000}},	//   аара, _सीटी, túsj, --, 
   {{0xdb180598,0x260c0490,0x00000000,0x00000000}},	//   _üzäg, तीही_, --, --, 
   {{0xf5040c04,0x51441669,0x333001f5,0x6d8402d2}},	// [17ec0] _изпо, лдағ, rgyx_, _iðav, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xafe407d6,0x00000000,0x00000000,0x00000000}},	//   вожл, --, --, --, 
   {{0xf2a400c7,0x398803b2,0x802400f1,0x7dcc0d12}},	//   _аимп, _búsk_, ارلم, búsk, 
   {{0xa3bc0c2e,0x261800e1,0x42d40024,0xa3e40073}},	//   इवर_, _बिछी_, _біру, _पळत_, 
   {{0x6d590752,0x3cfc0316,0xec682235,0xa2ac0490}},	//   _qata, रुले_, дрик_, ंपर्, 
   {{0x21a10753,0xe1fc004d,0xef180395,0x00000000}},	//   _тирм, _tróc_, _омв_, --, 
   {{0xceb83769,0xe29c02d2,0xe1fc02d2,0x7c240419}},	//   _пәл_, _geðs_, _hróa_, áhra, 
   {{0x6d590754,0xa9280046,0x00000000,0x00000000}},	//   _tata, міне_, --, --, 
   {{0x6d590755,0x49750756,0x59cc25c9,0x00000000}},	//   _uata, улос, _सीआर, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6ac800fe,0x00000000,0x00000000,0x00000000}},	//   াইবো, --, --, --, 
   {{0xaac400c5,0xa5b80332,0xa6d81d0e,0x00000000}},	//   _लडिक, lrói, veðs, --, 
   {{0x2b440117,0x00000000,0x00000000,0x00000000}},	//   _hboc_, --, --, --, 
   {{0x41840046,0x6fc00490,0x67fc002b,0x2a6402fb}},	//   қтағ, षकां, _bīje, _hrob_, 
   {{0x63b8341a,0xaac4012c,0x47342f5c,0x00000000}},	//   čuno, _लडाक, _снис, --, 
   {{0x964400f7,0xe7b000db,0xa5b800ae,0x260c01f9}},	// [17ed0] _кээд, _مۅگد, hrói, तीशी_, 
   {{0xa2a40574,0xb9ec044e,0xe4a50757,0x2a64020c}},	//   _घेण्, _ሓዊ_, _армо, _mrob_, 
   {{0xd498084c,0x1cbc0327,0xe8040073,0x64540139}},	//   _аря_, _གཙེ_, वीचा_, _usxi, 
   {{0x443007c4,0x7dcd0758,0x2a641574,0xa5b801e7}},	//   muz_, músi, _orob_, drói, 
   {{0x2a640218,0x8fa404fb,0x3ea41c3b,0xe1fc02d2}},	//   _nrob_, جمنه, دشاہ, _fróa_, 
   {{0xaac42007,0x51850759,0x5bc800dc,0xe1fc08a5}},	//   _लड़क, _куса, ात्व, _gróa_, 
   {{0x4431075a,0xe29c02d2,0xa5b800ae,0x2d700241}},	//   nuz_, _geðr_, grói, _s̟eé_, 
   {{0xf0780724,0x38685049,0x28c400cd,0x00000000}},	//   _яисә_, _čar_, _रुधि, --, 
   {{0x7dcc09cc,0x398809f3,0xb9e801b9,0xa5b801e7}},	//   húsi, _húsi_, нмиз_, arói, 
   {{0x4431075b,0x2a65075c,0x7dcc0030,0xa5b80332}},	//   kuz_, _drob_, kúsi, brói, 
   {{0x5fb426d9,0x8d84322e,0x2a6401c7,0x37e496da}},	//   _अदाल, _тутд, _erob_, лоог, 
   {{0x4431075d,0x2b440048,0x2a65075e,0x39880077}},	//   duz_, _gboc_, _frob_, _músi_, 
   {{0x2a65075f,0x44300226,0xa3d400af,0xe9cc234c}},	//   _grob_, euz_, ितन_, _гк_, 
   {{0x44310760,0x75d402dd,0x3dd000cc,0x00000000}},	//   fuz_, ايسا, াদকল, --, 
   {{0x4430801b,0xe2941ee3,0x280000bc,0xc5c40327}},	//   guz_, ҳат_, ěrné_, _གཉྫི, 
   {{0xe7b80918,0xf3e50761,0x00000000,0x00000000}},	//   _उदयप, ужбо, --, --, 
   {{0xe2950762,0x44300369,0x64400793,0x716801c0}},	// [17ee0] гат_, auz_, _änin, нааг_, 
   {{0x44310763,0x398802d2,0xa5b8012d,0x3d0c012d}},	//   buz_, _búsi_, drów, हरों_, 
   {{0x44300399,0xf0b81291,0x00000000,0x00000000}},	//   cuz_, رائش_, --, --, 
   {{0xe29c0162,0x2dd40014,0x00000000,0x00000000}},	//   _veðr_, گُتھ_, --, --, 
   {{0x1cbc0327,0x3ec40124,0x427401ee,0xf91800cc}},	//   _གཙུ_, аицҳ, _кѳрс, _দানৱ_, 
   {{0xad24fad7,0x398802d2,0xe1fc02d2,0xa5b801e7}},	//   ارشو, _fúsi_, _krón_, trói, 
   {{0x4c950764,0xa0641cd6,0xa5b80210,0x00000000}},	//   рийс, _йара_, arów, --, 
   {{0xa2d8041c,0xf0e804a9,0x09ac044b,0xa5b90765}},	//   पेक्, _يىڭى_, टच्य, rrói, 
   {{0x44300dd4,0x63680724,0xe9e401c0,0x2fc4058a}},	//   zuz_, _hönä, лцоо, moog_, 
   {{0x2fc4f0b1,0x44310766,0x1e800c60,0x636800a2}},	//   loog_, yuz_, _улум, _könä, 
   {{0x9960424c,0x2b4405f5,0x53c400dc,0xa3d400dc}},	//   стыл, _бэлг, वकाश, ितम_, 
   {{0x63680724,0x44310767,0x162005f9,0xa2580165}},	//   _mönä, vuz_, _बिखर_, _kyôt, 
   {{0x2a650768,0x06cc0154,0x59cc0210,0x00000000}},	//   _urob_, রেনি, _सीकर, --, 
   {{0x6b810769,0x2fc40460,0x44300323,0x1a9800c8}},	//   _hoog, hoog_, tuz_, _אידע, 
   {{0x6b81076a,0x2fc5076b,0x63680166,0x00000000}},	//   _koog, koog_, _nönä, --, 
   {{0x4431076c,0x6b81076d,0x5335076e,0x2fc40067}},	//   ruz_, _joog, йест, joog_, 
   {{0x6b81076f,0x44310770,0xc1140640,0xd7b40a59}},	// [17ef0] _moog, suz_, имај, ीवरच, 
   {{0x6b800d62,0x44310771,0xe1fc02d2,0xdb180162}},	//   _loog, puz_, _frón_, sluø, 
   {{0xe1fc0162,0x9148064e,0x00000000,0x00000000}},	//   _grón_, ычта_, --, --, 
   {{0x6b810772,0x2fc4000d,0xa5b8012d,0x00000000}},	//   _noog, goog_, trów, --, 
   {{0x22850773,0xe6d01d97,0x91c80150,0x00000000}},	//   _сунг, _सरोज, _ﯨﻘﯩﻼ, --, 
   {{0x6b800b23,0x69c80421,0x7dcc022c,0xfc04bd80}},	//   _aoog, _nkfe, húsv, апко, 
   {{0x6b810774,0x2000094a,0xfaf00597,0x2fc50775}},	//   _boog, _utji_, يثة_, boog_, 
   {{0x3b850776,0x4420ec97,0x6b800072,0x3a24267c}},	//   рлиг, _mvh_, _coog, амиг, 
   {{0x6b80a1ae,0x00000000,0x00000000,0x00000000}},	//   _doog, --, --, --, 
   {{0x7e690777,0x44210778,0x4ea42ec5,0x00000000}},	//   _irep, _ovh_, _урса, --, 
   {{0x6d880f31,0x1cbc0135,0x6b803d20,0x06cc0eac}},	//   _جملہ_, _གཙི_, _foog, রেমি, 
   {{0x6b810779,0x7e69077a,0x1be401b9,0x00000000}},	//   _goog, _krep, _сўзг, --, 
   {{0xcaf4066d,0x69c81132,0xe1fc00ae,0xe72401f0}},	//   _اسمب, _fkfe, _srón_, шояд_, 
   {{0x4420aed5,0x7e68020c,0xf98400a7,0x45340334}},	//   _bvh_, _mrep, _ъгло, йхст, 
   {{0x2fc40218,0x644000fd,0x6b81077b,0x7dcc0784}},	//   yoog_, _änil, _yoog, súsw, 
   {{0x6b800a81,0xa25800d2,0x2fc401d4,0x7e69077c}},	//   _xoog, _nyôs, xoog_, _orep, 
   {{0x6261077d,0xe1f401c0,0xd764004b,0xf7700133}},	// [17f00] овта, игт_, _ننګی, _هاک_, 
   {{0x7f4801f0,0xc0f002d3,0xe1fd077e,0x2fc401f5}},	//   _abeq, ልጋሊ_, _iról_, woog_, 
   {{0x4421077f,0x7e690780,0xef1803b7,0x2fc40926}},	//   _gvh_, _arep, вме_, toog_, 
   {{0xae890781,0x636801b8,0xa5b801ed,0x7d00032e}},	//   кбез_, _vönä, csób, _afls, 
   {{0x2fc50782,0xfe748b1f,0x1ec4bde0,0x7dcc0321}},	//   roog_, бүт_, алци_, húsu, 
   {{0x7e690783,0x7f48014b,0x2fc50784,0x4c94086f}},	//   _drep, _ebeq, soog_, йилс, 
   {{0x7e690785,0x2fc4a107,0xafe50786,0x6b810787}},	//   _erep, poog_, _вовл, _poog, 
   {{0xe61c011f,0x7d0002d2,0x2d8c030a,0x9b64035b}},	//   ysô_, _efls, skfe_, ашьа_, 
   {{0x7e690788,0x6b810789,0x3a2c1700,0x00000000}},	//   _grep, _voog, grep_, --, 
   {{0x6b81078a,0x06cc0154,0xa2d809b2,0x00000000}},	//   _woog, রেডি, पेट्, --, 
   {{0x6b806ed9,0x1cbc025c,0xddd8005f,0x67fc00dc}},	//   _toog, _གཙག_, _bruņ, _bīja, 
   {{0xe61c0770,0xdcac1c3e,0x7e6802d0,0x394402d2}},	//   tsô_, _تىم_, _yrep, afls_, 
   {{0xc0f0001f,0x00000000,0x00000000,0x00000000}},	//   ልጋሉ_, --, --, --, 
   {{0xbadc0150,0xd940009b,0x00000000,0x00000000}},	//   _ﺇﺭﺠﺎ, _дељи, --, --, 
   {{0xd5b80801,0xe61c0548,0x6db00210,0xa5b83e33}},	//   рся_, ssô_, mład, drót, 
   {{0x98780375,0x7dcc000f,0xe3b001d3,0x44200327}},	//   _ירוק, lúst, زرز_, _vvh_, 
   {{0x82d805f5,0xe61c011f,0xab78022e,0x2c4c03b9}},	// [17f10] удас_, qsô_, _mo鼠j, _hədd_, 
   {{0x7e69078b,0x44200356,0xa08800fd,0xa5b80174}},	//   _rrep, _tvh_, ксез_, grót, 
   {{0x7e68020c,0xff40001f,0xf1bc190c,0xb9d00092}},	//   _srep, _የምርመ, ्तजन, _ስዬ_, 
   {{0x16140073,0xb4000107,0x7dcc03b2,0x398800e5}},	//   तीवर_, _хӯрд, húst, _húst_, 
   {{0x6db0006d,0x91b80086,0xa5b806ea,0x3b0c0477}},	//   kład, òñòñ_, brót, vbeq_, 
   {{0x39880579,0x987417a3,0x6db0012d,0x80b800fe}},	//   _júst_, _ušće_, jład, _অৰণ্, 
   {{0x40940491,0x7dcd078c,0x3a2c0175,0x00000000}},	//   _الأر, dúst, wrep_, --, 
   {{0xa3d466eb,0x7f480921,0x3a2c06a3,0x8f340953}},	//   िति_, _ubeq, trep_, _месц, 
   {{0xab9c0201,0x7e69078d,0xf990007b,0xf1bc190c}},	//   ግረዋል_, _urep, كبد_, ्तचन, 
   {{0x47d039db,0xc0f00125,0x7dcd078e,0x0dc86a7c}},	//   _সংগী, ልጋል_, gúst, _кухи_, 
   {{0xa3d40bc5,0xdb180254,0x00000000,0x00000000}},	//   िता_, oluü, --, --, 
   {{0xe7340150,0x00000000,0x00000000,0x00000000}},	//   бею_, --, --, --, 
   {{0x7bc80421,0xabb400c7,0x7dcc0bcd,0x67fc002b}},	//   moeu, _уацә, búst, _vīja, 
   {{0xb8dc0d42,0x7dcc04d4,0xe1fc01e7,0x7bc800d7}},	//   _আর_, cúst, _cróm_, loeu, 
   {{0xe5a0236a,0x00000000,0x00000000,0x00000000}},	//   чири, --, --, --, 
   {{0xa454c6da,0x00000000,0x00000000,0x00000000}},	//   şağı_, --, --, --, 
   {{0x3125078f,0x35a401d5,0x70f47660,0xa5b81d0e}},	// [17f20] йдаг, _гапг, مسائ, trót, 
   {{0x59c4069f,0x97040131,0xdb180798,0x7bc80438}},	//   रकिर, _دېڭى, bouç, hoeu, 
   {{0xaacc6bf6,0x7dcd0790,0x23440131,0x98a42737}},	//   _हुनक, húss, شلەپ_, _kanı_, 
   {{0xd3700f78,0x7bc90791,0xa5b90792,0x6db0012d}},	//   _تۇر_, joeu, brós, zład, 
   {{0x7bc90793,0x59c45b67,0xdfcd0794,0x7dcc067c}},	//   doeu, रकार, ريه_, júss, 
   {{0xb6040427,0x6df40137,0x00000000,0x00000000}},	//   mašč, _ۇكرا, --, --, 
   {{0xfd7801ed,0xb6040010,0x00000000,0x00000000}},	//   ششوں_, lašč, --, --, 
   {{0x6fb50795,0x09d053a5,0x7bc8003e,0x2c4c0213}},	//   _امرا, हत्य, goeu, _rədd_, 
   {{0x2c4c03b9,0x00000000,0x00000000,0x00000000}},	//   _sədd_, --, --, --, 
   {{0x6e200921,0x00000000,0x00000000,0x00000000}},	//   msob, --, --, --, 
   {{0x7bc90796,0x6e20281f,0x398808a5,0x7dcc1941}},	//   boeu, lsob, _rúst_, rúst, 
   {{0xdee0069c,0x7bc90797,0x98a50356,0x6e210798}},	//   _ምሉእ_, coeu, _canı_, osob, 
   {{0x6e210799,0x98a40724,0x6f0000b5,0xb3880023}},	//   nsob, _danı_, icoc, _ዘለዋን_, 
   {{0xb38802d3,0xb60401fa,0xa3a87220,0x00000000}},	//   _ዘለወን_, dašč, कोन_, --, 
   {{0x291d079a,0x7afc0122,0x6f007623,0x3cfc0490}},	//   mata_, žste, kcoc, रुटे_, 
   {{0xa5b9079b,0x00000000,0x00000000,0x00000000}},	//   trós, --, --, --, 
   {{0xe1fc011f,0x291d079c,0x6f01079d,0x56941188}},	// [17f30] _irók_, oata_, dcoc, _наът, 
   {{0x291d079e,0x6f000393,0xa5b831b7,0x00000000}},	//   nata_, ecoc, rrós, --, 
   {{0x2004c3b4,0x291d079f,0x98a40d9c,0x66dc01e1}},	//   ëni_, iata_, _yanı_, _fàkí, 
   {{0x6f000af2,0x200507a0,0xd498717e,0x98a40dde}},	//   gcoc, īni_, _ыры_, _xanı_, 
   {{0x291d07a1,0x049400cd,0x00000000,0x00000000}},	//   kata_, _āvṛt, --, --, 
   {{0x6f00a73e,0x443107a2,0x00000000,0x00000000}},	//   acoc, orz_, --, --, 
   {{0x7f9405f5,0x44300099,0x6e201418,0x01d800db}},	//   _давх, nrz_, asob, _موڭع_, 
   {{0x6f0107a3,0x6db0033f,0x25d8000d,0x0ea401f9}},	//   ccoc, głab, _खीसी_, _खेकड, 
   {{0x291d07a4,0x7bc907a5,0x67fc0055,0x443001ef}},	//   fata_, roeu, _bījo, hrz_, 
   {{0x291d07a6,0x98a40724,0x7dcd07a7,0x7bc80129}},	//   gata_, _sanı_, rúss, soeu, 
   {{0x3a0801d5,0xb6040427,0x9f4800ae,0x37e401d5}},	//   اکچی_, zašč, _ómós_, жонг, 
   {{0xb38802d3,0x291c013c,0x443002f0,0xfaa80451}},	//   _ዘለዎን_, aata_, drz_, _پهتي_, 
   {{0x06cc00bd,0xda640137,0x443107a8,0xc8b401b9}},	//   রেসি, _دااي, erz_, قلیک, 
   {{0x291d07a9,0x6f0107aa,0xb6040219,0x66dc01e1}},	//   cata_, zcoc, vašč, _sàkí, 
   {{0x6f00037e,0x98a4083c,0xdb18002e,0xb3880023}},	//   ycoc, _tanı_, lluñ, _ዘለውን_, 
   {{0xaacc0574,0x73346923,0x6f0107ab,0x2450007b}},	//   _हुडक, تىرا, xcoc, بنفس, 
   {{0x443107ac,0xd5e401fb,0x6f0000d7,0x00000000}},	// [17f40] arz_, _trì, vcoc, --, 
   {{0xb6050675,0x31240150,0x00000000,0x00000000}},	//   rašč, ідег, --, --, 
   {{0x6e200334,0xa0640395,0x6f0002d0,0x6db00210}},	//   wsob, жаха_, tcoc, yłab, 
   {{0x291d07ad,0x6e2107ae,0x13a82304,0x35800092}},	//   zata_, tsob, _چنگی_, _ካለበት_, 
   {{0xed5907af,0xb51c0c2e,0x9ea507b0,0x764405ac}},	//   иод_, _बजाय_, овца_, ntky, 
   {{0x291c094a,0x20040137,0x79800218,0x6e2001c4}},	//   xata_, ínic_, jjlw, rsob, 
   {{0x291d07b1,0x6e2107b2,0xccf80118,0xa5b800d7}},	//   vata_, ssob, _kněz_, ksón, 
   {{0x291d07b3,0x2078008f,0x6094007b,0xa5b802d2}},	//   wata_, _דאלא, _بنفس_, hróp, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x291d07b4,0xc5f8009e,0x6db00210,0x298800d8}},	//   uata_, _অবলা_, słab, рсио_, 
   {{0xdd8c10e0,0xa3a809ab,0xf9a80248,0x6db0033f}},	//   _جول_, कोड_, _ilẹ̀_, ałac, 
   {{0x291d07b5,0x6d4907b6,0x7644007c,0xefbc01f3}},	//   sata_, lffa, ftky, _ሴማዊ_, 
   {{0x291d07b7,0xdb18068c,0x6d480036,0xda600120}},	//   pata_, pluò, offa, _овци, 
   {{0x291d07b8,0xdb1801a8,0x4430bac7,0x6d482306}},	//   qata_, lluð, trz_, nffa, 
   {{0x889405f5,0x442409c2,0x6d48208d,0x1cbc0327}},	//   _хийх, él_, iffa, _གཙབ_, 
   {{0x442d07b9,0x69a4089a,0x25d80034,0xd3789c49}},	//   če_, टोरी, _खीरी_, очу_, 
   {{0xd24401c6,0x00000000,0x00000000,0x00000000}},	// [17f50] дэхи, --, --, --, 
   {{0x7dcc0122,0xa5b80005,0x443107ba,0xd5e40051}},	//   júsp, cróp, prz_, _trí, 
   {{0x65740023,0x6db00210,0x00000000,0x00000000}},	//   _inxh, złac, --, --, 
   {{0x6d480a4d,0x3f9c0810,0x00000000,0x00000000}},	//   effa, uhwu_, --, --, 
   {{0xa3a81152,0x64440660,0x260c0490,0xa13402dd}},	//   कोण_, ltji, तीची_, _ورسش, 
   {{0x64440ea0,0x0d8400d4,0x00000000,0x00000000}},	//   otji, млін, --, --, 
   {{0x644507bb,0xdb1802d2,0x00000000,0x00000000}},	//   ntji, fluð, --, --, 
   {{0x5f7407d6,0x6d4907bc,0x644405e4,0x6db0012d}},	//   _باسر, affa, itji, tłac, 
   {{0x7dcc02d1,0xe1fc02d2,0x00000000,0x00000000}},	//   súsq, _brói_, --, --, 
   {{0x39441830,0x397907bd,0x79800007,0x00000000}},	//   чног, ссию_, ujlw, --, 
   {{0x7cd8004b,0xc3380306,0x29f4012d,0xa92001c6}},	//   _اواز_, _čínš, _płac_, эдэл, 
   {{0xf09000c8,0x6db00034,0x3e5c02e2,0x64440af9}},	//   גנט_, płac, _kňt_, dtji, 
   {{0xa5b907be,0x644405e4,0x739802dd,0x00000000}},	//   rsón, etji, ұтас_, --, 
   {{0xa50507bf,0x6444045f,0x28c40cb4,0xa5b907c0}},	//   зера_, ftji, _रुकि, uróp, 
   {{0xb9f80020,0xa3d40a28,0x3e5c0699,0x7af801ee}},	//   _መሪ_, ितं_, _lňt_, _kgwt, 
   {{0x1cbc031c,0x7af80175,0x65740200,0x67d0009b}},	//   _གཙན_, _jgwt, _enxh, _поју, 
   {{0xa5b80120,0x644507c1,0xe1f507c2,0x3e5c033b}},	// [17f60] próp, atji, згу_, _nňt_, 
   {{0xd5a4006c,0xaacc00e1,0x6eb0000d,0xe2945b0f}},	//   _آلدی, _हँसक, _अधबु, чау_, 
   {{0x85044e85,0x00000000,0x00000000,0x00000000}},	//   _توپن, --, --, --, 
   {{0xd9c4e079,0xa3d40a28,0x20041c69,0x6d480042}},	//   रकुट, ितः_, ínia_, wffa, 
   {{0x6fb41973,0x00000000,0x00000000,0x00000000}},	//   _ہمسا, --, --, --, 
   {{0x6d4820ef,0x726c00b7,0xad240ee8,0x0cd40f06}},	//   uffa, _አሉታዊ_, سرتو, молю, 
   {{0x6d480a35,0xe534010f,0x00000000,0x00000000}},	//   rffa, לטסט_, --, --, 
   {{0x3e5c0100,0x7dcc095b,0x6d480142,0xbb44010a}},	//   _fňt_, súsp, sffa, çекк, 
   {{0xacf40491,0x6d480036,0x00000000,0x00000000}},	//   _فسات, pffa, --, --, 
   {{0x644405e4,0x6da41291,0x889507c3,0xa3780051}},	//   ytji, _عمام, диох, _nhõn, 
   {{0x29e000a2,0x2c4c03b9,0x07347a9c,0x00000000}},	//   _açaý_, _fəda_, меню, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe1fc004d,0x66c80276,0x6444017a,0x00000000}},	//   _trói_, сунг_, wtji, --, 
   {{0x2464012c,0x644507c4,0xa3780051,0x6ac00356}},	//   jímá_, ttji, _chõn, ătfă, 
   {{0x58d06719,0x644405e4,0x00000000,0x00000000}},	//   _пошт, utji, --, --, 
   {{0x64440151,0x58b80375,0x0edc0037,0x00000000}},	//   rtji, _למוצ, _बरंड, --, 
   {{0x51f8c2e2,0x644507c5,0x00000000,0x00000000}},	// [17f70] зную_, stji, --, --, 
   {{0xa6c4021a,0x6444017a,0x69c01fc4,0x00000000}},	//   _ووژل_, ptji, रकटी, --, 
   {{0xa5b80077,0x3e5c007f,0x06b400eb,0x00000000}},	//   nsóm, _sňt_, _ঘরটি, --, 
   {{0x7e9907c6,0x63b86b48,0xa5b80077,0x3e5c02e2}},	//   ينار_, čuns, isóm, _pňt_, 
   {{0x8d748a54,0x00000000,0x00000000,0x00000000}},	//   کانا, --, --, --, 
   {{0x3e5c02e2,0x7af80042,0x2c4c03e3,0x00000000}},	//   _vňt_, _sgwt, _səda_, --, 
   {{0x41d907c7,0xd52c01e1,0x1fa40166,0x4dd401e2}},	//   _बीएस, _ló̟d, _ераг, رتهس, 
   {{0xe1fc1132,0x28b000dc,0x00000000,0x00000000}},	//   _kuó_, ुपनि, --, --, 
   {{0xbe640451,0x9da800a7,0x2c4c06be,0x00000000}},	//   _تهذي, _лъжа_, _vəda_, --, 
   {{0x82fc025c,0xe9d400ee,0xf990007b,0xec1000db}},	//   _ཐུའུ_, мкы_, ئبة_, روۋد, 
   {{0xa3bc5b99,0xe1fc03b2,0xa5b86ae6,0x00000000}},	//   ेवा_, _gróv_, rsól, --, 
   {{0xeaac00e5,0x00000000,0x00000000,0x00000000}},	//   اٹی_, --, --, --, 
   {{0xe9cd07c8,0x91a0063f,0x49b89165,0x00000000}},	//   _ак_, ntị_, _کاند_, --, 
   {{0xe1fc006d,0x49c802dd,0x6db0012d,0xa3a806b1}},	//   _osób_, _елін_, hłan, कोस_, 
   {{0xd6180014,0x6db0012d,0x33f400d4,0x13800023}},	//   _کعبچ_, kłan, дчас, _ሓሊፍካ_, 
   {{0xb4ac05ba,0xfbdc0b98,0x00000000,0x00000000}},	//   _कधी_, मतिम, --, --, 
   {{0xc7640e26,0xa3780051,0xa5603c5a,0x00000000}},	// [17f80] _سايى, _thõn, رگین, --, 
   {{0xef24010b,0x76580210,0x00000000,0x00000000}},	//   _ýüzi_, łtys, --, --, 
   {{0xdb0801c7,0x0108004b,0x6fb4004b,0x00000000}},	//   _emgé, ستلو_, ومطا, --, 
   {{0xd37000db,0x06b400cc,0x00000000,0x00000000}},	//   _حۇر_, _ঘৰটি, --, --, 
   {{0x6da507c9,0x561c009e,0x236c045f,0xada401b9}},	//   мида, _তমুক_, ôgje_, мадл, 
   {{0x6db0068f,0x8468001f,0xe1fc03b2,0xd9c41d03}},	//   ałan, _ችግሩን_, _próv_, रकोट, 
   {{0x644001b8,0x6140074d,0x00000000,0x00000000}},	//   _änit, _шера, --, --, 
   {{0x63ac037e,0x6398010f,0x00000000,0x00000000}},	//   _xmcn, ַסינ, --, --, 
   {{0x6e4402f2,0x20400092,0x00000000,0x00000000}},	//   _زنام, _ያልተረ, --, --, 
   {{0xbebc0421,0xc8640276,0xe1fc02d2,0x00000000}},	//   _seūg, еӂии, _gróu_, --, 
   {{0x99d02781,0x2d9c08c2,0x996065f1,0xddd83b33}},	//   ختيا, _ilte_, ттыл, _hruş, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xaae004e4,0x59a8012c,0x9b4042b5,0x9644010b}},	//   _परिक, टोहर, _شنوو, кэрд, 
   {{0xa5b81873,0x2d9c00d5,0x195400f7,0xa2ac00cd}},	//   msók, _jlte_, _жашы_, ूपस्, 
   {{0x28c42435,0x94d507ca,0xd25001d3,0x6db00210}},	//   _रुचि, ворц, ینِ_, yłan, 
   {{0x69d907cb,0xaae0a583,0x175401c6,0x00000000}},	//   llte, _पराक, _авъя, --, 
   {{0x45d448ad,0xe1fc0998,0xa3a80fc8,0x69d86da7}},	// [17f90] _поис, _quó_, कोष_, olte, 
   {{0x2004baac,0xc5380a89,0xe5e40338,0x84680092}},	//   ínio_, _эпох_, _تثبي, _ችግርን_, 
   {{0x69d80013,0x63ac010a,0x257001ec,0x06b400cc}},	//   ilte, _tmcn, _كۇڭس, _ঘৰচি, 
   {{0x2d9d07cc,0xa3a83d60,0x69d80730,0xe1fc03b2}},	//   _alte_, कोश_, hlte, _brót_, 
   {{0x2c500b82,0x73c01219,0x00000000,0x00000000}},	//   _መርገም, _сәре, --, --, 
   {{0x6db0068f,0xa3a83644,0x644000fd,0xcda801e2}},	//   słan, कोर_, _änis, وهنه_, 
   {{0x37d400bd,0x80b80154,0x6db0012d,0xa2d00da5}},	//   _সংঘর, _অরক্, płan, _भुत्, 
   {{0x69d813ee,0xd9c402ab,0x63bc0098,0x2d9ca491}},	//   elte, रक्ट, nnqn, _elte_, 
   {{0x3e34764c,0x20280220,0xe1fc06ea,0xc0e00023}},	//   _سفار, _ءﺗﯩﻞ_, _grót_, ሓይሽ_, 
   {{0x8d7507cd,0xe1fc08a5,0x69f000db,0xada000d7}},	//   _لاما, _hrós_, гүчт, žúrk, 
   {{0xf744504b,0x2844010b,0x00000000,0x00000000}},	//   нено, нзэп_, --, --, 
   {{0x69d907ce,0xe5a00131,0x2d9c00d7,0x00000000}},	//   alte, қиси, _zlte_, --, 
   {{0x64540054,0xddd825a8,0x00000000,0x00000000}},	//   _apxi, _xruş, --, --, 
   {{0x645800e4,0x00000000,0x00000000,0x00000000}},	//   ̃uie, --, --, --, 
   {{0x62880793,0xb86401d5,0x20040118,0xc974132f}},	//   ägon, _ساغو, ínil_, _جانث, 
   {{0xd7e800f7,0xa3a81152,0x6ef4010b,0xaacc000d}},	//   _توبۇ_, कोल_, _jübü, _हुँक, 
   {{0x765400e4,0x76140022,0x00000000,0x00000000}},	// [17fa0] _upyy, _џьих, --, --, 
   {{0x9d7800e8,0x6fb0000d,0x00000000,0x00000000}},	//   gg茜e, _आगहू, --, --, 
   {{0x54e4012c,0x00000000,0x00000000,0x00000000}},	//   _गरिए_, --, --, --, 
   {{0x6db0068f,0x3f8c004e,0xaec507cf,0x28b018cc}},	//   ałal, _coeu_, нбел, ुपति, 
   {{0xaacc2ba2,0xa3bc0490,0x3f8c0798,0xe1fc0162}},	//   _हुंक, ेवर_, _doeu_, _drós_, 
   {{0xe1fc0ba1,0x06cc015b,0x54e400bc,0xf1d001af}},	//   _erós_, রেকি, _गराए_, _сөбө, 
   {{0x6ac800fe,0x2f540064,0xabb107d0,0x00000000}},	//   াইছো, _птас, лакә, --, 
   {{0xe1fd07d1,0xa5b8089f,0xce3405af,0x70bc0b4c}},	//   _trót_, tsók, _لورک, ्थील, 
   {{0x32000124,0xddd800ee,0x00000000,0x00000000}},	//   _juky_, _uruş, --, --, 
   {{0xd91411ed,0x32000a49,0x29080428,0x69d907d2}},	//   нью_, _muky_, ùba_, ulte, 
   {{0x2ab403b2,0x32000306,0xda6c0166,0x610c00e5}},	//   _bøbø_, _luky_, _өя_, lőlü, 
   {{0x69d80158,0x451c03d4,0xe6640c5c,0x999c14b2}},	//   slte, _তাইক_, нтго, rtuš_, 
   {{0xefcc1b49,0x12c4015b,0xbb5000db,0xf3e400fe}},	//   _እገዳ_, ্ধুদ, _ئچىب, কদাৰ_, 
   {{0xa6d80008,0x6db00210,0x1a98010f,0xda78011a}},	//   ggða, kłam, _ציגע, _מנדר, 
   {{0xf400054e,0xa5b800ae,0x79e800e5,0xa85001ee}},	//   _niţă_, nsói, _تووہ_, _сейә, 
   {{0xa3a8006d,0x98a80311,0x320107d3,0x9cd4011a}},	//   कों_, şcă_, _buky_, גולה_, 
   {{0xd250004b,0x598401c6,0xb6c4004e,0x00000000}},	// [17fb0] ینې_, _цөөн_, _үсөй, --, 
   {{0x20c400fb,0x320001ef,0xb6380150,0x00000000}},	//   нсег, _duky_, _ﺘﺩ_, --, 
   {{0x55ac00c8,0xe1fd07d4,0x00000000,0x00000000}},	//   _זייַ, _prós_, --, --, 
   {{0x439507d5,0x2a64012c,0xf1c0005f,0x6db0012d}},	//   _рамс, _osob_, ekšā_, słal, 
   {{0x12e40046,0x8e0802bf,0x3f8c06af,0x6db0012d}},	//   _бірг, енів_, _voeu_, ałam, 
   {{0xf4000356,0xde340023,0x6ef406be,0x00000000}},	//   _fiţă_, _ኣይከው, _sübü, --, 
   {{0x6da01a21,0xdc5000e5,0x00000000,0x00000000}},	//   рища, ارتک, --, --, 
   {{0xe1fc0ba1,0x5e8400f3,0x00000000,0x00000000}},	//   _urós_, _пузз, --, --, 
   {{0x200107d6,0xfaa42bba,0x2a6402f0,0x3df4022e}},	//   _huji_, тапо, _csob_, _азас, 
   {{0x200107d7,0x398801d3,0x99cc0154,0x00000000}},	//   _kuji_, _húsz_, রষ্ক, --, 
   {{0x200107d8,0xa5b80cde,0x3c0401b9,0x37e4004e}},	//   _juji_, bróz, _рўзғ, коог, 
   {{0x200107d9,0x03c404c5,0x21200135,0xabb4035b}},	//   _muji_, ্ষুণ, _lejh_, _иахә, 
   {{0x2a6400ca,0xbbdc00bc,0x628801e3,0x78ac01ef}},	//   _gsob_, मतीक, ägol, _živě, 
   {{0x32000232,0x20000165,0x33200200,0x00000000}},	//   _ruky_, _ouji_, _sekx_, --, 
   {{0xa3bc0882,0x32008c43,0xa5040452,0x67fc00b8}},	//   ेवं_, _suky_, теса_, _pūje, 
   {{0xb9ec1772,0x7d0c013f,0xa5b8033f,0x7dcc00e5}},	//   _ዓሊ_, ɛase, ksów, gúsz, 
   {{0x07f80598,0xb1444727,0x383c001f,0x052003d4}},	// [17fc0] _яхшы_, кнал, _በተባበ, _বাৰৰ_, 
   {{0x70f40597,0x6db00034,0xab640254,0x200107da}},	//   نسائ, ałaj, _krüü, _buji_, 
   {{0x659808d8,0x602400e5,0x00000000,0x00000000}},	//   _חייק, _rémá, --, --, 
   {{0x2000020c,0x320002fb,0xf4000356,0xfaf80064}},	//   _duji_, _tuky_, _viţă_, ndūs_, 
   {{0x6db0012d,0xdd8c01c8,0x00000000,0x00000000}},	//   słam, ڊون_, --, --, 
   {{0xdd8d07db,0xde90026a,0xe16000db,0x00000000}},	//   يون_, рашњ, _ۅگۅي, --, 
   {{0xa06407dd,0x200107dc,0xa5b803da,0xe1fc032e}},	//   _иара_, _guji_, tróz, _hróp_, 
   {{0xd1d4001f,0xafe402bf,0xa5b801f6,0x00000000}},	//   ራዎች_, _робл, rsói, --, 
   {{0x602400dd,0x63a00311,0x200016a3,0xa5b800d8}},	//   _témá, _înne, _zuji_, ssói, 
   {{0x2000037e,0xadb400db,0x00000000,0x00000000}},	//   _yuji_, _جۇتا_, --, --, 
   {{0xa8500032,0x53940023,0x1ca40133,0xab60000d}},	//   шенә, _ዘገድስ_, _لێوی_, üüsi, 
   {{0x2a640070,0xc6900014,0x00000000,0x00000000}},	//   _tsob_, مِج_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7e7c1dec,0x628801b8,0x0ce4009e,0x00000000}},	//   _áspe, ägom, মশীত, --, 
   {{0xe1fc01e1,0x290c0ba7,0x00000000,0x00000000}},	//   _aróp_, _iffa_, --, --, 
   {{0x20000a2e,0x212005be,0x93a4013e,0x533400d8}},	//   _ruji_, _sejh_, ашуд, иест, 
   {{0x68e40cc1,0xe5c507dd,0xc6f80212,0x06cc0154}},	// [17fd0] əkda, _асно, _яних_, রেজি, 
   {{0x61bd07de,0x25d8000d,0x6ed4000d,0x00000000}},	//   ्वेष, _खीची_, _बड़ु, --, 
   {{0xa5b81709,0x35180302,0xd7c80ee8,0x40e401ec}},	//   dróx, _אותנ, _سویه_, усағ, 
   {{0xff24034c,0x20000a73,0x38bc00e4,0x00000000}},	//   ابای, _vuji_, lárô_, --, 
   {{0x20000198,0xbebc00b8,0x290d07df,0x00000000}},	//   _wuji_, _adūr, _offa_, --, 
   {{0x20000219,0xdd9802bf,0x03a400c7,0x290c032e}},	//   _tuji_, ьше_, _риҭо, _nffa_, 
   {{0x44200036,0x506401e0,0x8d8400f1,0x00000000}},	//   _jwh_, _ктта, ششون, --, 
   {{0x44200399,0x290d07e0,0x2c4c06be,0xdb20013d}},	//   _mwh_, _affa_, _mədh_, _üsüe, 
   {{0x7f480076,0x8b6404da,0x8a240022,0x00000000}},	//   _iceq, شايم, азыҵ, --, 
   {{0x44204694,0x7e6907e1,0xef240037,0xab60000d}},	//   _owh_, _isep, _üüri_, üüri, 
   {{0x5c0507e2,0x3f9c05db,0x281001d3,0xfaa40022}},	//   _ряза, okwu_, یویس, _әало, 
   {{0x290c05b1,0xeab40116,0x7e680055,0x8b940120}},	//   _effa_, _әйш_, _ksep, _вршч, 
   {{0x4420020c,0x7bd80521,0xd7640214,0xa3d4000d}},	//   _awh_, _ikwu, هنگی, ाकन_, 
   {{0x660033fc,0x442107e3,0x1dc05168,0x4534084c}},	//   спра, _bwh_, वचित, ихст, 
   {{0x7e6802c4,0x3a2c0869,0x588402dd,0x5fd01b76}},	//   _lsep, lsep_, _шыда, तवाल, 
   {{0x7e6907e4,0x77a40789,0x00000000,0x00000000}},	//   _osep, _bóxe, --, --, 
   {{0x3a2d07e5,0x77a40077,0x7e6801f2,0x00000000}},	// [17fe0] nsep_, _cóxe, _nsep, --, 
   {{0x15b404a9,0x44200007,0x7f4804d4,0x3a2c0194}},	//   _ئەسس, _fwh_, _aceq, isep_, 
   {{0x7e6907e6,0x7bd800b4,0xd5a4dc89,0x442107e7}},	//   _asep, _okwu, _ملکی, _gwh_, 
   {{0x7bd80521,0xdd2c012c,0x3a2c0115,0x6db00210}},	//   _nkwu, měři, ksep_, płak, 
   {{0x7e6801ed,0xa5b8056a,0xe29507e8,0x87ac00df}},	//   _csep, tróx, _бая_, ושאַ, 
   {{0x7bd800b4,0xec6907e9,0x7d00015d,0x4424552d}},	//   _akwu, ерик_, _cgls, _حریف, 
   {{0x7e6907ea,0xdee001a9,0x00000000,0x00000000}},	//   _esep, _ҳоти, --, --, 
   {{0x67fc0171,0x38bc00e4,0x00000000,0x00000000}},	//   _nūja, zárô_, --, --, 
   {{0x9f000014,0xdee107eb,0xaec4005b,0x23bc01f4}},	//   _اڈمو, _готи, _сбал, läjä_, 
   {{0x7bd800b4,0x2d9801b8,0x1a54007b,0x00000000}},	//   _ekwu, öped_, اشية_, --, 
   {{0x61d400c8,0x23bc023a,0x00000000,0x00000000}},	//   רויף_, näjä_, --, --, 
   {{0xc6600092,0x2c4c03e3,0x00000000,0x00000000}},	//   ዳደሪያ_, _nədi_, --, --, 
   {{0x4420002d,0x96f80b7e,0x00000000,0x00000000}},	//   _swh_, леют_, --, --, 
   {{0x290c20ac,0x442000b5,0x9c800010,0x291800e4}},	//   _uffa_, _pwh_, _ščis, _ýpa_, 
   {{0x4420020c,0xefe00023,0xa5b80162,0x84c4010b}},	//   _qwh_, ምምዕ_, dsót, рәпд, 
   {{0xc2c44630,0x03c4009e,0x9878010f,0x00000000}},	//   ليزي, ্ষ্ণ, _טרוק, --, 
   {{0xb6c0121c,0xd1d40092,0xc6a401ec,0x00000000}},	// [17ff0] _дөрд, ራጎት_, _әрқи, --, 
   {{0x442003cd,0x00000000,0x00000000,0x00000000}},	//   _twh_, --, --, --, 
   {{0x7e6907ec,0x7afc0419,0x00000000,0x00000000}},	//   _ssep, ľsti, --, --, 
   {{0x7e680076,0xc2100014,0x7afc00d0,0x0dc80131}},	//   _psep, _ؤج_, žsti, қучи_, 
   {{0xbe6801c6,0x645c01e4,0x00000000,0x00000000}},	//   талж_, ŭziĝ, --, --, 
   {{0x7e6907ed,0xa3bc1d68,0x3a2c0175,0xd658011a}},	//   _vsep, ेवक_, vsep_, טידת_, 
   {{0xdb080042,0xfce406ed,0xbb440395,0x00000000}},	//   _amgá, шоко, аейк, --, 
   {{0xab9004a9,0x7e6818d6,0x69c401ed,0x92d800fe}},	//   قلىغ, _tsep, éken, াধৰ_, 
   {{0x7e6907ee,0x00000000,0x00000000,0x00000000}},	//   _usep, --, --, --, 
   {{0xdb2001d3,0x67fc00ef,0xfb8400e5,0x00000000}},	//   جوکی, _rūja, _ھدای, --, 
   {{0x9a840220,0xc6880a1e,0x00000000,0x00000000}},	//   _әуел, _קא_, --, --, 
   {{0xc5e80302,0x67fc0882,0x7bd800b4,0xdd2c012c}},	//   _חד_, _pūja, _ukwu, věři, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x29c81cd1,0x2c4c03b9,0x00000000,0x00000000}},	//   _үтәү_, _sədi_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x67fc0171,0xe4c000d4,0xa5b8032e,0x00000000}},	//   _tūja, ійти, fsós, --, 
  
   {{0xe2940a16,0x3124006c,0x6db00034,0x2c4c03b9}},	// [18000] аат_, идаг, cław, _vədi_, 
   {{0x23bc049b,0x31140276,0xb38401ec,0x00000000}},	//   täjä_, рфас, ылұл, --, 
   {{0xaf040262,0x73e406ed,0x6ae02c30,0x653800d9}},	//   апел, _вонз, _पर्र, _בעיד, 
   {{0xdfccfb25,0xd1743e25,0x324429db,0x613000fd}},	//   ويل_, шығы, _кемг, _añlı, 
   {{0x7c3c002b,0x00000000,0x00000000,0x00000000}},	//   _āsra, --, --, --, 
   {{0xa5b80798,0xac74007b,0x00000000,0x00000000}},	//   lsór, لاعش, --, --, 
   {{0x4c9411ed,0xdc840801,0xdca00114,0x00000000}},	//   сийс, исъл_, жаји, --, 
   {{0xa5b80120,0x92d80154,0x00000000,0x00000000}},	//   nsór, াধী_, --, --, 
   {{0xa3a9026a,0x2fc40989,0xa9c507ef,0xa3d404fa}},	//   कोट_, mnog_, исок, ाकत_, 
   {{0x2fc41326,0x9994084c,0x7c3801bf,0xaf700092}},	//   lnog_, икыт_, åbræ, _ጥበቃና_, 
   {{0x1ddc05f9,0x2fc43421,0xab6416ab,0x1d040075}},	//   _पीटत, onog_, _ввел, _техи_, 
   {{0xeb9907f0,0x2fc507f1,0xeab81925,0x00000000}},	//   _шие_, nnog_, _ийе_, --, 
   {{0xc9c80799,0x6b8107f2,0x2fc41c06,0x00000000}},	//   _مژده_, _inog, inog_, --, 
   {{0x99d107f3,0x48c40124,0xd8b401ed,0x95d8005b}},	//   _وتوا, _гәма, ادیا_, идят_, 
   {{0x6db00034,0x6b8107f4,0xd90c04fb,0x2fc401a6}},	//   sław, _knog, _تیپ_, knog_, 
   {{0x2fc404b9,0x6d5802c4,0x7afc01a2,0x291c02d5}},	//   jnog_, _lbta, ľstv, lbta_, 
   {{0x6b800bb8,0x6d5907f5,0x2fc41326,0x7afc03c6}},	// [18010] _mnog, _obta, dnog_, žstv, 
   {{0xd5b84294,0x9258013e,0xa3a82ef1,0x2fc40142}},	//   _всю_, рафт_, कोज_, enog_, 
   {{0x6b801505,0x2004006a,0x60600131,0x291c0067}},	//   _onog, êni_, غۇرل, ibta_, 
   {{0x02d89cc8,0x6d58102c,0xb0bc0490,0x6b8004ba}},	//   _موجب_, _abta, ्थजग, _nnog, 
   {{0x6e3802d3,0x443000dd,0x228464d0,0xfe446e1e}},	//   _ብተግባ, lsz_, _тунг, ёнко, 
   {{0x9474424b,0x6b8107f6,0x69c401ed,0xf2940a1e}},	//   _ادیا, _anog, ékel, _הכשר_, 
   {{0x2fc40989,0x6d58007f,0x5044013e,0x443101b4}},	//   bnog_, _dbta, _меёб, nsz_, 
   {{0x6d5800c6,0x2fc40b91,0xa3a802e5,0x3b849a58}},	//   _ebta, cnog_, कोच_, слиг, 
   {{0x3d940276,0x00000000,0x00000000,0x00000000}},	//   _лиар, --, --, --, 
   {{0x443107f7,0x6b8107f8,0x8d84014b,0x3b540408}},	//   ksz_, _enog, _мухд, _ӳкер, 
   {{0x8d7507f9,0xa3d42db8,0xe8f507fa,0x69c8009f}},	//   _باقا, ाका_, йль_, _djfe, 
   {{0x443001ed,0x6b8000a3,0x291d07fb,0x00000000}},	//   dsz_, _gnog, abta_, --, 
   {{0x4430068f,0x291c01ab,0xa3a800bc,0xe1fc00e5}},	//   esz_, bbta_, कोछ_, _csók_, 
   {{0x2fc42d2b,0x37a80228,0x05980014,0x00000000}},	//   znog_, ттүн_, لمُک_, --, 
   {{0x64a107fc,0x443001d3,0x6b8002d0,0xe85000f2}},	//   пара, gsz_, _ynog, _فنود, 
   {{0x730404ad,0xe3b404f0,0xf77107fd,0x00000000}},	//   спаз, ббс_, _راب_, --, 
   {{0x2fc404b9,0xdb08013d,0xa3d4033f,0x71a40022}},	// [18020] vnog_, _imgä, ाक़_, бааз, 
   {{0xa5b803b7,0x76440a49,0x957801c0,0x2fc40142}},	//   ssór, muky, _төмс_, wnog_, 
   {{0x2fc404b9,0x752c02ce,0xa9b8008f,0xef180567}},	//   tnog_, mabz, נזער, гме_, 
   {{0xa2d107fe,0x2cb803b9,0x00000000,0x00000000}},	//   _भुक्, _üzdə_, --, --, 
   {{0x2fc41326,0x291c0050,0xefcc0020,0xddc907ff}},	//   rnog_, ybta_, _እገዛ_, _šišk, 
   {{0x752caa0e,0x6b810800,0xdd9002dd,0x6db0012d}},	//   nabz, _snog, зашы, jłat, 
   {{0x2fc4098d,0xdb08007c,0x20050801,0x764402d0}},	//   pnog_, _omgä, ínit_, huky, 
   {{0x4f840014,0x76450802,0x09d07ef5,0xa098010f}},	//   _باسہ, kuky, सक्य, _גילט, 
   {{0x752d0803,0xa9285d9d,0x764400e4,0xda14036b}},	//   kabz, ліне_, juky, یزیش_, 
   {{0x4430a735,0xdf54004b,0x6d5802d0,0x65a8002f}},	//   ysz_, _پرېښ, _ubta, _kühe, 
   {{0x752c0161,0x291d0804,0xe80002e5,0x00000000}},	//   dabz, rbta_, _रूखा_, --, 
   {{0x65a90805,0x6b8005b8,0x6d481512,0x76440083}},	//   _mühe, _unog, lgfa, fuky, 
   {{0x9f5c067c,0x44310806,0x65a800af,0x76441418}},	//   _diuè_, wsz_, _lühe, guky, 
   {{0x6d490807,0xe5c41301,0x443000dd,0x00000000}},	//   ngfa, ссмо, tsz_, --, 
   {{0xd5b80845,0x44250808,0x28000118,0xe1900137}},	//   сся_, èl_, ísně_, үлбө, 
   {{0x4430514a,0x76440337,0xe3b0072d,0x00000000}},	//   rsz_, buky, سرز_, --, 
   {{0x443000dd,0xc1b90809,0x752c00ca,0x672c0034}},	// [18030] ssz_, алах_, babz, macj, 
   {{0x69d9080a,0x672c006d,0xa37800e4,0x443001d3}},	//   note, lacj, _chõr, psz_, 
   {{0x4395080b,0x63a00311,0x98ac009b,0x69d8005a}},	//   _данс, _înno, ćaće_, iote, 
   {{0x6445080c,0x672c0034,0x65640200,0x00000000}},	//   muji, nacj, lejh, --, 
   {{0x69d9080d,0xd24405f5,0x6445080e,0x63bc636d}},	//   kote, _нэри, luji, miqn, 
   {{0x69d9080f,0xd6580302,0x20050810,0x5e3001ed}},	//   jote, ציות_, ínis_, _ہڑتا, 
   {{0x672c006d,0x64450811,0xbc48013e,0xa5b811e8}},	//   kacj, nuji, рӯза_, apóg, 
   {{0xdb081506,0x752c0161,0x6dbc0882,0x98640725}},	//   _omgå, zabz, ṇapr, ەلدە_, 
   {{0x64450812,0x69d90813,0x672c033f,0x45000eac}},	//   huji, fote, dacj, ্রিক_, 
   {{0x64450814,0x63bd0815,0x6564014f,0x0ca80124}},	//   kuji, hiqn, jejh, ртәи_, 
   {{0x644401fa,0x77c80b3e,0x63bc0309,0x194c037e}},	//   juji, илог_, kiqn, _ｍａｍ_, 
   {{0x260c014a,0x672c0034,0x64450816,0x76440337}},	//   _büo_, gacj, duji, tuky, 
   {{0x69d90817,0x6db00034,0x752c0112,0x2bd40073}},	//   bote, płat, tabz, डकरा, 
   {{0x7bc90818,0x6444037e,0x76450819,0xa80000fd}},	//   lneu, fuji, ruky, _çınn, 
   {{0x6445081a,0x23a400c5,0x7bc9081b,0x7644037e}},	//   guji, _sõja_, oneu, suky, 
   {{0x7bc9081c,0x4894044e,0x61f40369,0xdb085b00}},	//   nneu, ርግጋጽ_, emxl, _umgä, 
   {{0xa3b84425,0x260c0793,0xf11800c6,0x7bc9081d}},	// [18040] _अगर_, _güo_, لغات_, ineu, 
   {{0x6445081e,0x4254016a,0x65a800af,0x00000000}},	//   buji, ятст, _pühe, --, 
   {{0x260c01b8,0x6445081f,0x7bc90820,0x13a847f7}},	//   _züo_, cuji, kneu, _هندی_, 
   {{0x69d90821,0xdfcc00ec,0xaa840162,0xdb180254}},	//   zote, پيه_, ntýð, nnuä, 
   {{0x69d90822,0xa3d431a0,0x69c401ed,0x7bc801bf}},	//   yote, ाकर_, ékek, dneu, 
   {{0x672c006d,0x69d801c4,0x7bc801f5,0xddb40006}},	//   zacj, xote, eneu, огіі_, 
   {{0x6d490823,0xaff86248,0x40944137,0xa5b803b2}},	//   rgfa, _نفسا_, _ертт, spóg, 
   {{0x7bc90824,0x69d90825,0x2c4c06be,0x21ec002f}},	//   gneu, wote, _bədr_, rühe_, 
   {{0xaa640212,0xa2d000dc,0x3c140055,0x00000000}},	//   ітик, _भुञ्, _rāve_, --, 
   {{0x672c0034,0x6444af78,0x7bc90826,0x450003d4}},	//   wacj, yuji, aneu, ্ৰিক_, 
   {{0x672c068f,0xa3b80cb4,0x63bc022e,0x58d0004e}},	//   tacj, _अगल_, yiqn, доэт, 
   {{0x69d90827,0x64447c6f,0xdcac15bf,0x00000000}},	//   sote, vuji, _جىم_, --, 
   {{0x672c006d,0x69d90828,0xfa54179e,0x6564031c}},	//   racj, pote, _فروگ, tejh, 
   {{0x64450829,0x69d80014,0xe4a5082a,0xc9c80133}},	//   tuji, qote, орбо, _دژبه_, 
   {{0xd37015bf,0x58d0004e,0x63bd082b,0x672c012d}},	//   چۇپ_, _оошт, tiqn, pacj, 
   {{0xd370049e,0x6445082c,0xdb0401d3,0xe78401a9}},	//   نۇپ_, ruji, űlöl, _фуко, 
   {{0xdb0801e6,0x63bc544b,0x53343129,0x7bc40165}},	// [18050] _umgå, riqn, ьетт, éhui, 
   {{0x6445082d,0x60100003,0xd1b80592,0x6564014f}},	//   puji, _aħma, يالا_, qejh, 
   {{0x63bc0113,0x9e680092,0x00000000,0x00000000}},	//   piqn, _በልመና_, --, --, 
   {{0x63bc02d1,0x95380023,0xe1fc0210,0x2d98007c}},	//   qiqn, _እምነተ, _spód_, öpen_, 
   {{0x62881f53,0x8fe401e0,0x00000000,0x00000000}},	//   ågod, фәрҙ, --, --, 
   {{0x7bc800a9,0xf3f40133,0xfd1093fc,0x01a8009f}},	//   wneu, _وتێک, رجت_, _اُسي_, 
   {{0x8d75082e,0x7bc8257c,0x2c4c0213,0x00000000}},	//   بانا, tneu, _sədr_, --, 
   {{0x7bc85b55,0xe1fc033f,0xffb4008e,0x00000000}},	//   uneu, _psów_, _эйбэ, --, 
   {{0xdce01a48,0x68e400ac,0x2c4c03e3,0x00000000}},	//   menč, əkdi, _qədr_, --, 
   {{0x8d742db0,0xdce1082f,0x7bc90830,0x98640145}},	//   _يالا, lenč, sneu, ەلگە_, 
   {{0x7bc80af9,0x37e401b9,0xa3b80073,0x00000000}},	//   pneu, зонг, _अगं_, --, 
   {{0xf7706bc6,0xd6c40075,0xdce00010,0x49c801c6}},	//   راج_, димқ, nenč, йлөн_, 
   {{0xe8506071,0xcab8023a,0x59b01367,0x00000000}},	//   ونید, _мышц_, _жөнс, --, 
   {{0x8ac400c7,0x999c0327,0x78180395,0x00000000}},	//   _цқьа_, ntuż_, _люис_, --, 
   {{0x49b896e0,0x5fd8694b,0xa3d400dc,0xdce00024}},	//   _باند_, यकाल, ाकं_, kenč, 
   {{0xdce0bc2c,0xb7d839b1,0xa2d000dc,0x00000000}},	//   jenč, _دوعا_, _भुङ्, --, 
   {{0xdce02e31,0x00000000,0x00000000,0x00000000}},	// [18060] denč, --, --, --, 
   {{0xa6d801a8,0x00000000,0x00000000,0x00000000}},	//   ggðu, --, --, --, 
   {{0xa0640801,0x69c401ed,0x78a02d8b,0x6f650831}},	//   заха_, ékei, nylv, звез, 
   {{0x777401a9,0xd370113e,0xdce00010,0xa3d400cd}},	//   _jayx, _جۇر_, genč, ाकः_, 
   {{0x77750832,0x00000000,0x00000000,0x00000000}},	//   _mayx, --, --, --, 
   {{0x78a00c4e,0x00000000,0x00000000,0x00000000}},	//   kylv, --, --, --, 
   {{0xdce0107d,0x50a400db,0x00000000,0x00000000}},	//   benč, _تەال, --, --, 
   {{0xd1d40020,0x65a803be,0x950c025c,0xdce02e31}},	//   ያዎች_, _müha, _ཁུའི_, cenč, 
   {{0xad5815a0,0xe1fc0798,0xee389509,0x18b40022}},	//   _грех_, _próx_, _ына_, ҧгьы_, 
   {{0x9eb401e0,0x3330022e,0x00000000,0x00000000}},	//   _эшсә, hayx_, --, --, 
   {{0x7c2c107d,0x290801a6,0x186400d8,0x00000000}},	//   ćarc, žbao_, паќи_, --, 
   {{0x67fd0833,0xc6900014,0x00000000,0x00000000}},	//   _kūji, نِج_, --, --, 
   {{0xd49801c0,0x00000000,0x00000000,0x00000000}},	//   үрс_, --, --, --, 
   {{0xdce054b1,0x06e000ab,0x84c400d1,0x00000000}},	//   zenč, _गुणव_, дәмд, --, 
   {{0x7774102c,0x00000000,0x00000000,0x00000000}},	//   _fayx, --, --, --, 
   {{0x65a803b9,0x29f40210,0x00000000,0x00000000}},	//   _düha, _złap_, --, --, 
   {{0xdce10834,0x216402e8,0xd77400f7,0x67fc0171}},	// [18070] venč, зтег, _سايع, _nūji, 
   {{0x16980014,0xa088008e,0x00000000,0x00000000}},	//   _رٕپھ_, йсез_, --, --, 
   {{0xe7cc015b,0xdce019d6,0x96180d73,0x00000000}},	//   রতীয, tenč, _وغیر_, --, 
   {{0x657402d3,0x23681c4e,0x8f7402dd,0x8f010835}},	//   _haxh, _احدي_, еуші, бiр_, 
   {{0x65740472,0x3ce50836,0x999c025c,0x00000000}},	//   _kaxh, _sylv_, ttuż_, --, 
   {{0x050000bd,0x8d5402e8,0xdce00427,0x00000000}},	//   ্রীর_, етъч, senč, --, 
   {{0x65750837,0x8d740066,0xdf4400c0,0x00000000}},	//   _maxh, عاها, _нэап, --, 
   {{0x6574005c,0x2010022e,0x999c031c,0x00000000}},	//   _laxh, mqxi_, stuż_, --, 
   {{0x3c140055,0x77741eca,0x657402d0,0x34c801ad}},	//   _dāva_, _rayx, _oaxh, _रश्द, 
   {{0xbdc00150,0x777401a9,0x78a0017a,0x65742c76}},	//   _جەتۋ, _sayx, tylv, _naxh, 
   {{0xdb0801bf,0x050000eb,0x00000000,0x00000000}},	//   _omgø, ্রুর_, --, --, 
   {{0xded802d3,0x77740548,0x3c1400b8,0x78a001a4}},	//   _ንመን_, _qayx, _gāva_, rylv, 
   {{0x78a10838,0x65750839,0xb9b402e8,0xb99400ae}},	//   sylv, _baxh, _оскъ, _يشتغ, 
   {{0x65a8007d,0xc5f4774d,0xe3bc0165,0x1cd80327}},	//   _püha, нғы_, _amñ_, _རྙོ_, 
   {{0x7774011f,0x6601083a,0x290c0419,0x3c14002b}},	//   _tayx, тпра, ájať_, _yāva_, 
   {{0xb9dc2295,0x00000000,0x00000000,0x00000000}},	//   _ብሎ_, --, --, --, 
   {{0x95b405f5,0xd1680b82,0x29080205,0x00000000}},	// [18080] _зөвх, _ጽሑፍን_, şhaş_, --, 
   {{0x65a803fa,0x6574036e,0x7164007b,0xe1f44964}},	//   _hühn, _gaxh, بارك, дгу_, 
   {{0x65a80ccc,0xef240432,0x00000000,0x00000000}},	//   _kühn, _ýüki_, --, --, 
   {{0xaec5083b,0x65740b6f,0x1cd80327,0x67fc00dc}},	//   мбел, _zaxh, _རྙེ_, _pūji, 
   {{0xdef5083c,0x65741617,0x3c1400ef,0xe2941367}},	//   мыш_, _yaxh, _rāva_, _жая_, 
   {{0xc0cc0092,0x6fbc03d4,0x3c140055,0x21ec0037}},	//   ኤልም_, ইকেই, _sāva_, püha_, 
   {{0x2f5407d6,0x705428ee,0x61400114,0x1d040114}},	//   _отас, _تنزا, _јеса, мељи_, 
   {{0x9034010a,0x00000000,0x00000000,0x00000000}},	//   ăхĕч, --, --, --, 
   {{0x2908892f,0xfe7001d9,0x7c2c0e04,0x3c14002b}},	//   žbam_, _مدٕ_, ćara, _vāva_, 
   {{0x6e21083d,0xd9140c9e,0x09d83ead,0x5e98011a}},	//   mpob, мью_, डवेय, _ובמק, 
   {{0x65a83262,0xdb4c4990,0x04f8015b,0x6e2001e4}},	//   _bühn, _ию_, _অভ্র_, lpob, 
   {{0xdca0724a,0x00000000,0x00000000,0x00000000}},	//   _шахи, --, --, --, 
   {{0xdce00b13,0x5694008e,0x597002f2,0x7b1c110e}},	//   menā, ваят, ردیز, _ṣugb, 
   {{0xdb09083e,0x3a285397,0xe5d8010e,0xab600254}},	//   _algè, _çapa_, _ösüš, üüfi, 
   {{0x65742116,0x764400ad,0x69c400d5,0xd82c0139}},	//   _vaxh, arky, ékeu, _шэ_, 
   {{0x65744b2a,0x00000000,0x00000000,0x00000000}},	//   _waxh, --, --, --, 
   {{0x050000bd,0x85a4010b,0x65740200,0x98a400ef}},	// [18090] ্রের_, _зынҗ, _taxh, _ienā_, 
   {{0x51f83c1b,0x2a640ac5,0xa280004b,0x6e200210}},	//   дную_, _mpob_, _ییزو, dpob, 
   {{0x6ac84c3d,0x21ec01c7,0x98a400b8,0xef380023}},	//   ापुर, bühn_, _kenā_, _ከምዝው, 
   {{0xd2500131,0xb4f80375,0x00000000,0x00000000}},	//   انە_, _מפתי, --, --, 
   {{0x98a41d77,0x332400e8,0x00000000,0x00000000}},	//   _menā_, ñoxe_, --, --, 
   {{0x98a40b23,0x290801a6,0x67fc00b8,0x110400db}},	//   _lenā_, žbaj_, _vījy, ربەپ, 
   {{0x3ea9083f,0xe0900244,0x00000000,0x00000000}},	//   šat_, _جیاخ, --, --, 
   {{0x6ac8590f,0xa9200220,0x7644005b,0xdb180174}},	//   ापूर, ңдыл, yrky, nnuø, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf9910840,0xf1b0008f,0x9ac01418,0x65a8002f}},	//   ابة_, ָסט_, ŋŋoo, _sühn, 
   {{0xd52c01e1,0xe9cc01ec,0x46c40037,0x00000000}},	//   _lọ́d, _ұк_, _लेबह, --, 
   {{0xbebc0421,0x98a400e2,0x7bf860c6,0xe4e00037}},	//   _feūt, _cenā_, _энер_, _गड़ि_, 
   {{0xa680a6bb,0x80d809bd,0x2bd80014,0xa3e003ce}},	//   гляд, ভেচ্, _عامک_, धवन_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb0820ef,0x77a41709,0xd348006c,0x33f42bbd}},	//   _algé, _lóxi, ویده_, ечас, 
   {{0xa1c00c60,0x240400d8,0xa560036b,0x00000000}},	//   ҳбуд, енси_, پگین, --, 
   {{0x65a80730,0xa5b883a8,0xe1fc032e,0x00000000}},	// [180a0] _kühl, mpón, _spóa_, --, 
   {{0x5f9001d5,0x6e20047e,0xef380023,0x00000000}},	//   ғишт, vpob, _ከምዘው, --, 
   {{0x65a90841,0x21ec002f,0x98a400b8,0x00000000}},	//   _mühl, mühl_, _yenā_, --, 
   {{0x63ac045a,0x88bc01ef,0x00000000,0x00000000}},	//   _glcn, dběl, --, --, 
   {{0xdfcc3a16,0xdce00b13,0xe1fc01e1,0x00000000}},	//   حين_, venā, _ipón_, --, 
   {{0x6e20005a,0x63ac0175,0x7c2c107d,0x00000000}},	//   rpob, _zlcn, ćarn, --, 
   {{0x6e20d829,0x4c940354,0x00000000,0x00000000}},	//   spob, тийс, --, --, 
   {{0x2a64020b,0x6e200108,0x09c8712e,0x06cc03d4}},	//   _ppob_, ppob, िच्य, ৰেটি, 
   {{0x65a80ccc,0x2fc4037e,0xab640254,0x6e441291}},	//   _bühl, miog_, _asüü, _سنام, 
   {{0xdce03a71,0xec784166,0x3c14002b,0x2fc40143}},	//   senā, _нпз_, _gāvo_, liog_, 
   {{0x2d9c0270,0x98a4a33e,0xdd8d0842,0x22a401e1}},	//   _iote_, _penā_, _دول_, _kíkú_, 
   {{0xe7cc00bd,0x2fc40368,0x1cd8025c,0xab60000d}},	//   রত্য, niog_, _རྙི_, üüdi, 
   {{0x2d9c2752,0x65a80730,0x21ec0730,0x69c401ed}},	//   _kote_, _fühl, fühl_, ékes, 
   {{0x64440b21,0x2d9c8302,0xa8500131,0x3208033f}},	//   trji, _jote_, _бекә, _niby_, 
   {{0x2d9d0843,0x94d50844,0x842400d1,0x98a46856}},	//   _mote_, горц, ئىرن, _tenā_, 
   {{0x65a800b0,0xd37807d5,0x00000000,0x00000000}},	//   _tüho, нчу_, --, --, 
   {{0x32080851,0x21ecb44b,0x41541422,0xc6f80212}},	// [180b0] _biby_, bühl_, квас, _юних_, 
   {{0x2d9d0845,0x846802d3,0x65a80254,0x68e80208}},	//   _note_, _ሽግርን_, _kühm, _kyfd, 
   {{0x22a40241,0x03f810f3,0x80bc02a0,0x2fc40142}},	//   _bíkú_, _оној_, ्पें, fiog_, 
   {{0x44203e7c,0x2fc40142,0x00000000,0x00000000}},	//   _ith_, giog_, --, --, 
   {{0x2d9d0846,0x29080219,0x73c10847,0xbdf81e24}},	//   _bote_, žbah_, _тәре, ورتا_, 
   {{0x2d9d0848,0x44210849,0x61440241,0x98a40356}},	//   _cote_, _kth_, _délà, _jenă_, 
   {{0x1048034b,0xd13809a5,0xe24c01e1,0x00000000}},	//   _пяти_, _яхя_, _ṣèka, --, 
   {{0x3b8445ba,0x290cfac5,0xba740066,0x00000000}},	//   тлиг, _agfa_, ناخت, --, 
   {{0x2d9c06ee,0x4421084a,0xddd80356,0x3f8c054e}},	//   _fote_, _lth_, _cruţ, _ineu_, 
   {{0x8d747115,0x7e69084b,0x4421084c,0x2d9d084d}},	//   _ماما, _ipep, _oth_, _gote_, 
   {{0x61e4013f,0x7e680175,0x60c000ae,0xe9d4013d}},	//   _mkjl, _hpep, únmh, ткэ_, 
   {{0x2d9c00b2,0xf9902491,0xb6a401b9,0x65a80112}},	//   _zote_, ابک_, вимл, _wühl, 
   {{0x2d9c00b2,0x4421084e,0x999c0356,0xfaa41d39}},	//   _yote_, _ath_, gruţ_, _јало, 
   {{0xa5b9084f,0x68e8045f,0x7e6800f1,0xaa401945}},	//   spón, _fyfd, _mpep, _тешл, 
   {{0x44210850,0x24e400d8,0xe4c001f4,0x00000000}},	//   _cth_, вмри_, айри, --, 
   {{0x7e68016b,0x64a0045c,0x00000000,0x00000000}},	//   _opep, шаса, --, --, 
   {{0x44209b4c,0x7e68006e,0x290c010a,0xd34801b9}},	// [180c0] _eth_, _npep, _ygfa_, ویگه_, 
   {{0x3f8d0851,0x23c401e1,0xaa800432,0x2fc403cb}},	//   _aneu_, _pìjè_, _öýer, wiog_, 
   {{0x2d9d0852,0x7e690853,0x44200998,0x320800b5}},	//   _rote_, _apep, _gth_, _viby_, 
   {{0x2d9d0854,0x00000000,0x00000000,0x00000000}},	//   _sote_, --, --, --, 
   {{0x2d9d0855,0xde700372,0x2fc4996f,0x00000000}},	//   _pote_, لدوع, riog_, --, 
   {{0x2fc402d5,0x442001f9,0xf1d0b01b,0x37c803d4}},	//   siog_, _yth_, _төбө, ৰতিৰ, 
   {{0x2d9c4ea3,0x6ac8085c,0x7e690856,0x22a401e1}},	//   _vote_, ाप्र, _epep, _tíkú_, 
   {{0x2d9d0857,0xce350858,0x65a800af,0x00000000}},	//   _wote_, _مورک, _rühm, --, 
   {{0x2d9cd34f,0x5a303697,0x65a806be,0x7fd44f32}},	//   _tote_, аныт, _sühm, _сірі, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3a7401c0,0x00000000,0x00000000,0x00000000}},	//   влөр, --, --, --, 
   {{0x68e805e4,0x7e6802d0,0x00000000,0x00000000}},	//   _vyfd, _ypep, --, --, 
   {{0xddd81f48,0x9bc40150,0x947400f2,0x00000000}},	//   _hruš, _جۇيە_, یدفا, --, 
   {{0xddd81050,0xd87000cf,0x00000000,0x00000000}},	//   _kruš, _چايب, --, --, 
   {{0xd5b8870a,0x04c8131e,0x98a00640,0xa85001e0}},	//   тся_, روري_, _вије, _тейә, 
   {{0x61e40158,0x9cd402e4,0x88bc0118,0x7c4402f0}},	//   _skjl, דולה_, yběj, _útrž, 
   {{0x44200076,0xd6d8084c,0xd05c0213,0x00000000}},	// [180d0] _wth_, _атэ_, _iyrə, --, 
   {{0x4420aac6,0x3f8c5613,0xa5e4010b,0xa0a402dd}},	//   _tth_, _sneu_, _шюйл, кшел, 
   {{0x44200fa2,0x10140736,0x00000000,0x00000000}},	//   _uth_, لبند, --, --, 
   {{0x752005be,0x00000000,0x00000000,0x00000000}},	//   _đozi, --, --, --, 
   {{0x3f80012c,0x42a400d1,0x65a8000d,0xb3b8011a}},	//   ěhu_, _сунғ, _nühk, _נמשכ, 
   {{0xddd9015d,0x8e080212,0xed54eec3,0x54343267}},	//   _bruš, внів_, гош_, _حریر, 
   {{0x6da06128,0x6e400131,0xd05c06be,0x10a4014b}},	//   сища, لچەم, _oyrə, _киён, 
   {{0x5ba03500,0x5a400116,0x81d40107,0x999c00d7}},	//   рлиғ, амиғ, _роҳх, druš_, 
   {{0x7e690859,0xf99000f2,0x98a40153,0x00000000}},	//   _upep, مبد_, _meną_, --, 
   {{0xdd98006c,0xe9d5085a,0xddd9085b,0x382801c0}},	//   _ўша_, лкы_, _fruš, нжоо_, 
   {{0xa3e000e1,0xbb5424c5,0x65a800af,0xddd80010}},	//   धवा_, _مناب, _tühj, _gruš, 
   {{0xe1fc0332,0xdb18000d,0xd90c00e5,0x00000000}},	//   _spól_, nnuü, حیں_, --, 
   {{0xddd80e96,0x7bc9085c,0x00000000,0x00000000}},	//   _zruš, mieu, --, --, 
   {{0x7bc9085d,0x23a400af,0x999c01a6,0x88c401b9}},	//   lieu, _mõju_, bruš_, اتیل, 
   {{0x74147660,0x441400fb,0x29d001e2,0x00000000}},	//   اورا, ифтт, _ديوس, --, 
   {{0x7bc9085e,0x98a4012d,0x88bc013a,0x00000000}},	//   nieu, _ceną_, dběh, --, 
   {{0xafe401d5,0xe7b000f1,0x00000000,0x00000000}},	// [180e0] қодл, _دميد, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7bc9085f,0x7054059e,0xd2500014,0x70f4003b}},	//   kieu, انصا, _ژۆر_, учає, 
   {{0xaf350860,0x7bc83386,0x98a40064,0x00000000}},	//   ارات, jieu, _geną_, --, 
   {{0xddd82d2b,0x7bc90861,0x6da50862,0xa2c80316}},	//   _sruš, dieu, лида, _सेप्, 
   {{0xddd90863,0x65a80254,0x00000000,0x00000000}},	//   _pruš, _rühk, --, --, 
   {{0x7bc90864,0xa0a10865,0x00000000,0x00000000}},	//   fieu, _лард, --, --, 
   {{0xafe50866,0xd1f80020,0x7bc90867,0x65a80037}},	//   _собл, ቋዎች_, gieu, _pühk, 
   {{0xac900046,0xdb080142,0x50f4000d,0x91a8000d}},	//   рақш, _algâ, _अरुआ_, _गवाई, 
   {{0xa2c81cd2,0xddd8b2be,0x00000000,0x00000000}},	//   _सेफ्, _truš, --, --, 
   {{0xddd808ad,0xa2c80bae,0xcc8403e6,0x7bc8d65f}},	//   _uruš, _सेन्, _ڕۆژه_, bieu, 
   {{0x7bc90868,0xdcac0150,0xdc980375,0xdb10032e}},	//   cieu, _عىن_, _ריאל, _óaðf, 
   {{0x99d00133,0x964400ee,0xa03c0023,0x88bc0118}},	//   شتیا, йэрд, _ኣውንታ, zběh, 
   {{0x3eb8247e,0x98a40153,0xe73c00e4,0x00000000}},	//   _üste_, _seną_, ikõi_, --, 
   {{0x6d585557,0x00000000,0x00000000,0x00000000}},	//   _mcta, --, --, --, 
   {{0x65a90869,0x291c003a,0x461400f2,0x27ec08a5}},	//   _mühi, lcta_, _پودر, _ógn_, 
   {{0x6d59086a,0x65a8007d,0x9c1001f2,0x45d40276}},	// [180f0] _octa, _lühi, họpu, _вопс, 
   {{0x291d086b,0x7bc9086c,0xe5680ca8,0x00000000}},	//   ncta_, zieu, _àfàì, --, 
   {{0x3f15086d,0x7c2c53fb,0x291c003a,0x7bc8003e}},	//   адес, ćark, icta_, yieu, 
   {{0xfe7800bc,0x3dc40334,0x7bc806af,0x00000000}},	//   _psů_, _smlw_, xieu, --, 
   {{0x7bc84345,0x65a80254,0xfd7401c6,0x7338010f}},	//   vieu, _pühh, илдэ, _בערס, 
   {{0x61400131,0x4d64003b,0x00000000,0x00000000}},	//   _دىسە, йків, --, --, 
   {{0xa3780022,0x9f680953,0x4270001f,0x5108010a}},	//   _akõi, _праз_, _ስርአት_, _йĕшĕ, 
   {{0x291c9b18,0x6d59086e,0x0ec00073,0xab6000d1}},	//   ecta_, _ecta, _शेकड, قۇمى, 
   {{0x7bc9086f,0xab6000d1,0x46c4000d,0x00000000}},	//   rieu, تۇنى, _लेलह, --, 
   {{0x7bc90870,0xf8650871,0x79c402bf,0x2d9801e3}},	//   sieu, авоо, рйоз, öpet_, 
   {{0xe8f50872,0x7bc90873,0xa5b80022,0x00000000}},	//   иль_, pieu, apók, --, 
   {{0x6280005f,0x3c1400e2,0x37e44eca,0x00000000}},	//   ānoj, _nāvi_, ромг, --, 
   {{0xaf74008f,0xc8b4036b,0xf9d40024,0x00000000}},	//   בערס_, للیک, _кодэ, --, 
   {{0x291c074d,0x7b180419,0x00000000,0x00000000}},	//   ccta_, sťuč, --, --, 
   {{0xc9d40963,0x79800921,0x64a001ec,0x00000000}},	//   _دموک, mdlw, оара, --, 
   {{0x44f40165,0xe73c0022,0x00000000,0x00000000}},	//   _d̥_, ykõi_, --, --, 
   {{0x51440220,0x311402d5,0x290801a6,0xada00022}},	// [18100] йдағ, афес, žbat_, _ñúgu, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa1101f7a,0x00000000,0x00000000,0x00000000}},	//   زونت, --, --, --, 
   {{0x60200212,0x65a8000d,0x388400ef,0x8e38022e}},	//   ідча, _rühi, _mēr_, аzаm_, 
   {{0x7afc0162,0x00000000,0x00000000,0x00000000}},	//   ýstl, --, --, --, 
   {{0x79800218,0x65a800c5,0xec680cc9,0x3f980241}},	//   jdlw, _pühi, врик_, _òsun_, 
   {{0x260c0327,0x6140010b,0x26f00037,0x00000000}},	//   _ożon_, _феса, _घर्र_, --, 
   {{0x2078008f,0xaa64cfae,0xe0d4014b,0x00000000}},	//   _באלא, аток, _твс_, --, 
   {{0x41dc01ad,0xa92800fa,0x999c0356,0x00000000}},	//   _मदमस, кіне_, ârşi_, --, 
   {{0x65a800af,0x291c003a,0x6d5802d0,0x00000000}},	//   _tühi, ucta_, _ucta, --, 
   {{0xb9840220,0x65a8000d,0x00000000,0x00000000}},	//   стық, _kühv, --, --, 
   {{0xddd8033f,0xa5b81941,0x00000000,0x00000000}},	//   _opuś, mpói, --, --, 
   {{0x2a7404fb,0xcbc4004b,0x2b440051,0x00000000}},	//   _خداح, _پېښو_, _idoc_, --, 
   {{0x67000574,0x21ec000d,0x00000000,0x00000000}},	//   रेषक_, pühi_, --, --, 
   {{0x94a90874,0x44250875,0xd90c0276,0x00000000}},	//   атта_, ël_, _фь_, --, 
   {{0x473412ff,0xdb180008,0xa5b800e4,0xc2c400ae}},	//   _унис, nnuð, ipói, ميزي, 
   {{0x7c2c39ae,0xb060023a,0x1cd8031c,0x26cc01e3}},	// [18110] ćari, äänl, _རྙན_, _ägo_, 
   {{0xa2c85b82,0xc0c4010b,0x00000000,0x00000000}},	//   _सेण्, бәби, --, --, 
   {{0x6700547d,0xdce00153,0xa6d8032e,0x00000000}},	//   रेरक_, benę, faðg, --, 
   {{0x98a40034,0x7eb801e0,0x1afc03d4,0x2b44036e}},	//   _cenę_, лгес_, োঁতে_, _ndoc_, 
   {{0xd2450876,0xc0e00020,0xf16400d1,0x00000000}},	//   _мэри, ናክሮ_, شخەۋ, --, 
   {{0x2b44067c,0x6da10877,0xada10878,0x00000000}},	//   _adoc_, зиша, зашл, --, 
   {{0xdb1801a8,0x5c7400fb,0x00000000,0x00000000}},	//   fnuð, рҙер_, --, --, 
   {{0x14d80a1e,0xdb1801a8,0xeeb4035f,0xc0e00092}},	//   יוול_, gnuð, рләш_, ናክር_, 
   {{0xa3ac033d,0x2b440142,0x00000000,0x00000000}},	//   _कवन_, _ddoc_, --, --, 
   {{0x3944074d,0xdb08007c,0xcaf4009d,0x00000000}},	//   щног, _omgö, өцөө, --, 
   {{0x499802d5,0x37e400db,0x00000000,0x00000000}},	//   ртыя_, йоог, --, --, 
   {{0x80d4012c,0xab600166,0x00000000,0x00000000}},	//   _दशैं, _çüpt, --, --, 
   {{0x3a2806a3,0x3934013d,0x87f801c6,0x00000000}},	//   _ïap_, _лэйс, рээт_, --, 
   {{0x7df802e2,0xdb080432,0xa5200798,0x00000000}},	//   _pňsy, _bmgö, змрд, --, 
   {{0xddd80210,0x7bf800df,0x00000000,0x00000000}},	//   _spuś, ָפּצ, --, --, 
   {{0xf1a8030f,0x00000000,0x00000000,0x00000000}},	//   گاره_, --, --, --, 
   {{0xb1450879,0x59a8000d,0x7168009d,0x32440166}},	// [18120] йнал, _छवार, лааг_, сезг, 
   {{0xf1a9087a,0x572400db,0x995c0118,0x00000000}},	//   داره_, _دۉڭك, téři_, --, 
   {{0x65a80254,0xf064bd83,0x73e45dc0,0xddd80210}},	//   _pühv, скеп, _гонз, _wpuś, 
   {{0x09a40073,0xa3e000cd,0x00000000,0x00000000}},	//   _ओव्य, धवः_, --, --, 
   {{0x9f5c004d,0x0cb1087b,0xe4d001ec,0xddd80210}},	//   _khuê_, जन्म, _وقۋد, _upuś, 
   {{0x4c9400f7,0x62800034,0x260400e8,0xfb8401d9}},	//   жикс, łnoc, 鯵oo_, ۪گلی, 
   {{0x672c0210,0x00000000,0x00000000,0x00000000}},	//   ybcj, --, --, --, 
   {{0xdce000bc,0x00000000,0x00000000,0x00000000}},	//   leně, --, --, --, 
   {{0xa5b80597,0x65a803e3,0x2984008e,0x2a9800ae}},	//   spói, _zühu, бынг, ائعة_, 
   {{0x9d40165d,0xbda400c6,0x9b5401d5,0x00000000}},	//   _неуд, _وحلو, _ғишт_, --, 
   {{0xab8400ee,0x21ec03fa,0x0a6800d1,0x65a80205}},	//   _гулк, müht_, урқи_, _müht, 
   {{0x65a80254,0x98c001e0,0x21ec002f,0x00000000}},	//   _lüht, ясыл, lüht_, --, 
   {{0x6af48b4d,0x6a840137,0xd49801ec,0x00000000}},	//   _اثار, _ылда, ұрт_, --, 
   {{0x6b809a91,0x7c40040e,0xdce001ef,0x00000000}},	//   _haog, _äyrä, jeně, --, 
   {{0xb060023a,0x58d00276,0x80ac2cc5,0x850433d2}},	//   ääll, _ношт, _টেন্, زورن, 
   {{0xc61801f4,0xd3a4011c,0x00000000,0x00000000}},	//   _коих_, пруп, --, --, 
   {{0x6b8001af,0xc2987fb5,0xb5e00150,0x52140e48}},	// [18130] _maog, шках_, _ﺍﻳﯩﺰ, здут, 
   {{0x6b80464c,0x7e98732b,0x00000000,0x00000000}},	//   _laog, ینار_, --, --, 
   {{0x6b800607,0x69c80093,0x80781219,0x92580131}},	//   _oaog, _mmfe, рбес_, _һаят_, 
   {{0x6b81087c,0xab600254,0x00000000,0x00000000}},	//   _naog, üüli, --, --, 
   {{0x69c8000f,0xbef400dc,0xa41c02db,0xdce0013a}},	//   _omfe, ेधेन_, _मंडप_, beně, 
   {{0x6b80096b,0x98a4012c,0x65a800b0,0xa5b800e4}},	//   _aaog, _ceně_, _tühu, apóv, 
   {{0xfc04c43c,0x6b8001ab,0x00000000,0x00000000}},	//   опко, _baog, --, --, 
   {{0xba25087d,0xe61c011f,0x6b80952b,0x65a80205}},	//   одик, kqô_, _caog, _züht, 
   {{0x7d98c2f7,0x00000000,0x00000000,0x00000000}},	//   _квас_, --, --, --, 
   {{0x65a80e78,0x00000000,0x00000000,0x00000000}},	//   _mühs, --, --, --, 
   {{0x6b8008c2,0xf771087e,0xfcd4027d,0x00000000}},	//   _faog, واح_, _بياج, --, 
   {{0x6b81087f,0x69c801c7,0x00000000,0x00000000}},	//   _gaog, _emfe, --, --, 
   {{0xe9cd0880,0xfaa4039b,0xda2400db,0x2c0801af}},	//   _жк_, _фало, _ايتۇ_, _тьфү_, 
   {{0xc8c800ec,0x00000000,0x00000000,0x00000000}},	//   _ڏوهن_, --, --, --, 
   {{0xd5e4063f,0xe61c0548,0x65a80254,0x00000000}},	//   _arị, aqô_, _rüht, --, 
   {{0xcb080137,0x66040009,0xdce000ef,0x00000000}},	//   _ئيۇن_, amjk, ednī, --, 
   {{0x9f5c07ae,0xdce0012c,0x63a807de,0xf77000f2}},	// [18140] _thuê_, teně, ögna, _فاک_, 
   {{0x7f490881,0x00000000,0x00000000,0x00000000}},	//   _adeq, --, --, --, 
   {{0xef190882,0x38640455,0x00000000,0x00000000}},	//   аме_, ntlr_, --, --, 
   {{0xa48401d9,0xa2c801bc,0xae8800fd,0x69c401d3}},	//   _بێٲل_, _सेव्, ибез_, ékez, 
   {{0x1ec41575,0xab6000c5,0x6b8000a3,0x3330003a}},	//   олци_, üümi, _raog, mbyx_, 
   {{0x6b810883,0xac2412e7,0x00000000,0x00000000}},	//   _saog, офик, --, --, 
   {{0x6b800607,0x21ec0112,0xa5b837b5,0x00000000}},	//   _paog, rüht_, mpót, --, 
   {{0x3a2c0004,0xdd8c006c,0x6fb4007b,0x00000000}},	//   fpep_, _یوق_, _بمرا, --, 
   {{0xed583532,0x6b800607,0xdfcc007b,0x65a803e0}},	//   _воз_, _vaog, _شيك_, _mühr, 
   {{0x6b8001c8,0x4fc400cf,0xfec80451,0x27e80142}},	//   _waog, _بەچە, _طبقو_, wocn_, 
   {{0x2b44152d,0x27e8011c,0x6b8001ab,0xbbd401d9}},	//   _дэлг, tocn_, _taog, _کٕنک, 
   {{0x6b800618,0x46240327,0x7c641291,0xdb54011c}},	//   _uaog, _འཕྱས_, _ءالل, _дюш_, 
   {{0x46c4012c,0xeab003c7,0x0a940395,0x00000000}},	//   _लेखह, _تعا_, _халю, --, 
   {{0x69c90884,0x00000000,0x00000000,0x00000000}},	//   _umfe, --, --, --, 
   {{0xa50404a9,0x69d8009a,0xe3b02e0b,0xdb080166}},	//   زىرە_, mnte, ورر_, _elgä, 
   {{0xddd8054e,0x69d90885,0xd90c10e8,0x47350886}},	//   _opuş, lnte, _جیپ_, _энис, 
   {{0x1dd813b4,0xd2500592,0x1b78010f,0xae181b51}},	// [18150] _बदलत, َنِ_, סטמע, _फूलन_, 
   {{0x69d90887,0x7afc09f3,0xd25001ed,0xa088008e}},	//   nnte, ýsti, کنے_, исез_, 
   {{0x65a80639,0xe7cc0c58,0xddd80139,0x4dd0009e}},	//   _führ, ৰতীয, _apuş, াকাং, 
   {{0xa3ac0abd,0x69d80730,0x3a2c0076,0x28a03885}},	//   _कवि_, hnte, ypep_, _ओपनि, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd6580375,0xa5b80798,0xf2d0008f,0x69d801a4}},	//   קיות_, mpós, _װעל_, jnte, 
   {{0xa3dc0a28,0x21ec0730,0x80a4182c,0xbb4411d2}},	//   _तदा_, bühr_, _عمرن, пейк, 
   {{0x69d90888,0x4c0400c6,0x628c00d7,0x4034014b}},	//   ente, وظيف, _krco, _меҳс, 
   {{0x69d801a8,0x1c1800c5,0x3e340244,0x00000000}},	//   fnte, _पूरल_, _رفار, --, 
   {{0x4e9401d5,0x0ca80124,0x00000000,0x00000000}},	//   _تشفر, стәи_, --, --, 
   {{0x7c2d0889,0x8d7401d9,0x3a2c0784,0xdb8400fb}},	//   ćars, _زالا, spep_, _мѳди, 
   {{0x69d803bd,0x628c0561,0xe8900022,0xeb8c00f0}},	//   ante, _orco, хаџь, _џи_, 
   {{0xa2c839de,0x65a803fa,0x00000000,0x00000000}},	//   _सेल्, _rühr, --, --, 
   {{0x69d8003a,0xb90000eb,0xf868020c,0x00000000}},	//   cnte, _দর_, _همتي_, --, 
   {{0xb864004b,0x00000000,0x00000000,0x00000000}},	//   _راغو, --, --, --, 
   {{0xb225088a,0x63bc0204,0xdb08005c,0x88c400db}},	//   змал, ghqn, _elgå, _زتىل, 
   {{0xe295088b,0x337c0023,0xdce001e4,0xa2e002e8}},	// [18160] пат_, _ብኽልተ_, venĝ, еотд, 
   {{0xb46437ab,0x7645088c,0x628cea52,0x00000000}},	//   _екол, msky, _drco, --, 
   {{0xe1fc0cfc,0x628d088d,0x7645088e,0x41dc00e1}},	//   _após_, _erco, lsky, _मदरस, 
   {{0xa6d805f7,0xd2500014,0xa2a40490,0xee842f6a}},	//   laða, _لۆر_, _टॅक्, зыко, 
   {{0x7645088f,0xa5b90890,0x684001e1,0xdb1800e4}},	//   nsky, mpór, _kídá, chué, 
   {{0xa6d826b8,0x62804424,0x00000000,0x00000000}},	//   naða, ānot, --, --, 
   {{0xfd7801d3,0x69d8072b,0xc10400f1,0x00000000}},	//   زشوں_, vnte, _يوټي, --, 
   {{0x753c007f,0x69d8015d,0x7644007c,0xceb801e0}},	//   _lepz, wnte, ksky, _мәл_, 
   {{0x98a40115,0xa6d80ad9,0x69d805ac,0xa5b80588}},	//   _venĝ_, kaða, tnte, ipór, 
   {{0x76450891,0xa6d80bcd,0x6e200472,0xdeb8011a}},	//   dsky, jaða, mqob, _הממל, 
   {{0x69d90892,0x764404e6,0x6e20022e,0xa6d809e8}},	//   rnte, esky, lqob, daða, 
   {{0xdc9808a8,0xdb1800e4,0x7644032e,0x00000000}},	//   _ליבל, yhué, fsky, --, 
   {{0x6e201717,0x9f4c0004,0x7644376e,0xeaf8007b}},	//   nqob, llgã_, gsky, _ارات_, 
   {{0x7afd0893,0xe8b4025c,0x628c0175,0xa3cc01ad}},	//   üste, ྒྱུག, _rrco, वोन_, 
   {{0x68400248,0x628c01a6,0x6e20022e,0xa2bc000d}},	//   _dídá, _srco, hqob, लैन्, 
   {{0x628c037e,0xab600037,0xd8d8011a,0x53440108}},	//   _prco, üühi, _לקור, ехфа, 
   {{0x93e401b9,0x7658012d,0x21300051,0xf2840166}},	// [18170] хўрл, ątyc, tbxh_, мөрд_, 
   {{0xbba81d8a,0x673c02d3,0xa5b800c7,0x63bc022e}},	//   _छक्क, _heqj, apór, shqn, 
   {{0x673c0023,0x40940131,0xbb4801ec,0x55ac010f}},	//   _keqj, بلار, _ﺁﻻﻑ_, _הייַ, 
   {{0x66140165,0x443000d8,0x661c036e,0x67fc00dc}},	//   _hixk, mpz_, _kuqk, _pūjy, 
   {{0x661401c4,0x6e204b2a,0x673c0003,0x4430004e}},	//   _kixk, gqob, _meqj, lpz_, 
   {{0x51850894,0x7c942083,0xed4c210e,0x00000000}},	//   _пуса, дриц, لھم_, --, 
   {{0x6614005a,0x6da000a7,0x6444045f,0x44300010}},	//   _mixk, тища, nsji, npz_, 
   {{0x6614031c,0x6e200175,0x76450895,0xd49805d0}},	//   _lixk, bqob, ysky, לכות_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x64450896,0x9588033f,0x4ea4010a,0x00000000}},	//   ksji, _krąż, _ярса, --, 
   {{0xddd8098d,0x5ae45533,0x673c036e,0x37e50897}},	//   _kruž, _کثاف, _beqj, донг, 
   {{0x2aec02e3,0x644403cd,0x00000000,0x00000000}},	//   ịkị_, dsji, --, --, 
   {{0xa6d809cc,0x6614005a,0x764404b1,0x00000000}},	//   taða, _bixk, usky, --, 
   {{0x76450898,0x4430030d,0x00000000,0x00000000}},	//   rsky, fpz_, --, --, 
   {{0xddd81326,0x76444162,0x80ac015b,0xa6d8041e}},	//   _oruž, ssky, _টেস্, raða, 
   {{0x76450899,0x661c031c,0xa6d80d12,0x00000000}},	//   psky, _fuqk, saða, --, 
   {{0xdb0828f2,0xa3ac1533,0xa5b80a90,0xa6d80d12}},	// [18180] _algú, _कवर_, rpór, paða, 
   {{0xa5b80efe,0xe1fc012d,0x7614030d,0x00000000}},	//   spór, _spór_, _юьйх, --, 
   {{0x628801e6,0xa0642d1f,0x24200124,0xddd8139f}},	//   ågor, даха_, _аҧсҭ, _bruž, 
   {{0xdd8c230f,0x9588012d,0x00000000,0x00000000}},	//   یون_, _drąż, --, --, 
   {{0xdfcc286d,0xddd8140b,0xcd740395,0xee7800f2}},	//   جين_, _druž, еглъ, تصات_, 
   {{0x844404fb,0x6e2001a9,0x00000000,0x00000000}},	//   _تخیل, rqob, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xddd9089a,0x60941bf4,0x5c700395,0x00000000}},	//   _gruž, _تنفس_, тлът, --, 
   {{0x6e200ba7,0x00000000,0x00000000,0x00000000}},	//   qqob, --, --, --, 
   {{0xdee000c7,0xdbdc032e,0x00000000,0x00000000}},	//   _роуи, fíós, --, --, 
   {{0xc0f00023,0x600000e4,0x00000000,0x00000000}},	//   ፍፋል_, sõme, --, --, 
   {{0xe7cc0c58,0x9b9000c6,0xb8642a9f,0xc78400cf}},	//   ৰত্য, _للمت, راپو, راجۉ, 
   {{0x661401c0,0x298400db,0x00000000,0x00000000}},	//   _pixk, _жыйг, --, --, 
   {{0x64440a85,0x7d000175,0x00000000,0x00000000}},	//   tsji, _yzls, --, --, 
   {{0x78a0003a,0x248c0023,0x673c0200,0xaa84032e}},	//   cxlv, _ሓያላት_, _teqj, brýð, 
   {{0x6444000f,0x44300393,0xa5b8035b,0x6280012d}},	//   rsji, rpz_, apóp, łnom, 
   {{0x6d1c0c70,0x260400cf,0xc1b80064,0xb274035b}},	// [18190] _पलंग_, _очог, плах_, нктә, 
   {{0xf6e80dd4,0x4430010a,0x6444002d,0x95880210}},	//   _རྙིང, ppz_, psji, _prąż, 
   {{0xddd805ce,0x10480212,0x4430003a,0xd7c830cd}},	//   _pruž, дячи_, qpz_, _رویه_, 
   {{0x4421089b,0x00000000,0x00000000,0x00000000}},	//   _iuh_, --, --, --, 
   {{0x25ac05d5,0x5224013e,0x60000037,0x9f4c0240}},	//   _îgls_, _афса, tõmb, logë_, 
   {{0x44200086,0xa2bc02e5,0x0d85089c,0x6e900338}},	//   _kuh_, लैण्, клін, الوا, 
   {{0x4421089d,0x1048023b,0x3ce805ac,0x60000022}},	//   _juh_, _ояти_, য়েন্_, rõmb, 
   {{0x4421089e,0xcc0806f6,0x60000254,0x39480055}},	//   _muh_, وزين_, sõmb, _śas_, 
   {{0x4421089f,0xa5b80022,0xb060007c,0x00000000}},	//   _luh_, ypóp, äävl, --, 
   {{0x3d1800e1,0xa6d8148b,0x13dc00cd,0x00000000}},	//   _पलटे_, taðn, _यद्भ, --, 
   {{0x4420016d,0xbb180451,0x3e6908a0,0x00000000}},	//   _nuh_, _فياض_, lút_, --, 
   {{0xf090159d,0xe7340815,0xdb080200,0xa6d803b2}},	//   אנט_, нею_, _jogë, raðn, 
   {{0x3e6908a1,0x442108a2,0x7c200450,0xb54c0023}},	//   nút_, _auh_, _hulr, _ንምፍት, 
   {{0x44200652,0xdb080036,0x7c2001d5,0xb8e403d4}},	//   _buh_, _logë, _kulr, _এশ_, 
   {{0x6600b2bd,0x394508a3,0xdce0005f,0xa50508a4}},	//   упра, mals_, menē, еера_, 
   {{0x442108a5,0x3944004e,0x9f5c007b,0x3e6908a6}},	//   _duh_, lals_, _bhuí_, kút_, 
   {{0x442108a7,0x9f5c007b,0x3e685511,0xa6d80162}},	// [181a0] _euh_, _chuí_, jút_, naðl, 
   {{0xe1f508a8,0x442108a9,0x3944ea90,0xefb001b9}},	//   егу_, _fuh_, nals_, گیرگ, 
   {{0x44200207,0xddd80034,0x3944004e,0x7c2001bf}},	//   _guh_, _druż, ials_, _nulr, 
   {{0xa2c865d9,0x394508aa,0xddd80327,0x2ee44b1c}},	//   _सेक्, hals_, _eruż, нжег, 
   {{0x3e6830f9,0x394400da,0x9f5c01e7,0xe29508ab}},	//   gút_, kals_, _ghuí_, _зая_, 
   {{0x7c20017a,0x442003e0,0x0cd40828,0x00000000}},	//   _bulr, _yuh_, колю, --, 
   {{0x7e68014b,0x7c2001ab,0x6da40032,0xd84c0241}},	//   _eqep, _culr, _үҙең_, _sọnu_, 
   {{0x3e68000f,0x512002e5,0x2d98002d,0x39440175}},	//   bút_, _बलुआ_, űpe_, eals_, 
   {{0xdee108ac,0xdb0800f2,0x394508ad,0x3f8800b0}},	//   _боти, _jogè, fals_, ɾau_, 
   {{0x394508ae,0x7afd08af,0x00000000,0x00000000}},	//   gals_, üsta, --, --, 
   {{0xb9840046,0x7c2108b0,0x00000000,0x00000000}},	//   ттық, _gulr, --, --, 
   {{0x4420b032,0xddd8041a,0xdcac215c,0x7658012d}},	//   _ruh_, _isuš, _دىم_, ątyn, 
   {{0x44200978,0x394508b1,0x3a28004e,0x00000000}},	//   _suh_, bals_, _жечү_, --, 
   {{0x394508b2,0x442108b3,0xc8f40801,0xd84c0241}},	//   cals_, _puh_, _излъ, _kọlu_, 
   {{0x442108b4,0x9f5c00ae,0x3e6800e5,0x00000000}},	//   _quh_, _shuí_, zút_, --, 
   {{0x924c0020,0xc2c4088c,0x44200158,0xdb1800e4}},	//   _እርምጃ, نيزي, _vuh_, yhuí, 
   {{0x4420020c,0xddd80327,0x00000000,0x00000000}},	// [181b0] _wuh_, _pruż, --, --, 
   {{0x442108b5,0xdb080066,0x60e44404,0x3eb80209}},	//   _tuh_, _dogè, нцез, _üsti_, 
   {{0x442108b6,0xd498023a,0x7e68036e,0x00000000}},	//   _uuh_, _зря_, _sqep, --, 
   {{0x3e6908b7,0xbf140345,0x11280166,0x983400df}},	//   tút_, نواب, _җюри_, גראף_, 
   {{0xdb08044e,0x6d4400b0,0x6fc0012d,0x13940108}},	//   _vogë, _ēkar, _शतरं, _сияю, 
   {{0x3e6908b8,0x7c200076,0x63ac0208,0x80d40073}},	//   rút_, _pulr, _hocn, _येथे, 
   {{0x394508b9,0x63ac08ad,0x7c2001a9,0x3e6801d3}},	//   vals_, _kocn, _qulr, sút_, 
   {{0xab900058,0x39442bab,0xc0e00092,0x00000000}},	//   للىغ, wals_, ናክል_, --, 
   {{0x63ac239b,0xdce000e2,0xa3b002a0,0x1cb908ba}},	//   _mocn, tenē, जॉय_, _کاذب_, 
   {{0x7c2108bb,0xdb0891f8,0x6d5c00db,0x63ac0051}},	//   _tulr, _jogé, òpat, _locn, 
   {{0x394508bc,0xdb180124,0x98a400ef,0x00000000}},	//   rals_, siuñ, _renē_, --, 
   {{0x394508bd,0xb908878d,0x63ac012d,0xdb084e01}},	//   sals_, _यश_, _nocn, _logé, 
   {{0xf98400b1,0x394508be,0x9f4c00f2,0xd90c00e5}},	//   _агло, pals_, gogé_, جیں_, 
   {{0xd1d4001f,0x8964009f,0x00000000,0x00000000}},	//   ሩበት_, _مُهن, --, --, 
   {{0xe5a108bf,0xaec4025c,0xc8b4872f,0x33f49a9a}},	//   шири, _ཀཿཐོ, _ملوک, вчас, 
   {{0x5eb4015b,0xfe204707,0xdec40b82,0x00000000}},	//   _আইনে, मदास_, ጽልን_, --, 
   {{0x63ac0cf4,0xf5e8023b,0x02c4004e,0x00000000}},	// [181c0] _docn, _омил_, гитү, --, 
   {{0xdb080129,0x200c0254,0xa1c070c1,0x1b1000cc}},	//   _cogé, emgi_, абуд, _সভাই_, 
   {{0xdb0908c0,0x21645e0c,0x602001c4,0x9f4c0139}},	//   _dogé, тихи_, адха, klgä_, 
   {{0xdfcc8b4d,0xb4ad08c1,0xa0640114,0x00000000}},	//   ييل_, कही_, ђача_, --, 
   {{0x6da508c2,0x4ad00490,0xb4d002ab,0xbf641fae}},	//   кида, _तेंव, _वधु_, ادمو, 
   {{0xde0013d6,0xac741e24,0x600000c7,0xa2c86c5a}},	//   апчи, ناعش, rõma, _सेट्, 
   {{0xa0a0187d,0xefb02c26,0x216508c3,0x9c400022}},	//   _кард, _پیشگ, _шири_, ахыл, 
   {{0xe454008f,0xdca00063,0x3eb00200,0x00000000}},	//   דיקט_, раћи, ëntë_, --, 
   {{0xdbdc05f7,0x63a801a8,0x7f740395,0x00000000}},	//   ríðs, ögni, _щурц, --, 
   {{0xb4d00574,0x2fc405c7,0xb0a4000d,0xdbdc03b2}},	//   _वधू_, lhog_, _गपाग, síðs, 
   {{0x2d9c10aa,0x7f280050,0xab6447f9,0xddd80306}},	//   _inte_, _آسہِ_, _авел, _usuš, 
   {{0xd84c0241,0x9f4c020c,0x9e700023,0x9cd4011a}},	//   _kọju_, togé_, _ኩላህና_, _בובה_, 
   {{0x63ac6875,0x2d9c00a3,0xb63108c4,0x4ca800cc}},	//   _rocn, _knte_, یکیش, _কেচু, 
   {{0x9f4cbda7,0x63ac0e04,0x7c2c02d2,0x00000000}},	//   rogé_, _socn, _óorð, --, 
   {{0x63ac0b91,0x18843d58,0xdb080120,0x9f4c0267}},	//   _pocn, _асып_, _rogé, llgå_, 
   {{0xa6d8041e,0x00000000,0x00000000,0x00000000}},	//   naðk, --, --, --, 
   {{0x2d9d08c5,0x2fc508c6,0x63ac1050,0x534401c6}},	// [181d0] _onte_, dhog_, _vocn, рхса, 
   {{0xa3ac012d,0x00000000,0x00000000,0x00000000}},	//   _कवक_, --, --, --, 
   {{0x63ad08c7,0x518508c8,0x00000000,0x00000000}},	//   _tocn, шута, --, --, 
   {{0x2d9d08c9,0x2fc41c06,0x9f500086,0x9eb0070e}},	//   _ante_, ghog_, ñeàn_, ишлә, 
   {{0xeaa468e7,0x00000000,0x00000000,0x00000000}},	//   _اٹ_, --, --, --, 
   {{0xf2d0025f,0x2d9c00eb,0x4d6400d4,0x1c180037}},	//   _פעם_, _cnte_, иків, _पूजल_, 
   {{0x9f6908ca,0x518401c6,0x290800d0,0x80d00154}},	//   _ораз_, _туяа, ýbal_, _তুর্, 
   {{0x2d9d08cb,0x3b84086f,0x2fc508cc,0x9e645285}},	//   _ente_, улиг, chog_, _لائن, 
   {{0x4a4439fb,0x8d74e0b6,0x00000000,0x00000000}},	//   амың, _چاما, --, --, 
   {{0xdcb8156b,0x8d740725,0xdfd00046,0xf9880b24}},	//   _още_, _ناما, _соғы, رنجي_, 
   {{0xf74508cd,0xf864005b,0x47040055,0xa6d802d2}},	//   лено, ывно, _tsṛṣ, baðk, 
   {{0xd6c410e5,0x37a00116,0x00000000,0x00000000}},	//   لمجی, сқиғ, --, --, 
   {{0x3f8c0b23,0xa6d805f7,0x097801c6,0x2d9c015d}},	//   _maeu_, naðh, хрөө_, _ynte_, 
   {{0x059801d9,0xc8b40133,0x00000000,0x00000000}},	//   نمُک_, الێک, --, --, 
   {{0x7398c851,0x04b458f0,0xb4ac000d,0x00000000}},	//   нтас_, астя, कहे_, --, 
   {{0x68f80a1e,0x00000000,0x00000000,0x00000000}},	//   _אלצה, --, --, --, 
   {{0x64400135,0x715908ce,0x1c1800c5,0xb8900092}},	// [181e0] _ħnie, ерес_, _पूछल_, _ቆርጠው_, 
   {{0xa6800139,0x00000000,0x00000000,0x00000000}},	//   _ульд, --, --, --, 
   {{0xdce002d5,0x3f8c0098,0x2fc40368,0xdb080205}},	//   menė, _baeu_, thog_, _algü, 
   {{0x798108cf,0x3f8d08d0,0x2d9c0407,0xd84c0241}},	//   helw, _caeu_, _snte_, _pọju_, 
   {{0x79804ec2,0xdef508d1,0x2fc40004,0xde70009f}},	//   kelw, лыш_, rhog_, مدوع, 
   {{0x79805b12,0xe0cc01d9,0x704400cf,0x2fc4022e}},	//   jelw, _کٲف_, _مئرك, shog_, 
   {{0x798108d2,0xdb0803e3,0xad6801c6,0xe104030d}},	//   delw, _elgü, _үабз_, _берд_, 
   {{0x3f8c0399,0x4a5508d3,0x7c680092,0x4bb400d1}},	//   _gaeu_, акис, _ደርሷል_, рйис, 
   {{0x79809692,0x7fd40220,0xa6d81427,0x246c0023}},	//   felw, _тірі, raðk, _ስፍሓት_, 
   {{0x798108d4,0xfd640521,0xdb080413,0x2d9c00d8}},	//   gelw, _metụ, _algó, _unte_, 
   {{0x6d4908d5,0xd91400c9,0x56940032,0x98a40064}},	//   mafa, лью_, ҙарт, _menė_, 
   {{0x6d4908d6,0xa6d81873,0xf8b400f7,0x999c0213}},	//   lafa, laði, рөш_, ppuş_, 
   {{0xa5b81de4,0x7bb00022,0xe664005b,0x00000000}},	//   mpóz, _фҩыу, ытно, --, 
   {{0x6d4908d7,0xa6d81ffb,0x798108d8,0xe5c400c9}},	//   nafa, naði, celw, усмо, 
   {{0xd5b85238,0x00000000,0x00000000,0x00000000}},	//   уся_, --, --, --, 
   {{0x6d481311,0x833508d9,0xa3cc1fb0,0x45340131}},	//   hafa, рнах, वों_, _ھىجر, 
   {{0x3f8c0399,0x69d8ce09,0x5b7800c8,0xa6d80321}},	// [181f0] _raeu_, oite, ערמא, kaði, 
   {{0x6d4908da,0x3f8c0421,0xa6d80d12,0x00000000}},	//   jafa, _saeu_, jaði, --, 
   {{0x6d489bbf,0xa6d8148b,0x1ee410e8,0x00000000}},	//   dafa, daði, گوشی_, --, 
   {{0x79806580,0x439508db,0x506400c0,0xd7a80073}},	//   zelw, _тамс, стфа, गायच, 
   {{0x3ea508dc,0x6d4908dd,0x798108de,0xbea508df}},	//   рилг, fafa, yelw, ралк, 
   {{0x65640007,0x7980004b,0xa6d80321,0x72a000cf}},	//   ngjh, xelw, gaði, _بەكن, 
   {{0x798108e0,0x3f8c0421,0x2b4405c7,0x1ec400d1}},	//   velw, _taeu_, _beoc_, _әһли_, 
   {{0x6d480770,0x798108e1,0x59a405f9,0xef9005d9}},	//   aafa, welw, _कचहर, _وڌند, 
   {{0x798108e2,0x2b4403bd,0x5ca00075,0x4fc455b6}},	//   telw, _deoc_, риқб, _усра, 
   {{0x2b44033b,0x6d4908e3,0x39442179,0x27d8063f}},	//   _eeoc_, cafa, шног, ụalụ_, 
   {{0x798108e4,0x0dc8cc8a,0xdb1800c7,0x2f180166}},	//   relw, _сути_, ikué, _tügü_, 
   {{0x798108e5,0xfcd41772,0x69d908e6,0xb6a401a9}},	//   selw, ራተጂ_, aite, қиҳл, 
   {{0x798108e7,0x7bc80142,0x60000254,0x4a4400d4}},	//   pelw, mheu, jõmm, _гнів, 
   {{0x7bc908e8,0x798108e9,0x69d908ea,0x656406ea}},	//   lheu, qelw, cite, ggjh, 
   {{0x201c0093,0x792c02d3,0xda08000d,0x00000000}},	//   _oiui_, _ተሓታት, _सीयत_, --, 
   {{0x7bc908eb,0x6d4908ec,0xdb08a0fb,0xdb180124}},	//   nheu, zafa, _logí, ekué, 
   {{0x6d4908ed,0x281000d1,0x7bc801f4,0xdce000c0}},	// [18200] yafa, _بويس, iheu, penė, 
   {{0x7bc80369,0x6d4908ee,0x490c012c,0xe29508ef}},	//   hheu, xafa, डेको_, шау_, 
   {{0x6d480433,0xa3ac02ab,0x25f00037,0x047801d5}},	//   vafa, _कवच_, ंकरी_, _یلیک_, 
   {{0x6d4908f0,0x201c003a,0xdb18035b,0xe690072d}},	//   wafa, _ciui_, akué, _الید, 
   {{0xe8e04b01,0x69d908f1,0xa6d81f60,0xeda40580}},	//   _पश्च, yite, taði, ишко, 
   {{0x69d908f2,0x2b4401c3,0x9df4109a,0x7bc800d8}},	//   xite, _seoc_, аніт_, eheu, 
   {{0x2bd80050,0x6d4908f3,0x4ab405f5,0xa6d809f3}},	//   _बगदा, rafa, өөдр, raði, 
   {{0x6d4908f4,0x69d908f5,0xa0340375,0xd9e000fe}},	//   safa, wite, _כאלה_, _নীলম, 
   {{0x6d4908f6,0xada40228,0xf1b800cd,0x00000000}},	//   pafa, _каал, _इवान, --, 
   {{0x7bc908f7,0x6d4908f8,0x69d908f9,0x7d040112}},	//   aheu, qafa, uite, ühsc, 
   {{0x19a43fc2,0x8d74004b,0x7bc908fa,0x1ca40133}},	//   ртып_, _ناڅا, bheu, _نێوی_, 
   {{0x9a640066,0x00000000,0x00000000,0x00000000}},	//   دمیل_, --, --, --, 
   {{0xfd5000e4,0xd80801c0,0x25f00073,0x2af4005b}},	//   _rokẽ, рхэл_, ंकली_, _тяжё, 
   {{0x69d908fb,0xa8a416ac,0x5ac80244,0x00000000}},	//   qite, _نصبو, _جامێ_, --, 
   {{0x58d108fc,0x61f4022e,0x00000000,0x00000000}},	//   _мошт, voxl, --, --, 
   {{0x57a40022,0xfba80b98,0x60000037,0xd3a4072c}},	//   _дшьа, कायम, tõmm, оруп, 
   {{0xc2987cf4,0xadf41d8a,0x4154013e,0x201c003a}},	// [18210] ыках_, इवान_, йвас, _riui_, 
   {{0x7bc80165,0x00000000,0x00000000,0x00000000}},	//   zheu, --, --, --, 
   {{0x61f400e8,0xdb180022,0x814400db,0x60940092}},	//   roxl, rkué, _ۇچان, _መዋጋት_, 
   {{0xdb0800d8,0x7498010f,0x3f140139,0x00000000}},	//   _jogã, _עירפ, бдес, --, 
   {{0x3d180073,0x00000000,0x00000000,0x00000000}},	//   येने_, --, --, --, 
   {{0x62800034,0x7bc800b0,0x7cfc02d2,0x00000000}},	//   łnos, wheu, _nærþ, --, 
   {{0x7bc908fd,0x8d7508fe,0xa6d81c38,0x1fa40640}},	//   theu, تانا, maðu, _краг, 
   {{0x201d08ff,0xa6d80ad9,0x7bc90900,0x2c0800cd}},	//   _uiui_, laðu, uheu, _हीदं_, 
   {{0x7bc80d47,0x8b6400be,0x00000000,0x00000000}},	//   rheu, زايم, --, --, 
   {{0xa6d805a4,0x7bc801f5,0x9f4c00d8,0xf2d0011a}},	//   naðu, sheu, bogã_, פעי_, 
   {{0x7f48011f,0x62980024,0x00000000,0x00000000}},	//   _keeq, _šuol, --, --, 
   {{0x7f48198f,0x5fc41df1,0x3f7800df,0x00000000}},	//   _jeeq, लसिल, נאָס, --, 
   {{0x34b01fb2,0x7f490901,0x7bd800ca,0x7d010902}},	//   ीन्द, _meeq, _imwu, _hyls, 
   {{0x7f480ba7,0x7d010903,0xa6d80bcd,0x00000000}},	//   _leeq, _kyls, jaðu, --, 
   {{0xdb0806ed,0xf6240107,0xa6d81d1d,0xdce000de}},	//   _fogã, рдҳо, daðu, denī, 
   {{0xd1f0001f,0x7d0002d2,0xf9600244,0x00000000}},	//   ግዛት_, _myls, _بۆگێ, --, 
   {{0xb05403e6,0xa6d808a5,0x00000000,0x00000000}},	// [18220] ڵپشت, faðu, --, --, 
   {{0xa6800a89,0xa6d8041e,0x9f4c0100,0x61b407d0}},	//   _эльд, gaðu, yogã_, _आकृष, 
   {{0x7bd8002d,0x7d000af9,0x021802bf,0x61e8003e}},	//   _omwu, _nyls, ріть_, égla, 
   {{0xa85400d9,0x00000000,0x00000000,0x00000000}},	//   מיעה_, --, --, --, 
   {{0x7f480050,0xdee00276,0xdce00171,0x00000000}},	//   _deeq, поци, benī, --, 
   {{0x7bd90904,0x7d00000f,0x28c800cd,0xdce000ef}},	//   _amwu, _byls, ानमि, cenī, 
   {{0x80c40150,0x30d400cc,0x00000000,0x00000000}},	//   _وڭمە, _তুৰস, --, --, 
   {{0x9528031c,0x66cc01e1,0x7d010905,0xe0d401c6}},	//   _ཡུའི_, _jòké, _dyls, _увс_, 
   {{0x15f8230e,0x2ca802dd,0x3e88008e,0xaec40cab}},	//   ंकार_, _әкеп_, _китү_, _убал, 
   {{0x26c40374,0x5d1001d9,0x5ce000db,0x00000000}},	//   _āno_, _کِما, تكۉل, --, 
   {{0xdca10906,0x7f480810,0x48b80eac,0x1828069d}},	//   _нафи, _yeeq, ুপ্র, _ተቃውሞ, 
   {{0xab290907,0x29010908,0x00000000,0x00000000}},	//   _сода_, āka_, --, --, 
   {{0x7d00002d,0x1bf8010f,0x00000000,0x00000000}},	//   _zyls, _גלאב, --, --, 
   {{0xe6a40209,0x7e7c007c,0x00000000,0x00000000}},	//   _güýç, _äspe, --, --, 
   {{0xbebc02b5,0xa6d8041e,0xdce0005f,0x47d427b4}},	//   _ngūn, vaðu, venī, _ويتر, 
   {{0xdc34008f,0x00000000,0x00000000,0x00000000}},	//   מאלט_, --, --, --, 
   {{0xa6d81f60,0x45d4cffb,0xdce000e2,0x81b400d4}},	// [18230] taðu, _моис, tenī, обає, 
   {{0x7f48013c,0xe4e40826,0xdb0801ed,0x7afce523}},	//   _seeq, _гімн, _jogá, üsti, 
   {{0x7f48013c,0xa6d80436,0x28dc1cd2,0xdbdc0248}},	//   _peeq, raðu, _फेमि, bíès, 
   {{0xdb080491,0x6d5d0909,0x7f49090a,0x3330a104}},	//   _logá, ópan, _qeeq, ccyx_, 
   {{0x7d01090b,0xa6d805f7,0xa2240066,0x00000000}},	//   _syls, paðu, _درجه, --, 
   {{0x6da1090c,0x628d090d,0x7f480548,0x1474035c}},	//   диша, _isco, _weeq, _بایج, 
   {{0x0dc80114,0x00000000,0x00000000,0x00000000}},	//   ључи_, --, --, --, 
   {{0xdb080332,0xbc180150,0x00000000,0x00000000}},	//   _aogá, шілі_, --, --, 
   {{0x7d000a85,0xe3bc00e8,0x628c0175,0xdb080f47}},	//   _wyls, _giñe_, _jsco, _bogá, 
   {{0x7d00023a,0xdb18017a,0xf984009d,0x00000000}},	//   _tyls, skuï, цгоо, --, 
   {{0x291802f0,0x00000000,0x00000000,0x00000000}},	//   _úpal_, --, --, --, 
   {{0x7bd80516,0x628ca2e5,0xdd2c0118,0x00000000}},	//   _umwu, _osco, něži, --, 
   {{0xdb09090e,0xe7d000cf,0x00000000,0x00000000}},	//   _fogá, بۅيگ, --, --, 
   {{0x992877c6,0xa96400a7,0x3d1800cd,0x9b4002f2}},	//   _сюда_, _диша_, येथे_, _بۆکو, 
   {{0x39140345,0x00000000,0x00000000,0x00000000}},	//   _بوغز, --, --, --, 
   {{0x9c10063f,0x628c02f0,0x27f40f47,0x00000000}},	//   kọmu, _bsco, _وفود_, --, 
   {{0xe294020a,0x3d1800dc,0x00000000,0x00000000}},	// [18240] оат_, येते_, --, --, 
   {{0xdb080005,0x883c0092,0xd9a4000d,0xd7a80073}},	//   _xogá, _የተቀደ, _कचोट, गावच, 
   {{0x3084bbcc,0x628c6a3a,0xe3bd090f,0x2bd807f7}},	//   تلاف, _esco, _siñe_, _बगला, 
   {{0xaf040b2c,0xf2a40276,0x4c940107,0x7ac84982}},	//   опел, _димп, ҷикс, िनाअ, 
   {{0xe4d4182f,0x9fa008a5,0x00000000,0x00000000}},	//   _هویت_, _víðs_, --, --, 
   {{0xe2940120,0x00000000,0x00000000,0x00000000}},	//   _ќар_, --, --, --, 
   {{0xabb000d1,0x00000000,0x00000000,0x00000000}},	//   дайә, --, --, --, 
   {{0xe3bd0910,0x60c03bb4,0xed580066,0x00000000}},	//   _tiñe_, ønme, _چشات_, --, 
   {{0xe924025c,0x628c0036,0x6d58007b,0x42700023}},	//   _རྔུབ_, _xsco, _نجاح_, _ድርኺት_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb4c1c3e,0x7d0c03f9,0x28a400d4,0x00000000}},	//   _ою_, ƙasa, ішог, --, 
   {{0x61b40d41,0xdb08000d,0xa6d802d2,0x00000000}},	//   _आक्ष, _algõ, daðr, --, 
   {{0x1dd40073,0xdb080332,0x00000000,0x00000000}},	//   भोवत, _togá, --, --, 
   {{0x99d0007b,0xa6d8032e,0x899401af,0x00000000}},	//   _يتوا, faðr, _хикє, --, 
   {{0xd4980daf,0x291801e1,0xa6d808a5,0x00000000}},	//   орт_, _àpa_, gaðr, --, 
   {{0x5c5800df,0x00000000,0x00000000,0x00000000}},	//   ידלק, --, --, --, 
   {{0xa6d80008,0x24940024,0x6d590911,0x27e80175}},	// [18250] raðs, _žemė_, _odta, mncn_, 
   {{0x6b28031c,0x45d401c0,0xc6d4004b,0x9268519b}},	//   _ཤུའོ_, _хоос, _وتښت, юрса_, 
   {{0x961831ed,0xdd2c0118,0xe73c0254,0x00000000}},	//   _بغير_, těži, sjõu_, --, 
   {{0x6d590912,0xb6300133,0xb4f8011a,0x78a408a5}},	//   _adta, _تکێش, _לפתי, _áhve, 
   {{0x628d0913,0xfba82432,0x00000000,0x00000000}},	//   _usco, कासम, --, --, 
   {{0xd0101e87,0xb2b80375,0x61b000d1,0x7d04002f}},	//   ىلە_, _המשר, _تەئا, ühso, 
   {{0x3ea80276,0x23bc1a47,0x6d589b60,0x00000000}},	//   ţat_, _एकाद, _ddta, --, 
   {{0x6d58035a,0x00000000,0x00000000,0x00000000}},	//   _edta, --, --, --, 
   {{0x12240014,0xdce43535,0xefb001b9,0x80d00011}},	//   _رٹہَ, ğlıl, _سیوگ, _তুচ্, 
   {{0xdce41b07,0x2ee401d9,0x4ea401d5,0x00000000}},	//   şlıl, _عقلہ, _юрса, --, 
   {{0xdb080109,0x06d802f5,0x8d750914,0x68a40023}},	//   _algô, _ধুলি, _تاقا, _ፈተውቲ_, 
   {{0x69c90915,0xe29c05a4,0x00000000,0x00000000}},	//   _elfe, _orð_, --, --, 
   {{0xfaa457e2,0xdb0802d2,0xe9cd0916,0x00000000}},	//   _хало, _sogæ, _зк_, --, 
   {{0x7afc03fa,0x3c3002f0,0xd1d40092,0x00000000}},	//   üstu, _káv_, ዩበት_, --, 
   {{0x64a10917,0xe29c032e,0xd5880133,0x00000000}},	//   нара, _arð_, مێکه_, --, 
   {{0xe8d40375,0x3c302bb4,0x00000000,0x00000000}},	//   _מוצר_, _máv_, --, --, 
   {{0x27340016,0x00000000,0x00000000,0x00000000}},	// [18260] _ủng_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdfcc3fff,0xef8497d0,0x00000000,0x00000000}},	//   گين_, злеп, --, --, 
   {{0xfaf80024,0x2ca001ef,0x00000000,0x00000000}},	//   ngūs_, _čkd_, --, --, 
   {{0xdfcd0918,0xdb0800a2,0xfaf80064,0xfe74009d}},	//   دين_, _jogä, igūs_, мүт_, 
   {{0xdd8c1b45,0x00000000,0x00000000,0x00000000}},	//   ُون_, --, --, --, 
   {{0xd7cc0574,0x4c940801,0xe0d400f0,0xa0646c9c}},	//   ासाच, фийс, _евр_, _нара_, 
   {{0xa1102a8b,0x28c82d81,0x68240022,0x00000000}},	//   _سوقت, ानसि, ҟьоз, --, 
   {{0x6e44168d,0x321806d9,0xed580209,0x1d20010b}},	//   _رنام, ompy_, _гоз_, ммәм, 
   {{0xe3bd0919,0x6d5804ce,0x1e5408c3,0x00000000}},	//   _miña_, _udta, _משמר_, --, 
   {{0xe3bc0f71,0xd7a80490,0xfba80303,0xd5b00b02}},	//   _liña_, गांच, काशम, ञानज, 
   {{0x7aec00bc,0x00000000,0x00000000,0x00000000}},	//   _žate, --, --, --, 
   {{0xe3bc015b,0xfba80b33,0x7b640014,0xe29c0162}},	//   _niña_, कारम, _زانٕ, _oyða_, 
   {{0x69c8022f,0x00000000,0x00000000,0x00000000}},	//   _ulfe, --, --, --, 
   {{0x1514b190,0x00000000,0x00000000,0x00000000}},	//   едря, --, --, --, 
   {{0xe3b02e0b,0x00000000,0x00000000,0x00000000}},	//   ررز_, --, --, --, 
   {{0xc1b9091a,0x28c811bc,0x00000000,0x00000000}},	// [18270] олах_, ानवि, --, --, 
   {{0x29000213,0x00e4158b,0x8188009a,0x00000000}},	//   əkar_, وتای, تنطق_, --, 
   {{0xd1640c60,0xdb180022,0x00000000,0x00000000}},	//   эъти, ikuá, --, --, 
   {{0xe29c0008,0xded4001f,0x2fc4003e,0x00000000}},	//   _eyða_, _ይጫኑ_, gkog_, --, 
   {{0xf8a85e8d,0x28dc07f7,0xe29c0413,0x8fc400db}},	//   _छप्प, _फेसि, _urð_, رۅكۇ, 
   {{0xdb0439b2,0x3c300cde,0x61400e56,0xe29c08a5}},	//   _éléc, _páv_, _سىرە, _gyða_, 
   {{0xfba818cc,0x7c2c0115,0x00000000,0x00000000}},	//   कालम, ĉaro, --, --, 
   {{0x2fc40b91,0x7aa40261,0x98a40064,0x3b8401a9}},	//   ckog_, дииз, _senį_, флиг, 
   {{0x0e4400ee,0x98a400c0,0x41c000cd,0x00000000}},	//   _зэхм, _penį_, _एवास, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8d741066,0x378862bd,0xbabc0c58,0xdb08014a}},	//   _سالا, обно_, ইছেঞ, _sogä, 
   {{0xdb1800e4,0xe7340024,0x8f0001ec,0x00000000}},	//   akuá, мею_, нiш_, --, 
   {{0xa3c01152,0xfaf80024,0xb6f8215c,0x00000000}},	//   ्सन_, rgūs_, زىسا_, --, 
   {{0xe3bc0407,0xa6d803b2,0x00000000,0x00000000}},	//   _riña_, raðp, --, --, 
   {{0x9f5c0022,0xe3bc008e,0xc8c401f9,0x00000000}},	//   _ekué_, _siña_, _लॅपट, --, 
   {{0xe3bd091b,0xf77000c6,0xb6680022,0x88c400cf}},	//   _piña_, _شاب_, _дииз_, _ستىل, 
   {{0x13a81c3b,0x7e780175,0xf48c0023,0xb2242e80}},	// [18280] _ہندی_, jtwp, _ብፍላጥ_, дмал, 
   {{0xe3bc26ce,0x216401f0,0x00000000,0x00000000}},	//   _viña_, дифи_, --, --, 
   {{0x2fc41b24,0xe3bc0309,0x234400d1,0xc0580006}},	//   tkog_, _wiña_, سلەپ_, зіі_, 
   {{0xe3bc0f71,0xee84c45c,0xd2500133,0x347c0240}},	//   _tiña_, дыко, _مۆر_, _ሕልናኻ_, 
   {{0x2fc4110c,0x3f800150,0x00000000,0x00000000}},	//   rkog_, ығта, --, --, 
   {{0x2fc40552,0x6ca42e36,0x28dc000d,0x00000000}},	//   skog_, дриж, _फइलि, --, 
   {{0xe1200364,0xfba80073,0x67380113,0x3d180dba}},	//   _амри, कांम, ñujk, येले_, 
   {{0x3ea80118,0x6aa40fac,0x00000000,0x00000000}},	//   ťata_, åkfo, --, --, 
   {{0x29890029,0xec34037e,0x5f0001c6,0x00000000}},	//   осно_, sタ_, _азта, --, 
   {{0x2d880332,0x2b1800cd,0x7aec013a,0x00000000}},	//   _úbe_, मेषु_, _žatc, --, 
   {{0xa3c06956,0x00000000,0x00000000,0x00000000}},	//   ्सम_, --, --, --, 
   {{0xddd81ebd,0x3cf002fb,0x20540a7c,0x00000000}},	//   _ipuš, ťový_, ויטל_, --, 
   {{0x6b8067c5,0x2004054e,0x28dc00bc,0x00000000}},	//   _ibog, înii_, _फेरि, --, 
   {{0xae0c01d9,0xe8e800ec,0x270c0b26,0x00000000}},	//   ितिन_, _ورثو_, _सरीर_, --, 
   {{0x7bd400e4,0xc95801a9,0xbdd800df,0x00000000}},	//   _õguá, _дўқ_, פֿשט, --, 
   {{0xe7840212,0xe8c80073,0x78a4032e,0x588000c0}},	//   _цуко, ानीच, _áhva, _рыша, 
   {{0x6b81091c,0x00000000,0x00000000,0x00000000}},	// [18290] _mbog, --, --, --, 
   {{0x91e40640,0x00000000,0x00000000,0x00000000}},	//   вође, --, --, --, 
   {{0x96b8036b,0xb5f00220,0x00000000,0x00000000}},	//   _فایز_, _сүрі, --, --, 
   {{0x6b804230,0x47c00154,0x3518011a,0x00000000}},	//   _nbog, শোরী, _מותנ, --, 
   {{0x733800c8,0x53a400c0,0x00000000,0x00000000}},	//   _מערס, _раўб, --, --, 
   {{0x6b81091d,0x7c9485c0,0x00000000,0x00000000}},	//   _abog, ериц, --, --, 
   {{0x6aa1091e,0x28dc134e,0x00000000,0x00000000}},	//   _arof, _फेलि, --, --, 
   {{0x6aa1091f,0xe3bc172e,0x6b8001ab,0x5ba00116}},	//   _brof, _miño_, _cbog, тлиғ, 
   {{0xba250920,0x6aa10921,0xe3bc056a,0x6b800175}},	//   ндик, _crof, _liño_, _dbog, 
   {{0x6aa10922,0x8e1400c7,0xe9d4084c,0x6b807eb6}},	//   _drof, _адуц, екь_, _ebog, 
   {{0xe3bc7ce5,0x5eb400bd,0x6aa00a40,0x23bc0490}},	//   _niño_, _আইটে, _erof, _एकंद, 
   {{0x6b804e53,0x6aa03012,0x00000000,0x00000000}},	//   _gbog, _frof, --, --, 
   {{0x6aa10923,0x7bc80438,0xd90c00dd,0x64a10924}},	//   _grof, mkeu, دیں_, қата, 
   {{0x7bc90925,0x6b8005ce,0xe3bc005a,0xf504014b}},	//   lkeu, _zbog, _biño_, езго, 
   {{0x49b800aa,0x93c800e5,0x6d5c01e7,0x00000000}},	//   _تاند_, وارہ_, ópai, --, 
   {{0x7bc81dd4,0xe3bc01c4,0x3774b590,0x00000000}},	//   nkeu, _diño_, _чыкс, --, 
   {{0x7bc802f6,0x57cc00bc,0xa06400c7,0xf1d001c4}},	// [182a0] ikeu, ासीह, ҵаха_, гөвө, 
   {{0x7bc81dd4,0xf748004b,0x72040472,0x00000000}},	//   hkeu, _بلکي_, روام, --, 
   {{0x7bc90926,0xa0280003,0xe5740276,0xdfcc0451}},	//   kkeu, _སྤྱང_, _язэ_, ڍيل_, 
   {{0xef180b8d,0x7bc80d27,0x9f5c004d,0xd31401ec}},	//   пме_, jkeu, _thuý_, _аягө, 
   {{0x7bc90927,0xddd90928,0x0ca81100,0xce940395}},	//   dkeu, _spuš, कम्म, талъ, 
   {{0x2fd80272,0xdb080248,0x470400b8,0x8c3c27ac}},	//   _کورد_, _fogú, _apṛṣ, _arğa, 
   {{0xac243afa,0xa0a00131,0x7bc90929,0x8c18007b}},	//   нфик, _йард, fkeu, ويتر_, 
   {{0x6aa00a85,0xa0280003,0x7bc83386,0xdb080798}},	//   _prof, _སྤྲང_, gkeu, _ingê, 
   {{0x6b8004fb,0xba3c01ef,0x00000000,0x00000000}},	//   _vbog, jvůd, --, --, 
   {{0x67e8023a,0x7bc8003e,0xfa300022,0xf98000c7}},	//   köjä, akeu, шҭшь, ҳҳәо, 
   {{0x7bc83386,0xddd8041a,0x00000000,0x00000000}},	//   bkeu, _upuš, --, --, 
   {{0x6b8065d2,0x2d8d092a,0x7bc806af,0xdb080241}},	//   _ubog, lefe_, ckeu, _logù, 
   {{0x62800210,0x00000000,0x00000000,0x00000000}},	//   łnoz, --, --, --, 
   {{0x2d8d092b,0x5b102626,0x00000000,0x00000000}},	//   nefe_, _сміт, --, --, 
   {{0x6b7406be,0x00000000,0x00000000,0x00000000}},	//   cəgö, --, --, --, 
   {{0xe3bc172e,0xd90c0101,0x00000000,0x00000000}},	//   _viño_, _دیپ_, --, --, 
   {{0xe1640640,0xd24401c6,0x2164011c,0xe8140037}},	// [182b0] еђен, гэхи, етег, _धीया_, 
   {{0x2d8c0789,0xdb040129,0xdb080241,0x00000000}},	//   jefe_, éléo, _pogú, --, 
   {{0x7bc80438,0x2d8c03e0,0x06880150,0xd5640024}},	//   ykeu, defe_, _ﺑﻴﻠﯩ, _стып, 
   {{0xfe700035,0xe8140456,0x8f740150,0x00000000}},	//   لدت_, _धीमा_, гуші, --, 
   {{0x2d8d092c,0x975c010f,0x6fb00244,0x80ac000d}},	//   fefe_, לדאט, شموا, _टपकइ, 
   {{0x7bc80196,0xe3bc0139,0x50640075,0x470400cd}},	//   wkeu, _hoñ_, _әтра, _spṛṣ, 
   {{0x7bc81dd4,0xe3bc00e8,0xc104009f,0x5ca000db}},	//   tkeu, _koñ_, _شوري, البە, 
   {{0xe3bc002e,0x7bc800d5,0xa3c00b98,0xc94401ec}},	//   _joñ_, ukeu, ्सि_, ңдық, 
   {{0x7bc9092d,0xe3bc008e,0xceac00fb,0x00000000}},	//   rkeu, _moñ_, _уҙ_, --, 
   {{0x7bc81dd4,0x2d8c0117,0xd68401e4,0xda0800af}},	//   skeu, cefe_, _ofiϲ, _सीखत_, 
   {{0x7bc81dd4,0xa3c035e0,0xdca4010b,0xf86402e8}},	//   pkeu, ्सा_, _яшап, ъвно, 
   {{0xf771092e,0xe3bc030a,0xc8b4036b,0x00000000}},	//   جاد_, _noñ_, چلیک, --, 
   {{0xc8b4036b,0x2f58011a,0x2bd800f2,0x00000000}},	//   نلیک, ודרנ, _تالک_, --, 
   {{0xc5f44d50,0x67e8023a,0x78a402d2,0xdce00166}},	//   лғы_, töjä, _áhvo, ldnı, 
   {{0xa504024d,0xe3bc030a,0x73983769,0xdb0801c7}},	//   вера_, _boñ_, мтас_, _ongë, 
   {{0x2d8c0085,0xdb080158,0x437401c6,0x79800142}},	//   zefe_, _bogø, луут, lflw, 
   {{0xe3bc0165,0x27b000fd,0x2d8c02e3,0x12b00011}},	// [182c0] _doñ_, _тәэс, yefe_, ছন্দ, 
   {{0xd76800db,0xf62800ae,0x00000000,0x00000000}},	//   _تەڭى_, _تسعى_, --, --, 
   {{0x27f45a0a,0x92b40154,0xcdc40116,0x00000000}},	//   _سفید_, ড়ছে_, һадқ, --, 
   {{0x6e440006,0x00000000,0x00000000,0x00000000}},	//   ведз, --, --, --, 
   {{0xdb180054,0x2d8d092f,0xdef40209,0xcdc400d1}},	//   khuñ, tefe_, кыш_, ладқ, 
   {{0x61410930,0xdb08004e,0x00000000,0x00000000}},	//   _вера, _ingè, --, --, 
   {{0x2d8d0931,0x84840023,0x61e8007f,0x00000000}},	//   refe_, _ምውሳን_, ègle, --, 
   {{0x2d8d0932,0x60c10933,0x2b9001d5,0xea6802dd}},	//   sefe_, änme, شیتس, _ﺳﻪﺭﯞ, 
   {{0xde7400dd,0xe8c813f7,0xaf040022,0x79800142}},	//   _لینڈ_, ान्च, _рпал, fflw, 
   {{0x2e241537,0x683c005f,0x6da400d1,0x6cc4030d}},	//   _شفاف, _līde, _шиза, _ийза, 
   {{0x4ce000bd,0xc7b02674,0xad24a9f1,0xe57000e5}},	//   _পুরু, مّد_, _شرطو, یطس_, 
   {{0x9f5c0022,0x683c00e2,0xeb0401f0,0x00000000}},	//   _ikuã_, _nīde, _ичло, --, 
   {{0x2900068f,0xe66402e8,0x9f4c005c,0xdb18002b}},	//   łka_, ътно, rogø_, bhuñ, 
   {{0x28a40323,0xe3bd0934,0xdb180113,0xa8a401a9}},	//   _ашиг, _soñ_, chuñ, _арик, 
   {{0xdb080214,0xe3bc1bce,0x683c00ef,0x3f9c0210}},	//   _angè, _poñ_, _bīde, ydwu_, 
   {{0xe3b10935,0xd8700345,0x00000000,0x00000000}},	//   جرس_, _ئاوب, --, --, 
   {{0xd7745f8e,0xf1ac0490,0xa5600014,0xb6c000cf}},	// [182d0] _ضايع, घांन, _پۯزن, _лөрд, 
   {{0x51f811ed,0x24880023,0x00000000,0x00000000}},	//   вную_, _ሕፍረት_, --, --, 
   {{0xdb08067c,0x52250936,0x00000000,0x00000000}},	//   _engè, рфта, --, --, 
   {{0x3fe02baf,0x64450937,0x00000000,0x00000000}},	//   যক্ষ, mpji, --, --, 
   {{0x79800368,0x1ee47cda,0x00000000,0x00000000}},	//   yflw, خوشی_, --, --, 
   {{0xa3c005ba,0xc2e800cc,0x00000000,0x00000000}},	//   ्सव_, _কঁপি_, --, --, 
   {{0xdb090938,0x00000000,0x00000000,0x00000000}},	//   _ingé, --, --, --, 
   {{0x0fe41b16,0xab900131,0x00000000,0x00000000}},	//   _көчү, ملىغ, --, --, 
   {{0xdb10063f,0xce94305d,0x7f58014f,0x2de801e2}},	//   _ọ́nụ, _катъ, mawq, _ګولۍ_, 
   {{0x78a0003a,0xe4980257,0x00000000,0x00000000}},	//   tvlv, ፎርንያ_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf0900a7c,0x00000000,0x00000000,0x00000000}},	//   זנט_, --, --, --, 
   {{0xeaac67fd,0x27a002dd,0xaa8401d5,0x683c0171}},	//   _уй_, сқың, _یچیم_, _rīde, 
   {{0xdb180227,0xfb00003e,0x7f5802d1,0xb9080154}},	//   qhuñ, _chūō_, hawq, _মড_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb090939,0x7f580455,0x67380113,0x00000000}},	//   _angé, jawq, ñujt, --, 
   {{0xaa34008f,0xb6a40354,0x00000000,0x00000000}},	// [182e0] ָטעק_, _сипл, --, --, 
   {{0x63ac0334,0x00000000,0x00000000,0x00000000}},	//   _encn, --, --, --, 
   {{0x73e400c0,0xd3e400f2,0x00000000,0x00000000}},	//   _бонз, _نقدی, --, --, 
   {{0xb4c006e3,0x200c07c5,0x42900023,0xe04001b9}},	//   ्नी_, glgi_, _ምርኩስ_, ёнчи, 
   {{0xa3c009fd,0xda100490,0x00000000,0x00000000}},	//   ्सर_, डतात_, --, --, 
   {{0x2700001e,0x00000000,0x00000000,0x00000000}},	//   ổng_, --, --, --, 
   {{0x6d1c0073,0x00000000,0x00000000,0x00000000}},	//   येंग_, --, --, --, 
   {{0xaf94022a,0x998c01ef,0x15400055,0x00000000}},	//   ážďa, _bugů_, _vāṭī, --, 
   {{0xb4c0038e,0x6d5c172e,0x9b200166,0xeb040108}},	//   ्नु_, ópas, йфьл, ычко, 
   {{0x6d450506,0x00000000,0x00000000,0x00000000}},	//   _şkaf, --, --, --, 
   {{0x2d9c03c1,0x7d040730,0xab84ce59,0x62800356}},	//   _iate_, ühst, _булк, ănoi, 
   {{0xfe70021a,0x2d9c0c30,0xd91400ee,0xa8000139}},	//   _ددې_, _hate_, ыьы_, _ğısm, 
   {{0x2d9d093a,0x06340798,0x00000000,0x00000000}},	//   _kate_, регџ, --, --, 
   {{0x2d9c0022,0x9f4c020c,0xb4c02e05,0x5a98011a}},	//   _jate_, rngé_, ्नू_, _נשוא, 
   {{0x2d9d093b,0x94d5093c,0xa3c006e3,0x195400d9}},	//   _mate_, борц, ्सल_, _גבול_, 
   {{0xd379093d,0x2d9c74da,0x00000000,0x00000000}},	//   лчу_, _late_, --, --, 
   {{0x4155093e,0xdce0025c,0xccf801ef,0x00000000}},	// [182f0] ивас, penħ, _sděl_, --, 
   {{0x2d9d093f,0x7e7c01b8,0xe3bc002e,0x00000000}},	//   _nate_, _äspi, _miñi_, --, 
   {{0xa0a429e7,0xb0b8031c,0x7f580309,0x660401e4}},	//   ышал, བྱཅེ, tawq, mojk, 
   {{0x2d9d0940,0x6604009b,0x27e80198,0x63ac02d0}},	//   _aate_, lojk, nicn_, _uncn, 
   {{0x2d9d0941,0xd2450942,0xdb0800a2,0xe29c0162}},	//   _bate_, _гэси, _bogý, _oyði_, 
   {{0xd658025f,0x2d9d0943,0xd5e4063f,0x0d8402dd}},	//   ניות_, _cate_, _ipị, йлін, 
   {{0x2f3c01f2,0xdb08010e,0x7f580455,0x00000000}},	//   _ịge_, _dogý, pawq, --, 
   {{0x3ff800c8,0xf98800b2,0x2d9c04ba,0x9e642b9f}},	//   _ספּע, ھنجي_, _eate_, _مائن, 
   {{0x66040309,0xc0e40209,0x2d9d0944,0xe29c02d2}},	//   kojk, _соңк, _fate_, _byði_, 
   {{0xdfd00220,0xe9a41473,0x2d9c2517,0xe1e401ec}},	//   _тоғы, لگىن_, _gate_, ктiк_, 
   {{0x2900825f,0x7c943346,0x66042625,0xb7c000d8}},	//   şkan_, _خلاص, dojk, çãoe, 
   {{0x2d9c09a8,0xb8ec19cc,0xe29c08a5,0x00000000}},	//   _zate_, _रथ_, _eyði_, --, 
   {{0x2d9d0945,0x9f4c0789,0xe9cd0946,0xdb2033ae}},	//   _yate_, logó_, _дк_, _اوشی, 
   {{0x96d40022,0xeaac00e5,0x00000000,0x00000000}},	//   асҳә, _آٹو_, --, --, 
   {{0xb4c073c6,0xd5e4063f,0x7d0c03f9,0x290c0142}},	//   ्ने_, _apị, ƙasu, _gyfa_, 
   {{0x26c8003a,0x290c00d0,0xa87800df,0x00000000}},	//   byco_, íjať_, _סאפר, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [18300] --, --, --, --, 
   {{0x673800d0,0x683c00cd,0x347401af,0x00000000}},	//   ľuje, _hīda, _кѳмѳ, --, 
   {{0x67383831,0x2d9c0302,0xa6c804c5,0x61e80ba1}},	//   žuje, _rate_, _লেপট, ègla, 
   {{0x60c0005b,0xa0647180,0xe04000d4,0x00000000}},	//   änma, раца_, інчи, --, 
   {{0x92e400fe,0x9f9400c7,0x00000000,0x00000000}},	//   _পুৰ_, рыхә, --, --, 
   {{0x5ea00075,0x9f4c01d3,0xdb090947,0x683c00de}},	//   زمىل, fogó_, _logó, _līda, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2d9d0948,0x9cc429db,0x5bc00725,0x8cc80210}},	//   _wate_, рыша_, ققىل, ़हबो, 
   {{0x2d9d0949,0x49a457aa,0x8eb4a67e,0x66040309}},	//   _tate_, бынғ, _دەشت, yojk, 
   {{0x2d9c0093,0x644007ea,0xa9c4c43c,0x9f4c01d3}},	//   _uate_, _énig, рсик, bogó_, 
   {{0x66040bb8,0xb4c1094a,0xdb080210,0xde340023}},	//   vojk, ्नो_, _bogó, _እተዳለ, 
   {{0xb4c00316,0x00000000,0x00000000,0x00000000}},	//   ्नै_, --, --, --, 
   {{0xbc244c2d,0x683c0055,0x7bb000c7,0xe5c4551b}},	//   _ارلى, _dīda, _хҩыу, асво, 
   {{0x129402d3,0xe97015bf,0x00000000,0x00000000}},	//   _ምርካብ_, _بۇدد, --, --, 
   {{0x6605094b,0x5558117e,0xdb08ec23,0x00000000}},	//   rojk, рася_, _fogó, --, 
   {{0x53340046,0x83340801,0x3ea80419,0x00000000}},	//   жетт, снах, ťati_, --, 
   {{0x660478fe,0x925801b9,0x248c0023,0xd7fc011a}},	// [18310] pojk, لشلر_, _ምፍራስ_, _שהחל, 
   {{0xa0a407d8,0x683c005f,0x66040113,0x7dd00174}},	//   ишел, _zīda, qojk, iðsæ, 
   {{0xd1380c04,0x43940d06,0x69d8005b,0xbd440c50}},	//   рху_, _ланс, ihte, ەپتى, 
   {{0xdb080ba1,0x00000000,0x00000000,0x00000000}},	//   _mogò, --, --, --, 
   {{0xbea487b7,0x249ca33e,0x3ea46bce,0x00000000}},	//   салк, āumu_, силг, --, 
   {{0x8e0802bf,0xed5481b9,0x69d8003e,0x7f840066}},	//   анів_, бош_, jhte, _گلرن, 
   {{0x69d81554,0x00000000,0x00000000,0x00000000}},	//   dhte, --, --, --, 
   {{0x7c580150,0x69d80254,0x48e00037,0xbb380150}},	//   _ەلار_, ehte, _ओइजो_, _ﺒﻨﻲ_, 
   {{0x201c00b0,0xe3bc05c7,0x377400fb,0xbb5400cf}},	//   _ihui_, _fiñv_, ҙынс, _ۇناب, 
   {{0x69d8b557,0xdb080034,0xe9d40137,0x8ca4197c}},	//   ghte, _sogó, йкы_, किशो, 
   {{0x201c0208,0xf9a40014,0x683c0055,0xdb080210}},	//   _khui_, لٕکُ, _pīda, _pogó, 
   {{0xe3bc00e8,0x4ce0015b,0x00000000,0x00000000}},	//   _kiñu_, _পুকু, --, --, 
   {{0x201c0194,0xf770581f,0xe3bc002e,0xf988352e}},	//   _mhui_, ياڭ_, _jiñu_, _منشي_, 
   {{0x69d9094c,0xe614023a,0xdb08012d,0x00000000}},	//   chte, йдя_, _wogó, --, 
   {{0x201c0134,0xdb080086,0x628c011c,0xe3bc1bce}},	//   _ohui_, _gogò, _apco, _liñu_, 
   {{0x201c013f,0x3dc40083,0xb4c000dc,0xdb080210}},	//   _nhui_, _lolw_, ्नौ_, _uogó, 
   {{0xe3bc00e8,0xdb080248,0x628c0208,0x00000000}},	// [18320] _niñu_, _ongí, _cpco, --, 
   {{0x201c06c8,0x63b801e1,0x00000000,0x00000000}},	//   _ahui_, _òunn, --, --, 
   {{0xa1101216,0x628c014f,0x00000000,0x00000000}},	//   كوكت, _epco, --, --, 
   {{0xe3bc1bce,0x201d094d,0xdb080306,0x69d8030a}},	//   _biñu_, _chui_, _angí, zhte, 
   {{0xb8e80489,0x6da407d6,0x69d9094e,0x201c01ab}},	//   _ིཝ_, йида, yhte, _dhui_, 
   {{0xc95400c6,0xe3bc002e,0x8ca41fad,0x69d80200}},	//   _ʚɞ_, _diñu_, किलो, xhte, 
   {{0x3a240334,0x19c802dd,0x7d6800d4,0x00000000}},	//   dmlp_, _ﯗﺭﭘﺎ, ршів_, --, 
   {{0x9f4c0161,0xe3bc00e8,0x201c01e4,0xe29c02d2}},	//   angâ_, _fiñu_, _ghui_, _eyðu_, 
   {{0x69d9094f,0xe3bc00e8,0x4ce003d4,0x49d8010a}},	//   thte, _giñu_, _পুখু, идию_, 
   {{0xb81002f5,0x69d80789,0x8c6002dd,0xe29c02d2}},	//   _সংগত_, uhte, тiң_, _gyðu_, 
   {{0x6d590950,0xaac401d5,0x569400c7,0x00000000}},	//   _ieta, شتکن, ҟарт, --, 
   {{0x69d8b449,0x6d5807dd,0xe3bc1bce,0x5edc00eb}},	//   shte, _heta, _yiñu_, _ফুটে, 
   {{0x6d590951,0x689000dd,0x63800022,0x00000000}},	//   _keta, _کیجئ, hãnó, --, 
   {{0x6d590952,0xd6d800d6,0x30f800dc,0x9a641291}},	//   _jeta, стю_, ्थाः_, _امول_, 
   {{0x6d590953,0x00000000,0x00000000,0x00000000}},	//   _meta, --, --, --, 
   {{0x6d590954,0x00000000,0x00000000,0x00000000}},	//   _leta, --, --, --, 
   {{0x6d590955,0x5c380023,0xefcc0092,0x00000000}},	// [18330] _oeta, _ኣነጺር, ኢአድ_, --, 
   {{0x201d0956,0x78401132,0x41b41867,0x9f4c0332}},	//   _shui_, _hēva, غمار, rngí_, 
   {{0x2f3c0521,0x67ec007f,0x40940131,0x628c003e}},	//   _ịga_, _gòjè, تلار, _wpco, 
   {{0x6d580483,0xd4980276,0x628c0175,0x7aec0432}},	//   _aeta, _урь_, _tpco, _ýatg, 
   {{0x6d590957,0x628c5337,0xed4c01d9,0x00000000}},	//   _beta, _upco, چھم_, --, 
   {{0x6d590958,0xa3c00254,0x3cc8059f,0x784000ef}},	//   _ceta, ्सक_, илло_, _lēva, 
   {{0x201c001e,0x3dc401a4,0xe3bc00e8,0x9f5c01d3}},	//   _thui_, _volw_, _wiñu_, óról_, 
   {{0x6d590959,0x201c0093,0x00000000,0x00000000}},	//   _eeta, _uhui_, --, --, 
   {{0x6d59095a,0x8b640ef6,0x1f14007b,0xddc800ef}},	//   _feta, سايم, _طبرج, augš, 
   {{0x3ead095b,0x39e8dd5c,0x6ee401a9,0xf8642179}},	//   _iret_, рдоо_, _mаbl, овоо, 
   {{0xfc6400f2,0x5c040153,0x00000000,0x00000000}},	//   _ذخای, _ляда, --, --, 
   {{0x6d59095c,0xabb40022,0x6e340248,0x5c14009a}},	//   _zeta, _махә, _ògbò, _اظطر, 
   {{0x3f8d095d,0x6d59095e,0x9f4c0109,0xe3bc030a}},	//   _mbeu_, _yeta, ingà_, _liñs_, 
   {{0x6d59095f,0x00000000,0x00000000,0x00000000}},	//   _xeta, --, --, --, 
   {{0x3f8c0115,0x317c04cc,0x00000000,0x00000000}},	//   _obeu_, _ötzi_, --, --, 
   {{0x88c40150,0x3ead0960,0xa5049842,0xf348030d}},	//   _ءتول, _oret_, цеса_, рпал_, 
   {{0x7aec00ee,0x5334030d,0x00000000,0x00000000}},	// [18340] _ýatd, çест, --, --, 
   {{0xe6906112,0x00000000,0x00000000,0x00000000}},	//   _کلید, --, --, --, 
   {{0x3eacfc0b,0x7bd80083,0xe7ac0073,0x021800d4}},	//   _aret_, _olwu, _जोडप, сіть_, 
   {{0x3eac06a3,0xe3bc030a,0x00000000,0x00000000}},	//   _bret_, _diñs_, --, --, 
   {{0x3ead0961,0xdfcc0ada,0x7f4c0113,0x00000000}},	//   _cret_, خين_, ñaqa, --, 
   {{0x3eacc231,0x2bd053b7,0x6d590962,0xc29036bd}},	//   _dret_, तस्थ, _qeta, _سیمب, 
   {{0x3eac91bf,0xa064e10e,0x6140e017,0x00000000}},	//   _eret_, _мара_, _цеса, --, 
   {{0x3eac1590,0xd1d4001f,0xb0b8031c,0x7e6c0784}},	//   _fret_, ጫዎች_, བྱཞེ, šapa, 
   {{0x6d590963,0x3ead0964,0x784000ef,0x00000000}},	//   _teta, _gret_, _rēva, --, 
   {{0x6d590965,0x60e40174,0xa2b4011a,0x00000000}},	//   _ueta, _úrmæ, קפיד_, --, 
   {{0xeb990966,0x65600051,0x00000000,0x00000000}},	//   _вие_, _ônhi, --, --, 
   {{0xf8ac00aa,0xc8880116,0x6120022e,0xaac41291}},	//   اکو_, _һәмд_, dеll, _وتشن, 
   {{0x39490967,0xf1d80073,0x7aec0419,0xa9a4aec3}},	//   _şase_, णसान, _žatv, _мидд, 
   {{0xe8e90968,0x7e7c2d8b,0x5558084c,0x9f4802d2}},	//   _پرتو_, _åspe, жаря_, _álög_, 
   {{0xd90c0262,0x94a80354,0x784000de,0x00000000}},	//   _ць_, отта_, _tēva, --, 
   {{0xd70c01f2,0x27ec08a5,0x38b800e4,0x00000000}},	//   ọrịr, _ögn_, ẽrõ_, --, 
   {{0xe1f10969,0x7ddc0ba1,0xc8780205,0xddc800e5}},	// [18350] وسط_, _hèse, luğ_, zsgő, 
   {{0xddd80301,0x91b8023a,0x00000000,0x00000000}},	//   _spuž, огут_, --, --, 
   {{0x3eac0098,0xb88000bc,0x91a8007b,0x00000000}},	//   _sret_, žíve, تهلك_, --, 
   {{0x3ead096a,0x7ddd096b,0xe3bc030a,0x00000000}},	//   _pret_, _mèse, _viñs_, --, 
   {{0xb3b80302,0x1ee42f4d,0xf0000107,0x13a80244}},	//   _המרכ, غوتی_, хӯри, _بۆقی_, 
   {{0x3eac02d3,0x0dc80114,0x57c801f9,0xed54072c}},	//   _vret_, жући_, _लव्ह, пош_, 
   {{0x5065096c,0x7ddc007f,0x28ac1cd2,0x00000000}},	//   _отта, _nèse, टिफि, --, 
   {{0x3ead096d,0x386804ac,0xdb080124,0x39480118}},	//   _tret_, _ĉar_, _angá, _řas_, 
   {{0x4429096e,0xe7ac068f,0xdb080793,0xb9e82310}},	//   ima_, _जोधप, _logö, ймиз_, 
   {{0x4429096f,0x4ea4006c,0xae000075,0x8c3c0139}},	//   hma_, _ўрта, _كۈنى, _arğu, 
   {{0x4428d939,0x00000000,0x00000000,0x00000000}},	//   kma_, --, --, --, 
   {{0x44280b9b,0xdb08056a,0x1ca8031c,0x00000000}},	//   jma_, _engá, _བླར_, --, 
   {{0x7c290970,0x44290971,0x98a8a493,0xb880056a}},	//   mmer, dma_, ılık_, ñíbe, 
   {{0x44290972,0x7ddc020c,0x1da800cd,0x6120022e}},	//   ema_, _hèsb, चयित, tеll, 
   {{0x7c290973,0xc2e804c5,0x44280bfa,0x23240107}},	//   omer, _কুলি_, fma_, ҷоти_, 
   {{0x7c28398e,0x44290974,0x00000000,0x00000000}},	//   nmer, gma_, --, --, 
   {{0x23240c60,0x22480208,0x00000000,0x00000000}},	// [18360] зоти_, _ctck_, --, --, 
   {{0x7c290975,0x7ddd0976,0xdb18d3a7,0x21a00120}},	//   hmer, _lèsb, nkuñ, ниум, 
   {{0x7c290977,0x7e7801a4,0x44290978,0x65540375}},	//   kmer, euwp, bma_, _מביא_, 
   {{0x7c290979,0xa854011a,0x00000000,0x00000000}},	//   jmer, פינה_, --, --, 
   {{0x7c283858,0x87ac008f,0xdb180de2,0x00000000}},	//   dmer, ישאַ, kkuñ, --, 
   {{0x7c29097a,0x4c94022e,0x00000000,0x00000000}},	//   emer, дикс, --, --, 
   {{0x7c280fad,0x2a640165,0xdc100790,0x53e006e3}},	//   fmer, _svob_, _aşıs, _नताश, 
   {{0x7c29097b,0xaff90220,0x00000000,0x00000000}},	//   gmer, _افرا_, --, --, 
   {{0xfaf80421,0x9a800104,0x29180010,0xdee001d5}},	//   taūa_, нуэл, _špa_, _зоти, 
   {{0x7ddc02bd,0xc8780790,0x3c200022,0xad242a9f}},	//   _pèse, tuğ_, vóve_, _فرضو, 
   {{0x4429097c,0x7ddc020c,0x00000000,0x00000000}},	//   yma_, _fèsb, --, --, 
   {{0x4429097d,0x00000000,0x00000000,0x00000000}},	//   xma_, --, --, --, 
   {{0x44287958,0x6b800472,0x67380427,0x96f80395}},	//   vma_, _icog, žujo, зеят_, 
   {{0xe1fc067c,0x1a9800c8,0xdb0800c6,0x4429097e}},	//   _avón_, _לידע, _ungá, wma_, 
   {{0x69c802d0,0x291800e4,0x22480112,0x550401af}},	//   _iofe, _ápa_, _stck_, ечта, 
   {{0xe9400075,0x93a401f0,0x745000e5,0x00000000}},	//   _تۆھپ, ншуд, کھیئ, --, 
   {{0xdb080798,0x6aa0025c,0xddd80327,0x00000000}},	// [18370] _fogõ, _jsof, _ppuż, --, 
   {{0x7c28b8dd,0x7ddc067c,0xe4a5097f,0x521400d4}},	//   zmer, _mèsc, _ермо, едут, 
   {{0x44289e59,0x69c90980,0x7c290981,0x9f4c07ea}},	//   pma_, _mofe, ymer, ligé_, 
   {{0x44290982,0x6aa004c9,0x2248004d,0x00000000}},	//   qma_, _osof, _ttck_, --, 
   {{0x69c80036,0xdb1800c7,0xbe68009d,0x00000000}},	//   _oofe, ykuñ, цалж_, --, 
   {{0x6b810983,0x69c90984,0x7e780986,0x171c010f}},	//   _acog, _nofe, ruwp, צוגע, 
   {{0x7c290985,0x6aa10986,0x10a401b9,0x9f4c007f}},	//   tmer, _asof, _пиён, yigè_, 
   {{0x7ddc01c7,0xab900131,0xbc680451,0x0ca801d5}},	//   _bèsc, نلىغ, ممڪن_, ятчи_, 
   {{0x200d0987,0x69c88ad8,0xba241823,0x9f4c0100}},	//   mogi_, _bofe, мдик, vigè_, 
   {{0x69c90988,0x6b810989,0x7c29098a,0x39e810f5}},	//   _cofe, _ecog, smer, ідно_, 
   {{0x7c29098b,0x7e683c38,0x69c9098c,0x3ff8008f}},	//   pmer, _hvep, _dofe, ַפֿע, 
   {{0x200d098d,0x7e680006,0x7ddc0036,0x6b8000ae}},	//   nogi_, _kvep, _fèsc, _gcog, 
   {{0x69c800fb,0x7841098e,0x684802d3,0xd90c01d3}},	//   _fofe, _tēvo, _ዘደልድ, خیں_, 
   {{0x1ca81e81,0x69c9098f,0xd1d40092,0x200c0042}},	//   _བློ_, _gofe, ኩበት_, hogi_, 
   {{0x200d0990,0xe5a00131,0x69200117,0x00000000}},	//   kogi_, ъири, _имша, --, 
   {{0x7f4d0991,0x7e680857,0xe3b42ded,0x200d0992}},	//   ñaql, _ovep, мбс_, jogi_, 
   {{0x69c8090c,0x200c0086,0x64404db4,0x00000000}},	// [18380] _yofe, dogi_, _énin, --, 
   {{0x69c90993,0xc7640220,0x70f4007b,0x00000000}},	//   _xofe, _قاۋى, وسائ, --, 
   {{0x7e690994,0xc100010b,0x200ce931,0x73e401d5}},	//   _avep, гүрл, fogi_, _жонз, 
   {{0xef18bda8,0x683c00b8,0x00000000,0x00000000}},	//   оме_, _dīdh, --, --, 
   {{0xe5e40133,0x00000000,0x00000000,0x00000000}},	//   _رزیی, --, --, --, 
   {{0x6b80cdd9,0x7f48011f,0xefd40092,0x00000000}},	//   _scog, _efeq, ራቢያ_, --, 
   {{0x69c80165,0x200d0995,0x7e68b636,0x6aa10996}},	//   _rofe, bogi_, _evep, _ssof, 
   {{0x69c90997,0x2fd80611,0x7ddc07c5,0xdb080036}},	//   _sofe, _بورد_, _pèsc, _ongä, 
   {{0x69c90998,0x248c0023,0x1e80014b,0x00000000}},	//   _pofe, _ምፍሳስ_, _илтм, --, 
   {{0x69c8058a,0x7e7c33b8,0x6aa00051,0x00000000}},	//   _qofe, _åspa, _vsof, --, 
   {{0x7e6805b8,0xa6c802f5,0xae000131,0x48dc015b}},	//   _zvep, _লেংট, _كۈچى, ডপ্র, 
   {{0x6aa10999,0xa8600032,0x9f4c06af,0x00000000}},	//   _tsof, неүҙ, tigé_, --, 
   {{0x69c9099a,0x6aa0014b,0x2d8c0421,0x7ddc0561}},	//   _tofe, _usof, offe_, _uèsc, 
   {{0x7aec0209,0x9f4c004a,0x3c200124,0xb6300133}},	//   _ýata, rigé_, móva_, ێکیش, 
   {{0x1635099b,0x200d099c,0x439432cf,0xf8b4013d}},	//   теря, yogi_, навс, _зөя_, 
   {{0x7ddc020c,0xaad021bd,0x6d445043,0x00000000}},	//   _mèsa, _तथाक, _şkal, --, 
   {{0x200c0008,0x9f4c08fb,0xe8d00050,0x83a40022}},	// [18390] vogi_, nngå_, _سمکھ, _ҧымҵ, 
   {{0x200c0337,0x0488190b,0xe1f800cd,0x00000000}},	//   wogi_, _нәби_, ्वेण_, --, 
   {{0x200d099d,0xdb0804f3,0x7e69099e,0x3c200124}},	//   togi_, _ingå, _svep, hóva_, 
   {{0x3c2007dd,0x4f9403b7,0x2fc47c70,0xb35c0023}},	//   kóva_, вршу, gjog_, ታትውን_, 
   {{0x200d099f,0x443909a0,0x683c00b8,0xdce0008f}},	//   rogi_, _iis_, _dīdi, manĉ, 
   {{0x443820c6,0x0ea800d6,0xdce000df,0x200d09a1}},	//   _his_, ькій_, lanĉ, sogi_, 
   {{0x443909a2,0x200d09a3,0x7ddc00cf,0x23d00406}},	//   _kis_, pogi_, _cèsa, _सवाद, 
   {{0x443909a4,0x2d8c04ba,0x4608031c,0xefcc0092}},	//   _jis_, affe_, _གཉྀས_, ባታው_, 
   {{0x443909a5,0xa378000d,0x3f9c8cbd,0x3d94081b}},	//   _mis_, _klõb, mewu_, _пиар, 
   {{0x4438a146,0x3f9d09a6,0xddb4009a,0x00000000}},	//   _lis_, lewu_, _تحرب, --, 
   {{0x443802f6,0x8d741d37,0x0ca81d0f,0xe8f4013d}},	//   _ois_, _جاقا, _отци_, елэ_, 
   {{0xf77109a7,0x443909a8,0xdb0909a9,0x3f9d09aa}},	//   داد_, _nis_, _angå, newu_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x443909ab,0x7c380784,0xa2c016d1,0xe9a073b6}},	//   _ais_, _hiwr, रमन्, _башп, 
   {{0x443909ac,0x3f9c014b,0x00000000,0x00000000}},	//   _bis_, kewu_, --, --, 
   {{0x44383b08,0xdb080267,0xf77109ad,0x683c0055}},	//   _cis_, _engå, _صاب_, _sūdg, 
   {{0x443909ae,0xb2241e43,0x78a0037e,0x66b00451}},	// [183a0] _dis_, емал, lwlv, _مٽيء, 
   {{0x443909af,0x7c3803f0,0x798109b0,0x6f14012d}},	//   _eis_, _liwr, nglw, życk, 
   {{0x443909b1,0x13a8006c,0x3f9c0117,0x79800142}},	//   _fis_, _قندی_, fewu_, iglw, 
   {{0x44383d27,0x776509b2,0x3f9d09b3,0xdb180789}},	//   _gis_, nakx, gewu_, zjuá, 
   {{0x7ddc00db,0x5ed0015b,0xdce0c8d8,0x00000000}},	//   _sèsa, _দেবে, denı, --, 
   {{0x443909b4,0x2d8c07ea,0x0f200037,0xc2e80011}},	//   _zis_, uffe_, _बरीस_, _কুকি_, 
   {{0x4438ddb1,0xafe401c0,0x7c38015d,0xdd2c0118}},	//   _yis_, _зовл, _biwr, těši, 
   {{0x443909b5,0x7ddc007f,0x77640175,0x683c00ef}},	//   _xis_, _vèsa, jakx, _jūde, 
   {{0x7c380cfd,0x20042a74,0x00000000,0x00000000}},	//   _diwr, énie_, --, --, 
   {{0x9f94013d,0xacb000d1,0x3c20035b,0x00000000}},	//   _eçä_, _مەتب, róva_, --, 
   {{0x7c380042,0x98a40790,0x3c200124,0x00000000}},	//   _fiwr, _benı_, sóva_, --, 
   {{0x6d480332,0x3c200588,0x683c0171,0xdce00139}},	//   lcfa, póva_, _nūde, cenı, 
   {{0x443909b6,0x38c4006a,0x6e38882e,0x6d4800c6}},	//   _ris_, _pêrë_, _kitb, ocfa, 
   {{0x44380190,0x7afd09b7,0x6e380135,0x95c8a401}},	//   _sis_, úste, _jitb, нуса_, 
   {{0x443909b8,0xd5b81301,0x6e3803fa,0x98a00063}},	//   _pis_, хся_, _mitb, _бије, 
   {{0xe3b109b9,0x44380070,0x69d88007,0xe78436b1}},	//   درس_, _qis_, lkte, _чуко, 
   {{0x443909ba,0xb6c01473,0x28ac21f6,0x69d801f5}},	// [183b0] _vis_, _көрд, टिवि, okte, 
   {{0x443909bb,0x69d817c0,0xf8ac7b32,0x3f9c0161}},	//   _wis_, nkte, _اکی_, wewu_, 
   {{0xb5f00046,0x3f9d09bc,0x656409a8,0x69d801a4}},	//   _түрі, tewu_, majh, ikte, 
   {{0x443909bd,0x6e3830a2,0x656509be,0x8318007b}},	//   _uis_, _aitb, lajh, _يقدر_, 
   {{0x3ea509bf,0x6e3909c0,0x69d909c1,0x60d803f9}},	//   тилг, _bitb, kkte, _ƙums, 
   {{0x3f9c0bd7,0x69d801a4,0x69cc0112,0x7c3803cb}},	//   sewu_, jkte, öbel, _siwr, 
   {{0x64440227,0x7c380986,0x61f401b8,0x9f4c01e7}},	//   nqji, _piwr, mixl, ligí_, 
   {{0x69d909c2,0x6e3801c6,0x7e7c03cd,0x656509c3}},	//   ekte, _eitb, _åspo, hajh, 
   {{0x6e3909c4,0x5ca000c2,0x2444004d,0x656400df}},	//   _fitb, тиқб, _lõm_, kajh, 
   {{0x99bc02a6,0x98a403e0,0x683c0171,0x394401d5}},	//   ইস্ক, _senı_, _līdu, ъног, 
   {{0x7c380113,0x65640115,0xba742e3e,0xdcac0131}},	//   _tiwr, dajh, راکت, _ھىچ_, 
   {{0x61f40054,0x1ca80135,0x798000a9,0x6e380d27}},	//   hixl, _བླག_, sglw, _zitb, 
   {{0xda600451,0x65640115,0x6e38014f,0x999c0010}},	//   _ڌاڙي, fajh, _yitb, mpuž_, 
   {{0x7ae8066d,0x69d909c5,0x9f4c0561,0x7bc8000f}},	//   mzet, ckte, digí_, ljeu, 
   {{0x7ae909c6,0x683c00e2,0x3c2000e4,0x00000000}},	//   lzet, _pūde, nóvo_, --, 
   {{0x7bc83386,0x6f14068f,0x9f4c00ae,0x98a4013d}},	//   njeu, życi, figí_, _uenı_, 
   {{0x7ae909c7,0xf62509c8,0xdb080429,0x9f4c05d5}},	// [183c0] nzet, _идио, _angú, rigì_, 
   {{0x7ae909c9,0x229001b9,0xdce00327,0x3c20035b}},	//   izet, شلمس, ganċ, kóvo_, 
   {{0xa06509ca,0x7bc80158,0x6e3803b2,0xe0401ebb}},	//   ваха_, kjeu, _ritb, анхи, 
   {{0x7ddc020c,0x6e3909cb,0x53c401ec,0x7c7c0092}},	//   _bèso, _sitb, _самұ, _የሞራል_, 
   {{0xdb080085,0x69d802bf,0x7ae909cc,0xa2c0146b}},	//   _engú, ykte, jzet, रमण्, 
   {{0x7ae909cd,0x6e38047e,0xacd00131,0xdb1c0cad}},	//   dzet, _qitb, иблә, _àwùj, 
   {{0x7ae909ce,0xdb0801e1,0x6e382bdd,0x023001d3}},	//   ezet, _ingù, _vitb, _اہلح, 
   {{0x6e3909cf,0x7bc80098,0x7ae82963,0x65640115}},	//   _witb, gjeu, fzet, zajh, 
   {{0x7ae801ed,0x7aec0209,0x1d200032,0xada400c7}},	//   gzet, _ýatl, лмәм, _иаал, 
   {{0x6e380e29,0x28ac2232,0x3eb801a8,0x6ee401d5}},	//   _uitb, टिलि, _ásta_, _qаbu, 
   {{0x69d909d0,0x7ae8003a,0xdca057ce,0x656400df}},	//   rkte, azet, _вахи, vajh, 
   {{0xf9800124,0xe61c0051,0x00000000,0x00000000}},	//   аҳәо, mtôi_, --, --, 
   {{0x656400df,0x7ae8012d,0x61f4022e,0x44240064}},	//   tajh, czet, yixl, _ėl_, 
   {{0x644000c7,0xd6d80212,0x80b4012d,0x00000000}},	//   _énik, ттю_, ईटमे, --, 
   {{0x656509d1,0x98c001af,0x00000000,0x00000000}},	//   rajh, _всыл, --, --, 
   {{0xd37909d2,0x65640115,0xc0c80092,0x00000000}},	//   кчу_, sajh, _በነሱ_, --, 
   {{0xa2c0712e,0x656401e4,0x2ebc2450,0x45d40150}},	// [183d0] रमध्, pajh, ्होत, _бопс, 
   {{0x9f4d09d3,0x1154234c,0x65640135,0x24440051}},	//   xigâ_, икую, qajh, _tõm_, 
   {{0x7ae909d4,0x61f4467d,0x00000000,0x00000000}},	//   zzet, rixl, --, --, 
   {{0x7ddc0d29,0xb2740f25,0x8f0000fa,0xfe701f3c}},	//   _pèso, _әкрә, мiр_, مدت_, 
   {{0x75e00109,0x61f42915,0x5ec00075,0xdce00327}},	//   _hôza, pixl, рилғ, panċ, 
   {{0x7ae86709,0x8d5406bb,0xdb080158,0x9f5c00d8}},	//   vzet, атъч, _ingø, _ijuí_, 
   {{0x784109d5,0x7c9438eb,0x7bc8002d,0xc2e80154}},	//   _tēvi, اشتا, tjeu, _কুচি_, 
   {{0x7ae909d6,0xac9509d7,0xab600131,0xbe646ea9}},	//   tzet, انيا_, مۇمى, _مهري, 
   {{0x7ae80bb8,0x2c4c002d,0x7bc80fac,0xdce058b9}},	//   uzet, _ręde_, rjeu, manč, 
   {{0x7bc8002d,0x7ae909d8,0x6fd87afe,0xdce04a52}},	//   sjeu, rzet, _aïch, lanč, 
   {{0x7ae800dd,0xe85007d6,0x7f4c0113,0x47cc00fe}},	//   szet, ینید, ñaqw, াসনী, 
   {{0xdce109d9,0x9f4c026c,0x7ae909da,0x49700166}},	//   nanč, nigà_, pzet, бһәс, 
   {{0xdb080036,0xe73416ab,0x1dc4190c,0x00000000}},	//   _magë, лею_, लापत, --, 
   {{0xdb080240,0x3c300419,0x00000000,0x00000000}},	//   _lagë, _všvu_, --, --, 
   {{0xa50509db,0xdce02e03,0x3a0401ed,0x8cb81d03}},	//   гера_, kanč, _لکھی_, ्मयो, 
   {{0xdce002d5,0xfe64a0c8,0x7784255b,0xf1a858fb}},	//   janč, _وگ_, _слиз, کاره_, 
   {{0xdce00006,0xd1640124,0x24040fac,0x00000000}},	// [183e0] danč, инақ, унти_, --, 
   {{0x4e782e1f,0x113909dc,0xa6e001af,0x00000000}},	//   _አፍሪቃ_, نتاژ_, _ыжыл, --, 
   {{0xdb080240,0xdce00010,0x021800d4,0x00000000}},	//   _bagë, fanč, тіть_, --, 
   {{0x21a049d2,0xdce00024,0x2ee40209,0x683c0171}},	//   _қисм, ganč, лжег, _jūda, 
   {{0x6438008f,0x2d880205,0x20043df9,0x00000000}},	//   _רעכנ, _öbek_, énia_, --, 
   {{0x614109dd,0x5ed00154,0x00000000,0x00000000}},	//   _гера, _দেহে, --, --, 
   {{0xc1d429dc,0xdce109de,0x7aec010e,0xaf9828f6}},	//   _төтә, banč, _ýatj, _птах_, 
   {{0xdb0800f2,0x09dc00dc,0x9c0400c7,0x6fb4007b}},	//   _kagè, यस्य, лхыз_, _حمرا, 
   {{0xaf0509df,0xe208068f,0x00000000,0x00000000}},	//   _спал, łóż_, --, --, 
   {{0xdb080561,0x7afc08a5,0x2bb42ca5,0x00000000}},	//   _magè, ústa, _अफवा, --, 
   {{0x683c02d5,0xdb08020c,0x88940107,0x00000000}},	//   _būda, _lagè, шинх, --, 
   {{0xfbc400cd,0x29080003,0x00000000,0x00000000}},	//   वाणम, ħba_, --, --, 
   {{0xeab06568,0x98b0008f,0x57f41f39,0x1bf80115}},	//   _دعا_, _ĉeĥa_, спят, _אלאב, 
   {{0xa8a509e0,0x1dc4190c,0x1b140154,0xa2c000cd}},	//   _брик, लायत, দেহে_, रमस्, 
   {{0xd8b446e6,0xd54800f1,0x00000000,0x00000000}},	//   _مديا_, الفو_, --, --, 
   {{0xdb0807b0,0xc35400d8,0x00000000,0x00000000}},	//   _bagè, ркај, --, --, 
   {{0xb0600724,0xdce00e04,0x9f4c026c,0x48dc00bc}},	// [183f0] çänl, vanč, vigà_, खनको_, 
   {{0x44f41fc1,0xe1fc020c,0xdd2000d0,0x00000000}},	//   _впос, _lvóv_, _réži, --, 
   {{0xdce0dbeb,0x4394dd77,0xdb080023,0x25a0007c}},	//   tanč, _канс, _pagë, mejl_, 
   {{0x673807f5,0x7ddc007f,0xd25001d3,0x00000000}},	//   žuju, _vèsm, تنے_, --, 
   {{0xdce01dd5,0xeaa401ed,0x6f6014fb,0x00000000}},	//   ranč, _بٹ_, زۇلم, --, 
   {{0x3f7401dc,0x228d09e1,0x63ac0042,0x00000000}},	//   ều_, mük_, _hacn, --, 
   {{0x5ed003f4,0x228d09e2,0x63ac3a73,0xfbc418ac}},	//   _দেশে, lük_, _kacn, ибко, 
   {{0x7aec010e,0x00000000,0x00000000,0x00000000}},	//   _ýatk, --, --, --, 
   {{0x63ad09e3,0xdb080c6a,0x228d0283,0x2bc4010b}},	//   _macn, _kagé, nük_, рлып_, 
   {{0x63ac01a2,0x957802d3,0xe9d4010b,0x683c00ef}},	//   _lacn, ርታትን_, икы_, _rūda, 
   {{0xf1b0159d,0xdb080098,0xfbc40b98,0xf8b00214}},	//   קסט_, _magé, वादम, تکش_, 
   {{0x63ad09e4,0xdce00306,0x228c952a,0x09c40022}},	//   _nacn, lanď, kük_, _ҳашҟ, 
   {{0x228c00dd,0x25a0037e,0x6e3401e1,0x3f98013d}},	//   jük_, fejl_, _àgbó, _ısul_, 
   {{0xd1f8001f,0x63ac008e,0xca741374,0x228c41bb}},	//   ሉበት_, _aacn, _انوک, dük_, 
   {{0x1b140eac,0xdb0909e5,0x33f509e6,0xf77509e7}},	//   দেশে_, _sagè, ачас, _купю, 
   {{0x240509e8,0xdb081e7b,0x683c0a88,0x00000000}},	//   анси_, _pagè, _tūda, --, 
  
   {{0xdb085f14,0xb6a400d1,0x63ac0009,0x9f4c0548}},	// [18400] _bagé, _типл, _dacn, xigá_, 
   {{0xd5a417ae,0x63ac0597,0x7ddd09e9,0xa1c109ea}},	//   _الدی, _eacn, _dèsk, обуд, 
   {{0x673812fe,0x2bb4f5d8,0xe73c0254,0x784000ef}},	//   žujt, _अफला, reõe_, _tēvu, 
   {{0x75e0025a,0x63ac0548,0x99840024,0x228c0274}},	//   _kôzo, _gacn, _kinų_, bük_, 
   {{0x228c0790,0xf4280108,0x00000000,0x00000000}},	//   cük_, _erää_, --, --, 
   {{0x63ad09eb,0xa6e006ea,0xde0002bf,0x99840153}},	//   _zacn, øðis, опчи, _minų_, 
   {{0x63ac0067,0x9ca4009f,0x998400c0,0xa06400f3}},	//   _yacn, لهول_, _linų_, _васа_, 
   {{0x7f4c0309,0x63ac0139,0xa06400d8,0x00000000}},	//   ñaqt, _xacn, _њата_, --, 
   {{0x75e001a2,0xdee0aa08,0xdb080066,0xef180276}},	//   _rôzn, _доти, _yagé, _рма_, 
   {{0xe61c20ef,0x41c80b02,0x7c2c0327,0x00000000}},	//   ntôt_, रायस, ċara, --, 
   {{0x7654003e,0x228d09ec,0xdb4c036b,0x7e6c01fa}},	//   _atyy, zük_, _мю_, šapt, 
   {{0x228c2799,0x999c0113,0x00000000,0x00000000}},	//   yük_, rquš_, --, --, 
   {{0xdce00a54,0x41c8185d,0x63ac0356,0x47a80154}},	//   manā, रामस, _racn, গালী, 
   {{0x63accf63,0x65840022,0x00000000,0x00000000}},	//   _sacn, шымз, --, --, 
   {{0x63ac0a73,0xdef0010c,0x765401f4,0x7954009f}},	//   _pacn, _ውያን_, _etyy, _اَٺا, 
   {{0xdb080d51,0x228d09ed,0xddd82ca8,0x255401ef}},	//   _sagé, tük_, _ovuş, _bělé_, 
   {{0x58f0038f,0x4df80c2e,0x628c030d,0xdb0909ee}},	// [18410] _བཟོས_, ्चाई_, _qqco, _pagé, 
   {{0x228c93ba,0x7e7c0212,0xdce00882,0x63ac0067}},	//   rük_, _åspi, hanā, _wacn, 
   {{0x63ac0384,0x228c01d3,0xe4a400d8,0x83f8014b}},	//   _tacn, sük_, _трпо, _бенс_, 
   {{0x228d09ef,0x645405f5,0xdce00882,0x63ac0175}},	//   pük_, _itxi, janā, _uacn, 
   {{0xdce00882,0xfbc4dd06,0x3ef80276,0xf1c400d1}},	//   danā, वासम, ындэ_, _گۈلى_, 
   {{0x518509f0,0xd6580375,0xfce4045c,0xc234010f}},	//   _муса, סיות_, йоло, _לאָז_, 
   {{0xe61c003a,0xed4c0451,0x9e64211f,0xdb1803b2}},	//   ltôs_, رپي_, _چائن, ljuø, 
   {{0x3ff800c8,0x7ddc0100,0x7afc2167,0xdbb4ae3e}},	//   _עפּע, _mèsi, ústo, рткә_, 
   {{0x7ddc004e,0xfc4801ef,0x00000000,0x00000000}},	//   _lèsi, dlíš_, --, --, 
   {{0x3eac0261,0xdb080c86,0x1dd808f8,0x98500276}},	//   _iset_, _ingü, _भवित, оӂиш, 
   {{0x64540190,0xf74401e0,0x765401f4,0x7c6400d1}},	//   _ntxi, йено, _styy, _چاچل, 
   {{0xdce00882,0x3eac01a6,0x683c0064,0x00000000}},	//   canā, _kset_, _dūdo, --, 
   {{0xe9cd09f1,0x645405f5,0xd34807d6,0xca48004d}},	//   _ек_, _atxi, ییده_, _hờn_, 
   {{0x9f4c0166,0x00000000,0x00000000,0x00000000}},	//   ligä_, --, --, --, 
   {{0x04b43f51,0xb424c009,0xb4d000dc,0x739800fb}},	//   остя, معرو, वहे_, лтас_, 
   {{0x7ddc00f2,0x68080034,0xdb0909f2,0x00000000}},	//   _dèsi, lędn, _ongü, --, 
   {{0x3eac1529,0xdb080008,0x6454009d,0xbebc0024}},	// [18420] _nset_, _ingó, _etxi, _dzūk, 
   {{0xdb2000c7,0x00000000,0x00000000,0x00000000}},	//   _ãrõv, --, --, --, 
   {{0x3ead09f3,0xe2940873,0xe1fc617f,0xee380724}},	//   _aset_, _қар_, _avós_, ңне_, 
   {{0xe61c00d0,0xa0647621,0x00000000,0x00000000}},	//   stôt_, саца_, --, --, 
   {{0xdce00882,0xdef509f4,0x2450004b,0xf674010f}},	//   vanā, йыш_, _ونیس, צײַט_, 
   {{0x41c909f5,0x2d9807dd,0x3f8c0c6a,0x5ea015bf}},	//   राणस, ýpe_, _eceu_, سمىل, 
   {{0xdce00882,0x3f8c0076,0x3ead09f6,0x2d9400c7}},	//   tanā, _fceu_, _eset_, _ҳрес, 
   {{0x3218a345,0x683c4a97,0x8bd84ed4,0xa4b4011a}},	//   lopy_, _rūdo, рмис_, מלצה_, 
   {{0xed58c793,0x2d94562a,0xe51c2a67,0x683c00ef}},	//   _боз_, _грес, _मुनि_, _sūdo, 
   {{0x1ca803bd,0xa9c43cdf,0xdce00a54,0xdb0801e7}},	//   _བླམ_, ссик, sanā, _angó, 
   {{0x62180375,0xd7c41fbc,0xd90c01d3,0xbce400ae}},	//   רויק, षांच, ٹیٹ_, _وأمو, 
   {{0x7ddc020c,0x321802fb,0xb4d000dc,0x00000000}},	//   _rèsi, hopy_, वहै_, --, 
   {{0x321909f7,0xfbc4102f,0xdec80b82,0x00000000}},	//   kopy_, वारम, _በተን_, --, 
   {{0xfc4802fb,0x7ddc02e2,0xdb0801e1,0xd55402e8}},	//   slíš_, _pèsi, _magì, зкръ, 
   {{0x1294069c,0xda04004b,0xbb58037e,0xf8b4013d}},	//   _ዝርከብ_, _ديوه_, _uggブ_, _дөя_, 
   {{0x98a40024,0x00000000,0x00000000,0x00000000}},	//   _agnė_, --, --, --, 
   {{0x53340220,0x7ddc007f,0xb9dc0092,0x00000000}},	// [18430] зетт, _wèsi, _ጡት_, --, 
   {{0x7ddc067c,0x00000000,0x00000000,0x00000000}},	//   _tèsi, --, --, --, 
   {{0x64540054,0x637c01ab,0x7fd40220,0x3eac0334}},	//   _utxi, _cànà, жілі, _sset_, 
   {{0x2b44001e,0x68080034,0x7ddc0100,0x7eb8011c}},	//   _ngoc_, zędn, _yèsw, игес_, 
   {{0x91b80183,0x32180022,0xca480051,0x00000000}},	//   _আকৰ্, bopy_, _sờn_, --, 
   {{0xe0543e66,0x25b0022e,0x72a00150,0x00000000}},	//   _هیئت_, _jaxl_, _تەكن, --, 
   {{0x22480798,0xed4c0131,0x25b0002f,0x8b440241}},	//   _huck_, خپى_, _maxl_, _ẹrọf, 
   {{0x22480a40,0x5f74004b,0xca480208,0x3a9800d4}},	//   _kuck_, _داسر, _vờn_, атою_, 
   {{0xb9e80da6,0x22400936,0xdb0909f8,0xa258002d}},	//   имиз_, _kijk_, _angò, _drôg, 
   {{0x224909f9,0x69dc0227,0xf98821ec,0x25b00009}},	//   _muck_, _ŋper, جندي_, _naxl_, 
   {{0x224909fa,0xe9a401d5,0x95b404a9,0xf98800ec}},	//   _luck_, زگون_, үргә, هنکي_, 
   {{0x22400d27,0xb8d02c35,0x1dc41fc4,0x00000000}},	//   _lijk_, _ऑन_, लावत, --, 
   {{0xfa68004e,0x00000000,0x00000000,0x00000000}},	//   _талк_, --, --, --, 
   {{0xe9a0004e,0xaa542a9f,0x7958030d,0xca54030d}},	//   _жашп, _بلوا_, _тикĕ, _хĕрп, 
   {{0x2248045f,0x2ea40b33,0x201ce14a,0xdb083a6c}},	//   _auck_, _गन्त, _okui_, _magí, 
   {{0x22483b08,0x88c401ec,0xdb0803b2,0x741400f2}},	//   _buck_, _رتىل, _ungó, آورا, 
   {{0x281109fb,0x321843c0,0x00000000,0x00000000}},	// [18440] _تويس, topy_, --, --, 
   {{0x201c3223,0x9f94013d,0x715909fc,0x2248123b}},	//   _akui_, _eçü_, ррас_, _duck_, 
   {{0x3218ea1f,0x224024d1,0x7ddc180f,0xf8c80406}},	//   ropy_, _dijk_, _jèsu, िमिय, 
   {{0x2248010a,0x224001a4,0x7f4c0309,0x3218f1df}},	//   _fuck_, _eijk_, ñaqp, sopy_, 
   {{0xee3909fd,0x8b040198,0x224909fe,0x6808012d}},	//   анд_, ƙƙin, _guck_, zędo, 
   {{0x8cb800dc,0x98a400c0,0x6e4400d7,0xf8c811bc}},	//   ्मलो, _ugnė_, _ľubľ, िमाय, 
   {{0xc0c80cfc,0x3ea8003d,0xafe509ff,0xa2580109}},	//   _луѓе_, ħata_, _довл, _prôg, 
   {{0x224874b4,0x7f7405f5,0x00000000,0x00000000}},	//   _yuck_, _нууц, --, --, 
   {{0x9a80751d,0x00000000,0x00000000,0x00000000}},	//   муэл, --, --, --, 
   {{0xa378000d,0x00000000,0x00000000,0x00000000}},	//   _plõk, --, --, --, 
   {{0xd91411ed,0x0d2802dd,0x6bd801d9,0xed580117}},	//   жья_, _اقاۋ_, _پوشس_, _боҷ_, 
   {{0x6ac400ae,0x00000000,0x00000000,0x00000000}},	//   _وقام, --, --, --, 
   {{0xd6d8448a,0x99d0e415,0x9594001f,0x7d0c1432}},	//   отр_, ستیا, _ሌሎችን_, şast, 
   {{0x22490a00,0x6aa0011c,0xe1fc01e1,0x2d9c01fa}},	//   _ruck_, _ipof, _awón_, _jbte_, 
   {{0x22490a01,0x22400cf9,0x200401ed,0x23680114}},	//   _suck_, _rijk_, énik_, ијао_, 
   {{0x7ddc180f,0x2248045a,0x93a40107,0x598001af}},	//   _hèst, _puck_, мшуд, _еләб, 
   {{0x1834007b,0x92940124,0x00000000,0x00000000}},	// [18450] _تروح, матц, --, --, 
   {{0x6aa10a02,0xdb0800e4,0x201c01e4,0x22480076}},	//   _mpof, _hagã, _skui_, _vuck_, 
   {{0x7ddc180f,0x00000000,0x00000000,0x00000000}},	//   _mèst, --, --, --, 
   {{0x2bb50a03,0x22481590,0x22400cf9,0x9f9466ce}},	//   _अफगा, _tuck_, _wijk_, _açò_, 
   {{0x7ddc067c,0x6aa000b5,0x224001f5,0x7f58013e}},	//   _oèst, _npof, _tijk_, _ҳабс_, 
   {{0xa37800c5,0xcdc40116,0x00000000,0x00000000}},	//   _slõh, дашқ, --, --, 
   {{0x5ed000bd,0x6aa0ca67,0x6da00212,0xdb080306}},	//   _দেখে, _apof, хища, _vagí, 
   {{0xdef830c8,0x201c02b5,0x41c82802,0xde941291}},	//   _кыз_, _ukui_, रावस, _وجذب, 
   {{0x7fa00201,0x7ddd0a04,0x7f480194,0xfaa400d8}},	//   _ለምሳሌ_, _bèst, _igeq, чапо, 
   {{0x7e680521,0x2cbc031c,0x0dc8487f,0xca480208}},	//   _iwep, _frtd_, _мухи_, _gờm_, 
   {{0x7e680433,0x7ddc0100,0xc6880375,0x00000000}},	//   _hwep, _dèst, _תא_, --, 
   {{0xf74451f2,0x69cc69e3,0x00000000,0x00000000}},	//   яемо, öber, --, --, 
   {{0x7ddc1497,0xf7180006,0x00000000,0x00000000}},	//   _fèst, сіны_, --, --, 
   {{0x7e690a05,0x7ddc0ba1,0x75e005da,0x7bd90a06}},	//   _mwep, _gèst, _kôzi, _howu, 
   {{0x7e690a07,0x37e4010b,0x7bd90a08,0xd8b800ec}},	//   _lwep, _нокг, _kowu, _خدشا_, 
   {{0x7e684242,0x7f490a09,0xf3480353,0x7aec010e}},	//   _owep, _ngeq, спал_, _ýats, 
   {{0x7bd802ea,0x31080b8d,0x7e6802e3,0xa68000c0}},	// [18460] _mowu, әнеп_, _nwep, _злыд, 
   {{0x7bd806e4,0x00000000,0x00000000,0x00000000}},	//   _lowu, --, --, --, 
   {{0x7e685b9f,0x7ddc0268,0xd5a400e5,0x00000000}},	//   _awep, _lèss, _فلکی, --, 
   {{0xa1101b06,0x98a4002b,0x6440020c,0x7bd90a0a}},	//   رونت, _agnī_, _énip, _nowu, 
   {{0x1dc494f7,0x00000000,0x00000000,0x00000000}},	//   लांत, --, --, --, 
   {{0x7f48009a,0xec690a0b,0x7e682694,0xa2e01fbe}},	//   _egeq, брик_, _dwep, _џорд, 
   {{0x7bd90a0c,0xa0a01b74,0x7e6800b4,0x7ddc1497}},	//   _bowu, _пард, _ewep, _rèst, 
   {{0x6fb00014,0xfca80592,0x614003c5,0x00000000}},	//   _سۅتا, تاهو_, _чеса, --, 
   {{0x7ddc0ba1,0x7e6855e9,0x7bd8010b,0x44240165}},	//   _pèst, _gwep, _dowu, _ɔl_, 
   {{0x7bd80086,0x1bd0010b,0x00000000,0x00000000}},	//   _eowu, _җошя, --, --, 
   {{0x7bd90a0d,0x7ddc067c,0xdb080798,0x7e7c143a}},	//   _fowu, _vèst, _pagã, _åspr, 
   {{0x683c02d5,0x7bd80209,0x00000000,0x00000000}},	//   _kūdi, _gowu, --, --, 
   {{0x7ddc068c,0x6aa0696c,0xdb0800d8,0xea540166}},	//   _tèst, _upof, _vagã, _эзлә_, 
   {{0x555800a8,0x969401d3,0x5a300064,0x00000000}},	//   заря_, ریپش, _зніт, --, 
   {{0x7bd90a0e,0x99d002e9,0xd90c084c,0xb4b40116}},	//   _yowu, _ستوا, _чь_, мирә, 
   {{0x683c0029,0xdb080407,0x00000000,0x00000000}},	//   _līdz, _hagá, --, --, 
   {{0x473489b6,0x044420b0,0x683d0a0f,0x00000000}},	// [18470] _юнис, зеңн, _nūdi, --, 
   {{0x9f4c006a,0x7e68004c,0x81e400fe,0xd7740150}},	//   nngö_, _rwep, বোন_, _قاۋع, 
   {{0xdb08066d,0x7e681590,0x50641f39,0x00000000}},	//   _magá, _swep, етча, --, 
   {{0x683c0fda,0x7e68a136,0xbebc0055,0xdb0800ae}},	//   _būdi, _pwep, _dyūn, _lagá, 
   {{0x44290a10,0x2bb402e5,0xb3b8011a,0x00000000}},	//   mla_, _अफजा, _ומרכ, --, 
   {{0x44290a11,0x6da10a12,0x7ddc067c,0x7bd90a13}},	//   lla_, виша, _rèss, _sowu, 
   {{0xdb08004e,0x7bd90a14,0x00000000,0x00000000}},	//   _sagà, _powu, --, --, 
   {{0x44290a15,0x7f48014b,0x7ddc00db,0xba740472}},	//   nla_, _ugeq, _pèss, واخت, 
   {{0x442859e4,0x7e690a16,0xdb0801e7,0xdfa40014}},	//   ila_, _uwep, _bagá, _وُڑو_, 
   {{0x7bd88967,0x00000000,0x00000000,0x00000000}},	//   _wowu, --, --, --, 
   {{0x7bd90a17,0x9ce4030d,0x00000000,0x00000000}},	//   _towu, _эцал, --, --, 
   {{0xad181a4c,0x44290a18,0x41c809ab,0x00000000}},	//   _ווער, jla_, राँस, --, 
   {{0x44290a19,0x7c290a1a,0x7ddc0ba1,0xdb080908}},	//   dla_, mler, _hèsq, _fagá, 
   {{0xde8c01f2,0x682c0192,0x3eb808a5,0x63b801e1}},	//   lịsi_, rùda, _ástu_, _óunj, 
   {{0xe6410a1b,0x44290a1c,0xe9703e45,0x69b00574}},	//   терп, fla_, _شهيد, _असती, 
   {{0x7c290a1d,0xa92000d7,0xe1fc0210,0x00000000}},	//   nler, _úľan, _dwóm_, --, 
   {{0xe2942483,0x41c8189a,0x2324c018,0xdb0802d2}},	// [18480] мат_, रांस, доти_, _engö, 
   {{0x7c290a1e,0x5ef0038e,0x683c139f,0x8cc000cd}},	//   hler, ्छन्_, _rūdi, विमो, 
   {{0x7c290a1f,0x683c411e,0x281003e6,0xb8001414}},	//   kler, _rīdz, _سویس, _लगाम_, 
   {{0xe8d400c8,0xde6002d3,0xaf043129,0x4078005b}},	//   ווער_, _ዝተኸፍ, мпел, ящую_, 
   {{0x7c290a20,0x7ddc007f,0xdd000055,0xdce00064}},	//   dler, _rèsr, _ārāv, manę, 
   {{0x7bdc0730,0x71750a21,0x7c290a22,0x00000000}},	//   ösun, _زهرا, eler, --, 
   {{0x7c290a23,0x61410a24,0xabb00131,0x2d8c01ab}},	//   fler, _аера, вайә, rgfe_, 
   {{0x7c290a25,0x60c00008,0xa2c00d2c,0xca48004d}},	//   gler, ænme, रमच्, _hời_, 
   {{0x1ccc0156,0xdb090a26,0x63b802d2,0x298400cf}},	//   ུདཔ_, _pagá, _ðune, мынг, 
   {{0x44290a27,0x7c290a28,0xad2401d3,0x628801ab}},	//   zla_, aler, _قرضو, àgoi, 
   {{0x44290a29,0xca480016,0xfaa40046,0xdb0800e5}},	//   yla_, _mời_, _үшін, _vagá, 
   {{0x7c290a2a,0xca4801dc,0x44281574,0xeb0401c6}},	//   cler, _lời_, xla_, _очло, 
   {{0x44290a2b,0xdb080e55,0x683c012c,0x07082361}},	//   vla_, _tagá, jádř, سيسي_, 
   {{0x95c80d97,0x00000000,0x00000000,0x00000000}},	//   муса_, --, --, --, 
   {{0x44290a2c,0x69c90a2d,0x00000000,0x00000000}},	//   tla_, _infe, --, --, 
   {{0xd8a400b2,0x7ddc0100,0xa3780124,0xdb0801bf}},	//   _آهيو_, _lèsp, _moõg, _dagæ, 
   {{0x6d590a2e,0xd7744e74,0x64400ffb,0x2c780165}},	// [18490] _ofta, _شايع, _ènim, hīd_, 
   {{0x7c28ec90,0x22450a2f,0xca48004d,0x55740139}},	//   zler, önk_, _bời_, _игьт, 
   {{0x44290a30,0x7c290a31,0x96183092,0x58f00327}},	//   pla_, yler, _تغير_, _བཟབས_, 
   {{0x6d590a32,0x3f150a33,0x442803be,0x7c2801b8}},	//   _afta, ндес, qla_, xler, 
   {{0x7c290a34,0x69c83fbc,0x534412c1,0x00000000}},	//   vler, _onfe, _ахра, --, 
   {{0x7c290a35,0x00000000,0x00000000,0x00000000}},	//   wler, --, --, --, 
   {{0x7c290a36,0x7bdc005b,0xedd0515c,0x53c40b4c}},	//   tler, ösuo, ايىد, _लोडश, 
   {{0x69c90a37,0x7f850a38,0x7c28b91e,0x6808003a}},	//   _anfe, _سلطن, uler, będi, 
   {{0x7c290a39,0x6808012d,0xca480208,0x200400d7}},	//   rler, lędw, _zời_, éniu_, 
   {{0x7c290a3a,0xe1fc068f,0x6d58004e,0x9ce40801}},	//   sler, _swój_, _gfta, _оцел, 
   {{0x7c290a3b,0x66e0036b,0x200d0a3c,0x0ae80137}},	//   pler, қора, ongi_, здөй_, 
   {{0x200c9ac3,0x7c2806be,0x00000000,0x00000000}},	//   nngi_, qler, --, --, 
   {{0x200d0a3d,0xf9848f8c,0xfaa4bbb8,0x00000000}},	//   ingi_, _згло, _чало, --, 
   {{0x200c0649,0xba3800c8,0x75d416ac,0x00000000}},	//   hngi_, _צײַט, ريزا, --, 
   {{0x64a02095,0xe1fc068f,0x65c10a3e,0xdb08010e}},	//   лара, _twój_, ыбра, _bagç, 
   {{0xca48001e,0xd6c40022,0x683c0153,0x00000000}},	//   _rời_, _аииқ, _būdu, --, 
   {{0x6f14068f,0x18a00853,0x69c8000f,0x00000000}},	// [184a0] życz, _чақм, _ynfe, --, 
   {{0x31150a3f,0x683c00ef,0x200c02d2,0x00000000}},	//   нфес, _dūdu, engi_, --, 
   {{0x7ddc07d1,0xef84c143,0x208400cf,0x00000000}},	//   _rèsp, елеп, ейхи_, --, 
   {{0xca48001e,0xa2580120,0x6d580175,0x41c8000d}},	//   _vời_, _irôn, _sfta, राउस, 
   {{0xa2e10a40,0x7ddc02e2,0xa2580165,0xfe7400d1}},	//   _бояд, _pèsp, _trôa, күт_, 
   {{0xdb080793,0xe0e808e7,0x200d0a41,0xdd9000ee}},	//   _magä, ñòñ_, angi_, гашы, 
   {{0x7ddc0ba1,0x200400db,0xdb0801e3,0x40940408}},	//   _vèsp, ènic_, _lagä, _иртт, 
   {{0xaa64d63e,0x2c7800e2,0x69b00037,0xbed4013a}},	//   нток, rīd_, _असही, _šířc, 
   {{0xada404a9,0xaec50a42,0x1dc40073,0xb6040171}},	//   _паал, _ябал, लाखत, _košā, 
   {{0xdb1801a8,0x6d580166,0x09bc00cd,0x8cc021f2}},	//   rjuð, _ufta, ्ञेय, विदो, 
   {{0x26c400b0,0xb4e0002e,0x257000d1,0xab84004e}},	//   _ōno_, _ŋàna, ңқис, _зулк, 
   {{0x7c642e67,0x9cd40302,0xdce001ef,0x00000000}},	//   _شامل, _רואה_, haně, --, 
   {{0x58d00032,0x9e040150,0xf1b000dc,0x00000000}},	//   _ҡошт, _تيەك_, ीयान, --, 
   {{0x69c85fc7,0xa25800d8,0x700001f2,0xdb0800a2}},	//   _unfe, _brôn, ọcha, _sagç, 
   {{0xa25806ed,0x94a8d175,0x683c56ce,0xdce00118}},	//   _crôn, нтта_, _sūdu, daně, 
   {{0xa2580142,0x00000000,0x00000000,0x00000000}},	//   _drôn, --, --, --, 
   {{0x59b4b1e3,0x200c0fac,0x249c002e,0x25640139}},	// [184b0] _असमर, vngi_, ŋum_, _tеl_, 
   {{0xd28400f1,0x00000000,0x00000000,0x00000000}},	//   اټلي, --, --, --, 
   {{0x200c0270,0x660460c9,0xdb08010e,0xc61c0b4c}},	//   tngi_, mijk, _tagç, पकीय_, 
   {{0x66043a0e,0x76a4013f,0x00000000,0x00000000}},	//   lijk, _wɔye, --, --, 
   {{0x44390a43,0x200cf4d1,0xd70000cc,0x00000000}},	//   _ihs_, rngi_, _এঁৱা_, --, 
   {{0x6d540882,0x200d0a44,0xd6580375,0x4438202b}},	//   śyan, sngi_, עיות_, _hhs_, 
   {{0x1fa50a45,0x44390a46,0x200c03a2,0xf3f403e6}},	//   _праг, _khs_, pngi_, _ستێک, 
   {{0x66050a47,0x200c009a,0xdb085794,0xf00001f0}},	//   hijk, qngi_, _lagå, _кӯчи, 
   {{0x66040936,0x44390a48,0x7e985dc6,0x784000de}},	//   kijk, _mhs_, _زنار_, _tēvz, 
   {{0x7d790a49,0x44390a4a,0xafc00116,0x4b1800e5}},	//   _آمار_, _lhs_, _бәәй, رکنگ_, 
   {{0x44390a4b,0x9be400d6,0xdb080793,0x66050a4c}},	//   _ohs_, _підк, _sagä, dijk, 
   {{0x3dc803f9,0x44389024,0x00000000,0x00000000}},	//   ɓawa_, _nhs_, --, --, 
   {{0x9f4c09c2,0xabb40022,0x00000000,0x00000000}},	//   ligó_, _шацә, --, --, 
   {{0xa258004a,0x2adc00bc,0x98a40153,0x8e200150}},	//   _prôn, गहरु_, _ugnį_, ңiл_, 
   {{0x44390a4d,0xdce0012c,0x9f4c00cf,0x7e6c00e4}},	//   _bhs_, vaně, nigó_, ġapy, 
   {{0x443807c5,0x97240014,0x6f1c033f,0x00000000}},	//   _chs_, _مہجو, ępcz, --, 
   {{0x660401fa,0x00000000,0x00000000,0x00000000}},	// [184c0] bijk, --, --, --, 
   {{0xf1a8e8e1,0x44390a4e,0xa2590a4f,0xf1d0bc82}},	//   باره_, _ehs_, _trôn, साधन, 
   {{0x443806ea,0xdce0012c,0x61e00847,0xe1fc0210}},	//   _fhs_, raně, önla, _lwów_, 
   {{0xaf1001f2,0xee84248c,0x7c380042,0x2344185e}},	//   dụrụ, выко, _nhwr, رلەپ_, 
   {{0x200400db,0x683c03ef,0x00000000,0x00000000}},	//   ènia_, _kūdr, --, --, 
   {{0xfe1400a2,0x00000000,0x00000000,0x00000000}},	//   _ďîäî, --, --, --, 
   {{0x44380263,0xa37800af,0xfd7801ed,0xf4900023}},	//   _yhs_, _klõp, رشوں_, _ዝውሃብ_, 
   {{0x5bc06abd,0x9cc40209,0x7c3803cb,0x6fb402cb}},	//   لقىل, тыша_, _chwr, _جمرا, 
   {{0x2d9407dd,0x78ac0841,0xdce000df,0x81d40154}},	//   _арес, _ćava, manĝ, িঘর_, 
   {{0x09d039db,0xdce00115,0xade401f9,0x00000000}},	//   িস্থ, lanĝ, _कविन_, --, 
   {{0x5a309731,0xfcc00124,0x7afc021c,0x00000000}},	//   рнэт, _гәым, ústr, --, 
   {{0x66040cf9,0x9f4c0268,0x9be00064,0x00000000}},	//   wijk, ligò_, _вішк, --, 
   {{0xf3f80c58,0x6b800ca8,0x66040113,0x8bb401ec}},	//   ্কাৰ_, _idog, tijk, _аққу_, 
   {{0x44382255,0xa25807ea,0x89d800c6,0x15a80395}},	//   _shs_, _drôl, _سوبر_, къси_, 
   {{0x66040936,0x3ea8031c,0x00000000,0x00000000}},	//   rijk, ħati_, --, --, 
   {{0xe784d28b,0xa25806af,0xaab40825,0x5880586a}},	//   _руко, _frôl, _अनाक, _тыша, 
   {{0x6b8005d9,0x9f5c020c,0xdce0010f,0x660401f5}},	// [184d0] _mdog, _umué_, danĝ, pijk, 
   {{0x443805e4,0x1a98008f,0x69d8036e,0x00000000}},	//   _whs_, וימע, njte, --, 
   {{0x44390a50,0x6b810a51,0x69d801f5,0xdce000df}},	//   _ths_, _odog, ijte, fanĝ, 
   {{0x6b810a52,0xe1fc0162,0xa3e4000d,0x442c032e}},	//   _ndog, _stód_, _बकि_, _óe_, 
   {{0x6288c00f,0x3da848a4,0xd6181a4b,0x00000000}},	//   ágod, екло_, _ستیا_, --, 
   {{0x6b80f126,0x7c940798,0x7c380142,0x69d80327}},	//   _adog, гриц, _shwr, jjte, 
   {{0x60440022,0xd0d400fd,0x7c38015d,0x00000000}},	//   _ахаз, _коръ, _phwr, --, 
   {{0x9f4cbaa9,0x6b806f35,0xf4280108,0x00000000}},	//   rigó_, _cdog, _isää_, --, 
   {{0xba250a53,0x6b8000a9,0x3a240075,0x37e40fc0}},	//   лдик, _ddog, лмиг, ҳонг, 
   {{0x6b8008e7,0xaf100521,0x9f4c00db,0x74900092}},	//   _edog, pụrụ, pigó_, _ዝግጅቱ_, 
   {{0x37e4855e,0x7c3803cb,0xdb0802d2,0x00000000}},	//   гонг, _thwr, _jagú, --, 
   {{0x69d80211,0xa258004a,0xb7d0015b,0x06ac03d4}},	//   ajte, _arôm, াস্ট, খিনি, 
   {{0xdb081de4,0xd9dc2cc5,0x00000000,0x00000000}},	//   _lagú, যোগম, --, --, 
   {{0x38640204,0xbebc00cd,0x00000000,0x00000000}},	//   pplr_, _vyūh, --, --, 
   {{0x7ae90a54,0xa258004a,0x00000000,0x00000000}},	//   lyet, _drôm, --, --, 
   {{0x7bdc1073,0xa2440131,0x2ba408dd,0x00000000}},	//   ösuh, ۇرلۇ, क्पा, --, 
   {{0x7ae90a55,0x43750a56,0x59b40aff,0xc7740137}},	// [184e0] nyet, руст, _असार, _өтөө, 
   {{0xdb0801e7,0x7ae80205,0x281015bf,0x53a400db}},	//   _bagú, iyet, _پوۋس, دۅڭك, 
   {{0xa0650a57,0xa5b4008f,0xdce001e4,0x41c8194b}},	//   гаха_, _גליק_, tanĝ, राजस, 
   {{0x7654c7e9,0xef190a58,0x00000000,0x00000000}},	//   _kuyy, нме_, --, --, 
   {{0x42d49d2c,0xdce0010f,0x77740213,0x924801f0}},	//   _кіру, ranĝ, _meyx, _аҷаб_, 
   {{0x6b80011c,0x7ae90a59,0x76540789,0xaa640075}},	//   _sdog, dyet, _muyy, қтик, 
   {{0x7ae8007f,0xdee008ca,0x00000000,0x00000000}},	//   eyet, _қофи, --, --, 
   {{0x7ae80de2,0x5fa803ce,0xe930031c,0x00000000}},	//   fyet, _टॉपल, ħożż, --, 
   {{0x76541bce,0x6d94aa36,0x7ae83902,0xe7740131}},	//   _nuyy, _مشائ, gyet, һанә_, 
   {{0x49745884,0x00000000,0x00000000,0x00000000}},	//   шлос, --, --, --, 
   {{0x481422e9,0xdb0805d5,0x6ec00034,0x7ae800e8}},	//   имос, _magù, लिवु, ayet, 
   {{0x7ae80337,0x6b810a5a,0xdce000fd,0x00000000}},	//   byet, _udog, lanğ, --, 
   {{0x7774022e,0x7ae800cd,0x00000000,0x00000000}},	//   _deyx, cyet, --, --, 
   {{0x76540429,0x295402e8,0x00000000,0x00000000}},	//   _duyy, _съдр, --, --, 
   {{0x76540c6a,0x777406be,0x81e400fe,0xe3b000ec}},	//   _euyy, _feyx, বোঁ_, ٽرز_, 
   {{0x78a400af,0x784400c7,0xa4f00022,0x00000000}},	//   _ähva, _кьыҧ, ажҳә, --, 
   {{0x2ba493cb,0x765422a9,0xa2580109,0x3744030d}},	// [184f0] क्या, _guyy, _irôk, _вĕтт, 
   {{0x7860063f,0xba3c3012,0xdb080241,0xdb18002f}},	//   ịvet, rtůg, _pagú, heuß, 
   {{0xfaf80006,0x27380248,0xd1b80137,0xc1400055}},	//   lbūt_, _fàní_, داقا_, _yāṃs_, 
   {{0x7ae90a5b,0x81b40154,0x00000000,0x00000000}},	//   yyet, ঝাই_, --, --, 
   {{0xf7841248,0xf8c801e1,0x7ae85e23,0x7654208d}},	//   _öçen_, _asẹ́_, xyet, _xuyy, 
   {{0x644d0a5c,0x7ae90a5d,0xe3bc0489,0x29080004}},	//   _hici, vyet, _hañ_, ºbal_, 
   {{0x644c6928,0xe3bc1bce,0x65740240,0x00000000}},	//   _kici, _kañ_, _mexh, --, 
   {{0x7ae90a5e,0xe3bd0a5f,0xaf10063f,0x644c058a}},	//   tyet, _jañ_, pụpụ, _jici, 
   {{0xe3bc0ad3,0x64550a60,0x5fa806ab,0x682c0268}},	//   _mañ_, _luxi, _टॉयल, cùdi, 
   {{0x7ae90a61,0xe3bc1bce,0x65746994,0xb9540640}},	//   ryet, _lañ_, _nexh, штић, 
   {{0x7ae860d7,0x7cd83a55,0x6fc80574,0x8d74868d}},	//   syet, _جواز_, _सोडू, _داقا, 
   {{0x644d0a62,0x7ae90a63,0xe3bc1bce,0xf7443d6c}},	//   _nici, pyet, _nañ_, иено, 
   {{0x64542cab,0x65750a64,0x00000000,0x00000000}},	//   _auxi, _bexh, --, --, 
   {{0x644c0029,0xc5f46f78,0x64550a65,0xdce09358}},	//   _aici, йғы_, _buxi, lanđ, 
   {{0x644d0a66,0xe3bc1574,0x7bc4013f,0x76541bce}},	//   _bici, _bañ_, _ɔhun, _wuyy, 
   {{0x3eac04b9,0x644d0a67,0x64541730,0xdce000fd}},	//   _opet_, _cici, _duxi, zanğ, 
   {{0x644d0a68,0xe3bc1bce,0x64540393,0x94740014}},	// [18500] _dici, _dañ_, _euxi, _گۯزا, 
   {{0xe3bc0428,0x645410ba,0xe1f50a69,0x667800c8}},	//   _eañ_, _fuxi, агу_, _שטיק, 
   {{0xe1fc01e1,0x644d0a6a,0x645402d3,0x6f647092}},	//   _awós_, _fici, _guxi, لهام, 
   {{0x644c01b2,0x3eac01fa,0x65740472,0xaec400ee}},	//   _gici, _bpet_, _zexh, ибел, 
   {{0x3ead0a6b,0x3ad4013f,0x2eb42309,0xfd780092}},	//   _cpet_, bɛpɛ_, рсес, _ጥንካሬ_, 
   {{0x3eac0263,0x644c5ea5,0x7aec0209,0x7ddc0100}},	//   _dpet_, _zici, _ýaty, _kèsy, 
   {{0x644d0a6c,0xeb0c05d7,0x645402b9,0xe3bc0139}},	//   _yici, ाप्त_, _xuxi, _yañ_, 
   {{0xe3bc1bce,0x113814d4,0xa9c00131,0x00000000}},	//   _xañ_, _аяғы_, ﺭﺑﯩﻴ, --, 
   {{0x0f3423cf,0xa25800d8,0xdb180112,0x9a7400db}},	//   _اکاد, _esôf, reuß, айыт_, 
   {{0xace90a6d,0xe9e410ae,0x3ea8031c,0x49d800d4}},	//   _имза_, рцио, ħatt_, удою_, 
   {{0xdd8d0a6e,0x657402d3,0xec78030d,0x3eac013a}},	//   _زون_, _rexh, _рпе_, _zpet_, 
   {{0x65750a6f,0x645428e5,0x00000000,0x00000000}},	//   _sexh, _ruxi, --, --, 
   {{0x644d0a70,0xd8380323,0x64541709,0xe3bc0295}},	//   _rici, рээ_, _suxi, _rañ_, 
   {{0x2b90066d,0xfaf84ffc,0xe3bc3d27,0x2a640086}},	//   _ایکس, rbūt_, _sañ_, _itob_, 
   {{0x6ab50a71,0xe7844476,0x644d0a72,0x6574036e}},	//   _अनुर, _купо, _pici, _vexh, 
   {{0x64550a73,0xc3541fbe,0x00000000,0x00000000}},	//   _vuxi, скај, --, --, 
   {{0xe16413ef,0x6454208d,0x644c2b00,0xf1d00490}},	// [18510] لداي, _wuxi, _vici, सांन, 
   {{0x2ba40303,0x644c00a9,0x51f85b97,0xe3bc002e}},	//   क्ता, _wici, аную_, _wañ_, 
   {{0x3eac0fb7,0xceb400ac,0xe61c002d,0xe3bc008e}},	//   _spet_, çən_, tsôf_, _tañ_, 
   {{0x644d0a74,0x403407d8,0x7a3c0214,0x7f940b01}},	//   _uici, щеес, mète, садх, 
   {{0x44290a75,0x6f601b16,0x7a3cff0c,0xdce03421}},	//   moa_, سۇلم, lète, vanđ, 
   {{0x44290a76,0x9f5c0112,0x00000000,0x00000000}},	//   loa_, _fluß_, --, --, 
   {{0x7a3c276b,0xde8c063f,0xdce40374,0x00000000}},	//   nète, nịzi_, _īmēr, --, 
   {{0x44290a77,0x3ea89972,0xa25800e4,0x2a650a78}},	//   noa_, çats_, _arôi, _btob_, 
   {{0x44290a79,0xde8c063f,0x4e9400c6,0x7a3c5f72}},	//   ioa_, hịzi_, _وشكر, hète, 
   {{0xdce000f3,0xbebc00cd,0x00000000,0x00000000}},	//   sanđ, _dyūt, --, --, 
   {{0x44290a7a,0x00000000,0x00000000,0x00000000}},	//   koa_, --, --, --, 
   {{0x44290a7b,0xc5e8008d,0x36680354,0x00000000}},	//   joa_, _אד_, ламо_, --, 
   {{0x44290a7c,0x7c280af9,0x6d4c0077,0xa3c80d0d}},	//   doa_, moer, _ºbac, लयन_, 
   {{0x7c2823f3,0xdb18617f,0x7ddc007f,0x00000000}},	//   loer, nduí, _pèsy, --, 
   {{0x44290a7d,0x33f50a7e,0x00000000,0x00000000}},	//   foa_, бчас, --, --, 
   {{0x44290a7f,0x7ddc0d29,0x7c290a80,0x2bd81788}},	//   goa_, _vèsy, noer, भाया, 
   {{0x9ad001f2,0x00000000,0x00000000,0x00000000}},	// [18520] _aịzi, --, --, --, 
   {{0x44280069,0xe2950a81,0x7a3c0129,0x00000000}},	//   aoa_, саф_, bète, --, 
   {{0x44290a82,0x7c290a83,0x7a3c00cf,0xdfcc1371}},	//   boa_, koer, cète, کين_, 
   {{0x7c290a84,0x93f40150,0xc0a8007b,0xf2a401af}},	//   joer, _بۋرش, شامل_, _лимп, 
   {{0x7c28002d,0x6ab410fa,0x00000000,0x00000000}},	//   doer, _अनेर, --, --, 
   {{0xc1d446e8,0x6ff8009e,0x3e6c01e1,0x09ac00eb}},	//   _мөхә, েকেও_, _sótò_, _কোনা, 
   {{0x2a641a0e,0xa0640063,0x69d400bc,0xa2180354}},	//   _stob_, _гаса_, बासी, _сарă_, 
   {{0xdb0802d2,0x00000000,0x00000000,0x00000000}},	//   _dagþ, --, --, --, 
   {{0xee3801c0,0xa03000db,0xef186a40,0x63a80254}},	//   _бна_, _رىكت, _сма_, õgni, 
   {{0x442805f5,0xa2b8008f,0x7a30022e,0xdb0802d2}},	//   zoa_, נמיט, _qаtо, _fagþ, 
   {{0x7c289938,0xe1fc0077,0x44290a85,0x00000000}},	//   boer, _otón_, yoa_, --, 
   {{0x442801c0,0x6e2801c7,0x7a3c007f,0x00000000}},	//   xoa_, lofb, vète, --, 
   {{0x44290a86,0x32080851,0xbebc00b8,0x8cc02efd}},	//   voa_, _omby_, _hyūr, विको, 
   {{0xe1fc0077,0x442804ba,0x7a3c004e,0x6e280036}},	//   _atón_, woa_, tète, nofb, 
   {{0x2d9c031c,0x00000000,0x00000000,0x00000000}},	//   _mcte_, --, --, --, 
   {{0x32080170,0x442801ee,0x7a3c07ea,0xfbbc00dc}},	//   _amby_, uoa_, rète, ्ययम, 
   {{0x44290a87,0x7a3c0100,0x00000000,0x00000000}},	// [18530] roa_, sète, --, --, 
   {{0x44290a88,0x7c2801c4,0x7a3c06af,0x00000000}},	//   soa_, zoer, pète, --, 
   {{0x53c40490,0x7c280083,0x00000000,0x00000000}},	//   _लोकश, yoer, --, --, 
   {{0x753803fa,0x3cf003e3,0xf1d000bc,0x00000000}},	//   ütze, _üzvi_, साउन, --, 
   {{0x7c283441,0xa2580022,0x6aa00200,0x00000000}},	//   voer, _arôv, _nqof, --, 
   {{0x2ba46b9b,0x7c280083,0x00000000,0x00000000}},	//   क्सा, woer, --, --, 
   {{0x7c290a89,0xdb0800a2,0xddd80356,0xd250007b}},	//   toer, _dagý, _avuţ, _أنّ_, 
   {{0xa258002d,0x61e4014f,0x2d9c0240,0x00000000}},	//   _drôv, _hojl, _ecte_, --, 
   {{0x200d0a8a,0x7c285a29,0x2cbc01e4,0x3eb81497}},	//   migi_, roer, _estd_, _èst_, 
   {{0x200d0a8b,0x7c290a8c,0xf8a86c48,0x78a80640}},	//   ligi_, soer, авок_, аког_, 
   {{0xdb0800e4,0x61e4016d,0x00000000,0x00000000}},	//   _hagü, _mojl, --, --, 
   {{0x200d0a8d,0x61e40455,0x7ad4009f,0x00000000}},	//   nigi_, _lojl, _وقاص, --, 
   {{0x3e540943,0x7e68025c,0xdb0c0108,0x06b80014}},	//   ﬁta_, _jtep, äjäy, ٕنُک_, 
   {{0x200d0a8e,0x09ac03d4,0xa25800d7,0xdb200254}},	//   higi_, _কোঠা, _osôb, örõi, 
   {{0x62890a8f,0x2ba421b8,0x49b80214,0x200c008f}},	//   ágon, क्वा, _داند_, kigi_, 
   {{0x7e690a90,0x200d0a91,0x00000000,0x00000000}},	//   _otep, jigi_, --, --, 
   {{0x200d0a92,0xe1fc007f,0x71583f07,0x7538002f}},	// [18540] digi_, _pwóp_, арес_, ützb, 
   {{0x61e400f3,0xdb0801e7,0xf6240212,0x00000000}},	//   _cojl, _hagó, _єдно, --, 
   {{0x7e68127b,0xa37800e4,0x25d40a1e,0x09ac0154}},	//   _atep, _moõj, _ווין_, _কোডা, 
   {{0x200d0a93,0xdb0880c1,0x00000000,0x00000000}},	//   gigi_, _bagü, --, --, 
   {{0x6e290820,0xdee000d8,0xf674008f,0x2d9c0798}},	//   tofb, моци, קײַט_, _pcte_, 
   {{0xdb08011f,0x04200055,0x00000000,0x00000000}},	//   _lagó, _śaḍk, --, --, 
   {{0x2d9c067c,0x7e690a94,0x200c4ebc,0x6e280036}},	//   _vcte_, _etep, bigi_, rofb, 
   {{0x6aa00204,0x6e2801a8,0x200d0a95,0x8bd80276}},	//   _pqof, sofb, cigi_, смис_, 
   {{0x2ba43af4,0x38690a96,0x61e4014f,0x6e280098}},	//   क्षा, _čara_, _yojl, pofb, 
   {{0x2fc401ed,0xa8a4234c,0x2d9c00d7,0xb92001e1}},	//   ldog_, ормк, _ucte_, _ìsọ_, 
   {{0x61e00639,0xab840598,0x5fcc0490,0xf81401fb}},	//   önli, _дулк, _सोडल, ước_, 
   {{0x2fc410c7,0x2ba40406,0xdb090a97,0xfcc00116}},	//   ndog_, क्शा, _yagü, _чәшм, 
   {{0x6f010a98,0xe5c50a99,0xdb20032e,0x00000000}},	//   nzoc, осво, _örðu, --, 
   {{0x2ba41cba,0x200d0a9a,0x6f00004c,0x2fc43d43}},	//   क्रा, zigi_, izoc, hdog_, 
   {{0x09ac00bd,0x16340276,0xd8700137,0x2bec012d}},	//   _কোথা, феря, _قايب, _जवां_, 
   {{0x683c00da,0x61e50a9b,0x200d0a9c,0xdb1803b2}},	//   _lūdz, _sojl, xigi_, lduá, 
   {{0x4abc1d97,0x200c008f,0x2fc50a9d,0x7a3c068c}},	// [18550] ्टिव, vigi_, ddog_, lèta, 
   {{0x6f000161,0xdb080210,0x200d0a9e,0x00000000}},	//   dzoc, _zagó, wigi_, --, 
   {{0x200d0a9f,0x7e690aa0,0xa25800e4,0x7fd45d9d}},	//   tigi_, _step, _arôt, зілі, 
   {{0x2fc50aa1,0xdb08007f,0xd9b4012c,0x4abc01bc}},	//   gdog_, _magò, _अस्ट, ्टाव, 
   {{0x200d0aa2,0x2cc4025c,0xdb08007f,0x61e4047e}},	//   rigi_, _གནུབ, _lagò, _tojl, 
   {{0x200d0aa3,0x8e0800d6,0xa2580030,0x7a3c0066}},	//   sigi_, онів_, _drôt, kèta, 
   {{0x200d0aa4,0xdfd80354,0x51080408,0x00000000}},	//   pigi_, _къа_, _мĕшĕ, --, 
   {{0xcfb40801,0x2ba4193d,0x4fc402dd,0x81ac0154}},	//   _обсъ, क्ला, _يەلە, _কফি_, 
   {{0xa258000f,0x7e680250,0xaff8008f,0x00000000}},	//   _grôt, _utep, _פּלי, --, 
   {{0x7a3c067c,0x7e9c0150,0x00000000,0x00000000}},	//   fèta, _ﺍﻻﺳﺎ_, --, --, 
   {{0xf86402bf,0x3f9c0198,0x7a3c067c,0x16d40e85}},	//   явно, ogwu_, gèta, दम्ब, 
   {{0x6d540a28,0x3f9d0aa5,0xe1fd0aa6,0x69dc0241}},	//   śyat, ngwu_, _stól_, _òpen, 
   {{0xfb3405f5,0x3dc4003a,0xe1fc0744,0xeaac47db}},	//   _эндэ, _kalw_, _atóm_, _яй_, 
   {{0x97441ee0,0x63ac00d4,0xe9a00064,0xc5d40212}},	//   _ዩናይት, _abcn, _зашп, місь, 
   {{0x6f000395,0x33f50aa7,0x63ad0aa8,0x2fc4037e}},	//   zzoc, пчас, _bbcn, ydog_, 
   {{0x79802939,0x2fc40369,0xceb40213,0x7414007b}},	//   lalw, xdog_, çək_, أورا, 
   {{0x070805d9,0xd1300092,0x683c0055,0xb50400cf}},	// [18560] _ويٺي_, _እሳቸው, _nūdy, زۉڭۅ_, 
   {{0x798014dc,0x010800aa,0xada40030,0x2fc40036}},	//   nalw, ښتنو_, _krúž, wdog_, 
   {{0xfbbc0c00,0xdb0800e8,0x2fc50aa9,0x705400ae}},	//   ्याम, _magñ, tdog_, أنصا, 
   {{0x7980b6d2,0x683c005f,0xa2590aaa,0x201c01f7}},	//   halw, _sūdz, _prôt, _cjui_, 
   {{0x79800a07,0x2bd807b7,0x73340116,0x00000000}},	//   kalw, भासा, _رىسا, --, 
   {{0x3dc50aab,0x79804d11,0x6f010aac,0x47040055}},	//   _calw_, jalw, rzoc, _avṛṣ, 
   {{0x79802935,0x4bc405f5,0x6560000f,0x2fc401a6}},	//   dalw, дөлг, _ûnhe, pdog_, 
   {{0xa2580109,0x35dc012d,0x00000000,0x00000000}},	//   _trôt, माड़, --, --, 
   {{0x20040023,0x79800368,0x7a3c0066,0x00000000}},	//   ënie_, falw, wèta, --, 
   {{0x79810aad,0x3dc400a9,0x00000000,0x00000000}},	//   galw, _galw_, --, --, 
   {{0x6d581b26,0xca44001f,0xdcac215c,0x00000000}},	//   _igta, _የባቢሎ, _مىل_, --, 
   {{0xec481064,0x20050aae,0xe7d8015b,0x7a3cff24}},	//   _узел_, énix_, দস্য, rèta, 
   {{0x79800028,0xe664447e,0xd1f8069d,0x7a3c0100}},	//   balw, ятно, ጋሎት_, sèta, 
   {{0x79800c8c,0x2bd80882,0xdce00064,0x00000000}},	//   calw, भावा, ganė, --, 
   {{0x6d581c06,0x9ad001f2,0x18a000ea,0x00000000}},	//   _mgta, _pịgi, _зајм, --, 
   {{0xc2c47735,0x54550aaf,0xe61c00d8,0x67fc036e}},	//   ويزي, евст, trôs_, _bëje, 
   {{0x6d5801d9,0x98a40153,0x00000000,0x00000000}},	// [18570] _ogta, _vyną_, --, --, 
   {{0x6d580280,0xa37800e4,0x683c00c0,0x00000000}},	//   _ngta, _moõi, _rūdy, --, 
   {{0xdb080008,0xa2580109,0x98ac00f3,0x683c00c0}},	//   _lagð, _prôs, čaće_, _sūdy, 
   {{0x7980136f,0x3f150ab0,0x6d590ab1,0xdbc801a8}},	//   zalw, мдес, _agta, jóðf, 
   {{0x6d582a1f,0x67fc002e,0x79810ab2,0xfbbc102f}},	//   _bgta, _gëje, yalw, ्यसम, 
   {{0x8d84104b,0x2ef00217,0x7d240066,0x00000000}},	//   ىشىن, øyfa_, وفشن, --, 
   {{0x91840e26,0x38680030,0x8d8405af,0x61e04268}},	//   _سۇنۇ, _čaro_, رشون, önlu, 
   {{0x79810ab3,0x2bd90ab4,0xdb180120,0x201c009f}},	//   walw, भाषा, nduç, _ujui_, 
   {{0x79810ab5,0x3f8c00d5,0x8b6410a8,0x68080034}},	//   talw, _ideu_, رايم, będz, 
   {{0x9ce4084c,0xada400d0,0xfbbc00dc,0x8e2001ec}},	//   _нцел, _prúž, ्यहम, ңiз_, 
   {{0x39443f51,0x79810ab6,0x3f8c0139,0xdce00153}},	//   ьног, ralw, _kdeu_, vanė, 
   {{0xba740617,0x79810ab7,0x59d800bc,0xaab4000d}},	//   _قاتت, salw, बाहर, _अनचक, 
   {{0x7bd801f2,0x79810ab8,0x7c2d0ab9,0x69c400b0}},	//   _inwu, palw, čard, ēker, 
   {{0x79801cdf,0x4abc2017,0x7bc82d1d,0xda48228c}},	//   qalw, ्टरव, ldeu, _учел_, 
   {{0x7bc80129,0xf8b000c5,0xb808007b,0xdce000c0}},	//   odeu, _जहिय, _ويتم_, ranė, 
   {{0x7bc90aba,0x3f8c0207,0x68080034,0x22a000b0}},	//   ndeu, _ndeu_, zędz, kūkā_, 
   {{0xd2450abb,0x2c7800e2,0xdce00064,0x00000000}},	// [18580] емақ, zūd_, panė, --, 
   {{0x3f8c00db,0xe614010b,0xb13c001f,0x7bc80108}},	//   _adeu_, _оды_, _ይታወሳ, hdeu, 
   {{0x7bd802e3,0xafe402bf,0x7bc88eaf,0x5fcc000d}},	//   _onwu, можл, kdeu, _सोहल, 
   {{0x7bd8013b,0x67fc0de2,0x6808033f,0x00000000}},	//   _nnwu, _tëje, wędz, --, 
   {{0x7bc90abc,0x3f8c0142,0xf678010f,0x00000000}},	//   ddeu, _ddeu_, קאַמ, --, 
   {{0x7bd81d36,0x3f8c009a,0xb8040eac,0xec689928}},	//   _anwu, _edeu_, োকিত_, орик_, 
   {{0xdb0800fc,0x7bc8257d,0x601400b4,0x7c9c0092}},	//   _sagð, fdeu, ụmaa, _ወክለው_, 
   {{0x7bc90abd,0x61407fe3,0xd1f80092,0x00000000}},	//   gdeu, _реса, ጋዎች_, --, 
   {{0x6808033f,0xfe910abe,0xdd140419,0x00000000}},	//   pędz, _مینج, väťr, --, 
   {{0x6d580548,0x06880220,0x00000000,0x00000000}},	//   _ugta, _ﺑﻪﻛﯩ, --, --, 
   {{0xdca0fbd3,0x63b81bce,0x5bc001b9,0x1af400cf}},	//   _аахи, _ñung, رقیل, здөө_, 
   {{0x628801ed,0x01e402dd,0x00000000,0x00000000}},	//   ágok, _ﺍﻷﻤﻨ, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7c2c1225,0x29080793,0x09ac015b,0xca2000d1}},	//   čare, úbas_, _কোরা, ﺸﯩﺶ_, 
   {{0x98c0799d,0x55590abf,0x7bd8002d,0x3418002b}},	//   _асыл, даря_, _ynwu, _śvaḥ_, 
   {{0xc2d401ec,0x5b78010f,0x2c4c0210,0x00000000}},	//   _ۇﺳﺘﯩ, ַרבא, _pędy_, --, 
   {{0xc2990ac0,0x183400ae,0x00000000,0x00000000}},	// [18590] яках_, _جروح, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa25806d9,0xa0a40408,0x00000000,0x00000000}},	//   _erôp, ьшал, --, --, 
   {{0x5fcc02ab,0x6da0023b,0xfe70007b,0x2c4c0210}},	//   _सोशल, ҳиша, هدت_, _tędy_, 
   {{0x7bc80010,0x5ec00075,0x13a80244,0x00000000}},	//   vdeu, тилғ, _تۆقی_, --, 
   {{0x0dc80640,0xada00166,0xadd40114,0x00000000}},	//   дући_, гашл, емљу_, --, 
   {{0x2718bebc,0xdce04424,0x1fa43ab9,0x7bc80112}},	//   नपुर_, manī, _ораг, tdeu, 
   {{0x7bc80489,0x38680003,0xb60002d2,0x00000000}},	//   udeu, _ċar_, _þávo, --, 
   {{0x7bc90ac1,0x9da800a7,0xeab401e0,0xdb08007c}},	//   rdeu, _мъжа_, ейы_, _lagö, 
   {{0x7bc82506,0xca7453b2,0x00000000,0x00000000}},	//   sdeu, کنیک, --, --, 
   {{0xf1b000c8,0x7bc801f5,0x00000000,0x00000000}},	//   נסט_, pdeu, --, --, 
   {{0x7bd8002f,0x00000000,0x00000000,0x00000000}},	//   _unwu, --, --, --, 
   {{0xaff8008f,0x7a3c033b,0x00000000,0x00000000}},	//   פּטי, lètm, --, --, 
   {{0x644000b0,0x94c800f1,0xf1cc033f,0x00000000}},	//   _īnia, وازې_, _होंन, --, 
   {{0x2ba41810,0xa3c801bc,0x0a3400db,0x33d40212}},	//   क्का, लयं_, _جووڭ, ніат, 
   {{0xa2580109,0xb75801af,0x00000000,0x00000000}},	//   _prôp, _эшкє_, --, --, 
   {{0x2b9803e0,0x4a780023,0x00000000,0x00000000}},	// [185a0] lücü_, _ጽብቕቲ_, --, --, 
   {{0xbbbc08f8,0x21a00209,0xdcfc0118,0xdce000ef}},	//   ्युक, лиум, ívět, ganī, 
   {{0x6560002d,0x00000000,0x00000000,0x00000000}},	//   _ûnha, --, --, --, 
   {{0xa3c800cd,0xaad02c2e,0x00000000,0x00000000}},	//   लयः_, तिमक, --, --, 
   {{0x61f017c1,0x20040023,0x00000000,0x00000000}},	//   ådlø, ënia_, --, --, 
   {{0x71747b1a,0x2b980790,0x5f000137,0xdda402e8}},	//   _سهرا, kücü_, ызча, етъл_, 
   {{0x61410ac2,0x67fc1bce,0x764c04ba,0xab8400d1}},	//   _бера, _lëja, imby, нупк, 
   {{0x2bb80491,0x70440137,0x00000000,0x00000000}},	//   ساعة_, _سئزك, --, --, 
   {{0x3e5c007f,0xcdc40022,0xadb002dd,0x18b400c7}},	//   _pňte_, _иаақ, _бұлш, ҭгьы_, 
   {{0xc624009e,0xa92801ec,0x00000000,0x00000000}},	//   _মীনা_, зіме_, --, --, 
   {{0x6d600421,0x2b980790,0x7538002f,0x00000000}},	//   ātaā, gücü_, ützl, --, 
   {{0x27fd0ac3,0x48240055,0x2ba46a42,0x7af40419}},	//   óun_, _daḿṣ, क्खा, _šatň, 
   {{0xdb0801b8,0xda6c0451,0xef14000d,0x00000000}},	//   _sagö, _هُن_, _देमऽ_, --, 
   {{0x6b8022d0,0x21fc035b,0xd40400d1,0x850401e2}},	//   _heog, _oîha_, қяси, پورن, 
   {{0x69c90ac4,0xf1cc7aec,0x3ea80ba1,0x38c401ec}},	//   _iafe, _होइन, çatz_, _ашың, 
   {{0x69c90ac5,0x6b810ac6,0x5f0000cd,0x7b040205}},	//   _hafe, _jeog, वनम्_, _öttü, 
   {{0x658400a8,0x26cd0ac7,0x929400d8,0xc35400f0}},	// [185b0] _пынз, _égo_, латц, ткај, 
   {{0x6b810ac8,0xc1400020,0x69c90ac9,0xe1f00214}},	//   _leog, _ይታወቃ, _jafe, دسر_, 
   {{0x69c8486a,0xf9ec009e,0x8ff8036b,0x5224f3dd}},	//   _mafe, টোকল_, کرلر_, уфта, 
   {{0x69c90aca,0xa28036c1,0x7a3c02e2,0x44d00064}},	//   _lafe, _میرو, vètm, _ią_, 
   {{0x69c802d0,0x63bc0455,0x453400db,0x2b9803e0}},	//   _oafe, meqn, _سىڭر, zücü_, 
   {{0x44d00953,0x69c90acb,0x629c0a73,0x6b800076}},	//   _ką_, _nafe, muqo, _aeog, 
   {{0x6b8056c0,0x44d10acc,0x629c0944,0x0c94010b}},	//   _beog, _ją_, luqo, гшыя, 
   {{0xbbbc3f55,0x69c86da9,0xfdd80451,0x4fc40131}},	//   ्येक, _aafe, _ڪارڻ_, _مەمە, 
   {{0x69c90acd,0x6b810ace,0x7f5801c0,0x764d0acf}},	//   _bafe, _deog, _цаас_, ymby, 
   {{0x69c816a9,0x959402d3,0x63bc0477,0x98b00219}},	//   _cafe, ልታትን_, heqn, žeči_, 
   {{0x69c90ad0,0x6b80062c,0x44d00153,0x00000000}},	//   _dafe, _feog, _ną_, --, 
   {{0x6b810ad1,0x629d0ad2,0x2b980259,0x69c802d0}},	//   _geog, kuqo, rücü_, _eafe, 
   {{0x69c90ad3,0x644001e1,0x00000000,0x00000000}},	//   _fafe, _èniy, --, --, 
   {{0x69c80521,0xe9d430c8,0x6b8007ab,0xcbe40124}},	//   _gafe, _акш_, _zeog, _ацәи, 
   {{0x74141ec7,0x764c02d3,0xdb0800d8,0x39140244}},	//   نوسا, rmby, _vagõ, _جوغز, 
   {{0x69c90ad4,0x6b80172e,0x67fc002e,0x64a01fbe}},	//   _zafe, _xeog, _tëja, јата, 
   {{0x69c90ad5,0x048803e6,0x626000fb,0x18a001ec}},	// [185c0] _yafe, وڕێی_, ивта, _рақм, 
   {{0x30741575,0xb46400c7,0x69c800db,0xdb18068c}},	//   вудс, _икол, _xafe, reuè, 
   {{0x60c4004e,0x44d000c0,0xef8400d8,0xa234008e}},	//   _csjm, _gą_, влеп, тьтә, 
   {{0xef190ad6,0x629c1449,0xcbbc0f22,0x7a3c02e2}},	//   мме_, buqo, _আচ্ছ, fètk, 
   {{0xbbbc00cd,0x00000000,0x00000000,0x00000000}},	//   ्यैक, --, --, --, 
   {{0x6b802f48,0x00000000,0x00000000,0x00000000}},	//   _seog, --, --, --, 
   {{0x69c90ad7,0x6b800dd4,0x00000000,0x00000000}},	//   _rafe, _peog, --, --, 
   {{0x2fd81bff,0x69c90ad8,0x4dc8015b,0x7a3c020c}},	//   _تورد_, _safe, লাধূ, lèth, 
   {{0x67fc044e,0x69c90ad9,0x6b800254,0x5c000d1d}},	//   _bëjn, _pafe, _veog, ряща, 
   {{0xdba00023,0x69c8bd71,0x65680477,0x49740108}},	//   _ገዳይም_, _qafe, _ğgho, ылос, 
   {{0x69c90ada,0x6b810adb,0xa37800e4,0x06ac03d4}},	//   _vafe, _teog, _moõr, খিছি, 
   {{0xa86001e0,0x69c8bcfd,0x44d000c0,0xaae401e2}},	//   леүҙ, _wafe, _rą_, _لستو, 
   {{0x44d014cf,0x69c90adc,0x0a950add,0xb4b463b8}},	//   _są_, _tafe, _салю, һирә, 
   {{0xb60000bc,0xd5b8010b,0x80d40073,0xdb18002f}},	//   _žáro, ксс_, णिमे, lfuß, 
   {{0x43950ade,0x629c401f,0x7a3c067c,0x6b44022e}},	//   лавс, wuqo, dèth, dаgi, 
   {{0x2ba47e29,0xd3706073,0x629c0784,0xdb180112}},	//   क्चा, يۇپ_, tuqo, nfuß, 
   {{0x386807f5,0x63bcba3d,0x00000000,0x00000000}},	// [185d0] _čari_, reqn, --, --, 
   {{0x44d0d5fb,0x629c058a,0xf8ac1291,0x00000000}},	//   _tą_, ruqo, _بکی_, --, 
   {{0xa3780798,0x46140633,0x959800f3,0x00000000}},	//   _anõe, _لوکر, _ртњу_, --, 
   {{0x4f950adf,0xe40801d5,0x63bc0455,0x00000000}},	//   аршу, _آغده_, qeqn, --, 
   {{0x8f340953,0x12e456a4,0x4fc40116,0x9268014b}},	//   аецц, _кірг, рсха, _арса_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8f440022,0x00000000,0x00000000,0x00000000}},	//   лхәд, --, --, --, 
   {{0x443802a8,0x2bd800a5,0xbb448b06,0xfba800cc}},	//   _jks_, भागा, лейк, _খোজত, 
   {{0xeb8d0ae0,0x7a3c1e7b,0xd76401d5,0xfdb800f5}},	//   _қи_, lèti, یندی, _плащ_, 
   {{0xf9900597,0x7538002f,0x00000000,0x00000000}},	//   حبة_, ützk, --, --, 
   {{0x44390ae1,0x7a3ceacd,0x8d750ae2,0x25e43517}},	//   _oks_, nèti, _خاقا, ञानी_, 
   {{0x44380472,0x624829ef,0xeb8c0063,0x8ba400d4}},	//   _nks_, lüod, _ћи_, _виїж, 
   {{0xa3e4141f,0x59b00032,0xe9ccd080,0xb6f81870}},	//   पान_, _көнс, _лк_, رىسا_, 
   {{0x44390ae3,0xaa9000c6,0x7b045775,0x874c0092}},	//   _aks_, _الوث, ıttı, _በፕሮጀ, 
   {{0x628c02d0,0x44390ae4,0x7a3c068c,0xe2950ae5}},	//   _avco, _bks_, vèth, һат_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe2950ae6,0xb2250ae7,0x443821e3,0x13a801d5}},	// [185e0] лат_, гмал, _dks_, _یندی_, 
   {{0x44390ae8,0x7a3c004e,0x619402d3,0x960401c0}},	//   _eks_, fèti, _ግዳማዊ_, _түгж, 
   {{0x34a90ae9,0x7a3c00db,0xe29401e0,0x234400d1}},	//   _явно_, gèti, _ҙар_, پلەپ_, 
   {{0xfaf8003e,0x4438b29b,0x00000000,0x00000000}},	//   kyū_, _gks_, --, --, 
   {{0x62882af5,0x765d0aea,0xa0640184,0xb8d40135}},	//   ágot, _kipy, _ҡара_, _ཝཱ_, 
   {{0x765c0451,0x6ca414a4,0x7a3c5eaf,0x78a10aeb}},	//   _jipy, гриж, bèti, kulv, 
   {{0x765c7c84,0x7c2c46aa,0x44381073,0x7a3c00db}},	//   _mipy, čarn, _yks_, cèti, 
   {{0x765d0aec,0x3218289f,0xa3e4043e,0x6c8402dd}},	//   _lipy, lipy_, पाय_, _ەلام, 
   {{0x2984807e,0xa3780124,0x765c0588,0xdb180112}},	//   лынг, _moõp, _oipy, rfuß, 
   {{0x321806d9,0xa9c4234c,0x6a8402dd,0x1a6461be}},	//   nipy_, усик, _ұлда, دیوی_, 
   {{0x6e390aed,0x78a10aee,0xa3e42efd,0x00000000}},	//   _iktb, gulv, पाम_, --, 
   {{0x7c6404a9,0x765c00c7,0x00000000,0x00000000}},	//   _ئالل, _aipy, --, --, 
   {{0x765c0083,0x321806d9,0xadf807f7,0x00000000}},	//   _bipy, kipy_, _्तान_, --, 
   {{0x44390aef,0x7afc08d7,0x67fc0de2,0x7a18033b}},	//   _sks_, øste, _tëjo, pňta, 
   {{0x44390af0,0x765c0368,0xc8a82c30,0x78a0009a}},	//   _pks_, _dipy, _कमिट, culv, 
   {{0x765c0022,0xe7850af1,0x7a3c033b,0x00e40345}},	//   _eipy, _суко, vèti, یتای, 
   {{0x44390af2,0x20040023,0x00000000,0x00000000}},	// [185f0] _vks_, ënim_, --, --, 
   {{0x7a3c00f7,0x765c00ca,0xa2580030,0x91e40640}},	//   tèti, _gipy, _hrôz, бође, 
   {{0x44390af3,0x55ac010f,0xe4a4009d,0x00000000}},	//   _tks_, _אייַ, _ёроо, --, 
   {{0x44390af4,0x628c00f2,0x628801ed,0xd1390af5}},	//   _uks_, _tvco, ágos, уху_, 
   {{0x66f41ab2,0x7a3c0100,0xa3e44f76,0x80bc0154}},	//   ुनिक_, sèti, पाठ_, োমধ্, 
   {{0x2bd84eae,0x7c950af6,0xbca40fb4,0x7a3c007f}},	//   _मोबा, ариц, لمتي, pèti, 
   {{0x7e710af7,0x4fc400cf,0x1128011c,0x00000000}},	//   _žepč, _گەنە, _бюти_, --, 
   {{0x67fc02d3,0x2a6407de,0x75380e78,0x78a07e03}},	//   _bëjm, _buob_, ützi, vulv, 
   {{0x4fc40eff,0x3dcc00fe,0xfc300014,0xea840150}},	//   _دەنە, লাবল, ٝحک_, абыл_, 
   {{0x7f4801f0,0x2a64003a,0xcef40640,0xe9d400c7}},	//   _izeq, _duob_, _упућ, акь_, 
   {{0xd7646071,0x68f800a2,0x00000000,0x00000000}},	//   ینگی, gytd, --, --, 
   {{0x765c4eba,0x78a10af8,0x18b000d1,0x36690af9}},	//   _sipy, rulv, _һәмр, камо_, 
   {{0xe3bc00b8,0x765c014f,0x00000000,0x00000000}},	//   _ajño_, _pipy, --, --, 
   {{0xcaf50afa,0xa9640114,0xaad026e4,0x68f800a2}},	//   _دسمب, _киша_, तिरक, bytd, 
   {{0x765c00ec,0xf8d800c5,0x00000000,0x00000000}},	//   _vipy, _बछिय, --, --, 
   {{0x3cec14cf,0x37740166,0x00000000,0x00000000}},	//   _अपने_, _тыкс, --, --, 
   {{0x765c0368,0x43750afb,0x7ae8001b,0xe8500472}},	// [18600] _tipy, суст, nxet, _بنيد, 
   {{0xe1fd0afc,0x7ae8004e,0x86c401f7,0x00000000}},	//   _stór_, ixet, _ايٿن, --, 
   {{0x6f6415ed,0x13a80517,0x321800b5,0x87250afd}},	//   авез, _ینگی_, ripy_, _نعیم, 
   {{0x321806d9,0x2c6801ab,0x7a3c02bd,0x62880327}},	//   sipy_, _rùd_, pètw, ġgor, 
   {{0xdfcc2361,0xe2950afe,0x32180109,0x9ea4009b}},	//   بين_, _кая_, pipy_, ивца_, 
   {{0x248c008e,0x7ae8005a,0x00000000,0x00000000}},	//   _ämmä_, dxet, --, --, 
   {{0x6ce47707,0x00000000,0x00000000,0x00000000}},	//   ріле, --, --, --, 
   {{0x2a6404cc,0x68fc00a2,0xaad000cd,0x00000000}},	//   _puob_, _üpdi, तिलक, --, 
   {{0x15f80cf1,0xa3e40f4a,0x1d200139,0x00000000}},	//   ुसार_, पात_, ймәм, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x88580a27,0x7ae8009d,0xdb080112,0x2bd8000d}},	//   лиос_, axet, _abgä, _मोथा, 
   {{0x2cbc022e,0xdca00798,0x32fc00b8,0x3b0400c7}},	//   _iptd_, _фаци, _kāyā_, рҵәо_, 
   {{0xab64000d,0x32fc002b,0x4a74211f,0x673c0200}},	//   _etüü, _jāyā_, _اُتر, _qyqj, 
   {{0x2bd8033d,0x32fc00cd,0x00000000,0x00000000}},	//   _मोता, _māyā_, --, --, 
   {{0x98a00640,0x04c81541,0xcfe401ec,0x18a0119e}},	//   _дије, دوزي_, _ﺍﺗﺎﺗ, _дајм, 
   {{0x539800d6,0xd3790aff,0x62645085,0x14080124}},	//   ився_, ичу_, لائق, ахуп_, 
   {{0x21650b00,0xe164026a,0xc1b90b01,0x92680063}},	// [18610] атег, ађен, ллах_, арха_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe7e8033f,0xa3e41df0,0x6ab000cc,0xedfc00eb}},	//   टापा_, पाद_, জিটো, ্চাশ_, 
   {{0x9ad0063f,0x5fa00e8e,0x8f000150,0x00000000}},	//   _dịji, تەرم, кiр_, --, 
   {{0x644002b5,0x7ae8025c,0x00000000,0x00000000}},	//   _īnih, xxet, --, --, 
   {{0x6e90007b,0x00000000,0x00000000,0x00000000}},	//   ألوا, --, --, --, 
   {{0x10a40364,0x1ea800ec,0x6da01b0a,0xba3c013a}},	//   _миён, _ڄائي_, чища, ktůr, 
   {{0x7ae8e2da,0x26d80309,0x5fcc007d,0x1ea800ec}},	//   txet, _orqo_, _सोचल, _لائي_, 
   {{0x99880118,0xe7e80210,0xfe78014b,0x00000000}},	//   álům_, टाना_, _сӯе_, --, 
   {{0x7ae90b02,0x00000000,0x00000000,0x00000000}},	//   rxet, --, --, --, 
   {{0x26d80548,0x7e68f577,0x1cb90220,0x00000000}},	//   _arqo_, _huep, _جاذب_, --, 
   {{0x7e680451,0x00000000,0x00000000,0x00000000}},	//   _kuep, --, --, --, 
   {{0x7e60049b,0xfc7c0118,0xe1c40210,0x00000000}},	//   _kilp, žádá_, रजाघ, --, 
   {{0xa2d837e3,0x7e60014f,0x00000000,0x00000000}},	//   निन्, _jilp, --, --, 
   {{0x644c00a3,0x21dc00b0,0xe9cc05d9,0xa5042901}},	//   _bhci, _māhē_, _سٺي_, бера_, 
   {{0x644c772b,0x69dc6457,0x33644961,0x38b10b03}},	//   _chci, _òper, сваг, már_, 
   {{0x38b10b04,0x644c01ab,0x2f0c01d3,0xf3482077}},	// [18620] lár_, _dhci, _mögé_, упал_, 
   {{0xd5a401ed,0xe1f50b05,0x97300092,0x32fc00b8}},	//   _بلدی, бгу_, ተያየት, _rāyā_, 
   {{0x7c2c151c,0x38b10b06,0x644c00a3,0x0684004e}},	//   čarj, nár_, _fhci, _лгөн, 
   {{0x7e610b07,0xefb00214,0xe7e816ae,0xdb180022}},	//   _ailp, ثیرگ, टाया_, nduó, 
   {{0x38b01a09,0x7e680ac5,0xb8d8025c,0xdfcc5214}},	//   hár_, _cuep, _ངད_, عيه_, 
   {{0x38b10b08,0x6fb4a55b,0x21650b09,0xa110141d}},	//   kár_, _گمرا, _гири_, _کوفت, 
   {{0x38b10b0a,0x7e600455,0xa0a10b0b,0x0b94001f}},	//   jár_, _dilp, _нард, _መቀየር_, 
   {{0x38b10b0c,0x7e600156,0xfc3801e4,0xa2500133}},	//   dár_, _eilp, goŭ_, _وپێش, 
   {{0x7e681a56,0xaf041734,0x7e610b0d,0xfe700014}},	//   _guep, _упал, _filp, _قدٕ_, 
   {{0x2fc437a8,0x7e600072,0x38b0102c,0x7afc08fb}},	//   leog_, _gilp, fár_, østa, 
   {{0xdd8c8eef,0xeb980323,0x2cbc3132,0x6560002d}},	//   _سون_, _бие_, _uptd_, _ûnhi, 
   {{0x2d8d0b0e,0x2fc4007b,0x7e60007f,0xd1f80023}},	//   lafe_, neog_, _zilp, _ገዳብ_, 
   {{0xa3e40141,0xd83805f5,0xde8c063f,0xd6840b3b}},	//   पास_, сээ_, gịhi_, зусп, 
   {{0xf2cc015b,0x644c01ab,0x38b0ea0f,0xdce00135}},	//   রমাণ, _shci, bár_, lanġ, 
   {{0xa25805da,0x2d8c0093,0xd8b4009f,0x4a7400ec}},	//   _msôt, iafe_, _هديا_, _اُڪر, 
   {{0x2d8cf2fa,0x2fc40076,0x9d1800df,0x00000000}},	//   hafe_, jeog_, אולט, --, 
   {{0x7a3c5a72,0xe16429c6,0x2d8d0b0f,0x2fc50b10}},	// [18630] mètr, مداي, kafe_, deog_, 
   {{0x51f8c2e2,0x21650b11,0xd678009a,0x65a800f3}},	//   бную_, стаг, _احيا_, _стиг_, 
   {{0x7e68020c,0x75380e78,0xdce0025c,0xe0e400eb}},	//   _suep, ützt, kanġ, পন্ন, 
   {{0x7e610b12,0x7e680607,0x2d8c0270,0x7a3d0b13}},	//   _silp, _puep, eafe_, nètr, 
   {{0x38b0a568,0x7e68447a,0x7e610b14,0x35dc05f9}},	//   zár_, _quep, _pilp, _फोड़, 
   {{0xa5240135,0x9f5c0093,0xa3e40490,0x56b8011a}},	//   _རྨོག_, _uluí_, पाव_, צפון_, 
   {{0x63ac0e14,0x2bd81be1,0x7e60023a,0x00000000}},	//   _kccn, _मोहा, _vilp, --, 
   {{0x7e690b15,0x38b10b16,0x2c0c01e1,0x00000000}},	//   _tuep, vár_, _péjọ_, --, 
   {{0x44290b17,0x7e607a1e,0xec1001ec,0x34c405f9}},	//   ina_, _tilp, بويد, _लन्द, 
   {{0x44290b18,0x2d8c019b,0x38b00f47,0x0eb800f1}},	//   hna_, cafe_, tár_, _دافغ_, 
   {{0x44290b19,0xdb200efc,0x2bd80118,0x39480798}},	//   kna_, توکی, _मोवा, рзно_, 
   {{0x38b10b1a,0xa524025c,0xc5e80375,0x6f0c1432}},	//   rár_, _རྨེག_, _בד_, _öncü, 
   {{0x38b10b1b,0x7c28e7cc,0x34c00882,0xdb2002f6}},	//   sár_, mner, शब्द, öräi, 
   {{0x7c290b1c,0x63ac0175,0x38b10b1d,0x79580408}},	//   lner, _accn, pár_, _килĕ, 
   {{0x44290b1e,0x7afc0267,0x33f404b0,0xb6f80228}},	//   fna_, ästf, очас, _چىعا_, 
   {{0x7c290b1f,0x24050b20,0x136801ec,0xdb1800a2}},	//   nner, онси_, спақ_, lduñ, 
   {{0x7c290b21,0xc7a8107b,0x31781291,0xaad00118}},	// [18640] iner, _ادىل_, لحاظ_, तिएक, 
   {{0x7c290b22,0xa6c40014,0xa1c0013e,0x63ac02d0}},	//   hner, _بوٝل_, мбуд, _eccn, 
   {{0x44290b23,0x63ac0664,0x7c290b24,0x2d8c0810}},	//   bna_, ännö, kner, vafe_, 
   {{0x2d8c1529,0x63ac0332,0xb61801ec,0x6020009d}},	//   wafe_, _gccn, _ﹼﻡ_, мдха, 
   {{0xa3e46f64,0x2d8c442c,0x7c290b25,0x63802626}},	//   पार_, tafe_, dner, _ігра, 
   {{0xa6e0008c,0x2fc401e7,0x1aec00cc,0x00000000}},	//   æðis, seog_, টনাই_, --, 
   {{0x2d8d0b26,0x61410b27,0x7c290b28,0xdce0031c}},	//   rafe_, _жера, fner, tanġ, 
   {{0x2d8c6a61,0xa064084c,0x2bd800bc,0x9c540114}},	//   safe_, _фата_, _मोशा, ошњу_, 
   {{0x9c8401f1,0x320800d7,0xdce00003,0x00000000}},	//   _počú, _klby_, ranġ, --, 
   {{0x44290b29,0xa2d800dc,0x7c280d90,0xbe3000db}},	//   zna_, नित्, aner, _كۉنب, 
   {{0x7c290b2a,0xb8d000ec,0x00000000,0x00000000}},	//   bner, فڪيش, --, --, 
   {{0x44290b2b,0xac940022,0x00000000,0x00000000}},	//   xna_, _гаҧш, --, --, 
   {{0x44290b2c,0x624804cc,0x00000000,0x00000000}},	//   vna_, düon, --, --, 
   {{0x44290b2d,0xa524031c,0x2868009b,0x00000000}},	//   wna_, _རྨུག_, _крио_, --, 
   {{0xa3e42db8,0x38940055,0x00000000,0x00000000}},	//   पाल_, cār_, --, --, 
   {{0x44290b2e,0x32090b2f,0x7afc01e3,0x427400d8}},	//   una_, _alby_, ästg, згас, 
   {{0x44284bc1,0xa2d80b02,0x320802f0,0x7538002f}},	// [18650] rna_, निध्, _blby_, ützr, 
   {{0x7c2c05a1,0xfe780118,0x00000000,0x00000000}},	//   čari, _rtů_, --, --, 
   {{0x44290b30,0x7c290b31,0x204002d3,0x818800cf}},	//   pna_, yner, _ንዲሞክ, _ۇچاق_, 
   {{0x98b00b91,0x44290b32,0x1014872f,0xa3e40073}},	//   žeći_, qna_, وبند, पाळ_, 
   {{0x7c281fcd,0xce9402e8,0x00000000,0x00000000}},	//   vner, дачъ, --, --, 
   {{0xb64c001f,0x41c401d9,0x7c280f85,0x00940139}},	//   _በቅንጅ, _عٲزِ, wner, _нигэ, 
   {{0x7c290b33,0x61e40076,0x00000000,0x00000000}},	//   tner, _injl, --, --, 
   {{0x7c280af5,0xa2580109,0x6560000f,0x7afc143a}},	//   uner, _tsôs, _ûnhu, østo, 
   {{0x7c280d90,0xa9c000d1,0x00000000,0x00000000}},	//   rner, ﯩﻴﯩﺴ, --, --, 
   {{0x8d7466a3,0x989000fd,0x3d948660,0x00000000}},	//   _قاما, мумә, _хижр, --, 
   {{0x67fc00e8,0x3944bbdb,0x7c290b34,0x00000000}},	//   _lëju, яног, pner, --, 
   {{0xdd8d0b35,0x4bd81291,0x00000000,0x00000000}},	//   _سوچ_, _وبند_, --, --, 
   {{0x3f8c017a,0xe724013e,0x7bc8017a,0x6bd40345}},	//   _meeu_, зояд_, meeu, _رووس_, 
   {{0x7bc90b36,0x3f8c05e4,0xd1f8001f,0x00000000}},	//   leeu, _leeu_, ፉበት_, --, 
   {{0xa5050b37,0x36680107,0x8af806be,0xdb080162}},	//   пера_, раҳо_, _çərx, ðhæd, 
   {{0x61e50b38,0x77845ce1,0x3f8d0b39,0xfa48215c}},	//   _anjl, _элиз, _neeu_, _ئشچى_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [18660] --, --, --, --, 
   {{0xa1107611,0x00000000,0x00000000,0x00000000}},	//   کومت, --, --, --, 
   {{0x7bc80098,0x00000000,0x00000000,0x00000000}},	//   keeu, --, --, --, 
   {{0xa5240135,0x35b00307,0xa3e400dc,0x00000000}},	//   _རྨིག_, _जाड़, पाः_, --, 
   {{0x7bc90b3a,0xef1400af,0x7afc08cb,0x00000000}},	//   deeu, _देखऽ_, østl, --, 
   {{0x5ea00131,0x2d98000f,0x2e4001d3,0x3e680417}},	//   رمىل, ûpe_, رہاہ, ішін_, 
   {{0x40950b3b,0x3f8c0363,0x7bc8062c,0x00000000}},	//   _ортт, _feeu_, feeu, --, 
   {{0xac940014,0x20040200,0x00000000,0x00000000}},	//   _ہۆتا_, ënit_, --, --, 
   {{0xada44f41,0x4a541eec,0xe7e801f9,0xf3fc00fe}},	//   _наал, мкис, टासा_, _এষাৰ_, 
   {{0x6f010b3c,0x2b5003e0,0x00000000,0x00000000}},	//   myoc, _ıncı_, --, --, 
   {{0xf8ac004b,0xab6408da,0x5d78011a,0x1fdc00cc}},	//   لکي_, _евел, _האבק, _ভকতস, 
   {{0x7f2801d9,0xb4e40118,0x00000000,0x00000000}},	//   _اسہِ_, पमै_, --, --, 
   {{0x56950b3d,0x3e5c033b,0x6f000066,0x59d401f9}},	//   наят, _sňti_, nyoc, _भोकर, 
   {{0xa2d875be,0xfaa4005e,0x7afd0b3e,0xe3b00014}},	//   निस्, _ішін, äste, کرس_, 
   {{0x19b80302,0x75380112,0x04c800f1,0xd5540395}},	//   _המוב, ützp, غوري_, екръ, 
   {{0x994400e3,0x62480254,0x00000000,0x00000000}},	//   _عليل_, tüoo, --, --, 
   {{0xc618023a,0x979c0375,0x18380a1e,0x00000000}},	// [18670] _моих_, _השחק, _מאהל_, --, 
   {{0x51f80108,0x62480254,0x291006be,0xe7e801f9}},	//   пную_, rüoo, _əyan_, टावा_, 
   {{0x7fd4eeec,0x83f80902,0x00000000,0x00000000}},	//   ділі, _денс_, --, --, 
   {{0x9eb01945,0x00000000,0x00000000,0x00000000}},	//   ешкә, --, --, --, 
   {{0x6f00037e,0xbef800cd,0x7bc80254,0x00000000}},	//   gyoc, ्नेन_, veeu, --, 
   {{0x9f5c00db,0x7bc8003e,0xd24401c6,0x98a400c0}},	//   _lluç_, weeu, _зэси, _gynė_, 
   {{0xed5403b7,0x5578008f,0xc10415f2,0xa2d80a59}},	//   мош_, לעגן_, _غوري, निव्, 
   {{0x27f80009,0x3a980212,0x00000000,0x00000000}},	//   _noqn_, отою_, --, --, 
   {{0x7bc80731,0x6f0000ca,0x05dc09bb,0xbdb400f0}},	//   reeu, cyoc, मयाब, _обај, 
   {{0xaa550b3f,0x7bc8003e,0x00000000,0x00000000}},	//   وليا_, seeu, --, --, 
   {{0x7bc8003e,0x7afc007c,0x00000000,0x00000000}},	//   peeu, ästb, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb4e40882,0xa3e4134e,0xac040212,0x1b000139}},	//   पम्_, पाई_, _інша_, _чүпн, 
   {{0x25b0003a,0x7c2c02f0,0x09e400d4,0x00000000}},	//   _ccxl_, čaru, _поін, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb4bc000d,0x00000000,0x00000000,0x00000000}},	//   _इही_, --, --, --, 
   {{0xa2d80c00,0xb88000db,0x98a40064,0xe7e803ce}},	// [18680] निष्, üífe, _pynė_, टारा_, 
   {{0xf1a8bc10,0x201d0b40,0x6f0000ec,0x2554037e}},	//   تاره_, _amui_, vyoc, 幅led_, 
   {{0xa83001ed,0x7afc03cd,0x6a3800df,0x00000000}},	//   _سٹیش, østj, קגעפ, --, 
   {{0x556401ec,0x06d000eb,0x724400b8,0xb64802dd}},	//   _يۇڭك, ামরি, _ṅgīk, _ﻋﻲ_, 
   {{0xee390b41,0x76b00134,0xf1a804fb,0x32600022}},	//   онд_, _bɛyɛ, _واسه_, _аҵаҳ, 
   {{0xa2d8043e,0x3cb80150,0x00000000,0x00000000}},	//   निर्, _ﺤﺴﺒﻤ, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8af90b42,0x5bc00131,0x2bac0073,0xa3e40456}},	//   знис_, نقىل, _टाळा, पाए_, 
   {{0xea5400fb,0x00000000,0x00000000,0x00000000}},	//   мзиә_, --, --, --, 
   {{0xb4bc000d,0xed581b0a,0x1ef800d9,0x00000000}},	//   _इहू_, _доз_, _ולמע, --, 
   {{0xd9150b43,0xe7e883e3,0xdce00115,0x00000000}},	//   дья_, टाला_, tanĥ, --, 
   {{0x60d000e4,0xfca8009f,0x7d0c01e4,0x7afc002f}},	//   _ñemũ, _رامو_, ĝast, ästc, 
   {{0xe9d80261,0x99d10b44,0x5cc001c6,0x7c2c00d7}},	//   _мкд_, رتیا, _зөөв, čart, 
   {{0x69cc0037,0x00000000,0x00000000,0x00000000}},	//   õbed, --, --, --, 
   {{0x69d8007c,0x0cbc00cc,0x00000000,0x00000000}},	//   mdte, _আছুত, --, --, 
   {{0x69d90b45,0xd3a43d6c,0xe7e80490,0x9f5c03e0}},	//   ldte, круп, टाळा_, _uluç_, 
   {{0x69d801ab,0x83342901,0x00000000,0x00000000}},	// [18690] odte, хнах, --, --, 
   {{0x45d41fbe,0xb194008e,0x00000000,0x00000000}},	//   _џонс, елфә, --, --, 
   {{0xdce0005f,0x69d90b46,0x6128009d,0x00000000}},	//   rbnī, idte, ццаг_, --, 
   {{0x442d0b47,0xa2a417ee,0x9e910b48,0x00000000}},	//   _ñe_, _चिप्, ناتچ, --, 
   {{0x3ea405f5,0x2d9c00e4,0xbea50b49,0x8ff801b9}},	//   хилг, _bdte_, халк, برلر_, 
   {{0x69d801f5,0x92940a5b,0x00000000,0x00000000}},	//   jdte, _јарц, --, --, 
   {{0x2f740055,0x61402a8b,0x00000000,0x00000000}},	//   _aṇuṣ, _شىرە, --, --, 
   {{0x69d84fa5,0xbed40063,0x00000000,0x00000000}},	//   edte, _побј, --, --, 
   {{0x69d80d27,0x63b80022,0xaea001ec,0x19c401ec}},	//   fdte, _ñunu, _مەني, _ﺒﻤﻭﺠ, 
   {{0x7f48014b,0x69d801f5,0x00000000,0x00000000}},	//   _iyeq, gdte, --, --, 
   {{0xb4bc033d,0x6ce0004b,0x00000000,0x00000000}},	//   _इहे_, _مړين, --, --, 
   {{0xb6a50b4a,0xba740131,0x69d801ab,0x0c840153}},	//   нимл, _كاتت, adte, _рыфм, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7bd90b4b,0x82bc031c,0x03a800f1,0x68ec01e7}},	//   _hawu, _ཕྱེའ, ېدلو_, óidí, 
   {{0x7bd90b4c,0x00000000,0x00000000,0x00000000}},	//   _kawu, --, --, --, 
   {{0x7bd80198,0xb600012c,0xf11800d1,0x00000000}},	//   _jawu, _žádo, ۋغات_, --, 
   {{0xfbd802a6,0xdc000306,0x629c01e1,0x437401f4}},	// [186a0] থাপত, jčís, _àyò, туст, 
   {{0x7bd90b4d,0xb9cc00b7,0x71580114,0x00000000}},	//   _lawu, _ቶን_, прес_, --, 
   {{0x7f48379d,0xee390b4e,0xa5b408a8,0xdb0806be}},	//   _ayeq, үне_, _אליק_, _abgü, 
   {{0x7bd90b4f,0x70540150,0x69d801ed,0x1bdc000d}},	//   _nawu, رنشا, zdte, _खोलल_, 
   {{0xdee10b50,0x2bd801ad,0x3a240254,0x9f80009d}},	//   лоци, _मोगा, kilp_, угчд, 
   {{0xfe780118,0xdeb81ef7,0x00000000,0x00000000}},	//   _trůn_, ተለካ_, --, --, 
   {{0x7f488f98,0xb4bc033d,0x09d800eb,0x00000000}},	//   _eyeq, _इहो_, তামা, --, 
   {{0x7bd80066,0x614040f8,0x2aa800cf,0xa2a40118}},	//   _cawu, _сеса, птоо_, _चिम्, 
   {{0xfe900214,0x3a5401d3,0x052c0023,0xddc80166}},	//   _نینج, چینج_, _ደድሕሪ, _çişk, 
   {{0x7afc908f,0x09d80154,0xdb0c02d2,0x69d8000d}},	//   ästa, তাভা, _ídýr, udte, 
   {{0x290800dd,0x7bd800ca,0xdca00563,0x00000000}},	//   ába_, _fawu, _бахи, --, 
   {{0x7bd90b51,0x3cf8010f,0x29080327,0x00000000}},	//   _gawu, _קלײנ, ġba_, --, 
   {{0x290809a8,0xb4bc0037,0x00000000,0x00000000}},	//   šba_, _इहॉ_, --, --, 
   {{0x7bd90b52,0x6010509e,0xca4400d1,0x00000000}},	//   _zawu, _içme, ﻘﯩﺶ_, --, 
   {{0x7bd90b53,0xaaa40490,0x439432b0,0x5558084c}},	//   _yawu, _खिडक, кавс, еаря_, 
   {{0x7bd802b9,0x60c4020b,0x21000030,0x82bc0327}},	//   _xawu, _rpjm, nčiť_, _ཕྱུའ, 
   {{0x2bc01a67,0x7aec0129,0x53e400c7,0x6708009d}},	// [186b0] व्या, _àatt, ыцра, _хэйг_, 
   {{0xa2a405dc,0x21000030,0x3eb80254,0xc0c40139}},	//   _चिठ्, hčiť_, _ästi_, кәби, 
   {{0x20040120,0xb4f00139,0x00000000,0x00000000}},	//   ênio_, _күрч, --, --, 
   {{0x9f5c01e1,0x210000d0,0x92c00154,0x85440064}},	//   _iluú_, jčiť_, ংয়ে_, rmėč, 
   {{0x62801326,0x7bd90b54,0x1f9400f7,0x210000d0}},	//   ćnos, _rawu, _үйгө_, dčiť_, 
   {{0x7bd90b55,0x00000000,0x00000000,0x00000000}},	//   _sawu, --, --, --, 
   {{0x7bd90b56,0x009401c0,0x6cd0007b,0x9258009d}},	//   _pawu, _шивэ, لقوا, _чарт_, 
   {{0x8fd40139,0xdc500014,0xbb4401ec,0x6d9c0248}},	//   _бәшә, درتک, кейк, _ṣatu, 
   {{0x7f48014b,0x7bd8bc61,0x5a4004a9,0x00000000}},	//   _uyeq, _vawu, лмиғ, --, 
   {{0x7bd8471d,0xf99000ae,0x5fb80118,0x00000000}},	//   _wawu, جبة_, ोजकल, --, 
   {{0x7bd90b57,0x6bd40b8a,0x58040961,0x00000000}},	//   _tawu, رویس_, гонғ, --, 
   {{0xeb8c0063,0x00000000,0x00000000,0x00000000}},	//   _њи_, --, --, --, 
   {{0xe9cd0b58,0x2bd81f13,0xdb0c0241,0x00000000}},	//   _кк_, _मोटा, _ìdàr, --, 
   {{0xc5d401ce,0x437401f0,0x00000000,0x00000000}},	//   лісь, ҳуфт, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4374016c,0xa3dc000d,0x00000000,0x00000000}},	//   гуфт, _धोआ_, --, --, 
   {{0x23248ab1,0x33640139,0x00000000,0x00000000}},	// [186c0] воти_, тваг, --, --, 
   {{0x66e00354,0x00000000,0x00000000,0x00000000}},	//   _тоьа, --, --, --, 
   {{0x628c02d0,0x32a800d1,0x00000000,0x00000000}},	//   _ewco, _ﺷﻪﮬﻪ, --, --, 
   {{0x764c11ad,0xaf040150,0x00000000,0x00000000}},	//   llby, кпел, --, --, 
   {{0x764c017a,0x9db400f1,0x25e40118,0x00000000}},	//   olby, ږديز_, _छोडी_, --, 
   {{0xa2a438db,0x06d40150,0x2bd80f4a,0x00000000}},	//   _चित्, _ﺘﺅﻴﺩ, _मोजा, --, 
   {{0x644000d8,0xe0d40166,0xe610010f,0x7afc3453}},	//   _ínic, _ивр_, יִק_, ästn, 
   {{0x2cf107c7,0x00000000,0x00000000,0x00000000}},	//   _अपील_, --, --, --, 
   {{0x9c3402e8,0xecf00154,0x2984013d,0x210000d7}},	//   ъпът_, জনেস_, кынг, rčiť_, 
   {{0x2bac0574,0x2a6801ed,0x00000000,0x00000000}},	//   _टाका, öbb_, --, --, 
   {{0x6c740107,0x00000000,0x00000000,0x00000000}},	//   _рузх, --, --, --, 
   {{0x3ea8237d,0x27fc2242,0x9960547c,0xab9801d5}},	//   šate_, ðun_, штыл, _آخار_, 
   {{0x0708082e,0xd83805f5,0xcc8804fb,0x96f80801}},	//   ريسي_, тээ_, _آنچه_, веят_, 
   {{0x95c8020f,0xdb0c0ca8,0x00000000,0x00000000}},	//   куса_, _ìdár, --, --, 
   {{0x55050b59,0xa85000c7,0xc1a401ec,0x3a3800e4}},	//   ачта, _кекә, ғызқ, éspe_, 
   {{0x543401b9,0xa2a400cd,0x00000000,0x00000000}},	//   لرقر, _चिद्, --, --, 
   {{0xfe78013a,0x00000000,0x00000000,0x00000000}},	// [186d0] _prům_, --, --, --, 
   {{0xe16438eb,0x52140212,0xa3e400bc,0xf8a81546}},	//   نداي, адут, पाङ_, _किमय, 
   {{0x21650b5a,0x5f745821,0x5638010f,0x308800db}},	//   ттаг, ناشر, _באזע_, ешчү_, 
   {{0xa280034c,0x3f14237e,0x838801d5,0xb3400139}},	//   _نیرو, лдес, _яроғ_, _şçel, 
   {{0x2284036b,0x69d40134,0x7a3c007f,0xa3dc07f7}},	//   _шунг, _ɔyer, rètz, _धोए_, 
   {{0x1ee435cd,0x63a80210,0x00000000,0x00000000}},	//   _یوزی_, łoną, --, --, 
   {{0x4428ead8,0xa2d817c6,0x91840131,0x00000000}},	//   oia_, निक्, _ئۇمۇ, --, 
   {{0xfd2801e1,0x4fc4005e,0x7afc0621,0x00000000}},	//   _akìí_, _نەمە, ästo, --, 
   {{0x4428166a,0x2bc43f6e,0x2f8401ee,0x00000000}},	//   iia_, улып_, _сәхн_, --, 
   {{0x44290b5b,0x00000000,0x00000000,0x00000000}},	//   hia_, --, --, --, 
   {{0xf988021a,0x3828355b,0x3e78180f,0x00000000}},	//   ونکي_, ежно_, _hèt_, --, 
   {{0x44290b5c,0x3e78007f,0xe81c000d,0xddc0007f}},	//   jia_, _kèt_, मोला_, wonň, 
   {{0xfaa485c4,0x3e78020c,0xc8840139,0x00000000}},	//   _сало, _jèt_, _peşü_, --, 
   {{0x3e780d29,0x4428166a,0x7afc0162,0x00000000}},	//   _mèt_, eia_, østu, --, 
   {{0x44290b5d,0x3e780699,0x37e50b5e,0xd5b800e2}},	//   fia_, _lèt_, _бойг, ļā_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3e780699,0xa2d90b5f,0x136801ec,0xe81c01f9}},	// [186e0] _nèt_, निग्, тпақ_, मोळा_, 
   {{0x44290b60,0x7c290b61,0xaaa4023e,0x00000000}},	//   aia_, hier, _खिसक, --, 
   {{0x7c290b62,0xdfcc00f1,0xaf500d52,0x00000000}},	//   kier, ګين_, әнлә, --, 
   {{0x3e780d29,0x7c290b63,0x8f850b64,0x8fc40022}},	//   _bèt_, jier, рқал, радҵ, 
   {{0x3e78020c,0x7afc2bd5,0xdfcc007b,0x7fd4003b}},	//   _cèt_, ästl, ثين_, ріхі, 
   {{0x3e7802bd,0x7c290b65,0xdd910b66,0x716400d1}},	//   _dèt_, eier, башы, _مازك, 
   {{0xa3b90b67,0xec680139,0x00000000,0x00000000}},	//   _घाम_, нрик_, --, --, 
   {{0x3e7811c1,0x7c290b68,0xa064c7eb,0x09ac0490}},	//   _fèt_, gier, _баса_, चल्य, 
   {{0xee38026a,0xaae400c6,0xdee0023b,0x1cc80327}},	//   _зна_, اسبو, _лоти, ིསུ_, 
   {{0x7c282ad4,0x6010013d,0xa2b8010f,0xdea0872f}},	//   aier, _içma, עמיט, _ایوی, 
   {{0x4428013b,0xf1c411bc,0x98a400a2,0x481800d4}},	//   yia_, र्यन, _dynį_, вжню_, 
   {{0x7c290b69,0xaae50b6a,0x64c40219,0xc60c00dc}},	//   cier, _مستو, nčiš, हस्य_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x44290b6b,0xf1c4043e,0x88f800db,0x78b006ea}},	//   wia_, र्मन, _لىتر_, ðkvø, 
   {{0x44290b6c,0xa2a4071e,0x94a80026,0x00000000}},	//   tia_, _चिह्, лтта_, --, 
   {{0x44290b6d,0x2a6c01ab,0x64c40841,0xb90c0ca8}},	//   uia_, _hifb_, jčiš, _lilọ_, 
   {{0xc1b80251,0x00000000,0x00000000,0x00000000}},	// [186f0] клах_, --, --, --, 
   {{0x44290b6e,0x7c290b6f,0x26d80309,0x41840121}},	//   sia_, zier, _isqo_, ртағ, 
   {{0x60109d6a,0x3e79030a,0x74150b70,0x4614208f}},	//   _açma, _sèt_, _چوپا, _موکر, 
   {{0xb4f90b71,0x442802d3,0x7c290b72,0x3e78033b}},	//   _ספרי, qia_, xier, _pèt_, 
   {{0x7c290b73,0x9f5c025a,0x44390b74,0x00000000}},	//   vier, _koué_, _ijs_, --, 
   {{0x7c290b75,0x9f5c07ea,0xc0c40131,0x7afc00c5}},	//   wier, _joué_, _вәди, ästm, 
   {{0xa3780086,0x4438020b,0xd13800f3,0x00000000}},	//   _eaõe, _kjs_, _бхт_, --, 
   {{0x3e7811c1,0x9f5c004a,0x00000000,0x00000000}},	//   _tèt_, _loué_, --, --, 
   {{0x7c290b76,0xfbd00014,0x44380113,0xfaa50b77}},	//   rier, متک_, _mjs_, шапо, 
   {{0x7c290b78,0x9f5c0129,0xaaa40037,0xba240a5b}},	//   sier, _noué_, _खिरक, рдок, 
   {{0x2bc00574,0xe8f40262,0x2bac02ab,0x44380f85}},	//   व्हा, алэ_, _टाचा, _ojs_, 
   {{0x44380fac,0xb0b4011a,0xdedc0240,0x00000000}},	//   _njs_, ספרס_, _ጓህን_, --, 
   {{0xfaa40063,0x3b080114,0xf1c41fc4,0x00000000}},	//   _ђако, _јело_, र्डन, --, 
   {{0x64c40427,0x2b000118,0x00000000,0x00000000}},	//   zčiš, षहरु_, --, --, 
   {{0xe9450b79,0x44380120,0x9f5d0b7a,0x64a004b3}},	//   _پروی, _bjs_, _doué_, жаса, 
   {{0xb3844d5d,0x473401d9,0xdebc01f3,0x977404b4}},	//   рлал, _گر٘ز, _ሱባኤ_, _уткә, 
   {{0xa2e016a8,0x44390b7b,0xb60400e2,0x09d80154}},	// [18700] оотд, _djs_, _pašā, তারা, 
   {{0xa2a4278e,0x64410b7c,0x00000000,0x00000000}},	//   _चिर्, _ínin, --, --, 
   {{0x7afc00c5,0xe7e80b72,0x00000000,0x00000000}},	//   ästj, _जोडा_, --, --, 
   {{0x43750b7d,0x888c008f,0xc05802d5,0x1b180154}},	//   _гурт, גראַ, гіі_, _তখনই_, 
   {{0xa3b80ce0,0x6e2805c7,0xaf3433d2,0xd25002f2}},	//   _घात_, tifb, جرات, _فۆر_, 
   {{0xeca4026a,0x6ca401d5,0xf1a801e2,0x00000000}},	//   ајин, ариж, _ګاڼه_, --, 
   {{0xa0a00aa5,0x4c94023a,0x6e290b7e,0xf1c4215d}},	//   _мард, щийс, rifb, र्णन, 
   {{0x2a6c1529,0xceb80075,0x7aec00d0,0x3ea80219}},	//   _sifb_, _бәк_, _šata, šata_, 
   {{0xf1c407af,0x6011069b,0xb8800798,0x298808da}},	//   र्थन, _uçma, üíne, ксно_, 
   {{0xc30800eb,0x00000000,0x00000000,0x00000000}},	//   _রেডি_, --, --, --, 
   {{0x09d8045e,0xdd7827af,0xfca80736,0x9f5ca573}},	//   তালা, _סטאל, _مانو_, _roué_, 
   {{0xf1c47509,0xa2a40d2e,0x9f5c00e8,0x65c40124}},	//   र्तन, _चिल्, _soué_, _oĩhí, 
   {{0x92e8045e,0x6b801140,0xeaf813de,0x29841ee1}},	//   বহু_, _ifog, _جرات_, _кыйг, 
   {{0x1a980a1e,0xf2cc03d4,0xe4a4ffac,0x0488008e}},	//   _יידע, ৰমাণ, ирбо, ләми_, 
   {{0x69c80218,0x443890d8,0xda580375,0x9f5c0129}},	//   _ibfe, _pjs_, _שכול, _voué_, 
   {{0x25e41b90,0x3cdc033f,0x291c0064,0x00000000}},	//   _छोरी_, _कैफे_, mzta_, --, 
   {{0x9378013e,0x6b8001ab,0x71640131,0x6e380175}},	// [18710] рбут_, _mfog, ەپلە, _ojtb, 
   {{0x41b40597,0xddd801a6,0x00000000,0x00000000}},	//   إمار, _otuš, --, --, 
   {{0x44390b7f,0xf1c50b80,0xcfe000cc,0xd1b8f9ec}},	//   _tjs_, र्धन, ণানন, شالا_, 
   {{0x6aa000df,0xa25806af,0x44380165,0x2fc4956c}},	//   _ovof, _apôt, _ujs_, gfog_, 
   {{0x6d58a57b,0x69c80393,0xa2640395,0x00000000}},	//   _azta, _obfe, _въвл, --, 
   {{0x6b810b81,0x7c94a437,0x1bdc0037,0xf1c400cd}},	//   _afog, бриц, _खोजल_, र्दन, 
   {{0xc1040fb4,0x206805a2,0xd0840108,0xb05000e5}},	//   _اوزي, _ашап_, _мыти, _کھلت, 
   {{0x2d8000dd,0x69c80112,0x3b08025c,0x00000000}},	//   _őket_, _abfe, _żaqq_, --, 
   {{0x6d5805f5,0x3f1500fc,0xba2404a9,0x68e80165}},	//   _ezta, _удас, йдик, _arfd, 
   {{0x3f9c0c11,0x6b800770,0x69c80175,0x181000cd}},	//   lawu_, _efog, _cbfe, ास्व_, 
   {{0xdea001ed,0xbc280166,0x37e40454,0x291c00c0}},	//   _ایڈی, _йхдҗ_, бонг, gzta_, 
   {{0x3f9d0b82,0x69c80175,0x0c040014,0x765c0200}},	//   nawu_, _ebfe, _وولُ, _shpy, 
   {{0xdce00ba5,0x68e823f3,0x291c01c4,0x00000000}},	//   manı, _erfd, azta_, --, 
   {{0xdce10b83,0xe45c006a,0x3f9cb05f,0x00000000}},	//   lanı, _ahö_, hawu_, --, 
   {{0x3f9c0bd7,0x6aa00810,0x291c0034,0x00000000}},	//   kawu_, _zvof, czta_, --, 
   {{0xdce08e8e,0x3f9c00e8,0x10f800e5,0xf86800ec}},	//   nanı, jawu_, یباں_, _ڌمڪي_, 
   {{0x7afc0112,0x00000000,0x00000000,0x00000000}},	// [18720] ästh, --, --, --, 
   {{0x38700076,0xdce03535,0x00000000,0x00000000}},	//   _hiyr_, hanı, --, --, 
   {{0xdce00bfc,0xa25806d9,0x3f9c022f,0x92e8009e}},	//   kanı, _apôs, fawu_, বহে_, 
   {{0xa0650b84,0x00000000,0x00000000,0x00000000}},	//   баха_, --, --, --, 
   {{0xb8f803bd,0x7aec0122,0xdce0b8f1,0x6d581790}},	//   _ོར_, _šatn, danı, _szta, 
   {{0x6b809933,0x6d58005a,0xdd903740,0x00000000}},	//   _sfog, _pzta, пашы, --, 
   {{0x3f9c06ee,0xafe50b85,0x6ce49684,0xdce01432}},	//   bawu_, _ловл, сіле, fanı, 
   {{0x6d580316,0xdce03279,0x69c806ff,0x00000000}},	//   _vzta, ganı, त्नी, --, 
   {{0xa3b84614,0xada50b86,0x682c0241,0xf3e803d4}},	//   _घास_, _газл, _lòdè, _টকাৰ_, 
   {{0x3870062c,0xdd7000e5,0x00000000,0x00000000}},	//   _aiyr_, _ٹھوک, --, --, 
   {{0x2bc810f5,0x6d590b87,0xdce00259,0xc7f802bf}},	//   _було_, _uzta, banı, аннє_, 
   {{0xdce00ac1,0xa154011a,0x00000000,0x00000000}},	//   canı, מביה_, --, --, 
   {{0x291c5642,0xe81c02ab,0x28d80490,0x00000000}},	//   szta_, मोगा_, _बनवि, --, 
   {{0x3f9d0b88,0x387000ad,0x375000d1,0x00000000}},	//   zawu_, _eiyr_, بھىس, --, 
   {{0x3f9c04ba,0xba3c0118,0xee2c01ca,0x885800f0}},	//   yawu_, trův, ьнi_, _кикс_, 
   {{0xc958006c,0xf1c40892,0x3f9c1bce,0x5f0807b6}},	//   _йўқ_, र्सन, xawu_, ऽहम्_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [18730] --, --, --, --, 
   {{0xdce00c07,0xa3b851a5,0x7afd0b89,0x3f9d0b88}},	//   zanı, _घाव_, ästi, wawu_, 
   {{0xdce045a5,0xa2580038,0xc0d50b8a,0x3f9d0b8b}},	//   yanı, _spôs, تياب, tawu_, 
   {{0xdce06656,0x442c0166,0x00000000,0x00000000}},	//   xanı, _öe_, --, --, 
   {{0xdce0722d,0x3f9d0b8c,0xc694010f,0xf1c400cd}},	//   vanı, rawu_, קאַ_, र्हन, 
   {{0x7aec098d,0x3f9c0142,0x609805e0,0x00000000}},	//   _šato, sawu_, _مخرج_, --, 
   {{0xdce0538f,0x3f9c5412,0xed4c01d9,0xdb0c0ca8}},	//   tanı, pawu_, پھل_, _ìdúr, 
   {{0x1ea80451,0xfed80451,0x00000000,0x00000000}},	//   _مائي_, _پارڪ_, --, --, 
   {{0xdce03bc2,0xf1c40882,0x387000ad,0xce9402e8}},	//   ranı, र्वन, _riyr_, _натъ, 
   {{0xdce04ba9,0xc8a400e1,0x387000ad,0x8e150b8d}},	//   sanı, _खटखट, _siyr_, _едуц, 
   {{0x644c00c8,0xdce0c5d2,0x387000ad,0xf1b0025d}},	//   _okci, panı, _piyr_, וסי_, 
   {{0xb9002007,0x644c0472,0x29100198,0xdce000ac}},	//   _नई_, _nkci, _ƙyar_, qanı, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7ae90b8e,0x7bc85161,0x961401ad,0x80c80210}},	//   mvet, lfeu, डसेट_, _रहूं, 
   {{0x7ae90b8f,0x996401d9,0xcaf400db,0x00000000}},	//   lvet, _دۅدٕ_, _وسۇب, --, 
   {{0x69dd0b90,0x7bc90b91,0x00000000,0x00000000}},	//   _óper, nfeu, --, --, 
   {{0x7ae90b92,0xba3c01ef,0x00000000,0x00000000}},	// [18740] nvet, brůt, --, --, 
   {{0xe1f50b93,0x644c01e4,0x7bc8002f,0xc8c40345}},	//   огу_, _ekci, hfeu, _بڕیی, 
   {{0x7ae8016d,0x1ab40154,0x7aec00a2,0xd1300137}},	//   hvet, ড়িয়া, _šatl, رۅر_, 
   {{0x7ae90b94,0x00000000,0x00000000,0x00000000}},	//   kvet, --, --, --, 
   {{0x7ae8047e,0x00000000,0x00000000,0x00000000}},	//   jvet, --, --, --, 
   {{0xf1c41157,0x7ae90b95,0x2d98035b,0xe2950b96}},	//   र्शन, dvet, úpe_, _фар_, 
   {{0x7ae801e0,0x7bc90b97,0x6fb415b0,0x014c0023}},	//   evet, ffeu, _ومسا, _ንሳቶም, 
   {{0x7bc80086,0x00000000,0x00000000,0x00000000}},	//   gfeu, --, --, --, 
   {{0xada40e26,0x1cc80156,0xeb0402f6,0x7ae90b98}},	//   _маал, ིསཔ_, ючко, gvet, 
   {{0xacf400aa,0x3eb803cd,0x00000000,0x00000000}},	//   _وسات, _åsta_, --, --, 
   {{0x7ae8a1c6,0x290800d2,0xdca0004e,0xa3b801f9}},	//   avet, âba_, _жахи, _घाल_, 
   {{0xd90c01ed,0x7ae8047e,0x00000000,0x00000000}},	//   ئیٹ_, bvet, --, --, 
   {{0xb90002f8,0x7ae88841,0x69b00490,0x9e040150}},	//   _नै_, cvet, _आयपी, _ديەك_, 
   {{0x5ee80882,0xd99400cf,0x00000000,0x00000000}},	//   चित्_, _ۇنۇت_, --, --, 
   {{0x80c80034,0x388402b1,0x7afc2bd5,0x00000000}},	//   _रहें, _pēre_, ästv, --, 
   {{0xe3b001d9,0x3cdc00c5,0x00000000,0x00000000}},	//   برس_, _कईसे_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [18750] --, --, --, --, 
   {{0x51f801ce,0x067c00d1,0x91b00051,0x00000000}},	//   оную_, ﻣﻪﻟﯩ, _đạn_, --, 
   {{0x2124431d,0x7ae90b99,0xa2a49d35,0x00000000}},	//   ành_, zvet, _चिक्, --, 
   {{0x7ae8016d,0x47ac0eac,0x1fa401ec,0x00000000}},	//   yvet, ট্রী, ірег, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7ae90b9a,0x91840075,0xfce40261,0x6f60515c}},	//   vvet, _يۇقۇ, зоко, رۇلم, 
   {{0x1fa4035b,0xb600022a,0x7ae8014f,0x7bc80112}},	//   _мраг, _žáko, wvet, tfeu, 
   {{0x7ae90b9b,0x9d4802d3,0x81bc015b,0x7bc80de2}},	//   tvet, _ሕንፍሽ, _আসি_, ufeu, 
   {{0x7ae80276,0x7bc90b9c,0x00000000,0x00000000}},	//   uvet, rfeu, --, --, 
   {{0x7ae90b9d,0x7bc80112,0x00000000,0x00000000}},	//   rvet, sfeu, --, --, 
   {{0x7ae90b9e,0xf1b000c8,0x81bc015b,0xbb7416a4}},	//   svet, עסט_, _আসা_, _егеј, 
   {{0x7ae90b9f,0xb92c0023,0x00000000,0x00000000}},	//   pvet, _ብዘለዎ, --, --, 
   {{0xe7350ba0,0xdb201194,0x7ae80978,0xb60002d2}},	//   зея_, _توشی, qvet, _þáko, 
   {{0x7afc2771,0x37a80137,0xeb8801af,0x00000000}},	//   ästu, штүн_, _крәҫ_, --, 
   {{0x1828034c,0x6c64002b,0x00000000,0x00000000}},	//   _وقتی_, _hṛṣy, --, --, 
   {{0x6c64002b,0x00000000,0x00000000,0x00000000}},	//   _kṛṣy, --, --, --, 
   {{0x3cdc006d,0xc8640597,0x12880345,0x27ec032e}},	// [18760] _कैसे_, _تطوي, زمای_, _ógna_, 
   {{0xc76400d1,0x6c64002b,0x00000000,0x00000000}},	//   _غايى, _mṛṣy, --, --, 
   {{0x764c000f,0xc6440137,0x3d14033f,0x6d9c025c}},	//   moby, _تئيى, तनों_, nħaż, 
   {{0x764c06e4,0xa064c80b,0xdb1800d8,0x80240330}},	//   loby, паха_, rguê, ورنم, 
   {{0xc354004e,0x59a80073,0x00000000,0x00000000}},	//   _жъръ, चणार, --, --, 
   {{0x29084606,0x764c0083,0xfe4413de,0x00000000}},	//   øbak_, noby, وکلی, --, 
   {{0xdb18180f,0x61405ac1,0x621805d0,0x00000000}},	//   lguè, _зера, _פולק, --, 
   {{0x32090ba1,0xef84166f,0x918400cf,0x764c02f0}},	//   _hoby_, _хлап, _رۇچۇ, hoby, 
   {{0xa0650ba2,0xef184fe8,0xdb182508,0x764c01f1}},	//   _хата_, _ума_, nguè, koby, 
   {{0x6da50ba3,0x7de40597,0xdb18067c,0x6c6400b8}},	//   _хижа, _يسلم, iguè, _dṛṣy, 
   {{0x2d9c00e4,0x764c21ed,0x6d9c0135,0x32a80150}},	//   _iete_, doby, għaż, _ﺷﻪﮔﻪ, 
   {{0x2d9d0ba4,0x29000552,0x320800d7,0x00000000}},	//   _hete_, ćka_, _loby_, --, 
   {{0x2d9d0ba5,0x764c0223,0xe66400a7,0x97a401c6}},	//   _kete_, foby, зтво, эрэл, 
   {{0x2d9d0ba6,0x29e0031c,0x764d0ba7,0x00000000}},	//   _jete_, _bħaż_, goby, --, 
   {{0x2d9d0ba8,0x00000000,0x00000000,0x00000000}},	//   _mete_, --, --, --, 
   {{0x69d90ba9,0xc2986c20,0x9d18008f,0x1338001f}},	//   lete, жках_, זולט, _በመጽሐ, 
   {{0x764c1347,0xd51401d3,0x00000000,0x00000000}},	// [18770] boby, وظہب, --, --, 
   {{0x2d9c052f,0x216442c6,0x388402b5,0x59cc87ea}},	//   _nete_, птег, _hēra_, त्पर, 
   {{0x320802fd,0x29e00003,0x948400ee,0x25a00240}},	//   _doby_, _għaż_, _пыяд, majl_, 
   {{0x69d90baa,0x2d9c0421,0xa424074d,0x92bc03d4}},	//   hete, _aete_, _хьол, _আনৰ_, 
   {{0x69d90bab,0xa2a44425,0x2d9d0bac,0x51a810a8}},	//   kete, _चिट्, _bete_, زدەپ_, 
   {{0x2d9c0b91,0x69d90bad,0x00000000,0x00000000}},	//   _cete_, jete, --, --, 
   {{0x2d9d0bae,0xd0d40c04,0x63380092,0xbcc40124}},	//   _dete_, _поръ, _በመጠበ, ьӡал, 
   {{0xdb190baf,0x388402b1,0x61e50bb0,0x63bc0399}},	//   lgué, _nēra_, _hajl, ngqn, 
   {{0x2d9d0bb1,0x61e50bb2,0x9f5c0270,0x60c4010a}},	//   _fete_, _kajl, _fouá_, _hqjm, 
   {{0x69d90bb3,0xdb190bb4,0x2d9d0bb5,0xf8a84408}},	//   gete, ngué, _gete_, овок_, 
   {{0x61e50bb6,0x8d7413bd,0x764c0306,0x00000000}},	//   _majl, _كاما, voby, --, 
   {{0x2d9c07ab,0xf090008f,0x61e50bb7,0x69d8003a}},	//   _zete_, כנט_, _lajl, aete, 
   {{0xf7706ca1,0x2d9d0bb8,0x764d0bb9,0x69d90bba}},	//   ضاح_, _yete_, toby, bete, 
   {{0x69d90bbb,0x61e50bbc,0x20c407dd,0xc60c012c}},	//   cete, _najl, kõi_, _सकृय_, 
   {{0x764d0bbd,0x32090bbe,0x37e44cd0,0x601006be}},	//   roby, _roby_, _жойг, _eçmi, 
   {{0x764c0a49,0x36680107,0x999400e5,0x00000000}},	//   soby, саҳо_, _بھکر_, --, 
   {{0x61e50bbf,0xa6e04dbb,0x25a00327,0x00000000}},	// [18780] _bajl, _ажыл, bajl_, --, 
   {{0x61e40009,0xdb190793,0xa24415bf,0xb4700133}},	//   _cajl, rguè, ورلۇ, _ڤێرژ, 
   {{0x2d9d0bc0,0xb4640c56,0x25e40d5f,0x61e50bc1}},	//   _rete_, _окол, _छोटी_, _dajl, 
   {{0x69d90bc2,0xdb180005,0x61e4005a,0xa2a408df}},	//   zete, agué, _eajl, _चिच्, 
   {{0x69d90bc3,0x61e50bc4,0x81bc015b,0x2d9d0bc5}},	//   yete, _fajl, _আসর_, _pete_, 
   {{0xd04c03be,0x61e50bc6,0x69d90bc7,0x2d9d0bc8}},	//   _əhəm, _gajl, xete, _qete_, 
   {{0x2d9d0bc9,0xe61c007f,0x00000000,0x00000000}},	//   _vete_, mpôt_, --, --, 
   {{0x69d90bca,0x2d9d0bcb,0x61e401ed,0xa06404b3}},	//   wete, _wete_, _zajl, _жаса_, 
   {{0x2d9d0bcc,0x388402b5,0xee385788,0xe4540375}},	//   _tete_, _rēra_, _дна_, ויקט_, 
   {{0x6ffc0311,0x69d80165,0x38840171,0xf8ac01e2}},	//   _făcâ, uete, _sēra_, څکي_, 
   {{0x69d90bcd,0x3884f987,0x7afc0621,0x6e4000d1}},	//   rete, _pēra_, ästr, _كۆچم, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x25a00427,0x38840171,0x00000000,0x00000000}},	//   tajl_, _vēra_, --, --, 
   {{0x7afc7c1d,0x69d90bce,0x388402b1,0x00000000}},	//   åste, qete, _wēra_, --, 
   {{0x81bc015b,0x388402b1,0x61e50bcf,0x0cdc085c}},	//   _আসল_, _tēra_, _rajl, _मनोम, 
   {{0x69c85b67,0x57a40588,0x7aec02f0,0x20c4000d}},	//   त्री, _ишьа, _šati, või_, 
   {{0x61e50bd0,0x53350bd1,0xe664004e,0x787c0419}},	// [18790] _pajl, ветт, _отоо, rávň, 
   {{0x42541e4b,0x61e4031c,0x00000000,0x00000000}},	//   رنار, _qajl, --, --, 
   {{0xdb185e45,0x61e50bd2,0x4f0800d1,0xdeb81ef7}},	//   rgué, _vajl, ېتىپ_, ተወን_, 
   {{0x61e40784,0x20c40022,0xe86c0240,0x00000000}},	//   _wajl, rõi_, _ባህሪኡ_, --, 
   {{0x26c83e1d,0x3ea80c6a,0x63a803b2,0x00000000}},	//   ntco_, éat_, ógnu, --, 
   {{0xe61c00d8,0xdbc40139,0x61e40200,0x8e0800d4}},	//   mpôs_, _köçq, _uajl, мнів_, 
   {{0xbd4400db,0x00000000,0x00000000,0x00000000}},	//   رچئي, --, --, --, 
   {{0x6cd00f54,0x388400ef,0x00000000,0x00000000}},	//   اقيا, _bērn_, --, --, 
   {{0xfbd00014,0x201c0194,0xf1c411a0,0x00000000}},	//   نتک_, _ilui_, र्कन, --, 
   {{0xe9a4278f,0xce940107,0x6d6800f1,0x00000000}},	//   ىگىن_, _рафъ, _کلمې_, --, 
   {{0xe8c4009d,0xe9a50bd3,0x6fe000fe,0xf8a801f9}},	//   нгэл_, رگون_, ফাৰে, कळेप, 
   {{0x628c1d55,0x0b5002e3,0xeb8c0114,0x00000000}},	//   _otco, ịkọl, _љи_, --, 
   {{0xc5e80154,0xeb940798,0xe9cc01af,0x00000000}},	//   খানা_, _џиш_, _йк_, --, 
   {{0xa2c0000d,0x00000000,0x00000000,0x00000000}},	//   िंन्, --, --, --, 
   {{0x33f50bd4,0x628c02d0,0x3ebc01f5,0xc98400f3}},	//   нчас, _atco, huwt_, _ручи, 
   {{0xdb1801a4,0x36c4030d,0x00000000,0x00000000}},	//   nguï, _збиг, --, --, 
   {{0x0cdc00cd,0x00000000,0x00000000,0x00000000}},	// [187a0] _मन्म, --, --, --, 
   {{0x80c800bd,0x201d0bd5,0x7afd0bd6,0xef1801c6}},	//   রবন্, _alui_, østy, үмж_, 
   {{0x99840618,0x7bcc0086,0x3ebc01a4,0x628c0334}},	//   _nonō_, _ñauw, euwt_, _etco, 
   {{0x628ce0f2,0x59cc0882,0x6f00004e,0x37dc03d4}},	//   _ftco, त्तर, txoc, যাকৰ, 
   {{0x628c0175,0x201c054e,0xbe800131,0x02c407a5}},	//   _gtco, _dlui_, иқти, _иқти_, 
   {{0x201d0bd7,0xc17400db,0x00000000,0x00000000}},	//   _elui_, ردەت, --, --, 
   {{0x201d0bd8,0x4bc401c6,0xe0d4262e,0x00000000}},	//   _flui_, вөлг, _пвр_, --, 
   {{0x201c01e4,0x3884005f,0x00000000,0x00000000}},	//   _glui_, _pērn_, --, --, 
   {{0xef180153,0x00000000,0x00000000,0x00000000}},	//   _эма_, --, --, --, 
   {{0x99840421,0xdb1c0d4e,0x00000000,0x00000000}},	//   _fonō_, évár, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x99610bd9,0x6d580309,0x26c80810,0x9be001ec}},	//   ытыл, _iyta, ttco_, _бішк, 
   {{0x6d580209,0x00000000,0x00000000,0x00000000}},	//   _hyta, --, --, --, 
   {{0x7e7d0bda,0x6d590bdb,0x26c80077,0x00000000}},	//   _èspe, _kyta, rtco_, --, 
   {{0x53340046,0xb8e402dd,0x3a38067c,0x26c86a36}},	//   ңест, _асық, èspe_, stco_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xba040023,0x57b4005b,0x6d580064,0x6a6408a5}},	// [187b0] _ጎቦ_, _сбыт, _lyta, aðfe, 
   {{0xbbdcd2b9,0xa50402d5,0xe61c00d8,0x6d5803ac}},	//   _मस्क, _зямл, rpôs_, _oyta, 
   {{0x201c04cc,0x6d580158,0xe61c00d8,0x00000000}},	//   _plui_, _nyta, spôs_, --, 
   {{0xa3b85345,0x3f14010b,0x00000000,0x00000000}},	//   _घाट_, кдес, --, --, 
   {{0x6d590bdc,0xb3c80eac,0xe7d007b7,0x93f400c0}},	//   _ayta, _লোকজ, ध्यप, _спяц, 
   {{0x6d5810d1,0xed5c00d7,0x00000000,0x00000000}},	//   _byta, _žľab_, --, --, 
   {{0x6d590bdd,0x4fc40131,0xbc680451,0x00000000}},	//   _cyta, _әсса, ومتن_, --, 
   {{0x201d0bde,0x7c2c00d0,0x6d580200,0x6f740137}},	//   _ului_, ďaro, _dyta, رەەر_, 
   {{0xaf5400c7,0x7e7400ee,0xf7d000d1,0x3cdc000d}},	//   _антә, _агах, ﭘﻪﻧﺪ, _कईके_, 
   {{0x3ead0bdf,0x6ef001e1,0x00000000,0x00000000}},	//   _ivet_, _àtiṣ, --, --, 
   {{0xf1c41d72,0x3ead0be0,0xab6000ee,0x69a0033f}},	//   र्टन, _hvet_, çüri, _ग़री, 
   {{0x6cb10be1,0xdb1809c2,0xa6d8009e,0x3eac00d0}},	//   _төшт, lguí, দিনট, _kvet_, 
   {{0x60104e7e,0x9f48013d,0x00000000,0x00000000}},	//   _uçmu, _ämät_, --, --, 
   {{0x69c401d3,0x00000000,0x00000000,0x00000000}},	//   őker, --, --, --, 
   {{0xe5a10be2,0x64a00588,0x3f8c0036,0xddd839e4}},	//   риси, иара, _ofeu_, _otuž, 
   {{0x3eac2f12,0xe8d40375,0x6a6406ea,0x84580108}},	//   _ovet_, _יוצר_, rðfe, ерут_, 
   {{0xe2810be3,0xf62400c0,0x00000000,0x00000000}},	// [187c0] илти, _адпо, --, --, 
   {{0x0a200020,0x311406ed,0x00000000,0x00000000}},	//   _ስለሚያ, кфес, --, --, 
   {{0x3eac004e,0xdfcc0451,0xa5b4008f,0x00000000}},	//   _avet_, ڪين_, _בליק_, --, 
   {{0xf1c444af,0x6d580006,0xdfcc007b,0x70d00037}},	//   र्जन, _ryta, قيم_, _सहील, 
   {{0x6d590be4,0xdfcc9f43,0x3eac60c0,0x87ac008f}},	//   _syta, تين_, _cvet_, לשאַ, 
   {{0x6d590be5,0x81a4066d,0x3f8c324c,0x37d4015b}},	//   _pyta, _محفل, _efeu_, _তোমর, 
   {{0x3ead0be6,0x7f490be7,0x30740967,0x6ce40046}},	//   _evet_, _exeq, _ауас, тіле, 
   {{0x6d590be8,0x59cc00dc,0xad2c00b7,0xdb180022}},	//   _vyta, त्सर, _እንግዶ, aguí, 
   {{0xdee10be9,0x49a41669,0x6da40124,0xa3b800af}},	//   _коти, лынғ, _аиза, _घाघ_, 
   {{0x7afc4bc1,0x2d880112,0x6d58012d,0x6cd4007b}},	//   åsta, _übe_, _tyta, _لقطا, 
   {{0x21b80302,0x6d580784,0x7afc01e4,0x00000000}},	//   וזיא, _uyta, ĥsta, --, 
   {{0x25a428b5,0x00000000,0x00000000,0x00000000}},	//   _žnl_, --, --, --, 
   {{0x3eac05c7,0x00000000,0x00000000,0x00000000}},	//   _xvet_, --, --, --, 
   {{0x70d005f9,0x56950bea,0xca440131,0x00000000}},	//   _सहूल, рарт, ﺘﯩﺶ_, --, 
   {{0x55582e3f,0x7bd40022,0xd90d0beb,0x94a80ce8}},	//   варя_, _ÿguá, _ть_, ктта_, 
   {{0x9cd4011a,0x00000000,0x00000000,0x00000000}},	//   כולה_, --, --, --, 
   {{0x6b9400c7,0x59cc00cd,0x67d00b01,0xc30800eb}},	// [187d0] _õygu, त्वर, _боқу, _রেজি_, 
   {{0x26d80477,0xddd81d55,0xe4a401d5,0x00000000}},	//   _ipqo_, _stuž, _ирмо, --, 
   {{0x3ead0bec,0xd4980276,0x3e6800d0,0x00000000}},	//   _svet_, _иря_, núte_, --, 
   {{0xa2c003f3,0x50650bed,0x00000000,0x00000000}},	//   िंद्, атча, --, --, 
   {{0x4fc4005e,0xd3780117,0x3444014b,0x00000000}},	//   شەلە, _ачр_, _сӯри_, --, 
   {{0x645c8957,0x3eac05c7,0x0dc80114,0xada00166}},	//   llqi, _vvet_, вући_, башл, 
   {{0xed550bee,0x6da0034b,0xdb190bef,0x3f8c0327}},	//   лош_, щища, rguí, _tfeu_, 
   {{0x20f0071b,0x30d800c8,0x3f98032e,0x00000000}},	//   _ići_, _אַמע, _ýsu_, --, 
   {{0x3eb80744,0x00000000,0x00000000,0x00000000}},	//   _íst_, --, --, --, 
   {{0x20f00d0f,0xb9080166,0x39e801c6,0x7aec1155}},	//   _kći_, еноз_, хдоо_, _šats, 
   {{0x9ad001f2,0x8c3c00fd,0xd90c01b9,0xdeb80092}},	//   _gịnw, _avğu, تیغ_, ተገኘ_, 
   {{0x30d800c8,0x17c40588,0xc5e80375,0x8cd80b98}},	//   ײַטע, шамҭ, _מד_, _महतो, 
   {{0x38b8032e,0xdb0803b9,0x00000000,0x00000000}},	//   _býrð_, _acgö, --, --, 
   {{0x2ab80302,0x741415f6,0x20f001a6,0xddd8025c}},	//   _נמצא, گورا, _oći_, _ntuż, 
   {{0x70d00c2e,0x232400c2,0x2be40183,0x38b8032e}},	//   _सहेल, ҳоти_, কাৰে_, _dýrð_, 
   {{0x7c2c0724,0x7414034e,0x59cc1d03,0xba3c00bc}},	//   _çorı, دورا, त्रर, jrůz, 
   {{0x2324361e,0x59a4000d,0x00000000,0x00000000}},	// [187e0] готи_, _ग़ार, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x645c010a,0x28a40b4c,0x00000000,0x00000000}},	//   blqi, कीपि, --, --, 
   {{0xca3801e4,0x00000000,0x00000000,0x00000000}},	//   ziĝ_, --, --, --, 
   {{0xaf34212d,0xef1801c0,0xc6480244,0xee3801c4}},	//   درات, эмд_, _سجیل_, ннд_, 
   {{0x6abc015b,0xca540150,0x00000000,0x00000000}},	//   ্বমো, _ﻋﻜﺎ_, --, --, 
   {{0x4c94023a,0x224400a7,0x00000000,0x00000000}},	//   шийс, _спри_, --, --, 
   {{0xe4f406bc,0x00000000,0x00000000,0x00000000}},	//   ुमति_, --, --, --, 
   {{0x67f8005b,0xca3801e4,0xabb000fb,0xe39401ec}},	//   _läjä, tiĝ_, _ғалә, _ﺘﺘﻴﺢ_, 
   {{0xe9e50bf0,0x8a1801c0,0xe8b00725,0x3e6800d7}},	//   уцио, тоос_, مەتج, túte_, 
   {{0xdd8c5767,0x7e7d0bf1,0x38b802d2,0x00000000}},	//   _رون_, _èspa, _rýrð_, --, 
   {{0x2fc4c643,0x27fc03f0,0xda6c01d9,0xca3801e4}},	//   ngog_, ñun_, _ہُن_, siĝ_, 
   {{0x6b810bf2,0x23b801e1,0x00000000,0x00000000}},	//   _igog, _làjà_, --, --, 
   {{0x7bcc0113,0x6aa00241,0x48c4010b,0xb68801f0}},	//   _ñaur, _iwof, _кәма, тиёҷ_, 
   {{0x6b80073c,0x69c80789,0xf8b40139,0x628001e4}},	//   _kgog, _icfe, _көя_, ĉnom, 
   {{0x94850bf3,0x375405db,0x68e80175,0x43948602}},	//   сырд, ọdụ_, _isfd, раас, 
   {{0x6b8024f0,0xfe140037,0x00000000,0x00000000}},	// [187f0] _mgog, _तकलस_, --, --, 
   {{0x45d419bb,0xe164007b,0xdb180022,0x00000000}},	//   _тоос, هداي, nguá, --, 
   {{0x6b810bf4,0x2d8c030d,0x6aa004ba,0x27280241}},	//   _ogog, dcfe_, _lwof, _fòné_, 
   {{0xa280c5a5,0x6b810bf5,0xdb1800e4,0x7c2c0419}},	//   _هیرو, _ngog, hguá, ďark, 
   {{0x44290bf6,0x388400e2,0xaf54035b,0x00000000}},	//   mha_, _pērk_, анцә, --, 
   {{0x6b810bf7,0xb2b80375,0x00000000,0x00000000}},	//   _agog, _במשר, --, --, 
   {{0x44280751,0x6aa0013b,0x20f0098d,0xfc04009b}},	//   oha_, _awof, _ući_, ипко, 
   {{0x44290bf8,0x3b8421f9,0x6aa01418,0x7afc143a}},	//   nha_, шлиг, _bwof, åsto, 
   {{0xba240058,0x3a242097,0xec1000cf,0x44290bf9}},	//   идик, имиг, تويد, iha_, 
   {{0xda2404a9,0x44280978,0x3e680162,0x6f8c0150}},	//   ايدۇ_, hha_, sútb_, _ﺟﯩﻌﺎ_, 
   {{0x44290bfa,0x388400b0,0xdb18004e,0xe9d4084c}},	//   kha_, _kēri_, sguà, шкэ_, 
   {{0x44290bfb,0x67f802f6,0x69c8003a,0x68e804ce}},	//   jha_, _räjä, _ecfe, _dsfd, 
   {{0x44290bfc,0xfaa48035,0xd90c066d,0x7c290bfd}},	//   dha_, _тало, تیں_, mher, 
   {{0x7c290bfe,0x44290bff,0xe5a0300e,0xaf74010f}},	//   lher, eha_, жири, יערס_, 
   {{0x44280084,0x9b400133,0xbb340092,0x00000000}},	//   fha_, _خۆکو, ርጋቸዋ, --, 
   {{0x7c290c00,0x91d800cd,0xe850009a,0x00000000}},	//   nher, न्नै, _ونود, --, 
  
   {{0x44f401e4,0x7c282305,0x00000000,0x00000000}},	// [18800] _eĥ_, iher, --, --, 
   {{0x44290c01,0x7c290c02,0x35680166,0x15b400d1}},	//   aha_, hher, _үрүн_, _دەسس, 
   {{0x7c290c03,0x7bd80a40,0x208412d7,0x950801ed}},	//   kher, _obwu, айхи_, _صفحے_, 
   {{0x8f840046,0xef190c04,0x7c290c05,0x798c0166}},	//   сқал, кме_, jher, _şawl, 
   {{0x23b80241,0xdb18035b,0x6398011a,0x63b001ee}},	//   _wàjà_, yguá, _בסכנ, _фәсх, 
   {{0x7bd90c06,0x7c288c58,0x00000000,0x00000000}},	//   _abwu, eher, --, --, 
   {{0x7c290c07,0x6aa002b9,0xafe47a83,0x614031aa}},	//   fher, _swof, _ковл, _дера, 
   {{0x7c290c08,0x6aa00d29,0x6ee4004b,0x1d040640}},	//   gher, _pwof, _پسرل, рећи_, 
   {{0x7af80042,0xcdd8004b,0x9b640022,0x00000000}},	//   _crwt, _مېشت_, ишьа_, --, 
   {{0xdd8c0058,0x44290c09,0xd3140220,0x90640131}},	//   _يوق_, zha_, лiкт, _ئۆچۇ, 
   {{0x44290c0a,0x7c290c0b,0x28a4146b,0x7af801a4}},	//   yha_, bher, _कौशि, _erwt, 
   {{0x7c290c0c,0x44290c0d,0x6aa0037e,0xeb98af9e}},	//   cher, xha_, _twof, _рид_, 
   {{0x4428c72e,0xa8600032,0x7af80142,0x28a4000d}},	//   vha_, йеүҙ, _grwt, _कौरि, 
   {{0x44290c0e,0xd5b80108,0x6fe000eb,0x00000000}},	//   wha_, исс_, ফায়ে, --, 
   {{0xd1e80020,0x5fd412cc,0xd5b83334,0x3e68a56b}},	//   መንት_, ण्डल, шся_, núta_, 
   {{0x44290c0f,0x00000000,0x00000000,0x00000000}},	//   uha_, --, --, --, 
   {{0x44290c10,0x1cbc0dd4,0x3e680124,0x00000000}},	// [18810] rha_, གངོ_, húta_, --, 
   {{0x44290c11,0xd1b8021f,0x7c2803bd,0x41840046}},	//   sha_, لاما_, zher, стағ, 
   {{0x44290c12,0x46147f05,0x75d40150,0x62900010}},	//   pha_, _نوکر, _ايپا, _žgoč, 
   {{0x44290c13,0x7c280023,0xfff80214,0xcfa40114}},	//   qha_, xher, دکست_, ошљи, 
   {{0x7c290c14,0x44390c15,0xdec80798,0x00000000}},	//   vher, _ims_, туел_, --, 
   {{0x7c290c16,0x6da003b7,0xc0c40022,0x3e6803b2}},	//   wher, пиша, _гәди, fúta_, 
   {{0x44385182,0x50480092,0x0dc8bf77,0x00000000}},	//   _kms_, ካከላች, ручи_, --, 
   {{0x443800af,0x40340801,0xfbd001b9,0xe1c40037}},	//   _jms_, _уебс, ستب_, _लाँघ, 
   {{0x44390c17,0x7c290c18,0x00000000,0x00000000}},	//   _mms_, rher, --, --, 
   {{0x7c290c19,0x44390c1a,0x959402d3,0x3e6800d2}},	//   sher, _lms_, ፍታትን_, búta_, 
   {{0x7c290c1b,0xe8f400a8,0x00000000,0x00000000}},	//   pher, блэ_, --, --, 
   {{0x7bd8bf65,0x4438030d,0x00000000,0x00000000}},	//   _ubwu, _nms_, --, --, 
   {{0x7bc801c8,0x9aa400db,0xfaa40120,0xddc001e4}},	//   mgeu, _ئنتە_, _ѓако, zonŝ, 
   {{0x7ae90c1c,0xd9400116,0xb994007b,0x00000000}},	//   mwet, _қеқи, _الغب, --, 
   {{0x7ae8b123,0xb22401ec,0xb8081063,0x00000000}},	//   lwet, ұмал, _ميثم_, --, 
   {{0x7bc81dd4,0x0e300882,0xb3850c1d,0x733415bf}},	//   ngeu, ṇḍav, слал, مىزا, 
   {{0x443801b8,0xe2944c0b,0x7bc8009f,0xb1442cc8}},	// [18820] _dms_, йат_, igeu, әнел, 
   {{0xd5b01973,0x7afc02f6,0x7bc90c1e,0xf5e8026b}},	//   _زہر_, ästy, hgeu, _смол_, 
   {{0x7ae90c1f,0x6a38008f,0x09ac0154,0x0594002b}},	//   hwet, נגעפ, _খামা, _nāṭy, 
   {{0x7ae90c20,0x00000000,0x00000000,0x00000000}},	//   kwet, --, --, --, 
   {{0x9ad000b4,0x7ae90c21,0xfbbc00bc,0x00000000}},	//   _dịkw, jwet, ोलनम, --, 
   {{0x7ae90c22,0x44380175,0xddc001e4,0x3e680124}},	//   dwet, _zms_, ponŝ, túta_, 
   {{0x7a2cff83,0x44390c23,0x21a005a2,0x7bc800a3}},	//   _kútf, _yms_, _хисм, fgeu, 
   {{0x7bc83386,0xe040010b,0xd1e80023,0x388400ef}},	//   ggeu, _енси, መንቲ_, _jēru_, 
   {{0x09ac00bd,0xdfcc7427,0x7ae8d78f,0x29840137}},	//   _খাবা, _سيل_, gwet, йынг, 
   {{0x98a40ab7,0xfe740116,0x7bc80098,0xf8ac4c8b}},	//   _aynı_, _дүч_, ageu, چکي_, 
   {{0xf8ac1ead,0xfca80271,0xab840798,0x00000000}},	//   نکي_, _نانو_, _лулк, --, 
   {{0x7ae90c24,0x27500023,0xf7440023,0x00000000}},	//   bwet, _ዘቕረበ, _ዘሕዝን, --, 
   {{0x44390c25,0x7ae90c26,0xa5500092,0x00000000}},	//   _rms_, cwet, _የትራፊ, --, 
   {{0x7afc04ce,0x4a7401d9,0x9f5c004a,0x00000000}},	//   æste, _بُتر, éréo_, --, 
   {{0xd49801c0,0x16350c27,0x7c38015d,0x388400de}},	//   йрт_, черя, _ymwr, _bēru_, 
   {{0x25bd0c28,0x4438004e,0x00000000,0x00000000}},	//   şul_, _qms_, --, --, 
   {{0x443800af,0x291ca5ee,0x59cc00dc,0xf318035b}},	// [18830] _vms_, lyta_, त्कर, антә_, 
   {{0x9ad0063f,0xb60400c0,0x00000000,0x00000000}},	//   _sịkw, gyšč, --, --, 
   {{0x44390c29,0x7ae80161,0x291d0c2a,0x798c00a2}},	//   _tms_, zwet, nyta_, _şawk, 
   {{0x44390c2b,0x7ae80142,0xfde00210,0x00000000}},	//   _ums_, ywet, फ़्फ, --, 
   {{0x6614009d,0x6e3801a9,0x291c003e,0x3da84eeb}},	//   _koxk, _bmtb, hyta_, акло_, 
   {{0x9294d808,0x661400e8,0x7c941677,0x291c0024}},	//   _харц, _joxk, ориц, kyta_, 
   {{0x6614005a,0x7ae90c2c,0x00000000,0x00000000}},	//   _moxk, wwet, --, --, 
   {{0x7ae90c2d,0xcce43baf,0x291c0006,0xfc30007b}},	//   twet, سسىي, dyta_, بحت_, 
   {{0x7bc820ef,0x30c40150,0xea845378,0x7ae84fa5}},	//   rgeu, _ءﻧﻮﻝ_, обыл_, uwet, 
   {{0x39444963,0xaa54575b,0xe9d40276,0x7bc80e89}},	//   жног, يليا_, окь_, sgeu, 
   {{0x7ae90c2e,0x8d840323,0x291c6fab,0xef2400a2}},	//   swet, _хууд, gyta_, _çüri_, 
   {{0x7ae80bd7,0x3dc802a8,0x81c00011,0x2d900010}},	//   pwet, ɗawa_, ্জি_, čnež_, 
   {{0x661401a4,0x7ae90c2f,0xabd801ec,0x00000000}},	//   _boxk, qwet, _ﺃﺤﻀﺎ, --, 
   {{0xe45c006a,0x291d0c30,0xf50457bf,0x38840171}},	//   _akö_, byta_, озго, _bērt_, 
   {{0x388400ef,0xc5681291,0x00000000,0x00000000}},	//   _cērt_, محفل_, --, --, 
   {{0xb464242f,0x3e680030,0x00000000,0x00000000}},	//   ікал, kúto_, --, --, 
   {{0x7a2c00d2,0x09ac0154,0x00000000,0x00000000}},	// [18840] _vútf, _খাতা, --, --, 
   {{0xfe644af1,0xe45c0793,0xc76401ec,0x28a40b67}},	//   _سگ_, _ekö_, _عايى, कीवि, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x307445b3,0x00000000,0x00000000,0x00000000}},	//   цузс, --, --, --, 
   {{0x291c033f,0x661406be,0x00000000,0x00000000}},	//   zyta_, _yoxk, --, --, 
   {{0x388400ef,0x5e3000ae,0x00000000,0x00000000}},	//   _jērs_, وّنا, --, --, 
   {{0x388400e2,0x00000000,0x00000000,0x00000000}},	//   _mērs_, --, --, --, 
   {{0x09b47f53,0x291c00e4,0x00000000,0x00000000}},	//   জ্ঞা, vyta_, --, --, 
   {{0x2d950c31,0x291cbcce,0x00000000,0x00000000}},	//   _дрес, wyta_, --, --, 
   {{0x291c824d,0x3870010b,0xf75c0092,0x00000000}},	//   tyta_, _ahyr_, _ማስፋፋ, --, 
   {{0xed590c32,0x00000000,0x00000000,0x00000000}},	//   _тож_, --, --, --, 
   {{0x8c141d4c,0x72881e38,0x291d0c33,0x98d8000d}},	//   ়োজন_, ማኖታዊ_, ryta_, _बहरए, 
   {{0x291d0c34,0x00000000,0x00000000,0x00000000}},	//   syta_, --, --, --, 
   {{0x291c7b33,0x09b4015b,0x00000000,0x00000000}},	//   pyta_, জ্জা, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69d8408b,0x41dc00dc,0xe7281e5a,0x388400ef}},	//   lfte, न्नस, _نسخو_, _vērt_, 
   {{0x833400a7,0x69d8208d,0x6614002e,0xc1b90c35}},	// [18850] чнах, ofte, _toxk, йлах_, 
   {{0x69d81a80,0x21642dbf,0x7afc0158,0x1a98010f}},	//   nfte, отег, åsti, יימע, 
   {{0x12c42302,0x69d80ba7,0xd25001ed,0x43950c36}},	//   كتەپ, ifte, ڑنے_, _нанс, 
   {{0x05a40133,0xec6400ec,0x10481436,0x00000000}},	//   _بشکێ, _سٿ_, оячи_, --, 
   {{0x3ea50c37,0x8ff8107f,0x60d80cf4,0xbea4487f}},	//   чилг, ترلر_, _ćumu, чалк, 
   {{0x69d801f5,0xd25801c6,0x4278010f,0x00000000}},	//   jfte, _дцс_, _לאָג, --, 
   {{0xc0c46590,0x604400c7,0xa2c00d79,0x00000000}},	//   _хәзи, _дхаз, िंक्, --, 
   {{0x7f9473b3,0x1ea801f7,0x00000000,0x00000000}},	//   _хаах, _نائي_, --, --, 
   {{0x69d90c38,0x9c1001f2,0x7a2c032e,0xa29c01f9}},	//   ffte, _lọgh, _lúte, खीच्, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x41dc0882,0x9c1001f2,0x644c033f,0x7a2c00d0}},	//   न्यस, _nọgh, _ojci, _núte, 
   {{0x3c443306,0x7c2c0232,0x69d90c39,0xc4d40150}},	//   _عَشِ, ďars, afte, _ﺘﺴﺘﻌ, 
   {{0xec105845,0x95800023,0x388400ef,0x00000000}},	//   _سوود, ናዕትን_, _pērs_, --, 
   {{0xa6e02242,0x7a2c002d,0xcb44010a,0x00000000}},	//   óðar, _búte, _юххи, --, 
   {{0x38840171,0x00000000,0x00000000,0x00000000}},	//   _vērs_, --, --, --, 
   {{0xdb080798,0xf5040107,0x00000000,0x00000000}},	//   _regê, озҳо, --, --, 
   {{0xa2c006ab,0x644c037e,0xb2248fdf,0xa2e001d5}},	// [18860] िंग्, _djci, пмал, нотд, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb080036,0x26cc007c,0x00000000,0x00000000}},	//   _begë, _ägor_, --, --, 
   {{0xc0a80a2c,0x00000000,0x00000000,0x00000000}},	//   تاكل_, --, --, --, 
   {{0xdb080023,0x2908a63c,0xc5b40137,0x69d801e3}},	//   _degë, ̣ba_, _эрөө, yfte, 
   {{0xe2950c3a,0xb63c037e,0xa7f80124,0x00000000}},	//   _хар_, _ａｍ_, moñe, --, 
   {{0x5d6002e8,0x716400be,0x00000000,0x00000000}},	//   нтъз, _راسك, --, --, 
   {{0xdb080240,0xde7400e5,0x00000000,0x00000000}},	//   _gegë, _ہینڈ_, --, --, 
   {{0x298802bf,0xaf2800d8,0xfaec01e2,0x00000000}},	//   йсно_, _ужаз_, لګو_, --, 
   {{0x2d950c3b,0x7afd0c3c,0x69d80e78,0xdb080129}},	//   _храс, æsta, ufte, _megè, 
   {{0xdca10c3d,0x69d90c3e,0xdb0800f2,0xda6c0116}},	//   _захи, rfte, _legè, _җя_, 
   {{0x7a2c002d,0x7c6406b3,0xc06c032e,0x00000000}},	//   _rúte, _قانل, _þátí, --, 
   {{0xdb0802e2,0x41dc17e6,0x69d80e78,0x23f40137}},	//   _negè, न्डस, pfte, үмгө_, 
   {{0xa7f90c3f,0xd684447e,0x00000000,0x00000000}},	//   doñe, еусп, --, --, 
   {{0x7a2c28f2,0x00000000,0x00000000,0x00000000}},	//   _fútb, --, --, --, 
   {{0x6d480208,0xe1f010e8,0xfc480051,0x00000000}},	//   _đoà, کسر_, hận_, --, 
   {{0xdb080036,0x00000000,0x00000000,0x00000000}},	// [18870] _regë, --, --, --, 
   {{0x26c90c40,0xdb090c41,0x9c1001f2,0x00000000}},	//   muco_, _degè, _tọgh, --, 
   {{0x212407ae,0x26c90c42,0xe08402dd,0x00000000}},	//   ánh_, luco_, سجاي, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa7f836ed,0x26c80113,0x61400174,0xdb08036e}},	//   coñe, nuco_, _bílø, _vegë, 
   {{0x645d0c43,0x63ad0c44,0xfce50c45,0x9c840419}},	//   loqi, _hecn, доко, _načú, 
   {{0x78500a28,0x26c90c46,0x3cf8033f,0x6284ddf1}},	//   hāva, huco_, ्में_, _iijo, 
   {{0x62850c47,0x628d0c48,0x26c80af2,0x645c3c0a}},	//   _hijo, _kuco, kuco_, noqi, 
   {{0x63ad0c49,0x62850c4a,0xd25000f1,0x00000000}},	//   _mecn, _kijo, _شنې_, --, 
   {{0x26c90c4b,0xdb08003e,0x645c014b,0x62850c4c}},	//   duco_, _jegé, hoqi, _jijo, 
   {{0x628d0c4d,0xdb0800dd,0xd90c034c,0x62850c4e}},	//   _luco, _megé, ایع_, _mijo, 
   {{0x63ac1730,0x62850c4f,0x41dc0882,0x645c0194}},	//   _necn, _lijo, न्तस, joqi, 
   {{0x09ac00bd,0x62840086,0xe9cd0c50,0xe73422c3}},	//   _খারা, _oijo, _ик_, дея_, 
   {{0xc8ec0c58,0x62850c51,0xdb08004e,0x7afc05ac}},	//   _ওপৰত_, _nijo, _regè, åstu, 
   {{0x628c5fcf,0x1ddc0882,0x645c01b9,0x33f50c52}},	//   _auco, प्यत, foqi, мчас, 
   {{0x628d0c53,0x26c80656,0xb828136b,0xdb08020c}},	//   _buco, buco_, _фоиз_, _pegè, 
   {{0x628d0c54,0xdb090c55,0x26c8003a,0x7e7c007f}},	// [18880] _cuco, _begé, cuco_, _èspw, 
   {{0x80c81c82,0x62850c56,0xb5c804fb,0xa7f80428}},	//   ৰবন্, _cijo, _بودم_, roñe, 
   {{0x62850c57,0x8704bd8e,0x3cf80034,0x628c0e89}},	//   _dijo, _قبیل, ्मों_, _euco, 
   {{0xa7f90c58,0x628c08e5,0x62840428,0xf8c406ff}},	//   poñe, _fuco, _eijo, _विनय, 
   {{0x628c1419,0x62850c59,0x7d0003ac,0x5f900063}},	//   _guco, _fijo, _arls, њишт, 
   {{0x62850c5a,0x1b1004c5,0x41dc00dc,0x764c5794}},	//   _gijo, িনাই_, न्दस, nnby, 
   {{0x32080204,0x764c0158,0x21650c5b,0x628c00e4}},	//   _inby_, inby, _жири_, _zuco, 
   {{0x78500882,0x62850c5c,0xbad801ec,0x00000000}},	//   yāva, _zijo, _ﺃﺴﺒﺎ, --, 
   {{0x7d0002d0,0x6284047e,0xdb180112,0xa0640902}},	//   _erls, _yijo, rauß, _цата_, 
   {{0x645c0818,0x628401d5,0xdb18002f,0x00000000}},	//   zoqi, _xijo, sauß, --, 
   {{0x645c08ca,0xda9001c0,0x48c400c7,0x00000000}},	//   yoqi, нгөө, хәла, --, 
   {{0x699c038e,0x26c90c5d,0x3ea8054e,0x00000000}},	//   _ख्री, tuco_, ţate_, --, 
   {{0x4ebc0729,0x63ac0114,0xe66402bf,0xb8d41fc4}},	//   _আঙুল, _recn, дтво, _चौ_, 
   {{0x78503a71,0x63ac011f,0x764c08fb,0x26c90c5e}},	//   rāva, _secn, gnby, ruco_, 
   {{0x62850c5f,0x628d0c60,0x767000b2,0x63ac04a7}},	//   _rijo, _suco, دگيء, _pecn, 
   {{0x62850c61,0x628d0c62,0xc2981fdf,0xdb0801ed}},	//   _sijo, _puco, зках_, _segé, 
   {{0x62850c63,0x645d0c64,0x94850c65,0x63ac6517}},	// [18890] _pijo, roqi, тырд, _vecn, 
   {{0x9c10063f,0x645c0140,0xf4280108,0x00000000}},	//   _kọch, soqi, _pvää_, --, 
   {{0x62850c66,0x216466b5,0xa3d40073,0x52740798}},	//   _vijo, фтаг, _साप_, туѓу, 
   {{0x628c00f3,0x6d44013f,0x645c0117,0x62850c67}},	//   _tuco, _ɛkat, qoqi, _wijo, 
   {{0x4428509f,0x62850c68,0xf2c001c0,0x670c1d68}},	//   mka_, _tijo, _бөхи, ामिक_, 
   {{0x44290c69,0x78740120,0x7a2c00e4,0x91840116}},	//   lka_, máve, _oúta, رجەم, 
   {{0x78750c6a,0x0d3c02d3,0x9c100521,0x403400f3}},	//   láve, _ክንፈል, _nọch, _зевс, 
   {{0x4428120d,0xa3d40dad,0x7cb8001f,0x7afc01bf}},	//   nka_, _साफ_, _ሊደረግ_, æsto, 
   {{0x44290c6b,0x8d742b09,0x787406ed,0x506400c7}},	//   ika_, _یاما, náve, _ртра, 
   {{0x44290c6c,0x5ff00075,0x7a2c032e,0x8f080354}},	//   hka_, _язғу, _búta, _юхса_, 
   {{0x44290c6d,0x3eac0399,0xa92001c6,0x7d0070a9}},	//   kka_, _hwet_, гдэл, _urls, 
   {{0xd1d4001f,0x787400bc,0x764c0042,0xcb0800ec}},	//   _ረዳት_, káve, wnby, _ڊيمن_, 
   {{0xbbbc0574,0x44281e15,0x78740120,0x3eac033b}},	//   ोलीक, dka_, jáve, _jwet_, 
   {{0x44290c6e,0x78750c6f,0xf6500597,0x3eac0295}},	//   eka_, dáve, ائح_, _mwet_, 
   {{0x44290c70,0x7c290c71,0xa504074d,0xa9650c72}},	//   fka_, oker, нера_, _пиша_, 
   {{0x1ddc00a5,0x3f8cbb8c,0xfbac00fe,0x41dc0bae}},	//   प्तत, _ngeu_, _গাঁত, न्सस, 
   {{0x7c283441,0x787406ed,0x38610c73,0x24780092}},	// [188a0] iker, gáve, mokr_, _በጥራት_, 
   {{0x7c281ae7,0xa7f8035b,0xddc400a2,0x00000000}},	//   hker, moña, _ülňe, --, 
   {{0x44280d62,0x7c290c74,0x6d44013f,0xa0a0141c}},	//   bka_, kker, _ɛkas, гахд, 
   {{0x44290c75,0x7c290c76,0x6498010f,0xa3d4a9ec}},	//   cka_, jker, _מיטה, _साय_, 
   {{0xc8ec2052,0x787406ed,0x7c290c77,0x52840124}},	//   _जन्म_, cáve, dker, _аҳаб, 
   {{0x7c290c78,0x3f8c521d,0x3eac033b,0x64400248}},	//   eker, _egeu_, _dwet_, _ìnir, 
   {{0x3da410f5,0xa3d4f059,0xf1b81870,0x7c28032e}},	//   тріб, _साम_, _ﻧﯘﻗﺘ, fker, 
   {{0x3eac0100,0x7c290c79,0x7a2c03f2,0x00000000}},	//   _fwet_, gker, _rúta, --, 
   {{0xbf600014,0x785000e2,0x7fd402dd,0xee38030d}},	//   _پۯوو, tāvn, _шірі, _ена_, 
   {{0x44290c7a,0x7c290c7b,0x7a2c00d0,0x3f8c0342}},	//   zka_, aker, _púta, ğmuş_, 
   {{0x44290c7c,0x78740120,0xaac02ef1,0x3eac0036}},	//   yka_, záve, _शिवक, _zwet_, 
   {{0x44290c7d,0x7c290c7e,0xe7cc02f5,0xdecc0092}},	//   xka_, cker, িজ্য, ጣጣኝ_, 
   {{0x56950c7f,0xa7f90c80,0x52bc0131,0xa3d407af}},	//   лаят, goña, _ﺧﻪﯞﻩ, _साब_, 
   {{0x44290c81,0x78750c82,0x7a2c011f,0xef0c0212}},	//   wka_, váve, _túta, рмi_, 
   {{0x17b00183,0x04c811f0,0x7a2c659a,0xa4040114}},	//   _কাৰি, ظوري_, _kútn, нџак, 
   {{0x44290c83,0x78740261,0x3e6843e9,0x00000000}},	//   uka_, táve, rúti_, --, 
   {{0x44290c84,0x2470044e,0xa3d47f1a,0x2be000dc}},	// [188b0] rka_, _ጸገማት_, _साठ_, क्यं_, 
   {{0x78750c85,0x51f8876e,0x7c2805f5,0x00000000}},	//   ráve, нную_, zker, --, 
   {{0x7c290c86,0x4184e17f,0x3ead0c87,0x7fd41fe2}},	//   yker, ттағ, _swet_, вілі, 
   {{0x3eac8b14,0x44280023,0x43950c88,0x78750c89}},	//   _pwet_, qka_, _шамс, páve, 
   {{0xdb0804ce,0x00000000,0x00000000,0x00000000}},	//   _udgø, --, --, --, 
   {{0x7c290c8a,0x4f580214,0xfbac00eb,0x00000000}},	//   wker, رجند_, _গাইত, --, 
   {{0x7c290c8b,0xf40000a8,0x3f8c04cc,0xd2500592}},	//   tker, _faţă_, _tgeu_, _انّ_, 
   {{0xa3e402ab,0x26d801a9,0x4ea401ec,0xed4c00cf}},	//   _मॉम_, _oqqo_, _әрта, تپى_, 
   {{0x26d8014b,0x3ed800c6,0x201c0393,0x92080055}},	//   _nqqo_, _زواج_, _ioui_, _upāñ, 
   {{0x201c030a,0x785000e2,0xaac0353b,0xcfbc0154}},	//   _houi_, tāvo, _शिरक, _ইউএন, 
   {{0x45f4003d,0x201c0421,0xf9880451,0x7c290c8c}},	//   _བལྟས_, _koui_, بندي_, pker, 
   {{0x201c6ede,0xaca800e5,0x7874013a,0x00000000}},	//   _joui_, _آپنے_, dávc, --, 
   {{0x201c03c1,0x2dc800cf,0x993011ca,0xdb180254}},	//   _moui_, _راەۋ_, _әфлә, nguü, 
   {{0x24880789,0xa7f80428,0x201c030a,0xc5f40395}},	//   _aicm_, roña, _loui_, лясъ, 
   {{0xdb0801ed,0x58046ecf,0x06b80133,0x5fb007b7}},	//   _megí, _бойғ, ونێک_, ुणाल, 
   {{0x201c0381,0xa7f8fd13,0x7a2c0030,0x741405af}},	//   _noui_, poña, _kúto, خورا, 
   {{0x2a6c2776,0xf4000356,0xb384009d,0xdb180022}},	// [188c0] _âmbâ_, _raţă_, тлал, yguý, 
   {{0xa3d414cf,0xa2e001b9,0x00000000,0x00000000}},	//   _साथ_, рофд, --, --, 
   {{0x3e683b1a,0x6abc05d7,0xd474136e,0x00000000}},	//   nútu_, _एट्र, _مضحک, --, 
   {{0xafa001ec,0x00000000,0x00000000,0x00000000}},	//   рқақ, --, --, --, 
   {{0x43750c8d,0xcf040124,0x00000000,0x00000000}},	//   _бурт, ыҟап, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x201d0c8e,0x7a2c00d0,0x4bc4ed20,0x6bd47b8f}},	//   _foui_, _pútn, гөлг, نتظر, 
   {{0xab846be2,0x7a2c00dd,0xeb0401c6,0xceb801af}},	//   купк, _búto, вчоо, _зәк_, 
   {{0xa03004a9,0x3a0801d5,0xa9c400f2,0x00000000}},	//   _ئىقت, ککنی_, پزخو, --, 
   {{0x6f00014b,0x6ab4009d,0x00000000,0x00000000}},	//   mvoc, нсүх, --, --, 
   {{0xd91411ed,0x2d9c00ca,0x290000b0,0x7a2c032e}},	//   вья_, _ifte_, ākao_, _tútn, 
   {{0x9b40e43b,0xa3d403e5,0x6d580789,0x7e7c007f}},	//   انیو, _साध_, _ixta, _èspr, 
   {{0x6f010c8f,0xe29c0ad9,0xdcec00df,0x28a400af}},	//   nvoc, _orða_, _ĉeĉe, कीजि, 
   {{0x6f00f1e5,0x6aa00270,0x7a2c0162,0x00000000}},	//   ivoc, _itof, _jútl, --, 
   {{0xa3d408f8,0xe9700131,0x32180332,0x00000000}},	//   _साद_, _خۇدد, djpy_, --, 
   {{0x78740232,0x3c300122,0x54541318,0xe29c03b2}},	//   rávc, _káva_, авст, _arða_, 
   {{0x2d9d0c90,0x24540135,0xe5c40b01,0x00000000}},	// [188d0] _ofte_, għma_, _исно, --, 
   {{0x2be00882,0x41b400c6,0x3c30035b,0x201c0165}},	//   क्तं_, امار, _máva_, _soui_, 
   {{0xdb0800bd,0x78741dee,0x6f00003a,0x00000000}},	//   _regí, láva, evoc, --, 
   {{0xdb08066d,0x2d9d0c91,0x7a380ca8,0x6aa00208}},	//   _segí, _afte_, _kùtù, _otof, 
   {{0x6d590c92,0x78750c93,0x6aa00b6f,0xc694008f}},	//   _axta, náva, _ntof, נאַ_, 
   {{0x9f4c0240,0xa7f80022,0xdb18000d,0x42a80092}},	//   legë_, koño, rguü, ላእክት_, 
   {{0x6aa0d10b,0xf3f404d3,0x16b00073,0x7a2c00d7}},	//   _atof, _شتێک, _झब्ब, _súto, 
   {{0x78741ab0,0xdb08b3d8,0x2d9d0c94,0x2dd000c7}},	//   káva, _negã, _efte_, ажәр, 
   {{0x6d590c95,0x9d20015b,0x78750c96,0xdd0003e0}},	//   _exta, বছেন_, jáva, ırık, 
   {{0x78740745,0x3c3001f1,0xb6a44eac,0x5a40036b}},	//   dáva, _dáva_, һимл, рмоғ, 
   {{0x23c007b7,0x00000000,0x00000000,0x00000000}},	//   षणाद, --, --, --, 
   {{0x1ddc726e,0xb6a50c97,0x6aa0036e,0x7a2c00d7}},	//   प्रत, лимл, _ftof, _túto, 
   {{0x44f40316,0x61e4010a,0x6a64041e,0x78750c98}},	//   _ať_, _objl, rðfr, gáva, 
   {{0xaf74008f,0x9f4c0798,0x7a2c02d2,0x27ec0205}},	//   טערס_, tegê_, _kútm, _ıgne_, 
   {{0xe5a0225f,0xa7f80077,0x78740022,0xc9840114}},	//   сиси, coño, aáva, _кући, 
   {{0x78750c99,0x850401d9,0xf1d001c6,0x00000000}},	//   báva, جوٲن, өөгө, --, 
   {{0xa95001d3,0xd2446ecf,0xe3f400db,0x00000000}},	// [188e0] _نہیں, амақ, دىقت_, --, 
   {{0xdb08004e,0x00000000,0x00000000,0x00000000}},	//   _megà, --, --, --, 
   {{0xa2e00046,0x35a40022,0x00000000,0x00000000}},	//   _қорд, _иаҿг, --, --, 
   {{0x6f010c9a,0xdfcc007b,0x00000000,0x00000000}},	//   tvoc, كيم_, --, --, 
   {{0x785000da,0x02c400fd,0x3e6803b2,0xeaf00037}},	//   tāvj, _кияү, júts_, _अनेत_, 
   {{0x6f00067c,0x00000000,0x00000000,0x00000000}},	//   rvoc, --, --, --, 
   {{0x6aa10c9b,0xf8c428d4,0xe804038e,0x787403f7}},	//   _stof, _विषय, षयमा_, záva, 
   {{0x787401d3,0xa3d401ad,0xd25000e5,0x2aa8004e}},	//   yáva, सलय_, _انڑ_, нтоо_, 
   {{0xa3d416f0,0x6da50c9c,0xfbd42d8f,0x2078010f}},	//   _सास_, _биза, _धारम, _טאלא, 
   {{0x78740232,0x1e810c9d,0xee3805f5,0x6d58a8cf}},	//   váva, _глум, _янз_, _txta, 
   {{0x7a2c04d7,0x6d58cc2f,0x98b4013d,0x00000000}},	//   _kútj, _uxta, ллэт_, --, 
   {{0x78750c9e,0x3e68067c,0x3c300588,0xbbe801b9}},	//   táva, búts_, _táva_, _لرهم_, 
   {{0x6aa10c9f,0xca140395,0x00000000,0x00000000}},	//   _utof, _вдлъ, --, --, 
   {{0x7874f9a7,0xe3bc00c7,0x569457f9,0xa3d40d2b}},	//   ráva, _moñe_, сарт, _साह_, 
   {{0x78750ca0,0x5558af2a,0x689000dd,0x98a00640}},	//   sáva, гаря_, _دیجئ, _лије, 
   {{0x787400d0,0xc7b800b8,0x00000000,0x00000000}},	//   lávn, bhīṇ, --, --, 
   {{0xb6c005f5,0xe3bc0124,0x0444013d,0x00000000}},	// [188f0] _мөрд, _noñe_, геңн, --, 
   {{0xa3d400e1,0x7afc0393,0x00000000,0x00000000}},	//   _साव_, æsti, --, --, 
   {{0xdb0800dd,0x00000000,0x00000000,0x00000000}},	//   _megá, --, --, --, 
   {{0x44c00006,0x7a2c0174,0xdb085955,0xc4640345}},	//   mė_, _rútm, _legá, _ئیرۆ_, 
   {{0x44c00953,0xb3b80302,0x787402f0,0x1ee4085b}},	//   lė_, _במרכ, kávn, اوتی_, 
   {{0x0dc8026a,0xdb081b08,0xf8c407d0,0x00000000}},	//   гући_, _negá, _विलय, --, 
   {{0x44c00953,0x78740232,0x9258acb9,0x24780092}},	//   nė_, dávn, _сарт_, _በእሳት_, 
   {{0xab900131,0x00000000,0x00000000,0x00000000}},	//   يلىغ, --, --, --, 
   {{0xeab4223c,0x4fc41586,0xdb0803b2,0x5a4000d1}},	//   айы_, _ысра, _begá, ймиғ, 
   {{0x44c00953,0x9f4c020c,0x9f5c00a2,0x00000000}},	//   kė_, jegé_, _onuú_, --, 
   {{0x8e840491,0x9f4c0066,0x44c00064,0xd5dc09ab}},	//   _الله, degé_, jė_, _बाबज, 
   {{0x44c002d5,0xdb180407,0xa7f8030a,0xec6c00d4}},	//   dė_, sguñ, loñj, _єп_, 
   {{0xeb8c1142,0x78503a71,0x377400fa,0x00000000}},	//   _фи_, nāvi, рынс, --, 
   {{0xe94404d3,0x44c000c0,0x00000000,0x00000000}},	//   اریی, fė_, --, --, 
   {{0x44c002d5,0x7e6c03a2,0x78500882,0x00000000}},	//   gė_, ïapy, hāvi, --, 
   {{0x88c40b24,0x00000000,0x00000000,0x00000000}},	//   _اتول, --, --, --, 
   {{0xa3d421bd,0xa3e400af,0x00000000,0x00000000}},	// [18900] _सार_, _मउर_, --, --, 
   {{0xe3bc0022,0x785048e1,0x44c00024,0x00000000}},	//   _roñe_, dāvi, bė_, --, 
   {{0xeaf01524,0x73e421ca,0xe3bc00eb,0x78740306}},	//   _अन्त_, _конз, _soñe_, návo, 
   {{0xaf04084c,0xe3bc002e,0xafe41eca,0x00000000}},	//   ипел, _poñe_, родл, --, 
   {{0x78740022,0x8cd8012d,0x00000000,0x00000000}},	//   hávo, नूनो, --, --, 
   {{0x78740030,0x942400d1,0x62480210,0x00000000}},	//   kávo, _ئوڭۇ, lżon, --, 
   {{0xdb080122,0x00000000,0x00000000,0x00000000}},	//   _regá, --, --, --, 
   {{0x78740030,0xe3bc00e4,0x60c0002d,0x1b0c03d4}},	//   dávo, _toñe_, ânme, িহনে_, 
   {{0xadb83a16,0x44c00006,0xdb0804d4,0x2be000dc}},	//   _لهذا_, zė_, _pegá, क्षं_, 
   {{0xdea001d3,0x00000000,0x00000000,0x00000000}},	//   _بیوی, --, --, --, 
   {{0xa3d40abd,0x78740745,0xdca00323,0xdb1803b2}},	//   _साल_, rávn, _дахи, sguð, 
   {{0x44c002d5,0x7a2d0ca1,0xab843740,0x17780092}},	//   vė_, _lúth, _кулк, _በሕዝቡ_, 
   {{0x24840100,0xdc38010f,0x00000000,0x00000000}},	//   _ènmi_, _בעאר, --, --, 
   {{0x44c00953,0xdb0800b5,0xe6650ca2,0x27fc4b16}},	//   tė_, _begæ, ртмо, žun_, 
   {{0x9f4c020c,0x244400c7,0xa50400d1,0x00000000}},	//   regé_, ахаг, جىزە_, --, 
   {{0x44c00006,0x94a8a19b,0xe3b04ce4,0x00000000}},	//   rė_, ртра_, ترس_, --, 
   {{0x44c002d5,0x59000135,0x98a80034,0x00000000}},	// [18910] sė_, _མནོས_, ącą_, --, 
   {{0x44c002d5,0xa6e009f3,0x7a2c00ae,0xe18801f7}},	//   pė_, óður, _cúth, نئان_, 
   {{0x92580b2c,0xc3c40209,0x7a2c00ae,0x15b801c6}},	//   шафт_, _гөзл, _dúth, _өвөө_, 
   {{0x7850198e,0xc4340214,0x31840116,0x7a2c0419}},	//   tāvi, _اکست, стуң, _pútk, 
   {{0x7a2c007b,0x787402f0,0x00000000,0x00000000}},	//   _fúth, závo, --, --, 
   {{0x14b80403,0x3c300022,0xc10400ec,0x00000000}},	//   _حدیث_, _pávo_, _ٿوري, --, 
   {{0x7a6801a9,0x00000000,0x00000000,0x00000000}},	//   ғинг_, --, --, --, 
   {{0xd05c013f,0x8fd4013d,0xa7f80156,0xd13000f1}},	//   _mprɛ, _дәшә, soñj, _کمې_, 
   {{0x6d5403e0,0x00000000,0x00000000,0x00000000}},	//   şyap, --, --, --, 
   {{0x787401ed,0x7a2d0ca3,0x0dc8009b,0x00000000}},	//   távo, _kúti, _вуци_, --, 
   {{0xa3d41889,0x60c0007b,0x78640334,0x39480120}},	//   सला_, ánmh, йкоз, узно_, 
   {{0x787402fb,0xa3e40807,0xd9f0000d,0x48e8000d}},	//   rávo, _मॉल_, _असकत_, _जहरो_, 
   {{0xbb840491,0x2b2800e5,0x29c8010e,0x00000000}},	//   _الشي, _مغوی_, _ỳaş_, --, 
   {{0xe5a01e51,0x00000000,0x00000000,0x00000000}},	//   зири, --, --, --, 
   {{0x2ba40316,0xe6410ca4,0x7a2cdd18,0x0a680114}},	//   síců_, черп, _núti, _трци_, 
   {{0x7a2c01e7,0xdeb80b82,0x4414117e,0xddc0013a}},	//   _súth, ደለን_, офут, konů, 
   {{0x0cd41a2a,0xf77001d3,0x6248033f,0xa6e003f2}},	// [18920] _धम्म, _ڈاک_, rżon, óðtr, 
   {{0xf77003ae,0x7a2c0413,0x25a80306,0x00000000}},	//   _واک_, _búti, čilí_, --, 
   {{0x30743cee,0x764d0ca5,0xc1000075,0xcfc00220}},	//   будс, miby, мүрл, _ﺯﻩﺭﺗ, 
   {{0x764d0ca6,0x787400d0,0xddc00118,0x00000000}},	//   liby, kávm, fonů, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x764c00a9,0xdb190ca7,0x7a2d0ca8,0x00000000}},	//   niby, mauè, _fúti, --, 
   {{0x9f4c07c5,0x7174484d,0x80b000d1,0x00000000}},	//   legì_, _طهرا, _يەكش, --, 
   {{0x2580043b,0x1d040114,0x00000000,0x00000000}},	//   lélé_, сећи_, --, --, 
   {{0xfcbc0020,0x764c2c36,0x5b100500,0xfc480051}},	//   ደረገ_, kiby, змыт, vật_, 
   {{0xe3bc0724,0xdee00c60,0x00000000,0x00000000}},	//   _moña_, _хофи, --, --, 
   {{0x290806ed,0x7a2c00d2,0xe3bc0077,0xfe4404fb}},	//   íba_, _lútw, _loña_, _بکنی, 
   {{0xdb08049f,0xaae4004b,0xa3d407f7,0x290001e4}},	//   _begä, _هستو, _साइ_, ĉka_, 
   {{0x7c650ca9,0xdb080139,0x290801e4,0x00000000}},	//   _بالل, _cegä, ŭba_, --, 
   {{0xfcbc0020,0x764d0caa,0xdb08010e,0xe7d80825}},	//   ደረጉ_, giby, _degä, _भावप, 
   {{0x94a90cab,0xa54c0092,0x00000000,0x00000000}},	//   йтта_, _አድራጊ, --, --, 
   {{0x69d81f0c,0x7a2c4eb4,0xd8a400ec,0x00000000}},	//   lgte, _rúti, _اهيو_, --, 
   {{0xdee81b49,0x764c046a,0xe3bc09c2,0x69d80926}},	// [18930] ዘብን_, biby, _coña_, ogte, 
   {{0x69d90cac,0xe3bc3a64,0x1fb0102f,0x1b78008f}},	//   ngte, _doña_, ुण्ड, רטמע, 
   {{0x69d80332,0xe510000d,0x00000000,0x00000000}},	//   igte, _डपटि_, --, --, 
   {{0xdb08014a,0x41a8000d,0x00000000,0x00000000}},	//   _yegä, _च्रस, --, --, 
   {{0x44390cad,0x63bd0cae,0x25800085,0xd7fc008f}},	//   _ils_, maqn, bélé_, טהאל, 
   {{0x63bc0357,0x44390caf,0x00000000,0x00000000}},	//   laqn, _hls_, --, --, 
   {{0x4438020b,0x4034871a,0x00000000,0x00000000}},	//   _kls_, _девс, --, --, 
   {{0x69d80014,0x629c0140,0x63bd0cb0,0x764c767d}},	//   egte, oqqo, naqn, ziby, 
   {{0xb4d4ec76,0x764c0526,0x44390cb1,0xa3d401ad}},	//   _सम्_, yiby, _mls_, _साई_, 
   {{0xfcbc0020,0x443804cc,0x672c0034,0x69d83bba}},	//   ደረግ_, _lls_, dycj, ggte, 
   {{0x9424031c,0x4c9400c7,0x57940124,0x00000000}},	//   _ཤྭཀྱ_, _еихс, зыгӡ, --, 
   {{0x44381682,0x69d90cb2,0x764c0223,0x2a6c005a}},	//   _nls_, agte, wiby, _ekfb_, 
   {{0xdb090cb3,0x25800085,0x78740306,0x63bd0cb4}},	//   _begå, yélé_, lávk, daqn, 
   {{0x44390cb5,0xd060016b,0x00000000,0x00000000}},	//   _als_, _ɑwɑr, --, --, 
   {{0x764d0cb6,0x44390cb7,0xe3bc0005,0x7c38003e}},	//   riby, _bls_, _soña_, _klwr, 
   {{0xd5dc09d9,0xe3bc056a,0x9f4c05d5,0x764d0cb8}},	//   _बावज, _poña_, tegì_, siby, 
   {{0xb2249786,0x78740419,0xb544035b,0x00000000}},	// [18940] омал, hávk, сҧҟа_, --, 
   {{0x44390cb9,0x87040150,0x764c011f,0x7afc12e8}},	//   _els_, _ءبيل, qiby, åsty, 
   {{0x44390cba,0x629c0140,0x2580003e,0x61400107}},	//   _fls_, aqqo, rélé_, мефа, 
   {{0x78740232,0x44390cbb,0xdb18067c,0x7c3802d0}},	//   dávk, _gls_, pauè, _nlwr, 
   {{0x69d804ce,0xa25801f1,0x61f40036,0x2580020c}},	//   ygte, _kvôl, bexl, pélé_, 
   {{0x61f40076,0xeca40640,0x4c94470c,0x7a2c032e}},	//   cexl, ојин, пикс, _kútu, 
   {{0x672c068f,0xdd8c1ec7,0x44380334,0xab6000a2}},	//   zycj, نوه_, _yls_, _ýüzs, 
   {{0x7a2d0cbc,0x44383c36,0x2fd82444,0xa7f80005}},	//   _mútu, _xls_, _خورد_, poñi, 
   {{0xd1380092,0x00000000,0x00000000,0x00000000}},	//   _በሚበል, --, --, --, 
   {{0x298867f0,0x69d80112,0xfca800ec,0x00000000}},	//   исно_, ugte, _ڇانو_, --, 
   {{0x69d90cbd,0xbb50005e,0x2ee401a8,0x497455ee}},	//   rgte, ﺎﻟﻰ_, ltof_, ялос, 
   {{0x672c033f,0xa78001ec,0x00000000,0x00000000}},	//   tycj, _ﺭﻭﺭﺓ_, --, --, 
   {{0x44390cbe,0x78ac6c3c,0x2ee4054e,0x63bc014f}},	//   _rls_, _čave, ntof_, vaqn, 
   {{0x63bc02d1,0x7a2c02d2,0x00000000,0x00000000}},	//   waqn, _bútu, --, --, 
   {{0x63bc0357,0xe8740722,0xdb08143a,0x44380f85}},	//   taqn, _واعظ, _vegå, _pls_, 
   {{0xc3980212,0xdb180112,0x91b00051,0x00000000}},	//   скає_, nbuß, _đán_, --, 
   {{0x29000053,0x44390cbf,0x6e38035a,0x67440139}},	// [18950] ākau_, _vls_, _oltb, _фэйз, 
   {{0x44380113,0xf8ac0ec9,0x290c00f3,0x63bc636d}},	//   _wls_, _جکی_, _krfa_, saqn, 
   {{0xdb080a85,0x61f400fd,0x63bc03f0,0xb4f0010b}},	//   _begû, rexl, paqn, _пүрч, 
   {{0x63bc0357,0xa34401c0,0x6e382caa,0x290c009f}},	//   qaqn, _дэгл, _altb, _mrfa_, 
   {{0xdef81c31,0xe29c0ad9,0x7a2c02f0,0x60d4010a}},	//   рые_, _orði_, _zútu, suxm, 
   {{0x291c0227,0xdcec0cf4,0xef0c004b,0x78740306}},	//   kxta_, šečl, اټو_, távk, 
   {{0xe3bc005a,0x683c0036,0x3c3003b2,0x200800d8}},	//   _joño_, _këdd, _hávi_, _ócio_, 
   {{0x69c90cc0,0x787425f7,0xe3bc0407,0x6e380857}},	//   _adfe, rávk, _moño_, _eltb, 
   {{0x290d0cc1,0x683c00e8,0x291c0327,0xe45c032e}},	//   _arfa_, _mëdd, exta_, _mjö_, 
   {{0x39450cc2,0x78740306,0x00000000,0x00000000}},	//   зног, pávk, --, --, 
   {{0x7d790cc3,0x9f4c07c5,0x78750cc4,0x20c401e4}},	//   _امار_, legà_, lávi, nĵi_, 
   {{0xa3d49a28,0x290c009f,0xdb0801ed,0x69c80162}},	//   _साग_, _drfa_, _megú, _edfe, 
   {{0xdb0800dd,0x9f5c00b0,0x78740122,0xe9cc3417}},	//   _legú, _mauï_, návi, _пк_, 
   {{0x7a2c03b2,0xdb0c00c7,0x00000000,0x00000000}},	//   _pútu, _ñeño, --, --, 
   {{0xe3bc0154,0x99840418,0xa3d41431,0x7ae800f1}},	//   _coño_, _monū_, सलं_, _خوږې_, 
   {{0x21cc04fe,0x38a00332,0xa7a4010a,0x00000000}},	//   hēhē_, _iór_, _екъа_, --, 
   {{0xe29c008c,0x683c1bce,0xe2950cc5,0x38a00332}},	// [18960] _yrði_, _dëdd, зау_, _hór_, 
   {{0x38a10cc6,0x7a2c02d2,0x290c03cb,0x00000000}},	//   _kór_, _gútt, _yrfa_, --, 
   {{0x066410e0,0xe45c02d2,0x00000000,0x00000000}},	//   _تايپ, _fjö_, --, --, 
   {{0x38a00491,0x7a2c0af2,0x683c00e8,0xc32c0075}},	//   _mór_, _kúts, _gëdd, _ھەل_, 
   {{0x437400f7,0x7d00035a,0x63b800c5,0x2ee40793}},	//   _журт, _asls, _õuna, utof_, 
   {{0x78a0074d,0x2ee50cc7,0x00000000,0x00000000}},	//   kqlv, rtof_, --, --, 
   {{0x2ee48aad,0x7a2ccf34,0xdd910cc8,0x82b80327}},	//   stof_, _lúts, нашы, _བསོའ, 
   {{0xf8c436c7,0x2c780023,0xceb801af,0x00000000}},	//   _विजय, rëdo_, _дәк_, --, 
   {{0x7a2c002d,0x2d945016,0x7874003a,0xa6e408a5}},	//   _núts, _ерес, cávi, _miðö, 
   {{0x38a015c0,0x00000000,0x00000000,0x00000000}},	//   _bór_, --, --, --, 
   {{0x38a000ae,0x00000000,0x00000000,0x00000000}},	//   _cór_, --, --, --, 
   {{0x7a2c00d2,0x6bd40220,0xe3bc002e,0xddc00030}},	//   _búts, _ءتار, _roño_, monš, 
   {{0xe3bc1709,0x6a840724,0x683c0de2,0x82b80327}},	//   _soño_, _елда, _rëdd, _བསེའ, 
   {{0x38a01c38,0x7a2c0225,0x291c0bc9,0xe45cb625}},	//   _fór_, _dúts, pxta_, _sjö_, 
   {{0xe0d42158,0x78740232,0xe3b001ed,0x290000e2}},	//   _সন্ন, závi, ٹرز_, ākas_, 
   {{0xdb080005,0xdd38008f,0x3c3003b2,0x7a2c0332}},	//   _regú, זעלכ, _pávi_, _fúts, 
   {{0xdb090cc9,0x7a2c032e,0x00000000,0x00000000}},	// [18970] _segú, _tútt, --, --, 
   {{0x4ad40da8,0xddc001a2,0x17580375,0xe3bc09c2}},	//   _दिनव, konš, _מסחר_, _toño_, 
   {{0xe45c01c7,0x683c0de2,0x19ac02dd,0x00000000}},	//   _tjö_, _tëdd, _ﺳﺘﻴﻠ, --, 
   {{0x7f740276,0xddc00010,0x00000000,0x00000000}},	//   мулц, donš, --, --, 
   {{0xe6d8012c,0xa7f8030a,0xe3b402dd,0x644c0064}},	//   _बमोज, loñs, _мұң_, _imci, 
   {{0x78740122,0xe3bc030a,0x9f4c00cf,0x00000000}},	//   rávi, _heñ_, regà_, --, 
   {{0xa2ac00cc,0x00000000,0x00000000,0x00000000}},	//   _ছটিও, --, --, --, 
   {{0xe3bc002e,0x6b8002e3,0x1ea801c8,0x00000000}},	//   _jeñ_, _ọgan, _هائي_, --, 
   {{0xe3bc0598,0x657401e3,0x00000000,0x00000000}},	//   _meñ_, _lyxh, --, --, 
   {{0x38a10cca,0x7a2c000f,0x38705cf2,0xa7f80165}},	//   _pór_, _rúts, _skyr_, koñs, 
   {{0xa2580109,0x8c3c1ae4,0xda1c0490,0x00000000}},	//   _avôk, _buğd, बाबत_, --, 
   {{0xe3bc0724,0x38a003b2,0x00000000,0x00000000}},	//   _neñ_, _vór_, --, --, 
   {{0xa3d451a5,0x98740356,0x01d40154,0x4ad4000d}},	//   _साज_, _aţă_, স্যদ, _दियव, 
   {{0x7ae90ccb,0xf1b8001e,0xdb180ba1,0x19e40327}},	//   mtet, ươi_, nauí, _འཁྲབ, 
   {{0xe3bd0ccc,0xe5a0548a,0x82b8025c,0xa7f80165}},	//   _beñ_, тиси, _བསུའ, goñs, 
   {{0x99800953,0x7a2c000f,0x3eac054e,0x7ae85184}},	//   ųjų_, _túts, _otet_, otet, 
   {{0x7ae90ccd,0xe3bd0cce,0x9f5c0209,0x3eac03cd}},	// [18980] ntet, _deñ_, _onuñ_, _ntet_, 
   {{0x7ae90ccf,0x644c4a7d,0x4374016c,0x8c3c03e0}},	//   itet, _emci, хуст, _tuğg, 
   {{0x7ae90cd0,0x9c1001f2,0x291800cf,0x644c0175}},	//   htet, _jọsh, _àpat_, _fmci, 
   {{0xdfcd0cd1,0xe3bd0cd2,0x7ae90cd3,0x3c300122}},	//   ليم_, _geñ_, ktet, _kávu_, 
   {{0x7ae90cd4,0xe29c2833,0x24540327,0xdb0801e1}},	//   jtet, _guð_, għmu_, _tegù, 
   {{0x2d98174e,0xc4c40014,0xe3bc005a,0x7ae801d3}},	//   øpe_, _تتیو, _zeñ_, dtet, 
   {{0x9f4c0789,0x3e680030,0x6248033f,0x5ce018fd}},	//   regá_, núty_, eżow, نكول, 
   {{0xe29c03b2,0x3ea800df,0x64400064,0x00000000}},	//   _erðu_, ŭata_, _įnik, --, 
   {{0xae1c42e3,0x1ec4036b,0x7bc402b5,0x78ac0841}},	//   पादन_, _олти_, _ēhut, _čava, 
   {{0x1e807737,0x69f00137,0x00000000,0x00000000}},	//   _алум, түкт, --, --, 
   {{0xe3bc0165,0x787403b2,0x00000000,0x00000000}},	//   _doñj_, hávu, --, --, 
   {{0xe784190d,0x8c3c0166,0xd5dc000d,0x7c6400be}},	//   дуго, _buğe, _बाउज, _كانل, 
   {{0x7ae80483,0xe29c01a8,0x00000000,0x00000000}},	//   ctet, _yrðu_, --, --, 
   {{0x6b810cd5,0x56950cd6,0xe3bd0cce,0xa7f80165}},	//   _izog, каят, _señ_, toñs, 
   {{0x5694074d,0x644c0f85,0xe29c2507,0xa928003b}},	//   тарт, _pmci, _suð_, _філе_, 
   {{0x443c0034,0xe3bc0165,0xe29c0162,0xa7f805c7}},	//   ów_, _zoñj_, _orðt_, roñs, 
   {{0x78740579,0x9f5c0589,0xe3bc0165,0x3c3006ea}},	// [18990] gávu, _mauã_, _veñ_, _gávu_, 
   {{0x51f8046e,0x6b8001f7,0xe4a50cd7,0xe3bc0694}},	//   мную_, _mzog, _ормо, _weñ_, 
   {{0x7ae8d16e,0x3ead0cd8,0x5900031c,0xe3bc002e}},	//   ztet, _stet_, _མནབས_, _teñ_, 
   {{0x7ae90cd9,0x644c1cdf,0x6b810cda,0x6248033f}},	//   ytet, _umci, _ozog, yżow, 
   {{0x6b800eb4,0x4f5805d9,0xef2400a2,0x00000000}},	//   _nzog, وجهد_, _çüli_, --, 
   {{0x787400d7,0x00000000,0x00000000,0x00000000}},	//   lávt, --, --, --, 
   {{0x6b810cdb,0xba3c012c,0xdb180077,0xa2b8002b}},	//   _azog, způs, rauí, शीर्, 
   {{0xe3bc0dd4,0xfd64001e,0x9f5c0798,0xdef8fad8}},	//   _soñj_, _khuẩ, _cauã_, _мыз_, 
   {{0x3ead0cdc,0x3ed40150,0x7ae802f6,0xba3c0118}},	//   _utet_, _سقار, utet, dpůr, 
   {{0x7ae90cdd,0x6b80aa9e,0xe29c0008,0x3b0c0240}},	//   rtet, _dzog, _urðu_, rveq_, 
   {{0x7ae8dc18,0x6b806f16,0x00000000,0x00000000}},	//   stet, _ezog, --, --, 
   {{0x9b400014,0x7ae90cde,0xc5e800d9,0x00000000}},	//   _لۆبو, ptet, _לד_, --, 
   {{0x62840ac5,0xdbb400fb,0x00000000,0x00000000}},	//   _ohjo, _етһә_, --, --, 
   {{0x645c009a,0x06cc0150,0xa6e0041e,0x3e680419}},	//   enqi, _ﺑﻪﺗﻪ, áðas, túty_, 
   {{0xe29c032e,0x9f4c0166,0x00000000,0x00000000}},	//   _orðs_, legä_, --, --, 
   {{0x8c3c0166,0x62841ffa,0x69dc03e0,0x00000000}},	//   _tuğe, _ahjo, _öper, --, 
   {{0xfd6407ae,0x3d00028a,0x02c40137,0x00000000}},	// [189a0] _chuẩ, _वैसे_, китү, --, 
   {{0x62842b1d,0xe29c02d2,0xdbd801e1,0x78740174}},	//   _chjo, _arðs_, _láàf, rávu, 
   {{0x9f5c032e,0x00000000,0x00000000,0x00000000}},	//   _snuð_, --, --, --, 
   {{0xa0650cdf,0x80c000e1,0xf1e001bc,0x1fa401af}},	//   наха_, _लबरे, _पावन, екци_, 
   {{0x066404fb,0x00000000,0x00000000,0x00000000}},	//   _سایپ, --, --, --, 
   {{0x62840ba3,0x9f4c0166,0xad2400ae,0x00000000}},	//   _ghjo, degä_, فربو, --, 
   {{0x32080109,0x78740306,0x62603db7,0xed3401c6}},	//   _iaby_, návs, _свра, ээдэ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa06428e8,0x9f4c0139,0x00000000,0x00000000}},	//   _чата_, gegä_, --, --, 
   {{0xfe6c04fb,0x00000000,0x00000000,0x00000000}},	//   _وگو_, --, --, --, 
   {{0x6f00324c,0x32cc0150,0x00000000,0x00000000}},	//   lwoc, _ﺗﻪﮔﻪ, --, --, 
   {{0x9cd40bd4,0x2fc41c06,0x6b80007f,0xdd8c009f}},	//   _טובה_, naog_, _tzog, _طون_, 
   {{0x6b80e346,0xd83805f5,0xe664fedc,0x9ba80583}},	//   _uzog, хээ_, етво, _رخنہ_, 
   {{0x32080151,0x6aa00421,0x298400ee,0x2c1c00cd}},	//   _naby_, _iuof, _пыйг, भावं_, 
   {{0x9f5c0798,0xb8d40011,0x237c8a8a,0x42a80023}},	//   _mauá_, _ছয়_, _šuj_, ላጥነት_, 
   {{0x6aa10ce0,0x3208005c,0x6284022e,0x6f010ce1}},	//   _kuof, _aaby_, _shjo, kwoc, 
   {{0xc2990ce2,0x2fc50ce3,0x43945cf9,0x794002d3}},	// [189b0] дках_, daog_, таас, _ኣቦታት, 
   {{0x64640232,0x6aa10ce4,0x21650ce5,0xd24401c0}},	//   _špič, _muof, нтег, лэхи, 
   {{0x21650ce6,0xacc80064,0x00000000,0x00000000}},	//   хтаг, _дзiв, --, --, 
   {{0x26c90ce7,0x2d9c062c,0x50d401b9,0xfd640051}},	//   osco_, _agte_, ازلر, _thuẩ, 
   {{0x32090ce8,0x8f7402dd,0x26c80142,0x6284032e}},	//   _faby_, луші, nsco_, _thjo, 
   {{0x78740306,0x72a000d1,0x4ea473f6,0xdbd801e1}},	//   návr, _ئەلن, урца, _sáàf, 
   {{0x442802d5,0x78ac107d,0xdb080432,0x8d5402e8}},	//   oja_, _čavo, _degý, лтъч, 
   {{0x2d9c05e4,0x00000000,0x00000000,0x00000000}},	//   _egte_, --, --, --, 
   {{0x44290ce9,0xe7d87f90,0xbb4400f7,0x0ba81456}},	//   ija_, _भाजप, тепк, رايى_, 
   {{0x44290cea,0x6aa00522,0xdfd002dd,0x1be000c5}},	//   hja_, _duof, _шоғы, _गावल_, 
   {{0x44290ceb,0xbca400ec,0x26c8003a,0x0c24009d}},	//   kja_, _شمشي, esco_, тмөн, 
   {{0x44290cec,0xb6a428a9,0x6aa003c1,0x3af44421}},	//   jja_, кимл, _fuof, _аякс, 
   {{0xf0901a4c,0x7c290ced,0x6aa10cee,0xd97005f5}},	//   ינט_, mjer, _guof, _өвдө, 
   {{0x44280400,0xe9a01422,0xdb0800e5,0x869800d8}},	//   eja_, _кашп, _megü, етст_, 
   {{0x44290cef,0x26c80395,0x320805da,0xdb080036}},	//   fja_, asco_, _raby_, _ofgë, 
   {{0x4428438d,0x320801b8,0x51440220,0x683ca87b}},	//   gja_, _saby_, ңдағ, _tëda, 
   {{0x7c290cf0,0x71a40107,0x28100133,0x00000000}},	// [189c0] ijer, вазз, _ڵویس, --, 
   {{0x7c290cf1,0x44290cf2,0x8c3c00ac,0x32080009}},	//   hjer, aja_, _muğa, _qaby_, 
   {{0x44290cf3,0xc8780bcc,0x7c290cf4,0x01140816}},	//   bja_, luğa_, kjer, льцю, 
   {{0x442814cf,0x7c290cf5,0x78ac28b5,0xdb090cf6}},	//   cja_, jjer, _čavl, _begü, 
   {{0x7c290cf7,0xdee044e4,0xae1c146c,0x2fc40165}},	//   djer, иоци, पालन_, raog_, 
   {{0x6f010cf8,0x7c2800b5,0xdb081686,0xdd2800c0}},	//   rwoc, ejer, _legó, _dėže, 
   {{0x71750cf9,0x7c2800ed,0x6f010cfa,0x5cc10cfb}},	//   _شهرا, fjer, swoc, асыз, 
   {{0xdb0803b7,0x7c28f2ea,0xe3bc00e8,0x8c3c8411}},	//   _negó, gjer, _poñi_, _buğa, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x44290cfc,0x2d9c011f,0x7f7400a8,0x7c2800e4}},	//   zja_, _ugte_, _сусц, ajer, 
   {{0x7c286964,0x394823db,0x9f4c0627,0x668000f2}},	//   bjer, _ƙasa_, regå_, ییعل, 
   {{0x6aa01132,0xe3bc04d4,0x44280003,0x00000000}},	//   _tuof, _toñi_, xja_, --, 
   {{0x44290cfd,0xada0008c,0x49a401e0,0x6d480112}},	//   vja_, _þúsu, _йыйғ, lzfa, 
   {{0xc2100406,0x00000000,0x00000000,0x00000000}},	//   _डोंब_, --, --, --, 
   {{0x88582ecb,0x6f6c0882,0x18a01d39,0x98a00063}},	//   _пикс_, ḥkhā, _кајм, _кије, 
   {{0x8c3c0724,0x44280006,0x63b00022,0xc878008e}},	//   _yuğa, uja_, рааӡ, buğa_, 
   {{0xc87805d1,0xd6d819d8,0xe664009b,0x00000000}},	// [189d0] cuğa_, _итэ_, _атно, --, 
   {{0x44290cfe,0x7c283eb7,0xd1b90cff,0xdb0803e0}},	//   sja_, zjer, ناما_, _regü, 
   {{0xdb081daa,0x44290d00,0x7fd42a55,0xdfb0004b}},	//   _segü, pja_, гілі, لټاک, 
   {{0x4428069c,0x661803f9,0x7c280200,0x00000000}},	//   qja_, ɓuka, xjer, --, 
   {{0x7c28036f,0xdb08004e,0x10040395,0xb0340022}},	//   vjer, _legò, ряхм, ымцә, 
   {{0xc0c400d1,0x7c280083,0xdd280064,0x8ca4012d}},	//   _бәди, wjer, _vėže, _चूहो, 
   {{0x7c290d01,0xdb08068c,0xe3bc05c7,0x8c3c008e}},	//   tjer, _negò, _doñv_, _suğa, 
   {{0x5ba01f71,0xdb08013d,0xfc0400d8,0x00000000}},	//   шлиғ, _tegü, упио, --, 
   {{0x7c285c07,0x201c0869,0x98640882,0x5f74eaaa}},	//   rjer, _inui_, jñā_, _شارر, 
   {{0x7c290d02,0xa3d01a22,0xdb08004e,0x6c0400f7}},	//   sjer, हृत_, _segó, _ۅكمۅ, 
   {{0x9f5c0ba1,0x9bd000ec,0x7c280200,0x00000000}},	//   _bauç_, _نماڻ, pjer, --, 
   {{0x8c3c0724,0x7b140214,0x5fa8012c,0x3dc40042}},	//   _tuğa, _مبتذ, _छलफल, _helw_, 
   {{0xeaac0262,0x7bc90d03,0x22400010,0x1b0002dd}},	//   _ый_, maeu, _oljk_, _түпн, 
   {{0xf1e0038e,0x7bc90d04,0x9ba801d9,0x63a0013f}},	//   _पाइन, laeu, _رخچہ_, ɛnni, 
   {{0x201c0069,0x9f5c0561,0xf7702002,0x33f4fcdd}},	//   _onui_, _fauç_, شاڭ_, лчас, 
   {{0x7bc90d05,0xe8d40375,0x37e40120,0xc8780205}},	//   naeu, _עופר_, _соиг, puğa_, 
   {{0x998406c8,0xb38405f5,0x44140798,0x00000000}},	// [189e0] _manō_, улал, јфст, --, 
   {{0x7bc90d06,0x00000000,0x00000000,0x00000000}},	//   haeu, --, --, --, 
   {{0x735801e1,0x1cac031c,0x7bc800d5,0xf50401d5}},	//   _dídẹ, ྐམས_, kaeu, _ёзмо, 
   {{0xdb180120,0x7bc80098,0x4ad42122,0x00000000}},	//   cauç, jaeu, _दिलव, --, 
   {{0x7bc80097,0x00000000,0x00000000,0x00000000}},	//   daeu, --, --, --, 
   {{0x6d490d07,0x21a00209,0x236c000f,0x00000000}},	//   tzfa, _гирм, ûgje_, --, 
   {{0x6d4803fa,0x3dc40042,0x76f803d4,0x7534010f}},	//   uzfa, _delw_, ইটিছ_, טאַד_, 
   {{0x7bc90d08,0x5de00588,0x6d490d09,0xeb04009d}},	//   gaeu, ажәа, rzfa, гчоо, 
   {{0xdb0826b7,0xdfcc0451,0xef18e017,0x245ce9b1}},	//   _segò, _ريل_, _яма_, lämä_, 
   {{0xdd8c021a,0x4a542852,0x00000000,0x00000000}},	//   _کوم_, ркос, --, --, 
   {{0x7bc826fc,0xf1e0012c,0x6b580174,0x5e903592}},	//   baeu, _पाईन, _bøgø, _اللط, 
   {{0x7bc90d0a,0x9960008e,0x00000000,0x00000000}},	//   caeu, стьл, --, --, 
   {{0x8a700133,0x00000000,0x00000000,0x00000000}},	//   _وێبچ, --, --, --, 
   {{0x899401af,0x00000000,0x00000000,0x00000000}},	//   _килє, --, --, --, 
   {{0xdb080008,0x24880076,0x163402e8,0x00000000}},	//   _hegð, _phcm_, щеря, --, 
   {{0xf1e00316,0xc9840131,0x245c0139,0x00000000}},	//   _पाउन, _йуқи, dämä_, --, 
   {{0x28d8038e,0x57b4023a,0x24440037,0x92b4007b}},	// [189f0] _भिडि, _убыт, _nõme_, محلا, 
   {{0x7bc80393,0x68a001ec,0x63c000fb,0xb384010a}},	//   zaeu, _ﺍﻟﮕﻰ_, раҡҡ, ăлал, 
   {{0xdb08022c,0x78ac0e3c,0x7bc90d0b,0x92689131}},	//   _legð, _čavk, yaeu, урта_, 
   {{0x3f14a289,0x00000000,0x00000000,0x00000000}},	//   идес, --, --, --, 
   {{0xfe700ccb,0x7bc80418,0x3dc4009d,0x00000000}},	//   يدت_, vaeu, айлг, --, 
   {{0xc1040451,0x7bc80c6a,0xf1e000bc,0x00000000}},	//   _پوري, waeu, _पाएन, --, 
   {{0x51850d0c,0xb7e4813f,0x29180427,0x7bc90d0d}},	//   _гута, _कालम_, _špan_, taeu, 
   {{0x201c0262,0xfc3014e9,0x3dc50d0e,0x3ff800c8}},	//   _unui_, تحت_, _welw_, _שפּע, 
   {{0x7bc90d0f,0x28c000af,0x2ba4012d,0x78500055}},	//   raeu, वीसि, _ऑलरा, cāvy, 
   {{0x7bc90d10,0x00000000,0x00000000,0x00000000}},	//   saeu, --, --, --, 
   {{0xdb2004fb,0xc8b46559,0x5d641f5a,0x7bc8c92c}},	//   _گوشی, یلیک, _стаз, paeu, 
   {{0x25f802ab,0xe3bc0165,0x6c0400cf,0xddc000e5}},	//   _लॉबी_, _moñs_, _ۅكۅۅ, minő, 
   {{0x81dc2f8b,0xb6a401c0,0x8c3c05d1,0xdb2010e8}},	//   থ্য_, ригл, _muğl, _دوشی, 
   {{0xf6740120,0x68f0005c,0x00000000,0x00000000}},	//   румџ, øddæ, --, --, 
   {{0x55c401ec,0x64400153,0x6ca00150,0x00000000}},	//   _қанғ, _įnir, _ﻏﺎﻟﺏ_, --, 
   {{0xddcc0f91,0xf74800ae,0xc8b41699,0x00000000}},	//   šeňo, _للبي_, _اليک, --, 
   {{0xa8780a7c,0x00000000,0x00000000,0x00000000}},	// [18a00] _שאפר, --, --, --, 
   {{0xfe650d11,0x245c8b82,0xd2500133,0xddc00356}},	//   _رگ_, tämä_, سۆز_, vinş, 
   {{0x8c3c06be,0xe190002b,0x00000000,0x00000000}},	//   _buğl, _kāṃś_, --, --, 
   {{0x92680354,0x00000000,0x00000000,0x00000000}},	//   ăрта_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe3bc05c7,0xddc0054e,0x926410e8,0xa2bc0037}},	//   _foñs_, rinş, _اگرم, _लौट्, 
   {{0xdb082bde,0x2d9804cc,0x3f980174,0x7d0c0210}},	//   _segð, äpe_, _úsun_, łasn, 
   {{0x40940120,0x2164361e,0x4ad40037,0x00000000}},	//   _грут, _тиси_, _दिआव, --, 
   {{0x49a43e25,0xaa643542,0x4a540116,0x2c78002e}},	//   йынғ, иток, йкис, wëds_, 
   {{0xad58030d,0x00000000,0x00000000,0x00000000}},	//   _ирех_, --, --, --, 
   {{0xed043016,0x00000000,0x00000000,0x00000000}},	//   _خواپ, --, --, --, 
   {{0xbbe808f0,0x00000000,0x00000000,0x00000000}},	//   _مرهم_, --, --, --, 
   {{0xe7850d12,0x29010d13,0x44240208,0x38a0054e}},	//   руно, ňka_, _đl_, tărî_, 
   {{0xfd1001ed,0x5af808a8,0x3ea80162,0x00000000}},	//   _بجے_, _סלוצ, íati_, --, 
   {{0x94a90d14,0x59c002dd,0x3d18000d,0x00000000}},	//   итта_, _بيىك, भिये_, --, 
   {{0xe3bc0165,0xa7f80166,0x00000000,0x00000000}},	//   _roñs_, diñg, --, --, 
   {{0x28c00034,0x78ac3421,0x2d0001ad,0x26cc01e1}},	// [18a10] वीरि, _čavi, लबुल_, _ìgo_, 
   {{0xe4e4204c,0x3eb80064,0x00000000,0x00000000}},	//   _кімн, _įst_, --, --, 
   {{0x80f50d15,0x56940166,0x00000000,0x00000000}},	//   спех, _фаэт, --, --, 
   {{0xf36402d3,0x7d1401d3,0x506406a6,0x442c0037}},	//   _ተመኩሮ_, _ázsi, отча, _õe_, 
   {{0xa9dc009e,0x961801d3,0x6d5c2d37,0x73c000c7}},	//   ব্যঞ, _صغیر_, úpan, _хәсе, 
   {{0x386801e4,0x3f801da6,0x00000000,0x00000000}},	//   _ĉarm_, āhu_, --, --, 
   {{0x9258fdf0,0x4ac401ad,0x8c3c0790,0xdb18035b}},	//   _тарт_, लीसव, _tuğl, mbué, 
   {{0xdb0801d3,0xd0180166,0x2c1c00cd,0xa7f8010e}},	//   _megö, _кфу_, भागं_, niñd, 
   {{0xa2b80073,0xdb0800e5,0x00000000,0x00000000}},	//   शीच्, _legö, --, --, 
   {{0x0ca80588,0x4ea40114,0x00000000,0x00000000}},	//   ытәи_, _фрта, --, --, 
   {{0xdb080793,0x28c001ad,0xa7f80139,0x00000000}},	//   _negö, वीलि, kiñd, --, 
   {{0x80c801f9,0x00000000,0x00000000,0x00000000}},	//   हीये, --, --, --, 
   {{0x683c044e,0xec1003e6,0xeb8c0408,0x377401ec}},	//   _mëdh, _روود, _хи_, сынс, 
   {{0xdb08014a,0xfa68010b,0xaf74010f,0x00000000}},	//   _begö, _щалк_, מערס_, --, 
   {{0xf1c80232,0xe19000cd,0x00000000,0x00000000}},	//   ntáž_, _tāṃś_, --, --, 
   {{0xf3641772,0x38640de2,0x78741f0d,0xa7f800a2}},	//   _ተመክሮ_, _ñor_, _دُعا, giñd, 
   {{0x23250d16,0xc7b000e5,0x93640124,0x00000000}},	// [18a20] боти_, _تڑپ_, цнаҵ, --, 
   {{0xf1c802f0,0x00000000,0x00000000,0x00000000}},	//   ktáž_, --, --, --, 
   {{0xdb080112,0x21a06e1f,0xe614aec3,0x00000000}},	//   _gegö, чихм, _удэ_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb9100882,0xffa40032,0x00000000,0x00000000}},	//   rmaṃ_, әләү, --, --, 
   {{0xa7f90d17,0xf1e017ee,0x02c400fb,0x940401f7}},	//   miñe, _पाटन, _фирү, _اوڏه, 
   {{0x61e02880,0xa7f8056a,0x00000000,0x00000000}},	//   ónle, liñe, --, --, 
   {{0x63b80037,0x0c380114,0x00000000,0x00000000}},	//   _õunt, рзић_, --, --, 
   {{0xfaec004b,0xe8a00150,0xd1cc0023,0xfd640139}},	//   نګو_, _ﺍﻟﺘﻬ_, _ኣሓት_, йнәү, 
   {{0xa9280220,0x683c0023,0x09c8015b,0xdb0800d8}},	//   гіме_, _zëdh, _শাহা, _negõ, 
   {{0x627808a8,0xaa8002d2,0x00000000,0x00000000}},	//   רנינ, _íýms, --, --, 
   {{0x89d866df,0xa7f8005a,0x00000000,0x00000000}},	//   دوگر_, kiñe, --, --, 
   {{0x8690052f,0x212401fb,0xab94007b,0x00000000}},	//   мғиә, ̣nh_, _الشغ, --, 
   {{0x6b810d18,0xe664c928,0x683c0200,0x01cc00cc}},	//   _iyog, стмо, _mëdi, _লাভদ, 
   {{0x6b802165,0x69c90d19,0x7c380129,0xc8780139}},	//   _hyog, _iefe, _àcré, arğa_, 
   {{0x69c90d1a,0x6b800a49,0x00000000,0x00000000}},	//   _hefe, _kyog, --, --, 
   {{0x69c90d1b,0xa7f90d1c,0x00000000,0x00000000}},	// [18a30] _kefe, giñe, --, --, 
   {{0x69c90d1d,0x6b8057cf,0x224401d3,0x00000000}},	//   _jefe, _myog, ónk_, --, 
   {{0x69c90d1e,0xd5b850db,0x6b800337,0x6604009b}},	//   _mefe, _усы_, _lyog, mejk, 
   {{0x69c90d1f,0x753801cf,0x06ec02ab,0x6b810d20}},	//   _lefe, ätze, _जमाव_, _oyog, 
   {{0x69c82253,0x171c00c8,0xa7f8056a,0x6b810d21}},	//   _oefe, ָווע, ciñe, _nyog, 
   {{0x645d0d22,0x5bb004fa,0x69c90d23,0x62440050}},	//   liqi, ीर्व, _nefe, _آسہ_, 
   {{0x6b800c8a,0xd1b801d3,0x00000000,0x00000000}},	//   _ayog, _چاہا_, --, --, 
   {{0x6b810d24,0x69c90d25,0x645d0d26,0xf1c80122}},	//   _byog, _aefe, niqi, rtáž_, 
   {{0x69c90d27,0x6b800526,0x290c0077,0x660402fb}},	//   _befe, _cyog, _asfa_, kejk, 
   {{0x645c013e,0x6b800280,0x2c1c0073,0x228c0205}},	//   hiqi, _dyog, _मोठं_, büke_, 
   {{0x69c90d28,0x38290d29,0x6b80b23d,0x660402f0}},	//   _defe, ажно_, _eyog, dejk, 
   {{0x69c89f72,0x290c0332,0x00000000,0x00000000}},	//   _eefe, _dsfa_, --, --, 
   {{0x69c90d2a,0x7d000334,0x645d0d2b,0x6b810d2c}},	//   _fefe, _hpls, diqi, _gyog, 
   {{0x69c90d2d,0x660400ca,0x9f4c0789,0xaa840014}},	//   _gefe, gejk, legó_, _وۆٹم_, 
   {{0xe5a0a6cf,0x48e002e5,0x645c679e,0x43680092}},	//   дири, _कियो_, fiqi, _ተመረቀ_, 
   {{0x69c90d2e,0xa7f80998,0x645c0117,0x692800ac}},	//   _zefe, tiñe, giqi, rəet, 
   {{0x69c90d2f,0x660402f0,0x28980a7c,0xdb200139}},	// [18a40] _yefe, bejk, _דיקא, _üsäb, 
   {{0xa7f8172e,0x69c90d30,0x85542099,0x290c0042}},	//   riñe, _xefe, _کیفر_, _ysfa_, 
   {{0x60c40211,0x7bd8013f,0x00000000,0x00000000}},	//   _cwjm, _odwu, --, --, 
   {{0xef190d31,0x7bd8016b,0xa7f80005,0xef841422}},	//   име_, _ndwu, piñe, олеп, 
   {{0x9f4c5d7e,0x00000000,0x00000000,0x00000000}},	//   degó_, --, --, --, 
   {{0x7bd80605,0xe3bc0113,0x6b80037e,0x3f8c0356}},	//   _adwu, _inña_, _ryog, _dzeu_, 
   {{0x69c90d32,0xe0d40a83,0x6b810d33,0x216400ee}},	//   _refe, _мвр_, _syog, _дири_, 
   {{0x69c90d34,0x3c300122,0x6b801b25,0x683c002e}},	//   _sefe, _kávy_, _pyog, _tëdi, 
   {{0x69c80134,0x00000000,0x00000000,0x00000000}},	//   _pefe, --, --, --, 
   {{0x7bd8013b,0x645d0d35,0x6b8000ca,0xed590d36}},	//   _edwu, ziqi, _vyog, _коз_, 
   {{0x645d0d37,0x69c80489,0xad580cc9,0x4ba401ec}},	//   yiqi, _vefe, _трах_, _елең, 
   {{0x69b83156,0x69c90d38,0xdd8c06c2,0xf8ad0d39}},	//   _श्री, _wefe, _شون_, دکو_, 
   {{0x69c90d3a,0x66050d3b,0x6b810d3c,0x645c0023}},	//   _tefe, tejk, _uyog, viqi, 
   {{0x645c0113,0x00000000,0x00000000,0x00000000}},	//   wiqi, --, --, --, 
   {{0x66050d3d,0x645c094a,0x00000000,0x00000000}},	//   rejk, tiqi, --, --, 
   {{0xe2a82b9f,0x66040327,0x66c8030d,0x00000000}},	//   لائن_, sejk, _куог_, --, 
   {{0x645d0d3e,0x66040010,0x6d5d0d3f,0xc35400f0}},	// [18a50] riqi, pejk, úpaj, чкај, 
   {{0x645ce289,0x8c3c0139,0x75380e78,0x00000000}},	//   siqi, _duği, ätzc, --, 
   {{0x645c0113,0xf3640023,0xa7f80055,0x00000000}},	//   piqi, _ተዘክሮ_, ciñc, --, 
   {{0x645c036b,0x7d0c0210,0x00000000,0x00000000}},	//   qiqi, łask, --, --, 
   {{0x545417a1,0x44390d40,0x00000000,0x00000000}},	//   _цвят, _ios_, --, --, 
   {{0x44390d41,0x00000000,0x00000000,0x00000000}},	//   _hos_, --, --, --, 
   {{0x44390d42,0x6da0020a,0x1ee40133,0xada10d43}},	//   _kos_, ниша, _ژوری_, нашл, 
   {{0x8c3c013d,0xfbd000ae,0x00000000,0x00000000}},	//   _yuği, رتب_, --, --, 
   {{0x44390d44,0x9f4c0154,0xec4402e8,0x00000000}},	//   _mos_, regó_, язъл_, --, 
   {{0x44390d45,0x7e54036d,0x7bf80354,0x00000000}},	//   _los_, _عناص, _ӳнер_, --, 
   {{0x3eac04d1,0x44390d46,0xdc3c00d7,0x00000000}},	//   _huet_, _oos_, líčs, --, 
   {{0x3ea40072,0xf18c0150,0x64900200,0x5b3400ae}},	//   _hilt_, _ﺒﺭﻴﻤ_, nçid, _وعشر, 
   {{0x3ea50d47,0x764c0042,0x00000000,0x00000000}},	//   _kilt_, thby, --, --, 
   {{0x443810b4,0x3ea50d48,0x7c3800a2,0x3eacad4c}},	//   _aos_, _jilt_, _howr, _muet_, 
   {{0x7ae90d49,0x3ead0d4a,0xa9641bc4,0x7c3800a2}},	//   luet, _luet_, _ниша_, _kowr, 
   {{0x44390d4b,0x3ea50d4c,0x7c3800a2,0x764c1368}},	//   _cos_, _lilt_, _jowr, shby, 
   {{0x4438fafe,0x7ae90d4d,0x81bc02f5,0x2324009b}},	// [18a60] _dos_, nuet, _ইয়_, поти_, 
   {{0x44390d4e,0x7c390d4f,0xa7f90d50,0x8ccc000d}},	//   _eos_, _lowr, miña, _सबलो, 
   {{0x7ae90d51,0x765d0d52,0xef1805f5,0x3eac0036}},	//   huet, _impy, өмж_, _auet_, 
   {{0x7c390d53,0x3ead0d54,0x44390d55,0x7ae90d56}},	//   _nowr, _buet_, _gos_, kuet, 
   {{0x3ea44fa5,0xa7f80bc9,0xdfcc5230,0x683c0036}},	//   _bilt_, niña, ايه_, _gëdu, 
   {{0x44380457,0xb1446c4d,0x3ea403ee,0x7ae801c6}},	//   _zos_, _енгл, _cilt_, duet, 
   {{0x5ac50d57,0xa7f80227,0x4438dd3d,0xabb00075}},	//   _གསུམ, hiña, _yos_, найә, 
   {{0xa7f80054,0x44390d58,0x7c380731,0x3eac00db}},	//   kiña, _xos_, _cowr, _fuet_, 
   {{0xdee07696,0x3eac3ae2,0x7c390d59,0x3ea493e0}},	//   _поти, _guet_, _dowr, _filt_, 
   {{0x78ac62b3,0xa7f8eb82,0x3ea402c2,0xacb00228}},	//   _čavr, diña, _gilt_, _كەتب, 
   {{0x2d880241,0x00000000,0x00000000,0x00000000}},	//   _ábe_, --, --, --, 
   {{0x765d0d5a,0x7c390d5b,0x27fc0209,0x5f101a75}},	//   _ampy, _gowr, ýun_, _धनम्_, 
   {{0x44390d5c,0x6e380003,0x7ae80789,0xbebd0d5d}},	//   _ros_, _kotb, cuet, _grūd, 
   {{0x44390d5e,0xdb980375,0x3ea4022e,0x00000000}},	//   _sos_, _הסדר, _xilt_, --, 
   {{0x44390d5f,0x6e3878d0,0x29180588,0x99f80375}},	//   _pos_, _motb, _épa_, _הפופ, 
   {{0x765d0d60,0x6e380100,0x44390d61,0x00000000}},	//   _empy, _lotb, _qos_, --, 
   {{0x44390d62,0xa7f8172e,0x6e390d63,0xe7c000dc}},	// [18a70] _vos_, ciña, _ootb, _व्यप, 
   {{0xe600023a,0x3eac003a,0x52d8034b,0x2444000d}},	//   ätää, _ruet_, ямую_, _tõmo_, 
   {{0x44390d64,0x3eac3113,0x7ae8009d,0x74b000fb}},	//   _tos_, _suet_, zuet, _аҡсу, 
   {{0x44381730,0x3ea41405,0x66140175,0x8c3c03e0}},	//   _uos_, _silt_, _haxk, _kuğu, 
   {{0x3ea4007d,0xdef82ecb,0x3ead0d65,0x6e387566}},	//   _pilt_, сые_, _quet_, _botb, 
   {{0x3eac0369,0x7ae90d66,0x6e3801ab,0x6e2c026c}},	//   _vuet_, vuet, _cotb, _òbbl, 
   {{0x66140a81,0x3ea4148b,0x7c38068f,0xc8780259}},	//   _maxk, _vilt_, _powr, luğu_, 
   {{0x3ea40460,0x7ae90d67,0x2ab0026c,0xa7f80bc9}},	//   _wilt_, tuet, _bâb_, yiña, 
   {{0x2ca40368,0xa7f80077,0x41e000af,0x2444000d}},	//   _diod_, xiña, _पयास, _nõmm_, 
   {{0x3944c08e,0x7ae90d56,0xea840220,0x66140de2}},	//   дног, ruet, мбыл_, _naxk, 
   {{0x37e50d68,0xec10036b,0x2ca401f5,0x7c390d69}},	//   монг, روید, _fiod_, _towr, 
   {{0xa7f8094a,0x2ca405d5,0x765c020c,0x7ae801c4}},	//   tiña, _giod_, _smpy, puet, 
   {{0xba540801,0x6e380477,0xbc2400f7,0x00000000}},	//   _откъ, _yotb, _ىرچى, --, 
   {{0xc8780baf,0xa7f90d6a,0x0b4428f6,0x394801ef}},	//   duğu_, riña, _янін, _řasu_, 
   {{0xa7f82e95,0x00000000,0x00000000,0x00000000}},	//   siña, --, --, --, 
   {{0xa7f90d6b,0xfaf802b5,0xf77002e9,0x853401b9}},	//   piña, otū_, _لاخ_, روقچ, 
   {{0xd7650d6c,0xa7f80113,0xf2a42077,0x00000000}},	// [18a80] _سندی, qiña, диап, --, 
   {{0xe2940046,0x765c03ac,0x00000000,0x00000000}},	//   дау_, _umpy, --, --, 
   {{0x80c80073,0xe0cc0014,0x00000000,0x00000000}},	//   हीले, لٲل_, --, --, 
   {{0xa064d4de,0x6e38014f,0xc8787225,0x2420035b}},	//   маха_, _sotb, buğu_, _иҧсҭ, 
   {{0xc87803ee,0xafa02b8d,0x6e380af9,0x43740117}},	//   cuğu_, тқақ, _potb, _зурт, 
   {{0x228c2045,0x64640034,0x2ca401c3,0x6e380139}},	//   püka_, ąpił, _siod_, _qotb, 
   {{0x0ee005ba,0x7aec01e4,0x2ca40142,0x00000000}},	//   _निवड, _ĥata, _piod_, --, 
   {{0xd17402dd,0xdc841de6,0x00000000,0x00000000}},	//   _жығы, мсыл_, --, --, 
   {{0x2fc50d6d,0xf1b06a42,0x00000000,0x00000000}},	//   mbog_, _जलान, --, --, 
   {{0x2fc50d6e,0x49b40139,0x00000000,0x00000000}},	//   lbog_, хәду, --, --, 
   {{0x8c3c0139,0xbebc0171,0xf12401ec,0x7e7c0139}},	//   _suğu, _grūb, здiк_, _íspa, 
   {{0x24440254,0x2fc50d6f,0x427c0092,0x00000000}},	//   _põmm_, nbog_, ባሪነት_, --, 
   {{0x661481ed,0xd7d000b5,0x491002c3,0x00000000}},	//   _paxk, _mj部_, _तनवो_, --, 
   {{0x3eb8204e,0xe5dc0139,0xc87803e0,0x00000000}},	//   _éste_, _änüç, vuğu_, --, 
   {{0xb88400bc,0x6614007c,0xdb1803b2,0xc4a80118}},	//   _smíš, _vaxk, mbuá, कदेख, 
   {{0xd498a337,0xa7f8172e,0x66145284,0x88c40118}},	//   дру_, miño, _waxk, _vděč, 
   {{0x2fc404ce,0x97140022,0xa7f8056a,0x291d0d70}},	// [18a90] dbog_, _амыц, liño, lvta_, 
   {{0x1fd4000d,0xe1640472,0x00000000,0x00000000}},	//   डण्ड, وداي, --, --, 
   {{0xa7f8056a,0x00000000,0x00000000,0x00000000}},	//   niño, --, --, --, 
   {{0x2fc50d71,0xc8780205,0x00000000,0x00000000}},	//   gbog_, puğu_, --, --, 
   {{0x644c010e,0x2fd40244,0x05a40244,0x00000000}},	//   _ilci, روود_, _تشکێ, --, 
   {{0xb9000327,0xc69400df,0x00000000,0x00000000}},	//   _སྷ_, עאַ_, --, --, 
   {{0xbebc00de,0x1ea800ec,0x518400d8,0x00000000}},	//   _brūc, _ڀائي_, _аута, --, 
   {{0xd7d000b5,0x26d80477,0xa7f8f07f,0x68f800b5}},	//   _gj部_, _ovqo_, diño, dttd, 
   {{0xe3bc0165,0xfaf80421,0x7e740022,0x7d7801d3}},	//   _boñz_, utū_, _згах, _کمار_, 
   {{0x28d800c5,0xcce400db,0x5a4001a9,0x00000000}},	//   _भिखि, رسۉي, тмоғ, --, 
   {{0xf8643e1e,0x644c0210,0x00000000,0x00000000}},	//   евно, _olci, --, --, 
   {{0x3b5402dd,0xdb0800b5,0x88bc00bc,0x00000000}},	//   _пкер, _afgå, dvěd, --, 
   {{0x39480198,0x00000000,0x00000000,0x00000000}},	//   _ƙass_, --, --, --, 
   {{0xa7f8dfe2,0xd94000c7,0xeb38010f,0x74141bf4}},	//   biño, _аҵои, _מענש, کورا, 
   {{0xa7f80f71,0xf20005b3,0x3af80100,0x98d005dc}},	//   ciño, र्फ़_, lèp_, _दबिए, 
   {{0xe85000db,0x00000000,0x00000000,0x00000000}},	//   _منىد, --, --, --, 
   {{0xd3a438b4,0xb22478e1,0x3af80100,0xf74400f3}},	// [18aa0] тлақ, нмал, nèp_, _чепо, 
   {{0x98d01d15,0x644c06be,0xd1d40092,0x25fc0210}},	//   _दबाए, _elci, _ከታች_, श्दी_, 
   {{0xaf350d72,0xd7650d73,0x61400024,0x3944045a}},	//   کرات, _سنگی, лефа, nyls_, 
   {{0xdfcd0d74,0x2ee4e3ba,0xa3c400dc,0x09dc00cd}},	//   ميم_, trof_, _उभय_, _मय्य, 
   {{0xb8d0081f,0x9f4c0214,0xa7f801c4,0x42b4004e}},	//   _ཞང_, nggè_, ziño, _аёсу, 
   {{0xc32c0c50,0x2fc50d75,0x20c029db,0x00000000}},	//   _بەك_, sbog_, _әйтм, --, 
   {{0xafe47d11,0xe2950492,0xa7f80077,0xe1040276}},	//   _повл, _чар_, xiño, _перд_, 
   {{0x2ee50d76,0x09d80490,0xa7f80005,0x3d001d94}},	//   prof_, ढण्य, viño, _शहरे_, 
   {{0xdb20022c,0x88bc00bc,0x3af80066,0x8c3c03e0}},	//   órði, zvěd, gèp_, _buğr, 
   {{0x1f610d77,0xa7f8eb82,0xdbe00241,0x00000000}},	//   _скум, tiño, _léèw, --, 
   {{0x694416a3,0x75380e78,0xbebc00e2,0x58d00108}},	//   _očeš, ätzl, _trūc, лоэт, 
   {{0xa7f90d78,0xe784023a,0x29180010,0xb7d80133}},	//   riño, еуго, _špas_, ووپا_, 
   {{0xdb0800f2,0x3af80561,0xab6401c0,0xa7f85893}},	//   _nggè, cèp_, _явдл, siño, 
   {{0xa7f80005,0x8c3c0205,0xb80c0011,0x00000000}},	//   piño, _tuğs, ষাগত_, --, 
   {{0xd4e4dfe7,0x534400d1,0x19b4011a,0x3364069d}},	//   люти, ңхуа, _אפור_, _ተመለሰ_, 
   {{0xd30c01ad,0x6aa801f4,0xd52c0241,0x657400cd}},	//   हबूब_, _hiff, _sọ̀r, _ābhā, 
   {{0x6aa90d79,0x88bc012c,0x6d4c0003,0x9f5c02d2}},	// [18ab0] _kiff, svěd, _żbal, _nauð_, 
   {{0x6aa90d7a,0x00000000,0x00000000,0x00000000}},	//   _jiff, --, --, --, 
   {{0x6aa8005c,0xdb940023,0x25bc00cd,0x00000000}},	//   _miff, _ቅድድም_, ्रीण, --, 
   {{0x644d0d7b,0xe08407d2,0x6aa80042,0x228c014a}},	//   _ulci, رجاي, _liff, püko_, 
   {{0x88300020,0x00000000,0x00000000,0x00000000}},	//   _እየተደ, --, --, --, 
   {{0x9f4c0502,0x6aa90d7c,0xfce4361e,0xe03001c0}},	//   nggé_, _niff, воко, _өмгө, 
   {{0xe3bc0432,0x00000000,0x00000000,0x00000000}},	//   _soñy_, --, --, --, 
   {{0x6aa803cb,0x8c3c06be,0xac9400e5,0x00000000}},	//   _aiff, _suğr, نچنا_, --, 
   {{0x200d0d7d,0x628000f3,0x7e7c02d2,0x00000000}},	//   megi_, čnof, _íspo, --, 
   {{0x200d0d7e,0x3af82508,0x6aa801bf,0x00000000}},	//   legi_, rèp_, _ciff, --, 
   {{0xf1b004ae,0x3af8068c,0x29180010,0x00000000}},	//   יסי_, sèp_, _špar_, --, 
   {{0x200d0d7f,0x3af8007f,0x0d640395,0xb8d86620}},	//   negi_, pèp_, _съум, _अं_, 
   {{0x6aa90d80,0x7bc90d81,0x377478da,0x8c3c62c7}},	//   _fiff, mbeu, тынс, _tuğr, 
   {{0x6aa90d82,0xdb080066,0x200d0d83,0x683c002e}},	//   _giff, _nggé, hegi_, _wëdp, 
   {{0x1cac03bd,0x7ae82759,0x200d0d84,0x33f50d85}},	//   _ཐངས_, lret, kegi_, кчас, 
   {{0x7bc8f204,0x6aa90d86,0x3f88005f,0x7ae90d87}},	//   nbeu, _ziff, ļauj_, oret, 
   {{0x7ae80ac8,0x200d0d88,0x7bc8002f,0x00000000}},	// [18ac0] nret, degi_, ibeu, --, 
   {{0x7ae90d89,0xdbe0002e,0xa1c00138,0x1288030f}},	//   iret, _dééw, ибуд, رمای_, 
   {{0x649003be,0x7ae90d8a,0x69cc09f3,0x7bc85d43}},	//   mçin, hret, ðbei, kbeu, 
   {{0x69441467,0x628405b1,0x64910d8b,0xafe454a0}},	//   _učeš, _ekjo, lçin, тодл, 
   {{0x7bc802e2,0xdbd82507,0x00000000,0x00000000}},	//   dbeu, _ráðf, --, --, 
   {{0xde010d8c,0x7bc8002f,0x99840153,0xdbd802d2}},	//   ипчи, ebeu, _jonų_, _sáðf, 
   {{0x7ae90d8d,0x9b6402d3,0x6218011a,0x7bc80112}},	//   eret, _ዝቆጻጸ, _קולק, fbeu, 
   {{0x6aa90d8e,0x200d0d8f,0x3074010b,0x7bc90d90}},	//   _siff, cegi_, _ругс, gbeu, 
   {{0x6aa80af5,0xa064026a,0x7ae84c28,0x64902093}},	//   _piff, _рата_, gret, kçin, 
   {{0x3eb8204e,0x62801710,0x8a1801c0,0x6cc4113e}},	//   _ésta_, čnog, хоос_, _айжа, 
   {{0x9f4c073c,0x6aa801bf,0x649006be,0x6da4011c}},	//   segô_, _viff, dçin, _рижа, 
   {{0xdd8c350a,0xda9005f5,0xab64156c,0xeb050d91}},	//   _بوم_, лгөө, _ивел, _ачко, 
   {{0x6aa8b4bb,0x9f5c01d3,0x5fa802e5,0x00000000}},	//   _tiff, őrök_, _छलछल, --, 
   {{0x0530044e,0x84c4723c,0x25bc1b61,0x44240166}},	//   _ኣመልኪ, ләмд, ्रेण, _şl_, 
   {{0x200c063f,0x94d400c7,0xa7f8010e,0x00000000}},	//   yegi_, иорц, niñk, --, 
   {{0x62840ac8,0xe6f0025c,0x200c774c,0x2c780171}},	//   _skjo, _བཀྭན_, xegi_, bīde_, 
   {{0x200c0321,0xbebc0024,0x94a800c7,0xdb180205}},	// [18ad0] vegi_, _arūn, ттра_, rbuç, 
   {{0xbebc00e2,0x200c0083,0x5398005b,0x00000000}},	//   _brūn, wegi_, твуя_, --, 
   {{0x7ae90d92,0x32e00037,0x00000000,0x00000000}},	//   zret, _पिअऽ, --, --, 
   {{0x25fc2017,0x7ae90d93,0x8be80011,0x99840153}},	//   श्री_, yret, ক্তন_, _zonų_, 
   {{0xdce4236c,0x00000000,0x00000000,0x00000000}},	//   _ılıc, --, --, --, 
   {{0xc0ec0092,0x7bc801f5,0xa6d80162,0x7c9400f2}},	//   _ቅጥር_, wbeu, eyðk, گشتا, 
   {{0xc0e0044e,0x200d0d94,0xa3c40490,0xa0a451bc}},	//   ነቶም_, pegi_, _उभा_, _ашал, 
   {{0xa7f80227,0xc0240150,0x1ee400f1,0x7bc8003e}},	//   siñj, _حىري, _لوری_, ubeu, 
   {{0xac940597,0x7bc90d95,0x9ce400e5,0xe1a40b02}},	//   دنيا_, rbeu, روکے_, _कृतघ, 
   {{0x7ae90d96,0x3f8c0438,0x7bc8a26b,0x5ce44990}},	//   rret, _iyeu_, sbeu, _аюда, 
   {{0x7bc8282c,0x00000000,0x00000000,0x00000000}},	//   pbeu, --, --, --, 
   {{0x7ae90d97,0x6ce000aa,0x9ba00131,0x2444000d}},	//   pret, _اړون, _پەخى, _kõmu_, 
   {{0x3b0807b5,0x64910d98,0xdb20a79f,0x99840064}},	//   _чело_, tçin, _خوشی, _ponų_, 
   {{0x75d400c6,0xb9244cec,0xd01c00eb,0x00000000}},	//   طيرا, _مفتي, ণায়_, --, 
   {{0xdb0804ce,0xa504074d,0x04b422c3,0x2bd808a3}},	//   _afgø, лера_, истя, _यजमा, 
   {{0x88bc0118,0x00000000,0x00000000,0x00000000}},	//   svěc, --, --, --, 
   {{0x99840024,0xc76410de,0x64910d99,0x00000000}},	// [18ae0] _tonų_, _پايى, pçin, --, 
   {{0x649077f9,0x7e1c0b26,0xe1f4145a,0x62300063}},	//   lçil, पयोग_, лгу_, беђу, 
   {{0x3f8c0098,0x41b401ec,0x00000000,0x00000000}},	//   _ayeu_, рсут, --, --, 
   {{0x649009a5,0xb0600724,0x00000000,0x00000000}},	//   nçil, _ğäsk, --, --, 
   {{0x8f340faa,0x6140013d,0x6e440006,0x230400ec}},	//   релц, _һера, ледз, _مڪلي_, 
   {{0x764d0d9a,0xf788001f,0x649041bb,0x00000000}},	//   nkby, _መንስኤ_, hçil, --, 
   {{0x64907b37,0xf1a80345,0x6140030d,0x64480037}},	//   kçil, _ساسه_, _лера, ögig, 
   {{0x6280110c,0x00000000,0x00000000,0x00000000}},	//   čnoe, --, --, --, 
   {{0x4a550d9b,0xcdc400d1,0x764c03cd,0x649003e3}},	//   икис, _кәйп, kkby, dçil, 
   {{0x307401d5,0x00000000,0x00000000,0x00000000}},	//   _руҳс, --, --, --, 
   {{0x61e00579,0xebe4c07f,0x3f8c007f,0x09940114}},	//   ónli, _боеп, _zyeu_, ранџ, 
   {{0x7a48006a,0x64900209,0xa2580109,0x228c00c5}},	//   _pêtê, gçil, _ntôn, tükk_, 
   {{0x6d480c8c,0xd04800ac,0x941800ac,0xa6d803b2}},	//   lyfa, ülər, _özəl_, oyði, 
   {{0x2bd05b82,0xa25800d8,0x228c0254,0x00000000}},	//   सरवा, _atôn, rükk_, --, 
   {{0x69d90d9c,0x6d490d9d,0x99440592,0xa7f80113}},	//   mate, nyfa, _ملول_, hiñi, 
   {{0x69d90d9e,0x00000000,0x00000000,0x00000000}},	//   late, --, --, --, 
   {{0x53350d9f,0x2c040882,0x69d8002d,0x0ee00a59}},	// [18af0] бетт, व्यं_, oate, _निगड, 
   {{0x51f8023a,0x764c007c,0x6d4803ac,0x01c40022}},	//   лную_, ckby, kyfa, рраҭ, 
   {{0x212401dc,0xa2580109,0x45340131,0xffd402d5}},	//   ính_, _ftôn, _ئىجر, аўля, 
   {{0x69d8325f,0x6d480332,0xa6d8032e,0x00000000}},	//   hate, dyfa, eyði, --, 
   {{0x64900200,0x958c0023,0xa7f90da0,0x00000000}},	//   nçim, _መስተን_, giñi, --, 
   {{0x3ea407d6,0x20d44dad,0xbea451a7,0x4e0002ab}},	//   шилг, _مترج, шалк, ल्लई_, 
   {{0x6d48bde2,0x00000000,0x00000000,0x00000000}},	//   gyfa, --, --, --, 
   {{0x3eb800eb,0xcd280451,0x50f400f7,0x7538002f}},	//   _ésto_, اسون_, _ызст, ätzi, 
   {{0x69d90da1,0xbebc1039,0x34d0033f,0x00000000}},	//   fate, _krūm, _तब्द, --, 
   {{0x61f40399,0x5e84084c,0x201c0051,0x649006be}},	//   ngxl, _субз, _haui_, dçim, 
   {{0x64900fb9,0x201d0da2,0x6d490da3,0x00000000}},	//   tçil, _kaui_, cyfa, --, 
   {{0x69d80140,0x00000000,0x00000000,0x00000000}},	//   aate, --, --, --, 
   {{0x69d90da4,0x649046d5,0x91d8033f,0xca54009d}},	//   bate, rçil, यरमै, рхөө, 
   {{0x69d90da5,0xed8c044e,0x201c1132,0x2cb001e1}},	//   cate, _ምንባር_, _laui_, _òndò_, 
   {{0x201c0093,0x64902e11,0x764d0da6,0x35a40107}},	//   _oaui_, pçil, rkby, равг, 
   {{0x201d0da7,0xc98401c6,0x78b40306,0x764c007c}},	//   _naui_, _уучи, ízvu, skby, 
   {{0xa3c405f9,0xe3b4426c,0xbebc00cd,0x6d4802d0}},	// [18b00] _उभर_, рбу_, _brūm, zyfa, 
   {{0x224001fa,0x00000000,0x00000000,0x00000000}},	//   _cojk_, --, --, --, 
   {{0x201c08cd,0x2240151c,0x116800f1,0x61b001d9}},	//   _baui_, _dojk_, دلای_, زٕنا, 
   {{0xdfcc06f6,0x6d4800d7,0xa99800df,0x00000000}},	//   ِين_, vyfa, דבער, --, 
   {{0x201c0810,0x6d480368,0xc29001b9,0x00000000}},	//   _daui_, wyfa, _کیلب, --, 
   {{0x6d480c8c,0x69d90da8,0xbebc0064,0xad0801c4}},	//   tyfa, xate, _grūm, вхиж_, 
   {{0x69d90da9,0x32080077,0xa7f80428,0xc0940131}},	//   vate, _ibby_, siñi, ججەت, 
   {{0x6d480c8c,0x201d0daa,0x00000000,0x00000000}},	//   ryfa, _gaui_, --, --, 
   {{0x69d89583,0xdad4010b,0xe45405d0,0x9ca400ec}},	//   tate, амыц_, ייקט_, جهيل_, 
   {{0x6f010dab,0x69d80618,0x9e6012e7,0x4a545c83}},	//   mtoc, uate, _двуд, скос, 
   {{0x69d90dac,0x201c0a73,0x6f010dad,0x6da400db}},	//   rate, _yaui_, ltoc, _ئمام, 
   {{0x69d90dae,0xdcac3baf,0x64900790,0x00000000}},	//   sate, _قىل_, tçim, --, 
   {{0x32080076,0x2c7800e2,0x69cc0162,0x00000000}},	//   _obby_, cīda_, ðbes, --, 
   {{0x69d90daf,0xddc00311,0x228c29ef,0x64910db0}},	//   qate, minţ, püki_, rçim, 
   {{0xddc0054e,0x648801c4,0x00000000,0x00000000}},	//   linţ, всаг_, --, --, 
   {{0x290d0db1,0x6f010db2,0x3208045a,0x54540f4e}},	//   _ipfa_, ktoc, _abby_, овст, 
   {{0xddc00276,0x64903bc1,0x6f00a82c,0x224001e3}},	// [18b10] ninţ, lçik, jtoc, _pojk_, 
   {{0x6f00030d,0x46150db3,0xf0780131,0xa664072d}},	//   dtoc, _اودر, қичә_, _خطبو, 
   {{0x201c0270,0x6f0000d7,0x83f8014b,0x7e7c02d2}},	//   _paui_, etoc, _йенс_, _íspi, 
   {{0x290c1dc9,0x320801e1,0x6f00002d,0x5fe40212}},	//   _mpfa_, _ebby_, ftoc, ріжж, 
   {{0xdef800c9,0x4fe85cd9,0x6f0001a4,0x53380408}},	//   тые_, рмін_, gtoc, _курă, 
   {{0xddc000a8,0xb6d8008f,0xe9cc02dd,0x878c0092}},	//   dinţ, אַקט, _екi_, _መንስዔ_, 
   {{0x201d0db4,0xd65804ae,0xd40c0183,0x2470033f}},	//   _taui_, שיות_, ৱাৰি_, ećmi_, 
   {{0xc17c00c6,0xddc0054e,0x3ce80419,0x3a2803e0}},	//   ăɗă_, finţ, čav_, _şap_, 
   {{0x290c01b2,0xddc00356,0x00000000,0x00000000}},	//   _apfa_, ginţ, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa3c44970,0xb5cc01ec,0x27280092,0x7d94072d}},	//   _उभं_, _ﺑﯘﻟﻌ, _ስላለበ, _الاؤ, 
   {{0x3d00068f,0xdd9000c7,0x00000000,0x00000000}},	//   mów_, _лаҕы, --, --, 
   {{0x7bd80117,0x8b6800d6,0xddc00276,0x3d000034}},	//   _iewu, _київ_, cinţ, lów_, 
   {{0x65c10db5,0x60c4037e,0x683c0240,0x7c2c0174}},	//   збра, _otjm, _mëdy, _óarb, 
   {{0x3d00006d,0x7bd90db6,0xbebd0db7,0x6f000210}},	//   nów_, _kewu, _brūk, ztoc, 
   {{0x88c42df0,0x6f010db8,0xf74801f7,0x2908025c}},	//   _بتول, ytoc, _ملبي_, ħbat_, 
   {{0x7bd833cb,0x6f0000d0,0x3d00012d,0x00000000}},	// [18b20] _mewu, xtoc, hów_, --, 
   {{0x3d0014cf,0x7bd90db9,0x78a40250,0x88bc01ef}},	//   ków_, _lewu, lmkv, kvěl, 
   {{0x3d001afd,0x021802bf,0xddc00356,0x48e00037}},	//   jów_, шіть_, zinţ, _किछो_, 
   {{0x3d00068f,0x6f010dba,0x7bd80408,0x75380ade}},	//   dów_, ttoc, _newu, ätzu, 
   {{0x437405f5,0x7d0001a9,0x6f000051,0x25fc00bc}},	//   _дурт, _aqls, utoc, श्की_, 
   {{0xddc00276,0x3d00033f,0x9f50010e,0x00000000}},	//   vinţ, fów_, _çeýe_, --, 
   {{0x7bd90dbb,0x3d00068f,0x2d98143a,0xfc4802f0}},	//   _bewu, gów_, åpe_, zdíš_, 
   {{0xa3c802ab,0xf07400dd,0xddc00311,0xa92802dd}},	//   रुप_, _اُرد, tinţ, ңіне_, 
   {{0x7bd80083,0xa0a009a5,0x2aa82be5,0x2b440139}},	//   _dewu, _хатд, лтоо_, сэйг, 
   {{0xddc000a8,0x6e950dbc,0x3d000034,0x3f8800e2}},	//   rinţ, _الطا, bów_, ļaut_, 
   {{0x3d00068f,0xddc00311,0xa7f801c4,0x00000000}},	//   ców_, sinţ, ziñu, --, 
   {{0x7bd801cf,0xbc24005e,0xbebc00dc,0x64910dbd}},	//   _gewu, _ورنى, _brūh, rçik, 
   {{0xe3bc00e8,0xe62402d3,0xe7850dbe,0xddc01a48}},	//   _jañe_, _ትምክሕ, суно, linš, 
   {{0xa3c80574,0xe3bc00e4,0xfc4802f0,0xdb8001c6}},	//   रुन_, _mañe_, rdíš_, _эгчи, 
   {{0xe5700597,0x290c0526,0x7bd90dbf,0x5558084c}},	//   سطس_, _upfa_, _yewu, баря_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x53341c3e,0x660001ed,0x3d000034,0xe3bc00e4}},	// [18b30] петт, _önko, zów_, _nañe_, 
   {{0xddc00010,0xa7f80de2,0xdb200332,0x00000000}},	//   kinš, riñu, óréi, --, 
   {{0xbebc2602,0xf6500302,0xa7f8005a,0xddc06b92}},	//   _trūk, _חצי_, siñu, jinš, 
   {{0xe3bc002e,0x46150dc0,0xddc03858,0x00000000}},	//   _bañe_, _اوگر, dinš, --, 
   {{0x7d00ae4d,0x3d000034,0xc1e801ed,0x7bd80098}},	//   _sqls, wów_, _نکال_, _rewu, 
   {{0x3d00006d,0x7bd8192e,0xe3bc0789,0x45780092}},	//   tów_, _sewu, _dañe_, _የስንዴ_, 
   {{0x7bd80ac5,0xfbd0007b,0x772c0092,0x6da02766}},	//   _pewu, وتة_, _ሲያስተ, миша, 
   {{0x3d00006d,0x00000000,0x00000000,0x00000000}},	//   rów_, --, --, --, 
   {{0x3d00006d,0xe3bc1bce,0x3ce400e1,0xdb18004e}},	//   sów_, _gañe_, _टिके_, rcuï, 
   {{0x3d00068f,0x7bd90dc1,0xddc001a6,0xb908bbf1}},	//   pów_, _wewu, binš, аноз_, 
   {{0x7bd83699,0x5d48010a,0x228c06be,0x00000000}},	//   _tewu, _сăнĕ, lüks_, --, 
   {{0x8d750dc2,0x78a400cc,0xa3c80b8f,0x1fd40154}},	//   _عالا, umkv, रुम_, _হাঁস, 
   {{0xeb8ca710,0xe3bc00e8,0x9f50020c,0x1ac80139}},	//   _ци_, _xañe_, èdèr_, _суеп_, 
   {{0x3ce401f5,0x00000000,0x00000000,0x00000000}},	//   _kvlv_, --, --, --, 
   {{0xa7f80998,0xa9640f37,0x741400db,0x7e7c03b2}},	//   tiñt, _миша_, يوسا, _íspu, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc5d800bd,0x6448000d,0x00000000,0x00000000}},	// [18b40] _তারপ, ögia, --, --, 
   {{0x43741d0f,0x394800bc,0x00000000,0x00000000}},	//   чуст, _řasy_, --, --, 
   {{0xd5d000dc,0x35a401d5,0xdfcc00ec,0x00000000}},	//   _त्यज, _фанг, چيم_, --, 
   {{0xdfcc785c,0x8eb43b5f,0x00000000,0x00000000}},	//   نيم_, كەرت, --, --, 
   {{0xfd640228,0xa3c42982,0xdee00d2d,0x00000000}},	//   үнчү, उडर_, дочи, --, 
   {{0xe2940ec6,0xf0c801d9,0x9db400d1,0x00000000}},	//   _мая_, _نظرو_, يدىز_, --, 
   {{0x25d4010f,0xc32000cc,0x307441e5,0xad240633}},	//   קוקן_, নমণি_, _дуас, ترشو, 
   {{0xc1c801d9,0xa4b40375,0xddc0b9af,0xabb00131}},	//   _نبہٕ_, חלקה_, rinš, майә, 
   {{0xee385b66,0x00000000,0x00000000,0x00000000}},	//   _кна_, --, --, --, 
   {{0xddc00427,0x00000000,0x00000000,0x00000000}},	//   pinš, --, --, --, 
   {{0x21b80677,0x00000000,0x00000000,0x00000000}},	//   יזיא, --, --, --, 
   {{0xa7f80489,0xda6c01d9,0x74ac0220,0x00000000}},	//   viñs, _یُن_, _ﺳﺎﻻﺳ, --, 
   {{0x67440953,0x1c40010b,0x6b7400ae,0xcb340395}},	//   цэнз, _юнцм, _بطاط, _хелъ, 
   {{0x2bd00e49,0x00000000,0x00000000,0x00000000}},	//   सरका, --, --, --, 
   {{0xe4680120,0x00000000,0x00000000,0x00000000}},	//   ашал_, --, --, --, 
   {{0xa7f80165,0x03c80154,0x64900205,0x00000000}},	//   riñs, ষণ্ণ, hçiv, --, 
   {{0xddc80030,0x00000000,0x00000000,0x00000000}},	// [18b50] _čižm, --, --, --, 
   {{0x1fd402a6,0x6ce802ab,0xbebc0024,0x15b000d1}},	//   _হাইস, _टिंग_, _krūv, _ﻳﯜﺭﻩ, 
   {{0xc0141c22,0x7d0c0034,0xc0f802d3,0x75c801af}},	//   змещ, łasz, _ለባም_, _утың_, 
   {{0x35180375,0xfd7401c0,0xf980001f,0x02440014}},	//   _פורנ, үлдэ, _ያንብቡ_, _کَسَ, 
   {{0xa3c806b1,0xf438011a,0xe7f00037,0x00000000}},	//   रुण_, _הגרמ, _अयना_, --, 
   {{0xb2b80375,0x00000000,0x00000000,0x00000000}},	//   _למשר, --, --, --, 
   {{0xdb181709,0x6d4c031c,0x81a800eb,0x00000000}},	//   rcuí, _żbar, _গ্র_, --, 
   {{0x228c014a,0xdb180077,0x6294036e,0x00000000}},	//   püks_, scuí, llxo, --, 
   {{0x7a40003a,0x3f9803f2,0xfbd00cbb,0xfaf0007b}},	//   _nâtû, _ásu_, وتک_, رثة_, 
   {{0xa3c80b02,0xbebc0a2f,0xdb2001e1,0x00000000}},	//   रुत_, _brūv, _àsíb, --, 
   {{0xdcec0006,0x6b8083fb,0xa9e000f1,0x2ea80101}},	//   _įdėt, _exog, رګون, _اپلی_, 
   {{0x315400c8,0x787400e2,0x48dc00ab,0x00000000}},	//   פירן_, kšve, _खबरो_, --, 
   {{0x2b2800aa,0xd5b8005f,0x00000000,0x00000000}},	//   _هغوی_, žām_, --, --, 
   {{0xfe780316,0xc68c02d3,0xab6000d1,0x64480037}},	//   _svůj_, _ማእለያ_, _سۇپى, ögin, 
   {{0x393405f5,0x0f180073,0x00000000,0x00000000}},	//   _хэлс, _धन्स_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe3bc00e8,0x81a800fe,0x3668014b,0x00000000}},	// [18b60] _sañc_, _গ্ল_, _гапо_, --, 
   {{0xb9500023,0xfbac00cd,0x00000000,0x00000000}},	//   _ዝመስሎ, ञेयम, --, --, 
   {{0x92080055,0xfe7800bc,0xc100004e,0x00000000}},	//   _avāñ, _tvůj_, күрл, --, 
   {{0x7a240374,0x645d0dc3,0xa3c82e2a,0x1fd400eb}},	//   _hōtē, chqi, रुद_, _হাউস, 
   {{0xddcc0316,0x21a00724,0x2d9c00e5,0x00000000}},	//   _řeše, _җитм, _szte_, --, 
   {{0x78b40455,0xb62c037e,0xad2400ae,0x00000000}},	//   _liyv, _ｓａ_, كربو, --, 
   {{0x649003be,0x7a2400b0,0xb60400ef,0x71a41171}},	//   rçiv, _mōtē, _iešā, _хавз, 
   {{0x3218068f,0xe3bc00e4,0x00000000,0x00000000}},	//   lepy_, _kaña_, --, --, 
   {{0xaae400c6,0xbd0001f5,0xe3bc0139,0x00000000}},	//   أسبو, _éénd, _jaña_, --, 
   {{0xe3bd0dc4,0x09bc0154,0x298412b9,0x00000000}},	//   _maña_, _আজহা, зымг, --, 
   {{0x7cf00579,0xfe442c26,0x2d9c26ef,0x3a0807d6}},	//   _vórð, _تکنی, _uzte_, تکنی_, 
   {{0x6b800218,0xeb980276,0x2fc4003e,0x32180022}},	//   _txog, _лие_, ncog_, hepy_, 
   {{0x7c6404a9,0xd8389bb1,0xe3bc0086,0x7cf00174}},	//   _تالل, чээ_, _naña_, _tórð, 
   {{0xcc8807d6,0x3eb80561,0x321800c7,0x00000000}},	//   _انچه_, _èste_, jepy_, --, 
   {{0x5558084c,0x69940014,0x645c0200,0x1a980115}},	//   паря_, _ڈێکس_, thqi, _היגע, 
   {{0xe3bd0dc5,0x9584068f,0xbebc2602,0xa3780798}},	//   _baña_, _łącz, _krūt, _leõe, 
   {{0xe3bce5ff,0xe2a846c6,0x68f803cd,0x9484010b}},	// [18b70] _caña_, مائن_, lutd, хырд, 
   {{0x645d0dc6,0xe3bc0407,0xe8e8031c,0x9f4c007c}},	//   shqi, _daña_, _རྗོག, nggå_, 
   {{0x68f90dc7,0xa1640063,0x21650dc8,0x00000000}},	//   nutd, чњак, чтаг, --, 
   {{0x2a500023,0x7414225f,0x835401c8,0x506400cf}},	//   _ዝገበሮ, _قوپا, _ٺھرا, нтча, 
   {{0x4428fccb,0x44390dc9,0xe3bc1709,0x6d8c06d6}},	//   mda_, _ins_, _gaña_, ṱalu, 
   {{0x4438b745,0xf1c802fb,0x291c0083,0x68f8022e}},	//   _hns_, tráž_, kwta_, kutd, 
   {{0x44280a81,0xe3bc0113,0xc10412e3,0xbca41867}},	//   oda_, _zaña_, _توزي, ومتي, 
   {{0xe3bc1248,0x68f8089c,0x44386af6,0xbebc6991}},	//   _yaña_, dutd, _jns_, _brūt, 
   {{0x64910dca,0x6b600408,0xac800395,0x41e00210}},	//   lçis, ккъа, ъгъл, _फ़ास, 
   {{0xbebc0064,0x00000000,0x00000000,0x00000000}},	//   _drūt, --, --, --, 
   {{0x44390dcb,0x44290dcc,0xd5b8005f,0x68f8143a}},	//   _ons_, kda_, žāk_, gutd, 
   {{0x44390dcd,0x644800c5,0x845c00b7,0x78b401a9}},	//   _nns_, ögil, _ሰለሞን_, _qiyv, 
   {{0x44290dce,0xbebc00da,0x7a2402b5,0x7c3801f5}},	//   dda_, _grūt, _pōtē, _inwr, 
   {{0x44390dcf,0x44290dd0,0x2a6c070d,0x6b944673}},	//   _ans_, eda_, _gmfb_, _øyga, 
   {{0xe3bc0bc9,0x7c290dd1,0x44390dd2,0x44290dd3}},	//   _saña_, oder, _bns_, fda_, 
   {{0x44390dd4,0x74150dd5,0x5ed000bd,0xe3bc0309}},	//   _cns_, بورا, _সিনে, _paña_, 
   {{0x7c290dd6,0xb224c331,0x3cfc00dc,0x3218035b}},	// [18b80] ider, ммал, रूते_, tepy_, 
   {{0x44390dd7,0x87043306,0x7c290dd8,0x00000000}},	//   _ens_, _أبيل, hder, --, 
   {{0x7c290dd9,0xe3bd0dda,0x4438ce46,0x7c380af9}},	//   kder, _waña_, _fns_, _onwr, 
   {{0x7c290ddb,0x44280a81,0xe3bc00e4,0xf0fc00e1}},	//   jder, cda_, _taña_, _उमीद_, 
   {{0x7c28193f,0xaf350ddc,0xa3780120,0x2fc40010}},	//   dder, برات, _peõe, rcog_, 
   {{0x7c290ddd,0xa2e00e92,0x00000000,0x00000000}},	//   eder, _јорд, --, --, 
   {{0x2ee405b1,0xdfcc05d9,0x4c94a4ec,0xe120010b}},	//   ssof_, _چيف_, никс, _имри, 
   {{0x776405b1,0x68f80158,0xb6001155,0x21a000f3}},	//   kzkx, vutd, _šálo, _рисм, 
   {{0x1dcc1b87,0x81900023,0x00000000,0x00000000}},	//   _स्वत, _ክሳተፉ_, --, --, 
   {{0x68f90dde,0x7c3802d0,0xfb84036b,0x00000000}},	//   tutd, _enwr, رگنی, --, 
   {{0x6e380135,0x7c28876a,0x998001d9,0x66010ddf}},	//   _intb, bder, ہلیو, _önki, 
   {{0x44280a81,0x68f90de0,0x765c4f82,0x286802bf}},	//   xda_, rutd, _alpy, ірно_, 
   {{0x44390de1,0x68f878d0,0x2d503253,0xdedc02d3}},	//   _rns_, sutd, _سێکس, _ሓቅን_, 
   {{0x44290de2,0x44390de3,0xdb2000d8,0xdb980375}},	//   wda_, _sns_, _àsáb, _וסדר, 
   {{0x44290de4,0x44390de5,0x69c814dc,0x6fdc033d}},	//   tda_, _pns_, _iffe, मरां, 
   {{0xd5b81830,0xb1380092,0x765c94ee,0x74a000cd}},	//   ься_, _የሚያዳ, _elpy, _कीदृ, 
   {{0x6e380e29,0x2ca400a3,0x44388f13,0x00000000}},	// [18b90] _ontb, _mhod_, _vns_, --, 
   {{0x7c290de6,0x6490344b,0x00000000,0x00000000}},	//   zder, tçis, --, --, 
   {{0x7c290de7,0x44290de8,0x03a401e0,0x845c0023}},	//   yder, pda_, фиҡо, _ሰለሙን_, 
   {{0x44290de9,0x44390dea,0xca5008b0,0x2c7800ef}},	//   qda_, _uns_, ﺎﺭﺍ_, bīdi_, 
   {{0x93c80014,0x7c280240,0x2c7800ef,0x00000000}},	//   _تاپہ_, vder, cīdi_, --, 
   {{0x7c290deb,0xceb8068f,0xe45d0dec,0x649024d7}},	//   wder, _cię_, _hlö_, pçis, 
   {{0x2ca400a3,0xfd1048ef,0x7c2800e2,0xbebc56ce}},	//   _bhod_, اجت_, tder, _prūs, 
   {{0x7c290ded,0x6e390dee,0xb88400bc,0x00000000}},	//   uder, _entb, _klíš, --, 
   {{0x3ed836fe,0x8ed8007b,0x00000000,0x00000000}},	//   _رواج_, _يذكر_, --, --, 
   {{0x7c290def,0x3944cc98,0x64480254,0x00000000}},	//   sder, еног, ögij, --, 
   {{0xe3bd0585,0x00000000,0x00000000,0x00000000}},	//   _naño_, --, --, --, 
   {{0xed541a4c,0x7c390df0,0x2ca40455,0xcc3400c7}},	//   _אבער_, _unwr, _ghod_, _ахшы, 
   {{0xe62802d3,0xdac40075,0xe5a000d1,0x00000000}},	//   _ብምኽን, _تېخى_, ғити, --, 
   {{0xe3bc2760,0x7ae90df1,0x7bc80393,0xaafc01a8}},	//   _baño_, mset, lceu, _óháð_, 
   {{0x7ae90df2,0x9984d663,0xe3bcbb80,0xf0fcccc0}},	//   lset, _manū_, _caño_, _उमेद_, 
   {{0x7bc90df3,0xe3bd0df4,0xa3c8007d,0x7ae800f3}},	//   nceu, _daño_, रुल_, oset, 
   {{0x7ae90df5,0xc614045e,0xd9f065d9,0x7bc801ab}},	// [18ba0] nset, ায়া_, _आयात_, iceu, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7ae90df6,0xa8200133,0xe0cc0014,0x73e401f0}},	//   hset, _شکێن, مٲل_, _понз, 
   {{0xceb81b13,0x7ae816ca,0x00000000,0x00000000}},	//   _się_, kset, --, --, 
   {{0x7ae90df7,0x2ca46330,0x00000000,0x00000000}},	//   jset, _rhod_, --, --, 
   {{0x7ae90df8,0x2ca50df9,0x25080345,0x00000000}},	//   dset, _shod_, _بریی_, --, 
   {{0x21a0d4b3,0xc1940395,0x00000000,0x00000000}},	//   _бирм, _аштъ, --, --, 
   {{0x7ae90dfa,0xffc00220,0x7bc80c6a,0xd1740961}},	//   fset, _көшп, gceu, _зығы, 
   {{0x3f810dfb,0x7ae90dfc,0x2ca43831,0x69f000f7}},	//   şhur_, gset, _vhod_, гүлт, 
   {{0x7d0c0054,0xdb2000c6,0x4a54bf73,0x6e3803ac}},	//   ńasa, órái, ткос, _untb, 
   {{0x88bc0316,0x644800c5,0xa85001e0,0x7ae90dfd}},	//   jvět, ögik, генә, aset, 
   {{0x62800cf4,0xa17808a8,0xab8474e4,0xac840024}},	//   čnoi, לטיט, _пулк, _ягел, 
   {{0xdca00354,0x7ae800e5,0x41e0012d,0x00000000}},	//   _саци, cset, _फ़लस, --, 
   {{0x69c90dfe,0xe3bc00eb,0x387003cb,0xe45c01e3}},	//   _uffe, _paño_, _emyr_, _slö_, 
   {{0x9aa003e6,0x00000000,0x00000000,0x00000000}},	//   _حموو, --, --, --, 
   {{0x47350dff,0x48140022,0x61100118,0xa3c800cd}},	//   _анис, _рмис, nělš, रुं_, 
   {{0xc6700020,0xbebc00ef,0x4e0000bc,0x2374072d}},	// [18bb0] _ባለሙያ_, _asūn, ईलाई_, رارح, 
   {{0x7afc0228,0x3718009f,0x00000000,0x00000000}},	//   àsti, _آريھ_, --, --, 
   {{0xbebc002b,0xfe7001d3,0xb9dc0092,0x00000000}},	//   _arūp, یدت_, _ባዩ_, --, 
   {{0x1b1400bd,0xc6a40853,0x7f740120,0x3ddc00fe}},	//   তিতে_, _ярқи, кулц, _ঠাইল, 
   {{0x644c0381,0x4f5802bf,0xa3c800dc,0x00000000}},	//   _ioci, ницю_, रुः_, --, 
   {{0x7ae90e00,0x644d0e01,0xbd88b32a,0x8d74029e}},	//   vset, _hoci, ونشن_, گاها, 
   {{0x644d0e02,0x518454aa,0xfc300597,0xc0c43941}},	//   _koci, _бута, لحة_, _рәзи, 
   {{0x7ae90e03,0x644cc25d,0x7bc80098,0x8d74030f}},	//   tset, _joci, uceu, داها, 
   {{0x644d0e04,0x7ae90e05,0x7bc81a1d,0x7f94035b}},	//   _moci, uset, rceu, _раах, 
   {{0x7ae90e06,0x644d0e07,0x5d640276,0x8520012c}},	//   rset, _loci, _птез, मबाट_, 
   {{0x7e60035a,0x88bc01ef,0x00000000,0x00000000}},	//   _illp, dvěs, --, --, 
   {{0x644d0e08,0x00000000,0x00000000,0x00000000}},	//   _noci, --, --, --, 
   {{0x7e600113,0x49700139,0x00000000,0x00000000}},	//   _kllp, иһәс, --, --, 
   {{0xb6a47b17,0xd7f80311,0x00000000,0x00000000}},	//   тигл, şă_, --, --, 
   {{0xa504236b,0x81c80154,0x00000000,0x00000000}},	//   кера_, োণা_, --, --, 
   {{0x644d0e09,0x79e000d1,0x00000000,0x00000000}},	//   _coci, _ﺋﯘﭼﺮ, --, --, 
   {{0x644d0e0a,0xa3e049fc,0x88bc012c,0xf2d00592}},	// [18bc0] _doci, _नजर_, svět, شآء_, 
   {{0x04f003d4,0xd1c00092,0x00000000,0x00000000}},	//   _চহৰৰ_, ስፋት_, --, --, 
   {{0x644d0e0b,0xc0ec0092,0x34a801c6,0x72d000d1}},	//   _foci, _ህብር_, _овоо_, _چەرچ, 
   {{0x7e601bb7,0xa3c800c5,0xc05802d5,0xd010007b}},	//   _allp, रुआ_, ніі_, صلت_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x644c379d,0x78640162,0xfaf90e0c,0x00000000}},	//   _zoci, _hóvd, drū_, --, 
   {{0x61400517,0x3cfc0316,0x644c01f0,0xe294084c}},	//   _кера, रूले_, _yoci, _рар_, 
   {{0x40943849,0x7e6003ac,0x09bd0e0d,0x00000000}},	//   _брут, _ellp, ोड्य, --, 
   {{0x2b4401c0,0xaf044d56,0x2a6402e8,0x5b00009f}},	//   тэйг, _шпал, вънг, لِيم, 
   {{0xad5813f3,0xa2580208,0x5a310e0e,0xc06c0ca8}},	//   _орех_, _luôn, аньт, _àárí, 
   {{0xdd1c01a2,0x2908019f,0x5ec400bd,0x3b0c013c}},	//   píšt, îba_, রীদে, ateq_, 
   {{0xa2580208,0xb88001ef,0x00000000,0x00000000}},	//   _nuôn, _žíra, --, --, 
   {{0x69f00b8d,0xe7850e0f,0x7c64036b,0x7e60036e}},	//   _күпт, туно, _حالل, _yllp, 
   {{0xed70067d,0x09bc0154,0xdb3400df,0x00000000}},	//   _እንታይ_, _আজকা, _שנגח_, --, 
   {{0x644c2320,0x69d90e10,0xa258001e,0x28a401b9}},	//   _poci, mbte, _buôn, _ишиг, 
   {{0xa2580051,0x69d8002f,0x572400cf,0xe4a40114}},	//   _cuôn, lbte, _چىيك, трго, 
   {{0x644d0e11,0x69d80009,0xd77438eb,0x00000000}},	// [18bd0] _voci, obte, _پايع, --, 
   {{0x69d803a2,0x644c0e90,0x68f80af9,0x51f806a6}},	//   nbte, _woci, ortd, кную_, 
   {{0x212401dc,0xd888dc89,0x05d8012c,0x69d90e12}},	//   ình_, _سپین_, _ब्यब, ibte, 
   {{0x644c0393,0xe7e000dc,0xbbd0000d,0x00000000}},	//   _uoci, परिप, _सभेक, --, 
   {{0xd9e005f9,0x62b40032,0x787400d0,0x23a400bc}},	//   _ग़लत_, _ағас_, zšvo, _खरिद, 
   {{0x3b0c045a,0x00000000,0x00000000,0x00000000}},	//   vteq_, --, --, --, 
   {{0x6284208d,0x7cd00882,0x69d80113,0xe3bc0055}},	//   _ijjo, _mārg, dbte, _rañj_, 
   {{0x06d80c58,0xdb20036b,0x69d8ab10,0xcc3400c7}},	//   _তিনি, لوبی, ebte, ахьы, 
   {{0x7864612f,0x9e0400a8,0x3b0c013c,0xfe7800bc}},	//   _jóve, _ачел, uteq_, _dvůr_, 
   {{0x786403b7,0xd9e000bd,0x1dc43d1d,0x68f8013f}},	//   _móve, _মাহম, _ललित, frtd, 
   {{0x37e40323,0x81b40154,0xac9c0023,0x85440064}},	//   лонг, ছুর_, ልየሎም_, nkėč, 
   {{0x8d740131,0x69d8b3b6,0x7cd00171,0x00000000}},	//   _ئاكا, abte, _pārf, --, 
   {{0x7864008c,0x81e800bd,0x37740032,0x68f81691}},	//   _nóve, _যান_, уынс, artd, 
   {{0x7cd00055,0xa258004d,0x377401e0,0xa6c4072d}},	//   _cārg, _suôn, _ҡыпс, اوّل_, 
   {{0x7cd000da,0x05540212,0xddc000a2,0x2c7800ef}},	//   _dārg, аття, kinž, cīds_, 
   {{0x7864447a,0x6d5c00a3,0x00000000,0x00000000}},	//   _bóve, ùpai, --, --, 
   {{0x64a10e13,0xa258001e,0x09340014,0x7cd000cd}},	// [18be0] сата, _vuôn, _مى۪ح, _hārd, 
   {{0x7cd00b13,0x998401ef,0x00000000,0x00000000}},	//   _gārg, _janů_, --, --, 
   {{0xea7400c8,0xa258004d,0x00000000,0x00000000}},	//   נגער_, _tuôn, --, --, 
   {{0x62841418,0xa0650e14,0xd5b800e2,0x7cd06991}},	//   _ejjo, лаха_, žās_, _mārd, 
   {{0x786403b2,0x683807d9,0x69d80067,0x91e800cc}},	//   _kóvb, _hädä, ybte, _পাঠখ, 
   {{0x06d8045e,0xb5e0015b,0x644800c5,0x68f90e15}},	//   _তিমি, _বাঁচ, ögiv, yrtd, 
   {{0xa3c817ee,0x62880165,0x62800010,0x7cd00055}},	//   रुक_, égoe, čnot, _nārd, 
   {{0x68381248,0x1f601de6,0xeb490e16,0x00000000}},	//   _mädä, ркәм, ечок_, --, 
   {{0x78640005,0xa0650e17,0xae880022,0xefb0036b}},	//   _xóve, _сата_, _збаз_, _ایشگ, 
   {{0xfd5c00b4,0xfe74425b,0x69d80e78,0x7cd000de}},	//   _jizọ, _күч_, ubte, _bārd, 
   {{0x69d90e18,0x7cd0002b,0x81e800fe,0x7b14009d}},	//   rbte, _cārd, _যাম_, гдөх, 
   {{0x87b405f5,0x7c6400aa,0x19a50e19,0xf8ac2764}},	//   ийнх, _پامل, ытып_, وکي_, 
   {{0x98750e1a,0xe66405f5,0x7cd0005f,0x66140175}},	//   сляц, гтво, _pārg, _pbxk, 
   {{0x2d9c788f,0x68380166,0x00000000,0x00000000}},	//   _kyte_, _bädä, --, --, 
   {{0x7cd024b8,0x6f000208,0x00000000,0x00000000}},	//   _gārd, huoc, --, --, 
   {{0x2d9d0e1b,0x68380166,0x140800c7,0x947403c7}},	//   _myte_, _dädä, лхуп_, مدقا, 
   {{0x81e8000e,0x27e80a40,0x2d9c03cd,0x42750e1c}},	// [18bf0] _যাব_, macn_, _lyte_, агас, 
   {{0x5ed003f4,0x7cd03a2f,0xe3bc0086,0x80d80183}},	//   _সিলে, _hāre, _mañi_, _ডিব্, 
   {{0x7cd03b37,0x2d9c168c,0x68380166,0x00000000}},	//   _kāre, _nyte_, _gädä, --, 
   {{0x6f00fa08,0x7cd000e2,0x7fb8007b,0x035401ee}},	//   fuoc, _jāre, نهار_, _күбә_, 
   {{0xe814de66,0x7cd03b37,0x6f000286,0x00000000}},	//   ध्या_, _māre, guoc, --, 
   {{0x62801f48,0x8fd400d1,0x2d9d0e1d,0x98ac03ce}},	//   čnos, _һәшә, _byte_, _टीनए, 
   {{0xd658025f,0x68380139,0x00000000,0x00000000}},	//   ריות_, _xädä, --, --, 
   {{0x62950e1e,0x2d9c02d3,0x61e50e1f,0x645c01e2}},	//   loxo, _dyte_, _hejl, nkqi, 
   {{0x50650e20,0x60c4014f,0x7cd00882,0x61e40115}},	//   _утра, _hujm, _sārd, _kejl, 
   {{0x7cd00029,0x1b1404c5,0x61e50e21,0x62940472}},	//   _pārd, তিলে_, _jejl, noxo, 
   {{0x61e50e22,0xe3bc002e,0x2d9d0e23,0x60c50e24}},	//   _mejl, _dañi_, _gyte_, _jujm, 
   {{0x7cd10e25,0x61e50e26,0x60c50e27,0x38580212}},	//   _vārd, _lejl, _mujm, трою_, 
   {{0xe9cd0e28,0x629407a9,0x60c40477,0x7cd0002b}},	//   _мк_, koxo, _lujm, _dāre, 
   {{0x61e4038e,0x683801b8,0xed8c02d3,0x2d9c009f}},	//   _nejl, _pädä, _ዝሕብር_, _yyte_, 
   {{0x68380724,0xfd5c01f2,0x60c40477,0xa9640212}},	//   _qädä, _rizọ, _nujm, _вища_, 
   {{0x7cd000e2,0xa5040114,0x00000000,0x00000000}},	//   _kārb, јета_, --, --, 
  
   {{0x61e50e29,0x629401b9,0x00000000,0x00000000}},	// [18c00] _bejl, foxo, --, --, 
   {{0x60c4022e,0x00000000,0x00000000,0x00000000}},	//   _bujm, --, --, --, 
   {{0x61e4019b,0x31240e76,0x06bc00cc,0x00000000}},	//   _dejl, рдег, _অবচি, --, 
   {{0x60c50e2a,0x41b4016c,0x2d9c0006,0x644800c5}},	//   _dujm, ссут, _ryte_, ögit, 
   {{0x61e50e2b,0x0d84052f,0x2d9cb0a7,0xa3c80037}},	//   _fejl, әһен, _syte_, रुओ_, 
   {{0x81b400bd,0xa7f80bc9,0x61e45738,0x2d9c00c7}},	//   ছুই_, siñx, _gejl, _pyte_, 
   {{0xafe402d5,0xf1a80e49,0xcda800f1,0x3cfc012d}},	//   _вобл, _करिन, دهغه_, रंगे_, 
   {{0x3f8c0369,0xe3bc1bce,0x7cd000e2,0x31380092}},	//   _fxeu_, _sañi_, _bārb, _የሚታይ, 
   {{0x2aa80228,0x2d9d0e2c,0x6f00004d,0x00000000}},	//   ктоо_, _wyte_, quoc, --, 
   {{0x2d94ac51,0xf1a80034,0x7cd00a88,0xdb0801d3}},	//   _крес, _करान, _dārb, _aggó, 
   {{0x7cd10e2d,0x386800e8,0x00000000,0x00000000}},	//   _pāre, _ŋara_, --, --, 
   {{0x62940107,0xe3bc0de2,0xca8401c6,0xba040022}},	//   zoxo, _wañi_, ргүй, аҭәа_, 
   {{0xe3bc0dd4,0xe5c40249,0x3ce80e3c,0x629407a5}},	//   _hañv_, исво, ćave_, yoxo, 
   {{0x62950e2e,0xe3bc05c7,0x7cd002b5,0x7afd0e2f}},	//   xoxo, _kañv_, _wāre, áste, 
   {{0xd99400aa,0x7cd01da6,0x04c843b1,0xd55402e8}},	//   _پخوا_, _tāre, اوري_, окръ, 
   {{0x61e404ce,0x6d480369,0x84c40022,0x925801d5}},	//   _sejl, ixfa, _ҳәад, یشلر_, 
   {{0x59200135,0x61e50e30,0x62940005,0x758001d5}},	// [18c10] _འགོས_, _pejl, toxo, قییم, 
   {{0xa3c899b6,0x60c4014f,0xfe040027,0x00000000}},	//   रुज_, _pujm, _राइस_, --, 
   {{0x61e4019b,0x61100316,0x7fd4d89b,0xd1c801c0}},	//   _vejl, dělá, білі, рууд_, 
   {{0x60c40369,0x78640124,0x61e4016d,0x918400cf}},	//   _vujm, _kóva, _wejl, زۇقۇ, 
   {{0x533434d8,0x61e48ef1,0x786401ed,0x7eac00e4}},	//   _деят, _tejl, _jóva, húpe, 
   {{0x7eac01f1,0x98a8012c,0x60c50e31,0x8e080212}},	//   kúpe, _brně_, _tujm, инів_, 
   {{0x403406bb,0xbebc00e2,0x6044010a,0x00000000}},	//   _левс, _krūz, _кхаз, --, 
   {{0x7cd000da,0x99840311,0x00000000,0x00000000}},	//   _pārb, _lanţ_, --, --, 
   {{0x3d3405c7,0x6d4c0129,0x00000000,0x00000000}},	//   _wāw_, _àban, --, --, 
   {{0x7cd0002b,0x00a002f2,0x00000000,0x00000000}},	//   _cārc, _بیڵێ, --, --, 
   {{0xe734052f,0x6e4001d9,0xeb9401b9,0xbc1800d3}},	//   ҙер_, _رۆٹم, _қиш_, _білі_, 
   {{0xca8400f7,0x00000000,0x00000000,0x00000000}},	//   йгөй, --, --, --, 
   {{0xe3bc0de2,0xae0c0254,0x00000000,0x00000000}},	//   _kañu_, _सामन_, --, --, 
   {{0xe3bc00e8,0xa6e001a8,0x6f78010f,0x00000000}},	//   _jañu_, íðas, אָלג, --, 
   {{0x33f42626,0x3dc40332,0xfc3801e4,0xbebc6e98}},	//   йчас, _mglw_, nlŭo_, _brūz, 
   {{0xe81474f6,0xe3bc1574,0x503c001f,0x00000000}},	//   ध्दा_, _lañu_, _በሌሎች, --, 
   {{0xf988004b,0xe1f401c0,0xbebc00ef,0xc2e8007b}},	// [18c20] _جنګي_, өгт_, _drūz, لعلم_, 
   {{0xe3bc3d27,0x3a2400d8,0xb5e000fe,0xe3b40107}},	//   _nañu_, nelp_, _বাকচ, сбу_, 
   {{0xc9e40075,0xa3c8012c,0x62800cf4,0x00000000}},	//   _ﺋﯘﻳﻐ, रुङ_, čnop, --, 
   {{0x3a250e32,0x649005d1,0x61b00014,0x00000000}},	//   help_, kçiy, سٕنا, --, 
   {{0xe3bc0de2,0x60d800f3,0x3a24009a,0x00000000}},	//   _bañu_, _čume, kelp_, --, 
   {{0x3a24168c,0x92640244,0x00000000,0x00000000}},	//   jelp_, _بگرم, --, --, 
   {{0xe3bc0694,0x78740064,0xe0d401f4,0x00000000}},	//   _dañu_, ašvi, _гвс_, --, 
   {{0xbf4c012c,0xa0640139,0x8af834ae,0xbebc00ef}},	//   _šířk, _ласа_, анис_, _apūd, 
   {{0xdee007d6,0xe040485b,0x7cd0005f,0x6f6400d3}},	//   _ноти, _энти, _pārc, _уваз, 
   {{0x3a2400d8,0x7eac0419,0x00000000,0x00000000}},	//   gelp_, túpe, --, --, 
   {{0x786400e5,0xd91401f4,0x00000000,0x00000000}},	//   _sóva, бья_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x81e802f5,0x6b346248,0x99d0004b,0x7eac0022}},	//   _যাস_, _دعاء, غتیا, súpe, 
   {{0x7cd07bc9,0xb2f4025c,0xbebc00dc,0x78640332}},	//   _hāra, _བྷེང_, _brūy, _vóva, 
   {{0x7cd10e33,0xd4c40107,0xe7e0012d,0x765801f4}},	//   _kāra, зсуп, परआप, ötya, 
   {{0x213c01fa,0x7cd019ae,0x253800b8,0x6fb805c0}},	//   _čuh_, _jāra, _ānṛṇ, ेशां, 
   {{0x7cd10e34,0x73c00184,0x22740451,0xb784329e}},	// [18c30] _māra, дәре, ٽلاگ_, _дәре_, 
   {{0xf8c8004d,0x00000000,0x00000000,0x00000000}},	//   _mẩn_, --, --, --, 
   {{0xf8c8004d,0x00000000,0x00000000,0x00000000}},	//   _lẩn_, --, --, --, 
   {{0x7cd00882,0xa37800e4,0xe3bc0694,0xc4640244}},	//   _nāra, _leõi, _sañu_, _بیرۆ_, 
   {{0x741400f1,0x00000000,0x00000000,0x00000000}},	//   _بوټا, --, --, --, 
   {{0x78741ebf,0x00000000,0x00000000,0x00000000}},	//   ršvi, --, --, --, 
   {{0x3a240165,0x6e900472,0x00000000,0x00000000}},	//   velp_, بلوا, --, --, 
   {{0xf8c8001e,0x7cd000cd,0x64901432,0x78740064}},	//   _bẩn_, _cāra, tçiy, pšvi, 
   {{0xf8c8001e,0x7cd000dc,0x50640209,0x3a250e35}},	//   _cẩn_, _dāra, _этра, telp_, 
   {{0xba74e251,0xe3bc030a,0xf8c8004d,0x8f08010a}},	//   تابت, _hañs_, _dẩn_, _ыхса_, 
   {{0x8c240729,0xf60801d5,0x00000000,0x00000000}},	//   ভাজন_, یتسه_, --, --, 
   {{0x7cd00055,0x64900790,0xeff40023,0x00000000}},	//   _gāra, pçiy, _ወሓዚ_, --, 
   {{0xfb8401ed,0xe3bc05c7,0xa7f800e4,0x56380240}},	//   _بدای, _mañs_, ukña, _ብምክብ, 
   {{0xe3bc0489,0x97500023,0x8d800023,0x00000000}},	//   _lañs_, _ንኸይት, _ክቕበል_, --, 
   {{0x65c01c50,0x00000000,0x00000000,0x00000000}},	//   дбра, --, --, --, 
   {{0xd13800c6,0x9f4c01a8,0x64480037,0x00000000}},	//   _ĩą_, yggð_, ögip, --, 
   {{0xc8882961,0x02ec05f9,0x80d800fe,0x1b140f22}},	// [18c40] _دخول_, _चौदह_, _ডিষ্, তিকে_, 
   {{0xae0c1ab2,0xd25004d3,0x78a45794,0x00000000}},	//   _साधन_, رۆز_, llkv, --, 
   {{0xe81400dc,0xb4540092,0x786400e5,0x00000000}},	//   ध्वा_, _የፈለጉ, _jóvo, --, 
   {{0x6490025c,0x00000000,0x00000000,0x00000000}},	//   għid, --, --, --, 
   {{0x7cd00053,0x81e800bd,0xe3bc0489,0xcce401ec}},	//   _rāra, _যার_, _dañs_, _ﺍﻹﺘﻔ, 
   {{0x7cd000dc,0xf1a81c93,0x38b001d3,0x78a4007c}},	//   _sāra, _نازه_, lárd_, hlkv, 
   {{0x7cd10e36,0xec68118f,0x78640077,0xf8c80051}},	//   _pāra, ирик_, _nóvo, _sẩn_, 
   {{0x6ab0d04e,0x7df40131,0x80b000f7,0xd1740150}},	//   ँग्र, ققۇچ, _كەلش, _дығы, 
   {{0x3ce80bb8,0xdfcc038b,0x7cd000dc,0xceb82a9d}},	//   ćava_, _شيل_, _vāra, _ләк_, 
   {{0x6f005003,0x7afca3be,0xf8c801fb,0x00000000}},	//   mroc, ásta, _vẩn_, --, 
   {{0x7cd09db5,0x20d40003,0x78a402d2,0x00000000}},	//   _tāra, _għid_, flkv, --, 
   {{0x6f010e37,0x2a7c00d5,0x7afc00e2,0xeb990880}},	//   oroc, sitb_, šsta, _кие_, 
   {{0xf8c8004d,0x5fc800bc,0x7eac00d7,0x00000000}},	//   _uẩn_, िशतल, lúpa, --, 
   {{0x95c800a7,0x78640162,0xb0600166,0xda941291}},	//   жута_, _hóvl, _şälk, _وخوض_, 
   {{0x59200135,0x5558084c,0x00000000,0x00000000}},	//   _འགགས_, оаря_, --, --, 
   {{0x6f004f60,0x88bc0118,0x15b40c75,0x80d800eb}},	//   kroc, hvěz, بەپس, _ডিল্, 
   {{0x4cb4015b,0x64900003,0x6f0000d7,0x00000000}},	// [18c50] ঁদপু, jħie, jroc, --, 
   {{0xe3bc0227,0x93881fe2,0xe8140d2c,0xe1641001}},	//   _sañs_, іста_, ध्रा_, يداي, 
   {{0x6f010e38,0x7fd447c5,0x92681d39,0x4cd00046}},	//   eroc, пілі, црта_, _ﻗﺎﻻﻻ, 
   {{0x6f00011c,0x7cd000ef,0xa4400133,0xe7ac01f9}},	//   froc, _bārn, _تێرو, _घराप, 
   {{0x6f00004e,0xf1d4000d,0x00000000,0x00000000}},	//   groc, _ढ्कन, --, --, 
   {{0x38b06711,0x622002dd,0xb2f40327,0x522400d8}},	//   máre_, _توسە, _བྷིང_, _офса, 
   {{0x61f802a8,0x38b00030,0x44290e39,0x51843594}},	//   _ɓull, láre_, oea_, _жута, 
   {{0x44290e3a,0x6f010e3b,0xbebc00b8,0x6490025c}},	//   nea_, broc, _asūt, bħie, 
   {{0x59200135,0x6f00cc97,0xaf540022,0x38b0da5f}},	//   _འགངས_, croc, _ентә, náre_, 
   {{0x44290e3c,0x7864021c,0x38b000e5,0x00000000}},	//   hea_, _póvo, zárd_, --, 
   {{0x44290e3d,0x38b109f7,0x4ea40b3e,0xbb4855de}},	//   kea_, háre_, _црта, _گلشن_, 
   {{0x44290e3e,0x7cd01d77,0x6f6000cf,0x7aec0327}},	//   jea_, _hāro, _تۇۇم, _ħatf, 
   {{0x4428f520,0x7c290e3f,0x201c00e4,0x1ac8013d}},	//   dea_, meer, _mbui_, _туеп_, 
   {{0x41bc2982,0xf8c80051,0x7cd00171,0xaf74010f}},	//   ्खास, _hẩm_, _jāro, לערס_, 
   {{0x44290e40,0x7cd01da6,0x5fc8ed65,0x3eb8020c}},	//   fea_, _māro, िशाल, _èstu_, 
   {{0x7c290e41,0x44290e42,0x6f010e43,0x8d80044e}},	//   neer, gea_, yroc, _ክንብል_, 
   {{0x6d440227,0x7c28957c,0x38b000e4,0x00000000}},	// [18c60] _ąkam, ieer, gáre_, --, 
   {{0x7c28682b,0x69dc007d,0xf8c8004d,0x6f004f44}},	//   heer, _õpet, _lẩm_, vroc, 
   {{0x44290e44,0x7c290e45,0x35a40323,0xd7650e46}},	//   bea_, keer, _ханг, _رنگی, 
   {{0x44290e47,0xdfcc9f43,0x7c290e48,0x7cd000e2}},	//   cea_, هيم_, jeer, _pārn, 
   {{0x7c290e49,0x38b0003a,0xaf3401d3,0xee3801c0}},	//   deer, cáre_, ثرات, йнд_, 
   {{0xefdc02d3,0x7cd00a2f,0x64900327,0x3f0400c7}},	//   _ዓንዲ_, _cāro, rħie, ьҭуп_, 
   {{0x7c290e4a,0xf8c801fb,0x4c9448a4,0xafe40f06}},	//   feer, _bẩm_, микс, _новл, 
   {{0x7c290e4b,0xae0c4284,0xf8c8001e,0x2c78005f}},	//   geer, _सावन_, _cẩm_, līdz_, 
   {{0x6f64036b,0xd9e0009e,0x7eac1d0e,0x00000000}},	//   _эваз, _মাজম, súpa, --, 
   {{0x44290e4c,0xd448001f,0x2a6801ed,0x6da4035b}},	//   zea_, _አፈፃፀ, óbb_, _еиза, 
   {{0x7c280c8a,0x44290e4d,0x38b000d0,0x6d5c007c}},	//   beer, yea_, záre_, äpad, 
   {{0x7c280936,0x442801c0,0xdf5400aa,0xbbe800cf}},	//   ceer, xea_, _برېښ, _ۇرۇم_, 
   {{0x44290e4e,0xbb4800c6,0x00000000,0x00000000}},	//   vea_, _وجهك_, --, --, 
   {{0x44290e4f,0xccf8012c,0x5af8010f,0xdb18002e}},	//   wea_, _kvě_, _פלוצ, ccuñ, 
   {{0x44290e50,0xf3d802e3,0x88588404,0x56950e51}},	//   tea_, _ọbụn, _микс_, харт, 
   {{0x81e800bd,0x44280607,0xd5b8034b,0xf8c80208}},	//   _যাই_, uea_, яся_, _xẩm_, 
   {{0x44290e52,0xe7e014cf,0xd7fc0375,0xb630036b}},	// [18c70] rea_, _क्या_, _ההחל, رکیش, 
   {{0x7c290e53,0x6ab800d2,0x201c00f3,0x38b0003a}},	//   zeer, nmtf, _sbui_, ráre_, 
   {{0x44290e54,0x44b480df,0x7c290e55,0x51f400c6}},	//   pea_, _обос, yeer, عسكر, 
   {{0x7c290e56,0x4428036b,0x9f4c0129,0xd9e000fe}},	//   xeer, qea_, lagé_, _মাছম, 
   {{0x7c290e57,0x7cd004fe,0x4370001f,0x00000000}},	//   veer, _pāro, _ለመቆጣ, --, 
   {{0x7c290e58,0xbebc0055,0x9f4c06af,0x2c6800a3}},	//   weer, _asūr, nagé_, _rùda_, 
   {{0xae0c00ab,0x3ce801a6,0x1b1400cc,0x7cd00171}},	//   _सारन_, ćavo_, তিছে_, _vāro, 
   {{0x69c8009a,0xccf80316,0x7cd000b0,0x7afd0e59}},	//   _agfe, _dvě_, _wāro, ásto, 
   {{0x7c290e5a,0xdb2013f9,0x7cd00374,0x4fc4cf33}},	//   reer, رودی, _tāro, _كەمە, 
   {{0x7c290e5b,0x00000000,0x00000000,0x00000000}},	//   seer, --, --, --, 
   {{0x7c290e5c,0x38282e3f,0x200c0395,0xf8c801fb}},	//   peer, ожно_, oggi_, _tẩm_, 
   {{0x200d0e5d,0xc5c4015b,0x7c290e5e,0xdb180077}},	//   nggi_, ্রাপ, qeer, scuñ, 
   {{0xec1001b9,0xba540063,0xfc480241,0x00000000}},	//   _شوود, _овдј, atíà_, --, 
   {{0x9f4c07ea,0xf984005a,0x00000000,0x00000000}},	//   gagé_, _огло, --, --, 
   {{0xe5a00075,0x9f4c067c,0x00000000,0x00000000}},	//   вири, sagè_, --, --, 
   {{0x848c0023,0x68300064,0x6730007c,0xe9440066}},	//   _ዘብልን_, gždė, ädjä, _آروی, 
   {{0xf1f8ca3e,0x7aec03be,0x9f4c7cd8,0xae0c0ce0}},	// [18c80] قعات_, _çatd, bagé_, _सालन_, 
   {{0x7cd000da,0xd1d00020,0xa6810e5f,0x66f005f9}},	//   _pārl, _እስቲ_, _альд, _अबतक_, 
   {{0x7cd000de,0x683000c0,0xf3e41422,0x00000000}},	//   _bārm, bždė, _ожно, --, 
   {{0xf8ac00af,0x7bdd0e60,0xef840108,0x00000000}},	//   घतिय, ñsul, млеп, --, 
   {{0x490400cd,0x7afc0419,0x389400cd,0x00000000}},	//   _विभो_, ástl, cāre_, --, 
   {{0x200c02e8,0x00000000,0x00000000,0x00000000}},	//   aggi_, --, --, --, 
   {{0xdd910e61,0x7cd00171,0xc100009d,0x00000000}},	//   кашы, _fārm, _бүхл, --, 
   {{0xe0407327,0x3f9802ea,0x76580108,0x00000000}},	//   _инси, égué_, ötyj, --, 
   {{0x9f4c06af,0x00000000,0x00000000,0x00000000}},	//   yagé_, --, --, --, 
   {{0x7cd000cd,0xdee10190,0x00000000,0x00000000}},	//   _mārj, _рофи, --, --, 
   {{0xfca8004b,0x9f4c73a0,0x00000000,0x00000000}},	//   _کالو_, vagé_, --, --, 
   {{0x89d8a638,0x00000000,0x00000000,0x00000000}},	//   _کوثر_, --, --, --, 
   {{0xdb200174,0x62800010,0x7cd000b8,0xc5c400fe}},	//   _ørðu, čnoz, _nārj, ্ৰাপ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x200c09f3,0x9f4c06af,0x9aa00244,0x00000000}},	//   yggi_, ragé_, _جموو, --, 
   {{0x9f4c06af,0x38941c52,0x69d8081e,0x00000000}},	//   sagé_, tāre_, पुरी, --, 
   {{0x4e000316,0x7cd0002b,0xa5e400ee,0xe3b02586}},	// [18c90] ैलाई_, _cārj, _оюнл, ئرز_, 
   {{0xa1a8608d,0x38680135,0x38b0d08c,0x997800b8}},	//   отез_, _ċari_, mára_, _nāśe_, 
   {{0x38b10e62,0x7cd0005f,0x72c40014,0x00000000}},	//   lára_, _pārm, رٕمۆ, --, 
   {{0x249c02d2,0x7f9401f4,0x00000000,0x00000000}},	//   _ðum_, наех, --, --, 
   {{0x38b05f5b,0x7cd000ef,0x00000000,0x00000000}},	//   nára_, _vārm, --, --, 
   {{0x44390e63,0xb7d40241,0xee3420c8,0x00000000}},	//   _has_, _iṣep, енш_, --, 
   {{0x4438f11e,0x38b007dd,0x6da0c940,0xada10e64}},	//   _kas_, hára_, лиша, лашл, 
   {{0x44390e65,0xfc30034c,0x38b10e66,0x7aec0327}},	//   _jas_, احث_, kára_, _ħatb, 
   {{0x44390e67,0x38b087bc,0x7658005b,0x7cd000de}},	//   _mas_, jára_, ötyk, _kārk, 
   {{0x44390e68,0x38b02655,0xb90801f4,0x00000000}},	//   _las_, dára_, пноз_, --, 
   {{0x44390e69,0x7cd00318,0x0c2401c6,0xa40c0118}},	//   _oas_, _mārk, хмөн, िलाप_, 
   {{0xe45c01b8,0x6d38011a,0x00000000,0x00000000}},	//   _siön_, _מתענ, --, --, 
   {{0x38b001d3,0x16840133,0x00000000,0x00000000}},	//   gára_, ناسێ, --, --, 
   {{0x78650e6a,0x7e78008f,0x7c380067,0x64a07323}},	//   _móvi, לאָז, _hawr, ҳаса, 
   {{0xb7d40248,0x7c38034c,0xd99800e5,0x986403b9}},	//   _aṣep, _kawr, _بخشا_, cığ_, 
   {{0x44390e6b,0x38b00cad,0x7c380de2,0x64a05ce3}},	//   _cas_, bára_, _jawr, гаса, 
   {{0x44390e6c,0x7c390e6d,0x23250e6e,0x27b000d1}},	// [18ca0] _das_, _mawr, ноти_, _бәрс, 
   {{0x44390e6f,0xae0c068f,0x7cd000b8,0x7c390e70}},	//   _eas_, _साइन_, _cārk, _lawr, 
   {{0x44390e71,0xefcc1b49,0xe85004fb,0x30043cbb}},	//   _fas_, _ብሉይ_, _شنید, езег, 
   {{0x61e00c07,0x765d0e72,0x78640077,0x44382734}},	//   ınla, _hopy, _bóvi, _gas_, 
   {{0x765d0e73,0xb8d0081f,0xff14037e,0x986405d1}},	//   _kopy, _ཐེ_, _cの_, zığ_, 
   {{0x765c00e4,0x5f40004b,0xabb00032,0x71740451}},	//   _jopy, انول, һайә, _ٻهرا, 
   {{0x44390e74,0xf1a874e3,0x81c40124,0x765ce247}},	//   _yas_, _راسه_, _аарҧ, _mopy, 
   {{0x44390e75,0x7c380067,0xabb00131,0x765c0064}},	//   _xas_, _cawr, лайә, _lopy, 
   {{0x3ea40270,0x7c390e76,0xddcc012c,0x765c03ac}},	//   _fklt_, _dawr, řešn, _oopy, 
   {{0x38b05f5b,0xfec801f7,0x00000000,0x00000000}},	//   vára_, _قبلو_, --, --, 
   {{0xa37800e4,0x62890b13,0x7c3803cb,0x2bc86518}},	//   _leõp, égoi, _fawr, _елеп_, 
   {{0x6e390e77,0x7c390e78,0x38b029c5,0x00000000}},	//   _hatb, _gawr, tára_, --, 
   {{0x6e380652,0x940c013b,0x7c6400d1,0x46340023}},	//   _katb, _ɔdɔ_, _جالل, _ብምግራ, 
   {{0x44390e79,0x7cd0002b,0x7c38033f,0x38b00e33}},	//   _sas_, _bārh, _zawr, rára_, 
   {{0x44390e7a,0xa8a50c5b,0x6e388258,0x38b01315}},	//   _pas_, _прик, _matb, sára_, 
   {{0x38b00124,0x4438dba6,0x69d80998,0x68f90e7b}},	//   pára_, _qas_, lcte, mstd, 
   {{0x7cd000da,0xe94401d3,0x6e380857,0x833410e4}},	// [18cb0] _pārk, _آرڈی, _oatb, ънах, 
   {{0x44390e7c,0x69d90e7d,0x38940aed,0x20d40327}},	//   _was_, ncte, māra_, _dħin_, 
   {{0x44390e7e,0x68f90e7f,0x81a8015b,0x20c80150}},	//   _tas_, nstd, খেন_, سباي_, 
   {{0x44380b89,0x3ea405b1,0xd1b90e80,0xae0c012c}},	//   _uas_, _sklt_, رالا_, _साउन_, 
   {{0x6e390e81,0x7c380986,0x20d40135,0x38947106}},	//   _batb, _rawr, _għin_, nāra_, 
   {{0x6e390e82,0x7c390e83,0x7cd0e261,0x2bdc01f9}},	//   _catb, _sawr, _hāri, फुसा, 
   {{0x6e380cfd,0x7cd10e84,0x7c9400f3,0x61f4007c}},	//   _datb, _kāri, криц, maxl, 
   {{0x20d42ed2,0x38940882,0x69d80276,0x4e940131}},	//   _içi_, kāra_, ecte, پشۇر, 
   {{0x7cd10e85,0x6e390e86,0xe45c00e4,0x68f801a4}},	//   _māri, _fatb, _moö_, estd, 
   {{0x394424ab,0x7c390e87,0x6e390e88,0x6a84004a}},	//   вног, _wawr, _gatb, _réfè, 
   {{0x71f4015b,0x37e50e89,0x7c387902,0x765d0e8a}},	//   _চামচ_, конг, _tawr, _ropy, 
   {{0xcc150e8b,0x8d844ecc,0x765d0e8c,0x7cd06991}},	//   _مذهب, _сууд, _sopy, _nāri, 
   {{0x765d0e8d,0x64d40521,0x6c78008f,0x68f80175}},	//   _popy, _ụkpụ, _קאנפ, astd, 
   {{0x66e10e8e,0x69d80784,0xbbd0b340,0x6e388761}},	//   рора, ccte, _हलुक, _xatb, 
   {{0x7cd000e2,0x6d4c0129,0x20d40139,0x8bc40139}},	//   _bāri, _àbat, _nçi_, _исәд, 
   {{0x15b80046,0x7cd000cd,0x36680107,0xf77002f2}},	//   дығы_, _cāri, чаҳо_, _ناخ_, 
   {{0x20d40139,0x765d0e8f,0x7cd000dc,0x389400dc}},	// [18cc0] _açi_, _topy, _dāri, cāra_, 
   {{0x9f4c04cc,0x61f4058a,0x00000000,0x00000000}},	//   ragì_, gaxl, --, --, 
   {{0x6d6403f9,0x00000000,0x00000000,0x00000000}},	//   ƙraɗ, --, --, --, 
   {{0xa06400a7,0x20d4025c,0x21a002e8,0x7e7c00c0}},	//   каха_, _tħin_, шихм, _įspa, 
   {{0x6e390e90,0x61f40009,0x737400c7,0x00000000}},	//   _patb, baxl, _рынх, --, 
   {{0x6e38014f,0x68f8000f,0x3870015d,0x2ca50e91}},	//   _qatb, ystd, _llyr_, _skod_, 
   {{0x6e381a7c,0x7aec025c,0x38b00022,0x35b80210}},	//   _vatb, _ħata, járo_, _इरफ़, 
   {{0x62884de4,0x6490025c,0x00000000,0x00000000}},	//   égov, jħil, --, --, 
   {{0xaec40228,0x6e390e92,0x1fa50e93,0x8e140133}},	//   _абал, _tatb, _акти_, _مساڵ, 
   {{0x2ca50e94,0xf8c8004d,0x2be001ad,0x68400241}},	//   _wkod_, _mẩu_, _ट्रू_, _ọdú, 
   {{0x69d90e95,0xf8c801fb,0x65640076,0x7c800023}},	//   rcte, _lẩu_, xyjh, _ንህሉው_, 
   {{0x68f8b784,0x38941a14,0x6490031c,0x69d812f2}},	//   rstd, tāra_, għil, scte, 
   {{0xd1f40201,0xdca045f1,0x7cd002b5,0x3dc40032}},	//   _ውጤት_, _таци, _rāri, _иҫәп_, 
   {{0x7aec47af,0x6d4d0e96,0x26f0130b,0xbebc002b}},	//   _çata, _àbas, _अबीर_, _apūj, 
   {{0x7cd10e97,0x3870ce8a,0x2a900241,0x2b4405c7}},	//   _pāri, _flyr_, _e̟bí_, _hroc_, 
   {{0x4814713a,0x2b440156,0x291c011f,0xd498e78a}},	//   _смис, _kroc_, mtta_, вру_, 
   {{0x291d0e98,0xf8c801fb,0x3ce8110c,0x7cd000cd}},	// [18cd0] ltta_, _cẩu_, ćavi_, _vāri, 
   {{0x7afc1a36,0x21640202,0x6680168d,0x7cd00374}},	//   ásti, ктег, _ئیسل, _wāri, 
   {{0x291d0e99,0x7cd042ef,0x26b01df2,0x61f41dd0}},	//   ntta_, _tāri, _مەڭز, raxl, 
   {{0x291c440f,0x9f481bce,0xb7d400cd,0x50b8ace5}},	//   itta_, _ëlëg_, _kṣap, ندند_, 
   {{0x6d5d0e9a,0x644c1e16,0x78640162,0x291c0165}},	//   äpan, _inci, _góvu, htta_, 
   {{0x644c0334,0x4278010f,0x291c04ab,0x00000000}},	//   _hnci, _טאָג, ktta_, --, 
   {{0x2618367a,0x1138001f,0xdb1400b5,0x20d40200}},	//   _बानी_, _የፋይና, _sノ_, _uçi_, 
   {{0x39490e9b,0x2b450e9c,0x8fd411ca,0xbc2400d1}},	//   _čas_, _broc_, _кәшә, ارغى, 
   {{0x644c0944,0x291d0e9d,0x7c3000f3,0x7f9401c4}},	//   _mnci, etta_, _čerč, _саах, 
   {{0x7eac01f1,0x2b4405c7,0x291c0139,0x00000000}},	//   kúpi, _droc_, ftta_, --, 
   {{0xb7d40241,0x644c24c2,0x9f4c026c,0x00000000}},	//   _aṣap, _onci, lagà_, --, 
   {{0x7e609188,0xb7d40882,0xec6c0798,0x00000000}},	//   _holp, kṣet, _ѓп_, --, 
   {{0x7e610e9e,0x2b44f100,0x291c0869,0xda940724}},	//   _kolp, _groc_, atta_, _искә_, 
   {{0x644cd78a,0x7e60014f,0x7cd00055,0x291c022e}},	//   _anci, _jolp, _dārv, btta_, 
   {{0x644c003e,0x81a803d4,0xf4940138,0x00000000}},	//   _bnci, খেত_, граю, --, 
   {{0x7e60017a,0x74150b6a,0x00000000,0x00000000}},	//   _lolp, طوطا, --, --, 
   {{0xb2250e9f,0xe3bc0124,0xd1f4001f,0x7e610ea0}},	// [18ce0] лмал, _kañy_, _ውጤቱ_, _oolp, 
   {{0xe7444b87,0x644c987e,0x7cd002b5,0xf8c80051}},	//   ções_, _enci, _hāru, _vẩu_, 
   {{0x216400c2,0xc0d002d3,0x7cd09779,0x850000cf}},	//   лифи_, _እብል_, _kāru, _мүрз, 
   {{0x644c0175,0xf8c8004d,0x7cd000de,0xd0106d29}},	//   _gnci, _tẩu_, _jāru, زلت_, 
   {{0x7e6083b3,0x7cd10ea1,0x78640162,0x00000000}},	//   _bolp, _māru, _hóvs, --, 
   {{0x7e610ea2,0x291d0ea3,0xc32c1dc8,0x389400dc}},	//   _colp, ytta_, _تەك_, kāro_, 
   {{0xe2950ea4,0xad250ea5,0x78a4a01b,0x644c02d0}},	//   _сар_, ارتو, kokv, _ynci, 
   {{0x2b450ea6,0x00000000,0x00000000,0x00000000}},	//   _proc_, --, --, --, 
   {{0x2e1452d4,0x78a401b8,0x60d8517b,0x00000000}},	//   _مباح, dokv, _čumi, --, 
   {{0xed5800f0,0x2b4491fa,0x1f610ea7,0x00000000}},	//   _поз_, _vroc_, _укум, --, 
   {{0x291c049b,0x26180073,0x78a40254,0x2d942b2e}},	//   utta_, _बाबी_, fokv, _срас, 
   {{0x291d0ea8,0x7cd09787,0x2b450ea9,0xb9100882}},	//   rtta_, _pārv, _troc_, nnaṃ_, 
   {{0x291c00fd,0x7cd000dc,0x00000000,0x00000000}},	//   stta_, _dāru, --, --, 
   {{0x7eac01f1,0x27e8004e,0x00000000,0x00000000}},	//   túpi, sbcn_, --, --, 
   {{0x78a4017a,0x389400cd,0x00000000,0x00000000}},	//   bokv, cāro_, --, --, 
   {{0x7cd0002b,0xb4500023,0x00000000,0x00000000}},	//   _gāru, _ኣከለጉ, --, --, 
   {{0x0514015b,0xc7b001ed,0x7afc02f0,0x97a400c0}},	// [18cf0] াবের_, _گڑھ_, šstv, _грэл, 
   {{0x7cd09787,0xbbd011b1,0x765801f4,0xe3700150}},	//   _kārt, _हल्क, ötyt, алғы, 
   {{0x7e600660,0x6d5c005b,0xae0c1c5d,0x00000000}},	//   _rolp, äpal, _साजन_, --, 
   {{0x7e610eaa,0x7cd00f40,0x261800c5,0xd1390eab}},	//   _solp, _mārt, _बाडी_, ыху_, 
   {{0x64d80574,0x7e610eac,0xd2500131,0x2d98002d}},	//   _मंडळ, _polp, تنە_, ûpen_, 
   {{0xe0d00133,0x00000000,0x00000000,0x00000000}},	//   _هزر_, --, --, --, 
   {{0x7e610ead,0x3e7807de,0x7cd000cd,0x00000000}},	//   _volp, _lètg_, _nārt, --, 
   {{0x9f4c04cc,0xbc64c547,0xdb200330,0x00000000}},	//   pagà_, рвик, موبی, --, 
   {{0x7e610eae,0x7cd002b1,0xeb300131,0x78a4010f}},	//   _tolp, _rāru, قىيد, vokv, 
   {{0x1fb4054a,0x7e6005d5,0x6e4001d9,0x389448e1}},	//   _алғы_, _uolp, _وۆنم, tāro_, 
   {{0xf9900597,0x7cd0702d,0x6d5c03cd,0xc4b4012d}},	//   تبة_, _pāru, øpat, ंताओ, 
   {{0xf74400c9,0x7d0002d0,0x4aa80137,0x7cd00171}},	//   аемо, _ivls, ккөн_, _dārt, 
   {{0x62850eaf,0x63ac0334,0x3ce4045a,0x7cd000cd}},	//   _omjo, _nycn, _htlv_, _vāru, 
   {{0x3e7807de,0x6d4c0005,0x7afc3fac,0x2618000d}},	//   _dètg_, _ábac, ástu, _बाणी_, 
   {{0x7cd0ec83,0x37e40228,0x33f50eb0,0x00000000}},	//   _tāru, _койг, ичас, --, 
   {{0x628401e2,0xfe7800bc,0x73e400ea,0x7ae8005b}},	//   _amjo, _stůl_, роаз, opet, 
   {{0x7ae8763b,0x63ac0381,0xf5e80276,0x3b0c0334}},	// [18d00] npet, _cycn, _импл_, nreq_, 
   {{0x23240a76,0x14b80574,0x7cd00055,0x00000000}},	//   рофи_, _आठवण, _yārt, --, 
   {{0x7f490eb1,0x7d00011c,0xa11000db,0x2618007d}},	//   _areq, _nvls, قولت, _बाती_, 
   {{0x62840921,0x628814a9,0x010816ac,0x13a804f2}},	//   _emjo, égor, اتلو_, _منجی_, 
   {{0x7b0c06d6,0x7f48030a,0x7d0028b3,0xa0640063}},	//   _ṱung, _creq, _avls, јача_, 
   {{0x7f480023,0xc0d40023,0xfbc820f0,0x7cd00171}},	//   _dreq, _ኪህሉ_, ाइनम, _nārs, 
   {{0xdd8c168d,0xa6dc02f5,0x7f4803ac,0x7ae80393}},	//   ووه_, বীপট, _ereq, epet, 
   {{0xa064bdd4,0x00000000,0x00000000,0x00000000}},	//   _каса_, --, --, --, 
   {{0x7f48044e,0xee390eb2,0x7ae8089c,0xa0648c75}},	//   _greq, _ина_, gpet, _тата_, 
   {{0x7cd10eb3,0x3e7805d5,0x6d5c00cc,0x9100022e}},	//   _pārt, _rètg_, øpas, _ta値i, 
   {{0x7ae80109,0xdc8c02d3,0x6da4010b,0x88bc0118}},	//   apet, _ዝጅምር_, _тижа, jtěc, 
   {{0x7cd00318,0x286801c0,0x7ae80240,0x7b640014}},	//   _vārt, троо_, bpet, _گامٕ, 
   {{0x7ae80137,0x7c2d0eb4,0xbebc00cd,0xe6640064}},	//   cpet, _ñara, _asūy, атво, 
   {{0x7b640014,0x7cd0411e,0x9c840419,0xaab800c5}},	//   _دامٕ, _gārs, _tečú, _उठिक, 
   {{0x67d00058,0x569449b4,0x26c00115,0x99840153}},	//   _һоқу, царт, rmjo_, _danų_, 
   {{0x63ad0eb5,0x18340150,0x00000000,0x00000000}},	//   _pycn, _ۇرۋح, --, --, 
   {{0xaab80c2e,0xdecc0b82,0x99840153,0x78a408ce}},	// [18d10] _उठाक, _ብጹእ_, _fanų_, _íhva, 
   {{0x4394016c,0xe7e0060c,0x85740108,0x7cd00171}},	//   _ҳамс, कुरा_, _глох, _mārr, 
   {{0x7ae90eb6,0x00000000,0x00000000,0x00000000}},	//   zpet, --, --, --, 
   {{0x7ae90eb7,0x7f480f85,0x7534010f,0xd0400213}},	//   ypet, _preq, _פארד_, _kimə, 
   {{0x60d801a6,0x7eac00d0,0x7f4806be,0x00000000}},	//   _čumu, kúpt, _qreq, --, 
   {{0x62840921,0x90280124,0x7ae80051,0x00000000}},	//   _umjo, гцәа_, vpet, --, 
   {{0x5d3000dd,0x1ee401ed,0x614000d1,0x00000000}},	//   تہائ, _چوری_, _بىزە, --, 
   {{0xb7d40a28,0x6adc04c5,0x7f490eb8,0x00000000}},	//   kṣat, _মিজো, _treq, --, 
   {{0x7cd00029,0x7ae90eb9,0x6d5c168c,0x5f740131}},	//   _pārs, upet, øpar, _ئازر, 
   {{0x7ae90eba,0x7aec03be,0xdc8c0023,0x38b00aa6}},	//   rpet, _çatm, _ዝጅመር_, mári_, 
   {{0x7ae90ebb,0x81a800bd,0x8d750ebc,0xf9880451}},	//   spet, খের_, _واما, انجي_, 
   {{0x38580212,0xd04003e3,0x3154010f,0x00000000}},	//   урою_, _bimə, צירן_, --, 
   {{0x3b083aeb,0xbae400f7,0x38b10ebd,0x23a41cba}},	//   _село_, _اكتي, nári_, _कुलद, 
   {{0xb92400ec,0xfe78013a,0x00000000,0x00000000}},	//   _هفتي, _stůj_, --, --, 
   {{0x38b000d0,0x86983da1,0x94c800f1,0x9f4c0166}},	//   hári_, ртят_, لارې_, lagä_, 
   {{0x38b00030,0x7aec025c,0xe81c0210,0x00000000}},	//   kári_, _ħatj, _भाया_, --, 
   {{0x38b00419,0x3668014b,0x00000000,0x00000000}},	// [18d20] jári_, _бапо_, --, --, 
   {{0xe1f44965,0x38b03afd,0x628800e4,0x6d5c01f4}},	//   йгу_, dári_, égop, äpak, 
   {{0x2324036b,0x25d405d0,0x00000000,0x00000000}},	//   _қори_, _לוין_, --, --, 
   {{0x38b000d8,0x68f40210,0xb7f800ce,0x00000000}},	//   fári_, _łydk, ्णिम_, --, 
   {{0x27e406be,0x00000000,0x00000000,0x00000000}},	//   _ənn_, --, --, --, 
   {{0xa2e06c5b,0x00000000,0x00000000,0x00000000}},	//   _хорд, --, --, --, 
   {{0x26190ebe,0xafe45332,0x21640a0e,0x162000c5}},	//   _बासी_, _гобл, _лири_, _बानर_, 
   {{0x6ab044af,0x9f4c0421,0x7a200100,0x38b00419}},	//   ुग्र, fagä_, _lňtč, bári_, 
   {{0x7cd0005f,0x3e7839b4,0x7eac00d0,0xceb801ee}},	//   _pārr, _sète_, túpt, _кәк_, 
   {{0x6f010ebf,0x3e78af8c,0x1f6000c0,0x00000000}},	//   msoc, _pète_, _экум, --, 
   {{0x6f00a5b6,0xace80120,0xa6100131,0x00000000}},	//   lsoc, _смеа_, үзмә, --, 
   {{0xca840323,0x13b0015b,0x6f000789,0x00000000}},	//   сгүй, চেয়, osoc, --, 
   {{0x6f010ec0,0x23a41431,0x00000000,0x00000000}},	//   nsoc, _कुंद, --, --, 
   {{0xaa3400db,0x3e790ec1,0xca48009f,0x4f2c0092}},	//   _اۋدئ_, _tète_, _ضلعه_, _ሳይደር, 
   {{0x7cd01981,0xa9c400f2,0x7c2c08a5,0x6d5c01f4}},	//   _kārp, _ازشو, _þorð, äpah, 
   {{0x44b402dd,0x6f010ec2,0x00000000,0x00000000}},	//   ібас, ksoc, --, --, 
   {{0x0ea801ad,0x6f0001e4,0x228c012d,0x948479ea}},	// [18d30] गवाड, jsoc, eżka_, чырд, 
   {{0x51f80962,0x6f000267,0x3eb800de,0x38b001d3}},	//   йную_, dsoc, _īsto_, vári_, 
   {{0x6f000142,0x00000000,0x00000000,0x00000000}},	//   esoc, --, --, --, 
   {{0x26d000f1,0x9f4c0724,0xd1c801c0,0x26d80200}},	//   _hixo_, yagä_, сууд_, _kuqo_, 
   {{0x44290ec3,0x6f0001bf,0x00000000,0x00000000}},	//   mfa_, gsoc, --, --, 
   {{0x38b10ec4,0x00000000,0x00000000,0x00000000}},	//   rári_, --, --, --, 
   {{0x26d00564,0x44290ec5,0x38b10ec6,0x26d83df1}},	//   _mixo_, ofa_, sári_, _luqo_, 
   {{0x44290ec7,0x26d010ba,0xbebc0055,0x7cd00055}},	//   nfa_, _lixo_, _apūt, _cārp, 
   {{0x2908066d,0xd0400085,0x44290ec8,0xbb44020f}},	//   ában_, _limɛ, ifa_, цепк, 
   {{0x44290ec9,0x7eac0332,0xd358011a,0x00000000}},	//   hfa_, rúps, משחק_, --, 
   {{0xdd990eca,0x162006ab,0x3894005f,0x42e4015b}},	//   _сша_, _बाबर_, lāri_, _ফটোশ, 
   {{0xc5e81203,0x44290ecb,0x26d00137,0x22400841}},	//   _יד_, jfa_, _aixo_, _lajk_, 
   {{0x7c28b5a3,0x27fc09cc,0x44280cfd,0x26d00120}},	//   mfer, ðuna_, dfa_, _bixo_, 
   {{0x7c290ecc,0x44290ecd,0xe45c00a2,0x228c0210}},	//   lfer, efa_, _yhög_, yżka_, 
   {{0x26d0172e,0xf7700222,0x2618924b,0x6f0002f0}},	//   _dixo_, ساڭ_, _बारी_, zsoc, 
   {{0x74149d01,0x44290ece,0x26d010ba,0x29d001ec}},	//   تورا, gfa_, _eixo_, _تيىس, 
   {{0x26d10ecf,0xd3703baf,0x9ae40198,0x867805f5}},	// [18d40] _fixo_, رۇس_, _ƙiƙi_, рөөр_, 
   {{0x44290ed0,0x201c003a,0x7c28002d,0x6f00007c}},	//   afa_, _acui_, hfer, vsoc, 
   {{0x7c290896,0x44280175,0x6f0003cb,0xd25001e2}},	//   kfer, bfa_, wsoc, ونړ_, 
   {{0x44290ed1,0x7c280cf9,0x6f010ed2,0x224001c6}},	//   cfa_, jfer, tsoc, _eajk_, 
   {{0xee38f51b,0x7c290ed3,0x26d00139,0x8f8401d5}},	//   инд_, dfer, _yixo_, чқал, 
   {{0x7c290ed4,0x6f010ed5,0x0cb40882,0x81a8015b}},	//   efer, rsoc, ुष्म, খেই_, 
   {{0x7c290ed6,0x7cd000da,0xafe50ed7,0xe12034ac}},	//   ffer, _pārp, _мовл, _омри, 
   {{0x7c290ed8,0xeb04009d,0x00000000,0x00000000}},	//   gfer, очоо, --, --, 
   {{0x6f00010a,0x26186bcf,0x92dc0183,0xef9000f1}},	//   qsoc, _बाली_, ণীৰ_, _کیږد, 
   {{0x7c280356,0x29080077,0x49a401ec,0x00000000}},	//   afer, ábao_, зымғ, --, 
   {{0x44290ed9,0x38b00118,0xa2a80a97,0x7cd000de}},	//   yfa_, háru_, जकत्, _tārp, 
   {{0xab284727,0x7c280077,0x2bc80276,0xd7f90eda}},	//   _вода_, cfer, _куло_, жур_, 
   {{0xa09800c8,0x3e78067c,0xaa440c9e,0xac940022}},	//   שיכט, _hèta_, _медл, _лаҧш, 
   {{0xee2c10da,0xca2001ec,0x00000000,0x00000000}},	//   енi_, _ﺸﻴﺦ_, --, --, 
   {{0x44290edb,0x35780107,0x00000000,0x00000000}},	//   tfa_, барӯ_, --, --, 
   {{0x44290edc,0xd5b90edd,0x26d80ba7,0x3e78067c}},	//   ufa_, юся_, _tuqo_, _mèta_, 
   {{0x44290ede,0x26d10edf,0x68e8010a,0x22405049}},	// [18d50] rfa_, _tixo_, _htfd, _pajk_, 
   {{0x44290ee0,0x4eac00bd,0x02600133,0x7c2800e5}},	//   sfa_, গগুল, رێزێ, zfer, 
   {{0x442885ba,0x7c290ee1,0x80e000fe,0xd164011c}},	//   pfa_, yfer, _পটঙ্, мъци, 
   {{0xdb0c00fd,0x7c290ee2,0x44280135,0x46140956}},	//   _çeçn, xfer, qfa_, _بوگر, 
   {{0xdb04046c,0x7c282dba,0x3ce401ec,0x00000000}},	//   ümüz, vfer, _ﺍﻨﺘﻤ, --, 
   {{0x0e640046,0x3e781f3f,0xbebc00cd,0x7aed0ee3}},	//   мкін, _bèta_, _apūr, _çati, 
   {{0x7c290ee4,0x6d4c007b,0xbebc0024,0x64900327}},	//   tfer, _ábal, _spūs, bħit, 
   {{0x201c0481,0x7c28b7e1,0x5bc01d00,0x6da000cf}},	//   _ucui_, ufer, _ﺯﻭﺭﻻ, رۅنم, 
   {{0xceac0184,0x6d4803cd,0xef900451,0x00000000}},	//   _аҙ_, avfa, _ٻڌند, --, 
   {{0xb7d40241,0xbdc00150,0xaea000db,0x88bc0118}},	//   _iṣip, _كەشۋ, _كەني, utěn, 
   {{0x68e80204,0x7c290ee5,0xa92065eb,0x38b03afd}},	//   _ctfd, pfer, ндэл, záru_, 
   {{0xe8ec05f5,0xb7d40882,0x88bc012c,0x38b001ed}},	//   _үл_, _kṣip, stěn, járt_, 
   {{0xaca800f8,0x7bd8063f,0x162000c5,0x81c000eb}},	//   _اپنے_, _igwu, _बादर_, ঁশি_, 
   {{0xe7340e92,0x00000000,0x00000000,0x00000000}},	//   џер_, --, --, --, 
   {{0x1ae0015b,0x098821f3,0xb8c400db,0x1dc800cd}},	//   _মিয়া, _машқ_, _ىزعى, ाधित, 
   {{0x4cd800cc,0x370449c4,0x00000000,0x00000000}},	//   ণীকু, _епиг, --, --, 
   {{0xb9c802d3,0xb38405f5,0xd24400c7,0x00000000}},	// [18d60] _ሳላ_, члал, ммақ, --, 
   {{0x6d48007c,0xb8800c5e,0x00000000,0x00000000}},	//   yvfa, _žíha, --, --, 
   {{0xd5b0c0f9,0x7bd801f2,0x00000000,0x00000000}},	//   _شہر_, _ogwu, --, --, 
   {{0x7bd802e3,0x00000000,0x00000000,0x00000000}},	//   _ngwu, --, --, --, 
   {{0xe81c033d,0x00000000,0x00000000,0x00000000}},	//   _भासा_, --, --, --, 
   {{0x7bd8063f,0xed40030d,0x00000000,0x00000000}},	//   _agwu, _агlо_, --, --, 
   {{0xdb040745,0x3894005f,0x6490025c,0xd72800eb}},	//   _člán, lāru_, mħir, মিয়া_, 
   {{0x65c40098,0x5cc0e9ae,0x5d1000db,0x00000000}},	//   léhé, нсыз, ربىز, --, 
   {{0x3894005f,0xa0a0010b,0x00000000,0x00000000}},	//   nāru_, _чатд, --, --, 
   {{0x7bd805db,0x7d0c0227,0x20d40327,0x38b001d3}},	//   _egwu, ņasa, _għis_, zárt_, 
   {{0x38b00174,0x00000000,0x00000000,0x00000000}},	//   járs_, --, --, --, 
   {{0x65c40098,0x00000000,0x00000000,0x00000000}},	//   héhé, --, --, --, 
   {{0xfca80014,0x00000000,0x00000000,0x00000000}},	//   _بالو_, --, --, --, 
   {{0xc0cc067d,0x6d4c0327,0xe81c0b3c,0x00000000}},	//   _ብዙሕ_, _ġbaj, _भावा_, --, 
   {{0x95c80b3b,0x38b001d3,0x6fbc00d1,0x00000000}},	//   зута_, tárt_, ﺭﺩﺍﺷ, --, 
   {{0x99840142,0x64900327,0x00000000,0x00000000}},	//   _canŵ_, eħir, --, --, 
   {{0x4e1c0316,0x533412cd,0x00000000,0x00000000}},	// [18d70] नलाई_, нетт, --, --, 
   {{0x38b00419,0x94840139,0x00000000,0x00000000}},	//   bárs_, _җыюд, --, --, 
   {{0x5900025c,0x20d40327,0xe504009f,0x9f480241}},	//   ྙེགས_, _rħis_, _عبدي, _àmús_, 
   {{0xbebc00b8,0x25b401d9,0x00000000,0x00000000}},	//   _apūp, _ونکھ_, --, --, 
   {{0x65c4020c,0x938800d8,0xc1c400d1,0x38940055}},	//   béhé, _есра_, _ﺩﺍﺩﺍ, cāru_, 
   {{0x73c0053f,0x4fc43ee0,0x291000b8,0x00000000}},	//   _рәсе, رەلە, _āyan_, --, 
   {{0x3cc80276,0xada086e5,0x6da007a5,0x51844572}},	//   олко_, кашл, киша, _зута, 
   {{0xe81c09bb,0x7e7c0064,0x00000000,0x00000000}},	//   _भाषा_, _įspu, --, --, 
   {{0xfc380115,0x28e402dd,0x00000000,0x00000000}},	//   reŭ_, _ﺍﻟﺨﻠ, --, --, 
   {{0xb908013d,0x00000000,0x00000000,0x00000000}},	//   оноз_, --, --, --, 
   {{0x389400da,0x98b001a6,0xb178010f,0xcb44009d}},	//   kārt_, žača_, ַטשר, _үхчи, 
   {{0x162009d9,0x3f6400b5,0x00000000,0x00000000}},	//   _बाहर_, のusb_, --, --, 
   {{0xeb8c6a40,0x3360001f,0x59000327,0xbb44005b}},	//   _ри_, _ተካሄደ_, ྙེངས_, _целк, 
   {{0x38b001d3,0xaad8011a,0x00000000,0x00000000}},	//   társ_, _וחסר, --, --, 
   {{0xd76800cf,0x00000000,0x00000000,0x00000000}},	//   زەگى_, --, --, --, 
   {{0x389400e2,0x00000000,0x00000000,0x00000000}},	//   tāru_, --, --, --, 
   {{0x23240aa5,0x00000000,0x00000000,0x00000000}},	// [18d80] моти_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf77043f3,0x65c40098,0x35a473f6,0x00000000}},	//   _ساک_, réhé, _цанг, --, 
   {{0x389400e2,0x00000000,0x00000000,0x00000000}},	//   mārs_, --, --, --, 
   {{0xe7e00316,0x389400e2,0xca6001a9,0x00000000}},	//   कुटा_, lārs_, kumа, --, 
   {{0x717405d9,0x6d4c02d2,0x9e30d54f,0x00000000}},	//   _ٺهرا, _ábak, вешч, --, 
   {{0x3894005f,0x614048bd,0xe81c00c5,0xa2a8024a}},	//   nārs_, _иера, _भाला_, जकर्, 
   {{0x3e780248,0xabb00131,0xe478010f,0xabcc0220}},	//   _fèto_, кайә, ַריכ, _ﻗﻭﺍﻋ, 
   {{0xb7d40055,0xfee8007b,0xb4b40210,0x00000000}},	//   _kṣup, _فعلى_, _चीज़_, --, 
   {{0x7aec0327,0x81a800eb,0x00000000,0x00000000}},	//   _ħatt, খেও_, --, --, 
   {{0x06bc0eac,0x596001c6,0xf8c80051,0x00000000}},	//   _ইংলি, въяа, _hẩy_, --, 
   {{0x3eb8005f,0x00000000,0x00000000,0x00000000}},	//   _īsti_, --, --, --, 
   {{0xab990ee6,0x64800254,0xfca800f1,0xb7d40241}},	//   _بخار_, _hõig, _عامو_, _oṣup, 
   {{0x6480033d,0x99d00330,0xf8c80051,0xcc880244}},	//   _kõig, عتیا, _mẩy_, _بنچه_, 
   {{0xf8c80051,0x2444009d,0x00000000,0x00000000}},	//   _lẩy_, мхаг, --, --, 
   {{0x26188d42,0x64800254,0xdce00064,0x00000000}},	//   _बाकी_, _mõig, gynę, --, 
   {{0x648000af,0x25bc03f9,0xd7fc0375,0xf8c80208}},	// [18d90] _lõig, ƙulo_, _והחל, _nẩy_, 
   {{0x389400ef,0x00000000,0x00000000,0x00000000}},	//   bārs_, --, --, --, 
   {{0xa8040166,0x00000000,0x00000000,0x00000000}},	//   _tuñı, --, --, --, 
   {{0xb9c802d3,0xf8c8004d,0x00000000,0x00000000}},	//   _ሳዋ_, _bẩy_, --, --, 
   {{0x7c2c00e8,0x30cc0150,0xcf2400ae,0x00000000}},	//   _ñari, _ﺑﯟﻻﻧ, نروي, --, 
   {{0xc0cc0020,0x3e78068c,0xb900031c,0x171c008f}},	//   _ብዙም_, _vèto_, _ཧྤ_, קווע, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x88bc0316,0x91840228,0xd01800f3,0xdb200633}},	//   stěj, _جۇمۇ, _офу_, نوبی, 
   {{0x6d5d0ee7,0xbf140214,0x64800254,0xf8c80051}},	//   äpar, _سواب, _eõig, _gẩy_, 
   {{0x26180dad,0xdce0012d,0x00000000,0x00000000}},	//   _बागी_, zynę, --, --, 
   {{0x64d80490,0xcd04267c,0x2d9800d0,0x00000000}},	//   _मंगळ, _аччи, ĺpec_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd05c013f,0xd5b8005f,0xf8c80208,0xe5a00aac}},	//   _atrɛ, ļām_, _xẩy_, ҳири, 
   {{0x389400e2,0x6448000f,0x6fd403b9,0x57e402dd}},	//   tārs_, ôgin, _hücü, _ﺍﯞﯨﺮ, 
   {{0xe5a06bee,0x81e4015b,0x6fd40790,0x00000000}},	//   гири, নরা_, _kücü, --, 
   {{0xb4a800c5,0x64800037,0x7aec03b9,0x00000000}},	//   खके_, _nõid, _çats, --, 
   {{0xb7d40a28,0x78b40022,0x8a1802dd,0xdb2000e4}},	// [18da0] kṣit, _ikyv, _ءتۇس_, _ïräv, 
   {{0xf8c8004d,0x00dc0150,0x00000000,0x00000000}},	//   _rẩy_, _ﻁﺎﺒﻘ, --, --, 
   {{0x7cd000da,0x6e3c0213,0xf8c8004d,0xea74010f}},	//   _dārz, _özbə, _sẩy_, עגער_, 
   {{0x92c00154,0x00000000,0x00000000,0x00000000}},	//   ঁদে_, --, --, --, 
   {{0xa00401d5,0x28e40150,0x7e7c0064,0x6ab801e3}},	//   رقول_, _ﺍﻟﺤﻠ, _įspr, yltf, 
   {{0xf8c8004d,0x6480000d,0x37c000fe,0x00000000}},	//   _vẩy_, _põig, _এলাৰ, --, 
   {{0x78b400c7,0x7cd000b8,0x6fd40205,0x76580108}},	//   _okyv, _hāry, _bücü, ötyy, 
   {{0x7cd00a28,0xf8c8001e,0x6d5c0309,0xb6040427}},	//   _kāry, _tẩy_, äpaq, lušč, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdee04482,0x64800254,0x7cd000b8,0x00000000}},	//   _софи, _tõig, _māry, --, 
   {{0x29080bfa,0x00000000,0x00000000,0x00000000}},	//   éba_, --, --, --, 
   {{0xe45c145e,0x6fd44a4a,0xf8ac00aa,0xb4a80316}},	//   _ahön_, _gücü, يکي_, खको_, 
   {{0x6b64002e,0x9874d4d5,0x7cd000cd,0x00000000}},	//   _dégë, уляц, _nāry, --, 
   {{0xe664016c,0x2b44003a,0xdcdc13f5,0x00000000}},	//   хтмо, _isoc_, _पूँछ, --, 
   {{0x555800a8,0xb60401fa,0x48c40116,0xa85001e0}},	//   наря_, dušč, _ишиғ, _бейә, 
   {{0x5a6000c7,0xf9680212,0x98c401af,0x00000000}},	//   _акәб, _юрій_, _йсыл, --, 
   {{0xe3b02e6f,0x61f801fa,0x82d8039b,0x7cd01a14}},	// [18db0] ارز_, _đulb, ддас_, _cāry, 
   {{0x979c0d65,0x6480033d,0x261801b0,0x02bc1a22}},	//   _משחק, _sõid, _बाटी_, ्गेन, 
   {{0x291c1591,0x80ac0073,0x45d41d39,0xed400408}},	//   nuta_, जवले, _јонс, _агiо_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x54550ee8,0x291c7e24,0x6480007d,0xb60449ad}},	//   _свят, huta_, _võid, bušč, 
   {{0x66050ee9,0x88bc00bc,0x2284013d,0x00000000}},	//   najk, stěh, _чумг, --, 
   {{0x291d0eea,0xd6580bd4,0x22b00724,0xae0000d1}},	//   juta_, תיות_, _eşkä_, شۈنى, 
   {{0x66050eeb,0x3eb800e2,0x6fd406be,0xd0d40395}},	//   hajk, _īstu_, _qücü, _босъ, 
   {{0x8fd40831,0x60d80194,0x66050eec,0x291c07de}},	//   _йәшә, _iium, kajk, euta_, 
   {{0x78b50eed,0xdb081f53,0xd01001d3,0x12cc02dd}},	//   _skyv, _nygå, _پلے_, _ﺒﺎﻟﻭ, 
   {{0x291c05b8,0x60d80451,0x66040030,0xa9040451}},	//   guta_, _kium, dajk, نڊيل_, 
   {{0xc5f4416c,0x92dc0011,0x6294022e,0x00000000}},	//   ңғы_, ণীয়_, hixo, --, 
   {{0x60d90eee,0x291d0eef,0xdb08003b,0x6294005a}},	//   _mium, auta_, _bygå, kixo, 
   {{0x291d0ef0,0xdb08012d,0x6294022e,0x7aec0166}},	//   buta_, _wzgó, jixo, _çatq, 
   {{0x291d0ef1,0x6294009a,0x00000000,0x00000000}},	//   cuta_, dixo, --, --, 
   {{0x60d90ef2,0x64a005f5,0x6b940006,0x6294004e}},	//   _nium, ааса, _žygi, eixo, 
   {{0xb2242de0,0x1620000d,0x116805af,0x00000000}},	// [18dc0] кмал, _बाऊर_, کلای_, --, 
   {{0x62940117,0x660416a3,0x7cd000cd,0xe2800a5b}},	//   gixo, cajk, _vāry, алуи, 
   {{0xb60400c0,0x00000000,0x00000000,0x00000000}},	//   rušč, --, --, --, 
   {{0x60d90ef3,0x764cf20e,0x6480000d,0x7cd00055}},	//   _cium, ldby, _põie, _tāry, 
   {{0x60d90ef4,0x27fc0579,0xb604151c,0x291d0ef5}},	//   _dium, ðuni_, pušč, zuta_, 
   {{0x764c5c3d,0xf1c4010b,0x228c012d,0x00000000}},	//   ndby, _айгп, yżki_, --, 
   {{0x60d8f622,0x4c94409a,0xafe4035b,0x3dd40011}},	//   _fium, ликс, _аобл, _স্বল, 
   {{0x291d0ef6,0x60d90ef7,0xef9007d6,0x77640332}},	//   vuta_, _gium, _پیتد, kxkx, 
   {{0x291d0ef8,0x66040113,0xc0cc0092,0x00000000}},	//   wuta_, yajk, ብኝም_, --, 
   {{0x291d0ef9,0x60d852ae,0xed5800f7,0x7c2c0267}},	//   tuta_, _zium, _ооз_, _öarn, 
   {{0x621800c8,0x3ea80407,0x6604821e,0x764c0158}},	//   וויק, éate_, vajk, ddby, 
   {{0x765c007f,0x60d8213f,0x62940944,0x764c0369}},	//   _anpy, _xium, zixo, edby, 
   {{0x291d0efa,0x3e78180f,0x6a850efb,0x2ca4036b}},	//   suta_, _bèth_, _илда, _ijod_, 
   {{0x291d0efc,0x477000d1,0x00000000,0x00000000}},	//   puta_, иққу, --, --, 
   {{0x660405a1,0x291c3d07,0xd4e41422,0x00000000}},	//   rajk, quta_, июти, --, 
   {{0xd5f0030d,0x00000000,0x00000000,0x00000000}},	//   _чlог, --, --, --, 
   {{0x1cc849a6,0x629401b9,0xa7f80784,0x60d90efd}},	// [18dd0] _ྲེལ_, tixo, jjñi, _rium, 
   {{0x60d80af5,0x2ca40158,0x53350efe,0x66040784}},	//   _sium, _ljod_, рефт, qajk, 
   {{0x60d80af5,0x648000af,0x629497c3,0x01c400c7}},	//   _pium, _võib, rixo, ураҭ, 
   {{0x62950eff,0x9f4c011f,0xd1c801c0,0x9f48002e}},	//   sixo, xagó_, тууд_, _ëmët_, 
   {{0x60d80451,0xc0c402dd,0x28e402dd,0x00000000}},	//   _vium, _ұшақ, _ﺍﻟﺴﻠ, --, 
   {{0x03a40124,0x614000f7,0x3eb800de,0x00000000}},	//   _аиҭо, _پىرە, _īsts_, --, 
   {{0x60d90f00,0x00000000,0x00000000,0x00000000}},	//   _tium, --, --, --, 
   {{0xe81c0d41,0x0d74010b,0x00000000,0x00000000}},	//   _भागा_, рышя, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7f490f01,0x8d740131,0xb8840306,0xdedc0023}},	//   _iseq, _ھالا, _mníš, _ናህና_, 
   {{0x8d750f02,0x0ae800f7,0xe81c2d8f,0xb5a00150}},	//   _پالا, ндөй_, _भाखा_, _ﺍﻣﺎﻝ_, 
   {{0x06bc04c5,0x8d840137,0x3dd40011,0x8b640133}},	//   _ইংগি, _тууд, _স্থল, _چاوم, 
   {{0x3e78067c,0x8b640133,0x3f7800df,0x00000000}},	//   _pèth_, _ناوم, גאָס, --, 
   {{0xe45c0374,0x66e10f03,0x764c01bf,0x00000000}},	//   _anö_, сора, udby, --, 
   {{0x764c143a,0x7ae802d1,0x3ae80208,0x6d4c032e}},	//   rdby, lqet, _húp_, _ábat, 
   {{0x7f480117,0xb4bc012c,0x3ae81315,0xe8f40209}},	//   _oseq, इते_, _kúp_, _ёлы_, 
   {{0x59000327,0xfbc80ebb,0x3ae80051,0x7ae8036e}},	// [18de0] ྙེམས_, ाइटम, _júp_, nqet, 
   {{0x3870022c,0xe3b50681,0x3b0c013c,0xe294a5c1}},	//   _hoyr_, убу_, iseq_, гау_, 
   {{0x7f490f04,0x387006ea,0x3ae80208,0x00000000}},	//   _aseq, _koyr_, _lúp_, --, 
   {{0x2d8002b5,0xe29400fb,0x251800df,0x00000000}},	//   _āke_, _ҡая_, _אוטא, --, 
   {{0x7d0002d0,0x3ae8004d,0x888c00df,0x00000000}},	//   _awls, _núp_, וראַ, --, 
   {{0xacd0052f,0x3ce400ef,0x25080244,0x00000000}},	//   әбиә, _bulv_, _تریی_, --, 
   {{0x7f490f05,0x20f001fa,0xe2800a5b,0x7dcc0022}},	//   _eseq, _aćif_, _улри, võsé, 
   {{0x3ae801fb,0x9f4c0100,0xa174010f,0x7ae8036e}},	//   _búp_, ragò_, _געלד_, fqet, 
   {{0x3ae801fb,0x7ae8009a,0x00000000,0x00000000}},	//   _cúp_, gqet, --, --, 
   {{0xdb0c010e,0x1b1400c7,0x00000000,0x00000000}},	//   _çeýn, ыжьы_, --, --, 
   {{0x3b0c0eda,0x3ce44e9b,0x2d8803cd,0xdea03451}},	//   aseq_, _gulv_, _åbe_, _دیوی, 
   {{0x387000ad,0x00000000,0x00000000,0x00000000}},	//   _coyr_, --, --, --, 
   {{0x3e78180f,0x387006ea,0x9cb016ac,0x64800037}},	//   _sèti_, _doyr_, _امنت, _nõia, 
   {{0xe45c01e6,0xd498013e,0x672c010a,0x00000000}},	//   _snö_, ҳру_, rtcj, --, 
   {{0x387000ad,0x291848bf,0x00000000,0x00000000}},	//   _foyr_, _ípa_, --, --, 
   {{0xd498084c,0x3e780100,0xf928010f,0x00000000}},	//   гру_, _vèti_, _סופּ, --, 
   {{0x3ae80051,0x00000000,0x00000000,0x00000000}},	// [18df0] _xúp_, --, --, --, 
   {{0x66810f06,0xe290007b,0x00000000,0x00000000}},	//   _ایسل, حذر_, --, --, 
   {{0x3ff4007b,0x00000000,0x00000000,0x00000000}},	//   لكار, --, --, --, 
   {{0xb4f804ac,0x40344b4d,0x7f1801ce,0x7ae8dea7}},	//   _שפרי, редс, віку_, yqet, 
   {{0x4f9405f5,0x644c16b8,0x44390f07,0x4f580212}},	//   йршу, _iaci, _ibs_, лицю_, 
   {{0x644d0f08,0x6d540882,0xc0cc02d3,0x6d4c031c}},	//   _haci, āyan, _ኢዶም_, _ġbar, 
   {{0x644d0f09,0x3ae90f0a,0xc0f40092,0x2bd00a8a}},	//   _kaci, _súp_, ዎቹም_, देसा, 
   {{0x644d0f0b,0x3b0c013c,0xc0c400d1,0x00000000}},	//   _jaci, tseq_, _тәзи, --, 
   {{0x7ae80333,0x7f490f0c,0x00000000,0x00000000}},	//   uqet, _useq, --, --, 
   {{0x644d0f0d,0x3ce40254,0x3b0c014f,0x00000000}},	//   _laci, _tulv_, rseq_, --, 
   {{0xf8641049,0x644c0077,0x3b0c0140,0x7d000009}},	//   авно, _oaci, sseq_, _uwls, 
   {{0x44390f0e,0x31e4015b,0x9d500014,0x2bd01788}},	//   _nbs_, _পড়াশ, _پنچت, देहा, 
   {{0xe3bc0432,0x6d4c02d2,0x7ae803e3,0x00000000}},	//   _nyñ_, _ábar, qqet, --, 
   {{0x44387062,0x96200034,0xdbb401e0,0x06b80133}},	//   _abs_, बलेट_, _итһә_, ێنێک_, 
   {{0xf494cef8,0x44390f0f,0xa5050f10,0xf504013e}},	//   араю, _bbs_, иера_, рзбо, 
   {{0x2bd007b7,0xb4e476f8,0x62880200,0x00000000}},	//   देवा, _पढी_, ëgon, --, 
   {{0x44390f11,0x644d0f12,0xd1dc02d3,0xb6a402bf}},	// [18e00] _dbs_, _daci, ዕዋት_, _випл, 
   {{0x44390f13,0xe1f4024d,0xe690004b,0x88bc00bc}},	//   _ebs_, игу_, _وليد, stět, 
   {{0x644d0f14,0xb1450f15,0x0cd00150,0x34a800f3}},	//   _faci, рнел, _ﺗﺎﯞﻗ, _авно_, 
   {{0x44380998,0x644c992e,0x92e4015b,0x78a40738}},	//   _gbs_, _gaci, _নবী_, nnkv, 
   {{0x648000c7,0x78a40158,0xf08801d5,0xca3801e4}},	//   _kõin, inkv, _یئره_, liĝe_, 
   {{0x5f140b7d,0x644d0f16,0x7c380112,0xe1f4010a}},	//   _निर्_, _zaci, _abwr, _вгр_, 
   {{0x644c0eb4,0x44390f17,0x21650f18,0x8e7c010f}},	//   _yaci, _ybs_, _кири_, _niĝe, 
   {{0x67145d4f,0x644d0f19,0x7aec002b,0x00000000}},	//   _तिलक_, _xaci, _ũata, --, 
   {{0xab8412e7,0xfbcc0050,0x00000000,0x00000000}},	//   руйк, ى۪م_, --, --, 
   {{0x81cc2baf,0xddc000a2,0x00000000,0x00000000}},	//   _ষ্ট_, kenň, --, --, 
   {{0x798c0b45,0x3dc803f9,0xfaf800b0,0x2900009b}},	//   _ƙawa, ƙawa_, apū_, ćkao_, 
   {{0x2d8c0165,0x49a402dd,0xdd78010f,0x6d590f1a}},	//   mzfe_, _қылғ, _שטאל, _irta, 
   {{0x2bd0206b,0xd83805f5,0x7c6400f1,0x6d5802f0}},	//   देशा, шээ_, _دالل, _hrta, 
   {{0x644d0f1b,0x6d590f1c,0xfd480055,0x44380b84}},	//   _saci, _krta, _asmṛ, _sbs_, 
   {{0x4438123b,0x2bd002c3,0x38b0022a,0xe4d4007b}},	//   _pbs_, देरा, háry_, لترب, 
   {{0x6d58098d,0x644d0f1d,0x1cb00327,0x38b002f0}},	//   _mrta, _qaci, ྟོར_, káry_, 
   {{0x644d0f1e,0x443804ce,0xc2c4188d,0x7b3801e4}},	// [18e10] _vaci, _vbs_, ميري, lʈur, 
   {{0x6d584a98,0x644d0f1f,0x51f807d8,0x6aa800b5}},	//   _orta, _waci, иную_, _jjff, 
   {{0x644d0f20,0x21650f21,0x26c00219,0x4438dfc6}},	//   _taci, штаг, mljo_, _tbs_, 
   {{0x4438b44b,0x644c4079,0x291c0014,0x7e60017a}},	//   _ubs_, _uaci, irta_, _snlp, 
   {{0x44290f22,0x1cb0025c,0x2d8c0165,0xb6040010}},	//   mga_, ྟོལ_, ezfe_, bršč, 
   {{0x44290f23,0x6d580a2e,0x7c380368,0xfce42bbd}},	//   lga_, _brta, _sbwr, боко, 
   {{0x44290f24,0x6d58098d,0x6284011c,0xdef807dd}},	//   oga_, _crta, _iljo, хыҵ_, 
   {{0x44290f25,0x6d58037e,0x80a41867,0x291c0010}},	//   nga_, _drta, _امرن, drta_, 
   {{0x44290f26,0x6d590f27,0x291d0f28,0x78a40fac}},	//   iga_, _erta, erta_, vnkv, 
   {{0x442807d6,0x6d5801fa,0xdd98e695,0xdec81086}},	//   hga_, _frta, _ише_, _рубл_, 
   {{0x44290f29,0xb4e4028a,0x6e8800aa,0x291c01a6}},	//   kga_, _पढे_, _حملې_, grta_, 
   {{0x44290f2a,0xcf2400f1,0x3cd4005b,0xeb5000cf}},	//   jga_, _درېي, _ужес, زۉۉگ, 
   {{0x44290f2b,0x6d583421,0x62840267,0xf09008a8}},	//   dga_, _zrta, _oljo, לנט_, 
   {{0x6d5802d0,0x6b94010e,0x00000000,0x00000000}},	//   _yrta, _ýyga, --, --, 
   {{0x291c0552,0x3e78067c,0x44290f2c,0x648000c5}},	//   crta_, _hèts_, fga_, _võin, 
   {{0x44290f2d,0xe5a084cc,0xdb20008c,0x20d4031c}},	//   gga_, чиси, _þróu, _għix_, 
   {{0x7c290f2e,0x26c00010,0x7cf80166,0x00000000}},	// [18e20] iger, bljo_, lärğ, --, 
   {{0x44290f2f,0x6fcc05f9,0x7c290f30,0x23243eb8}},	//   aga_, _तरबू, hger, софи_, 
   {{0x442807d6,0xa11005a9,0xd5b8005f,0x33300072}},	//   bga_, كولت, ļās_, styx_, 
   {{0x6da40831,0x7c290f31,0x1cb0025c,0xeeb42cc8}},	//   ҙҙең_, jger, ྟོས_, әккә_, 
   {{0x6284000f,0x7c28807b,0x64a001c6,0x7cf80139}},	//   _fljo, dger, _хаяа, härğ, 
   {{0x67284673,0x7c290f32,0x6d58020b,0x291d0f33}},	//   _ågje, eger, _prta, yrta_, 
   {{0x7c290f34,0x4c9400a7,0xc29001d5,0xb7f801ad}},	//   fger, жийс, _تیلب, ूराम_, 
   {{0x6d590f35,0xdc8400f7,0x320801e3,0x00000000}},	//   _vrta, йсыл_, _heby_, --, 
   {{0x320801a2,0x6d580142,0x291c0009,0x09e000cd}},	//   _keby_, _wrta, wrta_, नश्य, 
   {{0x44290f36,0x7c28e279,0x6da42502,0x291c0427}},	//   zga_, ager, _лиза, trta_, 
   {{0x44290f37,0x6d590f38,0x291c1af4,0x7c28da5c}},	//   yga_, _urta, urta_, bger, 
   {{0x44290f39,0x291c036e,0x26c00175,0x00000000}},	//   xga_, rrta_, wljo_, --, 
   {{0x44290f3a,0xa098008f,0x4e0c07f7,0x00000000}},	//   vga_, ריכט, _सजाई_, --, 
   {{0x44280a81,0x291c09a8,0x32090f3b,0x00000000}},	//   wga_, prta_, _neby_, --, 
   {{0x44290f3c,0x5694010a,0x5a98011a,0x00000000}},	//   tga_, чарт, _תשוא, --, 
   {{0x44290f3d,0x18a41b6b,0x6ab90f3e,0x6284000f}},	//   uga_, _најм, lotf, _sljo, 
   {{0x44290f3f,0x32090f40,0xc2980dce,0x6284110c}},	// [18e30] rga_, _beby_, аках_, _pljo, 
   {{0x44290f41,0x6ab8003c,0x5b7800c8,0x7c290f42}},	//   sga_, notf, ארמא, zger, 
   {{0x44290f43,0x32090f44,0x7c290f45,0x1fa429db}},	//   pga_, _deby_, yger, әрег, 
   {{0x7c280112,0x442801a9,0x00000000,0x00000000}},	//   xger, qga_, --, --, 
   {{0x3208020b,0x3f690f46,0x6480000d,0xd13801ec}},	//   _feby_, рило_, _jõim, _қхр_, 
   {{0x90280588,0x290001a6,0x1cc80327,0x00000000}},	//   ацәа_, ćkaj_, _ྲེང_, --, 
   {{0x648000c5,0x00000000,0x00000000,0x00000000}},	//   _lõim, --, --, --, 
   {{0x7c290f47,0xf0780184,0x4a24025c,0x3208489d}},	//   uger, _кисә_, _འཐུལ_, _zeby_, 
   {{0x68e8245f,0x200d0f48,0x6ab803cd,0x389400b8}},	//   _aufd, magi_, fotf, cāry_, 
   {{0x200d0f49,0x7c290f4a,0x68e80217,0x6ab80857}},	//   lagi_, sger, _bufd, gotf, 
   {{0xdda877c6,0x6b940209,0x7c280436,0xfc180d17}},	//   _стал_, _ýygn, pger, _نقاب_, 
   {{0x200d0f4b,0x7c280113,0x3154010f,0x6288036e}},	//   nagi_, qger, קירן_, ëgoj, 
   {{0x3b090f4c,0x31c453c7,0x8e7c0115,0x648000c5}},	//   _тело_, _वर्ध, _hiĝa, _võil, 
   {{0x200cbcc3,0x6ab8003c,0xcbc80451,0x00000000}},	//   hagi_, cotf, _اِهو_, --, 
   {{0x200d0f4d,0x8698082d,0x75d40691,0x9f9001e1}},	//   kagi_, стят_, زيرا, _ṣì_, 
   {{0x200c036b,0x32080356,0x92e400cc,0x00000000}},	//   jagi_, _seby_, _নবৌ_, --, 
   {{0x200d0f4e,0xf1f80aa0,0x64a10f4f,0xca380115}},	// [18e40] dagi_, لعات_, фата, liĝa_, 
   {{0x6d480368,0xb6a4023a,0x00000000,0x00000000}},	//   ywfa, _фиол, --, --, 
   {{0xb5c8034c,0xdb087236,0xc7a803e6,0xca380115}},	//   _خودم_, _aygü, _ندیل_, niĝa_, 
   {{0x32080232,0x200d0f50,0xd3705f32,0xb63401d3}},	//   _weby_, gagi_, _كۇز_, _اٹھت, 
   {{0xa2c86236,0x6ab800d2,0xba44013a,0xb4d400bc}},	//   _तीव्, yotf, _krůč, िगी_, 
   {{0x561c03d4,0xe3b000ec,0x7aec0432,0x5f900798}},	//   দ্ৰক_, _آرٽ_, _çaty, ќишт, 
   {{0x200cae08,0xa29001e1,0x00000000,0x00000000}},	//   bagi_, _mọ̀n, --, --, 
   {{0x200d0f51,0x5cc10f52,0xca3801e4,0x7c8800ee}},	//   cagi_, мсыз, diĝa_, йшың_, 
   {{0xde080372,0x00000000,0x00000000,0x00000000}},	//   ارۇۇ_, --, --, --, 
   {{0xa3a80034,0x00000000,0x00000000,0x00000000}},	//   गपत_, --, --, --, 
   {{0x648000c5,0xec4800a7,0x28e402dd,0x6ab802d0}},	//   _sõim, _взел_, _ﺍﻟﺒﻠ, rotf, 
   {{0x57f50f53,0xab84a92d,0x4aa80137,0x64800037}},	//   мпют, _мулк, ркүн_, _põim, 
   {{0x868c044e,0x98750f54,0x00000000,0x00000000}},	//   _ሓለፍቲ_, фляц, --, --, 
   {{0x6480367a,0x200d0f55,0xda610f56,0x4a24031c}},	//   _võim, zagi_, _овчи, _འཐིལ_, 
   {{0x200d0f57,0x00000000,0x00000000,0x00000000}},	//   yagi_, --, --, --, 
   {{0xc9850f58,0x200c011f,0xe7e00073,0x2614012c}},	//   _муқи, xagi_, _गणपा_, _भएकी_, 
   {{0x53350f59,0x200d0f5a,0x6480000d,0x00000000}},	// [18e50] метт, vagi_, _hõik, --, 
   {{0x6480033d,0xa3e40dad,0x00000000,0x00000000}},	//   _kõik, _पलक_, --, --, 
   {{0x00e416e6,0x200d0f5b,0xabd000d1,0x00000000}},	//   ستای, tagi_, ﻟﯩﻤﺎ, --, 
   {{0xa2c808ec,0x64800254,0xe8e402dd,0x61f80139}},	//   _तीर्, _mõik, _ﺍﻟﯟﻋ, _şuld, 
   {{0x200d0f5c,0x6480007d,0xe1f001d9,0xca380115}},	//   ragi_, _lõik, _ٲسس_, ziĝa_, 
   {{0x200d0f5d,0xe7e04d53,0xfce44303,0x028801f7}},	//   sagi_, _गणना_, поко, _اَسي_, 
   {{0x200cd99d,0x6df10f5e,0xa0a400c7,0x511800f5}},	//   pagi_, ركيا, _дшал, _морю_, 
   {{0x3b9400d8,0x00000000,0x00000000,0x00000000}},	//   зјот, --, --, --, 
   {{0xfaa418a4,0x2d883f5b,0xd05c03e3,0x6b940432}},	//   запо, _üben_, _nurə, _ýygl, 
   {{0xca3801e4,0xb9b402e8,0x6288036e,0x00000000}},	//   tiĝa_, зсмъ, ëgoh, --, 
   {{0x0c240137,0x527c010f,0x0dc8009b,0x00000000}},	//   чмөн, ינזא, _дуци_, --, 
   {{0x49c801c0,0x7cd8034b,0x3cd40cdd,0xca380115}},	//   өлөн_, _умер_, _эжес, riĝa_, 
   {{0x27fc02d1,0xe7344316,0xa85001d5,0xba44013a}},	//   ñuna_, пея_, хкўч, _průč, 
   {{0xdb080210,0x00000000,0x00000000,0x00000000}},	//   _wygó, --, --, --, 
   {{0xed840023,0x7bdc03b2,0xca7433d2,0x00000000}},	//   _ጐይታይ_, ýsuf, _تانغ, --, 
   {{0x34b46766,0xa2900248,0xd37000d1,0x00000000}},	//   ंवेद, _wọ̀n, پۇس_, --, 
   {{0x867801c6,0x09e000cc,0x798003ac,0x662400e5}},	// [18e60] сөөр_, _ম্পা, lylw, árké, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd6f4015b,0x79810f5f,0xa6940a7c,0x00000000}},	//   _জিয়া_, nylw, _זכיה_, --, 
   {{0xdce00153,0x00000000,0x00000000,0x00000000}},	//   mynė, --, --, --, 
   {{0xdce00024,0xafb81291,0x7980035a,0xa2a4000d}},	//   lynė, حطاط_, hylw, _टॆक्, 
   {{0x79800857,0x68ec01e4,0x25bc0356,0x00000000}},	//   kylw, ŭbdi, şule_, --, 
   {{0x61404077,0x00000000,0x00000000,0x00000000}},	//   _пера, --, --, --, 
   {{0x61f80cf4,0x8af8030d,0x4bc40137,0x00000000}},	//   _đuli, онис_, мөлг, --, 
   {{0x92c0045e,0xa03010de,0x28e40150,0xe040030d}},	//   ুদী_, _سىلت, _ﺍﻟﺘﻠ, _янти, 
   {{0x64800037,0x6b94010e,0xdce00064,0x00000000}},	//   _põik, _ýygm, kynė, --, 
   {{0xd05c03be,0x00000000,0x00000000,0x00000000}},	//   _surə, --, --, --, 
   {{0xab2843a7,0x6480007d,0xd7f90f60,0xdce00006}},	//   _года_, _võik, зур_, dynė, 
   {{0x6380008c,0x4df01d8a,0x8a1800f3,0x00000000}},	//   _mínú, _चलाई_, _долс_, --, 
   {{0xca38010f,0x291400e5,0x00000000,0x00000000}},	//   miĝo_, _ففتھ_, --, --, 
   {{0xca38010f,0xdb08032e,0xdce00064,0xa9c40532}},	//   liĝo_, _hygð, gynė, _عزتو, 
   {{0x63800ca8,0x225c0139,0x00000000,0x00000000}},	//   _nínú, _şuk_, --, --, 
   {{0xe664bf77,0x2488004d,0xca38008f,0x00000000}},	// [18e70] _етно, _vlcm_, niĝo_, --, 
   {{0x09e02f8b,0x6ffc0154,0x00000000,0x00000000}},	//   _ম্যা, ুলোও_, --, --, 
   {{0x60d80419,0x403401f4,0x00000000,0x00000000}},	//   _ďumb, деес, --, --, 
   {{0xca38010f,0xa3e41414,0xc4640244,0x66e401e1}},	//   kiĝo_, _पलट_, _تیرۆ_, békè, 
   {{0x3dc40cfd,0xca3801e4,0x00000000,0x00000000}},	//   _sylw_, jiĝo_, --, --, 
   {{0xca3800df,0xbea407d5,0xd2f800f3,0xdef801ec}},	//   diĝo_, ьалк, _херц_, _ңыз_, 
   {{0x6d4c006a,0x2d880e78,0x31300022,0x6b94010e}},	//   _âbal, _übel_, _аҵхр, _ýygj, 
   {{0x0288009f,0x00000000,0x00000000,0x00000000}},	//   _اَڳي_, --, --, --, 
   {{0xd6b8084c,0xca3800df,0x79800042,0x00000000}},	//   yдри, giĝo_, wylw, --, 
   {{0xdb08032e,0x7980035a,0x00000000,0x00000000}},	//   _dygð, tylw, --, --, 
   {{0xbc1843e1,0x00000000,0x00000000,0x00000000}},	//   _ділі_, --, --, --, 
   {{0xc6881a4c,0x8e700124,0xdce00024,0xded40023}},	//   _דא_, _ақәш, vynė, _ይረአ_, 
   {{0xca3800df,0x9ba000d1,0x798039ea,0xfb840345}},	//   ciĝo_, _سەدى, sylw, _تدای, 
   {{0xdce00006,0x798002d0,0x68ec0332,0x00000000}},	//   tynė, pylw, úidí, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6840136b,0x8e2c022e,0x29d00150,0xf8d000c5}},	//   _анъа, _lidа_, _جيىس, _सठिय, 
   {{0x1cc80327,0x00000000,0x00000000,0x00000000}},	// [18e80] _ྲེན_, --, --, --, 
   {{0x021802d5,0xdce00153,0x63800241,0x00000000}},	//   зіць_, pynė, _sínú, --, 
   {{0x86c40451,0xca38010f,0x00000000,0x00000000}},	//   _سيٽن, ziĝo_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x5f740014,0x00000000,0x00000000,0x00000000}},	//   ٘منس_, --, --, --, 
   {{0x61f4003a,0x94240e56,0xca38008f,0x00000000}},	//   ccxl, _توڭۇ, viĝo_, --, 
   {{0x6288017a,0x2d9800c7,0x7f4c0135,0x00000000}},	//   êgoe, àpe_, ħaqa, --, 
   {{0xcb540640,0xca38008f,0x00000000,0x00000000}},	//   евић, tiĝo_, --, --, 
   {{0xe378010f,0x42680023,0x00000000,0x00000000}},	//   ַרטר, _ሰማእት_, --, --, 
   {{0x6f00204e,0xca38008f,0x00000000,0x00000000}},	//   mpoc, riĝo_, --, --, 
   {{0x6f000077,0xca38010f,0x2ec828e0,0x00000000}},	//   lpoc, siĝo_, ितीत, --, 
   {{0x648000c5,0x69dc00e4,0xca3800df,0x8e2c022e}},	//   _hõiv, _úpem, piĝo_, _zidа_, 
   {{0x6f00005c,0xfc2c00cf,0x64800037,0x48c40166}},	//   npoc, _اڭى_, _kõiv, _җәна, 
   {{0x7afc4eb7,0x00000000,0x00000000,0x00000000}},	//   íste, --, --, --, 
   {{0x5558084c,0x87081893,0xd90cb3e4,0x048802dd}},	//   маря_, _کعبہ_, _шь_, пшақ_, 
   {{0x6480000d,0x20c4000d,0x00000000,0x00000000}},	//   _lõiv, lõiv_, --, --, 
   {{0xd4e411f4,0x04440139,0xd3f40150,0x00000000}},	// [18e90] тюри, меңн, гiтт, --, 
   {{0x6f00007c,0x00000000,0x00000000,0x00000000}},	//   dpoc, --, --, --, 
   {{0x5778136e,0x00000000,0x00000000,0x00000000}},	//   _فصیح_, --, --, --, 
   {{0x44f40004,0x8e2c022e,0x7fd4de10,0x4fc400d1}},	//   _iå_, _sidа_, нілі, ھەلە, 
   {{0x44f4d007,0xbe68009d,0x00000000,0x00000000}},	//   _hå_, залж_, --, --, 
   {{0x44f40589,0x73c00032,0x7aec00d8,0x00000000}},	//   _kå_, _сәсе, _éati, --, 
   {{0x2b4409d3,0x44f50f61,0x3f880006,0x3ea8107d}},	//   _apoc_, _jå_, šau_, đat_, 
   {{0x44f46ab9,0xbf10013d,0x998406be,0x00000000}},	//   _må_, _бүдә, _adnş_, --, 
   {{0x44f417c1,0x00000000,0x00000000,0x00000000}},	//   _lå_, --, --, --, 
   {{0x44f40004,0x4ea400c7,0x8fa40063,0x00000000}},	//   _oå_, _ирха, _рађе, --, 
   {{0x44f414f5,0x2b450f62,0x58040032,0xd90c179e}},	//   _nå_, _epoc_, конғ, جیع_, 
   {{0xf1b00bd9,0x6d540882,0x00000000,0x00000000}},	//   רסט_, āyat, --, --, 
   {{0xeb8c0697,0x44f40589,0xdb08008e,0xbb440108}},	//   _си_, _aå_, _aygö, _челк, 
   {{0x44f40656,0xba38008f,0x00000000,0x00000000}},	//   _bå_, _זײַט, --, --, 
   {{0x6f00068f,0x9ba002de,0xaa540114,0x00000000}},	//   zpoc, _سەگى, _чију_, --, 
   {{0x44f50f63,0x201c009f,0x6f000076,0x00000000}},	//   _då_, _ndui_, ypoc, --, 
   {{0x61f90934,0x44f40004,0xcd400020,0xd94000d1}},	// [18ea0] _şula, _eå_, ደተናገ, _чеқи, 
   {{0x78a50f64,0x201c0451,0x00000000,0x00000000}},	//   likv, _adui_, --, --, 
   {{0x764d0f65,0x35a50f66,0xdbc80295,0x648000af}},	//   meby, _чанг, _mòñi, _rõiv, 
   {{0x764d0f67,0xc764021f,0x76b800fb,0x00000000}},	//   leby, _ساۋى, _флүр_, --, 
   {{0x44f40004,0xb4bc0fe6,0xa2c800dc,0x00000000}},	//   _zå_, ेती_, _तीक्, --, 
   {{0x44f40589,0xdbc80428,0x764d0f68,0x2ec8041c}},	//   _yå_, _nòñi, neby, ितेत, 
   {{0x6480007d,0xfd5400b8,0x6ab402d2,0x00000000}},	//   _võiv, _khaṃ, _íyfi, --, 
   {{0x764d0f69,0x00000000,0x00000000,0x00000000}},	//   heby, --, --, --, 
   {{0x764d0f6a,0x61f00023,0x78a401e4,0xcee401ec}},	//   keby, _çelë, dikv, _абақ, 
   {{0x752c0161,0x764cb529,0xadb8007b,0xb4bc4f4b}},	//   kubz, jeby, _فهذا_, ेतु_, 
   {{0xd9141248,0x78a50f6b,0x95080327,0xdb340345}},	//   нья_, fikv, _ཇསཊི_, وسیش_, 
   {{0x4ba4abba,0x569401ec,0x00000000,0x00000000}},	//   _илең, қаст, --, --, 
   {{0xe7850f6c,0x387002dd,0x4a54022e,0x00000000}},	//   хуно, рқыт, _аклс, --, 
   {{0x764c12ed,0xfd5400cd,0xca4801d5,0x00000000}},	//   geby, _ahaṃ, _آلغه_, --, 
   {{0xb9100882,0x91a000c5,0x00000000,0x00000000}},	//   khaṃ_, _गेलै, --, --, 
   {{0x44f40158,0xfd5400b8,0x6b9400c0,0x00000000}},	//   _vå_, _chaṃ, _žygy, --, 
   {{0x44f40004,0xb9100882,0xe8040490,0x290c55e9}},	// [18eb0] _wå_, dhaṃ_, _व्या_, _hwfa_, 
   {{0xd5fc063f,0x752c0083,0x53e401c0,0x44f40b3b}},	//   riṛ, bubz, уцса, _ипос, 
   {{0x26c002d5,0x672c033f,0x44f40fac,0xc014005b}},	//   mojo_, lucj, _uå_, вмещ, 
   {{0x69c8003b,0x26c10f6d,0x753800db,0xd058155b}},	//   _myfe, lojo_, àtze, ерші_, 
   {{0x83d4000d,0x00000000,0x00000000,0x00000000}},	//   _दरिआ, --, --, --, 
   {{0x6ab81533,0x26c10f6e,0x3e780561,0xc104038b}},	//   ईकोर, nojo_, _hètz_, _لوسي, 
   {{0xd6580302,0xdbc80086,0xb9100882,0xcdc404a9}},	//   גיות_, _ròñi, bhaṃ_, лашқ, 
   {{0x764c033f,0x3c6400d1,0x672c012d,0x35ac00cc}},	//   zeby, ткиг, kucj, _গৰুহ, 
   {{0x290c0204,0xdde83463,0x26c10f6f,0x78a42d8b}},	//   _awfa_, _فراه_, kojo_, vikv, 
   {{0x26c10f70,0x69c8005c,0x9f00004b,0x672c031c}},	//   jojo_, _byfe, _لوړو, ducj, 
   {{0x78a50f71,0x1cb0081f,0x69c80cfd,0x26c10f72}},	//   tikv, ྟོད_, _cyfe, dojo_, 
   {{0x6480033d,0x69c80368,0x764c7294,0x20c4000d}},	//   _mõis, _dyfe, weby, mõis_, 
   {{0x69cc0209,0x69c87d06,0x00000000,0x00000000}},	//   ýber, _eyfe, --, --, 
   {{0x78a50f73,0x752d0f74,0x26c10f75,0xb4e881e9}},	//   sikv, tubz, gojo_, मद्_, 
   {{0x69c80f7b,0x00000000,0x00000000,0x00000000}},	//   _gyfe, --, --, --, 
   {{0x764d0f76,0xb4bca782,0x672c033f,0x00000000}},	//   seby, ेते_, bucj, --, 
   {{0xd2446788,0x7f4ca090,0x3e78180f,0x78b4035b}},	// [18ec0] лмақ, çaql, _dètz_, _ijyv, 
   {{0x6480007d,0x26c10f77,0x00000000,0x00000000}},	//   _sõit, cojo_, --, --, 
   {{0xb9100a28,0x7f480af5,0xa2b007af,0xb7f4012c}},	//   thaṃ_, _apeq, _आदर्, _इलाम_, 
   {{0x2ec84697,0xf8d0098a,0x05ac000d,0xef84026b}},	//   ित्त, सतिय, _फ़ुटब, клеп, 
   {{0x6480033d,0x1cb0031c,0x98640205,0x20c40037}},	//   _võit, ྟོན_, nıı_, võit_, 
   {{0xb1450f78,0xae000210,0x00000000,0x00000000}},	//   _ингл, _र्शन_, --, --, 
   {{0xdd8c088c,0x7d000175,0xb0700451,0x71a40107}},	//   يوه_, _ctls, _پھاڪ, _равз, 
   {{0x70549ce2,0x69c80368,0xca38010f,0xdd803740}},	//   _جنرا, _ryfe, miĝi_, рышп, 
   {{0xee390f79,0x69c80660,0xaf3401b9,0xa038008f}},	//   _она_, _syfe, _جرأت, _קעמפ, 
   {{0xaa650f7a,0x7afc1897,0x20c400af,0x98640205}},	//   ттик, ísta, sõit_, dıı_, 
   {{0x26c10f7b,0x1af44f41,0xca38010f,0x96180154}},	//   vojo_, ндөө_, niĝi_, ়লাম_, 
   {{0x672c012d,0x7afc010f,0xb4bc043e,0x00000000}},	//   tucj, ŭsta, ेतो_, --, 
   {{0x26c10f7c,0xa2b00073,0x00000000,0x00000000}},	//   tojo_, _आदल्, --, --, 
   {{0x3e78180f,0x672c0e3c,0xca38010f,0x00000000}},	//   _sètz_, rucj, kiĝi_, --, 
   {{0x26c10f7d,0xca3801e4,0x9aa002f2,0x29180241}},	//   rojo_, jiĝi_, _خموو, _ìpa_, 
   {{0x8e7c010f,0x26c10f7e,0xca3800df,0x00000000}},	//   _diĝi, sojo_, diĝi_, --, 
   {{0x26c095ac,0x03d41f39,0x4614187c,0x00000000}},	// [18ed0] pojo_, ужаю, _یوکر, --, 
   {{0x8e7c0115,0x85742d29,0xd87402dd,0x64800254}},	//   _fiĝi, _блох, _ماۋب, _põis, 
   {{0xb600012c,0x7f48003a,0x78b400e4,0xca3801e4}},	//   čáte, _speq, _yjyv, giĝi_, 
   {{0x6480007d,0x90340212,0x00000000,0x00000000}},	//   _võis, ихіч, --, --, 
   {{0x96b8034c,0x1014dea3,0x44380f85,0x62200150}},	//   _سایز_, شبند, _ics_, _پوزە, 
   {{0x2bc41533,0xc3080729,0xca380115,0x64800254}},	//   _लड़ा, _লিপি_, biĝi_, _tõis, 
   {{0x4438009b,0x6da0036b,0xca3800df,0xb6d800df}},	//   _kcs_, йиша, ciĝi_, ײַסט, 
   {{0x443805b1,0x997800ef,0xe0dc0241,0xfbd0552d}},	//   _jcs_, _pāže_, _òò_, یتک_, 
   {{0x44381cc1,0x60d83209,0x69cc03e0,0x00000000}},	//   _mcs_, _ihum, üben, --, 
   {{0x443804ba,0x6ed8012d,0xcd280137,0x00000000}},	//   _lcs_, _पीपु, رسۉن_, --, 
   {{0x60d90f7f,0x3ea4013c,0x8b640066,0x00000000}},	//   _khum, _imlt_, هایم, --, 
   {{0x44390f80,0xe45c01e6,0x80d8033f,0x00000000}},	//   _ncs_, _skön_, _फीमे, --, 
   {{0x60d90f81,0x07140276,0xca3800df,0x00000000}},	//   _mhum, ифря, ziĝi_, --, 
   {{0xb4bc1161,0x8e7c0115,0x60d80076,0x44380f85}},	//   ेत्_, _piĝi, _lhum, _acs_, 
   {{0x60d8166a,0x78b4007c,0x98640205,0x00000000}},	//   _ohum, _tjyv, sıı_, --, 
   {{0x60d90f82,0xca38010f,0x22a80064,0xf4e400d1}},	//   _nhum, viĝi_, _lėkė_, _ﺋﺎﺷﻜ, 
   {{0x44383c36,0x23242cb8,0xf26801a9,0x00000000}},	// [18ee0] _dcs_, лоти_, ниал_, --, 
   {{0x60d90f83,0x6294003e,0xca38010f,0x00000000}},	//   _ahum, ghxo, tiĝi_, --, 
   {{0x765c03a2,0x60d90f84,0x312402dd,0x27940107}},	//   _iapy, _bhum, удег, _ашӯр, 
   {{0xca38008f,0x765c035b,0x4438007b,0x8d78001f}},	//   riĝi_, _hapy, _gcs_, ያውቀው_, 
   {{0x43750f85,0x60d90f86,0x69c802db,0x35b80cb4}},	//   _курт, _dhum, _सुनी, _उखड़, 
   {{0x60d8a333,0x765d0f87,0x64b400f3,0x65a001a9}},	//   _ehum, _japy, nćin, _mеhn, 
   {{0x765d0f88,0x44380161,0x321805d6,0x00000000}},	//   _mapy, _ycs_, mapy_, --, 
   {{0x60d8047e,0x765d0f89,0x23c000bc,0x443801e7}},	//   _ghum, _lapy, _वुँद, _xcs_, 
   {{0x2aa805c5,0x00000000,0x00000000,0x00000000}},	//   етно_, --, --, --, 
   {{0x32190f8a,0x60d90f8b,0xdeb80051,0x2be400fe}},	//   napy_, _zhum, _truơ, ওঁলৈ_, 
   {{0x98b405d1,0xe870a4ca,0xda4400ee,0x3ce80419}},	//   çeği_, مندگ, учыл_, ňava_, 
   {{0x6d590f8c,0x60d90f8d,0xeb983529,0x81b8015b}},	//   _ista, _xhum, _пие_, _চরম_, 
   {{0x44390f8e,0x2ca4019b,0x765c03a2,0x32190f8f}},	//   _rcs_, _imod_, _bapy, kapy_, 
   {{0x765d0f90,0x32190f91,0xdb1c0241,0x00000000}},	//   _capy, japy_, _íwáj, --, 
   {{0xa3e40882,0x2ca4009f,0x44387c7f,0xe73c0254}},	//   येन_, _kmod_, _pcs_, stõ_, 
   {{0x6d580451,0x765c02ea,0x7aec00d8,0x00000000}},	//   _msta, _eapy, _éatr, --, 
   {{0x60d90f92,0x291d0f93,0x44380261,0x765c0007}},	// [18ef0] _rhum, lsta_, _vcs_, _fapy, 
   {{0x60d90f94,0x291d0f95,0x6e380998,0x44390f96}},	//   _shum, osta_, _nctb, _wcs_, 
   {{0x60d90f97,0x41550f98,0x6d590f99,0x44390f9a}},	//   _phum, рвес, _nsta, _tcs_, 
   {{0x291d0f9b,0x765c068f,0x835475e4,0x20c800f7}},	//   ista_, _zapy, _پھرا, رباي_, 
   {{0x6d590f9c,0x83341a4c,0x60d80084,0xca3800df}},	//   _asta, _דאָס_, _vhum, liĝu_, 
   {{0x6d590f9d,0x2ca403cb,0x60d80076,0x00000000}},	//   _bsta, _amod_, _whum, --, 
   {{0x72640075,0x2ca4031c,0x69cd0f9e,0x60d90f9f}},	//   _خەلق_, _bmod_, übel, _thum, 
   {{0x7afc5f24,0x60d90fa0,0x291d0fa1,0x00000000}},	//   ísto, _uhum, dsta_, --, 
   {{0x291d0fa2,0x6d58a8e0,0x5dd00150,0x69c80950}},	//   esta_, _esta, _ﯞﯨﻨﺴ, _सुबी, 
   {{0x7aa50fa3,0x6d580334,0x394402bf,0x2ca40c6a}},	//   риоз, _fsta, аног, _emod_, 
   {{0xe8042413,0x291d0fa4,0xd05c02a8,0x765c5c36}},	//   _व्हा_, gsta_, _gurɓ, _rapy, 
   {{0x37e43e9c,0x765d0fa5,0xca3800df,0x5ce4014b}},	//   ионг, _sapy, diĝu_, _сюза, 
   {{0x291d0fa6,0x765d0fa7,0x87b90fa8,0xa3e4574f}},	//   asta_, _papy, гурт_, येम_, 
   {{0x6d590fa9,0x291cbbb8,0xf5040395,0x00000000}},	//   _ysta, bsta_, изго, --, 
   {{0x6614022e,0xe6140a5b,0xe8040490,0x6b94010e}},	//   _dexk, рдс_, _व्वा_, _ýygr, 
   {{0x778406bb,0x765c0451,0x00000000,0x00000000}},	//   _влиз, _wapy, --, --, 
   {{0x765d0faa,0x27b00131,0x867801c0,0x81cc0154}},	// [18f00] _tapy, _дәрс, төөр_, শেম_, 
   {{0xca380115,0xe294035b,0x00000000,0x00000000}},	//   biĝu_, аау_, --, --, 
   {{0x73340131,0xa3e42983,0xca3801e4,0x00000000}},	//   _ھىسا, येब_, ciĝu_, --, 
   {{0x3860014b,0x6f64ea45,0x3218035b,0x9f4001e1}},	//   ndkr_, ивез, sapy_, _ńjá_, 
   {{0xdfccede9,0x6d580c61,0x2f54399a,0x38700200}},	//   ويم_, _ssta, ртес, _mnyr_, 
   {{0x291d0fab,0x6d58030d,0x2ca4004d,0xd29400e5}},	//   ysta_, _psta, _smod_, _اُسک, 
   {{0x70240014,0x1fb01321,0x30740139,0x00000000}},	//   _پرزٕ, йсәр, _куас, --, 
   {{0x5ce0046f,0x6ce40046,0x6d58955b,0x291c2915}},	//   يكول, шіле, _vsta, vsta_, 
   {{0x6d590fac,0xbd880020,0xca380115,0x00000000}},	//   _wsta, ንያቱም_, ziĝu_, --, 
   {{0xd05c0198,0x291c00c5,0xada47bca,0x6a840120}},	//   _turɓ, tsta_, _казл, рѓие, 
   {{0x6d590fad,0x291d0fae,0xac7400cf,0x5df800df}},	//   _usta, usta_, _پااش, _ספאנ, 
   {{0x291d0faf,0x66150fb0,0x9c8001fa,0x28a402bf}},	//   rsta_, _sexk, _ščvr, ршог, 
   {{0x291d0fb1,0x98b802e8,0x00000000,0x00000000}},	//   ssta_, рлят_, --, --, 
   {{0x298402f6,0x291d0fb2,0xca3800df,0x273c03cb}},	//   _выиг, psta_, tiĝu_, rîn_, 
   {{0x45d50fb3,0x291c0054,0x035429db,0x628001e3}},	//   совс, qsta_, әүгә_, önom, 
   {{0x18a40e92,0x3870007c,0xca38008f,0x48141436}},	//   _мајм, _gnyr_, riĝu_, _умис, 
   {{0x66140784,0x7cf40006,0xb784104e,0xca3801e4}},	// [18f10] _texk, _išre, _ләре_, siĝu_, 
   {{0x3168030a,0xca3801e4,0x66140254,0x4ec80154}},	//   _brbz_, piĝu_, _uexk, ষগুল, 
   {{0xd5b84d15,0x3ff40131,0x9258023b,0x38700042}},	//   _вся_, مكار, рахт_, _ynyr_, 
   {{0xb9dc02d3,0x7f181cb8,0x104801a9,0x00000000}},	//   _ኣዩ_, гіку_, иячи_, --, 
   {{0x65a001a9,0xc0c40166,0xd1300116,0x00000000}},	//   _mеhm, _һәди, كمە_, --, 
   {{0xa3e400dc,0xa1340214,0x81b800fe,0xc5f401f9}},	//   येण_, _پرسش, _চৰণ_, _आलोय_, 
   {{0x01e403f4,0x8e540220,0x72e401d3,0xe0840133}},	//   _প্রদ, ітші, _اہلِ_, _پێشو_, 
   {{0x69c805b7,0x7f940117,0x00000000,0x00000000}},	//   _सुधी, _лабх, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x387003b2,0xdda801ee,0x00000000,0x00000000}},	//   _snyr_, _ител_, --, --, 
   {{0xa3e47922,0x69c84709,0x9c8023cc,0xe8f40139}},	//   येत_, _सुदी, _ščur, йлэ_, 
   {{0x7e610fb4,0x8d740b8c,0xc6880a1e,0xb4b4000d}},	//   _halp, _باكا, _אא_, _जदे_, 
   {{0x2d8891e1,0x7e610fb5,0x64b401fa,0x97840214}},	//   _über_, _kalp, rćil, زیده, 
   {{0x66010fb6,0x7e610fb7,0x00000000,0x00000000}},	//   зпра, _jalp, --, --, 
   {{0x7e610fb8,0x64b40b4b,0x00000000,0x00000000}},	//   _malp, pćil, --, --, 
   {{0xfaa800ec,0x00000000,0x00000000,0x00000000}},	//   _جهڪي_, --, --, --, 
   {{0xd6c4035c,0x00000000,0x00000000,0x00000000}},	// [18f20] _ومبی, --, --, --, 
   {{0x7e60a2c1,0x00000000,0x00000000,0x00000000}},	//   _nalp, --, --, --, 
   {{0x7af801f5,0x2bcc012c,0xb1443e4f,0x00000000}},	//   _luwt, _हुना, снел, --, 
   {{0x7e600421,0x69d8010f,0x00000000,0x00000000}},	//   _aalp, אַדו, --, --, 
   {{0x9f5c002e,0x7e6001f5,0x35800092,0x00000000}},	//   _beuñ_, _balp, _ያሉበት_, --, 
   {{0x7e609ef9,0x25dc032c,0xd17401e0,0x00000000}},	//   _calp, _गरमी_, _һығы, --, 
   {{0x7e6007ab,0xe294039e,0x9e20215c,0x00000000}},	//   _dalp, _уар_, سىيو, --, 
   {{0xd174054a,0x14c80073,0xbdd40150,0x00000000}},	//   _лығы, लविण, _ﺘﻭﻗﻔ, --, 
   {{0x536c693c,0x7e60848b,0x81cc015b,0xbe4800f2}},	//   _ሰራዊት_, _falp, শেদ_, _چشمم_, 
   {{0xed340323,0x7e610fb9,0x7af801f5,0x81b800cc}},	//   _гэдэ, _galp, _duwt, _চৰি_, 
   {{0xdd8c005e,0x20f001fa,0x2d9477ff,0x14c80cb2}},	//   _كوك_, _ućit_, _урас, लवाण, 
   {{0x63b80008,0x7c64036b,0x7e600139,0x00000000}},	//   _þung, _وانل, _zalp, --, 
   {{0x7e610fba,0x6bd50fbb,0xabd411dc,0x00000000}},	//   _yalp, _اتار, _ازات, --, 
   {{0x96f80021,0x7e60031c,0x4aa400c5,0x00000000}},	//   серт_, _xalp, गोशव, --, 
   {{0x59cc07af,0x6d4c0793,0x6aa80010,0x04c80b24}},	//   _सुपर, _äbad, _imff, لوسي_, 
   {{0xd91407d5,0x00000000,0x00000000,0x00000000}},	//   _уьш_, --, --, --, 
   {{0x2bcc121d,0x94040066,0x00000000,0x00000000}},	// [18f30] _हुमा, سوله, --, --, 
   {{0x45d4020f,0x00000000,0x00000000,0x00000000}},	//   _мопс, --, --, --, 
   {{0x66d8019f,0x00000000,0x00000000,0x00000000}},	//   cîka, --, --, --, 
   {{0x7e600a55,0xd05c03f9,0x228c05d1,0x7afc02f0}},	//   _salp, _murɗ, _sıkı_, ístk, 
   {{0xddd001e4,0x7438010f,0x59cc0037,0x00000000}},	//   ĵaŭd, _דערװ, _सँभर, --, 
   {{0x171c00c8,0x7e6001a9,0x00000000,0x00000000}},	//   נווע, _qalp, --, --, 
   {{0x518400a8,0x6ea8000d,0x00000000,0x00000000}},	//   _еута, _झगरु, --, --, 
   {{0x7e610fbc,0x6284037e,0x6aa8015d,0x00000000}},	//   _walp, _hojo, _amff, --, 
   {{0x628404b9,0x7e610fbd,0x32140213,0x3dc8012d}},	//   _kojo, _talp, _şeyə_, ław_, 
   {{0x62850fbe,0x60c803cd,0x6280023a,0x4ba50fbf}},	//   _jojo, logm, önoh, ялың, 
   {{0x69c50fc0,0x2d880139,0x7f4c0327,0x00000000}},	//   şken, _übep_, ħaqu, --, 
   {{0x62840248,0xf1c40150,0xf744026b,0x00000000}},	//   _lojo, _ﺒﺼﻔﺘ, оемо, --, 
   {{0x6ce0004b,0x00000000,0x00000000,0x00000000}},	//   _تړون, --, --, --, 
   {{0x6284013e,0x3b0c0455,0xf1bc0b98,0xeb940395}},	//   _nojo, mpeq_, ्थमन, _фиш_, 
   {{0x60c80158,0x69dc00e4,0xf8a800f1,0xa3e405c0}},	//   kogm, _úpep, _پدغه_, येस_, 
   {{0x62840428,0x0928007b,0x00000000,0x00000000}},	//   _aojo, _اسوي_, --, --, 
   {{0xded4044e,0xdb2001b8,0xb6a43a4e,0x6aa8015d}},	// [18f40] ሮምን_, _äsäb, _миил, _ymff, 
   {{0x62850fc1,0x00000000,0x00000000,0x00000000}},	//   _cojo, --, --, --, 
   {{0x62850fc2,0xf77010e8,0x00000000,0x00000000}},	//   _dojo, _راک_, --, --, 
   {{0x63b80010,0xe0d43f0f,0x14040022,0x60c8005c}},	//   _žune, овх_, _хҧан, gogm, 
   {{0x628400c8,0x00000000,0x00000000,0x00000000}},	//   _fojo, --, --, --, 
   {{0x62850fc3,0xb6501954,0x61f80139,0xa3bc0c5e}},	//   _gojo, _ህዝባዊ, _şulv, _užší_, 
   {{0x4c950fc4,0xf8c82368,0xe4d40133,0xb60400ef}},	//   зийс, रवाय, _دوێت_, _izšā, 
   {{0xa3e40882,0x6284009a,0xeb4800f5,0x00000000}},	//   येव_, _zojo, ачок_, --, 
   {{0xee380212,0xddc001e4,0x00000000,0x00000000}},	//   _внз_, menŝ, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69c84d53,0x1d04030d,0x00000000,0x00000000}},	//   _सुशी, _дехи_, --, --, 
   {{0x7d0c0e04,0x6aa80142,0xbb7000f7,0x00000000}},	//   ćast, _wmff, بۇۇع, --, 
   {{0x69c85e8d,0x7cf40006,0x00000000,0x00000000}},	//   _सुरी, _išra, --, --, 
   {{0x7cc00374,0x44240210,0xdb2002d2,0x00000000}},	//   rēre, _śl_, _þráu, --, 
   {{0x62850fc5,0x6ab81cea,0x2bcc1a2a,0x1a98010f}},	//   _rojo, mntf, _हुता, _דיגע, 
   {{0x62843142,0x481417b4,0x00000000,0x00000000}},	//   _sojo, _эмис, --, --, 
   {{0x62850fc6,0x312c01ec,0x37c00075,0x2be000e1}},	// [18f50] _pojo, _ءﺟﻮﻥ_, _зәрб, _परफा, 
   {{0xcfd002a6,0x628400fb,0x7afd0fc7,0x6ab800d2}},	//   িধান, _qojo, ísti, nntf, 
   {{0xd1b80150,0x6284008f,0x00000000,0x00000000}},	//   ياما_, _vojo, --, --, 
   {{0x63000131,0x6284012d,0x00000000,0x00000000}},	//   _يۈزل, _wojo, --, --, 
   {{0x534429be,0x3f68f7cf,0x25bc0342,0x60c90fc8}},	//   _охра, сило_, ğulu_, rogm, 
   {{0xc2c4143e,0x25bc0790,0x0ea80212,0xcee90fc9}},	//   _ريزي, şulu_, окій_, يرون_, 
   {{0x6140215c,0xf2d0011a,0x00000000,0x00000000}},	//   _تىزە, _נעל_, --, --, 
   {{0x3b847b45,0xed4c0849,0x6ab8035a,0xd0180108}},	//   злиг, اپي_, entf, _мфу_, 
   {{0xbf150fca,0x9d9005d9,0x6d5c5d04,0xb7c400fe}},	//   _رواب, _ڪهاڻ, æpar, _এণ্ট, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x81cc03f4,0x8d740075,0x644d0fcb,0xc040001f}},	//   শের_, _ياما, _obci, _የምትለ, 
   {{0x06d804c5,0x0c040014,0x6ab80076,0xf1bc012c}},	//   _ধূলি, _قومُ, antf, ्थतन, 
   {{0xf77000c6,0x5b0000d1,0x00000000,0x00000000}},	//   راح_, _تېخم, --, --, 
   {{0x59cc6ace,0xddc001e4,0x867400c7,0x00000000}},	//   _सुथर, zenŝ, мысц, --, 
   {{0x1868039b,0xbec400ef,0x75d4007b,0xb8a00092}},	//   _ҳақи_, _grīņ, سيرا, ገለግል_, 
   {{0x2be03ee1,0x00000000,0x00000000,0x00000000}},	//   _परमा, --, --, --, 
   {{0x644c02b9,0xf1f80aaa,0x64a01d8c,0x59cc4433}},	// [18f60] _dbci, معات_, хата, _सुतर, 
   {{0x2bcc75be,0x00000000,0x00000000,0x00000000}},	//   _हँसा, --, --, --, 
   {{0x7ce40077,0x2be0c488,0xc31c0154,0x00000000}},	//   mórf, _परभा, ধূলি_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x71741077,0x3f9803e3,0xa3b001f9,0x00000000}},	//   _کهزا, _üsul_, _झेप_, --, 
   {{0xb8dc3ae9,0x4254355a,0x9f8005f5,0x00000000}},	//   _ཀམ_, _отст, эгчд, --, 
   {{0xa2e10fcc,0x6600002d,0x8480001f,0xc29000f2}},	//   _чорд, _ûnke, _ነገሩን_, _جیلب, 
   {{0x71a40022,0x59cc1414,0x00000000,0x00000000}},	//   _даҳз, _सुधर, --, --, 
   {{0x8ac80517,0xe454008f,0xd90c01d9,0x00000000}},	//   оқда_, ליקט_, ۯیٹ_, --, 
   {{0xf8ac00aa,0x6f00009a,0xe45c01a8,0x1f60013e}},	//   یکي_, mqoc, _gjöf_, _якум, 
   {{0xed3405f5,0x59cc07d0,0x2d950fcd,0x5e6000d1}},	//   _хэзэ, _सुदर, _эрас, _سۆيە, 
   {{0x290811f9,0xece873e6,0xdca0010a,0x00000000}},	//   ība_, _удел_, _пахи, --, 
   {{0x6f000309,0xa6f00107,0x00000000,0x00000000}},	//   nqoc, нҷиш, --, --, 
   {{0xf1bc01bc,0x7cc00029,0x9b840150,0x644c058a}},	//   ्थान, mēra, _ءنول_, _sbci, 
   {{0x48c401d5,0x00000000,0x00000000,0x00000000}},	//   _ошиғ, --, --, --, 
   {{0xe45c00fc,0x00000000,0x00000000,0x00000000}},	//   _mjög_, --, --, --, 
   {{0xa3e4652f,0xe45c01e3,0x21c40150,0x66c81188}},	// [18f70] यें_, _ljög_, _ﺩﻜﺘﻭ, _гунг_, 
   {{0x2494001f,0x979c011a,0xa2802a9f,0x00000000}},	//   _መገመት_, _לשחק, ریزو, --, 
   {{0x2bbc004d,0x61f80166,0x00000000,0x00000000}},	//   ịch_, _şuls, --, --, 
   {{0x7fd50617,0xbffc00fe,0x21240208,0x00000000}},	//   мілі, ুণ্ণ_, ĩnh_, --, 
   {{0x5338010a,0x00000000,0x00000000,0x00000000}},	//   _нурă, --, --, --, 
   {{0xfa080135,0x7a2801d3,0x3e6c01d3,0xddc000a2}},	//   _གཅེན_, _kötő, kötő_, genş, 
   {{0x3b08025c,0x5f7404f2,0x18a40092,0xa0a400d8}},	//   _ħaqq_, _کازر, _ሊፈጠር_, _ешал, 
   {{0xb5a802f5,0x6294022e,0x00000000,0x00000000}},	//   _খুঁচ, lkxo, --, --, 
   {{0xfaa50fce,0xfbc4068e,0xfa3400f2,0x00000000}},	//   дапо, ьбио, وردد, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdd990fcf,0xd90c0214,0x00000000,0x00000000}},	//   _уша_, دیع_, --, --, 
   {{0x7cf40064,0x00000000,0x00000000,0x00000000}},	//   _išro, --, --, --, 
   {{0xdec802d3,0x1b0400cc,0x59cc0037,0xddc000e5}},	//   _ኢለን_, _শিকে_, _सँवर, menő, 
   {{0x7afc9eb8,0xddc000dd,0x201c0381,0x2be0041c}},	//   ístu, lenő, _leui_, _परता, 
   {{0xa504871a,0xf7700c50,0x00000000,0x00000000}},	//   деса_, راڭ_, --, --, 
   {{0x6f000113,0x00000000,0x00000000,0x00000000}},	//   yqoc, --, --, --, 
   {{0xc61c03f4,0x7ce40798,0xa760004e,0x798002d0}},	// [18f80] _তারা_, mórd, _акыд, lxlw, 
   {{0xe45d0fd0,0x248805b1,0x236c0008,0x201c0393}},	//   _sköt_, _eocm_, ægja_, _aeui_, 
   {{0xe45c01e6,0xa6d802d2,0x00000000,0x00000000}},	//   _bjöd_, fuðf, --, --, 
   {{0x998400e5,0x00000000,0x00000000,0x00000000}},	//   _jenő_, --, --, --, 
   {{0x201cebf1,0x2be01a04,0xe81c0490,0x6ee4004b}},	//   _deui_, _परधा, परता_, وستل, 
   {{0x6280023a,0x6f000113,0x81cc0011,0x8fc40022}},	//   önot, rqoc, শেই_, _ҟазҵ, 
   {{0x7cf00124,0x00000000,0x00000000,0x00000000}},	//   _ẽrap, --, --, --, 
   {{0xfa08025c,0xdcb40276,0xde000131,0x2be0de66}},	//   _གཅུན_, дщь_, нпәи, _परदा, 
   {{0x2bcc0073,0xfaf80064,0x00000000,0x00000000}},	//   _हुशा, dvūs_, --, --, 
   {{0xed5819c9,0x201c0165,0x25ec0073,0x1b040154}},	//   _моз_, _zeui_, _आणली_, _শিখে_, 
   {{0xd9141301,0xe870034c,0xc61c0154,0x96280171}},	//   мья_, نندگ, _তালা_, _meņģ, 
   {{0xbe800124,0x6d48002f,0x00000000,0x00000000}},	//   _ақәи, mtfa, --, --, 
   {{0xb9040401,0xd7f90be2,0x6d482711,0x667405af}},	//   _बी_, дур_, ltfa, ودسر, 
   {{0x59cc3f55,0x7ce40005,0x69cc05d1,0xbb440150}},	//   _सुवर, tórg, übes, _ﺘﺤﻠ_, 
   {{0x9960fba1,0x38a001e7,0x0cd000fe,0x73c00022}},	//   _атыл, _bórd_, াগীত, ҳәре, 
   {{0x7ce50fd1,0x290c0327,0x260c4466,0x758001d5}},	//   córd, _itfa_, _त्री_, چییم, 
   {{0x73c018ce,0xc2987fb5,0x4274b5f5,0x6d487906}},	// [18f90] гәре, пках_, нгас, htfa, 
   {{0x201c0b23,0x7ce4033f,0x00000000,0x00000000}},	//   _seui_, móre, --, --, 
   {{0xd49c01e1,0x7ce40c63,0x00000000,0x00000000}},	//   _kọ̀_, lóre, --, --, 
   {{0x6d4800b5,0x4614036b,0xd77401ec,0x4ad00073}},	//   dtfa, _توگر, _ساۋع, सकडव, 
   {{0x6d48002d,0xd49c0ca8,0x2bcc302b,0x628001f4}},	//   etfa, _mọ̀_, _हुला, önos, 
   {{0x6b940209,0xd49c0241,0x78740166,0xa7f80139}},	//   _ýygy, _lọ̀_, _küvä, leñd, 
   {{0x201d0fd2,0xed4c4ce4,0x6d48005c,0x0f340023}},	//   _teui_, مپو_, gtfa, _ኣይርከ, 
   {{0x38a00241,0x7ce400d0,0xbb8400ae,0x260cf5d8}},	//   _kóre_, kóre, فلبي, तुती_, 
   {{0x7cc000de,0x00000000,0x00000000,0x00000000}},	//   bērn, --, --, --, 
   {{0x7f480921,0x2ec807b7,0xd01000f1,0x7ce40022}},	//   _iqeq, ाकृत, _ملې_, dóre, 
   {{0xd49c0241,0xf99000c6,0x6d4800d8,0x5d640166}},	//   _bọ̀_, ابخ_, ctfa, _ютаз, 
   {{0x7cc000da,0x9ba00efb,0xded40023,0x7b3406be}},	//   mēro, _لەبى, _ክረአ_, _ağuş, 
   {{0xcc98021a,0x7d010fd3,0x69cc0730,0x888014d4}},	//   _زموږ_, _huls, über, рғыл, 
   {{0x7d000429,0x7f48379d,0xfa080135,0x7ce40789}},	//   _kuls, _mqeq, _གཅིན_, sórd, 
   {{0x7d010fd4,0xd49c0241,0xbb0003d4,0x916c0051}},	//   _juls, _fọ̀_, _এবিধ_, _mộc_, 
   {{0x7d010fd5,0x7f480944,0x37e415d1,0x7ce45178}},	//   _muls, _oqeq, _пойг, bóre, 
   {{0xacd8010f,0xa6d802d2,0x00000000,0x00000000}},	// [18fa0] פֿלי, fuðd, --, --, 
   {{0xc3082158,0x2be011a6,0x7d000857,0x71a421f3}},	//   _লিখি_, _परसा, _ouls, назз, 
   {{0x7f480944,0x7d00037e,0x64480137,0xd49c0241}},	//   _aqeq, _nuls, ògic, _yọ̀_, 
   {{0x38a001a2,0xefc0001f,0xa0a001c6,0x00000000}},	//   _fóre_, _ስራው_, лахд, --, 
   {{0x6d4c006a,0x7bd80223,0x7d0003ac,0x3a243735}},	//   _âbaz, _nywu, _auls, kalp_, 
   {{0x7d010fd6,0xf1a80244,0xdfcca706,0x00000000}},	//   _buls, _فازه_, حيه_, --, 
   {{0x2d9807dd,0x7f4801e2,0x7d000548,0xe1f00014}},	//   ápe_, _eqeq, _culs, _مسٲ_, 
   {{0x6d490fd7,0x7d010fd8,0x7bd8045f,0xa3e50fd9}},	//   rtfa, _duls, _bywu, येक_, 
   {{0xaec4177b,0x6d485337,0xa0a000ee,0xd49c0241}},	//   _збал, stfa, _сатд, _rọ̀_, 
   {{0x7d010fda,0xdd8c0050,0x6d48faf0,0x65a0022e}},	//   _fuls, _گوم_, ptfa, _mеhr, 
   {{0x7afc0232,0x7d010fdb,0x7bd80113,0x2be00b03}},	//   ístr, _guls, _eywu, _परवा, 
   {{0xdd8d0fdc,0xaa900116,0x1af400cf,0x00000000}},	//   _دوم_, _әгкә, мдөө_, --, 
   {{0xfca801d9,0xf8ac12ea,0x7afc00df,0x5984009d}},	//   _تالو_, تکو_, ŭstr, дөөн_, 
   {{0xe97001d9,0x7d010fdd,0xd49c0241,0x00000000}},	//   _منتھ, _yuls, _wọ̀_, --, 
   {{0x45d43d63,0x22a40241,0xe3bc013d,0xd49c01e1}},	//   товс, _líkù_, _meñe_, _tọ̀_, 
   {{0xe290d537,0x25bc0311,0x7ce4012d,0x91d400cd}},	//   گذر_, ăul_, mórc, _बुधै, 
   {{0x53349b96,0xc3c40184,0x00000000,0x00000000}},	// [18fb0] летт, төнл, --, --, 
   {{0x7aec02e8,0xe3bc00e4,0x52d835c7,0x00000000}},	//   _èatt, _neñe_, емую_, --, 
   {{0xd1300583,0x00000000,0x00000000,0x00000000}},	//   یمے_, --, --, --, 
   {{0x7cc000da,0x7d000115,0x3ff40a11,0x42e00011}},	//   vēro, _ruls, نكار, বদেশ, 
   {{0x4f08005e,0x7d010fde,0xbe6801c0,0x83a40022}},	//   енін_, _suls, далж_, _рынҵ, 
   {{0x7bd800a9,0x645c0869,0x7cc000b0,0xe1f02b9f}},	//   _rywu, leqi, tēro, _مسز_, 
   {{0x6d4c01b8,0x7bd8017a,0x6e900114,0xbb440150}},	//   _äbal, _sywu, рију, _ﺘﻤﻸ_, 
   {{0x7d010fdf,0x645c01f0,0x98e0022e,0x00000000}},	//   _vuls, neqi, _yo創a, --, 
   {{0xac810fe0,0x7f484242,0x7d00002f,0x916c0208}},	//   ргыл, _uqeq, _wuls, _tộc_, 
   {{0x41381ee0,0x2be00b40,0x645c0240,0x8fa400f3}},	//   _ቤተሰቦ, _पररा, heqi, _сађе, 
   {{0x645cc069,0x7d00003a,0x3a250fe1,0x89f402d5}},	//   keqi, _uuls, ralp_, ляюц, 
   {{0x7ce40077,0xa7f8005a,0xefcc0023,0xda100133}},	//   sórb, zeñe, እልዩ_, _ڵستک, 
   {{0xeb8d0fe2,0x645c022f,0xfb8404fb,0x6d600210}},	//   _ти_, deqi, _جدای, ętał, 
   {{0xa7f8172e,0x59cc00ab,0x00000000,0x00000000}},	//   xeñe, _सुअर, --, --, 
   {{0xa6d8008c,0xa7f8056a,0x00000000,0x00000000}},	//   fuðb, veñe, --, --, 
   {{0x645cb708,0xe4c006b3,0xefc00023,0x00000000}},	//   geqi, айси, _ስያዊ_, --, 
   {{0x229c00d2,0xe8d4b0a6,0x2324561e,0xa7f8056a}},	// [18fc0] _sîka_, _בוקר_, коти_, teñe, 
   {{0x229c145e,0x95242fc0,0x62800108,0x00000000}},	//   _pîka_, _مکرم, önop, --, 
   {{0x35a421f3,0x645d0fe3,0xe3bc0022,0x64b4107d}},	//   _ранг, beqi, _reñe_, rćir, 
   {{0xa7f804d4,0x00000000,0x00000000,0x00000000}},	//   señe, --, --, --, 
   {{0x437400d1,0xe3bd0fe4,0xf40800db,0x00000000}},	//   _йурт, _peñe_, _ىيگى_, --, 
   {{0x5f910fe5,0x00000000,0x00000000,0x00000000}},	//   ришт, --, --, --, 
   {{0xe1f400f3,0x00000000,0x00000000,0x00000000}},	//   _агр_, --, --, --, 
   {{0x61e10fe6,0x66d8006a,0x7ce40798,0x7df400d1}},	//   ünle, rîki, vórc, چقۇچ, 
   {{0x69c84709,0xceb801ec,0x7ce4012d,0x620402d2}},	//   _सुजी, _пәк_, wórc, _örlæ, 
   {{0x645c014b,0x935802d3,0xa7f805c7,0x9eb40022}},	//   zeqi, _ምክትታ, heñc, _ишхә, 
   {{0x645c401f,0xe81c0073,0x00000000,0x00000000}},	//   yeqi, परला_, --, --, 
   {{0x6d590fe7,0xfa5401b9,0xeb9800d8,0x00000000}},	//   _ipta, پریگ, _оие_, --, 
   {{0xab988efb,0x68ec0175,0x2aa800cf,0xeabc0354}},	//   _تخار_, rmcd, _отко_, _дιа_, 
   {{0xda6c0a81,0x645c01f0,0x7ce50fe8,0x9980004b}},	//   _وُن_, weqi, móra, _چلوو, 
   {{0x645cc069,0x7ce40332,0x85040066,0xd5b8009d}},	//   teqi, lóra, اورن, вст_, 
   {{0x645c0194,0x69c802d0,0x7800014b,0x00000000}},	//   ueqi, _ixfe, _гӯра, --, 
   {{0xd3703306,0x6600002d,0x645d0fe9,0xc2c400e3}},	// [18fd0] يهِ_, _ûnko, reqi, هيري, 
   {{0x6d590fea,0x2244066d,0x645d0feb,0x00000000}},	//   _opta, ünk_, seqi, --, 
   {{0xa3e4069f,0xc69001d9,0x96b90fec,0x7ce50fed}},	//   येज_, _نِک_, _جايز_, hóra, 
   {{0x38a021f1,0x65740200,0x7ce400c7,0xb9ec0023}},	//   _kóra_, _irxh, kóra, _ሓዋ_, 
   {{0x44290fee,0x6d590fef,0x7ce41f60,0xe3bc00e8}},	//   maa_, _apta, jóra, _deñc_, 
   {{0x44290ff0,0x6d5808cd,0x38a10ff1,0x7cf40006}},	//   laa_, _bpta, _móra_, _išri, 
   {{0x44280270,0xee2c05d9,0xcd2806f6,0xf2d002e4}},	//   oaa_, سٽي_, نسين_, _העם_, 
   {{0x44290ff2,0x7ce40597,0x26c00010,0x00000000}},	//   naa_, fóra, hnjo_, --, 
   {{0x7b74ef10,0x44290ff3,0x6d590ff4,0x26c00219}},	//   اطبا, iaa_, _epta, knjo_, 
   {{0x44290ff5,0xbb7401e0,0xdd98466e,0x00000000}},	//   haa_, _ҡулъ, _оше_, --, 
   {{0x26c00fb7,0x00000000,0x00000000,0x00000000}},	//   dnjo_, --, --, --, 
   {{0x44290ff6,0x7ce40077,0x3154010f,0x20d000cd}},	//   jaa_, bóra, נירן_, तविध, 
   {{0x44290ff7,0x7c290ff8,0x69c8003a,0x7ce40077}},	//   daa_, maer, _exfe, córa, 
   {{0x25ec05ba,0x7c280dd4,0x38a0012b,0x78a40240}},	//   _आणखी_, laer, _dóra_, shkv, 
   {{0x44290ff9,0x00000000,0x00000000,0x00000000}},	//   faa_, --, --, --, 
   {{0x44290ffa,0x38a10ffb,0x7c290ffc,0x26c0d0a4}},	//   gaa_, _fóra_, naer, anjo_, 
   {{0xb9d00020,0x38a0068f,0x7c280083,0xded40023}},	// [18fe0] _ስር_, _góra_, iaer, ዮምን_, 
   {{0x7c290ffd,0x229c2776,0x0cb000cd,0x00000000}},	//   haer, _dîko_, _जग्म, --, 
   {{0x44290ffe,0x7c290fff,0xa7f804d4,0xd16400c7}},	//   baa_, kaer, meña, рнеқ, 
   {{0x44291000,0x6738151c,0xe7b80034,0xa7f83eba}},	//   caa_, šuje, _उधमप, leña, 
   {{0x8f8407d6,0x7c291001,0xabb00882,0x6d580135}},	//   шқал, daer, kṣaṃ_, _spta, 
   {{0xa7f80086,0x7ce400c7,0x6f2400ef,0x00000000}},	//   neña, vóra, _ērcī, --, 
   {{0x78b40118,0xdcf00205,0x00000000,0x00000000}},	//   _omyv, çağd, --, --, 
   {{0x229c025a,0x7c291002,0x7ce51003,0x817c0092}},	//   _yîko_, gaer, tóra, _የሚባሉ_, 
   {{0xabb00116,0xcdc800cf,0x00000000,0x00000000}},	//   сапә, رۇچۇ_, --, --, 
   {{0x44291004,0x204c010c,0xd9300092,0x7ce400e4}},	//   zaa_, _መዝሙር, _በተዘዋ, róra, 
   {{0x44291005,0x6d591006,0x7c280280,0xa7f83eba}},	//   yaa_, _upta, baer, deña, 
   {{0x44287fc5,0xe3bc2b76,0xb4cc0316,0x7c280077}},	//   xaa_, _leña_, शको_, caer, 
   {{0x44291007,0x26c11008,0xac940022,0x2b146584}},	//   vaa_, tnjo_, _иаҧш, _сьер, 
   {{0x44291009,0xa7f800e8,0x49742b8e,0x59cc002b}},	//   waa_, geña, _влкс, _सुकर, 
   {{0x4429100a,0x229c00d2,0x6ab8003c,0x26c00219}},	//   taa_, _sîko_, mitf, rnjo_, 
   {{0x6ab8192e,0x38a065ff,0x26c09a64,0x44280194}},	//   litf, _tóra_, snjo_, uaa_, 
   {{0x4429100b,0x26c009a8,0x0444013d,0x7ce5100c}},	// [18ff0] raa_, pnjo_, леңн, kórn, 
   {{0x4429100d,0x7ce41c38,0x7c280099,0x6ab801bf}},	//   saa_, jórn, zaer, nitf, 
   {{0x4429100e,0x7c282d3a,0x41843452,0xd25800c7}},	//   paa_, yaer, штағ, ыцт_, 
   {{0x442822a9,0x66d8019f,0x229c00d2,0x6ab800d2}},	//   qaa_, rîku, _tîko_, hitf, 
   {{0x68fc0fed,0x7c29100f,0x7ce51010,0x53a40153}},	//   _miqd, vaer, fórn, _гаўб, 
   {{0x7c291011,0x2284008e,0x7cc000e2,0x68fc56f7}},	//   waer, _сумг, pērk, _liqd, 
   {{0x7c291012,0xb14401ed,0x6ab801bf,0x7cc000e2}},	//   taer, _نیلم_, ditf, lēri, 
   {{0x3f1400d4,0x9f2400e5,0x59ccd639,0xe0dc0ca8}},	//   _вдас, _ميرے_, _सुगर, _óò_, 
   {{0xbf151013,0x7c291014,0x60d91015,0x00000000}},	//   _ضواب, raer, _ikum, --, 
   {{0xa7f81709,0x7c291016,0x6ab80af2,0x7ce40798}},	//   xeña, saer, gitf, córn, 
   {{0xdd7000aa,0x68fc016d,0x60d91017,0x58043d09}},	//   _دپاک, _biqd, _kkum, йонғ, 
   {{0xe45c01e6,0x7c280194,0xe8f4084c,0x00000000}},	//   _sjön_, qaer, илэ_, --, 
   {{0x60d91018,0xa7f80005,0xc61c0154,0x38a002d2}},	//   _mkum, teña, _তাজা_, _fórn_, 
   {{0x6ab8003c,0xa498067c,0xca4800ec,0x00000000}},	//   citf, _niòb, _ملهه_, --, 
   {{0x60d91019,0x2564015d,0xa7f876df,0x2ab8011a}},	//   _okum, _cŵl_, reña, _שמצא, 
   {{0xa7f828f2,0x60d9101a,0x78b402fb,0xe3bc0615}},	//   seña, _nkum, _umyv, _seña_, 
  
   {{0xe3bc98fa,0xa7f9101b,0x38a000e4,0x64a02401}},	// [19000] _peña_, peña, _hóro_, цата, 
   {{0x817c0020,0xe2801fbe,0x00000000,0x00000000}},	//   _የሚችሉ_, олуи, --, --, 
   {{0x14c8034c,0xe3bc056a,0x7ae1101c,0x68fc022e}},	//   _مهدی_, _veña_, illt, _yiqd, 
   {{0x3ea5101d,0x6d4c01b8,0x61e02e1b,0x38a000e4}},	//   _allt_, _äbai, ünla, _móro_, 
   {{0xe3bc172e,0x6ab8003c,0xe45cc9df,0xb4e00490}},	//   _teña_, yitf, _mjöl_, धती_, 
   {{0xe29c032e,0x92e400cc,0x00000000,0x00000000}},	//   _tuða_, _পূৰ_, --, --, 
   {{0x6e282c6a,0x42541def,0x6ca4eb13,0xeca40114}},	//   rafb, _утят, ириж, ијин, 
   {{0x6ab804cc,0xffa405a2,0x00000000,0x00000000}},	//   witf, рләү, --, --, 
   {{0x6ab9101e,0x68fc31c5,0x00000000,0x00000000}},	//   titf, _riqd, --, --, 
   {{0x68fc014f,0x60d801ef,0x00000000,0x00000000}},	//   _siqd, _zkum, --, --, 
   {{0x6ab81654,0x60d800e4,0x92e400fe,0xa7f8013d}},	//   ritf, _ykum, _পূৱ_, geñn, 
   {{0x6ab81cea,0x7ae1101f,0x60d8025c,0x2eb400c5}},	//   sitf, allt, _xkum, _अगुत, 
   {{0xfca80014,0x9cb0007b,0x00000000,0x00000000}},	//   _حالو_, _بمنت, --, --, 
   {{0x2ca479d7,0xdb980375,0xe29c02d2,0x78ac025c}},	//   _hlod_, _בסדר, _auðn_, _ċave, 
   {{0x2ca40100,0x68fc016d,0xe45c032e,0x00000000}},	//   _klod_, _tiqd, _fjöl_, --, 
   {{0x7cc000da,0x94a87b68,0x00000000,0x00000000}},	//   tēri, атуа_, --, --, 
   {{0xa7f80407,0x2ca40332,0x00000000,0x00000000}},	// [19010] meño, _mlod_, --, --, 
   {{0xa7f82b76,0x00000000,0x00000000,0x00000000}},	//   leño, --, --, --, 
   {{0x4154adc0,0x00000000,0x00000000,0x00000000}},	//   свес, --, --, --, 
   {{0xa49800db,0x7cc000e2,0xa7f80022,0xe7b8000d}},	//   _diòc, pēri, neño, _उधाप, 
   {{0x7ae11020,0x61f8008f,0x7050007b,0xfbd4000d}},	//   yllt, _ŝuld, سنوا, _डुंम, 
   {{0x201c001f,0xa7f80124,0x2bc8a765,0xe73c0022}},	//   ስትራክ, heño, ापना, irõ_, 
   {{0xdf7001e1,0x3ea51021,0x7a6801d5,0x00000000}},	//   _bẹ̀é, _vllt_, қинг_, --, 
   {{0x60d91022,0x2ca51023,0xa7f80789,0xd0d402e8}},	//   _ukum, _clod_, jeño, _досъ, 
   {{0xe3bc0789,0xa3d41dd1,0xa7f80407,0xec740153}},	//   _meño_, िथि_, deño, спы_, 
   {{0xe3bc04d4,0xfaa80451,0x39450cc2,0xbb4801d5}},	//   _leño_, اهدي_, бног, پلگن_, 
   {{0x2ca51024,0x38280b32,0xbb8408f0,0x7ce40332}},	//   _flod_, лжно_, _گلشي, lórm, 
   {{0xa7f80724,0x2ca4015d,0x7ae00042,0x0ae800cf}},	//   reñn, _glod_, sllt, лдөй_, 
   {{0x9b6402da,0x00000000,0x00000000,0x00000000}},	//   _خطاه, --, --, --, 
   {{0x87b80c9e,0x38a000c7,0x00000000,0x00000000}},	//   руют_, _tóro_, --, --, 
   {{0xe5a02310,0xa7f91025,0x3b0c0309,0x25d807f7}},	//   пири, beño, lqeq_, _खुदी_, 
   {{0xe3bc0789,0xb4e028b8,0x3944dcf8,0xb8641291}},	//   _ceño_, धते_, muls_, _طاعو, 
   {{0x962400ef,0x00000000,0x00000000,0x00000000}},	// [19020] _šņuk, --, --, --, 
   {{0x3870155d,0xe2951026,0x5fd80037,0x00000000}},	//   _hayr_, бау_, _बड़ल, --, 
   {{0x39440998,0xb7e802f5,0x38700165,0x3b0c016d}},	//   nuls_, _গলিত_, _kayr_, hqeq_, 
   {{0x7ce42d86,0xefe8044e,0xe3bc00e8,0xef840006}},	//   fórm, _ህሉው_, _geño_, йлеп, 
   {{0x2f551027,0x394404cc,0xceb80032,0xdf7001e1}},	//   стес, huls_, аҙа_, _rẹ̀é, 
   {{0x39451028,0xf678008f,0xdce00139,0x00000000}},	//   kuls_, ראַמ, dynı, --, 
   {{0x6140bd08,0x50a401e0,0x394401bf,0x00000000}},	//   _нера, _һуҡҡ, juls_, --, 
   {{0x39451029,0xde140075,0xa7f80005,0x0dc80131}},	//   duls_, لقۇت_, xeño, луқи_, 
   {{0x7e70006a,0x394405d5,0x2ca40076,0x2084005b}},	//   ökpä, euls_, _vlod_, _уйти_, 
   {{0x3945102a,0xc600015b,0x6ec4009f,0x63b8010e}},	//   fuls_, ্রতা_, _اترق, _ýune, 
   {{0x38700363,0xa7f8c5e5,0xdf700241,0x00000000}},	//   _bayr_, teño, _tẹ̀é, --, 
   {{0x2ca4089c,0x38705d3e,0x7c2c0115,0xb88000d0}},	//   _ulod_, _cayr_, _ĵarg, _šíra, 
   {{0x27481301,0xa7f9102b,0x3871102c,0x98b800a7}},	//   ычно_, reño, _dayr_, слят_, 
   {{0x442c23e2,0xa7f809ff,0x3945102d,0x9b90030d}},	//   _že_, seño, buls_, _хишц, 
   {{0xa7f804d4,0x394407de,0x2ba40307,0x7c4401a8}},	//   peño, culs_, गनवा, _útrý, 
   {{0xd499102e,0xfbe8ad47,0x58d400a7,0x38700205}},	//   бру_, _øªù_, _нощт, _gayr_, 
   {{0xe3bc0005,0x1fb41d15,0x63b00022,0x00000000}},	// [19030] _veño_, _अधेड, чааӡ, --, 
   {{0x37b0015b,0x00000000,0x00000000,0x00000000}},	//   _টুকর, --, --, --, 
   {{0xe3bc172e,0xd25001d9,0xd564022e,0x00000000}},	//   _teño_, ژنے_, _етяп, --, 
   {{0x387001d5,0x3b0c016d,0x3f9c012d,0x442c08a5}},	//   _xayr_, yqeq_, tywu_, _þe_, 
   {{0x4439102f,0x644ce9e5,0xd13800d1,0x00000000}},	//   _ids_, _icci, لكەش_, --, 
   {{0x44381d3f,0xfd10007b,0x2be000cd,0x00000000}},	//   _hds_, وجب_, _परजा, --, 
   {{0xa6d803b2,0x21240066,0x00000000,0x00000000}},	//   vuðl, _ديزی_, --, --, 
   {{0x7ce40034,0x44391030,0x00000000,0x00000000}},	//   mórk, _jds_, --, --, 
   {{0x25d8012c,0x4438045a,0x3b8428f6,0xa6d80d12}},	//   _खुसी_, _mds_, ілог, tuðl, 
   {{0x3a9807d8,0x387001d5,0x443878de,0x539c011a}},	//   ртию_, _sayr_, _lds_, טיחו, 
   {{0xf8648701,0x44391031,0x39e83acc,0x644d1032}},	//   овно, _ods_, рдно_, _occi, 
   {{0x44391033,0x3870058a,0x2be002c3,0x00000000}},	//   _nds_, _qayr_, _परचा, --, 
   {{0x387000ad,0x00000000,0x00000000,0x00000000}},	//   _vayr_, --, --, --, 
   {{0x44391034,0x39451035,0x644d1036,0x9f5c01e7}},	//   _ads_, puls_, _acci, _nguí_, 
   {{0x44391037,0x660063e8,0xa6e009f3,0x66e0013e}},	//   _bds_, дпра, úðar, фора, 
   {{0x443802c2,0x7cc000ef,0x00000000,0x00000000}},	//   _cds_, cērt, --, --, 
   {{0x2bf400c8,0x2be0012d,0x723400ae,0x00000000}},	// [19040] ַמען_, _परछा, قراط, --, 
   {{0x644d1038,0x00000000,0x00000000,0x00000000}},	//   _ecci, --, --, --, 
   {{0x443810d8,0x7c38033f,0xe29c02d2,0x7ce40210}},	//   _fds_, _odwr, _guðm_, górk, 
   {{0xf0b8014d,0x61f80115,0xd01000f2,0x00000000}},	//   جائش_, _ŝulc, رلت_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x1ec4036b,0xa6d801a8,0x44380010,0x23240353}},	//   олчи_, orða, _zds_, _фори_, 
   {{0xeba80579,0x44391039,0x71742614,0x21300051}},	//   kvøð_, _yds_, _بهزا, csxh_, 
   {{0xe8b40135,0x44380067,0xe0d4234c,0xef184f5c}},	//   _བཏེག, _xds_, _двс_, _вма_, 
   {{0x7cc00029,0x7c380042,0xefb0036b,0xb6040024}},	//   vērt, _ddwr, _تیشگ, opšč, 
   {{0x4a540798,0x00000000,0x00000000,0x00000000}},	//   чкос, --, --, --, 
   {{0x3f8002b5,0x6c741188,0x00000000,0x00000000}},	//   āhue_, _мудх, --, --, 
   {{0x76400198,0xe784399b,0x00000000,0x00000000}},	//   _ɓoye, оуго, --, --, 
   {{0x4439103a,0x8e7c0115,0x9804010b,0xfe7000db}},	//   _rds_, _ekĝe, дярд, _زدە_, 
   {{0x44380f85,0x67380427,0x00000000,0x00000000}},	//   _sds_, šujo, --, --, 
   {{0x25d8b5f0,0x0424025c,0xa49800a3,0x7afd103b}},	//   _खुशी_, _འབྱམ_, _diòn, ïste, 
   {{0x291d103c,0x98c40046,0x4735103d,0xd8b806f6}},	//   mpta_, _осыл, _енис, _وديا_, 
   {{0x4439103e,0x291c0393,0x7ce4012d,0x00000000}},	// [19050] _vds_, lpta_, wórk, --, 
   {{0x291c020b,0xa4980208,0xca900023,0x00000000}},	//   opta_, _giòn, ምሮኦም_, --, 
   {{0x644c01f7,0x2124180f,0xe2c400f1,0x00000000}},	//   _tcci, ènh_, موړو_, --, 
   {{0x644d103f,0x44391040,0x291c00c0,0x00000000}},	//   _ucci, _uds_, ipta_, --, 
   {{0xf7e40150,0x1e703eeb,0x93e4022e,0x00000000}},	//   _ﺍﺭﻟﻪ, мғас, _жўрл, --, 
   {{0xa1340502,0x7ce51041,0xe1640092,0x00000000}},	//   _ورزش, móri, _ደጋግሞ_, --, 
   {{0x7ce51042,0x69cc000f,0x3f880356,0x00000000}},	//   lóri, ûbel, ţau_, --, 
   {{0x7cc000da,0x6aa91043,0xeb3c0092,0xa6d8032e}},	//   vērs, _alff, _ተነጋገ, fuðk, 
   {{0x5f74bc3d,0x7ce40798,0xdb1806be,0x291d1044}},	//   _بازر, nóri, _üzüd, epta_, 
   {{0xe8b4031c,0x4ea51045,0x39441468,0x00000000}},	//   _བཏུག, _орха, пног, --, 
   {{0x291c02b9,0x60c801fb,0x38a003b2,0x25d81414}},	//   gpta_, ongm, _hóri_, _खुली_, 
   {{0x8d741e0e,0x7ce4022c,0x6aa82d42,0x38a003b2}},	//   _زاما, kóri, _elff, _kóri_, 
   {{0x60c80d04,0x291c084c,0x62851046,0x7ce408a7}},	//   ingm, apta_, _onjo, jóri, 
   {{0x6aa80175,0x41bc07b7,0xeb940354,0x64a00124}},	//   _glff, ्पास, _хиш_, ҭара, 
   {{0x9ba00150,0x38a00248,0x00000000,0x00000000}},	//   _رەگى, _lóri_, --, --, 
   {{0x62851047,0x7ce406c6,0xa938011a,0x00000000}},	//   _anjo, fóri, _התקפ, --, 
   {{0x7ce4eb0d,0xe3611048,0x00000000,0x00000000}},	// [19060] góri, нкти, --, --, 
   {{0xe2951049,0x60c80369,0x61f80115,0x00000000}},	//   пау_, engm, _ŝula, --, 
   {{0x11680fa2,0x62840254,0xa698011a,0x5edc00cd}},	//   تلای_, _dnjo, _השיפ, गवन्_, 
   {{0x6285104a,0x38a00241,0xe7f00316,0xe755104b}},	//   _enjo, _bóri_, _घरमा_, _بلیغ_, 
   {{0x38a0026c,0x7ce400d8,0x6e3801e7,0x6f000241}},	//   _córi_, córi, _pdtb, _níbì, 
   {{0x764d104c,0x291d104d,0x62849f35,0x60c82877}},	//   ngby, ypta_, _gnjo, angm, 
   {{0x4c95104e,0x70540137,0xb1e400ae,0x224400d7}},	//   дийс, _ىنسا, _رأسه, ónke_, 
   {{0x38a001e1,0xad2400e5,0x00000000,0x00000000}},	//   _fóri_, _ہرصو, --, --, 
   {{0xa7f80165,0xcb98028e,0xe3bc00a2,0x00000000}},	//   reñk, زندش_, _reñk_, --, 
   {{0xa7f800e8,0x493800d4,0x00000000,0x00000000}},	//   señk, озою_, --, --, 
   {{0xa49800db,0x5a300276,0xa8509735,0x1dc000bc}},	//   _biòl, энэт, ненә, _वेपत, 
   {{0x6d48f16e,0x291d104f,0xa7f800a2,0x00000000}},	//   mufa, rpta_, leñi, --, 
   {{0x6d491050,0xa49801ab,0x2d6c00bc,0xe7851051}},	//   lufa, _diòl, _hře_, чуно, 
   {{0x291c5210,0x2ac00241,0x6d491052,0x290800d8}},	//   ppta_, _débè_, oufa, íbas_, 
   {{0xda5823e4,0x6d491053,0xa6d80008,0x2bc800cd}},	//   _הכול, nufa, nuði, ापवा, 
   {{0x7ce40cfc,0xd4991054,0xe3bc0165,0x62840158}},	//   tóri, пру_, _heñi_, _snjo, 
   {{0x6d491055,0x290c01c8,0x42751056,0xd8751057}},	// [19070] hufa, _hufa_, мгас, _سايب, 
   {{0x6d484ec2,0x00000000,0x00000000,0x00000000}},	//   kufa, --, --, --, 
   {{0xd130f703,0x26c10df7,0x7ce406ed,0xd850004d}},	//   ُمْ_, mijo_, sóri, _họat_, 
   {{0x6d48015c,0x290d1058,0x26c11059,0xd1381fe2}},	//   dufa, _mufa_, lijo_, яху_, 
   {{0x290d105a,0x00000000,0x00000000,0x00000000}},	//   _lufa_, --, --, --, 
   {{0x26c1105b,0x6284038f,0x2d6c012c,0x6d483210}},	//   nijo_, _unjo, _bře_, fufa, 
   {{0x6d481d5c,0x290c02a8,0x78a403cd,0xb91000b8}},	//   gufa, _nufa_, ykkv, bjaṃ_, 
   {{0x38a0f71b,0x3b842e36,0x2d6c01ef,0xa6b000eb}},	//   _tóri_, длиг, _dře_, ঁচিয়, 
   {{0x1ee5105c,0x290c0b23,0x6d480421,0xa49807c5}},	//   _فوری_, _aufa_, aufa, _riòl, 
   {{0xf7840510,0x6d484b7a,0x290c00db,0x26c1105d}},	//   _üçin_, bufa, _bufa_, jijo_, 
   {{0x26c1105e,0x290c0ba7,0xe9d40276,0x6d4801ab}},	//   dijo_, _cufa_, дкэ_, cufa, 
   {{0x3178010f,0x9f480162,0x00000000,0x00000000}},	//   קארד, _ímót_, --, --, 
   {{0x26c1105f,0x290c0198,0xe724016c,0xa4980ba1}},	//   fijo_, _eufa_, мояд_, _viòl, 
   {{0x6a80ec89,0x26c11060,0x290d1061,0xe7340261}},	//   _алша, gijo_, _fufa_, ќер_, 
   {{0x290d1062,0xe29c0321,0x00000000,0x00000000}},	//   _gufa_, _guði_, --, --, 
   {{0x7e600175,0x67281427,0x00000000,0x00000000}},	//   _lblp, ðmjú, --, --, 
   {{0xa854025f,0x26c11063,0x6d491064,0x290c0198}},	// [19080] _חיפה_, bijo_, zufa, _zufa_, 
   {{0x26c00f72,0xb848004b,0x7ce40022,0x00000000}},	//   cijo_, _اټکل_, móru, --, 
   {{0x7ce51065,0x6d48004e,0xa2cc00dc,0xf4080150}},	//   lóru, xufa, _ददर्, _ويدى_, 
   {{0x6aa808a3,0x3eb80064,0x00000000,0x00000000}},	//   _छत्र, _įsta_, --, --, 
   {{0xdd8c4046,0x6d485b12,0x6600002d,0x60c002bd}},	//   یوه_, wufa, _ûnkr, ènma, 
   {{0x6d491066,0xdfcc00c6,0x7e600334,0xb14401d5}},	//   tufa, جيه_, _cblp, _онгл, 
   {{0x3f8004fe,0x00000000,0x00000000,0x00000000}},	//   āhua_, --, --, --, 
   {{0x290d1067,0x26c0151c,0x764003f9,0x1f6000fd}},	//   _rufa_, zijo_, _ɓoya, хкәм, 
   {{0x290c8913,0xee7000fd,0x3588001f,0x7ce4148b}},	//   _sufa_, _аңлы, ኖርበት_, jóru, 
   {{0x6d480607,0x24bc00cc,0x290c15c0,0x00000000}},	//   pufa, _আৱাহ, _pufa_, --, 
   {{0x6da42004,0x26c00fb7,0x7afc067c,0x38a00248}},	//   _تمام, vijo_, ïsta, _lóru_, 
   {{0x7afc0024,0xdd8c02f2,0x1b6401ec,0x7ce4072d}},	//   įsta, _خوم_, _ﺳﻴﯩﺮ_, fóru, 
   {{0x26c11068,0x394497d4,0xa7f805c7,0xd7e40212}},	//   tijo_, arls_, heñv, віро, 
   {{0x290d1069,0x6b81106a,0xef3c02d3,0x00000000}},	//   _tufa_, _irog, _ኣይደል, --, 
   {{0x26c00fb7,0x6b81106b,0xddc0054e,0x00000000}},	//   rijo_, _hrog, menţ, --, 
   {{0x6b81106c,0x26c0151c,0xddc00276,0x38a00174}},	//   _krog, sijo_, lenţ, _bóru_, 
   {{0x5335106d,0x7ce40597,0x26c0151c,0xe3bc030a}},	// [19090] кетт, mórt, pijo_, _leñv_, 
   {{0xddc00276,0x38a0032e,0x8c140154,0x7ce40332}},	//   nenţ, _dóru_, সরিন_, lórt, 
   {{0xe3bc0156,0xa7f80165,0xa6d808a5,0x00000000}},	//   _neñv_, geñv, fuðv, --, 
   {{0x6b81106e,0x38a1106f,0x50b8028e,0x00e402f2}},	//   _orog, _fóru_, ودند_, رتای, 
   {{0x6b800218,0x93b40006,0x00000000,0x00000000}},	//   _nrog, _абяц, --, --, 
   {{0xddc0054e,0x00000000,0x00000000,0x00000000}},	//   jenţ, --, --, --, 
   {{0xddc000a8,0x5908025c,0x6d5c0200,0x81d4030d}},	//   denţ, _གཤེས_, çpap, _човх, 
   {{0x6b811070,0xf1b000c8,0x75cc01d3,0xa6d80bcd}},	//   _brog, _עסן_, lőzé, muðu, 
   {{0x1ddc0a94,0x6b811071,0xa6d80008,0x00000000}},	//   _पुरत, _crog, luðu, --, 
   {{0xddc0084c,0x39440477,0xa7f800e4,0x09c00154}},	//   genţ, trls_, neñu, _উড়া, 
   {{0x6b811072,0xa6d8008c,0xbebc0421,0x0dbc0125}},	//   _erog, nuðu, _atūg, ሳተፍ_, 
   {{0x6b811073,0xb4ac1a04,0x3bb85bc5,0x7ce40413}},	//   _frog, _कते_, _нулю_, tóru, 
   {{0x6b811074,0xd85001f2,0xe734011c,0x00000000}},	//   _grog, _fọnt_, нея_, --, 
   {{0xddc00276,0xba74581f,0x7ce4be27,0x00000000}},	//   cenţ, _ساتت, róru, --, 
   {{0x7ae11075,0x869802e8,0x00000000,0x00000000}},	//   molt, фтят_, --, --, 
   {{0x9c1002e3,0x80a00034,0x24880332,0xd864035b}},	//   sọft, कॉमे, _cncm_, _реиҩ, 
   {{0x7ae00f7e,0x88bc00bc,0x75cc00e5,0x00000000}},	// [190a0] oolt, spěc, főzé, --, 
   {{0x38a01125,0x87e8104e,0xa6d808a5,0x00000000}},	//   _vóru_, _юлың_, fuðu, --, 
   {{0x22440030,0x38a00162,0xa6d801a8,0x00000000}},	//   ónka_, _fórt_, guðu, --, 
   {{0x7ae11076,0xddc0084c,0x38a003b2,0xa7f80165}},	//   holt, zenţ, _tóru_, reñv, 
   {{0x1fa40276,0x93040022,0xe29c032e,0xa7f80165}},	//   нкци_, _аҟал, _auðu_, señv, 
   {{0x1fdc09bd,0x6b800023,0xe29c09e8,0xa0a000c7}},	//   _বৃহস, _rrog, _buðu_, _ҩард, 
   {{0xddc0084c,0x6b800166,0x7ae11077,0x21651078}},	//   venţ, _srog, dolt, _пири_, 
   {{0x7ce401a8,0xbebc00ef,0xa03000cf,0xf40403d4}},	//   dórs, _atūd, _مىفت, ষুণৰ_, 
   {{0x7ae11079,0xddc0084c,0xc0a84950,0xb4ac012c}},	//   folt, tenţ, _غافل_, _कतै_, 
   {{0x7ae1107a,0x3f980120,0x6b81107b,0x7ce400ae}},	//   golt, _àsua_, _vrog, fórs, 
   {{0xddc0084c,0x6b80033f,0xe8000412,0x7ce4012d}},	//   renţ, _wrog, रेना_, górs, 
   {{0xeb9818ec,0x6b800731,0x6d59107c,0xddc00311}},	//   _ние_, _trog, _iqta, senţ, 
   {{0x7ae1107d,0x996001ec,0xddc1107e,0xc5f80c6e}},	//   bolt, _ұтыл, menš, ंध्य_, 
   {{0x7ae1107f,0x38a00597,0x2488ba1f,0x00000000}},	//   colt, _sórt_, _sncm_, --, 
   {{0xd850063f,0x7ce47954,0xe7f000c5,0x2d580200}},	//   _kọlt_, pórt, _घरवा_, nëe_, 
   {{0x7bdc0140,0x00000000,0x00000000,0x00000000}},	//   ûsug, --, --, --, 
   {{0x4e1000ab,0x644800cf,0xe784030d,0x00000000}},	// [190b0] ाशाई_, ògiq, _чуйо, --, 
   {{0xa6d805f7,0x6d580213,0x00000000,0x00000000}},	//   tuðu, _oqta, --, --, 
   {{0xa7f801c4,0x00000000,0x00000000,0x00000000}},	//   reñu, --, --, --, 
   {{0x7ae0cee3,0xff501291,0x00000000,0x00000000}},	//   zolt, لخت_, --, --, 
   {{0x6d580bf1,0x7ae11080,0xe45c01a8,0xe29c032e}},	//   _aqta, yolt, _fjör_, _suðu_, 
   {{0x44291081,0xdebc02d3,0xc02802d3,0x222401d9}},	//   lba_, _ድማኒ_, ስትራል, _سٲری_, 
   {{0x44291082,0x8e7c0115,0x00000000,0x00000000}},	//   oba_, _ekĝo, --, --, 
   {{0x7ae0842d,0xe3bc00e8,0x8d8424b2,0xb0600037}},	//   wolt, _weñu_, اشون, äätm, 
   {{0xe800038e,0x44291083,0x6d580113,0xe3bc00e8}},	//   रेमा_, iba_, _eqta, _teñu_, 
   {{0x2d58006a,0x44280978,0x7ce403b2,0xf98400d4}},	//   bëe_, hba_, tórs, вгоо, 
   {{0x442800dd,0x2d98168c,0x7ae001d3,0xddc000ef}},	//   kba_, øpet_, rolt, benš, 
   {{0x44291084,0x2ab0006a,0xbb84007b,0xddc000de}},	//   jba_, _râbe_, _للصي, cenš, 
   {{0x7ae11085,0xb4ac000d,0x00000000,0x00000000}},	//   polt, _कतौ_, --, --, 
   {{0x44291086,0x7ce41e7b,0x7ae00548,0x00000000}},	//   eba_, córr, qolt, --, 
   {{0x65c11087,0x44291088,0xe3bc0165,0x7c291089}},	//   абра, fba_, _oeñs_, ober, 
   {{0x4429108a,0xf7482ab5,0xa6d801a8,0x77840117}},	//   gba_, _قلبي_, fuðs, _ализ, 
   {{0x7c29108b,0xa6d803f2,0xb9ec0240,0x00000000}},	// [190c0] iber, guðs, _ዓላ_, --, 
   {{0x7c29108c,0x3cec04cc,0x38a003b2,0x5ea400fe}},	//   hber, hlev_, _tórs_, কোতে, 
   {{0xf8c426d9,0x6449108d,0x7c2800e5,0xa2a0033f}},	//   _लगाय, ógic, kber, _गवर्, 
   {{0x4429108e,0xefdc02d3,0x00000000,0x00000000}},	//   cba_, _ሕራይ_, --, --, 
   {{0xdfcc06d5,0x2f542d31,0xddc1108f,0xd348034c}},	//   ييم_, ттес, venš, _سیاه_, 
   {{0x2d58006a,0x3cec00b5,0x7cf40024,0x437401a9}},	//   tëe_, elev_, _išry, _суют, 
   {{0x7c291090,0x81d400ee,0xcec80051,0x00000000}},	//   fber, _бцтц, nội_, --, 
   {{0x7c291091,0x3cec0dd4,0xa0a01171,0xd6b800eb}},	//   gber, glev_, _касд, ঁচিয, 
   {{0xe29c0ad9,0xafe40139,0xa0a001c6,0x00000000}},	//   _guðs_, _роал, _татд, --, 
   {{0x7c291092,0x44291093,0x2d5824ba,0x2d980212}},	//   aber, zba_, pëe_, øpes_, 
   {{0x44291094,0xb50001ad,0x3ced1095,0x6d580139}},	//   yba_, लगाय_, blev_, _uqta, 
   {{0x44280050,0xa8a42f34,0x49a40032,0x7c28010e}},	//   xba_, трок, _ҡыйғ, cber, 
   {{0x58d44945,0x44291096,0x1d040063,0x00000000}},	//   роят, vba_, _реци_, --, 
   {{0x44291097,0xa6d8022c,0x00000000,0x00000000}},	//   wba_, vuðs, --, --, 
   {{0x44291098,0x55591099,0x5695109a,0x048801ec}},	//   tba_, каря_, шарт, ншақ_, 
   {{0x4429109b,0x6d49109c,0x6d4400b8,0x00000000}},	//   uba_, irfa, _ākal, --, 
   {{0x6d480730,0x044402dd,0x7d0c0115,0xb78401af}},	// [190d0] hrfa, кеңн, ĉasi, _йәре_, 
   {{0x4429109d,0xe5c4022e,0x00000000,0x00000000}},	//   sba_, _асмо, --, --, 
   {{0x4429109e,0x7c29109f,0xd5b910a0,0x995401ef}},	//   pba_, yber, _ася_, _báře_, 
   {{0x67383ad4,0x7fd50575,0x237c0010,0x7c28007c}},	//   šuju, лілі, _šuju_, xber, 
   {{0x6d4910a1,0xd1300075,0x3ced10a2,0x7c280162}},	//   erfa, ممە_, vlev_, vber, 
   {{0x7c2910a3,0xca3801e4,0xb0600641,0x00000000}},	//   wber, jaĝ_, äärm, --, 
   {{0x925910a4,0xe8002e1e,0x3ced10a5,0x6d4c0fac}},	//   _шарт_, रेता_, tlev_, _åbal, 
   {{0xef940131,0x00000000,0x00000000,0x00000000}},	//   ткәш_, --, --, --, 
   {{0x2d9803a1,0x3cec037e,0x9e900451,0x6d4910a6}},	//   øper_, rlev_, _پهاڪ, arfa, 
   {{0xa4980268,0x3ced10a7,0x995401ef,0x00000000}},	//   _giòv, slev_, _záře_, --, 
   {{0xd8e80327,0x20c40042,0x00000000,0x00000000}},	//   _ལེདྲ, nŵio_, --, --, 
   {{0xcc8801b9,0x4f0800cf,0x58043452,0x7c28579a}},	//   _لنمه_, _كتەپ_, ионғ, qber, 
   {{0xf77110a8,0xeb8c07dd,0xbb4510a9,0x00000000}},	//   حاج_, _уи_, _селк, --, 
   {{0xfc3801e4,0x3b080798,0x00000000,0x00000000}},	//   laŭ_, _џеко_, --, --, 
   {{0xd7340124,0x00000000,0x00000000,0x00000000}},	//   ыхҟь, --, --, --, 
   {{0xfc3800c8,0xb4ac0d2c,0xb794009b,0x00000000}},	//   naŭ_, कसे_, _броћ, --, 
   {{0xb38510aa,0x25bc0115,0x6d440055,0x00000000}},	// [190e0] ылал, ĝula_, _ākam, --, 
   {{0xa6d80008,0x2ed000dc,0x6d480142,0x9c1000b8}},	//   yrði, _तदेत, yrfa, _śālī, 
   {{0xfc381a4c,0x35a510ab,0x6738151c,0x9954013a}},	//   kaŭ_, _санг, šujt, _páře_, 
   {{0xfc3801e4,0xca380115,0x00000000,0x00000000}},	//   jaŭ_, zaĝ_, --, --, 
   {{0x6d480009,0xa854011a,0x7ce400c7,0x7cc000ef}},	//   wrfa, רינה_, vórp, bērz, 
   {{0xdee07724,0x2ea401ed,0x205000c7,0x5f900120}},	//   бочи, دھری_, атәр, сишт, 
   {{0xccf80316,0x02c400f7,0xca3801e4,0x6d4803ac}},	//   _opět_, _тирү, vaĝ_, urfa, 
   {{0xd17401e0,0x6d500023,0x00000000,0x00000000}},	//   _йығы, _ዘይፈር, --, --, 
   {{0xa0300c75,0x7bcc032e,0xeb0430ab,0x00000000}},	//   _دىقت, _þaul, лчоо, --, 
   {{0xadb80375,0x0dc00201,0x5bb510ac,0x7fd401ec}},	//   _كهذا_, _ድጋፍ_, улья_, _тісі, 
   {{0xd914c7d5,0xfc3800c8,0x6da400c6,0xca3801e4}},	//   лья_, baŭ_, _حمام, raĝ_, 
   {{0x3af800e4,0x07a40124,0x00000000,0x00000000}},	//   vèpe_, ҳаҭн, --, --, 
   {{0xdc38008f,0x7c3c0d12,0xa6d8032e,0x00000000}},	//   _טעאר, ðsre, fuðp, --, 
   {{0xfd100150,0x9b400244,0x63b8010e,0x3af80022}},	//   _اجە_, _انوو, _ýuni, tèpe_, 
   {{0x648801c6,0x00000000,0x00000000,0x00000000}},	//   нсаг_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x439430ab,0x00000000,0x00000000,0x00000000}},	// [190f0] шаас, --, --, --, 
   {{0xccf80316,0xfc3800c8,0x57fc0375,0x9258586a}},	//   _zpět_, zaŭ_, _אלחו, лаут_, 
   {{0xa498004e,0x926910ad,0x201c2305,0x80c400c7}},	//   _biòt, ырта_, _pfui_, аӡаз, 
   {{0xc3c41206,0x0cb8009e,0x00000000,0x00000000}},	//   _көзл, ুকুত, --, --, 
   {{0x50641171,0xf438011a,0x00000000,0x00000000}},	//   стха, _בגרמ, --, --, 
   {{0x171c00c8,0x3a2801fa,0x6aac02ab,0xc69400df}},	//   עווע, _đapo_, टसोर, שאַ_, 
   {{0xfc3804ac,0x51840c17,0xf2d00375,0xd6580375}},	//   taŭ_, _лута, _ועם_, איות_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfc381a4c,0x60c84cd3,0x92d803d4,0x00000000}},	//   raŭ_, migm, াতৰ_, --, 
   {{0x60c910ae,0x88bc0316,0xa49801c3,0x4fc40209}},	//   ligm, spěl, _fhòg, _усса, 
   {{0xe80110af,0xa6d80174,0x00000000,0x00000000}},	//   रेसा_, vuðp, --, --, 
   {{0x60c89aed,0x3154008f,0x00000000,0x00000000}},	//   nigm, סירן_, --, --, 
   {{0xdb20006c,0xa49800a3,0xb8dcde66,0x6f0c0205}},	//   _اوتی, _mhòd, _इत_, _üncü, 
   {{0x64480579,0xd9400022,0x60c80009,0x0cb800cc}},	//   ógin, _лҵои, higm, ুকৃত, 
   {{0x3cfc0457,0xcec80051,0x00000000,0x00000000}},	//   _khwv_, một_, --, --, 
   {{0xb4240fb4,0x00000000,0x00000000,0x00000000}},	//   شعرو, --, --, --, 
   {{0xdef0044e,0x6380e17f,0xa50510b0,0xd2440ae5}},	// [19100] ሎምን_, огта, рета_, ймақ, 
   {{0xc51400d1,0xf10c04af,0x00000000,0x00000000}},	//   شبېت, िद्द_, --, --, 
   {{0xa49800a3,0x78b45794,0x00000000,0x00000000}},	//   _bhòd, _klyv, --, --, 
   {{0xef84048a,0x00000000,0x00000000,0x00000000}},	//   илеп, --, --, --, 
   {{0x6fd40597,0x7ccc00da,0xa49801ab,0xc0c00023}},	//   جزائ, _mērķ, _shòg, _ድኻም_, 
   {{0xa49800a3,0x717400ec,0x00000000,0x00000000}},	//   _phòg, _پهرا, --, --, 
   {{0x614110b1,0x78b4035a,0xa2b800dc,0x71a40107}},	//   _мера, _olyv, _एतत्, _тавз, 
   {{0x3cfc01d4,0x6adc1221,0x00000000,0x00000000}},	//   _chwv_, नक्र, --, --, 
   {{0x442403be,0xefe81d0a,0x5b10005b,0x92d80011}},	//   _əl_, _شعرو_, омыт, াতী_, 
   {{0x78b40006,0x00000000,0x00000000,0x00000000}},	//   _alyv, --, --, --, 
   {{0xd6cc02f5,0x78b4007c,0x00000000,0x00000000}},	//   লকায, _blyv, --, --, 
   {{0x78b40076,0x26ec0254,0x6d4400b0,0x1af42be5}},	//   _clyv, छत्र_, _ākah, лдөө_, 
   {{0x3d1027c4,0x27480801,0x6b7430fe,0xdc980a7c}},	//   _išwa_, ъчно_, _خطاط, _שידל, 
   {{0x78b400ca,0xd6d910b2,0xa49801ab,0x6b840451}},	//   _elyv, атс_, _niòr, _مشڪل, 
   {{0x78b426ff,0xd6d81142,0x29300131,0x25bc010f}},	//   _flyv, ртя_, ﺭﯗﭖ_, ĝulo_, 
   {{0x78b406ea,0x84145b7f,0x19b40115,0x58d4011c}},	//   _glyv, смах, _כפור_, _мощт, 
   {{0xa2b800dc,0x00000000,0x00000000,0x00000000}},	// [19110] _एतद्, --, --, --, 
   {{0xa49800a3,0x6ab80334,0x5694030d,0x00000000}},	//   _shòd, nhtf, _даьт, --, 
   {{0x7afc27bb,0xd734004e,0x00000000,0x00000000}},	//   ïsti, _лдөө, --, --, 
   {{0xcee84e5d,0x442c0432,0x00000000,0x00000000}},	//   یرون_, _ýe_, --, --, 
   {{0x60c910b3,0xb4f80302,0x13a803e6,0x00000000}},	//   rigm, _תפרי, _پۆلی_, --, 
   {{0x443910b4,0x8ee80212,0x22840139,0x3af800e4}},	//   _hes_, амів_, _тумг, kèpa_, 
   {{0x443910b5,0x3cfc0218,0xa49801ab,0x6ab80175}},	//   _kes_, _phwv_, _thòd, dhtf, 
   {{0x443910b6,0x3cfc0211,0x88bc0118,0xdf740066}},	//   _jes_, _qhwv_, spěj, _پدرب, 
   {{0x60d80451,0x69cc01f1,0xef64009d,0x00000000}},	//   _ijum, úben, _гэхү, --, 
   {{0x443910b7,0xdef85d02,0x60d800f3,0x6ab910b8}},	//   _les_, _рыб_, _hjum, ghtf, 
   {{0x44380cfd,0x3cfc0218,0x78b40254,0xb90801d5}},	//   _oes_, _thwv_, _plyv, лноз_, 
   {{0x443910b9,0x3ea46040,0x60d81418,0x329c0150}},	//   _nes_, _holt_, _jjum, _ﺍﻷﻤﺱ_, 
   {{0x60d80451,0x3ea510ba,0xe800d589,0x7c380432}},	//   _mjum, _kolt_, रेला_, _iewr, 
   {{0x443910bb,0x6ab910bc,0x3ea4594a,0x60d80267}},	//   _aes_, chtf, _jolt_, _ljum, 
   {{0x3ea40e26,0x9b4001ed,0x60d80248,0x00000000}},	//   _molt_, _انڈو, _ojum, --, 
   {{0x443910bd,0x60d910be,0x43540092,0x00000000}},	//   _ces_, _njum, _ዝርዝሩ, --, 
   {{0x443910bf,0xf26910c0,0x64a01d5a,0x09cc0154}},	// [19120] _des_, лиал_, чата, _রুপা, 
   {{0x443910c1,0x60d910c2,0xa68000c7,0x7c3801ab}},	//   _ees_, _ajum, _ельд, _lewr, 
   {{0x443910c3,0xa49801ab,0x6a38008f,0x00000000}},	//   _fes_, _dhòb, רגעפ, --, 
   {{0x443910c4,0x92d82f8b,0xa148066d,0x7c3910c5}},	//   _ges_, াতে_, اسلے_, _newr, 
   {{0x61f8010f,0x3ea42517,0x8ec80b01,0x00000000}},	//   _ŝult, _bolt_, аҳаб_, --, 
   {{0xb8f808ea,0x443910c6,0xdee110c7,0x60d88934}},	//   _འམ_, _zes_, почи, _ejum, 
   {{0x3ea510c8,0xbebc0b23,0x443910c9,0x7c38062c}},	//   _dolt_, _itūl, _yes_, _bewr, 
   {{0x0cb86569,0x44380070,0x60d802d3,0x7c38015d}},	//   ুক্ত, _xes_, _gjum, _cewr, 
   {{0xdfcc0491,0x3ea510ca,0x7c38015d,0x60c0017a}},	//   _كيف_, _folt_, _dewr, ënme, 
   {{0x7c380327,0x3af80ba1,0x7f4c0784,0xa9285e82}},	//   _eewr, tèpa_, šaqc, ліме_, 
   {{0xa2b80882,0x60d80022,0x7c3910cb,0xac8401af}},	//   _एतस्, _yjum, _fewr, _гѳлл, 
   {{0x3d101ebd,0xdca110cc,0x7c3910cd,0x6e3801f5}},	//   _tšwa_, _нахи, _gewr, _hetb, 
   {{0x443910ce,0x00000000,0x00000000,0x00000000}},	//   _res_, --, --, --, 
   {{0x443910cf,0x00000000,0x00000000,0x00000000}},	//   _ses_, --, --, --, 
   {{0x6e38f722,0x2ca510d0,0xa49800db,0x7c3910d1}},	//   _metb, _kood_, _biòp, _yewr, 
   {{0x92d802a6,0xbebc0607,0x6e38cc23,0x4438e947}},	//   াতো_, _atūl, _letb, _qes_, 
   {{0x443910d2,0x60d80204,0xa49801ab,0x2ca48a83}},	// [19130] _ves_, _rjum, _phòb, _mood_, 
   {{0x443910d3,0x2ca510d4,0xa49801ab,0x60d8020c}},	//   _wes_, _lood_, _bhòc, _sjum, 
   {{0x443910d5,0xb5f00046,0x97d89c4c,0xa498f2b6}},	//   _tes_, _жүрі, _نظیر_, _chòc, 
   {{0x4438068c,0x439406bb,0x2ca510d6,0xa49800a3}},	//   _ues_, _дамс, _nood_, _dhòc, 
   {{0x7c3910d7,0x3ea510d8,0x6e38010b,0xbea415bd}},	//   _rewr, _polt_, _betb, жалк, 
   {{0x3da800e6,0xdeec13bd,0x00000000,0x00000000}},	//   икло_, رۋا_, --, --, 
   {{0x3ea510d9,0x2ca510da,0x60d910db,0xfc30007b}},	//   _volt_, _bood_, _tjum, وحة_, 
   {{0x60d910dc,0xbebc0618,0x6e380f49,0x7ce404d4}},	//   _ujum, _itūm, _eetb, lórz, 
   {{0x2ca510dd,0x6e3910de,0x3ea443e9,0xbed40a5b}},	//   _dood_, _fetb, _tolt_, _доај, 
   {{0x6e380175,0x3944b1e0,0x3ea4003a,0x4fc4030d}},	//   _getb, оног, _uolt_, _эсса, 
   {{0x7d781365,0x2ca40302,0x0dc80114,0x2d9801e3}},	//   _خمار_, _food_, _луци_, äpet_, 
   {{0x2ca4025f,0x3f8ccb49,0x691c00b0,0x80b800eb}},	//   _good_, _kreu_, _tīen, েকক্, 
   {{0xddcc01ef,0x00000000,0x00000000,0x00000000}},	//   _čeře, --, --, --, 
   {{0x590c49a6,0x5044001f,0x87b8005b,0xaae40133}},	//   _གཤམས_, _የኮሚሽ, суют_, _وتوۆ, 
   {{0x2ca40076,0x00000000,0x00000000,0x00000000}},	//   _yood_, --, --, --, 
   {{0xe7f00490,0x3f8c0042,0xbebc00ef,0x00000000}},	//   _घरचा_, _oreu_, _stūl, --, 
   {{0x7ce40005,0x4990036b,0x98a80139,0x00000000}},	// [19140] fórz, _قییر, _uqnı_, --, 
   {{0xa49800a3,0x7ce4033f,0x00000000,0x00000000}},	//   _phòc, górz, --, --, 
   {{0x6e3800df,0xd9ec1b57,0x911400db,0x00000000}},	//   _retb, _घुमत_, سساچ, --, 
   {{0x3f8c0137,0x02d400d1,0xfe74009d,0x00000000}},	//   _breu_, يتەخ, үүт_, --, 
   {{0x3f8d10df,0x2ca510e0,0x6ee4004b,0x386400e8}},	//   _creu_, _rood_, يستل, _ñoru_, 
   {{0x3f8c19a2,0xde90026a,0xa49800a3,0x2ca40254}},	//   _dreu_, дашњ, _thòc, _sood_, 
   {{0x2ca400af,0x3dac0154,0x3c9001b9,0x00000000}},	//   _pood_, _কেবল, کینز, --, 
   {{0xafe40b7b,0x6e3869d0,0x3f8c1a80,0x00000000}},	//   _добл, _wetb, _freu_, --, 
   {{0x3f8d10e1,0xae78169c,0xac900046,0x6e3910e2}},	//   _greu_, _всех_, зақш, _tetb, 
   {{0x2ca4d406,0x2d942377,0xf1dc000d,0x69f000cf}},	//   _wood_, _мрес, _मशान, мүлт, 
   {{0x2ca45a7a,0xa85000fb,0x21bc0116,0x00000000}},	//   _tood_, менә, ﻣﻜﺎﺭ, --, 
   {{0x291c022e,0xd8388e21,0x0eb801af,0x00000000}},	//   rqta_, жэр_, _туғы_, --, 
   {{0x291c0054,0x6bd43adf,0xe8800023,0xae1c0037}},	//   sqta_, _بتار, _ይዛረቡ_, _पलान_, 
   {{0x3ce8009b,0xf8c402d2,0x00000000,0x00000000}},	//   čave_, _þéna_, --, --, 
   {{0x62800798,0x00000000,0x00000000,0x00000000}},	//   ônom, --, --, --, 
   {{0xd49910e3,0x19b80302,0xd91000f1,0x00000000}},	//   ору_, _כמוב, _ټیټ_, --, 
   {{0xbebc4a38,0x00000000,0x00000000,0x00000000}},	// [19150] _stūm, --, --, --, 
   {{0x6ed4000d,0x672c012d,0x3f90013a,0x00000000}},	//   _बदगु, mpcj, _čzu_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x65642784,0x3f8c0228,0xd1c8009d,0xd1380108}},	//   mtjh, _preu_, цууд_, юху_, 
   {{0xcf2401e2,0x69cc00d7,0x00000000,0x00000000}},	//   وروي, úbej, --, --, 
   {{0x3f8c054e,0xdb200241,0xa1540150,0x00000000}},	//   _vreu_, _òrét, _қағу_, --, 
   {{0x656510e4,0xbd44007b,0x22440419,0x7c3c0162}},	//   ntjh, أنبي, ónku_, ðsro, 
   {{0x3f8d10e5,0xdb203bd6,0x00000000,0x00000000}},	//   _treu_, ووبی, --, --, 
   {{0x38a0068f,0x2008026c,0x3af402d5,0x00000000}},	//   _góry_, _àci_, зянс, --, 
   {{0x3a9869a4,0xed1400e5,0x00000000,0x00000000}},	//   стию_, _کہيں_, --, --, 
   {{0x7ebc06af,0xddc00419,0xbc180816,0x00000000}},	//   _cèpe, lenž, _лілі_, --, 
   {{0xcb6800aa,0xf1b0008f,0x8d7402ef,0x37e401d5}},	//   _ژمنه_, גסט_, _تاكا, зомг, 
   {{0x7d0910e6,0xa82005af,0x00000000,0x00000000}},	//   mmes, رکين, --, --, 
   {{0x7d0910e7,0x0ae878e3,0x80b80f22,0x00000000}},	//   lmes, _وروي_, েকট্, --, 
   {{0x6600189d,0x2a3804ae,0x7d0910e8,0x248800d1}},	//   епра, _העצמ, omes, ﻗﻠﯩﯟ, 
   {{0x7d0910e9,0x37e400db,0x00000000,0x00000000}},	//   nmes, _нойг, --, --, 
   {{0x4ab405f5,0x998400bc,0x7d0910ea,0x93640124}},	// [19160] _хөөр, _jenž_, imes, ьнаҵ, 
   {{0x7d0910eb,0xa8009033,0xd6c442c2,0xddc00171}},	//   hmes, _языл, _آمدی, denž, 
   {{0xbebc0270,0x7d0910ec,0xd78800ec,0x00000000}},	//   _etūk, kmes, _انڌو_, --, 
   {{0x7d0910ed,0xe8000316,0x38a00306,0x88bc0118}},	//   jmes, रेका_, _póry_, spěv, 
   {{0x7d0910ee,0x60c0017a,0x72d000db,0x888c010f}},	//   dmes, ënma, _كەرچ, יראַ, 
   {{0xdfcca5d1,0x69cc0af2,0x3f7c00d0,0x2324a4e9}},	//   ديه_, úbek, _dňu_, _хори_, 
   {{0xa49800a3,0x3cec01a9,0xdd94346d,0x6d440055}},	//   _mhòn, foev_, зшы_, _ākas, 
   {{0x672c033f,0xe0d400d8,0x38a00118,0x00000000}},	//   ypcj, _евс_, _tóry_, --, 
   {{0x7ebc007f,0xacb000db,0xaec4011c,0x00000000}},	//   _sèpe, _ۋەتب, _ебал, --, 
   {{0x7ebc007f,0x9f800166,0xe6b807f7,0x00000000}},	//   _pèpe, _ягуд, _उतेज, --, 
   {{0x2eed10ef,0x7d0910f0,0x691c02b5,0x3cec01d5}},	//   moff_, bmes, _tīem, boev_, 
   {{0x2eecf0d3,0x7d0910f1,0xc7d400a7,0x9d5000e3}},	//   loff_, cmes, джмъ, _سنهت, 
   {{0xdb4c05d4,0xe64802d3,0xfbcc00ec,0x88bc01ef}},	//   _مَن_, _ንምግላ, _پڪي_, dpět, 
   {{0x6b8110f2,0xe800033f,0xa4980051,0x00000000}},	//   _isog, रेगा_, _chòn, --, 
   {{0x656401af,0x6aa80334,0xa49801ab,0x45d40798}},	//   utjh, _ioff, _dhòn, фовс, 
   {{0x6aa910f3,0x00000000,0x00000000,0x00000000}},	//   _hoff, --, --, --, 
   {{0x6aa910f4,0xe80002ab,0x68ec0998,0x656401af}},	// [19170] _koff, रेखा_, mocd, stjh, 
   {{0x6aa910f5,0x6b8088fe,0x7d0910f6,0x3cec01e4}},	//   _joff, _msog, zmes, zoev_, 
   {{0x6aa910f7,0x7d0910f8,0x05e00073,0x3cec01a9}},	//   _moff, ymes, _नशिब, yoev_, 
   {{0x7d0800d8,0x6b8110f9,0xd13000d1,0x00000000}},	//   xmes, _osog, چمە_, --, 
   {{0x645c1cdf,0x6b8005db,0x6aa910fa,0x4e9404fb}},	//   mgqi, _nsog, _ooff, کشنر, 
   {{0x6d440b3a,0x2eec0f64,0x6aa80003,0x7f580113}},	//   _ākar, goff_, _noff, ruwq, 
   {{0x6b80013f,0x7d0910fb,0xfce4a9e8,0x645c0472}},	//   _asog, tmes, моко, ogqi, 
   {{0x645d10fc,0x6284defb,0xed54013e,0x7d0910fd}},	//   ngqi, _hajo, фоъ_, umes, 
   {{0x7d0910fe,0x628510ff,0x6aa91100,0x2eec030d}},	//   rmes, _kajo, _boff, boff_, 
   {{0x62840124,0x88bc038e,0x6aa8e1b2,0x2eec00e4}},	//   _jajo, zpět, _coff, coff_, 
   {{0x6b811101,0x645c009a,0x69c401e4,0x8b6401e2}},	//   _esog, kgqi, ŝken, وایم, 
   {{0x62851102,0x2b504a4a,0x6aa803ac,0xf7451103}},	//   _lajo, üncü_, _eoff, мемо, 
   {{0xa49801dc,0xbebc0421,0x6aa91104,0x6d4c003b}},	//   _phòn, _atūi, _foff, _åbar, 
   {{0x62851105,0x6aa91106,0x00000000,0x00000000}},	//   _najo, _goff, --, --, 
   {{0x68ec0009,0xe9cc00ec,0x31b000eb,0x00000000}},	//   bocd, _پٺي_, _টেনশ, --, 
   {{0x1cd80003,0x62841bce,0x6b8800d2,0xe0cc009e}},	//   _རམས_, _aajo, _úmgâ, িকুন, 
   {{0xd5b800da,0x6aa80175,0x7ce8010b,0x2eed1107}},	// [19180] šā_, _yoff, _görş, yoff_, 
   {{0x62851108,0x63a85df7,0x6aa90996,0x00000000}},	//   _cajo, ägna, _xoff, --, 
   {{0x62851109,0x7f48013c,0x2eec0175,0x7608945a}},	//   _dajo, _aveq, voff_, _фенг_, 
   {{0x6aa808ec,0x30bc045e,0x62840083,0x258400bc}},	//   _चक्र, েক্স, _eajo, sílá_, 
   {{0x2eed110a,0x4375110b,0xa49800a3,0x6285110c}},	//   toff_, _пурт, _mhòl, _fajo, 
   {{0xad24236e,0x5f91110d,0x00000000,0x00000000}},	//   وربو, тишт, --, --, 
   {{0x6b801418,0x317c067c,0x99840024,0x29080810}},	//   _ssog, _ètz_, _menų_, ymca_, 
   {{0x6aa9110e,0x2eed110f,0xeb4800d4,0x6284072d}},	//   _soff, soff_, очок_, _zajo, 
   {{0x62851110,0x691c02b5,0xceb80166,0xa0640166}},	//   _yajo, _tīek, _нәк_, _юата_, 
   {{0x3ce80bb8,0x63a8ebd4,0x6aa91111,0x62843d20}},	//   čava_, øgni, _qoff, _xajo, 
   {{0xdd8c0451,0x2fc401f5,0x88bc0118,0x6aa8032e}},	//   _پون_, lzog_, dpěr, _voff, 
   {{0x6b811112,0xeb991113,0x7fb400db,0x00000000}},	//   _tsog, _мие_, _تۇۇر_, --, 
   {{0x6aa91114,0x6b800b23,0x9c6002e9,0x2fc4002f}},	//   _toff, _usog, _شهوو, nzog_, 
   {{0x68ec0014,0x6aa80ac8,0x00000000,0x00000000}},	//   socd, _uoff, --, --, 
   {{0x62851115,0xa49800a3,0xda58011a,0x99840064}},	//   _rajo, _fhòl, _וכול, _denų_, 
   {{0x62851116,0x00000000,0x00000000,0x00000000}},	//   _sajo, --, --, --, 
   {{0x62851117,0x8318313e,0xe2a800ec,0xe51c0037}},	// [19190] _pajo, سقار_, يائن_, _मूरि_, 
   {{0x62840194,0xd6d400c7,0x99840153,0x61e8002f}},	//   _qajo, _ажьы, _genų_, ßglo, 
   {{0x62851118,0x3eb8005f,0x518400ea,0x00000000}},	//   _vajo, _ēst_, куца, --, 
   {{0x62851119,0xc434208f,0xddc00327,0xc104e7e1}},	//   _wajo, _سکرت, renż, روشي, 
   {{0x644c1730,0x6285111a,0xddc00327,0xfff800e5}},	//   _idci, _tajo, senż, سکرت_, 
   {{0x4429111b,0x691c00b0,0x00000000,0x00000000}},	//   lca_, _tīeh, --, --, 
   {{0x4429111c,0xefdc2440,0x4ea40395,0xd164014b}},	//   oca_, _ሕያው_, ърца, _иъти, 
   {{0x3b84010b,0x9104013d,0x00000000,0x00000000}},	//   елиг, _ачуд, --, --, 
   {{0xfe7403b7,0x4fc41086,0x26c00472,0xca180116}},	//   _плаќ, _исфа, khjo_, _ﻳﺎﺭ_, 
   {{0xa49800a3,0xe8900124,0x00000000,0x00000000}},	//   _shòl, ҳаџь, --, --, 
   {{0x4429111d,0x644c4966,0x27e4013f,0xa49801c3}},	//   kca_, _odci, _ɛnne_, _phòl, 
   {{0x644c009a,0x99840024,0x00000000,0x00000000}},	//   _ndci, _senų_, --, --, 
   {{0x4429111e,0x7c29111f,0xa4980e89,0xe94403e6}},	//   dca_, mcer, _chòm, ورێی, 
   {{0x44291120,0xa4980e89,0x644d1121,0x06740395}},	//   eca_, _dhòm, _adci, куся, 
   {{0x44291122,0x7c280083,0xc5d40212,0x99840153}},	//   fca_, ocer, віть, _venų_, 
   {{0x44291123,0xb4e801bc,0x00000000,0x00000000}},	//   gca_, यवे_, --, --, 
   {{0xdef002d3,0x7c280381,0x7d18015d,0x73040354}},	// [191a0] ዎምን_, icer, _miws, епаз, 
   {{0x44291124,0x644c02d0,0x26c000df,0xdbf00166}},	//   aca_, _edci, chjo_, _işär, 
   {{0x442801f1,0x3af80100,0x916c0051,0xf7700101}},	//   bca_, gèpi_, _bốc_, _شاک_, 
   {{0x44291125,0x70f40597,0x415812c4,0x7d191126}},	//   cca_, رسائ, ьшую_, _niws, 
   {{0xe45c0793,0x741413ea,0x7ebc02e2,0x2324013e}},	//   _blöf_, _سوسا, _sèpa, _пояи_, 
   {{0x2fc51127,0x7c2816b8,0x7ebc007f,0xb640037e}},	//   rzog_, ecer, _pèpa, _ｍｔ_, 
   {{0x59280156,0x7c287021,0xa2e041b9,0xc4c40133}},	//   ྩམསས_, fcer, _сорд, _ستێو, 
   {{0x7c280137,0x916c0208,0x2d8c0165,0x2ba4041b}},	//   gcer, _gốc_, rvfe_, ејов, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x44291128,0x7c285bd9,0xada40138,0x6da400d8}},	//   zca_, acer, _пазл, _пиза, 
   {{0x44291129,0x7d180042,0x2d95112a,0x00000000}},	//   yca_, _fiws, _ярас, --, 
   {{0x7c29112b,0x6d480c8c,0x44283fb4,0x6f180e21}},	//   ccer, msfa, xca_, _hitc, 
   {{0x6d483dd3,0x6f180c30,0x00000000,0x00000000}},	//   lsfa, _kitc, --, --, 
   {{0x4428068f,0x6d4802d0,0x6f1801ef,0xdb98011a}},	//   wca_, osfa, _jitc, _מסדר, 
   {{0x6d49112c,0x4429112d,0x79800368,0xbf1c012c}},	//   nsfa, tca_, cwlw, _पढ्न_, 
   {{0x6f19112e,0x4429112f,0xa49800a3,0x00000000}},	//   _litc, uca_, _thòm, --, 
   {{0x3cf00037,0x6d4802d0,0x7c3c0413,0x00000000}},	// [191b0] ँकते_, hsfa, ðsri, --, 
   {{0x6d491130,0x6f18037e,0x916c0051,0x00000000}},	//   ksfa, _nitc, _sốc_, --, 
   {{0x44291131,0x6d48007c,0x00000000,0x00000000}},	//   pca_, jsfa, --, --, 
   {{0xe2700372,0x6d491132,0x6f180072,0x442800ac}},	//   _өкмө, dsfa, _aitc, qca_, 
   {{0x1e700046,0x2d9878d0,0x6f191133,0x8ca4033f}},	//   лғас, åpen_, _bitc, कानो, 
   {{0x7d180054,0x63a80579,0x29191134,0x6d483ce6}},	//   _siws, øgnu, _liqa_, fsfa, 
   {{0x6d484cab,0x7c291135,0x60e40022,0x916c0208}},	//   gsfa, tcer, _зцаз, _tốc_, 
   {{0x3ce80f03,0x00000000,0x00000000,0x00000000}},	//   čavo_, --, --, --, 
   {{0x6f191136,0x248805b1,0xa49800db,0x201c00e4}},	//   _fitc, _macm_, _diòx, _igui_, 
   {{0x7c291137,0x8a380c9e,0xe45c0267,0x6d487e42}},	//   scer, няют_, _flög_, bsfa, 
   {{0x98680aaf,0x6d48ce33,0x00000000,0x00000000}},	//   ىلدە_, csfa, --, --, 
   {{0x26d001b9,0x22411138,0x6f1801f5,0xdd8c5cfc}},	//   _amxo_, _lejk_, _zitc, _پوچ_, 
   {{0xb9091139,0x2918025c,0x6f18047e,0xf770bfae}},	//   _मद_, _diqa_, _yitc, جاج_, 
   {{0x22400327,0xfaa410fc,0x6ab8002f,0x00000000}},	//   _nejk_, _јако, cktf, --, 
   {{0xe641113a,0x7bc82caa,0x256400f3,0x69d000ec}},	//   респ, lzeu, карп_, _پٺيء, 
   {{0x201c1bce,0xa5041422,0x8ca41be1,0x00000000}},	//   _ngui_, веса_, कायो, --, 
   {{0x7bc9113b,0x37e400c7,0x80bc07f7,0xbb380150}},	// [191c0] nzeu, _шоиг, ्फैं, _ﺒﺩﻯ_, 
   {{0x201c00c7,0xa56004fb,0x7bc8030a,0x554c0092}},	//   _agui_, دگین, izeu, _ንግግሮ, 
   {{0xe45d113c,0xf50801c0,0x7bc8002f,0x00000000}},	//   _blöd_, _онол_, hzeu, --, 
   {{0x10f80583,0x2918011f,0xc5f401af,0xdfcc01e2}},	//   رباں_, _xiqa_, _сғс_, ښين_, 
   {{0xc0a81375,0x6f19113d,0x22408af2,0x2050109a}},	//   عامل_, _pitc, _fejk_, ркія, 
   {{0x6d49113e,0x201c00c7,0x00000000,0x00000000}},	//   tsfa, _egui_, --, --, 
   {{0x6f19113f,0x40940eff,0x6d491140,0x21a11141}},	//   _vitc, _өртт, usfa, _кирм, 
   {{0x6d480c8c,0x6f182517,0xe45c01e3,0xffa40ce8}},	//   rsfa, _witc, _glöd_, тләү, 
   {{0x6d483fc1,0x6f180522,0x7bc803fa,0x291806be}},	//   ssfa, _titc, gzeu, _riqa_, 
   {{0xbe851142,0xdd8c01d9,0x2c54013f,0x6d482110}},	//   _مجمو, _ژول_, _mɛdɔ_, psfa, 
   {{0x29180309,0x6ab80e78,0x201c0022,0x9b9001d5}},	//   _piqa_, rktf, _ygui_, هشیش, 
   {{0x29180113,0xd9183efd,0x818401ec,0x00000000}},	//   _qiqa_, кья_, _ﺭﺅﻴﺔ_, --, 
   {{0xd7f8407e,0xcb5400ae,0x00000000,0x00000000}},	//   вур_, _إنتظ, --, --, 
   {{0x99d05a9d,0x20dc010e,0x41b4033f,0x00000000}},	//   اتیا, _içiň_, ंहमस, --, 
   {{0x29180a73,0x569416a4,0x00000000,0x00000000}},	//   _tiqa_, јаст, --, --, 
   {{0xd1d4001f,0x545402bf,0x290c0e89,0x98a4009b}},	//   ሪነት_, ивст, _òga_, _виће, 
   {{0xc2991143,0x73c01cd1,0x42751144,0xae200d2c}},	// [191d0] нках_, бәре, лгас, मशान_, 
   {{0xa4980192,0x92580798,0x00000000,0x00000000}},	//   _mhòi, каут_, --, --, 
   {{0x7bc80267,0x926800a7,0x3f1402dd,0x00000000}},	//   zzeu, ърта_, ңдес, --, 
   {{0xc3c400fd,0x63a80158,0x00000000,0x00000000}},	//   _йөзл, øgns, --, --, 
   {{0x224001e4,0x93884990,0x260c0073,0x00000000}},	//   _tejk_, _исра_, णेरी_, --, 
   {{0x0e640212,0xc694008f,0xdcec0427,0x42a400fb}},	//   икін, ראַ_, čečn, _сумғ, 
   {{0x51851145,0x27e40134,0xa49801ab,0x20680166}},	//   _кута, _ɛnna_, _phòh, _ошап_, 
   {{0xa4980e89,0x7bc8ef32,0x0c940d33,0x00000000}},	//   _bhòi, tzeu, ашья, --, 
   {{0xec751146,0xa4980192,0x7bc89584,0x00000000}},	//   упы_, _chòi, uzeu, --, 
   {{0x7bc80730,0xa4980e89,0xcdd400d1,0x00000000}},	//   rzeu, _dhòi, _ھېيت_, --, 
   {{0x7bc85380,0xd010004b,0x9ba000cf,0xa9200e3b}},	//   szeu, _هلې_, _چەبى, йдэл, 
   {{0xa49801c3,0x25f400e1,0x9ba0075e,0x00000000}},	//   _fhòi, _एड़ी_, _نەبى, --, 
   {{0xa49801ab,0x87f83163,0x3914010b,0xcb6800f1}},	//   _ghòi, вэрт_, кмүр, _لمنه_, 
   {{0x87b8005b,0xb9c51147,0x1db4084d,0x00000000}},	//   туют_, _متعه, _अथात, --, 
   {{0x7ebc00cf,0xddc00374,0x93c801ed,0x394401b9}},	//   _rèpl, kanō, ھارہ_, _ёниг, 
   {{0x77841d11,0xe45c01e6,0xa92000a7,0x95840092}},	//   _близ, _smör_, _удъл, ምነቱን_, 
   {{0xd2440131,0x867801c6,0xd3a400d1,0xca1800d1}},	// [191e0] имақ, хөөр_, шлақ, _ﻳﺎﺵ_, 
   {{0xa83000e5,0x152801a9,0x00000000,0x00000000}},	//   _پٹیش, _иноқ_, --, --, 
   {{0x97040131,0x02180006,0x00000000,0x00000000}},	//   _مېڭى, віць_, --, --, 
   {{0x70551148,0x34f80212,0x925400e5,0x00000000}},	//   انشا, _їхню_, _چھاؤ, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x691c02b1,0xbebc005f,0xce9402e8,0x00000000}},	//   _mīer, _stūr, ракъ, --, 
   {{0xa4980e89,0x0d8400fb,0x00000000,0x00000000}},	//   _shòi, рһен, --, --, 
   {{0x4094c3bc,0xa49800a3,0x5cc11149,0xe1f5114a}},	//   _крут, _phòi, йсыз, _сгс_, 
   {{0xafe40131,0x00000000,0x00000000,0x00000000}},	//   _соал, --, --, --, 
   {{0x49744834,0x9e84168d,0x9504025c,0xdca00116}},	//   алос, _مامۆ, _ཙེའི_, _қачи, 
   {{0x8ee80131,0xed580107,0x00000000,0x00000000}},	//   _كېچە_, _чое_, --, --, 
   {{0xfcd80125,0xa4980192,0x61e0000f,0xab2801f0}},	//   ኖሎጂ_, _thòi, ûnli, _зода_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x442c14cf,0xa03c0023,0x00000000,0x00000000}},	//   _że_, _ኣዎንታ, --, --, 
   {{0x7e740205,0x95c80153,0x00000000,0x00000000}},	//   _özpe, гута_, --, --, 
   {{0x2a8c06be,0x00000000,0x00000000,0x00000000}},	//   lәb_, --, --, --, 
   {{0xa49800e4,0x5334329e,0xb7d801d3,0xd91c011a}},	// [191f0] _ohòv, йетт, _لوٹا_, _אוהל, 
   {{0x66640395,0x00000000,0x00000000,0x00000000}},	//   _съиз, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbf0c0d01,0x25c4467d,0xb18412e8,0x6018010b}},	//   िग्न_, ıqlı_, _småø, _nämü, 
   {{0x3fc80ee8,0x00000000,0x00000000,0x00000000}},	//   خدای_, --, --, --, 
   {{0x5064035b,0x00000000,0x00000000,0x00000000}},	//   атәа, --, --, --, 
   {{0x56b800c8,0x00000000,0x00000000,0x00000000}},	//   רפון_, --, --, --, 
   {{0xacb00131,0x00000000,0x00000000,0x00000000}},	//   قمىغ, --, --, --, 
   {{0x9e640228,0x2ca4969b,0xceac00fb,0x00000000}},	//   _ماان, ркып_, _еҙ_, --, 
   {{0x3b080640,0xeab400fb,0x3d04012d,0x00000000}},	//   ђено_, ийы_, _हीरे_, --, 
   {{0x4ea40b65,0xceb8068f,0xdd980440,0xccc40137}},	//   _урта, _więc_, _яша_, рбөй, 
   {{0x8304031c,0xc5b80327,0x00000000,0x00000000}},	//   _མེའུ_, _པཎྟི, --, --, 
   {{0xfb85114b,0xfaa5114c,0x691c00b0,0xbb444627}},	//   _خدای, _вало, _pīer, _телк, 
   {{0xe735114d,0x41b40037,0x0ca80124,0x00000000}},	//   рер_, ंहास, _атәи_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x23242b97,0x00000000,0x00000000,0x00000000}},	// [19200] иоти_, --, --, --, 
   {{0x3235114e,0xe2c44f0c,0x656c007c,0x00000000}},	//   рхас, алуд_, önhö, --, 
   {{0xf505114f,0x7afc002d,0x360408f0,0x00000000}},	//   _взно, ïsty, _خودف, --, 
   {{0xbebc00cd,0x00000000,0x00000000,0x00000000}},	//   _stūp, --, --, --, 
   {{0xa064426c,0xc5b8031c,0xfd5400b8,0xbb3801ec}},	//   рача_, _པཎྜི, _imaṃ, _ﺒﺩﻻ_, 
   {{0xdee003f5,0x00000000,0x00000000,0x00000000}},	//   оочи, --, --, --, 
   {{0x601801b8,0x00000000,0x00000000,0x00000000}},	//   _pämü, --, --, --, 
   {{0x3208c466,0x00000000,0x00000000,0x00000000}},	//   _izby_, --, --, --, 
   {{0xef18833f,0xdd9c0419,0x00000000,0x00000000}},	//   _ама_, ĺňal_, --, --, 
   {{0x63a85df4,0x00000000,0x00000000,0x00000000}},	//   ägni, --, --, --, 
   {{0xc5b80327,0x60180166,0x00000000,0x00000000}},	//   _པཎྚི, _tämü, --, --, 
   {{0x5fd801ad,0x26ec7875,0x9cb015eb,0x00000000}},	//   _मेडल, चक्र_, _وملت, --, 
   {{0x7b94168d,0xdcac3baf,0xbc240c75,0x8d94001f}},	//   _هاوڕ, _تىن_, _ارمى, _ቀርበው_, 
   {{0x07080b24,0x00000000,0x00000000,0x00000000}},	//   ايسي_, --, --, --, 
   {{0xd5b91150,0x66c800a2,0xe8900022,0x96e801c6}},	//   аст_, _lükg, _ҳақь, рьяа_, 
   {{0x98c401af,0x00000000,0x00000000,0x00000000}},	//   _мсыл, --, --, --, 
   {{0x46140214,0x94a8030d,0x00000000,0x00000000}},	// [19210] _گودر, штра_, --, --, 
   {{0xd7fc0375,0xb36c0023,0x00000000,0x00000000}},	//   _בהחל, _ኣዋዘን_, --, --, 
   {{0xa49808c2,0x212401fb,0x7e8406be,0xc1740395}},	//   _bhòt, ênh_, _örpə, слещ, 
   {{0xa4991151,0xd0580212,0x60601884,0x615c01f3}},	//   _chòt, арші_, تۇرل, _ዳግማዊ_, 
   {{0xa28024c5,0x00000000,0x00000000,0x00000000}},	//   _ویرو, --, --, --, 
   {{0xc2c41913,0xe7ec01ad,0x3f980a87,0x00000000}},	//   _ايسي, _चखना_, _ásum_, --, 
   {{0xee2c00b2,0xd6580302,0x00000000,0x00000000}},	//   رٽي_, ביות_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa4980086,0x8fd4723c,0x7ebc020c,0x00000000}},	//   _ekòg, _мәшә, _lèpi, --, 
   {{0x61300327,0x7bcc00e2,0x8d74105d,0x00000000}},	//   _eħle, _ļaud, _ژانا, --, 
   {{0x3c5801c0,0x224400d0,0x00000000,0x00000000}},	//   _биеэ_, ónky_, --, --, 
   {{0xa49800a3,0x3ff8008f,0x79a40124,0x00000000}},	//   _mhòs, ָפֿע, арҭе, --, 
   {{0xeaad1152,0x8ca4d857,0x00000000,0x00000000}},	//   _ей_, कारो, --, --, 
   {{0x3f8c02ce,0x06b80014,0x64480d12,0x00000000}},	//   _mseu_, لنُک_, ðgin, --, 
   {{0x691c00b0,0xe45c007c,0x00000000,0x00000000}},	//   _tīep, _slöa_, --, --, 
   {{0x70b41533,0x35a421f3,0x00000000,0x00000000}},	//   _अकेल, _ғамг, --, --, 
   {{0x3f8c0161,0xa50414b7,0x66c800a2,0x00000000}},	// [19220] _nseu_, сета_, _bükd, --, 
   {{0xa4980428,0x78b4022c,0x00000000,0x00000000}},	//   _akòd, _hoyv, --, --, 
   {{0x3f8c0421,0xef180daf,0x78b40205,0x464800cf}},	//   _aseu_, ңме_, _koyv, _өзөн_, 
   {{0x764d1153,0x78b400e4,0xede401e0,0x69f8010f}},	//   laby, _joyv, ҙһеҙ_, אלעק, 
   {{0x77640054,0xede40032,0xbef40073,0x00000000}},	//   nukx, әһеҙ_, ेतून_, --, 
   {{0x78b40579,0x764d1154,0x00000000,0x00000000}},	//   _loyv, naby, --, --, 
   {{0x2d980124,0x3f8d1155,0x00000000,0x00000000}},	//   ípe_, _eseu_, --, --, 
   {{0x764d1156,0xf07401d9,0x66c800a2,0x6598010f}},	//   haby, _دُرد, _tükg, ריקק, 
   {{0x764c0796,0x66c803e3,0x00000000,0x00000000}},	//   kaby, _yükd, --, --, 
   {{0x66c91157,0x764c0158,0x37cc0154,0x9f98002f}},	//   _küke, jaby, রপার, läßt_, 
   {{0x764c0223,0x78b51158,0xa4980e89,0x7dc401d9}},	//   daby, _boyv, _mhòr, _وزمٔ, 
   {{0x66c80365,0x70b510af,0x00000000,0x00000000}},	//   _müke, _अकोल, --, --, 
   {{0x7ebc004e,0x78b40174,0x00000000,0x00000000}},	//   _sèpi, _doyv, --, --, 
   {{0x764d1159,0x00000000,0x00000000,0x00000000}},	//   gaby, --, --, --, 
   {{0xd6d9115a,0x00000000,0x00000000,0x00000000}},	//   стя_, --, --, --, 
   {{0x764c04ba,0x88580150,0x04c81359,0x00000000}},	//   aaby, _тиис_, جوري_, --, 
   {{0x764d115b,0x82d9115c,0xa4980e89,0xa22400c6}},	// [19230] baby, адас_, _bhòr, مراه, 
   {{0xa49808c2,0x764c058a,0x66c803e0,0xb9100055}},	//   _chòr, caby, _büke, ddaṃ_, 
   {{0xa49801c3,0x46140066,0x00000000,0x00000000}},	//   _dhòr, _گوگر, --, --, 
   {{0x272c008e,0x2b44012d,0x7aec02d2,0xe0480066}},	//   _kün_, _owoc_, _íatv, اشاه_, 
   {{0x3d3402b5,0xa49800a3,0xd498084c,0x66c806be}},	//   _māwe_, _fhòr, _урэ_, _tükd, 
   {{0x24a800bd,0xa49808c2,0x26c0037e,0x0fe40137}},	//   _ঐতিহ, _ghòr, nkjo_, чөсү, 
   {{0xd658011a,0x00000000,0x00000000,0x00000000}},	//   זיות_, --, --, --, 
   {{0x764d115d,0x4ba800f7,0x3f8c0129,0x99842d40}},	//   zaby, өөчү_, _tseu_, ەمدە_, 
   {{0x2efc0270,0x764c48d8,0x3f8c004e,0x272c083c}},	//   _fktf_, yaby, _useu_, _nün_, 
   {{0x656400d2,0x78b40789,0x6d5c0419,0x39380092}},	//   kujh, _soyv, ápac, _የተወካ, 
   {{0x4ea407d6,0xdb2007d6,0x764c07a9,0x78b40124}},	//   _эрта, _کوتی, vaby, _poyv, 
   {{0x764cf339,0x272c0036,0x6564014f,0x00000000}},	//   waby, _bün_, dujh, --, 
   {{0x764d115e,0x65640007,0x60d81418,0xcc88004b}},	//   taby, eujh, _mmum, _دننه_, 
   {{0x272c509e,0xfaa400d1,0x3ce801a6,0x70b400cd}},	//   _dün_, _фако, čavu_, _अक्ल, 
   {{0x764d115f,0x60d91160,0x272c0165,0x00000000}},	//   raby, _omum, _eün_, --, 
   {{0x764d1161,0x272c0793,0x73340aaf,0x2c1400cd}},	//   saby, _fün_, قىرا, देवं_, 
   {{0x272c0c40,0x88c40efb,0xb060005b,0xa854011a}},	// [19240] _gün_, _ءتىل, äämm, _ויפה_, 
   {{0x60d91162,0x88047cbc,0x66c802b5,0x00000000}},	//   _amum, _عظيم, _püke, --, 
   {{0x8bf8009e,0x00000000,0x00000000,0x00000000}},	//   আইএন_, --, --, --, 
   {{0x272c62c7,0xfbc844af,0xe5b40cad,0x9da00210}},	//   _yün_, िनाम, _ìfáà, _कपड़ो, 
   {{0xdd8c04d3,0x888c00c8,0xef1801c0,0xa49800a3}},	//   ێوه_, טראַ, амд_, _thòr, 
   {{0x66c91163,0x60d80521,0x20508fb9,0xa80000e4}},	//   _tüke, _emum, птәр, _êñep, 
   {{0x66c806be,0x00000000,0x00000000,0x00000000}},	//   _yükb, --, --, --, 
   {{0xa064326d,0x71a400c2,0x27fc031c,0x00000000}},	//   _маса_, _лаҳз, żuni_, --, 
   {{0x2aa80faa,0x2ee4020f,0xe80c0037,0x00000000}},	//   атно_, _джаг, _सरधा_, --, 
   {{0x358802d3,0x9e60009b,0x00000000,0x00000000}},	//   ሕነታት_, _овуд, --, --, 
   {{0xdd8d1164,0x272c1570,0xdce00118,0x00000000}},	//   _لول_, _sün_, ntně, --, 
   {{0x691c0053,0x272c0793,0x2d9d1165,0x06e401ec}},	//   _tūem, _pün_, _irte_, _ﺍﻳﺘﻪ, 
   {{0xfca80014,0xfbcc00ec,0x2c1400cd,0x00000000}},	//   _دالو_, _ٽڪي_, देशं_, --, 
   {{0x6b800124,0xe45c01d3,0x2d9c0055,0xdce001ef}},	//   _ipog, _elöl_, _krte_, ktně, 
   {{0x26c005ac,0x7c380129,0x00000000,0x00000000}},	//   rkjo_, _écré, --, --, 
   {{0x26c00158,0x9980143e,0x833402e8,0x80b8000d}},	//   skjo_, _آليو, знах, _आवें, 
   {{0x6b800327,0x49540240,0x00000000,0x00000000}},	// [19250] _jpog, _መተባብ, --, --, 
   {{0x67d01955,0x2d9d1166,0x60d80332,0x857400d8}},	//   _ноқу, _orte_, _smum, _елох, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6b811167,0x2ca40142,0x39480210,0xa34401af}},	//   _opog, _nnod_, _łask_, _мэгл, 
   {{0x3ea407d6,0x70506e0c,0xbea422c3,0x902802d5}},	//   зилг, رنوا, залк, іцца_, 
   {{0x2ca40656,0xb3b802e4,0xdb0415b7,0x00000000}},	//   _anod_, _המשכ, ülüm, --, 
   {{0x6b811168,0xf2d000c8,0x2d9c05ce,0x92580f06}},	//   _apog, _װען_, _crte_, _фаст_, 
   {{0x60d91169,0x2d9c0477,0x00000000,0x00000000}},	//   _umum, _drte_, --, --, 
   {{0xdca004a9,0x2d9d116a,0x00000000,0x00000000}},	//   зақи, _erte_, --, --, 
   {{0x3ed40597,0x99846911,0x00000000,0x00000000}},	//   _عقار, ەمگە_, --, --, 
   {{0x2d987813,0xf2d0011a,0x00000000,0x00000000}},	//   åpet_, געי_, --, --, 
   {{0x7f481449,0x2ca40036,0x3ce800c7,0x8b6400cf}},	//   _kweq, _gnod_, _ñav_, ساۋم, 
   {{0xdb2001e7,0xe97005af,0x00000000,0x00000000}},	//   úrói, وهید, --, --, 
   {{0xe9447ba2,0x00000000,0x00000000,0x00000000}},	//   _کروی, --, --, --, 
   {{0x7f481cdf,0xe5a1116b,0x00000000,0x00000000}},	//   _lweq, нири, --, --, 
   {{0x7f48014b,0x7ae1116c,0x6b8003ac,0x15b81219}},	//   _oweq, lilt, _ypog, бығы_, 
   {{0x87b850bb,0xe45c01e6,0xdce028b5,0x7ae037a8}},	// [19260] _дуэт_, _glöm_, junč, oilt, 
   {{0xdce017a3,0x7ae0023a,0x00000000,0x00000000}},	//   dunč, nilt, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7ae1116d,0x00000000,0x00000000,0x00000000}},	//   hilt, --, --, --, 
   {{0x7ae070cd,0xdce000bc,0xa3080014,0xce9402e8}},	//   kilt, stně, _گرَے_, далъ, 
   {{0x7ae1116e,0x2ca4039a,0xc32c0131,0x999000bc}},	//   jilt, _snod_, _ئەل_, žeři_, 
   {{0x28ac11b1,0x6b81116f,0x7f480548,0x7ebd1170}},	//   टामि, _spog, _eweq, _rèpt, 
   {{0x2d9c1505,0x66c803be,0x7ebc2a4a,0x2ca40393}},	//   _vrte_, _müka, _sèpt, _qnod_, 
   {{0x66c800c5,0x7ebc004e,0xceb80ce8,0x00000000}},	//   _lüka, _pèpt, _мәк_, --, 
   {{0x7ae11171,0x3870062c,0x6b8009a8,0x2aa80640}},	//   gilt, _acyr_, _vpog, стио_, 
   {{0x2d9c0323,0xe9e408b9,0xe298008f,0x00000000}},	//   _urte_, яцио, זשיר, --, 
   {{0x2ca4951a,0x7bfc004d,0x7ae0c052,0x6b80031c}},	//   _unod_, ợtốt_, ailt, _tpog, 
   {{0x7ae11172,0xac091173,0x6b800219,0xe8800023}},	//   bilt, _унда_, _upog, _ክዛረቡ_, 
   {{0x66c80793,0x7ae11174,0x05940244,0x5b101cd0}},	//   _büka, cilt, وازگ, _зміт, 
   {{0xda78011a,0xe80c000d,0x00000000,0x00000000}},	//   _הנור, _सरवा_, --, --, 
   {{0x66c8ffea,0xba180451,0x00000000,0x00000000}},	//   _düka, _بيٺا_, --, --, 
   {{0x5fd8012d,0xc2c400ae,0x00000000,0x00000000}},	// [19270] _मेंल, ويري, --, --, 
   {{0x92940276,0x0a44001f,0x00000000,0x00000000}},	//   науц, _የአሠራ, --, --, 
   {{0x691c00b0,0x752401c6,0xfbd803ce,0x216400c0}},	//   _pūeh, _fikz, _बेईम, ятаг, 
   {{0x7ae11175,0xd1c805f5,0x6938031c,0xdf50004e}},	//   zilt, чууд_, _iċed, ендө, 
   {{0x44391176,0x7f48009a,0x644c005f,0x46d005d7}},	//   _ifs_, _qweq, _ieci, _हताह, 
   {{0x44380162,0x7524037e,0xbe64007b,0x16140073}},	//   _hfs_, _zikz, ذهبي, णेकर_, 
   {{0x644d1177,0xd1640801,0x6938031c,0x6d5c0010}},	//   _keci, _пъти, _jċed, špan, 
   {{0x443800b5,0x98a802f0,0xdb180112,0x00000000}},	//   _jfs_, _punč_, szuü, --, 
   {{0x644d1178,0x44391179,0x3af402bf,0x2d981445}},	//   _meci, _mfs_, дянс, åper_, 
   {{0x644d117a,0x637c054e,0x7aa401f4,0x00000000}},	//   _leci, mână, фиоз, --, 
   {{0x7ae1117b,0x4438b56e,0xcb8001ec,0x00000000}},	//   rilt, _ofs_, _ұқып, --, 
   {{0x7ae1117c,0xf1b0010f,0xc0b80248,0x00000000}},	//   silt, דסט_, _áádá, --, 
   {{0xb8e41161,0x7ae1117d,0x61300135,0x7524022e}},	//   _एव_, pilt, _oħlo, _rikz, 
   {{0x644c0022,0x7d080d92,0x66c8014a,0x7ae00a55}},	//   _aeci, lles, _püka, qilt, 
   {{0x644c034c,0x7d08198f,0x68ec0109,0x752401f5}},	//   _beci, oles, òndò, _pikz, 
   {{0xf5080111,0xddcc00d7,0x00000000,0x00000000}},	//   інал_, čeňa, --, --, 
   {{0x7d09117e,0x44380009,0x4ab4009d,0x00000000}},	// [19280] iles, _dfs_, _цөөр, --, 
   {{0x7d09117f,0xf624033a,0x00000000,0x00000000}},	//   hles, _одпо, --, --, 
   {{0x644d1180,0x66c82b24,0x3cec000d,0x00000000}},	//   _feci, _kükn, knev_, --, 
   {{0x7d0800dd,0x443805d5,0x644c5397,0x7bcc005f}},	//   jles, _gfs_, _geci, _ļaun, 
   {{0x5f7001d9,0x3d3400b0,0x7ebc020c,0xdf700345}},	//   ناور, _rāwa_, _rèpr, ندوب, 
   {{0x644d1181,0x00000000,0x00000000,0x00000000}},	//   _zeci, --, --, --, 
   {{0x644d1182,0xe2951183,0xdce0008e,0x00000000}},	//   _yeci, _юар_, evnı, --, 
   {{0x3cec2d1e,0x44380175,0x00000000,0x00000000}},	//   gnev_, _xfs_, --, --, 
   {{0xa03000f7,0xe45c032e,0x765c44ef,0x00000000}},	//   _شىلت, _slök_, _odpy, --, 
   {{0x7d089b5d,0x1e802377,0x2e141f0d,0x00000000}},	//   ales, _илум, _قباح, --, 
   {{0x7d091184,0x7c380368,0xa11400f1,0x2d951185}},	//   bles, _ffwr, _رسېږ, _юрас, 
   {{0x7d091186,0xab280364,0xb80800fe,0x2bc81171}},	//   cles, _дода_, ৰখনত_, _муло_, 
   {{0x443802fa,0x644c123b,0x9d18008d,0x58d41468}},	//   _rfs_, _reci, _וואט, тоят, 
   {{0x644d1187,0xdce01a14,0x5bb40111,0x00000000}},	//   _seci, munā, _юлія_, --, 
   {{0x644c5909,0x45d51188,0x6aa80254,0x6f0801ab}},	//   _peci, ховс, _inff, ilfc, 
   {{0xb4b4008e,0x00000000,0x00000000,0x00000000}},	//   нисә, --, --, --, 
   {{0x6e3803ac,0x41b4104c,0x00000000,0x00000000}},	// [19290] _oftb, کمار, --, --, 
   {{0x7d091189,0x644c0fec,0x6d580455,0x2909118a}},	//   zles, _weci, _ovta, llca_, 
   {{0x44387cea,0x644d118b,0x7d09118c,0x98a800b0}},	//   _tfs_, _teci, yles, _hunā_, 
   {{0xdce05da4,0x7d089b7d,0x48ac03d4,0x403400f0}},	//   kunā, xles, _চতুৰ, хедс, 
   {{0x6d58b41e,0x9f480fb9,0x6d5c02d1,0x00000000}},	//   _avta, _ömür_, špal, --, 
   {{0x7d081590,0x7a3001ed,0x626402dd,0x66c80254}},	//   wles, _műté, _تاحق, _müko, 
   {{0x3cec04cc,0x00000000,0x00000000,0x00000000}},	//   tnev_, --, --, --, 
   {{0xf0780184,0x7d09118d,0x6aa80368,0x7c641291}},	//   _нисә_, ules, _anff, راعل, 
   {{0x6d580010,0x3cec0489,0x66c806be,0x00000000}},	//   _evta, rnev_, _rükn, --, 
   {{0x3944230c,0xba744689,0x3cec0037,0xdda802e8}},	//   нног, راخت, snev_, _мтел_, 
   {{0x7d09118e,0x8d743669,0x6d8c06d6,0x690c0086}},	//   ples, _لانا, _ṱavh, rùen, 
   {{0xe45c24ba,0x66c801b8,0x32e401e1,0x8d7400d1}},	//   _ndö_, _büko, _kíyè_, _جاكا, 
   {{0xe5a00131,0x00000000,0x00000000,0x00000000}},	//   қити, --, --, --, 
   {{0xe45c006a,0x29080e3c,0xeba806ea,0x00000000}},	//   _adö_, alca_, støð_, --, 
   {{0x499438be,0x0eb801f9,0x00000000,0x00000000}},	//   _ашыт, _अवघड, --, --, 
   {{0x7a3001ed,0x00000000,0x00000000,0x00000000}},	//   _fűté, --, --, --, 
   {{0x66c8013d,0x32e40248,0xdb200241,0x00000000}},	// [192a0] _kükl, _níyè_, _òrót, --, 
   {{0xe295118f,0x63a803cd,0xdc40013a,0x00000000}},	//   нау_, ågna, déčk, --, 
   {{0xe128081f,0xdcfc012c,0x66c80139,0xfa3c0092}},	//   _སྤྱད_, ívěs, _mükl, _የአሕዛ, 
   {{0xeff00020,0x00000000,0x00000000,0x00000000}},	//   _ሌላው_, --, --, --, 
   {{0xe0411190,0x64a001c6,0x00000000,0x00000000}},	//   унчи, _саяа, --, --, 
   {{0x6448022c,0x66c805d1,0x00000000,0x00000000}},	//   ðgiv, _nükl, --, --, 
   {{0x4c9401f4,0x00000000,0x00000000,0x00000000}},	//   вийс, --, --, --, 
   {{0xe128003d,0xe570010f,0xd7e0000d,0xfaf800de}},	//   _སྤྲད_, אַץ_, _पइंच, brūk_, 
   {{0xdfcc00b2,0xa8500032,0x6f640214,0x66c80205}},	//   _ٿيل_, һенә, _سهام, _bükl, 
   {{0xdce000da,0x2fc51191,0x98a8005f,0x00000000}},	//   runā, myog_, _runā_, --, 
   {{0xa85002d9,0x15fc01ad,0x2fc446ab,0x00000000}},	//   ленә, _एडगर_, lyog_, --, 
   {{0x66c80793,0x23c40248,0x98a8002b,0x00000000}},	//   _püko, _jíjú_, _punā_, --, 
   {{0x69cc00e1,0xac080108,0x00000000,0x00000000}},	//   दनही, _энда_, --, --, 
   {{0xa49801e1,0xdb2003b2,0x6aa8015d,0x00000000}},	//   _ekòl, _árðu, _unff, --, 
   {{0x7f580007,0xc8f402e8,0x5a98010f,0x298400db}},	//   zswq, _изкъ, _זשוא, _чылг, 
   {{0xd4986885,0xa90406c2,0xfaec01e2,0x00000000}},	//   нру_, _ثبتن, _هګۍ_, --, 
   {{0x66c82c6f,0xc2989785,0xc6f80640,0x00000000}},	// [192b0] _yükl, мках_, _оних_, --, 
   {{0xd6d40124,0xd04003b9,0x00000000,0x00000000}},	//   _бжьы, _ilmə, --, --, 
   {{0x36f40014,0x6d5c01a6,0xdce00356,0x7e740205}},	//   _شہِج_, špaj, nună, _özpi, 
   {{0xb5f0005e,0x58f8025c,0x1ee4114f,0x00000000}},	//   _түсі, ྔོགས_, کوتی_, --, 
   {{0x23c46791,0x41ac000d,0x00000000,0x00000000}},	//   _díjú_, _टपकस, --, --, 
   {{0x238402d3,0x245801e1,0x00000000,0x00000000}},	//   _ምርዳእ_, bàmí_, --, --, 
   {{0xf08001ed,0xf2c000d1,0xa6d000fe,0xbbc806ff}},	//   _چیمپ, _төти, _সদায়, िन्क, 
   {{0x2fc4409c,0xb4e40ffb,0xa4980100,0x62642309}},	//   byog_, mpàù, _okòm, _تاڭق, 
   {{0x98a8084c,0xd7e007f7,0xca180150,0x00000000}},	//   _lună_, _पेंच, _ﺳﺎﺭ_, --, 
   {{0xa9bc0ed1,0x66c8137e,0xb060010e,0x00000000}},	//   ﺭﻣﯩﺴ, _bükm, _ýäri, --, 
   {{0xac951192,0xe9d4084c,0x00000000,0x00000000}},	//   رنیا_, вкэ_, --, --, 
   {{0xa3c002e5,0xe9446e92,0x00000000,0x00000000}},	//   ौना_, کریی, --, --, 
   {{0xd6780328,0x66c80213,0xabb40124,0xb0b4011a}},	//   ىڭدا_, _tükl, _иацә, דפרס_, 
   {{0x98a8084c,0xdce00276,0x69cc1f13,0x00000000}},	//   _bună_, bună, दनशी, --, 
   {{0x691c00b0,0x9ba01075,0xd04003b9,0x00000000}},	//   _pūet, _شەگى, _elmə, --, 
   {{0x3208132c,0x7bcc00e2,0x00000000,0x00000000}},	//   _ryby_, _ļauj, --, --, 
   {{0xa50431de,0xb4d04ed3,0xff1400b5,0x8d78001f}},	// [192c0] тета_, _वती_, _gのg_, ከሰተው_, 
   {{0x2fc40218,0x0a44001f,0xb5c406b4,0x23c402d2}},	//   vyog_, _የአሰራ, _айол, _síjú_, 
   {{0xd25000db,0x55c401ec,0x00000000,0x00000000}},	//   _ۇچا_, _санғ, --, --, 
   {{0xc7640150,0xeba40162,0x64480162,0x00000000}},	//   _شاۋى, íøki_, ðgit, --, 
   {{0x7e600175,0x00000000,0x00000000,0x00000000}},	//   _bdlp, --, --, --, 
   {{0x32080356,0x2fc401a9,0x00000000,0x00000000}},	//   _tyby_, ryog_, --, --, 
   {{0xceb8052f,0xa2e01fc7,0x2fc40211,0x69380135}},	//   _үҙе_, _торд, syog_, _oċea, 
   {{0x7d18015d,0x00000000,0x00000000,0x00000000}},	//   _chws, --, --, --, 
   {{0x39440204,0x2078008f,0x00000000,0x00000000}},	//   epls_, _קאמא, --, --, 
   {{0x64bc1df1,0x00000000,0x00000000,0x00000000}},	//   _एक्श, --, --, --, 
   {{0xae1c000d,0x6c84007b,0x5b100166,0x7bdc03b2}},	//   येशन_, _للام, рмэт, úsur, 
   {{0x8d750593,0x61e003b2,0x00000000,0x00000000}},	//   _لاچا, únli, --, --, 
   {{0x98a80311,0xeab801c6,0xdce00356,0x99440133}},	//   _sună_, _ойд_, sună, _یلول_, 
   {{0x98a80276,0xdce0054e,0x1ae01a71,0x66c91193}},	//   _pună_, pună, _кочм, _tükm, 
   {{0xd6d810f5,0x37c07cdd,0xe80c000d,0x00000000}},	//   ття_, _һәрб, _सरका_, --, 
   {{0xa49801e1,0x66c91194,0x43940153,0x00000000}},	//   _ikòk, _kükk, лабс, --, 
   {{0x69d86144,0x53340220,0xf3f801d2,0x69cc01bf}},	// [192d0] lzte, иетт, емтә_, øbef, 
   {{0x42543947,0x66c80205,0xb7d80133,0xceb80210}},	//   انار, _mükk, _سوپا_, _mięs_, 
   {{0x69d91195,0x66c800af,0xe45c0267,0x09a80327}},	//   nzte, _lükk, _blöt_, བཀྲ_, 
   {{0xe3e00ed1,0x69d8530f,0x00000000,0x00000000}},	//   _көзқ, izte, --, --, 
   {{0x3f8800a9,0x9eb00131,0x74140451,0x40880139}},	//   ïau_, ишкә, _موٽا, _җәем_, 
   {{0x95640092,0x00000000,0x00000000,0x00000000}},	//   ስጣችን_, --, --, --, 
   {{0x81d51196,0x8d5402d5,0xddc001e4,0xe45cf971}},	//   _совх, атыч, banŝ, _flöt_, 
   {{0x69c4924b,0x66c800e5,0x69d800de,0xa5c00210}},	//   ाहनी, _bükk, dzte, łóws, 
   {{0xa4980248,0xfaa51197,0x1dac0cb4,0x26d0022e}},	//   _akòk, гапо, _झपकत, _olxo_, 
   {{0xa3b8033d,0x66c803ee,0xbf14aa36,0xe45c007c}},	//   _अपन_, _dükk, _صواب, _klös_, 
   {{0xbc751198,0x7bcc0139,0xdd9801ee,0x00000000}},	//   _مهاب, _şouı, _юша_, --, 
   {{0xf7451199,0x291801d5,0xbb74030d,0xe9a50ee6}},	//   лемо, _chqa_, _букъ, اگون_, 
   {{0x691c02b1,0x69d8009d,0x62840010,0x00000000}},	//   _pūer, azte, _objo, --, 
   {{0x5a444077,0x61300327,0x00000000,0x00000000}},	//   _рэда, _eħli, --, --, 
   {{0x3de40183,0x228401d5,0x6ed0012d,0xe64000d8}},	//   _পুতল, dеk_, głby, сесп, 
   {{0x6284208d,0x49b830a7,0x00000000,0x00000000}},	//   _abjo, _جاهد_, --, --, 
   {{0x7bc871d1,0xdd000006,0x92e4010b,0x3ce40037}},	// [192e0] nyeu, ūrėj, абаҗ, जोये_, 
   {{0x63840882,0x7bc80099,0xe45c01e3,0x66c80205}},	//   dīnā, iyeu, _slöt_, _nükh, 
   {{0xd5b000e5,0x7bc80051,0x28d8134e,0x00000000}},	//   _ظہر_, hyeu, मोकि, --, 
   {{0x2ebc085c,0x504400c7,0x00000000,0x00000000}},	//   ्स्त, рҵаб, --, --, 
   {{0x69d80407,0x14080022,0x2284022e,0x60340006}},	//   zzte, _рҭак_, bеk_, упіў_, 
   {{0xe3b0009f,0x00000000,0x00000000,0x00000000}},	//   _ارٽ_, --, --, --, 
   {{0x57d0012c,0xe45c08a5,0x66c80139,0x5d80027d}},	//   हनुह, _glös_, _sükk, ملول, 
   {{0x59a4000d,0x1d040114,0x638400b8,0xeb4800cf}},	//   गिनर, леји_, bīnā, нчок_, 
   {{0xe040084c,0xa06402e8,0x63841619,0xe0d40f06}},	//   _ынти, _щата_, cīnā, _свт_, 
   {{0x69d809f0,0xe45c049b,0xe378008f,0x4a54041b}},	//   tzte, _ylös_, עריר, шкос, 
   {{0xd7f81086,0xcff4547d,0x69d8f2f1,0xdcd000cf}},	//   ҳур_, _अशुभ_, uzte, рбөө, 
   {{0xddc1119a,0x02c00882,0x66c86713,0x69d9119b}},	//   lanş, _शक्न, _tükk, rzte, 
   {{0x69d8066d,0xd7f9119c,0x8c44010b,0x00000000}},	//   szte, гур_, _беҗе, --, 
   {{0x66c80037,0xa9c402da,0xddc00432,0x00000000}},	//   _küki, _مزبو, nanş, --, 
   {{0xdb2001d3,0xdce0012d,0x00000000,0x00000000}},	//   _órát, suną, --, --, 
   {{0x290d119d,0xddc1119e,0x00000000,0x00000000}},	//   _óga_, hanş, --, --, 
   {{0xd7a80451,0xe78400cf,0x75f000e5,0x00000000}},	// [192f0] _مٿين_, _суйо, tűzé, --, 
   {{0xa3b001ec,0x00000000,0x00000000,0x00000000}},	//   _құзі, --, --, --, 
   {{0x46140502,0xc0f802d3,0xc0340798,0x00000000}},	//   _خودر, _ገበረ_, анеј, --, 
   {{0x0eb80150,0x00000000,0x00000000,0x00000000}},	//   ғушы_, --, --, --, 
   {{0x5185119f,0xc3c401c0,0xda0800af,0x00000000}},	//   _қура, _төвл, _सुनत_, --, 
   {{0xbea511a0,0xfe7111a1,0x3dc4009d,0x00000000}},	//   ракк, زدت_, ийлг, --, 
   {{0xfc300597,0xbd44007b,0x00000000,0x00000000}},	//   يحة_, جنبي, --, --, 
   {{0xff1403f4,0xc0f0001f,0x7bc800ca,0xc0f80023}},	//   াদেশ_, ቃቀም_, tyeu, _ገበሩ_, 
   {{0x7bc800d5,0x00000000,0x00000000,0x00000000}},	//   uyeu, --, --, --, 
   {{0x7bc80100,0xf98401f4,0x00000000,0x00000000}},	//   ryeu, агоо, --, --, 
   {{0x7bc80100,0x20d403e3,0xac9400cf,0x00000000}},	//   syeu, _içib_, انۋا_, --, 
   {{0x7bc80051,0x00000000,0x00000000,0x00000000}},	//   pyeu, --, --, --, 
   {{0xb8ec1533,0xe8f511a2,0x87f801c6,0x6d5c0306}},	//   _शक_, рля_, гэрт_, ápav, 
   {{0xb6a401c6,0x00000000,0x00000000,0x00000000}},	//   шигл, --, --, --, 
   {{0x65c0dea5,0x00000000,0x00000000,0x00000000}},	//   обра, --, --, --, 
   {{0x8a1511a3,0x56f42063,0xe45c08a5,0x644803b2}},	//   _اظها, рүүс, _slör_, ðgip, 
   {{0x3774004e,0xc0f80023,0x00000000,0x00000000}},	// [19300] _тыйс, _ገበሮ_, --, --, 
   {{0x0ea402a0,0x3ce80030,0xa49801e1,0xc3e400f1}},	//   _गोंड, čavy_, _okòw, حثفو, 
   {{0x6ee40b8a,0xddc111a4,0xa49801e1,0x79800142}},	//   یستل, vanş, _nkòw, ntlw, 
   {{0x39a40029,0x21643e9f,0x98a80166,0xf1a801b9}},	//   _mēs_, рици_, _kvnı_, _یازه_, 
   {{0xb184072b,0xca7801a9,0xb9ec0023,0x00000000}},	//   _blåø, _rivо, _ዕጭ_, --, 
   {{0x66c8014a,0xfaf80006,0x764c0076,0x63a8005c}},	//   _püki, irūs_, nbby, ægne, 
   {{0xc0f8001f,0xd6d803d4,0xaaa400bc,0xc0c80023}},	//   _ገበሬ_, _সদায, _कोषक, ጽሮም_, 
   {{0x66c82045,0x764c0036,0xa218010a,0xfaf80064}},	//   _vüki, hbby, _расă_, krūs_, 
   {{0xafe4721f,0xb1840fac,0xdcb419b0,0x00000000}},	//   _тоал, _flåø, ргыч_, --, 
   {{0x6e9400c6,0x66c800c5,0xb4d01a04,0x2ac40063}},	//   _خلطا, _tüki, वसु_, рљив, 
   {{0xa5f801a9,0x88581d0f,0xec78009b,0x66740066}},	//   _o想ar, линс_, _апе_, یدسر, 
   {{0x6d4911a5,0x00000000,0x00000000,0x00000000}},	//   mpfa, --, --, --, 
   {{0x394911a6,0x6938031c,0xe7844cd0,0x9be028f6}},	//   _čase_, _iċem, шуно, _мішк, 
   {{0x9b40168d,0x6d482112,0x81bc00fe,0xa9c40395}},	//   _بنوو, opfa, ইনত_, _всик, 
   {{0x7afd11a7,0x98a8003a,0x6d482caa,0x95c82bbd}},	//   éste, _lunę_, npfa, аута_, 
   {{0x04c80486,0x6938031c,0x00000000,0x00000000}},	//   دوري_, _jċem, --, --, 
   {{0x0444013d,0x94a80114,0xb7d800e5,0x00000000}},	// [19310] иеңн, јтса_, _موٹا_, --, 
   {{0x21dc0150,0x00000000,0x00000000,0x00000000}},	//   _ﺃﻁﺭﻭ, --, --, --, 
   {{0xcfe400cc,0x00000000,0x00000000,0x00000000}},	//   _ফুলন, --, --, --, 
   {{0x7fd401ec,0x51a801d5,0x00000000,0x00000000}},	//   йілі, шъум_, --, --, 
   {{0xa3b81161,0xbe6801c6,0xef0c01e2,0x00000000}},	//   _अपि_, галж_, کټو_, --, 
   {{0xaaa44142,0xcf2416ac,0x5e840212,0x00000000}},	//   _कोलक, يروي, рудз, --, 
   {{0x6d480036,0x00000000,0x00000000,0x00000000}},	//   gpfa, --, --, --, 
   {{0x84f806ab,0x2b4400b5,0x04f400cc,0x00000000}},	//   ्किट_, _btoc_, _আঠুৰ_, --, 
   {{0x6d48007b,0x9e64c0cc,0xcce4007b,0x764c062c}},	//   apfa, _ناان, تسوي, ybby, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfaa43461,0x39e911a8,0x2b440f85,0x7db40133}},	//   _ҳало, удно_, _etoc_, _دڵشا, 
   {{0x6938031c,0xfaf80153,0xbb3c0046,0xa7f800a2}},	//   _kċej, trūs_, _ﺑﯘﻝ_, kañd, 
   {{0xfaa40953,0x6d5d11a9,0x81bc0154,0xd9c00014}},	//   _гало, špat, ইনি_, _ژٕتۯ, 
   {{0x2488067c,0x3cec8e9e,0x7d0800a9,0xdb20efe5}},	//   _abcm_, liev_, loes, _بوتی, 
   {{0x66e0fa78,0x2ab80375,0x995401ef,0x5ba40118}},	//   чора, _תמצא, _háže_, _कछुव, 
   {{0x7d08005c,0x2c1c00dc,0x3ced11aa,0x6938031c}},	//   noes, _परमं_, niev_, _oċej, 
   {{0x2844008e,0x84540e56,0xda080037,0x00000000}},	// [19320] _узып_, زىلچ, _सुतत_, --, 
   {{0x7d0911ab,0x32340982,0x3ced11ac,0x58f80327}},	//   hoes, схас, hiev_, ྔོམས_, 
   {{0x7d0911ad,0x720400c6,0xdce00210,0x3cec28e5}},	//   koes, حوام, sunę, kiev_, 
   {{0x6938031c,0xdfcc05d9,0xe29402dd,0x7d08005b}},	//   _bċej, ڙين_, _қас_, joes, 
   {{0x7d0911ae,0xa0640536,0x3ced11af,0x00000000}},	//   does, сача_, diev_, --, 
   {{0xaaa410eb,0x6d48002f,0x32b401f7,0x00000000}},	//   _कोंक, tpfa, _اصحآ, --, 
   {{0x2b4511b0,0x6440068f,0xa7f8005a,0x7d0911b1}},	//   _stoc_, śnie, mañe, foes, 
   {{0x6d4911b2,0xa7f80077,0xdfb801e1,0x3cec0166}},	//   rpfa, lañe, _lóṣù_, giev_, 
   {{0x66c8008e,0x2fd00158,0x6d489841,0x00000000}},	//   _kükt, øygd_, spfa, --, 
   {{0x63a804ce,0x6d486afa,0x3e8001a8,0x639808a8}},	//   ågni, ppfa, rætó_, נסינ, 
   {{0x7d0911b3,0x8a180107,0x66c80205,0x6da406c5}},	//   boes, ронс_, _mükt, _دمام, 
   {{0x2d9c16fe,0x3cec008e,0x00000000,0x00000000}},	//   _iste_, ciev_, --, --, 
   {{0x80c402f5,0xabb09a47,0x27fc0342,0xfca83fe6}},	//   লোক্, _халә, çun_, _خالو_, 
   {{0x2eec05b1,0xfd5400cd,0x6f08009f,0x66c80205}},	//   niff_, _alaṃ, nofc, _nükt, 
   {{0x2d9c038e,0x45d4e8bb,0x69380327,0xe944022e}},	//   _jste_, цовс, _mċek, _ухло, 
   {{0x2eec17da,0x851400d4,0x66c803b9,0xdb1c0248}},	//   hiff_, імає, _rüku, _àwòk, 
   {{0x290911b4,0x66c8453a,0xd7880451,0x5f1800dc}},	// [19330] moca_, _süku, _هنيو_, यतम्_, 
   {{0x290911b5,0xa49801e1,0x2d9d11b6,0x68ec58c6}},	//   loca_, _akòt, _oste_, licd, 
   {{0x2eed11b7,0xa2bc34ef,0xa6e0022c,0x7d080083}},	//   diff_, लॉग्, øður, yoes, 
   {{0x29084e61,0x28ac000d,0x308800db,0x00000000}},	//   noca_, _जोमि, ишчү_, --, 
   {{0x2d9d11b8,0x645d11b9,0x98b407f5,0x69b801ad}},	//   _aste_, maqi, šeći_, एमडी, 
   {{0x645d11ba,0x7d080af9,0xa074035b,0x9954013a}},	//   laqi, woes, рыҧш, _ráže_, 
   {{0x290819a2,0x80c400fe,0xc0f81ee0,0x3cec0030}},	//   koca_, লোগ্, _ገጠር_, tiev_, 
   {{0x645d11bb,0x629511bc,0x290911bd,0x6cb000f7}},	//   naqi, lexo, joca_, дөшт, 
   {{0x2d9d11be,0x8c643ea0,0x3cec00fd,0x290800d8}},	//   _este_, سطين, riev_, doca_, 
   {{0x4500045e,0x6294d6a6,0x7f4911bf,0x7d080618}},	//   ্ষিক_, nexo, _iteq, soes, 
   {{0x6d5d11c0,0x7d0911c1,0x29002a53,0x29081ada}},	//   špar, poes, čkan_, foca_, 
   {{0x290803b4,0x160406ab,0xe9a41473,0x38280835}},	//   goca_, _शुगर_, زگىن_, ижно_, 
   {{0x6b80009a,0xb9000037,0x66c80205,0x00000000}},	//   _gqog, _धत_, _nüks, --, 
   {{0x2d9c0158,0xa8000077,0xb4d007d0,0x3634179e}},	//   _yste_, úñas, वस्_, ترحس, 
   {{0x62940408,0x645d11c2,0x29080009,0x68ec058a}},	//   dexo, faqi, boca_, bicd, 
   {{0x645c0944,0x290911c3,0xe94404fb,0x845911c4}},	//   gaqi, coca_, _بروی, йрут_, 
   {{0x6294035a,0x36684f33,0xa7f80789,0x36340345}},	// [19340] fexo, _капо_, tañe, _وردس, 
   {{0x645c013c,0xa4980158,0x78a41654,0x62940175}},	//   aaqi, _skòt, ldkv, gexo, 
   {{0x28ac038e,0x645d11c5,0x7f480869,0xdb0802d3}},	//   _जोडि, baqi, _ateq, _argë, 
   {{0x2d9c0450,0xa7f82e65,0x645c06be,0x00000000}},	//   _rste_, sañe, caqi, --, 
   {{0x629401f0,0x6440033f,0x2eec04a3,0xa7f911c6}},	//   bexo, śnic, tiff_, pañe, 
   {{0x2908337a,0x00000000,0x00000000,0x00000000}},	//   zoca_, --, --, --, 
   {{0x20d511c7,0x2eed11c8,0xdb0804e6,0x78b4037e}},	//   _için_, riff_, _ergë, _onyv, 
   {{0x66c882aa,0xa7f80bc9,0xdb080120,0x1be8000d}},	//   _yüks, nañc, _urgê, _जेहल_, 
   {{0x394911c9,0x9a74001f,0x0a440092,0x00000000}},	//   _časa_, _በአካል_, _የአማራ, --, 
   {{0x0a44001f,0x5b200b24,0x6d5c02d1,0x497457c6}},	//   _የአመራ, وفيل, špaq, плос, 
   {{0x09f80491,0x3150044e,0x2d9c05f5,0x7afd11ca}},	//   صفحة_, _ዝነበር, _uste_, ésta, 
   {{0x29000552,0x6294208d,0x1af401c6,0x00000000}},	//   čkao_, zexo, йдөө_, --, 
   {{0x290911cb,0x68ed11cc,0x62940117,0xaae4027d}},	//   roca_, ricd, yexo, _وستو, 
   {{0x290911cd,0xca480bbf,0x645d11ce,0xd6d8009b}},	//   soca_, _الغه_, waqi, отс_, 
   {{0x290911cf,0x96f80124,0x645c5c40,0x7800013e}},	//   poca_, церт_, taqi, _ҷӯра, 
   {{0xdb080ba1,0x66c800c5,0x6d4400f3,0x2c1c00cd}},	//   _argè, _püks, _čkal, _परां_, 
   {{0x645d11d0,0x62944e6f,0x78000117,0xdc98123b}},	// [19350] raqi, texo, _зӯра, סימל, 
   {{0x645d11d1,0x00000000,0x00000000,0x00000000}},	//   saqi, --, --, --, 
   {{0x62940005,0x645c0113,0xa7f80055,0x00000000}},	//   rexo, paqi, bañc, --, 
   {{0x6294f8bc,0x645c0869,0x26c00083,0xa7f8002b}},	//   sexo, qaqi, ljjo_, cañc, 
   {{0x443800ec,0x7b1c0561,0x00000000,0x00000000}},	//   _igs_, hèua, --, --, 
   {{0x443911d2,0x8ee80212,0x63ac01f4,0xdc100154}},	//   _hgs_, омів_, _ircn, াইমস_, 
   {{0xb1441060,0x5334f54e,0xd6580375,0x6d5c76cf}},	//   _فیلم_, _церт, חיות_, ápap, 
   {{0xd5fc0375,0xae000131,0xc10400ec,0x00000000}},	//   יפור, رۈنى, _ڀوڳي, --, 
   {{0x60d911d3,0x29006185,0x7f4820ac,0x69cc00b5}},	//   _ilum, čkal_, _uteq, øben, 
   {{0x443911d4,0x60d8014b,0x6ae00022,0xdac400d1}},	//   _lgs_, _hlum, ежьз, تېتى_, 
   {{0x3ea4037e,0x443911d5,0x3d940120,0xf990020c}},	//   _ialt_, _ogs_, _хиер, ربد_, 
   {{0x44389b7d,0x3f9c022f,0x3ea402c2,0x63ac02d0}},	//   _ngs_, owwu_, _halt_, _orcn, 
   {{0x3ea511d6,0xbb480a2c,0x60d911d7,0x5ba511d8}},	//   _kalt_, _التن_, _mlum, _фрез, 
   {{0x60d911d9,0xfaa499a4,0x66c80205,0xbbb800bc}},	//   _llum, _хако, _sükr, ेहीक, 
   {{0x3ea41590,0x63ac02d0,0x68fc010a,0xe9cc00ec}},	//   _malt_, _arcn, _fjqd, _مٺو_, 
   {{0x44384317,0x201c0085,0x63ac0427,0x00000000}},	//   _cgs_, _ozui_, _brcn, --, 
   {{0xdb0887fb,0x443803e0,0xdef00023,0x00000000}},	// [19360] _argé, _dgs_, ፎምን_, --, 
   {{0x3ea511da,0x4d800055,0x00000000,0x00000000}},	//   _nalt_, _ūḍhā, --, --, 
   {{0x60d90d2d,0x201c0085,0xa7f911db,0x59c83c71}},	//   _blum, _azui_, maña, ाहिर, 
   {{0x60d911dc,0xa7f8241c,0x3ea404e6,0x765c00c7}},	//   _clum, laña, _aalt_, _hepy, 
   {{0x765d11dd,0x74142756,0x63ac0010,0xb11800cf}},	//   _kepy, _روسا, _grcn, _ۇقسا_, 
   {{0xdee111de,0xdb084d74,0x59c8412f,0x765c00c7}},	//   ночи, _urgè, ाहार, _jepy, 
   {{0x60d911df,0x3ea511e0,0x201c0085,0x443805d1}},	//   _flum, _dalt_, _ezui_, _ygs_, 
   {{0x60d804b9,0xa7f80bc9,0x612000af,0x44380334}},	//   _glum, haña, võlg, _xgs_, 
   {{0xa7f8241c,0x3ea511e1,0x00000000,0x00000000}},	//   kaña, _falt_, --, --, 
   {{0x3ea511e2,0xa7f8094a,0xada400fd,0x6da46560}},	//   _galt_, jaña, _назл, _низа, 
   {{0x9eb45dc9,0xa7f80428,0xdd8d11e3,0x00000000}},	//   _эштә, daña, _مول_, --, 
   {{0x765c0165,0x6d580477,0x00000000,0x00000000}},	//   _aepy, _iwta, --, --, 
   {{0x44380024,0x3ea45b7f,0x998075f5,0x6fbc05c0}},	//   _rgs_, _yalt_, ولیو, ्हिं, 
   {{0xa7f911e4,0x2ca401ab,0xdb98011a,0xd4986efa}},	//   gaña, _haod_, _לסדר, үрт_, 
   {{0x567834d8,0x765c007f,0x3860009f,0x44380208}},	//   ября_, _depy, bakr_, _pgs_, 
   {{0x2a7c0077,0x765c02d0,0x6d580142,0x6fbc0b03}},	//   lgtb_, _eepy, _mwta, ्हां, 
   {{0xa7f911e5,0x4438168c,0xceb80165,0x98d8005e}},	// [19370] baña, _vgs_, _dięz_, _ءبىز_, 
   {{0xa7f80004,0x765cf4e5,0x81d40fc0,0x2a7c004d}},	//   caña, _gepy, мозх, ngtb_, 
   {{0x50d401b9,0xb224010a,0x00000000,0x00000000}},	//   کزلر, çмал, --, --, 
   {{0xb9e40020,0x2ca4030a,0x3ea511e6,0x673c036e}},	//   _ይዞ_, _naod_, _salt_, _kuqj, 
   {{0x6d58f0e3,0x442c0086,0xbea42c08,0x765c083c}},	//   _awta, _àe_, далк, _yepy, 
   {{0x7c3800a9,0x6734031c,0x20d45397,0xdb200162}},	//   _sgwr, _jixj, _içim_, _órøt, 
   {{0x3ea511e7,0x2ca40156,0x60d911e8,0x9258016c}},	//   _valt_, _baod_, _tlum, _хаст_, 
   {{0x3ea4094a,0x60d911e9,0x9f5c00dd,0xa7f809c2}},	//   _walt_, _ulum, áról_, zaña, 
   {{0x3ea412ed,0xa7f82e95,0x673c016d,0x66140267}},	//   _talt_, yaña, _nuqj, _lyxk, 
   {{0x3944e99a,0xa7f80bc9,0xe45c0022,0x6d580334}},	//   мног, xaña, _leö_, _fwta, 
   {{0x2ca40e89,0x28ac0cb4,0x765c0124,0xf2d002e4}},	//   _faod_, _जोहि, _repy, דעי_, 
   {{0x2ca40280,0xa7f80227,0x673c0200,0xdbd4005b}},	//   _gaod_, waña, _buqj, tääp, 
   {{0xa7f82e95,0x765c00c7,0xf99000f2,0x00000000}},	//   taña, _pepy, ربگ_, --, 
   {{0x9a8401c0,0x69380003,0x00000000,0x00000000}},	//   _худл, _rċev, --, --, 
   {{0xa7f82e95,0x7ae001ab,0x64400118,0x00000000}},	//   raña, mhlt, ěnin, --, 
   {{0x2ed8dadd,0xf8e02793,0xa7f911ea,0x00000000}},	//   _भत्त, _पतिय, saña, --, 
   {{0xa7f911eb,0x59c84688,0x765c0124,0xf654005b}},	// [19380] paña, ाहवर, _tepy, _отню, 
   {{0xe29511ec,0xa7f82e95,0x00000000,0x00000000}},	//   мау_, qaña, --, --, 
   {{0x2c080034,0x7ae00076,0x9850013d,0x00000000}},	//   _हुईं_, ihlt, lğız_, --, 
   {{0x673c047e,0xf8dc000d,0x00000000,0x00000000}},	//   _yuqj, मसिय, --, --, 
   {{0xca3801e4,0x6d580142,0x63b80327,0x00000000}},	//   leĝe_, _swta, _ġung, --, 
   {{0x7ae00175,0x00000000,0x00000000,0x00000000}},	//   jhlt, --, --, --, 
   {{0xa1846ff7,0x00000000,0x00000000,0x00000000}},	//   _обра_, --, --, --, 
   {{0xdc100259,0x2ca4003a,0x8c0400ee,0x00000000}},	//   _ağır, _qaod_, нҗел, --, 
   {{0xdfcd11ed,0x2ca40254,0x6b2401e2,0x00000000}},	//   _پيل_, _vaod_, وښتې_, --, 
   {{0x7ae001ab,0x2988009b,0xceb800c0,0x00000000}},	//   ghlt, осмо_, _unę_, --, 
   {{0x2ca400a3,0xa85001e0,0xdb2001f6,0xa7f80139}},	//   _taod_, кенә, úrái, gañn, 
   {{0x612000af,0x956802d3,0x2ca40076,0xe7b40aac}},	//   põle, ጽነትን_, _uaod_, дҳиш_, 
   {{0x69380327,0x6ec052f2,0xd83911ee,0x6bd400cf}},	//   _aċet, लापु, дэр_, _تتار, 
   {{0x7d0c33e9,0x387c0024,0x81d403d4,0xa7f80139}},	//   čase, ėtra_, িছত_, bañn, 
   {{0x944c0521,0x628056eb,0x27ec012d,0x00000000}},	//   _ọdịd, ònom, _żonę_, --, 
   {{0x673c0227,0xd4980064,0x00000000,0x00000000}},	//   _tuqj, мру_, --, --, 
   {{0xa7f830cf,0x6440033f,0x6734025c,0xfbb0629c}},	// [19390] maño, śnio, _tixj, जियम, 
   {{0x0500015b,0x97140022,0xa7f80124,0xa2f8166d}},	//   ্ষের_, _имыц, laño, ्वेज_, 
   {{0xd6680014,0x461401ec,0x6ec04a76,0x9268074d}},	//   _غمَو_, _سوحر, लानु, ьрта_, 
   {{0xb67c0092,0x00000000,0x00000000,0x00000000}},	//   ንጀለኛ_, --, --, --, 
   {{0x764401d9,0xaf540724,0x29000219,0x69cc00b5}},	//   _آیہِ_, енчә, čkah_, øbej, 
   {{0x1ee401b9,0x6fb00f2b,0xdce001ef,0x00000000}},	//   بوتی_, اموا, brně, --, 
   {{0x35900023,0x00000000,0x00000000,0x00000000}},	//   _ምውታት_, --, --, --, 
   {{0xcd2805d4,0x00000000,0x00000000,0x00000000}},	//   وسين_, --, --, --, 
   {{0xa7f90c3f,0x1ea80849,0x3ce40073,0x63b808ce}},	//   daño, _وائي_, जोगे_, _áund, 
   {{0x39e800db,0x00000000,0x00000000,0x00000000}},	//   здоо_, --, --, --, 
   {{0x39480108,0x00000000,0x00000000,0x00000000}},	//   язно_, --, --, --, 
   {{0xc6883d99,0x7e6111ef,0xa7f809d7,0xf1b0008d}},	//   _לא_, _help, gaño, אסט_, 
   {{0x7e6111f0,0x644000bc,0x20d403e0,0x2bd800e5}},	//   _kelp, ěnil, _açik_, _ٹانک_, 
   {{0x6d4402b5,0x7e60c5e0,0x00000000,0x00000000}},	//   _ōkai, _jelp, --, --, 
   {{0x7e60005c,0xa7f911f1,0xf50408db,0x29d0009f}},	//   _melp, baño, езво, _ميوس, 
   {{0xa7f804d4,0x81d400fe,0x00000000,0x00000000}},	//   caño, িছা_, --, --, 
   {{0x87a40022,0x6ec008f2,0x4b4c010f,0x042c0055}},	// [193a0] _алыҧ, लामु, ַגאַ, _kāṣa, 
   {{0x7e6111f2,0xdb080407,0x6440013f,0x35a400f3}},	//   _nelp, _orgí, ɛnim, _заог, 
   {{0x042c00b8,0xccf80118,0x9f980108,0x2c7806be}},	//   _māṣa, _květ_, häät_, nüdü_, 
   {{0x9f98005b,0xd1cc0092,0x63b80153,0x850415bf}},	//   käät_, _ጠባቂ_, _šune, _لوپن, 
   {{0x7e6111f3,0x36343a56,0x8704179e,0xa85405d0}},	//   _belp, _ترکس, _سبیل, גינה_, 
   {{0x7e6001e4,0xce9400a7,0xbe54004b,0x00000000}},	//   _celp, такъ, پروګ, --, 
   {{0xdb080261,0x42500131,0x23240107,0x776003b9}},	//   _orgâ, _ئۆمر, _чори_, _çoxf, 
   {{0x0584044e,0xe73c00c5,0x7e6111f4,0x00000000}},	//   _ዝግባእ_, svõi_, _eelp, --, 
   {{0x8e7c00df,0x7e6111f5,0xcb9800d4,0x46d0000d}},	//   _alĝe, _felp, євої_, _सकलह, 
   {{0x7e600280,0xeab02d4b,0x9f940375,0x042c00b8}},	//   _gelp, اعظ_, _אדמה_, _cāṣa, 
   {{0x8cc02144,0x1e540375,0x2c780205,0x00000000}},	//   वादो, _נשאר_, güdü_, --, 
   {{0xe77511f6,0x6d440374,0x0f5402d3,0x7e6001ef}},	//   намә_, _ōkaw, _ዝተሰረ, _zelp, 
   {{0x7e6111f7,0x274807d8,0xa7f8005a,0x3f980142}},	//   _yelp, ячно_, raño, _âsut_, 
   {{0xe5c4004e,0x00000000,0x00000000,0x00000000}},	//   нсбо, --, --, --, 
   {{0xa7f911f8,0x00000000,0x00000000,0x00000000}},	//   paño, --, --, --, 
   {{0x6aa911f9,0x8d700092,0x61200037,0x00000000}},	//   _haff, _አይተው_, kõla, --, 
   {{0x38b805d5,0x37c001af,0x00000000,0x00000000}},	// [193b0] sürà_, _кәрб, --, --, 
   {{0x6aa911fa,0xec6405d9,0xfbb000dc,0xfdf00037}},	//   _jaff, _ھٿ_, जितम, _अइलस_, 
   {{0x6aa911fb,0xa1f000ec,0x00000000,0x00000000}},	//   _maff, دياڻ, --, --, 
   {{0xd1b911fc,0xa4f8031c,0x620400b8,0x00000000}},	//   عالا_, _དམིག_, _āplā, --, 
   {{0x7e6111fd,0x00000000,0x00000000,0x00000000}},	//   _pelp, --, --, --, 
   {{0x6aa911fe,0x7e60014f,0x2c781432,0x6d4c031c}},	//   _naff, _qelp, yüdü_, _ħbar, 
   {{0xf2d030fb,0xbbc82f2e,0x3d0c0574,0xfce4e91f}},	//   _דעם_, ाङ्क, डकले_, коко, 
   {{0xacb004a9,0x6aa911ff,0x7e6009dc,0xdb080798}},	//   لمىغ, _aaff, _welp, _orgã, 
   {{0x7e611200,0x6aa91201,0xfbd018fd,0x042c00cd}},	//   _telp, _baff, شتة_, _pāṣa, 
   {{0x9e6422f3,0xccf8012c,0xa7f8002e,0x9f980108}},	//   _سائن, _svět_, rañl, räät_, 
   {{0x8d751202,0x6aa8102c,0x9f980108,0x80d433ee}},	//   _مانا, _daff, säät_, _दवाइ, 
   {{0x6aa803ac,0x9f98023a,0x2c781432,0xf74404b1}},	//   _eaff, päät_, rüdü_, кемо, 
   {{0x6aa91203,0x2c7801b8,0x9f480139,0x4c3401ee}},	//   _faff, südü_, _äcä_, _йэшт, 
   {{0xaa40010b,0xeb940107,0xa3f800fe,0x6568002b}},	//   _кешл, _риш_, _আৰ্য_, _āghr, 
   {{0xc98400f3,0x00000000,0x00000000,0x00000000}},	//   _буњи, --, --, --, 
   {{0x6aa91204,0x62840010,0xf86812ea,0x3864032e}},	//   _zaff, _acjo, _کمکي_, _þor_, 
   {{0xe7a40598,0x6aa91205,0x64a08afc,0xf74801f7}},	// [193c0] _авыл_, _yaff, шата, _تلخي_, 
   {{0xf1f91206,0xca3801e4,0x71f802cb,0xb9180cad}},	//   وعات_, leĝa_, وراس_, _nifẹ_, 
   {{0x2024013f,0x00000000,0x00000000,0x00000000}},	//   ɑtiɑ_, --, --, --, 
   {{0xb9180241,0x628401e4,0xff4c0023,0xa3b817ee}},	//   _aifẹ_, _ecjo, _ዝተመዘ, _अपच_, 
   {{0xa0650540,0xdb080137,0xa0703334,0x776000ac}},	//   тача_, _orgà, ргіч, _çoxd, 
   {{0xdfd09c36,0x00000000,0x00000000,0x00000000}},	//   рошы, --, --, --, 
   {{0x00d80075,0xceb80139,0x5d600006,0x4c94aec3}},	//   ببەت_, _җәл_, атыз, гийс, 
   {{0x6aa91207,0xacd00184,0x00000000,0x00000000}},	//   _saff, рбиә, --, --, 
   {{0x6aa91208,0xb9180ca8,0xef8400d8,0x7bc40241}},	//   _paff, _fifẹ_, _шлап, _ńhur, 
   {{0x6aa91209,0x63a804ce,0x6d4400b0,0x8cc00950}},	//   _qaff, ægni, _ōkau, वाहो, 
   {{0xb865120a,0x6aa9120b,0xdd9001ee,0x00000000}},	//   گاپو, _vaff, _ваєы, --, 
   {{0x6aa9120c,0xf12401ec,0x00000000,0x00000000}},	//   _waff, ндiк_, --, --, 
   {{0xd7fc00c6,0x6aa9120d,0xa498007f,0x64400034}},	//   мσѕ_, _taff, _djòl, śnik, 
   {{0x38700363,0x6aa807c5,0x00000000,0x00000000}},	//   _edyr_, _uaff, --, --, 
   {{0xa8500032,0x2d8c030a,0x298400db,0x96a4000d}},	//   _кейә, ntfe_, _рылг, _ओसरउ, 
   {{0x7bcc0129,0xa7f800e8,0x00000000,0x00000000}},	//   _àauc, nañk, --, --, 
   {{0x3948151c,0x534400c7,0xd7c800aa,0x2d8c037e}},	// [193d0] _časi_, ахха, _لويه_, htfe_, 
   {{0x247007ae,0x227401c8,0x00000000,0x00000000}},	//   ệm_, ئلاگ_, --, --, 
   {{0x45d5120e,0x7afd120f,0x72e40014,0x00000000}},	//   _сонс, ésti, ھہہِ_, --, 
   {{0x81d40349,0x80b80011,0xd04006be,0x00000000}},	//   িছল_, _আতঙ্, _komə, --, 
   {{0x74780302,0x7f1802d5,0xfff801d5,0x00000000}},	//   _אנרג, ніку_, رکرت_, --, 
   {{0x38b80724,0x3b8401d5,0x918400db,0x00000000}},	//   _kürä_, ҳлиг, _چۇلۇ, --, 
   {{0xa0a40124,0xfaa51210,0x1ee51211,0x00000000}},	//   _ишал, қано, _یوری_, --, 
   {{0xd0d400a7,0x3b8401a9,0x00000000,0x00000000}},	//   _косъ, глиг, --, --, 
   {{0x69cc0724,0xdb0800e4,0x644c010a,0x00000000}},	//   äben, _argá, _mfci, --, 
   {{0x6ca400db,0x6ba4010e,0x00000000,0x00000000}},	//   _ۅلمۅ, _şugü, --, --, 
   {{0x644c01ab,0xddc00118,0xeba80174,0x00000000}},	//   _ofci, manů, trøð_, --, 
   {{0xdce4005f,0xbec400e2,0x00000000,0x00000000}},	//   ēlēj, _dvīņ, --, --, 
   {{0x8cc0687b,0xd04006be,0xc0c80023,0xeba80162}},	//   वारो, _comə, _ጠቓሚ_, rrøð_, 
   {{0xa49801e1,0xc9d403e6,0xdb0801ef,0xeba80162}},	//   _ikòy, امێک, _frgá, srøð_, 
   {{0x5ebc0011,0xda0801f9,0x62f800eb,0x00000000}},	//   ্সপে, _सुचत_, ্তায়_, --, 
   {{0x30ac00bd,0x79811212,0x38700158,0x3788009b}},	//   _কক্স, mulw, _udyr_, _збио_, 
   {{0x290000bc,0x69cc08cb,0xf7440108,0xbec40171}},	// [193e0] čkat_, øbev, _щепо, _zvīņ, 
   {{0xc7640131,0x7bd000cc,0xfaf800c0,0x00000000}},	//   _ئايى, _তেৱো, msūs_, --, 
   {{0x79811213,0x776006be,0xfaf80064,0x00000000}},	//   nulw, _çoxb, lsūs_, --, 
   {{0xdce00024,0x00000000,0x00000000,0x00000000}},	//   munė, --, --, --, 
   {{0x79801aa1,0xa3a8012d,0x802400d1,0x00000000}},	//   hulw, _कैप_, ۇرۇم, --, 
   {{0x7980bf45,0x71651214,0xad240133,0x00000000}},	//   kulw, _مارك, گرتو, --, 
   {{0x7d0c23e2,0x236401fa,0x798071aa,0x8cc0445f}},	//   časn, ćnje_, julw, वालो, 
   {{0x79811215,0x2d8c054e,0xad2405af,0x61d4011a}},	//   dulw, rtfe_, درتو, _גולף_, 
   {{0x09dc0b9c,0x2d8c0165,0x28ac007a,0x00000000}},	//   मन्य, stfe_, _जोगि, --, 
   {{0xa3a907c7,0x798042fc,0xee38003b,0x00000000}},	//   _कैफ_, fulw, _знз_, --, 
   {{0x6c841d57,0x79811216,0x88580353,0xfaf800c0}},	//   _ملام, gulw, кинс_, esūs_, 
   {{0x28ac084a,0xab840139,0xe7851217,0xba1800ec}},	//   _जोखि, _букк, луго, ئيٽا_, 
   {{0x38b80a43,0x00000000,0x00000000,0x00000000}},	//   _sürä_, --, --, --, 
   {{0x79811218,0x9f4803cd,0xa7f8002e,0x06ac00eb}},	//   bulw, _åmås_, nañi, খাভি, 
   {{0x79803758,0xd6d80276,0x3b68001f,0x7afd1219}},	//   culw, утя_, _ሰነዶች_, èste, 
   {{0x69d9121a,0x5ac400d1,0xa7f80113,0xca380115}},	//   myte, _аләм_, hañi, leĝo_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [193f0] --, --, --, --, 
   {{0x569407d5,0x69d800ad,0x38b8013d,0xa22400ec}},	//   _лаьт, oyte, _türä_, هراه, 
   {{0x69d9121b,0x2b45121c,0x00000000,0x00000000}},	//   nyte, _luoc_, --, --, 
   {{0xb9d0001f,0xca3801e4,0x776003b9,0xc48400cf}},	//   _ቴዲ_, heĝo_, _çoxc, _өлүк, 
   {{0x7980136f,0x2b44001e,0x69d9121d,0x1e700417}},	//   zulw, _nuoc_, hyte, йғас, 
   {{0x6fb4039b,0xf2c00032,0x7980f29a,0x69d80b2c}},	//   шҳур_, _мөхи, yulw, kyte, 
   {{0x81d401c6,0x69cc0036,0x5224014b,0x69d800c0}},	//   _товх, äbel, _гфта, jyte, 
   {{0x69d9121e,0x6f180083,0x2488013c,0x7d0d121f}},	//   dyte, _ektc, _jccm_, časo, 
   {{0xacc40e26,0x79811220,0xa7f91221,0x2b44001e}},	//   ргыз_, wulw, bañi, _cuoc_, 
   {{0x2b440016,0xf8dc0316,0xa7f804d4,0x79811222}},	//   _duoc_, मस्प, cañi, tulw, 
   {{0x8a381de1,0x213c03a2,0x977439c7,0xbd840131}},	//   ляют_, _kiuh_, әтмә, _ئەبۇ_, 
   {{0xa4980100,0x201c0139,0x7980002e,0x6ca400db}},	//   _djòk, _kyui_, rulw, _ۅلۅۅ, 
   {{0x3948389e,0xf7449db1,0x81bc015b,0x79811223}},	//   _času_, рего, েনি_, sulw, 
   {{0xd04002ea,0x69d91224,0x213c0007,0x26d00077}},	//   _bomɛ, byte, _liuh_, _coxo_, 
   {{0x79811225,0x69d8e9d7,0x7afc0c6a,0x29000010}},	//   qulw, cyte, éstu, čkar_, 
   {{0x81bc00bd,0x00000000,0x00000000,0x00000000}},	//   েনা_, --, --, --, 
  
   {{0x26d00429,0xe8c400a7,0xa34401d5,0x234800f2}},	// [19400] _foxo_, _ъгъл_, изта_, نسلی_, 
   {{0x26d0009d,0xdb1c0066,0xa6e0004e,0x00000000}},	//   _goxo_, èwèn, _мжыл, --, 
   {{0x720424e0,0x612000c5,0x63b808a5,0x00000000}},	//   جوام, põll, _áunn, --, 
   {{0xe7b0d37d,0x213c0007,0xa7f802d1,0xf158035b}},	//   _امید, _ciuh_, wañi, еиҧш_, 
   {{0x213c003e,0xa7f904d9,0x26d000e8,0x69d91226}},	//   _diuh_, tañi, _yoxo_, zyte, 
   {{0x26d0bea3,0x2b451227,0x69d8023a,0x00000000}},	//   _xoxo_, _ruoc_, yyte, --, 
   {{0x6da4052f,0x6d480007,0x2b440165,0x21651228}},	//   рҙең_, uqfa, _suoc_, _виси_, 
   {{0x69d91229,0x61401d0f,0x00000000,0x00000000}},	//   vyte, _фета, --, --, 
   {{0x2b44001e,0xa7f8005a,0xceb83c1a,0xe0d46031}},	//   _quoc_, pañi, _бәй_, _твт_, 
   {{0x69d9122a,0x2b4405c7,0x7bd400e4,0x0a3401f3}},	//   tyte, _vuoc_, _ũguá, _ባሕርያ, 
   {{0x26d0d02b,0xca380115,0x20d403b9,0x00000000}},	//   _roxo_, reĝo_, _içir_, --, 
   {{0x9875122b,0xdcac04a9,0x394807f5,0xca3801e4}},	//   олюц, _يىل_, _čast_, seĝo_, 
   {{0x69d8035b,0x6bd801d9,0xd7f846eb,0x00000000}},	//   syte, _جوشس_, аур_, --, 
   {{0x69d8035b,0xd7f8782a,0x2488b450,0x69cc005c}},	//   pyte, рую_, _sccm_, øbes, 
   {{0x69d802d3,0x9aa005d9,0xddc00311,0x00000000}},	//   qyte, _ذميو, manţ, --, 
   {{0xdb082155,0xddc00276,0x9a38011a,0x00000000}},	//   _ergä, lanţ, _בתוק, --, 
   {{0x213d122c,0xc298e9e0,0x26d00005,0x4274694c}},	// [19410] _riuh_, лках_, _toxo_, йгас, 
   {{0xddc0084c,0x248802c4,0x213d122d,0x2d9ca37d}},	//   nanţ, _wccm_, _siuh_, _opte_, 
   {{0x6120000d,0x00000000,0x00000000,0x00000000}},	//   sõlm, --, --, --, 
   {{0x112800d6,0x00000000,0x00000000,0x00000000}},	//   аючи_, --, --, --, 
   {{0x2d9d122e,0xa7f80227,0x69cc01b8,0x213c000d}},	//   _apte_, rañw, äbej, _viuh_, 
   {{0x3ae80030,0xbea406b4,0x9758010f,0x00000000}},	//   _kúpe_, сакк, סיוו_, --, 
   {{0xddc0054e,0x23bc00b5,0xa7900432,0x00000000}},	//   danţ, のjb_, lýäň_, --, 
   {{0xc1044d49,0xa7f8002e,0x3d20033f,0x00000000}},	//   _اوري, lañu, मतें_, --, 
   {{0x201c01f7,0xddc00356,0x00000000,0x00000000}},	//   _uyui_, fanţ, --, --, 
   {{0xe8f003bd,0x389c04fe,0x7bc80077,0xd010004b}},	//   _བཏུབ_, _mārō_, rxeu, _ځلې_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7f400009,0xa79000a2,0x00000000,0x00000000}},	//   _hilq, kýäň_, --, --, 
   {{0xe8f5122f,0x69cc037e,0xddc0054e,0xa7f80156}},	//   сля_, øber, banţ, zañv, 
   {{0xbb2c6788,0xddc0084c,0x7f400003,0xa790010e}},	//   ﯩﺮﻯ_, canţ, _jilq, dýäň_, 
   {{0x7f400135,0xdbd400e4,0x00000000,0x00000000}},	//   _milq, päóp, --, --, 
   {{0x39911230,0x225c0841,0x98a80055,0x7534009d}},	//   más_, _đuka_, _munī_, сэгх, 
   {{0x399000f8,0xa3a805d7,0x7f480194,0x52586923}},	// [19420] lás_, _कैद_, _nueq, لساڭ_, 
   {{0x7b1c0137,0x7f411231,0xa7f80156,0x78a51232}},	//   cèut, _nilq, tañv, lekv, 
   {{0x39911233,0x20d406be,0xa49801e1,0x7d0c0010}},	//   nás_, _açiq_, _njòw, časj, 
   {{0xdfcd1234,0xddc0054e,0x3d20033f,0x216468d9}},	//   کيه_, zanţ, मतों_, сици_, 
   {{0x7f411235,0x43751236,0x930400c7,0x2d9c0010}},	//   _bilq, _мурт, _дҟал, _spte_, 
   {{0x39911237,0xa7f8867c,0x828002dd,0x6798010f}},	//   kás_, mañt, _оқуд, רױסג, 
   {{0x7f40014f,0x399001ed,0xddc00311,0x78a4143a}},	//   _dilq, jás_, vanţ, kekv, 
   {{0x3990066d,0xcb54026a,0xc1800014,0xfcc002d9}},	//   dás_, овић, _زیٖٹ, дәшм, 
   {{0xddc000a8,0x7f40011f,0x20d4452e,0x20c00166}},	//   tanţ, _filq, _içip_, _эйтм, 
   {{0x4974b280,0x399001f6,0x9bf073c7,0x8af8ede6}},	//   олос, fás_, языч, рнос_, 
   {{0xddc0084c,0x09d004c5,0x3990ba3b,0xee3800ee}},	//   ranţ, ানভা, gás_, _ёне_, 
   {{0xe8e80a12,0x7f480113,0x78a47f4f,0xddc00356}},	//   اردو_, _yueq, gekv, sanţ, 
   {{0x6c342444,0x29141c5c,0xddc11238,0x7f4001a9}},	//   _افشا, ﻳﯩﭗ_, panţ, _yilq, 
   {{0x6d4006c8,0x399000dd,0xddc001fa,0x8cc00316}},	//   _hioa, bás_, lanš, वाको, 
   {{0x9af80375,0xb5cc0183,0xa504515c,0x78a4022e}},	//   _תפוח, _ৱেবচ, مىسە_, bekv, 
   {{0xddc000da,0x389c02b5,0x6d40062c,0xd1240a81}},	//   nanš, _pārō_, _jioa, _سۅ_, 
   {{0x6d411239,0x7b1c4b84,0x5f1800cd,0x00000000}},	// [19430] _mioa, pèut, मकम्_, --, 
   {{0x6d400731,0x3ae80241,0x00000000,0x00000000}},	//   _lioa, _túpe_, --, --, 
   {{0x1a9800c8,0x7f48004e,0xa7f803f0,0x5184020f}},	//   ריבע, _sueq, rañu, зуча, 
   {{0xddc0151c,0x4f5402d3,0x1afc0154,0xd38c02dd}},	//   janš, _ዝተዘር, _উঠছে_, _ﯗﻗﯩﻖ_, 
   {{0x3990066d,0x22bc0db6,0xa7f9123a,0x7f48003a}},	//   zás_, _pākē_, pañu, _queq, 
   {{0x6d400418,0x7f400bc9,0xc2c42e6f,0x7f480036}},	//   _aioa, _qilq, _بيسي, _vueq, 
   {{0x6d41123b,0x99840cf4,0x39900798,0xdce800d7}},	//   _bioa, _žižu_, xás_, žičt, 
   {{0x6d41123c,0x63b8003d,0x7f400784,0x399001ed}},	//   _cioa, _ġunj, _wilq, vás_, 
   {{0x6ab0045e,0x6d40000f,0x6d4c1a06,0x78a401ed}},	//   জানো, _dioa, _éban, vekv, 
   {{0x3991123d,0x7aa42b97,0x543c010f,0x61200254}},	//   tás_, циоз, נעזא, dõli, 
   {{0x75340209,0x6d41123e,0x78a405ac,0xa7f9123f}},	//   ymyz, _fioa, tekv, kañs, 
   {{0x6d400363,0x00000000,0x00000000,0x00000000}},	//   _gioa, --, --, --, 
   {{0x39911240,0x78a4fef4,0x3cec0fac,0xa7f8002e}},	//   sás_, rekv, mhev_, xañt, 
   {{0x78a4f1e4,0x6d4001c4,0x399001ed,0x00000000}},	//   sekv, _zioa, pás_, --, 
   {{0x7d091241,0xba38008f,0x63ac01e7,0x00000000}},	//   ones, _דײַט, _ascn, --, 
   {{0x798001af,0xe8fc003a,0xa7f805c7,0x61200254}},	//   mrlw, ciû_, gañs, bõli, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [19440] --, --, --, --, 
   {{0x7d091242,0xcc9000b8,0x95b401ee,0x00000000}},	//   hnes, _hṛte_, _ермә, --, 
   {{0x7d091243,0xa7f80165,0xddc00113,0x9524dd55}},	//   knes, bañs, yanš, _فکرم, 
   {{0x7d091244,0xa99800c8,0x2998010f,0x00000000}},	//   jnes, יבער, יסעמ, --, 
   {{0xddc0009b,0x86e8583d,0x628000d0,0x102401d3}},	//   vanš, _ضعیف_, ónoc, سکرپ, 
   {{0x7aec0652,0x7d091245,0x6d4003a0,0xddc00309}},	//   _ïath, enes, _sioa, wanš, 
   {{0x30741b74,0x7bdc0158,0x9e300006,0x00000000}},	//   _муас, øsun, мешч, --, 
   {{0x61e0022c,0x80c00b26,0x00000000,0x00000000}},	//   ønle, _रोपे, --, --, 
   {{0x6d411246,0x81bc0154,0x9c340395,0x00000000}},	//   _vioa, েনঃ_, опът_, --, 
   {{0x6da4deea,0x1e800cdd,0xada51247,0xddc00010}},	//   _миза, _олум, _мазл, sanš, 
   {{0x6d411248,0x0ef81d8a,0xcdc400d1,0x7d08014f}},	//   _tioa, ्चीस_, _хәлп, bnes, 
   {{0xeb980b46,0x6d591249,0x3ced124a,0x7d09124b}},	//   _вид_, _itta, chev_, cnes, 
   {{0x776000ac,0x04880032,0xec1400db,0xa7f80165}},	//   _çoxl, ҙәни_, _بوشد, vañs, 
   {{0x79cc0046,0x00000000,0x00000000,0x00000000}},	//   _ﯗﻳﯩﻤ, --, --, --, 
   {{0xd5b8ee8b,0x06ac0729,0xee2c109a,0x45d40798}},	//   ост_, খালি, ннi_, човс, 
   {{0xb3d404c5,0xd910065f,0x61200254,0x7bdc000d}},	//   _সেইজ, _لیپ_, põli, äsug, 
   {{0xa7f9124c,0x73c00cef,0x3ae800e4,0x7538381a}},	// [19450] rañs, нәре, _húpa_, ïtza, 
   {{0x6d59124d,0x7d0c01f1,0x3ae801f1,0xa7f8030a}},	//   _otta, časi, _kúpa_, sañs, 
   {{0x6d580083,0x00000000,0x00000000,0x00000000}},	//   _ntta, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7d0817c1,0x6d59124e,0x4abc01bc,0xf0780075}},	//   vnes, _atta, ्ञाव, сичә_, 
   {{0xd13010a8,0x7d08232c,0x00000000,0x00000000}},	//   ىمە_, wnes, --, --, 
   {{0x7aec03a2,0xb8fc0135,0x6d4c02ea,0xc0c409a5}},	//   _ïati, _ལྭ_, _ébal, _нәди, 
   {{0x7d0807de,0x290800f3,0x3cc80063,0xba8000d1}},	//   unes, jnca_, слио_, ﯩﺪﻩﻙ_, 
   {{0x6d582f99,0x3ae80789,0x79800368,0x7d08f685}},	//   _etta, _aúpa_, wrlw, rnes, 
   {{0x7d09124f,0x29091250,0x3cec01b9,0x1cdc0327}},	//   snes, enca_, shev_, ཤིང_, 
   {{0x499000dd,0x3a2416ab,0x4e9407d6,0x7d080076}},	//   نیور, ямог, _تشقر, pnes, 
   {{0x0d8456a4,0x7d08014f,0x80c006e3,0x00000000}},	//   _ілін, qnes, _रोमे, --, 
   {{0xa3a800ab,0xeb500137,0xcc9000b8,0x7bdc0254}},	//   _कैल_, _كۉيگ, _vṛte_, äsud, 
   {{0x29091251,0x68ec01ab,0x6d591252,0xfd4800b8}},	//   anca_, ahcd, _ytta, _sumṛ, 
   {{0x65c0188b,0xe45c007c,0x1fc00154,0x00000000}},	//   нбра, _snöa_, ্নিস, --, 
   {{0xc044021a,0x00000000,0x00000000,0x00000000}},	//   _لږ_, --, --, --, 
   {{0xb38400fb,0x661803e0,0x00000000,0x00000000}},	// [19460] ялал, ğuka, --, --, 
   {{0x1ca80135,0x78b51253,0xb3d403d4,0xf1d0045c}},	//   _བྲལ_, _hayv, _সেউজ, нөбө, 
   {{0x78b402ac,0x00000000,0x00000000,0x00000000}},	//   _kayv, --, --, --, 
   {{0x6d58c113,0x00000000,0x00000000,0x00000000}},	//   _rtta, --, --, --, 
   {{0x9f500006,0x78b40051,0x00000000,0x00000000}},	//   евіч, _mayv, --, --, 
   {{0xb8cc2fb5,0x78b401a9,0xc32c00d1,0xdc780092}},	//   _པི_, _layv, _نەق_, _ተቀማጭ_, 
   {{0xde700372,0x48fc0037,0x21a01171,0xe1f41d4a}},	//   ردوع, _लगलो_, _пирм, _егр_, 
   {{0xdc10825f,0xd1740184,0xf8ac04c5,0x63b80006}},	//   _aşır, _нығы, গাঁথ, _šuni, 
   {{0x3ae808a5,0x6f640244,0x00000000,0x00000000}},	//   _súpa_, _رهام, --, --, 
   {{0xd9540020,0x1af0b93d,0x3ae80332,0x00000000}},	//   _የተዘጋ, епья, _púpa_, --, 
   {{0x6d591254,0x6f9c01ec,0x00000000,0x00000000}},	//   _utta, _ﺍﻴﻀﺎ_, --, --, 
   {{0x2908060a,0xada4016c,0x1ca80327,0x00000000}},	//   unca_, _маҷл, _བིར_, --, 
   {{0x78b40109,0x612000c5,0x0a951255,0xf8ac0811}},	//   _dayv, põlv, _жалю, شکي_, 
   {{0x96d803f3,0x63b80077,0x99440451,0x5b780a7c}},	//   नॉलॉ, _áuni, _کليل_, _פרוא, 
   {{0x95c886de,0x1a991256,0x5a9802e4,0x00000000}},	//   пута_, _ליגע, _השוא, --, 
   {{0x78b4010a,0x6a8001e1,0xf95800e5,0x7bd002d2}},	//   _gayv, _fífà, _بسوں_, _ökuþ, 
   {{0x31680d27,0x1ca80327,0x249c00e8,0x4ae000c5}},	// [19470] _awbz_, _བྲས_, _ñumm_, _पकाव, 
   {{0xe664040e,0x00000000,0x00000000,0x00000000}},	//   _этио, --, --, --, 
   {{0x9b140375,0x78b40205,0xa058007b,0x680c00b8}},	//   לחמה_, _yayv, مؤشر_, _ṛdhn, 
   {{0x78b45b7f,0x00000000,0x00000000,0x00000000}},	//   _xayv, --, --, --, 
   {{0xaf440014,0x00000000,0x00000000,0x00000000}},	//   ژرى۪, --, --, --, 
   {{0x10151257,0x61200254,0x00000000,0x00000000}},	//   ربند, võlu, --, --, 
   {{0xcd3c040d,0x51851258,0xa498067c,0xd658011a}},	//   ﻧﻨﯩﯔ_, _пута, _imòb, היות_, 
   {{0xde2402d3,0xada001b9,0x995401ef,0x00000000}},	//   _ስንክል, таъл, _náše_, --, 
   {{0x2d8804ce,0x78b40946,0xdef80108,0x00000000}},	//   _åben_, _rayv, _лыж_, --, 
   {{0xbb24040d,0x60d91259,0x7f4c004e,0xce940395}},	//   ﻠﯩﻢ_, _houm, íaqu, _пауъ, 
   {{0x60d8406e,0x78b401d5,0x4ea40408,0x00000000}},	//   _koum, _payv, _ярта, --, 
   {{0xe45c01e6,0x60d8033b,0xae18010f,0x00000000}},	//   _snön_, _joum, _וועכ, --, 
   {{0x60d9125a,0x00000000,0x00000000,0x00000000}},	//   _moum, --, --, --, 
   {{0x60d9125b,0x35c800db,0x00000000,0x00000000}},	//   _loum, огго_, --, --, 
   {{0x78b5125c,0xcc900055,0x00000000,0x00000000}},	//   _tayv, _kṛpe_, --, --, 
   {{0x60d9125d,0x1ca8025c,0x64a05bc6,0x6d5c0115}},	//   _noum, _བིས_, каса, ŭpag, 
   {{0xa505125e,0xaac001ad,0x12c40022,0x00000000}},	// [19480] фета_, _वोडक, ниаҟ, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x60d9125f,0xe45c01e3,0x00000000,0x00000000}},	//   _boum, _knöl_, --, --, 
   {{0x61e11260,0x60d807ab,0xcc9000b8,0x69bc28e0}},	//   ønla, _coum, _nṛpe_, षिती, 
   {{0x1ca80135,0xff24037e,0x61200254,0x00000000}},	//   _བྲེ_, _suuな, võlt, --, 
   {{0x20501206,0x00000000,0x00000000,0x00000000}},	//   нтәр, --, --, --, 
   {{0x60d802e2,0x00000000,0x00000000,0x00000000}},	//   _foum, --, --, --, 
   {{0x60d91261,0x40940f06,0x00000000,0x00000000}},	//   _goum, _прут, --, --, 
   {{0x2aa8aa52,0xdca00063,0x614001e1,0x09b82c2e}},	//   отно_, тањи, _wìlì, ेम्य, 
   {{0x60d80a40,0x612000c5,0xee380212,0x00000000}},	//   _zoum, sõlt, _днз_, --, 
   {{0x6d5d1262,0x60d91263,0xdd8c01f7,0x00000000}},	//   ípad, _youm, _نول_, --, 
   {{0xdccc0208,0xab8400cf,0x00000000,0x00000000}},	//   _hỉnh_, _жукк, --, --, 
   {{0x274802bf,0x995402f0,0xdca0399f,0xdccc0208}},	//   ючно_, _váše_, _јачи, _kỉnh_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x442c4859,0xc0c0044e,0x69cc33b8,0xdccc0051}},	//   _še_, _ጻዕሪ_, åbed, _mỉnh_, 
   {{0x28740032,0xdccc0208,0x6ab8005c,0xeb18009f}},	//   _юҡмы_, _lỉnh_, ldtf, _ارچڪ_, 
   {{0xe66461ff,0x60d91264,0x83340354,0x00000000}},	// [19490] _отно, _roum, енах, --, 
   {{0x60d91265,0x26a40150,0x02c800bc,0x3f9800de}},	//   _soum, _تۇسپ_, राइभ, _īsu_, 
   {{0x60d91266,0xd2440276,0xe794004b,0x6d4c0129}},	//   _poum, вэци, _راښک, _ébah, 
   {{0x567c1772,0x63b800a2,0x00000000,0x00000000}},	//   _እምነቱ_, _šunu, --, --, 
   {{0x3f691228,0x60d91267,0xdccc004d,0x3ea400c7}},	//   чило_, _voum, _bỉnh_, еилг, 
   {{0x60d91268,0x7db40395,0x00000000,0x00000000}},	//   _woum, есиц, --, --, 
   {{0xbd440617,0x1ca8031c,0x52240117,0xaad0095f}},	//   ىپتى, _བྲུ_, _афта, तानक, 
   {{0x3ae801e1,0x00000000,0x00000000,0x00000000}},	//   _púpo_, --, --, --, 
   {{0x8e7c00df,0x00000000,0x00000000,0x00000000}},	//   _alĝu, --, --, --, 
   {{0x63b80162,0x776003b9,0x8d740133,0x00000000}},	//   _áunu, _çoxi, _ڤالا, --, 
   {{0x5c9000a8,0x8b6401d5,0x59b0009d,0x00000000}},	//   _алеӂ, _یاوم, төлс, --, 
   {{0x8d8401c0,0xa3dc0b7d,0x66180790,0xbb740395}},	//   _шууд, तहा_, ğukl, _зукъ, 
   {{0xe5a004a9,0x87b8f5ed,0x00000000,0x00000000}},	//   һири, мурт_, --, --, 
   {{0xf624009b,0x41b0000d,0x00000000,0x00000000}},	//   едго, ीटास, --, --, 
   {{0xe5a049c6,0x13c91269,0xa2c009b4,0xa92000d0}},	//   лири, रम्भ, रयन्, šľaj, 
   {{0xd0400085,0x3864010e,0x23240022,0x00000000}},	//   _komɔ, _ýor_, ҵоуи_, --, 
   {{0xf6740120,0x00000000,0x00000000,0x00000000}},	// [194a0] _пунџ, --, --, --, 
   {{0xd5b01973,0x3871126a,0x7afc020c,0x63b80327}},	//   _پہر_, _heyr_, èsth, _ġunt, 
   {{0x70840724,0x63b80113,0xef1829dc,0xdccc0051}},	//   егез, _šunt, үме_, _rỉnh_, 
   {{0x7cf50ed8,0xdb09126b,0x00000000,0x00000000}},	//   _hárf, _argü, --, --, 
   {{0xd5c400b8,0xce94011c,0x00000000,0x00000000}},	//   bhāþ_, валъ, --, --, 
   {{0x73340372,0x2bb4000d,0x26140073,0x00000000}},	//   _سىزا, _अनबा, पॅकी_, --, 
   {{0x427000d1,0x80c00037,0x00000000,0x00000000}},	//   _ﺷﯘﻧﭽ, _रोवे, --, --, 
   {{0xd040043b,0x6141126c,0x13e4015b,0xdb082ca8}},	//   _bomɔ, _беса, _নেয়, _ergü, 
   {{0xdccc07ae,0xeb04524d,0x3ce0007d,0xceb802dd}},	//   _tỉnh_, ечно, _ओकरे_, _жәй_, 
   {{0x29840f15,0x00000000,0x00000000,0x00000000}},	//   нымг, --, --, --, 
   {{0x6ab802fa,0x236401fa,0x22f40375,0xdb08007b}},	//   rdtf, ćnji_, גזין_, _argó, 
   {{0x38700067,0x201401e7,0x47d401f7,0xf1240150}},	//   _ceyr_, _ídiú_, نيجر, мдiк_, 
   {{0xdcac1b16,0x3871126d,0xd83801c6,0x57a4009d}},	//   _دىن_, _deyr_, еэр_, лшра, 
   {{0x75240036,0xa3a80210,0x00000000,0x00000000}},	//   _akkz, _कैग_, --, --, 
   {{0x62802b76,0x2d8c0421,0xe3b0210e,0x00000000}},	//   ónom, nufe_, گرز_, --, 
   {{0xd1f82e1f,0x3871126e,0x98a40114,0x00000000}},	//   ዊነት_, _geyr_, _биће, --, 
   {{0x2d8d126f,0x47351270,0xa7e0010b,0x7bcc0129}},	// [194b0] hufe_, _инис, _сөнҗ, _àaut, 
   {{0x2d8d1271,0x27f000fd,0x63b80064,0x00000000}},	//   kufe_, ınnı_, _šuns, --, 
   {{0xc61801c6,0x7afc359e,0xfccc0023,0x00000000}},	//   _цонх_, èsti, _እዝጊ_, --, 
   {{0x7bcc0077,0x8e7c010f,0x387000ac,0x00000000}},	//   _áaug, _loĝd, _xeyr_, --, 
   {{0x644c4b26,0x7cf401a8,0x58f8010f,0x518401e0}},	//   _igci, _hárg, עמדע_, _ҙура, 
   {{0xafe11272,0xbea51273,0xf7840139,0x00000000}},	//   рошл, такк, _äçen_, --, 
   {{0x776006be,0x523401af,0x5dc02309,0x00000000}},	//   _çoxv, _берѓ, امبە, --, 
   {{0x09e400bd,0x7cf43eba,0xdbdc01e1,0xdec80023}},	//   _ফেভা, _márg, _fììm, ቢቕካ_, 
   {{0x644c0b6f,0x3af40024,0x387002d2,0x00000000}},	//   _mgci, вянс, _reyr_, --, 
   {{0x1cb00489,0xdb08067c,0x38701368,0xfaa4033a}},	//   _ཞལམ_, _argò, _seyr_, њано, 
   {{0x644c1cdf,0x7bcc0024,0x3ea00037,0x46d42c2e}},	//   _ogci, _šaud, õhtu_, दानह, 
   {{0x644c01e2,0xf1b0008f,0x3870679e,0x7cf41463}},	//   _ngci, בסט_, _qeyr_, _sárf, 
   {{0x1ca808ea,0xe8f4c1ca,0x307800df,0xeaac9665}},	//   _བྲག_, тля_, וארנ, _кй_, 
   {{0x644c2747,0xba7402de,0x2bdc00bc,0x47e000cc}},	//   _agci, _شاتت, गहरू_, _পেহী, 
   {{0x7cf51274,0x66011275,0x00000000,0x00000000}},	//   _várf, апра, --, --, 
   {{0x56f400f7,0x69d80073,0x09a800cc,0x00000000}},	//   түүс, _पॅटी, _ওপচা, --, 
   {{0x95b40116,0x3ce80037,0xe7b00066,0x00000000}},	// [194c0] _өрнә, _जवने_, _نميد, --, 
   {{0x39480232,0x644c6f4f,0x81dc02f5,0xf7447401}},	//   _časy_, _egci, _তেই_, _шепо, 
   {{0x765c014b,0x7cf404d4,0x00000000,0x00000000}},	//   _ifpy, _gárg, --, --, 
   {{0x2164094c,0x09e40011,0xf8b0033f,0x41b40006}},	//   тици_, _ফেডা, ज़िय, ысут, 
   {{0xa8540302,0x60202140,0x8e7c008f,0x2d8c009a}},	//   דינה_, адца, _loĝe, wufe_, 
   {{0x2d8d1276,0xa3a80034,0x255c063f,0x77600213}},	//   tufe_, _कैट_, ọlet_, _çoxu, 
   {{0xe2940323,0x06ac0154,0xdee00114,0x224400f3}},	//   _шар_, খাচি, роји, _апри_, 
   {{0x3ea4000f,0x61e0ea10,0x2d8c03fa,0xbd540271}},	//   _eblt_, änle, rufe_, دروژ, 
   {{0x46d406ff,0x3f9c0210,0x00000000,0x00000000}},	//   दामह, ctwu_, --, --, 
   {{0xdb2006ea,0x2ac40640,0xdfcc007b,0x00000000}},	//   ørði, тљив, _بيك_, --, 
   {{0xa2c00846,0x98a80166,0x6b84036b,0x5a308271}},	//   रयत्, _atnı_, رشکل, иньт, 
   {{0x7cf51277,0xa4980109,0x3ea808a4,0x00000000}},	//   _cárd, _amòn, đate_, --, 
   {{0x7cf401ed,0x98040209,0x1dc001c6,0xdce00139}},	//   _sárg, аярд, _бөөн, ctnı, 
   {{0xdb0405da,0x00000000,0x00000000,0x00000000}},	//   ôlôj, --, --, --, 
   {{0x7afc0221,0x5ebc0154,0x00000000,0x00000000}},	//   ëste, ্সচে, --, --, 
   {{0x6d4c07ea,0x63b80784,0x7cf51278,0xb4b40131}},	//   _ébau, _šunq, _várg, лисә, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [194d0] --, --, --, --, 
   {{0x7cf400dd,0xd250005e,0x45d409a0,0xe72401af}},	//   _tárg, ەنە_, _боос, _шєйн, 
   {{0x22451279,0x2ca4036b,0x09d00eac,0x7cf402d2}},	//   änk_, _obod_, ানকা, _háre, 
   {{0x644c136f,0xb50001ad,0xccf80118,0x00000000}},	//   _ugci, रोदय_, _stěn_, --, 
   {{0x1e7002dd,0xc1740133,0xe45c007c,0xa3a803ce}},	//   иғас, _ڕیاڵ_, _ifö_, _कैच_, 
   {{0x1ca8025c,0x00000000,0x00000000,0x00000000}},	//   _བིང_, --, --, --, 
   {{0xdcec00f3,0xe45c007c,0x00000000,0x00000000}},	//   _žeđa, _kfö_, --, --, 
   {{0x8e7c0115,0x7bdc005b,0x00000000,0x00000000}},	//   _roĝe, äsuo, --, --, 
   {{0x7bcc00e2,0x705000f7,0x7cf400d0,0xe45c0205}},	//   _šaub, _اچما, _náre, _mfö_, 
   {{0x2ca4003e,0x3f580ba1,0x7cf40599,0xddc002fb}},	//   _ebod_, _ièu_, _sárd, manž, 
   {{0x8d75127a,0x7c94129e,0x3944034b,0x00000000}},	//   _نانا, _ملاص, лног, --, 
   {{0x17c4035b,0x5fc400bc,0xdcb800d4,0xbd00013a}},	//   аамҭ, लिपल, _іще_, _šéfe, 
   {{0x7d09127b,0x3cec0218,0x00000000,0x00000000}},	//   mies, mkev_, --, --, 
   {{0x3f58067c,0x7cf4012c,0xeb940166,0xe5a000d1}},	//   _mèu_, _dáre, _сиш_, әити, 
   {{0xe7340801,0x3f581497,0x7afc020c,0x6d4c0129}},	//   уер_, _lèu_, èstu, _ébat, 
   {{0x7d09127c,0x8cb800dc,0x29080066,0x7cf408ce}},	//   nies, ्ययो, ébat_, _hárb, 
   {{0x7cf5127d,0x3f58180f,0xe28005f5,0x18a40131}},	// [194e0] _kárb, _nèu_, өлти, _бақм, 
   {{0xe295127e,0x7d09127f,0x15b400cf,0x3244008e}},	//   лау_, hies, _پەرس, гезг, 
   {{0xea7400c8,0xb03004a9,0xdb08010e,0xcfa80154}},	//   רגער_, әмлә, _isgä, ওয়ান, 
   {{0x3f580ba1,0x3cec0070,0x7d091280,0x77600213}},	//   _bèu_, jkev_, jies, _çoxs, 
   {{0x3f58068c,0x3cec0010,0xddcc8256,0x7bdc1b99}},	//   _cèu_, dkev_, _češe, äsul, 
   {{0x3f580ba1,0x7cf400ae,0xd2040139,0xa06400fb}},	//   _dèu_, _nárb, _күзк, _ҡаса_, 
   {{0x7d091281,0xc32c00d1,0x00000000,0x00000000}},	//   fies, _غەم_, --, --, 
   {{0x7d091282,0x3f580ba1,0x3cec0218,0x71a400c7}},	//   gies, _fèu_, gkev_, _иаҳз, 
   {{0x7cf51283,0x3f58068c,0x25bc0421,0x2ca40010}},	//   _bárb, _gèu_, āuli_, _vbod_, 
   {{0x2ca40142,0x6cc40166,0x66180205,0x00000000}},	//   _wbod_, _әйда, şuki, --, 
   {{0x7d091284,0xc4c40154,0x6fc001f9,0xdce000ef}},	//   bies, _একসঙ, लिवू, gsnē, 
   {{0x7d091285,0x2ca51286,0x7cf40c5e,0xfca80769}},	//   cies, _ubod_, _páre, _لاهو_, 
   {{0x19a401ec,0xac081de6,0x00000000,0x00000000}},	//   _ұтып_, _янда_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d4c0798,0xaae4004b,0x29080129,0xa2c0043e}},	//   _ébas, _لسګو, ébas_, रयस्, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa7f80227,0x0354535f,0x58940137,0x43940395}},	// [194f0] jañx, рүгә_, _اجىز, разс, 
   {{0x7d091287,0xc86401b9,0xe4a40107,0x81dc00cc}},	//   zies, _ётқи, ърҳо, _তেগ_, 
   {{0x3f58067c,0x6724141e,0x45d51288,0x00000000}},	//   _sèu_, mojj, _тонс, --, 
   {{0x7cf400dd,0x43951289,0x3f58067c,0x6724141e}},	//   _márc, _камс, _pèu_, lojj, 
   {{0x7d09128a,0x3cec0218,0x36240014,0x6d5c765a}},	//   vies, vkev_, _مویہ, ípan, 
   {{0x7d09128b,0x2909128c,0xddc002f0,0x44385752}},	//   wies, hica_, ranž, _izs_, 
   {{0x7d09128d,0x90280588,0x6294009a,0xd34401ed}},	//   ties, кцәа_, mgxo, _اہلی, 
   {{0x3b84006c,0xe3bc0309,0x7d080607,0x6725128e}},	//   алиг, _ayñi_, uies, hojj, 
   {{0x7d09128f,0x3cec2753,0x69cc037e,0x7cf401d3}},	//   ries, rkev_, åben, _párb, 
   {{0x7d091290,0x62940928,0x7cf51291,0x6f08003a}},	//   sies, ngxo, _bárc, cifc, 
   {{0x7cf51292,0x7d091293,0x44380427,0xe9d4084c}},	//   _cárc, pies, _lzs_, акэ_, 
   {{0x44391294,0x7cf40118,0x00000000,0x00000000}},	//   _ozs_, _dárc, --, --, 
   {{0x44380010,0x95b402d9,0x27e80175,0x00000000}},	//   _nzs_, әргә, gycn_, --, 
   {{0x672404ba,0x29080311,0x3b080354,0x00000000}},	//   gojj, aica_, _шело_, --, 
   {{0x8e7c01e4,0xaad0db71,0xddc00153,0x06a000d1}},	//   _joĝa, तारक, manų, ﺍﺷﻠﯩ, 
   {{0x05540262,0x443805d5,0x74140c8b,0x94c8004b}},	//   стря, _bzs_, لوزا, داسې_, 
   {{0x73045e3e,0x8e7c04ac,0xa3e51295,0xe4540acf}},	// [19500] апаз, _loĝa, адта_, ржу_, 
   {{0x8ccc006d,0x44384b16,0x776006be,0x00000000}},	//   _दोनो, _dzs_, _çoxq, --, 
   {{0x44391296,0xf8d82cf5,0x00000000,0x00000000}},	//   _ezs_, _बचाय, --, --, 
   {{0x2bb4038e,0x61e11297,0x3124010b,0x06640cbb}},	//   _अनला, änla, шдег, _پایپ, 
   {{0x44380219,0x33d401ec,0x2e0c06be,0x00000000}},	//   _gzs_, _тінт, _səf_, --, 
   {{0x290800a8,0xdfcc0597,0x81dc02f5,0x3ae80030}},	//   zica_, بيه_, _তেও_, _kúpu_, 
   {{0x290801b2,0x44391298,0x80c087ee,0x00000000}},	//   yica_, _zzs_, _रोके, --, 
   {{0x29080f71,0x62800313,0x44380175,0x1ca80327}},	//   xica_, ónov, _yzs_, _བྲད_, 
   {{0x2eb51299,0x2f4800c7,0xaad00b98,0x7cf401e7}},	//   _всес, _апап_, तालक, _sárc, 
   {{0x2909129a,0x00000000,0x00000000,0x00000000}},	//   wica_, --, --, --, 
   {{0x7afc0af9,0xe45c007c,0xdbd40306,0x5c340023}},	//   ësta, _knöt_, rťác, _ብድፍረ, 
   {{0x8d75129b,0x61e0005c,0x2fc416a3,0x672404ba}},	//   _ناچا, ønli, ovog_, wojj, 
   {{0x79600374,0x67245f78,0x5c0000c0,0x00000000}},	//   _rēwe, tojj, _мяша, --, 
   {{0x6b808461,0x6f180076,0xe9e43cc5,0x7cf401d3}},	//   _ivog, _jjtc, _вцио, _tárc, 
   {{0x09e4015b,0x7cf42131,0x6724141e,0x44380010}},	//   _ফেরা, _hára, rojj, _szs_, 
   {{0x2fc41326,0x2909129c,0x7cf5129d,0x44380010}},	//   kvog_, qica_, _kára, _pzs_, 
   {{0x7cf4804d,0xe8c00073,0x776003b9,0xd838009d}},	// [19510] _jára, षयीच, _çoxp, _вээ_, 
   {{0x1ca80003,0x7cf42def,0x6724208d,0x58f4031c}},	//   _བྲན_, _mára, qojj, _བཞོས_, 
   {{0x81dc03d4,0xd25810cd,0x7cf5129e,0x6294002e}},	//   _তেজ_, рцу_, _lára, rgxo, 
   {{0x6b801326,0x4439129f,0x7bdc0037,0xddc0012d}},	//   _ovog, _tzs_, äsuk, ranż, 
   {{0x7cf46b07,0x25bc06c8,0x443801d5,0x6d5c01e4}},	//   _nára, āulu_, _uzs_, ŭpal, 
   {{0x26c00100,0x00000000,0x00000000,0x00000000}},	//   ndjo_, --, --, --, 
   {{0x6b8112a0,0x1ca80156,0x628512a1,0x6f1801a6}},	//   _avog, _བིད_, _idjo, _djtc, 
   {{0x7cf4110e,0x8e7c01e4,0x6b800010,0xdf800014}},	//   _bára, _voĝa, _bvog, _وُزی, 
   {{0x69c912a2,0xa2d8228a,0x09e4015b,0x6ab00154}},	//   _arfe, नाप्, _ফেলা, ড়ানো, 
   {{0x6b800552,0x7cf40ca8,0x6e380175,0x273c054e}},	//   _dvog, _dára, _fztb, nînd_, 
   {{0x6b8002d0,0x9ce40014,0x3948009d,0xdd98010a}},	//   _evog, _پوشے_, лзоо_, _шша_, 
   {{0x26d01709,0x7cf42a31,0x00000000,0x00000000}},	//   _anxo_, _fára, --, --, 
   {{0x69c912a3,0x2918022e,0x7cf402d2,0x3ae8032e}},	//   _erfe, _djqa_, _gára, _súpu_, 
   {{0xbb244da8,0x61f802a8,0x62840066,0xf7440fbe}},	//   ﻠﯩﻖ_, _ƙull, _ndjo, сего, 
   {{0xb9943fe2,0xa2d912a4,0x6b8112a5,0x69c80076}},	//   _العب, नान्, _zvog, _grfe, 
   {{0xf8c40122,0xa5042bbd,0x62842d61,0xf65000db}},	//   _šéfa_, беса_, _adjo, تئڭ_, 
   {{0x1ca8025c,0x7bdc005b,0x733483c9,0xb3c8035b}},	// [19520] _བིན_, äsuh, مىرا, ылаз_, 
   {{0xefd41b49,0x273c0356,0x69cc005c,0x3ae802d2}},	//   ራባዊ_, gînd_, æbeg, _túpu_, 
   {{0x46d400bc,0xd5a41bc6,0x81840014,0xded00240}},	//   दारह, _بلجی, ٲجمٕ, ራናን_, 
   {{0x213c014f,0x2fc405ce,0x61401e76,0x66180790}},	//   _chuh_, tvog_, пеха, ğukt, 
   {{0x213c00f2,0x7bcc0006,0x00000000,0x00000000}},	//   _dhuh_, _šaun, --, --, 
   {{0x273c054e,0xdc8401e0,0xcaac00cc,0x00000000}},	//   cînd_, ҡсыл_, _কোনফ, --, 
   {{0x6b805c7a,0x201c003a,0x7cf4e302,0xceb80064}},	//   _svog, _exui_, _sára, _skęs_, 
   {{0x213c014f,0xb11407d6,0x26c005be,0x7cf45821}},	//   _ghuh_, _اورغ, zdjo_, _pára, 
   {{0x6140074d,0x80d40073,0xeb480108,0x00000000}},	//   _хета, णारे, лчок_, --, 
   {{0x58f4025c,0x7cf401ed,0xdd7001d3,0xed58576f}},	//   _བཞུས_, _vára, _کھوک, _бож_, 
   {{0x1ca80135,0x2940001f,0x5e5450ea,0xee380064}},	//   _བྲམ_, _የሃይማ, _المس_, _снж_, 
   {{0x6b801505,0xdd8c00aa,0x6d5912a6,0x7cf43e33}},	//   _tvog, _سوه_, _iuta, _tára, 
   {{0x6d5850f9,0xd7f85c9c,0xc1a4102f,0xa2d8859c}},	//   _huta, бур_, _गङ्ग, नाम्, 
   {{0x7cf4fda8,0xd7f8f56c,0xc4c400fe,0x00000000}},	//   _járn, сую_, _একেজ, --, 
   {{0x6d583c41,0x26c07c74,0x69c912a7,0x8e7c00df}},	//   _juta, rdjo_, _urfe, _loĝo, 
   {{0x7cf400c6,0x2a7c00a3,0x41b40014,0xa2d800cd}},	//   _lárn, latb_, ۪مار, नाभ्, 
   {{0x273c054e,0x99d000f7,0xf8d400cd,0x00000000}},	// [19530] tînd_, _وقۇت, धारय, --, 
   {{0x6d580dd4,0x213c138f,0x7cf400d8,0x80c009ab}},	//   _outa, _shuh_, _nárn, _रोजे, 
   {{0x6d580680,0x213c06a3,0xa1840ede,0x41b44677}},	//   _nuta, _phuh_, сызл, تمار, 
   {{0x9998008f,0xed44431a,0x00000000,0x00000000}},	//   רבאט, _زپ_, --, --, 
   {{0x63ac004e,0x94280327,0x273c054e,0x65c0013a}},	//   _upcn, _ཨཙརྱ_, pînd_, bíhá, 
   {{0x6d5912a8,0x7cf409c2,0x925801c6,0x79800142}},	//   _buta, _cárn, _гарт_, yslw, 
   {{0x6d5912a9,0x213c06a3,0xc0c512aa,0xbd8804da}},	//   _cuta, _thuh_, _мәди, شچان_, 
   {{0x6d5912ab,0x98a001a6,0x5578008f,0x213c003e}},	//   _duta, _ikić_, זעהן_, _uhuh_, 
   {{0x6d5912ac,0xfe740184,0xa3dc012c,0x9f60005b}},	//   _euta, _һүҙ_, तहट_, övät_, 
   {{0x6d5912ad,0xf98512ae,0x1ca80327,0xc4c400cc}},	//   _futa, огоо, _བིམ_, _একোজ, 
   {{0x6d5912af,0x69dc00d8,0x7afc00e2,0xf41800cc}},	//   _guta, _àpel, ūsto, _দৰাৰ_, 
   {{0xe3bc0113,0x8e7c008f,0xbb74030d,0x7cf400e5}},	//   _osñ_, _loĝl, _дукъ, _zárn, 
   {{0x7cf400dd,0x6d5912b0,0xa524025c,0xa80002d5}},	//   _háro, _zuta, _རྩེག_, дзял, 
   {{0x6d5912b1,0x7cf400dd,0x2bd8036b,0xeac40014}},	//   _yuta, _káro, _خامک_, _وٕنێ, 
   {{0x7bc912b2,0x6d58004e,0x7cf401d3,0x00000000}},	//   lveu, _xuta, _járo, --, 
   {{0x58f40135,0x5fb87c33,0x00000000,0x00000000}},	//   _བཞིས_, ोटाल, --, --, 
   {{0x67340008,0x7bc8030a,0x7cf40332,0xb2e002dd}},	// [19540] ðgjö, nveu, _láro, _ﺍﻷﻭﺍ, 
   {{0xbb2476b9,0xe7b0006c,0x637c0241,0xaad000bc}},	//   ﻠﯩﻚ_, _کمید, _sàná, ताएक, 
   {{0x7cf403c6,0x021802d5,0x7bcc0024,0x7bc80156}},	//   _náro, біць_, _šaul, hveu, 
   {{0x7cf402d2,0x00000000,0x00000000,0x00000000}},	//   _sárn, --, --, --, 
   {{0x6d5912b3,0xae9800c6,0x7cf40e33,0x00000000}},	//   _suta, لضغط_, _párn, --, 
   {{0xed8868eb,0x7afc0036,0x52200408,0x00000000}},	//   асик_, ëstl, _пĕлӳ_, --, 
   {{0x6d583d07,0x7cf401ed,0x4d44002b,0xf8c8ec2c}},	//   _quta, _várn, _aṣṭo, ियाय, 
   {{0x6d5912b4,0xd1740961,0xfd500055,0x00000000}},	//   _vuta, _мығы, _kidṛ, --, 
   {{0x6d5912b5,0x796000b0,0x00000000,0x00000000}},	//   _wuta, _rēwa, --, --, 
   {{0x9b407ae6,0x7cf512b6,0xf1c00064,0x6e440354}},	//   ونيو, _hárl, _tušą_, _дезз, 
   {{0xa2d81971,0x796000b0,0xed580953,0x6d580bfa}},	//   नात्, _pēwa, _тое_, _uuta, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7cf404bf,0x29140046,0x6d40ca5a,0x29400092}},	//   _záro, ﺳﯩﭗ_, _ihoa, _የኃይማ, 
   {{0x7cf40332,0x00000000,0x00000000,0x00000000}},	//   _lárl, --, --, --, 
   {{0x6d4112b7,0x9b401d0a,0x6d5c00e4,0x00000000}},	//   _khoa, _تنوو, ípah, --, 
   {{0x6d40002d,0x58f4025c,0x290c0267,0x00000000}},	//   _jhoa, _བཞགས_, _öga_, --, 
   {{0x94e803b9,0x00000000,0x00000000,0x00000000}},	// [19550] nşə_, --, --, --, 
   {{0xded402d3,0x6d4000ad,0xfd5000cd,0xa2d8448b}},	//   ሬታን_, _lhoa, _didṛ, नाध्, 
   {{0x6d400093,0x7bc8006f,0x518512b8,0x048800fb}},	//   _ohoa, zveu, дуча, _гәзи_, 
   {{0xd7c801d5,0x6d400051,0x09b40154,0x00000000}},	//   _اویه_, _nhoa, টিপা, --, 
   {{0x7cf512b9,0xa2d800dc,0x00000000,0x00000000}},	//   _dárl, नाद्, --, --, 
   {{0x6d401311,0x7cf512ba,0xc10400aa,0x00000000}},	//   _ahoa, _páro, _کوري, --, 
   {{0x6d4112bb,0x8ccc0b68,0x98a001a6,0x00000000}},	//   _bhoa, _दोहो, _ukić_, --, 
   {{0x7cf4066d,0x6d4112bc,0x62641066,0x63b80024}},	//   _váro, _choa, _داڭق, _šuny, 
   {{0x6d4000ad,0x7bc8bcf6,0x69dc01e1,0x00000000}},	//   _dhoa, uveu, _àpej, --, 
   {{0x7bc912bd,0x6d4112be,0x7cf401ed,0x4fc402d5}},	//   rveu, _ehoa, _táro, _ўста, 
   {{0x6d4001ab,0x7bc801fa,0x7cf401d3,0x4ea512bf}},	//   _fhoa, sveu, _hárm, _юрта, 
   {{0x6d400731,0x2e38011a,0x5fbc166d,0x00000000}},	//   _ghoa, _הגענ, _एनाल, --, 
   {{0x7cf401ed,0x81e000cc,0x00000000,0x00000000}},	//   _járm, ধনি_, --, --, 
   {{0xdb20006c,0x7bdc005b,0xfaf80064,0x00000000}},	//   _توتی, äsuu, rpūs_, --, 
   {{0x6da806be,0x00000000,0x00000000,0x00000000}},	//   _nəal, --, --, --, 
   {{0x336400d3,0xd8840214,0x6d40036e,0x00000000}},	//   зваг, _کهکی, _xhoa, --, 
   {{0xb0c40764,0xa49801e1,0x28980a7c,0x7bcc00de}},	// [19560] _रोगग, _olòf, _היפא, _šauj, 
   {{0x662401ed,0xa56001d5,0xe9a400f2,0x7cf402d2}},	//   érké, بگین, _بگین_, _sárl, 
   {{0xc21802bf,0x00000000,0x00000000,0x00000000}},	//   оєї_, --, --, --, 
   {{0x7cf400dd,0x69cc03cd,0x22440118,0x00000000}},	//   _bárm, åbei, ýnka_, --, 
   {{0xa5240003,0xa498007f,0x7cf400e4,0xee84010b}},	//   _རྩིག_, _blòf, _cárm, пыйо, 
   {{0x6da80cc1,0x59d800dc,0x2ec400cd,0x00000000}},	//   _fəal, यमार, लयेत, --, 
   {{0x6d40062c,0x7cf45821,0xea5400fb,0x00000000}},	//   _phoa, _tárl, үзиә_, --, 
   {{0x7cf512c0,0x6d4000fb,0x09b40eac,0x4094004e}},	//   _fárm, _qhoa, টিমা, _орут, 
   {{0x2e5413f9,0xa49802e2,0x00000000,0x00000000}},	//   _فضاس, _imòt, --, --, 
   {{0x6d4112c1,0xfee80597,0x7cf401d3,0xeb9801d5}},	//   _whoa, _وعلى_, _járj, _ҳид_, 
   {{0x6d4112c2,0x61f80198,0x8e7c0115,0x88940107}},	//   _thoa, _ƙuli, _loĝk, минх, 
   {{0xeb980d1d,0x6d400108,0x00000000,0x00000000}},	//   _гид_, _uhoa, --, --, 
   {{0x57f4016a,0xd7f912c3,0x9b600131,0x58d408ca}},	//   епят, пур_, _كۆيۈ, хоят, 
   {{0xe5703adf,0x1ae000fd,0x24440022,0x00000000}},	//   فطر_, _почм, ҧхаг, --, 
   {{0xa2d8193d,0x6ab800d2,0xfd5400b8,0x2a34009d}},	//   नास्, metf, _anaṃ, _ээдр, 
   {{0x6ab8ff83,0xef20033f,0xd91001d3,0xdb200108}},	//   letf, leżą_, _میپ_, äröi, 
   {{0xd06403be,0x98a4026a,0x00000000,0x00000000}},	// [19570] _ürəy, _чиње, --, --, 
   {{0x26c4019f,0x7bcc0006,0xd7fc0375,0x57fc011a}},	//   _ûno_, _šauk, _להחל, _ללחו, 
   {{0xaaac629c,0xf1c0005f,0xdce00064,0x00000000}},	//   ज्यक, jušā_, lpną, --, 
   {{0x6ab8003c,0x614003cc,0xdce000e2,0xf1c00171}},	//   hetf, رىشە, rsnī, dušā_, 
   {{0x6ab8003c,0x00000000,0x00000000,0x00000000}},	//   ketf, --, --, --, 
   {{0x2bb40c2e,0xa49912c4,0x3ea112c5,0x6da80213}},	//   _अनजा, _blòg, üht_, _təal, 
   {{0x6ab80fac,0xdd1c00d0,0xf1c00171,0x00000000}},	//   detf, rížs, gušā_, --, 
   {{0xed5406bb,0x7cf401d3,0xacb000d1,0x00000000}},	//   мощ_, _zárj, نمىغ, --, 
   {{0x273c145e,0xa498067c,0x5f740150,0x6ab8004e}},	//   zîna_, _elòg, _ءارر, fetf, 
   {{0x212d12c6,0xa498007f,0x7cf408a5,0x6ab80857}},	//   logh_, _flòg, _kárk, getf, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc688008d,0x7cf401ed,0x69cc01bf,0x2bb4012d}},	//   _כא_, _márk, æbea, _अनचा, 
   {{0xfaa512c7,0xe970182f,0x6ab80af2,0x59d8012c}},	//   _жало, _یهود, betf, यमहर, 
   {{0x3cfc0218,0x6ab800d2,0x212c016d,0xcc900055}},	//   _hlwv_, cetf, hogh_, _tṛce_, 
   {{0xe5a112c8,0x29180321,0x75541d39,0x00000000}},	//   кири, ðgað_, дњац, --, 
   {{0x212c003e,0xd8580166,0x00000000,0x00000000}},	//   jogh_, _эчкә_, --, --, 
   {{0xb4bc068f,0x88c410fe,0x72c46496,0xe9446676}},	// [19580] _इसी_, _ستيل, мбаз, _تروی, 
   {{0xb0c41428,0xa498007f,0x7cf401ed,0xe294013e}},	//   _रोजग, _alòd, _bárk, даф_, 
   {{0x7cf400dd,0x02180006,0x00000000,0x00000000}},	//   _várj, піць_, --, --, 
   {{0x7cf40316,0xdb0805d5,0x31bc012c,0x6ab800e5}},	//   _dárk, _asgü, _vůz_, zetf, 
   {{0x6ab82959,0x5eec01ad,0xa2d800cd,0x00000000}},	//   yetf, _अवश्_, नाश्, --, 
   {{0x644000bc,0x7cf402d2,0xb4bc000d,0x00000000}},	//   řnic, _hárh, _इसु_, --, 
   {{0xa2d811bc,0xa49801c3,0x212c0842,0x6da806be}},	//   नार्, _flòd, bogh_, _təam, 
   {{0xfe440f00,0x6ab8003c,0xc0c011ca,0x69dc06af}},	//   رکلی, wetf, _бәши, _àpei, 
   {{0x6ab912c9,0x8e7c008f,0xa2c000cd,0x00000000}},	//   tetf, _loĝi, रयच्, --, 
   {{0xa48c0023,0x00000000,0x00000000,0x00000000}},	//   _ዝጎደሎ_, --, --, --, 
   {{0x6ab81a56,0xdee112ca,0x9208002b,0x00000000}},	//   retf, _шофи, bhāų, --, 
   {{0x6ab813c4,0x61e112cb,0xa2d801f9,0xdcac00d1}},	//   setf, änli, नाऱ्, _نىم_, 
   {{0xeb047d02,0x9a2001d3,0xaae4007b,0x2d7401ef}},	//   _очко, فٹین, _يستو, _dřeň_, 
   {{0xa5f4035b,0x00000000,0x00000000,0x00000000}},	//   дҵоу_, --, --, --, 
   {{0xe9385024,0x163440b9,0x7cf401d3,0x00000000}},	//   _وسعت_, веря, _bárh, --, 
   {{0xa498067c,0x3ea81b24,0x2bd0726b,0xdec80023}},	//   _amòr, đati_, तिपा, ቢቕና_, 
   {{0xa2d806b1,0x7cf401d3,0x94a801f4,0xeca40118}},	// [19590] नाल्, _sárk, ьтра_, क्एफ, 
   {{0x7cf43b95,0x00000000,0x00000000,0x00000000}},	//   _párk, --, --, --, 
   {{0xaaa4012c,0x212c014f,0x00000000,0x00000000}},	//   _खानक, togh_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3f8839b4,0xa2a400dc,0x212c00ad,0x00000000}},	//   éau_, _चाप्, rogh_, --, 
   {{0x47b8031c,0x2bd018cc,0x5064035b,0x7cf400e5}},	//   _བརླམ, तिना, нтәа, _zárh, 
   {{0x7cf40321,0x44380af9,0x8d8401f7,0x00000000}},	//   _hári, _hys_, نشين, --, 
   {{0xd6580d65,0x443912cc,0x7cf4659a,0xfbc400d8}},	//   ויות_, _kys_, _kári, ебио, 
   {{0xfbd112cd,0x44380af9,0x69ccd02e,0xe9a001d5}},	//   اتب_, _jys_, æben, қаяп, 
   {{0x7cf512ce,0x3f9c0bd7,0x7e980150,0xec6c839a}},	//   _mári, muwu_, _ءنار_, _әп_, 
   {{0x7cf400c6,0xa2a407b7,0x3f9c1bce,0x3d940166}},	//   _lári, _चान्, luwu_, _чиер, 
   {{0xb4bca018,0x8d74f2e7,0xa3dc012c,0x443912cf}},	//   _इसे_, _شاما, थमा_, _oys_, 
   {{0x443912d0,0x60d912d1,0xc01c015b,0xeb8c7111}},	//   _nys_, _mnum, _তরুণ_, _щи_, 
   {{0xfaa4384f,0x00000000,0x00000000,0x00000000}},	//   _чако, --, --, --, 
   {{0x60d912d2,0x7cf401d3,0xdce0013d,0x00000000}},	//   _onum, _párh, lunı, --, 
   {{0x60d8dbbe,0x443912d3,0x3f9d12d4,0x00000000}},	//   _nnum, _bys_, kuwu_, --, 
   {{0x7cf512d5,0x2bd007c1,0x44381c2e,0x00000000}},	// [195a0] _cári, तिया, _cys_, --, 
   {{0x60d912d6,0xa8540302,0x44380731,0x7cf40248}},	//   _anum, _איפה_, _dys_, _dári, 
   {{0x44380072,0x7cf401d3,0xdce00166,0x00000000}},	//   _eys_, _tárh, hunı, --, 
   {{0xd3704d2d,0x1cc80003,0x44380731,0x2bd00782}},	//   _نۇر_, ླབས_, _fys_, तिमा, 
   {{0x443802a4,0x3f9c0099,0x703800ae,0x00000000}},	//   _gys_, guwu_, أساس_, --, 
   {{0xa498642b,0xdee112d7,0x9cec0154,0x00000000}},	//   _glòb, лочи, টফোন_, --, 
   {{0xc32c0328,0x7c3802d0,0x2bd112d8,0x1fa40166}},	//   _بەل_, _aywr, तिभा, _үкси_, 
   {{0x3f9c020c,0xf8c81025,0x00000000,0x00000000}},	//   buwu_, ियोप, --, --, 
   {{0x7c380042,0xffa40166,0x644801d5,0x7bdc000d}},	//   _cywr, _илтү, оgiy, äsup, 
   {{0xa49802e2,0xda740cb9,0x2bd0012c,0xa3c000e1}},	//   _klòc, няю_, तिबा, ्ित_, 
   {{0xdd8c5712,0xdb2001d3,0x5b100276,0xde0800cf}},	//   _هول_, óság, умэт, _ىرمۇ_, 
   {{0xab8401d5,0xdce00139,0x00000000,0x00000000}},	//   _зукк, bunı, --, --, 
   {{0x2e4401e1,0x7c380042,0x6e38036e,0x00000000}},	//   _fífí_, _gywr, _hytb, --, 
   {{0x443912d9,0xc01c03d4,0x00000000,0x00000000}},	//   _rys_, _তৰুণ_, --, --, 
   {{0x443912da,0x59d03229,0x7cf42507,0x7afc000f}},	//   _sys_, _مغير, _sári, êste, 
   {{0x9a380302,0x44382a3d,0xa49800a3,0x7cf4ea0f}},	//   _מתוק, _pys_, _slòb, _pári, 
   {{0x6b4401a8,0x00000000,0x00000000,0x00000000}},	// [195b0] aðge, --, --, --, 
   {{0x7cf403b7,0xa498068c,0x926882de,0x00000000}},	//   _vári, _blòc, ерца_, --, 
   {{0x44380591,0x60d80077,0x3f9c0134,0x673402d0}},	//   _wys_, _pnum, wuwu_, _ikxj, 
   {{0x4438068f,0x3f9c0161,0x7cf512db,0x83f8004e}},	//   _tys_, tuwu_, _hárv, _жемс_, 
   {{0xbea4e0c3,0x442c0086,0x8e7c01e4,0x44390e94}},	//   валк, _âe_, _loĝu, _uys_, 
   {{0x2ca40142,0x9618036b,0x7c380142,0x6e38007c}},	//   _acod_, _آغیر_, _rywr, _bytb, 
   {{0x6e38015d,0xc0c40022,0x6da002e8,0x6fa000d1}},	//   _cytb, _ишақ, аища, ﺎﻧﻐﺎ_, 
   {{0x9258ac5b,0x60d912dc,0x61e001f4,0x00000000}},	//   _част_, _unum, änlu, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9e0512dd,0xe6c89f23,0xb4bc012d,0x00000000}},	//   _пчел, ायोज, _इस्_, --, 
   {{0x6e38015d,0x7c38012d,0x98a8013d,0xf2d000d9}},	//   _gytb, _wywr, _sunı_, בעי_, 
   {{0xe45c145e,0xec10023f,0x17c8013e,0x00000000}},	//   _ngö_, اوید, еҳии_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4758026b,0x00000000,0x00000000,0x00000000}},	//   ерся_, --, --, --, 
   {{0x66e0023b,0x0ae81e5a,0xab2401a9,0x00000000}},	//   шора, _سروي_, _шоша_, --, 
   {{0x69dc0010,0x142001f3,0x73340145,0x00000000}},	//   _špeg, _ተመርኩ, چىرا, --, 
   {{0xe360049e,0x73341e4a,0x2934010f,0x7cf4032e}},	// [195c0] икти, نىرا, _שאפן_, _fárv, 
   {{0x796004fe,0xe29512de,0x2bd000cd,0xa798123b}},	//   _pēwh, кау_, तिता, _קשיח, 
   {{0x7cf512df,0x3f8d12e0,0x69dc06af,0x72041bf4}},	//   _háru, _aveu_, _àpet, خوام, 
   {{0x11387e2c,0x25d40375,0xb38401b9,0x7cf4559d}},	//   رتاژ_, _סוכן_, _илмл, _káru, 
   {{0x7cf401d3,0x73740022,0x00000000,0x00000000}},	//   _járu, _шынх, --, --, 
   {{0x796002b1,0x2ca400a3,0x7cf40241,0x5ed000d1}},	//   _tēwh, _scod_, _máru, لتىز, 
   {{0x78b40232,0xe2940cfc,0xa2a400dc,0x7cf512e1}},	//   _obyv, _јас_, _चात्, _láru, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7cf402fb,0xaec512e2,0xceb82abf,0xeb04003b}},	//   _náru, _ибал, _зәй_, вчно, 
   {{0x3ae800d0,0x00000000,0x00000000,0x00000000}},	//   _kúpy_, --, --, --, 
   {{0x7bcc4a97,0xed587fec,0x2d880241,0xa2f4011a}},	//   _šaut, _жож_, _ìbe_, דמיה_, 
   {{0xe6d800dc,0x7cf512e3,0x2bd021b8,0x00000000}},	//   यञ्ज, _báru, तिदा, --, 
   {{0xd8380323,0xac080116,0x44f402dd,0x00000000}},	//   вэр_, _юнда_, қпас, --, 
   {{0xd7f83c1b,0xb8f912e4,0x8e7c00e4,0x3a2800b8}},	//   тую_, _डो_, _toĝu, _śape_, 
   {{0x6d4c011c,0x1fbc0709,0xe7a400d1,0x7cf43add}},	//   _èbas, _एन्ड, رۇھى_, _várv, 
   {{0xd49912e5,0x00000000,0x00000000,0x00000000}},	//   кру_, --, --, --, 
   {{0x2a6c045f,0x7bcc0077,0x796000b0,0x82d8c141}},	// [195d0] _kffb_, _áaut, _rēwi, ндас_, 
   {{0x644003be,0x69dc00d8,0x61400241,0x78b401ef}},	//   ənil, _àpes, _ọló, _zbyv, 
   {{0x7cf512e6,0xf8a912e7,0x00000000,0x00000000}},	//   _záru, _कामय, --, --, 
   {{0x7cf401ed,0x00000000,0x00000000,0x00000000}},	//   _járt, --, --, --, 
   {{0x7cf512e8,0x1fa4084c,0x00000000,0x00000000}},	//   _márt, трег, --, --, 
   {{0x7cf401e7,0x57fc00d9,0x2fd4009a,0x00000000}},	//   _lárt, ולדו, اوود_, --, 
   {{0x6098007b,0x20c400db,0x00000000,0x00000000}},	//   _يخرج_, _исаг, --, --, 
   {{0xa2d80f4c,0x7f840014,0x3ea80024,0x47b80327}},	//   नाक्, _ملرن, _šitą_, _བརྕམ, 
   {{0x3ea401ed,0xe81000c5,0x6d5c01e4,0xf98800ec}},	//   _مشاہ, _ढेला_, ŭpap, ڙندي_, 
   {{0xa3a800e1,0x7bcc00e2,0x3f880024,0xec440026}},	//   _गमन_, _šaus, šaus_, ызыл_, 
   {{0x7cf512e9,0x47b80327,0x00000000,0x00000000}},	//   _sáru, _བརྔམ, --, --, 
   {{0x7cf40597,0xfa400092,0x00000000,0x00000000}},	//   _cárt, _የዓለማ, --, --, 
   {{0xe8f512ea,0x00000000,0x00000000,0x00000000}},	//   уля_, --, --, --, 
   {{0x2908020c,0x7cf401d3,0x00000000,0x00000000}},	//   èbar_, _váru, --, --, 
   {{0x29d00592,0x00000000,0x00000000,0x00000000}},	//   _هيوس, --, --, --, 
   {{0xa6200020,0x8e7c008f,0xd76401d5,0x7cf512eb}},	//   ደሚያደ, _inĝe, _پندی, _gárt, 
   {{0x7cf512ec,0x69dca547,0xf3480798,0xe1f400d1}},	// [195e0] _hárs, _àper, епал_, ңгу_, 
   {{0x8e7c01e4,0xa2d833af,0x36c402e8,0x7cf512ed}},	//   _loĝr, नाग्, _сбог, _zárt, 
   {{0xaaa4134e,0x7cf400e5,0x6ee000bc,0x00000000}},	//   _खासक, _járs, पासँ, --, 
   {{0x78a40162,0x00000000,0x00000000,0x00000000}},	//   ngkv, --, --, --, 
   {{0xa2d81684,0x773c0092,0x00000000,0x00000000}},	//   नाख्, _በሶስተ, --, --, 
   {{0x69cc01bf,0x2bd0090a,0xa85400d9,0x00000000}},	//   æbek, तिसा, אינה_, --, 
   {{0xdd94010b,0x93440150,0x2324020f,0x3074001b}},	//   гшы_, _مىڭۇ, _сори_, _бузс, 
   {{0x70540014,0x25d408a8,0x00000000,0x00000000}},	//   _منزا, רוקן_, --, --, 
   {{0x2aa81173,0x8e7c008f,0x7bcc00e2,0x31ac0306}},	//   нтно_, _anĝe, _šaur, lýz_, 
   {{0xdee00022,0x7cf40f47,0xb80800eb,0x00000000}},	//   _лоуи, _sárt, রপাত_, --, 
   {{0x7cf512ee,0xa2a400dc,0x2bd0cc41,0x31ac00d7}},	//   _párt, _चास्, तिहा, nýz_, 
   {{0x7cf48550,0xdd8c0150,0xc0f0001f,0x7afd12ef}},	//   _dárs, _ءون_, ፃፀር_, ëstr, 
   {{0x06c804c5,0x7cf401d3,0x2fc40142,0x6b4402d2}},	//   শাসি, _várt, nwog_, aðga, 
   {{0x27fc003d,0x6b80009a,0x20480023,0x798c0210}},	//   ġun_, _iwog, _ዝዓበየ, _ławe, 
   {{0x6b80006f,0x2bd007d0,0x6aa803ac,0x27fc03f0}},	//   _hwog, तिवा, _icff, šun_, 
   {{0x69c912f0,0x6b8112f1,0xdb2001a8,0x7cf409e8}},	//   _isfe, _kwog, ðsög, _hárr, 
   {{0x7cf40c63,0x987400c7,0xa344009d,0x00000000}},	// [195f0] _kárr, _улыц, гэжл, --, 
   {{0x6b8112f2,0x7cf400e4,0xb8800139,0x00000000}},	//   _mwog, _járr, _çíra, --, 
   {{0x26c112f3,0x6b801418,0x310407b7,0x00000000}},	//   mejo_, _lwog, _शतशः_, --, 
   {{0x26c112f4,0x6b800083,0x00000000,0x00000000}},	//   lejo_, _owog, --, --, 
   {{0xa27402dd,0xdb1803e0,0x00000000,0x00000000}},	//   _бұзу_, _özçe, --, --, 
   {{0x26c112f5,0x7cf40077,0x41c40014,0x00000000}},	//   nejo_, _nárr, _پٲرِ, --, 
   {{0x69c81529,0x6b80033b,0xfce41f91,0xf4b801a8}},	//   _nsfe, _awog, иоко, _þýða_, 
   {{0x6b8112f6,0x628512f7,0x26c112f8,0x72080014}},	//   _bwog, _hejo, hejo_, _شفقہ_, 
   {{0x26c112f9,0x628512fa,0x7cf401a8,0x2bd092c2}},	//   kejo_, _kejo, _sárs, तिषा, 
   {{0x26c00f72,0x6b80007f,0x6aa8010a,0x628512fb}},	//   jejo_, _dwog, _ccff, _jejo, 
   {{0x628512fc,0x2ef80e78,0xf2d0008f,0x8d740133}},	//   _mejo, öpfe_, קעט_, _هانا, 
   {{0x69dc01a2,0x628512fd,0x7cf40aaa,0x2bd007d0}},	//   _špec, _lejo, _várs, तिशा, 
   {{0x7d086456,0x6b801418,0x7cf512fe,0x26c112ff}},	//   mhes, _gwog, _fárr, fejo_, 
   {{0x7cf4066d,0x3cec5835,0x62840316,0xc878e090}},	//   _társ, ljev_, _nejo, ışa_, 
   {{0x7d08009f,0xe6140c69,0xba38010f,0x00000000}},	//   ohes, адр_, _בײַט, --, 
   {{0x7d091300,0x3cec0219,0x35a40022,0x23ac03e0}},	//   nhes, njev_, лаҳг, füj_, 
   {{0x62851301,0x26c11302,0x273c025a,0x93c801ed}},	// [19600] _bejo, bejo_, zîni_, دازہ_, 
   {{0x7cf44a34,0x26c0008f,0x62840076,0x128804d3}},	//   _márq, cejo_, _cejo, امای_, 
   {{0xa2a4813f,0x7d085b12,0x6284005f,0x870401e2}},	//   _चार्, khes, _dejo, _دبيل, 
   {{0x6140034b,0xcc9000dc,0x425400d4,0x69cc0174}},	//   оеха, _gṛhe_, стут, æbei, 
   {{0x7d091303,0x3cec1710,0xaaa4012c,0x6284036e}},	//   dhes, djev_, _खालक, _fejo, 
   {{0x9ea4026a,0x6b800230,0x9aec02a8,0x7d080108}},	//   авља_, _rwog, ƙaƙe_, ehes, 
   {{0xb2380597,0x4c600055,0x4c948a2e,0x00000000}},	//   _شكرا_, _aṇḍa_, бийс, --, 
   {{0x6b800d29,0x62851304,0x7d091305,0x3cec05ac}},	//   _pwog, _zejo, ghes, gjev_, 
   {{0x7cf40cc3,0xa2d808e6,0x6284f3bc,0x26c00337}},	//   _párr, नाच्, _yejo, yejo_, 
   {{0xaa640075,0x6e340354,0x00000000,0x00000000}},	//   штик, _кхех, --, --, 
   {{0x26c11306,0x7d091307,0x3cec01fa,0x7bd80221}},	//   vejo_, bhes, bjev_, _erwu, 
   {{0x7d091308,0x58851309,0x6b800a49,0xfca800c6}},	//   ches, жыра, _twog, _ماهو_, 
   {{0x26c000c8,0x6b81130a,0xe665130b,0x7cf400e4}},	//   tejo_, _uwog, итво, _tárr, 
   {{0x89d807d6,0x5b309347,0xda1408dc,0x7cf40413}},	//   _موتر_, _وعور, ازیش_, _hárp, 
   {{0x6285130c,0x2eec282c,0x7cf401ed,0x2984004e}},	//   _rejo, ijff_, _kárp, _тылг, 
   {{0x26c1130d,0x47d4009a,0x00000000,0x00000000}},	//   sejo_, _هيبر, --, --, 
   {{0x6285130e,0x26c1130f,0x7cf400e5,0x00000000}},	// [19610] _pejo, pejo_, _márp, --, 
   {{0x7cf42131,0x7d091310,0x00000000,0x00000000}},	//   _lárp, zhes, --, --, 
   {{0x09b402a6,0x62840153,0xe7f40037,0x7d08036e}},	//   টিকা, _vejo, ुनवा_, yhes, 
   {{0xd1b801ec,0x62842aa4,0x7d091311,0xa2d800dc}},	//   شاما_, _wejo, xhes, नाङ्, 
   {{0x7d091312,0x7f180845,0x628400dc,0x3f9c0099}},	//   vhes, ліку_, _tejo, urwu_, 
   {{0x1dd000af,0x6724003e,0x7d08020c,0x00000000}},	//   थिलत, nnjj, whes, --, 
   {{0x7cf403df,0x9294f14d,0xcee8007b,0x6448000d}},	//   _bárp, _фасц, شرون_, ügif, 
   {{0xd5d8a4ea,0x3b843e54,0xd04003b9,0x00000000}},	//   डितज, блиг, _lamə, --, 
   {{0x3cec0f72,0x7d091313,0xf1bc031c,0x6b4402d2}},	//   rjev_, rhes, ġġeb_, gðgo, 
   {{0x7d091314,0x657402c4,0xd04000ac,0xfaa4399f}},	//   shes, _otxh, _namə, љано, 
   {{0x7d0853ff,0xfe740184,0x65740190,0xe0dc0248}},	//   phes, _күҙ_, _ntxh, _òòs_, 
   {{0x0508015b,0x7d091315,0xdea000f1,0x00000000}},	//   রচুর_, qhes, _ایډی, --, 
   {{0x657402b9,0xdb0804ce,0x7bd80230,0x48f80037}},	//   _atxh, _opgø, _urwu, _उकरो_, 
   {{0xda791316,0x0d642309,0xfd4c0051,0x68401291}},	//   _ряд_, _ادەپ, _nhoẻ, سَّل, 
   {{0xa4980248,0x7bc8009a,0x9504031c,0x998400c0}},	//   _elòm, lweu, ངྒའི_, _vynų_, 
   {{0xf4e4009e,0x741402c9,0x82400023,0x00000000}},	//   নস্ব, موزا, _ክሳራታ, --, 
   {{0xeb5001d9,0xa49800a3,0x00000000,0x00000000}},	// [19620] _بى۪گ, _glòm, --, --, 
   {{0x66200118,0x00000000,0x00000000,0x00000000}},	//   ávká, --, --, --, 
   {{0x200c07de,0x7bc80098,0x00000000,0x00000000}},	//   ezgi_, hweu, --, --, 
   {{0x92e80154,0x61e0143a,0xd37000d1,0x00000000}},	//   বসে_, ånla, _يۇز_, --, 
   {{0x6554011a,0x00000000,0x00000000,0x00000000}},	//   _לבטא_, --, --, --, 
   {{0xb8f803bd,0x5f911317,0x7bc80142,0x00000000}},	//   _ོལ_, чишт, dweu, --, 
   {{0xa4980248,0x7cf40407,0x273c054e,0x7bc80af9}},	//   _amòy, _párp, mînt_, eweu, 
   {{0x64487148,0x5ce00131,0x6f6400c0,0x00000000}},	//   ügig, ككىل, _гваз, --, 
   {{0x30051318,0x8ac801d5,0x6c8400f7,0x7fd412fa}},	//   _узаг, иқда_, _ۇلام, _міфі, 
   {{0x37bc015b,0x00000000,0x00000000,0x00000000}},	//   ইটার, --, --, --, 
   {{0x6e440e5a,0x2d94ec38,0x2b4c031c,0x0c8401e0}},	//   _انام, _ырас, _vhfc_, _һыҙм, 
   {{0xd04006be,0x7c440413,0xbb3001ec,0x00000000}},	//   _samə, ðuræ, _ﺫﺍﻙ_, --, 
   {{0xf8a80882,0xdca001c0,0x6bd4004b,0x00000000}},	//   _कारय, _хачи, _دتار, --, 
   {{0x6b5418b6,0xa97000c7,0xd04003e3,0x00000000}},	//   _утех, _евкә, _qamə, --, 
   {{0xd49805f5,0x00000000,0x00000000,0x00000000}},	//   өрт_, --, --, --, 
   {{0xd99401e2,0x00000000,0x00000000,0x00000000}},	//   _اخوا_, --, --, --, 
   {{0xd83801c6,0x6b440162,0x00000000,0x00000000}},	// [19630] _гээ_, yðgl, --, --, 
   {{0x2918070d,0xa2640364,0x00000000,0x00000000}},	//   _hmqa_, съал, --, --, 
   {{0x40940075,0x7bc8014b,0x3d18000d,0x00000000}},	//   قلار, zweu, _बगले_, --, 
   {{0xd2580114,0xfde80133,0x00000000,0x00000000}},	//   сцу_, یکاو_, --, --, 
   {{0xff5010ac,0x3e8800a7,0x53a00092,0x64480c48}},	//   وخت_, айло_, ልቃይት_, ügid, 
   {{0x01c801d3,0x9e900137,0x00000000,0x00000000}},	//   _پورٹ_, ساتچ, --, --, 
   {{0x51840323,0x69dc02fb,0x646001e4,0xed4c0a81}},	//   _нута, _špen, ŝtiĝ, چھن_, 
   {{0xed4c00b2,0xc1040d2f,0x26d0003a,0x6b140327}},	//   نھن_, _بوري, _laxo_, ྲིའོ_, 
   {{0xa498007f,0x7bc80c6a,0xfaa40452,0x34d8010f}},	//   _alòk, uweu, оапо, בֿיב, 
   {{0x26d00067,0xb05001d9,0x7bc800e8,0x00000000}},	//   _naxo_, _کھۅت, rweu, --, 
   {{0x2df800dd,0x9e051319,0x7bc80c6a,0x7f4c0129}},	//   _پبلک_, _учал, sweu, ïaqu, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x26d001d9,0x69dc00e4,0x00000000,0x00000000}},	//   _baxo_, _ápen, --, --, 
   {{0x5d1001d9,0xa498007f,0xaaa400bc,0x00000000}},	//   _بِچا, _flòk, _खाएक, --, 
   {{0x9604084a,0x26d00055,0x273c0356,0x00000000}},	//   रनेट_, _daxo_, vînt_, --, 
   {{0xb38401c0,0x00000000,0x00000000,0x00000000}},	//   жлал, --, --, --, 
   {{0x236000e8,0x26d00393,0xc0d40092,0x72880022}},	// [19640] _bijj_, _faxo_, _የሠራ_, ибаг_, 
   {{0x26d0005a,0xf77000e5,0x00000000,0x00000000}},	//   _gaxo_, _ٹاک_, --, --, 
   {{0x7c2c008c,0x2360002e,0x491000bc,0x00000000}},	//   _þarf, _dijj_, दोको_, --, 
   {{0xf8a8000d,0xa9b8010f,0x00000000,0x00000000}},	//   कलिय, יזער, --, --, 
   {{0x6f19131a,0x5f707611,0x00000000,0x00000000}},	//   _pmtc, واور, --, --, 
   {{0xa49801e1,0xf1a84fe0,0x64480037,0x00000000}},	//   _alòh, _پاسه_, ügie, --, 
   {{0x4c9495be,0xe2940108,0xca68022e,0xf8a807b7}},	//   пийс, _фас_, tidо, कलाय, 
   {{0xd9cc02f5,0xd1e00023,0xbe300137,0x00000000}},	//   িমাম, _ሓተቶ_, رۉنب, --, 
   {{0xcbe800eb,0x00000000,0x00000000,0x00000000}},	//   গন্ধ_, --, --, --, 
   {{0x7dc400cf,0xd1e00023,0x00000000,0x00000000}},	//   تتۇك, _ሓተተ_, --, --, 
   {{0x26d1131b,0x00000000,0x00000000,0x00000000}},	//   _raxo_, --, --, --, 
   {{0x88b1131c,0x26d1131d,0xcdc40124,0xab84074d}},	//   ریخچ, _saxo_, _маҷқ, _дукк, 
   {{0xab29131e,0x24880205,0x00000000,0x00000000}},	//   _кода_, _recm_, --, --, 
   {{0x26d03a73,0x7c2cdadf,0x69cc005c,0x8c1800ec}},	//   _qaxo_, _žarg, æbes, _پيڪر_, 
   {{0x2bd03711,0xda300166,0x5ee8024a,0xd1e00240}},	//   तिका, _оешы, चात्_, _ሓተቱ_, 
   {{0x395000ad,0x00000000,0x00000000,0x00000000}},	//   _ghys_, --, --, --, 
   {{0x29d800b0,0x26d004cc,0xdcf000f3,0xc298e99a}},	// [19650] _hīa_, _taxo_, žaće, йках_, 
   {{0x29d80374,0x26c4012c,0x273c0356,0x00000000}},	//   _kīa_, _úno_, rîns_, --, 
   {{0xc1b800a7,0xd25001d3,0x6448000d,0x00000000}},	//   слех_, ہنے_, ügib, --, 
   {{0xed45131f,0xa2a40303,0x00000000,0x00000000}},	//   _سپ_, _चाक्, --, --, 
   {{0x69dc09a8,0x3f6800f5,0x00000000,0x00000000}},	//   _špel, щило_, --, --, 
   {{0x644c005f,0xdcc000dc,0x00000000,0x00000000}},	//   _izci, वज्ञ, --, --, 
   {{0x4cd400cc,0x00000000,0x00000000,0x00000000}},	//   থানু, --, --, --, 
   {{0x3b842097,0x818401af,0x00000000,0x00000000}},	//   плиг, _мѳғж, --, --, 
   {{0xd1e0044e,0x39500368,0xa49801c3,0x3e351320}},	//   _ሓተታ_, _rhys_, _clòi, _کفار, 
   {{0xa3780037,0x00000000,0x00000000,0x00000000}},	//   _krõb, --, --, --, 
   {{0x7c2c00f3,0x39500d63,0xe9d40166,0x00000000}},	//   _žard, _phys_, пкэ_, --, 
   {{0x9ba00131,0xa3c80037,0x00000000,0x00000000}},	//   _قەبى, लबा_, --, --, 
   {{0x69d80218,0xa49808c2,0x69cc00b5,0xcc34013d}},	//   avte, _glòi, æber, _охшы, 
   {{0x3950007f,0xa3cc1b76,0xa2a400cd,0x00000000}},	//   _whys_, _वैध_, _चाग्, --, 
   {{0x6b6016c3,0x395062f1,0xaa4028e5,0xf7c800d1}},	//   _якша, _thys_, _пешл, ﻪﻧﻠﻪ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf42801a2,0x644c033f,0xd3f4003b,0x00000000}},	// [19660] _opäť_, _czci, кiст, --, 
   {{0x644c0165,0x760801ee,0x00000000,0x00000000}},	//   _dzci, _геог_, --, --, 
   {{0xe5740276,0x7f380092,0x00000000,0x00000000}},	//   _нзэ_, _እቃዎች, --, --, 
   {{0x2d9800d0,0xa998008f,0x00000000,0x00000000}},	//   ápem_, מבער, --, --, 
   {{0x09a8000b,0x5f402ab4,0xb62402dd,0x703805e0}},	//   _कम्य, کنول, _ﺫﻱ_, حساس_, 
   {{0x290800da,0xf67800c8,0x3f4808a5,0x00000000}},	//   ībai_, זאַמ, búum_, --, 
   {{0x71640150,0xa49801c3,0x2008010e,0x00000000}},	//   _ءاسك, _slòi, _ücin_, --, 
   {{0xa4984079,0x00000000,0x00000000,0x00000000}},	//   _plòi, --, --, --, 
   {{0xceb801af,0x29040171,0xa0640150,0x00000000}},	//   _дәй_, _ēna_, _хауа_, --, 
   {{0x3a740e26,0x00000000,0x00000000,0x00000000}},	//   үлөр, --, --, --, 
   {{0x4a5400d4,0x00000000,0x00000000,0x00000000}},	//   ькос, --, --, --, 
   {{0x7c2c46aa,0x9b8401d3,0xf4280419,0x92e800cc}},	//   _žare, _کنول_, _zpäť_, _বতো_, 
   {{0x6d411321,0xd7e40816,0xa80000db,0x95c80022}},	//   _ikoa, ніро, ركسۉ, ҟура_, 
   {{0x29d802b5,0x00000000,0x00000000,0x00000000}},	//   _tīa_, --, --, --, 
   {{0x160416da,0x6b3c001f,0x04c800ec,0x75f80139}},	//   रनगर_, _አባቶቻ, يوسي_, _näzī, 
   {{0xd1f80020,0xd9440a5b,0x286800d8,0x86440092}},	//   ፊነት_, _пеји, _урко_, _የኤክስ, 
   {{0x6d4005d9,0x47349111,0x66c8084c,0x58b80271}},	// [19670] _mkoa, _онис, _лунг_, _رايج_, 
   {{0x6d400198,0xaa240092,0x00000000,0x00000000}},	//   _lkoa, _ትመስላ, --, --, 
   {{0x7afc002d,0x69dc013a,0x4e1c000d,0x00000000}},	//   êsti, _špej, _भेलई_, --, 
   {{0xf42801a2,0x6d40016b,0x0e440023,0xc2c400ec}},	//   _späť_, _nkoa, _ካታኮም, _ڪيسي, 
   {{0x3fc80214,0x644c84d7,0x2284003b,0x00000000}},	//   تدای_, _uzci, _нувг, --, 
   {{0x6d411322,0xc2c405d4,0xbea4039b,0xafe11323}},	//   _akoa, _تيسي, факк, тошл, 
   {{0x22a00241,0x50640022,0x00000000,0x00000000}},	//   _eékà_, мтәа, --, --, 
   {{0xd0d400a7,0x64400213,0x8d540006,0x00000000}},	//   _посъ, ənir, нтыч, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d4001c4,0xd7680131,0x2bd01546,0x00000000}},	//   _ekoa, ۋەبى_, तिजा, --, 
   {{0x7cf400e4,0x8e2c022e,0x00000000,0x00000000}},	//   _márz, _undа_, --, --, 
   {{0x6d400076,0xec6c0b3e,0x4f080150,0x00000000}},	//   _gkoa, _јп_, _وتەپ_, --, 
   {{0xeb8c7176,0xeaad1324,0xb8f42208,0x00000000}},	//   _ши_, _ий_, _हस_, --, 
   {{0xdb2002f6,0x00000000,0x00000000,0x00000000}},	//   äräi, --, --, --, 
   {{0xed1400dd,0xe6401855,0xe9840150,0xca68022e}},	//   _رہیں_, верп, _قايۋ, midа, 
   {{0x79801529,0xcb940345,0xa3cc00c5,0x00000000}},	//   mplw, _تۆیش_, _वैह_, --, 
   {{0x60c804e6,0x3364003b,0x00000000,0x00000000}},	// [19680] degm, дваг, --, --, 
   {{0x64480037,0xca6801d5,0x27fc002f,0x845400cf}},	//   ügia, nidа, äune_, رىلچ, 
   {{0x7980bff2,0xe29475d7,0x00000000,0x00000000}},	//   nplw, фах_, --, --, 
   {{0x69dc3858,0xd1f8001f,0xca68022e,0x00000000}},	//   _špek, ፊነቱ_, hidа, --, 
   {{0xb4c80807,0x7afc0024,0xf1a80133,0xdce00153}},	//   लजी_, ūsty, _ژاره_, lpnė, 
   {{0x6d411325,0xdee01a39,0xca3400d1,0x00000000}},	//   _skoa, кочи, ﯖﻼﺭ_, --, 
   {{0x62611326,0xca68022e,0xdee00114,0x00000000}},	//   _авра, didа, тоји, --, 
   {{0x60140521,0xc1c80014,0x00000000,0x00000000}},	//   ụman, _ڈبہٕ_, --, --, 
   {{0xaf28cff1,0xc8d80118,0x00000000,0x00000000}},	//   _джаз_, _बोगट, --, --, 
   {{0xadb80597,0xe454008f,0xca68022e,0x49a40121}},	//   _وهذا_, ויפט_, gidа, нымғ, 
   {{0x5ee80073,0xcdc4013d,0x00000000,0x00000000}},	//   चार्_, _чәлп, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xec1407d6,0x0cbc07f7,0xca68022e,0x00000000}},	//   _توشد, ्जीम, bidа, --, 
   {{0xfbbc1bd6,0x00000000,0x00000000,0x00000000}},	//   ्बरम, --, --, --, 
   {{0xd9100b43,0x73c00724,0x9b4024e0,0x00000000}},	//   _چیپ_, һәре, _جنوو, --, 
   {{0x83b80131,0xa49801e1,0x00000000,0x00000000}},	//   _ﻧﻪﺭﺳ, _moòg, --, --, 
   {{0x73c11327,0x60c80158,0x69dc02f0,0xc35400d8}},	// [19690] ләре, vegm, _špeh, екај, 
   {{0x0cbc0864,0x60c801a4,0x45d51328,0xa2240472}},	//   ्जुम, wegm, _зоос, وراه, 
   {{0xa498068c,0x7cf40798,0x224400b5,0xa3a80ce0}},	//   _blòt, _várz, ænk_, _गमक_, 
   {{0xa4984079,0x798c012d,0x00000000,0x00000000}},	//   _clòt, _ławk, --, --, 
   {{0xa49801ab,0x60c91329,0x00000000,0x00000000}},	//   _dlòt, regm, --, --, 
   {{0x9264104b,0xca6801a9,0x00000000,0x00000000}},	//   ردەم, yidа, --, --, 
   {{0xa498180f,0xfd280ca8,0x7cf401ef,0x00000000}},	//   _flòt, _nyìí_, _záry, --, 
   {{0x7c9400db,0xd0a8009b,0x00000000,0x00000000}},	//   رشبا, _отуд_, --, --, 
   {{0x2bc400fd,0x00000000,0x00000000,0x00000000}},	//   елып_, --, --, --, 
   {{0xfaf000c6,0xf98401c6,0xca6801a9,0x00000000}},	//   اثة_, нгоо, tidа, --, 
   {{0xa49802e2,0xfaa40107,0x00000000,0x00000000}},	//   _koòd, _ҷало, --, --, 
   {{0xa9e0004b,0x998801d3,0xca6801d5,0xe9a413bd}},	//   اګون, ülők_, ridа, رگىن_, 
   {{0x7981132a,0x7d09132b,0x7aa5132c,0x8cb801b9}},	//   splw, mkes, _зилз, _آدمس_, 
   {{0x7d0848a1,0xdb208a4c,0x00000000,0x00000000}},	//   lkes, _جوتی, --, --, 
   {{0xe735132d,0x7d08009a,0x65c07de7,0xca6801a9}},	//   хер_, okes, лбра, qidа, 
   {{0x1da40034,0x00000000,0x00000000,0x00000000}},	//   _गिनत, --, --, --, 
   {{0xb9d41540,0xa498033b,0x7d09132e,0x39400153}},	// [196a0] _ጸረ_, _alòs, ikes, moks_, 
   {{0x3cfc02c4,0x212c0226,0x7d0825c6,0x3941132f}},	//   _lowv_, engh_, hkes, loks_, 
   {{0xa4991330,0x39400175,0x32340107,0xc51400d1}},	//   _clòs, ooks_, ххас, ربېت, 
   {{0x39411331,0x00000000,0x00000000,0x00000000}},	//   noks_, --, --, --, 
   {{0xe7e00dcc,0x43746c4d,0xdd9002dd,0x7d08000d}},	//   खिया_, _ауст, ңашы, dkes, 
   {{0x212c062c,0xa0640354,0x7d0837cd,0x61e80162}},	//   angh_, хача_, ekes, ámlý, 
   {{0x2d9803a5,0x39406e98,0x41b400cf,0xde240240}},	//   épe_, koks_, _истт, _ኽንከው, 
   {{0xd9e005f9,0xe80000bc,0x2d9800e4,0x23c00055}},	//   गिनत_, रङमा_, ĩpe_, bījā_, 
   {{0xef190eb2,0x5ce000c9,0x3f8c0042,0x00000000}},	//   _ема_, ующа, _gweu_, --, 
   {{0x2d6c038e,0x7d08000d,0xa49801e1,0x9f940a7c}},	//   _před_, akes, _toòg, _נדבה_, 
   {{0x3940000d,0x00000000,0x00000000,0x00000000}},	//   foks_, --, --, --, 
   {{0x7d091332,0x61e00267,0x0fd401ef,0x2d6c01ef}},	//   ckes, ånli, _धनाढ, _vřed_, 
   {{0xfca82d77,0x00000000,0x00000000,0x00000000}},	//   _زانو_, --, --, --, 
   {{0xd04002a8,0x7c2c032e,0x00000000,0x00000000}},	//   _hamɓ, _þara, --, --, 
   {{0x39411333,0x95c803a6,0xabb000d1,0x692800bc}},	//   boks_, нута_, _раһә, třed, 
   {{0x290811f9,0x394005b1,0x04c87427,0xbf1c0825}},	//   ības_, coks_, بوري_, _भग्न_, 
   {{0x94751147,0x82d802dd,0x2de401ec,0x00000000}},	// [196b0] ادفا, мдас_, _ﻋﻅﻴﻤ, --, 
   {{0x68fc0477,0x212c0399,0x8574059f,0x798c0210}},	//   _hoqd, wngh_, _илох, _ławi, 
   {{0x672405be,0x6928012c,0x02d00034,0x7d0833b8}},	//   mijj, před, _हसीन, ykes, 
   {{0xc60c02ab,0x68fc014f,0x67242252,0x925801d5}},	//   सनीय_, _joqd, lijj, رشلر_, 
   {{0x68fd1334,0xa4991335,0x9fdc0011,0x00000000}},	//   _moqd, _flòr, বঙ্গ, --, 
   {{0x443802fa,0x7d0801ab,0x68fc0369,0xa4991336}},	//   _ixs_, wkes, _loqd, _glòr, 
   {{0x7d081059,0x6294022e,0xadb40472,0x00000000}},	//   tkes, maxo, نهوا_, --, 
   {{0x68fc0a81,0x62951337,0x2efc009f,0x67245da9}},	//   _noqd, laxo, _eotf_, hijj, 
   {{0x7d087963,0x67240337,0xbbbc06b1,0x00000000}},	//   rkes, kijj, ्बेक, --, 
   {{0xf8a8085c,0x60d91338,0x672454f8,0x629401a9}},	//   कल्प, _haum, jijj, naxo, 
   {{0x60d91339,0x68fd133a,0x3941133b,0x67249073}},	//   _kaum, _boqd, toks_, dijj, 
   {{0x60d84fcf,0x6605133c,0xc0f0001f,0x6d8800e5}},	//   _jaum, dyjk, ፃፀም_, _آمنہ_, 
   {{0x60d9133d,0x3941133e,0x68fc014f,0x672401fa}},	//   _maum, roks_, _doqd, fijj, 
   {{0x60d9133f,0xfaa51340,0x2ba40034,0x67241418}},	//   _laum, _рако, _खिता, gijj, 
   {{0x8c640166,0x62951341,0x9f4c00e5,0x39400254}},	//   _итәд, daxo, lygó_, poks_, 
   {{0x68fc0369,0x443800db,0xb7e400db,0x741400be}},	//   _goqd, _bxs_, _ажик, نوزا, 
   {{0x67251342,0x00000000,0x00000000,0x00000000}},	// [196c0] bijj, --, --, --, 
   {{0x62940117,0xb46401ec,0x6724002b,0x00000000}},	//   gaxo, екұл, cijj, --, 
   {{0x44380334,0x68fc01b9,0x437401e0,0x6604012d}},	//   _exs_, _yoqd, _ҡурт, cyjk, 
   {{0x60d91343,0xa378000d,0x00000000,0x00000000}},	//   _caum, _krõl, --, --, 
   {{0x60d91344,0x7c2d1345,0xa0640063,0x62951346}},	//   _daum, _žarn, ваца_, baxo, 
   {{0x60d80069,0x64400276,0x62940077,0xdfcc02eb}},	//   _eaum, şnic, caxo, تيه_, 
   {{0x2050b392,0x60d81140,0x00000000,0x00000000}},	//   лтәр, _faum, --, --, 
   {{0x60d91347,0x67241418,0x5ce01b56,0x00000000}},	//   _gaum, zijj, لكىل, --, 
   {{0x6f641fc7,0x2eb400c7,0x4438332e,0x5ec40eac}},	//   _аваз, _асес, _xxs_, লয়ে, 
   {{0x60d802ce,0x6f641e95,0xdb18067c,0x68fc047e}},	//   _zaum, _شهام, ntuè, _soqd, 
   {{0x7c2c008c,0x68fc014f,0x00000000,0x00000000}},	//   _þarn, _poqd, --, --, 
   {{0x68fc047e,0xdca11348,0x629401a9,0x00000000}},	//   _qoqd, _ваци, zaxo, --, 
   {{0x6928038e,0x62951349,0x4bc5134a,0x98488675}},	//   třeb, yaxo, _сөйг, вяра_, 
   {{0x4ee002f5,0x6b80de20,0xe9e40276,0x64481cb0}},	//   _বকুল, _itog, _ацио, ügim, 
   {{0x69f05f69,0x68fc016d,0x6725134b,0x974c0023}},	//   _түнт, _toqd, rijj, _ሓጥያት, 
   {{0x672401fa,0x629401f0,0x6604012d,0x8505134c}},	//   sijj, waxo, ryjk, دورن, 
   {{0x60d9134d,0x6295134e,0x8335134f,0x69280118}},	// [196d0] _raum, taxo, гнах, přeb, 
   {{0x60d8b019,0x6b800161,0xa280277d,0x00000000}},	//   _saum, _mtog, شیرو, --, 
   {{0x60d91350,0x62951351,0xa26401a9,0x00000000}},	//   _paum, raxo, тъал, --, 
   {{0x60d80357,0x6b811352,0x69c80036,0xd1b80131}},	//   _qaum, _otog, _mpfe, ئالا_, 
   {{0xd91c04ac,0x629418f7,0x44380ffb,0x60d80099}},	//   וואל, paxo, _uxs_, _vaum, 
   {{0x60d91353,0x69c91354,0x7c2c0427,0xdb18067c}},	//   _waum, _opfe, _žaro, ctuè, 
   {{0x60d91355,0x3ea82523,0x21640830,0x00000000}},	//   _taum, ğat_, _атаг, --, 
   {{0x3ea91356,0x5ba01638,0x9258147e,0xa3d40d2c}},	//   şat_, алиғ, _раст_, _ाना_, 
   {{0x69c80730,0x6e391357,0xfc04034b,0xc0340e92}},	//   _apfe, _extb, уппо, _снај, 
   {{0x6b80007b,0x69280118,0xab606c68,0x00000000}},	//   _dtog, yřec, مۇنى, --, 
   {{0x6b811358,0xdb191359,0x64480037,0x00000000}},	//   _etog, ntué, ügij, --, 
   {{0x8d740058,0x224400bc,0x00000000,0x00000000}},	//   _ئالا, ýnky_, --, --, 
   {{0x2d9801a6,0x69dc0118,0xaf240154,0x87b8004e}},	//   špet_, _špet, মকরণ_, курт_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf60801b9,0x1ae000fb,0x68ec00ae,0x00000000}},	//   رتسه_, _боҙм, áidí, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [196e0] --, --, --, --, 
   {{0xdb18002e,0x00000000,0x00000000,0x00000000}},	//   owuñ, --, --, --, 
   {{0x64dc01f9,0x00000000,0x00000000,0x00000000}},	//   _पोकळ, --, --, --, 
   {{0xdef4052f,0x309400db,0xdce0013d,0x00000000}},	//   ғыш_, اشاس, ksnı, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa8540375,0x399000e2,0x00000000,0x00000000}},	//   ניסה_, kšs_, --, --, 
   {{0xdb1807ea,0x00000000,0x00000000,0x00000000}},	//   ctué, --, --, --, 
   {{0xfb7000d1,0x200c030a,0x907400d1,0x42500244}},	//   ﭼﯜﺭﯛ, ñjiñ_, _ئۇشش, _بۆمر, 
   {{0x6eb45085,0x7c2c032e,0x00000000,0x00000000}},	//   _مصائ, _þarl, --, --, 
   {{0x38700209,0x6e38010a,0x2d940114,0x298400cf}},	//   _agyr_, _txtb, _брдс, лымг, 
   {{0x9980dbec,0x99940166,0xed5801f4,0x00000000}},	//   یلیو, лкэт_, _зож_, --, 
   {{0xdd8c168d,0x644800af,0x6b800337,0x00000000}},	//   _روه_, ügik, _ttog, --, 
   {{0x6b800472,0xd838d391,0x00000000,0x00000000}},	//   _utog, гэр_, --, --, 
   {{0x38700142,0xd6d8180b,0xd7500257,0xadf8012d}},	//   _egyr_, лтс_, _ማእከሎ, _्थान_, 
   {{0xda04b8ee,0x45d4034f,0x00000000,0x00000000}},	//   _ميوه_, шовс, --, --, 
   {{0x998006d5,0x00000000,0x00000000,0x00000000}},	//   _اليو, --, --, --, 
   {{0xf948010f,0x00000000,0x00000000,0x00000000}},	// [196f0] _שעפֿ, --, --, --, 
   {{0x826801d3,0x00000000,0x00000000,0x00000000}},	//   نشاہ_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x19b400c8,0x00000000,0x00000000,0x00000000}},	//   רפאר_, --, --, --, 
   {{0x4ac4725a,0x656c019b,0x65740200,0x453400db}},	//   वभाव, _iich, _huxh, _مىگر, 
   {{0x656d135a,0x65746ae5,0x8e7c01e4,0x0354013d}},	//   _hich, _kuxh, _naĝd, _түзә_, 
   {{0x656d135b,0x92580408,0x56b80375,0x65740200}},	//   _kich, _барт_, אפון_, _juxh, 
   {{0x656d135c,0x65740240,0x2ba40073,0x80dc0037}},	//   _jich, _muxh, _खिशा, _नोचइ, 
   {{0x656d135d,0x657401b3,0x644800c5,0x81ac00cc}},	//   _mich, _luxh, ügih, _কনট_, 
   {{0xa37800e4,0x644d135e,0xfaa410fc,0x777401a9}},	//   _arõk, _myci, јано, _ruyx, 
   {{0x69dc0232,0x644c0381,0x76cc015b,0x656d135f}},	//   _šper, _lyci, িএমএ, _oich, 
   {{0x656d1360,0xf8642e82,0x3e54004d,0x00000000}},	//   _nich, ивно, _ít_, --, 
   {{0x644c00b5,0x0c7400cf,0xcc080035,0x2d6c01ef}},	//   _nyci, _ادمد, _مزون_, _křen_, 
   {{0x656d1361,0x65751362,0x8d8400f7,0x3d1001e1}},	//   _aich, _buxh, _ئشەن, _káwo_, 
   {{0x656d1363,0x65747dac,0x6600ff8f,0xe5a00131}},	//   _bich, _cuxh, опра, жиси, 
   {{0x2a380375,0x656d1364,0x644c033f,0x64400213}},	//   _בעצמ, _cich, _byci, əniz, 
   {{0x24041a4f,0x8e7c00e4,0x69dc0077,0xb60000bc}},	// [19700] анти_, _haĝe, _áper, _řádn, 
   {{0x656d1365,0x387c013f,0x00000000,0x00000000}},	//   _eich, ɛtra_, --, --, 
   {{0x65740200,0x00000000,0x00000000,0x00000000}},	//   _guxh, --, --, --, 
   {{0x2ba42007,0x656c030a,0x8e7c01e4,0x00000000}},	//   _खिला, _gich, _maĝe, --, 
   {{0xca3800df,0x602000c0,0x00000000,0x00000000}},	//   maĝe_, одца, --, --, 
   {{0x656d1366,0xf1a8021a,0x3d100ca8,0x3ea40129}},	//   _zich, _لاره_, _báwo_, _cdlt_, 
   {{0x656d1367,0xdd951368,0x23251369,0xa37800e4}},	//   _yich, ашы_, _тори_, _arõh, 
   {{0x656c18f7,0x6141136a,0x3d100248,0x1da45edd}},	//   _xich, _деса, _dáwo_, _गिरत, 
   {{0xa065136b,0xe0cc0050,0xdb9400fd,0x3f480162}},	//   _вата_, _زٲل_, авыч_, rúur_, 
   {{0xada400d6,0x3d100248,0xdb2001a8,0x6da4013e}},	//   _важл, _fáwo_, ærði, _вижа, 
   {{0xe2980375,0xed340166,0xdee008ca,0x405400e5}},	//   כשיר, _кэдэ, _фохи, _نئےس, 
   {{0xca3801e4,0xe7e00d2e,0x00000000,0x00000000}},	//   jaĝe_, खिला_, --, --, 
   {{0x656d136c,0x65740200,0x57b40395,0x81ac05ac}},	//   _rich, _suxh, обят, _কনছ_, 
   {{0x644d136d,0x2054010f,0x56940816,0xdb4c00d4}},	//   _ryci, ייכל_, жарт, _єю_, 
   {{0x656d136e,0x644c003a,0x24f4035b,0x8894030d}},	//   _pich, _syci, аҽны_, _лийх, 
   {{0x842404a9,0x656d136f,0x75340007,0x00000000}},	//   مىزن, _qich, gnyz, --, 
   {{0x656d1370,0x00000000,0x00000000,0x00000000}},	// [19710] _vich, --, --, --, 
   {{0x656d1371,0xded0001f,0x7c34000f,0x644c13d5}},	//   _wich, ሩትን_, _ôfrű, _vyci, 
   {{0x656d1372,0x644c068f,0x048804a9,0x2ca401e1}},	//   _tich, _wyci, _бәзи_, _odod_, 
   {{0x2ca40472,0x8e7c01e4,0x656cf7c7,0xfc380115}},	//   _ndod_, _naĝb, _uich, laŭe_, 
   {{0x3ea4004e,0x3d1001e1,0xc0c801f3,0xdd1c01ef}},	//   _pdlt_, _sáwo_, _በዓለ_, cířs, 
   {{0x3d100248,0x4f2400d4,0xaf440050,0x00000000}},	//   _páwo_, одіб, ٝرى۪, --, 
   {{0x5184085a,0x69280316,0xe0d0027d,0x9268009b}},	//   _мута, vřen, _وزر_, _врта_, 
   {{0xca300020,0x3d94036b,0x1638011a,0x2c680cad}},	//   _ጥያቄዎ, _ҳижр, ינור_, _ẹda_, 
   {{0x69280316,0x2ca400a9,0x8e7c010f,0xb14404fb}},	//   třen, _ddod_, _saĝe, _اینم_, 
   {{0x2ca40165,0xd1e002d3,0xc0c800b7,0xdb18004e}},	//   _edod_, _ዓሰብ_, _በዓሉ_, rtuï, 
   {{0x39451373,0x8a38005b,0x37bc0154,0x00000000}},	//   йног, ияют_, েয়ার, --, 
   {{0xec1000db,0x00000000,0x00000000,0x00000000}},	//   توۋد, --, --, --, 
   {{0x9ba00131,0xbb8400c6,0x69280118,0x6d54008f}},	//   _بەخى, _التي, mřel, _פינף_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69dc00e4,0x64400205,0x00000000,0x00000000}},	//   _ápep, şnil, --, --, 
   {{0x15b84908,0x00000000,0x00000000,0x00000000}},	//   лығы_, --, --, --, 
   {{0x27b11374,0xca38010f,0x13a802f2,0x6b78010f}},	// [19720] _нәрс, raĝe_, شنای_, ָרענ, 
   {{0x324400fd,0x63a801d3,0x3dc8012d,0xc4080014}},	//   безг, ágna, ławy_, گتہٕ_, 
   {{0xc76434b1,0xca3801e4,0x00000000,0x00000000}},	//   _بايى, paĝe_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3ae000b0,0x2d6c013a,0x2a680092,0x692801ef}},	//   _kōpē_, _dřel_, ደሆነች_, dřel, 
   {{0xe454008f,0x00000000,0x00000000,0x00000000}},	//   _ליכט_, --, --, --, 
   {{0x64480037,0x00000000,0x00000000,0x00000000}},	//   ügiv, --, --, --, 
   {{0x712401d5,0xfc3801e4,0x5c700395,0x00000000}},	//   _طرزل, zaŭe_, плът, --, 
   {{0x77e001ad,0x6eb80ca5,0xc0d00092,0xe1640244}},	//   गटोक_, _مداح_, ሩንም_, _اڵله_, 
   {{0xdfcc1bf4,0x00000000,0x00000000,0x00000000}},	//   _سيم_, --, --, --, 
   {{0xbf6001d9,0x6ce443a2,0x00000000,0x00000000}},	//   _تۯوو, _гіле, --, --, 
   {{0xeb980323,0xec786b1d,0x58851375,0x00000000}},	//   _бид_, _спд_, зыра, --, 
   {{0xfc3804ac,0xab291376,0xc0480023,0x1dc000db}},	//   taŭe_, _йода_, _እናተገ, _дөөн, 
   {{0x798001f2,0xa49800a3,0xdc3800c8,0x81c0009e}},	//   _ịwep, _eoòl, _געדר, ্টত_, 
   {{0x2b4c0810,0x50c81788,0xfc38010f,0xfa5400cf}},	//   _ikfc_, रभाष, raŭe_, _ورىگ, 
   {{0xd4991377,0xdb180356,0x6ab801bf,0x00000000}},	//   йру_, ctuâ, lgtf, --, 
   {{0xc29805b0,0x0fd400bc,0x00000000,0x00000000}},	// [19730] иках_, _धनगढ, --, --, 
   {{0x6ab91378,0xd054013f,0x45d45378,0x20d0004d}},	//   ngtf, _ɔbɔf, _доос, _ải_, 
   {{0xe5c48bbe,0x31640166,0x00000000,0x00000000}},	//   _успо, fmoz_, --, --, 
   {{0xc60407f7,0x7c2c00a2,0x00000000,0x00000000}},	//   रहीय_, _ýarg, --, --, 
   {{0xa37800c7,0x692800bc,0xefe80092,0x00000000}},	//   _arõv, vřel, _መተው_, --, 
   {{0x3f691379,0xef1401a9,0x00000000,0x00000000}},	//   шило_, жмш_, --, --, 
   {{0x692800bc,0x90280022,0x00000000,0x00000000}},	//   třel, ицәа_, --, --, 
   {{0x5185137a,0x3b84f027,0xdb180077,0x31640166}},	//   _хура, олиг, rtuí, cmoz_, 
   {{0xfc30eaff,0x212d137b,0x00000000,0x00000000}},	//   بحث_, migh_, --, --, 
   {{0x212d137c,0x00000000,0x00000000,0x00000000}},	//   ligh_, --, --, --, 
   {{0xfbd0036b,0xe9d40276,0x212d137d,0x200d137e}},	//   ستک_, окэ_, oigh_, lygi_, 
   {{0xc688b4a1,0x212c0597,0x00000000,0x00000000}},	//   _יא_, nigh_, --, --, 
   {{0x81c009bd,0xfaa448f2,0x4c34004e,0x314c0023}},	//   ্টি_, _дало, _нэшт, _ንኣብር, 
   {{0x212c0192,0x2d58006a,0xfa680228,0x7a6801ee}},	//   high_, nëen_, _калк_, _килг_, 
   {{0x36683169,0xe7340006,0x316404cc,0x75d4007b}},	//   раво_, цер_, ymoz_, غيرا, 
   {{0x8e7c01e4,0xf1f80214,0x69280118,0xf77001e2}},	//   _maĝa, یعات_, hřej, _ښاد_, 
   {{0x7c2c0209,0x7304d62a,0x212c007b,0xa3e5137f}},	// [19740] _ýard, опаз, digh_, одта_, 
   {{0xf1a8212d,0xca3800df,0x00000000,0x00000000}},	//   لاصه_, laĝa_, --, --, 
   {{0x8e7c00df,0x75440aa8,0x69280118,0x212c01e7}},	//   _naĝa, _мноз, dřej, figh_, 
   {{0x212c00c6,0xca380115,0x00000000,0x00000000}},	//   gigh_, naĝa_, --, --, 
   {{0x3164067c,0x644800c5,0x2fd475b0,0x636001f2}},	//   rmoz_, ügit, تتاح, ọnar, 
   {{0x212c1549,0x316401c4,0xa3e400cd,0x00000000}},	//   aigh_, smoz_, भिर_, --, 
   {{0x5d80088c,0x212c022f,0xa2e00276,0x00000000}},	//   ولول, bigh_, _юорд, --, 
   {{0x7d18015d,0x212c007b,0xca380115,0x69280118}},	//   _clws, cigh_, jaĝa_, třem, 
   {{0x93300020,0x69d80327,0x00000000,0x00000000}},	//   _ተከታታ, wwte, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2fc43e04,0x69d801f5,0x2bf80154,0x2d8000d1}},	//   ltog_, uwte, ইনেই_, _ﻧﺎﻣﻰ_, 
   {{0x7c64104a,0x2d8d1380,0x2fc40158,0x7d180042}},	//   _کامل, mpfe_, otog_, _glws, 
   {{0x2fc51381,0xd7e489bf,0x00000000,0x00000000}},	//   ntog_, міро, --, --, 
   {{0x29d800b0,0x2fc4017a,0x00000000,0x00000000}},	//   _tūa_, itog_, --, --, 
   {{0xc1c8068f,0x00000000,0x00000000,0x00000000}},	//   _रहेग, --, --, --, 
   {{0x69280316,0x2fc51382,0x89d80451,0xa3cc09bb}},	//   zřej, ktog_, _نوڪر_, _शहद_, 
   {{0x6f180276,0x2918031c,0x66c817a0,0xdce80055}},	// [19750] _oltc, _ilqa_, _кунг_, _jigā, 
   {{0x2fc4037e,0x81c00154,0x00000000,0x00000000}},	//   dtog_, ্টস_, --, --, 
   {{0x212c0597,0xdb191383,0x40945734,0xe7e021bd}},	//   tigh_, ntuá, كلار, खिका_, 
   {{0x6f18084c,0x691c002e,0x644800c5,0x8e7c01e4}},	//   _altc, _dëeg, ügis, _raĝa, 
   {{0x2fc51384,0x212c379c,0x2d58006a,0xbbd80316}},	//   gtog_, righ_, tëen_, _भनेक, 
   {{0x212d1385,0xdb181ab0,0x8e7c008f,0xca3800df}},	//   sigh_, ktuá, _paĝa, zaĝa_, 
   {{0x20d51386,0x62847c1d,0x2918ccb5,0x171c010f}},	//   _وترج, _ifjo, _olqa_, שווע, 
   {{0xbe54044e,0xa3cc01f9,0x00000000,0x00000000}},	//   _ምንጭታ, _शहा_, --, --, 
   {{0xceb8002d,0x692800bc,0xca38010f,0xdce80171}},	//   _blęd_, přej, vaĝa_, _cigā, 
   {{0x29191387,0xdce800b8,0xbda40133,0xceb40114}},	//   _alqa_, _digā, _فۆتۆ_, _обућ, 
   {{0xdb18381a,0xca380115,0xc1c821f2,0x0dc800f3}},	//   rtuà, taĝa_, _रहोग, _муци_, 
   {{0x7c2c92ca,0x7bdc0003,0x1a6401e2,0x00000000}},	//   _žaru, ħsub, میږی_, --, 
   {{0x69dc006a,0x6aa80175,0x3dbc00fe,0xca38008f}},	//   _âpen, _fdff, _আনিল, raĝa_, 
   {{0xbbe80a98,0x2918047e,0x1d9c0092,0xca3800df}},	//   _پرچم_, _elqa_, _ሂደቶች_, saĝa_, 
   {{0xca3801e4,0xdb191388,0x2d6c013a,0x00000000}},	//   paĝa_, ctuá, _břeh_, --, 
   {{0xb4e42232,0xaa54007b,0xe45c002f,0x3dac00fe}},	//   पये_, _عليا_, _bzö_, _কঙাল, 
   {{0x06d02158,0xa50406bb,0xa4409a58,0x3980022c}},	// [19760] ায়ি, чета_, ентд, _hós_, 
   {{0xfa281b35,0x213c4db4,0x39811389,0x00000000}},	//   _སྟོན_, _ajuh_, _kós_, --, 
   {{0xc8b468cf,0x765c0064,0x61f80139,0x6448000d}},	//   _علیک, _uzpy, _ƅula, ügir, 
   {{0x39800162,0xfc380115,0x00000000,0x00000000}},	//   _mós_, zaŭa_, --, --, 
   {{0xa3e40a28,0x398001e1,0x04c800f1,0x00000000}},	//   भिः_, _lós_, _بوټي_, --, 
   {{0x9c8400d1,0x71a401f0,0x00000000,0x00000000}},	//   ۋپىق_, _нагз, --, --, 
   {{0x3981138a,0xe294ad60,0xb63c00b5,0x52d800af}},	//   _nós_, _хас_, _ａｎ_, ड़ीस, 
   {{0xfa280135,0xa3b0012c,0x2fc5138b,0x213c0240}},	//   _སྟེན_, _टिम_, ptog_, _gjuh_, 
   {{0x6141138c,0xfc38008f,0x00000000,0x00000000}},	//   _чета, taŭa_, --, --, 
   {{0x39807bd7,0x3dc80227,0x39500024,0x692800bc}},	//   _bós_, ńawa_, _akys_, přek, 
   {{0x3980d015,0x62800841,0x6da40120,0xfc38010f}},	//   _cós_, žnog, _ѕида, raŭa_, 
   {{0xdb1828ca,0x8e7c0115,0x18a407b5,0x398009e8}},	//   rtuá, _kaĝo, наџм, _dós_, 
   {{0xdb1806ed,0x00000000,0x00000000,0x00000000}},	//   stuá, --, --, --, 
   {{0x39800491,0xdb1802f0,0xc62400fe,0xd9a40150}},	//   _fós_, ptuá, _মুগা_, _ﻋﻨﺩﻩ_, 
   {{0xe3b01968,0xca38010f,0x2988009b,0x00000000}},	//   کرز_, maĝo_, _усло_, --, 
   {{0xca38008f,0x29180309,0x64a407b6,0x00000000}},	//   laĝo_, _ulqa_, गणेश, --, 
   {{0x73c046e8,0x8e7c01e4,0xc62400fe,0x93784eca}},	// [19770] кәре, _naĝo, _মুখা_, збут_, 
   {{0xca38010f,0x00000000,0x00000000,0x00000000}},	//   naĝo_, --, --, --, 
   {{0x8e7c01e4,0xbd74001f,0x4f4c0023,0x00000000}},	//   _paĝn, ጠቃቀም_, _ንሃዋር, --, 
   {{0xd7c8082a,0x7fd40150,0x00000000,0x00000000}},	//   _بویه_, дікі, --, --, 
   {{0x691c01c7,0xca3801e4,0x2d58002e,0xdb2001d3}},	//   _gëee, kaĝo_, rëel_, űség, 
   {{0xca38008f,0x33f800d9,0x00000000,0x00000000}},	//   jaĝo_, _והשנ, --, --, 
   {{0xc0c402dd,0x692800bc,0xf2d0011a,0xdb180166}},	//   _ошақ, přeh, _שעל_, ltuç, 
   {{0x3981138d,0xb91000b8,0x00000000,0x00000000}},	//   _rós_, bbaṃ_, --, --, 
   {{0xfaa4405c,0x92e00183,0x39803add,0xfc30007b}},	//   үшүн, থাৰ_, _sós_, ضحة_, 
   {{0x39800261,0xab600131,0xfa28031c,0xca3801e4}},	//   _pós_, نۇنى, _སྟུན_, gaĝo_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3981138e,0x9ba021ef,0xa0480023,0x2ba40b26}},	//   _vós_, _كەبى, _ንሓንሳ, _खिचा, 
   {{0x69cc0209,0x200800cf,0x38580c4b,0x8e7000c7}},	//   çber, _àcid_, تشدد_, _иқәш, 
   {{0x7bc800ec,0x00000000,0x00000000,0x00000000}},	//   mteu, --, --, --, 
   {{0x7bc9138f,0x2e2c001f,0xc5d400d4,0x00000000}},	//   lteu, _እንደዘ, ніть, --, 
   {{0x7bc8bc38,0xa998011a,0x7c2c032e,0x00000000}},	//   oteu, _ובקר, _þars, --, 
   {{0x7bc91390,0x3f8c0098,0x3a0401ed,0x644800c5}},	// [19780] nteu, _nteu_, _رکھی_, ügip, 
   {{0xa3cc09bb,0x7bc91391,0xe3b44f35,0xf1d0004e}},	//   _शहर_, iteu, ьбу_, көбө, 
   {{0x3f8c09b1,0x63b84606,0x8e7c00df,0x7bc80108}},	//   _ateu_, _åunn, _saĝo, hteu, 
   {{0x8e7c04ac,0x7bc91392,0xca38008f,0xf494072d}},	//   _paĝo, kteu, zaĝo_, _تشدد, 
   {{0xb36c001f,0xaf4800f1,0x06300092,0xe82c0092}},	//   ባለውን_, يشتل_, _አስደነ, _አንተነ, 
   {{0xed883596,0x2578063f,0xf1a905bf,0x7538068c}},	//   осик_, ụlee_, _وازه_, ètzf, 
   {{0x3e340023,0x2d9800e4,0x00000000,0x00000000}},	//   _ክንከይ, èpe_, --, --, 
   {{0x71a4016c,0xa378000d,0x7bc80129,0x2c6001b9}},	//   _наҳз, _krõp, fteu, lаdi_, 
   {{0xaec51393,0x2e2c001f,0xca380115,0x2dd401d9}},	//   _обал, _እንዲዘ, taĝo_, سُکھ_, 
   {{0x1f611394,0x98a0068f,0x2c6001a9,0x00000000}},	//   _акум, _imię_, nаdi_, --, 
   {{0x7bc91395,0xd7100183,0xca38010f,0xddc0022e}},	//   ateu, হোৱা_, raĝo_, _абхи, 
   {{0xca38008f,0x6928013a,0x00000000,0x00000000}},	//   saĝo_, hřev, --, --, 
   {{0x7bc91396,0x6d400022,0xac38179e,0xca38010f}},	//   cteu, _ijoa, _بساط_, paĝo_, 
   {{0x7c2c09a5,0xdce80356,0x00000000,0x00000000}},	//   _ýara, _tigă, --, --, 
   {{0x95c80b3b,0x2d6c01ef,0x6928013a,0x00000000}},	//   мута_, _dřev_, dřev, --, 
   {{0xd1f80092,0xa6dc0154,0x00000000,0x00000000}},	//   ጊነት_, মাইয়, --, --, 
   {{0x8e7c01e4,0x00000000,0x00000000,0x00000000}},	// [19790] _paĝl, --, --, --, 
   {{0xda78010f,0xae1c0d2e,0x00000000,0x00000000}},	//   ַנדר, बनान_, --, --, 
   {{0x518402d5,0x857405cc,0xab040086,0x6d400588}},	//   вуча, _плох, ùrùñ_, _ojoa, 
   {{0xe1f001d5,0x7bc8003a,0x00000000,0x00000000}},	//   _یسز_, yteu, --, --, 
   {{0x62800419,0x00000000,0x00000000,0x00000000}},	//   ľnob, --, --, --, 
   {{0x6280009b,0x6d411397,0xdbc40108,0x4fc400d1}},	//   žnob, _ajoa, _kööp, ئەلە, 
   {{0x9258109a,0xa3e44721,0xfc3800df,0x20c4005b}},	//   _жарт_, भिक_, taŭo_, _осаг, 
   {{0x7bc91398,0x50f400a7,0x00000000,0x00000000}},	//   tteu, _изст, --, --, 
   {{0x7bc91399,0x6d4001a6,0x4fc40952,0xfc380115}},	//   uteu, _djoa, _асха, raŭo_, 
   {{0x7bc9139a,0x6d4000c7,0x9e6400db,0xfc3801e4}},	//   rteu, _ejoa, _قاان, saŭo_, 
   {{0xf2d000c8,0x13d8015b,0xdbc40037,0x00000000}},	//   נעט_, সিয়, _nööp, --, 
   {{0x7bc90746,0x2c60022e,0x00000000,0x00000000}},	//   pteu, zаdi_, --, --, 
   {{0x395c00da,0x00000000,0x00000000,0x00000000}},	//   ēts_, --, --, --, 
   {{0x06b80014,0x00000000,0x00000000,0x00000000}},	//   ونُک_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa5040902,0xa964005b,0xade000c5,0x66000150}},	//   неса_, _пища_, _कईसन_, ыпса, 
   {{0x33650fce,0xd87800f1,0xa938011a,0x2c60022e}},	// [197a0] еваг, _کمښت_, _מתקפ, tаdi_, 
   {{0x78a5139b,0x00000000,0x00000000,0x00000000}},	//   lakv, --, --, --, 
   {{0xda0c1d8a,0xe294e7bf,0xc0600023,0xcff8000d}},	//   ाहित_, хах_, _ዝሓለፍ, ंम्भ_, 
   {{0x78a5139c,0xee3805f5,0xddc9139d,0x1acc085c}},	//   nakv, үнд_, _şişk, त्तथ, 
   {{0x69280118,0x6440002f,0xf6740244,0x00000000}},	//   přev, ßnit, _تاکخ, --, 
   {{0x6d400158,0x7c780092,0x2c60022e,0xda0c0073}},	//   _sjoa, _የቢሮው_, qаdi_, ाहात_, 
   {{0xe354159d,0x78a404b9,0x2050052f,0xd1d4001f}},	//   _נשלח_, kakv, ктәр, ረቶች_, 
   {{0xafe5139e,0x716400d1,0xaac000bc,0xe478010f}},	//   _побл, _سازك, _शाहक, ּריכ, 
   {{0x9f9400c7,0x78a401e4,0x3ec4005b,0x00000000}},	//   _зыхә, dakv, ästö_, --, 
   {{0x91c40073,0x8a1801c6,0x00000000,0x00000000}},	//   ांपै, доос_, --, --, 
   {{0x5ee000eb,0x78a402d2,0x00000000,0x00000000}},	//   পাশে, fakv, --, --, 
   {{0x6d4001f0,0xdbc4000d,0xca8401c6,0x78a4032e}},	//   _ujoa, _rööp, эгүй, gakv, 
   {{0xd7f829db,0x5ee0015b,0xe7bc015b,0xabb00166}},	//   нур_, পারে, ইব্য, _салә, 
   {{0x6b800618,0x2d9c0810,0x7c6400d1,0x00000000}},	//   _iuog, _kwte_, _شانل, --, 
   {{0x6b8001f7,0x78a400df,0x00000000,0x00000000}},	//   _huog, bakv, --, --, 
   {{0x6b800451,0xda58011a,0xd9101888,0x00000000}},	//   _kuog, _מכול, _هیپ_, --, 
   {{0xade00037,0x7800014b,0x00000000,0x00000000}},	// [197b0] _कैसन_, _кӯра, --, --, 
   {{0xdbc4007d,0x6b8001f7,0xd3243cc5,0xded00092}},	//   _tööp, _muog, льхи, ዩትን_, 
   {{0x6b8006bb,0x5344013e,0x9f48003e,0x97580375}},	//   _luog, ухта, _écé_, _איזו_, 
   {{0xc0600240,0x00000000,0x00000000,0x00000000}},	//   _ዝሓልፍ, --, --, --, 
   {{0x6b800006,0x00000000,0x00000000,0x00000000}},	//   _nuog, --, --, --, 
   {{0x4429139f,0xc2c40451,0x63bc0309,0xdb040162}},	//   mza_, _جيسي, muqn, _óløn, 
   {{0xfce400d4,0x78a400e4,0x409400ae,0x00000000}},	//   войо, yakv, _للأر, --, 
   {{0x442913a0,0x6b8004cc,0xd13801c6,0x8d841bf4}},	//   oza_, _buog, _зху_, دشون, 
   {{0x78a40cfe,0x69c80327,0x6b8004cc,0xcb0c0c70}},	//   vakv, _aqfe, _cuog, ाउंड_, 
   {{0x442913a1,0x6b8001a9,0x6d4c032e,0x00000000}},	//   iza_, _duog, _íban, --, 
   {{0x8b649c97,0x6b80015d,0xab60009d,0xe9a400ec}},	//   دايم, _euog, рвэл, نگين_, 
   {{0xe8f477c1,0x63bc0309,0x6c304ea7,0xa49801e1}},	//   влю_, kuqn, افیا, _moòs, 
   {{0x7d081f7f,0x442913a2,0x78a513a3,0x69280118}},	//   mjes, jza_, rakv, vřet, 
   {{0x442913a4,0x7d083e5d,0x26c00217,0x7c2913a5}},	//   dza_, ljes, ggjo_, mzer, 
   {{0x442913a6,0x7c2913a7,0xd6e40729,0x6b8004cc}},	//   eza_, lzer, মালয, _zuog, 
   {{0x3ced13a8,0x7d0913a9,0x442801fa,0x7c2805c7}},	//   ndev_, njes, fza_, ozer, 
   {{0x7c2913aa,0x63bc0357,0x442913ab,0x638001c0}},	// [197c0] nzer, guqn, gza_, игта, 
   {{0x7d0808e5,0xa3e400bc,0x7534022e,0xade00037}},	//   hjes, भिज_, siyz, _कईलन_, 
   {{0x44280262,0x7d0913ac,0x63681a80,0x69280118}},	//   aza_, kjes, künf, přet, 
   {{0x442816b7,0x7d08022f,0x7bd81983,0x7c28ef17}},	//   bza_, jjes, _opwu, kzer, 
   {{0x4428006d,0x7c2913ad,0x39400175,0xa6440092}},	//   cza_, jzer, inks_, _የስደተ, 
   {{0x7c2913ae,0x6b8004cc,0x437403d0,0x3ec401b9}},	//   dzer, _ruog, _буст, лқум_, 
   {{0x6b8004cc,0x21a02069,0x6368002f,0x7d080200}},	//   _suog, _висм, fünf, fjes, 
   {{0x7d0913af,0x6b8113b0,0x6fb4007b,0x9f800022}},	//   gjes, _puog, _لمرا, ыгәд, 
   {{0x7c282622,0xca3800df,0xa21801e1,0x7c2c0432}},	//   gzer, maĝi_, _lọ́f, _ýarl, 
   {{0x2d6c0316,0x3cec00ca,0x7d08022f,0xa49801e1}},	//   _přes_, adev_, ajes, _joòr, 
   {{0x442913b1,0x7d0816a3,0x7c2806be,0x00000000}},	//   zza_, bjes, azer, --, 
   {{0x442913b2,0x6b800093,0x3cece607,0x8e7c00df}},	//   yza_, _tuog, cdev_, _naĝi, 
   {{0x7c280034,0x996401c0,0x5984009d,0xa09800df}},	//   czer, ртэл, нөөн_, ויכט, 
   {{0x442913b3,0x0708216b,0x69280118,0x63bc01a9}},	//   vza_, ريزي_, třes, vuqn, 
   {{0xabb00075,0x26c0036e,0x63bc014f,0x442913b4}},	//   _саһә, rgjo_, wuqn, wza_, 
   {{0x4428ab76,0xca38010f,0x63bc014f,0x2e2c0023}},	//   tza_, jaĝi_, tuqn, _እንዕዘ, 
   {{0x442913b5,0x55580262,0xf948010f,0x00000000}},	// [197d0] uza_, татя_, _רעפֿ, --, 
   {{0x692800bc,0x7d0913b6,0x9f5c0342,0x3cec0072}},	//   přes, zjes, ürüm_, zdev_, 
   {{0x442913b7,0x636804cc,0xc5f001d3,0x2eec0175}},	//   sza_, hüng, _آج_, ddff_, 
   {{0x4428020b,0x63bc02d1,0xca3801e4,0x00000000}},	//   pza_, puqn, gaĝi_, --, 
   {{0x7d081f7f,0x63bc01b9,0x7c2800b5,0xaac00073}},	//   vjes, quqn, xzer, _शांक, 
   {{0x6368006a,0x04440022,0x0b14009e,0xf07800d1}},	//   düng, _аеҭн, াফুল_, хичә_, 
   {{0x533513b8,0x7d08afc9,0x3cec0327,0x00000000}},	//   _терт, tjes, tdev_, --, 
   {{0x7c2913b9,0x2efc0112,0xf1b0011a,0x7d080210}},	//   tzer, _entf_, _לסל_, ujes, 
   {{0x7d0913ba,0x9f5c0639,0x7c2913bb,0x7fb800aa}},	//   rjes, _gruß_, uzer, _سهار_, 
   {{0x7d0913bc,0x5e3000e5,0x7c2c010b,0x00000000}},	//   sjes, _پڑتا, _ýarm, --, 
   {{0x7c2800f8,0x7d0913bd,0x63681e0c,0x3d94011c}},	//   szer, pjes, münd, _сиер, 
   {{0x3ea4ec97,0x6368d95c,0x7d080113,0x0bdc0150}},	//   _helt_, lünd, qjes, _ﺃﻴﺩﻫ, 
   {{0x7b1913be,0x5ba40022,0x3ea513bf,0x00000000}},	//   _подр_, _ррез, _kelt_, --, 
   {{0x8afc068f,0xbb44656c,0x63689e1c,0x8e7c01e4}},	//   ględ, _щелк, nünd, _saĝi, 
   {{0x3ea43371,0x7ae113c0,0x8e7c01e4,0x00000000}},	//   _melt_, melt, _paĝi, --, 
   {{0x36680364,0x7ae0df4c,0x28d0dcbe,0x37e401f0}},	//   даҳо_, lelt, ध्दि, _боиг, 
   {{0x27f500a3,0x636913c1,0x8afc000f,0xb4646885}},	// [197e0] _مفيد_, künd, blęd, укал, 
   {{0x7ae113c2,0x3ea4003e,0xe2c41086,0xe4543cc5}},	//   nelt, _nelt_, ллуд_, ужу_, 
   {{0x8e7c00df,0x4374e772,0x35a402e8,0xe12000d1}},	//   _taĝi, рутт, _щанг, әмчи, 
   {{0x7ae113c3,0x25d4008f,0xb144084c,0x00000000}},	//   helt, _גוטן_, ынел, --, 
   {{0x7ae000ed,0x3ea40c18,0xca3801e4,0x765c0108}},	//   kelt, _belt_, raĝi_, _hypy, 
   {{0x98a0031c,0x3ea513c4,0x6368eab4,0x00000000}},	//   _bliċ_, _celt_, günd, --, 
   {{0x3ea410b8,0x00000000,0x00000000,0x00000000}},	//   _delt_, --, --, --, 
   {{0x7ae002f6,0x3ea513c5,0x41740014,0x5d8000ae}},	//   eelt, _eelt_, _نآس, حليل, 
   {{0xdd8c2832,0x691c00e8,0x636913c6,0x6d4c09c2}},	//   _ہول_, _dëel, bünd, _íbam, 
   {{0x636913c7,0x3ea513c8,0x5bb4005b,0xc0d40023}},	//   rüng, _gelt_, ылья_, _ከበሳ_, 
   {{0xdd8c0502,0x6368006a,0xda7484da,0x32180022}},	//   _فول_, süng, ляю_, nypy_, 
   {{0x92e000bd,0x3ea43f5b,0x636807de,0xdca000fb}},	//   থায়_, _zelt_, müne, _гаци, 
   {{0x9cd4025f,0x7ae113c9,0x636913ca,0xa2c416d1}},	//   _תודה_, belt, lüne, ालम्, 
   {{0x7ae113cb,0xa5e43e2e,0x96e841bd,0x286801f0}},	//   celt, любл, льса_, дрҳо_, 
   {{0xfa5513cc,0x765c0042,0xd5b913cd,0x569513ce}},	//   _پروگ, _cypy, лст_, саст, 
   {{0x636913cf,0x00000000,0x00000000,0x00000000}},	//   zünd, --, --, --, 
   {{0x8334e1c2,0x636806b9,0xfc3800df,0x9394007b}},	// [197f0] анах, yünd, taŭi_, مجلا, 
   {{0x8e7c0588,0x2ca40327,0x00000000,0x00000000}},	//   _haĝu, _leod_, --, --, 
   {{0x40943955,0xe73405d9,0xe5c401c0,0x765c010e}},	//   للار, _ليکڪ_, _ёсоо, _gypy, 
   {{0x3ea43d40,0x7ae1028d,0x2ca40793,0x41540032}},	//   _selt_, zelt, _neod_, швес, 
   {{0x63680fcd,0x3ea40076,0xff504cdb,0xca3801e4}},	//   tünd, _pelt_, يخت_, maĝu_, 
   {{0x7ae06445,0x7db426c7,0xc694010f,0x00000000}},	//   xelt, асиц, באַ_, --, 
   {{0x0d6407dd,0x3ea513d0,0x7ae01bb3,0x636803e0}},	//   әныҟ, _velt_, velt, güne, 
   {{0x3ea45651,0x7ae0097d,0x636913d1,0x394800df}},	//   _welt_, welt, sünd, _ĉaso_, 
   {{0x3ea513d2,0x7ae113d3,0x2ca4030a,0x3e34001f}},	//   _telt_, telt, _deod_, _እንዲረ, 
   {{0x6368002f,0x1ea800ec,0xe45c0108,0x00000000}},	//   büne, _سائي_, _myö_, --, 
   {{0x8e840491,0x39445aa6,0x7ae113d4,0xe45c023a}},	//   _المه, иног, relt, _lyö_, 
   {{0x7ae113d5,0xdb200b28,0xca380115,0x765d13d6}},	//   selt, _گوتی, jaĝu_, _rypy, 
   {{0x8d740228,0x765d13d7,0x2bd800f1,0x00000000}},	//   _االا, _sypy, _ټانک_, --, 
   {{0x9a8513d8,0xf7703fe2,0x2ca48c66,0xab9113d9}},	//   _судл, تاج_, _zeod_, _بلوغ, 
   {{0x6448045f,0x00000000,0x00000000,0x00000000}},	//   ûgin, --, --, --, 
   {{0x77843246,0xda600451,0x765c0419,0x00000000}},	//   _клиз, _پاڙي, _vypy, --, 
  
   {{0x37e4036b,0x88c41c3e,0x765c012d,0xf7700b24}},	// [19800] _топг, _اتىل, _wypy, _واخ_, 
   {{0x72940022,0x765d13da,0xe2940276,0xc100009d}},	//   ршах, _typy, иау_, үүрл, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x636829ef,0xf8c41524,0xc40801d9,0x6fb4007b}},	//   vüne, वलिय, ختہٕ_, لمصا, 
   {{0xee1ced65,0x985c001f,0x321802f0,0x00000000}},	//   बन्ध_, ደመሆኑ_, sypy_, --, 
   {{0x2f5403b7,0x63681bc5,0xe29468ce,0x2ca40332}},	//   штес, tüne, _вар_, _seod_, 
   {{0x98a00010,0xede40032,0x8ee8015b,0x4ea402dd}},	//   _alič_, рһеҙ_, পালগ, арқа, 
   {{0x636913db,0x8afc0210,0x00000000,0x00000000}},	//   rüne, klęc, --, --, 
   {{0xeb0513dc,0x6eb400c6,0xac900220,0x2ca40254}},	//   ачно, _نصائ, бақш, _veod_, 
   {{0xe6440020,0x8e7c010f,0x00000000,0x00000000}},	//   _መሆኑን, _saĝu, --, --, 
   {{0x2ca4700a,0x63680b97,0x00000000,0x00000000}},	//   _teod_, lünc, --, --, 
   {{0xc4c401ec,0x00000000,0x00000000,0x00000000}},	//   _ﺩﻋﺎﺌ, --, --, --, 
   {{0x63680790,0x00000000,0x00000000,0x00000000}},	//   nünc, --, --, --, 
   {{0xd7240212,0x4ab81e24,0x00000000,0x00000000}},	//   офсп, _صُبح_, --, --, 
   {{0xe45c02f6,0xb0d408a3,0x00000000,0x00000000}},	//   _syö_, ठभाग, --, --, 
   {{0xd49913dd,0x63680205,0x00000000,0x00000000}},	//   иру_, künc, --, --, 
   {{0x89d80344,0xe8fc000f,0x94a80408,0x82d80e1d}},	// [19810] _شوکر_, rlûd_, ртса_, лдас_, 
   {{0xa37800d8,0xe45c0108,0x00000000,0x00000000}},	//   _opõe, _vyö_, --, --, 
   {{0xd7740f1b,0xa3b00027,0x213401a9,0xae9000c7}},	//   _بايع, _टिक_, аchа_, tỹng, 
   {{0xe45c02f6,0xed44103f,0x00000000,0x00000000}},	//   _työ_, _رپ_, --, --, 
   {{0x656c047e,0x12880014,0x13f40006,0x00000000}},	//   _ihch, اۅہی_, _дзяя, --, 
   {{0xc69400c8,0x6fb0007b,0x7c2c00a2,0x00000000}},	//   זאַ_, أموا, _ýari, --, 
   {{0xcdc8007b,0x009401af,0x00000000,0x00000000}},	//   لذين_, _гибэ, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x60d913de,0x0d0802dd,0x8fa40120,0x51180395}},	//   _ibum, рдық_, _маѓе, _тотю_, 
   {{0x38640327,0x00000000,0x00000000,0x00000000}},	//   _ġor_, --, --, --, 
   {{0x656d13df,0x386400f3,0x499065a2,0x8afc012d}},	//   _ohch, _šor_, ویور, wlęc, 
   {{0x0b4400f7,0xc68800df,0xed4c010a,0x00000000}},	//   йнөн, _טא_, _ѕо_, --, 
   {{0x60d913e0,0x7e6113e1,0xfc3801e4,0xec6c0108}},	//   _mbum, _hylp, taŭu_, _хп_, 
   {{0x7e6002f6,0x6b940375,0x973513e2,0xb6f800db}},	//   _kylp, _הכסף_, تکبا, دىسا_, 
   {{0x60d8b23d,0x59d8085c,0x644c102c,0xe5a00075}},	//   _obum, _बहिर, _axci, зиси, 
   {{0x656c02d0,0x7e604e1b,0xf6240107,0x348401c6}},	//   _chch, _mylp, адҳо, сгаг, 
   {{0x644c0393,0x290c00d0,0x64a001c6,0x00000000}},	// [19820] _cxci, úmať_, яата, --, 
   {{0x60d913e3,0x63b801e4,0x36c4233a,0xfdf801f9}},	//   _abum, _ĥunt, _убог, ्मास_, 
   {{0x60d81418,0x644d13e4,0x00000000,0x00000000}},	//   _bbum, _exci, --, --, 
   {{0x60d800a3,0x6ed80b33,0x636803e0,0x00000000}},	//   _cbum, प्नु, tünc, --, 
   {{0x565400f1,0x00000000,0x00000000,0x00000000}},	//   _درکړ, --, --, --, 
   {{0x60d913e5,0xf1a83028,0x6368083c,0x0ef8013d}},	//   _ebum, _ماره_, rünc, рекъ_, 
   {{0xe7ac068f,0x636803e0,0x00000000,0x00000000}},	//   _जौनप, sünc, --, --, 
   {{0x7124ad7b,0x63681570,0x2d880798,0x00000000}},	//   _ارسل, müna, _ébem_, --, 
   {{0xa3c806e3,0xa0640276,0xe0cc01d9,0x7b380306}},	//   रूप_, _гата_, _سٲل_, mňuj, 
   {{0x7b380122,0x6e4400ee,0x49d80212,0x00000000}},	//   lňuj, _лезз, адою_, --, 
   {{0xdee0a848,0x7e6075f9,0x636805d5,0xceb8012d}},	//   _хохи, _gylp, nüna, _idę_, 
   {{0x6c840597,0xa49800f7,0xd01c00bd,0x7c2c202a}},	//   _الإم, _anòn, _দেয়_, _żare, 
   {{0x7d1c03fa,0x00000000,0x00000000,0x00000000}},	//   össe, --, --, --, 
   {{0x569513e6,0x63680793,0xe5c4c8cb,0x998065d1}},	//   зарт, küna, йсбо, _کليو, 
   {{0xa3c87e29,0x6ed8b658,0xa2c400cd,0x00000000}},	//   रंभ_, प्यु, ालस्, --, 
   {{0x6aa913e7,0x636913e8,0x7b3802fb,0x94040490}},	//   _heff, düna, jňuj, रमंच_, 
   {{0x6aa8e654,0x7b380122,0xdb185c17,0x4734004e}},	// [19830] _keff, dňuj, ctuó, _мнис, 
   {{0x6aa913e9,0xdb180036,0x7b380419,0xa3c801f9}},	//   _jeff, trué, eňuj, रंब_, 
   {{0x636807c5,0x656c01c3,0xd3700214,0x2fc4015d}},	//   güna, _thch, رهٔ_, euog_, 
   {{0x6aa876c7,0xc104007b,0xdb180022,0x00000000}},	//   _leff, توصي, rrué, --, 
   {{0x6aa913ea,0x7e601ef9,0x57fc00df,0x00000000}},	//   _oeff, _sylp, ָלוו, --, 
   {{0x6aa913eb,0x7aec013f,0x7e60017a,0x8bf00154}},	//   _neff, _ɔats, _pylp, য়হান_, 
   {{0x171c04ac,0x628403b2,0x7b381155,0xcc340124}},	//   רווע, _igjo, bňuj, ҧхьы, 
   {{0x60d801b2,0x7b380306,0x5ba00116,0xd0d40395}},	//   _ubum, cňuj, плиғ, _носъ, 
   {{0x6aa913ec,0x7c2c0135,0x00000000,0x00000000}},	//   _beff, _żarb, --, --, 
   {{0x6aa80368,0x9da800a7,0x3f9c0472,0x7e6001f4}},	//   _ceff, _бъда_, mpwu_, _tylp, 
   {{0x7a68c3ff,0x6aa913ed,0x4ad800cd,0xc86808c3}},	//   ринг_, _deff, ब्धव, _סן_, 
   {{0x6aa88240,0x628001f1,0x8d741291,0x00000000}},	//   _eeff, ľnoh, _فانا, --, 
   {{0xeaacf262,0xa3c801ad,0x6284007c,0x3b08026b}},	//   _ой_, रूम_, _ogjo, _вело_, 
   {{0xd5b800da,0xdb18baa9,0x6aa913ee,0x7b3802fb}},	//   šām_, rtuó, _geff, zňuj, 
   {{0xdb18004e,0x6b940432,0x00000000,0x00000000}},	//   stuó, _çygr, --, --, 
   {{0x39b400da,0x62840009,0x6aa913ef,0x00000000}},	//   mās_, _agjo, _zeff, --, 
   {{0x39b40029,0x6aa8011f,0x7b380308,0x222803e6}},	// [19840] lās_, _yeff, vňuj, یزمی_, 
   {{0xf77081cd,0xdb18002e,0x00000000,0x00000000}},	//   _تاب_, otuñ, --, --, 
   {{0x39b411f9,0x7b3802fb,0x7608036b,0xdb18002e}},	//   nās_, tňuj, _тенг_, ntuñ, 
   {{0x2614012d,0x00000000,0x00000000,0x00000000}},	//   नहरी_, --, --, --, 
   {{0xceb8052f,0x7b380122,0xb4e40034,0xb9200248}},	//   йҙа_, rňuj, फ़ी_, _ńsọ_, 
   {{0x39b49787,0x04780014,0x7b3802fb,0xa8540375}},	//   kās_, _دلُک_, sňuj, חינה_, 
   {{0x39b411f9,0x272c0730,0x2fc41c06,0x6aa913f0}},	//   jās_, _fünf_, suog_, _reff, 
   {{0x39b400da,0x628402d3,0xe28001ec,0x2d80bb1b}},	//   dās_, _zgjo, _ілти, öke_, 
   {{0x6aa913f1,0xe45c07c5,0xeb482d29,0xac9001ec}},	//   _peff, _sböz_, ичок_, пақш, 
   {{0xa3c81d15,0x31640165,0x7c2c0210,0x00000000}},	//   रंत_, lloz_, _żarc, --, 
   {{0x39b400da,0x636888e9,0x6aa913f2,0x7d1c0b8b}},	//   gās_, künn, _veff, össc, 
   {{0x272c07c5,0x31640007,0x802401d3,0x2bc00073}},	//   _küng_, nloz_, _برہم, _शिपा, 
   {{0x58842cd0,0x6aa80548,0xdb18067c,0x6368002f}},	//   дыра, _teff, rtuò, dünn, 
   {{0x39b4005f,0xa49800db,0x7bd40311,0x00000000}},	//   bās_, _enòl, ăzut, --, 
   {{0x39b400da,0x60c8050a,0x00000000,0x00000000}},	//   cās_, yggm, --, --, 
   {{0x31640369,0x47d40451,0x6ed800cd,0xd9940345}},	//   jloz_, _فيبر, प्तु, _بخوا_, 
   {{0xe3b113f3,0x2bc02677,0x7c2c010e,0x00000000}},	// [19850] برز_, _शिफा, _ýart, --, 
   {{0x2b4c0161,0x394800df,0x2bc0012d,0x00000000}},	//   _jjfc_, _ĉasi_, _शिना, --, 
   {{0x91b0004d,0x2d6c013a,0x6928013a,0x00000000}},	//   _đạo_, _dřez_, dřez, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x70b0177a,0x39b4005f,0x9fe406f6,0xf8c400e8}},	//   رموض, zās_, تساه, _ñéen_, 
   {{0x3cdc0316,0xa3c801ad,0x63680205,0x4fc400db}},	//   क्ने_, रूण_, müno, بەكە, 
   {{0x6e9005d9,0xcee804f2,0x00000000,0x00000000}},	//   رليا, زرون_, --, --, 
   {{0x39b44424,0xdb1800f7,0x91843baf,0xacb00075}},	//   vās_, truï, _قۇلۇ, ىمىغ, 
   {{0x518401ca,0x692801ef,0xb91000cd,0x00000000}},	//   _цура, břez, ccaṃ_, --, 
   {{0x39b49787,0xe80c5f46,0xdb18004e,0x6d5c00e4}},	//   tās_, ामना_, rruï, îpar, 
   {{0xa498004e,0x3f8513f4,0x8eb00131,0x02dc00cd}},	//   _anòm, _iilu_, _شەيت, न्यभ, 
   {{0x39b40061,0x3f840114,0x63680793,0xd5b800e2}},	//   rās_, _hilu_, küno, šāk_, 
   {{0x3f8513f5,0xdb180054,0x39b40f40,0x3f8c00cf}},	//   _kilu_, stuñ, sās_, _jueu_, 
   {{0x7d1913f6,0x39b40f40,0x7bc80099,0x290c007f}},	//   _hows, pās_, mueu, _ògan_, 
   {{0xe7340a70,0x3f8513f7,0x7d18867a,0x7bc913f8}},	//   чер_, _milu_, _kows, lueu, 
   {{0x3f8513f9,0x63040154,0x7c2c0432,0x00000000}},	//   _lilu_, োসফট_, _ýars, --, 
   {{0x394113fa,0xa498004e,0x3cdc1a2a,0x636913fb}},	// [19860] miks_, _gnòm, क्ये_, rünn, 
   {{0x394113fc,0xd76513fd,0x3f8513fe,0x7d1913ff}},	//   liks_, _زنجی, _nilu_, _lows, 
   {{0x7bc8dc8c,0x46801188,0x00000000,0x00000000}},	//   hueu, _ақра, --, --, 
   {{0x3f8d1400,0x39411401,0x7bc91402,0x7d18033f}},	//   _bueu_, niks_, kueu, _nows, 
   {{0xc32c04a9,0xa3c8032c,0x3f840477,0x7bc80098}},	//   _ھەم_, रूद_, _bilu_, jueu, 
   {{0x3f851403,0x394000af,0x437400a8,0x7bc8003e}},	//   _cilu_, hiks_, _жуст, dueu, 
   {{0x3f8d1404,0xdd946ae9,0x39411405,0x7bc80098}},	//   _eueu_, пшы_, kiks_, eueu, 
   {{0x272c6de4,0x2ce82626,0x7d1860b7,0x7538068c}},	//   _zünd_, сько_, _cows, ètzh, 
   {{0x39411406,0x7bc91407,0x3f8408e5,0x7d191408}},	//   diks_, gueu, _filu_, _dows, 
   {{0x161c05d7,0x6368010e,0x628000d7,0x00000000}},	//   नहार_, jünl, ľnov, --, 
   {{0x39411409,0x7d18058a,0xac84329e,0x6280013a}},	//   fiks_, _fows, _егел, žnov, 
   {{0x6f19140a,0xdb1808a7,0x3941140b,0x7bc80098}},	//   _hotc, stuð, giks_, bueu, 
   {{0x6f19140c,0x7bc80098,0x3f84022e,0x980400ee}},	//   _kotc, cueu, _yilu_, нярд, 
   {{0x6f18014f,0x48e8012c,0x6369140d,0xcb54007b}},	//   _jotc, _जसको_, günl, _تنتظ, 
   {{0x3941140e,0x2b900393,0x6f180175,0xf8c400dc}},	//   biks_, _hâc_, _motc, _वाचय, 
   {{0x04c800aa,0x6f1802ce,0x25bc00d0,0x4ad800dc}},	//   توري_, _lotc, čul_, ब्रव, 
   {{0x6f18039a,0x63680790,0xf3f80022,0xd6ec00cc}},	// [19870] _ootc, bünl, омтә_, _ওচৰা_, 
   {{0x7c3c002d,0x6f1858b7,0x2918036e,0x2b5c0051}},	//   úsri, _notc, _hoqa_, notc_, 
   {{0x26d0030d,0x857401c0,0x994813de,0x4ad42802}},	//   _icxo_, _олох, _ذلیل_, _दानव, 
   {{0x9c10063f,0x527404f2,0x272d140f,0x00000000}},	//   _kọti, رالز, _düne_, --, 
   {{0x7d180408,0x3f851410,0x6f191411,0x3f8c067c}},	//   _rows, _pilu_, _botc, _queu_, 
   {{0xdb180a62,0x29186cdd,0x3f840a73,0x05b00574}},	//   truí, _loqa_, _qilu_, _जबाब, 
   {{0x272c4252,0x7d18068f,0x6f191412,0x7bc80098}},	//   _güne_, _pows, _dotc, wueu, 
   {{0xc1051413,0x2d8431ca,0x29191414,0x7bc8dac8}},	//   _توري, _cioe_, _noqa_, tueu, 
   {{0x39411415,0x3f841dd4,0x0044021a,0x6f1812eb}},	//   viks_, _tilu_, _کیږي_, _fotc, 
   {{0x80d8000b,0x3a251416,0xba240139,0x7bc8003e}},	//   फ्रे, дмог, ддок, rueu, 
   {{0x39411417,0x7d181368,0x236001f7,0x2918022e}},	//   tiks_, _tows, _mkjj_, _boqa_, 
   {{0x29180481,0x6f180161,0x9c100ca8,0x02dc00cd}},	//   _coqa_, _zotc, _bọti, न्तभ, 
   {{0x63685556,0x39411418,0x7bc91419,0xceb8002d}},	//   tünl, riks_, queu, _glęs_, 
   {{0x3941141a,0xa29c0316,0xfd6401e1,0x6d4c0a87}},	//   siks_, खुम्, _nitẹ, _íbar, 
   {{0xa3c9141b,0x291801ee,0xca65141c,0x3940a1bc}},	//   रूस_, _foqa_, _пешқ, piks_, 
   {{0x9aa000db,0xa50402e8,0x00000000,0x00000000}},	//   _تۅگو, меса_, --, --, 
   {{0xb38401c0,0x09280150,0xa53c0023,0x00000000}},	// [19880] длал, _ءسىي_, _ተገላጊ, --, 
   {{0x3cdc0882,0x00000000,0x00000000,0x00000000}},	//   क्ते_, --, --, --, 
   {{0x29181afe,0x6f19141d,0xc8f003d4,0x940c06be}},	//   _yoqa_, _rotc, টাৰত_, _ədə_, 
   {{0x3125141e,0x6f181e54,0x0cc8009e,0x91c401e0}},	//   ьдег, _sotc, _শস্ত, _үҙал, 
   {{0x6f19141f,0x2d840076,0x7c2c0210,0x00000000}},	//   _potc, _rioe_, _żarn, --, 
   {{0x213c0c6a,0x2d8400a9,0xee84010b,0x00000000}},	//   _emuh_, _sioe_, мыйо, --, 
   {{0x7bc40325,0x4c94130f,0xe29401c6,0x6f191420}},	//   _āhua, нийс, _цас_, _votc, 
   {{0x6f180bd7,0x9c1001f2,0xe73c0120,0x272c03b9}},	//   _wotc, _nọsi, mpõe_, _künc_, 
   {{0x61411421,0x6f18004e,0x2a78001f,0x636803e0}},	//   _рета, _totc, _ባንኮች_, zünm, 
   {{0x3dc0000a,0x2918208d,0xdee000c7,0x6f18022e}},	//   šhwa_, _soqa_, _иоуи, _uotc, 
   {{0x9c1001e1,0x2b5c009f,0x29180139,0x8c181410}},	//   _bọsi, rotc_, _poqa_, زيگر_, 
   {{0x2d9d1422,0x291801e0,0x636800a2,0x00000000}},	//   _itte_, _qoqa_, günj, --, 
   {{0xd7f91423,0x291819a2,0x9c100241,0xbe8000c7}},	//   мур_, _voqa_, _dọsi, _иқәи, 
   {{0x2fc41c06,0x63682ca8,0xe5a80798,0x00000000}},	//   irog_, tünm, жњак_, --, 
   {{0x29180333,0x2fc51424,0x78a40250,0x00000000}},	//   _toqa_, hrog_, bbkv, --, 
   {{0x2fc51425,0x6368864e,0x5908025c,0x3950036e}},	//   krog_, rünm, _ཆོགས_, _gjys_, 
   {{0x69d88573,0x2fc40399,0x57f40006,0xd8384530}},	// [19890] ltte, jrog_, _апыт, _жээ_, 
   {{0x2fc51426,0x2d9c04ce,0x69d83601,0xa3c81b87}},	//   drog_, _otte_, otte, रूष_, 
   {{0x69d91427,0xe0dc0295,0x636801d3,0x62940477}},	//   ntte, _ñòk_, lünk, rcxo, 
   {{0x69d80664,0x2fc51428,0x3cdc0150,0x716400d1}},	//   itte, frog_, _ﺃﻤﺎﻤ, ىپلە, 
   {{0xf1fc00c6,0x2d9d1429,0x73c046e8,0x75380221}},	//   _ғιяs_, _atte_, _бәхе, ëtze, 
   {{0x69d80623,0x1ae003d4,0x7c2c012d,0x6ed80303}},	//   ktte, _কোনে_, _żaro, प्लु, 
   {{0x628001a2,0xa3c887d9,0x7d1c007c,0x00000000}},	//   ľnos, रूर_, össo, --, 
   {{0x62809a4d,0xa2d400bd,0x98a02220,0xa2c407b7}},	//   žnos, _সফটও, _ilić_, ालक्, 
   {{0x2d9c033d,0x3b84ccce,0xd019142a,0x9c100241}},	//   _ette_, нлиг, _офф_, _rọsi, 
   {{0x59080327,0x6d4c01e1,0x4ea458e5,0x00000000}},	//   _ཆོངས_, _ìban, _арца, --, 
   {{0xb0606583,0xe9d400a8,0x69d800b5,0xbc6800e5}},	//   _ääri, нкэ_, gtte, _کمشن_, 
   {{0x7c3402e8,0x00000000,0x00000000,0x00000000}},	//   _пеех, --, --, --, 
   {{0x69d9142b,0x6369142c,0xdb086afa,0x69dc014a}},	//   atte, günk, _avgå, _äpen, 
   {{0xdb18a568,0x3cec8e9e,0x2d9d142d,0x98a001a6}},	//   bruá, leev_, _ytte_, _olić_, 
   {{0x69d844b6,0x602400b8,0x4ad400cd,0x00000000}},	//   ctte, _hīmā, _दातव, --, 
   {{0x2fc401b9,0x2a38011a,0x00000000,0x00000000}},	//   yrog_, _מעצמ, --, --, 
   {{0x98a096c0,0xa3e4b0fb,0x73040107,0xdb180254}},	// [198a0] _alić_, ндта_, нпаз, stuõ, 
   {{0x3cec01d4,0x602400cd,0x9c1001e1,0x95b41de6}},	//   heev_, _mīmā, _yọri, _ирмә, 
   {{0x02180006,0x2fc4015d,0x970400d1,0x3cec0166}},	//   міць_, wrog_, _كېڭى, keev_, 
   {{0x2fc439ae,0xa998008f,0x2d9c0139,0x3cec045a}},	//   trog_, לבער, _rtte_, jeev_, 
   {{0xe73c06ed,0x2fc40589,0x1fa40cdd,0xef6402e8}},	//   spõe_, urog_, екчи_, нъко, 
   {{0x69d8e2b7,0xb8d00867,0x2fc5142e,0x00000000}},	//   ytte, _ཟབ_, rrog_, --, 
   {{0xe12000d1,0x69d8343a,0x636800e5,0x3cec013d}},	//   _өмри, xtte, zünk, feev_, 
   {{0x2fc5142f,0xf2e4004b,0x61d8011a,0x00000000}},	//   prog_, _تکړه_, _מקלד, --, 
   {{0xa4980086,0x2fc4036b,0x5d100372,0xbf880131}},	//   _enòw, qrog_, ابىز, سئۇل_, 
   {{0xdb18ea0f,0x22380240,0x00000000,0x00000000}},	//   truá, በርኩሙ, --, --, 
   {{0x2bc11430,0xaa643004,0x69d91431,0x5c101d10}},	//   _शिवा, этик, utte, نظیر, 
   {{0x69d91432,0x636801ed,0x2eed1433,0xa3c807f7}},	//   rtte, tünk, leff_, रूँ_, 
   {{0x6d400093,0x25740790,0x00000000,0x00000000}},	//   _imoa, nçle_, --, --, 
   {{0x272c04cc,0x61300274,0xf8c4002e,0x636801d3}},	//   _büna_, _içle, _ñénn_, rünk, 
   {{0x6d40002d,0x636801d3,0x69d802d0,0x00000000}},	//   _kmoa, sünk, qtte, --, 
   {{0xe570b23e,0x272c04cc,0x636805d1,0x2eec04e6}},	//   اطس_, _düna_, müni, heff_, 
   {{0x6d40016b,0xd55402e8,0xe8bc01f9,0x636800ee}},	// [198b0] _mmoa, уктъ, ्लीच, lüni, 
   {{0x6b880327,0x2eed1434,0xca8c0023,0x86991435}},	//   _jifg, jeff_, ነትኩም_, _юкос_, 
   {{0x6d400588,0x272c010e,0xd8740345,0x06342377}},	//   _omoa, _güna_, _لایب, _ренџ, 
   {{0xe1641075,0x3cec0211,0x51840024,0x7c2c031c}},	//   رداي, xeev_, гуча, _żarm, 
   {{0x800800dd,0xd25000dd,0x00000000,0x00000000}},	//   براہ_, لنے_, --, --, 
   {{0x63680432,0x00000000,0x00000000,0x00000000}},	//   küni, --, --, --, 
   {{0x82640722,0x41851436,0x4ea40137,0x68ec0175}},	//   _شهرن, _атағ, урча, kecd, 
   {{0x602400b8,0x3eb800ef,0x00000000,0x00000000}},	//   _pīmā, _ēstu_, --, --, 
   {{0x7f94b3dc,0x4fc400f4,0x3cdc28b8,0x00000000}},	//   _разх, _مەنە, क्षे_, --, 
   {{0x6d411437,0xac80010b,0x2ac40241,0x2bc01df0}},	//   _emoa, шгыл, _ríbà_, _शिरा, 
   {{0xcee801d9,0x6368010e,0x00000000,0x00000000}},	//   _سرٕن_, güni, --, --, 
   {{0x3cdc012d,0x00000000,0x00000000,0x00000000}},	//   क्शे_, --, --, --, 
   {{0xfb34009d,0x00000000,0x00000000,0x00000000}},	//   _индэ, --, --, --, 
   {{0xdb049226,0x6b88fb27,0xbb451438,0x3cdc00cd}},	//   äläm, _gifg, _шелк, क्रे_, 
   {{0x7bc82657,0x68ec9e38,0x00000000,0x00000000}},	//   lreu, becd, --, --, 
   {{0x2c5c01f2,0x7afc00e2,0xe4c11439,0x68ec045a}},	//   ịde_, ēstu, ийси, cecd, 
   {{0x7bc9143a,0x27b004b4,0x3484009d,0xdb18010b}},	// [198c0] nreu, _вәсс, тгаг, gruç, 
   {{0x657c0218,0x525800d1,0x00000000,0x00000000}},	//   amqh, ىساڭ_, --, --, 
   {{0x7bc8c250,0xd73400c7,0x35a400f0,0x00000000}},	//   hreu, _ахҟь, _шанг, --, 
   {{0xd5b80029,0x2bc1143b,0x7bc9143c,0xe7b0598f}},	//   šās_, _शिला, kreu, _حمید, 
   {{0xb4cc5345,0x636800ee,0xa3c80037,0x00000000}},	//   रली_, züni, रूआ_, --, 
   {{0x6d41143d,0x776c030d,0x5f9000d1,0xc64800f2}},	//   _smoa, nlbx, шишт, _آجیل_, 
   {{0xe1f402f6,0x7bc9143e,0x6b880946,0x9db40d2f}},	//   _игр_, ereu, _rifg, نديز_, 
   {{0x7bc80730,0x636801b8,0x00000000,0x00000000}},	//   freu, vüni, --, --, 
   {{0x7bc9143f,0xe060168d,0xef851440,0x6d4c01e1}},	//   greu, _پێوی, _алап, _ìbam, 
   {{0x3f980798,0x49a43007,0xee78007b,0x1ec45211}},	//   _ésua_, лымғ, _قصات_, _алфи_, 
   {{0x65780092,0x00000000,0x00000000,0x00000000}},	//   _በጥብቅ_, --, --, --, 
   {{0x7bc91441,0x97380023,0x00000000,0x00000000}},	//   breu, _ጥምየት, --, --, 
   {{0x7bc91442,0xabb00724,0x272c0e78,0x6b880327}},	//   creu, _талә, _dünn_, _tifg, 
   {{0x6b8800a3,0x00000000,0x00000000,0x00000000}},	//   _uifg, --, --, --, 
   {{0xb6000118,0xfb1800e5,0x00000000,0x00000000}},	//   _žárl, _سروں_, --, --, 
   {{0xdb1803b7,0x850c06ab,0xd5540395,0x248c03b2}},	//   truç, हाइट_, аксъ, øgm_, 
   {{0x9948082e,0x3f7c010e,0x753801c7,0xd4980124}},	// [198d0] _جليل_, _oňup_, ëtza, трс_, 
   {{0x764c01ed,0x98ac0024,0xded0069d,0x00000000}},	//   ányá, ėdą_, ኩትን_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7bc91443,0x9f5c05d5,0xc174179e,0xa2c400cd}},	//   yreu, _eruì_, اگست, ालङ्, 
   {{0xc374592e,0x9f48036e,0x00000000,0x00000000}},	//   _مُحب, _ëmës_, --, --, 
   {{0x7bc91444,0x0b140154,0x6b94010e,0x3eb800ef}},	//   vreu, িসুল_, _çygy, _ēsts_, 
   {{0x44291445,0x92680b14,0x7bc8003e,0xf2d000d9}},	//   lya_, _арта_, wreu, _לעם_, 
   {{0x7bc8956e,0x16b00c2e,0x442870b6,0xe7e4010e}},	//   treu, _जज्ब, oya_, _tüňç, 
   {{0x7bc91446,0xbab40aec,0xcd2800cf,0x00000000}},	//   ureu, лёны, ئسىن_, --, 
   {{0x7bc91447,0x2d88011c,0x3e180276,0x8ac401ec}},	//   rreu, _èben_, _позэ_, ақша_, 
   {{0x44291448,0x39491449,0xf98405f5,0x41e0031c}},	//   hya_, езно_, лгоо, _ཤཱསྟ, 
   {{0x4429144a,0x7bc800a8,0x00000000,0x00000000}},	//   kya_, preu, --, --, 
   {{0x4429144b,0x3154008f,0x3ff8010f,0x850c466d}},	//   jya_, רירן_, עפֿע, हाईट_, 
   {{0x7c29144c,0x3cfc0218,0x3944013d,0xf7c80116}},	//   myer, _hawv_, _әниг, _ﺑﻪﻧﺪ, 
   {{0x3cfc0218,0x442801d9,0x272c0254,0xb5780395}},	//   _kawv_, eya_, _tünn_, ещах_, 
   {{0xb4cd144d,0x4429144e,0xdb18002d,0xca54030d}},	//   रले_, fya_, ksuë, _тĕсп, 
   {{0x7c29144f,0x44291450,0xdcf8107d,0x085800cf}},	// [198e0] nyer, gya_, jmuč, _үчөө_, 
   {{0x3cfc0b89,0x78b51451,0x7c280099,0xa49801ab}},	//   _lawv_, _heyv, iyer, _snòt, 
   {{0xf7702fc0,0x44291452,0x78b4010a,0x7c291453}},	//   _پاک_, aya_, _keyv, hyer, 
   {{0x3cfc0070,0x78b400c7,0x7c281958,0x00000000}},	//   _nawv_, _jeyv, kyer, --, 
   {{0x78b51454,0x44291455,0x7c291456,0xe80423ef}},	//   _meyv, cya_, jyer, शिया_, 
   {{0x7c291457,0x78b51458,0x06640150,0x00000000}},	//   dyer, _leyv, _حاۋپ, --, 
   {{0x32000131,0xa49801ab,0x7c280083,0x7ed400d4}},	//   _ھېچق, _gnòs, eyer, річч, 
   {{0x3cfc0070,0x7c282622,0x78b4022c,0xa3c801ad}},	//   _cawv_, fyer, _neyv, रूक_, 
   {{0x7c28efbe,0x3cfc0218,0x8afc012d,0x257403e0}},	//   gyer, _dawv_, klęt, nçla_, 
   {{0xdfcc007b,0xdb18007f,0x20080419,0x613006be}},	//   _ريم_, nsuè, _ácia_, _içla, 
   {{0x5e900491,0x44291459,0x6ce40046,0x7c280334}},	//   _المط, zya_, _біле, ayer, 
   {{0x4429145a,0x2869145b,0x7c29145c,0x3cfc0218}},	//   yya_, ерго_, byer, _gawv_, 
   {{0x44281bce,0x06700952,0x7c280526,0x78b5145d}},	//   xya_, ﺳﺘﯩﮕ, cyer, _deyv, 
   {{0x4429145e,0x3cfc0218,0x753801c7,0x5bc0007b}},	//   vya_, _zawv_, ëtzn, _اقول, 
   {{0x6ab9145f,0x44280bf1,0x24e401c0,0x95c89808}},	//   matf, wya_, лцаг, лута_, 
   {{0x6ab91460,0x61300166,0x78b403e0,0x00000000}},	//   latf, _oçla, _geyv, --, 
   {{0x44291461,0x7bc41d77,0x29240034,0x28681e28}},	// [198f0] uya_, _āhuk, ętać_, _ярко_, 
   {{0x6ab800d2,0x68fcf7c0,0x78b406be,0x42a401ec}},	//   natf, _haqd, _zeyv, руағ, 
   {{0x44291462,0x23f44e90,0x7c280083,0x61300205}},	//   sya_, _өмнө_, zyer, _açla, 
   {{0xa498068c,0x6ab82959,0x68fc0135,0x7c28022f}},	//   _enòr, hatf, _jaqd, yyer, 
   {{0x6ab87aa5,0x68fd1463,0x3cfc0211,0x44291464}},	//   katf, _maqd, _rawv_, qya_, 
   {{0x7c281459,0x3cfc0190,0x68fc0009,0x92951465}},	//   vyer, _sawv_, _laqd, _гарц, 
   {{0x3cfc0218,0x4fc402dd,0x7c291466,0x31640010}},	//   _pawv_, _қста, wyer, booz_, 
   {{0x7c291467,0x68fd1468,0x7bcc05ac,0xfbc40798}},	//   tyer, _naqd, _åauk, абио, 
   {{0x60d80516,0xa3c803f3,0x78b406ea,0x636800e5}},	//   _icum, रंट_, _reyv, bünt, 
   {{0x7c291469,0x6369146a,0x6ab8003c,0xd018016c}},	//   ryer, müns, gatf, _ёфт_, 
   {{0x3cfc0457,0x7c28bd47,0x3d940032,0x68fc0014}},	//   _tawv_, syer, _тиер, _baqd, 
   {{0x7c29146b,0x68fc0009,0x2c5c0521,0x78b40455}},	//   pyer, _caqd, ịda_, _qeyv, 
   {{0x6ab9146c,0x68fc016d,0x5ba5146d,0x7c280240}},	//   batf, _daqd, _срез, qyer, 
   {{0xfaa5146e,0x59080327,0xab2400f3,0x00000000}},	//   _тако, _ཆོམས_, _воша_, --, 
   {{0x28a4878d,0x60d9146f,0x3be400ab,0x36691470}},	//   _क्वि, _ocum, _कहुँ_, таво_, 
   {{0x60d91471,0xf7700133,0x63691472,0x00000000}},	//   _ncum, _ژاد_, zünt, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [19900] --, --, --, --, 
   {{0xa3c8012d,0x63680112,0x25740205,0x06ac00eb}},	//   रंज_, düns, rçla_, কৃবি, 
   {{0x60d80208,0x4374dba2,0x00000000,0x00000000}},	//   _bcum, сутт, --, --, 
   {{0x6ab81cea,0x3be405f9,0x68fd1473,0x00000000}},	//   zatf, _कहूँ_, _xaqd, --, 
   {{0x63691474,0x6ab8003c,0x3164009f,0xe8fc0165}},	//   güns, yatf, rooz_, koûn_, 
   {{0x7c2c0209,0xe8040ad7,0xfca802dd,0x31640334}},	//   _ýary, शिता_, ңсық_, sooz_, 
   {{0x6368708d,0x60d800a3,0x00000000,0x00000000}},	//   rünt, _fcum, --, --, 
   {{0xdc90069c,0x60d800c6,0x6ed0b5f0,0x6ab80af2}},	//   _ቀዳማይ_, _gcum, _ठाकु, watf, 
   {{0x28a40b9c,0x2aa85c9e,0x61311475,0x68fd1476}},	//   _क्षि, ктно_, _uçla, _raqd, 
   {{0x32080122,0xdfcc05d9,0x68fd1477,0x6e44010b}},	//   _krby_, _آيل_, _saqd, _кезз, 
   {{0x2bc023ef,0x68fc047e,0xa2b8010f,0x00000000}},	//   _शिका, _paqd, כמיט, --, 
   {{0xdd8c7572,0x6ab8192e,0x68fc014f,0x7bdc01ab}},	//   _قول_, satf, _qaqd, àsuc, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x68fc81f1,0x07085edc,0x8afc000f,0x249c031c}},	//   _waqd, ديسي_, rlęs, _żum_, 
   {{0x68fc07d6,0x68911478,0x3cdc02ab,0x5b78011a}},	//   _taqd, _ویدئ, क्के_, _שרוא, 
   {{0x65780327,0xa85001ee,0x0a6801a9,0x00000000}},	//   ċuho, _мейә, _ирқи_, --, 
   {{0xe89000c7,0xea6000e5,0x00000000,0x00000000}},	// [19910] _лақь, _دھکی, --, --, 
   {{0x60d91479,0x00000000,0x00000000,0x00000000}},	//   _scum, --, --, --, 
   {{0x63680730,0xa3c80c66,0x40940131,0x92687b1b}},	//   wüns, रूज_, ملار, арца_, 
   {{0x3208013a,0x63680205,0x00000000,0x00000000}},	//   _drby_, tüns, --, --, 
   {{0xb3e4045e,0xbea434f5,0x320802f0,0x00000000}},	//   নিউজ, балк, _erby_, --, 
   {{0xc2c423bb,0x63681922,0xcf4400d4,0x00000000}},	//   _ديسي, rüns, оній, --, 
   {{0xfe08038b,0x23c400bc,0x00000000,0x00000000}},	//   اقبي_, _लिँद, --, --, 
   {{0x28a4072a,0x60d9147a,0x91cc61f2,0x2bc0090a}},	//   _क्लि, _ucum, _हितै, _शिखा, 
   {{0xedb00022,0xa3c801f9,0x00000000,0x00000000}},	//   _ҵәыџ, रूच_, --, --, 
   {{0xce940c60,0xd99c02dd,0xde640354,0x00000000}},	//   _дафъ, _ﺍﻟﺭﺩ_, _къеп, --, 
   {{0x4b240451,0x00000000,0x00000000,0x00000000}},	//   تعيف, --, --, --, 
   {{0x7c9400c6,0x7c2c0327,0x18b40022,0x1a6400f1}},	//   _الإص, _żaru, цәкр, هیږی_, 
   {{0x2604010f,0x00000000,0x00000000,0x00000000}},	//   _aĵo_, --, --, --, 
   {{0x2f0c0166,0x8b640345,0x00000000,0x00000000}},	//   _iñgä_, _واوم, --, --, 
   {{0xb9c40150,0x634c0064,0x00000000,0x00000000}},	//   _اقبي, _mėnė, --, --, 
   {{0x65602959,0x00000000,0x00000000,0x00000000}},	//   _ínhl, --, --, --, 
   {{0x79840334,0xa5041422,0xf744014b,0x00000000}},	// [19920] mmkw, щета_, _гепо, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfe65147b,0x3cf80118,0x00000000,0x00000000}},	//   _آگ_, ्याइ_, --, --, 
   {{0xe294a3c3,0xe0000d79,0x79840100,0x320801ef}},	//   _ҳар_, लिंद_, nmkw, _vrby_, 
   {{0x28d9147c,0xceb801e0,0x00000000,0x00000000}},	//   _भासि, иҙа_, --, --, 
   {{0xe2949243,0x02d400a7,0xc64400db,0x42d400c0}},	//   _гар_, _мюсю, _دئۋى, _місу, 
   {{0x9c10063f,0xc32c113e,0xef9001b9,0x1dcc0764}},	//   _gọzi, _جەل_, _کیتد, संगत, 
   {{0xcc98119e,0x00000000,0x00000000,0x00000000}},	//   швиц_, --, --, --, 
   {{0x31e40150,0x2c1c015b,0x2518011a,0x00000000}},	//   _ءﺷﻮﻝ_, _বেড়ে_, רופא, --, 
   {{0x6021147d,0x4a5400d4,0x994400a2,0x00000000}},	//   _эдуа, жкос, lıň_, --, 
   {{0x7c2c033f,0x2d04009d,0x298400db,0x00000000}},	//   _żart, _гялг, йымг, --, 
   {{0x7524009a,0x3a740228,0x7d1c0e78,0x9c100241}},	//   _nokz, өлөр, össt, _lọyi, 
   {{0xd8380b83,0xab841111,0x00000000,0x00000000}},	//   бэр_, _лукк, --, --, 
   {{0x28d81a2a,0x1ca40014,0xb865147e,0x00000000}},	//   _भावि, _پێیی_, تاپو, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2a8c03be,0x98d80150,0xe8fc002d,0x92b80183}},	// [19930] ləb_, _ابىز_, slûs_, ছলৈ_, 
   {{0x85b800d8,0x00000000,0x00000000,0x00000000}},	//   _клос_, --, --, --, 
   {{0x76b8004e,0x00000000,0x00000000,0x00000000}},	//   _өлөр_, --, --, --, 
   {{0x7ff442c6,0x3f9800f2,0xb64002dd,0x994400a2}},	//   قستا, _ésuk_, _ﺃﺠ_, gıň_, 
   {{0xd99c0150,0x00000000,0x00000000,0x00000000}},	//   _ﺍﻟﺤﺩ_, --, --, --, 
   {{0x8ee8003b,0x00000000,0x00000000,0x00000000}},	//   ймів_, --, --, --, 
   {{0x52240117,0x00000000,0x00000000,0x00000000}},	//   _ефта, --, --, --, 
   {{0x28d83f55,0x9f5c05d1,0xbd4400ae,0x00000000}},	//   _भाषि, _oruç_, تنبي, --, 
   {{0x4ad405ba,0xb144034d,0x3af41c50,0x3e480092}},	//   _दाखव, _بینم_, оянс, _እንዲጨ, 
   {{0x8b8808b0,0x0ee003ce,0xb9e80454,0x00000000}},	//   مەنە_, _नायड, амоз_, --, 
   {{0x272c0209,0x8d743293,0xf2d004ae,0x0dc80c17}},	//   _güni_, _کالا, ועי_, _гучи_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x28d8e079,0xe5200882,0xb6a401c0,0x883400a8}},	//   _भारि, ṃśay, жигл, пэрц, 
   {{0x656d147f,0x2a8c03be,0x00000000,0x00000000}},	//   _akch, bəb_, --, --, 
   {{0xe5a0f307,0x660026c4,0xf50457c6,0x2a8c0213}},	//   диси, мпра, озво, cəb_, 
   {{0xb4a800c2,0xb82807a5,0x00000000,0x00000000}},	//   рказ_, _воиз_, --, --, 
   {{0x24051480,0xf34800c0,0x752454a0,0x00000000}},	// [19940] онти_, апал_, _vokz, --, 
   {{0xe3b43334,0x29040134,0x75240432,0x00000000}},	//   юбу_, _ɔnam_, _wokz, --, 
   {{0x48e0fad5,0xd25003e6,0x752401a9,0x00000000}},	//   _कामो_, رۆر_, _tokz, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf1a91481,0x272c0213,0x00000000,0x00000000}},	//   _چاره_, _süni_, --, --, 
   {{0xe3b51482,0xf1a8208f,0x3ea40175,0xeda40120}},	//   _фбр_, _ناره_, _cflt_, ошио, 
   {{0x3ea40175,0x2d9806af,0xceb800d1,0xdd9402d5}},	//   _dflt_, êpe_, _һәй_, ошы_, 
   {{0xad24035c,0xe0d40212,0x3ea4032e,0x2534010f}},	//   ترتو, _мвс_, _eflt_, ַניש_, 
   {{0x7e60013f,0xceb82a9d,0x00000000,0x00000000}},	//   _exlp, _ләй_, --, --, 
   {{0x69f000f7,0x7bc400cd,0x00000000,0x00000000}},	//   дүкт, _āhut, --, --, 
   {{0xdee001c0,0xf8b400cd,0x4dd800fe,0x00000000}},	//   _цохи, ंरूप, _ভৈৰৱ, --, 
   {{0xe80406b1,0x00000000,0x00000000,0x00000000}},	//   शिला_, --, --, --, 
   {{0xdd8c021a,0xb89800bc,0x00000000,0x00000000}},	//   _شوه_, _šťáv, --, --, 
   {{0xea283efd,0x00000000,0x00000000,0x00000000}},	//   _вцик_, --, --, --, 
   {{0xda6c00d6,0x387c012d,0x00000000,0x00000000}},	//   _ця_, ętra_, --, --, 
   {{0x5bc000fb,0x00000000,0x00000000,0x00000000}},	//   _эйәб, --, --, --, 
   {{0x833402e8,0x00000000,0x00000000,0x00000000}},	// [19950] пнах, --, --, --, 
   {{0xdef40020,0x28a4098a,0x00000000,0x00000000}},	//   ሉትን_, कुरि, --, --, 
   {{0xd1b8c539,0x2ca4015d,0x22441bce,0xdc780023}},	//   قانا_, _ofod_, ànk_, _ብድሕር_, 
   {{0x4394009d,0xb82000fe,0x00000000,0x00000000}},	//   _намс, _পেটত_, --, --, 
   {{0x3ea4036b,0xbea51483,0x4394009d,0x00000000}},	//   пилг, палк, _хагс, --, 
   {{0x705034f6,0xafe0010b,0xf67800d1,0xa2640395}},	//   عنوا, хошл, ﻠﯩﮕﻪ_, _дъбл, 
   {{0x925800db,0xb8fc0327,0x6da002e8,0x00000000}},	//   _дарт_, _ཤྐ_, нища, --, 
   {{0x8d8401f7,0xc0c401af,0x00000000,0x00000000}},	//   وشين, _хәжи, --, --, 
   {{0xdb180120,0xdca00131,0x5fdc00bc,0x86380023}},	//   ssuí, пақи, _नमिल, _ጥፍኣት, 
   {{0x6f600150,0x00000000,0x00000000,0x00000000}},	//   _كۇنم, --, --, --, 
   {{0x7a691484,0x272c014a,0xc86800c8,0xce38007b}},	//   синг_, _jünu_, _ען_, _وأما_, 
   {{0x8d740447,0x9c1001f2,0x28a411bc,0x00000000}},	//   _قانا, _nọgi, कुलि, --, 
   {{0x9c100cad,0x9ba000d1,0xb82000cc,0x00000000}},	//   _sọfi, _تەخى, _পেজত_, --, 
   {{0xf504016c,0x3d1800dc,0x6d4c0248,0x00000000}},	//   ӯзго, भावे_, _ìbar, --, 
   {{0xba7402dd,0xfbbc0154,0x2ab800d9,0x00000000}},	//   _عاتت, _আমিত, _המצא, --, 
   {{0x15b80961,0x00000000,0x00000000,0x00000000}},	//   йығы_, --, --, --, 
   {{0xc98450a3,0x69dc0793,0xade00490,0x68f80037}},	// [19960] _تشوي, _äper, _गमभन_, õude, 
   {{0x1dd8032c,0x661400e5,0x225c002b,0x00000000}},	//   _यमंत, égkö, _śuka_, --, 
   {{0xe2951485,0x2ac4012c,0xc7642160,0xa698011a}},	//   чах_, líbí_, _تايى, _לשיפ, 
   {{0x2364b745,0x09e002f5,0x00000000,0x00000000}},	//   čnja_, _বনমা, --, --, 
   {{0x7994014f,0x2164892e,0x00000000,0x00000000}},	//   _miyw, чици_, --, --, 
   {{0x33182e0b,0x00000000,0x00000000,0x00000000}},	//   _ازحد_, --, --, --, 
   {{0x5ea052c8,0xde90026a,0x9f9400c7,0xd1d40092}},	//   رميل, нашњ, _ҵыхә, ከቶች_, 
   {{0x5ae4025c,0x7bc41da6,0x6e9001e0,0x4c951486}},	//   _འཁུམ, _āhur, миҙу, мийс, 
   {{0xc0f4001f,0x00000000,0x00000000,0x00000000}},	//   ሉንም_, --, --, --, 
   {{0x2fc47bc3,0x00000000,0x00000000,0x00000000}},	//   msog_, --, --, --, 
   {{0x272c0254,0x48e00037,0x00000000,0x00000000}},	//   _münt_, _कादो_, --, --, 
   {{0x2d9c0311,0xb4ed1487,0x2ca40254,0x2fc403cb}},	//   _iute_, ङ्मय_, _ufod_, osog_, 
   {{0x3ae40100,0xac08fff2,0x2fc401a8,0x2d9c00b8}},	//   _bňpč_, _ында_, nsog_, _hute_, 
   {{0x2d9c13c4,0xaae414a5,0x3c451488,0x00000000}},	//   _kute_, _رستو, _غضنف, --, 
   {{0xdd8c00db,0x998401d9,0x25740205,0x00000000}},	//   _شوۇ_, بلێو, lçli_, --, 
   {{0x69d81dcb,0x79540f8b,0xda580302,0x225c16a3}},	//   mute, tšwe, _לכול, _ćuk_, 
   {{0x43940aa5,0x2d9d1489,0x257451bb,0x6d480051}},	// [19970] даас, _lute_, nçli_, _đoá, 
   {{0x2d9d148a,0x69d805c7,0x6131148b,0xdef00023}},	//   _oute_, oute, _içli, ፌታን_, 
   {{0x26c0151c,0x00000000,0x00000000,0x00000000}},	//   majo_, --, --, --, 
   {{0x26c1148c,0x69d800c5,0x80780276,0x00000000}},	//   lajo_, iute, обес_, --, 
   {{0x2d9d148d,0x69d9148e,0xab600432,0x00000000}},	//   _aute_, hute, _ýüwr, --, 
   {{0x2d9d148f,0x26c11490,0x6f60063f,0x6d5c8651}},	//   _bute_, najo_, tọọk, épan, 
   {{0x69d91491,0x2d9c011a,0x5fcc0ce0,0x3d183be5}},	//   jute, _cute_, _हटवल, भाले_, 
   {{0x2d9c152d,0x918404a9,0x69d91492,0x26c11493}},	//   _dute_, _كۇلۇ, dute, hajo_, 
   {{0x26c0151c,0x3b8465c2,0x69d91494,0x51851495}},	//   kajo_, млиг, eute, _чура, 
   {{0x2d9d1496,0x26c00f72,0x6fd01533,0x69d91497}},	//   _fute_, jajo_, _सितं, fute, 
   {{0x2d9d1498,0x26c00fb7,0xfbd02099,0x0f2400c7}},	//   _gute_, dajo_, رتک_, _џьум, 
   {{0xf1b0008f,0x9ce401d3,0x00000000,0x00000000}},	//   כסט_, _روتے_, --, --, 
   {{0x272c29ef,0x2d9c0960,0x776c01b9,0x69d8ba3a}},	//   _nüns_, _zute_, tobx, aute, 
   {{0xdb08049f,0x26c0151c,0x7d081c2e,0xc7951499}},	//   _avgö, gajo_, ldes, ерсы, 
   {{0x6a81149a,0x7d09149b,0x60240374,0x69d9149c}},	//   _илша, odes, _hūmā, cute, 
   {{0x7b6400ee,0x272c010e,0xc0e00092,0x2fc40142}},	//   _этҗе, _sünt_, ነትህ_, ysog_, 
   {{0x26c1149d,0x7305149e,0x3f84014b,0xa8003cbb}},	// [19980] bajo_, мпаз, _ohlu_, _азыл, 
   {{0x7d0805cc,0xd76401ed,0x27ec0267,0x26c00427}},	//   hdes, _سنجی, _ägna_, cajo_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7d09149f,0x3f842f19,0x3cf80034,0x2fc401ee}},	//   jdes, _ahlu_, ्यों_, tsog_, 
   {{0x1cdc0003,0x3f84009a,0x2d9d14a0,0x69d84bec}},	//   ྣུན_, _bhlu_, _sute_, zute, 
   {{0x69d914a1,0x437400d6,0x7d0914a2,0x2d9d14a3}},	//   yute, _зуст, edes, _pute_, 
   {{0x7d08f658,0x69d90c80,0xa2e000cf,0x00000000}},	//   fdes, xute, _шорд, --, 
   {{0x69d914a4,0x7d0914a5,0xb0340075,0x26c009a8}},	//   vute, gdes, _قىزغ, zajo_, 
   {{0x3004036b,0x69d914a6,0x2d9c0de2,0xdcf80e04}},	//   _юзаг, wute, _wute_, zmuć, 
   {{0x48e0069f,0x2d9c04ac,0xdb180332,0x00000000}},	//   _काहो_, _tute_, tsuá, --, 
   {{0x26c114a7,0x2d9c007d,0x69d80869,0x6f18b4b7}},	//   vajo_, _uute_, uute, _intc, 
   {{0x7d0914a8,0xeb980364,0x6cd4036b,0x26c000b5}},	//   cdes, _дид_, _آقشا, wajo_, 
   {{0x8d7514a9,0x69d914aa,0x26c009a8,0xd7e514ab}},	//   _قاچا, sute, tajo_, кіро, 
   {{0x69d914ac,0x2d840109,0xb8d411a6,0x850465fd}},	//   pute, _hhoe_, _च्_, کورن, 
   {{0x26c114ad,0x2d840016,0x69d80869,0x00000000}},	//   rajo_, _khoe_, qute, --, 
   {{0x26c0af5c,0x225c00b8,0x00000000,0x00000000}},	//   sajo_, _śuko_, --, --, 
   {{0x26c009a8,0x63680112,0x6f186548,0x47a800cc}},	// [19990] pajo_, münz, _ontc, _কটকী, 
   {{0x43942095,0xa78401d5,0x175401c6,0x43740769}},	//   хазс, _تشبو, _авья, رهار, 
   {{0xe8044a01,0x7d0914ae,0x75dc0356,0x6f8c0150}},	//   शिका_, ydes, _văzî, _ﺟﻮﻋﺎ_, 
   {{0x6f1914af,0x29080276,0x753801c7,0x00000000}},	//   _antc, ndca_, ëtzt, --, 
   {{0x7d0914b0,0x27e8020c,0x3f840142,0x00000000}},	//   vdes, ntcn_, _phlu_, --, 
   {{0x2d8405da,0x602402b1,0x7d0914b1,0x00000000}},	//   _ahoe_, _rūmā, wdes, --, 
   {{0x69ccff83,0x7d0914b2,0xdce8025c,0x10e80150}},	//   ábel, tdes, _jigħ, _ﺎﻫﺩﻨ, 
   {{0x291801ee,0x7d0802f6,0x2d840076,0x602402b5}},	//   _nnqa_, udes, _choe_, _pūmā, 
   {{0x06740952,0x213c020c,0x69c811ad,0x3cf800bc}},	//   ﺸﯩﻤﯩ, _iluh_, _avfe, ्यौं_, 
   {{0x3a2514b3,0x29184375,0x3f84013e,0xba240b3e}},	//   емог, _anqa_, _uhlu_, едок, 
   {{0x7d0914b4,0xba1c0154,0x7cd406be,0x00000000}},	//   pdes, দন্ড_, gərç, --, 
   {{0x602402b1,0x63ac035a,0xfce80ccb,0xdb1800e4}},	//   _tūmā, _otcn, _رفتي_, rruñ, 
   {{0x1cdc08ea,0x213c083a,0x3cc00116,0x00000000}},	//   _སྐར_, _mluh_, _ﺭﻩﺳﻤ, --, 
   {{0xa82001b9,0x7cd403e3,0x27fc0205,0x00000000}},	//   چکین, bərç, çuna_, --, 
   {{0xe61514b5,0x69c80270,0x7bc82f81,0xf96003e6}},	//   ндр_, _gvfe, lseu, _مۆدێ, 
   {{0x7bc80421,0xe8040243,0x01e40154,0x00000000}},	//   oseu, शिखा_, নবাদ, --, 
   {{0x7bc9081d,0xb3840a8f,0x25bc01fa,0x96d40139}},	// [199a0] nseu, елал, ćula_, _иснә, 
   {{0x1cdc0867,0x7bc914b6,0x63a80077,0x7ae114b7}},	//   _སྐལ_, iseu, ígna, nglt, 
   {{0xda1c12eb,0xf7705220,0x7ae00204,0x63ac035a}},	//   यमित_, _لاگ_, iglt, _etcn, 
   {{0x7bd40034,0x7bc914b8,0x614017b4,0x21640108}},	//   ązuj, kseu, леха, нихи_, 
   {{0x7bc914b9,0x8f24002e,0x6f183b03,0x8afc002d}},	//   jseu, _l茜ep, _pntc, rlęz, 
   {{0x213c020c,0x2d84123b,0x290800d0,0x63b8036e}},	//   _eluh_, _shoe_, zdca_, _çuna, 
   {{0xe36114ba,0x213c0036,0x48e0227c,0x91c46ba3}},	//   _скри, _fluh_, _कालो_, _шавҗ, 
   {{0xe29514bb,0x213c1224,0x7bc80af9,0x63680b97}},	//   _час_, _gluh_, fseu, düny, 
   {{0xd6d804c5,0x1be4026a,0x614114bc,0x7bc800d5}},	//   দ্যয, едњи_, _сета, gseu, 
   {{0x6c980055,0x7fb40066,0x00000000,0x00000000}},	//   _dṛḷh, _شلمچ, --, --, 
   {{0x2d840032,0x7bc8a621,0x00000000,0x00000000}},	//   _thoe_, aseu, --, --, 
   {{0x79541ebd,0xdca00063,0x5ca0030d,0x2d8800fb}},	//   tšwa, _баци, _бицб, _эйеп_, 
   {{0xdce80003,0x00000000,0x00000000,0x00000000}},	//   _sigħ, --, --, --, 
   {{0xda6005f5,0xa4980086,0x39500ffb,0x2908014b}},	//   _өвчи, _iaòi, _emys_, sdca_, 
   {{0xdce80327,0x8880004b,0x34acec74,0x00000000}},	//   _qigħ, دیښن, _ọdọ_, --, 
   {{0x48140588,0x28d805f9,0xe8fc06af,0x7c4406be}},	//   _амис, _भाटि, goût_, _ötrü, 
   {{0x1cdc0135,0xd838009d,0x00000000,0x00000000}},	// [199b0] _སྐས_, _зээ_, --, --, 
   {{0xd6d804c5,0xdce8031c,0x534400c7,0x00000000}},	//   দ্বয, _tigħ, лхха, --, 
   {{0xbb34001f,0x213c0306,0xc1740133,0xd04006be}},	//   _ይገባዋ, _pluh_, نگرت, _idmə, 
   {{0x4094cc45,0x7fd40845,0xc484004e,0x41540395}},	//   نلار, вікі, _үлүк, ъвес, 
   {{0x7bc80007,0xb340031c,0x00000000,0x00000000}},	//   xseu, ħħre, --, --, 
   {{0x25740790,0x00000000,0x00000000,0x00000000}},	//   rçlu_, --, --, --, 
   {{0xfd10007b,0x00000000,0x00000000,0x00000000}},	//   لجة_, --, --, --, 
   {{0x7e6d14bd,0x213c0c6a,0x7bc914be,0x00a00244}},	//   şapo, _uluh_, tseu, _ئیشێ, 
   {{0x7bc914bf,0xfb880139,0x4c3401c0,0xcd040114}},	//   useu, мбик_, гээт, учји, 
   {{0x1ea80be2,0x9f4801f4,0x00000000,0x00000000}},	//   _رائي_, ölän_, --, --, 
   {{0x7bc914c0,0x7f400194,0x61e80139,0x95f0000d}},	//   sseu, _illq, _çolğ, _चहेट_, 
   {{0x09e000cc,0x8afc0210,0xcd180064,0x00000000}},	//   _বনশা, gnęb, _пціч_, --, 
   {{0xeb8d14c1,0x69dc02bf,0xb8e82d81,0x38600092}},	//   _ви_, _åpen, _लज_, ተካሄዱ_, 
   {{0x41d035a7,0x4c8401ca,0x00000000,0x00000000}},	//   _हिंस, _слів, --, --, 
   {{0x65c114c2,0xc5d40212,0x00000000,0x00000000}},	//   ибра, літь, --, --, 
   {{0xf98800e3,0x25080101,0x85780108,0xe8f401af}},	//   _تنبي_, ورقی_, есут_, _алъ_, 
   {{0x64a0586c,0x7f400784,0xf7440022,0xd48400c7}},	// [199c0] рауа, _ollq, _аепо, укақ, 
   {{0x98a001fa,0xdb04007c,0x00000000,0x00000000}},	//   _boić_, _ölän, --, --, 
   {{0x63b8010e,0x4d8c0220,0xb52c0023,0x6d5c6479}},	//   _çunn, _ﺗﺎﯞﯨ, _ደገፍት, épak, 
   {{0x7f4003f0,0xb3400327,0x5f700633,0x00000000}},	//   _allq, ħħqe, یاور, --, 
   {{0x98a0003a,0x90540133,0x7e6c0205,0x00000000}},	//   _aliī_, دراڵ, şapl, --, 
   {{0xdbd81f60,0x9f8001c0,0x1f70109a,0x00000000}},	//   _ráðg, агчд, алія, --, 
   {{0xe2950d56,0xdbd80162,0xede401e0,0xa2f4011a}},	//   _аар_, _sáðg, тһеҙ_, _שמלה_, 
   {{0x3d1912d8,0x00000000,0x00000000,0x00000000}},	//   भागे_, --, --, --, 
   {{0x1e8005a2,0x2dd40050,0xab8400f3,0x00000000}},	//   лләм, رُکھ_, куок, --, 
   {{0x09dc031c,0x2b900066,0x00000000,0x00000000}},	//   _ཤཀྱ_, جیتس, --, --, 
   {{0x2d043a49,0x00000000,0x00000000,0x00000000}},	//   _аялг, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d4114c3,0xd7c40818,0xd9ac00eb,0x00000000}},	//   _iloa, иёро, _কিঃম, --, 
   {{0x6d4114c4,0x260c0ce0,0x00000000,0x00000000}},	//   _hloa, डिली_, --, --, 
   {{0x95c8ede6,0xda44004b,0xdbe006af,0xdb18007c}},	//   кута_, _لټون_, _réév, truö, 
   {{0xc4dc23e9,0x69d914c5,0x00000000,0x00000000}},	//   यलेख, mrte, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [199d0] --, --, --, --, 
   {{0x69d914c6,0xe5c41ee3,0x6d4000cf,0x7d1c01ed}},	//   orte, _исмо, _lloa, össz, 
   {{0x6d4114c7,0x2bec0154,0x92a400d8,0x00000000}},	//   _oloa, জিয়ে_, рјул, --, 
   {{0x69d914c8,0xb3d4013d,0x5184013d,0x00000000}},	//   irte, _әйрә, ауча, --, 
   {{0x69d8481f,0xd250066d,0xccac0150,0x00000000}},	//   hrte, منے_, _ﺴﺘﺘﻔ, --, 
   {{0x6d4114c9,0xaed0026a,0x00000000,0x00000000}},	//   _aloa, бољш, --, --, 
   {{0x6d4007e4,0xb06002f6,0xfd980063,0x00000000}},	//   _bloa, _ääni, нтић_, --, 
   {{0x6d4114ca,0xc0e0001f,0x7c940023,0x628400de}},	//   _cloa, ነትም_, _መሳልል_, _izjo, 
   {{0x69d914cb,0x91840131,0xfaa46179,0x91b00208}},	//   erte, _ئۇنۇ, лапо, _đảo_, 
   {{0x6d409da5,0x7f4002d1,0xcc08007b,0xdb1803b2}},	//   _eloa, _ullq, ئزين_, lsuú, 
   {{0x9ba004a9,0x6d400746,0x3e3437ba,0x00000000}},	//   _ھەدى, _floa, _حفار, --, 
   {{0x6d4114cc,0x2e3800c8,0x00000000,0x00000000}},	//   _gloa, _אגענ, --, --, 
   {{0x69d914cd,0xbb74030d,0x00000000,0x00000000}},	//   arte, _йукъ, --, --, 
   {{0x97741cd1,0x9b6801b9,0x00000000,0x00000000}},	//   ртмә, _ўшда_, --, --, 
   {{0xe64003c5,0x7958010a,0x00000000,0x00000000}},	//   берп, _пикĕ, --, --, 
   {{0xa50514ce,0xae04000d,0x00000000,0x00000000}},	//   леса_, _वईसन_, --, --, 
   {{0xf2d87eea,0x03a8004b,0x63b800a2,0x34840139}},	// [199e0] فظات_, ندلو_, _çunl, угаг, 
   {{0xb96001f2,0x370514cf,0xbad400eb,0x216401a9}},	//   ọndọ, _спог, ত্রছ, қичи_, 
   {{0x7ae40254,0x00000000,0x00000000,0x00000000}},	//   _öhtu, --, --, --, 
   {{0xe0400323,0x69cd14d0,0xf8b405f9,0xea74010f}},	//   өнхи, ábei, ूरिय, אגער_, 
   {{0xb61c02dd,0xf4c401ec,0xa3d000c0,0x00000000}},	//   _ﺤﻕ_, _ﺩﻩﺳﻜ, _лоўч, --, 
   {{0x6d4114d1,0xc8780209,0x643800c8,0x69d88b1c}},	//   _sloa, üşi_, _טעכנ, yrte, 
   {{0x6d4114d2,0x324407d6,0xc17400d1,0xd1f80092}},	//   _ploa, _севг, ددەت, ለቶች_, 
   {{0x614042cd,0x69d8012c,0xdee00fc0,0x52741188}},	//   _леса, vrte, _ҳофи, _буғу, 
   {{0x6d4003bd,0xa06514d3,0xf06514d4,0x62840135}},	//   _vloa, _бата_, _скап, _zzjo, 
   {{0x69d8151c,0x3d180574,0xdee01171,0x00000000}},	//   trte, _मोठे_, _гофи, --, 
   {{0x69d914d5,0x6d400184,0xfd4c063f,0x00000000}},	//   urte, _tloa, nchọ, --, 
   {{0x6d400270,0x69d83b52,0xe03001e1,0x291c7db4}},	//   _uloa, rrte, _ìṣé, ñua_, 
   {{0xd7f8c9ff,0x00000000,0x00000000,0x00000000}},	//   лур_, --, --, --, 
   {{0x69d809a8,0xfa54036b,0x320801e3,0xf4080154}},	//   prte, اریگ, _osby_, রমার_, 
   {{0x059440f3,0x00000000,0x00000000,0x00000000}},	//   لارگ, --, --, --, 
   {{0x99d000dd,0x44b4cec6,0x290c0086,0x960402f5}},	//   _اتوا, рбас, _ûga_, _উপশম_, 
   {{0x6fc40490,0x7df00b98,0xae04000d,0x00000000}},	// [199f0] रीमं, _अङ्ग_, _वैसन_, --, 
   {{0xd49914d6,0x0ee00412,0x9474007b,0xb9f00092}},	//   урс_, _नागड, صدقا, _ሞቅ_, 
   {{0x057800c6,0x64480086,0x13682e63,0x00000000}},	//   _لمدة_, ùgib, ушти_, --, 
   {{0x11280801,0xeaa40014,0xb61c0150,0x9f480248}},	//   лючи_, _ژٹ_, _ﺤﺕ_, _ìmús_, 
   {{0xa49914d7,0xb0600108,0x00000000,0x00000000}},	//   _caòt, _ääli, --, --, 
   {{0x44280bc9,0xe9c40451,0xbddc01ec,0x00000000}},	//   mxa_, _وٺ_, _ﺘﻘﻭل_, --, 
   {{0x442914d8,0x00000000,0x00000000,0x00000000}},	//   lxa_, --, --, --, 
   {{0xd658025f,0x49fc0327,0xdb180162,0x79440210}},	//   טיות_, _ྐྱེལ_, lsuø, _mówc, 
   {{0x442914d9,0x2bc40fb5,0xcd283b5f,0xbf100139}},	//   nxa_, алып_, اسىن_, _мүдә, 
   {{0x60c851e2,0x4428d6fa,0xefb0034c,0x00000000}},	//   lagm, ixa_, _بیوگ, --, 
   {{0x44280227,0xdcf80139,0x00000000,0x00000000}},	//   hxa_, cmuğ, --, --, 
   {{0x60c914da,0x44280bc9,0xe8f40826,0xd01001d3}},	//   nagm, kxa_, алю_, _بلے_, 
   {{0x9c1001f2,0x1cdc025c,0xda9411ca,0xeaac014b}},	//   _kọmi, _སྐག_, _өскә_, _мй_, 
   {{0x2ae005d7,0x377514db,0xcc3405af,0xaa5400ec}},	//   _खाएँ_, рымс, _درمع, _ھليا_, 
   {{0x810400ab,0x44280009,0x24980023,0xdcf80306}},	//   _रसूख_, exa_, _ጀመረት_, hluč, 
   {{0x64a00026,0xdcf80427,0x00000000,0x00000000}},	//   жата, kluč, --, --, 
   {{0x60c914dc,0x7c2914dd,0x442800f1,0xa50421b4}},	// [19a00] dagm, nxer, gxa_, шета_, 
   {{0xdcf807f5,0xc8b49a87,0x7c287a26,0x60c801ab}},	//   dluč, _پلیک, ixer, eagm, 
   {{0x44281bce,0x02180006,0x00000000,0x00000000}},	//   axa_, ліць_, --, --, 
   {{0x60c8089c,0x764c0369,0x281040ec,0x4428022e}},	//   gagm, mzby, _اویس, bxa_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9f505928,0xc290136e,0x00000000,0x00000000}},	//   овіч, _کیمب, --, --, 
   {{0x6fd006ab,0x7c28003a,0x6fb400f2,0xc0540023}},	//   _सिकं, exer, _چمرا, ሓላለፍ, 
   {{0x6fb40214,0xfe900244,0x00000000,0x00000000}},	//   _نمرا, سینج, --, --, 
   {{0xa1100a2c,0x316405c7,0x4fc400f7,0xec3000e5}},	//   _بوقت, mnoz_, _چەچە, زودگ, 
   {{0x91840058,0x3164022e,0x4fc40137,0x00000000}},	//   _ئۇچۇ, lnoz_, _نەچە, --, 
   {{0x44280083,0xece80902,0x497400cf,0x00000000}},	//   zxa_, _адел_, йлос, --, 
   {{0x442914de,0xa4980ba1,0x316405c7,0xdcac00cf}},	//   yxa_, _maòr, nnoz_, _قىم_, 
   {{0x442914df,0x06900952,0xf8ac65d1,0x48c40022}},	//   xxa_, ﻘﯩﻨﯩ, رکي_, _қәна, 
   {{0x6ff80b13,0x316514e0,0xe6640107,0xa5f40124}},	//   mācā, hnoz_, атбо, аҵоу_, 
   {{0xdcf914e1,0x44280054,0x00000000,0x00000000}},	//   zluč, wxa_, --, --, 
   {{0x442914e2,0x7c340798,0x63b914e3,0x387003b2}},	//   txa_, _égrá, _çunk, áorð_, 
   {{0x442914e4,0x79440034,0x73c0013d,0xe78400f3}},	// [19a10] uxa_, _wówc, зәсе, _вуно, 
   {{0x442914e5,0x00000000,0x00000000,0x00000000}},	//   rxa_, --, --, --, 
   {{0x60c914e6,0x46140f1c,0x442914e7,0x5694030d}},	//   tagm, _اوجر, sxa_, _маьт, 
   {{0x44280bc9,0x316514e8,0xc3c418c7,0x00000000}},	//   pxa_, gnoz_, _гөжл, --, 
   {{0x60c914e9,0x7c28025c,0x39a40171,0x00000000}},	//   ragm, xxer, _vēsi_, --, 
   {{0x8ee800d4,0x13a80244,0x00000000,0x00000000}},	//   имів_, _ئۆلی_, --, --, 
   {{0x60c8113c,0xbdf8179e,0x31640156,0xb6d800df}},	//   pagm, ارتا_, bnoz_, אַפט, 
   {{0x61403ee0,0x7c2819bb,0x23642375,0x9f5c0008}},	//   _بىرە, txer, čnju_, _eruð_, 
   {{0x8d280598,0x7c2810d8,0x00000000,0x00000000}},	//   рның_, uxer, --, --, 
   {{0x7c28056a,0xd5440241,0x3b080063,0x00000000}},	//   rxer, _kẹ̀l, ћено_, --, 
   {{0x39e807e6,0x3a98005b,0x00000000,0x00000000}},	//   ыдно_, ытию_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x5ba46ff7,0xfaa423c5,0x6ff8002b,0x00000000}},	//   _трез, _лало, cācā, --, 
   {{0x31640165,0xa7a40022,0xab24026b,0x00000000}},	//   znoz_, скра_, _гоша_, --, 
   {{0xe64000d6,0x9f4c05d5,0x7ae800f1,0xe73403c5}},	//   перп, rtgè_, _لوږې_, щер_, 
   {{0x3164022e,0x00000000,0x00000000,0x00000000}},	//   xnoz_, --, --, --, 
   {{0xdeb8010c,0x81e405ac,0x00000000,0x00000000}},	// [19a20] ደሉን_, _বৈল_, --, --, 
   {{0x3d1801ad,0x5fa8000d,0x00000000,0x00000000}},	//   _मोसे_, _चढ़ल, --, --, 
   {{0x06c800cf,0x37a800fe,0x00000000,0x00000000}},	//   _өгөй_, _কবিৰ, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x31640dd4,0xdfcc43b9,0xd37057d7,0x9c100241}},	//   rnoz_, فين_, _قۇر_, _dọki, 
   {{0x437514ea,0xfd5400b8,0x27fc0200,0x00000000}},	//   _дуст, _idaṃ, çuni_, --, 
   {{0x3d1802ab,0x426400ee,0x316415b7,0xa34401b9}},	//   _मोहे_, _дерң, pnoz_, _узра_, 
   {{0x69dc0158,0x31640213,0x00000000,0x00000000}},	//   _åpei, qnoz_, --, --, 
   {{0x61f800f3,0xbd5400f2,0x00000000,0x00000000}},	//   _ćuli, تروژ, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xcdc40137,0x00000000,0x00000000,0x00000000}},	//   _بۇعۇ_, --, --, --, 
   {{0xefd00020,0xdd8c00c6,0xac84004e,0x00000000}},	//   ረገው_, _كول_, _лгел, --, 
   {{0x2ca4009a,0x00000000,0x00000000,0x00000000}},	//   _igod_, --, --, --, 
   {{0x63b80200,0x8a180a5b,0x00000000,0x00000000}},	//   _çuni, _вокс_, --, --, 
   {{0xfd540055,0xd5b914eb,0x99d0007b,0x00000000}},	//   _adaṃ, йст_, _فتيا, --, 
   {{0x39a4005f,0xeac00345,0x00000000,0x00000000}},	//   _cēsu_, _بڕکێ, --, --, 
   {{0x994816a2,0x833514ec,0x2ca4004d,0x00000000}},	// [19a30] _دليل_, онах, _mgod_, --, 
   {{0xd5440248,0x386408a5,0x00000000,0x00000000}},	//   _pẹ̀l, _þora_, --, --, 
   {{0x8afc0034,0x93880166,0x12c401b9,0x92680798}},	//   międ, сста_, яётг, брца_, 
   {{0x2ca4016d,0x20c80372,0x96b80133,0x00000000}},	//   _ngod_, اباي_, _پایز_, --, 
   {{0xbea40f06,0x00000000,0x00000000,0x00000000}},	//   оалк, --, --, --, 
   {{0x2ca40004,0x8afc0034,0xd5440241,0x00000000}},	//   _agod_, nięd, _tẹ̀l, --, 
   {{0x260c01ad,0xdf800014,0x5fa801f9,0x00000000}},	//   डिटी_, _ہُری, _चढवल, --, 
   {{0xdb800023,0x00000000,0x00000000,0x00000000}},	//   _ርእዮም_, --, --, --, 
   {{0x797006c8,0x3ea4000d,0x00000000,0x00000000}},	//   nāwe, _tglt_, --, --, 
   {{0x6d5c0231,0x3d1894f7,0xab7514ed,0xe518000d}},	//   épar, _मोरे_, يميا_, _पोसि_, 
   {{0x7cd86e9a,0xd1cc0020,0x79700374,0xc0c80092}},	//   _نواز_, _አባት_, hāwe, _አናሳ_, 
   {{0x8328031c,0xa49801e1,0xbc1801ce,0xbb4801b9}},	//   _ལོའུ_, _gbòg, _вікі_, الگن_, 
   {{0x31c400dc,0x9500031c,0x8d74007b,0x3178010f}},	//   _लब्ध, _ཝིཏི_, _عاما, שארד, 
   {{0xf6242377,0x2ca40010,0xd1cc0092,0x7944012d}},	//   одго, _zgod_, _አባቴ_, _gówn, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2ca404e6,0x91b00208,0x37e421b4,0x00000000}},	//   _xgod_, _đào_, _доиг, --, 
   {{0xe5742355,0x1cdc025c,0xe3b40063,0x39a400de}},	// [19a40] ізу_, _སྐབ_, жбу_, _vēsu_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa498033b,0xf74800aa,0x8afc033f,0x7984017a}},	//   _abòd, _ملکي_, sięg, olkw, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xee0114ee,0xa110709c,0x6b080135,0x00000000}},	//   लब्ध_, بونت, _ཀྲའོ_, --, 
   {{0x2cb00210,0x00000000,0x00000000,0x00000000}},	//   _żyd_, --, --, --, 
   {{0x7944006d,0x386c013f,0xdb182508,0x00000000}},	//   _równ, _ɛfra_, mpuè, --, 
   {{0x71242e0b,0x00000000,0x00000000,0x00000000}},	//   _برسل, --, --, --, 
   {{0xeb042607,0xa4980ca8,0x6fc477ca,0xa4b4011a}},	//   очно, _gbòd, रीशं, חלפה_, 
   {{0x4a54de2f,0x2aa80063,0xd1cc0092,0x6b800248}},	//   зкос, штио_, _አባተ_, _ọgbo, 
   {{0x2ca405d5,0x6fc406e3,0x00000000,0x00000000}},	//   _tgod_, रीरं, --, --, 
   {{0x2ca40280,0x00000000,0x00000000,0x00000000}},	//   _ugod_, --, --, --, 
   {{0x2d480086,0x3dc40154,0x7e6c0205,0x00000000}},	//   _tùeb_, _এমএল, şapt, --, 
   {{0x6ce800e1,0xca780139,0x04400092,0xa9a8009b}},	//   _टाँग_, _sovе, _የመጻሕ, _књиж_, 
   {{0x89d836ba,0xd1cc0092,0x00000000,0x00000000}},	//   _اوبر_, _አባቱ_, --, --, 
   {{0x797000b0,0x99640166,0x55040022,0x569401f4}},	//   tāwe, _отыл, мчуа, фаст, 
   {{0xd8380323,0x91b0004d,0x68f8000d,0x00000000}},	// [19a50] _дээ_, _đáo_, õudu, --, 
   {{0xdce804a7,0x797000b0,0x1cdc0327,0x27fc2ca8}},	//   _čičk, rāwe, _སྐན_, çunu_, 
   {{0x6ce81889,0xdb00017a,0xd7741411,0xd3780024}},	//   _टांग_, _binê, _تايع, ічу_, 
   {{0x7ff514ef,0x83540014,0xd2580108,0x00000000}},	//   كستا, _کھرا, ццу_, --, 
   {{0x6fc410dc,0x656c047e,0x442c008e,0x948401ec}},	//   रीलं, _ijch, _çe_, _жырд, 
   {{0xdb080798,0x961801d5,0x6d5c020c,0xd61800f1}},	//   _eugê, _اغیر_, èpan, _اتیا_, 
   {{0xfe442e01,0x00000000,0x00000000,0x00000000}},	//   янко, --, --, --, 
   {{0x10e47c3f,0x00000000,0x00000000,0x00000000}},	//   _оюум, --, --, --, 
   {{0x60d914f0,0xb7e40eac,0xac80011c,0x00000000}},	//   _idum, _ফন্ট, нгъл, --, 
   {{0xdb040b97,0x00000000,0x00000000,0x00000000}},	//   _ölün, --, --, --, 
   {{0xd910066d,0x98b01b24,0x60d8022e,0x00000000}},	//   ہیں_, šača_, _kdum, --, 
   {{0x60d8025c,0x201d14f1,0xdb000240,0xf990007b}},	//   _jdum, _krui_, _kinë, عبد_, 
   {{0x60d914f2,0xec6c0958,0xd91000e5,0x315400df}},	//   _mdum, _чп_, فیں_, פישן_, 
   {{0x7d08394f,0x656c0309,0xdb0000e8,0xdb080200}},	//   lees, _ajch, _minë, _mugë, 
   {{0xdb08036e,0x39a40171,0x00000000,0x00000000}},	//   _lugë, _vēss_, --, --, 
   {{0x7d0914f3,0x60d914f4,0x2a380302,0xf624013e}},	//   nees, _ndum, _לעצמ, одҳо, 
   {{0x656c009f,0xf7e804b3,0xb4bc000d,0x00000000}},	// [19a60] _djch, _ارعى_, _ीजी_, --, 
   {{0x7d0914f5,0x60d80428,0x8afc068f,0xd6c40811}},	//   hees, _adum, mięc, _تمدی, 
   {{0x7d0914f6,0xdce80139,0x00000000,0x00000000}},	//   kees, _ligı, --, --, 
   {{0x7d080a55,0x9f4c07c5,0xdb18068c,0x33d40212}},	//   jees, stgì_, spuè, _нігт, 
   {{0x8afc068f,0x7d08be5c,0x60d81418,0xee3801c0}},	//   nięc, dees, _ddum, өнд_, 
   {{0x60d8668f,0xa2b8f068,0xdb080de2,0x8afc012d}},	//   _edum, शुद्, _dugë, zięb, 
   {{0x7d0914f7,0x201d14f8,0x723801d9,0x95900092}},	//   fees, _erui_, _آزر_, _ሁኔታን_, 
   {{0x7d0914f9,0x201d14fa,0x61e001e7,0x00000000}},	//   gees, _frui_, ánle, --, 
   {{0x6fb4044d,0xdb08002e,0xab8400d1,0xdd9c00d7}},	//   _رمضا, _gugë, зунк, áňal_, 
   {{0x49d80212,0x60d8012d,0x6da801ef,0xe4540677}},	//   одою_, _zdum, _přad, פייט_, 
   {{0x7d0822a9,0x1cdc0003,0xdd8c04d3,0x6130010b}},	//   bees, _སྐམ_, _ڵوه_, _açly, 
   {{0x7d088200,0xdb0002e2,0x68fc0175,0xdce80166}},	//   cees, _linè, _qbqd, _figı, 
   {{0x6d440054,0xac9875f5,0x8afc0210,0x00000000}},	//   _ŋkaw, _انشا_, gięc, --, 
   {{0xd7f914fb,0x7c6514fc,0x6f08009a,0x98c400c7}},	//   чую_, _تامل, nefc, _ҧсыл, 
   {{0x50cc6c08,0x69140077,0xda6c00a8,0xdbd80ca8}},	//   ाराष, güeñ, _чя_, _láìg, 
   {{0x39900077,0x6f089017,0xa8a4004e,0x00000000}},	//   táse_, hefc, _эркк, --, 
   {{0x290914fd,0xdb00588b,0xdb08020c,0xe2a80a2c}},	// [19a70] meca_, _binè, _bugè, ماان_, 
   {{0xdb00180f,0x797006c8,0x60d8014b,0x3990056a}},	//   _cinè, māwa, _sdum, ráse_, 
   {{0xdb0914fe,0x7d0914ff,0x79700069,0x224401ed}},	//   _utgå, yees, lāwa, ánk_, 
   {{0xdb091500,0x29081d47,0x656c0309,0xed446449}},	//   _eugè, neca_, _ujch, _شپ_, 
   {{0xdb184e4c,0x7d091501,0x797018a6,0xdb011502}},	//   spué, vees, nāwa, _finè, 
   {{0x7d091503,0x29091504,0xa4980699,0xdb1803fa}},	//   wees, heca_, _ebòc, ßzüg, 
   {{0x7d091505,0x29091506,0x63a40165,0x8afc0034}},	//   tees, keca_, _iijn, zięc, 
   {{0x60d91507,0x63ac1225,0x201c23f3,0x657c0b6f}},	//   _udum, _kucn, _trui_, noqh, 
   {{0x29091508,0x63ac0113,0x5ba00131,0x39900332}},	//   deca_, _jucn, нлиғ, hásc_, 
   {{0x7d091509,0xdb01150a,0x63a4014f,0x63ac08a4}},	//   sees, _xinè, _jijn, _mucn, 
   {{0x7d09150b,0x63a40cf9,0xdb00012c,0xdb08529d}},	//   pees, _mijn, _jiné, _jugé, 
   {{0x63a40cf9,0xdb00a4f1,0x6284054e,0x8d75150c}},	//   _lijn, _miné, _myjo, _كانا, 
   {{0xdb0061d0,0x6aa80175,0x9be4031c,0x657c0477}},	//   _liné, _fgff, _འཀྲོ, doqh, 
   {{0xe7e0012d,0x00000000,0x00000000,0x00000000}},	//   कंजा_, --, --, --, 
   {{0x8afc068f,0x00000000,0x00000000,0x00000000}},	//   sięc, --, --, --, 
   {{0x95b401d2,0x2909150d,0x63ac110c,0xdb0000db}},	//   _үрнә, ceca_, _bucn, _sinè, 
   {{0x63a40936,0x63ac01a6,0xdb01150e,0xe4ec000d}},	// [19a80] _bijn, _cucn, _pinè, _छारि_, 
   {{0x63a40007,0xdb000098,0x63ac0208,0x324400db}},	//   _cijn, _biné, _ducn, мезг, 
   {{0xdb01150f,0x63a51510,0x79440210,0x00000000}},	//   _ciné, _dijn, _nówk, --, 
   {{0xdb000165,0xafe40982,0x00000000,0x00000000}},	//   _diné, додл, --, --, 
   {{0x63a40cf9,0xdb091511,0xdb000100,0x00000000}},	//   _fijn, _eugé, _tinè, --, 
   {{0x63a40007,0xdb011512,0x29080cf4,0xce940395}},	//   _gijn, _finé, zeca_, налъ, 
   {{0xc32c0131,0x63ac110c,0xdb000332,0x00000000}},	//   _دەل_, _zucn, _giné, --, 
   {{0x63a40196,0x2d80002d,0x290800cf,0x79940042}},	//   _zijn, ôke_, xeca_, _nhyw, 
   {{0xa0641d37,0x9f4c04cc,0x1b14015b,0x00000000}},	//   _жата_, btgà_, তানে_, --, 
   {{0xdee0035b,0x657c0107,0x29080066,0xac904942}},	//   _аофи, zoqh, weca_, нақш, 
   {{0x6e447092,0x657c0107,0xdb00004e,0x3d1802e5}},	//   _تنام, yoqh, _xiné, _मोके_, 
   {{0x799403cb,0x797002b5,0xefc001f3,0x00000000}},	//   _chyw, tāwa, _ሺኖዳ_, --, 
   {{0xdd8c0075,0x5884e368,0x9f4800d8,0xe7846426}},	//   _ئون_, выра, _ímãs_, дуво, 
   {{0x290808ad,0x63ac07f5,0xdba002d3,0x797002b1}},	//   seca_, _rucn, _ወሲዶም_, rāwa, 
   {{0x29091513,0x63a40196,0x2c1400cd,0x00000000}},	//   peca_, _rijn, तिकं_, --, 
   {{0x99440baf,0x63ac597f,0xdb000c6a,0x797002b1}},	//   mış_, _pucn, _riné, pāwa, 
   {{0x9944538f,0xdb011514,0x63a46ae2,0xdb08003e}},	// [19a90] lış_, _siné, _pijn, _sugé, 
   {{0xdb000789,0xdb08004e,0x63a40455,0xe2a86f04}},	//   _piné, _pugé, _qijn, زائن_, 
   {{0x9944538f,0x399000dd,0x63a402d3,0x64b00118}},	//   nış_, lása_, _vijn, třič, 
   {{0x63a51515,0x63ac02f0,0xe4e8007b,0x00000000}},	//   _wijn, _tucn, _بعده_, --, 
   {{0x5ed000bd,0x63a40582,0xb82025c9,0x39906293}},	//   _সাবে, _tijn, मियम_, nása_, 
   {{0x994403ee,0xc2c41b80,0x1ee401d3,0xdb0000e5}},	//   kış_, _سيري, ذوبی_, _tiné, 
   {{0x64480b34,0x9f4c0c86,0x00000000,0x00000000}},	//   øgif, rtgà_, --, --, 
   {{0x92951516,0x99451517,0x9f4c05d5,0x399001d3}},	//   _расц, dış_, stgà_, kása_, 
   {{0x79940cfd,0x51851518,0x3af4855f,0x00000000}},	//   _rhyw, _рура, нянс, --, 
   {{0x399000dd,0xd0400213,0x1b000166,0x00000000}},	//   dása_, _nemə, түкн, --, 
   {{0x99440724,0xdcf800bc,0x2f1400db,0x0c2401ec}},	//   gış_, louč, _سۉيگ_, емөн, 
   {{0x7c2c0327,0x39900332,0x6d9c0055,0x00000000}},	//   _ġarf, fása_, _ṭava, --, 
   {{0x87b801f0,0x399000e5,0x00000000,0x00000000}},	//   дуст_, gása_, --, --, 
   {{0x7d191519,0x7944068f,0x9944008e,0x00000000}},	//   _haws, _mówi, bış_, --, 
   {{0x7d184375,0xd0400cc1,0x7994015d,0xdcf8013a}},	//   _kaws, _demə, _thyw, houč, 
   {{0x7d18094a,0xd6b000fe,0x39901aa9,0xdcf801ef}},	//   _jaws, কৰূপ, bása_, kouč, 
   {{0x7d180649,0x3d000b7c,0xf770411c,0x778401f4}},	// [19aa0] _maws, व्ये_, _ماد_, _плиз, 
   {{0x7d19151a,0xa2b813da,0x66e0010a,0xa878011a}},	//   _laws, शुल्, _йоьа, _מאפר, 
   {{0xc7642dfc,0x7c2c0162,0xeb90010f,0x00000000}},	//   _جايى, _áarf, אָף_, --, 
   {{0x61e0066d,0xbb380150,0x03a40022,0x09ac00cc}},	//   ánla, _ﮔﺎﻱ_, еиӡо, কীকা, 
   {{0xd04000ac,0x00000000,0x00000000,0x00000000}},	//   _yemə, --, --, --, 
   {{0x99443235,0x2f540276,0xf1d0004e,0x6fc40210}},	//   yış_, этес, _бөдө, रीगं, 
   {{0x99440cc1,0x6b644aee,0x399000dd,0x321c0109}},	//   xış_, _légè, zása_, _éty_, 
   {{0x21a1151b,0x7d19151c,0xdd94d8f9,0xdd9000ee}},	//   _бисм, _caws, ншы_, лащы, 
   {{0x3075151d,0x0084013d,0x1e80a5a9,0x60d4011a}},	//   _чувс, _актү, кләм, _רומא_, 
   {{0x99444952,0x5ed0015b,0xd1d00b82,0xdb180254}},	//   tış_, _সাথে, _ጥሪት_, ksuõ, 
   {{0x7d180009,0x00000000,0x00000000,0x00000000}},	//   _faws, --, --, --, 
   {{0x6f19151e,0x3990066d,0x9944722d,0x6c8400c6}},	//   _hatc, tása_, rış_, _كلام, 
   {{0xa4980699,0x56940046,0x2d8400f2,0x98046030}},	//   _abòn, ғатт, _ikoe_, лярд, 
   {{0x7d18068f,0x7c2c17a3,0x399106e6,0xdca00063}},	//   _zaws, _šarg, rása_, _сачи, 
   {{0x2d840418,0xe97006ba,0x6368031c,0x399000e5}},	//   _kkoe_, _مۇدد, nżne, sása_, 
   {{0x7d18002e,0x6f180f85,0x00000000,0x00000000}},	//   _xaws, _latc, --, --, 
   {{0xe3b00f1b,0x6f19151f,0x2d84020c,0x31650d1c}},	// [19ab0] ارر_, _oatc, _mkoe_, dioz_, 
   {{0x69d85a29,0x2d840270,0x29180ba7,0x7944012d}},	//   oste, _lkoe_, _haqa_, _rówi, 
   {{0x69d91520,0x2d847343,0x2bec015b,0xa4980248}},	//   nste, _okoe_, ড়িয়ে_, _gbòn, 
   {{0x2d8400fb,0xd0480952,0x6f1802d0,0x29180135}},	//   _nkoe_, ﯩﻠﯩﭗ_, _aatc, _jaqa_, 
   {{0x6f191521,0x7d1804ce,0x29191522,0x69d91523}},	//   _batc, _raws, _maqa_, hste, 
   {{0x2d840418,0x7d191524,0xdcf85ef9,0x6f1826e7}},	//   _akoe_, _saws, rouč, _catc, 
   {{0x2f103306,0x69d91525,0x92945518,0x7d191526}},	//   شِير, jste, _барц, _paws, 
   {{0x26d0044e,0x387c0034,0x6f1803ac,0x29191527}},	//   _lexo_, ętrz_, _eatc, _naqa_, 
   {{0x69d91528,0x6f180ffb,0xdb000ffb,0x6bd400db}},	//   este, _fatc, _finì, نويس_, 
   {{0x2d8403a0,0x26d02cd7,0x69d91529,0x29180194}},	//   _ekoe_, _nexo_, fste, _aaqa_, 
   {{0x28c00574,0x2d840270,0x2919152a,0x7d19152b}},	//   _व्हि, _fkoe_, _baqa_, _taws, 
   {{0x8afc068f,0x17c400c7,0x00000000,0x00000000}},	//   wnęt, ламҭ, --, --, 
   {{0x69d9152c,0x17842097,0x2918014f,0x6f19152d}},	//   aste, лқиг, _daqa_, _yatc, 
   {{0xdb0800d2,0x6f180077,0x69d9152e,0x99780356}},	//   _kugí, _xatc, bste, _băţ_, 
   {{0x26d00077,0x2919152f,0xdb0001ef,0x69d8072d}},	//   _dexo_, _faqa_, _jiní, cste, 
   {{0x25a8011c,0x66dc008e,0xdb0000d8,0x26d00009}},	//   _cicl_, _açkı, _miní, _eexo_, 
   {{0xe5a01f54,0x28104955,0x7c2c03b2,0xb38473b3}},	// [19ac0] рити, _نويس, _áard, влал, 
   {{0x15b4313e,0x66180210,0x00000000,0x00000000}},	//   _مەسس, łuka, --, --, 
   {{0x6f191530,0xf77001d9,0x29180986,0x213c0129}},	//   _ratc, _ماگ_, _yaqa_, _bouh_, 
   {{0x6f191531,0x213c0226,0x291801d9,0x66003648}},	//   _satc, _couh_, _xaqa_, _änka, 
   {{0x31651532,0x6f182517,0xdfcc3a16,0x5fb0007b}},	//   rioz_, _patc, قين_, لمنط, 
   {{0x69d91533,0x26d007a9,0x395000a9,0x6f18014f}},	//   yste, _xexo_, _llys_, _qatc, 
   {{0x69d8f496,0x62802045,0x3164009d,0xdb0000ae}},	//   xste, ünot, pioz_, _ciní, 
   {{0x69d80623,0x6f188a83,0xe2951534,0x4c951535}},	//   vste, _watc, _рас_, лийс, 
   {{0x69d91536,0x29184e61,0xdb000ffb,0x5910031c}},	//   wste, _raqa_, _tinì, _ཏྲེས_, 
   {{0xdb0001e1,0x3950abd8,0x2fc51537,0x00000000}},	//   _finí, _alys_, mpog_, --, 
   {{0x69d91538,0x2fc4036b,0x213c0097,0x26d00077}},	//   uste, lpog_, _youh_, _rexo_, 
   {{0x26d11539,0x2919153a,0x7c2c1b24,0x00000000}},	//   _sexo_, _qaqa_, _šare, --, 
   {{0xdb0006ed,0x291819a2,0xd7f85395,0x00000000}},	//   _dinâ, _vaqa_, кур_, --, 
   {{0x2919153b,0x39500109,0x7c644cf2,0xe6bc012c}},	//   _waqa_, _elys_, _حامل, ्रेज, 
   {{0xdb00000f,0x26d01709,0xa49801e1,0x2919153c}},	//   _finâ, _vexo_, _ebòl, _taqa_, 
   {{0x592c1e81,0x55747ecf,0x290c01e1,0x00000000}},	//   _སོགས_, агст, _úga_, --, 
   {{0x213d153d,0x26d1153e,0xa4980241,0x6d5c39b2}},	// [19ad0] _rouh_, _texo_, _gbòl, épay, 
   {{0x4094049e,0x61e000dd,0x213c0369,0x93440063}},	//   ۇلار, ánlo, _souh_, анђе, 
   {{0xa4980ca8,0x61e80210,0xb6d800df,0x00000000}},	//   _ibòm, ąglo, _אַכט, --, 
   {{0x3fd80166,0x80780132,0x98c0002b,0x00000000}},	//   емдэ_, нбес_, _āsīc_, --, 
   {{0x2fc40270,0x5fa010a8,0x94a8010a,0x00000000}},	//   gpog_, لەرم, _атра_, --, 
   {{0x5ed0015b,0xf4100375,0x00000000,0x00000000}},	//   _সাহে, _הפך_, --, --, 
   {{0xfd1000c6,0x00000000,0x00000000,0x00000000}},	//   مجة_, --, --, --, 
   {{0xdb01153f,0x2fc40218,0x7c2c0327,0x3a2800d7}},	//   _viní, bpog_, _ġarb, _čap_, 
   {{0x3b843e5b,0xfc300597,0x98a00b4b,0x80c800dc}},	//   ллиг, صحة_, _inić_, _ह्ये, 
   {{0xe6bc6b9b,0x592c0327,0x39511540,0x8fa40114}},	//   ्रोज, _སོངས_, _slys_, _вађе, 
   {{0x98a000f3,0xe9d40276,0x39511541,0xeb8c0454}},	//   _knić_, лкэ_, _plys_, _ҳи_, 
   {{0x7f40016d,0x0dc800d8,0x00000000,0x00000000}},	//   _holq, _руфи_, --, --, 
   {{0xeb8d1542,0x4f080150,0x7544cb18,0xde440101}},	//   _ги_, _ستەپ_, қназ, _سیکو_, 
   {{0x7f400135,0xfee400eb,0x00000000,0x00000000}},	//   _jolq, প্রধ, --, --, 
   {{0x8ed8000e,0x6ec80b9c,0x7c2c0162,0x00000000}},	//   _সামগ, _स्फु, _áarb, --, 
   {{0x055401e5,0x2fc4022e,0x63b800b8,0x00000000}},	//   атуя, ypog_, _ũuna, --, 
   {{0x798402e3,0x73051543,0xf7440c60,0x93640588}},	// [19ae0] mokw, лпаз, _бепо, анаҵ, 
   {{0xdb08004e,0x98a0107d,0xf7700133,0xa260004d}},	//   _jugà, _anić_, _داب_, _tuổ, 
   {{0xdef4010c,0x7294a90c,0xf1cc0073,0x858c0150}},	//   ጋናን_, ушах, हींन, _ﺒﻌﺩﺍ_, 
   {{0x79846f46,0xa9180008,0x21a00395,0x00000000}},	//   nokw, llþr, бихм, --, 
   {{0x7f411544,0x1ae80154,0xdeb80023,0xef640395}},	//   _bolq, জ্যে_, _ኰንካ_, лъко, 
   {{0x79851545,0x7f411546,0x1f7002d5,0xe7b400c5}},	//   hokw, _colq, блія, _इंसप, 
   {{0x79851547,0x7f40014f,0x6280033f,0x2fc40af9}},	//   kokw, _dolq, żnor, spog_, 
   {{0x79840af2,0x9cc4010b,0x22940118,0x9df4011c}},	//   jokw, лыьа_, užků_, унът_, 
   {{0x7f411548,0xdb00004e,0x798402e3,0x797000b0}},	//   _folq, _binà, dokw, māwh, 
   {{0x2d9401ec,0xc90c3be5,0x00000000,0x00000000}},	//   _өрес, िज्म_, --, --, 
   {{0x49751316,0xdb0000f7,0x6ec800dc,0xfe6c030c}},	//   илос, _dinà, _स्यु, _يگى_, 
   {{0x1cb00867,0x79851549,0x797002b5,0x9f4c007c}},	//   _དུར_, gokw, nāwh, rtgå_, 
   {{0xdb0004cc,0x9a8006b3,0xdd7001ed,0x7f41154a}},	//   _finà, _қушл, _دھوک, _yolq, 
   {{0x6d41154b,0x86c4007b,0x7f400166,0xdb1803b2}},	//   _hooa, شيرن, _xolq, ppuá, 
   {{0x7985154c,0x8a180139,0x797002b5,0x45d45bc6}},	//   bokw, _ройс_, kāwh, робс, 
   {{0x79840af2,0x6d400076,0x00000000,0x00000000}},	//   cokw, _jooa, --, --, 
   {{0x6d4002a4,0x1cb00135,0x7afc3881,0xa49801e1}},	// [19af0] _mooa, _དུལ_, đstv, _ibòk, 
   {{0x6d400076,0x9f4c0240,0xdb0037b5,0xe8180037}},	//   _looa, rugë_, _kiná, _पैया_, 
   {{0x5ed000bd,0xdb080407,0x063406ed,0xd874158b}},	//   _সালে, _jugá, _тенџ, _نایب, 
   {{0xe189154d,0x6d41154e,0x7f40003a,0xdb0002f0}},	//   رئان_, _nooa, _solq, _miná, 
   {{0x7f400139,0x00000000,0x00000000,0x00000000}},	//   _polq, --, --, --, 
   {{0x7985154f,0x7f4003f0,0xd7bc0677,0xfe4401d5}},	//   zokw, _qolq, עצור, инло, 
   {{0x79851550,0x6d411551,0x6288033f,0xdb0802f0}},	//   yokw, _booa, ęgos, _nugá, 
   {{0x6d400363,0x7984009a,0xacb000d1,0xae04000d}},	//   _cooa, xokw, يمىغ, _शहरन_, 
   {{0x798418f7,0x6d400363,0x6d448234,0x7f411552}},	//   vokw, _dooa, ökaa, _tolq, 
   {{0x506405f5,0x79851553,0x3b080063,0xdb081de4}},	//   _утса, wokw, њено_, _bugá, 
   {{0x79851554,0x6d40062c,0x9f4c2a59,0xdb203765}},	//   tokw, _fooa, jugé_, لوکی, 
   {{0xdb0009ff,0x6d40062c,0x00000000,0x00000000}},	//   _diná, _gooa, --, --, 
   {{0x6b54025a,0x61e001ed,0x79840433,0x797000b0}},	//   _dâgb, ánlj, rokw, nāwi, 
   {{0xfaa4b47a,0x7bc91555,0xdb0040cf,0xa4980428}},	//   _кало, mpeu, _finá, _ebòk, 
   {{0xe7340bd6,0xdb0006ed,0x798400ec,0x7bc806af}},	//   шер_, _giná, pokw, lpeu, 
   {{0xf988038b,0x79840107,0x24e400c7,0xf8b803ba}},	//   _جنبي_, qokw, имси_, _इलिय, 
   {{0x33640006,0x7bc8030a,0x15c000d1,0xdef41954}},	// [19b00] аваг, npeu, _ﻣﺎﺩﺩ, ጋናና_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8afc068f,0xf8b806ab,0x7bc80c6a,0x79700374}},	//   więk, _इलाय, hpeu, tāwh, 
   {{0xe7b0129e,0x00000000,0x00000000,0x00000000}},	//   _دمید, --, --, --, 
   {{0x6d40062c,0x79700374,0x58a800fe,0x00000000}},	//   _rooa, rāwh, কুৰী, --, 
   {{0x6d411556,0xade42472,0x63b011ca,0x00000000}},	//   _sooa, ацик, _фәтх, --, 
   {{0xdbcc02fb,0x6d401368,0x3c9000d1,0x00000000}},	//   _džín, _pooa, ﻟﯩﺘﻰ_, --, 
   {{0x7c2c0b91,0x22443262,0x8afc033f,0x42740120}},	//   _šara, änke_, pięk, _ѓурѓ, 
   {{0xef181b10,0xceb80184,0xdb000005,0x9c3400a7}},	//   _има_, _йәй_, _siná, ипът_, 
   {{0xdb0805d5,0x8a1801c0,0x6d4000ad,0xa03000d1}},	//   _stgò, гоос_, _wooa, _بىكت, 
   {{0x6d403495,0x49a40150,0x00000000,0x00000000}},	//   _tooa, йымғ, --, --, 
   {{0xda9005f5,0x6ec8243c,0xdb18004a,0xdb011557}},	//   өгөө, _स्तु, nquê, _viná, 
   {{0xdcf87236,0x4ed8009e,0x7d0d1558,0xe7ac0150}},	//   lluğ, সলীল, _ñasa, _ﺳﻮﺭﻟ, 
   {{0xe7851559,0x6a480213,0x5bc0007b,0x00000000}},	//   румо, vəff, _بقول, --, 
   {{0xdcf8046c,0xdb000ac8,0x0594030f,0xe5280139}},	//   nluğ, _binæ, مارگ, _sıñğ, 
   {{0x25ac05d5,0x99840345,0xd91001b9,0x44b48abc}},	//   ögl_, _ولوو, _قیپ_, сбас, 
   {{0x9949155a,0x427405a2,0xe5280166,0x4498003b}},	// [19b10] _خليل_, әгес, _qıñğ, уваю_, 
   {{0xdcf803ee,0xdb0002d2,0x5c34011a,0x80c800bc}},	//   kluğ, _einæ, ברמן_, हुने, 
   {{0xd1b9155b,0x00000000,0x00000000,0x00000000}},	//   لانا_, --, --, --, 
   {{0xc1040597,0x25840131,0xdcf80213,0x7bc80381}},	//   صوتي, _ئۆرپ_, dluğ, ypeu, 
   {{0x4fc400ea,0x00000000,0x00000000,0x00000000}},	//   осја, --, --, --, 
   {{0x20c01682,0x20e4001e,0x6d440621,0xc10400ec}},	//   ṱi_, ối_, ökan, _گوري, 
   {{0xbea4010b,0xed4c0014,0xfce400db,0x5758011a}},	//   щакк, کھل_, бойо, שבוע_, 
   {{0x387c0276,0x7bc8017a,0xdb0000a2,0xc10416a2}},	//   ştri_, tpeu, _kinç, _دوري, 
   {{0x7bc800d5,0x00000000,0x00000000,0x00000000}},	//   upeu, --, --, --, 
   {{0xd01000aa,0xdb00005a,0x7bc8a621,0xdcf806be}},	//   _ډلې_, _minç, rpeu, bluğ, 
   {{0x3991155c,0xdb01155d,0x7bc80b4f,0xf98401c0}},	//   lási_, _linç, speu, йгоо, 
   {{0x7bc9155e,0xe8f5155f,0xb9540114,0x6a4803b9}},	//   ppeu, блю_, стоћ, dəfd, 
   {{0xe8180abd,0x3b080f1a,0x79a40022,0x00000000}},	//   _पैदा_, _бело_, ирҭе, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa6e026b8,0x75d4007b,0x6368012d,0x3dd40154}},	//   íðar, إيرا, eżno, সংকল, 
   {{0x39911560,0xdec40023,0x660001d5,0x00000000}},	//   kási_, _ጽዋእ_, япса, --, 
   {{0x64a11561,0xdcf81ae4,0x2b8c0165,0xdb0001bf}},	// [19b20] зата, zluğ, kʷc̓_, _vinæ, 
   {{0x399001ed,0xdb011562,0xfa040327,0x00000000}},	//   dási_, _dinç, _མྱོན_, --, 
   {{0xdcf80213,0xf1f81291,0x6a4806be,0x00000000}},	//   xluğ, طعات_, cəfd, --, 
   {{0xe2942b9c,0x9f9c020c,0x21a00395,0x399002d2}},	//   щах_, léèl_, пихм, fási_, 
   {{0xdcf808ad,0xdb180798,0xdb0036d9,0x7c2c56ce}},	//   jluđ, rquê, _kinä, _šarn, 
   {{0xe81800c5,0xdcf80205,0x00000000,0x00000000}},	//   _पईसा_, tluğ, --, --, 
   {{0x62611563,0xdb0002f6,0x764c0042,0x80c804af}},	//   _евра, _minä, nyby, _ह्वे, 
   {{0x2fd81060,0x6fb51564,0xdcf847af,0x6448260b}},	//   _مورد_, _همرا, rluğ, ägig, 
   {{0xdcf81b0d,0xe0407df6,0xee3801ec,0x80c000eb}},	//   sluğ, _енти, _әне_, শৃঙ্, 
   {{0xdb0029ef,0x2054008f,0xdb18068c,0x1b140124}},	//   _ninä, _הימל_, nquè, бжьы_, 
   {{0x764c00a2,0xdcf803b9,0x00000000,0x00000000}},	//   jyby, qluğ, --, --, 
   {{0x61e00118,0x764c0142,0x57a4035b,0x00000000}},	//   ánli, dyby, ҧшра, --, 
   {{0xdcac07a7,0x28681173,0xdb00014a,0x069006ba}},	//   _كىم_, урно_, _binä, ﺘﯩﻨﯩ, 
   {{0xdb011565,0x99d00efc,0x660001f4,0x06d800eb}},	//   _cinä, _کتوا, _änkk, _তাহি, 
   {{0xdb00014a,0xdb080793,0x399000dd,0xcfbc0131}},	//   _dinä, _dugä, zási_, ﻧﺪﺍﻗ, 
   {{0x6a4803be,0xdb011566,0xd5b850af,0x4cac0011}},	//   rəfd, _pinç, сср_, _ট্যু, 
   {{0xe7843075,0xdb000784,0x82d91567,0xfa040327}},	// [19b30] _гуно, _qinç, идас_, _མཱོན_, 
   {{0xdb011568,0x764c00a2,0x00000000,0x00000000}},	//   _vinç, byby, --, --, 
   {{0x82140597,0xdb0000a2,0x24740092,0x00000000}},	//   تواص, _winç, _በመሬት_, --, 
   {{0x3990066d,0x6d4402f6,0xdb080730,0xdb00008e}},	//   tási_, ökal, _zugä, _tinç, 
   {{0x5ec000d1,0x6adc00eb,0x00000000,0x00000000}},	//   пилғ, _মানো, --, --, 
   {{0x7c2c07f5,0x26c001e4,0x39902bb4,0x35dc000d}},	//   _šaro, ncjo_, rási_, _फौड़, 
   {{0xe818257b,0x59d439a1,0x00000000,0x00000000}},	//   _पैसा_, _भौंर, --, --, 
   {{0x44291569,0xd65806a9,0xae1c012c,0x00000000}},	//   ova_, מיות_, भिजन_, --, 
   {{0x4429156a,0x60d80c6a,0x7c8802d3,0x764c0034}},	//   nva_, _ieum, _ምድላው_, zyby, 
   {{0x4429156b,0x201c7093,0x60d9156c,0x3d2812e9}},	//   iva_, _isui_, _heum, اتژی_, 
   {{0xdb19156d,0x60d80a2e,0x4429156e,0x61f5156f}},	//   nqué, _keum, hva_, nuxl, 
   {{0x60d80de2,0xdb0002f6,0xbd800023,0x00000000}},	//   _jeum, _sinä, _ይህቦም_, --, 
   {{0x44291570,0x60d91571,0x764c0368,0x201c0129}},	//   jva_, _meum, wyby, _jsui_, 
   {{0x7c291572,0x60d91573,0x2efc0204,0x592c025c}},	//   mver, _leum, _xctf_, _སོམས_, 
   {{0x44291574,0x80d800ab,0xdb000267,0x7c900092}},	//   eva_, _ढ़ूं, _vinä, ጀንሲው_, 
   {{0x44283167,0x201c005b,0x65ac0248,0x00000000}},	//   fva_, _osui_, _ròhì, --, 
   {{0x06d803f4,0x44291575,0x7d08009a,0x61f402d0}},	// [19b40] _তারি, gva_, ifes, euxl, 
   {{0x7c291576,0x1b1400bd,0xb2940640,0x7d080036}},	//   iver, তাকে_, ојећ, hfes, 
   {{0x7c291577,0x44291578,0x8afc068f,0x60d801ab}},	//   hver, ava_, mięt, _beum, 
   {{0x44281cbd,0x7c291579,0x60d80e89,0x7aec03f9}},	//   bva_, kver, _ceum, _ɓata, 
   {{0xb4d42cf5,0x7c29157a,0x7d08f27a,0x60d833e7}},	//   हरी_, jver, dfes, _deum, 
   {{0x7d09157b,0x8afc068f,0xc0a8007b,0x2898010f}},	//   efes, nięt, حامل_, בינא, 
   {{0x7d09157c,0x7c29157d,0x201c02ea,0x60d80013}},	//   ffes, ever, _esui_, _feum, 
   {{0x7c29157e,0x7d08a873,0x201c003e,0x60d9157f}},	//   fver, gfes, _fsui_, _geum, 
   {{0x7c291580,0x31e401ec,0x80b002dd,0x7c2c03b2}},	//   gver, _ءﺗﻮﻝ_, _كەمش, _áarl, 
   {{0xb4d40dc5,0xeb48fb0a,0x2efc0204,0x2aa8188b}},	//   हरु_, рчик_, _uctf_, итно_, 
   {{0x44291581,0x7c291582,0x60d91583,0x6fd0015b}},	//   zva_, aver, _yeum, _সময়ে, 
   {{0x44291584,0xdb0801bf,0x9e70216b,0x286801f0}},	//   yva_, _rugå, _تهمت, ҳрҳо_, 
   {{0xac7400cf,0x7c28037e,0x44280051,0x00000000}},	//   _بااش, cver, xva_, --, 
   {{0xdb0000d4,0x88f40139,0x8afc0210,0xef0c0150}},	//   _pinå, _şöğе, gięt, емi_, 
   {{0xb4d42ce6,0x4428fa45,0xe81805f9,0x61f4011f}},	//   हरू_, wva_, _पैरा_, xuxl, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x44291585,0xdd0000b8,0xc3540798,0x00000000}},	// [19b50] uva_, _śrīt, пкај, --, 
   {{0x44291586,0x60d91587,0x8afc0034,0x98140ccb}},	//   rva_, _seum, cięt, _آبيا, 
   {{0x44291588,0x7c291589,0x8ed8015b,0x60d80810}},	//   sva_, zver, _সাংগ, _peum, 
   {{0xdb186320,0x7c29158a,0xdb0801e6,0x399002f0}},	//   rqué, yver, _utgö, básu_, 
   {{0xc0e4044e,0x7c28508f,0xdb184afb,0x8fc5158b}},	//   _ማዕረ_, xver, squé, وزون, 
   {{0x7c28cd33,0x399000dd,0x60d80099,0xb7ec0037}},	//   vver, lást_, _weum, _जिसम_, 
   {{0x1cb0915c,0x7c29158c,0x8e7c01e4,0x69c80327}},	//   _དུང_, wver, _leĝf, _ntfe, 
   {{0x7d080140,0x5c7001e0,0x61e00f47,0x00000000}},	//   ufes, мһет, ánlu, --, 
   {{0x7c2820ef,0x201c16b8,0x69c9158d,0x8e7c01e4}},	//   uver, _usui_, _atfe, _neĝf, 
   {{0xbdc002dd,0x00000000,0x00000000,0x00000000}},	//   _كەتۋ, --, --, --, 
   {{0x7e99158e,0x29080175,0x399001d3,0x8b642309}},	//   _انار_, ffca_, kást_, بايم, 
   {{0x7c29158f,0xe9cc18ce,0xe8f51590,0x17c8013e}},	//   pver, _үк_, плю_, оҳии_, 
   {{0xdb011591,0x63b81709,0x399001ed,0xba740066}},	//   _minú, _éunh, dást_, تاکت, 
   {{0x6adc03d4,0x00000000,0x00000000,0x00000000}},	//   _মাথো, --, --, --, 
   {{0x47d800fe,0x6da801ef,0x00000000,0x00000000}},	//   ভংগী, _vřav, --, --, 
   {{0xf9900502,0xb4d423ef,0x399000e5,0x385800d4}},	//   _ثبت_, हरे_, gást_, _грою_, 
   {{0xb464f5e8,0xd05403f9,0x61e4022e,0x8afd1592}},	// [19b60] чкал, ɗaɗi, _avjl, mięr, 
   {{0xdb080077,0xf7bc1c5c,0x7ae11593,0xb6a400d8}},	//   _augú, ﻣﻪﻟﺪ, nalt, _нипл, 
   {{0x7ae11594,0xc7a8bd5e,0x00000000,0x00000000}},	//   ialt, _بديل_, --, --, 
   {{0x7ae11595,0xa03c0b82,0x00000000,0x00000000}},	//   halt, ፓጋንዳ, --, --, 
   {{0x7ae11596,0x5ed00154,0x399006ea,0x6d5c0200}},	//   kalt, _সাজে, láss_, ëpam, 
   {{0x7ae11597,0x00000000,0x00000000,0x00000000}},	//   jalt, --, --, --, 
   {{0x7ae11598,0x00000000,0x00000000,0x00000000}},	//   dalt, --, --, --, 
   {{0x7ae11599,0x5ce00075,0x2e0c06be,0x00000000}},	//   ealt, ىكىل, _cəfa_, --, 
   {{0x752400df,0x2eb401ec,0xa00400db,0x00000000}},	//   _makz, _есес, _ىسكۇ, --, 
   {{0x7ae1159a,0x399000dd,0x4a55159b,0x8e7c01e4}},	//   galt, zást_, дкос, _reĝf, 
   {{0xfe6c016c,0x9f2000d1,0x00000000,0x00000000}},	//   _рӯ_, _سۈيۈ, --, --, 
   {{0x7ae0b6a5,0xdb000393,0xacf402dd,0xa49801ab}},	//   aalt, _minù, _ءسات, _mbòr, 
   {{0x7ae1159c,0xdca1159d,0xf7881df2,0x399000e5}},	//   balt, _заци, ﺮﻟﯩﻚ_, vást_, 
   {{0x7ae1159e,0x4df005d7,0x63b800d8,0x4e20107c}},	//   calt, _घटाई_, _éuni, _मनाई_, 
   {{0x399000dd,0x69c9159f,0x00000000,0x00000000}},	//   tást_, _utfe, --, --, 
   {{0x5694014b,0x00000000,0x00000000,0x00000000}},	//   хаст, --, --, --, 
   {{0xa49915a0,0x18680640,0xd1f80023,0x399115a1}},	// [19b70] _abòr, _наћи_, _ወዲቑ_, rást_, 
   {{0x81b003d4,0x399000e5,0x00000000,0x00000000}},	//   ওৱা_, sást_, --, --, 
   {{0x2b0c39d7,0x63680327,0x15b00046,0x399000e5}},	//   त्यु_, nżni, _ﺳﯟﺭﻩ, pást_, 
   {{0xe8fc006a,0x7ae115a2,0xdb040118,0x5fa402dd}},	//   ngû_, zalt, ěléh, _ﺷﻮﭘﺘ, 
   {{0x8e7c010f,0x0fc40220,0x656c0332,0x4fe803de}},	//   _leĝd, ейін, _imch, змін_, 
   {{0x75240c09,0x2e0c03b9,0x1014009f,0x00000000}},	//   _zakz, _səfa_, عبند, --, 
   {{0x7ae115a3,0x3da800cf,0xab700092,0xdb000241}},	//   valt, окко_, _ችለዋል_, _tinú, 
   {{0x7ae115a4,0x973c044e,0xd1c915a5,0xdbe0003e}},	//   walt, _ኣገደስ, _хурд_, lééh, 
   {{0x7ae115a6,0x3af45d02,0xe3bcfd3d,0x9f9c0c6a}},	//   talt, мянс, _juñ_, _lééh_, 
   {{0xe3bc1bce,0x7ae00072,0x39e801c6,0x00000000}},	//   _muñ_, ualt, одоо_, --, 
   {{0x987001f1,0x656c009a,0xe3bc002e,0x9f9c002e}},	//   rúča_, _omch, _luñ_, _nééh_, 
   {{0x7ae115a7,0x38640432,0x4e9400ae,0x00000000}},	//   salt, _ýork_, _أشكر, --, 
   {{0x7ae115a8,0xeb8d15a9,0xb8d40490,0xdb18004e}},	//   palt, _аи_, _जण_, lquí, 
   {{0x656d15aa,0xb4d40490,0xb6a40063,0x5ba400db}},	//   _amch, हर्_, дигл, _эрез, 
   {{0xdb1915ab,0x00000000,0x00000000,0x00000000}},	//   nquí, --, --, --, 
   {{0xe5a02e3f,0xe3bc0de2,0xe614b7bb,0x32d402dd}},	//   виси, _buñ_, ьдс_, _ﺟﯘﮔﻪ, 
   {{0x9f5c31d3,0xdb0803cd,0xf348005b,0x6d441b99}},	// [19b80] _aquí_, _bugø, опал_, ökai, 
   {{0xe3bc00e8,0x656d15ac,0x25740003,0x64a012b9}},	//   _duñ_, _emch, dħlu_, тауа, 
   {{0x752515ad,0x6d5c0784,0x00000000,0x00000000}},	//   _takz, ëpak, --, --, 
   {{0x656c0998,0xa49826b7,0xe3bc002e,0xdb000158}},	//   _gmch, _icòn, _fuñ_, _einø, 
   {{0x0f140138,0x2574025c,0x23b000cf,0x00000000}},	//   емлю, għlu_, رمۅس, --, 
   {{0x9f5c0381,0x8e7c00df,0x2e0c0213,0x2f540cc9}},	//   _aquâ_, _leĝe, _dəfn_, ьтес, 
   {{0x656c0cfd,0x973c02d3,0x321c0109,0xe29515ae}},	//   _ymch, _ኣገዳስ, _èty_, _жар_, 
   {{0x8e7c01e4,0xe3bc00e8,0xdd9515af,0xad641a9b}},	//   _neĝe, _yuñ_, мшы_, باته, 
   {{0xe3bc1709,0xaf041bc0,0xab84050b,0x00000000}},	//   _xuñ_, _опал, дунк, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xad60001e,0xdd8d15b0,0x7af401d3,0x2a68002e}},	//   _đươn, _аш_, ózta, àbb_, 
   {{0x7afc0153,0x00000000,0x00000000,0x00000000}},	//   ėsta, --, --, --, 
   {{0xab281fbd,0xa36401e1,0x6c3001d3,0x28a40212}},	//   _мода_, _bọ̀r, _شہدا, ьшог, 
   {{0x85c80116,0x6da801ef,0x57a4009d,0x00000000}},	//   зтағ_, _třas, вшса, --, 
   {{0x569515b1,0xe7e82ce1,0xe3bc002e,0x25bc010f}},	//   варт, _झटका_, _suñ_, ĉulo_, 
   {{0x6b980142,0x59840139,0x6a4803e3,0x00000000}},	//   lltg, _үләб, ləfo, --, 
   {{0x1cb0025c,0x8afc0034,0xa36401e1,0x63a80ea0}},	// [19b90] _དུབ_, chęc, _fọ̀r, ïgno, 
   {{0xe5c40b01,0x06d8015b,0xc6f800db,0x00000000}},	//   _осмо, _তাকি, _энох_, --, 
   {{0xd77402de,0xdb0001bf,0x656c010e,0x00000000}},	//   _جايع, _vinø, _tmch, --, 
   {{0x656d15b2,0xe3bd15b3,0x2b0c5347,0x00000000}},	//   _umch, _tuñ_, त्तु_, --, 
   {{0x442d15b4,0x98a00db6,0x8e7c0115,0x3c1c0118}},	//   _ée_, _kaiā_, _neĝb, _भनेँ_, 
   {{0x3ea401b9,0xeaa401d3,0xcf680014,0xbea515b5}},	//   нилг, _مٹ_, وٝنو_, налк, 
   {{0xb4e4000d,0x00000000,0x00000000,0x00000000}},	//   _ओजमय_, --, --, --, 
   {{0x1cb02fb5,0xdb1826ce,0x56b80302,0x6da04316}},	//   _དུད_, rquí, ופון_, лища, 
   {{0x6ec82c2e,0x8e7c0115,0xdec8368e,0xfc302364}},	//   _स्कु, _reĝe, _дуел_, احب_, 
   {{0x38640115,0x8d740345,0x00000000,0x00000000}},	//   _ĥor_, _یانا, --, --, 
   {{0xa3640248,0x8f68007b,0xdc3000d7,0x0dc800f3}},	//   _rọ̀r, _تملك_, múče, _жучи_, 
   {{0xefd0044e,0xdc300030,0xa3640ca8,0x9f4c0332}},	//   ከለዉ_, lúče, _sọ̀r, irgí_, 
   {{0x66140227,0x973420d4,0x3154010f,0x6a4803b9}},	//   _apxk, نکدا, גירן_, ləfl, 
   {{0xf62401c0,0x6d440f23,0xa8000077,0x6a4803b9}},	//   ндго, ökav, áñas, cəfo, 
   {{0x6288002f,0x79580408,0x00000000,0x00000000}},	//   ßgol, _никĕ, --, --, 
   {{0x7bcc036e,0x00000000,0x00000000,0x00000000}},	//   _çaus, --, --, --, 
   {{0x98a00b23,0xc82401ec,0x34840022,0x00000000}},	// [19ba0] _faiā_, _азық, хгаг, --, 
   {{0x1cb0025c,0x762400d4,0x68b4011a,0x00000000}},	//   _དུན_, _змоз, _אלפא_, --, 
   {{0x96942a9f,0x00000000,0x00000000,0x00000000}},	//   _شیرش, --, --, --, 
   {{0x45b008b0,0x70840107,0x6a480213,0xf0a80121}},	//   _ﺳﺎﻳﻼ, нгез, dəfl, пкел_, 
   {{0x628401e3,0x00000000,0x00000000,0x00000000}},	//   _exjo, --, --, --, 
   {{0x63a4026c,0xe5e404fb,0x2d7c031c,0x00000000}},	//   _ghjn, _تزیی, rċem_, --, 
   {{0x638006bb,0xdb0000c6,0x5f4008c9,0x25e002ab}},	//   _сгра, _ghné, انىل, टीपी_, 
   {{0xc0c0070e,0x4c9428e8,0x6600007c,0xec6801a9}},	//   _кәши, кийс, _ånke, зрок_, 
   {{0xf4d40150,0x6e8800f2,0xef840064,0x00000000}},	//   _ﺘﺘﺤﻜ, _کناف_, _злап, --, 
   {{0xdbd80248,0xdc3000d0,0x00000000,0x00000000}},	//   _dààt, cúče, --, --, 
   {{0x4d2400d1,0x6a4806be,0x00000000,0x00000000}},	//   _аялғ, cəfl, --, --, 
   {{0x93f00073,0x53740092,0x3ea075ee,0x00000000}},	//   _चिंच_, _ኦህዴድ_, ühte_, --, 
   {{0xdd8c5c8c,0x6b98074d,0x2bb00dad,0x5884dfe6}},	//   _اون_, pltg, ीददा, гыра, 
   {{0x48ec038e,0x99a0005f,0x7c64179e,0x0595050d}},	//   _आएको_, āršu_, _جامل, چارگ, 
   {{0x249c009b,0xdb000316,0xbd240050,0x2720009e}},	//   _šum_, _jiný, _سى۪ٹ, মালো_, 
   {{0xe3bc0309,0x290c0428,0x1a980375,0x63a40051}},	//   _asña_, _ùga_, _מיוע, _shjn, 
   {{0x1ae00154,0x4394009d,0xb7ec000d,0x44b401a9}},	// [19bb0] _খাতে_, ваас, _जिएम_, тбас, 
   {{0xe7a40ef6,0xdef40092,0x4734011c,0x8654014b}},	//   _سۇزى_, ፉትን_, _рнос, _акох, 
   {{0x81c80f22,0x85b400d1,0x7c2c0174,0xeb1c000d}},	//   লীন_, _җәңч, _áarv, _भसैत_, 
   {{0xca900092,0x36180101,0x00000000,0x00000000}},	//   _ማንንም_, _کریگ_, --, --, 
   {{0x249c03f2,0x00000000,0x00000000,0x00000000}},	//   _áum_, --, --, --, 
   {{0xdb0000ee,0xcee802de,0x0eac02a0,0x1ee4179e}},	//   _biný, ىرىن_, टइंड, روبی_, 
   {{0x02dc01ad,0x00000000,0x00000000,0x00000000}},	//   यरीन, --, --, --, 
   {{0x6a4800ac,0x2b0c4668,0xbea40116,0x20d40472}},	//   rəfl, त्सु_, наһк, _سترج, 
   {{0x518515b6,0x3b8421f9,0xd108036b,0x00000000}},	//   _сура, клиг, _سقله_, --, 
   {{0x6b54019f,0xf4100375,0x799515b7,0xdcf800d7}},	//   _yâgi, ספי_, _skyw, mnuč, 
   {{0x7a6800c7,0x6ec828a2,0xdb08032e,0xe9d40166}},	//   финг_, _स्टु, _tugþ, ккэ_, 
   {{0xdb000112,0x6d4437e9,0x00000000,0x00000000}},	//   _hinü, ökat, --, --, 
   {{0xf1b013e2,0xda9001c0,0x64480254,0x00000000}},	//   יסט_, _өгдө, ägil, --, 
   {{0xdeb80023,0xb6f800db,0x00000000,0x00000000}},	//   _ኰንና_, بىسا_, --, --, 
   {{0x66e08035,0xdb0115b8,0xa6e000d4,0x06b40154}},	//   роса, _minü, ржсл, _জ্বি, 
   {{0xdb180054,0x3328031c,0x1db000dc,0xf6240107}},	//   mpuñ, _sabx_, ुदित, ндҳо, 
   {{0xf77001d9,0x332915b9,0x7d0c00e4,0xc4c41dd8}},	// [19bc0] _ناد_, _pabx_, _ñasu, اتفو, 
   {{0xf7700050,0x9cfc02f5,0xe3602119,0x8e7c010f}},	//   _خاب_, ্যয়ন_, акуи, _leĝa, 
   {{0x1db000dc,0xa758011a,0x00000000,0x00000000}},	//   ुदात, _חדיר, --, --, 
   {{0xdb0000d2,0x3f8401fa,0x8e7c00df,0xf3e401d5}},	//   _kinó, _ajlu_, _neĝa, _ижмо, 
   {{0xdb0915ba,0x6b54019f,0xdb0001b8,0xaa1c00bc}},	//   _bugü, _wâgi, _binü, _बन्छ_, 
   {{0xdb000139,0xdef115bb,0x25e4000d,0xde900055}},	//   _cinü, апшы, _छौडी_, _ṣiṇa, 
   {{0x92b000cc,0x00000000,0x00000000,0x00000000}},	//   _ট্ৰ_, --, --, --, 
   {{0xdb00002f,0x2fc401a9,0x1d040114,0x00000000}},	//   _einü, pqog_, већи_, --, 
   {{0x316515bc,0x88e003d4,0x6e2c00c0,0x00000000}},	//   mhoz_, _ভালক, _žibė, --, 
   {{0x9f5c16b8,0x31647b35,0x49d80212,0x25e003ce}},	//   _aquæ_, lhoz_, ндою_, टीडी_, 
   {{0x7bdc07a8,0x7c2c05be,0x60e48021,0x6d44340f}},	//   âsur, _šart, _örmä, ökas, 
   {{0x316515bd,0x4ba40046,0xdb000798,0x27e801f5}},	//   nhoz_, _өлең, _binó, tscn_, 
   {{0xdd10b809,0x0bf4188c,0xdbd80241,0xf4d40150}},	//   _خونخ, _сплю, _tàát, _ﺘﺘﺸﻜ, 
   {{0x31640399,0xdca00640,0x644800c5,0x497400d1}},	//   hhoz_, _тачи, ägim, _әлис, 
   {{0x316400dd,0x77f001f9,0x00000000,0x00000000}},	//   khoz_, _अटॅक_, --, --, 
   {{0xd944026a,0x2bb01d15,0x2b0c00bc,0x00000000}},	//   _већи, ीदवा, त्रु_, --, 
   {{0xdb00011f,0x88580353,0x96d4072a,0x7c2c03b2}},	// [19bd0] _ginó, _чипс_, _ब्वॉ, _áart, 
   {{0x7fd40220,0xa6200014,0x00000000,0x00000000}},	//   ңілі, _پہرى, --, --, 
   {{0x5ab40156,0x9c100241,0xa19801ec,0xa6e003f2}},	//   _ནུབམ, _nọnw, _ﺘﻌﺭﻑ_, íður, 
   {{0x2ca4036b,0xe4a43129,0xdb000342,0xe3b04739}},	//   _ozod_, _арго, _sinü, _چرس_, 
   {{0xdcf801fa,0x8e7c010f,0xe3b0e5e7,0x00000000}},	//   unuč, _reĝa, _نرس_, --, 
   {{0x2d8401af,0xdb00004e,0x3f9800ef,0x00000000}},	//   _ajoe_, _linò, _īsus_, --, 
   {{0x316515be,0xdb0d15bf,0xdb000037,0x00000000}},	//   bhoz_, _àdép, _vinü, --, 
   {{0x45b000d1,0x00000000,0x00000000,0x00000000}},	//   _ﺳﺎﻏﻼ, --, --, --, 
   {{0x8d2800fd,0x00000000,0x00000000,0x00000000}},	//   тның_, --, --, --, 
   {{0xdb0000a3,0x6d443f41,0xdb0801d3,0xbae00150}},	//   _ghnì, ökar, _rugó, _ﻋﻘﺒﺎ, 
   {{0xdb0115c0,0x2d840477,0x52e000e1,0x6f88004d}},	//   _sinó, _fjoe_, _पड़ोस, _ýkiế, 
   {{0xdb0115c1,0xdb180309,0x00000000,0x00000000}},	//   _pinó, rpuñ, --, --, 
   {{0xe81c05d7,0xdb180005,0x80cc00eb,0x00000000}},	//   मौला_, spuñ, ারপ্, --, 
   {{0x3dc40337,0xdd8c0517,0x316515c2,0xab24de00}},	//   _kulw_, _اوچ_, zhoz_, _боша_, 
   {{0x81c800fe,0x316400e5,0x00000000,0x00000000}},	//   লীত_, yhoz_, --, --, 
   {{0x96d40c66,0x02e0033f,0x7c2c0162,0xdb000332}},	//   _ब्रॉ, _फ़ॉन, _áars, _tinó, 
   {{0xe5a115c3,0x06b403d4,0xb38401c6,0xbcfc00e4}},	// [19be0] сити, জুলি, глал, yhũn, 
   {{0xdb0002f0,0x00000000,0x00000000,0x00000000}},	//   _ohní, --, --, --, 
   {{0xf7702832,0x316401d3,0x80cc0154,0x00000000}},	//   _ناگ_, thoz_, ারন্, --, 
   {{0x248800b5,0x395115c4,0x00000000,0x00000000}},	//   _fxcm_, _joys_, --, --, 
   {{0xdfcc00c6,0x3fc80d73,0x316401d3,0xe7b004f2}},	//   كين_, نگلی_, rhoz_, _خمید, 
   {{0xb8e41f21,0x316400dd,0x96a80316,0x8f34f6a1}},	//   _ཏུ_, shoz_, _गराउ, рекц, 
   {{0xe36011f7,0x316401d3,0x4904033f,0x6ec803ce}},	//   _укри, phoz_, _वालो_, सुगु, 
   {{0xf1a825da,0xe2940354,0x7c2c0135,0x25640037}},	//   _سازه_, _сас_, _ġarr, _võlg_, 
   {{0x216515c5,0xa0a0010a,0xfbcc00ec,0xf0a801af}},	//   _сити_, _гатд, وڪو_, _чкал_, 
   {{0x96d43a19,0xdb001e7b,0x40840032,0x88e00154}},	//   _ब्लॉ, _sinò, _әҙәм_, _ভাইক, 
   {{0xdb000597,0x3950de48,0x6d5c0240,0xdb2001e7}},	//   _ghní, _boys_, ëpas, árái, 
   {{0x395000ca,0x2d840117,0x8e7c00df,0x25640254}},	//   _coys_, _ujoe_, _heĝo, _kõle_, 
   {{0x9c54034c,0x2564000d,0x1ae000fe,0x00000000}},	//   _مجوز_, _jõle_, _মাৰা, --, 
   {{0x28e038d2,0x257c0958,0x00000000,0x00000000}},	//   परहि, kälä_, --, --, 
   {{0x48c4008e,0x7c2c03b2,0x00000000,0x00000000}},	//   _вәга, _áarr, --, --, 
   {{0x8e7c008f,0x39500009,0x45b000d1,0xdb0808a5}},	//   _leĝo, _goys_, _ﺳﺎﻗﻼ, _hugð, 
   {{0x80cc015b,0x6a4803e3,0x00000000,0x00000000}},	// [19bf0] ারম্, dəfi, --, --, 
   {{0x8e7c00df,0x28e01cba,0x257c0166,0x00000000}},	//   _neĝo, परवि, fälä_, --, 
   {{0x938915c6,0x77b80375,0x25640037,0xe030009d}},	//   уста_, _שמתח, _põld_, өмжө, 
   {{0xa49801ab,0xc0341f5a,0xda78010f,0x00000000}},	//   _lcòi, инеј, ענאר, --, 
   {{0xdb0001e7,0x00000000,0x00000000,0x00000000}},	//   _shní, --, --, --, 
   {{0x200c05d5,0x3ce80010,0x4438123b,0x80d4033f}},	//   rtgi_, _žav_, _irs_, _ड्रइ, 
   {{0x1ae003d4,0xbea400c2,0x200c05d5,0x44382238}},	//   _খালে_, шакк, stgi_, _hrs_, 
   {{0x52840597,0x443915c7,0x491402a0,0xd1b857d4}},	//   _الفك, _krs_, _फॉलो_, _ماقا_, 
   {{0x69cd15c8,0xdb0802d2,0xed4c00e5,0x00000000}},	//   íben, _bugð, بھل_, --, 
   {{0xd7a41533,0xca78022e,0x443911e6,0x6d5c0200}},	//   _खींच, _davо, _mrs_, ëpar, 
   {{0x443915c9,0xd01000aa,0xed4c0cbe,0x09e0031c}},	//   _lrs_, _ولې_, سپی_, _སྦྱ_, 
   {{0x395001d9,0x399000e5,0x0dc80117,0x00000000}},	//   _qoys_, lász_, _суфи_, --, 
   {{0x25e003f3,0x443801f5,0xbb442d3c,0x2e0c06be}},	//   टीसी_, _nrs_, _велк, _rəfi_, 
   {{0x66e007d6,0x2e0c06be,0xcb0850d8,0xddc000e5}},	//   жора, _səfi_, _ميهن_, lynő, 
   {{0x65ac06d6,0x8e7c01e4,0x0b9416ac,0xdb18002f}},	//   _ṱhap, _neĝl, _اجند, rquä, 
   {{0xaa4000c2,0x399000e5,0x2bf800fe,0x00000000}},	//   _феъл, hász_, ্বৰে_, --, 
  
   {{0x33b4007b,0x00000000,0x00000000,0x00000000}},	// [19c00] لمرأ, --, --, --, 
   {{0x443915ca,0x2bb4012d,0x00000000,0x00000000}},	//   _drs_, _płci_, --, --, 
   {{0x443915cb,0xb22515cc,0x36680d08,0x8e7c008f}},	//   _ers_, рмел, _рано_, _reĝo, 
   {{0x443915cd,0xe294c88f,0x8e7c010f,0x2564000d}},	//   _frs_, шах_, _seĝo, _põle_, 
   {{0x443915ce,0x6a480cc1,0x257c00fd,0x79840472}},	//   _grs_, rəfi, sälä_, inkw, 
   {{0x27fc000a,0x25e00c2e,0x1fa4036b,0x9f8001c0}},	//   šung_, टीवी_, акчи_, огчд, 
   {{0x224515cf,0x7c2c36dd,0xed88877c,0x7c38015d}},	//   änkt_, _šarp, ксик_, _arwr, 
   {{0x4438123b,0x00000000,0x00000000,0x00000000}},	//   _yrs_, --, --, --, 
   {{0x8fd0052f,0x1e800cef,0xc10001c6,0x9ee400cf}},	//   _эҙлә, йләм, _хүчл, ازۇۇ, 
   {{0x7c3802fa,0xdb0001c3,0x79840472,0x69c810eb}},	//   _drwr, _chnà, enkw, _संदी, 
   {{0xfaec00aa,0x3ea80b45,0x14b001f9,0x00000000}},	//   رګو_, ƙata_, _झणझण, --, 
   {{0x1ccc025c,0x3b0400c7,0xec78030d,0x00000000}},	//   _ྱུར_, аҵәо_, _ипе_, --, 
   {{0x6d4115d0,0xdca044e4,0xb7d401ed,0x0bd400db}},	//   _inoa, _даци, یڈیا_, _ايتح, 
   {{0xdb0008c2,0x00000000,0x00000000,0x00000000}},	//   _ghnà, --, --, --, 
   {{0x6d40002d,0x45d4a2bd,0x7ae4000d,0x24e40733}},	//   _knoa, собс, _õhta, ицаг, 
   {{0x99d085d4,0x8e7c00df,0x69d915d1,0xe4d4158b}},	//   _بتوا, _neĝm, mpte, شترب, 
   {{0x69d915d2,0x2918025c,0x399000e5,0x25e4000d}},	// [19c10] lpte, _ibqa_, yász_, _छौरी_, 
   {{0x443915d3,0xf7601772,0x52d80108,0x00000000}},	//   _vrs_, _ፕሮፖጋ, имую_, --, 
   {{0x6d4115d4,0x25e00073,0x00000000,0x00000000}},	//   _onoa, टीशी_, --, --, 
   {{0x6d4115d5,0x69d915d6,0x91ac01fb,0x7afc0024}},	//   _nnoa, ipte, _đọc_, ėsti, 
   {{0x443915d7,0x948412af,0x69d80175,0x0dcc0092}},	//   _urs_, _дырд, hpte, _ባለፈ_, 
   {{0x6d4115d8,0x22240014,0xf40400fe,0x224515d9}},	//   _anoa, _پٲری_, ৰিখৰ_, änks_, 
   {{0x171c010f,0x399000e5,0x00000000,0x00000000}},	//   דווע, rász_, --, --, 
   {{0x442915da,0x7c9002d3,0xdb0001c3,0x399002f0}},	//   owa_, _ይትረፍ_, _shnà, básy_, 
   {{0xdd2c012c,0x69d80b4f,0xdb0003db,0x6adc00cc}},	//   _těžk, epte, _minö, _মাজো, 
   {{0x6d40000f,0x201c01c4,0x88e0009e,0x69d80175}},	//   _enoa, _ipui_, _ভাগক, fpte, 
   {{0x442915db,0x81c8015b,0xdb0000ae,0x80cc03d4}},	//   hwa_, লীর_, _chná, াৰণ্, 
   {{0x442915dc,0xce6809ed,0xdb0001b8,0x6d402ee4}},	//   kwa_, _труд_, _ninö, _gnoa, 
   {{0x7d0915dd,0x798401f5,0x69d8cdc8,0x00000000}},	//   mges, rnkw, apte, --, 
   {{0x59cc0714,0x442881b3,0x7c2915de,0x7d0915df}},	//   _संपर, dwa_, mwer, lges, 
   {{0x442915e0,0x7c2915e1,0xdb0115e2,0x6d40002d}},	//   ewa_, lwer, _binö, _ynoa, 
   {{0x442915e3,0x16a808e9,0x9c10063f,0x1ccc025c}},	//   fwa_, _गरीब, _nọkw, _ྱུས_, 
   {{0x7c2915e4,0xf3c8004b,0x7d0915e5,0xb86513e2}},	// [19c20] nwer, ابره_, iges, _داغو, 
   {{0xdb000086,0x7d081a80,0x7c280af9,0x2d7c0135}},	//   _einö, hges, iwer, nċer_, 
   {{0xdb00006a,0x7c2915e6,0x201c204d,0x7d08325d}},	//   _finö, hwer, _apui_, kges, 
   {{0x4428a760,0x7c2915e7,0x7d080196,0x28100345}},	//   bwa_, kwer, jges, _بویس, 
   {{0x44282dab,0x7d0915e8,0x7c280cf9,0x3f58067c}},	//   cwa_, dges, jwer, _nèus_, 
   {{0x69d915e9,0x7d0915ea,0xdbfc0f22,0x6d4115eb}},	//   ypte, eges, ্বাস_, _snoa, 
   {{0x7d082426,0x7c2915ec,0x201c007f,0x644800c5}},	//   fges, ewer, _epui_, ägiv, 
   {{0x7c2915ed,0x7d0915ee,0xf3f4031c,0x69cc0789}},	//   fwer, gges, _བྷོད_, íbem, 
   {{0x7c2915ef,0xdb0000ae,0x6a4806be,0xf0640da9}},	//   gwer, _shná, həft, _укап, 
   {{0x7d0831c1,0x1f603e0c,0xe45400df,0x00000000}},	//   ages, _екум, צייט_, --, 
   {{0x7c281418,0x6e9400c6,0x7d0813ee,0x6e3803ac}},	//   awer, _الضا, bges, _urtb, 
   {{0x7c2915f0,0x69d915f1,0x2eed15f2,0x3f58068c}},	//   bwer, rpte, laff_, _fèus_, 
   {{0x44281cdf,0x7c2801a4,0x69d800b5,0x23ac00a2}},	//   xwa_, cwer, spte, lüje_, 
   {{0x44285f74,0x69d915f3,0xd7f81de1,0x7c2c006a}},	//   vwa_, ppte, щую_, _âara, 
   {{0x4428faa0,0x3f580ba1,0x6b9801b9,0xd46c0092}},	//   wwa_, _zèus_, motg, _ለመፈፀ, 
   {{0x46d81161,0x95c80588,0x2eed15f4,0x6b9802ec}},	//   _ब्रह, сура_, haff_, lotg, 
   {{0x442915f5,0x69c915f6,0x68ed15f7,0x290800f1}},	// [19c30] uwa_, _hufe, macd, mgca_, 
   {{0x9c1001f2,0x7d0915f8,0x68ec058a,0x6b9915f9}},	//   _sọkw, zges, lacd, notg, 
   {{0x7d0915fa,0x201c084c,0x2eec003e,0xd6d8151e}},	//   yges, _spui_, daff_, _уты_, 
   {{0xd1b915fb,0x69c915fc,0x7c2915fd,0x290915fe}},	//   مانا_, _mufe, ywer, ngca_, 
   {{0x657c209c,0x7d0804cc,0x7c2801a4,0x6b98022e}},	//   miqh, vges, xwer, kotg, 
   {{0x657cbe09,0xf07804a9,0x69c8030a,0x68ec058a}},	//   liqh, шичә_, _oufe, hacd, 
   {{0x7d0915ff,0x7c291600,0x9c1001f2,0x69c91601}},	//   tges, wwer, _tọkw, _nufe, 
   {{0x7c291602,0xda2404a9,0x657c0cfe,0xee2c0451}},	//   twer, ەيدۇ_, niqh, ئٽي_, 
   {{0x7c291603,0x69c91604,0x26ec2158,0xe7e80316}},	//   uwer, _aufe, _জানো_, जीमा_, 
   {{0x7c291605,0x7d091606,0x67240789,0x660402d1}},	//   rwer, sges, jejj, kujk, 
   {{0x7c291607,0x69c91608,0x7d091609,0x8e7c01e4}},	//   swer, _cufe, pges, _neĝh, 
   {{0x7c29160a,0xe8f4cadc,0x660400f3,0x68ec0014}},	//   pwer, олю_, dujk, gacd, 
   {{0x6b9829ef,0x8b64107f,0x06c4015b,0x657c0472}},	//   botg, زایم, ্রনি, diqh, 
   {{0x7bd800ca,0x69c9160b,0x6b9805d5,0x67240337}},	//   _itwu, _fufe, cotg, gejj, 
   {{0x69c9160c,0xdb0005da,0x5a20025c,0x68ec0014}},	//   _gufe, _dinô, _འགྲེ_, bacd, 
   {{0x657c0357,0xe9701bb1,0xf9905957,0x2d7c025c}},	//   giqh, _يهود, _تبت_, nċep_, 
   {{0x64a1160d,0x2eec0204,0x6725160e,0xf2d9160f}},	// [19c40] дата, yaff_, bejj, لباش_, 
   {{0x6da802a8,0x25640037,0x00000000,0x00000000}},	//   _aƙal, _võla_, --, --, 
   {{0x25bc002e,0x6a4806be,0x00000000,0x00000000}},	//   ňula_, ləfr, --, --, 
   {{0xd1c00023,0x34940124,0x00000000,0x00000000}},	//   _ስለቲ_, _ҳаҭр, --, --, 
   {{0x6b980517,0x2eed1610,0x64491611,0x00000000}},	//   yotg, taff_, ägit, --, 
   {{0xa498067c,0x8e7c01e4,0x753400ee,0x00000000}},	//   _ecòs, _heĝi, ldyz, --, 
   {{0x2eed1612,0x7bd8565e,0x764c0369,0x6b991613}},	//   raff_, _atwu, nxby, votg, 
   {{0x69c91614,0x2eec0165,0x2fd81bf4,0x6724031c}},	//   _rufe, saff_, _نورد_, zejj, 
   {{0x69c91615,0xa064a76a,0xdca0026a,0xa1102ba5}},	//   _sufe, _дата_, маћи, _توقت, 
   {{0x657c0912,0x8e7c0115,0x660402d1,0x00000000}},	//   ziqh, _leĝi, yujk, --, 
   {{0xed344e90,0x657c1cdf,0x6b9802ec,0xf1c8227c}},	//   _мэдэ, yiqh, rotg, िदिन, 
   {{0x69c802b9,0xdb007e87,0x8e7c01e4,0x67251616}},	//   _vufe, _sinô, _neĝi, wejj, 
   {{0x657c0d04,0x67240003,0x69c91617,0x6b991618}},	//   viqh, tejj, _wufe, potg, 
   {{0x69c80618,0xf1c8f894,0xe66450da,0x6b9801d5}},	//   _tufe, िदान, отбо, qotg, 
   {{0x63b8011c,0x16343580,0x672495bd,0x00000000}},	//   _èuni, меря, rejj, --, 
   {{0xa504185e,0x59cc4f4b,0x03d4005b,0x490400bc}},	//   تىرە_, _संतर, зжаю, _वाटो_, 
   {{0xa4981497,0xd4980f64,0x66040113,0x67240003}},	// [19c50] _acòr, орф_, sujk, pejj, 
   {{0x28e002ab,0x657d1619,0xd7c80244,0x93b400d8}},	//   परकि, siqh, _گویه_, дбуц, 
   {{0x69cc01f1,0x00000000,0x00000000,0x00000000}},	//   íbeh, --, --, --, 
   {{0x61e40218,0xc0cc0023,0x64480254,0x00000000}},	//   _vwjl, _ብዘላ_, ägis, --, 
   {{0xa3b80753,0x80cc0154,0x00000000,0x00000000}},	//   _ناسر_, ারল্, --, --, 
   {{0xbf0401ad,0x15e80073,0x00000000,0x00000000}},	//   रलेन_, टीवर_, --, --, 
   {{0xe7e800e1,0x00000000,0x00000000,0x00000000}},	//   जीता_, --, --, --, 
   {{0x61402544,0xdcf80327,0x00000000,0x00000000}},	//   _تىرە, fluġ, --, --, 
   {{0xdcf807f5,0x00000000,0x00000000,0x00000000}},	//   hnuć, --, --, --, 
   {{0x59cc5345,0xdcf82630,0x3b080640,0xec740108}},	//   _संदर, knuć, љено_, япы_, 
   {{0x31ac0122,0x8d740451,0xdcf80153,0x00000000}},	//   lýza_, _ڪالا, liuč, --, 
   {{0xbd800023,0x59ac0a8a,0x00000000,0x00000000}},	//   _ክህቦም_, _टीशर, --, --, 
   {{0x8d75161a,0x8e7c00c8,0x7bd80526,0xa3a85c0b}},	//   _تالا, _reĝi, _utwu, खता_, 
   {{0x81e08961,0xc6140eac,0xcc880451,0x3ea4007c}},	//   _দিন_, াবনা_, _بنهه_, _kylt_, 
   {{0xdcf81225,0x3ea40204,0x1e20010c,0xeb300e56}},	//   gnuć, _jylt_, _ሰይጣና, _سىيد, 
   {{0x5fc80490,0x1ae00154,0x6a4806be,0x6e3c01e3}},	//   ादाल, _মায়া, cəfq, åpbi, 
   {{0xe3e42fb5,0x73c40150,0x48580153,0xe7e80210}},	// [19c60] _སྦྱང, سيام, _дрэў_, जीदा_, 
   {{0x37e0015b,0x2bcc07d0,0xf77002f2,0x00000000}},	//   _বিপর, _हंसा, _ساخ_, --, 
   {{0x31240e76,0xa7580375,0xc0cc02d3,0x35a4b971}},	//   здег, _הדיר, _ብዘሎ_, _наог, 
   {{0x69cc056a,0xa7f800a2,0x00000000,0x00000000}},	//   íbei, lyña, --, --, 
   {{0x34381867,0x234400d1,0x8f340902,0x00000000}},	//   _اسجد_, تلەپ_, делц, --, 
   {{0xb8dc031c,0x21a0013e,0x7174009f,0x00000000}},	//   _ཀཛ_, _ҷисм, _کهرا, --, 
   {{0x644000e2,0x00000000,0x00000000,0x00000000}},	//   ānie, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x61f80093,0xa111161b,0xdcf805be,0x00000000}},	//   _āuli, _سولت, znuć, --, 
   {{0x3ea5161c,0x9f800276,0x3164005a,0x06c40154}},	//   _fylt_, _згуд, lkoz_, ্রতি, 
   {{0x3ea40162,0xeb980116,0x65b00076,0x92c003d4}},	//   _gylt_, _һид_, lçhe, ীৰৰ_, 
   {{0x81c803d4,0x1ccc031c,0x81e003d4,0xeff40092}},	//   লীক_, _ྱུག_, _দিম_, ለገው_, 
   {{0x7c30035b,0x260c4688,0x47dc015b,0x65b0062c}},	//   _аҵых, तूनी_, _বিহী, nçhe, 
   {{0x2868013e,0x88d400b8,0x1cb8011a,0xa7f800a2}},	//   арҳо_, _nṛva, _המדע, gyña, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x26dc01e4,0xeff401f3,0xbdd001ec,0x00000000}},	//   ŝuo_, ወለድ_, _ﻓﺼﻴل_, --, 
   {{0x5efc0a28,0xdcf82375,0x00000000,0x00000000}},	// [19c70] रणम्_, snuć, --, --, 
   {{0x81e1161d,0x8afc012d,0xa2b807b7,0xa2c8035b}},	//   _দিব_, chęt, ौशल्, суаз_, 
   {{0xe18c010e,0xddc80e04,0xa28001d3,0x00000000}},	//   _aỳal_, _žiži, ریرو, --, 
   {{0x2ca40214,0x59cc06ff,0x92b4007b,0x00000000}},	//   _oyod_, _संसर, رحلا, --, 
   {{0x2ca40399,0x26140798,0x3ea426bc,0x00000000}},	//   _nyod_, lço_, _sylt_, --, 
   {{0x961800dd,0xbea403b7,0x1ccc025c,0x3ea40228}},	//   _بغیر_, малк, _ྱུང_, милг, 
   {{0x2615161e,0xa37800e4,0x929401c0,0x67340067}},	//   nço_, _atõg, _зарц, _maxj, 
   {{0x5f7400dd,0x8e7d161f,0xae000d79,0x00000000}},	//   _کارر, _neĝu, रंजन_, --, 
   {{0x3f1400f3,0x00000000,0x00000000,0x00000000}},	//   _одас, --, --, --, 
   {{0xa4980086,0x2ca402e2,0x00000000,0x00000000}},	//   _idòd, _dyod_, --, --, 
   {{0x25640254,0xcfd80154,0x5bfc0154,0x0df80023}},	//   _põll_, _সিএন, ্বেগ_, _ፊሊፖ_, 
   {{0x37e0015b,0x00000000,0x00000000,0x00000000}},	//   _বিবর, --, --, --, 
   {{0x2ca41c06,0x59ccde66,0xb8d405f9,0xeff4001f}},	//   _gyod_, _संवर, _झर_, ለፈው_, 
   {{0x31642c2b,0x8a600133,0x00000000,0x00000000}},	//   zkoz_, _ڕێپۆ, --, --, 
   {{0x3164123d,0xeff40092,0xe5a0084c,0x2564000d}},	//   ykoz_, ወለደ_, ӂити, _tõll_, 
   {{0x671c12eb,0x8af003b9,0x6920014b,0x00000000}},	//   म्बक_, _şәxs, _амъа, --, 
   {{0xe5a11620,0xa7f800e4,0xc40801d9,0x13440124}},	// [19c80] тити, pyña, ۪تہٕ_, ндаҭ, 
   {{0xe3b4a30d,0x00000000,0x00000000,0x00000000}},	//   дбу_, --, --, --, 
   {{0xa2b00b7c,0x99880064,0x00000000,0x00000000}},	//   _अरण्, _urnų_, --, --, 
   {{0x290c01e6,0x65b000ad,0xeff40092,0x00000000}},	//   _ögat_, tçhe, ወለዱ_, --, 
   {{0xdfcc082e,0x92c0015b,0x31648489,0x00000000}},	//   لين_, ীরে_, rkoz_, --, 
   {{0x88d400cd,0x65b00076,0x00000000,0x00000000}},	//   _hṛta, rçhe, --, --, 
   {{0x88d40a28,0x8e7c01e4,0x00000000,0x00000000}},	//   _kṛta, _neĝt, --, --, 
   {{0xdb0001e7,0x2ce80212,0x66140205,0x00000000}},	//   _ghnú, цько_, _çakş, --, 
   {{0x8e7d1621,0xae0000af,0x88d400dc,0x00000000}},	//   _reĝu, रूजन_, _mṛta, --, 
   {{0x6eb40aaa,0x81c8009e,0x8eb41df2,0x4a542b2e}},	//   _قصائ, লীও_, _كەشت, екос, 
   {{0xfe6c0107,0x25640254,0x4ad800ec,0x00000000}},	//   _сӯ_, _sõlm_, ياھھ_, --, 
   {{0x88d4002b,0x59ac23ef,0x00000000,0x00000000}},	//   _nṛta, _टीआर, --, --, 
   {{0xd838c69e,0x69c84466,0x76591622,0x3dcc02dd}},	//   мэр_, _संकी, ätyn, _ﻗﺎﯕﺘ, 
   {{0x0a94109a,0x00000000,0x00000000,0x00000000}},	//   _палю, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x261403b7,0x673400e8,0x48140798,0x00000000}},	//   rço_, _waxj, _змис, --, 
   {{0x4254e9f1,0x5ec40154,0xd5782440,0x261400d8}},	// [19c90] کنار, রুপে, _አእምሮ_, sço_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe7e802ab,0xcfd80154,0x00000000,0x00000000}},	//   जीरा_, _সিগন, --, --, 
   {{0x40940c50,0x37e000bd,0x25640254,0x00000000}},	//   ىلار, _বিতর, _mõlk_, --, 
   {{0x656d1623,0xe8fc000f,0xff242095,0x00000000}},	//   _ilch, lhûs_, емло, --, 
   {{0x9f5c2508,0x2efc0175,0x5344728c,0x88d400b8}},	//   _aquò_, _cdtf_, _ихса, _kṛsa, 
   {{0x69c8023e,0xb9000003,0xdb0001c3,0xe8fc045f}},	//   _संगी, _ཧྥ_, _ghnù, nhûs_, 
   {{0x7c3c01bf,0x00000000,0x00000000,0x00000000}},	//   æsro, --, --, --, 
   {{0x60d91624,0x7e98034c,0x63b8026c,0x7f940105}},	//   _ifum, _کنار_, _èuns, _заах, 
   {{0xe1300184,0xe8fc000f,0x7c780092,0xac9400ec}},	//   _янғы, khûs_, ርላማው_, رچنا_, 
   {{0x656d1625,0xd91016e0,0x00000000,0x00000000}},	//   _olch, لیغ_, --, --, 
   {{0xe8fc000f,0x6e38011a,0xdd000064,0xed4c2360}},	//   dhûs_, _מתעד, _įsėd, _ёо_, 
   {{0xeb8d1626,0x60d91627,0xec6c1685,0xf1b008a8}},	//   _би_, _mfum, _сп_, טסט_, 
   {{0xe9cc00b2,0x3f78008f,0xbcfc0022,0x88d400b8}},	//   _ڏٺو_, לאָס, ikũm, _sṛta, 
   {{0x69cc9936,0x60d91628,0x656c0419,0x88d4002b}},	//   íbet, _ofum, _blch, _pṛta, 
   {{0x60d80337,0xe5a0ca0e,0xe7a80003,0x00000000}},	//   _nfum, гиси, ħaġġ, --, 
   {{0x656c01ab,0x79851629,0xd44c001f,0x25780092}},	// [19ca0] _dlch, mikw, _አዘጋጅ, _አጥጋቢ_, 
   {{0x60d9162a,0x656d162b,0x7985162c,0x98a0025c}},	//   _afum, _elch, likw, _lbiċ_, 
   {{0x656c02c4,0x8e7c0115,0x0cac1fe7,0xf90403d4}},	//   _flch, _leĝr, _चर्म, ষ্ণৱ_, 
   {{0x7985162d,0xd1300345,0xdecc001f,0x682c001f}},	//   nikw, شمت_, _ብቸኛ_, ሳሰሉት, 
   {{0xa4980428,0xa065162e,0x60cc013a,0x00000000}},	//   _edòb, наца_, _šimá, --, 
   {{0x60d8004b,0x7985162f,0x80cc0154,0xa7f8010e}},	//   _efum, hikw, ারগ্, dyñl, 
   {{0xe294c184,0x60d81418,0x79851630,0x656c062c}},	//   _зар_, _ffum, kikw, _ylch, 
   {{0x79841e5a,0x6e6000f7,0x9ca400ec,0x00000000}},	//   jikw, _ۅچبۅ, ڙهيل_, --, 
   {{0x79851631,0x65b003f0,0x00000000,0x00000000}},	//   dikw, nçha, --, --, 
   {{0x5c711632,0x2d8801d3,0x00000000,0x00000000}},	//   ульт, őbe_, --, --, 
   {{0x75780a28,0x2a6801ed,0xdee015d1,0x79851633}},	//   ṣṭha, ább_, _сохи, fikw, 
   {{0x79851634,0x13d8009e,0xa2b004af,0x00000000}},	//   gikw, দীয়, _अरस्, --, 
   {{0x7d1c067c,0x24640241,0x5f1400cd,0x00000000}},	//   òsse, _mímú_, _नाम्_, --, 
   {{0x7984004c,0x69cc0005,0xe8fc000f,0x2564000d}},	//   aikw, íbes, thûs_, _tõlk_, 
   {{0x79851635,0x569407d6,0xe8fc002d,0xda6c6af7}},	//   bikw, гарт, uhûs_, _ся_, 
   {{0x7984c38c,0x55580801,0xe8fc000f,0x24640241}},	//   cikw, нася_, rhûs_, _nímú_, 
   {{0x6aa80cfd,0xe8fc0b21,0x00000000,0x00000000}},	// [19cb0] _hyff, shûs_, --, --, 
   {{0x60d91636,0x6aa80004,0xe8fc002d,0xeff00023}},	//   _sfum, _kyff, phûs_, _ሂብዎ_, 
   {{0x60d91637,0xe1f02ed7,0x00000000,0x00000000}},	//   _pfum, اسط_, --, --, 
   {{0x7ff48f74,0xcfd804c5,0x258401e1,0x656d1638}},	//   نستا, _সিজন, _dìlè_, _ulch, 
   {{0xeaa40583,0xd564c38a,0x6aa80142,0x00000000}},	//   _چٹ_, _стэп, _lyff, --, 
   {{0xefe80125,0x15e801ad,0x8cc407f7,0xe1f00244}},	//   መሪያ_, टीकर_, ाइनो, _مسر_, 
   {{0x79851639,0x60d81cea,0x1ccc031c,0x6aa8fd11}},	//   yikw, _tfum, _ྱུད_, _nyff, 
   {{0x60d9163a,0x7d742586,0x614000db,0x37e00154}},	//   _ufum, ضابط, _حىرە, _বিসর, 
   {{0x7985163b,0x69c8a064,0x7dd4025c,0x100400a7}},	//   vikw, _संजी, _iġsm, _бяхм, 
   {{0x200d163c,0x6aa80042,0x7984006f,0xe8fc000f}},	//   mugi_, _byff, wikw, skûl_, 
   {{0x200d163d,0x7985163e,0x6aa80cfd,0xf2d004ae}},	//   lugi_, tikw, _cyff, יעי_, 
   {{0x212d163f,0x6aa80368,0x7658005b,0x30d000fe}},	//   negh_, _dyff, ätym, াৰীস, 
   {{0x8d74a397,0x79851640,0xd91000dd,0x3154010f}},	//   _حالا, rikw, لیں_, דירן_, 
   {{0x6aa800a3,0x59cc00e1,0xfaa4035b,0x212c0978}},	//   _fyff, _सूअर, _иало, hegh_, 
   {{0x798406d6,0xb6a51641,0x6aa800a9,0x98a00421}},	//   pikw, тивл, _gyff, _paiē_, 
   {{0x16141533,0xb82801b9,0x212c047e,0x65b000ad}},	//   तंबर_, _жоиз_, jegh_, tçha, 
   {{0x8e7c0115,0x8cc42e05,0x212c014f,0x1ccc0327}},	// [19cc0] _leĝp, ाइयो, degh_, _ྱུན_, 
   {{0x31c8043e,0x200c007d,0x65b000ad,0x25840248}},	//   िद्ध, dugi_, rçha, _pìlè_, 
   {{0xf50403a6,0x7ae4007d,0xf1d06240,0x88d400dc}},	//   _изно, _õhtu, рөгө, _kṛpa, 
   {{0xb8144284,0x200d1642,0xafe40953,0x6140023a}},	//   _तमाम_, fugi_, водл, иеха, 
   {{0x69c80316,0x200d1643,0x69c02ce6,0x00000000}},	//   _संघी, gugi_, रगती, --, 
   {{0xa2e11644,0xa0640640,0x01e400fd,0x30d00154}},	//   _ворд, ђаја_, _әйтү, ারেস, 
   {{0x67207536,0xa2d412eb,0x00000000,0x00000000}},	//   _önje, _बलत्, --, --, 
   {{0x799400ca,0x200c0295,0x88d40882,0x6aa804cc}},	//   _njyw, bugi_, _nṛpa, _ryff, 
   {{0x49a43e25,0x5d50008e,0x9bf0a6d1,0xef180395}},	//   ғынғ, ркыт, азыч, _ома_, 
   {{0x09bc01bc,0xceb80116,0xac900150,0xcd600092}},	//   ोद्य, _пәй_, лақш, ላችኋለ, 
   {{0x8fd4134b,0x00000000,0x00000000,0x00000000}},	//   _рәҗә, --, --, --, 
   {{0xac84151e,0x00000000,0x00000000,0x00000000}},	//   _игел, --, --, --, 
   {{0xdb34030f,0xfa800022,0x00000000,0x00000000}},	//   رسیش_, иқәм, --, --, 
   {{0xe78400f0,0xa7f800a2,0x00000000,0x00000000}},	//   тумо, lyñk, --, --, 
   {{0x200d1645,0xba540051,0x00000000,0x00000000}},	//   zugi_, _vắcx, --, --, 
   {{0x81e000bd,0x69c83507,0x200c0083,0x5a9000d1}},	//   _দিল_, _सूची, yugi_, _әрәф, 
   {{0x7bcc021c,0x439401c0,0x44b40026,0xf8b40139}},	// [19cd0] _éaut, гаас, убас, _бөр_, 
   {{0x47345119,0xdef4001f,0x25640254,0xd6d80139}},	//   _снос, ጉትን_, _nõlv_, _итю_, 
   {{0x53343e18,0x439400fb,0xd1b800e5,0x779000e5}},	//   рехт, _ҡамс, چانا_, _ایّا, 
   {{0x200d1646,0xd1b91647,0xcfcc03d4,0x7e8403b9}},	//   tugi_, نانا_, ৰীমন, _ürpə, 
   {{0x2bcc10eb,0x212c0455,0x04c8009f,0x00000000}},	//   _हंगा, regh_, _سوسي_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x44391648,0x200d1649,0x212c047e,0x00000000}},	//   _hss_, sugi_, pegh_, --, 
   {{0x443839e2,0x200d164a,0x4394014b,0x00000000}},	//   _kss_, pugi_, _раҳс, --, 
   {{0x5184b598,0xbb18525b,0x44380882,0x3af5164b}},	//   _тура, ىزدا_, _jss_, лянс, 
   {{0x39e87bb3,0x4439164c,0x7658005b,0xec74005b}},	//   ндоо_, _mss_, ätyk, упь_, 
   {{0x4439164d,0x8d740131,0x00000000,0x00000000}},	//   _lss_, _ھاما, --, --, 
   {{0x4438b2e3,0x37e5164e,0x8d743695,0x3f8400d7}},	//   _oss_, ломг, _پاما, _hmlu_, 
   {{0xfc04415e,0xe8f42401,0x59cc206b,0x1b00013d}},	//   _спло, ыля_, _संकर, _күпн, 
   {{0xc794abc6,0xf7440063,0x00000000,0x00000000}},	//   арсы, ћево, --, --, 
   {{0x4439164f,0x7bc0097d,0x66e11650,0x66000816}},	//   _ass_, mmlu, соса, йпра, 
   {{0xa6c400cf,0x59ac0412,0x7bc00e20,0x00000000}},	//   улса_, _टीचर, lmlu, --, 
   {{0x44391651,0x9f4c008c,0x70b00037,0x00000000}},	// [19ce0] _css_, yrgð_, _जरेल, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x44391652,0x31082cc8,0x7bc001ab,0x00000000}},	//   _ess_, енеп_, imlu, --, 
   {{0x44391653,0xa49800db,0x2d88004e,0x70f412dd}},	//   _fss_, _idòn, _íbex_, اسائ, 
   {{0x44391654,0x2718009e,0x8f8474f0,0x2564000d}},	//   _gss_, _ফোটো_, ақал, _põlv_, 
   {{0x7d18015d,0x2c780ca8,0xe5e4028e,0xb2c40472}},	//   _acws, _làdé_, _جزیی, _مغزو, 
   {{0x232400a7,0x31dc0154,0x7bdc03f2,0x27fc003d}},	//   _щори_, _ডিকশ, ísun, ġuni_, 
   {{0x44380363,0xdd9400ee,0x71a400c2,0x229000c6}},	//   _yss_, лшы_, _сабз, _الفس, 
   {{0x25d800e1,0x3074086f,0x4c9433d2,0x7d1c0ba1}},	//   _खूनी_, _сувс, рипс, òssa, 
   {{0xa4980100,0x40940063,0xdcb4013d,0x00000000}},	//   _odòn, _трст, ыгыч_, --, 
   {{0xdd8d1655,0x28c41f13,0x7d180175,0xe6d40321}},	//   _کون_, रेनि, _fcws, átíð, 
   {{0x6e38035a,0xbd2800ae,0x00000000,0x00000000}},	//   _istb, _لأهل_, --, --, 
   {{0x3cd407d6,0x02b00118,0x00000000,0x00000000}},	//   _тўхт, _झर्न, --, --, 
   {{0x44391656,0xdce8005f,0x65b00076,0x5cb40064}},	//   _rss_, _ilgā, tçho, _сліў_, 
   {{0x5f1402c3,0x00000000,0x00000000,0x00000000}},	//   _नास्_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb0000c6,0x81e00154,0x23ac010e,0xa6c4030d}},	// [19cf0] _ghnó, _দিই_, lüji_, ăлса_, 
   {{0x443808ad,0x6e38343a,0x4ac801ad,0x00000000}},	//   _vss_, _ostb, _रणाव, --, 
   {{0x443801f5,0xdcf800f3,0x00000000,0x00000000}},	//   _wss_, znuđ, --, --, 
   {{0x44391657,0x7bc00306,0x25640254,0x00000000}},	//   _tss_, zmlu, _põlu_, --, 
   {{0x44390544,0x6e38035a,0x9eb0535f,0xb4f80375}},	//   _uss_, _astb, әшлә, _בפרי, 
   {{0x2d8454bb,0x6e380112,0x25640037,0xaf440014}},	//   _amoe_, _bstb, _võlu_, لرى۪, 
   {{0x44ec022e,0xdce800de,0x21c00055,0x00000000}},	//   _kо_, _algā, _ṛjuḥ_, --, 
   {{0x7bc003a2,0x7658005b,0xfc0400d8,0x00000000}},	//   wmlu, ätyi, апио, --, 
   {{0x23600218,0x2d84033b,0x6e380c8c,0x28c405d7}},	//   _kojj_, _dmoe_, _estb, रेमि, 
   {{0x213c0399,0x201c08e7,0x5ec4015b,0x2d84017a}},	//   _hauh_, _iqui_, রুষে, _emoe_, 
   {{0x2c780ca8,0x05b401f9,0x00000000,0x00000000}},	//   _pàdé_, ंताब, --, --, 
   {{0x213cf1af,0x644000da,0xdb0001ab,0x26ec00eb}},	//   _jauh_, ānij, _chnò, _জাগো_, 
   {{0x213c0399,0x25d805f9,0x3cec0455,0xca7401d3}},	//   _mauh_, _खूबी_, mbev_, لنیک, 
   {{0x213c0369,0xf7443a8a,0x37e0015b,0x3b091658}},	//   _lauh_, шего, _বিআর, _реко_, 
   {{0x67140d2c,0x44ec01a9,0x00000000,0x00000000}},	//   _तारक_, _bо_, --, --, 
   {{0x03f431d9,0x213c0007,0xdb0001ab,0x00000000}},	//   _བསྡམ_, _nauh_, _ghnò, --, 
   {{0xb3849ad7,0x66880092,0x00000000,0x00000000}},	// [19d00] алал, _አድርጋ_, --, --, 
   {{0xa498067c,0x2cb005ac,0x00000000,0x00000000}},	//   _idòl, _øyde_, --, --, 
   {{0x201d1659,0x2364007c,0x80c40116,0x00000000}},	//   _aqui_, önja_, ەڭلە, --, 
   {{0x213c0399,0x224401a8,0x00000000,0x00000000}},	//   _cauh_, ænka_, --, --, 
   {{0x213c0007,0x6568b35a,0x00000000,0x00000000}},	//   _dauh_, öghe, --, --, 
   {{0x43741575,0x00000000,0x00000000,0x00000000}},	//   _луст, --, --, --, 
   {{0x201c16b8,0x00000000,0x00000000,0x00000000}},	//   _equi_, --, --, --, 
   {{0x213c0007,0x6440068f,0xe295165a,0x28c458c1}},	//   _gauh_, łnie, _тас_, रेडि, 
   {{0xc8a401ad,0x1be40063,0xefc8442d,0xdb0000d7}},	//   _गुंट, адњи_, _алал_, _ekní, 
   {{0x39500e26,0x4c941b6d,0xeb4808db,0x03f40327}},	//   _anys_, _қилс, тчик_, _བསྣམ_, 
   {{0x6e3802d0,0x9f78011a,0x00000000,0x00000000}},	//   _ustb, _שנבח, --, --, 
   {{0xac08ca97,0x6c040137,0x00000000,0x00000000}},	//   _анда_, _ۅكچۅ, --, --, 
   {{0xaf64010c,0x00000000,0x00000000,0x00000000}},	//   _ጸሎትና_, --, --, --, 
   {{0x3ea80276,0xd7f843a7,0x39500076,0x9e780432}},	//   şate_, шую_, _enys_, _öňüň, 
   {{0x63782776,0x96f9165b,0x31ac02fb,0xe7f000bc}},	//   _hîng, рест_, lýzu_, _अबका_, 
   {{0xda58025f,0x55740139,0x44ec022e,0x00000000}},	//   _יכול, огст, _qо_, --, 
   {{0x213c0007,0x7dd40153,0x00000000,0x00000000}},	// [19d10] _rauh_, _išse, --, --, 
   {{0x637824ba,0x28c4068f,0x213c020c,0xb96001e1}},	//   _mîng, रेणि, _sauh_, _àìra, 
   {{0x637824ba,0x395000a9,0x213c2a1f,0xc0d4314c}},	//   _lîng, _ynys_, _pauh_, مياب, 
   {{0x807800db,0xfde801d5,0x00000000,0x00000000}},	//   лбес_, қдик_, --, --, 
   {{0x6378025a,0x7658005b,0xe7e801f9,0x8afc00c0}},	//   _nîng, ätyv, जीचा_, nkęs, 
   {{0x213c003e,0x8fc406c7,0xa3440139,0x628002f0}},	//   _wauh_, يزون, _тэмл, únos, 
   {{0x9259165c,0x73c018ce,0x81e0015b,0x213c003e}},	//   _карт_, _хәте, _দিক_, _tauh_, 
   {{0x6378025a,0x00000000,0x00000000,0x00000000}},	//   _bîng, --, --, --, 
   {{0x3b84cb67,0x637800d2,0x201c0077,0x91841e4a}},	//   йлиг, _cîng, _uqui_, _بۇنۇ, 
   {{0xa92001c0,0x00000000,0x00000000,0x00000000}},	//   үдэл, --, --, --, 
   {{0x8b643e52,0xe9d40276,0x4e2800d4,0x00000000}},	//   تايم, йкэ_, _воєн_, --, 
   {{0x6378145e,0xdd8c006c,0x7f41165d,0x200c011c}},	//   _fîng, _کوچ_, _halq, orgi_, 
   {{0x6378025a,0x7f40c624,0x00000000,0x00000000}},	//   _gîng, _kalq, --, --, 
   {{0x66e083f9,0x7f400a4d,0x00000000,0x00000000}},	//   зора, _jalq, --, --, 
   {{0x6379165e,0x00000000,0x00000000,0x00000000}},	//   _zîng, --, --, --, 
   {{0x7bd9165f,0x39500165,0x69dc0129,0x857801f4}},	//   _kuwu, _unys_, _épea, асут_, 
   {{0x7bd80198,0x35a4016c,0x32d40131,0x00000000}},	// [19d20] _juwu, _ҳанг, مزاس, --, 
   {{0x7bd91660,0x21cc0150,0x00000000,0x00000000}},	//   _muwu, _ﺑﺎﺭﻭ, --, --, 
   {{0x7bd91661,0xb22400f3,0x3668024c,0x00000000}},	//   _luwu, смел, _сано_, --, 
   {{0x957801c0,0x200c0042,0xd0e800f2,0x00000000}},	//   _төгс_, frgi_, شکرم_, --, 
   {{0x7bd8034c,0x7f411662,0x00000000,0x00000000}},	//   _nuwu, _balq, --, --, 
   {{0x7f400f71,0x63780356,0xe0406e1e,0x64400210}},	//   _calq, _cînd, янчи, łnic, 
   {{0x6378006a,0x7f411663,0x200c005a,0xa00400cf}},	//   _sîng, _dalq, argi_, _ۇسلۇ, 
   {{0x7bd90db9,0x75340076,0x8cc41b51,0x00000000}},	//   _buwu, neyz, ाइलो, --, 
   {{0x7f40004e,0x300400ee,0x00000000,0x00000000}},	//   _falq, _ызаг, --, --, 
   {{0x7bd91664,0x63780311,0x7c2c0356,0x00000000}},	//   _duwu, _gînd, _ţarc, --, 
   {{0x904004d3,0x7bd80c6a,0x6e4401e2,0x00000000}},	//   _رۆژه, _euwu, _دنام, --, 
   {{0x5e54008f,0x3f980162,0x1ec4074d,0x00000000}},	//   _ליבע_, _ísur_, _улхи_, --, 
   {{0x7bd81418,0x7f409d24,0xbda4007b,0x00000000}},	//   _guwu, _yalq, _بحلو, --, 
   {{0x7f40851b,0x6d400093,0x9b54022e,0x00000000}},	//   _xalq, _haoa, _гишт_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x569432e6,0x7bd91665,0xfc480306,0x200c1d0e}},	//   част, _yuwu, stíš_, yrgi_, 
   {{0x6d411666,0xd83801c0,0x65b00309,0x00000000}},	// [19d30] _maoa, _лээ_, nçhi, --, 
   {{0x6d40d055,0x04e8015b,0xd49801c6,0xdce800c0}},	//   _laoa, গণের_, ёрт_, _ilgą, 
   {{0x7f40014f,0x6378054e,0x7658005b,0x00000000}},	//   _ralq, _rînd, ätyt, --, 
   {{0x6d4000b0,0x200c0427,0x7f4030b9,0x20d40c5e}},	//   _naoa, trgi_, _salq, džií_, 
   {{0x1ee40405,0x200d1667,0xd1b800f2,0xe4a400db}},	//   موشی_, urgi_, حالا_, _ыроо, 
   {{0x6d4016ee,0x2d9800dd,0x7bd800ca,0x7f411668}},	//   _aaoa, épen_, _ruwu, _qalq, 
   {{0x7bd91669,0x6d41166a,0x171c008f,0x7f40047e}},	//   _suwu, _baoa, אווע, _valq, 
   {{0x637807ea,0x7f400a55,0xbbd00118,0x00000000}},	//   _dîne, _walq, सद्क, --, 
   {{0x7f4001b9,0x3ea8033f,0xbb580798,0x7f94009d}},	//   _talq, łat_, ајнц_, _даах, 
   {{0x2d9400f7,0x3b080063,0xfe0800ec,0x543c00df}},	//   йрөс, јено_, _نقطي_, רעזא, 
   {{0x6d400421,0x7bd80e47,0x4fc4004e,0x4ea400c7}},	//   _faoa, _wuwu, _хста, _ерца, 
   {{0x6d4000b5,0x7bd9166b,0x00000000,0x00000000}},	//   _gaoa, _tuwu, --, --, 
   {{0xeb8d166c,0x69dc00d8,0x00000000,0x00000000}},	//   _жи_, _épen, --, --, 
   {{0x88d40055,0xdb1c01f4,0x00000000,0x00000000}},	//   _mṛya, äväp, --, --, 
   {{0xdac40075,0x52b8012d,0x00000000,0x00000000}},	//   _دېدى_, _अरेस, --, --, 
   {{0x74e805f5,0xdb0004cc,0x00000000,0x00000000}},	//   рдаг_, _chnö, --, --, 
   {{0x33648b0d,0xf6d40212,0xf8ac07f7,0x00000000}},	// [19d40] оваг, _міня, _घडिय, --, 
   {{0x7658023a,0x00000000,0x00000000,0x00000000}},	//   ätys, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x64400034,0xb0480276,0x61d4109a,0x00000000}},	//   łnia, изез_, імія_, --, 
   {{0x6d400109,0x00000000,0x00000000,0x00000000}},	//   _raoa, --, --, --, 
   {{0x6d401140,0xade4026b,0x00000000,0x00000000}},	//   _saoa, оцик, --, --, 
   {{0xe294caef,0x71580ebe,0xd0480213,0xf67800df}},	//   _дар_, _крас_, _ələs, יאַמ, 
   {{0x717443b1,0x69cc0115,0x00000000,0x00000000}},	//   _بهرا, ŭbez, --, --, 
   {{0x6d40f0cb,0x704400cf,0xd7bc0a59,0x19e001ec}},	//   _vaoa, _بئزك, ोगाच, _ﺍﻟﻨﺠ, 
   {{0xe45404ac,0x6d400069,0xee080276,0x8afc033f}},	//   קייט_, _waoa, _вежл_, djęc, 
   {{0x6d41166d,0x63780356,0xdd8c0137,0x00000000}},	//   _taoa, _hînc, _жш_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7dd402d5,0xeb98004e,0x00000000,0x00000000}},	//   _išsa, _кид_, --, --, 
   {{0x6378054e,0x5d8000db,0xea8814af,0x00000000}},	//   _mînc, _ىلەل, _پختن_, --, 
   {{0x5bc0007b,0x00000000,0x00000000,0x00000000}},	//   _تقول, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x889400d8,0x00000000,0x00000000,0x00000000}},	// [19d50] _хипх, --, --, --, 
   {{0xa49800a3,0x6b980e78,0xd78800f1,0xd499166e}},	//   _leòg, nntg, _ونيو_, ірт_, 
   {{0x28c40ebb,0x88ac00fe,0x00000000,0x00000000}},	//   रेरि, _গণিক, --, --, 
   {{0x20f400ab,0x0558007b,0x00000000,0x00000000}},	//   ुणेश_, _الحظ_, --, --, 
   {{0x91680248,0x00000000,0x00000000,0x00000000}},	//   _wó̟n_, --, --, --, 
   {{0x83a40022,0x9f48010e,0x9104013d,0x00000000}},	//   _хымҵ, _ümür_, пчәд, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xee2c0451,0xbc641d0f,0x6b99166f,0xd25000f1}},	//   اٽي_, звик, entg, _ګنې_, 
   {{0x80780588,0xa49801ab,0x00000000,0x00000000}},	//   _убас_, _deòg, --, --, 
   {{0x547c0302,0x644c0841,0x5f7401b9,0x6b9804cc}},	//   יטחו, _mrci, _بارر, gntg, 
   {{0x3cd41422,0x1c1412eb,0x00000000,0x00000000}},	//   _ежес, _दमकल_, --, --, 
   {{0x644d1670,0xa49800db,0x7d240214,0xed4c033a}},	//   _orci, _geòg, _رفتن, _џо_, 
   {{0x63700790,0x19e002dd,0x52b80d2e,0x28c40d2e}},	//   _kını, _ﺍﻟﻬﺠ, _अर्स, रेलि, 
   {{0x36680166,0xf1e400cc,0x00000000,0x00000000}},	//   баго_, _পয়োভ, --, --, 
   {{0x644c102c,0xa4980192,0xba181075,0x63700205}},	//   _arci, _leòd, _ايعا_, _mını, 
   {{0x644c01fa,0xdc9c037e,0x6d9c02b5,0xb4d40037}},	//   _brci, _pc版_, hīan, िखे_, 
   {{0x9f5c004e,0x19e001ec,0x64a00fac,0x00000000}},	// [19d60] _avuí_, _ﺍﻟﻠﺠ, еата, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7dc42b76,0xe3b803d4,0x644d1671,0xb9d80092}},	//   mósf, _অংশব, _erci, _በኛ_, 
   {{0x35a4152d,0x6a98008f,0x3864012d,0xe280009d}},	//   _хамг, זשענ, _żory_, элхи, 
   {{0x2904016b,0xa498007f,0xb62c01ec,0x00000000}},	//   _ɛna_, _reòg, _ﮔﻰ_, --, 
   {{0x78b4005b,0x00000000,0x00000000,0x00000000}},	//   _myyv, --, --, --, 
   {{0x6fb401ed,0x00000000,0x00000000,0x00000000}},	//   _ہمرا, --, --, --, 
   {{0x626005f5,0x61400063,0xdd2c0118,0x010800cf}},	//   _явса, _песа, _pěšk, _وتقو_, 
   {{0xd6c402a6,0x32180122,0xa49801ab,0x00000000}},	//   ্ডিয, lupy_, _geòd, --, 
   {{0x207800df,0x00000000,0x00000000,0x00000000}},	//   _האמא, --, --, --, 
   {{0x2efd1672,0x00000000,0x00000000,0x00000000}},	//   _ietf_, --, --, --, 
   {{0xb60400ef,0x00000000,0x00000000,0x00000000}},	//   _mušā, --, --, --, 
   {{0x32180784,0x98744d56,0x645c011f,0xd7f8828a}},	//   hupy_, еляц, xxqi, зус_, 
   {{0x3218239b,0x644002ea,0x00000000,0x00000000}},	//   kupy_, ́nis, --, --, 
   {{0x644c740a,0x321800e4,0x765801f4,0x00000000}},	//   _srci, jupy_, ätyp, --, 
   {{0x503c001f,0x88d40055,0xd6d02e0b,0x644c01ef}},	//   _በግንባ, _nṛga, اقِ_, _prci, 
   {{0x03d401ce,0x7d1cf2b8,0x98a400f3,0x00000000}},	// [19d70] джаю, òssi, _пиће, --, 
   {{0x68fc0477,0x6440033f,0xa49800a3,0x00000000}},	//   _heqd, łnio, _reòd, --, 
   {{0x68fc036e,0x637008a9,0x4254009f,0x00000000}},	//   _keqd, _rını, بنار, --, 
   {{0x63700ab7,0x4095041c,0x63780129,0x56340023}},	//   _sını, ولار, _dîna, _ኣራኣእ, 
   {{0x644d1673,0x3f680305,0x68fc014f,0x6d9c00b0}},	//   _urci, жило_, _meqd, tīan, 
   {{0x44291674,0x637006be,0x851c0bae,0x835400e5}},	//   mta_, _qını, _फाँट_, _تھرا, 
   {{0x88d40882,0x32180e21,0x9268010a,0xf530032e}},	//   _hṛda, cupy_, _ерта_, _þýði_, 
   {{0x44280a4d,0xd6580302,0xed4c0a52,0x88d400b8}},	//   ota_, ליות_, لپى_, _kṛda, 
   {{0x60d91675,0x63700724,0x00000000,0x00000000}},	//   _igum, _tını, --, --, 
   {{0x44291676,0xfbd001d5,0x88d400cd,0x50640166}},	//   ita_, ختب_, _mṛda, _ятса, 
   {{0x44291677,0x60d91678,0x68fc014f,0x7e981ec7}},	//   hta_, _kgum, _beqd, _بنار_, 
   {{0x44291679,0xd010040b,0x2cac063f,0x7c580220}},	//   kta_, _جلے_, ịmị_, _ولار_, 
   {{0x3b08ac40,0x60d800ec,0x5c7400d1,0x644801a8}},	//   _дело_, _mgum, _хәйр_, ægil, 
   {{0x4429167a,0x00000000,0x00000000,0x00000000}},	//   dta_, --, --, --, 
   {{0x4429167b,0x60d80995,0x66e0b68c,0x64400210}},	//   eta_, _ogum, тоса, łnil, 
   {{0x60d9167c,0x4429167d,0x3668023b,0x51cc02dd}},	//   _ngum, fta_, баҳо_, _ﺑﺎﻋﺸ, 
   {{0x4429167e,0xdedc0023,0x00000000,0x00000000}},	// [19d80] gta_, ነሉን_, --, --, 
   {{0x7c29167f,0x32191680,0x60d91681,0x00000000}},	//   iter, tupy_, _agum, --, 
   {{0x7c291682,0x2d9801ed,0x00000000,0x00000000}},	//   hter, épek_, --, --, 
   {{0x7c291683,0x44291684,0x321846dc,0xefb001b9}},	//   kter, bta_, rupy_, چیرگ, 
   {{0xa064eec3,0x764c072b,0x02c4013d,0x00000000}},	//   маца_, lvby, _җитү, --, 
   {{0x60d91685,0x7c2808cb,0x398003b2,0x00000000}},	//   _egum, dter, _hósd_, --, 
   {{0x7c291686,0x00000000,0x00000000,0x00000000}},	//   eter, --, --, --, 
   {{0x60d81418,0x00000000,0x00000000,0x00000000}},	//   _ggum, --, --, --, 
   {{0x7c291687,0xd1f80020,0x0fa4035b,0x68fc031c}},	//   gter, ገዶች_, _злаҟ, _reqd, 
   {{0x69dc0022,0x8a1801c4,0x00000000,0x00000000}},	//   _épek, поос_, --, --, 
   {{0x44291688,0xdb2000e5,0x00000000,0x00000000}},	//   zta_, úság, --, --, 
   {{0x44291689,0x68fc014f,0x298802bf,0x2d900a43}},	//   yta_, _qeqd, існо_, _öye_, 
   {{0x68fc014f,0x7aec0356,0x19e00150,0x00000000}},	//   _veqd, _şate, _ﺍﻟﻼﺠ, --, 
   {{0x4429168a,0x3f8806af,0x68fc014f,0x660403cd}},	//   vta_, éaux_, _weqd, tsjk, 
   {{0xa52808ea,0x68fd168b,0x4429168c,0x00000000}},	//   _སྡུག_, _teqd, wta_, --, 
   {{0x29ec0198,0xa49801e1,0x00000000,0x00000000}},	//   mƙa_, _odòt, --, --, 
   {{0x8cc40034,0xd5b88ad2,0xa49800a3,0x5ef000cd}},	// [19d90] ाइटो, фср_, _seòb, ुरम्_, 
   {{0x60d9168d,0xa2800ee8,0xd6d001e2,0x00000000}},	//   _sgum, پیرو, اقې_, --, 
   {{0x7c29168e,0x29ec03f9,0x45d40021,0x00000000}},	//   zter, nƙa_, _поос, --, 
   {{0xf9d800c8,0xc5a80014,0x31640200,0x88d40055}},	//   פֿעל, _ژُھن_, gjoz_, _tṛda, 
   {{0x4429168f,0x7c291690,0xe4a41614,0x00000000}},	//   qta_, xter, _црно, --, 
   {{0x70501d10,0x79540166,0x26c40306,0x00000000}},	//   انوا, _küwä, _únos_, --, 
   {{0x522400fd,0xa49800a3,0x7c291691,0xfce4004e}},	//   _ифта, _feòc, wter, нойо, 
   {{0x60d91692,0x7ed400f1,0x00000000,0x00000000}},	//   _ugum, وزګا, --, --, 
   {{0x7c291693,0x6cb001e0,0xa2d000dc,0x7db40133}},	//   uter, лөшт, _भृत्, وڵڵا, 
   {{0x0ae80228,0xfaf0007b,0x398002d2,0x7aec0139}},	//   үдөй_, دثة_, _móse_, _şatb, 
   {{0x2ca409d3,0x39e80cc9,0x3a98490c,0x7cd91694}},	//   _exod_, ядно_, ятию_, _емер_, 
   {{0xbd44007b,0xb4dc17ee,0x00000000,0x00000000}},	//   _سنتي, _ढले_, --, --, 
   {{0x8d741fd6,0xa3d81533,0x3dcc0135,0x00000000}},	//   _جالا, _ढंग_, mmew_, --, 
   {{0xfaa46c20,0x29ec0198,0xfbc400c9,0xdb2001b9}},	//   _пало, bƙa_, _ябло, _شوبی, 
   {{0xe8fc002d,0x00000000,0x00000000,0x00000000}},	//   mjûn_, --, --, --, 
   {{0xe8fc000f,0x3d0c033f,0x00000000,0x00000000}},	//   ljûn_, _ियों_, --, --, 
   {{0x212c01a6,0xe81400c5,0xa998011a,0xd7e80116}},	// [19da0] dfgh_, _तिया_, _מבקר, _توخۇ_, 
   {{0xe3b4b09c,0xe8fc045f,0xa49800a3,0xa44001ec}},	//   ебу_, njûn_, _seòc, ынуд, 
   {{0x79540432,0xe29400d8,0xd8e401ec,0x8afc0210}},	//   _güwä, наф_, _ﺍﯞﻩﺟ, djęl, 
   {{0x28c401ad,0x51cc01ec,0x00000000,0x00000000}},	//   रेकि, _ﺑﺎﻗﺸ, --, --, 
   {{0xa5280003,0xb8a00020,0x26c4012c,0x99e001ec}},	//   _སྡིག_, _ወንጀል_, _únor_, _ﺍﻟﺴﺅ, 
   {{0xdfcd1695,0x6a8400e8,0xe8fc000f,0x6ee401b9}},	//   مين_, _jéfé, jjûn_, رستل, 
   {{0xa49801ab,0x00000000,0x00000000,0x00000000}},	//   _teòc, --, --, --, 
   {{0xf1a81176,0x00000000,0x00000000,0x00000000}},	//   _رازه_, --, --, --, 
   {{0xa0a02ef6,0x6c300014,0x00000000,0x00000000}},	//   _батд, اہتا, --, --, 
   {{0x53b005d7,0x80a40022,0x4a540d1d,0xfbcc00ec}},	//   जकिश, _ргуҧ, вкос, يڪو_, 
   {{0xdfcc215e,0x7bdc022c,0x03f4031c,0xab640116}},	//   _ايل_, ísur, _བསྐམ_, _үвел, 
   {{0xbfa401fb,0x88d400b8,0xe06c01e1,0x290400de}},	//   hiệ, _nṛca, _ìṣí, _ēnas_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe664004e,0x00000000,0x00000000,0x00000000}},	//   нтбо, --, --, --, 
   {{0x6a8406af,0x79540166,0x2c4c0092,0x00000000}},	//   _défé, _qüwä, _ቁርጠኝ, --, 
   {{0xd5b91696,0x95d91697,0x698400cd,0x00000000}},	//   есу_, едст_, bṛṃh, --, 
   {{0xa2d000bc,0x7dc400ae,0xf928010f,0x00000000}},	// [19db0] भेन्, lósc, _חופּ, --, 
   {{0x7bcc011c,0x7524002f,0x2bc40210,0x00000000}},	//   _èaut, _eckz, _रीमा, --, 
   {{0xd7880014,0xd6d80276,0x69cc0175,0x00000000}},	//   _سنَو_, _птю_, omce, --, 
   {{0xcf240131,0xc0d4007b,0x5fc80220,0xd1640395}},	//   ۇرىي, نياب, _ﺗﻮﭘﺘ, лъчи, 
   {{0x656d1698,0x4fe80220,0x25bc11bc,0x764808a5}},	//   _ioch, емін_, ्षीण, _áfyr, 
   {{0x656d1699,0x3b040cc1,0x4f0820ea,0x44380f85}},	//   _hoch, xalq_, ىتىپ_, _ips_, 
   {{0xa37800b8,0x622000db,0x00000000,0x00000000}},	//   _guõa, _حوزە, --, --, 
   {{0x656d169a,0x443802b1,0x7dd402d5,0x11d400c6}},	//   _joch, _kps_, _išsk, _متقد, 
   {{0x4439169b,0x2fcc0076,0xe8fc000f,0x6c0000c7}},	//   _jps_, bmfg_, tjûn_, азыз, 
   {{0x69cc01d4,0x44380f85,0x39e851cd,0x00000000}},	//   emce, _mps_, мдоо_, --, 
   {{0xfaa47d03,0x6a840231,0x656d169c,0xe8fc0b21}},	//   тано, _réfé, _ooch, rjûn_, 
   {{0x656d169d,0xdc5010e5,0xe8fc000f,0x2e4400b5}},	//   _noch, _مرتک, sjûn_, のfaq_, 
   {{0xec6d169e,0xe9a0036b,0x4439169f,0x00000000}},	//   _тп_, раяп, _nps_, --, 
   {{0x656c32b5,0x08c463eb,0x978400f2,0x00000000}},	//   _aoch, ығып_, ایده, --, 
   {{0x660052d8,0xa2d00316,0x44383046,0x6b94011a}},	//   ипра, भेम्, _aps_, _בכסף_, 
   {{0x656d16a0,0x443916a1,0x18b40139,0xe5a00022}},	//   _coch, _bps_, _бәгр, аиси, 
   {{0x656d16a2,0x28440132,0x00000000,0x00000000}},	// [19dc0] _doch, _азып_, --, --, 
   {{0x656c0597,0x64580301,0x6d9c00b0,0x44382216}},	//   _eoch, _šuic, tīak, _dps_, 
   {{0xfe6402c0,0x4438045a,0x83c40116,0xb22473af}},	//   _اگ_, _eps_, уғра_, тмел, 
   {{0x656c0a4d,0xa11116a3,0xd130007b,0x44382216}},	//   _goch, لومت, صمت_, _fps_, 
   {{0x443811ce,0xe56516a4,0x6020005b,0x00000000}},	//   _gps_, _рияд_, идца, --, 
   {{0x656d16a5,0x28c40bc0,0x73740022,0xa0640114}},	//   _zoch, रेटि, _рымх, таља_, 
   {{0xf1a82814,0x656d16a6,0x9e0116a7,0x2244037e}},	//   _قاره_, _yoch, ачыл, ænkt_, 
   {{0xdd940372,0x656d16a8,0x4438010a,0xa37800e4}},	//   кшы_, _xoch, _yps_, _utõr, 
   {{0xafe402bf,0xa49801c3,0x4438045a,0x7aec06be}},	//   _розл, _leòn, _xps_, _şata, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdee00323,0xa49808c2,0x7bdc00df,0xe97000e5}},	//   _тохи, _neòn, ŭsup, لندھ, 
   {{0x7dc40aef,0xec7800f3,0xfe08007b,0x00000000}},	//   rósc, _опе_, _أغلى_, --, 
   {{0x656d16a9,0xdd8c4319,0x69cc01e4,0x98040026}},	//   _roch, _بون_, rmce, иярд, 
   {{0x656d16aa,0xdb4c01d9,0x57a4485b,0xdc3400df}},	//   _soch, _وَن_, ашса, _סאוט_, 
   {{0xda6c0c04,0x44380640,0xa4980ba1,0x569439f6}},	//   _тя_, _sps_, _adòp, аарт, 
   {{0x44381570,0x656d16ab,0xa4980e89,0x79840810}},	//   _pps_, _qoch, _deòn, chkw, 
   {{0x656d16ac,0x44380798,0x83340124,0x7dc401f6}},	// [19dd0] _voch, _qps_, лнах, nósa, 
   {{0x656d16ad,0x29d80374,0x00000000,0x00000000}},	//   _woch, _kūao_, --, --, 
   {{0x656d16ae,0x44382679,0x31ac0122,0x482400b8}},	//   _toch, _wps_, lýzy_, _duḥṣ, 
   {{0xc0e81169,0xf67800c8,0x1a98008f,0x7ff516af}},	//   رفتن_, _נארמ, ויבע, هستا, 
   {{0x35180375,0xa04400db,0x1ee4072d,0x00000000}},	//   _אורנ, ئكتە_, نوشی_, --, 
   {{0x7dd40953,0x3ea41180,0x439401c0,0xff240212}},	//   _išsi, лилг, _сагс, умко, 
   {{0xc66c069c,0xeff40023,0x00000000,0x00000000}},	//   _ኣመሪካ_, ፈለየ_, --, --, 
   {{0x8d54013d,0xfaa401d5,0x00000000,0x00000000}},	//   атьч, ғамо, --, --, 
   {{0xd0d402e8,0xeeb40131,0xa3d4000d,0xff245b74}},	//   _вотъ, кләш_, ागप_, _مبای, 
   {{0xbb8436e9,0xdca005c2,0xacc40724,0xdb2042c0}},	//   الدي, лақи, ыгыз_, جودی, 
   {{0x9ac000ee,0xbdf40798,0xa7f800a2,0xba74009a}},	//   ринҗ, _спеј, myñy, ااخت, 
   {{0x0c0401d9,0x2d9801d3,0x00000000,0x00000000}},	//   _چونُ, épet_, --, --, 
   {{0x7d0837e7,0xd91000dd,0xdb2004fb,0xa49801c3}},	//   maes, میں_, _نوشی, _seòn, 
   {{0x7d0916b0,0x3cec0fb7,0xca7404d3,0xb8280107}},	//   laes, lcev_, انێک, _ҷоиз_, 
   {{0x98a471e1,0xba38010f,0x68ec0332,0x00000000}},	//   ımı_, _טײַט, éidí, --, 
   {{0x3cec0fb7,0x00000000,0x00000000,0x00000000}},	//   ncev_, --, --, --, 
   {{0x394116b1,0x3864008e,0xb3c80114,0x00000000}},	// [19de0] meks_, _çor_, елаз_, --, 
   {{0x394116b2,0x7d0916b3,0x67e800ef,0x69000419}},	//   leks_, haes, _uļja, ľudň, 
   {{0xeb941a4c,0x7d0916b4,0x6b78008f,0x63ac0311}},	//   נדער_, kaes, ערענ, _ţinâ, 
   {{0x6738098d,0x394116b5,0xf1a80691,0x3cec0219}},	//   đuje, neks_, راضه_, jcev_, 
   {{0x9420016b,0x9348035b,0x3cec0219,0x7d0803ac}},	//   _ɑsɛm_, _иҟаз_, dcev_, daes, 
   {{0x43742488,0x3940007d,0xa7f8010e,0x00000000}},	//   _куст, heks_, gyñy, --, 
   {{0x638116b6,0x7d0916b7,0x39401d13,0x799402d0}},	//   _угра, faes, keks_, _omyw, 
   {{0x7d0916b8,0xec68a577,0x394003cd,0x7658005b}},	//   gaes, ерок_, jeks_, ätyy, 
   {{0x394116b9,0xa49801ab,0xeb040b7e,0xdef40023}},	//   deks_, _neòl, лчно, ለጺኡ_, 
   {{0x39800436,0x29d802b5,0x799403ac,0x35b4033f}},	//   _rósa_, _pūao_, _amyw, ंवड़, 
   {{0xdfd80491,0x7d08b171,0xa49801ab,0xfca804fb}},	//   _ʚϊɞ_, baes, _aeòl, _یاهو_, 
   {{0x7d080810,0x394000c5,0x00000000,0x00000000}},	//   caes, geks_, --, --, 
   {{0x588516ba,0xd83916bb,0xa4980e89,0x788806af}},	//   быра, лэр_, _ceòl, _rêvé, 
   {{0x29d802b1,0x25bc00dc,0x00000000,0x00000000}},	//   _tūao_, ्ष्ण, --, --, 
   {{0x5b7800c8,0x6b9916bc,0x98b40115,0x39400254}},	//   _ארגא, mitg, _ĉeĥo_, beks_, 
   {{0x2fdc05d5,0xa49801c3,0x6b9916bd,0xc61400ce}},	//   _litg_, _feòl, litg, _तटीय_, 
   {{0x290916be,0x84c4b7c3,0xa49905ae,0x99841e5a}},	// [19df0] maca_, рәнд, _geòl, _دليو, 
   {{0x290916bf,0x69dd053f,0x2fdc0048,0x6b980c86}},	//   laca_, _hiqe, _nitg_, nitg, 
   {{0xe2a81a90,0x7dd40153,0xdb200332,0x00000000}},	//   رائن_, _išsv, íréi, --, 
   {{0x290916c0,0x6b9916c1,0x69dc047e,0x63780356}},	//   naca_, hitg, _jiqe, _mîni, 
   {{0x3cec151c,0x6b980194,0x69dc0023,0x3ddc0036}},	//   vcev_, kitg, _miqe, _riww_, 
   {{0x29085a7d,0x69dd16c2,0x2b4d16c3,0xdbdc01e1}},	//   haca_, _liqe, _nafc_, _nìáj, 
   {{0x290916c4,0x6b980c86,0x2fdc1570,0x7d0916c5}},	//   kaca_, ditg, _ditg_, taes, 
   {{0x290808a4,0x69dd16c6,0xa49801c3,0x63b4022e}},	//   jaca_, _niqe, _leòm, loxn, 
   {{0x3b844efa,0x6b981570,0x2fdc1570,0x7d0916c7}},	//   илиг, fitg, _fitg_, raes, 
   {{0x69dc0784,0x2eec010a,0x2fdc07de,0x7d0916c8}},	//   _aiqe, ccff_, _gitg_, saes, 
   {{0x394116c9,0x3f8516ca,0x61e40113,0x69dc047e}},	//   teks_, _illu_, _jujl, _biqe, 
   {{0xac9516cb,0x290916cc,0xe9d41142,0x61e40455}},	//   انیا_, gaca_, икэ_, _mujl, 
   {{0x7dc42cd7,0x69dd16cd,0x61e516ce,0x394116cf}},	//   lóso, _diqe, _lujl, reks_, 
   {{0x3940367a,0xdd8c01d5,0x1a740066,0x00000000}},	//   seks_, _بوچ_, _مشبک_, --, 
   {{0x61e4014f,0x63b402fb,0x69dc0166,0x3e550e0c}},	//   _nujl, doxn, _fiqe, _jāt_, 
   {{0x290916d0,0xa49800db,0x7994033f,0x9990012d}},	//   caca_, _teòl, _umyw, żała_, 
   {{0xb46430c8,0x3f8516d1,0x7bc0198f,0xa3e40166}},	// [19e00] шкал, _ollu_, ollu, идта_, 
   {{0x7bc00f7b,0x69dd16d2,0x61e40649,0x7dd40153}},	//   nllu, _éper, _bujl, _išsu, 
   {{0x7bc116d3,0x2fdc04cc,0x69dc016d,0x3e540055}},	//   illu, _ritg_, _yiqe, _nāt_, 
   {{0x7aec26f8,0x61e4047e,0x3f8516d4,0x2fdc07c5}},	//   _şatl, _dujl, _allu_, _sitg_, 
   {{0x2fdc05d5,0x33d402bf,0x04c805d9,0x7bc02a71}},	//   _pitg_, _вівт, _موٽي_, kllu, 
   {{0x066402f2,0xa854011a,0x00000000,0x00000000}},	//   _ئایپ, יינה_, --, --, 
   {{0x290916d5,0x2fdc1570,0x61e40007,0x6f0801fa}},	//   yaca_, _vitg_, _gujl, rafc, 
   {{0x3f840ba3,0xe8140574,0x290800eb,0xad640597}},	//   _ellu_, _तिला_, xaca_, شابه, 
   {{0x29081326,0x6b9916d6,0x66f86d65,0x00000000}},	//   vaca_, titg, ्रमक_, --, 
   {{0x69dd16d7,0x7bc00194,0xdee01def,0x2fdc01f5}},	//   _siqe, gllu, _дофи, _uitg_, 
   {{0xa3d41bd6,0x6b9916d8,0x69dc0240,0x3e540055}},	//   ागत_, ritg, _piqe, _gāt_, 
   {{0x7bc00af5,0x6b980137,0xa4980192,0x657c0175}},	//   allu, sitg, _seòm, xkqh, 
   {{0x2d850529,0x6b9916d9,0x69dc0978,0x7df0f4b4}},	//   _iloe_, pitg, _viqe, _vāse, 
   {{0x69dc016d,0x6b98022e,0xe66401f0,0x3e540055}},	//   _wiqe, qitg, қтҳо, _yāt_, 
   {{0x290808a4,0x2d840036,0x69dc047e,0x63b4022e}},	//   paca_, _kloe_, _tiqe, voxn, 
   {{0x2909129c,0x7dc443e5,0x61e403e0,0x00000000}},	//   qaca_, jósl, _rujl, --, 
   {{0xd8380228,0x61e4014f,0x69dc00d8,0x7dd40153}},	// [19e10] _кээ_, _sujl, _épeq, _išst, 
   {{0x61e4df70,0x9cd40375,0x00000000,0x00000000}},	//   _pujl, שומה_, --, --, 
   {{0xe6840075,0xd8b8034c,0x61e4016d,0xa2640b01}},	//   _ئۆزى_, _مدیا_, _qujl, шъал, 
   {{0x61e40007,0x3f840263,0xdce80003,0x38100133}},	//   _vujl, _sllu_, _imgħ, _بژێر, 
   {{0x7bc0d70b,0xdce8005f,0x200c0036,0x3e540055}},	//   yllu, _nogā, usgi_, _sāt_, 
   {{0x2d84ef54,0x61e4f1f5,0x7dc401d3,0x438440bb}},	//   _aloe_, _tujl, tóso, _السق, 
   {{0x2d8404e6,0xceb400ac,0x216400db,0xa184010a}},	//   _bloe_, şən_, _ктаг, _вăйĕ_, 
   {{0xee3516da,0x5bdc18cc,0x400800ec,0x3e540055}},	//   ёны_, नद्व, _ميرٽ_, _vāt_, 
   {{0x7bc0004e,0xb1440345,0x30380066,0x00000000}},	//   tllu, _دینم_, _متلک_, --, 
   {{0x7bc00af5,0x2d84020b,0x3f84b3c1,0x3b8516db}},	//   ullu, _eloe_, _ullu_, слог, 
   {{0x2d840076,0x7bc116dc,0xdb2001a8,0x00000000}},	//   _floe_, rllu, _þrít, --, 
   {{0xdce80618,0x0d540fa2,0x7bc0004e,0xfb840022}},	//   _fogā, _وخند, sllu, рыҩн, 
   {{0x3bd5112a,0xa3d40b02,0x7bc00200,0x00000000}},	//   _люкс, ागा_, pllu, --, 
   {{0xa8000077,0x7bc002d1,0x3b080a5b,0xdcf80064}},	//   íñas, qllu, _секо_, ikuč, 
   {{0x6d9c00b0,0x756400e5,0x00000000,0x00000000}},	//   pīat, میدہ_, --, --, 
   {{0x69dc0022,0x88d40055,0x7dd40064,0xdce800dc}},	//   _épep, _mṛja, _išss, _yogā, 
   {{0xe8f4e695,0x1ddc1533,0xe45c04cc,0xe29401e0}},	// [19e20] _улы_, _पूछत, _uzöl_, ҡау_, 
   {{0x09cc015b,0xaacc0ebb,0x3950045a,0xf7700345}},	//   _রূপা, हेकक, _hays_, _راخ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x395116dd,0x00000000,0x00000000,0x00000000}},	//   _jays_, --, --, --, 
   {{0x3a240ae3,0x3950005a,0x61f800d7,0x00000000}},	//   hulp_, _mays_, _čule, --, 
   {{0xb8f80d46,0x2d84062c,0x3a24017a,0x8e2002dd}},	//   _འཛ_, _sloe_, kulp_, рiп_, 
   {{0x39500076,0x2d840036,0x65b00363,0xf678010f}},	//   _oays_, _ploe_, eçhy, טאַמ, 
   {{0xafe40276,0x88d40055,0xdce80171,0xd39801af}},	//   _гоал, _sṛma, _pogā, _сәғә_, 
   {{0xf0a801f4,0x00000000,0x00000000,0x00000000}},	//   _скал_, --, --, --, 
   {{0x4f84121e,0x3da400db,0x00000000,0x00000000}},	//   _بارہ, йрөб, --, --, 
   {{0xed04034c,0x6ce4109a,0x8afc012d,0x00000000}},	//   _هواپ, _ліле, djęt, --, 
   {{0xdce80421,0x8afc0034,0x00000000,0x00000000}},	//   _togā, ejęt, --, --, 
   {{0x6cd40efb,0x39500c3e,0x58840046,0x6cc46f34}},	//   _اقشا, _days_, пыра, _уйда, 
   {{0x7df0002b,0x9cd4011a,0x2b90085b,0x00000000}},	//   _hāsa, _הודה_, _ریجس, --, 
   {{0x395000e8,0x7d2405f7,0x6378054e,0x7df000b8}},	//   _fays_, _útsý, _mînt, _kāsa, 
   {{0x7df0005f,0xa49801ab,0x225c0010,0x00000000}},	//   _jāsa, _heòi, _čuk_, --, 
   {{0x7df116de,0x637800e4,0x88d4002b,0x00000000}},	// [19e30] _māsa, _oînt, _mṛka, --, 
   {{0xdce8054e,0x136801c6,0x7df00055,0x00000000}},	//   _kogă, йшхи_, _lāsa, --, 
   {{0x26c401a2,0xa49801c3,0x00000000,0x00000000}},	//   _áno_, _meòi, --, --, 
   {{0xa49808c2,0x7df000dc,0xd25000e5,0xd17400db}},	//   _leòi, _nāsa, ڈنے_, зышы, 
   {{0xd2501893,0x88d400cd,0xb6000022,0xb88000e5}},	//   ونے_, _sṛja, ñáva, őíve, 
   {{0x644d16df,0x66f8433a,0x63780311,0xa49801c3}},	//   _isci, ्रिक_, _cînt, _neòi, 
   {{0x7df000a3,0x693000bc,0xd1d00092,0x03f000cc}},	//   _bāsa, _křeč, ብሮች_, _চিটী_, 
   {{0x5bb00b9c,0xee340953,0x7df000dc,0x84940023}},	//   ुत्व, іны_, _cāsa, _ፍርሕን_, 
   {{0xa49801c3,0x7df000cd,0x6d9c02b5,0x63780356}},	//   _beòi, _dāsa, tīar, _fînt, 
   {{0x395116e0,0xdce80311,0x65b000ad,0xb4e42802}},	//   _says_, _bogă, rçhy, _कल्प_, 
   {{0x395116e1,0x644c0ffb,0xa49808c2,0xed4c01ed}},	//   _pays_, _lsci, _deòi, رپی_, 
   {{0x39508186,0x00000000,0x00000000,0x00000000}},	//   _qays_, --, --, --, 
   {{0xa49808c2,0x98780116,0x7dc40162,0xbb740408}},	//   _feòi, сәйф_, hósk, _мукъ, 
   {{0x395116e2,0xa49800a3,0xbae4007b,0xab24014b}},	//   _ways_, _geòi, _بكثي, _доша_, 
   {{0x66e00364,0xa4980428,0xe3ac00fe,0x395001f4}},	//   дора, _keòw, কতাব, _tays_, 
   {{0x6e3000a2,0x7dc402d2,0xca742a9d,0x00000000}},	//   _çebş, dósk, _хушы, --, 
   {{0x3774084c,0xe5a006bd,0x8afc002d,0x00000000}},	// [19e40] _дынс, фити, mjęr, --, 
   {{0x6d9c00b0,0xd37003cc,0x00000000,0x00000000}},	//   hīap, رۇز_, --, --, 
   {{0x644d16e3,0x437402bf,0xd9ec00c5,0x72443f6c}},	//   _esci, чутт, _घूमत_, تپال, 
   {{0x88d40882,0x6378054e,0x8e2002dd,0xdce800c0}},	//   _bṛha, _sînt, рiн_, _ilgė, 
   {{0xdfcd16e4,0x8f842b8d,0x644c0205,0x64400356}},	//   چين_, пқал, _gsci, ănic, 
   {{0xdfcc530d,0xceb403be,0x63780356,0x1fa401b9}},	//   نين_, şəm_, _dîns, окчи_, 
   {{0xa3d410dc,0xa49801c3,0x63780356,0x7df00055}},	//   ागर_, _reòi, _vînt, _pāsa, 
   {{0x29d800b0,0xa49801c3,0x9dd000ec,0x311400cd}},	//   _tūai_, _seòi, وزيش, दृशः_, 
   {{0x88d400cd,0x7df00882,0x7d180042,0x00000000}},	//   _gṛha, _vāsa, _ddws, --, 
   {{0xfd500055,0x409516e5,0x6e44030d,0x00000000}},	//   _madṛ, _эрст, _мезз, --, 
   {{0x6f1803ac,0x68f800e8,0x67e80171,0x7df00055}},	//   _idtc, ñudo, _iļji, _tāsa, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7dd40006,0xa49801c3,0x7df000de,0x00000000}},	//   _išsp, _teòi, _jāsn, --, 
   {{0x644c01e4,0x6fb8012d,0x00000000,0x00000000}},	//   _rsci, इविं, --, --, 
   {{0x69300316,0xdb20008c,0x45d4ca40,0x6b8802d0}},	//   _přeč, _þrát, зовс, _ilfg, 
   {{0x48140faa,0xe4a401f0,0x00000000,0x00000000}},	//   _емис, орзо, --, --, 
   {{0x2918011f,0x6fc81fbc,0xdce800c0,0xdeb80092}},	// [19e50] _idqa_, ितां, _elgė, _ቲያን_, 
   {{0xfd5000cd,0x00000000,0x00000000,0x00000000}},	//   _dadṛ, --, --, --, 
   {{0x765c020c,0xd8740271,0x8e200150,0x00000000}},	//   _grpy, _فایب, рiм_, --, 
   {{0x51841e76,0xe16400d1,0x00000000,0x00000000}},	//   муча, غداي, --, --, 
   {{0x644d16e6,0x6d9c00b0,0x6b88035a,0x81cc0154}},	//   _usci, tūan, _olfg, রদল_, 
   {{0x442916e7,0xdce8012d,0x7df000de,0x88d400b8}},	//   mua_, _mogą, _dāsn, _vṛha, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x442916e8,0x4034010b,0xed540107,0xe45c02d2}},	//   oua_, _небс, зоъ_, _krö_, 
   {{0x442916e9,0x00000000,0x00000000,0x00000000}},	//   nua_, --, --, --, 
   {{0x442803a0,0xd91001b9,0xbc381d37,0xcf78007b}},	//   iua_, چیغ_, _ۇستا_, _وإلا_, 
   {{0x442916ea,0x29d80069,0x00000000,0x00000000}},	//   hua_, _lūau_, --, --, 
   {{0x7dc401d3,0x00000000,0x00000000,0x00000000}},	//   kósi, --, --, --, 
   {{0x442916eb,0xeb8d16ec,0x213c0214,0x00000000}},	//   jua_, _зи_, _mbuh_, --, 
   {{0x442916ed,0x7c2916ee,0x7df00171,0x43c400cd}},	//   dua_, muer, _jāso, वतोऽ, 
   {{0x7c2916ef,0x6d9c06c8,0x44280270,0x7c2c2dba}},	//   luer, kūal, eua_, _åarb, 
   {{0x442916f0,0x7df00270,0x7c2805c7,0x74e801c6}},	//   fua_, _lāso, ouer, сдаг_, 
   {{0x44290b47,0x398003b2,0xa3d400cd,0x6ea00037}},	// [19e60] gua_, _nósi_, ागं_, _केनु, 
   {{0x213c4a16,0xf748007b,0xa2d000cd,0x00000000}},	//   _abuh_, _الدي_, _भृङ्, --, 
   {{0x442916f1,0x7c2916f2,0xe45c0086,0xd88400f2}},	//   aua_, huer, _erö_, _رهگی, 
   {{0x442916f3,0x7c2916f4,0x73e483f9,0x7dc40077}},	//   bua_, kuer, _номз, bósi, 
   {{0x442916f5,0x7dc40005,0xe2940022,0x7c29059e}},	//   cua_, cósi, _ҵар_, juer, 
   {{0x7c2916f6,0xa3d400dc,0x00000000,0x00000000}},	//   duer, ागः_, --, --, 
   {{0x67e8003d,0xe2940124,0x7c280393,0x00000000}},	//   _iżje, _еар_, euer, --, 
   {{0x7c2916f7,0xdcf801a9,0x108801af,0x00000000}},	//   fuer, _o倉uv_, _мөлк_, --, 
   {{0x7c2916f8,0xadc000fb,0x00000000,0x00000000}},	//   guer, маҫһ, --, --, 
   {{0xfe500598,0x7c2c0419,0x15ec228d,0x00000000}},	//   äçäk_, _ťarc, झदार_, --, 
   {{0x442916f9,0x7c280393,0xdd8c0329,0x7df000de}},	//   zua_, auer, _зш_, _jāsl, 
   {{0x7c2916fa,0x79840280,0xa3d05a30,0x442916fb}},	//   buer, gkkw, _हीन_, yua_, 
   {{0x7c2916fc,0x442801c0,0xab8400cf,0xfc480419}},	//   cuer, xua_, _нукк, tríš_, 
   {{0x442916fd,0x3864110c,0x6b88035a,0x00000000}},	//   vua_, _šorc_, _ulfg, --, 
   {{0xa49800a3,0x4428063f,0x00000000,0x00000000}},	//   _leòt, wua_, --, --, 
   {{0x442916fe,0x67e8031c,0x29d802b5,0x45d40064}},	//   tua_, _ażje, _pūau_, фобс, 
   {{0x09c81971,0x4428a33e,0xb88400d0,0xd91c011a}},	// [19e70] रतीय, uua_, _príš, _הוחל, 
   {{0x442916ff,0xe97000dd,0x398003b2,0xe7b01f0d}},	//   rua_, _آنکھ, _rósi_, _سلجھ, 
   {{0x44291700,0x213c0ac5,0x7c291701,0x7dc400d8}},	//   sua_, _pbuh_, zuer, sósi, 
   {{0x7dc41a36,0x44291702,0xa49801c3,0x00480023}},	//   pósi, pua_, _beòt, _መልክዓ, 
   {{0x44291703,0xc5f4009e,0x7c28003a,0x7f941188}},	//   qua_, _ছিটা_, xuer, мадх, 
   {{0x7c291704,0x00000000,0x00000000,0x00000000}},	//   vuer, --, --, --, 
   {{0x7c2804d1,0x7df0002b,0xc104216b,0x3d082052}},	//   wuer, _vāso, _يوسي, सरले_, 
   {{0x7c291705,0x016401d9,0x00000000,0x00000000}},	//   tuer, _تُرَ, --, --, 
   {{0xda800023,0x7c28003a,0x4c3401c6,0x6e28002f}},	//   _ዝመጸና_, uuer, нээт, aufb, 
   {{0x7c291706,0x7984fca5,0x7df000b8,0x00000000}},	//   ruer, wkkw, _hāsm, --, 
   {{0x7c291707,0x394808a0,0xcda81fae,0x39e8117e}},	//   suer, озно_, _کهنه_, юдно_, 
   {{0x7e60035a,0xd91001d3,0x7df00171,0x00000000}},	//   _irlp, چیں_, _jāsm, --, 
   {{0xd91001ed,0x7aec00a2,0xbb5801fe,0xada000d7}},	//   نیں_, _şatu, _мадх_, šúch, 
   {{0x6e2800d2,0x61f83421,0xa49800a3,0x6b604187}},	//   _úmbí, _čuln, _leòs, _акша, 
   {{0xe73474ac,0xb578117e,0xddc801ef,0x00000000}},	//   ьер_, ощах_, _šiři, --, 
   {{0xe8140574,0x055401c6,0x7df000cd,0x733400ec}},	//   _तिचा_, нтуя, _nāsm, ڀرائ, 
   {{0x64a11708,0x93640022,0x00000000,0x00000000}},	// [19e80] вата, ннаҵ, --, --, 
   {{0xa49801c3,0x232401f0,0x00000000,0x00000000}},	//   _reòt, дофи_, --, --, 
   {{0xa49800a3,0x7dc401d3,0xf50414b3,0x00000000}},	//   _beòs, lósu, _озно, --, 
   {{0x2f080034,0x7df000cd,0xf1d11709,0xea74010f}},	//   _mógł_, _cāsm, төгө, וגער_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x628801e4,0x00000000,0x00000000,0x00000000}},	//   ĝgor, --, --, --, 
   {{0xa2e0035b,0x7c2c01e4,0x2dd40014,0x068000d1}},	//   _аорд, _ĥara, وُتھ_, _ﮬﺎﻟﯩ, 
   {{0x7f4002d0,0x6e280e78,0xeff40092,0x00000000}},	//   _eblq, rufb, ፈለው_, --, 
   {{0x20c1170a,0xa49801ab,0x7e6002d0,0xef180902}},	//   _айтм, _heòr, _erlp, _мма_, 
   {{0xa03004b3,0x7dc402d2,0x00000000,0x00000000}},	//   _جىكت, dósu, --, --, 
   {{0xe45c025a,0x39800162,0x7aec0166,0x7df000b8}},	//   _nyön_, _lósu_, _ğatt, _yāsm, 
   {{0x28680228,0xa49801c3,0x00000000,0x00000000}},	//   орго_, _meòr, --, --, 
   {{0xd7f9170b,0x6ea00303,0x00000000,0x00000000}},	//   дус_, _केतु, --, --, 
   {{0x3728031c,0x00000000,0x00000000,0x00000000}},	//   _སྐྱལ_, --, --, --, 
   {{0x6d5c0134,0xc5f400fe,0x00000000,0x00000000}},	//   _ɔpan, _ছিঙা_, --, --, 
   {{0x03f806ed,0x19a80139,0x00000000,0x00000000}},	//   знај_, _отып_, --, --, 
   {{0x6d41170c,0x7dc4021c,0x95c801af,0xb2c401ec}},	// [19e90] _mboa, móst, фура_, _ﺒﺼﻭﺍ, 
   {{0x7df00055,0x58d80006,0x73c0013d,0x00000000}},	//   _sāsm, _ідэя_, гәсе, --, 
   {{0x6d400158,0x7a340139,0x00000000,0x00000000}},	//   _oboa, _iütç, --, --, 
   {{0xe50400b2,0x7dc5170d,0xa49801c3,0xe7281968}},	//   _تبدي, nóst, _deòr, _اسکو_, 
   {{0x04c80347,0x3f688f8c,0xb4f8011a,0x7df000b8}},	//   _روسي_, зило_, _מפרי, _vāsm, 
   {{0x443800db,0x7e541575,0xa49808c2,0x7e60004e}},	//   _iqs_, етиц, _feòr, _prlp, 
   {{0x53344ec9,0xa49800db,0x4439170e,0x12c401d5}},	//   _шерт, _geòr, _hqs_, _аётг, 
   {{0x7dc4008c,0xa3d00406,0x00000000,0x00000000}},	//   jóst, _हीत_, --, --, 
   {{0x6d4002c4,0xc4bc04c5,0x3b040455,0x00000000}},	//   _dboa, _অণুজ, tblq_, --, 
   {{0xa3bc16f0,0x4fd400a8,0x7df000e2,0x5fa000db}},	//   ँकि_, _ажут, _jāsk, _جەتم, 
   {{0xa2d00574,0x7e600175,0x7a69170f,0x7dc4032e}},	//   भेच्, _urlp, чинг_, fóst, 
   {{0xf9900b73,0x00000000,0x00000000,0x00000000}},	//   ابد_, --, --, --, 
   {{0x44391710,0x7a3403ee,0xe8f412c4,0xe45c023a}},	//   _nqs_, _bütç, эля_, _syön_, 
   {{0x6d400311,0x0c8409a5,0x398003f2,0x6440054e}},	//   _zboa, _шыхм, _rósu_, ănil, 
   {{0x7bc02b1d,0x2490001f,0x443801d5,0x3c38033b}},	//   molu, _መመለስ_, _aqs_, lèv_, 
   {{0x7bc11711,0xc3080183,0x398000a3,0xab7000c7}},	//   lolu, _লাগি_, _cóst_, _агәш, 
   {{0xa4980013,0xb3e801d3,0x3c3802e2,0x69ac0073}},	// [19ea0] _seòr, سٹال_, nèv_, ीवरी, 
   {{0xe45c02f6,0x7bc11712,0xa854011a,0x00000000}},	//   _työn_, nolu, _טיפה_, --, 
   {{0xe9701129,0x3124247f,0xb6a435e3,0x44380f85}},	//   _شهید, едег, _чинл, _eqs_, 
   {{0x7bc11713,0x00000000,0x00000000,0x00000000}},	//   holu, --, --, --, 
   {{0x92c0015b,0xfbb01223,0x9f9801f4,0x00000000}},	//   ঁধে_, ीकाम, kääs_, --, 
   {{0xa4991714,0x3c380100,0x00000000,0x00000000}},	//   _teòr, dèv_, --, --, 
   {{0x1dc801b0,0xade40124,0xdc9c00b5,0xb640037e}},	//   ातंत, нцик, _hd版_, _ｍｗ_, 
   {{0xdd951715,0x3c38007f,0x7dc400e5,0x00000000}},	//   ешь_, fèv_, dóss, --, 
   {{0x4c95116b,0x7bc11716,0x3c3802e2,0x7cf4032e}},	//   типс, folu, gèv_, _sýró, 
   {{0x09c818ea,0xa0a11717,0x7bc11718,0x7aec0356}},	//   रत्य, _сауд, golu, _şatr, 
   {{0xe7f000af,0x28d001ad,0x00000000,0x00000000}},	//   _इंहा_, _सरहि, --, --, 
   {{0x67e8025c,0xec78084c,0x7a3403e0,0x00000000}},	//   _ażja, _нпе_, _sütç, --, 
   {{0x7bc11719,0xa2a46859,0x398003b2,0x2984008e}},	//   bolu, _टेन्, _róst_, _җыйг, 
   {{0x7bc1171a,0x28680107,0x398002d2,0x7dc4e81d}},	//   colu, орҳо_, _sóst_, sóst, 
   {{0x9a78015b,0x7dc4008c,0x7b640014,0x398001a8}},	//   _нιѕт_, póst, _جانٕ, _póst_, 
   {{0x79c4035b,0xe8e800f1,0xd944009b,0xc4e00150}},	//   _ирыҵ, _عربو_, _бећи, _ﻋﻭﺍﺌ, 
   {{0x2e380036,0x44380129,0x833402e8,0x7a340139}},	// [19eb0] hëf_, _qqs_, кнах, _tütç, 
   {{0xe9dc01d3,0x62940175,0x2e380200,0x5334068e}},	//   lmú_, tzxo, këf_, леут, 
   {{0x2e380de2,0x3c38033b,0x53440006,0xe9dc0332}},	//   jëf_, zèv_, ыхта, omú_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd7740214,0x7bc1171b,0x44380009,0xc0c40022}},	//   _شایع, yolu, _uqs_, тәви, 
   {{0xbea41773,0xa49801e1,0x32180280,0x96182e07}},	//   калк, _afòg, bspy_, _تغیر_, 
   {{0x7df000ef,0x7db400d4,0x5e601c3e,0x00000000}},	//   _kāsi, ксиц, انبە, --, 
   {{0x4429171c,0x7bc1171d,0xe9dc0419,0x7df00171}},	//   ora_, wolu, jmú_, _jāsi, 
   {{0x4429171e,0x6c30007b,0x7df1171f,0x9f9801f4}},	//   nra_, لفيا, _māsi, tääs_, 
   {{0x3864000a,0x7bc02139,0xdb211720,0x61f8107d}},	//   _šoro_, uolu, دودی, _čulj, 
   {{0x44291721,0xe80c033f,0xa2a4072a,0x00000000}},	//   hra_, ़ीसा_, _टेम्, --, 
   {{0x7bc11722,0xc0d40023,0x7df000cd,0x00000000}},	//   solu, ርግር_, _nāsi, --, 
   {{0x44291723,0x9f9800c5,0xceb40213,0x3b780166}},	//   jra_, pääs_, şət_, _ойдэ_, 
   {{0x44291724,0x7d091725,0x7c2817f9,0xdaa00131}},	//   dra_, lbes, mrer, _مەخپ, 
   {{0x65b01f21,0x67340175,0x00000000,0x00000000}},	//   għho, _dcxj, --, --, 
   {{0x44284e07,0x7d091726,0x7c291727,0xf864764a}},	//   fra_, nbes, orer, _авио, 
   {{0x44291728,0x777c06be,0x00000000,0x00000000}},	// [19ec0] gra_, _topx, --, --, 
   {{0x7c291729,0x7d08002f,0x67d0119e,0x00000000}},	//   irer, hbes, _коњу, --, 
   {{0x4429172a,0x7c280639,0x7d08f498,0x6570002d}},	//   ara_, hrer, kbes, êdhû, 
   {{0x7c280ec3,0x42540006,0x00000000,0x00000000}},	//   krer, ытут, --, --, 
   {{0x7c29172b,0x00000000,0x00000000,0x00000000}},	//   jrer, --, --, --, 
   {{0x7d09172c,0x7dd400c0,0xe9dc0419,0x28980115}},	//   ebes, _išsy, zmú_, וינא, 
   {{0x7c29172d,0x7d08fc85,0xdce40055,0x00000000}},	//   erer, fbes, _āmār, --, 
   {{0x6ce41c26,0x7d09172e,0x7c280798,0x2e3801c7}},	//   кіпе, gbes, frer, rëf_, 
   {{0xc0447405,0x63c402d2,0x00000000,0x00000000}},	//   _مخلو, _örná, --, --, 
   {{0x3dcc022f,0x4a540cb9,0x7d080036,0x6f7c00d1}},	//   alew_, гкос, abes, ﯩﺰﻏﺎ_, 
   {{0x44281675,0x7c29172f,0x3dcc031c,0x00000000}},	//   zra_, arer, blew_, --, 
   {{0x44291730,0x63b801e4,0x09bc07f7,0x7d1c03b2}},	//   yra_, _ƭunk, ईवेय, ósst, 
   {{0xe9dc0005,0x7c280129,0xd8380209,0x44280003}},	//   rmú_, crer, кэр_, xra_, 
   {{0xe9dc00d0,0xaa645740,0x7df00055,0x00000000}},	//   smú_, _атик, _sāsi, --, 
   {{0x44291731,0xb8c87f1a,0x7df054bb,0x2b9040ec}},	//   wra_, _गे_, _pāsi, _میکس, 
   {{0x44291732,0xdcf807f5,0x7dc400e4,0xdcec002b}},	//   tra_, rkuć, nósp, _ādīp, 
   {{0x44280e8a,0xdcf80552,0x7df000cd,0x00000000}},	// [19ed0] ura_, skuć, _vāsi, --, 
   {{0x7dc404d4,0x7d091733,0x875400d4,0x2b5c0051}},	//   hósp, zbes, _скоє, ndtc_, 
   {{0x44291734,0x6378025a,0x91f4007b,0x65b00327}},	//   sra_, _kînz, لأنا, qħho, 
   {{0x7c282d75,0x673805ce,0x8fc4fb62,0x5ed00131}},	//   yrer, đuju, یزون, ﻟﺘﯜﺭ, 
   {{0x44291735,0x656d1736,0x69cc1cf8,0x7df000ef}},	//   qra_, _inch, ilce, _jāsv, 
   {{0x7c291737,0x2d811738,0x7d0801a4,0x69cc013a}},	//   vrer, öken_, wbes, hlce, 
   {{0x2908020b,0x0fe40228,0x670002e3,0x12e400c0}},	//   kbca_, рөтү, ọkwu, _вітг, 
   {{0x7c291739,0x7d080549,0x69cc0010,0x00000000}},	//   trer, ubes, jlce, --, 
   {{0x7c281347,0x3dcc0076,0x7df00055,0x00000000}},	//   urer, rlew_, _nāsv, --, 
   {{0x7c29173a,0x656c010a,0xd01001ed,0x69cc7f17}},	//   rrer, _lnch, _گلے_, elce, 
   {{0x656d173b,0x7d080d47,0xefb00d73,0xceb40213}},	//   _onch, pbes, _دیوگ, şər_, 
   {{0x7c29173c,0x05140154,0x00000000,0x00000000}},	//   prer, িলুর_, --, --, 
   {{0xbb448fba,0xa9a00724,0x3154008f,0x7df000b8}},	//   _белк, сияд, נישן_, _cāsv, 
   {{0x656d173d,0x69cc0010,0x33f401d5,0x00000000}},	//   _anch, alce, ғчас, --, 
   {{0x7a68009d,0xaa54009b,0x00000000,0x00000000}},	//   _чийг_, _бију_, --, --, 
   {{0x656c0076,0xe5a1173e,0xb2240032,0x5ed00131}},	//   _cnch, биси, ҫмал, ﻟﺘﯘﺭ, 
   {{0xd3a407dd,0xb4643395,0x2bf400c8,0xd9443500}},	// [19ee0] алақ, ыкал, ָמען_, _беқи, 
   {{0x69dcb56d,0x656c3046,0x25bc0419,0xe45c01f4}},	//   _èper, _ench, čula_, _myöh_, 
   {{0x201c0372,0x35a5173f,0x656c00e4,0xb2240006}},	//   _avui_, _банг, _fnch, умел, 
   {{0xfa240154,0xd1300137,0xa11006c2,0x00000000}},	//   _বহাল_, تۅر_, مومت, --, 
   {{0xa0651740,0x91d400d1,0x7df00055,0x00000000}},	//   лаца_, ﯘﭼﯩﻼ, _māsu, --, 
   {{0xa3cc0b02,0xa854011a,0x31c401ec,0x53b887ea}},	//   शतः_, טינה_, _ﯨﺸﯩﻜ, _आदिश, 
   {{0x69cc1c42,0x7c2c05ac,0x656c0857,0x00000000}},	//   ylce, _åarj, _ynch, --, 
   {{0x7df000b8,0xb0141291,0x75340432,0x00000000}},	//   _nāsu, _مورث, ngyz, --, 
   {{0xaf340ec9,0xdc8401c0,0x61f807f5,0xab851741}},	//   _مرات, гсэл_, _čuli, гунк, 
   {{0xafe405bc,0xe45408a8,0x69f0004e,0x00000000}},	//   _созл, נייט_, бүкт, --, 
   {{0xdd8c021a,0x63780356,0x2b5c0175,0x6fd815e0}},	//   _ډول_, _pînz, rdtc_, _पीयू, 
   {{0x7df000b8,0xaf740092,0xfe6c009f,0x00000000}},	//   _cāsu, ሪዎችና_, _آگو_, --, 
   {{0x984822d7,0xdca0a20e,0x7d1c0321,0x6378054e}},	//   ляра_, _лаци, ðsse, _vînz, 
   {{0xa3d00b7d,0x00000000,0x00000000,0x00000000}},	//   _हीं_, --, --, --, 
   {{0x56951742,0x5b2000e3,0xda6c3eeb,0x0a5801f0}},	//   барт, _طفيل, _уя_, _райъ_, 
   {{0x55583bb3,0xdb00004e,0x5694e58b,0x68fc022e}},	//   лася_, _amnè, щаст, _ufqd, 
   {{0x7c2c0115,0x7df000b8,0x00000000,0x00000000}},	// [19ef0] _ĥark, _hāst, --, --, 
   {{0x4ad805f9,0x0514015b,0x7df00055,0x9cd4011a}},	//   _डराव, িলের_, _kāst, רומה_, 
   {{0x6680036b,0x7df000e2,0xa6a80133,0x45d400d8}},	//   _ایزل, _jāst, _سادق_, _вонс, 
   {{0x656c1bb7,0x7df024b8,0xd2582b61,0x00000000}},	//   _unch, _māst, ыцу_, --, 
   {{0x7df000de,0x4ad8000d,0x00000000,0x00000000}},	//   _lāst, _डरऽव, --, --, 
   {{0x7a0002b1,0x1ee400f2,0x57fc00df,0x00000000}},	//   _hēte, هوشی_, עלוו, --, 
   {{0x7df00882,0xc694008f,0x00000000,0x00000000}},	//   _nāst, יאַ_, --, --, 
   {{0x614005a9,0xaa8400a2,0x00000000,0x00000000}},	//   _دىرە, _maýı, --, --, 
   {{0xff2404fb,0xaa8400a2,0x7a011743,0x0d640588}},	//   _نبای, _laýı, _mēte, сныҟ, 
   {{0x4e840014,0x7df000b8,0x1ea800ec,0x00000000}},	//   _گٔمٕ, _sāsu, _ٻائي_, --, 
   {{0xa2c83a19,0x8d749a99,0x7df000cd,0x4aa8000d}},	//   _तुम्, _گالا, _cāst, _छेदव, 
   {{0x4e94007b,0xe11003d4,0xf864117e,0x00000000}},	//   _اشكر, _হাঁহ_, авмо, --, 
   {{0xeb8d1744,0x8d744c2d,0xa2a469af,0xdb200799}},	//   _ди_, _دالا, _टेस्, _هوشی, 
   {{0x637800d2,0xba7402f2,0xb8dc2c30,0xa2c800cd}},	//   _tîny, _نابت, _आश_, _तुभ्, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x75351745,0xdb011746,0x74e801c0,0x12f400d1}},	// [19f00] rgyz, _amné, тдаг_, متاھ, 
   {{0xb6a51747,0x09cc0183,0xb4e40412,0x7df000b8}},	//   _виол, _ৰূপা, _पणी_, _yāst, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69c40427,0x7a000171,0xf064033a,0x00000000}},	//   čkeg, _gēte, икеп, --, 
   {{0x6d9c00b0,0xa15400c7,0xafe40798,0x00000000}},	//   kūar, рэхә, аодл, --, 
   {{0x79940cfd,0x5f900640,0x75800032,0x00000000}},	//   _llyw, жишт, _уңға, --, 
   {{0x926401d9,0x7994e7d9,0x71240014,0x00000000}},	//   _دۯام, _olyw, _پرزل, --, 
   {{0xfcdc1772,0x300402bf,0x7df00055,0x00000000}},	//   _ዓመጽ_, _взаг, _rāst, --, 
   {{0xef1800c7,0x245c037e,0x7df000b8,0x00000000}},	//   _амз_, のmt_, _sāst, --, 
   {{0x79951748,0x1cdc0327,0x7df00055,0x7fd400c0}},	//   _alyw, སྟེ_, _pāst, _ліхі, 
   {{0xdd8d1749,0x799405e4,0xc1c801d9,0xdb2002d2}},	//   _дш_, _blyw, _شبہٕ_, _þrýt, 
   {{0x799400a9,0x27fc0077,0x6ce410da,0x2fdc0051}},	//   _clyw, íuno_, _кіле, _hhtg_, 
   {{0xec141de6,0xe97000e5,0x00000000,0x00000000}},	//   _телә_, منگھ, --, --, 
   {{0x799402d0,0x7df000b8,0x8c0c00eb,0x00000000}},	//   _elyw, _tāst, _শিপন_, --, 
   {{0x79940b1d,0x7a01174a,0x62180220,0x7c2c01e4}},	//   _flyw, _pēte, _ءﺍﺭﻯ_, _ĥari, 
   {{0x44f4e857,0x79940368,0x89380452,0x38ac0022}},	//   спас, _glyw, _спис_, ẽra_, 
   {{0xe4e410f5,0x84c4a705,0x186800f3,0x00000000}},	// [19f10] рівн, сәнд, _вањи_, --, 
   {{0x4735174b,0x7a000374,0xe2a801ed,0xe7c800ec}},	//   _унос, _wēte, پائن_, _جذبو_, 
   {{0x7a000053,0x00000000,0x00000000,0x00000000}},	//   _tēte, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbb381c5c,0x7df00055,0xfff8187c,0xd7d40133}},	//   ﯕﮕﻮ_, _nāsr, اکرت_, _دڵێک, 
   {{0x50c40372,0x1ee400f1,0xfcdc1ef7,0x00000000}},	//   ڭقۇك, ټوبی_, _ዓመጻ_, --, 
   {{0x42e40c58,0xce180953,0x81d40117,0x00000000}},	//   _প্ৰশ, ацыі_, _говх, --, 
   {{0x56b80302,0x439402f4,0x814400f1,0xa3cc134e}},	//   יפון_, _таҳс, _دپرم, शतक_, 
   {{0xbb441411,0xe1f40150,0x7df00055,0x65b00327}},	//   бепк, _اﻗﯩﺮ, _cāsr, għhi, 
   {{0x6b99174c,0x60d8105c,0xd1dc0b82,0xdb20010e}},	//   ghtg, _izum, _ዕለተ_, _örüs, 
   {{0x39e81c13,0x3ed5174d,0x7994045a,0x00000000}},	//   лдоо_, _اقار, _plyw, --, 
   {{0x3f84032e,0x798c031c,0x00000000,0x00000000}},	//   _holu_, _ċaws, --, --, 
   {{0x3f85174e,0x7d19174f,0x2b9000d2,0xfc04023a}},	//   _kolu_, _iews, _gâco_, _упло, 
   {{0x6b991750,0x7d180618,0x60d801c8,0xc79401ee}},	//   chtg, _hews, _mzum, орсы, 
   {{0x3f851751,0x644c005f,0x89a80d62,0x00000000}},	//   _molu_, _apci, _چھُہ_, --, 
   {{0x3f851752,0xe5a11753,0x7d18007f,0x9f5c0c86}},	//   _lolu_, писи, _jews, _stuì_, 
   {{0x60d91754,0x3f84198f,0xc8240022,0x53846518}},	// [19f20] _nzum, _oolu_, _дзық, овағ, 
   {{0xb660044e,0x7d1802c4,0x3f851755,0x00000000}},	//   _ትግርኛ_, _lews, _nolu_, --, 
   {{0x60d91756,0x644c0789,0xa7600166,0x31080139}},	//   _azum, _epci, _экэд, гнеп_, 
   {{0x765d1757,0x7d191758,0x61b4085c,0xf118007b}},	//   _ispy, _news, _अदृष, اغات_, 
   {{0x9f5c0093,0x8f84036b,0xb5c80014,0x6fd40129}},	//   _etuí_, оқал, _لوگم_, bâcl, 
   {{0x60d81399,0x3f840841,0xceb00451,0x6440054e}},	//   _dzum, _colu_, وڙا_, ănit, 
   {{0x3f851759,0x60d800b4,0xa06401e0,0x9e0000db}},	//   _dolu_, _ezum, _һата_, пчыл, 
   {{0x008430cb,0xdd95175a,0x6141175b,0x7124036b}},	//   скәү, йшы_, _неса, _درسل, 
   {{0x3f8401fa,0xe0d40139,0xa0640354,0x50dc00bc}},	//   _folu_, _гвт_, _лата_, _बरिष, 
   {{0x69dc044e,0x3f85175c,0x256c013d,0x5fdc28d4}},	//   _shqe, _golu_, _kölä_, _पीपल, 
   {{0x2b90019f,0xef180022,0xada400d8,0xe378010f}},	//   _wâco_, _амҷ_, _лажл, אריר, 
   {{0x6f180165,0x3f8401e2,0xadb40137,0x6b98022e}},	//   _hetc, _zolu_, _دۇبا_, shtg, 
   {{0x3f842c6f,0x6f19175d,0x5fa00345,0x00000000}},	//   _yolu_, _ketc, _بڕۆم, --, 
   {{0x0a941c26,0x3f841bce,0x00000000,0x00000000}},	//   _малю, _xolu_, --, --, 
   {{0xa14000da,0x2d840270,0xdce800b0,0x7d0c054e}},	//   šķir, _kooe_, _ingā, _însâ, 
   {{0x6f19175e,0x9a81175f,0x7df000e2,0x00000000}},	//   _letc, _хушл, _jāsp, --, 
   {{0x2d840270,0x765d1760,0x6fb808a3,0xf8b401c4}},	// [19f30] _mooe_, _espy, ेवां, _дөр_, 
   {{0x6f191761,0x7a0002b1,0x2d8401ab,0x00000000}},	//   _netc, _hēta, _looe_, --, 
   {{0x7a0002b1,0x3f851762,0x60d80c57,0x29180200}},	//   _kēta, _rolu_, _szum, _keqa_, 
   {{0x3f840c95,0x2d8401ee,0x409408c9,0x764401d9}},	//   _solu_, _nooe_, يلار, _گیہِ_, 
   {{0x7a0002b1,0xdce8025c,0x3f851763,0x29191764}},	//   _mēta, _ilgħ, _polu_, _meqa_, 
   {{0x3f68016c,0x291803b4,0xd2f80139,0x764401d9}},	//   рико_, _leqa_, _герц_, _دیہِ_, 
   {{0x3f851765,0x256c00a2,0xfd10007b,0x26d001ef}},	//   _volu_, _gölä_, وجة_, _jyxo_, 
   {{0x23611766,0x7dc400dd,0x7a0000b0,0x60d8002d}},	//   _hajj_, lósz, _nēta, _tzum, 
   {{0x60d91767,0x3f851768,0xf4000356,0x6f1826e7}},	//   _uzum, _tolu_, _guţă_, _fetc, 
   {{0x6f180354,0x3a240828,0xba24af08,0xa378002b}},	//   _getc, омог, одок, _puõy, 
   {{0x2d840770,0x29180481,0x7d1800a2,0xf98816a2}},	//   _fooe_, _beqa_, _tews, لندي_, 
   {{0xdce800b0,0x236000e8,0x6f18009a,0xbc74104c}},	//   _engā, _lajj_, _zetc, _وهاب, 
   {{0xe45c426d,0x88cc0154,0x00000000,0x00000000}},	//   _myös_, রেসক, --, --, 
   {{0x1af0015b,0x9ba00137,0x00000000,0x00000000}},	//   _আজকে_, _رەجى, --, --, 
   {{0x41c91769,0xc9d400f1,0x00000000,0x00000000}},	//   िकास, _ډموک, --, --, 
   {{0xdcf807f5,0x50500092,0x66e001a9,0x00000000}},	//   kjuč, _መፍጠሩ, фоса, --, 
   {{0x28101a59,0x2eb497ad,0xb3847e09,0x765c00a2}},	// [19f40] _قويس, _अख्त, олал, _wspy, 
   {{0x213c0a2e,0xdb00003a,0xe45c0205,0x7aec010e}},	//   _acuh_, _omní, _dsö_, _şaty, 
   {{0x0b340020,0x2918014b,0x80d00183,0xe45c005b}},	//   _በአብዛ, _yeqa_, তেম্, _syöt_, 
   {{0xceb8052f,0x6f19176a,0xc0e8001f,0x64400356}},	//   ҙҙе_, _setc, _ህመም_, ănir, 
   {{0x6f19176b,0xceb801e0,0x00000000,0x00000000}},	//   _petc, әҙе_, --, --, 
   {{0xe45c0108,0x15cc02dd,0x8e2001ec,0x00000000}},	//   _vyöt_, _ﺒﻌﻀﻬ, сiп_, --, 
   {{0x6f1914b7,0x59bc024a,0x00000000,0x00000000}},	//   _vetc, ोकार, --, --, 
   {{0x23600472,0xe45c023a,0xf1a80133,0xd39800fb}},	//   _zajj_, _työt_, _ئاسه_, _тәғә_, 
   {{0x6f182a89,0xa290110e,0x7a000171,0x602000d8}},	//   _tetc, _lọ́n, _rēta, _одта, 
   {{0x31640004,0x7a0109d5,0x1be40063,0x00000000}},	//   ldoz_, _sēta, одњи_, --, 
   {{0x2d8401ee,0xa04802d3,0x2918f06e,0xed58084c}},	//   _tooe_, _ሓርነታ, _peqa_, _вое_, 
   {{0xbb300075,0x3165176c,0x398002d2,0x7dc400e5}},	//   ﺭﻧﻰ_, ndoz_, _kósy_, zósz, 
   {{0xab840454,0x00000000,0x00000000,0x00000000}},	//   _мукк, --, --, --, 
   {{0x29180117,0x7a0004fe,0x7aec00df,0xdce800e2}},	//   _weqa_, _wēta, _ŝate, _ungā, 
   {{0x7a001243,0x67540214,0x25a80114,0xdb34011a}},	//   _tēta, میکس_, ађан_, _ונוח_, 
   {{0x6281176d,0xa2c800dc,0x00000000,0x00000000}},	//   änom, _तुष्, --, --, 
   {{0x6fc8bfc8,0x947400c6,0x7dc401ed,0x236000e8}},	// [19f50] ाकां, ودكا, tósz, _pajj_, 
   {{0x9f5c03c1,0x98a0031c,0x937800d4,0x00000000}},	//   _otuá_, _sbiħ_, обут_, --, 
   {{0x41547579,0x45d5176e,0x9f400ca8,0x7dc501b4}},	//   звес, _ноос, _òjé_, rósz, 
   {{0x6fd4004a,0x2360002e,0xd174010b,0x7dc400e5}},	//   lâch, _wajj_, дышы, sósz, 
   {{0xa2c86c8e,0xe45c007c,0xb880013a,0xa51401f9}},	//   _तुर्, _usö_, _žízn, तरीच_, 
   {{0xa3d00490,0x4fa40014,0x5338030d,0x00000000}},	//   _हीच_, وٕنٕ, _мусă, --, 
   {{0x7d1c0008,0x8cd00210,0x00000000,0x00000000}},	//   ðsso, _डुबो, --, --, 
   {{0x3a2801e4,0x1154004e,0xfbd03fe6,0x00000000}},	//   _ĉap_, _оксю, کتب_, --, 
   {{0x918403cc,0x33b000db,0xfc305a07,0x6f7400cf}},	//   _تۇنۇ, _تەەر, رحة_, تەەر_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x80b007f7,0x8e74009f,0x68f80419,0x00000000}},	//   _आइडे, _يامض, ľudn, --, 
   {{0xc7a80375,0xe3c000eb,0x00000000,0x00000000}},	//   _גב_, ্গিব, --, --, 
   {{0xf9880451,0x6280005b,0x6cf8011a,0xfc0401a9}},	//   لنگي_, änoj, _הפנס, _эпло, 
   {{0xfaa4e9d4,0xcb680c8b,0x31640369,0x00000000}},	//   _нало, _ومنه_, zdoz_, --, 
   {{0xa2c82f2e,0xe3c0015b,0x00000000,0x00000000}},	//   _तुल्, ্গাব, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x5fc820f0,0xe4c041e5,0xb6000077,0x7a1001ef}},	// [19f60] िवाल, ейти, ñába, _dětř, 
   {{0x03a800f1,0x00000000,0x00000000,0x00000000}},	//   يدلو_, --, --, --, 
   {{0xe714025f,0x9694179e,0x00000000,0x00000000}},	//   _מחיר_, _غیرش, --, --, 
   {{0x0f140d0a,0x8e2002dd,0xc0d40023,0x00000000}},	//   डर्स_, сiн_, ርግሕ_, --, 
   {{0x31644d20,0xaf50151e,0x00000000,0x00000000}},	//   rdoz_, енлә, --, --, 
   {{0xdfcc00b2,0xa2a44721,0x00000000,0x00000000}},	//   هين_, _टेक्, --, --, 
   {{0xaff401ed,0x9f0000db,0x7a000171,0x00000000}},	//   _کہتا_, رويو, _sētn, --, 
   {{0x7a00005f,0x6ca41214,0x66e43e3b,0x00000000}},	//   _pētn, зрож, léké, --, 
   {{0xa0a00209,0x00000000,0x00000000,0x00000000}},	//   _затд, --, --, --, 
   {{0x66e40098,0x25bc0419,0xbf7001ec,0xceb82a9d}},	//   néké, čuli_, _ақшы, _мәй_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe6d4022c,0x00000000,0x00000000,0x00000000}},	//   ítíð, --, --, --, 
   {{0x6d400276,0x5d800214,0x6fd40129,0x00000000}},	//   _icoa, _سلول, tâch, --, 
   {{0x8a1800f3,0x00000000,0x00000000,0x00000000}},	//   _докс_, --, --, --, 
   {{0x45d5176f,0x7c2c03cd,0x66e400e5,0x00000000}},	//   довс, _åarr, déké, --, 
   {{0x6b891770,0x00000000,0x00000000,0x00000000}},	//   _hofg, --, --, --, 
   {{0x69cd1771,0x66e400e8,0x7a1001ef,0xc0d40023}},	// [19f70] moce, féké, _větř, ርግሖ_, 
   {{0x050c0154,0xe66401d5,0x00000000,0x00000000}},	//   ষণের_, _етмо, --, --, 
   {{0x6b8801ab,0x6d400857,0x462401a9,0x8e205e82}},	//   _mofg, _ocoa, _ўчоғ, сiм_, 
   {{0x69cd1772,0x7e600175,0x6b891773,0x00000000}},	//   noce, _rslp, _lofg, --, 
   {{0x6b880a40,0x94a80064,0x00000000,0x00000000}},	//   _oofg, _етра_, --, --, 
   {{0x69ccd981,0xcf240131,0x00000000,0x00000000}},	//   hoce, ىرىي, --, --, 
   {{0x69cd1774,0x00000000,0x00000000,0x00000000}},	//   koce, --, --, --, 
   {{0x6d400223,0x7c944c6b,0x200c0fac,0xc0d40023}},	//   _ccoa, дроц, ppgi_, ርግሑ_, 
   {{0x69cd1775,0x3f800267,0x16040073,0x7a000171}},	//   doce, öhus_, _शंभर_, _pēto, 
   {{0x6b880042,0x23bc00dc,0x4fc411dc,0x8fa400f3}},	//   _cofg, ्विद, _كەنە, _зађе, 
   {{0x69cd1776,0x6280005b,0x69c40010,0x39e80395}},	//   foce, änoh, čken, ждно_, 
   {{0x69cd1777,0x2d811778,0x00000000,0x00000000}},	//   goce, öket_, --, --, 
   {{0x23bc0882,0xa3bc1b77,0xa9a11779,0x6b89177a}},	//   ्वाद, ुका_, тияд, _fofg, 
   {{0x6b880042,0x6e340248,0x00000000,0x00000000}},	//   _gofg, _ìgbò, --, --, 
   {{0x69cd177b,0x6320015b,0xe64000db,0x00000000}},	//   boce, মলায়_, керп, --, 
   {{0x69cd177c,0x2cb00153,0x00000000,0x00000000}},	//   coce, _žydi_, --, --, 
   {{0x579400c7,0x66e401d3,0x00000000,0x00000000}},	// [19f80] _зынӡ, téké, --, --, 
   {{0xd37019c5,0x00000000,0x00000000,0x00000000}},	//   دۇس_, --, --, --, 
   {{0x66e47c70,0x35a5177d,0xb14410fc,0x00000000}},	//   réké, _жанг, днел, --, 
   {{0x387003cd,0xdb08032e,0xa11006c2,0x64600108}},	//   _kryr_, _óhæf, نومت, äviä, 
   {{0x50340023,0x39500200,0x05bc00bc,0x00000000}},	//   _ኣይካኣ, _mbys_, ्करब, --, 
   {{0x6d41177e,0x5034044e,0x69cd177f,0xc6480244}},	//   _scoa, _ኣይከኣ, zoce, _بجیل_, 
   {{0x69cd1780,0x6b891781,0x2244084c,0xfd540055}},	//   yoce, _rofg, _опри_, _hyaṃ, 
   {{0x71751782,0x6b88083a,0x610400b5,0x2244002e}},	//   _تهرا, _sofg, _ｓlif, ànke_, 
   {{0xe0402c23,0x69cd1783,0x3ea8010f,0x00000000}},	//   _инти, voce, ĝata_, --, 
   {{0x7aec00c8,0x39500118,0x3ea80115,0x00000000}},	//   _ŝata, _abys_, ŝata_, --, 
   {{0xdea015b4,0x00000000,0x00000000,0x00000000}},	//   _لیوی, --, --, --, 
   {{0x38702ff9,0x00000000,0x00000000,0x00000000}},	//   _bryr_, --, --, --, 
   {{0x69cd1784,0xb9100882,0x00000000,0x00000000}},	//   roce, nyaṃ_, --, --, 
   {{0x395000d7,0x48c40166,0x84941954,0x00000000}},	//   _ebys_, _җәма, _ግርማን_, --, 
   {{0xb9100882,0xfd5400b8,0x3870015d,0x97a4011c}},	//   hyaṃ_, _ayaṃ, _eryr_, трял, 
   {{0xb9100882,0x25ac04cc,0x45d40229,0x9f4400d7}},	//   kyaṃ_, ògl_, хобс, rmné_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [19f90] --, --, --, --, 
   {{0x6dc00055,0x00000000,0x00000000,0x00000000}},	//   _ḍala, --, --, --, 
   {{0x227411fc,0xe3c02aab,0x7d1c041e,0x4118007b}},	//   بلاگ_, ্গলব, ðssk, كياج_, 
   {{0x3d0c00c5,0x00000000,0x00000000,0x00000000}},	//   _सभें_, --, --, --, 
   {{0x7ff407a7,0x61e8002f,0x7fd443e1,0x00000000}},	//   ىستا, rmgl, нікі, --, 
   {{0x44291785,0xdc2c0882,0xca68022e,0x818c01ec}},	//   msa_, jñāy, yadа, _ﺒﻀﻌﺔ_, 
   {{0x442894ab,0x5334026a,0x50340023,0x1cdc0327}},	//   lsa_, _јест, _ኣይክኣ, སྟན_, 
   {{0xbc651786,0x5f7405d9,0xd13801c0,0x58fc031c}},	//   евик, _ڪارر, _оху_, _དཔེས_, 
   {{0x4429074e,0xb91000cd,0x00000000,0x00000000}},	//   nsa_, cyaṃ_, --, --, 
   {{0x44291787,0x2d8004f3,0x00000000,0x00000000}},	//   isa_, öker_, --, --, 
   {{0x80d000fe,0x7df000ef,0x8eb000d1,0x0ba81411}},	//   তেশ্, _māsz, _پەيت, بايى_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x66e001d5,0x80d000cc,0x25f0012d,0x8b641291}},	//   ғота, _তৃত্, ंगनी_, رایم, 
   {{0x7d091788,0x44291789,0xbb444a2f,0xbb8400ae}},	//   lces, dsa_, _чекк, _سلبي, 
   {{0x7c29178a,0x79801df2,0xb6a416c0,0x7d0804cc}},	//   lser, ﯨﯖﯩﺰ_, хивл, oces, 
   {{0x4429178b,0x7415178c,0x7d081486,0x7c29178d}},	//   fsa_, فورا, nces, oser, 
   {{0x7c29178e,0x64a1178f,0xb4e80574,0x7d091790}},	// [19fa0] nser, гата, मधे_, ices, 
   {{0xb9100a28,0xf2e4004b,0x7d082ca8,0xfd5400b8}},	//   vyaṃ_, ېکړه_, hces, _vyaṃ, 
   {{0x7d08f084,0xeb94010f,0x6dc00055,0x00000000}},	//   kces, עדער_, _ḍama, --, 
   {{0x44291791,0x7d0805a1,0xb9100a28,0x39400280}},	//   bsa_, jces, tyaṃ_, ngks_, 
   {{0x44291792,0x7c2800b5,0x00000000,0x00000000}},	//   csa_, jser, --, --, 
   {{0x7c291793,0x7d081730,0xb9100882,0xa2c82208}},	//   dser, eces, ryaṃ_, _तुक्, 
   {{0xa2e11794,0x7c281730,0xa3bc94f7,0x59e00254}},	//   _борд, eser, ुकर_, नतार, 
   {{0xfcf00020,0x7c291795,0x65b8023a,0x7df000b8}},	//   _ግልጽ_, fser, mähä, _kāsy, 
   {{0x7c284ba8,0x6280af45,0xdb000267,0x7df00055}},	//   gser, änov, _omnä, _jāsy, 
   {{0x69c400f3,0x00000000,0x00000000,0x00000000}},	//   čkem, --, --, --, 
   {{0x7c291796,0x26040115,0xed5817a2,0x4428f9c2}},	//   aser, _aĵon_, _нож_, zsa_, 
   {{0x44291797,0x7d091798,0x65a0000d,0x00000000}},	//   ysa_, cces, _kõhe, --, 
   {{0x44291799,0x7c2801ed,0x7df000cd,0x00000000}},	//   xsa_, cser, _nāsy, --, 
   {{0x4428819e,0x5c944077,0x65b8023a,0xeb4800ec}},	//   vsa_, _якія_, kähä, _رشتو_, 
   {{0x4429179a,0x65a000c5,0x21e40037,0x65b801f4}},	//   wsa_, _lõhe, lõhe_, jähä, 
   {{0x4429179b,0xd008015b,0xa3b005d7,0x80b00210}},	//   tsa_, রীয়_, जोन_, _आइले, 
   {{0x44f41c3e,0x8e200046,0x84c4446e,0x7df00882}},	// [19fb0] тпас, тiк_, тәнд, _cāsy, 
   {{0x7d09179c,0x7df000dc,0x6b98f49e,0x7a0000ef}},	//   zces, _dāsy, nktg, _bēth, 
   {{0x4429179d,0x6725179e,0x290819f5,0x7d086af6}},	//   ssa_, majj, occa_, yces, 
   {{0x5185179f,0x7c2917a0,0x672517a1,0xe164516c}},	//   луча, yser, lajj, عداي, 
   {{0x442917a2,0x3f68573e,0x00000000,0x00000000}},	//   qsa_, дило_, --, --, 
   {{0x101517a3,0x672517a4,0x2604000d,0x5f750b6a}},	//   ابند, najj, _kõo_, عاشر, 
   {{0x7c2917a5,0x925917a6,0xa0740588,0x69c40118}},	//   wser, _парт_, ьыҧш, čkej, 
   {{0x7c2917a7,0x672517a8,0x7aec00df,0xdb0c0213}},	//   tser, hajj, _ŝato, şdüy, 
   {{0x7d0917a9,0x67240a49,0x7c2817ce,0x8d8459e1}},	//   rces, kajj, user, اشىن, 
   {{0x7d0917aa,0x672517ab,0x7a0002b5,0x60d80223}},	//   sces, jajj, _hēti, _iyum, 
   {{0x34dc3711,0x7a0004fe,0x61f801f7,0x26040037}},	//   _मर्द, _kēti, _kiul, _nõo_, 
   {{0x60d917ac,0x7c2917ad,0xd01000db,0xf2d0008f}},	//   _kyum, pser, _ئلە_, שעט_, 
   {{0x60d800ca,0x201c007f,0x7c280113,0x0db896b4}},	//   _jyum, _jwui_, qser, _ثالث_, 
   {{0x290917ae,0x61f917af,0x60d917b0,0x672517b1}},	//   acca_, _liul, _myum, gajj, 
   {{0x61f804ba,0xe50c0521,0x60d801a9,0x7df000b8}},	//   _oiul, _ụmụn, _lyum, _sāsy, 
   {{0x201c016b,0x61f917b2,0x60d917b3,0xe9cc0451}},	//   _owui_, _niul, _oyum, _وٺو_, 
   {{0x60d917b4,0x672517b5,0x7bc117b6,0xb4bc00dc}},	// [19fc0] _nyum, bajj, onlu, ेथे_, 
   {{0x61f80421,0x65b8023a,0x7bc117b7,0x7df0002b}},	//   _aiul, tähä, nnlu, _vāsy, 
   {{0x60d8019b,0x7bc117b8,0x31245954,0x61f917b9}},	//   _ayum, inlu, вдег, _biul, 
   {{0x60d83184,0x61f850bb,0xc0a84c8b,0x00000000}},	//   _byum, _ciul, کامل_, --, 
   {{0x60d801aa,0x614117ba,0x7aec01e4,0x65b80108}},	//   _cyum, реча, _ŝatl, sähä, 
   {{0x61f80393,0x62940267,0x60d917bb,0x65b80108}},	//   _eiul, byxo, _dyum, pähä, 
   {{0x764c0408,0x61f917bc,0x628001f4,0x00000000}},	//   ntby, _fiul, änot, --, 
   {{0x61f917bd,0x3e700327,0x7bc00072,0x65a00254}},	//   _giul, _dġt_, enlu, _tõhe, 
   {{0x6f64013e,0x6724a9bb,0x14b400dc,0x25f006e3}},	//   _иваз, yajj, ूपिण, ंगती_, 
   {{0x8a1805f5,0xe8fc000f,0xa0a06ef4,0x764c1f53}},	//   ноос_, pdûk_, _тауд, ktby, 
   {{0xdfcc3b6c,0xdd8c2832,0x6b98c304,0x8af80b00}},	//   _بيل_, _ڈول_, rktg, энос_, 
   {{0xdd8d17be,0x764c00ed,0x14b400dc,0x61f800cf}},	//   _وول_, dtby, ूपाण, _xiul, 
   {{0x1d04828d,0xdca01f85,0x672517bf,0x764c0175}},	//   _речи_, _каци, tajj, etby, 
   {{0xa2c80574,0x29080784,0x63500118,0x764c0a87}},	//   _तुझ्, scca_, _mění, ftby, 
   {{0x672517c0,0xe9e401af,0x1bf800df,0x00000000}},	//   rajj, _ицио, _קלוב, --, 
   {{0x67240c8a,0x5694016c,0xb0d000dc,0x865c0023}},	//   sajj, шаст, तथाग, _ህውከት, 
   {{0x58fc025c,0x61f8004e,0xa3b800c6,0x7a0000ef}},	// [19fd0] _དཔགས_, _riul, واطر_, _rēti, 
   {{0x61f832ff,0xa4980100,0x60d917c1,0xe9dd17c2}},	//   _siul, _agòc, _ryum, llú_, 
   {{0x60d804ce,0xe9dc007b,0x7a0000ef,0xc11400d8}},	//   _syum, olú_, _pēti, гмеј, 
   {{0x61f8013c,0xc1740214,0xe9dc00ae,0x00000000}},	//   _qiul, دگست, nlú_, --, 
   {{0x61f917c3,0x94840228,0x63b40334,0x50640014}},	//   _viul, _кырд, pixn, لاوِ, 
   {{0x60d89715,0x7a0002b5,0xdcf808a4,0xe9dc00ae}},	//   _vyum, _wēti, ljuć, hlú_, 
   {{0x61f917c4,0xa2c80c6e,0x7a0000e2,0x2164013d}},	//   _tiul, _तुच्, _tēti, _итаг, 
   {{0xdcf808a4,0x60d917c5,0xde480023,0x81d400fb}},	//   njuć, _tyum, _ዘይከው, _собх, 
   {{0x60d917c6,0x28d013f7,0x5ba000d1,0x6cb000fb}},	//   _uyum, _धुलि, илиғ, йөшт, 
   {{0x3a14dfe7,0xe9dc0332,0x00000000,0x00000000}},	//   льмс, elú_, --, --, 
   {{0x58fc025c,0x7bc089b7,0x00000000,0x00000000}},	//   _དཔངས_, rnlu, --, --, 
   {{0xa3b005d7,0xb6a401b9,0x00000000,0x00000000}},	//   जोत_, қибл, --, --, 
   {{0x8d740131,0xe8f400d3,0x00000000,0x00000000}},	//   _خالا, ллю_, --, --, 
   {{0x6c304028,0xe9dc007b,0x3668824d,0xc5e00011}},	//   _افوا, alú_, наго_, _মূলপ, 
   {{0x764c03cd,0x869400d8,0x00000000,0x00000000}},	//   utby, ајтч, --, --, 
   {{0x764d17c7,0x5ba00037,0x00000000,0x00000000}},	//   rtby, _ओतुव, --, --, 
   {{0x69d804ac,0xf9900014,0x5fc02e05,0x00000000}},	// [19fe0] _אַזו, _نبک_, वचाल, --, 
   {{0x1c180d35,0x845400d1,0x00000000,0x00000000}},	//   पीएल_, شىمچ, --, --, 
   {{0xfe64158f,0xe2940454,0x63b0008e,0x00000000}},	//   _بگ_, лаф_, сәях, --, 
   {{0x644800cf,0x00000000,0x00000000,0x00000000}},	//   àgic, --, --, --, 
   {{0x25d40302,0x62803b22,0x6a8000d1,0x00000000}},	//   _תוכן_, änor, ﺭﻣﯘﺵ_, --, 
   {{0x8e2001ec,0xa854011a,0x00000000,0x00000000}},	//   тiп_, ריסה_, --, --, 
   {{0x2604010f,0x7524007f,0x2d940137,0x715800c0}},	//   _aĵoj_, _kekz, лөдө_, _прас_, 
   {{0xcbc0015b,0x76480139,0x00000000,0x00000000}},	//   _উঠেছ, _äfyu, --, --, 
   {{0xafe40276,0x00000000,0x00000000,0x00000000}},	//   _боал, --, --, --, 
   {{0x752407ab,0x6d5c013f,0x4a540556,0x9c5400e3}},	//   _lekz, _ɔpay, акос, اجيز_, 
   {{0x65a00254,0xc0d40092,0x37b80154,0xe9dc00d7}},	//   _lõha, ይውል_, ংকার, tlú_, 
   {{0x7524014b,0x7d1c08a7,0x00000000,0x00000000}},	//   _nekz, ðsst, --, --, 
   {{0xe9dc00c6,0xa4e00073,0xeff40092,0x00000000}},	//   rlú_, _खरेच_, ገገው_, --, 
   {{0xfca835f9,0xa498004d,0xd5b80c60,0x9cd4011a}},	//   _جامو_, _ngòa, ҳсу_, _עוגה_, 
   {{0x752401a9,0x6754129e,0xe9dc0419,0x00000000}},	//   _bekz, نیکس_, plú_, --, 
   {{0xd5b85a92,0x30f400cd,0x00000000,0x00000000}},	//   гсу_, ेशाः_, --, --, 
   {{0x752401f5,0x00000000,0x00000000,0x00000000}},	// [19ff0] _dekz, --, --, --, 
   {{0xc038001f,0x00000000,0x00000000,0x00000000}},	//   _አልቻለ, --, --, --, 
   {{0xd3d80a11,0x00000000,0x00000000,0x00000000}},	//   ابقا_, --, --, --, 
   {{0x9268035b,0x00000000,0x00000000,0x00000000}},	//   ыруа_, --, --, --, 
   {{0x656d17c8,0xf1a41bbb,0x712000db,0x00000000}},	//   _iach, _खतरन, زۉلم, --, 
   {{0x656d17c9,0xf4380677,0x00000000,0x00000000}},	//   _hach, _בגשמ, --, --, 
   {{0x656d17ca,0x244d17cb,0x3ea507e9,0x929400d8}},	//   _kach, lüm_, рийг, _ларц, 
   {{0x656d17cc,0x56b80375,0x807800c7,0xda08000d}},	//   _jach, טפון_, _иббс_, _संबत_, 
   {{0x656d17cd,0x244d17cb,0x7a0000ef,0x7bcc02d2}},	//   _mach, nüm_, _lētt, _íauk, 
   {{0x656d17ce,0x543c008f,0x5f7400db,0x6ab000cd}},	//   _lach, געזא, _حارر, ुपूर, 
   {{0x562c0201,0x244d17cf,0x656c0857,0x00000000}},	//   _እግዚአ, hüm_, _oach, --, 
   {{0x656d17d0,0x244c4252,0xc0d40023,0x2aa00241}},	//   _nach, küm_, ይፍለ_, _ọbà_, 
   {{0x37e401b9,0x888002dd,0x0c240024,0x3154010f}},	//   иомг, зғыл, _гмін, סישן_, 
   {{0x656d17d1,0x7524009d,0x244c41bb,0xeb9431e2}},	//   _aach, _sekz, düm_, _виш_, 
   {{0xf504cda6,0x75d40691,0xc9240c58,0xf5b40cc9}},	//   изво, ليسا, _ভাৰত_, асаю, 
   {{0x3668013e,0x65a00254,0x00000000,0x00000000}},	//   наҳо_, _põha, --, --, 
  
   {{0x2404d7b1,0xe5a01cc9,0x244c03e0,0x00000000}},	// [1a000] инти_, цити, güm_, --, 
   {{0x656d17d2,0xd764d52d,0x64580356,0x65a0000d}},	//   _each, _اندی, _ţuic, _võha, 
   {{0x656d17d3,0x752517d4,0x06a42d40,0x7a0000ef}},	//   _fach, _tekz, ﺎﺭﻟﯩ, _tētu, 
   {{0x656d17d5,0x244c03ee,0x8e200220,0x2a54008f}},	//   _gach, büm_, тiн_, יבען_, 
   {{0xf1a86aef,0x244c00fd,0x65a0000d,0x25640132}},	//   _یاره_, cüm_, _kõhn, _таяп_, 
   {{0x656d17d6,0x21e400e4,0xa3d00153,0x00000000}},	//   _zach, rõha_, _моўч, --, 
   {{0x656d17d7,0xc32c1e0e,0xee8400f7,0x65a00254}},	//   _yach, _سەن_, рыло, _mõhn, 
   {{0xdce803ee,0x65a000c5,0x6140b7e7,0x656c022e}},	//   _algı, _lõhn, _меса, _xach, 
   {{0xef84d77e,0x9da40801,0xc0c01206,0x321801f4}},	//   _клап, ръща_, _нәши, lppy_, 
   {{0x321802e8,0xe4540a1e,0x765c03ac,0xafe4008e}},	//   oppy_, סייט_, _oppy, _тозл, 
   {{0x244cec7b,0xdd8c00ec,0xd8d00150,0x00000000}},	//   züm_, _ڪون_, _ﻗﺒﻭﻟ, --, 
   {{0xdce80166,0x244c3361,0x00000000,0x00000000}},	//   _elgı, yüm_, --, --, 
   {{0xdd8c00b2,0xa498004e,0x765c538c,0x7c3800f1}},	//   _تون_, _agòn, _appy, _مينځ_, 
   {{0xbbb001ee,0x00000000,0x00000000,0x00000000}},	//   _нҡыш, --, --, --, 
   {{0x656d17d8,0x25f00574,0x6e380023,0x0a5801fe}},	//   _pach, ंगली_, _ከይኣኽ, _сайъ_, 
   {{0x656d17d9,0x244d17da,0xc6a400d1,0x7c3402d2}},	//   _qach, tüm_, арғи, _ágræ, 
   {{0x656c1cbd,0x765c0083,0x644c0175,0x833407d5}},	// [1a010] _vach, _eppy, _qqci, йнах, 
   {{0x656d17db,0x244c43eb,0x1c1803e5,0x7aec010f}},	//   _wach, rüm_, पीटल_, _ŝati, 
   {{0x244d17dc,0xd5b001d3,0x45d4005a,0x1b380092}},	//   süm_, سفے_, _гонс, _በአቅራ, 
   {{0x656c35b8,0x835446c6,0xeaa401ed,0x00000000}},	//   _uach, _گھرا, _ہٹ_, --, 
   {{0x98a000b0,0x20640640,0x00000000,0x00000000}},	//   _keiā_, рђев, --, --, 
   {{0x3ea41607,0xa3b00034,0xeaa401ed,0x7a000171}},	//   йилг, जोश_, _فٹ_, _mētr, 
   {{0xe45c0036,0x6ed81be1,0x00000000,0x00000000}},	//   _hpö_, _पुदु, --, --, 
   {{0xa3b019e5,0x00000000,0x00000000,0x00000000}},	//   जोर_, --, --, --, 
   {{0xeeb40131,0x3b08020f,0x108800db,0x7f940354}},	//   иләш_, лепо_, _ەڭۉۉ_, _лаах, 
   {{0xb7d40a28,0xfb8800f5,0xb478010f,0xcfe833ae}},	//   kṣas, убок_, אָטי, _نفقه_, 
   {{0xc86805d0,0x98ac0205,0x00000000,0x00000000}},	//   _רן_, _ımız_, --, --, 
   {{0x8d7517dd,0x00000000,0x00000000,0x00000000}},	//   _وانا, --, --, --, 
   {{0x63a409a8,0xf1b0008f,0xb8840030,0xeb8d17de}},	//   _oljn, לסט_, _opíš, _еи_, 
   {{0x5dd00137,0x3ff8010f,0x32180108,0x9b400345}},	//   _اقچئ, רפֿע, yppy_, _بۆدو, 
   {{0x644819f5,0x7a000129,0x739801ec,0x00000000}},	//   àgin, _fœta, қтас_, --, 
   {{0x9b4000f1,0xe3600116,0x00000000,0x00000000}},	//   _انډو, үкти, --, --, 
   {{0x98a00093,0x1604185b,0xf7440640,0x69c4009b}},	// [1a020] _feiā_, _शंकर_, _лепо, čket, 
   {{0x7994015d,0xa3b025c9,0xe29400c7,0x00000000}},	//   _hoyw, जोल_, әац_, --, 
   {{0xb5c82088,0x765d17df,0x86740006,0x00000000}},	//   _مودم_, _uppy, _дыяц, --, 
   {{0xd7642172,0xe45c0112,0x73340150,0xf0a8004e}},	//   _انگی, _fpö_, _گىسا, лкел_, 
   {{0xf0740075,0xdb0001d3,0x6ed800c5,0xafe401a9}},	//   силә_, _elné, _पँहु, бодл, 
   {{0x4524081f,0x5f900262,0x799517e0,0xa854011a}},	//   _འབོར_, зишт, _loyw, מינה_, 
   {{0x2f5401ec,0x00000000,0x00000000,0x00000000}},	//   _қтас, --, --, --, 
   {{0x7994047e,0x7d1c0174,0x00000000,0x00000000}},	//   _noyw, ðssp, --, --, 
   {{0x6ab08929,0x320917e1,0x939c0023,0x00000000}},	//   ुप्र, _huby_, ለጽክዎ_, --, 
   {{0x320917e2,0x2a8c0213,0x2d80000f,0xa85000fb}},	//   _kuby_, ləbi_, űke_, үенә, 
   {{0xdd8d17e3,0x15f80c66,0x3208030a,0xc1c80014}},	//   _еш_, ंगार_, _juby_, _صبہٕ_, 
   {{0x320917e4,0x2a8c0213,0x31640165,0xdcf801e4}},	//   _muby_, nəbi_, neoz_, ljuĝ, 
   {{0x79940de2,0x6614005a,0x320802f0,0xd83809a5}},	//   _doyw, _stxk, _luby_, йэр_, 
   {{0x1dc00228,0xdcf801e4,0xdca00063,0x2a8c06be}},	//   _мөөн, njuĝ, _хаљи, həbi_, 
   {{0x2b4c014b,0x7a00005f,0xe45c7a45,0x273c0023}},	//   _icfc_, _vētr, _spö_, _ክዝረበ, 
   {{0xb884012c,0x04c8027d,0x21d40150,0x00000000}},	//   _spíš, لوزي_, _ﺘﻌﺎﻭ, --, 
   {{0x6ed8069f,0x3164005a,0xe4e400d4,0x5f0800cd}},	// [1a030] _पुसु, deoz_, сівн, ाशम्_, 
   {{0xa3b0068f,0xdb00219b,0x473400f5,0x58d40354}},	//   जों_, _plné, _ьнос, _хоьт, 
   {{0xdcf801e4,0xb88400d0,0x98143c5a,0x00000000}},	//   djuĝ, _vpíš, _وبیا, --, 
   {{0xb5f002dd,0x2fdc002f,0x9f400248,0x00000000}},	//   _жүсі, _aktg_, _òjú_, --, 
   {{0x1958010f,0x00000000,0x00000000,0x00000000}},	//   מבאל_, --, --, --, 
   {{0x8cdc1533,0x63a407f5,0x00000000,0x00000000}},	//   _पड़ो, _uljn, --, --, 
   {{0x2a8c00ac,0x65a00037,0xd13c0092,0x00000000}},	//   bəbi_, _lõhm, ረታቸው, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2b4d17e5,0x212d17e6,0x32080122,0x00000000}},	//   _bcfc_, magh_, _zuby_, --, 
   {{0x212c02a4,0xa4980083,0xdfd80801,0xcc08007b}},	//   lagh_, _ngòm, _съб_, حزين_, 
   {{0xdec800d1,0x10640014,0x212c1368,0xdc8801ec}},	//   _суал_, _وُہُ, oagh_, _әсел_, 
   {{0x212c9d34,0x7994047e,0x9c100139,0x83080327}},	//   nagh_, _qoyw, _ечкә, _ཇུའུ_, 
   {{0x200c009a,0x644800db,0x212c1368,0xda0807c1}},	//   nqgi_, àgil, iagh_, _संवत_, 
   {{0x45242fb5,0x212d17e7,0x7aec010f,0x7994007f}},	//   _འབུར_, hagh_, _ŝatu, _woyw, 
   {{0x79940477,0x212c0363,0x69cc0129,0x00000000}},	//   _toyw, kagh_, ébec, --, 
   {{0xa49807c5,0xa50517e8,0x3208123b,0x212c1368}},	//   _tgòl, жета_, _ruby_, jagh_, 
   {{0x212c0731,0x7e60037e,0x80d80b4c,0x33180345}},	// [1a040] dagh_, _lplp, _फुले, لزاد_, 
   {{0x7e60007f,0x212c1368,0x32085f0b,0x00000000}},	//   _oplp, eagh_, _puby_, --, 
   {{0x250800e5,0x00000000,0x00000000,0x00000000}},	//   ارہی_, --, --, --, 
   {{0x3f8403b2,0x212c0731,0xa1807aa6,0xa5f400d8}},	//   _anlu_, gagh_, дышл, _меќу_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x66000c6a,0x271400bc,0xa3b007f7,0x320844ef}},	//   _énkr, mění_, जोआ_, _tuby_, 
   {{0x212d17e9,0xdcf801e4,0xca4802dd,0xa2e0005a}},	//   bagh_, rjuĝ, _ﺇﻤﺎ_, _жорд, 
   {{0x212c00ad,0x6ebc00cd,0x00000000,0x00000000}},	//   cagh_, _वेणु, --, --, 
   {{0x6ed808dd,0x27140316,0x00000000,0x00000000}},	//   _पुरु, nění_, --, --, 
   {{0xc1180014,0x00000000,0x00000000,0x00000000}},	//   _نفہچ_, --, --, --, 
   {{0x39840023,0x00000000,0x00000000,0x00000000}},	//   _ክረምቲ_, --, --, --, 
   {{0x6c843669,0x401c00fe,0x00000000,0x00000000}},	//   _ولام, _নিতৌ_, --, --, 
   {{0x7c84001f,0x8d74097b,0x00000000,0x00000000}},	//   ናክረው_, _واچا, --, --, 
   {{0x2b4c0421,0x2714012c,0x65a00037,0x212c0003}},	//   _ucfc_, dění_, _võhm, zagh_, 
   {{0x2d840270,0x387c0318,0x212c0363,0xca480244}},	//   _knoe_, ātra_, yagh_, _العه_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x59040ed9,0x95c8ea2b,0x212c00ad,0xb6300133}},	// [1a050] _ཚུགས_, цура_, vagh_, وکێش, 
   {{0x7a34063f,0x65a00037,0xdce800dc,0x212c062c}},	//   _ẹtit, _kõhk, _jagā, wagh_, 
   {{0xdce80421,0x212c02a4,0xdec41ee0,0x65a000c5}},	//   _magā, tagh_, _ሽፋን_, _jõhk, 
   {{0xe0d01060,0x45d517ea,0x45240327,0x65a00254}},	//   وزش_, _хомс, _འབིར_, _mõhk, 
   {{0x212c02a4,0x65a000af,0xd4e4e2f1,0x7520005a}},	//   ragh_, _lõhk, _жюри, ñoze, 
   {{0x212c02a4,0x2d84003e,0x4f081b56,0xcf242002}},	//   sagh_, _anoe_, يتىپ_, ورىي, 
   {{0xc22401ed,0x3ce80841,0x212c00ad,0x9f4401e7}},	//   _رکاو, _šav_, pagh_, omnú_, 
   {{0xdce8038f,0x2d8405da,0x7f9c00db,0xf2d0010f}},	//   _jogħ, _cnoe_, _rèqu, _נען_, 
   {{0x65a0033d,0xdce917eb,0x7f9c00cf,0xc5ac00fe}},	//   _põhj, _mogħ, _sèqu, _গদাপ, 
   {{0xdce8038f,0x2d840165,0x26d00407,0x7e600175}},	//   _logħ, _enoe_, _oxxo_, _tplp, 
   {{0xf988086e,0x539c008f,0x00000000,0x00000000}},	//   مندي_, ייזו, --, --, 
   {{0xdce80327,0x3dc89a2e,0x00000000,0x00000000}},	//   _nogħ, _ñaw_, --, --, 
   {{0xda080034,0xa3d84da1,0xc038001f,0x26d00f85}},	//   _सूरत_, डका_, _አውቃለ, _axxo_, 
   {{0x27140118,0x00000000,0x00000000,0x00000000}},	//   vění_, --, --, --, 
   {{0xdce80003,0xb9c401ec,0xdbc801e1,0x00000000}},	//   _bogħ, _ىقتي, bòòs, --, 
   {{0xde382295,0xf99117ec,0x7bc117ed,0x2714012c}},	//   _አይደለ, _سبب_, lilu, tění_, 
   {{0xf8a800aa,0x20080098,0x7bcc02d2,0x00000000}},	// [1a060] _ددغه_, _écih_, _íaus, --, 
   {{0x7bc117ee,0x28780375,0xd62c030d,0xa878011a}},	//   nilu, _פנימ, _гlаз, _פריח, 
   {{0x613402d3,0x64a00124,0xa798011a,0x00000000}},	//   _ከምዝኣ, _ҟара, _השיח, --, 
   {{0x2714012c,0x9f5c01a8,0x6a38010f,0x00000000}},	//   pění_, _stuð_, מגעפ, --, 
   {{0x7bc117ef,0x3dd0015b,0x60200006,0x40c40066}},	//   kilu, াতাল, едча, وزهف, 
   {{0x7bc00a55,0xb600012c,0x00000000,0x00000000}},	//   jilu, žáda, --, --, 
   {{0x2d847093,0x2324974c,0x00000000,0x00000000}},	//   _pnoe_, _хоси_, --, --, 
   {{0xdce917f0,0xace80214,0x65a00037,0x9f9400c7}},	//   _xogħ, یرکل_, _rõhk, _ҽыхә, 
   {{0x7bc117f1,0xdce800da,0x00000000,0x00000000}},	//   filu, _pagā, --, --, 
   {{0x7bc117f2,0x65a00254,0x00000000,0x00000000}},	//   gilu, _põhk, --, --, 
   {{0x387000ee,0xdce800b8,0xde14007b,0xed5801c4}},	//   _asyr_, _vagā, _فقلت_, _гое_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7bc117f3,0xdce917f4,0x588517f5,0xdd8c0150}},	//   bilu, _tagā, ныра, _حون_, 
   {{0xdce8031c,0x1be4010a,0x9c14011a,0x00000000}},	//   _sogħ, _едчи_, _צחוק_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x25a80334,0x21e40037,0x00000000,0x00000000}},	//   _qlcl_, rõhk_, --, --, 
   {{0x870801ed,0x00000000,0x00000000,0x00000000}},	// [1a070] _وعدہ_, --, --, --, 
   {{0x25ec10f7,0x7e6c0210,0x00000000,0x00000000}},	//   _आठवी_, łapi, --, --, 
   {{0x415517f6,0xa3b0b340,0xdce80003,0x65a00254}},	//   двес, जोग_, _togħ, _lõhi, 
   {{0x7bc00912,0xe9dc0418,0xe4a439c8,0x7c2c0139}},	//   zilu, noú_, _ерго, _çarg, 
   {{0x7ff42c1f,0x7bc117f7,0x00000000,0x00000000}},	//   وستا, yilu, --, --, 
   {{0x438800aa,0x7bc0198f,0xdce8054e,0x00000000}},	//   _بنسټ_, xilu, _lagă, --, 
   {{0x7bc0038f,0xe9dc0093,0xdb0002fb,0x73c02cc8}},	//   vilu, koú_, _plní, _рәте, 
   {{0x4438d055,0x0e440131,0x7bc00e47,0x6d540139}},	//   _kvs_, رخىپ, wilu, _öyal, 
   {{0xb6200150,0x8d28013d,0x00000000,0x00000000}},	//   _ﺩﯞ_, чның_, --, --, 
   {{0x443803b9,0x7aa47579,0x291c01c4,0x7c2c025c}},	//   _mvs_, диоз, ñuan_, _ħard, 
   {{0x7bc117f8,0x690003be,0xfd7401c0,0xdb200133}},	//   rilu, ətdə, _олжэ, ووکی, 
   {{0x443917f9,0xc7a800d9,0x00000000,0x00000000}},	//   _ovs_, _דב_, --, --, 
   {{0x7bc117fa,0x443917fb,0x00000000,0x00000000}},	//   pilu, _nvs_, --, --, 
   {{0x7bc117fc,0x87b917fd,0xcb08007b,0x37a001a9}},	//   qilu, пуст_, _فيهن_, тқоғ, 
   {{0x66e117fe,0x00000000,0x00000000,0x00000000}},	//   вора, --, --, --, 
   {{0x3dcd17ff,0x44391800,0xd3f40150,0x00000000}},	//   nnew_, _bvs_, ңiст, --, 
   {{0x7c2ccb7d,0x13680023,0x25f001ad,0x4438045a}},	// [1a080] _çard, _ጽሑፍካ_, ंगजी_, _cvs_, 
   {{0x44391801,0xf748007b,0x00000000,0x00000000}},	//   _dvs_, _بلدي_, --, --, 
   {{0x4ee800bd,0x95e801d9,0x00000000,0x00000000}},	//   _পল্ল, _فکرِ_, --, --, 
   {{0x970404a9,0x4439126e,0xc1c400d1,0x6ad000eb}},	//   _يېڭى, _fvs_, ىغنى, _হরমো, 
   {{0x44380268,0x00000000,0x00000000,0x00000000}},	//   _gvs_, --, --, --, 
   {{0x73340116,0x00000000,0x00000000,0x00000000}},	//   _زىرا, --, --, --, 
   {{0xa3d82232,0x63a11802,0x4438607b,0x25f001f9}},	//   डकर_, önne, _zvs_, ंगची_, 
   {{0x65a0033d,0xb7c40589,0x80d805d7,0xa49801ab}},	//   _põhi, naãº, _फुके, _sgòi, 
   {{0xe9dc03a0,0x6ebc0892,0x00000000,0x00000000}},	//   voú_, _वेरु, --, --, 
   {{0x65a00037,0x1f60430d,0x00000000,0x00000000}},	//   _võhi, _икум, --, --, 
   {{0x2d991803,0xf0d002e3,0x7c2c0003,0xed5800f5}},	//   êpes_, tịwọ, _ħare, _мож_, 
   {{0xdd8c71c5,0x00000000,0x00000000,0x00000000}},	//   _پوه_, --, --, --, 
   {{0xc8c80592,0xf77c00d1,0x00000000,0x00000000}},	//   سوسن_, ﻤﻠﯩﻚ_, --, --, 
   {{0x65a000c5,0xf0d0063f,0x4438045a,0xf03c0023}},	//   _jõhv, sịwọ, _rvs_, _ኣይሰም, 
   {{0xbd051804,0x4438003b,0xb9043507,0x7648143a}},	//   _théâ, _svs_, _बु_, _åfyl, 
   {{0x96f91805,0x8ac401b9,0x21e4000d,0x84240116}},	//   фест_, _оёқл, põhi_, فىرن, 
   {{0x98740022,0xd0080c58,0x98a001a6,0x69cc9601}},	// [1a090] _алыц, ৰীয়_, _reić_, mnce, 
   {{0x44389c48,0x7c2ceab4,0x69b8629c,0x7800014b}},	//   _vvs_, _çare, शोरी, _бӯса, 
   {{0x3dcc0204,0x69cd1806,0x00000000,0x00000000}},	//   ynew_, once, --, --, 
   {{0xd1b8156d,0x6f18035a,0x5bb80b8f,0xd1dc02d3}},	//   وانا_, _aftc, _ऋग्व, _ንፈቱ_, 
   {{0x8504020c,0x00000000,0x00000000,0x00000000}},	//   _سوسن, --, --, --, 
   {{0xd9bc043e,0x1fa401af,0x00000000,0x00000000}},	//   _उष्ट, ьрег, --, --, 
   {{0x272401a9,0xdec80023,0x3dcc0334,0x52140006}},	//   _mеn_, _ኢሉኒ_, tnew_, _адст, 
   {{0x69cd1807,0x8638001f,0x6f1803ac,0x7c9406ed}},	//   jnce, _እውነት, _eftc, ероц, 
   {{0x5ab40156,0x41280032,0x33b00137,0x3dcc031c}},	//   _བཟངམ, _моңо_, _جەەر, rnew_, 
   {{0x201c0270,0x4fc4c8dc,0x69cd1808,0x3dcd1809}},	//   _itui_, _исха, ence, snew_, 
   {{0xfaa5180a,0x4fc4af4b,0x39e81ab7,0x9cd00451}},	//   хано, _рста, здно_, _ڌماڪ, 
   {{0x9f440122,0x65a000af,0x3dcc0204,0xf2d0008f}},	//   dlné_, _kõhu, qnew_, רעט_, 
   {{0xbb445211,0xeaac00e5,0x0c24187f,0x02bc00cd}},	//   _зелк, لٹی_, _амін, ्पुन, 
   {{0x69cd180b,0xa0480f7c,0x201c01f7,0x00000000}},	//   ance, _ዓይነታ, _mtui_, --, 
   {{0x65a000c5,0x7c2c010e,0x00000000,0x00000000}},	//   _lõhu, _çarb, --, --, 
   {{0xf5040d1d,0x61e801bf,0x00000000,0x00000000}},	//   езбо, jlgl, --, --, 
   {{0x81d4045e,0xb7c40004,0x35a4016c,0x37e466b4}},	// [1a0a0] হতা_, raãº, _ҷанг, _поиг, 
   {{0x213c3f9a,0xe8f40510,0x00000000,0x00000000}},	//   _aduh_, _ялы_, --, --, 
   {{0x201d180c,0xb145180d,0x35a5180e,0x78a40af9}},	//   _atui_, енел, _занг, lykv, 
   {{0x764c5d23,0x21e40254,0x00000000,0x00000000}},	//   muby, kõhu_, --, --, 
   {{0x764d180f,0xe1211810,0x14040166,0xdc2c00ef}},	//   luby, умчи, _аҗаг, _džīn, 
   {{0x213c009a,0x75351811,0x61e802d0,0x00000000}},	//   _eduh_, layz, algl, --, 
   {{0x201d1812,0xda0800ab,0x764d1813,0x00000000}},	//   _etui_, _संगत_, nuby, --, 
   {{0x2c2400d6,0x22440030,0x00000000,0x00000000}},	//   ньог, ánke_, --, --, 
   {{0x764d1814,0x67240175,0xad251815,0x00000000}},	//   huby, ybjj, ورکو, --, 
   {{0x764d1816,0x80d81152,0x68040ca8,0xd1cc01f3}},	//   kuby, _फुटे, _méjì, _ጠበቃ_, 
   {{0x764d1817,0x65a00037,0x00000000,0x00000000}},	//   juby, _kõht, --, --, 
   {{0x69cc03ac,0xed5828f1,0x764c0014,0x3ea0061f}},	//   unce, _ход_, duby, ähte_, 
   {{0x69cc01a4,0xdb000306,0x0c9452d4,0x22040051}},	//   rnce, _vlná, _جداگ, _hìhì_, 
   {{0x764c0796,0x69cc0198,0x75200113,0x9b5401f0}},	//   fuby, snce, ñozn, _зишт_, 
   {{0x61e802fa,0xd6d80f12,0xdb011818,0x753401d5}},	//   ylgl, етт_, _alnæ, fayz, 
   {{0xf0a4001e,0x00000000,0x00000000,0x00000000}},	//   _đành_, --, --, --, 
   {{0x59640801,0x9f440118,0xc7f400f3,0x00000000}},	// [1a0b0] _съща, slné_, _изић, --, 
   {{0x764c0223,0x65a000af,0x9f440306,0x00000000}},	//   buby, _rõhu, plné_, --, 
   {{0x27e004ac,0x764c0223,0x680401e1,0x201c04cc}},	//   mojn_, cuby, _eéjì, _stui_, 
   {{0x27e004ac,0x201c0254,0x65a0000d,0x00000000}},	//   lojn_, _ptui_, _põhu, --, 
   {{0x7534010f,0x673c0023,0x00000000,0x00000000}},	//   _בארד_, _ክምዕብ, --, --, 
   {{0x27e004ac,0xe1906315,0x05740032,0x00000000}},	//   nojn_, _өлгө, _яҙғы_, --, 
   {{0xb1a801a8,0x27e001e4,0x00000000,0x00000000}},	//   þýðu, iojn_, --, --, 
   {{0x68f80006,0x65a000af,0x213c0098,0x27e0fb44}},	//   žudy, _tõhu, _uduh_, hojn_, 
   {{0x27e000c8,0x00000000,0x00000000,0x00000000}},	//   kojn_, --, --, --, 
   {{0x27e000c8,0x21e40037,0x00000000,0x00000000}},	//   jojn_, rõhu_, --, --, 
   {{0x27e000c8,0x21e4000d,0x00000000,0x00000000}},	//   dojn_, sõhu_, --, --, 
   {{0x764d1819,0x00000000,0x00000000,0x00000000}},	//   vuby, --, --, --, 
   {{0x764c0223,0xbca5181a,0xe8f40816,0x27e0010f}},	//   wuby, _جمشي, клю_, fojn_, 
   {{0x27e000c8,0x764d181b,0xf77000c6,0x69dc03b2}},	//   gojn_, tuby, جاح_, _ípen, 
   {{0x59040327,0x6ce000f1,0x34a800cd,0x00000000}},	//   _ཚུམས_, _مړین, छन्द, --, 
   {{0x764cda52,0x00000000,0x00000000,0x00000000}},	//   ruby, --, --, --, 
   {{0x64a00323,0x27e0008f,0x7535181c,0x66000137}},	// [1a0c0] аата, bojn_, rayz, рпта, 
   {{0x27e000c8,0x5f100154,0xdce80171,0x00000000}},	//   cojn_, হরুখ_, _angī, --, 
   {{0xa49801c3,0x75340076,0x55c401af,0x00000000}},	//   _sgòt, payz, _банғ, --, 
   {{0x3fe000cc,0x9f4400d7,0x00000000,0x00000000}},	//   যগোষ, rmný_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6e880063,0x00000000,0x00000000,0x00000000}},	//   дљив_, --, --, --, 
   {{0x2d9400f7,0x291c005a,0x7c2c025c,0x6fb401d9}},	//   көдө_, ñuak_, _ħara, _یمرا, 
   {{0x27e0008f,0x6e3c0020,0x21a0e269,0x5d8000d1}},	//   zojn_, _አይገባ, _кисм, للىل, 
   {{0xe8141533,0x2f55181d,0x300400fd,0x65a00254}},	//   _धंधा_, _атес, _азаг, _kõhr, 
   {{0x27e0036e,0x00000000,0x00000000,0x00000000}},	//   xojn_, --, --, --, 
   {{0x27e000c8,0x00000000,0x00000000,0x00000000}},	//   vojn_, --, --, --, 
   {{0xe8140073,0xc0d40092,0x00000000,0x00000000}},	//   _धंदा_, ክልሉ_, --, --, 
   {{0x27e004ac,0xeb981d56,0x9875181e,0x6d40005a}},	//   tojn_, _оид_, аляц, _idoa, 
   {{0x7c2c0598,0xd7f81241,0xe664004e,0x00000000}},	//   _çara, вус_, ктбо, --, 
   {{0x27e004ac,0x00000000,0x00000000,0x00000000}},	//   rojn_, --, --, --, 
   {{0x27e0a684,0x6ed8000d,0xa8a4022e,0x00000000}},	//   sojn_, _पुछु, _арок, --, 
   {{0x27e0008f,0x7a00003a,0x66c0022e,0xdb000267}},	// [1a0d0] pojn_, _cœtu, _dеka, _elnä, 
   {{0x61d807f8,0x73c0013d,0xe6700240,0x00000000}},	//   यक्ष, бәсе, _ብግፍዒ_, --, 
   {{0x2ba8098a,0xd404117e,0xd73401c6,0xf3f003d4}},	//   _चकना, ряти, _өдөө, _অংশৰ_, 
   {{0x8144034c,0x6d41181f,0x7a000129,0x00000000}},	//   انشن, _ndoa, _fœtu, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d40054e,0x00000000,0x00000000,0x00000000}},	//   _adoa, --, --, --, 
   {{0x92951820,0xe1d82d4b,0xd13c001f,0x387c00e2}},	//   _карц, _قبرص_, የታቸው, ātri_, 
   {{0xc10414a5,0xf2d002e4,0xdce8012d,0x00000000}},	//   _موزي, _העל_, _zagę, --, 
   {{0x61f91821,0x645c01e0,0x2e0c002d,0x6e3c1954}},	//   _ihul, ntqi, _sęft_, _አይግባ, 
   {{0x6d411822,0x00000000,0x00000000,0x00000000}},	//   _edoa, --, --, --, 
   {{0x61f8c4cc,0x00000000,0x00000000,0x00000000}},	//   _khul, --, --, --, 
   {{0xdea0066d,0x61f80036,0xd010215c,0xcbc80014}},	//   _میڈی, _jhul, _الە_, _یِنو_, 
   {{0x61f91823,0x3b640014,0x35c4033f,0x431c0023}},	//   _mhul, _مُشِ, रोफ़, ድሕድኩ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x61f91824,0xf990007b,0x00000000,0x00000000}},	//   _ohul, _هبة_, --, --, 
   {{0x61f802c4,0x60d803be,0xf770167e,0x39344889}},	//   _nhul, _oxum, جاڭ_, _сэкс, 
   {{0x6284198f,0x60d91825,0xa49801c3,0xaf500092}},	// [1a0e0] _arjo, _nxum, _sgòr, _የጽህፈ, 
   {{0x61f91826,0x628402d2,0x289400d9,0x00bc0116}},	//   _ahul, _brjo, _עדין_, ﻣﻼﺷﺘ, 
   {{0x61f91827,0xb6a40166,0xa75808c3,0x00000000}},	//   _bhul, _синл, _אדיר, --, 
   {{0x22440ceb,0x628401e4,0xd5b001d3,0xa24400cf}},	//   ánka_, _drjo, _بہر_, ارلۇ, 
   {{0x61f80a81,0x62842edd,0x61411828,0x9f4401ef}},	//   _dhul, _erjo, сеча, alní_, 
   {{0x61f801f2,0x84680882,0xceb000ec,0x9f3003de}},	//   _ehul, _kṛṣṇ, يڙا_, беші, 
   {{0x61f835ab,0x62845d86,0x00000000,0x00000000}},	//   _fhul, _grjo, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc0c01884,0x4bb404a9,0x9db400f1,0x00000000}},	//   _мәши, ийис, ږدیز_, --, 
   {{0x8ec4021a,0x61f8036e,0x628401f4,0x00000000}},	//   _پښتو, _zhul, _yrjo, --, 
   {{0x61f8009a,0x6b4c022e,0x7c2c0166,0x6da4030d}},	//   _yhul, _dеgа, _çarn, _йижа, 
   {{0x61f80240,0xca84009d,0x00000000,0x00000000}},	//   _xhul, ггүй, --, --, 
   {{0x33380227,0xab84011c,0x6ab800e5,0x2bc8009b}},	//   kapx_, _буйк, sztf, _пуко_, 
   {{0x1d0400d8,0xfa54179e,0x00000000,0x00000000}},	//   _сечи_, دریگ, --, --, 
   {{0x9f8800c5,0xc5c400c7,0x00000000,0x00000000}},	//   _töös_, араҩ, --, --, 
   {{0x62840200,0x645c031c,0x00000000,0x00000000}},	//   _rrjo, ttqi, --, --, 
   {{0x83351829,0x61f9182a,0xddc8031c,0x59d401e2}},	// [1a0f0] инах, _rhul, _ġiżi, _دغور, 
   {{0x61f9182b,0x628402d2,0x645c01d5,0x40941291}},	//   _shul, _prjo, rtqi, یلار, 
   {{0x61f9182c,0x42747a71,0xc1140a5b,0x00000000}},	//   _phul, ргес, амеј, --, 
   {{0x61f80986,0x00000000,0x00000000,0x00000000}},	//   _qhul, --, --, --, 
   {{0x61f81aa1,0x777c0054,0x9f4402f0,0x50640014}},	//   _vhul, _yapx, slní_, ماوِ, 
   {{0x4429182d,0x660d182e,0x3f69182f,0x61f80263}},	//   mpa_, _hick, тико_, _whul, 
   {{0x61f816ec,0x44291830,0xfd100597,0x6284198f}},	//   _thul, lpa_, يجة_, _urjo, 
   {{0x61f8016c,0x44291831,0x660c0036,0x6614009d}},	//   _uhul, opa_, _jick, _muxk, 
   {{0x44291832,0x00000000,0x00000000,0x00000000}},	//   npa_, --, --, --, 
   {{0x660d1833,0x44291834,0x9e6400e5,0xd1cc0023}},	//   _lick, ipa_, _ماؤن, _ጠበቓ_, 
   {{0x44280978,0x8d900092,0x00000000,0x00000000}},	//   hpa_, ጆቻቸው_, --, --, 
   {{0x44291835,0x777c0bc9,0x660c9229,0x41b403ce}},	//   kpa_, _sapx, _nick, ंसिस, 
   {{0x442827e0,0x27400139,0x580401e0,0x00000000}},	//   jpa_, _oçnı_, йомғ, --, 
   {{0x44291836,0x7c291837,0xdcf82220,0x777c0ba7}},	//   dpa_, mper, nduč, _qapx, 
   {{0x7c291838,0x660c4e13,0x44291839,0xa6c42095}},	//   lper, _bick, epa_, алра_, 
   {{0x44280bc9,0xb424007b,0x4534a8db,0x846800cd}},	//   fpa_, لعطو, йхут, _vṛṣṇ, 
   {{0x660d183a,0x44281c81,0x136808b0,0x6fd40073}},	// [1a100] _dick, gpa_, лпақ_, _बदलू, 
   {{0x7c283659,0xdcf87313,0xe3b5183b,0xded4010c}},	//   iper, jduč, абу_, ክርን_, 
   {{0x7c29183c,0xc1400023,0x72c400f0,0xf6740244}},	//   hper, _ከምዝሃ, јбез, _ئاخخ, 
   {{0x7c29183d,0x6449183e,0x69dc00e4,0x4428016d}},	//   kper, ágic, _êpet, bpa_, 
   {{0x4428aaec,0x00000000,0x00000000,0x00000000}},	//   cpa_, --, --, --, 
   {{0x7c29183f,0x660c1196,0x23240117,0x00000000}},	//   dper, _zick, _вори_, --, 
   {{0xe2951840,0x7c291841,0x5f704d2f,0x247c0023}},	//   _кар_, eper, زاور, _ብርሰት_, 
   {{0x2bac00cd,0x00000000,0x00000000,0x00000000}},	//   टस्थ, --, --, --, 
   {{0x7c291842,0x0cb4015b,0x8e7c0022,0x7c2d1843}},	//   gper, ঞপ্ত, _ryĝu, _çarl, 
   {{0xeb041049,0x4a54005b,0xfbcc0d62,0x00000000}},	//   ично, бкос, ى۪ن_, --, 
   {{0x7c291844,0x44291845,0x66c0022e,0xee391846}},	//   aper, zpa_, _rеko, _рне_, 
   {{0x44291847,0xbb4c08b0,0x67340076,0x6e280e78}},	//   ypa_, ﺍﻧﻰ_, _sexj, mpfb, 
   {{0x7c280d24,0x6c74132f,0x00000000,0x00000000}},	//   cper, _خطائ, --, --, 
   {{0x660d1848,0x6614005a,0x4428014f,0x0a580408}},	//   _sick, _puxk, vpa_, _бакъ_, 
   {{0x660c41fb,0x44280bf1,0x80cc012d,0x00000000}},	//   _pick, wpa_, _देने, --, 
   {{0x44291849,0xd5b9184a,0xc0f002d3,0xb8240154}},	//   tpa_, асу_, ልግሉ_, _বিরত_, 
   {{0x44280008,0x764c002d,0x461401ed,0x69cc0129}},	// [1a110] upa_, arby, _گوجر, ébeu, 
   {{0x230829c6,0x660cccab,0xa3b0012d,0x2325184b}},	//   نتاي_, _wick, ड़ों_, рфаг, 
   {{0x4429184c,0x7c29184d,0x660d184e,0x668007d6}},	//   spa_, zper, _tick, _بیزل, 
   {{0x9f4402fb,0x660c127b,0x00000000,0x00000000}},	//   dlná_, _uick, --, --, 
   {{0x7c29184f,0x70202f8b,0xe31802e1,0x44281bb7}},	//   xper, _নিউজ_, _لغزش_, qpa_, 
   {{0x9f44044e,0x7c291850,0x016401d9,0x10480395}},	//   monë_, vper, _گُرَ, ряци_, 
   {{0x7c28be66,0x9f440240,0xc694010f,0x00000000}},	//   wper, lonë_, מאַ_, --, 
   {{0x7c291851,0x66c001a9,0x0164009f,0x00000000}},	//   tper, _rеkl, _دُرَ, --, 
   {{0xc0f00b82,0x00000000,0x00000000,0x00000000}},	//   ልግሎ_, --, --, --, 
   {{0x7c291852,0x451c015b,0x5ea00050,0x7c2d1853}},	//   rper, তরিক_, _وۅشل, _çarm, 
   {{0x9f440240,0xc2e80011,0x6e400166,0x45400023}},	//   honë_, _কৃতি_, _äybе, _ክጽንበ, 
   {{0xc0f036d7,0x3e611854,0x7bf91855,0x7c291856}},	//   ልግል_, mót_, _өнер_, pper, 
   {{0xd2f40316,0x3e60ba10,0x7c280240,0xfca800ec}},	//   _अर्ब_, lót_, qper, _ڄاڻو_, 
   {{0x17c80364,0xab240e91,0x9f44036e,0x6c340408}},	//   рҳои_, _лоша_, donë_, _улшă, 
   {{0x75d406f6,0x377400fb,0x3e603add,0x00000000}},	//   ميسا, _һынс, nót_, --, 
   {{0xe8fc0a85,0x3dcc03a2,0x15280220,0xf624013e}},	//   mfûn_, niew_, рнақ_, идҳо, 
   {{0xe5a11857,0x9f440200,0x00000000,0x00000000}},	// [1a120] чити, gonë_, --, --, 
   {{0x2a6c0789,0x9ac00083,0xe98400db,0x3dcc0139}},	//   _ypfb_, ŋŋum, _ناۋۋ, hiew_, 
   {{0x3dcc03a2,0x3e611858,0x80cc4ca3,0xdce80166}},	//   kiew_, jót_, _देबे, _mogı, 
   {{0x15b41a59,0xdcfc00bc,0x9f4402bd,0x3e60655d}},	//   _بەرس, ávěr, lonè_, dót_, 
   {{0xc2e8009e,0x0f140815,0x3dcc0139,0x00000000}},	//   কেলি_, омлю, diew_, --, 
   {{0xc05810f5,0xe8fc000f,0xb30801d3,0xa0700006}},	//   рії_, kfûn_, _مغزل_, ягіч, 
   {{0x7c2ccaf5,0xee84005b,0x3e6001d3,0xa2b000e5}},	//   _çarj, сыло, gót_, _ٹینڈ, 
   {{0x3dcc0649,0xd1f00023,0x00000000,0x00000000}},	//   giew_, ውምቲ_, --, --, 
   {{0xaf34fb62,0xdb00007f,0xdce80166,0x4bb80798}},	//   _هرات, _honè, _bogı, илиџ_, 
   {{0x3e611859,0x5ce007d8,0xdb001801,0xdce80139}},	//   bót_, яюща, _konè, _cogı, 
   {{0x3e600429,0x9f44036e,0x00000000,0x00000000}},	//   cót_, zonë_, --, --, 
   {{0xdb01185a,0xadf84278,0x6ec806be,0x3dcc0139}},	//   _zonë, _صراط_, _qәbu, ciew_, 
   {{0xacf5185b,0xdb00007f,0x7de40b24,0x00000000}},	//   _اسات, _lonè, _بسلم, --, 
   {{0xdb80004e,0x00000000,0x00000000,0x00000000}},	//   _нгчи, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2488070d,0x9f44036e,0x6ec806be,0xf3f000cc}},	//   _prcm_, tonë_, _hәbs, _অংগৰ_, 
   {{0x3e6001ed,0x9f44007f,0xdce8008e,0x00000000}},	// [1a130] zót_, bonè_, _yogı, --, 
   {{0x69cd185c,0xdb000100,0x9f44036e,0x00000000}},	//   lice, _bonè, ronë_, --, 
   {{0xdb000228,0x02d9185d,0x5fa000d1,0x9f440200}},	//   _conè, جواب_, ۋەرم, sonë_, 
   {{0xdb00180f,0x9f440418,0xc058215c,0x32040162}},	//   _donè, moné_, لشتا_, gmoy_, 
   {{0x3dcd185e,0x7e6000b5,0xa6b8015b,0x3e60011f}},	//   view_, _sqlp, _উখিয়, wót_, 
   {{0x3204079b,0x3e6000dd,0xdb01185f,0x69cc00d2}},	//   amoy_, tót_, _fonè, hice, 
   {{0x69cd1860,0x3dcc003e,0x53343e09,0xdb000200}},	//   kice, tiew_, _хест, _vonë, 
   {{0x69cd1861,0x63a405d6,0x3e611862,0x7c2c2ac2}},	//   jice, _hojn, rót_, _çark, 
   {{0x69cd1863,0xf07830cb,0x9f444ce5,0x3dcc0652}},	//   dice, _китә_, yonè_, riew_, 
   {{0x3dcc06a3,0xdb00003e,0x63a40455,0xfbc402bf}},	//   siew_, _honé, _jojn, ібно, 
   {{0x63a40477,0x69ccbf0c,0xdb011864,0x7a691865}},	//   _mojn, fice, _koné, шинг_, 
   {{0x69cd1866,0x3e44005f,0x9f440066,0x63a40010}},	//   gice, mēt_, doné_, _lojn, 
   {{0x3e44005f,0x0bb805f5,0xdb011867,0x8d7401ec}},	//   lēt_, ртөө_, _moné, _ءاما, 
   {{0x63a40218,0xb90044af,0xe7351868,0x61e807de}},	//   _nojn, _दश_, жер_, hogl, 
   {{0xb9c41b06,0x3204022c,0x3e44005f,0x9f440214}},	//   _وقتي, ymoy_, nēt_, goné_, 
   {{0x9ac00083,0x61e801a6,0x20040327,0x00000000}},	//   _ŋŋwa, jogl, hmni_, --, 
   {{0x79951869,0x61e9186a,0x63a43858,0xdb000ba1}},	// [1a140] _inyw, dogl, _bojn, _sonè, 
   {{0x79840d27,0xdb004b84,0x9f45186b,0x63a5186c}},	//   ldkw, _ponè, boné_, _cojn, 
   {{0xdb01186d,0x61e9186e,0x925002d3,0x35a5186f}},	//   _boné, fogl, _ኣውራጃ, _данг, 
   {{0xdb011870,0x3e44005f,0x7984017a,0xe5751871}},	//   _coné, dēt_, ndkw, _дзю_, 
   {{0x63a51872,0xefb013f9,0xdb00004e,0x7994009f}},	//   _fojn, ویرگ, _doné, _mnyw, 
   {{0x69cd1873,0x63a40007,0x5f9023aa,0xdb000100}},	//   zice, _gojn, дишт, _tonè, 
   {{0xdb011874,0x62608fba,0x69cc2939,0x79951875}},	//   _foné, _овра, yice, _onyw, 
   {{0x61e91876,0x2004208d,0x79941418,0xe28001a9}},	//   cogl, amni_, _nnyw, _ўлти, 
   {{0x69cd1877,0x2d800030,0x00000000,0x00000000}},	//   vice, ľke_, --, --, 
   {{0x69cc02c4,0x2d811878,0x79946adb,0x9f4400f2}},	//   wice, žke_, _anyw, yoné_, 
   {{0x3e4400da,0xc04c001f,0x798401f5,0x63a00108}},	//   cēt_, _አልተገ, fdkw, önni, 
   {{0xc0f0001f,0x1af4009d,0x98bc002b,0xba5000db}},	//   ልግም_, өдөө_, _śvā_, رچىع, 
   {{0xdd8cc0cc,0x5884eaae,0xe9e8032e,0x7afc0153}},	//   _جون_, мыра, _alúð_, ęsta, 
   {{0x69cd1879,0x79940337,0xfca8015e,0x9f45187a}},	//   sice, _enyw, _دامو_, toné_, 
   {{0x69cd187b,0x63a40455,0x7c2c0135,0x61e80205}},	//   pice, _rojn, _ħari, yogl, 
   {{0x9f4404fb,0x63a5187c,0x89380f14,0x644800d8}},	//   roné_, _sojn, _упис_, ágio, 
   {{0x61e9187d,0x63a40070,0x3e4400da,0x5fd80490}},	// [1a150] vogl, _pojn, zēt_, _बदलल, 
   {{0xc2e811ba,0x66c001a9,0x63a40200,0x00000000}},	//   _কৃষি_, _lеki, _qojn, --, 
   {{0xdb00e551,0xa22400f2,0x2004022e,0x00000000}},	//   _poné, زراه, vmni_, --, 
   {{0xf67804ac,0x05b8066d,0x1a9800c8,0x63a40034}},	//   _פארמ, _اگست_, ייבע, _wojn, 
   {{0x61e9187e,0x63a40477,0x442c0142,0x00000000}},	//   rogl, _tojn, _ïe_, --, 
   {{0x3e44005f,0x61e9187f,0x44380042,0x7c2c06be}},	//   tēt_, sogl, _iws_, _çari, 
   {{0x44391880,0xdcf8005f,0xdb0000d8,0x00000000}},	//   _hws_, skuļ, _toné, --, 
   {{0x44380457,0x3e4400da,0x200401d5,0x918400d1}},	//   _kws_, rēt_, smni_, _يۇلۇ, 
   {{0x3e4400e2,0xfbd000f2,0x98a000d7,0x00000000}},	//   sēt_, فتد_, _pfič_, --, 
   {{0x44391881,0x3e44005f,0x09e4015b,0x7994017a}},	//   _mws_, pēt_, _নওগা, _snyw, 
   {{0x656c2d2a,0x44380218,0x387009cc,0x00000000}},	//   _obch, _lws_, _spyr_, --, 
   {{0xcda812ea,0x1a6400e5,0x00000000,0x00000000}},	//   _وهله_, میڈی_, --, --, 
   {{0x44380e37,0x2de800aa,0x64480789,0xa3e80da0}},	//   _nws_, _اونۍ_, ágil, मवा_, 
   {{0x3f851882,0x7c380a40,0x9f44025a,0x87b85a92}},	//   _jalu_, _iwwr, zonî_, оуст_, 
   {{0x44391883,0x656c02a8,0xed3400a2,0x00000000}},	//   _aws_, _bbch, _aỳyñ_, --, 
   {{0x3f84a763,0xe5a11884,0x74140597,0x44380368}},	//   _lalu_, ниси, كورا, _bws_, 
   {{0x3940033d,0x33191885,0x656c00a3,0x247c0092}},	// [1a160] maks_, مزاد_, _dbch, _ብክለት_, 
   {{0x39411886,0x3f8418a6,0x44387ae3,0x656c009f}},	//   laks_, _nalu_, _dws_, _ebch, 
   {{0x4438598e,0x468000d1,0x55c402dd,0xae0c503c}},	//   _ews_, _иқра, _жанғ, ागमन_, 
   {{0x3940e4ff,0x3f840b23,0x44391887,0x656c00d8}},	//   naks_, _aalu_, _fws_, _gbch, 
   {{0x44380998,0x3f851888,0x8f841c34,0x00000000}},	//   _gws_, _balu_, мқал, --, 
   {{0x3f851889,0x3940007d,0x66c0022e,0x6f0001e1}},	//   _calu_, haks_, _sеki, _níbí, 
   {{0x3f85188a,0x3941188b,0xdb0002fb,0xa2e000f7}},	//   _dalu_, kaks_, _plný, _зорд, 
   {{0x80cc3a37,0x3940007d,0x9e010743,0x44380211}},	//   _देवे, jaks_, нчыл, _yws_, 
   {{0x44380457,0x6f0001e1,0x394000af,0xab842bb6}},	//   _xws_, _bíbí, daks_, пунк, 
   {{0xa064023b,0x00000000,0x00000000,0x00000000}},	//   _хафа_, --, --, --, 
   {{0x3941188c,0x6d4405f7,0x69f000f7,0x2eb40510}},	//   faks_, ókas, нүкт, _эсас, 
   {{0x3f841529,0xdb0006ea,0x39400037,0x00000000}},	//   _zalu_, _alnó, gaks_, --, 
   {{0x2ac00231,0x6f006b3c,0x4bc400f7,0x3f840de2}},	//   _bébé_, _fíbí, _жөнг, _yalu_, 
   {{0x7bcc00c0,0x57a4009d,0x00000000,0x00000000}},	//   _įaug, ншса, --, --, 
   {{0x4439188d,0x3941188e,0x5695188f,0xc04c02d3}},	//   _sws_, baks_, нарт, _ኣይትፈ, 
   {{0x9a804123,0x44380142,0x3ea0023a,0xe4e400d4}},	//   _чушл, _pws_, ähti_, пізн, 
   {{0x44391890,0x2d840066,0xdb000241,0x95c8074d}},	// [1a170] _qws_, _maoe_, _lonì, чура_, 
   {{0x051c015b,0x443801a4,0x2d840076,0x53e401c0}},	//   তরের_, _vws_, _laoe_, нцха, 
   {{0x224401ed,0x3f84054e,0x00000000,0x00000000}},	//   énk_, _ralu_, --, --, 
   {{0x3f851891,0x443801d4,0x656d1892,0x00000000}},	//   _salu_, _tws_, _ubch, --, 
   {{0xdce80003,0x44380009,0xd8d8010f,0xc5f8230e}},	//   _ingħ, _uws_, ּווט_, ंतीय_, 
   {{0x14080574,0x6f1800db,0x39406c3c,0x3f851893}},	//   वगृह_, _cgtc, zaks_, _qalu_, 
   {{0x3f851894,0x63a0008c,0x2d84030a,0x925805f5}},	//   _valu_, önnu, _baoe_, _нарт_, 
   {{0x29180944,0x3f851895,0xd84000d7,0x00000000}},	//   _ngqa_, _walu_, účky_, --, 
   {{0x3f851896,0x3940007d,0x213c3386,0x9f451897}},	//   _talu_, vaks_, _ieuh_, loní_, 
   {{0x213c0097,0x6d451898,0x9e2000db,0x00000000}},	//   _heuh_, ókar, _كۉتو, --, 
   {{0x39411899,0x7afc1afd,0x7c2c025c,0x7bcc0064}},	//   taks_, ęsto, _ħaru, _įaud, 
   {{0xbcb461ff,0x213c003e,0x00000000,0x00000000}},	//   _обещ, _jeuh_, --, --, 
   {{0x6f0000d2,0xd5b80421,0x213c0129,0x9f441155}},	//   _tíbí, _ēā_, _meuh_, dlnú_, 
   {{0x3940033d,0x213c00d5,0x9f440418,0xc04c0023}},	//   saks_, _leuh_, koní_, _ኣይተፈ, 
   {{0xdb000232,0x0b8838b7,0x3941189a,0xd6c40022}},	//   _koní, _رضوي_, paks_, хивқ, 
   {{0x213c01f5,0x9f44004e,0x00000000,0x00000000}},	//   _neuh_, doní_, --, --, 
   {{0xb3846f34,0x80cc0037,0xdb0001ef,0xf7180064}},	// [1a180] млал, _देले, _moní, _міны_, 
   {{0x7bc1189b,0xe8f418ce,0x213c003e,0x9f45189c}},	//   nhlu, _юлы_, _aeuh_, foní_, 
   {{0xa3ac367a,0x213d189d,0x9f4400db,0xdb0001e1}},	//   _ओकर_, _beuh_, goní_, _ooní, 
   {{0x201c0a73,0x2244019f,0x60400521,0x7bc00327}},	//   _buui_, ânka_, _ọmar, hhlu, 
   {{0x7bc0a14d,0x213c00d5,0x9f4407de,0x614000d8}},	//   khlu, _deuh_, ponì_, теча, 
   {{0x7bc1189e,0xb0d00073,0x00000000,0x00000000}},	//   jhlu, _देणग, --, --, 
   {{0xdb0000cf,0x2d8400b0,0x2e480801,0x7bc0d739}},	//   _boní, _paoe_, цяло_, dhlu, 
   {{0xdb00d829,0x201c003e,0x7bc0014b,0x00000000}},	//   _coní, _fuui_, ehlu, --, 
   {{0xdb000248,0x61400e92,0x6ad411a0,0x00000000}},	//   _doní, _шета, डप्र, --, 
   {{0x7bc1189f,0xee70013d,0x962800e2,0x7c2c031c}},	//   ghlu, _аңкы, _kuņģ, _ħart, 
   {{0x213c3386,0x2d8401ee,0xdb000248,0xf1c000cd}},	//   _yeuh_, _taoe_, _foní, _शतान, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7bc001d4,0x310c00dc,0xa6f80154,0x00000000}},	//   bhlu, िधिः_, _আলেম_, --, 
   {{0x7bc0351e,0x8a100139,0x00000000,0x00000000}},	//   chlu, _әҗмә, --, --, 
   {{0x9a804908,0xcc88004d,0x81a800fe,0xdb0001e1}},	//   _ауыл, _hớ_, গোট_, _yoní, 
   {{0x2b4c045a,0xfd640241,0x00000000,0x00000000}},	//   _hdfc_, _satẹ, --, --, 
   {{0xe9dc01f1,0x439518a0,0x7c2c0200,0x4cb003d4}},	// [1a190] mnú_, наас, _çart, _জেতু, 
   {{0xe3000156,0xe9dc01f1,0x9f440418,0x213c003e}},	//   _མཛདཔ_, lnú_, toní_, _seuh_, 
   {{0x41542c75,0xe9dc007b,0xd5bc0248,0x7534116e}},	//   евес, onú_, _kọ́_, bbyz, 
   {{0xe9dd18a1,0x9f440137,0x201c013c,0xd2580354}},	//   nnú_, roní_, _puui_, ьцу_, 
   {{0xe4e400d6,0x213c0109,0x9f440093,0xb03400fd}},	//   _цінн, _veuh_, soní_, емчә, 
   {{0xe9dc0597,0x01c800dd,0x213c0098,0xd5bc01e1}},	//   hnú_, _کورٹ_, _weuh_, _lọ́_, 
   {{0xfe7118a2,0x7bc00211,0xdb0118a3,0x7bdcd256}},	//   ادت_, vhlu, _poní, ésum, 
   {{0x22440e96,0xf7880724,0x201c0270,0x7bc00117}},	//   ánku_, _kiçä_, _tuui_, whlu, 
   {{0xe9dc01a2,0xc0ac005e,0x7c2c003d,0xcc8801fb}},	//   dnú_, ﺰﻣﻪﺗ, _ħars, _cớ_, 
   {{0x66c0022e,0x1fa469a1,0x00000000,0x00000000}},	//   _yеkt, _ўраг, --, --, 
   {{0xa3b4367a,0xd5bc0248,0x998000b0,0x7bc001a8}},	//   _जवन_, _bọ́_, _whiō_, rhlu, 
   {{0x8d747092,0x7bc118a4,0xe9dc01e7,0x7c2c0139}},	//   _لاها, shlu, gnú_, _ƅorı, 
   {{0x66e0039b,0xb4ac0ce0,0xf78800fd,0x7bc0a75f}},	//   ҳора, _कथे_, _niçä_, phlu, 
   {{0x399805d5,0x9ba002dd,0xe9dc00ae,0x00000000}},	//   füsà_, _شەجى, anú_, --, 
   {{0xe9dc01f1,0xd5bc0248,0x7f400327,0x57e000bc}},	//   bnú_, _fọ́_, _melq, _नदीह, 
   {{0xca7402dc,0x66c0022e,0x7c2d18a5,0xe9dc00d0}},	//   _рушы, _rеkt, _çars, cnú_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [1a1a0] --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x27fc0198,0xae5c0150,0x92000ca8,0x00000000}},	//   ɓun_, _ﺍﻛﺎﯞ_, bọ́, --, 
   {{0xdb007172,0x00000000,0x00000000,0x00000000}},	//   _monà, --, --, --, 
   {{0x7f4118a6,0x9f4518a7,0xe3600075,0x00000000}},	//   _belq, fonà_, _әкси, --, 
   {{0xe9dd18a8,0xf1a8258c,0x61e80010,0xcc880051}},	//   znú_, _کاسه_, čgla, _rớ_, 
   {{0x7f400455,0xf678010f,0xcc880051,0xe9dc00d7}},	//   _delq, לאַמ, _sớ_, ynú_, 
   {{0xa7f80789,0x7c2c025c,0xe9dc0419,0x00000000}},	//   muñe, _ħarr, xnú_, --, 
   {{0xe9dc01f1,0x00000000,0x00000000,0x00000000}},	//   vnú_, --, --, --, 
   {{0x4f8400dd,0x7e6c094a,0xcc8801fb,0x7f40036e}},	//   _جارہ, ńapa, _vớ_, _gelq, 
   {{0x2ec518a9,0xe9dc01f1,0x00000000,0x00000000}},	//   _ثقاف, tnú_, --, --, 
   {{0xcc880016,0xdb00004e,0x9f441132,0x2d8800e2}},	//   _tớ_, _donà, moná_, ēbes_, 
   {{0x98b80801,0xe9dc01f1,0x56941d00,0x00000000}},	//   елят_, rnú_, қатт, --, 
   {{0xe9dcb231,0xd5bc0241,0x00000000,0x00000000}},	//   snú_, _wọ́_, --, --, 
   {{0xa7f80428,0xf8ad18aa,0xe9dc00d0,0x45d4ac57}},	//   juñe, مکی_, pnú_, вовс, 
   {{0xe3bc002e,0x6b8918ab,0xf7880139,0x00000000}},	//   _muñe_, _hafg, _piçä_, --, 
   {{0x6b88017a,0x23c401e1,0xf7880139,0xe4d40244}},	// [1a1b0] _kafg, _níjù_, _qiçä_, رترب, 
   {{0x6d4118ac,0x9f4402fb,0xdb0001ef,0x00000000}},	//   _leoa, koná_, _honá, --, 
   {{0xdb000122,0xd25000dd,0xa280004b,0x53e4009d}},	//   _koná, ینے_, دیزو, уцта, 
   {{0x6d4118ad,0xdb00ea19,0x40340120,0x00000000}},	//   _neoa, _joná, ведс, --, 
   {{0x7f40044e,0xdb000005,0x6a7401b8,0x657c0113}},	//   _pelq, _moná, _yüfö, meqh, 
   {{0x7f4118ae,0x657d02bb,0x00000000,0x00000000}},	//   _qelq, leqh, --, --, 
   {{0x645d18af,0x6d40045f,0x7c2c0327,0xbea518b0}},	//   luqi, _beoa, _ħarq, тайк, 
   {{0x657c0944,0x628402d0,0xbbb812eb,0xef940352}},	//   neqh, _isjo, इस्क, екәш_, 
   {{0x6d4000a8,0x7f400135,0xcd280ada,0x99940327}},	//   _deoa, _telq, رسين_, ġeżi_, 
   {{0xdb0000ae,0x7f9400c7,0x00000000,0x00000000}},	//   _aoná, _шазх, --, --, 
   {{0x6d400b23,0x645c014b,0x6b88007c,0x00000000}},	//   _feoa, huqi, _dafg, --, 
   {{0x645c1253,0x6d4118b1,0xdb000332,0xbc380150}},	//   kuqi, _geoa, _coná, _قستا_, 
   {{0xbb8400c6,0xdb0083a8,0x00000000,0x00000000}},	//   _للشي, _doná, --, --, 
   {{0x6d4001a9,0xdce800c0,0xcd0400d4,0x00000000}},	//   _zeoa, _sagė, _спій, --, 
   {{0xdce80024,0x09c00154,0xdb00007c,0x70500023}},	//   _pagė, _উদরা, _alnö, _ኣይትጸ, 
   {{0xbcb400b5,0x645c0023,0xc9d000d1,0x00000000}},	//   _mie侍_, fuqi, ﺗﺎﻟﻐ, --, 
   {{0x645c0357,0x62840158,0xa52118b2,0x6b88011f}},	// [1a1c0] guqi, _asjo, рмуд, _yafg, 
   {{0x35c40034,0x28dc01bc,0x00000000,0x00000000}},	//   रोज़, नपरि, --, --, 
   {{0x657c0944,0xdb0000dd,0x6284007c,0x00000000}},	//   beqh, _elnö, _csjo, --, 
   {{0xa7f8eb5e,0x645c2798,0x62840af9,0x00000000}},	//   ruñe, buqi, _dsjo, --, 
   {{0x6440071b,0x69a00490,0x850400ec,0xceb000ec}},	//   ćnic, गाती, _موٽن, ڍڙا_, 
   {{0x6d40056a,0x00000000,0x00000000,0x00000000}},	//   _seoa, --, --, --, 
   {{0x6d4118b3,0xee8408b9,0x6b88032e,0x7fc40066}},	//   _peoa, тыло, _rafg, دآنل, 
   {{0x6b88022e,0x00000000,0x00000000,0x00000000}},	//   _safg, --, --, --, 
   {{0x9c6005d9,0x6d4000c5,0x4ea40032,0xdb000332}},	//   لهيو, _veoa, трҙа, _roná, 
   {{0xe3bc00e4,0xb1c4010b,0x28b001ad,0xe0600345}},	//   _tuñe_, _яңҗа_, ुनसि, _ئێوی, 
   {{0xdea03a56,0x657c0921,0xdee118b4,0xa5b000e1}},	//   _نیوی, yeqh, _кофи, _इकलौ, 
   {{0x3ed8008f,0xfcc00032,0x00000000,0x00000000}},	//   _אַנא, рҙәм, --, --, 
   {{0x7c2c43eb,0xdb0000e5,0x00000000,0x00000000}},	//   _çarp, _voná, --, --, 
   {{0x6b88037e,0x57f40108,0x00000000,0x00000000}},	//   _uafg, ипят, --, --, 
   {{0x645c0921,0x9aa004d3,0xe6102674,0x386401e4}},	//   wuqi, _نموو, لشر_, _ĥore_, 
   {{0x645c0054,0x9f4402fb,0x59c400db,0x00000000}},	//   tuqi, dlný_, _ۅيۉك, --, 
   {{0x59640395,0x00000000,0x00000000,0x00000000}},	// [1a1d0] _тъща, --, --, --, 
   {{0x657c0117,0xd49800a7,0x38980375,0x645c378b}},	//   seqh, ърс_, _ניתנ, ruqi, 
   {{0x7bdc04cc,0x39500142,0x45d41422,0x645c0009}},	//   ésui, _ydys_, _бонс, suqi, 
   {{0xfb1400c8,0x51540aac,0xa5b801d3,0x00000000}},	//   אַנט_, атшу, _sióf, --, 
   {{0x80cc006d,0x81d40729,0x645c07d6,0x7fd40953}},	//   _देखे, সকল_, quqi, лікі, 
   {{0x62840b21,0xa5b85b84,0x27e0003e,0x442918b5}},	//   _tsjo, _bióg, nnjn_, mqa_, 
   {{0x442918b6,0x00000000,0x00000000,0x00000000}},	//   lqa_, --, --, --, 
   {{0x8cd42366,0x3ea83c52,0x442918b7,0xa5b81ada}},	//   _बेहो, ćat_, oqa_, _dióg, 
   {{0xa3b4069f,0x44281bb7,0x7c9400f7,0x4058f8f1}},	//   _जवा_, nqa_, اشبا, _سلاح_, 
   {{0x44280067,0x00000000,0x00000000,0x00000000}},	//   iqa_, --, --, --, 
   {{0x644c003a,0x4428016d,0xdb0118b8,0x00000000}},	//   _lvci, hqa_, _monç, --, 
   {{0xdcf828b5,0x442918b9,0xd32028d4,0x6e380677}},	//   leuč, kqa_, _बल्ब_, _נתנד, 
   {{0xeb8cf95e,0x442918ba,0x312c0240,0x00000000}},	//   _ли_, jqa_, _ብዓበይ, --, 
   {{0x6c50026a,0x442918bb,0x8b9400a7,0xbb44013d}},	//   _укљу, dqa_, _връч, _секк, 
   {{0x7c2918bc,0x644c4e7e,0x442918bd,0x00000000}},	//   lqer, _avci, eqa_, --, 
   {{0x442918be,0x00000000,0x00000000,0x00000000}},	//   fqa_, --, --, --, 
   {{0x64a118bf,0xb0d0068f,0x7c28d6a4,0x442918c0}},	// [1a1e0] бата, _देंग, nqer, gqa_, 
   {{0xdb0118c1,0xdd000024,0xbec01bce,0x00000000}},	//   _conç, ūrėk, _ñëwe, --, 
   {{0x442918c2,0x644c05d1,0x7afc033f,0xa5b80332}},	//   aqa_, _evci, ęstw, _biód, 
   {{0x249c0989,0x442918c3,0x764c29c2,0xb0e918c4}},	//   _šume_, bqa_, msby, ндез_, 
   {{0x44280784,0xa9180008,0x764d18c5,0xa5b918c6}},	//   cqa_, ldþr, lsby, _diód, 
   {{0xdb0118c7,0x9f440306,0x00000000,0x00000000}},	//   _konä, plný_, --, --, 
   {{0xa7f80054,0x764c1f53,0x3d100037,0x6aa004aa}},	//   nuña, nsby, देसे_, _ओपेर, 
   {{0xc1d400fd,0x764c017a,0x41b001d9,0x20c03d09}},	//   _көчә, isby, _وۅلر, рйәм, 
   {{0x2b4405f5,0x2fd80a11,0xdb000139,0x00000000}},	//   лэнг, _كورد_, _yonç, --, 
   {{0xa7f918c8,0xe3bc0588,0xe0d40063,0xdb0003e3}},	//   kuña, _kuña_, _сву_, _xonç, 
   {{0x8cd405d7,0xdd8c0f5c,0x442918c9,0x00000000}},	//   _बेरो, _лш_, zqa_, --, 
   {{0x44280bf1,0x316518ca,0x764c0250,0xa7f801c4}},	//   yqa_, ngoz_, dsby, duña, 
   {{0xec30006c,0x764c003a,0x00000000,0x00000000}},	//   _اوتگ, esby, --, --, 
   {{0x31640399,0x442918cb,0x00000000,0x00000000}},	//   hgoz_, vqa_, --, --, 
   {{0x31640007,0xdb0000db,0x442918cc,0x00000000}},	//   kgoz_, _ronç, wqa_, --, 
   {{0x2efc06af,0x00000000,0x00000000,0x00000000}},	//   _mytf_, --, --, --, 
   {{0x03d518cd,0x44281db9,0xdb0118ce,0x18681f5a}},	// [1a1f0] ажаю, uqa_, _ponç, _бањи_, 
   {{0x442918cf,0xdb0118d0,0xa7f80005,0x764c01bf}},	//   rqa_, _fonä, buña, bsby, 
   {{0x442918d1,0xd4049d39,0x7afc012c,0xe3bc09c2}},	//   sqa_, сяти, řstv, _cuña_, 
   {{0xe3bc0784,0x14d00cb4,0x442918d2,0xb63c01ec}},	//   _duña_, _सेकण, pqa_, _ﺁﺏ_, 
   {{0x3f680f37,0x8cd4000d,0xdb000139,0xdce800de}},	//   вило_, _बेलो, _tonç, _vagī, 
   {{0x3c280008,0x7e547758,0x0234035c,0x316401c4}},	//   _rúv_, атиц, _نظرگ, agoz_, 
   {{0x7de000e2,0x00000000,0x00000000,0x00000000}},	//   lēsi, --, --, --, 
   {{0xf2d006a9,0xe1fc0241,0x00000000,0x00000000}},	//   _ועל_, _óó_, --, --, 
   {{0x61f8c53d,0x33b00137,0xcc0800ec,0xbd4400f1}},	//   _ikul, _دەەر, گزين_, هنګي, 
   {{0xab6000ee,0xbed4cc30,0x7d780451,0x764c0142}},	//   şüni, _козј, _ڄمار_, ysby, 
   {{0x61f918d3,0x41b865c5,0xcfa40a5b,0x5e3000e5}},	//   _kkul, _आवास, _ушти, _اڑتا, 
   {{0x764c01e3,0x62e40154,0x656800a3,0x3c280419}},	//   vsby, _করায়_, òghl, _túv_, 
   {{0x61f85053,0x7c2820ac,0x3d1000dc,0xa7f802d1}},	//   _mkul, qqer, देशे_, wuña, 
   {{0xa7f918d4,0x764ca2ec,0x31640007,0xab240cb6}},	//   tuña, tsby, zgoz_, _коша_, 
   {{0x61f918d5,0x00000000,0x00000000,0x00000000}},	//   _okul, --, --, --, 
   {{0x61f918d6,0x39340953,0xa7f8260d,0x66e000d4}},	//   _nkul, _тэкс, ruña, іота, 
   {{0x741518d7,0xa7f80054,0x764c0efa,0x7afc3d44}},	// [1a200] لورا, suña, ssby, ęstu, 
   {{0x61f918d8,0xa7f80054,0xe3bc0005,0x764c03cd}},	//   _akul, puña, _puña_, psby, 
   {{0xa7f80227,0xf10c6956,0xa758011a,0xb6a47de7}},	//   quña, िध्द_, _בדיר, _тинл, 
   {{0xea7404ac,0xa498007f,0xd5a43b93,0x7de00171}},	//   יגער_, _dyòb, _الحی, bēsi, 
   {{0xb9100a28,0x3164005a,0x21640107,0xe52000d4}},	//   tvaṃ_, rgoz_, ричи_, _єдрп, 
   {{0xdfccaa79,0xa2ac012d,0x00000000,0x00000000}},	//   وين_, ूनख्, --, --, 
   {{0xb9100a28,0x61f803a0,0xa2e118d9,0xd4c402dd}},	//   rvaṃ_, _fkul, _дорд, _төңк, 
   {{0xdd94a2ff,0x7c2c002b,0x00000000,0x00000000}},	//   ашь_, _ũara, --, --, 
   {{0xdfcc00b2,0x15a41c5c,0x25ac04cc,0x3028003b}},	//   _ڪيل_, ﺎﺳﺘﯩ, ögli_, _розп_, 
   {{0xabb000db,0x00000000,0x00000000,0x00000000}},	//   تەتع, --, --, --, 
   {{0xdfccf18a,0x0c94e647,0x38640115,0x8a1801c6}},	//   _تيل_, _گداگ, _ĥora_, лоос_, 
   {{0xdeb805e1,0xdd8c0075,0xa5b80332,0xca8401c6}},	//   _שמאל, _يول_, _mióc, агүй, 
   {{0x9848014b,0xdc64014b,0xe4700205,0x00000000}},	//   ияра_, _вачд_, ücüğ, --, 
   {{0xdcf80259,0x248806d1,0x1d0518da,0x9b911147}},	//   lduğ, _rscm_, _течи_, _ولنت, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x59d4286d,0x53a40020,0xdcf8050e,0x00000000}},	//   _وغير, _ለማየት_, nduğ, --, 
   {{0x44981507,0xeff00023,0xe60000ee,0xf8b4004e}},	// [1a210] ываю_, _ውጹዕ_, йҗүн, _лөр_, 
   {{0xa3b40574,0xa7f8056a,0x7de0005f,0x00000000}},	//   _जवळ_, muño, rēsi, --, 
   {{0xdb0001e6,0xc2740120,0x00000000,0x00000000}},	//   _tonå, слеј, --, --, 
   {{0xa5b80615,0xe0d06ea9,0x00000000,0x00000000}},	//   _dióc, يزش_, --, --, 
   {{0x7980002e,0xe05401d3,0xa7f81bce,0xe4a416a4}},	//   _ñowe, شیات_, nuño, _трно, 
   {{0xff5065dc,0x7050007b,0x00000000,0x00000000}},	//   سخت_, أنوا, --, --, 
   {{0xd34400e5,0x00000000,0x00000000,0x00000000}},	//   _ذہنی, --, --, --, 
   {{0x61f902b5,0xed4c0075,0x0eb80220,0xd244013d}},	//   _ukul, ىپى_, рушы_, _фэри, 
   {{0x9f680022,0xf0780139,0x00000000,0x00000000}},	//   _арез_, _йитә_, --, --, 
   {{0xcce4104b,0xa7f8002e,0xdb0001e7,0xfce45f0f}},	//   تسىي, duño, _ionú, _қоло, 
   {{0xf988efc3,0xdef800c0,0x00000000,0x00000000}},	//   هندي_, _рыа_, --, --, 
   {{0x3b5400d1,0x00000000,0x00000000,0x00000000}},	//   шкүр, --, --, --, 
   {{0xe3bc04d4,0x7bdc00d2,0x78a000de,0x00000000}},	//   _nuño_, ésus, _šovb, --, 
   {{0x30d800c8,0x366800d8,0x00000000,0x00000000}},	//   אַלע, лаго_, --, --, 
   {{0xe73403f6,0xfa3518db,0x7afc0210,0x00000000}},	//   сес_, _ارتد, ęsts, --, 
   {{0xd1bc1e38,0x249c1591,0xe3bc056a,0x2a34007b}},	//   ታታት_, _šuma_, _buño_, _اكيد_, 
   {{0x798518dc,0xe3bc04d4,0x64a118dd,0xf50918de}},	// [1a220] mekw, _cuño_, пата, унал_, 
   {{0x7bc118df,0x798518e0,0xd76518e1,0xe3b428e5}},	//   nklu, lekw, _بندی, ббу_, 
   {{0xdce800da,0xdcf80259,0xfe64190f,0x7bc08e5d}},	//   _angļ, yduğ, _تگ_, iklu, 
   {{0x798518e2,0xf0d00521,0x7bc118e3,0x38700240}},	//   nekw, bịlọ, hklu, _kqyr_, 
   {{0x7bc0fcf4,0x92d80011,0x2bc800cd,0xdcf80205}},	//   kklu, াথে_, िसमा, vduğ, 
   {{0x798518e4,0x232518e5,0x717405d9,0x7bc001f5}},	//   hekw, _гори_, _گهرا, jklu, 
   {{0xddc8000a,0x79840796,0x7bc06130,0xdcf80213}},	//   _šiši, kekw, dklu, tduğ, 
   {{0x717518e6,0x7984c341,0x9184129d,0x7bc000ef}},	//   _دهرا, jekw, _گۇچۇ, eklu, 
   {{0xe3bc36ed,0xdcf8050e,0xf1940166,0x798518e7}},	//   _xuño_, rduğ, _киңь, dekw, 
   {{0x7bc118e8,0xa4b40302,0x4a5422c3,0xc34401e1}},	//   gklu, צליה_, окос, _ẹ̀tó, 
   {{0xee3918e9,0x5f34025d,0xa7f8002e,0xe8b00037}},	//   _сне_, _הטבע_, wuño, ुन्च, 
   {{0x798401b2,0xa7f800e8,0xa9c401a9,0x00000000}},	//   gekw, tuño, ссок, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7bc118ea,0xa7f80de2,0x86440124,0xe664020f}},	//   cklu, ruño, жьаҵ, йтбо, 
   {{0x798453ff,0x9f4403a0,0x6440110c,0xa7f800e8}},	//   bekw, tonú_, ćnim, suño, 
   {{0xe3bc09c2,0x798518eb,0x00000000,0x00000000}},	//   _puño_, cekw, --, --, 
   {{0xe9dc00c6,0x6e200109,0x87c4010b,0xe7840108}},	// [1a230] miú_, _miob, _дөвз, _луно, 
   {{0xe9dd18ec,0x6e209a14,0x645c031c,0x00000000}},	//   liú_, _liob, rrqi, --, 
   {{0xec6400ec,0xe8e800f1,0x00000000,0x00000000}},	//   _ڪٿ_, _جرګو_, --, --, 
   {{0xdb000038,0xe9dc0597,0x7bc001e4,0x00000000}},	//   _ponú, niú_, zklu, --, 
   {{0x7ff518ed,0x656c1197,0x00000000,0x00000000}},	//   يستا, _icch, --, --, 
   {{0x44386553,0x7bc01b9c,0x74c000f1,0x4fe800d4}},	//   _its_, xklu, _کښېن, бмін_, 
   {{0x798518ee,0xdfcd18ef,0x38b00139,0xdb2008a5}},	//   yekw, ويچ_, _kеrä_, _árét, 
   {{0x6e2118f0,0x443918f1,0x79844b2a,0x7bc118f2}},	//   _ciob, _kts_, xekw, wklu, 
   {{0x6e2118f3,0x44380472,0xe9dc00c6,0x7bc00726}},	//   _diob, _jts_, diú_, tklu, 
   {{0x798518f4,0x69cc025a,0x3b8401c0,0x4438045a}},	//   wekw, ëben, цлог, _mts_, 
   {{0x656c0bda,0x798518f5,0x3b0813e7,0xf9848701}},	//   _occh, tekw, рено_, огно, 
   {{0x64401591,0x443918f6,0xe9dd18f7,0x8fc402dd}},	//   ćnij, _ots_, giú_, _وزەن, 
   {{0x443918f8,0x798518f9,0x7bc094fc,0xf9880214}},	//   _nts_, rekw, pklu, هنگي_, 
   {{0x798518fa,0x656d18fb,0xd91001ed,0x17c8013e}},	//   sekw, _acch, ویں_, сҳои_, 
   {{0x443918fc,0xec1000f7,0x1b0001c6,0xe9dc0332}},	//   _ats_, _توود, _хүнн, biú_, 
   {{0x443918fd,0x7e6c0054,0xa80118fe,0x7984009a}},	//   _bts_, ńapw, _çınl, qekw, 
   {{0xdb0001c7,0x00000000,0x00000000,0x00000000}},	// [1a240] _onnë, --, --, --, 
   {{0x656c265a,0x59a80a59,0x3dcc0327,0x00000000}},	//   _ecch, गावर, hhew_, --, 
   {{0x443918ff,0xe2951900,0x656c0175,0x0ed91901}},	//   _ets_, жах_, _fcch, _भेंड, 
   {{0xd1311902,0xb9dc0020,0x44391903,0x216414a4}},	//   رمت_, _ጤና_, _fts_, жици_, 
   {{0x6e211904,0x00000000,0x00000000,0x00000000}},	//   _riob, --, --, --, 
   {{0xc05800d6,0x6e211905,0x3cfc0307,0xce94008e}},	//   сії_, _siob, _लड़े_, закъ, 
   {{0x6e211906,0x7c38015d,0x00000000,0x00000000}},	//   _piob, _atwr, --, --, 
   {{0x44391907,0x6e200175,0x9e011908,0x386001c7}},	//   _yts_, _qiob, мчыл, krkr_, 
   {{0x7de000e2,0x998000a2,0x7c2c00ae,0x00000000}},	//   vēst, _ikiň_, _éarl, --, 
   {{0x7aec0882,0x32044f1a,0x1f6000f7,0xf0d00521}},	//   _śata, lloy_, _окум, hịkọ, 
   {{0xe9dc0597,0x78a0031c,0x6e201cf8,0x0ca80853}},	//   tiú_, _ġova, _tiob, ртқи_, 
   {{0xb4a80cf9,0x3dcd181c,0x6e2001fa,0x78a0005f}},	//   bot혼_, chew_, _uiob, _šova, 
   {{0xe9dc0491,0x6440098d,0xa5b80789,0x58d4020a}},	//   riú_, ćnik, _bión, доят, 
   {{0xf8ac1f7b,0xe9dc0597,0xdb00007f,0x7c2c025c}},	//   چکی_, siú_, _onnè, _ħarx, 
   {{0xf8ac80c2,0x56951909,0x163477c1,0x656d190a}},	//   نکی_, март, деся, _pcch, 
   {{0x4439190b,0x96f9190c,0x84340212,0xc1b866c0}},	//   _pts_, цест_, знає, _आवेग, 
   {{0xdb00180f,0x443800d8,0x00000000,0x00000000}},	// [1a250] _annè, _qts_, --, --, 
   {{0x228401b9,0xa5b80208,0x00000000,0x00000000}},	//   жудг, _gión, --, --, 
   {{0x44380263,0xaac863a5,0xf770011a,0x00000000}},	//   _wts_, ानिक, _אקי_, --, 
   {{0xd1b80128,0x32040174,0x656d190d,0x00000000}},	//   يانا_, gloy_, _ucch, --, 
   {{0x4439190e,0xdb000100,0x6e3802d0,0xa08800fd}},	//   _uts_, _ennè, _attb, рсез_, 
   {{0x9f4420ef,0xce3401d3,0xaac81c15,0x9f48013d}},	//   onné_, ڈووک, ानाक, _ülüe_, 
   {{0x3dcd190f,0xe51c3c71,0x53351910,0xac800022}},	//   thew_, _मृति_, _цест, ҵгыл, 
   {{0xad5000d1,0x3da800d8,0x00000000,0x00000000}},	//   ىنىغ, скио_, --, --, 
   {{0xdb00007b,0x6e391911,0x69cc01ab,0xbdc000db}},	//   _inné, _ettb, dhce, _ۋەتۋ, 
   {{0x3dcd1912,0x9ac00166,0x00000000,0x00000000}},	//   shew_, диоҗ, --, --, 
   {{0x3dcd1913,0x61e91914,0x7c94221d,0xfaa428a8}},	//   phew_, ongl, زشکا, чано, 
   {{0x22448ea8,0x61e89584,0x20051915,0xa5b80332}},	//   ánky_, nngl, llni_, _sión, 
   {{0x61e91916,0xa9a11917,0x7c38000f,0xeaac01ed}},	//   ingl, хияд, _utwr, نٹی_, 
   {{0xe7351918,0x61e8409c,0x63a4003e,0xdb200517}},	//   зер_, hngl, _nnjn, _قوشی, 
   {{0xdb00f760,0x32040548,0xf60800f1,0x00000000}},	//   _onné, yloy_, متره_, --, 
   {{0x69cc0232,0x61e91919,0x3944022e,0x00000000}},	//   chce, jngl, _эниг, --, 
   {{0xc0c80023,0xb464109a,0xd5b00014,0x200401a9}},	// [1a260] _ጠቒሱ_, якал, _یہس_, klni_, 
   {{0xdb002047,0x7995191a,0xe4547da1,0xdb200241}},	//   _anné, _hayw, яжу_, _àrót, 
   {{0x799403f0,0xb2240137,0x67b805d0,0xc9d400f2}},	//   _kayw, чмел, _המיק, _رمیک, 
   {{0x799403f0,0x2005191b,0x00000000,0x00000000}},	//   _jayw, elni_, --, --, 
   {{0x92bc2158,0x7995191c,0xe041191d,0x64a001c0}},	//   ইছে_, _mayw, енчи, _заяа, 
   {{0xdb0001ed,0x61e80afa,0x00000000,0x00000000}},	//   _enné, angl, --, --, 
   {{0x59cc00a5,0x8cd405d7,0x320464fe,0x3ce800d7}},	//   ासार, _बेजो, ploy_, _ľava_, 
   {{0x7994017a,0x00000000,0x00000000,0x00000000}},	//   _nayw, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x0a3c0201,0x79940083,0x6f6403b7,0x9f4402f0}},	//   _የተለያ, _aayw, _ѕвез, ynné_, 
   {{0x79941c06,0xa5b82cd7,0x76580024,0x28cc1a4e}},	//   _bayw, _biól, štyj, सैनि, 
   {{0xdd8d191e,0x00000000,0x00000000,0x00000000}},	//   _موم_, --, --, --, 
   {{0xdca01fbd,0x79940332,0x9dd40375,0x00000000}},	//   _паци, _dayw, _צודק_, --, 
   {{0x6fbc06ab,0xa498007f,0x9ac00a49,0x81d400cc}},	//   ्सिं, _dyòl, ŋŋam, িচয_, 
   {{0xdb780375,0x61e803cb,0xa5b803b2,0xdb000432}},	//   _הנוכ, yngl, _fiól, _koný, 
   {{0x38800134,0x7994017a,0xd5b825ff,0x00000000}},	//   _sɔre_, _gayw, псу_, --, 
   {{0x92bc00fe,0x69dc6fa3,0x2d3c0092,0x200426ec}},	// [1a270] ইছো_, _imqe, _በኢንቨ, ylni_, 
   {{0xa3d41533,0x4734e581,0x27480114,0x58d40354}},	//   ़ों_, _юнос, _учио_, _чоьт, 
   {{0xc32404c5,0x27e0364b,0x79940477,0x45d50897}},	//   মুনি_, mijn_, _yayw, _жонс, 
   {{0x27e00196,0x61e9191f,0xdb2001c7,0x79940166}},	//   lijn_, ungl, éréi, _xayw, 
   {{0x61e91920,0x00000000,0x00000000,0x00000000}},	//   rngl, --, --, --, 
   {{0x27e00196,0x2b4c0099,0x00000000,0x00000000}},	//   nijn_, _nefc_, --, --, 
   {{0x69dc0fec,0xc2c40592,0x00000000,0x00000000}},	//   _omqe, _غيري, --, --, 
   {{0x27e00d27,0x2004022e,0x7aec0055,0x00000000}},	//   hijn_, slni_, _śato, --, 
   {{0x799403f9,0x06e00154,0x20040306,0x7f58205a}},	//   _rayw, _মুমি, plni_, _маас_, 
   {{0x79941bb7,0x78a11921,0x00000000,0x00000000}},	//   _sayw, _šovo, --, --, 
   {{0x7994e689,0x00000000,0x00000000,0x00000000}},	//   _payw, --, --, --, 
   {{0x832c0003,0xdb000432,0x7994013d,0x06e00011}},	//   _ཧུའུ_, _goný, _qayw, _মুভি, 
   {{0xca749a79,0x3154008f,0x27e001f5,0x1c08000d}},	//   ونیک, וירן_, fijn_, _सीअल_, 
   {{0x79951922,0x00000000,0x00000000,0x00000000}},	//   _wayw, --, --, --, 
   {{0xf7711923,0x2bd853be,0x2bc80490,0x7994aba8}},	//   _یاد_, _بانک_, िसरा, _tayw, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb000793,0x27e0282c,0xa50403fb,0x74e801c6}},	// [1a280] _lonü, bijn_, дета_, цдаг_, 
   {{0x27e00196,0xa8000022,0x59cc0073,0xe360011c}},	//   cijn_, _изыл, ासवर, ккуи, 
   {{0x06e0009e,0x26c11924,0xac640240,0x00000000}},	//   _মুঠি, cyjo_, _ተነጺሉ_, --, 
   {{0x49140316,0x25fc0490,0xdb003cb2,0xa180008e}},	//   नेको_, लवणी_, _honó, вышл, 
   {{0xdb00011f,0x61e0007f,0x0ce800eb,0x205000c7}},	//   _konó, ènla, _পর্ত, ҭтәр, 
   {{0xa7f80113,0x00000000,0x00000000,0x00000000}},	//   tuñi, --, --, --, 
   {{0x0cb800dc,0xe9e400d7,0xfbb000cd,0xdd0038af}},	//   ेन्म, _žúmp_, जानम, _ārāt, 
   {{0x27e00196,0xf1a804d3,0x00000000,0x00000000}},	//   zijn_, _باسه_, --, --, 
   {{0x30c40ed1,0x5a40001f,0xa030516c,0x26c01165}},	//   ﯩﻠﻪﻧ, _የተሻሻ, _لىقت, zyjo_, 
   {{0xdb0000e4,0x00000000,0x00000000,0x00000000}},	//   _nonó, --, --, --, 
   {{0x3b7c0020,0x27e11925,0xada000d0,0x8d2801af}},	//   ባቢዎች_, vijn_, ľúbi, _енең_, 
   {{0x27e024d1,0x7afc03fa,0x2b4c0810,0x5ed400eb}},	//   wijn_, ßsta, _wefc_, _ঢুকে, 
   {{0x27e00d27,0xd83805f5,0xe3bc002e,0xeb980580}},	//   tijn_, дэс_, _wuñi_, _мид_, 
   {{0xdb011926,0xa7f80165,0x00000000,0x00000000}},	//   _conó, huñv, --, --, 
   {{0x27e11927,0xdb000077,0x0708038b,0xe3bc030a}},	//   rijn_, _donó, سيري_, _kuñv_, 
   {{0x69dc6ae5,0x9a80010b,0xd56400d1,0x26c063d0}},	//   _umqe, _рушл, ктуп, ryjo_, 
   {{0x27e00196,0x84140801,0x6d5c03a0,0xfa6002d3}},	// [1a290] pijn_, емах, _ēpal, _ተሰነይ_, 
   {{0x6b991928,0x69c47220,0x00000000,0x00000000}},	//   ndtg, ासकी, --, --, 
   {{0x3d0402f8,0xddc0084c,0xd4041d1b,0xed4400ec}},	//   _हुने_, nunţ, тяти, _ٽپ_, 
   {{0x45d40a5b,0x00000000,0x00000000,0x00000000}},	//   _чомс, --, --, --, 
   {{0xd1b91929,0x25a9192a,0x9f4405d5,0x647000c7}},	//   بالا_, _incl_, ponü_, _шҳау, 
   {{0xdb0012d9,0x9f4800ac,0x0ce800cc,0x25bc01f9}},	//   _monò, _ölüb_, _পৰ্ত, _एकुण, 
   {{0xd1580092,0x81d401c6,0x00000000,0x00000000}},	//   ወታቸው, _зовх, --, --, 
   {{0xdcf016a3,0xdce81f21,0xa7f8002e,0xbbb801ad}},	//   šače, _jagħ, muñu, ेस्क, 
   {{0xdce81f21,0xa7f8002e,0xa2c801bc,0x00000000}},	//   _magħ, luñu, थैर्, --, 
   {{0x9f440407,0xdce80135,0x50f40022,0x00000000}},	//   ronó_, _lagħ, _рзут, --, 
   {{0xef384be7,0x99800356,0xa7f80de2,0x25bc0073}},	//   ዮጵያው, _chiş_, nuñu, _एकूण, 
   {{0xdce8003d,0x9f4400c6,0xdb01192b,0xe3bc030a}},	//   _nagħ, inní_, _bonò, _guñv_, 
   {{0xe3bc02d1,0xdb01192c,0xadb40b24,0x00000000}},	//   _huñu_, _ponó, _سهوا_, --, 
   {{0x6aac00c6,0x6284002d,0xe3bc00e8,0x3d040034}},	//   óifí, _opjo, _kuñu_, _हुये_, 
   {{0xe3bc0113,0xdce80135,0xa7f80113,0xa8000077}},	//   _juñu_, _bagħ, juñu, éñas, 
   {{0x98ac03be,0xdce80327,0xe3bc00e8,0x5bdc0037}},	//   şdı_, _cagħ, _muñu_, _फगुव, 
   {{0x628400da,0xdce8031c,0xe3bc1bce,0x38640332}},	// [1a2a0] _apjo, _dagħ, _luñu_, _íor_, 
   {{0x25a804cc,0x00000000,0x00000000,0x00000000}},	//   _encl_, --, --, --, 
   {{0x6448019f,0xe3bc00e8,0x3951192d,0xb9240633}},	//   âgir, _nuñu_, _keys_, _تفکي, 
   {{0x78a00327,0x2ba4482a,0xe1f4022e,0x55c401af}},	//   _ġovj, _कोना, нгх_, _рамғ, 
   {{0x2b040d26,0x00000000,0x00000000,0x00000000}},	//   _सुनु_, --, --, --, 
   {{0xe3bc0694,0xdf540075,0xdb000137,0x3951192e}},	//   _buñu_, ىشىش_, _anní, _leys_, 
   {{0xaadc0c2e,0x7dd401ed,0xb640037e,0x6288033f}},	//   _फेंक, _másf, _ｏｋ_, łgor, 
   {{0x249c05ce,0xe3bc0694,0xec6801b9,0xdce80003}},	//   _šumi_, _duñu_, прок_, _xagħ, 
   {{0xef84084c,0xa06400d8,0x00000000,0x00000000}},	//   _плап, _пата_, --, --, 
   {{0x95300135,0xe3bc00e8,0x9ac01418,0x5ef800dc}},	//   _ཨུའི_, _fuñu_, _ŋŋaa, _लुक्_, 
   {{0xe3bc002e,0xdb000ba1,0xd33c0115,0x6da40d08}},	//   _guñu_, _sonò, _vorʈ, _пижа, 
   {{0xfcd402d3,0xddc0054e,0x00000000,0x00000000}},	//   _ርግጽ_, runţ, --, --, 
   {{0x588430cb,0xdd8d192f,0x26140120,0xdce8025c}},	//   лыра, _دون_, nçoe_, _ragħ, 
   {{0xe3bc1bce,0xdce8025c,0xddc00010,0x00000000}},	//   _yuñu_, _sagħ, munš, --, 
   {{0x9a802de5,0xdb980375,0x00000000,0x00000000}},	//   _буыл, _מסגר, --, --, 
   {{0x225c01e4,0x39500009,0xdce80003,0x0488010b}},	//   _ĉuk_, _geys_, _qagħ, мәги_, 
   {{0x290c035b,0xe9f000c7,0xa7f8002e,0x62851930}},	// [1a2b0] _ága_, _аҧҽы, wuñu, _spjo, 
   {{0xa7f8fb08,0x2ba40709,0x25fc01f9,0x00000000}},	//   tuñu, _कोमा, लवही_, --, 
   {{0xdce83aaf,0xb63400c7,0x4274010b,0x00000000}},	//   _tagħ, _аҧсу_, тгес, --, 
   {{0xd174748c,0xe4e400d4,0x00000000,0x00000000}},	//   гышы, _зігн, --, --, 
   {{0x249c0261,0xe3bc1bce,0x00000000,0x00000000}},	//   _éum_, _suñu_, --, --, 
   {{0xbf100139,0x00000000,0x00000000,0x00000000}},	//   аүзә, --, --, --, 
   {{0x73c05a0b,0x91040166,0x72a000d1,0x00000000}},	//   _тәте, кчәд, _پەنن, --, 
   {{0xc2240133,0xce180006,0x25bc0073,0x6d440174}},	//   _شکاو, нцыі_, _एकोण, ðkap, 
   {{0xe3bc00e8,0x3950818a,0xaa8000e4,0x00000000}},	//   _wuñu_, _reys_, ñýnt, --, 
   {{0xdb000165,0xe3bc002e,0xba7400f2,0x7afc0112}},	//   _sonñ, _tuñu_, پادت, ßsto, 
   {{0xe7e4045e,0x39500493,0x9e6400f7,0x3cfc012d}},	//   পকাঠ, _peys_, _ساان, _लडके_, 
   {{0x8d7404fb,0x2ba428f5,0x39507caa,0x4d74103f}},	//   _ماها, _कोठा, _qeys_, _مطهر, 
   {{0xeb8ccaef,0x39500139,0x00000000,0x00000000}},	//   _ки_, _veys_, --, --, 
   {{0x39501c1d,0xb9080073,0x00000000,0x00000000}},	//   _weys_, _मध_, --, --, 
   {{0x1ccc0489,0xe7351931,0x66e00022,0x978400f2}},	//   ུནམ_, тес_, аора, نیکه, 
   {{0x644c015d,0x06e00154,0xca7443a2,0x00000000}},	//   _bwci, _মুহি, _сушы, --, 
   {{0xe4c0ac3c,0x644c0368,0xf74400c7,0x00000000}},	// [1a2c0] айти, _cwci, _иепо, --, 
   {{0x98a005be,0xe5cc0055,0x3a280419,0x00000000}},	//   _agić_, _kāśā, _čapy_, --, 
   {{0xa680084c,0x00000000,0x00000000,0x00000000}},	//   _клэд, --, --, --, 
   {{0x644c0142,0x30e40150,0x00000000,0x00000000}},	//   _fwci, кілб, --, --, 
   {{0x644c03cb,0x7afc012d,0x8f847d9d,0x00000000}},	//   _gwci, ęsty, лқал, --, 
   {{0x9f8001c6,0x00000000,0x00000000,0x00000000}},	//   игчд, --, --, --, 
   {{0xe29439f6,0xe5cc002b,0x00000000,0x00000000}},	//   _иар_, _nāśā, --, --, 
   {{0x2bc84195,0x3f8401e4,0x00000000,0x00000000}},	//   िस्थ, _eblu_, --, --, 
   {{0xffa46073,0x70500345,0x00000000,0x00000000}},	//   _өлтү, _ئۆتا, --, --, 
   {{0xa0300131,0xa06400c7,0x00000000,0x00000000}},	//   _ئىلت, _шауа_, --, --, 
   {{0x2ba40574,0x00000000,0x00000000,0x00000000}},	//   _कोणा, --, --, --, 
   {{0x5ef800dc,0xe5cc002b,0x7dd40332,0x00000000}},	//   _लुट्_, _dāśā, _cásd, --, 
   {{0x2d84020c,0xfd5000b8,0x98b800d4,0x00000000}},	//   _iboe_, _nedṛ, влят_, --, 
   {{0x5ba00c04,0x2ca51932,0x00000000,0x00000000}},	//   _връз, _irod_, --, --, 
   {{0x45d51933,0x7bdc0240,0x25fc01f9,0x00000000}},	//   говс, ësue, लवली_, --, 
   {{0x2ba404fa,0x644c01ef,0x00000000,0x00000000}},	//   _कोता, _pwci, --, --, 
   {{0xfd5000b8,0xdb0002d2,0x274801c4,0x48c40166}},	// [1a2d0] _cedṛ, _inná, _очно_, _сәна, 
   {{0x3d0400c5,0x27e408a5,0x00000000,0x00000000}},	//   _हँसे_, _önn_, --, --, 
   {{0x7dd408ce,0x00000000,0x00000000,0x00000000}},	//   _háse, --, --, --, 
   {{0x249c16a3,0x7dd400e4,0xe3bc05c7,0x2ca40067}},	//   _šumu_, _káse, _puñs_, _orod_, 
   {{0x008422f7,0x7a2400a3,0x00000000,0x00000000}},	//   улло, _dųth, --, --, 
   {{0x9f4402d3,0x2d840549,0x26140490,0x63e000db}},	//   minë_, _aboe_, _भीती_, _ئيسە, 
   {{0x7dd51934,0x9f4402d3,0x622007d2,0x9184129d}},	//   _láse, linë_, _نوسە, _چۇمۇ, 
   {{0x918404a9,0xdb00014a,0x27880023,0x442001c3}},	//   _نۇمۇ, _konö, _ህዝብኻ_, lmh_, 
   {{0x9f4402d3,0xdb00014a,0x80f43dc8,0x44200e89}},	//   ninë_, _jonö, _спах, omh_, 
   {{0x2ca40076,0x22400165,0xdb0000e7,0xf1b400c7}},	//   _drod_, _ktjk_, _anná, _аӡә_, 
   {{0x39e83117,0x442035b8,0xdb00014a,0x9f440023}},	//   едно_, imh_, _lonö, hinë_, 
   {{0x2ca407ab,0x9f4402d3,0x7dd51935,0x20b400e1}},	//   _frod_, kinë_, _báse, _आपाध, 
   {{0x9f440023,0x2ca403d5,0x0cd400d4,0x00000000}},	//   jinë_, _grod_, _коцю, --, 
   {{0xeb951936,0x17c80364,0x9ba00131,0x9f440023}},	//   _биш_, тҳои_, _ئەدى, dinë_, 
   {{0x2ca402f0,0x00000000,0x00000000,0x00000000}},	//   _zrod_, --, --, --, 
   {{0x44200007,0x9f440023,0x3dcc007f,0x69cc0200}},	//   emh_, finë_, nkew_, ëbet, 
   {{0xb3851937,0xe5a11938,0x9f440240,0xe6b0010b}},	// [1a2e0] ллал, щити, ginë_, _iýýä, 
   {{0x2488011c,0xdb000205,0x44200332,0x969402f2}},	//   _dpcm_, _donö, gmh_, _پیرش, 
   {{0xb1440276,0x9f44033b,0x7dd402f0,0x00000000}},	//   гнел, minè_, _záse, --, 
   {{0x4420387b,0x9f440783,0x1da0012d,0x00000000}},	//   amh_, binë_, _खोलत, --, 
   {{0x9f4402d3,0x442000a3,0x1c001fd2,0x00000000}},	//   cinë_, bmh_, रकाल_, --, 
   {{0x5ef800dc,0x4420003e,0xa5b84347,0xa8000205}},	//   _लुङ्_, cmh_, _chóf, _çıtl, 
   {{0x3f640220,0x00000000,0x00000000,0x00000000}},	//   ртіб, --, --, --, 
   {{0x2ca40408,0xe294005b,0xe0d401c6,0x00000000}},	//   _prod_, _щас_, _өвс_, --, 
   {{0x3204625d,0x261400d8,0x8bd40063,0x4ea401e0}},	//   mooy_, nçoa_, ижиц, урҙа, 
   {{0x32051939,0x261400d8,0x9f44be6d,0x20c000db}},	//   looy_, içoa_, jinè_, _уйум, 
   {{0x9f45193a,0x49d80212,0x16046d65,0x00000000}},	//   zinë_, вдню_, लवार_, --, 
   {{0x2e140597,0x2ca5193b,0x3d05193c,0x3204011f}},	//   _صباح, _trod_, _हुवे_, nooy_, 
   {{0x2ca5193d,0x24580ca8,0x44200175,0xa5b801d3}},	//   _urod_, _màmá_, ymh_, _miót, 
   {{0xe6b00209,0x9f45193e,0x3204f32c,0x5d1001f7}},	//   _eýýä, ginè_, hooy_, _اِها, 
   {{0x24883e17,0xe61000f1,0x320400e8,0x65a8009d}},	//   _spcm_, مشر_, kooy_, нтаг_, 
   {{0xdb002776,0x9f44044e,0x3ce80153,0x00000000}},	//   _ponö, tinë_, _žavi_, --, 
   {{0x4420020b,0x44b40220,0x9f4402e2,0xf8b43e52}},	// [1a2f0] tmh_, шбас, binè_, _көр_, 
   {{0x9f44069c,0xa5b800e4,0x69cc00df,0x442008c2}},	//   rinë_, _ohóg, lkce, umh_, 
   {{0x9f44044e,0x9389193f,0xa5b85b84,0x69cc0076}},	//   sinë_, ыста_, _biót, okce, 
   {{0x69cd1940,0x7dd4a896,0x9f451941,0xe45c008c}},	//   nkce, _másc, pinë_, _tvö_, 
   {{0x9f451942,0xe4c402d5,0x7dd40118,0x518428f3}},	//   liné_, _сённ, _lásc, суха, 
   {{0x53340b00,0x00000000,0x00000000,0x00000000}},	//   _герт, --, --, --, 
   {{0x422800c7,0x9f4400f2,0xa5b800ae,0x3204058a}},	//   _ахаҭ_, niné_, _chóg, booy_, 
   {{0x69cc01a4,0x3d18033f,0xbc640b00,0x00000000}},	//   jkce, _परदे_, авик, --, 
   {{0x61e91943,0x9f451944,0x2ba4000d,0x00000000}},	//   migl, hiné_, _कोहा, --, 
   {{0x61e91945,0xa5b80597,0x7dd43eba,0x9f440066}},	//   ligl, _fhóg, _básc, kiné_, 
   {{0x7dd51946,0x9f451947,0x3d9400d8,0x3b080114}},	//   _cásc, vinè_, _виер, ђемо_, 
   {{0x20051948,0x61e91949,0x9f45194a,0x7c941ec7}},	//   loni_, nigl, diné_, _نشتا, 
   {{0x2004033d,0xe8f416ab,0x9f44020c,0xa5b80332}},	//   ooni_, илю_, tinè_, _mhód, 
   {{0x2005194b,0x61e89acd,0x9f45194c,0xf400025c}},	//   noni_, higl, finé_, _མཉེད_, 
   {{0x9f45194d,0x61e8409c,0xf6080424,0x32043010}},	//   giné_, kigl, نتره_, yooy_, 
   {{0x2005194e,0xa7f80227,0x9ba00131,0x32040548}},	//   honi_, suñp, _ئەگى, xooy_, 
   {{0x2005194f,0x61e91950,0xd9103765,0x65a80139}},	// [1a300] koni_, digl, _ریس_, _söhä, 
   {{0x2004f7c6,0x9f440066,0xf7440640,0x290c00d0}},	//   joni_, biné_, _њено, ímať_, 
   {{0x20051951,0x61e8c044,0x9f44004a,0x3204058a}},	//   doni_, figl, ciné_, tooy_, 
   {{0x61e80ffb,0x35a51952,0xa5b82f5e,0xdb000139}},	//   gigl, _тамг, _chód, _innä, 
   {{0x81cc00bd,0x64a001c0,0x27fc0036,0x3204058a}},	//   ষোভ_, _даяа, éung_, rooy_, 
   {{0x20051953,0x26151954,0xbf200490,0x32043a73}},	//   goni_, nçon_, मधून_, sooy_, 
   {{0x61e91955,0xa498067c,0x2ba406b1,0x00000000}},	//   bigl, _exòd, _कोषा, --, 
   {{0x61e8db10,0x32040de2,0x7dd40332,0xeda4bf77}},	//   cigl, qooy_, _rásc, ршко, 
   {{0x200419f8,0x9f44020c,0x31080022,0xa2cc01e1}},	//   boni_, ziné_, _рнап_, _lọ́j, 
   {{0x20051956,0xa5b80597,0x7dd406ed,0x0a58001f}},	//   coni_, _thóg, _pásc, _ለተለያ, 
   {{0x7bdc02d3,0x00000000,0x00000000,0x00000000}},	//   ësua, --, --, --, 
   {{0xece80724,0x9f440129,0x09f8007b,0x00000000}},	//   _идел_, viné_, افحة_, --, 
   {{0xa3e41533,0x2b047971,0x69cc03ee,0x6d40009f}},	//   _बगल_, _सुरु_, rkce, _ifoa, 
   {{0x9f4404fb,0x7dd400c6,0xd7f89313,0xaae4764c}},	//   tiné_, _tásc, аус_, _پستو, 
   {{0xd7f8b4cb,0x00000000,0x00000000,0x00000000}},	//   руя_, --, --, --, 
   {{0x9f440214,0x28a4095f,0x00000000,0x00000000}},	//   riné_, खिदि, --, --, 
   {{0x61e8f622,0xf94804ac,0x9f4404fb,0xe784dd92}},	// [1a310] vigl, _געפֿ, siné_, _куно, 
   {{0x20051957,0x7dd51958,0x9f440066,0x61e80042}},	//   xoni_, _mása, piné_, wigl, 
   {{0x61e91959,0x9f44025a,0xa3b84e5c,0x7dd5195a}},	//   tigl, finî_, _یاسر_, _lása, 
   {{0x2005195b,0x1af400df,0x00000000,0x00000000}},	//   woni_, סמאל_, --, --, 
   {{0x61e9195c,0x9f4402f6,0xdb00713c,0x7dd40306}},	//   rigl, ynnä_, _innå, _nása, 
   {{0x61e9195d,0x4439195e,0x6d41195f,0x6aa80368}},	//   sigl, _ius_, _afoa, _orff, 
   {{0x61e82b1d,0xe61c0016,0x9d10015b,0xd24401c6}},	//   pigl, _khô_, _হলেন_, _мэти, 
   {{0x44391960,0x7dd51961,0xe0e401a9,0xc034009b}},	//   _kus_, _bása, _кўзо, _гнај, 
   {{0x20051962,0xfce51963,0x29183b28,0x61f85d53}},	//   poni_, сопо, _nzqa_, _ijul, 
   {{0x44380e37,0x200403b4,0x6d40005a,0x8d2800fd}},	//   _mus_, qoni_, _efoa, шның_, 
   {{0x44380b89,0x44311964,0x6d40015d,0x9ce400e5}},	//   _lus_, _miz_, _ffoa, _ھوتے_, 
   {{0x44300399,0x44380137,0x3cfc0457,0x61f80083}},	//   _liz_, _ous_, _txwv_, _jjul, 
   {{0x44391965,0x7dd51966,0x443001c4,0x7984017a}},	//   _nus_, _gása, _oiz_, rfkw, 
   {{0x61f80552,0x9e8c0023,0xd1c40023,0xab6000fd}},	//   _ljul, _መርትዖ_, _ጸዓት_, _çüpr, 
   {{0x44391967,0x7dd403c6,0x61f91968,0x26150dcf}},	//   _aus_, _zása, _ojul, rçon_, 
   {{0x443000da,0x61f866b0,0x44391969,0xdb08002e}},	//   _aiz_, _njul, _bus_, _ñiñu, 
   {{0x44308bf2,0x4439196a,0x37e4010b,0x261406af}},	// [1a320] _biz_, _cus_, _гопг, pçon_, 
   {{0x4439196b,0x4431196c,0x61f9196d,0x33181272}},	//   _dus_, _ciz_, _ajul, هزاد_, 
   {{0x44380ad3,0x443003b7,0x55c4016c,0x3940007f}},	//   _eus_, _diz_, _данғ, ocks_, 
   {{0x3940030a,0x261457bf,0x443005c7,0xa5b8012d}},	//   ncks_, nçol_, _eiz_, _wiór, 
   {{0x4439196e,0x4431196f,0x00000000,0x00000000}},	//   _gus_, _fiz_, --, --, 
   {{0x44311970,0x437498c1,0x161c09d9,0x61f91971}},	//   _giz_, _муст, _भीतर_, _ejul, 
   {{0x44391972,0x7dd4007b,0x00000000,0x00000000}},	//   _zus_, _sása, --, --, 
   {{0x44380190,0x44300bc2,0x7dd409c2,0xe81c47b8}},	//   _yus_, _ziz_, _pása, _मीना_, 
   {{0x44380190,0x44311973,0x8bd8084c,0x2bc800cf}},	//   _xus_, _yiz_, имис_, гуно_, 
   {{0x44300005,0x9f44026c,0x7c3800a2,0x00000000}},	//   _xiz_, ninì_, _duwr, --, 
   {{0x7aec0882,0xec3001b9,0x1dd401c6,0xfb8407d6}},	//   _śatr, _کوتگ, рлөө_, تگنی, 
   {{0xc32400cc,0x00000000,0x00000000,0x00000000}},	//   মুকি_, --, --, --, 
   {{0x6e391974,0x4bc401c0,0x3a3000a2,0xfca80014}},	//   _hutb, _дөнг, _diyp_, _پانو_, 
   {{0x6e380429,0x00000000,0x00000000,0x00000000}},	//   _kutb, --, --, --, 
   {{0x44391975,0x44311976,0x48e8007d,0xe61c01fb}},	//   _sus_, _riz_, _चेरो_, _phô_, 
   {{0x44391977,0x1b0802f5,0x6e382bdd,0x061402bf}},	//   _pus_, হেহে_, _mutb, ідаю, 
   {{0x44300c86,0x4438e952,0x06e0009e,0x6e3801ab}},	// [1a330] _piz_, _qus_, _মুখি, _lutb, 
   {{0x6e391978,0x44391979,0x6d8c1682,0x44300fed}},	//   _outb, _vus_, _ṱali, _qiz_, 
   {{0x4439197a,0x4431197b,0xe61c01fb,0xa5b800ae}},	//   _wus_, _viz_, _thô_, _chóc, 
   {{0x44380e37,0xa5b801e7,0x4430045a,0x3d180037}},	//   _tus_, _dhóc, _wiz_, _परले_, 
   {{0x4439197c,0x4431197d,0x7dd40122,0xe054a268}},	//   _uus_, _tiz_, _básn, صیات_, 
   {{0x6e38089c,0x185c00c8,0x22587c3c,0x44300427}},	//   _butb, רכגע, _مجرب_, _uiz_, 
   {{0xfe780364,0x6e380009,0xc904012c,0x61f9197e}},	//   рӯз_, _cutb, रथुम_, _tjul, 
   {{0x61f9197f,0x2d8800dd,0x9f440270,0x0eb802dd}},	//   _ujul, őben_, miní_, сушы_, 
   {{0x9f451980,0xc3240eac,0x00000000,0x00000000}},	//   liní_, মুখি_, --, --, 
   {{0xdb000077,0x9f4401e7,0x00000000,0x00000000}},	//   _innú, oiní_, --, --, 
   {{0xca3c04a9,0x601c00d8,0x6ea801d9,0x6e380112}},	//   _ﺑﯩﺮ_, gême, _پننہ_, _gutb, 
   {{0xee2c4e19,0x7dd40306,0xc04c0023,0x8ed800ae}},	//   _ін_, _zásn, _ዝተሰው, _اذكر_, 
   {{0xf7451981,0x39400036,0x261400db,0x00000000}},	//   жего, rcks_, rçol_, --, 
   {{0x7dd400e4,0xd1bc001f,0x00000000,0x00000000}},	//   _káso, ሳሳተ_, --, --, 
   {{0x26140077,0x6e391982,0x00000000,0x00000000}},	//   açom_, _xutb, --, --, 
   {{0x7dd4066d,0x660c3e39,0x9f440306,0xe81c0da3}},	//   _máso, _ckck, diní_, _मीठा_, 
   {{0x26140077,0xa5b801e7,0x8cac0456,0xdce800ef}},	// [1a340] cçom_, _shóc, जियो, _nagļ, 
   {{0x63b80198,0xa5b8007b,0x7bc0003e,0xedb429d9}},	//   _ɗung, _phóc, njlu, _आच्छ, 
   {{0x7dd402fb,0x00000000,0x00000000,0x00000000}},	//   _náso, --, --, --, 
   {{0x6e38022e,0x764c01e3,0x00000000,0x00000000}},	//   _rutb, mpby, --, --, 
   {{0x92bc0d42,0x6e3804cc,0x6ac002f5,0x9f440332}},	//   েছে_, _sutb, শনযো, ainí_, 
   {{0x6e380280,0x601c019f,0x7bc00327,0x00000000}},	//   _putb, yême, jjlu, --, 
   {{0x7dd40124,0x7d1400ac,0xc42401b9,0x6e391983}},	//   _cáso, əzsi, _رِِی, _qutb, 
   {{0x11f80014,0x834801d9,0x7d400023,0xa5b80208}},	//   _اورک_, _نشہِ_, _ኣበርቲ, _khóa, 
   {{0x2b5c003a,0x7aec0055,0x22bc0210,0x00000000}},	//   tatc_, _śatp, ałką_, --, 
   {{0x7dd40413,0x644801e4,0x80b808a3,0x00000000}},	//   _hásl, ŭgig, ्हरे, --, 
   {{0xdfcc215e,0xed44cf02,0xdce800e2,0xee38010a}},	//   _جيل_, _днеп, _zagļ, _тне_, 
   {{0x601c019f,0x00000000,0x00000000,0x00000000}},	//   rême, --, --, --, 
   {{0x7dd42195,0x6e211984,0x00000000,0x00000000}},	//   _záso, _ihob, --, --, 
   {{0x26140798,0xc3240011,0xfa54136e,0x00000000}},	//   rçom_, মুটি_, _کروگ, --, 
   {{0x6e211985,0x06e0015b,0xe81c012d,0x9a800150}},	//   _khob, _মুজি, _मीणा_, _жуыл, 
   {{0xd5b91986,0x7dd403c6,0x6e20031c,0x6d1c37bb}},	//   осу_, _násl, _jhob, _पराग_, 
   {{0x04580597,0xe9dc00c6,0x6e20015d,0xd83800cf}},	// [1a350] صلاة_, mhú_, _mhob, _мээ_, 
   {{0x57f51987,0x73c000fd,0x7d1c03b2,0x00000000}},	//   _опыт, нәсе, ýssi, --, 
   {{0x6680036b,0x555400cf,0x00000000,0x00000000}},	//   _تیزل, سپەر, --, --, 
   {{0x6e20031c,0x00000000,0x00000000,0x00000000}},	//   _nhob, --, --, --, 
   {{0x9f440270,0xc5f8012c,0x7dd40419,0x601c0022}},	//   siní_, ्कीय_, _sáso, vêmb, 
   {{0x6e200134,0x1da01715,0x7dd40122,0x2d800428}},	//   _ahob, _खोजत, _páso, òken_, 
   {{0x6e211988,0x9f44011f,0xc694008f,0xf41000d9}},	//   _bhob, tinâ_, לאַ_, _נפל_, 
   {{0xbca40597,0x6e211989,0xb2200008,0xdb0003cd}},	//   كمبي, _chob, áætl, _innø, 
   {{0x601c006a,0x6e203dc2,0x9f44003a,0x0054009f}},	//   rêmb, _dhob, rinâ_, _رَاج, 
   {{0x7dd402fb,0x1ea80451,0x601c00e4,0x3b84009d}},	//   _zásl, _پائي_, sêmb, члог, 
   {{0x3b09198a,0x7f1805d9,0x9f45198b,0x6e200332}},	//   сено_, _اياز_, minà_, _fhob, 
   {{0x6e21198c,0x66002959,0x9f44026c,0xf2d0008f}},	//   _ghob, _ínkh, linà_, געט_, 
   {{0x8d7403e6,0x2ba477ca,0xdb00036e,0x00000000}},	//   _زانا, _कोका, _kanë, --, 
   {{0x59c80490,0x9f440109,0x4bb401c6,0xdb000200}},	//   _लवकर, ninà_, _ойчс, _janë, 
   {{0xe9dc00c6,0xf62403fb,0x00000000,0x00000000}},	//   bhú_, здво, --, --, 
   {{0x6e200472,0xb900015b,0x9f4405d5,0xe9dc9655}},	//   _xhob, _দশ_, hinà_, chú_, 
   {{0xdce800fd,0xe978011a,0x00000000,0x00000000}},	// [1a360] _kagı, _הנפש, --, --, 
   {{0x9f440ffb,0x764c713c,0x71440023,0xdef00023}},	//   jinà_, ppby, ሕድሕዶ, ፍርን_, 
   {{0x9f4407c5,0xa5b80241,0xd5a401d5,0xfe64210e}},	//   dinà_, _ihón, _قلدی, _جگ_, 
   {{0xa5b9198d,0x2164fe08,0xdb000036,0xd5e00316}},	//   _hhón, зици_, _aanë, _नतिज, 
   {{0xa5b800d2,0x6e201dc2,0x00000000,0x00000000}},	//   _khón, _rhob, --, --, 
   {{0x9f45198e,0xc32c2002,0xdb00036e,0x739800d8}},	//   vinã_, _چەك_, _canë, _утмс_, 
   {{0x6e21198f,0x66d401b8,0xa5b80332,0xdb00036e}},	//   _phob, mükö, _mhón, _danë, 
   {{0x21a02e58,0x6e211990,0x66d40793,0xdd940022}},	//   _писм, _qhob, lükö, пшь_, 
   {{0xdce80598,0xa5b80022,0xaf351991,0x9d100395}},	//   _bagı, _ohón, _فرات, ндъч, 
   {{0x9f451992,0x7e6c0054,0xdb000100,0x66d4014a}},	//   rinã_, ņapa, _kanè, nükö, 
   {{0x6e20644f,0xe9dc0491,0xdb000100,0xdce8294f}},	//   _thob, thú_, _janè, _dagı, 
   {{0xdb011993,0x26140365,0x9f444b91,0x7af400e5}},	//   _manè, rçok_, pinã_, úzta, 
   {{0xa5b91994,0xdb000100,0x7de400c6,0xdce80139}},	//   _bhón, _lanè, _تسلم, _fagı, 
   {{0xdc3404ac,0xaa651995,0x7d1d1996,0xa5b91997}},	//   _זאגט_, _етик, üsse, _chón, 
   {{0x66d4014a,0xe9dc00d2,0x6b991998,0xa5b801e7}},	//   dükö, phú_, metg, _dhón, 
   {{0x6b980c86,0xe1a804fa,0x96f808b7,0x2614000d}},	//   letg, _घोंघ, чест_, _भीखी_, 
   {{0x9f440270,0x66d4014a,0xa5b801e7,0xdce800fd}},	// [1a370] hiná_, fükö, _fhón, _yagı, 
   {{0x9f4440f7,0x66d4014a,0xc0bc069d,0x6b9802d0}},	//   kiná_, gükö, _ተሰማ_, netg, 
   {{0xdb000ba1,0x9f451999,0xf77008a8,0x4adc08ec}},	//   _canè, vinà_, _בקי_, मनिव, 
   {{0x7dd40122,0x9f440122,0xdb0000cf,0x6b9807de}},	//   _pásm, diná_, _danè, hetg, 
   {{0x66d40793,0x9f45199a,0xdb000200,0xa088008e}},	//   bükö, tinà_, _panë, ссез_, 
   {{0xdb0004cc,0x6b9807c5,0xf788010f,0x00000000}},	//   _fanè, jetg, ַנפֿ, --, 
   {{0x9f45199b,0x92943e4f,0x6b99199c,0xbea401af}},	//   giná_, _парц, detg, файк, 
   {{0x53341920,0xe3bc2158,0x56b80302,0x657c0007}},	//   _чест, _ইতিব, לפון_, ngqh, 
   {{0x7dd41873,0x63a40219,0x6b9805d5,0x9f4405d5}},	//   _hásk, _kajn, fetg, pinà_, 
   {{0x63a5199d,0x6b99199e,0xff24004b,0xdce80139}},	//   _jajn, getg, _قبای, _qagı, 
   {{0x3ed4275c,0x63a4f3f7,0xdb01199f,0xdce80166}},	//   _تقار, _majn, _kané, _vagı, 
   {{0x63a519a0,0xa5b800d2,0x7dd519a1,0x3cd428e8}},	//   _lajn, _shón, _másk, _ожес, 
   {{0x7dd403c6,0xa5b80016,0xdce80724,0xdb0119a2}},	//   _lásk, _phón, _tagı, _mané, 
   {{0x63a519a3,0x0c2410f5,0x6b980077,0x7d1c03b2}},	//   _najn, _змін, cetg, ýssu, 
   {{0xe73519a4,0xec10d0f7,0x7dd440db,0x2ba40709}},	//   дер_, _جوود, _násk, _कोटा, 
   {{0xdb0001ef,0x00000000,0x00000000,0x00000000}},	//   _nané, --, --, --, 
   {{0xdb000502,0x66d4014a,0x63a519a5,0xb3c80114}},	// [1a380] _sanè, tükö, _bajn, олаз_, 
   {{0xdb0119a6,0xa29c12eb,0x95840210,0x00000000}},	//   _panè, _गैह्, _żądz, --, 
   {{0x63a40007,0xa5b800d2,0xdb0119a7,0xf62405f5}},	//   _dajn, _khól, _bané, _одоо, 
   {{0xdb005fe6,0xda0007f7,0x6b983368,0x00000000}},	//   _cané, ोकित_, zetg, --, 
   {{0x1cd46d7e,0x63a519a8,0xdb0119a9,0x66d4014a}},	//   ོགས_, _fajn, _dané, pükö, 
   {{0x63a400c8,0x5f900364,0x06640bce,0x7dd408a5}},	//   _gajn, вишт, _تایپ, _fásk, 
   {{0xdb0119aa,0x7dd402d2,0x0084004e,0x00000000}},	//   _fané, _gásk, _үксү, --, 
   {{0xdb000066,0xec6919ab,0x6b980d47,0x2ba4044b}},	//   _gané, орок_, wetg, _कोजा, 
   {{0x6b98b804,0x23800008,0x7dd519ac,0x63a4014f}},	//   tetg, _þrjá_, _másh, _yajn, 
   {{0x4a5519ad,0x0a3c0020,0x63a4002e,0x0f1c0092}},	//   нкос, _ከተለያ, _xajn, ስመልከ, 
   {{0xceb846e8,0x6b9919ae,0xdd8d19af,0xdb000008}},	//   _хәл_, retg, _چوم_, _ennþ, 
   {{0xdd8d19b0,0x6560013f,0x9f44003a,0xa5b801e7}},	//   _نوم_, ɔnhw, ginæ_, _chól, 
   {{0x6fc00490,0x6b9807c5,0x58840fca,0xe7841171}},	//   लापू, petg, кыра, муво, 
   {{0xeb3400db,0xdca000f3,0xfd600055,0x00000000}},	//   _قىشد, _раљи, davṛ, --, 
   {{0x63a519b1,0xe6100597,0x00000000,0x00000000}},	//   _rajn, نشر_, --, --, 
   {{0xe81c7f1a,0x63a400dd,0x694401b9,0x00000000}},	//   _मीरा_, _sajn, _غضبل, --, 
   {{0x843919b2,0x63a519b3,0x69dc0009,0xdb0119b4}},	// [1a390] سكار_, _pajn, _ilqe, _rané, 
   {{0xdb0119b5,0x63a40240,0x00000000,0x00000000}},	//   _sané, _qajn, --, --, 
   {{0x63a519b6,0xa5b800d2,0xdb00525e,0x63c00032}},	//   _vajn, _hhóm, _pané, наҡҡ, 
   {{0x63a402d1,0x7dd403b2,0x00000000,0x00000000}},	//   _wajn, _gásh, --, --, 
   {{0x63a404b9,0xca3c0131,0x5185007b,0x00000000}},	//   _tajn, _ﺑﯩﺰ_, туха, --, 
   {{0x842404a9,0x187c0302,0x644c0007,0x70740952}},	//   _سىزن, קטוב, _itci, رمىز_, 
   {{0x92688395,0x53340139,0xdb0119b7,0x7dd408a5}},	//   _орта_, _аерт, _tané, _hási, 
   {{0x6e906a87,0xa5b80124,0xdcf401ed,0xd738011a}},	//   اليا, _ohóm, وہات_, וטות_, 
   {{0x518519b8,0x3f880198,0x9f440393,0x101400db}},	//   _шура, ƙau_, vinæ_, ربۇد, 
   {{0x7dd400dd,0xa5b80332,0x9f4403e0,0x00000000}},	//   _mási, _shól, dinç_, --, 
   {{0x656cb224,0x7dd4a746,0x9f44003a,0xcce40150}},	//   _odch, _lási, tinæ_, _ﺍﻷﺼل_, 
   {{0x644c1710,0x7dd40798,0x6d44002e,0x00000000}},	//   _otci, _oási, ñkat, --, 
   {{0x261406ed,0x9f4519b9,0x7dd40122,0xeaad19ba}},	//   nçou_, ginç_, _nási, _өй_, 
   {{0x656c514c,0xa5b80332,0xec6c00ec,0xe5a00131}},	//   _adch, _dhóm, _اٿو_, һиси, 
   {{0x9f44248c,0x644c00ef,0xb37400e5,0x75f8013a}},	//   minä_, _atci, ہداش, hůze, 
   {{0x7dd49ace,0xe5a0c3d1,0xa5b800ae,0x9f44248c}},	//   _bási, лиси, _fhóm, linä_, 
   {{0xc6d400d1,0xb37401b9,0xf8683cc6,0x00000000}},	// [1a3a0] ىتېت, فداش, _عمدي_, --, 
   {{0xa3dc0a28,0xdb000054,0x9f44005b,0x08e800eb}},	//   _ततः_, _janï, ninä_, _টুকু_, 
   {{0x27b00598,0xd58408ca,0x00000000,0x00000000}},	//   _сәяс, _иғво, --, --, 
   {{0x3f8519bb,0xa1810934,0x2a6800dd,0x9a8c001f}},	//   _aclu_, гышл, ábbi_, _እያደገ_, 
   {{0x9f44adae,0x7dd408ce,0x2d1c01ad,0xe29400c7}},	//   kinä_, _gási, _परेल_, _ҿар_, 
   {{0x9f440108,0x00000000,0x00000000,0x00000000}},	//   jinä_, --, --, --, 
   {{0x7dd40232,0x261400d8,0xadf000c7,0x9f4519bc}},	//   _zási, açou_, локә, dinä_, 
   {{0x9e002fe5,0x00000000,0x00000000,0x00000000}},	//   лчыл, --, --, --, 
   {{0x2f2400ae,0x5fa80037,0x008400cf,0x9e200137}},	//   _bígí_, _टोकल, _иктү, دىيو, 
   {{0xdb542f45,0xa0302dfc,0x3ea8033f,0x2614004e}},	//   нюю_, _مىقت, łata_, lçot_, 
   {{0x69f00228,0x2f240241,0x2a6801d3,0xc0ec0023}},	//   лүкт, _dígí_, ébb_, _ቆይሙ_, 
   {{0x316405c7,0xa850010b,0x6d440205,0x00000000}},	//   naoz_, лемә, ıkas, --, 
   {{0x2ee000cc,0x32e401e1,0x00000000,0x00000000}},	//   _বশিষ, _yíyé_, --, --, 
   {{0x2ca400a9,0x9f4405d1,0x6d440024,0x7dd519bd}},	//   _isod_, rinç_, žkad, _rási, 
   {{0x3ea40b0e,0x5694b34e,0x3164030a,0x9c140375}},	//   _xslt_, ларт, kaoz_, _רחוק_, 
   {{0x7dd4dcf0,0x2984010b,0xa8a40153,0x00000000}},	//   _pási, _чыкг, _зрок, --, 
   {{0xe4e40212,0x00000000,0x00000000,0x00000000}},	// [1a3b0] хівн, --, --, --, 
   {{0xdb00004e,0x00000000,0x00000000,0x00000000}},	//   _innò, --, --, --, 
   {{0x27f0022f,0x79e801ed,0x32e40241,0x00000000}},	//   _imxn_, _رویہ_, _ríyé_, --, 
   {{0x2ca519be,0x7ae400af,0x45d4327c,0x3ea40334}},	//   _osod_, _ühte, _ромс, _rslt_, 
   {{0x6f18007f,0x25a800a3,0xf08405a9,0x9f44005b}},	//   _aytc, _iacl_, ندوۋ, yinä_, 
   {{0x26140798,0xa5b80124,0x601c004d,0x7d180042}},	//   rçou_, _ohók, rêmo, _ryws, 
   {{0xde2c02d3,0x316400ca,0x62880311,0x9f44023a}},	//   _ብህይወ, baoz_, ăgos, vinä_, 
   {{0x6fb40166,0x00000000,0x00000000,0x00000000}},	//   егәр_, --, --, --, 
   {{0xa5b82137,0x26141b84,0x213c0066,0xfce519bf}},	//   _dióx, lços_, _iguh_, топо, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x26150448,0xdb0119c0,0x29180309,0x99881a59}},	//   nços_, _annò, _ayqa_, ىمدە_, 
   {{0x9f44adae,0x7cd8119e,0x0dc80117,0x00000000}},	//   sinä_, _омер_, _пучи_, --, 
   {{0x998000a2,0x9f44005b,0xd1cc0092,0x75f8013a}},	//   _ekiş_, pinä_, _በአብ_, hůzc, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x64484a1f,0xdb0020c0,0x628000cf,0x6fc01b87}},	//   ígin, _kaní, ànol, लातू, 
   {{0x213c0649,0xdb000306,0x25a8045a,0x00000000}},	//   _nguh_, _janí, _cacl_, --, 
   {{0xe5a119c1,0xb38519c2,0x741519c3,0xdce801e4}},	// [1a3c0] шити, клал, نورا, _tagĵ, 
   {{0x32d403f6,0x453407e6,0x22400200,0x00000000}},	//   кцес, ухст, _bujk_, --, 
   {{0x78b4009f,0x27740375,0x7dd41427,0x9f8806ea}},	//   _hryv, _בגין_, _hásu, _røð_, 
   {{0x78b40162,0xc2f0009e,0x55c401ec,0x00000000}},	//   _kryv, _জুহি_, _самғ, --, 
   {{0x216519c4,0xf8c001ad,0x2614004e,0xdfcc0451}},	//   тичи_, शमिय, rçot_, ڊين_, 
   {{0xdfccda22,0x213c020c,0xb4dc0034,0x60202bb6}},	//   يين_, _eguh_, तनी_, адча, 
   {{0xdb0002fb,0x79940034,0xdcf80115,0x7dd4032e}},	//   _baní, _obyw, rfuĝ, _lásu, 
   {{0x75240218,0x06d404c5,0xdb0004d4,0xe8fc0086}},	//   _kzkz, _হেডি, _caní, daûn_, 
   {{0xdb0119c5,0x9f880162,0x7dd40419,0x49a401ec}},	//   _daní, _tøð_, _násu, қынғ, 
   {{0x7994010e,0x236000e8,0x6e94007b,0x225c0210}},	//   _abyw, _xejj_, _للطا, _łuki_, 
   {{0x37b800bd,0x78b519c6,0xb4dc02c3,0xe3780a1e}},	//   ুসার, _aryv, तनु_, וריר, 
   {{0x7dd41427,0x5a34084c,0x2a7c01ab,0x00000000}},	//   _básu, инэт, rutb_, --, 
   {{0x5c700212,0x29180200,0x00000000,0x00000000}},	//   _вліт, _qyqa_, --, --, 
   {{0xdb00013a,0x00000000,0x00000000,0x00000000}},	//   _zaní, --, --, --, 
   {{0x78b40c8c,0x00000000,0x00000000,0x00000000}},	//   _eryv, --, --, --, 
   {{0x7c2c0395,0xdb000548,0x7dd46791,0x64480798}},	//   _èarr, _fanâ, _fásu, ígio, 
   {{0x439473ac,0xdb0000d8,0x290c0124,0x163462d9}},	// [1a3d0] лаас, _ganâ, _âga_, ретя, 
   {{0xa5b8007b,0x7dd41d1d,0xe0d03267,0xe6640107}},	//   _mhói, _hást, یزش_, _итмо, 
   {{0x7dd40122,0x213c003e,0x938800a7,0x00000000}},	//   _zásu, _pguh_, ъста_, --, 
   {{0x261519c7,0x78b40124,0x27ec033f,0x7b34010f}},	//   rços_, _yryv, żoną_, אָנע_, 
   {{0x7dd519c8,0x2b4c0175,0x461401b9,0x918403cc}},	//   _mást, _offc_, _لوگر, شۇلۇ, 
   {{0x7dd409d7,0x22400010,0xdb00008e,0x3f68005a}},	//   _lást, _tujk_, _saní, хико_, 
   {{0xd3a4005b,0x6e9000f1,0x00000000,0x00000000}},	//   _тряп, ملوا, --, --, 
   {{0x7dd403c6,0x0eb89684,0xa5b8007b,0x918400cf}},	//   _nást, тушы_, _bhói, _ەجەم, 
   {{0xa5b80491,0xdb0001d3,0xbb4400c0,0x00000000}},	//   _chói, _vaní, лепк, --, 
   {{0x7aa432e6,0xa5b8007b,0x7dd41427,0x403519c9}},	//   гиоз, _dhói, _rásu, _сезс, 
   {{0xdb005f48,0x3ed41e24,0x00000000,0x00000000}},	//   _taní, _حقار, --, --, 
   {{0x2b4c0198,0x7dd512fe,0xa5b8007b,0x8d7519ca}},	//   _effc_, _cást, _fhói, _ناها, 
   {{0x9988185e,0x9f440419,0x49c400fb,0x2dd8010f}},	//   ىمگە_, dinú_, рһын_, _אַגב, 
   {{0x78b40af9,0x00000000,0x00000000,0x00000000}},	//   _vryv, --, --, --, 
   {{0x7dd400c6,0x68e003e3,0x00000000,0x00000000}},	//   _fást, _əndi, --, --, 
   {{0x7dd519cb,0xa6c4cc53,0xd1bc02d3,0x78b4003b}},	//   _gást, ылса_, ዳታት_, _tryv, 
   {{0xb4dc5edd,0xdb0005da,0xc2f0009e,0xf50802e8}},	// [1a3e0] तने_, _hanà, _জুলি_, хнал_, 
   {{0x7dd519cc,0xdb000109,0x7f400455,0xd37000d1}},	//   _zást, _kanà, _nglq, غۇز_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x798519cd,0xdb0006d9,0x71750661,0x22445a5e}},	//   ngkw, _manà, اهشا, упци_, 
   {{0xdb00004e,0x7e6003ac,0x7dd401d3,0x41dc0327}},	//   _lanà, _awlp, _láss, ཱིཿཟ, 
   {{0xeea8e33b,0xcf94010b,0xa3dc00cd,0x00000000}},	//   етик_, рыдө, तसः_, --, 
   {{0x23242648,0xa5b800c6,0xdb000109,0x63a000af}},	//   _бори_, _shói, _nanà, õnne, 
   {{0x6ca44c04,0xa5b800ae,0x00000000,0x00000000}},	//   грож, _phói, --, --, 
   {{0x7dd519ce,0xed58013e,0x9f9400c7,0x1d040063}},	//   _rást, _ҷое_, _ӡыхә, лећи_, 
   {{0x7dd40597,0x257801e1,0x8bd801af,0x00000000}},	//   _sást, _kàlà_, тмос_, --, 
   {{0xdb0119cf,0x7dd519d0,0x2bc82cc8,0xed5801d5}},	//   _canà, _pást, _үлеп_, _зое_, 
   {{0xa5b8007b,0x6fc001f9,0x00000000,0x00000000}},	//   _thói, लावू, --, --, 
   {{0x6d4075ac,0x7dd409d7,0xb4dc00af,0xabb000fd}},	//   _igoa, _vást, तनो_, _галә, 
   {{0xdb0119d1,0x5fc40490,0x00000000,0x00000000}},	//   _fanà, लायल, --, --, 
   {{0x6d40073c,0x7dd40597,0xdb00004e,0x48b400fe}},	//   _kgoa, _tást, _ganà, ঁহেৰ, 
   {{0x6aa80142,0x7ae4000d,0xc0f00092,0x00000000}},	//   _isff, _ühta, ግግሩ_, --, 
   {{0xa5b80588,0x00000000,0x00000000,0x00000000}},	// [1a3f0] _ohóv, --, --, --, 
   {{0xdb000c5e,0x5ee400dc,0xe9dc00d7,0x3cd000fe}},	//   _haná, जनम्_, lkú_, _তেঁৱ, 
   {{0xdb0040cf,0x7ff4afe9,0x6d4119d2,0x7dd401ed}},	//   _kaná, یستا, _ogoa, _másr, 
   {{0x6d4119d3,0xa5b800e4,0xdb00022a,0x00000000}},	//   _ngoa, _ahóv, _janá, --, 
   {{0x601c06ed,0xdce8003d,0x00000000,0x00000000}},	//   lêmi, _ibgħ, --, --, 
   {{0xe1ec06d5,0x6d407c80,0xe9dc00d0,0xdb0002d2}},	//   _ṁṃṧ_, _agoa, hkú_, _innö, 
   {{0xd34400dd,0x975804ae,0xe9dc00d7,0x00000000}},	//   _اہمی, ניהו_, kkú_, --, 
   {{0xdb0002fb,0xbca416a2,0x02e00073,0x5184014b}},	//   _naná, لمبي, पनीन, _гуфа, 
   {{0x6aa80142,0x796000b5,0xe9dc00d0,0x00000000}},	//   _asff, のwim, dkú_, --, 
   {{0x8d2864a4,0x7dd406ed,0x6d4001c6,0xdb0001ab}},	//   ының_, _páss, _egoa, _panà, 
   {{0x4fc4c260,0x6fc119d4,0x3b081d83,0xdb001a09}},	//   _уста, लारू, тено_, _baná, 
   {{0xcda85872,0x601c06ed,0xc0f0001f,0xdb0017ba}},	//   _مهمه_, dêmi, ግግር_, _caná, 
   {{0x7dd401e7,0x7984017a,0x00000000,0x00000000}},	//   _fásr, rgkw, --, --, 
   {{0xdb0119d5,0x6aa800b5,0x59c4012c,0x17c80107}},	//   _tanà, _fsff, षाहर, уҳои_, 
   {{0xdb000aef,0x86780153,0xdcf80419,0x00000000}},	//   _faná, лёту_, nduľ, --, 
   {{0xe9dc01a2,0xdb0119d6,0x4420068c,0xf5040024}},	//   ckú_, _ganá, elh_, азбо, 
  
   {{0x442001ab,0x257801e1,0x9b34009d,0x95e400cf}},	// [1a400] flh_, _sàlà_, _шүүс_, _ۇيدۇ, 
   {{0xf3c88b4d,0xf7480451,0xdb0002f0,0xa3e400c7}},	//   خبره_, _جلدي_, _zaná, адуа_, 
   {{0xb144bdd4,0x601c0798,0x7c200076,0xaaac012c}},	//   анел, cêmi, illr, टिएक, 
   {{0x25640166,0x3dcc025c,0x00000000,0x00000000}},	//   _каюп_, jjew_, --, --, 
   {{0x51840184,0x208402e8,0xd1cc0092,0x5ef00154}},	//   ауҙа, ийци_, _በበቂ_, _চুলও_, 
   {{0x63b803f9,0x6d400076,0x442000a3,0x68b40a7c}},	//   _ɗunk, _sgoa, clh_, ילנא_, 
   {{0x6b8801ab,0xeda4004e,0x30880240,0x00000000}},	//   _rcfg, ашпо, _ዘውጽእ_, --, 
   {{0x9fa009cc,0x7dd519d7,0x6e4400ef,0x00000000}},	//   síðu_, _básq, _ļubļ, --, 
   {{0x6aac0118,0x00000000,0x00000000,0x00000000}},	//   टि्र, --, --, --, 
   {{0x6fd801ad,0xdb000419,0x32041180,0x00000000}},	//   _बकिं, _saná, lnoy_, --, 
   {{0x1cd40dd4,0x6250003d,0xdb0119d8,0x00000000}},	//   ོགཔ_, _għod, _paná, --, 
   {{0xa5b800e4,0x885801c6,0x7c2001e7,0x10540023}},	//   _ikóg, лимс_, allr, _ዝተቐመ, 
   {{0xdb0000d8,0xa5b800ae,0x7ae40037,0xeb8c01d5}},	//   _vaná, _mhót, _ühtn, _биp_, 
   {{0xe9dc0030,0xe784013e,0x7dd409e8,0x67e80205}},	//   skú_, шумо, _hásp, _müjg, 
   {{0xdb0000dd,0xa5b800c7,0x39500142,0x00000000}},	//   _taná, _ohót, _ffys_, --, 
   {{0x32040139,0x00000000,0x00000000,0x00000000}},	//   jnoy_, --, --, --, 
   {{0x442119d9,0x89d8004b,0x95c919da,0x601c00e4}},	// [1a410] tlh_, _لوګر_, шура_, sêmi, 
   {{0xd1b8c3a6,0xc0583baf,0x1cdc025c,0xdb0001bf}},	//   یانا_, ۇشتا_, ྤྱི_, _danæ, 
   {{0xa5b800c6,0x00000000,0x00000000,0x00000000}},	//   _bhót, --, --, --, 
   {{0xa5b919db,0x7dd401ef,0x00000000,0x00000000}},	//   _chót, _násp, --, --, 
   {{0xdb0003fa,0xa0a42cc8,0xa5b800ae,0xa088008e}},	//   _unnö, ршел, _dhót, тсез_, 
   {{0xa3a800c5,0x2394013a,0x00000000,0x00000000}},	//   _खसि_, _dějí_, --, --, 
   {{0xa49800cf,0xa5b80332,0x32040139,0x6d4400d7}},	//   _exòt, _fhót, bnoy_, ľkan, 
   {{0x814401d5,0x224400bc,0xdb0003e0,0x00000000}},	//   _طنطن, ínku_, _hanç, --, 
   {{0xdb000113,0x1fa40212,0xab6003b9,0x00000000}},	//   _kanç, _врег, _şüas, --, 
   {{0x7dd4fb19,0x62500135,0x7c200076,0x7c9402dd}},	//   _vásq, _iħob, ullr, _ۇشتا, 
   {{0x67e82fbe,0xdb004dd9,0xaa5401ed,0x2004022f}},	//   _müjd, _manç, یلیا_, mnni_, 
   {{0xdb0119dc,0x472c02d3,0x7c9400f2,0x7dd400e5}},	//   _lanç, _ተስፋማ, _هشتا, _gásp, 
   {{0x20040a4d,0x62500135,0xbb4402e8,0x00000000}},	//   onni_, _jħob, _лелк, --, 
   {{0xa5b800e4,0xfaa40452,0x00000000,0x00000000}},	//   _ohós, _гако, --, --, 
   {{0x32044249,0x200519dd,0x06d8190b,0x9f440332}},	//   ynoy_, inni_, афты_, ghné_, 
   {{0x2004007f,0x75440022,0x00000000,0x00000000}},	//   hnni_, сназ, --, --, 
   {{0x6250025c,0x8cac012d,0x00000000,0x00000000}},	// [1a420] _nħob, ड़ियो, --, --, 
   {{0xdb0119de,0x29ec0198,0x84700023,0x77840063}},	//   _canç, nƙan_, ባብሮን_, _улоз, 
   {{0xdb0119df,0x2904016b,0xa5b8007b,0x9f440419}},	//   _danç, _ɛnam_, _chós, chné_, 
   {{0xc8b4066d,0x00000000,0x00000000,0x00000000}},	//   _الیک, --, --, --, 
   {{0xa5b82833,0x75e802fb,0x00000000,0x00000000}},	//   _skóg, _výzd, --, --, 
   {{0xdb0119e0,0x320519e1,0x28980a7c,0x00000000}},	//   _kanä, snoy_, ריסא, --, 
   {{0x764c0007,0x75e800a2,0x61e801ab,0x00000000}},	//   nqby, _eýze, bhgl, --, 
   {{0x200519e2,0xb7fc03d4,0x61e81196,0xb63800b5}},	//   anni_, ংকিত_, chgl, _ｆｉ_, 
   {{0x8afc0034,0x81bc06af,0xdb000166,0x00000000}},	//   zbęd, _chœu, _yanç, --, 
   {{0x67e800a2,0x6fb400f1,0x00000000,0x00000000}},	//   _küje, _دمطا, --, --, 
   {{0x356c02d3,0x7ae400af,0xa5b800c6,0x28c800cd}},	//   ድናታት_, _ühtl, _mhór, ामभि, 
   {{0x14c85b67,0xba140451,0x67e800a2,0xaa4c0092}},	//   रमाण, يڊيا_, _müje, _አደረጋ, 
   {{0xa5b800c7,0x00000000,0x00000000,0x00000000}},	//   _ohór, --, --, --, 
   {{0xb9100a28,0x2ac40114,0x00000000,0x00000000}},	//   ntaṃ_, _гљив, --, --, 
   {{0xdb009096,0x00000000,0x00000000,0x00000000}},	//   _ranç, --, --, --, 
   {{0xdb0119e3,0x9f440122,0xa5b80789,0xd1f80092}},	//   _danä, diný_, _ahór, ላቀቅ_, 
   {{0xb9100a28,0xdb0119e4,0x02e00882,0x2004022c}},	// [1a430] ktaṃ_, _panç, पन्न, ynni_, 
   {{0xa5b800c6,0x3e540374,0xdb0119e5,0x7d1d19e6}},	//   _chór, _hāte_, _fanä, üssi, 
   {{0x45d40fbe,0x5fc42886,0x61e80042,0x00000000}},	//   _донс, लासल, thgl, --, 
   {{0x3e5400cd,0x65a800f3,0x00000000,0x00000000}},	//   _jāte_, _стог_, --, --, 
   {{0xa5b800c6,0x9258016c,0xe4c801d9,0x3e5400e2}},	//   _fhór, _ҳаст_, _صبحن_, _māte_, 
   {{0x7e5410ea,0x2004013c,0x7a1065c9,0xa5b80332}},	//   отиц, unni_, māte, _thós, 
   {{0x2004c1b5,0x67e8010e,0xdb000139,0x3f9000a2}},	//   rnni_, _güje, _xanä, _özum_, 
   {{0x9aa416a0,0x62500135,0x00000000,0x00000000}},	//   ەندە_, _tħob, --, --, 
   {{0x443119e7,0x200406c8,0x7aec0198,0x61f919e8}},	//   _khz_, pnni_, _ƙato, _imul, 
   {{0x29ec0198,0x2004022f,0x5e84109a,0x00000000}},	//   uƙan_, qnni_, _гудз, --, 
   {{0x4fc4b93d,0x00000000,0x00000000,0x00000000}},	//   _эста, --, --, --, 
   {{0x7a1119e9,0x5fc40a59,0x7ae4000d,0x957c0240}},	//   kāte, लावल, _ühtm, ሖታትን_, 
   {{0x61f919ea,0x776c00ac,0xaa4c001f,0x443119eb}},	//   _mmul, tabx, _አደርጋ, _ohz_, 
   {{0xe61c025a,0x7a101619,0x00000000,0x00000000}},	//   _akô_, dāte, --, --, 
   {{0x61f80c8a,0x3668014b,0xdb00008e,0x00000000}},	//   _omul, рабо_, _qanä, --, 
   {{0xa5b812ad,0x00000000,0x00000000,0x00000000}},	//   _akób, --, --, --, 
   {{0x44300175,0xe6142626,0xa5b800ae,0xb37400d1}},	// [1a440] _bhz_, іду_, _phór, قداش, 
   {{0x61f919ec,0xf770168d,0x538c02d3,0xb6a45e0c}},	//   _amul, _کاک_, _ጕዳያት_, _диол, 
   {{0x9f440418,0x75e802fb,0x1dbc0b3c,0x4430e679}},	//   hinó_, _výzb, _शोभत, _dhz_, 
   {{0x443119ed,0x5edc0183,0x61f800d7,0x6a98010f}},	//   _ehz_, বছাই, _cmul, ישענ, 
   {{0xb9100a28,0x75f800bc,0x0ef401ad,0xa5b919ee}},	//   ttaṃ_, hůzk, ेप्स_, _thór, 
   {{0x443062e4,0xd4080451,0x6d440419,0x00000000}},	//   _ghz_, _اڪرم_, ľkam, --, 
   {{0x6d4402fb,0xceb8012d,0x9f3001ec,0x644803b2}},	//   žkam, _rzęs_, меші, ígiv, 
   {{0xdd9519ef,0x61f8089c,0x1e1400ae,0x00000000}},	//   ошь_, _gmul, يغية_, --, 
   {{0x9f440407,0x30040064,0x0cc800fe,0xdca00114}},	//   ginó_, _дзаг, ষন্ত, дањи, 
   {{0xdfcc004b,0xc2f00154,0x61f80064,0x00000000}},	//   _ټيم_, _জুটি_, _zmul, --, 
   {{0xa5b800e4,0x3e540055,0x1dd4009d,0x00000000}},	//   _ohóp, _pāte_, слөө_, --, 
   {{0x6da5083b,0x6ce4177b,0x628001a6,0xada4030d}},	//   _фида, _міле, šnog, _фадл, 
   {{0xa928005e,0x9f44a742,0x3e540055,0xfe080051}},	//   ріне_, minò_, _vāte_, sắc_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7a1004fe,0xd1e002d3,0x70c405dc,0x3e5400b8}},	//   wāte, ቓሳት_, लमुल, _tāte_, 
   {{0x7a100029,0x4430002f,0xa5b802d2,0x95c80022}},	//   tāte, _shz_, _skób, оууа_, 
   {{0xe4e4003b,0x00000000,0x00000000,0x00000000}},	// [1a450] цівн, --, --, --, 
   {{0x61f919f0,0x6d440205,0x00000000,0x00000000}},	//   _smul, ıkay, --, --, 
   {{0x98149e18,0x00000000,0x00000000,0x00000000}},	//   _تبيا, --, --, --, 
   {{0xee240451,0xa784179e,0x00000000,0x00000000}},	//   _سٽ_, _اشکو, --, --, 
   {{0xa49119f1,0x2040044e,0xd1b80150,0x9f44c044}},	//   _زیات, _ንደሞክ, تالا_, dinò_, 
   {{0x90280588,0x442519f2,0x26c406af,0x00000000}},	//   ҩцәа_, _ól_, _ànos_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x61f826ff,0x415411db,0x629401d4,0x9f4519f3}},	//   _umul, _хвас, mtxo, tinó_, 
   {{0x6294009d,0xd2440262,0x628000e2,0x3cc8009d}},	//   ltxo, _цэри, šnod, ёлоо_, 
   {{0x9aa4192c,0x6ab8005a,0x7ae400c5,0x629401c4}},	//   ەنگە_, fvtf, _ühtk, otxo, 
   {{0x629519f4,0x9f4519f5,0x00000000,0x00000000}},	//   ntxo, sinó_, --, --, 
   {{0x3d948a6b,0x9f4519f6,0x00000000,0x00000000}},	//   _хидр, cinò_, --, --, 
   {{0xdb0000fc,0x00000000,0x00000000,0x00000000}},	//   _janú, --, --, --, 
   {{0x7d1c002f,0x00000000,0x00000000,0x00000000}},	//   üssu, --, --, --, 
   {{0xdb0119f7,0x62940218,0xdb2001d3,0x0d540133}},	//   _lanú, jtxo, _توثی, _رخۆد, 
   {{0x7ae00363,0xb8d00011,0xe6400022,0x00000000}},	//   mylt, _টপ_, еесп, --, 
   {{0x64a119f8,0xaa0801ed,0xdb0000d7,0x7ae00108}},	// [1a460] ната, _دعوے_, _nanú, lylt, 
   {{0x59c4448b,0xd76400f2,0x37880798,0x00000000}},	//   षाकर, _تندی, _убоо_, --, 
   {{0xe7d80375,0xc77c0023,0xbba8012c,0x9f440332}},	//   _הקיש, _ንምዃኑ_, _कसैक, ghní_, 
   {{0xdb00004e,0x7ae00076,0x00000000,0x00000000}},	//   _banú, iylt, --, --, 
   {{0x25d41a4c,0x764400b5,0x6294005a,0xdb00007b}},	//   _זוכן_, _iiky, atxo, _canú, 
   {{0x62940218,0x3dc0013f,0x7ae008c5,0x2898008f}},	//   btxo, _ɔhwe_, kylt, מינא, 
   {{0x76450d20,0xdf7000db,0x9f4519f9,0x5f7003c7}},	//   _kiky, ردوب, tinò_, راور, 
   {{0xdb0108a1,0x7644020b,0x75e800a2,0x00000000}},	//   _fanú, _jiky, _yýza, --, 
   {{0x7644013f,0xa0644af9,0x09b403d4,0xeaf41098}},	//   _miky, _ната_, টামা, ुप्त_, 
   {{0x9f4519fa,0x764519fb,0x7a3400d2,0x7ae031a2}},	//   sinò_, _liky, nátf, fylt, 
   {{0x764519fc,0xdb000248,0xdee119fd,0xe45c08a5}},	//   _oiky, _kanù, _пофи, _gröf_, 
   {{0x764519fe,0xee38084c,0x9e840133,0x00000000}},	//   _niky, _уне_, _رامۆ, --, 
   {{0x6e20a5e6,0x7ae000ad,0x00000000,0x00000000}},	//   _ikob, aylt, --, --, 
   {{0xd7f84a35,0xe8fc0428,0x7644002b,0xdd38011a}},	//   пус_, daût_, _aiky, _העדכ, 
   {{0x76440337,0x3e54f987,0x6e201418,0x7ae00393}},	//   _biky, _kāta_, _kkob, cylt, 
   {{0xdce80115,0xcfc4009e,0x764519ff,0x3e5400cd}},	//   _segĉ, ্সিন, _ciky, _jāta_, 
   {{0x76451a00,0x3e551a01,0x6e211a02,0x63b40175}},	// [1a470] _diky, _māta_, _mkob, tdxn, 
   {{0x7a111a03,0x68ece162,0x4ab00bae,0x9f440332}},	//   māta, ındı, _जनाव, thní_, 
   {{0x6e20043b,0xdb20022c,0x7a101a14,0x63c000fb}},	//   _okob, ásøg, lāta, маҡҡ, 
   {{0x629405f5,0x76441418,0x6e200337,0x3e54002b}},	//   rtxo, _giky, _nkob, _nāta_, 
   {{0x656c0cfd,0x7a100061,0x62500135,0x7bc40ad9}},	//   _iech, nāta, _għon, _óhug, 
   {{0x656d1a04,0x6e211a05,0x3e540421,0x7a3400d2}},	//   _hech, _akob, _aāta_, cátf, 
   {{0x656c006c,0x7a100882,0x6444037e,0x920800de}},	//   _kech, hāta, _iiji, _brāķ, 
   {{0x644d1a06,0x656c0a4d,0x64451a07,0xdb0001ed}},	//   _kuci, _jech, _hiji, _tanú, 
   {{0x64451a08,0x656d1a09,0x7a100882,0xdb000158}},	//   _kiji, _mech, jāta, _hanø, 
   {{0x64451a0a,0x6e2090ef,0x7a100a30,0x644d1a0b}},	//   _jiji, _ekob, dāta, _muci, 
   {{0x64451a0c,0x661c0309,0xcfa400d1,0x7dd401d3}},	//   _miji, koqk, _яшти, _mász, 
   {{0x656d1a0d,0xf2d000c8,0x7dd401ed,0xdb0028b3}},	//   _nech, דעט_, _lász, _manø, 
   {{0x8d7473c5,0x644d1a0e,0xe8f51a0f,0x64440086}},	//   _سانا, _nuci, для_, _oiji, 
   {{0x64451a10,0x76451a11,0x7dd400e5,0x00000000}},	//   _niji, _siky, _nász, --, 
   {{0x656d1a12,0x76451a13,0x644d1a14,0xa5b802d2}},	//   _bech, _piky, _auci, _skóa, 
   {{0x644408e7,0xe5a00075,0x656c012d,0x76440548}},	//   _aiji, киси, _cech, _qiky, 
   {{0x644cb3cb,0x656d1a15,0x64451a16,0x2bc0012d}},	// [1a480] _cuci, _dech, _biji, _वोडा, 
   {{0x644d1a17,0x7644003e,0x656cded3,0x64440009}},	//   _duci, _wiky, _eech, _ciji, 
   {{0xe2951a18,0x656d1a19,0x64451a1a,0x76451a1b}},	//   дах_, _fech, _diji, _tiky, 
   {{0x644cf2de,0x656d1a1c,0x21648040,0xe45c01e6}},	//   _fuci, _gech, дици_, _bröd_, 
   {{0x644c015c,0x64451a1d,0x61400114,0x00000000}},	//   _guci, _fiji, веца, --, 
   {{0x6e211a1e,0x64451a1f,0xdb0012e8,0x656d1a20}},	//   _skob, _giji, _fanø, _zech, 
   {{0x656d1a21,0x644c23db,0xf1a839b1,0x0d840032}},	//   _yech, _zuci, _واره_, еһен, 
   {{0x9e006322,0x644416cc,0x6250031c,0x7dd401d3}},	//   кчыл, _ziji, _mħol, _zász, 
   {{0x64440223,0x316401f7,0xefb001d5,0xfe4401b9}},	//   _yiji, mboz_, _لیشگ, رکمی, 
   {{0xc0a8592e,0x3e5402b5,0x7a100318,0x64448186}},	//   _عاقل_, _wāta_, vāta, _xiji, 
   {{0xdd8d1a22,0xddc804b9,0x9a300943,0x6250025c}},	//   _иш_, žišt, _ṱaḓu, _nħol, 
   {{0x7a111a23,0x6e204509,0xdee002a9,0x3164022e}},	//   tāta, _ukob, _шохи, nboz_, 
   {{0x656d1a24,0x58d4136b,0x29ec02a8,0x7dd40306}},	//   _rech, воят, nƙai_, _násy, 
   {{0x656d1a25,0x644d1a26,0x2ca4d999,0x7a1000dc}},	//   _sech, _ruci, _ipod_, rāta, 
   {{0x656d1a27,0x644d1a28,0x75e803c6,0x64451a29}},	//   _pech, _suci, _význ, _riji, 
   {{0x64451a2a,0x7a111a2b,0x656d18b5,0x16342bb6}},	//   _siji, pāta, _qech, веся, 
   {{0x656d1a2c,0x64451a2d,0x7dd401d3,0x2bd00846}},	// [1a490] _vech, _piji, _pász, तापा, 
   {{0x656d1a2e,0x644d1a2f,0x7a1000da,0xe7a40150}},	//   _wech, _vuci, nātn, _تۇسى_, 
   {{0x656d1a30,0x64451a31,0x6250038f,0x644c0c09}},	//   _tech, _viji, _għol, _wuci, 
   {{0x050c015b,0x64451a32,0x2ca4017a,0x656c04e6}},	//   _শরীর_, _wiji, _opod_, _uech, 
   {{0x64451a33,0xb5f002dd,0x7ae4000d,0xe5046ea9}},	//   _tiji, _сүті, _ühtv, _آبجي, 
   {{0x7a340118,0x00000000,0x00000000,0x00000000}},	//   máte, --, --, --, 
   {{0x2bd07922,0x44211a34,0x2ca51a35,0x7a34013a}},	//   ताना, moh_, _apod_, láte, 
   {{0xf1c45c8d,0x7d742303,0x00000000,0x00000000}},	//   _रोपन, رابط, --, --, 
   {{0x44211a36,0x7a340118,0xc01400d4,0x00000000}},	//   ooh_, náte, _змащ, --, 
   {{0x44211a37,0x7a1000e2,0xfbd0007b,0x9f685bc5}},	//   noh_, gātn, اتة_, _фраз_, 
   {{0x2ca51a38,0x7a3401ef,0x00000000,0x00000000}},	//   _epod_, háte, --, --, 
   {{0x44211a39,0xe9d51a3a,0xa5b80252,0x7a34634d}},	//   hoh_, екю_, _skón, káte, 
   {{0x44211a3b,0x00000000,0x00000000,0x00000000}},	//   koh_, --, --, --, 
   {{0x4420047e,0x17c8013e,0x3ddc00a2,0x3e5400cd}},	//   joh_, фҳои_, _howw_, _jāto_, 
   {{0x44211a3c,0xe45c145e,0xe7351a3d,0x64480268}},	//   doh_, _atö_, еер_, ìgin, 
   {{0x7a111a3e,0x75e800d0,0x3164022e,0x291803b2}},	//   māto, _výzo, xboz_, ágað_, 
   {{0xa5b80241,0xe8fc002d,0x799402d0,0x00000000}},	// [1a4a0] _ikól, lbûn_, _icyw, --, 
   {{0x44211a3f,0x2bd012cc,0x2614003d,0x78b400e4}},	//   goh_, ताया, għob_, _isyv, 
   {{0x7a107106,0x75e800a2,0x0394011c,0x00000000}},	//   nāto, _yýzl, ъртя, --, 
   {{0x7a345a10,0x6250025c,0x00000000,0x00000000}},	//   báte, _għom, --, --, 
   {{0x44211a40,0x2bd01a55,0x1b000154,0x316401a9}},	//   boh_, तामा, _রুমে_, rboz_, 
   {{0x44211a41,0xc05802bf,0x04780014,0xe8fc000f}},	//   coh_, фії_, _زلفک_, kbûn_, 
   {{0x2ca51a42,0xa5b91a43,0x316403e0,0xddcc03e0}},	//   _spod_, _okól, pboz_, çeşm, 
   {{0x71651a44,0x78b400e4,0x66d8010b,0x7a1000de}},	//   _سارك, _osyv, läkç, dāto, 
   {{0x3ddc0de2,0x00000000,0x00000000,0x00000000}},	//   _doww_, --, --, --, 
   {{0xa5b80241,0x7c211a45,0x96e002ab,0x9f440113}},	//   _akól, golr, नहाउ, shná_, 
   {{0xda751a46,0x78b400e4,0x5ba00046,0x2bd00b40}},	//   няя_, _asyv, урыз, ताबा, 
   {{0xdd8c05d9,0xee391a47,0x442032b5,0x78740022}},	//   _هوم_, _эне_, zoh_, _ỹvar, 
   {{0xebe48374,0x44211a48,0x2ca4c643,0x4c9400a7}},	//   _подп, yoh_, _upod_, _рилс, 
   {{0xa5b80296,0x4420102c,0x7a1000de,0xdc2c00c0}},	//   _ekól, xoh_, bāto, džėj, 
   {{0x442001b9,0x78b402d0,0xe45c02d2,0x00000000}},	//   voh_, _esyv, _stö_, --, 
   {{0xd5b91a49,0x44211a4a,0x7a349903,0xb88400d7}},	//   нсу_, woh_, táte, _stíš, 
   {{0x44211a4b,0xdb003e9b,0x9f4400d7,0xe4509cba}},	// [1a4b0] toh_, _maný, linô_, اضر_, 
   {{0x7a351a4c,0x2fdc0c86,0x68440241,0x69dc036e}},	//   ráte, _notg_, _dédì, _hoqe, 
   {{0x44211a4d,0x69dcd8e7,0xd3a402dd,0x7ae40254}},	//   roh_, _koqe, ыртп, _ühtt, 
   {{0x44211a4e,0x69dc0240,0x78b400c7,0xdb051a4f}},	//   soh_, _joqe, _ysyv, élém, 
   {{0x4420138f,0x69dd1a50,0x3ddc0175,0x518401c6}},	//   poh_, _moqe, _roww_, ууха, 
   {{0x44211a51,0x69dc01e2,0x2fdc04cc,0x3ddc0de2}},	//   qoh_, _loqe, _cotg_, _soww_, 
   {{0x53351a52,0xdb0000a2,0x3e5400b8,0x00000000}},	//   _берт, _baný, _vāto_, --, 
   {{0x69dc6ae5,0xa5b80085,0xdef0010c,0x2e380221}},	//   _noqe, _okóm, ግርኛ_, hëff_, 
   {{0xceb40323,0xa5b80085,0xdb0002fb,0x3e5400b8}},	//   вшөө, _nkóm, _daný, _tāto_, 
   {{0xa5b800fc,0xe8fc002d,0x7a10f987,0xdb0008a5}},	//   _skól, tbûn_, tāto, _vanþ, 
   {{0xa5b8043b,0x69dcf857,0x05e00034,0xf98806c5}},	//   _akóm, _boqe, _नवंब, وندي_, 
   {{0xfbd001d9,0xef0c00aa,0xe8fc0b21,0xdb0000a2}},	//   اتک_, _بڼه_, rbûn_, _ganý, 
   {{0x7c200073,0x3b600014,0x00000000,0x00000000}},	//   polr, _پێجہ, --, --, 
   {{0x7a100882,0x8b9400a7,0xdb00002f,0x978400f2}},	//   mātm, _бръч, _kanü, دیده, 
   {{0x2bd858ae,0xa5b80296,0x20040421,0xe7240117}},	//   _تانک_, _ekóm, iini_, ворд_, 
   {{0x20051a53,0xdb010fe1,0x75d4007b,0x95b400c7}},	//   hini_, _manü, خيرا, ыргә, 
   {{0x20051a54,0xa504024d,0x66d81248,0xe8fc002d}},	// [1a4c0] kini_, вета_, täkç, nbûl_, 
   {{0x20051a55,0x7ae400c5,0x69dc004b,0x00000000}},	//   jini_, _ühts, _zoqe, --, 
   {{0xfe640050,0x7a100a28,0x69dc004b,0xefb001d5}},	//   _دگ_, hātm, _yoqe, ییرگ, 
   {{0xe2940063,0x00000000,0x00000000,0x00000000}},	//   ђач_, --, --, --, 
   {{0xdb011a56,0x7d0c02f0,0xfd540241,0x00000000}},	//   _kanó, _žasn, bafẹ, --, 
   {{0x2004f8ca,0x7a100882,0xe36000d4,0xdb000210}},	//   gini_, dātm, _вкри, _janó, 
   {{0xdb000548,0x0eec924b,0x69c80162,0xa3447227}},	//   _manó, जनेस_, _ógeg, _азра_, 
   {{0xdb000793,0xceb800d1,0xf1a80133,0x4cb8010a}},	//   _danü, _җәк_, _تاسه_, елию_, 
   {{0x20051a57,0xa030104b,0x61410844,0x31241513}},	//   bini_, _چىقت, _вета, _рдаг, 
   {{0x69dd1a58,0xa0640353,0x00000000,0x00000000}},	//   _soqe, _рафа_, --, --, 
   {{0xbe851a59,0x69dc036e,0xa5b802d2,0x00000000}},	//   _مجنو, _poqe, _skóm, --, 
   {{0x2d902c95,0xece8228c,0x62780375,0xace8014b}},	//   _øye_, _одел_, ונטנ, _омеа_, 
   {{0x69dc07d6,0x9d9802d3,0xdb0001e7,0xa85000b1}},	//   _voqe, _ዉሽጣዊ_, _banó, регә, 
   {{0xdb011a5a,0x7aec0198,0x69dc0472,0xd83801c4}},	//   _canó, _ƙatt, _woqe, вэс_, 
   {{0xdce800da,0x69dc0a73,0x5c351a5b,0x070805d9}},	//   _iegā, _toqe, _שטוב_, ريري_, 
   {{0x9a8001b9,0x661802f0,0xd564026b,0x00000000}},	//   _тушл, čuko, итуп, --, 
   {{0x20051a5c,0xdb00033f,0x00000000,0x00000000}},	// [1a4d0] yini_, _fanó, --, --, 
   {{0x20051a5d,0xceb80022,0x941800d1,0xf8b4008e}},	//   xini_, _osę_, вжут_, _сөю_, 
   {{0x461400c6,0x7a351a5e,0x00000000,0x00000000}},	//   _مودر, láta, --, --, 
   {{0x2004b04c,0x7a100882,0xdce800e2,0x45d401a9}},	//   wini_, yātm, _legā, _сомс, 
   {{0x3c3807ea,0x7e600419,0x00000000,0x00000000}},	//   lève_, _stlp, --, --, 
   {{0x7a100aed,0xdb000ba1,0x200403a0,0xdce800de}},	//   vātm, _manò, uini_, _negā, 
   {{0x20051a5f,0x3c3839b2,0x7a3500fd,0x9258014b}},	//   rini_, nève_, háta, _ааст_, 
   {{0x7a351a60,0x00000000,0x00000000,0x00000000}},	//   káta, --, --, --, 
   {{0xa5b801e1,0x7a351a61,0x6f18010a,0x3c3806af}},	//   _akók, játa, _extc, hève_, 
   {{0x20051a62,0x7a100882,0x614001e1,0x38640139}},	//   qini_, rātm, _ẹlò, _çori_, 
   {{0xba7404fb,0x00000000,0x00000000,0x00000000}},	//   داخت, --, --, --, 
   {{0x75e8012c,0x00000000,0x00000000,0x00000000}},	//   _výzk, --, --, --, 
   {{0x2244031f,0xdb011a63,0x6d440010,0xf98850d8}},	//   ínky_, _canò, žkar, ونگي_, 
   {{0xb7d800db,0x95840023,0xca740133,0x00000000}},	//   روزا_, ምዓትን_, دنێک, --, 
   {{0x3c380129,0xec100133,0x7aa4010a,0x00000000}},	//   gève_, _دوود, _сийз, --, 
   {{0xdb00011f,0x7a351a64,0x00000000,0x00000000}},	//   _wanó, báta, --, --, 
   {{0x386403a2,0x7a340077,0x00000000,0x00000000}},	// [1a4e0] _ïor_, cáta, --, --, 
   {{0xdb000129,0x56640214,0x95b400c7,0x00000000}},	//   _abné, _نگرف, ырҳә, --, 
   {{0x64a0699c,0xdb000309,0x38700368,0x7d0c0064}},	//   _қара, _kanñ, _hwyr_, _žasl, 
   {{0x80ac015b,0x00000000,0x00000000,0x00000000}},	//   চিন্, --, --, --, 
   {{0x4ddc02f5,0x6f180175,0xafe401b9,0xc1d401e0}},	//   বসমূ, _sxtc, лодл, шөрә, 
   {{0xb4c01b76,0xa0640063,0x67380118,0x00000000}},	//   ्मी_, ћаја_, řuje, --, 
   {{0x2bd0085c,0x3870015d,0x00000000,0x00000000}},	//   तासा, _lwyr_, --, --, 
   {{0x2d800a85,0xdce800ef,0xec6801a9,0xf0741f0d}},	//   ûke_, _segā, нрок_, _مُرد, 
   {{0x25d400c8,0x3c3802bd,0xa5b8032e,0x00000000}},	//   רופן_, zève_, _skók, --, 
   {{0x1958005e,0xd33c01e4,0xdd9002dd,0x6f180175}},	//   ғары_, _parʈ, _ғашы, _txtc, 
   {{0x387000a9,0x3fc801d5,0xdce83da0,0xcb340395}},	//   _awyr_, _جگنی_, _vegā, ренъ, 
   {{0xdb007d47,0x7a100882,0xa3a801ad,0xd7f8010b}},	//   _panò, nāth, _कॉन_, ңур_, 
   {{0x58851a65,0x38700042,0x00000000,0x00000000}},	//   йыра, _cwyr_, --, --, 
   {{0x7a3459de,0x3c380ba1,0x00000000,0x00000000}},	//   ráta, tève_, --, --, 
   {{0x7a351a66,0x7ae40254,0x00000000,0x00000000}},	//   mátn, _ühtp, --, --, 
   {{0x2bd0146c,0xb4c11a67,0x48c40724,0x3c380129}},	//   तावा, ्मू_, _кәга, rève_, 
   {{0x290c0124,0x3870996f,0x3c38033b,0x1634020f}},	// [1a4f0] _ãga_, _gwyr_, sève_, сетя, 
   {{0xe45c0267,0xe2a801d3,0x7a340c5e,0x00000000}},	//   _frön_, ٹائن_, nátn, --, 
   {{0x41551a68,0xe45c01e6,0xf77405d0,0xe2a801f7}},	//   авес, _grön_, _דעתי_, عائن_, 
   {{0xd17447b6,0xd6d8117e,0x53440022,0x00000000}},	//   бышы, _сть_, схуа, --, 
   {{0x7a3402fd,0x92580032,0xffb4009d,0x00000000}},	//   kátn, _ҡарт_, ийдэ, --, 
   {{0xdce8084c,0xe130010b,0xa5b8032e,0x9f4400ae}},	//   _legă, анҗы, _skóh, mhnú_, 
   {{0xb3d005ba,0x3e540053,0xa5b80124,0x7a3402f0}},	//   सारख, _kāti_, _akói, dátn, 
   {{0xad500131,0xdce80356,0x3e54002b,0x7a1000b8}},	//   ينىغ, _negă, _jāti_, cāth, 
   {{0xec7407dd,0x3e54ff26,0xdb000055,0x00000000}},	//   апы_, _māti_, _ranñ, --, 
   {{0xa3a84614,0x7a1000da,0x7a3402f0,0x75e80419}},	//   _कॉम_, māti, gátn, _výzi, 
   {{0x47b80135,0xfaa51a69,0x7a101c52,0xdb0000b8}},	//   _བལྟམ, шано, lāti, _panñ, 
   {{0x8d749165,0x3e541d77,0xdb000113,0x3f84107d}},	//   _هاها, _nāti_, _qanñ, _hdlu_, 
   {{0xed4d1a6a,0x7a104424,0xcc8800aa,0xdd9000ee}},	//   _фо_, nāti, _مننه_, _ваҗы, 
   {{0x9f4400c6,0x29ec0198,0xbb44001b,0x7a34013a}},	//   dhnú_, uƙar_, _келк, cátn, 
   {{0xf744e99a,0x7bc00b6f,0x2bd0590f,0xe0c00f22}},	//   рево, mdlu, तारा, ্নয়ন, 
   {{0x7a340122,0x32d40424,0x7bc00158,0x3e5400b8}},	//   máto, یزاس, ldlu, _cāti_, 
   {{0x7a340765,0xb4c02429,0x9f440597,0x7a103a71}},	// [1a500] láto, ्मे_, ghnú_, jāti, 
   {{0x3f841cdf,0x7a100318,0xe850036b,0x00000000}},	//   _ndlu_, dāti, _گنید, --, 
   {{0x7a341a09,0x2374faed,0xb22405f5,0x35a51a6b}},	//   náto, شمند_, амжл, _канг, 
   {{0x71a40953,0xf1c460c7,0xb22400ee,0x626000d4}},	//   радз, _रोशन, шмел, івча, 
   {{0x8f840873,0x9f4400c6,0x7a1000e2,0x98b800bc}},	//   йқал, chnú_, gāti, ेटिए, 
   {{0x7a341a09,0x7bc001f5,0xbb4c0150,0x940400ec}},	//   káto, jdlu, _ﺃﻟﻡ_, _چوڏه, 
   {{0x7a351a6c,0x61340116,0x7bc0638c,0xa5b8032e}},	//   vátn, лчәр_, ddlu, _skói, 
   {{0x6ca470c9,0x7a351a6d,0xdd0002b5,0x7bc00112}},	//   арож, dáto, _ōrāt, edlu, 
   {{0x2b5c074d,0x2bd0038e,0x2614003d,0xdce80276}},	//   tctc_, ताला, dħol_, _regă, 
   {{0x8bd8084c,0x7bc402d2,0x5d1000cf,0xe06002f2}},	//   умос_, _óhul, تبىز, _بێوی, 
   {{0x7a34533b,0x00000000,0x00000000,0x00000000}},	//   gáto, --, --, --, 
   {{0x2614038f,0x86300023,0x00000000,0x00000000}},	//   għol_, _ሰብኡት, --, --, 
   {{0x98b86345,0x3e5402b5,0xb4c0752d,0xdca11a6e}},	//   алят_, _rāti_, ्मो_, _маци, 
   {{0x62800525,0xb4c00882,0x7a341aa9,0xcd280092}},	//   ánok, ्मै_, báto, _ትሆናለ, 
   {{0x89d8193a,0x3e541d86,0x45d400d8,0x7a3400e4}},	//   _موثر_, _pāti_, бовс, cáto, 
   {{0x9f4400c6,0x6280341a,0x3c380022,0x00000000}},	//   thnú_, šnok, mèva_, --, 
   {{0x2d84009f,0xb3d007f7,0x290d1a6f,0x3c380ba1}},	// [1a510] _mdoe_, सांख, _äga_, lèva_, 
   {{0x3e5400b0,0x00000000,0x00000000,0x00000000}},	//   _wāti_, --, --, --, 
   {{0x3e5402b5,0x3c38068c,0x7a1002b5,0x7d1c01d3}},	//   _tāti_, nèva_, wāti, üssz, 
   {{0x2d84020c,0x7a111a70,0x09b400eb,0x00000000}},	//   _ndoe_, tāti, টাকা, --, 
   {{0x7a341dee,0xe8fc006a,0x3e5400b8,0x00000000}},	//   záto, nzû_, _jātv_, --, 
   {{0xafe000c9,0x7a111a71,0xb34001d9,0x09e003d4}},	//   зошл, rāti, _کێمى, মোচা, 
   {{0x75e80232,0x4fc40533,0xe7fc05b3,0x7a101c52}},	//   _výzv, تەلە, _उतना_, sāti, 
   {{0x7a111a72,0x7a3425fd,0x3c38067c,0x7bc00042}},	//   pāti, váto, dèva_, wdlu, 
   {{0x2d8403cb,0x00000000,0x00000000,0x00000000}},	//   _ddoe_, --, --, --, 
   {{0xdb011a73,0xdce80064,0x7a3428d1,0x00000000}},	//   _manö, _negą, táto, --, 
   {{0x7bc000af,0x62500003,0x7bc403b2,0x7a3401d3}},	//   rdlu, _għot, _óhum, bátl, 
   {{0x7a3419fd,0xcda800f1,0x00000000,0x00000000}},	//   ráto, _نهمه_, --, --, 
   {{0x2614031c,0x00000000,0x00000000,0x00000000}},	//   għom_, --, --, --, 
   {{0x62500135,0xcd3406c2,0x00000000,0x00000000}},	//   _jħos, _برمب, --, --, 
   {{0xe45c01e6,0x3cec06be,0x00000000,0x00000000}},	//   _dröm_, lyev_, --, --, 
   {{0xdb0001b8,0xe45c0036,0x5bb404af,0x00000000}},	//   _banö, _eröm_, _असुव, --, 
   {{0x097805f5,0xb384668d,0x09b40154,0x7a3400d7}},	// [1a520] _өрөө_, йлал, টাখা, nátm, 
   {{0xdb0005d5,0x3ea80034,0x62500135,0x32d40006}},	//   _danö, łaty_, _nħos, йцес, 
   {{0x27fc0198,0x02c401c6,0x3e5400ef,0xb80801e2}},	//   ɗun_, жихү, _kātu_, _ليکم_, 
   {{0xdb0001b8,0xf77028f4,0x3e5400b8,0xa5b802d2}},	//   _fanö, _باک_, _jātu_, _skóv, 
   {{0x3e5403a0,0x51840032,0x3cec047e,0x7a3400e5}},	//   _mātu_, буҙа, jyev_, játm, 
   {{0x7a111a03,0xf3e400d6,0x7a3400d7,0x0eb4012d}},	//   mātu, _ужго, dátm, ंबलड, 
   {{0xceb8052f,0x7050168d,0x27400066,0xe9dc0419}},	//   рҙе_, _کۆتا, méné_, yjú_, 
   {{0x3cec1529,0x21a00640,0x3c380022,0x00000000}},	//   fyev_, _нисм, vèva_, --, 
   {{0x225c0010,0x7a3400d7,0xb0f8009d,0x00000000}},	//   _čuki_, gátm, _сэвх_, --, 
   {{0x62500327,0x3c38068c,0x60e402a9,0x5eb40011}},	//   _għos, tèva_, _умум_, _অপরে, 
   {{0x91bc07f7,0x9a640ee8,0x00000000,0x00000000}},	//   _ईसाई, یمیل_, --, --, 
   {{0x1e540375,0xed5801c4,0xdb1000a2,0x628001e7}},	//   _השאר_, _сод_, _çaýg, ánoi, 
   {{0xe9dc01ed,0x274004fb,0x3c38067c,0x291c0200}},	//   rjú_, kéné_, sèva_, çua_, 
   {{0x7bcc23db,0x2740020c,0xa5b803b2,0x62500327}},	//   _ɗauk, jéné_, _kjóg, _xħos, 
   {{0x274004fb,0x7c2c00e4,0x65a8009d,0x958c0240}},	//   déné_, _êara, лтаг_, _ንጽቡቕ_, 
   {{0xa5b80296,0xa3a80316,0x59d00490,0xe24c0023}},	//   _nkót, क्न_, _तोपर, ንቅስቓ, 
   {{0x67e804cc,0x2eec017a,0x00000000,0x00000000}},	// [1a530] _süju, hyff_, --, --, 
   {{0x274000f2,0x24f400fb,0x6b98007c,0xf4240139}},	//   géné_, анғы_, ngtg, _şärm_, 
   {{0x26c40798,0x176802d9,0xe45c007c,0x3e54002b}},	//   _éno_, _урып_, _krök_, _yātu_, 
   {{0xa5b8041e,0xd174010b,0x7a100171,0x00000000}},	//   _sjóf, пышы, bātu, --, 
   {{0x657c1cdf,0x27400098,0x75e80118,0x154400d8}},	//   maqh, béné_, _výzt, _неџм, 
   {{0x657d1a74,0xdb000109,0x645c0334,0x00000000}},	//   laqh, _kanô, mqqi, --, 
   {{0x92944cc1,0xfe44346b,0xa1840209,0x0fe400f7}},	//   _нарц, онко, _гызл, чөтү, 
   {{0x657c0357,0x63b40232,0xfde8c9e1,0xbc651a75}},	//   naqh, lexn, рдик_, овик, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6b98074d,0x657d1a76,0x6250025c,0x7a3400d0}},	//   ggtg, haqh, _għor, rátm, 
   {{0xbf140597,0x657c0921,0x629402fb,0xa5b806ea}},	//   _بواب, kaqh, nuxo, _gjóg, 
   {{0x7a34012c,0x39484712,0xa6cc015b,0xfcd4009f}},	//   mátk, изно_, রহাট, _وياج, 
   {{0x7a340232,0xae400050,0xfce40262,0xa5b808a5}},	//   látk, _تھوو, _фоло, _mjód, 
   {{0x62940912,0x7a10005f,0xeb94010b,0xf77025ef}},	//   kuxo, vātu, _диш_, باح_, 
   {{0x645c20ac,0x7a3402fb,0xb578117e,0xd1e00023}},	//   eqqi, nátk, ищах_, ሓሳብ_, 
   {{0x657c4242,0xbc2400db,0x9b400014,0x274106cd}},	//   gaqh, _ارچى, _وچھو, wéné_, 
   {{0x7a340122,0x64a11a77,0x3e5400ef,0x7d0c010e}},	// [1a540] hátk, мата, _kāts_, _ýasd, 
   {{0xdb000a85,0xa5b806ea,0x245c0368,0x7a340518}},	//   _fanô, _skót, _dîm_, kátk, 
   {{0xf7441f91,0x645d1a78,0x657c676c,0xa5b81427}},	//   _фено, aqqi, baqh, _bjód, 
   {{0xd0105311,0x7a3402fb,0x7a1000b0,0x6280000f}},	//   کلت_, dátk, pātu, ânoa, 
   {{0x09b40729,0xa5b8022c,0x2740020c,0xf04417b4}},	//   টাচা, _sjóg, péné_, оэко, 
   {{0x62951a79,0x67e8010e,0x00000000,0x00000000}},	//   buxo, _hüjr, --, --, 
   {{0x7a3401d3,0x00000000,0x00000000,0x00000000}},	//   rátj, --, --, --, 
   {{0x2cc40327,0x52740818,0x00000000,0x00000000}},	//   _ཀླུབ, _муғу, --, --, 
   {{0x6b98074d,0x62800232,0xa0651a7a,0x6250031c}},	//   tgtg, ánov, _мата_, _għoq, 
   {{0x7a351a7b,0x657c014b,0xa5b80162,0x00000000}},	//   láth, zaqh, _tjóg, --, 
   {{0x657d1a7c,0xada4d44f,0x7a3400bc,0x62804841}},	//   yaqh, _мажл, cátk, šnov, 
   {{0x7a3400c6,0x09b4009e,0x00000000,0x00000000}},	//   náth, য়াভা, --, --, 
   {{0xa3a806ab,0x98740816,0x00000000,0x00000000}},	//   क्ड_, мляц, --, --, 
   {{0xf8ac021a,0x657d1a7d,0xd7f8e088,0x7a3401e7}},	//   اکي_, waqh, оус_, háth, 
   {{0x98ac4424,0xadec228d,0x45d41fbe,0x8afc002d}},	//   ādā_, _जवान_, повс, rbęs, 
   {{0xa5b801e1,0x49751a7e,0x2bd00b9a,0x00000000}},	//   _akór, _элис, ताका, --, 
   {{0x657c0cfe,0x63b4851b,0x62940fec,0xa5b808ce}},	// [1a550] raqh, texn, wuxo, _skós, 
   {{0x69a40d5f,0x657c0944,0xa5b80162,0x645c022e}},	//   ट्री, saqh, _sjód, rqqi, 
   {{0x7a100a28,0x657c03f0,0x77b80375,0x13680116}},	//   mātr, paqh, _המתח, юшти_, 
   {{0x5bb442e3,0x657c0357,0x245c00a9,0x62940077}},	//   _अस्व, qaqh, _tîm_, ruxo, 
   {{0x3f6826c7,0x40346c7d,0xdd0c00d7,0x00000000}},	//   било_, педс, _oľša, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x53342038,0xf1c40034,0xa5b803b2,0xdb000306}},	//   _жерт, _रोकन, _tjód, _obná, 
   {{0xf074066d,0x171c00c8,0x7a351a7f,0xc10431ed}},	//   _کیوں_, יווע, rátk, _فوزي, 
   {{0x61f80eda,0x7a3400bc,0x3ea800e8,0xfd10e7e1}},	//   _ilul, sátk, ŋat_, عجب_, 
   {{0x7a351a80,0x61f91a81,0x44300076,0x2bd008a3}},	//   máti, _hlul, _jkz_, तागा, 
   {{0xa5b8032e,0xed4c00d1,0x00000000,0x00000000}},	//   _mjób, نھۇ_, --, --, 
   {{0x78a4007c,0x69c802d2,0x00000000,0x00000000}},	//   ttkv, _ógel, --, --, 
   {{0x7a351a82,0x61f8020b,0xc9540953,0xbc6801f7}},	//   náti, _mlul, дтры, _امتن_, 
   {{0x61f91a83,0x1ca80135,0xa3a834ef,0x78a40158}},	//   _llul, _བྱར_, _कॉल_, rtkv, 
   {{0x61f91a84,0x67cc0153,0x2810009a,0x00000000}},	//   _olul, dėjė, روفس, --, 
   {{0xa5b88864,0xdc1000ac,0x7c2c03b2,0x44300200}},	//   _skór, _işıq, _íarb, _akz_, 
   {{0x443003ee,0x62840200,0xb37400d1,0xf1d827c6}},	// [1a560] _bkz_, _avjo, كداش, णासन, 
   {{0xc8b433f5,0x7a340120,0xdcf80024,0x03a8009f}},	//   _کلیک, dáti, jauč, قدمو_, 
   {{0x44300a73,0x61f800f2,0xa7580375,0x00000000}},	//   _dkz_, _blul, _לדיר, --, 
   {{0x443000c8,0x61f80066,0x7a341e0b,0x00000000}},	//   _ekz_, _clul, fáti, --, 
   {{0x61f8013e,0x765c00c7,0x7a351a85,0x92ac0154}},	//   _dlul, _hupy, ráth, কটে_, 
   {{0x765d1a86,0x61f91a87,0x00000000,0x00000000}},	//   _kupy, _elul, --, --, 
   {{0xe2951a88,0xb8cc0003,0x61f91a89,0x3a30010e}},	//   _нар_, _པཱ_, _flul, _okyp_, 
   {{0x765c04ba,0x6b88037e,0x7a351a8a,0x1dd000dc}},	//   _mupy, _sdfg, báti, थागत, 
   {{0xdc111a8b,0x6b88007f,0xb0f40521,0xc0580212}},	//   _aşıq, _pdfg, ụọgụ_, _діє_, 
   {{0x7e6c0063,0xbf64b5ed,0x3a300432,0x9f440332}},	//   ćapr, _قدمو, _akyp_, ghnó_, 
   {{0xdd8c039b,0x5b100276,0x7d0c00c0,0xa918032e}},	//   _пш_, емэт, _žast, daþa, 
   {{0x6da400db,0x31640010,0xada4009d,0x00000000}},	//   _хида, ncoz_, _хадл, --, 
   {{0xa9280046,0x777c0051,0x9aa01291,0x00000000}},	//   сіне_, _bepx, ومیو, --, 
   {{0x765c1418,0x31640399,0xd5b801c0,0x7c3000c7}},	//   _bupy, hcoz_, үст_, _иҵых, 
   {{0x96f800c7,0xbaa40046,0x7a100882,0x2d5003e6}},	//   перт_, _жуық, rātr, _تێکس, 
   {{0xa9c40133,0xa5b81d1d,0x00000000,0x00000000}},	//   _رزبو, _sjób, --, --, 
   {{0x62840427,0x98480014,0xa3a800c5,0x92ac00cc}},	// [1a570] _svjo, زلہٕ_, _कउआ_, কটো_, 
   {{0x1ca83aaf,0x61f8020c,0x7a340306,0x00000000}},	//   _བྱས_, _slul, váti, --, 
   {{0x2baca3a7,0x765c00ca,0x3164030d,0x61f8a8a1}},	//   ज्या, _gupy, fcoz_, _plul, 
   {{0x692401c7,0x44300334,0x00000000,0x00000000}},	//   céeë, _wkz_, --, --, 
   {{0x443007f5,0xe05401d3,0xbb540220,0x00000000}},	//   _tkz_, سیات_, _ﻋﺎﻡ_, --, 
   {{0x7a340122,0x765c020c,0x6fb4013e,0x628001d3}},	//   ráti, _yupy, мҳур_, ános, 
   {{0x61f806e4,0x67340175,0x7a3400bc,0x00000000}},	//   _tlul, _jyxj, sáti, --, 
   {{0x61f91a8c,0x7a3400e5,0x00000000,0x00000000}},	//   _ulul, látv, --, --, 
   {{0xe0dc2508,0xda480323,0xb308031c,0x6734007c}},	//   _çò_, үүлж_, _གཟོང_, _lyxj, 
   {{0x9f60049b,0x9e6401d3,0x00000000,0x00000000}},	//   ävät_, _فاؤن, --, --, 
   {{0x61400241,0xdcf800e4,0x2bd007b7,0xc0a801e2}},	//   _fìlí, iguĩ, ताजा, _داځل_, 
   {{0x9f44007c,0x00000000,0x00000000,0x00000000}},	//   rknä_, --, --, --, 
   {{0x765c0024,0x00000000,0x00000000,0x00000000}},	//   _supy, --, --, --, 
   {{0x31640007,0x765c0024,0x9c440139,0xa5b802d2}},	//   zcoz_, _pupy, _эхел, _skóp, 
   {{0xb3080327,0xe7fc08e9,0x00000000,0x00000000}},	//   _གཟེང_, _उतरा_, --, --, 
   {{0xa3a8547d,0xd1e002d3,0x1ca8031c,0x4de000dc}},	//   क्स_, ሓታት_, _བྱོ_, कायै_, 
   {{0xd0400cc1,0x25ec0037,0x2bd00825,0x00000000}},	// [1a580] _ermə, _इकरी_, ताचा, --, 
   {{0xc50801a9,0xe3b4390e,0x78b400e4,0x660c03ac}},	//   ستقل_, мбу_, _ipyv, _emck, 
   {{0x8454215c,0x0834010a,0xe7d8011a,0x52580c75}},	//   رىمچ, _яхъя, _וקיש, سساڭ_, 
   {{0x25b80175,0xdcf80022,0x00000000,0x00000000}},	//   ceql_, aguĩ, --, --, 
   {{0xb9100a28,0xdfcc05d9,0x21640798,0x00000000}},	//   traṃ_, ڌين_, фичи_, --, 
   {{0x1ca80867,0x7a34ea68,0x00000000,0x00000000}},	//   _བྱེ_, mátu, --, --, 
   {{0x626005f5,0x7a34fd26,0x2ca40076,0x9e9001f3}},	//   _авса, látu, _sqod_, _ፍቅርና_, 
   {{0x78b40124,0xa5b802d2,0xf1c407b7,0x00000000}},	//   _opyv, _kjóa, _रोचन, --, 
   {{0xa3a817ee,0x7a101a14,0x00000000,0x00000000}},	//   क्व_, vātp, --, --, 
   {{0xe45c04cc,0xa5b8032e,0xe04000d8,0x2aa8004e}},	//   _tröv_, _mjóa, _ануи, отмо_, 
   {{0xdfcc05e6,0x59d0007d,0x78b4c40d,0xa5b803b2}},	//   _خيل_, _तोहर, _apyv, _ljóa, 
   {{0xdde00276,0x00000000,0x00000000,0x00000000}},	//   ărţi, --, --, --, 
   {{0x6e211a8d,0x5c7000c0,0x00000000,0x00000000}},	//   _ijob, _аліт, --, --, 
   {{0x7d0c0209,0x0cbc547d,0xdd380375,0x00000000}},	//   _ýasa, ्टीम, _ועדכ, --, 
   {{0x156c063f,0xd1d40092,0x00000000,0x00000000}},	//   _ọmịm, ቨስት_, --, --, 
   {{0x5c8401ee,0x00000000,0x00000000,0x00000000}},	//   _эйәм_, --, --, --, 
   {{0xb3080135,0x7a340413,0x00000000,0x00000000}},	// [1a590] _གཟུང_, gátu, --, --, 
   {{0x73c00724,0xa7841079,0xe6640d1d,0x5edc0210}},	//   ләсе, _کشکو, _отмо, _कपल्_, 
   {{0xa3a80b26,0x2ba445c7,0x6e208a15,0xf1d80073}},	//   क्ष_, _खाना, _ojob, णांन, 
   {{0x6e211a8e,0x660c014b,0xe45c01e6,0x7a34041e}},	//   _njob, _umck, _bröt_, bátu, 
   {{0x3f691a8f,0x7a34003a,0xe4a401b9,0x77600139}},	//   пило_, cátu, _ўрмо, _şoxi, 
   {{0x6e2004ba,0x7a34fd26,0x78a008fb,0x3f680868}},	//   _ajob, látt, _åove, чико_, 
   {{0x6d4006d9,0x2a6c0165,0xae0000d1,0xf41000df}},	//   _azoa, _ntfb_, گۈنى, _עפל_, 
   {{0xa3a83eaf,0x1ca80135,0x23a800af,0x7a340252}},	//   क्र_, _བྱུ_, घ्रद, nátt, 
   {{0x6e211a90,0xe45c0267,0x00000000,0x00000000}},	//   _djob, _gröt_, --, --, 
   {{0x6e211a91,0x7a3409f3,0x00000000,0x00000000}},	//   _ejob, hátt, --, --, 
   {{0xe7e0216a,0x6e200334,0x00000000,0x00000000}},	//   खाना_, _fjob, --, --, 
   {{0xc7a81203,0x6e2002d3,0x7a34022c,0xa91802d2}},	//   _לב_, _gjob, játt, gaþo, 
   {{0x7e600e29,0x8d8473c3,0x888014d4,0x1c400022}},	//   _hulp, _рухд, ағыл, _иҽим, 
   {{0x7e611a92,0x7644036e,0xfaf000ae,0x00000000}},	//   _kulp, _shky, _مثب_, --, 
   {{0xf6251a93,0x7e6001e3,0xc6080154,0xa5b808ce}},	//   едво, _julp, রচনা_, _sjóa, 
   {{0xa2c00b98,0xe7341cd1,0x7a351a94,0x260800e1}},	//   रबन्, хес_, tátu, ठोली_, 
   {{0x79851a95,0xf5083529,0x4c6c010f,0x00000000}},	// [1a5a0] makw, чнал_, ַדאַ, --, 
   {{0x644408e5,0x7984055a,0xa3a8924b,0x36c40e92}},	//   _chji, lakw, क्ल_, _због, 
   {{0x2bf404ac,0x7e611a96,0x62800022,0x00000000}},	//   עמען_, _nulp, ánop, --, 
   {{0x31243b5f,0x7a351a97,0xa5b80008,0x64440108}},	//   ндег, pátu, _hjón, _ehji, 
   {{0x7bcc0b45,0x7e600857,0x6140084c,0xa3a801ad}},	//   _ɗaur, _aulp, геца, _कॉक_, 
   {{0x7984252e,0x64442b1d,0xe7e00034,0xce9402e8}},	//   hakw, _ghji, खाया_, вакъ, 
   {{0x79851a98,0x81b40f22,0x1ca8031c,0x15f4000d}},	//   kakw, জয়_, _བཱུ_, _इकार_, 
   {{0x79851a99,0xe45c02d2,0xa5b808a5,0x00000000}},	//   jakw, _grös_, _ljón, --, 
   {{0xe7e003f8,0x1ca8031c,0xdcf80374,0x9980010b}},	//   खामा_, _བྱཱ_, tauā, _iliň_, 
   {{0x60506bd8,0x7a3400d0,0x8af803c5,0x00000000}},	//   _منقط, káts, днос_, --, 
   {{0x798448b5,0x7a3401ed,0x58d4023b,0x6e20054e}},	//   fakw, játs, ҳоят, _tjob, 
   {{0x7984cf3e,0xa5b8067c,0x1da41788,0x6e20013e}},	//   gakw, _ajón, _गायत, _ujob, 
   {{0x7a34022c,0x7e60be52,0x6d40009f,0xa91801a8}},	//   vátt, _zulp, _uzoa, raþo, 
   {{0x1ca8081f,0x2b4401af,0x7d1c0174,0x00000000}},	//   _བྱི_, _пэйг, ússe, --, 
   {{0x79851a9a,0xa5b80174,0x7a3406ea,0x69b0012d}},	//   bakw, _djón, tátt, ेजदी, 
   {{0x79843c72,0x26140135,0x9f4400d7,0x00000000}},	//   cakw, eħor_, tknú_, --, 
   {{0x7a342242,0xd4986690,0xa5b803b2,0xe7840640}},	// [1a5b0] rátt, ерх_, _fjón, _пуно, 
   {{0x7a340436,0xa5b80162,0x27e40037,0xd91c011a}},	//   sátt, _gjón, _õnn_, _מוחל, 
   {{0x543401d5,0x7ff40133,0x48f800bc,0x00000000}},	//   ارقر, ێستا, उनको_, --, 
   {{0x7e600115,0xd9e413f7,0x1a98010f,0x00000000}},	//   _rulp, गायत_, ליבע, --, 
   {{0x7e611a9b,0xb5f002dd,0x3c380100,0x7ff401d9}},	//   _sulp, _түті, sèvi_, َستا, 
   {{0x79851a9c,0xae0c00e1,0x99800432,0x7e60f6ad}},	//   zakw, ़ोसन_, _eliň_, _pulp, 
   {{0x79840028,0x2aa80086,0x7e60047e,0x442000a3}},	//   yakw, jùb_, _qulp, mnh_, 
   {{0x7e611a9d,0x798434ca,0x7a343b2c,0x00000000}},	//   _vulp, xakw, hátr, --, 
   {{0xac8007dd,0x79840433,0x7e600b4f,0x00000000}},	//   агыл, vakw, _wulp, --, 
   {{0x79851a9e,0x2ba40073,0x44200051,0x00000000}},	//   wakw, _खाणा, nnh_, --, 
   {{0x79851a9f,0x7c944144,0x7e600393,0x442001a4}},	//   takw, رشکا, _uulp, inh_, 
   {{0xa5b81bb0,0x442001ab,0x09b40154,0x00000000}},	//   _sjón, hnh_, _জোবা, --, 
   {{0x7984f730,0x1ca8031c,0xfbc46219,0x00000000}},	//   rakw, _བཱི_, _абло, --, 
   {{0x3dcd1aa0,0x1ca80489,0x7d091872,0x44200208}},	//   ldew_, _བྱག_, mzes, jnh_, 
   {{0x79851aa1,0x7d091aa2,0x8b040198,0x2ba403ba}},	//   pakw, lzes, ƙƙal, _खाता, 
   {{0x44200097,0x7a3428cb,0x7d08009f,0x224c037e}},	//   enh_, ráts, ozes, jmgk_, 
   {{0xa5b801a8,0xdbe001e1,0x00000000,0x00000000}},	// [1a5c0] _tjón, _pèèb, --, --, 
   {{0xa5b8008c,0xdb000129,0x7d080036,0xd5b000e5}},	//   _hjól, _acné, izes, _گہر_, 
   {{0xf6240953,0xa5b80321,0x7d0801c7,0x62611aa3}},	//   _адно, _kjól, hzes, авха, 
   {{0x442001fb,0x43740032,0xd7640f01,0x9f440023}},	//   anh_, _ҡуст, _جنگی, ajnë_, 
   {{0xa0651aa4,0xa5b809f3,0x69a42052,0x3dcc0003}},	//   вача_, _mjól, ट्टी, ddew_, 
   {{0xe0402b17,0x7d091aa5,0x5f900120,0x44200051}},	//   анчи, dzes, аишт, cnh_, 
   {{0xa2e11aa6,0x7d0804ba,0x733457d4,0xc0580212}},	//   _корд, ezes, _شىرا, хії_, 
   {{0x387000ee,0x7d0804e6,0x99b400cc,0xe45c01e3}},	//   _otyr_, fzes, টযুক, _kröp_, 
   {{0x2ba41fbc,0x7d080036,0x7d0c00a2,0x00000000}},	//   _खादा, gzes, _ýasl, --, 
   {{0xfe4402f2,0x00000000,0x00000000,0x00000000}},	//   نکۆی, --, --, --, 
   {{0x2fdc056a,0x387000a2,0xa5b8032e,0x3dcc003d}},	//   _intg_, _atyr_, _bjól, bdew_, 
   {{0x8fd4013d,0x7d08496e,0xa2c01c5d,0x00000000}},	//   _шәҗә, bzes, रबत्, --, 
   {{0xbd7018ce,0x7d091aa7,0x4420001e,0x99800024}},	//   _уңыш, czes, ynh_, _akių_, 
   {{0xeb740064,0x00000000,0x00000000,0x00000000}},	//   _рыдэ, --, --, --, 
   {{0x442001a4,0xa5b80321,0x1ac43452,0x00000000}},	//   vnh_, _fjól, _ауып_, --, 
   {{0x44200399,0xa5b803b2,0xa3a801ad,0x38700200}},	//   wnh_, _gjól, _कॉज_, _ftyr_, 
   {{0x69dc031c,0x7a3403da,0x00000000,0x00000000}},	// [1a5d0] _inqe, pátr, --, --, 
   {{0x93940aaa,0x58d4010a,0xe2900116,0x00000000}},	//   لجما, _тоьт, لذص_, --, 
   {{0x7d091aa8,0x63c001e0,0x442001ab,0xc5f400cc}},	//   zzes, лаҡҡ, rnh_, ঘোষা_, 
   {{0x32051aa9,0x92951aaa,0x69ccd026,0x2fdc0208}},	//   ghoy_, рацц, ndce, _antg_, 
   {{0x69cc0175,0x3dcc031c,0xd4e43e38,0x00000000}},	//   idce, vdew_, _кюри, --, 
   {{0x2fdc0077,0x617802d3,0xb2744a4e,0xdb080036}},	//   _cntg_, ርትራዊ_, _әктә, éiër, 
   {{0x69dc01f0,0xa5b80321,0xc1d00352,0xc0e00023}},	//   _onqe, _ljóm, _гөлә, _ቐደም_, 
   {{0x7d091aab,0x69dc01af,0xcee8143e,0x32051aac}},	//   tzes, _nnqe, ئرون_, choy_, 
   {{0x1fa40588,0x69cc0076,0xceb4009d,0x00000000}},	//   _арег, ddce, гшөө, --, 
   {{0x7d091aad,0x69dc0309,0x69cc01a4,0xa5b8148b}},	//   rzes, _anqe, edce, _sjól, 
   {{0x38705629,0x7d091aae,0x7cf801e1,0x3f84005f}},	//   _styr_, szes, _bùrú, _ielu_, 
   {{0x3f84123c,0x7d08f760,0x9c6000db,0x00000000}},	//   _helu_, pzes, _پۇدو, --, 
   {{0x8d7461b7,0x3f8402c4,0x3c1400bc,0xec6d1aaf}},	//   _ئاما, _kelu_, těvě_, _ып_, 
   {{0x3f8405a1,0x656c0165,0xfaa51ab0,0xca3800df}},	//   _jelu_, _afch, _бако, ruĝa_, 
   {{0x3f851ab1,0xa3e49a09,0x00000000,0x00000000}},	//   _melu_, भान_, --, --, 
   {{0x7bc11ab2,0x656c0810,0x62500003,0xe5a004a9}},	//   lelu, _cfch, _għox, йиси, 
   {{0xa50400f0,0xea6001d9,0xa82001b9,0x754401f0}},	// [1a5e0] гета_, _پھۯی, شکین, уназ, 
   {{0xd94404a9,0x3f840311,0x200409a8,0x656c03ac}},	//   _йеқи, _nelu_, jhni_, _efch, 
   {{0x20040023,0xdb0806af,0x6fe000bc,0x290403b9}},	//   dhni_, éièr, पासं, _ənam_, 
   {{0x656c0998,0x7bc11ab3,0xe45c05d5,0xe2940120}},	//   _gfch, helu, _tröp_, ѓач_, 
   {{0x7bc11ab4,0x3f851ab5,0x32040789,0x8f8439b8}},	//   kelu, _belu_, rhoy_, иқал, 
   {{0x3f851ab6,0x7bc11ab7,0x20045103,0x32040009}},	//   _celu_, jelu, ghni_, shoy_, 
   {{0x7bc11ab8,0x3f851ab9,0xb8d4025c,0x00000000}},	//   delu, _delu_, _ཛད_, --, 
   {{0x3f84002e,0xeda40f37,0x200400d0,0x2fcc037e}},	//   _eelu_, ушко, ahni_, sdfg_, 
   {{0x3ba40201,0x7bc11aba,0x2fdc0a2e,0x3f848f7e}},	//   _ጉዳዮች_, felu, _tntg_, _felu_, 
   {{0x7bc056dc,0x20051abb,0x3f851abc,0xd70425fe}},	//   gelu, chni_, _gelu_, रनाथ_, 
   {{0xa5b81f60,0x69cc0a73,0xabb000d1,0x69f00137}},	//   _sjóm, tdce, _ғайә, йүкт, 
   {{0x3f840327,0xfe4001d3,0x00000000,0x00000000}},	//   _zelu_, _وکٹی, --, --, 
   {{0x7bc11abd,0x69cc01e6,0x6da400c7,0x3e540055}},	//   belu, rdce, _аиҵа, _nāty_, 
   {{0x3f841bce,0x00000000,0x00000000,0x00000000}},	//   _xelu_, --, --, --, 
   {{0xd7f8009d,0x59d0000d,0x00000000,0x00000000}},	//   ууя_, _तोकर, --, --, 
   {{0x69dc014b,0xe4e40826,0x99803535,0x85746bd7}},	//   _unqe, лізн, _imiş_, рлах, 
   {{0x53e007b7,0x84146206,0x2004022e,0x147433d2}},	// [1a5f0] नांश, амах, yhni_, مالج, 
   {{0xb4b400fd,0x4aa80073,0xf8b40166,0x46142bef}},	//   рифә, _कमाव, _төю_, _چودر, 
   {{0x3f851abe,0xfd540055,0x66800066,0x00000000}},	//   _relu_, _draṃ, _دیزل, --, 
   {{0x45d51abf,0x7bc11ac0,0x3f8408a4,0x2d8401ee}},	//   _томс, zelu, _selu_, _neoe_, 
   {{0x3f851ac1,0xaf440014,0x20040200,0xc0e4119e}},	//   _pelu_, یرى۪, thni_, ролк, 
   {{0xa3a8033f,0x23e402d5,0xc2c41e5a,0xa918032e}},	//   क्ख_, _сімв, _پيري, gaþi, 
   {{0x7bc11ac2,0x3f851ac3,0xca380115,0x2004022e}},	//   velu, _velu_, juĝo_, rhni_, 
   {{0x2004006c,0x7bc11ac4,0x2d851ac5,0x3f840548}},	//   shni_, welu, _ceoe_, _welu_, 
   {{0x3f851ac6,0x7bc11ac7,0xb880038e,0x2004208d}},	//   _telu_, telu, říze, phni_, 
   {{0x225c0098,0x5e840953,0x1da41b57,0x6c300592}},	//   _hiuk_, _будз, _गावत, يفيا, 
   {{0xbb451ac8,0x7bc11ac9,0x3a242edc,0xca747983}},	//   ренк, relu, имог, ینیک, 
   {{0xa5b808a5,0x2e1c0327,0x00000000,0x00000000}},	//   _djók, fċfu_, --, --, 
   {{0x2e3804e6,0x998003e0,0x4c680150,0x00000000}},	//   rëft_, _emiş_, _биін_, --, 
   {{0x225d1aca,0x6720107d,0x95b40131,0x00000000}},	//   _liuk_, _žnja, әрвә, --, 
   {{0x25a80175,0xfaa40868,0x7aa43e38,0x3b080408}},	//   _bccl_, _тайо, _тийз, _шеко_, 
   {{0x95700092,0xb6a401d5,0xfd5400b8,0x660003fb}},	//   _ቤታችን_, лиҳл, _sraṃ, опса, 
   {{0xb3851326,0xb3740aae,0x09b40011,0xe56401c6}},	// [1a600] илал, لداش, য়াখা, риуд_, 
   {{0x19c4052f,0x25a91acb,0x1ca8031c,0xfd640022}},	//   _тәүг, _eccl_, _བྱབ_, _petỹ, 
   {{0x213c2a1f,0x25a8010a,0x72c40026,0x55c4190b}},	//   _ayuh_, _fccl_, рбез, _ланғ, 
   {{0x213c0066,0x15b40075,0x225c005a,0x06280014}},	//   _byuh_, _دەرس, _ciuk_, _مسُٹ_, 
   {{0x225c3386,0x7d0c010e,0x00000000,0x00000000}},	//   _diuk_, _ýash, --, --, 
   {{0x75806f78,0x836401d5,0x74151acc,0x00000000}},	//   _ыңға, _هدفل, _ئوسا, --, 
   {{0x42d43334,0x799402d0,0x00000000,0x00000000}},	//   _літу, _odyw, --, --, 
   {{0xa2c09401,0xe1f4026b,0x00000000,0x00000000}},	//   रबर्, _кгс_, --, --, 
   {{0x1ca80003,0xa5b82507,0x00000000,0x00000000}},	//   _བྱད_, _sjók, --, --, 
   {{0x70500133,0x00000000,0x00000000,0x00000000}},	//   _بۆتا, --, --, --, 
   {{0xa3a88a4f,0xa0301c3e,0xa3e405c0,0x00000000}},	//   क्ट_, _بىلت, भात_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe94464d6,0xa9280046,0x799400a9,0xed3405f5}},	//   рхно, тіне_, _ddyw, _тэжэ, 
   {{0xd9181064,0x25a800cf,0x00000000,0x00000000}},	//   рью_, _sccl_, --, --, 
   {{0xf8ad1acd,0x69f001c0,0xe3cc0154,0x44240205}},	//   وکی_, _дүнт, রামব, _ıl_, 
   {{0xe9dc0005,0x8c180451,0x96f8014b,0xe97000db}},	//   flúe_, _جيڪر_, шест_, _گۇڭد, 
   {{0x225c0c6a,0xe9dc03b2,0x00000000,0x00000000}},	// [1a610] _riuk_, smús_, --, --, 
   {{0x225c003e,0x7c2c0115,0xa5b802d2,0x70800092}},	//   _siuk_, _ƭari, _mjói, _ይሰራሉ_, 
   {{0x1ca8025c,0xdcf801e4,0xd4040212,0x213c00b8}},	//   _བྱན_, rbuĉ, цяти, _syuh_, 
   {{0xdcf801e4,0x00000000,0x00000000,0x00000000}},	//   sbuĉ, --, --, --, 
   {{0xe9dc172e,0x20c40eff,0x80e006ab,0x4614030f}},	//   clúe_, рсег, पमें, _نوگر, 
   {{0xa5b8032e,0x7d0c00a2,0x00000000,0x00000000}},	//   _sjóh, _ýasi, --, --, 
   {{0x92941fe9,0x7f9400c7,0x00000000,0x00000000}},	//   _марц, _ҳазх, --, --, 
   {{0x7d1c0008,0xf2d0008f,0xbd8800d1,0x00000000}},	//   ússo, _צען_, اچان_, --, 
   {{0x213c00f2,0x81444028,0xac94007b,0x7f94014b}},	//   _uyuh_, _اچان, منيا_, _газх, 
   {{0x0b800020,0x60d91ace,0xef0c004b,0x39440327}},	//   _የአየር_, _irum, _ګڼه_, _ġos_, 
   {{0x3944005f,0x00000000,0x00000000,0x00000000}},	//   _šos_, --, --, --, 
   {{0xa6cc0183,0x8a3802e8,0x0c2400cf,0x00000000}},	//   ৰহাট, ияят_, ймөн, --, 
   {{0xeaac00dd,0xa92000a7,0x23c40243,0x6d446aad}},	//   وٹی_, здял, रजाद, ýkat, 
   {{0x60d8009f,0x9ba00131,0xbb84007b,0x59b80ebb}},	//   _mrum, _بەدى, _الثي, ेजहर, 
   {{0xa3a847d0,0xf7440108,0x00000000,0x00000000}},	//   क्छ_, сево, --, --, 
   {{0xd1e0044e,0x60d91acf,0x00000000,0x00000000}},	//   ዓታት_, _orum, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [1a620] --, --, --, --, 
   {{0x657c0218,0x77c88f3a,0xf41c00cc,0x00000000}},	//   abqh, _слог_, _বীজৰ_, --, 
   {{0x60d8094a,0x6b5c03e0,0x1da4000d,0x00000000}},	//   _arum, _içgü, _गांत, --, 
   {{0x60d91ad0,0xdb2000e4,0x71a40006,0x00000000}},	//   _brum, _ãrõt, садз, --, 
   {{0x60d91ad1,0xa5b801e1,0xe294aede,0x25bc0de2}},	//   _crum, _ajów, _қат_, _ñula_, 
   {{0x60d91ad2,0xd010007b,0x76540108,0x00000000}},	//   _drum, بلت_, lmyy, --, 
   {{0x60d91ad3,0x32440261,0xa5b808a5,0x6f1c0419}},	//   _erum, _гевг, _sjói, ĺpco, 
   {{0x60d91ad4,0x78a4022c,0x7654005b,0x6ca42077}},	//   _frum, kukv, nmyy, брож, 
   {{0x60d91ad5,0x78a40267,0xdce800c0,0x5c7001f4}},	//   _grum, jukv, _megė, плыт, 
   {{0x29040325,0x7654005b,0x00000000,0x00000000}},	//   _āna_, hmyy, --, --, 
   {{0xd9e401f9,0xdee007a5,0x00000000,0x00000000}},	//   गांत_, _нофи, --, --, 
   {{0x60d80124,0x1ca80327,0xdce800c0,0x00000000}},	//   _yrum, _བྱམ_, _negė, --, 
   {{0x244c51bb,0x60d80332,0x38b000c7,0x78a402d2}},	//   lüme_, _xrum, võrã_, gukv, 
   {{0x6d400009,0xed6c001f,0xfb1801d3,0x00000000}},	//   _iyoa, _አቀባይ_, اریں_, --, 
   {{0x244c0274,0x6b8803ac,0xa5b803b2,0xdce80064}},	//   nüme_, _iefg, _mjóv, _begė, 
   {{0x6d4004ba,0x059401d5,0x00000000,0x00000000}},	//   _kyoa, غازگ, --, --, 
   {{0xe6640107,0x244c00e4,0xdce800c0,0x38b00022}},	// [1a630] ртҳо, hüme_, _degė, rõrã_, 
   {{0x60d80023,0x244c010e,0x00000000,0x00000000}},	//   _rrum, küme_, --, --, 
   {{0x2364151c,0x244c0432,0x00000000,0x00000000}},	//   žnjo_, jüme_, --, --, 
   {{0x60d91ad6,0x6b880076,0x00000000,0x00000000}},	//   _prum, _lefg, --, --, 
   {{0xdce80327,0x6d411ad7,0x60d806be,0x249c02d2}},	//   _idgħ, _nyoa, _qrum, _íum_, 
   {{0xafe11ad8,0x661c0113,0x60d8030a,0x00000000}},	//   дошл, liqk, _vrum, --, 
   {{0x6d405cb6,0x00000000,0x00000000,0x00000000}},	//   _ayoa, --, --, --, 
   {{0x6d411ad9,0xa3e51ada,0xdce89825,0x171c008f}},	//   _byoa, भाव_, _jdgħ, טווע, 
   {{0x60d91adb,0x51851adc,0x00000000,0x00000000}},	//   _urum, _хуса, --, --, 
   {{0x661c5431,0x50f40276,0x244c0205,0x78a403b2}},	//   hiqk, _эзут, büme_, vukv, 
   {{0x39e8ceb8,0x661c0309,0xdcf80024,0xc94805d0}},	//   адно_, kiqk, mbuč, _סמ_, 
   {{0xddd00210,0x00000000,0x00000000,0x00000000}},	//   żałe, --, --, --, 
   {{0xeb8c2cb8,0xdce80024,0x8d745226,0x00000000}},	//   _ои_, _regė, _رانا, --, 
   {{0x78a40552,0xec180116,0xa5b802d2,0xdce800c0}},	//   rukv, _кечә_, _mjóu, _segė, 
   {{0x8d94001f,0x998c01ed,0x00000000,0x00000000}},	//   _መቀበል_, ődő_, --, --, 
   {{0x661c0309,0x9ba0215c,0xdb000332,0xf5040798}},	//   giqk, _بەگى, _gcná, озбо, 
   {{0x81c002a6,0xdce80327,0x244c3712,0x74e801c6}},	// [1a640] ্ঞা_, _ddgħ, züme_, шдаг_, 
   {{0x244c05d1,0x7654023a,0xa3e46620,0xc044004b}},	//   yüme_, smyy, भाष_, _سږ_, 
   {{0x1168129e,0x00000000,0x00000000,0x00000000}},	//   ملای_, --, --, --, 
   {{0xa5b808a7,0x6abc0e78,0xb1440353,0x00000000}},	//   _sjóv, _äpfe, онел, --, 
   {{0xc764247f,0x00000000,0x00000000,0x00000000}},	//   _باۋى, --, --, --, 
   {{0x2bac4900,0x244c2ba3,0xaf0400d4,0x00000000}},	//   ज्ञा, tüme_, жчик, --, 
   {{0xe2951add,0x23251ade,0x6b880327,0xeda400cf}},	//   _мар_, _дори_, _refg, ошпо, 
   {{0x244d1adf,0x6b891ae0,0x00000000,0x00000000}},	//   rüme_, _sefg, --, --, 
   {{0xa5b80174,0x00000000,0x00000000,0x00000000}},	//   _tjóv, --, --, --, 
   {{0x29d4004d,0x661c022e,0xe8fc00e4,0x5bb40108}},	//   _ủa_, ziqk, vyû_, олья_, 
   {{0xdd8d1ae1,0x2e68799d,0x6b88032e,0xa5b801ef}},	//   _ош_, _тиеп_, _vefg, _kjót, 
   {{0x6cd51ae2,0x2bac00cd,0xc0f80023,0xa91802d2}},	//   _وقضا, ज्जा, ላሲሉ_, daþr, 
   {{0xed5801c0,0x6b880135,0xa5b802d2,0x1e54011a}},	//   _тод_, _tefg, _mjót, _ושאר_, 
   {{0xa5b80ad9,0xec3001b9,0x661c0784,0xdd0c0153}},	//   _ljót, _توتگ, wiqk, _užša, 
   {{0xd6d82dbb,0x661c0113,0xfa5401b9,0xa91802d2}},	//   отт_, tiqk, تریگ, gaþr, 
   {{0xa5b809f3,0x25ac04cc,0x78b401d3,0x00000000}},	//   _njót, ügl_, égvá, --, 
   {{0xe9dc056a,0x661c02d1,0xca380115,0xa3e4033f}},	// [1a650] clúa_, riqk, juĝi_, भाल_, 
   {{0x54341077,0x2eec0175,0x661c022e,0xdd00002b}},	//   ورلر, kxff_, siqk, _śrīs, 
   {{0x661c0784,0xa5b803b2,0x00000000,0x00000000}},	//   piqk, _sjóu, --, --, 
   {{0x661c0113,0xca3801e4,0xd04003e3,0xe7e000bc}},	//   qiqk, fuĝi_, _ismə, खाका_, 
   {{0x2724013f,0xa5b800e4,0xa3b006b1,0x00000000}},	//   _hεn_, _amóg, _टाप_, --, 
   {{0xd25073c5,0xee3407dd,0x00000000,0x00000000}},	//   ىنە_, ҟны_, --, --, 
   {{0x44211ae3,0x88d0045e,0x4f680bd6,0xbea493fb}},	//   mih_, ামিক, әшәм_, чайк, 
   {{0xb8cc0135,0xa5b802d2,0xbc903c1a,0xfde808ca}},	//   _ནྀ_, _gjót, еңдә, сдик_, 
   {{0x3cf400af,0xec7401f4,0x00000000,0x00000000}},	//   इहें_, ппы_, --, --, 
   {{0xa5b8066a,0xbb4801d5,0xcd281411,0x00000000}},	//   _kjós, یلکن_, تسىن_, --, 
   {{0x4420003e,0xd25001d3,0x00000000,0x00000000}},	//   iih_, _سنے_, --, --, 
   {{0x44211ae4,0xdce80055,0xa5b802d2,0x0dc85a5e}},	//   hih_, _jegī, _mjós, _мучи_, 
   {{0xfce51ae5,0x44203a69,0xa5b81c38,0x3e711ae6}},	//   _холо, kih_, _ljós, _hát_, 
   {{0x44200263,0xfbd02547,0xa5b801e1,0x3e7008a5}},	//   jih_, _ستت_, _ojós, _kát_, 
   {{0x442081f1,0x7c200cfe,0xa5b80aab,0x00000000}},	//   dih_, milr, _njós, --, 
   {{0x3e711ae7,0x7c200083,0x7d0c010b,0x00000000}},	//   _mát_, lilr, _ýass, --, 
   {{0x3e711ae8,0x09b404c5,0x98ac005f,0x4420102c}},	// [1a660] _lát_, _জোকা, ādē_, fih_, 
   {{0x38b421e3,0xa5b803f2,0xa5206390,0xa4400150}},	//   mær_, _sjót, хмуд, енуд, 
   {{0x38b42759,0x3e70001e,0x00000000,0x00000000}},	//   lær_, _nát_, --, --, 
   {{0x442000ad,0x4adc00dc,0x7c20062c,0x00000000}},	//   aih_, यितव, hilr, --, 
   {{0x44211ae9,0x38b50c9b,0x7c20994b,0xdfcc0451}},	//   bih_, nær_, kilr, ڏين_, 
   {{0x44211aea,0x3e711aeb,0x2724016b,0xa5b81d1d}},	//   cih_, _bát_, _yεn_, _fjós, 
   {{0xc058090b,0xb8fc3ae9,0x3e70001e,0x7c211aec}},	//   ції_, _ཤན_, _cát_, dilr, 
   {{0x3e700232,0x646401ed,0x38b51aed,0x98ac0210}},	//   _dát_, _óriá, kær_, łdę_, 
   {{0x38b41477,0xa3b00037,0x00000000,0x00000000}},	//   jær_, _टाम_, --, --, 
   {{0x7c211aee,0x8e7c008f,0x38b42f48,0x3e711aef}},	//   gilr, _arĝe, dær_, _fát_, 
   {{0x600d0d70,0x9f780375,0xa5b8032e,0x09b40154}},	//   _dømd, _הנבח, _mjór, _জোগা, 
   {{0x320402c4,0x4d2401ee,0x00000000,0x00000000}},	//   nkoy_, _оялғ, --, --, 
   {{0x7c211af0,0x4420102c,0x38b4005c,0x98b828e8}},	//   bilr, yih_, gær_, плят_, 
   {{0xc6040a28,0x44200429,0x09b400cc,0xdcf80166}},	//   रस्य_, xih_, _জোখা, lauğ, 
   {{0x3e70004d,0x32040de2,0x9bb805d0,0x2604022e}},	//   _xát_, kkoy_, _הצופ, пчаг, 
   {{0x44211af1,0xa5b80248,0xb90c110e,0x00000000}},	//   wih_, _ajór, _julọ_, --, 
   {{0xa5b805f7,0x99d40592,0xdce80171,0x32040139}},	// [1a670] _sjós, _ستيا, _regī, dkoy_, 
   {{0x7d1d1af2,0x73c00724,0xa3e410fa,0x00000000}},	//   ússi, кәсе, भाइ_, --, 
   {{0x44211af3,0x3864011c,0xa5b8022c,0x999001f1}},	//   rih_, _èora_, _djór, ťaťa_, 
   {{0x44208a77,0x3e70004d,0x00000000,0x00000000}},	//   sih_, _rát_, --, --, 
   {{0x44211af4,0x3e7007ae,0xa5b82242,0x3f691af5}},	//   pih_, _sát_, _fjór, оило_, 
   {{0x44211af6,0x3e70012c,0xa5b803b2,0x96b802f2}},	//   qih_, _pát_, _gjór, _بایز_, 
   {{0x5334005e,0x7c202153,0x600c00cc,0x614002d2}},	//   _зерт, vilr, _rømd, _bílþ, 
   {{0x600c0174,0x3e703a04,0x44300051,0x4fc400db}},	//   _sømd, _vát_, _hjz_, _ۋەنە, 
   {{0x3e70017a,0xa5b80022,0xa3e40073,0x00000000}},	//   _wát_, _yjór, भाऊ_, --, 
   {{0x61f91af7,0x38b40e38,0x3e7001fb,0x8fa400f3}},	//   _houl, vær_, _tát_, _пађе, 
   {{0x61f91af8,0xf98800b2,0xe9dc002d,0x44300332}},	//   _koul, يندي_, rlún_, _mjz_, 
   {{0x61f8049b,0x600c0183,0x38b46ab9,0x20051af9}},	//   _joul, _døme, tær_, lkni_, 
   {{0x61f81da7,0x2c700142,0x600c0feb,0x00000000}},	//   _moul, _gâd_, _tømd, --, 
   {{0xb8f51afa,0xf6b90d57,0xe61c0548,0x38b4383d}},	//   _सन_, _བྱུང, _amô_, rær_, 
   {{0x32040280,0xa3e407af,0xb4e400dc,0xe704179e}},	//   ykoy_, भाई_, भम्_, وسفی, 
   {{0x61f91afb,0x8e7c0115,0xa5b80321,0x38b401bf}},	//   _noul, _urĝe, _sjór, pær_, 
   {{0x443001f5,0xb46475e1,0xe6411afc,0x00000000}},	// [1a680] _bjz_, дкал, тетп, --, 
   {{0x61f88cae,0x64a11afd,0xe4540111,0xb4cc0073}},	//   _aoul, тафа, джу_, _शनी_, 
   {{0x4430030d,0x31691afe,0x2ba4000d,0x00000000}},	//   _djz_, ошло_, _खाघा, --, 
   {{0x61f88d04,0x2004208d,0x3124113e,0x3204002e}},	//   _coul, ekni_, мдег, ukoy_, 
   {{0xe7e00574,0x753401c6,0x320408a9,0x00000000}},	//   खाचा_, _цэнх, rkoy_, --, 
   {{0x61f80156,0x6d440793,0xb2f4031c,0x62947a06}},	//   _eoul, ükam, བྱུང_, bsxo, 
   {{0xe3611aff,0xa80003e0,0x6240000d,0x00000000}},	//   _акри, _şıkk, tõot, --, 
   {{0x61f91b00,0x600d1b01,0x20040e14,0xdd940124}},	//   _goul, _røme, akni_, мшь_, 
   {{0x614000c7,0x600c0158,0xb0340131,0xdca00063}},	//   _аета, _søme, _قىرغ, вањи, 
   {{0x61f91b02,0x60f8011a,0xa3e404af,0x00000000}},	//   _zoul, _והמק, भाए_, --, 
   {{0x61f91b03,0xfff51b04,0x00000000,0x00000000}},	//   _youl, _سکوت_, --, --, 
   {{0x8c4800a2,0x60e40166,0xe7d4000d,0x00000000}},	//   _bişý, _ürmä, _णोजप, --, 
   {{0x9cb000c6,0x00000000,0x00000000,0x00000000}},	//   _لمنت, --, --, --, 
   {{0x600c0158,0x00000000,0x00000000,0x00000000}},	//   _tøme, --, --, --, 
   {{0x80d41533,0x683c012c,0x00000000,0x00000000}},	//   _मैने, vádě, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x78a400f3,0x94747aaf,0x271400cc,0x00000000}},	// [1a690] crkv, ندلا, _দুখো_, --, 
   {{0x61f91b05,0x7cfc01e4,0x00000000,0x00000000}},	//   _soul, nɨra, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe4a51b06,0xf6b80135,0xe3cc015b,0x629401d5}},	//   _орго, _བྱིང, রাইব, rsxo, 
   {{0x61f91b07,0xa5b81f08,0xa3b4010b,0xfd6800e4}},	//   _voul, _emóc, _оңат_, pepẽ, 
   {{0x61f91b08,0x81c000cc,0x00000000,0x00000000}},	//   _woul, ্ঞই_, --, --, 
   {{0x61f91b09,0x20051b0a,0x534481b5,0x00000000}},	//   _toul, rkni_, _ахта, --, 
   {{0x20051b0b,0x925801c6,0x00000000,0x00000000}},	//   skni_, _жаст_, --, --, 
   {{0xc0340640,0x3c64094f,0xacc4008e,0xfc04004e}},	//   _знај, нкиг, егыз_, еппо, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbf151b0c,0x660c017a,0xeab400ee,0x00000000}},	//   _ثواب, _olck, нйэ_, --, 
   {{0x3f640198,0x00000000,0x00000000,0x00000000}},	//   mɓu_, --, --, --, 
   {{0xbb4807d6,0x66e021f3,0x4c8400c0,0x00000000}},	//   تلگن_, қота, _алів, --, 
   {{0x660c0120,0xa5b8032e,0xc8380092,0x00000000}},	//   _alck, _sjóp, _የቅርን, --, 
   {{0x6bd416ac,0xf654005b,0x00000000,0x00000000}},	//   _سويس_, етаю, --, --, 
   {{0x7cf00139,0xc1d81bd6,0x00000000,0x00000000}},	//   _tοrğ, णयोग, --, --, 
   {{0xe45c007c,0x73e4011c,0x00000000,0x00000000}},	// [1a6a0] _spöa_, ноаз, --, --, 
   {{0xa3e406e3,0x93c800dd,0x7784030d,0x00000000}},	//   भाग_, بارہ_, _ялоз, --, 
   {{0x387000ad,0x6b2401e1,0x68f8005c,0x6430215c}},	//   _huyr_, _kòmẹ, øudv, دىلئ, 
   {{0xda100316,0x64a000c7,0x00000000,0x00000000}},	//   ासित_, _әара, --, --, 
   {{0x7644003e,0x63a8634d,0x3dcc00e8,0xc7a800e5}},	//   _ikky, álné, deew_, _عدیل_, 
   {{0xeeb429db,0x2714015b,0x6ab87813,0x00000000}},	//   еккә_, _দুটো_, yttf, --, 
   {{0xa3e40b2c,0xa2e11b0d,0xda100490,0x8f344684}},	//   _ядра_, _йорд, ासात_, ъекц, 
   {{0x387000ad,0x81640137,0x00000000,0x00000000}},	//   _ouyr_, رەەك_, --, --, 
   {{0x244c0205,0x00000000,0x00000000,0x00000000}},	//   küml_, --, --, --, 
   {{0x80dc07f7,0xe0d51b0e,0xc15400fb,0x00000000}},	//   पिरे, _яву_, _рњсњ, --, 
   {{0xcb3402e8,0xad1004b4,0x4a541188,0x00000000}},	//   тенъ, _әплә, ккос, --, 
   {{0xa3e400c5,0xeb04004e,0x00000000,0x00000000}},	//   _मोन_, _үчко, --, --, 
   {{0x6e211b0f,0x272401d5,0x6dc400d0,0x00000000}},	//   _imob, _kеng_, _vďač, --, 
   {{0x7644037e,0x9cd402e4,0x00000000,0x00000000}},	//   _akky, _נווה_, --, --, 
   {{0xd7580022,0x00000000,0x00000000,0x00000000}},	//   еирц_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69cd1b10,0x6e200327,0xe2f400e5,0x00000000}},	// [1a6b0] mece, _mmob, کواڈ_, --, 
   {{0x69cd1b11,0x36a004a9,0x00000000,0x00000000}},	//   lece, _ھەقق, --, --, 
   {{0x7024009e,0x6e211b12,0x00000000,0x00000000}},	//   মকাজ_, _omob, --, --, 
   {{0x69cca5be,0x00000000,0x00000000,0x00000000}},	//   nece, --, --, --, 
   {{0x69cc0381,0x00000000,0x00000000,0x00000000}},	//   iece, --, --, --, 
   {{0x44249577,0x6e20102c,0xbea4f145,0x00000000}},	//   _öl_, _amob, вакк, --, 
   {{0x69cd1b13,0x6e200332,0xb2740166,0x1014a39b}},	//   kece, _bmob, _аксә, دبند, 
   {{0x600c0feb,0x2d805511,0x00000000,0x00000000}},	//   _døma, űken_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x23640bb8,0x6e211b14,0xa92400f3,0xdef8005b}},	//   žnju_, _emob, _možđ, _ные_, 
   {{0x69cd1b15,0x00000000,0x00000000,0x00000000}},	//   fece, --, --, --, 
   {{0xf2d000c8,0x8e7c010f,0x656c022e,0xd1e801f3}},	//   בעט_, _urĝa, _ngch, _ሙቀት_, 
   {{0xe8f4021b,0xe9a001b9,0xec6c0395,0x7d2801e2}},	//   вля_, шаяп, _ъп_, _کيږې_, 
   {{0xe45c01e3,0x6e2015c0,0x00000000,0x00000000}},	//   _spön_, _zmob, --, --, 
   {{0x69cc2cd7,0xf74431df,0xf6080345,0x7bc03830}},	//   bece, тево, وتره_, mflu, 
   {{0x69cd1b16,0x940c0cc1,0x7bc11b17,0x64440139}},	//   cece, ələr_, lflu, _akji, 
   {{0x7bc001c7,0xdc740092,0x00000000,0x00000000}},	// [1a6c0] oflu, _በባህር_, --, --, 
   {{0x8b040118,0x37047b0e,0x643000d1,0x00000000}},	//   ůřez, _апог, لىقئ, --, 
   {{0xe2949133,0x7234182f,0xa3b005d7,0x7cfc0115}},	//   вах_, پراط, _टार_, kɨro, 
   {{0x7bc00e78,0xa3e44f76,0x00000000,0x00000000}},	//   hflu, _मोठ_, --, --, 
   {{0x21641b10,0x600c95aa,0xf6500228,0x7bc11b18}},	//   вици_, _søma, _مئڭ_, kflu, 
   {{0x6380721f,0x69cd1b19,0x8f340395,0x00000000}},	//   _вгра, zece, лелц, --, 
   {{0x69cc0ab7,0x41dc772c,0x91c42f89,0x3ce8031c}},	//   yece, _नोकस, _бәлл, _ġava_, 
   {{0x6e211b1a,0xe6b8723e,0x65c400b0,0x7bc0003a}},	//   _qmob, şaçı, _tīhō, eflu, 
   {{0xf064035b,0xa3e41f13,0x7bc11b1b,0x4bc400f7}},	//   _акап, _मोड_, fflu, гөйг, 
   {{0x8af80c17,0x600c03b2,0xa83800e4,0xf1b01546}},	//   енос_, _tøma, huÿr, ीभवन, 
   {{0x6e2002fa,0xd9dc009e,0xb88000bc,0x00000000}},	//   _tmob, ধানম, říle, --, 
   {{0xfe700050,0xa5b8565c,0x6e200117,0x00000000}},	//   _ادٕ_, _amón, _umob, --, 
   {{0xa3b005f9,0xaac401d5,0x7bc11b1c,0xd1d40023}},	//   _टाल_, رتگن, bflu, ረስታ_, 
   {{0x69cd1b1d,0x00000000,0x00000000,0x00000000}},	//   sece, --, --, --, 
   {{0xd7940395,0x00000000,0x00000000,0x00000000}},	//   рисъ, --, --, --, 
   {{0x64440b21,0xfd540882,0x00000000,0x00000000}},	//   _skji, _asaṃ, --, --, 
   {{0xda101524,0x55751b1e,0x00000000,0x00000000}},	// [1a6d0] ासरत_, ргут, --, --, 
   {{0xfd5400b8,0x00000000,0x00000000,0x00000000}},	//   _csaṃ, --, --, --, 
   {{0x668001d5,0x527406c2,0x00000000,0x00000000}},	//   _خیزل, لانز, --, --, 
   {{0xe9dd1b1f,0x656c01f5,0x00000000,0x00000000}},	//   ndú_, _ugch, --, --, 
   {{0xd7c11b20,0xc454009f,0x00000000,0x00000000}},	//   श्वच, _مَحب, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfe70027d,0xaf440014,0x7e984e10,0x92941ff1}},	//   حدت_, ُرى۪, رنظر_, _васц, 
   {{0xe0d00014,0xe9dcea0f,0x9758010f,0x00000000}},	//   _پزر_, jdú_, כיוו_, --, 
   {{0x212801c7,0xd1d40023,0xe9dc02d2,0x00000000}},	//   _äch_, ረትቲ_, ddú_, --, 
   {{0x81e400cc,0x3b840153,0x00000000,0x00000000}},	//   _পকি_, ылог, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7bc11b21,0xe45c5bf6,0xefb80023,0x6ec803e3}},	//   sflu, _spöl_, ተዘይ_, _dəbd, 
   {{0x2630009b,0x81e400fe,0xb8800139,0x00000000}},	//   rćol_, _পকা_, _ğísa, --, 
   {{0x3e700038,0x315404ac,0xe9dc40bb,0x7d08035b}},	//   _ešte_, טירן_, adú_, myes, 
   {{0x09c8045e,0x7d091b22,0x80d405b3,0x35a4013e}},	//   ষয়া, lyes, _मैसे, лавг, 
   {{0x3ddc002e,0x7d080083,0xdb0c010e,0x65700055}},	//   _jaww_, oyes, _ýeñl, _ādhå, 
   {{0x7d081283,0x600c003b,0x237c00a2,0x00000000}},	// [1a6e0] nyes, _rømn, _şuja_, --, 
   {{0x79951b23,0x600c03cd,0xe3b51b24,0xa83800e4}},	//   _heyw, _sømn, лбу_, yrÿi, 
   {{0x79951b25,0x7d091b26,0x437401c0,0xeb94010f}},	//   _keyw, hyes, руут, רדער_, 
   {{0x600c05ac,0x79940455,0x7d08dbbe,0x91c40139}},	//   _bømo, _jeyw, kyes, радҗ, 
   {{0x7994047e,0x7d080200,0xbb5400d1,0x00000000}},	//   _meyw, jyes, _ﺋﺎﻱ_, --, 
   {{0xa06407d6,0x79940309,0xddc81d64,0x5f903756}},	//   гача_, _leyw, _figū, бишт, 
   {{0x600c005c,0x00000000,0x00000000,0x00000000}},	//   _tømn, --, --, --, 
   {{0x7d090f3b,0x64400419,0x00000000,0x00000000}},	//   fyes, čnie, --, --, 
   {{0x7d091b27,0xb8800118,0x91c400fb,0x00000000}},	//   gyes, říje, _бәһл, --, 
   {{0xdd8c01ed,0x00000000,0x00000000,0x00000000}},	//   _ہوم_, --, --, --, 
   {{0xda7411ed,0x3ddc00e8,0x79951b28,0xa038008f}},	//   ляя_, _faww_, _beyw, _טעמפ, 
   {{0xee391b29,0x7d091b2a,0x8d2801e0,0xdd8c1888}},	//   _яне_, byes, _инең_, _فوم_, 
   {{0x02d04407,0x4bc51b2b,0xe9dd1b2c,0x7d0800ca}},	//   _सन्न, _көнг, rdú_, cyes, 
   {{0x1cb400d9,0x6ec806be,0xeb740064,0x00000000}},	//   _עלול_, _təbd, _сыдэ, --, 
   {{0x6b991b2d,0x2fdc1570,0x1ac46215,0x00000000}},	//   matg, _matg_, _буып_, --, 
   {{0x6b991b2e,0x2fdc0c86,0xd5b8a2ae,0x843800d1}},	//   latg, _latg_, лсу_, ھكار_, 
   {{0x600c03d4,0x44f51b2f,0x84c40075,0xdc740092}},	// [1a6f0] _bøml, шпас, шәнд, _በባሕር_, 
   {{0x6b986427,0xddc80024,0xe5c40139,0x00000000}},	//   natg, _pigū, _өсмо, --, 
   {{0x69dc058a,0x600c01bf,0x981400f1,0x6ec806be}},	//   _kaqe, _sømo, _دبيا, _ləbb, 
   {{0x69dc0054,0x6b991b30,0x7d091b31,0x2b4c01bf}},	//   _jaqe, hatg, yyes, _myfc_, 
   {{0x69dd1b32,0x6b98036b,0x9484010b,0x7598011a}},	//   _maqe, katg, _гысд, _בסרג, 
   {{0x3ddc0a2e,0x69dd1b33,0x20100120,0x7d091b34}},	//   _saww_, _laqe, óxi_, vyes, 
   {{0x6b991b35,0x80d4189a,0x3ddc013f,0x29080368}},	//   datg, _मैरे, _paww_, hyca_, 
   {{0x7d091b36,0xcee8143e,0xfde80982,0x14ac0073}},	//   tyes, ارون_, тдик_, _चिमण, 
   {{0x2fdc060a,0x1fa40a31,0x79940784,0x6b991b37}},	//   _fatg_, _брег, _reyw, fatg, 
   {{0x60d80680,0x6b991b38,0xa5b80332,0x63b4022e}},	//   _isum, gatg, _smól, ngxn, 
   {{0x69dd1b39,0xa5b801e1,0xd1cc001f,0x7d086f9e}},	//   _baqe, _amóm, _አበበ_, syes, 
   {{0x69dcdc40,0x7d080589,0xaab400af,0x8bb400c7}},	//   _caqe, pyes, _अमरक, ақәу_, 
   {{0x69dc016d,0x6b98036b,0x600c01bf,0xdff8000d}},	//   _daqe, batg, _lømm, _्वाद_, 
   {{0xb8ec09d9,0x6b991b3a,0x60d8a7d0,0xf770b3b0}},	//   _रह_, catg, _msum, تاح_, 
   {{0x69dc044e,0x600c03cd,0x65c00ae5,0x601c0024}},	//   _faqe, _røml, ﺭﻗﯩﻠ, _išmė, 
   {{0x273005a9,0x2908003a,0xda1426a8,0x600c072b}},	//   زىقس, byca_, _دستک, _søml, 
   {{0xf7711b3b,0x60d91b3c,0xb2f40327,0xe5743d76}},	// [1a700] _واد_, _nsum, བྱནང_, рзу_, 
   {{0x69dc014b,0x27b00150,0x00000000,0x00000000}},	//   _zaqe, _мәсс, --, --, 
   {{0x69dd1b3d,0x00000000,0x00000000,0x00000000}},	//   _yaqe, --, --, --, 
   {{0x6b981570,0x600c2188,0x2fdc07c5,0x69dc0067}},	//   zatg, _dømm, _satg_, _xaqe, 
   {{0x6b9807d6,0x2fdc07c5,0x0fc801ec,0x00000000}},	//   yatg, _patg_, лқап_, --, 
   {{0x6ec800ac,0x7d0c0432,0x62800419,0x205000c7}},	//   _rəbb, _ýasy, ínoc, ҩтәр, 
   {{0x6b991b3e,0x60d91b3f,0x29082634,0x9ea40798}},	//   vatg, _esum, zyca_, авја_, 
   {{0x6a7c1132,0x6b980af9,0x4c9401f0,0x4cb80108}},	//   _nīfa, watg, биис, глию_, 
   {{0x6b991b40,0xeb0c9f6b,0x2fdc003a,0x2164010a}},	//   tatg, ान्त_, _tatg_, _вити_, 
   {{0xd1cc2295,0x69dc27b3,0xd2500345,0x80e8210e}},	//   _አበባ_, _saqe, _بۆڵ_, _حرفِ_, 
   {{0x6b991b41,0x69dc02d3,0xe45c007c,0x2908012d}},	//   ratg, _paqe, _spök_, wyca_, 
   {{0x6b98fcbd,0x6ab42871,0x69dd1b42,0x6ec806be}},	//   satg, _अमीर, _qaqe, _təbb, 
   {{0x6b9835f5,0x69dc0333,0x3e7039ca,0xab8400db}},	//   patg, _vaqe, _išta_, _куйк, 
   {{0x69dd1b43,0x6b98036b,0x9b900372,0x00000000}},	//   _waqe, qatg, _ۇلۇت, --, 
   {{0x69dc0333,0x1cb00135,0xbd240d62,0xeff4001f}},	//   _taqe, _ཞའོ_, _پى۪ٹ, _ፈንድ_, 
   {{0x85747041,0x600c168c,0x00000000,0x00000000}},	//   слах, _rømm, --, --, 
   {{0x600c0627,0x2374210e,0x04951b44,0x00000000}},	// [1a710] _sømm, لاضح, صلاح, --, 
   {{0xaad82aa1,0x9418005b,0x00000000,0x00000000}},	//   _बनाक, ажут_, --, --, 
   {{0xd37807d5,0x60d80083,0x6d5433b8,0x45d401af}},	//   рчу_, _ssum, _øyaf, _лонс, 
   {{0xa3e42017,0x600c0fac,0xa3b00073,0x00000000}},	//   _मोर_, _vømm, _टाक_, --, 
   {{0x9508066d,0xe3b01001,0xe9dc00db,0x95380108}},	//   _پہلے_, _ورس_, llús_, _взят_, 
   {{0x600c7a1e,0x6ab407d0,0xa3a80210,0x00000000}},	//   _tømm, _अमूर, _गयि_, --, 
   {{0x53351b45,0x26c02959,0x63a40334,0x00000000}},	//   _дерт, ntjo_, _idjn, --, 
   {{0x60d81aa1,0x628401af,0x41c401d9,0xdce8025c}},	//   _tsum, _itjo, _دٲرِ, _jegħ, 
   {{0xa3a814cf,0x99805656,0xdce80135,0x00000000}},	//   _गया_, _aliş_, _megħ, --, 
   {{0x40586396,0x99940210,0xfb880108,0x00000000}},	//   _صلاح_, żdży_, ыбок_, --, 
   {{0xd9dc02f5,0xbb445899,0x00000000,0x00000000}},	//   ধাসম, сенк, --, --, 
   {{0xdce8031c,0x00000000,0x00000000,0x00000000}},	//   _negħ, --, --, --, 
   {{0x80dc01ad,0xc0d40023,0x00000000,0x00000000}},	//   पिटे, ረብሉ_, --, --, 
   {{0xa3e408e9,0x628488e6,0xca4c0150,0xebfc0208}},	//   _मोल_, _otjo, _ﺃﻭﺼ_, _thưở_, 
   {{0x6a7c0421,0xdce80327,0xdb00013a,0x00000000}},	//   _tīfa, _begħ, _odné, --, 
   {{0x066c08b0,0xf77021ea,0x59dc00bc,0x00000000}},	//   _ﺳﺎﻧﯩ, تاڭ_, _बसिर, --, 
   {{0xb37400f7,0xe9641188,0x00000000,0x00000000}},	// [1a720] مداش, _лаъл_, --, --, 
   {{0xe9dc0b21,0x68f80375,0x00000000,0x00000000}},	//   slút_, _עליה, --, --, 
   {{0x225c0055,0xe9dc5c17,0xf3580e92,0x00000000}},	//   _bhuk_, clús_, ушај_, --, 
   {{0x225c0223,0xdce80327,0xe2951b46,0x64400419}},	//   _chuk_, _gegħ, сац_, čnia, 
   {{0x225c020c,0x6284a8ac,0x00000000,0x00000000}},	//   _dhuk_, _etjo, --, --, 
   {{0xa5b80241,0x5f911b47,0x225c009d,0x74144029}},	//   _amóh, пишт, _ehuk_, _اوسا, 
   {{0x90a01954,0x00000000,0x00000000,0x00000000}},	//   _ናይዝጊ_, --, --, --, 
   {{0xdce8031c,0x00000000,0x00000000,0x00000000}},	//   _xegħ, --, --, --, 
   {{0x61ec0790,0x61b001d9,0x53980023,0xec6801a9}},	//   şilç, _ژٕہا, _ቅኑዓት_, лрок_, 
   {{0xca4c01ec,0x00000000,0x00000000,0x00000000}},	//   _ﺃﺭﺽ_, --, --, --, 
   {{0xdd8c00c0,0x00000000,0x00000000,0x00000000}},	//   _нш_, --, --, --, 
   {{0xa92801ec,0x00000000,0x00000000,0x00000000}},	//   гіге_, --, --, --, 
   {{0xa9280220,0xdce80327,0x00000000,0x00000000}},	//   уіне_, _regħ, --, --, 
   {{0xa3e405f9,0xd9181064,0xdce80327,0x2d9401e0}},	//   _मों_, сью_, _segħ, _төҫө_, 
   {{0x569427f0,0x00000000,0x00000000,0x00000000}},	//   заст, --, --, --, 
   {{0xdce8003d,0xe664cb0d,0x80b8015b,0x26c00219}},	//   _qegħ, стго, _ইনস্, rtjo_, 
   {{0x6284193f,0x26c00fb7,0xc39802bf,0xa2b80b7c}},	// [1a730] _stjo, stjo_, икає_, शून्, 
   {{0x225c03f0,0xdce80135,0x00000000,0x00000000}},	//   _shuk_, _wegħ, --, --, 
   {{0xfbbc00fe,0xdce8025c,0x00000000,0x00000000}},	//   _অসমত, _tegħ, --, --, 
   {{0x41549919,0x47d401c8,0x00000000,0x00000000}},	//   овес, _ايگر, --, --, 
   {{0xed4455b4,0x90e51b48,0x03a803e6,0x918403cc}},	//   _آپ_, كسون, _نگاو_, سۇلۇ, 
   {{0x6ec80213,0xf78800a2,0x3e885cf7,0xc3cc01af}},	//   _səba, _ilçä_, айко_, _шөбh, 
   {{0xa5b8498d,0x6284045f,0x6360022e,0x00000000}},	//   _amói, _utjo, mеno, --, 
   {{0xf2d01a4c,0x99807dfd,0x225c008b,0xa5240327}},	//   _קען_, _omiš_, _uhuk_, _ལྟོག_, 
   {{0xee340953,0xec751b49,0x6ec806be,0x00000000}},	//   ўны_, опы_, _vəba, --, 
   {{0xc9a001ec,0xfc280064,0x7c28009d,0x00000000}},	//   _ﺃﺩﺭﻙ_, ржок_, роог_, --, 
   {{0x3950023a,0xddd8033f,0x6ec80213,0x00000000}},	//   _syys_, rmuł, _təba, --, 
   {{0x600c003b,0x00000000,0x00000000,0x00000000}},	//   _sømh, --, --, --, 
   {{0x1cb0031c,0xed4c07d5,0x3ea40fac,0x00000000}},	//   _ཞའི_, _цо_, _hvlt_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x66e11b4a,0xda4801c6,0x35a4004e,0xab24009b}},	//   мора, _гүнж_, жабг, _моша_, 
   {{0xd1e002d3,0x600c022c,0xb9085d99,0xe61401d5}},	//   ናታት_, _dømi, _вниз_, одс_, 
   {{0x64400fb7,0x3f840205,0x00000000,0x00000000}},	// [1a740] čnin, _oflu_, --, --, 
   {{0xa5b8012d,0x00000000,0x00000000,0x00000000}},	//   _omów, --, --, --, 
   {{0x80b80729,0x00000000,0x00000000,0x00000000}},	//   _ইনষ্, --, --, --, 
   {{0x3f840276,0x8e7c0115,0x4b4c008f,0x00000000}},	//   _aflu_, _urĝi, נגאַ, --, 
   {{0xa5b801e1,0x26140316,0x95880006,0x6ab4578b}},	//   _amów, नसरी_, grąž, _अम्र, 
   {{0x7654023a,0xdfcc00e3,0xaad8000d,0x00000000}},	//   llyy, َين_, _बनलक, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6ca44294,0x741400ec,0x80d4012d,0x00000000}},	//   орож, _اوڳا, _मैके, --, 
   {{0x76540108,0xefb80092,0x00000000,0x00000000}},	//   ilyy, ተመው_, --, --, 
   {{0xd1bc001f,0x9c6016ac,0x00000000,0x00000000}},	//   _ደቂቃ_, وهيو, --, --, 
   {{0xa5b803b7,0xca6c022e,0x00000000,0x00000000}},	//   _imóv, аhаr, --, --, 
   {{0x600c0158,0xd1bc0b82,0x00000000,0x00000000}},	//   _rømi, _ደቂቅ_, --, --, 
   {{0x600d1b4b,0x98b91b4c,0x58840209,0xa3a80037}},	//   _sømi, олят_, дыса, _गयल_, 
   {{0xdcf80139,0x00000000,0x00000000,0x00000000}},	//   lbuğ, --, --, --, 
   {{0xdb4c00d6,0x02c810fa,0x00000000,0x00000000}},	//   _цю_, _रहेन, --, --, 
   {{0x3ce800f3,0x00000000,0x00000000,0x00000000}},	//   _šavi_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [1a750] --, --, --, --, 
   {{0x600c3619,0xe6640107,0x00000000,0x00000000}},	//   _tømi, стҳо, --, --, 
   {{0xe2a800db,0x00000000,0x00000000,0x00000000}},	//   شاان_, --, --, --, 
   {{0xa5b800c7,0x2bc8033f,0x2ca51b4d,0x8e200150}},	//   _amóv, ़्ता, _ovod_, шiм_, 
   {{0x3dc802d1,0x00000000,0x00000000,0x00000000}},	//   _ñawi_, --, --, --, 
   {{0x2d840b23,0x7a340153,0x00000000,0x00000000}},	//   _afoe_, mšte, --, --, 
   {{0xd13801e0,0x6454003a,0x81440133,0x00000000}},	//   йхә_, mlxi, _کچان, --, 
   {{0xb3240135,0x918403cc,0xed4c01d3,0x7a340064}},	//   _རྟིང_, _قۇمۇ, گھم_, ošte, 
   {{0x81183667,0x7a343e9d,0x518401c0,0x40941066}},	//   _ужас_, nšte, _цуса, _رلار, 
   {{0x3e7001fa,0x4fc40116,0x00000000,0x00000000}},	//   _tšto_, _يەنە, --, --, 
   {{0xe8b4031c,0x6d5c0115,0xa5b8012d,0xc94800d9}},	//   _བཀུག, _ŝpat, _umów, _עמ_, 
   {{0x7a351b4e,0x6ec800ac,0x00000000,0x00000000}},	//   kšte, _məbl, --, --, 
   {{0x7a340010,0xa3c801bc,0x6f6000cf,0xa5b802d2}},	//   jšte, लभा_, _قۇۇم, _klóf, 
   {{0x7e68000d,0x00000000,0x00000000,0x00000000}},	//   lmep, --, --, --, 
   {{0x644002fb,0x8b8400db,0xa9a40014,0xabf8011a}},	//   čnil, _تەپە_, _کشى۪, _להסר, 
   {{0xe7340276,0x25a8045a,0x00580023,0x00000000}},	//   чес_, _cdcl_, ግብኣና, --, 
   {{0xa5b80248,0x7e6800e4,0x765403ac,0xb0d8012d}},	// [1a760] _olóf, imep, rlyy, _मैंग, 
   {{0x78a40158,0x600c0174,0x7e680112,0x00000000}},	//   mskv, _kømu, hmep, --, 
   {{0xa5b80241,0x248805b1,0xdb0002fb,0x46801c5c}},	//   _amóu, _etcm_, _odní, _ақса, 
   {{0xa5b800e4,0x6ec803e3,0xe45c007c,0x7e680200}},	//   _alóf, _dəbl, _spöt_, jmep, 
   {{0xf7708198,0x2ba50801,0x7e68000d,0x00000000}},	//   _تاک_, nící_, dmep, --, 
   {{0xe1f4016c,0xaf04034b,0x6454003a,0xfa10015b}},	//   оҳӣ_, зчик, clxi, হফিল_, 
   {{0x2bc02017,0xdcf80724,0x2ca40010,0x91c40166}},	//   _शाबा, tbuğ, _svod_, _жәлл, 
   {{0xb2251b4f,0xf1a8451a,0x00000000,0x00000000}},	//   _эмбл, _داسه_, --, --, 
   {{0x2ba402f8,0xdb04025a,0x2ca4003a,0xecf80154}},	//   jící_, _âlên, _qvod_, ইন্স_, 
   {{0x2ba4012c,0xa5b802d2,0x00000000,0x00000000}},	//   dící_, _glóf, --, --, 
   {{0x161c000d,0x7a347edf,0xb9240092,0x00000000}},	//   नसार_, zšte, ደራሴዎ, --, 
   {{0xa5b80789,0x6d40005a,0x600c0174,0x2ca40129}},	//   _ilóg, _txoa, _dømu, _tvod_, 
   {{0x78a46916,0xed5800db,0x7c300010,0xdcac0c71}},	//   gskv, _اشات_, _škrž, _مىن_, 
   {{0x7a346b07,0x00000000,0x00000000,0x00000000}},	//   všte, --, --, --, 
   {{0xa5b8030a,0x661c0240,0xdc7000ee,0x8b6400f1}},	//   _omót, thqk, _ягшы, _ډاډم, 
   {{0x6440151c,0x6ab91b50,0x3e60007f,0x2ba40118}},	//   čnim, mutf, póte_, bící_, 
   {{0x6ab91b51,0xd9440063,0x96440166,0x00000000}},	// [1a770] lutf, _пећи, хэрд, --, 
   {{0x7e680789,0xa5b80cad,0x63680120,0x6280010f}},	//   zmep, _ológ, брег_, ŭnom, 
   {{0x53351b52,0x6ab80158,0x7e680158,0xddc80064}},	//   нефт, nutf, ymep, _ligš, 
   {{0x7a341467,0xdcf801a6,0x00000000,0x00000000}},	//   pšte, zbuđ, --, --, 
   {{0xd174f1c4,0x52751b53,0x9af001e4,0x00000000}},	//   нышы, رامز, _ĉeƭa_, --, 
   {{0x6ab813c4,0x6ec800ac,0x00000000,0x00000000}},	//   kutf, _təbl, --, --, 
   {{0x442005da,0xc2c400ec,0x6ab801e3,0x2ba40118}},	//   mhh_, _تيزي, jutf, zící_, 
   {{0xdef80046,0x6ab8143a,0x442001ab,0x6f5400d1}},	//   _қыз_, dutf, lhh_, بلىز_, 
   {{0x7e68e0de,0x442006ee,0x6d5c010f,0x600c03b2}},	//   rmep, ohh_, _ŝpar, _sømu, 
   {{0x8d29127e,0x9ba0167e,0x6ab8192e,0xa5b80162}},	//   яның_, رەبى, futf, _flóg, 
   {{0xa5b80162,0x600c08cb,0xbf145c14,0x442001ab}},	//   _glóg, _dømt, _تواب, ihh_, 
   {{0xac7c001f,0x2ba40118,0x6d4c002f,0x78a4fcf4}},	//   _የሁሉም_, tící_, ßbac, tskv, 
   {{0x644004b9,0x4420020b,0xfce51b54,0x6e1401f7}},	//   čnij, khh_, _цоло, _زيوس_, 
   {{0x6ab8003c,0x78a42147,0x23cc00dc,0x2ba40332}},	//   butf, rskv, स्मद, rící_, 
   {{0x78a51b55,0xef2c001f,0x3cec03cd,0xa5b80ca8}},	//   sskv, _እንደው, lvev_, _olód, 
   {{0x2b080316,0x4420003e,0x2ba400bc,0x6300015b}},	//   ाहरु_, ehh_, pící_, লনায়_, 
   {{0x64a11b56,0xa5b8056a,0x38680af2,0x7414a0c3}},	// [1a780] ката, _amós, pmbr_, وورا, 
   {{0x44211b57,0x73351b58,0x4964a4c3,0x00000000}},	//   ghh_, ورائ, _яның, --, 
   {{0xf744537c,0xa5b803b2,0x760801d5,0x00000000}},	//   _цено, _blód, _денг_, --, 
   {{0x442006d1,0xa5b800ae,0x00000000,0x00000000}},	//   ahh_, _clód, --, --, 
   {{0x292c001f,0xa5b91b59,0xa3cc0073,0xf04400cf}},	//   _አንደኛ, _slóg, _वॉव_, мэко, 
   {{0xd01032f7,0xa5b81d0e,0x97440092,0x00000000}},	//   طلب_, _plóg, _የስድስ, --, 
   {{0xa2e0ce06,0xa3e42983,0x600c1445,0x1d34001f}},	//   _иорд, _मोट_, _rømt, _እስከመ, 
   {{0xb11405c2,0x6ab800d2,0xb2c80150,0xce5400d1}},	//   _قوزغ, vutf, _ﺖﻴﻓﺍ, رھاب, 
   {{0x2fd8236e,0x6ab8192e,0xef2c001f,0x320400b5}},	//   _وورد_, wutf, _እንዲው, mjoy_, 
   {{0x6ab80175,0xa4f8011a,0xcdc80137,0xdf700e56}},	//   tutf, קליט, تۇچۇ_, رگەب, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3204009f,0x44200165,0xa5b802d2,0x6ab80250}},	//   njoy_, zhh_, _klóe, rutf, 
   {{0x6ab8478a,0x600c3c02,0xe78401f0,0x00000000}},	//   sutf, _tømt, дубо, --, 
   {{0xabb000c7,0x6ab80175,0x00000000,0x00000000}},	//   _ракә, putf, --, --, 
   {{0x3e611b5a,0x45d472e5,0x32040113,0x600c03b2}},	//   lóta_, новс, kjoy_, _kømr, 
   {{0xa5b801e1,0xba28035b,0x76480162,0x00000000}},	//   _amór, _нхыҵ_, _ífyl, --, 
   {{0x65c406c8,0x2724022e,0x3e6000c7,0x41b400e5}},	// [1a790] _nūhō, _mеni_, nóta_, ہمار, 
   {{0x03540184,0x93947092,0x4420003e,0xb6000327}},	//   еүгә_, نجما, uhh_, ġġag, 
   {{0x7a348bbb,0xa5b800ae,0x3e600022,0x00000000}},	//   lšta, _plód, hóta_, --, 
   {{0x44203743,0x929402d5,0xa3cc0412,0x3e611b5b}},	//   shh_, тацц, _वॉर_, kóta_, 
   {{0x7a343466,0x3e6009f3,0x6b88f49d,0x64700124}},	//   nšta, jóta_, _offg, _аҳау, 
   {{0x74980a7c,0x7a340153,0xc0c4013d,0xd9dc134e}},	//   _מישפ, išta, _җәди, _बस्ट, 
   {{0xdb000306,0xe6380092,0xc1d001af,0x41780023}},	//   _odná, _የእናን, _бөлә, _ክጠፍእ_, 
   {{0x7a3402d5,0x6b880042,0x3cec0158,0x21280051}},	//   kšta, _affg, tvev_, _ýcho_, 
   {{0x61f91b5c,0x3dcc9b7d,0x8d840131,0x3e6001d3}},	//   _inul, rfew_, خشىن, góta_, 
   {{0x44300076,0x7a340030,0x3cec03cd,0xdb0000e5}},	//   _jmz_, dšta, rvev_, _adná, 
   {{0x4ea51b5d,0x61f91b5e,0x6d5403d4,0x7a340006}},	//   _арча, _knul, _øyan, ešta, 
   {{0x23cc00dc,0x8ed8007b,0x3e700064,0x4a740139}},	//   स्तद, _تذكر_, _ošti_, кыят, 
   {{0x4430009a,0x825002d3,0x60c804cc,0xa5b80248}},	//   _omz_, _ንኣስታ, ntgm, _olób, 
   {{0xa3cc06ab,0xe61d1b5f,0xebe001b9,0x4430002f}},	//   _वॉल_, _alô_, _бошп, _nmz_, 
   {{0x6ec800ac,0x00000000,0x00000000,0x00000000}},	//   _cəbh, --, --, --, 
   {{0x4430010a,0x85b4026a,0x82ec0327,0xaa540114}},	//   _amz_, кључ, _ལླེའ, _пију_, 
   {{0xb464782f,0x1c1000bc,0x61e8015d,0x754433ea}},	// [1a7a0] екал, _ढकाल_, ddgl, хназ, 
   {{0x61f91b60,0x7bc11b61,0xe45485c0,0x61e8017a}},	//   _anul, nglu, ежу_, edgl, 
   {{0x44303c36,0x35a400a8,0xa798008d,0x00000000}},	//   _dmz_, _панг, _משיח, --, 
   {{0xb144aa6c,0xe2800276,0x229050ea,0x00000000}},	//   ннел, улци, النس, --, 
   {{0x3878d644,0x320401a9,0x9b2800cd,0x00000000}},	//   _kipr_, rjoy_, _vīṇā, --, 
   {{0x7bc0041a,0x61f815df,0x2724022e,0x600c12e8}},	//   jglu, _enul, _sеni_, _sømr, 
   {{0x61f80728,0x6ec803e3,0x00000000,0x00000000}},	//   _fnul, _kəbi, --, --, 
   {{0x11f811c2,0x2bc0033d,0x61f8004e,0x4430005a}},	//   _تورک_, _शाहा, _gnul, _zmz_, 
   {{0x6140e73b,0x224401c7,0x13d40154,0x00000000}},	//   _бета, énke_, _হোয়, --, 
   {{0x09a80490,0x9f4402fb,0x7bc11b62,0x6ec806be}},	//   कण्य, zdné_, gglu, _ləbi, 
   {{0x600c2188,0x7a2408ce,0x3e6000e4,0x00000000}},	//   _tømr, _mótf, sóta_, --, 
   {{0x6448019f,0x7bc00218,0x6da4361c,0xada401c6}},	//   îgiz, aglu, _чида, _чадл, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7a340006,0x6b8802d0,0x3e4400de,0x0ed41bbb}},	//   ršta, _uffg, mēta_, _दहाड, 
   {{0x387801fa,0xc2200abd,0x3e4400e2,0x6ec803b9}},	//   _dipr_, _मतलब_, lēta_, _bəbi, 
   {{0x443000ec,0x7a345c92,0xa5b80162,0x6ec803b9}},	//   _smz_, pšta, _slób, _cəbi, 
   {{0xc4342a60,0xa5b80077,0x9f440030,0x3e4400e2}},	// [1a7b0] نکست, _alóc, rdné_, nēta_, 
   {{0x61f80a87,0x00000000,0x00000000,0x00000000}},	//   _snul, --, --, --, 
   {{0x61f80ac5,0xd1f8001f,0xa5b801e7,0xd9340023}},	//   _pnul, ጋጀት_, _clóc, _ኣስተን, 
   {{0x92b400c6,0x7bc11b63,0x17680ce8,0x00000000}},	//   احلا, zglu, _ярып_, --, 
   {{0xc0e405b2,0xb5c800fe,0x7a2408ce,0x61e801e4}},	//   толк, _লোকচ, _fótf, rdgl, 
   {{0xe054424b,0x4430004b,0x660d1b64,0x7e780042}},	//   ریات_, _umz_, _hock, _siwp, 
   {{0x61f80083,0x5ba00131,0x6d4c002f,0x00000000}},	//   _tnul, ңлиғ, ßban, --, 
   {{0x7bc00218,0x61f8bb7d,0x6ec806be,0x3e4400ef}},	//   wglu, _unul, _xəbi, fēta_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x660d1b65,0x00000000,0x00000000,0x00000000}},	//   _lock, --, --, --, 
   {{0xbb44e80b,0x660c02d0,0xf784013d,0x2bc01cd2}},	//   тенк, _oock, _öçil_, _शारा, 
   {{0x660c167c,0x7a240162,0x8c9401ec,0x69c803e0}},	//   _nock, _mótg, _өрші, _ögel, 
   {{0x4c940323,0xaa405fb7,0x3e4400e2,0x6ec803e3}},	//   _бичс, реял, cēta_, _rəbi, 
   {{0x6ec80213,0x4d640064,0x00000000,0x00000000}},	//   _səbi, _сків, --, --, 
   {{0x660d1b66,0x7a241427,0xdeec010b,0x00000000}},	//   _bock, _rótf, рыx_, --, 
   {{0x6ec800ac,0x660c0d8b,0x4e0400cd,0xa3cc03ce}},	//   _qəbi, _cock, वायै_, व्स_, 
   {{0x387800ca,0x00000000,0x00000000,0x00000000}},	// [1a7c0] _tipr_, --, --, --, 
   {{0xb3743663,0xe3b400db,0xdb0401e1,0x00000000}},	//   نداش, кбу_, _ńlùl, --, 
   {{0x6ec803be,0x660c0731,0x3e4400e2,0xe7b4011a}},	//   _təbi, _fock, zēta_, _בהיר_, 
   {{0x600c01bf,0x660d1b67,0xe2951b68,0x74b80798}},	//   _sømp, _gock, тац_, _оугс_, 
   {{0x0cbc2f04,0xdb00037e,0xa3cc0490,0xc10000d1}},	//   _অন্ত, _udnæ, व्ह_, бүтл, 
   {{0x7a340006,0x660ca5b9,0x3e4400e2,0x7a2408ce}},	//   kšto, _zock, vēta_, _fótg, 
   {{0xaca401d3,0x00000000,0x00000000,0x00000000}},	//   چھتے_, --, --, --, 
   {{0xf1a804d3,0xdef51b69,0x066c0ed1,0x3e4400e2}},	//   _زاره_, тыш_, _ﺳﺎﻟﯩ, tēta_, 
   {{0x62800122,0xe9dc0270,0xa1102162,0x00000000}},	//   ínov, veú_, _پولت, --, 
   {{0x3e44005f,0x2bc00073,0x00000000,0x00000000}},	//   rēta_, _शाळा, --, --, 
   {{0xdee11b6a,0xcfe80154,0x7a340427,0xeb48234c}},	//   _вохи, পাদন, rštn, ьчик_, 
   {{0x5f3405d0,0x889460a9,0x6360022e,0x00000000}},	//   _בטבע_, лимх, mеnt, --, 
   {{0xac091b6b,0x00000000,0x00000000,0x00000000}},	//   _онда_, --, --, --, 
   {{0x660d1b6c,0xd91834d8,0x6e211b6d,0x2d88016b}},	//   _sock, тью_, _hlob, ɛbea_, 
   {{0x6e206041,0xaa651b6e,0x660d1b6f,0xf8ac00f1}},	//   _klob, _итик, _pock, يکی_, 
   {{0xd5b91b70,0x7a24032e,0x00000000,0x00000000}},	//   ксу_, _rótg, --, --, 
   {{0xe6cc012c,0xb4b40131,0xa3a40063,0x286830ab}},	// [1a7d0] _हङकङ, литә, вјек, _ороо_, 
   {{0x6e2000f7,0x7d1c026c,0x6360022e,0x3ce40037}},	//   _llob, ùssi, kеnt, _जईसे_, 
   {{0x6e211b71,0x6ec806be,0x0634119e,0xa2c80022}},	//   _olob, _kəbu, _бенџ, ьуаз_, 
   {{0xa5b808a5,0x636001d5,0x6ab80332,0x00000000}},	//   _flóa, dеnt, irtf, --, 
   {{0x6d4c0730,0x90e400f1,0xa5b8032e,0x6ec803b9}},	//   ßbal, لسون, _glóa, _məbu, 
   {{0x6e203d81,0x3f6917ba,0xe2900d17,0x7a351b72}},	//   _alob, нило_, _نذر_, yšto, 
   {{0x6e211b73,0x7a240008,0x6444022f,0x7e540484}},	//   _blob, _hóte, _ijji, лтиц, 
   {{0x6e211b74,0xdb0020ef,0xa3cc433a,0x69d80254}},	//   _clob, _fenê, व्र_, õuel, 
   {{0xdb011b75,0x00000000,0x00000000,0x00000000}},	//   _genê, --, --, --, 
   {{0x6e201aac,0x60d8014b,0x5ba0036b,0x7a2408a5}},	//   _elob, _ipum, шлоғ, _móte, 
   {{0xe8041533,0x7cfc01a8,0x00000000,0x00000000}},	//   शाना_, færð, --, --, 
   {{0x7a340fda,0xd9100133,0xbcf47660,0xb880013d}},	//   ršto, قیع_, _مستغ, _ğíba, 
   {{0x7a2404d4,0x64441418,0xa3c00490,0x6ab801f5}},	//   _nóte, _ojji, ःला_, artf, 
   {{0x60d86978,0x395c00da,0x6444020c,0x1bc401d9}},	//   _mpum, āts_, _njji, _شُبی_, 
   {{0x3e44005f,0x1b0001ec,0x00000000,0x00000000}},	//   nēto_, _түнн, --, --, 
   {{0x64441418,0x60d91b76,0x7a24004e,0x6ec806be}},	//   _ajji, _opum, _bóte, _gəbu, 
   {{0x30bc015b,0xdb2003b2,0x00000000,0x00000000}},	// [1a7e0] _ইন্স, ðsæd, --, --, 
   {{0xdb00045f,0x99e402fb,0x37e400db,0x6ec803b9}},	//   _renê, čňuj, _соог, _zəbu, 
   {{0xe2940e1f,0x3ce4006d,0x60d91b77,0xb6a400ee}},	//   гах_, _जैसे_, _apum, _щинл, 
   {{0x64451b78,0x6a7c002d,0x3124a654,0x6b78010f}},	//   _ejji, _jūfa, лдег, גרענ, 
   {{0xdb00006a,0xa3cc02ab,0xf65000db,0x2244022a}},	//   _benë, _वॉक_, _نئڭ_, énka_, 
   {{0x6e2000d0,0x249c0166,0x43840354,0x00000000}},	//   _slob, _çuma_, _кăшт, --, 
   {{0x60d80295,0x644807ea,0x644023cc,0x7a2403f2}},	//   _epum, égie, čnit, _mótb, 
   {{0x6e2000ac,0x6ab80118,0x8e1400f3,0x14d801f9}},	//   _qlob, vrtf, рдиц, _डहाण, 
   {{0x9980010e,0xa5b80241,0xe80400bc,0xb1440114}},	//   _iniň_, _olón, शामा_, _снал, 
   {{0xdb011b79,0x6ab80427,0x6ec803b9,0x76540205}},	//   _kenè, trtf, _səbu, hoyy, 
   {{0xe45400c8,0xdb0002bd,0xdce80790,0x3e4400e2}},	//   רייט_, _jenè, _degı, cēto_, 
   {{0x6ec80cc1,0xfbe02aab,0x6e200a42,0xdb0035a5}},	//   _qəbu, বাগত, _ulob, _menè, 
   {{0xddd84a4a,0x5a34234c,0x00000000,0x00000000}},	//   lmuş, снят, --, --, 
   {{0x9f44012c,0xa5b800ae,0x7d1c383d,0x7a251b7a}},	//   zdní_, _clón, øsse, _róte, 
   {{0xddd807b3,0xfd4c01f2,0x5bc00a52,0x998000a2}},	//   nmuş, kshọ, _اقىل, _oniň_, 
   {{0x6ec803be,0x7654102c,0x624000df,0xd2440133}},	//   _həbs, goyy, aĵoj, _رۆ_, 
   {{0x7a2409cc,0x3e4400e2,0x28a401b9,0xa5b802d2}},	// [1a7f0] _fótb, zēto_, _ёшиг, _flón, 
   {{0x7e9000b0,0x47342f59,0xdb0067c1,0xa5b80332}},	//   _hāpe, _внос, _benè, _glón, 
   {{0x7e9004fe,0x60d91b7b,0x7654011f,0x27e00135}},	//   _kāpe, _spum, boyy, mejn_, 
   {{0x60d8031c,0x27e00175,0x26c001e4,0x40951b7c}},	//   _ppum, lejn_, mujo_, аркт, 
   {{0x7e900374,0x9f44012c,0x606003cc,0x26c11b7d}},	//   _māpe, rdní_, مۇرل, lujo_, 
   {{0xdb011b7e,0x62800122,0x6444464e,0x66c8510c}},	//   _fenè, ínos, _ujji, _gökç, 
   {{0xdb011b7f,0x64551b80,0x26c11b81,0x92940006}},	//   _genè, moxi, nujo_, _гасц, 
   {{0x64551b82,0x2e380421,0x3e44005f,0x63a51b83}},	//   loxi, tūfa_, rēto_, _hejn, 
   {{0x10d8fc3b,0x60d91b84,0x62840810,0x80780124}},	//   _مبلغ_, _upum, _hujo, _абас_, 
   {{0x62843c2c,0x64551b85,0xfc305085,0x63a40009}},	//   _kujo, noxi, تحب_, _jejn, 
   {{0x63a51b86,0x628435f5,0x25f805dc,0x765403f9}},	//   _mejn, _jujo, _लोभी_, yoyy, 
   {{0x26c11b87,0xc86806a9,0x64541cdf,0x63a51b88}},	//   dujo_, _חן_, hoxi, _lejn, 
   {{0xeb8c2830,0x62851b89,0xfc0411ed,0xdb005f6f}},	//   _ми_, _lujo, _впло, _mené, 
   {{0x63a40316,0x6284017a,0x7d08009a,0x26c11b8a}},	//   _nejn, _oujo, mxes, fujo_, 
   {{0x62851b8b,0xa7a421d0,0xe7340120,0x26c00115}},	//   _nujo, ркса_, аер_, gujo_, 
   {{0xdb011b8c,0xfc7c00bc,0xcc880051,0x00000000}},	//   _renè, řádá_, _uớc_, --, 
  
   {{0x62843a6d,0x63a51b8d,0x7d080077,0xdb00fc7b}},	// [1a800] _aujo, _bejn, nxes, _senè, 
   {{0x26c11b8e,0x64540005,0xa5b800d2,0x13a804d3}},	//   bujo_, goxi, _hlól, انای_, 
   {{0x63a40218,0x67b80302,0x62840120,0x7e9000b8}},	//   _dejn, _במיק, _cujo, _yāpe, 
   {{0xdb011b8f,0x62851b90,0x62606ee2,0x00000000}},	//   _venè, _dujo, овха, --, 
   {{0x644800d8,0x00000000,0x00000000,0x00000000}},	//   égic, --, --, --, 
   {{0xe040343e,0x6d4c0365,0x63a4031c,0xdb001f3f}},	//   ончи, şbak, _gejn, _tenè, 
   {{0x72780131,0xcfa40116,0xa5b80241,0xee900133}},	//   _асас_, ашқи, _olól, زگاک, 
   {{0xddd809a5,0x2d801700,0xe36002bf,0xc18001ed}},	//   rmuş, øke_, _єкти, _ٹیوٹ, 
   {{0x7e9002b1,0x6ec80213,0x26c001e4,0xec6801a9}},	//   _rāpe, _cəbr, zujo_, крок_, 
   {{0xdb0001ed,0x7e9048e1,0x0ed800e5,0x27e00135}},	//   _zené, _sāpe, _ماؤں_, xejn_, 
   {{0xceb80952,0x6284058a,0x7e9000cd,0xdfcc01c8}},	//   _сәл_, _xujo, _pāpe, _آيم_, 
   {{0xdd8c7ff6,0xdb00172e,0x6cd40d28,0x2bc0185b}},	//   _قوم_, _xené, _نقصا, _शाका, 
   {{0x3ea80989,0x940c03be,0x27e11b91,0x7e900055}},	//   ćate_, şlər_, tejn_, _vāpe, 
   {{0x26c000c8,0x64542798,0x5c5000ec,0x5ba002e8}},	//   tujo_, xoxi, _وضوء, _дръз, 
   {{0x63a51b92,0x7e903b28,0x645401d5,0x27e11b93}},	//   _rejn, _tāpe, voxi, rejn_, 
   {{0x27e11b94,0x63a424e7,0x26c0010f,0x62840064}},	//   sejn_, _sejn, rujo_, _rujo, 
   {{0x62851b95,0x63a401e4,0x1cd80327,0x26c0010f}},	// [1a810] _sujo, _pejn, རཆག_, sujo_, 
   {{0x62851b96,0x68280732,0xdb011b97,0x26c001e4}},	//   _pujo, _südf, _sené, pujo_, 
   {{0xd87411dc,0x2d8001f1,0x63a4b263,0x7a2443e5}},	//   _بايب, ľkej_, _vejn, _hóta, 
   {{0x92690934,0x62840063,0x6454c5eb,0x2d800306}},	//   арча_, _vujo, soxi, žkej_, 
   {{0xdb001e0b,0x14f402d5,0x64540f85,0x63a40200}},	//   _vené, _дзяў, poxi, _tejn, 
   {{0x7a251b98,0x62851b99,0x3e6005f7,0xa3cc02ab}},	//   _móta, _tujo, móti_, _वॉच_, 
   {{0x6fb0340c,0xdb0004cf,0x324004d3,0x6ec80213}},	//   سميا, _tené, _کۆنف, _səbr, 
   {{0xf2d006a9,0x44200113,0xa538001f,0xa5b80ca8}},	//   _מעל_, lkh_, _በመንቀ, _olóm, 
   {{0x7a251b9a,0x2bc0190c,0xbc191b9b,0x8644001f}},	//   _nóta, _शाखा, гіні_, _የእንስ, 
   {{0x442000d2,0x7d091b9c,0xa15401ec,0xed4d1b9d}},	//   nkh_, rxes, _бағу_, رھن_, 
   {{0xdce46f30,0x44211b9e,0x68280cc1,0xed5424d5}},	//   ımız, ikh_, _müdd, _қош_, 
   {{0x6ec803be,0xa5b809f3,0x4420003e,0x7a251b9f}},	//   _təbr, _blóm, hkh_, _bóta, 
   {{0x7a34abea,0xa5b80332,0xcc88004d,0x7a2401e7}},	//   nšti, _clóm, _hớn_, _cóta, 
   {{0xd26400e2,0x7a241a70,0x4420036e,0x7a340153}},	//   miņš_, _dóta, jkh_, išti, 
   {{0xd264005f,0x6ec800dc,0xe72518b0,0xd7700092}},	//   liņš_, संयु, борд_, _በስቲያ_, 
   {{0x44201990,0x7a340006,0x7a251ba0,0x00000000}},	//   ekh_, kšti, _fóta, --, 
   {{0xcc8801dc,0xa5051ba1,0xb8c42309,0xd26400e2}},	// [1a820] _lớn_, бета_, _ازعى, niņš_, 
   {{0xb9f41b49,0x9f4402fb,0x00000000,0x00000000}},	//   _ምሳ_, zdná_, --, --, 
   {{0x6448f85a,0x6d5405ac,0x6828002f,0x7a340419}},	//   égia, _øyav, _südg, ešti, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7a340024,0xe690004b,0xa5b80248,0x00000000}},	//   gšti, _ولید, _olój, --, 
   {{0x44200072,0xd26400e2,0x682806be,0xb6400220}},	//   ckh_, diņš_, _güdd, _ﺃﻡ_, 
   {{0xe29407b5,0x3ea40142,0x00000000,0x00000000}},	//   _гас_, _cwlt_, --, --, 
   {{0xa5b801e1,0x6ec80882,0xc32c2002,0x3f84005a}},	//   _alój, संबु, _جەم_, _eglu_, 
   {{0x65bc0241,0x9f4400d0,0x5ed800cc,0x308400f2}},	//   _hàhà, rdná_, ভিষে, _طلاف, 
   {{0x60211ba2,0x7d1d1ba3,0x68280254,0x7a2409e8}},	//   _едуа, øssa, _küde, _róta, 
   {{0x7a246428,0x68280036,0xf40401ec,0x00000000}},	//   _sóta, _jüde, рлiк_, --, 
   {{0x682805d5,0xa5b802d2,0x2ca800c0,0xd26400de}},	//   _müde, _plóm, _бкдп_, biņš_, 
   {{0x7e900069,0x44211ba4,0x68280112,0xacf400f1}},	//   _iāpa, ykh_, _lüde, _دسات, 
   {{0x7e901e2b,0x7a251ba5,0x1ae40154,0xcac8010a}},	//   _hāpa, _vóta, _ওপরে_, _кӳме_, 
   {{0x6fd81533,0x7e911ba6,0xdc3800c8,0x3a2005b1}},	//   प्यू, _kāpa, _געגר, bkkp_, 
   {{0x7a24043b,0x7e900f40,0x68291ba7,0xdcf803e0}},	//   _tóta, _jāpa, _südd, ncuğ, 
   {{0x84151ba8,0xa5b800d2,0xf8b405f5,0x7e900340}},	// [1a830] омах, _hlók, _мөр_, _māpa, 
   {{0x7a340b9b,0xfa8801fb,0xa5b80bcd,0xb93c0092}},	//   všti, _mẫn_, _klók, _ካድሬዎ, 
   {{0xfa88001e,0xc0c802d3,0xd26400e2,0x00000000}},	//   _lẫn_, በገሰ_, ziņš_, --, 
   {{0x2d84052f,0xa5041cb8,0x1fb007f7,0x68280205}},	//   _ngoe_, _лягл, ील्ड, _düde, 
   {{0x7a3405ce,0xc1749c96,0x6ec400bc,0x00000000}},	//   ušti, زگرت, रूसँ, --, 
   {{0x7a340006,0x1b0c00cc,0x3e4400e2,0xd26400e2}},	//   ršti, ানতে_, mēti_, viņš_, 
   {{0xa49801c3,0x68291ba9,0x2ca40009,0xe654001f}},	//   _bròg, _güde, _awod_, _ለእናን, 
   {{0x7a340bb8,0x7e9000dc,0xd26400e2,0x850c06e3}},	//   pšti, _cāpa, tiņš_, _सपाट_, 
   {{0xa498068c,0x814401ed,0x3e4400e2,0x7e90002b}},	//   _dròg, _بچان, nēti_, _dāpa, 
   {{0xfa8801dc,0x010405d9,0xa498004e,0xd264005f}},	//   _dẫn_, _هڪڙو_, _tròf, riņš_, 
   {{0x6d080156,0xcd28036b,0x3d951baa,0xaaa4000d}},	//   གདཔེ_, لسین_, _диер, _कौआक, 
   {{0x24800d27,0x2ca402e2,0x8d740cbe,0xcc08237e}},	//   _lijm_, _fwod_, _کاما, _ۇزىن_, 
   {{0x38640200,0xa5b801e1,0xc0d40092,0x00000000}},	//   _ëork_, _umóy, ከብሩ_, --, 
   {{0x25a807de,0xfaa42081,0xa5b80008,0xf9e8015b}},	//   _aecl_, _дако, _flók, গাইল_, 
   {{0x0c040014,0xa5b802d2,0xdb0008a5,0x7e90002b}},	//   _روٹُ, _glók, _kení, _yāpa, 
   {{0xba740c71,0x68280e78,0x6d4801a6,0x29d002dd}},	//   _باتت, _rüde, šmaš, _قيىس, 
   {{0x6829113c,0x6820063f,0x39351bab,0x25a80356}},	// [1a840] _süde, _ọdek, _фэйс, _decl_, 
   {{0x225d1bac,0x73991bad,0x7a2402f0,0xdb008f63}},	//   _akuk_, ртас_, _kóto, _lení, 
   {{0xdb04006a,0x36682766,0xa5b80241,0x24800200}},	//   _âlän, _вано_, _olóh, _dijm_, 
   {{0x25a801ab,0x7a240008,0x00000000,0x00000000}},	//   _gecl_, _móto, --, --, 
   {{0xe0cd1bae,0xa49800a3,0x7e900374,0x3dc80113}},	//   نزو_, _cròd, _rāpa, _ñawy_, 
   {{0xa5b80022,0x682801b8,0x7e911baf,0x2364031c}},	//   _alóh, _tüde, _sāpa, żnja_, 
   {{0xdb002cf4,0x7e911bb0,0xa4991bb1,0x7a2401e1}},	//   _bení, _pāpa, _eròd, _nóto, 
   {{0xdb00012c,0x41d00073,0x00000000,0x00000000}},	//   _cení, _हायस, --, --, 
   {{0xdb000316,0xecf80f22,0xa5b80162,0xc0d401f3}},	//   _dení, েন্স_, _slók, ከብር_, 
   {{0xfa8807ae,0x7a2402ea,0xdb000ffb,0x7050105d}},	//   _vẫn_, _bóto, _tenì, _تۆتا, 
   {{0x7e9065d4,0xdb00004e,0x3e4400e2,0xfff40133}},	//   _tāpa, _fení, zēti_, _رکوت_, 
   {{0x2d900ab7,0xed591bb2,0x7a351bb3,0xdb0000cf}},	//   _üye_, _кое_, kštu, _gení, 
   {{0xe80407af,0x25a80356,0x770800fe,0x00000000}},	//   शाला_, _recl_, _ৱেলছ_, --, 
   {{0x7a2403b2,0x68280112,0x3e4400de,0x6d4c002f}},	//   _fóto, _südb, vēti_, ßbau, 
   {{0x569438a9,0x248001f5,0x6fd00764,0xcc880051}},	//   даст, _rijm_, _सानं, _mớm_, 
   {{0x682803be,0x6d540158,0x27f00009,0x3e4400e2}},	//   _büdc, _øyas, _waxn_, tēti_, 
   {{0xe7843461,0x64484738,0x7e90002b,0x7a2408ce}},	// [1a850] _муно, égio, _nāpn, _mótl, 
   {{0x3c2800d2,0x2efc0ffb,0x3e44005f,0x25f802e5}},	//   _kúva_, _ortf_, rēti_, _लोरी_, 
   {{0x57180064,0x00000000,0x00000000,0x00000000}},	//   _джэя_, --, --, --, 
   {{0xa4991bb4,0x78b400c7,0x225c0240,0xe7f0012c}},	//   _aròe, _yvyv, _qkuk_, इएका_, 
   {{0xd1740daf,0x248001a4,0x7e9000b8,0x00000000}},	//   мышы, _tijm_, _cāpn, --, 
   {{0x656c07d6,0x3c28035b,0xcc880208,0x44ec25ad}},	//   _izch, _oúva_, _cớm_, _iž_, 
   {{0xdb000316,0x44ec7dfd,0xb860001f,0xa5b80332}},	//   _pení, _hž_, ደረጃው_, _alói, 
   {{0x92580364,0x3e6009cc,0x44ec3aba,0x31a0022e}},	//   _даст_, jótt_, _kž_, _gаz_, 
   {{0xdb00db52,0xa5b8007b,0x44ed1bb5,0x6b94010b}},	//   _vení, _clói, _jž_, _şyga, 
   {{0x1fa506e4,0xbb6800b5,0x44ec01a6,0xcc88004d}},	//   _фраг, _apuは_, _mž_, _gớm_, 
   {{0xdb011bb6,0x98b02d2b,0x83dc033f,0x7a2408ce}},	//   _tení, đača_, न्यआ, _fótl, 
   {{0x7e900374,0x3c2894d5,0x656c01d5,0x38c0032e}},	//   _hāpo, _dúva_, _ozch, _nærð_, 
   {{0xed4d1bb7,0x7870037e,0xa5b85e4f,0x6fd010eb}},	//   _чо_, hæve, _glói, _सामं, 
   {{0xfe78012c,0xdb0000d8,0xe9340023,0xe7f0033f}},	//   lmů_, _venâ, _ኣትሒዞ, इएगा_, 
   {{0x44ec0745,0x91cc0316,0x7e9002b5,0xabbc4da8}},	//   _až_, _हालै, _māpo, _ﻣﯘﻧﺎ, 
   {{0x7e900618,0x3dcc06a3,0x75d400b3,0xded40023}},	//   _lāpo, ngew_, ثيرا, _ኮነን_, 
   {{0xa3fc00bc,0xa50423c5,0xfa880208,0xe8380118}},	// [1a860] _řeší_, пета_, _mẫm_, řeší, 
   {{0x44ed1bb8,0xdec81e38,0x7a242833,0x1bf012eb}},	//   _dž_, በረን_, _mótm, _असफल_, 
   {{0xa49801ab,0x656c0076,0x38c001a8,0x64a000d1}},	//   _cròb, _ezch, _færð_, _җаса, 
   {{0xcc880016,0xfe78012c,0xa49808c2,0xdb00004e}},	//   _sớm_, jmů_, _dròb, _menà, 
   {{0xa5b80241,0xdb0000db,0x059401b9,0xa1806733}},	//   _alów, _lenà, _تاپگ, нышл, 
   {{0x7e9000b8,0xd7dc1fe7,0xe2a00051,0x00000000}},	//   _cāpo, यभिच, _khứ_, --, 
   {{0xb8cc025c,0x8f340276,0xa5b8007b,0x71a51480}},	//   _ཕས_, ьекц, _slói, _навз, 
   {{0x68291bb9,0x3c2800e4,0x3dcc031c,0x00000000}},	//   _müda, _rúva_, ggew_, --, 
   {{0xb12402e3,0xfa88004d,0x9f80013d,0x00000000}},	//   ọọdụ_, _dẫm_, мгәд, --, 
   {{0x3e4400e2,0x00000000,0x00000000,0x00000000}},	//   dētu_, --, --, --, 
   {{0x28ac1533,0x6a7c0270,0x7e900171,0x00000000}},	//   जीनि, _hūfi, _jāpl, --, 
   {{0xdb0006ed,0xfa880208,0x7a2402d2,0x00000000}},	//   _senã, _gẫm_, _fótm, --, 
   {{0x3e600436,0xa5b803b2,0x9980892f,0x00000000}},	//   rótt_, _klóv, _pliš_, --, 
   {{0x68280793,0x3c280124,0x44ec0010,0x5fdc00cd}},	//   _büda, _túva_, _rž_, प्पल, 
   {{0x45d4d093,0x44ec09a8,0xe2a0004d,0x9f44036e}},	//   мовс, _sž_, _chứ_, venë_, 
   {{0xb8600201,0xade006ab,0x3e44005f,0x59d402a0}},	//   ደረገው_, _कॉमन_, bētu_, _थायर, 
   {{0x69ccaf97,0x3e4400e2,0xd55400a7,0x19bc011a}},	// [1a870] mgce, cētu_, ектъ, _המחב, 
   {{0xa49912c4,0x44ece13c,0x656c02f0,0x7870005c}},	//   _pròb, _vž_, _vzch, tæve, 
   {{0x41d0068f,0x682807de,0x7e911bba,0x9f440023}},	//   _हादस, _güda, _rāpo, renë_, 
   {{0x69cc1928,0x6fd802ab,0x656c009f,0x7870005c}},	//   ngce, प्सू, _tzch, ræve, 
   {{0x44ecb976,0x7e900374,0x69cc01ab,0xdb000419}},	//   _už_, _pāpo, igce, _mená, 
   {{0x44240f7b,0x23c06a08,0x9f451bbb,0x7a3401a2}},	//   _ôl_, _déjà_, lené_, nštr, 
   {{0x3e4400e2,0x622001ec,0x7e900055,0x00000000}},	//   zētu_, _كوسە, _vāpo, --, 
   {{0xdb011bbc,0x9f4401f1,0x7e9000b0,0x00000000}},	//   _nená, nené_, _wāpo, --, 
   {{0x61e91bbd,0x0d080220,0x7e900374,0xa5b806ea}},	//   megl, здық_, _tāpo, _flóv, 
   {{0x61e91bbe,0x60c822d0,0x6aa80042,0x3e4400e2}},	//   legl, mugm, _bwff, vētu_, 
   {{0x60c81c06,0xdb000122,0x6aa80042,0x9f440066}},	//   lugm, _bená, _cwff, kené_, 
   {{0xdb000d14,0x9f451bbf,0x80d00037,0x00000000}},	//   _cená, jené_, _समाइ, --, 
   {{0x9f440038,0x6828260b,0x60c8089c,0x6d5405ac}},	//   dené_, _süda, nugm, _øyap, 
   {{0x3e440029,0x7e691bc0,0x61e91bc1,0x6d78011a}},	//   rētu_, llep, hegl, _ואנח, 
   {{0x0b880592,0x6aa80142,0x61e8613e,0xefb80092}},	//   _عضوي_, _gwff, kegl, ሰኘዉ_, 
   {{0x9f441f5d,0x61e80158,0x7e685ab3,0x7a240162}},	//   gené_, jegl, nlep, _mótk, 
   {{0x7e680270,0x3c280022,0x3e4400e2,0x9f440100}},	// [1a880] ilep, _júvo_, lēts_, senè_, 
   {{0x60c8089c,0x46800046,0x7e691bc2,0xe2a001fb}},	//   dugm, _ұқса, hlep, _thứ_, 
   {{0x9f4403c6,0x61e91bc3,0xa498180f,0x7e6876e0}},	//   bené_, fegl, _pròc, klep, 
   {{0x7e683f9d,0x61e91bc4,0xb1451bc5,0x9f44012c}},	//   jlep, gegl, мнел, cené_, 
   {{0x60c8c643,0x7e691bc6,0x00000000,0x00000000}},	//   gugm, dlep, --, --, 
   {{0x7e691bc7,0xaf04023a,0xc7640220,0xb64801ec}},	//   elep, дчик, _تاۋى, _ﻋﻰ_, 
   {{0x61e91bc8,0x6d380020,0xc600045e,0xdee0026a}},	//   begl, _ኢንፎር, _একতা_, воји, 
   {{0x7e691bc9,0xa64400b7,0xcc88004d,0x3e4400e2}},	//   glep, _ፕሬዚደ, _hới_, dēts_, 
   {{0x1b18015b,0x2d811bca,0xdb0003da,0x60c80175}},	//   _ফেলে_, äke_, _rená, cugm, 
   {{0x9f440e96,0xdb000122,0x8d74004b,0xb9240248}},	//   zené_, _sená, واښا, _wiwọ_, 
   {{0xcc88431d,0x7e680c8c,0xefb8001f,0xdb007247}},	//   _mới_, blep, ሰኘው_, _pená, 
   {{0xdcac049e,0x7e691bcb,0xcc880051,0x6fd8012d}},	//   _چىن_, clep, _lới_, प्रू, 
   {{0x9f446b07,0x69cc01a4,0x6ec803b9,0xdcac0228}},	//   vené_, rgce, _nəbz, _نىن_, 
   {{0x61e8006d,0x9f440214,0xfca801c8,0x3e4400de}},	//   zegl, wené_, _راهو_, bēts_, 
   {{0x9f451bcc,0x3e44005f,0xcc88004d,0x96f8836f}},	//   tené_, cēts_, _nới_, мерт_, 
   {{0xdb0000b5,0x00000000,0x00000000,0x00000000}},	//   _benæ, --, --, --, 
   {{0x9f4401a2,0x61e91bcd,0xd6840116,0x98c4009d}},	// [1a890] rené_, vegl, турп, _исэл, 
   {{0x7e691bce,0x9f451bcf,0x61e817da,0xcc88004d}},	//   zlep, sené_, wegl, _bới_, 
   {{0x9f442195,0x7a2400c6,0xa5b809e8,0x7e9000dc}},	//   pené_, _bóth, _blót, _pāpm, 
   {{0x4154035b,0x60c82c53,0x60600075,0xc0cc001f}},	//   нвес, tugm, چۇرل, _ባህር_, 
   {{0x3e44005f,0x7534033f,0x7a24007b,0xdec80023}},	//   zēts_, czyz, _dóth, በየን_, 
   {{0x61e91bd0,0x682804cc,0x60c91bd1,0x624001e4}},	//   segl, _müdo, rugm, aĵop, 
   {{0x7e691bd2,0x61e91bd3,0xa5b80ad9,0xcc880051}},	//   tlep, pegl, _flót, _gới_, 
   {{0x7e68000f,0x3e4400e2,0xa5b800ae,0xfe082e05}},	//   ulep, vēts_, _glót, वाइस_, 
   {{0x7e682831,0xdfd806bb,0xcc880208,0x00000000}},	//   rlep, _мъж_, _zới_, --, 
   {{0x7e691bd4,0xa5b801a8,0x3e4400e2,0xdb000139}},	//   slep, _klós, tēts_, _jenç, 
   {{0x7e6814dc,0xdb011bd5,0xfcb8001f,0xcc880208}},	//   plep, _menç, ዲወጡ_, _xới_, 
   {{0xc8680302,0xdb0097e2,0xaca0001f,0x3e44005f}},	//   _הן_, _lenç, _ለሁሉም_, rēts_, 
   {{0xfce410f5,0xdcf8003d,0xac7c001f,0xccf402dd}},	//   _чоло, bbuġ, _ከሁሉም_, _ақы_, 
   {{0x8d7403e6,0x7a240321,0xdb00005c,0xa5b80241}},	//   _شانا, _móti, _renæ, _olós, 
   {{0x66e11bd6,0x6ec806be,0x7e9000de,0x00000000}},	//   лора, _səbz, _sāpj, --, 
   {{0x13a800dc,0xe614005a,0xdcf80139,0x00000000}},	//   गर्भ, ндс_, lauı, --, 
   {{0xdb000120,0xe8040e49,0x1bf00490,0x2bb417cb}},	// [1a8a0] _benç, शाखा_, _असाल_, _आजमा, 
   {{0x9f44006a,0x75340210,0x00000000,0x00000000}},	//   venî_, rzyz, --, --, 
   {{0xf2a51bd7,0xa5b8fc37,0x7ae40432,0x0bac0150}},	//   хиеп, _clós, _ähtd, _ﺳﯘﻳﺮ, 
   {{0xcc88431d,0x7a24082c,0x63a00598,0x6a7c0270}},	//   _với_, _bóti, ınna, _fūfu, 
   {{0xfcb8001f,0xf770015e,0x00000000,0x00000000}},	//   ዲወጣ_, _جاک_, --, --, 
   {{0xcc8801dc,0xdb00a493,0xeea80228,0x7a2408a5}},	//   _tới_, _genç, птик_, _dóti, 
   {{0x2bb4012c,0xa5b808a5,0x7a241de4,0x00000000}},	//   _आजबा, _glós, _tóth, --, 
   {{0x6fd034ef,0xdb00013d,0x7a240aab,0x224404e6}},	//   _सावं, _menä, _fóti, énkt_, 
   {{0xa5b912ec,0xa49801ab,0x9f4405d5,0x00000000}},	//   _klór, _lròn, lenì_, --, 
   {{0x7d1c01e6,0x29040010,0x1ae400cc,0x00000000}},	//   ässa, _čna_, _ওপজে_, --, 
   {{0x29040325,0x68291bd8,0xdb00023a,0xada4020f}},	//   _ōna_, _südo, _nenä, _заел, 
   {{0xc5e403d4,0x88940139,0x00000000,0x00000000}},	//   _পোনপ, кимх, --, --, 
   {{0xdca000d6,0xa5b8110e,0x00000000,0x00000000}},	//   _бачи, _olór, --, --, 
   {{0xdb010fd0,0xa49808c2,0x00000000,0x00000000}},	//   _benä, _bròn, --, --, 
   {{0xa4991bd9,0x41d0012c,0xdce800e2,0xdb00294f}},	//   _cròn, _हालस, _izgā, _renç, 
   {{0xa5b80241,0x6ab80728,0xdb0000a2,0x787006ea}},	//   _alór, mstf, _senç, ræva, 
   {{0xa5b802d2,0xdb0003e0,0xb4b40166,0x00000000}},	// [1a8b0] _blór, _penç, китә, --, 
   {{0xa498068c,0x73c001e0,0xa5b80332,0x7a2403f2}},	//   _fròn, иәсе, _clór, _róti, 
   {{0xdb011bda,0xdec80023,0x00000000,0x00000000}},	//   _venç, በየና_, --, --, 
   {{0x7870037e,0xb6b80375,0x626400db,0xd3700214}},	//   nævn, _קצרי, رااق, حهٔ_, 
   {{0xa5b91bdb,0xdb00067c,0x68280139,0xa088013d}},	//   _flór, _tenç, _lüdm, чсез_, 
   {{0x6ab85b47,0x7e9002b1,0xa5b91bdc,0xdb011bdd}},	//   kstf, _hāpi, _glór, _henå, 
   {{0xf454008d,0x7e911bde,0xe638001f,0xe7f802dd}},	//   _יישר_, _kāpi, _ከእናን, _ءﺍﻥ_, 
   {{0x7a240085,0x7e900f40,0x68291bdf,0x63b4002e}},	//   _tóti, _jāpi, _südl, laxn, 
   {{0x9f451be0,0x61f80607,0x7e911be1,0x6cd03997}},	//   mení_, _iaul, _māpi, لقيا, 
   {{0x61f91be2,0x6b98074d,0x9f44038e,0x7e9072dc}},	//   _haul, gctg, lení_, _lāpi, 
   {{0x61f91be3,0xbf151be4,0x7a240436,0x80d000af}},	//   _kaul, _جواب, _mótv, _समुं, 
   {{0x61f91be5,0x9f4401f1,0x7d781037,0x8f440212}},	//   _jaul, není_, _قمار_, _схуд, 
   {{0x6ab83b08,0xdb011be6,0x60d8031c,0x55c401ec}},	//   astf, _senä, _jqum, ғазғ, 
   {{0x6b98074d,0xdb00014a,0x9f440270,0x7a2403b2}},	//   cctg, _penä, hení_, _nótv, 
   {{0xdb004bc1,0x52d000c5,0x63b40067,0x682803b9}},	//   _benå, _हमेस, daxn, _güdm, 
   {{0x9f44031d,0xdb00049b,0x60d80140,0x7d0ca37d}},	//   jení_, _venä, _oqum, _àass, 
   {{0x9f4403c6,0x60d91be7,0x44311be8,0xb46491ec}},	// [1a8c0] dení_, _nqum, _blz_, вкал, 
   {{0xa4991be9,0x7998013f,0x63b40009,0x73c400db}},	//   _tròn, ɛtwa, gaxn, ئيام, 
   {{0x61f91bea,0x60d802d1,0x160002ab,0x1b0c0154}},	//   _baul, _aqum, _लोअर_, ানকে_, 
   {{0xdb0000b5,0x28ac146b,0xcc88004d,0x61f80e21}},	//   _genå, जीवि, _hớt_, _caul, 
   {{0x61f91beb,0x443000ca,0x63b401d9,0x6294022f}},	//   _daul, _flz_, baxn, aqxo, 
   {{0x61f8005a,0x6ab91bec,0x205001e0,0x00000000}},	//   _eaul, ystf, ҫтәр, --, 
   {{0x60d80472,0xe29405f5,0x9f4402fd,0x6828008e}},	//   _equm, _аас_, bení_, _büdj, 
   {{0x9f44038e,0x6024007f,0x7e780042,0xe2941d39}},	//   cení_, _pèmê, _chwp, _јат_, 
   {{0x6b98074d,0x70840124,0x716400c6,0x2bc82766}},	//   tctg, _агаз, _شارك, муно_, 
   {{0xfa8807ae,0x3a3009a5,0x61f8055a,0xe9dd1bed}},	//   _mẫu_, _alyp_, _zaul, giún_, 
   {{0x61f91bee,0x787000b5,0xa5b80241,0x52e000bc}},	//   _yaul, tævn, _olóp, _नहोस, 
   {{0x6cc51bef,0x4aa80372,0x236400ee,0x6da4dd6b}},	//   _айда, мкүн_, ünji_, _рида, 
   {{0xa498067c,0xcc88001e,0x7e9002b1,0x38780055}},	//   _cròl, _bớt_, _rāpi, _bhpr_, 
   {{0x9f44038e,0xa498068c,0x7e900171,0xdce800de}},	//   zení_, _dròl, _sāpi, _uzgā, 
   {{0x3a300194,0x443000d8,0x387800cd,0x7e9000cd}},	//   _flyp_, _rlz_, _dhpr_, _pāpi, 
   {{0x7a2408a5,0x9a84013d,0x443001ef,0x298800f3}},	//   _bótu, _куыл, _slz_, _оспо_, 
   {{0x61f80472,0x9f44038e,0x3ea804b9,0xc3c405f5}},	// [1a8d0] _raul, vení_, ćati_, лөвл, 
   {{0x61f91bf0,0xfa8801fb,0x20d80022,0x684002f2}},	//   _saul, _dẫu_, vêi_, _ئێسل, 
   {{0x7e900053,0x9f451bf1,0xdb00168c,0x45d401e0}},	//   _tāpi, tení_, _tenå, _йонс, 
   {{0x61f80a2e,0xd3791bf2,0x7a240321,0xa5b802d2}},	//   _qaul, тчу_, _fótu, _glóp, 
   {{0x9f4401f1,0x660c0cf4,0xfa8801fb,0xb3d40116}},	//   rení_, _inck, _gẫu_, _әйсә, 
   {{0x61f91bf3,0x7a24022c,0x9f4402fd,0xbd0400d7}},	//   _waul, _hótt, sení_, ntéš, 
   {{0x61f91bf4,0x9f44031d,0x229402d3,0x13691bf5}},	//   _taul, pení_, _uçk_, _ашти_, 
   {{0x61f807de,0xcf2400d1,0xdb040bcd,0x7d1c01e3}},	//   _uaul, شرىي, ðlík, ässo, 
   {{0x7a2408a7,0x3c641955,0x60d8009a,0x41541a5c}},	//   _mótt, лкиг, _uqum, _свас, 
   {{0x3a300ea0,0x5ee800cc,0xade00037,0x00000000}},	//   _slyp_, কিবও_, _कउअन_, --, 
   {{0xcc8801fb,0xa49801ab,0x00000000,0x00000000}},	//   _rớt_, _sròl, --, --, 
   {{0xe9dc0597,0xa49867c1,0x7a240008,0x9f4400db}},	//   siún_, _aròm, _nótt, menà_, 
   {{0x9f440268,0xec6c4c6b,0x28ac3c20,0xe9dc01e7}},	//   lenà_, _гп_, जीलि, miúl_, 
   {{0xdb00eae3,0x7a251bf6,0xa498067c,0x9f440306}},	//   _menú, _rótu, _cròm, zdný_, 
   {{0xe9dc0008,0xcc8801fb,0x682803b9,0x00000000}},	//   gnús_, _vớt_, _müdh, --, 
   {{0xe6405e91,0xb0cc012d,0x00000000,0x00000000}},	//   бесп, हूँग, --, --, 
   {{0x81b8045e,0x7a242833,0x944400c7,0xdb0000d7}},	// [1a8e0] চলা_, _dótt, амаҵ, _nenú, 
   {{0xdee40020,0x7e900374,0x41d06bcf,0x660c035a}},	//   ዚህን_, _hāpu, _हाउस, _enck, 
   {{0x7a2403b2,0x2324013e,0x7084086a,0x7e911bf7}},	//   _fótt, лофи_, ңгез, _kāpu, 
   {{0x9f44004e,0xd1cc0023,0x7e9000ef,0x7a2401e1}},	//   denà_, _ባሕቲ_, _jāpu, _tótu, 
   {{0x7d1c245f,0x7e90f43c,0xe2940032,0x9f440030}},	//   ässl, _māpu, _ҡар_, rdný_, 
   {{0xdb0119c7,0xc76402dd,0xccdc01ec,0x00000000}},	//   _denú, _حاۋى, _ﺘﺩﺨل_, --, 
   {{0x6ee51bf8,0x9f440589,0x68283f5b,0x8f343d2a}},	//   استل, venã_, _südk, рейц, 
   {{0xf1a91bf9,0x7a2408a7,0xdef40184,0xb64400b5}},	//   _ساره_, _móts, уыш_, _ｈｍ_, 
   {{0x2fd40491,0x200c02f0,0x00000000,0x00000000}},	//   _متاح, álií_, --, --, 
   {{0x09ac0882,0x5ec0015b,0xe7d001ad,0x2f5401f4}},	//   चर्य, _শহরে, _ताइप, _йтес, 
   {{0x2f543739,0x28b4033d,0x7644017a,0x4a54ac57}},	//   _стас, _अबहि, _omky, икос, 
   {{0x7e90002b,0xe9dc0332,0x00000000,0x00000000}},	//   _cāpu, ciúl_, --, --, 
   {{0x9f4403c6,0x7a2401a8,0x7d1c0158,0xf4d40154}},	//   mená_, _rótt, øsst, হবুব, 
   {{0x9f4403c6,0x6e211bfa,0x7a24066a,0xd7f91bfb}},	//   lená_, _hoob, _sótt, лус_, 
   {{0x6e211bfc,0x68280e78,0x6fd001ad,0xdb9800d9}},	//   _koob, _jüdi, _साईं, _אסור, 
   {{0x9f4401f1,0x6828950d,0x6e211bfd,0xe9dc004e}},	//   nená_, _müdi, _joob, rnús_, 
   {{0x6e211bfe,0x6828002f,0x00000000,0x00000000}},	// [1a8f0] _moob, _lüdi, --, --, 
   {{0xdb002897,0x6e211bff,0x76440083,0x7a2409e8}},	//   _renú, _loob, _emky, _fóts, 
   {{0x97a401af,0x00000000,0x00000000,0x00000000}},	//   _урыл, --, --, --, 
   {{0x6e211c00,0x9f440122,0x6fd002ab,0x68281196}},	//   _noob, jená_, _साउं, _südh, 
   {{0x90e4179c,0x9f446b07,0x5dc00075,0xe3140150}},	//   مسون, dená_, ەمبە, _ءﺳﯩﺮ, 
   {{0x1ae800bd,0x656c0113,0xade00d2e,0x6828002f}},	//   টিতে_, _iych, क्सन_, _büdi, 
   {{0x6e211c01,0x6444b9d2,0x7a241d0e,0x656c03cb}},	//   _boob, _imji, _mótr, _hych, 
   {{0x6e211c02,0x9f440ffb,0x59d409ab,0x00000000}},	//   _coob, renà_, _थाइर, --, 
   {{0x6e211c03,0x9d100011,0x7e900171,0x00000000}},	//   _doob, িন্ন_, _rāpu, --, 
   {{0x3ce4534e,0x656c02a4,0x92e803d4,0xe9dc0332}},	//   _कहीं_, _mych, বিৰ_, siúl_, 
   {{0x6e20375a,0x9f440232,0x656cd02e,0x682807de}},	//   _foob, bená_, _lych, _güdi, 
   {{0x6e211c04,0xdb000140,0x656c01a9,0x9f4400bc}},	//   _goob, _menø, _oych, cená_, 
   {{0xe8f422e9,0xb8651c05,0x6444009a,0x656d1c06}},	//   аля_, لاسو, _omji, _nych, 
   {{0x80cc3eaf,0xd1f802d3,0xeb940334,0x59d400bc}},	//   _सिने, ለስተ_, _киш_, थलहर, 
   {{0x7e911c07,0x656c33d8,0x6e20bdb3,0xf5b400f5}},	//   _tāpu, _aych, _yoob, исаю, 
   {{0x35a405f5,0x656c8812,0x6e20208d,0x64451c08}},	//   рааг, _bych, _xoob, _amji, 
   {{0x7ae000c6,0x656c00a9,0x7e9000ef,0x2614000d}},	// [1a900] ltlt, _cych, _kāps, _पचरी_, 
   {{0x656d1c09,0x9f4402fd,0x37e419bb,0x00000000}},	//   _dych, zená_, _тоог, --, 
   {{0x656c014f,0xe29405f5,0xd3701183,0xfbdc2802}},	//   _eych, аах_, سۇر_, _मानम, 
   {{0xcc8807ae,0x6444209c,0x69c000b0,0x68280b70}},	//   _lớp_, _emji, _ēnek, _rüdi, 
   {{0x6e211c0a,0x9f440232,0x6fb40597,0x656c0368}},	//   _roob, vená_, لمشا, _gych, 
   {{0x6e211c0b,0x16140490,0x7e900055,0x68e8007c}},	//   _soob, डावर_, _nāps, _ägde, 
   {{0x6e211c0c,0x9f442b57,0x73340131,0x8fc400c7}},	//   _poob, tená_, _ئىزا, _ҳазҵ, 
   {{0xd1f802d3,0x6e20058a,0x6fd00a59,0x6ff400cc}},	//   ለስቲ_, _qoob, _ठाकू, চাইজ_, 
   {{0xa0a00cef,0x9f4401f1,0xa498004e,0x6e202a89}},	//   _матд, rená_, _esòf, _voob, 
   {{0x7e90002b,0x9f4413d5,0xac244965,0x68280037}},	//   _cāps, sená_, рфик, _tüdi, 
   {{0xdfcc3ed4,0x6e20102c,0x9f4402fb,0xcc880051}},	//   _زين_, _toob, pená_, _dớp_, 
   {{0xade02356,0x80cc8d1b,0x7e900055,0x00000000}},	//   क्शन_, _सिमे, _vāpt, --, 
   {{0x9f44003a,0x7ae4010e,0x00000000,0x00000000}},	//   genæ_, _ähtn, --, --, 
   {{0x656c038e,0x682806be,0xa5b80051,0x00000000}},	//   _rych, _lüdv, _coón, --, 
   {{0xfa5407d6,0x656d1c0d,0xe61000ec,0x5c78011a}},	//   _گروگ, _sych, يشر_, _שאוה, 
   {{0x656d1c0e,0x7a340006,0x00000000,0x00000000}},	//   _pych, kšty, --, --, 
   {{0xd4991c0f,0x7e9000e2,0xa3a40066,0x2c180412}},	// [1a910] арх_, _jāpr, لحان, बापू_, 
   {{0x656c0e96,0xa3a40114,0x00000000,0x00000000}},	//   _vych, рјак, --, --, 
   {{0xd7dc09d9,0x656c068f,0x68280ade,0x64480129}},	//   _बातच, _wych, _südw, égiq, 
   {{0x656d1c10,0xdb000158,0x9f44010b,0x00000000}},	//   _tych, _venø, lenç_, --, 
   {{0x3ce40c2e,0x656cf1de,0xf1c400bc,0xd1b81ec7}},	//   _कहें_, _uych, _žáci_, شانا_, 
   {{0x64440944,0x9f440205,0x035401ee,0x00000000}},	//   _umji, nenç_, _лүзә_, --, 
   {{0x64540472,0xbf0000e1,0xddd8010e,0x00000000}},	//   mnxi, लटेन_, gluş, --, 
   {{0x7e900055,0x175808c3,0x9f44010b,0x00000000}},	//   _sāps, יסור_, henç_, --, 
   {{0xa49800a3,0x7e9000cd,0x682803e3,0xe45c002f}},	//   _bròi, _cāpr, _hüdu, _tvöd_, 
   {{0xa49801c3,0x3ea40208,0x682806be,0x00000000}},	//   _cròi, _ttlt_, _küdu, --, 
   {{0x9f44068c,0x7dec0024,0xe8340092,0xddd8054e}},	//   denç_, _pėsč, _ባሪያዎ, cluş, 
   {{0xa498067c,0xdb20032e,0x00000000,0x00000000}},	//   _eròi, _þrís, --, --, 
   {{0xc0cc044e,0xbca47153,0x7e681132,0x00000000}},	//   _ባህሊ_, _امتي, moep, --, 
   {{0x9f4400ee,0xeb500137,0x00000000,0x00000000}},	//   genç_, تۉۉگ, --, --, 
   {{0xe7351c11,0x2ca402fa,0x682801b8,0x7a2403b2}},	//   бер_, _ztod_, _nüdu, _fótp, 
   {{0x9f4400fd,0x7e6801f5,0x18b40166,0xdce80064}},	//   menä_, noep, _мәгр, _lygč, 
   {{0x9f440724,0x14c804fb,0x7d1c0036,0x00000000}},	// [1a920] lenä_, شهای_, ässh, --, 
   {{0x9f44170c,0xe3b46b1a,0x682804cc,0x645400b5}},	//   cenç_, йбу_, _südv, gnxi, 
   {{0xfdf813f7,0x9f440891,0x7e680270,0xa80001c0}},	//   ्यास_, nenä_, koep, _эзэл, 
   {{0x30a001ec,0x7a3400d7,0x00000000,0x00000000}},	//   зғағ, tšty, --, --, 
   {{0x69d800c8,0x51190761,0x9f44248c,0xb2740124}},	//   אַוו, ролю_, henä_, алҧш, 
   {{0xdfcc0491,0x249c0261,0x3ddc0009,0xa064013e}},	//   فيه_, _éuma_, _acww_, бача_, 
   {{0x2ca51c12,0x91c40661,0x23240108,0x00000000}},	//   _stod_, _дәлл, _лори_, --, 
   {{0xddd80209,0xa49808c2,0xa3440166,0x7e900055}},	//   rluş, _sròi, _узса_, _sāpr, 
   {{0xa4980192,0xe1200220,0xddd8054e,0x00000000}},	//   _pròi, _емти, sluş, --, 
   {{0xef90036b,0x9f440166,0x00000000,0x00000000}},	//   _عیبد, fenä_, --, --, 
   {{0x6e9419f9,0x9f451c13,0x7e6801ee,0x2c18256a}},	//   _الصا, genä_, boep, बाबू_, 
   {{0x2efc0117,0x7e680381,0x00000000,0x00000000}},	//   _istf_, coep, --, --, 
   {{0x2ca4c95a,0xa4991c14,0xdd8c00c6,0x00000000}},	//   _utod_, _tròi, _كوم_, --, 
   {{0xe61c0208,0x9f44008e,0x00000000,0x00000000}},	//   _khôg_, benä_, --, --, 
   {{0x9f451c15,0x6f1c01c7,0xdb00032e,0x27100210}},	//   renç_, äpch, _kený, डमेर_, 
   {{0xd5b8c88f,0x00000000,0x00000000,0x00000000}},	//   йсу_, --, --, --, 
   {{0xfc4800e4,0xdb00010b,0x6828002f,0x00000000}},	// [1a930] _umíã_, _mený, _südu, --, 
   {{0x7d1d1c16,0x27e40268,0xa5b80077,0x47d406f6}},	//   ässi, _ùnn_, _zoól, _بيدر, 
   {{0x319c02e3,0x2be800dc,0x00000000,0x00000000}},	//   _ịza_, ज्यं_, --, --, 
   {{0xc0cc0020,0xdf5000f7,0x00000000,0x00000000}},	//   _ባህል_, үндө, --, --, 
   {{0x26c00158,0x60e40212,0xe1640b24,0x00000000}},	//   lsjo_, сцез, حداي, --, 
   {{0xc60003f4,0x4fe80220,0x3ddc0009,0x2174010b}},	//   _একটা_, ймін_, _scww_, айҗы_, 
   {{0x7e691c17,0x01c40124,0x7f18753d,0x3f180108}},	//   toep, _мраҭ, рілу_, рюлю_, 
   {{0xceac0831,0x9f449226,0x3cc80063,0x3fc801d3}},	//   _үҙ_, venä_, алио_, _چدای_, 
   {{0x7e683441,0x2efc0117,0xee342626,0xe3140150}},	//   roep, _estf_, інь_, _ءﺷﯩﺮ, 
   {{0x9f440891,0x7e680263,0x6b94010b,0x00000000}},	//   tenä_, soep, _şygr, --, 
   {{0x7e68166a,0x7f540736,0xb05001d9,0x00e002dd}},	//   poep, _بناؤ, _کھۆت, _ﺍﻻﺠﺘ, 
   {{0x3cfc0b89,0x9f440598,0x7d0c0077,0x1ae800cc}},	//   _tswv_, renä_, _áaso, টিলে_, 
   {{0x9f44a02a,0xdb000365,0x6d4400d2,0x3868003a}},	//   senä_, _henü, úkat, tobr_, 
   {{0x8880054a,0x0d8001e0,0x3b0801f4,0x7d081291}},	//   нғыл, _яһын, _веко_, mves, 
   {{0x2c1400dc,0x66980107,0xbb4400f5,0x5884010a}},	//   तारं_, иётӣ_, _фейк, çыра, 
   {{0x8504eb47,0x68291c18,0x75d43592,0x05a401f9}},	//   रिंट_, _büds, تيرا, गुलब, 
   {{0x7d091c19,0xdb0001b8,0x7398004e,0x21e00150}},	// [1a940] nves, _lenü, атес_, _ﺍﺤﺘﺭ, 
   {{0xf77006b7,0xf20005f9,0xa5b8002e,0x7d08127b}},	//   _ياد_, _रोज़_, _joój, ives, 
   {{0x7d091c1a,0xe94401d5,0xa2e001c4,0x00000000}},	//   hves, _هریی, дохд, --, 
   {{0xdb0000c7,0xd49803e6,0xe61c0142,0x721400c6}},	//   _henó, _هێرش_, _chôd_, غذائ, 
   {{0xa1800598,0x0fc802dd,0x12e80150,0x3ea40092}},	//   мышл, йқап_, _ﺎﻴﻌﻭ, _ዋነኞቹ_, 
   {{0x74151c1b,0xdb0012b6,0xa498180f,0x7d091c1c}},	//   _بوسا, _benü, _pròv, dves, 
   {{0x71a450df,0x5ea000f7,0xa2e00137,0x260c0073}},	//   _мавз, ومول, _оорд, डाची_, 
   {{0xe29401af,0x7d08d000,0x00000000,0x00000000}},	//   _фат_, fves, --, --, 
   {{0x7d091c1d,0x68280213,0x91c40166,0x00000000}},	//   gves, _müdr, _дәһл, --, 
   {{0x394005be,0xdb000254,0xe61c0051,0xd2500345}},	//   dzks_, _fenü, _thôg_, _تۆڵ_, 
   {{0xdb000730,0x639802e4,0xada40064,0x6f6000d1}},	//   _genü, יסינ, _даел, _تۇغم, 
   {{0x6d44022c,0x2bb442e3,0x32051c1e,0xb4e801ad}},	//   úkas, _आजका, ndoy_, _महू_, 
   {{0xa5b80077,0xdb0008a5,0x00000000,0x00000000}},	//   _ilóx, _benó, --, --, 
   {{0xeb483695,0x25c000dc,0x44200175,0xddd801ef}},	//   _پشتو_, षण्ण, xjh_, douř, 
   {{0xdb00068c,0x68282fc1,0xdc38008f,0x00e00220}},	//   _denó, _süds, _דעגר, _ﺍﻻﺤﺘ, 
   {{0x225c01e4,0xcb0800ec,0xdb2002d2,0x00000000}},	//   _ĉuko_, _نيڻن_, _þrás, --, 
   {{0xdb0009ff,0x7aec0b94,0x998005d2,0x682803e3}},	// [1a950] _fenó, _ćati, _iniş_, _qüds, 
   {{0xa5b801e1,0xf4cc00d1,0xf948010f,0xdb0015c0}},	//   _koók, _ﺗﻪﺷﻜ, _לעפֿ, _genó, 
   {{0x7d091c1f,0x539800d4,0x00000000,0x00000000}},	//   zves, івця_, --, --, 
   {{0x32042819,0xdb00db8b,0x442001f4,0xddd8013a}},	//   gdoy_, _kenò, sjh_, bouř, 
   {{0x361806a9,0xe3d4007b,0xddd801ef,0x00000000}},	//   _הורד, _وتسع, couř, --, 
   {{0xdb00629e,0xa2d0134e,0x9f440419,0x00000000}},	//   _menò, _डिप्, menú_, --, 
   {{0xa49800cf,0x9f440030,0xc1d00daf,0x53480354}},	//   _eròt, lenú_, _зөлә, _мăшă, 
   {{0xa1851c20,0xdb000790,0x7d0801d3,0x6e900114}},	//   _дызл, _venü, tves, нију, 
   {{0x225c3743,0xa4980ba1,0x1fa4a90c,0x9f4400d0}},	//   _ijuk_, _tròu, _дрег, nenú_, 
   {{0xac811c21,0xe08402f2,0x00000000,0x00000000}},	//   нгыл, _بێتو_, --, --, 
   {{0x6d440579,0xdb011c22,0x61e801c7,0x00000000}},	//   úkar, _renó, ofgl, --, 
   {{0xeaac0a52,0xdb011c23,0x6aa809bd,0x7d091c24}},	//   _үй_, _senó, _কিশো, pves, 
   {{0xfd7405f5,0x225c00bf,0xdb00004e,0xa3b805f9}},	//   _элдэ, _mjuk_, _penó, घरा_, 
   {{0x9f440030,0x998003e3,0x6828002f,0x0d5400f2}},	//   denú_, _eniş_, _südr, _تخمد, 
   {{0xe7351c25,0x225c00a2,0xade002db,0xec34011a}},	//   пер_, _ojuk_, क्कन_, _מאסר_, 
   {{0x7bc11c26,0xdb011c27,0x225c0214,0x682800ac}},	//   lalu, _fenò, _njuk_, _qüdr, 
   {{0xdb004a2e,0x33f51c28,0x5fb800bc,0x00000000}},	// [1a960] _genò, зчес, उराल, --, 
   {{0xe8f51c29,0x00e401ec,0x73984130,0x00000000}},	//   _эль_, _ﺍﺴﺘﻘ, стас_, --, 
   {{0x6828007d,0xe7b40302,0x35a4e201,0x20050315}},	//   _tüdr, _מהיר_, _нанг, ddni_, 
   {{0x7bc11c2a,0xa49856eb,0x28d01562,0xd7dc3105}},	//   halu, _cròs, _तिमि, _बाँच, 
   {{0x225c00f3,0xdb0000cf,0x32040162,0x9f4400d7}},	//   _djuk_, _xenò, rdoy_, cenú_, 
   {{0x7530005f,0xa0651c2b,0x80cc05d7,0x20040010}},	//   īdzī, пача_, _सिरे, gdni_, 
   {{0x5f911c2c,0x64380115,0x00000000,0x00000000}},	//   ништ, _פעלנ, --, --, 
   {{0xa4991c2d,0x5ed00372,0xb62c00b5,0x8f0001ec}},	//   _gròs, رتىز, _ｓｃ_, рiс_, 
   {{0xd7dc00af,0xe80c00bc,0x9ce08e21,0x00000000}},	//   _बांच, ायमा_, нцэл, --, 
   {{0x7bc11c2e,0x09c400a5,0xa2d02efd,0x00000000}},	//   galu, वण्य, _डिम्, --, 
   {{0x290c0129,0xfbdc00bc,0x9f440419,0x00000000}},	//   _àgaz_, _मारम, zenú_, --, 
   {{0x7bc11c2f,0x30c41df2,0xd0100451,0x5f3405d0}},	//   aalu, ﺮﮔﻪﻧ, _سڄڻ_, _מטבע_, 
   {{0x92e805ac,0x7d1c007c,0x00000000,0x00000000}},	//   বিয়_, ässt, --, --, 
   {{0x7bc11c30,0x9f440030,0x93300023,0x00000000}},	//   calu, venú_, ሰርትታ, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa2d00c2e,0x80cc0d0a,0x9f4400d0,0x20051c31}},	//   _डिब्, _सिले, tenú_, zdni_, 
   {{0x24800208,0x00000000,0x00000000,0x00000000}},	// [1a970] _phjm_, --, --, --, 
   {{0x225d1c32,0x9f4400d0,0x6824010a,0x00000000}},	//   _sjuk_, renú_, _хьиз, --, 
   {{0xa4991c33,0x20040427,0x9f440419,0x00000000}},	//   _pròs, vdni_, senú_, --, 
   {{0xe9dd1c34,0x7bc11c35,0xd24401c0,0x680c0153}},	//   ngú_, zalu, нэчи, sėdė, 
   {{0x7bc0e439,0xf5700184,0xfbdc0490,0x680c0153}},	//   yalu, _аҫты, _मालम, pėdė, 
   {{0x91841823,0x225c0b21,0xd77402dd,0x7bc03d3d}},	//   رۇلۇ, _wjuk_, _تاۋع, xalu, 
   {{0xa49801ab,0x2c14000d,0x3e8836ca,0xcee800ae}},	//   _tròs, ताईं_, ойко_, كرين_, 
   {{0x225c00f2,0xbca42f84,0xfe440120,0x7870005c}},	//   _ujuk_, ومبي, ќнио, nævr, 
   {{0x7bc11c36,0xd0d40801,0xdee001b9,0x6ce001e2}},	//   talu, _потъ, фоқи, نړون, 
   {{0x7bc11c37,0x90541d83,0xec751c38,0xfc3000c6}},	//   ualu, _звуц, мпы_, ئحة_, 
   {{0x7bc032ff,0xcf98041b,0xaca001e0,0x00000000}},	//   ralu, _хју_, нгөһ, --, 
   {{0x7bc11c39,0xed4c350a,0x68281196,0x70440137}},	//   salu, اپی_, _südp, _ىرەە, 
   {{0x7bc11c3a,0xed4c0aa5,0xec6cb6ac,0xee3402d5}},	//   palu, _ро_, _ап_, _інш_, 
   {{0xb8f51c3b,0x7bc00eda,0x9be40135,0x787001bf}},	//   _हि_, qalu, _འཁྲོ, vævs, 
   {{0x28d000ce,0x00e00220,0x00000000,0x00000000}},	//   _तिथि, _ﺍﻻﺴﺘ, --, --, 
   {{0xddc40419,0x00000000,0x00000000,0x00000000}},	//   álňo, --, --, --, 
   {{0xa49800cf,0xf86400d8,0x42680092,0xfe78013a}},	// [1a980] _bròq, _овио, ታዊነት_, ilů_, 
   {{0xa49800cf,0x741416ac,0x2c14012d,0x00000000}},	//   _pròr, بوطا, ताएं_, --, 
   {{0x02a40046,0x1ae8015b,0xfe7800bc,0xdb04013d}},	//   ерім, টিকে_, klů_, _älän, 
   {{0x7df8000b,0xe9dc01e7,0xfe7801ef,0x00000000}},	//   ्योग_, liúr_, jlů_, --, 
   {{0xfbd4009e,0xe45c032e,0xd0d402e8,0x00000000}},	//   ত্যত, _kvöl_, холъ, --, 
   {{0xeea91c3c,0x4f4c0092,0xe9dc00ae,0x00000000}},	//   отик_, _ኔትወር, niúr_, --, 
   {{0xe80c7df0,0xfcc0506f,0x942405a9,0xd7dc01f9}},	//   ायता_, ңәшм, _قوڭۇ, _बाईच, 
   {{0xc32c3baf,0xdce801e4,0xa638010f,0x765800d7}},	//   _دەم_, ŝiĝu, ַגיר, étyh, 
   {{0x4c94774c,0x00000000,0x00000000,0x00000000}},	//   ниис, --, --, --, 
   {{0xc0b80092,0x00000000,0x00000000,0x00000000}},	//   _ሲኖሩ_, --, --, --, 
   {{0x20540375,0x5b2001c0,0xa0300c75,0xeb4800f5}},	//   _קיבל_, вьяа, _جىلت, ючик_, 
   {{0xefdc0023,0x00000000,0x00000000,0x00000000}},	//   ጓዓዝ_, --, --, --, 
   {{0xf8ac096d,0xd91001d3,0xe9dc01e7,0x00000000}},	//   یکی_, لیٹ_, fiúr_, --, 
   {{0xe9dc01e7,0xdd8c02f2,0x00000000,0x00000000}},	//   giúr_, _ئوه_, --, --, 
   {{0xfa8801fb,0xe45c08a5,0xaa6401ee,0x00000000}},	//   _lẫy_, _dvöl_, _отик, --, 
   {{0x833400c7,0x00000000,0x00000000,0x00000000}},	//   ҭнах, --, --, --, 
   {{0x3d1029da,0xe80c06ab,0x9c3000a2,0x99640153}},	// [1a990] तिये_, ायदा_, _öçýä, _атэл, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfe780118,0x021801ca,0x00000000,0x00000000}},	//   ylů_, зіль_, --, --, 
   {{0xfa8801fb,0x3d104709,0x00000000,0x00000000}},	//   _bẫy_, तिमे_, --, --, 
   {{0x90e50cff,0x5504022e,0x00000000,0x00000000}},	//   نسون, _ичра, --, --, 
   {{0x751404ac,0xc0b80092,0xa3e000c5,0x44240254}},	//   _אַלע_, _ሲኖር_, _नञि_, _õl_, 
   {{0x81d4010b,0x4cb800cc,0xfe780118,0x00000000}},	//   _повх, _আমগু, tlů_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb0029ef,0xfa880208,0xef9400d1,0xfd100553}},	//   _jenö, _gẫy_, мкәш_, اجب_, 
   {{0x51851c3d,0xa9a007a5,0x00000000,0x00000000}},	//   _руса, ғирд, --, --, 
   {{0xeaac00dd,0xddd804ba,0x00000000,0x00000000}},	//   یٹی_, nnuŋ, --, --, 
   {{0xe45c02d2,0x00000000,0x00000000,0x00000000}},	//   _svöl_, --, --, --, 
   {{0xec1004d3,0xa74c001f,0xa3dc01f9,0xefdc0092}},	//   _ڕوود, _አስፈጻ, णला_, ጓጓዝ_, 
   {{0x7c880bd6,0x8c640166,0xdb200244,0x9ba015bf}},	//   _эшең_, _үтәд, _لوتی, _جەدى, 
   {{0x375415b4,0xe9dc01e7,0x00000000,0x00000000}},	//   رپرس, riúr_, --, --, 
   {{0xa4991c3e,0xdb010e6c,0x34a80640,0xb4a802e8}},	//   _pròp, _benö, звао_, зказ_, 
   {{0xdb000793,0x00000000,0x00000000,0x00000000}},	// [1a9a0] _cenö, --, --, --, 
   {{0xfa88004d,0x38a40142,0x00000000,0x00000000}},	//   _rẫy_, _iôr_, --, --, 
   {{0x0cdc1cd2,0x38a400d0,0x00000000,0x00000000}},	//   _मम्म, _hôr_, --, --, 
   {{0x38a40109,0xa498004e,0x7bc4000d,0x71a40006}},	//   _kôr_, _tròp, _õhuf, хадз, 
   {{0x76551c3f,0xe61c001e,0x33d40212,0xdb00002f}},	//   miyy, _khôn_, _півт, _genö, 
   {{0x7654e7be,0x38a400a9,0x75811c40,0xfa88004d}},	//   liyy, _môr_, _аңға, _vẫy_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x76551c41,0x644800e2,0x7e9000b8,0x00000000}},	//   niyy, īgie, _kāpy, --, 
   {{0x2d8008fb,0x9f4402fb,0x7654003e,0x7e900055}},	//   åke_, mený_, iiyy, _jāpy, 
   {{0x9f440232,0x765403be,0xa0a001b9,0x2ac401e1}},	//   lený_, hiyy, _сафд, _níbá_, 
   {{0x3fc80502,0x76540429,0x69f0009d,0x2d8000d7}},	//   _آگهی_, kiyy, гүйт, ťke_, 
   {{0xa2d0d3a8,0x9f4401f1,0x76551c42,0x00000000}},	//   _डिस्, nený_, jiyy, --, 
   {{0x76551c43,0x2ac401e1,0x38a40368,0x7e9000cd}},	//   diyy, _bíbá_, _côr_, _nāpy, 
   {{0x2c14068f,0xe61c01fb,0xae1c00e1,0x38a40142}},	//   ताओं_, _chôn_, भावन_, _dôr_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9f440122,0xdb0001b8,0x38a51c44,0x76540548}},	//   jený_, _penö, _fôr_, giyy, 
   {{0x9f446b07,0x7e9000cd,0x38a4015d,0x00000000}},	// [1a9b0] dený_, _cāpy, _gôr_, --, 
   {{0x7e90002b,0xdb009d06,0x47346206,0x00000000}},	//   _dāpy, _venö, _анос, --, 
   {{0x76551c45,0xb3e0690c,0xa498004e,0x9474009a}},	//   biyy, _पारख, _isòm, ادقا, 
   {{0xd6d802bf,0x80cc0490,0x76551c46,0x00000000}},	//   _ять_, सळले, ciyy, --, 
   {{0xd17508d1,0x7bc4000d,0x7658007f,0xa2d001f9}},	//   лышы, _õhug, ètye, _डिव्, 
   {{0xdbd001e1,0x00000000,0x00000000,0x00000000}},	//   _fúùf, --, --, --, 
   {{0x6454ea1d,0x9f440232,0x6280004e,0x80cc00bc}},	//   mixi, bený_, ïnos, _सिके, 
   {{0x64551c47,0xb3400724,0x9f451c48,0x171c010f}},	//   lixi, üçel, menü_, לווע, 
   {{0xd1f80023,0x3c6400d1,0x1ae800fe,0xbc6400d4}},	//   ወትቲ_, ккиг, টিছে_, квик, 
   {{0x76540cc1,0x18b4035b,0x00000000,0x00000000}},	//   ziyy, қәир, --, --, 
   {{0x7a684a7a,0x319c063f,0x76540198,0x629801f7}},	//   динг_, _ịzi_, yiyy, _kiuo, 
   {{0xd9791c49,0x38a406ed,0x64540921,0xc86802e4}},	//   ергә_, _pôr_, hixi, _ון_, 
   {{0x765403be,0x64551c4a,0xfc04020f,0xfce41c6c}},	//   viyy, kixi, _апло, _роло, 
   {{0x76551c4b,0x9f4404bf,0x28d0772c,0xb8e802ab}},	//   wiyy, zený_, _तिरि, _ऊब_, 
   {{0x76551c4c,0x64551c4d,0xb6a51c4e,0xaeb4031c}},	//   tiyy, dixi, тибл, _ནསབོ, 
   {{0x645400db,0x9ba08e98,0x1db000cd,0x00000000}},	//   eixi, _جەگى, ीरित, --, 
   {{0x9f440232,0x76551c4f,0xe61c001e,0x74e801c0}},	// [1a9c0] vený_, riyy, _thôn_, ьдаг_, 
   {{0x76551c50,0x62980395,0x64540050,0xdb0006ed}},	//   siyy, _aiuo, gixi, _fenô, 
   {{0x3ced1c51,0xdb000a85,0xf7447136,0x9f451c52}},	//   htev_, _genô, _рено, tený_, 
   {{0x76540548,0xd9f42356,0x35a42f09,0x62980064}},	//   qiyy, ेजित_, _шамг, _ciuo, 
   {{0x9f4401f1,0x62980393,0x64540014,0x00000000}},	//   rený_, _diuo, bixi, --, 
   {{0xa07002d5,0xdfcd1c53,0x9f441d55,0xc76402dd}},	//   агіч, قيه_, sený_, _جاۋى, 
   {{0x9f451c54,0x72940124,0x6e880063,0x2d980241}},	//   denó_, _ашах, мљив_, _ńpe_, 
   {{0x62991c55,0x28d03be5,0x2284000d,0xb3e00037}},	//   _giuo, _तिलि, tõke_, _पाँख, 
   {{0x69c80086,0x80c03885,0x62a400e2,0x00000000}},	//   _ôgei, रीदे, ēroš, --, 
   {{0x7d0c0327,0x2f54010a,0x29f0002b,0x00000000}},	//   _ġast, _итес, _ṇa_, --, 
   {{0xb0d00118,0x00000000,0x00000000,0x00000000}},	//   _सिँग, --, --, --, 
   {{0x05e01d8a,0x8c440032,0x06b0009e,0xad2401b9}},	//   _फाइब, теүе, _ছিলি, _لرتو, 
   {{0xe80c05ba,0xb3e00406,0x64540009,0x2d900241}},	//   ायला_, _पांख, yixi, _àye_, 
   {{0xd7f82551,0x64551c56,0x9874b19d,0x2d840ea0}},	//   кус_, xixi, иляц, _izoe_, 
   {{0x45d40323,0x69f08337,0x0a580166,0x64551c57}},	//   ловс, _күнт, _пакъ_, vixi, 
   {{0xb0d021bd,0xa8a41188,0x543407d6,0x2c18012d}},	//   _सिंग, _ирок, یرلر, बाकू_, 
   {{0x56940993,0x64544a85,0x6298003a,0x3c2800d7}},	// [1a9d0] ратт, tixi, _riuo, _rúvz_, 
   {{0xe7b429d7,0x62990624,0x6b9400ee,0xa8f000d7}},	//   _अभिप, _siuo, _şygy, ľôčo, 
   {{0xd3a51c58,0x64551c59,0x93a401f0,0x00000000}},	//   рруп, rixi, ршуд, --, 
   {{0x645401d9,0x60c8009a,0x00000000,0x00000000}},	//   sixi, tsgm, --, --, 
   {{0x645401af,0x403470e5,0xa3b8152b,0x94a91c5a}},	//   pixi, ледс, _ياسر_, _атса_, 
   {{0xa5b8002e,0x2eec0332,0x00000000,0x00000000}},	//   _goór, ftff_, --, --, 
   {{0x629800df,0x00e00150,0x54540114,0x00000000}},	//   _tiuo, _ﺍﻻﺌﺘ, _тврт, --, 
   {{0x44311c5b,0x62980393,0xddf400fd,0xa49801e1}},	//   _hoz_, _uiuo, тькә_, _osòk, 
   {{0x44311c5c,0xd8400122,0xe61c001e,0xed54013e}},	//   _koz_, áčky_, _nhôm_, лоъ_, 
   {{0x443001c4,0xed1400dd,0x3cec04cc,0xdb0008a5}},	//   _joz_, اہوں_, rtev_, _afná, 
   {{0xa49801e1,0x3ced1c5d,0x39e868eb,0x3f840118}},	//   _asòk, stev_, ндно_, _uzlu_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x0dc91c5e,0x817802d3,0xe61c004d,0x44300427}},	//   _рухи_, _እናበሉ_, _chôm_, _ooz_, 
   {{0x6cd05285,0x443003bd,0xe61c0109,0xd1e8010c}},	//   _اقوا, _noz_, _anô_, _መዓት_, 
   {{0xe8f40046,0xeb94074d,0x00000000,0x00000000}},	//   _ұлы_, _йиш_, --, --, 
   {{0x3ea51c5f,0x7ae11c60,0x44311c61,0x9b4000ec}},	//   _mult_, mult, _aoz_, _ٽنڊو, 
   {{0x44311c62,0x3ea401f5,0x00000000,0x00000000}},	// [1a9e0] _boz_, _lult_, --, --, 
   {{0x7ae0014b,0xe575007b,0x44300f85,0xf7d000db}},	//   oult, узу_, _coz_, _دەسڭ, 
   {{0x59b8069f,0x7ae11c63,0x44311c64,0xb0c4068f}},	//   _आभार, nult, _doz_, रीनग, 
   {{0x7e78063f,0xb144030d,0x00000000,0x00000000}},	//   _nkwp, лнел, --, --, 
   {{0x44311c65,0x7ae11c66,0x3ea40c86,0x64480153}},	//   _foz_, hult, _ault_, ūgia, 
   {{0x64891c67,0x44311c68,0x00000000,0x00000000}},	//   güid, _goz_, --, --, 
   {{0x7ae008cb,0x319c063f,0x3ea40f85,0xe9dc0332}},	//   jult, _ịzu_, _cult_, dhún_, 
   {{0xe2951c69,0x4430836b,0x3ea40162,0xa5b800d8}},	//   _бас_, _zoz_, _dult_, _inóc, 
   {{0x4430ec7f,0x216415ed,0xa5b800e4,0x4ea40032}},	//   _yoz_, _бити_, _moóp, ырҙа, 
   {{0x3ea51c6a,0x7ae11c6b,0x443001a9,0x67240175}},	//   _fult_, fult, _xoz_, yxjj, 
   {{0xa3f40375,0xce34691d,0x7ae11c6c,0x00000000}},	//   נמטק_, _پوشک, gult, --, 
   {{0x6da4225f,0xdb0001a8,0x80c00bca,0x00000000}},	//   _сида, _ofnæ, रीवे, --, 
   {{0x3ea40cf9,0x7ae000ad,0x00000000,0x00000000}},	//   _zult_, ault, --, --, 
   {{0x7ae11c6d,0xe7e000bd,0xe9dc01e7,0xd9100244}},	//   bult, য়্য, chún_, سیپ_, 
   {{0x44311c6e,0xe6880114,0x00000000,0x00000000}},	//   _roz_, ељак_, --, --, 
   {{0x44311c6f,0x00000000,0x00000000,0x00000000}},	//   _soz_, --, --, --, 
   {{0x44311c70,0xf96800db,0xb0c403ce,0x00000000}},	// [1a9f0] _poz_, _үрөй_, रीमग, --, 
   {{0x443003e3,0x00000000,0x00000000,0x00000000}},	//   _qoz_, --, --, --, 
   {{0x41b51c71,0x90e40f78,0x2be000af,0xfbdc190c}},	//   لمار, ەسىن, _खाईं_, _माघम, 
   {{0x44311c72,0xd3791c73,0xb6b80375,0xfb14010f}},	//   _woz_, учу_, _שצרי, יַנט_, 
   {{0x3ea51c74,0x44306d5b,0x68280205,0xc0c40166}},	//   _sult_, _toz_, _südy, рәби, 
   {{0x7ae02f4d,0x50b800f2,0x443000d7,0x96b84e10}},	//   yult, ادند_, _uoz_, _جایز_, 
   {{0xc1d00058,0x27e401a8,0xa5b801e7,0x22840139}},	//   _дөлә, _önnu_, _gnóc, _буаг, 
   {{0x3ea51c75,0x2ca422d0,0x7ae11c76,0x975800c8}},	//   _vult_, _buod_, vult, טיוו_, 
   {{0x660d1c77,0x7ae00408,0xacc40724,0x9fe400c6}},	//   _mack, wult, агыз_, _مساه, 
   {{0x1c1cbebc,0x660d1c78,0x7ae11c79,0xdd3c00a2}},	//   बाइल_, _lack, tult, _eňşe, 
   {{0xcd291c7a,0x3ea40381,0x5eac0eac,0x9f48005b}},	//   نسین_, _uult_, _টিকে, älän_, 
   {{0x660d1c7b,0x7ae11c7c,0x00000000,0x00000000}},	//   _nack, rult, --, --, 
   {{0x2ca40b21,0x00000000,0x00000000,0x00000000}},	//   _guod_, --, --, --, 
   {{0x2be0033f,0xddd8025c,0x00000000,0x00000000}},	//   _खाएं_, hmuż, --, --, 
   {{0x660c0fa9,0x7ae0014f,0x16840133,0x00000000}},	//   _back, qult, مارێ, --, 
   {{0x660d1c7d,0x75d4007b,0xe6400022,0x00000000}},	//   _cack, شيطا, оесп, --, 
   {{0x660cf4bd,0x00000000,0x00000000,0x00000000}},	// [1aa00] _dack, --, --, --, 
   {{0x78b40022,0xe3b40107,0x2934008f,0x7d18015d}},	//   _ityv, ибу_, _כאפן_, _mrws, 
   {{0x660d1c7e,0x0ef40490,0xe7d8011a,0x00000000}},	//   _fack, _आहेस_, _בקיש, --, 
   {{0x660d1c7f,0x00000000,0x00000000,0x00000000}},	//   _gack, --, --, --, 
   {{0x3eb80276,0x7e6c01fa,0x76451c80,0x00000000}},	//   _ăsta_, čapl, _ilky, --, 
   {{0x660d1c81,0x2be800cd,0x00000000,0x00000000}},	//   _zack, ज्ञं_, --, --, 
   {{0x1c1c13f7,0x2324a9c3,0x4fc40046,0xcf2404c5}},	//   बाईल_, _кори_, асқа, বন্দ_, 
   {{0x7d18015d,0xe28401b9,0x118801af,0x00000000}},	//   _brws, _نطقی, _йәлп_, --, 
   {{0x2ca4f899,0x61411c82,0xafe41de1,0x7d180042}},	//   _quod_, _дета, _возл, _crws, 
   {{0x7d18015d,0x00000000,0x00000000,0x00000000}},	//   _drws, --, --, --, 
   {{0x78b400e4,0x764400ad,0xfbcc00ec,0x2414011a}},	//   _atyv, _olky, رڪو_, בחין_, 
   {{0x2ca4356c,0x2efc01fa,0x29440ed1,0x7d180042}},	//   _tuod_, _iptf_, ﺘﺎﭖ_, _frws, 
   {{0x6e211c83,0x29851c84,0x7afc0356,0x070801f7}},	//   _inob, рынг, ăsta, گيزي_, 
   {{0x660c1943,0x76451c85,0x00000000,0x00000000}},	//   _sack, _alky, --, --, 
   {{0x660d1c86,0x6e211c87,0x7bc4000d,0x28d00073}},	//   _pack, _knob, _õhua, _तिकि, 
   {{0xe61c001e,0xd5b8bfed,0x9f9000d0,0x76580129}},	//   _khôi_, ису_, _pľúc_, étyp, 
   {{0x660c04f3,0x2868d87d,0xf8b400ee,0xaac0095f}},	// [1aa10] _vack, _арно_, _гөс_, वीरक, 
   {{0x6f1803ac,0x0a1805ac,0x6e200064,0x68f80205}},	//   _ortc, _ডকিং_, _lnob, çudu, 
   {{0x6e20542c,0x660cfe91,0x465800f5,0x19ac01ec}},	//   _onob, _tack, _баню_, _ﺳﯩﭙﺎ, 
   {{0xc0e8001f,0xd1b80a8e,0x660c02d0,0xe80c00bc}},	//   _መሃል_, لاها_, _uack, ायका_, 
   {{0x6f187a02,0xa2d01b76,0x5a1800df,0x00000000}},	//   _artc, _डिक्, יקאן_, --, 
   {{0x6e2005b8,0x3f68390e,0x656c01b9,0xbea41e43}},	//   _anob, лило_, _ixch, бакк, 
   {{0x64451c88,0x2d800205,0x00000000,0x00000000}},	//   _ilji, üken_, --, --, 
   {{0x11d400c6,0x291801b9,0x7d180142,0x00000000}},	//   _وتقد, _orqa_, _prws, --, 
   {{0x61f91c89,0x58f4031c,0x6f1802d0,0xd38402dd}},	//   _ibul, _བདེས_, _ertc, _ﺩﺍﯕﻖ_, 
   {{0x6e211c8a,0x61f80327,0xfc2814a3,0xe4fc0037}},	//   _enob, _hbul, ужок_, _उहनि_, 
   {{0x78b44cab,0xbf140133,0x00000000,0x00000000}},	//   _styv, _دواب, --, --, 
   {{0x61f8020c,0x7d1803cb,0x00000000,0x00000000}},	//   _jbul, _trws, --, --, 
   {{0x61f91c8b,0x8e740597,0xe8f45477,0x64451c8c}},	//   _mbul, _بالض, бля_, _olji, 
   {{0x17c8016c,0x7d080a49,0xfe78030a,0x00000000}},	//   шҳои_, mwes, loů_, --, 
   {{0x7d091c8d,0xa2d0375c,0x61f91c8e,0x29180113}},	//   lwes, _डिग्, _obul, _erqa_, 
   {{0x64447b06,0xfe78030a,0x35a4009d,0x00000000}},	//   _alji, noů_, сааг, --, 
   {{0x64440010,0xfe78030a,0x7d091c8f,0x1aac00eb}},	// [1aa20] _blji, ioů_, nwes, _কিয়া, 
   {{0x69c80086,0x7d1c023a,0x7d080af9,0xfe78030a}},	//   _ôger, ässy, iwes, hoů_, 
   {{0x7d091c90,0x61f80337,0x656d1c91,0xfe78030a}},	//   hwes, _bbul, _exch, koů_, 
   {{0x7d08124c,0xe2951c92,0x6b7800c8,0x8cd81d8a}},	//   kwes, бах_, ארענ, _मिलो, 
   {{0x6e2001ab,0xfe780156,0x2164377e,0xd1301867}},	//   _rnob, doů_, бици_, ظمت_, 
   {{0x61f91c93,0x6444098d,0x944400e5,0xdb0c0432}},	//   _ebul, _glji, _بھرن, _šeýl, 
   {{0xa2e11c94,0x323400d1,0x7d080af9,0xa2b000e5}},	//   _норд, _лхас, ewes, _فیلڈ, 
   {{0x6f18151c,0xe61c01fb,0xfe7805c7,0x0cd80063}},	//   _vrtc, _phôi_, goů_, адић_, 
   {{0xa49800f7,0x7d080117,0x05940055,0xb1451c95}},	//   _pròx, gwes, _bāṣy, _унал, 
   {{0x61f8044e,0x8af81d0f,0x00000000,0x00000000}},	//   _zbul, анос_, --, --, 
   {{0xdfcc2834,0xa498004e,0x3dcc00ee,0x4af800d4}},	//   _سين_, _isòt, baew_, шеню_, 
   {{0xe61c07ae,0x6e211c96,0x4aa80145,0x7d0804ba}},	//   _thôi_, _unob, лкүн_, bwes, 
   {{0x6cb800fd,0xa6100131,0x00000000,0x00000000}},	//   _сыер_, үзгә, --, --, 
   {{0x7d1c00b5,0xa5b800ae,0x5c700212,0x00000000}},	//   æsse, _cnón, _еліт, --, 
   {{0x644802d3,0x85c80075,0x998000cd,0x4ac4009f}},	//   ëgim, итағ_, _kaiś_, _بيعق, 
   {{0x48c40598,0xa5b8067c,0x64441050,0x6aa80194}},	//   _мәга, _enón, _slji, _iuff, 
   {{0x69ccebf9,0xdb011c97,0x00000000,0x00000000}},	// [1aa30] mace, _agnè, --, --, 
   {{0x69ccb636,0x6aa91c98,0x61f80268,0xa5b801e7}},	//   lace, _kuff, _sbul, _gnón, 
   {{0x6aa8f498,0xa4987172,0x216405a2,0x7d091c99}},	//   _juff, _apòc, әтег, zwes, 
   {{0xa498007f,0x7d091c9a,0x7d1c33b8,0x00000000}},	//   _asòt, ywes, åssk, --, 
   {{0x4128dba2,0x65c001ec,0x06b000eb,0x00000000}},	//   роло_, _мұңа, _ছিটি, --, 
   {{0x2fcc00a3,0xa4f400bc,0x00000000,0x00000000}},	//   gafg_, ुबीच_, --, --, 
   {{0x69cc03b4,0x6aa91c9b,0xa4981497,0x10e401ec}},	//   kace, _nuff, _epòc, _ﺍﻻﺜﻨ, 
   {{0x61f8e4ed,0x7d0804ba,0xa498026c,0x9f4400f2}},	//   _ubul, twes, _esòt, ngné_, 
   {{0x6aa91c9c,0xae1c2cce,0x9f4407ea,0xa13404fb}},	//   _auff, भाजन_, igné_, _ارزش, 
   {{0x6aa91c9d,0x7f940022,0xfe78030a,0xff24cddb}},	//   _buff, _дазх, soů_, _وبای, 
   {{0x69cd1c9e,0x7d091c9f,0x63a0022e,0xaff8010f}},	//   face, swes, оnni, _כּאי, 
   {{0x69ccb742,0x61e91ca0,0x7d091ca1,0x6aa8f474}},	//   gace, nggl, pwes, _duff, 
   {{0xf6084144,0x7d0800f1,0x98940116,0x7e683ed8}},	//   یتره_, qwes, зувә, mnep, 
   {{0x20051ca2,0x6aa91ca3,0xbb440b32,0x7e680407}},	//   neni_, _fuff, _мелк, lnep, 
   {{0xf7442db9,0x7bc11ca4,0x2004054e,0x9980002b}},	//   цево, mblu, ieni_, _yaiś_, 
   {{0x7bc11ca5,0xb818d054,0xdb0001e7,0xa2d012eb}},	//   lblu, _फोरम_, _ngné, _डिज्, 
   {{0x20051ca6,0x6aa8026c,0x2348158b,0x7e680c4e}},	// [1aa40] keni_, _zuff, یسمی_, inep, 
   {{0x7bc11ca7,0xe45c0008,0x7e682305,0x33f45a44}},	//   nblu, _svör_, hnep, ўчас, 
   {{0x7bc00cfe,0x7e691ca8,0xf77025ef,0xa6c40014}},	//   iblu, knep, _زاد_, _ووٝل_, 
   {{0x7bc00e78,0x200401f4,0x00000000,0x00000000}},	//   hblu, eeni_, --, --, 
   {{0x20043e6e,0xe80c0574,0x491c1d8a,0x7bc11ca9}},	//   feni_, ायचा_, मियो_, kblu, 
   {{0x69cd1caa,0x7e68002d,0x61e8062c,0x6d4c01e4}},	//   zace, enep, aggl, ŝbak, 
   {{0x69cd1cab,0x64a11cac,0x7bc00334,0x5f900137}},	//   yace, _цара, dblu, мишт, 
   {{0x6aa80429,0x11f80014,0x7e691cad,0x69cc0005}},	//   _ruff, _دورک_, gnep, xace, 
   {{0x20040163,0x69cd1cae,0x6aa8dad9,0xec68a2b6}},	//   beni_, vace, _suff, ирок_, 
   {{0x69cd1caf,0x3c7008b0,0x7bc40037,0x70440137}},	//   wace, ﻴﺎﺳﻰ_, _õhul, _بئرك, 
   {{0xdd8c00dd,0x6f6401e2,0x9980002b,0x00000000}},	//   _یوم_, _بهام, _taiś_, --, 
   {{0x6aa801bf,0x7e6802f0,0x7bc00254,0x80c00acd}},	//   _vuff, cnep, ablu, रीके, 
   {{0x7bc11cb0,0xed50d537,0x7c6401d5,0x2988009b}},	//   bblu, _تپش_, _کانل, рсно_, 
   {{0x6aa91cb1,0xa5b85b84,0x29080034,0x7bc001ab}},	//   _tuff, _enól, rwca_, cblu, 
   {{0x69cd1cb2,0x61e91cb3,0x00000000,0x00000000}},	//   pace, yggl, --, --, 
   {{0x44b4dccb,0xa5b8007b,0xddc40055,0x00000000}},	//   збас, _gnól, _āmūr, --, 
   {{0x9f4406af,0x00000000,0x00000000,0x00000000}},	// [1aa50] rgné_, --, --, --, 
   {{0x200418f7,0x7d1c003b,0xe3e00011,0x3cdc01f9}},	//   xeni_, åssi, ন্নব, _खिसे_, 
   {{0xb4f0009d,0x7e6803e0,0x00000000,0x00000000}},	//   _үүсч, ynep, --, --, 
   {{0x63b90934,0x7bc001e4,0x9268187f,0xddd800d7}},	//   _şund, zblu, орча_, kluš, 
   {{0x7bc01ef9,0x12d8009e,0x61e80267,0x7e68072b}},	//   yblu, _সহৃদ, rggl, vnep, 
   {{0x20040093,0x7bc00175,0x0fb400ce,0x00000000}},	//   ueni_, xblu, ुरगढ, --, 
   {{0x439401c0,0xe0cc01d9,0x2fd4007b,0x00000000}},	//   _хавс, رٲژ_, سويد_, --, 
   {{0x3cc80276,0x7e680793,0x622001ec,0x44f80327}},	//   блио_, unep, _تورە, _ཕྱོར_, 
   {{0x7bc00334,0xddd80427,0xd1083918,0x80c017ee}},	//   tblu, gluš, _وقفه_, रीखे, 
   {{0x20050f8d,0x7bc00cfe,0xc5d003d4,0xdef80024}},	//   qeni_, ublu, িলিপ, _выд_, 
   {{0x7bc0b7ad,0xa5b809c2,0x3b0848ab,0x7bc4000d}},	//   rblu, _anóm, щено_, _õhum, 
   {{0x7bc0002f,0x00000000,0x00000000,0x00000000}},	//   sblu, --, --, --, 
   {{0x7bc00334,0xe8991cb4,0xc838001f,0xe8f47676}},	//   pblu, çağı, _ያለምን, пля_, 
   {{0x3154008f,0xed8402d3,0x44f80327,0x7bc0025c}},	//   לירן_, _ምስባክ_, _ཕྱེར_, qblu, 
   {{0xec1026c0,0xbb44010b,0xf40403d4,0x00000000}},	//   _سويد, _хейк, ৰামৰ_, --, 
   {{0x27fc01a6,0xe9dc00c7,0x00000000,0x00000000}},	//   đuna_, yhúi_, --, --, 
   {{0xdb2000e5,0x00000000,0x00000000,0x00000000}},	// [1aa60] _روکی, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf62418ec,0x39411cb5,0x00000000,0x00000000}},	//   _едно, lyks_, --, --, 
   {{0xe2945e3e,0xade807f7,0xc2180037,0x00000000}},	//   пах_, _टाइन_, _नोआब_, --, 
   {{0xf77001d9,0xa13047e7,0xa4542d1c,0x21640a5b}},	//   _زاگ_, فروش, _çağı_, пици_, 
   {{0x3f840142,0xb4c80490,0x00000000,0x00000000}},	//   _bylu_, ोळी_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4cb80a93,0x7bc4000d,0x224401c7,0xe1f40108}},	//   олию_, _õhuj, ënkt_, _нгс_, 
   {{0x644112c5,0x00000000,0x00000000,0x00000000}},	//   önig, --, --, --, 
   {{0x09b40490,0x3e6800db,0x0ab4033a,0x00000000}},	//   ंड्य, йшөн_, мбоџ, --, 
   {{0x8f680014,0xfaec004b,0x00000000,0x00000000}},	//   _بلاے_, لګي_, --, --, 
   {{0xdb00015d,0xddd80064,0x00000000,0x00000000}},	//   _egnï, pluš, --, --, 
   {{0xdcf41060,0x58d41d56,0x00000000,0x00000000}},	//   _فروش_, ноят, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe3e000eb,0x00000000,0x00000000,0x00000000}},	//   ন্ডব, --, --, --, 
   {{0x44f80003,0xa49801e1,0x26dc0fcf,0x00000000}},	//   _ཕྱུར_, _asòp, čuo_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [1aa70] --, --, --, --, 
   {{0xe61c0042,0x987400c0,0x00000000,0x00000000}},	//   _chôr_, _плыц, --, --, 
   {{0xfd54002b,0x972400c0,0xd8b800e5,0x00000000}},	//   _dvaṃ, _зьяд, _ودیا_, --, 
   {{0x3cdc0c2e,0xfd540882,0xd37000f2,0x93941063}},	//   _खिले_, _evaṃ, دهٔ_, رجلا, 
   {{0x5634044e,0x3618011a,0x00000000,0x00000000}},	//   _ኣረኣእ, _וורד, --, --, 
   {{0xe7bc1bd6,0xc3280451,0x3f851cb6,0xade83d1d}},	//   ्रिप, _وڃان_, _pylu_, _टाउन_, 
   {{0xae1c38d2,0x80c007f7,0x00000000,0x00000000}},	//   _मोहन_, रीजे, --, --, 
   {{0xf40400fe,0x00000000,0x00000000,0x00000000}},	//   ৰাণৰ_, --, --, --, 
   {{0xe7bc0b9c,0x7bc400c5,0x8d2800fd,0x522400fd}},	//   ्राप, _õhuk, зның_, _яфра, 
   {{0xac94188d,0x9e651cb7,0x39400024,0x3f843d44}},	//   ونيا_, _کائن, vyks_, _tylu_, 
   {{0x225c0064,0x00000000,0x00000000,0x00000000}},	//   _kmuk_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb000789,0x9fcc015b,0xce3403e6,0x00000000}},	//   _igní, রলীগ, _سووک, --, 
   {{0xe3e0015b,0xfbd01ec7,0x311c00cd,0x3940376e}},	//   ন্তব, _شتت_, पितः_, ryks_, 
   {{0x81e47f53,0x225c1418,0x8da40092,0x94c800f1}},	//   ব্য_, _omuk_, _መሳተፍ_, ګازې_, 
   {{0x99800139,0xba740eff,0xfd540055,0x394000c0}},	//   _gaiş_, _تاتت, _svaṃ, pyks_, 
   {{0x33f40cc9,0x00000000,0x00000000,0x00000000}},	// [1aa80] дчес, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x63b8054e,0x00000000,0x00000000,0x00000000}},	//   _şunc, --, --, --, 
   {{0xdb0000c6,0x225c0419,0x998006be,0x00000000}},	//   _ngní, _cmuk_, _xaiş_, --, 
   {{0x3cf80456,0xfd54002b,0xc1a40150,0x00000000}},	//   ्बों_, _tvaṃ, нышқ, --, 
   {{0x44f81efe,0x225c0098,0xdd3c00a2,0x7bc40254}},	//   _ཕྱིར_, _emuk_, _iňňe, _õhuh, 
   {{0x25a80175,0x31e4009f,0x00000000,0x00000000}},	//   _ygcl_, _يسرّ, --, --, 
   {{0xe294005e,0x7c2c0198,0xae1c02ab,0xe3e00154}},	//   _жас_, _ɗare, _मोशन_, ন্দব, 
   {{0x216402bf,0x71a401c6,0xa5b8032e,0xb80c09ab}},	//   _жити_, _цааз, _snók, ाजाम_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x42f402dd,0x6d4403cd,0x79c41884,0x00000000}},	//   _ءﺩﺍﻝ_, økab, ﯩﻨﯩﻤ, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6da40124,0x9c5400c6,0x387001ec,0x00000000}},	//   _еиҵа, _يجوز_, лқыт, --, 
   {{0x442d1cb8,0x00000000,0x00000000,0x00000000}},	//   _đe_, --, --, --, 
   {{0x56951a49,0xe4c4023a,0x00000000,0x00000000}},	//   васт, дёжн, --, --, 
   {{0x7c3402d2,0x00000000,0x00000000,0x00000000}},	// [1aa90] _ígræ, --, --, --, 
   {{0x225c04ce,0xb4b400fd,0x00000000,0x00000000}},	//   _smuk_, хифә, --, --, 
   {{0xdb0002d2,0x636801c6,0x25a80051,0x7c2408a5}},	//   _ofný, цраг_, _tgcl_, _óhre, 
   {{0xe9dc000f,0xa5b8007b,0xd6d80212,0x00000000}},	//   chút_, _onói, _ють_, --, 
   {{0xc0e4005b,0x1ad800e1,0xd8743047,0xd17400ee}},	//   холк, _मट्ठ, _سایب, кышы, 
   {{0x3f140798,0x8cd844d0,0x3c7000d1,0x3e7c0240}},	//   еќит, _मिजो, ﻴﺎﺗﻰ_, _ኣባላታ_, 
   {{0xe9dd1cb9,0x2d8800d1,0x00000000,0x00000000}},	//   nhús_, ﻗﯩﻘﻰ_, --, --, 
   {{0x225c00f2,0x00000000,0x00000000,0x00000000}},	//   _umuk_, --, --, --, 
   {{0xbc1802dd,0x00000000,0x00000000,0x00000000}},	//   піні_, --, --, --, 
   {{0xfc3006d5,0x62891cba,0x60d80a07,0xe2100184}},	//   احة_, llgo, _ivum, _ямғы, 
   {{0x6288011c,0x506401ee,0x00000000,0x00000000}},	//   olgo, _ртта, --, --, 
   {{0xee2c4077,0xe9dc01a8,0x00000000,0x00000000}},	//   _ён_, dhús_, --, --, 
   {{0xed4d1cbb,0xa4980241,0x6288020c,0xec6d1cbc}},	//   _со_, _apòm, ilgo, _бп_, 
   {{0x60d91cbd,0x00000000,0x00000000,0x00000000}},	//   _mvum, --, --, --, 
   {{0x9f440268,0x941803e3,0x16840133,0x6ed023e9}},	//   ngnà_, _girə_, نارێ, णीपु, 
   {{0x60d91cbe,0x648801b8,0xbca401e2,0x00000000}},	//   _ovum, büik, _غمګي, --, 
   {{0x660010e0,0xa5041515,0x60d804ba,0x2c1003d4}},	// [1aaa0] ыпта, нета_, _nvum, ়াৰে_, 
   {{0x62891cbf,0x96d42cc8,0xe3340055,0x00000000}},	//   elgo, _исмә, _ṭādi, --, 
   {{0x6144002b,0xdb0401e3,0xf20401f4,0x00000000}},	//   _līlā, _ålän, еяло, --, 
   {{0x60d91cc0,0x2374413a,0x11691cc1,0x00000000}},	//   _bvum, رمند_, ولای_, --, 
   {{0xa1800b8d,0x6a680793,0x614400cd,0x7d1c005c}},	//   лышл, löfä, _nīlā, æssl, 
   {{0x60d800d2,0xa0a0009d,0x00000000,0x00000000}},	//   _dvum, гачд, --, --, 
   {{0x60d81cdf,0x62880165,0x00000000,0x00000000}},	//   _evum, blgo, --, --, 
   {{0x9df402e8,0xf1a802f2,0x00000000,0x00000000}},	//   енът_, _راره_, --, --, 
   {{0x90a4010b,0x31251cc2,0x941806be,0x00000000}},	//   _агаҗ, _ядаг, _sirə_, --, 
   {{0x46e01d15,0xa0640022,0x941806be,0x00000000}},	//   _फिलह, _зауа_, _pirə_, --, 
   {{0xdee031a8,0x60d8004c,0xe45408a8,0x9f9400c7}},	//   _бохи, _zvum, גייט_, _зыцә, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x92bc03d4,0x2eec007c,0x00000000,0x00000000}},	//   _ইটো_, luff_, --, --, 
   {{0x517c0020,0xdd8d1cc3,0xe9dc06ea,0x22a40248}},	//   _እናንተ_, _اوه_, thús_, _kìkì_, 
   {{0x45d51cc4,0xe9dc002d,0x3ea80419,0x00000000}},	//   ковс, uhús_, ňate_, --, 
   {{0xe9dc0ad9,0x89d800ec,0x00000000,0x00000000}},	//   rhús_, _کوکر_, --, --, 
   {{0xe9dc0321,0x22a40241,0x48c400c7,0x00000000}},	// [1aab0] shús_, _lìkì_, _шәна, --, 
   {{0x68ec058a,0x9418022e,0x2eec0162,0xb7ec00c5}},	//   mucd, нжут_, kuff_, _जाएम_, 
   {{0x28b449fc,0x68ec0014,0x60d91cc5,0x00000000}},	//   _इंडि, lucd, _svum, --, 
   {{0x2eed1cc6,0xb924063f,0x7bc40037,0x1fb80412}},	//   duff_, _nkwọ_, _õhuv, ॉर्ड, 
   {{0x527415eb,0x72a000d1,0xed44009f,0xd4b80153}},	//   دالز, شەكن, _ئپ_, _пляц_, 
   {{0xb92401f2,0xd77401ec,0x92080171,0xdd100419}},	//   _akwọ_, _جاۋع, _atāķ, túže, 
   {{0x4fc46b1a,0x42a40150,0x030400c5,0x00000000}},	//   усча, _ауағ, _रहिह_, --, 
   {{0xdb00007b,0x9f4405d5,0x622000db,0xcf24027d}},	//   _ngná, rgnà_, _حورە, اروي, 
   {{0x7c9406a6,0x6ba40213,0xc01402e8,0x00000000}},	//   кроц, əsgə, _имащ, --, 
   {{0x51849505,0x2eec032e,0x00000000,0x00000000}},	//   _суса, buff_, --, --, 
   {{0xa49801e1,0x2eec0076,0x5c0002dd,0x3df400d8}},	//   _apòk, cuff_, _ەكتە, _азес, 
   {{0xd910114f,0x00000000,0x00000000,0x00000000}},	//   میع_, --, --, --, 
   {{0x2d8001d3,0xb8642f84,0x22840254,0x00000000}},	//   üket_, ناسو, lõks_, --, 
   {{0xed5415ed,0xdb211cc7,0x63b800fd,0x00000000}},	//   _још_, _موتی, _şunn, --, 
   {{0x685836d7,0x58f40003,0xe1fc002e,0x00000000}},	//   _ሃገራት, _བདམས_, _ñów_, --, 
   {{0xe5f000a8,0x9b34009d,0xdeec1954,0x00000000}},	//   văţă, _жүүс_, ቀረና_, --, 
   {{0x35a401c6,0x48e80401,0xca54030d,0x00000000}},	// [1aac0] тааг, _जियो_, _сĕтп, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe5f00356,0x00000000,0x00000000,0x00000000}},	//   răţă, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x753408a5,0xaf040f06,0xa1900798,0x00000000}},	//   mxyz, вчик, јашч, --, 
   {{0x43751cc8,0x68ec0175,0x2d881870,0xe29c022e}},	//   _бутт, zucd, ﺗﯩﻨﻰ_, _вð_, 
   {{0x2eed1cc9,0x8e140166,0xcf1800db,0x00000000}},	//   ruff_, удиц, _ۋراچ_, --, 
   {{0x5ea000c6,0xd13000db,0x21a0010a,0x2eed1cca}},	//   جميل, _دۅش_, _витм, suff_, 
   {{0x2eec343a,0x28a80150,0x00000000,0x00000000}},	//   puff_, _ﺴﺎﺫﺠ, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x28b403f3,0x6b88017a,0x6fc80154,0x338c0150}},	//   _इंदि, _vyfg, _রায়ে, _ﺒﻭﻟﻲ_, 
   {{0x99651ccb,0xe61001d3,0x00000000,0x00000000}},	//   атрл, یشر_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9c1001f2,0x96f8008e,0x98a05160,0xcc8807d6}},	//   _kọnv, керт_, _grič_, _قنچه_, 
   {{0x69e435dd,0x9a84010a,0x04c800ae,0x00000000}},	//   _рюкз, _вуьл, فوري_, --, 
   {{0x9a680f13,0xe3b0009f,0x4498005b,0x00000000}},	// [1aad0] _جميل_, لرض_, еваю_, --, 
   {{0xa5b8e0ff,0x7bc400af,0x54543981,0x68e000b8}},	//   _anót, _õhut, авут, _āndh, 
   {{0x752402d0,0x48c40022,0xd7f801ec,0xa280e0d7}},	//   _erkz, _шәҽа, _руы_, لیسو, 
   {{0xe45c04f3,0x270c00e1,0x4154189d,0x1fcc00eb}},	//   _stöd_, ाबीर_, лвес, _রাইস, 
   {{0xb9fc0092,0x33d402dd,0x11d40345,0x11e401ec}},	//   _ሆድ_, _ﺟﯘﺭﻣ, شتند, ржім, 
   {{0xe3c003ee,0x44fd1ccc,0xa49002f2,0x00000000}},	//   _тıк_, mì_, _ئیئت, --, 
   {{0x5334b6cb,0x93891ccd,0x44fd1cce,0xaed00063}},	//   _керт, _аста_, lì_, бојш, 
   {{0xa5b800c6,0x78a0011c,0xe7e000cd,0x00000000}},	//   _gnót, _èovv, कृता_, --, 
   {{0x62980270,0x306800f1,0xc1740108,0x1ee4032f}},	//   _ihuo, _ګټلی_, _слащ, روکی_, 
   {{0xec740dd8,0x909800a8,0x98a00427,0x6454004d}},	//   лпы_, _авут_, _prič_, nhxi, 
   {{0xac8001c0,0x6298004d,0x7654023a,0x00000000}},	//   сгэл, _khuo, yhyy, --, 
   {{0x63b91ccf,0x81e4015b,0xa5b8033f,0xd9780116}},	//   _şunl, ব্র_, _mnós, вргә_, 
   {{0x753400c6,0xfce51cd0,0x7e68007c,0x3ce802d2}},	//   xxyz, _соло, miep, _íav_, 
   {{0x44fd1cd1,0x7e6802d5,0x0b900023,0x00000000}},	//   dì_, liep, _ማሕዩር_, --, 
   {{0xcfd803f4,0x629833f6,0x64540014,0x8b9400a7}},	//   _সামন, _ohuo, dhxi, _кръч, 
   {{0xba74005e,0x64411cd2,0x6298004d,0x24680153}},	//   _حاتت, önin, _nhuo, _lėmė_, 
   {{0x44fd1cd3,0x7bc400c5,0x7994033f,0x00000000}},	// [1aae0] gì_, _õhus, _uzyw, --, 
   {{0x629802b5,0x7e691cd4,0x00000000,0x00000000}},	//   _ahuo, hiep, --, --, 
   {{0xb190723c,0x91d005f9,0x7e691cd5,0xf7451cd6}},	//   әллә, दरलै, kiep, _сено, 
   {{0x62991cd7,0x7e691cd8,0x0f341046,0xc0c80092}},	//   _chuo, jiep, یکاد, አለሁ_, 
   {{0xf7704d4e,0x629801ab,0x44fc026c,0xae1c0037}},	//   _خاک_, _dhuo, cì_, _मोगन_, 
   {{0xdfcc00c6,0xe45c00a2,0x61400063,0xd01007d6}},	//   كيه_, _etöb_, сеља, زلب_, 
   {{0x23240166,0x246800c0,0x00000000,0x00000000}},	//   _йори_, _dėmė_, --, --, 
   {{0x629801ab,0x7e682305,0x73e408ca,0xe4600241}},	//   _ghuo, giep, _шоҳз, _ìmò̟, 
   {{0xad2403e6,0xa49800a3,0xa5b80162,0xeca40798}},	//   اربو, _spòi, _knór, лјон, 
   {{0xa0a000d8,0xc1740166,0x3eb801ef,0x00000000}},	//   _гауд, _әҗә_, _čstv_, --, 
   {{0x44fc026c,0xabb00075,0x2030004b,0x00000000}},	//   zì_, _һалә, _دفلس, --, 
   {{0x78b4022e,0x6f185ad0,0x3cdc05dc,0x7e691cd9}},	//   _buyv, _istc, _खिचे_, ciep, 
   {{0x9f480793,0xa5b800ae,0xa3d40037,0x2d9001e1}},	//   älön_, _onór, सरम_, _áye_, 
   {{0x44fc3c9b,0x3cf00122,0x6fc802ab,0x78b4c50b}},	//   vì_, ňový_, _स्मू, _duyv, 
   {{0x96e8c134,0xe8fc002d,0xfca81541,0x26045889}},	//   льта_, stû_, _شاهو_, лчаг, 
   {{0x7bc40037,0x00000000,0x00000000,0x00000000}},	//   _õhur, --, --, --, 
   {{0xddd8012c,0xb8e804c5,0x27fc0198,0x5694a74b}},	// [1aaf0] nouš, _লয়_, ƙun_, сатт, 
   {{0x44fd1cda,0x7d1c04ce,0x291803f0,0xe4a51cdb}},	//   rì_, æssi, _isqa_, урбо, 
   {{0x44fd1cdc,0x6298001e,0xe3140046,0x77b8011a}},	//   sì_, _phuo, _ءﺑﯩﺮ, _במתח, 
   {{0xb5f00220,0x44fd1cdd,0xddd800bc,0x1af4008f}},	//   _мүсі, pì_, kouš, רמאל_, 
   {{0x6f191cde,0x7e691cdf,0xb61c0150,0x00000000}},	//   _astc, viep, _ﺤﺔ_, --, 
   {{0xa49800e4,0x6488381a,0xddd8013a,0x00000000}},	//   _apòv, güit, douš, --, 
   {{0x7e68257d,0x62980016,0x26d00014,0x2ab800e8}},	//   tiep, _thuo, _jwxo_, _nëb_, 
   {{0xa26406bb,0xfe440261,0x4420aea6,0x00000000}},	//   _съгл, рнио, ldh_, --, 
   {{0xee351ce0,0x44200013,0x61f91ce1,0x6f191ce2}},	//   рны_, odh_, _icul, _estc, 
   {{0x4420006d,0x7e691ce3,0xbc6413f3,0x3c640fac}},	//   ndh_, siep, рвок, рког, 
   {{0x44208ad6,0x291803f0,0xbf1435e6,0x7e691ce4}},	//   idh_, _asqa_, _خواب, piep, 
   {{0x44211ce5,0x2cac01ab,0x8f44034b,0x00000000}},	//   hdh_, _eifd_, _ухуд, --, 
   {{0x44311ce6,0x98a004fe,0x8e840597,0x61f82798}},	//   _onz_, _ariā_, _النه, _mcul, 
   {{0x3b080022,0x6f1802d0,0x00000000,0x00000000}},	//   _аеко_, _ystc, --, --, 
   {{0x61f91ce7,0x5ae002dd,0x26d0058a,0x0bf400cf}},	//   _ocul, _اقبە, _cwxo_, _ايىڭ, 
   {{0x44311ce8,0x78b40455,0xa5b80162,0x73346f51}},	//   _anz_, _tuyv, _snór, یرائ, 
   {{0xa68002dd,0x00000000,0x00000000,0x00000000}},	// [1ab00] ілуд, --, --, --, 
   {{0xe45426d7,0x442001f5,0x3cec00d8,0xd5c400ef}},	//   ажу_, gdh_, irev_, drāž_, 
   {{0x443005be,0xddd8012c,0x3a304e1b,0xc5fc0154}},	//   _dnz_, dluž, _knyp_, ুয়া_, 
   {{0x44203c65,0x44311ce9,0x224c003e,0x31242309}},	//   adh_, _enz_, gkgk_, идег, 
   {{0x7c20074d,0x31144b59,0x753401c0,0x64891cea}},	//   kdlr, рфес, _тэнх, güis, 
   {{0x3ced1ceb,0x61f91cec,0x44300036,0x442001c3}},	//   drev_, _ecul, _gnz_, cdh_, 
   {{0xa2e057a8,0x777c0477,0x00000000,0x00000000}},	//   _морд, _jxpx, --, --, 
   {{0x5ea001ec,0x443001c8,0x2ab800e8,0x99500030}},	//   يمول, _znz_, _rëb_, pĺňa_, 
   {{0xdd94ceac,0x3cec23ee,0x6fc817c6,0x777c0353}},	//   ишь_, grev_, _स्थू, _lxpx, 
   {{0xddd80118,0x00000000,0x00000000,0x00000000}},	//   rouš, --, --, --, 
   {{0xa3d42017,0x6f191ced,0xfee83a16,0xee3823c5}},	//   सरत_, _ustc, _معنى_, _инж_, 
   {{0x3cec51dc,0xaa645e7a,0xddd8012c,0x6fc809fa}},	//   brev_, рток, pouš, _स्तू, 
   {{0x44200014,0x2a6800a3,0x6da4074d,0x00000000}},	//   ydh_, ricb_, _тида, --, 
   {{0xdca0026a,0x7bc400c5,0x2ab800e8,0x00000000}},	//   _дачи, _õhup, _tëb_, --, 
   {{0x644001f4,0x00000000,0x00000000,0x00000000}},	//   önim, --, --, --, 
   {{0x4a740050,0x00000000,0x00000000,0x00000000}},	//   _دُبر, --, --, --, 
   {{0x29180309,0xa49802bd,0x44300010,0x7eb40153}},	// [1ab10] _usqa_, _opòt, _pnz_, _išpe, 
   {{0x61f91cee,0xaa8402d2,0x4420058a,0x00000000}},	//   _scul, _flýð, udh_, --, 
   {{0xa6a86bd8,0x44200023,0x44308f13,0x00000000}},	//   _لاحق_, rdh_, _vnz_, --, 
   {{0x4430005c,0x73880131,0x30a40014,0xa6e003b2}},	//   _wnz_, уруң_, ۅلنہ, óðup, 
   {{0xe4a40261,0x4420045a,0x09e000eb,0x00000000}},	//   _врво, pdh_, ভলপা, --, 
   {{0x320405da,0x94d40262,0x048802dd,0x00000000}},	//   afoy_, _форц, _сәби_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x61f85b5d,0xa498007f,0x00000000,0x00000000}},	//   _ucul, _epòt, --, --, 
   {{0x3dcc0327,0x41540024,0x00000000,0x00000000}},	//   rbew_, _увас, --, --, 
   {{0x3a311cef,0xa3d402c3,0xddd8031c,0x00000000}},	//   _snyp_, सरि_, lluż, --, 
   {{0x3ced1cf0,0x3b080640,0x200446aa,0x00000000}},	//   srev_, ћемо_, mfni_, --, 
   {{0x3ced1cf1,0x75f001a9,0x3d940798,0xe61c0208}},	//   prev_, _nаzа, _лиер, _thôy_, 
   {{0xa3d4d589,0xb4d400c5,0x00000000,0x00000000}},	//   सरा_, _सबे_, --, --, 
   {{0xf7442add,0xa5b803b2,0x8cb40014,0x200401a9}},	//   бего, _snóp, _گۯیس_, nfni_, 
   {{0xfaa51cf2,0xddd8003d,0x998000b0,0x2004022f}},	//   _лако, kluż, _kaiū_, ifni_, 
   {{0x7bc01fe8,0x00000000,0x00000000,0x00000000}},	//   lclu, --, --, --, 
   {{0xe5a11cf3,0x387800d8,0x9ba01411,0x00000000}},	// [1ab20] зити, _tjpr_, _دەگى, --, 
   {{0xc8b4179e,0x2eec03cb,0x00000000,0x00000000}},	//   _گلیک, yrff_, --, --, 
   {{0xa49856ed,0x7ae00286,0xd5440241,0x8afc033f}},	//   _apòs, nslt, _bẹ̀m, rzęg, 
   {{0x20040008,0xa498033b,0xc8b400f1,0x00000000}},	//   efni_, _spòt, _دلیک, --, 
   {{0x7bc08fa2,0xceb80393,0x1fcc015b,0x4fc402dd}},	//   kclu, _suę_, _রাজস, ұсқа, 
   {{0x764400c7,0x8f3400a7,0xc76441c3,0x200401ab}},	//   _hoky, жекц, _داۋى, gfni_, 
   {{0xb8d81b4b,0x764402d5,0x7bc01cf1,0xceb816b8}},	//   _ཅང_, _koky, dclu, _quę_, 
   {{0x7644cb5b,0x6a6c0100,0x7bc00381,0x48e807f7}},	//   _joky, _mòfè, eclu, _जिलो_, 
   {{0x76440953,0xafe40209,0x7ae0030a,0x68ec0175}},	//   _moky, _гозл, eslt, xrcd, 
   {{0xb4d4038e,0xceb8003a,0x7bc001f5,0xa1540375}},	//   _सबै_, _tuę_, gclu, _הבמה_, 
   {{0x2f5405f5,0x764402d0,0x802400f2,0x00000000}},	//   _утас, _ooky, _برقم, --, 
   {{0x76446637,0x9f480fac,0x00000000,0x00000000}},	//   _noky, ålån_, --, --, 
   {{0x6440049f,0x7d1c01bf,0x7bc000d7,0x29840124}},	//   önik, æsst, bclu, сынг, 
   {{0x7bc002d0,0x6e2001ab,0x9d9401f7,0xa8500139}},	//   cclu, _haob, _انهئ_, чегә, 
   {{0x76440280,0x6e20003e,0x9ba800e2,0x00000000}},	//   _boky, _kaob, _žāvē, --, 
   {{0x8afc068f,0x6e211cf4,0x2b9000e5,0x00000000}},	//   rzęd, _jaob, _ویکس, --, 
   {{0xe9dc0270,0x6e211323,0x7644ffd2,0x95c81f39}},	// [1ab30] maú_, _maob, _doky, суса_, 
   {{0xa4980ba1,0xe9dc0418,0xa3a40b3e,0xa6e003b2}},	//   _apòr, laú_, бјек, óðsp, 
   {{0xa23000fd,0x200401a9,0x00000000,0x00000000}},	//   зьлә, vfni_, --, --, 
   {{0x09ac03f4,0x6e211cf5,0xe9dc1132,0xd1b80035}},	//   _ক্যা, _naob, naú_, ماها_, 
   {{0x7bc0508f,0xf40400fe,0x00000000,0x00000000}},	//   yclu, ৰাজৰ_, --, --, 
   {{0x7bc00175,0x7ff424c5,0x6e200334,0xd8dc0a1e}},	//   xclu, زستا, _aaob, נקור, 
   {{0xe9dc03a0,0x764519fb,0x2004022e,0xd54401e1}},	//   kaú_, _yoky, rfni_, _tẹ̀m, 
   {{0x64440a4d,0x6e211cf6,0xe9dc0798,0x9258005a}},	//   _hoji, _caob, jaú_, _ласт_, 
   {{0x64440b91,0x62891cf7,0x6e201db0,0x00000000}},	//   _koji, mogo, _daob, --, 
   {{0x62891cf8,0x3d08028a,0x99801e0d,0x6d44023a}},	//   logo, _वहीं_, _waiū_, äkaa, 
   {{0x7bc11cf9,0x3b08355b,0xbb451cfa,0x6e211cfb}},	//   rclu, шено_, ценк, _faob, 
   {{0x62891cfc,0x64451cfd,0xbc381d10,0x00000000}},	//   nogo, _loji, اسکا_, --, 
   {{0xe8f51cfe,0x7bc03b4d,0x644400b5,0xec6c00a7}},	//   оля_, pclu, _ooji, _жп_, 
   {{0x62891cff,0x6e201c75,0x64446394,0x76451d00}},	//   hogo, _zaob, _noji, _soky, 
   {{0x76451d01,0x62891d02,0xe9dc00d8,0xf624009b}},	//   _poky, kogo, baú_, одво, 
   {{0x644404ce,0x62891d03,0x3d1c012c,0x00000000}},	//   _aoji, jogo, _भनाइ_, --, 
   {{0x64441050,0x62891d04,0xfa3400f2,0x0b901ef7}},	// [1ab40] _boji, dogo, _هرکد, _ማሕደር_, 
   {{0x64451d05,0x22280b43,0x7644016b,0xa4980192}},	//   _coji, یزنی_, _woky, _spòr, 
   {{0x764407ad,0x760807d6,0x62887cb5,0xd37000d1}},	//   _toky, _кенг_, fogo, رۇر_, 
   {{0x7afc006d,0x6b7800c8,0x6b8c07de,0xfe7801ef}},	//   ństw, ברענ, übgi, jnů_, 
   {{0x6e209ef6,0x6444036b,0xfe78012c,0x00000000}},	//   _raob, _foji, dnů_, --, 
   {{0x6e20b485,0x94c800aa,0x64451d06,0xa1240137}},	//   _saob, _پاڼې_, _goji, زكىل_, 
   {{0x62891d07,0x00000000,0x00000000,0x00000000}},	//   bogo, --, --, --, 
   {{0x62881099,0xfe7801ef,0x00000000,0x00000000}},	//   cogo, gnů_, --, --, 
   {{0x6e20006f,0xafe40276,0x998000bc,0x041c0154}},	//   _vaob, _моал, _aniž_, নারী_, 
   {{0xaf351d08,0xa110313e,0xa0646518,0x644401a9}},	//   _ورات, _توكت, _дауа_, _xoji, 
   {{0x6e200ea3,0xe9dc0093,0xc0f802d3,0x62800129}},	//   _taob, taú_, ፈጥረ_, énog, 
   {{0x7c2c02a8,0x00000000,0x00000000,0x00000000}},	//   _ɗari, --, --, --, 
   {{0xd91000dd,0x7eb40006,0xe9dc00d8,0x58d4013e}},	//   نیٹ_, _išpa, raú_, моят, 
   {{0xf8ac0272,0x62891d09,0x8afc033f,0x92a00150}},	//   ێکی_, zogo, rzęb, _ﻀﻌﻴﻑ_, 
   {{0x64451d0a,0xe9dc0270,0x00000000,0x00000000}},	//   _roji, paú_, --, --, 
   {{0x644423db,0x163439b0,0x62881709,0x7e8000b0}},	//   _soji, меся, xogo, pēpe, 
   {{0x64440316,0x05940214,0xa3d40406,0x00000000}},	// [1ab50] _poji, سارگ, सरल_, --, 
   {{0x8afc0034,0xd49801c0,0x62880337,0x00000000}},	//   częc, орх_, wogo, --, 
   {{0x88bc03d4,0x64451d0b,0xdc9c00b5,0x041c0011}},	//   _অবিক, _voji, _ds版_, নালী_, 
   {{0x64444520,0xd37000f2,0x00000000,0x00000000}},	//   _woji, خهٔ_, --, --, 
   {{0x55040598,0x644407d6,0x63b800ee,0xd1b8e969}},	//   _очра, _toji, _şunu, زانا_, 
   {{0x62880925,0x1be80034,0xff24004e,0xa088013d}},	//   sogo, _फ़ाइल_, змко, шсез_, 
   {{0x6d451d0c,0x3f800784,0xa2a811a6,0xe1f000ae}},	//   äkan, çhu_, जगद्, _يسر_, 
   {{0x5214026a,0x577c00df,0xdb200248,0x00000000}},	//   _одст, יטוצ, _òrér, --, 
   {{0xc0f80020,0x5fcc61ef,0x28b41d8a,0x00000000}},	//   ፈጥሮ_, _स्थल, _इंगि, --, 
   {{0xcfe800ae,0x00000000,0x00000000,0x00000000}},	//   _وفقه_, --, --, --, 
   {{0xdce40365,0x2d90143a,0x00000000,0x00000000}},	//   ğlık, _øyen_, --, --, 
   {{0xc86806a9,0xdce4a493,0xb9f805ac,0xd91016d0}},	//   _גן_, şlık, ইজ্ড_, نیع_, 
   {{0x3cc8010a,0x00000000,0x00000000,0x00000000}},	//   _улло_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x81e01aba,0xf7440cc9,0x6d440158,0xe9dd1d0d}},	//   _দান_, чево, økav, rkúr_, 
   {{0x98a00b4b,0xdc9c00b5,0xe6403cc5,0x00000000}},	//   _orić_, _ss版_, несп, --, 
   {{0xcaa47ae6,0x14c8034c,0xa3d4041c,0x94c801e2}},	// [1ab60] _تصوي, زهای_, सरं_, تازې_, 
   {{0x3ddc002e,0x00000000,0x00000000,0x00000000}},	//   _leww_, --, --, --, 
   {{0xf77001d9,0x67b8011a,0xda200037,0x00000000}},	//   _ساد_, _למיק, _बसात_, --, 
   {{0xf12402bf,0xcfd8015b,0xc0ec0092,0x00000000}},	//   зько, _সাইন, ሀለሁ_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x09d807b6,0xa3d400cd,0x765401f4,0x00000000}},	//   _भज्य, सरः_, lkyy, --, 
   {{0x64a11056,0x63801614,0xc32c7a32,0x98a00cf4}},	//   _чара, _згра, _پەن_, _erić_, 
   {{0x7654023a,0x00000000,0x00000000,0x00000000}},	//   nkyy, --, --, --, 
   {{0x200c00d7,0x00000000,0x00000000,0x00000000}},	//   ílií_, --, --, --, 
   {{0xa1100a2c,0xafe4009d,0xdd9c0419,0x00000000}},	//   _سومت, _хожл, áňam_, --, 
   {{0x7654105c,0x2f5401d5,0x00000000,0x00000000}},	//   kkyy, _этас, --, --, 
   {{0xbb5c00b5,0xe398011a,0x00000000,0x00000000}},	//   ftyゲ_, משיכ, --, --, 
   {{0x81e009bd,0x5b100046,0x5a3400a7,0x7eb401a6}},	//   _দাম_, _үміт, хнят, _ušpa, 
   {{0x7b0402f6,0xd2440133,0x00000000,0x00000000}},	//   öttö, _ڵۆ_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2fdc07de,0xdbd80248,0xd6b402e8,0x00000000}},	//   _letg_, _láìd, ейсъ, --, 
   {{0x28b406ab,0xe97001d3,0x44b400f3,0xdb200cad}},	// [1ab70] _इंटि, _سندھ, дбас, _àròs, 
   {{0x69dc036e,0x00000000,0x00000000,0x00000000}},	//   _heqe, --, --, --, 
   {{0x27e000c8,0x3ac400b0,0x2c0c0490,0x69dc0023}},	//   majn_, _kēpa_, त्यू_, _keqe, 
   {{0x27e11d0e,0x2fdc0005,0x97a51d0f,0x660c0051}},	//   lajn_, _aetg_, _ярыл, _ubck, 
   {{0x2fdc1675,0x69dc102c,0x92b4a012,0x3ddc002e}},	//   _betg_, _meqe, رحما, _reww_, 
   {{0x69dc0831,0x27e000c8,0xcfd80154,0x00000000}},	//   _leqe, najn_, _সাউন, --, 
   {{0x2d800a85,0xe3b01698,0x2fdc1570,0xb3441432}},	//   ûken_, _سرس_, _detg_, rkçü, 
   {{0x69dc753a,0x7c2c02a8,0xd7380375,0x27e001e4}},	//   _neqe, _ɗaru, לטות_, hajn_, 
   {{0x2fdc060a,0x27e000c8,0x21280036,0x09ac00cc}},	//   _fetg_, kajn_, _éch_, _ক্সা, 
   {{0x60d801f0,0x2fdc0c86,0x27e11d10,0x00000000}},	//   _iwum, _getg_, jajn_, --, 
   {{0xac800323,0x69dc0944,0x28b4073d,0x625000d8}},	//   тгэл, _beqe, _इंजि, _açoi, 
   {{0x7c64021a,0x60d801b2,0x3ea80428,0x2d8c0521}},	//   _ښاغل, _kwum, _òat_, ịlị_, 
   {{0xdbd801e1,0x27e0010f,0xa3bc1100,0x00000000}},	//   _háíd, fajn_, ीडा_, --, 
   {{0x60d801b2,0xed1400dd,0x27e0008f,0xc8b4e9b5}},	//   _mwum, _کہیں_, gajn_, ессы, 
   {{0x7d091d11,0x8cac012d,0x00000000,0x00000000}},	//   ltes, ुआरो, --, --, 
   {{0x60d91d12,0x7d091d13,0x61440055,0x00000000}},	//   _owum, otes, _kūlā, --, 
   {{0xa8211d14,0xa50464b3,0x7d090a2d,0x60d8013f}},	// [1ab80] رکین, мета_, ntes, _nwum, 
   {{0x69dc0944,0x7d091d15,0x27e0010f,0x95b405a2}},	//   _zeqe, ites, cajn_, _үрмә, 
   {{0x7d091d16,0x69dc0944,0x60d91d17,0xdb000077}},	//   htes, _yeqe, _awum, _ignó, 
   {{0x7d091d18,0x60d80230,0x2fdd042e,0x592c0327}},	//   ktes, _bwum, _setg_, _སློས_, 
   {{0x7d0802d3,0x2fdc07c5,0xa284001f,0xa1803e1f}},	//   jtes, _petg_, ሜሪካን_, кышл, 
   {{0x60d8013b,0xdfcc16a2,0x74151d19,0x68f800db}},	//   _dwum, ليه_, _توسا, àudi, 
   {{0x60d91d1a,0x7eb00124,0x7d08d734,0xce9402e8}},	//   _ewum, _ẽpap, etes, накъ, 
   {{0x27e11d1b,0x7e8000b0,0x00000000,0x00000000}},	//   zajn_, tēpa, --, --, 
   {{0x7eb40006,0x2fdc0c86,0x5fcc00dc,0x7d091d1c}},	//   _išpl, _tetg_, _स्वल, gtes, 
   {{0x69dcb708,0x592c0327,0xdb0000ae,0x00000000}},	//   _seqe, _སླེས_, _ngnó, --, 
   {{0x27e000c8,0x5f000588,0x69dc0477,0x7d091d1d}},	//   vajn_, _азха, _peqe, ates, 
   {{0x69dd1d1e,0x7d091d1f,0x6d440158,0x60e400fd}},	//   _qeqe, btes, økas, _ärmä, 
   {{0x7d091d20,0x27e004ac,0x00000000,0x00000000}},	//   ctes, tajn_, --, --, 
   {{0x69dd1d21,0x3164005a,0x00000000,0x00000000}},	//   _weqe, izoz_, --, --, 
   {{0x27e11d22,0x69dd1d23,0x3ac402b5,0xeabc0354}},	//   rajn_, _teqe, _tēpa_, _тιе_, 
   {{0x27e0008f,0x8da40240,0x00000000,0x00000000}},	//   sajn_, _ዘሳትፍ_, --, --, 
   {{0xd7d11d24,0x569489a7,0x1fa80146,0x28a400f7}},	// [1ab90] _त्वच, татт, _चण्ड, _ошог, 
   {{0x60d80189,0x9f4407c5,0x37e00154,0x27e00135}},	//   _rwum, tgnü_, _বাথর, qajn_, 
   {{0x7d08a57b,0xf8b00a1e,0xd404005b,0xe970211f}},	//   ztes, _תשי_, ъяти, _سنگھ, 
   {{0x29080998,0x7d091d25,0xd3a43576,0x9f4404cc}},	//   otca_, ytes, труп, rgnü_, 
   {{0x3d1c012c,0x7ea400e4,0x6440000d,0x00000000}},	//   _भनें_, nópe, önis, --, 
   {{0x7a340724,0xb77401d3,0x7d08007c,0x00000000}},	//   _kütä, _آئیڈ, vtes, --, 
   {{0x7d080036,0x7998012d,0x00000000,0x00000000}},	//   wtes, ętwi, --, --, 
   {{0x60d91d26,0x7ea400e4,0x6e900114,0x00000000}},	//   _twum, kópe, лију, --, 
   {{0x6fc837f3,0x225c08cd,0x60d91d27,0x7d080108}},	//   _स्कू, _iluk_, _uwum, utes, 
   {{0x041c03d4,0x7d091d28,0xdb0005d5,0xac8022bf}},	//   নাকী_, rtes, _tgnü, лгыл, 
   {{0x09ac11ba,0x7d091d29,0xf410010f,0x225d1d2a}},	//   _ক্লা, stes, נפט_, _kluk_, 
   {{0xfb340323,0x6144f4b4,0x0e6401af,0xdb2001e1}},	//   _үндэ, _tūlā, _икєн, _òrír, 
   {{0x3ead1d2b,0x00000000,0x00000000,0x00000000}},	//   mmet_, --, --, --, 
   {{0x3ead1d2c,0x225c0548,0x7a34008e,0x1bf0000d}},	//   lmet_, _lluk_, _bütä, _आयिल_, 
   {{0x601047af,0xaac4012a,0x225c0205,0xeb94022e}},	//   mımı, _रूपक, _oluk_, _пиш_, 
   {{0xe61c01f1,0x601071e1,0x3ead06a6,0x47dc03d4}},	//   _skôr_, lımı, nmet_, বলগী, 
   {{0x33f4efc7,0x3eacdf4c,0xdbd801e1,0xe8f40153}},	// [1aba0] ечес, imet_, _káàd, _злы_, 
   {{0x3eac8eab,0x601007c4,0x225c003e,0xbfb000cd}},	//   hmet_, nımı, _aluk_, _kṣīy, 
   {{0xc8880979,0x225c0c6a,0xddd800f3,0x3eac05d2}},	//   _تخيل_, _bluk_, douž, kmet_, 
   {{0x3eac044e,0x6b645f15,0x31641529,0x786001f1}},	//   jmet_, _hégé, tzoz_, _dôve, 
   {{0x6458066d,0x3ead1d2d,0x601003ee,0x00000000}},	//   áció, dmet_, kımı, --, 
   {{0xe4d51d2e,0x225d1d2f,0xe1340006,0x7a340139}},	//   _سوفت_, _eluk_, эзіі_, _yütä, 
   {{0x5f90c846,0xda200c2e,0x62500798,0x60103535}},	//   лишт, _बसंत_, _açou, dımı, 
   {{0x6b650ac7,0xa344013d,0xe2945dbe,0x00000000}},	//   _légé, _язса_, _зас_, --, 
   {{0x6010cdfe,0xd1300050,0x70841fbe,0xf150104c}},	//   fımı, _خۅش_, _згаз, _حکاک, 
   {{0x5d1052c8,0x3ead1d30,0x60100342,0x00000000}},	//   ابيز, amet_, gımı, --, 
   {{0xd1d00020,0xd1e8001f,0x8afc033f,0x5c70013d}},	//   _ጥራት_, _ሚስት_, częl, улэт, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x752401a6,0xfda40022,0x60101b0d,0x7a340166}},	//   _nskz, _иышҟ, bımı, _sütä, 
   {{0x6010029f,0x245c00c7,0x98480276,0xdb8001c6}},	//   cımı, _oîma_, няса_, _өгчи, 
   {{0x81e02158,0x6b644e01,0xa09808a8,0x7a340139}},	//   _দাস_, _dégé, פילט, _qütä, 
   {{0x7860002d,0x7ea40022,0x9f94011a,0x00000000}},	//   _rôve, pópe, גדלה_, --, 
   {{0x59d40597,0x6d4401f4,0x00000000,0x00000000}},	// [1abb0] _صغير, äkah, --, --, 
   {{0x3eac0365,0x225d1d31,0xdbd801e1,0x9968008f}},	//   zmet_, _sluk_, _káád, _נייַ_, 
   {{0x225d1d32,0xb1cc063f,0x3eac15b7,0x925801d5}},	//   _pluk_, _ịrịa_, ymet_, کشلر_, 
   {{0x41b51d33,0x601006b9,0x81e002f5,0x41540064}},	//   نمار, zımı, _দাহ_, квес, 
   {{0x9980009b,0x60103535,0xc0c40131,0xddd80118}},	//   _kaiš_, yımı, тәби, touž, 
   {{0x601000ac,0xe3b00214,0x3eac0327,0x00000000}},	//   xımı, _مرز_, wmet_, --, 
   {{0x41c401d9,0x3eaca986,0x7524045a,0xddd80118}},	//   _لٲزِ, tmet_, _zskz, rouž, 
   {{0x3eb91d34,0x225c8616,0x3eac067c,0x69d00709}},	//   öst_, _uluk_, umet_, भुमी, 
   {{0x3ead1d35,0x60104a4a,0xddd80122,0x80b400c7}},	//   rmet_, tımı, použ, _абах, 
   {{0x09e02f04,0xc68c001f,0x4c842123,0xec7400cf}},	//   _ভাষা, _መኖሪያ_, лкың, кпы_, 
   {{0x6fc81533,0x60100baf,0x6b64908d,0x5064004e}},	//   _स्टू, rımı, _régé, _стта, 
   {{0x60100ab5,0x24640241,0x3eac0200,0xfbd000f2}},	//   sımı, _yímù_, qmet_, دتک_, 
   {{0x6010083c,0x2c500023,0xb7e4012d,0x00000000}},	//   pımı, _ዝፈጸም, _क़दम_, --, 
   {{0x3154008f,0xefd00092,0x00000000,0x00000000}},	//   דישן_, _የዕዳ_, --, --, 
   {{0x6b651d36,0x66e0030d,0xd1e80092,0x00000000}},	//   _végé, иора, _ሚስቱ_, --, 
   {{0xba740eff,0x86980108,0x00000000,0x00000000}},	//   _جاتت, етут_, --, --, 
   {{0xd04011a9,0x6b64020c,0xe4c00408,0xe7d000fd}},	// [1abc0] _etmə, _tégé, ийти, _äfğä, 
   {{0x6d441577,0x00000000,0x00000000,0x00000000}},	//   äkai, --, --, --, 
   {{0x281004d3,0xd7d400c7,0x00000000,0x00000000}},	//   _ڵوێس, _ицҟь, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x81e00154,0x00000000,0x00000000,0x00000000}},	//   _দাশ_, --, --, --, 
   {{0xa0a001c0,0xaf5000d1,0x00000000,0x00000000}},	//   аачд, инлә, --, --, 
   {{0xeea8001b,0xe3b41188,0x00000000,0x00000000}},	//   мтик_, _абр_, --, --, 
   {{0xdce803ee,0x10280451,0x63a022d9,0x00000000}},	//   _azgı, _ڳڻتي_, ünne, --, 
   {{0xf428031c,0xc2900214,0x00000000,0x00000000}},	//   _ྤྲོད_, _اینب, --, --, 
   {{0x705003e6,0x00000000,0x00000000,0x00000000}},	//   _خۆتا, --, --, --, 
   {{0xc1c801d9,0xddd8002e,0xe454010f,0x9c40039e}},	//   _آبہٕ_, kkuň, דייט_, рхыл, 
   {{0x7f7405f5,0xfee800c6,0x7af401d3,0x0b44010b}},	//   _сууц, _أعلى_, ázta, внүн, 
   {{0x29851d37,0xa054010e,0x995000d7,0x00000000}},	//   тынг, _öňýa, túša_, --, 
   {{0xabb000fd,0x6ec8012d,0x7ea512fe,0x00000000}},	//   _калә, _zęba, mópa, --, 
   {{0xdb4cdba2,0x2604bae0,0x995000d7,0x00000000}},	//   _тю_, кчаг, rúša_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa50434d8,0x95c81768,0x84140c82,0x00000000}},	// [1abd0] ъявл, туса_, лмах, --, 
   {{0x47dc0729,0x47d400b2,0x6488005f,0x2918014f}},	//   _বাকী, _حيدر, kļie, _ipqa_, 
   {{0x26c4006a,0x43746e0c,0x7d080240,0xd498009d}},	//   _îno_, دهار, _kërç, трт_, 
   {{0x62511d38,0x7ea400e5,0x00000000,0x00000000}},	//   _açor, kópa, --, --, 
   {{0xed451d39,0xd5b812d7,0x6f191d3a,0xbad80150}},	//   _اپ_, _аср_, _aptc, _ﺃﻨﺤﺎ, 
   {{0x7eb40024,0x43950665,0xafe001b9,0xc2c401c8}},	//   _išpi, _багс, бошл, _ميسي, 
   {{0x44211d3b,0x9f4402d3,0x648800e2,0xf4780092}},	//   meh_, manë_, gļie, _በረሃብ_, 
   {{0x44211d3c,0x222401d9,0x88d802f5,0x13e80eac}},	//   leh_, _جٲری_, _তিনক, _পায়, 
   {{0x6f1802d0,0x51851d3d,0xa0c000f1,0x00000000}},	//   _eptc, _куфа, _څيړو, --, 
   {{0x44211d3e,0x51851d3f,0xa19000d1,0x8afc012d}},	//   neh_, _туса, _бағч, częk, 
   {{0xec74084c,0xc10001af,0x00000000,0x00000000}},	//   упэ_, _түҙл, --, --, 
   {{0xdde801d5,0x7eb40010,0x9f44036e,0xce94011c}},	//   _آراه_, _ošpi, hanë_, _кахъ, 
   {{0x9f4402d3,0x7ea40789,0x8eb053f0,0x3db00154}},	//   kanë_, cópa, _بەيت, _ট্রল, 
   {{0x44201f7f,0x9f44036e,0x6f1802d0,0x7c880166}},	//   jeh_, janë_, _yptc, _яшең_, 
   {{0x44211d40,0x7c200af9,0x9f440240,0x7eb400d7}},	//   deh_, melr, danë_, _ašpi, 
   {{0x44211d41,0x628006af,0x66ec000d,0x7c2000a2}},	//   eeh_, énol, _छिऐक_, lelr, 
   {{0x4420011f,0x34a80114,0x81e000cc,0x00000000}},	// [1abe0] feh_, евао_, _দাং_, --, 
   {{0x4420102c,0x9f440240,0xf770009f,0x3ebc015d}},	//   geh_, ganë_, _هاج_, _liwt_, 
   {{0x04b454ea,0x00000000,0x00000000,0x00000000}},	//   рстя, --, --, --, 
   {{0x1c101d8a,0x78bc0477,0x442001ab,0x6ec8012d}},	//   त्तल_, _hipv, aeh_, _bębn, 
   {{0x44211d42,0x7c207c52,0x661803f0,0x9f451d43}},	//   beh_, kelr, _ñuka, banë_, 
   {{0x3cf8006d,0x44211d44,0x09c01d8a,0xfcd40092}},	//   ोंने_, ceh_, _एल्य, _የሥጋ_, 
   {{0x7c209f58,0x27e400af,0x78bc014f,0x3ebc0142}},	//   delr, _õnne_, _mipv, _biwt_, 
   {{0x3ebc0142,0xd2500133,0x2ab80064,0x8cf400f3}},	//   _ciwt_, _گۆڵ_, _rūbo_, азиц, 
   {{0x21a00209,0x78bc02d0,0x31b80213,0x7c211d45}},	//   _гитм, _oipv, _düzü_, felr, 
   {{0x7ea400dd,0x13e8015b,0x9f440100,0x00000000}},	//   rópa, _পাড়, kanè_, --, 
   {{0xdfcc1b45,0xdd900220,0x7d080023,0x510402e5}},	//   _رين_, _қашы, _përç, _रमुआ_, 
   {{0xdd8d1d46,0x58840032,0x3ebc0142,0x9f440240}},	//   _کوه_, ҡыра, _giwt_, zanë_, 
   {{0x44211d47,0x49a40046,0xec1429db,0x78600109}},	//   yeh_, рынғ, _белә_, _sôva, 
   {{0x6d4402f6,0x44200429,0x3204003e,0x786000d0}},	//   äkau, xeh_, hgoy_, _pôva, 
   {{0x44211d48,0x2bd80316,0x31b805d1,0x32040fac}},	//   veh_, _म्या, _yüzü_, kgoy_, 
   {{0x44211d49,0x45d4a836,0x7a1802b1,0x49383cc5}},	//   weh_, роас, _pātō, _азию_, 
   {{0x44211d4a,0x628020ef,0x78bc037e,0x9f440240}},	// [1abf0] teh_, énom, _fipv, tanë_, 
   {{0x9f441f3f,0xb8651d4b,0xe3b0007b,0x4420003e}},	//   banè_, _ناپو, مرض_, ueh_, 
   {{0x44211d4c,0x9f44044e,0xd7f85ab1,0x533400fb}},	//   reh_, ranë_, _суы_, йефт, 
   {{0x44211d4d,0x320422d0,0x66800acb,0x6abc0327}},	//   seh_, ggoy_, _ایرل, _jiqf, 
   {{0x44211d4e,0x9f44034c,0xdf511d4f,0xa5b87d3d}},	//   peh_, mané_, өндө, _caót, 
   {{0x9f44034c,0x5fcc4900,0x44200429,0x3ebc0042}},	//   lané_, _स्खल, qeh_, _siwt_, 
   {{0x7c211d50,0xfe4429e4,0xa3540214,0x6ec8012d}},	//   velr, инко, _حیاط_, _dębo, 
   {{0x9f451d51,0x43941b74,0x3cec00c5,0xe29c2507}},	//   nané_, _баҳс, tsev_, _óð_, 
   {{0xddc00046,0x62991d52,0x3c64825e,0x7c211d53}},	//   _құпи, _ikuo, икиг, telr, 
   {{0x9f68156b,0x9f451d54,0x61e91d55,0xddd80083}},	//   _през_, hané_, lagl, okuŋ, 
   {{0xba7441c1,0x9f451d51,0x20c8005c,0x7a68022e}},	//   لاحت, kané_, _høi_, винг_, 
   {{0x37e000bd,0x9f44b7d8,0x6fa8004b,0x3d94008e}},	//   _বাইর, jané_, _شننې_, _киер, 
   {{0x9f451d56,0xfce51d57,0x7e680433,0x7c211d58}},	//   dané_, _толо, mhep, pelr, 
   {{0x20051d59,0x6abc0369,0x61e91d5a,0xddd80083}},	//   ngni_, _eiqf, hagl, kkuŋ, 
   {{0xfaa51d5b,0x7ea406ed,0x61e91d5c,0x62991d5d}},	//   _како, nópo, kagl, _okuo, 
   {{0x629800fb,0x7e68006f,0x9f4400f2,0x61e804cc}},	//   _nkuo, nhep, gané_, jagl, 
  
   {{0x61e91d5e,0xd8f51d5f,0x2d900212,0xddd80083}},	// [1ac00] dagl, _ازبک, _øyet_, ekuŋ, 
   {{0x62991d60,0xe45c01e6,0x7eb40024,0x33d400d4}},	//   _akuo, _stör_, _išpu, ріат, 
   {{0x9f451d61,0x61e83c12,0xf74411af,0x7e691d62}},	//   bané_, fagl, _тено, khep, 
   {{0x61e91d5e,0x63a0dcd4,0x9f4400f2,0x20c803b2}},	//   gagl, ünna, cané_, _bøi_, 
   {{0xe0cd1d63,0xddd81418,0x7e6804fb,0x3204002e}},	//   وزو_, akuŋ, dhep, rgoy_, 
   {{0xa07010f5,0x62980810,0xa15400fd,0xe1200108}},	//   огіч, _ekuo, рашу_, юмчи, 
   {{0x61e91d64,0x95780092,0x00000000,0x00000000}},	//   bagl, ሪያችን_, --, --, 
   {{0xa2c87e29,0x61e886ed,0xe9dc01d3,0x2dd401d9}},	//   _तंत्, cagl, rjúk_, گُکھ_, 
   {{0xd16401d5,0xe9dc1427,0xdd1000d7,0x00000000}},	//   _унақ, sjúk_, túše, --, 
   {{0x9f442195,0xefcc02d3,0xeb4804fb,0x2dd40014}},	//   zané_, _ኣትዩ_, نشجو_, دُکھ_, 
   {{0x9f440502,0xab8402e8,0x7e680055,0x00000000}},	//   yané_, рупк, bhep, --, 
   {{0x7e680925,0x68ec02d0,0x6d440108,0x6c3c00b8}},	//   chep, tscd, äkas, _ṭhān, 
   {{0x9f440745,0x27240368,0xdb0c00e4,0x69cc00e5}},	//   vané_, _sŵn_, _ñeîm, rcce, 
   {{0x786001a2,0xd7f8e43f,0xe9940023,0x9f44034c}},	//   _dôvo, иус_, _መዕለቢ_, wané_, 
   {{0x9f451d65,0xaae400db,0xd7f8009d,0x00000000}},	//   tané_, _ئستو, шуя_, --, 
   {{0xd6d8ae2e,0x00000000,0x00000000,0x00000000}},	//   ртр_, --, --, --, 
   {{0xd1d00201,0x61e8b2cc,0x9f451d66,0xe4e40212}},	// [1ac10] _ጥያቄ_, vagl, rané_, рібн, 
   {{0x9f451d66,0x62991d67,0x61e91d68,0xf8d800af}},	//   sané_, _skuo, wagl, _बढ़िय, 
   {{0x61e91d69,0x9f451d51,0x3ac40374,0x66180de2}},	//   tagl, pané_, _pēpi_, _ñuko, 
   {{0xddd801fa,0x7e680023,0x862402dd,0x80f4007b}},	//   knuš, xhep, _ابدە, مستض, 
   {{0x61e91d6a,0x91283ccf,0x7bcc2d9a,0x3618011a}},	//   ragl, لسوق_, _şaum, _גורד, 
   {{0x61e91d6b,0xe8fc0022,0xd40401f4,0x00000000}},	//   sagl, irû_, _мяси, --, 
   {{0x7e691d6c,0x61e88b14,0x443001c0,0x20051d6d}},	//   thep, pagl, _iaz_, rgni_, 
   {{0x44311d6e,0x7ea40077,0x925800ee,0x6298009a}},	//   _haz_, rópo, _каст_, _ukuo, 
   {{0xee350b47,0x44311d6f,0x7ea48bac,0x7e68023a}},	//   сны_, _kaz_, sópo, rhep, 
   {{0x3c651d70,0x44300f72,0x7e691d71,0x63b8010e}},	//   ског, _jaz_, shep, _şuny, 
   {{0x44311d72,0x7e685b36,0x6d451d73,0x26c40c6a}},	//   _maz_, phep, äkar, _énoh_, 
   {{0x44311d74,0x786001a2,0x7e687b88,0x00000000}},	//   _laz_, _pôvo, qhep, --, 
   {{0xfce406ed,0xc954e987,0x44300200,0x00000000}},	//   _ѓоко, отры, _oaz_, --, 
   {{0x44311d75,0x3b0800f0,0x4c8001ec,0x2d880790}},	//   _naz_, _беко_, _оғыз, ğbet_, 
   {{0x2d904606,0x4758084c,0xec100035,0x37e401d5}},	//   _øyer_, артя_, _رويد, _қонг, 
   {{0x44300477,0xa3b80dba,0xf5040395,0x00000000}},	//   _aaz_, आइन_, йзбо, --, 
   {{0x4430159f,0x20a40406,0xb38401e0,0xb464072c}},	// [1ac20] _baz_, गताध, әлел, бкал, 
   {{0x44311d76,0x656801c3,0x00000000,0x00000000}},	//   _caz_, ùgha, --, --, 
   {{0x44311d77,0xddc80034,0x4dfc00bc,0x55c47855}},	//   _daz_, _mogł, ोलमै_, _манғ, 
   {{0x3a300054,0xb1440046,0x44311d78,0xe0cc0154}},	//   _jayp_, йнел, _eaz_, _রিজভ, 
   {{0x44311d79,0xa13000c6,0x211401e2,0x00000000}},	//   _faz_, كروش, متوب_, --, 
   {{0x44304120,0x3a300280,0x84581677,0x00000000}},	//   _gaz_, _layp_, _крст_, --, 
   {{0x0dc825f8,0x7e780395,0x1ef400c6,0xb3d000dc}},	//   қуқи_, _bmwp, معية_, दुःख, 
   {{0x9f440421,0xd250004b,0xe280014b,0x64a0010a}},	//   panî_, _کنړ_, _елси, _маӏа, 
   {{0x44300ba5,0x00000000,0x00000000,0x00000000}},	//   _yaz_, --, --, --, 
   {{0x7aec0210,0x00000000,0x00000000,0x00000000}},	//   _łata, --, --, --, 
   {{0xfaec004b,0xdea001e2,0xddc80210,0x00000000}},	//   نګي_, _ډیوی, _dogł, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4bc40323,0x62805fe6,0xd31401ec,0x00000000}},	//   _мөнг, énoi, рiкт, --, 
   {{0xd9100101,0x00000000,0x00000000,0x00000000}},	//   ریپ_, --, --, --, 
   {{0x44311d7a,0x27fc6f30,0x9c140375,0x7eb40024}},	//   _raz_, ğun_, _החוק_, _išpr, 
   {{0xf1b81fe5,0x27fc0fb9,0x44311d7b,0x3878067c}},	//   ेशान, şun_, _saz_, _empr_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [1ac30] --, --, --, --, 
   {{0xe7851d7c,0x443003be,0x00000000,0x00000000}},	//   _гумо, _qaz_, --, --, 
   {{0x94a91d7d,0xdecc044e,0x0ec40d01,0x8afc033f}},	//   стта_, _ኣብኡ_, _लंगड, częt, 
   {{0x44311d7e,0x95c82bbd,0x0608004e,0xdb9800df}},	//   _waz_, _гура_, _өнүк_, נסאר, 
   {{0x44311d7f,0x92b4007b,0xf23401d5,0x92940006}},	//   _taz_, أحلا, تبلک, чацц, 
   {{0x81e000bd,0x3cf801ad,0xa1840150,0x442401ef}},	//   _দাও_, ोंसे_, _құла_, _úl_, 
   {{0x7afc012d,0x00000000,0x00000000,0x00000000}},	//   ąstk, --, --, --, 
   {{0x8264021a,0xc0f8044e,0xa1840022,0x00000000}},	//   _بهرن, ገብረ_, _лызл, --, 
   {{0x9f451d80,0x2bd81098,0x660c005a,0x5bb07d07}},	//   maní_, _म्हा, _mcck, ीश्व, 
   {{0x9f451d81,0x9f5c00e5,0x00000000,0x00000000}},	//   laní_, órók_, --, --, 
   {{0x2d80045f,0x7eb000e4,0x00000000,0x00000000}},	//   ûker_, _ẽpup, --, --, 
   {{0xee2c07d6,0x9f451d82,0xa5b80ca8,0x7d98014b}},	//   _ўн_, naní_, _gbóg, _квес_, 
   {{0xdecc02d3,0xc0f802d3,0xce3402f2,0x00000000}},	//   _ኣብኣ_, ገብሩ_, _رووک, --, 
   {{0x9f451d83,0xb7d8103f,0x00000000,0x00000000}},	//   manâ_, شورا_, --, --, 
   {{0x9f4413d5,0x628001e4,0x7aa400ae,0xf65401f4}},	//   kaní_, ɩnov, _وإعل, отаю, 
   {{0x8afc0034,0xfd54002b,0x9f440419,0x00000000}},	//   rzęt, _staṃ, janí_, --, 
   {{0x9f4425f7,0xe5a11d84,0x00000000,0x00000000}},	// [1ac40] daní_, дити, --, --, 
   {{0x8afc012d,0x00000000,0x00000000,0x00000000}},	//   częs, --, --, --, 
   {{0xa5b801e1,0x3ac404fe,0x00000000,0x00000000}},	//   _abód, _tēpu_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x76451d85,0x2ba402ab,0x00000000,0x00000000}},	//   _inky, _ऑर्थ, --, --, 
   {{0xc0f8044e,0x8f340108,0x69340166,0x00000000}},	//   ገብሮ_, зекц, lğeç, --, 
   {{0xdbe008a5,0x733400d1,0x9f4400d7,0x91c401af}},	//   _réðu, _بىزا, baní_, _еҙел, 
   {{0x42d400d3,0xe2940354,0xdbe002d2,0x9f440419}},	//   _хіру, _дас_, _séðu, caní_, 
   {{0xc0f8044e,0x245c00d2,0xa5b80ca8,0x2164004e}},	//   ገብር_, _sîmi_, _gbód, _дити_, 
   {{0x62811d86,0x00000000,0x00000000,0x00000000}},	//   énov, --, --, --, 
   {{0x25b40490,0x00000000,0x00000000,0x00000000}},	//   _अण्ण, --, --, --, 
   {{0x09e00154,0x00000000,0x00000000,0x00000000}},	//   _ভাঙা, --, --, --, 
   {{0xdbe002d2,0x00000000,0x00000000,0x00000000}},	//   _téðu, --, --, --, 
   {{0x76451d87,0x9f4413d5,0x00000000,0x00000000}},	//   _anky, zaní_, --, --, 
   {{0x96f836ca,0x6618002e,0xf8ac12ea,0x00000000}},	//   жест_, _ñukk, دکي_, --, 
   {{0xa2c800cd,0x00000000,0x00000000,0x00000000}},	//   _तूष्, --, --, --, 
   {{0x9f451d88,0x5ac4031c,0x6ec8012d,0x8574009d}},	// [1ac50] vaní_, _གཤོམ, _dębi, члах, 
   {{0xa3a415ed,0x76451d89,0x00000000,0x00000000}},	//   ојек, _enky, --, --, 
   {{0xd4980164,0x7ea40af2,0x9f440030,0x784400c7}},	//   іру_, bóph, taní_, _хьыҧ, 
   {{0x98a0107d,0xe5005d4f,0xd3780408,0x00000000}},	//   _psić_, _लिपि_, цчу_, --, 
   {{0x9f4445be,0xa2c801bc,0x81b005ac,0x61281d39}},	//   raní_, _तूर्, _ঞ্জ_, рцег_, 
   {{0x9f4400d0,0xd8dc0677,0xddd800b8,0x00000000}},	//   saní_, סקור, bhuś, --, 
   {{0x64451d8a,0xdb051d8b,0xdb0004bf,0xaac4146c}},	//   _inji, ülük, _ozná, _रंगक, 
   {{0x69d91d8c,0x24980153,0x13a80244,0x11d400ae}},	//   ñuel, žymą_, _بۆمی_, _يتقد, 
   {{0xd8400232,0xe61c06d9,0x62891d8d,0x212804cc}},	//   íčky_, _mbô_, mngo, _èch_, 
   {{0x60d91d8e,0x62880589,0x50641422,0x00000000}},	//   _itum, lngo, _отха, --, 
   {{0x62891d8f,0x64440161,0xbb451d90,0x00000000}},	//   ongo, _mnji, ченк, --, 
   {{0x62880680,0x213c1dd5,0x7ea51d91,0xce3800c6}},	//   nngo, _kruh_, kópi, _وأنا_, 
   {{0x62891d92,0x61f80161,0x64451d93,0x9f440109}},	//   ingo, _mdul, _onji, lanà_, 
   {{0x60d91d94,0x7d091d95,0xed551d96,0xe61c011f}},	//   _mtum, mues, _хош_, _abô_, 
   {{0x7d091d97,0x61f80c8c,0x9f440109,0x6288003e}},	//   lues, _odul, nanà_, kngo, 
   {{0x64443fa0,0x61f80296,0x60d915d5,0x80e00eac}},	//   _anji, _ndul, _otum, _নিন্, 
   {{0x7d091d98,0x60d91d99,0x2bd016da,0x62880004}},	// [1ac60] nues, _ntum, _सलमा, dngo, 
   {{0x61f91d9a,0xf8e002f5,0x9f440109,0x62891d9b}},	//   _adul, _বিপথ, kanà_, engo, 
   {{0x213c00f2,0xb2240cdd,0x7d086f9e,0x00000000}},	//   _aruh_, змел, hues, --, 
   {{0x64451d9c,0xe61c145e,0x7d08044e,0x62891d9d}},	//   _enji, _gbô_, kues, gngo, 
   {{0x8804687d,0x7ea51d9e,0x7d0802d3,0x61f80368}},	//   _عظیم, cópi, jues, _ddul, 
   {{0x62891d9f,0x213c0232,0x61f91da0,0x7d091da1}},	//   ango, _druh_, _edul, dues, 
   {{0x60d91da2,0x213c0066,0x2c800241,0x00000000}},	//   _etum, _eruh_, _lédè_, --, 
   {{0xdce82258,0x628006af,0x64440010,0x62880208}},	//   _aygı, énot, _znji, cngo, 
   {{0x2bc8004e,0x00000000,0x00000000,0x00000000}},	//   йуно_, --, --, --, 
   {{0xdfcc00c6,0x8af91da3,0x00000000,0x00000000}},	//   _ميك_, онос_, --, --, 
   {{0xdee0152d,0xd1cc02d3,0x9f440c67,0x61f80139}},	//   _зохи, _ኣንታ_, ranã_, _ydul, 
   {{0x7d091da4,0xe81c3996,0x3de800f7,0x00000000}},	//   bues, म्ना_, _ۇعۇپ_, --, 
   {{0x7d091da5,0x66180113,0xdb000306,0x9e60009d}},	//   cues, _ñuki, _vzná, _явцд, 
   {{0x98c46565,0xd9180a8f,0x62880007,0x9f440646}},	//   ессл, чью_, zngo, laná_, 
   {{0x62880368,0x2b4401c4,0x00000000,0x00000000}},	//   yngo, _хэлг, --, --, 
   {{0xdb000122,0x9f4413d5,0x00000000,0x00000000}},	//   _uzná, naná_, --, --, 
   {{0x628803b2,0xa4240166,0x00000000,0x00000000}},	// [1ac70] vngo, зьел, --, --, 
   {{0x29082dab,0x628800a9,0x9f440306,0x7af40139}},	//   muca_, wngo, haná_, _ägtä, 
   {{0x62880c67,0x7d091da6,0x60d91da7,0x9f4402fb}},	//   tngo, zues, _stum, kaná_, 
   {{0x78600109,0x9f441841,0x213c02fb,0x00000000}},	//   _rôvi, vanà_, _pruh_, --, 
   {{0xb9d8069c,0x9f440232,0x62891da8,0x7d0802d3}},	//   _በዚ_, daná_, rngo, xues, 
   {{0xd1b91da9,0x439405f5,0x7ed4da98,0x9f440109}},	//   سانا_, _жагс, وزبا, tanà_, 
   {{0x7d080221,0x2908014b,0x213c00f2,0x26c4020c}},	//   wues, huca_, _wruh_, _énos_, 
   {{0x7d08044e,0x29080286,0x61f84097,0x62880369}},	//   tues, kuca_, _udul, qngo, 
   {{0x60d91daa,0x29091dab,0x63a402d3,0x9f440268}},	//   _utum, juca_, _hyjn, sanà_, 
   {{0x7d08044e,0x29091dac,0xe81c2c30,0x7c2801c0}},	//   rues, duca_, म्मा_, цоог_, 
   {{0x7d091dad,0x9f4492f7,0x63a0004e,0x8c3c03e0}},	//   sues, baná_, ünnh, doğd, 
   {{0x7d08dbd1,0x29091dae,0x63a4012d,0x9f4401ef}},	//   pues, fuca_, _myjn, caná_, 
   {{0x7d08d5c5,0x00000000,0x00000000,0x00000000}},	//   ques, --, --, --, 
   {{0xdce80139,0x00000000,0x00000000,0x00000000}},	//   _uygı, --, --, --, 
   {{0xc7951daf,0xb6a51db0,0x291cc608,0xb6581cb8}},	//   ерты, дивл, çuar_, ошах_, 
   {{0x29080481,0xe81c2c2e,0x9b3401c6,0x00000000}},	//   buca_, म्बा_, _дүүс_, --, 
   {{0x14c80502,0x250801b9,0x7afc0153,0x00000000}},	// [1ac80] سهای_, قرلی_, ąstu, --, 
   {{0x9f451db1,0xdb2008a5,0x00000000,0x00000000}},	//   zaná_, _árós, --, --, 
   {{0xb368001f,0x00000000,0x00000000,0x00000000}},	//   _በዚያን_, --, --, --, 
   {{0xdd100030,0x36040244,0xf1242e73,0x00000000}},	//   dĺže, _توحف, дько, --, 
   {{0x9f4403c6,0x960800aa,0x48dc0183,0x00000000}},	//   vaná_, _وکړې_, _বিৱৰ, --, 
   {{0xa0651db2,0x765401f4,0x67380210,0x6280753e}},	//   мача_, ljyy, łuje, énor, 
   {{0x9f440579,0x7ea40008,0x5f911db3,0x63800174}},	//   taná_, hópu, кишт, _vínø, 
   {{0xdb00004a,0x38b43a26,0x29091db4,0x00000000}},	//   _gyné, lærd_, yuca_, --, 
   {{0x9f451db5,0x7f4003ac,0xa36401e1,0x00000000}},	//   raná_, _erlq, _lọ́r, --, 
   {{0x29080481,0x9f4413d5,0xac243cc5,0x6004010b}},	//   vuca_, saná_, ффик, _онум_, 
   {{0x9f443df8,0x29082dab,0x79940175,0xdcd000db}},	//   paná_, wuca_, _axyw, нбөө, 
   {{0x38b403b2,0x63a0000d,0x00000000,0x00000000}},	//   hærd_, ünni, --, --, 
   {{0x6e211db6,0xba500137,0x00000000,0x00000000}},	//   _ibob, اچىع, --, --, 
   {{0x29091db7,0x6d40000f,0xdbd80241,0x9d940092}},	//   ruca_, _iroa, _dáód, _ውስጣዊ_, 
   {{0xd7043306,0x29091db8,0x6d411db9,0x00000000}},	//   َظِي, suca_, _hroa, --, 
   {{0xa36401e1,0xe4e402bf,0xa5d00432,0x04c8007b}},	//   _dọ́r, діжн, _aỳra, كوري_, 
   {{0x38b4037e,0x6e2000f2,0x3128001f,0x44b4dcc6}},	// [1ac90] færd_, _mbob, ደነበር, ебас, 
   {{0xdb0007a8,0x47343981,0x21280042,0xe450007b}},	//   _syné, _знос, _âchi_, خضر_, 
   {{0x20100137,0x6e211dba,0x9f4456eb,0xddd80356}},	//   òxim_, _obob, manç_, niuţ, 
   {{0x23dc0da3,0x9f4466e5,0x6d4001e6,0xa5d000ee}},	//   _प्रद, lanç_, _oroa, _eỳra, 
   {{0x6d4403cd,0xd04006be,0xc5f40154,0xdb0001ef}},	//   åkal, _humə, _ছাপা_, _vyné, 
   {{0x3e7003c6,0x6e211dbb,0x239c0023,0xd04006be}},	//   _máte_, _abob, ግንዛብ_, _kumə, 
   {{0x6d400325,0x6e2000e8,0xd3a45130,0xbea51dbc}},	//   _aroa, _bbob, _артп, накк, 
   {{0x38b411aa,0x6d411dbd,0x00000000,0x00000000}},	//   mære_, _broa, --, --, 
   {{0x38b439c2,0x6d411dbe,0x81c40171,0x3fc800f2}},	//   lære_, _croa, _blēņ, _فدای_, 
   {{0x6d400489,0xd0100e26,0x6e2002d0,0x6f0c007b}},	//   _droa, _ەلە_, _ebob, óicé, 
   {{0x38b43c12,0x6d411dbf,0x1bc40014,0x6d540248}},	//   nære_, _eroa, بُدی_, _àyan, 
   {{0x6d40ad7c,0x6e200248,0x9f44003a,0xfbd00014}},	//   _froa, _gbob, tanæ_, ختک_, 
   {{0x7e680008,0x00000000,0x00000000,0x00000000}},	//   mkep, --, --, --, 
   {{0x8d74278f,0x7ea4008c,0x3e7002fb,0x38b4005c}},	//   _جاما, rópu, _dáte_, kære_, 
   {{0x38b42188,0xbb5c00b5,0x6d40030a,0x3d18007f}},	//   værd_, _wayサ_, _zroa, lèw_, 
   {{0x7ea4bae7,0x7e6800c4,0x7c90044e,0xd9111dc0}},	//   cópt, nkep, _ዝብሃል_, _پیس_, 
   {{0x7e6800fe,0x00000000,0x00000000,0x00000000}},	// [1aca0] ikep, --, --, --, 
   {{0x38b40627,0x7e6800c5,0xdb2001e1,0x00000000}},	//   fære_, hkep, _òrór, --, 
   {{0x38b4005c,0xa2e02910,0x786000d7,0x42d400d4}},	//   gære_, гохд, _dôvt, вічу, 
   {{0xe2951dc1,0x95b400c7,0x7e6801f5,0xb8080451}},	//   нах_, _аргә, jkep, _بيگم_, 
   {{0x21642e58,0x3218012d,0xd04003b9,0x7e680064}},	//   ници_, ępy_, _zumə, dkep, 
   {{0xdfcc157c,0x68f80120,0x38b41512,0x6e200051}},	//   ميه_, áudi, bære_, _sbob, 
   {{0x6d40037e,0x23251d84,0xd25035ea,0x68f80135}},	//   _sroa, _пори_, _پچا_, ġudi, 
   {{0x6d411dc2,0xa5b80296,0x9f44a697,0x3d18007f}},	//   _proa, _mbón, zanç_, fèw_, 
   {{0xe2951dc3,0x1dd400c6,0x00000000,0x00000000}},	//   _чат_, ربيع_, --, --, 
   {{0x6d400489,0xa0a02de5,0xecb001e0,0x60f8011a}},	//   _vroa, _бауд, ыҡлы, _מהמק, 
   {{0xdfcc00b2,0x4a2c025c,0x31640790,0x9f441432}},	//   _ايم_, _ཧྲུལ_, lyoz_, vanç_, 
   {{0x6d411dc4,0x6e2001f0,0xed590db5,0x2bd02ba2}},	//   _troa, _ubob, _ное_, _सलवा, 
   {{0x58d41d18,0x6d411dc5,0x7ea40077,0x2f181bce}},	//   лоят, _uroa, rópt, lëg_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x31640097,0xddd800c0,0x00000000,0x00000000}},	//   hyoz_, liuš, --, --, 
   {{0x16340395,0x00000000,0x00000000,0x00000000}},	//   леся, --, --, --, 
   {{0x56943088,0x84151dc6,0xddd800c0,0x8858022e}},	// [1acb0] уатт, кмах, niuš, _жипс_, 
   {{0x38b43c12,0xb88400ae,0x00000000,0x00000000}},	//   tære_, raíú, --, --, 
   {{0xa5b80ca8,0xb7d800d1,0x7e69145b,0x00000000}},	//   _gbón, _توپا_, ykep, --, 
   {{0x38b45b47,0x61c80882,0x2f180036,0x3d18007f}},	//   rære_, िशेष, dëg_, yèw_, 
   {{0x81c80eac,0xdce80327,0x00000000,0x00000000}},	//   লুন_, _ixgħ, --, --, 
   {{0x38b42f48,0x644000d8,0x00000000,0x00000000}},	//   pære_, ônid, --, --, 
   {{0x026003e6,0x9980010b,0xfbd02a77,0x7a4000e5}},	//   _پێشێ, _ediň_, یتد_, lítő, 
   {{0x4f081a59,0xc104819a,0x7e680161,0x26d11dc7}},	//   رتىپ_, _لوري, ukep, _muxo_, 
   {{0x26d11dc8,0x26c91dc9,0xee351dca,0xa5b81bce}},	//   _luxo_, _mico_, тны_, _mbóo, 
   {{0x225c000f,0x26c8f35e,0x3c641468,0x7ea400d8}},	//   _houk_, _lico_, тког, tóps, 
   {{0x225c0280,0x29191dcb,0x2f180de2,0xde640395}},	//   _kouk_, _aqqa_, cëg_, _пъдп, 
   {{0x26c91dcc,0x225c0699,0x7ea51dcd,0x2c70054e}},	//   _nico_, _jouk_, róps, _râde_, 
   {{0x3ead1dce,0x2c70025a,0x225d1dcf,0x00000000}},	//   mlet_, _sâde_, _mouk_, --, 
   {{0x7d091dd0,0x225c1529,0xc0c00020,0x26d078aa}},	//   mres, _louk_, ትችሉ_, _buxo_, 
   {{0x3ead1dd1,0x26d01709,0x26c9118b,0x31640007}},	//   olet_, _cuxo_, _bico_, zyoz_, 
   {{0x3ead1dd2,0x7aec068f,0x26c80841,0x660017a0}},	//   nlet_, _łatw, _cico_, ипса, 
   {{0x26c91dd3,0x7d091dd4,0x3eac1b0a,0x7a4001d3}},	// [1acc0] _dico_, nres, ilet_, gítő, 
   {{0x3ead1dd5,0x7d08127b,0x44200421,0x26c800b5}},	//   hlet_, ires, gfh_, _eico_, 
   {{0x3ead1dd6,0x26c91dd7,0x225d1dd8,0x7d091dd9}},	//   klet_, _fico_, _bouk_, hres, 
   {{0x7d091dda,0x26c800ca,0x3ead1ddb,0xc304072d}},	//   kres, _gico_, jlet_, ابلو, 
   {{0x225c039a,0x7d091ddc,0x311400d8,0x211401e2}},	//   _douk_, jres, тфес, نتوب_, 
   {{0x7d091ddd,0x95b40022,0x3ead1dde,0x741408f0}},	//   dres, _арҳә, elet_, _جوسا, 
   {{0x7d091ddf,0x3ead1de0,0x225d1de1,0xdbd802d2}},	//   eres, flet_, _fouk_, _ráðd, 
   {{0x80e00d42,0x7d091de2,0x8c3c0ba5,0x26c81ada}},	//   _নির্, fres, doğa, _xico_, 
   {{0xffa51de3,0x7d08eb56,0x31640007,0xb808009e}},	//   кләү, gres, qyoz_, শ্যত_, 
   {{0x225d1de4,0xc0c00092,0x00000000,0x00000000}},	//   _zouk_, ትችል_, --, --, 
   {{0x3ead1de5,0x7d091de6,0xa5b801e1,0x2e240740}},	//   blet_, ares, _aból, _لفاف, 
   {{0x3ead1de7,0xeda401b9,0xaae403e6,0x26d00009}},	//   clet_, _ишло, _یسبو, _ruxo_, 
   {{0x7d091de8,0x00000000,0x00000000,0x00000000}},	//   cres, --, --, --, 
   {{0x26d01709,0xdd8c04d3,0x5c7002bf,0x8c3c0205}},	//   _puxo_, _بوه_, _кліт, boğa, 
   {{0xc6200154,0x44200332,0x9ca401c8,0x00000000}},	//   _পোষা_, vfh_, _جهول_, --, 
   {{0x3e701427,0x5694141c,0x7a4001d3,0x00000000}},	//   _káta_, ааст, títő, --, 
   {{0x26c91de9,0xa5b8110e,0x3e7008a5,0x00000000}},	// [1acd0] _vico_, _gból, _játa_, --, 
   {{0x225d1dea,0xb808045e,0x3e711deb,0x3ead1dec}},	//   _souk_, শ্বত_, _máta_, zlet_, 
   {{0x3e70fdc6,0x225c151c,0x7d091ded,0x7a4001d3}},	//   _láta_, _pouk_, zres, sítő, 
   {{0x7d081455,0xe81c0316,0x26c8003a,0xd6d80276}},	//   yres, म्रा_, _uico_, _шть_, 
   {{0x95c800c7,0x3eacde1d,0x225c0165,0x3e7003b2}},	//   _аура_, vlet_, _vouk_, _náta_, 
   {{0x3eac0510,0x7d091dee,0x9f440270,0x225c007f}},	//   wlet_, vres, manú_, _wouk_, 
   {{0x3ead1def,0x7d091df0,0x9f4400d7,0xd9c01fd2}},	//   tlet_, wres, lanú_, _एण्ट, 
   {{0x3eacdfc9,0xed4c0451,0x3e7008a5,0x30100166}},	//   ulet_, ڻھن_, _báta_, адәр, 
   {{0x3ead1df1,0x38b4003a,0xdb000419,0x9f44dd18}},	//   rlet_, hæra_, _vyní, nanú_, 
   {{0x3ead1df2,0x3e70b231,0xbed41677,0x29080010}},	//   slet_, _dáta_, _божј, drca_, 
   {{0x3eacb4b4,0x38b40217,0x290829b1,0xbe1408de}},	//   plet_, jæra_, erca_, _مواع, 
   {{0xddd8031c,0x9f440419,0x00000000,0x00000000}},	//   nnuż, kanú_, --, --, 
   {{0x323404ac,0xf9900aaa,0x3e7003f2,0xed4d1df3}},	//   נטשן_, صبح_, _gáta_, _уо_, 
   {{0xe81c0316,0x9be402bf,0x9f4400d0,0x6ce000f1}},	//   म्ला_, _рідк, danú_, _اړين, 
   {{0x29091df4,0x6c7800df,0x00000000,0x00000000}},	//   arca_, _ראצפ, --, --, 
   {{0x1d900023,0x00000000,0x00000000,0x00000000}},	//   _ዝስዕባ_, --, --, --, 
   {{0xa5051df5,0xf98800ec,0xbcfc00e4,0x00000000}},	// [1ace0] лета_, _سندي_, kyũm, --, 
   {{0xa5b801e1,0x38b40158,0x00000000,0x00000000}},	//   _gbóm, bæra_, --, --, 
   {{0x2bf4010f,0x00000000,0x00000000,0x00000000}},	//   רמען_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x644003b7,0xa1804caf,0x00000000,0x00000000}},	//   ônic, йышл, --, --, 
   {{0x3e7000c6,0xfe440214,0x00000000,0x00000000}},	//   _ráta_, یکنی, --, --, 
   {{0xa2e0023a,0x42500014,0x00000000,0x00000000}},	//   _госд, _ژۆمر, --, --, 
   {{0x3e7000e4,0x638001c0,0x118801ee,0x00000000}},	//   _páta_, _угса, _иҙеп_, --, 
   {{0x61411df6,0xeda407e6,0xafe4008e,0xefc00023}},	//   _лета, ышко, _бозл, ትክዎ_, 
   {{0x2c70006a,0x290805a1,0xc1800014,0x3e7003b2}},	//   _bâda_, vrca_, _بیٖٹ, _váta_, 
   {{0x753404cc,0x9f440216,0x7f7400c0,0x00000000}},	//   hwyz, ybné_, _куцц, --, 
   {{0xf418015b,0x38b428bf,0x3e700118,0x29080010}},	//   ড়ির_, væra_, _táta_, trca_, 
   {{0xcdc4136b,0xbd540ec9,0x15ac08b0,0x29840220}},	//   _тадқ, _نروژ, ﺳﯩﺮﺩ, уынг, 
   {{0x58d4c133,0x9f4401f1,0x6c3001d3,0x58840150}},	//   сорт, vanú_, _اہدا, быса, 
   {{0xa5b80248,0xdb4c06a6,0xf418015b,0x23c00401}},	//   _gbój, _ую_, ড়ার_, _वृंद, 
   {{0x9f4400d0,0xdb2001d3,0xe3640051,0x00000000}},	//   tanú_, _órár, _đềđã_, --, 
   {{0x99480451,0xe4d41ec7,0x61e80175,0x28682377}},	// [1acf0] _مليل_, اترب, vbgl, _зрно_, 
   {{0xe9dc004e,0x9f4400d0,0x00000000,0x00000000}},	//   lcú_, ranú_, --, --, 
   {{0xe7e80574,0xd4991df7,0x9f4400d7,0x00000000}},	//   _ज्या_, урт_, sanú_, --, 
   {{0xe2a800cf,0x15ec000d,0x9f4400d7,0x00000000}},	//   راان_, _छ्पर_, panú_, --, 
   {{0xa5b8043b,0xd1b89165,0x61e804cc,0xddd80327}},	//   _mbók, هاها_, rbgl, rnuż, 
   {{0xb0602347,0x00000000,0x00000000,0x00000000}},	//   _şäri, --, --, --, 
   {{0xcee8092f,0xa4980ba1,0x00000000,0x00000000}},	//   هرين_, _evòc, --, --, 
   {{0xf2c0009d,0x00000000,0x00000000,0x00000000}},	//   _дөчи, --, --, --, 
   {{0xddc800a2,0x00000000,0x00000000,0x00000000}},	//   _dogş, --, --, --, 
   {{0xcd2805d9,0x518401c6,0xbd68013d,0x00000000}},	//   اسين_, _ууса, ерүе_, --, 
   {{0x8c3c3535,0xae2400db,0x00000000,0x00000000}},	//   moğl, _چومۉ, --, --, 
   {{0xfaa4fcad,0x62891df8,0x8c3c1d89,0x999001e4}},	//   рамо, nigo, loğl, ŭaŭa_, 
   {{0x87c00156,0xec6c3e2e,0x3fb80131,0x4dd40066}},	//   ཞཟའཡ, _дп_, ﻤﯩﺰﻧ, _اتمس, 
   {{0x62891df9,0x8c3c0259,0xed4c009f,0x00000000}},	//   higo, noğl, _آپو_, --, 
   {{0x62891dfa,0xe8142ef1,0x60c001ab,0xb8cc012d}},	//   kigo, _तारा_, imnm, _औऱ_, 
   {{0x5ed400bd,0xf504e4a2,0xe9840131,0xa5b80241}},	//   _সবাই, избо, _ھايۋ, _gbók, 
   {{0xb4a8baec,0x348401c0,0x8c3c0342,0x3e7001e1}},	// [1ad00] вказ_, агаг, koğl, _láto_, 
   {{0x62880153,0x00000000,0x00000000,0x00000000}},	//   eigo, --, --, --, 
   {{0x62891dfb,0x8c3c0213,0x64400798,0xf98808f0}},	//   figo, doğl, ônia, _سنگي_, 
   {{0x6288a86f,0xb1451dfc,0x9694036b,0x36683252}},	//   gigo, инел, _ایرش, _рамо_, 
   {{0x8c3c0c3c,0x00000000,0x00000000,0x00000000}},	//   foğl, --, --, --, 
   {{0x73340328,0x6288004c,0x00000000,0x00000000}},	//   _پىرا, aigo, --, --, 
   {{0xa06416a4,0xe81407af,0x00000000,0x00000000}},	//   раја_, तलता_, --, --, 
   {{0x62880115,0xc40801d9,0xdb00032e,0xeda40353}},	//   cigo, _لتہٕ_, _kynæ, ишпо, 
   {{0xf1a8168d,0x38b400b5,0xe8142982,0xf7bc2d40}},	//   _شاره_, værn_, _ताला_, ﻠﯩﻤﻪ, 
   {{0x27200030,0xdb0002f0,0x8c3c4e7e,0x00000000}},	//   nčná_, _syná, coğl, --, 
   {{0xdee11dfd,0x5bb43cc5,0xdb0001bf,0xdea000e5}},	//   _дохи, илья_, _lynæ, _ڈیوی, 
   {{0xfe78012c,0x100404af,0x00000000,0x00000000}},	//   chů_, रणवश_, --, --, 
   {{0xdb000122,0xe9dc0553,0xa5b80ca8,0xed5802a9}},	//   _vyná, rcú_, _gbóh, _шод_, 
   {{0xe9dd1dfe,0x00000000,0x00000000,0x00000000}},	//   scú_, --, --, --, 
   {{0x1cb804ac,0x62885055,0xd6d858e5,0x00000000}},	//   _שמוע, yigo, итт_, --, 
   {{0xdb000b1a,0x6288011f,0x8c3c1b0d,0x1ac8008e}},	//   _bynæ, xigo, zoğl, _куып_, 
   {{0x8c3c083c,0x63e400be,0x00000000,0x00000000}},	// [1ad10] yoğl, لساك, --, --, 
   {{0xd7f800fd,0x62891dff,0xfcf80092,0x00000000}},	//   _кую_, wigo, _ለእጅ_, --, 
   {{0x62891e00,0x73c00724,0xed451e01,0xa5b8a749}},	//   tigo, зәте, _کپ_, _mbói, 
   {{0xdb0401ed,0x628805c7,0x27200419,0x8c3c0205}},	//   ülék, uigo, ačná_, doğm, 
   {{0x6288c5a3,0x8c3c6f38,0xdb003c38,0x55040124}},	//   rigo, toğl, _gynæ, _мчра, 
   {{0x62891e02,0x3ebc0042,0x44240142,0x00000000}},	//   sigo, _shwt_, _ùl_, --, 
   {{0x8c3c0259,0x62891e03,0xb3d400fb,0xa2c801ee}},	//   roğl, pigo, _ѳйрә, _ауаз_, 
   {{0x09ac04c5,0xa1840724,0xddd00030,0xddd80115}},	//   _গণনা, _кызл, ťaže, bkuŝ, 
   {{0xdb000209,0x8c3c0790,0x7d080114,0x00000000}},	//   _kynç, poğl, ћног_, --, 
   {{0x3e7001a2,0xec74010b,0x8c3c03b9,0x00000000}},	//   _táto_, йпы_, qoğl, --, 
   {{0xdb00062c,0xdce47975,0x7a6886e5,0x00000000}},	//   _mynç, ılım, гинг_, --, 
   {{0xc8681a4c,0xa5b801e7,0x00000000,0x00000000}},	//   _אן_, _gcóg, --, --, 
   {{0x81c8015b,0xa3d42c30,0x7c280166,0x37b800cc}},	//   লুর_, ाखा_, _болг_, _আলধৰ, 
   {{0x14d8043e,0x9f4002d2,0x00000000,0x00000000}},	//   _भूषण, _þjó_, --, --, 
   {{0x06d848bd,0xf744034b,0x62991e04,0x00000000}},	//   ифты_, щево, _ojuo, --, 
   {{0x64400109,0xe5004244,0xba7400cf,0x141000c5}},	//   ônin, _लिखि_, _داتت, ाल्ह_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [1ad20] --, --, --, --, 
   {{0xb9ec044e,0xa3e01b76,0x7414484d,0x27e80118}},	//   _ጓል_, फुल_, صوصا, činí_, 
   {{0xdb000432,0xf7700a0a,0x272000d0,0xabf8010f}},	//   _dynç, _راد_, rčná_, רהער, 
   {{0xf1f912cd,0x71f802dd,0x6600016b,0x00000000}},	//   اعات_, اراس_, ɔnko, --, 
   {{0x9f8001c6,0xe81c20f0,0x6ed80456,0x65c400d1}},	//   үгчд, म्का_, _पंहु, ﯩﯟﯦﻠ, 
   {{0x38b400b5,0x09ac015b,0xdb011e05,0x64880327}},	//   kærm_, _গণমা, _kynä, nżil, 
   {{0x5f4000c6,0x6ec800bc,0xec1401e0,0xddd801e4}},	//   كنول, _hřbi, ҙенә_, skuŝ, 
   {{0x329400c6,0xdb000108,0x00000000,0x00000000}},	//   _الرأ, _mynä, --, --, 
   {{0x9f440306,0x2658010f,0x00000000,0x00000000}},	//   maný_, רכפא, --, --, 
   {{0x9f4402fb,0xa17400df,0x00000000,0x00000000}},	//   laný_, _העמד_, --, --, 
   {{0xdb000267,0x00000000,0x00000000,0x00000000}},	//   _nynä, --, --, --, 
   {{0xa5b801e1,0x9f441d55,0x6398010f,0x00000000}},	//   _gbów, naný_, רסטנ, --, 
   {{0x2988a6be,0x44f4025c,0x00000000,0x00000000}},	//   усно_, _བསེར_, --, --, 
   {{0x9f4402fb,0x00000000,0x00000000,0x00000000}},	//   haný_, --, --, --, 
   {{0xaae41aa3,0x1bf8025f,0x9f440122,0x7c2400a2}},	//   _استو, _גלוב, kaný_, _öhra, 
   {{0xd6d82095,0xdb00010b,0x9f440419,0x00000000}},	//   стр_, _synç, janý_, --, 
   {{0x9f440232,0x64400120,0xe4e402bf,0x04c806c7}},	// [1ad30] daný_, ônio, сібн, لوري_, 
   {{0xddd80790,0x7698010e,0xc62000cc,0x00000000}},	//   kkuş, lįyl, _পোখা_, --, 
   {{0x45d51e06,0xdb000e78,0x23c010eb,0x00000000}},	//   _монс, _gynä, वेंद, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x1a9c00df,0x00000000,0x00000000,0x00000000}},	//   נידע, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9f441155,0x81c800cc,0x769800a2,0x00000000}},	//   baný_, লুং_, kįyl, --, 
   {{0x9f4402f0,0xaf440014,0x00000000,0x00000000}},	//   caný_, زرى۪, --, --, 
   {{0xada0039b,0x61f8035a,0x92580166,0xc0e80023}},	//   маъл, _ieul, _уатт_, _ዚብሉ_, 
   {{0x61f91e07,0x6a7c0de2,0x00000000,0x00000000}},	//   _heul, _jëff, --, --, 
   {{0x60d91e08,0xf4100302,0x61f91e09,0xbe3800a7}},	//   _huum, ופי_, _keul, _взех_, 
   {{0x60d91e0a,0x61f91e0b,0x394800d8,0x75200327}},	//   _kuum, _jeul, азмо_, ħozz, 
   {{0x61f91e0c,0xdea0066d,0x60d91e0d,0xb238008f}},	//   _meul, _ویڈی, _juum, בערז, 
   {{0x60d91e0e,0x61f91e0f,0x38b404ce,0x9f4401f1}},	//   _muum, _leul, mærk_, zaný_, 
   {{0x44f4031c,0x66e00fbb,0x60d91e10,0xcbc400cf}},	//   _བསུར_, доса, _luum, _ىزىي, 
   {{0x61f91e11,0xf5e91e12,0xd0400198,0xbb4805d9}},	//   _neul, рмал_, _yumɓ, _ملڪن_, 
   {{0x9f440745,0x60d80eda,0x760401d3,0x24e401a9}},	// [1ad40] vaný_, _nuum, _néző, жмуи_, 
   {{0xe4551e13,0xc0e80023,0xb3740633,0xddd80205}},	//   ожу_, _ዚብሎ_, يداش, ykuş, 
   {{0x61f91e14,0x213d1e15,0x72047a13,0x9f4402fb}},	//   _beul, _asuh_, قوام, taný_, 
   {{0x61f80438,0x60d91e16,0x31691e17,0x00000000}},	//   _ceul, _buum, ишло_, --, 
   {{0xc0e8044e,0x60d80083,0x61f91e18,0xd34804fb}},	//   _ዚብል_, _cuum, _deul, _گیاه_, 
   {{0x60d91e19,0x9f440f91,0x65680112,0x00000000}},	//   _duum, saný_, äghe, --, 
   {{0xdfcc3092,0x61f91e1a,0x9f4402fb,0xa5b80332}},	//   نيه_, _feul, paný_, _gcób, 
   {{0x61f91e1b,0xa2d41788,0xceb000ec,0x508400f1}},	//   _geul, यदर्, رڙا_, _کارې, 
   {{0x60d81e0f,0xc0f80023,0x8c3c013d,0x00000000}},	//   _guum, ገጥሞ_, loği, --, 
   {{0xec68c78c,0x80e0015b,0xa0a002dd,0xdca00063}},	//   ррик_, _নিচ্, _жауд, мањи, 
   {{0xee380c9e,0x60d80254,0x61f80051,0x00000000}},	//   _вне_, _zuum, _yeul, --, 
   {{0x2eed1e1c,0x60d804ce,0x7ea400e4,0x7c240139}},	//   mpff_, _yuum, kópy, _öhrn, 
   {{0x7aec0219,0xa92802dd,0xd91001b9,0x2d9000fd}},	//   _čate, шіне_, پیپ_, _äye_, 
   {{0x3ea80f03,0xa5b8007b,0xac9401d3,0x00000000}},	//   čate_, _mbót, _گنڈا_, --, 
   {{0x644006ed,0x29049334,0x9aa40451,0x3e700051}},	//   ônim, _ānau_, _ڪميو, _báth_, 
   {{0xf1c80882,0x6a7c0036,0xe8143174,0x00000000}},	//   िधान, _sëff, _ताका_, --, 
   {{0xaae405d9,0x56951e1d,0x61f91e1e,0x8c48010b}},	// [1ad50] _اسڪو, фатт, _reul, _goşý, 
   {{0x61f91e1f,0x60d91e20,0x18680063,0x00000000}},	//   _seul, _ruum, _мањи_, --, 
   {{0x3e700597,0x61f91e21,0x60d80429,0xed7400b5}},	//   _fáth_, _peul, _suum, _seﾌ_, 
   {{0x60d91e22,0x00000000,0x00000000,0x00000000}},	//   _puum, --, --, --, 
   {{0x61f91e23,0x60d8735c,0x90e40472,0x00000000}},	//   _veul, _quum, وسون, --, 
   {{0x38b404ce,0x0084036b,0x537002d3,0x61f8d4d6}},	//   værk_, ялло, _ጻውዒት_, _weul, 
   {{0x61f91e24,0x60d86f57,0x90280953,0x00000000}},	//   _teul, _wuum, юцца_, --, 
   {{0xe1fc00fc,0x3e700296,0xcd280075,0xa5b80332}},	//   _þó_, _káti_, ﺰﻧﯩﯔ_, _gcóc, 
   {{0x9f443fa8,0xfd1000c6,0x6d5c01e1,0x00000000}},	//   ganò_, رجة_, _ńpar, --, 
   {{0x9e6400dd,0x3b845aab,0x3e7006ea,0x00000000}},	//   _ڈاؤن, злог, _máti_, --, 
   {{0x3e704e53,0xf410008f,0x3cec014f,0xc62000cc}},	//   _láti_, עפט_, spev_, _পোছা_, 
   {{0x3cec000d,0x00000000,0x00000000,0x00000000}},	//   ppev_, --, --, --, 
   {{0x2ea800f8,0x3ead1e25,0x8c6410ac,0x3e7000ae}},	//   _اپنی_, moet_, سطین, _ráth_, 
   {{0x3eac0489,0x95880210,0x2c640240,0x00000000}},	//   loet_, niąż, _ዝፈልጡ, --, 
   {{0x38c800dd,0xeb941677,0xc5ec0154,0x7a68009d}},	//   لاڑی_, _ниш_, _ওয়া_, _гийг_, 
   {{0xb9040801,0x3e700d12,0x00000000,0x00000000}},	//   _език, _báti_, --, --, 
   {{0x3ae0066a,0xe8f400fd,0x00000000,0x00000000}},	// [1ad60] _hóp_, _елы_, --, --, 
   {{0xdbe0004a,0x3ae008ce,0x38b403b2,0xe7e809ab}},	//   _déçu, _kóp_, kæri_, जुदा_, 
   {{0x9f4402fb,0xa5d0010e,0x3eac0098,0x24b800cc}},	//   ybná_, _aỳda, koet_, _অংশহ, 
   {{0x828802bf,0x3ae00208,0x6d4401bf,0xb6a400f3}},	//   осіб_, _móp_, ækak, _химл, 
   {{0x3ead1e26,0x76440652,0xb0301945,0x25d40375}},	//   doet_, _iaky, емлә, _מוכן_, 
   {{0x76440510,0x78ac0e8a,0x38b4008c,0x00000000}},	//   _haky, nobv, færi_, --, 
   {{0xb8dc003d,0x76451e27,0x274400bc,0x00000000}},	//   _ཇེ_, _kaky, míná_, --, 
   {{0x3ead1e28,0x76451e29,0xddc80790,0x00000000}},	//   goet_, _jaky, çişt, --, 
   {{0x76451e2a,0x6a7c1bce,0x78ac006f,0x2fd400f2}},	//   _maky, _jëfe, kobv, _فتاح, 
   {{0x3ae0001e,0x95880034,0x38b40162,0x30840ccb}},	//   _bóp_, ciąż, bæri_, _علاف, 
   {{0x3ead1e2b,0x78ac533a,0x3ae00208,0x00000000}},	//   boet_, dobv, _cóp_, --, 
   {{0x76451e2c,0x32dc00a2,0x6e9400c6,0x3eac003e}},	//   _naky, _aįyk_, _علشا, coet_, 
   {{0x6e211e2d,0x5b200066,0xb18400b8,0x00000000}},	//   _icob, وفیل, bhåų, --, 
   {{0x7644079b,0x6d400109,0xdd380302,0x78ac0810}},	//   _aaky, _isoa, _לעדכ, gobv, 
   {{0x3ae007ae,0x76451e2e,0x97a51e2f,0x57a4026a}},	//   _góp_, _baky, ертл, ешта, 
   {{0xfd50063f,0x7644010e,0x00000000,0x00000000}},	//   _nkeọ, _caky, --, --, 
   {{0xa5b87bd7,0x76451e30,0x78ac0810,0x48c401e0}},	// [1ad70] _abór, _daky, bobv, _ошоғ, 
   {{0x7644035a,0x3eac01f5,0x00000000,0x00000000}},	//   _eaky, zoet_, --, --, 
   {{0x76451e31,0x00000000,0x00000000,0x00000000}},	//   _faky, --, --, --, 
   {{0x6d4005f5,0x76441418,0x8e7c01e4,0x7ea80166}},	//   _osoa, _gaky, _juĝd, _köpş, 
   {{0x3ead1e32,0x8c3c0790,0xf6080244,0x00000000}},	//   voet_, loğu, _بتپه_, --, 
   {{0x6e211e33,0x0034141b,0xdb000419,0xd498361e}},	//   _acob, بکرخ, _vynú, _ерс_, 
   {{0x6d411e34,0x533400c7,0xbea51e35,0xa5b80248}},	//   _asoa, _перт, макк, _gbór, 
   {{0x64451e36,0x78ac0433,0x3ae00162,0xdb0401d3}},	//   _haji, zobv, _róp_, _élén, 
   {{0x7ae0074d,0x3eac99aa,0xf2d00375,0x6aac020c}},	//   wqlt, roet_, _יעל_, docf, 
   {{0x6e211e37,0x64451e38,0x3eac01c7,0x00000000}},	//   _ecob, _jaji, soet_, --, 
   {{0x64451e39,0xe81497ad,0x6d40005a,0x44300165}},	//   _maji, _ताजा_, _esoa, _mbz_, 
   {{0x64451e3a,0x6e211e3b,0x6d400421,0x630c0183}},	//   _laji, _gcob, _fsoa, _সহায়_, 
   {{0x76445101,0xe8f51e3c,0x35d00927,0x78ac006f}},	//   _raky, мля_, _दृढ़, tobv, 
   {{0x64451e3d,0x76451e3e,0x3ae00208,0x00000000}},	//   _naji, _saky, _tóp_, --, 
   {{0x6a7c002e,0x41dc0b02,0x8b9400a7,0x6e2002d0}},	//   _sëfe, यशास, _пръч, _ycob, 
   {{0x56f40323,0x4430219b,0x78ac01b9,0x00000000}},	//   мүүс, _abz_, sobv, --, 
   {{0x443001f5,0x195400b5,0x764400b8,0x00000000}},	// [1ad80] _bbz_, _ｉｌｌ_, _vaky, --, 
   {{0x64451e3f,0x76451e40,0x62800240,0x65c00075}},	//   _caji, _waky, ënon, тбуа, 
   {{0x76451e41,0x443019a2,0x3668fc21,0x64451e42}},	//   _taky, _dbz_, _дано_, _daji, 
   {{0xe2951e43,0x644400ad,0xa5b8097a,0x926407d6}},	//   мах_, _eaji, _icón, رگزم, 
   {{0xd1301efa,0x64451e44,0x8e7c010f,0x2164377e}},	//   امت_, _faji, _juĝe, мици_, 
   {{0x64451e45,0x8e7c01e4,0x6e211e46,0xa0640640}},	//   _gaji, _muĝe, _scob, даља_, 
   {{0x3e7001e1,0x1ae00154,0xdb200248,0x00000000}},	//   _látu_, কীতে_, _ìrèt, --, 
   {{0x667800c8,0x64440316,0x00000000,0x00000000}},	//   ַװיג, _zaji, --, --, 
   {{0x64451e47,0x39500076,0x38b406ea,0x7aec0064}},	//   _yaji, _nrys_, læru_, _čata, 
   {{0xcf0c015b,0x3ea815ad,0x64440067,0x00000000}},	//   _শহীদ_, čata_, _xaji, --, 
   {{0xdfcc00c6,0x395000a2,0xa3e01546,0x00000000}},	//   _نيك_, _arys_, फुट_, --, 
   {{0x6d411e48,0x8e7c010f,0xed591e49,0x6e20009a}},	//   _tsoa, _buĝe, _мое_, _ucob, 
   {{0x6d411e4a,0x39511e4b,0x3cf002fb,0x00000000}},	//   _usoa, _crys_, čový_, --, 
   {{0x58d51e4c,0x395000b5,0x3e7003b2,0x00000000}},	//   коят, _drys_, _dátu_, --, 
   {{0x44300810,0x3950a4fd,0x58d51e4d,0xb9041414}},	//   _rbz_, _erys_, торт, _बू_, 
   {{0x644457fb,0x3950e461,0x8c3c0205,0x00000000}},	//   _saji, _frys_, roğu, --, 
   {{0x644402d3,0xa5b80077,0x3950b896,0x4430107d}},	// [1ad90] _paji, _ecón, _grys_, _pbz_, 
   {{0x3e7026b8,0x6444e20a,0xa92c00d0,0x95c800f3}},	//   _hátt_, _qaji, ľôčk, фуса_, 
   {{0xa5b80597,0x64451e4e,0x3e7008ce,0x00000000}},	//   _gcón, _vaji, _kátt_, --, 
   {{0x44300204,0xd5b001ed,0xe7e8012c,0x00000000}},	//   _wbz_, افے_, जुरा_, --, 
   {{0x6444e7e4,0x3e700252,0x939806be,0x00000000}},	//   _taji, _mátt_, _əşər, --, 
   {{0x6444009f,0x439401f4,0xff240108,0x6ed8012d}},	//   _uaji, _загс, емко, _पंखु, 
   {{0x38b47eb1,0x6cfc0055,0x00000000,0x00000000}},	//   mært_, _ākiṃ, --, --, 
   {{0x38b40e38,0x3e70022c,0x4420923e,0xdb200241}},	//   lært_, _nátt_, lgh_, _ìrét, 
   {{0x44201368,0x00000000,0x00000000,0x00000000}},	//   ogh_, --, --, --, 
   {{0x4420ffe8,0x38b408d7,0x8e7c010f,0x9e640451}},	//   ngh_, nært_, _ruĝe, _ڪائن, 
   {{0x44203c76,0xba24010b,0x3e7001a8,0x00000000}},	//   igh_, нднк, _sátu_, --, 
   {{0x442004fb,0x39500151,0xb0600139,0x00000000}},	//   hgh_, _prys_, _şäxi, --, 
   {{0xa498007f,0xfe7800bc,0x3e700a87,0x3c580139}},	//   _gwòg, mků_, _dátt_, _нидэ_, 
   {{0xfe78012c,0xf7443cc5,0xe7e81431,0x38b4003b}},	//   lků_, него, जुला_, jært_, 
   {{0x7d0839c2,0x3e700252,0x8b651e4f,0x78f80014}},	//   lses, _fátt_, _لايم, _کعبس_, 
   {{0x39500006,0xfe7800bc,0x3e711e50,0xdb0001a8}},	//   _trys_, nků_, _gátt_, _kynþ, 
   {{0x44200076,0xc8f800cf,0xe4e0000d,0x38b4032e}},	// [1ada0] fgh_, _قويچ_, _कूदि_, fært_, 
   {{0x7d08049b,0x44200076,0x00000000,0x00000000}},	//   ises, ggh_, --, --, 
   {{0x7d080036,0x3e7002d2,0x9f98000d,0x00000000}},	//   hses, _játs_, näär_, --, 
   {{0x7d091e51,0x44211e52,0x798000a2,0xfe78013a}},	//   kses, agh_, _ýows, jků_, 
   {{0x6a7c1574,0xa4980100,0xfe78012c,0x7d08037e}},	//   _jëfa, _bwòd, dků_, jses, 
   {{0x7bcc01e4,0xe0cc01d9,0x9f980254,0x8fd40588}},	//   _ĝaun, مٲن_, käär_, ҕәҕә, 
   {{0x7d091e53,0x63b00122,0x8e7c0115,0xe29c3eeb}},	//   eses, čené, _ruĝb, _бð_, 
   {{0xe36001a9,0x00000000,0x00000000,0x00000000}},	//   _ёкти, --, --, --, 
   {{0x7d091e54,0xa5b800d2,0x35a402d3,0x21a0086f}},	//   gses, _ncól, _ዉድባት_, _битм, 
   {{0x3e701d1d,0xe61c0419,0x9f980254,0xb060013d}},	//   _sátt_, _hmôt_, fäär_, _şäfi, 
   {{0xa5b80077,0xfd4801f2,0x8a1810f3,0xfe78012c}},	//   _acól, _kalị, монс_, bků_, 
   {{0x7d080263,0x5884ec80,0x38b4013c,0xda1800bc}},	//   bses, ңыра, kærs_, थलगत_, 
   {{0x49a4054a,0x3e700162,0x44200363,0x7d0800e5}},	//   тынғ, _vátt_, ygh_, cses, 
   {{0x6a7c0de2,0xefc002d3,0x845c0023,0x64880135}},	//   _dëfa, _ስሩዕ_, _ሰፊሕን_, nżit, 
   {{0x38b400b5,0x0ac400c7,0x3e700162,0x00000000}},	//   vært_, _ишиҭ, _tátt_, --, 
   {{0x6a7c002e,0xdb2001a8,0x9a840354,0x8c3c06be}},	//   _fëfa, _árás, _буьл, coğr, 
   {{0x38b42d75,0x442005b1,0xa5b80332,0x44b51486}},	// [1adb0] tært_, tgh_, _gcól, вбас, 
   {{0x7d1d1e55,0x44211e56,0xfe78012c,0x00000000}},	//   àssi, ugh_, zků_, --, 
   {{0x44200842,0x29080048,0x38b40623,0x00000000}},	//   rgh_, lsca_, rært_, --, 
   {{0x7d091e57,0x6a7c002e,0xaab00aff,0x290800ae}},	//   yses, _yëfa, ीतिक, osca_, 
   {{0xfe78038e,0x7d080175,0x00000000,0x00000000}},	//   vků_, xses, --, --, 
   {{0x7d08000d,0xf078008e,0x00000000,0x00000000}},	//   vses, мичә_, --, --, 
   {{0xfe78012c,0x7d080175,0x7c24002f,0x7aec0171}},	//   tků_, wses, _öhri, _čato, 
   {{0x7d091e58,0xc1d0beb4,0x69dc487e,0x00000000}},	//   tses, _көлә, _ngqe, --, 
   {{0x21280a40,0x2908068f,0x7d091e59,0xfe7800bc}},	//   _ëch_, jsca_, uses, rků_, 
   {{0x69dc014b,0xfe78012c,0x7d091e5a,0xdfe8074d}},	//   _agqe, sků_, rses, _хьал_, 
   {{0x8c3c0ab7,0x7d091e5b,0xcd2803e6,0x29080077}},	//   toğr, sses, وسین_, esca_, 
   {{0x20051e5c,0x7d091e5d,0x00000000,0x00000000}},	//   lani_, pses, --, --, 
   {{0x20040421,0xf2d0008f,0x7e68014f,0x9f980254}},	//   oani_, יעט_, mjep, säär_, 
   {{0x69dc014b,0x7e691e5e,0x62800023,0x49c40032}},	//   _egqe, ljep, ënoj, ыһын_, 
   {{0x29091e5f,0x20045930,0xfaa44bbc,0x9d740014}},	//   asca_, iani_, _иако, _زٕژا_, 
   {{0x20051e60,0x7e691e61,0xb994007b,0x59b4009d}},	//   hani_, njep, _للعب, _бөгс, 
   {{0x8e7c010f,0x7e6800e4,0x73e4005b,0x00000000}},	// [1adc0] _juĝa, ijep, возз, --, 
   {{0x8e7c0115,0xa5b801e7,0x7e68340f,0x00000000}},	//   _muĝa, _gcóm, hjep, --, 
   {{0x7e691e62,0x2fdc0175,0xf7701291,0x00000000}},	//   kjep, _rgtg_, _ضاد_, --, 
   {{0xf5051e63,0x35f896b4,0x8f8401ec,0x20040254}},	//   _измо, _تردد_, ңқал, eani_, 
   {{0x20051e64,0x7e682ab7,0xdb0002d2,0x00000000}},	//   fani_, djep, _kynó, --, 
   {{0xe0cc00aa,0x3f50031c,0xa1545476,0x644000d8}},	//   يزو_, _bġu_, ташу_, ônit, 
   {{0x7e68219c,0xce943032,0x6488025c,0x289800df}},	//   fjep, лакъ, rżit, ויסא, 
   {{0x20040869,0x7e680023,0x91c401e0,0x29080076}},	//   aani_, gjep, _йәлл, ysca_, 
   {{0x614007d6,0xe294026a,0x0cd80063,0xaab0012d}},	//   _кета, _рат_, ндић_, ीतसक, 
   {{0x20051e65,0xa3d40358,0xc0441e24,0x7e6800c7}},	//   cani_, ाखच_, _مخمو, ajep, 
   {{0x09bd1e66,0xab851e67,0x5f2400d8,0x92e400fe}},	//   ोध्य, тупк, _аохм_, পীৰ_, 
   {{0x8e7c00df,0x7e682804,0x7bc4010b,0x6488031c}},	//   _fuĝa, cjep, ырыҗ, nżir, 
   {{0x8e7c00df,0x99282077,0xe9dc00c7,0x00000000}},	//   _guĝa, кюра_, ndúi_, --, 
   {{0xcb5405c6,0x9b9001d5,0x00000000,0x00000000}},	//   _منتظ, اشیش, --, --, 
   {{0xeff4001f,0x290800f3,0x37d400eb,0x00000000}},	//   _ወንድ_, ssca_, _ত্বর, --, 
   {{0x9b000139,0xf41800fe,0x947401e2,0x00000000}},	//   _өзәд, ন্মৰ_, یدلا, --, 
   {{0x20051e68,0x85047ff6,0x00000000,0x00000000}},	// [1add0] yani_, اوطن, --, --, 
   {{0x20051e69,0xeabc0ffb,0x7e68045f,0x00000000}},	//   xani_, llù_, zjep, --, 
   {{0x6a7c002e,0x97a40395,0x00000000,0x00000000}},	//   _jëfo, _врял, --, --, 
   {{0xa4980100,0xdbdc01e1,0xa2803fe6,0x51f400ae}},	//   _avòt, _yìók, جیرو, لسهر, 
   {{0x956400a7,0x3f50031c,0xd24401c6,0x00000000}},	//   _кърд, _sġu_, рэхи, --, 
   {{0x20051e6a,0x8e7c010f,0x04c84cec,0x2a8c012d}},	//   uani_, _ruĝa, _سوزي_, ręby_, 
   {{0x7e6805ac,0x43540092,0x00000000,0x00000000}},	//   tjep, _የሚቆጣ, --, --, 
   {{0xfe4453ab,0x8f740220,0xc1044706,0xfd48022e}},	//   унио, руші, _موري, език_, 
   {{0x20051e6b,0xee351e6c,0x225c0d8d,0x7e680ce0}},	//   pani_, уны_, _inuk_, rjep, 
   {{0x7e691e6d,0xac802b2a,0x2ca450c0,0x3af402e8}},	//   sjep, йгыл, лкып_, лямс, 
   {{0xb0b400c8,0x99c011ba,0x3f500327,0x8f08074d}},	//   _עפעס_, _ইলেক, _uġu_, _ахча_, 
   {{0xeabc0ffb,0x62800023,0xccc40137,0xdb000210}},	//   glù_, ënoh, лбөй, _synó, 
   {{0x18840116,0x00000000,0x00000000,0x00000000}},	//   иңин, --, --, --, 
   {{0x2dc00131,0xad1805d0,0x75980241,0x3b0800f3}},	//   _ﮬﻪﻣﻤ, _נוצר, _nífẹ, _зеко_, 
   {{0xe7343ae0,0xeabc0395,0x00000000,0x00000000}},	//   лер_, blù_, --, --, 
   {{0x6a7c1bce,0x2a6800b5,0x00000000,0x00000000}},	//   _jëfl, cjcb_, --, --, 
   {{0x9980003e,0xa87401c0,0x25a8045a,0xddc80064}},	// [1ade0] _keiō_, _өөрт_, _cxcl_, _ilgų, 
   {{0xdb000649,0x225c102c,0x853401b9,0x13d800f2}},	//   _hynñ, _anuk_, شومچ, نداژ_, 
   {{0x25a91e6e,0xe2800116,0xe3700092,0x6c78010f}},	//   _excl_, әлчи, _ወቸውጉ, ערעד, 
   {{0xa49802e2,0x3164005a,0x00000000,0x00000000}},	//   _pwòc, txoz_, --, --, 
   {{0x759801e1,0xe7e805dc,0xe1f4009d,0x00000000}},	//   _fífẹ, जुका_, угч_, --, 
   {{0xa0651e6f,0xe61c0142,0xf8b4012d,0x00000000}},	//   лача_, _glôb_, ृतिय, --, 
   {{0x5f903baf,0x00000000,0x00000000,0x00000000}},	//   йишт, --, --, --, 
   {{0xfe740032,0x00000000,0x00000000,0x00000000}},	//   ғүә_, --, --, --, 
   {{0xddd81ebd,0x6a7c00e8,0xa2b001d3,0x00000000}},	//   thuš, _sëfo, _اینڈ, --, 
   {{0xa11020ea,0x4c94022e,0x7c6400d1,0x00000000}},	//   _دوكت, риос, لاپل, --, 
   {{0xa5d00432,0xa9d000d1,0xa4b4011a,0x2078010f}},	//   _aỳla, ﻘﺘﯩﺴ, רליה_, _ראבא, 
   {{0xaa6403fb,0x5ca0013d,0x00000000,0x00000000}},	//   уток, _һичб, --, --, 
   {{0xd5b0000d,0xd31401ec,0x470400b8,0x00000000}},	//   _अँगड़, тiкт, bhṛṣ, --, 
   {{0xdca00116,0xf4180183,0x98491846,0xc1e000cd}},	//   _лачи, ন্তৰ_, ляса_, _फल्ग, 
   {{0x8e7c010f,0x80c408a3,0x00000000,0x00000000}},	//   _juĝo, ितते, --, --, 
   {{0x56942103,0x7d1c0162,0x00000000,0x00000000}},	//   баст, ássg, --, --, 
   {{0xa8a42f84,0x00000000,0x00000000,0x00000000}},	// [1adf0] _مصدو, --, --, --, 
   {{0x08c40166,0xe78400d8,0x00000000,0x00000000}},	//   _әбүн, _бумо, --, --, 
   {{0x94a91e70,0x852403e6,0x9a68335b,0x00000000}},	//   утта_, اوڕۆ, _شمیل_, --, 
   {{0x4154468d,0x25b40451,0xdb9800df,0x01d842f4}},	//   ивес, _منجھ_, עסאר, نواع_, 
   {{0xd7c85dcd,0xf4180183,0x225c19d6,0x720000d1}},	//   _لویه_, ন্ধৰ_, _vnuk_, زۈلم, 
   {{0xd1b80372,0x9eb0723c,0xa4980ba1,0xe3b00214}},	//   داما_, әшкә, _evòr, _هرز_, 
   {{0xfe7000ae,0x00000000,0x00000000,0x00000000}},	//   قدة_, --, --, --, 
   {{0xcee8117d,0x225c08a4,0xbd440592,0xf4180183}},	//   درون_, _unuk_, لنبي, ন্দৰ_, 
   {{0x9980031c,0x113826c6,0xa1840408,0x00000000}},	//   _qbiż_, _مثلث_, _сывл, --, 
   {{0xdb000649,0x8e7c0115,0xec74023a,0x03d0002b}},	//   _synñ, _fuĝo, ипы_, _sāṃg, 
   {{0x506402d9,0x98a00327,0xbe14007b,0xd13000f1}},	//   _утта, _nsiġ_, _نواع, _ومې_, 
   {{0xeb951e71,0x09ac0154,0x7c3000ef,0x00000000}},	//   рию_, _গণজা, _žerā, --, 
   {{0xc4c4033f,0x5dd000fe,0x00000000,0x00000000}},	//   वताओ, _ধ্ৰু, --, --, 
   {{0xa5b8007b,0x00000000,0x00000000,0x00000000}},	//   _gcói, --, --, --, 
   {{0xb8cc00e1,0x36940032,0xf7447651,0x580401ec}},	//   _कद_, ашас, шево, _қонғ, 
   {{0x8e2c022e,0xf9880592,0xe6140114,0x00000000}},	//   _judа_, _لنبي_, идс_, --, 
   {{0x95740240,0x00000000,0x00000000,0x00000000}},	// [1ae00] ረፍትን_, --, --, --, 
   {{0x33f51e72,0x32dc00a2,0xa87401af,0xf8e008a3}},	//   рчас, _aįyp_, _көст_, पदीप, 
   {{0x64880327,0x00000000,0x00000000,0x00000000}},	//   rżip, --, --, --, 
   {{0x8e7c01e4,0xf214012d,0x00000000,0x00000000}},	//   _ruĝo, दृढ़_, --, --, 
   {{0x11547705,0xd0e875f5,0x00000000,0x00000000}},	//   склю, اکرم_, --, --, 
   {{0x37d803d4,0xe7f81fe7,0x00000000,0x00000000}},	//   _ব্যৰ, ्रया_, --, --, 
   {{0xeea8af83,0x00000000,0x00000000,0x00000000}},	//   ктик_, --, --, --, 
   {{0x4bc40032,0xa5b8007b,0x9df400a7,0x7f440309}},	//   ҙөлг, _scói, анът_, çhqa, 
   {{0xe7f812eb,0xe1600451,0x00000000,0x00000000}},	//   ्रमा_, _وگهي, --, --, 
   {{0x62800200,0x00000000,0x00000000,0x00000000}},	//   ënov, --, --, --, 
   {{0xe45400c8,0xe4780375,0x00000000,0x00000000}},	//   בייט_, דריכ, --, --, 
   {{0x386403f9,0xe7f84a76,0x00000000,0x00000000}},	//   _ɗore_, ्रभा_, --, --, 
   {{0x8cf400c6,0xb4d40490,0x00000000,0x00000000}},	//   _اكتش, _हळू_, --, --, 
   {{0xa5b80241,0x7d1c0798,0x98b81422,0x1b9400e5}},	//   _gbóy, ásse, илят_, ائیب_, 
   {{0x6a7c0de2,0xe9dc002d,0x00000000,0x00000000}},	//   _jëfk, edút_, --, --, 
   {{0xd7c91147,0x00000000,0x00000000,0x00000000}},	//   شوقه_, --, --, --, 
   {{0x6a840014,0xd12400cf,0x00000000,0x00000000}},	// [1ae10] _مشکٕ, _تۅ_, --, --, 
   {{0x7688010e,0x9d18011a,0x00000000,0x00000000}},	//   _aýyd, כומט, --, --, 
   {{0x833409ac,0x00000000,0x00000000,0x00000000}},	//   снех, --, --, --, 
   {{0x66800517,0x7bd8008f,0x62200137,0x00000000}},	//   _بیرل, אַנק, تۉرل, --, 
   {{0x9f4400ae,0xd1480066,0x00000000,0x00000000}},	//   rcní_, لشون_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6a7c00e8,0x3f8002fb,0x321001d3,0xc2c401f7}},	//   _cëfk, áhu_, ányú_, _هيسي, 
   {{0x2bb81d15,0xe9dd1e73,0x00000000,0x00000000}},	//   _उड़ा, ndús_, --, --, 
   {{0x0d0802dd,0x00000000,0x00000000,0x00000000}},	//   адық_, --, --, --, 
   {{0xa6bc00cc,0x00000000,0x00000000,0x00000000}},	//   ্দিয়, --, --, --, 
   {{0xbb441d6c,0x9e6400cf,0xc94808a8,0x44ec08a5}},	//   щенк, _پاان, _רמ_, _lþ_, 
   {{0x62880007,0x00000000,0x00000000,0x00000000}},	//   nhgo, --, --, --, 
   {{0x81e803d4,0xec6d1e74,0xa9a11e75,0xf7d01884}},	//   _য়া_, _еп_, зияд, ﻘﯩﻨﺪ, 
   {{0x3ff8008f,0xbb440139,0x998000ee,0xfaa4010b}},	//   טפֿע, _гекк, _ediş_, ршүн, 
   {{0x9f4402fb,0x3af4001b,0x00000000,0x00000000}},	//   ybný_, _уялс, --, --, 
   {{0xba740133,0x00000000,0x00000000,0x00000000}},	//   _چاکت, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [1ae20] --, --, --, --, 
   {{0xc044021a,0x11680330,0xe7f83cbe,0x00000000}},	//   _غږ_, یلای_, ्रणा_, --, 
   {{0x213c020c,0xe9dc067c,0x95e400cf,0x00000000}},	//   _apuh_, bdús_, _ويدۇ, --, 
   {{0x3668334a,0x41d815e0,0x35a51e76,0x6288025c}},	//   _само_, _बृहस, _гамг, ghgo, 
   {{0x8e7c01e4,0x222864ec,0x645800e5,0x00000000}},	//   _fuĝj, ازمی_, íció, --, 
   {{0xaf041b0a,0xe1f40107,0x74143cc4,0x00000000}},	//   бчик, иҳӣ_, _دوسا, --, 
   {{0xe7f8023e,0x00000000,0x00000000,0x00000000}},	//   ्रता_, --, --, --, 
   {{0xa0640184,0x6288002d,0xc40801d9,0xb224084c}},	//   _һауа_, chgo, _متہٕ_, _ымбл, 
   {{0xdcf4006c,0xffa40daf,0x6260030d,0x2d800124}},	//   یریش_, йләү, _эвта, áke_, 
   {{0xb0b80117,0x00000000,0x00000000,0x00000000}},	//   _субх_, --, --, --, 
   {{0x2d80596b,0x6fb45aa3,0x19580184,0x8e7c01e4}},	//   ške_, _امضا, ҙары_, _juĝk, 
   {{0xe9dc011f,0x2bcc0073,0xa92801ec,0x8c180066}},	//   ddúr_, हेगा, ліге_, ديگر_, 
   {{0x6a7c00e8,0x00000000,0x00000000,0x00000000}},	//   _jëfi, --, --, --, 
   {{0xd91809fe,0x1cc41b4b,0x62880240,0x00000000}},	//   щью_, _ཉེར_, zhgo, --, 
   {{0x5c3406a9,0x44ec08a5,0x940c06be,0x6440022e}},	//   _הטוב_, _sþ_, _ödə_, еnin, 
   {{0x5bc0c015,0x00000000,0x00000000,0x00000000}},	//   _عقيل, --, --, --, 
   {{0xe9dc00cf,0x449800c0,0xb8e401ec,0x00000000}},	// [1ae30] rdús_, аваю_, _мсэқ, --, 
   {{0xd8c80156,0x213c003e,0x7afc39ae,0xb06000a2}},	//   _གེརི, _rpuh_, ćstv, _şäni, 
   {{0x62891e77,0x81f800be,0x73c0013d,0x00000000}},	//   thgo, لفار_, дәте, --, 
   {{0x4ac8d034,0x672496a9,0x527400db,0x00000000}},	//   रतिव, mujj, зушу, --, 
   {{0x80c40490,0x75a4035b,0x47d40214,0x67240083}},	//   ितले, _дырҧ, _ديگر, lujj, 
   {{0x11d51e78,0x43943f1d,0x2b4c0332,0x00000000}},	//   ستند, _дагс, _osfc_, --, 
   {{0x4ac808a3,0xdef40092,0x00000000,0x00000000}},	//   रताव, _ወህኒ_, --, --, 
   {{0xa4980428,0xfde801b9,0x00000000,0x00000000}},	//   _mwòm, шдик_, --, --, 
   {{0x629801f4,0x00000000,0x00000000,0x00000000}},	//   _imuo, --, --, --, 
   {{0x67240a49,0x00000000,0x00000000,0x00000000}},	//   kujj, --, --, --, 
   {{0xb90c0521,0x3b080640,0x3df402d5,0x00000000}},	//   balị_, јемо_, _дзес, --, 
   {{0xd1300014,0x34a400ab,0xd97801e0,0x3a9800d4}},	//   _تمے_, _खद्द, бргә_, ртою_, 
   {{0x7c947092,0x00000000,0x00000000,0x00000000}},	//   _وشتا, --, --, --, 
   {{0x67241418,0x2c44001f,0x92e40154,0x00000000}},	//   fujj, ያቀርቡ, পীয়_, --, 
   {{0x6299065f,0xeb94a2b6,0x6724693e,0x1af0015b}},	//   _omuo, _миш_, gujj, _আটকে_, 
   {{0x8e7c0115,0x00000000,0x00000000,0x00000000}},	//   _ruĝk, --, --, --, 
   {{0xa85802dd,0x35a401c0,0x7dfc00c0,0x00000000}},	// [1ae40] _ءﯗﻱ_, цааг, mąsč, --, 
   {{0x672479c4,0x969413f9,0x62991e79,0xc0d401ec}},	//   bujj, _کیرش, _amuo, _ﺟﻮﯞﻳ, 
   {{0xb7140214,0xeaac01ed,0xb4c8000d,0xf34857c6}},	//   _ببخش, _سٹی_, _ऊठी_, рпел_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc32c00db,0x00000000,0x00000000,0x00000000}},	//   _ەەم_, --, --, --, 
   {{0x6298769b,0xd01001b9,0x00000000,0x00000000}},	//   _emuo, رلب_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7654a1fd,0x386402a8,0xd39800fd,0xa5b91e7a}},	//   ndyy, _ɗora_, _кәҗә_, _gcós, 
   {{0x8e7c008f,0xb8084a01,0x21a0013d,0x7534012d}},	//   _juĝi, वराम_, _житм, ntyz, 
   {{0x7d1c00dd,0x8e7c0115,0xdbd4013d,0x67241fde}},	//   ássa, _muĝi, _fäüz, yujj, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdfcc1fbb,0x2b4c00b5,0xaee001ec,0xfaec004b}},	//   _شين_, _vsfc_, _تۋعى, دګو_, 
   {{0xdb000109,0x8e7c01e4,0x672404ba,0x00000000}},	//   _synô, _ruĝh, wujj, --, 
   {{0x6d40011c,0xa5b8311a,0xe78411f4,0xa498007f}},	//   _ipoa, _ocór, оубо, _pwòm, 
   {{0xb06000fd,0xda980023,0x00000000,0x00000000}},	//   _ğäli, ገለጽና_, --, --, 
   {{0x893401d3,0x00000000,0x00000000,0x00000000}},	//   _فٹبا, --, --, --, 
   {{0x04c806f6,0xa5b8baac,0x67240a49,0x00000000}},	// [1ae50] موري_, _acór, sujj, --, 
   {{0x6d400134,0x62980395,0x473428eb,0x00000000}},	//   _mpoa, _smuo, _енос, --, 
   {{0x8c3c03ee,0x00000000,0x00000000,0x00000000}},	//   ciğe, --, --, --, 
   {{0x8e7c00df,0x77b8011a,0xd7640133,0xdbd40166}},	//   _fuĝi, _למתח, _تۆفی, _räüz, 
   {{0x1a9c008f,0xda5c00df,0x00000000,0x00000000}},	//   סידע, יכאל, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d411e7b,0xeff40020,0xa5b800c6,0x00000000}},	//   _apoa, _ወንዝ_, _gcór, --, 
   {{0x629801f7,0x43940107,0x53a8012d,0x00000000}},	//   _umuo, _даҳс, कपरश, --, 
   {{0x6a7c002e,0x00000000,0x00000000,0x00000000}},	//   _jëfu, --, --, --, 
   {{0xed54074d,0x00000000,0x00000000,0x00000000}},	//   чоь_, --, --, --, 
   {{0x6d400270,0x2bc400ee,0x00000000,0x00000000}},	//   _epoa, злэп_, --, --, 
   {{0x2f2c06be,0x00000000,0x00000000,0x00000000}},	//   _təgr_, --, --, --, 
   {{0x0eb835e6,0x4e9401d5,0xc0e80092,0x00000000}},	//   _بالغ_, _تشلر, መቻሉ_, --, 
   {{0x7e791e7c,0x8e7c00df,0x9980030a,0xacf8011a}},	//   _howp, _ruĝi, _reiń_, _ההסכ, 
   {{0x3668721f,0x8b940395,0xdb20002f,0x00000000}},	//   баво_, _оръч, ßräu, --, 
   {{0x37880107,0xf5e8009d,0x44311e7d,0x00000000}},	//   абҳо_, смал_, _acz_, --, 
   {{0x2914027d,0xa5b800ae,0xb0600166,0x00000000}},	// [1ae60] _فقيد_, _scór, _şämi, --, 
   {{0x7e7909c4,0x44300099,0x363428c4,0x75342e05}},	//   _lowp, _ccz_, _کردس, rtyz, 
   {{0xa8780302,0x44300175,0x1dd800dc,0x00000000}},	//   _האיר, _dcz_, मेतत, --, 
   {{0x7e781bde,0x3878030a,0x39500175,0x443003e0}},	//   _nowp, _hopr_, _ksys_, _ecz_, 
   {{0x44300065,0xe2c80109,0x38791e7e,0xa5b800e5}},	//   _fcz_, n地y_, _kopr_, _adóf, 
   {{0x61fd1e7f,0x26c40374,0xaf040138,0x75d400ec}},	//   ıqla, _īnoi_, пчик, _ويھا, 
   {{0xdfcc092f,0x6d411e80,0xdd9407dd,0xddc8033f}},	//   هيه_, _spoa, ҧшь_, _nagł, 
   {{0x7e78039a,0x00000000,0x00000000,0x00000000}},	//   _cowp, --, --, --, 
   {{0xefe8001f,0x25ec012d,0xc0e80092,0x00000000}},	//   መራው_, _अलसी_, መቻል_, --, 
   {{0x3a300432,0x6a7d1e81,0xa0a01c56,0xd6c400cc}},	//   _acyp_, _lëft, _зауд, ্দিয, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7e78c006,0x602c00e5,0x00000000,0x00000000}},	//   _gowp, rőmű, --, --, 
   {{0xaae40014,0xbe3000c7,0x66d00205,0x00000000}},	//   _کستو, _рҭыш, nçke, --, 
   {{0x387803cb,0x00000000,0x00000000,0x00000000}},	//   _copr_, --, --, --, 
   {{0x44311e82,0x2ee40083,0x6a7ca87b,0x387802f0}},	//   _rcz_, _kiof_, _sëfu, _dopr_, 
   {{0xa498007f,0x44300356,0x64540135,0x00000000}},	//   _twòk, _scz_, wdxi, --, 
   {{0xeabc0dd4,0xa3dd1e83,0xddc80034,0x56942769}},	// [1ae70] moù_, देन_, _zagł, хатт, 
   {{0xeabc03bd,0x38791e84,0xddd80784,0x00000000}},	//   loù_, _gopr_, nkuš, --, 
   {{0xb63003e6,0x6d440240,0xdcf802f0,0x00000000}},	//   رکێش, çkaj, vyuč, --, 
   {{0xeabc03bd,0x6a7c01c7,0xa498007f,0x00000000}},	//   noù_, _gëft, _otòg, --, 
   {{0xeabc03bd,0x69c800b5,0x7e780175,0x00000000}},	//   ioù_, _øged, _rowp, --, 
   {{0x660d1e85,0xeabc0dd4,0x94a801d5,0x1df40a8a}},	//   _heck, hoù_, _етса_, ीर्ष_, 
   {{0xeabc0dd4,0x660d1e86,0x00000000,0x00000000}},	//   koù_, _keck, --, --, 
   {{0xeabc0dd4,0x660c04cc,0xae000116,0xddd800ef}},	//   joù_, _jeck, نۈمى, ekuš, 
   {{0x660d1e87,0xeabc0ad3,0x51840b01,0xc03400f3}},	//   _meck, doù_, _пуфа, _онај, 
   {{0x3b84f01d,0x660c2604,0xeabc0156,0x7d0c031c}},	//   длог, _leck, eoù_, _ħasd, 
   {{0x8e7c01e4,0xeabc0489,0x88d400b8,0x40e80345}},	//   _ruĝv, foù_, _mṛdn, _اوڕێ_, 
   {{0x660c7e80,0xeabc03bd,0x768809a5,0x387808e5}},	//   _neck, goù_, _aýyn, _sopr_, 
   {{0x3ead1e88,0x38791e89,0x0b4401ec,0x00000000}},	//   mnet_, _popr_, _үнін, --, 
   {{0xeabc0165,0xb9040073,0x6a7c0200,0x00000000}},	//   aoù_, _फळ_, _bëfs, --, 
   {{0xec1000aa,0x3ead1e8a,0xfbd11e8b,0x17c8016c}},	//   _شويد, onet_, _हरिम, яҳои_, 
   {{0x3ead1e8c,0x8e7c01e4,0x660c0419,0x00000000}},	//   nnet_, _fuĝu, _ceck, --, 
   {{0xe5a11e8d,0x3ead1e8e,0xb9081867,0xe7a0000d}},	// [1ae80] вити, inet_, _بزعم_, _बैठs, 
   {{0x3ead1e8f,0xfbd003e5,0x660c00ad,0x00000000}},	//   hnet_, _हराम, _eeck, --, 
   {{0x660d1e90,0x3ead1e91,0xa5b8772a,0x00000000}},	//   _feck, knet_, _adód, --, 
   {{0x660d1e92,0xddd8488c,0x3eac9e25,0x00000000}},	//   _geck, zkuš, jnet_, --, 
   {{0x3cfc0218,0x2ee401ab,0xa3dc00af,0xddd802d1}},	//   _ntwv_, _riof_, देब_, ykuš, 
   {{0x3ead1e93,0xeabc03bd,0x74151e94,0x660d1e95}},	//   enet_, zoù_, _زورا, _zeck, 
   {{0x3ead1e96,0xa49804cc,0x00000000,0x00000000}},	//   fnet_, _stòg, --, --, 
   {{0x3ead1e97,0xeabc0165,0x9f5c03b2,0x00000000}},	//   gnet_, xoù_, ðrák_, --, 
   {{0x32051e98,0xeabc0156,0x00000000,0x00000000}},	//   mboy_, voù_, --, --, 
   {{0x32051e99,0x3ead1e9a,0x8e7c0115,0xeabc030a}},	//   lboy_, anet_, _ruĝu, woù_, 
   {{0xeabc0dd4,0x3ead1e9b,0xddd91e9c,0x7d0c025c}},	//   toù_, bnet_, chuž, _ħase, 
   {{0x32051e9d,0xddd8151c,0x3ead1e9e,0xde080137}},	//   nboy_, skuš, cnet_, _ۇرۇۇ_, 
   {{0xeabc03bd,0x3204002d,0x660c0e21,0xfca8032f}},	//   roù_, iboy_, _reck, _کانو_, 
   {{0x660d1e9f,0xeabc0dd4,0x32040072,0xb8e40124}},	//   _seck, soù_, hboy_, ессқ, 
   {{0x32040280,0x660d1ea0,0x6a7c0023,0x036002dd}},	//   kboy_, _peck, _dëfr, _ءﻭﺯﺍ, 
   {{0x85051ea1,0x9f6000e5,0x00000000,0x00000000}},	//   فورن, övér_, --, --, 
   {{0x32051ea2,0x660c0628,0xf8acf9e1,0x1fc400cc}},	// [1ae90] dboy_, _veck, شکی_, ষেপস, 
   {{0x3eac5844,0x660d1ea3,0xe78439b8,0x0354008e}},	//   znet_, _weck, _жумо, нүгә_, 
   {{0x660c04f3,0x32040109,0xae0c000d,0x00000000}},	//   _teck, fboy_, सरान_, --, 
   {{0x660c0004,0x97a400c7,0xa5b800e5,0xd32401f4}},	//   _ueck, _шрыл, _adóe, тьфи, 
   {{0x3eacf940,0xe16400c6,0x00000000,0x00000000}},	//   vnet_, بداي, --, --, 
   {{0x7ff51ea4,0xe3d00cef,0x3ead1ea5,0xf53406a9}},	//   رستا, _айгө, wnet_, _אנשי_, 
   {{0x3ead1ea6,0x2d804675,0x3204022e,0x00000000}},	//   tnet_, øken_, bboy_, --, 
   {{0x3eac05d5,0x522400d1,0xc1d00116,0x7d0c025c}},	//   unet_, _аффа, _йөлә, _ħasb, 
   {{0x61f84a7d,0x6e2401d3,0xa99001e1,0xbd4401c8}},	//   _iful, ókba, _íwèé_, رندي, 
   {{0x7688010b,0x61f803b2,0x6aac010f,0x00000000}},	//   _aýyl, _hful, encf, --, 
   {{0x3ead1ea7,0x2918014f,0x20051ea8,0xfaa51ea9}},	//   pnet_, _avqa_, mbni_, еано, 
   {{0x3d94084c,0x200401a9,0x2f58011a,0x00000000}},	//   _пиер, lbni_, _מדענ, --, 
   {{0x61f80451,0xf2d000c8,0xa3dc041c,0x00000000}},	//   _mful, טעט_, देत_, --, 
   {{0xdb800022,0xbc380451,0xfce400d8,0x00000000}},	//   _аҳои, _رستا_, _џоко, --, 
   {{0x2bc43daa,0xfaa51eaa,0x61f91eab,0xb2200008}},	//   _रुपा, _пако, _oful, _þægi, 
   {{0x61f804ba,0xc6a40063,0x32040072,0x5964022e}},	//   _nful, врђи, xboy_, _аниғ, 
   {{0xb4646950,0xa5b801d3,0xe6400209,0x320403e0}},	// [1aea0] нкал, _adób, ыетп, vboy_, 
   {{0xb9fc2295,0x61f91eac,0xe4540075,0xe9d40139}},	//   _ሁሉ_, _aful, нжу_, _якы_, 
   {{0xb2251ead,0x32051eae,0x7984017a,0x5fb8012d}},	//   емел, tboy_, lykw, _ऊँगल, 
   {{0xbb54001f,0x32040076,0x2004031c,0xd1e400d1}},	//   _ቆይተዋ, uboy_, ebni_, نياۋ, 
   {{0x80d4036b,0x6ebc01f9,0x60f428f6,0x00000000}},	//   چمنچ, शवसु, енія_, --, 
   {{0x61f80a49,0x40980451,0x74b8009d,0xcf300023}},	//   _eful, وٽنگ_, _хумс_, _ደርፍታ, 
   {{0xce940801,0x61f89508,0x32040051,0xddd80432}},	//   какъ, _fful, pboy_, lduň, 
   {{0x20040ba7,0x8e7c01e4,0xa2e094c9,0x3204022e}},	//   abni_, _ruĝs, _босд, qboy_, 
   {{0x2004031c,0x00000000,0x00000000,0x00000000}},	//   bbni_, --, --, --, 
   {{0x253400c8,0x016800ec,0x7d000139,0x4bc400db}},	//   עניש_, _تحفو_, dírğ, көйг, 
   {{0x7688010e,0x5fa401ad,0xdfcc007b,0x47a400eb}},	//   _aýym, _केपल, _هيك_, _খুনী, 
   {{0xf4140154,0x09b400eb,0x00000000,0x00000000}},	//   ালির_, _ঘরবা, --, --, 
   {{0x28680120,0x00000000,0x00000000,0x00000000}},	//   прво_, --, --, --, 
   {{0xf54c001f,0x56940220,0x258401e1,0x6cd8022e}},	//   _ምርጫዎ, ңарт, _lílú_, _эфес_, 
   {{0x92102017,0x7c643500,0xf4140154,0xdca000ea}},	//   ाराज_, _جانل, ালার_, _љаји, 
   {{0xa5b80332,0x25840241,0x45d401d5,0xd1d80023}},	//   _ndóc, _nílú_, вобс, ኮላት_, 
   {{0x47a800cc,0xc5391eaf,0x00000000,0x00000000}},	// [1aeb0] _গৰখী, ьпах_, --, --, 
   {{0xa49800a3,0x9538084c,0xa2800101,0xa5b800e5}},	//   _stòb, эзут_, گیرو, _adóc, 
   {{0x61f91eb0,0x2bc47220,0xe784e753,0x00000000}},	//   _pful, _रुमा, _чупо, --, 
   {{0xa28031d6,0xe7f82c2e,0x00000000,0x00000000}},	//   دیرو, ्रका_, --, --, 
   {{0xd5b800d8,0x00000000,0x00000000,0x00000000}},	//   _зср_, --, --, --, 
   {{0xe0540d73,0x6fa000c5,0x15e40150,0x00000000}},	//   عیات_, _केहू, _ﻋﺭﻀﻬ, --, 
   {{0x61f91eb1,0xb880012c,0xf3c40124,0x7984002d}},	//   _tful, _říka, _артҟ, zykw, 
   {{0x61f80925,0x925800c2,0x975808a8,0x200401a9}},	//   _uful, _паст_, תיהו_, sbni_, 
   {{0xddc80171,0xb22c02d2,0x2bc421bd,0x9268010a}},	//   _ingū, _æðaþ, _रुबा, _ярра_, 
   {{0x1ea805d9,0x212c016d,0x00000000,0x00000000}},	//   _کائي_, mugh_, --, --, 
   {{0x60c11eb2,0x212c047e,0xdb0401d3,0xe2340092}},	//   monm, lugh_, _élün, _የምትኖ, 
   {{0x60c11eb3,0xfaa51eb4,0x62891eb5,0x0f18007b}},	//   lonm, тамо, nkgo, _أغلب_, 
   {{0x6e400e56,0xc0dc0023,0x00000000,0x00000000}},	//   _ئچىم, ቕጽል_, --, --, 
   {{0x60c11eb6,0x4c840064,0x00000000,0x00000000}},	//   nonm, _йлів, --, --, 
   {{0xe7351eb7,0x8b641e39,0x212c27cc,0xd1d4001f}},	//   кер_, _مايم, hugh_, _ይዘት_, 
   {{0x24740201,0x60c11eb8,0x8e7c01e4,0x7a3400e5}},	//   _በማለት_, honm, _juĝp, _شعبئ, 
   {{0x60c11eb9,0x66e11eba,0x74e805f5,0xa3dc2a05}},	// [1aec0] konm, рота, ддаг_, देस_, 
   {{0x14c81060,0x778400c7,0x62880af9,0x212c0192}},	//   رهای_, _алоз, ekgo, dugh_, 
   {{0x60c11ebb,0xf9880832,0x212c062c,0xe2a00208}},	//   donm, _رنگي_, eugh_, _trừ_, 
   {{0x6b78008f,0x157801ec,0x00000000,0x00000000}},	//   ורענ, _كەزد_, --, --, 
   {{0x5fa4190e,0x00000000,0x00000000,0x00000000}},	//   _केबल, --, --, --, 
   {{0xa3dc49f1,0xe0411ebc,0xefdc02d3,0x84580e92}},	//   देह_, инчи, _ሕሩይ_, _прст_, 
   {{0x7d0c025c,0xa0640063,0x00000000,0x00000000}},	//   _ħasa, таја_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa498007f,0x7688010e,0x60c0007f,0x9d100a89}},	//   _gwòs, _aýyk, bonm, адыч, 
   {{0xa3dcbcbc,0xec302c10,0xaa7802f0,0xe0d401f4}},	//   देव_, جودگ, kmýc, _аву_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d2402d5,0xdcd000db,0x00000000,0x00000000}},	//   _аддз, лбөө, --, --, 
   {{0x6e200521,0x49a40032,0xdd8c3016,0x00000000}},	//   _idob, уынғ, _ووم_, --, 
   {{0xcb342d1f,0xdca024fc,0xefc00023,0x6d4c012d}},	//   _бекъ, _качи, _ድሩዕ_, łbas, 
   {{0x9cd40302,0x44b4013e,0x2ab40139,0x8e2000d4}},	//   _שווה_, ҳбас, _аңны_, _вiд_, 
   {{0x60c11ebd,0x212c0165,0x893800d8,0xa5b800e5}},	//   zonm, yugh_, _зпис_, _adóa, 
   {{0x60c11ebe,0xa2b000cd,0x00000000,0x00000000}},	// [1aed0] yonm, ेकस्, --, --, 
   {{0x7d1d1ebf,0xa4980241,0x88580798,0x00000000}},	//   ássi, _awòr, _џинс_, --, 
   {{0x6b980c86,0x2c1801ad,0xaad4000d,0x00000000}},	//   nztg, _मजनू_, _ठठाक, --, 
   {{0xe61c0129,0x60c0033b,0x00000000,0x00000000}},	//   _clôt_, wonm, --, --, 
   {{0x628806f2,0x81441f7e,0x00000000,0x00000000}},	//   rkgo, انتن, --, --, 
   {{0xa4980428,0x6e211ec0,0x212c0793,0x75980a7c}},	//   _ewòr, _adob, rugh_, _טירח, 
   {{0xa3dc0b03,0xa280034c,0xbea51ec1,0xb4b400fd}},	//   देश_, _پیشو, лакк, _сирә, 
   {{0x60c11ec2,0xa1840022,0x2bc400cd,0x212401e2}},	//   sonm, _иызл, _रुधा, _ليری_, 
   {{0x6e200a49,0x50f402bf,0x1cc4031c,0x60c11ec3}},	//   _ddob, _взут, _ཉེད_, ponm, 
   {{0x6e211ec4,0x1fa4151e,0x60c0014f,0x00000000}},	//   _edob, _ирег, qonm, --, 
   {{0x3e34007b,0x3864013d,0x00000000,0x00000000}},	//   _مفار, _ğor_, --, --, 
   {{0x450800cc,0x9e642e0b,0x38642057,0x3934009d}},	//   _লিনক_, _جائن, _şor_, лэгс, 
   {{0xe8f41ed2,0x64451ec5,0x00000000,0x00000000}},	//   лля_, _obji, --, --, 
   {{0x6e202a5c,0xc8b40209,0x5c04d3a6,0x8d751ec6}},	//   _zdob, ассы, _ряда, _خاما, 
   {{0xded0001f,0xf6240276,0x69c8005c,0xbb44011c}},	//   _ያለን_, лдво, _øgen, _сейк, 
   {{0x6444003a,0x56f40137,0x00000000,0x00000000}},	//   _abji, лүүс, --, --, 
   {{0x232407a5,0x00000000,0x00000000,0x00000000}},	// [1aee0] ғочи_, --, --, --, 
   {{0xb4bc00c5,0x00000000,0x00000000,0x00000000}},	//   आवे_, --, --, --, 
   {{0xe61c0142,0xa3dc0ebb,0x733400ae,0x00000000}},	//   _clôs_, देल_, طرائ, --, 
   {{0xe2948f43,0xa5b82b76,0xefd40023,0x00000000}},	//   лах_, _idón, _ይኸዱ_, --, 
   {{0x6e200c67,0x21651188,0xe7b004fb,0x926801e0}},	//   _rdob, лици_, _نمید, ерҙа_, 
   {{0xb2240139,0x00000000,0x00000000,0x00000000}},	//   _әмал, --, --, --, 
   {{0xa854011a,0x5f40027d,0x5fa40037,0x00000000}},	//   ריצה_, منول, _केदल, --, 
   {{0x1ef400c6,0x3f8000b0,0x00000000,0x00000000}},	//   دعوة_, ähua_, --, --, 
   {{0xe2951ec7,0xe0cc01d9,0xfc440419,0x00000000}},	//   _сат_, _کٲل_, _číre_, --, 
   {{0xf1e4002e,0x6b98002f,0x9f9000c7,0xdcb4004e}},	//   _y斡ng_, tztg, ршәш, лгыч_, 
   {{0xaf051ec8,0xdb640395,0x00000000,0x00000000}},	//   _спел, грял_, --, --, 
   {{0x6e20341a,0xd7f849c6,0x8c0c015b,0xdb100432}},	//   _udob, ғур_, _শাওন_, _ýaýd, 
   {{0x6b9800e5,0xa5b8ec23,0x00000000,0x00000000}},	//   sztg, _adón, --, --, 
   {{0xa4991ec9,0xcb54007b,0x00000000,0x00000000}},	//   _atòn, _ننتظ, --, --, 
   {{0xee14037e,0xc434006c,0xd7f80798,0x00000000}},	//   _cmｇ_, یکست, ѓур_, --, 
   {{0xa8a40116,0x5b00009f,0x00000000,0x00000000}},	//   _әрик, _اِيم, --, --, 
   {{0x04c80be2,0xd6d81220,0x84142901,0x00000000}},	// [1aef0] نوري_, утр_, имах, --, 
   {{0x84c41a98,0xd72400cc,0x00000000,0x00000000}},	//   рәмд, _পহৰা_, --, --, 
   {{0x1cb800c8,0x6444009f,0xa3dc41d8,0x00000000}},	//   עמבע, _vbji, दें_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd24401c6,0xbbd03507,0x00000000,0x00000000}},	//   сэхи, _हर्क, --, --, 
   {{0x6440004e,0xddd00135,0x00000000,0x00000000}},	//   ònid, ħaże, --, --, 
   {{0xdb0803b2,0xc10400ec,0x00000000,0x00000000}},	//   _óhøg, _چوري, --, --, 
   {{0xc1043c19,0xa3dc00cd,0x8f7401ec,0x00000000}},	//   _نوري, देः_, суші, --, 
   {{0x212807ae,0xadf4023e,0x8d28013d,0xdda001ef}},	//   _ích_, ीड़न_, гның_, _ohňů_, 
   {{0x225c02d2,0x06c802dd,0x8d540395,0x00000000}},	//   _hauk_, _ﺒﻌﻴﺩ, стъч, --, 
   {{0xbb44aebf,0x225c0a73,0x22940724,0xcdc4185c}},	//   шенк, _kauk_, _eçke_, _қашқ, 
   {{0xa5b800e8,0xf2d0008f,0x8e7400c0,0x8e38009f}},	//   _ndóo, ַעם_, _гушч, _مسهر_, 
   {{0x225c0477,0xded00092,0x00000000,0x00000000}},	//   _mauk_, _ያለና_, --, --, 
   {{0x225d1eca,0xa5b801e1,0x7d1c06ea,0x2bc40118}},	//   _lauk_, _adóo, ássu, _रुवा, 
   {{0xa7a508d9,0x7d09120b,0xdb0000cf,0x37e42708}},	//   акра_, lpes, _exnò, ровг, 
   {{0x225d1ecb,0xd8c80327,0xb37400f2,0x00000000}},	//   _nauk_, _གེམི, یداش, --, 
   {{0x33f51ecc,0x7d091ecd,0xa49802e2,0x2480036e}},	// [1af00] ачес, npes, _pwòp, _bojm_, 
   {{0x49000323,0x7d091ece,0x00000000,0x00000000}},	//   _хүрг, ipes, --, --, 
   {{0xd7651ecf,0x225c0e04,0x7d08013f,0x24800200}},	//   _انجی, _bauk_, hpes, _dojm_, 
   {{0x23247fba,0x00000000,0x00000000,0x00000000}},	//   роци_, --, --, --, 
   {{0x28d80d5f,0x225c00c0,0xe2940114,0x00000000}},	//   _मीडि, _dauk_, шац_, --, 
   {{0x944401d3,0x7d080254,0xe0d401c6,0x5fa4000d}},	//   _دھرن, dpes, авч_, _केहल, 
   {{0x225ca1e7,0x7d0801e2,0xc0c002d3,0x6440004e}},	//   _fauk_, epes, _ድኹም_, ònie, 
   {{0x225c0024,0x8c3c0790,0x7d0802d2,0x00000000}},	//   _gauk_, miği, fpes, --, 
   {{0x8c3c0365,0x71a42be5,0x7d0c010e,0xffa4104e}},	//   liği, _тааз, _çasl, иләү, 
   {{0x5fa41be1,0xa0a11ed0,0x6adc87ea,0x00000000}},	//   _केवल, _дауд, नग्र, --, 
   {{0xee3828a8,0x7d08c2ea,0x8c3c0790,0x00000000}},	//   _ане_, apes, niği, --, 
   {{0xfc340022,0xa92801ec,0xd91000e5,0x00000000}},	//   аҭә_, кіге_, ڈیٹ_, --, 
   {{0x7d1c0174,0xd91000e5,0x00000000,0x00000000}},	//   ásst, ویٹ_, --, --, 
   {{0xd9191ed1,0x8c3c0205,0x00000000,0x00000000}},	//   шью_, kiği, --, --, 
   {{0x9cd8011a,0x00000000,0x00000000,0x00000000}},	//   _שקופ, --, --, --, 
   {{0x8c3c0ab7,0xa498004e,0x569400a8,0x18b400fb}},	//   diği, _etòl, оаст, йҙөр, 
   {{0x225d1ed2,0x2b4c0051,0x3be8586a,0x00000000}},	// [1af10] _rauk_, _hpfc_, _иләү_, --, 
   {{0x225d1ed3,0x8c3c0790,0x31640010,0x795401f7}},	//   _sauk_, fiği, dvoz_, _اَٿا, 
   {{0x14b817ee,0x29080427,0x316400d7,0x7d080200}},	//   _आदरण, lpca_, evoz_, zpes, 
   {{0x9f400248,0x00000000,0x00000000,0x00000000}},	//   _àjé_, --, --, --, 
   {{0x016400d8,0xd7c80244,0x00000000,0x00000000}},	//   скло, _مویه_, --, --, 
   {{0x225c039a,0x918400d1,0x90e40472,0x8c3c0139}},	//   _wauk_, غۇلۇ, يسون, biği, 
   {{0x2bc405f9,0x225d1ed4,0x03e40183,0x8c3c0790}},	//   _रुला, _tauk_, _প্ৰণ, ciği, 
   {{0x945400ac,0x57b80375,0x7d0801a9,0x0244009f}},	//   _çərş, ילוב_, tpes, _دَرَ, 
   {{0x09cc015b,0xbc1810da,0xd16402e8,0xed4c0050}},	//   রেতা, ліні_, _мъфи, ٹھن_, 
   {{0x0dc8026a,0xc0b401f7,0x00000000,0x00000000}},	//   јући_, _اجرڪ, --, --, 
   {{0xb7d40882,0x7cec002d,0xbfd4516c,0x5ea001d9}},	//   kṣar, _wźro, _اياع, _وۅتل, 
   {{0x7d08d3da,0xeb951ed5,0xa5b800e5,0x00000000}},	//   ppes, сию_, _adóm, --, 
   {{0x3ead1ed6,0x914802ea,0xa49856ed,0x8d742d74}},	//   miet_, _kɔ́n_, _atòm, _واها, 
   {{0x3ead1ed7,0x212c01c3,0x00000000,0x00000000}},	//   liet_, irgh_, --, --, 
   {{0x316402fb,0xfa680d1d,0x9b400244,0x00000000}},	//   zvoz_, _байк_, _بۆجو, --, 
   {{0x869827f0,0x160808b0,0xa3c809bb,0x35a408ca}},	//   атут_, рмақ_, _लड़_, бабг, 
   {{0x29080810,0xddd80010,0x59bc0073,0x6cf8010f}},	// [1af20] cpca_, hkuž, _उशिर, ָפעס, 
   {{0x3ead1ed8,0x8c3c0365,0x7688010e,0x33f51ed9}},	//   hiet_, tiği, _aýyt, счас, 
   {{0x3ead1eda,0x78ac006f,0x00000000,0x00000000}},	//   kiet_, mibv, --, --, 
   {{0x3eac3aaf,0x8c3c03ee,0x969407d6,0x78ac003a}},	//   jiet_, riği, _بیرش, libv, 
   {{0x644000f7,0x76551edb,0x8c3c03e0,0xcff4011c}},	//   ònic, meyy, siği, оплъ, 
   {{0x2eb00a28,0x31651edc,0x7654022f,0x78ac003a}},	//   ुक्त, rvoz_, leyy, nibv, 
   {{0x3eac1bce,0x3f400077,0xb8f8031c,0xe9dc0419}},	//   fiet_, góu_, _འཚ_, jfún_, 
   {{0x3ead1edd,0xefd4001f,0x78ac05b8,0x9c4001c6}},	//   giet_, _ይኸው_, hibv, үхэл, 
   {{0x2b4c0120,0x74180154,0xa5b8398f,0xa2e03e38}},	//   _spfc_, দলীয়_, _adój, _хотд, 
   {{0x76551ede,0x00000000,0x00000000,0x00000000}},	//   heyy, --, --, --, 
   {{0x2e480801,0x78ac0099,0x15f80034,0x7534017a}},	//   _бяло_, dibv, ंखार_, huyz, 
   {{0x3ead1edf,0x7cd801c0,0x00000000,0x00000000}},	//   ciet_, лмөр_, --, --, 
   {{0xac8c02d3,0x00000000,0x00000000,0x00000000}},	//   _ዝገርም_, --, --, --, 
   {{0xa49801ab,0x7654007f,0x00000000,0x00000000}},	//   _ptòm, eeyy, --, --, 
   {{0x97d80736,0x00000000,0x00000000,0x00000000}},	//   مظفر_, --, --, --, 
   {{0x22940139,0x00000000,0x00000000,0x00000000}},	//   _oçka_, --, --, --, 
   {{0xe0cc045e,0x6aad1ee0,0xddd80219,0xddc80432}},	// [1af30] িগতভ, micf, zkuž, _magş, 
   {{0x3ead1ee1,0xddc800a2,0x00000000,0x00000000}},	//   ziet_, _lagş, --, --, 
   {{0x3eac0428,0x96b802ab,0x22940139,0x00000000}},	//   yiet_, ्कशॉ, _açka_, --, 
   {{0x6aac02fa,0xddc8010e,0x3eac031c,0x765400b8}},	//   nicf, _nagş, xiet_, ceyy, 
   {{0x763800c8,0x661c0bf1,0x212c007f,0xd14802da}},	//   _דערג, maqk, urgh_, مشون_, 
   {{0x3ead1ee2,0x661c0309,0x22a001d9,0xd49800f3}},	//   wiet_, laqk, _کٔرہ, _лрс_, 
   {{0xddc80209,0x3ea401c6,0x0d0801ec,0xbea51ee3}},	//   _bagş, жийг, ұдық_, жайк, 
   {{0x64551ee4,0x661c87b9,0x00000000,0x00000000}},	//   lexi, naqk, --, --, 
   {{0x0d0801ec,0x00000000,0x00000000,0x00000000}},	//   бдық_, --, --, --, 
   {{0x6454982b,0x3ead1ee5,0x661c02d1,0xa5b801d3}},	//   nexi, siet_, haqk, _adók, 
   {{0x3ead1ee6,0xa4981ed9,0x661c02d1,0x78ac004c}},	//   piet_, _atòk, kaqk, vibv, 
   {{0x6454014b,0x39e91ee7,0x68e40399,0xddc800a2}},	//   hexi, идно_, emjd, _gagş, 
   {{0xa9a049c1,0x2d8008fb,0x78ac006f,0x00000000}},	//   дияд, øket_, tibv, --, 
   {{0x9ce422d7,0x7688032e,0x8c3c0166,0x00000000}},	//   _уцел, _nýyr, fiğu, --, 
   {{0x78ac93df,0x7654208d,0x64540f85,0xddc8010e}},	//   ribv, teyy, dexi, _yagş, 
   {{0xf6082a60,0x768800ee,0x64540393,0x00000000}},	//   شتره_, _aýyr, eexi, --, 
   {{0x64540564,0x34a80640,0x76551ee8,0x1dac0073}},	// [1af40] fexi, авао_, reyy, _जेमत, 
   {{0x670001f2,0xd3140150,0x00000000,0x00000000}},	//   ọkat, уiпт, --, --, 
   {{0x644000cf,0x8d8c0092,0x661c03e3,0x00000000}},	//   ònia, ማርተው_, baqk, --, 
   {{0xe1f4052f,0x7c2c02a8,0x3668026a,0xb6340101}},	//   ҙгә_, _ɓara, _тамо_, _بعدت, 
   {{0xe1f418ce,0x64551ee9,0xffa40137,0x7d0c036e}},	//   әгә_, bexi, үлчү, _çash, 
   {{0xc2080116,0x00000000,0x00000000,0x00000000}},	//   لغۇم_, --, --, --, 
   {{0x23240d09,0xa5b801d3,0x00000000,0x00000000}},	//   _мори_, _adóh, --, --, 
   {{0xc4080050,0x00000000,0x00000000,0x00000000}},	//   _نتہٕ_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xddc80432,0xa9e00150,0x00000000,0x00000000}},	//   _wagş, _ﺍﺭﯨﺴ, --, --, 
   {{0x6aad1eea,0x661c02d1,0x5ba00395,0x00000000}},	//   ticf, yaqk, дряз, --, 
   {{0x645402c4,0x2d8000d4,0x81cc00eb,0x00000000}},	//   zexi, økes_, রধর_, --, 
   {{0x6aac55f5,0xfee81b80,0x00000000,0x00000000}},	//   ricf, _اعلى_, --, --, 
   {{0xd7f80cb9,0x661c02d1,0x00000000,0x00000000}},	//   жут_, waqk, --, --, 
   {{0x58d47c0c,0x6aac00b0,0x64540381,0x7d0c0003}},	//   форт, picf, vexi, _ħasi, 
   {{0x645402c4,0xaae42a9f,0x00000000,0x00000000}},	//   wexi, _بستو, --, --, 
   {{0x64540f71,0x661c0986,0x9ae800db,0x00000000}},	// [1af50] texi, raqk, _بىيك_, --, 
   {{0xd5b81ed2,0x69dc208d,0x661c02d1,0x48c40124}},	//   іст_, _izqe, saqk, _хәма, 
   {{0xa4980ba1,0x661c03f0,0xd498399f,0xc2740166}},	//   _luòg, paqk, црт_, зылъ, 
   {{0x661c03f0,0x64540393,0x5274146a,0xe2a801c8}},	//   qaqk, sexi, душу, جائن_, 
   {{0x645416b8,0x00000000,0x00000000,0x00000000}},	//   pexi, --, --, --, 
   {{0xa5b800c6,0x656caa24,0x66000134,0xa6c40154}},	//   _ndói, _irch, ɛnka, লগওয়, 
   {{0x44211eeb,0x2bc4000d,0xddd8031c,0xa0700150}},	//   mah_, _रँगा, skuż, зықш, 
   {{0x44211eec,0xa5b91eed,0x656c02f0,0x9f4001e1}},	//   lah_, _adói, _krch, _àjí_, 
   {{0x2fdc010a,0x720801d9,0x62991eee,0x442001ab}},	//   _eztg_, _طفلہ_, _iluo, oah_, 
   {{0x44211eef,0x23bc05ba,0xa5b80784,0x656d1ef0}},	//   nah_, _एखाद, _teóf, _mrch, 
   {{0xfa6817be,0x2d8003a1,0x39500af9,0x7a68442d}},	//   банк_, øker_, _spys_, бинг_, 
   {{0x44211ef1,0xa5b80113,0x3a9819c9,0x91b801d3}},	//   hah_, _geóg, стою_, _اطہر_, 
   {{0x44211ef2,0x1ca8025c,0x8eb00150,0x00000000}},	//   kah_, བོད_, _جەيت, --, 
   {{0x20c8c853,0x450809bd,0x2bc405f9,0x62980368}},	//   िविध, _লিংক_, _रुका, _lluo, 
   {{0x6298123c,0xded00092,0x369401ec,0xa8d400db}},	//   _oluo, _ያገኙ_, пшас, سوفئ_, 
   {{0xa5b80005,0xaa400131,0xe7340b3e,0x4ad80014}},	//   _xeóg, _كۆپى, џет_, _واٹھ_, 
   {{0x656c01ab,0x7c2c03f9,0x1c1c00af,0x35a401c6}},	// [1af60] _crch, _ɓarn, _मजाल_, чааг, 
   {{0x442061c6,0x34c42e35,0x00000000,0x00000000}},	//   gah_, ववेद, --, --, 
   {{0x62991ef3,0x656d1ef4,0x00000000,0x00000000}},	//   _bluo, _erch, --, --, 
   {{0x44211ef5,0x629805d5,0x7c200112,0x81e40154}},	//   aah_, _cluo, halr, নশন_, 
   {{0x44211ef6,0x7af40477,0xf0743c1a,0xd010036b}},	//   bah_, _miyt, зилә_, پلب_, 
   {{0x44211ef7,0x629800c5,0xa50400d8,0x06c40154}},	//   cah_, _eluo, _хера_, ্ষণি, 
   {{0x7c2001ed,0x3cf00034,0xeea85378,0x00000000}},	//   dalr, ीदने_, йтик_, --, 
   {{0x62991ef8,0x7af403f0,0xede401e0,0x00000000}},	//   _gluo, _niyt, пһеҙ_, --, 
   {{0xa4991ef9,0x00000000,0x00000000,0x00000000}},	//   _awòy, --, --, --, 
   {{0x7af4007f,0x32040789,0x7c211efa,0x2198011a}},	//   _aiyt, lcoy_, galr, _הבמא, 
   {{0xa4980295,0x00000000,0x00000000,0x00000000}},	//   _etòw, --, --, --, 
   {{0x44211efb,0x8ec400aa,0x15ec00ab,0x7c20000d}},	//   zah_, _تښتو, झधार_, aalr, 
   {{0x44211efc,0xa3d0038e,0x9b4069f1,0x00000000}},	//   yah_, _हुन_, ونیو, --, 
   {{0x2ba0003e,0x7c20e3f7,0x5c7001ce,0x4420102c}},	//   _cécé_, calr, _пліт, xah_, 
   {{0x44211efd,0x656c882b,0xfca87138,0x690800de}},	//   vah_, _srch, _بانو_, _oļeg, 
   {{0x44211efe,0x656c0c5e,0x656801bf,0x00000000}},	//   wah_, _prch, ægho, --, 
   {{0x2efc01a9,0x44f40064,0x00000000,0x00000000}},	// [1af70] _lutf_, дпас, --, --, 
   {{0x656c04bf,0x7d1c004a,0x62980006,0xe7d80154}},	//   _vrch, âssi, _sluo, _দলীয, 
   {{0x62980024,0x68fc0009,0x00000000,0x00000000}},	//   _pluo, _huqd, --, --, 
   {{0x41b41cbc,0x7c211eff,0x61fc022e,0x00000000}},	//   ومار, zalr, оqla, --, 
   {{0xe8e808ea,0x656d1f00,0x44211f01,0xa5b800e5}},	//   _རྫོག, _urch, pah_, _adóv, 
   {{0x68fc0d62,0x44211f02,0x6f180142,0x7c200009}},	//   _muqd, qah_, _bwtc, xalr, 
   {{0x7c211f03,0x629800fb,0xe61c0086,0x672402d0}},	//   valr, _tluo, _keô_, nsjj, 
   {{0x6298235a,0x68f401d9,0x2efc0175,0x7c20035a}},	//   _uluo, _lixd, _dutf_, walr, 
   {{0x7af40309,0x68fc0978,0x61f87c86,0x00000000}},	//   _riyt, _nuqd, _igul, --, 
   {{0x7af50717,0x79e40150,0x00000000,0x00000000}},	//   _siyt, _ﺍﺭﯨﻤ, --, --, 
   {{0x291802d1,0x7fb91f04,0xcee801d9,0x92c003d4}},	//   _awqa_, _بهار_, _کرٕن_, ঁতৰ_, 
   {{0x7d7800db,0x7c20035a,0x394800db,0x00000000}},	//   _ومار_, salr, озмо_, --, 
   {{0x61f80161,0x7c291f05,0x68fc0014,0x7e691f06}},	//   _mgul, _долг_, _cuqd, mdep, 
   {{0x7e691f07,0x68fcd8a7,0x68f403b9,0x37e401c6}},	//   ldep, _duqd, _cixd, догг, 
   {{0x61f91f08,0x29180548,0x7e68014b,0xebe000d1}},	//   _ogul, _ewqa_, odep, _иошп, 
   {{0x7e691f09,0x61f91f0a,0x31400020,0x68f400db}},	//   ndep, _ngul, _የግብር, _eixd, 
   {{0x68f40334,0xb4651f0b,0x7e68002f,0x200401ef}},	// [1af80] _fixd, мкал, idep, kcni_, 
   {{0x52b82c30,0x7e68005b,0xe454004e,0x00000000}},	//   ेक्स, hdep, мжу_, --, 
   {{0xf99024c5,0x7e680209,0xf7711f0c,0x32040a73}},	//   _سبک_, kdep, _شاد_, tcoy_, 
   {{0xf504016c,0x7e6800b5,0xe0cc004b,0x68fc047e}},	//   _озмо, jdep, یزو_, _yuqd, 
   {{0xd1dc0020,0x7e680003,0x6f180175,0x386800d8}},	//   ሕፍት_, ddep, _swtc, odbr_, 
   {{0x61f80c8c,0x2bc4216a,0x6ab805c0,0x00000000}},	//   _egul, _रुझा, _उद्र, --, 
   {{0xe3604965,0x1fa002e8,0xe81c00ce,0x6c940150}},	//   _икри, кръг, भरता_, _ﺘﺠﻨﺏ_, 
   {{0x7e691f0d,0x61f82f99,0x2cac0064,0x00000000}},	//   gdep, _ggul, _smfd_, --, 
   {{0x6498054e,0x20040010,0x88d40055,0x80f8022e}},	//   _mîin, bcni_, _kṛtn, _еххт_, 
   {{0x68fc01a9,0x61f801d5,0xb5d80150,0x00000000}},	//   _ruqd, _zgul, _ﺃﻭﻟﺌ, --, 
   {{0x68fc014f,0x753400d0,0x2cac00c0,0x00000000}},	//   _suqd, hryz, _vmfd_, --, 
   {{0x3d181d15,0x68fc047e,0x38780142,0x8c4800a2}},	//   _मौके_, _puqd, _anpr_, _başý, 
   {{0x961404c5,0x68fc014f,0xe0d4010a,0x00000000}},	//   িণাম_, _quqd, _авă_, --, 
   {{0xfb1800dd,0x8c4800a2,0x7aec0419,0x06c80150}},	//   _کروں_, _daşý, _ďate, _ﺒﻌﻘﺩ, 
   {{0x6440eacd,0xa4981497,0x68f40393,0x2bc400bc}},	//   ònim, _luòc, _vixd, _रुचा, 
   {{0xddd82220,0x68fc014f,0x70c829c7,0x6498054e}},	//   ljuš, _tuqd, ाकुल, _cîin, 
   {{0x7d0c4bc4,0x68f40014,0x61f801a9,0xa5b80332}},	// [1af90] _çast, _tixd, _rgul, _ndót, 
   {{0x61f807de,0xddd816a3,0x68f4003a,0x00000000}},	//   _sgul, njuš, _uixd, --, 
   {{0x7e680212,0x61f8022e,0x6618000d,0xa5b801d3}},	//   ydep, _pgul, _õuko, _adót, 
   {{0x4ed0015b,0x8c24009e,0x02c8858a,0x00000000}},	//   াগুল, পলিন_, िकेन, --, 
   {{0xcfd42e56,0x7e6801f1,0x55051f0e,0xb6c00166}},	//   _ﭘﺎﺭﺗ, vdep, _ачса, _сөрд, 
   {{0x04c917a3,0x3f684bf5,0x7170c35c,0x00000000}},	//   _روزي_, зико_, اهوا, --, 
   {{0x7e68fa77,0xff503267,0x92e40724,0x61f805d5}},	//   tdep, اخت_, äşül, _tgul, 
   {{0xcee8774e,0x61f91f0f,0xa4980ba1,0x2ee4b5fd}},	//   ورين_, _ugul, _fuòc, _chof_, 
   {{0xee351f10,0xaea00efb,0xd244010b,0x2a680175}},	//   хны_, دەني, _шэри, ddcb_, 
   {{0x7e68dd44,0xa4980241,0x271c000d,0x00000000}},	//   sdep, _itòs, _बबूर_, --, 
   {{0x1ee42be7,0x7a68fd34,0x7e6800db,0xe51c00dc}},	//   _قوطی_, пинг_, pdep, मीति_, 
   {{0xeabc011c,0xa3e4000d,0x75e800e5,0x00000000}},	//   gnù_, _परन_, nözé, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd1dc02d3,0x9b000117,0x00000000,0x00000000}},	//   ሕፍቲ_, _иҷод, --, --, 
   {{0x38680158,0x64980356,0xe5a00aac,0x75e801d3}},	//   rdbr_, _pîin, ҳити, közé, 
   {{0xf5080a70,0xb904009e,0x00000000,0x00000000}},	//   знал_, _বং_, --, --, 
   {{0xe5a11f11,0x49640304,0xcdac010f,0x00000000}},	// [1afa0] гити, _аның, ֿיבֿ, --, 
   {{0xa5b801ed,0x38780311,0x45080183,0x00000000}},	//   _adós, _unpr_, _লিখক_, --, 
   {{0xdaf80589,0x00000000,0x00000000,0x00000000}},	//   dåºn, --, --, --, 
   {{0xa6811f12,0x6d5401b8,0x0cac0073,0x00000000}},	//   _блюд, _äyag, _चष्म, --, 
   {{0x7644035a,0x2ee40142,0x00000000,0x00000000}},	//   _icky, _rhof_, --, --, 
   {{0x74151f13,0x92c02158,0x2ee40240,0x00000000}},	//   _سورا, ঁতে_, _shof_, --, 
   {{0xb90003bd,0xf1d001c6,0x00000000,0x00000000}},	//   _ཧེ_, _өөдө, --, --, 
   {{0xb64000b5,0x425001d9,0x4c940276,0x7d0c025c}},	//   _ｍｖ_, _نۆمر, ӂиос, _ħasr, 
   {{0x7644017a,0x00000000,0x00000000,0x00000000}},	//   _mcky, --, --, --, 
   {{0xa3e51f14,0x2bc8004e,0x4c9400f3,0x00000000}},	//   _परम_, зумо_, тиос, --, 
   {{0x7644035a,0x8e200408,0xaf340066,0xddd800c0}},	//   _ocky, _гiа_, _سرات, rjuš, 
   {{0xa3d00dad,0x00000000,0x00000000,0x00000000}},	//   _हँस_, --, --, --, 
   {{0x6b54013d,0xadb40116,0x00000000,0x00000000}},	//   _bügö, _سۇدا_, --, --, 
   {{0x7c2c0b45,0x764403ac,0x38700124,0x6e200051}},	//   _ɓark, _acky, ақьт, _heob, 
   {{0xa498007f,0x57a4009d,0xf8ac0133,0x00000000}},	//   _otòr, гшта, ڵکی_, --, 
   {{0xa3e410f7,0xd6d91f15,0x49751f16,0x442402f0}},	//   _परब_, ету_, _алис, _žl_, 
   {{0x6e200051,0xa5b8b941,0x00000000,0x00000000}},	// [1afb0] _meob, _adór, --, --, 
   {{0x6e211f17,0x22940a9d,0x7644035a,0xe7840212}},	//   _leob, _içki_, _ecky, _зумо, 
   {{0xee2400b2,0x7d1c01d3,0x75e801d3,0x00000000}},	//   _پٽ_, ássz, tözé, --, 
   {{0x53d00073,0x00000000,0x00000000,0x00000000}},	//   _तुळश, --, --, --, 
   {{0x95c800e4,0x1dac0037,0x00000000,0x00000000}},	//   _зура_, _जेंत, --, --, 
   {{0xdce800e2,0x00000000,0x00000000,0x00000000}},	//   _orgā, --, --, --, 
   {{0x6e200730,0x3c2c01ed,0xbea401b9,0xfe70007b}},	//   _beob, _jövő_, какк, لدة_, 
   {{0x44311f18,0x6e200332,0x00000000,0x00000000}},	//   _hdz_, _ceob, --, --, 
   {{0x6e211f19,0x31200014,0x0f480023,0xd658011a}},	//   _deob, _نہنٲ, _ዘይርከ, תיחת_, 
   {{0x1fa42e58,0x7f94035b,0x3f8001e3,0x00000000}},	//   _прег, _иазх, ähus_, --, 
   {{0xfaa43e0c,0x59fc0156,0x8d841482,0x00000000}},	//   вано, _དཔྱེ_, نشین, --, 
   {{0x6e211f1a,0xeb951f1b,0x443000de,0x00000000}},	//   _geob, тию_, _ldz_, --, 
   {{0xc9540276,0xb82400cc,0x2d804268,0x3c64022e}},	//   лтры, _বাবত_, äket_, _аклг, 
   {{0xe8f51f1c,0x44301c4d,0xec740408,0x00000000}},	//   кля_, _ndz_, _апш_, --, 
   {{0x6e2001f9,0x00000000,0x00000000,0x00000000}},	//   _yeob, --, --, --, 
   {{0x44300a2e,0x2b040406,0x25bc02f0,0xd3a401ec}},	//   _adz_, _संतु_, _žula_, ңлақ, 
   {{0x443005be,0xb4e00694,0x00000000,0x00000000}},	// [1afc0] _bdz_, _ñàkk, --, --, 
   {{0xa4991f1d,0x64a00124,0x7d1c0419,0x00000000}},	//   _stòr, аауа, ássy, --, 
   {{0x28d852be,0x232408ca,0x33f40f06,0x00000000}},	//   _मीटि, вохи_, тчас, --, 
   {{0xe2949702,0x44308294,0x76440857,0x00000000}},	//   ках_, _edz_, _ucky, --, 
   {{0xdc24045e,0x6e204b84,0x4430009d,0x216421fa}},	//   _মানস_, _reob, _fdz_, кици_, 
   {{0xa1911f1e,0x25bc02d2,0x69c02052,0x00000000}},	//   рашч, _þula_, रपती, --, 
   {{0xee84005b,0xaa7800a2,0x00000000,0x00000000}},	//   выпо, llýe, --, --, 
   {{0xa3e405ba,0x4430003a,0x09cc0154,0x6004104e}},	//   _परत_, _zdz_, রেটা, ннәм_, 
   {{0xa2cc13da,0xa5b80005,0x00000000,0x00000000}},	//   धकर्, _león, --, --, 
   {{0x5c704f88,0x00000000,0x00000000,0x00000000}},	//   альт, --, --, --, 
   {{0xdeec7798,0xe0cc0014,0x60d408a8,0xa5b80419}},	//   _вы_, _بٲل_, _יומא_, _neón, 
   {{0x7c2c03f9,0xa93000c7,0x00000000,0x00000000}},	//   _ɓari, аҵиш, --, --, 
   {{0x2a7c0092,0x00000000,0x00000000,0x00000000}},	//   _እየገባ_, --, --, --, 
   {{0x98c4008e,0x00000000,0x00000000,0x00000000}},	//   ассл, --, --, --, 
   {{0x44311f1f,0x00000000,0x00000000,0x00000000}},	//   _rdz_, --, --, --, 
   {{0xa498004e,0x67000137,0x5ac80304,0x442c00b8}},	//   _atòp, лүүб, _үләм_, _śe_, 
   {{0x44300395,0x37c00075,0x8574035b,0x00000000}},	// [1afd0] _pdz_, _ғәрб, ылах, --, 
   {{0x18b80022,0x64bd1f20,0x3d04098a,0x04c801c8}},	//   _агьы_, ्वेश, _हंसे_, روضي_, 
   {{0x99d40014,0xe78401f4,0x00000000,0x00000000}},	//   _متیا, _рупо, --, --, 
   {{0xd1b801ed,0x00000000,0x00000000,0x00000000}},	//   ھانا_, --, --, --, 
   {{0x4430003a,0x33380175,0xd14819be,0xd1b8d2d8}},	//   _tdz_, arpx_, نشون_, پانا_, 
   {{0xb9d80023,0x00000000,0x00000000,0x00000000}},	//   _አዚ_, --, --, --, 
   {{0xa3e40243,0x62480b7e,0xc3c40139,0x903420c8}},	//   _परि_, _очаг_, _сөал, рхіч, 
   {{0x929402d5,0xe9dc004e,0x2a7c0092,0x6f541063}},	//   _касц, nfús_, _እረኞች_, اليز_, 
   {{0x3cf005dc,0xfe7030d1,0x00000000,0x00000000}},	//   ीदले_, لدک_, --, --, 
   {{0xa3e4a06f,0xacc40228,0x2fd000ee,0x98a04bc9}},	//   _परा_, лгыз_, şyga_, _ivić_, 
   {{0x2d8001e6,0x7c6400d1,0xaa780174,0x3f140108}},	//   äker_, ناھل, vmýr, _сдес, 
   {{0xc8680bd4,0x62880007,0x38a405e4,0x00000000}},	//   _מן_, njgo, _môre_, --, 
   {{0xf2d025f9,0x8d751f21,0xec6c0329,0xa5b800ae}},	//   מעט_, _پانا, _лп_, _seón, 
   {{0xa5b8056a,0xf7451f22,0x7d0800aa,0x81e4009e}},	//   _peón, лего, mqes, _নলা_, 
   {{0x8b651f23,0xc7951f24,0x7d091f25,0xfbb00154}},	//   _نايم, арты, lqes, _ঘুরত, 
   {{0xa4991f26,0xaa540063,0x64a000fb,0x8bc4013d}},	//   _quòn, _бићу_, ҡата, _әсәд, 
   {{0x66e000c0,0x3438007b,0xa6c40354,0x7d080200}},	// [1afe0] сота, فساد_, улта_, nqes, 
   {{0x77840212,0x7414007b,0x39400037,0x00000000}},	//   _блоз, اوضا, muks_, --, 
   {{0x39411f27,0x2898008f,0x628801bf,0xefdc0023}},	//   luks_, _ניטא, fjgo, ሕርዚ_, 
   {{0xf2d8030f,0x35a401f0,0x00000000,0x00000000}},	//   رباش_, _бамг, --, --, 
   {{0x394000af,0x7d080240,0x37a800eb,0x00000000}},	//   nuks_, jqes, _খুচর, --, 
   {{0xa49800db,0x9f8001c0,0x39400254,0x00000000}},	//   _utòp, өгчд, iuks_, --, 
   {{0x6a7801b8,0x394000c5,0x00000000,0x00000000}},	//   _jäfä, huks_, --, --, 
   {{0x3940007d,0x60c00597,0xed8880e8,0x6720036e}},	//   kuks_, annm, есок_, _çnje, 
   {{0x22900491,0xe28000a8,0x7d0800f1,0xb19c063f}},	//   _القس, _улти, gqes, ọọlụ_, 
   {{0xa3d0012c,0x394000c5,0xaa78022a,0x00180064}},	//   _हुँ_, duks_, klýc, _аўцы_, 
   {{0x6e442d74,0x00000000,0x00000000,0x00000000}},	//   _منام, --, --, --, 
   {{0xede4036b,0xceb81b15,0xaa780306,0xa3e40764}},	//   _йўлн, _шәл_, dlýc, _परस_, 
   {{0x2f0801ab,0xdeb8010f,0x39400037,0x00000000}},	//   _hùg_, _אמאל, guks_, --, 
   {{0x01d00154,0x00000000,0x00000000,0x00000000}},	//   ়েকদ, --, --, --, 
   {{0xa3d01100,0x1cb400d9,0x00000000,0x00000000}},	//   _हुं_, _גלגל_, --, --, 
   {{0x7d0c0597,0x39411f28,0x5b780677,0x00000000}},	//   _éasc, buks_, _טרוא, --, 
   {{0xa5b91f29,0x44b51f2a,0x39400171,0x00000000}},	// [1aff0] _geól, абас, cuks_, --, 
   {{0xddc80171,0x00000000,0x00000000,0x00000000}},	//   _sagū, --, --, --, 
   {{0x7d08036e,0xddc80171,0x00000000,0x00000000}},	//   zqes, _pagū, --, --, 
   {{0x7d080240,0x97a401e0,0x69dc0200,0xa224009a}},	//   yqes, _ырыл, _kyqe, اراه, 
   {{0xa5b80077,0xd4240c58,0xf2c001c6,0x00000000}},	//   _xeól, _পাৰি_, цөри, --, 
   {{0xa1c00220,0xf0780116,0x69dc036e,0x00000000}},	//   _құлд, кичә_, _myqe, --, 
   {{0xb4b51327,0x43941d56,0x60c007ab,0xa2c800c7}},	//   _тирә, _тавс, rnnm, _зуаз_, 
   {{0xddc800e4,0x9b600131,0x2f080208,0x133c0023}},	//   _hagũ, ەندۈ, _dùg_, _ኣልኣሚ, 
   {{0x9a9002d3,0xae849f2e,0x1ce00327,0xbc18ef2a}},	//   ዝኽእል_, рбыз_, _ྩེད_, кіні_, 
   {{0x7d080240,0x3940000d,0x00000000,0x00000000}},	//   rqes, vuks_, --, --, 
   {{0x69dc02d1,0xece401c6,0x00000000,0x00000000}},	//   _ayqe, рдэл_, --, --, 
   {{0x3940007d,0x7c640131,0x00000000,0x00000000}},	//   tuks_, _چاغل, --, --, 
   {{0x6a780724,0xdb2002d2,0x7bcc00b8,0x00000000}},	//   _säfä, _örþr, _śaud, --, 
   {{0x3f74166a,0x5c04495c,0x3940716e,0x8f000212}},	//   _kāu_, _сяда, ruks_, цiї_, 
   {{0x394000af,0xfaa4010a,0x00000000,0x00000000}},	//   suks_, _вайо, --, --, 
   {{0x3f7404fe,0xa5b82cd7,0x3940007d,0xa6c51f2b}},	//   _māu_, _teól, puks_, алса_, 
  
   {{0xe9dc1709,0xaa7802fb,0xa50400a7,0x250801b9}},	// [1b000] lgún_, slýc, иета_, نرلی_, 
   {{0xaa780306,0x739802dd,0xa998011a,0x896401c8}},	//   plýc, ктес_, _סביר, _اُٿن, 
   {{0xa3d0006d,0xe9dc28f2,0x3f749388,0xede0012c}},	//   _हुआ_, ngún_, _nāu_, _पर्छ, 
   {{0xefd40023,0x05d0000d,0x00000000,0x00000000}},	//   _ክኸዱ_, _थुकब, --, --, 
   {{0xe2940e92,0xaa78010e,0x00000000,0x00000000}},	//   јач_, nlýa, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2324022e,0xe29c022e,0x00000000,0x00000000}},	//   _воси_, _дð_, --, --, 
   {{0xe294016c,0x212c0076,0xdf7000cf,0x00000000}},	//   _кас_, bsgh_, زدىب, --, 
   {{0xe2951f2c,0x216400f3,0x01d401ec,0x00000000}},	//   _тат_, _кити_, _ﭘﺮﻳﻨ, --, 
   {{0xaa1c0316,0x8fc400c7,0xeb380092,0xfc2c3769}},	//   पर्छ_, _лазҵ, _በተገለ, ىڭى_, 
   {{0xee8402f6,0x394401e4,0xdb640395,0x00000000}},	//   _выло, _ĥosa_, арял_, --, 
   {{0x8de801ee,0xaa78010e,0x3f8401af,0x00000000}},	//   _йылғ_, flýa, _уѓђа, --, 
   {{0xa3d0006d,0xa49801c3,0x7c6401d5,0xfe6c00f2}},	//   _हुई_, _suòm, _گانل, _سگي_, 
   {{0xa3e4007d,0x8d751f2d,0xceb80166,0x48b400fe}},	//   _परल_, _پاچا, _шәһ_, ংক্ৰ, 
   {{0x7c6413e1,0x8b8400cf,0xada402d2,0xd8c802d5}},	//   _دانل, _داشۅ, _flúó, рыяд_, 
   {{0x9bf80677,0x9a840354,0xaa7802d2,0x00000000}},	//   _בהוט, _дуьл, blýa, --, 
   {{0x04c81371,0x00000000,0x00000000,0x00000000}},	// [1b010] هوري_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf8b0010f,0x00000000,0x00000000,0x00000000}},	//   _זשי_, --, --, --, 
   {{0xdee0001f,0xd3791f2e,0x00000000,0x00000000}},	//   ሞችን_, шчу_, --, --, 
   {{0x26c80a73,0x216515bb,0xe1640063,0x40940139}},	//   _ijco_, ртег, рђен, йркт, 
   {{0x64400005,0x38a40419,0xd4981422,0x902800c7}},	//   ónid, _kôra_, _крс_, қцәа_, 
   {{0x5334940c,0x104800d4,0x00000000,0x00000000}},	//   _мерт, рячи_, --, --, 
   {{0xa3d014cf,0xaa780209,0xc2c43229,0xc10400ec}},	//   _हुए_, ylýa, _ايري, _هوري, 
   {{0x8d2839fb,0x17e41524,0xf2d000c8,0x3f7402b5}},	//   аның_, _गर्व_, _זען_, _wāu_, 
   {{0x3f740053,0x8d540006,0x8f080124,0x00000000}},	//   _tāu_, ітыч, ыхәа_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xccc400db,0x00000000,0x00000000,0x00000000}},	//   йбөй, --, --, --, 
   {{0xe8fc002d,0x00000000,0x00000000,0x00000000}},	//   rwûn_, --, --, --, 
   {{0xa3e40882,0x96200807,0xad18011a,0x00000000}},	//   _परं_, बर्ट_, _עוצר, --, 
   {{0xe7351f2f,0x31ac01ed,0xe8140037,0x7b140066}},	//   йер_, _közé_, थड़ा_, _ابتذ, 
   {{0x315c0092,0x00000000,0x00000000,0x00000000}},	//   _ለግብር, --, --, --, 
   {{0xf5e91f30,0x765401f4,0x00000000,0x00000000}},	// [1b020] умал_, rfyy, --, --, 
   {{0x38a40158,0xc8b4004b,0xb5c402dd,0x00000000}},	//   _fôra_, _وليک, айұл, --, 
   {{0x289402e4,0xa3e400dc,0x56640345,0xc7b80153}},	//   _הדין_, _परः_, _وگرف, _вёў_, 
   {{0xf55c4be7,0x7b040055,0xc61800d4,0x23251f31}},	//   ገልግሎ, _kųub, _вірш_, соци_, 
   {{0xfc4400d0,0x00000000,0x00000000,0x00000000}},	//   _číne_, --, --, --, 
   {{0x870400f1,0x00000000,0x00000000,0x00000000}},	//   _دبیل, --, --, --, 
   {{0x2d9400f7,0x00000000,0x00000000,0x00000000}},	//   өөдө_, --, --, --, 
   {{0xe51c448b,0x00000000,0x00000000,0x00000000}},	//   मीकि_, --, --, --, 
   {{0xe2800440,0xddd80356,0x00000000,0x00000000}},	//   _элти, rduş, --, --, 
   {{0xca78022e,0x5c380092,0x00000000,0x00000000}},	//   _avvа, _በአገር, --, --, 
   {{0xef180f43,0x7c8800ee,0xc0a80345,0x00000000}},	//   _сме_, ршың_, _ئاقل_, --, 
   {{0x7bcc00dc,0xdfcc00ae,0x00000000,0x00000000}},	//   _śauc, _ثيم_, --, --, 
   {{0x0c9402d3,0x9c800427,0xcca401ec,0x00000000}},	//   _ይገልጽ_, _ščep, _ۇڭگى, --, 
   {{0xfbb800dd,0xacf400d8,0x00000000,0x00000000}},	//   ائیڈ_, _учеј, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x237c1710,0x00000000,0x00000000,0x00000000}},	//   _čuj_, --, --, --, 
   {{0x6f011f32,0x56945dce,0x6fd801f9,0xdb2001e3}},	// [1b030] _mioc, чатт, _पुसू, öröv, 
   {{0x98751c29,0x6f0001ab,0xeabc08c2,0xdee00092}},	//   _ельц, _lioc, liù_, ሞችና_, 
   {{0x64400137,0xa5b80332,0xed4400ec,0x00000000}},	//   òniq, _meói, _ڪپ_, --, 
   {{0x46480228,0xeabc0086,0x6440003a,0x6f011f33}},	//   _өзүн_, niù_, ónib, _nioc, 
   {{0xed44c303,0x00000000,0x00000000,0x00000000}},	//   _تپ_, --, --, --, 
   {{0x656d1f34,0x6f0000e4,0x690800ef,0xe3b002c9}},	//   _isch, _aioc, _aļek, _فرز_, 
   {{0x44211f35,0x2d8001e3,0x63a00162,0x00000000}},	//   mbh_, åken_, ønnd, --, 
   {{0x6f011f36,0x44200876,0x3eb8ff98,0x656c002f}},	//   _cioc, lbh_, òst_, _ksch, 
   {{0x44200ea3,0x290c0086,0xa5b801ed,0xee351f37}},	//   obh_, _ũgan_, _adóz, цны_, 
   {{0x44211f38,0x26d80784,0x3c64023a,0x00000000}},	//   nbh_, hoqo_, цког, --, 
   {{0x44211f39,0x6f00c5bf,0x26d80333,0x1fa46914}},	//   ibh_, _fioc, koqo_, _ураг, 
   {{0x6f000c04,0x656c91a5,0xdef91f3a,0xb8240154}},	//   _gioc, _osch, _сыз_, _বাইত_, 
   {{0x3ead1f3b,0x656d1f3c,0x26d801e2,0xddd80841}},	//   mhet_, _nsch, doqo_, ljuž, 
   {{0x3ead1f3d,0x7d18073c,0xaa7800a2,0x00000000}},	//   lhet_, _itws, blýo, --, 
   {{0x656c060a,0xd1dc044e,0x7c211f3e,0x44200332}},	//   _asch, _ዕዉት_, mblr, dbh_, 
   {{0x3ead1f3f,0x26d801f0,0x70b40864,0x656c2305}},	//   nhet_, goqo_, _अग्ल, _bsch, 
   {{0x656c1529,0x3a20004e,0xe86c02d3,0x00000000}},	// [1b040] _csch, mbkp_, _ብምሉኡ_, --, 
   {{0x656d1f40,0x97740184,0x7ae40113,0x98680220}},	//   _dsch, _етмә, llkt, _الدە_, 
   {{0x3ead1f41,0xf204005b,0xee3400c7,0x00000000}},	//   khet_, ояло, ̆ны_, --, 
   {{0x44207ea1,0x4b4c00c8,0x3eac031c,0x716400ae}},	//   abh_, רגאַ, jhet_, قاتك, 
   {{0x3ead1f42,0x644026c8,0x6f004695,0x656d1f43}},	//   dhet_, ónic, _rioc, _gsch, 
   {{0x6f011f44,0x3eac023a,0xeabc0165,0x00000000}},	//   _sioc, ehet_, ziù_, --, 
   {{0x38a4025a,0xddc801e4,0x3eac05e4,0x6f011f45}},	//   _lôro_, _dagŭ, fhet_, _pioc, 
   {{0x3ead1f46,0x63a00ac7,0x656c0175,0x25bc0010}},	//   ghet_, ønne, _ysch, _žuli_, 
   {{0x6fd80f4a,0xf1a803e6,0x9df402e8,0x00000000}},	//   _पुरू, _ئازه_, онът_, --, 
   {{0x95ec015b,0x0bb400a8,0x6f000210,0x2164011c}},	//   _কলাম_, збою, _wioc, _фифи_, 
   {{0x6f0035ab,0x2bc8016c,0xceb91f47,0xe04000d4}},	//   _tioc, рупо_, _гәп_, _інци, 
   {{0x38a40109,0xed58be81,0x44200099,0xdf1400e5}},	//   _bôro_, _вод_, zbh_, _بڑوں_, 
   {{0x78ac0175,0xeabc0165,0xe86c0023,0x2ed401f9}},	//   fhbv, riù_, _ብምልኡ_, डकीत, 
   {{0x656d1f48,0x50bc00dc,0x9c7400f1,0xc0c402dd}},	//   _rsch, ्चिष, _ومنئ_, _ﺩﻳﯚﻳ, 
   {{0xeabc4d72,0x656c23ac,0x26280114,0x00000000}},	//   più_, _ssch, ицао_, --, 
   {{0x656c0036,0xabb000d1,0x2c2000cc,0xd7c80244}},	//   _psch, _наһә, _মায়ে_, زوقه_, 
   {{0x26d91f49,0x44211f4a,0xde8c0051,0x00000000}},	// [1b050] roqo_, tbh_, _hịch_, --, 
   {{0x3ead1f4b,0xa3a402dd,0xde8c001e,0x26d803b4}},	//   zhet_, يحان, _kịch_, soqo_, 
   {{0x44211f4c,0x656c1afd,0x3ead1f4d,0x02182626}},	//   rbh_, _wsch, yhet_, біль_, 
   {{0x656c1675,0x462408ea,0x38a4006a,0x442000dc}},	//   _tsch, _འབྲས_, _yôro_, sbh_, 
   {{0xde8c01dc,0x656c060a,0x95c856da,0x6f180072}},	//   _lịch_, _usch, _дура_, _attc, 
   {{0xccf80316,0x6908025c,0x6f180175,0x9eb00798}},	//   jmě_, _eżeg, _bttc, cãª_, 
   {{0x6f18074d,0x3ead1f4e,0xbea402e8,0xde8c0208}},	//   _cttc, thet_, зайк, _nịch_, 
   {{0xa1f00046,0xa28003ff,0x00000000,0x00000000}},	//   _قۋات, _زیتو, --, --, 
   {{0x3ead1f4f,0x225d1f50,0x91840075,0x7c200175}},	//   rhet_, _ibuk_, _يۇمۇ, tblr, 
   {{0x3ead1f51,0xde8c004d,0x99811f52,0xbb4400cf}},	//   shet_, _bịch_, _afiş_, пеок, 
   {{0x3c2001c0,0x3ead1f53,0x3af007dd,0xff2411fc}},	//   _vгv_, phet_, hápe_, _ربای, 
   {{0xde8c01dc,0x3af00124,0x00000000,0x00000000}},	//   _dịch_, kápe_, --, --, 
   {{0x49981de1,0x7ae40054,0x290c529d,0x6e911f54}},	//   отря_, rlkt, _égal_, _سلوا, 
   {{0xa3a80bb2,0x7e6839ed,0xdb205bb8,0x3af000e4}},	//   गना_, leep, _قوتی, dápe_, 
   {{0xfaa51f55,0x291807a9,0x8cb801d9,0x00000000}},	//   _нако, _etqa_, _بدنس_, --, 
   {{0x3a2448bd,0x46f402bf,0x784c01ed,0x7e6801e2}},	//   _эмиг, дчут, _bőví, neep, 
   {{0x3af000c7,0x00000000,0x00000000,0x00000000}},	// [1b060] gápe_, --, --, --, 
   {{0x7e680af4,0x225c0429,0x33f51f56,0xddd8025c}},	//   heep, _abuk_, пчес, djuż, 
   {{0x35f8034c,0x9eb00589,0x37e51f57,0xb668419d}},	//   _گردد_, rãª_, _хонг, _линз_, 
   {{0xe3f400db,0x00000000,0x00000000,0x00000000}},	//   سىنت_, --, --, --, 
   {{0xc21802bf,0xe2800276,0xe1211f58,0xddd80327}},	//   ієї_, элци, емчи, gjuż, 
   {{0xa498067c,0x75340432,0x00000000,0x00000000}},	//   _buòu, msyz, --, --, 
   {{0xa8540302,0x63a001ab,0xe3b40798,0x7bcc002b}},	//   פיקה_, ùnnt, _ебр_, _śaun, 
   {{0xde8c0208,0xddd8031c,0x7e6802d0,0x00000000}},	//   _rịch_, bjuż, geep, --, 
   {{0x6ce40046,0x61411f59,0xde8c0051,0x91dc01ec}},	//   зіне, _пета, _sịch_, _тәжi, 
   {{0xceb8000f,0xdd8c0022,0xdc240154,0xf2e40244}},	//   _stęd_, _ҧш_, _মাউস_, _بکڕه_, 
   {{0xe45400c8,0xccf8012c,0x6f1800b5,0xa0651f5a}},	//   הייט_, rmě_, _uttc, _хаха_, 
   {{0x78bc03ac,0x6eb4007b,0x3af000e4,0x7534010b}},	//   _ampv, _عصائ, yápe_, ksyz, 
   {{0x9f400ca8,0x00000000,0x00000000,0x00000000}},	//   _àjò_, --, --, --, 
   {{0xdde81a4c,0xde8c0016,0xc8c801d5,0xe9dc0022}},	//   _פֿאָ, _tịch_, زوزن_, ngúi_, 
   {{0xd7f919ef,0x58d402dd,0xddd8031c,0xab8407a5}},	//   зут_, хорт, zjuż, _хулк, 
   {{0x78bc02d0,0x1ae410fc,0x3af0035b,0xa5041183}},	//   _empv, _појм, tápe_, كىرە_, 
   {{0x26c416a3,0x051800ec,0x29191f5b,0x44980153}},	// [1b070] đno_, زياب_, _utqa_, оваю_, 
   {{0xe8d022f3,0x225c003e,0xe8242b8e,0x3af000c7}},	//   _سمجھ, _sbuk_, _эфио, rápe_, 
   {{0x7e68009a,0x25640014,0x387c06af,0x3af00124}},	//   yeep, _کاجُ, ôtre_, sápe_, 
   {{0x0518007b,0x3af0035b,0xaa7800a2,0x00000000}},	//   _ويجب_, pápe_, boýe, --, 
   {{0xb64401ec,0x7e68000d,0x00000000,0x00000000}},	//   _ﺎﺹ_, veep, --, --, 
   {{0xddd8025c,0x00000000,0x00000000,0x00000000}},	//   rjuż, --, --, --, 
   {{0xddc80142,0x7e68340f,0x00000000,0x00000000}},	//   _yngŷ, teep, --, --, 
   {{0x3010052f,0x925801c4,0x00000000,0x00000000}},	//   ндәр, _наст_, --, --, 
   {{0x7e691f5c,0x00000000,0x00000000,0x00000000}},	//   reep, --, --, --, 
   {{0x62980270,0x7e684c48,0x00000000,0x00000000}},	//   _houo, seep, --, --, 
   {{0x62980093,0x60c11f5d,0x7e68016b,0x1fa4013d}},	//   _kouo, minm, peep, _эраг, 
   {{0xc0d402d3,0x62991f5e,0x3b5400cf,0x00000000}},	//   ርዎም_, _jouo, пкүр, --, 
   {{0x629800fb,0x6908012d,0x00000000,0x00000000}},	//   _mouo, _ażeb, --, --, 
   {{0xfbc451a7,0x60c11f5f,0x62991f60,0x4c840212}},	//   _обло, ninm, _louo, _плів, 
   {{0x313c0023,0x80a400c5,0x00000000,0x00000000}},	//   _ኣይትር, _कवने, --, --, 
   {{0x64400436,0x60c11f61,0x62991f62,0xfe7800bc}},	//   ónin, hinm, _nouo, ndů_, 
   {{0x60c11f63,0x6908031c,0x78bc0334,0x74540108}},	// [1b080] kinm, _eżeb, _tmpv, дъех, 
   {{0xf8d000ab,0x60c11f64,0xddcc0419,0x00000000}},	//   _सदिय, jinm, čeňo, --, 
   {{0x60c11f65,0xb9ec044e,0x2cb4025c,0x25c406be}},	//   dinm, _ቓል_, ྒྲིབ, _ətlə_, 
   {{0x9bb40003,0xeb9400c8,0x35a43be4,0x63a0bee6}},	//   _བཟློ, ודער_, _жамг, ønna, 
   {{0x657801fa,0x60c11f66,0x234400d1,0xf0740166}},	//   _šuhv, finm, كلەپ_, дилә_, 
   {{0x60c11f67,0xa4980ba1,0x00000000,0x00000000}},	//   ginm, _quòt, --, --, 
   {{0xb4e81025,0xa5040354,0x00000000,0x00000000}},	//   मती_, _цера_, --, --, 
   {{0x6298b6b3,0x1ef4007b,0xddc800ef,0xe280014b}},	//   _gouo, وعية_, _sagš, _илси, 
   {{0x63b823db,0x60c11f68,0x2a6800b5,0x00000000}},	//   _ƙung, binm, vecb_, --, 
   {{0xe0403129,0xfe7801ef,0x60c11f69,0x00000000}},	//   _анфи, adů_, cinm, --, 
   {{0xdaf00943,0x00000000,0x00000000,0x00000000}},	//   _ṱoḓa, --, --, --, 
   {{0x7af51f6a,0x298801c6,0x00000000,0x00000000}},	//   _chyt, осго_, --, --, 
   {{0x7af40363,0x6d4402f0,0xb98400c7,0x00000000}},	//   _dhyt, ákad, нтрқ, --, 
   {{0x313c02d3,0x7d1c00d8,0x00000000,0x00000000}},	//   _ኣይተር, ísse, --, --, 
   {{0xa2bc06ab,0xabb00124,0x444400e5,0x00000000}},	//   लोड्, _шакә, ہراہ, --, 
   {{0xa5280135,0x60c003e0,0xde8c0051,0x00000000}},	//   _སྦུག_, zinm, _lịnh_, --, 
   {{0x44f4033a,0xa01000fe,0x04f40108,0x644000d7}},	// [1b090] епас, হৰিব_, езаю, ónio, 
   {{0x92c00183,0x7af40023,0xfe7800bc,0xde8c004d}},	//   ুতো_, _zhyt, zdů_, _nịnh_, 
   {{0x62991f6b,0x60c11f6c,0x3af00784,0x063400d8}},	//   _pouo, vinm, lápa_, _пенџ, 
   {{0x60c00113,0x57a400c7,0x00000000,0x00000000}},	//   winm, _ршьа, --, --, 
   {{0x60c11f6d,0x58b804fb,0x56940209,0xde8c0208}},	//   tinm, _رایج_, _раят, _bịnh_, 
   {{0x63b803f9,0x442403b2,0xe4c40006,0x00000000}},	//   _ƙund, _ýl_, _цёмн, --, 
   {{0x60c11f6e,0x62980093,0x4430030a,0xa5b800d8}},	//   rinm, _touo, _iez_, _geór, 
   {{0x44311f6f,0xfe704030,0x60c11f70,0x629803a0}},	//   _hez_, ادث_, sinm, _uouo, 
   {{0x44300ab7,0xfe78013a,0x60c07769,0x3af000e4}},	//   _kez_, rdů_, pinm, jápa_, 
   {{0x443031cd,0x7af40240,0x60c0022e,0xcc6400d1}},	//   _jez_, _shyt, qinm, نچىۋ, 
   {{0x7af51f71,0x44311f72,0xa9a01f71,0x2bc4010b}},	//   _phyt, _mez_, қирд, елэп_, 
   {{0x44311f73,0xe7e00c2e,0xba74179e,0x8e8400ae}},	//   _lez_, _गड़ा_, راجت, _للمه, 
   {{0x3d1800fe,0x443002f0,0xdc400118,0xc9540024}},	//   _দিক্_, _oez_, léči, ктры, 
   {{0x7af51f74,0xa2bc17c6,0x6b8c01e7,0x00000000}},	//   _whyt, लोत्, óigí, --, 
   {{0x7e7803f0,0x00000000,0x00000000,0x00000000}},	//   _kawp, --, --, --, 
   {{0x4430030a,0x7e78014f,0x66e11f75,0x00000000}},	//   _aez_, _jawp, госа, --, 
   {{0x34851f76,0x7964013f,0x7e780649,0x68f40175}},	// [1b0a0] нгаг, _bɔwe, _mawp, _fhxd, 
   {{0x44300038,0xb4e811a6,0x7e780113,0x00000000}},	//   _cez_, मते_, _lawp, --, 
   {{0x44311f77,0x3a30022c,0xb6a400c7,0x00000000}},	//   _dez_, _keyp_, _зинл, --, 
   {{0x7e791f78,0x44311f79,0x00000000,0x00000000}},	//   _nawp, _eez_, --, --, 
   {{0x443003b7,0x38791f7a,0xa6800024,0x00000000}},	//   _fez_, _kapr_, _сляд, --, 
   {{0x44311f7b,0xa5b8810d,0xa528031c,0x3a3006ea}},	//   _gez_, _teór, _སྦིག_, _leyp_, 
   {{0xaf051f7c,0xde8c01fb,0x00000000,0x00000000}},	//   нчик, _vịnh_, --, --, 
   {{0xb640037e,0x4430036e,0x91c401e0,0x9f5008a5}},	//   _ｌｅ_, _zez_, _иҙел, _ódýr_, 
   {{0xf8dc00ca,0xde8c01fb,0xe9dc002d,0x44300489}},	//   n篩s_, _tịnh_, ngút_, _yez_, 
   {{0x387801a2,0xc0bc0092,0x4430013d,0xa1c00108}},	//   _napr_, ዳበር_, _xez_, _сбуд, 
   {{0xfe78007f,0x7bdc0342,0xa4b4011a,0xa5b802d2}},	//   moůn_, şsun, גליה_, _leóp, 
   {{0x9e702088,0x3af000c7,0x9f4001e1,0x00000000}},	//   _مهمت, tápa_, _ájá_, --, 
   {{0x2ee40472,0x09200c58,0x5a340006,0xe7e00037}},	//   _ikof_, _বিহু_, ынят, _गडहा_, 
   {{0x3af000e4,0x62840064,0xb4e82e35,0x00000000}},	//   rápa_, _ėjom, मतो_, --, 
   {{0xe7d80714,0x44311f7d,0x64400cc3,0x387c05da}},	//   _मुखप, _rez_, ónim, ôtra_, 
   {{0x44311f7e,0xef5002d3,0xb600013a,0x00000000}},	//   _sez_, _ዘይደል, _čáro, --, 
   {{0x44311f7f,0x99851f80,0x2c0001c0,0xd1240137}},	// [1b0b0] _pez_, _مليو, _шүүм, _دۅ_, 
   {{0x84c40116,0x00000000,0x00000000,0x00000000}},	//   тәмд, --, --, --, 
   {{0x44311f81,0x23091f82,0x00000000,0x00000000}},	//   _vez_, ستاي_, --, --, 
   {{0x44311f83,0xb7c400c7,0x28040118,0x7bcc0055}},	//   _wez_, _шрық, ětně_, _śauk, 
   {{0x44311f84,0xb6c11f85,0x00000000,0x00000000}},	//   _tez_, _төрд, --, --, 
   {{0x7e780455,0x3f682bb7,0x1ee42099,0x00000000}},	//   _sawp, дико_, کوبی_, --, 
   {{0x7e78014f,0x9c2402dd,0xe5a401e1,0xaa7800a2}},	//   _pawp, _ﺳﯘﻟﯟ_, _ńdẹ̀, llýu, 
   {{0xf2c00116,0x00000000,0x00000000,0x00000000}},	//   _көчи, --, --, --, 
   {{0x3a3003b2,0x00000000,0x00000000,0x00000000}},	//   _reyp_, --, --, --, 
   {{0x3b84f867,0xdbb40352,0xfc30007b,0xefb80092}},	//   влог, етмә_, جحة_, ታኒያ_, 
   {{0xf4100302,0xaf5400c7,0x7c2c107d,0x00000000}},	//   יפי_, _анхә, _đard, --, 
   {{0x3878030a,0x6d440306,0x4fc40108,0x00000000}},	//   _sapr_, ákac, _ссуа, --, 
   {{0x0f04f703,0x8eb01c5c,0xec6c117e,0x89d40212}},	//   _إِنّ, _دەيت, _кп_, гірш, 
   {{0x6d451f86,0x00000000,0x00000000,0x00000000}},	//   škac, --, --, --, 
   {{0x63a003cd,0x66d00003,0x37e401d5,0x3a3003e0}},	//   ønnl, għko, товг, _teyp_, 
   {{0x683c0213,0xb4e800dc,0x00000000,0x00000000}},	//   _açdı, मत्_, --, --, 
   {{0xf5083529,0x657801fa,0x00000000,0x00000000}},	// [1b0c0] днал_, _šuhr, --, --, 
   {{0x293406a9,0x3f851f87,0x3878004b,0xa2bca4cd}},	//   _שאין_, _orlu_, _uapr_, लोस्, 
   {{0xf7700133,0x3cf80456,0x00000000,0x00000000}},	//   _ئاخ_, _उठने_, --, --, 
   {{0xb6a51f88,0x232403b7,0xdcf8110c,0xf8d03507}},	//   _римл, тоци_, dvuč, _सदुप, 
   {{0xaa782b57,0x63b803f9,0xdebc0023,0x412800db}},	//   plýv, _ƙunc, _ስምካ_, енчү_, 
   {{0x2ee40ea0,0x00000000,0x00000000,0x00000000}},	//   _skof_, --, --, --, 
   {{0xdd180241,0x3af00162,0x69080210,0x00000000}},	//   _láńg, vápn_, _ożen, --, 
   {{0x63a11f89,0x00000000,0x00000000,0x00000000}},	//   änne, --, --, --, 
   {{0x3f842507,0x42e40153,0x00000000,0x00000000}},	//   _erlu_, _сцёб, --, --, 
   {{0xa1100075,0xcb980212,0x38a40419,0x00000000}},	//   _ئولت, евої_, _kôru_, --, 
   {{0xa2bc01f9,0x7d0c0055,0xee3800f3,0x00000000}},	//   लोव्, _ũast, _жне_, --, 
   {{0x2de51f8a,0xdee00117,0x47c000cc,0x00000000}},	//   _июлг, _кохи, _এডলী, --, 
   {{0xe94400a7,0xfca8004b,0x6440628d,0x3ed8010f}},	//   ъхно, _ګانو_, ónik, _אַסא, 
   {{0x2d8405da,0x69080135,0xb60000d7,0x00000000}},	//   _iroe_, _eżen, _čápo, --, 
   {{0x6600016b,0xa2b00073,0x97a46584,0x00000000}},	//   ɛnky, _आतल्, артл, --, 
   {{0x49751f8b,0x4a540276,0xd6d82766,0x00000000}},	//   _блис, _скис, вту_, --, 
   {{0xdcf80552,0xf8ac1968,0xd6840b3e,0x7e6c00e4}},	// [1b0d0] zvuč, زکی_, јусп, _ñape, 
   {{0x0354008e,0x00000000,0x00000000,0x00000000}},	//   лүгә_, --, --, --, 
   {{0xddd801e4,0x53e40006,0x00000000,0x00000000}},	//   deuŝ, ацца, --, --, 
   {{0x90e48338,0x0b800023,0xfb14008f,0x00000000}},	//   یسون, _ንጉዳይ_, אַסט_, --, 
   {{0x7964013f,0x63a00267,0x016461ac,0x00000000}},	//   _kɔwa, ännb, укло, --, 
   {{0x76440014,0x00000000,0x00000000,0x00000000}},	//   _لیہِ_, --, --, --, 
   {{0x53351f8c,0x2d8400b0,0xfe70b085,0xdb2001bf}},	//   _вест, _aroe_, مدة_, _ærøs, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdcf807f5,0x7eb40419,0x7e7000d7,0x63c001af}},	//   svuč, _nápe, _čepč, _саңҡ, 
   {{0x75200120,0x2d851f8d,0x3f800250,0xd1b800cf}},	//   ãozi, _droe_, åhus_, _شاقا_, 
   {{0x2d851f8e,0x2000002e,0xfbc4011b,0x66000118}},	//   _eroe_, _àji_, убно, ěnky, 
   {{0x7eb40085,0x2d840221,0x00000000,0x00000000}},	//   _bápe, _froe_, --, --, 
   {{0x2d801511,0x2d851f8f,0x3eac002d,0xaa7800a2}},	//   åket_, _groe_, mket_, moýl, 
   {{0x3eac17c0,0xed540b87,0xaa7802d2,0x00000000}},	//   lket_, _сош_, flýs, --, 
   {{0xaa7800fc,0x81a8015b,0x3eac005a,0x36680117}},	//   glýs, খছি_, oket_, наво_, 
   {{0x3ead1f90,0x1cb0031c,0x00000000,0x00000000}},	//   nket_, ྟིམ_, --, --, 
   {{0xb4651f91,0x7ae51f92,0x7d0c0798,0x3eac00e5}},	// [1b0e0] лкал, mokt, _éass, iket_, 
   {{0xe5744445,0xe61c0142,0xaa7802f0,0x3eac000d}},	//   ызу_, _efô_, blýs, hket_, 
   {{0x3ead1f93,0x63b802a8,0xe4d48a41,0x23240107}},	//   kket_, _ƙuna, دولت_, гохи_, 
   {{0x7ae51f94,0xd25003e6,0xa798011a,0x00000000}},	//   nokt, تۆر_, _נשכח, --, 
   {{0x28480023,0x76540432,0x00000000,0x00000000}},	//   _ንምእራ, mgyy, --, --, 
   {{0x3ead1f95,0x3ad400b0,0x63a02ad7,0x00000000}},	//   eket_, kāpo_, ännc, --, 
   {{0x437400f7,0x80a40456,0x3ead1f96,0x00000000}},	//   _кутт, _कवरे, fket_, --, 
   {{0x2d8405e4,0x3ead1f97,0x9f140214,0xd204014b}},	//   _proe_, gket_, دآور_, _кӯлк, 
   {{0x216400ee,0x9b54e36e,0xd12c0014,0xdda401c6}},	//   _йити_, қият_, _کۅڈ_, гтэл_, 
   {{0x7eb40077,0x3ead1f98,0x3ce47813,0x2d840af9}},	//   _rápe, aket_, golv_, _vroe_, 
   {{0xdeed1f99,0xdfcc0597,0x7ae401f5,0xc1740132}},	//   _гы_, _فيك_, fokt, _مدەت, 
   {{0x3ead1f9a,0x7eb40030,0x2d851f9b,0x2d80003b}},	//   cket_, _pápe, _troe_, åkes_, 
   {{0x2d840158,0x9d405954,0x1be001b9,0x4c951f9c}},	//   _uroe_, _гечд, _қўшг, _вилс, 
   {{0x7eb402fb,0x63a033b8,0xaa780162,0x00000000}},	//   _vápe, ønnk, tlýs, --, 
   {{0x7c640131,0x3cf80412,0x2b44009d,0x5c34011a}},	//   _خانل, _उठते_, _сэлг, _גרון_, 
   {{0xaa7809f3,0x7964016b,0x7eb401d3,0x00000000}},	//   rlýs, _wɔwa, _tápe, --, 
   {{0xaa78041e,0x15a800a7,0x9c800427,0xa42400c7}},	// [1b0f0] slýs, лъфи_, _ščip, гьел, 
   {{0xaa7811c3,0x8afc000f,0x3eac005a,0x00000000}},	//   plýs, stęd, zket_, --, 
   {{0xe7851f9d,0x38340228,0xdc38008f,0x3eac3b3b}},	//   _супо, _өнөр, געבר, yket_, 
   {{0x3ce4054e,0x29000200,0xd37800c0,0x00000000}},	//   zolv_, lmja_, ычу_, --, 
   {{0x210c7db3,0x763800c8,0x3eac03e0,0x00000000}},	//   ादेश_, _בערג, vket_, --, 
   {{0x7ae401d3,0x68e4014f,0xff2400d8,0x00000000}},	//   zokt, nojd, амко, --, 
   {{0x7ae51f9e,0x3ead1f9f,0x3ce40327,0x6d440419}},	//   yokt, tket_, volv_, ákan, 
   {{0x29000240,0x68e4014f,0x3eac0165,0x00000000}},	//   hmja_, hojd, uket_, --, 
   {{0x6d451fa0,0x40951cc1,0x7ae51fa1,0x7cfc00db}},	//   škan, _پلار, vokt, nèrg, 
   {{0x6454ffb4,0x3ead1fa2,0xbc480107,0x29000327}},	//   ngxi, sket_, тӯда_, jmja_, 
   {{0x2d801511,0x3eac002d,0x3ce40158,0x63a003cd}},	//   åker_, pket_, rolv_, ønnh, 
   {{0x6908012d,0x7c9426a6,0x00000000,0x00000000}},	//   _dżem, اشکا, --, --, 
   {{0x7ae51fa3,0x69080135,0xc0dc02d3,0xb274008f}},	//   rokt, _eżem, ንጽር_, בערג_, 
   {{0x7ae4367d,0x00000000,0x00000000,0x00000000}},	//   sokt, --, --, --, 
   {{0xe7351fa4,0x7ae41e24,0x2d74033f,0x7cfc02e2}},	//   иер_, pokt, _złe_, tèrf, 
   {{0x6908025c,0xbb840451,0x75d40b24,0x00000000}},	//   _jżej, _ملڪي, ليزا, --, 
   {{0xe6151fa5,0xaf5002d3,0x6908025c,0x7eb400d0}},	// [1b100] рду_, _ዘይሕለ, _mżej, _zápc, 
   {{0x6908012d,0xe4d400ae,0x00000000,0x00000000}},	//   _lżej, لوقت_, --, --, 
   {{0x7cfc004e,0xb4b4190c,0x9f4801e1,0x00000000}},	//   pèrf, _जती_, _ìlèe_, --, 
   {{0x63a004f3,0x7cfc067c,0x6908031c,0x00000000}},	//   änna, bèrg, _nżej, --, 
   {{0x71581cc9,0x00000000,0x00000000,0x00000000}},	//   трес_, --, --, --, 
   {{0x25ac00b5,0x00000000,0x00000000,0x00000000}},	//   øgle_, --, --, --, 
   {{0xdfcc9476,0x64a06d7d,0xa3d401f9,0xa0c000db}},	//   ويه_, _ьара, ापण_, تيوو, 
   {{0xee84fe4b,0x00000000,0x00000000,0x00000000}},	//   рыко, --, --, --, 
   {{0x310800c7,0xdd940b5e,0xddd80356,0x016800ec}},	//   _анап_, ашэ_, reuş, _محلو_, 
   {{0xdfcc0451,0xae4405af,0xa0642a9d,0x00000000}},	//   _ڪيم_, _چپاو, _вафа_, --, 
   {{0x764402f0,0x4094009d,0x68e400d7,0x00000000}},	//   _odky, _уртт, vojd, --, 
   {{0x2aa80228,0x63a00ac8,0x69080003,0xdfcc2004}},	//   ттоо_, ønni, _gżej, _تيم_, 
   {{0xdd8d1fa6,0x75240354,0x290002d3,0x7e6c0309}},	//   _يوم_, _ntkz, tmja_, _ñapa, 
   {{0x6d411fa7,0x09d80154,0x00000000,0x00000000}},	//   _ivoa, _সরদা, --, --, 
   {{0x29002fce,0x68e4025c,0x1b74007b,0x00000000}},	//   rmja_, rojd, _نصية_, --, 
   {{0x6d400421,0xdb9808d8,0x7cfc02e2,0x2900036e}},	//   _kvoa, _יסור, tèrg, smja_, 
   {{0x7eb40789,0x44b51fa8,0x68e41155,0x00000000}},	// [1b110] _jápa, ббас, pojd, --, 
   {{0xbb2c02dd,0x00000000,0x00000000,0x00000000}},	//   _ﺩﻩﻥ_, --, --, --, 
   {{0x7eb40ca8,0x8214007b,0x00000000,0x00000000}},	//   _lápa, مواص, --, --, 
   {{0x7cfc4325,0x998440bf,0x64540472,0x45d40064}},	//   mère, _الیو, sgxi, _гомс, 
   {{0x7eb40232,0x6d451fa9,0x7cfd1faa,0x91480120}},	//   _nápa, ákal, lère, ачја_, 
   {{0x6e211fab,0x656d1fac,0x3e70004d,0x826400ec}},	//   _afob, _ipch, _ạt_, _گهرن, 
   {{0x7cfc7d4f,0x6d411fad,0x6d441822,0x2fdc056a}},	//   nère, _avoa, škal, _cxtg_, 
   {{0x44211fae,0x98a00010,0x7cfc0129,0xc10400ec}},	//   lch_, _rtič_, ière, جوڪي, 
   {{0x44211faf,0x51841086,0x7cfc004a,0x6b88032e}},	//   och_, _муфа, hère, _arfg, 
   {{0x44211fb0,0x61f80173,0x7eb401e1,0x98a00010}},	//   nch_, _izul, _dápa, _ptič_, 
   {{0x44211fb1,0xa3d40a28,0x69080003,0x3ff400db}},	//   ich_, ापि_, _eżek, _اكار, 
   {{0xf9881d1f,0x7cfd1fb2,0x9e640b24,0x98a00010}},	//   هنجي_, dère, _خائن, _vtič_, 
   {{0x44200bf1,0x6b881a93,0x7cfc007f,0x64440118}},	//   kch_, _erfg, tèrd, _odji, 
   {{0x44211fb3,0xa3d40b7d,0x79640134,0xe8f400a8}},	//   jch_, ापा_, _wɔwo, йля_, 
   {{0x7eb403c6,0x7cfd1fb4,0x75240109,0xdb204144}},	//   _zápa, gère, _stkz, _بوبی, 
   {{0x64451fb5,0x44211fb6,0x5fdc00af,0x00000000}},	//   _adji, ech_, _पुछल, --, 
   {{0x61f91fb7,0x18b40075,0xf99000c6,0x56f40137}},	// [1b120] _nzul, _дәвр, _ربة_, йүүс, 
   {{0x7cfc6320,0x656c0036,0xd91004d3,0x64440af9}},	//   bère, _dpch, _زیز_, _cdji, 
   {{0x7cfc7d4f,0xb9e002d3,0x656c01a9,0xb6ac01af}},	//   cère, _ከላ_, _epch, _зинh, 
   {{0x44211fb8,0x6444020c,0x23480214,0x00000000}},	//   ach_, _edji, اسلی_, --, 
   {{0x6738098d,0x61f8012d,0x93f4000d,0x503801ca}},	//   ćuje, _czul, _अरकच_, аплю_, 
   {{0x61f81aa1,0x44203c6d,0x644004d4,0x00000000}},	//   _dzul, cch_, ónit, --, 
   {{0x61f83058,0x733400db,0x6f8401a9,0x00000000}},	//   _ezul, _دىزا, сулж, --, 
   {{0x7eb51fb9,0x11f80014,0xb8d80327,0x00000000}},	//   _pápa, _نوزک_, _ཙཾ_, --, 
   {{0x4cb869a4,0xb14400a8,0x7cfc1e54,0x63a00fac}},	//   илию_, _ынал, zère, ønnv, 
   {{0x7d1801f5,0x7cfc06af,0x7cf001d5,0x1b1c0154}},	//   _duws, yère, _qаrо, _ভিজে_, 
   {{0xdfcc00b2,0xa2bc00dc,0x9db401b9,0x7bcc00cd}},	//   _ٻين_, लोक्, لدیز_, _śaur, 
   {{0xbe851386,0x7cfc59cc,0x8afc002d,0x6e2051a0}},	//   _وجنو, vère, lwęz, _ufob, 
   {{0x44211fba,0x777c1c42,0x7eb401ef,0x00000000}},	//   ych_, _aspx, _kápn, --, 
   {{0x6f191fbb,0x7cfd1fbc,0x4c9475a2,0x8afc000f}},	//   _kutc, tère, _фикс, nwęz, 
   {{0x9c6005d9,0x491807c1,0x6b8801a9,0x4420022e}},	//   _رهيو, _यूरो_, _urfg, vch_, 
   {{0x44201649,0x7cfc4325,0x6f191fbd,0x82c40327}},	//   wch_, rère, _mutc, _གཏེའ, 
   {{0x4420771c,0x6f191fbe,0x7cfc2a78,0x9b900137}},	// [1b130] tch_, _lutc, sère, _ولۇت, 
   {{0x44211fbf,0x9d180302,0x7cfd1954,0x6f191fc0}},	//   uch_, טומט, père, _outc, 
   {{0x44211fc1,0x43741371,0x61f81f6f,0x6f18045a}},	//   rch_, تهار, _szul, _nutc, 
   {{0x44211fc2,0xddd80356,0x7d1c0162,0x00000000}},	//   sch_, nduţ, íssk, --, 
   {{0x656d1fc3,0x44200227,0x6f18003a,0x26c8004e}},	//   _upch, pch_, _autc, _imco_, 
   {{0x6f191fc4,0x442002d1,0x80a406c2,0x00000000}},	//   _butc, qch_, تمتن, --, 
   {{0x104811ed,0x29111fc5,0x29180135,0x7d18010b}},	//   сячи_, _mixa_, _luqa_, _suws, 
   {{0x29111fc6,0x248001a9,0x6f191fc7,0x25bc02f0}},	//   _lixa_, _hajm_, _dutc, _žuly_, 
   {{0xc0dc044e,0x29191fc8,0x1b0405f5,0xc0bc02d3}},	//   _ንጹር_, _nuqa_, үүлн, ዳበለ_, 
   {{0x6f180099,0x69080327,0x29100393,0x99800139}},	//   _futc, _iżew, _nixa_, _agiş_, 
   {{0x29180784,0x7e6c00c7,0x00000000,0x00000000}},	//   _auqa_, _ñapo, --, --, 
   {{0xef0c1c26,0x248002d3,0x2918c1b5,0x291098e0}},	//   _ім_, _lajm_, _buqa_, _aixa_, 
   {{0x2ab800e8,0x2910060f,0x00000000,0x00000000}},	//   _bëbb_, _bixa_, --, --, 
   {{0x2480025a,0x29180014,0x49c40032,0xc0bc02d3}},	//   _najm_, _duqa_, яһын_, ዳበሉ_, 
   {{0xfaa51fc9,0x7cfd1fca,0xe9a40214,0x9f600166}},	//   _мако, pèrb, مگین_, _äwäl_, 
   {{0x291000cf,0x29180327,0x225c0200,0xe4480118}},	//   _eixa_, _fuqa_, _ncuk_, vňáč, 
   {{0x7cfc1497,0x7eb4143c,0x24805c23,0xd5b001d9}},	// [1b140] cèrc, _lápo, _bajm_, رہس_, 
   {{0x33f44b7d,0x225c0c6a,0x77c81d0f,0x00000000}},	//   очес, _acuk_, _влог_, --, 
   {{0x7eb403c6,0xb6a51fcb,0x36680798,0x7bc00327}},	//   _nápo, _динл, _кано_, nzlu, 
   {{0x29191fcc,0x2910009a,0x6f18cbab,0x95b400fb}},	//   _yuqa_, _zixa_, _rutc, _ергә, 
   {{0x6f18a2c1,0x05540276,0x00000000,0x00000000}},	//   _sutc, _нтря, --, --, 
   {{0x2910036e,0x00000000,0x00000000,0x00000000}},	//   _xixa_, --, --, --, 
   {{0x7eb40f60,0x225c0fac,0xe3611fcd,0xe7fc02e5}},	//   _vápn, _fcuk_, _окри, ोइया_, 
   {{0xa3d4069f,0x00000000,0x00000000,0x00000000}},	//   ापर_, --, --, --, 
   {{0x7bc00369,0x61400139,0x918000d1,0x6e9001d5}},	//   ezlu, _оета, _سۇغۇ, зиқу, 
   {{0x316401b9,0x6f180115,0x4cb800d4,0x00000000}},	//   mtoz_, _tutc, слою_, --, 
   {{0x6d44019f,0x29111fce,0x2ab80de2,0x7eb443e9}},	//   âkab, _rixa_, _rëbb_, _kápl, 
   {{0x291000f1,0xc058001f,0x5fc002ab,0xb4b41a04}},	//   _sixa_, ፈጠረው, _वेटल, जसु_, 
   {{0x7eb41a09,0x0c9402d3,0x291064cb,0x6f011fcf}},	//   _zápo, _ክገልጽ_, _pixa_, _ihoc, 
   {{0x291803b4,0x29100ba7,0x6c3001d9,0x6f0001ab}},	//   _vuqa_, _qixa_, _تہدا, _hhoc, 
   {{0x6f011fd0,0x26c800d8,0x2ac4009b,0x00000000}},	//   _khoc, аѓан_, _мљив, --, 
   {{0x7eb40232,0x56951fd1,0x2918022f,0x7cfc1e4c}},	//   _nápl, маст, _tuqa_, mèra, 
   {{0x6f011fd2,0x7cfc067c,0x2ab8002e,0x561800fe}},	// [1b150] _mhoc, lèra, _tëbb_, ়ৰ্ক_, 
   {{0x7d1d19c7,0x2fd00209,0x00000000,0x00000000}},	//   íssi, şygy_, --, --, 
   {{0x7cfc5051,0xd5d000c5,0x7e6803b2,0x4274013d}},	//   nèra, _सेठज, yfep, згес, 
   {{0xb7781a4c,0x7c2c009b,0x6f0001fb,0xdb980a1e}},	//   _פארש, _đarm, _nhoc, יסבר, 
   {{0x2480009b,0x7cfc020c,0xd7c8030f,0xd56400f3}},	//   _tajm_, hèra, _هویه_, _отрп, 
   {{0x63a003a1,0x6f00e6b3,0xf07804a9,0x720000d1}},	//   ønns, _ahoc, йичә_, رۈلم, 
   {{0x6f007ea6,0xddd800f3,0xd0181b15,0xa5b801e7}},	//   _bhoc, dduš, әфә_, _mfóm, 
   {{0x3eb81873,0x6f00c0f2,0x92591fd3,0xfe440261}},	//   óst_, _choc, _маст_, чнио, 
   {{0xee351fd4,0x30100032,0x31640789,0x6f011fd5}},	//   чны_, мдәр, ctoz_, _dhoc, 
   {{0x7eb41a09,0x7cfc0ba1,0x7bc00175,0x3c651fd6}},	//   _zápl, fèra, tzlu, чког, 
   {{0x6f001552,0x7e680810,0x7cfc0066,0xa5b803b2}},	//   _fhoc, pfep, gèra, _sfól, 
   {{0x6f00047e,0xdef8004e,0x00000000,0x00000000}},	//   _ghoc, _тыз_, --, --, 
   {{0xf990007b,0x0d8001e0,0xbc94119e,0x00000000}},	//   ربح_, _аһын, _надј, --, 
   {{0x7cfc00f2,0xe51c00c5,0x25ec00ab,0x4c84187f}},	//   bèra, _बढ़ि_, _आड़ी_, _олів, 
   {{0x3b080801,0x7cfc020c,0xa5b801e7,0x941803b9}},	//   _леко_, cèra, _dfóm, _gorə_, 
   {{0x6f1cada8,0xa5b800d2,0x39443849,0xdb2000e5}},	//   ípci, _tfól, _ениг, _ٹوکی, 
   {{0x18188efb,0xada002d2,0xaa78010b,0x00000000}},	// [1b160] _وردک_, _óútr, goýu, --, 
   {{0x5fd807f7,0x98e000bc,0xb4b407b6,0xa3d400cd}},	//   यपाल, _नदिए, जसे_, ापं_, 
   {{0xa8780a7c,0xb8080066,0x00000000,0x00000000}},	//   _פאטר, _ديدم_, --, --, 
   {{0xddd8a355,0x6d440006,0x6720020c,0xd258036b}},	//   zduš, škai, _énja, تیرش_, 
   {{0x6f000142,0x00000000,0x00000000,0x00000000}},	//   _rhoc, --, --, --, 
   {{0x92cc00bd,0x31640dd4,0x6f011fd7,0x855401b9}},	//   রকে_, rtoz_, _shoc, _آیلر_, 
   {{0x6f011fd8,0xddd8151c,0x7eb401ed,0x316401c4}},	//   _phoc, vduš, _tápl, stoz_, 
   {{0x6f000784,0x7cfc0ba1,0x316406be,0x00000000}},	//   _qhoc, vèra, ptoz_, --, 
   {{0x7cfc00f2,0x4d980212,0x5d60d54f,0x072c00d1}},	//   wèra, ікою_, нтэз, ﻧﻤﯘ_, 
   {{0x7cfc0100,0xc0dc0092,0x00000000,0x00000000}},	//   tèra, ንችል_, --, --, 
   {{0x6f000c3a,0xdcf816a3,0xabb000fd,0x2dd401d9}},	//   _thoc, zvuć, ханә, تُکھ_, 
   {{0xed591fd9,0x6f0000d2,0x94fc031c,0xada403fb}},	//   _год_, _uhoc, _ཐེའི_, _наел, 
   {{0x5e8400aa,0x7cfc1df3,0x5ea00472,0x00000000}},	//   _رپوټ_, sèra, _سمول, --, 
   {{0x7cfc4bc7,0xdca0f086,0xb4b40b98,0x63a0007c}},	//   pèra, _пачи, जसो_, ännk, 
   {{0x7c2c010e,0x00000000,0x00000000,0x00000000}},	//   _şarg, --, --, --, 
   {{0xc6f81fe2,0x677002d3,0xb92401e1,0x00000000}},	//   інах_, _ኣካይዱ_, _jawọ_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [1b170] --, --, --, --, 
   {{0xb974009f,0x00000000,0x00000000,0x00000000}},	//   _آئيڪ, --, --, --, 
   {{0x57b4084c,0xd7f801f4,0x00000000,0x00000000}},	//   _збэт, _ную_, --, --, 
   {{0xdb20003b,0x00000000,0x00000000,0x00000000}},	//   _årås, --, --, --, 
   {{0x7cfc1497,0x6804003e,0x95c800ea,0xa1e800ae}},	//   dèrn, béjé, _еура_, حراك_, 
   {{0xb9240241,0x44251fda,0x00000000,0x00000000}},	//   _aawọ_, _ül_, --, --, 
   {{0x3ea51fdb,0xafe0013d,0xbea4011c,0xfe711fdc}},	//   дийг, кошл, дайк, ندة_, 
   {{0x6efc0200,0x00000000,0x00000000,0x00000000}},	//   tëba, --, --, --, 
   {{0xdce8005f,0x8d28008e,0x00000000,0x00000000}},	//   _apgā, пның_, --, --, 
   {{0xc0d4007b,0x3f80005c,0x6efc0200,0x00000000}},	//   _غياب, æhus_, rëba, --, 
   {{0x3b08355b,0x63a0007c,0x00000000,0x00000000}},	//   жено_, ännh, --, --, 
   {{0xe3bc0011,0xeb9468dd,0x3cf8000d,0xbdb400f3}},	//   _আশাব, фию_, _उठके_, _обеј, 
   {{0x94040134,0xa9a0eb1e,0xe8fc0327,0x00000000}},	//   _ɑmɑ_, вияд, rtûn_, --, 
   {{0x315404ac,0x82fc025c,0x17c8016c,0x7cfc0ba1}},	//   וישן_, _ཟེའུ_, зҳои_, mèro, 
   {{0xd7bc0134,0x7cfc068c,0xcc080150,0x6d4402f0}},	//   yerε, lèro, _ىزىن_, ákav, 
   {{0xb4b42144,0xfb140150,0x00000000,0x00000000}},	//   जस्_, _توعج, --, --, 
   {{0xba74034d,0x6d44bb62,0x34a80640,0x7cfc180f}},	// [1b180] _فاکت, škav, овао_, nèro, 
   {{0xd7bc013f,0x8e2002dd,0x00000000,0x00000000}},	//   werε, _бiз_, --, --, 
   {{0x7cfc067c,0x91540241,0x37e40a5b,0x680400e5}},	//   hèro, _ọ̀_, _цонг, réjé, 
   {{0xaa78022c,0x36340066,0x00000000,0x00000000}},	//   rnýg, _تردس, --, --, 
   {{0x7cfc068c,0xb92401e1,0x00000000,0x00000000}},	//   jèro, _rawọ_, --, --, 
   {{0x628c0077,0x7cfc0ba1,0xf53c0092,0x00000000}},	//   _ócon, dèro, ራቴጂዎ, --, 
   {{0x63802b39,0x7cfc2508,0xaf04026b,0x00000000}},	//   _игра, tèrn, мчик, --, 
   {{0x7cfc067c,0x3ebc0042,0x00000000,0x00000000}},	//   fèro, _clwt_, --, --, 
   {{0x7cfc0ba1,0x6908031c,0xf0641d4a,0x2d8000e4}},	//   gèro, _mżer, _окап, ìke_, 
   {{0x7cfc067c,0x00000000,0x00000000,0x00000000}},	//   sèrn, --, --, --, 
   {{0xc05803ee,0xe4540a1e,0x7cfd1fdd,0x60d4010f}},	//   _ѕіѕ_, וייט_, pèrn, _קובא_, 
   {{0x63a11fde,0x92b00c58,0x7cfc180f,0x3ebc0142}},	//   änni, টোৰ_, bèro, _glwt_, 
   {{0x7cfc0ba1,0x6fb00014,0x9f400241,0x1d300153}},	//   cèro, _سۅکا, _ájò_, _анія, 
   {{0x6908025c,0xec1401d5,0x38a40419,0x764003b2}},	//   _ażer, _قوشد, _kôry_, ðoyn, 
   {{0xd7f91fdf,0x5bc03669,0x98c40116,0x644001a9}},	//   дут_, _لقول, тсял, аnin, 
   {{0x6d440024,0x56e400cd,0x00000000,0x00000000}},	//   škau, _śīrṣ, --, --, 
   {{0x09d80d42,0x00000000,0x00000000,0x00000000}},	// [1b190] _সরকা, --, --, --, 
   {{0x69080003,0xb86407d2,0x1b040154,0xbcfc00e4}},	//   _eżer, _كاپو, _রূপে_, ytũm, 
   {{0xe8fc003a,0x7cfc068c,0xf8b40166,0xd32401c6}},	//   ntûm_, zèro, _чөя_, вьчи, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7cfc0ba1,0x00000000,0x00000000,0x00000000}},	//   xèro, --, --, --, 
   {{0xd1b8438b,0xd548dcb1,0x85051fe0,0x7cfc0ba1}},	//   باما_, _زلفو_, _سوزن, vèro, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd25807d5,0x7cfc1497,0x00000000,0x00000000}},	//   _оцу_, tèro, --, --, 
   {{0x6298aca0,0xa3d4121d,0x00000000,0x00000000}},	//   _inuo, ापक_, --, --, 
   {{0xee2d1fe1,0xb16c012c,0x628801bf,0x7cfc180f}},	//   _ән_, ížeč, ldgo, rèro, 
   {{0x7eb51fe2,0x671c7220,0x7cfc068c,0x2d8001bf}},	//   _lápi, _मूलक_, sèro, æker_, 
   {{0x62891fe3,0x7cfc068c,0xfaa4014b,0x00000000}},	//   ndgo, pèro, хамо, --, 
   {{0xed4cbd3e,0xd01000dd,0x7eb40122,0x684802d3}},	//   _що_, _ملے_, _nápi, _ንምምስ, 
   {{0xfc3005d3,0x9c10010b,0xf1c800d0,0x00000000}},	//   _صحت_, _ичйә, _ukáž_, --, 
   {{0x62980198,0x369402dc,0x7cfc0100,0xcc0800db}},	//   _onuo, ншас, nèrm, _ۉزۉن_, 
   {{0x6440008c,0x98a063e0,0x37e400fd,0xa3b02d8f}},	//   ðnin, _otić_, _җомг, टहन_, 
   {{0x7eb51fe4,0xaad80375,0x62880142,0x63b000c7}},	// [1b1a0] _cápi, _מחקר, ddgo, қәрх, 
   {{0x62980134,0x62880549,0x00000000,0x00000000}},	//   _anuo, edgo, --, --, 
   {{0x040c00b8,0x00000000,0x00000000,0x00000000}},	//   _kāṃc, --, --, --, 
   {{0xaa780232,0x7cfd1fe5,0x35a40d33,0xb1441eca}},	//   mnýc, dèrm, _замг, ендл, 
   {{0xaa780232,0x7cfc007f,0xb38801f3,0x00000000}},	//   lnýc, tèrl, _መጋዘን_, --, 
   {{0x63b80198,0x62991fe6,0x00000000,0x00000000}},	//   _ƙunt, _enuo, --, --, 
   {{0xaa780232,0x7eb40232,0x7bd400d2,0x7af400c7}},	//   nnýc, _zápi, úzul, _okyt, 
   {{0x66d80724,0x629800df,0x3c900330,0xede400fb}},	//   mäkä, _gnuo, یینز, нһеҙ_, 
   {{0x66d91fe7,0x30191fe8,0xf1a803e6,0x63a00267}},	//   läkä, _فتاة_, _عاره_, ännv, 
   {{0x7af476b8,0xa1100aad,0xaa7802fb,0x605c0092}},	//   _akyt, _موقت, knýc, ተናገድ_, 
   {{0xc0dc069c,0x31e000bd,0xaa780232,0x66d8da8f}},	//   _ንኹሉ_, _বরিশ, jnýc, näkä, 
   {{0xaa78278a,0xad2400c6,0x61e81bce,0xdd8c030f}},	//   dnýc, _كرتو, _ëllë, _گوه_, 
   {{0xbe940451,0x66d80108,0x6440022e,0x00000000}},	//   _جهنڊ, häkä, аnil, --, 
   {{0x7eb41a36,0xdd8c021a,0x21280005,0x58840220}},	//   _rápi, _دوه_, _éche_, лыса, 
   {{0x66c0000d,0x66d80108,0x00000000,0x00000000}},	//   _lõke, jäkä, --, --, 
   {{0x2d84002d,0x7b200129,0x7eb406ea,0x66d80108}},	//   _ksoe_, _bœuf, _pápi, däkä, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [1b1b0] --, --, --, --, 
   {{0xaa786b07,0x6298002d,0x439415ce,0x00000000}},	//   bnýc, _snuo, казс, --, 
   {{0xaa780122,0x00000000,0x00000000,0x00000000}},	//   cnýc, --, --, --, 
   {{0xbd0401e1,0xf1d000af,0x57a400c7,0x00000000}},	//   _akẹ́, _देहन, _сшьа, --, 
   {{0x63b80c09,0x629807de,0x56951fe9,0x00000000}},	//   _ƙuns, _vnuo, _саят, --, 
   {{0x7cfd0976,0x70c800f1,0x66d80139,0x00000000}},	//   tèrm, وهنې_, bäkä, --, 
   {{0x66d80139,0x00000000,0x00000000,0x00000000}},	//   cäkä, --, --, --, 
   {{0x7c800201,0xcf24179c,0x73c00046,0xf1d0230e}},	//   _ይቻላል_, دروي, _тәуе, _देवन, 
   {{0xd1b91fea,0xaa780316,0xed40539e,0xfce400c7}},	//   _كاكا_, znýc, анып, коио, 
   {{0x0d08005e,0x61f91feb,0x7af478d0,0x68f400b5}},	//   ндық_, _iyul, _skyt, _nkxd, 
   {{0x2724004d,0x3f840790,0xa3d40073,0x6d440413}},	//   _nõn_, _uslu_, ापट_, ákar, 
   {{0xaa786b07,0xe61c001e,0xf420015b,0xdbb401e0}},	//   vnýc, _ngô_, _পড়ার_, _үткә_, 
   {{0x6d4404b9,0x6d5c00b8,0x00000000,0x00000000}},	//   škar, _āpag, --, --, 
   {{0xaa78278a,0x61f8a376,0xba0400c7,0x6440022e}},	//   tnýc, _myul, нҭқа_, аnim, 
   {{0xac04fb83,0x81b400cc,0x00000000,0x00000000}},	//   _инша_, _ছেম_, --, --, 
   {{0xaa780232,0x66d80108,0x61f82ca8,0x00000000}},	//   rnýc, väkä, _oyul, --, 
   {{0x61f91fec,0xaa780232,0x7d0c0395,0x7cfc020c}},	// [1b1c0] _nyul, snýc, _èass, jèrk, 
   {{0xf8051fed,0xaa791fee,0x66d8023a,0x81b400fe}},	//   _үчүн, pnýc, täkä, _ছেভ_, 
   {{0x213c020c,0x61f8013d,0x7eb408a5,0x90b400c7}},	//   _awuh_, _ayul, _hápu, қәаш, 
   {{0x66d80724,0x61f91fef,0x7eb42507,0x00000000}},	//   räkä, _byul, _kápu, --, 
   {{0xa2d06cb9,0x66d8005b,0xf1d01db2,0x00000000}},	//   جينت, säkä, _देशन, --, 
   {{0x61f860fc,0xbfac00cc,0xfbc01100,0x00000000}},	//   _dyul, _কেইঘ, शनाम, --, 
   {{0x213c4a16,0x61f80083,0xb2242377,0x64140354}},	//   _ewuh_, _eyul, _амбл, _аврă, 
   {{0x2d842815,0xfe0c0034,0x66c00037,0x799402d0}},	//   _psoe_, ाइंस_, _tõke, _oryw, 
   {{0x61f801ed,0x7c2c1395,0xceb800fd,0x00000000}},	//   _gyul, _şara, _җәй_, --, 
   {{0x2d680131,0x6d5c00dc,0xbb2c00d1,0x00000000}},	//   _ﻳﻪﻧﻰ_, _āpad, _ﺩﻩﻝ_, --, 
   {{0xa0300075,0x799402d0,0x7b2006af,0x00000000}},	//   _ئىمت, _aryw, _nœud, --, 
   {{0x2d8401e0,0x79940142,0x00000000,0x00000000}},	//   _tsoe_, _bryw, --, --, 
   {{0x4ea40032,0xada400d1,0x27240254,0x6da40818}},	//   _арҙа, _шадл, _sõn_, _шида, 
   {{0x79941829,0x6bd400ae,0x00000000,0x00000000}},	//   _dryw, _لتعر, --, --, 
   {{0x799402d0,0x00000000,0x00000000,0x00000000}},	//   _eryw, --, --, --, 
   {{0x9c14011a,0x79940210,0x00000000,0x00000000}},	//   _בחוק_, _fryw, --, --, 
   {{0xf8b40323,0x68f40139,0x79940210,0xf1d00037}},	// [1b1d0] _өөр_, _tkxd, _gryw, _देलन, 
   {{0xa5b80599,0x61f800b5,0x454400db,0x09d800fe}},	//   _agóc, _ryul, _ەچاق, _ধঁপা, 
   {{0x213c020c,0xf8b0008f,0x7eb402f0,0x9f8801e3}},	//   _swuh_, _השי_, _zápu, _höör_, 
   {{0xdee0001f,0x2ee40240,0x62300022,0x00000000}},	//   ኞችን_, _njof_, рҵау, --, 
   {{0x2164516c,0x34a00014,0x16840345,0x00000000}},	//   ттег, _گۅلٲ, _ئاپێ, --, 
   {{0xb9ec044e,0xe05404fb,0x63a00267,0xd4980354}},	//   _ሓው_, ئیات_, änns, _ирс_, 
   {{0x136800f7,0x94d5139e,0x00000000,0x00000000}},	//   _ишти_, _торц, --, --, 
   {{0x7cfc0137,0xaa7800ee,0x61f81180,0x00000000}},	//   mèri, ynýa, _tyul, --, 
   {{0x4034206e,0x213c0214,0x7cfc35f5,0x61f803e0}},	//   _безс, _uwuh_, lèri, _uyul, 
   {{0x3b8401c0,0x6098007b,0x1ea800ec,0xe8680023}},	//   глог, _تخرج_, _ڪائي_, _ድምጾም_, 
   {{0x7a685c81,0x7c940502,0x7cfc00cf,0x7eb41d1d}},	//   нинг_, نشگا, nèri, _sápu, 
   {{0x7994006d,0x7eb51ff0,0x00000000,0x00000000}},	//   _pryw, _pápu, --, --, 
   {{0x168403e6,0x80b817ee,0xbf1000fb,0x676c0240}},	//   یارێ, ्सपे, _күҫә, _ድልየቱ_, 
   {{0x79940660,0x8b640330,0x00000000,0x00000000}},	//   _vryw, دایم, --, --, 
   {{0xb7d80133,0x9ba00131,0x7994522d,0x00000000}},	//   رورا_, _ئەجى, _wryw, --, 
   {{0x799403cb,0x7eb40174,0x8b640244,0x00000000}},	//   _tryw, _tápu, _ئاوم, --, 
   {{0xe5a11ff1,0xf5082472,0xf5e84eb0,0xc0dc0092}},	// [1b1e0] бити, енал_, хмал_, _ንጹሕ_, 
   {{0x7cfc0137,0x4b3c001f,0xa44007a5,0x00000000}},	//   fèri, _የተጠየ, йнуд, --, 
   {{0x7cfc56ed,0x7984009a,0x80b800af,0x122400c7}},	//   gèri, lwkw, ्सने, азеҭ, 
   {{0x31680a31,0x2bf4008f,0x45640014,0x4374013e}},	//   ешко_, אמען_, _چھلہ, руфт, 
   {{0x35f8a012,0xd04400c7,0x63a0007c,0x95b401c4}},	//   _سرحد_, иҭак, ännr, _төвх, 
   {{0x7cfd1fe5,0x8f3402d5,0xa1111fdc,0x00000000}},	//   bèri, аекц, مونت, --, 
   {{0x76443c8b,0x7cfc004e,0xa0a000ea,0x00000000}},	//   _keky, cèri, сајд, --, 
   {{0x79851ff2,0x51d401d9,0x00000000,0x00000000}},	//   kwkw, _پۯتھ_, --, --, 
   {{0xfe4401b9,0xad24598f,0x00000000,0x00000000}},	//   شکنی, دربو, --, --, 
   {{0xddc8084c,0x75240ac5,0x1704031c,0x212800e4}},	//   ţişt, _mukz, _ཙེའམ_, _écha_, 
   {{0xa1102be7,0x7eb4a896,0xbcfc0022,0xee38009b}},	//   _اولت, _cáps, ytũv, _зне_, 
   {{0x76451ff3,0x67200264,0x6efc0240,0x00000000}},	//   _neky, _énji, këbi, --, 
   {{0x752405b1,0x6e211ff4,0x7cfc0100,0x3eb8343a}},	//   _nukz, _igob, zèri, öste_, 
   {{0xe78480d7,0x13ac03d4,0xb8e40022,0x473401a9}},	//   лубо, কৈয়, ассқ, ингс, 
   {{0x76451ff5,0x6e20b567,0x6d401368,0xd1ec02d3}},	//   _beky, _kgob, _hwoa, _ህያብ_, 
   {{0x6d4002e2,0x7644010e,0xf4b401d5,0x00000000}},	//   _kwoa, _ceky, یشلگ, --, 
   {{0xf8acdcb2,0x6e20014b,0x80b80b67,0x00000000}},	// [1b1f0] سکی_, _mgob, ्समे, --, 
   {{0x7cfd1c3e,0xf8b40184,0x76442f63,0x2cbc0175}},	//   tèri, _көс_, _eeky, nktd_, 
   {{0x6e211ff6,0xa3e80124,0xe190009d,0x00000000}},	//   _ogob, хьаз_, өлжө, --, 
   {{0x6e211ff7,0x76440660,0x6d400241,0x938800c7}},	//   _ngob, _geky, _owoa, ысуа_, 
   {{0x7cfd1ff8,0xb68400db,0x00000000,0x00000000}},	//   sèri, _ئشپى, --, --, 
   {{0x6e211ff9,0x256c29ef,0x7eb40122,0x656c0455}},	//   _agob, mül_, _nápr, _iqch, 
   {{0x256d1ffa,0x6d400083,0xd4980801,0x443001c4}},	//   lül_, _awoa, _сря_, _ifz_, 
   {{0x44300b4b,0x6d401368,0x64440165,0xb9ec0023}},	//   _hfz_, _bwoa, _heji, _ሓፍ_, 
   {{0x64451ffb,0x256d1ffc,0x44311ffd,0x00000000}},	//   _keji, nül_, _kfz_, --, 
   {{0x6444038e,0x6e20849d,0x6d400363,0x8e0800ee}},	//   _jeji, _egob, _dwoa, ымың_, 
   {{0x64451ffe,0x7984020c,0x256d1fff,0xb098011a}},	//   _meji, wwkw, hül_, _שיער, 
   {{0x64452000,0x256d2001,0x656c01b9,0xee2c00ec}},	//   _leji, kül_, _oqch, _ٺٽو_, 
   {{0x76452002,0x3eac02d3,0x00000000,0x00000000}},	//   _reky, mjet_, --, --, 
   {{0x64452003,0xe8f45322,0x76452004,0x3ead2005}},	//   _neji, иля_, _seky, ljet_, 
   {{0xb8dd0b67,0x656c03f0,0xf74424db,0xf6252006}},	//   _आव_, _aqch, ребо, идво, 
   {{0x3ead2007,0x1fe40154,0x7eb41155,0x00000000}},	//   njet_, _ফরাস, _zápr, --, 
   {{0x64452008,0x256d02a1,0x443000d7,0x80c40d2b}},	// [1b200] _beji, gül_, _bfz_, वसाइ, 
   {{0x764404ba,0x3ead2009,0x3898008f,0x656801c3}},	//   _weky, hjet_, _ייִנ, àgha, 
   {{0xddd80552,0x7d000013,0x3ead200a,0x656c0455}},	//   jduž, ills, kjet_, _eqch, 
   {{0x4430009a,0x26d80481,0xa3e40073,0x3ead200b}},	//   _efz_, ciqo_, _बखर_, jjet_, 
   {{0x27f4d37d,0x3eac20c2,0x256c1b0d,0x43740b01}},	//   _مفید_, djet_, cül_, _қурт, 
   {{0x60f41ed2,0x6e2008c2,0x6445200c,0x3eac01bf}},	//   анія_, _sgob, _geji, ejet_, 
   {{0x3eac036e,0x00000000,0x00000000,0x00000000}},	//   fjet_, --, --, --, 
   {{0x7d000408,0x3eac044e,0xeeb401e0,0xb1a001ee}},	//   ells, gjet_, ркиә_, _мһеҙ, 
   {{0xb7e800cc,0x00000000,0x00000000,0x00000000}},	//   _গৰমত_, --, --, --, 
   {{0x64440067,0x5c70234c,0x7cfc0100,0xacb000db}},	//   _xeji, ольт, zèrv, تەتب, 
   {{0x256c00dd,0x3ead200d,0xa5b8004d,0x395000c0}},	//   zül_, bjet_, _ngón, _avys_, 
   {{0x6e21200e,0x6d401368,0x7d001554,0x84800023}},	//   _ugob, _twoa, alls, _ነዊሕን_, 
   {{0x3dcc5675,0x256c0793,0x00000000,0x00000000}},	//   czew_, xül_, --, --, 
   {{0x256c00dd,0xaa7802fb,0xe730007b,0x00000000}},	//   vül_, mným, قصر_, --, 
   {{0x6445200f,0xaa780122,0x3af000e4,0x00000000}},	//   _reji, lným, hápy_, --, 
   {{0x256d2010,0x443000d0,0xa3a40330,0x91bc00fe}},	//   tül_, _sfz_, یحان, _আইনখ, 
   {{0x64452011,0xaa780122,0xddd80558,0x656c0129}},	// [1b210] _peji, nným, zduž, _qqch, 
   {{0x256c00dd,0x26300882,0x3ead2012,0x7cfc068c}},	//   rül_, ṇo_, zjet_, sèrv, 
   {{0x64452013,0x69cc005f,0x256d2014,0x787401c8}},	//   _veji, lzce, sül_, _اُپا, 
   {{0x29012015,0x64440014,0x26d800f1,0xaa7802f0}},	//   llja_, _weji, qiqo_, kným, 
   {{0x3ead2016,0x64452017,0x80bc045e,0x69cc0007}},	//   vjet_, _teji, ্চস্, nzce, 
   {{0xaa780122,0x8afc002d,0x3eac4e1b,0x00000000}},	//   dným, bręg, wjet_, --, 
   {{0x3eac044e,0x987c00c8,0xa2640801,0xe8fc003a}},	//   tjet_, דרוק, _възл, ltûs_, 
   {{0x21284056,0x29000427,0x13a80133,0x2bc8043e}},	//   _écho_, hlja_, _خۆمی_, ानना, 
   {{0x3ead2018,0x00000000,0x00000000,0x00000000}},	//   rjet_, --, --, --, 
   {{0x3ead2019,0xab7801a9,0x5f741424,0x2900031c}},	//   sjet_, _bo鼠i, _ناصر, jlja_, 
   {{0x3dcc5675,0x3ead201a,0x92cc03d4,0x3fc400fb}},	//   szew_, pjet_, ৰকৰ_, _урағ, 
   {{0xaa780122,0xa5b80de2,0x3eac0240,0x3f140114}},	//   bným, _ngóo, qjet_, _удес, 
   {{0x2ab8002e,0x7cfc068c,0xaa7802fb,0x7e680af9}},	//   _nëbu_, fèrt, cným, mgep, 
   {{0x7e69201b,0x29000010,0x35dc01e1,0x00000000}},	//   lgep, glja_, _níbẹ_, --, 
   {{0xc795201c,0xdd8c158b,0x00000000,0x00000000}},	//   орты, _روژ_, --, --, 
   {{0x75d4084e,0x2900036e,0x7d2c0023,0x00000000}},	//   ميزا, alja_, _ተኣሳሲ, --, 
   {{0x290049ad,0xe5a1201d,0x7cfc1497,0x7e68002f}},	// [1b220] blja_, пити, bèrt, igep, 
   {{0xd9108bee,0x38780223,0x7cfc020c,0x7c2c0790}},	//   _آیس_, _ubpr_, mèrs, _şarj, 
   {{0x3dbc0729,0xaa79201e,0x00000000,0x00000000}},	//   ইছিল, zným, --, --, 
   {{0x6738110c,0x7e6801f5,0x4681201f,0x00000000}},	//   ćujt, jgep, _оқса, --, 
   {{0xf1d0028a,0xe8fc003a,0xaa7800d7,0x00000000}},	//   _देखन, ctûs_, xným, --, 
   {{0xb1c406ba,0xaa792020,0x7e680036,0x2bc80303}},	//   аңға_, miýe, egep, ानमा, 
   {{0x7e680e78,0x2d80031c,0x3db400cc,0xaa7800ee}},	//   fgep, ħkem_, _জেলল, liýe, 
   {{0xa5b8068f,0x7e692021,0x6da40184,0xaa792022}},	//   _ogól, ggep, йҙең_, tným, 
   {{0xaa7809a5,0x61412023,0xfbd4015b,0xefe8010c}},	//   niýe, _нета, _সুলত, _ህላዌ_, 
   {{0xaa7802fb,0x7e6801ab,0xc9d400d1,0xa064011c}},	//   rným, agep, ﻟﻼﻧﻐ, _гафа_, 
   {{0xaa7802fb,0x7cfc7d47,0x7eb401d3,0xfca801ec}},	//   sným, vèrt, _tápp, рсық_, 
   {{0x68e40369,0xaa792024,0x2bc812eb,0xdc8c0023}},	//   wnjd, pným, ानबा, _ዝጻረር_, 
   {{0x290005a1,0x80bc0154,0xb4f800cd,0xaa7800a2}},	//   tlja_, ্চর্, ्ताय_, jiýe, 
   {{0xaa78010e,0x29000254,0x00000000,0x00000000}},	//   diýe, ulja_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x29000fcf,0x7cfc26b7,0x1ae400f3,0x00000000}},	//   slja_, sèrt, _нојм, --, 
   {{0x290008a4,0x48c4468c,0x7b2000b0,0xe4e402bf}},	// [1b230] plja_, _дәва, _tēur, біжн, 
   {{0xa4240139,0x00000000,0x00000000,0x00000000}},	//   сьал, --, --, --, 
   {{0x7c2d2025,0x7d1c026c,0x543401b9,0x7e68005c}},	//   _şark, ìssi, سرلر, ygep, 
   {{0x03fc015b,0xfbd400cc,0xaa7800d7,0x6d5c1c48}},	//   ৌশলী_, _সুঁত, dnýk, _āpan, 
   {{0xd1500092,0x00000000,0x00000000,0x00000000}},	//   _ኃይማኖ, --, --, --, 
   {{0xd7740244,0x00000000,0x00000000,0x00000000}},	//   _بایع, --, --, --, 
   {{0x7e681af3,0xaa780008,0xddd800f3,0x7cfc007f}},	//   tgep, rnýj, deuš, zèrs, 
   {{0x2ff400d1,0xc2c44c1c,0x00000000,0x00000000}},	//   ڭتۇڭ, _بيري, --, --, 
   {{0xd244010b,0x3cc800f3,0xefcc0023,0x00000000}},	//   _хэси, илио_, _እዋይ_, --, 
   {{0x7cfc2508,0x3b380020,0x7e692026,0xcd291c53}},	//   vèrs, _የተገኘ, sgep, حسين_, 
   {{0x7e680036,0x8afc012d,0x00000000,0x00000000}},	//   pgep, dręb, --, --, 
   {{0xc0f0044e,0xcd280451,0xc0d40023,0x7cfc0100}},	//   ልዎም_, _ڏسون_, ክዎም_, tèrs, 
   {{0x0f180f84,0xe8fc000f,0xbc9400f3,0xb5880150}},	//   _اغلب_, krûd_, _мадј, _ﻗﻴﺎﻝ_, 
   {{0x8afc14cf,0x8e2401a9,0xbb440354,0x00000000}},	//   stęp, limа_, _декк, --, 
   {{0xb6f81884,0x5c04ce01,0x76b40114,0x00000000}},	//   لىسا_, _уяда, ољац, --, 
   {{0x7cfc067c,0x672c0118,0xdb080cad,0x00000000}},	//   mèrq, _žijí, _ìlàn, --, 
   {{0x0ae816ac,0x66e00117,0xaa7801ef,0x00000000}},	// [1b240] _دروي_, фота, dnýh, --, 
   {{0xd910006c,0x00000000,0x00000000,0x00000000}},	//   _سیز_, --, --, --, 
   {{0xba0402d3,0xaa780209,0x28a407f7,0xd9cc03d4}},	//   _ወላ_, siýe, खारि, _লখিম, 
   {{0xe2780116,0x6b78010f,0xd68800d1,0x2bc80aff}},	//   ишчә_, ירענ, ﺗﻠﻪﺭ_, ानता, 
   {{0x9268052f,0xa130009a,0x00000000,0x00000000}},	//   арҙа_, وروش, --, --, 
   {{0x7bcc0198,0x211400aa,0x27fc0112,0xbe2001e1}},	//   _ƙaul, يتوب_, ßung_, _mọdẹ, 
   {{0xaa7801ef,0x00000000,0x00000000,0x00000000}},	//   bnýh, --, --, --, 
   {{0x1ef400c6,0x316407c5,0xe28001d5,0x00000000}},	//   يعية_, puoz_, _олси, --, 
   {{0x307400c9,0xb05912cd,0xf0a8ea13,0xa2180354}},	//   _мужс, _نشاط_, _ккал_, _ватă_, 
   {{0x8afc0034,0x43700137,0xa0300150,0xe0d4011c}},	//   kręc, _زۇۇر, _يىقت, _дву_, 
   {{0x7cfc180f,0x64980677,0x2fe400ae,0x00000000}},	//   tèrr, בסיד, _بكاف, --, 
   {{0x8afc0034,0xa1240150,0xb8801155,0x00000000}},	//   dręc, _اكەل_, _šípo, --, 
   {{0x2d950bf0,0xae14084a,0x7c9c0092,0xace800d4}},	//   _фрес, देशन_, _ገበሬው_, _кмда_, 
   {{0x2bc81533,0x4c941d0f,0x00000000,0x00000000}},	//   ानदा, _хикс, --, --, 
   {{0x7d1c1f40,0x00000000,0x00000000,0x00000000}},	//   ïsse, --, --, --, 
   {{0x7c2c008e,0x00000000,0x00000000,0x00000000}},	//   _ğari, --, --, --, 
   {{0x2b98003a,0x06cc0eac,0x7c2c154a,0x00000000}},	// [1b250] _hīc_, রচলি, _şari, --, 
   {{0x9984438b,0xf93401c0,0x00000000,0x00000000}},	//   _کلیو, _хүрч_, --, --, 
   {{0xefe8001f,0x66c00037,0x2d8000d1,0x00000000}},	//   _ህጋዊ_, _jõkk, ﯩﻤﻨﻰ_, --, 
   {{0xa2802bef,0xe1f00066,0x00000000,0x00000000}},	//   بیرو, وسش_, --, --, 
   {{0x66c000c5,0x9294074d,0x26140562,0xe6b400a2}},	//   _lõkk, ьацц, पेशी_, _ýeññ, 
   {{0x04c835f9,0x80c401f9,0x667400e5,0x00000000}},	//   _اوسي_, वसें, _ادھر, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8d292027,0xfce41985,0xef0c00fd,0xc1040127}},	//   оның_, зопо, _җм_, _فوري, 
   {{0xd10401ec,0x7f94014b,0x00000000,0x00000000}},	//   _قۋنۋ, _назх, --, --, 
   {{0x01bc00bd,0xfaa8007b,0xbe200241,0x5fac000d}},	//   _অধিদ, مهدي_, _sọdẹ, _झपिल, 
   {{0xef0c00d6,0x6fe4031c,0x3f14010b,0x00000000}},	//   _їм_, _སྨྲའ, _эдес, --, 
   {{0x41bc07b7,0x00000000,0x00000000,0x00000000}},	//   ्निस, --, --, --, 
   {{0x26c8070d,0x00000000,0x00000000,0x00000000}},	//   _alco_, --, --, --, 
   {{0xd5b00014,0x69c80139,0x00000000,0x00000000}},	//   ھہس_, _ügen, --, --, 
   {{0x41bc3f55,0xe7b12028,0xd5b00014,0x00000000}},	//   ्नास, رمقد, پہس_, --, 
   {{0x2d3802d3,0xa2bc033f,0x261400bc,0x7bc001f4}},	// [1b260] _የቐንየ, _वक़्, पेली_, lylu, 
   {{0x26c80048,0xaa7800ee,0x77c82b2e,0x00000000}},	//   _elco_, miýa, _глог_, --, 
   {{0xc61c00bd,0xaa7800ee,0x00000000,0x00000000}},	//   ধুলা_, liýa, --, --, 
   {{0x55c4036b,0x00000000,0x00000000,0x00000000}},	//   _жамғ, --, --, --, 
   {{0xaa7809a5,0xa1300131,0x7bc12029,0x00000000}},	//   niýa, ۈرۈش, hylu, --, 
   {{0x27fc0356,0x00000000,0x00000000,0x00000000}},	//   şune_, --, --, --, 
   {{0x64a001c0,0x741402dd,0x1acc00dc,0xaa780432}},	//   _яара, _ءوزا, ासाथ, hiýa, 
   {{0x66c00254,0x2bc8090a,0xaa78010e,0x00000000}},	//   _rõkk, ानसा, kiýa, --, 
   {{0xe281202a,0x7cfd202b,0x6a8008a5,0xe29c02d2}},	//   _ялти, tèrp, _lífæ, _óða_, 
   {{0xe16005d9,0xaa78010b,0x00000000,0x00000000}},	//   _سگهي, diýa, --, --, 
   {{0x7cfc067c,0x00000000,0x00000000,0x00000000}},	//   rèrp, --, --, --, 
   {{0xef180414,0xbc540092,0xd1d00092,0xaa78010b}},	//   _уме_, _መጠየቂ, _እራት_, fiýa, 
   {{0x6f0000ca,0xaa780209,0xed080154,0x00000000}},	//   _ikoc, giýa, রদৌস_, --, 
   {{0x66c00037,0x7e085285,0x7bc0032e,0x00000000}},	//   _tõkk, _بزمِ_, bylu, --, 
   {{0x5c78011a,0x7bc1202c,0x00000000,0x00000000}},	//   _האוה, cylu, --, --, 
   {{0xbbe9202d,0xaa780209,0x96d80034,0x249c0432}},	//   _برهم_, biýa, नोलॉ, _şum_, 
   {{0x2bc807b7,0xe570007b,0x00000000,0x00000000}},	// [1b270] ानवा, عطر_, --, --, 
   {{0x290400c6,0x1b040183,0x00000000,0x00000000}},	//   _óna_, _ৰূপে_, --, --, 
   {{0xfc301aa1,0xe6c4038b,0xca7801a9,0x97a402e8}},	//   nḓa_, _فتحي, _muvо, _зрял, 
   {{0xd7f8030d,0x00000000,0x00000000,0x00000000}},	//   _хуь_, --, --, --, 
   {{0xe9dc067c,0x7bc00210,0x00000000,0x00000000}},	//   maús_, zylu, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7bc0020c,0xb60400d0,0xaa7800a2,0x00000000}},	//   xylu, _vráť, lnýu, --, 
   {{0x3eb81ffb,0x358402d3,0xa5b8007b,0x7bc11d01}},	//   ðst_, _ርክባት_, _agói, vylu, 
   {{0x6289202e,0x72a00075,0xbd880116,0x00000000}},	//   mego, _جەنن, تچان_, --, 
   {{0x6289202f,0x26f803d4,0x602001d3,0x00000000}},	//   lego, ্দটো_, _címü, --, 
   {{0xf0b4010f,0x00000000,0x00000000,0x00000000}},	//   _קלער_, --, --, --, 
   {{0x62892030,0xbe152031,0x63a0c6cb,0xa5b802d2}},	//   nego, _قواع, änny, _egói, 
   {{0xed4d2032,0x00000000,0x00000000,0x00000000}},	//   _шо_, --, --, --, 
   {{0x6288b567,0xaa780209,0x3ff8008f,0x2bdc0118}},	//   hego, riýa, ַפּע, _फेवा, 
   {{0xe7352033,0xaa7809a5,0x6288000f,0x3694030c}},	//   дес_, siýa, kego, мшас, 
   {{0x62892034,0xfa3401b9,0x00000000,0x00000000}},	//   jego, _غربد, --, --, 
   {{0x62892035,0x98a001a6,0x00000000,0x00000000}},	// [1b280] dego, _nuić_, --, --, 
   {{0xe3dc2aab,0x3f840010,0x00000000,0x00000000}},	//   _বুধব, _oplu_, --, --, 
   {{0x6aa800d2,0x628801f2,0xd6c400c7,0xd7e800f7}},	//   _úmfá, fego, _зинқ, _روحۇ_, 
   {{0x62892036,0x42d4109a,0x00000000,0x00000000}},	//   gego, нічу, --, --, 
   {{0x7520035b,0x7e6c00c7,0xa2bc0118,0x00000000}},	//   _аҟаҵ, _ñapy, _वकर्, --, 
   {{0x6f012037,0xefd40092,0xaa780162,0x2bdc0037}},	//   _skoc, _ኪራይ_, lnýt, _फइला, 
   {{0x62892038,0x00000000,0x00000000,0x00000000}},	//   bego, --, --, --, 
   {{0x62892039,0xede40032,0xaa781d0e,0x23740118}},	//   cego, мһеҙ_, nnýt, žejí_, 
   {{0x3f8400f3,0x00000000,0x00000000,0x00000000}},	//   _eplu_, --, --, --, 
   {{0x6fb00014,0x2bc8095f,0x4c9401c6,0x6140011c}},	//   _لۅتا, ानला, хиос, _рефа, 
   {{0x7d1c067c,0xee39203a,0xdce80171,0xaa780162}},	//   ïssa, _дне_, _apgē, knýt, 
   {{0x7c2cb753,0x6f00012d,0x81b400fe,0x2de4004e}},	//   _şart, _ukoc, _ছেট_, _оюлг, 
   {{0x2bdc04fa,0x31640165,0xa92801ec,0x00000000}},	//   _फेरा, nroz_, юіне_, --, 
   {{0x2129203b,0x3165203c,0xdd8c03e6,0x6289203d}},	//   _èche_, iroz_, _خوه_, zego, 
   {{0x6289203e,0xd7e40212,0x00000000,0x00000000}},	//   yego, віто, --, --, 
   {{0x62890c80,0x31640205,0xaa7801a8,0x00000000}},	//   xego, kroz_, gnýt, --, 
   {{0x6289203f,0x310c0882,0x994802eb,0x99640166}},	// [1b290] vego, िताः_, _قليل_, _итэл, 
   {{0x62880a49,0x00000000,0x00000000,0x00000000}},	//   wego, --, --, --, 
   {{0x20c80162,0x27e401c7,0x78f002dd,0x5504329e}},	//   _bøin_, _änn_, _сүру, тчта, 
   {{0x31c41c5c,0x26a4215c,0x6288030a,0x3164022e}},	//   ﯩﻠﯩﻜ, _تۇرپ_, uego, froz_, 
   {{0x3f840165,0xb60000bc,0xb5f002dd,0x008446bf}},	//   _splu_, žárn, _бүті, елло, 
   {{0x62892040,0xdb0802d2,0x00000000,0x00000000}},	//   sego, _ílön, --, --, 
   {{0x62892041,0x2d840086,0xfe7000c6,0xf7c000d1}},	//   pego, _apoe_, هدة_, _ﮬﺎﻟﺪ, 
   {{0x5dd401ec,0xaa78010e,0x7db400d8,0x00000000}},	//   _ﺘﻁﻭﻴ, diýo, есоц, --, 
   {{0x9980068f,0x13c400fe,0x3ea40166,0x00000000}},	//   _dziś_, _এইয়, _җилг, --, 
   {{0x0d08005e,0x91e4026a,0x213c4405,0x55ac010f}},	//   мдық_, _рође, _ituh_, קייַ, 
   {{0x3b092042,0xd9100214,0xaa78010e,0x00000000}},	//   зено_, ییع_, giýo, --, 
   {{0x73d8010f,0xeb944109,0x00000000,0x00000000}},	//   פֿיצ, хию_, --, --, 
   {{0xa9a12043,0x213c0327,0xdb242a77,0xdde86ea9}},	//   гияд, _jtuh_, _یوتی, _براه_, 
   {{0x17c8016c,0x21292044,0x213c009f,0x4a000022}},	//   дҳои_, _échu_, _mtuh_, рҟьа, 
   {{0xe9dc0008,0x3ebd2045,0x8cac033f,0xac140063}},	//   rbúa_, _kowt_, जारो, _пољу_, 
   {{0x3ebc002d,0x225c8106,0x7d000009,0xf624009b}},	//   _jowt_, _nduk_, lols, едбо, 
   {{0x7ae52046,0x27fc046c,0x213d1aca,0xf608015e}},	// [1b2a0] mikt, ğuna_, _ntuh_, ستره_, 
   {{0x225d0ef3,0xaa78022c,0x27fc3630,0xe8fc000f}},	//   _aduk_, snýt, şuna_, lrûn_, 
   {{0x213cebf1,0x316414ce,0x6aac01e7,0x72880064}},	//   _atuh_, wroz_, _áifé, збег_, 
   {{0x7ae52047,0x213c020b,0x3ebc0204,0x78bc0455}},	//   nikt, _btuh_, _nowt_, _hopv, 
   {{0x7564aaac,0x76552048,0x78bd2049,0x2c0400af}},	//   _سیاہ_, mayy, _kopv, _सुनू_, 
   {{0x7ae5204a,0x7655204b,0x3165204c,0x7d00022e}},	//   hikt, layy, rroz_, jols, 
   {{0x7ae5204d,0x213c003e,0xdde000de,0xd5c40055}},	//   kikt, _etuh_, _āršt, bhāü_, 
   {{0xe2940364,0x213c0327,0x78bc014f,0x7655204e}},	//   _пас_, _ftuh_, _lopv, nayy, 
   {{0x7ae447a0,0x78bc0af9,0x7d00045f,0x21644e8b}},	//   dikt, _oopv, fols, _пити_, 
   {{0x7ae401c4,0x7654155d,0x00000000,0x00000000}},	//   eikt, hayy, --, --, 
   {{0xdeec7798,0x7655204f,0x5ba011ed,0xa80003be}},	//   _бы_, kayy, гряз, _çıxm, 
   {{0xe8fc000f,0xef1800db,0xdb2001e1,0x00000000}},	//   grûn_, _эме_, _ńwòk, --, 
   {{0x7d012050,0x21292051,0x6ce43981,0x76552052}},	//   bols, _écht_, _піке, dayy, 
   {{0x7d012053,0x1e1000d4,0x00000000,0x00000000}},	//   cols, _смія, --, --, 
   {{0x7ae52054,0xab841064,0x76540ba7,0xd7f8009b}},	//   bikt, _чулк, fayy, еут_, 
   {{0xf1c407ae,0x7c240122,0x7654b434,0x7ae52055}},	//   _đánh_, _úhra, gayy, cikt, 
   {{0x225c0354,0xaa7803b2,0x85040472,0x3eb80108}},	// [1b2b0] _rduk_, snýs, نورن, östi_, 
   {{0x47342a39,0x76552056,0x00000000,0x00000000}},	//   _инос, aayy, --, --, 
   {{0x290016cb,0x76552057,0x68e401f5,0x213c01ef}},	//   moja_, bayy, mijd, _stuh_, 
   {{0x68e52058,0x29012059,0x52740228,0x79940042}},	//   lijd, loja_, гушу, _ysyw, 
   {{0x3ebc0204,0xb0bd205a,0x00000000,0x00000000}},	//   _rowt_, ्संग, --, --, 
   {{0x2901205b,0x68e42df6,0x7ae4ce7c,0xd498014b}},	//   noja_, nijd, zikt, _прс_, 
   {{0x6455205c,0x7d01205d,0x00000000,0x00000000}},	//   maxi, vols, --, --, 
   {{0x6455205e,0x2901205f,0x3f800309,0x995000d7}},	//   laxi, hoja_, çhuq_, _rúže_, 
   {{0x7ae52060,0x3010052f,0x29012061,0x213c0b5d}},	//   vikt, лдәр, koja_, _utuh_, 
   {{0x29012062,0x629831ce,0x7ae4083a,0x64552063}},	//   joja_, _hauo, wikt, naxi, 
   {{0x76543142,0x7ae456ce,0x62980751,0x29012064}},	//   yayy, tikt, _kauo, doja_, 
   {{0x64552065,0xd01000dd,0x3b540daf,0x7d001841}},	//   haxi, _چلے_, нкүр, sols, 
   {{0x7ae52066,0xbd884bcf,0x7d0084c9,0x62992067}},	//   rikt, _آنتن_, pols, _mauo, 
   {{0x7ae44e97,0x290024dd,0x62992068,0x776c07d6}},	//   sikt, goja_, _lauo, tubx, 
   {{0x645411d8,0x76552069,0x7ae5206a,0x66c0000d}},	//   daxi, tayy, pikt, _nõks, 
   {{0x6299206b,0x78bc0810,0xfb840022,0xdb080108}},	//   _nauo, _wopv, _зыҩн, äläk, 
   {{0x7655206c,0x68e401a4,0x65c1206d,0xa6800120}},	// [1b2c0] rayy, bijd, абта, јлуд, 
   {{0xa5b8067c,0x2901206e,0xa4402b97,0x64540014}},	//   _agós, coja_, инуд, gaxi, 
   {{0x62980112,0xf74400d8,0x00000000,0x00000000}},	//   _bauo, _шено, --, --, 
   {{0x76540a4d,0xbe44001f,0x66700228,0x00000000}},	//   qayy, _የፀጥታ, _ەگەر, --, 
   {{0xd13065dc,0xca78022e,0x6455206f,0x28a4547d}},	//   حمت_, _muvа, baxi, खाचि, 
   {{0x645400d8,0x70bc0562,0x00000000,0x00000000}},	//   caxi, ्सेल, --, --, 
   {{0xdf7000db,0x62992070,0x72940124,0xdfccf5f9}},	//   لديب, _fauo, _ишах, ييه_, 
   {{0x29001446,0x68e40d27,0x7c2d2071,0x71a40124}},	//   zoja_, zijd, _şarp, _иабз, 
   {{0x31240124,0x5d502eca,0xdce80205,0xa11000cf}},	//   _адаг, акыт, _argı, _چوقت, 
   {{0x26140574,0x4c94026a,0x6298003a,0x6ca41d0f}},	//   पेटी_, ћинс, _zauo, триж, 
   {{0x29012072,0xbf640050,0x7cfc007f,0x00000000}},	//   voja_, _مدنو, nèry, --, 
   {{0x68e52073,0xdb140321,0xbe200248,0x00000000}},	//   wijd, ðaða, _kọlẹ, --, 
   {{0x29012074,0x68e40cf9,0x645418f7,0x5ee400dc}},	//   toja_, tijd, yaxi, _जगत्_, 
   {{0x6d412075,0xa5b8f52d,0x29000024,0xab340022}},	//   _itoa, _ogór, uoja_, _иҿоу_, 
   {{0x68e52076,0x29012077,0x2cac014b,0x64547c1d}},	//   rijd, roja_, _infd_, vaxi, 
   {{0x29012078,0x7af40200,0x6454058a,0xa9c4014b}},	//   soja_, _gjyt, waxi, _асок, 
   {{0x64552079,0xa5b86791,0x2901207a,0x629802b5}},	// [1b2d0] taxi, _agór, poja_, _rauo, 
   {{0x62980618,0x590c0135,0x6d4001c8,0x66c00254}},	//   _sauo, _གེགས_, _mtoa, _põks, 
   {{0xed44806b,0x6455207b,0x62986b49,0x00000000}},	//   _گپ_, raxi, _pauo, --, 
   {{0x629801af,0x6d41207c,0x6455207d,0xc0cc0023}},	//   _qauo, _otoa, saxi, _እማመ_, 
   {{0x6d40016b,0x5695207e,0xed45207f,0x00000000}},	//   _ntoa, _таят, _دپ_, --, 
   {{0xdb04067c,0x6298009f,0xd1640395,0x00000000}},	//   _ernè, _wauo, ръци, --, 
   {{0x62992080,0x6d412081,0x443001a4,0x00000000}},	//   _tauo, _atoa, _igz_, --, 
   {{0x92680064,0x00000000,0x00000000,0x00000000}},	//   _арфа_, --, --, --, 
   {{0x44300010,0x63a80210,0x9258010a,0x00000000}},	//   _kgz_, łonę, _шатт_, --, 
   {{0x75ec06d9,0x7c941234,0x6d5c00dc,0x00000000}},	//   lôzô, уриц, _āpat, --, 
   {{0x6d4003d1,0x0d8401c6,0x8cb40139,0x00000000}},	//   _etoa, глөн, рсыч, --, 
   {{0x6d400109,0x75ec05da,0x00000000,0x00000000}},	//   _ftoa, nôzô, --, --, 
   {{0x67e001a9,0x00000000,0x00000000,0x00000000}},	//   _rеja, --, --, --, 
   {{0x44312082,0x63a40205,0x9ce401d3,0x79980210}},	//   _ngz_, _orjn, _جوتے_, łtwo, 
   {{0xb73400f2,0xdce80166,0x00000000,0x00000000}},	//   افرب, _urgı, --, --, 
   {{0x66e012d7,0x443000a2,0xdb0406af,0x69cc030a}},	//   боса, _agz_, _orné, ñneñ, 
   {{0x61f800aa,0x34852083,0xca54009d,0xad34010f}},	// [1b2e0] _nxul, лгаг, _өхөө, ָנעס_, 
   {{0x443004cc,0x33d400d4,0x00000000,0x00000000}},	//   _cgz_, ліет, --, --, 
   {{0x443001f2,0xdb0404d4,0x61f85844,0x84540b38}},	//   _dgz_, _arné, _axul, شىنچ, 
   {{0x44312084,0x00000000,0x00000000,0x00000000}},	//   _egz_, --, --, --, 
   {{0x63a40083,0x234400d1,0x00000000,0x00000000}},	//   _erjn, نلەپ_, --, --, 
   {{0x73341b92,0xb4249f21,0x443009b6,0x6d400109}},	//   _مىسا, _معزو, _ggz_, _rtoa, 
   {{0x6d412085,0x61f92086,0xc0cc0020,0x6f8405f5}},	//   _stoa, _exul, _እኛም_, уулж, 
   {{0x44300789,0x02c40166,0x23240353,0x00000000}},	//   _zgz_, _кисү, _боси_, --, 
   {{0x752c00ca,0xbb8c02dd,0x6d5c00b8,0x00000000}},	//   _kibz, _ﺒﻴﻨﻪ_, _āpas, --, 
   {{0xc0a8004b,0x752c031c,0x3a3000a2,0xbe200241}},	//   _لامل_, _jibz, _agyp_, _gọmẹ, 
   {{0xedd418ce,0xee840006,0x752c0100,0x9b4042c2}},	//   _әллә_, _было, _mibz, ینیو, 
   {{0x7bcc0b45,0xdfcc43b9,0x6d400083,0x395003cb}},	//   _ƙaur, _عين_, _ttoa, _bwys_, 
   {{0x6d400451,0x00000000,0x00000000,0x00000000}},	//   _utoa, --, --, --, 
   {{0x3a300493,0x752c031c,0x395003cb,0x00000000}},	//   _egyp_, _nibz, _dwys_, --, 
   {{0xb7c40967,0xfca8132f,0xb22002d2,0x00000000}},	//   артқ, _جانو_, _áæfi, --, 
   {{0x9a84030d,0xaa7800a2,0x00000000,0x00000000}},	//   _луьл, kiýi, --, --, 
   {{0x44312087,0x998421ec,0x752c01bf,0x39504e18}},	// [1b2f0] _pgz_, _هليو, _bibz, _gwys_, 
   {{0x41b49a87,0x00000000,0x00000000,0x00000000}},	//   یمار, --, --, --, 
   {{0x5c34008f,0x443001f5,0x3a3000a2,0xd04806be}},	//   ארבן_, _vgz_, _ygyp_, _öləs, 
   {{0x4174215c,0x994810e5,0x1c08000d,0x48fc00bc}},	//   لاتس, _جلیل_, _सुफल_, लकको_, 
   {{0xe1640063,0x1c080037,0x00000000,0x00000000}},	//   уђен, _सँभल_, --, --, 
   {{0xe0542c6c,0xb9ec02d3,0x67340135,0x3f6800d8}},	//   ایات_, _ዓው_, _kuxj, вико_, 
   {{0x44252088,0x7b205eb5,0x660c6ab6,0x93880108}},	//   _àl_, _mœur, _hyck, _йста_, 
   {{0x660c049f,0x61f8009d,0xc1d001e0,0x6d5c0055}},	//   _kyck, _txul, _мөлә, _āpar, 
   {{0x61f80117,0x660c01e3,0xe4f800cd,0x5184014b}},	//   _uxul, _jyck, ्वपि_, _гуха, 
   {{0x660c9c56,0x3b844e0c,0x51f406c2,0xfc044627}},	//   _myck, алог, _اسفر, иппо, 
   {{0x660c04f3,0xfc3006d6,0x3950017a,0x7fb801f7}},	//   _lyck, nḓi_, _swys_, _جهار_, 
   {{0xe8fc0b21,0x2020003d,0x3950015d,0xef0c0212}},	//   brûk_, ħriġ_, _pwys_, _єм_, 
   {{0x660c049f,0xbcfc00e4,0x89d40150,0xb7d800e5}},	//   _nyck, yrũh, бірш, ھورا_, 
   {{0x7b20004a,0xb7d80c4f,0x00000000,0x00000000}},	//   _cœur, پورا_, --, --, 
   {{0xf6541de1,0x672c00b5,0xe4f807d0,0x00000000}},	//   итаю, _bicj, ्वनि_, --, 
   {{0x24900092,0xe4c401b9,0x37e401d5,0x2bdc01f9}},	//   _ማምረት_, یصلی, гоҳг, _फेटा, 
   {{0xb53801f2,0x660d2089,0xf5080798,0x00000000}},	// [1b300] ptọ́, _cyck, внал_, --, 
   {{0x2ed00c00,0x94c8004b,0xf7f40150,0x660d208a}},	//   _तत्त, دارې_, _ەسڭد, _dyck, 
   {{0x3dbc03f4,0x660c01f5,0x3244027d,0xd78800ec}},	//   েছিল, _eyck, لناف, _ڌنڌو_, 
   {{0xb6a4030d,0x525811dc,0x00000000,0x00000000}},	//   _тимл, اساڭ_, --, --, 
   {{0x752c031c,0x660c007c,0x69c9208b,0x00000000}},	//   _tibz, _gyck, _üget, --, 
   {{0x25f001f9,0x00000000,0x00000000,0x00000000}},	//   ंपरी_, --, --, --, 
   {{0x15b80022,0xeeb40075,0xe3b40108,0x00000000}},	//   _рыҟы_, иккә_, _кбр_, --, 
   {{0x26c4054e,0xe3dc00cc,0x00000000,0x00000000}},	//   _înot_, _বুকব, --, --, 
   {{0x2ee4022e,0x00000000,0x00000000,0x00000000}},	//   _vmof_, --, --, --, 
   {{0xccb80212,0x8f6801d3,0x4cb800d4,0x00000000}},	//   угої_, _ملئے_, улою_, --, 
   {{0xec140b65,0x72700092,0x7b1403b2,0x1d0400d8}},	//   ренә_, _ጥናታዊ_, ráun, реќи_, 
   {{0x7b20004a,0x00000000,0x00000000,0x00000000}},	//   _sœur, --, --, --, 
   {{0x2c040574,0x6ce400aa,0x9f200131,0xfb8801ec}},	//   _सुरू_, _نژدې_, _بۈيۈ, _ұрық_, 
   {{0x660c01e6,0x00000000,0x00000000,0x00000000}},	//   _ryck, --, --, --, 
   {{0x97a5208c,0x57a5208d,0x672c0066,0x75c800d1}},	//   ортл, ошта, _picj, ңтуң_, 
   {{0x96f87656,0x00000000,0x00000000,0x00000000}},	//   аест_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [1b310] --, --, --, --, 
   {{0xe87005c6,0x660c0064,0x24440124,0xa3a40114}},	//   _بندگ, _vyck, рхаг, ијек, 
   {{0x7d1c00db,0xd1b800f2,0x00000000,0x00000000}},	//   ïssi, یاها_, --, --, 
   {{0x660c0628,0x23640fb7,0x56942d29,0x00000000}},	//   _tyck, šnjo_, _дают, --, 
   {{0xb3400014,0x956402e8,0xd5b801ec,0x00000000}},	//   _ہێلى, _мърд, _кср_, --, 
   {{0xeca407f7,0xef1401e0,0x00000000,0x00000000}},	//   _कोलफ, ҙмы_, --, --, 
   {{0xc0c404a9,0x2c0401ad,0x00000000,0x00000000}},	//   _қәди, _सुलू_, --, --, 
   {{0x53340f06,0x00000000,0x00000000,0x00000000}},	//   _фетт, --, --, --, 
   {{0xba000729,0xdcf9208e,0xbcfc0124,0xbbb000cd}},	//   _এণ্ড_, stuč, irũv, ुङ्क, 
   {{0xe0d024e0,0x25fc032c,0xe9dc004e,0xab600213}},	//   _بزر_, _रखनी_, dzú_, _şüar, 
   {{0xe2142765,0xb1b00137,0x3fe400fe,0x00000000}},	//   _तरुण_, _وڭۇش, _পুৰষ, --, 
   {{0x960000cc,0x00000000,0x00000000,0x00000000}},	//   ্ধতম_, --, --, --, 
   {{0xbd4400db,0x39440003,0x00000000,0x00000000}},	//   _اپتى, _ħoss_, --, --, 
   {{0x6efc003a,0x00000000,0x00000000,0x00000000}},	//   rībe, --, --, --, 
   {{0xe9dc26b6,0x36681f91,0xdb04013a,0x1b04009d}},	//   azú_, лаво_, _hrní, _мүон, 
   {{0x66e00f37,0x15b80220,0xe2140490,0x26d8047e}},	//   поса, қығы_, _तरूण_, ghqo_, 
   {{0xb465208f,0x3dcc009f,0xf7700214,0x75d400a2}},	// [1b320] йкал, nyew_, _کاخ_, _gцzl, 
   {{0xe9d4004e,0x656800e5,0x00000000,0x00000000}},	//   _ыкы_, ágha, --, --, 
   {{0x25a8009a,0x3dcc016b,0xb3841d0f,0x00000000}},	//   _ercl_, hyew_, слел, --, 
   {{0x71645734,0x3dcc016b,0x26d8047e,0x6b7800df}},	//   ماتك, kyew_, chqo_, טרענ, 
   {{0xb23800db,0x00000000,0x00000000,0x00000000}},	//   _ەكرا_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x51940113,0x00000000,0x00000000,0x00000000}},	//   鯵oj鯵, --, --, --, 
   {{0xa110b184,0x33240076,0x00000000,0x00000000}},	//   _کولت, mmox_, --, --, 
   {{0x27fc0356,0x00000000,0x00000000,0x00000000}},	//   şuni_, --, --, --, 
   {{0x8af86a8e,0xdfcc00c6,0x8afc033f,0x2e68008e}},	//   инос_, _كيك_, kręt, _биеп_, 
   {{0xed590adf,0xee383334,0x5a440006,0x00000000}},	//   _бод_, _снд_, зэра, --, 
   {{0x8df40133,0xde0001af,0x00000000,0x00000000}},	//   _بزاڤ, _епци, --, --, 
   {{0xde004eca,0x00000000,0x00000000,0x00000000}},	//   _эпчи, --, --, --, 
   {{0x48240075,0xccf8012c,0x070814a0,0x314c0023}},	//   زىرق, mně_, ليسي_, ሕብባር, 
   {{0xccf8038e,0xe3dc015b,0x7c2c010f,0x00000000}},	//   lně_, _বুঝব, _ŝarg, --, 
   {{0x06cc0183,0xfa540e56,0x00000000,0x00000000}},	// [1b330] ৰচলি, _برىگ, --, --, 
   {{0xccf8012c,0x157800d1,0x26d8022e,0xa35400ae}},	//   nně_, _ﻧﻪﺗﯩ, shqo_, مخصص, 
   {{0xa04408c9,0x69cc045a,0x7c2c0205,0x95c800fb}},	//   ەكتە_, lyce, _şarz, _һура_, 
   {{0xd04803be,0x48f012eb,0x99840ef4,0xdb7800df}},	//   _ildə, ँचको_, _بلیو, רנאכ, 
   {{0xe9240135,0xa1e80b8c,0xccf8012c,0xf6780a7c}},	//   _རྫོབ_, دراك_, kně_, _דארמ, 
   {{0xccf80316,0xdcf800e2,0x00000000,0x00000000}},	//   jně_, ktuā, --, --, 
   {{0xccf8038e,0xff241f42,0x69cc00bc,0xaa7800e4}},	//   dně_, омко, hyce, chýg, 
   {{0x3dcc007f,0x00000000,0x00000000,0x00000000}},	//   tyew_, --, --, --, 
   {{0xccf801ef,0x00000000,0x00000000,0x00000000}},	//   fně_, --, --, --, 
   {{0x7f952090,0x27380521,0xfb880120,0xfce400d4}},	//   _мазх, ụnye_, абок_, іоно, 
   {{0x3dcc007f,0x00000000,0x00000000,0x00000000}},	//   syew_, --, --, --, 
   {{0xeb941c22,0x7c2c008f,0x3b0806a7,0x00000000}},	//   цию_, _ĝard, ремо_, --, 
   {{0xccf80316,0x89d401ec,0x00000000,0x00000000}},	//   bně_, пірш, --, --, 
   {{0x6efc005f,0xccf8012c,0x8f28002b,0xaa7800e4}},	//   mība, cně_, _vṛśc, yhýg, 
   {{0x6efc00da,0xbae4282b,0xfd500055,0xb8d001ad}},	//   lība, _وكتي, _aneḍ, _टफ_, 
   {{0x69cd2091,0x0b58010b,0x7b140419,0x00000000}},	//   byce, _уршы_, záuj, --, 
   {{0x6efc00da,0x74e805f5,0xd04803e3,0x69cc0112}},	// [1b340] nība, адаг_, _eldə, cyce, 
   {{0x7c2c0432,0x8afc00c0,0x00000000,0x00000000}},	//   _şary, bręs, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xccf80316,0x148800ec,0x00000000,0x00000000}},	//   zně_, _گھري_, --, --, 
   {{0xccf80316,0x6efc00e2,0x5edc0183,0x30a0329e}},	//   yně_, jība, বচাই, мғағ, 
   {{0x6efc00da,0x2ed00882,0x8f352092,0x25fc033f}},	//   dība, तस्त, пекц, _रखती_, 
   {{0xccf8038e,0xdb040109,0xc05802d5,0x5f412093}},	//   vně_, _ornà, сіі_, ونول, 
   {{0x1f3802d3,0xed892094,0x0ddc0023,0x2b9800ef}},	//   _ኣቐዲም, асок_, _ሕልፍ_, _rūc_, 
   {{0xccf8038e,0xe2802cdb,0x798402d0,0x2b9800ef}},	//   tně_, _юлти, jtkw, _sūc_, 
   {{0xb14402f2,0x91e4014b,0x6ed40037,0x00000000}},	//   _هیچم_, _доғе, _बतकु, --, 
   {{0xccf80316,0xbed801c6,0xdeec1367,0x69cc0210}},	//   rně_, рдөх_, _жы_, wyce, 
   {{0x69cd2095,0xccf80316,0x21e00dc9,0xdcf800e2}},	//   tyce, sně_, ṱhe_, rtuā, 
   {{0x6efc0029,0xccf80316,0x00000000,0x00000000}},	//   cība, pně_, --, --, 
   {{0x76440af9,0xdcf800e2,0x5a34855f,0x15e40150}},	//   _afky, ptuā, ьнят, _ﺍﺒﺘﺩ, 
   {{0x69cc12eb,0x00000000,0x00000000,0x00000000}},	//   syce, --, --, --, 
   {{0xae1c4196,0x4a5400db,0x656800e5,0x00000000}},	//   _परान_, _экис, ágho, --, 
   {{0x5f080303,0x00000000,0x00000000,0x00000000}},	// [1b350] ावत्_, --, --, --, 
   {{0x286848e5,0xd04806be,0x8afc0153,0x00000000}},	//   _трио_, _tldə, pręs, --, 
   {{0x6efc00da,0x25e8000d,0xc95801d5,0xa5b800e5}},	//   zība, _घेरी_, _тўқ_, _szód, 
   {{0xf7700a1e,0xdb0400d7,0x00000000,0x00000000}},	//   _אקט_, _krná, --, --, 
   {{0x27fc82aa,0x76b8011a,0x00000000,0x00000000}},	//   ğunu_, _המרפ, --, --, 
   {{0x850476a7,0xd1b92096,0x27fc06b9,0x6efc00e2}},	//   _روزن, تاما_, şunu_, vība, 
   {{0xe9dc00db,0x2bac01ad,0x00000000,0x00000000}},	//   obús_, टिफा, --, --, 
   {{0x6efc00da,0x201800ac,0xe9dc0077,0x57fc010f}},	//   tība, əqil_, nbús_, ילוו, 
   {{0xcee897b5,0x00000000,0x00000000,0x00000000}},	//   ترون_, --, --, --, 
   {{0x6efc00da,0x6288017a,0xed4c00ec,0x3b380092}},	//   rība, lfgo, اھن_, _ከተገኘ, 
   {{0x6efc0029,0xfaa52097,0xeae40183,0x00000000}},	//   sība, пано, _নৱেম, --, 
   {{0x6efc005f,0x7f9400c7,0x00000000,0x00000000}},	//   lībn, _маҷх, --, --, 
   {{0xec6c1318,0x649000de,0x6e38011a,0x00000000}},	//   _пп_, _kļič, _התנד, --, 
   {{0x79840373,0xccf401ec,0xada0010a,0x7ea401ec}},	//   rtkw, _оқы_, _чашл, _ﻋﻤﻠﺕ_, 
   {{0xc5e800cc,0xb6f81870,0x00000000,0x00000000}},	//   _কুলা_, مىسا_, --, --, 
   {{0xfb8400c7,0x75440153,0x00000000,0x00000000}},	//   _дыҩн, зназ, --, --, 
   {{0x660000a8,0xdcf8054e,0x66e12098,0x8e200354}},	// [1b360] епта, ctuă, хота, _зiе_, 
   {{0x9a880014,0xaa780030,0xd8840214,0xe61c0208}},	//   _اچھٕ_, chýb, _کهگی, _dzô_, 
   {{0x73352099,0x2bac4ff1,0x28980115,0x00000000}},	//   سرائ, टिया, _פיטא, --, 
   {{0x6444037e,0xe2480023,0xb2243c1a,0x00000000}},	//   _efji, _ዝበልና, пмел, --, 
   {{0x3f8401a9,0x67e0022e,0xc32c6911,0x503800d4}},	//   _aqlu_, _rеji, شەك_, оплю_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa3e40395,0x00000000,0x00000000,0x00000000}},	//   _едра_, --, --, --, 
   {{0xaa780306,0x00000000,0x00000000,0x00000000}},	//   zhýb, --, --, --, 
   {{0x23240c54,0x00000000,0x00000000,0x00000000}},	//   _хоти_, --, --, --, 
   {{0x64440175,0x437000cf,0x5e540014,0xe0d400f3}},	//   _xfji, _سۇۇر, _ہلمس_, _еву_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdee02f34,0x2bac013a,0x00000000,0x00000000}},	//   _похи, टिबा, --, --, 
   {{0xf1bc4802,0x2d947420,0x00000000,0x00000000}},	//   ्हिन, _хрес, --, --, 
   {{0x236405ce,0x1cb80003,0x0bf40395,0x00000000}},	//   šnji_, _ངོར_, _оплю, --, 
   {{0x9ac40337,0xfd240244,0x00000000,0x00000000}},	//   _ŋŋen, _تووێ, --, --, 
   {{0x31642005,0xf1bc2ce6,0xdb041155,0x97c400cf}},	//   ksoz_, ्हान, _trná, رققو, 
   {{0x31640369,0xa5b801ed,0x00000000,0x00000000}},	// [1b370] jsoz_, _szób, --, --, 
   {{0x659001e0,0xa424013d,0x00000000,0x00000000}},	//   мағу, пьел, --, --, 
   {{0xaa7802fb,0x7afc1d55,0x3cd40150,0x00000000}},	//   chýc, čstv, _ﺘﻠﺯﻤ, --, 
   {{0xdb040e38,0x646008a4,0x00000000,0x00000000}},	//   _ernæ, _štić, --, --, 
   {{0x26c80393,0x6288282c,0x5f082144,0x00000000}},	//   _ioco_, rfgo, ावस्_, --, 
   {{0x26c80051,0x00000000,0x00000000,0x00000000}},	//   _hoco_, --, --, --, 
   {{0x26c9209a,0xdb2401ed,0x50640014,0x53a4014b}},	//   _koco_, őség, راوِ, _паёб, 
   {{0x26c813fd,0x2910004e,0x95800b82,0x02600133}},	//   _joco_, _lkxa_, _ዕርቅን_, _شێتێ, 
   {{0x26c9209b,0xfce4cda6,0xc105209c,0x6b74001f}},	//   _moco_, допо, _قوري, _በተሻለ_, 
   {{0x916494d2,0x26c9209d,0x225c039a,0x50f400c7}},	//   _أهله, _loco_, _heuk_, _ззут, 
   {{0x213c0098,0xdfd8030d,0x00000000,0x00000000}},	//   _huuh_, _уъа_, --, --, 
   {{0xc868025f,0x26c80286,0x225ca6d3,0x9e6401d3}},	//   _כן_, _noco_, _jeuk_, _راؤن, 
   {{0x213d209e,0x225c01a4,0x00000000,0x00000000}},	//   _juuh_, _meuk_, --, --, 
   {{0x225d209f,0xbbe800ae,0x00000000,0x00000000}},	//   _leuk_, _ورغم_, --, --, 
   {{0x26c80004,0xbb48aaab,0xac0402dd,0xaa780118}},	//   _boco_, _بلبن_, _онша_, uhýc, 
   {{0x225d20a0,0x3cf402ab,0xdb08000d,0x00000000}},	//   _neuk_, एचके_, öläh, --, 
   {{0x26c8037e,0x213c009f,0x00000000,0x00000000}},	// [1b380] _doco_, _nuuh_, --, --, 
   {{0x1cb81e81,0xe8f40724,0xa5b801d3,0x3164022e}},	//   _ངོས_, _олы_, _szóc, vsoz_, 
   {{0x26c920a1,0x4900c947,0x13381973,0xe9dc0407}},	//   _foco_, _сүрг, ستاں_, ncún_, 
   {{0x225c1dd4,0x26c80063,0x31640bc2,0xab604a98}},	//   _ceuk_, _goco_, tsoz_, _şükr, 
   {{0x61400ec6,0x225d20a2,0x2164abad,0x765520a3}},	//   веча, _deuk_, дичи_, mbyy, 
   {{0x213d20a4,0x00000000,0x00000000,0x00000000}},	//   _duuh_, --, --, --, 
   {{0xceb8767b,0x213c003e,0x61f406be,0x00000000}},	//   зәл_, _euuh_, _əblə, --, 
   {{0x21e006d6,0x225c01c6,0x799402d0,0x00000000}},	//   ṱha_, _geuk_, _opyw, --, 
   {{0x644000e2,0xf1a85d95,0x6e900022,0x8e200150}},	//   žnie, _بازه_, еиқу, _дiн_, 
   {{0x225c01c0,0x7c2c01e4,0x00000000,0x00000000}},	//   _zeuk_, _ŝara, --, --, 
   {{0x5ea11d33,0x225c00e8,0xdb04007c,0x31440023}},	//   رمیل, _yeuk_, _ornä, _ንሰበይ, 
   {{0x25fc000d,0x00000000,0x00000000,0x00000000}},	//   _रखली_, --, --, --, 
   {{0x6f0000e4,0x6cc4185c,0xace80451,0xd1380064}},	//   _ijoc, _ойда, _ورتل_, _kią_, 
   {{0x6e2120a5,0xa8000365,0x26c920a6,0x6f00026c}},	//   _izob, _çıkm, _soco_, _hjoc, 
   {{0x26c920a7,0x5ba002de,0x799402d0,0xada408ce}},	//   _poco_, _арыз, _epyw, brúð, 
   {{0x569496db,0xd1380064,0x00000000,0x00000000}},	//   каст, _lią_, --, --, 
   {{0x225c05e4,0x2b4c010a,0x26c920a8,0xe7b000db}},	// [1b390] _reuk_, _htfc_, _voco_, رۅڭد, 
   {{0x6f000a85,0x29100054,0xdb040730,0x6e20014b}},	//   _ljoc, _ukxa_, _ernä, _mzob, 
   {{0x26c81ada,0xc27416a4,0x427401ec,0x00000000}},	//   _toco_, елеј, егес, --, 
   {{0x6e200107,0x26c8003a,0x213c0036,0xb9dc001f}},	//   _ozob, _uoco_, _puuh_, _ብቁ_, 
   {{0x6e2120a9,0xd14920aa,0x28c007f7,0x21644a1a}},	//   _nzob, وشون_, शापि, фтег, 
   {{0xd498010b,0xe50401f7,0x00000000,0x00000000}},	//   _орс_, _آبحي, --, --, 
   {{0x6e2120ab,0x225c0c3a,0x6d440115,0x20b400c7}},	//   _azob, _teuk_, ŭkal, зықь_, 
   {{0x7b147d3d,0x213c06d1,0x225c01c4,0x6aa80332}},	//   náut, _tuuh_, _ueuk_, _ógfh, 
   {{0x6f000135,0x6e2000d7,0x00000000,0x00000000}},	//   _djoc, _czob, --, --, 
   {{0x23641326,0x6e200099,0x6f000356,0xd25001e2}},	//   šnju_, _dzob, _ejoc, _منې_, 
   {{0x6e2120ac,0x6f000b21,0x2b4c00db,0x1fa4036b}},	//   _ezob, _fjoc, _ctfc_, _юраг, 
   {{0x6f000200,0x00000000,0x00000000,0x00000000}},	//   _gjoc, --, --, --, 
   {{0x7f4001a9,0xe9dc004e,0x00000000,0x00000000}},	//   _hulq, scún_, --, --, 
   {{0x6f0001a6,0x0c941de6,0x26cc007c,0x00000000}},	//   _zjoc, _ашъя, ögon_, --, 
   {{0x6f00020c,0x7f4001a9,0xc5cc015b,0xdc700124}},	//   _yjoc, _julq, _রেলপ, _зықь, 
   {{0xab240801,0x7f40f681,0x00000000,0x00000000}},	//   _поща_, _mulq, --, --, 
   {{0xdb14035b,0x00000000,0x00000000,0x00000000}},	// [1b3a0] _ñañe, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x941806be,0x6cd00150,0xdc740092,0x00000000}},	//   _yarə_, _ﺘﺠﺴﺴ, _በአስር_, --, 
   {{0xbee80d0a,0xa5b800e4,0xa2e06f34,0xdb040139}},	//   टफोन_, _izón, лохд, _urnä, 
   {{0x6f00334b,0xd138033f,0x00000000,0x00000000}},	//   _rjoc, _pią_, --, --, 
   {{0x6f000225,0x644001f1,0x7f40622b,0x00000000}},	//   _sjoc, ľnic, _bulq, --, 
   {{0x644120ad,0x6e2000dd,0xe1300220,0x2f18002e}},	//   žnic, _szob, ыншы, lëgi_, 
   {{0x7f4120ae,0xc29000f2,0x00000000,0x00000000}},	//   _dulq, _نیمب, --, --, 
   {{0xb11807d6,0xa2e001d5,0x00000000,0x00000000}},	//   _فقرا_, _сотд, --, --, 
   {{0xdfcc22ad,0xa5b80306,0x4c940063,0x6140f69e}},	//   _گيم_, _ozón, њинс, _сефа, 
   {{0x6f00049f,0xee3809a5,0x9ac404ba,0x7f40022e}},	//   _tjoc, _ене_, _ŋŋan, _gulq, 
   {{0xacd00166,0x00000000,0x00000000,0x00000000}},	//   _әбкә, --, --, --, 
   {{0x6e2120af,0x7f4120b0,0x00000000,0x00000000}},	//   _uzob, _zulq, --, --, 
   {{0x6d400421,0x7aec00e8,0x7f40022e,0xaa7800d7}},	//   _iuoa, _ňatt, _yulq, chýn, 
   {{0x9ca436e9,0x7f4001d5,0x7afc0427,0x0cdc44eb}},	//   _سهيل_, _xulq, čstr, यसीम, 
   {{0x6d4120b1,0x3ae0035b,0x00000000,0x00000000}},	//   _kuoa, _pópe_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [1b3b0] --, --, --, --, 
   {{0x99640801,0x6d40009f,0x00000000,0x00000000}},	//   _стъл, _muoa, --, --, 
   {{0xdcf80552,0xd1e402d3,0x55040137,0x6454058a}},	//   stuć, _ሞይቱ_, учта, rbxi, 
   {{0x93a40166,0x00000000,0x00000000,0x00000000}},	//   ышуд, --, --, --, 
   {{0x7f400ba1,0x5eec0034,0xf3b002dd,0x52740ee8}},	//   _sulq, इफस्_, _ءﻣﻮﺭ, طانز, 
   {{0x7f4120b2,0x00000000,0x00000000,0x00000000}},	//   _pulq, --, --, --, 
   {{0x7f400a4d,0xbea44d16,0x657c4b2a,0x00000000}},	//   _qulq, вайк, luqh, --, 
   {{0x7c2c01e4,0x7f40d36a,0x00000000,0x00000000}},	//   _ŝaro, _vulq, --, --, 
   {{0x816004d3,0xddc8010e,0x7f400139,0xaec001ec}},	//   _ئۆتۆ, _degş, _wulq, рбыл, 
   {{0x8d2920b3,0x6d402b1d,0xdb04003e,0x7f40022e}},	//   нның_, _duoa, _isné, _tulq, 
   {{0x3b086ca7,0x24e000cc,0x00000000,0x00000000}},	//   дено_, _মদাহ, --, --, 
   {{0x657cd059,0x9ce80156,0x6d4000fb,0xf4100302}},	//   kuqh, རལཤས, _fuoa, שפט_, 
   {{0x4e780597,0x3eac002f,0xa5b800e5,0x00000000}},	//   _أحمد_, mdet_, _szón, --, 
   {{0x3eac0ac7,0xba4401c6,0x2bac0073,0x00000000}},	//   ldet_, эхүй, टिशा, --, 
   {{0xb90810f7,0xa6d8022c,0xf744fd1e,0xb8c802c3}},	//   _मत_, _miðf, тебо, _गघ_, 
   {{0x657c014b,0xa6d80162,0x06d40154,0x00000000}},	//   fuqh, _liðf, সোসি, --, 
   {{0x657c0cfe,0x3ead20b4,0x4ad801ed,0x00000000}},	// [1b3c0] guqh, idet_, _ساٹھ_, --, 
   {{0xe8f520b5,0x3eac02f6,0x00000000,0x00000000}},	//   _аль_, hdet_, --, --, 
   {{0x64a120b6,0xb3842cc8,0xddc801ed,0x6efc00b8}},	//   раха, тлел, _megő, bībh, 
   {{0x3eac019b,0xdb04004e,0x657c676c,0x2bc06b9b}},	//   jdet_, _arnú, buqh, षमता, 
   {{0x3ead20b7,0x644002d5,0xa6d802d2,0xc304007b}},	//   ddet_, žnia, _biðf, دبلو, 
   {{0x6d4002f6,0x3eac4fc3,0xe12078af,0x00000000}},	//   _ruoa, edet_, амчи, --, 
   {{0x7414619c,0x67382b57,0x3d18020c,0x6d4001f4}},	//   _شورا, ňuje, nèwu_, _suoa, 
   {{0x3ead20b8,0x717427dc,0xc5e800cc,0x00000000}},	//   gdet_, _لهرا, _কুটা_, --, 
   {{0x6d401730,0x21a029db,0x6ce402d5,0xfe780118}},	//   _quoa, _китм, віне, chům_, 
   {{0x3ead20b9,0x6d400108,0xa154011a,0x2bac41ac}},	//   adet_, _vuoa, _סבבה_, टिला, 
   {{0x5cc120ba,0x3950004e,0xceb80352,0x3eac025c}},	//   рсыз, _atys_, _зәп_, bdet_, 
   {{0xbe8520bb,0x75d800e2,0xaa7813d5,0x8c3c0790}},	//   _مجهو, _kāzā, chýl, değe, 
   {{0x7e7d20bc,0x4c9520bd,0xc8300092,0x00000000}},	//   óspe, _билс, _በትራን, --, 
   {{0xab600213,0x1cb80327,0x6efc00ef,0x00000000}},	//   _şüur, _ངོག_, dībi, --, 
   {{0x683c001f,0x657c2d2f,0xd7f40105,0x00000000}},	//   _በኤርት, wuqh, азры, --, 
   {{0x657d20be,0xa6d81d1d,0xc8780205,0x6efc00ef}},	//   tuqh, _miðg, şş_, fībi, 
   {{0x66ec07f7,0x6d4406ea,0x00000000,0x00000000}},	// [1b3d0] घोषक_, íkah, --, --, 
   {{0xb2d80150,0x051800f1,0x9474007b,0x3eac00e5}},	//   _ﺃﺠﻭﺍ, رياب_, لدما, zdet_, 
   {{0x29000989,0x3eacb065,0xc984b780,0x3ae001a8}},	//   mnja_, ydet_, _руқи, _hópa_, 
   {{0xa6d80252,0x3ae10b7c,0xe2a8592e,0xddd80356}},	//   _siðf, _kópa_, بائن_, nguţ, 
   {{0x3eac003b,0x290001f7,0x7dd80241,0xb0ec00cc}},	//   vdet_, onja_, _mùsú, _ওৱেব_, 
   {{0x008520bf,0x656c00ef,0x29000327,0x3eac0327}},	//   улко, _ivch, nnja_, wdet_, 
   {{0xa6d808a7,0x938920c0,0x2900045f,0x656c0175}},	//   _viðf, _иста_, inja_, _hvch, 
   {{0x29007dfd,0x3ead20c1,0x9f440419,0x00000000}},	//   hnja_, udet_, nzné_, --, 
   {{0x3eac17c0,0x0d640588,0x9ac40083,0xc1b8009d}},	//   rdet_, аныҟ, _ŋŋon, _ялах_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa5b800dd,0xbb4401ec,0x00000000,0x00000000}},	//   _szól, _ﺘﻘﻲ_, --, --, 
   {{0xa5b8066d,0x656cf5a0,0x2900025c,0x3eac025c}},	//   _gyóg, _ovch, enja_, qdet_, 
   {{0xaa7920c2,0xa6d8041e,0xddd8025c,0x61e8002f}},	//   chým, _miðd, nfuż, nzgl, 
   {{0x7e6804c9,0x68e4026c,0x290001a6,0x3ae002d2}},	//   laep, ghjd, gnja_, _dópa_, 
   {{0x656d20c3,0x5fb001ad,0x00000000,0x00000000}},	//   _avch, ंटिल, --, --, 
   {{0x39500165,0x273801f2,0x75d4a6e0,0x35a40aac}},	//   _ttys_, ụnne_, هيزا, лабг, 
   {{0x2900bc47,0xc98406ed,0x00000000,0x00000000}},	// [1b3e0] bnja_, _куќи, --, --, 
   {{0xe614213d,0xdb0405ac,0x29000e3c,0x5fb003e5}},	//   уду_, _arnø, cnja_, ंटाल, 
   {{0x7e6920c4,0x656d20c5,0x366920c6,0xa6d802d2}},	//   kaep, _evch, _пано_, _biðd, 
   {{0x6efc005f,0xf204d3a6,0x64a09246,0xddd8031c}},	//   lībv, ляло, _қаса, ffuż, 
   {{0xdee002d3,0x9f480118,0xa6d8032e,0xaa780162}},	//   ዝዀነ_, ělým_, _siðg, skýg, 
   {{0x38680109,0x00000000,0x00000000,0x00000000}},	//   nabr_, --, --, --, 
   {{0xd01120c7,0x656c0099,0xa5040064,0xabe00150}},	//   غلب_, _zvch, _сера_, _ﺇﻁﺎﻋ, 
   {{0xa6d82bde,0x290008ad,0xda0405d7,0xede40032}},	//   _viðg, znja_, रपात_, лһеҙ_, 
   {{0x38680f36,0x29000252,0xaa780118,0x00000000}},	//   kabr_, ynja_, uhým, --, 
   {{0x7af4002d,0xe1f40022,0x3ae120c8,0x386800e8}},	//   _amyt, _сгу_, _rópa_, jabr_, 
   {{0x4bc520c9,0x2900b745,0x28c01d97,0x19580046}},	//   рөлг, vnja_, शासि, ғасы_, 
   {{0xf424015b,0x7e68d02e,0xdde000fb,0x2e1c01e1}},	//   _বলার_, caep, рҙәү, _ọfun_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa6d81d0e,0x073c9c97,0x00000000,0x00000000}},	//   _miðe, _ﺟﯩﯔ_, --, --, 
   {{0x656c0334,0x765001f2,0xf730001f,0xa918032e}},	//   _svch, _ọkọw, _በእያን, ftþr, 
   {{0x29002625,0x86542901,0x00000000,0x00000000}},	//   snja_, рках, --, --, 
   {{0x290120ca,0xa3e40034,0x44f45b66,0x9f4400d0}},	// [1b3f0] pnja_, मैन_, апас, rzné_, 
   {{0x95c80032,0x6efc00ef,0x00000000,0x00000000}},	//   ыуса_, cībv, --, --, 
   {{0xd49920cb,0x42540137,0x7e6801f7,0xe7b001d3}},	//   ырт_, لنار, yaep, _الجھ, 
   {{0xbd0401e1,0x2cac002e,0x7c2c00df,0x57a400c7}},	//   _amẹ́, _lafd_, _ŝark, _ушьа, 
   {{0xd6d8084c,0x656c01d5,0xa6d802d2,0x00000000}},	//   _стэ_, _uvch, _viðd, --, 
   {{0x210c1b6e,0xddd8110c,0x7e6801f7,0x61e802d0}},	//   िवेश_, jguš, waep, rzgl, 
   {{0x2e4c0cad,0x7e6920cc,0x3b780092,0xddd80327}},	//   _jọwọ_, taep, _በሰዎች_, sfuż, 
   {{0xfe4403b7,0x7bc40129,0xddd800e2,0x00000000}},	//   шнио, _àhui, eguš, --, 
   {{0x3868c645,0x60842ab5,0x7e6920cd,0x2cac0129}},	//   yabr_, _مشاك, raep, _bafd_, 
   {{0x7e6920ce,0x0d080046,0xee3520cf,0xa2c00073}},	//   saep, лдық_, шны_, ळाव्, 
   {{0xa6d809f3,0x7e6920d0,0x2f180036,0xdfb000f1}},	//   _miðb, paep, tëgt_, _دټاک, 
   {{0x2a6801ab,0x3d9520d1,0xa6d8032e,0x12800092}},	//   gacb_, _видр, _liðb, _የዝናብ_, 
   {{0x3868036b,0x18b4013d,0x00000000,0x00000000}},	//   tabr_, бәнр, --, --, 
   {{0x2e4c0241,0xdcf80115,0x00000000,0x00000000}},	//   _bọwọ_, kruĉ, --, --, 
   {{0xbebc2602,0x366802bf,0x2a6801ab,0x644000d0}},	//   plūd, каво_, bacb_, ľnil, 
   {{0x7af4cbae,0x644002fb,0xe6400150,0x00000000}},	//   _umyt, žnil, жетп, --, 
  
   {{0xb46520d2,0xe73520d3,0x94200213,0xeb3000db}},	// [1b400] икал, рет_, əsən_, _بىيد, 
   {{0x25bc5d39,0x2e4c0241,0xe45403b0,0xd91120d4}},	//   _šulc_, _fọwọ_, ижу_, _ریز_, 
   {{0x25a80395,0x287804ae,0xa878011a,0xf770030f}},	//   _escl_, _בנימ, _באיר, _باخ_, 
   {{0xeb9404ac,0x2114004b,0x25a80175,0x969400f1}},	//   ידער_, یتوب_, _fscl_, _دیرش, 
   {{0xaa7800bc,0x00000000,0x00000000,0x00000000}},	//   lkýc, --, --, --, 
   {{0xa6d801a8,0xc1340451,0x00000000,0x00000000}},	//   _viðe, مونڊ, --, --, 
   {{0x506404a9,0x733457d4,0xaa780306,0x9f640022}},	//   атқа, _نىسا, nkýc, арыз_, 
   {{0xc32c0aaf,0x2f3c413b,0xdb0408a5,0x00000000}},	//   _كەل_, _ọgba_, _arnþ, --, 
   {{0xaa7802fb,0x88ac00cc,0x00000000,0x00000000}},	//   hkýc, খাতক, --, --, 
   {{0xa5b801d3,0xaa780306,0xc0a800cf,0x35a40023}},	//   _szók, kkýc, _مامل_, _ዋጋታት_, 
   {{0xa11120d5,0x2a6801ab,0xb814000d,0x00000000}},	//   _بولت, tacb_, _दुलम_, --, 
   {{0x2cac0158,0xdce41a14,0xaa780306,0xa3d44709}},	//   _wafd_, ālāk, dkýc, िहत_, 
   {{0x2a6801ab,0x28c0043e,0x00000000,0x00000000}},	//   racb_, शालि, --, --, 
   {{0x25a920d6,0x19587e27,0xdca011af,0x9cb000c6}},	//   _rscl_, рары_, _мачи, _ومنت, 
   {{0xdcf82c78,0x00000000,0x00000000,0x00000000}},	//   ltuğ, --, --, --, 
   {{0xa6d8148b,0x89d800f2,0x56780108,0xe570007b}},	//   _siðb, _موبر_, ибся_, قطط_, 
   {{0x64401a48,0xaae4221d,0x8b3401ed,0x2bac1fe7}},	// [1b410] žnim, _مسکو, _پڑھت, टिका, 
   {{0x7c2c0115,0xe7851df3,0xaec40327,0xf990011a}},	//   _ŝari, _кумо, _ཀོའོ, _צרי_, 
   {{0xaa780745,0xa6d81873,0x2ee520d7,0xa2c00490}},	//   ckýc, _viðb, _olof_, ळाल्, 
   {{0x417400f7,0xb060023a,0x2ee401f5,0xdcf803e0}},	//   ماتس, äänk, _nlof_, ktuğ, 
   {{0x95c8074d,0xe4a40e92,0x00000000,0x00000000}},	//   _кура_, _крво, --, --, 
   {{0x2ee4f812,0x00000000,0x00000000,0x00000000}},	//   _alof_, --, --, --, 
   {{0x2ee40100,0x442520d8,0xf4940014,0x2af400bc}},	//   _blof_, _ál_, _چھۅت_, ँफाँ_, 
   {{0x814400f2,0x00000000,0x00000000,0x00000000}},	//   _هنرن, --, --, --, 
   {{0x62980295,0xc224065f,0xaa7858bb,0xab60000d}},	//   _ibuo, _اکاو, chýi, üünt, 
   {{0x2ee4007c,0x27002efd,0x3b8520d9,0x00000000}},	//   _elof_, रचुर_, блог, --, 
   {{0x7a68006c,0x3a24c2bf,0x00000000,0x00000000}},	//   линг_, _šop_, --, --, 
   {{0x2ee50948,0x0c2401e0,0x4ea400f0,0x00000000}},	//   _glof_, өмөн, _мрча, --, 
   {{0xee2c01c4,0xa3e4dde9,0x00000000,0x00000000}},	//   _хн_, मैत_, --, --, 
   {{0x644004b9,0xaa7801a2,0xa3d43ee1,0xfe780118}},	//   žnij, tkýc, िहा_, ghův_, 
   {{0x629920da,0xe9e802d2,0x6d4401e4,0x6efc00de}},	//   _obuo, _prúð_, ŭkat, cībs, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xaa78031d,0xa3d400c5,0x00000000,0x00000000}},	// [1b420] skýc, िहऽ_, --, --, 
   {{0x798520db,0xfe780118,0xaa7802f0,0x78a80114}},	//   mukw, chův_, pkýc, _ског_, 
   {{0x1cb8025c,0xf77000c6,0x1604033f,0xe9e80174}},	//   _ངོན_, _عاد_, _रखकर_, _trúð_, 
   {{0xe43000f2,0x6efc7aa9,0x00000000,0x00000000}},	//   سفند, kūba, --, --, 
   {{0x79848b75,0x363404fb,0x690402d2,0x00000000}},	//   nukw, _دردس, _árdí, --, 
   {{0x6298016b,0x3d10068f,0x2ee42112,0x2e4c0241}},	//   _ebuo, ठकों_, _slof_, _lọtọ_, 
   {{0x8f34fe1c,0x24e4020a,0x2ee40561,0x798520dc}},	//   оекц, _умри_, _plof_, hukw, 
   {{0xdcf805d1,0xb1440b2c,0xa6d802d2,0x2bc801a9}},	//   ttuğ, _гнал, _kiða, ҳумо_, 
   {{0x79850135,0xad64007b,0xe81c1b97,0x00000000}},	//   jukw, حابه, _मुना_, --, 
   {{0xa6d82242,0x798520dd,0x53dc012a,0xdb040112}},	//   _miða, dukw, _यथाश, _ernü, 
   {{0xec1401d2,0xa6d80321,0x290520de,0xdcf80205}},	//   сенә_, _liða, _ına_, stuğ, 
   {{0x79850226,0x6d440413,0xdcf80205,0x00000000}},	//   fukw, íkas, ptuğ, --, 
   {{0x798493ea,0xa6d80579,0xac989924,0x6efc00e2}},	//   gukw, _niða, _منشا_, sībs, 
   {{0x6e2120df,0x1d040e92,0x644000d7,0x00000000}},	//   _iyob, _лечи_, ľnik, --, 
   {{0x6440341a,0x6e20020b,0x7cec09e8,0x24a403b9}},	//   žnik, _hyob, _búrf, _ötmə_, 
   {{0xaae424d0,0x798520e0,0x6e2120e1,0x7cec0332}},	//   _دستو, bukw, _kyob, _cúrf, 
   {{0xf8ac8d24,0x798520e2,0x00000000,0x00000000}},	// [1b430] رکی_, cukw, --, --, 
   {{0x6e2120e3,0x629805d5,0x00000000,0x00000000}},	//   _myob, _sbuo, --, --, 
   {{0x6e2004ba,0xa6d80413,0xe9dc00e5,0x1b1c00eb}},	//   _lyob, _eiða, lyú_, নগরে_, 
   {{0x6e2001f0,0x00000000,0x00000000,0x00000000}},	//   _oyob, --, --, --, 
   {{0x6e2120e4,0x9f440216,0xe9dd20e5,0x482400d1}},	//   _nyob, rzní_, nyú_, _دىھق, 
   {{0x7bc41bb0,0xaa7800c7,0xdcf8025c,0xe4a401d5}},	//   _áhug, chýv, rruċ, _урмо, 
   {{0x6e2120df,0xe3b0585a,0x7984209c,0x7ff4cddb}},	//   _ayob, _عرس_, zukw, غستا, 
   {{0x6e20513a,0x79840796,0xdb0401e7,0xdb080790}},	//   _byob, yukw, _osná, çlük, 
   {{0x6e200223,0x798401f0,0xfa24031c,0xbd44004b}},	//   _cyob, xukw, _ལཊེན_, غندي, 
   {{0x798520e6,0x7cec004e,0x2e4c0248,0x00000000}},	//   vukw, _múrg, _sọtọ_, --, 
   {{0x6e2049cf,0x7cec00db,0x798520e7,0x6d440d12}},	//   _eyob, _lúrg, wukw, íkar, 
   {{0x628920e8,0x1cb82b88,0xdb040109,0x798520e9}},	//   nggo, _ངོམ_, _arnò, tukw, 
   {{0xec6cfebb,0x6e201418,0x628920ea,0x6d440115}},	//   _оп_, _gyob, iggo, ŭkar, 
   {{0x644402d3,0xf744011b,0xfc700014,0x00000000}},	//   _ngji, жево, _کھکھ, --, 
   {{0xb900069f,0x31a40882,0xa6d80ad9,0x59b8012c}},	//   _दव_, _गन्ध, _siða, इटहर, 
   {{0x2e4c00b4,0x798520eb,0x64440240,0x7cec02d2}},	//   _họrọ_, pukw, _agji, _búrg, 
   {{0x2e4c02e3,0x798400f1,0x00000000,0x00000000}},	// [1b440] _kọrọ_, qukw, --, --, 
   {{0x2e4c01f2,0xa6d82833,0x2ea42017,0x00000000}},	//   _jọrọ_, _viða, _खस्त, --, 
   {{0xdcf800d7,0x289800df,0x00000000,0x00000000}},	//   jruč, _דייא, --, --, 
   {{0xdcf83d67,0xd250b8c6,0x6444044e,0xb22436ca}},	//   druč, رنت_, _egji, омел, 
   {{0xa5b800dd,0x7cec1427,0xa918032e,0x00000000}},	//   _szóv, _kúrd, duþj, --, 
   {{0x6e2120ec,0xfbc920ed,0x2e4c0521,0x6288208d}},	//   _ryob, िमाम, _nọrọ_, aggo, 
   {{0xa6d82880,0x6e2120ee,0x91d803d4,0xede0007a}},	//   _miðn, _syob, _দেশখ, गन्ध_, 
   {{0xf1a920ef,0x6444044e,0xa6d808a7,0x7cec03b2}},	//   _پاره_, _zgji, _liðn, _lúrd, 
   {{0x2e4c02e3,0x600400fb,0xe0680228,0xad08009d}},	//   _sọsọ_, йнәм_, اشۇۇ_, ихож_, 
   {{0x6e2120f0,0x3324003d,0xa06400d8,0x00000000}},	//   _vyob, llox_, _мауа_, --, 
   {{0x2e4c01f2,0x6e200034,0x6ee402dd,0x00000000}},	//   _dọrọ_, _wyob, _وسصل, --, 
   {{0x6e2000b5,0xade4010b,0x00000000,0x00000000}},	//   _tyob, _мцлк, --, --, 
   {{0x6e2120f1,0x2e4c01f2,0x80ac015b,0xdd8c0aaa}},	//   _uyob, _fọrọ_, চার্, _لون_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3324005a,0x7cec03b2,0x64440200,0x070801f7}},	//   klox_, _súrg, _rgji, ميسي_, 
   {{0x497520f2,0xea600014,0xdb0520f3,0xe60400d4}},	//   _елис, _تھدی, _asnæ, оїзн, 
   {{0xa5b8043b,0xf1a40037,0xa9280153,0xdb0401ef}},	// [1b450] _nzót, _गनगन, _віне_, _usná, 
   {{0xe9dcd829,0x5504035b,0x00000000,0x00000000}},	//   scús_, мчха, --, --, 
   {{0xa5b801ed,0x26cc01b8,0x3324007c,0x00000000}},	//   _azót, ögos_, flox_, --, 
   {{0x99482263,0x00000000,0x00000000,0x00000000}},	//   _دلیل_, --, --, --, 
   {{0x628801f5,0x64440200,0x9f4400d7,0x3dcc0135}},	//   rggo, _tgji, dzná_, xxew_, 
   {{0x7cec01f1,0xdcf807f5,0x00000000,0x00000000}},	//   _kúre, truč, --, --, 
   {{0x2e4c063f,0xaa7806ea,0x7050004b,0x3324045a}},	//   _rọrọ_, nhýs, رنيا, blox_, 
   {{0x533483c0,0xa6d802d2,0x2e4c7ef1,0xa28000f2}},	//   _жест, _miðo, _sọrọ_, _آیشو, 
   {{0xddc800da,0x00000000,0x00000000,0x00000000}},	//   _iegū, --, --, --, 
   {{0xa3dca5cd,0x3b841734,0xdc2c00ef,0x00000000}},	//   _तथा_, плог, ežāk, --, 
   {{0x3ae001a8,0x6d4401e4,0xc4bc0154,0xaa780022}},	//   _hópi_, ŭkap, _আকাঙ, yhýt, 
   {{0x387800f3,0xeb94b68c,0x3b0832b0,0xfce86ea9}},	//   _sdpr_, чию_, семо_, _گفتي_, 
   {{0x2e4cba77,0x3f5120f4,0x00000000,0x00000000}},	//   _tọrọ_, _háu_, --, --, 
   {{0xa5b8002e,0x7cec032e,0xaa7808a5,0x00000000}},	//   _ayóo, _búre, fhýs, --, 
   {{0x8b640a52,0xe81c007d,0x8cc8033f,0xfa6920f5}},	//   _قايم, _मुदा_, ़ारो, _лайк_, 
   {{0x3f500016,0x2e4c0241,0x7d000162,0xddc800de}},	//   _máu_, _jọpọ_, lils, _negū, 
   {{0xe5a120f6,0xb060023a,0xa6d803b2,0x7d0003d5}},	// [1b460] нити, ääkk, _tiðn, oils, 
   {{0xe52034da,0x387800ca,0xa520009b,0x993401ed}},	//   едуп, _udpr_, емуд, _آہست, 
   {{0xa5b801ed,0x3f500208,0x7cec08ce,0x39940388}},	//   _szót, _náu_, _kúrb, læs_, 
   {{0x7d0120f7,0x00000000,0x00000000,0x00000000}},	//   hils, --, --, --, 
   {{0xa6d81f60,0x7d00d5e4,0xdb040139,0x7cec02d2}},	//   _miðl, kils, _isnä, _múrb, 
   {{0x3f5001fb,0x3b000113,0x3ae01427,0xa6d81d1d}},	//   _báu_, hikq_, _dópi_, _liðl, 
   {{0x3f50004d,0x24e4010b,0x1fa0013d,0x3cd401ec}},	//   _cáu_, _эмри_, ерыг, _ﺘﺠﺘﻤ, 
   {{0x3f50067c,0x7d000254,0x76546143,0x6720036e}},	//   _dáu_, eils, ncyy, _ënjt, 
   {{0x216520f8,0x71640150,0x3eb80109,0x9f440419}},	//   _нити_, _ءارك, ôsta_, rzná_, 
   {{0x7d0120f9,0x3f50148b,0x8afc012d,0x13e000eb}},	//   gils, _fáu_, zpęd, _যেয়, 
   {{0xdeed20fa,0xceb80058,0xa6d81d12,0x64400219}},	//   _зы_, _дәп_, _biðl, žniv, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7d0120fb,0xa3b0073d,0xeabc04cc,0x4c940104}},	//   bils, _जैन_, blùn_, _жилс, 
   {{0x79940175,0x00000000,0x00000000,0x00000000}},	//   _dqyw, --, --, --, 
   {{0x57a520fc,0xdc980375,0xa6d808a5,0xaa780118}},	//   ншта, _הסוכ, _fiðl, lkým, 
   {{0xd6d920fd,0xa6d80162,0x00000000,0x00000000}},	//   пту_, _viðo, --, --, 
   {{0x44b408eb,0xaa7802f0,0x04c81541,0xe8e850d8}},	// [1b470] мбас, nkým, يوري_, _هردو_, 
   {{0xa5b8297b,0x3ae00162,0xd78801d9,0xfe780118}},	//   _szós, _rópi_, _کنَو_, vkům_, 
   {{0x0edc00e1,0xa3e407f7,0xaa7802f0,0x473520fe}},	//   _बवंड, मैं_, hkým, _онос, 
   {{0xaa7802f0,0x91d80154,0xfe780118,0xf774010f}},	//   kkým, _দেইখ, tkům_, _קערי_, 
   {{0x3f5120ff,0x7d012100,0xb6b8011a,0x404800d8}},	//   _sáu_, yils, _וצרי, опло_, 
   {{0x7cec5c17,0xaa7802f0,0xa6d808ce,0xc2c400ec}},	//   _múrc, dkým, _miðm, _ڪيري, 
   {{0x7d012101,0x7ae40008,0xa6d803b2,0xfe780118}},	//   vils, ykkt, _liðm, skům_, 
   {{0x7d000810,0xc2c4004b,0xa0240b82,0xa3e400dc}},	//   wils, _تيري, _ስንክሳ, मैः_, 
   {{0x7d002d75,0x443063e0,0xbeec0ce0,0xa6d80321}},	//   tils, _hzz_, _जतीन_, _riðl, 
   {{0xec740276,0x3fc80133,0xa6d809e8,0x2e4c0ca8}},	//   мпь_, _ودای_, _siðl, _wọpọ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7d012102,0x44300010,0x7cec01e7,0x1ea83cc6}},	//   sils, _mzz_, _búrc, _دائي_, 
   {{0xaa780232,0xa6d805f7,0x6e90012f,0x4430027e}},	//   ckým, _viðl, _شلوا, _lzz_, 
   {{0xdcf800da,0xbaac02f5,0x6da12103,0x399400b5}},	//   bruā, গাইছ, _риша, ræs_, 
   {{0x44312104,0x7cec032e,0xc5cc00fe,0x97e400cf}},	//   _nzz_, _túrb, _ৰেলপ, رتسۅ, 
   {{0xaa7803b2,0x00000000,0x00000000,0x00000000}},	//   shýr, --, --, --, 
   {{0x29012105,0x44300395,0xa5b800dd,0xa6d802d2}},	// [1b480] bija_, _azz_, _szór, _kiðj, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa6d809f3,0x17dc00cc,0x00000000,0x00000000}},	//   _miðj, _ডেৰি, --, --, 
   {{0x44300223,0xf1a8007b,0x73341291,0xd1300014}},	//   _dzz_, قاته_, ذرائ, گمت_, 
   {{0x92680032,0x44312106,0x7bd400d0,0xbbc800dc}},	//   орҙа_, _ezz_, äzuj, िमुक, 
   {{0x6454003a,0xd1305230,0xa6d8032e,0xd6b000cc}},	//   ccxi, دمت_, _niðj, _চচিয, 
   {{0x6eec08e5,0x44300477,0x00000000,0x00000000}},	//   _rùbb, _gzz_, --, --, 
   {{0x6eec026c,0xaa780030,0x6678010f,0x5fb0012d}},	//   _sùbb, tkým, ֿטיק, ंटजल, 
   {{0x6eec19f5,0xa6d82833,0x29000526,0x8c3c05d1}},	//   _pùbb, _biðj, yija_, meği, 
   {{0x2900038f,0xd054016b,0x8c3c05d1,0x6ca401f4}},	//   xija_, _ɔbɛd, leği, фриж, 
   {{0x3a3000a2,0xa2c00490,0xe51c00dc,0xaa78219b}},	//   _azyp_, ळाच्, भवति_, ským, 
   {{0x6da45cb5,0x29012107,0x8c3c0365,0xa0300150}},	//   _يمام, wija_, neği, _شىنت, 
   {{0xca980150,0xda24003b,0x00000000,0x00000000}},	//   _ﺘﺄﻜﺩ_, вєро, --, --, 
   {{0xa6d81125,0x4c94376d,0xe7682377,0x00000000}},	//   _viðm, _чикс, жјак_, --, 
   {{0x3cf802d3,0x8c3c05d1,0xdca00063,0xc0f8010f}},	//   ësve_, keği, _раји, פּשט, 
   {{0x98a4005f,0x3b100023,0x7cec0332,0xaa7800e4}},	//   ēmā_, _gjyq_, _iúra, chýp, 
   {{0xa5b80241,0x7e7c021c,0x8c3c03e0,0x00000000}},	// [1b490] _iyók, óspi, deği, --, 
   {{0x3ae0026c,0x29000023,0x45180327,0x00000000}},	//   _dópu_, qija_, ྱོེར_, --, 
   {{0x75a40022,0x8c3c03e0,0x00000000,0x00000000}},	//   _ҿырҧ, feği, --, --, 
   {{0x7ceca3be,0x00000000,0x00000000,0x00000000}},	//   _múra, --, --, --, 
   {{0xb658008d,0xa6d80d12,0x7cec03b2,0xa0b400c7}},	//   _מדרש, _liðk, _lúra, мҳау_, 
   {{0x44312108,0xa29c02a0,0xd1640395,0x00000000}},	//   _tzz_, _गॉर्, тъци, --, 
   {{0x8c3d2109,0xb19405a2,0xaa780022,0x00000000}},	//   beği, _үлсә, yhýp, --, 
   {{0x8c3c0ab7,0x555401e2,0x00000000,0x00000000}},	//   ceği, _سپېر, --, --, 
   {{0xc105210a,0xc1140063,0xa3b0098b,0x00000000}},	//   _كوري, _змај, _जैत_, --, 
   {{0x8d286564,0xbc180046,0xa5b801e1,0x7cec0030}},	//   мның_, зімі_, _ayók, _búra, 
   {{0x7cec0597,0xe81c28a2,0xa6d8032e,0xbbc808a3}},	//   _cúra, _मुला_, _viðj, िमेक, 
   {{0x5928003d,0xf410008f,0x7cec007b,0xdce8025c}},	//   _རེངས_, רפט_, _dúra, _oqgħ, 
   {{0x3ead210b,0x00000000,0x00000000,0x00000000}},	//   meet_, --, --, --, 
   {{0x3ead210c,0x26c8003e,0xc8300092,0x998c00e5}},	//   leet_, _anco_, _በስምን, ülői_, 
   {{0x6b98074d,0xfaa40116,0x8c3c0205,0x00000000}},	//   cttg, _зайо, yeği, --, 
   {{0x3eac0664,0x91b007f7,0x00000000,0x00000000}},	//   neet_, _आईलै, --, --, 
   {{0xa6d81d1d,0x00000000,0x00000000,0x00000000}},	// [1b4a0] _miðh, --, --, --, 
   {{0x3ead210d,0x26c80561,0x977429db,0x26c40418}},	//   heet_, _enco_, _итмә, ēnoa_, 
   {{0x3ead210e,0x4901210f,0x8c3c05d1,0x395001f5}},	//   keet_, _түрг, teği, _huys_, 
   {{0x3eac02f6,0x73342002,0x59a4000d,0x00000000}},	//   jeet_, رىشا, _ओहार, --, 
   {{0xf1244de2,0x8c3d2110,0x39500363,0x3ead2111}},	//   нько, reği, _juys_, deet_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3eac2ad4,0x8c3c05d1,0xceb80116,0x21240133}},	//   feet_, peği, дәл_, ربهێ, 
   {{0x3eac04e6,0x7cec21dd,0xaa7801ef,0x00000000}},	//   geet_, _rúra, ckýh, --, 
   {{0x6eec01ab,0x7cec0419,0xfd5400b8,0x00000000}},	//   _cùba, _súra, _khaṅ, --, 
   {{0x6eec01c3,0xc10004a9,0x7cec0174,0xfd540055}},	//   _dùba, _күчл, _púra, _jhaṅ, 
   {{0xe1fc0008,0xdfcc05d9,0x78ac0810,0x3eac2c4a}},	//   _þór_, _ٿين_, debv, beet_, 
   {{0x39512112,0xa6d805a4,0x3eac011f,0x00000000}},	//   _buys_, _viðk, ceet_, --, 
   {{0x78ac5eb5,0x6f000286,0x26c801ab,0x3ae00174}},	//   febv, _imoc, _rnco_, _rópt_, 
   {{0x7cec5c0c,0x2c8401e1,0x00000000,0x00000000}},	//   _túra, _dídà_, --, --, 
   {{0x6d48004b,0x9c6040c7,0x5ba0005b,0x7cec02d2}},	//   _iifa, _صهيو, _брыз, _kúrn, 
   {{0x6d492113,0xfd54002b,0x00000000,0x00000000}},	//   _hifa, _ahaṅ, --, --, 
   {{0x6d492114,0x39512115,0xfd5400cd,0x1c4001af}},	// [1b4b0] _kifa, _guys_, _bhaṅ, _инәм, 
   {{0x6d492116,0x04c830bf,0xfd5400b8,0xa6d8148b}},	//   _jifa, بوطي_, _chaṅ, _miði, 
   {{0x6d492117,0xa6d805a4,0x9d180375,0x6f012118}},	//   _mifa, _liði, לומט, _omoc, 
   {{0x6d48420d,0xbebc005f,0x26c81c1d,0x41742a8b}},	//   _lifa, rlūk, _unco_, ناتس, 
   {{0xd7c8036b,0x6d5c00b0,0x3ead2119,0x216450cb}},	//   _قویه_, _ōpan, veet_, хтег, 
   {{0x6d49211a,0x3eac0660,0x6f000165,0x656c014f}},	//   _nifa, weet_, _amoc, _iwch, 
   {{0x3ead211b,0x6fb00597,0x6eec01c3,0x2d8000bc}},	//   teet_, لموا, _sùba, áken_, 
   {{0x6d4805b8,0xa6d876ad,0x8fc400f1,0xddd80064}},	//   _aifa, _biði, ازون, rguž, 
   {{0x6d49211c,0xa6d82833,0x5185211d,0x26041d72}},	//   _bifa, _viðh, _буха, _सेमी_, 
   {{0x6d48420d,0x93a001a9,0xa2a8000d,0x00000000}},	//   _cifa, _qo僧i, ीएक्, --, 
   {{0x3ead211e,0x6d548616,0xa6d80bcd,0x5ca010de}},	//   peet_, _éyan, _eiði, _ەلتە, 
   {{0x6d48324c,0x656c035a,0x00000000,0x00000000}},	//   _eifa, _owch, --, --, 
   {{0x6d49211f,0x7e692120,0x7e7c03b2,0x00000000}},	//   _fifa, mbep, óspu, --, 
   {{0x6d488aa7,0x6f00d193,0x7e68017a,0xa3c044eb}},	//   _gifa, _zmoc, lbep, ौमा_, 
   {{0xf0900302,0x656d2121,0x78ac0099,0xabd001d9}},	//   ינם_, _awch, rebv, _نٲوت, 
   {{0x6d485936,0xfaa40022,0x3950010e,0xfca800ec}},	//   _zifa, _раио, _tuys_, _راڻو_, 
   {{0x6d492122,0x7bc001a4,0xf21001f2,0x6a98011a}},	// [1b4c0] _yifa, lvlu, họrọ, _חשפנ, 
   {{0xe5a12123,0x6d4807a9,0x7cec0419,0x00000000}},	//   рифи, _xifa, _múro, --, 
   {{0xfd541aa1,0x27b000d1,0x260400e1,0x7bc0257c}},	//   _vhaṅ, _кәтс, _सेठी_, nvlu, 
   {{0x6d440122,0x42d40212,0x00000000,0x00000000}},	//   íkaz, лічу, --, --, 
   {{0xe734005b,0x00000000,0x00000000,0x00000000}},	//   _шею_, --, --, --, 
   {{0x7e680549,0xa3b05325,0x7cece9f0,0x67380216}},	//   ebep, _जैव_, _súrn, ňujt, 
   {{0x7e680af9,0xa6d80d12,0x00000000,0x00000000}},	//   fbep, _siði, --, --, 
   {{0xede40032,0x7bc00ea0,0x7cec0419,0x00000000}},	//   кһеҙ_, dvlu, _búro, --, 
   {{0x6d480170,0x81a4182c,0xd29400c7,0x7bc004cc}},	//   _pifa, _محلل, _арҕь, evlu, 
   {{0xf210063f,0x31640165,0xa6d80413,0x0cd00154}},	//   bọrọ, mpoz_, _viði, িস্ত, 
   {{0x6d4805d9,0xec1430cb,0x7e680158,0x7bc03a34}},	//   _vifa, тенә_, bbep, gvlu, 
   {{0x6d492124,0xeda40588,0xa6d80174,0x6f000609}},	//   _wifa, _ашко, _tiði, _umoc, 
   {{0x6d492125,0x31645138,0x3ea8002e,0xabc801ec}},	//   _tifa, npoz_, _ñata_, _ﯗﻳﻌﺎ, 
   {{0x6d48009f,0x00000000,0x00000000,0x00000000}},	//   _uifa, --, --, --, 
   {{0xa6d826b8,0x7cec0306,0xe9dc00d0,0x00000000}},	//   _miðv, _zúro, ncúz_, --, 
   {{0xa6d808a5,0xa91808a5,0x00000000,0x00000000}},	//   _liðv, guþr, --, --, 
   {{0x73c0052f,0x06c400bd,0x286801c0,0x49a402dd}},	// [1b4d0] ҙәре, _একদি, _орно_, _сыйғ, 
   {{0x290402b1,0x7b140003,0x00000000,0x00000000}},	//   _öna_, nġun, --, --, 
   {{0xa5b800d2,0xd4980801,0xa3b000af,0xf8b0010f}},	//   _nyóv, ърт_, _जैश_, _פשט_, 
   {{0xeabc026c,0xba8c02dd,0x4274009d,0x9f4400e5}},	//   ndù_, _ﺒﺫﻟﻙ_, угдс, sznú_, 
   {{0x4aa52126,0x7cf80295,0x656c00a9,0x7cec00d0}},	//   ग्यव, _jùrù, _uwch, _búrl, 
   {{0x7bc0017a,0x7cec0419,0x51840395,0x00000000}},	//   yvlu, _rúro, руца, --, 
   {{0x2604012c,0x7cec1315,0x7e6834b9,0xbea4020f}},	//   _सेती_, _súro, tbep, гайк, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd1b92127,0x225c011f,0x7bc00218,0x7e692128}},	//   _لالا_, _ifuk_, wvlu, rbep, 
   {{0xee352129,0x7bc0057b,0x7e680d47,0xf21002e3}},	//   ыны_, tvlu, sbep, pọrọ, 
   {{0xfc04e085,0xd120007d,0x57a00023,0xe81c00c5}},	//   упно, मकरण_, _ልፍንቲ_, _मँगा_, 
   {{0x7cf80241,0x6568063f,0x7bc00373,0x98b80205}},	//   _bùrù, ̣gha, rvlu, _ızın_, 
   {{0x7bc00af9,0xc0e00092,0x9f440200,0x6b5c0171}},	//   svlu, ናጠል_, hynë_, _rīge, 
   {{0xa6d80008,0x39a0013f,0xe9a400f2,0x00000000}},	//   _miðu, _wɔso_, اگين_, --, 
   {{0xa6d82880,0x3ebc0327,0xcc2401ed,0x3754009f}},	//   _liðu, _kawt_, _پروٹ, اپرس, 
   {{0x2a680175,0xfd5000cd,0x00000000,0x00000000}},	//   cbcb_, _sudṛ, --, --, 
   {{0xa6d811c3,0xf6080fc6,0x15281171,0x86743395}},	// [1b4e0] _niðu, رتره_, внақ_, рысц, 
   {{0x225c045f,0x32b00327,0x33f4004e,0x00000000}},	//   _afuk_, _ནིཤྐ, лчес, --, 
   {{0x37e40323,0x64a1212a,0xb38402dd,0xb60402f0}},	//   _сонг, саха, улел, dláž, 
   {{0x78bc0455,0xa6d80bcd,0xb5d0030d,0x00000000}},	//   _hapv, _biðu, _гιил, --, 
   {{0x28100502,0x78bc00df,0x6eec01c3,0x234801b9}},	//   _نویس, _kapv, _dùbl, رسمی_, 
   {{0xe5a0026a,0x7cec032e,0x2d800118,0xca3c0ef6}},	//   _ћири, _búrm, ákem_, _ﺑﻮﺯ_, 
   {{0xa6d80321,0x31641529,0xa8540375,0xa3b801ad}},	//   _viðv, spoz_, ניקה_, _अनय_, 
   {{0x2d80786d,0x7174913f,0x78bcf541,0xa6d802d2}},	//   škem_, _مهرا, _lapv, _fiðu, 
   {{0x6ce40220,0x8cf45a92,0x00000000,0x00000000}},	//   гіне, изиц, --, --, 
   {{0x3ae0002e,0x78bc01d3,0x00000000,0x00000000}},	//   _sópp_, _napv, --, --, 
   {{0x5cc020b0,0x7cec02d2,0x6f640114,0x00000000}},	//   ссыз, _gúrm, _свез, --, 
   {{0xef183baa,0x66c8013d,0xabb00022,0x00000000}},	//   _яме_, _mökä, _ҳакә, --, 
   {{0x0cd40166,0xa6d808ce,0x49a40961,0x66c801f4}},	//   _волю, _miðt, шынғ, _lökä, 
   {{0x5d800597,0x78bd212b,0xdcf80841,0xefdc0023}},	//   _الول, _capv, vruć, ሓሒዙ_, 
   {{0xe7307467,0xd7f8169c,0x78bc0477,0x25a80175}},	//   مصر_, гут_, _dapv, _spcl_, 
   {{0xa4fc000b,0x7b940133,0xdb1002d2,0x00000000}},	//   ोच्च_, _ئاوڕ, _íeðl, --, 
   {{0x78bc0369,0x00000000,0x00000000,0x00000000}},	// [1b4f0] _fapv, --, --, --, 
   {{0x48c40598,0xe0dc0729,0x66c80166,0xa6d802d2}},	//   _тәма, _ভগ্ন, _bökä, _riðu, 
   {{0x94a80fca,0xa6d80d12,0xa918032e,0x00000000}},	//   ытта_, _siðu, gsþe, --, 
   {{0x52740137,0x00000000,0x00000000,0x00000000}},	//   бушу, --, --, --, 
   {{0x6abc73a8,0x7cec032e,0x8c080154,0x9f440200}},	//   _maqf, _súrm, _রুমন_, synë_, 
   {{0xa6d805a4,0x2375212c,0x4128023b,0x00000000}},	//   _viðu, _مارح, ъоло_, --, 
   {{0x7fd40046,0x51840e46,0xe808134e,0x33240129}},	//   рілі, _қута, _हेमा_, boox_, 
   {{0x225d212d,0x00000000,0x00000000,0x00000000}},	//   _ufuk_, --, --, --, 
   {{0xf1c80122,0x3010013d,0x009401c4,0x00000000}},	//   _pláž_, йдәр, _визэ, --, 
   {{0x7cec004e,0x51840063,0x61e802d0,0x66c801f4}},	//   _túrm, _ћута, mygl, _yökä, 
   {{0x7a69212e,0x78bc0477,0x0e6400f7,0xddc800de}},	//   кинг_, _rapv, шкөн, _degš, 
   {{0xa6d808a7,0x8eb801af,0x00000000,0x00000000}},	//   _miðs, _бышт_, --, --, 
   {{0xa6d8066a,0x5d642bbd,0x61e80042,0x78bc0064}},	//   _liðs, _стез, nygl, _papv, 
   {{0xa96424fc,0x2f18005f,0x315400d9,0x00000000}},	//   рира_, mīga_, יישן_, --, 
   {{0x61e8008c,0x6bd403e6,0x2f1800e2,0x69c83e33}},	//   hygl, _نووس_, līga_, _ágen, 
   {{0x78bc01fb,0x26040037,0x33240009,0xd8540150}},	//   _wapv, _सेही_, xoox_, реңө, 
   {{0x2f1800e2,0x78bc000d,0x65c06171,0x00000000}},	// [1b500] nīga_, _tapv, обта, --, 
   {{0x80a42158,0x6299212f,0x6d5c02b1,0xa6d801a8}},	//   _গোস্, _acuo, _ōpak, _biðs, 
   {{0xb6a40166,0x00000000,0x00000000,0x00000000}},	//   _кинл, --, --, --, 
   {{0x7cec0030,0x26040210,0x00000000,0x00000000}},	//   _búrk, _सेवी_, --, --, 
   {{0xa6d80321,0xe29455c3,0xb14407d6,0x363400f2}},	//   _viðt, рач_, андл, _خردس, 
   {{0x7af400a9,0x6b5c005f,0x7cec03b2,0x2f1800e2}},	//   _llyt, _līga, _dúrk, dīga_, 
   {{0xa5052130,0x25180375,0x7af403ac,0x25780241}},	//   _тера_, _סולא, _olyt, _tàlá_, 
   {{0x5f400228,0xddc800de,0x00000000,0x00000000}},	//   ينول, _segš, --, --, 
   {{0x7cec08a5,0x160c0037,0x7b140327,0x00000000}},	//   _gúrk, _सेमर_, rġul, --, 
   {{0x7af402d5,0x4c940114,0x6efc0064,0x00000000}},	//   _alyt, љинс, gūbr, --, 
   {{0x7af40493,0xdeed2131,0xb0640432,0xa6d81d1d}},	//   _blyt, _ды_, _edäý, _miðr, 
   {{0x6da48439,0xa00400cf,0x7af52132,0xeb0400cf}},	//   _вида, _ئسكۇ, _clyt, рчоо, 
   {{0x2f1800e2,0x7aec025c,0x6abc022e,0x29880395}},	//   cīga_, _ċatt, _vaqf, ъсно_, 
   {{0xa6d808a7,0x6abc0003,0xdca00063,0x1d041513}},	//   _niðr, _waqf, _даљи, _кечи_, 
   {{0x7d1d2133,0xd9192134,0x61e8012d,0x00000000}},	//   ésse, рья_, zygl, --, 
   {{0x7af40d22,0xaae40133,0xa6d802d2,0x86540395}},	//   _glyt, _خستو, _riðs, сках, 
   {{0x7cec0413,0xa6d80d12,0xc6380212,0xf77c025c}},	// [1b510] _búrh, _siðs, упає_, ċħad_, 
   {{0x62992135,0x7cec00d0,0x58d4010a,0x9f4400d7}},	//   _scuo, _rúrk, _доьт, dzný_, 
   {{0xa6d802d2,0x00000000,0x00000000,0x00000000}},	//   _diðr, --, --, --, 
   {{0xa6d800fc,0x00000000,0x00000000,0x00000000}},	//   _viðs, --, --, --, 
   {{0x6eec01ab,0xa6d8e324,0x16840244,0x00000000}},	//   _iùbh, _fiðr, _باپێ, --, 
   {{0x61e800a9,0xe4c435c7,0x00000000,0x00000000}},	//   rygl, _тёмн, --, --, 
   {{0xa3b8038e,0x2124009a,0x2e4c01e1,0x61e803ac}},	//   _अनि_, ronh_, _lọdọ_, sygl, 
   {{0x7ced2136,0x21241497,0x2f1800e2,0xa18401af}},	//   _túrk, sonh_, tīga_, _выжл, 
   {{0x6b5c0029,0x4430010e,0x00000000,0x00000000}},	//   _rīga, _hyz_, --, --, 
   {{0x4430089c,0x2f1800da,0x7ced2137,0x00000000}},	//   _kyz_, rīga_, _kúri, --, 
   {{0x7af52138,0x1ee42099,0x2f1800de,0x6fa800f1}},	//   _plyt, _پوشی_, sīga_, _منلې_, 
   {{0x94180134,0x7ced2139,0x2f1800e2,0x443000a2}},	//   _abrɛ_, _múri, pīga_, _myz_, 
   {{0xec6d213a,0x7af40af9,0x7e7803ac,0x7ced213b}},	//   _нп_, _vlyt, _iewp, _lúri, 
   {{0xcc0811fc,0xe73c00e4,0xbebc262b,0x3ea40345}},	//   ازین_, _ahõ_, plūs, _ئێکێ_, 
   {{0xbb8406d5,0x7cec00f7,0x158c02dd,0xbb4495a2}},	//   _البي, _núri, _ﯗﻗﺘﯩ, _лекк, 
   {{0xaa780008,0x6eec00a3,0x7e78014f,0xd99803e6}},	//   skýr, _cùbh, _jewp, _پۆست_, 
   {{0x6eec0192,0x443000d8,0x34840166,0x00000000}},	// [1b520] _dùbh, _ayz_, йгаг, --, 
   {{0x7ced213c,0xf86800ae,0x00000000,0x00000000}},	//   _búri, _حمدي_, --, --, 
   {{0x7cec004e,0xa6d8066a,0x387800ef,0x84540e56}},	//   _cúri, _viðr, _iepr_, زىنچ, 
   {{0x4430010e,0x80a40154,0x00000000,0x00000000}},	//   _dyz_, _গোল্, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7ced213d,0x9f440030,0x443002f0,0xd7ac0073}},	//   _fúri, rzný_, _fyz_, _चहाच, 
   {{0xaf0450f1,0x44300209,0x00000000,0x00000000}},	//   йчик, _gyz_, --, --, 
   {{0xe1f5213e,0x6360013f,0x437400a8,0x00000000}},	//   ргә_, rεnt, _фурт, --, 
   {{0x7ced213f,0x2dd800c6,0x41b40034,0x2d8001d3}},	//   _zúri, ابعة_, _आईएस, éke_, 
   {{0x2d888bb3,0xdaf4031c,0x38785049,0x44300fac}},	//   čbe_, _བཞུཌ_, _nepr_, _yyz_, 
   {{0x44312140,0xa0d401d9,0x248400d0,0x2e4c01e1}},	//   _xyz_, _دِلا_, ónmi_, _sọdọ_, 
   {{0xc1c80014,0xdee0013e,0xddd80115,0xe04001c6}},	//   _حبہٕ_, _нохи, lbuŝ, _энхи, 
   {{0x7be401e4,0xdcf800df,0x2f1800e2,0x14c800cd}},	//   _ĥruŝ, lruĝ, līgo_, रयाण, 
   {{0x2ee40151,0xa260010c,0x93f80490,0xddd801e4}},	//   _hoof_, ስትናን_, ंनाच_, nbuŝ, 
   {{0xb7c4ec89,0x387800ca,0x2ee44ddf,0x2f1800e2}},	//   ортқ, _depr_, _koof_, nīgo_, 
   {{0x2c4c00ac,0x2ee401f5,0x9c140375,0x613c06af}},	//   məd_, _joof_, _לחוק_, mêle, 
   {{0x26c4012c,0x7ced2141,0x2ee404e6,0x6360013f}},	// [1b530] ěno_, _súri, _moof_, yεns, 
   {{0x2ee52142,0x26c477d7,0x00000000,0x00000000}},	//   _loof_, śno_, --, --, 
   {{0x2c4c00ac,0x00000000,0x00000000,0x00000000}},	//   nəd_, --, --, --, 
   {{0x81bc015b,0x45d4bba2,0x2f1800e2,0x92580811}},	//   ইমস_, _домс, dīgo_, مشهر_, 
   {{0x99492143,0xc0c40588,0xe5c4292c,0x2c4c03b9}},	//   _خلیل_, жәеи, _усно, həd_, 
   {{0x7ced2144,0x00000000,0x00000000,0x00000000}},	//   _túri, --, --, --, 
   {{0x11a8069c,0xfe7000c6,0x4430003e,0x78a80267}},	//   _መግለጺ_, ودة_, _uyz_, _öfve, 
   {{0x2c4c03b9,0xf3e000cc,0x00000000,0x00000000}},	//   dəd_, _গেকৰ_, --, --, 
   {{0x2ee42d1d,0x4adc3517,0x7cec02d2,0x00000000}},	//   _doof_, यानव, _múrv, --, 
   {{0x2e4c01e1,0xd1cc02d3,0x7d080640,0x9fa4002e}},	//   _bọbọ_, በብቲ_, рног_, _wёñ_, 
   {{0x2f18005f,0xbb441b0a,0xfc30007b,0x00000000}},	//   cīgo_, женк, بحة_, --, 
   {{0x2ee40009,0x6d5c02f0,0x00000000,0x00000000}},	//   _goof_, _čpav, --, --, 
   {{0x9f4400e5,0x00000000,0x00000000,0x00000000}},	//   sznó_, --, --, --, 
   {{0x672c068f,0x8d74158b,0x7b1400e4,0xa6d802d2}},	//   _akcj, _راها, iġui, _siðp, 
   {{0x6eec0268,0x7aa4030d,0xfa680117,0x9f4401ef}},	//   _sùbi, _дийз, _кайк_, hyní_, 
   {{0x6eec0428,0x1b18015b,0x3a300254,0x9f440118}},	//   _dùbw, _ধীরে_, _tyyp_, kyní_, 
   {{0xf5092145,0xe5a12146,0x644009cc,0x00000000}},	// [1b540] анал_, мити, ýnin, --, 
   {{0xe5752147,0x3f84013c,0x60980092,0x7b140327}},	//   юзу_, _ovlu_, ቀናጀት_, wġuh, 
   {{0x80dc047f,0xded80023,0x00000000,0x00000000}},	//   पाने, ንሑን_, --, --, 
   {{0x316803f6,0xa3b80037,0x4adc07b7,0x657800ae}},	//   ашко_, _अनर_, यायव, úchó, 
   {{0x3f846a37,0x2c4c00ac,0x2ee52148,0x7b14031c}},	//   _avlu_, zəd_, _roof_, rġuh, 
   {{0x2ee40de2,0x7cec03b2,0x6b5c00ef,0x2f880114}},	//   _soof_, _kúru, _bīgl, аљин_, 
   {{0xddd80115,0x2ee4045a,0x4adc06ff,0x00000000}},	//   rbuŝ, _poof_, यामव, --, 
   {{0x2f1800e2,0x7cec0174,0xdcf801e4,0x9f5c01d3}},	//   rīgo_, _múru, rruĝ, úrák_, 
   {{0x2164003b,0x00000000,0x00000000,0x00000000}},	//   _мити_, --, --, --, 
   {{0x2ee40204,0x00000000,0x00000000,0x00000000}},	//   _woof_, --, --, --, 
   {{0x7d1c004a,0xce343b93,0xf8dc00cd,0x00000000}},	//   éssa, _کوشک, मानय, --, 
   {{0xeb0410f5,0xfbcc0451,0x7f180024,0x00000000}},	//   ічно, اڪو_, _лічу_, --, 
   {{0xad580b32,0xddc000a8,0x00000000,0x00000000}},	//   _трех_, _обци, --, --, 
   {{0xe61c0042,0x7cec032e,0xa928155b,0xdcf82ca8}},	//   _ddôl_, _búru, ріме_, mruğ, 
   {{0x3eb001d3,0x00000000,0x00000000,0x00000000}},	//   őzte_, --, --, --, 
   {{0xd6d92149,0xae1c375c,0x7cec0332,0x96f80107}},	//   оту_, _बखान_, _dúru, оест_, 
   {{0xe8082ba2,0x44f46408,0x00000000,0x00000000}},	// [1b550] _हेरा_, ппас, --, --, 
   {{0x6eec0086,0x84c40166,0x00000000,0x00000000}},	//   _tùbw, чәмд, --, --, 
   {{0x42d402dd,0x7cec032e,0x47340108,0xdd00002b}},	//   зілу, _túrv, _ннос, _śrīr, 
   {{0xcfe00011,0xd379214a,0x86f800f2,0xbebc0064}},	//   বনান, ючу_, _اکسس_, roūk, 
   {{0x36a00150,0x3ea80022,0x1a9c008f,0x00000000}},	//   _سەلق, _ñati_, שידע, --, 
   {{0xdcf8005f,0x6369214b,0x7f740276,0xd498009b}},	//   ksuā, _враг_, пуиц, _мрс_, 
   {{0x2d840048,0x7cec0332,0x00000000,0x00000000}},	//   _avoe_, _múrt, --, --, 
   {{0x3f84017a,0x00000000,0x00000000,0x00000000}},	//   _vvlu_, --, --, --, 
   {{0xfe700214,0xcf240116,0x00000000,0x00000000}},	//   ودک_, بروي, --, --, 
   {{0xf3e000cc,0x00000000,0x00000000,0x00000000}},	//   _গেটৰ_, --, --, --, 
   {{0xca29214c,0x6e21214d,0x2d840165,0x7c280798}},	//   _עם_, _exob, _evoe_, сонг_, 
   {{0x1ee4168d,0xdb0404ce,0x00000000,0x00000000}},	//   _گوڵی_, _opnå, --, --, 
   {{0x7f4820ac,0xae580375,0x7cec1427,0x7bcc00ef}},	//   mmeq, _הכנר, _súru, _ņaud, 
   {{0xae000131,0xccc402bf,0x6e24000f,0x00000000}},	//   _سۈپى, _обій, ûkbe, --, 
   {{0x68400166,0x69d80112,0xf74400d4,0x00000000}},	//   енра, äuer, зево, --, 
   {{0x66e1214e,0xf98401af,0xab240395,0x00000000}},	//   носа, _егио, _ноща_, --, 
   {{0x7f48037e,0xe9cc0451,0x00000000,0x00000000}},	// [1b560] imeq, _مٺي_, --, --, 
   {{0x7cec06ea,0x7f480112,0x00000000,0x00000000}},	//   _túru, hmeq, --, --, 
   {{0x79840311,0x7cec01e7,0xe8c401c6,0x00000000}},	//   lskw, _húrs, _эгэл_, --, 
   {{0x7e7c022c,0xdcf81b0d,0x7cec08a5,0x9f4c0150}},	//   ðspl, yruğ, _kúrs, _ﺟﺎﻻﯞ_, 
   {{0x798423f3,0x23240798,0x00000000,0x00000000}},	//   nskw, чоци_, --, --, 
   {{0x6eec01ab,0x798401f5,0x2564010b,0x7cec08ce}},	//   _lùbt, iskw, _харп_, _múrs, 
   {{0xd0100491,0x2404010a,0x96e00118,0x00000000}},	//   ضلة_, _енри_, _पचाउ, --, 
   {{0x68444de4,0x2450007b,0x71a401f0,0x00000000}},	//   lédé, _أنفس, _набз, --, 
   {{0x91800131,0x798401f5,0xcf900014,0xf3e000cc}},	//   _شۇغۇ, jskw, ر٘ک_, _গেচৰ_, 
   {{0x7984257d,0x69c800d8,0x00000000,0x00000000}},	//   dskw, _ágei, --, --, 
   {{0x212800e4,0x0a9428f6,0x00000000,0x00000000}},	//   _ícha_, маню, --, --, 
   {{0x6e20005a,0x7cec03b2,0x7984017a,0xe9dc00db}},	//   _txob, _búrs, fskw, txú_, 
   {{0xdd8c16cb,0x7cec0597,0xa5b80005,0x7984017a}},	//   _مون_, _cúrs, _axón, gskw, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfb880022,0x68440098,0x9ca400ec,0x98480395}},	//   _дрық_, dédé, _رهيل_, зята_, 
   {{0x7cec03b2,0x6b9803cd,0x8a180395,0x00000000}},	//   _fúrs, mutg, _мойс_, --, 
   {{0xa5b80077,0x6b99214f,0xd6680133,0x2c8401e7}},	// [1b570] _exón, lutg, سملو_, cídí_, 
   {{0x68440c6a,0x7ced2150,0x7f480200,0x00000000}},	//   gédé, _húrr, zmeq, --, 
   {{0x7f480113,0x6b992151,0x00000000,0x00000000}},	//   ymeq, nutg, --, --, 
   {{0x41b400c7,0x28c806ff,0x00000000,0x00000000}},	//   дскт, ायवि, --, --, 
   {{0xd04803b9,0xe294010a,0x00000000,0x00000000}},	//   _ində, çах_, --, --, 
   {{0x684407ea,0x6b9803cd,0x981417a5,0x06c40154}},	//   cédé, kutg, _آبیا, _একটি, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6b9807de,0x614000bc,0x8afc0153,0x7984c882}},	//   dutg, _bílý, ipęs, yskw, 
   {{0xf4080003,0x7f480ee9,0x7d1d2152,0x217800f1}},	//   _གཟོད_, rmeq, ésso, _دحزب_, 
   {{0x20c402dd,0xfb880138,0x00000000,0x00000000}},	//   _хқко_, обок_, --, --, 
   {{0x6b992153,0x7cec032e,0xfc2800d4,0x902800c0}},	//   gutg, _súrs, южок_, _ецца_, 
   {{0xf428013d,0x00000000,0x00000000,0x00000000}},	//   lläü_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6b9800cf,0xdcf801a6,0x387c0118,0x9f0000f1}},	//   butg, pruđ, útr_, _غوږو, 
   {{0xf408031c,0x3dcc025c,0x00000000,0x00000000}},	//   _གཟེད_, lvew_, --, --, 
   {{0x79840b21,0xba5400a7,0x66180153,0xdcf8003d}},	//   pskw, _отпъ, _žuka, ftuħ, 
   {{0xf428008e,0xd1c40023,0x00000000,0x00000000}},	// [1b580] kläü_, ኻባት_, --, --, 
   {{0x3eac036e,0x00000000,0x00000000,0x00000000}},	//   hfet_, --, --, --, 
   {{0x64a0836f,0x5928031c,0x6844003e,0x00000000}},	//   таха, _ལྩགས_, rédé, --, 
   {{0x6b5c00b8,0x68440129,0x63a00694,0x3eac0327}},	//   _dīgh, sédé, ànna, jfet_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2f1800da,0xc7a89831,0x3eac025c,0x6b98022e}},	//   mīgi_, _بدیل_, efet_, yutg, 
   {{0x64a12154,0x3eac00ed,0xe3612155,0x2f18005f}},	//   _шара, ffet_, _акси, līgi_, 
   {{0xed886b1a,0xbf2802d3,0x6b9850d1,0xa91801a8}},	//   осок_, _ስቶክሆ, vutg, gsþj, 
   {{0x2f1800da,0x4adc07b7,0x00000000,0x00000000}},	//   nīgi_, यासव, --, --, 
   {{0x6b992156,0xab852157,0x7cec08ce,0x00000000}},	//   tutg, мумк, _súrr, --, 
   {{0x5cc09a21,0xe0cc01d9,0x7cecfd54,0x2e6800fd}},	//   тсыз, _خٲل_, _púrr, _диеп_, 
   {{0xed580aa5,0x6b98168c,0x00000000,0x00000000}},	//   _дод_, rutg, --, --, 
   {{0x5ea0066d,0x6b981f53,0xed0801d5,0x160009bb}},	//   _شمول, sutg, _وآته_, लैमर_, 
   {{0x2f18005f,0xded80023,0x2d500244,0x00000000}},	//   dīgi_, _ንምነ_, _جێخس, --, 
   {{0xe73000c6,0xd83801c6,0x00000000,0x00000000}},	//   نصر_, дэт_, --, --, 
   {{0x3ea80694,0xbd840244,0x00000000,0x00000000}},	//   _ñatt_, _تۆین_, --, --, 
   {{0xe4e402bf,0x00000000,0x00000000,0x00000000}},	// [1b590] міжн, --, --, --, 
   {{0x94746216,0x147400ae,0x00000000,0x00000000}},	//   ندما, نامج, --, --, 
   {{0xe7a402dd,0x7cec0332,0x69cc12e8,0x00000000}},	//   _تۇزى_, _múrp, lvce, --, 
   {{0x3eac025c,0xc55801af,0x2f1800de,0x00000000}},	//   xfet_, _нимє_, bīgi_, --, 
   {{0x2f18005f,0x09ac2b1b,0x00000000,0x00000000}},	//   cīgi_, খিকা, --, --, 
   {{0x656c5337,0xd10801b9,0x31d000db,0x00000000}},	//   _itch, وقنه_, اقوز, --, 
   {{0x93892158,0x6eec2b1d,0x6d5c02b5,0xddd801e4}},	//   _оста_, _rùbr, _ōpap, rauŭ, 
   {{0xfde92159,0x6fb0027d,0x53440220,0xbea441e5}},	//   здик_, اميا, _ахуа, хаик, 
   {{0x67200048,0x3eac3813,0x6440068c,0xd234011c}},	//   _ínju, rfet_, ünif, _антъ, 
   {{0x6d211f3a,0x3eac29b1,0x656c02ce,0x3dcc025c}},	//   лдыз, sfet_, _mtch, rvew_, 
   {{0x7c940502,0x2900044e,0x7d0002c4,0xfaa4bae4}},	//   وشگا, dhja_, rhls, нано, 
   {{0x656d215a,0x2e4c063f,0xdcf800e2,0x2004022e}},	//   _otch, _kọlọ_, truē, mzni_, 
   {{0x656c1813,0x6e91215b,0x7e6864bf,0x20040010}},	//   _ntch, _صلوا, mcep, lzni_, 
   {{0x29000ba3,0x2f1800e2,0x20040e04,0xc8b400fb}},	//   ghja_, vīgi_, ozni_, кссы, 
   {{0x656d215c,0x9f44010e,0x00000000,0x00000000}},	//   _atch, gynç_, --, --, 
   {{0x2f18005f,0x20040240,0xddd8054e,0x00000000}},	//   tīgi_, izni_, cauţ, --, 
   {{0xf9880597,0x7f580455,0x00000000,0x00000000}},	// [1b5a0] _عندي_, _miwq, --, --, 
   {{0x64a1215d,0x2f1800da,0x656c020c,0x29000c95}},	//   лауа, rīgi_, _dtch, chja_, 
   {{0x7e69215e,0x656d215f,0xcab40154,0xfbac00fe}},	//   kcep, _etch, য়ারফ, গিকত, 
   {{0x2f18005f,0x656c022e,0xf1a4023a,0x95b40124}},	//   pīgi_, _ftch, еркн, _иргә, 
   {{0x39592160,0xc32c6abd,0xba040023,0x200400ef}},	//   _kips_, زەك_, _ፎእ_, ezni_, 
   {{0x7e680483,0xddc83535,0x3958022e,0x61d40006}},	//   ecep, _şişi, _jips_, эмія_, 
   {{0x39580419,0xa52016a4,0xaa780118,0x9f440108}},	//   _mips_, _смрд, rkýz, kynä_, 
   {{0x39586f94,0xc0580006,0xa30801d3,0x6b5c00de}},	//   _lips_, фіі_, _فرقے_, _jūge, 
   {{0x7cec7d3d,0x200400d7,0x31240153,0x00000000}},	//   _púrp, azni_, _здаг, --, 
   {{0x39592161,0xdbd801e1,0xafe43aeb,0x644080e1}},	//   _nips_, _bààr, _позл, ünig, 
   {{0x247402ea,0x2004033f,0x4bc498c5,0x09c80a8a}},	//   lɛmá_, czni_, төлг, िट्य, 
   {{0x395804cc,0x00000000,0x00000000,0x00000000}},	//   _aips_, --, --, --, 
   {{0xee3805f5,0x29000023,0x00000000,0x00000000}},	//   _энд_, thja_, --, --, 
   {{0x1cdc0867,0x39582d1a,0xe76806ed,0x2e4c0241}},	//   _ཤོར_, _cips_, зјак_, _jọmọ_, 
   {{0x395806f2,0xdbd80241,0x99a000de,0x2dc80150}},	//   _dips_, _gààr, āršs_, _ﻓﻴﻠﻤ, 
   {{0x2900044e,0xdc3806a9,0x2e4c01e1,0x00000000}},	//   shja_, _מעור, _lọmọ_, --, 
   {{0x39580115,0x00000000,0x00000000,0x00000000}},	// [1b5b0] _fips_, --, --, --, 
   {{0x39592162,0x2f18005f,0x17c00183,0x7e688a8a}},	//   _gips_, mīgu_, _উপৰি, zcep, 
   {{0xd4992163,0x6b5c002d,0xe0dc004d,0x1cdc031c}},	//   эрт_, _fūge, _đò_, _ཤོལ_, 
   {{0x39580030,0x93952164,0xf77404ae,0x7e680f85}},	//   _zips_, اجلا, _שערי_, xcep, 
   {{0x26c80113,0x656d2165,0x964400ee,0x2f1800e2}},	//   _iaco_, _utch, _бэрд, nīgu_, 
   {{0xd1b810fe,0x7f580113,0x395800db,0xddd800e2}},	//   عانا_, _siwq, _xips_, jauš, 
   {{0x26c89d33,0x82c40022,0x638401e7,0xa91802d2}},	//   _kaco_, _ишаҵ, _déná, gsþi, 
   {{0x26c92166,0x24800115,0x02600244,0x00000000}},	//   _jaco_, _hejm_, _ئێشێ, --, 
   {{0x26c92167,0xf2d000c8,0x2e4c0241,0x6e3405ac}},	//   _maco_, _דען_, _fọmọ_, _øybl, 
   {{0x7e692168,0x6b5c00da,0x26c90517,0x2f1800e2}},	//   scep, _līgu, _laco_, dīgu_, 
   {{0x23612169,0x4adc0490,0x9aa82ba5,0x3958045a}},	//   _jujj_, यांव, ىندە_, _rips_, 
   {{0x26c9216a,0x23601574,0x29100332,0xdfcca44e}},	//   _naco_, _mujj_, _amxa_, _پيچ_, 
   {{0xed4d216b,0xdbd80241,0xf8dc3381,0x85000118}},	//   _во_, _dàár, मालय, लघाट_, 
   {{0xdbd80ca8,0x00000000,0x00000000,0x00000000}},	//   _tààr, --, --, --, 
   {{0x3958713c,0xdbd801e1,0x68440248,0x65680332}},	//   _vips_, _fàár, _rédí, íghn, 
   {{0xdbd80241,0x2f1800de,0x00000000,0x00000000}},	//   _gàár, bīgu_, --, --, 
   {{0x26c9216c,0x68440077,0x39580302,0x24800240}},	// [1b5c0] _daco_, _pédí, _tips_, _bejm_, 
   {{0x225c0589,0x33f5216d,0xbb740092,0xc8c800ec}},	//   _aguk_, кчес, _የተሰኘ_, _ٻوٽن_, 
   {{0x26c9216e,0x684402d2,0x69c88c89,0x00000000}},	//   _faco_, _védí, _áger, --, 
   {{0x26c83c72,0x00000000,0x00000000,0x00000000}},	//   _gaco_, --, --, --, 
   {{0x551c00c6,0x21641d4a,0x2e4c01e1,0x79800432}},	//   _нαиα, вичи_, _pọmọ_, _çowd, 
   {{0x26c9216f,0x95b40124,0xe228001f,0x2344be0c}},	//   _zaco_, _ирҳә, _እናምና, ىلەپ_, 
   {{0x0fe00d42,0x26c8601a,0x2f1800de,0xd10801b9}},	//   বন্ধ, _yaco_, zīgu_, وقچه_, 
   {{0x6440002f,0x248001ef,0x14e001f9,0x00000000}},	//   ünie, _zejm_, नावण, --, 
   {{0xd25001d9,0x644000e2,0x2e4c0241,0x71a4009d}},	//   _اۆش_, ļnie, _tọmọ_, _шааз, 
   {{0x64404812,0x9360063f,0x00000000,0x00000000}},	//   żnie, _ịnyị, --, --, 
   {{0x2e4c0241,0x1dd400db,0x00000000,0x00000000}},	//   _kọkọ_, елөө_, --, --, 
   {{0x2f1800e2,0x7bd40066,0x00000000,0x00000000}},	//   tīgu_, اژور_, --, --, 
   {{0x6f012170,0x26c8004e,0x80a800c5,0x65780327}},	//   _iloc, _raco_, _घामे, _ħuho, 
   {{0x26c868b1,0xdd912171,0x2f18005f,0x6c740117}},	//   _saco_, _ташы, rīgu_, _рудх, 
   {{0x1958f58e,0x6f012172,0x26c846bb,0x24802dac}},	//   тары_, _kloc, _paco_, _rejm_, 
   {{0x2f1800e2,0x569403f5,0x24801426,0xd774007b}},	//   mīgs_, иаст, _sejm_, شافع, 
   {{0x44b50d9f,0x2f18005f,0x6f000055,0xe8703c97}},	// [1b5d0] лбас, līgs_, _mloc, _پنجگ, 
   {{0x26c92173,0x6f012174,0x00000000,0x00000000}},	//   _waco_, _lloc, --, --, 
   {{0x7d1d2175,0x6f012176,0x2f1800e2,0x94a80395}},	//   éssi, _oloc, nīgs_, ътта_, 
   {{0x6b9804cc,0xd2940022,0x00000000,0x00000000}},	//   irtg, аршь, --, --, 
   {{0x925800f2,0x6b98002f,0xca7c0139,0x00000000}},	//   نشهر_, hrtg, _äzеr, --, 
   {{0x6f012177,0x80cc0307,0xbf1000fd,0x00000000}},	//   _aloc, _धोखे, әүдә, --, 
   {{0x6f012178,0x00000000,0x00000000,0x00000000}},	//   _bloc, --, --, --, 
   {{0xb7f40034,0xfe700597,0x6f0074da,0x2f1800e2}},	//   ीनतम_, حدث_, _cloc, dīgs_, 
   {{0x6d480491,0xcee821ec,0x6f000334,0xa184010a}},	//   _bhfa, ضرين_, _dloc, _шывл, 
   {{0x6f012179,0x9ba0005e,0x6230024c,0x3cc8009d}},	//   _eloc, لەتى, _беғу, хлоо_, 
   {{0x6f000e21,0x00000000,0x00000000,0x00000000}},	//   _floc, --, --, --, 
   {{0x6f01217a,0xe51000cd,0xcc3400c7,0x00000000}},	//   _gloc, णोति_, рхьы, --, 
   {{0x9aa853f0,0x6b9804cc,0xcda801b9,0xd90400d1}},	//   ىنگە_, artg, _لهنه_, иҗио, 
   {{0x6f000b91,0x2f1800de,0xc0f00023,0x00000000}},	//   _zloc, bīgs_, ግፎም_, --, 
   {{0x9c8000b0,0x3154008f,0xc0c802d3,0x2f1800e2}},	//   _āōha, טישן_, _ጠቕሚ_, cīgs_, 
   {{0xa6c4010b,0xe73401e0,0x00000000,0x00000000}},	//   ллса_, гес_, --, --, 
   {{0xb9082f8b,0xd484035b,0x644401ef,0xdb1000a2}},	// [1b5e0] _মত_, икақ, _azji, _ýeñm, 
   {{0xe5a1217b,0x7b140064,0x37e4009d,0x01a800eb}},	//   сифи, išum, _боог, ওবাদ, 
   {{0x673c0175,0x00000000,0x00000000,0x00000000}},	//   blqj, --, --, --, 
   {{0x6444002d,0x23746728,0x4adc01f9,0x00000000}},	//   _dzji, امند_, याएव, --, 
   {{0xe61c0142,0x9e38001f,0x2f1800e2,0x00000000}},	//   _ddôs_, ጠንቀቂ, zīgs_, --, 
   {{0x6f01217c,0x80a80073,0x70541bf4,0xcff40395}},	//   _sloc, _घाणे, هنشا, иплъ, 
   {{0x6f01217d,0xa2cc00bc,0x00000000,0x00000000}},	//   _ploc, _ठोक्, --, --, 
   {{0x6d48044e,0x64400034,0x00000000,0x00000000}},	//   _shfa, żnic, --, --, 
   {{0xddc8045f,0xb225217e,0x6f00898a,0x1ed4007b}},	//   _begű, _смал, _vloc, طبيب_, 
   {{0x6f01217f,0x2f192180,0xdee0036b,0x4c940640}},	//   _wloc, _bàgè_, _қочи, јинс, 
   {{0x6f0063e0,0x253400df,0x614001a9,0x00000000}},	//   _tloc, רניש_, _уефа, --, 
   {{0x7d0c03a2,0xe45400c8,0x2f1800da,0xee0800d8}},	//   _ïasn, טייט_, rīgs_, _пеел_, 
   {{0xd7f8036b,0x2f1800e2,0x3f50013a,0x00000000}},	//   қур_, sīgs_, _ešus_, --, 
   {{0x7b140306,0x00000000,0x00000000,0x00000000}},	//   nšuj, --, --, --, 
   {{0x7d1c068c,0xd7e40212,0xb67001e1,0x00000000}},	//   èsse, біто, _ọtọt, --, 
   {{0xeaf8104a,0x3a340521,0xaa7800c7,0x042c00b8}},	//   _سرعت_, ọgụ_, ejýv, cāṭa, 
   {{0xb4c00456,0x9f4801d3,0x49a4190b,0x00000000}},	// [1b5f0] ्यू_, élén_, _тыйғ, --, 
   {{0xd1f0001f,0x7b140427,0x00000000,0x00000000}},	//   ፃነት_, jšuj, --, --, 
   {{0xdb04067c,0x7b140427,0x83a40124,0x00000000}},	//   _ipnò, zšum, рызҵ, --, 
   {{0x280400fd,0xe61c0142,0x798c013d,0xd87400f2}},	//   ıqnı_, _ddôr_, _änwä, _پایب, 
   {{0x008416c3,0x00000000,0x00000000,0x00000000}},	//   алло, --, --, --, 
   {{0xe70801d5,0x361800d9,0x00000000,0x00000000}},	//   _آتگن_, _יורד, --, --, 
   {{0x42a401ee,0xfd600241,0x00000000,0x00000000}},	//   _вузғ, bewọ, --, --, 
   {{0x646005d1,0xf2c001c6,0x00000000,0x00000000}},	//   ştiğ, _мөчи, --, --, 
   {{0x62892181,0xd1b80740,0xdce8005f,0xcee813d7}},	//   mago, _مالا_, _atgā, ارىن_, 
   {{0x7b152182,0x8d28008e,0x00000000,0x00000000}},	//   ršum, лның_, --, --, 
   {{0x3b083117,0x60c12183,0xb92401e1,0x92e803d4}},	//   вено_, menm, _eewọ_, মঘৰ_, 
   {{0x60c12184,0x17c8016c,0x7b040077,0x6b5c00b8}},	//   lenm, ҳҳои_, _sóub, _pūga, 
   {{0xfce44963,0x3cc92185,0x6288005a,0xec6c2218}},	//   _воло, _алло_, iago, _мп_, 
   {{0x62892186,0x393405f5,0x395c691c,0x17c80107}},	//   hago, рэмс, öts_, гҳои_, 
   {{0xb8ec93d3,0xcd3400db,0xb73402e9,0x6b5c0171}},	//   _रस_, _ارنب, لفسب, _vīgr, 
   {{0x60c12187,0xf62401f0,0xdb24114f,0x00000000}},	//   henm, адбо, _دوبی, --, 
   {{0x60c12188,0x7b140122,0x4adc0073,0xd7640214}},	// [1b600] kenm, yšuj, याऐव, _گنجی, 
   {{0xb4c0a3a7,0x2ec05cac,0xf7707a1f,0x60c003f9}},	//   ्ये_, _शस्त, _واج_, jenm, 
   {{0x60c12189,0x6289218a,0x37e5218b,0x87f8084c}},	//   denm, fago, _тонг, _бэят_, 
   {{0x62880429,0xa5b8056a,0xca7c01a9,0x00000000}},	//   gago, _axóu, nosа, --, 
   {{0x75200124,0xb0e00fc8,0x60c0bddd,0x00000000}},	//   _дҟаҵ, पालग, fenm, --, 
   {{0x60c1218c,0x6440033f,0xe1208fe2,0x9524114f}},	//   genm, żnia, омчи, _اکرم, 
   {{0x6289218d,0xcfe8006c,0x7b150be8,0x645801e4}},	//   bago, افعه_, ršuj, _ĝuig, 
   {{0xca2c04a2,0xa8540302,0x73340075,0x66180064}},	//   ﯩﻼﺭ_, סיקה_, _ئىرا, _žuki, 
   {{0x7b140122,0x71680354,0x60c00112,0x2d801ef4}},	//   pšuj, _разг_, benm, èke_, 
   {{0x33240076,0x7e7c1d0e,0x60c05db3,0x00000000}},	//   lnox_, ðspr, cenm, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x33240d81,0xdee1218e,0x9a84010b,0xdef400c0}},	//   nnox_, _мохи, журл, _выш_, 
   {{0x3325218f,0x5a340229,0x00000000,0x00000000}},	//   inox_, жнят, --, --, 
   {{0x1cdc1b35,0xb4c107de,0x62892190,0xaa7800e4}},	//   _ཤོག_, ्यो_, zago, ejýt, 
   {{0xb4c0726e,0xd7f92191,0x62892192,0xfce802d3}},	//   ्यै_, аут_, yago, ህናጽ_, 
   {{0xbce80022,0x3864123d,0x62882f86,0xa918032e}},	//   _агәҧ_, _şort_, xago, gsþr, 
   {{0x60c12193,0x62892194,0x96e80588,0xd6d8399f}},	// [1b610] yenm, vago, шьра_, јтс_, 
   {{0x62892195,0x60c0168e,0x00000000,0x00000000}},	//   wago, xenm, --, --, 
   {{0x60c12196,0xb4b40032,0x89d801d3,0x00000000}},	//   venm, сихә, _شوگر_, --, 
   {{0xf21001f2,0x3cdc033f,0x00000000,0x00000000}},	//   rọnọ, _कोने_, --, --, 
   {{0xd1c85734,0xa22400f2,0x00000000,0x00000000}},	//   لبوم_, جراه, --, --, 
   {{0x62892197,0x850400aa,0x4534215c,0x60c0002f}},	//   sago, _اوسن, _چىڭر, uenm, 
   {{0x60c12198,0xa5b8748d,0xcfa800cf,0x7fd456a4}},	//   renm, _exót, لايم_, сілі, 
   {{0x53345e7a,0x3eb809cc,0x60c12199,0x62880194}},	//   _дест, ýst_, senm, qago, 
   {{0x20c4169c,0x9259219a,0x6908067c,0x7b300421}},	//   _всег, _ватт_, _güeg, lāug, 
   {{0xf428013d,0x2f1800c0,0xfe1c000d,0x00000000}},	//   _çäç_, būgo_, _बइठस_, --, 
   {{0xab74072d,0x00000000,0x00000000,0x00000000}},	//   یمیا_, --, --, --, 
   {{0xc86800c8,0xd978cffe,0xf210063f,0x3b080d1d}},	//   _טן_, иргә_, kọlọ, уемо_, 
   {{0x4adc0073,0xdd8c0451,0x00000000,0x00000000}},	//   याजव, _کوڙ_, --, --, 
   {{0xa965219b,0xdcf800e2,0xa3e400bc,0xb4c4012d}},	//   сира_, ntuļ, बमा_, _ऎसे_, 
   {{0x69c8006a,0x33240036,0x8b9400c0,0x00000000}},	//   _âgen, ynox_, _дрыч, --, 
   {{0xb4c00882,0x00000000,0x00000000,0x00000000}},	//   ्य्_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [1b620] --, --, --, --, 
   {{0x7af40522,0x690805d5,0x00000000,0x00000000}},	//   _hoyt, _rüeg, --, --, 
   {{0xb4c05ceb,0x4adc0073,0x00000000,0x00000000}},	//   ्यौ_, याचव, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf0750a6d,0x7af40694,0x3325219c,0xe2943e4f}},	//   билә_, _moyt, rnox_, сач_, 
   {{0x7af5219d,0x53a401ec,0x4f4c0241,0x00000000}},	//   _loyt, _қағб, _ọ̀pá_, --, 
   {{0x437402f4,0x80a8000d,0x447001ec,0xfe1c012d}},	//   _мутт, _घारे, _ﺗﺎس_, _बेबस_, 
   {{0xf2100521,0x3f840142,0x7af40162,0xb8e80327}},	//   lọmọ, _dwlu_, _noyt, _ཋི_, 
   {{0x72d400d1,0x9df402e8,0x3f5001ef,0x00000000}},	//   _коңф, йнът_, _všup_, --, 
   {{0xcb780020,0xeabc04cc,0xaa7800e4,0xa110210e}},	//   _የተለየ_, gnùn_, jjýr, _فوقت, 
   {{0x7af5219e,0x7d1c0066,0xac8401e0,0x81e800eb}},	//   _boyt, èssa, _һѳйл, মনঃ_, 
   {{0xf21001f2,0x3cdc0073,0x6b5c00ef,0x6da401a9}},	//   yọlọ, _कोठे_, _gūgl, _гида, 
   {{0x4c9402a9,0xce3405af,0x00000000,0x00000000}},	//   _дилс, _بوشک, --, --, 
   {{0x4ad802ab,0x5e54011a,0x66f8000d,0x4adc012d}},	//   _बोरव, _הידע_, _एकहक_, याङव, 
   {{0x690805d5,0x7af4022e,0xd91800f5,0x00000000}},	//   _rüed, _foyt, сья_, --, 
   {{0x7af40429,0x798001f2,0x00000000,0x00000000}},	//   _goyt, ọwag, --, --, 
   {{0x44f455cc,0x3cdc0073,0x00000000,0x00000000}},	// [1b630] опас, _कोडे_, --, --, 
   {{0x6e340158,0x6440068c,0x00000000,0x00000000}},	//   _øybu, ünio, --, --, 
   {{0xdc340139,0x5b78010f,0x47340024,0xb0e019cc}},	//   _mäğz, ָרדא, _мнос, पाईग, 
   {{0x6440033f,0x00000000,0x00000000,0x00000000}},	//   żnio, --, --, --, 
   {{0x68f4058a,0xbebc0024,0xd6d80166,0x00000000}},	//   _koxd, liūg, _утэ_, --, 
   {{0x2900cc33,0x154400c0,0x00000000,0x00000000}},	//   nkja_, _неўм, --, --, 
   {{0x29000321,0x81e800eb,0x00000000,0x00000000}},	//   ikja_, মনই_, --, --, 
   {{0x4ad87662,0xdcf800e2,0x00000000,0x00000000}},	//   _बोलव, stuļ, --, --, 
   {{0x2901219f,0x7af40548,0xdc340139,0x69080790}},	//   kkja_, _royt, _bäğz, _müeb, 
   {{0x7e988d3c,0x2cac030a,0x7af521a0,0x0d0801ec}},	//   _چنار_, _ccfd_, _soyt, йдық_, 
   {{0x7af444b1,0xdce80118,0x00000000,0x00000000}},	//   _poyt, řiďt, --, --, 
   {{0x7af47769,0x41ac033f,0x4430007c,0x00000000}},	//   _qoyt, _घमास, _mxz_, --, 
   {{0xbdc80014,0x68f40175,0x5be00014,0x6b5c0241}},	//   _خداے_, _boxd, زتھہ, _sàgì, 
   {{0xbebc0421,0xbac8009e,0x3ddc0254,0x68f40213}},	//   inūm, ষাইছ, _irww_, _coxd, 
   {{0x68f40097,0x6440000d,0xb06400a2,0x00000000}},	//   _doxd, ünil, lläñ, --, 
   {{0x66e01606,0x3e3c0092,0xc0e40023,0x00000000}},	//   моса, _አሳስቧ, ማዓሉ_, --, 
   {{0x68f40072,0xeb3000db,0xf5e800fb,0x47580064}},	// [1b640] _foxd, _تىيد, шмал_, ёрся_, 
   {{0x64a00107,0xbebc0153,0x00000000,0x00000000}},	//   дафа, liūd, --, --, 
   {{0xb37521a1,0xb3c921a2,0x00000000,0x00000000}},	//   زداش, рлез_, --, --, 
   {{0xf1a85868,0xbb2c0150,0x00000000,0x00000000}},	//   لاته_, _ﯩﻨﻪ_, --, --, 
   {{0x68f40cc1,0x7f4c031c,0x00000000,0x00000000}},	//   _yoxd, ċaql, --, --, 
   {{0xf8c801d9,0x7d0c0649,0x00000000,0x00000000}},	//   ाजिय, _ïash, --, --, 
   {{0x63a000a3,0x00000000,0x00000000,0x00000000}},	//   ànnt, --, --, --, 
   {{0x63b002fd,0x7b0402d2,0x4374c710,0x4208104e}},	//   žení, _sóun, _хурт, рмәү_, 
   {{0x290005f7,0x11680214,0xecc42077,0xdcf800a2}},	//   ykja_, _طلای_, ощно, gruį, 
   {{0x7c2c0882,0xec680b01,0x00000000,0x00000000}},	//   _śara, шрик_, --, --, 
   {{0x68f40007,0xa1100eff,0x799402d0,0xdfcc3592}},	//   _roxd, _تولت, _avyw, _ليل_, 
   {{0x68f406be,0xee38030d,0xe9e4009d,0x00000000}},	//   _soxd, _кне_, оцго, --, 
   {{0x79800432,0xa9f400bc,0x2d900ca8,0x00000000}},	//   _çowl, ुनेछ_, _ìye_, --, 
   {{0xa8500166,0x00000000,0x00000000,0x00000000}},	//   дегә, --, --, --, 
   {{0x2900daa5,0x7d28004b,0x00000000,0x00000000}},	//   rkja_, _ديوې_, --, --, 
   {{0x442c04b9,0xb90121a3,0x2900a23e,0x78bc01e4}},	//   _će_, _नो_, skja_, _ebpv, 
   {{0xc2f800fe,0xe4680798,0x00000000,0x00000000}},	// [1b650] _আগলি_, ашел_, --, --, 
   {{0x3d0800d2,0x1cdc031c,0x613c0092,0x00000000}},	//   _kúwa_, _ཤོབ_, ይወታች, --, 
   {{0x7b1456ce,0xa3e800c7,0x00000000,0x00000000}},	//   ršuv, шьаз_, --, --, 
   {{0x94040035,0x245400c7,0x00000000,0x00000000}},	//   بومه, баҕь_, --, --, 
   {{0x2fdc07de,0x7b1401a6,0xbc5c001f,0x964400c0}},	//   _artg_, pšuv, ደሆነና_, _жэрд, 
   {{0x27e401ab,0xa4906241,0x63a001ab,0x00000000}},	//   _ànns_, _آیات, ànns, --, 
   {{0x7d0c03a2,0x81bc00cc,0x00000000,0x00000000}},	//   _ïasi, েমই_, --, --, 
   {{0xf21001f2,0x00000000,0x00000000,0x00000000}},	//   kọhọ, --, --, --, 
   {{0x1cdc003d,0xb8cc031c,0x7c640055,0xdee0013e}},	//   _ཤོད_, _པྰ_, _aḍḍh, зоқи, 
   {{0x7d080640,0x1600012d,0x606000d1,0x00000000}},	//   сног_, लैटर_, _قۇشل, --, 
   {{0xbb442fc3,0x7a6801b9,0xfeb80798,0xa08001af}},	//   зенк, йинг_, _глеј_, _еңһе, 
   {{0x4ad80037,0x00000000,0x00000000,0x00000000}},	//   _बोआव, --, --, --, 
   {{0xddd82e03,0xdce001e4,0x14ac0490,0x89d401ec}},	//   lauž, _linĉ, _चालण, мірш, 
   {{0x3eacf933,0x672c0354,0x00000000,0x00000000}},	//   lget_, _ajcj, --, --, 
   {{0x69dc0309,0x3dcc009a,0x2ee4015d,0x62982e12}},	//   _erqe, lwew_, _ynof_, _oduo, 
   {{0xa3dc2ce1,0x00000000,0x00000000,0x00000000}},	//   तिन_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [1b660] --, --, --, --, 
   {{0xd88453f3,0x6298013b,0x14ac01f9,0xab700244}},	//   _تهدی, _aduo, _चाळण, _تۆێژ, 
   {{0x3eac00fb,0xf210063f,0x1cdc0327,0xf74418a4}},	//   kget_, pọkọ, _ཤོན_, _неоо, 
   {{0xe29521a4,0xddd80024,0x6fd800dc,0x82480023}},	//   зац_, dauž, भिसं, _ኪኢላታ, 
   {{0x237c098d,0x62980142,0x75d41e5a,0xbebc0064}},	//   _čuje_, _dduo, _عيسا, anūk, 
   {{0x673921a5,0x3eac01bf,0xcf900014,0x6618010e}},	//   čuje, eget_, ن٘ت_, _ýuka, 
   {{0x28980115,0x00000000,0x00000000,0x00000000}},	//   ציקא, --, --, --, 
   {{0x3eac08d7,0x7764094a,0xb2240262,0x9ed400a7}},	//   gget_, _jikx, _ембл, змът_, 
   {{0x764521a6,0xdbc809c2,0x7764031c,0x3dcc025c}},	//   _jyky, dóñe, _mikx, gwew_, 
   {{0xcb9810f5,0xa6140375,0x3eac002d,0x776401a9}},	//   ової_, פקיד_, aget_, _likx, 
   {{0xa9f4038e,0xc05800d6,0xa3dc012c,0x62980208}},	//   ुन्छ_, _дії_, तिय_, _yduo, 
   {{0x37b80156,0x7764031c,0xda78010b,0x3dcc031c}},	//   _བྱེད, _nikx, зяр_, bwew_, 
   {{0x7644049b,0x4ea400fb,0x6d8800e5,0x00000000}},	//   _nyky, _ерҙа, _چمچہ_, --, 
   {{0xa3dc5345,0x3f7402b5,0x00000000,0x00000000}},	//   तिम_, _hāua_, --, --, 
   {{0x3f740069,0x1cb806a9,0x6d5801a8,0xeabc01c3}},	//   _kāua_, _המוע, mmta, tiùd_, 
   {{0x6d5921a7,0x64400034,0x764400a2,0x00000000}},	//   lmta, żnik, _byky, --, 
   {{0x3f740053,0x963521a8,0x6d5848a1,0xba1805d9}},	// [1b670] _māua_, ентц, omta, _ويٺا_, 
   {{0x6d5921a9,0x3f7418a6,0xdce000df,0x7644010b}},	//   nmta, _lāua_, _pinĉ, _dyky, 
   {{0x3eac01e6,0x6d5921aa,0x00000000,0x00000000}},	//   yget_, imta, --, --, 
   {{0xf6e40dd4,0x764400a2,0xf3f40327,0xdeb80023}},	//   _ཤོགང, _fyky, བྱེད_, ዲድና_, 
   {{0xd6d80276,0x76440432,0x00000000,0x00000000}},	//   _этэ_, _gyky, --, --, 
   {{0x7b1401fa,0x656c0192,0xdce0010f,0x6d58fb44}},	//   nšur, _iuch, _tinĉ, jmta, 
   {{0x656d21ab,0x442521ac,0x3eac07c5,0x7e7c0165}},	//   _huch, _äl_, tget_, ñspo, 
   {{0x6d58e47b,0x629801f2,0x3ead21ad,0x76440432}},	//   emta, _uduo, uget_, _yyky, 
   {{0x3ead21ae,0x656c9b55,0x53349dc3,0xfde80212}},	//   rget_, _juch, _четт, ідок_, 
   {{0x656d21af,0x6d580589,0xc1040fb4,0xb18402d3}},	//   _much, gmta, _توطي, _ዝሰኣነ_, 
   {{0x656d21b0,0x7eb4010a,0x3dcc0135,0x00000000}},	//   _luch, _жёлч, swew_, --, 
   {{0x1cdc03bd,0x8880e17f,0x656d21b1,0x6d5844db}},	//   _ཤོམ_, ңғыл, _ouch, amta, 
   {{0x656d21b2,0xdce0031c,0x49c400fb,0xbcf4007b}},	//   _nuch, _jinċ, еһын_, _يستغ, 
   {{0x7f480eda,0x6564d6ce,0x645801e4,0x6d580334}},	//   lleq, _nijh, _ĝuin, cmta, 
   {{0x656d21b3,0xdbc80005,0xdce00327,0xf74401a9}},	//   _auch, póñe, _linċ, дево, 
   {{0x656d21b4,0x75d401d3,0x00000000,0x00000000}},	//   _buch, ويزا, --, --, 
   {{0x656d21b5,0x656521b6,0xaf900092,0x00000000}},	// [1b680] _cuch, _bijh, _ሂደትና_, --, 
   {{0x656d21b7,0x76440306,0x37e400db,0x6b5c0064}},	//   _duch, _vyky, _жоог, _rūgi, 
   {{0x656d21b8,0x65640369,0x7764025c,0x753c01f5}},	//   _euch, _dijh, _tikx, ropz, 
   {{0x2bf404ac,0x6444000f,0xb2240209,0x71a402d5}},	//   ומען_, _dyji, ммел, дадз, 
   {{0x3f741f4c,0x8364006c,0x3d0801e1,0x6d5921b9}},	//   _rāua_, ردمل, _núwo_, ymta, 
   {{0x3878022e,0x6d4400bc,0x00000000,0x00000000}},	//   _jfpr_, ůkaz, --, --, 
   {{0xd0100597,0xdc74001f,0x3f740374,0xa0640640}},	//   طلة_, _አሠራር_, _pāua_, маља_, 
   {{0x656d21ba,0x00000000,0x00000000,0x00000000}},	//   _yuch, --, --, --, 
   {{0x65640369,0xdda401c0,0x4c94010b,0x6d5803ac}},	//   _yijh, мтэл_, нипс, tmta, 
   {{0x7f480eda,0x27180037,0x00000000,0x00000000}},	//   aleq, _नग्र_, --, --, 
   {{0x3f7521bb,0xa6b0015b,0x6d5921bc,0x7f489108}},	//   _tāua_, ঁড়িয়, rmta, bleq, 
   {{0xdd8d21bd,0xa3dc5219,0x7b300618,0x6d580857}},	//   _چون_, तित_, tāua, smta, 
   {{0xdd8d21be,0xddd80356,0x00000000,0x00000000}},	//   _نون_, rbuţ, --, --, 
   {{0x656d21bf,0xdcec0135,0x00000000,0x00000000}},	//   _ruch, _ġeħo, --, --, 
   {{0x656d21c0,0xb88001a2,0x656401f5,0x7b3002b5}},	//   _such, _číta, _rijh, māun, 
   {{0x656d21c1,0x65640190,0x00000000,0x00000000}},	//   _puch, _sijh, --, --, 
   {{0x656d21c2,0x6564047e,0x29cc0003,0x00000000}},	// [1b690] _quch, _pijh, _uża_, --, 
   {{0x656c0564,0x7b300270,0x00000000,0x00000000}},	//   _vuch, nāun, --, --, 
   {{0x656d21c3,0xdce00135,0x673c0455,0x00000000}},	//   _wuch, _sinċ, poqj, --, 
   {{0x656401a4,0x98b800b0,0xf7845775,0xe9dc00d7}},	//   _wijh, morā_, ıçta_, ovú_, 
   {{0x656c0036,0x65640477,0x4ac01546,0xf6780677}},	//   _uuch, _tijh, ष्यव, _מארמ, 
   {{0x2c0c0a28,0xdce0031c,0x3f6800d8,0x7c2c002b}},	//   ानां_, _vinċ, пико_, _śarm, 
   {{0x7028025c,0x3f980055,0xf8b000cd,0x00000000}},	//   _སྨྱུ_, _āsus_, _जासय, --, 
   {{0x7f48013c,0x97240092,0xdcf80064,0x00000000}},	//   uleq, _ተወዳድ, rpuč, --, 
   {{0x98b804fe,0x7f4921c4,0xbaa400d1,0xc82c0092}},	//   horā_, rleq, _ﺋﯚﻟﮕ, ደሚጠቁ, 
   {{0x690801b8,0xe9dc0af2,0x98b8e762,0xe0d0007b}},	//   _süen, dvú_, korā_, _جزر_, 
   {{0x6b5c005f,0x3d0801e1,0x7f487350,0x200008a5}},	//   _lūgu, _wúwo_, pleq, _æji_, 
   {{0xc948011a,0x98b80171,0x00000000,0x00000000}},	//   _המ_, dorā_, --, --, 
   {{0xf1e039de,0x0d84177b,0xb6040306,0xfe7800bc}},	//   पियन, _алін, onáž, mců_, 
   {{0xfe7800bc,0x00000000,0x00000000,0x00000000}},	//   lců_, --, --, --, 
   {{0x3b08026a,0xd04803b9,0xe5a00131,0x8cd40073}},	//   _неко_, _badə, һити, _बघतो, 
   {{0xfe78012c,0xa5201ee3,0xdce00024,0x00000000}},	//   nců_, ҳмуд, _minč, --, 
   {{0xdce000f3,0x237c01a6,0xf50821fa,0xa92000d0}},	// [1b6a0] _linč, _čuja_, пнал_, šľah, 
   {{0x38780798,0x4ac0043e,0x00000000,0x00000000}},	//   _ufpr_, ष्ठव, --, --, 
   {{0x64a00032,0xdce0107d,0x04b400a7,0x68e00162}},	//   уаха, _ninč, ъстя, _ónda, 
   {{0xfe7800bc,0x27e40d12,0xddd802f0,0x63a000e5}},	//   jců_, _ánna_, zbuš, ánna, 
   {{0xfe7800bc,0xe280e17a,0xf5b400d4,0x66e0014b}},	//   dců_, улчи, _ясню, _сояа, 
   {{0xe1f405f5,0xae6c0092,0xd04803b9,0x3f98002b}},	//   эгч_, _አቀፋዊ_, _zadə, _āsur_, 
   {{0xdce00841,0xe9dc00d7,0x00000000,0x00000000}},	//   _cinč, zvú_, --, --, 
   {{0xdce00cf4,0xb3080327,0x5f7090b2,0x00000000}},	//   _dinč, _གཞིང_, داور, --, 
   {{0x3eb921c5,0xad242761,0xfe1c000d,0x00000000}},	//   òsta_, فردو, _बेआस_, --, 
   {{0x6b5c00e2,0xd12c01d9,0x09c800eb,0x63c400e5}},	//   _lūgt, _گۅڈ_, শিমা, _írná, 
   {{0xfe7800bc,0xdce00024,0x69080790,0x00000000}},	//   bců_, _ginč, _düel, --, 
   {{0xbebc0024,0x5ce00137,0xe9dc00d7,0x00000000}},	//   liūn, _ەكول, tvú_, --, 
   {{0xeabcc7cc,0x3204003e,0xd0480213,0x00000000}},	//   rfù_, nyoy_, _radə, --, 
   {{0xd04803be,0xbebc0006,0x690921c6,0x98b800e2}},	//   _sadə, niūn, _güel, torā_, 
   {{0xdcf426a6,0x57a410fc,0x00000000,0x00000000}},	//   _سروش_, лшта, --, --, 
   {{0xd6d82a30,0xa3dc0243,0x98b802b1,0xd7f40132}},	//   нту_, तिस_, rorā_, ызсы, 
   {{0xe57121c7,0x4ac00b7c,0x6e4802d3,0x893921c8}},	// [1b6b0] اطر_, ष्णव, _ምትእኽ, _опис_, 
   {{0xfe780118,0x4ab0000d,0x00000000,0x00000000}},	//   zců_, _झाँव, --, --, 
   {{0x7b300069,0x4734084c,0x193800b5,0x7d1c00db}},	//   kāul, _аннс, _ｗｉｉ_, èssi, 
   {{0x66f81b57,0xa2300724,0x6b98030a,0x7d1c01d3}},	//   _एकटक_, льлә, istg, éssz, 
   {{0x92b521c9,0xe4a47b00,0xdce04b16,0xfe78012c}},	//   احما, _прво, _sinč, vců_, 
   {{0xe5880724,0x6b9921ca,0xe4a41cb8,0x8844001f}},	//   _uñış, kstg, _ярмо, _የቤተሰ, 
   {{0x7fd40220,0x6b9801f5,0x98b80356,0xb4b40139}},	//   тілі, jstg, loră_, _ширә, 
   {{0xdce121cb,0xfde8094e,0x6b9801bf,0x00000000}},	//   _vinč, ддик_, dstg, --, 
   {{0x98b80311,0xfe7800bc,0x6b9801c7,0x6b5c0171}},	//   noră_, rců_, estg, _lūgs, 
   {{0xdce04b16,0xb35c001f,0x15bc00d1,0xbebc0153}},	//   _tinč, ታየውን_, _ﻧﻪﺯﻩ, ciūn, 
   {{0x212521cc,0x6b9921cd,0xfe7800bc,0x00000000}},	//   minh_, gstg, pců_, --, 
   {{0x2124004d,0x00000000,0x00000000,0x00000000}},	//   linh_, --, --, --, 
   {{0x7df0043b,0x9404016b,0x6b991907,0x98b8054e}},	//   kɛsɛ, _ɛmɑ_, astg, joră_, 
   {{0x69a00034,0x2124004d,0xdd8c072d,0x00000000}},	//   _कटरी, ninh_, _نوچ_, --, 
   {{0xa9641d73,0x690800e4,0xeabc04cc,0x67380960}},	//   тира_, _güem, miùn_, čujn, 
   {{0x2124004d,0x32040548,0xbb4521ce,0x98b80356}},	//   hinh_, yyoy_, _шейк, foră_, 
   {{0xe9d43697,0x80e0012d,0x21240051,0x200401ef}},	// [1b6c0] _акы_, पयाइ, kinh_, hyni_, 
   {{0xd91000f8,0xf77121cf,0x7984000f,0x200521d0}},	//   _ایس_, _پاد_, mpkw, kyni_, 
   {{0xa3dc0d35,0x2124001e,0xe5a00262,0x733521d1}},	//   तिष_, dinh_, лиӂи, پرائ, 
   {{0x2ae807f7,0xf62402d5,0xa83405d0,0x20040210}},	//   टाएँ_, _адмо, _יריד_, dyni_, 
   {{0xc0dc044e,0xc32c08c9,0xe29521d2,0x3324031c}},	//   _ኔሮም_, سەك_, тач_, riox_, 
   {{0x6b9803b2,0x5f400ee8,0xa3dd21d3,0x00000000}},	//   ystg, ینول, तिश_, --, 
   {{0x7b300421,0x200401ed,0xb11401d5,0xefb0036b}},	//   tāul, gyni_, _یورغ, شیشگ, 
   {{0xa3dc4c21,0xfe9000f2,0xc0580006,0x00000000}},	//   तिर_, میمج, хіі_, --, 
   {{0x3244355b,0x2124004d,0x6820022e,0xd250c530}},	//   _реаг, binh_, _mеda, _اچا_, 
   {{0xeabc07c5,0x6b9801a4,0x00000000,0x00000000}},	//   giùn_, tstg, --, --, 
   {{0x3fa47eea,0x00000000,0x00000000,0x00000000}},	//   _مصنف, --, --, --, 
   {{0x6b981570,0x6da40124,0xceb8535f,0x6b5c6e98}},	//   rstg, _аида, _чәк_, _rūgs, 
   {{0x7df0013f,0x2d9400c7,0x6b98143a,0x00000000}},	//   yɛsɛ, _ррес, sstg, --, 
   {{0x2bb8007b,0x4c94d174,0x98b80356,0x00000000}},	//   _قاعة_, _сикс, voră_, --, 
   {{0x7d1c0221,0xd91800c9,0x00000000,0x00000000}},	//   ësse, тья_, --, --, 
   {{0x67380219,0x1bf4011a,0x00000000,0x00000000}},	//   čujo, _יצור_, --, --, 
   {{0x27341f21,0x48c40116,0x20040456,0x00000000}},	// [1b6d0] għna_, _йәва, zyni_, --, 
   {{0x212401fb,0xa3dc87d9,0x04940b24,0x6908496e}},	//   xinh_, तिल_, الاح, _müek, 
   {{0x2124004d,0xb88000bc,0xe7a401ec,0xfa540517}},	//   vinh_, číte, _جۇزى_, _لریگ, 
   {{0xeabc1570,0x65800014,0x5694020f,0x20040153}},	//   ziùn_, _نیرٕ, _кают, vyni_, 
   {{0x212521d4,0x14ac0073,0xe31401d5,0x09d000fe}},	//   tinh_, _चाचण, _یبرب, ামকা, 
   {{0xe3b121d5,0x644121d6,0x200521d7,0x00000000}},	//   _پرس_, ünis, tyni_, --, 
   {{0x09ac025c,0xe61c0109,0x4f9521d8,0x2124004d}},	//   _པའྀ_, _teôs_, арыу, rinh_, 
   {{0x24940014,0xdce002f0,0x21240208,0x00000000}},	//   _سۅچھ_, _pinď, sinh_, --, 
   {{0x2004066a,0xeabc0ffb,0xfce4050b,0xdce000de}},	//   syni_, tiùn_, гопо, _ainā, 
   {{0x200403a2,0x6370025c,0x8d280724,0x7b3002b5}},	//   pyni_, _aħni, кның_, rāum, 
   {{0x5ed8015b,0xed4c08ca,0x98b80153,0x00000000}},	//   ভাবে, _ҳо_, norą_, --, 
   {{0x65680ffb,0xeabc07de,0x7b3002b5,0xdce06991}},	//   ìghj, siùn_, pāum, _dinā, 
   {{0xed4c833f,0xdce00171,0xb6a401d5,0x00000000}},	//   _го_, _einā, ғизл, --, 
   {{0x81b40183,0xdce0005f,0x6b4c01c3,0x00000000}},	//   _জনা_, _finā, hùgh, --, 
   {{0x682001d5,0xbb5c00b5,0xf090011a,0xb6a400d4}},	//   _pеda, ryxア_, מנם_, ливл, 
   {{0xdb24c73b,0x2734025c,0x98b80064,0x00000000}},	//   _خوبی, tħna_, dorą_, --, 
   {{0xdce00029,0xe734169c,0x74e86d5f,0x00000000}},	// [1b6e0] _zinā, ует_, ндаг_, --, 
   {{0xa3dc0882,0x7b3000b0,0x34380131,0xdce800cd}},	//   तिं_, kāuk, ىساد_, _yugā, 
   {{0x69c8006a,0x00000000,0x00000000,0x00000000}},	//   _âger, --, --, --, 
   {{0x24847975,0xd764158b,0xe3a401d5,0x8f6400b8}},	//   ınma_, _خنجی, اشلی, _kṛśo, 
   {{0xf12521d9,0x855401d5,0x00000000,0x00000000}},	//   лько, _چیقر_, --, --, 
   {{0xbebc02d5,0x98b80064,0x00000000,0x00000000}},	//   siūl, borą_, --, --, 
   {{0xa3dc0a28,0x3ca803d4,0xf8b00950,0xceb8013d}},	//   तिः_, কভাৱ, _जाईय, вәл_, 
   {{0x5ea439db,0x69c8014a,0xed8841b9,0xdce80171}},	//   ক্সে, _ägeg, нсок_, _rugā, 
   {{0xdce80a88,0x2d800200,0x00000000,0x00000000}},	//   _sugā, ëke_, --, --, 
   {{0xc1802832,0x63a0025a,0xab840116,0xdce0002b}},	//   _بیوٹ, ânng, лумк, _pinā, 
   {{0xef842bf6,0xa2d8012c,0x00000000,0x00000000}},	//   _слеп, _नसम्, --, --, 
   {{0xdce00882,0x00000000,0x00000000,0x00000000}},	//   _vinā, --, --, --, 
   {{0x4cdc0154,0xd9c80154,0x00000000,0x00000000}},	//   বাবু, ষয়সম, --, --, 
   {{0x6f000204,0x2f0800a3,0x8f640055,0x6c74059f}},	//   _hooc, _sùgh_, _dṛśo, _судх, 
   {{0x195921da,0x7b3006c8,0x2bc80114,0x7c2c00cd}},	//   уары_, kāuh, _чуло_, _śarv, 
   {{0x6f0121db,0x49746bed,0x7bc402b1,0x00000000}},	//   _jooc, _клис, _ähua, --, 
   {{0x6f0121dc,0xb8800118,0x00000000,0x00000000}},	// [1b6f0] _mooc, číre, --, --, 
   {{0x6f0000e8,0xf7b40066,0x00000000,0x00000000}},	//   _looc, دگیش_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6f000050,0x98b80153,0x00000000,0x00000000}},	//   _nooc, rorą_, --, --, 
   {{0x69c800c5,0xb2702cc8,0xdce80356,0x925800f2}},	//   _äged, әләш, _jugă, هشهر_, 
   {{0x7b3000b0,0xe5c4059f,0x00000000,0x00000000}},	//   tāuk, _исҳо, --, --, 
   {{0xfe7006d5,0x2284c9e1,0x6f010074,0xd098007b}},	//   يدة_, _бузг, _booc, ائها_, 
   {{0x6f0121dd,0x6b4c0086,0x6d4921de,0x3eb921df}},	//   _cooc, bùgi, _akfa, üst_, 
   {{0x3f740053,0x8d84036b,0xfc440023,0x6b5c00c0}},	//   _māui_, یشین, _ሓንጎል, _rūgp, 
   {{0x9ba00e8e,0x7d080640,0x7b3002b5,0x048000dc}},	//   مەتى, тног_, māui, _pīṭh, 
   {{0x6f00102c,0xfeb80114,0xfc30007b,0xbebc0064}},	//   _fooc, _алеј_, تحة_, niūk, 
   {{0x6d4921e0,0x6f0121e1,0x2bb443d1,0xeb9521e2}},	//   _ekfa, _gooc, _अमरा, шию_, 
   {{0x6d481132,0x7b040162,0xcda8009f,0x00000000}},	//   _fkfa, _sóus, _مهنه_, --, 
   {{0xdce00356,0x6f000064,0x00000000,0x00000000}},	//   _dină, _zooc, --, --, 
   {{0x6f0121e3,0x36941188,0x00000000,0x00000000}},	//   _yooc, ишас, --, --, 
   {{0x5ea4015b,0xaa7802fb,0xdce80356,0x2bd80a8a}},	//   ক্রে, rdýc, _fugă, _बनता, 
   {{0xb4f038d2,0x7bc006be,0x00000000,0x00000000}},	// [1b700] घालय_, ltlu, --, --, 
   {{0xa5a402e5,0x3f840205,0x7bc00037,0x00000000}},	//   _चिरौ, _otlu_, otlu, --, 
   {{0x7bc121e4,0xded002d3,0x7b3000b0,0x45c40116}},	//   ntlu, ራሕን_, tāuh, _қарң, 
   {{0xf20400f7,0x0674010b,0xe0cc00f1,0xa798011a}},	//   ияло, _гуря, ېزي_, _בשטח, 
   {{0x7bc0007d,0x6f000548,0x1b0803d4,0x00000000}},	//   htlu, _rooc, _লগাই_, --, 
   {{0x6f0121e5,0x6b4c0428,0x7bc0007c,0x2bb41810}},	//   _sooc, rùgi, ktlu, _अमला, 
   {{0x64a09919,0x6f00039a,0xd250105d,0x2cb800a2}},	//   _фаса, _pooc, _کۆش_, _öpdi_, 
   {{0x6d480076,0x63a0002d,0x5fa400af,0x00000000}},	//   _skfa, ânne, _गिरल, --, 
   {{0x9df400a7,0xb224010b,0xe2802461,0x00000000}},	//   инът_, _тмал, _флуи, --, 
   {{0xdce8084c,0x06884da8,0x6f00037e,0x7bc0005c}},	//   _rugă, _ﺑﯩﻠﯩ, _wooc, ftlu, 
   {{0xa3dc0034,0x6f000009,0x00000000,0x00000000}},	//   तिए_, _tooc, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7b140784,0x9e8403e6,0x7bc0000d,0x00000000}},	//   nšuy, _ئامۆ, atlu, --, 
   {{0x2d8521e6,0xefe4001f,0x6d4802d0,0x070921e7}},	//   _itoe_, ዜጣው_, _ukfa, گيري_, 
   {{0x5ba000c7,0xf1f80cb4,0x6e3402d2,0x00000000}},	//   _дрыз, ्हड़_, _þybb, --, 
   {{0x9b44105d,0x2d84007f,0x108c00d1,0x57b40816}},	//   _ونوو, _ktoe_, _ﮔﯧﺰﯨ, юбст, 
   {{0xa4840d3c,0xe664255b,0x00000000,0x00000000}},	// [1b710] لجان, ртво, --, --, 
   {{0xa8a4c896,0x2d8401f7,0x3a840014,0xd5b800f0}},	//   _трик, _mtoe_, _پُیہ, јст_, 
   {{0x9cd40302,0x69c80793,0x394400c6,0x00000000}},	//   שובה_, _ägeb, _íosa_, --, 
   {{0xded002d3,0xd14800f2,0xbebc0064,0x00000000}},	//   ራቕን_, یشون_, riūk, --, 
   {{0x26c80218,0x42a401b9,0x00000000,0x00000000}},	//   _ibco_, _қувғ, --, --, 
   {{0xc2c46ea9,0x7bc00162,0x00000000,0x00000000}},	//   _گيري, ytlu, --, --, 
   {{0x2d8521e8,0xe43001ed,0x3ea45a52,0xbea40108}},	//   _atoe_, _بہاد, бийг, байк, 
   {{0x28a4b500,0xd1b81e4a,0xc2c40592,0x7bc00334}},	//   कृति, _چالا_, _ديري, vtlu, 
   {{0xa3dc1428,0x518521e9,0xcf2400c6,0xd1b80451}},	//   तिक_, _духа, تروي, _نالا_, 
   {{0x7bc00730,0x74c800dc,0x5ba000fb,0xee341f39}},	//   ttlu, स्पृ, олоғ, снь_, 
   {{0x2d840270,0x3b08119e,0xfce41171,0x7bc00254}},	//   _etoe_, гено_, _ҳоло, utlu, 
   {{0x7bc121ea,0xbb1921eb,0x00000000,0x00000000}},	//   rtlu, ازدا_, --, --, 
   {{0xfce41830,0x7bc121ec,0x3da80212,0x00000000}},	//   _голо, stlu, _скло_, --, 
   {{0x17c80aa5,0x00000000,0x00000000,0x00000000}},	//   аҳои_, --, --, --, 
   {{0x7bdc0b23,0x7bc00327,0x3154010f,0x00000000}},	//   āsus, qtlu, מישן_, --, 
   {{0x7b140113,0x46f44316,0x00000000,0x00000000}},	//   yšuy, очут, --, --, 
   {{0xf5e82fe5,0x35a40022,0xded00023,0x15280150}},	// [1b720] ымал_, сазг, ራሕና_, анақ_, 
   {{0xaa782b57,0x26c4013f,0x00000000,0x00000000}},	//   ndýn, ɑnom_, --, --, 
   {{0x394801b8,0xe8d4011a,0x00000000,0x00000000}},	//   mobs_, _פוטר_, --, --, 
   {{0x1db403f3,0x394921ed,0xeb74008f,0x52b400cf}},	//   _आमंत, lobs_, צענץ_, تەرئ, 
   {{0xb9d0069c,0x926401b9,0x00000000,0x00000000}},	//   _ድኣ_, زگرم, --, --, 
   {{0x61403de8,0x394801b8,0xf50521ee,0xe0d401c6}},	//   печа, nobs_, _узго, йвч_, 
   {{0x2d8404e6,0xb9dc0092,0x00000000,0x00000000}},	//   _stoe_, _እጁ_, --, --, 
   {{0xf26800f0,0x918400cf,0x98b80210,0x00000000}},	//   _библ_, _ۇۇچۇ, rorę_, --, 
   {{0x6ce521ef,0xf0b80137,0x2bd8000d,0x00000000}},	//   біне, _مااش_, _बनहा, --, 
   {{0x16f80135,0xf4240327,0xa0a0119e,0x2518010f}},	//   _པོའམ_, _རྟོད_, _науд, ָוטא, 
   {{0x39480793,0x68e003b2,0x70380108,0x00000000}},	//   dobs_, _óndi, _счас_, --, 
   {{0x6f64df65,0xfba80d2c,0x9a8521f0,0x27e521f1}},	//   _увез, _किरम, зурл, _ánni_, 
   {{0x63a8068f,0x39480793,0x2bd852f2,0x2d8401f7}},	//   ągni, fobs_, _बनवा, _utoe_, 
   {{0x39480793,0x74c84668,0x7994015d,0x4cdc00cc}},	//   gobs_, स्मृ, _dwyw, বাহু, 
   {{0xd7f921f2,0x5ed80154,0x00000000,0x00000000}},	//   бут_, ভারে, --, --, 
   {{0x9b8401f7,0x8c3c0205,0x00000000,0x00000000}},	//   _انيل_, tağf, --, --, 
   {{0x44989d3e,0x79940142,0x00000000,0x00000000}},	// [1b730] иваю_, _gwyw, --, --, 
   {{0x2fdc030d,0x048801ec,0xf4900023,0xf8b4009d}},	//   _ostg_, ршақ_, _ዝቀርብ_, _мөс_, 
   {{0x73c0506f,0xa85000d1,0xdcf804a7,0x690803e0}},	//   мәте, _хенә, spuć, _düet, 
   {{0x6458bb75,0xe0300137,0xda7c010f,0x00000000}},	//   _ŝuis, үмдө, ָנגר, --, 
   {{0x2fdc07c5,0x00000000,0x00000000,0x00000000}},	//   _astg_, --, --, --, 
   {{0x439459e6,0xd5b801ce,0xded002d3,0x00000000}},	//   _магс, _усю_, ራዕን_, --, 
   {{0x7f4800d8,0x00000000,0x00000000,0x00000000}},	//   toeq, --, --, --, 
   {{0xbd846d7d,0x6e340064,0x00000000,0x00000000}},	//   огик, _žyba, --, --, 
   {{0x69080793,0x0cc492c2,0x2fdc86ec,0x4420030a}},	//   _jües, वभूम, _estg_, lzh_, 
   {{0x69080342,0x00000000,0x00000000,0x00000000}},	//   _mües, --, --, --, 
   {{0x394801b8,0x69dc7ca1,0x7b3002b1,0x44200240}},	//   vobs_, _asqe, kāut, nzh_, 
   {{0x442007e4,0xd250066d,0x386401e4,0x3a980212}},	//   izh_, _آنے_, _ŝoro_, штою_, 
   {{0x39480793,0x257c0142,0xbda40244,0x00000000}},	//   tobs_, _nîl_, _بۆخۆ_, --, 
   {{0x629804cc,0x16e80588,0x44200477,0x7794033a}},	//   _leuo, әгаҩ_, kzh_, жјац, 
   {{0x220002b5,0x3948007f,0x5dc80150,0xb6a401a9}},	//   _hūhā_, robs_, _ﺒﻔﻀﻴ, жибл, 
   {{0x6299190a,0x220002b1,0x7c2c0b45,0x2a48063f}},	//   _neuo, _kūhā_, _ƙirƙ, ụhọ_, 
   {{0x442007e4,0xd7f800a8,0xd1c402d3,0x9b4401ed}},	// [1b740] ezh_, ţă_, ጻባት_, _ونڈو, 
   {{0x62980093,0x8c3c0213,0x49900330,0x7af402d2}},	//   _aeuo, bağd, _سیفر, _hnyt, 
   {{0x7af40a64,0xc8c85024,0x64a002d9,0x62980142}},	//   _knyt, _اوپن_, фаха, _beuo, 
   {{0x7af40267,0x7778004e,0xa3dc2356,0x72d00137}},	//   _jnyt, ítxu, तिज_, بەرچ, 
   {{0x44200489,0x629921f3,0x00000000,0x00000000}},	//   azh_, _deuo, --, --, 
   {{0x45d800c8,0xfba80490,0x442121f4,0x00000000}},	//   _פֿרא, _किंम, bzh_, --, 
   {{0x7af40c3a,0x7d0c03a2,0x2b480784,0x7a0c0064}},	//   _onyt, _ïasy, yocc_, lėtą, 
   {{0xefe80201,0x690804cc,0x00000000,0x00000000}},	//   _ሆነው_, _jüer, --, --, 
   {{0x7a0c0064,0x00000000,0x00000000,0x00000000}},	//   nėtą, --, --, --, 
   {{0x7af521f5,0xad2400c6,0x6ff41867,0x629921f6}},	//   _anyt, تربو, _وساط, _zeuo, 
   {{0xceb81cd1,0x106802dd,0x2fdc0112,0x5cc0010b}},	//   _ләп_, _اڭشى_, _ustg_, фсыз, 
   {{0x74c8197c,0xdce0012d,0x00000000,0x00000000}},	//   स्तृ, _minę, --, --, 
   {{0xad240e26,0x00000000,0x00000000,0x00000000}},	//   _ورتو, --, --, --, 
   {{0x257c0142,0xa3a8107c,0x00000000,0x00000000}},	//   _rîl_, _खिल_, --, --, 
   {{0xa2d80574,0x7b3121f7,0x187402e8,0x63b400d7}},	//   _नसल्, tāut, дгря, xuxn, 
   {{0xbbe8df9e,0x257c0142,0x44200165,0x415c0092}},	//   _درهم_, _pîl_, vzh_, ሄረሰቦ, 
   {{0x690800f7,0x0e5402d3,0x629816b8,0xfdec033f}},	// [1b750] _qües, _ምትእም, _reuo, जियस_, 
   {{0x6298003a,0xbebc0153,0x00000000,0x00000000}},	//   _seuo, liūt, --, --, 
   {{0x442003bd,0x690804cc,0x7b3000b0,0x00000000}},	//   uzh_, _wües, māur, --, 
   {{0x44200ad3,0x690804cc,0xd8380030,0xddd80356}},	//   rzh_, _güer, úče_, ncuţ, 
   {{0x237c08ad,0x09c80183,0x15a802e8,0x6360000d}},	//   _čuju_, শিকা, _мъри_, hõng, 
   {{0x673804b9,0x29000bc9,0x220002b5,0x88600092}},	//   čuju, njja_, _rūhā_, _ለቤተሰ, 
   {{0xd9a921f8,0x629921f9,0x43941606,0x68e00162}},	//   _कट्ट, _teuo, _хабс, _óndu, 
   {{0x43942c1d,0x22000374,0x7b3000b0,0x8e2001ec}},	//   _маҳс, _pūhā_, hāur, _кiм_, 
   {{0x2734025c,0x00000000,0x00000000,0x00000000}},	//   għni_, --, --, --, 
   {{0x7af521fa,0xa2c0276a,0xa3dc000d,0xc0c4008e}},	//   _snyt, रभक्, _थना_, _хәди, 
   {{0x225c0175,0x80c0009e,0x61e801bf,0x7c9400f2}},	//   _hzuk_, _এসপ্, lvgl, يشگا, 
   {{0x3ce400b5,0x98c00205,0x0eb80024,0xff251211}},	//   sdlv_, _ısıl_, _душы_, _عبای, 
   {{0xe9a001b9,0xbd881bf4,0x00000000,0x00000000}},	//   наяп, _انتن_, --, --, 
   {{0x5fbc0316,0x690805d5,0x29000023,0x0d480691}},	//   _एमाल, _süer, gjja_, _وشوي_, 
   {{0x9ba00075,0x690804cc,0x69c8000d,0xacf8011a}},	//   _تەجى, _püer, _ägen, _להסכ, 
   {{0x29000083,0x7af4143a,0x37880107,0xbebc0153}},	//   ajja_, _unyt, ибҳо_, ciūt, 
   {{0xf1d8068f,0xd6d003d4,0x762400c7,0x8b640244}},	// [1b760] _मैंन, ৱালয, чмаз, _تاوم, 
   {{0xbebc0055,0x00000000,0x00000000,0x00000000}},	//   bhūg, --, --, --, 
   {{0x3c2001c0,0xa8780302,0x690804cc,0x3878054e}},	//   _eгvv_, _לאיר, _tüer, _igpr_, 
   {{0xd5b0c67c,0xf7440e91,0xe28006ed,0x6608002e}},	//   _لہر_, _хемо, елци, ëlkë, 
   {{0x67382e31,0x4ac000dc,0x249000b5,0xc2e8007b}},	//   čujt, ष्टव, bbxm_, تعلم_, 
   {{0x2d80012c,0x00000000,0x00000000,0x00000000}},	//   íkem_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x5ea00131,0xc0581cb8,0xddd8031c,0xa2e001f0}},	//   ىمىل, ціі_, bbuż, _посд, 
   {{0xa1240131,0xdea001d5,0xdcf800ef,0x00000000}},	//   تكۈل_, ریوی, bruļ, --, 
   {{0xdd8c0046,0x40f000c7,0x0108004b,0xaa7802f0}},	//   _үш_, _аҧшр, _وتلو_, rdým, 
   {{0xdfcc774e,0x0cc4024a,0x09d40073,0x00000000}},	//   _ميل_, वभौम, धब्य, --, 
   {{0xc1c80014,0x636000c5,0x00000000,0x00000000}},	//   _دبہٕ_, rõng, --, --, 
   {{0x29000054,0x7b3000b0,0xddd80356,0xbebc00c0}},	//   tjja_, tāur, rcuţ, riūt, 
   {{0xb4e4038e,0xddd8084c,0xbebc0153,0x66180210}},	//   भयो_, scuţ, siūt, _żuko, 
   {{0xd7f8a6c7,0xd9109831,0xbebc002b,0x00000000}},	//   пут_, ایپ_, bhūd, --, 
   {{0x29000083,0xdc38011a,0xbebd046d,0x00000000}},	//   sjja_, _לעור, liūr, --, 
   {{0x8574009d,0xe9a801f7,0x00000000,0x00000000}},	// [1b770] длах, _ادبن_, --, --, 
   {{0xe61c00a9,0x9f440419,0x00000000,0x00000000}},	//   _ffôn_, rvné_, --, --, 
   {{0xd49801c6,0xdcf8025c,0xb464010a,0x00000000}},	//   ярт_, nsuġ, çкал, --, 
   {{0x636000c5,0x0cd800cc,0x94840166,0xd32401c4}},	//   kõne, তায়ত, _җырд, ньчи, 
   {{0xbebc0024,0x52741e87,0xeabc003a,0x95d8005b}},	//   kiūr, нушу, liùs_, _едят_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x225c009f,0x1ee400e5,0x00000000,0x00000000}},	//   _tzuk_, سوخی_, --, --, 
   {{0x225c5848,0x00000000,0x00000000,0x00000000}},	//   _uzuk_, --, --, --, 
   {{0xee3476a9,0x00000000,0x00000000,0x00000000}},	//   ьны_, --, --, --, 
   {{0x3c6410f5,0x7e780208,0x00000000,0x00000000}},	//   ьког, _tgwp, --, --, 
   {{0xaa7800e4,0x00000000,0x00000000,0x00000000}},	//   ndýh, --, --, --, 
   {{0xed4c98a4,0xddc8033f,0x00000000,0x00000000}},	//   _ао_, _wygł, --, --, 
   {{0xed600153,0x2a7c00d7,0x00000000,0x00000000}},	//   gužę_, ľuba_, --, --, 
   {{0xc5b80327,0x3b0810ea,0x3b8401d5,0x00000000}},	//   _པཀྴི, _меко_, _ўлиг, --, 
   {{0x2c080316,0x7b040077,0xaa4c063f,0x00000000}},	//   ाहरू_, _lóuz, ụgụt, --, 
   {{0xe5a076a6,0x8c3c70f7,0x6440000f,0xeb300137}},	// [1b780] кити, mağa, ûnin, _جىيد, 
   {{0x8c3d21fb,0x00000000,0x00000000,0x00000000}},	//   lağa, --, --, --, 
   {{0xf770154b,0x68f8011a,0x00000000,0x00000000}},	//   _لاح_, _וליה, --, --, 
   {{0xf7700244,0x00000000,0x00000000,0x00000000}},	//   _جاخ_, --, --, --, 
   {{0x3168df65,0x7164007b,0x00000000,0x00000000}},	//   ошко_, واتك, --, --, 
   {{0xde340092,0x508521fc,0xdce0013a,0x8c3c0139}},	//   _እስካል, راتې, _vině, hağa, 
   {{0x63801f10,0x74143bd7,0x00000000,0x00000000}},	//   _агса, _غورا, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8c3c03be,0x6fd40451,0xbebc0153,0x1d940050}},	//   dağa, _ڊزائ, tiūr, وٝٹھ_, 
   {{0x5ed80f22,0x00000000,0x00000000,0x00000000}},	//   ভাগে, --, --, --, 
   {{0xa1100aa0,0xccf80316,0x6ea800a7,0x7b30b1a8}},	//   _جولت, dmět_, _дълг_, tāup, 
   {{0xadb42309,0x63600254,0x8e20030d,0x00000000}},	//   _قۇبا_, põne, _кiа_, --, 
   {{0xeabc0ffb,0xda780209,0xaa780124,0xdcf80135}},	//   rgù_, дяр_, ndýi, ssuġ, 
   {{0xeabc0393,0xac940133,0x00000000,0x00000000}},	//   tiùs_, _تۆدا_, --, --, 
   {{0x1cb8011a,0x25b80477,0x57a40024,0x195800c0}},	//   _ומוע, wuql_, кшта, фары_, 
   {{0x6d5921fd,0x96f921fe,0xd6d8f60a,0x8c3c0213}},	//   llta, мест_, мту_, cağa, 
   {{0x6d5921ff,0x1634082d,0x95c80064,0x26d8009a}},	// [1b790] olta, ветя, духа_, reqo_, 
   {{0x6d592200,0x26d80117,0xaa7802d2,0x00000000}},	//   nlta, seqo_, ddýi, --, 
   {{0x6d592201,0x9b442832,0xdce001e4,0x82d801ec}},	//   ilta, _سنیو, _ninĝ, здес_, 
   {{0x6d592202,0xae0c0dad,0xa2300139,0x00000000}},	//   hlta, िहान_, кьлә, --, 
   {{0xe4a401c6,0xb194008e,0xe5c401a9,0x00000000}},	//   _орво, елчә, _ўсмо, --, 
   {{0xa2d8012c,0x6d583c63,0x6afc0327,0x8c3c03e0}},	//   _नसक्, jlta, _ཞོའོ_, zağa, 
   {{0x44240623,0x6fb12203,0x27340327,0x8c3c0205}},	//   _ål_, هموا, sħnu_, yağa, 
   {{0x6d592204,0xde34044e,0xaa78010e,0x00000000}},	//   elta, _ክትከው, neýd, --, 
   {{0x7b0c0943,0x53340046,0x41b41d93,0x64cc0490}},	//   ṱuka, _ретт, _سمار, स्थळ, 
   {{0x6d59078a,0x518424cd,0xfc041536,0x00000000}},	//   glta, _јута, епоо, --, 
   {{0x2bc4010b,0x6d540055,0x8c3c236c,0xaa7800a2}},	//   нлэп_, _īyat, tağa, keýd, 
   {{0x6d580876,0x8fd40ce8,0x00000000,0x00000000}},	//   alta, _рәшә, --, --, 
   {{0x8c3c0724,0x955c0092,0x01cc00eb,0x00000000}},	//   rağa, ዳለብን_, লিকদ, --, 
   {{0x6d5803ac,0xbebc00b8,0x00000000,0x00000000}},	//   clta, bhūc, --, --, 
   {{0x3fbc0c58,0xec101eeb,0x8d748e87,0x8c3c0e2d}},	//   _আনুষ, _موود, _شاها, pağa, 
   {{0x66e12205,0x7c2c0c09,0x8c3c06be,0x00000000}},	//   лоса, _ƙarf, qağa, --, 
   {{0x3a2400b5,0x00000000,0x00000000,0x00000000}},	// [1b7a0] _åop_, --, --, --, 
   {{0x9b440451,0x37e401c6,0x00000000,0x00000000}},	//   _سنڌو, _зоог, --, --, 
   {{0x28980a7c,0x1c0c0037,0xaa7800a2,0x00000000}},	//   _מייא, ाहिल_, beýd, --, 
   {{0x1cdc0135,0x73740022,0x00000000,0x00000000}},	//   _སྒལ_, хызх, --, --, 
   {{0x6d592206,0xdce001e4,0xe4c000d1,0xf77000db}},	//   ylta, _sinĝ, _әйси, _لاڭ_, 
   {{0x1c0c0cb4,0xf5080276,0xd0d402e8,0xaa780432}},	//   ाहाल_, _энгл_, токъ, meýe, 
   {{0xf8d007b7,0x6d580175,0xf41803d4,0xaa78010e}},	//   द्यय, vlta, _দশকৰ_, leýe, 
   {{0x50640022,0x00000000,0x00000000,0x00000000}},	//   нтқа, --, --, --, 
   {{0xb14431d5,0x39843657,0xc32c02dd,0x6d5801ab}},	//   _знал, _nôs_, _بەن_, tlta, 
   {{0x66180327,0x6d592207,0xaa7800c7,0x6d540055}},	//   _żukk, ulta, ndýv, _īyas, 
   {{0x6d5801bf,0x86300092,0x251800df,0x00000000}},	//   rlta, _በዘንድ, פוטא, --, 
   {{0x5884c5dc,0xd1e00023,0xaa7800a2,0x00000000}},	//   ғыра, _ጓሶት_, keýe, --, 
   {{0xdd8d2208,0x29880801,0x80d40d79,0x2bd0000d}},	//   _هون_, ясно_, _मॉडे, _तहवा, 
   {{0x83780201,0xf454022e,0x1d052209,0x39840142}},	//   _እነዚህ_, _bog鼠, _печи_, _dôs_, 
   {{0x98480801,0x3984003a,0x7d1c0af2,0x00000000}},	//   еята_, _eôs_, êsse, --, 
   {{0x6020002e,0x9f440419,0xc0340240,0x00000000}},	//   _jёma, yvní_, _እንብለ, --, 
   {{0x7c2c0198,0x6ed000dc,0x00000000,0x00000000}},	// [1b7b0] _ƙarg, भ्यु, --, --, 
   {{0x48149cb8,0xdce00139,0x00000000,0x00000000}},	//   _амос, _minğ, --, --, 
   {{0x0fdc32ed,0x2ba407d0,0xc60800eb,0x00000000}},	//   _मनगढ, _कौमा, _রেখা_, --, 
   {{0x823800d8,0x00000000,0x00000000,0x00000000}},	//   мзес_, --, --, --, 
   {{0xe5c4fd77,0x069002dd,0xdb0801d3,0x8ae806be}},	//   _ясно, _ﭘﻪﻳﯩ, álék, llәs, 
   {{0xccf8012c,0x7bc40158,0x5da80150,0x00000000}},	//   změr_, _åhug, _ﺳﻪﻛﺴ, --, 
   {{0x25500166,0x8c3c0139,0x00000000,0x00000000}},	//   _eşlä_, dağo, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd1d40240,0x00000000,0x00000000,0x00000000}},	//   _ከሰተ_, --, --, --, 
   {{0x39840798,0x6288067c,0x1ee417a5,0xe6c802c3}},	//   _pôs_, ncgo, _سوتی_, ाभोज, 
   {{0xf454022e,0x0d841cd0,0x2d740210,0xd9dc01f9}},	//   _sog鼠, _блін, _złem_, यबेट, 
   {{0x60c007ab,0x3dcc013f,0x9cc800c7,0x0e6412fa}},	//   ngnm, mtew_, _хыда_, _скін, 
   {{0xdb240332,0x8c3c0205,0x00000000,0x00000000}},	//   ásód, nağl, --, --, 
   {{0x65c400b0,0x37e408ca,0x2b0000ce,0x00000000}},	//   kūhā, ноҳг, षाणु_, --, 
   {{0x1cdc0c99,0x3dcc0134,0x80e0033f,0x00000000}},	// [1b7c0] _སྒོ_, ntew_, फ़ाइ, --, 
   {{0x98b802b5,0xa5200107,0x00000000,0x00000000}},	//   rorē_, амуд, --, --, 
   {{0xc1a40150,0x00000000,0x00000000,0x00000000}},	//   ңышқ, --, --, --, 
   {{0xdce03421,0x3dcc007f,0x437400cf,0x8c3c1cce}},	//   _minđ, ktew_, гучт, dağl, 
   {{0xdce0107d,0x30a001ec,0xf1f8007b,0x20280092}},	//   _linđ, иғағ, بعات_, _እንሞክ, 
   {{0x985c00de,0x00000000,0x00000000,0x00000000}},	//   _lāča_, --, --, --, 
   {{0xb4dd220a,0x6360007d,0x1fa1220b,0x1cdc031c}},	//   ढ़ी_, sõna, арыг, _སྒེ_, 
   {{0x91c400d1,0x00000000,0x00000000,0x00000000}},	//   _бәкл, --, --, --, 
   {{0x3eb800c6,0x00000000,0x00000000,0x00000000}},	//   ósta_, --, --, --, 
   {{0x8c3c3535,0xab840022,0x2d740210,0xeae8000d}},	//   bağl, кумк, _złej_, _जोड़त_, 
   {{0x9fc40022,0x3eb80024,0xaec44bcc,0x5fbc3d1d}},	//   _агха_, ųsta_, _абел, _एमएल, 
   {{0xddcd220c,0x63a0002d,0x80b001ec,0x33240051}},	//   žešk, ânni, _نەۇش, nhox_, 
   {{0x27240254,0x320400e4,0x6360000d,0x0cd400d4}},	//   _hõng_, nxoy_, kõnn, _болю, 
   {{0x7d1c01c7,0x00000000,0x00000000,0x00000000}},	//   ësst, --, --, --, 
   {{0x7c2c02a8,0xf8d000dc,0xeb4801b9,0xad440228}},	//   _ƙare, द्धय, _очик_, _كىچۉ, 
   {{0x99e40030,0x00000000,0x00000000,0x00000000}},	//   žňav, --, --, --, 
   {{0x7bc400b0,0x2725220d,0xc6080154,0x69080790}},	// [1b7d0] _ähur, _lõng_, _রেজা_, _müez, 
   {{0xed6c0020,0x8c3c03e0,0x00000000,0x00000000}},	//   _ትብብር_, yağl, --, --, 
   {{0x38980375,0x69cc0334,0x1bf81c5d,0x53a4007b}},	//   _איתנ, ltce, एमएल_, لملك, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69cd220e,0x8c3c0205,0x00000000,0x00000000}},	//   ntce, dağm, --, --, 
   {{0x65c402b5,0x88440092,0x6288007c,0x00000000}},	//   rūhā, _ከቤተሰ, scgo, --, 
   {{0x69cc005a,0x2724004d,0x00000000,0x00000000}},	//   htce, _cõng_, --, --, 
   {{0xfde80209,0x3e4c02d3,0x187c0375,0x27240051}},	//   едик_, _ዕስክር, וטוב, _dõng_, 
   {{0xdce00114,0x04440139,0x0094009d,0x4f0401ec}},	//   _sinđ, _реңн, _бизэ, ржығ, 
   {{0xd24400ee,0x3dcc0327,0xbebc0055,0x00000000}},	//   _тэси, rtew_, chūn, --, 
   {{0xfaa5220f,0x3dcc48ba,0x27240254,0x6d442cc3}},	//   лано, stew_, _kõnd_, ékaa, 
   {{0x3f840618,0x69cd2210,0xce340133,0xa3a80210}},	//   _iulu_, ftce, اویک, _गबन_, 
   {{0x27240037,0x69cc01bf,0x00000000,0x00000000}},	//   _mõnd_, gtce, --, --, 
   {{0x3f852211,0x00000000,0x00000000,0x00000000}},	//   _kulu_, --, --, --, 
   {{0xc81410f5,0x3f844beb,0xa964a641,0x00000000}},	//   аєть, _julu_, уира_, --, 
   {{0x7bc12212,0x3f852213,0x6908453a,0x00000000}},	//   mulu, _mulu_, _müey, --, 
   {{0x3f852214,0x4ad80014,0x69cc01f5,0x55c40150}},	// [1b7e0] _lulu_, _شاٹھ_, ctce, разғ, 
   {{0xb4dc45bf,0x3f852215,0x7bc00051,0xe3dc012d}},	//   ढ़े_, _oulu_, oulu, नबूझ, 
   {{0x7bc12216,0xded01ee0,0x6360000d,0x580401af}},	//   nulu, ያንና_, rõnn, _тонғ, 
   {{0xb2252217,0x7bc00276,0x636000af,0x23240c60}},	//   лмел, iulu, sõnn, лохи_, 
   {{0x7bc04ec2,0x3f840b23,0xddc80118,0x6360000d}},	//   hulu, _aulu_, _tygř, põnn, 
   {{0x7bc12218,0x3f852219,0xdce000da,0x96d00c4c}},	//   kulu, _bulu_, _minē, ड्रॉ, 
   {{0x7bc1221a,0x3f85221b,0x69c80793,0x845801ee}},	//   julu, _culu_, _ägev, _артт_, 
   {{0x7bc1221c,0x3f845088,0x4dd80f22,0x272401fb}},	//   dulu, _dulu_, তিসং, _võng_, 
   {{0x273c0724,0xdeec0032,0x23240116,0x7bc0017a}},	//   länä_, _һы_, _соти_, eulu, 
   {{0x7bc1221d,0x3f85221e,0x1dd4007b,0x3f640150}},	//   fulu, _fulu_, ابيع_, лтөб, 
   {{0x3f840925,0x5d50084c,0x69cc0142,0x273c01f4}},	//   _gulu_, скэт, wtce, nänä_, 
   {{0x317c0323,0x6da40cfc,0x6b88001f,0x272400c5}},	//   _hitz_, _бида, _አደረገ_, _kõne_, 
   {{0x3f85221f,0x2d9418a4,0x273c01f4,0x98b80064}},	//   _zulu_, _срес, hänä_, norė_, 
   {{0x2724007d,0xeabc04cc,0x4bc40026,0xb4dc0037}},	//   _mõne_, chùn_, _көмг, ढ़ो_, 
   {{0x7bc12220,0x3f840117,0xc03402d3,0x273c023a}},	//   culu, _xulu_, _እንተለ, jänä_, 
   {{0xcb692221,0x317c005a,0x98b80064,0x00000000}},	//   _جمعه_, _litz_, korė_, --, 
   {{0x6aa80183,0xe8702586,0x00000000,0x00000000}},	// [1b7f0] _কাপো, _گندگ, --, --, 
   {{0x317c0194,0x2004022e,0x98b800c0,0x00000000}},	//   _nitz_, yxni_, dorė_, --, 
   {{0xb9780375,0x9cd4011a,0x273c0139,0x00000000}},	//   _שנתי, רובה_, gänä_, --, 
   {{0x291018f7,0x317c005a,0xc29002d3,0xd68400ee}},	//   _hoxa_, _aitz_, _ዝበዝሐ_, _гурп, 
   {{0x7bc0b05f,0x3f852222,0x29100564,0xf8d00882}},	//   zulu, _sulu_, _koxa_, द्वय, 
   {{0x3f84ece3,0x7bc12223,0xe6640117,0x00000000}},	//   _pulu_, yulu, _атҳо, --, 
   {{0x7bc12224,0x317c1497,0x6fb41cd1,0x7e0c0864}},	//   xulu, _ditz_, ңгәр_, ाङ्ग_, 
   {{0x7bc12225,0x2d8401ee,0x3f84006a,0xe0d01893}},	//   vulu, _buoe_, _vulu_, _گزر_, 
   {{0xdb092226,0x7bc12227,0xdce000b8,0x4f080222}},	//   álík, wulu, _ahnā, اتىپ_, 
   {{0x3f852228,0x29112229,0xdb040139,0x317c03e0}},	//   _tulu_, _noxa_, _kvnç, _gitz_, 
   {{0x237c1a4c,0x225c248b,0x92e80183,0x7bc00194}},	//   _kiuj_, _hyuk_, বাৰ_, uulu, 
   {{0x7bc1222a,0x2d8401e0,0x9b04016c,0x6020002e}},	//   rulu, _fuoe_, сҷид, _jёmm, 
   {{0x2911222b,0x237c0369,0x99e40030,0xf9840395}},	//   _boxa_, _miuj_, ľňov, ргго, 
   {{0x2911222c,0x99e402fb,0xd1d40092,0x00000000}},	//   _coxa_, žňov, _ከደቀ_, --, 
   {{0x26c9222d,0x225d222e,0x7bc1222f,0xdce00055}},	//   _bcco_, _lyuk_, qulu, _ghnā, 
   {{0xd9112230,0x273c049b,0x225c0205,0x9c540117}},	//   _کیس_, vänä_, _oyuk_, _ишқу_, 
  
   {{0x29112231,0xe614040e,0x225c020c,0xaa7800a2}},	// [1b800] _foxa_, адт_, _nyuk_, leýn, 
   {{0x33f4165d,0x26c806bb,0x799403ac,0x273c0108}},	//   ичес, _ecco_, _ityw, tänä_, 
   {{0x317d2232,0x225c020b,0xf1a801e2,0x00000000}},	//   _ritz_, _ayuk_, چاته_, --, 
   {{0x225c0066,0x237c0115,0x317c03fa,0x98b80006}},	//   _byuk_, _ciuj_, _sitz_, torė_, 
   {{0x317d2233,0x69c8014a,0x6aa804c5,0x273c023a}},	//   _pitz_, _äget, _কামো, sänä_, 
   {{0xe5a00aa5,0x29112234,0x273c0108,0x98b800c0}},	//   _фири, _xoxa_, pänä_, rorė_, 
   {{0x317c067c,0xceb800fd,0xd25108c4,0xaa780022}},	//   _vitz_, гәл_, _کچا_, jeýn, 
   {{0x317c1021,0xbebc0882,0x4208104e,0x41b000db}},	//   _witz_, bhūm, тмәү_, زۅۅر, 
   {{0x7994009a,0x8e840022,0x8c3c06be,0x00000000}},	//   _ntyw, аҳҵе, maği, --, 
   {{0x6440068f,0xf1880131,0x7170113e,0x6e3400c0}},	//   źnie, _ﻗﻮﻳﯘ, _بۇتا, _žybs, 
   {{0x237c0007,0x7c2c0c09,0x291010d8,0x2ba40034}},	//   _yiuj_, _ƙara, _roxa_, _कौशा, 
   {{0xee392235,0x2910022e,0x00000000,0x00000000}},	//   _ине_, _soxa_, --, --, 
   {{0x8d940597,0x2910617f,0x80cc44eb,0x7f600220}},	//   _التش, _poxa_, _सामे, _ﻗﺒل_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe784647b,0x799401e2,0x6f00fb81,0x2bc802e8}},	//   руго, _etyw, _knoc, _руло_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x29100005,0xfd54002b,0x44b43004,0x98b80139}},	// [1b810] _toxa_, _amaṅ, йбас, _äzğa_, 
   {{0x998401d3,0x00000000,0x00000000,0x00000000}},	//   _گلیو, --, --, --, 
   {{0x6f00ccf1,0x6d480200,0x00000000,0x00000000}},	//   _onoc, _mjfa, --, --, 
   {{0x6f012236,0x256c00af,0x69c80793,0x850405f9}},	//   _nnoc, külg_, _äges, राहट_, 
   {{0xe4a4009b,0x00000000,0x00000000,0x00000000}},	//   _врбо, --, --, --, 
   {{0x6f012237,0xe3b01e95,0x00000000,0x00000000}},	//   _anoc, _ورز_, --, --, 
   {{0x237c04ac,0x4fc400d1,0x02600133,0x2fd40244}},	//   _tiuj_, قەلە, _کێشێ, موود_, 
   {{0x3adc02b1,0x85044103,0x6f012238,0xa51400dc}},	//   _kāpō_, रावट_, _cnoc, _दकुच_, 
   {{0x225c003e,0x6f000419,0xcee8007b,0x53380354}},	//   _uyuk_, _dnoc, شرين_, _турă, 
   {{0x61f8005a,0xd25000f1,0x5184005b,0x7d080114}},	//   _irul, _ځنې_, _фута, уног_, 
   {{0x7f840597,0x799405e4,0x61f92239,0x00000000}},	//   _الصن, _styw, _hrul, --, 
   {{0x6f01223a,0x61f9223b,0x7d2404fb,0x80cc0490}},	//   _gnoc, _krul, _گفتن, _साडे, 
   {{0x3eac0a64,0x13e0009e,0x8a3801c6,0xabd001d9}},	//   maet_, ণিয়, аярт_, _ہٲوت, 
   {{0x8a380cb9,0x3eac0489,0x00000000,0x00000000}},	//   ряют_, laet_, --, --, 
   {{0x98440201,0x2ba420f0,0x6f01223c,0xd0380092}},	//   _የትምህ, कीदा, _ynoc, _እንደቆ, 
   {{0x3eac0489,0x3ce40fac,0xe735223d,0xfd4c0051}},	//   naet_, lelv_, бес_, _nhoẹ, 
   {{0x7ae40365,0x68e00a85,0x7994004b,0xb8ec015b}},	// [1b820] mekt, _űnde, _utyw, _রস_, 
   {{0x3eac0007,0xade800af,0x5ed800eb,0x00000000}},	//   haet_, _जईसन_, _মোমে, --, 
   {{0x3eac03bd,0x61f80098,0x69c80724,0x941800ac}},	//   kaet_, _arul, _äger, _yerə_, 
   {{0x61f9223e,0xf154804b,0x78ac00de,0xfd4c0051}},	//   _brul, әпкә_, labv, _choẹ, 
   {{0x7ae40323,0xf675223f,0xaa780432,0x00000000}},	//   iekt, _دادخ, jeýl, --, 
   {{0x7ae52240,0x61f801a8,0x3ce408fb,0x644000d8}},	//   hekt, _drul, jelv_, únic, 
   {{0x64a12241,0x74152242,0xaf34044e,0x61f80ffb}},	//   _хаса, _اوزا, _ክህልወ, _erul, 
   {{0xb8c81b4b,0x61f85bd9,0x78ad2243,0x7c2c02a8}},	//   _བབ_, _frul, habv, _ƙarn, 
   {{0x78ac0e8a,0xa63800c8,0xd038001f,0x61f803b2}},	//   kabv, ָגיר, _እንዲቆ, _grul, 
   {{0xdce00006,0xdce80024,0x8bd800f3,0x00000000}},	//   _minė, _mugė, амос_, --, 
   {{0x3eac0280,0x78ac0810,0xceb80116,0xee8400c7}},	//   baet_, dabv, _кәп_, _лыло, 
   {{0x6f012244,0x7ae428be,0x3eac0369,0x256c01b8}},	//   _unoc, gekt, caet_, müle_, 
   {{0x29040086,0x941800ac,0x889401c6,0xdb140432}},	//   _ònak_, _verə_, жигх, _çaýd, 
   {{0x78ac006f,0xaa60001f,0xbd540133,0x6d480205}},	//   gabv, _ማድረጋ, _وروژ, _ujfa, 
   {{0x6d592245,0x7ae52246,0x00000000,0x00000000}},	//   mota, bekt, --, --, 
   {{0x7ae40365,0xd3640075,0x8698be81,0xb3cc0154}},	//   cekt, _سۇ_, ркас_, রবাজ, 
   {{0xe6640b46,0xdb2400dd,0xc5392247,0xa48400c6}},	// [1b830] ство, _írás, апах_, مجان, 
   {{0x6d592248,0x6aac007b,0x256c0112,0x3eac030a}},	//   nota, lacf, küle_, zaet_, 
   {{0x68e52249,0x1aec015b,0x6d5800b0,0xade800c5}},	//   mejd, টারে_, iota, _जैसन_, 
   {{0x61f80385,0x6d59224a,0x256c0205,0x49480023}},	//   _prul, hota, düle_, _ያእቆብ, 
   {{0x0085224b,0x3eaceccf,0x3ce400e5,0x00000000}},	//   олло, vaet_, yelv_, --, 
   {{0x68e42d2b,0x7ae40585,0x6d59224c,0x8504608a}},	//   nejd, zekt, jota, _بوسن, 
   {{0x7ae5224d,0x6d59224e,0xb9240521,0x3eac0489}},	//   yekt, dota, _agwọ_, taet_, 
   {{0x61f9224f,0xd1f00092,0xade80037,0x00000000}},	//   _trul, ቁሶች_, _जैहन_, --, 
   {{0x6b880f2a,0x3ead2250,0x6d592251,0x61f92252}},	//   _aufg, raet_, fota, _urul, 
   {{0x6d592253,0x8d280724,0x7ae52254,0x3ead2255}},	//   gota, йның_, wekt, saet_, 
   {{0x68e52256,0x78ac0433,0x3ce40037,0x3b0806ed}},	//   dejd, vabv, relv_, аено_, 
   {{0xf9f40135,0x6d580607,0x78ac0099,0x3ce4005c}},	//   _བླུན_, aota, wabv, selv_, 
   {{0xa9a07ef9,0xe9a0036b,0xdce8025c,0x673c01a9}},	//   мияд, маяп, _ntgħ, diqj, 
   {{0x6d592257,0x17c8013e,0x6aac0175,0xbc38009f}},	//   cota, бҳои_, aacf, _پستا_, 
   {{0x272400af,0x7f48b0b3,0x37380dce,0xdce800c0}},	//   _sõna_, oneq, ачаю_, _sugė, 
   {{0x7f480680,0x28d81bd6,0x78ac006f,0x35a401c6}},	//   nneq, म्बि, sabv, жааг, 
   {{0x68e4105c,0xb4a84205,0x7f480140,0x850402ab}},	// [1b840] bejd, иказ_, ineq, रांट_, 
   {{0x7bc00eda,0x6b8c05d1,0x37e401c0,0xb7e422c3}},	//   orlu, _öngö, _доог, _джок, 
   {{0x753d2258,0x11140075,0x1cdc025c,0x00000000}},	//   ripz, ۋېرس, _སྒབ_, --, 
   {{0x6d592259,0x528801e0,0xb88002f0,0xa3a80037}},	//   zota, сҡан_, _číha, _गबर_, 
   {{0x6d59225a,0x6d4400f2,0x00000000,0x00000000}},	//   yota, ékak, --, --, 
   {{0xf8a80c2e,0x6d5801c0,0x6440033f,0x00000000}},	//   करिय, xota, źnia, --, 
   {{0x6d59225b,0xe978010f,0xa50400d8,0x00000000}},	//   vota, בנסש, _ќеса_, --, 
   {{0x6d59225c,0x68e4068f,0x7f49004a,0x9f400241}},	//   wota, zejd, gneq, _èjì_, 
   {{0x7bc020ac,0x41d0012c,0xae180073,0xf8a816ae}},	//   erlu, _समयस, _फॅशन_, कराय, 
   {{0x7f4820ac,0x20c006d3,0x256c85e1,0x00000000}},	//   aneq, _ойум, püle_, --, 
   {{0xe61c0016,0xddc8010b,0x00000000,0x00000000}},	//   _ngôn_, _tygş, --, --, 
   {{0x6d59225d,0x78a000f3,0x2aa80137,0xdb0400d0}},	//   sota, _đova, штоо_, _zvnú, 
   {{0x7bc00af5,0x5a344294,0x9604012d,0x00000000}},	//   arlu, днят, रमोट_, --, 
   {{0x6d580050,0xaa780432,0x00000000,0x00000000}},	//   qota, leýk, --, --, 
   {{0x68e40724,0xfe6c0f31,0xd794011c,0x00000000}},	//   rejd, _لگی_, дисъ, --, 
   {{0x94180134,0xeacc0022,0x30c40154,0x2a6c0ca8}},	//   _werɛ_, _eỹre_, _এসোস, _ùgbo_, 
   {{0x80cc0034,0x68e401bf,0x00000000,0x00000000}},	// [1b850] सलमे, pejd, --, --, 
   {{0x85040d0a,0x04c80472,0x00000000,0x00000000}},	//   राइट_, صوصي_, --, --, 
   {{0x3eb802d5,0x91b00208,0x00000000,0x00000000}},	//   ųsti_, _đám_, --, --, 
   {{0x80cc7662,0xdce9225e,0xaa780124,0xb4a8000d}},	//   _साहे, _čiči, jeýk, _गड़ी_, 
   {{0x52740137,0x00000000,0x00000000,0x00000000}},	//   мушу, --, --, --, 
   {{0x612d225f,0x61e80142,0x7bc00042,0x00000000}},	//   _mølg, rwgl, yrlu, --, 
   {{0x28d06a60,0xb600025c,0xa3440064,0x00000000}},	//   _तानि, ġġed, _дэал, --, 
   {{0x7f480869,0x3eb8002d,0x00000000,0x00000000}},	//   uneq, ûst_, --, --, 
   {{0x7f480680,0x44200432,0x00000000,0x00000000}},	//   rneq, lyh_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7bc00357,0x81ac03d4,0x442000c7,0x2ba40118}},	//   urlu, _কমি_, nyh_, कीला, 
   {{0x612c5b47,0x2724000d,0x68e02ca8,0x6e2800e4}},	//   _bølg, _sõnn_, _ında, ãmbá, 
   {{0xb0d05020,0xa2d02dc5,0x2724000d,0x442000a2}},	//   _सामग, _डान्, _põnn_, hyh_, 
   {{0x6df000c6,0x81ac02f5,0x6360000d,0x4de0000d}},	//   _أكوا, _কমা_, mõnu, _कहतै_, 
   {{0x85040d79,0x6aa800eb,0x00000000,0x00000000}},	//   राईट_, _কারো, --, --, 
   {{0x612d2260,0xe7352261,0x91cc49fc,0x4420030a}},	//   _følg, пес_, _समलै, dyh_, 
   {{0x5bd80303,0x6440066a,0xbebc0882,0x612c0162}},	// [1b860] _बहुव, únin, bhūv, _køld, 
   {{0x7af481f1,0xb22401c0,0xe8f40229,0x3dbc00cc}},	//   _hayt, үмжл, _ель_, _অহাল, 
   {{0x7af52262,0x64a12263,0xe5a00116,0x612d2264}},	//   _kayt, хаха, _җиси, _møld, 
   {{0x7af40054,0xeb9400c8,0xe0cc0952,0x00000000}},	//   _jayt, לדער_, ۇزى_, --, 
   {{0x7af52265,0xf2e4004b,0xdce00171,0x98b0010f}},	//   _mayt, يکړه_, _cinī, ŭaĵo_, 
   {{0x7af52266,0x23440328,0xadf00307,0x741400e5}},	//   _layt, يلەپ_, _अनबन_, _ٹورا, 
   {{0x80cc0fe6,0xf1a802f2,0x44200210,0x00000000}},	//   _सारे, _گازه_, cyh_, --, 
   {{0x256c29ef,0x7af40ce1,0xc0340023,0x00000000}},	//   müla_, _nayt, _እንምል, --, 
   {{0xb2240108,0xfe74013e,0x9f6001d3,0x6aa80154}},	//   _эмал, мӯш_, ívás_, _কালো, 
   {{0x7af400e8,0x1d312267,0x3e680032,0xa3c005d7}},	//   _aayt, енья, өшөн_, _एटम_, 
   {{0x7af42c9e,0x9dd001ed,0xfbcc00ec,0xd5a4012d}},	//   _bayt, وزیش, لڪي_, _चौघड़, 
   {{0x7af43d3d,0xbebc139f,0xaa78010b,0x00000000}},	//   _cayt, lkūn, leýi, --, 
   {{0x7af52268,0x1cdc2fb5,0x612c06ea,0xce34036b}},	//   _dayt, _སྒམ_, _føld, _توشک, 
   {{0x256c00af,0xbebc0024,0xabb0035b,0x63800241}},	//   küla_, nkūn, _закә, _kìnì, 
   {{0xd14807ae,0xd7e40845,0x7af40009,0xdb040042}},	//   yễn_, ніто, _fayt, _gwnï, 
   {{0x5e600075,0x7af400ee,0x638001e1,0x00000000}},	//   _تۆۋە, _gayt, _mìnì, --, 
   {{0x572426a2,0x44f52269,0x612c03cd,0xe7ec000d}},	// [1b870] رىكك, мпас, _høle, _चनवा_, 
   {{0x612c04ce,0x28a43924,0x7af4155d,0x64880209}},	//   _køle, _эшиг, _zayt, ссаг_, 
   {{0x94a83740,0xccf80118,0xdce000b8,0xdce80055}},	//   ятта_, idě_, _sinī, _sugī, 
   {{0xaabc0c5a,0x68f40477,0x7af40548,0x612c0158}},	//   ्लिक, _haxd, _xayt, _møle, 
   {{0x7c2c02a8,0x442005b1,0x68f40009,0x95c800db}},	//   _ƙark, syh_, _kaxd, _нура_, 
   {{0x98b80356,0xdce000cd,0x00000000,0x00000000}},	//   miră_, _vinī, --, --, 
   {{0x612c2d8b,0xc03401f3,0xaabc2c2e,0x7fd4187f}},	//   _røld, _እንመል, ्लाक, філі, 
   {{0x68f46f68,0x998000a2,0x612c0174,0xbf34007b}},	//   _laxd, _eriň_, _søld, برتغ, 
   {{0x7af438bc,0x61400aaf,0x00000000,0x00000000}},	//   _rayt, _كىرە, --, --, 
   {{0x7af42994,0x9be42b88,0x68f401d9,0x63800241}},	//   _sayt, _འགྱོ, _naxd, _fìnì, 
   {{0x7af5226a,0x612c03b2,0x63600037,0xbc68009a}},	//   _payt, _vøld, sõnu, تمدن_, 
   {{0x7af5226b,0x41d00882,0x612c0217,0xb4e81d15}},	//   _qayt, _समास, _døle, _मस्_, 
   {{0x68f5226c,0x00000000,0x00000000,0x00000000}},	//   _baxd, --, --, --, 
   {{0x612c5d16,0x7af481f1,0xfce400f5,0x17c801f0}},	//   _føle, _wayt, _цоко, пҳои_, 
   {{0xb8f42413,0x9be40867,0xbebc0a28,0x7af5226d}},	//   _हा_, _འགྲོ, bhūt, _tayt, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xba7400aa,0x612c005c,0xc8c86241,0xba54030d}},	// [1b880] _ډاکت, _mølb, _کوپن_, _юткъ, 
   {{0x7c2c0198,0x64a008ca,0x00000000,0x00000000}},	//   _ƙarh, вафа, --, --, 
   {{0xb6040332,0x00000000,0x00000000,0x00000000}},	//   _bháú, --, --, --, 
   {{0x8454049e,0xfbc404fa,0x3ebc0369,0x1aec0f22}},	//   رىنچ, _विनम, _ndwt_, টাকে_, 
   {{0xe1ec0e26,0xb0d005f9,0x28d80864,0x63800248}},	//   لسو_, _सादग, म्वि, _sìnì, 
   {{0x70546884,0xb05403e6,0x00000000,0x00000000}},	//   ونشا, وپشت, --, --, 
   {{0x0fcc02a6,0x3d102e3c,0x06b0009e,0xbebc0024}},	//   লব্ধ, ताने_, _ছাতি, rkūn, 
   {{0xceb000ec,0xdb2401e1,0x00000000,0x00000000}},	//   اڙا_, _ìrès, --, --, 
   {{0x612c143a,0x626001c6,0x99d000cc,0x636000e4}},	//   _søle, _авта, িবুক, rõnt, 
   {{0x78bc02c4,0x21a0d5de,0xfa3c0023,0xdfcc00ec}},	//   _ndpv, _рифм, _ኣስላማ, _چيل_, 
   {{0xdfcc188d,0xccf80118,0x00000000,0x00000000}},	//   _نيل_, rdě_, --, --, 
   {{0x68f40014,0x2b980055,0x6204013d,0x6da400d4}},	//   _saxd, _nīce_, _ürlä, _жида, 
   {{0xf8a88109,0x00000000,0x00000000,0x00000000}},	//   करूप, --, --, --, 
   {{0x612c0158,0x68f5226e,0x1b2000cc,0x9f4001e1}},	//   _tøle, _qaxd, মোলে_, _éjò_, 
   {{0xd919226f,0xaa780124,0x68f454ad,0x00000000}},	//   фья_, jeýv, _vaxd, --, 
   {{0x442c0325,0x68f4058a,0xd6e80276,0xdce0013a}},	//   _āe_, _waxd, мфул_, _ohně, 
   {{0x68f52270,0x73c001e0,0x8654074d,0x00000000}},	// [1b890] _taxd, һәте, хках, --, 
   {{0x81ac045e,0xe4692271,0x6b7000d1,0xdb040042}},	//   _কমল_, ошел_, _ялқу, _gwnâ, 
   {{0x7c2c0c09,0x73c029db,0xc0c400c7,0x04300092}},	//   _ƙari, ләте, ҵәеи, _በዩጋን, 
   {{0x98b8054e,0x5b7c010f,0x00000000,0x00000000}},	//   piră_, ַרגא, --, --, 
   {{0xa1e800c6,0x5bd800dc,0x3d100dba,0x00000000}},	//   تراك_, _बह्व, तामे_, --, 
   {{0x44a52272,0x5504022e,0x00000000,0x00000000}},	//   _سمرق, _ичса, --, --, 
   {{0x13f4241e,0x1cc80327,0x94d42773,0x00000000}},	//   _изря, ྲཻལ_, _шорц, --, 
   {{0xbf642c04,0x98b80064,0x00000000,0x00000000}},	//   رگاو, mirą_, --, --, 
   {{0xcf2459e1,0xdb2401e1,0x00000000,0x00000000}},	//   ئرىي, _ìrés, --, --, 
   {{0x28dc03f3,0xa3c00034,0xfd1000c6,0x600801c6}},	//   _पॉलि, _एटा_, اجة_, _мхег_, 
   {{0x9418013f,0xdce001ef,0xbb4401f4,0x28d02c2e}},	//   _yerɑ_, _zhně, еенк, तलनि, 
   {{0xef0c0024,0x00000000,0x00000000,0x00000000}},	//   _ём_, --, --, --, 
   {{0xed4c187d,0x5e24165e,0xee2cd227,0xbc6801d5}},	//   _бо_, _تعاق, _сн_, تمگن_, 
   {{0x28d8278e,0xbebc0153,0x6d4400c7,0x00000000}},	//   म्लि, chūr, ékat, --, 
   {{0xed4c01d9,0x3dcc007f,0x0ba800cf,0xbb44010a}},	//   _دپو_, luew_, _قايى_, _пекк, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe7342cd4,0xfbc427c6,0xaa5400f3,0x00000000}},	// [1b8a0] хет_, _विडम, _пићу_, --, 
   {{0x62980607,0xadf000bc,0xe2940022,0x00000000}},	//   _afuo, _अनसन_, ҵац_, --, 
   {{0x72c40724,0xf7709aeb,0xd7640f1c,0xe8d40375}},	//   ебез, _ماح_, _لندی, _אויר_, 
   {{0xeb901a4c,0x256c01b8,0x290400a3,0x3d10000d}},	//   אָס_, bülo_, _ònar_, ताडे_, 
   {{0xd0d40395,0xdef80240,0x00000000,0x00000000}},	//   волъ, ሊኤን_, --, --, 
   {{0x323400c7,0x41d00bca,0x98b800c0,0x9f440419}},	//   _ҧхас, _समरस, birą_, rvný_, 
   {{0x52f40022,0x00000000,0x00000000,0x00000000}},	//   _ицаӡ, --, --, --, 
   {{0x9ed402e8,0xeda4bb65,0x00000000,0x00000000}},	//   емът_, ншоо, --, --, 
   {{0x256c0254,0x00000000,0x00000000,0x00000000}},	//   küll_, --, --, --, 
   {{0xe1f4013d,0x2ae000bc,0x5d50013d,0x3eb80210}},	//   _ягу_, ट्नु_, лкыт, óstr_, 
   {{0x63440109,0xb5d4009e,0xdef41954,0x00000000}},	//   lŕna, হবিচ, ላንካ_, --, 
   {{0xd1d00201,0x66e400b0,0x28d0023e,0xadb4129d}},	//   _ጥረት_, _kīkō, _ताहि, _كۇبا_, 
   {{0x6ea445c7,0x612c143a,0x68380092,0xaa7800c7}},	//   _ट्यु, _høla, _አስመስ, jeýt, 
   {{0x612c0174,0x00000000,0x00000000,0x00000000}},	//   _køla, --, --, --, 
   {{0x19580006,0x1ab003d4,0xd7c40108,0x00000000}},	//   хары_, _কাৰা, лёто, --, 
   {{0x6440033f,0x6aa800cc,0x00000000,0x00000000}},	//   źnik, _কাকো, --, --, 
   {{0x98580020,0x612c2d8b,0x256c002f,0x497401f4}},	// [1b8b0] _የድርጅ, _løla, büll_, _илис, 
   {{0x2724007d,0x69cc6a2a,0xd61807a7,0x6298468a}},	//   _mõni_, muce, رتقا_, _sfuo, 
   {{0x98c482f2,0x69cd2273,0xd4052274,0x612c0158}},	//   _ссыл, luce, ляци, _nøla, 
   {{0xd1f80092,0x1ab000cc,0x00000000,0x00000000}},	//   ጋጁት_, _কাৱা, --, --, 
   {{0xb5f00220,0xd6d8084c,0x69cd2275,0xaa78010e}},	//   _күті, _ятэ_, nuce, meýs, 
   {{0xe61d2276,0x612c3a26,0x016400a7,0xa2d00490}},	//   _ngôi_, _bøla, ъкло, _डाव्, 
   {{0x7ff40f87,0xb0d000ab,0x2fcc01ab,0x4424366f}},	//   ئستا, _सारग, gufg_, _æl_, 
   {{0x69cc6580,0x6298009f,0x612c143a,0xadf02e05}},	//   kuce, _ufuo, _døla, _अनशन_, 
   {{0x67200311,0x53340334,0xdea001d3,0x63c000fb}},	//   _înju, _сетт, پیڈی, _шаңҡ, 
   {{0x69cd2277,0x612c3619,0xfce40120,0x6d200022}},	//   duce, _føla, њоно, идыз, 
   {{0x7aa52278,0xbbbc0073,0xbebc00b8,0x00000000}},	//   кинз, ्ढेक, bhūp, --, 
   {{0xbb44040e,0xaa7800e4,0xe6240051,0x00000000}},	//   темк, jeýs, _phổ_, --, 
   {{0x69cc1096,0x572402dd,0x6d4c0010,0x00000000}},	//   guce, қпағ, čbar, --, 
   {{0x7aa00073,0x8cd81b61,0x00000000,0x00000000}},	//   _क्रॅ, _मायो, --, --, 
   {{0x28d028df,0x7c2c02a8,0xd7ac0490,0x9860001f}},	//   _तारि, _ƙaru, टींच, _ለትምህ, 
   {{0x69cd2279,0xe6240051,0xfe1401f9,0xd1d00092}},	//   buce, _thổ_, _तपास_, _ጥረቱ_, 
   {{0xb0d01fe5,0x69cc6c69,0xb50c03ba,0x00000000}},	// [1b8c0] _सालग, cuce, सालय_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x055400d4,0x00000000,0x00000000,0x00000000}},	//   уття, --, --, --, 
   {{0x7d0c0198,0xb2241586,0xa3d000d4,0xc7d800df}},	//   _ɗasa, кмел, роїч, _אַשכ, 
   {{0xbebc06c8,0xa2d00bc0,0x06742bb7,0x612c06ea}},	//   akūk, _डार्, _буря, _søla, 
   {{0xb48801e1,0x00000000,0x00000000,0x00000000}},	//   _ṣèyẹ_, --, --, --, 
   {{0x68e00274,0xd01000c6,0x8cd80073,0x69cc0210}},	//   _önde, صلة_, _माबो, zuce, 
   {{0x2b9807d7,0x27e40166,0x00000000,0x00000000}},	//   _nīca_, _änne_, --, --, 
   {{0x28d02cce,0xecb001e0,0x00000000,0x00000000}},	//   _तालि, аҡлы, --, --, 
   {{0x69cc08ad,0x612c03b2,0x2d880254,0x3f643947}},	//   vuce, _tøla, öbe_, ктөб, 
   {{0x69cc003c,0xdeed227a,0x5c70ff69,0x612c0162}},	//   wuce, _кы_, ильт, _køln, 
   {{0x69cc20ef,0x25b8002e,0xb0d028fe,0x00000000}},	//   tuce, ysql_, _साँग, --, 
   {{0x5ed800cc,0x00000000,0x00000000,0x00000000}},	//   _মোকে, --, --, --, 
   {{0x9d40ef40,0x00000000,0x00000000,0x00000000}},	//   _кечд, --, --, --, 
   {{0xa2d02208,0x69cccec4,0x98480006,0x00000000}},	//   _डाल्, suce, вята_, --, 
   {{0x6d5401e1,0x6608007c,0x00000000,0x00000000}},	//   _ìyab, ågko, --, --, 
   {{0xb0d07862,0x78a00205,0x5694c02c,0x00000000}},	// [1b8d0] _सांग, _şove, раут, --, 
   {{0xa4840f3e,0x9c34010e,0x256c03e0,0x00000000}},	//   نجان, _öýüñ_, mülk_, --, 
   {{0xe9dd227b,0xe9700725,0x00000000,0x00000000}},	//   ltú_, _مۇڭد, --, --, 
   {{0xc2c4009f,0x00000000,0x00000000,0x00000000}},	//   ايشي, --, --, --, 
   {{0xe9dd227c,0x00000000,0x00000000,0x00000000}},	//   ntú_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x42a41955,0x75806824,0xf524001f,0x612c0162}},	//   _бузғ, _ایلم, _ደረጃዎ, _føln, 
   {{0xe1f0034c,0x3ce40316,0xd379227d,0x28c000cd}},	//   _پسر_, ज्ने_, _ачу_, वृति, 
   {{0xaf0073c7,0xfd1008de,0xf78800df,0x00000000}},	//   спыл, مجد_, ענפֿ, --, 
   {{0xee35227e,0x43700075,0xe0d05598,0x00000000}},	//   унь_, _ئۇچر, _خزر_, --, 
   {{0x3ed412e3,0x3b85227f,0xdb2400f1,0x20640114}},	//   _مقار, ллог, لودی, _рђав, 
   {{0x20dc41ac,0xdb200205,0x3ea8010b,0x3d1000cd}},	//   प्रध, _övüy, _ýat_, ताहे_, 
   {{0xfce52280,0x7c2c0c09,0xd1f80092,0x25480153}},	//   _боло, _ƙars, _ወተት_, _kėlė_, 
   {{0xcdc456ff,0xc9552281,0x2724000d,0x7f48025c}},	//   _ташқ, атсы, _mõnu_, lieq, 
   {{0x8d740075,0x57940022,0x8cd806e3,0x00000000}},	//   _ئانا, рыгӡ, _मातो, --, 
   {{0x3d101094,0x1b0405f5,0x80cc03f8,0xbb2000d1}},	//   तावे_, _түмн, _साझे, ﺸﻜﻪ_, 
   {{0xe5a00019,0xfb840022,0x1ae401a9,0x00000000}},	// [1b8e0] йити, _иыҩн, _боқм, --, 
   {{0xdff05345,0xd9100405,0x7bc4003b,0x2a3802e4}},	//   _आनंद_, _بیس_, _åhus, _נעימ, 
   {{0xf744016c,0xb2712282,0xe4d52283,0x3ce41a2a}},	//   _бено, әклә, اومت_, ज्ये_, 
   {{0x1288034c,0xf7700133,0x00000000,0x00000000}},	//   نمای_, _داخ_, --, --, 
   {{0x52880184,0xf624039b,0x7f480381,0x00000000}},	//   тҡан_, _ёдго, dieq, --, 
   {{0x8cd80210,0x00000000,0x00000000,0x00000000}},	//   _माधो, --, --, --, 
   {{0xfbc407b7,0xde8c01f2,0xdd9402dd,0xf18800d1}},	//   _विषम, rịnt_, қшы_, _ﺗﻮﻧﯘ, 
   {{0x2ee4022f,0x612c022c,0xe9dc0419,0x2450fe06}},	//   _qbof_, _høll, ytú_, _انفس, 
   {{0x3eb80579,0x612c08cb,0xd25001ed,0x6fe80213}},	//   ðsta_, _køll, _بچا_, _səcd, 
   {{0x25480153,0x610800ef,0xdc140171,0x00000000}},	//   _gėlė_, _cēlē, _jāķe, --, 
   {{0xa11011ec,0x612c3778,0x985c00e2,0xecb001e0}},	//   _دولت, _møll, _cāļa_, аҡһы, 
   {{0x7f48003a,0xdef439af,0xee3800f0,0x6fe806be}},	//   cieq, _быш_, _пне_, _vəcd, 
   {{0xa14000e2,0x00000000,0x00000000,0x00000000}},	//   _šķit, --, --, --, 
   {{0xe9dd2284,0x959c02d3,0x20480023,0x7bdc054e}},	//   rtú_, ዋእትን_, _ንሕብረ, ăsur, 
   {{0xe9dd2285,0x3d10445f,0x5ed80154,0x7aec054e}},	//   stú_, तारे_, _মোটে, întâ, 
   {{0x96f8e3d8,0xd6d92286,0xe9dc00db,0x00000000}},	//   лест_, лту_, ptú_, --, 
   {{0x799403f9,0x2d8d2287,0x69c002b5,0x612c072b}},	// [1b8f0] _guyw, _kife_, _ānew, _bøll, 
   {{0x6fe803be,0x00000000,0x00000000,0x00000000}},	//   _məcb, --, --, --, 
   {{0x53a40597,0xdce00003,0x272400c5,0xc690072d}},	//   مملك, _jinġ, _sõnu_, _وِد_, 
   {{0xdce00327,0xfde400af,0x2b480332,0x00000000}},	//   _minġ, _कहलस_, nicc_, --, 
   {{0x29dc145e,0x76b8011a,0x1af800df,0x998400e5}},	//   nîa_, _במרפ, טמאל_, _خلیو, 
   {{0x2d8d2288,0x231401c0,0x2b980055,0xfbc4258d}},	//   _nife_, _өнгө_, _nīco_, _विलम, 
   {{0x2a7c0030,0xdce00327,0x7f480327,0xd78802f2}},	//   ľuby_, _ninġ, tieq, _جنێو_, 
   {{0x5334b9ad,0x2d8d2289,0x272400c5,0x637800a2}},	//   _лест, _aife_, _tõnu_, _däný, 
   {{0x2d8d228a,0x6f08145e,0xa281228b,0x3d100316}},	//   _bife_, _sêbä, _ایشو, ताले_, 
   {{0x61f9228c,0xdce00327,0xd0180304,0x00000000}},	//   _isul, _binġ, тфә_, --, 
   {{0x610800da,0xec74084c,0xb178010f,0x256c010e}},	//   _vēlē, ипь_, _סטער, güli_, 
   {{0x79940309,0xba1800f1,0x00000000,0x00000000}},	//   _puyw, پيسا_, --, --, 
   {{0x3ead228d,0x2d8c045a,0x0b3801d9,0x00000000}},	//   mbet_, _fife_, اقُک_, --, 
   {{0x61f9228e,0x3ead228f,0xc4b800cc,0x7b94003b}},	//   _msul, lbet_, ুভুজ, _криї, 
   {{0x39492290,0x69dd2291,0xcc08143e,0xfce40139}},	//   ribs_, _eqqe, _مزين_, _боһо, 
   {{0x2d8c014b,0x612c037e,0xa6c4036b,0x39b0007f}},	//   _zife_, _søll, илса_, pņs_, 
   {{0x75452292,0x66000262,0x61f85b52,0x612c01bf}},	// [1b900] аназ, опта, _nsul, _pøll, 
   {{0x3eac058f,0x499050f0,0x612c03b2,0x00000000}},	//   hbet_, _ریفر, _bølm, --, 
   {{0x3cdc06bc,0x61f92293,0x612c022c,0x2b9800e8}},	//   _खाने_, _asul, _vøll, _xëc_, 
   {{0xf1a40588,0x3dcc007f,0x3eac74ff,0x27b001af}},	//   аркн, krew_, jbet_, _фәрс, 
   {{0xc32c1a59,0x9ad4063f,0x612c005c,0x00000000}},	//   رەك_, _rịlt, _tøll, --, 
   {{0x612c0217,0x3ead2294,0x6fe806be,0x00000000}},	//   _hølj, ebet_, _nəcc, --, 
   {{0x61f814dc,0x2d8c3d19,0xb9ec001f,0xefb0036b}},	//   _esul, _rife_, _ዕጣ_, زیشگ, 
   {{0x2d8c0921,0x23241cc9,0x2b98002e,0x256c01ed}},	//   _sife_, _коси_, _rëc_, vüli_, 
   {{0x612c0fac,0xad2400c6,0x23245211,0xf2684130}},	//   _mølj, لردو, _тоти_, _риал_, 
   {{0x3eac009a,0xdce00135,0x256d2295,0x00000000}},	//   abet_, _pinġ, tüli_, --, 
   {{0x3ead2296,0xe0cc0014,0xceb8035f,0x2b48009a}},	//   bbet_, _زٲن_, _йәп_, ticc_, 
   {{0x2d8c0c30,0x28dc0034,0x256c01d3,0x3dcce6a6}},	//   _wife_, _पॉजि, rüli_, brew_, 
   {{0x32052297,0x3dcd2298,0x2d951fa4,0x9da406bb}},	//   nvoy_, crew_, _трес, _къща_, 
   {{0x27000016,0x3cdc0307,0xdce00135,0x29dd2299}},	//   _ổn_, _खाये_, _tinġ, rîa_, 
   {{0x612c0158,0x3204022e,0xe76800d8,0x00000000}},	//   _bølj, hvoy_, вјак_, --, 
   {{0x569434b1,0x8d7400d1,0xb60400d7,0x00000000}},	//   жатт, _ئاچا, zkáž, --, 
   {{0x612c0162,0x9a84074d,0x00000000,0x00000000}},	// [1b910] _sølm, _муьл, --, --, 
   {{0x64a40022,0x00000000,0x00000000,0x00000000}},	//   ршаз, --, --, --, 
   {{0x612c0623,0x61f8c35a,0x2910b034,0x5b2407d6}},	//   _følj, _ssul, _inxa_, _طفیل, 
   {{0x2900a40b,0x00000000,0x00000000,0x00000000}},	//   ldja_, --, --, --, 
   {{0x27fc00b0,0xd5b81302,0x69cc0327,0x72a000d1}},	//   āunu_, _всс_, nrce, سەلن, 
   {{0x2901229a,0xa2d01092,0xdce00327,0x2164034a}},	//   ndja_, _डाक्, _iinħ, штег, 
   {{0x3ead229b,0x3dcc0327,0xd9c400cd,0x00000000}},	//   tbet_, wrew_, _वट्ट, --, 
   {{0x61f9229c,0x3eac0489,0x3dcc007f,0xaf0002e8}},	//   _tsul, ubet_, trew_, зпъл, 
   {{0xf2d030fb,0x61f9229d,0x7c9404fb,0xdce1229e}},	//   _מען_, _usul, یشگا, _jinħ, 
   {{0xdce0038f,0x3ead229f,0xc0c402d3,0x8d28547c}},	//   _minħ, sbet_, ኺቦም_, иның_, 
   {{0x237c0218,0x69cc01f5,0x29000327,0xfb8802e8}},	//   _khuj_, erce, ddja_, лбок_, 
   {{0xdce4510c,0xa3cc0037,0x2900025c,0x3dcc031c}},	//   ımıy, _शिन_, edja_, prew_, 
   {{0x6e9006f6,0xdce0031c,0xe9a401d5,0x5fcc041c}},	//   _علوا, _ninħ, یگین_, संकल, 
   {{0x612cfcf4,0x69c000b8,0x5eac00cc,0xd1f801f3}},	//   _sølj, _ānet, _টাটে, _ወደቀ_, 
   {{0x69cd22a0,0x200522a1,0x78ac0208,0xad18011a}},	//   arce, nvni_, rbbv, _תוצר, 
   {{0xdce8025c,0x7bc04f8c,0x2b0c0037,0x00000000}},	//   _bugħ, mslu, _तोपु_, --, 
   {{0x7bc04c2e,0x74e805f5,0x98940116,0x75d4007b}},	// [1b920] lslu, лдаг_, _мунә, إيطا, 
   {{0x3204022e,0x7bc00254,0x00000000,0x00000000}},	//   vvoy_, oslu, --, --, 
   {{0x7bc122a2,0xb3c922a3,0x04840055,0x32c8035b}},	//   nslu, улез_, _kāṃk, гыло_, 
   {{0xe6940364,0xf1a8969f,0x63a00194,0x7bc122a4}},	//   _гурӯ, هاته_, ínna, islu, 
   {{0x237c0218,0x7ce00100,0x6d4404fb,0x200522a5}},	//   _dhuj_, _kňrč, èkak, evni_, 
   {{0x7bc122a6,0xe5a033d2,0x70d00490,0x32040946}},	//   kslu, _хири, सलेल, rvoy_, 
   {{0x1fa011db,0x7bc083a6,0x612c366f,0x2898010f}},	//   прыг, jslu, _mølh, ניקא, 
   {{0x290085a2,0x7bc001bf,0x4dc401e0,0xc4500244}},	//   zdja_, dslu, ороҡ, _تێمب, 
   {{0x6b4c5cee,0xed8800f7,0x8e140212,0x7bc00036}},	//   _lògè, лсок_, ідоц, eslu, 
   {{0x69cc0fcf,0x6a7c01e1,0x3cdc0073,0x00000000}},	//   vrce, _làfí, _खाणे_, --, 
   {{0x7bc122a7,0xa29c0cf1,0x256c01d3,0x6ab80174}},	//   gslu, _ओलम्, mült_, ðufo, 
   {{0x94f80327,0x37dc03d4,0xdfcc009f,0xef840114}},	//   _པིའི_, মবাৰ, _سيه_, _улеп, 
   {{0x69cd22a8,0xbf6400aa,0x6f00035a,0x7bc000ae}},	//   urce, _بدلو, _iaoc, aslu, 
   {{0x6f00037e,0x7bc00306,0xad240214,0xdec80092}},	//   _haoc, bslu, _درصو, _በስነ_, 
   {{0x6d484539,0x290122a9,0x3cdd22aa,0x6eac0034}},	//   _imfa, rdja_, _खाते_, ीरपु, 
   {{0xe7841e76,0xf41c03d4,0x6fe803b9,0x8ca417ee}},	//   суго, পনাৰ_, _xəca, चुरो, 
   {{0x6a7c0241,0xfd5400cd,0xdbd002d2,0x256c00e5}},	// [1b930] _dàfí, _alaṅ, _húðg, kült_, 
   {{0x6f001552,0x237c2a71,0x00000000,0x00000000}},	//   _laoc, _shuj_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d4922ab,0x42750fb9,0x6f0004ce,0x7ce00100}},	//   _lmfa, огес, _naoc, _zňrč, 
   {{0xe4a407b5,0x612c06ea,0x00000000,0x00000000}},	//   _грбо, _høli, --, --, 
   {{0x7bc122ac,0x612c4e95,0x23b8007b,0xda7c011a}},	//   yslu, _køli, _مدرب_, אנדר, 
   {{0x4fc410e0,0x237c78d1,0x6f000208,0xd8dc0677}},	//   كەلە, _thuj_, _baoc, אקור, 
   {{0x3eb80f99,0x6d484437,0x20045946,0x6f000e89}},	//   úst_, _amfa, rvni_, _caoc, 
   {{0x7bc075fa,0x00000000,0x00000000,0x00000000}},	//   wslu, --, --, --, 
   {{0x7bc122ad,0xee3522ae,0x256c29ef,0xd2000131}},	//   tslu, юны_, müls_, _чүшк, 
   {{0x6f0008c2,0x6fe800ac,0x518522af,0x491c09b4}},	//   _faoc, _təca, _хута, मानो_, 
   {{0x7bc122b0,0x6d4922b1,0x00000000,0x00000000}},	//   rslu, _emfa, --, --, 
   {{0x7bc122b2,0xed4d22b3,0xaa40005b,0x00000000}},	//   sslu, _жо_, деял, --, 
   {{0x7bc01f53,0x612c03b2,0xdd8c0451,0x6fe803e3}},	//   pslu, _bøli, _ڪوڙ_, _məcn, 
   {{0x612c0ac8,0x6f000810,0xe61c0042,0x98440092}},	//   _cøli, _yaoc, _sgôp_, _ከትምህ, 
   {{0xc5b8031c,0xf1b807f7,0x256c00e5,0x00000000}},	//   _བསྡི, _उबलन, zült_, --, 
   {{0x6b6007d5,0x6d486bba,0x67540014,0x3eb80210}},	// [1b940] _юкъа, _ymfa, زخٲر, ósty_, 
   {{0x612c06ea,0x6a7c0241,0x00000000,0x00000000}},	//   _føli, _wàfí, --, --, 
   {{0x69c801bf,0xdee40092,0x256c00e5,0x24940066}},	//   _åger, ሚሆን_, vült_, زنند_, 
   {{0x4c6c008f,0x70d0fdba,0x00000000,0x00000000}},	//   נדאַ, सल्ल, --, --, 
   {{0x256c01b8,0x00000000,0x00000000,0x00000000}},	//   güls_, --, --, --, 
   {{0x6f00f01e,0xefdc0023,0x65bc0ca8,0x6068110e}},	//   _saoc, _ጓለይ_, _wàhá, _ṣiṣe_, 
   {{0x256c066d,0x64a001c0,0xb600025c,0x387c00d7}},	//   rült_, _цаса, ġġud, ýtrh_, 
   {{0x733410a8,0x256c01ed,0xa2c80073,0xa3cc01ad}},	//   _بىرا, sült_, हणण्, _शित_, 
   {{0x256c01d3,0x00000000,0x00000000,0x00000000}},	//   pült_, --, --, --, 
   {{0x6f000099,0xd6c0009e,0x00000000,0x00000000}},	//   _waoc, ইলিয, --, --, 
   {{0x6f000552,0x00000000,0x00000000,0x00000000}},	//   _taoc, --, --, --, 
   {{0x2e68008e,0xeb48010b,0x00000000,0x00000000}},	//   _киеп_, рчок_, --, --, 
   {{0xed5922b4,0x612c03cd,0x7d0c0332,0xcfa80244}},	//   _код_, _søli, íosó, _ئاڕم_, 
   {{0xacb00131,0xdd8c02dd,0xeabc0165,0x2b980171}},	//   _تەدب, _іш_, saù_, _līci_, 
   {{0x6d5922b5,0xcb340408,0x00000000,0x00000000}},	//   mnta, _некъ, --, --, 
   {{0x612c0158,0x00000000,0x00000000,0x00000000}},	//   _vøli, --, --, --, 
   {{0x6d5922b6,0x256c0793,0x98740092,0x9b8801c8}},	// [1b950] onta, xüls_, _ለድርጅ, _بنيل_, 
   {{0x6d5922b7,0x612c0174,0xaaa42c2e,0x00000000}},	//   nnta, _tøli, कुरक, --, 
   {{0x612c00b5,0x947484d2,0x78f8011a,0x41741183}},	//   _kølv, ودما, _הפתו, ۋاتس, 
   {{0x6d580112,0xc2c416ac,0x00000000,0x00000000}},	//   hnta, سيتي, --, --, 
   {{0x95c833d2,0x8634008f,0x00000000,0x00000000}},	//   _мура_, _זאָג_, --, --, 
   {{0x6d5922b8,0xb5d00131,0x31d00137,0x00000000}},	//   jnta, _ﺟﻪﻣﺌ, رقىز, --, 
   {{0x256c014a,0x660d22b9,0x00000000,0x00000000}},	//   süls_, _hrck, --, --, 
   {{0xf4100375,0x228400ee,0x65740240,0x900800d1}},	//   _אפל_, _дузг, llxh, ززىق_, 
   {{0x0a4c0201,0x6d1412eb,0xfce47b0e,0x78a00205}},	//   ጀመሪያ, तांग_, попо, _şovm, 
   {{0x6d580441,0x5ba001b9,0x902800c7,0x00000000}},	//   gnta, млоғ, сцәа_, --, 
   {{0x3b0922ba,0x00000000,0x00000000,0x00000000}},	//   бено_, --, --, --, 
   {{0x6fe803be,0xaaa435e0,0xdb1c1432,0xef0c00d8}},	//   _məcl, कुलक, _üzüc, _џм_, 
   {{0x81e839db,0x6d5801d4,0x02b8000d,0x00000000}},	//   যিক_, bnta, _उजैन, --, 
   {{0x17c80364,0x6d580113,0x00000000,0x00000000}},	//   оҳои_, cnta, --, --, 
   {{0x25a801c8,0x3e840129,0x660c00e5,0x315400df}},	//   _atcl_, bêté_, _arck, לישן_, 
   {{0x660c05be,0x612c0fac,0xac140114,0xd6d400cc}},	//   _brck, _gølv, _хоћу_, হ্নয, 
   {{0x3ebc003d,0x612c06ea,0x7774007c,0x27302a8b}},	// [1b960] _mewt_, _hølu, rlyx, رىكس, 
   {{0x6d9c00b8,0xbef806b1,0x00000000,0x00000000}},	//   _ṣakr, ्युन_, --, --, 
   {{0x660c02d0,0x28980a7c,0xb6a4010a,0x00000000}},	//   _erck, _לייא, _нинл, --, 
   {{0x6fe803b9,0xa44001c6,0x1aec0154,0x00000000}},	//   _dəcl, энхд, য়াকে_, --, 
   {{0x6d5922bb,0x660c0384,0x741401b9,0x021800e5}},	//   ynta, _grck, _کوزا, قعوں_, 
   {{0x98a40006,0x614000c0,0x00000000,0x00000000}},	//   ėmė_, неча, --, --, 
   {{0xb4c84928,0x6d580218,0xbef802ab,0x6538008f}},	//   ोली_, vnta, ्यून_, _פעלד, 
   {{0x6d5922bc,0x683401b8,0x00000000,0x00000000}},	//   wnta, lüdö, --, --, 
   {{0x3ebc0327,0xb62c00b5,0xb1440139,0x6d5401e1}},	//   _dewt_, _ｒｓ_, _енал, _ìyak, 
   {{0x6fe803be,0x78bc01f5,0x00000000,0x00000000}},	//   _həcm, _nepv, --, --, 
   {{0x3cdc177c,0x4c940261,0x703801af,0xf1d03d22}},	//   _खारे_, ќинс, _учас_, _सिडन, 
   {{0xe454008d,0x612c0162,0x00000000,0x00000000}},	//   לייט_, _dølu, --, --, 
   {{0x3e8420ef,0x5a348807,0x78bc0455,0x612c03b2}},	//   rêté_, енят, _bepv, _vølv, 
   {{0x612c0162,0xd1f80240,0x00000000,0x00000000}},	//   _følu, _ወደቐ_, --, --, 
   {{0x612c03b2,0xa174010f,0x00000000,0x00000000}},	//   _gølu, פעלד_, --, --, 
   {{0x0a4c0092,0x6fe806be,0xb6a00356,0x660c01ef}},	//   ጀመርያ, _nəcm, ţâna, _prck, 
   {{0x683401b8,0x3d100490,0x3eb81d0e,0xa7a401ec}},	// [1b970] füdö, ताचे_, ðsti_, _ﻋﺎﺩﺓ_, 
   {{0x660c0e04,0x6b700116,0x00000000,0x00000000}},	//   _vrck, _юлқу, --, --, 
   {{0xb86404da,0x27e401c7,0x73c02cc8,0x6abc0200}},	//   _ياپو, _ënn_, кәте, _keqf, 
   {{0x25a801c8,0x00000000,0x00000000,0x00000000}},	//   _ttcl_, --, --, --, 
   {{0xa3cc2982,0x9394473f,0x3cdc0550,0x00000000}},	//   _शिव_, رجما, _खाले_, --, 
   {{0xd8740952,0x612c03cd,0x8cd80073,0xdef40023}},	//   _تاۋب, _nølt, _मागो, ላዕን_, 
   {{0x23740a2c,0xf1880116,0x00000000,0x00000000}},	//   _فارح, _ﺗﻮﻗﯘ, --, --, 
   {{0xbef80882,0xfd600248,0x00000000,0x00000000}},	//   ्येन_, bawọ, --, --, 
   {{0x612c022c,0xa3c400ab,0x44200356,0x00000000}},	//   _sølu, ोंक_, lxh_, --, 
   {{0x5fa02928,0xbabc08b0,0x00000000,0x00000000}},	//   _كەتم, _ﻣﯩﺴﺎ, --, --, 
   {{0x60c122bd,0x78bc014f,0x714400db,0xed4c1e2f}},	//   manm, _repv, _تىلۅ, جھن_, 
   {{0x78bc047e,0x612c3bb6,0x1ee4335b,0x00000000}},	//   _sepv, _vølu, _روتی_, --, 
   {{0xfce43bfd,0x612c0e38,0x8e740024,0x00000000}},	//   _жоло, _følt, _пушч, --, 
   {{0x60c122be,0x78bc014f,0x612c06ea,0x00000000}},	//   nanm, _qepv, _tølu, --, 
   {{0x2b9800de,0x6d8408a5,0x00000000,0x00000000}},	//   _pūce_, fðaf, --, --, 
   {{0x62980016,0x60c104ec,0xbb8400c6,0x442001f5}},	//   _nguo, hanm, _تلبي, dxh_, 
   {{0x612c03d4,0xa5f403b7,0xd83809a8,0x78bc0455}},	// [1b980] _jøls, меѓу_, šč_, _tepv, 
   {{0xb4c80892,0x60c000dc,0x612c0158,0xd8b40014}},	//   ोले_, janm, _møls, _سۅرخ, 
   {{0xf74522bf,0x7c2c02a8,0xa3c400e1,0x24cc0150}},	//   _жено, _ƙary, ोंग_, _ﻗﯘﻻﻣ, 
   {{0x683401b8,0xa3cc1223,0x00000000,0x00000000}},	//   südö, _शिर_, --, --, 
   {{0x60c121a9,0x9ad402e3,0xd7a4000d,0x00000000}},	//   fanm, _hịst, _खंडच, --, 
   {{0x60c122c0,0x442122c1,0xf0741945,0x00000000}},	//   ganm, bxh_, милә_, --, 
   {{0xd01096e0,0x44200175,0x01e400db,0xa3e403f6}},	//   الب_, cxh_, _үйсү, _одра_, 
   {{0xacb004a9,0x612c0162,0x9f440100,0xb2c4027d}},	//   ھەبب, _sølt, ntnè_, _زغرو, 
   {{0x60c122c2,0xef9001d5,0x00000000,0x00000000}},	//   banm, _ییتد, --, --, 
   {{0xe0d4026a,0x60c122c3,0x612c03b2,0xe1f40108}},	//   _ову_, canm, _døls, _югу_, 
   {{0xe0401341,0x6d8403b2,0x68e122c4,0xd1f00092}},	//   _инфи, yðaf, _öndi, ሁዶች_, 
   {{0x612d22c5,0xdef400cf,0x00000000,0x00000000}},	//   _føls, _жыш_, --, --, 
   {{0x612c03b2,0x44200175,0x00000000,0x00000000}},	//   _tølt, zxh_, --, --, 
   {{0xb4c80764,0x6abc031c,0x8cd800bc,0x1d040114}},	//   ोलो_, _weqf, _माटो, _жељи_, 
   {{0x1994ca5f,0xf1880131,0x1bb400db,0x00000000}},	//   таря, _ﺗﻮﻟﯘ, _قايع_, --, 
   {{0xb8e4033f,0x69d40bae,0x442002f0,0x6d84032e}},	//   _उड़_, _बिपी, vxh_, fðag, 
   {{0x60c122c6,0x6d8408a7,0x1b742ad5,0x4974011c}},	// [1b990] yanm, rðaf, _جدوج, _плис, 
   {{0x629804cc,0x442122c7,0x00000000,0x00000000}},	//   _sguo, txh_, --, --, 
   {{0x60c122c8,0xf990010f,0xc4342c04,0x00000000}},	//   vanm, _תרי_, رکست, --, 
   {{0x60c122c9,0x44200023,0xdedc0023,0xbebc0064}},	//   wanm, rxh_, ኒትን_, ejūn, 
   {{0xc5b80003,0x929402d5,0xb784010b,0xaa780162}},	//   _བསྲི, вацц, _чәре_, mfýs, 
   {{0x4420011c,0x569400ee,0xaa7803b2,0x00000000}},	//   pxh_, _шаят, lfýs, --, 
   {{0x60c122ca,0x612c0158,0x3ea4d021,0xe28401b9}},	//   ranm, _søls, нийг, سطچی, 
   {{0x612c3c12,0x6298014b,0xcf880592,0xaad844eb}},	//   _pøls, _uguo, وضين_, _भागक, 
   {{0x9f4401f1,0x2c300092,0x00000000,0x00000000}},	//   ntné_, ርግጠኝ, --, --, 
   {{0x60c0636d,0xd138030d,0x50f40798,0x00000000}},	//   qanm, _охх_, _изут, --, 
   {{0x3b084727,0xe73c0254,0x3e6800f2,0x00000000}},	//   пено_, _olõ_, _کجای_, --, 
   {{0xf41004ac,0x9418013f,0x9f4401f1,0x3b08301d}},	//   אפט_, _afrɛ_, ktné_, чемо_, 
   {{0xe9a007d6,0xa9a038ca,0x3eb876ad,0x8de4007b}},	//   лаяп, лияд, ðstu_, _لكنه, 
   {{0xf1b0025f,0xfce4147e,0x3f8d22cb,0x00000000}},	//   רסם_, _чоко, lmeu_, --, 
   {{0xb0640139,0xa9647503,0xeaa002dd,0x00000000}},	//   _ikäü, хира_, _ﺍﯞﺭﯞ, --, 
   {{0xb4c800ab,0x7a6801c6,0xf624a68e,0xfa681422}},	//   ोल्_, _нийг_, ндбо, _найк_, 
   {{0x37740209,0x00000000,0x00000000,0x00000000}},	// [1b9a0] _җынс, --, --, --, 
   {{0xe57485c0,0xd9e80055,0xeaac01d3,0x0ba4008e}},	//   езу_, _aṅgā_, _پٹی_, _яшәм, 
   {{0x59d80574,0x84540131,0xad34010f,0x2bc01546}},	//   भंकर, پىنچ, ענעס_, वीपा, 
   {{0xb37522cc,0x661922cd,0x66e402b1,0xf74522ce}},	//   رداش, _šuke, _pūkō, _чемо, 
   {{0x798c00ec,0x98280014,0xe73400a8,0x98b80166}},	//   ombw, _رتھہ_, _чея_, lorı_, 
   {{0xe1340953,0x3878013a,0xe12000d8,0x00000000}},	//   нзіі_, _kypr_, лмчи, --, 
   {{0x798c0506,0x2518010f,0x21740006,0x00000000}},	//   imbw, _צולא, эйшы_, --, 
   {{0x798c0369,0x752c0327,0x66e402b5,0xef640b01}},	//   hmbw, _hobz, _tūkō, эъло, 
   {{0x6ce522cf,0xb640037e,0xe354011a,0x6fe803e3}},	//   ніне, _ｏｌ_, _נשמח_, _məci, 
   {{0x798c0399,0x752c20e4,0x98b80153,0x0edc0073}},	//   jmbw, _jobz, mirė_, _याकड, 
   {{0xdfcc30bf,0x6fd44028,0xc0e80023,0x5d50084c}},	//   _هيل_, _سزائ, ሚኦም_, укэт, 
   {{0x752c382f,0x9f440122,0xada4d9ff,0xfee8007b}},	//   _lobz, ytné_, _задл, _يعنى_, 
   {{0x612c01bf,0xd138033f,0xce340214,0x491c00bc}},	//   _kølp, _ciąg_, _جوشک, मालो_, 
   {{0x798c0399,0x99280816,0x6d8408a5,0x00000000}},	//   gmbw, нюса_, fðae, --, 
   {{0x5d800fb4,0xd9183de2,0x38780210,0xd91476b8}},	//   _حلول, хья_, _cypr_, ыдры, 
   {{0x798c0083,0x6fe803b9,0x5c78011a,0x00000000}},	//   ambw, _vəch, _מאוה, --, 
   {{0x752c0327,0x857473b3,0x00000000,0x00000000}},	// [1b9b0] _bobz, влах, --, --, 
   {{0x752c1529,0x6fe800ac,0x9f440030,0x6b8c02d0}},	//   _cobz, _təch, rtné_, lmcg, 
   {{0x9f446b07,0xe9dc0418,0x69d401ad,0x78000117}},	//   stné_, luú_, _बिडी, _кӯта, 
   {{0xd32522d0,0x90e41a50,0x068400d1,0xd39801e0}},	//   льчи, ۇسىن, _үгүн, еҙсә_, 
   {{0x52740228,0x6d840008,0x7580036b,0x00000000}},	//   лушу, iðab, _چیقم, --, 
   {{0xd1841ed2,0x98b40552,0x61e801e3,0x04c800ec}},	//   глій, čeći_, rtgl, _زوري_, 
   {{0xe9dc0270,0x48e80034,0x672c0427,0x68e001a8}},	//   huú_, _जानो_, _kocj, _öndu, 
   {{0x27e404f3,0x752c0161,0xf42800fd,0x00000000}},	//   _ännu_, _zobz, skäü_, --, 
   {{0x752c02ce,0xb2740588,0x3f8c00cf,0xcf2415bf}},	//   _yobz, _актә, rmeu_, ارىي, 
   {{0x5224016c,0x3f8c00d5,0x00000000,0x00000000}},	//   _ёфта, smeu_, --, --, 
   {{0x9ba00075,0xbb4522d1,0x6d8401a8,0x9ac40116}},	//   دەبى, венк, fðab, линҗ, 
   {{0x3cdcad78,0x00000000,0x00000000,0x00000000}},	//   _खाके_, --, --, --, 
   {{0xee2c93ff,0x00000000,0x00000000,0x00000000}},	//   _тн_, --, --, --, 
   {{0x49985402,0x798d22d2,0x98b800fd,0x5a240014}},	//   ется_, umbw, torı_, ٖکھِ, 
   {{0xdb08110e,0x00000000,0x00000000,0x00000000}},	//   ólóh, --, --, --, 
   {{0x752c110c,0x6d840413,0xb6f800cf,0x00000000}},	//   _sobz, rðae, بىرا_, --, 
   {{0x752c02ce,0xf5080a27,0x6fe806be,0x78a003e0}},	// [1b9c0] _pobz, мнал_, _vəci, _şovu, 
   {{0xf4941216,0x798c0007,0x85080131,0x00000000}},	//   نشاد, qmbw, ндуң_, --, 
   {{0xca6c02bf,0xd7641f6d,0x6fe800ac,0xaa7800e4}},	//   _onaл, _مندی, _təci, ngýn, 
   {{0xdce8005f,0xccf80118,0xd4f401e0,0x290401e7}},	//   _augļ, jněn_, ъяғы, _ónar_, 
   {{0x7af522d3,0x6fbc5d2d,0xe294026a,0x3cd800fe}},	//   _mbyt, _ইমেই, вац_, ব্যৱ, 
   {{0x26cc00d7,0x00000000,0x00000000,0x00000000}},	//   ógov_, --, --, --, 
   {{0x7af40122,0x6d840174,0x00000000,0x00000000}},	//   _obyt, yðab, --, --, 
   {{0xd2940014,0x43743e38,0x00000000,0x00000000}},	//   _مُزک, _буут, --, --, 
   {{0x71e800c6,0xd1b00517,0x71a522d4,0x64640356}},	//   _زفاف_, _ایتک, _разз, ăriţ, 
   {{0xe9dc0093,0xe0d421f3,0xc58c0150,0xd34802f2}},	//   vuú_, _авф_, _ﺒﺎﻟﺨ_, _تیڤه_, 
   {{0xa0a002a9,0x30742a83,0xdfe400d8,0x00000000}},	//   _тахд, _руас, _адхд_, --, 
   {{0xee3922d5,0xdd8c00f1,0x4c240014,0xccf801ef}},	//   _оне_, _ېوه_, ٖٹھِ, cněn_, 
   {{0x6d842833,0x7af40076,0xda787aa6,0x6b8c02d0}},	//   rðab, _dbyt, вяр_, rmcg, 
   {{0x672d22d6,0x9e8404d3,0x00000000,0x00000000}},	//   _socj, _شانۆ, --, --, 
   {{0x57a522d7,0xe9dc0418,0xcd040116,0x596401c6}},	//   ишта, suú_, _ачқи, ръяа, 
   {{0xd6d922d8,0x7af4002f,0x00000000,0x00000000}},	//   кту_, _gbyt, --, --, 
   {{0x50b419cc,0x96340124,0xd79402e8,0x95c80eed}},	// [1b9d0] ुराष, антц, ритъ, вуха_, 
   {{0x7af522d9,0x00000000,0x00000000,0x00000000}},	//   _zbyt, --, --, --, 
   {{0x7af801ed,0x7af400c7,0x98c401ee,0x00000000}},	//   őtte, _ybyt, _тсыл, --, 
   {{0xbd040241,0x48e800bc,0x00000000,0x00000000}},	//   _abẹ́, _जाडो_, --, --, 
   {{0xe4a522da,0xccf800bc,0x764401d9,0x6fe803b9}},	//   _арбо, vněn_, _ییہِ_, _məcu, 
   {{0xec6400b2,0x00000000,0x00000000,0x00000000}},	//   _هٿ_, --, --, --, 
   {{0x7ff522db,0x4fc40447,0x442425a8,0xb3400139}},	//   استا, لەلە, _çl_, _şçek, 
   {{0x533522dc,0x6d4406c8,0x73c000c7,0xaff400ae}},	//   _кест, ūkal, _ыӡуа, افيا_, 
   {{0x5334f817,0x00000000,0x00000000,0x00000000}},	//   _тетт, --, --, --, 
   {{0xbd44f7d1,0x61f922dd,0xae848dc7,0xbd040248}},	//   اندي, _ipul, ыбыз_, _gbẹ́, 
   {{0xccf800bc,0xa2c51769,0x2bc40661,0x9f440118}},	//   mněl_, ारप्, ллэп_, ltní_, 
   {{0x8fd40075,0x00000000,0x00000000,0x00000000}},	//   _тәшә, --, --, --, 
   {{0x49c40184,0x9f440316,0x99800356,0xdb040200}},	//   аһын_, ntní_, _criş_, _hunë, 
   {{0x3eac3113,0x61f922de,0xa9a01e87,0x37e41180}},	//   lcet_, _mpul, сирд, логг, 
   {{0x998056f8,0x3ce40036,0x66180327,0x3f9c002f}},	//   _eriş_, mglv_, _ġuka, _kiwu_, 
   {{0x3ead22df,0x7af403c6,0x7d010721,0xc76404a9}},	//   ncet_, _ubyt, lels, لاقى, 
   {{0xae1400c5,0x3dcd0246,0x00000000,0x00000000}},	// [1b9e0] तियन_, nsew_, --, --, 
   {{0x7d0122e0,0x3f9c0bd7,0x27f40118,0xddc8002b}},	//   nels, _liwu_, ícný_, _śiśi, 
   {{0x61f922e1,0x48e80574,0x7a480129,0x7d00003b}},	//   _apul, _जातो_, _fêté, iels, 
   {{0x64a122e2,0x15b41b16,0x7d0122e3,0xf2680209}},	//   _ҳара, _نەرس, hels, ниел_, 
   {{0x7d0122e4,0x799c54c4,0xd1cc0092,0x3eac0139}},	//   kels, _kipw, ጠብቁ_, dcet_, 
   {{0x64a122e5,0x7d0122e6,0xdb04036e,0x00000000}},	//   _гара, jels, _bunë, --, 
   {{0x7d00ec5d,0x61f922e7,0x25643f6e,0x799c014f}},	//   dels, _epul, _сарп_, _mipw, 
   {{0x7d000037,0x506401ec,0x00000000,0x00000000}},	//   eels, лтқа, --, --, 
   {{0x3f9c0de2,0x10f801d9,0x7d0122e8,0xc32c0725}},	//   _diwu_, _لباں_, fels, _تەن_, 
   {{0x7d0008d7,0x3eac0393,0xccf801ef,0x00000000}},	//   gels, acet_, cněl_, --, 
   {{0x69d4012c,0x2d8000b0,0xef1801f4,0x00000000}},	//   _बिही, ēke_, _пмж_, --, 
   {{0xdd8c040b,0xe9e4009d,0x00000000,0x00000000}},	//   _ہون_, лцго, --, --, 
   {{0x7d0013b9,0x2ba41fd2,0xf7c400d1,0x00000000}},	//   bels, _गढवा, _ﺩﯨﻤﻪ, --, 
   {{0xdd8c7405,0x7d0122e9,0xdb048a69,0x00000000}},	//   _فون_, cels, _lunè, --, 
   {{0x3f9d22ea,0x799c07ab,0x6d58b4bb,0x5ce002dd}},	//   _yiwu_, _dipw, mita, _اكىل, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9b4407f2,0xd1cc001f,0x6d5922eb,0xe6640212}},	// [1b9f0] _دنيو, ጠብቅ_, oita, утво, 
   {{0x04880131,0xa484009f,0xdce8013d,0xa2c400cd}},	//   вәби_, هجان, _yugı, ारभ्, 
   {{0x61f8193f,0x69ccaea6,0x6d5922ec,0x3eac0076}},	//   _spul, lsce, iita, ycet_, 
   {{0x7d0122ed,0x491c0316,0x61f80083,0x59dc1b90}},	//   zels, माको_, _ppul, _बिमर, 
   {{0x7d0122ee,0xe030ed47,0xb2740022,0x00000000}},	//   yels, өмдө, акцә, --, 
   {{0x6d5922ef,0xdb04069c,0xeea0006a,0x69cc00c6}},	//   jita, _punë, ïönî_, isce, 
   {{0x7d008076,0x9f44038e,0xdb0522f0,0xff2411f4}},	//   vels, stní_, _funè, имко, 
   {{0x7d0122f1,0x290122f2,0x65740b6f,0x3dcc013f}},	//   wels, heja_, loxh, tsew_, 
   {{0x7d0122f3,0x290122f4,0xdce80724,0x61f922f5}},	//   tels, keja_, _sugı, _upul, 
   {{0x290122f6,0x3ead22f7,0x6d5922f8,0x69cc4174}},	//   jeja_, scet_, gita, dsce, 
   {{0x7d008076,0x69cd22f9,0x63a40309,0x799c020c}},	//   rels, esce, _jujn, _ripw, 
   {{0xbd44e549,0x6d5922fa,0x63a4e05e,0xdb0400e8}},	//   انگي, aita, _mujn, _kuné, 
   {{0xdb040098,0x290122fb,0x63a40139,0xba7401d5}},	//   _juné, feja_, _lujn, شاحت, 
   {{0x6d5922fc,0x290122fd,0xc5b8025c,0x799c047e}},	//   cita, geja_, _བསྟི, _qipw, 
   {{0x63a522fe,0xdb040129,0xbb440064,0x00000000}},	//   _nujn, _luné, _вейк, --, 
   {{0x37e4036b,0x7f4800d8,0x3204007f,0xf1c400cd}},	//   лоҳг, nheq, ywoy_, रीडन, 
   {{0x290122ff,0x6d8409f3,0x69cd2300,0x8b6455ab}},	// [1ba00] beja_, iðan, csce, _داوم, 
   {{0x14c8034c,0x2004014b,0xdb04020c,0x2900e007}},	//   اهای_, kwni_, _sunè, ceja_, 
   {{0x35d8033f,0xa5040395,0xdb0852e1,0x00000000}},	//   यूज़, реха_, _ólól, --, 
   {{0x2bf400c8,0x00000000,0x00000000,0x00000000}},	//   ימען_, --, --, --, 
   {{0x65740354,0xdb040129,0x7f4801ab,0xf1c403ce}},	//   boxh, _cuné, dheq, _रौशन, 
   {{0x6d592301,0xf8c42aa1,0x63a4062c,0xa1846bce}},	//   xita, वरिय, _fujn, абча_, 
   {{0xdb040ba1,0xf1d005f9,0x985c0092,0x6d8402d2}},	//   _tunè, _सिकन, ደሚሆኑ_, fðan, 
   {{0x6d592302,0x29008ab2,0xdb0407ea,0xa2c43abc}},	//   wita, zeja_, _funé, ारण्, 
   {{0xdb04002e,0xf8c4dc75,0xe2952303,0xd738001f}},	//   _guné, वराय, _ват_, _የወሰነ, 
   {{0x6d5816b8,0xdd940276,0x63a40139,0xabe80014}},	//   uita, ишэ_, _yujn, پردٕ_, 
   {{0x69cc0175,0xa0640114,0x00000000,0x00000000}},	//   wsce, _кафа_, --, --, 
   {{0x7f492304,0x6574014b,0x48e80406,0xad248863}},	//   cheq, zoxh, _जाहो_, ارکو, 
   {{0x29012305,0x6d5824b6,0x65740117,0x69cc0381}},	//   teja_, pita, yoxh, usce, 
   {{0x69cd2306,0x6d592307,0x5df80375,0x66180153}},	//   rsce, qita, _ספונ, _šuko, 
   {{0x09e402f5,0xdcac0137,0xad2400f1,0x7db00133}},	//   _পৈশা, _تۉپ_, _مرګو, _وڵیا, 
   {{0x29012308,0x63a4b745,0xdc980375,0x69cc007c}},	//   seja_, _rujn, _ביול, psce, 
   {{0xeabc0395,0x2bc04466,0x9f440030,0xe4a40022}},	// [1ba10] mbù_, वीरा, ntná_, арео, 
   {{0x48c40116,0xa3b8007b,0xe9dd2309,0x2900036e}},	//   _ушиғ, ناصر_, mrú_, qeja_, 
   {{0x94a80124,0xdb0400e8,0x63a40455,0xe9dcda0d}},	//   ртуа_, _suné, _qujn, lrú_, 
   {{0x62b5230a,0x20040109,0x63a40e04,0x9f440030}},	//   рғас_, vwni_, _vujn, ktná_, 
   {{0xe9dc00c6,0x7580006c,0xf0780116,0x620400d8}},	//   nrú_, _کیلم, ңичә_, рчез, 
   {{0x63a40113,0x98b800e4,0xdb24032e,0x981404f2}},	//   _tujn, tirĩ_, _ósön, _ابیا, 
   {{0xe9dc0597,0x7f49230b,0x32180882,0x5558084c}},	//   hrú_, theq, āpya_, _таря_, 
   {{0xc5b8025c,0xa344009d,0x98b800c7,0xe9dc00d7}},	//   _བསྙི, _тэгл, rirĩ_, krú_, 
   {{0x6d842242,0x7f48044e,0x4cb804c5,0xef140a43}},	//   rðan, rheq, _আয়ু, смы_, 
   {{0xe9dcfc2d,0x98b80022,0x00000000,0x00000000}},	//   drú_, pirĩ_, --, --, 
   {{0x7f480107,0x2bc0dadd,0xcfe80345,0x661800c0}},	//   pheq, वीला, _نفله_, _šukl, 
   {{0x6fe803be,0x15e8033f,0xbc2401ec,0x59dc000d}},	//   _təcr, टूडर_, _ۇرعى, _बिदर, 
   {{0xe9dc00c6,0x6374063f,0xa5b8032e,0x00000000}},	//   grú_, ụnwa, _hróf, --, 
   {{0xdce000ef,0x8ae806be,0x7b64013d,0x00000000}},	//   _rinķ, fiәs, ртүе, --, 
   {{0x8f500133,0xe9dc00ae,0x0d5400f2,0x00000000}},	//   _رۆیش, arú_, _بخند, --, 
   {{0x6b68068f,0xe9dd230c,0xccf80118,0x00000000}},	//   lęgn, brú_, yněk_, --, 
   {{0xe9dc00c6,0x7bc40076,0x75440107,0xeab400fb}},	// [1ba20] crú_, _çhub, бназ, _уйы_, 
   {{0xeb500050,0xa5b801e1,0xb828004e,0x00000000}},	//   _وى۪گ, _oróf, _бооз_, --, 
   {{0xf2e4004b,0xa3e0146c,0x00000000,0x00000000}},	//   یکړه_, फूल_, --, --, 
   {{0x3b100784,0xb2240cdd,0x9f4402fb,0xc32c1456}},	//   _jayq_, ймел, ytná_, پەك_, 
   {{0xb5b0009e,0xe7b00330,0x63b801ef,0x6d8402d2}},	//   _চিকচ, _ومید, _čune, fðal, 
   {{0xe0cc1b56,0x741400ec,0x6d8402d2,0x00000000}},	//   ىزى_, _ٿورا, gðal, --, 
   {{0xe0cc0472,0xe9dc00d7,0x00000000,0x00000000}},	//   رزو_, zrú_, --, --, 
   {{0xe360084c,0x39580ebe,0x00000000,0x00000000}},	//   _екси, _lmps_, --, --, 
   {{0xd25003e6,0xdda4009d,0x00000000,0x00000000}},	//   _تۆش_, йтэл_, --, --, 
   {{0x66dc01e1,0x9f4400d0,0xe9dc0419,0x3f640026}},	//   _kàkà, rtná_, vrú_, йтөб, 
   {{0x30840597,0x9f440232,0xa5b9230d,0xd054013f}},	//   _الاف, stná_, _gróf, _ɑbɛd, 
   {{0xceb800ee,0x3959230e,0x66dc01e1,0x00000000}},	//   _тәк_, _amps_, _màkà, --, 
   {{0x6e940491,0x161c1152,0xdee0141c,0x66dc01e1}},	//   _الشا, निफर_, _хочи, _làkà, 
   {{0xaa7800e4,0xe9dc5207,0x00000000,0x00000000}},	//   ngýi, rrú_, --, --, 
   {{0xa5b81d0e,0x97a40c69,0xe9dc00ae,0x57e80108}},	//   _króg, зрул, srú_, йдём_, 
   {{0x3958000d,0xd1e00092,0x00000000,0x00000000}},	//   _emps_, _ዐቃቤ_, --, --, 
   {{0xa2c40882,0x5694021f,0x6d840162,0xbebc00c0}},	// [1ba30] ारस्, затт, yðal, pjūv, 
   {{0x66dc01e1,0xf1d000bc,0xe7e400cc,0x00000000}},	//   _bàkà, _सिजन, _পনীয, --, 
   {{0x18680120,0xa5b80248,0xe4a40124,0x07340108}},	//   _гаќи_, _oróg, арҵо, _деню, 
   {{0x2910fbdb,0xd8b804fb,0xef04004b,0xefcc0092}},	//   _haxa_, _پدیا_, _غټ_, _ጣሪያ_, 
   {{0x2911230f,0x4174075e,0xd04806be,0xdb9c010f}},	//   _kaxa_, ياتس, _iddə, אסאר, 
   {{0xa5b8008c,0x7fd84f33,0x660c0113,0x59dc76f8}},	//   _próf, афит_, _isck, _बिसर, 
   {{0x29112310,0xcfb400bd,0x6d84041e,0xa5b8007b}},	//   _maxa_, _টিউন, rðal, _bróg, 
   {{0xff502084,0xefb8001f,0x26c800f3,0x29112311}},	//   بخت_, ተማዋ_, _jeco_, _laxa_, 
   {{0xee342ecc,0x161c1533,0x26c80077,0xa5b81d1d}},	//   жны_, नियर_, _meco_, _dróg, 
   {{0x25a0090c,0x2910004b,0xa5b92312,0xe2c400f1}},	//   _jijl_, _naxa_, _eróg, _خوړو_, 
   {{0x25a001a4,0x412801e0,0x28bc8109,0x00000000}},	//   _mijl_, _йоҡо_, ्रनि, --, 
   {{0x26c800bc,0xa5b80162,0x00000000,0x00000000}},	//   _neco_, _gróg, --, --, 
   {{0x29112313,0x612c12e8,0x25a80f85,0x00000000}},	//   _baxa_, _søly, _nucl_, --, 
   {{0x2910011f,0x3b1002d1,0x25a001f5,0xf1b0011a}},	//   _caxa_, _wayq_, _nijl_, וסך_, 
   {{0x26c92314,0xa9640256,0x2ba0000d,0x109400d1}},	//   _beco_, цира_, _ऐंचा, ﻜﯩﺪﯨ, 
   {{0xdb052315,0x26c8011c,0x36380092,0x684000d4}},	//   _kuní, _ceco_, _የመግዛ, єнта, 
   {{0x29112316,0x26c85182,0xdb040407,0x25a0257d}},	// [1ba40] _faxa_, _deco_, _juní, _bijl_, 
   {{0x29100117,0x88e00729,0x237c0113,0xdb0400d7}},	//   _gaxa_, ম্বক, _akuj_, _muní, 
   {{0xb6a52317,0xdb0400d0,0x2b980055,0x00000000}},	//   _минл, _luní, _sūci_, --, 
   {{0xa5b8fb73,0x291001e2,0x660c02d0,0x2b9800ef}},	//   _bród, _zaxa_, _fsck, _pūci_, 
   {{0xa5b80332,0x29112318,0xae9000e4,0x00000000}},	//   _cród, _yaxa_, tỹme, --, 
   {{0x614034d8,0x29100107,0x2bd80034,0x26c8009f}},	//   меча, _xaxa_, _भिला, _zeco_, 
   {{0x74152319,0xb4e42871,0xa5b80436,0xdb04026c}},	//   _بوزا, फली_, _próg, _punì, 
   {{0x6d841873,0xa5b803b2,0x25a001f5,0xf8c4daf5}},	//   rðam, _fród, _zijl_, वरुप, 
   {{0x5f70212d,0x28bc16d1,0x2d0401b9,0x00000000}},	//   باور, ्रमि, оянг, --, 
   {{0x71705841,0xefb80020,0x637401f2,0xe29c032e}},	//   _تۇتا, ተማው_, ụnta, _úða_, 
   {{0xc0e802d3,0xaa7800c7,0x00000000,0x00000000}},	//   ዚኦም_, ngýv, --, --, 
   {{0x92dc1c82,0x6da5231a,0x2911231b,0xada401c0}},	//   ত্ৰ_, _дида, _saxa_, _дадл, 
   {{0x26c9231c,0xf8c4085c,0x32c001a9,0x67185c0e}},	//   _reco_, वरूप, _mаy_, _पोषक_, 
   {{0x26c81dec,0x29100548,0x1d040d1d,0x00000000}},	//   _seco_, _qaxa_, _мечи_, --, 
   {{0x26c9177b,0xa1540302,0x6d49231d,0x69d4012d}},	//   _peco_, קבלה_, _ilfa, _बिकी, 
   {{0x29107fc5,0xd6a80116,0x00000000,0x00000000}},	//   _waxa_, ەدەم_, --, --, 
   {{0x2911231e,0x25a00d27,0x26c800e2,0x48c40139}},	// [1ba50] _taxa_, _pijl_, _veco_, _нәва, 
   {{0x290400ae,0x00000000,0x00000000,0x00000000}},	//   _úna_, --, --, --, 
   {{0x25a001f5,0xe6c400ae,0x00000000,0x00000000}},	//   _vijl_, _وتحي, --, --, 
   {{0xdc98010f,0x13683cd7,0x7c2402d2,0x00000000}},	//   ביבל, ошчи_, _áhre, --, 
   {{0x6d482b92,0x25a001f5,0xe0cc0154,0xf6b40115}},	//   _olfa, _tijl_, রলসভ, _מהרש_, 
   {{0xe61c0429,0x6b680210,0x550401a9,0x00000000}},	//   _irô_, węgl, _очса, --, 
   {{0x25e045bf,0x69c80073,0x00000000,0x00000000}},	//   टंकी_, तीती, --, --, 
   {{0xdb05231f,0x9f440240,0x59dc000d,0xe800000d}},	//   _puní, munë_, _बिलर, _लहना_, 
   {{0x64900153,0xa5b802d2,0x81b40154,0x00000000}},	//   _džiū, _hrób, _ঝিক_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xed4d2320,0x9f440200,0x00000000,0x00000000}},	//   _ҷо_, nunë_, --, --, 
   {{0x6d492321,0xdb052322,0x00000000,0x00000000}},	//   _elfa, _tuní, --, --, 
   {{0x9e652323,0xed4d2324,0xdb040311,0x64c80073}},	//   _باان, _зо_, _punâ, िराळ, 
   {{0xfbd00597,0x6d440200,0x00000000,0x00000000}},	//   _كتب_, ëkat, --, --, 
   {{0xe61c0022,0xb8641671,0x9f440200,0x00000000}},	//   _arô_, ساسو, junë_, --, 
   {{0x6d8403b2,0x00000000,0x00000000,0x00000000}},	//   yðak, --, --, --, 
   {{0xa5b80241,0x6d480076,0x6d8402d2,0x00000000}},	// [1ba60] _arób, _ylfa, fðah, --, 
   {{0x28bc00cd,0xb4e404e4,0x00000000,0x00000000}},	//   ्रणि, फले_, --, --, 
   {{0x49141f13,0xe7e81533,0xe61d2325,0x733400ec}},	//   _फोटो_, जूदा_, _erô_, ٻرائ, 
   {{0x7944001f,0x3668030d,0x00000000,0x00000000}},	//   _ያለበት, _гамо_, --, --, 
   {{0x46800046,0x06800022,0xf1c401f9,0x00000000}},	//   _ақта, _аҳтн, रींन, --, 
   {{0x9f452326,0x92cc0154,0x61100108,0x00000000}},	//   lunè_, ললে_, едшу, --, 
   {{0x28bc3f55,0x8f352327,0x24b40014,0x3fc801b9}},	//   ्रति, дейц, _رۆنگ_, قگنی_, 
   {{0xefd41540,0x64a036c8,0x4374004e,0x794c0092}},	//   _ራእይ_, _часа, _жуут, _ፕሮቴስ, 
   {{0xa5b80210,0x00000000,0x00000000,0x00000000}},	//   _zrób, --, --, --, 
   {{0xe80c00bc,0x00000000,0x00000000,0x00000000}},	//   ाबमा_, --, --, --, 
   {{0x7abc0490,0xccf80118,0xa5b8012d,0x00000000}},	//   _व्हॅ, dnět_, _króc, --, 
   {{0xefb80020,0xbebc00de,0x7804012d,0x00000000}},	//   ተኛው_, sjūr, शबैक_, --, 
   {{0x7bc402d1,0x6d840174,0x00000000,0x00000000}},	//   _çhun, yðah, --, --, 
   {{0x6d487d96,0x2d946779,0x00000000,0x00000000}},	//   _ulfa, _эрес, --, --, 
   {{0xa2741772,0x59840064,0x00000000,0x00000000}},	//   _ኪዳንን_, хлёб, --, --, 
   {{0xe61d2328,0x48e813f5,0x00000000,0x00000000}},	//   _prô_, _जाको_, --, --, 
   {{0xaac12329,0xdb043ea9,0xc5380b2c,0x4975232a}},	// [1ba70] _व्यक, _etnó, опах_, _олис, 
   {{0xa5b9232b,0x9f440023,0x92cc0154,0xe970210e}},	//   _prób, tunë_, ললো_, _سنجھ, 
   {{0xa5b867ca,0x92cc03d4,0x4db800fe,0x00000000}},	//   _bróc, ললৈ_, _ইটোৱ, --, 
   {{0x545401c0,0x18681fbe,0xdb0401ef,0x00000000}},	//   эвхт, _хаџи_, _kuná, --, 
   {{0xdb040306,0xa5b8012d,0x00000000,0x00000000}},	//   _juná, _wrób, --, --, 
   {{0x9f45232c,0x01640022,0x00000000,0x00000000}},	//   muné_, ькло, --, --, 
   {{0xdb040306,0x9f440214,0x00000000,0x00000000}},	//   _luná, luné_, --, --, 
   {{0xbea4011c,0x00000000,0x00000000,0x00000000}},	//   майк, --, --, --, 
   {{0xdb0801a8,0x9ea401ec,0x7af801d3,0x00000000}},	//   ílík, овқа_, őttk, --, 
   {{0x61e8026c,0x9f4400d0,0x48e802a0,0x0dc80114}},	//   mugl, ntnú_, _जागो_, чући_, 
   {{0x3b0809ed,0x00000000,0x00000000,0x00000000}},	//   оено_, --, --, --, 
   {{0x9f4404fb,0xdb05232d,0xd14800db,0x00000000}},	//   kuné_, _buná, _وشەن_, --, 
   {{0x9f45232e,0x61e807de,0x8aa4030d,0x3e680214}},	//   juné_, nugl, ерёд, _بجای_, 
   {{0x9f4400f2,0xdb0401d3,0x395c068c,0xdd980798}},	//   duné_, _duná, òts_, _уше_, 
   {{0xccf403ee,0xa9a1232f,0x61e828bf,0x00000000}},	//   _яқэ_, тирд, hugl, --, 
   {{0x7bc12294,0x61e8ab35,0x9f44020c,0xa6d8032e}},	//   mplu, kugl, funé_, _loðf, 
   {{0x7bc12330,0x35a401c0,0x9f4400f2,0xc7640116}},	// [1ba80] lplu, дааг, guné_, رافى, 
   {{0x61e852fd,0xaa7803b2,0x00000000,0x00000000}},	//   dugl, rgýt, --, --, 
   {{0x7bc12331,0x7f8400d8,0xa5b92332,0x00000000}},	//   nplu, lóqu, _próc, --, 
   {{0x61e92333,0x72882564,0x9f4400f2,0xf204dba2}},	//   fugl, обег_, buné_, дяко, 
   {{0x61e890cb,0xdb040036,0x7f8400d8,0x92640214}},	//   gugl, _viiè, nóqu, رگرم, 
   {{0x7bc0986a,0xa5b80034,0x00000000,0x00000000}},	//   kplu, _wróc, --, --, 
   {{0x64a09ad7,0xa5b8007b,0x61e808a5,0x00000000}},	//   _аара, _tróc, augl, --, 
   {{0xc3b801c0,0xa5b8032e,0x916001e1,0x00000000}},	//   _хурц_, _hróa, bò̟_, --, 
   {{0x61e92334,0x6ce52335,0xc4080050,0xa5b808a5}},	//   cugl, міне, _وتہٕ_, _króa, 
   {{0x60e40116,0x00000000,0x00000000,0x00000000}},	//   _омум_, --, --, --, 
   {{0x28bc17c6,0x7bc04536,0x9184129d,0x00000000}},	//   ्रसि, gplu, _قۇچۇ, --, 
   {{0x3a2401fa,0x9f4400f2,0x00000000,0x00000000}},	//   _šopa_, yuné_, --, --, 
   {{0x9a8444b2,0x5a3416ab,0x9f4400d0,0x2bd80073}},	//   вурл, внят, ytnú_, _भिका, 
   {{0x6e212336,0x2d992337,0x00000000,0x00000000}},	//   _irob, _òpe_, --, --, 
   {{0xfe6c168d,0x6e200122,0x61e8b1e1,0x9f440066}},	//   _نگی_, _hrob, zugl, wuné_, 
   {{0x9f440214,0xe7e81100,0x7c2402d2,0x6d8402d2}},	//   tuné_, जूषा_, _áhra, gðav, 
   {{0x3b0402d1,0x6f0100fd,0xd2451acc,0x69c80073}},	// [1ba90] _ñoqa_, _mboc, _ئۆ_, तीशी, 
   {{0x6e20031c,0x78a00115,0x61e8ed9b,0x59080327}},	//   _mrob, _ŝove, vugl, _ཆིགས_, 
   {{0x6f000030,0x9f452338,0x09e400cc,0xa85001ee}},	//   _oboc, suné_, _পৈচা, _ренә, 
   {{0x6e212339,0x9f45233a,0x42742f89,0x66180024}},	//   _orob, stnú_, нгес, _šuku, 
   {{0xa225233b,0x6e20020c,0x00000000,0x00000000}},	//   براه, _nrob, --, --, 
   {{0x6f01233c,0xa6d80413,0x80140b96,0x7bc00076}},	//   _aboc, _boðg, ефиц, yplu, 
   {{0x6e21233d,0x61e81505,0x6f0001ab,0x6368084c}},	//   _arob, sugl, _bboc, _драг_, 
   {{0x6e21233e,0x61e8c044,0x7ed4114f,0x00000000}},	//   _brob, pugl, رزبا, --, 
   {{0x7a04016b,0x6e21233f,0x3994005c,0x00000000}},	//   _kɔte, _crob, læse_, --, 
   {{0x2bd87db3,0x6f0002e2,0xa2c409fa,0xfbc4004e}},	//   _भिखा, _eboc, ारक्, нбоо, 
   {{0x6e212340,0xdb040798,0x9ac400ee,0xfce400c7}},	//   _erob, _junç, кинҗ, _ҷоло, 
   {{0x6f000521,0xf090008d,0x7bc40076,0x7bc02517}},	//   _gboc, _גנב_, _çhum, rplu, 
   {{0xdc381068,0xfce44d0b,0xe9d402e8,0x7f480200}},	//   _išče, _золо, нкя_, mkeq, 
   {{0x7bc12341,0x7f84315a,0x6e38011a,0xa6d8032e}},	//   pplu, róqu, _מתנד, _loðd, 
   {{0x6e20006d,0xe7e80490,0x59dc00c5,0x098801b9}},	//   _zrob, जूला_, _बिकर, фарқ_, 
   {{0xe7352342,0xa7a40f37,0x7f48013c,0x3994005c}},	//   нес_, екса_, nkeq, dæse_, 
   {{0xb8f409bd,0x6d840436,0x2614007d,0x6e20031c}},	// [1baa0] _হা_, rðav, निगी_, _xrob, 
   {{0x236c0097,0xdb040139,0xa68018e3,0x00000000}},	//   engj_, _bunç, улуд, --, 
   {{0xe1ec1473,0xf7452343,0x7f480869,0xdce00171}},	//   ەسى_, _зено, kkeq, _aknī, 
   {{0xa5b810e6,0xa2c400cd,0x00000000,0x00000000}},	//   _irón, ारग्, --, --, 
   {{0xaa7800c7,0x00000000,0x00000000,0x00000000}},	//   ngýp, --, --, --, 
   {{0xa5b826b8,0xdb052344,0x6f006933,0x6e2002d3}},	//   _krón, _funç, _sboc, _rrob, 
   {{0xdb052345,0xe1f401c0,0xa2c40490,0x59d02677}},	//   _kunä, _үгс_, ारख्, तीतर, 
   {{0xbd00056a,0x23f80677,0xb78400a2,0x00000000}},	//   ñénd, _מהלא, meỳä, --, 
   {{0xdb040054,0xb225097f,0x52cc012c,0x6e200327}},	//   _munä, _ямал, ारीस, _qrob, 
   {{0x7af52346,0x9f440ffb,0x06a40150,0x00000000}},	//   _acyt, lunì_, _ﻋﺭﻴﺽ_, --, 
   {{0x3d24006a,0x8da40133,0x6e2015c0,0x00000000}},	//   _sëwä_, _یشتۆ, _wrob, --, 
   {{0x6e212347,0x6f012348,0xdb0429ef,0x59dc1d15}},	//   _trob, _uboc, _nunä, _बिखर, 
   {{0x6e2001a2,0xa5b802f0,0xc0d40092,0x6d8408a5}},	//   _urob, _arón, _ራስህ_, fðat, 
   {{0xa5b8007b,0x8f00030d,0x6d84032e,0x00000000}},	//   _brón, _гiу_, gðat, --, 
   {{0x1cb405e1,0xa5b81280,0x2d9d2349,0xd7e43334}},	//   _אלול_, _crón, mmte_, літо, 
   {{0x2d9c0942,0xb78400a2,0x27fc0327,0x00000000}},	//   lmte_, deỳä, ċun_, --, 
   {{0x7a04016b,0xb50002ab,0x44f40137,0x00000000}},	// [1bab0] _pɔte, र्भय_, кпас, --, 
   {{0xdb0403f0,0x236c0007,0xeb9c332e,0x64c802c3}},	//   _punç, wngj_, lmø_, िरेश, 
   {{0x9cd4025f,0x2d9c0ae3,0xe8bc0a59,0x550464c2}},	//   גובה_, imte_, ्रीच, ычта, 
   {{0x7a04016b,0x2d9d234a,0x4908012c,0xdb0400a2}},	//   _wɔte, hmte_, ाजको_, _gunä, 
   {{0xe4e402bf,0x37d40154,0x4ad80037,0x00000000}},	//   _півн, _তৎপর, _भजनव, --, 
   {{0xdb05234b,0x6d84148b,0x00000000,0x00000000}},	//   _zunä, iðas, --, --, 
   {{0x7f4802d3,0xdb040724,0xd4a4014b,0x161c01f9}},	//   tkeq, _yunä, _биёй, निअर_, 
   {{0x2d9c022f,0x4395234c,0x2bd80bae,0xaec002e8}},	//   emte_, _рабс, _भिजा, абъл, 
   {{0xef15234d,0xc1144c70,0xe73c0124,0x7f480023}},	//   тмы_, _имај, _moõ_, rkeq, 
   {{0x7af5234e,0x61f82d2f,0x7f480194,0x63b80e04}},	//   _scyt, _iqul, skeq, _čunj, 
   {{0x44200158,0x2bc4010b,0x7c940133,0x00000000}},	//   nvh_, клэп_, کشکا, --, 
   {{0x2d9cfb2f,0x6d84032e,0x08c40150,0x00000000}},	//   amte_, fðas, ңғып_, --, 
   {{0x6d8401a8,0xa5b80332,0x3f8c054e,0xe8bc01f9}},	//   gðas, _srón, mleu_, ्रूच, 
   {{0x17c80364,0x3f8c41a0,0x61f80944,0xdd9818ce}},	//   нҳои_, lleu_, _mqul, _эше_, 
   {{0x48790abf,0x6d840321,0xbc180212,0xb8e80037}},	//   естя_, rðat, _цілі_, _ऊभ_, 
   {{0x3a240124,0x66e05822,0x61f80472,0xba24084c}},	//   _амиг, иоса, _oqul, _адик, 
   {{0x61f80472,0x66180cf4,0xa6d80413,0x00000000}},	// [1bac0] _nqul, _šukr, _boðb, --, 
   {{0xa5b8ef49,0xe575234f,0x44200334,0x00000000}},	//   _trón, взу_, fvh_, --, 
   {{0x61f92350,0x44200c6a,0xa5b8032e,0xd37000d1}},	//   _aqul, gvh_, _hról, مۇس_, 
   {{0xf744ae46,0xa5b80034,0x798c03cb,0x00000000}},	//   _ремо, _król, llbw, --, 
   {{0x6d842880,0xe2804d87,0x61b00014,0x54c401ec}},	//   iðar, алци, لٕنا, _бұзб, 
   {{0x7c2c0166,0x00000000,0x00000000,0x00000000}},	//   _ƅarl, --, --, --, 
   {{0xb500433a,0x61f800f1,0x3f8c03cb,0xb4cc012c}},	//   र्णय_, _equl, fleu_, ररी_, 
   {{0x6d8406ea,0x3f8c01a6,0xe3b40798,0x644001f4}},	//   yðas, gleu_, _јбт_, änie, 
   {{0x43752351,0x2d9c0270,0x00000000,0x00000000}},	//   _сурт, tmte_, --, --, 
   {{0x80c009b2,0x2d9d2352,0xdfcc00ec,0x00000000}},	//   रुदे, umte_, _ڀيل_, --, 
   {{0xc0a92353,0x2d9c23f5,0xa5b80241,0x6fb52354}},	//   _كامل_, rmte_, _aról, _شمشا, 
   {{0x6d840008,0x3f8d2355,0xdee0030d,0x7d0008a5}},	//   gðar, cleu_, _воци, afls, 
   {{0x9b592356,0x9f4401f1,0xa5b801e7,0xca4801b9}},	//   тият_, ntný_, _cról, رلسه_, 
   {{0x6d8426b8,0x86900882,0x78a000df,0xa5b80332}},	//   rðas, ṃskā, _ŝova, _dról, 
   {{0x1b081c82,0x58d45e3e,0x6db0012d,0x00000000}},	//   ষয়ে_, рост, _błag, --, 
   {{0x9f4401f1,0x9b6800c7,0x5c340375,0x69f000db}},	//   ktný_, _ашьа_, _ירון_, _күмт, 
   {{0xab600075,0x38780419,0x996801d9,0x68f40051}},	// [1bad0] _مۇھى, _expr_, رمہٕ_, _tcxd, 
   {{0xe29c02d2,0x01e000cc,0x00000000,0x00000000}},	//   _úði_, _মঙলদ, --, --, 
   {{0x47d40150,0x0630001f,0xc0c4035b,0x00000000}},	//   _حيجر, _በያዝነ, ҳәеи, --, 
   {{0xd4990a1b,0xd054013f,0x6db0033f,0x59d005c0}},	//   тру_, _ɑbɔd, _kład, तीवर, 
   {{0x672c0354,0x3f5000e4,0xdb0401e3,0xc0c4035b}},	//   _incj, _náua_, _ttnö, гәеи, 
   {{0x5908081f,0xd1842626,0x04c92357,0xdb0c02d2}},	//   _ཆིབས_, алій, _سوري_, _íhöf, 
   {{0x6d8409f3,0x0084023a,0x9f440407,0x787001d3}},	//   yðar, ылко, suní_, művé, 
   {{0xacc400fd,0x3250070e,0x80b40022,0xa07001ec}},	//   ңгыз_, рвәр, _ӡбах, лықш, 
   {{0x61f92358,0x3f8c00db,0xc27416a4,0x00000000}},	//   _uqul, rleu_, _слај, --, 
   {{0x25e92359,0x51840676,0xe8bc17c6,0x00000000}},	//   _चिनी_, _куха, ्रोच, --, 
   {{0x3f8c00ca,0x00000000,0x00000000,0x00000000}},	//   pleu_, --, --, --, 
   {{0xa5b9235a,0x00000000,0x00000000,0x00000000}},	//   _pról, --, --, --, 
   {{0x6d841c38,0xee2d235b,0x9f4405d5,0xa5b802d2}},	//   rðar, _ун_, munà_, _bróm, 
   {{0x672d235c,0xa5b80332,0x61e80332,0x00000000}},	//   _ancj, _cróm, irgl, --, 
   {{0x1b040220,0xa5b8032e,0xdb0402d2,0xac140114}},	//   _күнн, _dróm, _munú, _боју_, 
   {{0x9f4402fb,0x3654001f,0xd6c400c7,0x2564035b}},	//   ytný_, _ለመግዛ, риақ, ҳауп_, 
   {{0x76242d31,0xa5b817b6,0x6db0033f,0x75d4007b}},	// [1bae0] ымаз, _uról, _gład, ايطا, 
   {{0xe615235d,0xd76404fb,0x9f4407de,0xe564009d}},	//   ыду_, _چندی, hunà_, гиуд_, 
   {{0x23480066,0x00000000,0x00000000,0x00000000}},	//   کسلی_, --, --, --, 
   {{0x9f45235e,0x32d40f87,0x00000000,0x00000000}},	//   junà_, ازاس, --, --, 
   {{0xdb0400c6,0x9f4404cc,0x23740131,0xe29485ce}},	//   _bunú, dunà_, ھمۇد_, гац_, 
   {{0x9f4400d0,0x05b00acd,0xd01000ae,0x753401c4}},	//   rtný_, जदरब, قلت_, _сэмх, 
   {{0x9f45235f,0x61e8011c,0xdfe4035b,0x96b80b27}},	//   stný_, argl, гьыл_, _अलाउ, 
   {{0x9f4408e5,0xe3a400e5,0x00000000,0x00000000}},	//   gunà_, _مشقی, --, --, 
   {{0x70f479f8,0x63b801fa,0xaed001d5,0x00000000}},	//   _مسائ, _čuni, аоқш, --, 
   {{0x551405f9,0x00000000,0x00000000,0x00000000}},	//   ड़िए_, --, --, --, 
   {{0x9f440ffb,0xc0c40023,0xad240046,0x3074010a}},	//   bunà_, ጺኦም_, _ەربو, _суас, 
   {{0x9f4404cc,0x195802dd,0xe8bc07b7,0x00000000}},	//   cunà_, қасы_, ्र्च, --, 
   {{0x55140cb4,0xa5b80413,0x00000000,0x00000000}},	//   ड़ाए_, _próm, --, --, 
   {{0xb8e40022,0x64400feb,0x00000000,0x00000000}},	//   иссқ, ønik, --, --, 
   {{0x6db00034,0x8e24022e,0xa5b8012d,0x2900031c}},	//   _wład, namо_, _grój, rfja_, 
   {{0xa6d808a7,0x7a040134,0x9f44219b,0x61e80142}},	//   _boða, _wɔta, trné_, yrgl, 
   {{0x9f440129,0x00000000,0x00000000,0x00000000}},	// [1baf0] urné_, --, --, --, 
   {{0x61e80427,0xba1801ec,0xa6d802d2,0xddc8031c}},	//   vrgl, _شيپا_, _doða, _ġiżw, 
   {{0xa5b80ad9,0x37c00075,0x885800c7,0x98c400fb}},	//   _krók, _мәтб, _ринс_, _усыл, 
   {{0x9f440784,0x28bc076e,0x00000000,0x00000000}},	//   kuná_, ्रकि, --, --, 
   {{0x3f5001e1,0x63140154,0xa6d809e8,0x61e803ac}},	//   _báun_, ণালয়_, _goða, urgl, 
   {{0x26d80009,0x802401d5,0xe4a400f3,0x00000000}},	//   laqo_, لرعم, _брбо, --, 
   {{0x4fc40dd8,0xe9dc00c6,0x7580036b,0x9f4405d5}},	//   مەلە, hsú_, _بیلم, tunà_, 
   {{0x6f6000d1,0x00000000,0x00000000,0x00000000}},	//   يۇلم, --, --, --, 
   {{0x00e424c5,0xc0bc001f,0x6564037e,0x9f44026c}},	//   _نتای, ሰራር_, _kmjh, runà_, 
   {{0xa5b80407,0x00000000,0x00000000,0x00000000}},	//   _prój, --, --, --, 
   {{0x9f440ffb,0x4f0801ec,0x4a900055,0x26d803b9}},	//   punà_, _әнін_, _īyuḥ_, kaqo_, 
   {{0x34b02aa1,0x60d4005f,0xfaa43129,0x78a001e4}},	//   _जल्द, šamī, иано, _ŝovo, 
   {{0x26d8047e,0x00000000,0x00000000,0x00000000}},	//   daqo_, --, --, --, 
   {{0xa5b80034,0x9ce401ed,0xa6d81427,0x4ea4074d}},	//   _trój, _صوبے_, _roða, _урха, 
   {{0xb8fc00c5,0x26d80067,0x6840030d,0xf744005b}},	//   _ढ़_, faqo_, онра, аево, 
   {{0x26d8021a,0x36c40137,0x00000000,0x00000000}},	//   gaqo_, рбаг, --, --, 
   {{0xa7a52360,0x68f80fcf,0xe9dc5821,0x00000000}},	// [1bb00] ркта_, đudr, csú_, --, 
   {{0xa6d801a8,0x00000000,0x00000000,0x00000000}},	//   _voða, --, --, --, 
   {{0x7a04013f,0xb38401c0,0x26d8058a,0x00000000}},	//   _kɔto, алжл, baqo_, --, 
   {{0xb2252361,0xa3e4023a,0xd7646813,0x31c402e8}},	//   имел, рдца_, _چنگی, аскв, 
   {{0xf8d800e1,0x88d800fe,0x62600108,0x00000000}},	//   _बजाय, _তাতক, овца, --, 
   {{0x74152362,0xe0cc0220,0xf8b4012d,0x00000000}},	//   _پورا, وزى_, ंशिय, --, 
   {{0xd01000c6,0xd1b0036b,0xa15400d4,0x2564004e}},	//   سلة_, _کیتک, ращу_, _тарп_, 
   {{0x245000c6,0x8f340588,0xeba803b2,0xa6d808a5}},	//   _بنفس, сеиц, _mjøð_, _loðn, 
   {{0x6db00034,0xa5b804d4,0x161c230e,0x00000000}},	//   _słab, _esóf, निटर_, --, 
   {{0xad440120,0xbdc800e5,0x00000000,0x00000000}},	//   рхик, اگنے_, --, --, 
   {{0xaf352363,0xa5b802d2,0xa4b4011a,0x00000000}},	//   _پرات, _prók, יליה_, --, 
   {{0x9f440418,0xc0f00092,0xdfcc01c8,0x00000000}},	//   puná_, ሂዷል_, _آين_, --, 
   {{0xce3401d5,0xa6d809e8,0xa5b801d3,0xe9440024}},	//   _دوشک, _boðn, _zsóf, ахво, 
   {{0xdd8c02dd,0x26d80107,0xeabc026c,0xecf001ec}},	//   _قون_, waqo_, scù_, _بۋدد, 
   {{0x26d80a73,0x984800a7,0x91d80cf1,0x8ccc6766}},	//   taqo_, аята_, _नौसै, _द्यो, 
   {{0x442c4859,0x8a181621,0x6d580455,0xb0c40825}},	//   _če_, _боис_, lhta, रुतग, 
   {{0x26d80009,0x64b4009a,0xaa78010e,0x00000000}},	// [1bb10] raqo_, لحضر, daýg, --, 
   {{0x26d8011f,0x6d58004d,0xe7ec05b3,0x04c801c8}},	//   saqo_, nhta, _छिपा_, اوضي_, 
   {{0xee240451,0x6d580108,0x00000000,0x00000000}},	//   _کٽ_, ihta, --, --, 
   {{0x37c018ce,0x2ee400e8,0x26d80472,0xaa7800e4}},	//   _хәрб, _ndof_, qaqo_, gaýg, 
   {{0x6d592364,0xb40407d6,0x826801ed,0x00000000}},	//   khta, _қўрқ, دشاہ_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x44252365,0x3f6815ed,0x6d592366,0xd70c03d4}},	//   _él_, лико_, dhta, ৱাৰা_, 
   {{0x7c24008c,0x18780375,0xe7ec000d,0x00000000}},	//   _áhri, יעור_, _छिना_, --, 
   {{0xa5b8007b,0x3cd80d30,0x2ee40042,0xdcfc0166}},	//   _brói, льню_, _ddof_, _şvıy, 
   {{0x6d58b006,0x987805a1,0xa5b800c6,0x3cc80137}},	//   ghta, _ušća_, _crói, ылоо_, 
   {{0x40952367,0x6db00034,0x3b840137,0x3f5008a5}},	//   _الار, _płac, йлог, _háum_, 
   {{0x3f9c0433,0xa6d808a5,0x6d5801f4,0xaa780432}},	//   _uhwu_, _soðn, ahta, kaýd, 
   {{0xee2d2368,0x427800c8,0x6d5807f0,0x99800e04}},	//   _эн_, ראָג, bhta, _ariš_, 
   {{0x6d592369,0xb86410fe,0x7a040134,0x8d840372}},	//   chta, مازو, _wɔto, _وشون, 
   {{0xa5b9236a,0x28bc00cd,0xb9f800eb,0x00000000}},	//   _ysóg, ्रजि, েটেড_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x644004f3,0x3f5008a5,0xa5b8012d,0xaa780432}},	// [1bb20] änin, _náum_, _mrów, gaýd, 
   {{0xd91016f5,0x6a38010f,0xcbe400c7,0x37e4004e}},	//   _تیس_, _עגיפ, _уцәи, _лоог, 
   {{0xa92001c6,0xa50402e8,0x6299236b,0x00000000}},	//   _эдэл, сеха_, _azuo, --, 
   {{0xd04803be,0x3f5003b2,0xaa78010e,0x00000000}},	//   _gedə, _báum_, baýd, --, 
   {{0x06740209,0x63001176,0x93c801d3,0x00000000}},	//   _дуря, سوول, _چارہ_, --, 
   {{0xb1c40075,0x09bc0154,0x00000000,0x00000000}},	//   иңға_, _অবমা, --, --, 
   {{0x6298063f,0x80d82232,0xd04806be,0x9f4400d7}},	//   _ezuo, _नजरे, _yedə, arní_, 
   {{0x3f500ad9,0xa5b80332,0xaa78010e,0x00000000}},	//   _fáum_, _srói, laýe, --, 
   {{0xa5b80597,0x6d59236c,0xd01001ed,0xe2940395}},	//   _prói, thta, سلک_, _гат_, 
   {{0x6f08002b,0xaa78010e,0x00000000,0x00000000}},	//   _śocā, naýe, --, --, 
   {{0x6d9c010e,0xa6d808a5,0x00000000,0x00000000}},	//   _açaý, _boðl, --, --, 
   {{0x6d59236d,0xa5b80022,0x62980175,0x272c0166}},	//   shta, _iróv, _yzuo, _mönä_, 
   {{0xa5b800d8,0x6d5802d0,0xaa78010e,0x00000000}},	//   _trói, phta, kaýe, --, 
   {{0x6d580054,0xa5b8012d,0x9f4403e0,0xaa78010e}},	//   qhta, _zrów, tunç_, jaýe, 
   {{0xd83839d2,0x5eec00dc,0xaa78010e,0xfd6000a2}},	//   бэт_, _इयम्_, daýe, hsyỳ, 
   {{0xd6d9236e,0xf7ac08b0,0xfca80345,0x9f440205}},	//   йту_, _ﺳﺎﻧﺪ, _ئاهو_, runç_, 
   {{0x7bc402d1,0x00000000,0x00000000,0x00000000}},	// [1bb30] _çhur, --, --, --, 
   {{0x644001b8,0x290401c3,0x3f5003b2,0xdb0400a2}},	//   änio, _ùna_, _ráum_, _muný, 
   {{0x3f5008a5,0x00000000,0x00000000,0x00000000}},	//   _sáum_, --, --, --, 
   {{0x4255236f,0x9f440306,0x59d12370,0x7e6c010e}},	//   ينار, trní_, तीकर, _ýapg, 
   {{0xc0d002d3,0x1b7c010f,0xaa78010b,0x00000000}},	//   _ኩናማ_, נטדע, baýe, --, 
   {{0x40480022,0x00000000,0x00000000,0x00000000}},	//   ипло_, --, --, --, 
   {{0x842404a9,0x14280212,0xa6d802d2,0x92b800fe}},	//   _بىزن, _літо_, _loðm, ছৰে_, 
   {{0xfde801b9,0x00000000,0x00000000,0x00000000}},	//   адик_, --, --, --, 
   {{0xbd3802bf,0x62980153,0x00000000,0x00000000}},	//   аїні_, _uzuo, --, --, 
   {{0x272c023a,0xdb04010e,0x236c0240,0x270403d4}},	//   _yönä_, _duný, ligj_, ৱাটো_, 
   {{0xca286da4,0xa5b803b2,0xac80009d,0x00000000}},	//   _שם_, _gróv, дгэл, --, 
   {{0xa6d803b2,0xaa7800ee,0x00000000,0x00000000}},	//   _boðm, daýb, --, --, 
   {{0x8d752371,0xfce4fe4e,0x2d8c0418,0x00000000}},	//   _کانا, _доло, _fkfe_, --, 
   {{0x0d840220,0xe50800dc,0x02d4033f,0x31b8010f}},	//   _елін, स्मि_, दरुन, יזשנ, 
   {{0xbb452372,0x4e3400cf,0x64400108,0x6db00210}},	//   _мекк, _وعۇز, änil, _kłan, 
   {{0xdc3800f3,0x236c0023,0x7bc40309,0x00000000}},	//   _ašće, jigj_, _çhuq, --, 
   {{0x88d8015b,0x7544014b,0x3dcc007f,0x6d9c00a2}},	// [1bb40] _তারক, оназ, npew_, _uçaý, 
   {{0xdb04014a,0xa68003f5,0x00000000,0x00000000}},	//   _lunü, флуд, --, --, 
   {{0xf7452373,0x293402e4,0xe8040030,0x15b83007}},	//   _дено, _ואין_, púšť, рығы_, 
   {{0x7334007b,0x3d08012d,0xb73000f1,0x00000000}},	//   غرائ, ़्ते_, _تېرک, --, 
   {{0x6728000f,0x931c015b,0x7e7c002d,0xd7880451}},	//   ôgje, ণালয_, ûspl, _ننڍو_, 
   {{0xa5b80579,0xc2c92374,0x61400640,0xb3c80014}},	//   _próv, لبۇل_, деља, _نظرٕ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x316c010a,0x00000000,0x00000000,0x00000000}},	//   sifz_, --, --, --, 
   {{0xa5b803b2,0xe2c40cc9,0x00000000,0x00000000}},	//   _fróu, _флуд_, --, --, 
   {{0xa5b802d2,0x320401a9,0x00000000,0x00000000}},	//   _gróu, mtoy_, --, --, 
   {{0x6b5c00e8,0x320401a9,0x00000000,0x00000000}},	//   _jëgg, ltoy_, --, --, 
   {{0x25e806ab,0xa5b8068f,0x39592375,0xe73c0051}},	//   _चिली_, _krót, _alps_, _khõe_, 
   {{0x6b5c002e,0x32040429,0xfd7801ed,0x5f8001ec}},	//   _lëgg, ntoy_, ششیں_, _تۇيە, 
   {{0xdb052376,0xe6d00e5b,0x09bc0eac,0x26dc0064}},	//   _zunü, तर्ज, _অবদা, _žuo_, 
   {{0xdb04014a,0x7bc40309,0x00000000,0x00000000}},	//   _yunü, _çhup, --, --, 
   {{0x97a40108,0x00000000,0x00000000,0x00000000}},	//   друл, --, --, --, 
   {{0xe4c8267e,0x56952377,0x00000000,0x00000000}},	// [1bb50] لبان_, датт, --, --, 
   {{0x6b5c1574,0xa5b8056a,0x39592378,0x00000000}},	//   _bëgg, _asóc, _glps_, --, 
   {{0xdb04002e,0x8ae803b9,0x00000000,0x00000000}},	//   _gunó, hkәm, --, --, 
   {{0x6b5c0694,0xa5b806ea,0x69cc01f5,0x00000000}},	//   _dëgg, _brót, opce, --, 
   {{0xa6d802d2,0x00000000,0x00000000,0x00000000}},	//   _loðk, --, --, --, 
   {{0x88d8015b,0x78a000df,0xb6180150,0xa5b831b7}},	//   _তাঁক, _ŝovi, _ﹼﺤ_, _drót, 
   {{0xa5b92379,0xe3140736,0x7adc01f9,0x00000000}},	//   _erót, _وبرب, परमॅ, --, 
   {{0x6619237a,0xfe4406ed,0xaf0002e8,0x00000000}},	//   _šuky, знио, епъл, --, 
   {{0xee35237b,0xa5b9237c,0xd34401ed,0x00000000}},	//   зны_, _tróu, _تہنی, --, 
   {{0x16b9237d,0xa6d803b2,0xd13867ba,0x6b5c0de2}},	//   _अल्ब, _boðk, _мхх_, _yëgg, 
   {{0x317800c8,0x3154010f,0xe8a00166,0x00000000}},	//   _פרעמ, _ציען_, _ızğı, --, 
   {{0xc9700201,0xe5080a28,0x3959237e,0x65680268}},	//   _ባለፈው_, स्ति_, _slps_, èghj, 
   {{0xe638032e,0x00000000,0x00000000,0x00000000}},	//   _aþþí, --, --, --, 
   {{0x20040a55,0x41dc102f,0xa7a400c7,0x00000000}},	//   otni_, नीयस, ҧкра_, --, 
   {{0x2005237f,0xa9652380,0x7e6c00a2,0x00000000}},	//   ntni_, чира_, _ýapb, --, 
   {{0x32052381,0x200401a8,0x3894001f,0x00000000}},	//   ytoy_, itni_, _መድረሱ_, --, 
   {{0x74e8152d,0x6b5c002e,0x6ef405d1,0x3205103e}},	// [1bb60] йдаг_, _dëgd, lübü, xtoy_, 
   {{0x200415ad,0xa504361e,0x00000000,0x00000000}},	//   ktni_, зефа_, --, --, 
   {{0x798c08cd,0xa5b8022c,0xaa7800ee,0x3f8c0077}},	//   mobw, _brós, maýa, koeu_, 
   {{0xa5b92382,0xaa7809a5,0x798c0161,0xa6d80165}},	//   _prót, laýa, lobw, _noðh, 
   {{0x20042600,0xa5b808a5,0xd31c03ce,0x64400162}},	//   etni_, _drós, _नसीब_, ønir, 
   {{0xe29400c7,0x798c66a0,0xf8bc1a4e,0xaa780209}},	//   чач_, nobw, ्डिय, naýa, 
   {{0xe5a12383,0x32052384,0xa6d8032e,0xba040b82}},	//   _чири, stoy_, _boðh, _ሎጥ_, 
   {{0xa5b92385,0x9f440216,0x09bc0154,0x3f8c0327}},	//   _grós, trná_, _অবসা, goeu_, 
   {{0x798c0537,0x2004f4dd,0xd2504451,0xaa7800ee}},	//   kobw, atni_, _جۆش_, kaýa, 
   {{0xefe8001f,0x20044167,0xefb8001f,0x00000000}},	//   መረው_, btni_, ሰማው_, --, 
   {{0xdeed2386,0x7bc00399,0x9be001ca,0xaa78010b}},	//   _пы_, gqlu, ніяк, daýa, 
   {{0x8ccc16ae,0x09b40490,0xedd400f1,0x98b80139}},	//   _द्रो, ंद्य, _فيصد, dirı_, 
   {{0x6f012387,0xdb04001e,0x60c801ed,0x6da40124}},	//   _icoc, _khiê, _élmé, _еида, 
   {{0x6e212388,0x64400844,0x1cb80135,0x798c1418}},	//   _isob, änik, _མུར_, gobw, 
   {{0x80e00eac,0xd138033f,0xd918005b,0x6ef406be}},	//   _নাম্, _mną_, чья_, cübü, 
   {{0x6d492389,0x4ac001ad,0x57b42077,0x69cc007c}},	//   _hofa, _एलिव, ебст, ppce, 
   {{0x6d49238a,0x798c1446,0xfd54002b,0xaa7800a2}},	// [1bb70] _kofa, bobw, _anaṅ, baýa, 
   {{0xdb0407ae,0x2005238b,0xecd8015b,0xe4a48e38}},	//   _nhiê, ytni_, _দাঁড, прео, 
   {{0xa5b9238c,0x6d49238d,0x9cd40375,0x1cb8031c}},	//   _prós, _mofa, פואה_, _མུལ_, 
   {{0x6d49238e,0x6f0001ab,0x9f4400d0,0x6464031c}},	//   _lofa, _ncoc, sunú_, _ħriġ, 
   {{0x6d49238f,0x6e20513a,0x96340024,0x00000000}},	//   _oofa, _nsob, _зняц, --, 
   {{0x90e420ea,0x6d492390,0x6f012391,0xdb040016}},	//   ىسىن, _nofa, _acoc, _chiê, 
   {{0x6e212392,0x90e52393,0x00000000,0x00000000}},	//   _asob, رسون, --, --, 
   {{0x3eb92394,0x6d4914c3,0x20052395,0xa6d82242}},	//   øst_, _aofa, rtni_, _boði, 
   {{0x20052396,0x6d492397,0x4430107d,0x798c895d}},	//   stni_, _bofa, _hrz_, yobw, 
   {{0x6d492398,0x3f8c00fb,0x2004107d,0x91840131}},	//   _cofa, soeu_, ptni_, _كۇنۇ, 
   {{0x6d48002e,0x6e212399,0x443004cc,0x200401d5}},	//   _dofa, _esob, _jrz_, qtni_, 
   {{0x44300e78,0x6d4802d0,0x798c0a1d,0x6f000332}},	//   _mrz_, _eofa, wobw, _gcoc, 
   {{0x6d49239a,0x6b5c002e,0x798d239b,0x6db0033f}},	//   _fofa, _bëgb, tobw, _złam, 
   {{0x6d480cfd,0x4430e07a,0x3f640129,0x290403e0}},	//   _gofa, _orz_, cœur_, _önal_, 
   {{0xaa780209,0x798c1556,0x4430002f,0x7bc00327}},	//   raýa, robw, _nrz_, qqlu, 
   {{0x6d49239c,0x798c0796,0xe735239d,0x27b0008e}},	//   _zofa, sobw, мес_, кәяс, 
   {{0x4431239e,0x6d49239f,0x2e38010f,0xaa7800a2}},	// [1bb80] _arz_, _yofa, ֿגענ, laýn, 
   {{0x1cb80003,0xa5b82b76,0xa5940014,0x260c000d}},	//   _མུས_, _prór, ودٕچ, _डहरी_, 
   {{0x4430003e,0x03c40220,0xe98400f7,0x64400158}},	//   _crz_, есім, _تايۋ, ønip, 
   {{0x3a305794,0x9f400ca8,0x00000000,0x00000000}},	//   _kryp_, _ìjè_, --, --, 
   {{0xdb0407ae,0x75200124,0x7234007b,0x4430002f}},	//   _phiê, _иҟаҵ, براط, _erz_, 
   {{0x6f0123a0,0x7a04013f,0xa6d80a87,0x410001f0}},	//   _scoc, _wɔtw, _roði, лҷув, 
   {{0x44300395,0xa5b808a5,0x6d487ce1,0xc0ec0092}},	//   _grz_, _hróp, _rofa, _ቀንም_, 
   {{0x733453f0,0x6e20017a,0xaa780432,0x8c880022}},	//   _تىرا, _psob, daýn, ҟәла_, 
   {{0xdb0407ae,0x6d4923a1,0x20cc0b7c,0x6db0012d}},	//   _thiê, _pofa, _स्वध, _włam, 
   {{0x6d4822a9,0x717000cf,0xa6d802d2,0x00000000}},	//   _qofa, _جۇتا, _voði, --, 
   {{0x6d480099,0x3a3000a2,0xa5b80248,0xbad80150}},	//   _vofa, _aryp_, _nsón, _ﺃﺩﺒﺎ, 
   {{0xee38100e,0x6f0123a2,0x6d4923a3,0x6e2005da}},	//   _мне_, _ucoc, _wofa, _tsob, 
   {{0x6d4923a4,0x6e2054da,0xe9280327,0x00000000}},	//   _tofa, _usob, _སྣུབ_, --, 
   {{0x3a30353e,0xa6d808a5,0x7e6c0432,0x872400e5}},	//   _dryp_, _joðv, _ýapa, کٹرم, 
   {{0xa5b8772a,0x9ca40451,0xddd8012d,0xe9dc01d3}},	//   _aróp, _ٺهيل_, czuł, gyúr_, 
   {{0xdb040051,0x00000000,0x00000000,0x00000000}},	//   _nhiè, --, --, --, 
   {{0x3a309eaa,0xeabc003a,0x07a40131,0x443000d7}},	// [1bb90] _gryp_, ndùm_, даңн, _srz_, 
   {{0xa5b803b2,0x7ce801d3,0x4430012d,0x00000000}},	//   _dróp, _törő, _prz_, --, 
   {{0xa5b80085,0xd1e80092,0x2ae0012d,0x00000000}},	//   _eróp, ዘገበ_, _ख़ाँ_, --, 
   {{0x45d4177b,0xb86414a5,0x3a30010e,0x00000000}},	//   _помс, _ساپو, _yryp_, --, 
   {{0x44300034,0xa5b803b2,0xa6d802d2,0x9f400241}},	//   _wrz_, _gróp, _boðv, _ìjé_, 
   {{0x9f400241,0x00000000,0x00000000,0x00000000}},	//   _íjú_, --, --, --, 
   {{0x443123a5,0x4fc421ef,0xd4041c7c,0x491000cd}},	//   _urz_, نەلە, _ияти, द्यो_, 
   {{0x44200007,0x93a401ec,0x3994365a,0xd1e80092}},	//   mwh_, _ашуд, læst_, ዘገቡ_, 
   {{0x9f4c00c7,0x00000000,0x00000000,0x00000000}},	//   ñañe_, --, --, --, 
   {{0xd1b8021f,0x7d080640,0x00000000,0x00000000}},	//   _قالا_, чног_, --, --, 
   {{0x7c940276,0xece4009d,0x00000000,0x00000000}},	//   эриц, эдэл_, --, --, 
   {{0x2910011f,0xdb9402d3,0x00000000,0x00000000}},	//   _abxa_, ዘለዎም_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb040793,0x17c8013e,0xaa7800a2,0x00000000}},	//   _nunö, мҳои_, maýl, --, 
   {{0x2bc4243c,0x7b9402bf,0x5e5000f1,0xaa78010b}},	//   _रूपा, _приї, _سږکا, laýl, 
   {{0xa5b803b7,0xfaa523a6,0xbad8015b,0x15840150}},	//   _próp, _пайо, _থাকছ, _ﯨﻘﺘﯩ, 
   {{0x7ae523a7,0xdb0429ef,0x3a3000a2,0xa6d8032e}},	// [1bba0] makt, _bunö, _uryp_, _noðu, 
   {{0x26c8011c,0x3ce402c4,0x44200175,0x399401bf}},	//   _efco_, nalv_, fwh_, gæst_, 
   {{0xdb040793,0xa3d80574,0xc8c831f6,0x7ae400f2}},	//   _dunö, ढील_, _توپن_, oakt, 
   {{0x7ae40bf1,0xa6d8041e,0x6db0012d,0xe73c0051}},	//   nakt, _boðu, _płak, _thõa_, 
   {{0x23640240,0x741400f1,0xaa7800a2,0x00000000}},	//   ënja_, _ګوزا, jaýl, --, 
   {{0x7ae523a8,0x614123a9,0x6ff80327,0x216523aa}},	//   hakt, леча, _དཀྱུ_, ничи_, 
   {{0x7ae523ab,0xdb040129,0x00000000,0x00000000}},	//   kakt, _thiè, --, --, 
   {{0x23244e7d,0x777401a9,0x00000000,0x00000000}},	//   _поси_, niyx, --, --, 
   {{0x7ae50517,0xe1f420e5,0xa6d803b2,0xaa780432}},	//   dakt, _пгт_, _goðu, gaýl, 
   {{0xdbe001e1,0x3ce4030a,0xe29523ac,0x00000000}},	//   _kéèt, galv_, _чау_, --, 
   {{0x7ae523ad,0xdbd80789,0x509400c7,0x4af8bbc1}},	//   fakt, _báñe, _руаӡ, меню_, 
   {{0x7ae523ae,0x6b5c00e8,0xdd2c00bc,0xaa7800a2}},	//   gakt, _bëga, _měři, baýl, 
   {{0x2910070d,0xa3e40d2e,0x9a8523af,0x3ce400ef}},	//   _pbxa_, _मौन_, гурл, balv_, 
   {{0x6b5c0de2,0x7e7c52dd,0x2d980022,0xad2405af}},	//   _dëga, úspe, _ópe_, _سرتو, 
   {{0x6d580054,0x7b04023a,0xae000014,0x85040014}},	//   mkta, ättö, _شوژى, ێورن, 
   {{0x7ae523b0,0xdc98025d,0xa038010f,0xaa78010b}},	//   cakt, _מסוכ, העלפ, laým, 
   {{0x6d5923b1,0x00000000,0x00000000,0x00000000}},	// [1bbb0] okta, --, --, --, 
   {{0x6d5923b2,0x48c523b3,0xaa78010e,0x00000000}},	//   nkta, _шәма, naým, --, 
   {{0x73c00184,0xa5b80005,0xdbd825e6,0xbd900023}},	//   иәте, _isóm, _yáñe, _ምጥቃም_, 
   {{0x68e400dd,0x2900394a,0xdbe00241,0x6b5c1bce}},	//   lajd, lgja_, _déèt, _yëga, 
   {{0x7c20010a,0x44200399,0x6d581278,0x9f800205}},	//   zwlr, swh_, kkta, _hıç_, 
   {{0x2900438d,0x7a04013f,0x68e523b4,0x442000b5}},	//   ngja_, _kɔtr, najd, pwh_, 
   {{0x7ae523b5,0x7d00074d,0x65744b2a,0x3ce400d4}},	//   yakt, vgls, mixh, valv_, 
   {{0x657523b6,0xfce0044e,0xe230144c,0x68e4047e}},	//   lixh, _ሞንጎ_, _مکتب, hajd, 
   {{0x7ae46018,0x63b806c8,0x6d580270,0xeb501772}},	//   vakt, _iiun, fkta, _ይረጋገ, 
   {{0x7ae450f9,0x41b40cd2,0x6db04baa,0x63b84ba8}},	//   wakt, _شمار, _mław, _hiun, 
   {{0x63b923b7,0x68e4047e,0x69dc011f,0x4c340276}},	//   _kiun, dajd, _awqe, гэят, 
   {{0x63b923b8,0x6d580115,0x6db0012d,0x7e6c00ee}},	//   _jiun, akta, _oław, _ýapo, 
   {{0x63b923b9,0x7f48014b,0x3f500162,0xa6d803f2}},	//   _miun, mjeq, _fáur_, _loðs, 
   {{0x290123ba,0x63b923bb,0x6d58a7c7,0x68e40205}},	//   ggja_, _liun, ckta, gajd, 
   {{0x7ae523bc,0x63b80421,0x491000dc,0x1b040075}},	//   pakt, _oiun, द्धो_, _йүнн, 
   {{0x63b923bd,0x2900003e,0x7ae403f0,0x00000000}},	//   _niun, agja_, qakt, --, 
   {{0x7e6923be,0x6298020c,0x68e401ef,0x00000000}},	// [1bbc0] nzep, _nyuo, bajd, --, 
   {{0x63b816b8,0x7a04016b,0xa6d805f7,0x69f8008d}},	//   _aiun, _wɔts, _boðs, _קליק, 
   {{0x998108c7,0x63b8393b,0x9f800139,0xe8d4011a}},	//   _križ_, _biun, _gıç_, _שוטר_, 
   {{0x63b923bf,0x95b41945,0xdd2c00bc,0x7e681196}},	//   _ciun, _әрмә, _věři, kzep, 
   {{0x63b923c0,0xf1a923c1,0x6d5923c2,0x61e803cd}},	//   _diun, واته_, ykta, gsgl, 
   {{0x7e6923c3,0xf08c001f,0x62980042,0x23a40037}},	//   dzep, _ምንዛሪ_, _dyuo, võje_, 
   {{0x63b81730,0xdbe000e8,0x61e808c2,0xa6d808a5}},	//   _fiun, _féét, asgl, _goðs, 
   {{0x63b923c4,0xc24401e0,0xdb040419,0x9f400241}},	//   _giun, тмәҫ, _miió, _ìjì_, 
   {{0x6b5c002e,0x62980142,0x80e00154,0xa1c00212}},	//   _bëgn, _gyuo, _নার্, _вбуд, 
   {{0x6d5923c5,0x63b923c6,0x00000000,0x00000000}},	//   ukta, _ziun, --, --, 
   {{0x6d5923c7,0x68e523c8,0xa4f80375,0xcbc80014}},	//   rkta, vajd, וליט, ژِھو_, 
   {{0x6d580bc9,0x16dc0574,0x7ff000b2,0x657523c9}},	//   skta, बरोब, _اڳوا, zixh, 
   {{0x6d580227,0x7e680034,0x65742d2f,0x69f014fb}},	//   pkta, czep, yixh, шүпт, 
   {{0x1e8123ca,0x00000000,0x00000000,0x00000000}},	//   _әләм, --, --, --, 
   {{0x1cb80003,0x290123cb,0x68e523cc,0x6db00034}},	//   _མུག_, rgja_, rajd, _sław, 
   {{0x2d9d23cd,0x68e523ce,0xa6d80162,0xa9c4cd99}},	//   llte_, sajd, _roðs, _исок, 
   {{0x63b923cf,0x2d9c011c,0x7a04013f,0xa6d803b2}},	// [1bbd0] _riun, olte_, _wɔtr, _soðs, 
   {{0x63b923d0,0xdbe000e8,0x2c1400e1,0xeb9c01bf}},	//   _siun, _séét, _तहां_, llø_, 
   {{0x2d9c0ea3,0x63b923d1,0x7e680ffb,0x65740240}},	//   ilte_, _piun, zzep, rixh, 
   {{0x2d9c0730,0x657400aa,0xaae011bc,0x61e8007c}},	//   hlte_, sixh, परिक, tsgl, 
   {{0x63b805d9,0x6574020c,0x61e81196,0x9644004e}},	//   _viun, pixh, usgl, _кэрд, 
   {{0xb3d429db,0x629801c8,0xdbe0002e,0x98a40210}},	//   _әйтә, _vyuo, _wéét, śmą_, 
   {{0xd49812c4,0x63b923d2,0xdbe0002e,0xaae008df}},	//   _арт_, _tiun, _téét, पराक, 
   {{0x2d9c03fa,0xaa7800ee,0xf7ac1df2,0x63b801ab}},	//   elte_, raýj, _ﺳﺎﻟﺪ, _uiun, 
   {{0xa3e4534e,0xef1409a5,0x6df000c6,0x4de4054a}},	//   _मौत_, умы_, مكيا, айың, 
   {{0x6b5c002e,0x7e6c010b,0x7e680210,0x00000000}},	//   _bëgo, _ýapm, rzep, --, 
   {{0x3b08e4c1,0xbec4002b,0x6e24005c,0x7e6923d3}},	//   нено_, _anīś, ækbr, szep, 
   {{0x2d9c022f,0x91f000c7,0xeb9c0162,0x1ee402f2}},	//   alte_, _уҟәш, glø_, _شوتی_, 
   {{0xcd2923d4,0xd078001f,0xa5b801d3,0xca7400c7}},	//   رسین_, ርያርኩ_, _csók, ауры, 
   {{0x19c40daf,0xb6040306,0xdd8c00ec,0x6df0007b}},	//   ләүг, ndáž, _گوڙ_, _اكوا, 
   {{0x256c025c,0xe9a400ec,0x00000000,0x00000000}},	//   nżlu_, دگين_, --, --, 
   {{0x6b5c002e,0xba740131,0x375408f0,0xf62400db}},	//   _jëgl, _ماخت, دپرس, лдбо, 
   {{0xe1a00037,0x00000000,0x00000000,0x00000000}},	// [1bbe0] _ओठंघ, --, --, --, 
   {{0xf988301c,0x6b5c0de2,0xaa78010e,0x87500092}},	//   _سنجي_, _yëgo, daýh, _የገለፀ, 
   {{0x98a8038e,0xe98401ec,0x00000000,0x00000000}},	//   _गरिए, _حايۋ, --, --, 
   {{0xf7446fe4,0xc6980023,0xd05803e3,0x00000000}},	//   _семо, _ፈጺምካ_, cavə, --, 
   {{0xdb0400e8,0x2d9c08fb,0x92941fbe,0x00000000}},	//   _jiiñ, ylte_, јалц, --, 
   {{0xa5b80005,0x98a8012c,0xf1a80244,0x00000000}},	//   _apóf, _गराए, راشه_, --, 
   {{0xdb04002e,0x2d80634d,0x61400063,0x7e6c010e}},	//   _liiñ, ékem_, сеја, _ýapj, 
   {{0xe3b40aac,0xdd2c00bc,0x00000000,0x00000000}},	//   _ббс_, měřu, --, --, 
   {{0x752d23d5,0x6b5c00e8,0x6ce51b9b,0x437523d6}},	//   _kabz, _dëgl, ліне, _турт, 
   {{0x6218010f,0x2d9c0356,0x00000000,0x00000000}},	//   _אומק, ulte_, --, --, 
   {{0xd7b40073,0x5cc0010b,0x9a740092,0x00000000}},	//   ंगाच, щсыз, _ብቸኛው_, --, 
   {{0xd174052f,0xdb04002e,0x65a80e78,0xa4b40375}},	//   _сығы, _biiñ, mühe, טליה_, 
   {{0xed58e9d4,0xce342a60,0x65a8919c,0x5d800214}},	//   _под_, _خوشک, lühe, _گلول, 
   {{0x99800135,0xa5b800e4,0xdbe001e1,0x752c03e0}},	//   _griż_, _ipóg, _kéìt, _nabz, 
   {{0x58d40251,0xd7f8084c,0xb6d002e3,0x6b5c1bce}},	//   сост, лут_, _ọgọs, _yëgl, 
   {{0xcb980722,0xf40800bd,0x387c1f08,0xc6d40063}},	//   _جنبش_, রবার_, útra_, ржаћ, 
   {{0x857523d7,0x00000000,0x00000000,0x00000000}},	// [1bbf0] алах, --, --, --, 
   {{0x99d40769,0x00000000,0x00000000,0x00000000}},	//   _اتيا, --, --, --, 
   {{0x752c0198,0xc4440588,0x99800024,0x63a0054e}},	//   _dabz, шьақ, _erių_, înno, 
   {{0x49101a3e,0x00000000,0x00000000,0x00000000}},	//   द्रो_, --, --, --, 
   {{0x18700092,0x31c40014,0x527400db,0x00000000}},	//   ሸጋገር_, لمنہ, йушу, --, 
   {{0x752c0198,0xd184187f,0xd5b80064,0x00000000}},	//   _gabz, блій, _бсс_, --, 
   {{0xa5b800e4,0xa6a800db,0x65a8002f,0x00000000}},	//   _apóg, _زاڭق_, rühd, --, 
   {{0xbe3802bf,0xff50009a,0x00000000,0x00000000}},	//   вчої_, تخت_, --, --, 
   {{0xa1041e95,0x3eb8063d,0x672c036e,0xc1b923d8}},	//   _مذاه, äst_, _macj, _алах_, 
   {{0x6b5c00e8,0xa5b8004e,0x2794001f,0x65a80b8b}},	//   _dëgm, _aróz, _መጥቀሻ_, bühe, 
   {{0x3b8523d9,0x00000000,0x00000000,0x00000000}},	//   илог, --, --, --, 
   {{0x672d23da,0x3d00012d,0x6db0012d,0x9f400cad}},	//   _nacj, _शाके_, _błas, _ìjà_, 
   {{0x6db0068f,0xab8c0092,0x00000000,0x00000000}},	//   _płat, መሪያው_, --, --, 
   {{0xa5b80aa6,0x00000000,0x00000000,0x00000000}},	//   _eróz, --, --, --, 
   {{0xb8cd23db,0x69c801c7,0x37e401a9,0x9f4001e1}},	//   _और_, _égen, робг, _íjó_, 
   {{0x752c036b,0xdb04002e,0xdc740023,0x986842c6}},	//   _sabz, _tiiñ, _ካሕሳይ_, _ەلدە_, 
  
   {{0xf50813d6,0x7af402d0,0x672c00d7,0x6db00210}},	// [1bc00] кнал_, _idyt, _dacj, _głas, 
   {{0x752d23dc,0x6db00034,0x85080116,0x9990033f}},	//   _qabz, _ułat, лдуң_, żało_, 
   {{0xb4d4006d,0xd76523dd,0x752c0024,0x72c43f0f}},	//   _सभी_, _هندی, _vabz, абез, 
   {{0x09d80729,0x752c0161,0xa314013d,0x00000000}},	//   _তিতা, _wabz, иячә, --, 
   {{0x2d8000dd,0xe2942386,0x237435e6,0x22e40133}},	//   ékek_, аац_, جمند_, شتنێ, 
   {{0x672c1710,0x2d8800f3,0x00000000,0x00000000}},	//   _zacj, čbek_, --, --, 
   {{0xd748069c,0xfdc8005e,0x6b5c044e,0x23a400c5}},	//   _መሪሕነ, қтық_, _dëgj, sõja_, 
   {{0xd1380034,0x65a80112,0x7af4036e,0x9ed40395}},	//   _skąd_, rühe, _ndyt, амът_, 
   {{0xa5b80241,0x70f419f9,0xf11912cd,0x5f7004fb}},	//   _aróy, _نسائ, _لغات_, تاور, 
   {{0x20500184,0x7af409d3,0x98a40210,0x00000000}},	//   стәр, _adyt, śmę_, --, 
   {{0xec141cd1,0xa5b825fd,0x4c94e3cc,0x30740166}},	//   шенә_, _próz, синс, _туас, 
   {{0x6db00034,0x20780a7c,0x00000000,0x00000000}},	//   _płas, _באבא, --, --, 
   {{0xda7923de,0x672c0034,0x9f4001e1,0x00000000}},	//   аяр_, _racj, _ìjá_, --, 
   {{0x7af4068f,0x260c0793,0xa5b801e7,0xda78234c}},	//   _edyt, vüo_, _tsói, ряю_, 
   {{0x6db0006d,0x672c0034,0x00000000,0x00000000}},	//   _włas, _pacj, --, --, 
   {{0xd6d923df,0xd9080882,0x1cb80375,0x176800c7}},	//   иту_, āmāṇ, _במוע, аруп_, 
   {{0xdc38025c,0xacb00150,0x44f4a74b,0x25a800ec}},	// [1bc10] _iġġe, _دەگب, йпас, ندئي_, 
   {{0x1da40020,0x7470002b,0x00000000,0x00000000}},	//   _ወጣቶች_, _śāṭh, --, --, 
   {{0xd498035b,0xd7f800fd,0xa5b800e4,0x00000000}},	//   арц_, _куя_, _osóv, --, 
   {{0xbd040248,0xd6d923e0,0xa5b8033f,0x260401ad}},	//   _adẹ́, _втр_, _spód, िंदी_, 
   {{0x569400d6,0x76440014,0x6b5c0200,0xd684014b}},	//   _мают, _ێیہِ_, _pëgj, _дурп, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdc38003d,0xd1480451,0xaa780432,0x00000000}},	//   _oġġe, ششون_, maýu, --, 
   {{0x43840597,0x7e7c002d,0xab600790,0x9f4400bc}},	//   _الرق, úspo, çült, brný_, 
   {{0x6b5c0200,0x00000000,0x00000000,0x00000000}},	//   _tëgj, --, --, --, 
   {{0xdc380135,0x1cb8031c,0xa5b800e4,0xfd48005b}},	//   _aġġe, _མུད_, _próy, узок_, 
   {{0x7f180220,0xdb0400a3,0xca2800d9,0xa3d801f9}},	//   _білу_, _phià, _רם_, ढीच_, 
   {{0xcc0801ed,0xdb2400a2,0x0d8400cf,0x00000000}},	//   گزین_, _ösün, йлөн, --, 
   {{0x3f9c0521,0xed4d23e1,0x7c6400d1,0x00000000}},	//   _ikwu_, _ео_, شاھل, --, 
   {{0xe50002f8,0xb4d4007d,0xdb04000d,0x387c00d0}},	//   _लागि_, _सभे_, _niiö, útro_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd7480023,0xdb0401e7,0x7af403ac,0x6bd401f7}},	//   _መሪሒነ, _fhiá, _udyt, _اويس_, 
   {{0xa7a40352,0x00000000,0x00000000,0x00000000}},	// [1bc20] скта_, --, --, --, 
   {{0xb90401d5,0x98680eff,0x00000000,0x00000000}},	//   _узок, _ەلگە_, --, --, 
   {{0x3f9c05db,0x2d8001d3,0x00000000,0x00000000}},	//   _okwu_, ékei_, --, --, 
   {{0x3f9c063f,0xf770d8e1,0x9f4402fb,0x3668014b}},	//   _nkwu_, _راج_, trný_, _бамо_, 
   {{0x7e7c0b21,0xa00400d1,0x00000000,0x00000000}},	//   úspl, ەقىل_, --, --, 
   {{0x3f9c01f2,0x6220215c,0x00000000,0x00000000}},	//   _akwu_, سىىل, --, --, 
   {{0x3fc8006c,0x00000000,0x00000000,0x00000000}},	//   لگنی_, --, --, --, 
   {{0x506406ba,0x984c005f,0x4374009d,0x65a8496e}},	//   йтқа, dēļa_, _дуут, müha, 
   {{0xa5b81a36,0x2ce8230c,0x2c4c0213,0xf4080154}},	//   _próx, льно_, mədi_, _রনির_, 
   {{0x3f9c00b4,0xdce00139,0x2c4c0213,0x799c02d0}},	//   _ekwu_, _bknı, lədi_, _nkpw, 
   {{0xaf0810e5,0x32041c06,0xa5b85178,0x65980677}},	//   _مقام_, luoy_, _isót, רייק, 
   {{0xd1e0044e,0xeb4923e2,0x7cf400a2,0xdfcc00c6}},	//   _ሓሶት_, учок_, _aýrı, _أين_, 
   {{0xefb8001f,0xa6e400cc,0xaa7800a2,0x00000000}},	//   ደኛው_, _ফালট, jaýt, --, 
   {{0x29840137,0xdd8c3b44,0xaa78010e,0x00000000}},	//   сымг, _كون_, daýt, --, 
   {{0x9848023a,0x00000000,0x00000000,0x00000000}},	//   бята_, --, --, --, 
   {{0x6db0033f,0x00000000,0x00000000,0x00000000}},	//   _złap, --, --, --, 
   {{0xb6c000f7,0xd31400c0,0x2c4c03e3,0xd6d800f3}},	// [1bc30] дөрд, _вiкт, dədi_, стс_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x59d400dd,0xa5b809c2,0x99d403e6,0x2c4c06be}},	//   _وغیر, _apóc, _وتیا, fədi_, 
   {{0xa5b801e7,0x2c4c06be,0x00000000,0x00000000}},	//   _bpóc, gədi_, --, --, 
   {{0xa490040b,0x88340220,0x00000000,0x00000000}},	//   _کیات, _ءﯗﺷﯩ, --, --, 
   {{0xaa780432,0x00000000,0x00000000,0x00000000}},	//   laýs, --, --, --, 
   {{0xa6a800fe,0x2c4c0213,0x00000000,0x00000000}},	//   _কলিয়, bədi_, --, --, 
   {{0x987c008d,0x3204004d,0xa6e4009e,0x2c4c03b9}},	//   טרוק, buoy_, _ফাঁট, cədi_, 
   {{0x9ba40131,0x3f5000d7,0xafe403b2,0x00000000}},	//   ۋەتى, _káuz_, tmøð, --, 
   {{0xa5b80784,0xc0bc001f,0x00000000,0x00000000}},	//   _isós, ደራል_, --, --, 
   {{0x21240007,0x8f000220,0x9148036b,0xfb88468d}},	//   menh_, _бiр_, _учта_, ибок_, 
   {{0x200523e3,0x80e02158,0x3f9c00b4,0x3b0848a9}},	//   muni_, _নাট্, _ukwu_, шемо_, 
   {{0x200523e4,0x1cb80327,0x3dcc031c,0xaa78010e}},	//   luni_, _མུམ_, qqew_, daýs, 
   {{0x83280135,0xdea0004b,0x2004016b,0x2124067c}},	//   _ལིའུ_, _ویډی, ouni_, nenh_, 
   {{0xec6c00ec,0xa9a07fa5,0xe5000037,0x00000000}},	//   _لٿو_, фирд, _लाजि_, --, 
   {{0x75d431b1,0x00000000,0x00000000,0x00000000}},	//   قيرا, --, --, --, 
   {{0x200523e5,0x6440049f,0xe0dc01fb,0xeabc0ffb}},	// [1bc40] huni_, ånin, _đòn_, leùn_, 
   {{0x200523e6,0x916c0051,0xb50400ae,0x00000000}},	//   kuni_, _tổn_, تظرو, --, 
   {{0x200523e7,0xccf40085,0x212401fa,0x2c4c0213}},	//   juni_, _ɛɛ_, denh_, tədi_, 
   {{0x200523e8,0xa8000006,0x00000000,0x00000000}},	//   duni_, _ўзял, --, --, 
   {{0x491000bc,0xaa7800a2,0x00000000,0x00000000}},	//   द्को_, laýr, --, --, 
   {{0x20049e72,0x65a80037,0x00000000,0x00000000}},	//   funi_, püha, --, --, 
   {{0x64a0dcad,0xa0640640,0xb4d412eb,0xab600790}},	//   _жара, жаја_, सडी_, çükt, 
   {{0xeabc0ffb,0x2c4c00ac,0x19b000d1,0x00000000}},	//   deùn_, qədi_, ﺰﯨﻤﻠ, --, 
   {{0xed8807d8,0xd444001f,0x32040100,0xaa78010e}},	//   исок_, _የሚጠቅ, quoy_, haýr, 
   {{0x716523e9,0x200400b2,0x65a8002f,0x00000000}},	//   _بارك, buni_, hühn, --, 
   {{0x200406bb,0x30840214,0xcb98003b,0x00000000}},	//   cuni_, _بلاف, йвої_, --, 
   {{0x6e4442b5,0x7bcc1155,0x00000000,0x00000000}},	//   _ونام, _čaut, --, --, 
   {{0x2aa81149,0x6d4c000d,0x00000000,0x00000000}},	//   ртно_, öbas, --, --, 
   {{0x6e2000e4,0x8c8800c7,0x00000000,0x00000000}},	//   _ipob, _гәма_, --, --, 
   {{0xa5b80798,0xa92402d2,0xaa7800a2,0x00000000}},	//   _osór, _afþö, gaýr, --, 
   {{0xd36404a9,0x8d748efb,0x00000000,0x00000000}},	//   _شۇ_, _باچا, --, --, 
   {{0x200523ea,0xe664003b,0x00000000,0x00000000}},	// [1bc50] zuni_, цтво, --, --, 
   {{0x200523eb,0x6e2002ea,0xe9dcfc37,0x9ca400f7}},	//   yuni_, _mpob, mpú_, _اشۇۇ, 
   {{0x6ec8012c,0x65a923ec,0xa2240451,0x00000000}},	//   ाखाँ, bühn, ڪراه, --, 
   {{0x200523ed,0x53c801ec,0x00000000,0x00000000}},	//   vuni_, ігім_, --, --, 
   {{0x32f123ee,0x6e2000d2,0x200523ef,0x2124068c}},	//   ركوز, _npob, wuni_, tenh_, 
   {{0x200523f0,0x41281515,0x26c400bc,0xe9dc00c7}},	//   tuni_, соко_, ěnou_, ipú_, 
   {{0x2bc40574,0x200523f1,0x2124067c,0x00000000}},	//   _रंगा, uuni_, renh_, --, 
   {{0xe3b031f6,0x6e2000c6,0x21240007,0x00000000}},	//   _آرس_, _bpob, senh_, --, 
   {{0x200523f2,0x4094397a,0x443001d3,0x00000000}},	//   suni_, _کلار, _hsz_, --, 
   {{0x200523f3,0xce180006,0x2c4c06be,0x00000000}},	//   puni_, іцыі_, hədu_, --, 
   {{0x200523f4,0xdc98069d,0x00000000,0x00000000}},	//   quni_, _ላዕላይ_, --, --, 
   {{0x3f880086,0xdb0923f5,0x443123f6,0x7ccc00e5}},	//   _ñau_, _ölül, _msz_, _bőré, 
   {{0x6e2001e4,0x44300036,0x3ea803b2,0x00000000}},	//   _gpob, _lsz_, _áat_, --, 
   {{0x2d8000dd,0x00000000,0x00000000,0x00000000}},	//   éket_, --, --, --, 
   {{0x44308bbb,0x00000000,0x00000000,0x00000000}},	//   _nsz_, --, --, --, 
   {{0x6b5c002e,0xaa7921a6,0x7e6c00a2,0x9b940244}},	//   _bëgu, mbýn, _ýaps, _تاتڵ, 
   {{0x7f580014,0xa5b802d2,0x00000000,0x00000000}},	// [1bc60] _mowq, _spóa, --, --, 
   {{0xaa380302,0x1c1c01ad,0x00000000,0x00000000}},	//   _פתיח, _बहाल_, --, --, 
   {{0x4430030d,0xd74c02d3,0x65a817da,0x7a3400e5}},	//   _csz_, _ቀጻልነ, mühl, bütá, 
   {{0x443123f7,0x15b83e64,0xf748007b,0x3958045a}},	//   _dsz_, сығы_, _الحي_, _hops_, 
   {{0x71a51185,0x395923f8,0x1b4c0092,0x00000000}},	//   падз, _kops_, _እየተጫ, --, 
   {{0x39588ec5,0x00000000,0x00000000,0x00000000}},	//   _jops_, --, --, --, 
   {{0xa5b800ae,0xb6340150,0x00000000,0x00000000}},	//   _tsór, _ﺜﻤ_, --, --, 
   {{0x395903f2,0xdce0003a,0xa6d803b2,0x6b5c0de2}},	//   _lops_, _omnē, _boðy, _yëgu, 
   {{0x65a803fa,0xaa7800e4,0x1ef418fd,0x00000000}},	//   kühl, jaýp, سعية_, --, 
   {{0x680c013f,0x7bcc009b,0x61a40b02,0x00000000}},	//   _wɔdɛ, _čaur, गतृष, --, 
   {{0x3a300432,0x44300175,0x00000000,0x00000000}},	//   _asyp_, _xsz_, --, --, 
   {{0x39580334,0x00000000,0x00000000,0x00000000}},	//   _aops_, --, --, --, 
   {{0x65a8cac5,0x39580204,0xbe300588,0xee380276}},	//   fühl, _bops_, _аҭыш, _ынд_, 
   {{0xa5b800e4,0x39580f85,0x13d400fe,0x00000000}},	//   _apón, _cops_, হীয়, --, 
   {{0x2d9d23f9,0x2fc40076,0xcb54007b,0x1aec0154}},	//   mote_, _kiog_, _ينتظ, _কারই_, 
   {{0x27fd23fa,0x443001a4,0x0708004b,0x97a523fb}},	//   čun_, _rsz_, تيري_, ерул, 
   {{0x395804cc,0x2d9d071e,0x5694e772,0xe610007b}},	// [1bc70] _fops_, oote_, еатт, عشر_, 
   {{0x2d9d23fc,0x2fc523fd,0x4cc000eb,0x00000000}},	//   note_, _liog_, _শ্যু, --, 
   {{0x53e40395,0xfa541291,0x00000000,0x00000000}},	//   ецча, _فریگ, --, --, 
   {{0x395804cc,0x6b5c0200,0x00000000,0x00000000}},	//   _zops_, _tëgu, --, --, 
   {{0xb90801dc,0x73c046e8,0xdb24003e,0x00000000}},	//   _nghệ_, тәре, éréw, --, 
   {{0x2d9d23fe,0x7fd8188b,0x3958004e,0x1a9c008f}},	//   jote_, офит_, _xops_, זידע, 
   {{0xd4043819,0x2d9d23ff,0xa1a000fb,0xd4a4014b}},	//   _пяти, dote_, мыҫһ, _зиёй, 
   {{0x53340262,0xfe4403b7,0x387c0030,0x00000000}},	//   _пест, днио, útri_, --, 
   {{0xee352400,0x88c400bd,0x2d9c89f9,0x2fc45db7}},	//   дны_, ্রিক, fote_, _diog_, 
   {{0x3c640138,0x00000000,0x00000000,0x00000000}},	//   дког, --, --, --, 
   {{0x2fc401ab,0x39580108,0xa3d00037,0x20000ca8}},	//   _fiog_, _rops_, _हूम_, _íji_, 
   {{0x26c8192e,0x2bec033f,0x2d80893a,0x395801f4}},	//   _ngco_, _आबरू_, éker_, _sops_, 
   {{0x2d9d2401,0x39583fe5,0x34a80b3c,0xfe440212}},	//   bote_, _pops_, _कर्द, _інко, 
   {{0x2d9d2402,0xaa7805f7,0x8b640150,0xceb400fb}},	//   cote_, mbýl, _ۋايم, _яҙы_, 
   {{0x3f8c0137,0xa3bc1d15,0xdb040332,0x65a8002f}},	//   oneu_, ीदा_, _mhiú, rühl, 
   {{0x8b9402d5,0x3f8cf0ec,0x3a2400d8,0x00000000}},	//   _прыч, nneu_, _жмиг, --, 
   {{0x39586eee,0x00000000,0x00000000,0x00000000}},	// [1bc80] _tops_, --, --, --, 
   {{0xd9b42a8b,0xd5b001d9,0xf2d000fe,0x058400d4}},	//   _سەزد, اہس_, াৰাণ, нуєм, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2d9c00ec,0xe360074d,0x4374004e,0x00000000}},	//   zote_, ккхи, нучт, --, 
   {{0x9f800724,0x2d9d2403,0xdb040332,0x592c031c}},	//   _nıñ_, yote_, _bhiú, _སྲོས_, 
   {{0xdb0400ae,0x4f8400e5,0x00000000,0x00000000}},	//   _chiú, کاتہ, --, --, 
   {{0xe4c0eaf7,0x2d9d2404,0x74147425,0x65612405}},	//   _айри, vote_, _توزا, önhe, 
   {{0x2d9c0451,0x3f8c004e,0x00000000,0x00000000}},	//   wote_, gneu_, --, --, 
   {{0x2d9d2406,0xe1f401c0,0xdb0401e7,0xc32c0372}},	//   tote_, _огт_, _fhiú, _دەن_, 
   {{0x3eb80436,0xdb04007b,0x88c403d4,0x00000000}},	//   ýsta_, _ghiú, ্ৰিক, --, 
   {{0x32040a40,0x7bcc0139,0x00000000,0x00000000}},	//   lroy_, _ınuç, --, --, 
   {{0x2d9d2407,0xa5b92408,0x916c0208,0x00000000}},	//   sote_, _apól, _hồn_, --, 
   {{0x32052409,0x5f8002dd,0xde7000cf,0x88c403d4}},	//   nroy_, _جۇيە, _لدوع, ্ৰাক, 
   {{0x2d9c208d,0x9c100241,0x4ea400fb,0x00000000}},	//   qote_, _pọtu, _орҙа, --, 
   {{0x58d5240a,0xdd90db04,0x6440010f,0xaa7800e4}},	//   тост, _шашы, ĥnik, mbým, 
   {{0x65a9240b,0xa0340375,0x5ba40588,0xa56521eb}},	//   rühm, ואלה_, _ирыз, ژدان, 
   {{0xa3e40c66,0xd7c4490c,0x00000000,0x00000000}},	// [1bc90] _मौज_, тёро, --, --, 
   {{0x320406d9,0xa485240c,0xe29c0162,0x237c0200}},	//   droy_, وجان, _øði_, _smuj_, 
   {{0x96c001ad,0x48c40131,0x00000000,0x00000000}},	//   लेबॉ, _яшиғ, --, --, 
   {{0xdb05240d,0xd4980f37,0x32040129,0xa3d001ad}},	//   _bhiù, фру_, froy_, _हूण_, 
   {{0xb4b40598,0x7a11240e,0xdb040e89,0x6d49240f}},	//   _җитә, _pɛtɛ, _chiù, _onfa, 
   {{0xdb040e89,0x60300213,0x534400c7,0xab580205}},	//   _dhiù, _həmə, ехәа, lmüd, 
   {{0x603000ac,0x260401ad,0x9c1001e1,0x9f800139}},	//   _kəmə, िंकी_, _lọru, _sıñ_, 
   {{0x6d492410,0xdb0401c3,0x69dc0455,0x32052411}},	//   _anfa, _fhiù, _otqe, broy_, 
   {{0xc0d40020,0x3f8d2412,0xdb041554,0x603003b9}},	//   _የጦር_, rneu_, _ghiù, _məmə, 
   {{0x61f8b00f,0xd2000228,0xc8840139,0xa5b801e1}},	//   _ivul, _түшк, _koşı_, _opóm, 
   {{0x3f8c02f0,0x518400ea,0x65a8000d,0xab5806be}},	//   pneu_, _рута, tühj, kmüd, 
   {{0x6d492413,0x61f80118,0x603006be,0x9f800139}},	//   _enfa, _kvul, _nəmə, _tıñ_, 
   {{0xa5b800c7,0x9e640372,0x2004544b,0x592c0327}},	//   _apóm, _تاان, lrni_, _སྲུས_, 
   {{0x61f92414,0x20052415,0x7e7c045f,0x2c1c00fe}},	//   _mvul, orni_, úspu, _বছৰে_, 
   {{0xa3bc1df1,0x00000000,0x00000000,0x00000000}},	//   ँगा_, --, --, --, 
   {{0x603006be,0x200401a9,0x6c78011a,0x00000000}},	//   _cəmə, irni_, _מרצד, --, 
   {{0x6d48045f,0x603003e3,0x200401a9,0xd6c400c7}},	// [1bca0] _ynfa, _dəmə, hrni_, тиақ, 
   {{0x200401b9,0xe3d40154,0x00000000,0x00000000}},	//   krni_, _হিজব, --, --, 
   {{0x61f92416,0xdb0401c3,0x6db00210,0x00000000}},	//   _avul, _shiù, _płaz, --, 
   {{0x61f81682,0x660000d1,0x20048192,0x4aa40764}},	//   _bvul, _әпра, drni_, _गुडव, 
   {{0x2004011c,0x61d402bf,0xa2a000ab,0x69c801d3}},	//   erni_, емія_, _छुद्, _éget, 
   {{0x2004022e,0x63a80037,0x916c0051,0x00000000}},	//   frni_, algn, _bốn_, --, 
   {{0x61f92417,0x603003e3,0x00000000,0x00000000}},	//   _evul, _yəmə, --, --, 
   {{0xc0d0001f,0x64a06d60,0xade40063,0x00000000}},	//   ጨመረ_, _саса, нцок, --, 
   {{0x200420ac,0x7204132f,0x916c0051,0x00000000}},	//   arni_, _سوام, _tồn_, --, 
   {{0x2050052f,0x200446aa,0xfcc8001f,0x9c100cad}},	//   ттәр, brni_, በልጡ_, _rọru, 
   {{0x4c952418,0x904004d3,0x200416a3,0x00000000}},	//   тинс, _ڕۆژه, crni_, --, 
   {{0xa3d0813f,0xe0dc0016,0x2054011a,0x00000000}},	//   _हंस_, _đòi_, _ריאל_, --, 
   {{0xc0d00092,0x00000000,0x00000000,0x00000000}},	//   ጨመሩ_, --, --, --, 
   {{0x4aa461b8,0x6d492419,0x603000ac,0xdcac00db}},	//   _गुणव, _unfa, _səmə, _گۉپ_, 
   {{0xae6401d9,0x23c40cad,0xab6003e0,0x9cd4011a}},	//   _زٕژن_, _jìjì_, çüst, _אווה_, 
   {{0x603003e3,0x65a8000d,0x00000000,0x00000000}},	//   _qəmə, mühi, --, --, 
   {{0xab580112,0xdb2400e5,0x65a8000d,0xb7c400c7}},	// [1bcb0] rmüd, _árár, lühi, тррқ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x61f9241a,0x60300213,0x592c0327,0xa3bc00c5}},	//   _svul, _təmə, _སྲིས_, ीदल_, 
   {{0x2005241b,0xa3a5241c,0x7c24002f,0xab5806be}},	//   vrni_, رحان, _ähre, qmüd, 
   {{0xdb040d27,0x20040309,0x68e0000d,0xe05400e5}},	//   _skië, wrni_, _õnds, کیات_, 
   {{0xfcc8001f,0x2005241d,0x00000000,0x00000000}},	//   በልጥ_, trni_, --, --, 
   {{0x20040010,0x00000000,0x00000000,0x00000000}},	//   urni_, --, --, --, 
   {{0x200402d3,0x3ea41180,0x916c0208,0xbea40395}},	//   rrni_, кийг, _vốn_, кайк, 
   {{0x61f83e6e,0xc0d0001f,0x929401c6,0x81d400d4}},	//   _uvul, ጨመር_, _батц, _розх, 
   {{0xd1b800d1,0xa5b8012d,0x81600133,0x916c0208}},	//   _كالا_, _spój, _خۆتۆ, _tốn_, 
   {{0xa5b80022,0x3b08764a,0x3f14a2ff,0xfc040395}},	//   _apók, мено_, _адес, ъпно, 
   {{0x65a8000d,0x00000000,0x00000000,0x00000000}},	//   sühh, --, --, --, 
   {{0x9f440158,0xfd743fe9,0x2bc4012d,0x2b1000bc}},	//   dsnø_, _илдэ, रआजा, _थारु_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x916c0051,0x00000000,0x00000000,0x00000000}},	//   _hỗn_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfaa40261,0x35a401c0,0x36c40209,0x00000000}},	// [1bcc0] _јапо, вааг, тбаг, --, 
   {{0xe8f403cf,0xe6400108,0x00000000,0x00000000}},	//   _иль_, шеуп, --, --, 
   {{0x6560023a,0x37e4a0d5,0xe4c001c4,0x00000000}},	//   önha, _шонг, айфи, --, 
   {{0x69c824b0,0xf20400c0,0x64a000a6,0xb284004e}},	//   _éger, вяко, шаха, кылк, 
   {{0xa6d8032e,0x00000000,0x00000000,0x00000000}},	//   _baðf, --, --, --, 
   {{0xe121241e,0xe0cd0030,0x00000000,0x00000000}},	//   имчи, يزى_, --, --, 
   {{0xaf500032,0xd25038b5,0xab0800d7,0x00000000}},	//   инкә, _گۆش_, rčúľ_, --, 
   {{0x73348818,0xe0d400d1,0xada401e1,0xe3e400f1}},	//   _جىرا, нвә_, _ojúò, _شکمن_, 
   {{0x3114035b,0xab580e78,0xa3bc4ca3,0x6ce5241f}},	//   _афес, hmüc, ँगर_, кіне, 
   {{0x753c005a,0xf428031c,0x931400f1,0xe294190b}},	//   ndpz, _ྤྱོད_, _جوړش, _рау_, 
   {{0xaa7800e4,0xa5b8032e,0x00000000,0x00000000}},	//   mbýi, _spók, --, --, 
   {{0x7644127b,0xa0640114,0x5cc00209,0x00000000}},	//   _orky, _шаха_, шсыз, --, 
   {{0x6f00011c,0xed580801,0x65a800c5,0x5a347734}},	//   _idoc, _оод_, sühi, анят, 
   {{0x65a80254,0x00000000,0x00000000,0x00000000}},	//   pühi, --, --, --, 
   {{0xf8440364,0xd7f800a8,0x76440363,0x9f440fac}},	//   гӯяд_, кут_, _arky, tsnø_, 
   {{0x6d580227,0xab84694c,0x00000000,0x00000000}},	//   ljta, _шулк, --, --, 
   {{0x48c4015b,0x6f000175,0x9f4403cd,0x4614007b}},	// [1bcd0] ্রের, _mdoc, rsnø_, طوار, 
   {{0x9f4433b8,0x5574cbc7,0x23e400d4,0x6d592420}},	//   ssnø_, агут, відв, njta, 
   {{0x6f012421,0xa6d8022c,0x764402d0,0xa3bc0037}},	//   _odoc, _raðf, _erky, ँगल_, 
   {{0x6f012422,0x42741de6,0x00000000,0x00000000}},	//   _ndoc, лгес, --, --, 
   {{0x13040046,0xa3d0000d,0x00000000,0x00000000}},	//   рзім, _हूर_, --, --, 
   {{0xa6d802d2,0x00000000,0x00000000,0x00000000}},	//   _baðg, --, --, --, 
   {{0xb4b519ba,0x94a80408,0x00000000,0x00000000}},	//   _бирә, _атта_, --, --, 
   {{0xb2709151,0xe3bc0086,0xc3c474f1,0x932400dd}},	//   рләш, _òñ_, _сөзл, _پرِن, 
   {{0xa5b92423,0x63b92424,0xeb5002d3,0x6f000042}},	//   _apói, _ihun, _ክረጋገ, _ddoc, 
   {{0x6f012425,0x998000bc,0xfe7800bc,0xa5b800ae}},	//   _edoc, _opiš_, rzů_, _bpói, 
   {{0xfbc4b258,0xaa400184,0xc4b000e1,0x6f000334}},	//   лбоо, ҙерл, _झरोख, _fdoc, 
   {{0xaa780209,0x65a80e78,0x39440356,0x2d900248}},	//   laýy, mühu, _şos_, _ìyen_, 
   {{0x63b85553,0xd8440064,0x00000000,0x00000000}},	//   _mhun, _mačų_, --, --, 
   {{0x644403ee,0x63b80363,0xb6a401b9,0x6f000419}},	//   _orji, _lhun, ҳибл, _zdoc, 
   {{0xbb443740,0x63b92426,0x0dc80063,0xa8100108}},	//   _бейк, _ohun, _руци_, йдёш, 
   {{0xe7352427,0x63b92428,0xb6a477c1,0xdce0003a}},	//   лес_, _nhun, гибл, _omnī, 
   {{0x7e692429,0x6440019b,0x6445242a,0xaa7800ee}},	// [1bce0] nyep, ænin, _arji, kaýy, 
   {{0x63b9242b,0xaa78010b,0x00000000,0x00000000}},	//   _ahun, jaýy, --, --, 
   {{0x63b9242c,0x7775242d,0xaa780209,0x00000000}},	//   _bhun, phyx, daýy, --, 
   {{0x63b9242e,0x7af5242f,0xa6d801a8,0x00000000}},	//   _chun, _jeyt, _raðg, --, 
   {{0xa6805238,0x63b92430,0x7e680796,0x65740472}},	//   _гляд, _dhun, jyep, bhxh, 
   {{0x7af52431,0x63b92432,0x6f0001ab,0xaa78010e}},	//   _leyt, _ehun, _sdoc, gaýy, 
   {{0x63b81682,0x64540393,0xdd2c0118,0xaa7803b2}},	//   _fhun, cxxi, měňu, rbýi, 
   {{0x7af42012,0x63b80978,0xaa780124,0x33b400ae}},	//   _neyt, _ghun, mbýv, _إمرأ, 
   {{0xa5b80597,0xa2c92433,0xe2952434,0xdec402d3}},	//   _spói, _तृप्, _бат_, _ጽልኢ_, 
   {{0xa3d0006d,0x63b80784,0x64440363,0xa6d80162}},	//   _हूँ_, _zhun, _yrji, _taðg, 
   {{0x7af52435,0x65a80112,0x6d58022e,0x00000000}},	//   _beyt, müht, rjta, --, 
   {{0x7af43d20,0x6f00014b,0x63b80240,0x00000000}},	//   _ceyt, _udoc, _xhun, --, 
   {{0x7af4b1ab,0x99808c05,0x3cec0073,0x50a401ee}},	//   _deyt, _spiš_, _आजचे_, _суҡҡ, 
   {{0xded00201,0x49a41219,0xce340133,0x9cb00137}},	//   _የሆነ_, рымғ, _موڵک, _گۅپت, 
   {{0xa3d0068f,0xd24404d3,0x7af46f96,0x9cd80a1e}},	//   _हूं_, _کۆ_, _feyt, _אקופ, 
   {{0x7af481f1,0x2c0000db,0x473400d8,0x00000000}},	//   _geyt, _күүм, јнас, --, 
   {{0x63b802c4,0x2ab80cad,0x865407d5,0xaa780419}},	// [1bcf0] _rhun, _dàbí_, шках, ebýv, 
   {{0x63b92436,0x42542a60,0x6444030d,0x7af42fbe}},	//   _shun, ینار, _prji, _zeyt, 
   {{0x63b92437,0xded00020,0xa5b800e4,0x00000000}},	//   _phun, _የሆኑ_, _opóv, --, 
   {{0x63b802d1,0x68f400e4,0x7af40009,0x00000000}},	//   _qhun, _hexd, _xeyt, --, 
   {{0x63b81aa1,0xe73c0428,0x62b401e0,0xb784104e}},	//   _vhun, _iaõ_, уғас_, _тәре_, 
   {{0xa590521e,0xa5b8035b,0x3ce82625,0x94d40b2c}},	//   _اگرچ, _apóv, _đavo_, _горц, 
   {{0xaa780209,0x705000c6,0x64440ba7,0x63b92438}},	//   raýy, قنوا, _urji, _thun, 
   {{0x63b92439,0xa6d802d2,0x4420036e,0x00000000}},	//   _uhun, _faðe, mth_, --, 
   {{0x7af5243a,0x4421243b,0xaac4caa0,0x415450b1}},	//   _reyt, lth_, रेमक, _квас, 
   {{0x7af40694,0x4421243c,0x5918031c,0x4d1477e5}},	//   _seyt, oth_, ླུབས_, бьют, 
   {{0x4421243d,0xc0c40131,0x00000000,0x00000000}},	//   nth_, _тәди, --, --, 
   {{0x4421243e,0x1ee4034c,0xe73c00d8,0x10f001e1}},	//   ith_, _صوتی_, _naõ_, _iṣẹr, 
   {{0x4421243f,0x386800a9,0x4a744137,0xaa780118}},	//   hth_, wybr_, бырт, zbýv, 
   {{0xfce52440,0x7af40280,0xdb0401ab,0x44200023}},	//   _токо, _weyt, _chiò, kth_, 
   {{0x17c80364,0x7af40113,0x68f40009,0xe8f44d87}},	//   лҳои_, _teyt, _dexd, рлс_, 
   {{0x44204bbe,0x68f4058a,0xab592441,0x00000000}},	//   dth_, _eexd, lmün, --, 
   {{0x44201649,0xe7345b54,0x59b4010b,0x87b8009d}},	// [1bd00] eth_, шет_, _гөвс, уурт_, 
   {{0xe5744294,0xe73c0086,0x4420011a,0x85540014}},	//   азу_, _eaõ_, fth_, میُر_, 
   {{0x2ab80570,0x44212442,0xb4d42d8f,0x00000000}},	//   _tàbí_, gth_, _हली_, --, 
   {{0x15b80046,0xf745146e,0xf268121c,0x00000000}},	//   тығы_, _темо, киел_, --, 
   {{0x80ac2f8b,0xab5809a5,0x44209a6a,0xe2800a31}},	//   টেম্, kmün, ath_, олци, 
   {{0x7e6c0209,0xaa7800e4,0xab5800a2,0x00000000}},	//   _ýapy, mbýt, jmün, --, 
   {{0x442006ee,0x2164026a,0x8554006c,0xf0740131}},	//   cth_, рији_, _دیلر_, рийә_, 
   {{0xa6d803b2,0x00000000,0x00000000,0x00000000}},	//   _taðe, --, --, --, 
   {{0xaa780162,0x43744530,0xad647b8f,0x00000000}},	//   nbýt, _уурт, لاده, --, 
   {{0xce94020a,0xecc428e8,0x00000000,0x00000000}},	//   _қалъ, ищно, --, --, 
   {{0xef18f2f6,0x60d8010f,0xd3140212,0x00000000}},	//   _аме_, _סקאנ, _вiдт, --, 
   {{0x80ac1d4c,0x68f52443,0xd1741669,0x3180033f}},	//   _চলচ্, _sexd, _тығы, ższą_, 
   {{0xdb04e81d,0xab58002f,0x5f1808ec,0x00000000}},	//   _chiñ, bmün, _यात्_, --, 
   {{0x44212444,0x332414ce,0x5c8001d9,0xac905f0f}},	//   yth_, hfox_, _ژلوٕ, _қақш, 
   {{0x195809a5,0x44212445,0xec1401e0,0x00000000}},	//   шары_, xth_, _тейә_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x44212446,0x3cc80daf,0x332400b5,0xaa7803b2}},	// [1bd10] wth_, _икәү_, dfox_, gbýt, 
   {{0x44201730,0xe4e400d6,0x9984038b,0x3eb8041e}},	//   tth_, ріан, _وليو, ýsti_, 
   {{0x44212447,0x65a8fac1,0x95c822c3,0x94a83032}},	//   uth_, führ, рута_, атца_, 
   {{0x44208992,0xa5b92448,0x7bd800df,0x00000000}},	//   rth_, _apót, אַסק, --, 
   {{0x4420d02e,0xc0e40261,0xc0d402d3,0x13080212}},	//   sth_, болк, _ካስል_, рній_, 
   {{0x4420c2ce,0x33240332,0x65a80112,0xd184003b}},	//   pth_, afox_, rühs, олій, 
   {{0x65a80730,0xa4902e3e,0x8ff80124,0x00000000}},	//   bühr, _بیات, ахыу_, --, 
   {{0x22852449,0x67040a8a,0xa0700150,0x00000000}},	//   _кузг, षणिक_, йықш, --, 
   {{0x42743b2e,0x3eb8a2ec,0xed4c01d9,0xab58002f}},	//   _угас, åst_, کھن_, tmün, 
   {{0xdce00115,0x98b80311,0x00000000,0x00000000}},	//   _konĉ, ndră_, --, --, 
   {{0xbb4434d8,0x24480092,0x4aa40037,0xab59244a}},	//   бенк, _ሀላፊነ, _गँउव, rmün, 
   {{0xdb0402d1,0x9e6400e5,0x00000000,0x00000000}},	//   _phiñ, _پاؤن, --, --, 
   {{0x3f8c4c18,0xab59244b,0x256c03e0,0x00000000}},	//   mieu_, mmül, _kılı_, --, 
   {{0x3f8d244c,0x499811ed,0xa5b80085,0xdbe00241}},	//   lieu_, атся_, _mpós, _déòt, 
   {{0x6f0c00d2,0x332400b5,0x37e412d7,0xb7d801c8}},	//   _íncó, yfox_, собг, اورا_, 
   {{0x3f8c07de,0x5fa40073,0xab58002f,0xa3d8000d}},	//   nieu_, खविल, nmül, _ठढ़_, 
   {{0x7bc40112,0x00000000,0x00000000,0x00000000}},	// [1bd20] mmku, --, --, --, 
   {{0x3f8d244d,0xaa780174,0xe7d002dd,0x00000000}},	//   hieu_, rbýt, _ﻛﯟﺍﻟ, --, 
   {{0x3f8c0438,0x798d244e,0x64400158,0x332400b5}},	//   kieu_, mibw, ånip, tfox_, 
   {{0x798c2f99,0xdce0012c,0x3f8c05d5,0xa5b800ae}},	//   libw, _plně, jieu_, _bpós, 
   {{0x332404fb,0x3f8d244f,0x65a80730,0x925801c0}},	//   rfox_, dieu_, rühr, ралт_, 
   {{0xa3d003e5,0x256c00fd,0x798c0a49,0xdce00118}},	//   _हूक_, _cılı_, nibw, _vlně, 
   {{0x3f8c05d5,0xe5752450,0x798c04ba,0xa6d806ea}},	//   fieu_, _узр_, iibw, _haða, 
   {{0x3f8c0c86,0x798d2451,0xab5805d5,0xa6d80174}},	//   gieu_, hibw, gmül, _kaða, 
   {{0xa5b80124,0x798c9176,0xa6d808a5,0xa758011a}},	//   _ipór, kibw, _jaða, רדפר, 
   {{0x798c009f,0xb4d42c30,0x00000000,0x00000000}},	//   jibw, _हलो_, --, --, 
   {{0xdeec3c7f,0xb09802bf,0x3f8c05d5,0x798c04ba}},	//   _ны_, _стає_, bieu_, dibw, 
   {{0x3f8d2452,0xd0600296,0xe0b40115,0x00000000}},	//   cieu_, ́tɛl, _פלאט_, --, 
   {{0x256c1918,0x6da40276,0xef1800c7,0x00000000}},	//   _yılı_, _лида, _амҵ_, --, 
   {{0x6e209665,0x3eb90cf6,0x798c2252,0x6840013a}},	//   _iqob, üste_, gibw, jídá, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x89d804fb,0xa6d8032e,0x00000000,0x00000000}},	//   _پودر_, _baða, --, --, 
   {{0x798c43c4,0x9b1800db,0x6b8c035a,0x00000000}},	// [1bd30] bibw, _اتىز_, micg, --, 
   {{0x798c01b2,0xa5b800e4,0xa6d801a8,0x6b8c02d0}},	//   cibw, _apór, _daða, licg, 
   {{0xa2c800e0,0x29c4002e,0xd5b8009d,0x00000000}},	//   तेन्, 鯵al_, сст_, --, 
   {{0x6e20014b,0xca780023,0x6b8c02d0,0x69c52453}},	//   _oqob, _ኣጆኹም_, nicg, lmje, 
   {{0x3f8d2454,0x6e20401f,0xe74400fb,0x00000000}},	//   vieu_, _nqob, _күңе_, --, 
   {{0xa5040131,0xcfd01870,0x6b8c035a,0x00000000}},	//   _دىسە_, _ﺗﺎﺭﻗ, hicg, --, 
   {{0x758001b9,0x3f8d2455,0x31e40154,0xca4c01ec}},	//   _تیلم, tieu_, _নিঃশ, _ﺍﻷﺴ_, 
   {{0x798c0c8a,0x93e401d5,0x61e801e3,0xd5d8000d}},	//   zibw, _хўрл, ppgl, _भूँज, 
   {{0x63a81326,0x3f8d2456,0xab592457,0x798c43c4}},	//   mogn, rieu_, rmül, yibw, 
   {{0x63a92458,0x3f8d2459,0x44300cf4,0x65640455}},	//   logn, sieu_, _kpz_, _jojh, 
   {{0x6565245a,0x44300066,0x55ac008f,0x3f8c354d}},	//   _mojh, _jpz_, רייַ, pieu_, 
   {{0x798c1921,0x63a9245b,0x69c4002d,0x98b80024}},	//   wibw, nogn, emje, ndrą_, 
   {{0x798c2f99,0x4430005a,0x451000fe,0x00000000}},	//   tibw, _lpz_, স্যক_, --, 
   {{0x65640477,0x798c0083,0xa6d801a8,0xef24010e}},	//   _nojh, uibw, _raða, _çürt_, 
   {{0x63a80656,0x798d245c,0x44300427,0xf7440021}},	//   kogn, ribw, _npz_, оево, 
   {{0x798d245d,0x31b0019f,0x69c400b5,0x63a8003e}},	//   sibw, râzi_, amje, jogn, 
   {{0x63a9245e,0x6564022e,0x443000d7,0x00000000}},	// [1bd40] dogn, _bojh, _apz_, --, 
   {{0xa5b83adf,0x250801d5,0xaa780124,0xa6d802d2}},	//   _spór, لرمی_, mbýp, _vaða, 
   {{0x44300113,0x63a800e5,0x00000000,0x00000000}},	//   _cpz_, fogn, --, --, 
   {{0xa2c800dc,0x28100133,0x29c400e8,0xe5f00137}},	//   तेभ्, _کوێس, 鯵am_, سكۅد, 
   {{0x4431245f,0xe6940107,0xafe403b2,0xf8dc06b1}},	//   _epz_, _дурӯ, kløð, _मलाय, 
   {{0x443001a6,0xc0b80092,0x00000000,0x00000000}},	//   _fpz_, _ሲሉም_, --, --, 
   {{0xa5b80124,0x704400db,0x80ac00eb,0x00000000}},	//   _ipóp, تئشك, টেস্, --, 
   {{0x63a92460,0x69c41f7f,0xf1a803e6,0xf0740131}},	//   cogn, zmje, داڵه_, йиһә_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa2a0084a,0xf1a804d3,0x2d88068c,0xafe40162}},	//   _छुट्, _ئاره_, òbe_, gløð, 
   {{0xdd9402d5,0x3ce8012d,0x6b8c0857,0x00000000}},	//   ўшы_, छड़े_, ticg, --, 
   {{0xdd8cc5a5,0x60840023,0xab5800a2,0x00000000}},	//   _یون_, _ንንጉስ_, mmük, --, 
   {{0x6e200173,0x705003e6,0x5a44ede6,0xafe40174}},	//   _uqob, _رۆکا, мэра, bløð, 
   {{0x9d14016c,0xeba80174,0x69c401a6,0x6b8c00b5}},	//   _дошт_, _bløð_, umje, sicg, 
   {{0x69c4044e,0x984806bb,0x65640455,0x63a8ae51}},	//   rmje, оята_, _rojh, yogn, 
   {{0xa5b8035b,0x69c42804,0x65640477,0xdb1402d2}},	//   _apóp, smje, _sojh, _þaðe, 
   {{0x63a92461,0xe5051d63,0x65640218,0x44301b5c}},	// [1bd50] vogn, قباي, _pojh, _spz_, 
   {{0x443005b1,0xa2c8012a,0x961808de,0x04880209}},	//   _ppz_, _तृष्, تغفر_, бәби_, 
   {{0x63a886ed,0x6fc80d41,0xd54800f1,0xd4040229}},	//   togn, ागां, تللو_, дячи, 
   {{0xb864021a,0xdc9808a8,0x00000000,0x00000000}},	//   _راپو, סיאל, --, --, 
   {{0xc0e52462,0x44300175,0x96082f6a,0x00000000}},	//   полк, _wpz_, _мэра_, --, 
   {{0x63a89acb,0x00000000,0x00000000,0x00000000}},	//   sogn, --, --, --, 
   {{0xd40401b9,0x63a8ac43,0x45cc313e,0x00000000}},	//   _ояти, pogn, _ﺑﻮﻳﻼ, --, 
   {{0xdb040432,0x00000000,0x00000000,0x00000000}},	//   _ikiç, --, --, --, 
   {{0x4274036b,0x11d4215c,0x00000000,0x00000000}},	//   _эгас, ستۇد, --, --, 
   {{0x26f40183,0x45f4031c,0x00000000,0x00000000}},	//   ইলটো_, _བསླས_, --, --, 
   {{0xbb442763,0xa6d803b2,0xfe780118,0xafe403b2}},	//   пенк, _raðn, mcům_, rløð, 
   {{0xab58002f,0x23c800cd,0x00000000,0x00000000}},	//   nmüh, िषिद, --, --, 
   {{0xee2d2463,0x80ac00cc,0x81dc0154,0x00000000}},	//   _ян_, টেশ্, থীর_, --, 
   {{0xdce0389e,0xfe780118,0x00000000,0x00000000}},	//   _konč, ncům_, --, --, 
   {{0x7d012464,0xa9a005f5,0xec6c0451,0x00000000}},	//   mals, хирд, _مٿو_, --, 
   {{0x7d00005c,0xdce0702b,0x59bc00bc,0x68400006}},	//   lals, _monč, ोगहर, энса, 
   {{0x7bd4004b,0xdce0231e,0xf5080818,0xcbc4007b}},	// [1bd60] _iiyu, _lonč, йнал_, _تزوي, 
   {{0x7d0014dc,0x7bd52465,0x9ae800cf,0xab58002f}},	//   nals, _hiyu, _دۉڭك_, emüh, 
   {{0x7bd52466,0xa6d80a87,0xfe78013a,0x00000000}},	//   _kiyu, _kaðl, dcům_, --, 
   {{0x7bd521ba,0xe7bc00cd,0x437401f4,0x00000000}},	//   _jiyu, ्षणप, мучт, --, 
   {{0x7d001455,0x7bd52467,0x64a0016c,0x63012468}},	//   kals, _miyu, _ҷара, روول, 
   {{0x7bd52469,0x7d01246a,0xdce00010,0xeeb400d1}},	//   _liyu, jals, _bonč, үккә_, 
   {{0x68e0334b,0x7d01246b,0x7bd40295,0x6da40032}},	//   _ûnde, dals, _oiyu, үҙең_, 
   {{0x23241b10,0x2c80020c,0xdce028b5,0x7bd434a9}},	//   _носи_, _lédé_, _donč, _niyu, 
   {{0x2cb801fa,0xc32c0116,0xfe78013a,0x63a03df9}},	//   _špd_, _خەن_, bcům_, énne, 
   {{0x7bd40b45,0xdce0a0ac,0x00000000,0x00000000}},	//   _aiyu, _fonč, --, --, 
   {{0x3204022c,0xdce000ef,0x53dc0118,0x00000000}},	//   lsoy_, _gonč, यदिश, --, 
   {{0x7bd5246c,0x7d00007d,0xc044065f,0x00000000}},	//   _ciyu, aals, _زخمو, --, 
   {{0x7d000029,0x2aa861ff,0x3204155d,0xaac40034}},	//   bals, стно_, nsoy_, रेंक, 
   {{0x5e54025f,0x7d01246d,0x7bd40086,0x2c8006af}},	//   _מידע_, cals, _eiyu, _cédé_, 
   {{0x2c81246e,0x7bd40309,0xc8c801f7,0x00000000}},	//   _dédé_, _fiyu, زورن_, --, 
   {{0x7bd4089c,0x3b00020c,0x5ba40953,0x320408a9}},	//   _giyu, cakq_, _прыз, ksoy_, 
   {{0xefd4069c,0x2c800129,0x257c0129,0x1634234c}},	// [1bd70] _ካብዚ_, _fédé_, _lîle_, нетя, 
   {{0x2c80585c,0x7bd5246f,0x95c8026b,0x00000000}},	//   _gédé_, _ziyu, пуха_, --, 
   {{0xc8c001d9,0xfe780118,0x69dc0200,0x234800f2}},	//   _एरिट, vcům_, _huqe, یسچی_, 
   {{0x69dd2470,0x7bd402b9,0xdce0107d,0x64c001f9}},	//   _kuqe, _xiyu, _ronč, वेगळ, 
   {{0xdce00fb7,0x7d0060b7,0x69d4031c,0x32040158}},	//   _sonč, yals, _kixe, gsoy_, 
   {{0x29012471,0x69dd10e2,0xefd402d3,0x69d40327}},	//   naja_, _muqe, _ካብዛ_, _jixe, 
   {{0x69d52472,0x7d012473,0x7ae401e6,0x69dc016d}},	//   _mixe, vals, yckt, _luqe, 
   {{0x69d52474,0x29012475,0x2fdc07c5,0xe7bc0882}},	//   _lixe, haja_, _dutg_, ्षिप, 
   {{0x29012476,0x69dc014f,0x7bd52477,0x06500092}},	//   kaja_, _nuqe, _riyu, _ሃላፊዎ, 
   {{0x29012478,0x7bd52479,0xdce1247a,0x69d5247b}},	//   jaja_, _siyu, _tonč, _nixe, 
   {{0x7bd5247c,0x7d011132,0xe7bc1fbc,0x00000000}},	//   _piyu, rals, ्षाप, --, 
   {{0x69d400f7,0x61f8063f,0x7bd4011c,0x69dd247d}},	//   _aixe, _kwul, _qiyu, _buqe, 
   {{0x69dc0333,0x2901247e,0x69d5247f,0x7d012480}},	//   _cuqe, faja_, _bixe, pals, 
   {{0x29001cc6,0x69dd2481,0x7bd52482,0x7c645f2e}},	//   gaja_, _duqe, _wiyu, _ياغل, 
   {{0xb9049401,0x69d52483,0x7bd52484,0x6da12485}},	//   _फल_, _dixe, _tiyu, _шиша, 
   {{0x61f81514,0x69d49307,0x2900013c,0x69dc025c}},	//   _owul, _eixe, aaja_, _fuqe, 
   {{0x29012486,0x61f801f2,0x69d41864,0x200401a9}},	// [1bd80] baja_, _nwul, _fixe, hsni_, 
   {{0x29001326,0xe6140408,0x96d40166,0x28a40073}},	//   caja_, ьду_, _үсмә, _गडचि, 
   {{0x39592487,0x61f8b23d,0x200400f3,0x00000000}},	//   _inps_, _awul, jsni_, --, 
   {{0xd3701c02,0x69d401e2,0x320403d1,0xc4c4249f}},	//   دۇر_, _zixe, tsoy_, رتلو, 
   {{0x69d4009a,0xa13000d1,0xf1a815eb,0xef240037}},	//   _yixe, چرىش, ياته_, üümi_, 
   {{0x69d4e05e,0x32052488,0x2004022e,0x61f8012d}},	//   _xixe, rsoy_, fsni_, _dwul, 
   {{0x61f92489,0x2005248a,0xefb001b9,0x00000000}},	//   _ewul, gsni_, پیشگ, --, 
   {{0x02b80050,0x33640006,0x00000000,0x00000000}},	//   _کھٔژ_, _ўваг, --, --, 
   {{0x20040ba7,0xe294021f,0x3204022e,0xb1140116}},	//   asni_, _жат_, qsoy_, _يورغ, 
   {{0x2fdc04cc,0xa6d8032e,0xabe401ec,0xa1c032dc}},	//   _tutg_, _raðm, _ﺍﻟﺭﻋ, _абуд, 
   {{0x29000f03,0x6b540139,0x69dc014f,0x00000000}},	//   vaja_, _bügе, _suqe, --, 
   {{0x2901248b,0x69d5248c,0xef3000c7,0x69dc0200}},	//   waja_, _sixe, _рҭиы, _puqe, 
   {{0x290025e4,0x69d5248d,0xfd7801ed,0xde000120}},	//   taja_, _pixe, زشیں_, _апчи, 
   {{0x69d4022f,0x5d50008e,0xfca80066,0x00000000}},	//   _qixe, _акшт, _کاهو_, --, 
   {{0x69d5248e,0x2d9d248f,0x9c40035b,0x00000000}},	//   _vixe, mnte_, _ахыл, --, 
   {{0x69dd2490,0x2d9c002e,0x00000000,0x00000000}},	//   _tuqe, lnte_, --, --, 
   {{0x29012491,0x69d52492,0xf1dc05d7,0x56952493}},	// [1bd90] paja_, _tixe, _फूलन, ватт, 
   {{0x2d9d2494,0x61f800ca,0x20052495,0x69d40393}},	//   nnte_, _rwul, ysni_, _uixe, 
   {{0x2d9d2496,0x61f80083,0x200401d5,0x00000000}},	//   inte_, _swul, xsni_, --, 
   {{0x2d9c03fa,0xeb9c0158,0xa6d82507,0x00000000}},	//   hnte_, nnø_, _maðk, --, 
   {{0x427405f5,0x41b52497,0xefcc01f3,0x28d000dc}},	//   эгдс, нскт, _ባሪያ_, _धृति, 
   {{0xc10400c6,0x20051eb2,0x2d9c0200,0xa2c800cd}},	//   روبي, tsni_, jnte_, तेष्, 
   {{0x2fc40192,0xe0543047,0xdce0005f,0xee3400c7}},	//   _bhog_, بیات_, _nonā, ҵны_, 
   {{0x2d9d2498,0x2fc4036b,0x7dcc002d,0xfe440261}},	//   ente_, _chog_, _lźst, енио, 
   {{0xee3445b3,0x2fc400f2,0x61f80117,0xa2c80b02}},	//   ены_, _dhog_, _uwul, तेश्, 
   {{0xa6d808a5,0x216401d5,0x3c640114,0xbd44009a}},	//   _baðk, _ўтаг, еког, رنجي, 
   {{0x71d4011a,0xa2c800cd,0x00000000,0x00000000}},	//   _נועד_, तेर्, --, --, 
   {{0x9eb004a9,0x39580f85,0xab58002f,0x00000000}},	//   _ишлә, _snps_, hlüf, --, 
   {{0x7dcc002d,0x6e2800c7,0xd9440240,0x00000000}},	//   _bźst, ĩmbá, _ብምውፋ, --, 
   {{0x6e2800e4,0x00000000,0x00000000,0x00000000}},	//   ũmbá, --, --, --, 
   {{0x613003b9,0x00000000,0x00000000,0x00000000}},	//   mılı, --, --, --, 
   {{0x6130825f,0x7044001f,0x16840133,0xe9fc0051}},	//   lılı, ረሰባቸ, پارێ, _chẳg_, 
   {{0xb6a405f5,0x27fc0841,0x87b800c0,0xdce000de}},	// [1bda0] хиал, ćuna_, фурт_, _zonā, 
   {{0x61301ae6,0xf2000210,0x00000000,0x00000000}},	//   nılı, रीफ़_, --, --, 
   {{0x68e0002d,0xef240254,0x00000000,0x00000000}},	//   _ûnda, üüki_, --, --, 
   {{0x237c00a8,0x25f8032c,0x64a000c7,0xaac43cbe}},	//   _cluj_, _लौकी_, ыаха, रेकक, 
   {{0x61300259,0x2d9d2499,0xa2c80073,0x00000000}},	//   kılı, ynte_, तेल्, --, 
   {{0x2fc40204,0x7645249a,0xab58002f,0x00000000}},	//   _shog_, _isky, lmüt, --, 
   {{0x2d9c7eb1,0x613000ac,0x2fc400a3,0xa6d801a8}},	//   vnte_, dılı, _phog_, _baðh, 
   {{0xb901249b,0x2fc40218,0xceb81945,0xab583713}},	//   _སུ_, _qhog_, мәл_, nmüt, 
   {{0xd250168d,0x71a401c6,0xa02c0023,0xdce000ef}},	//   _خۆش_, _зааз, ደተኛታ, _sonā, 
   {{0x2d9c736b,0x613000fd,0xab580065,0x59b40950}},	//   unte_, gılı, hmüt, ंकफर, 
   {{0x2d9c03fa,0x2fc40e89,0x20301e24,0x65ac1870}},	//   rnte_, _thog_, _مفلس, ﻳﺮﯨﻠ, 
   {{0x58fc1b4b,0x2fc40280,0x764401e6,0x5cc09a25}},	//   _དབུས_, _uhog_, _osky, ысыз, 
   {{0x61300e51,0x31cc0150,0xed5801f4,0x00000000}},	//   bılı, _ﺗﻮﯕﻜ, _нод_, --, 
   {{0x613007c4,0x6f01249c,0xeb9c143a,0xab5884bf}},	//   cılı, _heoc, snø_, klüg, 
   {{0x6d4806d9,0xd8384bec,0xc08c00b8,0x25840248}},	//   _iafa, нэт_, _bāṇo_, _lílù_, 
   {{0x6d49249d,0x7c64785c,0x4a5400d1,0xccf80118}},	//   _hafa, _جاهل, _акис, lbě_, 
   {{0xc8f406bb,0x76441529,0x6f01249e,0xab580112}},	// [1bdb0] _изпъ, _csky, _meoc, tlüf, 
   {{0x6d49249f,0x257c00d2,0xab5803fa,0x6f0001e7}},	//   _jafa, _bîla_, flüg, _leoc, 
   {{0x6d4924a0,0x764524a1,0xef0400aa,0xa6d803b2}},	//   _mafa, _esky, _پټ_, _laði, 
   {{0x6d4924a2,0x61300c07,0xd4980107,0xab58002f}},	//   _lafa, zılı, хру_, slüf, 
   {{0x61304944,0x673c0477,0xab580342,0x56580153}},	//   yılı, meqj, mlüd, _заяў_, 
   {{0x6d4924a3,0x61300cc1,0x753c0c86,0x661c03f0}},	//   _nafa, xılı, cepz, muqk, 
   {{0x6f0124a4,0xd1b8484d,0xccf800bc,0xe28065ed}},	//   _beoc, راها_, dbě_, _әһли, 
   {{0x6d485f39,0x6444058a,0x6f000332,0xab580205}},	//   _aafa, _isji, _ceoc, nlüd, 
   {{0x6f0124a5,0x61303e67,0x3eb924a6,0xcee821ec}},	//   _deoc, tılı, æst_, ررين_, 
   {{0x6d4924a7,0x673c02d3,0x6f00035a,0x15cc01ec}},	//   _cafa, heqj, _eeoc, _ﺒﺎﻟﻬ, 
   {{0x61307230,0x6d4924a8,0x6f0001ab,0x518524a9}},	//   rılı, _dafa, _feoc, _сута, 
   {{0x6f0124aa,0x613070f7,0xeff40020,0x753c01c0}},	//   _geoc, sılı, ለጊያ_, zepz, 
   {{0x61304953,0xa6d808a7,0x00000000,0x00000000}},	//   pılı, _faði, --, --, 
   {{0x6d4924ab,0xa4641e38,0x64440af9,0x45f4031c}},	//   _gafa, _ተጋድሎ_, _osji, _བསྟས_, 
   {{0x9ba4104b,0x37e401d5,0xab580112,0x2fd00248}},	//   _مەدى, тобг, tmüt, _àngó_, 
   {{0xd91000dd,0x6f000005,0xe734223c,0x00000000}},	//   _گیس_, _xeoc, кес_, --, 
   {{0x6d48985a,0xab5884bf,0xa6480023,0x38480023}},	// [1bdc0] _yafa, rmüt, _ዘካየደ, _ብውሽጥ, 
   {{0x6e340724,0x6d4924ac,0xd91032de,0xf9880451}},	//   _äybe, _xafa, _دیس_, _آندي_, 
   {{0xdb0405d5,0x753c007f,0x88d8005b,0x250800f2}},	//   _skiù, repz, _пьют_, برقی_, 
   {{0x59bc038e,0x29cc025c,0xccf80118,0xab5803b9}},	//   ोगकर, _wżat_, zbě_, clüd, 
   {{0x76440450,0xdd1801e1,0x99800153,0x64b40073}},	//   _usky, _káńd, _upių_, _अडथळ, 
   {{0x25f800e1,0x29cc0003,0xd010034e,0x2a6c01e1}},	//   _लौटी_, _użat_, ملت_, _àgbe_, 
   {{0x6d5c0086,0xccf800bc,0xa6d809e8,0x741406c2}},	//   _òpai, vbě_, _raði, _جوزا, 
   {{0x6d4924ad,0x98ac0024,0xa6d80162,0x00000000}},	//   _safa, ždė_, _saði, --, 
   {{0x6d4924ae,0xa3c400af,0xb1440124,0x9e200b38}},	//   _pafa, _उठत_, _инал, لىيو, 
   {{0x6d4924af,0x53a4023b,0xccf80118,0xab580205}},	//   _qafa, _рағб, ubě_, zlüd, 
   {{0x6d4924b0,0x6f0124b1,0x2518008d,0xab5924b2}},	//   _vafa, _teoc, וויא, hlüe, 
   {{0x6d4924b3,0xdca00f14,0x661c03f0,0x409402e8}},	//   _wafa, раџи, yuqk, _срут, 
   {{0xab5805d5,0xa6d803b2,0xeda452fb,0xa994221c}},	//   vlüd, _taði, _ишко, نشست, 
   {{0x6d4924b4,0xab580139,0x00000000,0x00000000}},	//   _uafa, gmür, --, --, 
   {{0x29cc025c,0xf1cc02dd,0xebc4009b,0x00000000}},	//   _bżar_, _ﺗﻮﻟﻘ, _иљин, --, 
   {{0x661c0309,0x00000000,0x00000000,0x00000000}},	//   tuqk, --, --, --, 
   {{0xd2442dd2,0xc31802f5,0x68e0000f,0xe9fc0051}},	// [1bdd0] _بۆ_, ণ্ডি_, _ûndo, _thằg_, 
   {{0x27100016,0xe7c00f90,0x00000000,0x00000000}},	//   ện_, _वीरप, --, --, 
   {{0x83182ad5,0x7af8013d,0x63a000d7,0x00000000}},	//   فقار_, _íctí, énno, --, 
   {{0x661c0309,0xab58002f,0xb0600139,0x14c80022}},	//   puqk, llüb, _ñäyt, тыуи_, 
   {{0x661c0784,0xe3c00205,0x534400c7,0x00000000}},	//   quqk, _alıç_, рхха, --, 
   {{0x6444334b,0xa6d802d2,0x00000000,0x00000000}},	//   _tsji, _baðv, --, --, 
   {{0x80ac00bd,0x00000000,0x00000000,0x00000000}},	//   য়েন্, --, --, --, 
   {{0x442124b5,0xa3c400af,0x998000a2,0x932402dd}},	//   muh_, _उठि_, _ewiň_, _ەرەن, 
   {{0x442124b6,0xfce40b59,0x00000000,0x00000000}},	//   luh_, лопо, --, --, 
   {{0xbc18443f,0x98b80374,0xfd10007b,0x1d781954}},	//   німі_, herā_, حجة_, _ብሪቲሽ_, 
   {{0x442124b7,0xa3c41533,0xe02400c7,0xcfcc0150}},	//   nuh_, _उठा_, _шьап, _ﺗﯟﺍﺗ, 
   {{0x4fa400d6,0xa5b80120,0x29100009,0x442001ab}},	//   _києв, _epóx, _adxa_, iuh_, 
   {{0x442124b8,0xed4d24b9,0x62880007,0x9e640137}},	//   huh_, _ло_, nzgo, _جاان, 
   {{0x0d840845,0x6288005a,0xa3c40037,0x24640092}},	//   _клін, izgo, _उठऽ_, _ተፋሰስ_, 
   {{0x442124ba,0xa6d81c38,0xd1f0001f,0xaa8405f7}},	//   juh_, _maðu, _ግዛት_, _prýð, 
   {{0x442124bb,0xab580254,0x00000000,0x00000000}},	//   duh_, smür, --, --, 
   {{0xa7a524bc,0x442124bd,0x35a401c0,0xaa540451}},	// [1bde0] укта_, euh_, гааг, _مليا_, 
   {{0x442124be,0x39440108,0x00000000,0x00000000}},	//   fuh_, _сног, --, --, 
   {{0x442124bf,0x7c2005b1,0x20100005,0x04b40006}},	//   guh_, nulr, áxil_, асця, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7c200e78,0x442001ab,0xc8b41bf4,0xbfcc00d1}},	//   hulr, auh_, _ملیک, _ﺗﺎﭘﺸ, 
   {{0x44211efe,0x54b4008e,0xf42800d8,0x00000000}},	//   buh_, _кәеф, _погл_, --, 
   {{0x44200548,0x32d805d1,0xa6d802d2,0xc1d401e0}},	//   cuh_, _büyü_, _daðu, рөтә, 
   {{0x7c2124c0,0xa8540302,0xf52400aa,0x85e0005e}},	//   dulr, ריקה_, _جګړه_, _اۋەن, 
   {{0x59b407b7,0xb384001f,0x6b580139,0x32d803e3}},	//   ंकार, ዛኛውን_, _lägä, _düyü_, 
   {{0xe2941142,0xe0cc0014,0x7c2003ac,0x00000000}},	//   _сау_, _کٲم_, fulr, --, 
   {{0xa5b40677,0x00000000,0x00000000,0x00000000}},	//   רליק_, --, --, --, 
   {{0x33240204,0xfbcc0451,0x00000000,0x00000000}},	//   ngox_, وڪي_, --, --, 
   {{0x442001fa,0xedf001d5,0x89480023,0x9a8524c1}},	//   zuh_, _ايتگ, _ብምውጻ, бурл, 
   {{0x442124c2,0xab580732,0x61ec06af,0x0cd41468}},	//   yuh_, flüc, _écle, _колю, 
   {{0xab5803fa,0xbebc02b5,0x98b80374,0x442124c3}},	//   glüc, ngūn, terā_, xuh_, 
   {{0x9f444606,0x78bc03cd,0x44200327,0x00000000}},	//   ppnå_, _dypv, vuh_, --, 
   {{0x442124c4,0x461412a5,0x15f400c6,0x00000000}},	// [1bdf0] wuh_, شوار, مسلح, --, 
   {{0x628809a8,0xa50c0073,0xa9c41176,0x3eb80254}},	//   vzgo, ाणेच_, _حزبو, üsti_, 
   {{0x442124c5,0x842400d1,0x00000000,0x00000000}},	//   uuh_, شىشن, --, --, 
   {{0x06c805f5,0x6288005a,0xb87c0092,0x02d8007b}},	//   _үгүй_, tzgo, _ያመጣል_, نواب_, 
   {{0x5694008e,0x628805c7,0x89480240,0x00000000}},	//   _гаят, uzgo, _ብምዕጻ, --, 
   {{0x44206c04,0x99540166,0x80141149,0x00000000}},	//   puh_, _mäş_, афиц, --, 
   {{0xddc802d5,0x98b80276,0x4420011f,0x99540a43}},	//   žiūr, meră_, quh_, _läş_, 
   {{0x7fd4005e,0x427428e5,0x98b80356,0xb2700ce8}},	//   шілі, _кгбс, leră_, сләш, 
   {{0x63b924c6,0x5238ebc2,0xc1000184,0xbea400f7}},	//   _ikun, _مسلح_, _һүҙл, рапк, 
   {{0xefdc02d3,0x6300004b,0x98b80356,0x7c205204}},	//   _ሓወይ_, _خوړل, neră_, tulr, 
   {{0x63b924c7,0xbf1436fe,0x8d5402d5,0x9e900451}},	//   _kkun, _نواب, стыч, _ڏهاڪ, 
   {{0x63b8038f,0x99540209,0xd25001ed,0x68e0000f}},	//   _jkun, _bäş_, _بنے_, _ûndj, 
   {{0x63b924c8,0xaca00023,0xdb0403b9,0x6b580139}},	//   _mkun, _ዚድግፉ_, _ikiü, _sägä, 
   {{0x63b8089c,0x99540139,0xd7f8054e,0x98b8054e}},	//   _lkun, _däş_, ţăm_, jeră_, 
   {{0x63b924c9,0x9c10063f,0x98b80276,0xa96524ca}},	//   _okun, _kọmu, deră_, шира_, 
   {{0x59b40316,0xa7a407b5,0xdce00171,0x00000000}},	//   ंकहर, акса_, _olnī, --, 
   {{0x98b80276,0x7e6924cb,0xab580e78,0x00000000}},	// [1be00] feră_, nxep, slüc, --, 
   {{0x09e00003,0x8ccc033f,0x98b80356,0x78bc002f}},	//   _སྤྲ_, _हरमो, geră_, _typv, 
   {{0xa6d808a5,0x774c1954,0x00000000,0x00000000}},	//   _baðs, ሕበረሰ, --, --, 
   {{0x995400fd,0x21e801bf,0xdec80092,0x00000000}},	//   _yäş_, _bøh_, ጠሩን_, --, 
   {{0xe1ed24cc,0x98b80276,0x511924cd,0x23240b01}},	//   وسو_, beră_, голю_, рочи_, 
   {{0x63b85b36,0xf1a800c6,0xe2943849,0x33f40212}},	//   _ekun, خاصه_, шач_, _вчас, 
   {{0x64a124ce,0x63b80270,0x600405f5,0x7654005b}},	//   _дара, _fkun, ахыг_, lvyy, 
   {{0xa4f00327,0xc2e8007b,0xa0640114,0x00000000}},	//   _བཅོག_, _معكم_, раћа_, --, 
   {{0x3dc802b5,0x00000000,0x00000000,0x00000000}},	//   _ūawa_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdeec43a7,0x63b80113,0x9c1001e1,0xa6d808a5}},	//   _мы_, _ykun, _fọmu, _jaðr, 
   {{0x5c700212,0x6ed800cd,0x00000000,0x00000000}},	//   ілят, _पृथु, --, --, 
   {{0xfaec00aa,0x6da524cf,0x88cc0241,0x00000000}},	//   رګي_, _кида, _ṣàlà, --, 
   {{0x59f8084c,0xdef40092,0x49a40150,0x00000000}},	//   реря_, _ለሆነ_, сымғ, --, 
   {{0xded00201,0xa3c400af,0x98b8054e,0x00000000}},	//   _ከሆነ_, _उठल_, veră_, --, 
   {{0xd7f924d0,0xeab0a012,0x99540139,0x9cd8011a}},	//   рур_, _وعظ_, _täş_, _בקופ, 
   {{0x6b8416e0,0x85140212,0x98b8054e,0x00000000}},	// [1be10] _مشکل, ймає, teră_, --, 
   {{0x73c00724,0x63b924d1,0xa6d802d2,0x00000000}},	//   җәсе, _skun, _saðs, --, 
   {{0xdef40092,0x58d40408,0x00000000,0x00000000}},	//   _ለሆኑ_, _моьт, --, --, 
   {{0x98b80276,0xded0001f,0xdce001a6,0x21e80fac}},	//   seră_, _ከሆኑ_, _tonć, _pøh_, 
   {{0x98b80276,0x5b5800df,0x00000000,0x00000000}},	//   peră_, ישאן_, --, --, 
   {{0x90e40952,0x58fc0327,0x00000000,0x00000000}},	//   يسىن, _དབབས_, --, --, 
   {{0x63b80003,0x00000000,0x00000000,0x00000000}},	//   _tkun, --, --, --, 
   {{0x63b924d2,0x21e803cd,0x00000000,0x00000000}},	//   _ukun, _tøh_, --, --, 
   {{0x3984006a,0x8e080209,0xdb04017a,0x98b87502}},	//   _lôsa_, амың_, _sjiï, merą_, 
   {{0xbd886e93,0x51740491,0x3ea4006c,0xa3c81889}},	//   اندن_, _والأ, _қилг, _रीत_, 
   {{0x3b085549,0xe7c40f4c,0xdd2c0118,0xfce40304}},	//   лено_, लताप, _těži, _һоло, 
   {{0x3fc8034c,0x7654023a,0x98b80064,0x00000000}},	//   _صدای_, yvyy, nerą_, --, 
   {{0xeb945279,0xa2c80490,0xfce4014b,0xca740588}},	//   сия_, तेच्, _лоло, оуры, 
   {{0x81a80c58,0xf2d0011a,0x39482f09,0x00000000}},	//   _গীত_, פעם_, ызго_, --, 
   {{0xbbf4e9d0,0x19c401e0,0xed4c00f1,0xab580205}},	//   _استث, йәүг, _سپي_, mlün, 
   {{0x6d5c026c,0xda200037,0x8ae806be,0x00000000}},	//   _òpar, _बिपत_, ndәl, --, 
   {{0x3c3043ed,0x5fdc00af,0x00000000,0x00000000}},	// [1be20] láv_, _पूछल, --, --, 
   {{0xd910205b,0xdb042b34,0xab581b0d,0xb8cc00eb}},	//   _زیر_, _ikiñ, nlün, _ঔর_, 
   {{0xf744ca40,0x08c001ec,0x76540108,0x00000000}},	//   _лено, _жұрн, svyy, --, 
   {{0xb28400f7,0x15b8190b,0x2be8000d,0x8458014b}},	//   йылк, уығы_, _घंसू_, шрут_, 
   {{0xd5b02832,0x8ae806be,0x00000000,0x00000000}},	//   _قہر_, ddәl, --, --, 
   {{0x73341e87,0x3c300122,0xfcd0001f,0x9404008e}},	//   _گىرا, káv_, _የመጡ_, _могҗ, 
   {{0xf07404a9,0x21640640,0xb6400150,0x161001f9}},	//   сийә_, сији_, _ﺍﻫ_, ाळकर_, 
   {{0x733466a3,0x00000000,0x00000000,0x00000000}},	//   _دىرا, --, --, --, 
   {{0x52b400db,0x6ce401ec,0xe3601513,0xad6406c2}},	//   _بەشئ, йіне, _экти, ماده, 
   {{0x61ed24d3,0x61180421,0x8ccc0034,0xab5805d5}},	//   _écla, gālē, _हरदो, glün, 
   {{0xdb0400b8,0xb2840139,0xdce0013a,0x00000000}},	//   _akiñ, _тыңк, _honě, --, 
   {{0x60d800c8,0x255c00e2,0x7c640131,0xdef4004e}},	//   _עקאנ, _zālē_, زاپل, _лыш_, 
   {{0xab582045,0x9c100241,0x9a84004e,0x00000000}},	//   blün, _lọhu, пурл, --, 
   {{0x298800f3,0x00000000,0x00000000,0x00000000}},	//   усмо_, --, --, --, 
   {{0xfd64063f,0x26c80419,0x1994022e,0xd7f800db}},	//   hetụ, _szco_, чаря, йут_, 
   {{0xfcd0001f,0x6b8401b9,0x473402d5,0xc6f82f59}},	//   _የመጣ_, _دشتل, ўнас, рнах_, 
   {{0x2d9c9a14,0x0614005b,0x85740408,0xab580205}},	// [1be30] oite_, юдаю, олах, llüo, 
   {{0x7c4524d4,0x2d9d24d5,0xe4c924d6,0xd918026b}},	//   _útró, nite_, هبان_, _лью_, 
   {{0x2ee403cb,0x2d9c007c,0xee2400ec,0x1bf800df}},	//   _ogof_, iite_, _ڪٽ_, ָלדב, 
   {{0x2d9d24d7,0x23081473,0x18883740,0x9c1001e1}},	//   hite_, اتاي_, _ысып_, _sọku, 
   {{0x2d9d24d8,0x13080212,0x73c005a2,0xab5803e0}},	//   kite_, сній_, фәре, ylün, 
   {{0x2d9c341a,0x1a9c008f,0x2ee4002f,0xb6400150}},	//   jite_, ניגע, _agof_, _ﺍﺫ_, 
   {{0x2d9d24d9,0x442455e9,0x2454031c,0x00c40150}},	//   dite_, _êl_, _uħm_, _ﺯﺍﺗﻘ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2d9c685c,0x048400b8,0x00000000,0x00000000}},	//   fite_, _ādṛt, --, --, 
   {{0x2d9d24da,0x3c3043ed,0x7d080063,0x00000000}},	//   gite_, táv_, шног_, --, 
   {{0xd164a3c3,0x7f184957,0x4420009a,0xbb4401af}},	//   _эъти, _نياز_, nrh_, оенк, 
   {{0x3c300232,0x2d9d24db,0xf41004ae,0xd5d000bc}},	//   ráv_, aite_, ופט_, _तीनज, 
   {{0x2d9d24dc,0x34c40d2c,0xab5924dd,0xdd2002d3}},	//   bite_, _वर्द, mlül, _ተጠርኒ, 
   {{0x2d9cd34f,0x3f8c06ed,0xab581b0d,0xae400451}},	//   cite_, lheu_, llül, _آھيو, 
   {{0xedd00b24,0xe9d4003b,0x00000000,0x00000000}},	//   _تيود, ікс_, --, --, 
   {{0x8224031c,0xb9e80139,0xab582791,0x00000000}},	//   _རཀྵི_, _кмиз_, nlül, --, 
   {{0x257c025a,0xdb040054,0x57940023,0x498800db}},	// [1be40] _zîli_, _ukiñ, _መወከሲ_, _گئيپ_, 
   {{0x59b401c6,0x00000000,0x00000000,0x00000000}},	//   _хөмс, --, --, --, 
   {{0x2db400c8,0x1bec0037,0x00000000,0x00000000}},	//   קלען_, _घूमल_, --, --, 
   {{0xdb24020c,0x72c40835,0x00000000,0x00000000}},	//   èsèd, обез, --, --, 
   {{0x2d9d24de,0x776400aa,0xdce000bc,0x3f8c0023}},	//   yite_, _inkx, _poně, dheu_, 
   {{0x3f8c003e,0x7bc4002f,0x00000000,0x00000000}},	//   eheu_, hlku, --, --, 
   {{0x4420020b,0xe0d00114,0xdce0013a,0x00000000}},	//   crh_, мошњ, _voně, --, 
   {{0x4e18000d,0x232400f3,0x00000000,0x00000000}},	//   _दिआई_, _моси_, --, --, 
   {{0x71a400c7,0x9ed4011c,0x00000000,0x00000000}},	//   _дааз, омът_, --, --, 
   {{0x7bc40b4f,0x918000cf,0xa2d400cd,0x00000000}},	//   elku, _سۇعۇ, यधर्, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3984145e,0x3f8d24df,0x6fe8002d,0xa29c0073}},	//   _bôso_, cheu_, _ręch, _खेड्, 
   {{0xe8e02432,0x44200165,0xda7800fb,0x98b80210}},	//   पश्च, zrh_, ояр_, merę_, 
   {{0x2dd40050,0x6fe8033f,0x4c9400f0,0x2d9c036e}},	//   _بُتھ_, _pęch, _нилс, qite_, 
   {{0x7af40142,0xd7f801c6,0xab5800a2,0x3c1400b8}},	//   _ffyt, жуу_, llüm, cāv_, 
   {{0x442004bf,0x58d4009b,0xab58000d,0x176910b2}},	//   vrh_, фост, olüm, оруп_, 
   {{0xf1c80882,0x16348334,0xab581b0d,0x00000000}},	// [1be50] ितान, метя, nlüm, --, 
   {{0x77640472,0xdce001e4,0x3f8c0369,0xa4841916}},	//   _enkx, _lonĝ, zheu_, يجان, 
   {{0xd5b81fe2,0x290124e0,0xe7740d52,0xab5924e1}},	//   ісу_, mbja_, _данә_, hlüm, 
   {{0x442124e2,0x69c524e3,0xbd040241,0x668007d6}},	//   rrh_, llje, _afẹ́, _قیزل, 
   {{0xefdc02d3,0x016402e8,0x69c433b8,0x44200175}},	//   _ሓለዋ_, зкло, olje, srh_, 
   {{0x69c4000f,0x3f8c00b0,0xd5b80063,0x00000000}},	//   nlje, wheu_, _дсс_, --, 
   {{0x3f8c0184,0x7ff400c6,0xd14800ec,0x69c4062c}},	//   theu_, أستا, زشون_, ilje, 
   {{0x69c401fa,0x68e0000f,0x61ec06af,0x3f8c003e}},	//   hlje, _ûndu, _éclo, uheu_, 
   {{0xab580598,0xb27401e0,0x63a80200,0x25fc01f9}},	//   glüm, _ектә, mngn, शीची_, 
   {{0x61f924e4,0x69c422c1,0x3c140a30,0xbd44007b}},	//   _itul, jlje, tāv_, أندي, 
   {{0xdb240344,0x69c40841,0x63a924e5,0xab5803e0}},	//   وودی, dlje, ongn, lmüy, 
   {{0x61f807d5,0x63a80d04,0x69c4000f,0xeb948d93}},	//   _ktul, nngn, elje, зию_, 
   {{0x7f4820ac,0x69c401fa,0x63a924e6,0xab5805d1}},	//   meeq, flje, ingn, nmüy, 
   {{0x61f8c53d,0x7f4820ac,0x69c42230,0x2bac0210}},	//   _mtul, leeq, glje, ręca_, 
   {{0x8d74215c,0x7bc40113,0x39e80107,0x7e700356}},	//   _تانا, plku, рдҳо_, ţepă, 
   {{0x61f924e7,0xa3c805f9,0x7f480140,0x69c4000f}},	//   _otul, _रील_, neeq, alje, 
   {{0x69c449ad,0x98ad24e8,0x29003b8e,0x61f924e9}},	// [1be60] blje, ıdı_, bbja_, _ntul, 
   {{0xe61524ea,0x63a80007,0x69c401fa,0x00000000}},	//   яду_, engn, clje, --, 
   {{0x8d800201,0x61f924eb,0x225c0165,0x799c02d0}},	//   _ይገባል_, _atul, _aruk_, _impw, 
   {{0x225d24ec,0x39480408,0x63a8020c,0x07e800e5}},	//   _bruk_, lebs_, gngn, _گریٹ_, 
   {{0x1154b19d,0x225c003e,0xdce00115,0x799c03ac}},	//   дклю, _cruk_, _ronĝ, _kmpw, 
   {{0x225c7890,0xdce0008f,0x00000000,0x00000000}},	//   _druk_, _sonĝ, --, --, 
   {{0xf3f40491,0x61f924ed,0x7f4805b1,0x799c03ac}},	//   åңđ_, _etul, feeq, _mmpw, 
   {{0x7f480869,0x64580034,0x69c41710,0x00000000}},	//   geeq, śció, zlje, --, 
   {{0x69c40a85,0x312407ee,0x00000000,0x00000000}},	//   ylje, _ндаг, --, --, 
   {{0x20500daf,0x6678008f,0x0bf400db,0x00000000}},	//   фтәр, צטיק, мпою, --, 
   {{0x2ee48986,0xab5803ee,0xa1100a81,0xa06401fe}},	//   _ежег, slüm, _سونت, _нафа_, 
   {{0x799c7291,0xda1c022e,0x12c000eb,0xab58010e}},	//   _ampw, _o奏di_, েশীদ, mlük, 
   {{0xab5800a2,0x00000000,0x00000000,0x00000000}},	//   llük, --, --, --, 
   {{0xed3405f5,0x799c02d0,0xaa6800ee,0x69f001c6}},	//   _хэдэ, _cmpw, _güýç_, _үүнт, 
   {{0x290124ee,0x63a80649,0xab58344b,0x69c4000f}},	//   rbja_, yngn, nlük, rlje, 
   {{0x69c43d67,0x4508015b,0xab580793,0x00000000}},	//   slje, _লাইক_, ilük, --, 
   {{0xab5803be,0xd6b40395,0x2bd0000d,0x5bc400ae}},	// [1be70] hlük, ейтъ, _धीया, _ثقيل, 
   {{0x26c41991,0xab581432,0x21b80150,0x00000000}},	//   āno_, klük, _ﺠﻬﺎﺭ, --, 
   {{0x225c269e,0x0b000011,0xdce00166,0x00000000}},	//   _sruk_, ্লীল_, _monğ, --, 
   {{0x49040316,0x225c0098,0xf8b002e4,0x63a80c6a}},	//   वरको_, _pruk_, _ישי_, ungn, 
   {{0x7f4820ac,0xb224030d,0x00000000,0x00000000}},	//   veeq, çмел, --, --, 
   {{0x2b480784,0xab5805d1,0x98140214,0xe4a402dd}},	//   hecc_, rmüy, _تبیا, _ербо, 
   {{0x7f480869,0x8fc4004b,0xab580254,0x13a80133}},	//   teeq, کزون, glük, _کۆنی_, 
   {{0x225d24ef,0x61f81418,0x00000000,0x00000000}},	//   _truk_, _ttul, --, --, 
   {{0x225cff71,0x61f924f0,0x7f480869,0xee2c00ec}},	//   _uruk_, _utul, reeq, لٽي_, 
   {{0x7f48013c,0x00000000,0x00000000,0x00000000}},	//   seeq, --, --, --, 
   {{0x7f480194,0x00000000,0x00000000,0x00000000}},	//   peeq, --, --, --, 
   {{0xfaa40aa5,0x7f480194,0x394924f1,0xee2c00ec}},	//   дамо, qeeq, webs_, _ڦٽو_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x39484829,0xec6c00b2,0xc8b4d299,0x7cd80244}},	//   rebs_, _نٿو_, есты, _بوغز_, 
   {{0x17700023,0x00000000,0x00000000,0x00000000}},	//   _ኣረዲኡ_, --, --, --, 
   {{0xab5924f2,0x799c035a,0x36c40022,0x00000000}},	// [1be80] zlük, _tmpw, фбаг, --, 
   {{0x845c693c,0x00000000,0x00000000,0x00000000}},	//   _ሰላምን_, --, --, --, 
   {{0xe6540092,0x25080066,0x00000000,0x00000000}},	//   ፈልገዋ, زرلی_, --, --, 
   {{0x27f4278a,0xab5924f3,0x98b8007f,0x366924f4}},	//   žené_, vlük, nfrč_, _дамо_, 
   {{0x781c07f7,0x1bec000d,0x5fd40150,0x00000000}},	//   _बटुक_, _घूसल_, _ﺟﺎﭘﻘ, --, 
   {{0x75d412ea,0x06b80133,0x323c0023,0x00000000}},	//   _آيسا, _ژنێک_, _ሓይለኣ, --, 
   {{0xa0640640,0xf2000412,0xab580112,0x90b400c7}},	//   даја_, रीज़_, blüh, хәаш, 
   {{0xab5805d1,0xdce0008e,0x00000000,0x00000000}},	//   rlük, _sonğ, --, --, 
   {{0xad240228,0x88d40055,0xaf4802cb,0x00000000}},	//   وردو, _hṛto, مشکل_, --, 
   {{0x71647d8a,0xe1200b2b,0x6fe8003a,0x88d4002b}},	//   _تارك, _амфи, _sęcu, _kṛto, 
   {{0x30840d17,0x7bd400cd,0x5edc0011,0xec6800d4}},	//   _تلاف, _bhyu, ফুলে, ірок_, 
   {{0x76440af9,0x88d400b8,0x00000000,0x00000000}},	//   _opky, _mṛto, --, --, 
   {{0xed5924f5,0x7bd40055,0xdce00139,0xdfcc01c8}},	//   _мод_, _dhyu, _tonğ, _ئين_, 
   {{0xa090010b,0x00000000,0x00000000,0x00000000}},	//   _öňüm, --, --, --, 
   {{0xabb000c7,0xc31800cc,0xd8391499,0x00000000}},	//   _иакә, ণ্টি_, мэт_, --, 
   {{0x6d5924f6,0x8d740244,0x00000000,0x00000000}},	//   ldta, _تاچا, --, --, 
   {{0xe8e80228,0xab80001f,0xd6d02e0b,0x00000000}},	// [1be90] _وردو_, _ይረዳል_, لقِ_, --, 
   {{0xe5701a9b,0x00000000,0x00000000,0x00000000}},	//   خطر_, --, --, --, 
   {{0x6d5802d0,0xd9e80037,0x4ce000eb,0x00000000}},	//   idta, _टूटत_, পুরু, --, 
   {{0x68f80a28,0x00000000,0x00000000,0x00000000}},	//   śudd, --, --, --, 
   {{0xbebc02b5,0x8c4800fd,0x4ed000cc,0x00000000}},	//   ngūt, _yaşü, াখুল, --, 
   {{0x850524f7,0x00000000,0x00000000,0x00000000}},	//   _سورن, --, --, --, 
   {{0x439524f8,0x6d580fac,0xb4b42cc8,0x00000000}},	//   _завс, ddta, _зирә, --, 
   {{0x9980033f,0xb27063b8,0x6d5802d0,0x94d45124}},	//   _zwiń_, тләш, edta, _росц, 
   {{0xe4e075be,0x6d5801f5,0x051003d4,0x00000000}},	//   _कृति_, fdta, ালীৰ_, --, 
   {{0x7bd481e1,0xdea001d3,0x91b80108,0x926801d5}},	//   _shyu, ٹیڈی, _жгут_, _юрса_, 
   {{0x7bd40564,0x3cc800f7,0x00000000,0x00000000}},	//   _phyu, ялоо_, --, --, 
   {{0x2d8c5161,0x6444031c,0xa11001d3,0x6d581d01}},	//   _elfe_, _mpji, _سوچت, adta, 
   {{0xbe68009d,0x00000000,0x00000000,0x00000000}},	//   _халж_, --, --, --, 
   {{0x644404e6,0xa2d400af,0xac80013d,0x00000000}},	//   _opji, _बरन्, _әгъл, --, 
   {{0xf74524f9,0x6d3000d8,0x00000000,0x00000000}},	//   нево, _сејф, --, --, 
   {{0x7f580455,0x7cf001d3,0x00000000,0x00000000}},	//   _jawq, _fűré, --, --, 
   {{0x7f587268,0xa29c012c,0xe9cc0451,0x00000000}},	// [1bea0] _mawq, _खेल्, _ڏٺي_, --, 
   {{0x7f580455,0xd9100214,0x00000000,0x00000000}},	//   _lawq, _خیس_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x39592161,0x7f580548,0xa13000d1,0x00000000}},	//   _haps_, _nawq, ۇرىش, --, 
   {{0x71a44958,0x27b01c5c,0x0cac072a,0xa68124fa}},	//   надз, _сәрс, _चश्म, _бляд, 
   {{0x39585e20,0xaad008a3,0x00000000,0x00000000}},	//   _japs_, _सरसक, --, --, 
   {{0xb0d80d0a,0x21140691,0x3959184e,0xdce000e2}},	//   येंग, رتوب_, _maps_, _monē, 
   {{0x7f580399,0x3958007d,0x13a803e6,0xa56000db}},	//   _cawq, _laps_, _کۆچی_, _لگۅن, 
   {{0xe29409a5,0xeda4537c,0xdf7000cf,0x00000000}},	//   _зат_, ешно, ادىب, --, 
   {{0x3bd00309,0x2a640118,0xd9f40037,0x6d5924fb}},	//   váqa_, _čnb_, _आढ़त_, udta, 
   {{0x6d5924fc,0x99800432,0xde700150,0x00000000}},	//   rdta, _itiň_, _ەدىع, --, 
   {{0x317c01c6,0x75bc0073,0x09d80073,0xa2d405dc}},	//   _hotz_, ्तुळ, णग्य, _बरम्, 
   {{0x2fc40522,0x395924fd,0x58840220,0x317c002f}},	//   _ikog_, _baps_, қыра, _kotz_, 
   {{0xdee06141,0x395910ce,0x5df800d9,0x00000000}},	//   _сочи, _caps_, _צפונ, --, 
   {{0x984924fe,0x7f580429,0x317d24ff,0xfbd80451}},	//   нята_, _yawq, _motz_, _ڪاوڙ_, 
   {{0x317d2500,0x97a40209,0x387c01e3,0x00000000}},	//   _lotz_, грул, ätra_, --, 
   {{0x5694e772,0x6444002d,0xdce000ef,0x00d400d1}},	// [1beb0] гатт, _spji, _fonē, ﻜﯩﺴﺘ, 
   {{0x61eca547,0x317c01c7,0x39592501,0x984801d9}},	//   _écli, _notz_, _gaps_, بلہٕ_, 
   {{0xbebc0153,0x682400c7,0x00000000,0x00000000}},	//   ngūr, _џьоз, --, --, 
   {{0xd1740184,0x935800d4,0xf3b00124,0x04f00154}},	//   ғышы, ершу_, аҩсы, টরের_, 
   {{0xdb092502,0x317c01c7,0x2910009d,0x2314004e}},	//   élék, _botz_, _kexa_, _үнгө_, 
   {{0x7f580db4,0x00000000,0x00000000,0x00000000}},	//   _sawq, --, --, --, 
   {{0x29112503,0x94d4188b,0x7f580986,0x7bc401a8}},	//   _mexa_, _борц, _pawq, _íhug, 
   {{0x2910f221,0x7f592504,0xfe4403b7,0x99800432}},	//   _lexa_, _qawq, внио, _etiň_, 
   {{0xee352505,0x317c0036,0x00000000,0x00000000}},	//   вны_, _fotz_, --, --, 
   {{0x7f5803f0,0xdce000cd,0x29112506,0x606000d1}},	//   _wawq, _annā, _nexa_, _مۇتل, 
   {{0x5f440323,0x39592507,0x7f592508,0x3178008f}},	//   _зүйн_, _raps_, _tawq, _קרעמ, 
   {{0x39592509,0x7f580113,0x317c005a,0x00000000}},	//   _saps_, _uawq, _zotz_, --, 
   {{0xed4d250a,0x395805da,0x291034bc,0x8ae806be}},	//   _ко_, _paps_, _bexa_, ddәs, 
   {{0x237c0007,0x41c000e1,0xd6c40aac,0x00000000}},	//   _louj_, शकिस, ҳибқ, --, 
   {{0x291000d8,0x260c012d,0x00000000,0x00000000}},	//   _dexa_, eżo_, --, --, 
   {{0x810c1d72,0xec100116,0x00000000,0x00000000}},	//   हरुख_, _ئويد, --, --, 
   {{0x3959250b,0xf5e801c6,0xe734010b,0xdce000de}},	// [1bec0] _taps_, дмал_, ъет_, _tonē, 
   {{0x29100548,0x00000000,0x00000000,0x00000000}},	//   _gexa_, --, --, --, 
   {{0x237c0369,0x81c802f5,0x38288334,0x317c002f}},	//   _bouj_, োদা_, _южно_, _rotz_, 
   {{0x237c0369,0x2910009a,0x00000000,0x00000000}},	//   _couj_, _zexa_, --, --, 
   {{0x237c0007,0x317c067c,0x810c02a0,0xb2700131}},	//   _douj_, _potz_, हरूख_, рклә, 
   {{0x2fc46139,0x21646d64,0xf8d40263,0xab5806be}},	//   _skog_, кичи_, _धराय, llüt, 
   {{0xe5a09e7c,0xa5b800d2,0x8eb41df2,0x317c180f}},	//   _тири, _dvód, گەشت, _votz_, 
   {{0x237c0369,0xa0640063,0xe4540677,0x00000000}},	//   _gouj_, ђања_, _בילט_, --, 
   {{0x32440063,0x8eb400cf,0x00000000,0x00000000}},	//   _језг, دەشت, --, --, 
   {{0x237c05c7,0xab580112,0xa03000cf,0x00000000}},	//   _zouj_, hlüt, _چىلت, --, 
   {{0x237c0007,0x29100077,0x88d4002b,0x00000000}},	//   _youj_, _rexa_, _nṛpo, --, 
   {{0x29100f71,0xddd8090c,0xef8457c6,0x09bc00cd}},	//   _sexa_, dzuŵ, _шлеп, ोत्य, 
   {{0x2910003a,0x92e40183,0x00000000,0x00000000}},	//   _pexa_, পুৰ_, --, --, 
   {{0x2bd0043e,0x00000000,0x00000000,0x00000000}},	//   _धीरा, --, --, --, 
   {{0x29101709,0xb60002fb,0x7e6c00d8,0x1ae4015b}},	//   _vexa_, šáln, _àapr, কুলে_, 
   {{0xe4e073c6,0x57b5250c,0xab580254,0x310000cd}},	//   _कृषि_, абст, glüt, रुतः_, 
   {{0x237c033b,0x291001ab,0x2bac0210,0x00000000}},	// [1bed0] _rouj_, _texa_, jęci_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x95c9250d,0x98b8084c,0xab5832e9,0x00000000}},	//   тута_, _алэт_, blüt, --, 
   {{0x27e9250e,0xab580205,0x00000000,0x00000000}},	//   _uicn_, mlüs, --, --, 
   {{0x130802bf,0x6d54013f,0x96e8010a,0xe5c493e4}},	//   тній_, _ɔyar, _аьра_, _асво, 
   {{0x237c0699,0x00000000,0x00000000,0x00000000}},	//   _wouj_, --, --, --, 
   {{0x32041c06,0x35c412d7,0x237c030a,0x958c0023}},	//   apoy_, _саёҳ, _touj_, _ዘረባን_, 
   {{0x7e780120,0x7e7c01f4,0x00000000,0x00000000}},	//   ељот_, äspo, --, --, 
   {{0xfde9250f,0xab58cac5,0xcee81913,0x5338010a}},	//   ндик_, hlüs, پرين_, _шурă, 
   {{0xdc80020a,0x91e40640,0xc884294f,0x6e2401d3}},	//   иқло, _вође, _kaşı_, ákba, 
   {{0xefdc044e,0x5184bc40,0xc1000032,0x23b400dc}},	//   _ሓገዝ_, _тута, _күҙл, _अदाद, 
   {{0x20044879,0x23b000dc,0xdbc40022,0x00000000}},	//   mpni_, ंचिद, рамҩ, --, 
   {{0xbd4400ec,0xe1fc0332,0x200400c0,0x00000000}},	//   _منشي, _éód_, lpni_, --, 
   {{0xed540517,0x6840446e,0xab580e78,0x61ec06af}},	//   _бош_, әнта, flüs, _éclu, 
   {{0xe61c0120,0xab5804cc,0x23b0033f,0xcb4c022e}},	//   _avô_, glüs, ंचाद, _shaх, 
   {{0x2bb8f81d,0x32040004,0x3f8c0263,0xeabc0086}},	//   _उदया, ypoy_, nkeu_, rgùr_, 
   {{0x75444483,0x95a40124,0x00000000,0x00000000}},	// [1bee0] лназ, алаҵ, --, --, 
   {{0x7bc52510,0xc8844952,0x39840042,0x3f8c003e}},	//   loku, _başı_, _côst_, hkeu_, 
   {{0x3f8c002e,0xab5803b9,0x00000000,0x00000000}},	//   kkeu_, clüs, --, --, 
   {{0x7bc52511,0xc8840213,0x4ce000eb,0x00000000}},	//   noku, _daşı_, পুকু, --, 
   {{0x92592512,0x06752513,0x7e7c01e3,0x00000000}},	//   талт_, _куря, äspl, --, 
   {{0x32040113,0x00000000,0x00000000,0x00000000}},	//   rpoy_, --, --, --, 
   {{0x798c0083,0x3db800cc,0x33d400d4,0x00000000}},	//   ikbw, ঁতাল, _біат, --, 
   {{0x7bc4035b,0x3f8c003e,0x64a000db,0xab58002f}},	//   joku, gkeu_, _уаса, hlür, 
   {{0x2bb80037,0xc2900101,0xda200118,0xab582093}},	//   _उदबा, _ویمب, _बिगत_, zlüs, 
   {{0xc88447af,0x7e6c3341,0xc4080014,0xe280084c}},	//   _yaşı_, _šapc, _ستہٕ_, _улуи, 
   {{0xdfcc79a0,0x0cd40a42,0x7654015d,0x00000000}},	//   _гъ_, роню, hwyy, --, 
   {{0x7bc52514,0x40952515,0x00000000,0x00000000}},	//   goku, _трут, --, --, 
   {{0x7e6c0129,0x00000000,0x00000000,0x00000000}},	//   _àapp, --, --, --, 
   {{0x9ed41cb8,0x00000000,0x00000000,0x00000000}},	//   _сміт_, --, --, --, 
   {{0x7f4c0309,0x7bc52516,0x00000000,0x00000000}},	//   _ñaqc, boku, --, --, 
   {{0x7bc52517,0xab580205,0x00000000,0x00000000}},	//   coku, rlüs, --, --, 
   {{0x39840419,0x851400d4,0x07a40166,0x00000000}},	// [1bef0] _pôst_, имає, гаңн, --, 
   {{0xdb04067c,0xab5807c5,0x24841445,0x00000000}},	//   _amiè, plüs, ønmo_, --, 
   {{0xd5b92518,0x69c52519,0xa2d400dc,0xd68401e0}},	//   уст_, moje, _बरह्, _һурп, 
   {{0x69c5251a,0xf7e40131,0x00000000,0x00000000}},	//   loje, _ﺋﺎﻳﻪ, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69c5251b,0xc884247e,0x0085251c,0x98ac033f}},	//   noje, _taşı_, илло, żdą_, 
   {{0x04c84609,0x3f8c0098,0x19e400d1,0x00000000}},	//   _شوري_, tkeu_, _ﺋﻮﻏﻠ, --, 
   {{0x69c513d6,0x7bc4005a,0x0d0802dd,0x20040427}},	//   hoje, xoku, ңдық_, rpni_, 
   {{0x63a9251d,0x69c5251e,0x3f8c003e,0x7db406ed}},	//   mign, koje, rkeu_, исоц, 
   {{0x7bc43926,0x2004008c,0x1dcc05f9,0x69c5251f}},	//   woku, ppni_, _सीखत, joje, 
   {{0x69c4ef33,0x3f8c06d1,0x62892520,0x206858a7}},	//   doje, pkeu_, lygo, _яшап_, 
   {{0x63a92521,0x00000000,0x00000000,0x00000000}},	//   nign, --, --, --, 
   {{0x628800c0,0x00000000,0x00000000,0x00000000}},	//   nygo, --, --, --, 
   {{0x7bc52522,0x69c40219,0x63a92523,0xa8012524}},	//   soku, goje, hign, ğınt, 
   {{0x7bc52525,0x63a92526,0xa8000790,0x6de80022}},	//   poku, kign, şınt, _рыцҳ_, 
   {{0x398405d5,0x63a80014,0x7bc40309,0x9ba400f7}},	//   _pôss_, jign, qoku, _چەگى, 
   {{0x69c52527,0x9ba43b5f,0x63a8ec5b,0x62880432}},	// [1bf00] boje, _نەگى, dign, jygo, 
   {{0x69c40789,0x6fe8031c,0x63a92528,0x00000000}},	//   coje, _ལངྐའ, eign, --, 
   {{0x63a80c86,0xdb0401d3,0xf7440150,0x00000000}},	//   fign, _amié, _кено, --, 
   {{0x62880142,0xf2040153,0x83640133,0x63a8a620}},	//   fygo, аяко, یدۆل, gign, 
   {{0xb9600241,0x00000000,0x00000000,0x00000000}},	//   _àìso, --, --, --, 
   {{0xab580e78,0x63a80076,0xf02400d8,0x00000000}},	//   hlüp, aign, аќин, --, 
   {{0x63a92529,0x2eac26e4,0x310000dc,0x25ac0129}},	//   bign, ञप्त, रुषः_, ègle_, 
   {{0x63a80395,0x628800a9,0x69c5252a,0xceb80daf}},	//   cign, bygo, zoje, ләл_, 
   {{0x69c5252b,0x69c808a5,0x31e80064,0xe0d40139}},	//   yoje, _ígeg, _амап_, лвә_, 
   {{0xe29455c7,0x71e9252c,0x201401d3,0x69c4036e}},	//   _тау_, _شفاف_, údió_, xoje, 
   {{0x9c78054e,0x7e7c03cd,0xd13000f1,0x00000000}},	//   _ţără, øspr, _ومړ_, --, 
   {{0xdef4dfe6,0x69c5252d,0x1dd4009d,0x6e4400c0}},	//   _кыш_, woje, ллөө_, _ведз, 
   {{0x69c44db0,0x7f4c479c,0x5a340126,0xbc6400c7}},	//   toje, _ñaqa, онят, _ҳхық, 
   {{0x63a9252e,0x6e2001b8,0x6c6805f5,0xb2f4031c}},	//   zign, _ivob, _ашиг_, _བུའང_, 
   {{0x6288068f,0xd7f813cf,0x00000000,0x00000000}},	//   zygo, иут_, --, --, 
   {{0x27ed252f,0x69c52530,0xa50c00af,0x5bc4007b}},	//   ögn_, soje, िर्च_, _وقول, 
   {{0x63a92531,0x69c52532,0xe5040228,0x9a841f39}},	// [1bf10] vign, poje, لباي, _дуэл, 
   {{0x5574f7f2,0x05180592,0x63a8a728,0x00000000}},	//   огут, اياب_, wign, --, 
   {{0x26c4012d,0x62892533,0xb0fc010a,0x00000000}},	//   łno_, wygo, _эгiо, --, 
   {{0x42740598,0x6e200115,0x63a92534,0x62880747}},	//   йгес, _ovob, uign, tygo, 
   {{0x63a92535,0x6d480036,0x41282db7,0xc10400ec}},	//   rign, _obfa, голо_, موشي, 
   {{0x62892536,0x6f000142,0x1724031c,0x06ac00cc}},	//   rygo, _afoc, _འཇོམ_, _কঁপি, 
   {{0x04940491,0x63a87d90,0x6e208510,0xe9dc04d4}},	//   _الأح, pign, _avob, ctúe_, 
   {{0x6d4803fa,0x44212537,0x6714547d,0x6f6000a7}},	//   _abfa, msh_, तरिक_, звъз, 
   {{0x7ddc06af,0x44204fba,0x21080073,0x63b92538}},	//   hèse, lsh_, _स्थळ_, _ijun, 
   {{0x6e206b48,0x44212539,0x63b8009b,0xd5740116}},	//   _dvob, osh_, _hjun, лaйл, 
   {{0x4421253a,0xc0d40228,0x6f0003cb,0x6e200055}},	//   nsh_, _اياب, _ffoc, _evob, 
   {{0x4421253b,0x63b80337,0x6d480857,0x17240327}},	//   ish_, _jjun, _ebfa, _འཇེམ_, 
   {{0x63b80117,0xef74004b,0x63a001ed,0x98ac0790}},	//   _mjun, _دخلک, énny, _ılık_, 
   {{0x6d480998,0x63b9253c,0x4421253d,0x7f7001ec}},	//   _gbfa, _ljun, ksh_, _ﺘﻅل_, 
   {{0x4420044e,0xa9a1253e,0x6e20004c,0xa3c400bc}},	//   jsh_, чирд, _zvob, ईका_, 
   {{0xb6a4376d,0x63b9253f,0xe7352540,0x68402503}},	//   библ, _njun, йес_, янса, 
   {{0x4420b21c,0x75d4fb25,0x7c200076,0x66e0014b}},	// [1bf20] esh_, ميرا, lslr, зота, 
   {{0x63b92541,0x7c8c044e,0x44200023,0xdce00055}},	//   _ajun, _ዝመስል_, fsh_, _nonī, 
   {{0x4420009a,0x63b80fac,0x7ddc0129,0xab58000d}},	//   gsh_, _bjun, cèse, foüh, 
   {{0x55540a81,0x33181e7c,0x240401d5,0x00000000}},	//   _ژھار, ازاد_, ёнчи_, --, 
   {{0x23240aa8,0x63b92542,0x2700004d,0x7e6c01a6}},	//   сочи_, _djun, _ổng_, _šapn, 
   {{0x6f00c5bf,0xf59400c6,0x442000f2,0x63b802d0}},	//   _sfoc, _السج, bsh_, _ejun, 
   {{0x6e20140b,0x74152543,0x6f000810,0x63b8007c}},	//   _svob, _دوزا, _pfoc, _fjun, 
   {{0x63b92544,0x33b400c6,0x11680066,0x00000000}},	//   _gjun, _امرأ, الژی_, --, 
   {{0x63a00a40,0x349400ee,0x43740120,0xb22400db}},	//   ënne, _таңр, _ќуст, _ымал, 
   {{0x6fe8012d,0xceb80166,0x00000000,0x00000000}},	//   _jęcz, ләһ_, --, --, 
   {{0x63b800e4,0x6fe8033f,0xdd94005b,0x00000000}},	//   _yjun, _męcz, ёшь_, --, 
   {{0x7ddc0100,0xbf6400db,0xa074010f,0x98b800c0}},	//   vèse, _ودنو, _לעבנ_, lerė_, 
   {{0x2aa8026a,0xdce000b8,0x00000000,0x00000000}},	//   утно_, _yonī, --, --, 
   {{0x44212545,0x17240003,0x98b80024,0x6d4802d0}},	//   ysh_, _འཇུམ_, nerė_, _ubfa, 
   {{0x442001b9,0x00000000,0x00000000,0x00000000}},	//   xsh_, --, --, --, 
   {{0x06146be6,0xd7f92546,0x44209323,0x00000000}},	//   ждаю, сур_, vsh_, --, 
   {{0x63b800cd,0xf1b8043e,0xac1401ec,0x44200042}},	// [1bf30] _rjun, ेवान, _тоқу_, wsh_, 
   {{0x63b8049f,0x08540138,0x00000000,0x00000000}},	//   _sjun, _двою, --, --, 
   {{0x44212547,0xd6d8004b,0xe4680312,0xdce000ef}},	//   ush_, لوېش_, ышал_, _ronī, 
   {{0x44212548,0x05d839a7,0xf8a00014,0x00000000}},	//   rsh_, _बीरब, _کۅہَ, --, 
   {{0x44212549,0xbebc0064,0x00000000,0x00000000}},	//   ssh_, maūg, --, --, 
   {{0x2900068f,0x44205113,0x00000000,0x00000000}},	//   ncja_, psh_, --, --, 
   {{0xd1b87d7f,0x4420d359,0x63b800f3,0x439401c0}},	//   حانا_, qsh_, _tjun, _давс, 
   {{0x63b841be,0x00000000,0x00000000,0x00000000}},	//   _ujun, --, --, --, 
   {{0x2900068f,0xaec002e8,0xcf24009a,0x00000000}},	//   kcja_, мбъл, سريي, --, 
   {{0x225c3386,0x5185254a,0x75380b8b,0xdb0803e0}},	//   _isuk_, _нуха, _ötzt, şmüy, 
   {{0x06ac015b,0xada0c23e,0x61f9254b,0x83b400df}},	//   _কুমি, фаэл, _huul, ַפֿע_, 
   {{0xee2c0034,0x61f82053,0x00000000,0x00000000}},	//   _снo_, _kuul, --, --, 
   {{0x61f9254c,0x9e6400f7,0x9f4c0100,0x00000000}},	//   _juul, _داان, _rigè_, --, 
   {{0x225c3223,0x7e6802ce,0x00000000,0x00000000}},	//   _msuk_, mvep, --, --, 
   {{0x61f9254d,0xbc180046,0x6fe80034,0x7e6800c5}},	//   _luul, _тілі_, _ręcz, lvep, 
   {{0x225c009a,0x6d5c0268,0xbc6805d9,0x2900033f}},	//   _osuk_, _ópar, _ممڪن_, acja_, 
   {{0x61f80869,0xcec00198,0x9f4c0100,0xe6403f3a}},	// [1bf40] _nuul, ƙƙen_, _vigè_, метп, 
   {{0xd9103bbf,0x7e680099,0xe575254e,0xe615254f}},	//   _سیر_, ivep, озу_, юду_, 
   {{0x225cfb61,0x61f83bf3,0x14c80214,0xf1a81176}},	//   _asuk_, _auul, حهای_, یاته_, 
   {{0x61f92550,0x9f4c06af,0xb37400d1,0x7e6800c0}},	//   _buul, _figé_, غداش, kvep, 
   {{0xed8c02d3,0x6fe8012d,0x61f80051,0x00000000}},	//   _ዝገብር_, _tęcz, _cuul, --, 
   {{0x61f83388,0x02180006,0x00000000,0x00000000}},	//   _duul, сіць_, --, --, 
   {{0x7f480af5,0x225c591c,0xe9dc09c2,0x61f8003a}},	//   ffeq, _esuk_, ntúa_, _euul, 
   {{0x61f822a9,0x644000cf,0x42080352,0x00000000}},	//   _fuul, ànie, шмәү_, --, 
   {{0x61f80a81,0xe294e53e,0x29000034,0x3ce801e4}},	//   _guul, _дат_, ycja_, _ĝava_, 
   {{0x7f480194,0xdce400b0,0xae0000d1,0x4d9800d4}},	//   afeq, _ōmāp, كۈچى, скою_, 
   {{0xe4f800c8,0x7e680421,0x61f92551,0xa4f80a1e}},	//   יפיש, avep, _zuul, יליט, 
   {{0x61f8011f,0x7e68004c,0x7c640131,0x35bc0037}},	//   _yuul, bvep, ساپل, ौकड़, 
   {{0x61f8022f,0x6eb41867,0x00000000,0x00000000}},	//   _xuul, _بصائ, --, --, 
   {{0xa8502cc8,0x3ea800a2,0x56580023,0xf1c81fe7}},	//   мегә, _ýata_, _ምርካብ, ाकिन, 
   {{0x4c940323,0xb0c80034,0x2900033f,0xbebc0153}},	//   _хийс, िथिग, rcja_, taūg, 
   {{0x9f4c0129,0xc6f80a8d,0x7ddc033b,0xc7d80064}},	//   _pigé_, снах_, mèsa, ёмах_, 
   {{0x2900033f,0xf1c80b9a,0x298400c0,0x00000000}},	// [1bf50] pcja_, ाकान, _дынг, --, 
   {{0xe468034b,0x2d9c01fb,0x61f8000d,0x00000000}},	//   ишел_, nhte_, _ruul, --, 
   {{0x43740fcb,0xe9dc097a,0x97c40075,0x7e68006f}},	//   зулт, ctúa_, ستېم, zvep, 
   {{0xdb2408fb,0x7e68353e,0xdd2c01ef,0x9a6805af}},	//   ørøv, yvep, _měši, _امیل_, 
   {{0x61f92552,0x81d43da1,0x48f4012c,0x99840133}},	//   _quul, подх, ्डको_, _رلێو, 
   {{0x1a9c010f,0x00000000,0x00000000,0x00000000}},	//   סיגע, --, --, --, 
   {{0x2d9d2553,0xa4912554,0xa2d402e5,0x2b981bce}},	//   dhte_, _تیات, _बरक्, _xëcc_, 
   {{0xf7e400d1,0xc0e40240,0x00000000,0x00000000}},	//   _ﺋﺎﻟﻪ, _ምኩር_, --, --, 
   {{0x7f480eda,0x225c81f1,0x13a803e6,0x60040790}},	//   rfeq, _usuk_, _بۆنی_, _sımd, 
   {{0x2d9c327f,0x7e692555,0xf2d0025d,0x00000000}},	//   ghte_, rvep, _טען_, --, 
   {{0x2b480354,0xfbd12556,0x5f44010b,0x7e692557}},	//   ffcc_, فتح_, _дүйн_, svep, 
   {{0x75e00109,0x2b980de2,0xab580112,0x6e2800e4}},	//   môze, _rëcc_, hnüf, ëmbá, 
   {{0xdce000df,0x2d9c37a8,0x67380113,0x00000000}},	//   _manĉ, bhte_, _ñujy, --, 
   {{0x2d9d2558,0xdce0008f,0x88ac00cc,0x00000000}},	//   chte_, _lanĉ, _গড়ক, --, 
   {{0x2c0000dc,0xcce40137,0xb7940114,0x00000000}},	//   _रूपं_, _ۉسۉي, праћ, --, 
   {{0x3a252559,0xba240640,0x2be005d7,0xdb2401d3}},	//   _емиг, _едик, _टीपू_, _کوکی, 
   {{0x7e6c0010,0xb6a40262,0x00000000,0x00000000}},	// [1bf60] _šapj, чиал, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdce00115,0xc61c015b,0x4904075e,0xd7640101}},	//   _banĉ, ধূলা_, _توپق, _قندی, 
   {{0x98b80100,0x23240798,0xb6000419,0x00000000}},	//   ngrč_, зоци_, áásn, --, 
   {{0xc5140131,0xc68c004b,0x63a00549,0x525821ef}},	//   سبەت, _پېل_, ënna, تساڭ_, 
   {{0xe28001c0,0x6440eacd,0x530c0412,0x05540395}},	//   элчи, ànic, _ड्रॉ_, _отся, 
   {{0x998000a2,0x2934010f,0x00000000,0x00000000}},	//   _itiń_, לאסן_, --, --, 
   {{0x7ddc02e2,0xe3b4009d,0x00000000,0x00000000}},	//   vèsa, _ебс_, --, --, 
   {{0x2d9d255a,0x51440046,0x63b8002e,0x23740118}},	//   thte_, _одағ, _ňung, šejí_, 
   {{0x4c95255b,0x77640227,0xfbd404c5,0x7ddc0066}},	//   диос, _lakx, _সংগত, tèsa, 
   {{0xd054013f,0xd6c403d4,0xcb3402e8,0x1b940023}},	//   _ɛbɛd, ্ধিয, менъ, _ዝረኽቦ_, 
   {{0x2d9c067d,0x7cd8009d,0x02a4010a,0x00000000}},	//   shte_, өмөр_, _ирĕм, --, 
   {{0x0920015b,0x2d9c003a,0x00000000,0x00000000}},	//   _বাবু_, phte_, --, --, 
   {{0x3eb801f1,0xac24a3c8,0xdd2c00bc,0x1ec5255c}},	//   úste_, _ефик, _těši, _элчи_, 
   {{0xd7f80228,0x98c40724,0x88d40055,0x600403e0}},	//   зуу_, естл, _mṛgo, _zımb, 
   {{0x6d59255d,0x1cb80302,0x58d5255e,0x00000000}},	//   leta, _למוע, хост, --, 
   {{0xdce00115,0xbb58019b,0x6d5801c6,0x00000000}},	// [1bf70] _ranĉ, _wayト_, oeta, --, 
   {{0x6d59255f,0x00000000,0x00000000,0x00000000}},	//   neta, --, --, --, 
   {{0x6d5801c6,0xdb0400e4,0xab582305,0x00000000}},	//   ieta, _umiã, gnüg, --, 
   {{0x1474007b,0x00000000,0x00000000,0x00000000}},	//   عالج, --, --, --, 
   {{0x6d592560,0xe664c502,0xddd802fb,0x00000000}},	//   keta, _этно, využ, --, 
   {{0x6d94025a,0x2d884b3f,0xc0dc0023,0x00000000}},	//   _bâam, öbel_, _ዕሸል_, --, 
   {{0xe73c00e4,0x950800dd,0x3ce801e4,0xe9dc0548}},	//   _amõi_, _رہنے_, _ĝavo_, ytún_, 
   {{0x75e00109,0x6d592561,0x656401d3,0x00000000}},	//   rôze, eeta, _hajh, --, 
   {{0x6d592562,0x65640200,0x409400ec,0x00000000}},	//   feta, _kajh, _ڪلار, --, 
   {{0x6564014f,0xd6580375,0x1b940023,0xab582791}},	//   _jajh, ליחת_, _ዝረኸቦ_, mlüy, 
   {{0x65640fb7,0xa5b802d2,0x6ee401a9,0xe9dc0162}},	//   _majh, _avók, lаbl, ttún_, 
   {{0xeb952563,0x6d5800b0,0xe9dc002d,0x00000000}},	//   дию_, aeta, utún_, --, 
   {{0xdce00003,0xab580213,0xca740139,0x4a74004e}},	//   _kanċ, nlüy, нуры, нырт, 
   {{0x65652564,0x1d80001f,0xb864065f,0xe9dd2565}},	//   _najh, _ክለቦች_, وازو, stún_, 
   {{0xe9dc00d0,0x00000000,0x00000000,0x00000000}},	//   ptún_, --, --, --, 
   {{0xab592566,0xdce00327,0xdb2401f4,0x00000000}},	//   gnüd, _lanċ, äräv, --, 
   {{0x8b64a957,0x00000000,0x00000000,0x00000000}},	// [1bf80] _سايم, --, --, --, 
   {{0xe9dc01d3,0xc39001e1,0xab5806be,0x00000000}},	//   ntúl_, _àìjé, dlüy, --, 
   {{0xba740722,0x6564014f,0xa9780375,0x19c401ec}},	//   _راکت, _dajh, _ואיכ, _жәңг, 
   {{0x7f4c0bf1,0x644000cf,0xdb08020c,0xab580205}},	//   _ñaqh, ània, èlèk, flüy, 
   {{0x6d592567,0x71a40006,0x00000000,0x00000000}},	//   yeta, мадз, --, --, 
   {{0x6d592568,0xdce00327,0x00000000,0x00000000}},	//   xeta, _canċ, --, --, 
   {{0x6d592569,0x799c02d0,0xe3c800e8,0x00000000}},	//   veta, _mlpw, àññ_, --, 
   {{0x6d59256a,0x799c0857,0xae2801c6,0x6ee4022e}},	//   weta, _llpw, оцож_, bаbl, 
   {{0xb145256b,0x752c05c7,0x6564014f,0x45a000db}},	//   _онал, _kdbz, _yajh, _جەەك, 
   {{0xdce1256c,0x13a804d3,0x6d58009d,0x184c0023}},	//   _ganċ, _بۆچی_, ueta, _ምግንዛ, 
   {{0x6d59256d,0x4c95256e,0xc048004d,0xdfcc030d}},	//   reta, хинс, _mướn_, _аъ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xeda41ee3,0x7d0d256f,0x64d8012c,0x5a44010b}},	//   _ошко, _şase, _भर्श, кэра, 
   {{0xdce00598,0x7e7c713c,0xed34009d,0x00000000}},	//   _elnı, åspe, _цэдэ, --, 
   {{0x98480801,0xd70c0521,0x58d401c0,0x3c0400e2}},	//   мята_, _ọrịr, ворт, _tēva_, 
   {{0x442c1a4c,0x7e6c0960,0xab5803ee,0x38b80124}},	//   _ĉe_, _šapi, ylüy, _ẽrõ_, 
   {{0x656401d4,0xb6c0dd5c,0xab5805d5,0x00000000}},	// [1bf90] _pajh, гөрд, rnüd, --, 
   {{0x29041675,0x995401f1,0xab5800ac,0x89392570}},	//   _üna_, _päť_, vlüy, _эпос_, 
   {{0x65652571,0x777c001f,0xa8a400d8,0x00000000}},	//   _vajh, _ከወዲሁ_, _црпк, --, 
   {{0xd6d000dd,0x387c0158,0x00000000,0x00000000}},	//   اقے_, åtre_, --, --, 
   {{0x656501cb,0x37c001af,0x00000000,0x00000000}},	//   _tajh, _сәрб, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xab5803e0,0x45c000d1,0x03180114,0x00000000}},	//   slüy, ﻣﻮﻟﻼ, _новј_, --, 
   {{0x70511413,0x9f4c0548,0x2bb85096,0xab580112}},	//   انيا, _sigâ_, _उदगा, hnüb, 
   {{0xfe712572,0x98b800c7,0x00000000,0x00000000}},	//   ادب_, rerĩ_, --, --, 
   {{0xf1c404a9,0x9268036b,0xef0d2573,0xdee00672}},	//   _كۈنى_, _ўрта_, _әм_, ноқи, 
   {{0x3f141c22,0xff38001f,0x672c0841,0xbb44bae4}},	//   _здес, _በጀርመ, _odcj, ненк, 
   {{0xfe70230f,0x7ddc0100,0x8f68007b,0x00000000}},	//   _مدت_, pèso, _يملك_, --, 
   {{0x9984012c,0xed4c074d,0xba74297d,0x9b4401d9}},	//   émů_, _йо_, راحت, _یۆدو, 
   {{0xaa8403b2,0xdec80023,0xee2c00ec,0xdce001ef}},	//   _spýð, _ኣመና_, _اٽو_, _hanč, 
   {{0x8d752574,0x7c6402af,0xdce12575,0xcdc401ec}},	//   _جانا, _ساغل, _kanč, _шашқ, 
   {{0x63a00036,0xdce00166,0x00000000,0x00000000}},	//   ënnl, _ulnı, --, --, 
   {{0xdce02151,0xa6c40536,0xa5b801e1,0x04f000eb}},	// [1bfa0] _manč, елта_, _owód, য়রোর_, 
   {{0xc6080c58,0xdce00552,0x9f4c0ffb,0x058402bf}},	//   _লিখা_, _lanč, _ligà_, куєм, 
   {{0x6d94025a,0x98b80024,0x3634004b,0x00000000}},	//   _sâak, merį_, _ګرجس, --, 
   {{0x9f4c19f5,0x03a8004b,0xa1800032,0xa8002737}},	//   _nigà_, ودنو_, ғышл, ğıtt, 
   {{0x398406d9,0xe2940640,0xa8000205,0x00000000}},	//   _sôsy_, нац_, şıtt, --, 
   {{0x98b80153,0x6004008e,0x6618010e,0xd5880345}},	//   nerį_, _sıma, _çuka, _تێئه_, 
   {{0xb8800316,0xdce0151c,0xd0100c8b,0x7bd41418}},	//   _říjn, _banč, جلب_, _okyu, 
   {{0xf1a8168d,0x50480023,0x7bd40337,0x64480311}},	//   _کاره_, _ዘይከኣ, _nkyu, ăgit, 
   {{0x9f4c031c,0x74e00f22,0x27e404e6,0xd1652576}},	//   _digà_, _বলিউ, _ënne_, _инақ, 
   {{0x7bd40a49,0x6ee4022e,0x61c88153,0x00000000}},	//   _akyu, lаbk, िवृष, --, 
   {{0x600403e0,0x98b800c0,0x00000000,0x00000000}},	//   _tıma, derį_, --, --, 
   {{0xfbcc0451,0xfe000022,0x00000000,0x00000000}},	//   يڪي_, ыҟәм, --, --, 
   {{0xdfccf1b4,0xda780209,0x32040784,0xe9dce6e3}},	//   _اين_, няр_, nqoy_, stúm_, 
   {{0x7bd40a49,0x6d4401a6,0x74300023,0x98b80064}},	//   _ekyu, đkas, _ኣውጺእ, gerį_, 
   {{0xbc640124,0x26dc0024,0xab58002f,0x9d40119e}},	//   _ахық, _šuo_, rnüb, _сејд, 
   {{0xca484876,0x2d8d2577,0x78b81427,0x9cd8123b}},	//   _قلعه_, _hofe_, útva, _מקופ, 
   {{0x2d8d2578,0xfc440122,0x163412e7,0xe3bc013d}},	// [1bfb0] _kofe_, žíte_, летя, _ıñ_, 
   {{0xbebc02b1,0x95d835c7,0x95c801f4,0x00000000}},	//   kaūn, едут_, нуха_, --, 
   {{0xdce00003,0x9f4c00d8,0x2d8c0fac,0xa8006656}},	//   _konġ, _ligá_, _mofe_, ğıst, 
   {{0xd83802fd,0x2d8d2579,0x543407d6,0xe68400d1}},	//   áče_, _lofe_, ارلر, _كۆزى_, 
   {{0x569400d1,0x90340022,0x00000000,0x00000000}},	//   _баят, ҳхыч, --, --, 
   {{0xd8380f72,0xa5b800c7,0x9f4c026c,0xdce1257a}},	//   šče_, _avóv, _sigà_, _sanč, 
   {{0xa491257b,0xdce1257c,0x54680107,0x912800db}},	//   _حیات, _panč, _паём_, رسوق_, 
   {{0x7ddc007f,0x13ec07f7,0x00000000,0x00000000}},	//   rèsm, जगृह_, --, --, 
   {{0x2d8d257d,0x93380020,0x06500020,0xfde800f7}},	//   _bofe_, _አምባሳ, _ኃላፊዎ, мдик_, 
   {{0x2d8c0472,0x52741ec7,0x00000000,0x00000000}},	//   _cofe_, _حافز, --, --, 
   {{0xed4c2832,0x2d8c00e8,0xdce1257e,0x21240208}},	//   تھن_, _dofe_, _bonġ, manh_, 
   {{0x7e6c05a1,0x2124004d,0x7b940212,0x7f940166}},	//   _šapu, lanh_, трої, _шаех, 
   {{0x2d8c01af,0x200401b9,0x98b80024,0x98b00841}},	//   _fofe_, lqni_, terį_, _čađe_, 
   {{0x2125257f,0x49c40184,0x2004022f,0x00000000}},	//   nanh_, лһын_, oqni_, --, 
   {{0x5ed0015b,0x21240051,0xd1f80092,0xfbc4014b}},	//   দেশে, ianh_, _ሊገባ_, _ибко, 
   {{0x2124001e,0x2d8c0010,0x00000000,0x00000000}},	//   hanh_, _zofe_, --, --, 
   {{0x66012580,0x75449bf4,0x2004022e,0x00000000}},	// [1bfc0] ипта, кназ, hqni_, --, 
   {{0xa8001432,0x49012581,0x2124010b,0xfd900023}},	//   ğırt, _гүрг, janh_, _ዝወሃቦ_, 
   {{0x21243ba0,0xa80005d1,0x2998011a,0x00000000}},	//   danh_, şırt, _חסימ, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x21240369,0x2bb806b1,0xe61401f4,0x00000000}},	//   fanh_, _उदघा, _идя_, --, 
   {{0x7f941a36,0x74152582,0xe1ecf04e,0xe1307cee}},	//   _máqu, _لوسا, يسو_, аншы, 
   {{0x9f4c102c,0x33f52583,0x2d8d2584,0x32040784}},	//   _sigá_, _ачас, _rofe_, sqoy_, 
   {{0x2d8d2585,0xb96001e1,0x00000000,0x00000000}},	//   _sofe_, _àìfo, --, --, 
   {{0x21240369,0x02c401c0,0x26c40356,0x00000000}},	//   banh_, _битү, şnov_, --, 
   {{0x716401ec,0x2124004d,0x2ee000dc,0x7e7c5794}},	//   _جارك, canh_, _परीत, åspa, 
   {{0xf1c40131,0x7e6c2630,0xef64059f,0x00000000}},	//   _كۈچى_, _šapt, _аъло, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2d8c0607,0xa5b886cf,0x7f9400d8,0x6fdc01c7}},	//   _tofe_, _kvót, _cáqu, hëck, 
   {{0xdee00aa5,0xdd9002d5,0xdcf4030f,0x5e54011a}},	//   _точи, _вашы, عریش_, _סיוע_, 
   {{0x59f800a8,0x980438b4,0x7ddc0100,0xaa4000d1}},	//   теря_, иятд, dèsh, _ھۆسى, 
   {{0x97a49960,0x2b9801c7,0x644000db,0x05941a71}},	//   арул, _mëck_, ànim, گارگ, 
   {{0xd7f92586,0xeb1c141f,0x2fc40d12,0x8af8a90c}},	// [1bfd0] тур_, परीत_, _mjog_, _янис_, 
   {{0x0594bb69,0x212401fb,0xdce00055,0x00000000}},	//   دارگ, xanh_, _hanā, --, 
   {{0xdce000da,0xf99002e4,0x21252587,0x9f4406be}},	//   _kanā, _הרי_, vanh_, _çiçi_, 
   {{0xdce00882,0x317c01c4,0x6004013d,0x66180139}},	//   _janā, _antz_, _dıml, _çuko, 
   {{0x21252588,0xdce00a30,0x92640228,0x758001d5}},	//   tanh_, _manā, لدوم, _گیلم, 
   {{0xa5b8068f,0x1a9c08d8,0xd37800fd,0x6fdc04e6}},	//   _dwóc, וידע, ечә_, lëch, 
   {{0xb0500424,0x27e8004d,0x21252589,0xe81401f9}},	//   مپوت, _khcn_, ranh_, धीचा_, 
   {{0x2b9801c7,0x2125258a,0xf06000a7,0x7ddc0100}},	//   _dëck_, sanh_, скъп, mèsi, 
   {{0xcf242002,0x2b9801c7,0xee35258b,0x7ddd258c}},	//   جرىي, _iëch_, гны_, lèsi, 
   {{0x25a001ee,0x2fc4020c,0xee340c98,0x3c64234c}},	//   _jljl_, _ejog_, ынь_, гког, 
   {{0x7ddc034c,0x628c00d8,0xc014005b,0xdce000de}},	//   nèsi, _àcob, _смещ, _banā, 
   {{0x7e75258d,0xdce000b8,0x00000000,0x00000000}},	//   _ماتئ, _canā, --, --, 
   {{0x2b980a40,0x00000000,0x00000000,0x00000000}},	//   _mëch_, --, --, --, 
   {{0xf2d0010f,0xfce401ee,0x00000000,0x00000000}},	//   צעם_, _йоло, --, --, 
   {{0xdce00171,0x23d00b02,0xac94072d,0x00000000}},	//   _fanā, तवाद, _منوا_, --, 
   {{0x7ddc2a4a,0xdce000de,0xab5800e5,0x8cc40354}},	//   dèsi, _ganā, lnün, _тĕсĕ_, 
   {{0xf5e80354,0x6fdc0036,0x66180139,0x00000000}},	// [1bfe0] емал_, wëck, _çukl, --, 
   {{0x987802fb,0xab5801ed,0x7ddc0066,0xa52001f0}},	//   láče_, nnün, fèsi, ймуд, 
   {{0x26c82a1f,0x7ddc004e,0x6fdc01c7,0x828401d5}},	//   _exco_, gèsi, bëch, یجهل, 
   {{0x987802fb,0x2b9801c7,0x6fdc01c7,0xe4d45285}},	//   náče_, _rëck_, rëck, دومت_, 
   {{0x2b9804e6,0xb86400ec,0x64a000fb,0x00000000}},	//   _dëch_, _شاھو, _ғата, --, 
   {{0xb424da67,0x7ddc0066,0x98780306,0x6e6401d5}},	//   _معرو, mèsw, háče_, ҳтож, 
   {{0x987802fb,0x00000000,0x00000000,0x00000000}},	//   káče_, --, --, --, 
   {{0xa0640a16,0x1fa1258e,0x27e80208,0x9f4c00fd}},	//   ѓања_, йрыг, _xhcn_, _nigä_, 
   {{0x28d9258f,0x638001c6,0xad6402da,0x7e6c0153}},	//   _मुनि, _угта, هاده, _šapr, 
   {{0xdce00061,0x317c05be,0x4d980212,0xcc5402e8}},	//   _sanā, _untz_, ткою_, авоъ, 
   {{0xdce000da,0xa30801d3,0xa5b800d7,0x00000000}},	//   _panā, _آرہے_, _kvór, --, 
   {{0x9f4c0139,0x987800d7,0xc0f40092,0xf8d00037}},	//   _cigä_, gáče_, ገኘም_, _दुइय, 
   {{0xdef4f74b,0x27380241,0x63a001f5,0x7ddc033b}},	//   _йыш_, _lànà_, ënni, zèsi, 
   {{0x6fdc0036,0x27e80051,0xab580139,0x00000000}},	//   wëch, _shcn_, cnün, --, 
   {{0x6e200810,0xdce052c1,0x7ddc0ffb,0x58840024}},	//   _hwob, _tanā, xèsi, быта, 
   {{0x7ddc02bd,0x6e212590,0x2d9c0d47,0xd8380030}},	//   vèsi, _kwob, lkte_, áča_, 
   {{0xa9c41f84,0x5b1400ee,0x6fdd2591,0x2d9c0582}},	// [1bff0] _مزدو, _умыт, rëch, okte_, 
   {{0xd8380f72,0x6e2001b2,0x2b980a40,0x7ddc0ba1}},	//   šča_, _mwob, _sëch_, tèsi, 
   {{0x2d9d2592,0x24e401c6,0xd548009a,0x27e80051}},	//   ikte_, уцаг, المو_, _thcn_, 
   {{0x6e212593,0x7ddc00f2,0xeb9c0fac,0x05140154}},	//   _owob, rèsi, nkø_, াণের_, 
   {{0x6d4802d0,0x2d9c1bce,0x1c08023e,0x00000000}},	//   _ocfa, kkte_, _संभल_, --, 
   {{0x6f012594,0x2d9c0196,0x5344035b,0x00000000}},	//   _agoc, jkte_, ахәа, --, 
   {{0x6e212595,0x00000000,0x00000000,0x00000000}},	//   _awob, --, --, --, 
   {{0x2d9c1af3,0x7ff454af,0x6e205b70,0xe3b12596}},	//   ekte_, جستا, _bwob, _طرز_, 
   {{0x443000ef,0x00000000,0x00000000,0x00000000}},	//   _hvz_, --, --, --, 
   {{0x5ec00058,0x44312597,0xbd440592,0xfd940116}},	//   _қилғ, _kvz_, جندي, ршию, 
   {{0xb17800c8,0xab592598,0x5e840220,0xa5b80124}},	//   _שטער, rnün, _әуез, _yvór, 
   {{0x2d9c1af3,0x4430002f,0xace000fb,0x8d8411dc}},	//   akte_, _mvz_, өбөҙ, _ۇشىن, 
   {{0x6e2000a9,0x7f4c00e8,0x4430002f,0xef0c01e2}},	//   _gwob, _ñaqq, _lvz_, _غټو_, 
   {{0x3eac03bd,0x2d9c362e,0x3f8d2599,0xdb040660}},	//   mzet_, ckte_, ljeu_, _klië, 
   {{0xa3c43fec,0xbebc00b0,0x3ead259a,0x978401b9}},	//   ैका_, kaūk, lzet_, میده, 
   {{0x3eac05c7,0x3f8c036e,0xe7340305,0x87b8009d}},	//   ozet_, njeu_, иес_, гуут_, 
  
   {{0x28d8069f,0x3eac5613,0x67280008,0x39e80276}},	// [1c000] _मुठि, nzet_, ðgja, _идио_, 
   {{0x443004cc,0xdb040d27,0x3eac0165,0x741424b2}},	//   _bvz_, _olië, izet_, لوطا, 
   {{0xb465259b,0x7304e662,0x443001f5,0xf8c80490}},	//   ркел, апез, _cvz_, _रशिय, 
   {{0x7bc44699,0x00000000,0x00000000,0x00000000}},	//   nnku, --, --, --, 
   {{0x7bc5259c,0x4431259d,0x2d9c0ac7,0xcec002a8}},	//   inku, _evz_, ykte_, ƙƙin_, 
   {{0x6f000395,0x6e200526,0xdb040036,0x3ead0150}},	//   _sgoc, _rwob, _blië, dzet_, 
   {{0xdb040196,0x6e20772f,0x3eac31d9,0x88d400b8}},	//   _clië, _swob, ezet_, _nṛlo, 
   {{0x6e200d29,0x00000000,0x00000000,0x00000000}},	//   _pwob, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7bc5259e,0x1b200154,0x00000000,0x00000000}},	//   enku, _ভাগে_, --, --, 
   {{0x2d9d259f,0xdb0525a0,0xc578008f,0x3eac0156}},	//   rkte_, _kliè, אָרט, azet_, 
   {{0x6e2125a1,0x2d9c00fe,0xee3925a2,0x5b2400c7}},	//   _twob, skte_, _анд_, жьра, 
   {{0x2d9c083a,0x387800ca,0x7e7800a9,0x6e2000ca}},	//   pkte_, _arpr_, _grwp, _uwob, 
   {{0x7bc525a3,0xa5b801e1,0xeb9c0fac,0x6d4802d0}},	//   anku, _awón, skø_, _ucfa, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x20380092,0xa034011a,0x00000000,0x00000000}},	//   _አክብረ, יאלה_, --, --, 
   {{0xd244168d,0xe66407b5,0xa9c400f7,0xf1d400cd}},	// [1c010] _تۆ_, штво, _ۅزگو, धवान, 
   {{0xdb040ba1,0x443002d5,0x99800205,0x00000000}},	//   _aliè, _pvz_, _itiş_, --, 
   {{0x7ddd0302,0x3ead25a4,0x795401f7,0x00000000}},	//   mèst, zzet_, _اَپا, --, 
   {{0x69c40fb7,0x7ddd25a5,0x00000000,0x00000000}},	//   lnje, lèst, --, --, 
   {{0x69c40bd7,0x00000000,0x00000000,0x00000000}},	//   onje, --, --, --, 
   {{0x443125a6,0x7ddc068c,0x25540118,0x3eac0427}},	//   _tvz_, nèst, _dělí_, vzet_, 
   {{0xdef41e38,0x69c40731,0xd1b925a7,0x3f8c004e}},	//   ዉያን_, inje, جانا_, tjeu_, 
   {{0x69c48847,0x3eacb4b6,0xdb040129,0x3f8c55ef}},	//   hnje, tzet_, _gliè, ujeu_, 
   {{0x3ead25a8,0x69c409a8,0x63a125a9,0x92680063}},	//   uzet_, knje, ënnu, _врха_, 
   {{0x3ead25aa,0x518525ab,0xbc180046,0x69c408ad}},	//   rzet_, _муха, лімі_, jnje, 
   {{0x69c44d3c,0x3eac01ed,0x7ddc26b7,0xa3c800e1}},	//   dnje, szet_, dèst, _लदा_, 
   {{0xdb04003e,0x3eac01f5,0x7bc4058a,0x2d88002f}},	//   _klié, pzet_, unku, öber_, 
   {{0x7ddd25ac,0x00000000,0x00000000,0x00000000}},	//   fèst, --, --, --, 
   {{0x69c48e70,0x7e680bd7,0x7f480194,0x7ddc020c}},	//   gnje, mwep, lgeq, gèst, 
   {{0x7e680b6f,0x17c8016c,0xcce400f7,0x28d800cd}},	//   lwep, иҳои_, _وسىي, _मुदि, 
   {{0x81cc03f4,0x7f4925ad,0x69c525ae,0xd83809a8}},	//   রতি_, ngeq, anje, ščo_, 
   {{0x3878070d,0xf6084fe0,0xfa3400db,0xaa540451}},	// [1c020] _wrpr_, اتره_, _اربد, _هليا_, 
   {{0xc1700943,0x7ddc0ba1,0x923c001f,0x69c416a3}},	//   _na̗_, cèst, _አፍሪቃ, cnje, 
   {{0x7e68a42c,0x225c03f0,0x7ddd25af,0xdb0414a9}},	//   hwep, _apuk_, lèss, _alié, 
   {{0x7e6925b0,0xf78421ec,0x00000000,0x00000000}},	//   kwep, _الحَ, --, --, 
   {{0x52880184,0x234807d6,0xe9dc067c,0xdb240022}},	//   шҡан_, اسمی_, ctús_, _ãrõr, 
   {{0xe9dc00c6,0x6ee4022e,0x2164004e,0x00000000}},	//   ltúr_, kаbr, йичи_, --, 
   {{0x628d25b1,0xdb0400d8,0xeeb401e0,0x73e4074d}},	//   _àcon, _elié, өккә_, _говз, 
   {{0x69c40b3d,0xe9dc3afd,0xfd5400b8,0x8e14aa52}},	//   znje, ntúr_, _idaṅ, одиц, 
   {{0xa5d00432,0xa5b801e1,0x69c525b2,0x00000000}},	//   _aỳyn, _owól, ynje, --, 
   {{0x7f480194,0x7ddc5d7e,0xa354004b,0xe294011c}},	//   ageq, dèss, _پرېږ, _уау_, 
   {{0xb7f80764,0x69c4110c,0xe9dca56b,0xd138012d}},	//   ्दाम_, vnje, ktúr_, _idą_, 
   {{0xa5b80248,0x7e680428,0x7ddc020c,0xddcc04a7}},	//   _awól, bwep, wèst, češl, 
   {{0x69c41591,0x7e68003c,0xbe8406f6,0x7ddcfc7b}},	//   tnje, cwep, _وجهو, gèss, 
   {{0xec6800f3,0x7e7c01bf,0x00000000,0x00000000}},	//   _брик_, æspe, --, --, 
   {{0x58843f48,0x7ddc6f90,0x2198010f,0x00000000}},	//   пыта, rèst, נבלא, --, 
   {{0xab5801b8,0x7ddc56ec,0x5c700395,0x00000000}},	//   inük, bèss, _хлът, --, 
   {{0xe50448e8,0x69c455d5,0xcec00198,0x7ddd25b3}},	// [1c030] مباي, pnje, ƙƙun_, cèss, 
   {{0xe9dc0a2c,0x7d0c008e,0x00000000,0x00000000}},	//   rtús_, _ğask, --, --, 
   {{0xdce005da,0x831811dc,0x7e6801f5,0x225c002f}},	//   _taną, لقار_, zwep, _spuk_, 
   {{0x2b4925b4,0xe9dceccd,0xdb0406af,0x00000000}},	//   ngcc_, ptús_, _plié, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x80146799,0xc4840451,0x6d4c01ab,0x3f740208}},	//   офиц, _وڌاي, òbal, _ều_, 
   {{0x40880022,0x00000000,0x00000000,0x00000000}},	//   шәам_, --, --, --, 
   {{0x6004045f,0xd3a41fbe,0x76400162,0x00000000}},	//   _nűme, _еруп, áoyg, --, 
   {{0xe290263d,0x225c0098,0xee2c0451,0x7e68002d}},	//   _عذر_, _upuk_, نٽي_, uwep, 
   {{0x61e0074d,0x7e680810,0x00000000,0x00000000}},	//   qlnl, rwep, --, --, 
   {{0x63b806d1,0xdce000f3,0x7e68017a,0xa0a46d64}},	//   _kmun, _manć, swep, _ушал, 
   {{0x7ddc0ba1,0xc0e40023,0x00000000,0x00000000}},	//   tèss, ዝክር_, --, --, 
   {{0x63b925b5,0x6bd40014,0x092000cc,0x00000000}},	//   _mmun, توَس_, _বাজু_, --, 
   {{0x6e1400ec,0x7ddc068c,0x28d82e05,0x46dc000d}},	//   _بيوس_, rèss, _मुहि, _मड़ह, 
   {{0x63b925b6,0x9c10013d,0x00000000,0x00000000}},	//   _omun, _эчлә, --, --, 
   {{0xa7a40b3b,0xab6001ec,0x00000000,0x00000000}},	//   окса_, _قۇپى, --, --, 
   {{0xe6148345,0x66e125b7,0x70380023,0xe9dc1427}},	// [1c040] жду_, дота, _ከይትኸ, rtúr_, 
   {{0x63b925b8,0x2a6c025a,0xdb2464ec,0xb82800f7}},	//   _amun, _âgba_, _بوکی, _кооз_, 
   {{0x3c0400e2,0x02a401ec,0xe9dc21dd,0xa3c400cd}},	//   _tēvu_, үрім, ptúr_, ैकं_, 
   {{0x69c81427,0x63b80200,0xacd800df,0x00000000}},	//   _íger, _cmun, בֿדי, --, 
   {{0x63b8013c,0x628cb4a2,0x00000000,0x00000000}},	//   _dmun, _àcol, --, --, 
   {{0x63b91119,0x00000000,0x00000000,0x00000000}},	//   _emun, --, --, --, 
   {{0x600401c0,0xfd5400b8,0x049401d5,0x765401f4}},	//   охыг_, _udaṅ, _ертў, ltyy, 
   {{0x63b84cf1,0xe36125b9,0x9878013a,0x00000000}},	//   _gmun, _окси, _láďa_, --, 
   {{0x5144054a,0x7654023a,0xad24009a,0x00000000}},	//   _ндағ, ntyy, يردو, --, 
   {{0xa11000d1,0x63b8022e,0x6ce401ec,0xc0e401f3}},	//   _يوقت, _zmun, жіме, ምርም_, 
   {{0x63b80cfd,0x88d4002b,0x76540108,0xc2ec0ca8}},	//   _ymun, _gṛho, htyy, _ìírí, 
   {{0x2aa800db,0xdb200241,0x00000000,0x00000000}},	//   атго_, _òwìw, --, --, 
   {{0xdce00024,0xa5b8012d,0x81cc00eb,0x00000000}},	//   _manę, _dwój, রতর_, --, 
   {{0xdb0400e5,0x00000000,0x00000000,0x00000000}},	//   _amió, --, --, --, 
   {{0xdd0cada0,0xf1d000cd,0x00000000,0x00000000}},	//   _užšo, _तदनन, --, --, 
   {{0x9c6000b2,0x6d5925ba,0x061444c9,0xb5a80c50}},	//   _آهيو, lfta, здаю, ەپكە_, 
   {{0x1ab40775,0x63b80327,0x7d0d25bb,0x6d584146}},	// [1c050] _объя, _rmun, _şasi, ofta, 
   {{0x8b3400dd,0x63b925bc,0x6d5925bd,0x7e7c0fac}},	//   _بڑھت, _smun, nfta, åspi, 
   {{0x59d40338,0x00000000,0x00000000,0x00000000}},	//   _تغير, --, --, --, 
   {{0x61d000dc,0xed840023,0x00000000,0x00000000}},	//   दक्ष, ንምበር_, --, --, 
   {{0xdb7c008f,0xe9dc00d7,0x00000000,0x00000000}},	//   ינאכ, prúd_, --, --, 
   {{0x409458f0,0x628d25be,0x6d5801a4,0x96341cb8}},	//   зрит, _àcom, jfta, _інсц, 
   {{0xa2b8012c,0x00000000,0x00000000,0x00000000}},	//   _शेर्, --, --, --, 
   {{0x645401d4,0xbebc02b5,0x7ddc0561,0xe3bc010b}},	//   mtxi, kaūt, vèsq, _öñ_, 
   {{0xe1f01374,0x6d5925bf,0x645525c0,0xe29c032e}},	//   _قسط_, ffta, ltxi, _æð_, 
   {{0x41b4489b,0x66183712,0xe73c0037,0xf650011a}},	//   _عمار, _çuku, _slõl_, עצי_, 
   {{0xada006a6,0x645525c1,0x00000000,0x00000000}},	//   хаэл, ntxi, --, --, 
   {{0x6d5925c2,0x7654023a,0x645401c4,0x0dc80137}},	//   afta, ytyy, itxi, йлөй_, 
   {{0x4a7525c3,0x7c9404fb,0x4ed40116,0x00000000}},	//   мырт, زشگا, _оюшт, --, 
   {{0xdc380118,0x7c6525c4,0x00000000,0x00000000}},	//   _háče, _فاعل, --, --, 
   {{0x4878084c,0xdc3800d7,0x00000000,0x00000000}},	//   остя_, _káče, --, --, 
   {{0x22a00069,0x765525c5,0x00000000,0x00000000}},	//   _kīkā_, ttyy, --, --, 
   {{0x36040efc,0x600403e0,0x387c01e4,0x20480023}},	// [1c060] سواف, _kıms, ŭtr_, _ዘይቅየ, 
   {{0x3c04005f,0xe9dc056a,0x76546af6,0xeacc00c7}},	//   _tēvs_, trúe_, rtyy, tỹva_, 
   {{0x765402f6,0x2998011a,0x37e45acb,0xa99800d9}},	//   styy, _הסימ, _ноог, _הביר, 
   {{0xf99001b9,0xdc380306,0xe4d01291,0x00000000}},	//   _آبک_, _náče, رقند, --, 
   {{0x6d5801e3,0xf2d800ae,0x00000000,0x00000000}},	//   yfta, حظات_, --, --, 
   {{0x75d40150,0xa13003cc,0x00000000,0x00000000}},	//   _ريزا, ىرىش, --, --, 
   {{0xa08473e5,0x00000000,0x00000000,0x00000000}},	//   зсыз_, --, --, --, 
   {{0xc44401d9,0x752c01f5,0xb3540330,0xa854011a}},	//   _زیٖن_, _hebz, _ریتا_, ליצה_, 
   {{0xb62c037e,0xdd1800d0,0x752c00a2,0x6448012d}},	//   _ｓｄ_, _dážd, _kebz, ągie, 
   {{0xaf10063f,0xa1c0063b,0x644000da,0x6d58b3b6}},	//   _aụtụ, _збуд, šnie, ufta, 
   {{0x7ddc07b0,0x21643e38,0x00000000,0x00000000}},	//   rèsp, _хихи_, --, --, 
   {{0x752c1af9,0x1ac803ce,0x70500092,0x00000000}},	//   _lebz, रपंथ, _መሞታቸ, --, 
   {{0xdb04003a,0x5a342235,0x00000000,0x00000000}},	//   _aliâ, ннят, --, --, 
   {{0x2aa8013e,0x6454005a,0xb60400e2,0x752c0790}},	//   атҳо_, ytxi, nošā, _nebz, 
   {{0xaf10063f,0x565802d3,0x77f807f7,0x99800153}},	//   _fụtụ, _ዝርከብ, ्दूक_, _avių_, 
   {{0x387c05ac,0xfcc000c7,0xe51c9f23,0x291c01e4}},	//   ætra_, _шәым, मुनि_, ŝua_, 
   {{0x442c00a2,0x857490ad,0x00000000,0x00000000}},	// [1c070] _ňe_, млах, --, --, 
   {{0x6454038f,0xb604005f,0x00000000,0x00000000}},	//   ttxi, jošā, --, --, 
   {{0xf9900302,0xb60400e2,0x00000000,0x00000000}},	//   _סרט_, došā, --, --, 
   {{0x2ee400e8,0xb6000077,0x6454009d,0x644000db}},	//   _oyof_, ñáro, rtxi, àniq, 
   {{0x89400023,0x49400240,0x00000000,0x00000000}},	//   _ንምድኻ, _ንምትእ, --, --, 
   {{0xc0e525c6,0xbebc00b0,0x752c0790,0xdc380118}},	//   молк, kaūr, _gebz, _sáče, 
   {{0xd4983119,0xa5b800ae,0xdce0013a,0xdc3801ef}},	//   _ерт_, _atóg, _daně, _páče, 
   {{0x660c092e,0x442125c7,0xd8380122,0x60040790}},	//   _kuck, mph_, áči_, _sıms, 
   {{0x66040460,0x660d25c8,0x3eb801c3,0x2c04012d}},	//   _kijk, _juck, àst_, _संजू_, 
   {{0x660c4f7f,0xd838151c,0xa5b8007b,0xb6040171}},	//   _muck, šči_, _dtóg, cošā, 
   {{0x660d25c9,0x660401f5,0x99800327,0x00000000}},	//   _luck, _mijk, _vviż_, --, 
   {{0x66040936,0x22a000b0,0x44200113,0x0d8000fb}},	//   _lijk, _tīkā_, iph_, _ҡһын, 
   {{0xeb9525ca,0x4420014b,0xed4c00f3,0xee2c1171}},	//   фия_, hph_, _ио_, _шн_, 
   {{0x660424d1,0x9f6000fe,0x7e7c072b,0x0d8420c8}},	//   _nijk, åvær_, åspu, _плін, 
   {{0x6adc009e,0x37e48f47,0xb9600241,0x0dd0010a}},	//   নেলো, довг, _àìmo, _сăри_, 
   {{0x752d25cb,0xa820036b,0xdebc01f3,0x9b940133}},	//   _sebz, ککین, _ስሜን_, _سابڵ, 
   {{0x660d25cc,0xe7340124,0x6604923a,0x672c009b}},	// [1c080] _cuck, ьет_, _bijk, _decj, 
   {{0x660d25cd,0xdb0402d1,0x00000000,0x00000000}},	//   _duck, _umiñ, --, --, 
   {{0x660525ce,0xdce0013a,0xa5b80210,0x00000000}},	//   _dijk, _raně, _lwów, --, 
   {{0x660c07d5,0x660475c4,0x9f4c0139,0x23240f5c}},	//   _fuck, _eijk, _cigü_, доци_, 
   {{0x660c1a80,0xb60400e2,0xe2940063,0xd01001b9}},	//   _guck, tošā, мац_, گلب_, 
   {{0x644039b3,0x88c4036b,0x44200099,0xdb0400a3}},	//   ánic, _آتیل, bph_, _mlià, 
   {{0x660d25cf,0xd010036b,0x4420037e,0x2ea400cd}},	//   _zuck, دلب_, cph_, गन्त, 
   {{0x66040196,0xab580e78,0x00000000,0x00000000}},	//   _zijk, nnüt, --, --, 
   {{0xaf100521,0x504802d3,0x32c0022e,0x00000000}},	//   _bụrụ, _ዘይምኽ, _qаyd_, --, 
   {{0xf1a925d0,0xc6c800eb,0x00000000,0x00000000}},	//   _باره_, _শরৎচ, --, --, 
   {{0xdb0525d1,0x7d0c0166,0xef18003b,0x00000000}},	//   _alià, _ğast, _дме_, --, 
   {{0x3324de7c,0xa0a083f5,0x00000000,0x00000000}},	//   nbox_, _шахд, --, --, 
   {{0x672c00f3,0x4bb401c0,0xd958001f,0x998000d7}},	//   _recj, _үйлс, _ሌሎችን, _swiš_, 
   {{0x3324051f,0x660d25d2,0x0cd448ab,0xac9802dd}},	//   hbox_, _ruck, _полю, _ونشا_, 
   {{0x66040cf9,0x33240334,0x660c9536,0x701c0022}},	//   _rijk, kbox_, _suck, _ỹijó, 
   {{0x660d25d3,0xd7f80228,0x6604000f,0xdb0400a3}},	//   _puck, дуу_, _sijk, _flià, 
   {{0xdce000c8,0x332525d4,0xdb0404cc,0x672c0219}},	// [1c090] _manĝ, dbox_, _glià, _vecj, 
   {{0x660d25d5,0x3324af3e,0xa65c02d3,0x95c89384}},	//   _vuck, ebox_, _ህይወተ, муха_, 
   {{0x66044bc9,0x332406af,0x00000000,0x00000000}},	//   _vijk, fbox_, --, --, 
   {{0x442125d6,0x66040cf9,0xbebc00b0,0x73c00124}},	//   rph_, _wijk, kaūp, гәуе, 
   {{0x66040286,0xdcec05be,0x99d404d3,0x0164db20}},	//   _tijk, _čeča, _ستیا, екло, 
   {{0x5bac00dc,0x4420037e,0x00000000,0x00000000}},	//   _चत्व, pph_, --, --, 
   {{0x6004002d,0xa49003e6,0x00000000,0x00000000}},	//   _dűmn, _جیات, --, --, 
   {{0x33247baa,0x2480036e,0x00000000,0x00000000}},	//   cbox_, _irjm_, --, --, 
   {{0xdce0008f,0xaf1002e3,0x533402dd,0x20dc0037}},	//   _danĝ, _pụrụ, _шетт, _पुरध, 
   {{0xa0a45e3e,0xa5b801d3,0x46dc000d,0x00000000}},	//   _ошел, _utód, _मडै़, --, 
   {{0xfbc422e9,0x7d0c2b24,0x00000000,0x00000000}},	//   ебно, _şass, --, --, 
   {{0xcfa405c2,0xdb04d02b,0xcc2401ed,0xefcc001f}},	//   _ишчи, _aliá, کریٹ, ብቀው_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3f9c02c4,0xe9dc0008,0xed540212,0x600403e0}},	//   _howu_, trúa_, _зош_, _zımp, 
   {{0x3f9c0472,0x00000000,0x00000000,0x00000000}},	//   _kowu_, --, --, --, 
   {{0x33246445,0xc3240f22,0xe9dc25e6,0xeabc04cc}},	//   xbox_, মৃতি_, rrúa_, mbùn_, 
   {{0x7bc4ef0d,0xab5805d5,0xa3b002a0,0xe6411aaf}},	// [1c0a0] miku, rnüt, टसन_, летп, 
   {{0x7bc525d7,0x3f9c0c11,0xe57400d1,0xa5b801e1}},	//   liku, _lowu_, нзу_, _atób, 
   {{0x19c52282,0x7bc401f7,0x04fc002b,0x5efc00cd}},	//   _зәңг, oiku, _kāṃs, शेत्_, 
   {{0x799c80ab,0xd83802f0,0x00000000,0x00000000}},	//   _hopw, áču_, --, --, 
   {{0xc32c0075,0xdce00724,0x799c017a,0x7e7c00b5}},	//   زەل_, _monı, _kopw, æspl, 
   {{0x7bc525d8,0xd8380fb7,0xc6100075,0x799c0455}},	//   hiku, šču_, _ئېلخ, _jopw, 
   {{0x7bc41bb7,0xfa2403d4,0xdce000df,0x799c0477}},	//   kiku, _বিফল_, _panĝ, _mopw, 
   {{0x7bc40451,0x9f4c026c,0x799c0477,0xe28029db}},	//   jiku, _sigò_, _lopw, _әлфи, 
   {{0x7bc525d9,0x600427ac,0x00000000,0x00000000}},	//   diku, _vımp, --, --, 
   {{0xdeec01e0,0xaca400e5,0x00000000,0x00000000}},	//   _ҡы_, ٹھتے_, --, --, 
   {{0x7bc525da,0x3f9c002e,0xc4080050,0xdce001e4}},	//   fiku, _fowu_, _رتہٕ_, _tanĝ, 
   {{0x9510025c,0xe9dc01a8,0x3f9c010e,0x00000000}},	//   _ཏུའི_, grún_, _gowu_, --, 
   {{0x6da42e2d,0xacd00032,0xada40006,0x2b2400e5}},	//   _пида, _әбйә, _падл, وںکی_, 
   {{0xdd8c07d6,0x7bc405e4,0x9f9000c7,0x5e74011a}},	//   _ёш_, aiku, _ашәш, _נתון_, 
   {{0x28d87db3,0x799c0455,0x58d525db,0xdce00139}},	//   _मुखि, _dopw, горт, _fonı, 
   {{0x17f800c6,0xf0500023,0x86f001ec,0x00000000}},	//   فرقة_, _ዘይሰም, _ﻅل_, --, 
   {{0xe6100597,0x00000000,0x00000000,0x00000000}},	// [1c0b0] اشر_, --, --, --, 
   {{0x48140108,0x00000000,0x00000000,0x00000000}},	//   _имос, --, --, --, 
   {{0x69c41225,0xdce00166,0xab580037,0x00000000}},	//   mije, _manğ, hiüm, --, 
   {{0xa5b801e1,0x799c02ce,0x6b9c0003,0x00000000}},	//   _awót, _zopw, _joqg, --, 
   {{0xaf1002e3,0x799c047e,0x69c401f5,0x3f9c0210}},	//   _rụpụ, _yopw, oije, _rowu_, 
   {{0x7bc525dc,0x69c41326,0x3f9c0de2,0xf2a00137}},	//   ziku, nije, _sowu_, ришп, 
   {{0x3f9c00e8,0x758001d5,0xab580254,0xb88001ef}},	//   _powu_, _خیلم, tiül, _řízn, 
   {{0x7bc418f7,0xa5b801ed,0x531400c6,0x6b9c025c}},	//   xiku, _utób, _مذكر, _noqg, 
   {{0x69c525dd,0x7bc525de,0xdce00139,0xab580037}},	//   kije, viku, _banğ, riül, 
   {{0x7e900085,0x3f9c016b,0x69c47f83,0xdce00166}},	//   nɛpɛ, _wowu_, jije, _canğ, 
   {{0x69c41883,0x403525df,0x61e007d6,0xaf10063f}},	//   dije, _реес, monl, _tụpụ, 
   {{0x61e125e0,0x69c4045f,0x799d25e1,0xfaa4014b}},	//   lonl, eije, _sopw, вамо, 
   {{0x799c030d,0x7338008f,0x8ea4129e,0xbbc86ab8}},	//   _popw, וערס, _مصون, ाचौक, 
   {{0x7bc525e2,0x69c408a4,0xdb040137,0x61e125e3}},	//   siku, gije, _lliç, nonl, 
   {{0x7bc525e4,0xdce00139,0xdbd801f4,0x04fc00b8}},	//   piku, _tonı, _pääy, _tāṃs, 
   {{0x61e125e5,0x69c401f5,0x7bc43d07,0x236c036e}},	//   honl, aije, qiku, jegj_, 
   {{0x6440008c,0x61e125e6,0xdce0887f,0x37040228}},	// [1c0c0] ánin, konl, _yanğ, тпаг, 
   {{0x69c404b9,0xa2b40882,0x61e125e7,0xaa34008f}},	//   cije, ्छन्, jonl, _שטיק_, 
   {{0x64404e86,0x6bd525e8,0xc0dc0023,0xa5b801e7}},	//   šnin, _سویس_, _ንጸሊ_, _stóc, 
   {{0x61e0011c,0xddd800ee,0x8458084c,0xdedc0023}},	//   eonl, stuň, эрут_, _ሓጺን_, 
   {{0x61e0208b,0xadf4012c,0x41340092,0x00000000}},	//   fonl, ुगमन_, _ጥንካሬ, --, 
   {{0xe2941f5a,0x9f4c02d2,0x00000000,0x00000000}},	//   таљ_, _sigð_, --, --, 
   {{0x2ec80882,0xab580e78,0x118800d1,0xa504008e}},	//   ाप्त, knüp, _җәлп_, _аера_, 
   {{0xd4f43419,0x7ddc02bd,0xdce00166,0x00000000}},	//   _аяғы, mèsy, _sanğ, --, 
   {{0x61e125e9,0x69c525ea,0x6b9c0327,0x00000000}},	//   bonl, yije, _roqg, --, 
   {{0xa2b803f3,0xe1f4696b,0x6b9c014f,0xdce00166}},	//   _शेट्, _агу_, _soqg, _qanğ, 
   {{0x3e680efb,0x69c4c75b,0xc0440691,0xd9b80011}},	//   _үшін_, vije, _مخنو, ঁচাম, 
   {{0x6b9c014f,0x69c4020c,0x00000000,0x00000000}},	//   _qoqg, wije, --, --, 
   {{0x7af4006d,0x69c409a5,0x00000000,0x00000000}},	//   _czyt, tije, --, --, 
   {{0x6e2081f1,0x00000000,0x00000000,0x00000000}},	//   _itob, --, --, --, 
   {{0x69c404b9,0x2d8c1529,0xdb040139,0xabb00116}},	//   rije, _infe_, _aliä, _вайә, 
   {{0x61e05a67,0x44b402dd,0xe9dc0174,0xcb5400f3}},	//   zonl, ңбас, mrúm_, _свић, 
   {{0x69c42804,0x61e125eb,0xdb040036,0xd61801f7}},	// [1c0d0] pije, yonl, _cliä, نتلا_, 
   {{0xa5b80241,0x61e125ec,0x6e20009f,0xe5041c3e}},	//   _awór, xonl, _mtob, نباي, 
   {{0x61e125ed,0x590c0003,0x00000000,0x00000000}},	//   vonl, _ཁུགས_, --, --, 
   {{0x27fc0570,0x6e2125ee,0x64400153,0x82d925ef}},	//   _òun_, _otob, šnio, ндес_, 
   {{0x6e2125f0,0x00000000,0x00000000,0x00000000}},	//   _ntob, --, --, --, 
   {{0x7ff43340,0xd2440276,0xc56400ec,0x11e400d4}},	//   گستا, рэци, _حُسي, ажім, 
   {{0x6e2125f1,0x61e125f2,0x00000000,0x00000000}},	//   _atob, ronl, --, --, 
   {{0x7ff525f3,0x61e125f4,0x2d8c011c,0x28d800bc}},	//   دستا, sonl, _anfe_, _मुछि, 
   {{0xbea40046,0xdce0009b,0x61e125f5,0x44300334}},	//   уапк, _ranđ, ponl, _hwz_, 
   {{0x61e125f6,0x6e200332,0x20c4013d,0xab580254}},	//   qonl, _dtob, _исег, liüh, 
   {{0x6e200295,0x443001f5,0x7af40210,0x69c802d2}},	//   _etob, _jwz_, _szyt, _ígey, 
   {{0xdb240793,0xa3e0012c,0xfeb816a4,0xab58000d}},	//   _äsüa, नकि_, _плеј_, niüh, 
   {{0x2cb006be,0x00000000,0x00000000,0x00000000}},	//   _əydi_, --, --, --, 
   {{0xab580254,0x00000000,0x00000000,0x00000000}},	//   hiüh, --, --, --, 
   {{0x644125f7,0xf74525f8,0xa3e0084a,0xedd01541}},	//   ánil, лево, नका_, _ديود, 
   {{0x57246518,0x7ddc0100,0x00000000,0x00000000}},	//   рпағ, vèsy, --, --, 
   {{0x7af4033f,0xab580254,0x00000000,0x00000000}},	// [1c0e0] _uzyt, diüh, --, --, 
   {{0xb9540114,0x00000000,0x00000000,0x00000000}},	//   _стић, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x44300007,0x7334ba4f,0x1c0525f9,0x00000000}},	//   _dwz_, ارائ, रगिल_, --, 
   {{0x64a125fa,0x929405f5,0x71a40953,0x443007c5}},	//   _һара, ралц, ладз, _ewz_, 
   {{0x74145226,0x98b862c7,0xe2940798,0x00000000}},	//   _موسا, lerı_, ѓај_, --, 
   {{0xdb100510,0xa5b80034,0x39580142,0xdce000e2}},	//   _şeýl, _twór, _mcps_, _manē, 
   {{0x53b83c74,0xab580037,0xe4c001a9,0x00000000}},	//   _आतिश, riük, _уйси, --, 
   {{0x39580589,0xb0380086,0x8e140120,0xb1100154}},	//   _ocps_, ñòbò, јдоц, _সজীব_, 
   {{0x2c246215,0x00000000,0x00000000,0x00000000}},	//   льмг, --, --, --, 
   {{0xdfcc00b2,0x628c5941,0xef640395,0x98b8013d}},	//   _کين_, _àcor, _бъло, kerı_, 
   {{0x317d25fb,0xdd900022,0xe9dc1427,0x98b80166}},	//   _hatz_, _ҳашы, rrúm_, jerı_, 
   {{0x2fc4089c,0x58840184,0x3958007f,0x6e20029c}},	//   _imog_, ҙыра, _bcps_, _utob, 
   {{0xa5b925fc,0x7000063f,0xdd902347,0x2d980037}},	//   _atón, _ọcha, _гашы, _õpe_, 
   {{0x395802e2,0x317cdedc,0x98480801,0x98b80166}},	//   _dcps_, _matz_, лята_, ferı_, 
   {{0x644125fd,0x44300007,0x317d25fe,0x10440023}},	//   ánim, _rwz_, _latz_, _ከይተመ, 
   {{0x5694f62c,0x44300369,0xd7f805f5,0x387801e4}},	// [1c0f0] батт, _swz_, уур_, _espr_, 
   {{0x64400f03,0xe97001ed,0x2fc401d5,0x00000000}},	//   šnim, _اندھ, _lmog_, --, 
   {{0xab5800c5,0x44300334,0x256401a9,0x00000000}},	//   tiüh, _qwz_, rеl_, --, 
   {{0x05140154,0xaa300092,0xb7d800db,0x00000000}},	//   িরের_, _ጠቅሰዋ, _لوپا_, --, 
   {{0x317c0036,0xab5800c5,0x1ac400cc,0x47d40066}},	//   _batz_, riüh, _এঁৱা, _ميگر, 
   {{0x2fc4089c,0xab581a04,0x00000000,0x00000000}},	//   _amog_, siüh, --, --, 
   {{0x112800d6,0x317c01c7,0x636803a6,0x00000000}},	//   уючи_, _datz_, _праг_, --, 
   {{0xfe4410f3,0x8d28026f,0xe3b125ff,0x00000000}},	//   анио, ңның_, _ارس_, --, 
   {{0x2910009a,0x317c04e6,0x25a00327,0x00000000}},	//   _ogxa_, _fatz_, _kojl_, --, 
   {{0x237d2600,0x2fc40295,0xfce4084c,0x317c009d}},	//   _hauj_, _emog_, иопо, _gatz_, 
   {{0x237c0211,0x05dc0490,0x00000000,0x00000000}},	//   _kauj_, _मदनब, --, --, 
   {{0x317c01c7,0x6ce000f1,0xe9dc0162,0x7e7400cf}},	//   _zatz_, غړون, brúk_, _ناتئ, 
   {{0x237c0211,0xdce0e762,0xef0c68ba,0x38780356}},	//   _mauj_, _panē, _фм_, _sspr_, 
   {{0x237c0070,0x200c000d,0xc9542f89,0x6ea000bc}},	//   _lauj_, _higi_, йтсы, गहरु, 
   {{0x8d752601,0x6440071b,0xac1415ed,0x200d2602}},	//   _دانا, šnij, _коју_, _kigi_, 
   {{0x225c0194,0x81cc0c58,0x200d2603,0x31d000dc}},	//   _oquk_, ৰতি_, _jigi_, _तद्ध, 
   {{0x200d2604,0x25a000f3,0x27300372,0x14c80214}},	// [1c100] _migi_, _bojl_, زىلس, گهای_, 
   {{0xe61c0051,0x00000000,0x00000000,0x00000000}},	//   _trôn_, --, --, --, 
   {{0x237c0399,0x14c8034c,0xddc8005f,0x81cc03d4}},	//   _bauj_, دهای_, _apgū, ৰতা_, 
   {{0x237c0007,0x317c48aa,0xca7802d3,0xb4e402e5}},	//   _cauj_, _satz_, _እዚኦም_, _पडी_, 
   {{0x237c0369,0xd94402d3,0x317c1497,0x25a0025c}},	//   _dauj_, _ንምዕዋ, _patz_, _fojl_, 
   {{0xe1f405f5,0x200ca64b,0xb42400e5,0x00000000}},	//   агч_, _aigi_, _نعرو, --, 
   {{0x200c0156,0x00000000,0x00000000,0x00000000}},	//   _bigi_, --, --, --, 
   {{0x237d2587,0x317c01c8,0x644006af,0xb4b038d2}},	//   _gauj_, _watz_, ânie, टनी_, 
   {{0x623003b7,0xa3e049fc,0x715800c7,0xb2e80014}},	//   _меѓу, नकर_, _арес_, _شعرٕ_, 
   {{0x200c1873,0x237c05b1,0xdb0401e7,0x216400d8}},	//   _eigi_, _zauj_, _fliú, _вифи_, 
   {{0x200c0699,0x9df52605,0xe7f80316,0xdb040332}},	//   _figi_, рнэт_, ्षमा_, _gliú, 
   {{0x200d2606,0x237c0211,0xee840006,0xdb240008}},	//   _gigi_, _xauj_, _выко, örðu, 
   {{0x9e840133,0x37bc00fe,0x00000000,0x00000000}},	//   _پانۆ, ্কাৰ, --, --, 
   {{0x9d140006,0xb4e40073,0x64406711,0x00000000}},	//   _кошт_, _पडू_, ánik, --, 
   {{0xdb0401ab,0xa5b801e7,0x200c0241,0x00000000}},	//   _mliù, _dtól, _yigi_, --, 
   {{0x57b41342,0x64401fe6,0x200c0067,0x2aa800cf}},	//   обст, šnik, _xigi_, _атоо_, 
   {{0x237cab63,0xc6f84a1d,0x00000000,0x00000000}},	// [1c110] _rauj_, унах_, --, --, 
   {{0xeb9c2759,0x237c0369,0x2d9c02d3,0x29100472}},	//   ljø_, _sauj_, njte_, _ugxa_, 
   {{0xb8fc00c6,0x237c0211,0x29040ca8,0x2614012d}},	//   _ৣৣ_, _pauj_, _àna_, _भूरी_, 
   {{0x237c0218,0xa3b800ae,0x00000000,0x00000000}},	//   _qauj_, خاطر_, --, --, 
   {{0x96452607,0x00000000,0x00000000,0x00000000}},	//   _мэрд, --, --, --, 
   {{0x200c022c,0xdb0408c2,0x15a800a7,0x98140ee8}},	//   _sigi_, _cliù, _къси_, _دبیا, 
   {{0x237c01d4,0xe9dc011f,0xeb9c0158,0x86b402dd}},	//   _tauj_, rrúh_, kjø_, _тәңі, 
   {{0xd9a4033f,0xd8d80375,0x4fc41456,0xbbc400bc}},	//   _ऐक्ट, יווט_, يەلە, _लगेक, 
   {{0xfde92608,0xdb0401ab,0x200c03b2,0x7de80116}},	//   лдик_, _fliù, _vigi_, лмиг_, 
   {{0x200c090c,0xdb0401ab,0x2d9c036e,0x92b4072d}},	//   _wigi_, _gliù, gjte_, _بحفا, 
   {{0x200d2609,0x2fd40214,0x6fb00244,0x3cc80902}},	//   _tigi_, شوید_, زمیا, улно_, 
   {{0x5f75260a,0x200c0618,0xa5b805f7,0x3cd401d5}},	//   _خاطر, _uigi_, _stól, _қўлт, 
   {{0xa5b8dbce,0x3a24031c,0x64400427,0xd9cc00cc}},	//   _atóm, _ħops_, šnih, লকসম, 
   {{0x7c9421c3,0x6fdc005f,0x692009ac,0x5ca00220}},	//   _гриц, rīce, змра, _ولشە, 
   {{0x3ead260b,0xb4e41889,0x3ff8010f,0x00000000}},	//   lyet_, _पडे_, ָפּע, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3ead260c,0xdb040036,0x7545260d,0x00000000}},	// [1c120] nyet_, _moië, йназ, --, 
   {{0x3eac0295,0xa5b801d3,0xc4c4004b,0x6a98011a}},	//   iyet_, _utól, ښتنو, _עשינ, 
   {{0xb4b0150d,0x68f803f9,0xdb040162,0xb464a0f5}},	//   टने_, ƙuda, _aliø, скел, 
   {{0xdec40020,0xb9e00092,0x3eac0450,0xe7f8043e}},	//   ችሁን_, _ኩማ_, kyet_, ्षणा_, 
   {{0xdb0401ab,0x00000000,0x00000000,0x00000000}},	//   _pliù, --, --, --, 
   {{0x3eac417f,0x6440315a,0xe9dc2200,0x2228249f}},	//   dyet_, ânic, trúi_, ازنی_, 
   {{0x3dcc00eb,0x00000000,0x00000000,0x00000000}},	//   রকাল, --, --, --, 
   {{0x3eac00e8,0x00000000,0x00000000,0x00000000}},	//   fyet_, --, --, --, 
   {{0xe7f80562,0x3eac01d3,0xf0500023,0x71a430ab}},	//   ्षता_, gyet_, _ዘይምም, _лааз, 
   {{0xc1180150,0x00000000,0x00000000,0x00000000}},	//   _күшi, --, --, --, 
   {{0x6e2001f2,0x7654003e,0xdce00064,0xab58002f}},	//   _dịọk, huyy, _manė, nhüg, 
   {{0x3eac1c04,0x76540784,0x30040304,0xee3800f3}},	//   byet_, kuyy, _узег, _бнд_, 
   {{0xdb04067c,0x9b580801,0xec3001d5,0xa5b800d7}},	//   _joiè, щият_, _کوبگ, _stóm, 
   {{0x5ea00046,0xeb9c143a,0xd9100101,0x00000000}},	//   _ءمول, sjø_, کیپ_, --, 
   {{0x9c6002e9,0x4ac400af,0x98b8007f,0xb4b0000d}},	//   _فهوو, _लइकव, barč_, टनो_, 
   {{0x9424013f,0x58d402bf,0xbebc2672,0x8d75260e}},	//   _ɔtɔe_, чост, rbūv, _داچا, 
   {{0x5695260f,0x07a52610,0xe61c0208,0x6d580009}},	// [1c130] патт, баңн, _trôm_, ogta, 
   {{0x2734001e,0x4b54009f,0x00000000,0x00000000}},	//   ần_, _اَکر, --, --, 
   {{0x78f002dd,0x6d580024,0xdce00153,0x00000000}},	//   _жүру, igta, _danė, --, 
   {{0x769c0882,0x3ead2611,0x00000000,0x00000000}},	//   ṣyan, yyet_, --, --, 
   {{0x2c78002d,0x00000000,0x00000000,0x00000000}},	//   _lūd_, --, --, --, 
   {{0x3ead2612,0xdce00153,0x00000000,0x00000000}},	//   vyet_, _ganė, --, --, 
   {{0x261c145e,0x3eac0165,0xd56401d5,0x00000000}},	//   _hîo_, wyet_, _этяп, --, 
   {{0x6d592613,0x64540564,0x3eac4c5d,0x673c0200}},	//   egta, muxi, tyet_, naqj, 
   {{0x645407a9,0xfba800fe,0x00000000,0x00000000}},	//   luxi, খোঁত, --, --, 
   {{0xfc440232,0x6d58007c,0x65750a64,0xab582ca8}},	//   žíme_, ggta, nexh, hhüd, 
   {{0x3ead2614,0xa5b80248,0x12240248,0xc0d41cc7}},	//   syet_, _atók, _iṣọr, _بياب, 
   {{0x5fa00075,0x7c2c2625,0x6d592615,0x3b0806ed}},	//   _رەخم, _čard, agta, иено_, 
   {{0xbea4403b,0xb4e4000d,0x00000000,0x00000000}},	//   _фалк, _पड्_, --, --, 
   {{0x395c0c86,0x64552616,0x6d580009,0xed540408}},	//   üts_, kuxi, cgta, _дош_, 
   {{0x673c02d3,0xbc380244,0x00000000,0x00000000}},	//   faqj, _ئستا_, --, --, 
   {{0xa6d8008c,0x22a006c8,0x64541730,0x7654022f}},	//   _meðf, _kūkā_, duxi, tuyy, 
   {{0xdca000c2,0x6fdc1a14,0x76552617,0xdee40092}},	// [1c140] _фақи, nīca, uuyy, _ማራኪ_, 
   {{0x64552618,0xdb040077,0xa3b400e5,0xdec40092}},	//   fuxi, _noié, ےاور_, ችሁና_, 
   {{0x161c0210,0x00000000,0x00000000,0x00000000}},	//   _भंवर_, --, --, --, 
   {{0xab592619,0x21f800c7,0x00000000,0x00000000}},	//   chüd, vêha_, --, --, 
   {{0x657401b3,0x765404ba,0x6d580009,0xf20401f4}},	//   bexh, quyy, ygta, ояко, 
   {{0x28cc01ad,0xc32c00cf,0x00000000,0x00000000}},	//   _हेडि, _ەەن_, --, --, 
   {{0x628c056a,0x00000000,0x00000000,0x00000000}},	//   _ácon, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdf0401c0,0xc0b80327,0x00000000,0x00000000}},	//   жээл_, ħġaġ, --, --, 
   {{0x82e40327,0x00000000,0x00000000,0x00000000}},	//   _སྙིའ, --, --, --, 
   {{0x427c1b49,0x6d59261a,0x286402d3,0x644002fb}},	//   _ባርነት_, rgta, _ምፍንጫ, šniv, 
   {{0x1dd40137,0x65740200,0x00000000,0x00000000}},	//   йлөө_, zexh, --, --, 
   {{0x9a85261b,0x64540564,0x5a34084c,0x65740fec}},	//   мурл, zuxi, мнят, yexh, 
   {{0xe81c02ab,0x6574009a,0xafe400cf,0xab5800db}},	//   _मंदा_, xexh, _ايچۉ, tiüs, 
   {{0xab84721f,0x5cc000a7,0xcb6800f1,0x219800df}},	//   _дупк, _осъз, _همغه_, סבלא, 
   {{0x645402b9,0x5bc400c6,0xd79402e8,0x22a00055}},	//   vuxi, _يقول, мисъ, _yūkā_, 
   {{0xa6d8008c,0x9f5c03fa,0x4615261c,0xadfc29c8}},	// [1c150] _meðg, hluß_, سوار, _उठान_, 
   {{0x673c014f,0x78ac00e5,0x00000000,0x00000000}},	//   saqj, ínvá, --, --, 
   {{0x83180137,0x673c0113,0xf93401c0,0x6575261d}},	//   مقار_, paqj, _хүсч_, rexh, 
   {{0x645494b7,0x65740472,0xa28000f1,0xdc980a7c}},	//   ruxi, sexh, ویزو, ייבל, 
   {{0x7a30022e,0x6d4880ec,0x65740200,0xd7640345}},	//   nаtо, _odfa, pexh, _تۆقی, 
   {{0x645402b9,0x9f5c002f,0x00000000,0x00000000}},	//   puxi, fluß_, --, --, 
   {{0xc5f86b9b,0x22a000ef,0x237400ae,0xddd80210}},	//   ्गीय_, _sūkā_, _وارح, ytuł, 
   {{0x6d49261e,0xd8dc06a9,0xdb04010b,0x6f6000a7}},	//   _adfa, יקור, _aliý, евъз, 
   {{0x9a941ee0,0x00000000,0x00000000,0x00000000}},	//   _ሚካኤል_, --, --, --, 
   {{0x63b807a9,0xbf1400aa,0xfd980640,0x00000000}},	//   _hlun, _ځواب, стић_, --, 
   {{0x44200054,0x98b9261f,0x5fa00131,0x62880fac}},	//   nqh_, karā_, _يەتم, lvgo, 
   {{0x63b86085,0x6d480857,0xe9dc002d,0xa5b801e7}},	//   _jlun, _edfa, krús_, _dtói, 
   {{0xed4c40b9,0x63b92620,0x427800c8,0xdce0002b}},	//   _по_, _mlun, זאָג, _kanī, 
   {{0x63b92621,0xea6003cc,0xdce00171,0x68700023}},	//   _llun, رۇپپ, _janī, _ኣካያዲ_, 
   {{0x63b92622,0x7c64021a,0xdce00a30,0xbb3402dd}},	//   _olun, _راغل, _manī, _ﺗﻪﻙ_, 
   {{0x76241d4a,0x00000000,0x00000000,0x00000000}},	//   змаз, --, --, --, 
   {{0xe73409fe,0xe614352b,0x644401b9,0xf5180f87}},	// [1c160] яет_, зду_, _avji, متاش_, 
   {{0xca742421,0xab580112,0xd9980244,0x7864011c}},	//   _کنیک, chüb, _بۆست_, _екоз, 
   {{0xc694044e,0x7af4023a,0x98b800b8,0x00000000}},	//   _ሃዋርያ_, _hyyt, barā_, --, 
   {{0x7af4023a,0xb2842fe5,0x98b8002b,0x00000000}},	//   _kyyt, зыкк, carā_, --, 
   {{0x63b92623,0x628c0077,0xa340004b,0x59e00210}},	//   _dlun, _ácol, رپوه, _नदार, 
   {{0x63b8376b,0x7af402f6,0x55200034,0xc1d43c1a}},	//   _elun, _myyt, _बलिए_, мөхә, 
   {{0xa5b801e1,0x3c20008c,0xe9dc0005,0x63b82b00}},	//   _atów, _nóv_, nsúa_, _flun, 
   {{0x5f40a70b,0x64a001c0,0x00000000,0x00000000}},	//   ىنىل, _яаса, --, --, 
   {{0xa5b92624,0x6d48005a,0xa6d808a5,0x311400f3}},	//   _awóy, _pdfa, _geðd, _ефес, 
   {{0x6ce49d2c,0xdce000de,0x00000000,0x00000000}},	//   зіме, _ganī, --, --, 
   {{0x7af4010e,0xc2f000fe,0xd0e80066,0x00000000}},	//   _ayyt, জেদি_, _بکشم_, --, 
   {{0xdce000ef,0x00000000,0x00000000,0x00000000}},	//   _zanī, --, --, --, 
   {{0xe61c001e,0x98b80318,0x00000000,0x00000000}},	//   _trôi_, varā_, --, --, 
   {{0x6d481c42,0x65b800c7,0x44200175,0x7a30022e}},	//   _udfa, _oîha, yqh_, rаtо, 
   {{0x44200175,0xa6d8032e,0xab58002f,0x5df8011a}},	//   xqh_, _meðe, rhüb, _הפגנ, 
   {{0x9cd8011a,0x00000000,0x00000000,0x00000000}},	//   _לקופ, --, --, --, 
   {{0x98b802b5,0x06140138,0xc0cc0240,0x00000000}},	// [1c170] rarā_, ддаю, _እዚስ_, --, 
   {{0x63b80316,0x98b8005f,0x33240a05,0xe9dc004e}},	//   _slun, sarā_, ecox_, rrús_, 
   {{0xab58002f,0x00000000,0x00000000,0x00000000}},	//   chüc, --, --, --, 
   {{0xdce000b8,0x00000000,0x00000000,0x00000000}},	//   _sanī, --, --, --, 
   {{0x886002d3,0x4cd000fe,0xdce007d7,0x569400fb}},	//   _ውልቀሰ, _সুমু, _panī, _заят, 
   {{0x64412625,0x628c0005,0x40940902,0xa1f02374}},	//   ánis, _ácom, дрит, رۋات, 
   {{0x63b8657a,0x98b80311,0x50640063,0x94a8030d}},	//   _tlun, mară_, етња, _етта_, 
   {{0x63b92626,0x98b8084c,0x54345e07,0xdb0401ab}},	//   _ulun, lară_, _سرفر, _mliò, 
   {{0x98b80356,0xcf2401e2,0xdce10e0c,0x00000000}},	//   oară_, رريي, _tanī, --, 
   {{0x98b80276,0xe73c0022,0x7af401f4,0x00000000}},	//   nară_, _leõ_, _ryyt, --, 
   {{0x7af4049b,0x8cb48c72,0xd1f80092,0x00000000}},	//   _syyt, есяч, ገሪቷ_, --, 
   {{0x7af402f6,0xa6d8032e,0x00000000,0x00000000}},	//   _pyyt, _meðb, --, --, 
   {{0xd064013f,0x88c40118,0x00000000,0x00000000}},	//   ɛsɑk, hněč, --, --, 
   {{0xe61c01f1,0xe81c05f9,0x7e68713c,0x7c6400db}},	//   _osôb_, _मंशा_, mtep, _قاعل, 
   {{0x6440054e,0x98b80356,0x00000000,0x00000000}},	//   ânil, dară_, --, --, 
   {{0x7af402f6,0x00000000,0x00000000,0x00000000}},	//   _tyyt, --, --, --, 
   {{0x98b80356,0x00000000,0x00000000,0x00000000}},	// [1c180] fară_, --, --, --, 
   {{0xb0380086,0xdb0401ab,0x98b8054e,0x7e684132}},	//   ñòkò, _fliò, gară_, itep, 
   {{0xeabc05d5,0xdb0400a2,0x3384059f,0x7e692627}},	//   ncùn_, _iliñ, дулв, htep, 
   {{0xf6242850,0x7e68f7b7,0xe1ec00f1,0x00000000}},	//   _одмо, ktep, یسو_, --, 
   {{0xd1f80201,0x6d4c1686,0xadfc0037,0x00000000}},	//   ገሪቱ_, óbak, _उठलन_, --, 
   {{0x7e68003b,0xa5b803b2,0x98b8054e,0xda00000d}},	//   dtep, _stóv, cară_, ोगित_, 
   {{0x51840c60,0xa6d802d2,0x7e680022,0x00000000}},	//   дуқа, _geðb, etep, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8e145322,0x7c2c1591,0x7e682595,0xda0001f9}},	//   ндиц, _čara, gtep, ोगात_, 
   {{0xc3040fb4,0x35940092,0x00000000,0x00000000}},	//   _سبقو, _መዛባት_, --, --, 
   {{0x61402830,0x7e680c89,0x00000000,0x00000000}},	//   _реха, atep, --, --, 
   {{0xdb046bdf,0x98b8054e,0x765401f4,0x7c6400d1}},	//   _aliñ, zară_, kryy, راپل, 
   {{0xceb80304,0x00000000,0x00000000,0x00000000}},	//   _хәй_, --, --, --, 
   {{0x6f012628,0x00000000,0x00000000,0x00000000}},	//   _izoc, --, --, --, 
   {{0x98b80311,0x2f0001b9,0x6bd4007b,0x00000000}},	//   vară_, dаgi_, _يتعر, --, 
   {{0x64400798,0xdb04010e,0x785c0356,0x00000000}},	//   ânim, _eliñ, _săvî, --, 
   {{0x28cc038e,0x98b8084c,0xe61c003a,0xa51400dc}},	// [1c190] _हेरि, tară_, _quô_, तश्च_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb052629,0x98b80276,0x7e682a87,0x996401af}},	//   _goiâ, rară_, ztep, _ртыл, 
   {{0x7e680124,0xa5b80ca8,0x6f000117,0x98b80276}},	//   ytep, _atót, _ozoc, sară_, 
   {{0x7e680789,0x98b8054e,0xe66401b9,0x9264009f}},	//   xtep, pară_, _ўтмо, ندوم, 
   {{0x7e680158,0xdcec00d0,0x070800ec,0xe61c0419}},	//   vtep, _čeľa, _ويھي_, _drôt_, 
   {{0x6f0007a8,0x8015262a,0x70504fca,0x32c0022e}},	//   _azoc, нфиц, هنوا, _sаyt_, 
   {{0x816c0150,0x00000000,0x00000000,0x00000000}},	//   _ﺴﻤﻌﺔ_, --, --, --, 
   {{0xc17406bb,0x3eb8d787,0x6f01262b,0x42541424}},	//   _плащ, ást_, _czoc, _سنار, 
   {{0xee340064,0x00000000,0x00000000,0x00000000}},	//   энь_, --, --, --, 
   {{0x6f01262c,0x28cc3806,0xdfa400d8,0x00000000}},	//   _ezoc, _हेलि, _ојдо, --, 
   {{0x7e685613,0x76551e05,0x8f3400c0,0x98b80153}},	//   ptep, yryy, _аецц, narą_, 
   {{0xe9dc0332,0x00000000,0x00000000,0x00000000}},	//   rsún_, --, --, --, 
   {{0x393401c0,0x00000000,0x00000000,0x00000000}},	//   ээмс, --, --, --, 
   {{0x98b80006,0x2a7c0327,0x00000000,0x00000000}},	//   karą_, ħuba_, --, --, 
   {{0xc06002d3,0xdb0403b2,0xa7a40305,0xe5a000d1}},	//   _ዘይተፈ, _flið, нкса_, ңити, 
   {{0xc0cc0201,0xaff8008f,0xdb0408ce,0x98b800c0}},	// [1c1a0] _እዚህ_, פּלי, _glið, darą_, 
   {{0xa6800572,0x7655262d,0x00000000,0x00000000}},	//   ылуд, rryy, --, --, 
   {{0xf7440580,0x2db4010f,0xf86400f5,0x00000000}},	//   _пено, עלען_, _явно, --, 
   {{0x98b80153,0x326400d8,0xe4301063,0xb6a4022e}},	//   garą_, еткв, افند, _зимл, 
   {{0x97040075,0x64541eca,0xf12400d4,0x00000000}},	//   _شېئى, arxi, ньйо, --, 
   {{0xc51404a2,0xb9fc001f,0x7c2d262e,0x041000fe}},	//   ربەت, _ቀኝ_, _čarn, াৱলী_, 
   {{0xf8b1262f,0x6f0001ed,0x21640640,0xe21001ec}},	//   ीनिय, _szoc, хији_, ымшы, 
   {{0x7414007b,0xc3140154,0x80c40154,0x6004009d}},	//   _أورا, াড়ি_, _লুঙ্, нхыг_, 
   {{0xe1f400fd,0xddd80118,0xa2e001a9,0x00000000}},	//   ьгә_, ltuř, _ботд, --, 
   {{0xd06002d3,0xe804033f,0x6140023b,0x00000000}},	//   ተሃልዩ_, _वीना_, _бефа, --, 
   {{0xa5b814cf,0xa6d81c38,0xef18084c,0x705400c6}},	//   _któr, _meða, _еме_, _أنصا, 
   {{0x8c4401e0,0x00000000,0x00000000,0x00000000}},	//   неүе, --, --, --, 
   {{0x6f012630,0x00000000,0x00000000,0x00000000}},	//   _uzoc, --, --, --, 
   {{0xa6d8008c,0x3eb800ed,0xab5807c5,0xe7e000c5}},	//   _neða, øste_, chün, _गदहा_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd91401c0,0x1e8001af,0x00000000,0x00000000}},	//   удсы, _рләм, --, --, 
   {{0xacb001ec,0x6e200064,0xa9280064,0x00000000}},	// [1c1b0] _شەڭب, _juob, _ніне_, --, 
   {{0xa5b801e1,0xa2bc08df,0x00000000,0x00000000}},	//   _atór, वनस्, --, --, 
   {{0x6e212631,0xd918005b,0x98b83f05,0x00000000}},	//   _luob, _пью_, tarą_, --, 
   {{0x78b80fac,0xdcec00de,0x00000000,0x00000000}},	//   øtve, _čeļa, --, --, 
   {{0x6e200024,0xa5b80332,0x92952632,0x00000000}},	//   _nuob, _dtór, лацц, --, 
   {{0x98b80006,0xe7f8012c,0x00000000,0x00000000}},	//   sarą_, ्षका_, --, --, 
   {{0x442400a8,0xd14850d8,0x00000000,0x00000000}},	//   _îl_, رشون_, --, --, 
   {{0x6e200c86,0x44312633,0xaab0013a,0x7ec80150}},	//   _buob, _itz_, ुनाक, _ﺨﻁﻭﻁ, 
   {{0x4431220c,0x527404fb,0x447c01ec,0xa064020a}},	//   _htz_, _مالز, _ءﯗﻳﺴ, фақа_, 
   {{0x6e212634,0x44300208,0x00000000,0x00000000}},	//   _duob, _ktz_, --, --, 
   {{0xfce52635,0xab58002f,0xc3cc0241,0xfc0400db}},	//   тоно, rhün, _àìsí, кпоо, 
   {{0x44312636,0xeb952637,0x6cb000f7,0xbb44005b}},	//   _mtz_, вию_, рөшт, ъемк, 
   {{0xf41004ac,0x6e212638,0xe9dc00d0,0x4fd8010f}},	//   יפט_, _guob, psúl_, _אַװד, 
   {{0x4430e9e8,0x3f8c004e,0xab580254,0x00000000}},	//   _otz_, ldeu_, lhül, --, 
   {{0x684000c7,0x3f9c01f5,0xa9a094c9,0x4878084c}},	//   инра, _knwu_, ширд, нстя_, 
   {{0x3f8d2639,0xab580112,0x00000000,0x00000000}},	//   ndeu_, nhül, --, --, 
   {{0x7e780ac5,0xfaa5263a,0x16e80022,0x1ab000cc}},	// [1c1c0] _jpwp, _рапо, хгаҩ_, _চেৰা, 
   {{0xa5b9263b,0xdb05263c,0xe9cc00b2,0x977400d1}},	//   _stór, _goiá, _وٺي_, _өтмә, 
   {{0x3f9c1d36,0x44300798,0x799c02d0,0xd764036b}},	//   _onwu_, _ctz_, _inpw, _ینگی, 
   {{0x7c2cbb62,0x4430007c,0x7bc40051,0x6fdc0055}},	//   _čarl, _dtz_, nhku, cīch, 
   {{0x3f8cc552,0x0ed02274,0x71a5263d,0xc32c03cc}},	//   ddeu_, _तेंड, кадз, سەل_, 
   {{0x3f9c01f2,0xa5b8033f,0x443001bf,0xb0300124}},	//   _anwu_, _wtór, _ftz_, амкә, 
   {{0x64a1263e,0x4431263f,0x6fdc005f,0x604000c7}},	//   _кара, _gtz_, līci, ахыз, 
   {{0x6e2004cc,0xa6d80162,0xa8540375,0xa50401f0}},	//   _puob, _meðn, דיקה_, _реса_, 
   {{0x9c9c0085,0x6fdc005f,0x59b52640,0x798c0175}},	//   ́kɔ́_, nīci, ुसार, kdbw, 
   {{0x3f9d2641,0x3f8c003e,0xe61c0042,0xc3cc01e1}},	//   _enwu_, adeu_, _osôn_, _àìrí, 
   {{0xa0640124,0x3a30010b,0x2d8800d0,0x84800092}},	//   _ааха_, _atyp_, ľbe_, _የቋንቋ_, 
   {{0x799c8cf6,0xbf641b45,0xab580ade,0x76b800cd}},	//   _anpw, _مدهو, chül, _kāyā, 
   {{0xdfcc08f4,0x3878070d,0x799c02d0,0x76b8002b}},	//   _بين_, _appr_, _bnpw, _jāyā, 
   {{0xdd8c03e6,0x6fdc005f,0xda34023a,0x95ec02a0}},	//   _وون_, dīci, реры, जकोट_, 
   {{0xdc842cd0,0x7658002b,0xf7900116,0x00000000}},	//   _асыл_, _ātya, ﻟﻠﯩﻚ_, --, 
   {{0xa5b8172e,0x799c061c,0x7bc40e78,0x1c4004b4}},	//   _atóp, _enpw, chku, _өнәм, 
   {{0x6b9c0b6f,0x387800ca,0x85740408,0xe8042645}},	// [1c1d0] _inqg, _eppr_, ллах, _वीणा_, 
   {{0x939400e5,0x00000000,0x00000000,0x00000000}},	//   یجنا, --, --, --, 
   {{0x69c44606,0xab580790,0xb4b4104e,0x98b800c0}},	//   mhje, diüz, лифә, karę_, 
   {{0x69c45b47,0x443001a6,0xa4f00073,0x823400f2}},	//   lhje, _vtz_, _अडीच_, هرتا, 
   {{0x69c402f6,0x4430009f,0xe6100014,0x7c2c0010}},	//   ohje, _wtz_, _نشس_, _čarm, 
   {{0x69c4383d,0x76b8002b,0x443001a9,0x01647fec}},	//   nhje, _dāyā, _ttz_, укко, 
   {{0x6adc0f4c,0x443001c4,0xab580e78,0xd1b92642}},	//   नपुर, _utz_, thül, خانا_, 
   {{0x14080022,0x0244009f,0xcfa40063,0xd6e400fe}},	//   _ахуп_, _مَرَ, ишњи, _মৰিয, 
   {{0x3f8cd6fa,0xcee800dd,0xab580112,0x798c0042}},	//   rdeu_, ہرین_, rhül, ydbw, 
   {{0xdee0023b,0x3f8d2643,0xf654011a,0xab58002f}},	//   лоқи, sdeu_, נסתי_, shül, 
   {{0x69c4069c,0x6fdc005f,0x7bc40023,0xe81c00ab}},	//   dhje, zīci, thku, _मंगा_, 
   {{0xfaa428e5,0x210c0764,0x6adc09fa,0x5dc02309}},	//   гамо, ाधीश_, नपूर, امگە, 
   {{0xee2d2644,0xab5805d5,0x7f480381,0x61e00afe}},	//   _ын_, chüm, maeq, onnl, 
   {{0x7bc52645,0x69c40c95,0xdb0400d8,0x7f480381}},	//   shku, ghje, _loiç, laeq, 
   {{0xc8b47e3c,0x8d752646,0xb6000077,0x61e001ab}},	//   асты, _خانا, ñámo, innl, 
   {{0x2d980428,0xa5b80393,0x7f4816b8,0x3b080395}},	//   _òper_, _quón, naeq, _пейо_, 
   {{0x7bd4015c,0x69c4009a,0x7f48003a,0xdb0c0112}},	// [1c1e0] _imyu, bhje, iaeq, ßhän, 
   {{0xf990bf17,0x69c4fdf2,0x7f48003a,0x18b40124}},	//   _طبخ_, chje, haeq, _кәбр, 
   {{0x66e00107,0x76b8002b,0x14c80066,0x00000000}},	//   _ғора, _sāyā, خهای_, --, 
   {{0x39492647,0x61e0030a,0xa6d802d2,0x76b800b8}},	//   labs_, ennl, _geðo, _pāyā, 
   {{0xe29524f4,0x7f480381,0x555400ec,0x00000000}},	//   лац_, daeq, _نھار, --, 
   {{0x508400aa,0xa6d80008,0x7f48003a,0x76b80055}},	//   لابې, _meðl, eaeq, _vāyā, 
   {{0x65c105fc,0xa504a283,0x98b838a5,0x73e40354}},	//   _убра, _бера_, tarę_, _бовз, 
   {{0xeea92648,0x7f480393,0x39480076,0x61e04230}},	//   еток_, gaeq, habs_, annl, 
   {{0xda040490,0x39484eed,0x9ed402e8,0x69c401f4}},	//   ळतात_, kabs_, лмът_, yhje, 
   {{0xc0d40020,0x7bd41418,0x2c4c000f,0xe1f40a93}},	//   _ይላሉ_, _amyu, tęd_, _бгу_, 
   {{0x7f480393,0x69c4383d,0x41d80401,0x8c8800c7}},	//   baeq, vhje, _भगतस, тәла_, 
   {{0x7f480381,0x321c2f53,0x2ba400d8,0x00000000}},	//   caeq, _hity_, ујов, --, 
   {{0xda792649,0x69c40240,0x321c02f0,0x00000000}},	//   ляр_, thje, _kity_, --, 
   {{0x7bd404ba,0x2c4c012d,0x39480162,0x00000000}},	//   _emyu, pęd_, gabs_, --, 
   {{0x69c4ad6a,0xddd801e4,0xdca00063,0x321c012d}},	//   rhje, ntuŝ, _гаји, _mity_, 
   {{0x69c4044e,0xdc980302,0x2bb80597,0x321d1889}},	//   shje, _טיול, _ساعة_, _lity_, 
   {{0x2d8d264a,0x321c0124,0xa6d801a8,0xab5815b7}},	// [1c1f0] _kafe_, _oity_, _geðl, rküd, 
   {{0x2d8c1574,0x39480099,0x95c80a89,0x321c9e11}},	//   _jafe_, cabs_, луха_, _nity_, 
   {{0x2d8c03f9,0x69d4025c,0xfc1c00a2,0x00000000}},	//   _mafe_, _imxe, _üçüň_, --, 
   {{0x321d264b,0x2d8c01c7,0x2b49264c,0x98c412b9}},	//   _aity_, _lafe_, nacc_, _ысыл, 
   {{0xa3b002dd,0x7f480393,0x321c33c8,0xa49000e5}},	//   _құді, vaeq, _bity_, _گیات, 
   {{0xc0d40201,0x321d264d,0x2d8c239f,0xdce0031c}},	//   _ይላል_, _city_, _nafe_, _lanġ, 
   {{0x7f4816b8,0x31d001d5,0xa6d801a8,0xddd8025c}},	//   taeq, تقوز, _meðm, rvuż, 
   {{0x2d8c2486,0x00000000,0x00000000,0x00000000}},	//   _aafe_, --, --, --, 
   {{0x2d8d264e,0x200000da,0x2b4806af,0x7f4816b8}},	//   _bafe_, ēji_, dacc_, raeq, 
   {{0x2d8d264f,0x7f480393,0xef1401ee,0x02600133}},	//   _cafe_, saeq, шмы_, _هێڵێ, 
   {{0x2d8c5077,0xa6d809f3,0x7f48003a,0x9a5405a2}},	//   _dafe_, _seðl, paeq, әхмә, 
   {{0x2d8c0270,0xfaa402a9,0x00000000,0x00000000}},	//   _eafe_, қаҳо, --, --, 
   {{0x2d8d2650,0x00000000,0x00000000,0x00000000}},	//   _fafe_, --, --, --, 
   {{0x2d8c625a,0xdbb80116,0xa6d8032e,0x00000000}},	//   _gafe_, _әткә_, _veðl, --, 
   {{0x39480204,0x7bd40083,0x15f413f5,0xdd8c00cf}},	//   rabs_, _tmyu, अवसर_, _ووچ_, 
   {{0x69d40472,0x7bd40472,0x2b4800db,0x572402dd}},	//   _emxe, _umyu, cacc_, спағ, 
   {{0x2d8d2651,0x75452652,0x273005a9,0xec1011dc}},	// [1c200] _yafe_, иназ, تىقس, _بويد, 
   {{0x39981a4c,0x69f0016c,0xf518215c,0x39480175}},	//   _ייִד, _дӯст, نتاش_, qabs_, 
   {{0x34847283,0xeb9c366f,0x00000000,0x00000000}},	//   ргег, blød_, --, --, 
   {{0x321c03a2,0xeb9c3bb6,0x490402dd,0x90c80150}},	//   _sity_, rløg_, _دوپق, ңғаз_, 
   {{0x321d2653,0xeb9c06ea,0xa6d802d2,0xab58002f}},	//   _pity_, sløg_, _leðj, lküc, 
   {{0xf5081fdf,0x00000000,0x00000000,0x00000000}},	//   _англ_, --, --, --, 
   {{0x2d8d2654,0x74142e3e,0x64400356,0xab580112}},	//   _rafe_, _نوسا, ânit, nküc, 
   {{0x2d8d2655,0x3fc40220,0xd37002dd,0xddd8010f}},	//   _safe_, йрығ, _ءۇش_, rtuŝ, 
   {{0x317812dd,0xeda40a31,0x321c003e,0x2d8d2656}},	//   _لحاظ_, ашно, _tity_, _pafe_, 
   {{0x2d8c0023,0x307400f3,0x716400be,0x3ce80055}},	//   _qafe_, _вудс, _خارك, _śava_, 
   {{0x30848d1a,0x6adc11bc,0x2d8c004c,0x628c0077}},	//   _خلاف, नप्र, _vafe_, _ácor, 
   {{0x2d8d15f5,0xeb9c0623,0x00000000,0x00000000}},	//   _wafe_, kløe_, --, --, 
   {{0x2d8d2657,0x2fc4113c,0x9b5806bb,0x627002d3}},	//   _tafe_, _ilog_, шият_, _ሸውዓተ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2fc4037e,0x2b480113,0xdce00135,0xa6d8032e}},	//   _klog_, pacc_, _tanġ, _veðm, 
   {{0x97a400a8,0xfd48002b,0x00000000,0x00000000}},	//   орул, damṛ, --, --, 
   {{0x7c2c110c,0x9c8400d0,0x2fc4015d,0x4a741291}},	// [1c210] _čari, počú, _mlog_, _اُخر, 
   {{0x2704072a,0x69d40472,0x2fc403cb,0x48c4013d}},	//   _शरीर_, _umxe, _llog_, _ләба, 
   {{0xeb9c005c,0x454400db,0x00000000,0x00000000}},	//   mløb_, _ۇچاق, --, --, 
   {{0xeb9c00b5,0x00000000,0x00000000,0x00000000}},	//   lløb_, --, --, --, 
   {{0xb4b40032,0xdb98010f,0x00000000,0x00000000}},	//   _һирә, ידאט_, --, --, 
   {{0x2fc40004,0x3ea80327,0xd5b8009b,0xeb9c005c}},	//   _alog_, _ħat_, _ксс_, nløb_, 
   {{0x2fc52658,0xee340220,0x9f5c2ffe,0xa36000db}},	//   _blog_, ұны_, llué_, _وپسۇ, 
   {{0x2fc52659,0xfe440120,0xf3340055,0xff08011c}},	//   _clog_, бнио, _viṣā_, лейк_, 
   {{0xee340006,0xc06002d3,0xeb9c005c,0xa6d802d2}},	//   бны_, _ዘይምፍ, kløb_, _seðj, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2fc5265a,0x4095265b,0x01040451,0xeb9c005c}},	//   _flog_, _دلار, _ھڪڙو_, dløb_, 
   {{0x62980006,0xa6d8032e,0xdb24072d,0x00000000}},	//   _kruo, _veðj, توحی, --, 
   {{0x3ea90d98,0xeb9c01bf,0x00000000,0x00000000}},	//   _çat_, fløb_, --, --, 
   {{0xce340133,0x00000000,0x00000000,0x00000000}},	//   _بووک, --, --, --, 
   {{0xa3e40574,0xab580e78,0xa3d402a0,0x00000000}},	//   यचा_, uküc, ाफा_, --, 
   {{0x629800b0,0xeb9c383d,0xab5884bf,0xa6d808a5}},	//   _oruo, smør_, rküc, _geðk, 
   {{0xd53800d1,0xab58002f,0x64a000c7,0x27303769}},	// [1c220] لغاچ_, sküc, ҟаца, سىلس, 
   {{0xa6d801a8,0xb8ec0154,0x00000000,0x00000000}},	//   _meðh, _শখ_, --, --, 
   {{0x49000dd8,0x629800c0,0x00000000,0x00000000}},	//   _жүрг, _aruo, --, --, 
   {{0x6299265c,0x6cf8008f,0x69c80064,0x00000000}},	//   _bruo, אפעס, _įgei, --, 
   {{0x629816b8,0x64400311,0xa3d407c1,0x32d00037}},	//   _cruo, ânir, ाफ़_, _देखऽ, 
   {{0x2fc5265d,0x7dcd265e,0xd9f81cd2,0x2b9c008e}},	//   _slog_, _húsf, ंकित_, _käcä_, 
   {{0xd011265f,0x629801f2,0x2fc401d4,0x6560067c}},	//   ولت_, _eruo, _plog_, ónhe, 
   {{0x62992660,0xddd80205,0x00000000,0x00000000}},	//   _fruo, ttuş, --, --, 
   {{0xfe6ce4c4,0x25ec09fd,0x629802d5,0x2fc52661}},	//   نگو_, _आदमी_, _gruo, _vlog_, 
   {{0xddd856a3,0xed8801af,0x00000000,0x00000000}},	//   rtuş, усик_, --, --, 
   {{0xdd940220,0x2bf401f9,0x00000000,0x00000000}},	//   сшы_, ीतलं_, --, --, 
   {{0x2fc41505,0x1dd40137,0xddd8054e,0x7f440051}},	//   _ulog_, илөө_, ptuş, _đhqg, 
   {{0xd1f00201,0xa6d8032e,0xeb9c01bf,0xa92400e5}},	//   _ልማት_, _geðh, tløb_, یںگے_, 
   {{0x6f002beb,0x6ca52662,0x3eb92663,0x00000000}},	//   _iyoc, _гриж, äste_, --, 
   {{0xeb9c04ce,0x6d48009a,0x0bd400c6,0x5d100137}},	//   rløb_, _iefa, _ويتح, _ىبىز, 
   {{0x6d492664,0xa6d8022c,0xe97001d3,0xeb9c005c}},	//   _hefa, _heði, _کندھ, sløb_, 
   {{0x6d492665,0x78c40e3c,0xa6d8022c,0x2984084c}},	// [1c230] _kefa, _čuvš, _keði, _лынг, 
   {{0x6d492666,0x6f006eee,0xf8ac00e5,0x00000000}},	//   _jefa, _myoc, ءکی_, --, 
   {{0x6d48aaea,0xa6d803b2,0x2cbc0175,0x62980153}},	//   _mefa, _meði, nytd_, _sruo, 
   {{0x6d485118,0x1ab000bd,0xd83800bc,0xa784036b}},	//   _lefa, _চেয়া, íče_, _اشدو, 
   {{0x6f0000b4,0x6d4802d0,0x00000000,0x00000000}},	//   _nyoc, _oefa, --, --, 
   {{0x6d492667,0xab5804cc,0xda7c0375,0xdce400d0}},	//   _nefa, chüv, טנדר, _žlčn, 
   {{0x6f00014b,0x7dcc01a8,0x704400d1,0x00000000}},	//   _ayoc, _húsg, ەرۋە, --, 
   {{0x62992668,0x6d48039a,0x7e5400c7,0xd34401d3}},	//   _truo, _aefa, отоц, _فہمی, 
   {{0xa6d80008,0x6298037e,0x00000000,0x00000000}},	//   _beði, _uruo, --, --, 
   {{0x6d492669,0x4cd01c82,0x6f000175,0xa6d81d0e}},	//   _cefa, _সঁজু, _dyoc, _veðh, 
   {{0x6d49266a,0x6f00014b,0xcb080302,0x6fb0136e}},	//   _defa, _eyoc, _סל_, سمیا, 
   {{0x6d49266b,0xd9b405d7,0x62880009,0x00000000}},	//   _eefa, ुस्ट, owgo, --, 
   {{0x6d49266c,0xed4c54a7,0x7dcc03b2,0x00000000}},	//   _fefa, _оо_, _rúsf, --, 
   {{0x6d49266d,0x7b3c0034,0xa6d8032e,0x00000000}},	//   _gefa, dłuż, _geði, --, 
   {{0xab58418f,0xbebc0055,0xed4c01e2,0xb864009a}},	//   mkün, ccūr, _شپي_, غاسو, 
   {{0x6d48090c,0xab59266e,0xbd4400f1,0x80b1266f}},	//   _zefa, lkün, _انګي, _अपने, 
   {{0x6d48ca38,0x3ead2670,0xe7340108,0x366803c5}},	// [1c240] _yefa, nxet_, юет_, разо_, 
   {{0x6d481709,0x6ab92671,0xab592672,0x3eac00db}},	//   _xefa, äufe, nkün, ixet_, 
   {{0x395831b1,0x00000000,0x00000000,0x00000000}},	//   _idps_, --, --, --, 
   {{0x39580280,0x7dcd2673,0x3668055f,0xb6a52185}},	//   _hdps_, _húsd, _камо_, _димл, 
   {{0x2374a3a9,0xab580c6c,0x387c031c,0x00000000}},	//   تمند_, mhüt, ħtru_, --, 
   {{0x61d43334,0xea9800c8,0x6f00037e,0xab58002f}},	//   омія_, יסנש, _ryoc, lhüt, 
   {{0x216415ed,0x3eac0165,0x91480075,0x2ec000dc}},	//   цији_, exet_, ачқа_, षन्त, 
   {{0x6d492674,0xb600012c,0xab580112,0xa6d80d12}},	//   _sefa, řáda, nhüt, _seði, 
   {{0xa5b80241,0x6d48026c,0x8fd00032,0xab58002f}},	//   _atóy, _pefa, _үҙлә, fkün, 
   {{0xab580790,0x6d480200,0x00000000,0x00000000}},	//   hhüt, _qefa, --, --, 
   {{0x6d492675,0x3028008e,0xa6d802d2,0x6598011a}},	//   _vefa, _тоеп_, _veði, בייק, 
   {{0x6d480cfd,0xa06400a8,0x6f0000b5,0x7c3402f0}},	//   _wefa, _фаца_, _tyoc, ízra, 
   {{0x6d492676,0xee801c5c,0x6f0001f0,0xef1802dd}},	//   _tefa, ﯩﻤﻪﻥ_, _uyoc, _тмд_, 
   {{0xdd8c07d6,0x6d492677,0x39580142,0x317c0427}},	//   _ўш_, _uefa, _cdps_, _jbtz_, 
   {{0x395807c5,0x27480063,0x00000000,0x00000000}},	//   _ddps_, ичао_, --, --, 
   {{0x3958031c,0x4a5400d1,0xa6d801a8,0x00000000}},	//   _edps_, _екис, _meðv, --, 
   {{0x395800d8,0x7bd40240,0xd27801ec,0x00000000}},	// [1c250] _fdps_, ëzue, _مﻮﻨﻟ, --, 
   {{0xe8e8007b,0x64b40472,0x00000000,0x00000000}},	//   _نرجو_, يحضر, --, --, 
   {{0x7b3c033f,0xe9dc180f,0xe4e400d4,0xa3d417ee}},	//   służ, ssús_, ціан, ाफल_, 
   {{0x78f80302,0xab592678,0x00000000,0x00000000}},	//   _לפתו, chüt, --, --, 
   {{0x7dcd2679,0xdb9c010f,0xab5803b9,0x00000000}},	//   _húse, יסאר, lhüs, --, 
   {{0x76b8025f,0x7dcc0af2,0x00000000,0x00000000}},	//   _המשפ, _kúse, --, --, 
   {{0x671c1d8a,0x98b8054e,0xe7bc1810,0xab5806be}},	//   _मृतक_, mbră_, _एकाप, nhüs, 
   {{0xa5b80120,0xffd402d5,0x3eac00cf,0x98b416a3}},	//   _atóx, яўля, txet_, žeću_, 
   {{0xd1b8c67c,0xee35267a,0x7dcc032e,0x2bac2bf1}},	//   _ڈالا_, пны_, _lúse, टाना, 
   {{0xd1b9267b,0x9f5c01e7,0x3ead267c,0xbdc8009d}},	//   _والا_, mluí_, rxet_, сгож_, 
   {{0xab58791a,0x7dcc022c,0xa6d80008,0x00000000}},	//   rkün, _rúsd, _geðv, --, 
   {{0x3958009b,0xab580112,0xefe80092,0x00000000}},	//   _sdps_, skün, ቅቀው_, --, 
   {{0xbea48c73,0x80b0c8bf,0xa6d803b2,0x6fb009a6}},	//   _халк, _अपडे, _keðu, _سموا, 
   {{0x8e0800d6,0xab5800dd,0x7dcc09f3,0x2ca8007b}},	//   _днів_, lkül, _búse, óidí_, 
   {{0xbc39267d,0xa6d8032e,0x7e6801f4,0x00000000}},	//   _استا_, _meðu, luep, --, 
   {{0xa6d805f7,0x00000000,0x00000000,0x00000000}},	//   _leðu, --, --, --, 
   {{0x29cc0793,0xab5803fa,0x7bc40194,0xdca001b9}},	// [1c260] _büad_, rhüt, mkku, _хақи, 
   {{0x395800ca,0x7dcd267e,0x7bc4023a,0xf98805af}},	//   _udps_, _húsb, lkku, _اندي_, 
   {{0xa3e40574,0xab59267f,0x7bc52680,0x00000000}},	//   यचं_, chüs, okku, --, 
   {{0x7bc52681,0x7e692682,0x00000000,0x00000000}},	//   nkku, kuep, --, --, 
   {{0x7bc52683,0xc8b4179e,0xe0d4009d,0x00000000}},	//   ikku, _فلیک, үвч_, --, 
   {{0x1df451a5,0xe4d4179e,0x00000000,0x00000000}},	//   ुतोष_, _کوفت_, --, --, 
   {{0x7654005b,0x2bac3f7e,0x00000000,0x00000000}},	//   lsyy, टामा, --, --, 
   {{0xb60000bc,0xab5801d3,0x2c2400c7,0x00000000}},	//   žádo, gkül, ҟьог, --, 
   {{0x9f5c0261,0xa6d808a5,0x7e6800c7,0xb30808f0}},	//   cluí_, _feðu, guep, _طغرل_, 
   {{0x60e4008c,0x3eb8908f,0x7654023a,0x7bc4017a}},	//   ármá, ästa_, isyy, ekku, 
   {{0x1b040154,0xdfcc00db,0x59b00b02,0x76540432}},	//   রেমে_, _зъ_, ञानर, hsyy, 
   {{0x6fd52684,0x7dcc06ea,0x7e6800e4,0x7654005b}},	//   _عزائ, _rúse, buep, ksyy, 
   {{0xada52685,0x6da4024c,0x2bac141f,0x00000000}},	//   _надл, _нида, टाबा, --, 
   {{0x7bc4a9b5,0xbe300022,0xa6d808a5,0xf1bc013a}},	//   akku, _шҕьы, _meðt, ्सिन, 
   {{0x7bc40083,0x2e300042,0x58844c17,0xab5800a2}},	//   bkku, _hâf_, ныта, lküm, 
   {{0x7bc52686,0x00000000,0x00000000,0x00000000}},	//   ckku, --, --, --, 
   {{0xf1bc0a5a,0x00000000,0x00000000,0x00000000}},	// [1c270] ्सान, --, --, --, 
   {{0xab592687,0x3eb80162,0x00000000,0x00000000}},	//   iküm, østi_, --, --, 
   {{0x69c52688,0x2e300142,0xa6d802d2,0x48140117}},	//   mkje, _lâf_, _reðu, _омос, 
   {{0x69c46552,0xab5851e6,0x00000000,0x00000000}},	//   lkje, kküm, --, --, 
   {{0xa818c67c,0xd684d6c2,0xab5800c5,0x03300241}},	//   _پتھر_, _пурп, vkül, _èémí_, 
   {{0x69c40c58,0xf2a000f7,0xa5b801e7,0xf2e00183}},	//   nkje, тишп, _cuót, _বৰঙণ, 
   {{0xa6d826b8,0x69c405ac,0xab5888c6,0x10a00131}},	//   _veðu, ikje, eküm, _ﺋﯧﺮﯨ, 
   {{0xa2452689,0x7e68009f,0xfe34037e,0x139401f4}},	//   _فیصل_, tuep, tは_, _писю, 
   {{0x69c40183,0xab59268a,0x63b801ab,0x271c0154}},	//   kkje, rkül, _ioun, যুরো_, 
   {{0x63b9268b,0xab59268c,0x69c401f5,0x7e68003e}},	//   _houn, skül, jkje, ruep, 
   {{0x63b9268d,0x9d0800bd,0x7bc40d04,0x69c4174e}},	//   _koun, রশ্ন_, tkku, dkje, 
   {{0x63b9268e,0x7bc52683,0x3b09268f,0x69c496eb}},	//   _joun, ukku, жемо_, ekje, 
   {{0x7bc4049b,0x63b92690,0x69c4000f,0xed4c0131}},	//   rkku, _moun, fkje, اھۇ_, 
   {{0x61e12691,0x63b92692,0x69c40fac,0xfce400db}},	//   ninl, _loun, gkje, _ооло, 
   {{0x0ec8012d,0x6cd000ae,0x00000000,0x00000000}},	//   ाईअड, _لقوا, --, --, 
   {{0x63b92693,0x61e04ac0,0x69c44fa5,0x7654005b}},	//   _noun, hinl, akje, tsyy, 
   {{0x61e12694,0xe7dc0316,0xfe780316,0x34c42e1e}},	// [1c280] kinl, _नगरप, ntů_, लन्द, 
   {{0x60c12695,0xe61433b0,0xd1dc0240,0x00000000}},	//   kynm, дду_, _ንፊት_, --, 
   {{0x61e12696,0x6bd40050,0xdb240efc,0x63b80d8b}},	//   dinl, _رویس_, _توکی, _boun, 
   {{0x63b92697,0xfe78038e,0x37e41058,0xb2842fe5}},	//   _coun, ktů_, _цомг, дыкк, 
   {{0x63b92698,0x61e0009f,0x33180101,0xfe780118}},	//   _doun, finl, آزاد_, jtů_, 
   {{0x61e12699,0x30a5269a,0x00000000,0x00000000}},	//   ginl, дрив, --, --, 
   {{0x63b9269b,0xfe6c3b5f,0x8eb403e6,0xab58000d}},	//   _foun, ەگى_, کڕات, khüp, 
   {{0x63b9269c,0x7af4005c,0xdb0435f5,0xa6d801a8}},	//   _goun, _oxyt, _joió, _geðs, 
   {{0x61e1269d,0xe1f40724,0x69c4654e,0x240400f3}},	//   binl, ягә_, ykje, _цнти_, 
   {{0x63b9269e,0xab59269f,0x71700132,0xafe40174}},	//   _zoun, rküm, _شۇبا, fjøð, 
   {{0x63b8dcfb,0x69c400cc,0xab580037,0x6598011a}},	//   _youn, vkje, sküm, קיטק, 
   {{0xaec41234,0x2e300142,0x3ea80419,0x8c4400fb}},	//   _обел, _tâf_, _šate_, меүе, 
   {{0x7bd402d3,0xecdc0073,0x69c4143a,0xa6d808ce}},	//   ëzua, _फेरफ, tkje, _leðr, 
   {{0xe8e8025c,0xe804033f,0x00000000,0x00000000}},	//   _རྨུག, _वीजा_, --, --, 
   {{0x69c40183,0xa6d80321,0x236c0174,0x00000000}},	//   rkje, _neðr, yggj_, --, 
   {{0x69c41a82,0x61e01ae4,0x0594030f,0x7dcc0332}},	//   skje, zinl, کارگ, _túsc, 
   {{0x7dcc09cc,0x61e126a0,0xa9280220,0x0614005b}},	// [1c290] _húsa, yinl, _міне_, едаю, 
   {{0x63b926a1,0xe4c832e8,0x9e740375,0x00000000}},	//   _soun, يبان_, וגמה_, --, 
   {{0x5928031c,0x63b926a2,0x61e126a3,0xb4f0004e}},	//   _ཡུགས_, _poun, vinl, гүрч, 
   {{0xe6643e2f,0xe7a41c5c,0x7dcc9e9b,0x6f9c01ad}},	//   _отго, _تۇرى_, _músa, _खोलू, 
   {{0xa2ac0574,0x61e126a4,0x63b926a5,0xfe7800bc}},	//   ंमध्, tinl, _voun, xtů_, 
   {{0x409405c5,0xd2440262,0x63b926a6,0xa6d808a5}},	//   ерит, тэци, _woun, _feðr, 
   {{0x63b926a7,0x61e126a8,0x543401b9,0x11f803e6}},	//   _toun, rinl, _لرقر, بووک_, 
   {{0x61e051c8,0x6f5400d1,0x60c046f4,0x00000000}},	//   sinl, ىلىز_, rynm, --, 
   {{0x443126a9,0x61e126aa,0xae84013d,0x00000000}},	//   _huz_, pinl, ебыз_, --, 
   {{0x443126ab,0x61e007d6,0x60c00649,0xfe7800bc}},	//   _kuz_, qinl, pynm, rtů_, 
   {{0xfe780316,0x44305246,0xbd44004b,0xeb9c03cd}},	//   stů_, _juz_, ونکي, lmøy_, 
   {{0x7dcc621e,0xfe7800bc,0xeb9c00b5,0xf0900a7c}},	//   _dúsa, ptů_, lløj_, _תנא_, 
   {{0x44305599,0x5928025c,0x3f8c017a,0x4a7464c2}},	//   _luz_, _ཡུངས_, meeu_, кырт, 
   {{0xf2d000c8,0x3e780d29,0x395c20ef,0x443126ac}},	//   נעם_, mèt_, ûts_, _ouz_, 
   {{0x443126ad,0x3e7926ae,0x3eb4084c,0xac9000f3}},	//   _nuz_, lèt_, ţetă_, _бајш, 
   {{0x3f8c017a,0xbb74010a,0x00000000,0x00000000}},	//   neeu_, _чукъ, --, --, 
   {{0x3e7926af,0x572402dd,0x443126b0,0x35a401c6}},	// [1c2a0] nèt_, тпағ, _auz_, нааг, 
   {{0xe4d526b1,0x4430d95c,0x394400d4,0xe734009d}},	//   کومت_, _buz_, _яног, _үеэ_, 
   {{0x443126b2,0x798c0a49,0xab581196,0x3e78204d}},	//   _cuz_, mebw, fküh, hèt_, 
   {{0x44300097,0x3e780699,0xa6d809cc,0x798c2f99}},	//   _duz_, kèt_, _veðr, lebw, 
   {{0x929526b3,0xf20526b4,0x44300489,0x3e787d47}},	//   талц, няко, _euz_, jèt_, 
   {{0x798ca181,0x3e783c51,0x7ae0032e,0x00000000}},	//   nebw, dèt_, _þotu, --, 
   {{0xa5b8003a,0x64a0010b,0x3f8c062c,0x6fdc00e2}},	//   _tuór, _йара, feeu_, lūci, 
   {{0x3e780699,0x798d26b5,0x80b00864,0x7dcc0174}},	//   fèt_, hebw, _अपरे, _rúsa, 
   {{0x798c2f99,0x3e7919a6,0x7dcc06ea,0x437401d5}},	//   kebw, gèt_, _súsa, _шурт, 
   {{0x443007d6,0x1730031c,0x00000000,0x00000000}},	//   _yuz_, _ཨུའམ_, --, --, 
   {{0x61540014,0x798c0142,0x00000000,0x00000000}},	//   _سٔنز_, debw, --, --, 
   {{0x6fcc01ab,0x3e7926b6,0x798c0083,0x00000000}},	//   _fùca, bèt_, eebw, --, 
   {{0x5a343c55,0x3e78ff24,0x7b1c0030,0x9a8401d5}},	//   лнят, cèt_, _náuč, лурл, 
   {{0x7dcd26b7,0x798c0337,0x3a3000a2,0x2aa80107}},	//   _húsn, gebw, _duyp_, отҳо_, 
   {{0xd2440133,0x63680205,0x00000000,0x00000000}},	//   _گۆ_, nönü, --, --, 
   {{0x443126b8,0x00000000,0x00000000,0x00000000}},	//   _ruz_, --, --, --, 
   {{0x798c7b1e,0xd2444451,0xd7f926b9,0x964401c6}},	// [1c2b0] bebw, _دۆ_, хур_, гэхд, 
   {{0x798c0117,0x44300356,0x00000000,0x00000000}},	//   cebw, _puz_, --, --, 
   {{0x98b80006,0x443126ba,0x996402d5,0x3e7926bb}},	//   darė_, _quz_, _стыл, zèt_, 
   {{0xf8b404ae,0x78f00220,0xe2741945,0x63680213}},	//   _ספרי_, _түсу, ешкә_, dönü, 
   {{0xab580e78,0x3e78068c,0x85b00133,0x00000000}},	//   rküh, xèt_, _پیاڵ, --, 
   {{0xc0e4529e,0x443126bc,0xeb9c08fb,0x3f8c0083}},	//   колк, _tuz_, rmøy_, weeu_, 
   {{0x6fcc01ab,0x9f5c0129,0x601400e4,0x3e784ceb}},	//   _sùca, loué_, hãme, wèt_, 
   {{0x3e7835a9,0x3dbc0131,0x798c2f99,0x00000000}},	//   tèt_, ﺭﺳﯩﺘ, zebw, --, 
   {{0x3f8c0731,0x798d15f5,0x9f5c0129,0x6ab8002f}},	//   reeu_, yebw, noué_, äufl, 
   {{0x3e7926af,0x3cc801c0,0xc3cc0241,0x00000000}},	//   rèt_, длоо_, _àìbí, --, 
   {{0x3e7926b6,0xbebc02d5,0x9f5c004a,0xbb4526bd}},	//   sèt_, ncūz, houé_, кенк, 
   {{0x798d26be,0xa3d40034,0xdb0401c4,0x3e7919a6}},	//   webw, ाफट_, _soiñ, pèt_, 
   {{0x201c016b,0x798d26bf,0x9f5c0129,0x3af400d4}},	//   mmui_, tebw, joué_, тянс, 
   {{0x7e68009f,0xaa4079b4,0x6e289758,0x2ef00166}},	//   mrep, рерл, _gifb, _әзәр, 
   {{0xe9a01677,0x798d1816,0x7dcc01d3,0x00000000}},	//   јасп, rebw, _húso, --, 
   {{0x3b8526c0,0x6fdc005f,0x7dcc0030,0x798c2252}},	//   _рлиг, tūci, _kúso, sebw, 
   {{0x7e6926c1,0x798c04ba,0x636803e0,0x00000000}},	// [1c2c0] nrep, pebw, zönü, --, 
   {{0x5fa001ad,0x2a54011a,0x7e6802d0,0x00000000}},	//   _खोसल, _שבין_, irep, --, 
   {{0xe8f4084c,0x7e6801a8,0x00000000,0x00000000}},	//   _алэ_, hrep, --, --, 
   {{0x7e6926c2,0x601400e4,0x201c01b9,0xc51400d1}},	//   krep, hãmb, jmui_, ھبەت, 
   {{0x98b80006,0x9f5c06af,0x60140022,0x1af403d4}},	//   tarė_, coué_, kãmb, _ঘৰতে_, 
   {{0x7e68f155,0xe724016c,0xeb9c168c,0xddd800e2}},	//   drep, _шояд_, tløk_, lruņ, 
   {{0x201c0270,0x3cfc000d,0x6e285cf2,0xeb0c0118}},	//   fmui_, _रँगे_, _rifb, _सर्त_, 
   {{0xeb9c143a,0xef9001b9,0xdfe400c7,0x00000000}},	//   rløk_, شیتد, кьыл_, --, 
   {{0x7e6926c3,0xb22526c4,0xeb9c05ac,0x00000000}},	//   grep, _амал, sløk_, --, 
   {{0x20e00574,0x6440007b,0xf1a8d204,0x00000000}},	//   _केवळ_, ínig, _تاره_, --, 
   {{0x5fa0069f,0x7e681e0b,0xdd9402dd,0x712401d5}},	//   _खोवल, arep, тшы_, _شرطل, 
   {{0x9c2828f6,0x6014035b,0x2ee401af,0x00000000}},	//   кіяж_, tãme, _ижег, --, 
   {{0x7e6926c5,0x6b8c01fa,0xda780209,0x0c240209}},	//   crep, recg, кяр_, кмүн, 
   {{0x3cfc05f9,0x9f5c06af,0x60140022,0x00000000}},	//   _रुके_, voué_, rãme, --, 
   {{0x98c526c6,0x7dcc01a8,0x2d9c002d,0x00000000}},	//   астл, _músl, mdte_, --, 
   {{0x2d9d26c7,0xd7f801c0,0x69a0012c,0x9f5c06af}},	//   ldte_, вуу_, _छोरी, toué_, 
   {{0x2d9c08c2,0xc6f802e8,0x88e000eb,0x00000000}},	// [1c2d0] odte_, хнах_, _মুশক, --, 
   {{0x2d9d26c8,0x201c0024,0x9f5c0129,0xb60000d7}},	//   ndte_, zmui_, roué_, žáno, 
   {{0x201c0006,0x9968008f,0x96080006,0x2d9d26c9}},	//   ymui_, _בייַ_, тэта_, idte_, 
   {{0xdb0526ca,0x7e682ab7,0x2d9c0e89,0xeb9c5522}},	//   _uniã, yrep, hdte_, ndø_, 
   {{0xe19030af,0x7dcc032e,0x00000000,0x00000000}},	//   илдө, _búsl, --, --, 
   {{0x2d9d26cb,0x7dd80ca8,0x6e340432,0x00000000}},	//   jdte_, _mùsù, _çyby, --, 
   {{0x7e6926cc,0x7dcc4eb4,0x00000000,0x00000000}},	//   wrep, _súso, --, --, 
   {{0x7e6926cd,0xd3a4453f,0x2d9c1ad5,0x00000000}},	//   trep, _круп, edte_, --, 
   {{0x7f4926ce,0x442d26cf,0x201d26d0,0x7dcc032e}},	//   rbeq, _iie_, rmui_, _fúsl, 
   {{0x442d26d1,0xef1526d2,0x5bcc1944,0x201c0024}},	//   _hie_, ымы_, ास्व, smui_, 
   {{0x442d26d3,0x201c0165,0x60140124,0x00000000}},	//   _kie_, pmui_, rãmb, --, 
   {{0x442c0953,0xeb9526d4,0x60140124,0x00000000}},	//   _jie_, гию_, sãmb, --, 
   {{0x442d26d5,0x7dcc3e59,0x60140022,0x00000000}},	//   _mie_, _húsm, pãmb, --, 
   {{0x3f9d26d6,0x442d26d7,0x7c9400d8,0x00000000}},	//   _hawu_, _lie_, _бриц, --, 
   {{0x442c0731,0x3f9d26d8,0x27400118,0x00000000}},	//   _oie_, _kawu_, zénů_, --, 
   {{0x442d26d9,0x3f9c95e7,0xf7480345,0x00000000}},	//   _nie_, _jawu_, عجزه_, --, 
   {{0x3f9c0925,0xa3d4772c,0xe9dc0077,0xfaa526da}},	// [1c2e0] _mawu_, िसन_, mpún_, _сапо, 
   {{0x442c18a6,0xa2a4a5b3,0xdce003ee,0x3f9c414b}},	//   _aie_, चिन्, _hanı, _lawu_, 
   {{0x442d26db,0xdce06648,0x6fd40490,0xe7800131}},	//   _bie_, _kanı, बसमू, شلەپ, 
   {{0x3f9c0c11,0x799d26dc,0xd3701b56,0x442d26dd}},	//   _nawu_, _hapw, تۇر_, _cie_, 
   {{0x442d26de,0x799c113c,0x2d9c3e1d,0xdce126df}},	//   _die_, _kapw, ydte_, _manı, 
   {{0x442d26e0,0xdce00139,0xab58000d,0x00000000}},	//   _eie_, _lanı, lküt, --, 
   {{0x442d26e1,0x3f9caef8,0x799c089c,0x98b8002b}},	//   _fie_, _bawu_, _mapw, darī_, 
   {{0x09d06bcf,0x442d26e2,0x799c0100,0x644000cf}},	//   _हत्य, _gie_, _lapw, ínie, 
   {{0xd24c0014,0x7dcc01e7,0x00000000,0x00000000}},	//   _کۆڈ_, _túsl, --, --, 
   {{0x442d26e3,0x799c0455,0x6678010f,0x00000000}},	//   _zie_, _napw, עטיק, --, 
   {{0x442c013b,0x3f9c017a,0xa064b6d4,0xa5b402e4}},	//   _yie_, _fawu_, _баха_, אליק_, 
   {{0xdce071e1,0x799c035a,0xee3800f3,0x00000000}},	//   _canı, _aapw, _знд_, --, 
   {{0xdce03235,0x799c02ea,0xdee00e92,0xeb9c143a}},	//   _danı, _bapw, _лоци, rdø_, 
   {{0xa3a88919,0xed3405f5,0x799c0327,0x7dcc002d}},	//   _कोन_, _сэдэ, _capw, _lúsj, 
   {{0x3f9d26e4,0x799c0100,0xdce003e0,0x58d4bb61}},	//   _yawu_, _dapw, _fanı, борт, 
   {{0xd5b926e5,0xab58000d,0x00000000,0x00000000}},	//   қсу_, gküt, --, --, 
   {{0x442d26e6,0x26cc0083,0x00000000,0x00000000}},	// [1c2f0] _rie_, ágo_, --, --, 
   {{0x442d26e7,0x3eb8049b,0xd668314c,0x6b9c022e}},	//   _sie_, ästi_, املو_, _haqg, 
   {{0xdce03e67,0x442d26e8,0x8334074d,0xa8a40063}},	//   _yanı, _pie_, анех, _српк, 
   {{0xd49920b3,0xdce0654f,0xa3dc0034,0x6b9c0003}},	//   ыру_, _xanı, धों_, _jaqg, 
   {{0x442d26e9,0x6d5926ea,0x3f9cdd10,0x6b9c0327}},	//   _vie_, kata, _rawu_, _maqg, 
   {{0x442d26eb,0x6b9c003d,0x3f9c0198,0xa25c0023}},	//   _wie_, _laqg, _sawu_, ሰኣኑን_, 
   {{0x442d26ec,0xb4b41248,0x3f9c013f,0xab58002f}},	//   _tie_, _кирә, _pawu_, nküs, 
   {{0x442d26ed,0x6b9c406c,0xbfc526ee,0x225c107d}},	//   _uie_, _naqg, рбик, _tvuk_, 
   {{0x6d5926ef,0xdce00139,0xa3a81c5d,0x00000000}},	//   fata, _ranı, _कोय_, --, 
   {{0x6d5926f0,0xdce05d6d,0x6298079b,0xe1f00592}},	//   gata, _sanı, _isuo, _اسر_, 
   {{0x3f9c0004,0x6b9c0003,0x7dcd26f1,0x799d26f2}},	//   _tawu_, _baqg, _húsk, _rapw, 
   {{0x629803a2,0x6d5926f3,0x7dcc52dd,0x799c0455}},	//   _ksuo, aata, _kúsk, _sapw, 
   {{0x799d26f4,0xab58002f,0x00000000,0x00000000}},	//   _papw, eküs, --, --, 
   {{0x799c047e,0x3234008f,0x7dcc02d2,0x00000000}},	//   _qapw, יטשן_, _músk, --, 
   {{0xdce01b09,0x6b9c0327,0xdb040139,0x29cc03e3}},	//   _tanı, _faqg, _oniç, _güam_, 
   {{0x799c009f,0x00000000,0x00000000,0x00000000}},	//   _wapw, --, --, --, 
   {{0xe73526f5,0xa6c526f6,0x7bd46eb0,0xdee002d3}},	// [1c300] реу_, алта_, _ilyu, _ምልኪ_, 
   {{0x7dcc002d,0xe3ac00f1,0xab58000d,0x00000000}},	//   _súsj, ېرو_, sküt, --, 
   {{0x3ea80cf4,0x7bd4013d,0xeb9c01bf,0xab584dd9}},	//   _šatl_, _klyu, rløv_, mkür, 
   {{0x6d5926f7,0x7dcc0579,0xf7d001ec,0x543401d5}},	//   zata, _búsk, _بەرڭ, لرچر, 
   {{0x6d5926f8,0x2bd8000d,0xb34000a2,0xb224009d}},	//   yata, मोटा, _üçmi, амдл, 
   {{0x6d5926f9,0xf8b808ec,0x6ab803fa,0xab5800fd}},	//   xata, _उपाय, äufi, nkür, 
   {{0x1bf802a0,0x7bd403ac,0xbacc03d4,0x00000000}},	//   ीवाल_, _olyu, ৰপিছ, --, 
   {{0x6d5926fa,0x43740aa5,0x7dcd26fb,0xc8840724}},	//   wata, _гуфт, _húsh, leşü_, 
   {{0xab5807c4,0x7dcc0af2,0xc32c1a59,0x30b400eb}},	//   kkür, _kúsh, _كەم_, জনেস, 
   {{0x7bd526fc,0x6d5926fd,0x60140022,0xbacc00fe}},	//   _alyu, uata, rãma, ৰপাছ, 
   {{0x4c940801,0xf1c00006,0xa3a847b8,0x6b9c014f}},	//   щинс, rašą_, _कोड_, _paqg, 
   {{0x6d5926fe,0x6b9c0455,0x00000000,0x00000000}},	//   sata, _qaqg, --, --, 
   {{0x6d5926ff,0x9f800022,0x6b9c022e,0x00000000}},	//   pata, _eñó_, _vaqg, --, 
   {{0xa2a52700,0x6d592701,0x6b9c0135,0xab580112}},	//   चित्, qata, _waqg, tküs, 
   {{0x19591f3a,0x7bd428e5,0x6b9c0327,0x6d4c0790}},	//   расы_, _flyu, _taqg, ıbad, 
   {{0xab5830a8,0x27fc01fa,0x7bd45b7f,0x47340006}},	//   rküs, čuno_, _glyu, снас, 
   {{0x394406be,0xab580037,0x00000000,0x00000000}},	// [1c310] _şose_, sküs, --, --, 
   {{0x95d8011b,0xe97001d3,0x00000000,0x00000000}},	//   адут_, _بندھ, --, --, 
   {{0x7dcc00c6,0x5bc401d5,0x47d442f4,0x00000000}},	//   _dúsh, _طقیل, _هيدر, --, 
   {{0xeb9c0450,0x82d802dd,0x94a8013d,0x00000000}},	//   mløs_, лдес_, штуа_, --, 
   {{0xa3a805ba,0x68f81432,0xeb9c0450,0x4df800ce}},	//   _कोण_, ğudu, lløs_, ुवाई_, 
   {{0x95c817cd,0x92b40b61,0x68f82ca8,0x00000000}},	//   _куса_, تحما, şudu, --, 
   {{0xd4980120,0xeb9c005c,0x00000000,0x00000000}},	//   _крт_, nløs_, --, --, 
   {{0xe3b12702,0x629827be,0x6444002d,0xa2a400dc}},	//   _برس_, _tsuo, _itji, चिद्, 
   {{0x7dcc05a4,0x6fcc00a3,0x67f00327,0xe16400db}},	//   _húsi, _mùch, għji, _نداي, 
   {{0x7dcc00d2,0x321c0295,0x6fcc08c2,0x7bd4022e}},	//   _kúsi, _ghty_, _lùch, _slyu, 
   {{0x5f7433f5,0x7bd52703,0x1ee401d3,0x00000000}},	//   _ناشر, _plyu, _ھوتی_, --, 
   {{0x69d4056a,0xeb9c20e4,0xa3d4302b,0x2bac00cd}},	//   _alxe, dløs_, िसि_, टागा, 
   {{0xed4ca6be,0x77640208,0x8c480139,0xbe6801c6}},	//   _но_, _rdkx, _peşü, _салж_, 
   {{0x644405e4,0xba1800db,0x3eb80037,0x00000000}},	//   _otji, ايسا_, ästu_, --, 
   {{0x644400d2,0xab592704,0x7dcc03b2,0xb60002f0}},	//   _ntji, rkür, _núsi, žáko, 
   {{0x6fcc01ab,0x7bd40113,0x69d4005a,0xab580b97}},	//   _cùch, _ulyu, _elxe, skür, 
   {{0x64440d04,0x6fcc00a3,0x7c2417ef,0x00000000}},	// [1c320] _atji, _dùch, mmkr, --, 
   {{0x7dcc0bcd,0xeb9c4c5d,0xab580254,0xc568007b}},	//   _búsi, bløs_, lküp, لحمل_, 
   {{0xe00446c7,0x395801ab,0x17c40022,0x7c240fac}},	//   शवाद_, _ieps_, _данҭ, omkr, 
   {{0xf7706ea9,0x6d9c0327,0xeb9c0b1a,0x321c036e}},	//   _عاج_, _iħaż, llør_, _shty_, 
   {{0x39592705,0x00000000,0x00000000,0x00000000}},	//   _keps_, --, --, --, 
   {{0xf7707240,0x39592706,0x75d52707,0x7dcc0413}},	//   _باگ_, _jeps_, _ايسا, _fúsi, 
   {{0x39592708,0x7dcc002d,0x74140691,0x6d9c0327}},	//   _meps_, _húsw, _هوسا, _jħaż, 
   {{0x39580286,0x6d9c0327,0xe88c0023,0x00000000}},	//   _leps_, _mħaż, _ምግጣም_, --, 
   {{0x39581af3,0x63b004bf,0x20d12709,0x91c40166}},	//   _oeps_, šení, ại_, _мәкл, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x5fa001f9,0x00000000,0x00000000,0x00000000}},	//   _खोकल, --, --, --, 
   {{0xa0980375,0x09d000cd,0xeb9c0450,0xc0c80114}},	//   _תיאט, हस्य, vløs_, _туђе_, 
   {{0x6fcc01ab,0xdb800023,0x00000000,0x00000000}},	//   _rùch, _ክዛዘም_, --, --, 
   {{0x6ab85d2d,0x2fc43441,0x39581c69,0xeb9c0450}},	//   উনলো, _hoog_, _ceps_, tløs_, 
   {{0x2fc4429b,0x7f580429,0x3959270a,0x70b407af}},	//   _koog_, _yewq, _deps_, _अपोल, 
   {{0x2fc401d9,0x7dcd270b,0x7f580003,0xeb9c0450}},	//   _joog_, _rúsi, _xewq, rløs_, 
   {{0x2fc5270c,0x6444045f,0xeb9c20e4,0x7a20063f}},	// [1c330] _moog_, _stji, sløs_, ịtar, 
   {{0x2fc40211,0x2b58511b,0x39580254,0xeb9c0450}},	//   _loog_, _heqc_, _geps_, pløs_, 
   {{0x0735270d,0x6d9c038f,0x8a4401c8,0x00000000}},	//   _меню, _għaż, _ائڊم, --, 
   {{0x2fc40070,0x3958ca82,0x9f5c0270,0xb7d800f2}},	//   _noog_, _zeps_, kouá_, _نوپا_, 
   {{0x97a401c0,0x66c801b9,0x00000000,0x00000000}},	//   _эрэл, _сунг_, --, --, 
   {{0x7dccbed3,0x7f580135,0x4174215c,0x00000000}},	//   _húsv, _sewq, زاتس, --, 
   {{0x2fc5270e,0x64442e95,0xc8c80034,0xa2a41db2}},	//   _boog_, _utji, रहिट, चिह्, 
   {{0x5fa00dad,0x20d0063f,0xfe440120,0x00000000}},	//   _खोखल, ṛi_, онио, --, 
   {{0xee35270f,0x2fc52710,0x25a000f3,0x2910007c}},	//   оны_, _doog_, _kajl_, _lyxa_, 
   {{0x5fd8007d,0x7f58014f,0x3c64011b,0xfde8011c}},	//   _बतवल, _wewq, оког, рдок_, 
   {{0x2fc40de2,0x7f580548,0x06cc00eb,0x00000000}},	//   _foog_, _tewq, _রেমি, --, 
   {{0xdb0400c6,0x2fc41e0b,0xfe1802ab,0x3eb8007c}},	//   _iniú, _goog_, _नीरस_, ästs_, 
   {{0xef0c10fc,0xd0181078,0x6d6000e4,0x00000000}},	//   _цм_, _уфф_, îvaí, --, 
   {{0xa3a800af,0x2fc401f5,0x291001e3,0x9d740092}},	//   _कोस_, _zoog_, _byxa_, _በበኩሌ_, 
   {{0x2fc40211,0x3958003b,0x7dcc032e,0xee2400ec}},	//   _yoog_, _veps_, _búsv, _بڻيو_, 
   {{0xe7352711,0x2fc40050,0x98b80006,0xeb9c072b}},	//   жет_, _xoog_, sarį_, slør_, 
   {{0x39587ec7,0xeb9c03cd,0x70b41100,0x39340a89}},	// [1c340] _teps_, mløp_, _अप्ल, _мэнс, 
   {{0xeb9c143a,0xe73c0055,0xb4d48944,0x00000000}},	//   lløp_, _raõe_, يغات, --, 
   {{0x2bac8497,0x69a00073,0xa44000d7,0x7d540092}},	//   टाचा, _छोटी, _púšť_, _መጠናቸ, 
   {{0xeb9c2d8b,0x5dc401ec,0x00000000,0x00000000}},	//   nløp_, _ﺨﻠﻔﻴ, --, --, 
   {{0x25a0003d,0x2fc4e379,0x7dcc08a7,0x67f0025c}},	//   _fajl_, _roog_, _húsu, għju, 
   {{0xe1f401c0,0x2fc470ac,0xddd801e4,0xd010036b}},	//   огч_, _soog_, truŝ, کلب_, 
   {{0x2fc52712,0x00000000,0x00000000,0x00000000}},	//   _poog_, --, --, --, 
   {{0xb4d41cc3,0x32c41c5c,0xceb80032,0xe45001d3}},	//   िनी_, ﯩﻠﮕﻪ, йҙе_, _آہنگ, 
   {{0x7dcc00d2,0xa3d43d60,0xe3bc0295,0x2fc52713}},	//   _lúsu, िसर_, _òña_, _voog_, 
   {{0x06cc00bd,0x2fc401a4,0xc0cc02d3,0xa2a4084d}},	//   _রেডি, _woog_, ጥሞም_, चिर्, 
   {{0x2fc52714,0x6fb40127,0x00000000,0x00000000}},	//   _toog_, _ومطا, --, --, 
   {{0xa030129d,0x1b040154,0x00000000,0x00000000}},	//   _قىلت, রেছে_, --, --, 
   {{0xb4d4012c,0x6da52715,0x00000000,0x00000000}},	//   िनु_, _мида, --, --, 
   {{0xdd900228,0x1e300953,0x19592716,0xdd8c7b7a}},	//   _жашы, _жніў, жары_, _لوه_, 
   {{0xa3152717,0x588401ec,0x00000000,0x00000000}},	//   _तर्ज_, мыта, --, --, 
   {{0xdd7001d3,0xb3700092,0x00000000,0x00000000}},	//   _ٹھیک, _ብአዴን_, --, --, 
   {{0xa564004e,0xf4000276,0xa3a837f3,0xd7f80408}},	// [1c350] قدان, inţă_, _कोष_, цур_, 
   {{0xfce4001f,0x7dcc1427,0x25a00327,0x00000000}},	//   _ምርጥ_, _fúsu, _qajl_, --, 
   {{0xc3cc01e1,0x00000000,0x00000000,0x00000000}},	//   _àìkí, --, --, --, 
   {{0xa3a8006d,0x78b82d8b,0x7dcc659a,0xf84401f0}},	//   _कोश_, åtve, _húst, _хӯрд_, 
   {{0xb4000107,0x7dcc02d2,0x77b8011a,0x00000000}},	//   хӯрд, _kúst, _המרח, --, 
   {{0x1a9c00c8,0xf4000311,0x7dcd2718,0xa3a825c9}},	//   יידע, enţă_, _júst, _कोर_, 
   {{0x987807f5,0x00000000,0x00000000,0x00000000}},	//   ršće_, --, --, --, 
   {{0x7dcc045f,0x27f8003e,0x7e7c004e,0xddd80205}},	//   _lúst, nnqn_, àspo, fruş, 
   {{0xfe7000c6,0x2444013f,0xeb9c00d4,0x2bac01ad}},	//   ردة_, rεmu_, vløp_, _जोधा, 
   {{0xdc6c0201,0xf4000311,0x7dcc0162,0xee341b0a}},	//   _በተለይ_, anţă_, _núst, янь_, 
   {{0xcb083d99,0xac8001c0,0xe0544550,0x9d080183}},	//   _על_, нгэл, _بیعت_, ৰশ্ন_, 
   {{0x2d8c0175,0x7dcc0174,0x00000000,0x00000000}},	//   _ebfe_, _rúsu, --, --, 
   {{0xeb952719,0x7dcd271a,0xeb9c08fb,0x00000000}},	//   чия_, _búst, rløp_, --, 
   {{0x7dcc0077,0xfce41171,0xeb9c143a,0x00000000}},	//   _cúst, _ноло, sløp_, --, 
   {{0x9ba40075,0xbc240137,0x80a0134e,0x00000000}},	//   _قەدى, _ىرعى, _कैमे, --, 
   {{0x2d8001ed,0xe8980342,0xa3a82356,0xab5801d3}},	//   őket_, şağı, _कोल_, ljün, 
   {{0xe88c02d3,0x36680107,0x00000000,0x00000000}},	// [1c360] _ምፍጻም_, сазо_, --, --, 
   {{0x7dcd271b,0x7c340076,0x690400e5,0xab580a08}},	//   _gúst, _hiyr, érdé, njün, 
   {{0xb4d4c0fb,0xd911271c,0x7dcd271d,0x23b11cc1}},	//   िने_, _شیر_, _húss, کمنس, 
   {{0x7c34022e,0xf41000be,0x00000000,0x00000000}},	//   _jiyr, رؤا_, --, --, 
   {{0xb1901b15,0xe6840137,0xa3a801f9,0x00000000}},	//   еллә, _ىچكى_, _कोळ_, --, 
   {{0x71641216,0x7dcc02d2,0x00000000,0x00000000}},	//   ساتك, _múss, --, --, 
   {{0xd25000f1,0x21640063,0x02180006,0xab5800e5}},	//   رنګ_, чији_, ціць_, djün, 
   {{0x28940375,0x8f3428e8,0x00000000,0x00000000}},	//   פדפן_, мейц, --, --, 
   {{0xa2e001b9,0x37ac00fe,0x00000000,0x00000000}},	//   _зотд, _টকাৰ, --, --, 
   {{0x27fc2aac,0xdb0407de,0x6140010b,0xa1540114}},	//   čuni_, _uniù, _зефа, _нађу_, 
   {{0xc0d4069c,0x7c348119,0xec1400fd,0x00000000}},	//   _ክፋል_, _biyr, зенә_, --, 
   {{0xddd80dfe,0x7dcd271e,0x409400d1,0x699c00c5}},	//   rtuš, _súst, _юрут, _ओसही, 
   {{0x9b240261,0x7dcc08a5,0xdef460c6,0x00000000}},	//   ефрл, _púst, _ныш_, --, 
   {{0x7c341368,0x320c0170,0x80a000e1,0x7dcc02d2}},	//   _eiyr, nofy_, _कैडे, _dúss, 
   {{0x941c0085,0xb4d4193d,0x00000000,0x00000000}},	//   ívɛ_, िनो_, --, --, 
   {{0xb4d400bc,0xa3a8012d,0x00000000,0x00000000}},	//   िनै_, _कों_, --, --, 
   {{0x5694496b,0x59a801ad,0x1dc001c6,0x00000000}},	// [1c370] натт, _छोकर, _цөөн, --, 
   {{0x0594036b,0x7dcd271f,0x7c3401a9,0x00000000}},	//   بارگ, _húsr, _ziyr, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd8280111,0x00000000,0x00000000,0x00000000}},	//   _ніяк_, --, --, --, 
   {{0xdb04067c,0xa2ac35e0,0x2cb802d2,0x00000000}},	//   _caiè, ूमध्, _ápdf_, --, 
   {{0x76b80375,0x130802bf,0x00000000,0x00000000}},	//   _ומשפ, чній_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x320c06d9,0xf8b81cba,0x00000000,0x00000000}},	//   bofy_, _उप्प, --, --, 
   {{0x7dcd2720,0x7c34036a,0xc0cc1954,0x00000000}},	//   _rúss, _siyr, ባሃል_, --, 
   {{0xfce4ea5a,0x7c3400ad,0x2bac1cd2,0x55ac010f}},	//   фоно, _piyr, _जोहा, זייַ, 
   {{0x6cb00137,0x60140022,0x6e8800f1,0x7dcc08a5}},	//   төшт, kãmi, _ژمنې_, _púss, 
   {{0x06cc00bd,0x3ce800bc,0xbea402d5,0xef0c00f1}},	//   _রেসি, _živě_, _цалк, _پټو_, 
   {{0x3f8c004e,0x7c9422c3,0x395c0413,0x00000000}},	//   lfeu_, _жриц, úts_, --, 
   {{0x7c34022e,0xddd8033f,0x699c0073,0x00000000}},	//   _tiyr, psuł, _ओसरी, --, 
   {{0x320c0109,0x3b640014,0x8b84215c,0x7dcc02d2}},	//   zofy_, _کُکِ, _كەپە_, _túss, 
   {{0xb4d41c4c,0x3eac0489,0xcc340724,0x35a401c0}},	// [1c380] िन्_, nvet_, _яхшы, мааг, 
   {{0x7bc408ad,0x3ead2721,0x39441b0a,0x00000000}},	//   ljku, ivet_, _юног, --, 
   {{0x3eac850c,0x00000000,0x00000000,0x00000000}},	//   hvet_, --, --, --, 
   {{0x3eac0156,0x95e80014,0x7bc40219,0xa3a8000d}},	//   kvet_, _ککرِ_, njku, _कोआ_, 
   {{0xaaa40316,0xdb040077,0x320d2722,0x3eac0200}},	//   खिएक, _baié, tofy_, jvet_, 
   {{0x93c80583,0xc8880101,0x3eac00e5,0x00000000}},	//   _کاسہ_, _بخیل_, dvet_, --, 
   {{0x3ead2723,0x64a00124,0x798c0175,0xe484009d}},	//   evet_, _иара, ifbw, _ойрд_, 
   {{0x3ead2724,0x320d2725,0x68e12726,0x00000000}},	//   fvet_, sofy_, _ünde, --, 
   {{0xe2802dc4,0x00000000,0x00000000,0x00000000}},	//   _илти, --, --, --, 
   {{0x7dcc03f4,0xfca800ec,0x3eb801e3,0x00000000}},	//   _búsq, ڳاپو_, åsta_, --, 
   {{0x3eac0254,0x98b80064,0x00000000,0x00000000}},	//   avet_, mbrė_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3eac00f3,0x9ea449c4,0xaef804f2,0x9a84498b}},	//   cvet_, _овца_, _برائ_, курл, 
   {{0xa3a827a9,0x2bac4fed,0x9f5c01a8,0x9178004d}},	//   _कोई_, _जोरा, lluð_, _bởi_, 
   {{0xda352727,0x6d492728,0xd91401c0,0x91780051}},	//   теры, _iffa, вдры, _cởi_, 
   {{0x60140124,0x00000000,0x00000000,0x00000000}},	//   tãmi, --, --, --, 
   {{0xd244168d,0x056c02d3,0xae0007f7,0xab580139}},	// [1c390] _خۆ_, _ኣምልኾ_, _लदान_, kküz, 
   {{0x461516e4,0x00000000,0x00000000,0x00000000}},	//   روار, --, --, --, 
   {{0x7dcc03b2,0xa3a802e5,0x3eac030a,0x91780208}},	//   _músp, _कोउ_, zvet_, _gởi_, 
   {{0x3ead2729,0x84240131,0x00000000,0x00000000}},	//   yvet_, رىشن, --, --, 
   {{0x6d49272a,0x03180451,0x53340006,0x3eac0489}},	//   _offa, سڪرت_, вецт, xvet_, 
   {{0x7ff5272b,0x27fc0f03,0x3ead272c,0xe9dc180f}},	//   کستا, čunu_, vvet_, mpús_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d49272d,0xdc6c001f,0xd3785476,0x9f5d272e}},	//   _affa, _በሰማይ_, _очу_, _üsüe_, 
   {{0x63b9272f,0x3eac0a05,0x925800ae,0x00000000}},	//   _inun, uvet_, _يشكر_, --, 
   {{0x7dcc04d4,0x7bc40113,0xd24c0244,0x00000000}},	//   _cúsp, wjku, _بۆو_, --, 
   {{0x3eac0fb7,0x628804cc,0x506400cf,0x3234011a}},	//   svet_, ltgo, _атча, _נטען_, 
   {{0x6d492730,0xd9d849fc,0x00000000,0x00000000}},	//   _effa, डस्ट, --, --, 
   {{0x62892731,0xe8000acd,0x63b801f7,0x1ee403e6}},	//   ntgo, रचना_, _mnun, _توشی_, 
   {{0x6da12732,0x69c4036e,0xa51c0210,0x00000000}},	//   _биша, gjje, _भरूच_, --, 
   {{0x63b88af8,0x7e692733,0x6cd000f2,0x38b808a5}},	//   _onun, lsep, _مقوا, dýrð_, 
   {{0x63b80337,0x7f48013c,0x62880158,0xac1400f3}},	//   _nnun, nceq, ktgo, _поју_, 
   {{0x76252734,0x80a02aa1,0x8b640137,0x66e09c05}},	// [1c3a0] емаз, _कैसे, _شايم, гота, 
   {{0xe6152735,0x7e68002f,0xb6000118,0xd1e80092}},	//   еду_, isep, _čásl, ዛበት_, 
   {{0x6288017a,0xb7ac00cc,0x00000000,0x00000000}},	//   etgo, _টকীয়, --, --, 
   {{0x7e692736,0x3e5c0100,0x00000000,0x00000000}},	//   ksep, kňt_, --, --, 
   {{0x7e6804ce,0x628801bf,0xacbc00d1,0x59a40550}},	//   jsep, gtgo, ﺭﻣﯘﺷ, _ओसार, 
   {{0x63b92737,0x7e680254,0x61e00076,0x30a400ea}},	//   _enun, dsep, ghnl, ерив, 
   {{0x6600276f,0x7e692738,0xff380092,0xa3a828d4}},	//   _спра, esep, _አቀማመ, _कोक_, 
   {{0xb4bc5e58,0x63b800e4,0x3a392739,0x28b084b8}},	//   ेही_, _gnun, _lipp_, ुमति, 
   {{0x437410fc,0x61e00334,0x67f80108,0xab6000a2}},	//   _јуст, bhnl, läjä, ndüň, 
   {{0x71e8484d,0x3a380037,0xe0cc01d9,0x00000000}},	//   _عفاف_, _nipp_, _گٲم_, --, 
   {{0x67f802f6,0xc31404c5,0x7e69273a,0x00000000}},	//   näjä, ়েদি_, asep, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb6801c0,0x67f8005b,0x00000000,0x00000000}},	//   эрэл_, häjä, --, --, 
   {{0x6d49273b,0xdb050a26,0xec69273c,0x00000000}},	//   _uffa, _anió, _ерик_, --, 
   {{0x3a38007c,0x9d140212,0x18b800c0,0xdca00114}},	//   _dipp_, _пошт_, нгры_, _баји, 
   {{0x2d9d273d,0x62880142,0x69c40332,0x00000000}},	//   lete_, ytgo, sjje, --, 
   {{0x69c4094a,0x3a380694,0x63b80309,0x473402d5}},	// [1c3b0] pjje, _fipp_, _rnun, тнас, 
   {{0x88a0168d,0x26c4098d,0x00000000,0x00000000}},	//   _پیرۆ, ćno_, --, --, 
   {{0xe9dc067c,0x2d9c00c7,0xe5040137,0x00000000}},	//   spús_, iete_, ربئي, --, 
   {{0xdb0401ab,0x94746c6e,0x7e681347,0x27fc1bce}},	//   _iniò, ادلا, ysep, _ñun_, 
   {{0x63b80334,0x2ec85444,0xd1b8150e,0x82a4009d}},	//   _vnun, िहोत, کانا_, талж, 
   {{0x67f801b8,0x7e680175,0xeb9c005c,0xab5803e0}},	//   bäjä, vsep, lnød_, rküy, 
   {{0x2d9d273e,0x6289273f,0x7e680175,0xb6380150}},	//   dete_, stgo, wsep, _ﺘﺭ_, 
   {{0x63b92740,0x7e692741,0xac74001f,0x00000000}},	//   _unun, tsep, _በሰላም_, --, 
   {{0x2d9d2742,0x7e6839ed,0x7f48503f,0x88d400fe}},	//   fete_, usep, rceq, _হেমক, 
   {{0x81f88c6b,0x63e401e2,0x23b80241,0x3eb80419}},	//   _غفار_, _غېږې_, bàjà_, ťsto_, 
   {{0xefb801f3,0x00000000,0x00000000,0x00000000}},	//   ታንያ_, --, --, --, 
   {{0x3a3806d1,0xe73c001e,0x7e6800c5,0xaf5400c7}},	//   _sipp_, _ngõ_, psep, _анцә, 
   {{0x2d9d2743,0x3a380194,0xee2c36ca,0x4ea400f3}},	//   bete_, _pipp_, _вн_, _брја, 
   {{0x2d9c03c6,0x4ce0015b,0x00000000,0x00000000}},	//   cete_, _ফখরু, --, --, 
   {{0x98b800da,0x7c64f4ef,0x3a38072b,0x00000000}},	//   mbrī_, _شاغل, _vipp_, --, 
   {{0xbb74030d,0x67f80108,0x00000000,0x00000000}},	//   _рукъ, väjä, --, --, 
   {{0x3a38e93d,0x14c804fb,0x3a24311b,0xba252576}},	// [1c3c0] _tipp_, کهای_, _имиг, _идик, 
   {{0x67f80664,0x38680162,0xbbe0000d,0xdb040210}},	//   täjä, psbr_, _पतुक, _wnió, 
   {{0xe5a01b6d,0x80a00034,0xdb0401ab,0x741400f2}},	//   рихи, _कैले, _gniò, پوشا, 
   {{0xdb051291,0x67f8adae,0x256c013d,0xeb9c03cd}},	//   _unió, räjä, _añlı_, fløy_, 
   {{0x2d9d2744,0xeb9c0158,0x92940faa,0xe7340117}},	//   yete_, gløy_, уалц, _афрӯ, 
   {{0x7654005b,0xfe780118,0xe7340108,0x00000000}},	//   mpyy, drů_, _шея_, --, 
   {{0xef380020,0x765401f4,0xe6140064,0x00000000}},	//   _የኢኮኖ, lpyy, _рдр_, --, 
   {{0xe3b40b3b,0x4c940131,0xfe7801ef,0x00000000}},	//   _ибс_, қимс, frů_, --, 
   {{0xa3a92745,0x7d1c03be,0x425004d3,0xdb040086}},	//   _कोट_, əssi, _هۆنر, _oniñ, 
   {{0xf8d001bc,0x00000000,0x00000000,0x00000000}},	//   सहाय, --, --, --, 
   {{0x2d9d2746,0xd24c01d9,0xa0a00107,0x2084030d}},	//   rete_, _بۆڈ_, _вахд, _айхи_, 
   {{0x2d9d2747,0xd174005e,0xdfcd042c,0xdb052748}},	//   sete_, _шығы, _ويل_, _aniñ, 
   {{0xb92803d1,0x80a800fe,0xceb800fd,0xca3401ec}},	//   _tatỳ_, কমণ্, _чәй_, _ﯗﻻﺭ_, 
   {{0x2d9d03e0,0x00000000,0x00000000,0x00000000}},	//   qete_, --, --, --, 
   {{0xc6900125,0x6d592749,0x69c00100,0x4c940354}},	//   _ምርመራ_, mbta, _ònem, _сийс, 
   {{0x9f5c0ffb,0x6d580024,0x58d402bf,0x67500022}},	//   gnuè_, lbta, шост, рнаӡ, 
   {{0xd839274a,0x6d582860,0x00000000,0x00000000}},	// [1c3d0] тэр_, obta, --, --, 
   {{0x5695274b,0xdc000490,0x6d580009,0xeb9c01bf}},	//   рафт, ोकॅड_, nbta, snød_, 
   {{0x6d580014,0x99d4038b,0x437400f7,0x6d4c0205}},	//   ibta, _ختيا, гулт, ıbah, 
   {{0xeb9c05ac,0xd4980818,0x00000000,0x00000000}},	//   tløy_, ъру_, --, --, 
   {{0x442800e2,0x00000000,0x00000000,0x00000000}},	//   ķa_, --, --, --, 
   {{0x41283cb4,0xe450072d,0xd5b80354,0x00000000}},	//   ноло_, _نضر_, _исс_, --, 
   {{0xb3d424ce,0x51846885,0x6d5801c3,0x00000000}},	//   _өйрә, руча, dbta, --, 
   {{0xfe780316,0xa3a80034,0x826400f2,0x6d580064}},	//   trů_, _कोच_, _مهرن, ebta, 
   {{0x5de000d1,0x00000000,0x00000000,0x00000000}},	//   ийиғ, --, --, --, 
   {{0xd1b91bae,0x92580364,0x629800e4,0x00000000}},	//   _لاما_, _рафт_, _ipuo, --, 
   {{0xd084023a,0x00000000,0x00000000,0x00000000}},	//   _вычи, --, --, --, 
   {{0x6d583284,0x765401f4,0xc02000fe,0x00000000}},	//   abta, ypyy, _পূৰণ_, --, 
   {{0x5e600137,0xe73c0254,0xf410010f,0x00000000}},	//   _ئنتە, _eaõk_, מפט_, --, 
   {{0x201d004a,0x00000000,0x00000000,0x00000000}},	//   llui_, --, --, --, 
   {{0x26cc0793,0xdb0400d8,0x77940798,0x00000000}},	//   ägon_, _baiã, лјац, --, 
   {{0xb6a42dbe,0x201c01f5,0x00000000,0x00000000}},	//   либл, nlui_, --, --, 
   {{0x57a40184,0x00000000,0x00000000,0x00000000}},	// [1c3e0] лыҡҡ, --, --, --, 
   {{0x68f0002d,0x3eb8005b,0x59b401c6,0xeb9c01bf}},	//   ûddû, ästy_, _төмс, rnøe_, 
   {{0x7654005b,0x629812c4,0x201c0153,0x00000000}},	//   spyy, _apuo, klui_, --, 
   {{0xe5a004a9,0xf7480451,0x765401f4,0x00000000}},	//   _қиси, _ڪجھه_, ppyy, --, 
   {{0x6d5801d9,0xf6d40024,0x00000000,0x00000000}},	//   ybta, _сіня, --, --, 
   {{0xf12400d6,0xb0300032,0xc5d400c0,0x00000000}},	//   льйо, әмиә, _кісь, --, 
   {{0x764403f0,0xd0100be2,0x201c0115,0x644000ae}},	//   _huky, يلت_, flui_, ínit, 
   {{0xddc801fa,0x76440a49,0x4fd4de2f,0x70240014}},	//   _ćiši, _kuky, ржит, درتٕ, 
   {{0x7305274c,0x76440124,0x2bacd9e5,0x00000000}},	//   _спаз, _juky, _जोगा, --, 
   {{0x2051274d,0x27100016,0x76442252,0x201d274e}},	//   штәр, ệng_, _muky, alui_, 
   {{0x4c945882,0x7645274f,0xdd945aba,0xdb041f60}},	//   шинс, _luky, ушы_, _snið, 
   {{0x201c0261,0xee852750,0x8c440032,0x6d580009}},	//   clui_, _быко, леүе, sbta, 
   {{0x76440083,0x00000000,0x00000000,0x00000000}},	//   _nuky, --, --, --, 
   {{0x3eb800b5,0xf400054e,0x6ca4009b,0x00000000}},	//   æste_, liţă_, _бриж, --, 
   {{0x776401a9,0x91780208,0xfca801ec,0x00000000}},	//   _bekx, _mời_, _асық_, --, 
   {{0xd7f895de,0xb88406ed,0x76442252,0xf4000311}},	//   гуу_, _suíç, _buky, niţă_, 
   {{0x052000cc,0x00000000,0x00000000,0x00000000}},	// [1c3f0] _বলেৰ_, --, --, --, 
   {{0xd7f80032,0xdce0010f,0xf4000356,0xf41c00cc}},	//   _ҡуя_, _senĉ, hiţă_, _বংগৰ_, 
   {{0xd618581f,0x56952751,0x62992752,0x80d80154}},	//   اتقا_, _қарт, _spuo, _ভেন্, 
   {{0x43952753,0x76440332,0xd04803b9,0xb6040171}},	//   радс, _fuky, _ölər, ekšā, 
   {{0x76440337,0x27280241,0x01642083,0xf4000356}},	//   _guky, _dòní_, акло, diţă_, 
   {{0xf6780bd9,0xbbe00073,0x6f9c0150,0x00000000}},	//   _באשמ, _पत्क, _ﺃﻤﻨﺎ_, --, 
   {{0xc0e480df,0x27280248,0x53340150,0x00000000}},	//   ройк, _fòní_, _ңест, --, 
   {{0x201c084c,0x6564007c,0x764402d0,0x13a80133}},	//   ului_, _hejh, _yuky, _مۆمی_, 
   {{0x442d2754,0x64452755,0x201c0194,0xc1d004b4}},	//   _ihe_, _huji, rlui_, _мөкә, 
   {{0x644416cb,0xef152756,0x201c084c,0x442c3132}},	//   _kuji, рмь_, slui_, _hhe_, 
   {{0x65652757,0x442d2758,0xf4000356,0x7dcc00e5}},	//   _mejh, _khe_, biţă_, _kúsz, 
   {{0x644405d9,0xca280375,0x65640135,0x00000000}},	//   _muji, _חם_, _lejh, --, 
   {{0xed4d2759,0x442c0451,0xfc48001e,0x4a75275a}},	//   _мо_, _mhe_, _bậc_, йырт, 
   {{0x442c03b7,0x6564012c,0x7645275b,0x00000000}},	//   _lhe_, _nejh, _ruky, --, 
   {{0x442d275c,0x67e0007d,0x644401a4,0xdc5010e5}},	//   _ohe_, _sõja, _nuji, _ارتک, 
   {{0x76440bf1,0x442d275d,0x917801fb,0x00000000}},	//   _puky, _nhe_, _mới_, --, 
  
   {{0x64440589,0xfaa425ec,0x6565275e,0xb88001ef}},	// [1c400] _auji, _тапо, _bejh, _šídl, 
   {{0x442d275f,0xdb041709,0x6614005a,0xb6a401ec}},	//   _ahe_, _gaiá, goxk, лиұл, 
   {{0x656401e4,0xa9780375,0x91780051,0x00000000}},	//   _dejh, _באיכ, _rời_, --, 
   {{0x442d2760,0x76440a49,0x64452761,0xddd804a7}},	//   _che_, _tuky, _duji, jtuž, 
   {{0x442d2762,0x31c406bb,0x656401d3,0x66140009}},	//   _dhe_, искв, _fejh, boxk, 
   {{0x442c0924,0x6444105c,0xc5692763,0x217400ee}},	//   _ehe_, _fuji, _محفل_, айшы_, 
   {{0x6444198f,0x442d2764,0xf4000311,0x27280241}},	//   _guji, _fhe_, tiţă_, _tòní_, 
   {{0x442d2765,0x06cc015b,0x7414feab,0x5f4000d1}},	//   _ghe_, _রেটি, _ئورا, ينىل, 
   {{0xf4000311,0x65640978,0x00000000,0x00000000}},	//   riţă_, _yejh, --, --, 
   {{0xf1a803e6,0x2d8803ee,0x6444037e,0x442c01e7}},	//   _جاره_, übe_, _yuji, _zhe_, 
   {{0xa5b400c8,0xdfcc05d9,0x64440332,0x442c000d}},	//   בליק_, _ڪين_, _xuji, _yhe_, 
   {{0xdb040077,0x491000af,0xec140ce8,0x00000000}},	//   _saiá, _दुगो_, ремә_, --, 
   {{0xdfcc0740,0xe944009d,0x00000000,0x00000000}},	//   _تين_, ихво, --, --, 
   {{0xdd8c4d49,0xdcf52766,0x26cc0793,0x00000000}},	//   _يون_, اریش_, ägom_, --, 
   {{0x9848156b,0xed3401c0,0x5a340006,0x65640200}},	//   ията_, _тэдэ, інст, _rejh, 
   {{0x64452767,0x656474ff,0xe7240212,0xaae400e5}},	//   _ruji, _sejh, аєзн, _نسخو, 
   {{0x06cc00bd,0x64452768,0x442c0218,0xf8b40032}},	// [1c410] _রেজি, _suji, _rhe_, _һөт_, 
   {{0x442d2769,0x64442ebc,0x6564014f,0xddd80118}},	//   _she_, _puji, _qejh, ztuž, 
   {{0x442d276a,0x6564005c,0xa8a400d8,0x00000000}},	//   _phe_, _vejh, _трпк, --, 
   {{0x6565276b,0x6445276c,0x442c01d4,0x644000cf}},	//   _wejh, _vuji, _qhe_, íniq, 
   {{0x442c1aa1,0x64440198,0x6fb80073,0x00000000}},	//   _vhe_, _wuji, _शोधू, --, 
   {{0x6445276d,0x442d276e,0xdcec013a,0x00000000}},	//   _tuji, _whe_, _řečn, --, 
   {{0x442c6114,0xd1780006,0x7dcc00e5,0x00000000}},	//   _the_, рсіі_, _túsz, --, 
   {{0x442d276f,0x9178001e,0x00000000,0x00000000}},	//   _uhe_, _với_, --, --, 
   {{0x3eb92770,0xfe7000c6,0x6e90007b,0xfec800f1}},	//   íst_, أدب_, كليا, ابعو_, 
   {{0x5ca05a05,0x9178004d,0xddd80419,0x91e40063}},	//   ەلگە, _tới_, stuž, _дође, 
   {{0xf0780116,0x40e40032,0xddd816a3,0xddc400e5}},	//   _бихә_, _усағ, ptuž, áműz, 
   {{0xbdd40150,0xdbc40022,0x00000000,0x00000000}},	//   _ﺘﻠﻌﻔ, цамҩ, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xddd8003d,0xed544358,0x84f80037,0x6d4c002e}},	//   ntuż, _лош_, ्पाट_, ñbat, 
   {{0xc8b52771,0xdce00024,0xac540798,0x00000000}},	//   осты, _kenč, _лајф_, --, 
   {{0xdce0007f,0x30d8008f,0x4758005b,0x00000000}},	//   _jenč, אַמע, ируя_, --, 
   {{0xdce00064,0x00000000,0x00000000,0x00000000}},	// [1c420] _menč, --, --, --, 
   {{0xdce01aff,0x29101d0e,0xe7340150,0x00000000}},	//   _lenč, ánað_, сеу_, --, 
   {{0x7bd52772,0x387c0841,0x37340214,0x00000000}},	//   _koyu, štrb_, _گردآ, --, 
   {{0xdb0400d8,0x289800df,0x00000000,0x00000000}},	//   _caiç, _גיטא, --, --, 
   {{0x7bd52773,0x00000000,0x00000000,0x00000000}},	//   _moyu, --, --, --, 
   {{0xb9d002d3,0xdb0400d8,0x7bd40241,0x00000000}},	//   _ድአ_, _uniõ, _loyu, --, 
   {{0xdb04068c,0xdce00010,0x7c680023,0xaa78010e}},	//   _faiç, _benč, ተብህል_, myýe, 
   {{0xa854025f,0x7bd40fec,0xd010036b,0x32440006}},	//   זיקה_, _noyu, بلب_, _геаг, 
   {{0x5f700137,0x43740261,0x6dc401d5,0x232400f3}},	//   ساير, _фуст, مزدل, _готи_, 
   {{0x7bd402d0,0x06cc00fe,0x00000000,0x00000000}},	//   _aoyu, _ৰেডি, --, --, 
   {{0x7bd4a2d4,0xe040010a,0xfdc80150,0x00000000}},	//   _boyu, _енхи, ртық_, --, 
   {{0x96000729,0x7bd52774,0x0b4400f7,0x0ed801ed}},	//   ্তিম_, _coyu, өнүн, _پاؤں_, 
   {{0xda783e1f,0x7bd52775,0xcfe800f1,0xaa780432}},	//   йяр_, _doyu, _مځکه_, kyýe, 
   {{0xaa780432,0x00000000,0x00000000,0x00000000}},	//   jyýe, --, --, --, 
   {{0xaa780209,0x7bd4002e,0xfc48001e,0x19591f3a}},	//   dyýe, _foyu, _hận_, сасы_, 
   {{0xdb040793,0x7bd400ee,0xb7c400d1,0x176800db}},	//   _baiä, _goyu, оруқ, йруп_, 
   {{0xdb040ba1,0x9f5c0066,0x3f940055,0x00000000}},	// [1c430] _raiç, érék_, _åcuũ_, --, 
   {{0xfc48004d,0xaa780432,0x00000000,0x00000000}},	//   _mận_, gyýe, --, --, 
   {{0xfc4801fb,0x7bd400e8,0x00000000,0x00000000}},	//   _lận_, _yoyu, --, --, 
   {{0x69d418f7,0x78f80375,0x321c44ef,0x00000000}},	//   _hoxe, _כפתו, _akty_, --, 
   {{0x69d4058a,0xdce0a7ab,0xd6840334,0xddd8025c}},	//   _koxe, _renč, _нурп, ttuż, 
   {{0x69d52776,0xdce12777,0x00000000,0x00000000}},	//   _joxe, _senč, --, --, 
   {{0x69d40784,0x7050004b,0x00000000,0x00000000}},	//   _moxe, ونوا, --, --, 
   {{0xfc48001e,0x69d400db,0xc8340023,0xe1f0a638}},	//   _bận_, _loxe, _በብእዋ, _کسر_, 
   {{0xe1640bbd,0xdce00640,0xfc480016,0xfde92778}},	//   _هداي, _venč, _cận_, идик_, 
   {{0x7bd493ba,0x69d52779,0xfc480208,0x00000000}},	//   _soyu, _noxe, _dận_, --, 
   {{0x2d8c030d,0x7bd400e8,0x2cac0306,0xdce0013a}},	//   _dcfe_, _poyu, _csfd_, _tenč, 
   {{0x7bd40cc1,0x2d8c0332,0xdfcc00ec,0x00000000}},	//   _qoyu, _ecfe_, _ڪيچ_, --, 
   {{0x2b140307,0xbe680276,0x00000000,0x00000000}},	//   _धुआँ_, _талж_, --, --, 
   {{0xfce40371,0x69d4cdcf,0xa964cb13,0x3f9c0175}},	//   _моло, _coxe, жира_, _hbwu_, 
   {{0x69d40de2,0x7bd5277a,0x5c040150,0x00000000}},	//   _doxe, _toyu, _ىكتە, --, 
   {{0x3ea80232,0xb8d005d7,0x00000000,0x00000000}},	//   _šaty_, _टन_, --, --, 
   {{0x69d43d19,0xec100594,0x46642440,0x00000000}},	// [1c440] _foxe, _تويد, _ፎቶግራ, --, 
   {{0x7c240250,0x00000000,0x00000000,0x00000000}},	//   llkr, --, --, --, 
   {{0xf7447391,0xf348084c,0xb4a80798,0x00000000}},	//   _мено, апел_, ркез_, --, 
   {{0xded80023,0x15b801ec,0xc8c801c8,0x00000000}},	//   ንሐን_, шығы_, _اوٽن_, --, 
   {{0x7a30005c,0xe29400f0,0x00000000,0x00000000}},	//   rætf, жач_, --, --, 
   {{0x7c24c957,0x69d4036e,0xfc480208,0xf1a8009a}},	//   hlkr, _xoxe, _rận_, شاته_, 
   {{0x73e46bb8,0xa5040408,0x00000000,0x00000000}},	//   _довз, _дера_, --, --, 
   {{0x9f5c0ffb,0xe0cc0451,0xd01000ae,0xfc480092}},	//   gnuà_, ئزو_, علة_, _አሰፋፈ, 
   {{0x3ebc0142,0xeda5277b,0x00000000,0x00000000}},	//   _crwt_, ошно, --, --, 
   {{0xfc480016,0x799c02d0,0x7c240129,0x6fb807af}},	//   _vận_, _nbpw, elkr, _शोरू, 
   {{0x61400162,0x00000000,0x00000000,0x00000000}},	//   rílø, --, --, --, 
   {{0xfc480016,0x69d400e8,0x2ec41ec7,0x614003b2}},	//   _tận_, _soxe, _وقاف, sílø, 
   {{0x2fc5277c,0xdef5277d,0x3ebc0142,0x6438010f}},	//   _inog_, _мыш_, _grwt_, יעטנ, 
   {{0x7c2401f5,0xddc00212,0xaa14010e,0x12d800fe}},	//   alkr, _обчи, _ösüš_, _দেৱদ, 
   {{0x2fc400b5,0x57a800d1,0xe7680798,0x00000000}},	//   _knog_, ﺷﻠﯩﺮ, ијак_, --, 
   {{0x7df8012c,0xe4c8a638,0x00000000,0x00000000}},	//   yňsk, یبان_, --, --, 
   {{0x5695277e,0xdce000da,0xdb040086,0x69d40077}},	// [1c450] матт, _ienā, _maiû, _toxe, 
   {{0x9aa401ed,0x387c2230,0x05940214,0x9a4801d9}},	//   _کمیو, štra_, ثارگ, _گٔیم_, 
   {{0x2fc41326,0x0ce8009e,0xdce000cd,0x89d81d10}},	//   _onog_, _পশুত, _kenā, _نوکر_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xaac83347,0xdce00055,0x66c801c4,0x00000000}},	//   ामिक, _menā, _тунг_, --, 
   {{0x2fc4022e,0x41740137,0x00000000,0x00000000}},	//   _anog_, ساتس, --, --, 
   {{0xd244084c,0x4dd000cc,0xb22001c6,0x3c3000d7}},	//   фэци, িসাং, эмшл, láve_, 
   {{0xc0740092,0xdce01c52,0xaac80e85,0x0fe4004e}},	//   _ሊደረግ, _nenā, ामाक, мөчү, 
   {{0xc32805d9,0x00000000,0x00000000,0x00000000}},	//   _اڃان_, --, --, --, 
   {{0x606000d1,0xc0f80023,0x00000000,0x00000000}},	//   _قۇتل, ላሰል_, --, --, 
   {{0xd1b80e56,0x7c94007b,0xbb48006c,0x00000000}},	//   _باقا_, أشخا, یلگن_, --, 
   {{0xfaa40953,0xdce0005f,0xf33400b8,0x3c3000d7}},	//   памо, _cenā, _ukṣā_, káve_, 
   {{0xef0c023a,0x799c03ac,0x7c24007c,0x00000000}},	//   _чм_, _pbpw, rlkr, --, 
   {{0x3eac08e7,0x504800db,0xfc480208,0x00000000}},	//   mwet_, _اجەپ_, _hậm_, --, 
   {{0xdce00270,0x3eac017a,0xce340345,0x6d4c0419}},	//   _fenā, lwet_, _تووک, žbac, 
   {{0x3f8d277f,0xdb04617f,0xdce000ef,0xddd00210}},	//   ngeu_, _maiú, _genā, żańc, 
   {{0xe7352780,0x29100429,0x3eac27bb,0x2c092781}},	// [1c460] зет_, _exxa_, nwet_, _دعوی_, 
   {{0x27302f7c,0x3eac002d,0x80bc20f0,0x00000000}},	//   رىلس, iwet_, ्माइ, --, 
   {{0xb4d400bc,0xdce000dc,0x00000000,0x00000000}},	//   ाङे_, _yenā, --, --, 
   {{0x3eac0295,0x53980212,0xc3140154,0xfc480208}},	//   kwet_, івля_, ়েছি_, _nậm_, 
   {{0x3f8c01a6,0x98b83361,0x62600f1a,0x5fbc0073}},	//   dgeu_, marı_, евча, _शोधल, 
   {{0x98b812ca,0x63000137,0x2fc445b9,0x5eec00bc}},	//   ları_, عوول, _snog_, इनन्_, 
   {{0x3eac00b5,0x05c8d013,0x00000000,0x00000000}},	//   ewet_, रारब, --, --, 
   {{0x98b82ed0,0x93c80014,0x3f8c002e,0xc0a8007b}},	//   narı_, _باسہ_, ggeu_, تاهل_, 
   {{0xb8cc1efe,0x3eac017a,0xddcc0010,0xdce000e2}},	//   _ནག_, gwet_, _šešo, _renā, 
   {{0xdce0198e,0x98b81432,0x00000000,0x00000000}},	//   _senā, harı_, --, --, 
   {{0x98b82fbe,0x66e00ca8,0xa2340022,0xdce00171}},	//   karı_, _kíkú, _хьтә, _penā, 
   {{0x3eac0428,0x2d80247e,0xa0300150,0x00000000}},	//   bwet_, şke_, _كىلت, --, 
   {{0x98b81ae4,0xdfcc00c6,0x7f5402dd,0x00000000}},	//   darı_, _حين_, _ﺤﺎل_, --, 
   {{0xdd8c6a3b,0xdd9000c0,0x00000000,0x00000000}},	//   _موه_, _зашы, --, --, 
   {{0x59f92782,0x6d4814dc,0xdb040428,0xdce00882}},	//   черя_, _igfa, _maiù, _tenā, 
   {{0x25bc0598,0x98b80724,0x3c3000e4,0x00000000}},	//   _şul_, garı_, táve_, --, 
   {{0xe6640064,0x00000000,0x00000000,0x00000000}},	// [1c470] ятво, --, --, --, 
   {{0x3c300030,0x00000000,0x00000000,0x00000000}},	//   ráve_, --, --, --, 
   {{0x98b80add,0xdcf000f3,0xc7880023,0x9968010f}},	//   barı_, ćaće, _ዝጽውዑ_, _מייַ_, 
   {{0x67544667,0x3eac017a,0x7a3001bf,0x7e6c010e}},	//   _ریئس_, ywet_, ræte, _çapg, 
   {{0xfc48004d,0x6d4803ac,0x7a3008fb,0x82342cc6}},	//   _rậm_, _ogfa, sæte, ورتا, 
   {{0xd8740272,0xed44034c,0xfc480208,0x11e401ec}},	//   _تایب, _لپ_, _sậm_, нжім, 
   {{0x3c140270,0x3f8c00cf,0x63e00150,0x50580006}},	//   lāve_, tgeu_, _كيسە, пшыя_, 
   {{0x560000bd,0x7e7d2783,0x7ff52784,0x9f4c5522}},	//   ্তৃক_, áspo, بستا, _omgå_, 
   {{0x63a92785,0xe660010e,0xe0cc00e5,0x00000000}},	//   megn, _öläý, ئزڈ_, --, 
   {{0x98b81ae6,0x3ead2786,0xdce00356,0x7d080063}},	//   zarı_, rwet_, _nenă, жног_, 
   {{0x62892787,0x3eac1a7c,0x98b806b9,0xbd441e5a}},	//   lugo, swet_, yarı_, بندي, 
   {{0x6b8c074d,0x98b800ac,0x63a805d5,0x3eac017a}},	//   ggcg, xarı_, negn, pwet_, 
   {{0x62892788,0xbdf92789,0xaa780209,0x201c03a0}},	//   nugo, _ورتا_, tyýa, moui_, 
   {{0x63a80c86,0x201d278a,0xeb3401d3,0x00000000}},	//   hegn, loui_, برپخ, --, 
   {{0x63a80770,0x98b86f38,0xaa40c893,0x62886222}},	//   kegn, tarı_, терл, hugo, 
   {{0x6b8c074d,0x201c9ec6,0x63a80098,0x601400e4}},	//   cgcg, noui_, jegn, tãmy, 
   {{0x98b84947,0x6289278b,0xdb08023a,0xddd80356}},	// [1c480] rarı_, jugo, öläi, cruţ, 
   {{0xf989278c,0x628829ef,0x98b80598,0xe88c02d3}},	//   _بندي_, dugo, sarı_, _ዝፍጸም_, 
   {{0x7c340649,0x201c06c8,0xec109a12,0x39580356}},	//   _khyr, koui_, _سوید, _ifps_, 
   {{0x63a9278d,0x6288d02e,0xbf1c0073,0x201c0129}},	//   gegn, fugo, _पडून_, joui_, 
   {{0x201c0333,0x6289278e,0x00000000,0x00000000}},	//   doui_, gugo, --, --, 
   {{0xba00067d,0x63a80037,0x00000000,0x00000000}},	//   _ግና_, aegn, --, --, 
   {{0x63a9278f,0x201c0129,0x628800de,0x7c3401e3}},	//   begn, foui_, augo, _ohyr, 
   {{0x62892790,0x7c3400ad,0xceb82abf,0x00000000}},	//   bugo, _nhyr, зәк_, --, 
   {{0x7158033a,0xeea800d4,0x0ba40124,0x00000000}},	//   _дрес_, ітик_, ҭымҭ, --, 
   {{0x7c340209,0x39592791,0xc1800050,0x4d980212}},	//   _ahyr, _nfps_, _میٖٹ, чкою_, 
   {{0x6b8c074d,0xdce00356,0x1d040798,0x00000000}},	//   tgcg, _renă, деќи_, --, 
   {{0x7c352792,0xa06423be,0x2ee4009b,0x00000000}},	//   _chyr, _цаца_, _ожег, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x63a92793,0x395800db,0x00000000,0x00000000}},	//   zegn, _cfps_, --, --, 
   {{0x6288037e,0xefb80023,0xfaec00f1,0x00000000}},	//   zugo, ታሕዙ_, لګی_, --, 
   {{0x2d9d2794,0x62892795,0x3c1400e2,0x00000000}},	//   lfte_, yugo, tāve_, --, 
   {{0x63a92796,0x2d9c208d,0xc6f800a7,0x1dc0004e}},	// [1c490] vegn, ofte_, чнах_, _чөөн, 
   {{0x62892797,0x2d9c0e78,0x05c800e1,0x0cd0015b}},	//   vugo, nfte_, राइब, ানীত, 
   {{0x29052798,0x62892799,0x2d9c5b0a,0x21e803cd}},	//   _äna_, wugo, ifte_, _bøhn_, 
   {{0x62884511,0x49680345,0x00000000,0x00000000}},	//   tugo, _بشکێ_, --, --, 
   {{0x63a83570,0x3c31279a,0x201c19a2,0x26cc0250}},	//   regn, náva_, voui_, ågod_, 
   {{0x63a9279b,0x6289279c,0xd378013d,0xe4a400f3}},	//   segn, rugo, пчә_, _орбо, 
   {{0x63a9279d,0xd1b88d4e,0x6289279e,0x3c30035b}},	//   pegn, بانا_, sugo, háva_, 
   {{0x3c3109f7,0x6289279f,0x2d9c002f,0xee34035b}},	//   káva_, pugo, efte_, ҽны_, 
   {{0x6288013c,0x2d9c17da,0x3c30035b,0x00000000}},	//   qugo, ffte_, jáva_, --, 
   {{0xb8e00c99,0xee3527a0,0x6b800325,0x7c340649}},	//   _གླ_, нны_, _ēnga, _shyr, 
   {{0x7c3403a2,0xfce44c0d,0x201c03a0,0xfc0403cf}},	//   _phyr, хоно, poui_, епно, 
   {{0xca28025f,0x2d9d27a1,0x443c01f5,0x2d980205}},	//   _הם_, afte_, nmw_, _öpen_, 
   {{0x3c3127a2,0x2fd404d3,0xbea527a3,0xac941a4b}},	//   gáva_, _سوود_, _чалк, ونیا_, 
   {{0x67e0007d,0xb8641d93,0x443c01bf,0xddd90928}},	//   _mõju, فارو, hmw_, bruš, 
   {{0x16c927a4,0x7c342b00,0x3c300124,0x7a3002d2}},	//   रम्ब, _thyr, aáva_, gæta, 
   {{0x7c3428b3,0x2dd000c7,0x3c306711,0x00000000}},	//   _uhyr, _ажәр, báva_, --, 
   {{0xdca0044c,0x225cf169,0xd7c40490,0x9ba40150}},	// [1c4a0] _чақи, _ntuk_, _लोणच, _كەگى, 
   {{0x7a3003f2,0x15b400d1,0xfdac00cc,0x00000000}},	//   bæta, خەسس, _কচুড, --, 
   {{0x225c2a1f,0x7ae527a5,0xb38527a6,0x14c800f2}},	//   _atuk_, lykt, елел, بهای_, 
   {{0xaa7800a2,0xfe7801ef,0x00000000,0x00000000}},	//   kyýl, ksů_, --, --, 
   {{0xddd802f0,0xe36011eb,0x2d9c01e3,0x66e0014b}},	//   zruš, укчи, yfte_, _бояа, 
   {{0x237c009a,0x7774022e,0x00000000,0x00000000}},	//   _eduj_, layx, --, --, 
   {{0x225d27a7,0xa23400c7,0xe5a000d4,0x3c3000d7}},	//   _etuk_, хьцә, _щири, záva_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xab5803db,0x71a40153,0x00000000,0x00000000}},	//   ldüg, _пааз, --, --, 
   {{0x3c3127a8,0x7ae527a9,0xeabc011c,0x2d9c0e78}},	//   váva_, dykt, vvù_, ufte_, 
   {{0x6f6527aa,0x2d9c09dc,0xa0642081,0x93f40073}},	//   _звез, rfte_, _заха_, _आताच_, 
   {{0x3c3109f7,0x7ae4000f,0x00000000,0x00000000}},	//   táva_, fykt, --, --, 
   {{0xee3920f2,0x2d9c0e78,0xdee00354,0x0cd000eb}},	//   _енд_, pfte_, _йоци, ানেত, 
   {{0x3c3127ab,0x3e7c0055,0xdce00153,0xabb00022}},	//   ráva_, _dåtā_, _seną, _ӡакә, 
   {{0x3c30035b,0x00000000,0x00000000,0x00000000}},	//   sáva_, --, --, --, 
   {{0xfcc00184,0x6d5927ac,0x3c300124,0xfd4400c0}},	//   _тәьм, lcta, páva_, _рэін, 
   {{0x7d2000dd,0x9220134e,0x00000000,0x00000000}},	// [1c4b0] _مہین, मकाज_, --, --, 
   {{0x6d5927ad,0x1a688df6,0x00000000,0x00000000}},	//   ncta, _سیفی_, --, --, 
   {{0x225c3441,0x6d58003a,0x84240116,0x00000000}},	//   _stuk_, icta, پىشن, --, 
   {{0x387c004a,0xd3b802dd,0xc1e80014,0xd4980024}},	//   âtre_, еуші_, ژکال_, эру_, 
   {{0x9394dbec,0x7800013e,0x99d40133,0xd498009d}},	//   اجما, _тӯра, _شتیا, _үрс_, 
   {{0x814527ae,0x96440209,0xd5b800f3,0x00000000}},	//   نچان, _бэсд, _псс_, --, 
   {{0x80bc06ab,0xa04416a0,0x70b000c6,0x657527af}},	//   ्में, ىكتە_, لموض, maxh, 
   {{0x6d5816b8,0x6d4c07f5,0xab5807c5,0x657401e3}},	//   ecta, žbal, ndüd, laxh, 
   {{0x6e900e5a,0x63b801c4,0x225d27b0,0x96c401ad}},	//   لليا, _iaun, _utuk_, रियॉ, 
   {{0x6d58074d,0x657402d3,0x63b927b1,0x7ae40024}},	//   gcta, naxh, _haun, vykt, 
   {{0xc0d527b2,0x20c400fd,0xe0841b45,0x44c000c0}},	//   _جياب, _ясаг, _سجاي, _jė_, 
   {{0x63b927b3,0x3b0900ed,0x7ae40158,0x6d580e89}},	//   _jaun, демо_, tykt, acta, 
   {{0x657400f1,0x44c000c0,0xab584dd9,0x00000000}},	//   kaxh, _lė_, ddüd, --, 
   {{0x77740054,0x7ae41f53,0x63b927b4,0x6d580309}},	//   wayx, rykt, _laun, ccta, 
   {{0x44c00006,0x7ae4002d,0xb7940114,0x8cc4010a}},	//   _nė_, sykt, краћ, _йĕрĕ_, 
   {{0x63b927b5,0xb8d80d5f,0x3c3000e4,0xba54014b}},	//   _naun, _आई_, mávo_, _итоъ, 
   {{0xeab527b6,0x657402d0,0x6d4c0205,0x00000000}},	// [1c4c0] _айы_, faxh, şhaş, --, 
   {{0xe7340046,0x63b80618,0x657527b7,0xdb040428}},	//   теу_, _aaun, gaxh, _maiü, 
   {{0x63b81c1d,0x629927b8,0x3c300022,0x2610000d}},	//   _baun, _aquo, návo_, _ददरी_, 
   {{0x63b927b9,0x44c00153,0xb284013d,0xab580bbc}},	//   _caun, _dė_, выкк, rdüg, 
   {{0x63b927ba,0x657527bb,0xab5804cc,0x3c300124}},	//   _daun, baxh, sdüg, hávo_, 
   {{0x3c30035b,0x30a400d8,0xa2b028fe,0x00000000}},	//   kávo_, врив, _इनर्, --, 
   {{0x63b927bc,0xfc480016,0x62981730,0x3c3000c7}},	//   _faun, _hậu_, _equo, jávo_, 
   {{0x63b8493b,0x3c300022,0x6d4c00d0,0x8f340024}},	//   _gaun, dávo_, ľbam, лейц, 
   {{0x6d58074d,0x91c40348,0x6d4c041a,0xfbd444af}},	//   tcta, _бәйл, žbam, धानम, 
   {{0x63b823db,0xfc48004d,0x00000000,0x00000000}},	//   _zaun, _mậu_, --, --, 
   {{0x63b927bd,0x6d5927be,0xfc4801fb,0x6ac8227c}},	//   _yaun, rcta, _lậu_, ाम्र, 
   {{0x68e40306,0x9f0007d6,0x6d580332,0x00000000}},	//   vyjd, اویو, scta, --, 
   {{0xa0300075,0x657401b3,0x37c803d4,0x7a3003b2}},	//   _ئىنت, yaxh, ৰসাৰ, rætn, 
   {{0x7a3004ce,0x7e6d27bf,0x4c941def,0x657400aa}},	//   sætn, _çapa, _бикс, xaxh, 
   {{0x195927c0,0xdb040005,0x3a3800d8,0x00000000}},	//   тасы_, _baió, _dhpp_, --, 
   {{0xdb040005,0x657401b3,0xfc480051,0x7a300d12}},	//   _caió, waxh, _bậu_, lætl, 
   {{0x63b927c1,0xfc480016,0x473527c2,0x44c000c0}},	// [1c4d0] _raun, _cậu_, унас, _sė_, 
   {{0x63b927c3,0xfc48004d,0x44c00064,0x00000000}},	//   _saun, _dậu_, _pė_, --, 
   {{0x65740240,0xd974009d,0x00000000,0x00000000}},	//   raxh, _өвөө, --, --, 
   {{0xc43400aa,0x6574afef,0x63b80ffb,0xab58002f}},	//   اکست, saxh, _qaun, ldüb, 
   {{0x63b927c4,0x3c3000c7,0x00000000,0x00000000}},	//   _vaun, závo_, --, --, 
   {{0x63b927c5,0xdb040086,0x6d4c1674,0x40943591}},	//   _waun, _kaiò, žbaj, грит, 
   {{0x63b927c6,0x83f8a20e,0xd49927c7,0x6454031c}},	//   _taun, _зевс_, _ирт_, qqxi, 
   {{0x9418013f,0xdb0527c8,0x00000000,0x00000000}},	//   _mprɛ_, _maiò, --, --, 
   {{0xfc4807ae,0x7a3002d2,0x00000000,0x00000000}},	//   _mật_, fætl, --, --, 
   {{0xfc4801fb,0x62880e3c,0x387c01a6,0x3c300124}},	//   _lật_, mrgo, štri_, távo_, 
   {{0xece405f5,0x9f5c0112,0x00000000,0x00000000}},	//   гдэл_, chuß_, --, --, 
   {{0x3f78010f,0x3c3046dc,0x00000000,0x00000000}},	//   _װאַס, rávo_, --, --, 
   {{0x7f940022,0xee2c0139,0xef6401c6,0x1ee41079}},	//   _ааҵх, _гн_, _сэхү, _جوشی_, 
   {{0x090403f4,0x3c300124,0x1db4954a,0x00000000}},	//   _শুধু_, pávo_, _असित, --, 
   {{0xfc4801fb,0x99e402fb,0x16840133,0x00000000}},	//   _bật_, šňov, ڤارێ, --, 
   {{0xfc48004d,0x00000000,0x00000000,0x00000000}},	//   _cật_, --, --, --, 
   {{0xa7a459b7,0x35a527c9,0xfc48004d,0xb6000118}},	// [1c4e0] ыкта_, лааг, _dật_, _ďábl, 
   {{0xdb04067c,0x7c2527ca,0xb8c80183,0x00000000}},	//   _faiò, lokr, _গছ_, --, 
   {{0xe5a00209,0x29980a1e,0x8914084c,0xafe00162}},	//   сихи, _אסימ, _вьяц, ðøki, 
   {{0xdb0400e4,0xfc48004d,0xd73800c7,0xeb9c0158}},	//   _haiñ, _gật_, _ацгә_, lnør_, 
   {{0x0cb05b99,0xf20465cb,0x6440068c,0x2b5c002e}},	//   _जन्म, ляко, ïnia, ñuci_, 
   {{0xdb040649,0x7c2402fb,0xeb9c383d,0x00000000}},	//   _jaiñ, hokr, nnør_, --, 
   {{0x7c2527cb,0x11f848ef,0x00000000,0x00000000}},	//   kokr, _یورک_, --, --, 
   {{0x764c00ca,0xdb040077,0x80d80eac,0xfc640240}},	//   _hiby, _laiñ, _ভেঙ্, _ዘሰጋግ, 
   {{0x764d27cc,0x00000000,0x00000000,0x00000000}},	//   _kiby, --, --, --, 
   {{0x3244af8e,0x764c0100,0xdb040124,0x30740006}},	//   _сезг, _jiby, _naiñ, _будс, 
   {{0x764c00ca,0x7a30022c,0x00000000,0x00000000}},	//   _miby, rætl, --, --, 
   {{0x6140023a,0x7c2527cd,0x7a3006ea,0x00000000}},	//   _уеха, gokr, sætl, --, 
   {{0xeb046baf,0xdb0401c6,0xceb801af,0x00000000}},	//   учно, _baiñ, _рәй_, --, 
   {{0x764c01aa,0x5a3402bf,0x00000000,0x00000000}},	//   _niby, йнят, --, --, 
   {{0x4c94f366,0x00000000,0x00000000,0x00000000}},	//   _тийс, --, --, --, 
   {{0x7c2406d8,0x9c60009f,0x00000000,0x00000000}},	//   cokr, _اهيو, --, --, 
   {{0xfc4807ae,0x8574035b,0x764c19e1,0x96e825ec}},	// [1c4f0] _vật_, илах, _biby, льфа_, 
   {{0x764c3657,0xdb04009d,0x00000000,0x00000000}},	//   _ciby, _gaiñ, --, --, 
   {{0x764d27ce,0x44b527cf,0xfc48001e,0x56940075}},	//   _diby, рбес, _tật_, _һаят, 
   {{0x62888ef1,0x9a6801ed,0x00000000,0x00000000}},	//   trgo, _جمیل_, --, --, 
   {{0xb7780677,0x569400d4,0xe28400d8,0x00000000}},	//   _בארש, _лаят, уѓен, --, 
   {{0x764c0337,0xf8a001d9,0x628927d0,0xdce0013a}},	//   _giby, _دۅہَ, rrgo, _ceně, 
   {{0x7988000f,0x51840816,0x00000000,0x00000000}},	//   _ôfwe, суча, --, --, 
   {{0x3fe402ee,0x764d27d1,0xd7d80490,0x25b40153}},	//   ржив, _ziby, डायच, šelį_, 
   {{0x764c0230,0xa18400fd,0xef0c00f1,0x53340f06}},	//   _yiby, _быел, وڼه_, _гетт, 
   {{0xd1b927d2,0x764c02b9,0xccf800bc,0x7c2402e2}},	//   _ماما_, _xiby, ybět_, wokr, 
   {{0xee3527d3,0xdb040005,0x7fd41cd0,0xfd10007b}},	//   рнэ_, _raiñ, _вілі, تجة_, 
   {{0xbb443129,0x7a3001bf,0x10e400db,0x00000000}},	//   иенк, rætm, _уюум, --, 
   {{0x7c2527d4,0xeab44965,0x1b040116,0xfaa42377}},	//   rokr, айя_, сүпн, јаго, 
   {{0x7e682939,0xed5407ee,0x7c2401ed,0x7e7c03b2}},	//   mpep, _кош_, sokr, áspu, 
   {{0x764c18f7,0x7e68143a,0x00000000,0x00000000}},	//   _riby, lpep, --, --, 
   {{0x764d27d5,0xb4d408dc,0x9f5c00f2,0xe5e4006c}},	//   _siby, یغات, èrèk_, یزلی, 
   {{0x7e680af9,0xdb0400e4,0x764cb5fd,0xfbd000f2}},	// [1c500] npep, _taiñ, _piby, _هتک_, 
   {{0x7e68ca22,0xfdf407f7,0xeaac00e5,0x00000000}},	//   ipep, इसिस_, _کٹی_, --, 
   {{0xf770007b,0x00000000,0x00000000,0x00000000}},	//   _واح_, --, --, --, 
   {{0x87540801,0xa87800c8,0x764c0223,0xa30800e5}},	//   _гърц, _באטר, _wiby, ھرنے_, 
   {{0x764d27d6,0xdce00316,0x23240063,0x366800d8}},	//   _tiby, _peně, аоци_, _јаго_, 
   {{0x387c01a6,0x7e68007c,0x00000000,0x00000000}},	//   štru_, dpep, --, --, 
   {{0x8554072d,0x00000000,0x00000000,0x00000000}},	//   _ایمر_, --, --, --, 
   {{0x73340131,0x68e00de2,0x7e68002f,0xa854011a}},	//   _نىزا, _ànde, fpep, סיפה_, 
   {{0x7e68079b,0x7e6c4e7e,0x386800d8,0xde7401af}},	//   gpep, _çapl, hpbr_, абыч_, 
   {{0xa2d00a2c,0xae7801c0,0xade40120,0x2eb41116}},	//   _بيكت, нсүх_, рцик, _अनीत, 
   {{0x9f5c0270,0x2bc000bc,0x00000000,0x00000000}},	//   siuá_, षयला, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xda7873e5,0x7d0c0882,0xfcc40022,0x6eb408de}},	//   ияр_, _śast, _ҳшыҟ, _خصائ, 
   {{0xdd900209,0x00000000,0x00000000,0x00000000}},	//   _дашы, --, --, --, 
   {{0x2eb40882,0xab8439c6,0xce34004b,0x1cb405af}},	//   _अनुत, _купк, _پوډک, _نايب_, 
   {{0x87540212,0x57f40a5b,0xd7f801c4,0x00000000}},	//   скає, опст, ауу_, --, 
   {{0xa5640efb,0xf1c4041c,0x7c2402d2,0x00000000}},	// [1c510] لدان, लयान, _íhra, --, 
   {{0x039401e0,0xfc480051,0x00000000,0x00000000}},	//   өҙгө_, _hập_, --, --, 
   {{0x090403f4,0xa48401d5,0xd4980022,0x00000000}},	//   _শুরু_, شجان, ирц_, --, 
   {{0x439527d7,0x668001d5,0x7e6802d0,0x00000000}},	//   садс, _ویزل, ypep, --, 
   {{0xfc4801fb,0xd6d800cf,0xb0600108,0x00000000}},	//   _mập_, _ктр_, äänh, --, 
   {{0xfc4807ae,0xc5a85e13,0x5ab8010f,0x2d880210}},	//   _lập_, _حُسن_, ילדע_, óbel_, 
   {{0x26c801a6,0x490c02ab,0xa2b001ad,0xd5b8005b}},	//   _hrco_, _डेमो_, _इनक्, _тся_, 
   {{0x73c0010b,0xfc48004d,0x7e68229b,0xbd8801b9}},	//   _нәче, _nập_, tpep, گندن_, 
   {{0x442d27d8,0x7e680b23,0x00000000,0x00000000}},	//   _ike_, upep, --, --, 
   {{0x442c1132,0x7e6927d9,0xe1f07e01,0x38680076}},	//   _hke_, rpep, _بسر_, ypbr_, 
   {{0x7e6927da,0x442c0429,0x6614005a,0xfc480208}},	//   spep, _kke_, inxk, _bập_, 
   {{0xfc4807ae,0x7e680b1a,0x26c90028,0x442c0072}},	//   _cập_, ppep, _orco_, _jke_, 
   {{0x442d27db,0xeb9406bb,0xfc4801fb,0x7a300252}},	//   _mke_, щия_, _dập_, læti, 
   {{0x7338010f,0x6d6000c7,0x00000000,0x00000000}},	//   טערס, ĩvaí, --, --, 
   {{0x442d27dc,0x7c940597,0xa96527dd,0xab580213}},	//   _oke_, _العص, сиса_, mdün, 
   {{0x442c3127,0x21cc02b5,0x260c005f,0xfc4801fb}},	//   _nke_, _hēhē_, kļos_, _gập_, 
   {{0xed1455b4,0x26c80327,0x160802dd,0x10a80150}},	// [1c520] _نہیں_, _crco_, амақ_, _ﺴﻴﺄﺨ, 
   {{0x442d27de,0xab5800ee,0xcd3400cf,0xe5a0020f}},	//   _ake_, ndün, _ارۇب, зифи, 
   {{0x442d27df,0xa9b8008d,0x26c80115,0xa9540375}},	//   _bke_, _גזיר, _erco_, _לייק_, 
   {{0xa6dc015b,0xfc480208,0x442cf6ae,0x00000000}},	//   _নেওয়, _xập_, _cke_, --, 
   {{0x1db402ab,0xe9840131,0x7a30005c,0x468001ec}},	//   _असंत, _ئاۋۋ, tæth, _оқта, 
   {{0xdce00115,0xbc98010c,0x88c400f2,0x3fc801b9}},	//   _senĝ, _ጉባኤና_, _اتیل, یگنی_, 
   {{0x8458084c,0x799c03ac,0x7a308ecc,0x7e6c00a2}},	//   _врут_, _mcpw, ræth, _çapj, 
   {{0x741527e0,0x442c01c4,0x437401c0,0x7a30143a}},	//   _اورا, _gke_, _муут, sæth, 
   {{0xdce0010f,0xfc48004d,0x048803e6,0x00000000}},	//   _venĝ, _rập_, _مڕۆی_, --, 
   {{0x22f40302,0xfc4801fb,0x7a3006ea,0xb638037e}},	//   _הזמן_, _sập_, bæti, _ｅｘ_, 
   {{0x70542b9f,0x442c00c7,0x4bb402e8,0x69c008a5}},	//   _انصا, _yke_, ойнс, _ónei, 
   {{0x442c0395,0x799c035a,0x320d27e1,0xc5f400dc}},	//   _xke_, _acpw, lify_, _इत्य_, 
   {{0xaf340150,0x799c03ac,0x2de40166,0x7e7c0153}},	//   _ارات, _bcpw, _гюйг, šspr, 
   {{0x320d27e2,0xa3cc07f7,0x2c0800fe,0x00000000}},	//   nify_, _वोन_, ৰতেই_, --, 
   {{0xfc4801dc,0x0dd40023,0x5a3400d4,0x00000000}},	//   _tập_, ርናፍ_, їнст, --, 
   {{0x320c4e13,0x26c80332,0x765801ef,0x00000000}},	//   hify_, _prco_, _čtyr, --, 
   {{0xf40c0c58,0x320c020c,0xfbd4024a,0xe6644df8}},	// [1c530] িকাৰ_, kify_, धारम, стбо, 
   {{0x442d27e3,0x6abc0135,0x26c8009f,0x2eb42072}},	//   _ske_, _isqf, _vrco_, _अनैत, 
   {{0x442d27e4,0x7988045f,0x320d27e5,0x00000000}},	//   _pke_, _ôfwa, dify_, --, 
   {{0x799c00b5,0xdc9805d0,0x83340408,0xab5800e5}},	//   _zcpw, ריאל, онех, zdün, 
   {{0xc2c4e9ff,0x320c05da,0x442c003b,0x26c80010}},	//   تيشي, fify_, _vke_, _urco_, 
   {{0x6fa40882,0x3c300419,0x00000000,0x00000000}},	//   क्सं, rávi_, --, --, 
   {{0x442ceff0,0x00000000,0x00000000,0x00000000}},	//   _tke_, --, --, --, 
   {{0x442c00d6,0x7e6d27e6,0x00000000,0x00000000}},	//   _uke_, _çapk, --, --, 
   {{0xab58002f,0x00000000,0x00000000,0x00000000}},	//   tdün, --, --, --, 
   {{0x320d27e7,0xdb0400d8,0x5fd80037,0x00000000}},	//   cify_, _maiô, _मचवल, --, 
   {{0xab58b919,0x1dd80490,0xd24401c6,0x00000000}},	//   rdün, बाबत, _хэти, --, 
   {{0x3ed41867,0x394401e4,0x23cc0b67,0xab58002f}},	//   _وقار, _ŝoso_, _सोमद, sdün, 
   {{0xab58496e,0x00000000,0x00000000,0x00000000}},	//   mdül, --, --, --, 
   {{0xe73c08e7,0xab580793,0xb8640736,0x00000000}},	//   _ebõk_, ldül, قارو, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xcce401ec,0xab58952a,0x00000000,0x00000000}},	//   _ءسوي, ndül, --, --, 
   {{0x7bd40537,0x6d4c041a,0x3ce800e4,0xa6c40798}},	// [1c540] _inyu, žbat, _ęavy_, олта_, 
   {{0x7bd401d4,0x3dc4009a,0x7bc401bf,0xe8080073}},	//   _hnyu, ndlw_, ldku, सोबा_, 
   {{0x2eb4a5cd,0xddd808ad,0x64a127e8,0x37e426ef}},	//   _अन्त, kruž, даха, _донг, 
   {{0xddd807f5,0xf770158b,0x68e00694,0x00000000}},	//   jruž, _تاد_, _ànda, --, 
   {{0xddd927e9,0x7bd527ea,0x320d27eb,0x7e6c0432}},	//   druž, _mnyu, tify_, _çaph, 
   {{0xdce00cf4,0x5eec012c,0x06901884,0x00000000}},	//   _lenđ, ेनन्_, _ﺟﻪﻣﯩ, --, 
   {{0x320d27ec,0xfbc8047f,0x7bd527ed,0x80bc44af}},	//   rify_, ियाम, _onyu, _वैदे, 
   {{0xeea89f59,0x7bd42f99,0xddd8bc36,0x69c00162}},	//   аток_, _nnyu, gruž, _ónev, 
   {{0xdde0084c,0xe280036b,0x437527ee,0xac7000f1}},	//   ârşi, _олти, _хуст, ژندګ, 
   {{0x7bc527ef,0x7bd527f0,0x00000000,0x00000000}},	//   edku, _anyu, --, --, 
   {{0xfdc8005e,0xe8b4025c,0x7bc401a4,0xa0640408}},	//   стық_, _བགེག, fdku, _даха_, 
   {{0xaee80156,0x3c30022a,0x00000000,0x00000000}},	//   ལགདོ, kávu_, --, --, 
   {{0xdfcc7a3f,0xc0e40023,0x00000000,0x00000000}},	//   _جين_, ማዒል_, --, --, 
   {{0x7bc4017a,0x00000000,0x00000000,0x00000000}},	//   adku, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9f5c01a8,0x7a3002d2,0x00000000,0x00000000}},	//   nnuð_, dætu, --, --, 
   {{0x3c30022c,0x00000000,0x00000000,0x00000000}},	// [1c550] gávu_, --, --, --, 
   {{0x7a3002d2,0x00000000,0x00000000,0x00000000}},	//   fætu, --, --, --, 
   {{0x69d527f1,0x69c401f5,0xb4b400c7,0x00000000}},	//   _inxe, mdje, зихә, --, 
   {{0x69c527f2,0x21e8005c,0xeacc00fe,0x00000000}},	//   ldje, _nøhr_, ৱনীম, --, 
   {{0x69c40d27,0xb7d80375,0x321c0051,0xab580205}},	//   odje, _הקרי, _bjty_, vdül, 
   {{0x69c527f3,0x7a300008,0x04c805d9,0x7e6c0200}},	//   ndje, bætu, _ٿوري_, _çapi, 
   {{0x29007b87,0x7580028e,0x69d4009a,0xd0580953}},	//   nzja_, _سینم, _mnxe, орыі_, 
   {{0xe3b127f4,0x7a300579,0xd91c0a1e,0xd398013d}},	//   _ترس_, lætt, יוול, _дәшә_, 
   {{0x73f8008f,0xab5927f5,0xbd4400f1,0x00000000}},	//   _פּלו, rdül, ګندي, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa3dc08f2,0xddd80210,0x00000000,0x00000000}},	//   ताप_, mruż, --, --, 
   {{0x69d527f6,0xeb941064,0x7a3127f7,0xec6c2ada}},	//   _anxe, пию_, hætt, _үп_, 
   {{0x7bc40cfe,0x7a300158,0xa3b000ab,0x1044002b}},	//   rdku, kætt, _जउन_, _uṣṭr, 
   {{0xa9642461,0xada0023a,0x69c401a6,0x7a3001bf}},	//   зира_, _зашл, gdje, jætt, 
   {{0xf77019f9,0xddd80210,0x00000000,0x00000000}},	//   فاء_, zpuś, --, --, 
   {{0x69d527f8,0x7bd527f9,0x69c456d4,0xfa680276}},	//   _enxe, _unyu, adje, _лаик_, 
   {{0xa3dc534e,0x69c405be,0x68e000e8,0x29000003}},	// [1c560] तान_, bdje, _àndn, azja_, 
   {{0x3c3004bf,0x4ab8007d,0x7a3003b2,0x00000000}},	//   rávu_, इबरव, gætt, --, 
   {{0xb4a800d8,0x00000000,0x00000000,0x00000000}},	//   скез_, --, --, --, 
   {{0x387927fa,0xa3e402ab,0xf1a803e6,0x1d5c0023}},	//   _iwpr_, मॉल_, ڵاته_, _ተዓፅዩ_, 
   {{0x7a300008,0xe73527fb,0xe294368e,0x00000000}},	//   bætt, _нею_, зач_, --, 
   {{0x26c4012d,0x46c800bc,0x7a300162,0xf7700244}},	//   łnoc_, रिरह, pætu, _تاگ_, 
   {{0xe6402038,0x00000000,0x00000000,0x00000000}},	//   _черп, --, --, --, 
   {{0xe0cd27fc,0x437401b9,0x289808d8,0x69c527fd}},	//   ازو_, _жуфт, ציפא, zdje, 
   {{0x2900003d,0xddd80327,0x00000000,0x00000000}},	//   zzja_, bruż, --, --, 
   {{0x720412dd,0xf1a83cb9,0xe1f4443f,0xdd90010b}},	//   _عوام, _داره_, _егу_, наьы, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa3dc28e1,0x317d27fe,0x2010003a,0x24840419}},	//   ताय_, _hetz_, éxit_, ánmi_, 
   {{0xddd80115,0xab580b97,0x00000000,0x00000000}},	//   lpuŝ, ldük, --, --, 
   {{0xa3b034ef,0x317c0e78,0xbe3000c7,0x4c94004e}},	//   _जॉन_, _jetz_, _иҭыш, _жикс, 
   {{0x69c527ff,0x317cd8b9,0x395880e1,0xd7d80490}},	//   rdje, _metz_, _dgps_, डांच, 
   {{0x2d9c90f4,0x317c04e6,0x29000327,0x00000000}},	//   lgte_, _letz_, rzja_, --, 
   {{0x2d9c2a28,0x7a312800,0x26cc0022,0xd4c401ec}},	// [1c570] ogte_, tætt, ígo_, _ﺭﺅﻭﻓ, 
   {{0x2d9d2801,0x2fc40280,0x317c101c,0x69d47fa8}},	//   ngte_, _laog_, _netz_, _unxe, 
   {{0x7a312802,0x00000000,0x00000000,0x00000000}},	//   rætt, --, --, --, 
   {{0x7a30019b,0xe3b00597,0xd6e4015b,0xf1d0000d}},	//   sætt, عرض_, _নেওয, _धोबन, 
   {{0xa3dcb5f0,0x317c01c7,0xab580793,0x818804da}},	//   ताब_, _betz_, edük, قچاق_, 
   {{0xd37800d1,0x387800a2,0xd314030d,0x00000000}},	//   очә_, _ywpr_, _кiот, --, 
   {{0x2fc41c06,0x317c0ba1,0x40480137,0x80bc07d0}},	//   _baog_, _detz_, опко_, _वैशे, 
   {{0x72400116,0x00000000,0x00000000,0x00000000}},	//   ىھەل, --, --, --, 
   {{0xa3440323,0x317c07c5,0xfe4406ed,0x00000000}},	//   _хэвл, _fetz_, мнио, --, 
   {{0x237c0399,0xee352803,0x2d9c0e78,0xef140312}},	//   _heuj_, мны_, ggte_, ьмы_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x225d2804,0xeb9c0158,0x2d9c0ea0,0x27e80142}},	//   _kuuk_, ggø_, agte_, _nocn_, 
   {{0xee2d2805,0x6fd806ab,0x3958009a,0xef0d2806}},	//   _ан_, भारं, _pgps_, _рм_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xeb9c0ac8,0xc8b40006,0xdce000e2,0xfc04b08f}},	//   giøs_, нсты, _venē, _опко, 
   {{0x3c1400e2,0x00000000,0x00000000,0x00000000}},	//   tāvu_, --, --, --, 
   {{0xe7341c31,0x225c0eda,0x0ba89498,0x27ec6d88}},	// [1c580] дет_, _nuuk_, _رايى_, ögna_, 
   {{0x18880020,0x7a30037e,0xa3b00d0a,0x9f4c008e}},	//   _ንግግር_, ræts, _जॉब_, _ilgä_, 
   {{0x04640046,0xa3cc032c,0x80bc05f9,0x8cd08bb5}},	//   етім, _वोह_, _वैले, धियो, 
   {{0xb4ac1533,0x317c0d16,0x225d2807,0x4a880244}},	//   _कही_, _setz_, _buuk_, _بڵێێ_, 
   {{0x317c0221,0x2d9c037e,0x2fc40156,0x00000000}},	//   _petz_, ygte_, _raog_, --, 
   {{0xeb9c708a,0x64480076,0xbbc8508c,0x2fc42e5e}},	//   niør_, amgi, ियुक, _saog_, 
   {{0xe4c00137,0x00000000,0x00000000,0x00000000}},	//   _ийри, --, --, --, 
   {{0xe1f42e47,0x225c002e,0xab581ae4,0x317c0036}},	//   згә_, _fuuk_, rdük, _wetz_, 
   {{0x201000db,0xb4ac0037,0x705001d9,0x00000000}},	//   èxia_, _कहु_, _یۆتا, --, 
   {{0xfd540055,0x2d9c0112,0x00000000,0x00000000}},	//   _hyaṅ, ugte_, --, --, 
   {{0x2d9d2808,0x00000000,0x00000000,0x00000000}},	//   rgte_, --, --, --, 
   {{0x225c25a9,0x2b4401c0,0x2d9c08c2,0x00000000}},	//   _yuuk_, дэгг, sgte_, --, 
   {{0xa3dc2413,0x777401e3,0xdd8c0133,0x00000000}},	//   तात_, dbyx, _چوه_, --, 
   {{0xdd8c70c8,0xddc00115,0xeb9c00b5,0xb4ac0037}},	//   _نوه_, _kinŝ, tiøs_, _कहू_, 
   {{0x19587fc1,0xcec807ae,0xe0ac02f5,0x1e540375}},	//   дары_, _hộ_, কিঅভ, _קשור_, 
   {{0xeb9c08cb,0xfd540055,0x00000000,0x00000000}},	//   riøs_, _nyaṅ, --, --, 
   {{0xeb9c08fb,0x45d40276,0xb90400cd,0x7e6c1f02}},	// [1c590] siøs_, ноас, _यॊ_, _çapt, 
   {{0xcec80016,0x237c0369,0x7a3000cc,0x64480210}},	//   _mộ_, _seuj_, sætr, wmgi, 
   {{0xcec807ae,0x225d2809,0x00000000,0x00000000}},	//   _lộ_, _suuk_, --, --, 
   {{0x89640014,0xfc4801fb,0x225c000d,0xeb9c03cd}},	//   _تُھن, _bậy_, _puuk_, tnøy_, 
   {{0xfc48001e,0x644801e3,0xcec801fb,0x43940116}},	//   _cậy_, rmgi, _nộ_, _җазс, 
   {{0xfc480016,0xeb9c03cd,0x225c0254,0xed4496a5}},	//   _dậy_, rnøy_, _vuuk_, _مپ_, 
   {{0x5185280a,0x09c8015b,0xeb9c0158,0x4394010a}},	//   туча, শাপা, snøy_, _павс, 
   {{0xcec801dc,0x4439280b,0x6e380332,0x00000000}},	//   _bộ_, _ós_, eltb, --, 
   {{0xcec801fb,0xfc48004d,0x93440798,0xab580432}},	//   _cộ_, _gậy_, _анѓе, ldüw, 
   {{0xcee8038b,0x7d080063,0xcec80208,0x00000000}},	//   ظرين_, зног_, _dộ_, --, 
   {{0xfc48004d,0xac8001c6,0x51842151,0x00000000}},	//   _zậy_, лгэл, _шута, --, 
   {{0xbbc80b4c,0x00000000,0x00000000,0x00000000}},	//   ियेक, --, --, --, 
   {{0x7be4013d,0x00000000,0x00000000,0x00000000}},	//   _ıruğ, --, --, --, 
   {{0x201c00c0,0x00000000,0x00000000,0x00000000}},	//   lnui_, --, --, --, 
   {{0xb4ac0bb2,0xeb9c708a,0x6e2401ed,0x201d280c}},	//   _कहे_, riør_, ékbe, onui_, 
   {{0xec6c05d9,0xbb4402e8,0x7e6c00a2,0x00000000}},	//   _اٿي_, _пейк, _çaps, --, 
   {{0x201c19a2,0x7c3400c7,0x7774007c,0x00000000}},	// [1c5a0] inui_, _ikyr, rbyx, --, 
   {{0x7fbc00bc,0x777401e3,0x201c0064,0x00000000}},	//   ्युँ, sbyx, hnui_, --, 
   {{0xdbdc0241,0xa52000d1,0xfc480051,0x00000000}},	//   _káàb, гүрҗ, _sậy_, --, 
   {{0x03c40006,0xa3e400af,0x00000000,0x00000000}},	//   ксім, मउग_, --, --, 
   {{0x64b401e4,0xd01040ec,0xddc001e4,0xfd5400dc}},	//   _aĝiĝ, یلت_, _sinŝ, _vyaṅ, 
   {{0xfc4807ae,0xcec801fb,0x6728000f,0xdbdc01e1}},	//   _vậy_, _rộ_, ûgje, _láàb, 
   {{0xcec8004d,0x66080036,0xa155280d,0x92e000eb}},	//   _sộ_, ëgke, нашу_, দনে_, 
   {{0xceb854a2,0x644001f5,0x20d0009a,0x00000000}},	//   дәк_, ïnit, اتوج, --, 
   {{0x241405e1,0xe295280e,0xc44401d9,0xeda402e8}},	//   _נחמן_, _пат_, _شیٖن_, ншно, 
   {{0x201c02b1,0x918000d1,0x00000000,0x00000000}},	//   anui_, _ئۇغۇ, --, --, 
   {{0xdbdc01e1,0xb4ac17cb,0xdd9402dd,0xddd8054e}},	//   _báàb, _कहो_, хшы_, spuş, 
   {{0xb4ac02e5,0x5fa40073,0xcec80208,0x00000000}},	//   _कहै_, _गायल, _tộ_, --, 
   {{0xdbdc0241,0x00000000,0x00000000,0x00000000}},	//   _dáàb, --, --, --, 
   {{0x7c34013f,0x91a400cd,0x00000000,0x00000000}},	//   _ekyr, च्चै, --, --, 
   {{0x2c840248,0xdbdc0248,0x7e6c05d2,0x00000000}},	//   _dídá_, _fáàb, _çapr, --, 
   {{0x5de00588,0x5920010c,0xd12400db,0x00000000}},	//   _ажәа, ደሚካኤ, _ۇۅ_, --, 
   {{0x5695280f,0xa3dc0846,0x00000000,0x00000000}},	// [1c5b0] латт, तास_, --, --, 
   {{0xddc00139,0x7a1402e2,0xa3b000bc,0x00000000}},	//   _minş, pņta, ज्न_, --, 
   {{0xdb040ba1,0x29040158,0x00000000,0x00000000}},	//   _aciè, _åna_, --, --, 
   {{0x83180740,0xd3700214,0xd1740150,0x00000000}},	//   وقار_, مهٔ_, қышы, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa3dc32ed,0xdb04017a,0xdce00153,0xd8740244}},	//   ताह_, _scië, _genė, _جایب, 
   {{0xc0e43d2a,0x64412810,0x66140129,0x00000000}},	//   тойк, ïnis, mixk, --, 
   {{0x201d2811,0x23740a2c,0x00000000,0x00000000}},	//   unui_, _سارح, --, --, 
   {{0x92b52812,0x5fa40073,0x201c00c0,0x00000000}},	//   _محلا, _गाठल, rnui_, --, 
   {{0x7c352813,0x6288d918,0x6458062c,0x443d0a47}},	//   _skyr, msgo, _hiui, llw_, 
   {{0x6458cf11,0x79880b21,0x00000000,0x00000000}},	//   _kiui, _ôfwi, --, --, 
   {{0x645800ad,0xdb0400d8,0x00000000,0x00000000}},	//   _jiui, _ibiú, --, --, 
   {{0xa3b006e3,0x62892814,0x645801ab,0x7c2c00df}},	//   ज्य_, nsgo, _miui, _ĉard, 
   {{0xcdc40058,0x6458ec36,0x443c0472,0x4ccc009e}},	//   _башқ, _liui, hlw_, াহজু, 
   {{0xa96400f3,0xf1e000dc,0xab58002f,0xf1b0010f}},	//   тиса_, पातन, geüb, ױסן_, 
   {{0x7c340117,0x64580393,0xbb440131,0x62892815}},	//   _ukyr, _niui, _ﭘﯘﻝ_, ksgo, 
   {{0x3ead2816,0x9f4c00f7,0xdca0136b,0xa76020a9}},	// [1c5c0] ntet_, _algú_, _рақи, ркуд, 
   {{0x3eac0639,0x64580618,0x6288c4b2,0x443c0142}},	//   itet_, _aiui, dsgo, elw_, 
   {{0x26cc04f3,0x3ead2817,0x6288a927,0x254c002b}},	//   ågor_, htet_, esgo, _kāṃś, 
   {{0x3eac0ac7,0xddc000dd,0x64592818,0xdb040036}},	//   ktet_, _minő, _ciui, _acié, 
   {{0x64592819,0x628874b5,0x3ead281a,0xfba83b16}},	//   _diui, gsgo, jtet_, _कानम, 
   {{0xe1ec005e,0xba8c040d,0x3ead281b,0xc88875f5}},	//   قسى_, _ﺑﻪﻟﮕ, dtet_, _تخیل_, 
   {{0x3ead281c,0xa0c05230,0x00000000,0x00000000}},	//   etet_, ليوو, --, --, 
   {{0x3eac00ed,0x6459281d,0xb4dc1fbc,0x99940118}},	//   ftet_, _giui, तमी_, čeři_, 
   {{0xa3dc023e,0x3eac04ce,0xf1e007b7,0xa6d80174}},	//   तार_, gtet_, पादन, _eyðf, 
   {{0xe2942cc8,0xe0cc0014,0xa30801d9,0x244400c7}},	//   _шау_, _ژٲل_, _کرہے_, rõme_, 
   {{0x65980302,0x3eac036e,0xdbdc0ca8,0x244400c7}},	//   וייק, atet_, _sááb, sõme_, 
   {{0x254c00b8,0x3eac031c,0x52a00150,0xab58002f}},	//   _cāṃś, btet_, _ﺍﻻﯕﯩ, veüb, 
   {{0x3eac579d,0x4dfc0034,0x00000000,0x00000000}},	//   ctet_, एसआई_, --, --, 
   {{0x5a3451f2,0x7c2c00df,0xa7f80139,0x7d0c0118}},	//   инят, _ĉare, _kiñg, _řase, 
   {{0xa3b00f4a,0x00000000,0x00000000,0x00000000}},	//   ज्ड_, --, --, --, 
   {{0x7af002d3,0xfba846df,0xa7f8013d,0x628803cb}},	//   ëjtë, _कायम, _miñg, ysgo, 
   {{0x6459281e,0x658406a6,0xac9002dd,0x49a401af}},	// [1c5d0] _riui, выез, _сақш, _йынғ, 
   {{0x7e6c0120,0x293c07d2,0x00000000,0x00000000}},	//   _éape, _ﺑﺎﭖ_, --, --, 
   {{0xa3dc22e3,0x6458013c,0xfba8227c,0x6615281f}},	//   ताल_, _piui, _कामम, rixk, 
   {{0x3ead2820,0xdb041497,0xa6d8032e,0x00000000}},	//   ytet_, _scié, _ryðf, --, 
   {{0xefb80201,0x3ead2821,0x64580393,0x56940354}},	//   ዳንድ_, xtet_, _viui, _каят, 
   {{0x7d1401f1,0xb6d800c8,0x00000000,0x00000000}},	//   úzsk, _אַלט, --, --, 
   {{0xdb0401ab,0xa3a802ab,0xfbc8009e,0x91841e4a}},	//   _dbiù, _खाप_, ষাতত, شۇنۇ, 
   {{0x3eac0ac7,0x64592822,0xefb8001f,0xa3dc0490}},	//   ttet_, _uiui, ዳንዴ_, ताळ_, 
   {{0x430c151c,0x7ed402dd,0x1ca8031c,0x3eb80582}},	//   _ѕυмм_, ازبا, _པདང_, ïst_, 
   {{0x3ead2823,0xa6d80174,0x98bc0153,0x78ac0175}},	//   rtet_, _eyðg, _švč_, ytbv, 
   {{0x3ead2824,0x254c00cd,0xdce00171,0xd24c02f2}},	//   stet_, _pāṃś, _ienī, _تۆو_, 
   {{0x3ead2825,0x6aac074d,0x00000000,0x00000000}},	//   ptet_, ftcf, --, --, 
   {{0xfba8038e,0xa3a847b8,0x92b40154,0x23980064}},	//   _काठम, _खान_, জয়ী_, _iąjį_, 
   {{0x6e900491,0xca752826,0xa7f8002e,0xa3dc0a17}},	//   _الوا, شنفک, _liñd, ताँ_, 
   {{0x3e680016,0x7e680784,0xaa4400a8,0x254c002b}},	//   _hút_, lqep, упра_, _tāṃś, 
   {{0x7ae40227,0x3e690b1b,0x00000000,0x00000000}},	//   pxkt, _kút_, --, --, 
   {{0x66e0729a,0x7e68014b,0x00000000,0x00000000}},	// [1c5e0] бота, nqep, --, --, 
   {{0xb5c81d93,0x3e6801fb,0xab5807c5,0xfdf401ad}},	//   عوام_, _mút_, rdüt, ेसिस_, 
   {{0xa3dc0a28,0x3e692827,0xf1e01408,0x00000000}},	//   तां_, _lút_, पासन, --, 
   {{0x2898008f,0xa7f8008e,0x37e40137,0x7e68036e}},	//   _איטא, _ciñd, _сомг, kqep, 
   {{0x3e680016,0xab592828,0xa6d8032e,0xfdf40118}},	//   _nút_, ldür, _ryðg, ेसास_, 
   {{0x4ad40882,0x780001af,0x00000000,0x00000000}},	//   दितव, _түға, --, --, 
   {{0x66012829,0xab58e35c,0x7988002d,0xa6d803b2}},	//   _упра, ndür, _ôfwu, _eyðd, 
   {{0xa3dc0a28,0x3e68001e,0x3a38020b,0xa3a800af}},	//   ताः_, _bút_, _lkpp_, _खाय_, 
   {{0xefb8001f,0x7e68014b,0xfe6c00db,0x3e68004d}},	//   ዳንዱ_, gqep, وگو_, _cút_, 
   {{0x6ce40046,0xab59282a,0x00000000,0x00000000}},	//   гіме, kdür, --, --, 
   {{0xfdc8005e,0xbc8400c7,0xa3a809ab,0xcff49c1d}},	//   ттық_, аӡыз_, _खाम_, _پيشک, 
   {{0xa7f80086,0xc620278e,0x3e6800ae,0xdce000ef}},	//   _kiñe, _मद्य_, _fút_, _zenī, 
   {{0x3e68004d,0xa7f80139,0x00000000,0x00000000}},	//   _gút_, _jiñe, --, --, 
   {{0xa7f8005a,0x00000000,0x00000000,0x00000000}},	//   _miñe, --, --, --, 
   {{0x3a38020b,0xa7f80077,0x00000000,0x00000000}},	//   _dkpp_, _liñe, --, --, 
   {{0xab85282b,0xa7f8005a,0x00000000,0x00000000}},	//   _сукк, _oiñe, --, --, 
   {{0xa7f88dd6,0x07a46215,0x7ae8004b,0xd7c80345}},	// [1c5f0] _niñe, лаңн, _لويې_, دوقه_, 
   {{0xa7f800a2,0xab58002f,0x00000000,0x00000000}},	//   _siñd, sdüs, --, --, 
   {{0x6d5c02fb,0xd5b80006,0xd6d000f1,0x8d8c0150}},	//   _úpad, ыст_, يقې_, _ﻓﺘﺤﺕ_, 
   {{0xa7f8005a,0x00000000,0x00000000,0x00000000}},	//   _biñe, --, --, --, 
   {{0xa7f80724,0x00000000,0x00000000,0x00000000}},	//   _ciñe, --, --, --, 
   {{0x4094355a,0xa7f8172e,0x3e69282c,0x926801f4}},	//   арит, _diñe, _rút_, урца_, 
   {{0x3e682b7c,0x7e680113,0xa7f8013d,0x9f5c01e7}},	//   _sút_, wqep, _tiñd, shuí_, 
   {{0x73c00598,0x68e01bce,0x705006c5,0xc2740114}},	//   _мәче, _àndu, ينوا, _влај, 
   {{0xae848dc7,0x6d4c93b8,0xa7f90da0,0xab584a0f}},	//   абыз_, ýban, _giñe, zdür, 
   {{0x5fa40d01,0x9f4c1bce,0xfc74001f,0x3e68004d}},	//   _गावल, _jogé_, _የተገኙ_, _vút_, 
   {{0x2cac5eb5,0xa7f8005a,0xcee80132,0x23980064}},	//   _cqfd_, _ziñe, _ەرىن_, _tąjį_, 
   {{0x3f8800fc,0x26c80048,0x9f4c0129,0x3e69282d}},	//   _þau_, _osco_, _logé_, _tút_, 
   {{0xeb95282e,0xb4e00b03,0x3d141414,0x00000000}},	//   шия_, _गप्प_, _फेरे_, --, 
   {{0x9f4c003e,0xada05443,0x6da1282f,0xab58002f}},	//   _nogé_, _дашл, _диша, tdür, 
   {{0x26c92830,0xf7700aaa,0xfc3000ae,0x00000000}},	//   _asco_, قاء_, _وحب_, --, 
   {{0xb8dd2831,0xab5803ee,0xfcd4001f,0xafe403b2}},	//   _इह_, rdür, ራቴጂ_, mføð, 
   {{0xb4dc1161,0xa3dc1d34,0xb6a40835,0x00000000}},	// [1c600] तम्_, ताई_, ризл, --, 
   {{0xe57431d5,0xd5e03be5,0xbec400ef,0x00000000}},	//   изу_, नाइज, ccīņ, --, 
   {{0x26c80395,0x91780208,0xa7f8010e,0x38280024}},	//   _esco_, _lợi_, _siñe, _ажно_, 
   {{0xa7f80b19,0xb6a4842e,0x7c252832,0x29240419}},	//   _piñe, _кимл, nnkr, ávaš_, 
   {{0xe7f819e5,0xa6d80174,0x8c4800a2,0x7c252833}},	//   _एकता_, _eyðb, _huşý, inkr, 
   {{0xa7f809ff,0x7c240112,0xe2f401ec,0x00000000}},	//   _viñe, hnkr, реші_, --, 
   {{0xa0852834,0x21640114,0xe61400d8,0xad6400f2}},	//   асыз_, шији_, _тдр_, یاده, 
   {{0x2b5c01fa,0xa7f92835,0x2898010f,0x3d0801bc}},	//   žuci_, _tiñe, דיקא, ानने_, 
   {{0xa3a819ec,0xa3cc1533,0x9f5000a7,0x00000000}},	//   _खात_, _वोट_, овъч, --, 
   {{0x0ba403a5,0x78bc1a82,0x32452836,0xa7f80882}},	//   әынҭ, _oppv, _тезг, _kiñc, 
   {{0x7d0c3142,0x21640536,0xdfcc00ec,0x0bd40798}},	//   _ƙasa, _тихи_, _ڊيل_, бонџ, 
   {{0xef1821ca,0x92d811ba,0xa3dc2982,0x7c2402d2}},	//   _име_, াহী_, ताए_, gnkr, 
   {{0x78bc0354,0xceb80032,0x2b4401c6,0x1dd40073}},	//   _appv, _сәй_, рэнг, _भोवत, 
   {{0x7c24017a,0x7e6c0798,0x05d40073,0x00000000}},	//   ankr, _éapa, _डोंब, --, 
   {{0xe7f80574,0xdca000f3,0x09c800eb,0x00000000}},	//   _एकदा_, _даји, শালা, --, 
   {{0x26c80048,0x3c3002fb,0x8c48010b,0xa6d802d2}},	//   _psco_, kávy_, _duşý, _ryðb, 
   {{0xac052837,0x85b8840a,0x92d80154,0x1cc00327}},	// [1c610] _مذکو, ллас_, াহু_, _ཌརོ_, 
   {{0xe8a00023,0x73c001e0,0xf8740451,0xa2b409ab}},	//   _ዝፍለጡ_, үәте, _گهٽج, ोबस्, 
   {{0x237404a9,0xa7f80055,0xa3a838d2,0x95c80a5b}},	//   للاھ_, _ciñc, _खाद_, шута_, 
   {{0x88040014,0x00000000,0x00000000,0x00000000}},	//   _چِھو, --, --, --, 
   {{0x3f980321,0xdb2401d3,0x442800df,0x21640818}},	//   ósum_, ősöd, ĵa_, қиқи_, 
   {{0x130802bf,0x4428090c,0xeb9c00b5,0x68e0002e}},	//   шній_, ŵa_, lkød_, _ànds, 
   {{0x6d4c0030,0xf3f800d1,0x95c801c6,0x00000000}},	//   ýbal, _өмрә_, _туяа_, --, 
   {{0xe2a92838,0x00000000,0x00000000,0x00000000}},	//   _لائن_, --, --, --, 
   {{0x0fe8005e,0x63b807e2,0x6d482a1f,0x00000000}},	//   рлық_, _ibun, _azfa, --, 
   {{0xfde80b2c,0xa3dc1d34,0xd1b92839,0x00000000}},	//   удок_, ताक_, _ناما_, --, 
   {{0x69c006ea,0xee3401c6,0x11d4007b,0x7c2403b2}},	//   _óney, снэ_, _بتقد, tnkr, 
   {{0xeb9c01bf,0xafe403b2,0x00000000,0x00000000}},	//   lhøj_, rføð, --, --, 
   {{0x63b9283a,0x7c25283b,0xf410008f,0x66040427}},	//   _mbun, rnkr, לפט_, _oljk, 
   {{0x4998169c,0x3cf8212d,0x3f8c003e,0x9f5c01ab}},	//   ится_, _معبد_, laeu_, chuá_, 
   {{0x63b8816a,0xab582641,0x00000000,0x00000000}},	//   _obun, leül, --, --, 
   {{0x66040e3c,0x63b8063f,0x848400b7,0x3dc40fec}},	//   _aljk, _nbun, _ምሁራን_, lelw_, 
   {{0x7bc5283c,0x66e11228,0xa7f8002b,0x00000000}},	// [1c620] meku, пота, _siñc, --, 
   {{0xb06001f4,0x00000000,0x00000000,0x00000000}},	//   öäki, --, --, --, 
   {{0x78bd283d,0x798d283e,0x2d90013f,0x240400d1}},	//   _uppv, mabw, _ɛye_, әнчи_, 
   {{0x7bc5283f,0x3f8c0007,0x798c0337,0x4788023a}},	//   neku, jaeu_, labw, _всём_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3c300745,0x798d2840,0x7bc52841,0x752c0165}},	//   rávy_, nabw, heku, _txbz, 
   {{0x7bc52842,0x7c2c0115,0x80d40825,0x3dc40042}},	//   keku, _ĉarn, भिषे, delw_, 
   {{0x7bc409cb,0x798c0516,0x600401c0,0xa7f80de2}},	//   jeku, habw, йхыг_, _kiña, 
   {{0xb8e82b88,0x798d2843,0x7bc40821,0x12240022}},	//   _ཊར_, kabw, deku, _дзаҭ, 
   {{0x63b82ce2,0x27340016,0xa7f81709,0x4cb800d4}},	//   _zbun, ủng_, _miña, алою_, 
   {{0xa7f8172e,0x7bc52844,0x3f8c0369,0x798c0925}},	//   _liña, feku, baeu_, dabw, 
   {{0x7bc52845,0x3f8c0005,0xa7f801c4,0x386000b8}},	//   geku, caeu_, _oiña, _nikr_, 
   {{0xa3a83eaf,0xa7f92846,0x9a8424c3,0xa6d80162}},	//   _खास_, _niña, зусл, _oyða, 
   {{0xdb040077,0x798c0526,0x9f4c01e1,0x00000000}},	//   _abió, gabw, _mogì_, --, 
   {{0x7bc52847,0x59f800a7,0x00000000,0x00000000}},	//   beku, щеря_, --, --, 
   {{0x8c181bb1,0xd7f86768,0x6e38df5f,0x244400e4}},	//   _خيبر_, буу_, lotb, võmo_, 
   {{0x798c0516,0xa5652848,0xeb9c00b5,0x6b8c01c3}},	// [1c630] babw, مدان, yhøj_, macg, 
   {{0xa7f82e48,0x63b80268,0x798c0067,0x6b8c00de}},	//   _diña, _sbun, cabw, lacg, 
   {{0x386007d6,0x69c52849,0xeb9c01bf,0x00000000}},	//   _fikr_, meje, vhøj_, --, 
   {{0x69c50e15,0xa7f80784,0x3dc4af97,0x690800ac}},	//   leje, _fiña, zelw_, ıqdı, 
   {{0xa7f9284a,0x6d4c0030,0x016400f3,0x00000000}},	//   _giña, ýbaj, окло, --, 
   {{0x7ff416cb,0x7bc5284b,0xe5c5284c,0x04c83cda}},	//   ڪستا, zeku, _усмо, _پوري_, 
   {{0x7bc5284d,0xd5b801ce,0x600400a2,0xa7f801c4}},	//   yeku, _уся_, _añma, _ziña, 
   {{0x63b8be78,0x69c41459,0x798d284e,0xeb9cfede}},	//   _ubun, heje, zabw, shøj_, 
   {{0x442d284f,0x7bc52850,0x6e381f53,0x3f8d2851}},	//   _ije_, veku, fotb, raeu_, 
   {{0x7bc52852,0x69b8a5aa,0x00e40345,0xab58000d}},	//   weku, श्मी, _وتای, reül, 
   {{0x7bc52853,0x1ee40502,0x442c0fb7,0xfbc451e4}},	//   teku, _گوشی_, _kje_, обно, 
   {{0x798d2854,0x3dc40472,0x7e6d2855,0xab580254}},	//   wabw, selw_, _éapo, peül, 
   {{0x7bc52856,0x798d2857,0x69c400dd,0x9f4c0248}},	//   reku, tabw, feje, _kogí_, 
   {{0x69c52858,0x201d2859,0xa7f9285a,0xeb9c01bf}},	//   geje, liui_, _riña, gkøb_, 
   {{0x798c015c,0x442c0588,0x7bc40fcc,0xa7f9285b}},	//   rabw, _oje_, peku, _siña, 
   {{0x442d285c,0x6b8c074d,0x798c0516,0xa7f803f0}},	//   _nje_, cacg, sabw, _piña, 
   {{0xe7f8367a,0xe818000d,0x3860002b,0x5fa40bae}},	// [1c640] _एकरा_, _नगरा_, _vikr_, _गाईल, 
   {{0x442d285d,0xe5a0445a,0xa7f9285e,0x201c06c8}},	//   _aje_, дифи, _viña, hiui_, 
   {{0xa7f81bb7,0x386002b9,0x06980075,0xec1025da}},	//   _wiña, _tikr_, لخەت_, _روید, 
   {{0xa7f8172e,0xdb040210,0x00000000,0x00000000}},	//   _tiña, _ubió, --, --, 
   {{0x442d285f,0xa3a801b0,0x040002f5,0x92d8015b}},	//   _dje_, _खार_, লোভী_, াহ্_, 
   {{0x442d2860,0x9f4c0789,0xe69001d5,0xa1840063}},	//   _eje_, _cogí_, _زلفد, обља_, 
   {{0xa7f80724,0x0ef40bae,0xe5bc0241,0x00000000}},	//   _miñn, ेन्स_, _àláá, --, 
   {{0x442d2861,0x69c52862,0x201c0153,0x00000000}},	//   _gje_, zeje, giui_, --, 
   {{0x69c4770e,0x7e6c00d8,0xdbe408a5,0x00000000}},	//   yeje, _éapl, _réðs, --, 
   {{0x69c52863,0x442cad7e,0x00000000,0x00000000}},	//   xeje, _zje_, --, --, 
   {{0x69c52864,0xa3dc0490,0x442d2865,0xe0cc01d9}},	//   veje, ताच_, _yje_, _لٲل_, 
   {{0xdb04007b,0x69c4003e,0xa4b4011a,0x6e380477}},	//   _sciá, weje, חלטה_, sotb, 
   {{0x69c52866,0x6e3801ed,0x60040139,0xeb9c01bf}},	//   teje, potb, _uñma, tkøb_, 
   {{0xa7f80139,0x2c1800cc,0xec68026b,0x00000000}},	//   _ciñn, ণকেই_, _крик_, --, 
   {{0x69c52867,0x63a8ee18,0x58d401e0,0xeb9c00b5}},	//   reje, yggn, морт, rkøb_, 
   {{0x69c52868,0xb9280092,0xeb9c005c,0x8d700092}},	//   seje, ደሚካሄ, skøb_, _አበባው_, 
   {{0x70c446c7,0xa6d81d0e,0x442c0427,0xeb9c01bf}},	// [1c650] लबुल, _eyðn, _rje_, pkøb_, 
   {{0xe50400db,0xa7f8002e,0x442d2869,0x6100002e}},	//   يباي, _giñn, _sje_, _wёli, 
   {{0x27ec07de,0xd5ac00bc,0x6830025c,0x2484007f}},	//   ögns_, _चारज, eħde, ènm_, 
   {{0x37280023,0xc35400d8,0x00000000,0x00000000}},	//   _ተመኩሮ, пкеј, --, --, 
   {{0x201c0024,0x442c036e,0x6830025c,0xf7740677}},	//   viui_, _vje_, għde, _מערי_, 
   {{0x7e780589,0x7c2c010f,0xa3dc012c,0x7bd802b5}},	//   _rtwp, _ĉarm, ताङ_, ētui, 
   {{0xd1b9286a,0x442d286b,0x201c0393,0x01646b62}},	//   تانا_, _tje_, tiui_, окһо, 
   {{0xa7f81709,0x1ee4035c,0xab5801b8,0x201d286c}},	//   _miño, قوبی_, geük, uiui_, 
   {{0x443d286d,0x201c0006,0x5ab80327,0x00000000}},	//   mow_, riui_, _བདེམ, --, 
   {{0xee3434d8,0x443d286e,0xa3a82ba2,0x201c0024}},	//   знь_, low_, _खाँ_, siui_, 
   {{0xa7f84e4c,0x443d286f,0xfce4014b,0x201c00c0}},	//   _niño, oow_, чоно, piui_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2ce00327,0x98c00205,0x2fd40244,0xab58000d}},	//   ེའུབ, _ısım_, _روود_, neüh, 
   {{0x443d2870,0xddc000da,0xa05800b8,0x91fc0171}},	//   how_, _minū, _dṛśī, _liān, 
   {{0xadb400b2,0xa3a8012d,0x17c801d5,0x00000000}},	//   _رهيا_, _खां_, оҳни_, --, 
   {{0x443c08e7,0x37281772,0xa7f801c4,0x9ba4030c}},	//   jow_, _ተመክሮ, _diño, _تەحى, 
   {{0x443d2871,0xba2415bf,0xa7f8008e,0x64a000c7}},	// [1c660] dow_, _ндик, _tiñn, ҵаха, 
   {{0x443c08e7,0xab580254,0x00000000,0x00000000}},	//   eow_, deüh, --, --, 
   {{0x14c8034c,0xa7f92872,0x7d0048a2,0x22440175}},	//   تهای_, _giño, nyls, dlnk_, 
   {{0x443d2873,0x7bd52874,0x68e12875,0x91fc00ef}},	//   gow_, _jayu, _ánda, _ciān, 
   {{0x7bd52876,0x7d00010e,0x91fc00e2,0x0ca92877}},	//   _mayu, hyls, _diān, _कम्म, 
   {{0x7bd52878,0x741408dc,0x7d00010e,0x00000000}},	//   _layu, _کورا, kyls, --, 
   {{0x443d2879,0x3d04033f,0xab580254,0x9474009f}},	//   bow_, शनों_, teük, _آپرچ, 
   {{0x443d287a,0x7bd5287b,0xe3b40114,0x7d00176a}},	//   cow_, _nayu, _нбс_, dyls, 
   {{0x5f7000db,0x41280352,0x4374009d,0xda0c0f4a}},	//   راير, йнәү_, _цуст, सघात_, 
   {{0xddc80ab7,0x7bd422d0,0x7d00045f,0xab5801d3}},	//   ğişt, _aayu, fyls, lfüg, 
   {{0x7bd5287c,0xaf343b7a,0x7d0000a2,0x00000000}},	//   _bayu, _کرات, gyls, --, 
   {{0x7bd5287d,0xa7f80407,0xab59287e,0xdfcc188d}},	//   _cayu, _riño, nfüg, _ميم_, 
   {{0x7bd5287f,0xa7f80432,0xdee00484,0x00000000}},	//   _dayu, _diñl, _поци, --, 
   {{0xa7f83a9c,0x443d2880,0x7d000210,0x00000000}},	//   _piño, zow_, byls, --, 
   {{0x443d2881,0x2eac04c5,0x7bd4002e,0xab58274a}},	//   yow_, _কনিষ, _fayu, ndüz, 
   {{0x7bd52882,0xa7f92883,0x9998012c,0x443d2884}},	//   _gayu, _viño, borů_, xow_, 
   {{0x45d52885,0x443d2886,0xddd806be,0x00000000}},	// [1c670] моас, vow_, nquş, --, 
   {{0x2d8c98fa,0x443d2887,0xa7f80589,0x7bd40198}},	//   _jefe_, wow_, _tiño, _zayu, 
   {{0x443d2888,0x2d8c0100,0xe3b0484d,0x7bd52889}},	//   tow_, _mefe_, فرش_, _yayu, 
   {{0x2d8d288a,0x37e40156,0x7bd5288b,0x321c0109}},	//   _lefe_, _ཤོགད, _xayu, _amty_, 
   {{0x7d0c0198,0x443d288c,0x69d5288d,0xb7d8011a}},	//   _ƙask, row_, _kaxe, _וקרי, 
   {{0x443d288e,0x2d8c0165,0xd5b868eb,0x00000000}},	//   sow_, _nefe_, _нсс_, --, 
   {{0x69d5288f,0x443d2890,0x1dd42208,0x999800bc}},	//   _maxe, pow_, _भोगत, zorů_, 
   {{0x69d52891,0x321c0109,0x443c03d9,0x2008033f}},	//   _laxe, _emty_, qow_, óci_, 
   {{0x7bd43142,0x2d8c05c7,0x62200046,0x21643007}},	//   _rayu, _befe_, _كورە, _етег, 
   {{0x7bd52892,0x7ae009a8,0x69d4058a,0x99980118}},	//   _sayu, _šoto, _naxe, vorů_, 
   {{0x7bd48590,0x2d8d2893,0x00000000,0x00000000}},	//   _payu, _defe_, --, --, 
   {{0x2d8c01af,0x9998012c,0x3c180953,0x91f0035b}},	//   _eefe_, torů_, іўня_, _аҟәш, 
   {{0x2d8d2894,0xa3a87db3,0x29006ead,0x69d4212c}},	//   _fefe_, _खाई_, eyja_, _baxe, 
   {{0x2d8c0b45,0x7bd52895,0xab580213,0x00000000}},	//   _gefe_, _wayu, ndüy, --, 
   {{0x7bd52896,0xa9641503,0x29012897,0xa7f8013d}},	//   _tayu, дира_, gyja_, _tiñl, 
   {{0xa6d806ea,0x1948001f,0x00000000,0x00000000}},	//   _eyðm, _መድረኮ, --, --, 
   {{0x69d40429,0x2d8c0165,0xa7f80055,0x2f58010f}},	// [1c680] _faxe, _yefe_, _kiñj, ַדענ, 
   {{0x2d8d2898,0x7d0c02a8,0x9ba434b1,0xeb9c01bf}},	//   _xefe_, _ƙash, _تەڭى, nkøn_, 
   {{0xf7702002,0x6c3000e5,0xab5806be,0x00000000}},	//   _ۋاڭ_, _سفیا, ddüy, --, 
   {{0x69d4009a,0xf7712899,0x853400cf,0x00000000}},	//   _zaxe, _جاد_, رونچ, --, 
   {{0xab5809f0,0x69d5289a,0x5fa40073,0xeb9c03b2}},	//   rfüg, _yaxe, _गाजल, kkøn_, 
   {{0xc5d5289b,0xd25022eb,0x00000000,0x00000000}},	//   _пісь, دنت_, --, --, 
   {{0x741408b0,0xa1540166,0x2d8c0100,0xf50401b9}},	//   _قوسا, машу_, _refe_, _ўзбо, 
   {{0x2d8d289c,0xa3a849f1,0x2518010f,0x8ca40e49}},	//   _sefe_, _खाए_, _וולא, _किबो, 
   {{0x2d8c05c7,0xb8e8031c,0x799c02d0,0xa2b001d3}},	//   _pefe_, _ྲད_, _odpw, _لینڈ, 
   {{0xdce0031c,0xa6d8032e,0x2d8c0200,0x01cc0154}},	//   _senġ, _byðj, _qefe_, লাউদ, 
   {{0x2d8c03bd,0x69d40493,0xfba80118,0x00000000}},	//   _vefe_, _raxe, _काखम, --, 
   {{0x69d5289d,0x799c02d0,0xaf045348,0x00000000}},	//   _saxe, _adpw, _опел, --, 
   {{0x2d8c0418,0xddd800ac,0x69d40036,0xe3bc010b}},	//   _tefe_, qquş, _paxe, _öñe_, 
   {{0x7e7c3351,0x2901289e,0x9f9c00e8,0x2d8c01a6}},	//   íspe, tyja_, _rééw_, _uefe_, 
   {{0x69d4ecfc,0x57cc0131,0xa6d808ce,0x00000000}},	//   _vaxe, ﺗﻠﯩﺮ, _gyðj, --, 
   {{0x2901289f,0xa3b04d21,0x195800fd,0xdb040254}},	//   ryja_, ज्ञ_, фасы_, _abiõ, 
   {{0xb6c00372,0x56941952,0x473528a0,0x29000200}},	// [1c690] лөрд, катт, хнас, syja_, 
   {{0x799c03ac,0xe4a4059f,0xa7f8013d,0x290000e4}},	//   _gdpw, дрдо, _kiñk, pyja_, 
   {{0x7d0c03f9,0x41d84668,0x00000000,0x00000000}},	//   _ƙasi, _योगस, --, --, 
   {{0x69b8085c,0x83340139,0x00000000,0x00000000}},	//   श्री, ннех, --, --, 
   {{0xa7f8002e,0xb77800df,0x00000000,0x00000000}},	//   _liñk, _מארש, --, --, 
   {{0x41740328,0xa3a80412,0x00000000,0x00000000}},	//   راتس, _खाक_, --, --, 
   {{0xd49928a1,0xab5800ac,0xa7f800e8,0xed4c0354}},	//   _орт_, rdüy, _niñk, _йоi_, 
   {{0xe3b0027d,0xa6d808a5,0x00000000,0x00000000}},	//   _جرس_, _ryðj, --, --, 
   {{0x705031ed,0x72a0313e,0xa7f800b8,0xeb9c01bf}},	//   دنيا, _مەنن, _piñj, tkøn_, 
   {{0xa7f8002e,0x64491bd3,0xdce128a2,0xd1b401d9}},	//   _biñk, llgi, _agnā, _لیٖک, 
   {{0xd1b8075e,0xee2c02dd,0x3f98003a,0x799c02d0}},	//   _تاقا_, _ұн_, ósus_, _rdpw, 
   {{0xfaa528a3,0x6ce0004b,0xeb9c005c,0x8e7000c7}},	//   намо, اړون, skøn_, ықәш, 
   {{0x200d28a4,0xee2d28a5,0x64480153,0x5ac80327}},	//   _ilgi_, _бн_, ilgi, གསེམ, 
   {{0xe0c003d4,0xa6d8022c,0x3eac020c,0x9f5c0022}},	//   ্মীন, _eyðk, muet_, akuã_, 
   {{0x3eac4a1f,0x68e000d2,0x00000000,0x00000000}},	//   luet_, _ándl, --, --, 
   {{0xad18025f,0x3eac0156,0x00000000,0x00000000}},	//   _מוצר, ouet_, --, --, 
   {{0x3ead20b9,0xe73434d8,0x9ce400e5,0x91fc00ef}},	// [1c6a0] nuet_, еет_, _روکے_, _siām, 
   {{0x7c243174,0x64480158,0xf628007b,0x32c80022}},	//   likr, elgi, أسرى_, ҧыло_, 
   {{0x62980c86,0x3ead28a6,0xf4d00150,0x7c240472}},	//   _avuo, huet_, _ءﺑﻮﺭ, oikr, 
   {{0x78ac0433,0x3ead28a7,0xa878010f,0xb9d401f3}},	//   mubv, kuet_, _מאטר, _ጾመ_, 
   {{0x3eac119a,0x00000000,0x00000000,0x00000000}},	//   juet_, --, --, --, 
   {{0x3ead28a8,0x7c2528a9,0x64480ba1,0x52c000af}},	//   duet_, hikr, algi, _एहीस, 
   {{0x7c2528aa,0xaa780306,0x66540354,0x04b401f4}},	//   kikr, ovýc, _чарă, _истя, 
   {{0x60300311,0x3eac002e,0x7c240010,0x37280023}},	//   tăma, fuet_, jikr, _ተመኵሮ, 
   {{0x61e8066d,0x6b9c074d,0x3ead28ab,0x7c2528ac}},	//   állí, _rdqg, guet_, dikr, 
   {{0x78ac05b8,0x7c240af9,0x765c007f,0x6030054e}},	//   kubv, eikr, nmpy, răma, 
   {{0x7c2528ad,0x7988002d,0x78ac0810,0xf48c0212}},	//   fikr, _ôfwy, jubv, алiв_, 
   {{0x3ead20b9,0x290c0607,0x7c2401f5,0xaa781155}},	//   buet_, _āga_, gikr, jvýc, 
   {{0xdfcc2091,0x3eac45a7,0xeb480f06,0x3f944710}},	//   _دين_, cuet_, ячок_, _شھيد_, 
   {{0xdd8c7092,0x99980311,0xdbe40241,0x9f500212}},	//   _هوه_, vorţ_, _léès, _свіч, 
   {{0x644928ae,0x00000000,0x00000000,0x00000000}},	//   ylgi, --, --, --, 
   {{0x7c243e24,0x00000000,0x00000000,0x00000000}},	//   cikr, --, --, --, 
   {{0x4a5528af,0x6d480142,0xd83801c6,0x46440014}},	// [1c6b0] _икис, _hyfa, хэр_, نپرِ, 
   {{0x7e6c0395,0x6d440213,0x68400133,0xab58002f}},	//   _èape, əkar, _ڕێزل, pfüb, 
   {{0x629802e8,0x3eac01c6,0xa7f800e8,0x27e8004d}},	//   _svuo, zuet_, _liñi, _tncn_, 
   {{0xe7f87aa4,0x6d480042,0x5f1000dc,0x602401e1}},	//   _एकटा_, _myfa, धनम्_, _mèmè, 
   {{0xed4446ca,0xa7f80789,0xa6d8022c,0xdb0401e7}},	//   _چپ_, _niñi, _oyði, _sciú, 
   {{0x7c2528b0,0x8c3c0205,0x81a885cf,0x10681df2}},	//   zikr, muğu, গ্ন_, _ﺷﺎﺭﯨ, 
   {{0x200c0280,0x8c3c0259,0x6d480109,0x7c2528b1}},	//   _plgi_, luğu, _nyfa, yikr, 
   {{0x3ead28b2,0xa7f800e8,0x90e420d4,0x7174c5df}},	//   tuet_, _biñi, اسون, нбәр_, 
   {{0x533528b3,0x6d480548,0x7c2400dc,0x81d40139}},	//   _бетт, _ayfa, vikr, _иоах, 
   {{0x3ead28b4,0x7d0815ed,0x6d48002d,0x63500131}},	//   ruet_, дног_, _byfa, _авғу, 
   {{0x6d480f7b,0x7c2528b5,0xd1b928b6,0x2fd40344}},	//   _cyfa, tikr, _سالا_, روید_, 
   {{0x6d480368,0xa6d80008,0x78ac0810,0x3eac030a}},	//   _dyfa, _eyði, vubv, puet_, 
   {{0x7c2528b7,0x765d01e7,0xdbe40241,0x3eac0d63}},	//   rikr, ympy, _jéés, quet_, 
   {{0x8c3c82aa,0x7c248a18,0x6024007f,0x78ac0099}},	//   duğu, sikr, _fèmè, tubv, 
   {{0x6d480cfd,0x7d0c03f9,0x692128b8,0xeb9c2f48}},	//   _gyfa, _ƙasu, амра, rhør_, 
   {{0xf98800b2,0x78ac0099,0xa7f800e8,0x8d5400d4}},	//   _ڪندي_, rubv, _yiñi, _стіч, 
   {{0x81a82f04,0x7c340022,0x3d0843aa,0xeb9c003b}},	// [1c6c0] গ্য_, _ijyr, ानके_, phør_, 
   {{0x5c7c0020,0x1cdc0327,0xf98800f1,0x97740166}},	//   _የተነሳ_, _ཤློ_, _تندي_, _әтнә, 
   {{0x66000108,0x00000000,0x00000000,0x00000000}},	//   önka, --, --, --, 
   {{0x969413f9,0x8c3c029f,0x81a80011,0x64a00006}},	//   _میرش, buğu, গ্ম_, раца, 
   {{0x8c3c03ee,0xab580165,0x00000000,0x00000000}},	//   cuğu, leür, --, --, 
   {{0xb0c40cc9,0xded00092,0x2c7800ef,0x00000000}},	//   вщик, ያኔን_, _līda_, --, 
   {{0xa7f80113,0xd25000f1,0xab58010b,0x00000000}},	//   _siñi, ټنګ_, neür, --, 
   {{0x4fd42038,0x6d4805ac,0x7c3400a2,0x3ce40fe6}},	//   ужит, _ryfa, _njyr, टिने_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x60240699,0x24640241,0xe29c08ce,0x7e7c0174}},	//   _pèmè, _tìmì_, _æða_, íspa, 
   {{0xdfcc01fc,0x2c7800ef,0xec14008e,0x7e6c0055}},	//   _къ_, _bīda_, венә_, _ũapt, 
   {{0xa7f80784,0x6d480f91,0x7e7c01e4,0x00000000}},	//   _tiñi, _vyfa, ŭspa, --, 
   {{0x7c2c010f,0x2fc401bf,0x9f9400c7,0x00000000}},	//   _ĉart, _ibog_, _рыхә, --, 
   {{0x6d480142,0x6aac01e4,0x8c3c03e0,0x00000000}},	//   _tyfa, rucf, vuğu, --, 
   {{0x19947274,0x992800a7,0xbb381870,0x00000000}},	//   рася, вюта_, ﺒﻨﻰ_, --, 
   {{0xa7f805c7,0x588528b9,0x2ee40010,0x8c3c0790}},	//   _liñv, рыра, _krof_, tuğu, 
   {{0x29880601,0x6d447aa0,0x00000000,0x00000000}},	// [1c6d0] _осно_, şkad, --, --, 
   {{0xa56525e8,0xdbe4004a,0x2c7800e2,0x387c00df}},	//   ندان, _réés, _zīda_, ŭtra_, 
   {{0xd5b800a7,0xdbe40036,0x3ce400ab,0x147415eb}},	//   ъст_, _séés, टिये_, لانج, 
   {{0x8c3c0205,0x68400345,0x00000000,0x00000000}},	//   puğu, _ئێرل, --, --, 
   {{0x59c0c2fc,0xeabc2b1d,0xc2c4038b,0xfc48013a}},	//   श्वर, ntù_, ايتي, _umíš_, 
   {{0x2fc40280,0xd378c7e0,0xddc00311,0xd04803b9}},	//   _abog_, нчә_, _minţ, _isdə, 
   {{0xdbe40036,0x00000000,0x00000000,0x00000000}},	//   _wéés, --, --, --, 
   {{0x60300311,0x40946431,0x00000000,0x00000000}},	//   rămo, _ەلار, --, --, 
   {{0x64580d04,0xfe4403b7,0xa7f80156,0xa6d80162}},	//   _ihui, лнио, _fiñv, _eyðv, 
   {{0x8ca4023e,0xee3528ba,0x645801ab,0x2fc4005c}},	//   _किशो, лны_, _hhui, _ebog_, 
   {{0x645803a2,0x2ee40a40,0x3c64c43c,0x55ac010f}},	//   _khui, _erof_, лког, וייַ, 
   {{0x26c80334,0xfce401e0,0xab58000d,0x00000000}},	//   _opco_, _ҡоло, veür, --, 
   {{0x645835b8,0x2ee528bb,0xbea528bc,0x7d0c0198}},	//   _mhui, _grof_, _салк, _ƙass, 
   {{0x2fc40bb8,0xa7f800e8,0xddc00311,0x64581368}},	//   _zbog_, _miñu, _dinţ, _lhui, 
   {{0x26c80ac5,0xa7f81bce,0x6458005b,0x35c401ad}},	//   _apco_, _liñu, _ohui, र्फ़, 
   {{0x26c824a6,0xab580254,0x00000000,0x00000000}},	//   _bpco_, reür, --, --, 
   {{0x7de80036,0xa7f81bce,0xa6d806ea,0xdca128bd}},	// [1c6e0] _gësä, _niñu, _oyðu, _сақи, 
   {{0x645928be,0xa76001ca,0x2af000bc,0x00000000}},	//   _ahui, скуд, ुहरु_, --, 
   {{0x645865f2,0xa7f80165,0xa504011c,0x00000000}},	//   _bhui, _riñv, лефа_, --, 
   {{0x64583c76,0xa7f81bce,0xf98801c8,0x53840150}},	//   _chui, _biñu, _تنگي_, рқаз, 
   {{0x64a0183c,0x64580ea3,0xeff0044e,0x38bc0054}},	//   _қата, _dhui, ልታዊ_, lïr_, 
   {{0xe1ec1e39,0xa7f8002e,0xa19009a5,0xb2c00150}},	//   كسى_, _diñu, башч, _ۇڭتۇ, 
   {{0x64580fa3,0x38bc0054,0x00000000,0x00000000}},	//   _fhui, nïr_, --, --, 
   {{0x2ee528bf,0xa6d808a7,0xa7f80de2,0x64581251}},	//   _prof_, _eyðu, _fiñu, _ghui, 
   {{0xa7f8bcb1,0xa0640063,0x8e14010a,0xdf04009d}},	//   _giñu, ћања_, идиц, гээл_, 
   {{0x3eb80192,0x00000000,0x00000000,0x00000000}},	//   àsta_, --, --, --, 
   {{0xdef40032,0x5c700139,0x00000000,0x00000000}},	//   _ҡыш_, йлэт, --, --, 
   {{0x2ee45282,0x6ee412e3,0xddd928c0,0xa7f81bce}},	//   _trof_, _مستل, rpuš, _yiñu, 
   {{0xddd81674,0x19580220,0xede4036b,0xa7f80166}},	//   spuš, ғаты_, _бўйн, _miñt, 
   {{0xeabc8295,0x2b90323b,0x23a801e1,0xddc00356}},	//   rtù_, جیکس, _kòjà_, _vinţ, 
   {{0x0ed80316,0xeabc030a,0x00000000,0x00000000}},	//   _बैतड, stù_, --, --, 
   {{0x7e6c0798,0x00000000,0x00000000,0x00000000}},	//   _éapr, --, --, --, 
   {{0x645801ab,0x6600b35a,0x25a80063,0x2af001f9}},	// [1c6f0] _rhui, önko, еђен_, ुहळु_, 
   {{0x645928c1,0xe66528c2,0xb4c021bd,0x9f480129}},	//   _shui, утбо, ्बू_, éléo_, 
   {{0xa7f80309,0x64580e89,0xb978011a,0xc79800e5}},	//   _siñu, _phui, _בנתי, _لھذا_, 
   {{0xd56528c3,0x78f80375,0xb865050d,0x95641171}},	//   ступ, _ספרו, _پاپو, съуд, 
   {{0x64580084,0x04f4015b,0xd6840117,0x00000000}},	//   _vhui, চনের_, _гусп, --, 
   {{0x00840b2c,0x645928c4,0x412800f3,0x72a000d1}},	//   алко, _whui, коло_, زەمن, 
   {{0x645928c5,0x80141ea2,0x65740882,0xd4e4fb98}},	//   _thui, ифиц, ābhā, _люти, 
   {{0x645928c6,0xc004030d,0x7e7c0162,0x00000000}},	//   _uhui, рпик, íspo, --, 
   {{0xddc800da,0x63b928c7,0xa28028b1,0x6f6002e8}},	//   _augš, _icun, _ایتو, овъз, 
   {{0x38bc0227,0x00000000,0x00000000,0x00000000}},	//   yïr_, --, --, --, 
   {{0xc0d40214,0x00000000,0x00000000,0x00000000}},	//   _خياب, --, --, --, 
   {{0xa7f928c8,0x2f3c063f,0x910400a7,0x2244030a}},	//   _miñs, ịga_, _учуд, lonk_, 
   {{0x3f8d28c9,0xa7f805c7,0x8c3c0790,0xddc04e96}},	//   mbeu_, _liñs, tuğr, _einš, 
   {{0x3eace78f,0xddc06b92,0xd0100150,0x0bf40150}},	//   mret_, _finš, _ولە_, _ۇيىڭ, 
   {{0xb864708e,0x77941677,0x78bc0334,0x5ca000f7}},	//   لارو, ијац, _qqpv, _البە, 
   {{0x63b800ca,0x772800b7,0xa7a455cc,0x224528ca}},	//   _ncun, _ተመልሰ, икса_, honk_, 
   {{0x3eac002d,0xab580112,0x224403cd,0x7624b6d4}},	// [1c700] nret_, nfül, konk_, амаз, 
   {{0xe61528cb,0xd1dc02d3,0xa7f8030a,0xab580793}},	//   аду_, ኔታት_, _biñs, ifül, 
   {{0x22440699,0x3ead28cc,0xb4c0b7b0,0xa7f80166}},	//   donk_, hret_, ्बे_, _ciñs, 
   {{0x3ead28cd,0xa7f8030a,0x5f180154,0x37e401a9}},	//   kret_, _diñs, _তখনও_, _томг, 
   {{0x3eac04ce,0x33182be7,0xa3e401ad,0x1b500023}},	//   jret_, خزاد_, _बफर_, _መንበራ, 
   {{0x3eacec5d,0x30a502b0,0x63b808e5,0xa6d8041e}},	//   dret_, арив, _ecun, _eyðs, 
   {{0x3ead28ce,0x00000000,0x00000000,0x00000000}},	//   eret_, --, --, --, 
   {{0xcfe80611,0x3ead28cf,0x63b8007b,0x20a400e1}},	//   افظه_, fret_, _gcun, _गिरध, 
   {{0x3ead28d0,0x68e000d2,0xf4d002dd,0x7c2c00df}},	//   gret_, _ándv, _ءﺗﻮﺭ, _ĉarp, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa1780bd9,0x3eac9658,0x7bc40fac,0x00000000}},	//   _סטאט, aret_, ffku, --, 
   {{0x3ead28d1,0x91fc0882,0xac240114,0xddc00419}},	//   bret_, _bhāg, рфок, _vinš, 
   {{0x91fc002b,0x9c3808fc,0x2aa802e8,0x798000a2}},	//   _chāg, рпят_, ътно_, _şowa, 
   {{0xad2528d2,0x1994010b,0x2c78002e,0x48241ca1}},	//   _پرتو, жаря, _tëd_, ڭىرق, 
   {{0xb4c128d3,0x91fc002b,0x7c340332,0x00000000}},	//   ्बो_, _ihād, ógrá, --, 
   {{0xa7f80165,0x0708009f,0xab8401a9,0x00000000}},	//   _riñs, هيزي_, _тукк, --, 
   {{0x1bb87427,0x91fc00dc,0xd7f928d4,0xa6d802d2}},	// [1c710] _ضايع_, _khād, шур_, _ryðs, 
   {{0x63b928d5,0xa7f80165,0xa6d808ce,0x00000000}},	//   _scun, _piñs, _syðs, --, 
   {{0x3eac496e,0x69c40158,0x4374007b,0xc92400fe}},	//   zret_, mfje, مهار, _মুৰত_, 
   {{0x25f8c725,0x69c528d6,0x22447bbf,0xa7f80165}},	//   लॉजी_, lfje, wonk_, _viñs, 
   {{0x170800dd,0xa6d80162,0x00000000,0x00000000}},	//   _پہلی_, _eyðr, --, --, 
   {{0x3ead28d7,0x409528d8,0x56940b2c,0xdd280024}},	//   vret_, брит, _фарт, _lėša, 
   {{0x224528d9,0x85046520,0x69c401f5,0x9f4c0129}},	//   ronk_, _اوزن, ifje, _ingé_, 
   {{0x63b928da,0x3f8c026c,0xa7f80139,0xf49401d9}},	//   _ucun, ubeu_, _kiñq, _چھۆت_, 
   {{0x6830003d,0x3f8d28db,0xe1f0e9ad,0x91fc002b}},	//   għdi, rbeu_, _وسط_, _bhād, 
   {{0x69c4de16,0x3eac2b9d,0xab580e78,0x91fc00cd}},	//   jfje, rret_, rfül, _chād, 
   {{0xab580e78,0x8cb4109a,0x69c4353e,0x7fb8b460}},	//   sfül, осяч, dfje, _مهار_, 
   {{0x69c40d27,0x6e900050,0xaa780022,0x00000000}},	//   efje, _کلوا, avým, --, 
   {{0x1ee451ae,0xdce4ca2c,0x91fc00b0,0xdb080139}},	//   _خوشی_, ılık, _tiāt, _ülül, 
   {{0xaa8009a5,0xfce8a9f3,0xcd2928dc,0x69c400cc}},	//   ýýar, _مفتي_, اسین_, gfje, 
   {{0x48780276,0x16d03323,0x7e780142,0xf770007b}},	//   истя_, हब्ब, _huwp, كاء_, 
   {{0x9f4cb7e6,0x69c401f5,0x69c000a2,0x998c012d}},	//   _angé_, afje, _önen, ódł_, 
   {{0xb6a40c72,0xa6d8041e,0x6030054e,0x00000000}},	// [1c720] сизл, _syðr, gămi, --, 
   {{0xfa3528dd,0xc1e03af4,0x182801d5,0x00000000}},	//   _دربد, पयोग, _چقدی_, --, 
   {{0xd911228b,0x18283ee6,0x62880373,0xeb9c00b5}},	//   _غیر_, _نقدی_, epgo, rkøv_, 
   {{0xad3400c8,0xec70010f,0x00000000,0x00000000}},	//   זנעס_, פֿע_, --, --, 
   {{0x60300356,0xe1200075,0x00000000,0x00000000}},	//   cămi, үмчи, --, --, 
   {{0xf07429db,0x675400f1,0x00000000,0x00000000}},	//   бикә_, _دخپر, --, --, 
   {{0x1fc003d4,0x71a400c7,0x73e40408,0xa50403cf}},	//   ্যনস, _ҳазз, _ловз, _лера_, 
   {{0x6b5c01e1,0x6ac000fe,0x00000000,0x00000000}},	//   _jàgí, ষয়টো, --, --, 
   {{0xb8e803bd,0x71a40139,0x69c4143a,0x00000000}},	//   _ིད_, _газз, yfje, --, 
   {{0x2f3c01f2,0x4d980212,0x00000000,0x00000000}},	//   ịgo_, шкою_, --, --, 
   {{0x50dc6d58,0xab5928de,0x60300356,0xcfe00154}},	//   _मनिष, rfüm, zămi, ভাবন, 
   {{0xdb040005,0xc6040574,0x00000000,0x00000000}},	//   _aciñ, _शक्य_, --, --, 
   {{0xceb83769,0x940c00ac,0x7ae000f3,0x69c40ac8}},	//   _тәй_, ülər_, _šotr, tfje, 
   {{0x4c94010b,0xab5801b8,0x69c403cd,0x21400200}},	//   _дикс, lfük, ufje, _ëshë_, 
   {{0x5d980302,0x69c428b3,0x5e5400df,0x00000000}},	//   _גבוה, rfje, _היגע_, --, 
   {{0x2d9d28df,0x08541fe2,0x69c40ac8,0x00000000}},	//   late_, іваю, sfje, --, 
   {{0x798001f2,0x2d9cdbd9,0x00000000,0x00000000}},	// [1c730] ọwad, oate_, --, --, 
   {{0xdb040639,0x2d9d28e0,0x60300311,0x00000000}},	//   _heiß, nate_, rămi, --, 
   {{0x2d9c0276,0xeff002d3,0x88580353,0xbb3c0092}},	//   iate_, ውሳድ_, _винс_, _ያስተዋ, 
   {{0x2d9d28e1,0x6d8c0084,0xaa780306,0x47d40592}},	//   hate_, _ṱalu, jvýk, _بيحر, 
   {{0xdb04203d,0x59c00709,0x00000000,0x00000000}},	//   _meiß, श्कर, --, --, 
   {{0x2d9c16ba,0x1a9c008f,0x249800f2,0xa7740205}},	//   jate_, ריגע, _مخرب_, şöğr, 
   {{0x91fc00b8,0x00000000,0x00000000,0x00000000}},	//   _bhāb, --, --, --, 
   {{0x3f981aac,0x7e7802d1,0xcfac04c5,0x6e2806be}},	//   úsu_, _puwp, ক্সন, _amfb, 
   {{0x644928e2,0x2d9d28e3,0x66040218,0xbe380212}},	//   mogi, fate_, _kojk, ичої_, 
   {{0x3cc80228,0xef1528e4,0x6604897d,0x3ce400bc}},	//   алоо_, юмы_, _jojk, टिले_, 
   {{0x6d4504ff,0x91fc02b5,0x20e416a3,0xdb040e78}},	//   şkan, _tiār, _uđi_, _beiß, 
   {{0x644928e5,0x2f48063f,0x6eb00b4c,0x00000000}},	//   nogi, ịtịm, _आमचु, --, 
   {{0xab580730,0x6fbc04c5,0x91fc0374,0x2d9cca05}},	//   nfüh, ্যশৈ, _whāe, bate_, 
   {{0x2d9d28e6,0x660400f3,0x31500023,0x91fc0055}},	//   cate_, _nojk, _ምንባር, _ihāc, 
   {{0xab5803fa,0x64480428,0x273400d7,0x00000000}},	//   hfüh, kogi, yžné_, --, 
   {{0x764c003e,0x3ff8008f,0xdb040112,0xab580112}},	//   _skby, ספּע, _geiß, kfüh, 
   {{0x644800a9,0xaa780122,0xba24004e,0x00000000}},	// [1c740] dogi, jvýh, _мдик, --, 
   {{0x660401fa,0xeb9c03cd,0xab58002f,0xf65400d4}},	//   _cojk, dhøy_, dfüh, ітаю, 
   {{0x160003f3,0x644928e7,0x60300311,0x68300327}},	//   लॉगर_, fogi, lămu, eħdu, 
   {{0x2d9d28e8,0x528400c2,0xab580e78,0x34b800e1}},	//   zate_, зҳаб, ffüh, _उमीद, 
   {{0x2d9d28e9,0x537c044e,0xab580112,0x68300135}},	//   yate_, _ብዓወት_, gfüh, għdu, 
   {{0x2d9d28ea,0x66041591,0x9f4c00e5,0x00000000}},	//   xate_, _gojk, _logó_, --, 
   {{0x644928eb,0x2d9d28ec,0x04580131,0x00000000}},	//   bogi, vate_, ججەت_, --, 
   {{0x2d9d28ed,0x644843dc,0xdef00125,0x68e0025a}},	//   wate_, cogi, ልጣን_, _ânde, 
   {{0x2d9d2277,0xdb0403fa,0xe4207ba2,0x00000000}},	//   tate_, _reiß, _تکلي, --, 
   {{0x70f528ee,0x2734004d,0xae78009d,0x00000000}},	//   _وسائ, ầng_, лсүх_, --, 
   {{0x2d9d28df,0xdca00261,0xcfac0154,0xdef00092}},	//   rate_, маќи, ক্ষন, ልጣኔ_, 
   {{0x2d9d28ef,0x00000000,0x00000000,0x00000000}},	//   sate_, --, --, --, 
   {{0x2d9d28f0,0xaf34214b,0x9a840139,0xe9e4009d}},	//   pate_, _برات, дусл, оцво, 
   {{0x644928f1,0xdb040730,0x2d9d28f2,0x00000000}},	//   zogi, _weiß, qate_, --, 
   {{0x69c00ab7,0x644928f3,0x660433fe,0xaa780306}},	//   _önem, yogi, _rojk, zvýh, 
   {{0xeb9c0fac,0x58d400d4,0x00000000,0x00000000}},	//   yhøy_, ьост, --, --, 
   {{0x660528f4,0xeb9c0158,0xe3bc0432,0x443803e0}},	// [1c750] _pojk, skøs_, _öñi_, _ıs_, 
   {{0x644928f5,0x5a340724,0xe29c01a8,0x96ac000d}},	//   wogi, _оныт, _æði_, _चिरउ, 
   {{0x644928f6,0x59c406ab,0xa4840eff,0x2ec000cc}},	//   togi, _लॉटर, زجان, ্টিষ, 
   {{0xab5928f7,0x7e7c0115,0x66040210,0xd49928f8}},	//   tfüh, ŭspi, _wojk, юру_, 
   {{0x644928f9,0xddc800d7,0x657815b7,0xa86001ee}},	//   rogi, _čiži, _şuhu, _неүҙ, 
   {{0x409528fa,0xab580730,0x644928fb,0x850401ed}},	//   прит, rfüh, sogi, _ٹورن, 
   {{0xb8808ea8,0x644928fc,0xab580639,0x439528fd}},	//   žíva, pogi, sfüh, _навс, 
   {{0x6440d829,0x6e3801e4,0xe1f000ec,0x644803e3}},	//   énid, entb, _ڪسر_, qogi, 
   {{0x442d28fe,0x6d44825f,0xa1c00046,0x5334516c}},	//   _ime_, şkal, _жұлд, _жетт, 
   {{0x442c0270,0x41b40220,0xdb0801e1,0x00000000}},	//   _hme_, _ءمار, _àlél, --, 
   {{0x442c0280,0x00000000,0x00000000,0x00000000}},	//   _kme_, --, --, --, 
   {{0xca280d65,0xe61c0030,0x442c0129,0xdef01ee0}},	//   _גם_, _stôl_, _jme_, ልጣኑ_, 
   {{0x442d28ff,0x59b40137,0x00000000,0x00000000}},	//   _mme_, мөнс, --, --, 
   {{0x60300311,0x612802d3,0xdb240248,0xed5c0419}},	//   rămu, _እንዳኣ, _àsín, šľam_, 
   {{0x442d2900,0x9f4c01e1,0x6e1401ec,0x34b874f6}},	//   _ome_, _gogò_, _ءيىس_, _उमेद, 
   {{0x1ca8025c,0xbb4402d5,0x59740220,0x201c7a03}},	//   _བྷར_, _нейк, зығу, nhui_, 
   {{0x09d00011,0xdef00023,0x00000000,0x00000000}},	// [1c760] ায়া, ልጣኒ_, --, --, 
   {{0x442d2901,0x15b40131,0x3f9d2902,0x201c000d}},	//   _ame_, بەسس, _lewu_, hhui_, 
   {{0x442c431a,0x799c02d0,0x68300327,0xd2500133}},	//   _bme_, _iepw, għds, ۆۆر_, 
   {{0x442d2903,0x3f9c0175,0x00000000,0x00000000}},	//   _cme_, _newu_, --, --, 
   {{0x442d2904,0x201c0451,0x1ca8031c,0x00000000}},	//   _dme_, dhui_, _བྷལ_, --, 
   {{0x442c44fc,0x59c00b7c,0x761800db,0xf7701183}},	//   _eme_, श्चर, _اقسز_, _ياڭ_, 
   {{0xa0852905,0x799c007f,0x442d2906,0xb51c0354}},	//   псыз_, _mepw, _fme_, _сивĕ_, 
   {{0xd0100597,0x442c013c,0x6538010f,0x00000000}},	//   ئلة_, _gme_, _העלד, --, 
   {{0x9f4c0161,0xe2940311,0x644007ea,0xb2252907}},	//   _angâ_, _нат_, énie, _емал, 
   {{0xab592908,0x442c036b,0x3f9c0248,0x799c014f}},	//   ngüe, _zme_, _eewu_, _nepw, 
   {{0xa1100046,0x442cffcc,0x201c009a,0xdce005d1}},	//   _كوكت, _yme_, bhui_, _benı, 
   {{0x96ac000d,0x201d2909,0x00000000,0x00000000}},	//   _चिंउ, chui_, --, --, 
   {{0xc9040882,0xdce003e0,0x00000000,0x00000000}},	//   रह्म_, _denı, --, --, 
   {{0x3f9c04ba,0xbe3000c7,0xda04084c,0x00000000}},	//   _zewu_, _аҕьы, нчсп, --, 
   {{0x799c02e2,0x00000000,0x00000000,0x00000000}},	//   _depw, --, --, --, 
   {{0x6d8c06d6,0xd24403e6,0x3f9c00e8,0xdef0001f}},	//   _ṱahu, _ڕۆ_, _xewu_, ልጣኝ_, 
   {{0x442c1529,0x1ca8031c,0xb6c00137,0x00000000}},	// [1c770] _rme_, _བྷཧ_, көрд, --, 
   {{0x442c0038,0x1dcc090a,0x68300327,0x15a80395}},	//   _sme_, त्पत, għdr, зъци_, 
   {{0x442d290a,0xdce003e0,0xded40023,0x00000000}},	//   _pme_, _yenı, ሪብና_, --, 
   {{0x68240354,0x5ed000eb,0x00000000,0x00000000}},	//   _хьоз, তিতে, --, --, 
   {{0x37c08c00,0x3f9c0098,0x94743bd6,0xaa780124}},	//   _шәрб, _rewu_, ردما, avýv, 
   {{0x3f9c04fb,0x00000000,0x00000000,0x00000000}},	//   _sewu_, --, --, --, 
   {{0x94d4bdd4,0x442d290b,0x9f4000bc,0x6601290c}},	//   _порц, _tme_, ějí_, önku, 
   {{0x442d290d,0x606000d1,0x1dcc00cd,0xf8a800df}},	//   _ume_, رۇشل, त्नत, קספֿ, 
   {{0x91fc25fa,0x443c0208,0x80a81d3b,0x00000000}},	//   _whāa, mnw_, _टिके, --, 
   {{0x201d290e,0xdce00790,0x00000000,0x00000000}},	//   shui_, _senı, --, --, 
   {{0xc1047b63,0x799d290f,0x91fc002b,0x443c007f}},	//   _توضي, _repw, _khān, onw_, 
   {{0x3f1421f0,0x443c00a9,0x629801f2,0x2f4c02e3}},	//   _одес, nnw_, _kwuo, ịnị_, 
   {{0x6b9c014f,0x799c0455,0x88b8031c,0x34b80456}},	//   _deqg, _pepw, _བའུར, _उम्द, 
   {{0x5ed000eb,0x00000000,0x00000000,0x00000000}},	//   তিদে, --, --, --, 
   {{0x66140332,0x6d4c0254,0x3e88009f,0x00000000}},	//   dkxk, übat, _اَڪَ_, --, 
   {{0x6f14006d,0xfd2801e1,0xa9643ed6,0x799c014f}},	//   _życi, _enìà_, фиса_, _wepw, 
   {{0x799c014f,0x3ce402c3,0x00000000,0x00000000}},	// [1c780] _tepw, टिके_, --, --, 
   {{0x1ca80003,0x91fc00b8,0x97740daf,0x443c0042}},	//   _བྷོ_, _ahān, _үтмә, enw_, 
   {{0x1dcc0882,0xab581b08,0x91fc00cd,0xeb9c00cc}},	//   त्यत, rgüe, _bhān, ljøa_, 
   {{0x91fc002b,0xab5804cc,0x7980010b,0x5bdc00bc}},	//   _chān, sgüe, _şowh, _बसोव, 
   {{0x36692910,0x412800f7,0x91fc00cd,0x00000000}},	//   _мамо_, үнчү_, _dhān, --, 
   {{0xe1ec1916,0x6298012d,0x1dcc00cd,0xab580205}},	//   لسى_, _dwuo, त्मत, lgüc, 
   {{0x6440d3eb,0x9f4c0109,0x00000000,0x00000000}},	//   énic, _angà_, --, --, 
   {{0x1ca80003,0xeea81f99,0x91fc0055,0x00000000}},	//   _བྷེ_, оток_, _ghān, --, 
   {{0x6b9c0113,0xdb0401ab,0x99980153,0xb12c0092}},	//   _reqg, _ndià, norų_, _እንዲዳ, 
   {{0x43752911,0x4cb800d4,0xed5c00d0,0x00000000}},	//   _чуст, плою_, áľom_, --, 
   {{0xe61c000f,0xdfcc0451,0xa5b400d9,0x00000000}},	//   _stôk_, _چيم_, וליק_, --, 
   {{0xdfcc131e,0x09b80882,0xbf380150,0x70500345}},	//   _نيم_, ेभ्य, _اداﻣ, _جۆبا, 
   {{0x1ca80327,0xeb48005b,0x99980153,0x5f00011c}},	//   _བྷཻ_, ючок_, jorų_, _изца, 
   {{0x312c02d3,0x99980024,0x66140332,0x00000000}},	//   _እንታይ, dorų_, xkxk, --, 
   {{0x6ce402bf,0x80c000dc,0xad241291,0x00000000}},	//   _ціле, रूपे, _ترشو, --, 
   {{0x999800c0,0x00000000,0x00000000,0x00000000}},	//   forų_, --, --, --, 
   {{0x4ebc045e,0xf1c80030,0x1cb80327,0xaa643acc}},	// [1c790] _অনুল, _kráľ_, _ཅའོ_, _оток, 
   {{0xc4cc09bd,0xe664010a,0xb0ac01f9,0x00000000}},	//   রয়োজ, фтбо, _टिंग, --, 
   {{0x88b80327,0xa7f80139,0xaa7800e4,0xb4b40124}},	//   _བའིར, _miñz, avýt, еихә, 
   {{0x321c00ee,0x00000000,0x00000000,0x00000000}},	//   _alty_, --, --, --, 
   {{0x443c017a,0xd68424fc,0x67440006,0x7980010e}},	//   rnw_, _аусп, _цэнз, _şowi, 
   {{0x91fc1f4c,0x32f00150,0x443c010a,0x63ac0327}},	//   _whān, اكوز, snw_, _żinġ, 
   {{0x94a83f3a,0x2900025c,0x91fc00b8,0x70b000f2}},	//   _отта_, nxja_, _thān, هموض, 
   {{0x63e00150,0xb144158b,0x00000000,0x00000000}},	//   _جيرە, رینم_, --, --, 
   {{0x7a200231,0xd08c0023,0x71740166,0x00000000}},	//   _hôte, _ዚደልዩ_, мбәр_, --, 
   {{0x6ce80d5f,0x00000000,0x00000000,0x00000000}},	//   टिंग_, --, --, --, 
   {{0x7f947fb5,0xddd80327,0xf65000d9,0x0ea800cf}},	//   _заех, mpuż, רצי_, пкөй_, 
   {{0xeb94ac58,0xdb040005,0x7ca8001f,0x8ca0033f}},	//   нию_, _adiá, _መደረግ_, _खबरो, 
   {{0x91fc0069,0x4b5400a7,0x00000000,0x00000000}},	//   _ohāl, върт, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa964e514,0xfe4001ed,0xae180375,0x81e8015b}},	//   еира_, _لکھی, _מוסכ, যাপ_, 
   {{0xcc340588,0xdb249cad,0x2ba4012d,0x00000000}},	//   _ахьы, _لوبی, _ख़या, --, 
   {{0x68412912,0xfaa80451,0x91fc002b,0xe8506bcc}},	// [1c7a0] унта, _عهدي_, _bhāl, انقد, 
   {{0xba74035d,0x91fc00b8,0xab580112,0xd9e400cc}},	//   _ثابت, _chāl, rfüt, মাহম, 
   {{0x490046e8,0x7a212913,0xeabc05d5,0x0b440092}},	//   _күрг, _côte, nzùn_, _ያስተማ, 
   {{0x1dcc00dc,0xf2c400f3,0x2c780171,0x00000000}},	//   त्तत, ескн, _zīds_, --, 
   {{0x81e809bd,0xeb9c0158,0xab580205,0x65c001ec}},	//   যান_, kjøn_, lfür, _әбса, 
   {{0xf1a92914,0xab58067c,0x321c0334,0x35c4033f}},	//   ساته_, ngüa, _qlty_, र्ख़, 
   {{0xe6412915,0xb37c02d3,0xe210088c,0x91fc02b5}},	//   _серп, _ሕጂውን_, طبوع, _whāo, 
   {{0xefb0cf73,0x20643f6e,0x91fc002b,0xe45400d8}},	//   ایشگ, ншып_, _ihām, _зжс_, 
   {{0xa2b001d3,0x232421f3,0x6838008e,0x00000000}},	//   _مینڈ, _зоти_, lädä, --, 
   {{0x321c0204,0xd1bc001f,0xdeec0022,0xaa7802f0}},	//   _ulty_, _ታስቦ_, _ҩы_, zvýs, 
   {{0xddc00010,0xaa780306,0x1ca80327,0x3de00011}},	//   _finž, jvýr, _བྷཱ_, বাংল, 
   {{0xdd8c6566,0xf1c801ef,0xbe800124,0x611805d0}},	//   _әш_, _dráž_, ықәи, _מובה, 
   {{0xdcec010f,0x68380958,0x2c78139f,0x8f0000c0}},	//   _ĉeĥa, hädä, _dūda_, _мiс_, 
   {{0x673800f3,0x6838008e,0x00000000,0x00000000}},	//   _žujo, kädä, --, --, 
   {{0x58d42386,0x378c063f,0x998501ff,0xab84026b}},	//   лорт, _ọgọ_, الفو, _пупк, 
   {{0x1ca80135,0x195800ee,0x68380139,0x00000000}},	//   _བྷི_, хасы_, dädä, --, 
   {{0x6b980436,0xaae400c6,0x89d801ed,0x91fc002b}},	// [1c7b0] ðugu, _أسبو, _ہوکر_, _phāl, 
   {{0x68e0006a,0x91fc00cd,0xe4a46c48,0x68380166}},	//   _ândo, _bhām, ердо, fädä, 
   {{0xe1fc01dc,0x2cbd2916,0x81e8015b,0xd5b89731}},	//   _đó_, nutd_, যাম_, эст_, 
   {{0x43741564,0x9f5c008c,0xdce001e4,0x91fc00cd}},	//   نهار, kkuð_, _genĵ, _dhām, 
   {{0x2bd03f55,0x91fc0055,0x99e400fe,0xd6d84130}},	//   ध्या, _ihāj, মাৰক, _птр_, 
   {{0x1a9c00c8,0xd04806be,0x70500472,0x6838013d}},	//   לידע, _ipdə, ینوا, bädä, 
   {{0x2fc401ee,0x2ee40151,0xddc80064,0x925800f2}},	//   _bcog_, _asof_, _pugž, رشهر_, 
   {{0x7f7406a7,0xa7f80055,0x00000000,0x00000000}},	//   купц, _piñy, --, --, 
   {{0x4274efd5,0x81e80f22,0x25a00003,0xd2d401d5}},	//   _агас, যাব_, _kejl_, _مغلب, 
   {{0xee352917,0x518405f5,0x0044004b,0xaa7802f0}},	//   кны_, _буца, ریږي_, zvýr, 
   {{0x25a12918,0x2c7800ef,0xaa7800e4,0x00000000}},	//   _mejl_, _sūda_, yvýr, --, 
   {{0x3de02aab,0x27e801ab,0x25a00003,0x00000000}},	//   বাইল, _nacn_, _lejl_, --, 
   {{0xeb9d00b0,0xef0c75d7,0x20100210,0x00000000}},	//   mjøl_, _тм_, ębić_, --, 
   {{0x200ca059,0xddc00003,0x00000000,0x00000000}},	//   _hogi_, _jinż, --, --, 
   {{0xe9a12919,0xbb3c04a9,0x200d291a,0x68e000d2}},	//   расп, ﻐﺎﻥ_, _kogi_, _ândl, 
   {{0xf770158a,0x200c00dd,0x237c014b,0xab59291b}},	//   لاء_, _jogi_, _nguj_, rfür, 
   {{0x7bd401aa,0x200c0120,0x25a0009b,0xf5e812d7}},	// [1c7c0] _ibyu, _mogi_, _bejl_, ммал_, 
   {{0x200d291c,0x64401dee,0xdb040120,0xddc0031c}},	//   _logi_, énin, _adiç, _ninż, 
   {{0x27e8007f,0xab580112,0x200c058a,0xd9101f7e}},	//   _facn_, ngün, _oogi_, _ایز_, 
   {{0x7af4489c,0xb4d0068f,0x200c6c50,0x682000c5}},	//   _kryt, _वही_, _nogi_, _põde, 
   {{0x25a0019b,0x7bd40526,0x91fc02b5,0xab58010e}},	//   _fejl_, _mbyu, _whām, hgün, 
   {{0xdb05291d,0x2ee401c7,0x96d400c7,0x25a12264}},	//   _ediç, _rsof_, _исҳә, _gejl_, 
   {{0xa0a08395,0x200d291e,0x7af402d5,0x7bd40280}},	//   ашыл, _bogi_, _lryt, _obyu, 
   {{0xe1f430cb,0x200d291f,0x682000c5,0x7af4035a}},	//   егә_, _cogi_, _tõde, _oryt, 
   {{0x765c017a,0xa2e00166,0x2e4802e8,0xa0640114}},	//   olpy, _котд, дяно_, њања_, 
   {{0x7bd40230,0x1ca80135,0xe294030d,0x7c24002f}},	//   _abyu, _བྷང_, _раф_, ehkr, 
   {{0x9e002b2a,0xbde401e1,0x61400395,0x80c03507}},	//   рчыл, _ibẹ̀, _кефа, रूदे, 
   {{0x7af52920,0x200c0810,0x91fc00b0,0xddd80309}},	//   _bryt, _gogi_, _ohāk, rquš, 
   {{0x41c82435,0x68e000d2,0x48142c11,0x2b44009d}},	//   _रामस, _ándz, қмас, тэнг, 
   {{0x3eb801f1,0x7bd40a49,0x200c0198,0x7af4771b}},	//   áste_, _ebyu, _zogi_, _dryt, 
   {{0x1958e277,0x108c0046,0x6d4c000f,0x9e780115}},	//   вары_, _ﻗﺎﺯﯨ, ûbad, _קנופ, 
   {{0x7c252921,0x628c0109,0x7af52922,0x91fc00b8}},	//   chkr, _écog, _fryt, _bhāk, 
   {{0x7af52923,0x91fc002b,0x27e8003b,0x25a001e3}},	// [1c7d0] _gryt, _chāk, _vacn_, _pejl_, 
   {{0x91fc0055,0xdb0801e1,0x00000000,0x00000000}},	//   _dhāk, _àlál, --, --, 
   {{0x261c006a,0xd1cc0125,0x3c212924,0x9f4c01e6}},	//   _fîon_, ጣናት_, _hóva_, _ingå_, 
   {{0xbde401e1,0xa3100598,0x3c200588,0x58d400db}},	//   _abẹ̀, иялә, _kóva_, _тоют, 
   {{0x200c0086,0xab580209,0x108c0873,0x91fc00b8}},	//   _rogi_, zgün, _ﻗﺎﺭﯨ, _khāh, 
   {{0x78b81326,0x200c0b23,0x765c0175,0x25a0036e}},	//   štve, _sogi_, clpy, _uejl_, 
   {{0x200d2925,0x16340a8f,0x222401d9,0x5eac00cc}},	//   _pogi_, _теря, _یٲری_, _কহেং, 
   {{0x2d8d2926,0x3fe434d8,0x00000000,0x00000000}},	//   _affe_, ужив, --, --, 
   {{0x69d436ed,0x6d48035a,0xddc00003,0x611001ef}},	//   _obxe, _axfa, _tinż, _bělá, 
   {{0x7bd4020b,0x7d08026a,0xbde401e1,0xeb9c0158}},	//   _sbyu, еног_, _gbẹ̀, sjøl_, 
   {{0x7fd40efb,0x81e802f5,0x200c1140,0x6110012c}},	//   _білі, যাদ_, _togi_, _dělá, 
   {{0x2d8d2927,0xab592928,0x00000000,0x00000000}},	//   _effe_, rgün, --, --, 
   {{0x6d4804ce,0x68f40139,0x2bd000e1,0xdd00d16c}},	//   _exfa, _arxd, ध्धा, ısıd, 
   {{0x7c2402d3,0x3eac262a,0xdb240248,0x00000000}},	//   shkr, mset_, _ìrír, --, 
   {{0x3ead2929,0xe7340046,0x7af40204,0x7980010b}},	//   lset_, ңес_, _wryt, _şows, 
   {{0x1dcc26e4,0x3f8cd015,0x7bd40526,0xdb8c0131}},	//   त्रत, nceu_, _ubyu, ﯗﻟﺪﻯ_, 
   {{0x3eacf06a,0x1db52877,0x7bc4003e,0xbd4400f1}},	// [1c7e0] nset_, _आयात, mgku, _جنګي, 
   {{0x3eac049b,0x91fc0055,0xe6d403b2,0x7bc4007c}},	//   iset_, _ghāh, _ótýð, lgku, 
   {{0x91fc0374,0x7bc4017a,0xab580112,0xf7700ccb}},	//   _whāk, ogku, hgül, _گاد_, 
   {{0x7bc5292a,0x3eac426d,0x69c00365,0x2494034c}},	//   ngku, kset_, _öner, انند_, 
   {{0xf7701c67,0x3ead292b,0x76640592,0x7335292c}},	//   _داد_, jset_, _مُحم, درائ, 
   {{0xab583262,0xe2940640,0xeee8000d,0x3ca800cc}},	//   dgül, ћај_, _जईबऽ_, _কমনৱ, 
   {{0xdb040036,0xa155292d,0xe0cc007b,0x3eac0200}},	//   _beië, лашу_, كزي_, eset_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xefdc02d3,0x3eac2bd5,0x128801b9,0x00000000}},	//   ሓሕዛ_, gset_, _ризқ_, --, 
   {{0x7c3400e4,0x38700076,0x1ed400ae,0x00000000}},	//   _amyr, hmyr_, ابيب_, --, 
   {{0xec1418ce,0xdc78001f,0x3ead292e,0x41e000bc}},	//   генә_, አብሄር_, aset_, फ़रस, 
   {{0x3c2000e4,0x3ead292f,0x2904031c,0x30741180}},	//   _póva_, bset_, _ħna_, _сузс, 
   {{0xe0412930,0xadf00166,0xa0640354,0x00000000}},	//   _унци, _голә, _саца_, --, 
   {{0x7e6c0395,0x2c780241,0x2d8c0726,0x63780139}},	//   _èapp, _bàdì_, _uffe_, _hänü, 
   {{0xbd552931,0xf79001e1,0x00000000,0x00000000}},	//   _پروژ, _ọmọo, --, --, 
   {{0x58843ae0,0x6e392932,0x6d447f77,0x91fc02b5}},	//   сыра, litb, şkas, _whāh, 
   {{0x0a340020,0x1dc0dd5c,0x5694004e,0x00000000}},	// [1c7f0] _ባለሙያ, _төөн, йатт, --, 
   {{0x9f4c011f,0x7c340393,0x38700076,0xa5640a12}},	//   _angû_, _zmyr, amyr_, هدان, 
   {{0xfa340046,0x91fc00a3,0x69c4143a,0x7c3403cb}},	//   _түрі_, _ghāi, mgje, _ymyr, 
   {{0x14752933,0x69c52934,0x947400ec,0x00000000}},	//   مانج, lgje, مدنا, --, 
   {{0x427405f5,0x3eac010a,0x6e38031c,0x00000000}},	//   агдс, xset_, kitb, --, 
   {{0x69c52935,0x44e400a9,0xa49027a1,0x3eac346c}},	//   ngje, _tŷ_, _هیئت, vset_, 
   {{0x6e392936,0x69c4000f,0xeb9c0158,0xfbc42e1e}},	//   ditb, igje, skøy_, _वालम, 
   {{0x3ead2937,0x44392938,0x3f8c003e,0x69c4036e}},	//   tset_, _ös_, uceu_, hgje, 
   {{0x3eac04ce,0x3f8d2939,0x6459293a,0x69c40158}},	//   uset_, rceu_, _ikui, kgje, 
   {{0x3eac0eba,0x63a9293b,0x3f8c0261,0x7c340436}},	//   rset_, lagn, sceu_, _smyr, 
   {{0x3ead293c,0x61e1293d,0x69c403d4,0xcfe004c5}},	//   sset_, menl, dgje, ভাজন, 
   {{0x61e102a1,0x69c5293e,0x60c1293f,0x63a92940}},	//   lenl, egje, munm, nagn, 
   {{0x60c04953,0xbea4408a,0x6e381c06,0x3ea47390}},	//   lunm, _талк, bitb, _тилг, 
   {{0x61e12941,0x69c40183,0x22880158,0xc13402d3}},	//   nenl, ggje, _møk_, _እንዳሃ, 
   {{0x6d440598,0x63a80522,0x64592942,0x2288168c}},	//   şkar, kagn, _okui, _løk_, 
   {{0x63a804b9,0xa3d40c2e,0x6458090c,0x61e12943}},	//   jagn, ़्म_, _nkui, henl, 
  
   {{0x63a92944,0x91fd2945,0x61e12946,0xdca12947}},	// [1c800] dagn, _whāi, kenl, _тақи, 
   {{0x60c12948,0x64592949,0x63a80280,0x61e00bbc}},	//   kunm, _akui, eagn, jenl, 
   {{0x61e1294a,0x20e400dd,0x201c023a,0xec1001d5}},	//   denl, _női_, kkui_, _طوید, 
   {{0x63a9294b,0x60c1294c,0xb4e40316,0x228803cd}},	//   gagn, dunm, _भनी_, _bøk_, 
   {{0x61e00112,0xf11c07f7,0x6e3831c5,0x201c0037}},	//   fenl, बन्द_, yitb, dkui_, 
   {{0x61e1294d,0x6458c2d7,0xdce00064,0xb0f400ae}},	//   genl, _ekui, _ugnė, لأعش, 
   {{0x63a9294e,0x637801b8,0x60c1294f,0x99980124}},	//   bagn, _pänü, gunm, girũ_, 
   {{0x7e600408,0x63a82b1d,0x6e392950,0x69c44580}},	//   ellp, cagn, witb, zgje, 
   {{0x61e00007,0xe61c001e,0x68e40007,0x69c442bb}},	//   benl, _muôn_, zwjd, ygje, 
   {{0xe61c07ae,0x61e12951,0x3eb8007b,0xdb240241}},	//   _luôn_, cenl, ásta_, _àsùn, 
   {{0x6b8c074d,0x91fc0a28,0x64900003,0x6e385c3d}},	//   tccg, _bhāv, _għid, ritb, 
   {{0x68e02776,0x7e600175,0x628c0129,0xab580037}},	//   _ândi, allp, _écoc, sgüm, 
   {{0x81e803f4,0x6e38113c,0x69c408fb,0x7a20004a}},	//   যার_, pitb, tgje, _côto, 
   {{0x7c2c025c,0xe9440354,0x6fd007b7,0x00000000}},	//   _ċare, ахбо, भ्रू, --, 
   {{0x69c4f1c0,0x63a92952,0x2d9d2953,0x91fc04fe}},	//   rgje, yagn, mbte_, _whāw, 
   {{0x61e00ab7,0x69c4168c,0x5d780375,0x91fc00b8}},	//   zenl, sgje, _באוק, _ghāv, 
   {{0x63a92954,0x61e12955,0xeb9c0212,0x69c400fe}},	// [1c810] vagn, yenl, mbø_, pgje, 
   {{0x60c12956,0x64592957,0x228800d4,0x61e10def}},	//   yunm, _skui, _røk_, xenl, 
   {{0x2288a1e9,0x63a88d2d,0x61e12958,0x60c00213}},	//   _søk_, tagn, venl, xunm, 
   {{0x60c12959,0x61e1295a,0x00000000,0x00000000}},	//   vunm, wenl, --, --, 
   {{0x61e1295b,0x1ca8025c,0xb4b400d1,0x43940107}},	//   tenl, _བྷན_, _қитә, _ҳабс, 
   {{0x63a9295c,0x60c1295d,0x61e0002f,0xf77400df}},	//   sagn, tunm, uenl, _לערי_, 
   {{0x63a9295e,0x61e1295f,0x81e800bd,0xdb0400db}},	//   pagn, renl, যাল_, _veié, 
   {{0x60c12960,0x6458166a,0x228806ea,0x201c0153}},	//   runm, _ukui, _tøk_, ukui_, 
   {{0x61e12961,0x60c12962,0x9294d9ec,0x443d2963}},	//   penl, sunm, _матц, miw_, 
   {{0x443d2964,0x60c0034c,0x201c0006,0x9f4c036e}},	//   liw_, punm, skui_, _hagë_, 
   {{0xdc780201,0xac945226,0x60c0014f,0x00000000}},	//   አብሔር_, ینیا_, qunm, --, 
   {{0x443c2e95,0xf534011a,0x00000000,0x00000000}},	//   niw_, מנתי_, --, --, 
   {{0x9f0800c6,0xa3cc121d,0x03d400fe,0xad8400d1}},	//   _جزاك_, _शान_, _সোৱণ, جاۋۇ, 
   {{0xe61c004d,0xa3d4033f,0x2d9c01ab,0x5e4001d9}},	//   _suôn_, ़्त_, cbte_, _گنڈٕ, 
   {{0xb4e402f8,0x7c941b06,0x443c2e95,0x91fc0055}},	//   _भने_, _اشتا, kiw_, _ihāt, 
   {{0x443c0227,0x9f4c00e4,0xe61c0419,0x00000000}},	//   jiw_, _ragê_, _stôp_, --, 
   {{0x443c0694,0x91fc002b,0xa68002e8,0xd9700150}},	// [1c820] diw_, _khāt, злуд, _ﺴﺭﺩﻩ_, 
   {{0x81e8015b,0x1dc40bca,0x2d98000d,0xe61400db}},	//   যাঁ_, ललित, _õpet_, бду_, 
   {{0x2e3800c8,0x37e41536,0x3a380381,0xe61c004d}},	//   נגענ, _лонг, _impp_, _tuôn_, 
   {{0x443cd9a6,0xdce000cd,0xf9892965,0xb2840f15}},	//   giw_, _agnī, _جنگي_, быкк, 
   {{0xdb04000f,0x64900327,0xe734020f,0xfbd800cd}},	//   _meiï, _rħie, _гея_, य्यम, 
   {{0x443c08e7,0x6490031c,0x3f980165,0x30a4f347}},	//   aiw_, _sħie, ñsun_, брив, 
   {{0x92e803f4,0x7a20002d,0xf504b3ee,0x81e80154}},	//   যমে_, _nôtm, _узво, যাং_, 
   {{0x443d2966,0x24b40375,0x4aa80037,0x00000000}},	//   ciw_, _להלן_, _कबलव, --, 
   {{0x91fc00cd,0xf348447e,0x2404030d,0x00000000}},	//   _bhāt, _спал_, _унти_, --, 
   {{0xf1d00323,0x91fc00b8,0x2d9c0e78,0xf1bc0327}},	//   _хөдө, _chāt, ubte_, ġġsa_, 
   {{0x9f4c0699,0xa3cc3323,0x91fc0882,0x2d9d2967}},	//   _lagè_, _शाम_, _dhāt, rbte_, 
   {{0x09b00490,0x5ea000f1,0x81e80154,0xa0640354}},	//   जण्य, _کمول, যাঃ_, _лаха_, 
   {{0xe0412968,0x91fc02b5,0xeb9c4098,0x6438008f}},	//   _энци, _whāu, rbø_, רעכנ, 
   {{0xab592969,0x3a380036,0x200000e2,0x1ca80327}},	//   ngüi, _cmpp_, ējie_, _བྷམ_, 
   {{0x91fc00cd,0x443d296a,0x00000000,0x00000000}},	//   _ekāg, yiw_, --, --, 
   {{0x2c7811f9,0x3a380332,0xd6d80116,0xab8400db}},	//   _līdz_, _empp_, әтт_, _уукк, 
   {{0x443d296b,0xdce0005f,0x06145d99,0xab6000d1}},	// [1c830] viw_, _iznā, одаю, _رۇسى, 
   {{0x443d296c,0xa3b8000d,0xd96c00d1,0x00000000}},	//   wiw_, _इएह_, _ﺳﯜﺭﻩ_, --, 
   {{0x443d296d,0x9f4c0240,0x92d803d4,0xd668009a}},	//   tiw_, _pagë_, ়টো_, حملو_, 
   {{0x8cc01d94,0xaa780122,0x5f1800dc,0x00000000}},	//   _विनो, jvýz, यहम्_, --, 
   {{0x9f4c02e2,0x443c013b,0x02c40212,0x00000000}},	//   _gagè_, riw_, ійко, --, 
   {{0x40948262,0x5694912f,0x443d296e,0xab5806be}},	//   орит, _харт, siw_, ffüz, 
   {{0x439416c3,0x91fc0055,0x443d296f,0xb4b404b4}},	//   _мавс, _ahās, piw_, _мирә, 
   {{0x81e8045e,0xde24044e,0x443c0054,0x84244da8}},	//   যাই_, _ስለዘለ, qiw_, _بىرن, 
   {{0x91fc002b,0xf1bc0327,0x00000000,0x00000000}},	//   _chās, ġġra_, --, --, 
   {{0x7fb92970,0x91fc002b,0x20680139,0x00000000}},	//   _چهار_, _dhās, _өшеп_, --, 
   {{0x9f4c00d8,0x51f400c6,0x7fb92971,0x7f9400c0}},	//   _magé_, _عسكر, _نهار_, _даех, 
   {{0x91fc9db5,0x00000000,0x00000000,0x00000000}},	//   _whāt, --, --, --, 
   {{0x69d805be,0x91fc0055,0x00000000,0x00000000}},	//   đuen, _ghās, --, --, 
   {{0x9f4c0c6a,0xfce812ea,0x4278010f,0x31500240}},	//   _nagé_, _نفتي_, יאָג, _ዝሕብር, 
   {{0x9f4d2972,0x8cc06cf9,0xfc30007b,0x91fc0055}},	//   _sagè_, _वियो, _يحب_, _khār, 
   {{0x78b92973,0xbb440137,0xb6a401d5,0xb4e40118}},	//   štvo, _мейк, жиал, _भनौ_, 
   {{0x9f4c00d8,0xba7400c6,0x3c300208,0x7c94009f}},	// [1c840] _bagé_, _واخت, cơva_, _اشڪا, 
   {{0x8cc007d0,0xaa780306,0x20d00022,0x2c7800ef}},	//   _विमो, zvýz, kãi_, _rūdi_, 
   {{0x9f4c003e,0xae54008f,0x2c780171,0x00000000}},	//   _dagé_, קסעס_, _sūdi_, --, 
   {{0x3f98030a,0x00000000,0x00000000,0x00000000}},	//   ñsul_, --, --, --, 
   {{0x91ec00df,0xe81c134e,0x00000000,0x00000000}},	//   loցi, _यकता_, --, --, 
   {{0x9f4c0066,0x91fc00b8,0xf7200023,0x32d00051}},	//   _gagé_, _ahār, ተኾይን, rây_, 
   {{0x628d2974,0x91fc0a28,0x80c007f7,0x00000000}},	//   _écon, _bhār, रंगे, --, 
   {{0x91fc3da0,0x737400c7,0xfbc4012c,0x918400db}},	//   _chār, _дызх, _वागम, زۇچۇ, 
   {{0x91fc0882,0xdee00063,0x2324003b,0x00000000}},	//   _dhār, доњи, _доти_, --, 
   {{0xccf800bc,0x7c2c031c,0x2bbc2314,0x00000000}},	//   tvě_, _ċara, ्लभा, --, 
   {{0xeb9ccade,0x7c2c0de2,0x3e740241,0x00000000}},	//   kjøt_, _ŋara, _ẹtú_, --, 
   {{0xccf800bc,0x91fc0055,0x00000000,0x00000000}},	//   rvě_, _ghār, --, --, 
   {{0xb9280109,0x9b58011c,0x00000000,0x00000000}},	//   _tetỳ_, жият_, --, --, 
   {{0xde0033cc,0x00000000,0x00000000,0x00000000}},	//   _опчи, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdce000e2,0xbebc4a38,0x00000000,0x00000000}},	//   _uznā, mzūr, --, --, 
   {{0x85b80220,0x2984084c,0x47340006,0xac94009f}},	// [1c850] йлас_, _мынг, чнас, _انڊا_, 
   {{0xdd3400b8,0x1b140154,0x00000000,0x00000000}},	//   _nāśe, _ঢেকে_, --, --, 
   {{0x5bc404fb,0x91c400af,0x04d806ed,0xbebc56ce}},	//   _عقیل, _राजै, смеј_, nzūr, 
   {{0x9f4c00f2,0x764c01bf,0x321801f4,0x00000000}},	//   _wagé_, _ejby, öpyn_, --, 
   {{0x96f812e7,0x00000000,0x00000000,0x00000000}},	//   _деят_, --, --, --, 
   {{0x95c92975,0xdd340055,0x20d000e4,0x00000000}},	//   _муса_, _cāśe, tãi_, --, 
   {{0xd498ef44,0x91fc00a3,0xdd340055,0x00000000}},	//   _мрт_, _phār, _dāśe, --, 
   {{0xe7c80f44,0x6e2802d0,0x68300024,0xe2a82586}},	//   िलिप, _alfb, _uždė, _نائن_, 
   {{0xe2908117,0x63b92976,0x644006af,0x64484cab}},	//   _آذر_, _idun, éniu, mngi, 
   {{0x91fd2945,0x6298079b,0x644806a3,0xf07800d1}},	//   _whār, _ituo, lngi, _ғичә_, 
   {{0x64492977,0x63b8013d,0x91fc00cd,0xe7c808df}},	//   ongi, _kdun, _ihāp, िलाप, 
   {{0x6448e0b0,0xdb04010e,0x6e280332,0x00000000}},	//   nngi, _ediý, _elfb, --, 
   {{0x64492978,0xf1d05345,0x63b92979,0xee2c1cd0}},	//   ingi, _सामन, _mdun, _зн_, 
   {{0x81e800bd,0x7a200109,0x63b804ba,0x8f4401e0}},	//   যাক_, _kôti, _ldun, _юххд, 
   {{0x63b9297a,0x64480066,0x26cc92a7,0x25fc012d}},	//   _odun, kngi, àgon_, _रफ़ी_, 
   {{0x63b8055a,0x2c780006,0x6298063f,0x6448013c}},	//   _ndun, _būdu_, _otuo, jngi, 
   {{0x6f14068f,0xa7a450c0,0x9f4c1686,0x00000000}},	// [1c860] _życz, якта_, _ingó_, --, 
   {{0x63b9297b,0x6449297c,0xd9b40046,0x2c780171}},	//   _adun, engi, _زەرد, _dūdu_, 
   {{0x6299297d,0xe4c0010b,0x63b806be,0xdd340055}},	//   _atuo, ейхи, _bdun, _rāśe, 
   {{0x6449297e,0x63b80175,0xd344b888,0x00000000}},	//   gngi, _cdun, وفای, --, 
   {{0x628c8652,0x81d40729,0x63b82252,0x249c00f3}},	//   _écol, িজন_, _ddun, _čume_, 
   {{0x63b9297f,0x30a4026a,0x64487e99,0x91fc1a5a}},	//   _edun, прив, angi, _skāb, 
   {{0xf7700efb,0x7a212980,0x62992981,0x6600d4aa}},	//   _زاڭ_, _côti, _etuo, _япра, 
   {{0x81e811ba,0x2898008d,0x765c0c67,0xbbc4258d}},	//   যাগ_, זיקא, lopy, वलोक, 
   {{0xeb9c0fac,0xab580112,0xc2c800ae,0x00000000}},	//   kjør_, ngüt, _وبكل_, --, 
   {{0x765c1c06,0x63b92982,0x386001f5,0x7c24017a}},	//   nopy, _zdun, _lkkr_, ekkr, 
   {{0x91fc0055,0x5ed000f2,0x00000000,0x00000000}},	//   _ekāc, وتیز, --, --, 
   {{0x4b880137,0x62980051,0x00000000,0x00000000}},	//   өйүн_, _ytuo, --, --, 
   {{0x765c035b,0xeb9c0158,0x00000000,0x00000000}},	//   kopy, fjør_, --, --, 
   {{0xdb042b76,0xeb9c02bf,0x644800ca,0x7c247dfa}},	//   _adió, gjør_, zngi, akkr, 
   {{0x64492983,0x765d2984,0x2c780171,0x2d04009d}},	//   yngi, dopy, _sūdu_, _хялг, 
   {{0x7c252985,0x6820000d,0xb5e40150,0x2c7800ef}},	//   ckkr, _kõdi, _ﺎﻤﻨﺌ, _pūdu_, 
   {{0x64492986,0xb7840184,0xeb9cf5b8,0x00000000}},	// [1c870] vngi, дәре_, bjør_, --, 
   {{0x60c000c6,0xa3cc1092,0x644803a2,0x63b92987}},	//   yrnm, _शाह_, wngi, _sdun, 
   {{0x62992988,0x64492989,0x68200254,0xa48400be}},	//   _stuo, tngi, _lõdi, سجان, 
   {{0x6449298a,0xdb04068c,0x7a2006af,0x9b44136e}},	//   ungi, _idiò, _rôti, _آنیو, 
   {{0x644820ac,0x64900003,0x765c0124,0x569401f4}},	//   rngi, _għin, bopy, _паят, 
   {{0x765d298b,0x628d298c,0x64480280,0x2bbc0521}},	//   copy, _écom, sngi, ọchi_, 
   {{0xe61c0016,0x644803a2,0x62980ba7,0x6440f85a}},	//   _nuôi_, pngi, _wtuo, énis, 
   {{0x91fc02b5,0xab59298d,0x1ae400eb,0x00000000}},	//   _whāp, ngüs, খিতে_, --, 
   {{0x6299298e,0x91fc0055,0x00000000,0x00000000}},	//   _utuo, _thāp, --, --, 
   {{0x442d298f,0x41b404fb,0x00000000,0x00000000}},	//   _hle_, _آمار, --, --, 
   {{0x7fd401ec,0xab580432,0x00000000,0x00000000}},	//   _жілі, kgüs, --, --, 
   {{0xeb952990,0xca2823e4,0x442d242d,0xbb44010b}},	//   мию_, _דם_, _jle_, демк, 
   {{0x7c252991,0x442c01f7,0x765d2992,0xe2180248}},	//   rkkr, _mle_, yopy, _ṣùgb, 
   {{0x442d2993,0xdb24032e,0x7c242bd5,0x00000000}},	//   _lle_, _ásín, skkr, --, 
   {{0x442d2994,0x9f4c0137,0xed5400cf,0xc95400fb}},	//   _ole_, _magí_, _оош_, етты, 
   {{0x442d2995,0xb8f4146b,0x81e8015b,0x00000000}},	//   _nle_, _सम_, যাট_, --, 
   {{0xf34c01f2,0x765c0108,0x00000000,0x00000000}},	// [1c880] hụrụ_, topy, --, --, 
   {{0x442d2996,0xf1d02d6b,0xab592997,0xba7402f2}},	//   _ale_, _साधन, rgüt, _تابت, 
   {{0x442c090b,0x765d2998,0xe61c01fb,0x49000075}},	//   _ble_, ropy, _xuôi_, _йүрг, 
   {{0x442d2999,0xf34c02e3,0x8cc00073,0xb4cc6c5a}},	//   _cle_, dụrụ_, _विसो, _शमी_, 
   {{0x442c0316,0x765c0124,0x41c8000d,0x00000000}},	//   _dle_, popy, _राखस, --, 
   {{0x6d4c019f,0xc5f40801,0xf8e00490,0xf34c063f}},	//   ûbak, _пясъ, _पहाय, wụsụ_, 
   {{0xeb9c119a,0x442d299a,0xd13000c6,0x68200037}},	//   kjøp_, _fle_, طمة_, _sõdi, 
   {{0xd01006d5,0x68e00639,0x442d299b,0xc3b805f5}},	//   الة_, _ände, _gle_, _нууц_, 
   {{0x5fbc11b1,0x81e80154,0x00000000,0x00000000}},	//   _एयरल, যাজ_, --, --, 
   {{0x442d299c,0xf34c02e3,0x2d8800b5,0x68200254}},	//   _zle_, bụrụ_, øbe_, _võdi, 
   {{0x442d299d,0xe0cc01d9,0xfcc00124,0x00000000}},	//   _yle_, _نٲل_, гәым, --, 
   {{0x9f4c011f,0xdb046d50,0xe0401789,0xaf0800ae}},	//   _dagâ_, _adiñ, _инхи, _وقام_, 
   {{0x0180052f,0x2c780171,0x00000000,0x00000000}},	//   _иҫәп, _sūds_, --, --, 
   {{0x6f000b6f,0x2e300042,0x3ea803e3,0xe61c0051}},	//   _iroc, _sâff_, _çata_, _tuôi_, 
   {{0x58d433d2,0x81e8015b,0x6f000306,0x00000000}},	//   корт, যাচ_, _hroc, --, 
   {{0x6f01299e,0x68200037,0x00000000,0x00000000}},	//   _kroc, _lõdv, --, --, 
   {{0x78a056c0,0x58840d0e,0x442d299f,0x997c00b8}},	// [1c890] _čove, тыра, _rle_, _kāśa_, 
   {{0x15a800a7,0x6f0129a0,0x3eb8e9c4,0x2bbc1788}},	//   дъци_, _mroc, ásti_, ्लवा, 
   {{0x442d29a1,0x80dc2232,0xd5b801c4,0x00000000}},	//   _ple_, _महें, ьст_, --, 
   {{0x6f0129a2,0x5ef000dc,0x94741176,0x00000000}},	//   _oroc, ्टम्_, ندنا, --, 
   {{0x442c11c1,0x6440004a,0xf34c0521,0x3c2006ea}},	//   _vle_, éniq, wụrụ_, _góvu_, 
   {{0x863400c8,0xf34c02e3,0x997c00b8,0x6d444283}},	//   _טאָג_, tụrụ_, _nāśa_, şkay, 
   {{0x442d29a3,0x69d4033d,0x84240150,0x00000000}},	//   _tle_, _बानी, _كىسن, --, 
   {{0x442d29a4,0x6fe8003d,0x6f00de48,0xf34c01f2}},	//   _ule_, _རྒྱའ, _broc, rụrụ_, 
   {{0x3eb929a5,0x6f0095d0,0x9f4c01e1,0xf41000d9}},	//   ést_, _croc, _tagí_, _גפן_, 
   {{0x6f0129a6,0x78b805a1,0xf34c05db,0x27e4013f}},	//   _droc, štvi, pụrụ_, ɑnne_, 
   {{0x6f003cf7,0xac64001f,0x92681d39,0x00000000}},	//   _eroc, ደለሁም_, _црта_, --, 
   {{0xfc3129a7,0x6820000d,0x32280220,0x00000000}},	//   احد_, _kõdu, _وتەۋ_, --, 
   {{0x4a780092,0x00000000,0x00000000,0x00000000}},	//   _በጅቡቲ_, --, --, --, 
   {{0xdb040ba1,0x4a741e76,0x4a000124,0x00000000}},	//   _leiç, выст, аҟьа, --, 
   {{0xf34c01f2,0x7e600393,0x37e401d5,0xc8b529a8}},	//   hụpụ_, molp, новг, ксты, 
   {{0x7e60020b,0xa8840354,0x05dc2ce6,0x6f0002d0}},	//   lolp, ейса_, न्सब, _yroc, 
   {{0x7bd401aa,0xab5804cc,0x2bbc00af,0x64a000c7}},	// [1c8a0] _icyu, sgür, ्लरा, ҳаха, 
   {{0x7af48574,0x69d400e1,0x64400066,0x7e6129a9}},	//   _isyt, _बायी, ènin, nolp, 
   {{0x41c809bb,0xec105dcd,0xdb0400d8,0x17c400c7}},	//   _राजस, _شوید, _beiç, _ианҭ, 
   {{0x7e601ad5,0x2898008f,0x64400214,0xf1d0012d}},	//   holp, _מיטא, énip, _साहन, 
   {{0x7e6001ee,0x232406ed,0x538446ee,0x49540023}},	//   kolp, ноци_, тқаз, _ዘስተብ, 
   {{0x8cc0bc82,0xe1ec15bf,0x91fc00dc,0x00000000}},	//   _विलो, مسى_, _ekān, --, 
   {{0x7bd4003a,0xdb0400d8,0x00000000,0x00000000}},	//   _ocyu, _feiç, --, --, 
   {{0xf1d0069f,0x7bd400ca,0x9f4c00db,0xddc801fa}},	//   _सावन, _ncyu, _bagà_, _čiši, 
   {{0x997c00b8,0x00000000,0x00000000,0x00000000}},	//   _pāśa_, --, --, --, 
   {{0x437529aa,0xd010c0f9,0x7e6129ab,0x6f0129ac}},	//   _руст, الک_, golp, _vroc, 
   {{0x6f0129ad,0x9f4c00d8,0x69d40073,0xdca00798}},	//   _wroc, _pagã_, _बाबी, лаќи, 
   {{0x6f0129ae,0xd5cc033f,0xdfcc00ec,0x00000000}},	//   _troc, ालुओ, _هيم_, --, 
   {{0x321d29af,0x7a20045f,0x6fa40c5a,0x6f000034}},	//   _koty_, _nôts, _ट्यू, _uroc, 
   {{0x8bf0045e,0x7e6129b0,0xaa7800e4,0x95680023}},	//   টাইন_, colp, itýg, ጽንታን_, 
   {{0x7af400e4,0x00000000,0x00000000,0x00000000}},	//   _esyt, --, --, --, 
   {{0xdb0401b8,0xd7f82063,0x321c012d,0x9cd4011a}},	//   _beiä, нуу_, _loty_, _נוחה_, 
   {{0x2ba44ff1,0x00000000,0x00000000,0x00000000}},	// [1c8b0] _क्या, --, --, --, 
   {{0x321c0866,0x81e4015b,0x68200037,0x91fc00cd}},	//   _noty_, _বোন_, _rõdu, _skān, 
   {{0x682000af,0x4974011c,0x00000000,0x00000000}},	//   _sõdu, _шлос, --, --, 
   {{0x68200254,0x7af48b89,0xb86400f1,0x7e6002d0}},	//   _põdu, _ysyt, _ټاپو, zolp, 
   {{0x321c012c,0x7e60022e,0x00000000,0x00000000}},	//   _boty_, yolp, --, --, 
   {{0x321d29b1,0x9f4c011c,0xdce000d0,0xdb080118}},	//   _coty_, _ragà_, _synč, áléh, 
   {{0x7e6129b2,0xf1d00210,0x00000000,0x00000000}},	//   volp, _सारन, --, --, 
   {{0x9f4c08e5,0x8fd4586c,0xdb080306,0x200929b3}},	//   _pagà_, гәшә, šléh, ñci_, 
   {{0x1ee440bf,0x69d4012c,0x321c012d,0x00000000}},	//   رودی_, _बाढी, _foty_, --, 
   {{0xe3701ac1,0x7a2005da,0xaa7803b2,0x51f4009f}},	//   _алғы, _lôtr, ntýd, _مسمر, 
   {{0x224529b4,0x9f4c025a,0x7e6129b5,0x02d06ac2}},	//   mink_, _nngö_, rolp, _समुन, 
   {{0x7a20004a,0x0e6400db,0x00000000,0x00000000}},	//   _nôtr, ккөн, --, --, 
   {{0x5c0400db,0x24d400eb,0x7e6088d8,0x59b400db}},	//   _ەكبە, সবিহ, polp, лөнс, 
   {{0x1ae403d4,0xf2d0008f,0xdb04005b,0x224401ef}},	//   খিলে_, בעך_, _reiä, nink_, 
   {{0xa9644358,0xa92400e2,0xb8647aaf,0xfe4001d3}},	//   вира_, _nožē, نارو, _مکھی, 
   {{0x7bd40223,0x7af40109,0x91fd29b6,0xaa7800e4}},	//   _ucyu, _tsyt, _akāl, ytýg, 
   {{0x7af4033f,0x22448938,0xfc300271,0x8c240011}},	// [1c8c0] _usyt, kink_, _محک_, মোহন_, 
   {{0x66e0932e,0x2244003e,0x9f5c002e,0x00000000}},	//   рофа, jink_, njuñ_, --, 
   {{0x22440151,0x321c02f0,0xd7e800cf,0x00000000}},	//   dink_, _roty_, _كودۇ_, --, 
   {{0xad1804ac,0x91fc0421,0xc4c4088c,0x68e001e6}},	//   ווער, _ekāl, اتلو, _ända, 
   {{0xe2941bb8,0x321c0124,0x93040124,0x741401e2}},	//   вач_, _poty_, ыҟал, _یوسا, 
   {{0xe1ec0e26,0x22440153,0xe5a054d9,0xeb3800df}},	//   ۅسۉ_, gink_, _вири, וענש, 
   {{0xe6400dbb,0x6230003b,0x33f4022e,0x00000000}},	//   _терп, рещу, _ичас, --, 
   {{0x9f4c0429,0x24040276,0xe574156c,0x00000000}},	//   _sagá_, _инси_, _рзс_, --, 
   {{0x9f4c5b84,0xd9b804c5,0xf334002b,0x224529b7}},	//   _pagá_, _জানম, _doṣā_, bink_, 
   {{0x2244003e,0x60cc0174,0x00000000,0x00000000}},	//   cink_, ðimø, --, --, 
   {{0x78bc0175,0x00000000,0x00000000,0x00000000}},	//   _nvpv, --, --, --, 
   {{0x799c02d0,0x5f4001d5,0x7c5c0092,0x1fa40354}},	//   _afpw, انیل, _ሲኖረው_, _акци_, 
   {{0x3ad4016b,0x00000000,0x00000000,0x00000000}},	//   _yɛpɛ_, --, --, --, 
   {{0xdd911056,0x68200254,0x00000000,0x00000000}},	//   _кашы, _nõdr, --, --, 
   {{0x2a60007f,0x48d00154,0xf33400b8,0x00000000}},	//   rojb_, াব্র, _yoṣā_, --, 
   {{0x97a529b8,0xb8800306,0x482400db,0x00000000}},	//   ирул, žína, دىرق, --, 
   {{0x1bb805d9,0x7a2007ea,0x91fc002b,0x22440009}},	// [1c8d0] _شايع_, _vôtr, _akām, yink_, 
   {{0xe94401d5,0x00000000,0x00000000,0x00000000}},	//   _ахмо, --, --, --, 
   {{0x224529b9,0x91fc0055,0x62e40154,0x00000000}},	//   vink_, _ckām, ওয়ায়_, --, 
   {{0x395d29ba,0x3e7806af,0x91fc00b8,0x00000000}},	//   ûtse_, mète_, _ihāy, --, 
   {{0x224529bb,0x3e784aee,0xe6640b01,0x2bd808a3}},	//   tink_, lète_, _атво, _भाना, 
   {{0x91fc06c8,0x00000000,0x00000000,0x00000000}},	//   _ukāl, --, --, --, 
   {{0x3e7820ef,0x224529bc,0xc1040b24,0xf6540117}},	//   nète_, rink_, اوبي, _серӯ, 
   {{0xfce40364,0x22440b4f,0xdba80131,0xa3b800db}},	//   қомо, sink_, _ﺋﯩﺪﻯ_, _زارر_, 
   {{0x224460bd,0x3e7807ea,0xdce00166,0xc3541fbe}},	//   pink_, hète_, _rfnı, _скај, 
   {{0xeb9529bd,0x7a20000f,0xfa600023,0x533400d8}},	//   ғир_, _nôtp, ደየናይ_, _теут, 
   {{0x705004d3,0xe7c00e49,0x3e78067c,0x799c02d0}},	//   شنیا, षणाप, jète_, _rfpw, 
   {{0xfaa529be,0xff1000b5,0x7f940107,0x7aa40107}},	//   ламо, _exeが, _садх, лимз, 
   {{0xef0c37b7,0xdfcc00aa,0x200d29bf,0xb4600023}},	//   _ум_, _هيڅ_, _ingi_, _ንኣህጉ, 
   {{0x628c0231,0xba181216,0x91fc00b8,0x6d4c01e7}},	//   _écou, ريزا_, _bhāy, úbac, 
   {{0x68f80034,0x26147382,0x91fc00cd,0xfce400d1}},	//   łudn, नानी_, _chāy, _сойо, 
   {{0xc2f803f4,0xf77129c0,0x91fc00b8,0x63a80175}},	//   _আপনি_, ماء_, _dhāy, jbgn, 
   {{0xe7340026,0x68200037,0x59dc0073,0x00000000}},	// [1c8e0] гет_, _põdr, _बापर, --, 
   {{0x3e7929c1,0xf1d04c19,0x55c46171,0x00000000}},	//   bète_, _साइन, ражғ, --, 
   {{0x66e0044c,0x200d29c2,0xd370005e,0x69d80cf4}},	//   _қора, _ongi_, ﺴﺘﯩﻖ_, đuet, 
   {{0x25a43535,0xddc001ef,0xc32400fe,0x00000000}},	//   ınla_, _oknů, _মেধি_, --, 
   {{0x64a129c3,0xe7240aa5,0x16840133,0x168801ee}},	//   _ҳаса, _бояд_, _ناسێ, _аҡай_, 
   {{0x200d29c4,0x94c8021a,0x366802d5,0x00000000}},	//   _angi_, _لارې_, _чаго_, --, 
   {{0x81742002,0x65c0d993,0xd5c40055,0xe3b40572}},	//   ۇنۇچ, _ыбра, _etāñ_, _әбу_, 
   {{0xa0640114,0xeea80f06,0x00000000,0x00000000}},	//   лаја_, нток_, --, --, 
   {{0x3e78007f,0xaf3c0023,0x71a401a9,0x2e48011c}},	//   zète_, _ክትምለ, _базз, еяно_, 
   {{0xe29429db,0x200d29c5,0x3f980165,0x290003b2}},	//   _саф_, _engi_, ñsur_, yvja_, 
   {{0x9e001586,0xa3b80034,0xae1400af,0xad24104c}},	//   счыл, _आजम_, ताबन_, ارخو, 
   {{0xc0a83e1a,0x00000000,0x00000000,0x00000000}},	//   _شامل_, --, --, --, 
   {{0x26141f13,0x628c06af,0x00000000,0x00000000}},	//   नामी_, _écot, --, --, 
   {{0xad251720,0x5a4400a8,0xdd8c0244,0xdb1400ee}},	//   _مربو, бэса, _فوه_, _ýaýb, 
   {{0x91fc06c8,0x195845b1,0x6cc40006,0xf1d06d65}},	//   _akāk, гары_, _сёле, _साईन, 
   {{0xe7840364,0x3e78f20f,0x00000000,0x00000000}},	//   гузо, rète_, --, --, 
   {{0xc0bc0092,0x00000000,0x00000000,0x00000000}},	// [1c8f0] ደረሰ_, --, --, --, 
   {{0x2d9d29c6,0xcd4802d3,0x3e784056,0xe6d40162}},	//   ncte_, _ብመንገ, pète_, _ótíð, 
   {{0xd1f00020,0xb658110e,0x91fc00cd,0x2d9c01c3}},	//   ፃናት_, nrẹ́, _ekāk, icte_, 
   {{0xf1d000bc,0x00000000,0x00000000,0x00000000}},	//   _साउन, --, --, --, 
   {{0xeabc0ffb,0x77b8011a,0xf7d400d9,0x00000000}},	//   nsù_, _במרח, _דורש_, --, 
   {{0x64b45ff0,0x200cb032,0x108c0ae5,0xc0bc0092}},	//   _محرر, _sngi_, _ﺗﺎﺭﯨ, ደረሱ_, 
   {{0x717400d1,0x534400c7,0x00000000,0x00000000}},	//   һбәр_, ихәа, --, --, 
   {{0x2ba41c15,0x2d9c084c,0x63e00150,0x83b80037}},	//   कुमा, ecte_, _ديرە, _उजिआ, 
   {{0x644929c7,0x20000316,0xddc001e4,0x0fe80220}},	//   migi, ěji_, _ejnŝ, улық_, 
   {{0xcee8286d,0x7d08026a,0xa26400a7,0xfe4430c7}},	//   ارين_, вног_, _събл, рноо, 
   {{0x64480d04,0x59dc1889,0xfce529c8,0x00000000}},	//   oigi, _बाबर, шоно, --, 
   {{0x68e0006a,0x200c041e,0xdb0403b2,0xaa780306}},	//   _ândy, _ungi_, _keiø, ytýc, 
   {{0x628c7f70,0xee2c00f5,0x00000000,0x00000000}},	//   _écos, _дн_, --, --, 
   {{0x64485b17,0x7c94361e,0x00000000,0x00000000}},	//   higi, _криц, --, --, 
   {{0x644929c9,0x69d40a8a,0xc7f401e4,0x69201422}},	//   kigi, _बारी, _ŝɨaɨ, омра, 
   {{0x644929ca,0x91fc002b,0xb8eccc41,0xac1400f3}},	//   jigi, _ekāh, _रि_, _воћу_, 
   {{0x2bd80490,0x7c340129,0x18780092,0xd910179e}},	// [1c900] _भाता, _ilyr, _በእግር_, _کیز_, 
   {{0x62800e3c,0x6449137e,0x00000000,0x00000000}},	//   jmno, eigi, --, --, 
   {{0x644929cb,0xaa7802fb,0x75440798,0x00000000}},	//   figi, stýc, јнез, --, 
   {{0x644929cc,0x81cc045e,0x73e40006,0xb4644575}},	//   gigi, ষ্ম_, родз, шкел, 
   {{0x91c40184,0xaa7800a2,0x00000000,0x00000000}},	//   йҙал, ltýa, --, --, 
   {{0x644801ab,0x7c340142,0x38700363,0x00000000}},	//   aigi, _llyr, llyr_, --, 
   {{0x644929cd,0xf34c01f2,0x91c400fb,0x637400fb}},	//   bigi, nụzụ_, _ғәлл, лсәр_, 
   {{0x6448010f,0x628c013f,0x62800165,0xceb80075}},	//   cigi, _ɑhoɔ, amno, гәк_, 
   {{0xc2e82550,0x2ba40b7c,0x69d4060c,0xe29401f4}},	//   _معلم_, _क्षा, _बाली, _вау_, 
   {{0x62800175,0x00000000,0x00000000,0x00000000}},	//   cmno, --, --, --, 
   {{0x2d880724,0x2c4c033f,0x261403ce,0xa0a0030d}},	//   äbe_, zędu_, नाती_, _дахд, 
   {{0x628d29ce,0x6f8400f7,0x3074001b,0x999800b8}},	//   _écor, _кулж, _тузс, bhrū_, 
   {{0x2fc4037e,0x7c2c0327,0x9f5c02d2,0x00000000}},	//   _idog_, _ċart, _örðu_, --, 
   {{0x644929cf,0x7c3529d0,0x64400109,0xad08009d}},	//   zigi, _elyr, éniz, _ахиж_, 
   {{0x64489d20,0xeabcb2cc,0x7c341477,0x3ea8025c}},	//   yigi, ssù_, _flyr, _ħati_, 
   {{0x64480429,0xd484004b,0x2c7800e2,0x59dc134e}},	//   xigi, _زۀ_, _lūdz_, _बाथर, 
   {{0x644929d1,0x3ce800f3,0x64900327,0x3e78068c}},	// [1c910] vigi, _ćavi_, _lħit, lèta_, 
   {{0x644929d2,0xab580205,0x00000000,0x00000000}},	//   wigi, kgüz, --, --, 
   {{0x644929d3,0x3e780ba1,0xef0400f1,0x57840055}},	//   tigi, nèta_, _کټ_, _māṣā_, 
   {{0x2fc40687,0x2c4c012d,0x91ac0208,0x37c00150}},	//   _ndog_, pędu_, _đón_, _нәуб, 
   {{0x26147e7c,0x53c801ec,0x54340066,0x00000000}},	//   नादी_, ргім_, غرمر, --, 
   {{0x6448e396,0x2fc401a9,0x3ea84498,0x00000000}},	//   sigi, _adog_, _çati_, --, 
   {{0x644929d4,0x0688040d,0x2fc40204,0x753c010a}},	//   pigi, _ﺑﻮﻳﯩ, _bdog_, czpz, 
   {{0x2ba402a0,0x64483209,0x62800332,0x8cc00bae}},	//   _क्ला, qigi, smno, _विजो, 
   {{0x53340408,0x8334009d,0x6d4c0332,0x00000000}},	//   _детт, _унах, úban, --, 
   {{0xee3529d5,0x6e3929d6,0x64580cf4,0x3e78067c}},	//   йны_, ghtb, _hjui, fèta_, 
   {{0xa3b800ab,0xfd10a0bc,0x00000000,0x00000000}},	//   _आजा_, سجد_, --, --, 
   {{0xca280d65,0x5ac80116,0x00000000,0x00000000}},	//   _אם_, аһим_, --, --, 
   {{0x81cc02a6,0x201c00ec,0xef0d29d7,0x9f4c00ae}},	//   ষ্ণ_, mjui_, _эм_, _lagú_, 
   {{0x6e3929d8,0xa9a006b3,0x98b416a3,0x4278010f}},	//   chtb, зирд, _žeđi_, טאָג, 
   {{0x27e80198,0x5ca000db,0x64580241,0xaa4129d9}},	//   _bbcn_, _بلبە, _ojui, черл, 
   {{0x7c34010e,0x201c00e4,0x9ba400db,0x00000000}},	//   _ulyr, njui_, _گەڭى, --, 
   {{0x27e802b5,0x87b8016c,0x38700042,0x0bb800cf}},	// [1c920] _dbcn_, руст_, rlyr_, _өтөө_, 
   {{0x645929da,0x27e8004e,0xee74001f,0x9ba411dc}},	//   _ajui, _ebcn_, _የባንኩ_, _دەڭى, 
   {{0x69f8008d,0x91fc0270,0xba740799,0xc32403d4}},	//   _גליק, _ukāi, _پاکت, _মেলি_, 
   {{0x64900327,0xaa780118,0x00000000,0x00000000}},	//   _rħit, ntýn, --, --, 
   {{0x64582239,0x27b00116,0x00000000,0x00000000}},	//   _djui, _хәсс, --, --, 
   {{0x78a01727,0xc5d410f5,0x2fc40332,0xf494cea6}},	//   _čovj, _місь, _sdog_, _граю, 
   {{0xa0a00220,0x50f40212,0x1ae40154,0x00000000}},	//   пшыл, ізит, মিয়া, --, 
   {{0x628c02e8,0xe0cc0116,0x00000000,0x00000000}},	//   _ècon, رزى_, --, --, 
   {{0x644129db,0xa0640640,0xb22401ee,0x00000000}},	//   ënie, љања_, _лмал, --, 
   {{0x628c06af,0x00000000,0x00000000,0x00000000}},	//   _écop, --, --, --, 
   {{0xdb24145e,0x7c2c0327,0x644056ce,0x2fc402d2}},	//   _âsên, _ċarr, ūnie, _tdog_, 
   {{0x3e780ba1,0x6e38062c,0x00000000,0x00000000}},	//   rèta_, shtb, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2bd8206b,0x43840131,0x91fc00b8,0x00000000}},	//   _भावा, ﺭﺩﯨﻦ_, _ekāv, --, 
   {{0xfcc400c7,0xe7e8013d,0xb5dc00eb,0x00000000}},	//   _дшыҟ, лфак_, ড়াচ, --, 
   {{0x9f4c02f0,0xf8ac006c,0xae144709,0x00000000}},	//   _ragú_, ککی_, तावन_, --, 
   {{0x99b800cc,0x00000000,0x00000000,0x00000000}},	// [1c930] _জাৰক, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb8fc009e,0xade8007d,0x6490031c,0x2904cd11}},	//   _দৈ_, ज्यन_, _rħis, _éna_, 
   {{0x26140490,0xc1400055,0x00000000,0x00000000}},	//   नाही_, cāṃs_, --, --, 
   {{0x387d29dc,0xab580213,0x00000000,0x00000000}},	//   ître_, qaüd, --, --, 
   {{0xf8ac00e5,0x00000000,0x00000000,0x00000000}},	//   _سکہ_, --, --, --, 
   {{0x008529dd,0x85040014,0x6458007f,0x59dc0073}},	//   олко, _بوزن, _tjui, _बासर, 
   {{0x2bd828d4,0x26140918,0xd720015b,0x545401a9}},	//   _भाषा, नावी_, _নেয়া_, _евст, 
   {{0x63b80936,0xb3740020,0xdb0c03b2,0x213002f0}},	//   _ieun, ራቸውን_, _íhøg, šxh_, 
   {{0x63b929de,0x985802b1,0x6490025c,0xfe4402bf}},	//   _heun, _pōī_, _għir, інно, 
   {{0xcb083d99,0x1ae403d4,0x68e0007c,0x00000000}},	//   _של_, খিছে_, _ändh, --, 
   {{0x63b929df,0xdb24025a,0x59dc028a,0x629801c8}},	//   _jeun, _âsën, _बाहर, _kuuo, 
   {{0x63b929e0,0xf9f4025c,0x64d80073,0x2bd808a3}},	//   _meun, _བྲུན_, मंडळ, _भारा, 
   {{0x63b929e1,0x0e640046,0x985800b0,0xaa7800bc}},	//   _leun, _екін, _tōī_, stýn, 
   {{0x9f4c0395,0x3ead29e2,0x443c01b3,0x6e2c01ed}},	//   _ragù_, lpet_, khw_, öbbe, 
   {{0x63b929e3,0x59dc06ab,0x00000000,0x00000000}},	//   _neun, _बावर, --, --, 
   {{0x3eac2165,0xac740092,0x762401f4,0x858002dd}},	// [1c940] npet_, _ቢኖሩም_, омаз, _ﺩﺍﺭﺍ_, 
   {{0xe61529e4,0x63b80369,0x3eac003b,0xfe780118}},	//   оду_, _aeun, ipet_, ktům_, 
   {{0x63b81dd4,0x73c4007b,0x2ba40dba,0xa50402e8}},	//   _beun, قيام, कुवा, жеха_, 
   {{0x62980032,0x63b83386,0x00000000,0x00000000}},	//   _buuo, _ceun, --, --, 
   {{0x63b929e5,0x261408a3,0x00000000,0x00000000}},	//   _deun, नाशी_, --, --, 
   {{0xe1ed29e6,0x30a529e7,0x628c1a44,0x63b80489}},	//   نسى_, орив, _ècol, _eeun, 
   {{0x63b929e8,0x6ab42314,0x261529e9,0x00000000}},	//   _feun, _अब्र, नारी_, --, 
   {{0x63b929ea,0x91fc0055,0x3a380009,0x6440004e}},	//   _geun, _akāt, _llpp_, ènit, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x63b8d452,0x63800022,0x3ea8025c,0x60e401bf}},	//   _zeun, _цгуа, _ħatt_, ørmæ, 
   {{0xafe410f5,0x63b929eb,0x3eac000f,0xe5f4011a}},	//   _можл, _yeun, apet_, חזיר_, 
   {{0x91fc002b,0x3e78007f,0xaee001ec,0x6fbc01ad}},	//   _ekāt, bèto_, _قۋعى, _एजिं, 
   {{0xac740092,0x00000000,0x00000000,0x00000000}},	//   _ቢኖርም_, --, --, --, 
   {{0xfc440008,0x00000000,0x00000000,0x00000000}},	//   _þína_, --, --, --, 
   {{0x199426aa,0x78540055,0x2bc8014b,0x00000000}},	//   даря, _śvaḥ, _купо_, --, 
   {{0x443c01d4,0x69d41fca,0x648000c5,0xd7f80120}},	//   xhw_, _बाकी, mõig, жуф_, 
   {{0x25a810de,0x3a38020b,0x261417ee,0x648000c5}},	// [1c950] لداي_, _flpp_, नाली_, lõig, 
   {{0x63b929ec,0x2ba42713,0x65a929ed,0x00000000}},	//   _seun, कुरा, ртаг_, --, 
   {{0x63b929ee,0xf9f4025c,0xa7f80055,0x443c00f1}},	//   _peun, _བྲིན_, _ajñe, thw_, 
   {{0x629818a6,0x940400ac,0x3eac5e47,0xaa7800e4}},	//   _puuo, _kimə_, ypet_, itým, 
   {{0x78a0098d,0x63b8004c,0xe2a00208,0x00000000}},	//   _čovi, _veun, _giữ_, --, 
   {{0x443d29ef,0x63b929f0,0xaad05f46,0x6480e523}},	//   shw_, _weun, _तिनक, kõig, 
   {{0x63b929f1,0x628c02e8,0xdb04180f,0x91fc0055}},	//   _teun, _ècom, _efiè, _akās, 
   {{0x3ead29f2,0x93f400f3,0x00000000,0x00000000}},	//   tpet_, _опсц, --, --, 
   {{0xfe7800bc,0x3eac0158,0x6480000d,0x00000000}},	//   stům_, upet_, eõig, --, 
   {{0x3eac87ba,0x00000000,0x00000000,0x00000000}},	//   rpet_, --, --, --, 
   {{0x3ead29f3,0x91fc00b8,0xceb403b9,0x00000000}},	//   spet_, _ekās, _çən_, --, 
   {{0x3eac17c0,0xaa78012c,0x2ba401bc,0xec300022}},	//   ppet_, stýl, कुला, енџь, 
   {{0x7c940214,0x91fc002b,0x6e3401d3,0x00000000}},	//   _کشتا, _ikār, ágbó, --, 
   {{0xfce80451,0xac940451,0x99980153,0x1ba00220}},	//   _هفتي_, _کنيا_, virų_, _ﺍﯞﯨﺮ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb6a529f4,0xbc3929f5,0xa534c8d8,0x00000000}},	//   зиал, _دستا_, _şaşı_, --, 
   {{0x4dd40046,0x6fd40342,0xbb2c00d1,0xf98800ec}},	// [1c960] _ءتۇس, lücü, ﻨﭽﻰ_, _گندي_, 
   {{0x1be80562,0x00000000,0x00000000,0x00000000}},	//   ट्रल_, --, --, --, 
   {{0x0a8800cf,0x91fc0055,0xf98800f1,0xa99800d9}},	//   _بئيى_, _okār, _دندي_, _לביר, 
   {{0xb38401af,0x99980153,0xfbbc11a0,0x00000000}},	//   плел, pirų_, ्णिम, --, 
   {{0x81ac2158,0x00000000,0x00000000,0x00000000}},	//   _কয়_, --, --, --, 
   {{0x91fc00dc,0x6fd40790,0x629001e1,0xfc4401ef}},	//   _akār, kücü, _ìfo̟, _žíla_, 
   {{0x764d29f6,0x237c0810,0xfbbc00cd,0x00000000}},	//   _imby, _ezuj_, ्णाम, --, 
   {{0x91fc0055,0x855401d5,0x35e002e5,0x35fc0154}},	//   _ckār, _تیمر_, _पाड़, _উচিৎ_, 
   {{0xb8fc025c,0xde380023,0x0ef80456,0x00000000}},	//   _ལའ_, _ስለዝገ, ्टेस_, --, 
   {{0x317c0036,0x91fc00cd,0xae1400ab,0x00000000}},	//   _tztz_, _ekār, ताइन_, --, 
   {{0x6fd403e0,0xdfcc011c,0x00000000,0x00000000}},	//   gücü, _пъ_, --, --, 
   {{0xa134011a,0x64800254,0x00000000,0x00000000}},	//   _מאבק_, rõig, --, --, 
   {{0x764d29f7,0xaa780122,0x648000af,0x9b58036b}},	//   _omby, stým, sõig, зият_, 
   {{0xbac80150,0xdb24032e,0x00000000,0x00000000}},	//   _ﺑﻪﺗﺎ, _ásýn, --, --, 
   {{0x250c01ec,0x6a54002f,0xd9146219,0xa878007b}},	//   _ءﻭﺭﺷ, eßfä, ндры, محرر_, 
   {{0x764d29f8,0x6e28178a,0x19582eca,0xf334002b}},	//   _amby, _hofb, часы_, _gaṇā_, 
   {{0x6e2806d9,0x387c07ea,0x00000000,0x00000000}},	// [1c970] _kofb, îtra_, --, --, 
   {{0x68e400b5,0xdce00118,0x00000000,0x00000000}},	//   ptjd, _nyně, --, --, 
   {{0xdb0405a4,0xb0fc074d,0x543407d6,0x00000000}},	//   _heið, _агiо, کرلر, --, 
   {{0x4428b41c,0x764c0022,0x4374cf08,0xdb0529f9}},	//   ða_, _emby, мулт, _zeiñ, 
   {{0x6e2801c7,0x6440004e,0xd6d801c6,0x64800037}},	//   _oofb, èniq, _нтр_, võid, 
   {{0xdb0401a8,0x91fc00e2,0x6fd403e0,0x00000000}},	//   _meið, _skār, yücü, --, 
   {{0x6f0129fa,0xdb0411c3,0xade802ab,0x26d80009}},	//   _asoc, _leið, _जॉइन_, luqo_, 
   {{0x3f980162,0x00000000,0x00000000,0x00000000}},	//   øsu_, --, --, --, 
   {{0x9de4038f,0x660529fb,0x6e28017a,0x439401c0}},	//   _འཁྱེ, _kajk, _bofb, _цаас, 
   {{0x648000af,0x3cc801c0,0x6604772f,0xdcec0427}},	//   sõid, олоо_, _jajk, žeči, 
   {{0x66040bb8,0x068876b9,0x6f0129fc,0x69d410eb}},	//   _majk, _ﺑﻮﻟﯩ, _esoc, _बाजी, 
   {{0x6604098d,0x6fd44a4a,0xdb0401a8,0x26d80472}},	//   _lajk, rücü, _beið, kuqo_, 
   {{0x4c34009d,0x00000000,0x00000000,0x00000000}},	//   хээт, --, --, --, 
   {{0x660439ab,0x9de4025c,0x00000000,0x00000000}},	//   _najk, _འཁྲེ, --, --, 
   {{0x37e4036b,0xe9a0443f,0x26cc01d3,0x82f800cc}},	//   мовг, тасп, ágon_, _আপোচ_, 
   {{0xf77129fd,0xdb0403b2,0xb7d8027d,0x00000000}},	//   ناء_, _feið, تورا_, --, 
   {{0xdea803f9,0xc8c404d3,0xb6a454a0,0xbb441422}},	// [1c980] _ƙiƙi, وڕێی, физл, _цепк, 
   {{0xaad00574,0x66041e31,0x644129fe,0x7af40124}},	//   _तितक, _cajk, ënin, _ipyt, 
   {{0xf4cc00fe,0x7f4403b9,0x00000000,0x00000000}},	//   ৰব্ব, _əhqa, --, --, 
   {{0x660401c6,0x3b100240,0x64400214,0x7c240010}},	//   _eajk, _kryq_, ènip, njkr, 
   {{0x660529ff,0x847802d3,0x290403b2,0x3dd400cc}},	//   _fajk, _ይኣምን_, _ánar_, ত্যল, 
   {{0x9f4c011f,0x9f5c0ffb,0x764d2a00,0x00000000}},	//   _lagó_, dduà_, _umby, --, 
   {{0xb4651386,0x0ef80141,0x68e001e3,0x00000000}},	//   _قدره, ्ट्स_, _ändt, --, 
   {{0x74145a05,0x7af40588,0x6604804c,0x161c0574}},	//   _تورا, _opyt, _zajk, नावर_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb041f60,0x66040014,0x3e78068c,0x6e280067}},	//   _reið, _xajk, nèth_, _qofb, 
   {{0x7af407dd,0x9f4c004e,0x9e012a01,0xdb041d1d}},	//   _apyt, _bagó_, тчыл, _seið, 
   {{0x6f00007b,0x64800254,0x59dc000d,0x00000000}},	//   _tsoc, põie, _बाउर, --, 
   {{0x6f000067,0x00000000,0x00000000,0x00000000}},	//   _usoc, --, --, --, 
   {{0xdb042242,0xadb400db,0xeba00046,0x00000000}},	//   _veið, _تۇدا_, _ﺍﯞﯨﻞ_, --, 
   {{0x7af52a02,0xa7f800b8,0x99d0009e,0x98c4086a}},	//   _epyt, _ajña, িভূক, кстл, 
   {{0xd7f801c6,0x00000000,0x00000000,0x00000000}},	//   муу_, --, --, --, 
   {{0x660415ad,0xed3000e5,0xbe480244,0x00000000}},	// [1c990] _pajk, _سوکھ, _بشۆم_, --, 
   {{0x5378069c,0x3e78068c,0x15f801f0,0x00000000}},	//   _ኢሳያስ_, gèth_, мнуъ_, --, 
   {{0x1cc8031c,0xf1bc0135,0x00000000,0x00000000}},	//   ྲེར_, ġġla_, --, --, 
   {{0xa3f80030,0x7af40022,0x00000000,0x00000000}},	//   ťaží_, _ypyt, --, --, 
   {{0xe5c42082,0x66041aff,0x070800e3,0x939400ec}},	//   _осво, _tajk, _عيسي_, نجها, 
   {{0x130802bf,0x68e0007c,0x3c801884,0x52740108}},	//   ьній_, _änds, ﺩﯨﺴﻰ_, кущу, 
   {{0x3cec000d,0x00000000,0x00000000,0x00000000}},	//   _जहें_, --, --, --, 
   {{0x1cc82b65,0xb91844fc,0x2bd80574,0xfe780118}},	//   ྲེལ_, _anyị_, _भागा, ntův_, 
   {{0x442c04c9,0x6290035b,0x3e78067c,0xaa7800e4}},	//   _ioe_, _агаӡ, lèti_, atýi, 
   {{0x442d2a03,0xae841c3e,0xef802e9a,0xeb9c0158}},	//   _hoe_, нбыз_, ылып, sdøl_, 
   {{0x442d2a04,0x9f4c00eb,0xee3412cf,0x00000000}},	//   _koe_, _pagó_, хнэ_, --, 
   {{0xb91801f2,0x9f4c011f,0x442c3d4a,0x450000fe}},	//   _enyị_, _qagó_, _joe_, _এপাক_, 
   {{0x442d2a05,0x3f9c02e3,0x9f4c00db,0x29100213}},	//   _moe_, _igwu_, _vagó_, _arxa_, 
   {{0x442d2a06,0xab580254,0x00000000,0x00000000}},	//   _loe_, maül, --, --, 
   {{0x442ccf11,0xba740131,0x3e78180f,0xab580254}},	//   _ooe_, _ۋاخت, vèth_, laül, 
   {{0x442c090b,0x00000000,0x00000000,0x00000000}},	//   _noe_, --, --, --, 
   {{0x7bc466af,0x3e78067c,0x6fdc0208,0x4eac010f}},	// [1c9a0] maku, tèth_, ợcgi, ַבאַ, 
   {{0x7bc4122d,0x442d2a07,0x4aa40c6e,0x00000000}},	//   laku, _aoe_, _गंतव, --, 
   {{0x3f9c0521,0x3e78180f,0xa3c80073,0xf990007b}},	//   _ogwu_, rèth_, लणं_, _حبة_, 
   {{0x7bc44375,0x442c37b6,0x3f9c01f2,0x65640175}},	//   naku, _coe_, _ngwu_, _dxjh, 
   {{0x64a00831,0x68e004f3,0x7bc52a08,0x442d2a09}},	//   _ҡара, _ändr, iaku, _doe_, 
   {{0x7bc52a0a,0x3f9d2a0b,0x442d0520,0x8d040055}},	//   haku, _agwu_, _eoe_, _chṛṅ, 
   {{0x799c03ac,0x442c75cd,0x00000000,0x00000000}},	//   _mgpw, _foe_, --, --, 
   {{0x442d2a0c,0x68e01088,0x38700076,0xceb403e3}},	//   _goe_, _ånde, noyr_, _çək_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3f9c05db,0x9f4c026c,0x3dc4009a,0xdea00214}},	//   _egwu_, _pagò_, galw_, دیوی, 
   {{0x442c0363,0x00000000,0x00000000,0x00000000}},	//   _yoe_, --, --, --, 
   {{0x09a80490,0x442c0208,0xc04c00f1,0x00000000}},	//   कड्य, _xoe_, _وږي_, --, 
   {{0x2aa86582,0x38700076,0xaa780022,0xf42000cc}},	//   ятно_, doyr_, itýv, _মতাৰ_, 
   {{0x7bc40093,0x00000000,0x00000000,0x00000000}},	//   aaku, --, --, --, 
   {{0xdd900022,0x28840063,0x00000000,0x00000000}},	//   _йашы, ећав, --, --, 
   {{0x48240058,0x7bc4015c,0x3e7802bd,0x00000000}},	//   خىرق, caku, vèti_, --, 
   {{0x442d2a0d,0x644002d3,0xad24004b,0x5884329e}},	// [1c9b0] _roe_, ënim, _زرګو, уыра, 
   {{0x5678084c,0x964401c0,0x6e38002f,0x00000000}},	//   ебуя_, лэхд, nktb, --, 
   {{0x442c4774,0xd7f0185e,0xdcf007f5,0xefdc0023}},	//   _poe_, شكە_, čaće, ናንዓ_, 
   {{0x69c52a0e,0xe3b096b4,0x14740451,0xc35402e8}},	//   laje, ارض_, هانج, кълъ, 
   {{0x442c07e4,0x73c00724,0x68e000b5,0x00000000}},	//   _voe_, рәсе, _åndb, --, 
   {{0x7bc4bf45,0x69c52a0f,0x442d2a10,0x36a00131}},	//   zaku, naje, _woe_, _ئەلق, 
   {{0x7bc52a11,0x442d2a12,0x00000000,0x00000000}},	//   yaku, _toe_, --, --, 
   {{0x442c067c,0x7bc401c4,0x00000000,0x00000000}},	//   _uoe_, xaku, --, --, 
   {{0x7bc52a13,0x69c52a14,0xcfa92a15,0xaec0443f}},	//   vaku, kaje, رايم_, абыл, 
   {{0x7bc52a16,0x69c52a17,0x00000000,0x00000000}},	//   waku, jaje, --, --, 
   {{0x7bc52a18,0x69c52a19,0xdce0005f,0xcee80cbb}},	//   taku, daje, _iznī, ورین_, 
   {{0x3f9c00b4,0xfaa52a1a,0xfeb800f7,0x40340120}},	//   _ugwu_, камо, _قاتت_, _шеес, 
   {{0x7bc52a1b,0x69c4014a,0xb4cc00dc,0x00000000}},	//   raku, faje, _षट्_, --, 
   {{0x69c52a1c,0xada01d0f,0xca752a1d,0x4a742123}},	//   gaje, _кашл, ێنێک, гыст, 
   {{0x7bc52a1e,0xab58004e,0x644000e2,0x38700076}},	//   paku, naüj, īnij, toyr_, 
   {{0x7bc41bb7,0x64400006,0x69c400e4,0xdbcc032e}},	//   qaku, ūnij, aaje, _góðf, 
   {{0x87f801c6,0xe3d40154,0x387003b2,0x00000000}},	// [1c9c0] ээрт_, সভাব, royr_, --, 
   {{0x69c40b91,0xc7943352,0x91fc00cd,0x7f4805c7}},	//   caje, урсы, _ajān, izeq, 
   {{0x64a06c9f,0xf8643a61,0x261402db,0x5fb02cbb}},	//   ааха, _авно, नाजी_, ीराल, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe8bc031c,0x2ba40404,0x6e38007c,0x00000000}},	//   _མཆོག, कुटा, yktb, --, 
   {{0xe28005f5,0x8d0400b8,0x00000000,0x00000000}},	//   алчи, _ahṝṅ, --, --, 
   {{0xa50400c7,0xa3b80073,0x20c0a17f,0x9f4c02d2}},	//   _иера_, _आजच_, асыг, _sagð_, 
   {{0x69c52a1f,0xaad00e85,0xa0640a5b,0x00000000}},	//   zaje, _तिलक, каја_, --, 
   {{0x26c4098d,0x69c52a20,0x26140490,0xdde0054e}},	//   ćnog_, yaje, नाची_, îrşi, 
   {{0x43745067,0x00000000,0x00000000,0x00000000}},	//   _суст, --, --, --, 
   {{0x69c52a21,0x321d27e2,0x6e3813ee,0x4c9444a5}},	//   vaje, _inty_, rktb, лиос, 
   {{0x69c4696c,0x6fa40490,0x26cc01ed,0x70500133}},	//   waje, _ऑलिं, ágok_, _خۆبا, 
   {{0x64800124,0xdee00117,0x00000000,0x00000000}},	//   kõin, _вочи, --, --, 
   {{0x1f6004b4,0x00000000,0x00000000,0x00000000}},	//   _әкәм, --, --, --, 
   {{0x69c52a22,0x2c4c033f,0x27180f4a,0x00000000}},	//   raje, zędy_, नम्र_, --, 
   {{0x69c52a23,0x6440005f,0x00000000,0x00000000}},	//   saje, īnik, --, --, 
   {{0x69c52a24,0x03a4136b,0x91b40406,0x00000000}},	// [1c9d0] paje, қило, ुराई, --, 
   {{0x69c40472,0x00000000,0x00000000,0x00000000}},	//   qaje, --, --, --, 
   {{0x660001e0,0x95c406c2,0x00000000,0x00000000}},	//   лоҡҡ, شينه, --, --, 
   {{0xf34c01f2,0x321d2a25,0x00000000,0x00000000}},	//   rụnụ_, _anty_, --, --, 
   {{0x3e5c02f0,0xfbb40210,0x00000000,0x00000000}},	//   lňte_, ूरतम, --, --, 
   {{0x0164e4e0,0x84c400b1,0x00000000,0x00000000}},	//   лкло, _бәдд, --, --, 
   {{0x80f4007b,0xbb2801ec,0x00000000,0x00000000}},	//   استض, _ﺤﺠﻡ_, --, --, 
   {{0xc2c431ed,0xa2d81fe5,0x1ee4ff22,0x439401ee}},	//   _ميري, _निप्, نوبی_, _бабс, 
   {{0xb374001f,0x21c80166,0x7ff402dd,0x2374072d}},	//   ያቸውን_, _жыеп_, _ەستا, _شارح, 
   {{0x2008a409,0x51f80108,0xab58000d,0x00000000}},	//   žci_, _иную_, maüh, --, 
   {{0x25e8069f,0x290c02e2,0xab580254,0x0ea80166}},	//   _चानी_, _ņgan_, laüh, нкөй_, 
   {{0xdb040077,0x443c01e2,0x3e780100,0x00000000}},	//   _afiá, nkw_, vètu_, --, 
   {{0x628c02e8,0xeb952a26,0x5ec00075,0xa2d802a0}},	//   _ècos, лию_, _тилғ, _निफ्, 
   {{0xfce4524d,0xa2d92a27,0x0cac0150,0x00000000}},	//   _боко, _निन्, _ﺍﻟﯩﭗ, --, 
   {{0xa9643db5,0xdb241968,0xb8644fca,0x443c6085}},	//   гира_, _چوبی, هارو, kkw_, 
   {{0x6490025c,0xdb252a28,0x9f4c0254,0xf608082a}},	//   _għix, þróu, _dagö_, کتره_, 
   {{0xab580254,0x00000000,0x00000000,0x00000000}},	// [1c9e0] jaüh, --, --, --, 
   {{0x3dd4015b,0x66e00fc0,0x00000000,0x00000000}},	//   ত্রল, софа, --, --, 
   {{0xd91007d6,0x3e78067c,0x1cc8031c,0x2e38010f}},	//   _بیز_, lèts_, ྲེི_, עגענ, 
   {{0xf74422f7,0xf34c063f,0xb2702cc8,0x68e0143a}},	//   _бемо, bụlụ_, әккә, _ånda, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe2952a29,0xe5a0f4a1,0xa3440228,0xf1a88e10}},	//   гач_, _гири, ызча_, راته_, 
   {{0xe1ec00f1,0xc0c40150,0x00000000,0x00000000}},	//   سسو_, ашық, --, --, 
   {{0xaa7809f3,0xab58000d,0x161c012d,0x653400df}},	//   ntýr, baüh, नाकर_, _גאלף_, 
   {{0x27fc0086,0x62780034,0x33640114,0x00000000}},	//   _ñune_, _słoń, _сваг, --, 
   {{0x1ef40491,0x98ac00bc,0xd13001d9,0x6278012d}},	//   اعية_, ádě_, _وۅش_, _płoń, 
   {{0x2fe4007b,0x22904197,0x00000000,0x00000000}},	//   _مكاف, _اللس, --, --, 
   {{0xa2d8c853,0x628c011c,0x25e800e1,0xab58002f}},	//   _निम्, _ècor, _चाभी_, nbüg, 
   {{0xee392a2a,0xe45400c8,0x6df4007b,0xade00073}},	//   _пнд_, ריכט_, _مكشا, _खाऊन_, 
   {{0x5f00004e,0x00000000,0x00000000,0x00000000}},	//   _ызча, --, --, --, 
   {{0x25e80cf1,0x957c0023,0xec1400fb,0x00000000}},	//   _चाबी_, ጥንቀቕ_, _бейә_, --, 
   {{0xe4a4013e,0x0b440133,0x00000000,0x00000000}},	//   ҳрдо, _نرخێ, --, --, 
   {{0x91fc00b8,0x86552a2b,0x3e78007f,0x26cd2a2c}},	// [1c9f0] _ajām, аках, mètr_, égo_, 
   {{0x443d1a3b,0x45d40eed,0xaa792a2d,0x3e5c02e2}},	//   wkw_, рожс, atýr, pňte_, 
   {{0x1cc80003,0x443c020c,0xab58002f,0xd67800be}},	//   ྲེག_, tkw_, fbüg, احقا_, 
   {{0xf34c01f2,0xb86400f1,0x0ed401f9,0xe2180241}},	//   pụlụ_, _ناټو, _दिंड, _ṣàgb, 
   {{0x27e80048,0xa280129e,0x00000000,0x00000000}},	//   _iccn_, میرو, --, --, 
   {{0x53e40588,0x85041410,0x6594007b,0x00000000}},	//   ацәа, _پورن, _مجزر, --, 
   {{0xd378013d,0x00000000,0x00000000,0x00000000}},	//   кчә_, --, --, --, 
   {{0x44d04077,0x00000000,0x00000000,0x00000000}},	//   mą_, --, --, --, 
   {{0x44d12a2e,0x249c05b1,0x2fc4030a,0xfe440261}},	//   lą_, _iium_, _deog_, инио, 
   {{0xee352a2f,0x27e8068c,0xe1f014a5,0x3e780561}},	//   ины_, _lccn_, _دسر_, vèts_, 
   {{0x44d12a30,0xbc640ff1,0x21652a31,0x3c652a32}},	//   ną_, ивок, _стаг, иког, 
   {{0xed5524cd,0x2fc52a33,0x91f000c7,0x6f540214}},	//   рою_, _geog_, _дҟәш, الیز_, 
   {{0x1cc80003,0xfaa52a34,0x249c003a,0x64800254}},	//   ྲེང_, раго, _mium_, võil, 
   {{0x200d2a35,0x44d00953,0x249c3b17,0x902800c7}},	//   _hagi_, ką_, _lium_, _ацәа_, 
   {{0x44d12a36,0xfce52a37,0xec6c00b2,0x200c0162}},	//   ją_, _тойо, _ڪٿي_, _kagi_, 
   {{0x44d06b82,0x68412a38,0x249c0393,0xb8cd2a39}},	//   dą_, онса, _nium_, _ओं_, 
   {{0xe734169c,0x237c0070,0x7bd4fe9b,0x200cee3d}},	// [1ca00] ает_, _nyuj_, _idyu, _magi_, 
   {{0x200d2a3a,0xaa782880,0x25a00036,0x44d03f05}},	//   _lagi_, stýr, _cgjl_, fą_, 
   {{0x44d04f59,0x8b640330,0x00000000,0x00000000}},	//   gą_, _نایم, --, --, 
   {{0x249c4460,0x200d0035,0x00000000,0x00000000}},	//   _cium_, _nagi_, --, --, 
   {{0xdef002d3,0x249c0393,0x2fc4fa68,0x91ec01e4}},	//   ግባእ_, _dium_, _reog_, liցi, 
   {{0x200c0589,0x44d03920,0x62600452,0xe1f401c0}},	//   _aagi_, bą_, овча, игч_, 
   {{0x200d2a3b,0x249c0268,0x44d00034,0x0ce000fe}},	//   _bagi_, _fium_, cą_, _বন্ত, 
   {{0x200c19a2,0x64a02685,0x249d2a3c,0xb354072d}},	//   _cagi_, _фата, _gium_, _پیتا_, 
   {{0x237c0369,0x200ca617,0x91c47a15,0xdd3400e2}},	//   _gyuj_, _dagi_, _ләйл, _jāņe, 
   {{0xa2d80a28,0x628c011c,0x00000000,0x00000000}},	//   _नित्, _ècop, --, --, 
   {{0x1cc80135,0x200d2a3d,0xeca00150,0x00000000}},	//   ྲེཊ_, _fagi_, _ﺍﻟﺒﻠ_, --, 
   {{0x200d2a3e,0x0e6400cf,0x00000000,0x00000000}},	//   _gagi_, ркүн, --, --, 
   {{0xab852a3f,0x44d07502,0xdfccbf4e,0x00000000}},	//   рунк, zą_, _آيه_, --, 
   {{0x6480007d,0x200c773e,0x6ca4292c,0x60cc01f4}},	//   võim, _zagi_, _криж, _äimä, 
   {{0xdd8c01fd,0x91fc0055,0x19580137,0x4c9400d8}},	//   _قوه_, _ajāk, аары_, _ликс, 
   {{0xb7c42097,0x44d00006,0xaa7800c7,0x9f5c002f}},	//   йруқ, vą_, atýp, nfuß_, 
   {{0x44d0068f,0x249c0e89,0x27e8003b,0x00000000}},	// [1ca10] wą_, _rium_, _vccn_, --, 
   {{0x44d12a40,0xf8ac036b,0x249c003a,0xab5804cc}},	//   tą_, بکی_, _sium_, rbüd, 
   {{0xe7ec6b9b,0x249c0381,0xb34000ac,0x44f52a41}},	//   _छापा_, _pium_, əçil, спес, 
   {{0x44d0d5fb,0xdcec08ad,0xa2d8012a,0x64800254}},	//   rą_, žeći, _निद्, põim, 
   {{0x44d12a2e,0x648000c5,0x249c01bf,0x048802dd}},	//   są_, lõik, _vium_, _ұшақ_, 
   {{0x200c0048,0x44d12a2e,0xe819193c,0x249c017a}},	//   _sagi_, pą_, _पोता_, _wium_, 
   {{0x200c15a5,0xf34c01f2,0x249c0393,0xa4240124}},	//   _pagi_, hụhụ_, _tium_, _кьал, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x200d2a42,0xaa7800e4,0xe7ec0118,0x00000000}},	//   _vagi_, ytýp, _छाना_, --, 
   {{0x648000c5,0x200d2a43,0xfe4401c6,0x00000000}},	//   kõik, _wagi_, сноо, --, 
   {{0x200d2a44,0x7e7000ef,0x00000000,0x00000000}},	//   _tagi_, _ķepā, --, --, 
   {{0x64492a45,0x69d4056a,0x200c003a,0x0d852a46}},	//   nhgi, _adxe, _uagi_, өлөн, 
   {{0xee2d2a47,0x00000000,0x00000000,0x00000000}},	//   _ен_, --, --, --, 
   {{0x90a40150,0xfe440276,0x00000000,0x00000000}},	//   _احەم, _ынло, --, --, 
   {{0xceb400ac,0x6280a4e6,0xfaa4013e,0xa3e44fed}},	//   _çər_, ilno, раҳо, पला_, 
   {{0x7bd52a48,0x8868009f,0x00000000,0x00000000}},	//   _udyu, لحقّ_, --, --, 
   {{0x3eac036e,0x00000000,0x00000000,0x00000000}},	// [1ca20] nqet_, --, --, --, 
   {{0x7c341125,0x7ae52a49,0xc7644418,0x06d40046}},	//   _hoyr, mukt, زاقى, _ﺟﻪﺗﻪ, 
   {{0x7ae52a4a,0x7c341125,0x98ac005f,0x3ce405ac}},	//   lukt, _koyr, ēlēt_, nulv_, 
   {{0x7c3400b5,0xe7ec230e,0x38ac00a2,0x62812a4b}},	//   _joyr, _छाया_, _iýr_, elno, 
   {{0x7ae52a4c,0x26cc00dd,0xa3b400af,0x7c340363}},	//   nukt, ágot_, छड़_, _moyr, 
   {{0x02a40220,0xd25000c6,0xab580112,0x38ad2a4d}},	//   ірім, بنت_, lbüc, _kýr_, 
   {{0x7ae52a4e,0x64b401fa,0xeb9c0e38,0x64400120}},	//   hukt, _aćif, ndør_, ênic, 
   {{0x64492a4f,0x765d2a50,0x62812a51,0xab5803fa}},	//   chgi, lipy, alno, nbüc, 
   {{0x7ae52a52,0x9f5c0112,0x3fc807d6,0xa758010f}},	//   jukt, rfuß_, شگنی_, ָדיר, 
   {{0xdb04067c,0xeb9c0fac,0x765d2a53,0xab58002f}},	//   _igiè, kdør_, nipy, hbüc, 
   {{0x667804ac,0x4c952a54,0x38ac0008,0x3ce40627}},	//   רטיק, жинс, _nýr_, gulv_, 
   {{0x7c341368,0x7ae4ee21,0x2d80e762,0xeb9c005c}},	//   _coyr, fukt, āke_, ddør_, 
   {{0x7c352a55,0xaa780030,0x73040327,0x765d2a56}},	//   _doyr, jrýc, _གརྦྷ_, kipy, 
   {{0xa2d8197e,0x09e002f5,0x38ac2833,0x64480023}},	//   _निस्, ম্না, _býr_, zhgi, 
   {{0x7c3400ad,0x992812e7,0xeb9c01bf,0x15cc0150}},	//   _foyr, бюта_, gdør_, _ﺗﯘﺯﺩ, 
   {{0x7ae40264,0x25e8007d,0x38ac09f3,0x7c3400ad}},	//   bukt, _चाही_, _dýr_, _goyr, 
   {{0x7ae40790,0xdd8c00db,0xa3e4000d,0xfe6c04f2}},	// [1ca30] cukt, _قوۇ_, पलस_, _سگی_, 
   {{0x38ac03b2,0xd1240137,0x64800254,0xa9c400f5}},	//   _fýr_, _كۅ_, põik, _усик, 
   {{0x613c01e1,0x628002f0,0x1a9c0a7c,0x00000000}},	//   _màlú, vlno, _גיזע, --, 
   {{0x26cc00dd,0xdd780a1e,0xaa781d55,0x3eac036e}},	//   ágos_, נטאל, brýc, yqet_, 
   {{0x15cc0ed1,0x427401c0,0x6448020c,0x63ac031c}},	//   _ﺗﯘﺭﺩ, огдс, rhgi, _ġinġ, 
   {{0x64492a57,0xdce00024,0xe4a400d8,0xe7ec00bc}},	//   shgi, _gynė, _грао, _छाडा_, 
   {{0x64412a58,0xa2d80073,0x7c2003b2,0x7ae403e0}},	//   ënis, _निव्, _óorg, zukt, 
   {{0x7ae40a28,0x1b1000fe,0xd4992a59,0x644000e2}},	//   yukt, ামতে_, _гру_, īnis, 
   {{0x09e02aab,0x613c01e1,0x6458c2d0,0x62801d55}},	//   ম্যা, _bàlú, _imui, plno, 
   {{0x3ead078b,0x68e40023,0x3da40137,0x00000000}},	//   rqet_, kujd, өрүб, --, 
   {{0x2aac0139,0x7c3465f7,0x10640014,0x7fd4155b}},	//   _aüb_, _poyr, _کُنُ, _ділі, 
   {{0x7ae52a5a,0x7f1802bf,0x09e0015b,0x7c34834a}},	//   tukt, _віку_, ম্মা, _qoyr, 
   {{0x645827be,0x7c3400ad,0x38ac00bc,0x3ead2a5b}},	//   _mmui, _voyr, _sýr_, qqet_, 
   {{0x394800c7,0x1cc80135,0x2ca800c6,0x9da80801}},	//   азго_, ྲེད_, úidí_, _съда_, 
   {{0x6e912a5c,0x09e0045e,0xa9a088c8,0x64581418}},	//   _تلوا, ম্ভা, дирд, _omui, 
   {{0x38ac02f0,0xaa780306,0xeb9c072b,0x7c9402da}},	//   _výr_, trýc, rdør_, _بشتا, 
   {{0xa2d841ac,0x1cd40489,0x765c6af6,0xab5803fa}},	// [1ca40] _निष्, ོངམ_, tipy, rbüc, 
   {{0xdb0400d2,0x64592a5d,0x38ac0d12,0xab580112}},	//   _ngié, _amui, _týr_, sbüc, 
   {{0x25e92a5e,0x765c02f6,0x64580175,0x00000000}},	//   _चारी_, ripy, _bmui, --, 
   {{0xa2d812ec,0x765d2a5f,0xc4c419bc,0xb384736c}},	//   _निश्, sipy, ستمو, олел, 
   {{0xc8b4004b,0xab58067c,0x765c0022,0xe7ec3be5}},	//   _ولیک, laür, pipy, _छाता_, 
   {{0xa2d92877,0x00000000,0x00000000,0x00000000}},	//   _निर्, --, --, --, 
   {{0xe0cc2e6f,0xab58067c,0x756400e5,0x2a6c01e1}},	//   نزي_, naür, _بیاہ_, _ìgbe_, 
   {{0x1cc80ed9,0x8f340022,0x00000000,0x00000000}},	//   ྲེན_, зеиц, --, --, 
   {{0xa3e401ad,0x00000000,0x00000000,0x00000000}},	//   पलर_, --, --, --, 
   {{0x91fc00b8,0xc4080050,0x2aac03e3,0xab580254}},	//   _ajāv, _پتہٕ_, _rüb_, kaür, 
   {{0x7158d7b1,0xa2a00037,0x00000000,0x00000000}},	//   _трас_, _छूट्, --, --, 
   {{0x2aac0793,0x00000000,0x00000000,0x00000000}},	//   _püb_, --, --, --, 
   {{0x25e810f7,0x997c00e2,0x6e2c01d3,0xc5d400eb}},	//   _चाली_, _jāņa_, öbbs, স্টপ, 
   {{0x6f012a60,0xbe3000c7,0x3eb92a61,0x00000000}},	//   _ipoc, _зҕьы, íste_, --, 
   {{0x648000e4,0x2d98110e,0x00000000,0x00000000}},	//   mõiv, _àpe_, --, --, 
   {{0x6f0002e3,0xa6a8059e,0x2aac0166,0xa2d80fe6}},	//   _kpoc, لائق_, _tüb_, _निल्, 
   {{0x25a80640,0xd7c805af,0x00000000,0x00000000}},	// [1ca50] ађен_, زوله_, --, --, 
   {{0xe818069f,0x64592a62,0xab5805d1,0x00000000}},	//   _पोरा_, _smui, saüs, --, 
   {{0x68e4014f,0x00000000,0x00000000,0x00000000}},	//   qujd, --, --, --, 
   {{0xf8b52a63,0x64800254,0x6f000210,0x068400d1}},	//   _хөр_, hõiv, _opoc, ﺪﯨﻜﯩ, 
   {{0x5434036b,0xa2d80073,0x53342c12,0x6480035b}},	//   برلر, _निळ्, мецт, kõiv, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3f8801fa,0xc4c40451,0x00000000,0x00000000}},	//   _šau_, _رڪاو, --, --, 
   {{0xe45d2a64,0x00000000,0x00000000,0x00000000}},	//   _öö_, --, --, --, 
   {{0xddc0009b,0x3eb80036,0xf41000df,0x00000000}},	//   _ajnš, ëst_, _אפן_, --, 
   {{0xaa780209,0xfe7000c6,0x3eb800e2,0x395c045f}},	//   yrýa, عدة_, īst_, útsk_, 
   {{0x3eb800da,0x44f47c1d,0x6f002d28,0xf8d80037}},	//   ūst_, nå_, _epoc, _बटइय, 
   {{0x32fc0055,0x00000000,0x00000000,0x00000000}},	//   bāyā_, --, --, --, 
   {{0x6d44010f,0x00000000,0x00000000,0x00000000}},	//   ŝkap, --, --, --, 
   {{0x44f4007c,0x00000000,0x00000000,0x00000000}},	//   kå_, --, --, --, 
   {{0x260c0cb4,0xeb9c3c02,0x7e612a65,0x6f000118}},	//   ड़नी_, leøl_, milp, _zpoc, 
   {{0x44f400cc,0x7e6001e4,0x6f0003ac,0xfc30007b}},	//   då_, lilp, _ypoc, _سحب_, 
   {{0x1cc8081f,0x44f40589,0x15f0107c,0x6440022e}},	// [1ca60] ྲེམ_, eå_, _चादर_, ªnin, 
   {{0x7e600077,0xa6812a66,0x95701ef7,0x00000000}},	//   nilp, елуд, ባራቱን_, --, 
   {{0x0f0802ab,0xa3e401bc,0x755410fc,0x44f401bf}},	//   _वन्स_, पलं_, чњац, gå_, 
   {{0x3a392a67,0x65d42e56,0xe1ec0075,0x3a7400fb}},	//   _hopp_, ﻟﮕﯩﻠ, ۇسى_, _флүр, 
   {{0x44f40589,0x7e606935,0x240402e8,0xa2b000d4}},	//   aå_, kilp, янци_, ебіч, 
   {{0x9f5c00db,0xc32c0116,0x00000000,0x00000000}},	//   deuà_, جەك_, --, --, 
   {{0x6f012a68,0x44f40004,0x7e60017a,0x00000000}},	//   _spoc, cå_, dilp, --, 
   {{0x3a3801e6,0x91fc00cd,0xa0a00120,0xe6940133}},	//   _lopp_, _ajāt, најд, _وپێش_, 
   {{0xc4440014,0xf348005b,0x3a3802f0,0x648000e4}},	//   _زیون_, _упал_, _oopp_, tõiv, 
   {{0x3a381bce,0x7e612a69,0x00000000,0x00000000}},	//   _nopp_, gilp, --, --, 
   {{0x648000c5,0x2d940137,0x9ef00330,0xab5800e5}},	//   rõiv, чөдө_, وسیش, gbün, 
   {{0x3a380334,0xaa7803b2,0xec140139,0x00000000}},	//   _aopp_, grýn, чемә_, --, 
   {{0x3a381574,0x7e600088,0x00000000,0x00000000}},	//   _bopp_, bilp, --, --, 
   {{0x7e612a6a,0x00000000,0x00000000,0x00000000}},	//   cilp, --, --, --, 
   {{0x26c41591,0x3a3801e3,0x5df8011a,0x53cc4a76}},	//   ćnom_, _dopp_, _הפונ, ाराश, 
   {{0x44f4ce29,0x7e6c02d2,0x00000000,0x00000000}},	//   vå_, _íapr, --, --, 
   {{0x2bc02d6b,0x3a380de2,0x78a4017a,0xccf80118}},	// [1ca70] _व्या, _fopp_, _dikv, ltě_, 
   {{0xe2a0004d,0x44f41f53,0x78a52a6b,0xe7ec0bae}},	//   _chữ_, tå_, _eikv, _छावा_, 
   {{0x58d52a6c,0x64400120,0xe4c8027d,0xccf800bc}},	//   _поэт, ênio, صبان_, ntě_, 
   {{0x3a38e263,0x44f40158,0x00000000,0x00000000}},	//   _zopp_, rå_, --, --, 
   {{0x7e600784,0x44f426ff,0xe7841171,0x00000000}},	//   yilp, så_, _хуно, --, 
   {{0x44f40250,0x05e00037,0x00000000,0x00000000}},	//   på_, _पयिब, --, --, 
   {{0xf4f00588,0x7e612a6d,0x00000000,0x00000000}},	//   _аҧхь, vilp, --, --, 
   {{0x78a402c4,0x90e44da8,0xff240120,0x84242d40}},	//   _xikv, رسىن, дмио, _تىرن, 
   {{0x7e6003ef,0xa3000139,0x00000000,0x00000000}},	//   tilp, _чүле, --, --, 
   {{0x3e78180f,0x3f640139,0xccf801ef,0x91e4009b}},	//   lètz_, зтүб, ftě_, _пође, 
   {{0xab592a6e,0x7e600309,0x3a3812ce,0x00000000}},	//   ubün, rilp, _ropp_, --, 
   {{0x7e612a6f,0x3a392a70,0x26c4e108,0x648000af}},	//   silp, _sopp_, ćnoj_, mõis, 
   {{0x78a416a3,0x7e600784,0xab58002f,0x00000000}},	//   _rikv, pilp, sbün, --, 
   {{0x7e60014f,0xfce4004e,0x17c801f0,0x850c00bc}},	//   qilp, _жоко, ӯҳои_, सबाट_, 
   {{0x7c652a71,0xab581cce,0x78a40254,0x00000000}},	//   _ياعل, lbül, _pikv, --, 
   {{0x3a380de2,0xcc340022,0x0ec401f9,0x00000000}},	//   _wopp_, _зхьы, लीकड, --, 
   {{0x3a392a72,0xba745f2e,0xab580793,0x3e781497}},	// [1ca80] _topp_, _ياخت, nbül, dètz_, 
   {{0xa5f415ed,0xb9c44c1c,0x66e12a73,0x5edc03d4}},	//   међу_, _تقدي, тофа, _বঙাই, 
   {{0x78a4098d,0xf8d03d4d,0xd0480213,0x91fc00de}},	//   _tikv, _तबिय, _evdə, _ojār, 
   {{0x4994010b,0x00000000,0x00000000,0x00000000}},	//   _яшыт, --, --, --, 
   {{0x6480f5bc,0xa6c40014,0x00000000,0x00000000}},	//   võit, _ٲوِل_, --, --, 
   {{0xddd000a2,0x75d4009f,0x00000000,0x00000000}},	//   _ýaňg, _زيرا, --, --, 
   {{0x3e780ba1,0xd6b0009e,0x20d0007b,0xf074010b}},	//   bètz_, _ছবিয, نتيج, микә_, 
   {{0xa0852a74,0x91fc00b8,0x00000000,0x00000000}},	//   мсыз_, _smād, --, --, 
   {{0xf2685a12,0x638002d2,0x00000000,0x00000000}},	//   _диал_, _vínþ, --, --, 
   {{0x3eb85b84,0x648000c5,0xa2e12a75,0x00000000}},	//   ísta_, sõit, _шоуд, --, 
   {{0xe7ec00bc,0x260c012d,0x00000000,0x00000000}},	//   _छाला_, ड़ती_, --, --, 
   {{0x9418013f,0xccf800bc,0xefb80092,0xe020030d}},	//   _kurɑ_, rtě_, ደዚያ_, _аьшп, 
   {{0xccf8038e,0x78bc0208,0x9b58299f,0x00000000}},	//   stě_, _atpv, дият_, --, 
   {{0x33cc005e,0x7bc4000d,0x91fc0055,0x00000000}},	//   _ﻗﯩﺰﻣ, abku, _umād, --, 
   {{0xdd9000c7,0xa8a4299f,0x7bc401e3,0x00000000}},	//   _иашы, драк, bbku, --, 
   {{0x4298001f,0x764d2a76,0x78b80162,0x00000000}},	//   _ህፃናት_, _alby, ítva, --, 
   {{0x9f5c01a8,0x3e78068c,0xa038008f,0x9a880014}},	// [1ca90] nduð_, vètz_, קעמפ, سنہٕ_, 
   {{0xa5652a77,0xbebc00ef,0x00000000,0x00000000}},	//   ودان, bvūf, --, --, 
   {{0x69c402d3,0x3e78067c,0x00000000,0x00000000}},	//   mbje, tètz_, --, --, 
   {{0x44292a78,0x25e8069f,0x6480007d,0x69c400b5}},	//   ña_, _चाकी_, võis, lbje, 
   {{0x3e78067c,0x57a401fe,0x23081d37,0x00000000}},	//   rètz_, _ашра, تتاي_, --, 
   {{0x34180882,0x611000ac,0x69c43c38,0x3e78068c}},	//   āvaḥ_, _hələ, nbje, sètz_, 
   {{0xa2d83711,0x7ae40175,0x611003e3,0x00000000}},	//   _निक्, zrkt, _kələ, --, 
   {{0x7ae42200,0xaa780306,0x00000000,0x00000000}},	//   yrkt, drým, --, --, 
   {{0x611000ac,0x42752a79,0x2d8817da,0x73c000ee}},	//   _mələ, _згас, üben_, _сәхе, 
   {{0x69c400b5,0x611003e3,0x90e400cf,0x00000000}},	//   jbje, _lələ, رسۉن, --, 
   {{0x00e52a7a,0x4fe800f7,0x69c52a7b,0x00000000}},	//   _ستای, чмөн_, dbje, --, 
   {{0x6e28007f,0x611000ac,0x00000000,0x00000000}},	//   _enfb, _nələ, --, --, 
   {{0x63b92a7c,0xcee8689c,0xe7e04eae,0xf090010f}},	//   _mfun, _قرون_, गणना_, _ענד_, 
   {{0xaa7802fb,0x69c401bf,0x00000000,0x00000000}},	//   brým, gbje, --, --, 
   {{0x6e903833,0x611000ac,0xada000d1,0xf1b0011a}},	//   _حلوا, _bələ, _йашл, רסל_, 
   {{0x63b92a7d,0xcd280832,0xf770007b,0x69c401bf}},	//   _nfun, _آسون_, هاء_, abje, 
   {{0x66e12a7e,0xbb452a7f,0xdce000a2,0x611003e3}},	// [1caa0] лота, _чепк, _kynį, _dələ, 
   {{0xd9102fee,0xb8f40729,0x393401c6,0x00000000}},	//   _پیر_, _সম_, _зэмс, --, 
   {{0x1ab8015b,0x611000ac,0x73340ed8,0x98b80064}},	//   _জিয়া, _fələ, کرائ, fyrą_, 
   {{0x61100cc1,0x2934008f,0x91fc0055,0x2ba40b7d}},	//   _gələ, _נאכן_, _ajāp, _गणमा, 
   {{0x25bc03e0,0x648000e4,0x84780023,0xb28404f0}},	//   _şule_, tõir, _ክኣምን_, ныкк, 
   {{0x63b86272,0xe4c000fd,0x91fc00cd,0xaa780022}},	//   _efun, _әйти, _smāb, yrým, 
   {{0xa5052a80,0x63b92a81,0x386000c5,0x73e40138}},	//   _пера_, _ffun, _kmkr_, _повз, 
   {{0x69c43ad4,0x64a12a82,0x61100213,0x71a401f0}},	//   zbje, _баса, _xələ, _ҷазз, 
   {{0xe3f400db,0x00000000,0x00000000,0x00000000}},	//   _سىلت_, --, --, --, 
   {{0x6ce40220,0x35900023,0xaa781a53,0x42500228}},	//   німе, _ዜናታት_, trým, _ۅچۉر, 
   {{0x9e001248,0x4d9802bf,0x320c06d9,0x274401e1}},	//   учыл, ькою_, mefy_, _kínú_, 
   {{0x320c05da,0x7cf4496e,0x00000000,0x00000000}},	//   lefy_, _sürç, --, --, 
   {{0xfd480241,0x274401e1,0x7cf400a2,0x7c300022}},	//   _kilọ, _mínú_, _pürç, рҵых, 
   {{0x320c03d1,0x61100213,0xaa7800d7,0x9a847a9c}},	//   nefy_, _sələ, prým, гусл, 
   {{0x64800124,0x69c4005c,0x611003e3,0x6f8c00d1}},	//   kõip, rbje, _pələ, ﻟﯩﻐﺎ_, 
   {{0x27440570,0x611003be,0x320c0109,0x69c402ed}},	//   _nínú_, _qələ, hefy_, sbje, 
   {{0x17f800c6,0x611003b9,0x2a6c0241,0x00000000}},	// [1cab0] عرفة_, _vələ, _ìgbo_, --, 
   {{0x63b8ed9b,0x320c0109,0x2b500c3c,0x97a4008e}},	//   _sfun, jefy_, ıncı_, урсл, 
   {{0x63b92a83,0x61100cc1,0x44f402de,0x27440ca8}},	//   _pfun, _tələ, тпес, _bínú_, 
   {{0xa4849f5f,0x7af0012c,0x00000000,0x00000000}},	//   رجان, šetř, --, --, 
   {{0x14752a84,0x320c06d9,0x77000014,0x939401c8}},	//   دالج, fefy_, _نژٕن, هجها, 
   {{0x68e014f5,0x25e800ab,0x00000000,0x00000000}},	//   _ånds, _चाटी_, --, --, 
   {{0x2d881196,0x91fc0055,0x00000000,0x00000000}},	//   übel_, _smāc, --, --, 
   {{0x63b853ff,0x3eb802ea,0x2508004b,0xa4fc0118}},	//   _ufun, ísto_, _ورځی_, ैबीच_, 
   {{0x442d095d,0xe8000574,0x00000000,0x00000000}},	//   _ine_, ऱ्या_, --, --, 
   {{0xab5804cc,0x52140212,0x3eb800df,0xfe4401c4}},	//   mbüh, _йдут, ŭsto_, тноо, 
   {{0x62812a85,0x2bc005ba,0x86680020,0xb60002d2}},	//   mono, _व्हा, _ተከትሎ_, _þáek, 
   {{0x6280305c,0x442d2a86,0x64492a87,0xa3e405d7}},	//   lono, _jne_, nkgi, पलट_, 
   {{0x442c0232,0xab58f178,0xdef0001f,0xeb940868}},	//   _mne_, nbüh, ግባኝ_, кию_, 
   {{0xeb9c2dba,0xbe64009f,0x00000000,0x00000000}},	//   ndøy_, _جهتي, --, --, 
   {{0x442d2a88,0x62812a89,0x395c0561,0x00000000}},	//   _one_, iono, àts_, --, 
   {{0x442d2a8a,0xe0e00729,0x62812a8b,0x78b801e4}},	//   _nne_, _মহাভ, hono, ŭtvo, 
   {{0x274401e1,0x00000000,0x00000000,0x00000000}},	// [1cac0] _rínú_, --, --, --, 
   {{0x62812a8c,0xfaa52a8d,0xba240124,0x27440cad}},	//   jono, _шапо, _рдок, _sínú_, 
   {{0x62812a8e,0x442c02ea,0x37e4004e,0x3934014b}},	//   dono, _bne_, _ионг, _рэпс, 
   {{0x3d18068f,0x78bc02e3,0x35d000cc,0xaa780022}},	//   _बनने_, _ọkwọ_, ালেহ, yrýk, 
   {{0x442caaca,0x320c05da,0x25e8033f,0x84540137}},	//   _dne_, tefy_, _चाची_, دىنچ, 
   {{0x442d2a8f,0xf5043804,0xeb9c143a,0x65c000d4}},	//   _ene_, _изго, gdøy_, _вбра, 
   {{0x320c44f2,0x442c0270,0xd13000c6,0x1cc80327}},	//   refy_, _fne_, صمة_, ིེས_, 
   {{0x442d2a90,0x74152a91,0x68e000b5,0x93c801ed}},	//   _gne_, _جورا, _ænde, _سارہ_, 
   {{0x62812a92,0x320c05da,0x00000000,0x00000000}},	//   bono, pefy_, --, --, 
   {{0x22f40302,0x442c9ceb,0xedf000ec,0x7cc00171}},	//   _בזמן_, _zne_, جيدگ, _mērf, 
   {{0x2d88037e,0x442c0023,0x00000000,0x00000000}},	//   æbe_, _yne_, --, --, 
   {{0x81b800eb,0x00000000,0x00000000,0x00000000}},	//   চরণ_, --, --, --, 
   {{0xee380323,0xaf341291,0x5b140108,0x2d800210}},	//   _онд_, _جرات, амят, łke_, 
   {{0x2bc00303,0x48c40139,0x00000000,0x00000000}},	//   _व्रा, ләма, --, --, 
   {{0x58d400c7,0x387002d2,0x00000000,0x00000000}},	//   иорт, fnyr_, --, --, 
   {{0x62812a93,0x6d540213,0x25c806ff,0xaa786aad}},	//   zono, _əyal, िर्ण, guýr, 
   {{0x442d2a94,0x62812a95,0xe78400c2,0x26cc0561}},	// [1cad0] _rne_, yono, туво, ègo_, 
   {{0x62812a96,0x442d2a97,0x6d5801c4,0x8a18041b}},	//   xono, _sne_, ozta, _џонс_, 
   {{0x62812a98,0x442c00a3,0x6d592a99,0x00000000}},	//   vono, _pne_, nzta, --, 
   {{0x62812a9a,0x442c00d8,0x6d58009d,0x7320031c}},	//   wono, _qne_, izta, _ལནྡྷ_, 
   {{0x9984803d,0x442c0208,0x73c0013d,0x00000000}},	//   _ملیو, _vne_, сәсе, --, 
   {{0x6d5402a8,0x2cf002ab,0xab592a9b,0x4ed005ac}},	//   _ƙyal, _अमूल_, rbüh, _ামূল, 
   {{0x62812a9c,0xa440168d,0x442d2a9d,0xc1d00032}},	//   rono, _پێشو, _tne_, _һөйә, 
   {{0x442d2a9e,0x62812a9f,0xd49820b0,0x44380254}},	//   _une_, sono, _ару_, _õs_, 
   {{0x62812aa0,0x6d592aa1,0xbdf82f7c,0x27fc002e}},	//   pono, ezta, ىردا_, _ñunu_, 
   {{0x2164053f,0x6e380175,0x62807caa,0x41b4007b}},	//   _итег, gjtb, qono, _إمار, 
   {{0xd1b92aa2,0x7cc000ef,0x6d580064,0x00000000}},	//   _شالا_, _mērg, gzta, --, 
   {{0xdb040165,0x7f5800d8,0x00000000,0x00000000}},	//   _sfiñ, _паес_, --, --, 
   {{0x6d5805f5,0x37e401d5,0x81b800fe,0x00000000}},	//   azta, ғозг, চৰণ_, --, 
   {{0xca752aa3,0x64b400f3,0x01e4015b,0x201c00c0}},	//   аусы, _aćim, প্রদ, ldui_, 
   {{0xc8b40c9e,0x37e52aa4,0x7cc000de,0x00000000}},	//   исты, ловг, _sērf, --, 
   {{0x201d2aa5,0xda00007d,0xbca400ec,0x00000000}},	//   ndui_, _लउकत_, _ڌمڪي, --, 
   {{0x387001bf,0xaa7800e4,0xa9a001ec,0x00000000}},	// [1cae0] rnyr_, ruýr, _қиюд, --, 
   {{0x91fc002b,0x35a40137,0xaa7800c7,0x00000000}},	//   _amān, газг, yrýi, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x15f0ad78,0x64a00354,0x6d4c01c3,0x00000000}},	//   _चाकर_, баха, ùbai, --, 
   {{0x7bd40083,0x23240261,0x3948003a,0xa8000d30}},	//   _meyu, лоци_, lybs_, _узял, 
   {{0x7bd52aa6,0x00000000,0x00000000,0x00000000}},	//   _leyu, --, --, --, 
   {{0x6d540b45,0x60b80131,0x98b80024,0x00000000}},	//   _ƙyam, _ﻧﺎﺧﺸ, tyrę_, --, 
   {{0x7bd40921,0xf50402f4,0xe2940032,0xb86c0092}},	//   _neyu, _изҳо, _ҡат_, _በወጣው_, 
   {{0xf3340055,0x25b40200,0x1fa00166,0x4374014b}},	//   _kaṭā_, _çelë_, йрьг, _куфт, 
   {{0x71581c83,0x4374a229,0x6d580112,0xf33400b8}},	//   _прес_, _туст, tzta, _jaṭā_, 
   {{0x7bd4207b,0xafe43756,0x6d592aa7,0x00000000}},	//   _beyu, _боел, uzta, --, 
   {{0xdd952aa8,0x7bd4022f,0xd01036fe,0x321c00ee}},	//   ышы_, _ceyu, _ذلت_, _haty_, 
   {{0x6d592aa9,0x7bd4022e,0x321c0f85,0x00000000}},	//   szta, _deyu, _katy_, --, 
   {{0x7bd40472,0x245405d1,0xaa78035b,0xf3340055}},	//   _eeyu, _içme_, guýp, _naṭā_, 
   {{0x321c1311,0xaa780122,0x6ce4155b,0x4c942377}},	//   _maty_, krýv, _сіле, _кикс, 
   {{0xd7f92aaa,0x7bd40548,0x3d18e60e,0xaa640116}},	//   луу_, _geyu, _बनते_, _әтик, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [1caf0] --, --, --, --, 
   {{0x7bd4bc12,0x201c36a6,0x91fc00b8,0x00000000}},	//   _zeyu, zdui_, _smān, --, 
   {{0x91fc0607,0x7bd52aab,0x2cf00d79,0x7cc000ef}},	//   _amāo, _yeyu, _अमोल_, _vērg, 
   {{0xe784412c,0x69d52aac,0xc4352aad,0x81b80183}},	//   _буго, _hexe, جکست, চৰা_, 
   {{0x2d8d2aae,0xb7d80302,0x69d52aaf,0x4ab41408}},	//   _lyfe_, _בקרי, _kexe, ंदिव, 
   {{0x7cc000b0,0x5ec000fe,0x00000000,0x00000000}},	//   _hēre, _শিলে, --, --, 
   {{0xdb24006a,0x69d52ab0,0x91fc6856,0x321d2ab1}},	//   _âsön, _mexe, _imāl, _daty_, 
   {{0x69d52ab2,0x321c00c7,0x4ab40401,0xc2c401f7}},	//   _lexe, _eaty_, ंदाव, _نيري, 
   {{0x321c0851,0x7cc0005f,0x7bd52ab3,0x237418fd}},	//   _faty_, _mēre, _reyu, _صارح, 
   {{0x69d4004b,0x321c09a5,0x7bd40472,0xe2c4004b}},	//   _nexe, _gaty_, _seyu, _لوړو_, 
   {{0x7bd52ab4,0x2d8005d1,0x9848054e,0xc0140108}},	//   _peyu, şken_, nşă_, _вмещ, 
   {{0x20d00311,0x443c0472,0x321c00a2,0x4a7400fb}},	//   mţi_, njw_, _zaty_, ҡырт, 
   {{0x20d000a8,0x69d52ab5,0x91d800fe,0x59b401e0}},	//   lţi_, _bexe, _সাতখ, йөнс, 
   {{0x2ba52ab6,0x7bd45a25,0x20d00311,0x00000000}},	//   _गणरा, _weyu, oţi_, --, 
   {{0x20d000a8,0x69d52ab7,0xa96400c7,0x7bd4003e}},	//   nţi_, _dexe, аира_, _teyu, 
   {{0x87b80364,0x91fc442c,0x20d00311,0x18b400c7}},	//   гуфт_, _amāl, iţi_, _ҳәар, 
   {{0x69d52ab8,0x16080220,0xf3340055,0x00000000}},	// [1cb00] _fexe, лмақ_, _paṭā_, --, 
   {{0x18b40124,0x3948004e,0x9d240154,0xab24030d}},	//   _гәар, _азоо_, মহীন_, _тоьа_, 
   {{0x321c0034,0x95b40124,0xab5806be,0xfbb800bc}},	//   _raty_, арҵә, ccüb, _इलाम, 
   {{0x321d2ab9,0x69d400f1,0x00000000,0x00000000}},	//   _saty_, _zexe, --, --, 
   {{0x321ca00c,0x69d52aba,0x20d00311,0x9848054e}},	//   _paty_, _yexe, eţi_, aşă_, 
   {{0xf5080724,0xe29405f5,0x69d4003e,0x321c036e}},	//   _ингл_, аач_, _xexe, _qaty_, 
   {{0x443c0036,0x321c02f0,0xf8a80073,0x00000000}},	//   bjw_, _vaty_, _कळाय, --, 
   {{0xf104924b,0x321d2abb,0x644000d8,0x91fc002b}},	//   _शहीद_, _waty_, ênit, _imām, 
   {{0x321c0851,0x20d000a8,0xab580112,0x00000000}},	//   _taty_, aţi_, nbüt, --, 
   {{0xeda52abc,0xc3080154,0x00000000,0x00000000}},	//   ишно, লিশি_, --, --, 
   {{0x69d4172e,0x20d00311,0xa5b40a7c,0x6ce401ec}},	//   _rexe, cţi_, יליק_, шіпе, 
   {{0x69d52abd,0x4cb800bd,0x2298145e,0xaca401ed}},	//   _sexe, _আবদু, rêke_, جھتے_, 
   {{0x69d40694,0x2d8c039a,0x7cc002b1,0xca84022e}},	//   _pexe, _wyfe_, _rēre, оsаr, 
   {{0x5ef00574,0x7cc000ef,0xfd7800e5,0x00000000}},	//   ंढर्_, _sēre, ئشیں_, --, 
   {{0x69d52abe,0x7e7c0407,0x5e54008f,0xda780108}},	//   _vexe, éspe, _דיגע_, ряя_, 
   {{0x69d52abf,0x37c03ad0,0x8bd40063,0x00000000}},	//   _wexe, зәрб, _ужиц, --, 
   {{0x69d52ac0,0x91fc0421,0xd8380166,0x00000000}},	// [1cb10] _texe, _amām, шэр_, --, 
   {{0x25a83cd9,0x69d4003a,0xa92400ef,0x3eb92ac1}},	//   نداي_, _uexe, _pažē, ísti_, 
   {{0xe4a4f514,0xd5b92ac2,0x00000000,0x00000000}},	//   ардо, рсу_, --, --, 
   {{0xd4980323,0x00c8036b,0x29000240,0x443c012d}},	//   арч_, қлик_, mtja_, ujw_, 
   {{0xe0e004c5,0xda0438bf,0xd8382be5,0x290001d3}},	//   _মহেন, श्वत_, _тээ_, ltja_, 
   {{0x06cc2158,0x91fc0418,0xc308009e,0xd2640212}},	//   _লিপি, _umāl, লিলি_, окій, 
   {{0x29012ac3,0x7cc000e2,0x1a9c008f,0x20d00356}},	//   ntja_, _mērc, דיגע, uţi_, 
   {{0x20d000a8,0x260c05f9,0xfd940032,0xb60400e2}},	//   rţi_, ड़की_, ҙөлә_, _višņ, 
   {{0x29000200,0x00000000,0x00000000,0x00000000}},	//   htja_, --, --, --, 
   {{0x20d00276,0xf7c80ae5,0xa1840139,0x8e740212}},	//   pţi_, _ﺑﯩﻠﺪ, _кыел, жуюч, 
   {{0x249d2ac4,0x29012ac5,0x707401d5,0x70500244}},	//   _khum_, jtja_, شمیز_, زنیا, 
   {{0xed5402bf,0x2bc000bc,0x00000000,0x00000000}},	//   сою_, वुला, --, --, 
   {{0x249c020c,0x91fc002b,0xaa7800e4,0xff242bef}},	//   _mhum_, _ajāy, yrýt, _دبای, 
   {{0x59080022,0xfaa4030d,0x00000000,0x00000000}},	//   аҵом_, саго, --, --, 
   {{0x3ea40204,0x00000000,0x00000000,0x00000000}},	//   mmlt_, --, --, --, 
   {{0x8d752ac6,0x332404cc,0x249c0051,0x7cc000de}},	//   _باها, yvox_, _nhum_, _tērb, 
   {{0xe7352ac7,0xcc0800db,0xf5b4007b,0xd6c52ac8}},	// [1cb20] бет_, _ئزىن_, مصاد, زمای, 
   {{0x249c016b,0x4ab40210,0xba74009a,0x00000000}},	//   _ahum_, ंदरव, _دابت, --, 
   {{0x249c014b,0xab5800ac,0xdb0400ae,0x05b8000d}},	//   _bhum_, bbüs, _ngiú, ेड़ब, 
   {{0x249d2ac9,0x8d901772,0x64a00a89,0x53c80fc0}},	//   _chum_, _ማዕበል_, паха, рҳам_, 
   {{0xf7700597,0x94c800aa,0xc0d0069d,0xab58061f}},	//   _راح_, _چارې_, _ኦባማ_, lbür, 
   {{0x94c800f1,0x36680139,0x00000000,0x00000000}},	//   _نارې_, _саго_, --, --, 
   {{0x91fc0421,0xab59281c,0x00000000,0x00000000}},	//   _umām, nbür, --, --, 
   {{0x249c047e,0xd138033f,0x00000000,0x00000000}},	//   _ghum_, _rząd_, --, --, 
   {{0x64a12aca,0xb8f82b88,0xdd8c01d9,0xeea80108}},	//   _хата, _ོས_, ہوٝ_, лток_, 
   {{0x29000008,0x06cc0f22,0x00000000,0x00000000}},	//   ytja_, _লিমি, --, --, 
   {{0x91800075,0xdf5401d5,0xe1b45285,0xa63800df}},	//   _تۇغۇ, لشیش_, _اُمت_, אגיר, 
   {{0x91fc06c8,0x0e6401ec,0x00000000,0x00000000}},	//   _omāk, скүн, --, --, 
   {{0xab84ab37,0x78bc02e3,0x7cc000ef,0x998c0023}},	//   сунк, _ọkpọ_, _pērc, _መስለኒ_, 
   {{0x29012acb,0x66dc01e1,0x6d4c01ab,0x00000000}},	//   ttja_, _làká, ùbas, --, 
   {{0x19592acc,0x58d42218,0xe5cc02dd,0x00000000}},	//   бары_, зост, _ﺗﯘﻟﻜ, --, 
   {{0x29012acd,0x06cc0154,0xe7852ace,0xaa7806ea}},	//   rtja_, _লিবি, бузо, trýs, 
   {{0x249d2acf,0xaae400c6,0xaa7800a2,0x00000000}},	// [1cb30] _rhum_, _اسبو, asýa, --, 
   {{0x249c044e,0x7cc002b1,0x95d8023a,0xab5803e3}},	//   _shum_, _hēra, йдут_, bbür, 
   {{0x7d0c0114,0x2454083c,0x249ce4e2,0x14a40073}},	//   _ćask, _açma_, _phum_, _ओळखण, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x249c02c4,0x7cc000de,0x9324007b,0x00000000}},	//   _vhum_, _mēra, كرون, --, 
   {{0xed4400db,0x00e00150,0x3d181d94,0x00000000}},	//   _قپ_, _ﺍﻹﺭﺘ, _बनले_, --, 
   {{0x249d2ad0,0x244405f5,0x00000000,0x00000000}},	//   _thum_, _лхаг, --, --, 
   {{0x237c0457,0x6614009a,0x83a40022,0x50580006}},	//   _txuj_, lexk, _дызҵ, йшыя_, 
   {{0x3eb80a85,0xa2640395,0x00000000,0x00000000}},	//   êst_, _лъжл, --, --, 
   {{0xd2440209,0x7d080640,0x3eb001d3,0x00000000}},	//   _нэхи, аног_, özt_, --, 
   {{0x3ea4089c,0xee340024,0xaa7800e4,0x00000000}},	//   rmlt_, іню_, yrýr, --, 
   {{0xccfc0085,0xefc8001f,0xb4f80375,0x00000000}},	//   mpɛ́_, አቸው_, ספרי, --, 
   {{0xa2d400fe,0xf1c4448b,0x00e00150,0x00000000}},	//   _সমুখ, रुवन, _ﺍﻹﺠﺘ, --, 
   {{0xab580b70,0xde440101,0x00000000,0x00000000}},	//   tbür, _چیکو_, --, --, 
   {{0xf8a801d5,0x661401c4,0xed4c004b,0x91fc00cd}},	//   لدره_, dexk, _ټپي_, _smāk, 
   {{0x77c92ad1,0xfaa4016c,0xab592ad2,0x00000000}},	//   рлаг_, саҳо, rbür, --, 
   {{0xaa7809cc,0x09d8015b,0x7c3400b5,0xab587148}},	// [1cb40] msýn, _তারা, _inyr, sbür, 
   {{0x7c243fc8,0x66dc0241,0x39340064,0xb6a40166}},	//   ldkr, _sàká, _дэмс, цизл, 
   {{0xab58f768,0x7c252ad3,0x00000000,0x00000000}},	//   ncün, odkr, --, --, 
   {{0x87b81fe2,0xc32c0b38,0xdb0401c3,0x181800f2}},	//   _гурт_, گەك_, _sgiù, _اردک_, 
   {{0xe3b41cd1,0x7c340200,0xdb240139,0x91fc0055}},	//   әбә_, _mnyr, _äsän, _umāk, 
   {{0xc32c04a9,0x30e871fe,0xea7c0092,0x36680114}},	//   دەك_, афин_, _የቅድመ_, _ђаво_, 
   {{0x7c340204,0xf77000db,0x63741321,0xc0c40150}},	//   _onyr, _راڭ_, йсәр_, пшық, 
   {{0x64a073c5,0x260800ab,0xceb80b8d,0x7c2401f5}},	//   _жаса, ठ्ठी_, бәк_, jdkr, 
   {{0x7c24007c,0x245415b7,0x57b8012d,0x00000000}},	//   ddkr, _uçma_, _अलैह, --, 
   {{0x63000014,0xb50c0b7d,0x7c34dccc,0x5ec00154}},	//   _آوٕل, _सहाय_, _anyr, _শিখে, 
   {{0x7cc002b5,0x4c9495b2,0x2020005b,0x09d80154}},	//   _pēra, зинс, öriä_, _তালা, 
   {{0x6614005a,0x91fc00b8,0x5cb40006,0xaa7808a5}},	//   zexk, _smāh, ўляў_, gsýn, 
   {{0x92e8000e,0x4f840014,0xf1dc00bc,0xc8787b47}},	//   _বহু_, _عاصہ, _नजान, _ış_, 
   {{0xcdb800d3,0x00000000,0x00000000,0x00000000}},	//   _угкц_, --, --, --, 
   {{0x6d540198,0x7cc07106,0x28680063,0x00000000}},	//   _ƙyau, _tēra, арао_, --, 
   {{0x69c800dc,0xaa400092,0x00000000,0x00000000}},	//   _त्री, _ያገኘሁ, --, --, 
   {{0xb900375c,0x387d2ad4,0x00000000,0x00000000}},	// [1cb50] _नौ_, étra_, --, --, 
   {{0xe61000c6,0x4a740014,0x7cc000de,0x3d10000d}},	//   بشر_, _ژُکر, _mērn, _तहमे_, 
   {{0x6614005a,0xe970009f,0x00000000,0x00000000}},	//   rexk, _آنجھ, --, --, 
   {{0x53e40588,0xaa0401d3,0x00000000,0x00000000}},	//   ҿцәа, _اٹھے_, --, --, 
   {{0x668001d5,0x00000000,0x00000000,0x00000000}},	//   _قیرل, --, --, --, 
   {{0x32f00075,0x76b80375,0x00000000,0x00000000}},	//   ركىز, _למשפ, --, --, 
   {{0xd3780131,0x00000000,0x00000000,0x00000000}},	//   йчә_, --, --, --, 
   {{0x7cc011f9,0xbbb81ab2,0x8d74001f,0x7f4c025c}},	//   _bērn, _इलेक, _ጥያቄው_, _żaqq, 
   {{0x64580140,0xaa780124,0x3cdc01f9,0x00000000}},	//   _ilui, yrýp, कीने_, --, 
   {{0x57b80307,0x7c340008,0x00000000,0x00000000}},	//   _अल्ह, _snyr, --, --, 
   {{0x645823f5,0xee3401c0,0xe46801e1,0xf27800df}},	//   _klui, чнэ_, _ìdó̟, _פרעש, 
   {{0x8d54013d,0x00000000,0x00000000,0x00000000}},	//   фтьч, --, --, --, 
   {{0xeb9c019b,0xdb08864e,0x2d8803fa,0xef0d2ad5}},	//   lføj_, _ölüm, über_, _ям_, 
   {{0x64580228,0xed4c00f1,0x00000000,0x00000000}},	//   _llui, _څپو_, --, --, 
   {{0x25dc00e1,0x64592ad6,0xab5803e0,0x5d480354}},	//   गरनी_, _olui, lcül, _тăвĕ, 
   {{0x7cc00383,0x36c52ad7,0xb340344b,0x00000000}},	//   _hēro, збаг, şçil, --, 
   {{0xf5e81b9f,0xe7352ad8,0x91fc0055,0xabf8011a}},	// [1cb60] ймал_, пет_, _imāv, _ההפר, 
   {{0x64592ad9,0x195400b5,0x00000000,0x00000000}},	//   _alui, _ｉｎｇ_, --, --, 
   {{0x64592ada,0xddc00b23,0x92e802f5,0x7cc000e2}},	//   _blui, _nonō, _বহে_, _mēro, 
   {{0x645861a1,0x7bc52adb,0x00000000,0x00000000}},	//   _clui, ncku, --, --, 
   {{0x27f40232,0x645800a3,0x7ae40a7f,0x78bc0175}},	//   šené_, _dlui, nskt, _hupv, 
   {{0x64592adc,0x00000000,0x00000000,0x00000000}},	//   _elui, --, --, --, 
   {{0x78bc014f,0xa5c800e5,0x00000000,0x00000000}},	//   _jupv, _چاہۓ_, --, --, 
   {{0x09b80574,0x64592add,0x16140034,0x7cc000e2}},	//   _आल्य, _glui, ड़कर_, _pērn, 
   {{0x973002d3,0x78bc0455,0xb1b475f5,0x00000000}},	//   _ሰራዊት, _lupv, _فحاش, --, 
   {{0x3ebc01a4,0x91fc6856,0x00000000,0x00000000}},	//   _duwt_, _amāv, --, --, 
   {{0xd7dc01f9,0x00000000,0x00000000,0x00000000}},	//   बराच, --, --, --, 
   {{0x09c40490,0x2fd000a2,0x00000000,0x00000000}},	//   वड्य, _ýyg_, --, --, 
   {{0x7ae4074d,0x6d540198,0xf1c40254,0xdb5800f5}},	//   gskt, _ƙyas, रुअन, пюр_, 
   {{0xbd001709,0x7cc000ef,0x7648007c,0x3ce400ef}},	//   ñéce, _kērl, öfyl, bslv_, 
   {{0x19589a21,0x78bc0158,0x2d980588,0x9e200132}},	//   пары_, _cupv, _ápe_, _سىيو, 
   {{0x78bc014f,0x7cc00171,0x38700139,0x32a80150}},	//   _dupv, _mērl, giyr_, _ﺷﻮﮔﻪ, 
   {{0xd7c828fa,0x58840588,0x1e640345,0x00000000}},	// [1cb70] سوله_, хыра, _بخۆێ, --, 
   {{0x6458d503,0x00000000,0x00000000,0x00000000}},	//   _slui, --, --, --, 
   {{0x64592ade,0x0518ba15,0xab5803e0,0x00000000}},	//   _plui, تياب_, zcül, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7800016c,0x6ab4031c,0x6458062c,0x73c000fd}},	//   _шӯра, _kixf, _vlui, тәсе, 
   {{0x200c05b1,0x6d5406be,0x59d0cad6,0xa50400c0}},	//   _sbgi_, _əyar, तुपर, _нябл, 
   {{0x94040451,0x6d4c143a,0x0084004e,0x850400be}},	//   _ڳوله, øbal, млко, _توزن, 
   {{0x64592adf,0x7ae40b21,0x6d08025c,0x9184167e}},	//   _ului, yskt, _ཀྱེེ_, رۇنۇ, 
   {{0x63b8376b,0xb3980020,0x5ec000cc,0xbea401a9}},	//   _igun, ላቸውን_, _শিঙে, маик, 
   {{0x91fc0607,0x6ab4025c,0x69c52ae0,0xfe4400d4}},	//   _alāf, _nixf, jcje, єнно, 
   {{0xb3080c99,0x9bb8003d,0x7cc0005f,0x69c41710}},	//   _གདོང_, _དཔྱོ, _vēro, dcje, 
   {{0x61e07b4e,0x9ce4066d,0x20c12ae1,0x78bc0477}},	//   lanl, _ہوتے_, _iñi_, _rupv, 
   {{0x63b92ae2,0x3d180307,0x78bc0477,0x4f942377}},	//   _mgun, _बनके_, _supv, _пршу, 
   {{0x61e12ae3,0x63b801d5,0x7bc40113,0x7ae52ae4}},	//   nanl, _lgun, scku, rskt, 
   {{0x63b92ae5,0x78bc047e,0xc3080154,0x6e9001f7}},	//   _ogun, _qupv, লিটি_, _جلوا, 
   {{0x63b92ae6,0x61e12ae7,0xb8f4367a,0x9bb80327}},	//   _ngun, hanl, _हऽ_, _དཔྲོ, 
   {{0x61e12ae8,0xb3080003,0x6ab52ae9,0x66e0f297}},	// [1cb80] kanl, _གདེང_, _fixf, кота, 
   {{0xe6152aea,0x61e12aeb,0x78bc0455,0xa68008ca}},	//   мду_, janl, _tupv, влуд, 
   {{0x61e12aec,0xa5040395,0x00000000,0x00000000}},	//   danl, деха_, --, --, 
   {{0x06cc0154,0x61e0002f,0x00000000,0x00000000}},	//   _লিরি, eanl, --, --, 
   {{0x61e12aed,0x73344e7f,0xdb0800fd,0xb284004e}},	//   fanl, برائ, _äläl, мыкк, 
   {{0x63b8152d,0x61e12aee,0x7df811b1,0x7cc000e2}},	//   _egun, ganl, ्भोग_, _pērl, 
   {{0x63b80051,0x66000798,0x3d18000d,0x00000000}},	//   _fgun, _шпра, _बनगे_, --, 
   {{0xe5a12aef,0x91fd2af0,0x983c001f,0xceb80116}},	//   _риси, _amāt, _አወቃቀ, пәк_, 
   {{0x61e041bb,0xc44400e5,0x00000000,0x00000000}},	//   banl, _سیون_, --, --, 
   {{0x61e006b9,0x6ce402dd,0xa2c801ad,0xe1f400db}},	//   canl, міме, सऑर्, _огу_, 
   {{0xab583235,0x20c000e8,0xc1d40116,0x63b8022e}},	//   rcüm, _gñi_, _чөчә, _ygun, 
   {{0x3a3803f9,0x83fc00dd,0x6ab40072,0x320c37b5}},	//   _anpp_, _előf, _sixf, lffy_, 
   {{0x92bc00bd,0x2ca800f2,0x69c40841,0x00000000}},	//   _আবু_, rmcd_, tcje, --, 
   {{0xab580205,0x00000000,0x00000000,0x00000000}},	//   lcük, --, --, --, 
   {{0x199406bb,0x69c402d3,0x320c0076,0x5df8011a}},	//   варя, rcje, iffy_, _ופונ, 
   {{0x61e12af1,0x69c41710,0x91fc002b,0x00000000}},	//   zanl, scje, _hlād, --, 
   {{0x61e03630,0x59d0ec85,0xc6f8109a,0x00000000}},	// [1cb90] yanl, _त्वर, янах_, --, 
   {{0x63b80ffb,0x61e000ac,0x09d8015b,0x00000000}},	//   _sgun, xanl, _তাকা, --, 
   {{0x61e12af2,0xe8e800aa,0xe4c90ee6,0x00000000}},	//   vanl, _برخو_, زبان_, --, 
   {{0xe784004e,0x00000000,0x00000000,0x00000000}},	//   _жуго, --, --, --, 
   {{0x61e12af3,0x9f48029f,0x00000000,0x00000000}},	//   tanl, ücü_, --, --, 
   {{0x61e00112,0xa1440014,0x4128004e,0x00000000}},	//   uanl, ویذٕ_, зоко_, --, 
   {{0x61e12af4,0x91fc0618,0xc48400b2,0x63b807de}},	//   ranl, _amās, _ٻڌاي, _tgun, 
   {{0x61e12af5,0x63b92af6,0xff252af7,0x91fc00b8}},	//   sanl, _ugun, емио, _smāt, 
   {{0x61e12af8,0xef141c22,0x60c00309,0xccdc01ec}},	//   panl, емы_, sqnm, _ﺘﺯﺍل_, 
   {{0x61e01938,0xe3d400eb,0xd214009b,0x00000000}},	//   qanl, _হাটব, _имућ, --, 
   {{0x20c002d1,0xdeb8001f,0xc1040592,0xa08001ee}},	//   _uñi_, _ተገኘ_, _سوشي, _иңке, 
   {{0x9ac4013d,0x00000000,0x00000000,0x00000000}},	//   кимҗ, --, --, --, 
   {{0x7cf4032e,0xe9a001ec,0x00000000,0x00000000}},	//   _býrð, ғатп, --, --, 
   {{0xf2d010df,0x78a401a9,0xfce4014b,0x00000000}},	//   רעם_, _shkv, _зоко, --, 
   {{0x7c942218,0x7cf408a5,0x7cc000de,0x310000cd}},	//   _приц, _dýrð, _mērk, रूपः_, 
   {{0xfbd800bd,0xf7452af9,0x00000000,0x00000000}},	//   _থাকত, небо, --, --, 
   {{0x4ecc010f,0x00000000,0x00000000,0x00000000}},	// [1cba0] ַזאַ, --, --, --, 
   {{0xab5805d1,0xaba4008e,0x00000000,0x00000000}},	//   zcük, _явыз_, --, --, 
   {{0x69c0045f,0x92bc009e,0xb60402f0,0xae54010f}},	//   _ûnea, _আবে_, jváž, עסעס_, 
   {{0xf4952afa,0xb6040306,0x2db4010f,0xb9cc0023}},	//   رشاد, dváž, גלען_, _ሱሩ_, 
   {{0x66003769,0x7cc000ef,0x00000000,0x00000000}},	//   _әпса, _bērk, --, --, 
   {{0x75d52afb,0x91fc00b8,0x6d4c0217,0x3ce400fe}},	//   _سيرا, _amār, øbak, _কমন্_, 
   {{0xe5a12afc,0x14040022,0x2be000dc,0xa190010b}},	//   _бири, _аҧен, परमा, лашч, 
   {{0xa1300f87,0x764d2afd,0x00000000,0x00000000}},	//   اروش, _hoby, --, --, 
   {{0xb308025c,0x9f5c5a58,0x442801e4,0xab580205}},	//   _གདིང_, nguè_, ɾa_, ccüh, 
   {{0xdbd401e1,0x83fc01d3,0x28a4012d,0x00000000}},	//   _gúúd, _előd, _कीनि, --, 
   {{0x764d2afe,0xa1112aff,0x00000000,0x00000000}},	//   _moby, _مولت, --, --, 
   {{0xdb04005a,0x3d10007d,0xa0640354,0x764d2b00}},	//   _agiñ, _तहरे_, _паха_, _loby, 
   {{0x2be009ab,0x00000000,0x00000000,0x00000000}},	//   परबा, --, --, --, 
   {{0x764c256c,0xdbd40241,0x7ac40107,0x00000000}},	//   _noby, _múùd, тиёҷ, --, 
   {{0xa8a52b01,0x5b140046,0x1fb00166,0xd914009d}},	//   ерак, _ұмыт, _исәр, лдры, 
   {{0xdb04009d,0x6e292b02,0x2d8003e0,0x00000000}},	//   _egiñ, _hafb, şkes_, --, 
   {{0x09c400c7,0xb6040306,0x2cb806be,0x6e2808a5}},	// [1cbb0] _аӡбо, zváž, _iiqd_, _kafb, 
   {{0x26cc005f,0xaa780419,0x00000000,0x00000000}},	//   īgo_, hrýz, --, --, 
   {{0x764c3e91,0xbf1c012c,0xa5180118,0x00000000}},	//   _doby, _भन्न_, नबेच_, --, 
   {{0x4374ded0,0x19a92b03,0x6e280009,0xe3b00214}},	//   култ, _ятып_, _lafb, هرش_, 
   {{0x442801a2,0x7cc0005f,0x648001e4,0x91fc0055}},	//   ľa_, _pērk, bĵin, _rmār, 
   {{0x764d2b04,0x44283858,0x91fc3da0,0x09b40eac}},	//   _goby, ža_, _alāb, _জ্যা, 
   {{0x11e800db,0x637001d3,0xe2a401d9,0x04c81410}},	//   رعوي_, _bűnö, ٘اژن_, _آوري_, 
   {{0x9f5d2b05,0x7ae000a2,0x00000000,0x00000000}},	//   lgué_, _çotg, --, --, 
   {{0x6e280175,0xc1d00032,0x73c01945,0x94852b06}},	//   _bafb, _көйә, _тәхе, _сырд, 
   {{0x9f5d2b07,0x7cc002b5,0x5e600075,0x12940124}},	//   ngué_, _hēri, اندە, _биуџ, 
   {{0xed4001ec,0x00000000,0x00000000,0x00000000}},	//   анэп, --, --, --, 
   {{0xed5400d6,0x91fc005f,0x6e2800a3,0x7cc000ef}},	//   тою_, _glāb, _eafb, _jēri, 
   {{0xed4c0424,0x6e280175,0xce340133,0x7cc000de}},	//   مپی_, _fafb, _ڕووک, _mēri, 
   {{0x201c4264,0x00000000,0x00000000,0x00000000}},	//   leui_, --, --, --, 
   {{0x09b400bd,0x24540139,0xaa412b08,0x4ea40120}},	//   _জ্বা, _eçmi_, шерл, _срца, 
   {{0x764d2b09,0x2be00073,0x00000000,0x00000000}},	//   _soby, परणा, --, --, 
   {{0x764ca3f5,0xbb4417a0,0x00000000,0x00000000}},	// [1cbc0] _poby, _репк, --, --, 
   {{0xecc40724,0x9f5d2b0a,0x9b0c010f,0xaa780022}},	//   _яшәү, ggué_, ĥĥĵĵ, ysýi, 
   {{0xd8840214,0xe4c04534,0x7cc000ef,0xd58401d5}},	//   _مهدی, айхи, _bēri, уғво, 
   {{0x91fc0055,0xe510000d,0xdeec0023,0x00000000}},	//   _amāp, _ठहरि_, ሂለን_, --, 
   {{0x201c0098,0x2be00490,0xf7d000d1,0x00000000}},	//   deui_, परता, _ﭘﻪﻳﺪ, --, 
   {{0x98b80024,0x00000000,0x00000000,0x00000000}},	//   tyrė_, --, --, --, 
   {{0x6e2801a8,0xc8b40345,0x00000000,0x00000000}},	//   _rafb, _جلێک, --, --, 
   {{0x628d2b0b,0x83fc01ed,0x6e280368,0x09d8015b}},	//   _ícon, _előb, _safb, _তাছা, 
   {{0xb2242e58,0x91c401e0,0xb308029c,0x00000000}},	//   _имал, _йәйл, _تغزل_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3cdc0ebb,0x00000000,0x00000000,0x00000000}},	//   कीले_, --, --, --, 
   {{0x0178008f,0xfe000022,0x00000000,0x00000000}},	//   _אָנל, аҟәм, --, --, 
   {{0xab8401ce,0xaa7800e4,0x00000000,0x00000000}},	//   тунк, isýv, --, --, 
   {{0x6e28005c,0xa9c80022,0x00000000,0x00000000}},	//   _uafb, ьымз_, --, --, 
   {{0x98c52b0c,0x1ae400eb,0x6ca4009b,0xeca400f3}},	//   истл, কূলে_, _ириж, _ијин, 
   {{0x1d040640,0x3da402bf,0xd7f80137,0x00000000}},	//   _рећи_, _сріб, куу_, --, 
   {{0x7cc0e762,0x4734ad0e,0x2aa800db,0x00000000}},	// [1cbd0] _rēri, ынас, _отоо_, --, 
   {{0x7cc0005f,0xe8700066,0x00000000,0x00000000}},	//   _sēri, _چندگ, --, --, 
   {{0x7cc0c436,0x9f5c928e,0xf8c400d0,0xf8ad2b0d}},	//   _pēri, rgué_, žéra_, تکی_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe5c40fc0,0x7cc000e2,0x932401e2,0x00000000}},	//   _асбо, _vēri, لرون, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x201c0270,0x7cc000de,0xd4c400d4,0x00000000}},	//   teui_, _tēri, _всуп, --, 
   {{0x90352b0e,0xb4b401e0,0x91fc0171,0x00000000}},	//   ахьч, _бисә, _plāc, --, 
   {{0xe3b0323b,0x201c003e,0x81d40117,0x00cc0150}},	//   _ضرر_, reui_, _бозх, _ﻗﺎﺩﺘ, 
   {{0x442d2b0f,0xbe640128,0xae840026,0x7cc00171}},	//   _hae_, اهدي, лбыз_, _mērv, 
   {{0x442d2b10,0xece401c0,0x418401af,0x00000000}},	//   _kae_, лдэл_, _стағ, --, 
   {{0x442d2b11,0x64480399,0xca280a7c,0x5e6000db}},	//   _jae_, njgi, _מם_, انگە, 
   {{0x442c1649,0x62812b12,0xee2c0024,0x37e000cc}},	//   _mae_, onno, _лн_, _ফালৰ, 
   {{0x442d2b13,0x00000000,0x00000000,0x00000000}},	//   _lae_, --, --, --, 
   {{0xc9543cd9,0x442c2486,0x62812b14,0xed1401d3}},	//   атты, _oae_, inno, _یہیں_, 
   {{0x442d2b15,0x1df00d2c,0xfaa4013e,0xfc040276}},	//   _nae_, _आयुष_, таҳо, _спио, 
   {{0x7d0000f3,0xeb94030d,0x35f808de,0x00000000}},	// [1cbe0] luls, _йиъ_, فراد_, --, 
   {{0x06cc39db,0x442d2b16,0x3a2400c9,0xd3440344}},	//   _লিখি, _aae_, _смог, یفای, 
   {{0x442d2b17,0xae041715,0x59a80316,0x7d010aa9}},	//   _bae_, _शासन_, _गरिर, nuls, 
   {{0xe4d461f4,0x442d2b18,0x62812b19,0x64480369}},	//   اونت_, _cae_, enno, gjgi, 
   {{0x442d2b1a,0x68e0019b,0xcec8001e,0xb37426a8}},	//   _dae_, _ændr, _mộc_, دداش, 
   {{0x11540cca,0x442d2b1b,0x7d012b1c,0xcec8001e}},	//   иклю, _eae_, kuls, _lộc_, 
   {{0x442c0c3a,0x7d001654,0xd13000c6,0xa2241f5a}},	//   _fae_, juls, زمة_, ужја_, 
   {{0x442d2b1d,0x62812b1e,0x7d012b1f,0x98b4012c}},	//   _gae_, anno, duls, ंगिए, 
   {{0xa8540302,0xb3841c6c,0xa44001c6,0xe0cc01d9}},	//   טיקה_, _слал, _унтд, _ہٲل_, 
   {{0x5c1409bd,0x7d012b20,0xdce0247e,0xbe80036b}},	//   িযোগ_, fuls, _aynı, оқчи, 
   {{0x442d2b21,0xcec801fb,0x7d012b22,0x6678011a}},	//   _yae_, _bộc_, guls, תטיק, 
   {{0x5274301f,0x4ea40224,0x4c952b23,0xeb9c2142}},	//   _суғу, ырқа, римс, dfør_, 
   {{0xeb0400c9,0x9f5c04cc,0x5c7400f5,0x82800022}},	//   ычно, nguì_, слят, _ықәд, 
   {{0xee2c0116,0xeb9c005c,0xa14000de,0x00000000}},	//   _анa_, ffør_, _šķis, --, 
   {{0xeb9c06ea,0x69c80073,0xeb04008e,0x00000000}},	//   gfør_, तुगी, _өчпо, --, 
   {{0x765c017a,0x9a8401ec,0xcec80051,0x6d580857}},	//   ekpy, _қуыл, _gộc_, myta, 
   {{0x62812b24,0x442d2b25,0x6d592b26,0xfe6c04d3}},	// [1cbf0] ynno, _rae_, lyta, _رگی_, 
   {{0x442d2b27,0x2be01533,0x64480399,0xd1380024}},	//   _sae_, परवा, wjgi, _orą_, 
   {{0x442c73cf,0x6d592b28,0xd7f000f7,0x00000000}},	//   _pae_, nyta, زكە_, --, 
   {{0x29012b29,0x7cc000de,0xcec80208,0x15280022}},	//   muja_, _tērv, _xộc_, ыцуп_, 
   {{0x442d2b2a,0x23ac4614,0x2900049b,0x387c004a}},	//   _vae_, जेंद, luja_, ètre_, 
   {{0x442d2b2b,0x6d58652e,0x672801a8,0xab580205}},	//   _wae_, kyta, ægju, lcüs, 
   {{0x442d2b2c,0x29012b2d,0x83fc00dd,0x6280022f}},	//   _tae_, nuja_, _előa, rnno, 
   {{0x6d592b2e,0x442d2b2f,0xd1380064,0xd49800f3}},	//   dyta, _uae_, _drą_, _бру_, 
   {{0xaec12b30,0x91fc0109,0x29012b31,0xae0402e5}},	//   обыл, _ilān, huja_, _शाशन_, 
   {{0xee352b32,0x29012b33,0x7d0045d8,0x7e540c17}},	//   ань_, kuja_, tuls, ртиц, 
   {{0x6d592b34,0x41b400db,0x91fc6991,0x29003ed2}},	//   gyta, _ئمار, _klān, juja_, 
   {{0x3ef80276,0x799c017a,0xbe6400ec,0x00000000}},	//   _андэ_, _rypw, اهگي, --, 
   {{0x7e6c03a2,0x673801fa,0x21240007,0x6d58022f}},	//   _ïapo, _šujn, lwnh_, ayta, 
   {{0x4a740046,0x6d592b35,0x29012b36,0xca752581}},	//   быст, byta, fuja_, бусы, 
   {{0xcec80016,0x29012b37,0x4a752b38,0x6d592b39}},	//   _tộc_, guja_, сыят, cyta, 
   {{0xad180302,0xa8852b3a,0xdce0008e,0xeb9c942c}},	//   _יוצר, айса_, _uynı, rfør_, 
  
   {{0x7f48208d,0x29000153,0xeb9c0162,0xb4dc012d}},	// [1cc00] nxeq, auja_, sfør_, _दौड़_, 
   {{0x2900015c,0xe73402dd,0x35a40022,0xb8ec00fe}},	//   buja_, шеу_, аазг, _ৰি_, 
   {{0x2900970f,0x9f5c003a,0x6a681196,0x3eb800d7}},	//   cuja_, nguâ_, _büff, ísty_, 
   {{0x765c007c,0x00000000,0x00000000,0x00000000}},	//   skpy, --, --, --, 
   {{0xa8742ba5,0x6d583d44,0x00000000,0x00000000}},	//   _төрт_, zyta, --, --, 
   {{0xe280f819,0x21240369,0x66e00117,0x855400f2}},	//   олчи, fwnh_, _фора, _گیمر_, 
   {{0x6a6804cc,0x21240007,0x6d580076,0x7cc000de}},	//   _füff, gwnh_, xyta, _mērs, 
   {{0x91fc00cd,0x25a40790,0xe8dc0051,0x00000000}},	//   _glān, ünle_, _xuốg_, --, 
   {{0x53880124,0x6d58012d,0xa854011a,0x29000210}},	//   _сааҭ_, wyta, שיפה_, zuja_, 
   {{0x6d592b3b,0xd1380064,0xad64007b,0xab5803e0}},	//   tyta, _trą_, لاجه, zcüs, 
   {{0x4cb92b3c,0xdfcc011c,0x00000000,0x00000000}},	//   ллою_, _мъ_, --, --, 
   {{0x6d592b3d,0x29012b3e,0xdfcc007b,0x787801ef}},	//   ryta, vuja_, _قيم_, důvo, 
   {{0x6d592b3f,0xfbcc0451,0x00000000,0x00000000}},	//   syta, رڪي_, --, --, 
   {{0x6d592b40,0xde5402bf,0x29012b41,0xf20c033f}},	//   pyta, _ваші_, tuja_, _साफ़_, 
   {{0x6ce40046,0x3eb92b42,0xc8c801c8,0x00000000}},	//   _тіле, ïste_, اورن_, --, 
   {{0x7cc00029,0x48c4035b,0xaa7802d2,0x00000000}},	//   _vērt, _ҳәаа, gsýr, --, 
   {{0xab5803be,0x29012b43,0x00000000,0x00000000}},	// [1cc10] rcüs, suja_, --, --, 
   {{0x29012b44,0x91fc00e2,0x6a68002f,0x95d80108}},	//   puja_, _slān, _süff, идут_, 
   {{0x91fc0029,0x4ae401a9,0x00000000,0x00000000}},	//   _plān, _тўқа, --, --, 
   {{0x83fc01ed,0x94a80440,0xd3d842f4,0x00000000}},	//   _előn, атча_, لبها_, --, 
   {{0x5434036b,0x96f80276,0x53980212,0x7c20002e}},	//   ترلر, _кеят_, авця_, _ñore, 
   {{0x22a8013f,0x04c815f2,0xd1e002d3,0x3e6800d7}},	//   _kɔkɑ_, _موسي_, _ዓስቢ_, _kúte_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x955c0020,0x3e680194,0xc2c415f2,0xd40800db}},	//   ተኞችን_, _múte_, _هيري, _ەتەم_, 
   {{0x9e840023,0xb3980092,0x00000000,0x00000000}},	//   _ዝብለና_, ዋቸውን_, --, --, 
   {{0x09ac02f5,0x6e400116,0x00000000,0x00000000}},	//   _খলনা, كچىم, --, --, 
   {{0x41dc00dc,0x00000000,0x00000000,0x00000000}},	//   _न्यस, --, --, --, 
   {{0xdcc40064,0x7cc000ef,0x00000000,0x00000000}},	//   _žąsų_, _sērs, --, --, 
   {{0x7cc00171,0xec74011c,0x00000000,0x00000000}},	//   _pērs, спя_, --, --, 
   {{0x69b00073,0x786802d2,0x9e840240,0x00000000}},	//   _आणखी, _mýve, _ዝብሉና_, --, 
   {{0xa9641218,0x7cc0005f,0xee2c0451,0x00000000}},	//   бира_, _vērs, _سٽي_, --, 
   {{0x38640de2,0x00000000,0x00000000,0x00000000}},	//   óor_, --, --, --, 
   {{0xcec8001e,0x7b640014,0x786801a8,0x7c252b45}},	// [1cc20] _lộn_, _داغٕ, _nýve, mekr, 
   {{0xa6d808ce,0x35b41422,0x00000000,0x00000000}},	//   _orðf, бщес, --, --, 
   {{0xd9104eaf,0xcec80051,0x2a54011a,0x00000000}},	//   _تیز_, _nộn_, _הבין_, --, 
   {{0x15b800ee,0x00000000,0x00000000,0x00000000}},	//   гыҗы_, --, --, --, 
   {{0x78b52b46,0x8a800051,0x00000000,0x00000000}},	//   mmyv, _ôđán, --, --, 
   {{0xe1ec0c50,0x74152b47,0xe2940006,0xcec8004d}},	//   ىسى_, _گورا, бач_, _bộn_, 
   {{0xe1ec4cec,0x7c252b45,0x4e980014,0x00000000}},	//   رسو_, kekr, یٖبس_, --, 
   {{0x74152b48,0x7c252b49,0xc540001f,0xa2b000e5}},	//   _دورا, jekr, _የሚባሉ, _ہینڈ, 
   {{0x33641ed2,0xc3040a2c,0xd3700137,0x00000000}},	//   _уваг, _وبكو, _تۇش_, --, 
   {{0x2bac2b3d,0x67fc01e1,0x551c02e5,0x91fc00b8}},	//   _घरबा, _kàjà, _नहाए_, _klām, 
   {{0x69c0000f,0x61412b4a,0x6ce00073,0x31a40066}},	//   _ûnei, _нефа, कींग_, _اماف, 
   {{0x99980109,0x6a680790,0x673800de,0x00000000}},	//   ndrŕ_, _müfe, _šujm, --, 
   {{0xaf340fa2,0xcdc40075,0x6a6803e0,0x00000000}},	//   _درات, _мәнп, _lüfe, --, 
   {{0x2eb4109a,0x3e680419,0xca4802c9,0x00000000}},	//   _усес, _púte_, جلسه_, --, 
   {{0x7c252b4b,0xcec8004d,0x6d540205,0x57a400c7}},	//   bekr, _xộn_, çaağ, ҧшуа, 
   {{0xc7d80ee1,0xdcf4036b,0x7c252b4c,0x00000000}},	//   рмах_, _اروش_, cekr, --, 
   {{0x95440020,0xe9700e56,0x00000000,0x00000000}},	// [1cc30] _የሚከተ, زۇڭد, --, --, 
   {{0x67fc0248,0xe13039ae,0x9f5d2b4d,0xa3d80490}},	//   _bàjà, ščić_, nguá_, ढुन_, 
   {{0x2fc40086,0x9f5c0113,0x5a3401c0,0x65a8009d}},	//   _ogog_, iguá_, _энэт, утаг_, 
   {{0xcec801fb,0xd5b8bdb2,0x0708678e,0x00000000}},	//   _rộn_, ссу_, _پيسي_, --, 
   {{0x59d00b67,0xd6d8117e,0x00000000,0x00000000}},	//   तुकर, _гтс_, --, --, 
   {{0x672c1e31,0x2fc40076,0x7c252b4e,0xa6d8032e}},	//   _iscj, _agog_, zekr, _arðg, 
   {{0xd378c7e0,0x91fc00e2,0x09c40154,0xaa780022}},	//   ичә_, _klāj, ্রপা, apýg, 
   {{0x26c12b4f,0x00000000,0x00000000,0x00000000}},	//   _hijo_, --, --, --, 
   {{0x7c252b50,0x00000000,0x00000000,0x00000000}},	//   vekr, --, --, --, 
   {{0x26c80796,0x249c003e,0x26c00241,0x8e7428f6}},	//   _muco_, _hkum_, _jijo_, зуюч, 
   {{0x26c12b51,0x26c80393,0x7c24a491,0x7050527d}},	//   _mijo_, _luco_, tekr, سنیا, 
   {{0x26c00184,0x7534010f,0x7cc000ef,0xc0b80116}},	//   _lijo_, קארד_, _cērp, ﻧﻨﻪﺗ, 
   {{0xef0c152d,0xeb952b52,0x09c400bd,0x26c80077}},	//   _юм_, жия_, ্রনা, _nuco_, 
   {{0xfce464e1,0x26c00165,0x4a741d37,0x4a000022}},	//   _доко, _nijo_, пыст, нҟьа, 
   {{0x249d2b53,0x7c2400e5,0x00000000,0x00000000}},	//   _okum_, pekr, --, --, 
   {{0x26c92b54,0x26c001f4,0x2ef0008e,0x00000000}},	//   _buco_, _aijo_, _эзәр, --, 
   {{0xe734035b,0x26c809c2,0xcc0800db,0x26c12b55}},	// [1cc40] оет_, _cuco_, _ازىن_, _bijo_, 
   {{0x249d2b56,0xc540001f,0x26c92b57,0x95e45325}},	//   _akum_, _የሚችሉ, _duco_, गरेट_, 
   {{0x26c12b58,0x78b4ad72,0x3cdc0490,0x3ea4062c}},	//   _dijo_, pmyv, कीचे_, illt_, 
   {{0x26c92b59,0x3ea4062c,0x1cc00327,0x25a4000d}},	//   _fuco_, hllt_, གམི_, ünla_, 
   {{0x26c12b5a,0xe73407d6,0x249c0010,0x69e40022}},	//   _fijo_, _дея_, _dkum_, _êreí, 
   {{0x3ea40054,0x225428fa,0x36680953,0x6a6805d1}},	//   jllt_, يلند_, _таго_, _tüfe, 
   {{0xe5a02afd,0x21640063,0xb424007b,0x779002f2}},	//   _жири, жији_, _وعرو, _عیڕا, 
   {{0x3ea4049f,0x656004ce,0x26c001fa,0x2ee4007f}},	//   ellt_, ønhe, _zijo_, _pwof_, 
   {{0x69c0002d,0x26c000e4,0x2e480395,0x64a0030d}},	//   _ûnev, _yijo_, аяно_, _цата, 
   {{0x7bd469a6,0x200c0175,0x00000000,0x00000000}},	//   _afyu, _ecgi_, --, --, 
   {{0x200c0354,0x3eb826b7,0x7af52b5b,0x260828d4}},	//   _fcgi_, ïsta_, _avyt, ालती_, 
   {{0xe07416cb,0x2bac0490,0x3eb80153,0xa03000d1}},	//   _وڌيڪ_, _घरदा, įsta_, _يىلت, 
   {{0xdd8d2b5c,0xe87802d3,0x7cc00171,0x00000000}},	//   _یوه_, _ተፈሊጡ_, _vērp, --, 
   {{0x09c403d4,0x7878013a,0x00000000,0x00000000}},	//   ্ৰনা, bůvk, --, --, 
   {{0x58d4ac40,0x26c92b5d,0x7af4039a,0x26c00109}},	//   дост, _suco_, _evyt, _rijo_, 
   {{0xb3400209,0x83fc01d3,0xceb86dd3,0x00000000}},	//   şçyl, _előj, lmę_, --, 
   {{0xddc00115,0x7c20035b,0xd9ec000d,0x09c400eb}},	// [1cc50] _monŝ, _ñora, _जड़वत_, ্রবা, 
   {{0xa564198a,0x26c80301,0x3e692b5e,0xcec8004d}},	//   يدان, _vuco_, _kúta_, _nộm_, 
   {{0x290400e4,0x00000000,0x00000000,0x00000000}},	//   _êna_, --, --, --, 
   {{0x672c0221,0x7af40588,0x68f4035a,0x3e6802d2}},	//   _tscj, _yvyt, _ivxd, _múta_, 
   {{0x3ea52b5f,0x130802bf,0xceb80024,0x0a340023}},	//   yllt_, жній_, kmę_, _ብምስራ, 
   {{0x3ea40227,0x200c010a,0x3e6800e4,0xceb8033f}},	//   xllt_, _scgi_, _oúta_, jmę_, 
   {{0xddc0010f,0x00000000,0x00000000,0x00000000}},	//   _bonŝ, --, --, --, 
   {{0x70241efe,0x249d2b60,0x11280212,0x786802f0}},	//   _རྒྱུ_, _ukum_, юючи_, _kýva, 
   {{0x7e7c007f,0x00000000,0x00000000,0x00000000}},	//   èspo, --, --, --, 
   {{0x3e687978,0x78692b61,0x6b600055,0x7d080063}},	//   _búta_, _mýva, _mįgā, бног_, 
   {{0xcb08025f,0x7af40064,0xed4c0133,0x00000000}},	//   _תל_, _svyt, ۆپی_, --, 
   {{0x78780118,0x00000000,0x00000000,0x00000000}},	//   růvk, --, --, --, 
   {{0x70512b62,0x786806ea,0x29010c91,0x4f9401c6}},	//   _سنوا, _nýva, erja_, _оршу, 
   {{0xcd292b63,0x3e6803b2,0xa6d80d12,0xcff00154}},	//   حسین_, _fúta_, _orðb, _টায়_, 
   {{0x6da12b64,0x6e142756,0xe73c00c7,0xa9651a69}},	//   _пиша, _رييس_, _arõ_, пира_, 
   {{0x786803c6,0x9c140521,0x91fc00e2,0x77c8009d}},	//   _býva, _sọft, _plāk, слаг_, 
   {{0x29012b65,0x83fc01ed,0xa6d8032e,0x9b780092}},	// [1cc60] arja_, _elők, _arðb, _አንፌቃ_, 
   {{0xbb8401e2,0x4ba418c7,0x00000000,0x00000000}},	//   _ولګي, _юлың, --, --, 
   {{0x7c352b66,0xe73c00c7,0xf86800f1,0x00000000}},	//   _kayr, _erõ_, _همدي_, --, 
   {{0x7c352b67,0x20f40356,0x21e002dd,0xceb84f7e}},	//   _jayr, dăi_, _ﺍﭘﺎﺭ, zmę_, 
   {{0x09c403f4,0x7c352b68,0x00000000,0x00000000}},	//   ্রণা, _mayr, --, --, 
   {{0x7c341529,0xddc001e4,0x64a0013e,0xe29400f0}},	//   _layr, _sonŝ, _ҷаса, пач_, 
   {{0x6a680793,0x7c340076,0x20f4054e,0x70780023}},	//   _jüfa, _oayr, găi_, _ክህልዉ_, 
   {{0x64a00323,0x7c342e95,0xf8bc0fc8,0x67380841}},	//   _заса, _nayr, ्दिय, _šuji, 
   {{0xa1c00166,0xceb8bfb6,0x00000000,0x00000000}},	//   мбәд, tmę_, --, --, 
   {{0x29001f60,0xb63c037e,0x2a68001f,0x22f40375}},	//   yrja_, _ａａ_, _ታሪኮች_, _מזמן_, 
   {{0xc21800c6,0x4c952b69,0xceb80034,0x9e012b6a}},	//   _єєѕ_, динс, rmę_, хчыл, 
   {{0x7c342215,0xceb80024,0xe0d0010f,0x00000000}},	//   _cayr, smę_, _װײס_, --, 
   {{0x7c352b6b,0x09b42d6b,0x6e440006,0x2900025c}},	//   _dayr, ंध्य, _недз, wrja_, 
   {{0x7c34a77e,0xd1d4010c,0x29001ed8,0x83fc00e5}},	//   _eayr, _ያቆብ_, trja_, _előh, 
   {{0xdd8d2b6c,0x7c345d3e,0x5e5069a6,0x2bac02fe}},	//   _чш_, _fayr, _سئور, _घरवा, 
   {{0x290002d3,0x7c34509e,0x482421ef,0x42680092}},	//   rrja_, _gayr, بىرق, ሳሌነት_, 
   {{0xddc00139,0x09c400eb,0x00000000,0x00000000}},	// [1cc70] _konş, ্রধা, --, --, 
   {{0x786802fb,0x2900025c,0x31b000cc,0x00000000}},	//   _výva, prja_, _চলনশ, --, 
   {{0xddc0054e,0x7c352b6d,0xf9a40248,0x00000000}},	//   _monş, _yayr, _èèpo_, --, 
   {{0x7c352b6e,0x09c4015b,0xc4b87aec,0x395c000d}},	//   _xayr, ্রদা, ेदेख, ätse_, 
   {{0xaad0206b,0x427401c6,0xf5e400db,0x00000000}},	//   _धूमक, мгдс, ستەۋ, --, 
   {{0x93942d74,0x20f4054e,0x09c403d4,0x00000000}},	//   رجنا, tăi_, ্ৰণা, --, 
   {{0x91c4010b,0xd3f40150,0x00000000,0x00000000}},	//   нашҗ, _бiрт, --, --, 
   {{0x912800d1,0x260803ba,0x5184009a,0x00000000}},	//   سسىق_, ालवी_, عشوق, --, 
   {{0x64580381,0x699c012c,0x7c340009,0x9fc401ec}},	//   _ioui, _खुसी, _rayr, огқа_, 
   {{0x7c352b6f,0x64592b70,0xddc00276,0x00000000}},	//   _sayr, _houi, _conş, --, 
   {{0x7c352b71,0x6458796b,0x62812b72,0x2164036b}},	//   _payr, _koui, mino, _этаг, 
   {{0x64592b73,0x7c3411f2,0xff503ee6,0xe8dc0051}},	//   _joui, _qayr, _لخت_, _chọe_, 
   {{0x7c352b74,0x64592b75,0xa7f8030a,0x6280e481}},	//   _vayr, _moui, _koñf, oino, 
   {{0x62812b76,0x7c341181,0x64592b77,0xddc00432}},	//   nino, _wayr, _loui, _gonş, 
   {{0x7c340731,0xa9a12b78,0xb8652b79,0xa7f8030a}},	//   _tayr, вирд, وارو, _moñf, 
   {{0x62812b7a,0x64592b7b,0x083401c0,0xf74401f0}},	//   hino, _noui, нхуя, мебо, 
   {{0x62812b7c,0xabf800d9,0x00000000,0x00000000}},	// [1cc80] kino, _והפר, --, --, 
   {{0xe9d4084c,0x9ba40150,0x00000000,0x00000000}},	//   _окь_, _يەگى, --, --, 
   {{0x64592b7d,0x91fc00de,0x935415b4,0x00000000}},	//   _boui, _klāv, کراچ, --, 
   {{0x6458004a,0x65600158,0xb3840ce8,0xed54010f}},	//   _coui, ønha, млел, ובער_, 
   {{0x64591803,0x2d800198,0xc4c40fba,0x09c403d4}},	//   _doui, ̄ke_, رتمو, ্ৰদা, 
   {{0x645801ab,0x27b029db,0xf50400f7,0xa3bc033f}},	//   _eoui, _рәсс, _озго, ुख़_, 
   {{0x65c12b7e,0x64592b7f,0x05580276,0xceb80032}},	//   _абра, _foui, _ештъ_, үәл_, 
   {{0xcec801dc,0x64592b80,0x63740521,0xb7ec00e1}},	//   _hội_, _goui, ụnan, जरिम_, 
   {{0x62802045,0xe80d2b81,0x00000000,0x00000000}},	//   bino, िलता_, --, --, 
   {{0x64582165,0x91fc0618,0xddc000ac,0xe29402dd}},	//   _zoui, _alāv, _qonş, _жау_, 
   {{0x645863b3,0x91fc0171,0xcec80051,0x00000000}},	//   _youi, _blāv, _mội_, --, 
   {{0xcec801fb,0x6f6473c3,0x2008004e,0x8c1400cc}},	//   _lội_, _овез, òcit_, _়োজন_, 
   {{0xa6d809cc,0x5f704caa,0xddc00139,0x00000000}},	//   _orða, _لاور, _tonş, --, 
   {{0x99580316,0x28a40034,0x09c4015b,0xa7f80166}},	//   láře_, _कीजि, ্রসা, _koñg, 
   {{0xcec801dc,0x47e80003,0xd874249f,0xdb04008e}},	//   _nội_, _འབྱམ, چاقب, _aziä, 
   {{0x9958012c,0xa6d80162,0x38700363,0x6e383c02}},	//   náře_, _arða, ghyr_, ldtb, 
   {{0xd3640058,0xb8d452f2,0x26cc019f,0x62800921}},	// [1cc90] _ئۇ_, _ची_, êgo_, yino, 
   {{0x62812b82,0xcec801fb,0x64592b83,0xfc440308}},	//   xino, _bội_, _soui, šíte_, 
   {{0x64592b84,0xa7f8030a,0xcec8004d,0x7dd001d3}},	//   _poui, _roñf, _cội_, _hűsé, 
   {{0x62812b85,0xcec801fb,0x43952b86,0x3e740ca8}},	//   wino, _dội_, наес, _kùtù_, 
   {{0x62812b87,0xe8dc07ae,0x64592b88,0xb7d802e4}},	//   tino, _khỏe_, _voui, _מקרי, 
   {{0x25d805d7,0x00000000,0x00000000,0x00000000}},	//   खुशी_, --, --, --, 
   {{0x64592b89,0xcec801fb,0xa7f80165,0x00cc00d1}},	//   _toui, _gội_, _voñf, _ﻗﺎﺗﺘ, 
   {{0x4438000f,0x25d8ea74,0x79c40131,0x6280a61d}},	//   _ûs_, खुरी_, ﯩﺮﯨﻤ, sino, 
   {{0xc1d001ee,0x00000000,0x00000000,0x00000000}},	//   _йөйә, --, --, --, 
   {{0x62800194,0x53340063,0x21640cb6,0x7d080114}},	//   qino, _јефт, _отег, пног_, 
   {{0x673c0175,0x91fc002b,0x99580118,0xbb340092}},	//   hvqj, _plāv, báře_, _ይላቸዋ, 
   {{0x3e6801a2,0x12c400db,0x83fc01d3,0xab580205}},	//   _túto_, _كتەپ, _előv, lcüy, 
   {{0xa7f80139,0x09e000eb,0x00000000,0x00000000}},	//   _moñd, _বয়া, --, --, 
   {{0x427804ac,0x201c0064,0x00000000,0x00000000}},	//   לאָג, lfui_, --, --, 
   {{0x09c400fe,0x3870996f,0x1ddc5b29,0x00000000}},	//   ্ৰসা, thyr_, पुणत, --, 
   {{0x786803c6,0xdb840117,0x00000000,0x00000000}},	//   _vývo, _аҳми, --, --, 
   {{0x69c0056a,0x91fc005f,0x6a6803e0,0x6e2400e5}},	// [1cca0] _únen, _klāt, _küfl, őkbe, 
   {{0xba752b8a,0x38700363,0xdfcc0055,0x00000000}},	//   _ساخت, shyr_, _śālī_, --, 
   {{0x3870017a,0x3a38031c,0x6a6803e3,0x580401af}},	//   phyr_, _iapp_, _müfl, _ионғ, 
   {{0x3a380076,0xcec8001e,0x00000000,0x00000000}},	//   _happ_, _vội_, --, --, 
   {{0x3a3804c4,0xa7f80724,0x7cc0005f,0x1cdc025c}},	//   _kapp_, _soñg, _bērz, _སྕལ_, 
   {{0x3a392b8b,0xb6a40323,0xcec80016,0xa6d808ce}},	//   _japp_, _чигл, _tội_, _urða, 
   {{0x3a383bb8,0x995800bc,0xb0c4234c,0x00000000}},	//   _mapp_, táře_, нщик, --, 
   {{0x3a392b8c,0x85040014,0x91fc00b8,0x9f4c036e}},	//   _lapp_, _جوٲن, _alāt, _gegë_, 
   {{0x91fc01ab,0x00000000,0x00000000,0x00000000}},	//   _blāt, --, --, --, 
   {{0x3a38a8ce,0xa6d801a8,0x99580118,0x1f7001f4}},	//   _napp_, _orðn, sáře_, улья, 
   {{0xec141cd1,0xddc00419,0xec30009f,0x00000000}},	//   ненә_, _plnš, هودگ, --, 
   {{0x3a380194,0x00000000,0x00000000,0x00000000}},	//   _aapp_, --, --, --, 
   {{0x200800d0,0x5b24855f,0xdee0009b,0x00000000}},	//   ócie_, льра, _бочи, --, 
   {{0x3a38003a,0xa7f800c7,0x205000c7,0xaa780022}},	//   _capp_, _moñe, _атәр, apýn, 
   {{0x199475f3,0x3a392b8d,0x6ca49c9d,0x59a4012d}},	//   гаря, _dapp_, _приж, _खुदर, 
   {{0x91fc005f,0xd838084c,0x96080154,0x395c000d}},	//   _klās, нэу_, র্মম_, ätsa_, 
   {{0xa7f8035b,0x179857aa,0x26040733,0xad24009f}},	// [1ccb0] _noñe, евты_, ечег, _آرڪو, 
   {{0x9f4c01bf,0x65740175,0xa7f820b2,0x00000000}},	//   _udgå_, tzxh, _soñd, --, 
   {{0xe4c80956,0x290476cf,0x6d5c0241,0x00000000}},	//   سبان_, _ína_, _àpad, --, 
   {{0x88a002f2,0xa85000fb,0x00000000,0x00000000}},	//   _ئیرۆ, _семә, --, --, 
   {{0xa7f836ed,0xe7841086,0x3a3830b6,0x994800e5}},	//   _coñe, _чуно, _yapp_, _قلیل_, 
   {{0xa1f00131,0x26cc01e4,0x45d400d8,0x00000000}},	//   اۋات, ŭgos_, _јовс, --, 
   {{0x40941d11,0x56952b8e,0xc0940063,0xd694009b}},	//   крит, _сарт, кшић, _сирћ, 
   {{0xdb081432,0x92e000cc,0x00000000,0x00000000}},	//   _ölçm, _থিৰ_, --, --, 
   {{0xa3004ec9,0xa7f8005a,0x201c0393,0xef14010b}},	//   _сүле, _goñe, rfui_, вмы_, 
   {{0x83fc066d,0x6e400131,0xcf24007b,0x418401af}},	//   _előt, لچىم, اريي, _итеғ, 
   {{0xed1401d3,0x00000000,0x00000000,0x00000000}},	//   نہوں_, --, --, --, 
   {{0x3a380bfa,0x20000024,0xd17401af,0x00000000}},	//   _sapp_, ėjis_, _сыђы, --, 
   {{0x3a381545,0xee2cdf8d,0x91fc00de,0x2c100118}},	//   _papp_, _кн_, _glās, _थारू_, 
   {{0x60c80076,0x00000000,0x00000000,0x00000000}},	//   _higm, --, --, --, 
   {{0x3a392b8f,0x91fc00ef,0xe5280248,0x00000000}},	//   _vapp_, _klār, _òkèè, --, 
   {{0x60c80ba1,0x3a38007f,0xa8000395,0x00000000}},	//   _jigm, _wapp_, изсл, --, 
   {{0x3a38007c,0x443c03cb,0xd02400eb,0xa760011c}},	// [1ccc0] _tapp_, ddw_, _মোড়_, актд, 
   {{0x60c8017a,0xa7f800c7,0x34c8a7a2,0x00000000}},	//   _ligm, _roñe, िद्द, --, 
   {{0xa7f8005a,0x443c0175,0x65c00139,0x00000000}},	//   _soñe, fdw_, абфа, --, 
   {{0xa7f80f71,0x60c8008e,0xcec8004d,0xa3bc00dc}},	//   _poñe, _nigm, _hột_, ुखं_, 
   {{0xa2d00150,0x00000000,0x00000000,0x00000000}},	//   لينت, --, --, --, 
   {{0xd04c00ac,0x00000000,0x00000000,0x00000000}},	//   əhət, --, --, --, 
   {{0xcec8431d,0x60c92b90,0xeb9c1088,0x764c01e6}},	//   _một_, _bigm, ngør_, _inby, 
   {{0x65612b91,0xcec8001e,0xa7f8035b,0xa0851908}},	//   änhe, _lột_, _toñe, ксыз_, 
   {{0x60c88b14,0x83fc00dd,0x72c52b92,0x387c026c}},	//   _digm, _elős, _абаз, étry_, 
   {{0xa7f8030a,0xa11059e1,0xa2a036c7,0x00000000}},	//   _koñc, _چولت, गवण्, --, 
   {{0x60c8019b,0x00000000,0x00000000,0x00000000}},	//   _figm, --, --, --, 
   {{0x3e6801e7,0xdca401d5,0x64440064,0x6aa8043e}},	//   _lúth_, ишяп, _ėjik, छत्र, 
   {{0x9b589385,0xcec8001e,0x764c0af9,0xed3001ed}},	//   вият_, _bột_, _onby, _چوتھ, 
   {{0x2be0006d,0xcec8001e,0x60c92b93,0x00000000}},	//   _क्रं_, _cột_, _zigm, --, 
   {{0xeb9c037e,0xcec8004d,0x60c92b94,0xa80000e4}},	//   ggør_, _dột_, _ümmü, áñop, 
   {{0x764d2b95,0x60c80014,0x00000000,0x00000000}},	//   _anby, _xigm, --, --, 
   {{0x9c1402e3,0x9a8801d9,0x00000000,0x00000000}},	// [1ccd0] _kọnt, رنہٕ_, --, --, 
   {{0xb7c43daf,0xe4e400d6,0xfd5400cd,0xcec80051}},	//   урсқ, відн, _asaṅ, _gột_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x764cd843,0xd5b800d8,0xc3c4010b,0xd7e40212}},	//   _enby, тсу_, гөзл, _віро, 
   {{0x60c8365a,0xd76404d3,0xd6d8233a,0x00000000}},	//   _rigm, _پۆلی, _атс_, --, 
   {{0x443c0393,0x00000000,0x00000000,0x00000000}},	//   sdw_, --, --, --, 
   {{0x3ea401b9,0x7fd41cb8,0x814400f2,0x00000000}},	//   ғинг, ліпі, انبن, --, 
   {{0x83fc00dd,0x54340214,0x7f580120,0x33700131}},	//   _előr, _پرفر, ејот_, ргәр, 
   {{0x53342ba5,0xd1380024,0xa6d8032e,0xa2a017c6}},	//   _кетт, _esą_, _orðm, गवद्, 
   {{0xb06002f6,0xbea40120,0x00000000,0x00000000}},	//   _äänt, ѓанк, --, --, 
   {{0x60c92b96,0xa3d40406,0xcee801d9,0x00000000}},	//   _tigm, _सला_, _یرون_, --, 
   {{0x67001ab2,0x3b092b97,0xcec80051,0x00000000}},	//   _लिंक_, немо_, _sột_, --, 
   {{0x9c14f3a4,0xed540032,0xaa7800e4,0x0a340023}},	//   _fọnt, _ҡош_, apým, _ብምምራ, 
   {{0x8d842eac,0x90280022,0x00000000,0x00000000}},	//   اشین, _зцәа_, --, --, 
   {{0x3ea52b98,0x6e9040ec,0x3f880327,0x3e680419}},	//   molt_, _دلوا, _wċuħ_, _núti_, 
   {{0x1ddc0490,0x00000000,0x00000000,0x00000000}},	//   पुरत, --, --, --, 
   {{0xcec8004d,0x3ea400db,0x3f880135,0x76240209}},	// [1cce0] _tột_, oolt_, _uċuħ_, лмаз, 
   {{0xe6140372,0xeb9c005c,0xcec80051,0xf1c401a8}},	//   лду_, pgør_, _uột_, _þágu_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x91fc0b23,0x2da00724,0x33f415eb,0x04f800ec}},	//   _alāp, _üseş_, اساس, ئونڊ_, 
   {{0x3ea52b99,0x3e6802ea,0xb2852b9a,0xc91402f5}},	//   kolt_, _eúti_, лыкк, াবৃত_, 
   {{0x35a41def,0xe3a400f2,0x00000000,0x00000000}},	//   _багг, دشمی, --, --, 
   {{0x712407d6,0x38600219,0xfd540055,0xddcc0166}},	//   ارتل, _kokr_, _tsaṅ, _şeşn, 
   {{0x91fc0055,0x00000000,0x00000000,0x00000000}},	//   _elāp, --, --, --, 
   {{0x03a40014,0x7374010a,0xa85400d9,0x00000000}},	//   _پۯوو_, _сывх, ריפה_, --, 
   {{0x6ce4005e,0xa7f92b9b,0x3ea4fe6d,0x00000000}},	//   ліме, _moña, golt_, --, 
   {{0x2bc402ab,0xdf5401b9,0xbed8009d,0xe80400bc}},	//   रेना, نشیش_, ндөх_, षणमा_, 
   {{0x9c1401e1,0xf8d00037,0x00000000,0x00000000}},	//   _wọnt, _दूइय, --, --, 
   {{0xa7f800c7,0x3ea401ed,0x318c06be,0x00000000}},	//   _noña, bolt_, _həz_, --, 
   {{0x3ea52b9c,0x9a852b9d,0x00000000,0x00000000}},	//   colt_, бусл, --, --, 
   {{0x9f4c05d5,0x00000000,0x00000000,0x00000000}},	//   _legì_, --, --, --, 
   {{0xa8a48715,0x318c06be,0x6a680205,0x3e6800d7}},	//   ургк, _məz_, _müfi, _rúti_, 
   {{0x9c1401f2,0xa7f83eba,0x80c400dc,0x58d402dd}},	// [1ccf0] _mọlt, _coña, ागते, _қоят, 
   {{0xa7f91025,0x3e680419,0x47340150,0x00000000}},	//   _doña, _púti_, лнұс, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3ea401d3,0x91fc00de,0x00000000,0x00000000}},	//   zolt_, _slāp, --, --, 
   {{0x28d8012d,0x00000000,0x00000000,0x00000000}},	//   _मंडि, --, --, --, 
   {{0x01652b9e,0x2bc42bf1,0xeaf01d20,0x00000000}},	//   икло, रेया, _अबैत_, --, 
   {{0x3ea52b9f,0xf4000276,0x09c40154,0x00000000}},	//   volt_, faţă_, ্রকা, --, 
   {{0x6a6801b8,0x3ea40036,0xd14800f2,0x00000000}},	//   _düfi, wolt_, اشون_, --, 
   {{0x2bc40574,0x3ea488c6,0x6d4c376e,0xa6e000eb}},	//   रेमा, tolt_, åban, _পিঁয়, 
   {{0xa2b00490,0x6d4404fe,0x78680f91,0xef14084c}},	//   ेगळ्, ākan, _vývi, шмь_, 
   {{0x3ea400dd,0xaa780022,0x318c06be,0xc4800241}},	//   rolt_, apýk, _gəz_, _àìsù, 
   {{0x3ea52ba0,0xfbc400f5,0x00000000,0x00000000}},	//   solt_, ибно, --, --, 
   {{0x386002fa,0x7aa4007b,0x00000000,0x00000000}},	//   _rokr_, لإسل, --, --, 
   {{0xa7f800c7,0x00000000,0x00000000,0x00000000}},	//   _roña, --, --, --, 
   {{0xa7f92ba1,0xf8a8082a,0x5a040116,0x2bc407f7}},	//   _soña, ندره_, _қүвв, रेबा, 
   {{0xcec80016,0xa7f92ba2,0x455402d3,0x0dc80276}},	//   _hộp_, _poña, ዘይነበ, _сучи_, 
   {{0xa7f80113,0x77c801c6,0x41d407b7,0x00000000}},	// [1cd00] _qoña, тлаг_, दशास, --, 
   {{0x9f4c04cc,0xc7952ba3,0x00000000,0x00000000}},	//   _regì_, ёрты, --, --, 
   {{0x1da830fd,0x755424cd,0x00000000,0x00000000}},	//   _घुमत, шњац, --, --, 
   {{0xe1ec04a2,0xf3e40ae5,0xa7f800e4,0xc4c4007b}},	//   ۈسى_, рқақ_, _toña, متنو, 
   {{0xf4000311,0x57040124,0x93480124,0x00000000}},	//   vaţă_, _ыҟаз, ыҟаз_, --, 
   {{0xe1ed2ba4,0xcec8001e,0x00000000,0x00000000}},	//   وسى_, _nộp_, --, --, 
   {{0xd1300491,0x984800fd,0xa7f8008e,0x318c06be}},	//   سمة_, lğı_, _moñn, _qəz_, 
   {{0x74144c9a,0x7c2401f5,0xd010007b,0x64a12ba5}},	//   _خورا, jfkr, ألة_, _даса, 
   {{0x984800fd,0xcec80051,0x00000000,0x00000000}},	//   nğı_, _bộp_, --, --, 
   {{0x716800c7,0xcec80208,0x00000000,0x00000000}},	//   _иазг_, _cộp_, --, --, 
   {{0x6140013e,0xf8c4012c,0x7c24002f,0x00000000}},	//   _мефа, लगाय, ffkr, --, 
   {{0x52740075,0x4c940108,0xec68022e,0xec1404b4}},	//   _туғу, симс, трок_, шемә_, 
   {{0x5b140108,0x00000000,0x00000000,0x00000000}},	//   омят, --, --, --, 
   {{0x28d80d5f,0x6f0004ce,0xcec8004d,0x00000000}},	//   _मंदि, _ivoc, _gộp_, --, 
   {{0xadb40131,0x00000000,0x00000000,0x00000000}},	//   _خۇدا_, --, --, --, 
   {{0x6f000581,0xdd180118,0x00000000,0x00000000}},	//   _kvoc, _náře, --, --, 
   {{0x799c03ac,0x00000000,0x00000000,0x00000000}},	// [1cd10] _expw, --, --, --, 
   {{0xe6112ba6,0x88b8016b,0x7af001d3,0x2bc400dc}},	//   تشر_, _mpɛɛ, űjté, रेणा, 
   {{0xd7f02544,0x6d58031c,0x00000000,0x00000000}},	//   سكە_, nxta, --, --, 
   {{0x6f000232,0x442809a5,0x88580108,0x00000000}},	//   _ovoc, ýa_, _симс_, --, 
   {{0xa6d81c38,0x434402e8,0x00000000,0x00000000}},	//   _orði, селв, --, --, 
   {{0x6d486ad0,0x6d580227,0xe80c00af,0x00000000}},	//   _orfa, kxta, िलका_, --, 
   {{0x6f00a3d6,0x2bc40e85,0x55580276,0x200800d8}},	//   _avoc, रेता, _каря_, ócio_, 
   {{0xdb040209,0xa7f92ba7,0xa6d80413,0xd5f40208}},	//   _aziý, _moño, _arði, _đản, 
   {{0x6d492ba8,0x2c7800e8,0x629000c7,0x6d58002e}},	//   _arfa, _mëdd_, _дгаӡ, exta, 
   {{0x63b8556c,0x6f0001a2,0xdd1800bc,0x00000000}},	//   _izun, _dvoc, _záře, --, 
   {{0x41b4bb11,0x6f012ba9,0x3cc80323,0xa7f800e4}},	//   _امار, _evoc, ллоо_, _noño, 
   {{0x672c068f,0xfc3000c6,0x6d4801f7,0x63b80175}},	//   _opcj, أحد_, _drfa, _kzun, 
   {{0xe7a44486,0x6e280175,0xe7ac0116,0x00000000}},	//   _कुलप, _fbfb, ﺳﯩﺮﻟ, --, 
   {{0x63b91353,0x00000000,0x00000000,0x00000000}},	//   _mzun, --, --, --, 
   {{0x6a684a4a,0xa7f809d7,0x6d480076,0x6f000cf4}},	//   _nüfu, _coño, _grfa, _zvoc, 
   {{0x63b92baa,0xb864007b,0xd04803b9,0xac901d39}},	//   _ozun, حاسو, _budə, _најш, 
   {{0x7bd4951a,0x44f401a2,0x63b92bab,0x2c78002e}},	// [1cd20] _igyu, eť_, _nzun, _dëdd_, 
   {{0x7d000589,0xabbc1df2,0x6d48015d,0x3e680241}},	//   osls, _ﺭﻭﻣﺎ, _yrfa, _tútu_, 
   {{0x63b92bac,0xb40805f5,0x7af403cb,0xdd1801ef}},	//   _azun, гэлж_, _hwyt, _páře, 
   {{0x2c780de2,0x7af49eaa,0x2508249f,0x00000000}},	//   _gëdd_, _kwyt, ارلی_, --, 
   {{0x44f40030,0x9f4c004e,0xa7f8008e,0x075801af}},	//   ať_, _negà_, _moñl, _кјрњ_, 
   {{0x63b807a9,0x66e12bad,0xa7f8030a,0x7af40042}},	//   _dzun, _хора, _loñl, _mwyt, 
   {{0x2ee52bae,0x63b92baf,0x44f400d0,0x7af403cb}},	//   _stof_, _ezun, cť_, _lwyt, 
   {{0x7bd402ea,0x28d80316,0x6a680e78,0x68e0003e}},	//   _ngyu, _मंसि, _hüft, _énde, 
   {{0x6d480010,0xa854011a,0x6a6803b9,0x9f500006}},	//   _srfa, מיקה_, _küft, звыч, 
   {{0x6d580227,0x9f4c00db,0x1ed400c6,0xde74008e}},	//   txta, _degà_, حبيب_, йбыч_, 
   {{0x321c01c8,0x63b80083,0x6a68eab4,0x92e000fe}},	//   _icty_, _zzun, _müft, _থিয়_, 
   {{0x6a6803fa,0x7af400a9,0xfdc80220,0x9be401ce}},	//   _lüft, _bwyt, штық_, зірк, 
   {{0xa7f81709,0x7af40204,0x2c780de2,0x44f400d0}},	//   _soño, _cwyt, _rëdd_, zť_, 
   {{0x6d580bc9,0x3e68002d,0x7af4015d,0xa6d80162}},	//   pxta, _dúts_, _dwyt, _urði, 
   {{0x6d492bb0,0x6d580227,0xa7f800e8,0xbe840a8e}},	//   _urfa, qxta, _foñl, _بجنو, 
   {{0x7af40368,0xd7f80137,0xa2bc00e1,0x32f4012d}},	//   _fwyt, йуу_, _लीन्, kły_, 
   {{0x58846ec1,0x7af4015d,0x5bc402dd,0x321c012d}},	// [1cd30] чыра, _gwyt, _ىقىل, _octy_, 
   {{0xa7f80022,0x2ca800d8,0x32f4033f,0x668007d6}},	//   _toño, locd_, dły_, سیزل, 
   {{0x47d40f1b,0x69d40472,0x2c781bce,0x6a680112}},	//   _ويدر, _igxe, _tëdd_, _düft, 
   {{0xe1900228,0x38701368,0x00000000,0x00000000}},	//   үлдө, ckyr_, --, --, 
   {{0x44f43351,0xc0e0044e,0x2b5c0221,0x4ad80574}},	//   sť_, _ናብራ_, äuch_, ढदिव, 
   {{0x6d44005f,0xaa7800c7,0x6a680205,0x73c0008e}},	//   ākaj, apýv, _güft, фәсе, 
   {{0x29012bb1,0x32f4068f,0x7d000175,0xc0cc0092}},	//   nsja_, ały_, xsls, _ጥምር_, 
   {{0xaa7800ee,0xb270070e,0x29000254,0x92e800fe}},	//   mpýu, зләш, isja_, _মটৰ_, 
   {{0x63b92bb2,0x93e8007b,0x7e7c0ea0,0xcee83b8c}},	//   _uzun, _طفلك_, ëspo, یرین_, 
   {{0x69d41cdf,0x29000cb4,0x9f4c00db,0x6a6800a2}},	//   _ngxe, ksja_, _vegà_, _müfs, 
   {{0xda2010eb,0x00000000,0x00000000,0x00000000}},	//   _बाबत_, --, --, --, 
   {{0x69d40117,0x7f740262,0x6f0c3361,0x2900143a}},	//   _agxe, _мулц, üncü, dsja_, 
   {{0x442d2bb3,0x1ee401b9,0x29000240,0x00000000}},	//   _mbe_, _اوتی_, esja_, --, 
   {{0x4fc44df8,0x01f8010f,0xcfc002dd,0x00000000}},	//   _эсха, יפֿל, _ﺯﻭﻣﺒ, --, 
   {{0x442d2bb4,0x32f4033f,0xaa780022,0x00000000}},	//   _obe_, zły_, ypýv, --, 
   {{0x69d401f0,0xf77129c0,0xa7f8030a,0x2ca80066}},	//   _egxe, واء_, _hoñj, cocd_, 
   {{0xd5b800da,0xa6d82833,0xa7f8030a,0x248d2bb5}},	// [1cd40] _šā_, _orðu, _koñj, digm_, 
   {{0x7f48013c,0x387001e3,0xcd240345,0x00000000}},	//   iveq, skyr_, _بژیی, --, 
   {{0xfe2002ab,0x442d2bb6,0x2a540375,0x79580408}},	//   _मानस_, _bbe_, _ובין_, _тинĕ, 
   {{0x2bc52bb7,0x442d2bb8,0xfbac0490,0xa6d8032e}},	//   रेवा, _cbe_, _घडाम, _arðu, 
   {{0x442d2bb9,0x733405d9,0x1da802ab,0x6a68002f}},	//   _dbe_, ترائ, _घुसत, _tüft, 
   {{0x442c44fc,0x78b52bba,0x32f4012d,0x363400f2}},	//   _ebe_, llyv, rły_, _برحس, 
   {{0x69c01280,0xa5052bbb,0x32f40034,0x6a681b0d}},	//   _únet, _мера_, sły_, _küfr, 
   {{0xb4d409d9,0x442d2bbc,0x3cdc02e5,0x32f4012d}},	//   सदी_, _gbe_, _गढ़े_, pły_, 
   {{0x9f4c00d8,0x6a680790,0x1fa12bbd,0x321c0051}},	//   _pegá_, _müfr, дрэг, _tcty_, 
   {{0x321c02f0,0xf8d81b76,0x442c1617,0x29000fac}},	//   _ucty_, भदाय, _zbe_, ysja_, 
   {{0x442c00ca,0xa7f92bbe,0x7f480869,0x78b40158}},	//   _ybe_, _doñj, aveq, klyv, 
   {{0x43700372,0xefc800cf,0x6d5c01e1,0x00000000}},	//   _تۇۇر, _кулк_, _àpam, --, 
   {{0xa0980302,0x332401c7,0x78b402d0,0xa6d8032e}},	//   _דיאט, ntox_, dlyv, _yrðu, 
   {{0xa7f8030a,0xaf4805d9,0x29012bbf,0x59f80276}},	//   _goñj, _مشڪل_, tsja_, жеря_, 
   {{0x78b42f48,0x91fc00ef,0x00000000,0x00000000}},	//   flyv, _blāz, --, --, 
   {{0x29012bc0,0xdb04005a,0xa7f80165,0xa6d80d12}},	//   rsja_, _eziñ, _zoñj, _orðt, 
   {{0xa7f8030a,0x29000003,0x00000000,0x00000000}},	// [1cd50] _hoñk, ssja_, --, --, 
   {{0x69d40117,0x42880092,0x290015c0,0x00000000}},	//   _ugxe, ንኙነት_, psja_, --, 
   {{0xe4a52bc1,0x78680306,0x78b402d0,0x00000000}},	//   ордо, _vývr, blyv, --, 
   {{0xe7852bc2,0x91fc00e2,0x6d4402b5,0x75c8010b}},	//   _дуго, _glāz, ākah, стуң_, 
   {{0x00e40150,0x442c0064,0x00000000,0x00000000}},	//   _ﺍﻨﺘﻘ, _vbe_, --, --, 
   {{0x69c0056a,0x00c800d1,0x1b7c00df,0x00000000}},	//   _únes, әлик_, סטגע, --, 
   {{0x442c045a,0x55040166,0x00000000,0x00000000}},	//   _tbe_, _очта, --, --, 
   {{0x442c5b36,0xa7f80dd4,0x88b80327,0x91fc00b8}},	//   _ube_, _soñj, _དེསར, _mlāy, 
   {{0x38bc0054,0xe3b00c4f,0x00000000,0x00000000}},	//   nïra_, _آرز_, --, --, 
   {{0x72a00150,0x8e7400d3,0xa6d809e8,0x7f480200}},	//   _كەنن, дуюч, _urðu, rveq, 
   {{0x3eb8005f,0x26c00036,0xc10400e3,0x4e1c000d}},	//   ēst_, _mhjo_, _روشي, _मारै_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf0900302,0x91fc00b8,0x26c001c7,0xbc6801d5}},	//   _אנא_, _alāy, _ohjo_, لمگن_, 
   {{0xc6100f22,0xeb9c0217,0x6a680213,0x1c180037}},	//   স্তা_, ngøy_, _süfr, _थाकल_, 
   {{0xa6d80321,0x78b403ac,0x00000000,0x00000000}},	//   _orðs, tlyv, --, --, 
   {{0x83fc066d,0x26c00221,0x6d44033f,0xa3d40073}},	//   _előz, _ahjo_, łkac, _सलग_, 
   {{0x46300092,0x00000000,0x00000000,0x00000000}},	// [1cd60] _አማጽያ, --, --, --, 
   {{0xe9d40276,0xa6d808a5,0x66e001d5,0xe640447e}},	//   _нкь_, _arðs, хофа, неуп, 
   {{0xa6b802a6,0x78b401f1,0xf99004fb,0x18b400c7}},	//   _অংশট, plyv, _سبد_, _жәар, 
   {{0x68e0255a,0xeabc07de,0x64a12bc3,0x00000000}},	//   _énda, ntùn_, наха, --, 
   {{0x6d44005f,0x66e0014b,0x00000000,0x00000000}},	//   ākai, _пояа, --, --, 
   {{0x34080055,0x00000000,0x00000000,0x00000000}},	//   _ṇadī_, --, --, --, 
   {{0x33240054,0x9f4c0139,0xf0740075,0x21640063}},	//   stox_, _legä_, зийә_, зији_, 
   {{0x249c0240,0x00000000,0x00000000,0x00000000}},	//   _gjum_, --, --, --, 
   {{0x64a00228,0x71f822ad,0xa7f8010b,0x00000000}},	//   _чата, _هراس_, _soñk, --, 
   {{0x7ebc067c,0x4d9800d4,0xfe7400db,0x00000000}},	//   tèpa, жкою_, мүч_, --, 
   {{0x70f52bc4,0xbebc0fda,0xd1d00023,0x00000000}},	//   _رسائ, ptūn, ብርቲ_, --, 
   {{0xa064074d,0xa174011a,0x00cc02dd,0x00000000}},	//   _наха_, _מעבד_, _ﺗﺎﺳﺘ, --, 
   {{0x606005d9,0x00000000,0x00000000,0x00000000}},	//   _سهول, --, --, --, 
   {{0xa6d801a8,0x3a0400f2,0xdcf40066,0x00000000}},	//   _orðr, وکپی_, _کروش_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6e392bc5,0x58d40b3e,0xceb84d8c,0x00000000}},	//   letb, еост, llę_, --, 
   {{0xa6d802d2,0xceb80064,0x00000000,0x00000000}},	// [1cd70] _arðr, olę_, --, --, 
   {{0xaa780022,0x6e392bc6,0x00000000,0x00000000}},	//   apýr, netb, --, --, 
   {{0xb9000f22,0x6d4402b1,0x00000000,0x00000000}},	//   _নৌ_, ākaw, --, --, 
   {{0x6e38054e,0x92e800cc,0x00000000,0x00000000}},	//   hetb, _ময়ে_, --, --, 
   {{0x6e392bc7,0xceb80024,0x130800d4,0x00000000}},	//   ketb, klę_, зній_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc61811b1,0xeb9c0158,0x6e380fac,0x1a9c010f}},	//   दलीय_, rgøy_, detb, זיגע, 
   {{0x44392bc8,0xceb8033f,0x6ce402dd,0x00000000}},	//   _ús_, elę_, _ﺍﻟﺫﻴ, --, 
   {{0xa7f80789,0x6e389108,0x6ce402dd,0x00000000}},	//   _coñi, fetb, _ﺍﻟﺨﻴ, --, 
   {{0x3e8800d6,0x6e387f7b,0x4df42164,0xfe7000c6}},	//   ійно_, getb, няют, ئدة_, 
   {{0x99980374,0xaa780124,0x00000000,0x00000000}},	//   rerū_, ypýr, --, --, 
   {{0x4a740022,0x00000000,0x00000000,0x00000000}},	//   ҭырт, --, --, --, 
   {{0x9f4d2bc9,0x3af52771,0xa7f801c4,0x3f6801af}},	//   _begå_, ьянс, _goñi, _фило_, 
   {{0x201d2bca,0x68f8041a,0xd9c4009e,0xfaa46584}},	//   lgui_, ćudn, ্ডসম, фаго, 
   {{0xd5f40051,0x00000000,0x00000000,0x00000000}},	//   _đàn, --, --, --, 
   {{0x2abc025a,0xb90405f9,0xbebc0421,0x9f4c0139}},	//   rîba_, _पढ_, itūm, _tegä_, 
   {{0x2abc00d2,0x2be0033f,0xfaa8007b,0x27b00116}},	// [1cd80] sîba_, कुओं_, _وهبي_, вәрс, 
   {{0xb4d49417,0xc7641e4a,0x00000000,0x00000000}},	//   सद्_, راقى, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6e392bcb,0x00000000,0x00000000,0x00000000}},	//   zetb, --, --, --, 
   {{0x201c0022,0xf77000db,0xd1d00092,0x00000000}},	//   dgui_, _شاح_, ብይት_, --, 
   {{0x9c1402e3,0x64c00131,0x201ceb44,0xe7a400bc}},	//   _kọst, ىيەل, egui_, _कुटप, 
   {{0x28c0006d,0xaa7800e4,0x846c0023,0xb0c40108}},	//   _वीडि, ipýp, ኣማምን_, мщик, 
   {{0xa7f80077,0x6d5c0129,0x201c002e,0xceb8012d}},	//   _poñi, _àpai, ggui_, wlę_, 
   {{0xb2242082,0x6e3893ce,0xceb80210,0x00000000}},	//   _омал, tetb, tlę_, --, 
   {{0x91c400d1,0x201c0022,0x06c802dd,0x00000000}},	//   _пәйл, agui_, _ﺒﺎﻟﺩ, --, 
   {{0xb80c107c,0x4c941d83,0xec141945,0x6e391472}},	//   िणाम_, еинс, менә_, retb, 
   {{0xa7f903e2,0xceb8762b,0x6e3801d3,0x656001f4}},	//   _toñi, slę_, setb, änhi, 
   {{0xc0a9092e,0xa7f805c7,0xab850634,0x00000000}},	//   _عامل_, _koñv, функ, --, 
   {{0x64980432,0x9f3000d4,0x00000000,0x00000000}},	//   _içiň, _реші, --, --, 
   {{0x4c952bcc,0x6ca4084c,0x2cb86568,0x00000000}},	//   _пикс, _ориж, _واعظ_, --, 
   {{0xd5f401fb,0xaa780124,0xd7f80051,0x00000000}},	//   _đán, apýp, _đăc_, --, 
   {{0xf1dc01bc,0xeabc003a,0x6d449388,0x6ce40220}},	// [1cd90] मशान, ltùm_, ākau, _ﺍﻟﺠﻴ, 
   {{0x201c0369,0x68e00264,0x2c780240,0x00000000}},	//   zgui_, _éndo, _këdo_, --, 
   {{0x73c001e0,0xeabc0393,0x6680036b,0x1fa80d79}},	//   ғәте, ntùm_, _ییرل, _चड्ड, 
   {{0x395c0fac,0x932400f1,0x00000000,0x00000000}},	//   åtse_, چرون, --, --, 
   {{0xf8b00a1e,0x317000d1,0x932400f1,0x00000000}},	//   _תשכ_, ңғут, نرون, --, 
   {{0x28bc1db2,0x00000000,0x00000000,0x00000000}},	//   ्षवि, --, --, --, 
   {{0xa7f80156,0x00000000,0x00000000,0x00000000}},	//   _doñv, --, --, --, 
   {{0x201c0006,0xd4c400a8,0x249401d9,0x1ee402f2}},	//   ugui_, _асуп, _کۅچھ_, ووبی_, 
   {{0x64592bcd,0x443d2bce,0xbebc75e3,0x63b00124}},	//   _inui, mew_, stūm, _рааӡ, 
   {{0x443d2bcf,0x64483e1d,0xa7f80165,0x00000000}},	//   lew_, ldgi, _goñv, --, 
   {{0x62800332,0x6d440210,0x00000000,0x00000000}},	//   mhno, łkan, --, --, 
   {{0x64492bd0,0xa7f92bd1,0x399400c5,0xd138030d}},	//   ndgi, _koñu, _दs_, _юху_, 
   {{0x628003a2,0xdb040129,0xee2c01c4,0x20080419}},	//   ohno, _xxiè, _йн_, óciu_, 
   {{0x443d2bd2,0xddc000a8,0x645801ab,0xb060000d}},	//   hew_, _conţ, _lnui, _äärt, 
   {{0x443d2bd3,0xa9a12bd4,0x64592bd5,0xf1b0008f}},	//   kew_, гирд, _onui, ָסן_, 
   {{0x443d2bd6,0x914c0085,0xfaa4013e,0x00000000}},	//   jew_, nɛ́_, фаҳо, --, 
   {{0x443d2bd7,0xa7a52bd8,0xfd64001e,0x62812bd9}},	// [1cda0] dew_, екта_, _nhuậ, khno, 
   {{0x64592bda,0x98c045a5,0x62800427,0x64a000d1}},	//   _anui, ırır_, jhno, қача, 
   {{0xd9b400db,0xc5d40006,0x443d0246,0x4aa92bdb}},	//   _شەرد, віць, few_, _تايپ_, 
   {{0x443c0652,0x645808c2,0x73e402d5,0xaa44005b}},	//   gew_, _cnui, ходз, ätöä_, 
   {{0x87b80228,0x56340451,0xdeb80023,0x27fc0037}},	//   _журт_, _لڙائ, _ደገን_, _õuna_, 
   {{0x64592bdc,0xa7f90da0,0x999800bc,0x62800363}},	//   _enui, _doñu, nerů_, ghno, 
   {{0x443c2702,0x64580af9,0xf770313e,0x56440092}},	//   bew_, _fnui, _شاڭ_, _የማዳበ, 
   {{0x6458f6a7,0xa0a00220,0x905400f3,0x441401f4}},	//   _gnui, лшыл, твиц, _аффт, 
   {{0xa7f800a2,0xdec80023,0xe6680055,0x999801ef}},	//   _goñu, _በሪኽ_, _ũaũā, kerů_, 
   {{0xa7f80165,0xa2e01188,0x00000000,0x00000000}},	//   _hoñt, _софд, --, --, 
   {{0x914c0085,0xa7f80165,0x999801ef,0xfe20000d}},	//   bɛ́_, _koñt, derů_, _मारस_, 
   {{0x2b4401c0,0x6598010f,0xe7dc0150,0x4c9401f4}},	//   нэгг, לייק, _ﺃﻏﺎﻟ, тимс, 
   {{0x5f701208,0x5c74309f,0x06cc0150,0x00000000}},	//   _ماور, улят, _ﺑﻮﺑﻪ, --, 
   {{0x443d2bdd,0x2bc40d79,0x999801ef,0x00000000}},	//   zew_, रेगा, gerů_, --, 
   {{0x19580598,0x443d2bde,0x23c40241,0x00000000}},	//   нары_, yew_, _kìjí_, --, 
   {{0x1cc0025c,0x32cc0150,0x443c025c,0x5db8011a}},	//   _ཀེར_, _ﺗﻮﮔﻪ, xew_, _מזוה, 
   {{0xd838152d,0x2bc40b02,0x443d2bdf,0x15c80046}},	// [1cdb0] ээр_, रेखा, vew_, _ﺩﺍﺭﻩ, 
   {{0x64592be0,0xdb9c0302,0x443c0428,0xd7c81f07}},	//   _snui, _מסחר, wew_, روله_, 
   {{0x443c013b,0xddc001f1,0xa3d0f059,0xa7f80432}},	//   tew_, _konš, हेन_, _soñu, 
   {{0xa7f8002e,0x644800b5,0x00000000,0x00000000}},	//   _poñu, udgi, --, --, 
   {{0x62800cfd,0x64484a49,0x387c4056,0x443d1fc7}},	//   thno, rdgi, être_, rew_, 
   {{0x443d2be1,0xb0600054,0x70b004fb,0x6fc401a9}},	//   sew_, ñäni, یموض, mаch, 
   {{0x443c038f,0x62804158,0x00000000,0x00000000}},	//   pew_, rhno, --, --, 
   {{0xfd6401dc,0x64592be2,0x601801b8,0x62812be3}},	//   _thuậ, _unui, dämü, shno, 
   {{0xa7f8030a,0xaf000022,0x00000000,0x00000000}},	//   _hoñs, апыл, --, --, 
   {{0x63b92be4,0x3ae4045f,0xa7f805c7,0x00000000}},	//   _iyun, _rôp_, _koñs, --, 
   {{0x63b830c1,0x00000000,0x00000000,0x00000000}},	//   _hyun, --, --, --, 
   {{0x63b92be5,0x3b081b4f,0xa7f92be6,0xd9440124}},	//   _kyun, мемо_, _moñs, ҳҵои, 
   {{0x28d87f1a,0x6d4c6afa,0x63b800b5,0x6ce40150}},	//   _मंजि, åbar, _jyun, _ﺍﻟﺼﻴ, 
   {{0x63b92be7,0x6d440882,0x50640124,0x8f800220}},	//   _myun, ākar, _атәа, _ықыл, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x63b882aa,0xbb840597,0xfe200cb4,0xad18025d}},	//   _oyun, _للبي, _माँस_, _חוקר, 
   {{0x63b92be8,0xa3d04709,0x6fc4022e,0x66e00108}},	// [1cdc0] _nyun, हेम_, gаch, иота, 
   {{0x87b8013e,0xa6812be9,0xb7e000eb,0x00000000}},	//   хуст_, алуд, বরেট, --, 
   {{0x63b89afb,0x6d5c6764,0xfd640055,0xf4280108}},	//   _ayun, _àpat, _phuṭ, доел_, 
   {{0x63b92bea,0x37e4013e,0x96d400fb,0x00000000}},	//   _byun, _шомг, _әсмә, --, 
   {{0x63b81f9d,0x7c340022,0xfe202ce1,0x72d014fb}},	//   _cyun, _mbyr, _मांस_, لەرچ, 
   {{0xa7f80165,0x63b92beb,0xe21001ec,0x00000000}},	//   _foñs, _dyun, амшы, --, 
   {{0x30a42b39,0xa3d034f8,0xa7f8030a,0x01d40011}},	//   крив, हेब_, _goñs, _স্বদ, 
   {{0xd0100597,0x50b80214,0x00000000,0x00000000}},	//   حلة_, رگاد_, --, --, 
   {{0xceb92282,0x63b92bec,0x6ce40046,0xee840108}},	//   нәк_, _gyun, _ﺍﻟﺸﻴ, выно, 
   {{0x7c352bed,0x3e6800d0,0x6ce438a9,0x6d44012d}},	//   _abyr, _kúty_, кіме, łkam, 
   {{0x91fc00dc,0x61407b1b,0x200c03b2,0x00000000}},	//   _anāg, _веха, ømið_, --, 
   {{0x6aa80882,0xbec40200,0x00000000,0x00000000}},	//   चक्र, thëç, --, --, 
   {{0x6d5c01a6,0x7cdc054e,0xce342a77,0x00000000}},	//   _špad, tărî, _موشک, --, 
   {{0xde700150,0x995801ef,0x81c400cc,0xc5ac00eb}},	//   _ندىع, _káňa_, _এলত_, কেটপ, 
   {{0x2d982776,0x99d4007b,0x00000000,0x00000000}},	//   _äpe_, لتفا, --, --, 
   {{0xa7f89e91,0xe8bc0490,0xa3d00037,0x9c080022}},	//   _onñe, ्षेच, हेड_, _ихьз_, 
   {{0x58d52670,0x26040305,0xa7f800a2,0xfca8010f}},	// [1cdd0] ротт, вчег, _soñs, _ריפּ, 
   {{0x63b804ce,0x6d5ca37d,0x00000000,0x00000000}},	//   _ryun, _àpas, --, --, 
   {{0x63b804ce,0x9ca8028e,0xc0cc0150,0x00000000}},	//   _syun, _سهیل_, _ﺗﺎﯞﺳ, --, 
   {{0x5f101533,0x04c8027d,0xa85001e0,0x98a4119e}},	//   _दिल्_, روشي_, _темә, _виџе, 
   {{0x8624af84,0xe784014b,0x6ce40046,0x00000000}},	//   _مکال, _руно, _ﺍﻟﺴﻴ, --, 
   {{0x2b180307,0x63b8009f,0x91fc00b8,0x3f800055}},	//   _बिनु_, _vyun, _nnād, _āhu_, 
   {{0x5694cc53,0xd5b8187d,0x99980311,0x9f5c0005}},	//   _тарт, _аст_, merţ_, rauí_, 
   {{0xd174f1c4,0x91fc00dc,0x63b8037e,0x1cc00327}},	//   рышы, _anād, _tyun, _ཀེེ_, 
   {{0x63b92bee,0xa3001669,0xf07401d3,0xb3980092}},	//   _uyun, _түле, طیوں_, ፋቸውን_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x68e000f2,0x518405c5,0x66c806be,0x00000000}},	//   _éndh, _куца, mükd, --, 
   {{0x6d443a2f,0x8cb400d4,0x66c803e3,0xd17401af}},	//   ākap, исяч, lükd, _тыђы, 
   {{0x81c4009e,0x4c34009d,0x00000000,0x00000000}},	//   _এলি_, шээт, --, --, 
   {{0x66c80209,0x706400c7,0x5f7000e5,0x00000000}},	//   nükd, _ахәҧ, _ماڈر, --, 
   {{0xb6040232,0xa3d0dc75,0x6b8003b9,0xe52801e1}},	//   ntáž, हेत_, _əngi, _ókèè, 
   {{0xbb440022,0xe9d42472,0x7c3403ac,0xf74400f3}},	//   _беик, укс_, _ubyr, лебо, 
   {{0x6d5d2bef,0xb6a48bc5,0x8554001f,0xe73801d9}},	// [1cde0] _àpar, гиал, _የሚፈጥ, فتٕچ_, 
   {{0xb6040306,0xe89000c7,0x7c24072b,0x15d801d9}},	//   ktáž, _ҳаџь, lgkr, نداں_, 
   {{0x7ebc02e2,0x66c803e3,0x00000000,0x00000000}},	//   gèpi, dükd, --, --, 
   {{0x7c24fe75,0x79a40124,0x2db4010f,0x24e41d39}},	//   ngkr, _арҭе, אלען_, умци_, 
   {{0xb7d808f0,0x78b400e4,0x00000000,0x00000000}},	//   _سوسا_, moyv, --, --, 
   {{0x78b4022c,0xbfc000cc,0xa2d01bf4,0x00000000}},	//   loyv, _উলংঘ, مينت, --, 
   {{0xc68c14fa,0x00000000,0x00000000,0x00000000}},	//   _تېل_, --, --, --, 
   {{0x764d2bf0,0x9958022a,0x78b4045a,0xfe2028d4}},	//   _haby, _váňa_, noyv, _माउस_, 
   {{0x764d2bf1,0xb8e40489,0xa2bc012d,0x98489f9f}},	//   _kaby, _ཎེ_, _लीक्, nşı_, 
   {{0xb64400b5,0x764c0009,0x99580306,0x99980024}},	//   _ｉｐ_, _jaby, _táňa_, ndrų_, 
   {{0x764d2bf2,0x9b5821f3,0x99980064,0x00000000}},	//   _maby, ҳият_, idrų_, --, 
   {{0x68e0003e,0x10840131,0x764d2bf3,0x78b400e4}},	//   _éndi, ﻪﻳﺪﯨ, _laby, joyv, 
   {{0xe0b408a8,0x2fc40454,0xa8a40107,0x78b403b2}},	//   _גלאט_, _uzog_, ҳрак, doyv, 
   {{0x764d2bf4,0x7c2401a4,0xceb81219,0x00000000}},	//   _naby, agkr, _шәй_, --, 
   {{0x02e0038e,0x9f5c0093,0x91fc0171,0x9a880050}},	//   _पढ्न, mauá_, _knāb, ھنہٕ_, 
   {{0x6f007544,0x6d492bf5,0x5d10aaab,0x764c5b3b}},	//   _kwoc, _isfa, _ابوز, _aaby, 
   {{0x66c92bf6,0xbc04004e,0x20540115,0x00000000}},	// [1cdf0] yükd, _өчөй, נימל_, --, 
   {{0xe4e402bf,0x7ebc020c,0x48b400fe,0x00000000}},	//   гідн, tèpi, ংগেৰ, --, 
   {{0x93243b5f,0x78b400c7,0x66c800e5,0x00000000}},	//   ەرىن, boyv, jüke, --, 
   {{0xd5b92bf7,0x6f000034,0x764c062c,0x00000000}},	//   усу_, _owoc, _eaby, --, 
   {{0x4428005f,0x764d2bf8,0xd3b8753d,0x6a682791}},	//   ļa_, _faby, луші_, _süfy, 
   {{0x44292bf9,0x272d2bfa,0x764c760e,0x91fc002b}},	//   ża_, mün_, _gaby, _anāb, 
   {{0x6d488a05,0x6f00002e,0x272c06b9,0x81dc0154}},	//   _nsfa, _awoc, lün_, থুন_, 
   {{0x6f0002e2,0xb6040122,0x764d2bfb,0xa280136e}},	//   _bwoc, rtáž, _zaby, _گیتو, 
   {{0x272c6f30,0x764c39a2,0x43952bfc,0xf77000c8}},	//   nün_, _yaby, _таас, ַקט_, 
   {{0xf1c80306,0xd7f80208,0xa28002f2,0x6f000210}},	//   _stáž_, _đăm_, _دیتو, _dwoc, 
   {{0x272c0c86,0x66052bfd,0x00000000,0x00000000}},	//   hün_, _mejk, --, --, 
   {{0x272c2045,0x6d5c02f0,0x75380112,0x7fd52bfe}},	//   kün_, _špac, _ätze, _кілі, 
   {{0x9848cd02,0x7c240656,0x272c0209,0x2a700334}},	//   xşı_, rgkr, jün_, _boxb_, 
   {{0x6604012c,0x272c67ab,0xeab401d5,0x00000000}},	//   _nejk, dün_, ийя_, --, 
   {{0x764c002e,0x6d5c0cad,0x2a0400c7,0xccf8013a}},	//   _raby, _àpap, респ_, cpě_, 
   {{0x764d2bff,0x7ebc007f,0x00000000,0x00000000}},	//   _saby, tèpw, --, --, 
   {{0x272d2c00,0xbb44f262,0x764c1368,0x66c902a2}},	// [1ce00] gün_, _тепк, _paby, züke, 
   {{0x98480bfc,0xe7340598,0x764c01d9,0x66c902a2}},	//   rşı_, реф_, _qaby, yüke, 
   {{0x764c18f7,0xb0600054,0x78b400e4,0x7544011c}},	//   _vaby, ñäki, poyv, рнез, 
   {{0x764c5d23,0x22540edf,0xa9a000d1,0x272d2c01}},	//   _waby, یلند_, _фиюд, bün_, 
   {{0x764d2c02,0x660410ee,0x272c5397,0x23240114}},	//   _taby, _fejk, cün_, иоци_, 
   {{0x66c801d3,0xe1fc0051,0x00000000,0x00000000}},	//   tüke, _đóc_, --, --, 
   {{0x91fc002b,0xa504034b,0x2564026b,0x64480064}},	//   _anāc, _веса_, _карп_, _šliū, 
   {{0x6f000699,0xe0cd2c03,0x065c0020,0x9f4c09d7}},	//   _pwoc, وزي_, _ለማተሚ, _negó_, 
   {{0x9f5c0270,0x2ee40076,0x6604022e,0x1aec0154}},	//   tauá_, _quof_, _yejk, জীতে_, 
   {{0x66c80793,0xd34802f2,0x0248bb12,0x00000000}},	//   püke, _لیڤه_, _مجمو_, --, 
   {{0x272c51b7,0x2a70007f,0x3958031c,0x3d000bae}},	//   zün_, _roxb_, _nrps_, वीले_, 
   {{0xefd0044e,0xa17800c8,0x272c1d89,0xef1801c4}},	//   ከላይ_, _שטאט, yün_, _амд_, 
   {{0x39580066,0x3a380c6a,0x7af40051,0xad640271}},	//   _arps_, _bbpp_, _ctyt, _چابه, 
   {{0x386002e2,0xf3fc0154,0x00000000,0x00000000}},	//   _ankr_, ুলির_, --, --, 
   {{0xdd912c04,0x39580175,0x66040115,0x66c80790}},	//   _машы, _crps_, _rejk, yükb, 
   {{0x272cf7df,0xa564afe9,0x1cc0031c,0x6604036e}},	//   tün_, یدان, _ཀེག_, _sejk, 
   {{0x66040e04,0xb7840bd6,0x5bc40220,0x86c4027d}},	// [1ce10] _pejk, бәре_, _وقىل, ميرن, 
   {{0xbebd2c05,0x272c0c44,0x39581445,0x66c803b9}},	//   ltūr, rün_, _frps_, dükc, 
   {{0x272c2ca8,0x4a740014,0x1bb80214,0x6604005c}},	//   sün_, _نُکر, _مایع_, _vejk, 
   {{0xbebc5914,0x7ebc004e,0xb60000bc,0x272c03e0}},	//   ntūr, lèpt, _šátk, pün_, 
   {{0xbd0401e1,0x66040023,0xc3c4009d,0x88bc00cc}},	//   _atẹ́, _tejk, сөвл, _আওপক, 
   {{0xb7d8011a,0x00000000,0x00000000,0x00000000}},	//   _תקשי, --, --, --, 
   {{0xbebc5c07,0x409408ca,0xc0c4008e,0x00000000}},	//   ktūr, йрит, бәди, --, 
   {{0xd7f8004d,0x3f8c00cf,0x67180037,0x40480063}},	//   _đăk_, tzeu_, _फटाक_, упио_, 
   {{0x442d2c06,0x7e7401d3,0x00000000,0x00000000}},	//   _ice_, özpo, --, --, 
   {{0x1cc0025c,0x527400c6,0xae845680,0x9f4c004e}},	//   _ཀེང_, _والز, йбыз_, _segó_, 
   {{0xa3d00574,0x7af42833,0xfc442b57,0x442c0115}},	//   हेर_, _styt, šíme_, _kce_, 
   {{0x442c0072,0x66180198,0xdb040306,0x00000000}},	//   _jce_, _ɓuka, _axiá, --, 
   {{0x442d2c07,0xbec40055,0x39592c08,0x8f34010a}},	//   _mce_, _apīś, _srps_, _мецц, 
   {{0x442c0036,0x00000000,0x00000000,0x00000000}},	//   _lce_, --, --, --, 
   {{0x6da09386,0xada12c09,0x7f48014b,0xbcf52c0a}},	//   _ниша, _нашл, lweq, _استغ, 
   {{0x442d2c0b,0x0dc82f5c,0xad18011a,0x00000000}},	//   _nce_, _тучи_, _עופר, --, 
   {{0x77c8009d,0x16146c68,0x00000000,0x00000000}},	// [1ce20] улаг_, قساڭ, --, --, 
   {{0x7ebd1219,0x442c0d63,0x998800cf,0x00000000}},	//   cèpt, _ace_, _ەمگە_, --, 
   {{0x7ebc004e,0xf504490c,0xbebc0064,0x00000000}},	//   lèps, ёздо, arūg, --, 
   {{0xa504ac5b,0x7f48013e,0xe1fc01fb,0xf3e40150}},	//   сеца_, kweq, _đóa_, сқақ_, 
   {{0x442d2c0c,0xa3d0230e,0x00000000,0x00000000}},	//   _dce_, हेल_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x442c0072,0xa0852c0d,0x66c80793,0xa22400c7}},	//   _gce_, йсыз_, müka, ажәа_, 
   {{0xb38459e6,0x66c884cd,0x00000000,0x00000000}},	//   _улал, lüka, --, --, 
   {{0x442c0589,0x6e64b33f,0x71a481b9,0x22f40375}},	//   _zce_, стиж, _лазз, _לזמן_, 
   {{0x320c0851,0x66c829ef,0x442c062c,0x00000000}},	//   mafy_, nüka, _yce_, --, 
   {{0x320d2c0e,0xec680229,0x00000000,0x00000000}},	//   lafy_, урок_, --, --, 
   {{0x01c40220,0x2c3c0240,0x00000000,0x00000000}},	//   _ﺯﺍﯕﻌ, _ክዛረቡ, --, --, 
   {{0x320c05da,0xbebd2c0f,0x00000000,0x00000000}},	//   nafy_, stūr, --, --, 
   {{0x7ebc007f,0x66c800a2,0xbebc139f,0x00000000}},	//   rèpt, jüka, ptūr, --, 
   {{0x66c801b8,0x320c06d9,0xdca4147e,0xa3d02d8f}},	//   düka, hafy_, _наји, हेँ_, 
   {{0xd7f88985,0x442c0076,0x320c03d1,0x8c38013e}},	// [1ce30] сус_, _rce_, kafy_, _боқӣ_, 
   {{0x66c8014a,0x320c06d9,0xb600022a,0x345800e5}},	//   füka, jafy_, _šárk, یسنگ_, 
   {{0x320c0170,0xe504007b,0x00000000,0x00000000}},	//   dafy_, صباي, --, --, 
   {{0xeb9c01bf,0x9a780092,0x27fc00a2,0x00000000}},	//   rbøf_, _ያለነው_, _ýun_, --, 
   {{0xa3d009fd,0xe3b000c6,0x320c03d1,0x22880fac}},	//   हें_, أرض_, fafy_, _løke_, 
   {{0x320c05da,0x658400c7,0x00000000,0x00000000}},	//   gafy_, _лыбз, --, --, 
   {{0x442d2c10,0xeb9c0450,0x95c80064,0x00000000}},	//   _tce_, lbød_, _гута_, --, 
   {{0xb4b400fd,0xddcc0327,0x00000000,0x00000000}},	//   _дисә, ċeżm, --, --, 
   {{0x2164ff23,0x707400c6,0x02440592,0x9ce00220}},	//   риқи_, تميز_, _وَرَ, _ﺍﻟﺘﺄ, 
   {{0x2738084c,0xaec002dd,0x7f480309,0x00000000}},	//   mână_, мбыл, rweq, --, 
   {{0x926830cb,0x7dc40035,0x6280013a,0x40340108}},	//   _урта_, تقدن, mkno, _межс, 
   {{0x22452c11,0xb04800db,0x00000000,0x00000000}},	//   lenk_, _ۅكۅۅ_, --, --, 
   {{0x7f480944,0x10d800c6,0xff0836b1,0x00000000}},	//   qweq, _ابلغ_, _телк_, --, 
   {{0x66c82d1c,0x81dc00cc,0xbe64007b,0x00000000}},	//   yüka, _থ্য_, _ذهبي, --, 
   {{0x7ebc020c,0xb86400f1,0x00000000,0x00000000}},	//   sèps, يارو, --, --, 
   {{0x22452c12,0x66c80793,0x320c03d1,0x62800112}},	//   henk_, vüka, zafy_, hkno, 
   {{0xe1fc0016,0x628001a4,0x22440010,0x4e940345}},	// [1ce40] _đón_, kkno, kenk_, _بشۆر, 
   {{0x91fd2c13,0x66c82045,0x22440010,0x00000000}},	//   _anān, tüka, jenk_, --, 
   {{0x37e44e90,0x22440430,0x00000000,0x00000000}},	//   _монг, denk_, --, --, 
   {{0x64a0bb63,0x67dc0024,0x6280045a,0x00000000}},	//   маха, _sąjū, ekno, --, 
   {{0x68e00066,0x320c0170,0x27380356,0x00000000}},	//   _ènda, tafy_, gână_, --, 
   {{0x66c8420d,0x68e0003e,0x46c401f9,0x00000000}},	//   püka, _éndr, वतःह, --, 
   {{0x320d2c14,0x56600092,0x00000000,0x00000000}},	//   rafy_, _ለማዳበ, --, --, 
   {{0x38712c15,0x27380356,0x20c0010b,0x00000000}},	//   njyr_, bână_, мсыг, --, 
   {{0xf2a4330e,0xeea92c16,0x2288e73f,0x224403cd}},	//   _диап, иток_, _søke_, benk_, 
   {{0x628063ce,0xe2952c17,0xb11801c8,0x00000000}},	//   ckno, _дау_, _نقطا_, --, 
   {{0x7ebc033b,0x6ce40220,0xb1e0002b,0x00000000}},	//   tèpr, _ﺍﻟﺒﻴ, _ṛṣiṃ_, --, 
   {{0x6f652c18,0xa064ce65,0x6f8401d5,0x00000000}},	//   _وهام, _маха_, _мулж, --, 
   {{0x6fb400c6,0x2bc81b84,0xceb85224,0x00000000}},	//   _بمشا, руно_, _гән_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb040139,0x9e0402dd,0xc60800eb,0x00000000}},	//   _axiä, _بيىك_, _লালা_, --, 
   {{0x2244003e,0x00000000,0x00000000,0x00000000}},	//   zenk_, --, --, --, 
   {{0x4bc405f5,0x6d592c19,0x2244037e,0x62812c1a}},	// [1ce50] _хөнг, lvta, yenk_, ykno, 
   {{0xe8e80849,0xeb9ce0de,0x6e38002f,0x91fc00dc}},	//   _پردو_, rbød_, nftb, _snān, 
   {{0xc5382401,0xcfd003d4,0x7dec01d3,0x1fd409ab}},	//   спех_, াখিন, _hősé, _डण्ड, 
   {{0xe3b0012f,0x22440083,0x2738054e,0xc35402e8}},	//   ورش_, wenk_, tână_, зъкъ, 
   {{0x6d5c2e31,0x62812c1b,0xa280485f,0x130402d5}},	//   _špal, tkno, ویرو, дзім, 
   {{0x66c80793,0xb7d80375,0xd44c001f,0x27380356}},	//   müko, _לקרי, _በዝግጅ, rână_, 
   {{0x22452c1c,0x66c80793,0x64a400c7,0x65e00124}},	//   renk_, lüko, _дшаз, _цәаҧ, 
   {{0x22441123,0x62812c1d,0x1cb8025c,0x4438002d}},	//   senk_, skno, _མཉེ_, _ùs_, 
   {{0x66c829ef,0x62812c1e,0x22452c1f,0x27fc0037}},	//   nüko, pkno, penk_, _õunu_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa7f8010e,0xf40c03d4,0x00000000,0x00000000}},	//   _doñz, _হাতৰ_, --, --, 
   {{0x506495be,0x76a00248,0xccf80118,0x7dec01d3}},	//   _отча, _kíyè, dvěd_, _bősé, 
   {{0x6d587dfa,0xeabc0ffb,0x23d007f7,0x4b5402e8}},	//   avta, ruùn_, _तरफद, мърт, 
   {{0x66c829ef,0xfe34008f,0x00000000,0x00000000}},	//   düko, _זאַך_, --, --, 
   {{0x6d440034,0x395c01d3,0x00000000,0x00000000}},	//   łkar, íts_, --, --, 
   {{0x386430d9,0x66c8014a,0x91fc19ae,0x00000000}},	//   ñor_, füko, _anāl, --, 
   {{0x66c801b8,0xbb180137,0x8b940064,0x38640205}},	// [1ce60] güko, _ازبا_, _жрэч, ıor_, 
   {{0x4cd01c82,0x00000000,0x00000000,0x00000000}},	//   _সংযু, --, --, --, 
   {{0xe5a003f6,0xddc02e31,0x66c8453a,0x00000000}},	//   нифи, _lonž, mükl, --, 
   {{0x66c92c20,0x00000000,0x00000000,0x00000000}},	//   büko, --, --, --, 
   {{0xa7f80022,0xfa28031c,0x1cc0031c,0xdec80023}},	//   _noñy, _སྐོན_, _ཀེན_, በሮን_, 
   {{0x98b001e4,0xd30c03ce,0xeb3800df,0x00000000}},	//   ĝaĵo_, _हबीब_, מענש, --, 
   {{0x98b00115,0xe1040798,0x00000000,0x00000000}},	//   ŝaĵo_, пејд_, --, --, 
   {{0xa7f80055,0x00000000,0x00000000,0x00000000}},	//   _anñj, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xddc000c0,0x66c8010b,0x00000000,0x00000000}},	//   _donž, jükl, --, --, 
   {{0x2d8001a6,0x66c82ca8,0x00000000,0x00000000}},	//   _očeš_, dükl, --, --, 
   {{0xa3d00316,0xdd943d48,0x6d5810ee,0x66c80205}},	//   हेक_, яшы_, rvta, yüko, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdee00323,0xd1e4044e,0x32d0796d,0x228803b2}},	//   _зочи, _ምሸት_, bâye_, _køka_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x22880158,0x66c829ef,0x291c00f3,0x98c44827}},	//   _møka_, tüko, čua_, есул, 
   {{0x291c06c8,0x91fc00cd,0xe730c0a8,0x473402d5}},	// [1ce70] ōua_, _anām, عصر_, ьнас, 
   {{0x66c803e0,0x00000000,0x00000000,0x00000000}},	//   cükl, --, --, --, 
   {{0x889405f5,0xf8ac00aa,0x68e00066,0xb8f0035b}},	//   _жинх, اکۍ_, _èndo, _аҧсш, 
   {{0x2fc401b9,0x66c801b8,0x00000000,0x00000000}},	//   _oyog_, püko, --, --, 
   {{0x2fc40457,0xb7d800db,0x00000000,0x00000000}},	//   _nyog_, _ووپا_, --, --, 
   {{0x20280092,0x00000000,0x00000000,0x00000000}},	//   _ተቀራር, --, --, --, 
   {{0x2fc4022e,0x569406ed,0xd05c00d1,0x15c80150}},	//   _ayog_, _џаст, ﻛﻠﯩﭗ_, _ﺩﺍﻓﻬ, 
   {{0xa7f800e4,0x6d5c0129,0x66c82ac2,0xe3f40451}},	//   _poñy, _àpay, zükl, _روئڻ_, 
   {{0x64492c21,0x66c8046c,0x249d2c22,0x443c0332}},	//   megi, yükl, _imum_, mfw_, 
   {{0xddc00064,0xd13800c7,0x00000000,0x00000000}},	//   _vonž, цхә_, --, --, 
   {{0x9268036b,0x1ee4023f,0x4d140276,0x70508863}},	//   _эрта_, _کوتی_, ньят, رنیا, 
   {{0x64492c23,0x00000000,0x00000000,0x00000000}},	//   negi, --, --, --, 
   {{0xeb952c24,0xee2ccaef,0x60d92c25,0xef0c00fd}},	//   дия_, _ин_, mmum, _шм_, 
   {{0x4a744478,0x64492c26,0x91fc0055,0x1cc0031c}},	//   ныст, hegi, _anāj, _ཀེམ_, 
   {{0x200c54bb,0x64492c27,0x66c8029f,0x00000000}},	//   _kegi_, kegi, rükl, --, 
   {{0x64492c28,0x60d92c29,0x3f88005f,0x200c01e1}},	//   jegi, nmum, _ļauj_, _jegi_, 
   {{0xe734957a,0x200d2c2a,0x64492c2b,0xb8d4032c}},	// [1ce80] мет_, _megi_, degi, _जद_, 
   {{0x200d2c2c,0x249c002b,0xd6c4411c,0x60d80254}},	//   _legi_, _amum_, رمای, hmum, 
   {{0x64480796,0x3d000490,0x8b64451a,0xcfbc00cc}},	//   fegi, वीचे_, _قایم, আইএন, 
   {{0x64492c2d,0x200d2c2e,0x6d5c00e2,0x25a400ae}},	//   gegi, _negi_, _špak, únla_, 
   {{0x228805ac,0x52880032,0x60d80332,0x00000000}},	//   _søka_, пҡан_, dmum, --, 
   {{0x26c1192b,0x200c32ba,0x60d800ef,0x00000000}},	//   _gkjo_, _aegi_, emum, --, 
   {{0x64492c2f,0x200d2c30,0xceb80184,0x21640640}},	//   begi, _begi_, үҙе_, дији_, 
   {{0x60d88b14,0x64492c31,0xa0a00228,0x00000000}},	//   gmum, cegi, кшыл, --, 
   {{0x200d2c32,0x64a12c33,0x66c805d1,0xb4a80073}},	//   _degi_, _рата, zükm, गची_, 
   {{0x60d80ba7,0x200c9f02,0x22880174,0x4d9800d4}},	//   amum, _eegi_, _tøka_, зкою_, 
   {{0x200d2c34,0xc18001d9,0x33240332,0x3f9803b2}},	//   _fegi_, _میوٹ, lrox_, úsur_, 
   {{0x200c0048,0x2bd0353b,0x43700137,0x00000000}},	//   _gegi_, _सरदा, _جۇۇر, --, 
   {{0x2fc4089c,0xdb24022c,0x00000000,0x00000000}},	//   _uyog_, úrðu, --, --, 
   {{0x64492c35,0x200c1529,0x0e746248,0xb3f400b8}},	//   zegi, _zegi_, _سُبح, _iṣuṇ, 
   {{0x19592c36,0x91fc002b,0x6448014b,0x200c01e1}},	//   мары_, _anāk, yegi, _yegi_, 
   {{0x58d52c37,0x644890ad,0x6490010e,0xb3f400b8}},	//   вост, xegi, _içig, _kṣuṇ, 
   {{0x64492c38,0x6d5c01a6,0x7998002d,0x20780115}},	// [1ce90] vegi, _špah, útwr, קאמא, 
   {{0x64489045,0x33240a73,0x60d824e4,0x00000000}},	//   wegi, drox_, zmum, --, 
   {{0x64492c39,0x91fc02b5,0x66c80037,0xc48001e1}},	//   tegi, _ināh, lükk, _àìkù, 
   {{0x3e84145e,0x94051cc1,0x7d0c033f,0x889401c4}},	//   _kêtê_, نومه, _łask, _чимх, 
   {{0x200d2c3a,0x33240369,0x130802bf,0xbebc0153}},	//   _regi_, grox_, дній_, drūn, 
   {{0x64492c3b,0x200d2c3c,0xb5ec00b8,0x00000000}},	//   segi, _segi_, _āṇav, --, 
   {{0x64492c3d,0x200d2c3e,0x60d92c3f,0xa3d0a064}},	//   pegi, _pegi_, tmum, हेज_, 
   {{0x249d2c40,0x60d80194,0xdec80023,0x00000000}},	//   _umum_, umum, በዮን_, --, 
   {{0x200d2c41,0xb4b40139,0x00000000,0x00000000}},	//   _vegi_, _читә, --, --, 
   {{0xfe700491,0x60d92c42,0x3f900210,0x00000000}},	//   ادة_, smum, ązu_, --, 
   {{0x200d2c43,0x9f5c00d8,0x2900025c,0xca7c022e}},	//   _tegi_, mbuí_, jpja_, ntsе, 
   {{0x91fc002b,0x91a8007b,0xed54d255,0x7f940024}},	//   _anāh, _تهمك_, хою_, _паех, 
   {{0xd1ec02d3,0x64900205,0x9eb01de6,0x00000000}},	//   _ቅሩብ_, _içid, _ишкә, --, 
   {{0xfaa4bd61,0x00000000,0x00000000,0x00000000}},	//   хаго, --, --, --, 
   {{0x3ea80316,0x3ea52c44,0xa9641789,0x63852c45}},	//   čitě_, milt_, нира_, _hīnā, 
   {{0xd9c003e5,0x3ea400c5,0x638400b8,0x8d7400f2}},	//   _एडीट, lilt_, _kīnā, _جاها, 
   {{0x68412c46,0x27b03c1a,0x3ea400a3,0x00000000}},	// [1cea0] ынта, гәрс, oilt_, --, 
   {{0x3ea400c5,0x638400b8,0xeb94011a,0xa3d000bc}},	//   nilt_, _mīnā, _נדיר_, हेछ_, 
   {{0x638400b8,0xf7700133,0xd250105d,0x00000000}},	//   _līnā, _ڵاح_, یۆر_, --, 
   {{0x91fc0053,0x3ea52c47,0x98280014,0xb4a80073}},	//   _ināi, hilt_, _کتھہ_, गचे_, 
   {{0x3ea43402,0x925801c6,0x32e40248,0x00000000}},	//   kilt_, далт_, _níyì_, --, 
   {{0xd130b23e,0x9404013f,0xe2952c48,0x2bd01c54}},	//   لمت_, _ammɔ_, нач_, _सरसा, 
   {{0x3ea400c5,0x7c3400a2,0x00000000,0x00000000}},	//   dilt_, _ocyr, --, --, 
   {{0xd250004b,0xd01000c6,0x6538008f,0x33240f85}},	//   انګ_, جلة_, _מעלד, prox_, 
   {{0xceb88055,0x336405f5,0x3ea410ee,0x638400e2}},	//   мәк_, _яваг, filt_, _cīnā, 
   {{0x7c34062c,0x91fc02b1,0x3ea52c49,0xaca401ed}},	//   _acyr, _onāi, gilt_, کھتے_, 
   {{0x4c94573e,0xfbdc0118,0x00000000,0x00000000}},	//   винс, नेसम, --, --, 
   {{0xe1fc001e,0x66c92c4a,0xeabc04cc,0x3ea40363}},	//   _đói_, tükk, grùn_, ailt_, 
   {{0xab840845,0xace80014,0x2d880219,0x69f0004e}},	//   хунк, _کرتل_, šbe_, лүпт, 
   {{0xdfcc0597,0xd040013f,0x00000000,0x00000000}},	//   _ايه_, ammɔ, --, --, 
   {{0xdd8d2b6c,0x00000000,0x00000000,0x00000000}},	//   _сш_, --, --, --, 
   {{0x66c80793,0xfcc40124,0x999800ef,0x00000000}},	//   müki, _ишыҟ, berž_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [1ceb0] --, --, --, --, 
   {{0xaa44023a,0x29000003,0x00000000,0x00000000}},	//   ätää_, ppja_, --, --, 
   {{0xddc12c4b,0x00000000,0x00000000,0x00000000}},	//   _manş, --, --, --, 
   {{0x6aa40196,0xddc00139,0x3ea401c7,0x64b403c7}},	//   lijf, _lanş, zilt_, رحضر, 
   {{0x5434179e,0x96f802e8,0x93240472,0x00000000}},	//   ارمر, _пеят_, هرون, --, 
   {{0x59d80073,0x3ea4022e,0xb220009d,0x00000000}},	//   णेकर, xilt_, амшл, --, 
   {{0x3ea426ae,0x938800c7,0x5ec00075,0x63840055}},	//   vilt_, _ҧсуа_, ғинғ, _sīnā, 
   {{0x42d02f8b,0x6aa40d27,0x66152c4c,0x63840055}},	//   াদেশ, hijf, laxk, _pīnā, 
   {{0x3ea52c4d,0xccf402dd,0x00000000,0x00000000}},	//   tilt_, ққы_, --, --, 
   {{0x6458c676,0x7c34003a,0x00000000,0x00000000}},	//   _haui, _scyr, --, --, 
   {{0x645818a6,0x3ea400c5,0xeabc04cc,0x6490371e}},	//   _kaui, rilt_, trùn_, _içib, 
   {{0x68e00066,0x38b40150,0x3ea52c4e,0xeb9c87c2}},	//   _èndh, _ءﺍﻳﭙ, silt_, rbøn_, 
   {{0x64583111,0x3ea52c4f,0xa7f8030a,0x00000000}},	//   _maui, pilt_, _kañf, --, 
   {{0xeff4044e,0x6458b452,0xbea52c50,0x48ec02ab}},	//   ለዋይ_, _laui, _шалк, _आंखो_, 
   {{0x64580093,0x66140009,0x00000000,0x00000000}},	//   _oaui, daxk, --, --, 
   {{0x7c34014b,0x645816b8,0xf7440117,0x00000000}},	//   _ucyr, _naui, кебо, --, 
   {{0x9644010b,0xd9100345,0xab70030d,0x00000000}},	// [1cec0] лмаҗ, _گیز_, _кӳрш, --, 
   {{0x64580618,0x6aa40196,0x06b40eac,0x6614009d}},	//   _aaui, cijf, _জীবি, gaxk, 
   {{0x64592c51,0x00000000,0x00000000,0x00000000}},	//   _baui, --, --, --, 
   {{0x1cb01b4b,0x64580393,0xb3852c52,0x04640150}},	//   _ཐམས_, _caui, клел, лтім, 
   {{0x64580393,0x661400e8,0x98b802e2,0x00000000}},	//   _daui, baxk, ntrč_, --, 
   {{0xe1ec2302,0x66001830,0x714401c4,0x00000000}},	//   يسى_, _впра, вхиж, --, 
   {{0x64592c53,0x99980024,0xbebc00c0,0x35a401f0}},	//   _faui, merų_, grūm, _равг, 
   {{0xe1f441fd,0x64581681,0xa1812c54,0x765c002d}},	//   нгә_, _gaui, рышл, ldpy, 
   {{0xe0cc0116,0x00000000,0x00000000,0x00000000}},	//   غزى_, --, --, --, 
   {{0xa7f8030a,0x91fc00cd,0x66c800c5,0x765c928f}},	//   _gañf, _anāv, tüki, ndpy, 
   {{0x6aa401f5,0x00000000,0x00000000,0x00000000}},	//   vijf, --, --, --, 
   {{0x6aa401f5,0xeb9c005c,0x649003e0,0x66c80254}},	//   wijf, bbøl_, _içic, rüki, 
   {{0x5f712c55,0x6aa401f5,0xddc0010b,0x00000000}},	//   _ناور, tijf, _tanş, --, 
   {{0x66c92c56,0x7bd46140,0x6f012c57,0xa7f80139}},	//   püki, _dzyu, _itoc, _kañg, 
   {{0x6aa40d27,0x59f802bf,0x3ed8008f,0x3eb80036}},	//   rijf, теся_, _אַקא, éste_, 
   {{0x6d492c58,0x27ec022c,0xa7f8154a,0x00000000}},	//   _ipfa, øgn_, _mañg, --, 
   {{0xd7f92c59,0x64592c5a,0xa7f80165,0x00000000}},	// [1ced0] тус_, _raui, _lañg, --, 
   {{0x46141617,0xfd640055,0x26c400d2,0x645800ad}},	//   اوار, _akuṭ, ôno_, _saui, 
   {{0x9c641129,0x64592c5b,0x66140113,0x00000000}},	//   _صهیو, _paui, raxk, --, 
   {{0x6d4818f7,0x6f012c5c,0xa3c401ad,0x00000000}},	//   _mpfa, _otoc, _उडद_, --, 
   {{0x64580099,0x142402dd,0x667001d9,0xd3b800d4}},	//   _vaui, рдім, _پۯار, куші_, 
   {{0x6d492c5d,0x64580810,0x926410a8,0xfb14010f}},	//   _opfa, _waui, لدىم, אַקט_, 
   {{0x64592c5e,0x6f012c5f,0x66c8063f,0xda7c011a}},	//   _taui, _atoc, wükw, ונגר, 
   {{0x3200013f,0xa50c0073,0x2614012d,0x518400d1}},	//   _ɑkyi_, ाठीच_, _पड़ती_, ششىق, 
   {{0x6d480223,0xfe70165e,0x21242d56,0x00000000}},	//   _apfa, مدد_, ريکی_, --, 
   {{0x2288143a,0x6f000332,0x7e5400f3,0xeb9c01bf}},	//   _møkk_, _dtoc, утиц, rbøl_, 
   {{0xee34084c,0xeb9c005c,0x63c001ee,0x00000000}},	//   ынэ_, sbøl_, _саҡҡ, --, 
   {{0x7c9419b6,0xe814023e,0x00000000,0x00000000}},	//   اشدا, तरफा_, --, --, 
   {{0x4fa400d6,0x6d5c0316,0x69d403b9,0x6e900014}},	//   _київ, _špat, _azxe, شلێا, 
   {{0xa7f800fd,0xd944035b,0x00000000,0x00000000}},	//   _yañg, аҵои, --, --, 
   {{0x91fc00b0,0x66c801b8,0xdfcc0451,0x8d580139}},	//   _ināt, nüku, _ايڇ_, _ашыт_, 
   {{0x63b803be,0x228803b2,0xb8641e5a,0x6f00035a}},	//   _oxun, _bøkk_, داسو, _ytoc, 
   {{0x99980006,0xeef4010f,0x00000000,0x00000000}},	// [1cee0] terų_, ָמער_, --, --, 
   {{0xa3c40c2e,0xa68055c3,0x995802f0,0x25fc0118}},	//   _उड़_, блуд, máže_, शुली_, 
   {{0x63b92c60,0x99580306,0x7af52c61,0x765c12e8}},	//   _axun, láže_, _huyt, rdpy, 
   {{0x7af52c62,0x66c8014a,0x38540395,0x14040139}},	//   _kuyt, düku, _съос, рҗаг, 
   {{0x1cb80135,0xa7f88021,0x289808a8,0x99580306}},	//   _མཉན_, _dañd, _טיטא, náže_, 
   {{0xc32c0a52,0x7af401f5,0x96b401ee,0x00000000}},	//   بەك_, _muyt, _төбє, --, 
   {{0x6f012c63,0xe3b40220,0x66c801b8,0x63b80393}},	//   _stoc, _ұбт_, güku, _exun, 
   {{0x99580232,0x91fc00dc,0x3e8000bc,0x395801ab}},	//   káže_, _anāt, _létě_, _msps_, 
   {{0xa3c80307,0xec140184,0x7af401f5,0x00000000}},	//   _रुप_, һенә_, _nuyt, --, 
   {{0x39592c64,0x3f8800de,0x1aec0154,0xa7f80139}},	//   _osps_, _ļaut_, ড়ীতে_, _tañg, 
   {{0xec1418ce,0xa7f800e4,0x78a4353e,0xe81400bc}},	//   ленә_, _hañe, _omkv, तरमा_, 
   {{0x3a380005,0xdd94084c,0x66c92c65,0x00000000}},	//   _acpp_, ушь_, lükt, --, 
   {{0x395800b5,0x6f0063e4,0x3a3801ef,0xefd40006}},	//   _asps_, _utoc, _bcpp_, _сюжэ, 
   {{0xa7f92c66,0x22880162,0x7af40208,0x1af40815}},	//   _mañe, _røkk_, _duyt, спря, 
   {{0x6d492c67,0x228805ac,0x91fc0055,0xa3c8012c}},	//   _upfa, _søkk_, _hnās, _रुन_, 
   {{0x69440bb8,0x3958089c,0x2eec0295,0x5e600075}},	//   jčeš, _dsps_, _hiff_, _نۆۋە, 
   {{0x7af4007f,0x2eec004a,0x061435dd,0x00000000}},	// [1cef0] _guyt, _kiff_, идаю, --, 
   {{0x940403b9,0x70b02e35,0x00000000,0x00000000}},	//   _ilmə_, ुकुल, --, --, 
   {{0xe5040372,0x66c80790,0x81a80154,0xd9440798}},	//   ابئي, dükt, _গুন_, _леќи, 
   {{0x2ca804fb,0xa7f92c68,0xe4c92c69,0xbebc1d64}},	//   nicd_, _bañe, ربان_, trūk, 
   {{0xa7f92c6a,0x862400dd,0xbebc00b8,0x00000000}},	//   _cañe, _نکال, brūh, --, 
   {{0xa7f800e8,0x7ae0011c,0x66c801b8,0x228803b2}},	//   _dañe, _èott, tüku, _køki_, 
   {{0x4094ff99,0x91fc00cd,0x70b02435,0xd5b88083}},	//   ирит, _anās, ुकूल, _бст_, 
   {{0x2eec2a3e,0x63b8009d,0x91fc00dc,0xd1751375}},	//   _aiff_, _txun, _snāt, сышы, 
   {{0x98b84424,0x63b8014b,0xa7f92c6b,0x68f40036}},	//   ntrā_, _uxun, _gañe, _luxd, 
   {{0x999800dd,0xb0600209,0xbea52c6c,0x7af401a4}},	//   zerű_, ýäri, раок, _ruyt, 
   {{0x6d5c46aa,0x7af402d1,0x66c8000d,0xa184030d}},	//   _špar, _suyt, lüks, _сăнĕ_, 
   {{0x7f580218,0x7af40784,0x68ed2c6d,0x2eec0142}},	//   _tswq, _puyt, _nicd, _eiff_, 
   {{0x5f752c6e,0xdb04067c,0x7af5264c,0xfa500023}},	//   _حاضر, _axiò, _quyt, _ምምርማ, 
   {{0x2eec04c4,0x6fb416c8,0x99580122,0x39592c6f}},	//   _giff_, _әгәр_, ráže_, _psps_, 
   {{0x99580122,0xdce41d55,0x7af401f5,0xc0dc02d3}},	//   sáže_, _hrnč, _wuyt, _ሓሙስ_, 
   {{0xf7700491,0x2eed2c70,0x7af40309,0x68f4058a}},	//   ياء_, _ziff_, _tuyt, _duxd, 
   {{0x7c9521cf,0xf9a80ba1,0x6d5c0005,0x66c80790}},	// [1cf00] _مشکا, _brèç_, _ápar, yükt, 
   {{0x39580048,0xe9a404fb,0xa7f8002e,0x66c80790}},	//   _tsps_, اگین_, _rañe, düks, 
   {{0x39592c71,0x68ec009b,0x00000000,0x00000000}},	//   _usps_, _ficd, --, --, 
   {{0x78a402d2,0x00000000,0x00000000,0x00000000}},	//   _umkv, --, --, --, 
   {{0x37752c72,0x66c80205,0x17e400cc,0x00000000}},	//   _тынс, tükt, _ফ্ৰি, --, 
   {{0xb5052c73,0x91fc00cd,0x06b801d9,0x7e0007f7}},	//   _نظرو, _anār, _منُک_, ोरोग_, 
   {{0x6490e03b,0xc76c0020,0xa7f8002e,0x91fc00b8}},	//   _için, _ሠራተኛ_, _wañe, _snās, 
   {{0xdce40427,0xa7f800e4,0x66c80790,0x2eec0254}},	//   _brnč, _tañe, büks, _siff_, 
   {{0xa0641b88,0xdce416a3,0xe81443d1,0x00000000}},	//   рања_, _crnč, तरता_, --, 
   {{0x26c41326,0xa7f800cd,0xdce401ef,0x71a40454}},	//   čnog_, _kañc, _drnč, _казз, 
   {{0x7e6400c7,0x9ed40166,0xe7f80118,0x00000000}},	//   схыҵ, рмэт_, ौडमा_, --, 
   {{0xdb041709,0x68f44f40,0xa7f8002b,0x00000000}},	//   _axiñ, _ruxd, _mañc, --, 
   {{0xdce40cf4,0xa7f80156,0x2ca80066,0x22880162}},	//   _grnč, _lañc, ricd_, _søki_, 
   {{0x27fc0327,0x9e3000db,0xdee00f4e,0x00000000}},	//   _żun_, _дешч, _дочи, --, 
   {{0x2bd016f0,0xa8a495b3,0x68ec01f5,0x3cfc01bc}},	//   _सरका, арак, _picd, _रूपे_, 
   {{0x14101533,0xdca40063,0x66c82ca8,0x00000000}},	//   ारोह_, _маји, yüks, --, 
   {{0x68ed2c74,0x822000cc,0x2d9c002f,0xc7d8117e}},	// [1cf10] _vicd, প্টপ_, lzte_, умах_, 
   {{0x68f4bd10,0x00000000,0x00000000,0x00000000}},	//   _tuxd, --, --, --, 
   {{0x2d9c17da,0xa7f800cd,0x98b81a14,0x00000000}},	//   nzte_, _cañc, strā_, --, 
   {{0x2a600158,0x2d9c005a,0x00000000,0x00000000}},	//   ldjb_, izte_, --, --, 
   {{0x84c400d1,0xe2740075,0x00000000,0x00000000}},	//   _һәдд, ишкә_, --, --, 
   {{0xa7f80489,0x66c80205,0x00000000,0x00000000}},	//   _fañc, rüks, --, --, 
   {{0xa7f80de2,0x66c800c5,0xdce40306,0xc5e40154}},	//   _gañc, süks, _srnč, _প্রপ, 
   {{0xc0e0069c,0x19b80302,0x66c800c5,0x2d9c00d0}},	//   _ነቶም_, יפור_, püks, dzte_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe29002da,0x2d9c002f,0xa7f800b8,0x00000000}},	//   _بذر_, fzte_, _yañc, --, 
   {{0x6e2c01d3,0x98b8054e,0xa3c8012d,0x00000000}},	//   óbba, ntră_, _रुत_, --, 
   {{0x3b080261,0x00000000,0x00000000,0x00000000}},	//   лемо_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7c94029e,0x3f8c0051,0x00000000,0x00000000}},	//   _گشتا, myeu_, --, --, 
   {{0xf2d004ae,0xbebc00e2,0x00000000,0x00000000}},	//   פעל_, rsūd, --, --, 
   {{0x3ff800df,0x00000000,0x00000000,0x00000000}},	//   רפּע, --, --, --, 
   {{0xac94774e,0x3f8d2c75,0x7624669b,0xfaa52c76}},	// [1cf20] _دنيا_, nyeu_, ймаз, _гапо, 
   {{0xe6141b16,0xa7f80a28,0x22880174,0xcfe403d4}},	//   йду_, _pañc, _køku_, ফুকন, 
   {{0x26c80066,0x00000000,0x00000000,0x00000000}},	//   اطقی_, --, --, --, 
   {{0xb6040122,0x91fc00dc,0x64b407d0,0xa7f800cd}},	//   dráž, _anāp, _अदृश, _vañc, 
   {{0x6490eab4,0xb28400db,0xe734011c,0x00000000}},	//   _içil, йыкк, _лея_, --, 
   {{0xa30801ed,0x649000a2,0xa7f8002b,0x386001ef}},	//   ارنے_, _uçin, _tañc, _hakr_, 
   {{0xb0c40055,0x75d4007b,0x622000d1,0x00000000}},	//   _dṛśṭ, _طيرا, سىيل, --, 
   {{0xa7f92c77,0x00000000,0x00000000,0x00000000}},	//   _kaña, --, --, --, 
   {{0xa7f92c78,0x81a8015b,0xb5940116,0x38612c79}},	//   _jaña, _গুদ_, _тиңш, _makr_, 
   {{0xa7f92c7a,0x2d9c0639,0xa75800c8,0xab600790}},	//   _maña, tzte_, נדיר, çüms, 
   {{0x8e800020,0xa7f92c7b,0xfe4407d6,0x98c800ab}},	//   _ይገኛሉ_, _laña, تکنی, लवाए, 
   {{0x2d9c17da,0x38600162,0xbed801c6,0xef18011c}},	//   rzte_, _nakr_, лдөх_, _бмд_, 
   {{0xa7f92c7c,0x16b801f9,0x2d9c06d8,0x00000000}},	//   _naña, _आदूब, szte_, --, 
   {{0x649067ab,0x7bb00124,0x00000000,0x00000000}},	//   _açil, ьҩыу, --, --, 
   {{0x2d04094f,0x199428e8,0xceb8012d,0x7de0035b}},	//   _уялг, паря, mnę_, rãsé, 
   {{0xa7f92c7d,0xd1ec0092,0xceb800c0,0x00000000}},	//   _baña, ቅርታ_, lnę_, --, 
   {{0xa7f92c7e,0x09e400d1,0xb60400d7,0xceb80064}},	// [1cf30] _caña, соңн, zráž, onę_, 
   {{0xa7f92c7f,0x64900432,0x2450004d,0xd7f8024c}},	//   _daña, _eçil, _ảm_, _ҳур_, 
   {{0x3f8c007f,0x00000000,0x00000000,0x00000000}},	//   zyeu_, --, --, --, 
   {{0x9b4401d9,0xd7f84ae5,0x14c8005b,0x91fc00cd}},	//   _بنیو, _гур_, бычи_, _snāp, 
   {{0xa7f80f71,0x98b8084c,0x1dcc0c2e,0x96d401ad}},	//   _gaña, stră_, _सुनत, _बीकॉ, 
   {{0x64903630,0xb60402fb,0x417400db,0x38600165}},	//   _içim, tráž, قابس, _zakr_, 
   {{0x2d8801bf,0xceb80210,0x00000000,0x00000000}},	//   øbel_, dnę_, --, --, 
   {{0xa7f80598,0x6ea40316,0xceb800c0,0x00000000}},	//   _yaña, टोसु, enę_, --, 
   {{0x3eb8003e,0x4ac80073,0x00000000,0x00000000}},	//   ésto_, ळवाव, --, --, 
   {{0xfd492c80,0xdb240098,0xa2c80276,0xb60400d0}},	//   азок_, _ésén, _субз_, práž, 
   {{0xfce401b9,0x3f8d2c81,0x98b800c0,0x00000000}},	//   жоно, syeu_, ltrą_, --, 
   {{0xceb8033f,0xbb442077,0x80b40154,0x3f8c0051}},	//   anę_, оемк, ুষঙ্, pyeu_, 
   {{0xfc4801e1,0x201d2c82,0x98b80024,0xbebc0171}},	//   _adíá_, maui_, ntrą_, frūt, 
   {{0xa7f80428,0x38600156,0xbebc00e2,0x22880162}},	//   _raña, _sakr_, grūt, _tøku_, 
   {{0xa7f92c83,0xfbdc08e9,0xaa403dec,0xc4c8033f}},	//   _saña, नेजम, ьерл, िकाओ, 
   {{0xa7f92c84,0x201c0270,0xf3f4031c,0x228803b2}},	//   _paña, naui_, _བེུད_, _køks_, 
   {{0xa7f85d55,0xa3c80490,0xfaa40124,0x44f40327}},	// [1cf40] _qaña, रॅम_, _маио, _བཤུར_, 
   {{0xd1c002d3,0x00000000,0x00000000,0x00000000}},	//   _ስጋብ_, --, --, --, 
   {{0xa7f80054,0x201d2c85,0x1dcc07b6,0xe5a000f3}},	//   _waña, kaui_, _सुमत, мифи, 
   {{0xa7f92c86,0x87f801c0,0xceb8033f,0x649000fd}},	//   _taña, _гэрт_, znę_, _uçil, 
   {{0xceb8fea4,0x00000000,0x00000000,0x00000000}},	//   ynę_, --, --, --, 
   {{0x35a4030d,0x8e2c022e,0x32180419,0x00000000}},	//   _дагг, jmdа_, úpy_, --, 
   {{0x22887778,0xd13000c6,0x764c02d0,0xddcc010b}},	//   _røkt_, رمة_, _ibby, _ýeňl, 
   {{0x2288dd44,0x201c003a,0xab6003e0,0x00000000}},	//   _søkt_, gaui_, çüks, --, 
   {{0xc32c4d2d,0x28980a7c,0xabe00150,0xb22401ee}},	//   _مەن_, ייקא, _ﺍﻭﺮﺋ, _ммал, 
   {{0x73c001e0,0x91c401af,0x00000000,0x00000000}},	//   _нәҙе, _нәйл, --, --, 
   {{0x2d88019f,0x826007d2,0x116805af,0x00000000}},	//   âbe_, _سۇين, _دلای_, --, 
   {{0xceb92a2e,0x201c0393,0x1dd401c6,0x22bc033f}},	//   snę_, caui_, өлөө_, ałkę_, 
   {{0x7d0c00bc,0x764c0731,0x92cc0154,0x22880174}},	//   _čase, _obby, রগী_, _tøkt_, 
   {{0xbaa40131,0x7c380153,0x00000000,0x00000000}},	//   пусқ, ėtra, --, --, 
   {{0x4c94bba2,0x985006b9,0xe8140073,0x00000000}},	//   _никс, _ağız_, तरला_, --, 
   {{0x764c1368,0x00000000,0x00000000,0x00000000}},	//   _abby, --, --, --, 
   {{0x473480f4,0xdce400ef,0x00000000,0x00000000}},	// [1cf50] янас, _urnā, --, --, 
   {{0x5678010a,0x98480014,0x00000000,0x00000000}},	//   обуя_, ٝلہٕ_, --, --, 
   {{0xe504113e,0x00000000,0x00000000,0x00000000}},	//   زباي, --, --, --, 
   {{0xd7f00f78,0x764c0076,0x649000a2,0xa8500214}},	//   ركە_, _ebby, _içik, _تکسچ, 
   {{0x9cd80375,0x00000000,0x00000000,0x00000000}},	//   קודה_, --, --, --, 
   {{0xa7f8005a,0x996c00e2,0x52a800d4,0x00000000}},	//   _kaño, lēša_, овім_, --, 
   {{0xa7f80de2,0x201c1140,0x98b83ee4,0x66000784}},	//   _jaño, taui_, strą_, ñnku, 
   {{0xa7f85235,0xdd2c0118,0x90e4009f,0x19bc011a}},	//   _maño, těžt, وسين, ימוב, 
   {{0x201d2506,0xa7f8002e,0x531400ae,0x00000000}},	//   raui_, _laño, _يذكر, --, 
   {{0x201c06c8,0x2ee0121c,0x5334033a,0xfe44009d}},	//   saui_, нжыг, _цефт, чноо, 
   {{0x3cc80372,0x201c03a0,0xa7f81bce,0x00000000}},	//   йлоо_, paui_, _naño, --, 
   {{0x628008a4,0x443d2c87,0x934002d3,0x75780375}},	//   ljno, ngw_, _ኣኼባታ, צטרפ, 
   {{0xee2d1e3c,0x6e280175,0x64900790,0xaff4007b}},	//   _пн_, _fdfb, _açik, _عفوا_, 
   {{0xa7f92c88,0x4a74005e,0x09ac00eb,0xca74013d}},	//   _baño, мыст, _গড়া, мусы, 
   {{0xa7f82760,0x443c00b5,0xddc000b8,0x00000000}},	//   _caño, kgw_, _manū, --, 
   {{0xa7f92c89,0xefb001d5,0x6d4c0327,0x00000000}},	//   _daño, _آییگ, ħbat, --, 
   {{0xa7f80598,0xcce4007b,0x35f92c8a,0x00000000}},	// [1cf60] _tañn, _تسوي, مراد_, --, 
   {{0x7bd52c8b,0xd9103b7a,0x4734004b,0xc98c01ec}},	//   _iyyu, _لیس_, ګرېز, _ﮔﯟﺍﯕ, 
   {{0xa7f81709,0x64480194,0x68e0000f,0xf50400d4}},	//   _gaño, ffgi, _ūnde, їздо, 
   {{0x3d00012d,0x00000000,0x00000000,0x00000000}},	//   _mów_, --, --, --, 
   {{0x3d000241,0xa7f8010e,0x9850013d,0x00000000}},	//   _lów_, _mañl, _uğız_, --, 
   {{0x644800b5,0x987c0118,0x764c03ac,0xe9440244}},	//   afgi, _míč_, _ubby, _بریی, 
   {{0x66e0f9c9,0xa7f800e8,0x443c0175,0x65c12c8c}},	//   _чора, _xaño, bgw_, _збра, 
   {{0xa7f800e8,0x7bd4022e,0x237c01e1,0x667002dd}},	//   _nañl, _oyyu, _lóṣù, _يگەر, 
   {{0xa878008f,0x68e0a87b,0xef9001d5,0x8d740092}},	//   מאקר, _ënde, عیتد, _ሥራቸው_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7bd52c8d,0x0c240137,0x00000000,0x00000000}},	//   _ayyu, үмүн, --, --, 
   {{0x2d8056c0,0x321c06d9,0xeb9d2c8e,0xa7f80077}},	//   ćke_, _hety_, dbør_, _raño, 
   {{0xa7f8df5a,0xeb040138,0xab7400db,0x00000000}},	//   _dañl, ячно, سۅدا_, --, 
   {{0xa7f809c2,0x321c0124,0x9a8428e5,0x00000000}},	//   _paño, _jety_, нусл, --, 
   {{0x321c325f,0x7bd52c8f,0xdd18013a,0x9d4000f3}},	//   _mety_, _eyyu, _záže, _зејд, 
   {{0x321d2c90,0x50cc412f,0xc8d800d4,0x8d800092}},	//   _lety_, ाविष, імає_, _ይሉታል_, 
   {{0xc31000bd,0xa7f80113,0x6280033f,0xabe002dd}},	// [1cf70] _হয়নি_, _waño, yjno, _ﺍﺭﻣﺎ, 
   {{0x321c41d6,0xd1c0001f,0xeb9c003b,0x00000000}},	//   _nety_, _ስጋት_, sbøs_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe8b40c99,0xc4351d5f,0x62800369,0x00000000}},	//   _དམིག, بکست, wjno, --, 
   {{0x321d2c91,0x7cfc00d7,0xa3b800ae,0x9a940240}},	//   _bety_, márň, حاضر_, _ዚከኣል_, 
   {{0x62800218,0x321c00cd,0x443c009a,0x00000000}},	//   ujno, _cety_, sgw_, --, 
   {{0x321c003e,0x85040214,0x443c010a,0x5eb800eb}},	//   _dety_, _آورن, pgw_, _উঠলে, 
   {{0xd4990fce,0xf92800df,0x00000000,0x00000000}},	//   _еру_, קופּ, --, --, 
   {{0x442c7861,0x321c0851,0x53341e2d,0x69d4007c}},	//   _ide_, _fety_, _петт, _lyxe, 
   {{0xdd180122,0x442d2c92,0x321c0af9,0x9758011a}},	//   _váže, _hde_, _gety_, ליחו_, 
   {{0x442d2c93,0xe57c00a2,0x7cfc0419,0x00000000}},	//   _kde_, _öŷde_, kárň, --, 
   {{0xca2800c6,0x442c0316,0x321c0109,0x7c380006}},	//   _כם_, _jde_, _zety_, ėtro, 
   {{0x321c00e4,0x91f000c7,0x88c40011,0xe6bc0303}},	//   _yety_, _иҟәш, ্ষাক, ्वाङ, 
   {{0x442d2c94,0x6fe001ad,0x69d4007c,0xeb9c03cd}},	//   _lde_, _परतं, _byxe, tbør_, 
   {{0x442d2c95,0xa9652c96,0xf2d0008f,0x7f480194}},	//   _ode_, мира_, דעם_, lteq, 
   {{0x442d2c97,0x7f4800f7,0x638400b0,0x9998012d}},	//   _nde_, oteq, _kūnā, tarł_, 
   {{0xab600598,0x7f492c98,0x7bd4198f,0xa7f80055}},	// [1cf80] _авыл, nteq, _uyyu, _kañj, 
   {{0x442d2c99,0xeab402dd,0xd8880014,0xcd240244}},	//   _ade_, _ойы_, _کھسن_, _تژیی, 
   {{0x442d2c9a,0xd1c0001f,0x321c32ad,0x63840055}},	//   _bde_, _ስፋት_, _rety_, _lūnā, 
   {{0x442c0433,0x321c5188,0x1cdc0327,0x99980210}},	//   _cde_, _sety_, _འེས_, parł_, 
   {{0x442d19be,0x321d0f8f,0x638400b8,0xb284064e}},	//   _dde_, _pety_, _nūnā, дыйк, 
   {{0x442d2c9b,0x98280014,0x81c80f22,0xe2945df2}},	//   _ede_, _بتھہ_, োধন_, мач_, 
   {{0x321d2c9c,0x442c010a,0xe640030d,0x74140472}},	//   _vety_, _fde_, _шерп, _يوسا, 
   {{0x442c56c0,0x40e40032,0xd01000c6,0x00000000}},	//   _gde_, нсығ, دلة_, --, 
   {{0x321c03d1,0x7f480194,0xe4d4036b,0x4fd40276}},	//   _tety_, gteq, _آوقت_, эжит, 
   {{0x442c038e,0xa7780a1e,0xbe800853,0x00000000}},	//   _zde_, קריפ, лқчи, --, 
   {{0x7f480eda,0xa7f80156,0x442d2c9d,0x98b92c9e}},	//   ateq, _dañj, _yde_, strę_, 
   {{0x442c0092,0xb60002fb,0x5fac01f9,0x00000000}},	//   _xde_, _šálk, _जेवल, --, 
   {{0x7f480381,0x7cfc02f0,0xfd6400db,0x6fe003ce}},	//   cteq, várň, _үнчү, _परिं, 
   {{0x7c2001e4,0x394800b5,0x00000000,0x00000000}},	//   _ĵore, ftbs_, --, --, 
   {{0x59f8084c,0x99d42f84,0x00000000,0x00000000}},	//   деря_, نتفا, --, --, 
   {{0xa7f8030a,0x6fe02d6b,0x63840055,0x00000000}},	//   _zañj, _परां, _yūnā, --, 
   {{0x442d2c9f,0xa7f80055,0x7cfc00d7,0xe970215c}},	// [1cf90] _rde_, _yañj, rárň, رۇڭد, 
   {{0x442c12ce,0x7cfc00d7,0x00000000,0x00000000}},	//   _sde_, sárň, --, --, 
   {{0xe5740b28,0x8894008e,0x442d2ca0,0xf1ac033f}},	//   بلاژ_, _зинх, _pde_, _झेलन, 
   {{0x442c06be,0xfcf800df,0x00000000,0x00000000}},	//   _qde_, פּעל, --, --, 
   {{0xa7f800e8,0x442d2ca1,0x42d40111,0x42800092}},	//   _lañk, _vde_, ніку, ያምኑት_, 
   {{0xddcc0010,0xe814012c,0x00000000,0x00000000}},	//   _čeža, तरका_, --, --, 
   {{0xa7f92ca2,0x638407d7,0xb14400f2,0x00000000}},	//   _nañk, _sūnā, فیلم_, --, 
   {{0x442d2ca3,0x638406c8,0xd1746058,0x7f48013c}},	//   _ude_, _pūnā, тышы, tteq, 
   {{0x7f480af5,0x3f980122,0x2d88fbf7,0xa7f8002b}},	//   uteq, ásu_, äben_, _pañj, 
   {{0xa7f92ca4,0x7f480eda,0xd2001884,0x249c01ab}},	//   _bañk, rteq, _күшк, _hlum_, 
   {{0x7f492ca5,0xf650010f,0xf3340055,0xa7f80055}},	//   steq, נצט_, _teṣā_, _vañj, 
   {{0xfd740323,0xa7f800e8,0xc0d8001f,0x00000000}},	//   _үлдэ, _dañk, ሮችም_, --, 
   {{0x4c800220,0x91fc002b,0x1dcd1ada,0x60d92ca6}},	//   рғыз, _anāy, _सुरत, mlum, 
   {{0x249d2ca7,0xeabc05d5,0x00000000,0x00000000}},	//   _llum_, ssùn_, --, --, 
   {{0x249cbd89,0x60d8000d,0x00000000,0x00000000}},	//   _olum_, olum, --, --, 
   {{0x60d92ca8,0xfc30009f,0xe8f403c5,0x98b40419}},	//   nlum, _صحب_, елс_, šeľu_, 
   {{0x7c24eca6,0x36340101,0x60d80108,0xb3f40055}},	// [1cfa0] makr, فراس, ilum, _kṣeṇ, 
   {{0x7c252ca9,0x60d92caa,0x249d2cab,0xfaa80451}},	//   lakr, hlum, _alum_, _رهجي_, 
   {{0x60d80201,0x249d2cac,0xd9100405,0xed980023}},	//   klum, _blum_, _خیز_, _ጎይታይ_, 
   {{0xc0d00020,0x7c252cad,0x64a12cae,0x2404e41f}},	//   ጨማሪ_, nakr, лаха, енци_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7d0c8b19,0x249c0165,0x7c2400dc,0xc32c15bf}},	//   _časn, _elum_, hakr, زەم_, 
   {{0x7c252caf,0x1dcc03f3,0x249d2cb0,0x67200e3c}},	//   kakr, _सुलत, _flum_, ćnje, 
   {{0x60d92cb1,0xa3c80c2e,0x249c0204,0x00000000}},	//   glum, _रुक_, _glum_, --, 
   {{0xe1f423c9,0x7c252cb2,0xb4bc1f14,0xd3700131}},	//   мгә_, dakr, ीकी_, _خۇش_, 
   {{0x60d92cb3,0xeda52cb4,0xe3540375,0x7170313e}},	//   alum, ешмо, _אשמח_, _مۇتا, 
   {{0x60d92cb5,0xe2780daf,0x7c24143a,0xc18000e5}},	//   blum, _эштә_, fakr, _نیوٹ, 
   {{0x2fc40b89,0x60d80129,0x765c0124,0x00000000}},	//   _txog_, clum, hepy, --, 
   {{0x9f5c0ffb,0x765d2cb6,0x91fc00cd,0x00000000}},	//   ccuà_, kepy, _snāy, --, 
   {{0x765c0124,0x00000000,0x00000000,0x00000000}},	//   jepy, --, --, --, 
   {{0x3eb856ec,0xd5d007f7,0xe7e0000d,0x00000000}},	//   èste_, _तुलज, _खरहा_, --, 
   {{0x7c240882,0xa7f803f0,0x58d52cb7,0x1e800116}},	//   cakr, _kañi, гост, _аләм, 
   {{0x249c00a3,0xc6f92cb8,0x00000000,0x00000000}},	// [1cfb0] _rlum_, днах_, --, --, 
   {{0x249c45c0,0xa7f808e7,0x60d92cb9,0x00000000}},	//   _slum_, _mañi, zlum, --, 
   {{0xb40c063f,0xe5a81f5a,0x249c045a,0xe7e0000d}},	//   _ịpịa_, чњак_, _plum_, _खरवा_, 
   {{0x60d80097,0xd5d00073,0x94a8004e,0x00000000}},	//   xlum, _तुळज, нтча_, --, 
   {{0x6f012cba,0x69e01050,0xa3c887ee,0x13080212}},	//   _nuoc, šteć, _रुख_, еній_, 
   {{0xa7f800e8,0x3370020a,0x5efc03e5,0x37c0d8fd}},	//   _nañi, шҳур, रदस्_, _тәсб, 
   {{0x7c252cbb,0x7d0cebd0,0x60d92cbc,0x6f000393}},	//   yakr, _časo, tlum, _auoc, 
   {{0x249c0ac5,0xb9dc0020,0x6f007197,0x26d12cbd}},	//   _ulum_, _ባይ_, _buoc, loxo_, 
   {{0x708000f4,0x6f000801,0x60d92cbe,0x7c252cbf}},	//   ргыз, _cuoc, rlum, vakr, 
   {{0x60d92cc0,0xa7f809c2,0x26d00077,0x7c24db3d}},	//   slum, _cañi, noxo_, wakr, 
   {{0x4df5068d,0x60d81295,0x7c252cc1,0xa7f92cc2}},	//   ляют, plum, takr, _dañi, 
   {{0x6f000801,0x6fb0030f,0x26d12cc3,0x656400b5}},	//   _fuoc, امیا, hoxo_, _msjh, 
   {{0x26c40bb8,0x26d00564,0xab612cc4,0x00000000}},	//   čnoj_, koxo_, авял, --, 
   {{0xa7f82e48,0x673c0477,0x6b60399f,0x00000000}},	//   _gañi, duqj, јкра, --, 
   {{0x26d12cc5,0x2d8804ce,0xf2d0010f,0x3eb8065c}},	//   doxo_, øbet_, יעך_, éstu_, 
   {{0x37e4136b,0x6ee40d12,0x2bd00cb2,0x00000000}},	//   вобг, rðbe, _धुवा, --, 
   {{0x26d00077,0xac8002e8,0xa8000c60,0xabe00150}},	// [1cfc0] foxo_, _ъгъл, рзул, _ﺍﺭﻳﺎ, 
   {{0xdeb80198,0x6b881bce,0xb90400f3,0x00000000}},	//   ttuƙ, _àgga, _изок, --, 
   {{0xa2b400dc,0x78b40162,0xf5740092,0x765c00c7}},	//   ्चन्, piyv, _የሚዲያ_, repy, 
   {{0xb4bd0312,0x3958009a,0x7d0c01fa,0x753c04cc}},	//   ीके_, _ipps_, _časl, rupz, 
   {{0x64900205,0x00000000,0x00000000,0x00000000}},	//   _açis, --, --, --, 
   {{0x6f00011c,0x3958020b,0xb1902de8,0x49180118}},	//   _ruoc, _kpps_, иллә, यीको_, 
   {{0x6f012cc6,0x75d4310b,0x3cfc05f9,0xe81401f9}},	//   _suoc, _شيرا, _रंगे_, तरचा_, 
   {{0xe0cc099f,0xa7f80227,0x3ea403fa,0xc0c402dd}},	//   يزي_, _sañi, ehlt_, лшық, 
   {{0x6f012cc7,0x00000000,0x00000000,0x00000000}},	//   _quoc, --, --, --, 
   {{0x39580270,0xa7f80784,0x3fc8036b,0x81b402dd}},	//   _opps_, _qañi, رگنی_, _өңір_, 
   {{0x6f00af7a,0x64912cc8,0x4c940108,0x80a000db}},	//   _wuoc, _içir, гинс, _گۅين, 
   {{0x6f0007c5,0xa7f92cc9,0xd7b40073,0x64902b24}},	//   _tuoc, _wañi, ूपाच, _uçit, 
   {{0xa7f92cca,0x39592ccb,0x64900200,0x8f340e58}},	//   _tañi, _apps_, _kçir, _селц, 
   {{0x26d12ccc,0xa7f8030a,0x3cfc02e5,0xedd404b4}},	//   xoxo_, _kañv, _रूके_, _иллә_, 
   {{0xceb8033f,0x7e9801d3,0x00000000,0x00000000}},	//   mię_, _سنٹر_, --, --, 
   {{0xb4bc02f8,0xceb92ccd,0x673c0455,0xa5640133}},	//   ीको_, lię_, tuqj, ێدان, 
   {{0xd36449c6,0x58852cce,0x39580221,0xa7f8030a}},	// [1cfd0] _بۇ_, шыра, _epps_, _lañv, 
   {{0xceb8068f,0xd628026a,0x94740344,0x673c0455}},	//   nię_, кође_, یدنا, ruqj, 
   {{0xa8501cd1,0x39580142,0x8438007b,0xa7f80055}},	//   _кенә, _gpps_, فكار_, _nañv, 
   {{0xd4e402bf,0xb3ac00cc,0x00000000,0x00000000}},	//   аючи, _ছুইজ, --, --, 
   {{0xd7f8084c,0xf31800fd,0x7d0c00d7,0x00000000}},	//   _аур_, енчә_, _časm, --, 
   {{0xdce4012c,0x98b800e2,0x212412ea,0x4f380092}},	//   _brně, murā_, نيتی_, _በሐዋር, 
   {{0xceb8012d,0x9128007b,0x00000000,0x00000000}},	//   dię_, نسيق_, --, --, 
   {{0xa7f80156,0xddc00311,0x00000000,0x00000000}},	//   _dañv, _lanţ, --, --, 
   {{0x2bd005dc,0xceb8033f,0xb2740131,0x00000000}},	//   _धुला, fię_, _өктә, --, 
   {{0xceb8033f,0xa3d0023b,0xa03000ec,0x00000000}},	//   gię_, _боғч, _چواڻ, --, 
   {{0x29100211,0xc11410fc,0xeb94023b,0x00000000}},	//   _ntxa_, _смеј, қир_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xceb8068f,0xef0d2ccf,0xa7f80113,0xb3f40882}},	//   bię_, _ым_, _kañu, _kṣaṇ, 
   {{0xdc142523,0xe8f400d1,0x00000000,0x00000000}},	//   rğız, ғлу_, --, --, 
   {{0xa7f80077,0xa9a12cd0,0x7e60257c,0x36940220}},	//   _mañu, бирд, melp, қшас, 
   {{0x66180384,0xa7f80694,0x7e612cd1,0x00000000}},	//   _đuka, _lañu, lelp, --, 
   {{0xe73504cd,0x16146923,0xbde402dd,0x8724007b}},	// [1cfe0] лет_, لساڭ, _ﺃﻓﻀل_, لعلم, 
   {{0x7e612cd2,0xa7f81bce,0x6b6000c7,0x00000000}},	//   nelp, _nañu, _укьа, --, 
   {{0x7afc009a,0x672005ce,0x39580036,0x1fcc00cc}},	//   _iipt, ćnja, _upps_, াইটস, 
   {{0x7e60560b,0x7afc0200,0x6ee406ea,0x00000000}},	//   help, _hipt, iðba, --, 
   {{0xa7f82e65,0x7e612cd3,0x7afd2cd4,0x07f811ca}},	//   _bañu, kelp, _kipt, _ахры_, 
   {{0xa7f92cd5,0x7e60168c,0x925836dd,0x7afc0200}},	//   _cañu, jelp, такт_, _jipt, 
   {{0x7e612cd6,0xa7f81574,0xc5f40801,0x35a40107}},	//   delp, _dañu, _вятъ, _савг, 
   {{0x7afd2cd7,0xceb8033f,0xa0a00220,0xb3f400b8}},	//   _lipt, wię_, йшыл, _eṣaṇ, 
   {{0xa7f8002e,0x7afc00e4,0x649000a2,0xceb92c9e}},	//   _fañu, _oipt, _içip, tię_, 
   {{0x7afc02d1,0xa7f80156,0xe3b42d29,0x00000000}},	//   _nipt, _tañv, _сбу_, --, 
   {{0xceb8068f,0x3eb8180f,0x00000000,0x00000000}},	//   rię_, èsta_, --, --, 
   {{0xceb92536,0x3084030d,0xa3c801f9,0x00000000}},	//   się_, _сăмс, रॅक_, --, 
   {{0x5f7004d3,0xceb80034,0xddc00356,0x2078010f}},	//   _هاور, pię_, _panţ, _ראדא, 
   {{0x7afd2cd8,0x7e6002d0,0x70500244,0x00000000}},	//   _cipt, celp, _ئۆکا, --, 
   {{0x195820e2,0x14d400dc,0xa2b400dc,0xdeb4011a}},	//   лары_, धकाण, ्चत्, _תפוח_, 
   {{0x48152cd9,0x6b881bce,0x98b92cda,0x35bc00fe}},	//   рмас, _àggo, turā_, _অৰ্হ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [1cff0] --, --, --, --, 
   {{0x57f43cc5,0xd7f8009d,0x00000000,0x00000000}},	//   спут, уус_, --, --, 
   {{0xe970009f,0x00000000,0x00000000,0x00000000}},	//   _انجھ, --, --, --, 
   {{0xddc12cdb,0xa7f800e8,0x88a003e6,0x7e6001f5}},	//   _janš, _sañu, _بیرۆ, zelp, 
   {{0xf8b52cdc,0xa7f800eb,0xe19005f5,0xddc12cdd}},	//   _төр_, _pañu, өлдө, _manš, 
   {{0xa7f80784,0x7afc00cf,0x7e602e13,0xddc003ca}},	//   _qañu, _xipt, xelp, _lanš, 
   {{0x7e6001f5,0x95c8011c,0x00000000,0x00000000}},	//   velp, _бута_, --, --, 
   {{0xa7f80bf1,0x7e61026e,0x98b80311,0x1dcc00dc}},	//   _wañu, welp, mură_, _सुगत, 
   {{0xa7f80165,0x2164e2d2,0x00000000,0x00000000}},	//   _gañt, тиқи_, --, --, 
   {{0x0fe8005e,0xa7f8030a,0x00000000,0x00000000}},	//   ылық_, _hañs, --, --, 
   {{0xcee805d4,0x7e612cde,0x7afd2cdf,0xa7f8030a}},	//   درين_, relp, _ript, _kañs, 
   {{0x7afc6d9d,0x00000000,0x00000000,0x00000000}},	//   _sipt, --, --, --, 
   {{0xcee82ab4,0xa7f8030a,0xb8640cbb,0xddc00010}},	//   ضرین_, _mañs, یارو, _danš, 
   {{0xa7f80489,0x7afc31c5,0x7e607769,0x68e0036e}},	//   _lañs, _qipt, qelp, _ëndj, 
   {{0x610001ed,0xb6000306,0xfbd0012c,0x7afd2ce0}},	//   _főle, šáko, _सडकम, _vipt, 
   {{0x8d74168d,0x98b80276,0x05d8012c,0x6cd0007b}},	//   _داها, dură_, _बुधब, _وقوا, 
  
   {{0x7afd2ce1,0xf7452ce2,0xe8fc003a,0xb8cc00af}},	// [1d000] _tipt, резо, _diû_, _कत_, 
   {{0xe61404a9,0xd1bc001f,0x98b8054e,0x17c4035b}},	//   иду_, ሳሰብ_, fură_, _ҳамҭ, 
   {{0x98b80276,0xa7f80165,0x05d80307,0xddcc00a2}},	//   gură_, _bañs, _बुदब, _ýeńl, 
   {{0xed5400c8,0x00000000,0x00000000,0x00000000}},	//   יבער_, --, --, --, 
   {{0xa7f80489,0xf8e001f9,0x3870010b,0x00000000}},	//   _dañs, पतीप, mdyr_, --, 
   {{0x38712ce3,0x00000000,0x00000000,0x00000000}},	//   ldyr_, --, --, --, 
   {{0xe2942850,0x98b80276,0xceb801e0,0x30a52ce4}},	//   рај_, cură_, һәк_, ирив, 
   {{0x38712ce5,0xa7f8030a,0x7c340240,0x60d00451}},	//   ndyr_, _gañs, _ndyr, يزيء, 
   {{0xceb818ce,0xdb24020c,0xa1c00139,0x00000000}},	//   ләк_, _èsèn, йбәд, --, 
   {{0xa7f80156,0x3870010e,0x00000000,0x00000000}},	//   _zañs, hdyr_, --, --, 
   {{0x387000ee,0xd1e4247f,0xa2d000f1,0xb3f400b8}},	//   kdyr_, _اياۋ, _بيلت, _kṣoṇ, 
   {{0x387045f3,0x00000000,0x00000000,0x00000000}},	//   jdyr_, --, --, --, 
   {{0xa7f80165,0x7c3403cb,0x38701368,0x98b80356}},	//   _lañr, _ddyr, ddyr_, zură_, 
   {{0x78a403ac,0x29044a16,0x38700076,0x5fac0412}},	//   _alkv, _énak_, edyr_, _जेटल, 
   {{0xcfd9161d,0x610001d3,0xddc000a2,0x9d4000d8}},	//   দেশন, _tőle, _tanš, _дејд, 
   {{0x5df80375,0x1dcc0073,0x98b80356,0x38707edc}},	//   _בפונ, _सुटत, vură_, gdyr_, 
   {{0x1799226f,0x7d0c09a8,0xa7f8002e,0x1bb800db}},	// [1d010] авты_, _časi, _rañs, _پايع_, 
   {{0x98b800a8,0xa7f92ce6,0x5724568c,0x00000000}},	//   tură_, _sañs, تىكك, --, 
   {{0xa2b405cd,0xa7f80165,0x00000000,0x00000000}},	//   ्चस्, _pañs, --, --, 
   {{0x833414af,0xe3b01bf4,0x1dcc0037,0x00000000}},	//   مرتض, يرش_, _सँघत, --, 
   {{0x94743fb8,0x98b80276,0x5924025c,0x62b40032}},	//   تدلا, sură_, _འཆོས_, ағас_, 
   {{0xa7f800e8,0x98b80356,0x888000f1,0x73c0008e}},	//   _wañs, pură_, _بیړن, чәсе, 
   {{0xa7f92ce7,0x00000000,0x00000000,0x00000000}},	//   _tañs, --, --, --, 
   {{0x26c40232,0xe4a41614,0x7cd00882,0xd43400ae}},	//   čnou_, _трго, mārg, _وعقب, 
   {{0x6458009a,0xe3bc0166,0xe81c0037,0x00000000}},	//   _ibui, _äñ_, _बभना_, --, 
   {{0x91fc00e2,0xbea800ec,0x00000000,0x00000000}},	//   _paāt, اهدن_, --, --, 
   {{0x38700209,0xdce400b8,0xc1040592,0x59240327}},	//   ydyr_, _asnā, _اوصي, _འཆེས_, 
   {{0x64580175,0x31b80375,0xa6bc00fe,0xd1b80131}},	//   _jbui, _גזענ, ্তিয়, _ئاكا_, 
   {{0x201d2ce8,0xed4c2a60,0x38700a64,0x645800ae}},	//   mbui_, وپی_, vdyr_, _mbui, 
   {{0xbda8007b,0x201c0356,0x4fc000d1,0x00000000}},	//   _مطعم_, lbui_, _زەپە, --, 
   {{0x64592ce9,0x395c00f7,0x499800d6,0x387000ee}},	//   _obui, ïts_, аття_, tdyr_, 
   {{0x201c371a,0x3b84368e,0x7c348b98,0x98b80064}},	//   nbui_, _глиг, _udyr, kurą_, 
   {{0x38700209,0x68ec0009,0xa2600419,0x00000000}},	// [1d020] rdyr_, _dhcd, _krôč, --, 
   {{0x64581c1d,0x98b80210,0x00000000,0x00000000}},	//   _abui, durą_, --, --, 
   {{0x387009a5,0xeba80162,0x580402dd,0x6eb800df}},	//   pdyr_, _trøð_, _монғ, נצעס, 
   {{0x645800a3,0x68ec0076,0xb384e695,0xe5f0007b}},	//   _cbui, _ghcd, йлел, سكند, 
   {{0x84542002,0x645800a3,0x98b800e2,0x377401ee}},	//   تىنچ, _dbui, strē_, _уынс, 
   {{0x645803ac,0x201c003a,0xa7f80432,0x00000000}},	//   _ebui, ebui_, _tañr, --, 
   {{0xa6c41968,0xf594007b,0x00000000,0x00000000}},	//   _اوّل_, _الزج, --, --, 
   {{0x201c017a,0x2c7c0139,0x98b800c0,0x74b800d8}},	//   gbui_, _mädä_, burą_, _сугс_, 
   {{0xf1880046,0x43744131,0xa7f80309,0xa0640640}},	//   _әйел_, _муфт, _yañq, сања_, 
   {{0x91c40075,0x6ee40d12,0x00000000,0x00000000}},	//   _мәйл, rðbo, --, --, 
   {{0x201c01ab,0x7114030d,0x00000000,0x00000000}},	//   bbui_, _уçла, --, --, 
   {{0x64580175,0x683c0241,0x802400cf,0x200000e5}},	//   _xbui, _màdà, _ۇرۇم, _ٹِوِ, 
   {{0x0a4002d3,0x9b592cea,0x5924031c,0x68e000e8}},	//   _ንምርካ, бият_, _འཆུས_, _ëndi, 
   {{0x2c7c0139,0x5f900107,0x00000000,0x00000000}},	//   _bädä_, _хишт, --, --, 
   {{0xa8a46afe,0x2c7c0139,0x6e280857,0xbebc00e2}},	//   брак, _cädä_, _iefb, rsūt, 
   {{0x25ec4d53,0xddc80113,0x6e280373,0x1ac802dd}},	//   _अरबी_, _ñišu, _hefb, _қуып_, 
   {{0x2d9d2ceb,0x388c0240,0x00000000,0x00000000}},	// [1d030] lyte_, _ነገራቱ_, --, --, 
   {{0xd1ec0201,0x683c01e1,0x2d9c0e14,0x645801ab}},	//   ህርት_, _bàdà, oyte_, _sbui, 
   {{0xd6d85d77,0x889400a6,0x24740092,0x7cd000ef}},	//   ёту_, _динх, _በምርት_, bārd, 
   {{0xe78465cb,0x98b8012d,0x7cd00055,0x00000000}},	//   _луго, turą_, cārd, --, 
   {{0x05d82d8f,0x99580118,0x00000000,0x00000000}},	//   _बुरब, máše_, --, --, 
   {{0xb06000ee,0x6e2802d2,0x99580118,0x2d9c0064}},	//   ýäni, _nefb, láše_, kyte_, 
   {{0x683c0241,0x645801ab,0x91fc00ef,0x201c0051}},	//   _gàdà, _tbui, _saār, tbui_, 
   {{0x7f5803b7,0x64592cec,0xbf5800d4,0x00000000}},	//   ајот_, _ubui, арої_, --, 
   {{0x3f98025a,0x6b880268,0x94a92ced,0x201c0024}},	//   âsu_, _àggh, _утра_, rbui_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x64480395,0x2d9c0024,0xa058007b,0x00000000}},	//   oggi, gyte_, _مؤشر_, --, 
   {{0x644880bb,0x7cd00882,0x71d40a1e,0x6e2803ac}},	//   nggi, kāre, _וועד_, _eefb, 
   {{0xee2d2cee,0x60d92cef,0x7cd000da,0x10840022}},	//   _он_, moum, vārd, _хҩык_, 
   {{0x64480175,0x4ab800d4,0x00000000,0x00000000}},	//   hggi, буся_, --, --, 
   {{0x4e840014,0xed540212,0x2d9d2cf0,0x05d801ad}},	//   _رٔٹٕ, _дощ_, cyte_, _बुलब, 
   {{0x60d8006f,0x683c01e1,0x6248010e,0x00000000}},	//   noum, _ràdà, _ỳold, --, 
   {{0xb6340b24,0x7cd01da6,0x3f8c004e,0xd1ec069d}},	// [1d040] قعات, gāre, nxeu_, ህርተ_, 
   {{0x41c80574,0x60d90e91,0x3f8c004e,0x64480076}},	//   िपास, houm, ixeu_, eggi, 
   {{0x60d92cf1,0x7cd01c52,0x59240327,0x2508006c}},	//   koum, pārd, _འཆིས_, لرنی_, 
   {{0xe7e000c5,0x00000000,0x00000000,0x00000000}},	//   _खरचा_, --, --, --, 
   {{0x60d80552,0x0fc40154,0x2d9c4f7e,0x7cd000cd}},	//   doum, _ঊর্ধ, zyte_, cāre, 
   {{0x64480801,0xe7242c08,0xd1ec010c,0x2d9c005b}},	//   aggi, _форд_, ህርቱ_, yyte_, 
   {{0x6e283fc4,0xeb9c005c,0xf4280006,0xcf900014}},	//   _refb, ncør_, _вобл_, کژا_, 
   {{0x60d80165,0xa50400d8,0x00000000,0x00000000}},	//   goum, _фета_, --, --, 
   {{0x4910007d,0x23481968,0xb4d40073,0x00000000}},	//   _दूनो_, _نسلی_, हवी_, --, 
   {{0x81d82b1b,0x2d9c0024,0x59bcb1e3,0x00000000}},	//   ঠেই_, tyte_, ोपार, --, 
   {{0xd1ec069c,0x60d92cf2,0x6e28032e,0xa2d40303}},	//   ህርቲ_, boum, _vefb, मकर्, 
   {{0x7d0c03c6,0x60d80077,0x2d9d2cf3,0xd9e40037}},	//   _čast, coum, ryte_, _गरजत_, 
   {{0xe4f8008f,0xeb04003b,0x00000000,0x00000000}},	//   יפטש, ючно, --, --, 
   {{0x9a852cf4,0xfa240011,0x2d9c0124,0x90e40345}},	//   мусл, _বাউল_, pyte_, _بسڕن, 
   {{0x64480321,0x28c4242e,0x94040085,0xcda800aa}},	//   yggi, रचलि, _pomɛ_, _دهغه_, 
   {{0x7cd12cf5,0xa3bc2356,0xd874009a,0x00000000}},	//   tāre, ुपम_, واقب, --, 
   {{0x6ab003d4,0x00000000,0x00000000,0x00000000}},	// [1d050] ঁচবো, --, --, --, 
   {{0x60d8159f,0xea6002dd,0x7cd00374,0x386400df}},	//   zoum, _تۇسپ, rāre, ĵora_, 
   {{0xd6d8160b,0x5924031c,0x255400bc,0x60d8037e}},	//   іту_, _འཆགས_, dělá_, youm, 
   {{0xd1d00020,0x60d80077,0x7cd01d76,0x437400cf}},	//   እክት_, xoum, pāre, зукт, 
   {{0x60d92cf6,0x38ac0174,0xe8c40073,0x73c00ce8}},	//   voum, _dýrd_, रचीच, нәфе, 
   {{0x7eac01a2,0xe814012c,0x48f4012c,0x82340214}},	//   _kúpe, धुरा_, ्दको_, سرتا, 
   {{0x60d92cf7,0xd55400a7,0x3ea400d1,0x00000000}},	//   toum, _окръ, җинг, --, 
   {{0x04c835f9,0x00000000,0x00000000,0x00000000}},	//   _اوري_, --, --, --, 
   {{0x60d92cf8,0x91fc002b,0x317c009d,0x6d4c026c}},	//   roum, _abād, _ertz_, àban, 
   {{0x442d2cf9,0x2cb40156,0x60d92cfa,0x3f8cd829}},	//   _hee_, _བཏུབ, soum, rxeu_, 
   {{0x442d24af,0xfce451a7,0x317c0d27,0x60d87320}},	//   _kee_, зоно, _grtz_, poum, 
   {{0x442c02a4,0xed540212,0x7f940108,0x00000000}},	//   _jee_, чою_, _наех, --, 
   {{0x442d2cfb,0x2d88008e,0x7074275c,0x00000000}},	//   _mee_, äber_, _رموز_, --, 
   {{0xfaa52cfc,0x442c0c30,0x7eac02d2,0x00000000}},	//   чаго, _lee_, _búpe, --, 
   {{0x442c07de,0x00000000,0x00000000,0x00000000}},	//   _oee_, --, --, --, 
   {{0x442d2cfd,0x6d380375,0xd1d00023,0x72600023}},	//   _nee_, _התקנ, _እኩብ_, ደበታዊ_, 
   {{0x237c0211,0xed1401ed,0x684002d5,0xb6a52cfe}},	// [1d060] _nruj_, _وہیں_, энта, пиал, 
   {{0x442d2cff,0x6b7825f9,0x64900790,0xd5b01c3b}},	//   _aee_, _פרינ, _içiy, پہر_, 
   {{0x6a980375,0x255400bc,0x442c26de,0x00000000}},	//   _השינ, vělá_, _bee_, --, 
   {{0x442d2d00,0x7f480140,0x00000000,0x00000000}},	//   _cee_, kueq, --, --, 
   {{0x442ccdba,0xb3f4002b,0x66180205,0x00000000}},	//   _dee_, _kṣiṇ, _şuke, --, 
   {{0xd13097f7,0xd6a802f2,0x20640022,0x00000000}},	//   نمت_, _بگرم_, ҧшып_, --, 
   {{0x442c3d4a,0x237c0010,0x00000000,0x00000000}},	//   _fee_, _eruj_, --, --, 
   {{0x442d2d01,0x66184ca5,0x98b80034,0x40e401ec}},	//   _gee_, _đuki, turę_, мсығ, 
   {{0x7f480194,0xff1400b5,0x845400db,0x324400c0}},	//   gueq, gの_, _تىقچ, _неаг, 
   {{0x72440150,0xc30416ac,0x2aac013d,0xa798011a}},	//   _ءپال, _قبلو, _kübe_, משפח, 
   {{0x442c75c9,0x6e3c0020,0x317c01c4,0xdeec0166}},	//   _yee_, _በአግባ, _urtz_, _җы_, 
   {{0xd6c40729,0x7eac004e,0xfcc00022,0x14dc01f9}},	//   ্তিয, _rúpe, кәым, बविण, 
   {{0x7ead2d02,0x9b58084c,0xaff91488,0xd1d00023}},	//   _súpe, пият_, _افشا_, እክቲ_, 
   {{0xbe3000c7,0x00000000,0x00000000,0x00000000}},	//   _иҕьы, --, --, --, 
   {{0xa8a52d03,0xdcf80af6,0x2f100142,0x624800a2}},	//   прак, تریش_, _hâg_, _ỳokd, 
   {{0xb3f40055,0x00000000,0x00000000,0x00000000}},	//   _eṣiṇ, --, --, --, 
   {{0x442d2d04,0x666403cf,0x5ba400c0,0x00000000}},	// [1d070] _ree_, зъез, _зрэз, --, 
   {{0x7cd12d05,0x9bf52d06,0x394800ef,0x00000000}},	//   māra, _языч, bubs_, --, 
   {{0x442d2d07,0xe5052d08,0xd7f020ea,0x7cd01a14}},	//   _pee_, سباي, پكە_, lāra, 
   {{0x442c0457,0x00000000,0x00000000,0x00000000}},	//   _qee_, --, --, --, 
   {{0x442d2d09,0x7cd10ea1,0x932400d1,0x00000000}},	//   _vee_, nāra, ىرون, --, 
   {{0x442d2d0a,0xe66407d6,0xfd540055,0x6b8800e8}},	//   _wee_, _этмо, _evaṅ, _àggu, 
   {{0x7cd00a28,0xff14037e,0x6d4c00a3,0x90e401e2}},	//   hāra, wの_, àbal, کسون, 
   {{0x7cd00a28,0x442d2d0b,0x00000000,0x00000000}},	//   kāra, _uee_, --, --, 
   {{0x7eac28ed,0x995802f0,0xbffc0154,0x00000000}},	//   _núpc, _máša_, ীর্ণ_, --, 
   {{0x4ca4015b,0xfeb81291,0x00000000,0x00000000}},	//   খোমু, تابت_, --, --, 
   {{0x7f48013c,0xed1401ed,0x51840063,0x415401f4}},	//   sueq, وہوں_, _пуца, _цвес, 
   {{0xa2b40882,0xe45c00c5,0x7f480393,0x49100037}},	//   ्चक्, _ööd_, pueq, _दूधो_, 
   {{0x7f48daf0,0x9b0401f0,0x9f8400fb,0x833400df}},	//   queq, нҷид, _халҡ_, ואָס_, 
   {{0x3dc40323,0x6ee403b2,0x00000000,0x00000000}},	//   _ойлг, yðbi, --, --, 
   {{0xf33c0023,0x00000000,0x00000000,0x00000000}},	//   _ኣይትሓ, --, --, --, 
   {{0xbebc0024,0xfaa4013e,0x39480f85,0x2aac002f}},	//   spūd, чаҳо, rubs_, _rübe_, 
   {{0x7cd00882,0x995802f0,0x6ff8010f,0x00000000}},	// [1d080] cāra, _dáša_, ַהעפ, --, 
   {{0x35880451,0x35a464c2,0x7c240112,0xfd540055}},	//   ينءَ_, мазг, lbkr, _svaṅ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x49000323,0x2ea8068f,0x64a00153,0x00000000}},	//   _бүсг, _छत्त, каха, --, 
   {{0x8e7c01e4,0x5784013d,0x00000000,0x00000000}},	//   loĝe, _яңав, --, --, 
   {{0x68e002d3,0xdb0800f2,0x70d401ad,0x7cf431b7}},	//   _ëndr, èlèh, डक्ल, lárd, 
   {{0x7cf4056a,0x6600824d,0xfd5400b8,0xe61400d8}},	//   cárg, _апра, _tvaṅ, _цдс_, 
   {{0x7bd49e91,0xa1800166,0x00000000,0x00000000}},	//   _oxyu, тышл, --, --, 
   {{0xb4d80254,0xdf1401ed,0x80b000db,0x00000000}},	//   ठकी_, وڑوں_, دەنش, --, 
   {{0x7cd00882,0x62603ed6,0xbffc00fe,0xd01000f1}},	//   vāra, _ивуа, ীৰ্ণ_, خلک_, 
   {{0x52bc00ce,0x7bd82ca8,0x00000000,0x00000000}},	//   ्चीस, ştul, --, --, 
   {{0x7cd12d0c,0x4c9400ee,0x4bb40229,0x21a001d5}},	//   tāra, химс, еймс, _шихм, 
   {{0x9be400d6,0xc61400eb,0x00000000,0x00000000}},	//   вірк, িরতা_, --, --, 
   {{0x7cd12d0d,0x81d800fe,0xf33c0023,0x00000000}},	//   rāra, ঠেও_, _ኣይተሓ, --, 
   {{0x7cd00882,0x7c380174,0x00000000,0x00000000}},	//   sāra, ábrú, --, --, 
   {{0x7cd00882,0x7eac00ae,0x7cf400e5,0x00000000}},	//   pāra, _iúpa, várg, --, 
   {{0xb7852d0e,0x6d5829a8,0x7eac00d0,0x995800d7}},	// [1d090] нәре_, ltta, _húpa, _váša_, 
   {{0x6d583219,0x7eac01f1,0x49752d0f,0x25a80b6c}},	//   otta, _kúpa, _злос, يداي_, 
   {{0x7c441125,0x00000000,0x00000000,0x00000000}},	//   _ítró, --, --, --, 
   {{0x6d580664,0x69d4031c,0x7cf400d8,0x6b88002e}},	//   itta, _ixxe, cárd, _àggs, 
   {{0x27fc07ea,0x6d592d10,0x7eac0419,0xf8b400d9}},	//   _àun_, htta, _lúpa, _נפשי_, 
   {{0x6d587c1d,0x92641c02,0x051c00fe,0x00000000}},	//   ktta, ندىم, _পটীৰ_, --, 
   {{0x6d592d11,0xdbfc04af,0x38ac0162,0x47e0009e}},	//   jtta, _एण्ड_, _hýra_, পেশী, 
   {{0x69d40327,0xbf1000d1,0x6d5801bf,0x38ac032e}},	//   _mxxe, гүдә, dtta, _kýra_, 
   {{0x6d592d12,0xc2c40220,0x7cf413d5,0x41b400f1}},	//   etta, _كيري, náre, _ګمار, 
   {{0x2d7c0135,0x69d4031c,0x7f9400c7,0xd2500372}},	//   _bċe_, _oxxe, даҩх, _ەنە_, 
   {{0xee340323,0x6d58037e,0xed5430e3,0xfde89785}},	//   энэ_, gtta, ноэ_, ядок_, 
   {{0x7cf42b57,0x7fd40006,0x5f7418fd,0x9f80014b}},	//   káre, _пілі, _ياشر, _аҳид, 
   {{0x6d592d13,0x69d4031c,0x7cf4e9f0,0x38ac02d2}},	//   atta, _axxe, járe, _nýra_, 
   {{0x6ee40008,0x7cf41a03,0x3f58068c,0x7e740137}},	//   fðbu, dáre, mèu_, _ساتئ, 
   {{0x6d58074d,0xddc07dfd,0x38ac0432,0x3f58180f}},	//   ctta, _hanž, _aýra_, lèu_, 
   {{0xa7f80022,0xcc34035b,0xd1440023,0x59740150}},	//   _hañy, _ихьы, _ከይበል, нығу, 
   {{0x69d40548,0xa7f80022,0x7b7400c6,0xdb08007b}},	// [1d0a0] _exxe, _kañy, _أطبا, úlói, 
   {{0xddc003c6,0x7cf401a8,0x38ac0321,0x00000000}},	//   _manž, sárd, _dýra_, --, 
   {{0xe5a0016c,0x3a045007,0xa7f800a2,0xddc001ef}},	//   лифи, _سکسی_, _mañy, _lanž, 
   {{0x38ac0579,0x17c40588,0x7cf404d4,0x00000000}},	//   _fýra_, _аамҭ, báre, --, 
   {{0x5704035b,0xf2e401ca,0xb9fc0092,0x00000000}},	//   _аҟаз, нюко, _ሁላ_, --, 
   {{0x6d58b529,0x3f580ba1,0xe728031c,0xc32c0131}},	//   ytta, dèu_, _སྦྲན_, تەك_, 
   {{0xc310015b,0xdd0c0171,0x55c40107,0x6d584e3c}},	//   _সৌদি_, _džūl, _равғ, xtta, 
   {{0xb1440e26,0x3f580ba1,0x00000000,0x00000000}},	//   _үнал, fèu_, --, --, 
   {{0x68e12d14,0xf58c0150,0x3f58068c,0xb384e1fa}},	//   _índe, _ءﺷﻮﺑ, gèu_, _ялал, 
   {{0x7eac0419,0x15f40037,0x00000000,0x00000000}},	//   _púpa, _अरार_, --, --, 
   {{0x6d592d15,0x6140a7f2,0xa7f8010e,0xd9e00406}},	//   utta, _беха, _dañy, _खुलत_, 
   {{0x6d592d16,0x00000000,0x00000000,0x00000000}},	//   rtta, --, --, --, 
   {{0x3f58180f,0x1b8801f0,0x5f8000d1,0x00000000}},	//   cèu_, нёро_, _مۇيە, --, 
   {{0x98c42c1d,0x7cf402fb,0x7eac00e4,0x38ac032e}},	//   ҳсул, váre, _túpa, _rýra_, 
   {{0x082403bd,0x7eac0030,0x38ad2d17,0x7cd000b8}},	//   _འབདཝ_, _kúpn, _sýra_, cāro, 
   {{0xb4d8038e,0x315002d3,0x2e4401e1,0x38ac00e4}},	//   ठको_, _ዘይተር, _fífà_, _pýra_, 
   {{0xf4140154,0xe7a40116,0x00000000,0x00000000}},	// [1d0b0] ারার_, رۇسى_, --, --, 
   {{0x7cf40306,0x00000000,0x00000000,0x00000000}},	//   ráre, --, --, --, 
   {{0x15a800a7,0x7cf52d18,0x7bd4054e,0xc5e800eb}},	//   нъци_, sáre, ăguţ, কেনা_, 
   {{0x7cf425e6,0x38ac0022,0x00000000,0x00000000}},	//   márc, _týra_, --, --, 
   {{0x3208016b,0x291006ea,0xa3601e4a,0x00000000}},	//   ɛhyɛ_, _huxa_, اپتۇ, --, 
   {{0x291000f1,0x29092d19,0x6f080175,0x3f58180f}},	//   _kuxa_, _hica_, _nifc, vèu_, 
   {{0x96f807d8,0xa7f80022,0x2910058a,0x7170007b}},	//   _черт_, _rañy, _juxa_, لهوا, 
   {{0xd6c409bd,0xd1740032,0x3f58068c,0x008401b9}},	//   ্তৃপ, уышы, tèu_, тлио, 
   {{0x29092d1a,0x291108e0,0x2d8800b5,0x7cf401e7}},	//   _mica_, _luxa_, åben_, hárc, 
   {{0x3f58180f,0x7bd80790,0x8e747a9c,0x00000000}},	//   rèu_, ştuk, гуюч, --, 
   {{0x249c0a40,0x6f080393,0x3f58180f,0x4d152d1b}},	//   _koum_, _difc, sèu_, льят, 
   {{0x249c007f,0x3f581497,0x7cf42fda,0xd0d4010a}},	//   _joum_, pèu_, dárc, _йохъ, 
   {{0xeb9507e2,0xb1100521,0xa7f800c7,0x3eb8067c}},	//   вия_, rụed, _tañy, èsts_, 
   {{0x4a74005e,0x2908011c,0x29100429,0xf77001ed}},	//   лыст, _aica_, _buxa_, یاء_, 
   {{0x29092d1c,0x29101709,0x8d8400ec,0x00000000}},	//   _bica_, _cuxa_, _مشين, --, 
   {{0x29092d1d,0x7cf401ed,0x3b852d1e,0x249c007f}},	//   _cica_, sárb, _алиг, _noum_, 
   {{0x29092d1f,0xb6680020,0x15f400af,0x5924031c}},	// [1d0c0] _dica_, _አማርኛ_, _अरहर_, _འཆམས_, 
   {{0xc794abc6,0x7cf40077,0x2aac04cc,0xba7400be}},	//   ырсы, bárc, _tüba_, _شاخت, 
   {{0x200c0c04,0x29092d20,0x249d2d21,0xcd401954}},	//   _oggi_, _fica_, _boum_, _ተደናገ, 
   {{0x29081459,0x200c006c,0x249d2d22,0xbb2c0952}},	//   _gica_, _nggi_, _coum_, ﻧﮕﻪ_, 
   {{0x249d2d23,0x80dc015b,0x59bc00dc,0xa80006b9}},	//   _doum_, মগঞ্, ोपकर, şırs, 
   {{0x29092d24,0xe73415ed,0x249c003a,0xc32c08c9}},	//   _zica_, _јер_, _eoum_, سەم_, 
   {{0x290801b2,0x29100120,0x7f492d25,0xf0740116}},	//   _yica_, _xuxa_, ereq, вийә_, 
   {{0x64a06777,0x7f492d26,0x2908004e,0xdbf800b8}},	//   _каса, freq, _xica_, _lāñc, 
   {{0x64a12d27,0xa064026a,0x6f08003a,0x7f480393}},	//   _тата, тања_, _pifc, greq, 
   {{0x3c30431d,0x200d2d28,0x249c05c7,0x31240064}},	//   _được_, _eggi_, _zoum_, _аджг, 
   {{0x7f480869,0x3eb801f5,0xe2940faf,0x78b401e3}},	//   areq, ësta_, _шаф_, khyv, 
   {{0x9e00cced,0x6ca43de9,0x7f48b4a2,0x67e0063f}},	//   шчыл, трож, breq, ọjis, 
   {{0xe0b404ac,0xdb592d29,0xdb24022c,0x7f48056a}},	//   _בלאט_, кюр_, ørðu, creq, 
   {{0xdfcc7cbc,0x29100120,0x7cf401d3,0x70a00037}},	//   _بيه_, _puxa_, tárc, _ओकुल, 
   {{0xda349416,0x19582f26,0x200c0036,0xdd8c0753}},	//   ресы, кары_, _yggi_, _ووه_, 
   {{0x29100564,0x2ba403f6,0xe7840798,0x00000000}},	//   _vuxa_, _ајов, кузо, --, 
   {{0x290803b4,0xc6f8c8cb,0x249d2d2a,0x29100009}},	// [1d0d0] _vica_, енах_, _roum_, _wuxa_, 
   {{0x42800020,0x29092d2b,0x29100077,0x249c020c}},	//   ካኝነት_, _wica_, _tuxa_, _soum_, 
   {{0xe7e0038e,0x249d2d2c,0x7cf52d2d,0x39480120}},	//   _कुरा_, _poum_, lára, crbs_, 
   {{0x78b402d5,0x48c40598,0x7f480194,0x321c05d6}},	//   chyv, _сәга, yreq, _afty_, 
   {{0x7eac0162,0x249c0100,0x7cf52d2e,0x00000000}},	//   _búpl, _voum_, nára, --, 
   {{0x7eac0597,0x130802bf,0x7b3400df,0x00000000}},	//   _cúpl, вній_, אָקע_, --, 
   {{0x7ead2d2f,0x1a9c008f,0x7cf4035b,0x6ee40174}},	//   _dúpl, ויגע, hára, yðbr, 
   {{0x7cf447f1,0x00000000,0x00000000,0x00000000}},	//   kára, --, --, --, 
   {{0x7cf52d30,0xed5401d5,0x626400f2,0xb4b401ee}},	//   jára, қоя_, _لااق, _ситә, 
   {{0x7cf40077,0xddc00327,0x386401e4,0x00000000}},	//   dára, _tanż, ĵori_, --, 
   {{0x3cc80697,0x200c05b1,0x7f480175,0xafe001d5}},	//   елно_, _tggi_, sreq, _қошл, 
   {{0xcd292d31,0x200c03b2,0x7f480175,0x66180139}},	//   کسین_, _uggi_, preq, _şukl, 
   {{0x7f44d964,0x6ee401a8,0xe7e005dc,0xdbf800dc}},	//   _селж, rðbr, _कुला_, _pāñc, 
   {{0x6e2c01a9,0xdbdc013a,0x00000000,0x00000000}},	//   аbbu, _ušíc, --, --, 
   {{0x3914034c,0xa964074d,0xfce433d2,0xdd8c00ec}},	//   اورز, лира_, _йоко, _ڇوڙ_, 
   {{0xc8b402dd,0x38ac0124,0x1ea400ec,0x7cf4299d}},	//   асуы, _výro_, _ساڙي_, bára, 
   {{0x778407dd,0x27b002d9,0x91fc0055,0x7cf404d4}},	// [1d0e0] ылаз, бәрс, _abāl, cára, 
   {{0x7c352d32,0x999800b0,0x6b8800e4,0x78b40108}},	//   _heyr, narū_, _ágga, shyv, 
   {{0x7c352d33,0x33240076,0x78b402d0,0x754400c7}},	//   _keyr, wpox_, phyv, унез, 
   {{0x7c340ea1,0x00000000,0x00000000,0x00000000}},	//   _jeyr, --, --, --, 
   {{0x13940212,0x38705dd8,0x00000000,0x00000000}},	//   рилю, meyr_, --, --, 
   {{0x85540b43,0xe2952d34,0x38701368,0xb6f800f7}},	//   _چیلر_, лач_, leyr_, _سىزا_, 
   {{0xb4246568,0x38700076,0x7cf52d35,0x00000000}},	//   _معذو, oeyr_, zára, --, 
   {{0x733403cc,0x38700363,0xa5049607,0xc1a401ec}},	//   _مىرا, neyr_, _беса_, рышқ, 
   {{0xddcc07f5,0xceb84a4e,0x3fc801b9,0xab58002f}},	//   _češa, кәк_, پگنی_, mzüg, 
   {{0x7cf52d36,0x3870090e,0xc18001d9,0xab58002f}},	//   vára, heyr_, _ڈیٖٹ, lzüg, 
   {{0x3870062c,0xe0cc0014,0x4c941420,0x00000000}},	//   keyr_, _کٲن_, аинс, --, 
   {{0xab5801ed,0x7c352d37,0x7cf52d38,0x00000000}},	//   nzüg, _ceyr, tára, --, 
   {{0x999005ce,0x7c352d39,0x38701368,0xab580112}},	//   _čaše_, _deyr, deyr_, izüg, 
   {{0x5b140b3e,0xdb2401d3,0xda78010a,0x5f400b24}},	//   смрт, ásáb, ляс_, _انول, 
   {{0x7cf52d3a,0x7c34058a,0xdd8c0408,0x3870058a}},	//   márn, _feyr, _уш_, feyr_, 
   {{0x6e392d3b,0x7cf52d3c,0x7c341368,0x387000ad}},	//   latb, lárn, _geyr, geyr_, 
   {{0xd79402e8,0x443800d7,0x66c80210,0x00000000}},	// [1d0f0] битъ, _ľs_, eżka, --, 
   {{0x7cf440cf,0x6e3801d3,0x7c3456f8,0x00000000}},	//   nárn, natb, _zeyr, --, 
   {{0x6008d95c,0x38712d3d,0xab580112,0x8574030d}},	//   _kömü, beyr_, fzüg, рлех, 
   {{0x81cc03f4,0x7c3400ac,0x6e3801f5,0x38700076}},	//   রথম_, _xeyr, hatb, ceyr_, 
   {{0x7cf40232,0x6e3801e3,0x27b001e0,0x600806be}},	//   kárn, katb, _уҙас, _mömü, 
   {{0x57d406ed,0x7cf402cc,0xb22000d4,0x00000000}},	//   _ѓорѓ, járn, омшл, --, 
   {{0x7cf40122,0x814404da,0xab58002f,0x85040330}},	//   dárn, شچان, bzüg, _نوسن, 
   {{0x999802b5,0x443802d2,0x00000000,0x00000000}},	//   warū_, _þs_, --, --, 
   {{0x6e3801fa,0x3eb801f5,0x00000000,0x00000000}},	//   fatb, ësto_, --, --, 
   {{0x7c352d3e,0x7cd00b3a,0x38700009,0x929400d8}},	//   _seyr, māri, zeyr_, _лауц, 
   {{0x7c352d3f,0xbca400c6,0x7cd000e2,0x7c292d40}},	//   _peyr, لمدي, lāri, конг_, 
   {{0x7c3403be,0xfc0400f3,0x00000000,0x00000000}},	//   _qeyr, ипно, --, --, 
   {{0x7c340c67,0x6e392d41,0x7cd0005f,0x38700076}},	//   _veyr, batb, nāri, veyr_, 
   {{0xab252d42,0xceb8068f,0x6e380784,0x41a80b6d}},	//   рора_, chę_, catb, _कथास, 
   {{0x7c345129,0x38701368,0x00000000,0x00000000}},	//   _teyr, teyr_, --, --, 
   {{0x7cd11bb0,0x82f4025c,0xf1b0008f,0x600851bb}},	//   kāri, _བེའུ_, קסן_, _gömü, 
   {{0xa7a52d43,0x7cf401f1,0x872400c6,0x36c40137}},	// [1d100] акта_, láro, معلم, абаг, 
   {{0x63a80267,0x3870d958,0xd37000d1,0xabf8011a}},	//   dygn, seyr_, ۋۇز_, _בהפר, 
   {{0x7cf41dee,0xab58002f,0x06d801af,0x00000000}},	//   náro, tzüg, уфты_, --, 
   {{0x7cf52d44,0x6e38b52b,0xe45c00c5,0x645836f4}},	//   iáro, zatb, _ööl_, _ccui, 
   {{0xf74415ed,0x1cac025c,0xab5803fa,0xc9d404fb}},	//   _њего, བྲག_, rzüg, _نمیک, 
   {{0x7cf4dce6,0xab580e78,0x6458054e,0x00000000}},	//   káro, szüg, _ecui, --, 
   {{0x23b40156,0x7cf52d45,0x6e3801ed,0xf504274b}},	//   དནཔཕ, várn, vatb, _взво, 
   {{0x64580491,0x63a83774,0x7cf52d46,0x2edc00cd}},	//   _gcui, bygn, dáro, नक्त, 
   {{0xe1f47b80,0x317009a5,0x7eac2959,0x7cf403f7}},	//   лгә_, ňyz_, _kúph, tárn, 
   {{0x600805d1,0x6e880114,0x03a801c8,0x021800c0}},	//   _sömü, тљив_, _صدقو_, _біць_, 
   {{0x7cf440cf,0xab5807de,0x00000000,0x00000000}},	//   rárn, zzüd, --, --, 
   {{0x7cf400dd,0x7eac00d2,0xf1e4002e,0xafe450c0}},	//   sárn, _lúph, _j斡me_, _коел, 
   {{0x6e392d47,0x7cf41bbf,0x00000000,0x00000000}},	//   patb, párn, --, --, 
   {{0x7cf52d48,0x76480162,0x00000000,0x00000000}},	//   báro, ófyl, --, --, 
   {{0x63a80034,0x7cf4056a,0x6d4c00d8,0x60080205}},	//   zygn, cáro, ábad, _tömü, 
   {{0x290c2bea,0x48152d49,0x00000000,0x00000000}},	//   öga_, смас, --, --, 
   {{0x69000142,0xd8380006,0x5ba40153,0xd7c801e2}},	// [1d110] _bŵer, рэс_, _дрэз, ټوله_, 
   {{0x7cd00aed,0x64592d4a,0x94e800ac,0x00000000}},	//   vāri, _scui, _işə_, --, 
   {{0x7bd809a5,0x68e0f18c,0x7eac01e7,0x636400d0}},	//   ştut, _índo, _dúph, _očný, 
   {{0x7cd01a14,0x92e801b9,0xe784014b,0x00000000}},	//   tāri, یروق_, _куго, --, 
   {{0x7cf52d4b,0x031800ec,0x00000000,0x00000000}},	//   záro, اڪرت_, --, --, 
   {{0xed440c71,0x63a8005c,0xf2a000db,0x43940150}},	//   _ىپ_, rygn, зишп, _қазс, 
   {{0x7cf40005,0xab580112,0x63a80210,0x00000000}},	//   xáro, nzüb, sygn, --, 
   {{0x64580a73,0x7cf400dd,0x201c0333,0x7cd042ef}},	//   _ucui, váro, ucui_, pāri, 
   {{0x443d2d4c,0x201c3d6d,0x1ce4031c,0x00000000}},	//   maw_, rcui_, ྩོལ_, --, 
   {{0x7cf4066d,0x7eac01a2,0x201d2d4d,0x00000000}},	//   táro, _kúpi, scui_, --, 
   {{0x7eac9223,0x7d08026a,0x40580451,0xc5e80154}},	//   _júpi, лног_, _ملاح_, কেরা_, 
   {{0x7cf52d4e,0x7afc0354,0x62801c3a,0x00000000}},	//   ráro, _shpt, ldno, --, 
   {{0x7cf400dd,0xee2c06a6,0x91fc0055,0xef0c004b}},	//   sáro, _нн_, _abāh, _ګټو_, 
   {{0x443d2d4f,0x62812d50,0x7cf4059c,0x00000000}},	//   haw_, ndno, páro, --, 
   {{0x443d2d51,0xbd441913,0x6280020c,0x38ac4eb4}},	//   kaw_, _انبي, idno, _hýri_, 
   {{0x443d2d52,0x68e00af2,0xadf403ce,0x00000000}},	//   jaw_, _índl, ीधरन_, --, 
   {{0x443d2d53,0xf7443866,0x6900015d,0x0bf402dd}},	// [1d120] daw_, сезо, _pŵer, _ويىڭ, 
   {{0x38ac02d2,0x9b8800ec,0x27301884,0x00000000}},	//   _mýri_, _منڊل_, سىمس, --, 
   {{0x2e38008f,0xf7700f01,0x62800142,0x46b80073}},	//   רגענ, _کاج_, ddno, _इतरह, 
   {{0x443d2d54,0x3a380036,0x999800bc,0x74140154}},	//   gaw_, _hepp_, larů_, ার্ট_, 
   {{0x7cf47c7b,0x3a381bce,0x2d8002b1,0x00000000}},	//   járm, _kepp_, ākei_, --, 
   {{0x3a3861df,0x628005be,0x443c003e,0x45640014}},	//   _jepp_, gdno, aaw_, _ژھنہ, 
   {{0x443d2d55,0x3a3800e8,0xb0c4023a,0x78a400e2}},	//   baw_, _mepp_, йщик, _kokv, 
   {{0x3a381574,0x7cf404d4,0xe2940032,0xe3b40075}},	//   _lepp_, fárm, _һау_, рбә_, 
   {{0x78a40744,0x3244030d,0x00000000,0x00000000}},	//   _mokv, _гезг, --, --, 
   {{0x7cf4066d,0xfe6c005e,0x3a38a8ce,0xe2946518}},	//   sárl, نگى_, _nepp_, _лау_, 
   {{0x2d892d56,0x7eac0005,0x78a402d0,0x787c0023}},	//   íbe_, _xúpi, _ookv, _ብጽድቂ_, 
   {{0x38ac03b2,0xa0a0004e,0x407800db,0x00000000}},	//   _fýri_, _нахд, _ۅلۅڭ_, --, 
   {{0x3a380694,0x6ff406c2,0xed3000e5,0x00000000}},	//   _bepp_, _اساط, _کوبھ, --, 
   {{0xab58002f,0x443d2d57,0x00000000,0x00000000}},	//   tzüb, zaw_, --, --, 
   {{0xdd8c0348,0x78a52d58,0xad243918,0x2aac0432}},	//   _эш_, _bokv, _ارتو, _jübi_, 
   {{0xddc00042,0x628013d5,0x473402d5,0x443d0114}},	//   _canŵ, zdno, жнас, xaw_, 
   {{0x7bd80ab7,0x3a381bce,0x9c5800db,0x7eac00d0}},	// [1d130] ştur, _fepp_, _اجىز_, _súpi, 
   {{0x443d2d59,0x3a381bce,0xa7b400d1,0x98b800c0}},	//   waw_, _gepp_, алғу_, kurė_, 
   {{0x7d100254,0x7cf400e5,0x00000000,0x00000000}},	//   _üksü, zárm, --, --, 
   {{0x3a3804ce,0xddc00142,0x20d00356,0x2aac0213}},	//   _zepp_, _ganŵ, oţie_, _sübh_, 
   {{0x20d000a8,0x7cd00aed,0x443d2d5a,0x3a380694}},	//   nţie_, mārt, raw_, _yepp_, 
   {{0x3a38002e,0x00000000,0x00000000,0x00000000}},	//   _xepp_, --, --, --, 
   {{0x78c4032e,0x170800e5,0x00000000,0x00000000}},	//   _útvö, _اہلی_, --, --, 
   {{0x92580364,0x7cd00882,0x443d2d5b,0x2e0c0213}},	//   _ҳафт_, nārt, qaw_, dəf_, 
   {{0xef1411db,0xf07401d3,0x53342c29,0x031c0037}},	//   омы_, زیوں_, _нетт, _पढिह_, 
   {{0xa28028c4,0x00000000,0x00000000,0x00000000}},	//   _ریبو, --, --, --, 
   {{0x7cd09787,0xf6500375,0x99980118,0x00000000}},	//   kārt, וצי_, varů_, --, 
   {{0x3a392d5c,0x5be401d9,0x7cf41aa9,0x00000000}},	//   _sepp_, ۪تھہ, márk, --, 
   {{0xd97881fc,0x3a392d5d,0x7cd00882,0x78a400f3}},	//   әргә_, _pepp_, dārt, _rokv, 
   {{0x4fc00131,0x6d440024,0x6d4c00d0,0x61240205}},	//   _سەپە, ąkar, ábac, _cılg, 
   {{0x7cf41ab0,0x20d00311,0xab580112,0x2e0c03b9}},	//   nárk, aţie_, tzüc, cəf_, 
   {{0x7cd004fe,0x3a380de2,0x940403b9,0x38280063}},	//   tāru, _wepp_, _enmə_, ржао_, 
   {{0x20d000a8,0x78a401e4,0x3a392d5e,0xdb252d5f}},	// [1d140] cţie_, _vokv, _tepp_, örät, 
   {{0x7cf40030,0x61241f02,0x00000000,0x00000000}},	//   kárk, _kıld, --, --, 
   {{0x60c80204,0x78a4a98d,0x00000000,0x00000000}},	//   _omgm, _tokv, --, --, 
   {{0x26cd21f4,0x7cd000b8,0x00000000,0x00000000}},	//   égor_, cārt, --, --, 
   {{0x670001f2,0x7cf401d3,0x5334010b,0x61241ea0}},	//   ọkar, tárj, челт, _yılg, 
   {{0xe7340e92,0x00000000,0x00000000,0x00000000}},	//   _фер_, --, --, --, 
   {{0xc76c0092,0x3078007b,0x00000000,0x00000000}},	//   _አራተኛ_, لحظة_, --, --, 
   {{0x6560067c,0x6f680120,0x00000000,0x00000000}},	//   ànhe, ајов_, --, --, 
   {{0x7eac5178,0x4fd4023a,0x8e7c010f,0x709001ec}},	//   _lúpu, яжит, loĝi, зақф, 
   {{0xeea8829d,0x98b80024,0x612403e0,0x7cf400d7}},	//   ртик_, purė_, _bıld, bárk, 
   {{0x7cd00882,0x317c0ac5,0x38ac0174,0x61241ea0}},	//   yārt, _ustz_, _hýru_, _rılg, 
   {{0xa1108818,0x2e0c00ac,0x25a403cd,0x6d540055}},	//   _قولت, rəf_, ønli_, _āyad, 
   {{0x7cd03a71,0xefcc0023,0x00000000,0x00000000}},	//   vārt, _ብግዲ_, --, --, 
   {{0x20d00311,0x205001ee,0x00000000,0x00000000}},	//   rţie_, _етәр, --, --, 
   {{0x7cd00882,0xa8a48f61,0xacf40956,0x00000000}},	//   tārt, орак, _وسعت, --, 
   {{0x20d00276,0x7cf47c7b,0x53bc1fc4,0x00000000}},	//   pţie_, járh, ्छाश, --, 
   {{0x7cd00882,0xa644267c,0x38ac032e,0x00000000}},	// [1d150] rārt, قخان, _nýru_, --, 
   {{0x61252d60,0x7cd0005f,0x4a552d61,0x4ea800eb}},	//   _yıld, bārs, _экос, _ওগুল, 
   {{0x7cd048e1,0x00000000,0x00000000,0x00000000}},	//   pārt, --, --, --, 
   {{0x9b88be6e,0x7cf40646,0x00000000,0x00000000}},	//   _انیل_, várk, --, --, 
   {{0x93252d62,0x3eb81ebf,0x7eac00d0,0x661800a2}},	//   ورون, ūsti_, _kúpt, _şuku, 
   {{0x2d8c2452,0x7cf437b5,0x38ac2507,0x00000000}},	//   _orfe_, tárk, _dýru_, --, 
   {{0xd0400213,0x00000000,0x00000000,0x00000000}},	//   limə, --, --, --, 
   {{0x237c0070,0x61240139,0xbf5800d4,0x00000000}},	//   _tsuj_, _rıld, брої_, --, 
   {{0x2d8c03f9,0xe3b0009f,0x612406be,0x90e4027d}},	//   _arfe_, _غرر_, _sıld, بسون, 
   {{0x7cf52d63,0x42540150,0x61240205,0x7f5801f0}},	//   mári, _ءنار, _aıle, _ҳадс_, 
   {{0x7cf52d64,0xf650008f,0x61252d65,0x527401f7}},	//   lári, עצט_, _qıld, _زالز, 
   {{0xc0f4001f,0xd04003e3,0x00000000,0x00000000}},	//   ሎችም_, kimə, --, --, 
   {{0x7cf52d66,0x8f800046,0xcee801ed,0x03d8015b}},	//   nári, _ақыл, _ڈرون_, _তরুণ, 
   {{0x6124013d,0x7eac02d2,0xd04006be,0x00000000}},	//   _tıld, _púpu, dimə, --, 
   {{0x60d92d67,0x7cf519ce,0x61240166,0x00000000}},	//   onum, hári, _uıld, --, 
   {{0x61240139,0x00000000,0x00000000,0x00000000}},	//   _gıle, --, --, --, 
   {{0x60d81140,0x497c0023,0x6d5c000d,0x7cf40d12}},	// [1d160] inum, _ብውልቂ_, _äpar, jári, 
   {{0x7cf52d68,0x7cd000e2,0x60d875ee,0x7eac02d2}},	//   dári, pārs, hnum, _túpu, 
   {{0xf98800ec,0x38ad2d69,0x7d14022e,0x7aec014f}},	//   _انجي_, _býrt_, _kiys, mobt, 
   {{0xa5052d6a,0x7cf52d6b,0x7aed2d6c,0xc4c405af}},	//   пеха_, fári, lobt, وتنو, 
   {{0xb2700724,0x60d92d6d,0x33f400c6,0x7cf465fa}},	//   еклә, dnum, أساس, gári, 
   {{0x60d8679c,0x98b802b5,0x7aec014f,0x7cf401d3}},	//   enum, kurī_, nobt, sárh, 
   {{0x60d92d6e,0xefb001d5,0xbae00150,0xc68c00f1}},	//   fnum, کیشگ, _ﺍﺳﺤﺎ, _خېل_, 
   {{0x60d92d6f,0x61240166,0x7cf400d0,0x7aec047e}},	//   gnum, _bılb, bári, hobt, 
   {{0x7cf52d70,0x289827af,0x7aed2d71,0xa504074d}},	//   cári, מיקא, kobt, _хета_, 
   {{0x7d140100,0x765c138f,0x60d80ba7,0x63801a21}},	//   _aiys, ngpy, anum, _ягуа, 
   {{0x60d8011f,0x7aed2d72,0x00000000,0x00000000}},	//   bnum, dobt, --, --, 
   {{0x60d80175,0x00000000,0x00000000,0x00000000}},	//   cnum, --, --, --, 
   {{0x7d152d73,0x6568054e,0xaa480023,0x00000000}},	//   _diys, ăghi, _ንምልላ, --, 
   {{0x7d14062c,0xd0400213,0x20d0054e,0x03d800fe}},	//   _eiys, vimə, mţia_, _তৰুণ, 
   {{0x7cf518a8,0x3eb8045f,0x4fc00131,0x19942be9}},	//   zári, êste_, _سەھە, наря, 
   {{0x9dd80302,0x7d1405d1,0x612405d1,0x588400c7}},	//   _לקוח, _giys, _yılb, ныуа, 
   {{0x20d0084c,0x7aec3a73,0xeb48036b,0x61240790}},	// [1d170] nţia_, bobt, _اشبو_, _kılc, 
   {{0x7cf41a09,0xd0400213,0x60d92d74,0x6d592d75}},	//   vári, rimə, znum, outa, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x43752d76,0x7cf52d77,0x6d58d055,0x60d92d78}},	//   дукт, tári, iuta, xnum, 
   {{0xd7e40212,0xaa480023,0xab5801d3,0x602002d2}},	//   _зіро, _ንምሕላ, zzün, _límó, 
   {{0x6d592d79,0x7cf52d7a,0x59d401d5,0x780001f0}},	//   kuta, rári, _آغیر, _рӯса, 
   {{0x7cf51a94,0x26d00564,0xc0c4ecb2,0xc0e44eca}},	//   sári, mixo_, мәди, мокк, 
   {{0x6d592d7b,0xe4a52d7c,0x00000000,0x00000000}},	//   duta, _эрго, --, --, 
   {{0x60d92d7d,0x6d4cf8bc,0x6d5805d5,0x00000000}},	//   rnum, ában, euta, --, 
   {{0x6d592d7e,0x7d140198,0xab5803fa,0x3cf00087}},	//   futa, _siys, tzün, _skyv_, 
   {{0x41b400c6,0x20d00311,0x60d92d7f,0xd94c0023}},	//   _تمار, aţia_, pnum, _ንፍትሕ, 
   {{0x26d000aa,0x7d1401d5,0x00000000,0x00000000}},	//   hixo_, _qiys, --, --, 
   {{0x20d000a8,0x6d592d80,0xe8e8031c,0xab5801ed}},	//   cţia_, auta, _རྩེག, szün, 
   {{0x6d585de0,0x34d81d15,0x8c00010b,0xd72800c7}},	//   buta, _भद्द, ыҗыл, ҷнаҵ_, 
   {{0x3f8c0a62,0x7d14208d,0x7aed2d81,0xb5b000cc}},	//   lveu_, _tiys, robt, _টেনচ, 
   {{0x26d00077,0x168403e6,0x00000000,0x00000000}},	//   eixo_, کارێ, --, --, 
   {{0x26d12d82,0xfaa4516c,0x310c00dc,0xd5a4158b}},	// [1d180] fixo_, _жапо, ागतः_, کلای, 
   {{0x78b433b4,0x26d00129,0xc87800a2,0x00000000}},	//   skyv, gixo_, _ışe_, --, 
   {{0xb904004e,0xe5a00120,0xf4852d83,0x7bc4002f}},	//   _озок, кифи, дулн, lzku, 
   {{0xd4f4451a,0x2934010f,0x00000000,0x00000000}},	//   رتاژ, _קאכן_, --, --, 
   {{0x6d5804ce,0xd3706dd7,0x7bc4002f,0x00000000}},	//   zuta, اهت_, nzku, --, 
   {{0x6d592d84,0x7bc4151c,0xe0cc00f1,0x00000000}},	//   yuta, izku, یزي_, --, 
   {{0xdc300024,0x6d58009d,0xe5200064,0x00000000}},	//   _užėm, xuta, _адсп, --, 
   {{0x6d592d85,0x6ab8012c,0x2450007b,0xb4b8210e}},	//   vuta, _उत्र, _لنفس, _بُرا_, 
   {{0xe3612d86,0x6d592d87,0xceb800fd,0x1ae400eb}},	//   _икти, wuta, зәй_, _গঠনে_, 
   {{0x6d592d88,0x7eac01f1,0x68e000d2,0x7bc40030}},	//   tuta, _súpr, _índv, dzku, 
   {{0xc0cc044e,0x6d580140,0x7cf40124,0x3f880171}},	//   _ብዝሒ_, uuta, háru, _šaut_, 
   {{0x20d00276,0x3f8c0114,0x7cf400e5,0xabb00166}},	//   pţia_, bveu_, zárv, вамә, 
   {{0x6d592d89,0x764c068f,0x2d984bc9,0xc0441968}},	//   suta, _odby, _šped_, _سخنو, 
   {{0x20d00276,0x00000000,0x00000000,0x00000000}},	//   nţin_, --, --, --, 
   {{0x6d592d8a,0x61246648,0x7bc4005a,0xceb8012d}},	//   quta, _kıla, azku, mkę_, 
   {{0xfb1801ed,0xceb8d591,0x318c030a,0x00000000}},	//   _کريں_, lkę_, _męz_, --, 
   {{0x66652d8b,0xeb0401c0,0xdca40114,0x7cf400e5}},	// [1d190] дъез, _очоо, _јањи, tárv, 
   {{0xceb84f59,0x61252d8c,0x1be8000d,0x9fbc00d7}},	//   nkę_, _lıla, _टुटल_, nčár_, 
   {{0x26d06d50,0x15a802e8,0xceb800c0,0x00000000}},	//   rixo_, мъци_, ikę_, --, 
   {{0x85045945,0xbb680244,0x00000000,0x00000000}},	//   روشن, _بلیۆ_, --, --, 
   {{0xd7f92d8d,0x9f4806b9,0x69c40158,0x6e286460}},	//   _жур_, ümüz_, lzje, _offb, 
   {{0x45d40323,0x6d480174,0xf2c001c6,0xceb8012d}},	//   _зогс, _ovfa, лөхи, jkę_, 
   {{0xceb80034,0x6d4ce851,0x69c4045f,0x00000000}},	//   dkę_, ábal, nzje, --, 
   {{0x69c4002d,0x717031b1,0x6aa40175,0xceb8012d}},	//   izje, اهيا, hjjf, ekę_, 
   {{0x68e00048,0x6d4877d4,0x61240139,0x00000000}},	//   _índu, _avfa, _dıla, --, 
   {{0x3f8d2d8e,0x3dc40175,0x7cf42f5e,0x2ee0004e}},	//   rveu_, tzlw_, hárt, лжыг, 
   {{0xab58066d,0xb8d00135,0x7cf45955,0x9268010a}},	//   szül, _དྭ_, kárt, _юрта_, 
   {{0x69c40a85,0x672c1505,0x0fd00574,0xd09400c7}},	//   dzje, _otcj, _तेवढ, _ашшы, 
   {{0xaa4802d3,0x69c4000f,0xceb8012d,0x00000000}},	//   _ንምምላ, ezje, bkę_, --, 
   {{0x1ee40344,0x4a742123,0x7bc4002f,0xca74aec3}},	//   _توتی_, кыст, rzku, кусы, 
   {{0x6124247e,0x7bc4295c,0x00000000,0x00000000}},	//   _yıla, szku, --, --, 
   {{0xadd4008d,0xad18008f,0x672c0010,0x00000000}},	//   _רוקח_, _צופר, _btcj, --, 
   {{0x7f492d8f,0x69c4045f,0x00000000,0x00000000}},	// [1d1a0] nseq, azje, --, --, 
   {{0x7f480140,0x2b480118,0x00000000,0x00000000}},	//   iseq, řicí_, --, --, 
   {{0x7cf52d90,0xf51804d3,0x249404fb,0x6a3808a8}},	//   sáru, ستاش_, کنند_, _מגיפ, 
   {{0xa83800a2,0xceb8012d,0x7cf401e7,0x3af403b2}},	//   _boÿu, zkę_, cárt, ræpu_, 
   {{0x7cf401f1,0xb7d40882,0x7f492d91,0xe8e8031c}},	//   lárs, kṣip, jseq, _རྩིག, 
   {{0x764c04ce,0x92582e01,0x6124236c,0x6da803b9}},	//   _udby, факт_, _sıla, fəal, 
   {{0x66e12d92,0x7cf40313,0x20d00311,0x61240139}},	//   _сора, nárs, rţin_, _pıla, 
   {{0x6d4c2b76,0x20d00276,0xceb80034,0x7eac003a}},	//   ábam, sţin_, wkę_, _súpp, 
   {{0xceb80034,0xd2440022,0xa070010b,0x7cf40419}},	//   tkę_, _амзқ, угыч, hárs, 
   {{0x4374c4b4,0x7cf456b1,0x69c40034,0x98b80064}},	//   _шуст, kárs, yzje, kurį_, 
   {{0x7f480af5,0x61d80846,0x7cf52d93,0xceb8d591}},	//   aseq, यपृष, járs, rkę_, 
   {{0x7cf401a2,0x9e001586,0x7f490f14,0xceb8033f}},	//   dárs, ычыл, bseq, skę_, 
   {{0xceb8033f,0x271c00bc,0x00000000,0x00000000}},	//   pkę_, _बढेर_, --, --, 
   {{0x27fc025c,0x6e28035a,0x9a8401f4,0x00000000}},	//   _ġun_, _uffb, лусл, --, 
   {{0xa2b0146c,0x079802d3,0x7cf47d26,0x3e2c0023}},	//   _अवस्, _መራኸቢ_, tárt, _ተሓባቢ, 
   {{0x69c52d94,0x44fc0327,0x81e40154,0x188800d1}},	//   rzje, _ཟེེར_, _নরম_, нсуп_, 
   {{0x7cf52d95,0x00000000,0x00000000,0x00000000}},	// [1d1b0] rárt, --, --, --, 
   {{0x7cf401f1,0x00000000,0x00000000,0x00000000}},	//   bárs, --, --, --, 
   {{0x7cf52d96,0x96b8007b,0x00000000,0x00000000}},	//   párt, راكز_, --, --, 
   {{0xa4840150,0xca64022e,0xa41c015b,0x0594036b}},	//   عجان, _jihо, দর্য_, _یازگ, 
   {{0x139400d4,0x00000000,0x00000000,0x00000000}},	//   лицю, --, --, --, 
   {{0xdecc02d3,0x6d540055,0x2618000d,0x00000000}},	//   ብቱን_, _āyan, _बलटी_, --, 
   {{0x45d40139,0xe0542fb6,0x00000000,0x00000000}},	//   _ровс, فیات_, --, --, 
   {{0x7f480eda,0x70741870,0x7f9400c7,0x00000000}},	//   tseq, نمىز_, ҵаҩх, --, 
   {{0x442d2d97,0x7f480140,0x2164013e,0xd4e4014b}},	//   _ife_, useq, фиқи_, _сюри, 
   {{0x442c05c7,0x20d0054e,0x291c01e4,0xe688008e}},	//   _hfe_, mţim_, ĉuaj_, _ütäü, 
   {{0x7f480eda,0x442c0270,0xdcf485a2,0x22452d98}},	//   sseq, _kfe_, žača, mank_, 
   {{0x22452d99,0x61240724,0x442c010a,0x403400c0}},	//   lank_, _yıln, _jfe_, _редс, 
   {{0x442d2d9a,0x7f480113,0xd7d002a0,0x321c00a2}},	//   _mfe_, qseq, _सेंच, _ygty_, 
   {{0x7cf52d9b,0x442c0489,0x00000000,0x00000000}},	//   társ, _lfe_, --, --, 
   {{0xaa412d9c,0x442d2d9d,0xa964e051,0x1ce4031c}},	//   ресл, _ofe_, кира_, ྩོད_, 
   {{0x442d2d9e,0x22444653,0x7cf52d9f,0x61240139}},	//   _nfe_, hank_, rárs, _lılo, 
   {{0x7cf420be,0x2244003e,0xf744741b,0x91fc00ef}},	// [1d1c0] sárs, kank_, тезо, _acāl, 
   {{0x442d2da0,0x7cf52da1,0x22440010,0x960800f1}},	//   _afe_, cárr, jank_, ېکړې_, 
   {{0x22452da2,0x442c030d,0x00000000,0x00000000}},	//   dank_, _bfe_, --, --, 
   {{0x245019b6,0x00000000,0x00000000,0x00000000}},	//   لنمس, --, --, --, 
   {{0xa2b01b6e,0x442c1528,0xe3603591,0x7cf425e6}},	//   _अवश्, _dfe_, икци, nárq, 
   {{0x442d2da3,0xe2952da4,0x626015ed,0x224401c7}},	//   _efe_, кач_, авља, gank_, 
   {{0xe5a12da5,0x442c2f99,0xa2b00b7c,0xe2941b88}},	//   _кири, _ffe_, _अवर्, тај_, 
   {{0x660001ed,0x2244017a,0x61240139,0x20380092}},	//   ünke, aank_, _tıln, _ያበርክ, 
   {{0x22452da6,0xb4bc068f,0x336401ca,0xd2500133}},	//   bank_, इसी_, _шваг, _هۆش_, 
   {{0x6124510c,0xe8500023,0x00000000,0x00000000}},	//   _kıll, _ዝጎደሎ, --, --, 
   {{0x9da4009d,0x00000000,0x00000000,0x00000000}},	//   въяа_, --, --, --, 
   {{0xcb3400a7,0x61242093,0x00000000,0x00000000}},	//   лемъ, _mıll, --, --, 
   {{0x7cf4fc8a,0x9c3802e8,0x443003e3,0x5f340064}},	//   gárq, ъпят_, _əz_, _апія_, 
   {{0x387000b5,0x00000000,0x00000000,0x00000000}},	//   efyr_, --, --, --, 
   {{0x4c940108,0x59f80395,0x9e780115,0x00000000}},	//   _бийс, веря_, _חנופ, --, 
   {{0x387000a9,0x22440086,0x98c4c7b0,0xe7a400d1}},	//   gfyr_, zank_, асул, پۇسى_, 
   {{0x442d2da7,0x224430b5,0x7cf409c2,0xb3d00037}},	// [1d1d0] _rfe_, yank_, párr, _देलख, 
   {{0x6d580eda,0x442c05ac,0xe3b00edf,0x7cf400e4}},	//   orta, _sfe_, یرش_, lárp, 
   {{0x6d58074d,0x442c1682,0x224476ea,0x61240139}},	//   nrta, _pfe_, vank_, _rılo, 
   {{0x6d592da8,0x81cc1c82,0x224413bb,0x55040408}},	//   irta, ৰথম_, wank_, ачча, 
   {{0x22452da9,0x42d4063b,0x785c0311,0x6d592daa}},	//   tank_, ліку, săvâ, hrta, 
   {{0x22440dd4,0xd49818ce,0x1634005b,0x92680114}},	//   uank_, ерә_, _веря, врћа_, 
   {{0x22452dab,0xd1489245,0x442c0129,0x00000000}},	//   rank_, نشين_, _tfe_, --, 
   {{0xee3400fd,0x22452dac,0xd0940124,0x00000000}},	//   ңны_, sank_, ашьы, --, 
   {{0x6d592dad,0x249d2dae,0x224400af,0xa3b4007d}},	//   erta, _inum_, pank_, _छथि_, 
   {{0x6124b753,0x52752daf,0x6d5803ac,0xaec0004e}},	//   _yıll, _نامز, frta, йбыл, 
   {{0xeb94016c,0x6d5800f3,0x612405d1,0x3cf0041c}},	//   ҳия_, grta, _kılm, ीतले_, 
   {{0x7cf4cd11,0x00000000,0x00000000,0x00000000}},	//   tárq, --, --, --, 
   {{0x6d592db0,0x249d2db1,0xff24005b,0x92c803d4}},	//   arta, _mnum_, _ёмко, োকৰ_, 
   {{0x7cf42cd7,0x2908007f,0x7db44e76,0x00000000}},	//   rárq, _ahca_, _مصبا, --, 
   {{0x6d58098d,0x8d843c4b,0x249c00a2,0xf2d000df}},	//   crta, _نشين, _onum_, זעם_, 
   {{0x26c001fa,0x249c013f,0xbc644961,0xdb242099}},	//   _aljo_, _nnum_, _свик, _پودی, 
   {{0x387012e8,0x00000000,0x00000000,0x00000000}},	// [1d1e0] rfyr_, --, --, --, 
   {{0x249c0134,0x35a46523,0x1ce40327,0x3870005c}},	//   _anum_, лазг, ྩོམ_, sfyr_, 
   {{0x7cd0005f,0x249c0334,0x61242737,0xa2a400cd}},	//   dārz, _bnum_, _qıll, चान्, 
   {{0xb4bc4ca3,0x26c0007c,0x248c0432,0x00000000}},	//   इसे_, _eljo_, gdgm_, --, 
   {{0x6d5400b8,0x00000000,0x00000000,0x00000000}},	//   _āyam, --, --, --, 
   {{0x249cbea3,0x6d581368,0xe0b000eb,0x00000000}},	//   _enum_, yrta, টফোন, --, 
   {{0xf0740075,0x21640063,0xc29001d5,0x612403e0}},	//   гийә_, гији_, تیلب, _fılm, 
   {{0x92e42f8b,0x6d580960,0x20c0013d,0x00000000}},	//   নতে_, vrta, йсыг, --, 
   {{0x09e000dc,0x64a000c7,0x6d592db2,0x00000000}},	//   _नश्य, _уата, wrta, --, 
   {{0x2324f081,0x66f40139,0x4d980212,0xe3e8010f}},	//   _софи_, _işkä, вкою_, _אַבֿ, 
   {{0x61240d9c,0x6d592db3,0x6e380175,0x7cf400e5}},	//   _yılm, urta, rbtb, tárp, 
   {{0x6d584695,0x6ca4300e,0x7038007b,0x00000000}},	//   rrta, урож, _أساس_, --, 
   {{0x29080142,0x212802f0,0x7cf400e5,0x00000000}},	//   _rhca_, _čchi_, rárp, --, 
   {{0xdee00454,0x00000000,0x00000000,0x00000000}},	//   _лочи, --, --, --, 
   {{0x6d580194,0x00000000,0x00000000,0x00000000}},	//   qrta, --, --, --, 
   {{0x7cd00882,0x58d419c7,0x53c40825,0x00000000}},	//   kāry, бост, वनाश, --, 
   {{0xadb404a9,0x249c0175,0xaae40066,0xc6f92db4}},	// [1d1f0] _شۇڭا_, _rnum_, _مسدو, внах_, 
   {{0xaa652db5,0x00000000,0x00000000,0x00000000}},	//   _стик, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x48c400fd,0x44f40137,0x61246656,0x00000000}},	//   _тәга, шпес, _qılm, --, 
   {{0x03a40262,0x249c0381,0xf1c40241,0x630000d1}},	//   рило, _vnum_, _ááju_, مۈرل, 
   {{0xed440026,0xf8ac0014,0xb7d8011a,0x20d0054e}},	//   _وپ_, _ٹکہ_, _יקרי, mţii_, 
   {{0x66f400fd,0x80b8015b,0xd49810de,0x20d0054e}},	//   _eşkä, ইফস্, _өрт_, lţii_, 
   {{0x249d2db6,0xb4b4053f,0x20d00311,0xfbc4012d}},	//   _unum_, _кисә, oţii_, रैडम, 
   {{0x64492db7,0x20d000a8,0xe3b0034c,0x6700f3a4}},	//   magi, nţii_, _ارز_, ọkur, 
   {{0x64492db8,0xef0c00f1,0x443c002f,0xcfa80014}},	//   lagi, وټي_, lbw_, چایم_, 
   {{0x3714010f,0x92b4020c,0x00000000,0x00000000}},	//   יַטל_, _احقا, --, --, 
   {{0x6280859f,0xc0f4001f,0xcb0805d0,0xb6280150}},	//   leno, ዎችም_, _חל_, _ﺗﯟ_, 
   {{0x60d92db9,0xee2d2dba,0xbea52dbb,0x6448009f}},	//   mium, _мн_, _валк, iagi, 
   {{0x64492dbc,0xaa41103d,0x3b0801ee,0x00000000}},	//   hagi, жерл, тего_, --, 
   {{0x64482dab,0x20d00311,0x62800165,0xf2d0008f}},	//   kagi, eţii_, ieno, קעל_, 
   {{0x62812dbd,0x64492dbe,0x00000000,0x00000000}},	//   heno, jagi, --, --, 
   {{0x64492dbf,0x62812dc0,0xdca404a9,0xe73801d9}},	// [1d200] dagi, keno, _вақи, نتٕچ_, 
   {{0x60d92dc1,0xdb0801e1,0x00000000,0x00000000}},	//   hium, _òlàj, --, --, 
   {{0x64492dc2,0x60d92dc3,0xb5c804fb,0x20d00311}},	//   fagi, kium, خوام_, aţii_, 
   {{0x64492dc4,0x60d801f7,0x81cc03d4,0x00000000}},	//   gagi, jium, ৰথা_, --, 
   {{0x62812dc5,0xf7712dc6,0x20d0084c,0x925885ce}},	//   feno, _باج_, cţii_, галт_, 
   {{0x62809237,0x64480140,0xca64022e,0x41b007b7}},	//   geno, aagi, _jihа, जहंस, 
   {{0x64492dc7,0x73342928,0x443c0072,0x00000000}},	//   bagi, _چىرا, bbw_, --, 
   {{0x60d92dc8,0x64492dc9,0xd6c800fe,0x00000000}},	//   gium, cagi, _শদিয, --, 
   {{0x62800216,0x612403e0,0xa2440228,0x00000000}},	//   beno, _yılk, ارۇۇ, --, 
   {{0x623015ed,0x9af003f9,0x6d5c0fac,0xa5000327}},	//   _међу, ƙaƙa_, _åpak, _མཚོག_, 
   {{0x20c00428,0x4c94295d,0x60d92dca,0x5d600212}},	//   _iñin_, бинс, bium, отяз, 
   {{0xa0a03e08,0xec14013d,0x00000000,0x00000000}},	//   _махд, иенә_, --, --, 
   {{0xce9402e8,0x00000000,0x00000000,0x00000000}},	//   _галъ, --, --, --, 
   {{0x64492dcb,0x2d88005c,0x00000000,0x00000000}},	//   zagi, æbes_, --, --, 
   {{0xbe8400f1,0xcfe80154,0x9928447e,0x00000000}},	//   _دجنو, _পরিন, июта_, --, 
   {{0x64492dcc,0xa83400f2,0x00000000,0x00000000}},	//   xagi, شعرش, --, --, 
   {{0x64492dcd,0xd3641df2,0x00000000,0x00000000}},	// [1d210] vagi, _تۇ_, --, --, 
   {{0x64492dce,0x62800005,0x20d0084c,0x60d92dcf}},	//   wagi, xeno, rţii_, zium, 
   {{0x6448f213,0x85740395,0x98b80139,0x00000000}},	//   tagi, слех, atrı_, --, 
   {{0x62800428,0x20d00276,0x31bc0154,0x00000000}},	//   weno, pţii_, েপাশ, --, 
   {{0x62812dd0,0x6368084c,0xe29401ec,0x00000000}},	//   teno, трег_, ғақ_, --, 
   {{0x6280030a,0x86c40066,0x00000000,0x00000000}},	//   ueno, _ايسن, --, --, 
   {{0x64492dd1,0x38ac00ee,0xb64000d1,0x00000000}},	//   pagi, _aýry_, _ﻏﺎ_, --, 
   {{0x20c00428,0x64492dd2,0xd498361e,0xa2b000cd}},	//   _eñin_, qagi, _кру_, _अवक्, 
   {{0x628029ef,0xe3f80014,0x53348c75,0xc09401b9}},	//   peno, _شعرش_, _метт, لجکت, 
   {{0x60d92dd3,0x62800200,0xd1b8656a,0x00000000}},	//   sium, qeno, _ھالا_, --, 
   {{0x60d920c5,0x317c009f,0x13bc00eb,0xfe10012d}},	//   pium, _gptz_, _আইয়, डेंस_, 
   {{0x60d80cfe,0xfce52dd4,0xcfa803e6,0x40b40050}},	//   qium, сомо, _چاوم_, _چھکھ_, 
   {{0x2d88037e,0x0bb4447e,0xcfa80133,0x00000000}},	//   æber_, ощря, _ناوم_, --, 
   {{0xab243c85,0xa3ac4707,0xf2d0010f,0x3b080798}},	//   сора_, _ओपन_, ִען_, ѓево_, 
   {{0xa8009f9f,0x00000000,0x00000000,0x00000000}},	//   şıls, --, --, --, 
   {{0xb4e401bc,0xdb04002f,0x6d54011a,0xcfe800cc}},	//   _पदे_, _friß, _היקף_, _পৰিন, 
   {{0xc7642160,0xe7352dd5,0xed681772,0x68412dd6}},	// [1d220] قالى, йет_, _ዶክቶር_, янта, 
   {{0x13a80330,0x00000000,0x00000000,0x00000000}},	//   ینای_, --, --, --, 
   {{0x98b80598,0xb8cc09bd,0x00000000,0x00000000}},	//   strı_, _কত_, --, --, 
   {{0xed5400c8,0xb3c8010a,0xba7402f2,0x00000000}},	//   מבער_, ллез_, _ئاکت, --, 
   {{0x20d00311,0xe3ad2dd7,0x33f43567,0x00000000}},	//   nţiu_, فرو_, حساس, --, 
   {{0x7afc05b1,0x994800d0,0xd1cc0023,0x00000000}},	//   _jkpt, _móže_, ባሒቱ_, --, 
   {{0x59c8078a,0x38ac0118,0xdc3000c0,0x00000000}},	//   रनिर, _sýry_, ežči, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2e4802e8,0x42080ce8,0x662400e5,0x00000000}},	//   ляно_, лмәү_, _árká, --, 
   {{0xa29c37e3,0xd138033f,0x4a240327,0x00000000}},	//   _गोप्, _prąd_, _འཔེལ_, --, 
   {{0x720416ac,0xa3a000db,0xbae00220,0x2bb000bc}},	//   _اوام, _وڭۇن, _ﺍﺳﺘﺎ, ुन्थ, 
   {{0xc0d40092,0x0c240137,0xede401d5,0x5f4002f2}},	//   ይቀር_, өмүн, _қўлн, _کنول, 
   {{0xd010009a,0x00000000,0x00000000,0x00000000}},	//   _غلت_, --, --, --, 
   {{0x6d4c1709,0x7648066a,0x00000000,0x00000000}},	//   ábas, ðfyl, --, --, 
   {{0xa80003ee,0x8a180354,0x37c000cc,0x00000000}},	//   ğıms, ровс_, _এশগৰ, --, 
   {{0x58d43a61,0xa29c070f,0xa8000205,0x00000000}},	//   пост, _गोन्, şıms, --, 
   {{0x20d00311,0x2cf40490,0x290400e2,0x6624007b}},	// [1d230] mţit_, ीतील_, ēna_, مراك, 
   {{0x20d00356,0x6600002f,0x49a401af,0x6fd400cc}},	//   lţit_, ünko, _дымғ, _ডুৱে, 
   {{0xa2a400cd,0x00000000,0x00000000,0x00000000}},	//   चास्, --, --, --, 
   {{0x88a004d3,0x20d00311,0x296400f1,0x00000000}},	//   _تیرۆ, nţit_, _پیړۍ_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x96084077,0x00000000,0x00000000,0x00000000}},	//   _гэта_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8e2c022e,0xb0d8000d,0xfeb80633,0x00000000}},	//   tndа_, _बगरग, لادت_, --, 
   {{0x200000da,0xd3d821ec,0x6d4401fa,0xfe780107}},	//   āji_, _طبقا_, ćkan, рӯд_, 
   {{0x403403c5,0xa2c001af,0x00000000,0x00000000}},	//   _деес, _мәҫк, --, --, 
   {{0x22a00241,0x00000000,0x00000000,0x00000000}},	//   békà_, --, --, --, 
   {{0x6ab40072,0xb4f8008f,0x2d8c0393,0xd040016b}},	//   _boxf, שפרי, _esfe_, rimɔ, 
   {{0x6d6400df,0xa29c01ad,0x2ba802db,0x6d5400b8}},	//   _ŝraŭ, _गोम्, _चपरा, _āyav, 
   {{0x200808a4,0xfe0c000d,0x00000000,0x00000000}},	//   škić_, _हरिस_, --, --, 
   {{0x26cc0200,0x00000000,0x00000000,0x00000000}},	//   ëgon_, --, --, --, 
   {{0xe8f400d6,0x9bc8004b,0xe7340150,0x00000000}},	// [1d240] ілу_, _ددغې_, жеу_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6124008e,0xa2b00e85,0xb0d8000d,0x00000000}},	//   _kılu, _अवज्, _बगलग, --, 
   {{0x23d801ad,0x2d98f3a2,0x8e7c01e4,0x00000000}},	//   _मेहद, _špek_, miĝe, --, 
   {{0x181801d9,0x799c02d0,0x8e7c01e4,0x00000000}},	//   _دردک_, _hrpw, liĝe, --, 
   {{0xdeb003f9,0x7cf401ed,0x00000000,0x00000000}},	//   ƙaƙe, gárz, --, --, 
   {{0x8e7c0115,0x99980064,0x00000000,0x00000000}},	//   niĝe, marų_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb9e0001f,0x95ec015b,0xceb801e0,0x00000000}},	//   _የግ_, _করিম_, йәк_, --, 
   {{0xb2c40592,0x8e7c0115,0x799c02d0,0xa56000db}},	//   _بغرو, kiĝe, _orpw, _رگۅن, 
   {{0xa2a4c126,0x4c94361e,0xe29467f0,0x00000000}},	//   चार्, пинс, _фах_, --, 
   {{0x8e7c008f,0x802407d6,0x705003e6,0xdce40139}},	//   diĝe, _فرهم, _کۆکا, _brnı, 
   {{0x99980006,0x20d00311,0xaaa400bc,0xa0d41e24}},	//   karų_, rţit_, खालक, _بِنا_, 
   {{0x68e000d2,0x70d80cb4,0x7c340042,0xede401a9}},	//   _índz, _बगुल, _efyr, _мўйн, 
   {{0x7c3400a9,0x28bc0acd,0x19580c75,0xa92801ec}},	//   _ffyr, _एकदि, жасы_, ріге_, 
   {{0x47352dd8,0x395c0af2,0x2008012d,0xa2a40073}},	//   знас, átsa_, żcie_, चाऱ्, 
   {{0x07087427,0x1798054a,0x2d980219,0x26cc002e}},	// [1d250] ميري_, овты_, _špeh_, ëgoo_, 
   {{0xadfc0f44,0x799c02d0,0x2604005b,0x7d0c0419}},	//   _उडान_, _frpw, очег, _ďasi, 
   {{0xb864114f,0xe5a80114,0x1ef8010f,0x65a800d8}},	//   _کاپو, шњак_, סלבע, штаг_, 
   {{0xf9f80375,0x6124013d,0xfb540244,0xdd7800df}},	//   _להתמ, _mılt, _بڤێت_, שטאל, 
   {{0x95e4134e,0x00000000,0x00000000,0x00000000}},	//   कपॉट_, --, --, --, 
   {{0x77b80302,0x02c402db,0x2eec143a,0xcfd000fe}},	//   _המשח, वसेन, _njff_, াপান, 
   {{0xe0541b8d,0x5558084c,0xe4e400d4,0x557400f3}},	//   قیات_, _маря_, _діан, _огрт, 
   {{0x20c00309,0x65740218,0xadfc00e1,0x6d4416a3}},	//   _iñik_, mtxh, _उड़न_, ćkal, 
   {{0x20c00113,0xf07401ed,0x044400fd,0x691000a2}},	//   _uñim_, سیوں_, _меңн, mçed, 
   {{0x6124013d,0x95ec03d4,0x940403e3,0x00000000}},	//   _bılt, _কৰিম_, _namə_, --, 
   {{0x65751d62,0xee34084c,0x00000000,0x00000000}},	//   ntxh, янэ_, --, --, 
   {{0xa29c06ff,0x6124008e,0x8e7c0115,0x6d5400dc}},	//   _गोत्, _qılu, viĝe, _āyat, 
   {{0x90e40014,0x3f9c0433,0x20181bce,0x7f1802d5}},	//   _تسٕن, _urwu_, _àqi_, _ліку_, 
   {{0x69100790,0x8e7c0115,0x00000000,0x00000000}},	//   hçed, tiĝe, --, --, 
   {{0x657401d4,0x99980024,0x6e9001f7,0xe9a00107}},	//   jtxh, varų_, _سليا, нарп, 
   {{0xa3a80316,0x645800ae,0x77740076,0x8e7c0115}},	//   गमा_, _ndui, ttyx, riĝe, 
   {{0x8e7c01e4,0xe81cc126,0x6124236c,0xdce4013d}},	// [1d260] siĝe, _मृदा_, _kıls, _urnı, 
   {{0x6458003e,0x799c02d0,0x1af003d4,0x55c40417}},	//   _adui, _trpw, ছতহে_, мазғ, 
   {{0x3f8c54ef,0x65740218,0xd5a40214,0xaab8011a}},	//   hweu_, gtxh, بلای, _הזיכ, 
   {{0x798c02ea,0x3d10012d,0x00000000,0x00000000}},	//   mwbw, _धीमे_, --, --, 
   {{0x798c0083,0x92940305,0x32440092,0x00000000}},	//   lwbw, далц, _ያቀረባ, --, 
   {{0xe7340510,0x657401d4,0x68f80219,0x60c8000d}},	//   _хер_, btxh, čude, _algm, 
   {{0x200c003e,0x91fc0055,0x987c00d7,0x05540108}},	//   _azgi_, _acār, _míľ_, _оття, 
   {{0x764c01ab,0xbb3c0150,0x00000000,0x00000000}},	//   _heby, _ﺟﯘﻥ_, --, --, 
   {{0x25082352,0x91fc0055,0x6d4416a3,0x764cbb8b}},	//   _طرفی_, _ccār, ćkam, _keby, 
   {{0x752c055a,0xe3b40108,0x5ed00022,0xe0cc0014}},	//   _kubz, _эбу_, ежьу, ٖزی_, 
   {{0x200c0790,0x764c6729,0x71580137,0x81a4007b}},	//   _ezgi_, _meby, _ырас_, _يحمل, 
   {{0x764c0c11,0xa110030c,0x00000000,0x00000000}},	//   _leby, _كولت, --, --, 
   {{0xceb816af,0xa064010b,0xad2400e5,0x00000000}},	//   _дән_, _хача_, _کرتو, --, 
   {{0x764c0316,0xd9d8009e,0x61ec06be,0x00000000}},	//   _neby, _দুইম, _çilç, --, 
   {{0xa3e04244,0x2d98035b,0x1cb00327,0x6e28045a}},	//   _फेन_, _épe_, _ནྭམ_, _igfb, 
   {{0x02d90ab4,0x69100139,0x00000000,0x00000000}},	//   _भग्न, kçee, --, --, 
   {{0x764c17b8,0x23d80490,0x645801ab,0xd36400db}},	// [1d270] _beby, _मेंद, _rdui, _حۇ_, 
   {{0xd1f81772,0x28bc01bc,0x6458007f,0x6d5c33b8}},	//   ገራት_, _एकवि, _sdui, _åpas, 
   {{0x764c00a9,0x752c0ba1,0x0df0001f,0x69100205}},	//   _deby, _cubz, _ሃላፊ_, tçed, 
   {{0x764c0363,0x00000000,0x00000000,0x00000000}},	//   _eeby, --, --, --, 
   {{0x68fc006c,0x6d480368,0x764c0142,0x00000000}},	//   moqd, _lwfa, _feby, --, 
   {{0x764c7a1e,0x68fc2631,0x3244001f,0x050c015b}},	//   _geby, loqd, _ያቀርባ, ষদের_, 
   {{0xd5b800a8,0xd0400213,0x97d40241,0x00000000}},	//   _ест_, lhmə, _ò̟rò, --, 
   {{0x7f580cfc,0x67252dd9,0x68fc0067,0x04c815f2}},	//   ојот_, _hijj, noqd, _بوري_, 
   {{0xa2252dda,0x67242252,0x6d480009,0x94040451}},	//   _فراه, _kijj, _awfa, _ٻوله, 
   {{0x73c12ddb,0x672422a9,0x672c0014,0xa528031c}},	//   _шәхе, _jijj, _mucj, _སྤོག_, 
   {{0x3f8d0932,0x67252ddc,0x7e7c00e5,0x672c15c0}},	//   sweu_, _mijj, őspo, _lucj, 
   {{0x67252ddd,0x6604012d,0x00000000,0x00000000}},	//   _lijj, _myjk, --, --, 
   {{0x672c04ce,0x6d480c8c,0x68fc022e,0x612400a2}},	//   _nucj, _ewfa, doqd, _wıls, 
   {{0x67252dde,0x61240baa,0x01f8010f,0x00000000}},	//   _nijj, _tıls, ַפּל, --, 
   {{0x764c04ce,0xd9c8012c,0x68fc01d5,0x09e00154}},	//   _reby, रनेट, foqd, _মুবা, 
   {{0x8e7c008f,0x764c0083,0xa29c1414,0x798c0142}},	//   miĝa, _seby, _गोस्, rwbw, 
   {{0x67247e37,0x752c054e,0x6d5c0158,0x8e7c008f}},	// [1d280] _bijj, _subz, _åpar, liĝa, 
   {{0xc7940006,0xdb2401f4,0x00000000,0x00000000}},	//   эрсы, äräu, --, --, 
   {{0x8e7c008f,0x67247e7d,0x672c0175,0x68fc01a9}},	//   niĝa, _dijj, _eucj, boqd, 
   {{0x764c00d0,0x2db4010f,0x00000000,0x00000000}},	//   _weby, ולען_, --, --, 
   {{0x764d2ddf,0xdce40171,0x00000000,0x00000000}},	//   _teby, _apnī, --, --, 
   {{0x67252de0,0xf1a40c54,0x8e7c010f,0xaaa4012c}},	//   _gijj, дрин, kiĝa, खाएक, 
   {{0xf8d01524,0x8e7c0115,0xa6c401a9,0x00000000}},	//   _सताय, jiĝa, _ўлса_, --, 
   {{0x67240337,0x8e7c008f,0x3958045a,0x78b401f4}},	//   _zijj, diĝa, _mvps_, njyv, 
   {{0xa29c0073,0x78b400c7,0x00000000,0x00000000}},	//   _गोव्, ijyv, --, --, 
   {{0x8e7c0115,0x68fc022e,0x00000000,0x00000000}},	//   fiĝa, zoqd, --, --, 
   {{0xab5801ed,0x8e7c00df,0x55ec0154,0x68fc01d5}},	//   gyün, giĝa, _করুক_, yoqd, 
   {{0x7d152de1,0xd0540134,0xefc812d7,0xab840139}},	//   _chys, _ɔbɛb, _мулк_, мугк, 
   {{0x6f186c35,0x5c040006,0x61180a7c,0x68fc022e}},	//   pmtc, вяра, _וואה, voqd, 
   {{0x8e7c0115,0x9ea4156c,0x78b40022,0x9a841eca}},	//   biĝa, _овча_, ejyv, кусл, 
   {{0x8e7c00df,0x68fc022e,0xc8f40395,0x2ba8000d}},	//   ciĝa, toqd, езвъ, _चपका, 
   {{0x67240337,0x70000073,0x00000000,0x00000000}},	//   _sijj, _लडाख_, --, --, 
   {{0x2d9c143a,0x386400e8,0x68fcfa80,0x00000000}},	// [1d290] lvte_, óora_, roqd, --, 
   {{0x6724014f,0xa528031c,0xde0800f7,0x94fc031c}},	//   _qijj, _སྤུག_, _ارۇۇ_, ྐོའི_, 
   {{0xa29d2de2,0xeb9c0ac8,0xf658002e,0x68fc014f}},	//   _गोष्, lvø_, _ŋëñŋ, poqd, 
   {{0xbec40055,0x7d040200,0x00000000,0x00000000}},	//   _itīś, _ëhst, --, --, 
   {{0xa3a429c6,0x9cd802e4,0x67252de3,0x8e7c008f}},	//   بحان, וואה_, _tijj, ziĝa, 
   {{0xa610035b,0x677c001f,0x00000000,0x00000000}},	//   _азгә, _ሥርዓቱ_, --, --, 
   {{0xb23472ca,0x7580004b,0xc56400ec,0x00000000}},	//   ركيا_, _میلم, _سڏاي, --, 
   {{0x8e7c00c8,0xa29d2de4,0xf1640131,0x24880332}},	//   viĝa, _गोर्, رخىۋ, _úcm_, 
   {{0x81f82fc0,0x7d140042,0x9394007b,0xc0c80023}},	//   _کفار_, _rhys, _لجلا, _ሽኮር_, 
   {{0x442c0418,0xdec802d3,0xef141945,0x7d140076}},	//   _hge_, _ኣማኒ_, нмы_, _shys, 
   {{0x7d152de5,0x442c15c0,0x00000000,0x00000000}},	//   _phys, _kge_, --, --, 
   {{0x8e7c00c8,0xf198011a,0x00000000,0x00000000}},	//   riĝa, _משעש, --, --, 
   {{0xf1bc0135,0x8e7c010f,0x10d8bfae,0xd9c81fd2}},	//   _ġġib_, siĝa, _تبلغ_, रन्ट, 
   {{0x8e7c010f,0x00000000,0x00000000,0x00000000}},	//   piĝa, --, --, --, 
   {{0x442d2de6,0x2ca80597,0x7d152de7,0xc9542c12}},	//   _oge_, áidí_, _thys, ктты, 
   {{0x442d2de8,0x7d14014b,0xf1b0010f,0x6fd400eb}},	//   _nge_, _uhys, נסן_, _ডুয়ে, 
   {{0xfaa4329b,0x68ec013a,0x00000000,0x00000000}},	// [1d2a0] _запо, _šidí, --, --, 
   {{0xa29c37cc,0x3a3804cc,0xa8001e4a,0xc0cc0023}},	//   _गोल्, _ufpp_, узул, _ኣኻሊ_, 
   {{0x7bc52de9,0x442c0112,0xb4642a9d,0x00000000}},	//   lyku, _bge_, екел, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe7340395,0x00000000,0x00000000,0x00000000}},	//   _пея_, --, --, --, 
   {{0x442d2dea,0x387000a2,0x00000000,0x00000000}},	//   _ege_, lgyr_, --, --, 
   {{0xe5a01607,0x442c0077,0xa29c0073,0x7bc52deb}},	//   _йири, _fge_, _गोळ्, hyku, 
   {{0x38700076,0x7bc40f12,0x00000000,0x00000000}},	//   ngyr_, kyku, --, --, 
   {{0xb4bc089a,0xceb8506f,0x7bc40022,0x80b01408}},	//   ेसी_, дәй_, jyku, _आचरे, 
   {{0x7bc52dec,0x442d2ded,0x00000000,0x00000000}},	//   dyku, _zge_, --, --, 
   {{0xdcf00790,0xfd5400dc,0x7bc40009,0x442c0139}},	//   çeği, _khaṇ, eyku, _yge_, 
   {{0xe3a401ed,0xe0d434e2,0x93f40073,0x2d9c002f}},	//   _تشہی, _пвх_, _अशाच_, rvte_, 
   {{0x9b592dee,0xddc81591,0x7bd801e4,0x7bc400e5}},	//   ният_, ćišt, ŝtun, gyku, 
   {{0x38700076,0x8e7c00df,0xe0640092,0xb4bc00cd}},	//   egyr_, miĝo, _ተቀዳሚ_, ेसु_, 
   {{0x8e7c010f,0x28a48e21,0x00000000,0x00000000}},	//   liĝo, ншаг, --, --, 
   {{0x6d592def,0x7cf80086,0x38701368,0x00000000}},	//   msta, rùrû, ggyr_, --, 
   {{0xe730036d,0x442c0076,0x2aa826c7,0xee4800a2}},	// [1d2b0] اصر_, _rge_, _етно_, _giýñ_, 
   {{0x442d2df0,0x38700076,0x00000000,0x00000000}},	//   _sge_, agyr_, --, --, 
   {{0xa24004a9,0xfd5400dc,0x442c045a,0x00000000}},	//   ۇرغۇ, _bhaṇ, _pge_, --, 
   {{0xe5052df1,0x8e7c00df,0xd61801b9,0x9b4400e5}},	//   رباي, kiĝo, رتلا_, _جنیو, 
   {{0xd7f80598,0x25b002c4,0x442c0268,0xfd540055}},	//   _зур_, sxxl_, _vge_, _dhaṇ, 
   {{0x6d592df2,0x8e7c00df,0x73c00166,0x00000000}},	//   ksta, diĝo, шәсе, --, 
   {{0x442c1570,0x36a00075,0x7bc4012d,0x00000000}},	//   _tge_, _خەلق, zyku, --, 
   {{0x442c019b,0xceb80034,0xc2ec00bc,0xfd5400cd}},	//   _uge_, eję_, _řídí, _ghaṇ, 
   {{0x6d592df3,0xa280034c,0x8e7c0115,0x69c400c7}},	//   esta, _میشو, giĝo, hyje, 
   {{0x6d592df4,0x69c420e5,0xaec000c9,0x7bc4c40d}},	//   fsta, kyje, ибыл, vyku, 
   {{0xfd940032,0xbc68036b,0x7f8401b9,0x41b40035}},	//   төлә_, ومدن_, رلگن, _جمار, 
   {{0x7bc52df5,0xbc180046,0x83fc01ed,0x248c0036}},	//   tyku, дігі_, _időb, negm_, 
   {{0x6d59137d,0x8e7c00df,0xc0f40092,0x3fc80244}},	//   asta, ciĝo, ገኛል_, _تدای_, 
   {{0xceb8006d,0x3d112df6,0x6d592df7,0x7bc400c7}},	//   cję_, _धीरे_, bsta, ryku, 
   {{0x6d592df8,0x9418016b,0x68f80841,0xba740bce}},	//   csta, _ɑrɑ_, čudn, _یادت, 
   {{0x09e000bd,0xdb040ea0,0x8e2c01a9,0x7bc40588}},	//   _মুহা, _krië, lidа_, pyku, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [1d2c0] --, --, --, --, 
   {{0x35a4036b,0x69c4002d,0x8e2c01a9,0x00000000}},	//   казг, byje, nidа_, --, 
   {{0x8e7c00df,0xa5e00022,0xfd54002b,0xd91000f2}},	//   ziĝo, аҩрҵ, _phaṇ, _هیس_, 
   {{0xdb041a7c,0xceb80034,0xb4bc7347,0x8e2c01a9}},	//   _orië, zję_, ेसे_, hidа_, 
   {{0x6d592df9,0x8e2c022e,0xceb8012d,0xe73401f0}},	//   zsta, kidа_, yję_, _афсӯ, 
   {{0x6d592dfa,0xe2812dfb,0x8e7c010f,0x84240014}},	//   ysta, илчи, viĝo, ھى۪ن, 
   {{0x66e046fd,0xdebc1e38,0x6d592dfc,0xdb0401f5}},	//   _тора, ትናን_, xsta, _arië, 
   {{0x2ec8043e,0x73c00184,0x6d592dfd,0xdb040036}},	//   िस्त, _ҡәҙе, vsta, _brië, 
   {{0x24040262,0x6d58068f,0x69c4068f,0x9f50013d}},	//   _анти_, wsta, zyje, авыч, 
   {{0x8e7c008f,0x8e2c01a9,0x00000000,0x00000000}},	//   riĝo, gidа_, --, --, 
   {{0xdb0401fb,0x69c40076,0x8e7c00df,0x42d40006}},	//   _triê, xyje, siĝo, _сіту, 
   {{0x6d592dfe,0x69c44fc6,0xdb040036,0xceb8033f}},	//   rsta, vyje, _frië, sję_, 
   {{0x6d592dff,0x5bb8023a,0x6e94007b,0xdfcc00ec}},	//   ssta, вляя_, _للشا, _ويم_, 
   {{0x6d592e00,0xdee12e01,0x69c417ad,0xab5800e5}},	//   psta, _кочи, tyje, lyük, 
   {{0x6d592e02,0xb7840724,0x8d98001f,0xdd952e03}},	//   qsta, һәре_, _ቆይቷል_, _ашы_, 
   {{0x68f8fada,0x98f400c6,0xa3e0000d,0x69c415c0}},	//   čudo, لثقا, _फइल_, ryje, 
   {{0x69c52e04,0xb7846833,0xdb0404fb,0x4bc46215}},	// [1d2d0] syje, ләре_, _oriè, _сөнг, 
   {{0x69c400c7,0x00000000,0x00000000,0x00000000}},	//   pyje, --, --, --, 
   {{0x56941ee3,0x09e00154,0x00000000,0x00000000}},	//   рахт, _মুরা, --, --, 
   {{0xdb052e05,0x76480174,0x00000000,0x00000000}},	//   _ariè, ðfyr, --, --, 
   {{0xdb0406af,0xc0c400d1,0x25e00b27,0x00000000}},	//   _briè, һәди, _टेरी_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa3e0033d,0x45d434d8,0x51540032,0x8e7c01e4}},	//   _फेर_, _совс, атыу, riĝl, 
   {{0x395c00d2,0x212805d5,0x8e2c022e,0x00000000}},	//   átsi_, öch_, vidа_, --, 
   {{0x644800ca,0xbea400ee,0xd37801f4,0x00000000}},	//   mbgi, гапк, _ачх_, --, 
   {{0xdb0406af,0x8e2c01d5,0x20a0012d,0x2ba4095f}},	//   _griè, tidа_, _खोरध, खिना, 
   {{0x92580117,0x00000000,0x00000000,0x00000000}},	//   _рахт_, --, --, --, 
   {{0x3d0c01ad,0x8e2c01d5,0xbb4404c2,0x00000000}},	//   सतें_, ridа_, лемк, --, 
   {{0x8e2c01b9,0xef0d2e06,0x2bcc05d7,0x6d5c02d2}},	//   sidа_, _гм_, सैला, _æpan, 
   {{0x20c00784,0xfa8c0023,0x00000000,0x00000000}},	//   _iñiq_, _ምዝካር_, --, --, 
   {{0x395c004e,0x8e2c01a9,0x25e00d2e,0x00000000}},	//   éts_, qidа_, _टेली_, --, 
   {{0x6d4401a6,0xae4001d9,0x00000000,0x00000000}},	//   ćkat, _پھیو, --, --, 
   {{0xad1825f9,0xd7642ea3,0xe8f405f5,0x7b10037e}},	// [1d2e0] _אוקר, شنای, улт_, læum, 
   {{0x7d052e07,0x69112e08,0xdb052e09,0xa3d47347}},	//   loks, lçel, _orié, ानन_, 
   {{0x18b40124,0x443c0142,0x00000000,0x00000000}},	//   _кәар, fcw_, --, --, 
   {{0x7d052e0a,0x69100724,0x628001f5,0xdbd400e4}},	//   noks, nçel, efno, lúña, 
   {{0xdb052e0b,0xb9dc02d3,0x2ba402fe,0x660001d3}},	//   _priè, _ኣር_, खिया, ünkr, 
   {{0x691003ee,0x7d052e0c,0x1dd02bf1,0x00000000}},	//   hçel, hoks, दनात, --, 
   {{0x69100598,0xdb043ae2,0x7d052e0d,0x00000000}},	//   kçel, _crié, koks, --, 
   {{0x7d04002d,0xa24401ec,0x00000000,0x00000000}},	//   joks, _ەرنۇ, --, --, 
   {{0x32452e0e,0x7520a723,0xdb0402e2,0x69100139}},	//   _безг, mmoz, _triè, dçel, 
   {{0xc3400014,0x752001d3,0x00000000,0x00000000}},	//   _بێوٹ, lmoz, --, --, 
   {{0xdb0400c7,0x752004ba,0x2d880129,0x7f4c0139}},	//   _grié, omoz, ïbe_, _çaqn, 
   {{0x3f14004e,0x98b80139,0x00000000,0x00000000}},	//   лдөс, kurı_, --, --, 
   {{0x7cb402dd,0x00000000,0x00000000,0x00000000}},	//   рқыт_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x59f807d8,0x6d4439ae,0x9d4006ed,0x00000000}},	//   геря_, ćkas, _лејд, --, 
   {{0x7d0405b1,0xa3d400cd,0xdca400f3,0x00000000}},	//   coks, ानम_, _гаћи, --, 
   {{0x865485a1,0x6280015d,0xab852e0f,0x00000000}},	// [1d2f0] иках, yfno, _суйк, --, 
   {{0xea6001ec,0x00000000,0x00000000,0x00000000}},	//   _دۇسپ, --, --, --, 
   {{0xa29c007d,0x81c80154,0xc5d806c2,0x2d880327}},	//   _गोग्, _লেন_, خواص_, ħbew_, 
   {{0x56940220,0x5c38008f,0x752001d3,0xd618215c}},	//   _қаст, ָרגן_, gmoz, اتكا_, 
   {{0xdc3c008f,0xddd0010f,0x644805d5,0x6b8801e3}},	//   געדר, _ĵaŭd, rbgi, _äggd, 
   {{0xdb0406af,0x26cc00e2,0x00000000,0x00000000}},	//   _prié, īgos_, --, --, 
   {{0x7d04022f,0x26c00064,0x691003e0,0x96f80150}},	//   yoks, _iojo_, hçem, _серт_, 
   {{0x850404a9,0x26c12e10,0x69100205,0x62040171}},	//   _ئورن, _hojo_, kçem, _īslī, 
   {{0x26c12e11,0x7d052e12,0x6ea4000d,0x00000000}},	//   _kojo_, voks, _कोहँ, --, 
   {{0xdb04f9ef,0x249c0457,0xcf8800e3,0x91fc00dc}},	//   _trié, _haum_, اضين_, _idān, 
   {{0x249d2e13,0x7d04049b,0x69100724,0xd0041884}},	//   _kaum_, toks, tçel, _қошқ, 
   {{0x249c03a2,0xed5402bf,0x26c12e14,0xce180006}},	//   _jaum_, шою_, _lojo_, ыцыі_, 
   {{0x7d052e15,0x9f6806bb,0x249c0211,0x69112e16}},	//   roks, _чрез_, _maum_, rçel, 
   {{0x212c025f,0x249d2e17,0x26c0146a,0x7f480113}},	//   _high_, _laum_, _nojo_, mpeq, 
   {{0x393405f5,0x69100724,0x212c00a3,0xb8540640}},	//   рэгс, pçel, _kigh_, иђањ, 
   {{0x249d2e18,0xdbd408a5,0xab600327,0x00000000}},	//   _naum_, búða, żżag, --, 
   {{0x26c12e19,0xe7352e1a,0x212c016d,0x7f480309}},	// [1d300] _bojo_, иет_, _migh_, npeq, 
   {{0x26c00407,0x212c014f,0xacb8000f,0x0dec0092}},	//   _cojo_, _ligh_, nmûn, _ቅርፅ_, 
   {{0x249d2e1b,0x91fc00b8,0x212c00a3,0x200d2e1c}},	//   _baum_, _adān, _oigh_, _lygi_, 
   {{0x249c0070,0x212d2e1d,0x200c022e,0xa5300a4a}},	//   _caum_, _nigh_, _oygi_, ініч, 
   {{0x249d2e1e,0x24046c59,0x26c0008f,0x528801e0}},	//   _daum_, анци_, _fojo_, лҡан_, 
   {{0x212c0363,0x26c001e4,0x9294033a,0x6b880267}},	//   _aigh_, _gojo_, сакц, _ägge, 
   {{0x212c00a3,0xc32c1178,0x249c01ab,0x20f40311}},	//   _bigh_, رەم_, _faum_, răin_, 
   {{0x8e7c008f,0xdb04000f,0x74150cf9,0x200c0142}},	//   miĝi, _oriï, _نوزا, _bygi_, 
   {{0x999809a8,0x212c01ab,0x26c00066,0x8e7c008f}},	//   jbrž_, _digh_, _yojo_, liĝi, 
   {{0x249c0190,0xeea80372,0x212c01c3,0xeda401b9}},	//   _zaum_, ттик_, _eigh_, ашмо, 
   {{0x8e7c00c8,0x249c0211,0x212d2e1f,0x52740131}},	//   niĝi, _yaum_, _figh_, _вуҗу, 
   {{0x249c01d4,0xb03400d1,0x69100205,0x00000000}},	//   _xaum_, _ئىشغ, tçem, --, 
   {{0x9b443306,0xd0112e20,0x200c04cc,0x4bc4010b}},	//   ينَو, _علت_, _gygi_, сөйг, 
   {{0xa3d4b7b0,0xdb240008,0x8e7c008f,0xdfcc009f}},	//   ानत_, ærðu, kiĝi, _تيه_, 
   {{0xdd8c15fa,0x26c12e21,0x8e7c0115,0x00000000}},	//   _يوه_, _rojo_, jiĝi, --, 
   {{0x2d8c0393,0x26c00010,0x8e7c008f,0xc8c800ec}},	//   _ipfe_, _sojo_, diĝi, دورن_, 
   {{0x249d2e22,0xd7752e23,0xa6452e24,0x65c4035b}},	// [1d310] _raum_, قالع, لخان, _oĩhá, 
   {{0x249d2e25,0xaa6400d1,0x8e7c0115,0x96240171}},	//   _saum_, _ттик, fiĝi, _žņau, 
   {{0x26c000c8,0x249d2e26,0x8c0800bd,0x8e7c00df}},	//   _vojo_, _paum_, রেশন_, giĝi, 
   {{0x2d8c1dc9,0x249c0070,0x984800a7,0x7f480784}},	//   _mpfe_, _qaum_, _вяра_, ypeq, 
   {{0x03a52e27,0x26c12e28,0x212d2e29,0x691003e0}},	//   сило, _tojo_, _righ_, hçek, 
   {{0x93240691,0x13080845,0x2284013e,0x691005d1}},	//   يرون, аній_, рудг, kçek, 
   {{0x249c0211,0x212c0455,0x8e7c00df,0x55587c85}},	//   _taum_, _pigh_, ciĝi, _вася_, 
   {{0x787002bf,0xb9dc044e,0x212c0455,0x61240166}},	//   _jаvа, _ኣይ_, _qigh_, _yıly, 
   {{0x2d8c337a,0x91fc002b,0xf0a41e35,0x00000000}},	//   _apfe_, _udān, скыл_, --, 
   {{0x7f480194,0x816003e6,0x212c014f,0x7f4c0166}},	//   rpeq, _فۆتۆ, _wigh_, _çaqm, 
   {{0x212d2e2a,0xacb8000f,0x11d40736,0x82140472}},	//   _tigh_, rmûn, _وتمد, _اواص, 
   {{0xdfb000aa,0x7f480194,0x212c00a3,0x3f980003}},	//   _وټاک, ppeq, _uigh_, ħsub_, 
   {{0xa3d41161,0xbea52e2b,0x60d905e7,0xb4f808a8}},	//   ानि_, _галк, mhum, רפרי, 
   {{0xaa412e2c,0x60d92e2d,0xce9402e8,0x00000000}},	//   зерл, lhum, _мачъ, --, 
   {{0xdca47129,0xee2c00ec,0x00000000,0x00000000}},	//   _ҳақи, _ٻٽي_, --, --, 
   {{0xa3d4447d,0x60d92e2e,0x8e7c00c8,0xdb04004e}},	//   ाना_, nhum, viĝi, _triï, 
   {{0xbb840491,0x22ac0374,0x16e800c7,0x7c340419}},	// [1d320] _الخي, _kēkē_, агаҩ_, ďarč, 
   {{0x3de40489,0x8e7c008f,0x60d80784,0xbb1802e9}},	//   _སྟོན, tiĝi, hhum, _حزبا_, 
   {{0x60d8b634,0xcc08183b,0x00000000,0x00000000}},	//   khum, _مزین_, --, --, 
   {{0x8e7c00c8,0x7aec76b7,0x799c035a,0x15b8010b}},	//   riĝi, libt, _ispw, лыҗы_, 
   {{0x60d92e2f,0x925805f5,0x799c02d0,0x87b92e30}},	//   dhum, аалт_, _hspw, _курт_, 
   {{0xddc0010f,0x69c000db,0x06740d30,0x8e7c010f}},	//   _senŝ, _ànec, _муся, piĝi, 
   {{0x60d92e31,0xc5d402bf,0x799c02d0,0x02680212}},	//   fhum, _діть, _jspw, ршій_, 
   {{0x60d92e32,0x765d2e33,0xa3e02208,0x7518007b}},	//   ghum, lapy, _फेक_, _إقرأ_, 
   {{0xd01000c6,0x77740175,0x7aece10b,0x00000000}},	//   بلة_, nuyx, kibt, --, 
   {{0x765d2e34,0x7c352e35,0xb8d8025c,0x60d80a63}},	//   napy, _agyr, _ཙོ_, ahum, 
   {{0x60d92e36,0x4c952e37,0x7aec0009,0x00000000}},	//   bhum, оинс, dibt, --, 
   {{0x69100ab7,0x77740054,0xf1580124,0x765c035b}},	//   rçek, kuyx, _аиҧш_, hapy, 
   {{0x765d2e38,0x799c035a,0x00000000,0x00000000}},	//   kapy, _aspw, --, --, 
   {{0x7c3400dd,0x765c035b,0x09e000fe,0x705003e6}},	//   _egyr, japy, _মুগা, _بۆکا, 
   {{0x2d8c1dc9,0x6ce41ed2,0x799c02d0,0xa3700139}},	//   _upfe_, _гіпе, _cspw, _irеş, 
   {{0x7c340076,0x799c035a,0x1cb80327,0x00000000}},	//   _ggyr, _dspw, _ཛོར_, --, 
   {{0x799c02bd,0xab5800e5,0x00000000,0x00000000}},	// [1d330] _espw, gyüt, --, --, 
   {{0x60d802b9,0x91fc24cb,0xd04000ac,0xa3d41fad}},	//   zhum, _adām, rkmə, ानस_, 
   {{0xddc04a0f,0x00000000,0x00000000,0x00000000}},	//   _menş, --, --, --, 
   {{0x60d8016c,0xd8380323,0x8e7c01e4,0xd49801c6}},	//   xhum, _гэр_, miĝu, йрч_, 
   {{0x60d806d6,0x8e7c0115,0x1fa40037,0x00000000}},	//   vhum, liĝu, _कछेड, --, 
   {{0xf958040b,0x799c0334,0xf3180131,0xd68403f6}},	//   _حسیں_, _yspw, анчә_, _нусп, 
   {{0x60d902b5,0xc10400c6,0x8e7c0115,0x81440014}},	//   thum, يوتي, niĝu, زچان, 
   {{0x00c89fbd,0x00000000,0x00000000,0x00000000}},	//   рлик_, --, --, --, 
   {{0x60d92e39,0x65740472,0x318c03b9,0x00000000}},	//   rhum, luxh, _cəzb_, --, 
   {{0x60d8535e,0xdb040407,0x64580489,0xacb8000f}},	//   shum, _prií, _heui, smûl, 
   {{0x60d8124c,0x77f40034,0xc0c00023,0xa3d409b2}},	//   phum, _इश्क_, ስሳር_, ानव_, 
   {{0x7fd41c26,0x60d81cdf,0x8e7c01e4,0x00000000}},	//   _мілі, qhum, diĝu, --, 
   {{0xbc1802dd,0x7aec022e,0x765c32bc,0x00000000}},	//   ріні_, tibt, yapy, --, 
   {{0x65740928,0x64592e3a,0x799c035a,0x395400d8}},	//   kuxh, _leui, _pspw, жњат, 
   {{0xa9a12e3b,0x7aed2e3c,0x64580129,0xdc180055}},	//   мирд, ribt, _oeui, _kāīc, 
   {{0x64592e3d,0x7aec0218,0x7c3400a2,0x00000000}},	//   _neui, sibt, _ugyr, --, 
   {{0x765d2e3e,0xc7641473,0xf0900375,0xfaa40006}},	// [1d340] tapy, كالى, ונן_, _дапо, 
   {{0x273c0142,0x799c03ac,0x00000000,0x00000000}},	//   _dîn_, _tspw, --, --, 
   {{0x765c09a5,0xdb040120,0x799c02d0,0xddc001d3}},	//   rapy, _triâ, _uspw, _kenő, 
   {{0x3e30001f,0x645800a3,0x83fc01ed,0x765c035b}},	//   _አጠናክ, _ceui, _időj, sapy, 
   {{0x64592e3f,0xb4c806ab,0x01e405f5,0x7398030d}},	//   _deui, _लकी_, үйчү, ртес_, 
   {{0x6458003a,0x6574004b,0x765c0309,0xa6d802d2}},	//   _eeui, buxh, qapy, _auðf, 
   {{0x64592e40,0x74b80139,0x5ebc0154,0x630049f6}},	//   _feui, _куас_, ইসাই, بوول, 
   {{0x64592e41,0xf48401ed,0xa504036b,0xa1240a11}},	//   _geui, _گاڑی, _деса_, يكول_, 
   {{0xb600012c,0xddc00209,0xe3610d8c,0x60f40953}},	//   řádn, _penş, _окти, ўныя_, 
   {{0x64580156,0xa3e007f7,0x00000000,0x00000000}},	//   _zeui, _फेट_, --, --, 
   {{0xdea002a8,0xac7000f1,0x00000000,0x00000000}},	//   _jinƙ, وندګ, --, --, 
   {{0xa6d80252,0x8e7c0115,0x2ba52e42,0x69100139}},	//   _guðf, viĝu, खिला, lçev, 
   {{0x6ee4027d,0xc0f8010f,0x00000000,0x00000000}},	//   _وستل, _פּעט, --, --, 
   {{0xa7f80165,0x8e7c01e4,0x17e402dd,0x5e5400db}},	//   _heñg, tiĝu, _ﺍﺒﺘﺯ, _ۇلۇس_, 
   {{0x321c0175,0x09e00154,0x273c03cb,0xda3404b4}},	//   _jzty_, _মুজা, _sîn_, деры, 
   {{0x6d492e43,0x273c0142,0x8e7c00df,0x00000000}},	//   _itfa, _pîn_, riĝu, --, 
   {{0x64592e44,0x65740921,0xa7f800fd,0x8e7c01e4}},	// [1d350] _reui, wuxh, _meñg, siĝu, 
   {{0x64592e45,0x5778007b,0x8e7c01e4,0xb7840139}},	//   _seui, تصفح_, piĝu, чәюе_, 
   {{0x6458003e,0xba980375,0xa3e01cd2,0x843833d2}},	//   _peui, _הסתי, _फेज_, مكار_, 
   {{0x65740200,0x5df800df,0x00000000,0x00000000}},	//   ruxh, ספאנ, --, --, 
   {{0xd7f92e46,0x64580231,0x83fc01d3,0xd3d8007b}},	//   _дур_, _veui, _idők, يبها_, 
   {{0x91fc0618,0x68f810bf,0xdb9c008f,0x2fd0010b}},	//   _meāf, čudu, יסדר, _ýygy_, 
   {{0x64581dd4,0x6d48031c,0xa6d8032e,0x00000000}},	//   _teui, _ntfa, _auðg, --, 
   {{0x720000d1,0x23c000dc,0xba040b82,0xbfc40139}},	//   رۈنم, _pūjā_, _ለው_, збик, 
   {{0x6d480857,0x74940092,0xa4f40073,0x00000000}},	//   _atfa, _መምጣቱ_, ंचीच_, --, 
   {{0xd33400d1,0x00000000,0x00000000,0x00000000}},	//   _قعلع, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6f544d66,0x00000000,0x00000000,0x00000000}},	//   _کلوز_, --, --, --, 
   {{0x90d400aa,0x6d4802d0,0x63a807c5,0xcee801d3}},	//   _زموږ, _etfa, nvgn, صرین_, 
   {{0xef6401c0,0xbea52e47,0xa7f80139,0x953c01ee}},	//   _хэцү, _хакк, _meñd, _йәhү, 
   {{0xdb040332,0xe8d400dc,0x00000000,0x00000000}},	//   _criá, ठसूच, --, --, 
   {{0x7e600998,0xe204033f,0x00000000,0x00000000}},	//   lalp, ciół_, --, --, 
   {{0xe7352e48,0xdb052e49,0x27b071c1,0x369402e8}},	// [1d360] зеу_, _trià, нәрс, зшес, 
   {{0x7e612e4a,0x393401c0,0xe7b000e5,0xa6c4026b}},	//   nalp, _нэмс, عملد, плуа_, 
   {{0x1dc8012a,0x2a540375,0x00000000,0x00000000}},	//   ाहित, _מבין_, --, --, 
   {{0xa3d48005,0x7e600004,0x59241f7b,0x7f580175}},	//   ानं_, halp, _آکسف, _owwq, 
   {{0x7e612e4b,0x7ea402b5,0x66d00205,0x00000000}},	//   kalp, _kōpē, _bıkı, --, 
   {{0x20c00986,0xdea00198,0xa7f8415b,0x66d00790}},	//   _iñiy_, _tinƙ, _deñd, _cıkı, 
   {{0x78a41326,0x691003ee,0x66f80456,0xef00000d}},	//   _kakv, rçev, ्वरक_, _लदबऽ_, 
   {{0x64a11143,0x78a40115,0x318c00ac,0x15b86171}},	//   _паса, _jakv, _cəza_, _лығы_, 
   {{0xa3d40882,0x78a43a52,0x66d00790,0x52740022}},	//   ानः_, _makv, _fıkı, _ҕуҕу, 
   {{0xd8bc0327,0xc2c8004b,0xa6d808ce,0x69100200}},	//   _པོའི, _وبلل_, _guðd, lçet, 
   {{0x78a52e4c,0x7b100194,0x5d6000a8,0x318c03b9}},	//   _oakv, hæus, нтяз, _fəza_, 
   {{0x7b100194,0x78a40024,0x94200490,0x66e001e1}},	//   kæus, _nakv, _बराच_, _kíkù, 
   {{0x66d003ee,0xa7f80139,0x1dc028fc,0x228c0205}},	//   _yıkı, _keñe, дөөн, bıkı_, 
   {{0x7e600c8c,0x00000000,0x00000000,0x00000000}},	//   calp, --, --, --, 
   {{0x78a4f971,0x6d48ce29,0xdd8cad60,0x39580042}},	//   _bakv, _utfa, _яш_, _cwps_, 
   {{0xa92802dd,0x6b88007c,0x6e4000d1,0x00000000}},	//   сіге_, _äggo, _تۆھم, --, 
   {{0x473402d5,0x78a40373,0x66e00241,0x7bd801e4}},	// [1d370] днас, _dakv, _níkù, ŝtur, 
   {{0xdb04b9f0,0x8a18020f,0x00000000,0x00000000}},	//   _triá, _мопс_, --, --, 
   {{0x78a52e4d,0xa7f8013d,0x91fc00dc,0x00000000}},	//   _fakv, _señd, _udāh, --, 
   {{0x66d00365,0x7e6001c4,0xa4f401f9,0x88a00244}},	//   _sıkı, zalp, ंचेच_, _جیرۆ, 
   {{0xa7f8005a,0x986800e5,0x00000000,0x00000000}},	//   _beñe, _ریلے_, --, --, 
   {{0x41b4016c,0x92640131,0x63a80c86,0x77b80375}},	//   дсит, ىدىم, rvgn, _ומשח, 
   {{0x26f819e5,0xa7f80432,0x92652e4e,0x00000000}},	//   ्वीर_, _deñe, ردوم, --, 
   {{0x395c0af2,0x318c00ac,0xc1044caa,0xf4f0035b}},	//   âtsi_, _qəza_, بوبي, _иҧхь, 
   {{0x7e612e4f,0x66d00790,0x0ec803ce,0x00000000}},	//   talp, _tıkı, ाउंड, --, 
   {{0x0fe8005e,0xb9e00020,0xef1434d8,0xbb6800b5}},	//   ялық_, _ከፍ_, ммы_, jyuの_, 
   {{0x69112e50,0x7c9400f1,0x00000000,0x00000000}},	//   nçes, وشحا, --, --, 
   {{0x7e612e51,0xa7f801c4,0x70c800f1,0x00000000}},	//   salp, _zeñe, _وهلې_, --, 
   {{0xef0d2e52,0xb12400aa,0x78a4a084,0x7e600c8c}},	//   _ам_, _تړون_, _rakv, palp, 
   {{0x69112e53,0xb4b8ec76,0x7e60036b,0x60c92e54}},	//   kçes, _अच्_, qalp, _hogm, 
   {{0x78a41805,0xaa40030d,0xcd280345,0x00000000}},	//   _pakv, тесл, تسین_, --, 
   {{0x9ba400cf,0x69100139,0x00000000,0x00000000}},	//   _كەجى, dçes, --, --, 
   {{0xf7700491,0x78a52e55,0xac800124,0xb6a40395}},	// [1d380] ضاء_, _vakv, _ргыл, миал, 
   {{0x60c80bc2,0x68ec031c,0x7f4c180f,0xa6d8032e}},	//   _logm, _emcd, _çaqu, _auðb, 
   {{0x78a404b9,0x60c81ad7,0xa7f80124,0xf9880451}},	//   _takv, _oogm, _reñe, _بنجي_, 
   {{0x60c92e56,0xa7f8008e,0x00000000,0x00000000}},	//   _nogm, _señe, --, --, 
   {{0x20c00113,0x2b78008f,0xa7f800c7,0x9294011c}},	//   _uñiy_, ַטקײ, _peñe, еалц, 
   {{0x06b801d9,0x81c803d4,0x82807855,0x3f98031c}},	//   _فنُک_, _লেই_, лқуд, ħsul_, 
   {{0xa7f81709,0x60c800b5,0xdb0400db,0x75d4e1e1}},	//   _veñe, _bogm, _eriç, _غيرا, 
   {{0xa6d80008,0x2d9c0100,0x6f6800d8,0x69100139}},	//   _guðb, vwte_, ојов_, lçer, 
   {{0xa7f80f71,0x60c92e57,0x8f340022,0x00000000}},	//   _teñe, _dogm, неиц, --, 
   {{0xa7f80156,0xdee00114,0x6910236c,0x00000000}},	//   _heñc, коњи, nçer, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa7f80165,0x2eec0142,0xad2405af,0xe0d4014b}},	//   _jeñc, _wmff_, برخو, _овх_, 
   {{0x9b58ed7b,0xefe8027d,0xe454010f,0x2fd40244}},	//   мият_, _بعضو_, ויכט_, _تتاح, 
   {{0x5f901086,0x5b2401c0,0xdeb02503,0x6b88007c}},	//   _ришт, вьса, _абшы, _äggm, 
   {{0xa8a40a5b,0xdb340063,0x9e78011a,0xf9b40107}},	//   мрак, терњ, _ונופ, нарӯ, 
   {{0x60c80548,0x6f1801ab,0x83fc01d3,0xfaec01e2}},	//   _xogm, lltc, _időv, لګۍ_, 
   {{0x7f4c00fd,0x00000000,0x00000000,0x00000000}},	// [1d390] _çaqt, --, --, --, 
   {{0x4a5400d6,0x69100baa,0x00000000,0x00000000}},	//   _якос, tçes, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69102347,0x2a7c0198,0xdb052e58,0xe57c00de}},	//   rçes, ɗuba_, _priç, šķos_, 
   {{0xe66421ca,0xa7f81bce,0x260c05dc,0x394400d0}},	//   _отво, _deñc, _तुरी_, _čosi_, 
   {{0x29192e59,0xee240451,0x07081410,0x6910236c}},	//   llqa_, _مٽ_, _ريزي_, pçes, 
   {{0xfd8c0150,0x00000000,0x00000000,0x00000000}},	//   _ﺒﻴﺎﻥ_, --, --, --, 
   {{0x7cf400c0,0x00000000,0x00000000,0x00000000}},	//   kšra, --, --, --, 
   {{0x43748326,0x94842fe5,0x7f18a1a1,0x00000000}},	//   _سهار, _шырд, зіну_, --, 
   {{0x3ea405f5,0xaf00c01a,0xe0cc009e,0x92b4007b}},	//   хиог, лпыл, িফেন, _لحما, 
   {{0xa3d406e3,0xed4c2a60,0x60c92e5a,0x614000db}},	//   ानक_, یپی_, _togm, _شىشە, 
   {{0xf8c804c5,0x98ac005f,0x00000000,0x00000000}},	//   _ষষ্ঠ, īdī_, --, --, 
   {{0xbed40063,0xbdf81291,0x00000000,0x00000000}},	//   _подј, ترکا_, --, --, 
   {{0x4ab800f5,0x00000000,0x00000000,0x00000000}},	//   муся_, --, --, --, 
   {{0xf2d0008f,0xefe8001f,0xba180592,0xb8200210}},	//   נעל_, ሄደው_, سيرا_, _मरहम_, 
   {{0x2ca80175,0x3b84022e,0x00000000,0x00000000}},	//   cdcd_, _злиг, --, --, 
   {{0x7d1400e4,0xceb8002d,0x4ba402dd,0x91fc00b8}},	// [1d3a0] _ikys, blęd_, _алың, _udāv, 
   {{0xa3b019e5,0xa68002a9,0x04540023,0x00000000}},	//   टिन_, ллуд, _ዝበጻሕ, --, 
   {{0x25bc0139,0x00000000,0x00000000,0x00000000}},	//   _ƅula_, --, --, --, 
   {{0xa50409ac,0xd9100244,0x00000000,0x00000000}},	//   неха_, _ئیر_, --, --, 
   {{0x09d44251,0x96d400c7,0xc8a8000d,0x00000000}},	//   _হেপা, _ҧсҳә, _चोटट, --, 
   {{0xf1a52e5b,0x6f1805b1,0xb1a40209,0xdb04007c}},	//   ерин, xltc, ешик, _friå, 
   {{0xdb0405e4,0x7d1402f0,0x00000000,0x00000000}},	//   _asië, _okys, --, --, 
   {{0x66d8019f,0x7f4c0327,0x00000000,0x00000000}},	//   _yîko, _ħaqr, --, --, 
   {{0xef904bcf,0x91fc00b8,0xa5044140,0x2898008f}},	//   ایتد, _adāt, _чета_, ליקא, 
   {{0x15f4023e,0x09d400bd,0x7d1471d4,0x318c03e3}},	//   _आधार_, _হেফা, _akys, _həzm_, 
   {{0xa7f80022,0x09d4009e,0x9ed411ca,0x7ce401e7}},	//   _meña, _হেনা, хмэт_, _mórf, 
   {{0xa7f804d4,0xcb68004b,0x6b8801e3,0xafe448e5}},	//   _leña, وڅخه_, _äggk, _поел, 
   {{0xe0d401c0,0x20f40356,0xeb340107,0xa3b000bc}},	//   _явц_, răit_, нҷиш_, टिय_, 
   {{0xa7f80022,0xefe0001f,0x83fc01ed,0x7d140254}},	//   _neña, ዝነው_, _időt, _ekys, 
   {{0x38612e5c,0x7f4c008e,0x8bf800cc,0x98a00210}},	//   _bekr_, _çaqr, _ঘৰখন_, zmią_, 
   {{0x5a341cb8,0x318c03b9,0x94200073,0x00000000}},	//   унст, _nəzm_, _बरंच_, --, 
   {{0xb7840daf,0xa7f92e5d,0xfcc000fd,0xa6d8032e}},	// [1d3b0] кәре_, _beña, _тәэм, _auða, 
   {{0x260407ee,0x00000000,0x00000000,0x00000000}},	//   нчег, --, --, --, 
   {{0x03a4084c,0xd7f80139,0xa3b12e5e,0x00000000}},	//   ӂило, _җуя_, टिभ_, --, 
   {{0xdb04007f,0xdb08023a,0xaac401b9,0xe784005b}},	//   _asiè, älöi, _آتکن, _пуго, 
   {{0x03a52e5f,0xa7b40032,0xd4140024,0x62b400fb}},	//   тило, _яһау_, льшы, нғас_, 
   {{0xb1740023,0x00000000,0x00000000,0x00000000}},	//   _ከይኮነ_, --, --, --, 
   {{0x758001d5,0x7f4c025c,0xa6d808ce,0x048801ec}},	//   _نیلم, _ħaqq, _guða, _ошақ_, 
   {{0x91fc00b8,0xacb8002d,0x00000000,0x00000000}},	//   _adās, nlûd, --, --, 
   {{0x09d4045e,0x9394314e,0x8334c778,0x3e680137}},	//   _হেমা, _مجلا, _анах, үшүн_, 
   {{0x7d152e60,0x644800f3,0xfd48010b,0x4f040150}},	//   _skys, lcgi, мзок_, лжығ, 
   {{0xfce40364,0xc4d4033f,0xc12000fb,0x64480051}},	//   воно, _दवाओ, _күкһ, ocgi, 
   {{0x7ce401e7,0xcb08011a,0x00000000,0x00000000}},	//   _mórg, _ול_, --, --, 
   {{0x83fc00dd,0x60d92e61,0x62812e62,0x98a0107d}},	//   _idős, mkum, ogno, lmić_, 
   {{0x62812e63,0x60d92e64,0x38600115,0x7f4c0f77}},	//   ngno, lkum, _sekr_, _çaqq, 
   {{0x3f8d2e65,0x62812e66,0x60d8216b,0xa7f800c7}},	//   lteu_, igno, okum, _reña, 
   {{0xa7f8db58,0x7d14010e,0x5c8401af,0x00000000}},	//   _seña, _ukys, _скиғ, --, 
   {{0x3f8cebf1,0xa7f800e4,0xfc0421e0,0x98a005be}},	// [1d3c0] nteu_, _peña, _шпио, hmić_, 
   {{0x39440b32,0x60d92e67,0x3f8c0270,0x98a005be}},	//   _иног, hkum, iteu_, kmić_, 
   {{0x60d92e68,0xdb040077,0xa7f8056a,0x98a001a6}},	//   kkum, _oriú, _veña, jmić_, 
   {{0x385812a4,0x60d805be,0x49900214,0x332c01ab}},	//   _تشدد_, jkum, _دیفر, wmfx_, 
   {{0xa7f8172e,0x31d82cbc,0xa8003f51,0x7ce40174}},	//   _teña, बन्ध, _взял, _tórf, 
   {{0x7ce402d2,0xa6d802d2,0xf62400c0,0x00000000}},	//   _hórd, _tuða, _адго, --, 
   {{0x60d80036,0x2160013d,0xe7140066,0x00000000}},	//   fkum, атыг, _شيفت_, --, 
   {{0x60d818e0,0x09d402f5,0xa7f800fd,0x7ce402d2}},	//   gkum, _হেডা, _meñn, _jórd, 
   {{0x68e0084c,0x7ce400c6,0x24b40014,0x6414010a}},	//   _înde, _mórd, _جۆنگ_, _автă, 
   {{0xa3cc0034,0x81c80183,0x00000000,0x00000000}},	//   शहर_, _লেও_, --, --, 
   {{0xa7f8030a,0xe0cc01d9,0x1ad40183,0x7084004e}},	//   _neñn, _ڈٲل_, হোৱা, _агез, 
   {{0x52741f71,0x7ce40a90,0x3f8c00cf,0x83fc01ed}},	//   _шуғу, _nórd, bteu_, _időr, 
   {{0x3f8c0137,0x03c401e1,0x764c0b21,0xce952e69}},	//   cteu_, _bóṣe, _ofby, _балъ, 
   {{0xdef4069c,0x7d0c01e4,0xa6d8032e,0x91fc002b}},	//   _ወጻኢ_, _ĉase, _auðn, _udās, 
   {{0x4ea40046,0xab580205,0x00000000,0x00000000}},	//   _арқа, nyüz, --, --, 
   {{0x7ce52e6a,0x764c017a,0x5ce400f7,0x98e400db}},	//   _córd, _afby, _ۅكۉل, аюуд, 
   {{0xac9002dd,0x98a0107d,0xd138012d,0x00000000}},	// [1d3d0] _бақш, zmić_, _brąz_, --, 
   {{0xfd54002b,0x60d8012c,0xab5805d1,0x4eb000fe}},	//   _akaṇ, zkum, kyüz, _চকুল, 
   {{0x60d803f0,0x00000000,0x00000000,0x00000000}},	//   ykum, --, --, --, 
   {{0xa6d80008,0xe8241086,0x00000000,0x00000000}},	//   _guðn, _афго, --, --, 
   {{0xb0b4033f,0x60d80165,0xfb1800e5,0x00000000}},	//   _अफ़ग, vkum, _زریں_, --, 
   {{0xa7f8035b,0x04c8004b,0x62812e6b,0x7ce40174}},	//   _heño, _ګوري_, ugno, _tórg, 
   {{0x60d92e6c,0x814404fb,0x64a40124,0x3ea401b9}},	//   tkum, دنبن, _ишаз, қинг, 
   {{0xdb0400a3,0xd498ff02,0x60d8005f,0x7ce52e6d}},	//   _driù, _иру_, ukum, _kóre, 
   {{0x60d800de,0x00000000,0x00000000,0x00000000}},	//   rkum, --, --, --, 
   {{0xfe700597,0x3f8d2e6e,0x7ce4a737,0x60d92e6f}},	//   حدة_, rteu_, _móre, skum, 
   {{0x24740020,0x3f8d2e70,0x41541614,0xdb04007b}},	//   _አምስት_, steu_, _свес, _triú, 
   {{0x3f8c0137,0x4f2400db,0x00000000,0x00000000}},	//   pteu_, лдөб, --, --, 
   {{0xd110fe33,0x5fa00131,0xa6d802d2,0x91fc00cd}},	//   ावरण_, _ئەخم, _ruðn, _udār, 
   {{0x7f480944,0x7ce40077,0xde440244,0x00000000}},	//   mqeq, _sórd, _جیدو_, --, 
   {{0x3cd401d5,0xca6400c7,0x00000000,0x00000000}},	//   _бўпт, ресқ, --, --, 
   {{0x3f480248,0xb864027d,0x23a000bc,0x00000000}},	//   _kúu_, طارو, ओबाद, --, 
   {{0x6b8c074d,0xdd04005f,0xc7640c50,0x3f4801e1}},	// [1d3e0] ctcg, šsēd, لالى, _júu_, 
   {{0x6b580a1e,0x00000000,0x00000000,0x00000000}},	//   _רדיפ, --, --, --, 
   {{0x7ce403b2,0x7f48014f,0xe8a00139,0x27fc08a5}},	//   _tórd, hqeq, _ízğı, _þunn_, 
   {{0x73e400a7,0xe978008f,0xf5183b3c,0x603824cb}},	//   лоез, _אנטש, رتاش_, _kāmī, 
   {{0xe3ac3009,0x91fc0055,0x7ce52e71,0x1cb80327}},	//   كرو_, _adāp, _kórb, _ཛོན_, 
   {{0xe6412cb4,0xdb04003a,0x456401d9,0xa7f800fd}},	//   _герп, _priù, _چھنہ, _meñl, 
   {{0xdebc1772,0x6b880267,0x7ce40332,0x03d000b8}},	//   ስናን_, _äggv, _mórb, _māṅg, 
   {{0x1c0402ab,0x25d402e4,0xab5805d1,0xe614892e}},	//   रपाल_, _גולן_, ryüz, _сдс_, 
   {{0x7f480472,0xf41c05ac,0x00000000,0x00000000}},	//   gqeq, _ফলকৰ_, --, --, 
   {{0x83fc00dd,0xdb0408c2,0x03d000b8,0x00000000}},	//   _időp, _triù, _nāṅg, --, 
   {{0x02d4e58b,0x42d4003b,0x00000000,0x00000000}},	//   _тютю, _тіту, --, --, 
   {{0x13d800bd,0x70540597,0xa6d80008,0xc0f00023}},	//   _দেয়, _إنشا, _auðl, ልቀል_, 
   {{0xa1112e72,0xa6d80162,0x603800b8,0xa7f800c7}},	//   _اونت, _buðl, _cāmī, _reño, 
   {{0xa7f92e73,0x03d0002b,0x0ed801d3,0x205001e0}},	//   _seño, _cāṅg, _جاؤں_, _ктәр, 
   {{0x6b8c02fa,0x318c03be,0xa7f800c7,0x8a180120}},	//   stcg, _bəzi_, _peño, товс_, 
   {{0x7ce4013a,0x00000000,0x00000000,0x00000000}},	//   _póre, --, --, --, 
   {{0x4bc52e74,0x00000000,0x00000000,0x00000000}},	// [1d3f0] _төнг, --, --, --, 
   {{0xa3b0228d,0xa6d801a8,0x03d0002b,0x96e80816}},	//   टिस_, _guðl, _gāṅg, льха_, 
   {{0x32f4012d,0x56940395,0xbb38011a,0x847c0023}},	//   głym_, сахт, _שעתי, _ከምርሕ_, 
   {{0xa8a42e3f,0x84385f2e,0x318c06be,0x7f480455}},	//   _срок, نكار_, _gəzi_, yqeq, 
   {{0x7bc00129,0xdc0000a2,0x833428f3,0x76440a81}},	//   _àout, _oňýa, андх, ایہِ_, 
   {{0x321c0232,0x81b803f9,0x6b8801e3,0x3f4801e1}},	//   _byty_, _haɓɓ, _äggu, _rúu_, 
   {{0x45d40212,0xe4b001af,0x96080153,0x00000000}},	//   _товс, _гөлъ, _бэта_, --, 
   {{0xe2901efa,0xdc00010e,0x7ce4007b,0xd148d712}},	//   _گذر_, _aňýa, _mórc, دشون_, 
   {{0x70c401c6,0x200803e0,0x00000000,0x00000000}},	//   ргыг_, çci_, --, --, 
   {{0x61280432,0x7f480113,0xb40401b9,0x6d4401e4}},	//   _bölý, rqeq, _тўсқ, ĉkan, 
   {{0xa3b0068f,0x9258013e,0xc1a40022,0xa7f8013d}},	//   टिव_, _сахт_, _әыҷқ, _señl, 
   {{0x7c6400d1,0xaff40133,0xa6d802d2,0x03d0002b}},	//   گاھل, افیا_, _suðl, _sāṅg, 
   {{0x7f480869,0xa6d808a5,0x8e2c01d5,0xe7e40205}},	//   qqeq, _auðm, shdа_, vüşç, 
   {{0x60380055,0xdbc400c7,0x00000000,0x00000000}},	//   _cāmū, _ҳаиҩ, --, --, 
   {{0xc955106d,0xa96459df,0xfa8c02d3,0xee2c05d9}},	//   йтты, иира_, _ዝዝከር_, _ٺٽي_, 
   {{0xefb001d5,0x00000000,0x00000000,0x00000000}},	//   _اییگ, --, --, --, 
  
   {{0xb8fcfd3e,0x974801ed,0xcd440014,0x7ce40162}},	// [1d400] _तक_, اثرہ_, _پھۯٹ, _tórb, 
   {{0xf6248b30,0xf6543334,0xc0c00092,0x00000000}},	//   адзо, ртаю, ስዳሉ_, --, 
   {{0xa6d8008c,0x7ce52e75,0x00000000,0x00000000}},	//   _guðm, _górc, --, --, 
   {{0x81b80198,0x799c035a,0x32f40210,0x00000000}},	//   _gaɓɓ, _ippw, rłym_, --, 
   {{0x33f403b7,0x68e00311,0x321c19a5,0x32f4012d}},	//   јчес, _înda, _syty_, słym_, 
   {{0x91fc0618,0x81b803f9,0x53c402dd,0xa2f00212}},	//   _feāl, _zaɓɓ, _қазұ, опіч, 
   {{0xafe40579,0x7d04009a,0x25640209,0x4374216c}},	//   kvøð, knks, _васп_, _қутт, 
   {{0xa3b010dc,0xf65000db,0x00000000,0x00000000}},	//   टिश_, _دئڭ_, --, --, 
   {{0x752001a4,0xd010007b,0xefb007d6,0x00000000}},	//   mloz, ثلة_, تیشگ, --, 
   {{0xfe6c1473,0x75212e76,0x7d0c008f,0xa3b05690}},	//   ىگى_, lloz, _ĉasa, टिर_, 
   {{0x75200585,0xfe6d050d,0x4fc42bcb,0x00000000}},	//   oloz, رگو_, рсқа, --, 
   {{0x4c941064,0x752001a4,0x8d940150,0x5c740117}},	//   щимс, nloz, _ۇلتش, олют, 
   {{0x8f547c3c,0x799d0e2e,0x46c8012c,0xaac0687b}},	//   _انتش, _appw, रामह, शालक, 
   {{0x260c0490,0x752001f0,0x3f900276,0x5a440153}},	//   _तुझी_, hloz, ăzut_, жэта, 
   {{0x75212e77,0x00000000,0x00000000,0x00000000}},	//   kloz, --, --, --, 
   {{0x799c05b1,0x91fc005f,0xa6d80008,0xcca41075}},	//   _dppw, _reāl, _guðj, _اڭدى, 
   {{0x6d592e78,0x6e0001d9,0x0708038b,0xefe802d3}},	// [1d410] lpta, _دِژن, هيري_, _ህልዊ_, 
   {{0x45440597,0x7ce40077,0x6d58005c,0x78a001e4}},	//   منطق, _tórc, opta, ĵova, 
   {{0x7ce41d0e,0x799c02d0,0x4614007b,0xc5940798}},	//   _hóra, _gppw, حوار, сиеј, 
   {{0xa3b003ba,0x9b4497d1,0xd49801c0,0xfa5401b9}},	//   टिल_, _دنیو, ирч_, _پریگ, 
   {{0xd3786b62,0x00000000,0x00000000,0x00000000}},	//   ңчә_, --, --, --, 
   {{0x75200083,0x44280115,0xd6d800d4,0x272c06be}},	//   aloz, ĥa_, _ктс_, düng_, 
   {{0xe054687d,0x442801a2,0x7520033b,0x6d4c0306}},	//   لیات_, ťa_, bloz, íbal, 
   {{0x85040517,0x6600002d,0x00000000,0x00000000}},	//   _اورن, ûnku, --, --, 
   {{0x32f00075,0xdb0400a2,0x6d4c0115,0x21d4013a}},	//   تكۈز, _ariý, ŭbal, _běhá_, 
   {{0x63b92e79,0x818869f2,0x2bc82a8c,0xa1f401ed}},	//   _irun, _منطق_, ामना, _پڑتا_, 
   {{0x63b80008,0x2908033f,0xa6d801a8,0x41b400f1}},	//   _hrun, _ojca_, _auðk, _دمار, 
   {{0xa7f805c7,0x7ce40332,0xc2e401d5,0x00000000}},	//   _veñj, _bóra, _тўғи, --, 
   {{0x7ce40597,0x7bc039e2,0x799c035a,0x09d40011}},	//   _córa, _šoub, _sppw, _হেলা, 
   {{0xa1112e7a,0x63b801f7,0xfe440120,0x00000000}},	//   _اوچت, _mrun, _унко, --, 
   {{0xf2d004ac,0x3ea52e7b,0x00000000,0x00000000}},	//   לעך_, melt_, --, --, 
   {{0x7ce406d5,0x26c12e7c,0x63b92e7d,0x80d8015b}},	//   _fóra, _anjo_, _orun, বোর্, 
   {{0x6aa0000f,0x7b74e591,0x7ce4033f,0xf7482824}},	// [1d420] _űnfe, _اطبا, _góra, اجره_, 
   {{0x3ea41455,0x66d800c7,0x752001f5,0x00000000}},	//   nelt_, _oîku, wloz, --, 
   {{0x63b92e7e,0x75212e7f,0xd9b4215c,0x69100790}},	//   _arun, tloz, _بەزد, hçey, 
   {{0x26c0020c,0x63b84ebd,0x3ea52e80,0x1c1c033f}},	//   _enjo_, _brun, helt_, _नडाल_, 
   {{0x3ea417c0,0x75212e81,0xb7e401ee,0x00000000}},	//   kelt_, rloz, _уҫаҡ_, --, 
   {{0x6d592e82,0x39412e83,0x63b92e84,0x75212e85}},	//   ypta, _hiks_, _drun, sloz, 
   {{0x39412e86,0x3ea52e87,0x63b92e88,0x216415ed}},	//   _kiks_, delt_, _erun, бији_, 
   {{0xdb052e89,0xefe802d3,0xa6d808a5,0x3ea4072b}},	//   _krió, _ህልው_, _auðh, eelt_, 
   {{0x3940033d,0xe1f40058,0xe4d4036b,0x51d40014}},	//   _miks_, игә_, _اوقت_, _ژۯتھ_, 
   {{0x3ea41859,0x39412e8a,0x4d98109a,0xa7f800a2}},	//   gelt_, _liks_, акою_, _señk, 
   {{0x91fc00b0,0x7ce4002e,0xb628019b,0x46c82052}},	//   _meāk, _sóra, _ｔｈ_, रातह, 
   {{0x39407890,0x6d585c07,0xdb052e8b,0x272c05d1}},	//   _niks_, rpta, _asià, müne_, 
   {{0xdb04004e,0x272cd813,0x00000000,0x00000000}},	//   _friü, lüne_, --, --, 
   {{0x6d581f53,0x3ea4005f,0xa6d802d2,0x2bc83507}},	//   ppta, celt_, _guðh, ामबा, 
   {{0x272cefdd,0xdcf4029f,0x4c940209,0x394055ad}},	//   nüne_, _çağd, _дийс, _biks_, 
   {{0xdb041709,0x7ce52e8c,0x6f192e8d,0x26c00158}},	//   _brió, _tóra, lotc, _snjo_, 
   {{0x6d492e8e,0xc6f92e8f,0x7ce52e90,0xa6452e91}},	// [1d430] _hufa, анах_, _kórn, مخان, 
   {{0x6d492e92,0x6f18127b,0xcca40046,0x2efc0036}},	//   _kufa, notc, _اڭگى, nitf_, 
   {{0x68e00276,0x63b813bb,0xa7f8005a,0x6d480067}},	//   _îndo, _srun, _meñi, _jufa, 
   {{0x6d492e93,0x6f192e94,0x6aa405be,0x63b81486}},	//   _mufa, hotc, lejf, _prun, 
   {{0x29180286,0xed440451,0x2c1803d4,0x63b803b9}},	//   moqa_, _ڊپ_, নেৰে_, _qrun, 
   {{0xa5e52e95,0x68fc1444,0x6d48007f,0x12c40131}},	//   _любл, liqd, _oufa, كتىپ, 
   {{0x6f184fb5,0x272c03ee,0xf40c0133,0x00000000}},	//   dotc, güne_, _یڤه_, --, 
   {{0x63b92e96,0x3ea4097d,0xb8800122,0x7d0c0115}},	//   _trun, welt_, šíva, _ĉaso, 
   {{0x44392e97,0x63b92e98,0x6d4804c9,0x3ea52e99}},	//   _às_, _urun, _aufa, telt_, 
   {{0x6d492e9a,0x442d2e9b,0x7ce40005,0xa7f83eba}},	//   _bufa, _ize_, _córn, _ceñi, 
   {{0x3cc81b10,0x6d48198f,0x29180784,0xa7f80432}},	//   ално_, _cufa, koqa_, _deñi, 
   {{0x3ea4367a,0x6d492e9c,0x1ee403e6,0xee340006}},	//   selt_, _dufa, _گوتی_, ўню_, 
   {{0xdb052e9d,0x65640369,0x6d480077,0xefd4001f}},	//   _asiá, _lwjh, _eufa, ርቲው_, 
   {{0x39412e9e,0x6f181a0e,0x442c00ec,0x6d48198f}},	//   _siks_, cotc, _mze_, _fufa, 
   {{0x6d480537,0x442c0316,0xa6d8032e,0x68fc571b}},	//   _gufa, _lze_, _guði, fiqd, 
   {{0x442d2e9f,0xdb04e0ff,0x29180117,0x5ad401d3}},	//   _oze_, _prió, goqa_, _کےسا, 
   {{0x272cefdd,0x442d2ea0,0x6d492ea1,0x77c8dba2}},	// [1d440] züne_, _nze_, _zufa, шлаг_, 
   {{0x6d492ea2,0xc7943e1f,0x3940017a,0xb658109a}},	//   _yufa, ярсы, _wiks_, ршах_, 
   {{0x442d2ea3,0x394000da,0x942400ac,0x630c0154}},	//   _aze_, _tiks_, ətən_, িতায়_, 
   {{0x29180481,0x7ce52ea4,0x6910025c,0x66000413}},	//   coqa_, _móro, għed, únka, 
   {{0x442d2ea5,0x78b40153,0x6f1801d5,0x00000000}},	//   _cze_, mdyv, yotc, --, 
   {{0x272cefdd,0x442d2ea6,0x69c00077,0xf1a80b24}},	//   tüne_, _dze_, _ánec, لابه_, 
   {{0x3f800325,0x442c00b4,0xdb04002e,0xa7f804d4}},	//   _āhua_, _eze_, _jriñ, _reñi, 
   {{0x6d492ea7,0x78b52ea8,0x272d2ea9,0x6f18c008}},	//   _rufa, ndyv, rüne_, wotc, 
   {{0x6d492eaa,0xa7f80789,0x272c0790,0xa0640063}},	//   _sufa, _peñi, süne_, цања_, 
   {{0x7ce401e1,0x71a52eab,0x68fc01d5,0x00000000}},	//   _bóro, _мазз, ziqd, --, 
   {{0x442c5834,0x22912eac,0x6d48300b,0x91c41b15}},	//   _zze_, _آلمس, _qufa, _хәлл, 
   {{0xf1a8168d,0x6d4818f7,0x00000000,0x00000000}},	//   _ماڵه_, _vufa, --, --, 
   {{0xa7f92ead,0x6d48020b,0x7ce40587,0xdb050c80}},	//   _heñv, _wufa, _tórn, _ariñ, 
   {{0x6d492eae,0xa7f80dd4,0x7ce4f8bc,0xdb040156}},	//   _tufa, _keñv, _fóro, _briñ, 
   {{0x5b1410f5,0x28680640,0x395800d8,0x7ce40162}},	//   ємст, ирао_, _ctps_, _kórl, 
   {{0x32f4012d,0x2bc808f2,0x272c06be,0xda340139}},	//   pływ_, ामदा, künc_, фесы, 
   {{0xace84667,0xd7940801,0xa7f805c7,0x999400e2}},	// [1d450] _مرکل_, митъ, _leñv, ļešu_, 
   {{0x442c07ab,0x6798044e,0xe73c00d8,0x1f58008f}},	//   _rze_, _ህይወቱ_, _opõe_, ידמא, 
   {{0x91fc0421,0xdb040bf2,0xa7f80156,0x442d2eaf}},	//   _feāi, _griñ, _neñv, _sze_, 
   {{0x29180107,0x83fc01d3,0x68fc1898,0x00000000}},	//   qoqa_, _időz, qiqd, --, 
   {{0xa3a4fa0c,0x4824129d,0xdb04032e,0x00000000}},	//   تحان, _رىسق, _krið, --, 
   {{0xa6d8008c,0xa7f8030a,0xb7d8011a,0x00000000}},	//   _auðv, _beñv, _הקשי, --, 
   {{0xddc0084c,0x1a9c008f,0xc0e40395,0x00000000}},	//   _menţ, ייגע, зойк, --, 
   {{0x442d2eb0,0x00c8cd5f,0xa7f80156,0xe3bc035b}},	//   _tze_, слик_, _deñv, _áño_, 
   {{0x442d2eb1,0x249d2eb2,0x7e9805d4,0xd9dc00eb}},	//   _uze_, _ibum_, منظر_, _ডোম, 
   {{0x6264117d,0x7ce40306,0x98a00427,0x6910031c}},	//   _ذائق, _póro, vlič_, nħeb, 
   {{0xa3b01ab2,0xa7f80dd4,0x00000000,0x00000000}},	//   टिक_, _geñv, --, --, 
   {{0xa6d802d2,0x61100356,0x48fc141f,0x00000000}},	//   _guðv, făle, रोमो_, --, 
   {{0x39580789,0x249c030a,0xa7f80165,0xbc1802dd}},	//   _stps_, _mbum_, _zeñv, сіні_, 
   {{0x249c0407,0x91fc0055,0xdb040489,0x7ce40162}},	//   _lbum_, _adāy, _priñ, _tóro, 
   {{0xe3c00729,0xfce40c60,0x39580327,0xa9640d1d}},	//   ্নিব, _ноко, _qtps_, зиса_, 
   {{0x80a0006d,0xf1b000c8,0xa6d80162,0x39e80107}},	//   _कॉमे, עסן_, _muðu, адҳо_, 
   {{0xdb042242,0x6110054e,0x00000000,0x00000000}},	// [1d460] _frið, căle, --, --, 
   {{0x249c0086,0x7cf4b700,0x41bc11bc,0xddc0054e}},	//   _abum_, ršru, ्मास, _genţ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf7450c5b,0x249c01ab,0xed54008f,0xa7f80165}},	//   _немо, _cbum_, לבער_, _reñv, 
   {{0xdebc02d3,0xa6d801a8,0xe1f401c0,0xe8d40375}},	//   ድሓን_, _auðu, үгч_, _זוכר_, 
   {{0xe73406bb,0x249c02e3,0xa6d808a5,0x3870058a}},	//   _нея_, _ebum_, _buðu, layr_, 
   {{0xe5a04123,0xa7f8002e,0x7ce40077,0xdef000b7}},	//   _пири, _deñu, _pórl, ልጠና_, 
   {{0x249cb6de,0x38700198,0x272c04cc,0xcf900014}},	//   _gbum_, nayr_, müna_, ن٘ب_, 
   {{0xe0cd2eb3,0x272c05d5,0x7afc0857,0x00000000}},	//   ازى_, lüna_, _ompt, --, 
   {{0xa7f80156,0x620401d3,0xb238007b,0x3870058a}},	//   _teñv, árlá, _هكذا_, hayr_, 
   {{0x38700227,0xa7f80165,0xa6d80413,0x272c05d5}},	//   kayr_, _heñt, _guðu, nüna_, 
   {{0x7afd2eb4,0xc4080014,0xacb8000f,0xec140166}},	//   _ampt, _اتہٕ_, mlûk, земә_, 
   {{0x272c07c5,0x38700076,0xa2d002a0,0xce940395}},	//   hüna_, dayr_, बॉक्, _жалъ, 
   {{0x952c031c,0x7774007c,0x00000000,0x00000000}},	//   _ཧེའི_, dsyx, --, --, 
   {{0xd30801dc,0xacb8000f,0x5e980375,0xf9b40107}},	//   yện_, nlûk, _הבוק, марӯ, 
   {{0x58d4468d,0x91fc0421,0xdb040139,0x272c05d5}},	//   ност, _feāv, _asiä, düna_, 
   {{0xdb040579,0xac900150,0x00000000,0x00000000}},	// [1d470] _trið, _жақш, --, --, 
   {{0xe8dc063f,0xceb92eb5,0xdd700014,0x4a540139}},	//   _ipọd_, ndę_, _تھیک, _юкос, 
   {{0xd87817de,0x272c07de,0x38700169,0x00000000}},	//   زمەت_, güna_, bayr_, --, 
   {{0xa7f80407,0x7d0c01e4,0xa6d81427,0x91fc00b8}},	//   _señu, _ĉask, _ruðu, _udāy, 
   {{0xa6d81bb0,0xddc00232,0xd7f92eb6,0x7afc0857}},	//   _suðu, _menš, _еур_, _ympt, 
   {{0x272c0428,0xceb8033f,0xddc000ef,0x00000000}},	//   büna_, jdę_, _lenš, --, 
   {{0x6ab4036b,0x950800dd,0x8ff80022,0x00000000}},	//   _maxf, _کہنے_, ҧхьу_, --, 
   {{0x918404a9,0xa7f8002e,0x6ab401e3,0xbfc401ec}},	//   رجىم, _weñu, _laxf, дбик, 
   {{0x8cd08b95,0xa24401d3,0x00000000,0x00000000}},	//   धानो, _ٹیبل_, --, --, 
   {{0x929400f3,0x00000000,0x00000000,0x00000000}},	//   _пауц, --, --, --, 
   {{0x230400ec,0x53380354,0x00000000,0x00000000}},	//   _وڪڻي_, _хутă, --, --, 
   {{0xddc0005f,0xe0840046,0xc1040b61,0x7ce403b2}},	//   _cenš, _ءجاي, _توصي, _tórm, 
   {{0x800801ed,0x3870062c,0x61e12eb7,0x9ba4129d}},	//   _براہ_, vayr_, lynl, رەدى, 
   {{0xe8fc24ba,0xfe7018a2,0x00000000,0x00000000}},	//   _amû_, _شدت_, --, --, 
   {{0x61100276,0x6ab401f5,0xdef0001f,0x00000000}},	//   călc, _daxf, ልጠኛ_, --, 
   {{0x2bc803ce,0x83c40116,0x00000000,0x00000000}},	//   ामशा, _ﯪﺳﺎﺳ, --, --, 
   {{0x7d0c0115,0xf0900375,0x61e0015d,0x273000d1}},	// [1d480] _ĉash, כנן_, hynl, ھىمس, 
   {{0xe734005e,0x61e12eb8,0xa680084c,0x38700067}},	//   деу_, kynl, клуд, sayr_, 
   {{0xa7f8030a,0xa6d808a5,0xf86400f3,0x395c01d3}},	//   _beñs, _auðs, _овно, ítsd_, 
   {{0x272c07c5,0xceb8012d,0xa5042f5c,0x61e000a2}},	//   rüna_, zdę_, меха_, dynl, 
   {{0xe3ad2eb9,0xb4ac1d8a,0xa7f800a2,0x97840214}},	//   لرو_, _कसी_, _deñs, _سیاه, 
   {{0x2c180c58,0xa3b00490,0x00000000,0x00000000}},	//   নেকৈ_, टिज_, --, --, 
   {{0xda001715,0x7ce40034,0xdebc0023,0x2ca92eba}},	//   ोपित_, _córk, ድናን_, yecd_, 
   {{0xceb8068f,0x6124009d,0x00000000,0x00000000}},	//   wdę_, мцыг_, --, --, 
   {{0xa6d805f7,0x61e00076,0xee840276,0xba040092}},	//   _guðs, aynl, мыно, _ወግ_, 
   {{0xa6d803b2,0x23a4010b,0xe28001af,0xceb80153}},	//   _huðr, _ювуп_, _алфи, udę_, 
   {{0x4c94074d,0x7ce4179a,0xceb83ee4,0x2ca8009a}},	//   нинс, _kórh, rdę_, tecd_, 
   {{0x63c40724,0x216400a7,0x6ab40009,0x2bc8013a}},	//   _ürnä, _цици_, _saxf, ामला, 
   {{0xef300022,0x272c002f,0x00000000,0x00000000}},	//   _иҭиы, dünn_, --, --, 
   {{0xce9402e8,0x1ec401a9,0x00000000,0x00000000}},	//   _чакъ, _олчи_, --, --, 
   {{0x1958abc6,0x19952ebb,0x09d404c5,0x61100311}},	//   дасы_, каря, _হেজা, lăla, 
   {{0x2008012d,0x4c9400d8,0xe70801e2,0x00000000}},	//   źcie_, _џипс, ښتان_, --, 
   {{0x47352ebc,0x4814030d,0x00000000,0x00000000}},	// [1d490] енас, хмас, --, --, 
   {{0x7d0c010f,0xa7f800a2,0xa6d8032e,0x00000000}},	//   _ĉasi, _señs, _ruðs, --, 
   {{0xa7f80156,0x88580276,0x56942bb6,0xa6d802d2}},	//   _peñs, _нинс_, тахт, _suðs, 
   {{0xdb04067c,0xe4c808f0,0x395c00e5,0x00000000}},	//   _apiè, غبان_, ítse_, --, 
   {{0xdb040254,0x61e00142,0x00000000,0x00000000}},	//   _eriõ, wynl, --, --, 
   {{0x41b52ebd,0x61e000ee,0xf8ac0014,0x7ce4013a}},	//   есит, tynl, _پکہ_, _pórk, 
   {{0xa3b003f8,0xe80000ab,0xa6d802d2,0x00000000}},	//   टिङ_, _रेता_, _fuðr, --, 
   {{0x7074183c,0xa6d82833,0xb4b40139,0x7a0c01d3}},	//   ىمىز_, _guðr, _писә, lőté, 
   {{0x61e06ab9,0xa3b801d9,0xf07400dd,0x90e400db}},	//   synl, _بازر_, ریوں_, ئسىن, 
   {{0x61e003a2,0x2a44001f,0xcee801d9,0x2bc007b7}},	//   pynl, ኒስትሮ, ِرَن_, शिना, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa104034c,0x272c29ef,0x7ce52ebe,0x3154010f}},	//   _غذاه, küno_, _kóri, _װיסן_, 
   {{0x60c92ebf,0x61100356,0x00000000,0x00000000}},	//   _ingm, căla, --, --, 
   {{0x91fc00da,0x3eb800e2,0x7ce40736,0xb0600108}},	//   _teāt, ēsts_, _móri, äävi, 
   {{0x64580607,0x7ce401e1,0x57c80c22,0x395c0d49}},	//   _ofui, _lóri, रम्ह, ëts_, 
   {{0xfd1020d3,0xb4ac0574,0xa3cc1025,0x395c00da}},	//   _حجت_, _कसे_, षमा_, īts_, 
   {{0xa7a44c0f,0x3f8c0137,0xf77000c6,0x36c415d5}},	// [1d4a0] нкта_, nueu_, طاء_, нбаг, 
   {{0x7d052ec0,0x64580381,0xa6d8041e,0x00000000}},	//   liks, _afui, _suðr, --, 
   {{0x60c8014f,0x3f8c003e,0x64580332,0x74a4041b}},	//   _ongm, hueu_, _bfui, ејле, 
   {{0x798d2ec1,0x7d052ec2,0xdb040142,0x00000000}},	//   mubw, niks, _eriô, --, 
   {{0x798d01bc,0xf7712ec3,0x2bc038d2,0x237400f2}},	//   lubw, _حاج_, शिया, فمند_, 
   {{0x60c92ec4,0x7ce4021c,0x00000000,0x00000000}},	//   _angm, _dóri, --, --, 
   {{0x798c1419,0xe7352ec5,0x3f8c0421,0x7d04023a}},	//   nubw, _чер_, eueu_, kiks, 
   {{0x91fc0607,0x7d04023a,0xfa0003d4,0x45340064}},	//   _seās, jiks, _এডাল_, _ахут, 
   {{0x7d04434d,0x3f8d2ec6,0x752090ae,0x7ce402d2}},	//   diks, gueu_, mooz, _góri, 
   {{0x798d2ec7,0x75200a49,0x60c8047e,0xe3b4013d}},	//   kubw, looz, _engm, _ябу_, 
   {{0x7d052ec8,0x798c0086,0x62740050,0x21640117}},	//   fiks, jubw, _سٕنز_, _зихи_, 
   {{0x75202ad1,0x7d0401f4,0x645c022e,0xb4ac28fe}},	//   nooz, giks, аqiy, _कसो_, 
   {{0x764c0076,0x5c740153,0x2fd00432,0x6f0400e5}},	//   _ogby, ылят, _çyg_, ékcs, 
   {{0x798c04ba,0x7520007f,0x00000000,0x00000000}},	//   fubw, hooz, --, --, 
   {{0x798c046a,0x7d052ec9,0x75200337,0xc8c80133}},	//   gubw, biks, kooz, ووسن_, 
   {{0x764c006a,0x75201418,0xfda40124,0x92ac0154}},	//   _agby, jooz, _рышҟ, গায়_, 
   {{0xd36421ef,0x752004ba,0xd7e400d3,0x7a0c01d3}},	// [1d4b0] _دۇ_, dooz, ліфо, tőté, 
   {{0x798c1594,0x645804cc,0x09c400c7,0x00000000}},	//   bubw, _sfui, _иӡбо, --, 
   {{0x0df00201,0x7ce40162,0x3f9803e0,0x58e000cc}},	//   _ኃላፊ_, _sóri, çsuz_, _নগৰী, 
   {{0xdc9c010f,0xd1800023,0x00000000,0x00000000}},	//   ּיגל, _ከርፋሕ_, --, --, 
   {{0xd04c013f,0x6e28017a,0x2d6c0118,0xee2400ec}},	//   _ɔkɔd, _lyfb, hře_, _چٽ_, 
   {{0x7d052eca,0x6110054e,0x69c00327,0xe570007b}},	//   ziks, găln, _ġnej, _مطر_, 
   {{0x75202f99,0xa490315b,0x7d040784,0xe4a4361e}},	//   booz, _میات, yiks, _прао, 
   {{0x2cb801b9,0x04c835f9,0x3f8c004e,0x7ce40162}},	//   _naqd_, _توري_, tueu_, _tóri, 
   {{0x7d04aecc,0x798c00ca,0x68e00311,0x7ce40162}},	//   viks, zubw, _îndu, _kórv, 
   {{0x92b40592,0x7d052ecb,0xccf80118,0xfe70007b}},	//   _محما, wiks, spěl_, جدة_, 
   {{0x7d052ecc,0x91fc0421,0xdb0401e7,0xf650011a}},	//   tiks, _afāf, _tsiú, יצי_, 
   {{0x60c92ecd,0xb060005b,0x50b4009d,0xfbac0118}},	//   _ungm, ääti, _бсшу, टबलम, 
   {{0x3f8c00f7,0x798c0223,0x3d00033f,0x213c031c}},	//   queu_, wubw, _लगीं_, mmuh_, 
   {{0x798ce19c,0x7d052ece,0x2d6c0316,0x3f800055}},	//   tubw, siks, bře_, _āhuh_, 
   {{0x213c0548,0x7520009f,0x6f040036,0x798c0083}},	//   omuh_, yooz, _wébè, uubw, 
   {{0x798c2dab,0x6b8c0589,0xfbc400d8,0x98a00064}},	//   rubw, bucg, _абио, klią_, 
   {{0x7d140124,0x213c0548,0x798c1418,0x75200083}},	// [1d4c0] _ijys, imuh_, subw, vooz, 
   {{0x75200c8a,0x80a0228a,0x7f4c0798,0xdb08005b}},	//   wooz, क्ते, _éaqu, äläi, 
   {{0xd6b404c5,0x798c0117,0x00000000,0x00000000}},	//   ঘালয, qubw, --, --, 
   {{0x80a01fd5,0xe8000d2c,0xa9a012b9,0xd91017a6}},	//   _कॉले, _रेवा_, _тиюд, _ایر_, 
   {{0xd2500b38,0x75212ecf,0x98a00210,0x00000000}},	//   مچا_, rooz, glią_, --, 
   {{0xf1a4036b,0x752004ba,0x6d5cb4a2,0x764c03ac}},	//   врин, sooz, _épag, _ugby, 
   {{0x75212ed0,0x7ce408a5,0x318c03e3,0x6aa000e5}},	//   pooz, _hóru, _həzz_, _önfe, 
   {{0x69c12ed1,0x2d6c00bc,0x7d1400a2,0x204c0023}},	//   _šnek, vře_, _njys, _ቀዳማይ, 
   {{0xb42400aa,0x204c02d3,0x7ce52ebe,0xb4ac05b3}},	//   _شعرو, _ቀዳመይ, _jóru, क़ी_, 
   {{0x7d14010e,0x2d6c00bc,0x20092ed2,0x7ce401e7}},	//   _ajys, tře_, úcia_, _móru, 
   {{0x7c340432,0x6110054e,0x00000000,0x00000000}},	//   _azyr, călo, --, --, 
   {{0x6910025c,0xdde0013d,0x00000000,0x00000000}},	//   għel, рәшү, --, --, 
   {{0x7d0c0115,0x6fd40e55,0x5c0401c4,0x00000000}},	//   _ĉast, _جزائ, аяра, --, 
   {{0x2fc52ed3,0x7c340589,0xda000073,0x2d6c0118}},	//   _irog_, _dzyr, ोपंत_, pře_, 
   {{0x2fc40363,0x3cf001bf,0x6fd80154,0x1dd400ae}},	//   _hrog_, _flyv_, _বইয়ে, _لبيع_, 
   {{0x2fc52ed4,0x7d14044e,0x7ce403b2,0x2bc001ad}},	//   _krog_, _gjys, _bóru, शिदा, 
   {{0x386439b3,0x2d9c1f02,0x7ce40332,0xd774007b}},	// [1d4d0] ñora_, ltte_, _córu, لالع, 
   {{0x2d9d2ed5,0xa6452ed6,0x272c01d3,0x88a00133}},	//   otte_, نخان, münk_, _گیرۆ, 
   {{0x272c00dd,0x78a40158,0x7ce4003a,0x2d9c0790}},	//   lünk_, _fbkv, _eóru, ntte_, 
   {{0x7ce4b288,0x2d9d2ed7,0x93242a9f,0x1dc007b7}},	//   _fóru, itte_, یرون, षितत, 
   {{0x2fc40b89,0x2d9c01f5,0x272c01d3,0x69100327}},	//   _nrog_, htte_, nünk_, nħem, 
   {{0xe5c4136b,0x5ea403d4,0x6230035b,0x00000000}},	//   _исбо, _কোনে, аҵзу, --, 
   {{0x7ce52ed8,0xd6d8084c,0x758012ea,0x55e400cf}},	//   _kórt, _ртя_, _هیلم, _коёб, 
   {{0x272c01ed,0x3d0000e1,0x2fc40332,0x7ce402d2}},	//   künk_, _लगें_, _brog_, _jórt, 
   {{0x2d9d2ed9,0x7ce52eda,0x2fc40142,0xacb8000f}},	//   ette_, _mórt, _crog_, toûn, 
   {{0x2fc52edb,0x442d2edc,0xef142daf,0xb060d62e}},	//   _drog_, _iye_, лмы_, ääri, 
   {{0x442d2edd,0xd200c947,0x40952ede,0x2fc406af}},	//   _hye_, _мүшк, _ملار, _erog_, 
   {{0x442c0c8a,0xd850063f,0x7ce400e4,0xeb9c0158}},	//   _kye_, _pọmp_, _nórt, ftø_, 
   {{0x442c0796,0x2d9cbb46,0x3ea52edf,0x2fc52ee0}},	//   _jye_, atte_, _билг, _grog_, 
   {{0x442c10f5,0xed4c05d9,0x7ce404d4,0x60d92ee1}},	//   _mye_, _کپي_, _aórt, ljum, 
   {{0x442d2ee2,0x00000000,0x00000000,0x00000000}},	//   _lye_, --, --, --, 
   {{0x442d2ee3,0x7ce40005,0x00000000,0x00000000}},	//   _oye_, _córt, --, --, 
   {{0x442c08d7,0xdca52ee4,0x8cd00950,0x41c4012d}},	// [1d4e0] _nye_, _бақи, धारो, विडस, 
   {{0x60d92ee5,0x98a12ee6,0xdce40139,0x7b64008e}},	//   hjum, klić_, _iqnı, _итүе, 
   {{0x442d2ee7,0x6b8000b0,0x98a02630,0x237c0200}},	//   _aye_, _āngi, jlić_, _avuj_, 
   {{0x442d2ee8,0x60d80a49,0x7ce406ea,0x98a00210}},	//   _bye_, jjum, _tóru, dlić_, 
   {{0x442c01aa,0x60d8020c,0x98a0033f,0x930400c7}},	//   _cye_, djum, elić_, аҟал, 
   {{0x2d9c2759,0x68e0084c,0x80a03874,0x7ce52ee9}},	//   ytte_, _îndr, क्से, _kórs, 
   {{0x272c01ed,0x442c0375,0x2fc40098,0x98a02630}},	//   zünk_, _eye_, _srog_, glić_, 
   {{0x442c662e,0x35a400c7,0x60d92eea,0x67200e04}},	//   _fye_, _иаҳг, gjum, čnje, 
   {{0x442d2eeb,0xf5a00150,0x6fd8015b,0xd010007b}},	//   _gye_, _ءﺷﻮﻝ, _বেড়ে, تلة_, 
   {{0xfe6c1c5c,0x60d80869,0x98a04bc9,0x272c00e5}},	//   وگى_, ajum, blić_, vünk_, 
   {{0xdeec3e25,0x7ce40030,0x442c24b4,0x00000000}},	//   _ғы_, _nórs, _zye_, --, 
   {{0x2fc52eec,0x2d9d2eed,0x272c00dd,0xd060013f}},	//   _trog_, rtte_, tünk_, _ɑtɛn, 
   {{0x9b592eee,0x2fc40004,0x2d9d2eef,0xcb340395}},	//   лият_, _urog_, stte_, иемъ, 
   {{0x7ce40597,0x272c01ed,0x2d9caac5,0xeb9c01bf}},	//   _sórt, rünk_, ptte_, rtø_, 
   {{0x7ce52ef0,0x272c01ed,0xeb9c08fb,0x80a07688}},	//   _pórt, sünk_, stø_, क्वे, 
   {{0x272d0ddf,0x00000000,0x00000000,0x00000000}},	//   pünk_, --, --, --, 
   {{0x7ce40789,0x98a096c0,0x272c010e,0x8674003b}},	// [1d4f0] _vórt, zlić_, lüni_, илає, 
   {{0x442d2ef1,0x7ce52ef2,0x7aec0113,0x497463dd}},	//   _rye_, _fórs, ckbt, _клос, 
   {{0x442d2ef3,0x60d92ef4,0x2bc00157,0x7ce4033f}},	//   _sye_, yjum, शिवा, _górs, 
   {{0x442d2ef5,0x7ce41709,0xd5b80220,0x98a0107d}},	//   _pye_, _hórr, ысу_, vlić_, 
   {{0xd8386bd5,0x60d8022e,0x34b00633,0x00000000}},	//   _бэр_, vjum, زموز, --, 
   {{0x442c21a3,0x60d92ef6,0x272d1be6,0x00000000}},	//   _vye_, wjum, küni_, --, 
   {{0x442d2ef7,0x272c00a2,0x00000000,0x00000000}},	//   _wye_, jüni_, --, --, 
   {{0x00c84a69,0x442d2ef8,0x00e407fb,0x98a0248d}},	//   тлик_, _tye_, ржин, rlić_, 
   {{0x442d2ef9,0x80a12a27,0x60d92efa,0x98a01505}},	//   _uye_, क्षे, rjum, slić_, 
   {{0x63b92efb,0x7e5400ea,0xd40401a9,0x00000000}},	//   _isun, штиц, _уяси, --, 
   {{0x41b52efc,0xee352efd,0x42280022,0x51840024}},	//   _خمار, инь_, _рхаҭ_, _гуча, 
   {{0x60d8031c,0x00000000,0x00000000,0x00000000}},	//   qjum, --, --, --, 
   {{0x6d583209,0xbc180220,0x92d803d4,0xfc3001e2}},	//   aqta, тіні_, াসৰ_, تحد_, 
   {{0x7ce52efe,0x63b8055a,0x80a007af,0x2bc84244}},	//   _córr, _msun, क्रे, ामजा, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x78641d18,0xc9540953,0xb864a4a7,0x8d84009f}},	//   рказ, стры, شارو, _اشون, 
   {{0xb8dc1b13,0xc764525b,0x63b92eff,0x3f8c00cf}},	// [1d500] _इस_, مالى, _nsun, nreu_, 
   {{0x7ce41125,0x6b780677,0x2bc007b7,0x00000000}},	//   _tórs, _שרינ, शिरा, --, 
   {{0xd91060b3,0x7bc41455,0x2d98010b,0xb7c400de}},	//   _فیس_, lvku, _äpet_, _saģē, 
   {{0x29040064,0xb7c400ef,0x00000000,0x00000000}},	//   _įnag_, _paģē, --, --, 
   {{0x272c0209,0x739801ec,0x17e400cc,0x00000000}},	//   züni_, ттес_, _নেৰি, --, 
   {{0x3f8d2f00,0x6d5802d3,0x7bc40254,0x00000000}},	//   dreu_, yqta, ivku, --, 
   {{0x63b8675a,0xd4c42cc8,0x48fc0892,0x63005c32}},	//   _esun, _гөлк, रोको_, توول, 
   {{0x73e52f01,0x3f8d2f02,0x80a0694b,0xe6140395}},	//   _кобз, freu_, क्ले, _тдс_, 
   {{0x7d0c01e4,0x543400ec,0x00000000,0x00000000}},	//   _ĉasp, _اڱار, --, --, 
   {{0x2f540046,0x00000000,0x00000000,0x00000000}},	//   лтүс, --, --, --, 
   {{0x6d580cfe,0x6678008f,0x3f8c004e,0x00000000}},	//   uqta, כטיק, areu_, --, 
   {{0x321c1730,0x3f8d2f03,0x63b92f04,0xdfcc05d9}},	//   _ixty_, breu_, _ysun, _ڊيم_, 
   {{0x92d811ba,0x9d192f05,0x3f8c004e,0x727000b7}},	//   াসী_, роят_, creu_, _ጥንታዊ_, 
   {{0x2dc800f3,0xbd00032e,0xde54003b,0x00000000}},	//   _аћин_, _þéna, _каші_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc8d001ad,0x00000000,0x00000000,0x00000000}},	//   हाइट, --, --, --, 
   {{0x8c48010e,0x7ce40332,0x00000000,0x00000000}},	// [1d510] _duşü, _tórr, --, --, 
   {{0x7d2400d7,0x00000000,0x00000000,0x00000000}},	//   ľusť, --, --, --, 
   {{0xa8509e7e,0x38600a73,0x63b92f06,0x20340023}},	//   _менә, _ffkr_, _ssun, _ብድሕር, 
   {{0x63b8020b,0xdb0400e4,0xa8a52f07,0xa7f80432}},	//   _psun, _ipiá, _трок, _meñz, 
   {{0xd30807ae,0x7ce401e7,0x539800d4,0x00000000}},	//   yệt_, _mórp, ивця_, --, 
   {{0x63b802f0,0x6110054e,0x20080419,0x65900150}},	//   _vsun, măli, úcim_, _қағу, 
   {{0xc0c40116,0xdcf001ef,0x00000000,0x00000000}},	//   йәди, _řečo, --, --, 
   {{0x63b92f08,0x6564d58b,0x21292f09,0x3f8d2f0a}},	//   _tsun, _itjh, ôch_, treu_, 
   {{0x63b92f0b,0x7ed44e74,0xfeb812ea,0x3f8c004e}},	//   _usun, مزدا, هادت_, ureu_, 
   {{0x3f8d2f0c,0x00000000,0x00000000,0x00000000}},	//   rreu_, --, --, --, 
   {{0x69c41711,0x925821f3,0x91f400ae,0x00000000}},	//   jvje, _тахт_, _وأما, --, 
   {{0x7ce40048,0x656400fb,0x69c41711,0x3f8d2f0d}},	//   _córp, _mtjh, dvje, preu_, 
   {{0x7050dffc,0x69c4000f,0x21c4004d,0x00000000}},	//   _عنوا, evje, _hđh_, --, 
   {{0x61100276,0xafe00116,0xacb8002d,0x80d400dc}},	//   dăli, _хошл, slûp, भावे, 
   {{0x6564052f,0x4ea400d8,0x00000000,0x00000000}},	//   _ntjh, _фрча, --, --, 
   {{0x15d800e5,0x00000000,0x00000000,0x00000000}},	//   یداں_, --, --, --, 
   {{0x65642784,0x78b401fa,0xddc0012c,0xa7f80165}},	// [1d520] _atjh, _čavč, _jenž, _zeñz, 
   {{0xf6552f0e,0xdb04068c,0xddc000d7,0xc81400d4}},	//   стаю, _esiò, _menž, ієть, 
   {{0x2a540375,0xddc00030,0x69c42630,0xa7f8008e}},	//   _לבין_, _lenž, cvje, _meñy, 
   {{0x672004b9,0xb0a42c35,0x00000000,0x00000000}},	//   čnja, _कॉंग, --, --, 
   {{0x656401af,0x6110054e,0xb9f40023,0x78b4016d}},	//   _etjh, căli, _ምሰ_, meyv, 
   {{0x21c40208,0x78b4035a,0x39580108,0x00000000}},	//   _bđh_, leyv, _kups_, --, 
   {{0xded4044e,0x25a80306,0x69c008a5,0x216018bc}},	//   ኮኑን_, čilá_, _ánet, птыг, 
   {{0x92d82aab,0xf12027c6,0x80d4076e,0xf50400db}},	//   াসে_, मवेद_, भाषे, _узбо, 
   {{0x69c41e31,0xb38400ee,0x00000000,0x00000000}},	//   zvje, _ылал, --, --, 
   {{0xdb040077,0x39592f0f,0xe2944727,0x78b4014f}},	//   _osiñ, _oups_, _гаф_, heyv, 
   {{0xa11003b6,0x78b40175,0x80a0000d,0x272c0254}},	//   _کونت, keyv, _कउचे, münt_, 
   {{0xa1540302,0xb14400a8,0xf8a80846,0x78b40022}},	//   _הבאה_, _унел, ङ्मय, jeyv, 
   {{0xdb04094a,0x39581497,0x7bc001ef,0x00000000}},	//   _asiñ, _aups_, _šour, --, 
   {{0xc0dc044e,0xa7f80156,0x61100356,0x69c4036e}},	//   ሕዳር_, _teñz, văli, tvje, 
   {{0x39592f10,0x00000000,0x00000000,0x00000000}},	//   _cups_, --, --, --, 
   {{0x3d100f8b,0x61100276,0x69c52f11,0x00000000}},	//   tšwe_, tăli, rvje, --, 
   {{0x69c51f18,0xe8001d8a,0x656401af,0x00000000}},	// [1d530] svje, _रेखा_, _stjh, --, 
   {{0x5bb83cc5,0x9f5c0098,0xcac8010a,0x00000000}},	//   _улья_, éréh_, _тӳме_, --, 
   {{0x45b81e76,0x85b92f12,0x00000000,0x00000000}},	//   ргею_, рлес_, --, --, 
   {{0xb86401e2,0x00000000,0x00000000,0x00000000}},	//   _واټو, --, --, --, 
   {{0x395804cc,0x73880116,0x21c40051,0x00000000}},	//   _zups_, ңрәң_, _sđh_, --, 
   {{0x39580263,0xd49824a5,0x1b7c010f,0x00000000}},	//   _yups_, арә_, נטוע, --, 
   {{0x6564014b,0x1a9c008f,0x95c800f0,0x9f480118}},	//   _utjh, טיגע, _лута_, ácí_, 
   {{0xc10400ae,0x00000000,0x00000000,0x00000000}},	//   توبي, --, --, --, 
   {{0x26c12f13,0x54f80408,0x00000000,0x00000000}},	//   _kajo_, _ухрă, --, --, 
   {{0xbd846fbb,0x26c12f14,0x272c1570,0xccf80118}},	//   огок, _jajo_, müns_, zpět_, 
   {{0x26c12f15,0x7ed404fb,0x7e600175,0x00000000}},	//   _majo_, مزگا, rclp, --, 
   {{0x39592f16,0x00000000,0x00000000,0x00000000}},	//   _rups_, --, --, --, 
   {{0x39580204,0x6d5c004a,0xef0d2f17,0xe7b003f9}},	//   _sups_, _épan, _жм_, ƙaƙƙ, 
   {{0x26c00770,0x29080790,0xefb001d5,0x39580f85}},	//   _najo_, _amca_, _کییگ, _pups_, 
   {{0x272c04cc,0xfce400db,0x7fa80037,0x69c00064}},	//   hüns_, _моко, _कहुँ, _šner, 
   {{0x26c00cbd,0x290805b1,0x272c01b8,0xe8f401af}},	//   _aajo_, _cmca_, küns_, олс_, 
   {{0x26c044d5,0x29092f18,0x78b52f19,0x00000000}},	// [1d540] _bajo_, _dmca_, reyv, --, 
   {{0x249c0262,0x395891bf,0xccf80118,0x61100356}},	//   _acum_, _tups_, spět_, mălu, 
   {{0x26c12f1a,0x630c015b,0x39580036,0x8b64141d}},	//   _dajo_, াকায়_, _uups_, _وایم, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x272c07de,0x249c01bf,0xa53000d4,0x24042b97}},	//   güns_, _dcum_, єніч, онци_, 
   {{0x387003a1,0x6b88037e,0xddc00327,0x249c003a}},	//   lbyr_, _ægge, _benż, _ecum_, 
   {{0xe6140276,0xaac80316,0x29092f1b,0xe2940114}},	//   _ддр_, ायतक, _ymca_, цај_, 
   {{0x83640372,0x3870143a,0x26c000d7,0x00000000}},	//   زدۇل, nbyr_, _zajo_, --, 
   {{0x26c000e4,0xb0a41408,0x04780066,0x00000000}},	//   _yajo_, क्षग, _دلقک_, --, 
   {{0x32440276,0xab600790,0x717000d1,0x4d9800d4}},	//   _дезг, şükt, _قۇتا, бкою_, 
   {{0x265800d9,0x21640117,0x7bc0013a,0x00000000}},	//   יכיא, _дихи_, _šoup, --, 
   {{0x0ed801ed,0xad0801c6,0x3028013d,0xad24d243}},	//   _گاؤں_, рхож_, _коеп_, ترخو, 
   {{0x9bc41e76,0xceb83ad0,0xafb80956,0x00000000}},	//   мёрк, _лән_, _خطاط_, --, 
   {{0xb0a4813f,0xa26c0023,0x00000000,0x00000000}},	//   क्रग, _ጥዕናን_, --, --, 
   {{0xe9240003,0x26c12f1c,0x80a03228,0xadec000d}},	//   _རྩུབ_, _rajo_, क्के, _छथिन_, 
   {{0x58d50b85,0x26c12f1d,0x7980012d,0x88580395}},	//   мост, _sajo_, _łowc, сиас_, 
   {{0x26c064b1,0x675000c7,0x00000000,0x00000000}},	// [1d550] _pajo_, днаӡ, --, --, 
   {{0x249c47b4,0x26c00200,0x00000000,0x00000000}},	//   _scum_, _qajo_, --, --, 
   {{0x2bc02efd,0x26c00219,0xa5652f1e,0x3ab80375}},	//   शिका, _vajo_, زدان, _המתנ, 
   {{0xf99025f9,0x26c013bb,0x29080042,0x00000000}},	//   _ארט_, _wajo_, _umca_, --, 
   {{0xee8c044e,0x71740020,0x291801e2,0x00000000}},	//   ሓሳስባ_, _ጽህፈት_, mnqa_, --, 
   {{0x8504021a,0xaac807b7,0xb3800023,0xf77400d9}},	//   _کورن, ायिक, _ናይዘን_, _מעשי_, 
   {{0x2d892f1f,0x00000000,0x00000000,0x00000000}},	//   ábel_, --, --, --, 
   {{0xff68145e,0x6f1802d0,0x6b48025c,0x39400009}},	//   _ngîâ_, entc, _iżgu, _xhks_, 
   {{0x44386bf8,0x29180784,0xcee80451,0xa0640aac}},	//   _ás_, inqa_, ڪرين_, бақа_, 
   {{0x6110054e,0x925800d8,0x00000000,0x00000000}},	//   vălu, _дафт_, --, --, 
   {{0xcee8acb6,0x4cc404c5,0xe8000ce0,0xee34084c}},	//   ترين_, ষানু, _रेघा_, знэ_, 
   {{0xcb0802e4,0x61100311,0xddc00024,0x6f192f20}},	//   _גל_, tălu, _senų, antc, 
   {{0x007c00d1,0x69c000ef,0x661800dc,0x00000000}},	//   _ﺭﻩﺳﯘ, _šnep, _śukl, --, 
   {{0x61100276,0x00000000,0x00000000,0x00000000}},	//   rălu, --, --, --, 
   {{0xbd8801c8,0x00000000,0x00000000,0x00000000}},	//   _انبن_, --, --, --, 
   {{0x3b840075,0x04fc0154,0x00000000,0x00000000}},	//   _елиг, ংচুর_, --, --, 
   {{0x81b000bd,0x38704606,0xeb9c0fac,0xd6c400c7}},	// [1d560] টটি_, rbyr_, tzøe_, миақ, 
   {{0x98a03535,0x00000000,0x00000000,0x00000000}},	//   bliğ_, --, --, --, 
   {{0x1dd8228a,0x80bc13f7,0x39412f21,0x7c3401f4}},	//   यमित, ्याइ, _thks_, _hyyr, 
   {{0xba745d95,0x81b00154,0x7c340108,0x23c40f4a}},	//   _باکت, টটা_, _kyyr, लिंद, 
   {{0xe924025c,0xa85400d9,0x00000000,0x00000000}},	//   _རྩིབ_, _מיכה_, --, --, 
   {{0xd2512f22,0x1dd828e1,0x6ef420ef,0x7c34005b}},	//   نچا_, यमात, _câbl, _myyr, 
   {{0x7c3401f4,0xb35400e5,0x00000000,0x00000000}},	//   _lyyr, _کیتا_, --, --, 
   {{0x751800c6,0x0cb80349,0x855401b9,0x94a801d9}},	//   _اقرأ_, _ুক্ত, _قیلر_, _گاڑِ_, 
   {{0x73340145,0xa0640063,0xa93c0092,0xd2500133}},	//   _فىرا, чања_, _በጥቃቅ, رۆڵ_, 
   {{0x4508081f,0xc2e8007b,0x00000000,0x00000000}},	//   _གཏོར_, _وعلم_, --, --, 
   {{0x4db404c5,0x4c945b8c,0x7c340432,0x00000000}},	//   টিভং, минс, _ayyr, --, 
   {{0x3d107483,0xb1443db0,0xf1a804d3,0x00000000}},	//   tšwa_, _энел, _ناڵه_, --, 
   {{0x70392f23,0x6fb4031c,0x00000000,0x00000000}},	//   _اساس_, _དགྲའ, --, --, 
   {{0xdee12f24,0x00000000,0x00000000,0x00000000}},	//   _почи, --, --, --, 
   {{0xf1c00254,0x59f8084c,0x48c40150,0x9e300114}},	//   _वैमन, перя_, мшағ, _пешч, 
   {{0xacb86c80,0x37780248,0x00000000,0x00000000}},	//   goût, _ọdẹ_, --, --, 
   {{0x7c340076,0x80a00bc0,0x00000000,0x00000000}},	// [1d570] _gyyr, क्टे, --, --, 
   {{0xd2440133,0x68fc01a9,0x0b440244,0x00000000}},	//   _مۆ_, shqd, _تربێ, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8ca40574,0x03a52f25,0x00000000,0x00000000}},	//   _कानो, фило, --, --, 
   {{0xc0dc0023,0x00000000,0x00000000,0x00000000}},	//   ሕዳስ_, --, --, --, 
   {{0xf8b0032e,0x00000000,0x00000000,0x00000000}},	//   _þáði_, --, --, --, 
   {{0xe7dc009e,0x00000000,0x00000000,0x00000000}},	//   ণনীয, --, --, --, 
   {{0x64580ecf,0x00000000,0x00000000,0x00000000}},	//   _igui, --, --, --, 
   {{0x8e740845,0xf678008f,0x00000000,0x00000000}},	//   нуюч, ֿארמ, --, --, 
   {{0xddd00030,0xdce4005f,0x7c34023a,0x00000000}},	//   ňaže, _atnā, _syyr, --, 
   {{0x62812f26,0x90d40153,0x00000000,0x00000000}},	//   lano, _пціч, --, --, 
   {{0x2d9800d6,0xbea52f27,0xacb806af,0x7ce40210}},	//   _åpen_, _жалк, voût, _kórz, 
   {{0x6900000d,0xbf34010f,0x00000000,0x00000000}},	//   _jõef, _קאַץ_, --, --, 
   {{0xe9a000d6,0xa964ed64,0x395c07ea,0x64580083}},	//   карп, диса_, êts_, _ogui, 
   {{0x62812f28,0x64592f29,0xbd4402eb,0x7c340108}},	//   hano, _ngui, _تنبي, _tyyr, 
   {{0x36c52f2a,0x00000000,0x00000000,0x00000000}},	// [1d580] мбаг, --, --, --, 
   {{0x62812f2b,0x98a0012d,0x00000000,0x00000000}},	//   jano, koić_, --, --, 
   {{0x62812f2c,0x39452f2d,0x8ca41fad,0x64cc0073}},	//   dano, _оног, _कामो, _सोहळ, 
   {{0x499400fd,0x62800076,0xc64400cf,0x00000000}},	//   _яшьт, eano, رئلى, --, 
   {{0x62812f2e,0xf7700769,0x00000000,0x00000000}},	//   fano, _جاج_, --, --, 
   {{0x64582aee,0x00000000,0x00000000,0x00000000}},	//   _egui, --, --, --, 
   {{0xb1a001e0,0x7c20032e,0x00000000,0x00000000}},	//   тһеҙ, _þorf, --, --, 
   {{0x645804ba,0x2d8800f3,0x0ed000c5,0x80d400cd}},	//   _ggui, šbek_, _थो़ड, भागे, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7ce4033f,0x00000000,0x00000000,0x00000000}},	//   _górz, --, --, --, 
   {{0x5f700214,0xfd6400b8,0x6aa008a5,0x00000000}},	//   _یاور, _kauṭ, _önfi, --, 
   {{0x7afd2f2f,0x6aa408a3,0x00000000,0x00000000}},	//   _alpt, गभ्र, --, --, 
   {{0xce9402e8,0x7e6c0205,0x00000000,0x00000000}},	//   _залъ, _şape, --, --, 
   {{0x3ae405da,0xdbdc09f3,0xfd7800e5,0x00000000}},	//   _kôpy_, ráðg, _کشوں_, --, 
   {{0x4fc00075,0xd48400aa,0x69000254,0x6d6400d7}},	//   _شەھە, _پۀ_, _jõeg, úpač, 
   {{0xa8000724,0x7e6c107d,0x290c0ba1,0x00000000}},	//   _çıkk, _đapi, òga_, --, 
   {{0xc6f80395,0x00000000,0x00000000,0x00000000}},	// [1d590] пнах_, --, --, --, 
   {{0x62812f30,0x5b1405f5,0x64591f1d,0xaa840133}},	//   xano, _амьт, _sgui, _زۆرم_, 
   {{0x62812f31,0x26c400d0,0xd87800d1,0x049400ae}},	//   vano, ľno_, سمەت_, فلاح, 
   {{0x26c4ceba,0x62812f32,0x00000000,0x00000000}},	//   žno_, wano, --, --, 
   {{0x68300022,0x98a00210,0x00000000,0x00000000}},	//   _рҭат, woić_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x56941d39,0xb0d801f9,0x00000000,0x00000000}},	//   _јаст, भांग, --, --, 
   {{0x64580b6f,0x7c200008,0x45080327,0xd49864ad}},	//   _ugui, _þorg, _གཏིར_, _ору_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfe70007b,0xd9c00154,0x7e6c010e,0x628006be}},	//   ددة_, _উপসম, _şapb, qano, 
   {{0x3d000241,0x67f8022e,0x7db400e5,0xdb940248}},	//   _lówe_, 鼠jal, رصدا, _ọ̀ka, 
   {{0xfce402bf,0x00000000,0x00000000,0x00000000}},	//   хомо, --, --, --, 
   {{0x5ca42e51,0x63a80c86,0x4c346623,0xcee8136e}},	//   ىلگە, ntgn, вэрт, سرین_, 
   {{0xbea52f33,0xaed00114,0x45240154,0x00000000}},	//   _чакк, _бољш, বতিক_, --, 
   {{0xab2408ca,0x3f7c0419,0x6d4400e8,0xeab4300e}},	//   хора_, lňu_, ŋkaa, эйр_, 
   {{0x80d402ab,0xf1c0000d,0x00000000,0x00000000}},	//   _मोमे, _वईसन, --, --, 
   {{0x0d4820ef,0xc7644d2d,0x4ab405f5,0x09c0031c}},	// [1d5a0] _تشوي_, نالى, хөөр, _གརྨ_, 
   {{0x7afc035a,0xec44008e,0xab58002f,0x80bc3d22}},	//   _ulpt, _языл_, swüc, ्युं, 
   {{0xeef4008f,0x00000000,0x00000000,0x00000000}},	//   עמער_, --, --, --, 
   {{0x3f7c0419,0x00000000,0x00000000,0x00000000}},	//   kňu_, --, --, --, 
   {{0xe3ac05d9,0x3a380fac,0x3f7c00d0,0x00000000}},	//   مرو_, _hypp_, jňu_, --, 
   {{0x31c52f34,0x3f7c00d0,0x00000000,0x00000000}},	//   есив, dňu_, --, --, 
   {{0xded80023,0x52c009ab,0x00000000,0x00000000}},	//   ሕናን_, _एसीस, --, --, 
   {{0x6d5c5725,0x25081fae,0x00000000,0x00000000}},	//   _épai, _فرقی_, --, --, 
   {{0xc06002d3,0x00000000,0x00000000,0x00000000}},	//   _ተታሒዙ_, --, --, --, 
   {{0x1dd80d5f,0x69000254,0x80d40073,0x00000000}},	//   यमंत, _tõeg, _मोठे, --, 
   {{0x2d892f35,0x78a402d0,0x7e6c0356,0x00000000}},	//   ébe_, _ockv, _şapc, --, 
   {{0x91fc0618,0xb0601057,0x31240166,0x3f7c00d7}},	//   _agāg, äädi, _ядег, bňu_, 
   {{0x01080214,0x3f7c00d7,0x6140030d,0x1dc001c4}},	//   _تتلو_, cňu_, _сеца, вөөн, 
   {{0x91fc0421,0x2fc40589,0xce94c3ff,0x00000000}},	//   _afāi, _isog_, _ракъ, --, 
   {{0x317c00ec,0x20500724,0x80d4d969,0xdbe40241}},	//   _jwtz_, _итәр, _मोडे, _léèr, 
   {{0x2eed2f36,0x3a3803cd,0x00000000,0x00000000}},	//   _hoff_, _dypp_, --, --, 
   {{0x2eec01f4,0xd7940395,0xab602ca8,0x00000000}},	// [1d5b0] _koff_, литъ, ğüst, --, 
   {{0x61e0010a,0x6d4c01f5,0x00000000,0x00000000}},	//   yxnl, lmca, --, --, 
   {{0x2d9d2f37,0x6d4c01f5,0x5724129d,0x00000000}},	//   nute_, omca, دىلك, --, 
   {{0xdbe40ca8,0x2fc4003e,0x3f7c0030,0x2eec03cd}},	//   _béèr, _osog_, yňu_, _loff_, 
   {{0x2d9d2f38,0x58d4ad00,0x00000000,0x00000000}},	//   hute_, _соят, --, --, 
   {{0x2d9d2f39,0x3f7c0030,0x63a805d5,0x68ec0208}},	//   kute_, vňu_, rtgn, _hocd, 
   {{0x2d9d2f3a,0x63a807de,0x4128004e,0x5ec000d1}},	//   jute_, stgn, моко_, қинғ, 
   {{0x2d9d2f3b,0x80bc01ad,0x8e3801a9,0x3f7c0419}},	//   dute_, ्यें, аrо_, tňu_, 
   {{0x9fcc39db,0x13b450e9,0x90e40f78,0x2eed2f3c}},	//   াঙ্গ, _مصلح, اسىن, _boff_, 
   {{0x2d9d2f3d,0x68ec0208,0xef142123,0x6d4c02d0}},	//   fute_, _locd, кмы_, emca, 
   {{0x2d9d2f3e,0x2eed2f3f,0xcfa810e5,0x00000000}},	//   gute_, _doff_, وایم_, --, 
   {{0xdbe401f5,0xd1b802ef,0xd1640395,0x3f7c00d7}},	//   _héér, _ساما_, _съфи, pňu_, 
   {{0x2d9c037e,0xefdc0023,0xec3000c7,0xec740395}},	//   aute_, ዕባይ_, инџь, ъпя_, 
   {{0x2d9d2f40,0x60c86b56,0x100402e8,0x0b580108}},	//   bute_, _hagm, _щяхм, ерсы_, 
   {{0x2d9d2f41,0xcee81913,0x03bc05ac,0x00000000}},	//   cute_, _سرون_, _আপোণ, --, 
   {{0x2eed2f42,0x60c800dc,0xdbe400e8,0x692001c6}},	//   _zoff_, _jagm, _léér, амса, 
   {{0x60c92f43,0xf77129c0,0xb8d8772c,0x68ec058a}},	// [1d5c0] _magm, شاء_, _आउ_, _docd, 
   {{0x60c888fb,0x7bd407a8,0x27ec007c,0xdb0c3b22}},	//   _lagm, _iryu, ägna_, öhän, 
   {{0x7c2001a8,0x3ce4012d,0x00000000,0x00000000}},	//   _þorb, टापे_, --, --, 
   {{0x60c89b94,0x68ec0009,0x7bd40139,0xd538bd96}},	//   _nagm, _gocd, _kryu, رغاچ_, 
   {{0x2d9d27d3,0x6d5c06af,0x929406ed,0x741433ae}},	//   zute_, _épav, галц, خوشا, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x60c92f44,0x2eec0165,0xab580e78,0x00000000}},	//   _bagm, _roff_, kwün, --, 
   {{0x2d9d2f45,0x91fc02b5,0x45352f46,0x68ec00db}},	//   vute_, _ngāe, _бхут, _xocd, 
   {{0x60c92f47,0xdbe47cf3,0x3ce42232,0x2d9c02e3}},	//   _dagm, _féér, टाने_, wute_, 
   {{0x60c8000f,0x75212f48,0xa3440124,0xdbe401e1}},	//   _eagm, lnoz, _азуа_, _géér, 
   {{0x7bd400ca,0x60c81278,0x75200472,0x2eec02d2}},	//   _aryu, _fagm, onoz, _voff_, 
   {{0x2d9ca78c,0x60c851e2,0x7520905b,0x2fc40211}},	//   rute_, _gagm, nnoz, _tsog_, 
   {{0x2d9d2f49,0x6d4d2f4a,0x75212f4b,0xa064410a}},	//   sute_, rmca, inoz, _рача_, 
   {{0x2d9d2f4c,0x68ec0a81,0x9b592f4d,0x52c12f4e}},	//   pute_, _socd, кият_, _एसोस, 
   {{0x60c8137e,0x2d9c00e8,0x5b2401c6,0xa8a469a1}},	//   _yagm, qute_, рьяа, крак, 
   {{0x79e800e5,0x00000000,0x00000000,0x00000000}},	//   روقہ_, --, --, --, 
   {{0x7520132c,0x58852f4f,0x46145837,0xeb485c03}},	// [1d5d0] dnoz, рыса, گوار, _очок_, 
   {{0x9a849dc3,0x00000000,0x00000000,0x00000000}},	//   _куюл, --, --, --, 
   {{0xd470063f,0x9a840220,0x7bd800b0,0x95c80276}},	//   _ịtọr, _туыл, ātue, куца_, 
   {{0x6d5c5725,0x3d000241,0x3ce400ab,0x94740fba}},	//   _épau, _kówa_, टाये_, لدها, 
   {{0x44292f50,0x25f00574,0xd7e40845,0x60c80790}},	//   ça_, ूनही_, _кіро, _ragm, 
   {{0x4428003d,0x60c80af9,0x7520004c,0xe5709924}},	//   ħa_, _sagm, anoz, _نطر_, 
   {{0x60c810c7,0x042000fe,0x84740092,0x00000000}},	//   _pagm, _বৰশী_, ከታለን_, --, 
   {{0x7520011c,0xe05432de,0x26f0000d,0x00000000}},	//   cnoz, نیات_, _आकुर_, --, 
   {{0xdbe400e8,0x60c80055,0x28a83174,0x00000000}},	//   _téér, _vagm, _छानि, --, 
   {{0x63b92f51,0xfde92f52,0xaf001945,0x6d44002e}},	//   _ipun, едок_, йпыл, ŋkal, 
   {{0x60c92f53,0x009401c6,0xef14084c,0x00000000}},	//   _tagm, _биеэ, умэ_, --, 
   {{0x63b8003e,0x69c003b2,0x999c01ef,0x00000000}},	//   _kpun, _áney, _švů_, --, 
   {{0x69d52f54,0x5fb4038e,0x8ca423fd,0xab580e78}},	//   _arxe, _अहिल, _कारो, rwün, 
   {{0x63b92f55,0x3f8c090c,0x213c0429,0x6f9000c6}},	//   _mpun, mseu_, lluh_, _الوض, 
   {{0x3f8d2f56,0x63b8009a,0xdce400df,0x7520022e}},	//   lseu_, _lpun, _lunĉ, ynoz, 
   {{0x63b92f57,0x6e4001d9,0x7520022e,0x2d88031c}},	//   _opun, _دۆپم, xnoz, ġbet_, 
   {{0x3f8c8f1f,0x7d14014b,0x75200010,0xfa6801af}},	// [1d5e0] nseu_, _imys, vnoz, _папк_, 
   {{0x75212f58,0x3ea41368,0x96e801e2,0x00000000}},	//   wnoz, nglt_, خبرې_, --, 
   {{0x63b92f59,0xacb8045f,0x6d5c06af,0x213c0327}},	//   _apun, inûn, _épat, kluh_, 
   {{0x7520004c,0xf1a40fc0,0x63b801e7,0xab58002f}},	//   unoz, ҳрин, _bpun, hwül, 
   {{0x6ef4006a,0x3950062c,0x75212f5a,0x52840124}},	//   _zâbu, mmys_, rnoz, иҳаб, 
   {{0x63b80066,0xf1a52f5b,0x3cf003b2,0x6fd01fe7}},	//   _dpun, грин, _loyv_, तिसं, 
   {{0xd13036e9,0x8ca45612,0x7d1400e4,0x91c40032}},	//   يمت_, _कालो, _omys, рҙел, 
   {{0x752000ac,0x213c020c,0x50f4329b,0x395000ad}},	//   qnoz, gluh_, рзит, nmys_, 
   {{0x91fc0421,0x63b801c4,0xa5043c18,0x3f8c0098}},	//   _afāt, _gpun, _сета_, gseu_, 
   {{0x7d1400b5,0x00000000,0x00000000,0x00000000}},	//   _amys, --, --, --, 
   {{0x3f8c0421,0x918000db,0x3208007c,0xf46c0240}},	//   aseu_, _بۇعۇ, _åby_, _ትሓስብ_, 
   {{0xdd940124,0x61400354,0x8ca40073,0xc1700133}},	//   ышь_, _леха, _काळो, _بگوت, 
   {{0x60d8011a,0x00000000,0x00000000,0x00000000}},	//   _רקדנ, --, --, --, 
   {{0xbf600014,0x5ce40220,0xc6240154,0x00000000}},	//   _گۯیو, _ۇكىل, _ভরসা_, --, 
   {{0x6f1803ac,0x1ef8008f,0x2d98035b,0x22f4010f}},	//   mitc, _אלגע, _ípe_, נזלן_, 
   {{0x6f192f5c,0xd5c80210,0x00000000,0x00000000}},	//   litc, रबनज, --, --, 
   {{0xd7740026,0x9b440451,0x6d5c0009,0x6f18062c}},	// [1d5f0] مالع, _ڏنيو, _iiqa, oitc, 
   {{0x7d14c466,0x6d5c047e,0x213c0007,0x395000ad}},	//   _zmys, _hiqa, zluh_, amys_, 
   {{0x63b92f5d,0x69d4172e,0x7af92f5e,0x7d140368}},	//   _spun, _urxe, ötte, _ymys, 
   {{0x63b8baa1,0x6d5c016d,0x6f180897,0x213c0007}},	//   _ppun, _jiqa, hitc, xluh_, 
   {{0x6d5d2f5f,0x6f192f60,0x62b40184,0x29180309}},	//   _miqa, kitc, лғас_, miqa_, 
   {{0x6d5ce289,0x2918bc0f,0x7980033f,0xe79401d3}},	//   _liqa, liqa_, _łowi, _لاڑک, 
   {{0x6f18bbc4,0x6d5c0194,0xd6d800a8,0x213c0327}},	//   ditc, _oiqa, _стя_, tluh_, 
   {{0x63b800b0,0x29192f61,0x0fe400f7,0x7764022e}},	//   _tpun, niqa_, өөчү, _yukx, 
   {{0x55052f62,0x63b80451,0x6f180804,0x00000000}},	//   _учра, _upun, fitc, --, 
   {{0x3f8c0098,0xa18411db,0x7d14012c,0x442c0129}},	//   rseu_, _быдл, _smys, _ixe_, 
   {{0x39502fdb,0x3f8d2f63,0x6d5c047e,0x291802d1}},	//   ymys_, sseu_, _biqa, kiqa_, 
   {{0x7fd43bb3,0x6d5c01d9,0x98a00327,0x00000000}},	//   _вікі, _ciqa, rniċ_, --, 
   {{0x6f185e9c,0x6d5d2f64,0x7bc40d27,0xbb440108}},	//   bitc, _diqa, uwku, иемк, 
   {{0x442c0165,0xdce40003,0xfaa40114,0x00000000}},	//   _mxe_, _kunċ, јаво, --, 
   {{0x6d5d2f65,0x6564014f,0x2ba401ad,0xdb0403b2}},	//   _fiqa, _nujh, कूबा, _spió, 
   {{0x7d14033f,0x442c007c,0x29180166,0x00000000}},	//   _umys, _oxe_, giqa_, --, 
   {{0x442c036e,0xca1800d1,0x6d38123b,0x00000000}},	// [1d600] _nxe_, ﻳﺎﺕ_, _בתקנ, --, 
   {{0x6d5d2f66,0xd91012e1,0x65640165,0x00000000}},	//   _ziqa, _کیر_, _bujh, --, 
   {{0x442d2f67,0xb4642503,0x6d5c016d,0xceb8012d}},	//   _axe_, акел, _yiqa, sięg_, 
   {{0x6564014f,0x6f1802ce,0x6d5c0548,0xdb0401c4}},	//   _dujh, zitc, _xiqa, _ipiñ, 
   {{0x3d0001e1,0x673402d0,0x6f192f68,0x00000000}},	//   _lówo_, boxj, yitc, --, 
   {{0x61100276,0x442c0165,0x69000254,0xf1a80345}},	//   călz, _dxe_, _jõen, نابه_, 
   {{0x442c20f7,0x10600055,0xa13000ec,0x00000000}},	//   _exe_, _aṇḍe_, ڊريش, --, 
   {{0x64a12f69,0x6f192f6a,0x442c0165,0x00000000}},	//   _маса, witc, _fxe_, --, 
   {{0x6d5c208d,0xb2942e0b,0x00000000,0x00000000}},	//   _riqa, _نجاش, --, --, 
   {{0x6d5d2f6b,0x98a00010,0x6f1801ab,0x3234030d}},	//   _siqa, dnič_, uitc, _кхес, 
   {{0x6d5d2f6c,0xc6d8010f,0x00000000,0x00000000}},	//   _piqa, אַרר, --, --, 
   {{0x6f1800d8,0x6d5c06be,0x00000000,0x00000000}},	//   sitc, _qiqa, --, --, 
   {{0xdb040789,0x6f1801a6,0xa1101ec7,0x442c004a}},	//   _apiñ, pitc, _بونت, _xxe_, 
   {{0x6d5c047e,0x00000000,0x00000000,0x00000000}},	//   _wiqa, --, --, --, 
   {{0x8d940597,0x29192f6d,0x6d5c0455,0x7f38010f}},	//   _البش, tiqa_, _tiqa, _געװו, 
   {{0x6d5c740d,0x98a00427,0x2ba401f9,0x1e8001af}},	//   _uiqa, bnič_, कंदा, _лләм, 
   {{0x29192f6e,0xacb8000f,0xe6640139,0xe784346b}},	// [1d610] riqa_, nnûm, атео, рубо, 
   {{0x29190fba,0x2d9d2f6f,0x442c0129,0xf1c4000d}},	//   siqa_, orte_, _rxe_, लबान, 
   {{0x29180bf1,0xfd5400b8,0x442c01e7,0x65640455}},	//   piqa_, _amaṇ, _sxe_, _qujh, 
   {{0x29192f70,0x2d9c0e9e,0x27ec03cd,0x00000000}},	//   qiqa_, irte_, øgns_, --, 
   {{0x2d9ccac5,0x765803b2,0xe3b06640,0x14c80124}},	//   hrte_, _útyn, ترض_, рыхи_, 
   {{0xb0612f71,0x65640477,0x00000000,0x00000000}},	//   ääni, _tujh, --, --, 
   {{0xf42402f6,0x69000254,0x56940138,0x92e8007b}},	//   _ääni_, _jõeo, _фаст, شروق_, 
   {{0x00c8086f,0x00000000,0x00000000,0x00000000}},	//   улик_, --, --, --, 
   {{0x2d9d2f72,0x7ff4007b,0x00000000,0x00000000}},	//   erte_, إسبا, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2a700223,0x415501be,0xeb9c11c0,0x70c800f1}},	//   _afxb_, _увес, frø_, _مهمې_, 
   {{0xeb9c05ac,0x41740244,0x00000000,0x00000000}},	//   grø_, _ئاڕس, --, --, 
   {{0x20a41533,0xbdf80214,0x98a00427,0x4f0800f7}},	//   _गाँध, _مربا_, rnič_, _ۅتۉپ_, 
   {{0x2d9c04a7,0x00000000,0x00000000,0x00000000}},	//   crte_, --, --, --, 
   {{0x786489f1,0xab58002f,0xdce52f73,0x00000000}},	//   сказ, hwüh, _kunč, --, 
   {{0x6900007d,0x91fc0374,0xfaa414b3,0x00000000}},	// [1d620] _tõen, _ngān, _лапо, --, 
   {{0x3ce4ec91,0x00000000,0x00000000,0x00000000}},	//   टावे_, --, --, --, 
   {{0xf9912f74,0x20a40d35,0xd9112f75,0x00000000}},	//   _عبد_, _गांध, _قیس_, --, 
   {{0x2bec015b,0x69000037,0x92d400fe,0xf1c0012d}},	//   _চেয়ে_, _jõel, _হকে_, _वैगन, 
   {{0x6900007d,0x00000000,0x00000000,0x00000000}},	//   _mõel, --, --, --, 
   {{0x2d9c332c,0x38700798,0xe2940114,0x00000000}},	//   yrte_, lcyr_, баљ_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x690000c5,0xa5049b81,0xacb8002d,0x2d9d2f76}},	//   _nõel, _леса_, tnûm, vrte_, 
   {{0x43740364,0xf42800d1,0x00000000,0x00000000}},	//   _духт, _соал_, --, --, 
   {{0xd54401e1,0xfbbc009e,0x2d9c0427,0x00000000}},	//   _fẹ̀h, ইটাত, trte_, --, 
   {{0xb1e00058,0x2ae41a22,0x724400f7,0xacb8002d}},	//   _хәлқ, ञासु_, _اپال, snûm, 
   {{0x848c36bc,0x2d9d2f77,0xeb9c0162,0x00000000}},	//   _ቅዱሳን_, rrte_, trø_, --, 
   {{0x7c2001a8,0xceb84caf,0xa0a000ee,0xdce400ef}},	//   _þorl, _кән_, _хачд, _gunč, 
   {{0x2d9c09a8,0x8ca46c5a,0xd5c802db,0x00000000}},	//   prte_, _काको, रबाज, --, 
   {{0x7af80267,0x00000000,0x00000000,0x00000000}},	//   ötta, --, --, --, 
   {{0xeb9c0fac,0x00000000,0x00000000,0x00000000}},	//   prø_, --, --, --, 
   {{0xc1b42f2e,0x00000000,0x00000000,0x00000000}},	// [1d630] _अङ्ग, --, --, --, 
   {{0x91fc02b5,0xe6641606,0x00000000,0x00000000}},	//   _ngāo, стао, --, --, 
   {{0x7e6c05d1,0x80a807f7,0x00000000,0x00000000}},	//   _şapk, _टाले, --, --, 
   {{0xa8a52f78,0x91fc0618,0xd4f400ee,0xc1e81bf4}},	//   _урок, _agāo, зяшы, یکال_, 
   {{0x69000254,0x9554007b,0xae1800bc,0xd7f80354}},	//   _jõem, أخلا, _फेसन_, _лур_, 
   {{0xdce40171,0x1c1c000d,0x00000000,0x00000000}},	//   _runč, _पइसल_, --, --, 
   {{0xdce40bb8,0x00000000,0x00000000,0x00000000}},	//   _sunč, --, --, --, 
   {{0x850401b9,0xdce476e0,0x00000000,0x00000000}},	//   _بورن, _punč, --, --, 
   {{0xc2c42085,0xbc6801b9,0xb0f401f7,0x00000000}},	//   _ويري, یمدن_, تفيض_, --, 
   {{0x92941b4f,0x69000037,0xa11000f1,0x00000000}},	//   _науц, _sõel, غوښت, --, 
   {{0x3ce411b1,0xc32c1e87,0x00000000,0x00000000}},	//   टाले_, _كەچ_, --, --, 
   {{0xcee80150,0xdce45563,0x00000000,0x00000000}},	//   _ۇرىن_, _tunč, --, --, 
   {{0x3fc8021a,0x00000000,0x00000000,0x00000000}},	//   _خدای_, --, --, --, 
   {{0x7c20032e,0x00000000,0x00000000,0x00000000}},	//   _þorm, --, --, --, 
   {{0xfd100597,0x690000af,0x4ea40798,0x00000000}},	//   _يجب_, _tõel, _хрча, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x59d800bc,0x00000000,0x00000000,0x00000000}},	// [1d640] डिहर, --, --, --, 
   {{0xdb500014,0x54e401ec,0x00000000,0x00000000}},	//   _سێز_, _ﺍﻗﺘﺼ, --, --, 
   {{0x5ed0009e,0x00000000,0x00000000,0x00000000}},	//   তাপে, --, --, --, 
   {{0x6bd401d3,0xe4e000d4,0x37e4009d,0x81b000eb}},	//   _اویس_, дішн, _домг, য়টা_, 
   {{0x91fc0421,0xe3ac6ea9,0xfbc8194b,0x2898011a}},	//   _egāl, نرو_, िबिम, _דיכא, 
   {{0x2ae00034,0xb060023a,0x07340046,0x00000000}},	//   खाएँ_, äämi, _ﺯﺍﯓ_, --, 
   {{0x75d40451,0xded80023,0xf5040212,0xc32c1884}},	//   _بيزا, ዕናን_, _дзво, دەل_, 
   {{0xd13000c6,0x61f40267,0x6ed000c5,0x00000000}},	//   عمة_, äxla, _भोजु, --, 
   {{0xe4d47f51,0x5ed0015b,0x00000000,0x00000000}},	//   _بوقت_, তানে, --, --, 
   {{0xe4201b2c,0xb35404f2,0x9f5c0162,0x00000000}},	//   _تکمي, _بیتا_, úrði_, --, 
   {{0x05e002dd,0xae187c33,0x317001d5,0x00000000}},	//   _ءﺩﺍﺭ, _फेशन_, _ўғит, --, 
   {{0x7af92f79,0x00000000,0x00000000,0x00000000}},	//   öttn, --, --, --, 
   {{0xbec40171,0x00000000,0x00000000,0x00000000}},	//   _brūč, --, --, --, 
   {{0x7c38002f,0x00000000,0x00000000,0x00000000}},	//   ßtra, --, --, --, 
   {{0x91fc0421,0x9e703e52,0x6d8400e5,0x00000000}},	//   _ogām, _تۇپت, _بمعہ_, --, 
   {{0x91fc02b1,0x50bc00cd,0x00000000,0x00000000}},	//   _ngām, ्जिष, --, --, 
   {{0x59040327,0xfca8008f,0xfd6000dc,0xe7740014}},	// [1d650] ངྒེས_, _היפּ, _nivṛ, زلاں_, 
   {{0x672002d3,0x1ac8010b,0xdef0001f,0x00000000}},	//   _ተረዲእ, _дуюп_, _ጌታን_, --, 
   {{0xdce402b5,0xd66819bc,0xb060005b,0x69000037}},	//   _hunā, زمنو_, ääji, _jõek, 
   {{0xf9d800c8,0xdce400cd,0xe784014b,0x00000000}},	//   _פֿיל, _kunā, _муго, --, 
   {{0x248c50eb,0x2d8000d1,0x00000000,0x00000000}},	//   ragm_, ﯩﻘﻨﻰ_, --, --, 
   {{0xd49800d1,0x69c00129,0x07092f7a,0xb9f40023}},	//   брә_, _ânes, _ايسي_, _ዝተ_, 
   {{0xdce40055,0x91fc00de,0x00000000,0x00000000}},	//   _lunā, _ugāl, --, --, 
   {{0x6f0803ac,0xb4b40032,0x00000000,0x00000000}},	//   _alfc, _нисә, --, --, 
   {{0x8ca40c5a,0xd498026b,0x00000000,0x00000000}},	//   _काजो, _фрс_, --, --, 
   {{0x8e7400d4,0x00000000,0x00000000,0x00000000}},	//   муюч, --, --, --, 
   {{0x2d480086,0x628009a8,0xdcf00427,0xbc6801d5}},	//   rùen_, mbno, šeči, یمگن_, 
   {{0x29080d04,0x6f0802d0,0xac80084c,0x71d405d0}},	//   _nlca_, _elfc, нгюл, _מועד_, 
   {{0x3f78010f,0x5ed00154,0xef0c0fac,0x1c1c07af}},	//   _פאַס, তাবে, _зм_, _पेशल_, 
   {{0xafe40579,0x29080113,0x3d00068f,0xeba806ea}},	//   støð, _alca_, _mówi_, _støð_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xaa400724,0x29080175,0x69000254,0x00000000}},	//   хесл, _clca_, _jõeh, --, 
   {{0xac140063,0xdce400de,0x80bc00cd,0xb6a42377}},	// [1d660] _ноћу_, _gunā, व्ये, зизл, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd9b4021f,0x39440108,0x00000000,0x00000000}},	//   _تەزد, _нног, --, --, 
   {{0xb0d802ab,0xb060023a,0xaa540014,0x716400d1}},	//   _मोंग, ääki, _ژلیا_, ۋابك, 
   {{0x39400129,0x69c00129,0x00000000,0x00000000}},	//   _ikks_, _âner, --, --, 
   {{0x34b800ec,0xfd6000dc,0x00000000,0x00000000}},	//   _گهرج_, _vivṛ, --, --, 
   {{0x768402dd,0xe29410fc,0x94c801e2,0x00000000}},	//   _мыңж, чај_, _وارې_, --, 
   {{0x53d4000d,0x09b000cc,0x00000000,0x00000000}},	//   _धनपश, _চনমা, --, --, 
   {{0x96d000bc,0x00000000,0x00000000,0x00000000}},	//   _सघाउ, --, --, --, 
   {{0x75212f7b,0xdce400da,0xe2952f7c,0x4d9800d4}},	//   lioz, _runā, _нау_, окою_, 
   {{0xc0640023,0xdce400b8,0x00000000,0x00000000}},	//   _መዳርግ, _sunā, --, --, 
   {{0x75205c71,0x68000241,0xdce4002b,0x200c0413}},	//   nioz, _jíjú, _punā, ímið_, 
   {{0x80d406b1,0x5bb801f4,0x00000000,0x00000000}},	//   _मोटे, пляя_, --, --, 
   {{0x91fc0053,0x75200395,0x690000c5,0x39400254}},	//   _ngāk, hioz, _tõek, _akks_, 
   {{0xe4ec00dc,0xdeb8011a,0x00000000,0x00000000}},	//   छामि_, _המול, --, --, 
   {{0x75212f7d,0x9cb40228,0x00000000,0x00000000}},	//   jioz, _كۅپت, --, --, 
   {{0xc6f868ce,0x7520a604,0x634c016b,0x628002fb}},	// [1d670] онах_, dioz, _wɔnɑ, ybno, 
   {{0x04f800bd,0xfd540055,0x00000000,0x00000000}},	//   _আগের_, ddaṃ, --, --, 
   {{0x75200240,0xa5652f7e,0x3ab8011a,0xceb80153}},	//   fioz, سدان, _ומתנ, lnęs_, 
   {{0x752005a1,0x3f9800e5,0x00000000,0x00000000}},	//   gioz, ásuk_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe7841d18,0xfbdc00cd,0x00000000,0x00000000}},	//   _муҳо, मितम, --, --, 
   {{0xe35c002e,0x75202804,0x69c00793,0x7d04168c}},	//   _b茜r茜, bioz, _äned, ykks, 
   {{0x7c38068f,0xb270d73a,0x7c20010b,0x3fe40fac}},	//   ętrz, нләш, _ýorg, джив, 
   {{0x44392f7f,0xb0ac06ab,0x81600133,0x00000000}},	//   _âs_, _टारग, _یۆتۆ, --, 
   {{0x63a80280,0x80bc01ad,0x80a80073,0x7c2008a5}},	//   mugn, _वॉरे, _टाके, _þori, 
   {{0x3cc83529,0x91fc04fe,0x5ca40131,0x63a92f80}},	//   олно_, _ngāh, ۈلگە, lugn, 
   {{0x20c800ec,0xcb0808c3,0x00000000,0x00000000}},	//   _دبئي_, _דל_, --, --, 
   {{0x92d00c58,0xed540212,0x63a92f81,0xcf9800d8}},	//   ষাৰ_, ьою_, nugn, _ејј_, 
   {{0xdce40311,0x394000d5,0x316401c4,0x752001c6}},	//   _bună, _skks_, _zioz_, zioz, 
   {{0xaa40a435,0x5ed0015b,0x6b600a5b,0x63a92f82}},	//   верл, তাদে, ткра, hugn, 
   {{0x5a4802d3,0xdce40276,0x63a804ba,0x6cc0010a}},	//   _መድረኻ, _dună, kugn, _айъа, 
   {{0x63a82b1d,0xd5b800b0,0x56e463eb,0x27b0013d}},	// [1d680] jugn, _ūā_, нбағ, кәрс, 
   {{0xa2bc1889,0x98a00034,0x2c1401ad,0x3d180073}},	//   ल्म्, dnią_, _पेटू_, मोरे_, 
   {{0x75d400c6,0x75212f83,0x98a00210,0x2f3800df}},	//   بيضا, tioz, enią_, קגעד, 
   {{0x63a80e78,0xafe003b2,0x66003a26,0x00000000}},	//   fugn, íøki, ønka, --, 
   {{0x75212f84,0x31c426e4,0x63a92f85,0xe4d45e75}},	//   rioz, लब्ध, gugn, بونت_, 
   {{0x64948fb9,0x75212f86,0xab58002f,0x66f00210}},	//   птәр_, sioz, lwür, _pękł, 
   {{0x213c0369,0x00000000,0x00000000,0x00000000}},	//   fouh_, --, --, --, 
   {{0x63a92f87,0x4fd490b1,0xab580112,0x7c3402d0}},	//   bugn, ежит, nwür, _oxyr, 
   {{0x7334278f,0x63a92f88,0xdd8c0014,0x15f80210}},	//   _قىرا, cugn, یوٝ_, ूनकर_, 
   {{0x356c02d3,0xab580112,0x00000000,0x00000000}},	//   _ኵነታት_, hwür, --, --, 
   {{0x213c0399,0x7c3400a2,0x00000000,0x00000000}},	//   bouh_, _axyr, --, --, 
   {{0x7e6c0276,0x213c0007,0xc40801d9,0x91fc02b1}},	//   _şapt, couh_, _بتہٕ_, _ngāi, 
   {{0x5ed0082a,0xdce40356,0x28dc1157,0x5f4000cf}},	//   رتیز, _sună, _पोषि, رچۇل, 
   {{0x5f0000a7,0x6900000d,0xb0ac1b51,0x00000000}},	//   _изча, _jõev, _टाँग, --, 
   {{0x9f300046,0xdd8c035b,0x3eb800ac,0x29640063}},	//   _шеші, _шш_, əst_, дњав, 
   {{0xab581196,0x9ce80327,0x98a0012d,0xe6c4578b}},	//   gwür, _སོགས, ynią_, रज्ज, 
   {{0xd77402de,0x3d180490,0xa2bc1b76,0xdca40114}},	// [1d690] نالع, मोळे_, ल्ड्, _рањи, 
   {{0xb9052f89,0xab580086,0x06140064,0xd2440133}},	//   _यो_, rwüs, ндзю, _نۆ_, 
   {{0xb0ac1b87,0x88940107,0xab58002f,0x98a0012d}},	//   _टांग, _пинх, bwür, wnią_, 
   {{0x63a92f8a,0x98a0033f,0x3d3400b0,0x45180327}},	//   tugn, tnią_, pāwe_, ྱིེར_, 
   {{0x2fc40070,0x63a822d0,0x03a52f8b,0xd37800d1}},	//   _npog_, uugn, хило, үчә_, 
   {{0x63a92f8c,0xe5c4022e,0x7c20010e,0xefdc0023}},	//   rugn, _осбо, _ýore, ዕባዚ_, 
   {{0x2fc4079b,0x7c2001a8,0x7bd800b0,0x25a400e5}},	//   _apog_, _þorv, ātui, ánld_, 
   {{0x63a92f8d,0x81452f8e,0x98a00064,0x00000000}},	//   pugn, رچان, pnią_, --, 
   {{0x83343bb3,0x249c025c,0x213c0036,0x3f98002e}},	//   _знах, _idum_, rouh_, ésu_, 
   {{0x91fc04fe,0x8478001f,0x213c0007,0x831800c6}},	//   _ngāw, ሮፕላን_, souh_, _عقار_, 
   {{0x3eb8000f,0x6ce82ce6,0xf1b80208,0x00000000}},	//   ęst_, टांग_, ctơ_, --, 
   {{0x28dd1487,0xfd104c84,0x249c0135,0x00000000}},	//   _पोलि, اجد_, _jdum_, --, 
   {{0xeb942f33,0x60d87bad,0xbea40137,0x26c00129}},	//   ния_, mdum, _залк, _objo_, 
   {{0x3b0834d8,0x60d834d4,0x249c01a9,0xd52c0241}},	//   чего_, ldum, _ldum_, _kọ́n, 
   {{0x7f412f8f,0xf2d000c8,0x60d92f90,0xab580e78}},	//   molq, װען_, odum, twür, 
   {{0x60d92f91,0x249c0327,0xe9d40a89,0x2ef000fd}},	//   ndum, _ndum_, экс_, _азәр, 
   {{0x237c0b89,0xab580e78,0xd52c01e1,0xb76800ec}},	// [1d6a0] _ntuj_, rwür, _lọ́n, سٽال_, 
   {{0x249d2f92,0x7bd422d0,0xab5817da,0x60d80327}},	//   _adum_, _isyu, swür, hdum, 
   {{0xe3ac3cd9,0x98a004a7,0x00000000,0x00000000}},	//   ەرى_, jnić_, --, --, 
   {{0x7afc3098,0xb0ac02fe,0x7bd40139,0x98a0033f}},	//   _hopt, _टाइग, _ksyu, dnić_, 
   {{0x98a0068f,0x249c031c,0x60d92f93,0x69000254}},	//   enić_, _ddum_, ddum, _põev, 
   {{0x7af80267,0xeb90008f,0x60d800e2,0x7c2002d2}},	//   ötth, אָק_, edum, _þoru, 
   {{0x2fc405e4,0xf0740131,0xc19400ec,0x00000000}},	//   _spog_, нийә_, نديڪ, --, 
   {{0x60d86896,0x25b80302,0x2164026a,0x94c800aa}},	//   gdum, _מצלמ, нији_, _تاسې_, 
   {{0x936400c7,0x7afc4d25,0x25ac0034,0x94440124}},	//   _анаҵ, _oopt, ągle_, _рмаҵ, 
   {{0x7afc084c,0x98a12f94,0x71f8107b,0x00000000}},	//   _nopt, bnić_, _ىراس_, --, 
   {{0x80bc0574,0x7bd407e2,0x60d8208d,0x249c03b2}},	//   व्हे, _asyu, bdum, _ydum_, 
   {{0x60d801f5,0x31b8036e,0x00000000,0x00000000}},	//   cdum, mëz_, --, --, 
   {{0x7afd2f95,0xe0cc0014,0x31b80200,0xe7cc012d}},	//   _bopt, _دٲن_, lëz_, _सैंप, 
   {{0xdee00063,0xf7a800d1,0x00000000,0x00000000}},	//   _бољи, _ﺷﻪﻫﻪ, --, --, 
   {{0xda3401e0,0x9f5c01d3,0x7afc007c,0x98a0012d}},	//   геры, _órát_, _dopt, lnię_, 
   {{0x58d431de,0x290c00c6,0xc8c86ea9,0x00000000}},	//   лост, óga_, بورن_, --, 
   {{0x0708a5af,0x5ed0015b,0xb0ac00e1,0x249c022e}},	// [1d6b0] ويري_, তারে, _टाईग, _rdum_, 
   {{0xaa840014,0x31b80240,0x7afc002b,0xa034011a}},	//   _سۆرم_, këz_, _gopt, תאמה_, 
   {{0x60d8c7e9,0x3ce40f4a,0xaa6400d4,0x00000000}},	//   ydum, टाचे_, _ятик, --, 
   {{0x237c2340,0x7bd848e1,0xdb0c0108,0xc878010e}},	//   _ptuj_, ātuv, öhön, _üş_, 
   {{0x98a0033f,0x7afc022e,0x00000000,0x00000000}},	//   wnić_, _yopt, --, --, 
   {{0x130802bf,0xd7f82e01,0xb864021f,0x98a0012d}},	//   нній_, _чую_, _جاپو, dnię_, 
   {{0x15a806bb,0x91fc0421,0x60d80649,0x7af92f96}},	//   _пъти_, _ogāu, tdum, ötti, 
   {{0x98a03ad4,0x91fc02b5,0x00c92f97,0x3d3400b0}},	//   rnić_, _ngāu, флик_, kāwa_, 
   {{0x60d809a5,0x2008031d,0x98a007f5,0x6fb0007b}},	//   rdum, áci_, snić_, لميا, 
   {{0x63b801e2,0x8fc405e6,0x60d803cd,0x6efc013a}},	//   _iqun, ازين, sdum, _nábě, 
   {{0x7afd2f98,0x51852f99,0x690000c5,0x72401c3b}},	//   _ropt, _буча, _jões, _پھول, 
   {{0x7afd2f9a,0x6fb0158b,0x7f400455,0xd25000e5}},	//   _sopt, دمیا, solq, _چنے_, 
   {{0x7afd2f9b,0x4c340de7,0x7118011a,0x00000000}},	//   _popt, гэрт, _קונפ, --, 
   {{0xe8fc20ef,0x7afd2f9c,0xbea521e2,0x00000000}},	//   _aoû_, _qopt, _ракк, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf7702418,0x947c0055,0x7bd40166,0x00000000}},	//   لائ_, _gṛhñ, _tsyu, --, 
   {{0x63b84b2a,0x78652f9d,0x37c4007b,0x36940108}},	// [1d6c0] _nqun, тказ, ضياف, вшес, 
   {{0x637c054e,0x3ce400c5,0x8b940395,0xebe00354}},	//   _mână, _जोते_, _сръч, _тоьп, 
   {{0x63b820ac,0xceb8033f,0x6900000d,0xe690006c}},	//   _aqun, więk_, _põet, شلند, 
   {{0xe4a12f01,0x7c200008,0x6efc012c,0xe5a02083}},	//   аршо, _þors, _zábě, рици, 
   {{0xe3d025aa,0xa3b40014,0x6900007d,0x2904013f}},	//   لتوع, ناور_, _võet, ɔna_, 
   {{0x91fc0421,0x925805f5,0xab58b691,0x00000000}},	//   _ogāt, налт_, rtüg, --, 
   {{0x91fc1f4c,0x63b92f9e,0x1b1402f5,0x6900000d}},	//   _ngāt, _equn, _সদাই_, _tõet, 
   {{0x66012f9f,0x31b8044e,0x3f80996a,0x799c02d0}},	//   änke, rëz_, _ōhua_, _mvpw, 
   {{0xa2bc0574,0x336401c0,0x31b80200,0xd42000cc}},	//   ल्ह्, _аваг, sëz_, _ফুৰি_, 
   {{0x27fc07ea,0x69000254,0x31b8036e,0x98a00210}},	//   _àune_, _jõer, pëz_, rnię_, 
   {{0x4c952fa0,0x236800d0,0xe2952fa1,0x00000000}},	//   линс, žijú_, _рах_, --, 
   {{0x61400408,0x2dc40150,0x497401a9,0xefdc0092}},	//   _кеха, _ﺒﺴﻼﺤ, ғлас, ንሣይ_, 
   {{0x823c0023,0x1d2401b9,0x9d18020f,0x1dc0009d}},	//   _ኣታሓሳ, рмўм, тоят_, гөөн, 
   {{0xce947701,0xab580790,0xade400f3,0x205400d9}},	//   _сакъ, ktüe, _ацик, _סיגל_, 
   {{0x799c02d0,0x9e200137,0x4734024c,0x00000000}},	//   _cvpw, _پىيو, ҳнас, --, 
   {{0x3d3402b5,0x1958013d,0xadc000fb,0x61f401e3}},	//   pāwa_, васы_, _баҫһ, äxli, 
   {{0x47341f10,0x085402bf,0xab5804cc,0x58d43740}},	// [1d6d0] гнас, уваю, ttüd, шотт, 
   {{0x6d4d2fa2,0x799c03ac,0x7c2000a2,0x260418bc}},	//   llca, _fvpw, _ýora, кчег, 
   {{0x73c00184,0x6d5c3fa8,0xda9405f5,0x7c2001a8}},	//   ҙәте, _èpas, _өгөө, _þorr, 
   {{0x58842ecc,0xab592fa3,0x843800d1,0x00000000}},	//   _выра, stüd, ىكار_, --, 
   {{0x9d1c008f,0x69d802b5,0x66000267,0xab580112}},	//   וואט, āueu, änkb, mtüb, 
   {{0x6900007d,0x0594c9f0,0x6d4c0036,0xbd000129}},	//   _tões, _مارگ, hlca, _àéva, 
   {{0xd5b92fa4,0x7a3000e5,0x00000000,0x00000000}},	//   _ист_, műté, --, --, 
   {{0x91fc0618,0x7c3875c0,0xd04003b9,0x00000000}},	//   _agās, ştri, lemə, --, 
   {{0x2d480165,0x63b84964,0x6d4c0210,0x00000000}},	//   nùeu_, _uqun, dlca, --, 
   {{0x637c0276,0x00000000,0x00000000,0x00000000}},	//   _vână, --, --, --, 
   {{0xd1b92fa5,0x6d4c003a,0xff1400b5,0xab580112}},	//   _لانا_, flca, gのa_, ktüb, 
   {{0x637c084c,0x6b8000b0,0x9d04010b,0x25d800c5}},	//   _tână, _ōnga, рҗик, _गईनी_, 
   {{0x21e00205,0xedd80139,0xccf401ec,0x660001bf}},	//   _hıh_, _үлчә_, рқы_, ønkj, 
   {{0x6d4c0c8c,0x63a8007b,0xa3b8033f,0xfd100214}},	//   alca, irgn, _अमन_, _گجت_, 
   {{0xfce52fa6,0x94040213,0xab58002f,0x3cc0030d}},	//   _бойо, _demə_, ftüb, _гιер, 
   {{0x5fb47aec,0x6900000d,0x00000000,0x00000000}},	//   _आमाल, _sõer, --, --, 
   {{0x36c430af,0x06dc0154,0xac80013d,0xb7e40153}},	// [1d6e0] лбаг, ঠানি, _угыл, ыжак, 
   {{0x6d5c0395,0x28442374,0x2bf0012c,0x63a80427}},	//   _èpar, узуп_, ुहरू_, drgn, 
   {{0x6934098d,0x6900000d,0x80b80154,0x34a80114}},	//   mćen, _võer, _আসন্, евео_, 
   {{0xdb040227,0xd9105c81,0xb4dc00dc,0x2db4008f}},	//   _iqiñ, _بیر_, तये_, טלען_, 
   {{0x91fc04fe,0x940403b9,0x00000000,0x00000000}},	//   _ngār, _yemə_, --, --, 
   {{0x53341b6b,0xa2bc0490,0xa0840220,0xab58002f}},	//   јект, ल्ल्, ңсыз_, mtüc, 
   {{0xe7343e32,0x91fc00cd,0x6d4ccc2f,0x00000000}},	//   _сер_, _agār, ylca, --, 
   {{0x69000254,0x3dc00042,0x79580142,0x78b400c7}},	//   _jõep, _âhwy_, bïwe, ngyv, 
   {{0x35b80c2e,0x776c0ba7,0x764c0142,0xab580112}},	//   _उमड़, _kibx, _hyby, ntüc, 
   {{0x67b808a8,0x00000000,0x00000000,0x00000000}},	//   עמיק, --, --, --, 
   {{0x720400c6,0xdd100764,0x3ce40037,0x00000000}},	//   _حوام, ासंध_, _जोहे_, --, 
   {{0x776c045a,0x00000000,0x00000000,0x00000000}},	//   _libx, --, --, --, 
   {{0xc62002fe,0xff1400b5,0xf15003e6,0x6d4c0332}},	//   _मध्य_, sのa_, _پێکد, rlca, 
   {{0xe0400116,0x3c9400d1,0xdce401ef,0xd91800c7}},	//   _унчи, _ﻛﯩﺸﻰ_, _kuně, қьс_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2d9c6e1c,0x92d0015b,0x8c1801c8,0xb4dc00cd}},	//   mste_, ষায়_, _ليبر_, तयो_, 
   {{0x2d9c0430,0xab5803fa,0x0bd40798,0x7c2001a8}},	// [1d6f0] lste_, rtüb, _топџ, _þorp, 
   {{0xeb9c0a64,0x1b180022,0x764cbd77,0x63a807f5}},	//   msø_, _бжьы_, _byby, vrgn, 
   {{0xeb9c3bb4,0x764c0042,0xab58002f,0x6ff80154}},	//   lsø_, _cyby, ptüb, ইনিজ_, 
   {{0x2d9d2fa7,0x63a81710,0xfa3402dd,0x19240023}},	//   iste_, trgn, _түсі_, _ተፈልዮ, 
   {{0x3898d878,0x2d9d2fa8,0xdcf001a6,0xeb9c01bf}},	//   _בירנ, hste_, šeći, nsø_, 
   {{0x2d9d2fa9,0x776c198f,0xdce400bc,0xd8000408}},	//   kste_, _gibx, _buně, _хăш_, 
   {{0xa49022cd,0x2d9d2faa,0x764c0142,0x00000000}},	//   _هیات, jste_, _gyby, --, 
   {{0x2d9c105c,0x26d12fab,0xf47402dd,0xf1d8095f}},	//   dste_, lexo_, _көші_, भिजन, 
   {{0x2d9d2fac,0x7f180024,0x00000000,0x00000000}},	//   este_, віну_, --, --, 
   {{0x26d0056a,0x2d9c0b4f,0xff2400f7,0x776c011f}},	//   nexo_, fste_, рмоо, _xibx, 
   {{0x2d9d2fad,0x6934009b,0xc104abd7,0x00000000}},	//   gste_, vćen, _پوشي, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2d9d2fae,0xef0d2faf,0xeb9c005c,0x6adc0154}},	//   aste_, _дм_, gsø_, মানো, 
   {{0x2d9c0112,0xa07400c7,0x00000000,0x00000000}},	//   bste_, _рыҧш, --, --, 
   {{0x69c001b8,0x00000000,0x00000000,0x00000000}},	//   _änel, --, --, --, 
   {{0x776c0218,0x693400f3,0x3b9406ed,0xe704036b}},	//   _sibx, sćen, _кјот, یسلی, 
   {{0xa9652fb0,0xfaa52fb1,0x693462b3,0x6bd438b7}},	// [1d700] рита_, _капо, pćen, _نويس_, 
   {{0x26d00117,0xb6a401b9,0x764c0042,0x00000000}},	//   gexo_, рижл, _pyby, --, 
   {{0xab580639,0x91fc04fe,0x690000c5,0x7d147c46}},	//   stüc, _ngāp, _tõep, _klys, 
   {{0x66003f64,0x3ea802a8,0xab600209,0x764c01ef}},	//   änka, _ɓata_, rrüň, _vyby, 
   {{0x23747dc6,0x28dc00ab,0x3950017a,0x764c0042}},	//   لمند_, _पोटि, mlys_, _wyby, 
   {{0xf1a52fb2,0x39500731,0x2d9d2fb3,0x75d477eb}},	//   арин, llys_, yste_, _پيرا, 
   {{0xe5a01679,0x39512fb4,0x7d14127b,0xd7ac0c22}},	//   _мири, olys_, _olys, _चिडच, 
   {{0x39512fb5,0xa5052fb6,0x2d9c1196,0x71640a11}},	//   nlys_, _кеса_, vste_, جاتك, 
   {{0x60f402d5,0x39501368,0x2d9d2fb7,0xa50400f3}},	//   рныя_, ilys_, wste_, _тета_, 
   {{0x2d9c2da7,0x7d152fb8,0x39500076,0xaf041b0a}},	//   tste_, _alys, hlys_, рчик, 
   {{0x2d9d2fb9,0x7d14cc26,0x78a413d5,0x395000c0}},	//   uste_, _blys, _odkv, klys_, 
   {{0x7d152fba,0x395001bf,0xeb9c12e8,0x00000000}},	//   _clys, jlys_, tsø_, --, 
   {{0x2d9c3468,0xceb80032,0x6fd40736,0x39512fbb}},	//   sste_, _йән_, _خزائ, dlys_, 
   {{0x2d9d2fbc,0x28dc1d8a,0xeb9d0327,0x39500ea0}},	//   pste_, _पोजि, rsø_, elys_, 
   {{0x7d141088,0x3950017a,0xeb9c01bf,0x00000000}},	//   _flys, flys_, ssø_, --, 
   {{0x69c0014a,0xceb83f05,0x3c2c035b,0x00000000}},	//   _änem, lgę_, ẽva_, --, 
   {{0x26d00005,0x2aa806ed,0xda7800d0,0x00000000}},	// [1d710] texo_, _итно_, žďa_, --, 
   {{0xceb80006,0x0698007b,0xd7c801e2,0xf3fc00eb}},	//   ngę_, اناة_, شومه_, ্ছার_, 
   {{0x09f80491,0x26d0056a,0x39500153,0xceb800c0}},	//   _صفحة_, rexo_, blys_, igę_, 
   {{0x26d12fbd,0x43752fbe,0x00000000,0x00000000}},	//   sexo_, букт, --, --, 
   {{0x147403e6,0x00000000,0x00000000,0x00000000}},	//   زانج, --, --, --, 
   {{0xd7940b01,0x00000000,0x00000000,0x00000000}},	//   _фиръ, --, --, --, 
   {{0x41286be6,0x7580bc3d,0xe5e001d9,0x16341cd6}},	//   локо_, _فیلم, _بٲزی, _деря, 
   {{0x592c0327,0xaaa408df,0x00000000,0x00000000}},	//   སོགས_, कृतक, --, --, 
   {{0x437439b5,0x409410de,0xa3b84a76,0xb3840133}},	//   _طهار, _ۇلار, _अमि_, _هێنم_, 
   {{0x6d5c025a,0x6f192fbf,0x7d152d33,0xef14c23e}},	//   _ahqa, ghtc, _slys, ймы_, 
   {{0x7d140a85,0x42552fc0,0xfce4013e,0xb6d8008f}},	//   _plys, _انار, боно, אַכט, 
   {{0xcb081203,0x98b00030,0x6d5c6ea1,0xffb80354}},	//   _אל_, _šaľa_, _chqa, _букъ_, 
   {{0x7f840597,0x6d5c0009,0x27f800b5,0x6f1801e7}},	//   _التن, _dhqa, jxqn_, bhtc, 
   {{0x6f192fc1,0x6458009f,0x39500142,0x7c2000a2}},	//   chtc, _mzui, wlys_, _ýorm, 
   {{0x7d1403cb,0x3950372f,0x00000000,0x00000000}},	//   _tlys, tlys_, --, --, 
   {{0x2918016d,0xae4001d9,0x3950017a,0x8d840066}},	//   ghqa_, _ژھێو, ulys_, _بشون, 
   {{0x39512fc2,0x94100198,0x660001e6,0x37540451}},	// [1d720] rlys_, ɗaɗi_, änkn, مپرس, 
   {{0x39512fc3,0x6ec80a94,0xab5801ed,0x16146911}},	//   slys_, त्पु, ltün, يساڭ, 
   {{0x8b6430a3,0x64592fc4,0xade8012c,0x059803c7}},	//   _بايم, _azui, टियन_, لملک_, 
   {{0xab592fc5,0x81bc0729,0x2918bfbe,0x98ac005f}},	//   ntün, ইবা_, chqa_, ēlēs_, 
   {{0x64c12fc6,0x5eac015b,0x00000000,0x00000000}},	//   سيول, জ্যে, --, --, 
   {{0xe1f40323,0x00000000,0x00000000,0x00000000}},	//   өгч_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd1300597,0x00000000,0x00000000,0x00000000}},	//   ظمة_, --, --, --, 
   {{0xab5800e5,0x00000000,0x00000000,0x00000000}},	//   dtün, --, --, --, 
   {{0x6d5d2fc7,0x23e80214,0xceb80024,0x00000000}},	//   _shqa, _حذفی_, ugę_, --, 
   {{0x201c0085,0xceb87502,0xce5800ea,0x272c0327}},	//   azui_, rgę_, ранц_, nżna_, 
   {{0x6f192fc8,0x332c031c,0x00000000,0x00000000}},	//   shtc, lifx_, --, --, 
   {{0xe0401639,0xa2bc17c6,0xef640395,0x320c010e}},	//   _енци, ल्क्, _лъко, lyfy_, 
   {{0xc1740046,0x91dcd9e5,0xe0400137,0xdee00107}},	//   _ادەت, _मनाई, _энчи, _ночи, 
   {{0xa8a52fc9,0x60e4148b,0x28a40024,0x9e30e583}},	//   йрак, _ármú, йшаг, _нешч, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x5d140046,0x19592fca,0xe78494eb,0x6728180f}},	// [1d730] _ءبىز, саты_, субо, ègjo, 
   {{0x29192fcb,0x6600005b,0x00000000,0x00000000}},	//   shqa_, änko, --, --, 
   {{0x6ec811bc,0xa9c46568,0x00000000,0x00000000}},	//   त्यु, _ازخو, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x03a400a8,0x2bdc2a27,0x00000000,0x00000000}},	//   цило, _पैमा, --, --, 
   {{0xab5801d3,0x272c0327,0x201c01a9,0x00000000}},	//   ztün, bżna_, vzui_, --, 
   {{0x56952fcc,0x12c4a9de,0x00000000,0x00000000}},	//   _хаст, ستوپ, --, --, 
   {{0x707417de,0xb4b401af,0x00000000,0x00000000}},	//   يمىز_, _мисә, --, --, 
   {{0x645801f7,0x332c00b5,0xca4400d1,0x00000000}},	//   _uzui, bifx_, ﯘﺭﺍ_, --, 
   {{0xe81800bc,0x201c0356,0xff2400d4,0x00000000}},	//   पैया_, rzui_, імно, --, 
   {{0xab592fcd,0xece00154,0x10e40150,0x00000000}},	//   ttün, যানড, _ﻋﻤﺩﻨ, --, 
   {{0x7c200432,0xab580205,0xc32801a9,0x81600244}},	//   _ýork, ftüo, _сўғд_, _تۆبۆ, 
   {{0xab592fce,0xbea40022,0x3ea52fcf,0x92bc03d4}},	//   rtün, _далк, _дилг, ইজৰ_, 
   {{0x62812fd0,0x3f8d2fd1,0xab592fd2,0xf5700092}},	//   ncno, mpeu_, stün, _እነዚያ_, 
   {{0xd05c013f,0x3f8c3813,0x7f5c004e,0x66003bba}},	//   ɑyɑd, lpeu_, ïsqu, änkl, 
   {{0x5ba40116,0xab580790,0x8cc02e35,0x6d440419}},	//   _елиғ, ltül, _वायो, čkac, 
   {{0xdca422f7,0x7c649098,0xb8652fd3,0x00000000}},	// [1d740] _дақи, _باغل, زارو, --, 
   {{0xab58708d,0x7bc4002f,0x7e6c00a2,0x00000000}},	//   ntül, mtku, _şapy, --, 
   {{0x3944ab01,0x7bc52fd4,0x00000000,0x00000000}},	//   _мног, ltku, --, --, 
   {{0x538402dd,0x00000000,0x00000000,0x00000000}},	//   зқаз, --, --, --, 
   {{0x7bc4be79,0x249002d3,0x09dc0327,0xab5851e6}},	//   ntku, ምስራት_, _ལནྜ_, ktül, 
   {{0x47d800c8,0xa3b859c9,0xfbb00034,0x25ac1432}},	//   _פֿרײ, _अमर_, _जिनम, ümlü_, 
   {{0x65c11e17,0xb1a00032,0x7bc40037,0x418460c6}},	//   _обра, фһеҙ, htku, птығ, 
   {{0x7bc40250,0x88300092,0x320c0210,0x00000000}},	//   ktku, _በመቅደ, ryfy_, --, 
   {{0xab5805d2,0x00000000,0x00000000,0x00000000}},	//   ftül, --, --, --, 
   {{0xe2c80133,0xe29525ef,0xd0940092,0xaf3400be}},	//   _نامۆ_, _мау_, _መጀመሩ_, ترعت, 
   {{0x667825f9,0x7bc40af9,0xdce40139,0xdb080241}},	//   יטיק, etku, _qunğ, _àlùm, 
   {{0x7bc405ac,0xdce401a6,0x00000000,0x00000000}},	//   ftku, _bunđ, --, --, 
   {{0x1ae403f4,0x5bb80b7e,0x7bc401bf,0x9be400d4}},	//   খানে_, оляя_, gtku, мірк, 
   {{0xdce4f086,0xfbcc0451,0x25d80037,0x00000000}},	//   _dunđ, اڪي_, _गईली_, --, 
   {{0x7bc4001f,0xa2bc01ad,0xcfbc00eb,0x00000000}},	//   atku, ल्ट्, _অনিন, --, 
   {{0xa3b81414,0x00000000,0x00000000,0x00000000}},	//   _अमल_, --, --, --, 
   {{0xdce416a3,0xacb8002d,0x7df40137,0x00000000}},	// [1d750] _gunđ, rhûd, _وقۇچ, --, 
   {{0x8a1801c4,0x00000000,0x00000000,0x00000000}},	//   _гоос_, --, --, --, 
   {{0xab583262,0x06dc02f5,0x00000000,0x00000000}},	//   ntüm, ঠালি, --, --, 
   {{0x69c52fd5,0xd1f0001f,0x98a001a6,0x6ec8043e}},	//   mtje, ኃኒት_, viić_, त्तु, 
   {{0x69c52fd6,0x78f80375,0xd8380e3b,0x25d80456}},	//   ltje, _הפרו, _дэр_, _गैरी_, 
   {{0x69c401a4,0x20e4004d,0xc2c40592,0x04c801c8}},	//   otje, _ối_, سيبي, _گوري_, 
   {{0xe4d44439,0x69c52fd7,0xddc80006,0xdb240008}},	//   _وترب, ntje, čiūt, ðrét, 
   {{0x21280699,0x04c80f13,0x69c401a4,0x7bc40698}},	//   òch_, _دوري_, itje, ytku, 
   {{0x69c4c75b,0xd94c02d3,0xb27065ed,0x9128007b}},	//   htje, _መጥቃዕ, мләш, تسوق_, 
   {{0x69c0010e,0x7c20010e,0xdcd400cd,0x00000000}},	//   _änew, _ýori, धज्ञ, --, 
   {{0x69c4044e,0xdce43421,0xab592fd8,0xc0dc0092}},	//   jtje, _sunđ, rtül, ንሳል_, 
   {{0x69c4037e,0x7bc5214f,0xdce40331,0xab5801d3}},	//   dtje, ttku, _punđ, stül, 
   {{0x69c40cf9,0x2bdc00ab,0x5ec0022e,0x00000000}},	//   etje, _पैदा, _жилғ, --, 
   {{0x69c401f5,0xdb040129,0x6b800051,0x00000000}},	//   ftje, _xviè, _ăngt, --, 
   {{0xab252fd9,0x7bc52fda,0xfe34010f,0x00000000}},	//   чора_, stku, _מאַך_, --, 
   {{0x77852fdb,0x7bc401bf,0x00000000,0x00000000}},	//   злаз, ptku, --, --, 
   {{0x69c52fdc,0x56e52fdd,0x1ae40154,0x00000000}},	// [1d760] atje, мбағ, খাবে_, --, 
   {{0xdb040022,0x69c4332e,0xa6e0004e,0x00000000}},	//   _ovié, btje, нжул, --, 
   {{0xfebc0f22,0xf5b4023a,0x69c401f5,0x00000000}},	//   _অসাধ, ясаю, ctje, --, 
   {{0xb46478da,0x00000000,0x00000000,0x00000000}},	//   пкел, --, --, --, 
   {{0xdb04068c,0xe3ac7500,0x00000000,0x00000000}},	//   _avié, هرو_, --, --, 
   {{0x35a40408,0x2bdc000d,0x00000000,0x00000000}},	//   _нагг, _पईसा, --, --, 
   {{0xded80023,0xe640014b,0x00000000,0x00000000}},	//   ንናን_, _зерп, --, --, 
   {{0xe1ec021a,0x92bc0729,0x21600228,0x503402d3}},	//   اسو_, ইজে_, нтыг, _ክትረኽ, 
   {{0x2404010a,0x00000000,0x00000000,0x00000000}},	//   _енти_, --, --, --, 
   {{0xb8fc1e81,0x9e801ee0,0x69c52fde,0x00000000}},	//   _རི_, _ነበርና_, ytje, --, 
   {{0x8cc000e1,0x69c4007c,0x00000000,0x00000000}},	//   _वादो, xtje, --, --, 
   {{0xab580e78,0xd7ac0490,0xdca40120,0xabb00bd6}},	//   rtüm, _चिंच, наџи, намә, 
   {{0xab592fdf,0x69c40d27,0x5f800220,0x00000000}},	//   stüm, wtje, _كۇيە, --, 
   {{0x69c52fe0,0x00000000,0x00000000,0x00000000}},	//   ttje, --, --, --, 
   {{0x69c40d27,0x6adc00fe,0x6934107d,0x00000000}},	//   utje, মালো, ićev, --, 
   {{0x69c4e24f,0x317c04e6,0x00000000,0x00000000}},	//   rtje, _mutz_, --, --, 
   {{0x6d4d2fe1,0x317d2fe2,0x5ba40953,0x5a440092}},	// [1d770] moca, _lutz_, _прэз, _የድርሻ, 
   {{0x69c52fe3,0x962400ef,0x00000000,0x00000000}},	//   ptje, _šņau, --, --, 
   {{0x317c0112,0x8894014b,0x00000000,0x00000000}},	//   _nutz_, _оинх, --, --, 
   {{0xc4cc0183,0xb8f00022,0xab580205,0x00000000}},	//   ৰঞ্জ, _иҧсш, ktük, --, 
   {{0x2908003a,0x27fccaf5,0x5c38010f,0x00000000}},	//   _ioca_, _çun_, ּרון_, --, 
   {{0x6d4c00c6,0x317c0036,0x290803ee,0x6f080175}},	//   hoca, _butz_, _hoca_, _nofc, 
   {{0x6d4ccd71,0x290803ee,0x2bdd2fe4,0xdb2401d3}},	//   koca, _koca_, _पैसा, éséb, 
   {{0x29092fe5,0x6d4d2fe6,0x6ec84668,0x925800ae}},	//   _joca_, joca, त्सु, أشهر_, 
   {{0xd0a8157c,0x1ae4015b,0x3f5800f2,0x00000000}},	//   سطين_, খাতে_, sèum_, --, 
   {{0x29092fe7,0x00000000,0x00000000,0x00000000}},	//   _loca_, --, --, --, 
   {{0x6d441a48,0xdb040113,0x249c007f,0x821400c6}},	//   čkan, _uvié, _keum_, _تواص, 
   {{0x29080a73,0x6d4d2fe8,0x249c00e8,0x11d40330}},	//   _noca_, goca, _jeum_, _ستمد, 
   {{0x249c0483,0x60d92fe9,0x237c0009,0xe2280092}},	//   _meum_, meum, _juuj_, _እንሆና, 
   {{0x60d92fea,0x91fc0055,0x237c002e,0x249c0192}},	//   leum, _agāy, _muuj_, _leum_, 
   {{0xee2c0451,0x00000000,0x00000000,0x00000000}},	//   _پٽي_, --, --, --, 
   {{0x249d0af7,0x6d4d2feb,0x00000000,0x00000000}},	//   _neum_, coca, --, --, 
   {{0xbb8421ec,0xafe4022c,0xb6a41955,0x290800d8}},	// [1d780] _تلخي, mrøð, дизл, _doca_, 
   {{0x7bd84baa,0x3634034c,0xb6345298,0x426c001f}},	//   łtus, وراس, وعات, ትመንት_, 
   {{0x249c00a3,0x60d8003e,0x058402dd,0x7c24002f}},	//   _beum_, keum, еуім, lzkr, 
   {{0x29092fec,0x249c0e89,0x317c04cc,0x60d800d5}},	//   _goca_, _ceum_, _rutz_, jeum, 
   {{0x249c0483,0x60d81709,0x7c243f5b,0x317c04e6}},	//   _deum_, deum, nzkr, _sutz_, 
   {{0x6d4d2fed,0x2908c16f,0x317d2fee,0x7c200432}},	//   zoca, _zoca_, _putz_, _ýoru, 
   {{0xc5140131,0x249c0192,0x6d4c0117,0x60d8003e}},	//   ببەت, _feum_, yoca, feum, 
   {{0x249d2fef,0x60d83e24,0xe7d000f7,0xf0740075}},	//   _geum_, geum, _سۅۅگ, мийә_, 
   {{0x64a12ff0,0x317c04e6,0x7f1c0023,0x72c40114}},	//   _шата, _wutz_, _ስለዝኽ, _обаз, 
   {{0x75212ff1,0xab592ff2,0x6d4c015d,0x7c240171}},	//   lhoz, rtük, woca, dzkr, 
   {{0xafe40579,0xab580793,0x7bd4c5a9,0x60d89824}},	//   frøð, stük, _apyu, beum, 
   {{0x66012ff3,0x60d92ff4,0x6d4c0381,0xafe403b2}},	//   änki, ceum, uoca, grøð, 
   {{0x6d4d2ff5,0x29084a29,0x2bdcdc75,0x00000000}},	//   roca, _roca_, _पैशा, --, 
   {{0x29092ff6,0x6d4d2ff7,0x92b003d4,0xa0700064}},	//   _soca_, soca, ট্ৰ_, _ргіч, 
   {{0x29092ff8,0x75212ff9,0xdeb80375,0xafe403b2}},	//   _poca_, khoz, _ומול, brøð, 
   {{0x58d462d9,0x6ec837e3,0x290800ac,0x9e70215c}},	//   кост, त्रु, _qoca_, _جۇپت, 
   {{0x249c16b8,0xdd1401d9,0x588522cf,0x00000000}},	// [1d790] _reum_, _شوٝخ, тыса, --, 
   {{0x60d8c96e,0xd3780210,0x00000000,0x00000000}},	//   zeum, _nić_, --, --, 
   {{0x44b4eaae,0x60d92ffa,0x8644035b,0x00000000}},	//   ебес, yeum, хьаҵ, --, 
   {{0x2908003a,0x75212ffb,0x07081e5a,0x249c0200}},	//   _uoca_, ghoz, _کيسي_, _qeum_, 
   {{0x94743456,0x249d2ffc,0x7c2000a2,0xc3540395}},	//   ندها, _veum_, _ýort, нъкъ, 
   {{0xfbb0068f,0x31652ffd,0x7cf400fd,0xe4ec000d}},	//   _जिसम, _ahoz_, _kürä, _घोरि_, 
   {{0x75204242,0xd37801a6,0x60d80098,0x932400e5}},	//   bhoz, _dić_, teum, ضرون, 
   {{0x3fe43849,0x75212ffe,0x316402e2,0x823402d3}},	//   ежив, choz, _choz_, _ክንርዳ, 
   {{0x60d92fff,0xbf10013d,0x00000000,0x00000000}},	//   reum, лүдә, --, --, 
   {{0x60d93000,0x626400cf,0x7c240427,0x786800e5}},	//   seum, _قااق, vzkr, lövé, 
   {{0xee353001,0x60d8003a,0xafe40162,0x00000000}},	//   енэ_, peum, trøð, --, 
   {{0x7c253002,0x786801d3,0x00000000,0x00000000}},	//   tzkr, növé, --, --, 
   {{0x7c24030a,0x50b800f2,0xafe40174,0x00000000}},	//   uzkr, _زدند_, rrøð, --, 
   {{0x7cf4372c,0x7c24b571,0x752001d3,0x93f00073}},	//   _bürä, rzkr, zhoz, चितच_, 
   {{0x3ea53003,0xaa413004,0x213c102c,0x6b613005}},	//   malt_, герл, onuh_, укра, 
   {{0x3ea53006,0x75210a64,0x213c031c,0x00000000}},	//   lalt_, xhoz, nnuh_, --, 
   {{0x81d42f8b,0x75203b7f,0x6d380375,0x3ea4062c}},	// [1d7a0] িটি_, vhoz, _מתקנ, oalt_, 
   {{0x3ea4860e,0xacb8002d,0x00000000,0x00000000}},	//   nalt_, nhûn, --, --, 
   {{0x75213007,0xd9b40150,0x81d40154,0xc76400db}},	//   thoz, _جەزد, িয়ত_, ئاقى, 
   {{0x3ea49235,0x81d40eac,0xe0c0015b,0x00000000}},	//   halt_, িটা_, ্যুন, --, 
   {{0xd130293c,0x3ea53008,0xacb80af2,0x69343421}},	//   یمت_, kalt_, khûn, rćet, 
   {{0x75209c7a,0x3ea4007d,0x1ce00327,0x39513009}},	//   shoz, jalt_, _ཤིའ_, loys_, 
   {{0x8cc0068f,0xe3705e18,0x3ea5300a,0x75206580}},	//   _वालो, ылшы, dalt_, phoz, 
   {{0x752002c4,0xdce401e4,0x25640037,0x00000000}},	//   qhoz, _piiĝ, võlg_, --, 
   {{0x93c8066d,0xb465300b,0x2508806b,0xacb8002d}},	//   _تازہ_, _чкал, _عرفی_, fhûn, 
   {{0x6d441b5c,0xc2e8007b,0xfeb000c7,0x00000000}},	//   čkam, _يعلم_, аҩшь, --, 
   {{0x6fc002f5,0x3164009a,0x4c948a2e,0x213c0548}},	//   ্টেই, _thoz_, кинс, bnuh_, 
   {{0x9a8449c6,0x3950123b,0x1ce00327,0xad6402c9}},	//   ғурл, joys_, _ྤྲད_, عاده, 
   {{0x3ea5300c,0xacb800d2,0x7cf400fd,0x00000000}},	//   balt_, bhûn, _sürä, --, 
   {{0x7cf400b0,0xacb8002d,0xea54086a,0x6ee407d6}},	//   _pürä, chûn, езгә_, _سستل, 
   {{0x799c03cb,0x59f80276,0x00000000,0x00000000}},	//   _cwpw, неря_, --, --, 
   {{0x1ce0031c,0x6e2c01a8,0x39500009,0xda08007b}},	//   _ཤིར_, úbbu, goys_, ريقه_, 
   {{0x5bb80153,0xdca400f3,0x00000000,0x00000000}},	// [1d7b0] _злыя_, _сањи, --, --, 
   {{0xd2440133,0xa64400d1,0xd7740a11,0x7cf4008e}},	//   _هۆ_, ىخان, هالع, _türä, 
   {{0x348c00b4,0x799c0042,0xd5b001d3,0xda780064}},	//   _ịdị_, _gwpw, یفے_, _пяю_, 
   {{0x395000d5,0xdc340306,0x4394e8a7,0x3ea4e0c1}},	//   coys_, zúča, вадс, zalt_, 
   {{0x1ce00327,0x60dc06be,0x00000000,0x00000000}},	//   _ཤྲས_, _öymə, --, --, 
   {{0x3ea4007c,0x74a80139,0x00000000,0x00000000}},	//   xalt_, псәң_, --, --, 
   {{0x3ea4033d,0x9f49300d,0xc0e400a7,0x0494007b}},	//   valt_, ící_, войк, _للأح, 
   {{0x3ea5300e,0x66004022,0x36240050,0x2919300f}},	//   walt_, änku, _شوقہ, nkqa_, 
   {{0x31540597,0x4438014a,0xa3fc030d,0x00000000}},	//   خليج_, _äs_, _уявĕ_, --, 
   {{0x6578020b,0x213c0548,0x3ea40254,0x00000000}},	//   _hiuh, snuh_, ualt_, --, 
   {{0x3ea41455,0xdc3401a2,0x657801f7,0x6b9c0175}},	//   ralt_, rúča, _kiuh, _awqg, 
   {{0x3ea53010,0xddc003b9,0xc0346bb6,0x5184014b}},	//   salt_, _eynş, _инеј, _суфа, 
   {{0x3ea53011,0x6aa40115,0x63a800a3,0x00000000}},	//   palt_, fajf, nsgn, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x39513012,0x64593013,0xdb0406ed,0x00000000}},	//   toys_, _lyui, _aviã, --, 
   {{0xf1b000c8,0xa9643129,0x65782015,0x00000000}},	//   יסל_, виса_, _niuh, --, 
   {{0x395050eb,0x375405af,0x00000000,0x00000000}},	// [1d7c0] roys_, نپرس, --, --, 
   {{0x7674009f,0x00000000,0x00000000,0x00000000}},	//   نداء, --, --, --, 
   {{0x64580357,0x69c00793,0xacb80af2,0x3944010b}},	//   _ayui, _änep, khûl, _аннг, 
   {{0x65780097,0xb5940124,0x00000000,0x00000000}},	//   _ciuh, еиҧш, --, --, 
   {{0x65780007,0x5ea4015b,0x00000000,0x00000000}},	//   _diuh, _খানে, --, --, 
   {{0xba44006a,0x318c000f,0xe360036b,0x2bc00073}},	//   _gbïä, _lęze_, акчи, वंता, 
   {{0xe5a0b2bd,0x66005de3,0x35a40131,0x7c2803b9}},	//   _виси, änkt, _шавг, _əfra, 
   {{0x4f20069c,0xab58002f,0xe6405ce7,0x8500014b}},	//   _ስለዘይ, ltüt, _тесп, _гӯшз, 
   {{0x7c200327,0x7cd800ef,0x00000000,0x00000000}},	//   _żorn, _mārč, --, --, 
   {{0xa3e4ccc0,0x4d9802bf,0x7afc0208,0x00000000}},	//   _बनत_, нкою_, _nnpt, --, 
   {{0x72040344,0x6f181543,0x00000000,0x00000000}},	//   _جوام, rktc, --, --, 
   {{0x7afc01a4,0x00000000,0x00000000,0x00000000}},	//   _anpt, --, --, --, 
   {{0x02c8007d,0xcfb40801,0xf1580588,0xdbdc0cad}},	//   _रामभ, _сблъ, _еиҧш_, _pàáp, 
   {{0x81d4015b,0x439000d1,0x00000000,0x00000000}},	//   িটর_, ﻟﺪﯨﻦ_, --, --, 
   {{0x26c4004e,0x6aa40200,0x00000000,0x00000000}},	//   ònom_, rajf, --, --, 
   {{0x290c0436,0x00000000,0x00000000,0x00000000}},	//   ðga_, --, --, --, 
   {{0x19593014,0x65780369,0xade846c7,0xc6f8030d}},	// [1d7d0] таты_, _riuh, टिकन_, ннах_, 
   {{0x65793015,0x26c401b8,0x298800f0,0x61e00175}},	//   _siuh, üno_, _осмо_, ywnl, 
   {{0x6458037e,0x6578023a,0x00000000,0x00000000}},	//   _syui, _piuh, --, --, 
   {{0xd87804a2,0x3eb80024,0x00000000,0x00000000}},	//   رمەت_, ėsti_, --, --, 
   {{0x65780108,0x00000000,0x00000000,0x00000000}},	//   _viuh, --, --, --, 
   {{0x56944dba,0xdec00023,0x660001e3,0x00000000}},	//   _варт, ኻትን_, änks, --, 
   {{0xe4a41ee3,0x2d881709,0x65780108,0xab5803e0}},	//   _арзо, íbel_, _tiuh, ltüs, 
   {{0xc04c0023,0x00c801d5,0x00000000,0x00000000}},	//   _ይትረፍ, хлик_, --, --, 
   {{0x7ff45214,0xa3e400af,0xab58029f,0x5ea40154}},	//   اسبا, _बनि_, ntüs, _খাবে, 
   {{0x7cd802b5,0xa06407d6,0x7c200327,0x00000000}},	//   _mārō, нақа_, _żoro, --, 
   {{0x62653016,0x00d4022e,0x00000000,0x00000000}},	//   _شائق, _бўлў, --, --, 
   {{0x7ff48384,0xa3e44425,0xfa500092,0x7ca00023}},	//   _مستا, _बना_, _መስማማ, _ገንሸል_, 
   {{0xdb04180f,0x1fa400c7,0xbab40024,0xcee801d3}},	//   _aviá, _ррег, лёвы, ررین_, 
   {{0x318c0b21,0xbea4c9ff,0x6fb13017,0x703800df}},	//   _węze_, _сакк, _اموا, _אײנצ, 
   {{0xf3880cad,0x272c031c,0xd9440124,0x3948020f}},	//   _iṣe_, nżnu_, иҵои, езво_, 
   {{0x5fb458fc,0xdce43a71,0x39140ee8,0xab589c11}},	//   _इटाल, _munī, دورز, ftüs, 
   {{0x78640b30,0xfaa400d1,0xab5804cc,0x83fc01d3}},	// [1d7e0] указ, _йапо, ttüt, _szőn, 
   {{0xccac01e4,0x3f580ba1,0x00000000,0x00000000}},	//   _imaց, mèus_, --, --, 
   {{0x3f58068c,0xdb24315b,0xab58002f,0x00000000}},	//   lèus_, _موکی, rtüt, --, 
   {{0x66e00220,0xab5803fa,0x2a380375,0x91fc00b8}},	//   _қоса, stüt, _טעימ, _hyāg, 
   {{0x628c084c,0x3f581497,0x1404010b,0xab5806be}},	//   _şcoa, nèus_, шҗаг, mtür, 
   {{0xab5803ee,0x91fc00b8,0xf3880ca8,0x00000000}},	//   ltür, _jyāg, _nṣe_, --, 
   {{0x78a40064,0xf6240108,0x69a4012d,0x77900345}},	//   _kekv, _сдво, टीपी, _ئیڕا, 
   {{0xab593018,0xf38801e1,0x66540408,0x229000d1}},	//   ntür, _aṣe_, _сасă, للۇس, 
   {{0x51840184,0xd3f40212,0xab58002f,0x6ce401ec}},	//   ыуҙа, _мiст, itür, ңіме, 
   {{0x2bdc05f9,0x3f58067c,0x78a53019,0x8f340138}},	//   _पैगा, dèus_, _lekv, реоц, 
   {{0xacb8003c,0xab59301a,0xe298011a,0x02c80ebb}},	//   shûm, ktür, _נשאר, _रातभ, 
   {{0xad25301b,0xf3880055,0x6f64010b,0x53c800c5}},	//   اردو, _eṣe_, _өвез, _रमाश, 
   {{0xdb140209,0xddc80bb3,0x2bdc000d,0x00000000}},	//   şaýa, čišt, _पैखा, --, 
   {{0xce9406bb,0x59f4025c,0xcdc401ec,0xb4c06a60}},	//   _такъ, _བནྡེ_, _кәмп, ्भु_, 
   {{0xa3a809d9,0xbe54021a,0x78a5301c,0x4c943e27}},	//   _कौन_, _پروګ, _bekv, _кийс, 
   {{0x1958704a,0x7cd800b0,0x2eed301d,0x3f58067c}},	//   гасы_, _pārō, _haff_, bèus_, 
   {{0x1ce00135,0x78a40156,0x3f58068c,0x2ca80810}},	// [1d7f0] _ཤྲི_, _dekv, cèus_, macd_, 
   {{0xacb800d2,0xe7306bcc,0xab59301e,0x612400a2}},	//   khûk, حصر_, atür, _iñle, 
   {{0x2eec0418,0x78a401ed,0x04940736,0x00000000}},	//   _maff_, _fekv, للاح, --, 
   {{0x6b58019f,0xab5805d5,0x588400ee,0x2eec0142}},	//   rîgu, ctür, _гыра, _laff_, 
   {{0xab5800ac,0x66f802b5,0xdce40a2f,0x00000000}},	//   rrüf, _pākē, _sunī, --, 
   {{0x77b80375,0x78a40165,0xb9dc0023,0x68ec0205}},	//   _במשח, _zekv, _ኢቲ_, _hacd, 
   {{0xab59301f,0x68ec01d9,0x91fc00b8,0x606000d1}},	//   prüf, _kacd, _nyād, ڭۇشل, 
   {{0x2eec0036,0x5eac015b,0x00000000,0x00000000}},	//   _aaff_, জ্ঞে, --, --, 
   {{0x68ed3020,0x2eec0036,0xef813021,0x00000000}},	//   _macd, _baff_, олып, --, 
   {{0x2eed3022,0x3f58180f,0xef14005b,0xe2a82b9f}},	//   _caff_, vèus_, имы_, _سائن_, 
   {{0x52840491,0xd1b93023,0xab582ca8,0x74880116}},	//   _المك, _مانا_, ytür, _ﺗﯩﭙﯩ, 
   {{0x68ec6c05,0x2eec0175,0xee3421db,0x2ca80066}},	//   _nacd, _eaff_, рню_, gacd_, 
   {{0x2eec0175,0xccf40220,0x8d540006,0x91fc0055}},	//   _faff_, сқы_, стэч, _pyāg, 
   {{0x78a404ac,0x2eed3024,0x1f2001d9,0x68ec013d}},	//   _sekv, _gaff_, _دِتہ, _aacd, 
   {{0xab593025,0x68ec0014,0xdef0001f,0xf93416ab}},	//   ttür, _bacd, ግጠኛ_, ахаю, 
   {{0x68ec0589,0x3f58180f,0x2bc00a59,0xb7c000d8}},	//   _cacd, pèus_, वंशा, çãon, 
  
   {{0xab593026,0xb8ec13e0,0x69a405d7,0x68ec058a}},	// [1d800] rtür, _रा_, टीबी, _dacd, 
   {{0xab593027,0xdb5004d3,0x27e80334,0xe0c004c5}},	//   stür, _رێز_, _dscn_, ্যয়ন, 
   {{0x27e80c6a,0x6d442a69,0x68ec0175,0x78a53028}},	//   _escn_, čkav, _facd, _tekv, 
   {{0xab58245f,0x5924249f,0x68ec00a2,0xb4c008df}},	//   trüg, _اکسف, _gacd, ्भे_, 
   {{0xab580112,0x4b2417b9,0x00000000,0x00000000}},	//   brüd, _ضعیف, --, --, 
   {{0x60c801ab,0x00000000,0x00000000,0x00000000}},	//   _acgm, --, --, --, 
   {{0xe7348abc,0xf2041422,0x00000000,0x00000000}},	//   _тер_, ряло, --, --, 
   {{0x2eed3029,0x68ec0166,0xab583f17,0x00000000}},	//   _saff_, _xacd, prüg, --, 
   {{0x2eec0036,0x91fc00dc,0x5f3c0092,0x00000000}},	//   _paff_, _syād, _ይኖራቸ, --, 
   {{0xa0640063,0x8fc40022,0xb4e401f9,0x00000000}},	//   шања_, _ҳадҵ, _बघु_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2eec04e6,0x91fc00dc,0x00000000,0x00000000}},	//   _waff_, _vyād, --, --, 
   {{0x2eec03b2,0x68ec0009,0x00000000,0x00000000}},	//   _taff_, _racd, --, --, 
   {{0x68ec91f3,0x764c02d0,0xdee0026b,0x91fc00dc}},	//   _sacd, _oxby, _мочи, _tyād, 
   {{0x68ec01e4,0x91fc00b8,0xb4e40073,0xa8a4024c}},	//   _pacd, _hyāb, _बघू_, ирак, 
   {{0x1ce0038f,0x9f4c011f,0xa3e4007d,0x1d080640}},	//   _ཤིག_, _irgá_, _बनल_, _већи_, 
   {{0xad24cdb5,0x6728036e,0x9a880050,0xa0540240}},	// [1d810] _مرکو, ëgjo, انہٕ_, _ምትንታ, 
   {{0x68ec0014,0x7e6c01e4,0x6d440153,0x00000000}},	//   _wacd, _ŝapi, čkau, --, 
   {{0x2d8801f1,0xd6d80640,0x85b9302a,0x68ec0009}},	//   íbeh_, јту_, улес_, _tacd, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc65000dd,0xab582ac2,0x427000d1,0x00000000}},	//   _کہاک, prüd, ﻴﯩﻨﭽ, --, 
   {{0xdee8001f,0xc6e40124,0xee2400ec,0xb86401e2}},	//   ጅቱን_, _усмҩ, _فٽ_, _داپو, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3fd00150,0x00000000,0x00000000,0x00000000}},	//   _ﻛﻪﺭﻧ, --, --, --, 
   {{0x67240083,0x7f184f32,0x00000000,0x00000000}},	//   _kljj, гіну_, --, --, 
   {{0xbc242dfc,0x53340276,0xab58002f,0x00000000}},	//   ەرسى, _деут, hrüb, --, 
   {{0x5e6000db,0x00000000,0x00000000,0x00000000}},	//   تندە, --, --, --, 
   {{0xa3b805f9,0x50b800f2,0x00000000,0x00000000}},	//   _आटा_, _ندهد_, --, --, 
   {{0x6d5c005f,0x6d0000c7,0xf388002b,0x92bc00fe}},	//   _īpat, _ẽhár, _kṣa_, েজৰ_, 
   {{0x09d00011,0xa3dc000d,0x00a00244,0x00000000}},	//   াবনা, _तहन_, _بیکێ, --, 
   {{0xfaa4039b,0x3f8c0023,0xedd03cc6,0x00000000}},	//   _қано, lqeu_, _فيود, --, 
   {{0x628c084c,0x6724002e,0xab580036,0x91fc0055}},	//   _şcol, _aljj, grüb, _hyāc, 
   {{0xa964039b,0x764c0009,0x9b940244,0x00000000}},	// [1d820] сита_, _sxby, _بابڵ, --, 
   {{0xaadc02ab,0x7d14058a,0x00000000,0x00000000}},	//   _पॉपक, _hoys, --, --, 
   {{0x7d15302b,0x3f8c0200,0x00000000,0x00000000}},	//   _koys, hqeu_, --, --, 
   {{0xab586f30,0x7d1485a3,0xb4c0038e,0xf3880cad}},	//   crüb, _joys, ंले_, _aṣa_, 
   {{0x7d15302c,0x798c02d0,0x1dd8000d,0x00000000}},	//   _moys, lqbw, _बहऽत, --, 
   {{0x81e02f8b,0x7d140579,0x931401d5,0x398c08a5}},	//   দিন_, _loys, توتش, _kýs_, 
   {{0x7d15302d,0xe1ec7286,0xab58265c,0x91fc00b8}},	//   _ooys, فسي_, duül, _syāb, 
   {{0xf8b81ab2,0x1ae400bd,0xf3880882,0x91fc002b}},	//   ेलिय, মায়া, _eṣa_, _ayāc, 
   {{0x7bc5302e,0xab580e78,0x398c0d12,0x752001f5}},	//   juku, nrüc, _lýs_, mkoz, 
   {{0x7520066d,0x32440415,0x63b000bc,0x8ec4004b}},	//   lkoz, _лезг, ření, زښتو, 
   {{0x7d15302f,0x398c01a8,0xad24007b,0xa758010f}},	//   _boys, _nýs_, مرحو, רדיר, 
   {{0x7bc53030,0x75213031,0x2ad80316,0x308400c6}},	//   fuku, nkoz, ख्नु_, _الإف, 
   {{0x615401d9,0x752000ca,0x7d140205,0xde400023}},	//   _أنز_, ikoz, _doys, _ብዘይፈ, 
   {{0xab5803fa,0xad2404d3,0xcb680214,0x83fc01d3}},	//   drüc, _گرتو, شمزه_, _szők, 
   {{0xc33800bc,0x26dc0115,0xab580e78,0xdb340640}},	//   _říká, _ĝuo_, trüb, черњ, 
   {{0x7bc53032,0x7d153033,0x6d442aac,0x69c00158}},	//   buku, _goys, čkas, _ånem, 
   {{0x7bc53034,0x6d5c02d0,0xfaec004b,0xab58002f}},	// [1d830] cuku, _ikqa, رګی_, rrüb, 
   {{0xd7c93035,0x7d14009f,0x00000000,0x00000000}},	//   صومه_, _zoys, --, --, 
   {{0x752001f5,0xa3a82ce1,0x7d14022e,0xab580205}},	//   fkoz, कीन_, _yoys, prüb, 
   {{0xab593036,0x03f80063,0x7d1403b9,0x00000000}},	//   brüc, инеј_, _xoys, --, 
   {{0xd7640133,0x62b400fb,0x4374004e,0x00000000}},	//   _کۆلی, йғас_, оукт, --, 
   {{0x59d41b12,0x752004ba,0x00000000,0x00000000}},	//   _بغیر, akoz, --, --, 
   {{0x5ae80489,0x5ea400bd,0x61240724,0x69c53037}},	//   _སྲསམ, _খালে, _añla, nuje, 
   {{0x7bc41bb7,0x04c84c11,0x7580006c,0x7fd93038}},	//   yuku, _خوري_, _قیلم, афот_, 
   {{0x69c423d1,0x7d1406ea,0x7bc4b021,0x00000000}},	//   huje, _roys, xuku, --, 
   {{0x7bc53039,0x81e004c5,0xaad8012c,0x7d140205}},	//   vuku, দিব_, म्मक, _soys, 
   {{0x7bc40e6a,0x69c49ae3,0xfd480ce4,0xfce401c0}},	//   wuku, juje, изок_, ооно, 
   {{0x7bc5303a,0x7d15303b,0xcb0805d0,0x00000000}},	//   tuku, _qoys, _בל_, --, 
   {{0xdbf411b1,0x7bc5303c,0x69a401ad,0xaad800dc}},	//   इटेड_, uuku, टीसी, म्भक, 
   {{0x41dc08df,0x7bc5303d,0xa3a8d3a8,0x7d14011f}},	//   _महास, ruku, कीय_, _woys, 
   {{0x69c45ba2,0x7d15303e,0x6d45303f,0x38600165}},	//   guje, _toys, čkar, _sykr_, 
   {{0xaad8190c,0xee0401d5,0xab58002f,0x3934009d}},	//   म्बक, _феъл_, trüc, цэгс, 
   {{0x7bc40bf1,0xa3a81f13,0x2b8c0213,0x070400c5}},	// [1d840] quku, कीम_, _güc_, रांव_, 
   {{0x69c4389e,0x398c022c,0xab5803fa,0x00000000}},	//   buje, _týs_, rrüc, --, 
   {{0x7520066d,0xed4c208f,0xab580e78,0x9f4c0166}},	//   tkoz, _سپی_, srüc, _irgä_, 
   {{0xab5803fa,0x75200153,0xf3c81063,0xb46400cf}},	//   prüc, ukoz, لبته_, окел, 
   {{0x75213040,0x2e0c00ac,0xaadc033f,0x00000000}},	//   rkoz, rəfi_, _पॉडक, --, 
   {{0xcc9000b8,0x69a4012d,0x00000000,0x00000000}},	//   _hṛta_, टीवी, --, --, 
   {{0xcc9000dc,0x00000000,0x00000000,0x00000000}},	//   _kṛta_, --, --, --, 
   {{0x92bc015b,0x21600137,0x30a40063,0x00000000}},	//   েজে_, мтыг, цркв, --, 
   {{0x37c80183,0xceb805a2,0xcc90002b,0xd5880345}},	//   ৰিকৰ, бәй_, _mṛta_, _ئێڤه_, 
   {{0xa3dc09d9,0x85000131,0x69c4002e,0x8e38022e}},	//   _तहत_, _يۈەن, yuje, оrа_, 
   {{0x69c40306,0x8e7c0115,0xf3880055,0xc0d40023}},	//   xuje, reĝo, _kṣo_, ሪሆም_, 
   {{0x69c53041,0x213c0369,0x727002d3,0x71700137}},	//   vuje, ciuh_, _ብሕታዊ_, _تۇبا, 
   {{0xa11001d9,0xdfcd3042,0x27fc0327,0x69c4012d}},	//   _تونت, _لين_, _ġuno_, wuje, 
   {{0x69c00fac,0x407001e0,0x00000000,0x00000000}},	//   _ånek, _яғыу, --, --, 
   {{0xb5300ca8,0x00000000,0x00000000,0x00000000}},	//   _pẹ̀l, --, --, --, 
   {{0x2d9d3043,0x00000000,0x00000000,0x00000000}},	//   mpte_, --, --, --, 
   {{0x69c53044,0x2d9d3045,0x09d00eac,0xaad00892}},	// [1d850] suje, lpte_, াবধা, _तापक, 
   {{0x070407c1,0x2d9c0b4f,0xe6640798,0x24640118}},	//   राइव_, opte_, отео, _jímž_, 
   {{0xb5300241,0x25640254,0x00000000,0x00000000}},	//   _tẹ̀l, sõlm_, --, --, 
   {{0x1ce00327,0x7c3801e4,0x00000000,0x00000000}},	//   _ཤིབ_, ŝtre, --, --, 
   {{0x03a53046,0x26c4067c,0x00000000,0x00000000}},	//   чило, ònos_, --, --, 
   {{0xdee41540,0x88cc009e,0xf38800cd,0x24640118}},	//   ማትን_, _লসিক, _eṣo_, _nímž_, 
   {{0x56949ad7,0x7bd80311,0x2d9c01f5,0xa3a841d8}},	//   _цаст, ătui, jpte_, _कौर_, 
   {{0xc0bc1ee0,0x00000000,0x00000000,0x00000000}},	//   _ተድላ_, --, --, --, 
   {{0x4254c6db,0x2d9c69d0,0x00000000,0x00000000}},	//   _کنار, epte_, --, --, 
   {{0x389c0374,0x00000000,0x00000000,0x00000000}},	//   mārō_, --, --, --, 
   {{0xb8fc025c,0xacb8002d,0x1ce00327,0x91fc0055}},	//   _ལྡ_, rkûn, _ཤིད_, _hyān, 
   {{0x6e2c01ab,0x00000000,0x00000000,0x00000000}},	//   ùbba, --, --, --, 
   {{0x60d807a9,0x91fc0055,0x00000000,0x00000000}},	//   mfum, _jyān, --, --, 
   {{0x3b081c22,0x46dc00cd,0xab580037,0x3ea000a2}},	//   щего_, न्मह, nuüh, _ýht_, 
   {{0xa3a80490,0xee2c00ec,0x7f4006be,0x00000000}},	//   कीत_, _ٽٽي_, milq, --, 
   {{0xed540801,0x60d80083,0x6d5c00c7,0xab580213}},	//   _нощ_, nfum, _ëpap, rrüa, 
   {{0xa3a84fed,0xab5800c5,0x91fc002b,0xb86402cb}},	// [1d860] _कौल_, kuüh, _nyān, سارو, 
   {{0x290c007c,0x00000000,0x00000000,0x00000000}},	//   ögar_, --, --, --, 
   {{0xacb800d2,0x91fc00b8,0x80bc07f7,0x2364036e}},	//   phût, _ayān, ोलाइ, dlnj_, 
   {{0xbb5400b5,0x7f400381,0x32000419,0xb4e400bc}},	//   _usbケ_, hilq, _čky_, बजे_, 
   {{0x1ce00867,0x79840472,0xe3b40a4a,0x2bac01f9}},	//   _ཤིན_, _iikw, зліч_, जीपा, 
   {{0xf1a53047,0x798406e4,0x2d9d3048,0x1fc000bd}},	//   прин, _hikw, ypte_, ্বাস, 
   {{0x79853049,0x60d80cfe,0x7f40157f,0x35a400db}},	//   _kikw, ffum, dilq, _хабг, 
   {{0x798402e3,0x00000000,0x00000000,0x00000000}},	//   _jikw, --, --, --, 
   {{0x7985304a,0x441418d9,0x00000000,0x00000000}},	//   _mikw, _оффт, --, --, 
   {{0x7985304b,0x60d80083,0xd138033f,0x3e7c00e4}},	//   _likw, afum, _stąd_, kãtĩ_, 
   {{0x2bac45c7,0x308402c9,0x67280200,0x00000000}},	//   जीना, _فلاف, ëgji, --, 
   {{0x7984e3cb,0xab580730,0x2d9c0d47,0x0c7402d3}},	//   _nikw, grün, rpte_, _በንጻሩ_, 
   {{0x2d9c01f5,0x7f4003b9,0x00000000,0x00000000}},	//   spte_, bilq, --, --, 
   {{0x950c0003,0x7985304c,0x2d9d304d,0xacb8002d}},	//   _གོའི_, _aikw, ppte_, thûs, 
   {{0x79849390,0xda78241e,0x00000000,0x00000000}},	//   _bikw, зят_, --, --, 
   {{0x7985304e,0xc8c800db,0xf03c02d3,0x996401ec}},	//   _cikw, تورن_, _ክትሰም, етул, 
   {{0x7985304f,0x2d8c002f,0x298801f0,0xcb540114}},	// [1d870] _dikw, _hufe_, рсҳо_, _овић, 
   {{0x2d8c6df2,0x00000000,0x00000000,0x00000000}},	//   _kufe_, --, --, --, 
   {{0x4974004e,0x91fc00cd,0x25640254,0x00000000}},	//   _олос, _syān, lõli_, --, 
   {{0xe8e93050,0x333c0227,0x79849bc4,0x2d8d3051}},	//   _اردو_, _amtx_, _gikw, _mufe_, 
   {{0x29d53052,0x2d8d3053,0xc35402e8,0x78f8011a}},	//   lça_, _lufe_, мъкъ, _ופרו, 
   {{0xd6d8004e,0x2d8c0165,0x81e0015b,0x7f400009}},	//   _нтс_, _oufe_, দিস_, xilq, 
   {{0x29d53054,0xdce42808,0x2d8c03f9,0x79853055}},	//   nça_, _uhić, _nufe_, _yikw, 
   {{0x8504f4ef,0x79840c11,0x2128068f,0x84240131}},	//   _تورن, _xikw, óch_, _قىزن, 
   {{0xab593056,0x27fc0841,0x6fb0009f,0x7f400135}},	//   vrün, _šunj_, نميا, tilq, 
   {{0x29d504ff,0x9de40003,0xab580209,0x2d8c42bb}},	//   kça_, _འགྱེ, wrün, _bufe_, 
   {{0x60d93057,0xada0004e,0x21000064,0x14f000fe}},	//   pfum, каэл, _ačių_, ছাৰী_, 
   {{0xcfd8009e,0x7f400309,0x46dc0864,0xaad836c7}},	//   তিজন, silq, न्तह, म्सक, 
   {{0x79853058,0x29d40798,0x98a0003a,0xd12c00db}},	//   _rikw, eça_, chię_, _دۅي_, 
   {{0x2d8c0ba7,0x1ce00327,0x98a00010,0x91fc00de}},	//   _fufe_, _ཤིམ_, rkič_, _izār, 
   {{0x9de408ea,0x2d8c011f,0x79853059,0xfb842f89}},	//   _འགྲེ, _gufe_, _pikw, зыңн, 
   {{0xab58000d,0x2564000d,0x00000000,0x00000000}},	//   brüo, bõli_, --, --, 
   {{0x79851353,0x29d4d02b,0xec1000aa,0x107800d1}},	// [1d880] _vikw, aça_, _لويد, ﻧﯩﺪﯨ, 
   {{0x79840526,0x95b42123,0x9c6400db,0xd7640244}},	//   _wikw, ердә, _يۇگو, رنای, 
   {{0x7985305a,0x3ea000c5,0x3880013f,0x46dc00bc}},	//   _tikw, _õhtu_, sɔr_, न्धह, 
   {{0xe5a1305b,0x09d00154,0xf8b0012d,0xacb800e4}},	//   тици, াবশা, _ज़िय, ykûm, 
   {{0x8b6404fb,0xa3a80307,0x427402dd,0x00000000}},	//   _زایم, _कौआ_, _ﺸﺭﻭﻁ_, --, 
   {{0x7bc400cc,0xb284004e,0x00000000,0x00000000}},	//   irku, мыйк, --, --, 
   {{0x7bc4002f,0x75d41913,0x00000000,0x00000000}},	//   hrku, _تيزا, --, --, 
   {{0x2d8d305c,0x660004ce,0x799c02d0,0xcc9000dc}},	//   _rufe_, ænke, _mtpw, _nṛpa_, 
   {{0x69c00fac,0xceb818c7,0xa0640114,0xd41c00cc}},	//   _ånev, пәй_, маћа_, _দেৰি_, 
   {{0x2d8c00d8,0x8e140b3e,0x91fc0055,0x8e7c01e4}},	//   _pufe_, едоц, _hyām, leĝi, 
   {{0x7bc41ba6,0xdce40166,0xf48400d1,0x999400a2}},	//   erku, _atnı, _хуңн, _ýeňi_, 
   {{0xdce40327,0xe100004e,0x00000000,0x00000000}},	//   _punġ, _аяшп, --, --, 
   {{0xe8d80156,0x799c03ac,0x828000c7,0xab58002f}},	//   ྲུལག, _atpw, _иқәд, brül, 
   {{0x2d8d305d,0x29d5305e,0x81e0015b,0x00000000}},	//   _tufe_, tça_, দির_, --, 
   {{0x6f09305f,0x59f800a7,0x2d8c002e,0x29d4067c}},	//   _infc, меря_, _uufe_, uça_, 
   {{0x29d53060,0xd910267a,0x91fc0055,0x98c53061}},	//   rça_, لیپ_, _nyām, ксул, 
   {{0x6d4d3062,0x29d52af1,0x8e7c01e4,0x91fc002b}},	// [1d890] mnca, sça_, deĝi, _syāl, 
   {{0xa64403e6,0x29d53063,0xb8800077,0x799c03ac}},	//   وخان, pça_, ñían, _ftpw, 
   {{0x6d4c14dc,0x65a0013f,0x00000000,0x00000000}},	//   onca, rεho, --, --, 
   {{0x6d4c1db0,0x91fc002b,0x00000000,0x00000000}},	//   nnca, _vyāl, --, --, 
   {{0xb4b43306,0x29093064,0x6d4d3065,0x37c000ee}},	//   رُوا_, _inca_, inca, _бәхб, 
   {{0x4428038f,0x69c4002d,0xdbcc01e1,0x91fc0055}},	//   ġa_, orje, _kóòg, _iyāj, 
   {{0x44293066,0xd5b8c8cb,0x91fc0055,0x6728036e}},	//   ša_, _ост_, _hyāj, ëgju, 
   {{0x6d4c0407,0x7bc401a8,0x69c400ad,0xdbcc0248}},	//   ébal, yrku, irje, _móòg, 
   {{0x2908014b,0x7ed43cd9,0xff24084c,0xdbcc01e1}},	//   _mnca_, ىزدا, емпо, _lóòg, 
   {{0x6d4c7384,0x63b93067,0x6568e04a,0x5454026b}},	//   enca, _ivun, llgh, _рвут, 
   {{0x69c40841,0x29093068,0x63b802d2,0x8e7400d3}},	//   jrje, _onca_, _hvun, куюч, 
   {{0x6d4c0857,0x403400d8,0x00000000,0x00000000}},	//   gnca, _пеес, --, --, 
   {{0xab582e11,0x3f9c004c,0x69c44580,0x65680afe}},	//   prül, _utwu_, erje, ilgh, 
   {{0x6d4d3069,0x63b9306a,0x290819b2,0x7bc5306b}},	//   anca, _mvun, _anca_, rrku, 
   {{0x91fc00b8,0x2aa401d5,0x69c41710,0x00000000}},	//   _ayāj, _dеb_, grje, --, 
   {{0x6a800323,0x63b9306c,0x3cd401a9,0x46dc66c0}},	//   улса, _ovun, _чўкт, न्सह, 
   {{0x69c5306d,0x63b804ba,0x77c801c0,0xdce40139}},	// [1d8a0] arje, _nvun, ялаг_, _utnı, 
   {{0x656802c4,0x69c40327,0x91fc002b,0x00000000}},	//   elgh, brje, _syām, --, 
   {{0x02c9306e,0x212c01ab,0xa92000d7,0x00000000}},	//   _राजभ, _olgh_, šľav, --, 
   {{0x63b80433,0x7aec0e78,0x00000000,0x00000000}},	//   _bvun, lebt, --, --, 
   {{0x178529c3,0x78b4014b,0x83fc01ed,0x8e7c00df}},	//   _аҳам, mayv, _szőr, reĝi, 
   {{0x64a00184,0x656801e7,0x78b401a9,0x00000000}},	//   _ҡаса, algh, layv, --, 
   {{0x3f99306f,0x6d4c3602,0x66e000d4,0x6300007b}},	//   ísun_, ynca, _щора, طويل, 
   {{0x741410fe,0x31b800da,0x91fc00b8,0x15b801ee}},	//   _كوزا, rīz_, _hyāk, _нығы_, 
   {{0x69c48185,0x6d4c01d4,0x73c48ee7,0x00000000}},	//   zrje, vnca, _سيام, --, 
   {{0x69c53070,0xab580112,0x4d980212,0x6d4d3071}},	//   yrje, trüm, мкою_, wnca, 
   {{0x7aec127b,0x5f7078e3,0xb03000d1,0x78b40174}},	//   debt, داير, _әмлә, kayv, 
   {{0x6d4c1570,0x69c41e31,0x42547da1,0x59f40327}},	//   unca, vrje, _ртут, _བནྟེ_, 
   {{0x6d4c9442,0xec680816,0x25640037,0x69c46f19}},	//   rnca, ярок_, põlv_, wrje, 
   {{0x69c4151c,0xab59069b,0x7aeca4e6,0x20700064}},	//   trje, mrük, gebt, _сліў, 
   {{0xdb0439b3,0x2aa4022e,0x69c53072,0x91fc00b8}},	//   _avió, _vеb_, urje, _syāj, 
   {{0x7bd800a8,0x69c4044e,0x91fc0055,0xb88000d7}},	//   ătur, rrje, _ayāk, _číro, 
   {{0x91fc00b8,0x7c240076,0xc7d837fb,0xa2c000cd}},	// [1d8b0] _byāk, cykr, ьмах_, रणम्, 
   {{0x69c4003d,0x61440066,0x7aec058a,0xacb00c75}},	//   prje, _kèlè, cebt, _جەڭب, 
   {{0x63b85cf2,0x09c40150,0x316401d3,0xe6d402d2}},	//   _svun, _جۇزۋ_, _okoz_, _átíð, 
   {{0xa5653073,0xb904009e,0xa8a408ca,0x91fc002b}},	//   ردان, _যো_, _ярок, _tyāj, 
   {{0x27fc1709,0x61440066,0x212c00a3,0xa3a89387}},	//   _éun_, _lèlè, _rlgh_, कीं_, 
   {{0x31643459,0x61240a43,0xdbcc01a8,0x00000000}},	//   _akoz_, _iñli, _móðg, --, 
   {{0x95c8026a,0x1a9c00c8,0x7c240034,0xe4e400d4}},	//   _пута_, ליגע, zykr, _піан, 
   {{0x63b87c1d,0xa7f802d1,0xe77400c7,0x80bc03ce}},	//   _tvun, _ayñi, _цаҳә_, ोलें, 
   {{0x63b93074,0x439406bb,0xb2701b15,0x82d8004e}},	//   _uvun, _разс, лләш, _одас_, 
   {{0xe42005d9,0xdce401e4,0x26d00472,0x7c241155}},	//   _لکڻي, _munĥ, ngxo_, vykr, 
   {{0x61440066,0xab580254,0xa0800150,0x00000000}},	//   _cèlè, mrüh, _өңке, --, 
   {{0x61440066,0x7aec6144,0x7c2401e3,0xab580254}},	//   _dèlè, webt, tykr, lrüh, 
   {{0x78b420d2,0x00000000,0x00000000,0x00000000}},	//   vayv, --, --, --, 
   {{0x8b1812c4,0x7c380115,0xab580112,0xab600395}},	//   нюст_, ŝtro, nrüh, ивял, 
   {{0xf2d0008f,0xaad0a06f,0x61440241,0x78a00077}},	//   יעם_, _तारक, _gèlè, ñovo, 
   {{0xada03461,0x7aec01af,0x91fc0055,0x00000000}},	//   _таъл, sebt, _syāk, --, 
   {{0xa9653075,0xfaa400c7,0xdbcc0321,0x3ff8010f}},	// [1d8c0] тита_, _иапо, _góðg, ופּע, 
   {{0xba24035b,0xdb080241,0x87f8009d,0x00000000}},	//   _адок, _àlàm, ээст_, --, 
   {{0x91fc0882,0x14c80214,0x6720005b,0xc92000fe}},	//   _vyāk, فهای_, önja, _নগৰত_, 
   {{0xb444084c,0x2bac1546,0x00000000,0x00000000}},	//   кэлк, जीवा, --, --, 
   {{0xd3707165,0x39502ee4,0xab580112,0x35a40022}},	//   مۇر_, mnys_, früh, хаҵг, 
   {{0x31653076,0x41880150,0x779000f1,0x39513077}},	//   _skoz_, _ﺗﺎﺭﺱ_, _میړا, lnys_, 
   {{0x6d4c003e,0x395020da,0x00000000,0x00000000}},	//   ébak, onys_, --, --, 
   {{0x3950b49a,0x50f41de1,0xab593078,0xf8b0000d}},	//   nnys_, узит, trük, जरिय, 
   {{0x0554e90e,0x33b00075,0x61440066,0x60f402d5}},	//   _стря, _ئەتر, _sèlè, тныя_, 
   {{0xaf042c0b,0xf3880055,0x39500363,0x614401e1}},	//   тчик, _aṣv_, hnys_, _pèlè, 
   {{0x39500153,0x2d801525,0x91c41de6,0x00000000}},	//   knys_, ňkem_, _сәлл, --, 
   {{0x5d64170a,0xc4080014,0x00000000,0x00000000}},	//   итяз, _تتہٕ_, --, --, 
   {{0xceb806ba,0xdb05069d,0xab580254,0xdc680023}},	//   _пән_, _aviñ, duür, _ሻድሻይ_, 
   {{0x61440066,0xf38800b8,0x395000ad,0x91fc002b}},	//   _tèlè, _eṣv_, enys_, _pyāh, 
   {{0xa92001f1,0x4c940354,0xa2c0043e,0x00000000}},	//   áľov, _йийс, रणत्, --, 
   {{0xf3880ca8,0x39500076,0xe7c800d1,0x91fc00dc}},	//   _iṣu_, gnys_, _ﺗﻪﺭﺟ, _vyāh, 
   {{0x193c01f3,0xdca41d39,0xa9200419,0x00000000}},	// [1d8d0] _አእምሮ, _тањи, šľov, --, 
   {{0x30e00882,0x395000ad,0x00000000,0x00000000}},	//   क्तः_, anys_, --, --, 
   {{0x2bac0490,0x8e7c00e4,0x39500064,0xceb800c0}},	//   जीरा, peĝu, bnys_, lkęs_, 
   {{0xdb0402d2,0xaad007f7,0xa3d001b9,0x00000000}},	//   _hvið, _ताँक, لحتچ, --, 
   {{0xceb80024,0xdb0401a8,0xab580254,0x00000000}},	//   nkęs_, _kvið, trüh, --, 
   {{0x3f980436,0xf3880cad,0xceb800c0,0x00000000}},	//   ísum_, _oṣu_, ikęs_, --, 
   {{0x26c0020c,0xab580e78,0x00000000,0x00000000}},	//   _idjo_, rrüh, --, --, 
   {{0xab580037,0x417400db,0x00000000,0x00000000}},	//   srüh, داتس, --, --, 
   {{0x65793079,0x443878d0,0xab580112,0xa2d808df}},	//   _ihuh, _ås_, prüh, _नाप्, 
   {{0x39500118,0x00000000,0x00000000,0x00000000}},	//   znys_, --, --, --, 
   {{0x6578014b,0x249d307a,0x39501368,0xbd840395}},	//   _khuh, _kfum_, ynys_, лгок, 
   {{0xd1c805f5,0x29180309,0x3cec012d,0xd10802da}},	//   _шууд_, jjqa_, ज़ें_, _لقمه_, 
   {{0x5185307b,0x26c00066,0x81b4015b,0xf389307c}},	//   _туфа, _odjo_, _জমি_, _eṣu_, 
   {{0x39501368,0x00000000,0x00000000,0x00000000}},	//   wnys_, --, --, --, 
   {{0x6578013f,0xa2d80882,0x5f4001d3,0x39500363}},	//   _ohuh, _नान्, _مچھل, tnys_, 
   {{0xe8f40139,0x395000ad,0x8e54074d,0x65780051}},	//   ллс_, unys_, _тĕсл, _nhuh, 
   {{0xc8b5307d,0x27e80198,0x39500072,0xd744035b}},	// [1d8e0] рссы, _cpcn_, rnys_, адаҩ, 
   {{0x249c013f,0x6579307e,0x39500363,0x7674007b}},	//   _afum_, _ahuh, snys_, هداء, 
   {{0x64580077,0x91fc0055,0x864400c7,0xab580254}},	//   _axui, _hyāv, аҟра_, puür, 
   {{0x6579307f,0x7afd3080,0x00000000,0x00000000}},	//   _chuh, _hapt, --, --, 
   {{0x7afd3081,0x65782ebc,0xb2f80327,0xa30800e5}},	//   _kapt, _dhuh, _ྒྲུང_, کرنے_, 
   {{0xf7440775,0x6578014b,0x6d5c0022,0x7afd3082}},	//   _сего, _ehuh, _êpav, _japt, 
   {{0x7afc0589,0x64580381,0x923c0023,0xab58000d}},	//   _mapt, _exui, _ክንመሃ, ssüg, 
   {{0xd0113083,0x7afd3084,0x6578047e,0x21640063}},	//   قلب_, _lapt, _ghuh, лији_, 
   {{0x628401ed,0x8eb40131,0xb4c00e5b,0x91fc0055}},	//   _újon, لەشت, ूली_, _nyāv, 
   {{0x7afd3085,0x657872ac,0x2bd807f7,0xc4500244}},	//   _napt, _zhuh, _बमबा, _بێهب, 
   {{0x229006d5,0xab5801b8,0x30e4109a,0x29180076}},	//   _المس, nsüe, _білб, yjqa_, 
   {{0xdb04008c,0x8c181b45,0xa3a80406,0x6e38002f}},	//   _svið, نيجر_, कीक_, rztb, 
   {{0x7afd3086,0xa2d811bc,0x91fc00b8,0x6e3801d3}},	//   _bapt, _नाम्, _cyāv, sztb, 
   {{0x7afc5f7a,0xacb8002d,0x91fc00cd,0xab580790}},	//   _capt, nhûz, _dyāv, ksüe, 
   {{0x7afc3386,0x26c40030,0x00000000,0x00000000}},	//   _dapt, ónom_, --, --, 
   {{0xa2d800cd,0x00000000,0x00000000,0x00000000}},	//   _नाभ्, --, --, --, 
   {{0x7afc00a8,0x48153087,0x290c00fd,0xacb8002d}},	// [1d8f0] _fapt, шмас, ıga_, khûz, 
   {{0xd87804a9,0x65793088,0x7afd3089,0x27fc0024}},	//   ھمەت_, _shuh, _gapt, _šuns_, 
   {{0x6578000a,0x76a8025a,0x2c7801e1,0x317000ee}},	//   _phuh, _sêyâ, _fàdí_, ňyzy_, 
   {{0x1e28001f,0x7afd308a,0x27e80051,0x00000000}},	//   ሥልጣና, _zapt, _tpcn_, --, 
   {{0x7afc0ab7,0x65780084,0x0ed410eb,0xab58002f}},	//   _yapt, _vhuh, _दांड, msüb, 
   {{0x6578020c,0x26c05513,0xb9dc001f,0x28c03af4}},	//   _whuh, _udjo_, _እቃ_, षणवि, 
   {{0x6578044e,0xe3b06ea9,0xe4a41d39,0x6ab406be}},	//   _thuh, _گرز_, _брзо, _mexf, 
   {{0xbfc40304,0x249c003a,0xab580112,0xf0a40395}},	//   абик, _ufum_, nsüb, акъл_, 
   {{0xa301308b,0xe3b1308c,0xab580112,0x00000000}},	//   _гүле, _درز_, isüb, --, 
   {{0x6ab40327,0x69c800e2,0xeff00023,0x2fd400f2}},	//   _nexf, _āgen, ሂብዎ_, گوید_, 
   {{0xd24400a8,0x7afc0d63,0x1ee412ea,0x91fc0055}},	//   _лэци, _rapt, نوکی_, _syāv, 
   {{0x7afd308d,0x7ff5308e,0x236402e2,0xa2d8090a}},	//   _sapt, _نستا, lonj_, _नाड्, 
   {{0x98a00558,0x81e002f5,0x7afc01bf,0x1ee40330}},	//   lkić_, দিও_, _papt, _موشی_, 
   {{0x7afc014f,0xde440014,0xbea5308f,0x91fc00dc}},	//   _qapt, _میخو_, _такк, _vyāv, 
   {{0x98a106ae,0x5dc001ec,0xa9180055,0x7afc0055}},	//   nkić_, _امبە, _niþs, _vapt, 
   {{0x7afd3090,0x6e2c2c95,0xab580e78,0xf4240432}},	//   _wapt, øbbe, gsüb, _çägi_, 
   {{0x6ab40327,0x91fc002b,0x23640175,0xd9b40137}},	// [1d900] _fexf, _hyāt, konj_, _گەزد, 
   {{0xdb0407c5,0x23640369,0xdb24ea2e,0xe80408ca}},	//   _aviö, jonj_, _چوکی, шнуд_, 
   {{0xdb249b17,0x2cb0006a,0x98a00384,0x91fc0055}},	//   _نوکی, _ândö_, jkić_, _jyāt, 
   {{0xb4c0038e,0xa50402e8,0x787800db,0x00000000}},	//   ूले_, иеха_, _үйүр_, --, 
   {{0x33f53091,0xacb8045f,0xa8000024,0x00000000}},	//   рчес, sjûg, _дзял, --, 
   {{0x31c49cfe,0x925805f5,0x26c800f2,0x845800c7}},	//   асив, лалт_, _لطفی_, ырхт_, 
   {{0xacb8002d,0xe2941f5a,0x23240063,0xab580205}},	//   rhûz, шај_, роји_, mrüt, 
   {{0x7534009d,0x00000000,0x00000000,0x00000000}},	//   _тэгх, --, --, --, 
   {{0x91fc00b8,0x30e000dc,0xab58002f,0x46dc00bc}},	//   _ayāt, क्षः_, nsüc, न्कह, 
   {{0x32444427,0x43753092,0x00000000,0x00000000}},	//   _кезг, _лухт, --, --, 
   {{0xa2d828e1,0x8fd40724,0x6fc0012d,0xe29401c4}},	//   _नात्, рәҗә, _शिकं, _тах_, 
   {{0xafe40064,0x00000000,0x00000000,0x00000000}},	//   _водл, --, --, --, 
   {{0x2128002f,0x1dc0004e,0x21640798,0x26c400e5}},	//   öche_, бөөн, _тици_, ónok_, 
   {{0xa3a80490,0xe2a0004d,0xab58002f,0x00000000}},	//   कीट_, _ngữ_, wsüb, --, 
   {{0xab580112,0x88e400fe,0x00000000,0x00000000}},	//   tsüb, _পোষক, --, --, 
   {{0x23640369,0xe6ac02ab,0x91fc00b8,0x6ab51107}},	//   zonj_, टर्ज, _hyās, _wexf, 
   {{0xdb04652a,0x6d4c0129,0xbd5400f1,0x28680063}},	// [1d910] _aviõ, ébau, _دروژ, трво_, 
   {{0x9b4400aa,0xab58002f,0x8af84627,0x00000000}},	//   _ونيو, ssüb, _снос_, --, 
   {{0x049400c6,0x96f80117,0x668007d6,0x00000000}},	//   ملاح, рехт_, زیرل, --, 
   {{0x98a04bc9,0xe7a46911,0xe4c93093,0x0cc405c0}},	//   vkić_, _نۇرى_, ئبان_, _वयोम, 
   {{0x236401fa,0xe29402dd,0xab58002f,0x82a53094}},	//   tonj_, қақ_, brüt, балж, 
   {{0x91fc00dc,0xf7cc02dd,0x00000000,0x00000000}},	//   _nyās, _ﺗﻪﻣﻪ, --, --, 
   {{0xdb040036,0x23640783,0x637c00c7,0xa3a80401}},	//   _stië, ronj_, hêng, कीज_, 
   {{0x98a007f5,0x91fc00b8,0xb9dc0023,0x7c3801e4}},	//   rkić_, _ayās, _እዃ_, ŝtri, 
   {{0x98a00e3c,0xab58002f,0x91fc00dc,0x23640200}},	//   skić_, nrüs, _syāt, ponj_, 
   {{0x63a80ffb,0x91fc00b8,0xa2640354,0x00000000}},	//   mpgn, _pyāt, _къел, --, 
   {{0xdce400b0,0x5fd007f7,0xcf24009f,0x2ad80118}},	//   _akiā, _दमकल, تريي, ख्छु_, 
   {{0x409400c6,0xee344a2d,0x51853095,0xdbc80c60}},	//   _الإر, сню_, _дуча, аҳид_, 
   {{0xdbf428d4,0xa3a80073,0x101406c2,0x00000000}},	//   ेटेड_, कीच_, _وبهد, --, 
   {{0xeb943e6b,0xab580e78,0x00000000,0x00000000}},	//   сир_, drüs, --, --, 
   {{0x6d9c02b1,0x499802bf,0x91fc0055,0x3f840327}},	//   _hīan, иття_, _hyār, mmlu_, 
   {{0x637c006a,0x6d9c0374,0xab580e78,0x6d4c020c}},	//   lênd, _kīan, früs, ébat, 
   {{0x36c53096,0x2ca400fd,0xab580112,0x00000000}},	// [1d920] йбаг, _укып_, grüs, --, 
   {{0xf77000c6,0xab581196,0xaf340092,0x66e0014b}},	//   ساء_, rsüc, _ስለሚፈ, зофа, 
   {{0xab580065,0xc76400d1,0x00000000,0x00000000}},	//   rrüt, زاكى, --, --, 
   {{0xd91042c5,0xab58002f,0x3f84031c,0x00000000}},	//   _تیر_, brüs, hmlu_, --, 
   {{0x91fc0055,0x93480022,0xb224009d,0x87b8003b}},	//   _nyār, аҟаз_, өмдл, _вуст_, 
   {{0xb66800f3,0x00000000,0x00000000,0x00000000}},	//   _бигз_, --, --, --, 
   {{0x637c006a,0x24500372,0x8d700092,0x00000000}},	//   zêng, ينۅس, ጠብቀው_, --, 
   {{0xc4c4007b,0x91fc00b8,0x00000000,0x00000000}},	//   _وتقو, _syās, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc3240150,0x61e00334,0x637c00e4,0x00000000}},	//   _وعلى, btnl, vêng, --, 
   {{0x7204006c,0x91fc00dc,0x00000000,0x00000000}},	//   _دوام, _vyās, --, --, 
   {{0xab580205,0x00000000,0x00000000,0x00000000}},	//   yrüs, --, --, --, 
   {{0xcc90002b,0xc0e00023,0x00000000,0x00000000}},	//   _mṛga_, ሓኦም_, --, --, 
   {{0x637d3097,0x7c640131,0x9fc40114,0x00000000}},	//   rêng, تاپل, _угља_, --, 
   {{0xa2d80882,0xdeb000d0,0x6d4c00f2,0xda340006}},	//   _नास्, äčša_, ébas, перы, 
   {{0x637c006a,0x497402d5,0x09740212,0xab58002f}},	//   pêng, ілас, ігаю, trüs, 
   {{0x29040316,0x6d4c1864,0xad2401b9,0x00000000}},	// [1d930] ěna_, mica, _نرکو, --, 
   {{0x29042144,0xe9400133,0xab58002f,0x207800df}},	//   śna_, _کۆرپ, rrüs, ראמא, 
   {{0xa3d80574,0xbab805f5,0xab593098,0x88953099}},	//   ढून_, _өгөх_, srüs, _минх, 
   {{0xab5851bb,0x613c01e1,0x272c4682,0xfd240241}},	//   prüs, _màlù, _sını_, _àìta_, 
   {{0x048800d1,0x00000000,0x00000000,0x00000000}},	//   рәви_, --, --, --, 
   {{0x6d9c02b1,0x00000000,0x00000000,0x00000000}},	//   _rīan, --, --, --, 
   {{0xe8fc006a,0x7ae82155,0xe570297d,0x91fc00b8}},	//   _akûi_, _öfte, _فطر_, _syār, 
   {{0x67240a4d,0x00000000,0x00000000,0x00000000}},	//   _hojj, --, --, --, 
   {{0x200803c6,0x67241418,0x3f98004d,0x6569309a}},	//   íci_, _kojj, êsu_, mogh, 
   {{0x6569309b,0x613c0241,0xfde80f32,0x2a700208}},	//   logh, _bàlù, адок_, _oyxb_, 
   {{0x42543584,0x637c0120,0x6724014f,0x83fc01ed}},	//   _بنار, gêne, _mojj, _győr, 
   {{0x637c145e,0x6d4cbb99,0x6d9c00b0,0x50b8a2f2}},	//   sênd, gica, _tīan, _هدهد_, 
   {{0x91fc0055,0x4c35309c,0x25d80401,0xb2b403b9}},	//   _hyāp, пэрт, खंडी_, _şüər, 
   {{0x3b0809fe,0x3ea000c5,0x60d9309d,0x6569309e}},	//   шего_, _üht_, lgum, hogh, 
   {{0x6569309f,0xa9a001b9,0xedd0027d,0x6d54041e}},	//   kogh, дисд, _قيود, ðgað, 
   {{0x6d5c00c7,0xed5402e8,0xf8a8068e,0xbc3801c8}},	//   _êpap, _мощ_, рвак_, _نسخا_, 
   {{0x6724c00c,0x656930a0,0xab5930a1,0x7d1403ac}},	// [1d940] _bojj, dogh, rrür, _inys, 
   {{0xb63452c8,0x36340046,0x250801b9,0x60d804cc}},	//   يعات, يراس, یرنی_, hgum, 
   {{0x7d151280,0x60d805b1,0x656930a2,0x6724007c}},	//   _knys, kgum, fogh, _dojj, 
   {{0x6568026c,0x4aa824b2,0x93c80014,0xab5930a3}},	//   gogh, _پایپ_, ماتہ_, nsün, 
   {{0x91fc00b8,0xa2d930a4,0x60d8007c,0x00000000}},	//   _ayāp, _नाश्, dgum, --, 
   {{0xf1a4b283,0x6d4d30a5,0x60d800da,0x6724022f}},	//   орин, zica, egum, _gojj, 
   {{0x6d4d30a6,0xa2d930a7,0x94180213,0x656930a8}},	//   yica, _नार्, _ərə_, bogh, 
   {{0x94c8021a,0x60d930a9,0x26c401f1,0x65680268}},	//   _داسې_, ggum, ónov_, cogh, 
   {{0xab5875ee,0xb38c01af,0x00000000,0x00000000}},	//   dsün, _алаh, --, --, 
   {{0x6d4d30aa,0x7d1530ab,0x47b80135,0x60d930ac}},	//   wica, _anys, _བསྣམ, agum, 
   {{0xa778008f,0xd1b81e2f,0xf8c84f4b,0xa2d01063}},	//   שריפ, _چاچا_, िणाय, _زينت, 
   {{0x75200109,0x60d800a3,0x66000162,0x00000000}},	//   njoz, cgum, ænki, --, 
   {{0xe1304077,0x00000000,0x00000000,0x00000000}},	//   _іншы, --, --, --, 
   {{0x637d30ad,0x75200268,0x78a408a5,0x613c01e1}},	//   mênc, hjoz, _afkv, _tàlù, 
   {{0x65680521,0x637c0261,0x6d4d30ae,0x7d147fff}},	//   yogh, lênc, pica, _fnys, 
   {{0x7d14000f,0x6d4c8bd2,0x6724031c,0x00000000}},	//   _gnys, qica, _sojj, --, 
   {{0x637c06ed,0x6d5c014f,0x7520007f,0x65680076}},	// [1d950] nênc, _ijqa, djoz, vogh, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7d140368,0x6568e941,0x6724007c,0x75200200}},	//   _ynys, togh, _vojj, fjoz, 
   {{0x2fc41326,0x67240ba7,0x7520bd71,0x89640014}},	//   _ovog_, _wojj, gjoz, _ژُھن, 
   {{0x65681368,0x67240337,0x91fc002b,0x00000000}},	//   rogh, _tojj, _syāp, --, 
   {{0x637c03b7,0xd6d90503,0x65680ffb,0x91fc0055}},	//   dênc, _мтс_, sogh, _pyāp, 
   {{0xdb140724,0x656819f5,0x60d8000f,0xb78401ee}},	//   şaça, pogh, tgum, _хәте_, 
   {{0x91fc0882,0xda5c0375,0x60d930af,0x7d040175}},	//   _vyāp, יכול, ugum, xdks, 
   {{0x637c0261,0x6ad004c5,0xa0a000d1,0xd14802da}},	//   gênc, দ্যো, пақд, تشون_, 
   {{0xfe4530b0,0x7d14017a,0x60d8343a,0xece4009d}},	//   зноо, _snys, sgum, үдэл_, 
   {{0xab5800dd,0xb19400d1,0xbe687d60,0xeb9c03b2}},	//   tsün, _елхә, санж_, svøl_, 
   {{0xa3dc05f9,0x00000000,0x00000000,0x00000000}},	//   _थमा_, --, --, --, 
   {{0x637c0120,0xab5930b1,0x31780a1e,0x60c802d0}},	//   cênc, rsün, _פאנד, _idgm, 
   {{0x68ed30b2,0x200d30b3,0xab5888c6,0x00000000}},	//   _abcd, _irgi_, ssün, --, 
   {{0x68ec0067,0x3f9c0254,0xfaa40b01,0x00000000}},	//   _bbcd, _huwu_, жаҳо, --, 
   {{0x3f9c0438,0xacb8002d,0x00000000,0x00000000}},	//   _kuwu_, ljûn, --, --, 
   {{0x66180227,0xeaac00dd,0xed54011a,0x6d38011a}},	// [1d960] _ąuka, ئٹہ_, _מבקר_, _לתקנ, 
   {{0x68ed30b4,0x213c0108,0xac800166,0xf748009a}},	//   _ebcd, hhuh_, _ягыл, حجره_, 
   {{0x8b6530b5,0x7bc530b6,0x213c03a2,0x60c801fa}},	//   _تايم, lsku, khuh_, _odgm, 
   {{0xd37004a9,0x7bc40cb4,0x200c0009,0x2bd0547d}},	//   چۇر_, osku, _orgi_, _तिमा, 
   {{0x7bc40aab,0xe8e4025c,0xd3709498,0x213c00f2}},	//   nsku, _སྡིག, نۇر_, dhuh_, 
   {{0xa7f80054,0x799d30b7,0x637c06ed,0x273c0276}},	//   _uxña, _kupw, vênc, _cînd_, 
   {{0x2fc41326,0x200d30b8,0x799c016d,0x6aa00b21}},	//   _svog_, _argi_, _jupw, _ûnfe, 
   {{0xd1300597,0x637c0261,0x3f9c02c4,0xb0c4084a}},	//   ئمة_, tênc, _buwu_, रृंग, 
   {{0x656130b9,0x799c016d,0x00000000,0x00000000}},	//   énhe, _lupw, --, --, 
   {{0x637c0cfc,0x7bc421e3,0x2fc4002d,0xa2e017a0}},	//   rênc, dsku, _vvog_, _поуд, 
   {{0x637c0261,0x200c0ba7,0x7bc401f1,0xbfa401fb}},	//   sênc, _ergi_, esku, _hiệ, 
   {{0x2fc40b91,0x213d30ba,0x7b0c1682,0x06d402f5}},	//   _tvog_, chuh_, ṱulo, স্পি, 
   {{0x7bc530bb,0x6d9c00b0,0xdfcd30bc,0xb374001f}},	//   gsku, _kīak, _مين_, ርገውን_, 
   {{0xab5801ed,0xbfa40208,0xe04001d5,0x00000000}},	//   csül, _miệ, _янчи, --, 
   {{0xde5400d6,0x2e4000e8,0xbfa4004d,0x98a00115}},	//   _наші_, _défé_, _liệ, skiĝ_, 
   {{0x3f9c03f9,0x799c014f,0xdff008e9,0x28680261}},	//   _yuwu_, _dupw, _अहमद_, брзо_, 
   {{0x2e4001e1,0x06d400cc,0xbfa40208,0x8c880139}},	// [1d970] _féfé_, স্ফি, _niệ, _фәна_, 
   {{0x31e0045e,0x00000000,0x00000000,0x00000000}},	//   _মননশ, --, --, --, 
   {{0x46140133,0xdbe4180f,0xfd540055,0xab5807c5}},	//   بوار, _pèça, _anaṇ, nsüm, 
   {{0x69c4df4f,0xbfa4004d,0x5bc401d5,0x290400e2}},	//   msje, _biệ, _تقیل, ēnas_, 
   {{0xd4080137,0x69c4383d,0x38700022,0x00000000}},	//   كتوم_, lsje, _ақтт, --, 
   {{0x69c530bd,0x6b94025c,0x86c404fb,0xbfa4004d}},	//   osje, _jixg, _زيرن, _diệ, 
   {{0x69c530be,0x213c138f,0x6b940135,0x78a000d0}},	//   nsje, thuh_, _mixg, žove, 
   {{0x7bc530bf,0x69c40d27,0xc8dc09bb,0x00000000}},	//   ysku, isje, यलिट, --, 
   {{0xdb0400a2,0xab580205,0x00000000,0x00000000}},	//   _awiý, tsül, --, --, 
   {{0x69c40385,0x7bc4b4b5,0x63b930c0,0xff24003b}},	//   ksje, vsku, _iwun, ємно, 
   {{0x213c03a2,0x63b80099,0x3f9d30c1,0xacb8000f}},	//   phuh_, _hwun, _wuwu_, rjûn, 
   {{0x69c530c2,0x63b81419,0x799c014f,0x200c0219}},	//   dsje, _kwun, _rupw, _trgi_, 
   {{0x4a5c001f,0x3d1c032c,0x63b8003e,0x7bc530c3}},	//   ተዋፅኦ_, _बचीं_, _jwun, usku, 
   {{0x63b8015c,0x799c0280,0xdce405a1,0xd00400d1}},	//   _mwun, _pupw, _okić, _чошқ, 
   {{0x799c047e,0x69c4143a,0xcf2516af,0x6b94007c}},	//   _qupw, gsje, _سروي, _dixg, 
   {{0x63b930c4,0xac6c01f2,0x6e2c0036,0x00000000}},	//   _owun, ụnụb, äbbe, --, 
   {{0x69c40a85,0xb8f4038e,0x63b80521,0x7c642310}},	// [1d980] asje, _सय_, _nwun, _تاغل, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x63b930c5,0x66e00408,0x98a00010,0x6a8530c6}},	//   _awun, тоха, ljič_, réfé, 
   {{0x63b80526,0xd9101291,0x00000000,0x00000000}},	//   _bwun, _حیر_, --, --, 
   {{0x2508107f,0x98a00219,0x78b40022,0x8cb0012d}},	//   ترلی_, njič_, mbyv, ूरतो, 
   {{0xbfa4001e,0x78b437c5,0x63b8012d,0x1664030d}},	//   _việ, lbyv, _dwun, _пĕлӳ, 
   {{0x63b930c7,0x66012381,0x3cf002f0,0x66e130c8}},	//   _ewun, ænkt, _obyv_, _шора, 
   {{0xab5800ac,0xbfa4004d,0x418401e0,0x3ea80139}},	//   vsüm, _tiệ, нтығ, _ğata_, 
   {{0x6d9c00b0,0x63b80254,0x69c530c9,0x00000000}},	//   _tīak, _gwun, zsje, --, 
   {{0x69c40b21,0x638000c7,0x7f400327,0x65bc002b}},	//   ysje, _агуа, ghlq, _ṭhit, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x71700eff,0x00000000,0x00000000,0x00000000}},	//   _جۇبا, --, --, --, 
   {{0xa110036b,0x6b940175,0x78b401bf,0x37dc00cc}},	//   _جونت, _pixg, dbyv, _নৈসৰ, 
   {{0x69c40225,0x3b180798,0x47ac00cc,0xab5800a2}},	//   tsje, _cnpq_, _চিলী, msük, 
   {{0xda784945,0x9e0130ca,0x69c401f5,0x00000000}},	//   дят_, _ачыл, usje, --, 
   {{0x69c530cb,0x78b40ea0,0x00000000,0x00000000}},	//   rsje, gbyv, --, --, 
   {{0x69c48b5d,0x6b9530cc,0x19580032,0x00000000}},	// [1d990] ssje, _tixg, фаты_, --, 
   {{0x63b88a22,0x69c468a1,0x8b840c75,0x00000000}},	//   _rwun, psje, _سەزە_, --, 
   {{0x63b847b4,0xa2ac1a3e,0x95c800d4,0x69c40200}},	//   _swun, ुरस्, дуча_, qsje, 
   {{0xdd9c010b,0x78a000d7,0x00000000,0x00000000}},	//   _öňem_, ľovc, --, --, 
   {{0x27fc0801,0x97a42b17,0x98040139,0x43747fec}},	//   _èun_, _арсл, _иярд, нукт, 
   {{0x6d9c02b5,0xc2c400c6,0x6600005c,0x679010e8}},	//   _tīah, ريبي, ænks, _شیاط, 
   {{0x5694035b,0xa5e40150,0xd9380092,0x65e000c7}},	//   _аарт, _توزە_, _የለብን, _шәаҧ, 
   {{0x63b930cd,0xe0544550,0x3d1c09bb,0x00c8e9b3}},	//   _twun, ویات_, _बचें_, члик_, 
   {{0x63b80eb4,0xe73c00e4,0xb270891e,0x53e400c7}},	//   _uwun, _atõi_, кләш, _ацха, 
   {{0xdd0405d1,0x708000fd,0x7e24030d,0x00000000}},	//   _ısın, ыгыз, едож, --, 
   {{0x7ed453d7,0xc1d001d2,0xfce46e1f,0xf77000d9}},	//   وزگا, _сөлә, ноно, רקי_, 
   {{0xc0e8034c,0x98a00219,0x00000000,0x00000000}},	//   _رفتن_, tjič_, --, --, 
   {{0x78b402f0,0x3af40815,0x00000000,0x00000000}},	//   vbyv, нявс, --, --, 
   {{0xafe0005b,0xdfcc2c37,0x5ed400e5,0x98a40205}},	//   _сошл, _ميچ_, _آتشز, _ımı_, 
   {{0x2ca8007b,0x8f5003e6,0x00000000,0x00000000}},	//   éidí_, _ڕۆیش, --, --, 
   {{0x7aec0334,0x60cc01e7,0x00000000,0x00000000}},	//   sfbt, ócmh, --, --, 
   {{0xfaa40b2c,0x77840640,0x7b9402bf,0xfc5c1ee0}},	// [1d9a0] _папо, елаз, _прої, _ወንጌል, 
   {{0x3864038f,0x98c070f7,0xdb500133,0xa2d806ff}},	//   ħor_, ısın_, _ئێس_, _नाग्, 
   {{0x6aa0002d,0x00000000,0x00000000,0x00000000}},	//   _ûnfa, --, --, --, 
   {{0xb46530ce,0x1ab80154,0xd1d401f3,0xfe080051}},	//   нкел, _জায়া, ረከብ_, _mắ_, 
   {{0x57040124,0x00000000,0x00000000,0x00000000}},	//   _иҟаз, --, --, --, 
   {{0xf7d00150,0x00000000,0x00000000,0x00000000}},	//   _ﺟﻪﻳﺪ, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdce401e4,0xab5800c5,0x21601e35,0x00000000}},	//   _kunĵ, tsük, лтыг, --, 
   {{0xe8104688,0x35c40037,0x00000000,0x00000000}},	//   ठिया_, _लबड़, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2bd0084a,0xaf740023,0xee7000ee,0x2eb40014}},	//   _तिहा, _ከባቢና_, ыңкы, وَکھ_, 
   {{0xabb08595,0x273c054e,0xf3880055,0xf18801af}},	//   ламә, _mîna_, _rṣy_, _эйел_, 
   {{0x3c44004a,0x9d1802a9,0x9c38020f,0x00000000}},	//   _rêvé_, хоят_, епят_, --, 
   {{0x311c00dc,0xa004007b,0x00000000,0x00000000}},	//   भावः_, _أقول_, --, --, 
   {{0x2bd0033d,0xe9840063,0x5884329e,0xceb80210}},	//   _तिवा, ећан, ғыта, mbę_, 
   {{0x9998f112,0xceb80153,0xa7f800a2,0x00000000}},	//   екст_, lbę_, _zyñy, --, 
   {{0x274401e1,0x00000000,0x00000000,0x00000000}},	// [1d9b0] _nínù_, --, --, --, 
   {{0x4de405f9,0x65c400dd,0x78a001a2,0xe8e86276}},	//   _कमाई_, _néhá, ľova, _کردو_, 
   {{0x78a002fb,0x6f0802ce,0xdb0405c7,0xb604005f}},	//   žova, _mafc, _gwiñ, jušā, 
   {{0x6f080009,0xd668004b,0xb60400e2,0x00000000}},	//   _lafc, رمنو_, dušā, --, 
   {{0x66b00220,0xd7f88861,0x58847b93,0x2908054e}},	//   _бұзу, _пур_, _быра, _iaca_, 
   {{0x290930cf,0x6ad0015b,0x6f080009,0x91fc00b8}},	//   _haca_, দ্রো, _nafc, _hyāy, 
   {{0x290930d0,0x27e80051,0x3ea80205,0xd4980139}},	//   _kaca_, _hqcn_, _şato_, мрә_, 
   {{0x85040137,0x26c00438,0x6f080175,0x91fc002b}},	//   _جورن, _hejo_, _aafc, _jyāy, 
   {{0x290930d1,0x31211a47,0x7ed404fb,0x26c130d2}},	//   _maca_, рдыг, پزخا, _kejo_, 
   {{0x290930d3,0xa2d86d72,0x26c130d4,0xeae004c5}},	//   _laca_, _नाट्, _jejo_, য়ুম, 
   {{0x6f0800e8,0x26c130d5,0xf2e40214,0x22840139}},	//   _dafc, _mejo_, _شکوه_, _чуаг, 
   {{0x705130d6,0x26c130d7,0x290800dc,0xee344d56}},	//   انیا, _lejo_, _naca_, тню_, 
   {{0x26c0003e,0x6f080175,0x00000000,0x00000000}},	//   _oejo_, _fafc, --, --, 
   {{0xeb940c04,0x26c130d8,0x212c047e,0xef140588}},	//   кия_, _nejo_, _hogh_, _амш_, 
   {{0x249c00d8,0xbdf80214,0xca6400c7,0xce340133}},	//   _ogum_, _آرتا_, герқ, _مووک, 
   {{0x290930d9,0x00000000,0x00000000,0x00000000}},	//   _caca_, --, --, --, 
   {{0x29081142,0x26c130da,0x66040158,0x212cd250}},	// [1d9c0] _daca_, _bejo_, _asjk, _mogh_, 
   {{0x249c008b,0x212d30db,0x29080334,0xbb4807d6}},	//   _agum_, _logh_, _eaca_, _آلدن_, 
   {{0x290930dc,0x26c130dd,0x36947896,0x83fc00dd}},	//   _faca_, _dejo_, тшас, _győz, 
   {{0x290930de,0x2d980548,0x212c0455,0xc7940150}},	//   _gaca_, _xiqe_, _nogh_, _ұрсы, 
   {{0x26c001e4,0xceb83ee4,0x38c400c0,0x00000000}},	//   _fejo_, ybę_, gūrų_, --, 
   {{0x6d9c00b0,0x26c00115,0x638001c0,0x00000000}},	//   _kīat, _gejo_, агча, --, 
   {{0x212c27cc,0x290930df,0x6f080463,0x3674484d}},	//   _bogh_, _yaca_, _rafc, _شهرز, 
   {{0x6f08b56b,0x2bd062be,0x751800ae,0x00000000}},	//   _safc, _तिला, _تقرأ_, --, 
   {{0x26c007a8,0x212c016d,0xb4dc0490,0x6f08003a}},	//   _yejo_, _dogh_, ढली_, _pafc, 
   {{0xf7cc1c5c,0x777c010a,0x2d980200,0xb35400e5}},	//   _ﺗﻪﻟﻪ, nlpx, _siqe_, _جیتا_, 
   {{0x212d30e0,0xceb87063,0x02180153,0x00000000}},	//   _fogh_, rbę_, _піць_, --, 
   {{0x2efc2959,0x09b0015b,0xc8e005d7,0x425400d8}},	//   setf_, _ছিলা, _फाइट, _стут, 
   {{0x6f08009f,0x290930e1,0x2ca80066,0x00000000}},	//   _tafc, _raca_, rccd_, --, 
   {{0x29091a82,0xddcc0118,0x91fc00b8,0x00000000}},	//   _saca_, žeši, _syāy, --, 
   {{0x78a001f1,0x6d9c00b0,0x26c130e2,0x2ca800f2}},	//   ľovn, _pīau, _rejo_, pccd_, 
   {{0x26c130e3,0x6d8400dd,0x39400175,0x58d4005b}},	//   _sejo_, _جمعہ_, _clks_, иост, 
   {{0x481402d5,0x6aa0045f,0x19941c50,0x48e8227c}},	// [1d9d0] ымас, _ûnfo, ратя, ङ्गो_, 
   {{0x290930e4,0xaab407d0,0x394130e5,0x00000000}},	//   _waca_, _अभिक, _elks_, --, 
   {{0xaa4004a9,0x26c130e6,0x290930e7,0xaa64587f}},	//   _ئۆزى, _vejo_, _taca_, _штик, 
   {{0x29080998,0x38c40153,0xa2d80b98,0xdb04040e}},	//   _uaca_, tūrų_, _नाङ्, _ptiç, 
   {{0x26c130e8,0x28680b3e,0x6604005a,0x212c01ab}},	//   _tejo_, _црно_, _wsjk, _rogh_, 
   {{0x212cb01d,0x94a800c7,0x00000000,0x00000000}},	//   _sogh_, нтәа_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x212c016d,0x41042377,0xe50800c5,0xc05001d9}},	//   _qogh_, узив, _सोचि_, یٖں_, 
   {{0xbea438eb,0xc17804d3,0x212c0455,0xc8e0000d}},	//   лапк, وڵڵا_, _vogh_, _फाईट, 
   {{0x64480007,0x212c020c,0x5ec00154,0xdce80139}},	//   mzgi, _wogh_, _শাহে, _ılıl, 
   {{0xdce40115,0x212c047e,0x644886ea,0x00000000}},	//   _ekiĝ, _togh_, lzgi, --, 
   {{0x3d0c000d,0x43e00150,0x00000000,0x00000000}},	//   ियें_, _ﺍﻻﯕﺪ, --, --, 
   {{0x64480399,0xef0d30e9,0xbad40006,0x00000000}},	//   nzgi, _лм_, лівы, --, 
   {{0x6d9c02b1,0xce3404d3,0x6448005a,0xf7cc313e}},	//   _pīat, اوێک, izgi, _ﺗﻪﻛﻪ, 
   {{0xaa411f3a,0x00000000,0x00000000,0x00000000}},	//   берл, --, --, --, 
   {{0x78a000d0,0x4ad80014,0x00000000,0x00000000}},	//   ľovo, _یاپھ_, --, --, 
   {{0xe8f530ea,0xfbd019b6,0x6d9c02b5,0x78a002fb}},	// [1d9e0] ылт_, _اتب_, _wīat, žovo, 
   {{0x3a240166,0x64480064,0x00000000,0x00000000}},	//   _бмог, dzgi, --, --, 
   {{0x644804cc,0x3d18010b,0x00000000,0x00000000}},	//   ezgi, _güwä_, --, --, 
   {{0x25b404fb,0xb4dc0490,0xbb48006c,0x00000000}},	//   اهند_, ढले_, _آلگن_, --, 
   {{0xe808000d,0x00000000,0x00000000,0x00000000}},	//   _सईया_, --, --, --, 
   {{0x237407d6,0xcc900055,0x2324a3f8,0x64a000fb}},	//   همند_, _bṛja_, лочи_, _ғафа, 
   {{0x614c0023,0xe1ec3b44,0xeb9c0162,0xc32c0eff}},	//   _ንህዝባ, كسي_, nvør_, بەل_, 
   {{0x3d0c14cf,0x4fd530eb,0x059402dd,0x00000000}},	//   ियों_, ажит, _ﺑﺎﺳﭙ, --, 
   {{0xddcd30ec,0xeb9c0162,0xd6cc03d4,0x1fa001c6}},	//   _češn, hvør_, ৰ্ণয, йрэг, 
   {{0x9ff400e3,0xfe6c00f2,0x437400c0,0x3dc80210}},	//   اريء_, ژگي_, _кухт, _ława_, 
   {{0x47b8031c,0x00000000,0x00000000,0x00000000}},	//   _བསྐམ, --, --, --, 
   {{0xb88002f0,0xeb9c0174,0x4c941171,0x00000000}},	//   _číno, dvør_, иинс, --, 
   {{0x2da00150,0x00000000,0x00000000,0x00000000}},	//   _ﺍﻟﻌﻰ_, --, --, --, 
   {{0x160428fe,0xce940801,0x78a001a6,0x00000000}},	//   रबार_, _калъ, žovl, --, 
   {{0x64480158,0xeb9c03b2,0x00000000,0x00000000}},	//   zzgi, gvør_, --, --, 
   {{0xda14012d,0x00000000,0x00000000,0x00000000}},	//   डि़त_, --, --, --, 
   {{0xeb9c08cb,0x47d530ed,0x00000000,0x00000000}},	// [1d9f0] rvøs_, شيار, --, --, 
   {{0xab5800e5,0x00000000,0x00000000,0x00000000}},	//   gsüt, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8414ca5f,0x637c0798,0x64480112,0xc2241e4b}},	//   имех, mêni, tzgi, یکاو, 
   {{0x02c4e90e,0x637c0120,0x6448030a,0xcc900055}},	//   айло, lêni, uzgi, _sṛja_, 
   {{0xab580254,0x74a80166,0x00000000,0x00000000}},	//   msüs, нсәң_, --, --, 
   {{0x6e2c0036,0xab58000d,0x3698014b,0x00000000}},	//   äbbl, lsüs, _абрӯ_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6578ec8f,0xab5930ee,0xa02400e5,0x912800cf}},	//   _ikuh, nsüs, ازعے_, اسىق_, 
   {{0xff50180a,0xb398001f,0x00000000,0x00000000}},	//   تخب_, ገባውን_, --, --, 
   {{0x23a8019b,0x004400f1,0xc0d49edc,0xceb800c0}},	//   _høj_, دیږي_, _نياب, ejęs_, 
   {{0x61e00115,0xab580254,0xd1640395,0xfce530ef}},	//   munl, ksüs, _лъчи, шомо, 
   {{0xff5015fa,0x65780280,0x6d9c00b0,0x4a7401e0}},	//   _وخت_, _mkuh, _pīar, ҡыст, 
   {{0x47b80327,0x23a801bf,0x7c200135,0x6fb0007b}},	//   _བསྟམ, _møj_, _ġord, _بموا, 
   {{0x61e12ae7,0x657930f0,0x637c06ed,0x7e7800c8}},	//   nunl, _okuh, gêni, _באַז, 
   {{0x6d9c00b0,0x657800ca,0xb90400d8,0x00000000}},	//   _hūan, _nkuh, јзак, --, 
   {{0x36c4732e,0x6d9c02b1,0xa7a40640,0x37e475e6}},	// [1da00] ибаг, _tīar, икта_, розг, 
   {{0x61e130f1,0x213c0036,0x00000000,0x00000000}},	//   kunl, hkuh_, --, --, 
   {{0xaad80302,0x213c0429,0x1da8033f,0x61e0014f}},	//   _בחיר, kkuh_, _घूमत, junl, 
   {{0x66d00139,0xcc900055,0xec1001b9,0x23a801bf}},	//   _añkı, _bṛha_, _اوید, _bøj_, 
   {{0xe3ad30f2,0xb6a400d6,0x7c200077,0xab5801d3}},	//   ورو_, _вигл, _áord, psüt, 
   {{0x65782935,0xf744ea5a,0x1ad803d4,0xe36001d5}},	//   _ekuh, _тего, দ্ৰা, окчи, 
   {{0x61e130f3,0x65780418,0xb80c134e,0x00000000}},	//   gunl, _fkuh, सिकम_, --, 
   {{0x213c02b4,0x23a8037e,0xe5a063e6,0xab580342}},	//   gkuh_, _føj_, _фити, nsür, 
   {{0x2934008f,0xdb0401e7,0xcc90002b,0x00000000}},	//   שאפן_, _dtiú, _gṛha_, --, 
   {{0x61e0cdf0,0x00000000,0x00000000,0x00000000}},	//   bunl, --, --, --, 
   {{0x4d980212,0x72040690,0x213c0327,0x61e00205}},	//   лкою_, _خوام, bkuh_, cunl, 
   {{0xa3d80073,0x6e383bdc,0xe0d401f4,0x00000000}},	//   ढंच_, rytb, _ввц_, --, 
   {{0xc308015b,0x91c40131,0x89380150,0x00000000}},	//   লারি_, _тәһл, қпас_, --, 
   {{0x5f7000aa,0x9b6930f4,0x637c0798,0x6b48002f}},	//   _واور, ашса_, têni, _mügg, 
   {{0x6d4c0268,0xf3fc0154,0x7f28210e,0x00000000}},	//   èbas, ূমির_, _حسنِ_, --, 
   {{0x7c20005f,0x5e980375,0xe810000d,0xab58000d}},	//   _šore, _בבוק, ठिला_, tsüs, 
   {{0x61e006b9,0xdd900a81,0xdcf800db,0x6db02c11}},	// [1da10] zunl, _زوٝ_, _ئرىش_, _уйқу, 
   {{0x6578c525,0x61e07a36,0x26c400d2,0x290c0427}},	//   _skuh, yunl, úno_, žga_, 
   {{0xab5800af,0x3f8803f9,0x1ac86ef4,0x00000000}},	//   ssüs, _ɗau_, _туып_, --, 
   {{0x61e130f5,0x23a8365a,0x26c4033f,0x00000000}},	//   vunl, _pøj_, źno_, --, 
   {{0x61e130f6,0x270c0154,0x00000000,0x00000000}},	//   wunl, সাবো_, --, --, 
   {{0xdb040491,0x61e130f7,0x6b4804cc,0xd7f80006}},	//   _stiú, tunl, _dügg, _тую_, 
   {{0xdb0530f8,0x0a30044e,0x61e01c06,0x00000000}},	//   _quié, _ኣመሪካ, uunl, --, 
   {{0x65781253,0x23a804ce,0x61e00365,0x6b4800dd}},	//   _ukuh, _tøj_, runl, _függ, 
   {{0x61e130f9,0x6d9c02b5,0xe45c01f4,0x6d5c01e1}},	//   sunl, _pūan, _äö_, _ípay, 
   {{0x438400c6,0xdb0400a3,0x61e0034c,0x1ee4028e}},	//   _الطق, _ftiù, punl, جودی_, 
   {{0x443c377c,0x61e06edb,0x5338010a,0x00000000}},	//   lyw_, qunl, _тутă, --, 
   {{0x200804ce,0x06cc0154,0x99980588,0x78a000d7}},	//   æcis_, _লাফি, pyrũ_, ľovk, 
   {{0x51740597,0x443c03cb,0x6370010e,0x1ee401d3}},	//   _بالأ, nyw_, _eýnş, _نوشی_, 
   {{0x98a008ad,0xa274001f,0x00000000,0x00000000}},	//   ljić_, _ይሄንን_, --, --, 
   {{0x443c0007,0xaa4130fa,0x00000000,0x00000000}},	//   hyw_, перл, --, --, 
   {{0x98a056c0,0x420400dc,0xadb4143e,0x00000000}},	//   njić_, _शनैः_, _اهيا_, --, 
   {{0x7d04049b,0xab5803e0,0x00000000,0x00000000}},	// [1da20] meks, rsür, --, --, 
   {{0xa3a845bf,0x6c540a1e,0xab5930fb,0x2364003e}},	//   _गढ़_, _ליפא_, ssür, jnnj_, 
   {{0xb8ec00bd,0x6b88002e,0x2f58008f,0xe8900022}},	//   _রা_, _ëgga, נדענ, _ҽаџь, 
   {{0x7d0530fc,0x443c0042,0x986800db,0x00000000}},	//   neks, fyw_, _ەلڭە_, --, 
   {{0xdb040876,0x33f4005b,0x443c0142,0x53340108}},	//   _stiù, счес, gyw_, желт, 
   {{0x7d04d62e,0x00000000,0x00000000,0x00000000}},	//   heks, --, --, --, 
   {{0xf624cffc,0x321800d0,0x7ae802d2,0xba38010f}},	//   _удво, ípy_, _öftu, טײַט, 
   {{0x7d0530fd,0xb3e84028,0x00000000,0x00000000}},	//   jeks, _معطل_, --, --, 
   {{0x6b480e78,0x855400e5,0x64a125ef,0x00000000}},	//   _hüge, _بینر_, _хауа, --, 
   {{0x6d9c00b0,0x79940158,0x6b4930fe,0x7d040108}},	//   _pūao, hmyw, _küge, eeks, 
   {{0x06d4045e,0x637c0798,0x14cc0073,0xa14000ef}},	//   স্কি, gênu, ारपण, _šķer, 
   {{0x7d0436ff,0x842000db,0x00000000,0x00000000}},	//   geks, _رۉۉن, --, --, 
   {{0x70384950,0x6b480e78,0x656001d3,0x00000000}},	//   _حساس_, _lüge, énhi, --, 
   {{0x78a40093,0x9528025c,0x7c203421,0x3fc401ed}},	//   _agkv, _རོའི_, _šorc, _بگٹی_, 
   {{0x2d88004a,0x6ce40953,0x5f400150,0x7d04c357}},	//   ïbes_, _ліпе, _ءنىل, beks, 
   {{0x195930ff,0x7d040365,0x00000000,0x00000000}},	//   басы_, ceks, --, --, 
   {{0x473430c9,0xfca8010f,0x00000000,0x00000000}},	// [1da30] онас, _דיפּ, --, --, 
   {{0x6b481248,0x00000000,0x00000000,0x00000000}},	//   _büge, --, --, --, 
   {{0x49740816,0x00000000,0x00000000,0x00000000}},	//   _млос, --, --, --, 
   {{0xe4c8034c,0x443d3100,0xe45c02d2,0x00000000}},	//   ابان_, tyw_, _þök_, --, 
   {{0xe7841621,0xe3b0034c,0xf9f40327,0x06cc0154}},	//   _гуво, سرش_, _བཱོན_, _লাঠি, 
   {{0x41b462d9,0x86246bde,0x443c0368,0x6b493101}},	//   осит, _وکال, ryw_, _füge, 
   {{0x7d053102,0x00000000,0x00000000,0x00000000}},	//   yeks, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x443c0369,0x6b4808d5,0x00000000,0x00000000}},	//   qyw_, _züge, --, --, 
   {{0x2eec030d,0x2fc402e2,0x7d053103,0xf07401ed}},	//   _ccff_, _dwog_, weks, غیوں_, 
   {{0xd1b93104,0x79940034,0x78a000d0,0xa3ac012d}},	//   _هانا_, ymyw, ľovi, _ऐंड_, 
   {{0x78a0009b,0xee340024,0x00000000,0x00000000}},	//   žovi, іня_, --, --, 
   {{0x7d044240,0x60c8014b,0x637c00d2,0xe0853105}},	//   reks, _iegm, bênt, _اجاي, 
   {{0x7d053106,0x68ec037e,0x637c0798,0x00000000}},	//   seks, _accd, cênt, --, 
   {{0x7d053107,0x00000000,0x00000000,0x00000000}},	//   peks, --, --, --, 
   {{0x6b493108,0xc7653109,0xed5c0055,0x00000000}},	//   _rüge, ۋالى, ciþ_, --, 
   {{0x60c9310a,0x4998023a,0x3ce40cb4,0x6b49310b}},	// [1da40] _megm, ётся_, कलीं_, _süge, 
   {{0x7bd41446,0x66e0036b,0x60c801ed,0x36180212}},	//   _ivyu, дофа, _legm, ицею_, 
   {{0x3f85310c,0x74a40798,0x360400ae,0x00000000}},	//   illu_, ојле, تواف, --, 
   {{0x60c80810,0x3f840472,0x8698023a,0x00000000}},	//   _negm, hllu_, стут_, --, 
   {{0xe5a1310d,0xba743463,0x87b9310e,0x3f840309}},	//   фици, _داکت, _густ_, kllu_, 
   {{0x6b480598,0x60c80254,0x660c0108,0x2bd00073}},	//   _tüge, _aegm, äikä, _तिघा, 
   {{0x200c009a,0x6450013f,0x10a4002b,0x60c9310f}},	//   _asgi_, _ɑfiɑ, _aṇḍa, _begm, 
   {{0xd250021a,0x200c01c3,0x3f853110,0x6ab400cd}},	//   ونږ_, _bsgi_, ellu_, _अभ्र, 
   {{0x60c93111,0x637c0120,0xaabc012c,0xf2d800f2}},	//   _degm, tênt, ्रमक, _نباش_, 
   {{0x60c8058a,0x9f5c00b8,0x7e6c002b,0x00000000}},	//   _eegm, _āsãd_, _śapa, --, 
   {{0x7bd53112,0x200c00a2,0x637c00d8,0xf8a801ad}},	//   _avyu, _esgi_, rênt, कशाय, 
   {{0x3f853113,0x6eb80a28,0x21b401ed,0x00000000}},	//   allu_, _श्रु, _بھوک_, --, 
   {{0x06d400bd,0xf9f40327,0x65980a7c,0xbf6400f2}},	//   স্টি, _བཱུན_, ייטק, _کدنو, 
   {{0x40940323,0x6d9c02b5,0x60c801a4,0x00000000}},	//   _эрхт, _kūak, _zegm, --, 
   {{0x60c80af2,0x09b000cc,0x00000000,0x00000000}},	//   _yegm, _ছিঙা, --, --, 
   {{0x7e7c0112,0x5d6402dd,0x3e680150,0x00000000}},	//   ßspe, _отыз, _ушін_, --, 
   {{0x6d4c0007,0x9c8801ec,0x00000000,0x00000000}},	// [1da50] mhca, _وپىق_, --, --, 
   {{0x65b0031c,0xa6453114,0x1ab407d8,0x00000000}},	//   _aħha, يخان, _обья, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d4c0007,0xaae53115,0x29d4031c,0x00000000}},	//   nhca, _اسکو, mħa_, --, 
   {{0x321d078a,0xe8fc0428,0x60c805e4,0x588456a4}},	//   _arty_, _ibû_, _regm, _жыра, 
   {{0xe8fc002d,0xceb403e3,0x00000000,0x00000000}},	//   _hbû_, _şən_, --, --, 
   {{0x442800a8,0xe57030d6,0x60c93116,0x02183981}},	//   ţa_, _قطر_, _pegm, сіль_, 
   {{0x95c80f06,0xd04003b9,0x00000000,0x00000000}},	//   _фура_, lamə, --, --, 
   {{0x6d4d3117,0xab580793,0x3f840194,0xdb0400a2}},	//   dhca, ipüb, tllu_, _atiý, 
   {{0x3f840eda,0x63b93118,0xd04003b9,0x00000000}},	//   ullu_, _itun, namə, --, 
   {{0x65693119,0x60c9311a,0x6d9c0374,0x3f840194}},	//   ongh, _tegm, _kūah, rllu_, 
   {{0x6569311b,0xddc401d3,0x40341422,0xed540212}},	//   nngh, ülők, _неес, зою_, 
   {{0x88d00729,0x63b80327,0x6db80327,0x29d40003}},	//   িলাক, _jtun, _nċaf, eħa_, 
   {{0x63b9311c,0x51a800f7,0x3f8402d1,0x29d4025c}},	//   _mtun, _ادەپ_, qllu_, fħa_, 
   {{0x29d4003d,0x6d4c00a3,0x63b80112,0x00000000}},	//   għa_, bhca, _ltun, --, 
   {{0x63b9311d,0x6d4d311e,0x00000000,0x00000000}},	//   _otun, chca, --, --, 
   {{0xa7a40022,0x00000000,0x00000000,0x00000000}},	// [1da60] зкуа_, --, --, --, 
   {{0x7d15311f,0x29d40003,0xaabc00bc,0xe73401ec}},	//   _hays, bħa_, ्रणक, пеу_, 
   {{0x63b93120,0x7d153121,0x79480432,0xf6540108}},	//   _atun, _kays, _eýwa, чтаю, 
   {{0xe8fc2776,0x7d153122,0x92e800bd,0x00000000}},	//   _gbû_, _jays, _বসে_, --, 
   {{0x7d153123,0x293400c8,0x25bc0fcf,0x30a400d1}},	//   _mays, _זאכן_, _čule_, үрив, 
   {{0x65680491,0x7d140050,0x7aec03a2,0x63b8020b}},	//   angh, _lays, ngbt, _dtun, 
   {{0x63b93124,0x7d140076,0x00000000,0x00000000}},	//   _etun, _oays, --, --, 
   {{0x7d140548,0x63b93125,0xc308009e,0x321c02f0}},	//   _nays, _ftun, লাগি_, _vrty_, 
   {{0xdb040166,0x6b489ca0,0xe4d400f2,0x00000000}},	//   _btiü, _lüga, _رولت_, --, 
   {{0xa854025f,0x7d14058a,0x45a000cf,0x3ea80139}},	//   פייה_, _aays, _كەەك, _şatr_, 
   {{0x7d153126,0x6b48000d,0x44900240,0x00000000}},	//   _bays, _nüga, _ዝሓተተ_, --, 
   {{0xdb08145e,0x14cc0146,0x7d140548,0x2dd401d9}},	//   _âlêm, ारिण, _cays, _ہُتھ_, 
   {{0x7d153127,0xa3cc3d1d,0xd0400213,0x40f00022}},	//   _days, वीप_, yamə, _рҧыр, 
   {{0x6d4d3128,0x684000d2,0x7d140363,0x29d4025c}},	//   shca, _lídú, _eays, tħa_, 
   {{0x7d1401d9,0x14cc3347,0x656803cb,0x00000000}},	//   _fays, ाराण, yngh, --, 
   {{0x7d143516,0x1958385e,0x29d4031c,0x00000000}},	//   _gays, пасы_, rħa_, --, 
   {{0x6d5c0003,0x29d4025c,0xc7d80229,0x00000000}},	// [1da70] _imqa, sħa_, юмах_, --, 
   {{0xfbd00302,0x4de005f9,0xd7c82824,0x00000000}},	//   _שתי_, _खटाई_, سومه_, --, 
   {{0x63b93129,0x6d9c0374,0x7d14102c,0xa3cc2ce1}},	//   _stun, _pūah, _yays, वीन_, 
   {{0x63b802c4,0x65680311,0x7d15312a,0x00000000}},	//   _ptun, ungh, _xays, --, 
   {{0x68400248,0xb8840030,0x65680072,0xf8b401c6}},	//   _dídú, _príť, rngh, _цөс_, 
   {{0xaabc0b26,0xd04003be,0x147408f0,0x6d5c0327}},	//   ्रिक, qamə, رانج, _lmqa, 
   {{0x6d5c0472,0xe850001f,0x6d9c02b5,0x26d0058a}},	//   _omqa, _ለመቀነ, _tūah, maxo_, 
   {{0x63b9312b,0x7fd80798,0x00000000,0x00000000}},	//   _ttun, офот_, --, --, 
   {{0x63b9312c,0xaabc1b61,0x7d15312d,0x9dc000d1}},	//   _utun, ्राक, _rays, ﯩﺘﯩﺸ, 
   {{0xf8a829d9,0x7d15312e,0x6d5c014b,0x3cf00a40}},	//   _कल्प, _says, _amqa, _scyv_, 
   {{0xfce5312f,0x7d153130,0x00000000,0x00000000}},	//   моно, _pays, --, --, 
   {{0x7d153131,0x6b48000d,0x00000000,0x00000000}},	//   _qays, _rüga, --, --, 
   {{0x6b49140b,0xeb9c0217,0x7d14022e,0x00000000}},	//   _süga, lvøy_, _vays, --, 
   {{0x7d153132,0x6d5c4b2a,0xa3cc1f13,0xfaa4013e}},	//   _ways, _emqa, वीय_, ҷаҳо, 
   {{0x7d14102c,0x00000000,0x00000000,0x00000000}},	//   _tays, --, --, --, 
   {{0xfaa40107,0x6d5c01e1,0x00000000,0x00000000}},	//   заҳо, _ìpap, --, --, 
   {{0x0d480150,0x00000000,0x00000000,0x00000000}},	// [1da80] _ءشىي_, --, --, --, 
   {{0xdb0400db,0x6b600022,0x26d00009,0x00000000}},	//   _etiò, _акьа, gaxo_, --, 
   {{0xd5b001ed,0x00000000,0x00000000,0x00000000}},	//   اہر_, --, --, --, 
   {{0x273c0276,0x6d9c00b0,0xe8a0b071,0x00000000}},	//   _sînt_, _pūai, رمەپ, --, 
   {{0xa6e00c58,0x2d84013b,0x6aa0000f,0x26d0058a}},	//   ন্ধট, _ɔne_, _ûnfr, baxo_, 
   {{0x92940e92,0x6b48002f,0x78a00419,0x00000000}},	//   налц, _lügn, žovs, --, 
   {{0xe1ec1c4e,0xd25000c6,0x7c200010,0x273c0356}},	//   لسي_, طنة_, _šorl, _vînt_, 
   {{0xd1313133,0x21602fe5,0xf8cc012d,0x00000000}},	//   امة_, ктыг, ़रिय, --, 
   {{0x39501368,0x00000000,0x00000000,0x00000000}},	//   ihys_, --, --, --, 
   {{0x81ac0154,0x00000000,0x00000000,0x00000000}},	//   _কবর_, --, --, --, 
   {{0x9f480af2,0x437400d4,0x324400ae,0x00000000}},	//   îcá_, _чутт, _تناف, --, 
   {{0xdfcd3134,0x6fb4007b,0xf0d430d1,0x00000000}},	//   _چين_, _قمصا, _آغاخ, --, 
   {{0xdb0445a7,0xceb93135,0xdfcc2abb,0xef180117}},	//   _atiñ, _нән_, _نين_, _ммд_, 
   {{0x39500076,0xab5803e0,0x95940023,0x00000000}},	//   ehys_, lsüz, _ዝጣበቕ_, --, 
   {{0x5de000c7,0x00000000,0x00000000,0x00000000}},	//   _ҧжәа, --, --, --, 
   {{0x6d5c1cdf,0x39500731,0x26d00564,0x8bd8084c}},	//   _umqa, ghys_, waxo_, _емис_, 
   {{0x26d00009,0xd7f868eb,0x00000000,0x00000000}},	// [1da90] taxo_, дух_, --, --, 
   {{0xe7310935,0x6d9c02b5,0xadf05b82,0x39500076}},	//   خصر_, _pūaw, _अमान_, ahys_, 
   {{0x26d13136,0x4ddc03d4,0x6b480139,0x00000000}},	//   raxo_, _বহুৱ, _yügn, --, 
   {{0xe8e824e0,0x395000ad,0x2d880076,0x26d00067}},	//   _بردو_, chys_, nlce_, saxo_, 
   {{0x2d8836f4,0xb600031c,0xa5d80037,0x2bb4134e}},	//   ilce_, ġġab, _पटकौ, _इंफा, 
   {{0x947400c6,0xddcc07f5,0x26d001a9,0x00000000}},	//   خدما, _čežn, qaxo_, --, 
   {{0xceb80210,0xd68403f6,0x00000000,0x00000000}},	//   dcę_, _аутп, --, --, 
   {{0xdeb80020,0x05940cd6,0xeb9c143a,0x82340014}},	//   ቲያን_, _سازگ, rvøy_, ِرکا, 
   {{0x2d893137,0x00000000,0x00000000,0x00000000}},	//   dlce_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfcdc044e,0x3a246b48,0x7fd401ec,0xab580b97}},	//   _ዕዳጋ_, _čop_, _зікі, msüy, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6e2c0332,0x201c0051,0x00000000,0x00000000}},	//   óibí, mvui_, --, --, 
   {{0xa3cc28e1,0xc85c0020,0x13fc000d,0x201c00c0}},	//   वीत_, _ለመከላ, _एह्ह_, lvui_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x25bc098d,0x39500076,0xb86401e2,0xb4b000d1}},	// [1daa0] _čula_, rhys_, رارو, қилә, 
   {{0x2d981a44,0x201c0208,0x39500076,0xab5803e0}},	//   _èper_, ivui_, shys_, zsüz, 
   {{0x395026c2,0xceb406be,0x00000000,0x00000000}},	//   phys_, _şək_, --, --, 
   {{0xb1f003b2,0x00000000,0x00000000,0x00000000}},	//   óðmú, --, --, --, 
   {{0x7984025c,0xceb80210,0x00000000,0x00000000}},	//   _ikkw, ycę_, --, --, 
   {{0x3b180784,0x6b4807de,0x3f4808a5,0x00000000}},	//   _japq_, _nügl, _búum_, --, 
   {{0x6ed45536,0xb1a40107,0x00000000,0x00000000}},	//   _मजबु, ншик, --, --, 
   {{0xd010036b,0xceb8033f,0xe5a00408,0xc4c4007b}},	//   للب_, wcę_, _биси, _لتكو, 
   {{0xd3a53138,0x6b4805d5,0x386402d3,0xe7f000c5}},	//   _алақ, _bügl, _ተመሊሱ_, इंया_, 
   {{0xd130034c,0x59b0060c,0x2c1c00cc,0x00000000}},	//   امک_, झदार, _পথলৈ_, --, 
   {{0x7985131a,0x64c001ec,0xceb80210,0x00000000}},	//   _okkw, _شيەل, rcę_, --, 
   {{0xdb040162,0x2a000010,0xa3e400bc,0x00000000}},	//   _stið, nčaš_, _भिम_, --, 
   {{0x5c040006,0x201c0208,0x1028009f,0x00000000}},	//   ляра, cvui_, _آڻبي_, --, 
   {{0x79840003,0x6b4807c5,0x6d9c02b5,0x20540115}},	//   _akkw, _gügl, _rūau, _אידל_, 
   {{0x333c005a,0xda7800a7,0xe9f00022,0x00000000}},	//   _motx_, еят_, ыҧны, --, 
   {{0x6d9c00b0,0x97a400d1,0x5a340006,0xceb403e3}},	//   _pūau, ғрул, ынст, _şəh_, 
   {{0x23cc7e29,0x195800fa,0x00000000,0x00000000}},	// [1dab0] _सौंद, хаты_, --, --, 
   {{0x79840327,0x00000000,0x00000000,0x00000000}},	//   _ekkw, --, --, --, 
   {{0xdb040798,0x984801d9,0x3a7400cf,0xfb18011a}},	//   _suiç, ولہٕ_, _үлөр, _חותמ, 
   {{0x6d9c00b0,0x00000000,0x00000000,0x00000000}},	//   _tūau, --, --, --, 
   {{0x53e01b61,0xdb0400d8,0x00000000,0x00000000}},	//   _निःश, _quiç, --, --, 
   {{0xc1b808de,0xd7c80345,0x00000000,0x00000000}},	//   وابط_, _سوفه_, --, --, 
   {{0x45d4010b,0x04c835f9,0x00000000,0x00000000}},	//   _шовс, _يوسي_, --, --, 
   {{0x21280dd4,0x2f200014,0xc59400d8,0xab582ca8}},	//   ñch_, یہنِ, _рибј, rsüy, 
   {{0xa30024ce,0xdb040108,0x00000000,0x00000000}},	//   _бүле, _itiö, --, --, 
   {{0x94000490,0x7e7c002f,0xbea4004e,0x00000000}},	//   ोबरच_, ßspo, капк, --, 
   {{0x1be4032c,0xc1d02f8d,0x7e7c0790,0xb6b8011a}},	//   _कटहल_, _төлә, ğspo, וצתי, 
   {{0xedf004c5,0xca64022e,0x23640240,0x6b480205}},	//   জবংশ_, _bahо, linj_, _dügm, 
   {{0xed543da1,0xf19000d1,0x00000000,0x00000000}},	//   тоя_, _ﯞﻩﻣﯘ, --, --, 
   {{0x9ad40521,0x0e640220,0xafe0377b,0xab580036}},	//   _bịar, _өкін, _тошл, spün, 
   {{0x6d9c02b1,0xed1400e5,0xab5800a2,0x00000000}},	//   _pūat, رہیں_, mpül, --, 
   {{0x23653139,0x4ea40063,0x38640023,0x00000000}},	//   hinj_, _срча, _ተመልሱ_, --, 
   {{0xa9a001b9,0xe9a1313a,0x23640427,0xec101541}},	// [1dac0] ритд, ратп, kinj_, _نويد, 
   {{0x7984020b,0x00000000,0x00000000,0x00000000}},	//   _wkkw, --, --, --, 
   {{0x6d9c00b0,0x7c20009b,0xa3cc0b72,0x245001d5}},	//   _tūat, _šorh, वीस_, ینمس, 
   {{0x6d9c02b5,0x2e38010f,0x6a140066,0x00000000}},	//   _hūar, וגענ, _شبپر, --, 
   {{0x6d9c0374,0x33f4013d,0x23640200,0x33a80150}},	//   _kūar, тчес, finj_, _ﺷﻮﺭﻣ, 
   {{0xc1a80952,0x23242826,0xb28400fd,0x23640010}},	//   _ﺷﺎﺭﺍ, кочи_, кыйк, ginj_, 
   {{0x62600063,0x00000000,0x00000000,0x00000000}},	//   ивља, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x64a1313b,0x23640007,0x6ed4d9e5,0xceb81de6}},	//   _вата, binj_, _मजदु, нәй_, 
   {{0x23640007,0xf4540055,0x6b480254,0x61ec0162}},	//   cinj_, _jaḍā_, _pügm, ðilø, 
   {{0xcdc40137,0x00000000,0x00000000,0x00000000}},	//   دۇعۇ_, --, --, --, 
   {{0xb144010a,0x00000000,0x00000000,0x00000000}},	//   _шнел, --, --, --, 
   {{0xabb0035b,0x00000000,0x00000000,0x00000000}},	//   рагә, --, --, --, 
   {{0x6abc1a22,0x00000000,0x00000000,0x00000000}},	//   ्रेर, --, --, --, 
   {{0x25bc0552,0x00000000,0x00000000,0x00000000}},	//   _čulo_, --, --, --, 
   {{0x98c4f35c,0xe6c800dc,0x2364d347,0x00000000}},	//   исул, िर्ज, zinj_, --, 
   {{0x41d837c8,0x429801ec,0xdca4009b,0x00000000}},	// [1dad0] _यौनस, _ﺘﻭﺤﻲ_, _каћи, --, 
   {{0x8a18009d,0xb7840166,0x00000000,0x00000000}},	//   _зоос_, гәсе_, --, --, 
   {{0x23640331,0x57a5313c,0x00000000,0x00000000}},	//   vinj_, ршта, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe3240ad3,0x69c401b8,0xe9701f0d,0x00000000}},	//   _ཡོདཔ_, lpje, _منگھ, --, 
   {{0xd6a86788,0x69c401a4,0x674401a9,0x00000000}},	//   ردەم_, opje, _рэмз, --, 
   {{0xa2300724,0x23640023,0x96f8010b,0xabc40150}},	//   рьлә, rinj_, _шерт_, _ﺒﻨﻴﺎ, 
   {{0x236401a6,0x818814fb,0x5274007b,0x00000000}},	//   sinj_, رچاق_, جاهز, --, 
   {{0x43944ecc,0x23652b65,0xc3c4013d,0xd0940022}},	//   _баас, pinj_, _сөел, ишьы, 
   {{0xbdc801c0,0x2364036e,0xb478010f,0xdb240205}},	//   нгож_, qinj_, _אָבי, örüs, 
   {{0xa3cc1cd2,0x6804005f,0x69c401f5,0x61400150}},	//   वीर_, lījā, jpje, _پىشە, 
   {{0xab5803fa,0xbc18443f,0x00000000,0x00000000}},	//   spül, нігі_, --, --, 
   {{0x69c40d27,0x6d9c02b1,0xada403b2,0x680400e2}},	//   epje, _pūar, _sjúð, nījā, 
   {{0x6db80327,0x00000000,0x00000000,0x00000000}},	//   _iċan, --, --, --, 
   {{0x89b4023b,0x7f5c0561,0xce3403e6,0x00000000}},	//   иётш, èsqu, _نووک, --, 
   {{0x06cc39db,0x3f85313d,0xcdc4136b,0xc9546215}},	//   _লাগি, lolu_, _таъқ, атуы, 
   {{0x6d9c02b5,0x69c44fa5,0x6cc80150,0xf1bc0327}},	// [1dae0] _tūar, apje, _ﺒﺘﺠﻴ, ġġin_, 
   {{0xb6a41638,0x6804005f,0x6db80327,0xfa1c0b82}},	//   гизл, dījā, _mċan, _ትግርኛ, 
   {{0x3f840ffb,0x00000000,0x00000000,0x00000000}},	//   iolu_, --, --, --, 
   {{0x212c0076,0x37e400fd,0xe5e401d5,0xb4d40116}},	//   _nngh_, _йомг, ازلی, اغات, 
   {{0x3f85313e,0x23cc06ab,0x8834084c,0x00000000}},	//   kolu_, सीलद, _кэрц, --, 
   {{0x2bb41533,0x3f8408e5,0x00000000,0x00000000}},	//   _इंसा, jolu_, --, --, 
   {{0x3941313f,0x3f853140,0xc9b000d1,0x00000000}},	//   _koks_, dolu_, _ﻳﺎﻟﻐ, --, 
   {{0x39402ba4,0xe01c0210,0x680400cd,0x00000000}},	//   _joks_, बिंद_, bījā, --, 
   {{0x2738001f,0x98ac0024,0x39400153,0xb62c01ec}},	//   _በማህበ, ėlės_, _moks_, _ﺒﻕ_, 
   {{0x3f853141,0x39413142,0x69c53143,0x212c0fac}},	//   golu_, _loks_, ypje, _engh_, 
   {{0xc1801973,0xb644037e,0xce940395,0x00000000}},	//   _ڈیوٹ, _ｉｓ_, ранъ, --, 
   {{0x717000f7,0x3f840254,0x6abc8497,0x00000000}},	//   _دۇبا, aolu_, ्र्र, --, 
   {{0x3f853144,0x6b4800c5,0xc0e00023,0x80241291}},	//   bolu_, _hügi, ናኦም_, _پرنم, 
   {{0x3f8419f5,0x394001bf,0x96d806e3,0x00000000}},	//   colu_, _aoks_, यरफॉ, --, 
   {{0xa140005f,0xacb8000f,0xab5800a2,0x00000000}},	//   _šķir, rdûb, lpük, --, 
   {{0x1cb41b4b,0x69c4044e,0x2d8c01e1,0x00000000}},	//   _ཟུར_, rpje, _óge_, --, 
   {{0x69c53145,0x31040a28,0x637c019f,0x6b4801b8}},	// [1daf0] spje, व्यः_, rênz, _lügi, 
   {{0x69c53146,0x7db00133,0x6d4c0205,0xa610008e}},	//   ppje, _دڵیا, lkca, йззә, 
   {{0x39413147,0x6b8401fa,0x6b480254,0x3ab8011a}},	//   _foks_, mojg, _nügi, _במתנ, 
   {{0x6d4c00aa,0x6804005f,0x9dc00116,0x00000000}},	//   nkca, tījā, ﻨﺪﯨﺸ, --, 
   {{0x9fdc09bd,0xa3cd3148,0x3f8405d1,0xa2a40550}},	//   _বঙ্গ, वीं_, yolu_, टेन्, 
   {{0x03a53149,0x28d007b7,0x00000000,0x00000000}},	//   шило, तरवि, --, --, 
   {{0x7ae8002d,0x3214007b,0x00000000,0x00000000}},	//   _ôfte, ليود_, --, --, 
   {{0x3fe4828d,0x6d4c01f5,0x515401e0,0x3f85314a}},	//   ажив, jkca, йтыу, wolu_, 
   {{0x3f8473f4,0x6569314b,0xb27018ce,0x3165314c}},	//   tolu_, migh, йләш, _dmoz_, 
   {{0x6b48d93f,0x20d0001e,0x75e0063f,0x1ee479f8}},	//   _fügi, ải_, _ọzie, دودی_, 
   {{0x6449314d,0x821420ad,0x63a1314e,0xee340262}},	//   lygi, _خواص, mmnn, анэ_, 
   {{0x3f85314f,0x64480009,0x63a00200,0x00000000}},	//   solu_, oygi, lmnn, --, 
   {{0x60d93150,0x3f853151,0x6b480e78,0x64480072}},	//   maum, polu_, _zügi, nygi, 
   {{0x60d93152,0x3ea53153,0xbea53154,0x39400a85}},	//   laum, _килг, _калк, _soks_, 
   {{0x65681aef,0x6d9c00b0,0x394026bb,0xe9d408ca}},	//   kigh, _tūap, _poks_, икр_, 
   {{0x60d93155,0x8314025c,0x65693156,0x7c2000de}},	//   naum, _ཊིའུ_, jigh, _šoru, 
   {{0x65693157,0x39405b47,0xad180302,0x00000000}},	// [1db00] digh, _voks_, _יוקר, --, 
   {{0x60d93158,0x6568074d,0x394008cd,0x64493159}},	//   haum, eigh, _woks_, dygi, 
   {{0x65684b5a,0x394002d5,0xb8ec0c58,0xa2a40316}},	//   figh, _toks_, _ৰা_, टेम्, 
   {{0xe7ec0574,0x6568a745,0xf504020a,0x60d840b7}},	//   _चमचा_, gigh, рздо, jaum, 
   {{0x6b48007d,0x60d86dfb,0x1cb40327,0x6430007b}},	//   _sügi, daum, _ྟུན_, قروء, 
   {{0x6569315a,0x320801c6,0xa87401c4,0x00000000}},	//   aigh, вхин_, _төст_, --, 
   {{0x60d80618,0x6569315b,0x6494151e,0x366802a9}},	//   faum, bigh, лтәр_, _раво_, 
   {{0x6448002d,0xf1244d75,0x656801e4,0x60d9315c}},	//   bygi, рько, cigh, gaum, 
   {{0xdce4031c,0xb465315d,0x6b8401d5,0x00000000}},	//   _emiċ, _ткал, yojg, --, 
   {{0x9f5c026c,0x102800f7,0x8f54003b,0x00000000}},	//   ntuè_, _ۅتتۉ_, свої, --, 
   {{0x60d90d09,0xab58000d,0x00000000,0x00000000}},	//   baum, spük, --, --, 
   {{0x60d80263,0x7521315e,0x8e90001f,0xb0d8000d}},	//   caum, ndoz, _ማዕከሉ_, _यजिग, 
   {{0x2d6c00bc,0x7e6c002b,0xb28401af,0x00000000}},	//   třeb_, _śapt, _сыҡк, --, 
   {{0x6569315f,0x9b940014,0x6d4c007c,0xab843893}},	//   zigh, ٲلِت, skca, румк, 
   {{0x7c213160,0xae3400db,0x296400d8,0x6ce40153}},	//   _šort, _түнт_, ањав, _кіпе, 
   {{0x5d853161,0x00000000,0x00000000,0x00000000}},	//   _ولول, --, --, --, 
   {{0x65693162,0xe6c52374,0x64480072,0x00000000}},	// [1db10] vigh, لتاي, xygi, --, 
   {{0x6568057b,0x64480af9,0xd8740137,0x00000000}},	//   wigh, vygi, زاقب, --, 
   {{0x60d93163,0x644800a9,0x7f90022e,0xd9900150}},	//   yaum, wygi, _mаqо, _ﺒﻌﺩﻩ_, 
   {{0x64493164,0xeb9c00b5,0x60d8067c,0x38ac0124}},	//   tygi, stød_, xaum, _ẽre_, 
   {{0x442829ac,0x2fc40211,0x6f08003a,0xd49802d9}},	//   ía_, _ntog_, _obfc, һрә_, 
   {{0x64493165,0x85046e9a,0x60d93166,0x65693167}},	//   rygi, _گورن, waum, sigh, 
   {{0x60d93168,0x4428008f,0x2fc4003e,0x656822d0}},	//   taum, ŭa_, _atog_, pigh, 
   {{0x85053169,0x9a780375,0x6448003a,0x32280228}},	//   _دورن, יתוף_, pygi, اتوۋ_, 
   {{0x60d9316a,0x2fc401ab,0x6b480022,0x657800e4}},	//   raum, _ctog_, _hügu, _ijuh, 
   {{0x60d9316b,0x6db80327,0x2d58002e,0x2284013d}},	//   saum, _iċaj, _yëeg_, _куег, 
   {{0x60d9316c,0x9f5c0129,0x29080210,0x3da800cf}},	//   paum, ntué_, _obca_, лкоо_, 
   {{0x6f080175,0x2908010e,0xd1b8feab,0x7d5400d4}},	//   _ebfc, _nbca_, _ئالا_, стої, 
   {{0x213c0652,0x6e28257c,0x80cc28e0,0x80a40154}},	//   mjuh_, _erfb, _ध्ये, _গ্র্, 
   {{0x8024438b,0x29080fac,0x00000000,0x00000000}},	//   _پرچم, _abca_, --, --, 
   {{0xfbd13115,0x6578035b,0xfe44084c,0x5ea00014}},	//   _کتب_, _ojuh, _ынко, _گۅگل, 
   {{0xe8f47a16,0x29080334,0x213c1710,0xa96400f3}},	//   йлс_, _cbca_, njuh_, биса_, 
   {{0x66e800b0,0xed540375,0xacc40166,0x4918000d}},	// [1db20] kēkē, _לבקר_, _угыз_, _पसरो_, 
   {{0xc7641a59,0x6579316d,0xc92402f5,0x00000000}},	//   يالى, _ajuh, _যকৃত_, --, 
   {{0x80dc02a6,0x14c8034c,0x290803f0,0x6578007c}},	//   _যান্, لهای_, _fbca_, _bjuh, 
   {{0x752001a6,0xd9540244,0x00000000,0x00000000}},	//   udoz, _بۆرخ, --, --, 
   {{0x65786479,0x7521316e,0xeb9c0158,0x00000000}},	//   _djuh, rdoz, støe_, --, 
   {{0x657800e4,0x2fc401b9,0xa26c010c,0x67d001c6}},	//   _ejuh, _rtog_, _እንካን_, _хоёу, 
   {{0x9259316f,0x9f5c07ea,0x2fc401e3,0x49040243}},	//   райт_, ctué_, _stog_, ह्वो_, 
   {{0xe1ed3170,0x6578069c,0xb354c284,0x39513171}},	//   رسى_, _gjuh, _گیتا_, nkys_, 
   {{0x25bc0b91,0x65600221,0xa44001a9,0x39500064}},	//   _čuli_, ënhe, _ентд, ikys_, 
   {{0xdbd53172,0xb354af84,0x52740075,0xc1e001ec}},	//   _núñe, _دیتا_, _һуҗу, _ﺍﻹﺩﺍ, 
   {{0x38a002b5,0xab582897,0x00000000,0x00000000}},	//   _hōrī_, nqüe, --, --, 
   {{0x61413173,0x7afc02d0,0x321c0f91,0x4c940063}},	//   _неха, _acpt, _isty_, жимс, 
   {{0xd0102f84,0xa0640354,0x00000000,0x00000000}},	//   _آلت_, _лаца_, --, --, 
   {{0x2000054e,0x00000000,0x00000000,0x00000000}},	//   ăjit_, --, --, --, 
   {{0x9ee4143e,0x6e2802d0,0x00000000,0x00000000}},	//   _طفيل_, _urfb, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2d893174,0xab8400ee,0x65780427,0x57b53175}},	// [1db30] moce_, _гунк, _rjuh, збут, 
   {{0x2d893176,0x65780267,0xa098010f,0xdc3c011a}},	//   loce_, _sjuh, רימט, _תעזר, 
   {{0x7ae8002d,0x461426c6,0x00000000,0x00000000}},	//   _ôfta, توار, --, --, 
   {{0xdb253177,0x2d893178,0x39500363,0x9a8407d5}},	//   örös, noce_, ckys_, _хуьл, 
   {{0x321d3179,0x84240131,0x6b480112,0x06d00154}},	//   _asty_, تىشن, _fügt, াণবি, 
   {{0x82340b24,0x4904012c,0x13080212,0xa504215c}},	//   قربا, ह्रो_, йній_, _گىرە_, 
   {{0x213d317a,0xdce401a6,0x5afc008f,0x00000000}},	//   tjuh_, _smič, אלוצ, --, 
   {{0x6578009f,0xbfc43252,0x2d880010,0x00000000}},	//   _ujuh, обик, joce_, --, 
   {{0x321c0109,0x2d8800d8,0xf948008f,0x59c00073}},	//   _esty_, doce_, שעפֿ, _शंभर, 
   {{0x442d317b,0x63b80280,0x213c2112,0x00000000}},	//   _ire_, _iuun, sjuh_, --, 
   {{0x63b9317c,0x442d317d,0x3951317e,0x7afc0327}},	//   _huun, _hre_, ykys_, _rcpt, 
   {{0x63b9317f,0x442c43a5,0x38a002b5,0x2d893180}},	//   _kuun, _kre_, _hōrū_, goce_, 
   {{0x63b93181,0x1ee400f2,0x7c980395,0xd94400c7}},	//   _juun, _هوشی_, рънс_, ҧҵои, 
   {{0x63b93182,0x442d3183,0x1fa408db,0xd09401af}},	//   _muun, _mre_, _урег, _эшєы, 
   {{0x442c01ab,0x63b93184,0x2d88013a,0x18b40139}},	//   _lre_, _luun, boce_, зәгр, 
   {{0x2d893185,0x2ef00139,0x17c40124,0x7e7c002f}},	//   coce_, _езәр, зааҭ, ßspu, 
   {{0x442d3186,0x39513187,0x63b93188,0xfe4000dd}},	// [1db40] _nre_, rkys_, _nuun, _رکھی, 
   {{0x38a002b5,0x369413f3,0x7f400334,0x00000000}},	//   _rōrī_, ошес, njlq, --, 
   {{0x442c3d99,0x63b80393,0xfaa4cfc6,0x2cbc16a3}},	//   _are_, _auun, _фано, žude_, 
   {{0x442d3189,0x63b836b7,0x6b48002f,0x6d5c0153}},	//   _bre_, _buun, _fügs, _įpak, 
   {{0x442c0731,0x63b8022f,0xa2a40bc0,0x98940116}},	//   _cre_, _cuun, टेस्, _хунә, 
   {{0x442c07e4,0x63b9318a,0x69c0d02b,0x7995318b}},	//   _dre_, _duun, _énec, llyw, 
   {{0x442d318c,0xab5800ac,0x00000000,0x00000000}},	//   _ere_, mpüt, --, --, 
   {{0x7994a2e5,0x63b9318d,0x8e7c010f,0x00000000}},	//   nlyw, _fuun, naĝe, --, 
   {{0xb4e4b381,0x442c0f72,0x2d89318e,0x63b8581e}},	//   पणी_, _gre_, voce_, _guun, 
   {{0x98a00427,0xaf4801c6,0x799402d0,0x00000000}},	//   jdič_, рчиж_, hlyw, --, 
   {{0x2d89318f,0x387c013f,0x442c0010,0x8e7c01e4}},	//   toce_, _ɛtra_, _zre_, kaĝe, 
   {{0x63b93190,0x442d3191,0x8e7c0115,0x6ed40073}},	//   _yuun, _yre_, jaĝe, _मजकु, 
   {{0x2d893192,0x9f5c004e,0x442c0798,0x63b8058a}},	//   roce_, ctuï_, _xre_, _xuun, 
   {{0x2d88012c,0xa3cc0c4c,0x99980064,0x00000000}},	//   soce_, वीट_, kyrų_, --, 
   {{0x2bb41d15,0x00000000,0x00000000,0x00000000}},	//   _इंका, --, --, --, 
   {{0x4cd400bd,0x38ac0022,0xa92802dd,0x7994808f}},	//   _থাকু, _ẽra_, шіге_, glyw, 
   {{0x1cb40003,0x2b447c3f,0x00000000,0x00000000}},	// [1db50] _ཟུག_, _дэнг, --, --, 
   {{0x442c014c,0x63b93193,0x8af80640,0x44300216}},	//   _rre_, _ruun, _унос_, _čz_, 
   {{0x63b93194,0x442d3195,0x79940857,0x999800c0}},	//   _suun, _sre_, blyw, gyrų_, 
   {{0x442d3196,0x63b818a6,0xa92000d0,0x799402d0}},	//   _pre_, _puun, ážde, clyw, 
   {{0xdb04b9f0,0x63b80ba7,0x947400f2,0x6cc80150}},	//   _guió, _quun, ودها, _ﺒﺘﺄﻴ, 
   {{0x442d3197,0xb86400aa,0x63b80083,0x77b80375}},	//   _vre_, _راټو, _vuun, _למשח, 
   {{0x56953198,0xa3cc02ab,0x442c0175,0x63b89ad5}},	//   _жарт, वीज_, _wre_, _wuun, 
   {{0x442d3199,0x63b9319a,0x5184033a,0x00000000}},	//   _tre_, _tuun, муња, --, 
   {{0x442d319b,0x8e7c01e4,0x2d6c0118,0xefc401f4}},	//   _ure_, jaĝb, třen_, плыл_, 
   {{0x8e7c01e4,0xa24401e2,0x00000000,0x00000000}},	//   zaĝe, _ویشل_, --, --, 
   {{0x1cb40867,0x2274e0cb,0x8eb015bf,0xa2a42e04}},	//   _ཟུང_, _بلاگ_, پەيت, टेश्, 
   {{0x67080cb2,0xeb9400ee,0xee3400d4,0x00000000}},	//   स्तक_, җис_, їня_, --, 
   {{0x2d6c00bc,0xa3cc2cbb,0x8c00010b,0x8e7c00df}},	//   mřel_, वीच_, вҗыл, vaĝe, 
   {{0x3b080063,0x79951107,0x0b59319c,0xdb1c03b9}},	//   љево_, wlyw, орсы_, _üzüa, 
   {{0x7994035a,0x00000000,0x00000000,0x00000000}},	//   tlyw, --, --, --, 
   {{0xa9643ebf,0x9f5c03a0,0x249cd96c,0x6da000f5}},	//   писа_, ituí_, _ozum_, _пища, 
   {{0x1dd40c2e,0x7ae8002d,0x8e7c0115,0x7994127b}},	// [1db60] भीरत, _ôfto, raĝe, rlyw, 
   {{0xf771319d,0x8e7c010f,0x7994035a,0x3dc80210}},	//   راء_, saĝe, slyw, _ławy_, 
   {{0x7994127b,0x0ba800db,0xb38401e0,0x00000000}},	//   plyw, _بايى_, үлел, --, 
   {{0xb4e400a5,0xab5805d5,0x3ce003b2,0x00000000}},	//   पणे_, spüt, nakv_, --, 
   {{0x2d6c01ef,0xc6d42309,0x00000000,0x00000000}},	//   dřel_, ستەت, --, --, 
   {{0x670035e8,0x06b801d9,0xab58002f,0x9295319e}},	//   _लायक_, _ونُک_, lpür, малц, 
   {{0x3ce00e3c,0xa2a40d79,0x49400023,0x00000000}},	//   kakv_, टेल्, _ኣከባብ, --, 
   {{0xdb041709,0x00000000,0x00000000,0x00000000}},	//   _muiñ, --, --, --, 
   {{0xb4c80acd,0x456401d9,0xe8fc000f,0xd1b007d6}},	//   ोरी_, _تھلہ, _smûk_, _ییتک, 
   {{0x2d8000bc,0xc40801d9,0x8e7c01e4,0x00000000}},	//   čkem_, _گتہٕ_, vaĝb, --, 
   {{0x03a401d9,0xe0d800cc,0x00000000,0x00000000}},	//   _تۯوو_, _ধাৰন, --, --, 
   {{0x9cc800c7,0xe280030d,0x00000000,0x00000000}},	//   зыра_, _ялхи, --, --, 
   {{0xceb86788,0x3ae000b0,0x00000000,0x00000000}},	//   _мән_, kōpē_, --, --, 
   {{0xc0c8001f,0xe4540a7c,0xf4000356,0x205400df}},	//   በዋል_, ליכט_, muţă_, _ציגל_, 
   {{0xdb040005,0xda340064,0xf400054e,0x65a0000d}},	//   _cuiñ, неры, luţă_, lõhe, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf8b5319f,0x5c7400a7,0xf400054e,0x00000000}},	// [1db70] дөр_, _плът, nuţă_, --, 
   {{0x6f1931a0,0x80a8015b,0x1a68dc96,0x45d401f4}},	//   netc, ছুক্, _کیفی_, дожс, 
   {{0xdb0409c2,0x249c0210,0xab580254,0x00000000}},	//   _guiñ, _szum_, spüs, --, 
   {{0x6f1931a1,0x00000000,0x00000000,0x00000000}},	//   hetc, --, --, --, 
   {{0x6f1803ac,0x2d6c00bc,0x00000000,0x00000000}},	//   ketc, vřel_, --, --, 
   {{0x291819a2,0xe784055f,0x00000000,0x00000000}},	//   leqa_, _хумо, --, --, 
   {{0x9394086e,0x00000000,0x00000000,0x00000000}},	//   رجها, --, --, --, 
   {{0x672531a2,0x68fc0399,0x2918013c,0x3ea801e4}},	//   _hajj, ngqd, neqa_, _ŝato_, 
   {{0x672531a3,0x564802d3,0x425405d9,0x249c01d5}},	//   _kajj, ዘይክእ, _ڪنار, _uzum_, 
   {{0x672422a9,0x4ed40212,0x3f9000d0,0xfde80108}},	//   _jajj, нюют, ôzu_, одок_, 
   {{0x672531a4,0xf4080135,0x00000000,0x00000000}},	//   _majj, _གདོད_, --, --, 
   {{0xed5402bf,0xf4000356,0x672531a5,0x00000000}},	//   дою_, buţă_, _lajj, --, 
   {{0x2b9c019f,0x6f1931a6,0x29180113,0xf400054e}},	//   wîca_, betc, deqa_, cuţă_, 
   {{0x5eb400bd,0x1fa47a71,0x38ac0022,0xc1040451}},	//   _আজকে, _эрег, _ẽro_, _روڪي, 
   {{0xdea001e4,0x3ce005da,0xdb043a6c,0x2cbc107d}},	//   _konƭ, pakv_, _quiñ, žuda_, 
   {{0x67240194,0x2918014b,0xbf1c0073,0x499400d4}},	//   _aajj, geqa_, _बघुन_, ешут, 
   {{0x672531a7,0x42a0001f,0xac800724,0x8e7c00df}},	// [1db80] _bajj, _ኃጢአት_, _игъл, maĝa, 
   {{0x6724102c,0x9f5d31a8,0xab580112,0x8e7c010f}},	//   _cajj, ntuà_, spür, laĝa, 
   {{0x672531a9,0x2d6c00bc,0xcd540023,0x00000000}},	//   _dajj, dřej_, _ዝከኣለ, --, 
   {{0xb4c804fa,0x8e7c0115,0xf8d0000d,0x00000000}},	//   ोरे_, naĝa, _तभिय, --, 
   {{0x672531aa,0xbf1c0490,0x372000c7,0x87f801c6}},	//   _fajj, _बघून_, _иҿаҳ, _нэрт_, 
   {{0x67240337,0x201c007f,0x3668030d,0x00000000}},	//   _gajj, dwui_, _даго_, --, 
   {{0x6f1800f3,0xf1a80fb4,0x65c00006,0xb1a406ed}},	//   vetc, يابه_, _абса, мшик, 
   {{0x6724a86f,0xacb8000f,0x8e7c008f,0x622000d1}},	//   _zajj, rdûk, jaĝa, ئىيل, 
   {{0x730531ab,0x672531ac,0x69ac01f9,0x00000000}},	//   _опаз, _yajj, ंगती, --, 
   {{0xb3540502,0xeb9c022c,0xf4000311,0x67240009}},	//   _زیبا_, gtøl_, ruţă_, _xajj, 
   {{0x6f1931ad,0x2918011f,0xf4000356,0xe45c010b}},	//   retc, yeqa_, suţă_, _ýör_, 
   {{0xc0a90fdc,0x6f1802d0,0x2020023a,0x8e7c01e4}},	//   _کامل_, setc, äriä_, gaĝa, 
   {{0x5c243306,0xe0401f91,0xdf000014,0x92e000cc}},	//   نَّم, _инци, ر٘ێپ, থলী_, 
   {{0x291801f0,0x9f5c05d5,0x00000000,0x00000000}},	//   weqa_, ctuà_, --, --, 
   {{0xd6e4015b,0x6a60022e,0x672531ae,0x9aa4009f}},	//   মলায, _nеft, _rajj, َمُو, 
   {{0x672531af,0x6db8002e,0xb4c81777,0x00000000}},	//   _sajj, _eŋac, ोरो_, --, 
   {{0x67241f21,0x473531b0,0x481531b1,0x6d5c00ac}},	// [1db90] _pajj, ннас, эмас, _ilqa, 
   {{0x2918014b,0x672531b2,0x00000000,0x00000000}},	//   seqa_, _qajj, --, --, 
   {{0xfad4025f,0x201c043b,0xdbcc01e1,0x29180784}},	//   _אותך_, zwui_, _fòót, peqa_, 
   {{0x67240a4d,0x29180309,0xaa380023,0x00000000}},	//   _wajj, qeqa_, _ኣመሓላ, --, 
   {{0x672531b3,0x1cb4025c,0xf990010f,0x00000000}},	//   _tajj, _ཟུབ_, _תרכ_, --, 
   {{0xa6100166,0x8e7c00df,0xbf1c0073,0xb7d8011a}},	//   _изгә, zaĝa, _बघेन_, _מקשי, 
   {{0x41b531b4,0x6d5c022f,0xdb2400e5,0x00000000}},	//   нсит, _olqa, örés, --, 
   {{0x201c007f,0x657400e5,0x00000000,0x00000000}},	//   twui_, _کیچڑ_, --, --, 
   {{0x9f5c508d,0xf07401d3,0x8e7c010f,0x00000000}},	//   ttuà_, ٹیوں_, vaĝa, --, 
   {{0x6d5d31b5,0x24d40154,0x00000000,0x00000000}},	//   _alqa, _হাটহ, --, --, 
   {{0x8e7c0115,0x5238007b,0xeb9c0162,0xe7f003ce}},	//   taĝa, _يسمح_, rtøl_, ेंडा_, 
   {{0x409452c8,0x2604367a,0xeb9c8f30,0x00000000}},	//   _كلار, _हमनी_, støl_, --, 
   {{0x2eec5045,0x8e7c010f,0xee2d08ab,0x6d5c00c0}},	//   _fdff_, raĝa, _өн_, _įpat, 
   {{0xdb1c76bc,0xa26c0020,0x6d5c014f,0x68ec0142}},	//   _özün, _እንኳን_, _elqa, _adcd, 
   {{0x8e7c01e4,0x4a74013d,0x7e78010f,0xca7401f4}},	//   paĝa, вытт, _מאַז, вуты, 
   {{0xfaa4016c,0x68ec0175,0xeb9c005c,0x00000000}},	//   даҳо, _cdcd, ntøj_, --, 
   {{0xe8f405f5,0xa8840334,0xf1b0010f,0xa9645348}},	// [1dba0] элт_, ейта_, רסן_, хита_, 
   {{0x6db80327,0x3a240845,0xb4c80c00,0x2ca4010b}},	//   _iċar, _змог, ोर्_, _якып_, 
   {{0xaad8025f,0xeb9c00b5,0xdbcc0ca8,0x159801ec}},	//   _מחיר, ktøj_, _tòót, _ﺘﻌﺭﺽ_, 
   {{0xf3e4005b,0x34850fbf,0x00000000,0x00000000}},	//   еждо, нгег, --, --, 
   {{0x3d10c454,0x64a00323,0xeb9c00b5,0xc8b4013d}},	//   ध्ये_, гаца, dtøj_, _асры, 
   {{0x1cb40156,0x2d6c0118,0x00000000,0x00000000}},	//   _ཟུན_, třek_, --, --, 
   {{0xa2241f5a,0x22f401d9,0x229001d5,0xe614117e}},	//   ежја_, ر٘ٹھ_, лишя, _пдр_, 
   {{0x92e00154,0xeb9c005c,0x2eec007c,0x366807a5}},	//   থলে_, gtøj_, _sdff_, _даҳо_, 
   {{0x2d58002e,0xd05c0134,0x2518008f,0xd430003b}},	//   _dëel_, ɛyɛd, _צומא, _мiсц, 
   {{0xceb87400,0x00000000,0x00000000,0x00000000}},	//   мәй_, --, --, --, 
   {{0x26c4098d,0x6db8031c,0x7bc40309,0x2eec0064}},	//   žnog_, _aċar, eqku, _vdff_, 
   {{0x705004d3,0xaf5000fd,0x00000000,0x00000000}},	//   _مۆبا, _әнкә, --, --, 
   {{0xdfcc0451,0x00000000,0x00000000,0x00000000}},	//   _هين_, --, --, --, 
   {{0x5b250e1c,0x68ec010a,0xa2a446fb,0xa6e40051}},	//   льса, _sdcd, टेक्, _chừ, 
   {{0xeb9c0579,0x8e7c010f,0x00000000,0x00000000}},	//   ltøk_, maĝo, --, --, 
   {{0x8e7c008f,0xd9280276,0x5e980375,0x199402e8}},	//   laĝo, нцул_, _מבוק, гася, 
   {{0xeb9c06ea,0x00000000,0x00000000,0x00000000}},	// [1dbb0] ntøk_, --, --, --, 
   {{0x6db80327,0x8e7c00df,0x4a5531b6,0xdbcc01e1}},	//   _iċaq, naĝo, _акос, _tòòt, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x885801c0,0x36a000d1,0xceb800c0,0x00000000}},	//   _жимс_, شەقق, ldęs_, --, 
   {{0x6db8031c,0xc2c531b7,0xc878415b,0xd75800d1}},	//   _jċaq, نيشي, _äş_, بلەت_, 
   {{0x6db8025c,0xceb80024,0x8e7c008f,0x00000000}},	//   _mċaq, ndęs_, jaĝo, --, 
   {{0xd68531b8,0xeb9c005c,0xceb80064,0x00000000}},	//   _бутп, ttøj_, idęs_, --, 
   {{0x56942425,0x7bc40113,0x00000000,0x00000000}},	//   _саст, yqku, --, --, 
   {{0x7ed400d6,0xeb9c4e95,0x29c40208,0xceb80064}},	//   кінч, rtøj_, _lõa_, kdęs_, 
   {{0xeb9c00b5,0x8e7c01e4,0x00000000,0x00000000}},	//   støj_, gaĝo, --, --, 
   {{0xfe701867,0x7bc40113,0x6d5c0024,0x00000000}},	//   شدد_, wqku, _įpar, --, 
   {{0x6b8803b2,0x00000000,0x00000000,0x00000000}},	//   _íggj, --, --, --, 
   {{0x644d31b9,0x7bc40113,0x200800db,0xff24014b}},	//   _àcid, uqku, àcid_, _амло, 
   {{0xa9200419,0xbdf8009a,0x00000000,0x00000000}},	//   ážne, _قربا_, --, --, 
   {{0x0ce01c82,0x1cb4025c,0xf2d0010f,0xb8642b9f}},	//   _ভাৰত, _ཟུམ_, שעל_, ھارو, 
   {{0xb8648688,0x00000000,0x00000000,0x00000000}},	//   پارو, --, --, --, 
   {{0x37040137,0x7b3c00e4,0xa6e40208,0xceb80064}},	// [1dbc0] кпаг, g̃uí, _thừ, bdęs_, 
   {{0xd910f2af,0xfaa4004e,0x65a000e4,0x00000000}},	//   _گیر_, _үшүн, võha, --, 
   {{0xf9840166,0x7d1400b5,0xf5080798,0x00000000}},	//   _агно, _kbys, днел_, --, 
   {{0xd9105457,0x8e7c008f,0x7c340200,0x28c40117}},	//   _دیر_, zaĝo, _kryr, _ашёҳ, 
   {{0x7d140023,0xceb8002d,0x00000000,0x00000000}},	//   _mbys, ndęr_, --, --, 
   {{0xe3ac5706,0xdb2400db,0x27ec0129,0xe2f000c7}},	//   يرو_, ürèt, âgne_, азшь, 
   {{0xf50531ba,0xe640104e,0x29c40208,0x00000000}},	//   _изво, _керп, _xõa_, --, 
   {{0x7c342ae5,0x418457aa,0x65a00037,0x68040171}},	//   _oryr, лтығ, lõhn, būjā, 
   {{0x7ae8002d,0x8e7c00df,0x859000f2,0x24041188}},	//   _ôftw, taĝo, _اینص, _инти_, 
   {{0x7d14012c,0x9f5002f6,0x23a40131,0xd854002b}},	//   _abys, ивыч, _авуп_, _iḍā_, 
   {{0x6d540227,0xd7101c82,0x8e7c010f,0xeb9c0174}},	//   _ŋyaq, _হোৱা_, raĝo, støk_, 
   {{0x8e7c00c8,0x7c3401bf,0x2d6c013a,0x00000000}},	//   saĝo, _bryr, hřev_, --, 
   {{0x8e7c010f,0x78580171,0x00000000,0x00000000}},	//   paĝo, _jāvā, --, --, 
   {{0x69c001ed,0x7d140142,0x78580055,0x00000000}},	//   _ének, _ebys, _māvā, --, 
   {{0xda7931bb,0x7c340368,0x7af809f3,0x661800f3}},	//   вят_, _eryr, ótta, _ćuko, 
   {{0x9964d728,0xa2a401ad,0x7c340240,0xdd980022}},	//   атул, टेट्, _fryr, _ишы_, 
   {{0x7858002b,0x00000000,0x00000000,0x00000000}},	// [1dbd0] _nāvā, --, --, --, 
   {{0x3ea800df,0x7d140d2e,0xae1401f9,0x00000000}},	//   _ŝati_, _zbys, _तहान_, --, 
   {{0x4ad8012c,0x04c401e1,0x95c8011c,0x00000000}},	//   _ब्यव, _èèkù_, вуча_, --, 
   {{0x5694004e,0xe0dc0208,0xa8a40024,0x00000000}},	//   шахт, ưòi_, _аргк, --, 
   {{0x43740228,0x7858002b,0x7648143a,0x00000000}},	//   лукт, _cāvā, øfyr, --, 
   {{0x420931bc,0x628400e4,0x78580a2f,0x8e2c022e}},	//   енко_, _ÿjok, _dāvā, yadа_, 
   {{0x320c0036,0x96f80063,0x00000000,0x00000000}},	//   gtfy_, _јест_, --, --, 
   {{0x32140214,0x630000d1,0x7fd800d8,0xc6a4022e}},	//   اييد_, _چۈشل, нфот_, _арғи, 
   {{0xb270891e,0x3ea00419,0xc1cc02dd,0x00000000}},	//   иләш, _šht_, _ﻗﺎﺩﺍ, --, 
   {{0x94a8010a,0x1ee4114f,0x00000000,0x00000000}},	//   _ртса_, خودی_, --, --, 
   {{0x9e7c0023,0xf4000356,0xdce4012d,0x425400e5}},	//   _ዓቕምና_, arţă_, _zmię, _حنار, 
   {{0x92580f06,0x7858002b,0x00000000,0x00000000}},	//   _шахт_, _yāvā, --, --, 
   {{0x3af40815,0xa6b80154,0x00000000,0x00000000}},	//   лявс, েরিয়, --, --, 
   {{0x60d931bd,0x3ea407d6,0x98a001fa,0xdfcd31be}},	//   lbum, _йилг, ldić_, _هيچ_, 
   {{0xc1cc005e,0x00000000,0x00000000,0x00000000}},	//   _ﻗﺎﺯﺍ, --, --, --, 
   {{0x98a0098d,0xb7d80a2c,0x2c1003d4,0x4ea40e92}},	//   ndić_, فورا_, িয়েই_, _трча, 
   {{0x59c06d65,0x2d8000f3,0x7784005b,0xe9a03947}},	// [1dbe0] _शंकर, čket_, глаз, сатп, 
   {{0x78a401ef,0x00000000,0x00000000,0x00000000}},	//   _vzkv, --, --, --, 
   {{0x60d8003e,0x78580055,0x00000000,0x00000000}},	//   kbum, _sāvā, --, --, 
   {{0x98a01505,0xb464cc53,0x7d04020c,0x60d801bf}},	//   jdić_, лкел, ngks, jbum, 
   {{0xc1cc3ce1,0x33f458a8,0xd6e80349,0x00000000}},	//   _ﻗﺎﺭﺍ, учес, _পাঠয, --, 
   {{0x785931bf,0x60d8003a,0x79940857,0x00000000}},	//   _vāvā, ebum, loyw, --, 
   {{0x64940184,0xa7980375,0x2c6801e1,0x234410e0}},	//   ктәр_, _נשלח, _kòdé_, الىپ_, 
   {{0x98a001a6,0xcfe800f1,0x799403ac,0x7858002b}},	//   gdić_, نځته_, noyw, _tāvā, 
   {{0xa3c84425,0x752001f7,0x64a131c0,0x00000000}},	//   _रूप_, meoz, _гата, --, 
   {{0x799400f1,0x00000000,0x00000000,0x00000000}},	//   hoyw, --, --, --, 
   {{0x59b40bae,0x98a001fa,0x60d931c1,0xf1f80244}},	//   ंगार, bdić_, bbum, _سعات_, 
   {{0xafe40323,0x79940857,0x00000000,0x00000000}},	//   _бодл, joyw, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x670004aa,0x00000000,0x00000000,0x00000000}},	//   _लाइक_, --, --, --, 
   {{0xab580120,0x2c6801e1,0x7520009a,0x0cd400db}},	//   nqüi, _bòdé_, keoz, _койю, 
   {{0x6f080332,0x00000000,0x00000000,0x00000000}},	//   _hcfc, --, --, --, 
   {{0xb6040552,0x9f5c0158,0xd9a80395,0x00000000}},	// [1dbf0] _lišć, stuå_, уърд_, --, 
   {{0x2fc41c06,0x6e2801fa,0x98a00e3c,0x8e7c01e4}},	//   _muog_, _ksfb, zdić_, jaĝk, 
   {{0x3d1000dc,0x9f4931c2,0xb5f001ec,0x00000000}},	//   ध्वे_, écé_, жүсі, --, 
   {{0xd5b801c6,0x00000000,0x00000000,0x00000000}},	//   гсч_, --, --, --, 
   {{0x0444665a,0xe784442d,0xe97000e5,0x00000000}},	//   релн, _буво, _ننگھ, --, 
   {{0xb6040b94,0x0708aaab,0x932400d1,0xd3d800ae}},	//   _bišć, _جيسي_, مرىن, ابنا_, 
   {{0x60d800ca,0x6b280023,0xa23004b4,0x00000000}},	//   tbum, _ብዝተኻ, сьлә, --, 
   {{0xaca001e1,0x850400f2,0xdb1c00e5,0x00000000}},	//   _ajọf, _خورن, _özön, --, 
   {{0xff2531c3,0x60d931c4,0x98a0041a,0xc3c40166}},	//   ампо, rbum, rdić_, _төел, 
   {{0xd498fda6,0x8144072d,0xc83c0023,0x4ab401f9}},	//   _срс_, انکن, _ኣጸሓሕ, ंधाव, 
   {{0x3ea4006c,0xcfa80a2c,0xbea531c5,0x290837ca}},	//   ринг, دايم_, ранк, _occa_, 
   {{0x518531c6,0xbae0009e,0x25bc054e,0x290801e7}},	//   _луча, _বাইছ, _jiul_, _ncca_, 
   {{0xdc74044e,0xa3c831a0,0x6f080334,0x59b401ad}},	//   _ብኸመይ_, _रूम_, _fcfc, ंगसर, 
   {{0x290931c7,0x212c047e,0x3ea801e4,0x00000000}},	//   _acca_, _hagh_, _ŝatu_, --, 
   {{0x2d8820ef,0x752002e3,0xb9740261,0x00000000}},	//   ébec_, yeoz, аѓањ, --, 
   {{0x212caa66,0xe8f400d8,0x8e7c01e4,0x249c0205}},	//   _jagh_, илс_, zaĝk, _oyum_, 
  
   {{0x212c02a4,0x249d31c8,0x7520037e,0xfce80092}},	// [1dc00] _magh_, _nyum_, veoz, ጅንግ_, 
   {{0x13cc00bd,0x7bd4391b,0x7b7401ed,0x212d31c9}},	//   রীড়, _ityu, _خطبا, _lagh_, 
   {{0x8b647cbc,0x762531ca,0x249c003e,0xf6240415}},	//   _دايم, рмез, _ayum_, рдео, 
   {{0x212d31cb,0x25bc01ab,0x260400af,0x79940784}},	//   _nagh_, _ciul_, _हमरी_, qoyw, 
   {{0x3a380b23,0x7520c1b8,0x240531cc,0x39400f85}},	//   _hrpp_, reoz, инци_, _inks_, 
   {{0x212c062c,0x2fc404cc,0xeb9c12ed,0x00000000}},	//   _aagh_, _ruog_, støv_, --, 
   {{0x25bc084c,0x212c67de,0xe1f44cf3,0x7f9c0129}},	//   _fiul_, _bagh_, ңгә_, nèqu, 
   {{0xb60405be,0x25bc05d5,0x7bd531cd,0x212c00ad}},	//   _višć, _giul_, _otyu, _cagh_, 
   {{0x7f9d31ce,0x212c0731,0x8e7c00df,0x00000000}},	//   hèqu, _dagh_, maĝi, --, 
   {{0x20081daa,0x212c062c,0x4fc40228,0x00000000}},	//   àcia_, _eagh_, لەچە, --, 
   {{0x7bd531cf,0xeda4036b,0xee840166,0x349401e0}},	//   _atyu, ишмо, рыпо, _саҡр, 
   {{0x212c1368,0x8e7c0115,0xaf500023,0x00000000}},	//   _gagh_, naĝi, _ዝፈላለ, --, 
   {{0x80dc03f4,0xdda80323,0x249c0218,0xa0640395}},	//   _যাচ্, ртэл_, _xyum_, _каца_, 
   {{0x31640165,0x271400bc,0x39400064,0x00000000}},	//   _hloz_, _mění_, _anks_, --, 
   {{0x316531d0,0x7bd531d1,0x212cbaa4,0x1a7806a6}},	//   _kloz_, _etyu, _yagh_, абры_, 
   {{0x7bd400b5,0xa6443c5b,0x290800b5,0x8e7c008f}},	//   _ftyu, یخان, _qcca_, jaĝi, 
   {{0x9cc00dd4,0x2714013a,0xa3c801f9,0x00000000}},	// [1dc10] _ཚུགས, _nění_, _रूढ_, --, 
   {{0xd7741b06,0x2908014b,0x3a380334,0x25bc0332}},	//   يالع, _wcca_, _frpp_, _siul_, 
   {{0x09940798,0xa5880116,0x00000000,0x00000000}},	//   _ганџ, پئاق_, --, --, 
   {{0x6d4c0369,0x7ae8000f,0x69d401c4,0x8e7c010f}},	//   njca, _ôftr, _itxe, gaĝi, 
   {{0x5884c851,0x212d31d2,0x7bc0021c,0xbd0000e8}},	//   _дыра, _ragh_, _éout, _ñéen, 
   {{0x212c047e,0x271400bc,0x48f000bc,0x12c46c68}},	//   _sagh_, _dění_, ेलको_, يتىپ, 
   {{0x212c0842,0x93240633,0x00000000,0x00000000}},	//   _pagh_, زرون, --, --, 
   {{0x212c016d,0x29f001a6,0x555800c0,0x00000000}},	//   _qagh_, ića_, _кася_, --, 
   {{0x0fe8005e,0x656800c6,0xd8400122,0x249c05d1}},	//   алық_, mhgh, _účty_, _uyum_, 
   {{0x6da40184,0x212c047e,0x6568014f,0x00000000}},	//   ҙҙың_, _wagh_, lhgh, --, 
   {{0x69d40070,0x533531d3,0xbd4408f0,0x212d31d4}},	//   _ntxe, _фехт, مندي, _tagh_, 
   {{0x442d31d5,0x3164030a,0x3a380789,0x63a00194}},	//   _kse_, _gloz_, _rrpp_, llnn, 
   {{0x69d4009d,0x64480369,0x65680076,0x00000000}},	//   _atxe, nxgi, ihgh, --, 
   {{0x1dcc2017,0x6d480d29,0x8f80005e,0xb47800c8}},	//   _संपत, _ògan, _оқыл, אָלי, 
   {{0xfaa4016c,0xfce4014b,0x00000000,0x00000000}},	//   саво, _лойо, --, --, 
   {{0x442d31d6,0x6a80009d,0x00000000,0x00000000}},	//   _ose_, члса, --, --, 
   {{0x69d40323,0x442d31d7,0x7f9c07ea,0x7bd401e2}},	// [1dc20] _etxe, _nse_, sèqu, _utyu, 
   {{0x6b840175,0xa9240171,0xa3c8012d,0x5fdc0a8a}},	//   cnjg, _apžē, रआन_, पीएल, 
   {{0x442d31d8,0xf988e1e1,0xd1f8001f,0x8e7c01e4}},	//   _ase_, _مندي_, ለከተ_, taĝi, 
   {{0x7aec01d9,0x394001e2,0xe4e002bf,0xdb24036b}},	//   labt, _unks_, пішн, _اوگی, 
   {{0x442d31d9,0xd1f800b7,0x8e7c010f,0x2508085b}},	//   _cse_, ለየት_, raĝi, ارمی_, 
   {{0x69c002e8,0x7aed31da,0x442d31db,0xd37016ac}},	//   _ènec, nabt, _dse_, بهت_, 
   {{0x442d31dc,0x8e7c0115,0x656931dd,0x27b00139}},	//   _ese_, paĝi, bhgh, _хәтс, 
   {{0xf124090b,0x442d31de,0x4fd531df,0xf1a83669}},	//   сько, _fse_, ожит, داته_, 
   {{0x442cf558,0xe0cc2756,0xb46531e0,0x7aec01bf}},	//   _gse_, رزي_, _укал, kabt, 
   {{0x160c367a,0x777c0bc9,0x7aed31e1,0xe454009b}},	//   _हमार_, nipx, jabt, _ужу_, 
   {{0xeb9c6ab9,0x7aed31e2,0xdce40327,0x442d31e3}},	//   ktør_, dabt, _gliċ, _zse_, 
   {{0x31640216,0xd1b00244,0x00000000,0x00000000}},	//   _uloz_, _تیبک, --, --, 
   {{0x765d31e4,0x777c0227,0xd6c00154,0x00000000}},	//   hypy, kipx, েরিয, --, 
   {{0x7aed31e5,0x765c00e4,0x921c0037,0x00000000}},	//   gabt, kypy, _महाड़_, --, 
   {{0x5a44ede6,0x765c0022,0x1dcc00cd,0x9f78123b}},	//   пэта, jypy, _संयत, _תנוח, 
   {{0xd5a531e6,0x5644001f,0x4ad800dc,0x65a00037}},	//   _سہ_, _የሚያበ, _ब्रव, rõhk, 
   {{0x7aec0050,0x47d400c6,0x65a00254,0x00000000}},	// [1dc30] babt, زيار, sõhk, --, 
   {{0x442d31e7,0x7aec0548,0x1dcc07b6,0xeb9c03b2}},	//   _rse_, cabt, _संमत, drøg_, 
   {{0x442d31e8,0x656814d0,0x63a00122,0xa2c400cd}},	//   _sse_, thgh, vlnn, ाशस्, 
   {{0x442c069c,0x00000000,0x00000000,0x00000000}},	//   _pse_, --, --, --, 
   {{0x9a780020,0x02c405f5,0x442c00d8,0x8e7c0115}},	//   _የሆነው_, ойло, _qse_, maĝu, 
   {{0x442c4859,0x0744004b,0xf318010b,0x00000000}},	//   _vse_, _بنسټ, инчә_, --, 
   {{0x442c009a,0x74a8013d,0xe7f0012d,0x00000000}},	//   _wse_, лсәң_, ेंका_, --, 
   {{0x442cf6bc,0x00c8b38e,0xeb9c00b5,0x8e7c0115}},	//   _tse_, шлик_, lrød_, naĝu, 
   {{0x442c025f,0x65780eb4,0x7aec022e,0x00000000}},	//   _use_, _imuh, yabt, --, 
   {{0x2d8800dd,0x8e7c0124,0x7aec0009,0xeb9c072b}},	//   ében_, haĝu, xabt, nrød_, 
   {{0x8e7c0115,0x00000000,0x00000000,0x00000000}},	//   kaĝu, --, --, --, 
   {{0x8e7c00df,0x7aec0067,0x00000000,0x00000000}},	//   jaĝu, wabt, --, --, 
   {{0x777c0bc9,0xd1b800db,0xbc1802dd,0x7c381c52}},	//   yipx, _االا_, шіні_, ātro, 
   {{0xdce40010,0x2fd40345,0x3b082096,0x00000000}},	//   _ilič, _بوود_, јево_, --, 
   {{0xa3c81533,0x7aec01d9,0x657931e9,0xeb9d31ea}},	//   _रूस_, rabt, _omuh, ttør_, 
   {{0x7aecbf39,0xdce4b820,0x777c0054,0x1ea40451}},	//   sabt, _klič, wipx, _پاڙي_, 
   {{0x777c0bc9,0xeb9c00ed,0xa96431de,0x3ff8008f}},	// [1dc40] tipx, rtør_, цита_, יפּע, 
   {{0x65788aa7,0x7aed31eb,0x490005f5,0xeb9c365a}},	//   _amuh, qabt, _үүрг, grød_, 
   {{0x777c0054,0x14c804fb,0x00000000,0x00000000}},	//   ripx, مهای_, --, --, 
   {{0x52880184,0x777c2e95,0xdce408a4,0xeb9c005c}},	//   ҡҡан_, sipx, _olič, trøg_, 
   {{0x777c0054,0xeb9c1088,0x200800db,0xf98800ec}},	//   pipx, brød_, àcil_, _منگي_, 
   {{0x69c131ec,0x65784e2b,0x636c00b5,0x3950062c}},	//   _éner, _emuh, _lønf, ljys_, 
   {{0xdce401fa,0xe1ed31ed,0x925931ee,0x00000000}},	//   _alič, نسي_, сайт_, --, 
   {{0xa50531ef,0x758001b9,0x3950062c,0x00000000}},	//   _меса_, _کیچم, njys_, --, 
   {{0xe5a029be,0xb4e4121d,0x28bc00cd,0x00000000}},	//   _цити, फरी_, ्शयि, --, 
   {{0xdea00198,0x8e7c01e4,0x00000000,0x00000000}},	//   _hanƙ, zaĝu, --, --, 
   {{0xe8a4690c,0xdce4a08d,0x636c005c,0x53c801ad}},	//   _खर्च, _amiđ, _bønf, िआवश, 
   {{0xd1302c26,0x4c94004e,0x00000000,0x00000000}},	//   _سمت_, зимс, --, --, 
   {{0x395000ad,0x8e7c00df,0x00000000,0x00000000}},	//   djys_, vaĝu, --, --, 
   {{0xdea003f9,0xdf34007b,0x7bb00022,0x00000000}},	//   _lanƙ, _وكنت_, нҩыу, --, 
   {{0xda3531f0,0xdce4013a,0x00000000,0x00000000}},	//   меры, _zlič, --, --, 
   {{0x4c9531f1,0x65a000c5,0x290c0793,0x26c40030}},	//   _нийс, põhi, üga_, ľnom_, 
   {{0xc6f80408,0x2d580036,0x8e7c00df,0xeb9c01bf}},	// [1dc50] йнах_, _wëes_, raĝu, trød_, 
   {{0xb90078bf,0x2d880010,0x8e7c01e4,0x57b400d4}},	//   _न्_, lnce_, saĝu, дбут, 
   {{0xdea00198,0x8e7c00e4,0xfa1800eb,0x00000000}},	//   _banƙ, paĝu, ডিউল_, --, 
   {{0xa6e000bd,0x8e7c0115,0xeb9c0fac,0x2d880332}},	//   _পাওয়, laĝs, srød_, nnce_, 
   {{0xdea002a8,0x2d88007b,0xcaac00eb,0x00000000}},	//   _danƙ, ince_, _খলিফ, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdce404b9,0x7af81873,0xb7c40589,0x96f931f2}},	//   _slič, ótti, _gaãº, _фест_, 
   {{0x657931f3,0xdce4bc4a,0x04c821e7,0x00000000}},	//   _umuh, _plič, _طوطي_, --, 
   {{0x443931f4,0x7ff4007b,0x00000000,0x00000000}},	//   _és_, أسبا, --, --, 
   {{0x2d8890f3,0x8e7c01e4,0x8fb400f1,0x00000000}},	//   ence_, jaĝs, وليږ, --, 
   {{0x80a4a268,0xd24c01d9,0x39500076,0x3cc80395}},	//   _کمشن, _نۆو_, yjys_, йлно_, 
   {{0x7ff400c6,0x3234011a,0x00000000,0x00000000}},	//   _فستا, _מטען_, --, --, 
   {{0xdce417a3,0xfc480030,0x23c800cd,0xd13801a9}},	//   _ulič, _opíš_, ादिद, _фхх_, 
   {{0x2d8931f5,0x26c40989,0xd9b40a8a,0x00000000}},	//   ance_, žnoj_, ंग्ट, --, 
   {{0xaa4131f6,0x65a00254,0x00000000,0x00000000}},	//   нерл, lõhu, --, --, 
   {{0x394426ce,0x23c800cd,0x00000000,0x00000000}},	//   ños_, ादाद, --, --, 
   {{0x3b080640,0xa3c801ad,0xfc3000c6,0x636c01bf}},	// [1dc60] _лепо_, _रूल_, _أحب_, _gøng, 
   {{0xdea00198,0x3864031c,0x00000000,0x00000000}},	//   _sanƙ, ġor_, --, --, 
   {{0x7e6003ac,0x38640114,0x66e0016c,0xfaa4b6ac}},	//   nylp, šor_, хоха, _хано, 
   {{0xe69131f7,0x661800f3,0x636c353e,0x65a0000d}},	//   رلند, _ćukt, _lønd, kõhu, 
   {{0xe800006d,0x7e6002d0,0x00000000,0x00000000}},	//   _लिया_, hylp, --, --, 
   {{0x7e600108,0x00000000,0x00000000,0x00000000}},	//   kylp, --, --, --, 
   {{0xdea00198,0x2d8931f8,0x00000000,0x00000000}},	//   _tanƙ, ynce_, --, --, 
   {{0xb3c80a8f,0x66000118,0xd01007d6,0x78a402d2}},	//   _глаз_, ánke, نلب_, _kykv, 
   {{0x160402e5,0x636c2147,0x8e7c01e4,0xb4640006}},	//   शंकर_, _bønd, jaĝr, _экал, 
   {{0x7e600385,0xec140daf,0x636c01bf,0x1f703b8f}},	//   fylp, үенә_, _røng, елья, 
   {{0xb22521d9,0x23240107,0x59ac01f9,0x00000000}},	//   _хмел, _хохи_, चतार, --, 
   {{0x2d880493,0xacb8000f,0x935801d5,0x5d540395}},	//   unce_, nfûg, _урғу_, екют, 
   {{0x403000c7,0x78a40efa,0x00000000,0x00000000}},	//   _аҵыс, _nykv, --, --, 
   {{0x2c0c1c82,0x2d8803f9,0x60b8011a,0x65a00254}},	//   িবলৈ_, snce_, _הצדד, lõht, 
   {{0xf8d8063f,0xacb8002d,0x9db801d5,0x9cec00cc}},	//   _ọrụa, kfûg, تدیز_, _কাৰন_, 
   {{0xfc48012c,0x7dc401ab,0x00000000,0x00000000}},	//   _spíš_, _tųsa, --, --, 
   {{0x636c5c04,0x9f5c0407,0x2cf800e1,0x19580024}},	// [1dc70] _høne, ctuó_, ्लील_, чаты_, 
   {{0x2eed31f9,0x00000000,0x00000000,0x00000000}},	//   _jeff_, --, --, --, 
   {{0xacb8000f,0x65a0000d,0x00000000,0x00000000}},	//   ffûg, kõht, --, --, 
   {{0x636c143a,0x00000000,0x00000000,0x00000000}},	//   _møne, --, --, --, 
   {{0x636c05ac,0x444401ed,0x00000000,0x00000000}},	//   _løne, براہ, --, --, 
   {{0x68ec06be,0x82a426ef,0x00000000,0x00000000}},	//   _hecd, малж, --, --, 
   {{0x41b43a32,0x636c005c,0x68ec03b9,0x569418cd}},	//   мсит, _rønd, _kecd, _зарт, 
   {{0x636c39c2,0xe4a40354,0x41740137,0x65a00254}},	//   _sønd, _ерзо, باتس, tõhu, 
   {{0x3cdc2e1e,0x68ec0124,0x92cc00fe,0x00000000}},	//   _क्षे_, _mecd, লৰে_, --, 
   {{0x636c2d8b,0x65a00037,0x00000000,0x00000000}},	//   _bøne, rõhu, --, --, 
   {{0x2eed31fa,0xd2440276,0x68ec02d0,0x02780023}},	//   _deff_, _пэци, _oecd, _እንጌራ_, 
   {{0x68ed31fb,0xcac4015b,0x00000000,0x00000000}},	//   _necd, ্রাফ, --, --, 
   {{0xef0c1377,0x636d31fc,0x1dcc1b61,0x2eec5045}},	//   _им_, _tønd, _संवत, _feff_, 
   {{0x2eec04e6,0x636c003b,0x00000000,0x00000000}},	//   _geff_, _føne, --, --, 
   {{0x7d740375,0xb4b801ad,0x00000000,0x00000000}},	//   _يابط, _घण्_, --, --, 
   {{0x69c0011c,0x2eec003e,0x68ec0332,0x00000000}},	//   _ènel, _zeff_, _cecd, --, 
   {{0x68ec0334,0xe9a00c75,0x3d0800c5,0x00000000}},	// [1dc80] _decd, татп, वलीं_, --, 
   {{0x636c12e8,0x78a402f0,0xf74800be,0x98a401ef}},	//   _lønb, _vykv, غلاي_, _úmč_, 
   {{0x7af80008,0x00000000,0x00000000,0x00000000}},	//   óttu, --, --, --, 
   {{0x68ecd96c,0x34a80063,0x42680023,0xe0c404f2}},	//   _gecd, овео_, ታውነት_, _لز_, 
   {{0x9420013f,0xacb8000f,0xdb9c00b8,0x00000000}},	//   ɔsɛm_, rfûg, _ṛṣik, --, 
   {{0xe0dc0086,0xacb8002d,0xdb0808e2,0x23740271}},	//   ñòn_, sfûg, _äläm, ومند_, 
   {{0x2eec008b,0x68ec009a,0x8e7c01e4,0xe6140114}},	//   _reff_, _yecd, jaĝp, _одр_, 
   {{0xf0d001f2,0x636c05ac,0x2eed31fd,0x00000000}},	//   _rịsọ, _røne, _seff_, --, 
   {{0x6d480086,0x636c00fe,0xf2000cb4,0xe58c0332}},	//   _ògai, _søne, रूज़_, _úsáí, 
   {{0x60c8037e,0x65a000c5,0xee840166,0x43745296}},	//   _eggm, sõht, дымо, _пухт, 
   {{0x5f900108,0x1b1400cc,0x85540244,0x00000000}},	//   тиэт, াজাই_, _تیۆر_, --, 
   {{0x7afc00d8,0x70f4132f,0x00000000,0x00000000}},	//   _adpt, _آسائ, --, --, 
   {{0x9cc8547c,0x21b400e5,0x00000000,0x00000000}},	//   дыра_, _تھوک_, --, --, 
   {{0x68ec0342,0x20540a7c,0x00000000,0x00000000}},	//   _secd, _קיגל_, --, --, 
   {{0x9a843b49,0x443c0175,0x5f900107,0x98c000ef}},	//   вутл, zvw_, _шишт, _īsām_, 
   {{0x6ed80c00,0xd9280276,0xc7d8026b,0x850c04af}},	//   पुरु, мцул_, змах_, _हाइट_, 
   {{0xfe6c0133,0x68ec0205,0xad2400f1,0x88940022}},	// [1dc90] _نگێ_, _vecd, _فرکو, хиах, 
   {{0xf40400eb,0x00000000,0x00000000,0x00000000}},	//   োবার_, --, --, --, 
   {{0x68ec1437,0x00000000,0x00000000,0x00000000}},	//   _tecd, --, --, --, 
   {{0xe7bc0724,0x05941e2f,0x9a840150,0xe57000ae}},	//   ınıç, راضگ, _шуыл, خطط_, 
   {{0x98c4036b,0xe78401d5,0x00000000,0x00000000}},	//   _асрл, _жуво, --, --, 
   {{0x2fd000a2,0x35dc00cc,0xc0c40124,0x00000000}},	//   _çygy_, _ডিৰহ, ҕәеи, --, 
   {{0x7c381991,0xa3c82ba2,0xa23000fd,0xf2a000f7}},	//   ātri, _रंक_, тьлә, лишп, 
   {{0x72a00075,0x24440022,0x00000000,0x00000000}},	//   دەمن, _охзг, --, --, 
   {{0x439405f5,0xdeb800b7,0x95c80798,0xe4a400d8}},	//   _заас, ተውን_, _цура_, _црво, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x29c4015d,0x00000000,0x00000000,0x00000000}},	//   _rŵan_, --, --, --, 
   {{0xee340f30,0x8e7c01e4,0x3d08000d,0x6fdc00fe}},	//   хню_, raĝp, वलें_, _মিৰে, 
   {{0xa2c407d0,0x00000000,0x00000000,0x00000000}},	//   ाशक्, --, --, --, 
   {{0xa9640022,0x00000000,0x00000000,0x00000000}},	//   ҭира_, --, --, --, 
   {{0x3f8531fe,0xeb9531ff,0xbe6801c0,0xf2d008a8}},	//   milu_, хир_, _хайж_, רעל_, 
   {{0x3f853200,0xdc840220,0xe9a000c0,0x00000000}},	//   lilu_, _ақмо, гасп, --, 
   {{0xa3c86225,0x6cb1137f,0x7d14035a,0x6bd4007b}},	// [1dca0] _रंग_, _бөрт, _icys, _كويس_, 
   {{0x3f84e80c,0x7c34014b,0xe7340150,0x00000000}},	//   nilu_, _isyr, неу_, --, 
   {{0x19c40116,0x468000d1,0x07140395,0x00000000}},	//   _җәңг, ақра, ъфтя, --, 
   {{0xd91010e5,0xd6e800bd,0x3f853201,0x66013202}},	//   _خیر_, _পাওয, hilu_, ánka, 
   {{0x3f840093,0x9f5c07c5,0x28a400cd,0x00000000}},	//   kilu_, truì_, _कुपि, --, 
   {{0x7c353203,0x3f840ba7,0x87b80276,0xf1d001c0}},	//   _msyr, jilu_, _жуст_, гөдө, 
   {{0x3f853204,0xc8700092,0x00000000,0x00000000}},	//   dilu_, _ለመነጋ, --, --, 
   {{0xa3c805f9,0x7c340124,0x3cf00162,0x3d0801ad}},	//   _रूक_, _osyr, _neyv_, वलों_, 
   {{0xded40023,0x00000000,0x00000000,0x00000000}},	//   _ኮንካ_, --, --, --, 
   {{0x3f853205,0x29040153,0x8ec400f1,0x00000000}},	//   gilu_, ėnai_, پښتو, --, 
   {{0x7c340209,0x28a432ed,0xce9402e8,0x26c40118}},	//   _asyr, _कुनि, танъ, žnov_, 
   {{0xe29405f5,0xeb9c353e,0xfd640124,0x00000000}},	//   _яах_, grøn_, mitỹ, --, 
   {{0x3f853206,0x3cf00174,0x636c0162,0x00000000}},	//   bilu_, _deyv_, _høna, --, 
   {{0xdb584b53,0x636c03b2,0x3f84b2be,0xdef401f3}},	//   нюс_, _køna, cilu_, ሊዘኛ_, 
   {{0x7c34035b,0xe8000490,0x7ed402bf,0x00000000}},	//   _esyr, _लिहा_, _річч, --, 
   {{0x19593207,0x19a80022,0x7af803b2,0x00000000}},	//   насы_, етуп_, óttr, --, 
   {{0x636c022c,0x92ac00cc,0x00000000,0x00000000}},	// [1dcb0] _løna, _গলো_, --, --, 
   {{0xd838152d,0x6d5d3208,0x69b01889,0x00000000}},	//   ээс_, _hoqa, _आठवी, --, 
   {{0xd7c8b0bc,0x5f1002c3,0x00000000,0x00000000}},	//   رومه_, _दास्_, --, --, 
   {{0x3f8405a1,0x6d5d285b,0x7c340588,0x00000000}},	//   zilu_, _joqa, _ysyr, --, 
   {{0x6d5c01e0,0xf0d001f2,0xa3c8060c,0x9cd8011a}},	//   _moqa, _rịpọ, _रूख_, גודה_, 
   {{0x636c022c,0x3f84208d,0x6d5c01b9,0x9f5c004e}},	//   _bøna, xilu_, _loqa, truí_, 
   {{0x6d5c9585,0x73c029db,0xdeb801f3,0xb784586a}},	//   _ooqa, рәте, ተውና_, _рәте_, 
   {{0x6d5d3209,0x3f84dc83,0x7fd80798,0x00000000}},	//   _noqa, wilu_, мфот_, --, 
   {{0x3f85320a,0x66000184,0x26c40030,0x63b00022}},	//   tilu_, _шоңҡ, ľnou_, _бааӡ, 
   {{0x20008847,0x26c40308,0xfe4402e8,0x00000000}},	//   čji_, žnou_, вноо, --, 
   {{0xfce5320b,0x3f85320c,0x2cc403be,0x6d5d320d}},	//   коно, rilu_, ətdə_, _boqa, 
   {{0x3f85320e,0x80c80154,0x00000000,0x00000000}},	//   silu_, রডব্, --, --, 
   {{0x6d5c17bb,0x3f84dbe0,0x60d816b8,0x63a00270}},	//   _doqa, pilu_, mcum, oonn, 
   {{0x63a1320f,0x3b0811ed,0xee2c00b2,0x3f84022f}},	//   nonn, ьего_, _ڀٽو_, qilu_, 
   {{0xfaa40364,0x4a740372,0x60d8010a,0x6a80035b}},	//   таво, гытт, ocum, алра, 
   {{0x60d81cea,0x6d5c0334,0x00000000,0x00000000}},	//   ncum, _goqa, --, --, 
   {{0x63a13210,0x6b8401a4,0x00000000,0x00000000}},	// [1dcc0] konn, bijg, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc7942386,0x6d5d3211,0x332c00b5,0xa2d400eb}},	//   урты, _yoqa, vefx_, হরাও, 
   {{0xdac804a9,0x58040184,0xb46412b9,0x6d5c058a}},	//   _يېڭى_, _йомғ, ккел, _xoqa, 
   {{0x60d816b8,0x00000000,0x00000000,0x00000000}},	//   dcum, --, --, --, 
   {{0x63a06cbd,0x60d81730,0xeb9c0158,0x66e00006}},	//   gonn, ecum, ftøy_, _вора, 
   {{0x60d804cc,0x6d493212,0x68380023,0x00000000}},	//   fcum, _ógag, _ብርሰት, --, 
   {{0x60d80472,0xf1240212,0x00000000,0x00000000}},	//   gcum, тько, --, --, 
   {{0xb4cc0490,0x614000d8,0x00000000,0x00000000}},	//   रशी_, рења, --, --, 
   {{0x63a13213,0xe3b53214,0x6d5d3215,0x60d80077}},	//   conn, _абу_, _soqa, acum, 
   {{0x636c00b5,0x60d8003a,0x43751318,0xa3c825c9}},	//   _kønn, bcum, _сутт, _रूट_, 
   {{0x60d8c799,0x6d5c0194,0x636c0158,0x6b8401a4}},	//   ccum, _qoqa, _jønn, wijg, 
   {{0x6d5d3216,0x6b8409b6,0x2008004e,0x636c01bf}},	//   _voqa, tijg, àcit_, _mønn, 
   {{0x636c708a,0x6d5c0334,0xdee0009b,0x00000000}},	//   _lønn, _woqa, _кољи, --, 
   {{0x5fb4025f,0x6b853217,0x6d5d3218,0xdd040166}},	//   _שהוא_, rijg, _toqa, _äsğa, 
   {{0x63a13219,0xb7c401b9,0xfbe00154,0x6d5c03ac}},	//   zonn, ғруқ, _বিরত, _uoqa, 
   {{0x63a1321a,0x13cc0183,0x3eb91592,0xd7f80024}},	// [1dcd0] yonn, ৰীয়, ęste_, вух_, 
   {{0xe6c40075,0x660001f1,0x63a1321b,0xe664023a}},	//   نتاي, ánko, xonn, ктео, 
   {{0x636c1088,0xe0dc08e7,0x8640001f,0x290c0ba1}},	//   _bønn, ñòk_, _የሚኒስ, ògas_, 
   {{0x63a1321c,0x00000000,0x00000000,0x00000000}},	//   wonn, --, --, --, 
   {{0x63a1321d,0xc8c93169,0x442882b2,0x636c383d}},	//   tonn, _سوسن_, ïa_, _dønn, 
   {{0xe61001d9,0xeb9c143a,0xd4040395,0x00000000}},	//   _پشس_, ttøy_, ряци, --, 
   {{0x63a1321e,0x60d861bd,0x80d804ce,0x28a4023e}},	//   ronn, tcum, yをdv, _कुति, 
   {{0x63a1321f,0x56953220,0xeb9d3221,0xdce417a3}},	//   sonn, _таст, rtøy_, _ilić, 
   {{0xeb9c2dba,0x7f18109a,0xb14000c7,0x00000000}},	//   støy_, ніну_, сныл, --, 
   {{0x60d93222,0x63a13223,0xe8fc002d,0x81d4036b}},	//   scum, qonn, _klûs_, _божх, 
   {{0x63c001ee,0x00000000,0x00000000,0x00000000}},	//   _баҡҡ, --, --, --, 
   {{0x518452f7,0x60d802b9,0x00000000,0x00000000}},	//   _куча, qcum, --, --, 
   {{0x644c9312,0x9f4c01e3,0x213c0205,0x00000000}},	//   _ácid, _avgå_, mduh_, --, 
   {{0x50b8034c,0xdce401a6,0xd00406b3,0x201c0064}},	//   _شدند_, _olić, _тошқ, mtui_, 
   {{0x201d3224,0x636c01bf,0x8e54030d,0x81e400cc}},	//   ltui_, _løno, _кĕрл, _ভয়ত_, 
   {{0x213d3225,0xb8840316,0x201c0618,0x2d8801d3}},	//   nduh_, hlíž, otui_, ébet_, 
   {{0xdce401fa,0x201c2f6a,0x636c28b3,0x6d480209}},	// [1dce0] _alić, ntui_, _rønn, şmaç, 
   {{0xe8fc002d,0x213c03a2,0x636c0ac7,0x6d480428}},	//   _blûs_, hduh_, _sønn, _ògar, 
   {{0x7bd53226,0x201c02f6,0xd9102354,0xf5080798}},	//   _huyu, htui_, _ویس_, енел_, 
   {{0x7bd40bf1,0x14c8034c,0x201c0024,0x00000000}},	//   _kuyu, نهای_, ktui_, --, 
   {{0x213c03a2,0x7bd4002e,0x752022e2,0x24e401a9}},	//   dduh_, _juyu, rfoz, умчи_, 
   {{0x7bd53227,0x75d421ec,0x3a38007f,0xbc70001f}},	//   _muyu, _ميسا, _kspp_, ብርናና_, 
   {{0x1dcc2894,0x636d3228,0x7bd44c86,0x201c0158}},	//   _संगत, _tønn, _luyu, etui_, 
   {{0xd4c41945,0x3a3802e2,0xacb8000f,0xe6903592}},	//   _көлк, _mspp_, dfûn, _الفد, 
   {{0x7bd4003e,0xb8840308,0x3a393229,0xa5040395}},	//   _nuyu, blíž, _lspp_, _щета_, 
   {{0xeb9d322a,0xca940092,0x00000000,0x00000000}},	//   trøm_, _መሆኑም_, --, --, 
   {{0x7bd40369,0x213c05b1,0x2b1873ca,0x798401f5}},	//   _auyu, bduh_, _बाबु_, _omkw, 
   {{0x7bd41ac8,0x00000000,0x00000000,0x00000000}},	//   _buyu, --, --, --, 
   {{0x201c16b8,0x20cc0354,0x00000000,0x00000000}},	//   ctui_, _хιум, --, --, 
   {{0x20080038,0x7bd44953,0xe6d000bc,0x195801ec}},	//   ácie_, _duyu, _तलेज, қауы_, 
   {{0x58840184,0x333c00db,0x00000000,0x00000000}},	//   ҡыуа, _matx_, --, --, 
   {{0x7bd4037e,0x53d40950,0x00000000,0x00000000}},	//   _fuyu, ददाश, --, --, 
   {{0x7bd5322b,0xe8fc045f,0xdce40841,0x3d1805d7}},	// [1dcf0] _guyu, _slûs_, _slić, _भाते_, 
   {{0x213d06ae,0xdce407f5,0x15cc0116,0x00000000}},	//   zduh_, _plić, _ﺑﺎﺭﺩ, --, 
   {{0x2d580de2,0x00000000,0x00000000,0x00000000}},	//   _sëey_, --, --, --, 
   {{0x7bd5322c,0x60100419,0x25a80eff,0x00000000}},	//   _yuyu, nžmá, رداي_, --, 
   {{0x78f80302,0x69cc0472,0x333c41b9,0x7bd4022f}},	//   _בפרו, _iice, _batx_, _xuyu, 
   {{0x69d400f1,0x213c03a2,0x2d88054e,0xd4980022}},	//   _kuxe, wduh_, hice_, ырх_, 
   {{0x2d89322d,0xe4e41ed2,0x69cd322e,0x213c06a3}},	//   kice_, _бізн, _kice, tduh_, 
   {{0x201d322f,0x69d4fde2,0xc004010a,0x63480171}},	//   ttui_, _muxe, апик, _sēnē, 
   {{0x2d893230,0x69cd3231,0x213c06a3,0x646003ee}},	//   dice_, _mice, rduh_, çtiğ, 
   {{0x442d3232,0x7bd53233,0x201d3234,0x7e241575}},	//   _ipe_, _ruyu, rtui_, адож, 
   {{0x7bd52e59,0x201d3235,0x2d88e0f4,0x213c03a2}},	//   _suyu, stui_, fice_, pduh_, 
   {{0x69cd3236,0x2d893237,0x3a380395,0xacb8002d}},	//   _nice, gice_, _rspp_, rfûn, 
   {{0x69d5081d,0x442d3238,0x636d3239,0x7bd5323a}},	//   _auxe, _jpe_, _lønm, _quyu, 
   {{0x442d323b,0x69cd323c,0x69d5323d,0x2d89323e}},	//   _mpe_, _aice, _buxe, éber_, 
   {{0x442c070d,0x34b00d01,0xfce40137,0x7bd5323f}},	//   _lpe_, _जर्द, _койо, _wuyu, 
   {{0x7bd53240,0x69cd3241,0x2d880989,0x442d3242}},	//   _tuyu, _cice, cice_, _ope_, 
   {{0x69cd3243,0x68411ae5,0x442c0190,0x69d40077}},	// [1dd00] _dice, онта, _npe_, _euxe, 
   {{0x69cd3244,0x69d4003a,0x9ba400db,0xa2d400eb}},	//   _eice, _fuxe, _چەڭى, হরুখ, 
   {{0x442d3245,0x69cd3246,0xe7353247,0xb4cc0b6d}},	//   _ape_, _fice, рех_, रश्_, 
   {{0x69cc0223,0x79840af2,0x39153248,0x2ed003ce}},	//   _gice, _umkw, _өмүр, _सल्त, 
   {{0x7994009f,0xada402d2,0x00000000,0x00000000}},	//   mnyw, _hlúð, --, --, 
   {{0x69cd3249,0x442d324a,0x5335324b,0x2d89324c}},	//   _zice, _dpe_, сект, zice_, 
   {{0x442d324d,0x69cd324e,0x69d5324f,0x79951a99}},	//   _epe_, _yice, _xuxe, onyw, 
   {{0x442d3250,0x79953251,0x2d893252,0xe6840137}},	//   _fpe_, nnyw, xice_, _ئچكى_, 
   {{0x2d893253,0x333c0327,0x00000000,0x00000000}},	//   vice_, _tatx_, --, --, 
   {{0xceb8052f,0x2d893254,0x79940369,0x636c0162}},	//   ләй_, wice_, hnyw, _lønj, 
   {{0x01dc04c5,0xe2940a42,0x00000000,0x00000000}},	//   ণীবদ, _каф_, --, --, 
   {{0x442c0124,0x69d40009,0x3f9800e4,0x00000000}},	//   _ype_, _ruxe, ĩsua_, --, 
   {{0x69cd3255,0x2d880b9b,0x69d40f71,0x442c0ac5}},	//   _rice, rice_, _suxe, _xpe_, 
   {{0x69cd3256,0x69d51c67,0x79941418,0xadf000c7}},	//   _sice, _puxe, enyw, _докә, 
   {{0x7de00093,0x59f8084c,0x5a44005b,0x00000000}},	//   _pēse, иеря_, оэта, --, 
   {{0x69d53257,0x6ce40046,0xec689b4e,0x00000000}},	//   _vuxe, _тіке, _арок_, --, 
   {{0x69cc1e3d,0x995c0118,0x9814007b,0x00000000}},	// [1dd10] _vice, _míň_, قبلا, --, 
   {{0x69d53258,0x79941418,0x69cd3259,0xada408a5}},	//   _tuxe, anyw, _wice, _flúð, 
   {{0x69cd325a,0x442d325b,0x28a4146c,0x37b400cc}},	//   _tice, _spe_, _कुरि, _অংশৰ, 
   {{0xa8500131,0x69cd325c,0x00000000,0x00000000}},	//   _демә, _uice, --, --, 
   {{0xf9540302,0x1dd000af,0x675401d3,0x04440395}},	//   _הסרת_, _संघत, _پیاس_, селн, 
   {{0xe054028e,0xeb9c0162,0x442c002f,0x00000000}},	//   ییات_, frøi_, _vpe_, --, 
   {{0x5695325d,0x2c200154,0x00000000,0x00000000}},	//   _дарт, মিয়ে_, --, --, 
   {{0x442d325e,0x91842002,0x00000000,0x00000000}},	//   _tpe_, يۇلۇ, --, --, 
   {{0x442c07dd,0x449802d5,0xfd60002b,0x636c01bf}},	//   _upe_, _сваю_, _govṛ, _jønk, 
   {{0xe3140efc,0x3e4400ef,0xb4e00248,0x00000000}},	//   _خبرب, _pēt_, _ààri, --, 
   {{0xbdc805f5,0xbea405c8,0x636c005c,0xdb240129}},	//   лгож_, санк, _lønk, _àrép, 
   {{0xbc180046,0xc0e800ec,0x00000000,0x00000000}},	//   лігі_, _صفتن_, --, --, 
   {{0x7f440209,0xada401a8,0x8d940092,0xdeb80023}},	//   _гелж, _slúð, _ግዛቸው_, ሰውኡ_, 
   {{0x3d19325f,0x79940034,0x636c0fac,0xe130010b}},	//   _भावे_, wnyw, _sønj, _ынҗы, 
   {{0xf2d000c8,0xf0d00521,0x31b80200,0x00000000}},	//   לעם_, _rịzọ, lëza_, --, 
   {{0xe800028a,0x249c00d8,0x8d840472,0x00000000}},	//   _लिखा_, _oxum_, _وشين, --, 
   {{0xf6d419b6,0x7994015d,0xbd4400f1,0x370400db}},	// [1dd20] مزاد, rnyw, _ننګي, йпаг, 
   {{0x25bc009d,0x7994017a,0xb6a40a5b,0x00000000}},	//   _ahul_, snyw, бизл, --, 
   {{0x636c05ac,0xfa681513,0x31b80200,0x7a6800f3}},	//   _tønj, _санк_, hëza_, _синг_, 
   {{0x25bd3119,0x2a54011a,0x31b8036e,0xd51400d1}},	//   _chul_, _הבטן_, këza_, تېرد, 
   {{0x25bd3260,0xe280108a,0xe5a002e8,0x394000ef}},	//   _dhul_, үлчи, чици, _iaks_, 
   {{0xeb9c04ce,0x39408075,0x69c0020c,0x96dc00bc}},	//   rsøg_, _haks_, _èner, _बलिउ, 
   {{0x3940033d,0x2b1805d7,0x00000000,0x00000000}},	//   _kaks_, _बासु_, --, --, 
   {{0xf5940491,0x636c03b2,0x39400254,0xeb9c01bf}},	//   _الرج, _lønh, _jaks_, msøe_, 
   {{0x39400c3a,0xeb9c06ea,0xc0c000d1,0x3318007b}},	//   _maks_, lsøe_, мәши, _مزاد_, 
   {{0x20093261,0x39403c12,0xb8d8025c,0x4f840050}},	//   ácia_, _laks_, _ཆཊ_, تابہ, 
   {{0x39400d63,0x4d9800d4,0xa758010f,0x756400b8}},	//   _oaks_, икою_, אדיר, _ṛṇam_, 
   {{0x39401c06,0x00000000,0x00000000,0x00000000}},	//   _naks_, --, --, --, 
   {{0x636c0162,0x4f8401d9,0x3d180ce0,0x4bc4004e}},	//   _bønh, _واتہ, _भारे_, жөнг, 
   {{0xa00400c6,0x00000000,0x00000000,0x00000000}},	//   _اقول_, --, --, --, 
   {{0xeb9c0174,0x2de4004e,0x00000000,0x00000000}},	//   krøv_, _уюлг, --, --, 
   {{0x394001e4,0x636c143a,0x3dd000a2,0x99640276}},	//   _caks_, _pønk, _giyw_, птул, 
   {{0x636c00cc,0x39400036,0x88940124,0x98e400be}},	// [1dd30] _fønh, _daks_, циах, سكلو, 
   {{0x25bc485b,0x00000000,0x00000000,0x00000000}},	//   _shul_, --, --, --, 
   {{0x6e380455,0xeb9c01bf,0x00000000,0x00000000}},	//   nwtb, rsød_, --, --, 
   {{0x394005b1,0x44b40108,0x17e800fe,0x00000000}},	//   _gaks_, обес, _পিৰি, --, 
   {{0x68fc1938,0x636c0162,0xe8000210,0x00000000}},	//   maqd, _høni, _लिटा_, --, 
   {{0x39413262,0x57c4a5b3,0x68fc03e3,0x00000000}},	//   _zaks_, वगृह, laqd, --, 
   {{0xdce400c8,0x31640393,0x3940020b,0xeb9c022c}},	//   _aliĝ, _booz_, _yaks_, brøv_, 
   {{0x21282d2a,0x3fe53263,0x249c0218,0x29193264}},	//   ých_, ожив, _txum_, ngqa_, 
   {{0x44393265,0x636c022c,0x43953266,0x6614005a}},	//   _ès_, _løni, _даас, luxk, 
   {{0x68fd3267,0x31b80200,0xc20801c8,0x00000000}},	//   haqd, rëza_, _نقطن_, --, 
   {{0x3eb8068f,0xdce400df,0x636c12e8,0x31b80200}},	//   ęsto_, _eliĝ, _rønh, sëza_, 
   {{0x3cc81b10,0x31b8036e,0x00000000,0x00000000}},	//   илно_, pëza_, --, --, 
   {{0x68fc047e,0x00000000,0x00000000,0x00000000}},	//   daqd, --, --, --, 
   {{0x6f18074d,0x39413268,0x636c0174,0x26e005d7}},	//   cgtc, _saks_, _bøni, गडोर_, 
   {{0x3940e37a,0x16b86d65,0x68fc1898,0xeb94011c}},	//   _paks_, _अरेब, faqd, цир_, 
   {{0xee9400f2,0xdd9000ec,0xdb24150e,0x00000000}},	//   _بدهک, _ڊوڙ_, _کودی, --, 
   {{0x39413269,0xbb44004e,0x00000000,0x00000000}},	// [1dd40] _vaks_, _депк, --, --, 
   {{0x3941326a,0x636c1347,0xefe00023,0xf9886ea9}},	//   _waks_, _føni, _ነብዪ_, _چندي_, 
   {{0x3941326b,0x7c25326c,0x67fc01e1,0x68fc2009}},	//   _taks_, ltkr, _pàjá, baqd, 
   {{0x68fc00ac,0xe5cc0952,0xeb9cc300,0x00000000}},	//   caqd, _ﺑﺎﻧﻜ, rsøe_, --, 
   {{0xe6c000a2,0x31640332,0xf1a81046,0xeb9c01bf}},	//   _iįýä, _rooz_, یابه_, ssøe_, 
   {{0xeb9c01bf,0xc4c405af,0x7c24002f,0x00000000}},	//   psøe_, ستنو, itkr, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7c2401e3,0x7ae0d1e8,0x00000000,0x00000000}},	//   ktkr, _şotl, --, --, 
   {{0x6f18074d,0x316400d8,0xe0cc0214,0x2b18000d}},	//   tgtc, _vooz_, پزي_, _बालु_, 
   {{0x7c24002f,0xa854011a,0x00000000,0x00000000}},	//   dtkr, קייה_, --, --, 
   {{0xa3c400e1,0x26d8008f,0xb7c400de,0x91cc01af}},	//   ईगर_, יקימ, _izģē, _йәиh, 
   {{0xbff800cc,0x00000000,0x00000000,0x00000000}},	//   _আমৰণ_, --, --, --, 
   {{0x31b82776,0x7de000de,0x00000000,0x00000000}},	//   lëzo_, _vēsa, --, --, 
   {{0x68fc011f,0xc6200154,0x1ae40108,0x00000000}},	//   waqd, নবতা_, доём, --, 
   {{0x68fcff36,0x29880063,0xf7c80150,0xdb1c03b2}},	//   taqd, асао_, _ﺑﻮﻋﺪ, umrá, 
   {{0x80c0045e,0xd2444451,0xdce403e0,0x2d8c0205}},	//   _ষ্ট্, _یۆ_, _iliğ, _öge_, 
   {{0x47d40491,0x764c00ad,0xc8c44da4,0x68fcff36}},	// [1dd50] سيار, _arby, लेंट, raqd, 
   {{0xeb9c1445,0x26bc0327,0x68fc047e,0xdb840063}},	//   grøt_, _མཛདཔ, saqd, _огњи, 
   {{0xbb380375,0x00000000,0x00000000,0x00000000}},	//   _העתי, --, --, --, 
   {{0x661401c6,0x00000000,0x00000000,0x00000000}},	//   ruxk, --, --, --, 
   {{0x764c0cfd,0x43742607,0xeb9c003b,0x9a78001f}},	//   _erby, зуйт, brøt_, _ከሆነው_, 
   {{0xdb0800d2,0xa354007b,0x070800ec,0x00000000}},	//   _úmôy, تخصص, _ديسي_, --, 
   {{0xd498008e,0x00000000,0x00000000,0x00000000}},	//   йрә_, --, --, --, 
   {{0x2009326d,0xf6500302,0x246002b5,0x6f09326e}},	//   ácio_, _אצל_, _pūmā_, _adfc, 
   {{0x6579326f,0x7de00171,0x7c24007c,0x00000000}},	//   _iluh, _cēsn, xtkr, --, 
   {{0x6578017a,0x443c0175,0x5de002dd,0xff24009d}},	//   _hluh, mww_, _ﺍﻟﻭﺴ, чмоо, 
   {{0x3da80137,0x00000000,0x00000000,0x00000000}},	//   йкоо_, --, --, --, 
   {{0xb2b80302,0x7c253270,0x246000b0,0x00000000}},	//   _המער, ttkr, _tūmā_, --, 
   {{0xef0d3271,0x6f080175,0x16b81fd2,0x00000000}},	//   _пм_, _fdfc, _अर्ब, --, 
   {{0x7c2417b5,0x65780113,0x644804cc,0x270c00b0}},	//   rtkr, _lluh, ivgi, nēnē_, 
   {{0x65780912,0x636c0158,0xdce8510c,0x00000000}},	//   _oluh, _fønv, şmıy, --, 
   {{0x443c003e,0x62800165,0x39e80107,0x00000000}},	//   kww_, izno, идҳо_, --, 
   {{0xa9653272,0x636c0162,0x00000000,0x00000000}},	// [1dd60] чита_, _hønu, --, --, 
   {{0x65793273,0x636c0162,0xc4d00154,0x00000000}},	//   _aluh, _kønu, াডাঙ, --, 
   {{0x65780327,0x644807de,0xca6401d5,0xd5bc0248}},	//   _bluh, evgi, _uchа, bọ́_, 
   {{0x7afc030a,0x7de00418,0x636c03b2,0xe5a0011c}},	//   _hept, _lēso, _mønu, нихи, 
   {{0x7afd3274,0x20087499,0x6578012c,0x2604008f}},	//   _kept, ácil_, _dluh, aĵo_, 
   {{0x65786580,0x7afd3275,0xeb9c01bf,0xc33400c7}},	//   _eluh, _jept, lrør_, мҕу_, 
   {{0x64485243,0xe1ec01e2,0x00000000,0x00000000}},	//   avgi, هسي_, --, --, 
   {{0x65793276,0xeb9c0450,0x31b80200,0x00000000}},	//   _gluh, nrør_, rëzo_, --, 
   {{0xe5a12361,0x60f40953,0x636c0fac,0x443c0009}},	//   _чити, чныя_, _rønv, cww_, 
   {{0x32453277,0x636c0174,0xb7c400ef,0xe8700092}},	//   _незг, _bønu, _uzģē, _የዘጠኝ_, 
   {{0x6280068f,0x52c4004b,0x00000000,0x00000000}},	//   czno, _غښتل, --, --, 
   {{0x4c944a77,0x636c0174,0x161403ba,0xf8bc00cd}},	//   димс, _dønu, _डिनर_, ्धाय, 
   {{0x7afd3278,0xd0540134,0x5c741d5b,0x00000000}},	//   _bept, _ɛbɛb, елят, --, 
   {{0x7afd3279,0x09b407b6,0x00000000,0x00000000}},	//   _cept, ंत्य, --, --, 
   {{0x7afd327a,0xeb9c005c,0x00000000,0x00000000}},	//   _dept, frør_, --, --, 
   {{0x7de000e2,0xeb9c01bf,0x37b400fe,0x00000000}},	//   _mēsl, grør_, _অংগৰ, --, 
   {{0x7afcfed3,0x00000000,0x00000000,0x00000000}},	// [1dd70] _fept, --, --, --, 
   {{0x2470044e,0x00000000,0x00000000,0x00000000}},	//   _ጸልማት_, --, --, --, 
   {{0x6579327b,0x636c037e,0x5695327c,0xcfe000cc}},	//   _pluh, _mønt, нафт, _মৌমন, 
   {{0x7afc0316,0x636c392f,0xdb0c01a8,0x27e8004d}},	//   _zept, _lønt, ðhön, _ttcn_, 
   {{0xefb802d3,0x3f9800f2,0x27e80356,0x5de00046}},	//   ሰምዕ_, ésuk_, _utcn_, _ﺍﻟﻤﺴ, 
   {{0xb874001f,0xd3d8484d,0x6448007c,0x00000000}},	//   _የመጣው_, سبها_, rvgi, --, 
   {{0x81e40154,0x161412eb,0xc5940114,0x00000000}},	//   বীন_, _डियर_, _живј, --, 
   {{0x6579327d,0x7c2003cd,0x00000000,0x00000000}},	//   _uluh, _åorg, --, --, 
   {{0x628000f8,0xb14411fc,0x614002dd,0x90e401f7}},	//   szno, بینم_, деқа, رسين, 
   {{0xdb1c7a1e,0x6d4800e4,0x9378005b,0x00000000}},	//   områ, _ógaj, _ебут_, --, 
   {{0x7afd327e,0xd1b86112,0x92580107,0x00000000}},	//   _rept, _کالا_, _нафт_, --, 
   {{0xcb083d99,0x7afd327f,0x7ff40132,0x92b4007b}},	//   _כל_, _sept, _قستا, _أحكا, 
   {{0xe9283ae9,0x636c01bf,0x00000000,0x00000000}},	//   _སྡེབ_, _fønt, --, --, 
   {{0x7c2000df,0x6ab4007c,0x2a6c0241,0x00000000}},	//   _ĥord, _byxf, _ńgba_, --, 
   {{0x636c28b3,0x7afc07c5,0xab2402e8,0x00000000}},	//   _høns, _vept, ьора_, --, 
   {{0x636c037e,0x7afc0099,0x2ac001e1,0x00000000}},	//   _køns, _wept, _sébí_, --, 
   {{0x7afc0153,0xeb9d3280,0x636c5522,0x00000000}},	// [1dd80] _tept, rrør_, _jøns, --, 
   {{0x636c2759,0x36940046,0x39441494,0x7c340124}},	//   _møns, мшес, žos_, _ipyr, 
   {{0xeb9c2d75,0x636d3281,0xdb1c0267,0xfaa41d0f}},	//   prør_, _løns, rmrä, _цано, 
   {{0xe3ac5fc4,0x7de000ef,0x00000000,0x00000000}},	//   یرو_, _nēsm, --, --, 
   {{0xe8f46c20,0x883400a8,0xeaac01ed,0x00000000}},	//   _юля_, _пэрц, _مٹی_, --, 
   {{0x28a421b8,0xdeb80b82,0x00000000,0x00000000}},	//   _कुटि, ሰልን_, --, --, 
   {{0x636c2d75,0xd2504363,0x00000000,0x00000000}},	//   _rønt, انب_, --, --, 
   {{0x3d187e7c,0x7c353282,0x636c01bf,0x2978010f}},	//   _भागे_, _opyr, _bøns, ַטיא, 
   {{0x4fd401a9,0x77540092,0xefb80240,0x00000000}},	//   нжит, _ለማስደ, ሰምዑ_, --, 
   {{0x64a001ec,0x00000000,0x00000000,0x00000000}},	//   _рауа, --, --, --, 
   {{0xf7c804a2,0x629c0598,0x7c346219,0x81e40154}},	//   _ﺑﻮﻟﺪ, şqor, _apyr, বীব_, 
   {{0x636c01bf,0x00000000,0x00000000,0x00000000}},	//   _føns, --, --, --, 
   {{0xe7e000e1,0x2128180f,0x6b8c01d5,0x00000000}},	//   _कंधा_, òche_, аngа, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7c340124,0x7c200115,0x1bd468eb,0x00000000}},	//   _epyr, _ĥore, торя, --, 
   {{0x19593283,0x00000000,0x00000000,0x00000000}},	//   масы_, --, --, --, 
   {{0xe7080a52,0xfcc00075,0x25ac04cc,0x00000000}},	// [1dd90] قتان_, _бәрм, vogl_, --, 
   {{0x78a40175,0x6d1c00ab,0x636c01bf,0x6bd4007b}},	//   _dxkv, _भाँग_, _lønr, _تتعر, 
   {{0xb8d400dc,0xa91802d2,0xdb2401e1,0x387c03b9}},	//   _चु_, _alþe, _àráp, _ətri_, 
   {{0x7c3400c7,0x00000000,0x00000000,0x00000000}},	//   _ypyr, --, --, --, 
   {{0xefd00020,0x3cec00ac,0x25ac05d5,0x3eb80024}},	//   _ረገድ_, _əfv_, rogl_, ęsti_, 
   {{0x636c1347,0x2c140073,0x25ac0042,0x00000000}},	//   _røns, _तिनं_, sogl_, --, 
   {{0x6d1c2017,0x636c03cd,0x00000000,0x00000000}},	//   _भांग_, _søns, --, --, 
   {{0x636c5522,0x326001d9,0x00000000,0x00000000}},	//   _pøns, انٹہ, --, --, 
   {{0x9f5c0798,0x7de00171,0x39980166,0x00000000}},	//   ssuí_, _vēsm, lüsä_, --, 
   {{0xd3d86dd7,0x670c0562,0x00000000,0x00000000}},	//   _قبلا_, ाणिक_, --, --, 
   {{0x7c353284,0x2ca4013b,0x00000000,0x00000000}},	//   _spyr, _ɛnde_, --, --, 
   {{0xd1b810e0,0x636c168c,0x8144004b,0xf678008f}},	//   _قانا_, _tøns, _سپتم, פארמ, 
   {{0x636c2188,0xeb9c00b5,0x8c0000ee,0xec74011c}},	//   _uøns, rsøn_, аҗыл, епя_, 
   {{0xbea4a1f9,0x26c00194,0x0b7c0023,0x387c0171}},	//   _палк, _ozjo_, _ባኪየቭ_, _ātr_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe9d5305b,0x66e0036b,0xa9653285,0x98a001a6}},	//   екс_, ҳофа, ниса_, nfić_, 
   {{0x7d053286,0x1ce01b4b,0x7c340124,0xc76400d1}},	// [1dda0] maks, _སྔར_, _upyr, ھاكى, 
   {{0xe0c40372,0xbb4400ea,0x00000000,0x00000000}},	//   _ۅز_, _џенк, --, --, 
   {{0x81e400fe,0x0ba8215c,0x7d0401f4,0x765801ef}},	//   বীত_, _تايى_, oaks, _štyb, 
   {{0x7d04094a,0xe0c53287,0xdeb81954,0xf5b41291}},	//   naks, _مز_, ሰልና_, رصاد, 
   {{0x7bcd3288,0x93c80014,0x2de402dd,0x5de00150}},	//   ombu, واتہ_, _ﺍﻟﻤﻤ, _ﺍﻟﻴﺴ, 
   {{0x7d0418db,0x79940113,0x92940798,0xe36001d5}},	//   haks, liyw, калц, лкчи, 
   {{0x77540020,0x7bcc009a,0x7d053289,0x00000000}},	//   _ለማሳደ, imbu, kaks, --, 
   {{0x7d0504ec,0x00000000,0x00000000,0x00000000}},	//   jaks, --, --, --, 
   {{0x64a1328a,0x776c011f,0x6d4800e4,0xe1200063}},	//   _бата, _kobx, _ógai, умњи, 
   {{0x7520066d,0x79940028,0x7bcc036e,0x92f401f0}},	//   lgoz, hiyw, jmbu, _рӯдх, 
   {{0x79940309,0xdeec01e0,0x72780209,0x00000000}},	//   kiyw, _ҙы_, _эсас_, --, 
   {{0x752000ec,0x7bcc009a,0x7d040254,0x00000000}},	//   ngoz, embu, gaks, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc0ec0201,0x7d0401f4,0xabb00022,0x00000000}},	//   ቀዋል_, aaks, уагә, --, 
   {{0xef900b8a,0x7520005a,0xda34cfa3,0x00000000}},	//   _لیکد, kgoz, леры, --, 
   {{0x7bcd328b,0x7d05328c,0xacb00131,0x636c01bf}},	//   ambu, caks, _مەجب, _lønp, 
   {{0xf8b401c0,0x00000000,0x00000000,0x00000000}},	// [1ddb0] вөр_, --, --, --, 
   {{0x200801f1,0x257403e0,0xeabc00eb,0x00000000}},	//   ácii_, _içli_, _আলীম, --, 
   {{0x57a5328d,0x7994009a,0x97a4cf8a,0x00000000}},	//   ушта, biyw, уртл, --, 
   {{0x752004ba,0x1ac800fb,0x93243769,0x00000000}},	//   ggoz, _яуып_, ۇرىن, --, 
   {{0x04444482,0x1ce0025c,0x13e800d4,0x6da80210}},	//   телн, _སྔས_, емій_, męad, 
   {{0x7d05328e,0xe784300e,0x070801e2,0x00000000}},	//   zaks, _чумо, _زيري_, --, 
   {{0x7d0402bd,0x71f801ed,0x918400d1,0x00000000}},	//   yaks, ورٹس_, گۇنۇ, --, 
   {{0x2125328f,0x00000000,0x00000000,0x00000000}},	//   ريخی_, --, --, --, 
   {{0x7d053290,0x7f182626,0xdeb8001f,0x20081de4}},	//   vaks, міну_, ሰውን_, éci_, 
   {{0x79940928,0x7d041c06,0x94741867,0xa30001ee}},	//   ziyw, waks, _صدقا, _сүке, 
   {{0x7d04367a,0x3ea53291,0xbea53292,0x4ed402bf}},	//   taks, тинг, танк, люют, 
   {{0xed5400d6,0x7d0401f4,0x00000000,0x00000000}},	//   вою_, uaks, --, --, 
   {{0x7d053293,0x213c003e,0x4a7402dd,0x2de40150}},	//   raks, meuh_, қырт, _ﺍﻟﻼﻤ, 
   {{0x213c0438,0x7bcd3294,0x5ec00131,0xfaa44d56}},	//   leuh_, umbu, _йилғ, ваго, 
   {{0x7d053295,0x7bcd3296,0x7994003c,0x2c140073}},	//   paks, rmbu, tiyw, _तिथं_, 
   {{0x213c3386,0x00000000,0x00000000,0x00000000}},	//   neuh_, --, --, --, 
   {{0xfbc40022,0x79940309,0xb74802dd,0x00000000}},	// [1ddc0] _ибио, riyw, мпаз_, --, 
   {{0x3f8401f0,0x213c0c6a,0x79940784,0x7ac4013d}},	//   nhlu_, heuh_, siyw, _үсүе, 
   {{0x213c0438,0xacb8002d,0xa3c4033f,0x76240209}},	//   keuh_, ngûn, ैगन_, тмез, 
   {{0x213d3297,0x7de000e2,0x3f84031c,0x57a40408}},	//   jeuh_, _cēsi, hhlu_, ăшта, 
   {{0x213c0438,0x3f84014b,0xa82001ed,0x752001c4}},	//   deuh_, khlu_, _نکلن, rgoz, 
   {{0xb2713298,0x213c003e,0xb4b0033f,0x37740006}},	//   иклә, eeuh_, _ऑडी_, _рымс, 
   {{0xf1a53299,0x3f84025c,0x00000000,0x00000000}},	//   крин, dhlu_, --, --, 
   {{0x213c0438,0x00000000,0x00000000,0x00000000}},	//   geuh_, --, --, --, 
   {{0x30a400a7,0x2128068c,0xa5041fbe,0x1ce00327}},	//   ъркв, òcha_, _шета_, _སྔེ_, 
   {{0xd379329a,0x3f840978,0x00000000,0x00000000}},	//   _biće_, ghlu_, --, --, 
   {{0x213c00d5,0x7c200115,0x312400f7,0xee85329b}},	//   beuh_, _ĥora, _адег, тыпо, 
   {{0x213c00d5,0xeb9c0fac,0x3f8400d7,0x00000000}},	//   ceuh_, rsøm_, ahlu_, --, 
   {{0x2dd40050,0x8f3400ea,0xeabc0154,0xd1b800d1}},	//   _یُتھ_, _белц, _আলেম, _قاچا_, 
   {{0x3f84016d,0x7ff005d9,0xd37800f3,0x1dc496da}},	//   chlu_, _اڳيا, _fiće_, лөөн, 
   {{0x2e480801,0xeb9c03cd,0x2d880129,0x00000000}},	//   _цяло_, lsøk_, èbes_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d5d329c,0x08540948,0x451800cc,0xaa4000d1}},	// [1ddd0] _inqa, ываю, ণ্ডক_, _ھۆرى, 
   {{0x6d4c0c8c,0x25c892f8,0x00000000,0x00000000}},	//   ldca, िष्ण, --, --, 
   {{0x1b74082e,0x213c3386,0x099403f6,0xf1c000cd}},	//   _خديج, yeuh_, _банџ, शतान, 
   {{0x6d4c7635,0xf72c0092,0x00000000,0x00000000}},	//   ndca, _አዛውን, --, --, 
   {{0x6d5c014b,0xf3f8008e,0x00000000,0x00000000}},	//   _mnqa, емчә_, --, --, 
   {{0x213c1dd4,0x387000d1,0xf8b40150,0x00000000}},	//   weuh_, _уқут, _сөс_, --, 
   {{0x8235329d,0x6d5c379d,0xdb1c0b1a,0xd79400ee}},	//   ارتا, _onqa, rmrø, _тиръ, 
   {{0x201c0869,0x5275329e,0x213c003e,0x3ea401d5}},	//   tuui_, рушу, ueuh_, ғимг, 
   {{0x213c0438,0x3f8400a9,0xd5b9329f,0x432401ed}},	//   reuh_, thlu_, _рср_, _مذاہ, 
   {{0x6d5c4375,0xd3782d2b,0x7f8452c8,0x6d4c7562}},	//   _anqa, _piće_, الدن, edca, 
   {{0xbd44092f,0x201c0194,0x6d4c01f5,0x213c0098}},	//   هندي, suui_, fdca, peuh_, 
   {{0x201c06c8,0xacb80af2,0xd17402d5,0x66c0022e}},	//   puui_, tfûp, _вышы, lеks, 
   {{0x1f200014,0x3f980129,0x00000000,0x00000000}},	//   _نِشہ, ésus_, --, --, 
   {{0x6d5d32a0,0x200801f1,0xd3783c52,0x50380150}},	//   _enqa, áciu_, _tiće_, _شيىڭ_, 
   {{0x81e400bd,0x7f40003a,0x6a8000d8,0x00000000}},	//   বীর_, melq, блра, --, 
   {{0xfaa40107,0x00000000,0x00000000,0x00000000}},	//   ваҳо, --, --, --, 
   {{0x442c0457,0xacb8006a,0x4c34004e,0x00000000}},	// [1dde0] _nqe_, ngûl, _кээт, --, 
   {{0x2724004e,0xe724011c,0x00000000,0x00000000}},	//   лжуп_, лоуд_, --, --, 
   {{0x7bdd32a1,0x442d32a2,0x00000000,0x00000000}},	//   _iipu, _aqe_, --, --, 
   {{0x7bdd32a3,0xf50532a4,0x442c0200,0xd9b400d1}},	//   _hipu, уздо, _bqe_, _ئەرد, 
   {{0x7f400023,0x64a09607,0x00000000,0x00000000}},	//   kelq, баца, --, --, 
   {{0x66e035f7,0x7bdc047e,0xb6f802dd,0xd370007b}},	//   _гора, _jipu, _سىرا_, تهت_, 
   {{0x442c014b,0x7bdc0099,0x200c1445,0xe734010b}},	//   _eqe_, _mipu, _avgi_, _щер_, 
   {{0xeb9c03cd,0x66c001a9,0xb42406c2,0xf77000d1}},	//   tsøk_, rеkt, _معطو, _ئاڭ_, 
   {{0x442d32a5,0x7bdc0588,0x61400a5b,0x00000000}},	//   _gqe_, _oipu, сења, --, 
   {{0xceb80b8d,0xeb9c03a1,0xe8fc05c7,0x7f400309}},	//   кәй_, rsøk_, _hoût_, gelq, 
   {{0xeb9c00d4,0x43741513,0x7aec02d0,0x00000000}},	//   ssøk_, _тутт, dcbt, --, 
   {{0x7bdd32a6,0x57a402d3,0x4fc40220,0xeb9c03cd}},	//   _aipu, _ገዛእቲ_, ысқа, psøk_, 
   {{0x7bdd32a7,0x7f40014f,0xc0e00023,0x00000000}},	//   _bipu, belq, ነኩም_, --, 
   {{0x7bdc72ec,0xdfcc084e,0xe0d40108,0x09ac05c0}},	//   _cipu, _فين_, _свч_, चव्य, 
   {{0x7bdd32a8,0x5fb808c3,0x00000000,0x00000000}},	//   _dipu, _רצונ, --, --, 
   {{0xd5a49105,0x6d5d32a9,0x7bdcbb81,0xd9280276}},	//   _رہ_, _unqa, _eipu, лцул_, 
   {{0x5d84a534,0x7bdc03b2,0x2de40150,0x66c0022e}},	// [1ddf0] _دليل, _fipu, _ﺍﻟﻀﻤ, yеks, 
   {{0xe8fc2047,0x7bdd32aa,0x3244010c,0x00000000}},	//   _août_, _gipu, ረተሰባ, --, 
   {{0x290c01e7,0x00000000,0x00000000,0x00000000}},	//   ógas_, --, --, --, 
   {{0xe505082e,0xe8fc20ef,0xe8dc063f,0x7bdd32ab}},	//   اباي, _coût_, _klọb_, _zipu, 
   {{0x7bdc047e,0x28040118,0x8898010f,0xb4b40022}},	//   _yipu, átně_, _סבֿי, аицә, 
   {{0x7bdc02b9,0x63e00046,0xf8b4011a,0x00000000}},	//   _xipu, _ۇيرە, _כפרי_, --, 
   {{0x99d404d3,0x45d4023a,0x00000000,0x00000000}},	//   _ختیا, _вовс, --, --, 
   {{0xe8fd32ac,0x7de000e2,0xd5b8011c,0x00000000}},	//   _goût_, _mēst, _бсу_, --, 
   {{0x7c200115,0x91480063,0x7de00171,0x7f400327}},	//   _ĥoro, учја_, _lēst, telq, 
   {{0xe9dc0332,0x00000000,0x00000000,0x00000000}},	//   _liú_, --, --, --, 
   {{0xc0d41772,0xefc401c0,0x00000000,0x00000000}},	//   _ጭፍራ_, рлэл_, --, --, 
   {{0x7bdd32ad,0x7f4000db,0xe9dc010e,0x4034119e}},	//   _sipu, selq, _niú_, _ведс, 
   {{0x7bdd32ae,0x3178010f,0x5de00220,0x257403e0}},	//   _pipu, _שאנד, _ﺍﻟﻌﺴ, _uçlu_, 
   {{0x7f40047e,0xe62c0092,0x00000000,0x00000000}},	//   qelq, _አጋንን, --, --, 
   {{0x7bdd32af,0x00000000,0x00000000,0x00000000}},	//   _vipu, --, --, --, 
   {{0xd3789d28,0xe9dc0332,0x7bdc014f,0x7de00171}},	//   _mića_, _ciú_, _wipu, _dēst, 
   {{0x7bdd32b0,0x7d14009a,0xe8e532b1,0x7de00171}},	// [1de00] _tipu, _idys, рмуд_, _vēsu, 
   {{0x1ce0031c,0xa760a90c,0x6d4801e7,0x00000000}},	//   _སྔག_, окуд, _ógar, --, 
   {{0xe9dc2961,0x7d1400bc,0xbb8400f1,0x00000000}},	//   _fiú_, _kdys, _ملکي, --, 
   {{0x26140c2e,0x14c804fb,0xeb9c05ac,0x00000000}},	//   _पटरी_, ههای_, drøy_, --, 
   {{0x5de00150,0x395000c0,0x00000000,0x00000000}},	//   _ﺍﻟﻔﺴ, mdys_, --, --, 
   {{0xd378098d,0x39500153,0xae040412,0x6c54010f}},	//   _bića_, ldys_, वीडन_, יינא_, 
   {{0x7d1532b2,0xeb9c0158,0x75d4007b,0x39500076}},	//   _odys, grøy_, _نيسا, odys_, 
   {{0x395132b3,0x7d140240,0x35a4004e,0x00000000}},	//   ndys_, _ndys, _табг, --, 
   {{0x2b400083,0x3950062c,0xfff401b9,0x00000000}},	//   yejc_, idys_, یغیگ, --, 
   {{0x395002f6,0xd378009b,0x7d1532b4,0x3ea800cd}},	//   hdys_, _fića_, _adys, _śata_, 
   {{0x50641c5c,0x798402d0,0x39500153,0xb14400d8}},	//   ртқа, _olkw, kdys_, _внел, 
   {{0x40840184,0xd1301ec7,0x6a1400f2,0x00000000}},	//   рҙәм_, _رمت_, یبزر, --, 
   {{0x7d1400a9,0x395132b5,0xcff400a7,0xe9dc01e7}},	//   _ddys, ddys_, _уплъ, _riú_, 
   {{0x7d1532b6,0xe9dc0270,0x798532b7,0x39500076}},	//   _edys, _siú_, _alkw, edys_, 
   {{0xda7932b8,0x798402d0,0x00000000,0x00000000}},	//   аят_, _blkw, --, --, 
   {{0x7de00029,0x99640137,0xcc880691,0x39500064}},	//   _vēst, отул, _منعه_, gdys_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [1de10] --, --, --, --, 
   {{0xf0d001f2,0x798402d0,0x39500363,0x7d140210}},	//   _aịkọ, _elkw, adys_, _zdys, 
   {{0x2fcc037e,0x0ce80154,0x395000c0,0x00000000}},	//   _mhfg_, পরীত, bdys_, --, 
   {{0x3ed8008f,0xeb9c0158,0x00000000,0x00000000}},	//   אַנא, vrøy_, --, --, 
   {{0xf0d001f2,0xd3780e04,0x427401c6,0x437400db}},	//   _dịkọ, _sića_, өгдс, йукт, 
   {{0xd3780989,0x00000000,0x00000000,0x00000000}},	//   _pića_, --, --, --, 
   {{0x386401e4,0x65640114,0xd51800ec,0x00000000}},	//   ĥore_, _књаж, _چڙهڻ_, --, 
   {{0x01640cfc,0xc02801c0,0xef1400fb,0x1b2000eb}},	//   скио, гжиж_, ҡмы_, ম্পে_, 
   {{0x68f800c5,0x2d880332,0x7fd80798,0x00000000}},	//   _õudu, dhce_, лфот_, --, 
   {{0x645932b9,0x39500024,0x00000000,0x00000000}},	//   _irui, zdys_, --, --, 
   {{0xfce532ba,0x69cc0010,0x425400f1,0x39500731}},	//   йоно, _ohce, _دنار, ydys_, 
   {{0x645932bb,0x8cd800c5,0x2d8801e7,0x00000000}},	//   _krui, नेभो, ghce_, --, 
   {{0x7fd40212,0x00000000,0x00000000,0x00000000}},	//   _лікі, --, --, --, 
   {{0x7f8404fb,0xdef80276,0xdbb80ce8,0xdb2400a2}},	//   _دلتن, _рыд_, ртмә_, _ösül, 
   {{0xb9c402da,0x8e740117,0x00000000,0x00000000}},	//   متره, _муъч, --, --, 
   {{0x69cc65f3,0x2d880232,0x6d480124,0x64580332}},	//   _chce, chce_, _ógap, _orui, 
   {{0x395132bc,0xf0d0063f,0xbc24030c,0x778532bd}},	// [1de20] rdys_, _rịkọ, _ارعى, блаз, 
   {{0xdb243629,0x7c2532be,0x00000000,0x00000000}},	//   _بودی, mukr, --, --, 
   {{0x645826fc,0xe734074d,0x6284031c,0x00000000}},	//   _arui, сех_, _żjon, --, 
   {{0x645932bf,0xf7e847ea,0xb4640c75,0x0ce803d4}},	//   _brui, _مرسى_, йкел, পৰীত, 
   {{0x64586652,0x853400f7,0x00000000,0x00000000}},	//   _crui, تونچ, --, --, 
   {{0x645932c0,0x201c0333,0xdeb81772,0xf6080aad}},	//   _drui, drui_, ደልን_, _متره_, 
   {{0x645932c1,0x7c240113,0x64941321,0x05b800d1}},	//   _erui, hukr, итәр_, ددەت_, 
   {{0x7c2532c2,0xa918008c,0x645932c3,0x96b8022e}},	//   kukr, _alþj, _frui, _буғу_, 
   {{0x645932c4,0xb4a80816,0x00000000,0x00000000}},	//   _grui, _сказ_, --, --, 
   {{0xc0f40023,0x7c240254,0x161c05dc,0x00000000}},	//   _ዉዕል_, dukr, _पटार_, --, 
   {{0xa2bc3517,0x64580165,0x00000000,0x00000000}},	//   _लुप्, _zrui, --, --, 
   {{0xd3780841,0x00000000,0x00000000,0x00000000}},	//   _kićo_, --, --, --, 
   {{0x7c2532c5,0x201c003a,0xb324031c,0x2de40046}},	//   gukr, crui_, _རྐོང_, _ﺍﻟﻌﻤ, 
   {{0x395c013f,0xd3780960,0x764c0158,0x67340175}},	//   _ɔtse_, _mićo_, _osby, xfxj, 
   {{0x98b0003d,0x6f08127b,0x00000000,0x00000000}},	//   _ħaġa_, _iefc, --, --, 
   {{0x7c241717,0x5a3532c6,0x6f08e456,0x81e400cc}},	//   bukr, янст, _hefc, বীক_, 
   {{0x7c244299,0x764c0076,0xfcc002dd,0x00000000}},	// [1de30] cukr, _asby, _жәрм, --, 
   {{0x645801ab,0xf4540055,0xeb040063,0xd7700092}},	//   _rrui, _haḷā_, _учио, _አረቢያ_, 
   {{0xfd5400b8,0x3950023a,0x645808c2,0x201c0337}},	//   _adaṇ, önsä_, _srui, zrui_, 
   {{0xd6d932c7,0x645932c8,0xfcbc0020,0x1c20dadd}},	//   сту_, _prui, ደርጉ_, _बिमल_, 
   {{0x5c5c008f,0x00000000,0x00000000,0x00000000}},	//   ָדוק, --, --, --, 
   {{0x27e932c9,0x82180022,0x6f08003a,0x2908319c}},	//   _iucn_, ацит_, _nefc, _heca_, 
   {{0xd498723c,0x29080cf4,0x68f8000d,0x7c2532ca}},	//   ирә_, _keca_, _õuds, zukr, 
   {{0x201d32cb,0x645932cc,0x29080cf4,0x41741e4a}},	//   trui_, _trui, _jeca_, تاتس, 
   {{0x290823e0,0xff2532cd,0x64580ecf,0x25bc03f9}},	//   _meca_, омпо, _urui, _ikul_, 
   {{0x290932ce,0x764c00a9,0x7c2402c4,0x201c0393}},	//   _leca_, _ysby, vukr, rrui_, 
   {{0x27e03a0e,0xa5242fb5,0xb4e00241,0x00000000}},	//   _mijn_, _ལྐོག_, _áàri, --, 
   {{0x27e00cf9,0x201c054e,0x6448058a,0x00000000}},	//   _lijn_, prui_, owgi, --, 
   {{0xef0d32cf,0x09ac015b,0x6f0932d0,0x3f6801a9}},	//   _ом_, _কীভা, _fefc, _вило_, 
   {{0x27e001f5,0xa92000d0,0x00000000,0x00000000}},	//   _nijn_, ížne, --, --, 
   {{0x7c2532d1,0x25bc0365,0xa2bc0316,0xb9740120}},	//   sukr, _okul_, _लुम्, оѓањ, 
   {{0x290932d2,0xfcbc0020,0x25bc0564,0xae4001d9}},	//   _ceca_, ደርግ_, _nkul_, _کھیو, 
   {{0x290932d3,0xcd280150,0x8bf0015b,0xbb7400ee}},	// [1de40] _deca_, _اسىن_, জীবন_, _дунъ, 
   {{0xb6a40a31,0x25bc0254,0x2b500208,0xf624109a}},	//   оизл, _akul_, _gaxc_, жджо, 
   {{0x2908928e,0xeb9c03cd,0x27e0036e,0x00000000}},	//   _feca_, rsøt_, _dijn_, --, 
   {{0x2e3800c8,0xdb24179e,0x79580408,0x00000000}},	//   יגענ, _بوگی, _тимĕ, --, 
   {{0x27e00cf9,0xa2bc085c,0x00000000,0x00000000}},	//   _fijn_, _लुब्, --, --, 
   {{0xe4ec0037,0x237401c8,0x00000000,0x00000000}},	//   _छलथि_, يمند_, --, --, 
   {{0x09bc0f22,0x6f080175,0x290800e4,0x64480009}},	//   _আওতা, _refc, _yeca_, awgi, 
   {{0x27e045eb,0x63800588,0xeb9c0fac,0x00000000}},	//   _zijn_, згәа, nsør_, --, 
   {{0x64a0afa0,0x33186ea9,0xa0640114,0x00000000}},	//   _жата, _نزاد_, жања_, --, 
   {{0x324410e0,0x212c01c3,0x26c00175,0x437400db}},	//   _мезг, _ecgh_, _yyjo_, _нухт, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x91fc0055,0x3dd00042,0xafe401a9,0x00000000}},	//   _arāg, _chyw_, _додл, --, 
   {{0x290932d4,0x3164005a,0x83fc01d3,0x00000000}},	//   _reca_, _inoz_, _erőf, --, 
   {{0x81e402f5,0x50440209,0xdb100248,0x9f5000c0}},	//   বীও_, _меҗб, _òfìf, _овіч, 
   {{0xd37856c0,0x27e132d5,0x91fc00b8,0x00000000}},	//   _moć_, _rijn_, _drāg, --, 
   {{0x27e001f5,0x00000000,0x00000000,0x00000000}},	//   _sijn_, --, --, --, 
   {{0x27e00cf9,0x29082109,0x91fc00b8,0x21280ba1}},	// [1de50] _pijn_, _veca_, _hrād, òchi_, 
   {{0xd3781326,0x25bd32d6,0xac9002f4,0x2908020c}},	//   _noć_, _skul_, _нақш, _weca_, 
   {{0xa524031c,0x7c200115,0x27e0036e,0x00000000}},	//   _ལྐུག_, _ĥori, _vijn_, --, 
   {{0x27e00cf9,0xa92412e3,0xdcf40327,0xceb800c0}},	//   _wijn_, _بعده, ħaħa, lgęs_, 
   {{0x27e001a4,0x6fb80073,0xe78401f0,0xdb1c950c}},	//   _tijn_, ईकां, _дуво, llrá, 
   {{0xceb80006,0x6448015d,0x00000000,0x00000000}},	//   ngęs_, rwgi, --, --, 
   {{0xa918008c,0xd37863e0,0x170801ed,0x1ce0031c}},	//   _alþi, _doć_, _ذہنی_, _སྔན_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xacb8019f,0x3dd000a9,0xdeb8001f,0x0fe801ec}},	//   pfûy, _rhyw_, ደውን_, олық_, 
   {{0x62940005,0x398c00a2,0x00000000,0x00000000}},	//   úxos, _iýse_, --, --, 
   {{0xef0c00aa,0x5335275a,0x8cd801ad,0x00000000}},	//   اڼه_, _цехт, नेसो, --, 
   {{0xee3447f9,0x00000000,0x00000000,0x00000000}},	//   чню_, --, --, --, 
   {{0xd1b932d7,0x91fc0aed,0xa2bc05f9,0xd69c01e4}},	//   _بالا_, _prāg, _लुत्, _jarϲ, 
   {{0x705000c6,0xdb1c0023,0xf090011a,0x98a000c0}},	//   _أنوا, morë, _אנד_, ngią_, 
   {{0x91fc005f,0xbdf80132,0xeb942910,0xdb1c0240}},	//   _grād, _ارتا_, чир_, lorë, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb1c02d3,0xeb9c00b5,0x3ff8010f,0xb808007b}},	// [1de60] norë, rsør_, מפּע, صيام_, 
   {{0xc3200c58,0xeb9c0a64,0x3f840024,0x4ad80014}},	//   প্তি_, ssør_, nklu_, _ڈاپھ_, 
   {{0xf98932d8,0x3f840194,0x4ad801d9,0x00000000}},	//   _هندي_, iklu_, _واپھ_, --, 
   {{0x37e43edf,0x7c340240,0x00000000,0x00000000}},	//   _номг, _kqyr, --, --, 
   {{0xe4e02626,0xd37801a6,0x3f8532d9,0xb7a800cc}},	//   нішн, _poć_, kklu_, _কঠীয়, 
   {{0x3f8400f3,0xdb1c0023,0x87b81086,0x00000000}},	//   jklu_, dorë, _дуст_, --, 
   {{0x398d32da,0x64a00124,0x92940022,0x00000000}},	//   _eýse_, _ҧаса, ьакц, --, 
   {{0x7dd401d3,0xdb1c036e,0x88ac00fe,0x3f8532db}},	//   lásf, forë, _খৰিক, eklu_, 
   {{0xfce80092,0xdb1c0200,0x60cc013d,0xb62401ec}},	//   _መሸጫ_, gorë, _ğimä, _ﺭﻩ_, 
   {{0x91fc0882,0xa854011a,0xa24400db,0x00000000}},	//   _prād, ליפה_, ترۇۇ, --, 
   {{0xdb1c1497,0xb62c00b5,0x959801e1,0x83fc00e5}},	//   morè, _ｓｆ_, _è̟s̟, _erőd, 
   {{0xdb1c0240,0x66d00064,0x00000000,0x00000000}},	//   borë, _užkū, --, --, 
   {{0x2174011a,0x7dd400e5,0x8fd001ee,0x00000000}},	//   _מתאר_, kásf, _иҙиә, --, 
   {{0xdb1c0066,0xceb80024,0x3f84002f,0x27fc0200}},	//   norè, ugęs_, cklu_, _çuni_, 
   {{0x38f802e3,0x5a44ede6,0xca4801e2,0xceb800c0}},	//   _ọkụk, нэта, غلره_, rgęs_, 
   {{0x9eb40724,0x8708015b,0x00000000,0x00000000}},	//   _эшчә, _লাইফ_, --, --, 
   {{0xa4080c2e,0xdb1c0100,0x7dd40332,0x00000000}},	// [1de70] _सौंप_, korè, fásf, --, 
   {{0xd874621e,0x00000000,0x00000000,0x00000000}},	//   راقب, --, --, --, 
   {{0x2b8c03e0,0x0e2c0023,0xe4a40107,0xdb1c036e}},	//   _cüce_, _ተሰኪም, ӯрдо, zorë, 
   {{0xdb240241,0x00000000,0x00000000,0x00000000}},	//   _àròp, --, --, --, 
   {{0x43940da9,0x43740229,0xdb1c01e3,0x00000000}},	//   мадс, дуйт, rmrö, --, 
   {{0x332c0204,0xdb1c00f2,0x296400f1,0x3f84025c}},	//   ggfx_, gorè, _بیړۍ_, xklu_, 
   {{0x69c00036,0x91fc00e2,0x2b8c0790,0x98a0012d}},	//   _ënes, _arāb, _güce_, rgią_, 
   {{0xdb1c044e,0x806422e9,0xacb800d2,0xf65002e4}},	//   torë, движ, ngûs, _בצל_, 
   {{0xdb1c0ba1,0x8334036b,0x7dd400e5,0x00000000}},	//   borè, _онах, lásg, --, 
   {{0xdb1c0023,0x657932dc,0xd49801c0,0x2b8c05d1}},	//   rorë, _houh, _эрс_, _yüce_, 
   {{0x63a132dd,0xdeb8044e,0x657804ce,0xdb1c0023}},	//   minn, ደፍን_, _kouh, sorë, 
   {{0x63a132de,0x657932df,0xdce40135,0xb2b80375}},	//   linn, _jouh, _uniċ, _ומער, 
   {{0x657932e0,0x63a01368,0x2fd0025a,0x20c8113e}},	//   _mouh, oinn, ängü_, _اباي_, 
   {{0x63a132e1,0x3c340174,0x00000000,0x00000000}},	//   ninn, ræv_, --, --, 
   {{0x6e90b23e,0xdb1d32e2,0x63a132e3,0xd9c400fe}},	//   _للوا, noré, iinn, ্দসম, 
   {{0xa964cfdc,0x98a01710,0x2c140073,0x00000000}},	//   миса_, ngić_, _तिचं_, --, 
   {{0xb9042413,0x63a132e4,0xa3bc08a3,0xdb1d32e5}},	// [1de80] _पण_, kinn, ीता_, horé, 
   {{0x63a132e6,0xdb1d32e7,0x62800f91,0x00000000}},	//   jinn, koré, kyno, --, 
   {{0x63a132e8,0x65780007,0xdb1c4de4,0x62800200}},	//   dinn, _bouh, joré, jyno, 
   {{0x65780007,0xbb48036b,0x63a0d918,0x058401ec}},	//   _couh, _الگن_, einn, нуім, 
   {{0x63a132e9,0x6578037e,0xdb1c020c,0x3eb80210}},	//   finn, _douh, torè, ęsty_, 
   {{0xf6246fbd,0x63a132ea,0x80c0033f,0x62800042}},	//   _одго, ginn, _लड़े, fyno, 
   {{0xe1f45dc9,0x628132eb,0x7c240e78,0xdb1c00d5}},	//   үгә_, gyno, hrkr, goré, 
   {{0xdb1c049f,0x65780156,0xd378110c,0x386001c7}},	//   llrä, _gouh, _mići_, _krkr_, 
   {{0xe4c0006c,0x63a132ec,0xd6b0015b,0x62800076}},	//   _айти, binn, _করিয, ayno, 
   {{0x63a132ed,0x657801c7,0xdb1d32ee,0x62800042}},	//   cinn, _zouh, boré, byno, 
   {{0x657932ef,0xdb1c2d7d,0x62800210,0x00000000}},	//   _youh, coré, cyno, --, 
   {{0xd6b00154,0xdb1c002f,0x00000000,0x00000000}},	//   _করায, hlrä, --, --, 
   {{0x5c74230c,0x66140175,0x00000000,0x00000000}},	//   влят, zsxk, --, --, 
   {{0xeaf82cbb,0x91fc00ef,0x1fb0008e,0xd1c80244}},	//   ्रेत_, _grāc, _үсәр, _ببڕم_, 
   {{0x7c2405e4,0x00000000,0x00000000,0x00000000}},	//   arkr, --, --, --, 
   {{0xd37807f5,0x4ea4006c,0x63a132f0,0xdce40122}},	//   _dići_, _орқа, zinn, _znič, 
   {{0x63a132f1,0xd83805f5,0xeb0465cb,0x62800034}},	// [1de90] yinn, дэх_, _очно, zyno, 
   {{0x657932f2,0x63a09ae7,0x27e401a8,0xcb986d69}},	//   _souh, xinn, önn_, _رنجش_, 
   {{0x6578012c,0x1be8007d,0x1bb800db,0x3940007c}},	//   _pouh, _टूटल_, _تايع_, _fbks_, 
   {{0x63a132f3,0x6308015b,0x44b532f4,0xdb1d32f5}},	//   winn, _রাইট_, нбес, alrä, 
   {{0x63a132f6,0x62800368,0x78f80375,0x65780108}},	//   tinn, wyno, _מפרו, _vouh, 
   {{0x4254055f,0xdb1d32f7,0x62812eb5,0x63a00869}},	//   етит, toré, tyno, uinn, 
   {{0x63a132f8,0x657932f9,0x7dd532fa,0x29d40023}},	//   rinn, _touh, láse, rçaf_, 
   {{0x63a032ff,0xdb1d32fb,0x628132fc,0x00000000}},	//   sinn, roré, ryno, --, 
   {{0x63a132fd,0x98a00e3c,0x9f5c0407,0x44383621}},	//   pinn, rgić_, lpué_, _ës_, 
   {{0x63a020ac,0xdb1d32fb,0x9f4806be,0xd6b000cc}},	//   qinn, poré, _ölün_, _কৰিয, 
   {{0x398c1f60,0x1ee421f4,0x05200154,0x25ac015d}},	//   _lýsa_, بودی_, নভীর_, ongl_, 
   {{0x9f440023,0xf2d0008f,0x00000000,0x00000000}},	//   _kinë_, _געב_, --, --, 
   {{0xd3780e3c,0xa2812689,0x39400fac,0x7c24017a}},	//   _sići_, _سیکو, _rbks_, urkr, 
   {{0xe51c2e1e,0xdce4151c,0xbb5400b5,0x1ee401d5}},	//   मृति_, _unič, _subケ_, _قوشی_, 
   {{0xaa40e695,0x9f4c0023,0xdb1c0356,0xb0600037}},	//   лерл, _lugë_, borî, _äärs, 
   {{0xdce40135,0x5a540131,0x9f5c00a2,0x00000000}},	//   _eliġ, нъғу, msuñ_, --, 
   {{0xfc300597,0x7dd403b2,0x00000000,0x00000000}},	// [1dea0] _صحة_, gáse, --, --, 
   {{0x61c800cd,0xb88401ef,0x00000000,0x00000000}},	//   ातुष, jníž, --, --, 
   {{0xfaa4016c,0x98c000ac,0xdb1c015d,0x7aa4009d}},	//   _чано, ırıq_, lorï, _чинз, 
   {{0x3dc0014b,0x7dd401ed,0x75d4009a,0x00000000}},	//   nokw_, lásb, ريشا, --, 
   {{0x7dd40077,0xe5e417a5,0x24040354,0x2d580139}},	//   cáse, رزمی, енчи_, lüeñ_, 
   {{0x9f4402d3,0xecd0012c,0x25ad14b7,0x6e380efa}},	//   _dinë_, _सरसफ, angl_, yttb, 
   {{0x3dc0014b,0x73340e56,0x00000000,0x00000000}},	//   kokw_, _ۋىرا, --, --, 
   {{0x45b00131,0x3e740064,0x00000000,0x00000000}},	//   ﻳﺎﻟﻼ, ižtą_, --, --, 
   {{0x7dd401d3,0xe3600075,0xb4640166,0x00000000}},	//   kásb, _өкти, _якал, --, 
   {{0x64a00046,0x9f4c01e1,0xd3e40214,0xa3b800cd}},	//   _сауа, _jugè_, _شقای, घवः_, 
   {{0x9f4532fe,0x7dd401d3,0x98a0033f,0x00000000}},	//   _minè_, dásb, rgię_, --, 
   {{0x222804fb,0xc0a80451,0x00000000,0x00000000}},	//   _رزمی_, _ڪامل_, --, --, 
   {{0xdb1c0368,0x9a8401b9,0x3e7400c0,0x00000000}},	//   gorï, қурл, ežtą_, --, 
   {{0xc0a8521e,0x205401e4,0x00000000,0x00000000}},	//   _تامل_, _ריגל_, --, --, 
   {{0x99940024,0x2d580139,0x1c200037,0x00000000}},	//   _šeši_, güeñ_, _बिअल_, --, 
   {{0xe9d001d9,0xb88400d7,0x00000000,0x00000000}},	//   اغس_, zníž, --, --, 
   {{0x6d4d32ff,0x9f4402e2,0x00000000,0x00000000}},	// [1deb0] meca, _binè_, --, --, 
   {{0x6d4d3300,0x7dd41125,0x9dec000d,0x00000000}},	//   leca, ráse, _घूँघ_, --, 
   {{0x765801a2,0x9f4c0267,0x9a840bd6,0xdec80023}},	//   _štyr, _utgå_, _буял, _በራኺ_, 
   {{0x2d880316,0x9f440240,0x00000000,0x00000000}},	//   nkce_, _pinë_, --, --, 
   {{0x6d4c0a73,0x3880013f,0xe7ac00cc,0x984800c0}},	//   ieca, tɔre_, _কঠীয, _пяра_, 
   {{0xe610021a,0x6d4c82be,0xd49805f5,0x8234035c}},	//   _مشر_, heca, эрх_, نربا, 
   {{0x6d4c525e,0x86c431ed,0x3dc00117,0x41b53301}},	//   keca, _شيرن, yokw_, ксит, 
   {{0x6d4c1727,0xf8ac01d9,0x38800134,0x7dd401d3}},	//   jeca, _اکہ_, sɔre_, zásb, 
   {{0x6d4d3302,0xdc3c005f,0x213c031c,0x00000000}},	//   deca, ršīg, rfuh_, --, 
   {{0xd3781050,0xf07401ed,0x9f442d7d,0x49800092}},	//   _biću_, ئیوں_, _kiné_, _የወቅቱ_, 
   {{0x6d4c0076,0x9f440316,0x9f4c33a2,0x3dc0014b}},	//   feca, _jiné_, _jugé_, tokw_, 
   {{0x6d4d3303,0x91fc1a14,0x00000000,0x00000000}},	//   geca, _krān, --, --, 
   {{0x61e80472,0x7dd401ed,0x443c0472,0xdd0c012d}},	//   _iigl, tásb, ntw_, _półf, 
   {{0xd3780e04,0x61e80009,0x26dc01e4,0x2d8801ef}},	//   _fiću_, _higl, _ĝuon_, akce_, 
   {{0x6d4d3304,0x61e80357,0x9f440066,0x26dc0115}},	//   beca, _kigl, _niné_, _ŝuon_, 
   {{0x6d4c127b,0xbc640124,0xdb1d3305,0x61e800a2}},	//   ceca, _авик, morí, _jigl, 
   {{0x61e93306,0xdb1c3a6c,0x9f453307,0x257400a2}},	// [1dec0] _migl, lorí, _pinè_, _uçly_, 
   {{0x61e93308,0x60c800a2,0x9e600023,0x00000000}},	//   _ligl, _mygm, _ስራሕና_, --, 
   {{0x443c0354,0xdb1c21fc,0x9f453309,0x31b8005f}},	//   etw_, norí, _ciné_, līze_, 
   {{0x7bcd330a,0x9f45330b,0x61e800ad,0x443c0332}},	//   llbu, _diné_, _nigl, ftw_, 
   {{0x7bcc0af9,0xa3bc00dc,0x25b40306,0x60c8010b}},	//   olbu, ीतं_, _želé_, _nygm, 
   {{0x61e9330c,0x91fc0171,0x6d4c0857,0x64a0222a}},	//   _aigl, _drān, zeca, шача, 
   {{0x61e9330d,0xe735330e,0xdb1d330f,0x6d4d3310}},	//   _bigl, _шер_, jorí, yeca, 
   {{0xdb1d3311,0x6d4c0137,0x60c93312,0x59d85ae4}},	//   dorí, xeca, _bygm, _भीमर, 
   {{0x61e93313,0x6d4d3314,0xd3780841,0x443c012d}},	//   _digl, veca, _siću_, ctw_, 
   {{0x61e8062c,0xd3780960,0xdb1c004e,0x6d4c009a}},	//   _eigl, _piću_, forí, weca, 
   {{0x61e93315,0xdb1d3316,0x6d4d3317,0x3f98036e}},	//   _figl, gorí, teca, ësua_, 
   {{0x61e93318,0xa1800a8f,0x7bcc01f5,0x00000000}},	//   _gigl, _вышл, elbu, --, 
   {{0x2d893319,0xae040927,0x6d4c241f,0xdf54036b}},	//   rkce_, वीजन_, reca, رشیش_, 
   {{0x6d4d331a,0x61e819f5,0xdb1c0d50,0x00000000}},	//   seca, _zigl, borí, --, 
   {{0x61e85395,0x60c9331b,0xef904d66,0x00000000}},	//   _yigl, _zygm, _میکد, --, 
   {{0x7bcd331c,0x61e8011f,0x79940368,0x66e00cf1}},	//   albu, _xigl, ghyw, _कृषक_, 
   {{0x5d8416ac,0xf8b5331d,0x9814007b,0x00000000}},	// [1ded0] _خليل, гөр_, لبلا, --, 
   {{0x4b200131,0x7dd400e5,0x00000000,0x00000000}},	//   _دېسە, mása, --, --, 
   {{0x80c80316,0x947404fb,0x7dd5331e,0xdb1c0311}},	//   _हुने, یدها, lása, borâ, 
   {{0xd6d84cbe,0x799402d0,0x91fc6991,0x09bc00fe}},	//   тту_, chyw, _prān, _আওকা, 
   {{0x61e9331f,0xd7f80588,0x04440b3e,0xdb1c00e5}},	//   _rigl, _аус_, уелн, zorí, 
   {{0xdb1cdbd1,0x070823bb,0x60c8005c,0xe7853320}},	//   yorí, _سيري_, _rygm, _румо, 
   {{0x61e93321,0x443c0034,0x7dd400c7,0x60c80432}},	//   _pigl, stw_, hása, _sygm, 
   {{0x60c93322,0xdb1c0030,0x7dd401d3,0x91fc0055}},	//   _pygm, vorí, kása, _trān, 
   {{0x61e93323,0xf948008f,0xbfc46566,0xb4b40352}},	//   _vigl, געפֿ, лбик, _битә, 
   {{0xdb1c0cc3,0x3f9002fb,0x7dd401d3,0x61e80042}},	//   torí, ózu_, dása, _wigl, 
   {{0x9f442776,0x00000000,0x00000000,0x00000000}},	//   _finî_, --, --, --, 
   {{0xed5400d6,0xc10400c6,0x7dd4007b,0x61e804cc}},	//   гою_, _صوتي, fása, _uigl, 
   {{0x71180d65,0xdb1d3324,0xeb9c03cd,0xca4c0150}},	//   _נוספ, sorí, lsøy_, _ﺍﻵﺨ_, 
   {{0xe2480023,0x79940175,0x91fc00de,0xdb1c059c}},	//   _መርትዖ, whyw, _orāl, porí, 
   {{0xeb9c0158,0xdb1c00d8,0x7994035a,0x206400f1}},	//   nsøy_, torâ, thyw, _سلګۍ_, 
   {{0x3ca405ac,0x7dd4429f,0x00000000,0x00000000}},	//   _গুণৱ, bása, --, --, 
   {{0x3864007b,0x999800bc,0xa3e002c3,0xf8a801b9}},	// [1dee0] íor_, strů_, नगा_, ردره_, 
   {{0x7d14589e,0xe7340046,0x79940796,0x91fc005f}},	//   _heys, леу_, shyw, _brāl, 
   {{0x7d153325,0x0ba853f0,0xdb1d3326,0x46f42897}},	//   _keys, _جايى_, morà, рчут, 
   {{0x7d153327,0x46a400bc,0x00000000,0x00000000}},	//   _jeys, _गइरह, --, --, 
   {{0x7d153328,0x6ec900d0,0xdb1c00d8,0x39506607}},	//   _meys, _सुनु, corã, meys_, 
   {{0x7d153329,0x3951332a,0xb7d80150,0xdb1c0137}},	//   _leys, leys_, _سوزا_, norà, 
   {{0xeb9c00fe,0x7dd401d3,0x91fc00ef,0xf1d000db}},	//   gsøy_, zása, _grāl, бөдө, 
   {{0x7d15332b,0x7415332c,0x3950b21c,0x2bd82ba2}},	//   _neys, _مورا, neys_, _मीना, 
   {{0x91fc0374,0xdb1c0109,0x395000ad,0x21280332}},	//   _irām, korà, ieys_, ócha_, 
   {{0xa2bc9401,0xa8540302,0xad240405,0x39506c25}},	//   _लुक्, נייה_, گردو, heys_, 
   {{0x7d15332d,0x59c4215d,0x307402dd,0xe19001c6}},	//   _beys, वकार, _әуес, рлөө, 
   {{0x7dd400dd,0xb8840030,0x7d140009,0xa2b8011a}},	//   tása, _zvíť, _ceys, _אמבט, 
   {{0x7d14bdad,0x39508f9a,0xad1000c7,0x61d4011a}},	//   _deys, deys_, аҿқә, _עודף_, 
   {{0x7d14058a,0x39500076,0x7dd5332e,0x00000000}},	//   _eeys, eeys_, rása, --, 
   {{0x6f19332f,0x7d153330,0x39500009,0x8e20030d}},	//   matc, _feys, feys_, _хiа_, 
   {{0x7d143516,0x19591149,0x6f193331,0x39500076}},	//   _geys, ласы_, latc, geys_, 
   {{0x5ef808a3,0x00000000,0x00000000,0x00000000}},	// [1def0] लुक्_, --, --, --, 
   {{0x6d5d3332,0x6f182681,0x91fc00b8,0x00000000}},	//   _haqa, natc, _prāl, --, 
   {{0x6d5d3333,0x7d153334,0x39500009,0x91fc00ef}},	//   _kaqa, _yeys, beys_, _brām, 
   {{0x6f193335,0x6d5d3336,0xa2bc2d3b,0x7d140009}},	//   hatc, _jaqa, _लुग्, _xeys, 
   {{0x6d5d3337,0x29193338,0x6f193339,0x91fd333a}},	//   _maqa, maqa_, katc, _wrāl, 
   {{0x6d5d333b,0xf8b5333c,0x2919333d,0x14a40490}},	//   _laqa, _төс_, laqa_, _खेळण, 
   {{0x6f19333e,0x2efc0204,0xdb1d333f,0xc2240133}},	//   datc, dctf_, norá, شکاو, 
   {{0x29193340,0x91fc0061,0x6d5d3341,0xeb9c0158}},	//   naqa_, _grām, _naqa, rsøy_, 
   {{0x7d153342,0x9f44b513,0x9f4c04cc,0x6ec802c3}},	//   _reys, _finì_, _fugì_, _सुबु, 
   {{0x6f18074d,0xdb1cc2ef,0x6d5c013c,0x64580194}},	//   gatc, korá, _aaqa, _isui, 
   {{0x41549d39,0x291802d1,0xa0700220,0x7d153343}},	//   _ввес, kaqa_, рықш, _peys, 
   {{0x6d5cbfa3,0xfce46193,0x7d153344,0x00000000}},	//   _caqa, ионо, _qeys, --, 
   {{0x6d5ccab7,0x6f193345,0x2efc0204,0x29193346}},	//   _daqa, batc, bctf_, daqa_, 
   {{0x6f18074d,0xdb1c15b0,0x39508200,0x7d140014}},	//   catc, forá, weys_, _weys, 
   {{0x6d5d3347,0x7d14011f,0x395002f6,0xd6b0015b}},	//   _faqa, _teys, teys_, _কর্প, 
   {{0x6d5c0194,0x29193348,0x7dd401ed,0xb9053349}},	//   _gaqa, gaqa_, máso, рзак, 
   {{0x7dd4066d,0x201d334a,0x80dc06ab,0x3951334b}},	// [1df00] láso, nsui_, _परफे, reys_, 
   {{0xdb1c0005,0x201c0869,0x6d5d334c,0x6618033f}},	//   borá, isui_, _zaqa, _łuka, 
   {{0x6d5d334d,0x91fc0aed,0x645802f6,0x2919334e}},	//   _yaqa, _prām, _asui, baqa_, 
   {{0x6d5d334f,0x6f193350,0x29180784,0xdc0000a2}},	//   _xaqa, zatc, caqa_, _oňün, 
   {{0x6f18036b,0xf3e40415,0x74440023,0x00000000}},	//   yatc, аждо, _መውጋእ, --, 
   {{0xb4d40d5f,0x7dd400dd,0x29d4068c,0xa344efaf}},	//   _हरी_, káso, nçan_, изча_, 
   {{0x2b440ab7,0xd2500597,0x645802ea,0x6f193351}},	//   _önce_, سنة_, _esui, vatc, 
   {{0x7dd401ed,0xd13000c6,0x00000000,0x00000000}},	//   dáso, أمة_, --, --, 
   {{0x6d5d3352,0x7dd401d3,0x91fc00ef,0x29d40139}},	//   _raqa, tásn, _krāk, kçan_, 
   {{0x6d5d3353,0x9f4c004e,0x64a000d8,0x00000000}},	//   _saqa, _fugí_, _ќафа, --, 
   {{0x6d5c22c8,0xa3e006e3,0xb4d4012c,0x201c0140}},	//   _paqa, नगर_, _हरु_, asui_, 
   {{0xdb1d3354,0x6d5d3355,0x6f1801b9,0xeda401c6}},	//   vorá, _qaqa, satc, ршоо, 
   {{0x6f193356,0x6d5c23e0,0x7dd40cde,0x91fd3357}},	//   patc, _vaqa, pásn, _orāk, 
   {{0xc0a846c9,0x6d5d3358,0x764c04ce,0xdb1c03f7}},	//   _حامل_, _waqa, _opby, torá, 
   {{0x6d5c8e3d,0x29180bf1,0x5ed001ec,0xdeec0139}},	//   _taqa, taqa_, _وتىز, _фы_, 
   {{0x80dc0404,0x6ca416ab,0xb4d4012c,0x7dd40118}},	//   _परमे, _врож, _हरू_, násl, 
   {{0x29193359,0x19580137,0xdb1c0e33,0x2cac007c}},	// [1df10] raqa_, шаты_, sorá, _ägd_, 
   {{0xe730f3d7,0x291819a2,0x6458013c,0xdb1cb4a6}},	//   تصر_, saqa_, _rsui, porá, 
   {{0xdb1c00b5,0x201c0007,0x291802d1,0x91fc002b}},	//   foræ, zsui_, paqa_, _drāk, 
   {{0x29181bb7,0x00000000,0x00000000,0x00000000}},	//   qaqa_, --, --, --, 
   {{0x7dd400dd,0x9f4401e7,0xc87800a2,0x1c20000d}},	//   záso, _siní_, _çş_, _बिछल_, 
   {{0xc8540023,0x00000000,0x00000000,0x00000000}},	//   _ዋላሓን, --, --, --, 
   {{0x06e403f4,0xc6e40c58,0x29d4315a,0xcfdc009e}},	//   _প্রি, _প্ৰচ, nçao_, ঠদান, 
   {{0x201c019b,0x6d040316,0x6458007b,0x29d400d8}},	//   tsui_, _व्लग_, _tsui, içao_, 
   {{0x64586261,0x63b000c7,0x201c04ce,0x7f19335a}},	//   _usui, _дааӡ, usui_, ліну_, 
   {{0x7dd4066d,0x201d335b,0xdb1c004e,0x00000000}},	//   táso, rsui_, morç, --, 
   {{0x201d335c,0xdce400f3,0x6ec8227c,0xa2bc045b}},	//   ssui_, _knić, _सुदु, _लुच्, 
   {{0xeb9c022c,0x7dd401ed,0x7bdc0023,0x7db4007b}},	//   spøl_, ráso, _shpu, إصدا, 
   {{0xfcc80092,0xa3d80037,0x00000000,0x00000000}},	//   _በዋጋ_, _ठठा_, --, --, 
   {{0x91fc0a28,0x398c0162,0xe818012d,0x7dd400e5}},	//   _brāh, _týsk_, _पौधा_, páso, 
   {{0x29d4180f,0x398c02d2,0x00000000,0x00000000}},	//   rçan_, _hýsi_, --, --, 
   {{0xe9dc07ae,0x4999335d,0x7bdc0175,0x7c940063}},	//   _chú_, атуя_, _whpu, _гроц, 
   {{0xa965335e,0xb4d40b7d,0x29d5335f,0x06e40011}},	// [1df20] щита_, _हरे_, açao_, _প্লি, 
   {{0x9f4c004e,0xdce401a6,0x5fc4012c,0xc8b402d5}},	//   _jugà_, _anić, रकिल, істы, 
   {{0x9f4419f5,0x29d400d8,0x91fc00dc,0x398c1d1d}},	//   _minà_, cçao_, _grāh, _lýsi_, 
   {{0x29d4180f,0xdb1cf3b0,0x66013360,0xbdf800eb}},	//   nçal_, forç, ínka, _আবাদ_, 
   {{0x91fc0a26,0xdb1c00cf,0x048400cd,0x538400d1}},	//   _irāi, gorç, _kāṅk, оқаз, 
   {{0x7984013b,0x2b8c0112,0x7dd400e5,0x00000000}},	//   _hokw, _rück_, dásm, --, 
   {{0x79853361,0xf1a53362,0x75d401c8,0xdb1c0022}},	//   _kokw, йрин, _هيسا, morä, 
   {{0x79840770,0x00000000,0x00000000,0x00000000}},	//   _jokw, --, --, --, 
   {{0x79853363,0xdb1c00cf,0xd25001d9,0x2978010f}},	//   _mokw, corç, سنک_, רטפא, 
   {{0x437529aa,0x00000000,0x00000000,0x00000000}},	//   _мухт, --, --, --, 
   {{0x9f440109,0x59c85b82,0x798402d0,0x50653364}},	//   _dinà_, लवार, _ookw, стқа, 
   {{0x79853365,0x7dd400e5,0x00000000,0x00000000}},	//   _nokw, lásj, --, --, 
   {{0xdb1c01b8,0x6f8459e6,0xa3bc0073,0x00000000}},	//   korä, _гуйж, ीतच_, --, 
   {{0x59240135,0xce940801,0x80dc0d2c,0x048400b8}},	//   _འཇུས_, _малъ, _परते, _cāṅk, 
   {{0x79853366,0xe9dc0016,0xda78664d,0x5ecc0154}},	//   _bokw, _phú_, бят_, হেবে, 
   {{0x798407a8,0x9f44026c,0x6618012d,0x3d1801f9}},	//   _cokw, _zinà_, _łuko, परणे_, 
   {{0x798402e3,0x9f440270,0xa3d807f7,0x1b180154}},	// [1df30] _dokw, _hiná_, ठतम_, _তারে_, 
   {{0x6cc00014,0x9f4400d0,0x91fc00b8,0x62840241}},	//   _وٲژٕ, _kiná_, _trāh, _àjog, 
   {{0x79840770,0xe9dd3367,0x9f44012c,0x29d4cf78}},	//   _fokw, _thú_, _jiná_, lçam_, 
   {{0x333c00ca,0x00000000,0x00000000,0x00000000}},	//   _actx_, --, --, --, 
   {{0x29d53368,0x6ec802c3,0x3d1801f9,0x00000000}},	//   nçam_, _सुसु, परते_, --, 
   {{0x7984be56,0x38b0006a,0x4208a752,0x69cc01e4}},	//   _zokw, sôrô_, анко_, _hkce, 
   {{0x79849e73,0x6604094a,0xdb1c06ed,0x9f4c04cc}},	//   _yokw, _utjk, sorç, _rugà_, 
   {{0x80dc3eb6,0xc0053369,0xdb1d336a,0x7dd400e5}},	//   _परदे, опик, porç, tásm, 
   {{0x9f4404cc,0x91fc00cd,0x00000000,0x00000000}},	//   _pinà_, _asād, --, --, 
   {{0xdb78044e,0x25ac04cc,0xf8a8008f,0x7e2400d8}},	//   _ኣለዎም_, ligl_, יספֿ, одож, 
   {{0x9f440548,0x9f4c026c,0x69cc0115,0x622000d1}},	//   _ciná_, _vugà_, _okce, _روشە, 
   {{0xda7800c6,0x045c001f,0x69cd04aa,0x25ac6a0f}},	//   αят_, _ተልዕኮ_, _nkce, nigl_, 
   {{0x7984004c,0x7dd401ed,0x29d45b80,0x41d42356}},	//   _rokw, lásk, rçal_, _डीएस, 
   {{0x69cd336b,0x7984376b,0x9f4002f6,0x9f4401e1}},	//   _akce, _sokw, öjä_, _finá_, 
   {{0x7985336c,0x29d42852,0x05c8095f,0xfb840139}},	//   _pokw, pçal_, िकाब, быңн, 
   {{0x82f8025c,0x394402d5,0x8ca40562,0x00000000}},	//   _ཕུའུ_, ўнаг, _चेको, --, 
   {{0x7985336d,0xec1008c9,0x77840640,0x7dd405f7}},	// [1df40] _vokw, _قويد, олаз, hásk, 
   {{0x7984be56,0xcc080592,0x3b080063,0x91fc002b}},	//   _wokw, _ازين_, _њено_, _irāv, 
   {{0x4c05336e,0x7985336f,0xdb1c002f,0x00000000}},	//   _وظیف, _tokw, rorä, --, 
   {{0x25ac05d5,0x91fc0171,0xe3ac0133,0x7dd400e5}},	//   gigl_, _krāv, ێرو_, dásk, 
   {{0x193c037e,0xada402d2,0xdb1c00c7,0xa9a000db}},	//   _ｒａｙ_, _hnúð, porä, _цияд, 
   {{0xada402d2,0xb6a40114,0x36680006,0x29d40200}},	//   _knúð, _дигл, _каго_, jçaj_, 
   {{0xe294026a,0xd3a40022,0x5ecc00cc,0x00000000}},	//   жај_, _ҵлақ, হেতে, --, 
   {{0x6ec800dc,0x00000000,0x00000000,0x00000000}},	//   _सुषु, --, --, --, 
   {{0x7dd53370,0x7f8c00e4,0x83fc01d3,0x82a80139}},	//   másh, _lúqu, _csőd, ибәң_, 
   {{0x7dd40646,0x00000000,0x00000000,0x00000000}},	//   lásh, --, --, --, 
   {{0x398c06ea,0xefd00092,0x00000000,0x00000000}},	//   _hýsu_, _የገዛ_, --, --, 
   {{0xfe6c943c,0xd9c40864,0xeda400d4,0x00000000}},	//   اگو_, वकोट, ішно, --, 
   {{0x6ec81804,0x9f4401e1,0xe454010f,0x09c400eb}},	//   _सुरु, _winá_, ֿילט_, ্ষমা, 
   {{0xa004489b,0x29d40798,0x6fa40034,0x91fc002b}},	//   _بقول_, rçam_, टोशू, _drāv, 
   {{0x29d400d8,0x5a4400a8,0x7dd42cda,0x398c02d2}},	//   sçam_, мэта, kásh, _lýsu_, 
   {{0x09c4045e,0x2bd83885,0xdd9800c7,0x00000000}},	//   ্ষভা, _मीरा, _мшы_, --, 
   {{0xe7093371,0x58d41952,0x25ac07c5,0x91fc0a2f}},	// [1df50] لتان_, дотт, vigl_, _grāv, 
   {{0x80dc0037,0x66013372,0xfca8010f,0x00000000}},	//   _परसे, ínko, _ליפּ, --, 
   {{0x7c2800e2,0x25ac04cc,0xdee40023,0x1ac8004e}},	//   _āfri, tigl_, _መዘና_, _муюп_, 
   {{0x5924081f,0x84c400d1,0x286800f0,0x00000000}},	//   _འཇགས_, пәзд, _крго_, --, 
   {{0x25ad3373,0x7f2c0092,0x00000000,0x00000000}},	//   rigl_, _ተጠቅሷ, --, --, 
   {{0x1d7c067d,0x57f400c9,0x7dd401ed,0x25ac0142}},	//   _ብዛዕባ_, _опят, tásk, sigl_, 
   {{0x7f8c00db,0x25ac04cc,0x80dc228d,0x96080006}},	//   _xúqu, pigl_, _परहे, _мэта_, 
   {{0xe4e402bf,0x00000000,0x00000000,0x00000000}},	//   _дізн, --, --, --, 
   {{0x7fd40220,0x7dd41686,0x00000000,0x00000000}},	//   зіні, sásk, --, --, 
   {{0x398c1d0e,0x00000000,0x00000000,0x00000000}},	//   _hýst_, --, --, --, 
   {{0x80dc16ae,0x9f440342,0x398c02d2,0x91fc00b8}},	//   _परवे, _linç_, _kýst_, _srāv, 
   {{0x91fc0aed,0x6e2c01d3,0x00000000,0x00000000}},	//   _prāv, ábba, --, --, 
   {{0x7dd465fa,0xada4148b,0xbd88006c,0x83fc01d3}},	//   nási, _snúð, لنگن_, _erőv, 
   {{0x398c2833,0xa3d80882,0xdb1c26b7,0x3f8000c5}},	//   _lýst_, ठति_, lorú, _õhu_, 
   {{0xa0d4009f,0x00000000,0x00000000,0x00000000}},	//   _اِڇا_, --, --, --, 
   {{0x3dd40c58,0xf2d0008f,0x398c08a5,0x2364036e}},	//   _সংকল, געל_, _nýst_, hdnj_, 
   {{0x23c93374,0xec6c00b2,0xb7d81b45,0x98a00327}},	// [1df60] िवाद, _مٿي_, مورا_, ffiġ_, 
   {{0x25bc003e,0x91fc1a14,0x9f440bbc,0xdca40117}},	//   _ajul_, _krāt, _dinç_, _нақи, 
   {{0x7bcc19a2,0x7dd401d3,0x398c08a5,0xd5b00014}},	//   mobu, tásh, _býst_, نہس_, 
   {{0x7dd52408,0x7bcd3375,0x7d04026c,0x00000000}},	//   fási, lobu, ncks, --, 
   {{0x7c245d86,0x9f5c0120,0x6b6c0024,0x7d0401ab}},	//   nskr, rquê_, bėgė, icks, 
   {{0x7bcca709,0x53346b63,0x7c24017a,0xfd60002b}},	//   nobu, фект, iskr, _vavṛ, 
   {{0x9f44049b,0x7c240327,0x00000000,0x00000000}},	//   _minä_, hskr, --, --, 
   {{0x7bcc000d,0xdb1c01d3,0x30a53376,0x00000000}},	//   hobu, gorú, зров, --, 
   {{0x7bcd3377,0x7dd40407,0x91fc00b8,0x752005c7}},	//   kobu, cási, _arāt, maoz, 
   {{0x08e800bd,0x9f5c0137,0x752003d1,0x7d041901}},	//   টুকু_, nquè_, laoz, ecks, 
   {{0x799403f9,0x7bcd3378,0x7c240ea0,0xdb1c01d3}},	//   kkyw, dobu, eskr, ború, 
   {{0x75213379,0xa4480122,0x2d980784,0x7c25337a}},	//   naoz, lášť_, _qlqe_, fskr, 
   {{0x7c25337b,0xb3440432,0xddcc0309,0xbaa800eb}},	//   gskr, _gaçý, ñišp, _খুলছ, 
   {{0x2009337c,0x7bcc9c1f,0x3164030a,0x15fc00e1}},	//   ície_, gobu, _haoz_, एदार_, 
   {{0x15ec0cb4,0x31640dd4,0xda79337d,0x7521337e}},	//   जगार_, _kaoz_, пят_, kaoz, 
   {{0x7c25337f,0x6e393380,0xa7f80309,0x996400a8}},	//   bskr, mutb, _asña, нтул, 
   {{0x91fc0029,0x7bcd3381,0x3164022e,0x6e380250}},	// [1df70] _krās, bobu, _maoz_, lutb, 
   {{0x7bcc2619,0x3940062c,0x9f440790,0x38780092}},	//   cobu, _ecks_, _vinç_, _በያመቱ_, 
   {{0x6e384cab,0x26dc0115,0x3940005c,0xe8e8dc96}},	//   nutb, _ĝuos_, _fcks_, _گردو_, 
   {{0x3ea000af,0x316405c7,0x7520030a,0xfa5401d3}},	//   _ühte_, _naoz_, gaoz, _کریگ, 
   {{0xd8380323,0x6e393382,0xe4c826d4,0x987400c0}},	//   _нэр_, hutb, حبان_, _зляц, 
   {{0x932410a8,0x7dd53383,0xc79801d3,0x6e3801e3}},	//   ىرىن, rási, _بھرا_, kutb, 
   {{0x7c253384,0x7d0401e6,0x75200083,0xb3440432}},	//   zskr, ycks, baoz, _saçý, 
   {{0x7bcd3385,0xdce400df,0x25bc004b,0x443800d8}},	//   zobu, _aniĝ, _ujul_, _ªs_, 
   {{0x7bcd3386,0x3164005a,0x44380af9,0x9f5c0129}},	//   yobu, _daoz_, _ês_, lqué_, 
   {{0x91fc0a2b,0x7c24fbd4,0x7bcc0472,0x94a801b9}},	//   _prāt, vskr, xobu, _этса_, 
   {{0xdb1d3387,0xee3400a8,0x31640165,0x9f5d3388}},	//   porú, мнэ_, _faoz_, nqué_, 
   {{0x9f44049b,0xdce400df,0x31640156,0x7bcd3389}},	//   _sinä_, _eniĝ, _gaoz_, wobu, 
   {{0xacb80086,0xe7bc0b7c,0x7c25338a,0x7d04002f}},	//   taûa, ्वाप, uskr, rcks, 
   {{0x6e380a73,0x70743d93,0x752006d9,0x91fc002b}},	//   butb, _آموز_, zaoz, _grās, 
   {{0xaa41338b,0x936802d3,0x8e54074d,0xcee80137}},	//   керл, _ተኽእሎ_, _пĕрл, _ىرىن_, 
   {{0xd01000c6,0x7c245be9,0x7bcd02ec,0x213d338c}},	//   _çلê_, pskr, sobu, nguh_, 
   {{0x75200170,0x37882bbd,0xb90420f0,0x6da001f0}},	// [1df80] vaoz, обао_, _फर_, _шиъа, 
   {{0x1b1811ba,0x213c0007,0x7520009f,0x79940af9}},	//   _তাকে_, hguh_, waoz, skyw, 
   {{0x9f5c0372,0x4a74013d,0x00000000,0x00000000}},	//   rquè_, _зыят, --, --, 
   {{0x213c0369,0x86980108,0x92580022,0x00000000}},	//   jguh_, чтут_, ҧалт_, --, 
   {{0x9f5c026c,0x7521338d,0xdb1c005c,0x00000000}},	//   aqué_, raoz, forø, --, 
   {{0x31640dd4,0x7521338e,0xc4c40244,0x7dd400e5}},	//   _saoz_, saoz, رتنو, másu, 
   {{0x91fc00b0,0x7dd42bb4,0x66002852,0x00000000}},	//   _arār, lásu, _апса, --, 
   {{0x66e048ce,0x6140026a,0x213d338f,0x6e380455}},	//   _роса, већа, gguh_, vutb, 
   {{0x73340075,0xb464010b,0x91fc00dc,0x9f8806ea}},	//   _يىرا, _юкал, _prās, tøð_, 
   {{0x83fc00dd,0x69c00048,0xb28400c7,0x442801e4}},	//   _erős, _ínev, _ҭыҧк, ɩa_, 
   {{0xa3c80490,0x9f88022c,0x00000000,0x00000000}},	//   ळकर_, røð_, --, --, 
   {{0x6e3801e6,0x6ce402dd,0x3f800248,0x7dd400e5}},	//   rutb, діге, _òhun_, kásu, 
   {{0x6e386afa,0xb0e000dc,0x91fc00cd,0xe6d81bd6}},	//   sutb, _परिग, _trās, _भर्ज, 
   {{0x7dd401ed,0x6e380334,0xdce40115,0x9be40d30}},	//   dásu, putb, _uniĝ, віск, 
   {{0x6f0803ac,0x00000000,0x00000000,0x00000000}},	//   _iffc, --, --, --, 
   {{0xb0e01cc3,0xecb001af,0x4ae401a9,0x00000000}},	//   _पराग, _аҡмы, дўға, --, 
   {{0x984802e8,0x09e400d1,0x4c947579,0x7c5800e5}},	// [1df90] дяха_, доңн, _чипс, _فلٹر_, 
   {{0xb78400fd,0xf93401c6,0x00000000,0x00000000}},	//   нәсе_, _үүрч_, --, --, 
   {{0x055428e8,0xe67400f1,0xcfc000eb,0x00000000}},	//   етля, بلاګ_, _উঠান, --, 
   {{0x9f5c6320,0x8504004b,0x6d4c00a3,0xfa94011a}},	//   rqué_, روتن, nfca, _נדרש_, 
   {{0x7dd44da9,0x6f080334,0x9f5c1184,0x31b800e2}},	//   mást, _offc, squé_, cīzi_, 
   {{0x7dd53390,0xb4b4009f,0x00000000,0x00000000}},	//   lást, عُوا_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6f080204,0x7dd53391,0xa3dc08f2,0x527406d4}},	//   _affc, nást, _धीर_, тушу, 
   {{0xe7c0045e,0x657802b5,0x213c011f,0xd1640022}},	//   ্গীয, _inuh, rguh_, тнық, 
   {{0x4f080228,0x7dd4007b,0x644804cc,0x237400cf}},	//   үнөн_, hást, mtgi, _تارح, 
   {{0x443c9380,0x644804cc,0x9f4c01e1,0xe81c033f}},	//   luw_, ltgi, _kugú_, मीता_, 
   {{0x77a00092,0x99980022,0x00000000,0x00000000}},	//   _ጋምቤላ_, purũ_, --, --, 
   {{0x64493392,0xbdf8066d,0x443d3393,0x29d41497}},	//   ntgi, _کرتا_, nuw_, nçau_, 
   {{0x290801f5,0x6ec93394,0x91fc00e2,0x644801f5}},	//   _afca_, _सुकु, _krāp, itgi, 
   {{0xdb1c0008,0x443c01a4,0x6e90efe5,0x88dc01ec}},	//   nnré, huw_, _ملوا, _ﺃﺭﺍﻀ, 
   {{0x443c013b,0x7dd401d3,0x9f440248,0x6a813395}},	//   kuw_, tásu, _ninú_, ылса, 
   {{0xc32404d3,0x2ef00166,0x443c0432,0x00000000}},	// [1dfa0] _پڕ_, _изәр, juw_, --, 
   {{0x443c0428,0x6578ff5c,0x29080327,0x78c4002b}},	//   duw_, _anuh, _efca_, _āsvā, 
   {{0x443d3396,0x9f4401e1,0x91fc0055,0x00000000}},	//   euw_, _binú_, _asān, --, 
   {{0x29080268,0x7dd4b941,0x443c0134,0xdce45160}},	//   _gfca_, cást, fuw_, _laič, 
   {{0x443d3397,0x7dd53398,0x644801bf,0x271c0154}},	//   guw_, láss, gtgi, _পারো_, 
   {{0xdb1c0008,0x7afc00b5,0x9258004e,0x32643e4f}},	//   fnré, _jgpt, дакт_, етив, 
   {{0x66e13399,0x9f440241,0x443c2112,0x35a48b43}},	//   _бора, _finú_, auw_, _завг, 
   {{0x987000d7,0x256439af,0x69c008a5,0x00000000}},	//   _lúča_, _пасп_, _ínet, --, 
   {{0xe5a1339a,0x443ccdcc,0x9364035b,0x06b4009e}},	//   _сити, cuw_, _инаҵ, _জুপি, 
   {{0x2009339b,0xa3c4069f,0x29d40137,0x7dd400e5}},	//   ícia_, _उदय_, lçat_, zást, 
   {{0x91fc00ef,0xdce400ef,0x7dd400e5,0x00000000}},	//   _grāp, _kliķ, jáss, --, 
   {{0x29d419c6,0x7afc0005,0x9f5c0ffb,0x7dd401d3}},	//   nçat_, _agpt, lquì_, dáss, 
   {{0x6d4c1f06,0xa03000cf,0x5c74011c,0x00000000}},	//   rfca, _مىنت, глят, --, 
   {{0x0ce002ab,0x6f0803ac,0x09d80073,0x00000000}},	//   _नरीम, _uffc, ढत्य, --, 
   {{0x443c0209,0x7e64035b,0x7dd47009,0x644805d5}},	//   zuw_, _ахыҵ, tást, ztgi, 
   {{0x59f807d8,0x443c0428,0x6448022e,0x00000000}},	//   ееся_, yuw_, ytgi, --, 
   {{0x7dd5339c,0x64480175,0x443c002e,0x9f4401e1}},	// [1dfb0] rást, xtgi, xuw_, _rinú_, 
   {{0x9f4401e1,0x65780055,0x00000000,0x00000000}},	//   _sinú_, _snuh, --, --, 
   {{0x443c0428,0x7dd400e5,0x9990010b,0x80dc09ab}},	//   wuw_, másr, _ýaşa_, _पर्ू, 
   {{0xa5645496,0x9f440c95,0x7dd401ed,0x443d339d}},	//   عدان, _dinù_, lásr, tuw_, 
   {{0x6448143a,0xdb1c0124,0x7f400334,0x880000f1}},	//   utgi, horý, yglq, _څېړو, 
   {{0x91fc0a28,0x6449339e,0x443d339f,0x29d4067c}},	//   _prāp, rtgi, ruw_, rçau_, 
   {{0x644933a0,0x443c0605,0xdce40cf4,0x63a0009a}},	//   stgi, suw_, _raič, rhnn, 
   {{0x6578123c,0x96f8c89b,0x613801b8,0x64487e03}},	//   _unuh, _чест_, dälü, ptgi, 
   {{0x29d406ed,0x7dd401d3,0x443c0309,0x995c01ef}},	//   lças_, záss, quw_, _jíš_, 
   {{0x442d33a1,0x91fc1c52,0x290c0165,0x6d580254}},	//   _ive_, _trāp, ñgaj_, õuan, 
   {{0x29d41ad9,0x442c0008,0x7dd401ed,0x1afc015b}},	//   nças_, _hve_, dásr, ্রমে_, 
   {{0xe8fc2776,0x29d40798,0x987000d7,0x00000000}},	//   _ngû_, iças_, _súča_, --, 
   {{0x200c003b,0xdce40064,0x00000000,0x00000000}},	//   _utgi_, _taič, --, --, 
   {{0xfe88145e,0x7dd401d3,0x4fe802bf,0xcee86a0e}},	//   gbïä_, táss, _змін_, ظرین_, 
   {{0x442c0093,0x3da8dc9c,0x9f5c004e,0xbea533a2}},	//   _lve_, _окко_, nquí_, _шакк, 
   {{0x442c1326,0x7dd401d3,0xaa400114,0xbca4009a}},	//   _ove_, ráss, јетл, _لمبي, 
   {{0x442d33a3,0x3944005f,0x31b800e2,0x00000000}},	// [1dfc0] _nve_, ļos_, cīzu_, --, 
   {{0x5924031c,0xb8d800af,0x6ff0012d,0x00000000}},	//   _འཇམས_, _अइ_, _płci, --, 
   {{0x39e80323,0x06b40183,0x7dd40407,0x442d33a4}},	//   _одоо_, _জুবি, lásq, _ave_, 
   {{0x442c0943,0x272c0139,0xb87c0092,0x00000000}},	//   _bve_, _añnı_, _የጉግል_, --, 
   {{0x29d533a5,0x98940131,0xe4a04258,0x7c2000fd}},	//   aças_, _сунә, иршо, _çord, 
   {{0x442d33a6,0x63a00022,0xdb1c0e10,0x00000000}},	//   _dve_, ақуҧ, moró, --, 
   {{0x442d33a7,0xdb1d33a8,0xe7340a5b,0x00000000}},	//   _eve_, loró, _јес_, --, 
   {{0xd1300597,0x29d41892,0x7dd401ed,0x17c40022}},	//   حمة_, lçar_, zásr, _раҳҭ, 
   {{0x4fd4db74,0x67440008,0x442c017a,0x6ec8033f}},	//   лжит, _þrjá, _gve_, _सुजु, 
   {{0x29d459f9,0x64a0107e,0x00000000,0x00000000}},	//   nçar_, _тауа, --, --, 
   {{0x442d33a9,0x2324013e,0x29d40ba1,0xb14400a7}},	//   _zve_, _рохи_, içar_, _анел, 
   {{0x91e00c58,0x442c0022,0xdb1d33aa,0x2c04012d}},	//   _পূৰ্, _yve_, koró, _िंदू_, 
   {{0x7dd400dd,0xd01012e3,0x442c06af,0x1afc03d4}},	//   tásr, _الت_, _xve_, ্ৰমে_, 
   {{0x09bd33ab,0xdb1c012d,0xfe6c0137,0x00000000}},	//   ्क्य, doró, زگۉ_, --, 
   {{0x75f80316,0xeda400cf,0x7dd400e5,0x00000000}},	//   _různ, _ашпо, rásr, --, 
   {{0x195933ac,0x5f800131,0xdb1c0332,0x995c00d7}},	//   касы_, _مۇۋە, foró, _píš_, 
   {{0x0708007b,0x80c400cd,0x00000000,0x00000000}},	// [1dfd0] فيذي_, ापये, --, --, 
   {{0x9c14063f,0x995c00bc,0x7dd401d3,0x00000000}},	//   _kọns, _víš_, lásp, --, 
   {{0x442c04b9,0x91fcb872,0xdef4069d,0x7f880023}},	//   _sve_, _asām, _ጊዜና_, ምሮኣዊ_, 
   {{0x29d533ad,0x442cca6a,0x2d882630,0xdb1d33ae}},	//   rças_, _pve_, njce_, boró, 
   {{0xdce41e27,0x442c0113,0x6e3933af,0x58845aa1}},	//   _kaiā, _qve_, hrtb, _кыра, 
   {{0xe61133b0,0x442d33b1,0x69dc02d1,0x823407fc}},	//   _نشر_, _vve_, llqe, هربا, 
   {{0xc2540736,0xefd00023,0x75f801ef,0x00000000}},	//   اختت, _ከለዋ_, _kůzl, --, 
   {{0x45d48807,0x200803b7,0x442c09a9,0xef141945}},	//   _собс, ício_, _tve_, ңмы_, 
   {{0x443933b2,0x442d33b3,0x9f5c004e,0xc67c0092}},	//   _ís_, _uve_, squí_, _የሚሠራ_, 
   {{0x645801c0,0xf07401d3,0x200801e4,0xb0e40022}},	//   _ipui, ایوں_, ŭcio_, ыдыз_, 
   {{0xdb1c012d,0xf77000d9,0x00000000,0x00000000}},	//   zoró, זקי_, --, --, 
   {{0x98a002b5,0x00000000,0x00000000,0x00000000}},	//   haiā_, --, --, --, 
   {{0xefd0044e,0xa3c40490,0x60600131,0x6e38257c}},	//   _ከለዉ_, _उदा_, _ئۇخل, artb, 
   {{0xccf40046,0x645804ba,0x09e0009e,0x23c000dc}},	//   шқы_, _mpui, _মূলা, वचिद, 
   {{0xdb1c0034,0xc2f40154,0x395400d8,0x31b800de}},	//   woró, ঘুরি_, лњат, cīzs_, 
   {{0xa96533b4,0x645806c8,0xdb1c0034,0xb9e441fa}},	//   лиса_, _opui, toró, اسسى, 
   {{0xdce40421,0x0c680220,0xfc30007b,0xb864136e}},	// [1dfe0] _faiā, _азық_, _احب_, دازو, 
   {{0x4cac04c5,0x6da802a8,0x29d4067c,0xe0c40150}},	//   _টুকু, nƙan, uçar_, _ۇز_, 
   {{0x29d533b5,0x64580194,0x7c2133b6,0xa3d40037}},	//   rçar_, _apui, _çorb, सवन_, 
   {{0xdb1c05d6,0xb5d800c6,0x645801e7,0x6e2c01d3}},	//   poró, رباء_, _bpui, ábbi, 
   {{0x70e0b340,0x98c807f7,0x20080332,0x00000000}},	//   _परेल, _रखिए, ícil_, --, 
   {{0x41380020,0x685802d3,0x6e3801bf,0xf74401f4}},	//   _በሀገሪ, ልደመድ, yrtb, _щего, 
   {{0x645933b7,0x0ce06c8e,0x9f44007b,0x00000000}},	//   _epui, _नर्म, _ghné_, --, 
   {{0x645801ab,0x00000000,0x00000000,0x00000000}},	//   _fpui, --, --, --, 
   {{0x776c011f,0x9c1401f2,0xefd002d3,0x27d401d9}},	//   _kabx, _sọns, _ከለው_, _شِہج_, 
   {{0x836400cf,0x00000000,0x00000000,0x00000000}},	//   _ۅدۅل, --, --, --, 
   {{0xdce400b0,0x99980024,0x250801d3,0x79280023}},	//   _raiā, ntrų_, _آرہی_, ድናታት, 
   {{0xf0440166,0xec14151e,0xa2b00d79,0xe7e817cb}},	//   _бэко, лемә_, ेपर्, _जीना_, 
   {{0x9cc81e35,0x00000000,0x00000000,0x00000000}},	//   гыра_, --, --, --, 
   {{0x9f5c0ffb,0xeab133b8,0xa4a0067c,0x5d8402dd}},	//   cquà_, معز_, _çòex, _ۇلىل, 
   {{0x9f44012c,0x8cd42765,0x5f4000db,0x9e00004e}},	//   _jiný_, _युरो, _انىل, _лчыл, 
   {{0x290c0428,0xdce400b0,0x98a000b0,0xb4f4084d}},	//   ùga_, _waiā, waiā_, ेशाय_, 
   {{0xdce40374,0x91fc24b8,0x8d74004b,0x02e01f13}},	// [1dff0] _taiā, _asāk, _ماښا, _फर्न, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x645870a1,0xd7c87286,0x89d80035,0x00000000}},	//   _spui, دوله_, _لودر_, --, 
   {{0xdb1c066a,0xd6d933b9,0xfe0801fb,0x1638007b}},	//   lorð, уту_, _hắc_, اسلة_, 
   {{0xd4d80212,0x99980064,0xd72400fe,0x00000000}},	//   льші_, atrų_, _পাৰা_, --, 
   {{0xd7f80323,0xee2400b2,0xa7f80113,0xe7842179}},	//   _бус_, _وٽ_, _osñi, _сумо, 
   {{0xfe080016,0xaad805f9,0x82a400ee,0x5694074d}},	//   _mắc_, _मुमक, райж, _ларт, 
   {{0x5e601473,0xfe08001e,0xdc3400d0,0x672533ba}},	//   ەندە, _lắc_, _súče, _hejj, 
   {{0x64580421,0x67240327,0xd54856e8,0x00000000}},	//   _upui, _kejj, _حلقو_, --, 
   {{0xfe080208,0xd72405ac,0x00000000,0x00000000}},	//   _nắc_, _পাৱা_, --, --, 
   {{0x6724003d,0xd36c07d2,0x7db4007b,0x00000000}},	//   _mejj, _سۇي_, لصحا, --, 
   {{0xbca4082e,0x660405be,0x6da802a8,0x9f5cba1f}},	//   لمجي, _mujk, sƙan, squà_, 
   {{0xfe080016,0x66040166,0x443c002f,0x6e9001e2}},	//   _bắc_, _lujk, nrw_, ملیا, 
   {{0x672533bb,0xfe080051,0x443c0142,0x4bd80108}},	//   _nejj, _cắc_, irw_, гься_, 
   {{0xab2533bc,0xeab401fe,0x29d40205,0x00000000}},	//   роса_, айр_, tçap_, --, 
   {{0x0bc00150,0x00000000,0x00000000,0x00000000}},	//   _ﺭﻳﻜﻮ, --, --, --, 
  
   {{0x672533bd,0xdb1c09f3,0xb71533be,0xb7d8103c}},	// [1e000] _bejj, borð, لباش, نورا_, 
   {{0x9f440793,0x776c0a55,0x660533bf,0xe7a4010b}},	//   _ninü_, _qabx, _bujk, авул_, 
   {{0x6724038f,0xf50533c0,0xaa5002d3,0x443c0034}},	//   _dejj, азео, _ምፍልላ, erw_, 
   {{0x776c058a,0xae54010f,0xfe080051,0x4cac0154}},	//   _wabx, יסעס_, _zắc_, _টুটু, 
   {{0x9f4401b8,0x9f4c09d7,0x99980006,0xacb8002d}},	//   _binü_, _jugó_, strų_, rbûg, 
   {{0x67240135,0x9f440166,0x37740209,0xfe080208}},	//   _gejj, _cinü_, _тымс, _xắc_, 
   {{0xf1a40058,0x27fc00a7,0x443c04e6,0x9f44011f}},	//   ирин, _èuna_, arw_, _linó_, 
   {{0x741533c1,0xe1ec50a3,0x6724031c,0x0f0001ad}},	//   _نورا, وسي_, _zejj, ोड्स_, 
   {{0x64a0a6fa,0x9f440793,0x672490ae,0xb38533c2}},	//   _дата, _finü_, _yejj, _клал, 
   {{0x67245ccf,0x23440150,0x66040139,0xa854011a}},	//   _xejj, _ەلەپ_, _yujk, סייה_, 
   {{0xfe0801fb,0x389c0055,0xdb1c06ea,0xe190009d}},	//   _rắc_, _hārā_, vorð, слөө, 
   {{0xfe0807ae,0x389c07d7,0x7c2000a2,0x00000000}},	//   _sắc_, _kārā_, _ŧora, --, 
   {{0x6ce40046,0xfe080051,0x503800f5,0x6bd4007b}},	//   ріне, _pắc_, _сплю_, لتسر, 
   {{0x09b005ba,0x389c0055,0x1dc400db,0x9f4c00e5}},	//   ीच्य, _mārā_, йөөн, _dugó_, 
   {{0x91fc0618,0xc0c80020,0x67240113,0xfe08004d}},	//   _asāi, ጠዋል_, _rejj, _vắc_, 
   {{0x9f4c0789,0x67240003,0x1ef808a8,0xdb1c0d12}},	//   _fugó_, _sejj, _בלוע, sorð, 
   {{0xfe080016,0x9f440548,0x4734b720,0x67240327}},	// [1e010] _tắc_, _ginó_, йнас, _pejj, 
   {{0x7c2133c3,0x00000000,0x00000000,0x00000000}},	//   _çora, --, --, --, 
   {{0x81dc045e,0x17f800c6,0x995c00bc,0xb5200254}},	//   ণগত_, شركة_, _síť_, मरूप_, 
   {{0xd1500084,0x672404ba,0x3cec00c5,0x389c00de}},	//   _iṅwe_, _wejj, _घरमे_, _bārā_, 
   {{0x672533c4,0x9f440268,0x89d89e94,0x91fc005f}},	//   _tejj, _minò_, _لوگر_, _frāz, 
   {{0x9cd80302,0x9f44007f,0x389c00b8,0x660424e7}},	//   בודה_, _linò_, _dārā_, _tujk, 
   {{0x926400c6,0x733003cc,0x443c00b5,0x1634447e}},	//   قديم, سىيا, srw_, _меря, 
   {{0xe7e81d15,0x00000000,0x00000000,0x00000000}},	//   _जीता_, --, --, --, 
   {{0x41740b28,0x4394fbd3,0xdb1c007c,0x84c40150}},	//   لاکس, _лаас, morö, _уәжд, 
   {{0x5e600c50,0xf8b00375,0x91fc002b,0x31b800c0}},	//   ەنگە, פשי_, _apād, būzo_, 
   {{0x9f4533c5,0x3ce40219,0x00000000,0x00000000}},	//   _sinó_, _šov_, --, --, 
   {{0xcb080302,0xf98802d3,0xd16402e8,0x00000000}},	//   _טל_, _ሓሊፎም_, _мъчи, --, 
   {{0x9f4533c6,0x71700451,0x9f900124,0x00000000}},	//   _dinò_, _رهوا, _мыкә, --, 
   {{0xdb1d33c7,0xff500271,0x5f4002f2,0x00000000}},	//   mirë, _رخت_, _بۆدل, --, 
   {{0x68e00cc1,0xdb1c0200,0x00000000,0x00000000}},	//   əndi, lirë, --, --, 
   {{0x3dc40086,0xf2d0008f,0xb9040108,0x00000000}},	//   _ñow_, פען_, сзак, --, 
   {{0xa3d401b0,0xbb440d1d,0xa8000b01,0x36c400fb}},	// [1e020] सवा_, _лепк, ззул, әбег, 
   {{0xe8f45a46,0x389c02b1,0x3b64009f,0x00000000}},	//   слу_, _rārā_, _اُدِ, --, 
   {{0x7bdc01f2,0xdb1c0240,0x66e00798,0x389c0055}},	//   _ikpu, hirë, пофа, _sārā_, 
   {{0x34848715,0x00000000,0x00000000,0x00000000}},	//   йгег, --, --, --, 
   {{0x09e000fe,0x00000000,0x00000000,0x00000000}},	//   _মূকা, --, --, --, 
   {{0xbb240154,0x00000000,0x00000000,0x00000000}},	//   _বাঁধ_, --, --, --, 
   {{0x7bdc00b4,0xa7a4003b,0x00000000,0x00000000}},	//   _mkpu, _укра_, --, --, 
   {{0xd01001b9,0xdb1c0023,0xe81c0892,0x389c002b}},	//   ولب_, firë, मीका_, _tārā_, 
   {{0x7bdc00b4,0x9f44067c,0x2eb028b8,0xc67c001f}},	//   _okpu, _rinò_, ुप्त, _የሚሰራ_, 
   {{0x7bdc0521,0x9f4533c8,0xc2fc0154,0xb224032e}},	//   _nkpu, _sinò_, ঁড়ি_, gmæð, 
   {{0x9f440332,0xd9f80073,0x00000000,0x00000000}},	//   _ghní_, ंगात_, --, --, 
   {{0x7bdc02e3,0x91fc00b8,0xed8801f4,0x00000000}},	//   _akpu, _asāv, усок_, --, 
   {{0x2174011a,0x00000000,0x00000000,0x00000000}},	//   _לתאר_, --, --, --, 
   {{0x9508081f,0x00000000,0x00000000,0x00000000}},	//   _ཆུའི_, --, --, --, 
   {{0xfe080016,0x5f706049,0xdeec074d,0x91fc00b8}},	//   _hắn_, _راور, _хы_, _tpād, 
   {{0x7bdc0521,0x91fc0882,0xde900150,0x6efc0139}},	//   _ekpu, _upād, _ءجوب, _eçbü, 
   {{0x23a804ce,0x7bdc1132,0x00000000,0x00000000}},	// [1e030] _høje_, _fkpu, --, --, 
   {{0xfe08001e,0xd7f8187f,0x200800d0,0xda04000d}},	//   _mắn_, бух_, ícii_, _शूकत_, 
   {{0x46d80034,0xdb1d33c9,0x00000000,0x00000000}},	//   _बुशह, dirè, --, --, 
   {{0x91fc00cd,0x00000000,0x00000000,0x00000000}},	//   _trāy, --, --, --, 
   {{0x27fc02e8,0xe9dc0cad,0xfe08004d,0xc328007b}},	//   _èuno_, _ikú_, _nắn_, لكشن_, 
   {{0xe8fc0086,0xdee41ee0,0x78a05522,0x00000000}},	//   _daût_, _ዘመኑ_, øove, --, 
   {{0x23a800b5,0xdb200214,0x73c00139,0x00000000}},	//   _nøje_, éwék, фәте, --, 
   {{0xfe080016,0xdb1c02d3,0x3ea00254,0x00000000}},	//   _bắn_, tirë, _ühti_, --, 
   {{0xfe08001e,0xaad82ba2,0x04740137,0xae00107c}},	//   _cắn_, _मुसक, _بئزگ, _रंजन_, 
   {{0x53342875,0x9c14063f,0x23a800b5,0x00000000}},	//   _неут, _wọks, _bøje_, --, 
   {{0xe9dc03c1,0xdb1c02d3,0x236533ca,0x7dd401d3}},	//   _okú_, sirë, menj_, mász, 
   {{0xe9dcfd05,0x2364151c,0x6da80198,0xfce40137}},	//   _nkú_, lenj_, nƙah, жомо, 
   {{0x224400dd,0xfe080016,0x6b940175,0xdb1c0200}},	//   lunk_, _gắn_, _boxg, qirë, 
   {{0xbea43173,0xb4f8008d,0xe9dd33cb,0x63a00098}},	//   _малк, יפרי, _akú_, nknn, 
   {{0x6b940097,0x91780ca8,0x224401d3,0xfa840023}},	//   _doxg, _jé̟_, nunk_, ኮርኮር_, 
   {{0x628407ea,0x236533cc,0xdce407f5,0x7c200240}},	//   _àjou, henj_, _naić, _çoro, 
   {{0xe9d4242f,0xfe08001e,0x6b94062c,0x23640219}},	// [1e040] іку_, _xắn_, _foxg, kenj_, 
   {{0xe9dc0241,0x2364a46c,0x224401d3,0xbd44009f}},	//   _ekú_, jenj_, kunk_, _انکي, 
   {{0x236533cd,0x224533ce,0x7dd401ed,0x332cbea3}},	//   denj_, junk_, dász, vafx_, 
   {{0x224401ed,0xae58008f,0x7c345e71,0x8e20074d}},	//   dunk_, יכער, _kvyr, _цiе_, 
   {{0xdb1c35b0,0x23b000e5,0x00000000,0x00000000}},	//   tirè, ڈمنس, --, --, 
   {{0xfe08001e,0x22440112,0x7dd401ed,0x6c78010f}},	//   _rắn_, funk_, gász, ירנד, 
   {{0x224401ed,0xfe08004d,0x66e002dd,0xe73533cf}},	//   gunk_, _sắn_, _жора, _фес_, 
   {{0xf1241ed2,0xdb1d33d0,0xddd00432,0x76d8014b}},	//   цько, sirè, _ýeňm, _буғӣ_, 
   {{0x752133d1,0xdb1c0561,0x75e80306,0x85340145}},	//   mboz, pirè, lýzo, _رولچ, 
   {{0x91780248,0x91fc0055,0xfe08004d,0x752001d5}},	//   _fé̟_, _asāt, _vắn_, lboz, 
   {{0x79840083,0xdb1ced70,0xa3d40073,0x00000000}},	//   _onkw, ciré, सवर_, --, 
   {{0x798402e3,0xfe08004d,0xdb1c0112,0x75207b02}},	//   _nnkw, _tắn_, hnrä, nboz, 
   {{0x7c2062c7,0x7dd400d7,0xb90c0241,0x00000000}},	//   _çorl, násy, bajẹ_, --, 
   {{0x798438e9,0x75200369,0x9f4400a3,0x00000000}},	//   _ankw, hboz, _ghnà_, --, 
   {{0xda7933d2,0x7d140042,0x75e802f0,0x752001d5}},	//   оят_, _ffys, význ, kboz, 
   {{0xd5a41973,0x4814abe9,0x23648d55,0x7dd400e5}},	//   _شہ_, змас, zenj_, zász, 
   {{0x224401ed,0x6d5c01e1,0x7dd401d3,0x53bc00dc}},	// [1e050] zunk_, _ibqa, yász, ्चाश, 
   {{0x798533d3,0xab60005e,0x9ee40137,0x4a5533d4}},	//   _enkw, _تۇسى, _ازۇۇ, _екос, 
   {{0x236409a8,0x7dd401d3,0xe97001d3,0x7c3400c0}},	//   venj_, vász, _قندھ, _zvyr, 
   {{0x48c800bd,0x9f44007b,0x398c0023,0x7c340588}},	//   _শরীর, _mhná_, _ነፈርቲ_, _yvyr, 
   {{0x23640219,0xf55533d5,0xb5a801e1,0x00000000}},	//   tenj_, سلوب_, _ńṣoj, --, 
   {{0x224400dd,0xdb1d33d6,0xba04001f,0x78f80375}},	//   tunk_, tiré, _ዎቹ_, _לפרו, 
   {{0x3f880016,0x7984002d,0x23651122,0x7520031c}},	//   _đau_, _ynkw, renj_, bboz, 
   {{0x61340020,0x224401ed,0x2378033f,0x23651122}},	//   _ኮምፒዩ, runk_, _żyją_, senj_, 
   {{0x91fc0421,0xdb1c06af,0x224401ed,0x260c00ab}},	//   _asās, siré, sunk_, _तूती_, 
   {{0xdb1c00c7,0x6d5c0009,0x2244c8e0,0x00000000}},	//   piré, _abqa, punk_, --, 
   {{0x7c340024,0xdb1c0fac,0xaad80892,0x69cc012d}},	//   _svyr, nnrå, _मुलक, _ojce, 
   {{0x52740132,0x40941fd6,0x00000000,0x00000000}},	//   _زامز, _ىلار, --, --, 
   {{0xa280006c,0xff24030d,0x00000000,0x00000000}},	//   _ریکو, _емло, --, --, 
   {{0x0fc40046,0x200800d0,0x7c200166,0x46bc1223}},	//   _оқып_, íciu_, _çorm, ्पाह, 
   {{0x3ea40323,0x6b6133d7,0xbea533d8,0xcee80220}},	//   _хийг, экра, _хайк, _ورىن_, 
   {{0x7d74454b,0x7d1403cd,0x7c340153,0x6e38011a}},	//   _رابط, _ufys, _tvyr, _התקד, 
   {{0x66180063,0xfe0801fb,0xfca80014,0xf8c43874}},	// [1e060] _čuka, _mắm_, _داغو_, लपेप, 
   {{0xfe0807ae,0xdb240214,0x00000000,0x00000000}},	//   _lắm_, _تودی, --, --, 
   {{0x0a24044e,0x22a40de2,0xdb1c0423,0xd9102099}},	//   ታቶርያ, _dёkk_, gnrå, _لیز_, 
   {{0xfe08001e,0x7984009a,0x6b80067c,0x3dc00472}},	//   _nắm_, _unkw, _òngr, nikw_, 
   {{0x752133d9,0xdb1c0054,0x1ae405ac,0x00000000}},	//   rboz, nirï, _মলয়া, --, 
   {{0xacb8000f,0x995c013a,0x00000000,0x00000000}},	//   kbûn, _jíž_, --, --, 
   {{0xc32c07a7,0x27f4012c,0xa4340023,0xe294033a}},	//   شەن_, řené_, _ኣይግድ, зај_, 
   {{0x25ac04cc,0xfe08001e,0x91fc002b,0x201c01a4}},	//   chgl_, _cắm_, _asār, fpui_, 
   {{0xb4a81d1b,0x00000000,0x00000000,0x00000000}},	//   _указ_, --, --, --, 
   {{0x995c00bc,0xdb1c0165,0x442801e4,0x645c0327}},	//   _níž_, dirï, ɨa_, ħqit, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69c045a7,0xfe08004d,0x00000000,0x00000000}},	//   _ínex, _gắm_, --, --, 
   {{0x200800db,0x407001e0,0xdb1c0022,0x628401e1}},	//   ícit_, _ағыу, rirî, _àjor, 
   {{0x53dc07f7,0x00000000,0x00000000,0x00000000}},	//   मकिश, --, --, --, 
   {{0xb91844fc,0x1f580375,0x00000000,0x00000000}},	//   _ọtụt, _הדוא, --, --, 
   {{0x19940801,0x9d540131,0x7c3401bf,0x621800df}},	//   нася, _كۆپت, ægræ, מולק, 
   {{0x6d4c0472,0xd7240154,0x00000000,0x00000000}},	// [1e070] mgca, _পাড়া_, --, --, 
   {{0x2fdc07c5,0xb78400fd,0x6d4c0010,0x2d980200}},	//   notg_, мәсе_, lgca, _hoqe_, 
   {{0x2d980200,0x6ab400fe,0x00000000,0x00000000}},	//   _koqe_, _আঁকো, --, --, 
   {{0x6d4d33da,0x320400e8,0x2fdc04cc,0x31b800ef}},	//   ngca, _nioy_, hotg_, būzi_, 
   {{0x69dc0286,0xfe080208,0xdc3000c0,0x06b400fe}},	//   moqe, _rắm_, _džėj, _জুখি, 
   {{0xfe080016,0x69dd33db,0x050c015b,0x491828fe}},	//   _sắm_, loqe, শরের_, युरो_, 
   {{0x6d4c02d0,0x00000000,0x00000000,0x00000000}},	//   kgca, --, --, --, 
   {{0xdb1c0054,0x69dc0472,0xb6240046,0x83fc00e5}},	//   yirï, noqe, _ﺯﺏ_, _csőr, 
   {{0xbf0442e3,0x656933dc,0x29080472,0x25bc0393}},	//   रश्न_, megh, _mgca_, _imul_, 
   {{0x644933dd,0x69dc01f0,0x3ea533de,0x9eb002d9}},	//   mugi, hoqe, диог, ешмә, 
   {{0x644933df,0xdb0933e0,0xfe080016,0x954402d3}},	//   lugi, _élém, _tắm_, _ከምእተ, 
   {{0x6d4c074d,0x656808e5,0x2d980286,0x290933e1}},	//   ggca, negh, _coqe_, _ngca_, 
   {{0x644933e2,0x61f933e3,0x65680076,0xdb1c01e1}},	//   nugi, mmul, iegh, birì, 
   {{0x61f933e4,0xacb8145e,0x212c0978,0xdb1d33e5}},	//   lmul, mbûl, _hegh_, cirì, 
   {{0x25bc084c,0x200533e6,0x644933e7,0x200d33e8}},	//   _omul_, _iini_, hugi, _hugi_, 
   {{0x200533e9,0x61f933ea,0x69dc0b6f,0x212c047e}},	//   _hini_, nmul, goqe, _jegh_, 
   {{0x200533eb,0x656933ec,0x644933ed,0xdb1d33ee}},	// [1e080] _kini_, degh, jugi, qirï, 
   {{0x200d33ef,0x200533f0,0x25bc1574,0x644933f1}},	//   _mugi_, _jini_, _amul_, dugi, 
   {{0x200d01bc,0x65680ffb,0x200533f2,0xdb1c04d4}},	//   _lugi_, fegh, _mini_, nirí, 
   {{0x200533f3,0x29d4003d,0xe9b00124,0x212c016d}},	//   _lini_, għad_, _абџь, _negh_, 
   {{0x644933f4,0x61f834c5,0x1884013d,0x200d33f5}},	//   gugi, dmul, _яңан, _nugi_, 
   {{0x200533f6,0x61f933f7,0x7bcd33f8,0x00000000}},	//   _nini_, emul, nnbu, --, 
   {{0x7bcd33f9,0x212c047e,0x64480006,0x79940070}},	//   inbu, _begh_, augi, ojyw, 
   {{0x200533fa,0x61f88b14,0x30a42c9d,0x644839aa}},	//   _aini_, gmul, дров, bugi, 
   {{0x200533fb,0x212c016d,0xa2d01823,0x644800ca}},	//   _bini_, _degh_, ىيۇت, cugi, 
   {{0x200d33fc,0x20042ce2,0xb4a845bf,0x61f933fd}},	//   _dugi_, _cini_, खनी_, amul, 
   {{0x6d4c07d5,0x200533fe,0x200c005a,0xdb1c2e27}},	//   tgca, _dini_, _eugi_, girí, 
   {{0x7bcc167a,0x20042bde,0x200c0356,0x00000000}},	//   enbu, _eini_, _fugi_, --, 
   {{0x20042178,0xd37800f3,0x2d9801a9,0xdb1c0332}},	//   _fini_, _kać_, _voqe_, airí, 
   {{0x200533ff,0x7bcc8605,0xdb1c09c2,0x656819f5}},	//   _gini_, gnbu, birí, zegh, 
   {{0x2d980113,0xdb1c09c2,0x212c003e,0x656802e3}},	//   _toqe_, cirí, _yegh_, yegh, 
   {{0x20053400,0x200c0208,0x7bcc0067,0xa2cc00b8}},	//   _zini_, _yugi_, anbu, धपत्, 
   {{0x20053401,0x65693402,0x00000000,0x00000000}},	// [1e090] _yini_, vegh, --, --, 
   {{0x656805db,0x64480516,0x20053403,0x321c014b}},	//   wegh, vugi, _xini_, _otty_, 
   {{0x61f93404,0x6448f32a,0x65693405,0x00000000}},	//   ymul, wugi, tegh, --, 
   {{0xd6d8c720,0x91fc005f,0x69dc01f0,0x65680076}},	//   фту_, _spān, qoqe, uegh, 
   {{0x321d3406,0x65693407,0x212c0477,0xd378012d}},	//   _atty_, regh, _regh_, _bać_, 
   {{0xe66531bb,0x65693407,0x212c016d,0x932401e2}},	//   _отбо, segh, _segh_, پرون, 
   {{0x61f8e1e9,0x20053408,0x6da80b45,0x200cb57e}},	//   tmul, _rini_, nƙas, _sugi_, 
   {{0x20053409,0x4094048a,0x200d340a,0xdb1c04d4}},	//   _sini_, ерот, _pugi_, virí, 
   {{0x2005340b,0x321c020c,0x64480194,0x00c801b9}},	//   _pini_, _etty_, qugi, ялик_, 
   {{0x442d340c,0x61f9340d,0xdb1c2b76,0x212c014f}},	//   _iwe_, smul, tirí, _wegh_, 
   {{0x2005340e,0x442c0605,0xbea5340f,0x212c0978}},	//   _vini_, _hwe_, ханк, _tegh_, 
   {{0x20053410,0x442cb23d,0xdb1c30cf,0x661800f3}},	//   _wini_, _kwe_, rirí, _čukl, 
   {{0x20053411,0x442c0d29,0x9d000154,0x0b000154}},	//   _tini_, _jwe_, ূর্ন_, ্রোল_, 
   {{0x442c43c4,0x20053412,0xdb1d3413,0x7bcc0009}},	//   _mwe_, _uini_, dirã, unbu, 
   {{0x442d3414,0xdb1c05ac,0xafe0010b,0x7bcc9698}},	//   _lwe_, inrø, _щошл, rnbu, 
   {{0x442d3415,0x3ea400ad,0x290c0427,0x31b86e98}},	//   _owe_, mylt_, žgan_, būzu_, 
   {{0x442d3416,0xf1b0008f,0xfbd000f2,0x00000000}},	// [1e0a0] _nwe_, אסן_, _متد_, --, 
   {{0x91fc0055,0x29d40003,0x00000000,0x00000000}},	//   _apāl, għab_, --, --, 
   {{0x442d3417,0x3ea40076,0xcbc405af,0x00000000}},	//   _awe_, nylt_, _جزيي, --, 
   {{0x442d3418,0x14c8034c,0x6ab400cc,0x00000000}},	//   _bwe_, وهای_, _আঁচো, --, 
   {{0xb4a8006d,0x442c08bb,0xe4e00024,0x28c40210}},	//   खने_, _cwe_, лішн, _रेपि, 
   {{0x442c11c1,0xb7d93419,0x6da802a8,0xd25056e6}},	//   _dwe_, _روزا_, nƙar, لنت_, 
   {{0x929402d5,0x38700cfd,0x3950062c,0x27b002dd}},	//   тайц, lwyr_, ogys_, _сәтс, 
   {{0x442c0161,0x3951341a,0xd1300597,0x75f4010b}},	//   _fwe_, ngys_, جمة_, _düzý, 
   {{0x442d341b,0x387000a9,0x3ea40076,0x2008004e}},	//   _gwe_, nwyr_, eylt_, ícip_, 
   {{0x3ea44098,0x38700142,0xa854011a,0x00000000}},	//   fylt_, iwyr_, עייה_, --, 
   {{0x442d341c,0x387000a9,0xdb1c35f5,0x75f400a2}},	//   _zwe_, hwyr_, dirà, _güzý, 
   {{0x05100183,0xeff40023,0x00000000,0x00000000}},	//   াৰীৰ_, _ወፈያ_, --, --, 
   {{0xf1a804d3,0x3ea40363,0x00000000,0x00000000}},	//   _واڵه_, aylt_, --, --, 
   {{0x38700cfd,0xf410015b,0xdb1c067c,0x3ea40076}},	//   dwyr_, _হবার_, girà, bylt_, 
   {{0xfbd0012c,0xaad81223,0x58840150,0x00000000}},	//   _सदरम, _मुखक, қыта, --, 
   {{0x39501368,0x6da80b45,0xdb1c0120,0x6e384087}},	//   ggys_, rƙas, tirã, mstb, 
   {{0x387000a9,0xdd04084c,0xad9821fc,0x8bd80276}},	// [1e0b0] gwyr_, ărăt, rmúd, _омис_, 
   {{0x442d341d,0x2cb00bcc,0x395000ad,0xdb1c00d8}},	//   _rwe_, ındı_, agys_, rirã, 
   {{0x442d341e,0x91fc00b8,0xa5d000a2,0xe5c4009d}},	//   _swe_, _apām, _aỳal, нсдо, 
   {{0xdb1c3b82,0x442d341f,0x6e388c66,0x96f801b9}},	//   mirá, _pwe_, istb, رعلر_, 
   {{0x43753420,0x65b00076,0x442c0477,0x588401e0}},	//   вуйт, _nçhe, _qwe_, _йыра, 
   {{0x442c0100,0x78a001f4,0x00000000,0x00000000}},	//   _vwe_, äove, --, --, 
   {{0x442d3421,0xdb1c30e2,0x6e3801f5,0x00000000}},	//   _wwe_, nirá, jstb, --, 
   {{0x442d3422,0xceb8068f,0x91fc002b,0x00000000}},	//   _twe_, dzę_, _upāl, --, 
   {{0x442d3423,0x44380570,0x28c40e57,0x5c380092}},	//   _uwe_, _ìs_, _रेमि, _ኤግዚቢ, 
   {{0x65793424,0xa280034c,0x64593425,0x3ea4002d}},	//   _hauh, _میتو, _iqui, tylt_, 
   {{0x65793426,0xa07002dd,0x41547b78,0xbac40154}},	//   _kauh, тықш, _авес, _শুনছ, 
   {{0x65787bd5,0xdb1c2b76,0x70505a9d,0xd17463f5}},	//   _jauh, dirá, دنیا, _бышы, 
   {{0x65793427,0x009401c0,0x3ea42d8b,0x00000000}},	//   _mauh, _шидэ, sylt_, --, 
   {{0x6f1807d5,0xeff4044e,0x65793428,0x6e380036}},	//   cctc, _ወለዶ_, _lauh, bstb, 
   {{0xdb1d3429,0x64580113,0xceb80034,0x395400d8}},	//   girá, _lqui, czę_, књат, 
   {{0x6579342a,0xdb1c067c,0x387003cb,0xe96400f0}},	//   _nauh, sirà, twyr_, касл_, 
   {{0x261403b7,0x64580005,0xdb1c067c,0x395000ad}},	// [1e0c0] _aço_, _nqui, pirà, rgys_, 
   {{0x65780270,0x38700cfd,0xdb1c09ff,0x18680032}},	//   _aauh, rwyr_, birá, мағи_, 
   {{0x6459342b,0x387000a9,0xdb1c09c2,0x7c24017a}},	//   _aqui, swyr_, cirá, lpkr, 
   {{0x65780399,0x058402dd,0x387003cb,0x00000000}},	//   _cauh, луім, pwyr_, --, 
   {{0x81c802f5,0x1cc0031c,0x6578002b,0xeff40b82}},	//   োতা_, _གཟས_, _dauh, _ወለዱ_, 
   {{0x7c2005d1,0xe3601513,0xe5740107,0xf7440902}},	//   _çoru, икчи, нҷӣ_, _шего, 
   {{0xe5a00276,0xb1900116,0x24f000d1,0x491800bc}},	//   _ӂити, илкә, лчәр, युको_, 
   {{0x28c41428,0x6579342c,0xe5a03ed6,0x00000000}},	//   _रेडि, _gauh, _киси, --, 
   {{0x39400ac5,0xe5a047ca,0xa13000d1,0xe454014b}},	//   _mdks_, _тити, جرىش, _ижт_, 
   {{0xaad82871,0xeff4044e,0xdce4041a,0x6e380d27}},	//   _मुझक, _ወለዲ_, _naiđ, tstb, 
   {{0xdb1c0005,0x7c2401f5,0x657800e4,0x21f000e4}},	//   xirá, epkr, _yauh, sãha_, 
   {{0x6e381543,0x50840075,0xdb1c01d3,0xceb8033f}},	//   rstb, _ماتې, virá, rzę_, 
   {{0xceb8006d,0x3cfc00bc,0x00000000,0x00000000}},	//   szę_, रेले_, --, --, 
   {{0xdb1d342d,0x26140327,0x99980064,0x99800432}},	//   tirá, _bħol_, kurų_, lmiň_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x1e94025f,0x88d40a28,0xdb1c8550,0x290c022c}},	//   _יכול_, kṛta, rirá, øga_, 
   {{0x6579342e,0x91fc002b,0xd838009d,0x00000000}},	// [1e0d0] _rauh, _apāk, вэх_, --, 
   {{0x6578aea2,0x57b5342f,0xdb1c1de4,0x24580798}},	//   _sauh, абут, pirá, vêm_, 
   {{0x65793430,0x1cc0025c,0xdce4031c,0x64593431}},	//   _pauh, _གཟོ_, _iniġ, _squi, 
   {{0x44b40228,0x24580798,0x84840b82,0x1ac80166}},	//   лбес, têm_, _ሞራልን_, _шуып_, 
   {{0x657802f6,0x765c017a,0xfe080051,0x00000000}},	//   _vauh, atpy, _gắu_, --, 
   {{0xdce4025c,0xfe08004d,0x657801f4,0x91fc0055}},	//   _jniġ, _hắt_, _wauh, _upāj, 
   {{0x65793432,0x163412c4,0xdce40327,0x26040064}},	//   _tauh, _веся, _mniġ, _ачаг, 
   {{0x96f80276,0xc1e800f1,0xe4a49d9f,0x998000a2}},	//   _рест_, رکال_, _ирзо, gmiň_, 
   {{0xfe0807ae,0x64580b6f,0x1cc0031c,0x6714033f}},	//   _mắt_, _uqui, _གཟེ_, _तलाक_, 
   {{0xa3012e74,0x23746f04,0x23b4043e,0xfe080208}},	//   _күле, _جارح, _अतिद, _lắt_, 
   {{0xdb1c008c,0xee3405f5,0x00000000,0x00000000}},	//   gnrý, лнэ_, --, --, 
   {{0x4034bc6d,0x7db4007b,0xe66800cd,0x00000000}},	//   _бедс, اصدا, _śaśā, --, 
   {{0x443ca436,0xde4415f6,0x00000000,0x00000000}},	//   nsw_, ریکو_, --, --, 
   {{0x7a0c01e4,0x91fc00b8,0x64483226,0x00000000}},	//   _aŝta, _apāh, irgi, --, 
   {{0xfe0807ae,0x260c00e1,0xaa401c7c,0x8ac400c7}},	//   _bắt_, _तंगी_, йерл, аирҧ, 
   {{0xfe080016,0x7c241445,0xe7a8031c,0x00000000}},	//   _cắt_, ppkr, _ħaġġ, --, 
   {{0xe9d448a5,0xfe0801fb,0x2280247e,0xdb1c010b}},	// [1e0e0] укт_, _dắt_, _lık_, jirç, 
   {{0xb7d801f7,0x00000000,0x00000000,0x00000000}},	//   روضا_, --, --, --, 
   {{0xfaa416c3,0x228000fd,0x15d80014,0xdb1c0162}},	//   _сано, _nık_, پداں_, tiræ, 
   {{0x59b405f5,0xfe0801fb,0x29d40327,0x00000000}},	//   _төгс, _gắt_, lħan_, --, 
   {{0xda70001f,0x25b40214,0x6600017a,0x855401b9}},	//   _ሥልጠና_, دهند_, ïnka, شیلر_, 
   {{0x316407de,0x21c80150,0xb9e00092,0x00000000}},	//   _sboz_, _ﯗﺯﺍﺭ, _ሩም_, --, 
   {{0x6448f409,0xdce400b0,0x228003e0,0x64a021f3}},	//   argi, _kaiē, _cık_, _қафа, 
   {{0xaf500598,0x22800139,0xfe08004d,0xdb1c6cba}},	//   әннә, _dık_, _xắt_, birç, 
   {{0x6618009b,0xdb1cfafc,0x845800f3,0x7bd800d7}},	//   _čuki, nnró, _архт_, čtuj, 
   {{0xdb1c01e3,0x32d40064,0x00000000,0x00000000}},	//   nirä, _йцес, --, --, 
   {{0x9f64005e,0xb224871a,0x5ec40154,0x00000000}},	//   урыз_, _смел, _রুবে, --, 
   {{0xdb1d3433,0x00000000,0x00000000,0x00000000}},	//   knró, --, --, --, 
   {{0xe8fc025a,0x21280165,0xfe080208,0x518401ee}},	//   _abûn_, ñche_, _rắt_, _буҙа, 
   {{0xfe080016,0x29d40327,0x22800205,0xdb1c010e}},	//   _sắt_, għan_, _yık_, jirä, 
   {{0x443c0399,0xd484004b,0xfe080051,0xdb1c00a2}},	//   zsw_, _کۀ_, _pắt_, dirä, 
   {{0x64493434,0x3cec0073,0x00000000,0x00000000}},	//   yrgi, _घरचे_, --, --, 
   {{0x47353435,0xfe0801fb,0xdce40003,0xe87400f2}},	// [1e0f0] инас, _vắt_, _tniġ, دازظ, 
   {{0xdb1c00a2,0x00000000,0x00000000,0x00000000}},	//   girä, --, --, --, 
   {{0xfe080016,0x0a940108,0x7c200200,0x00000000}},	//   _tắt_, _таню, _çorr, --, 
   {{0x443c073c,0x22800139,0x91fc00b8,0xceb800c0}},	//   tsw_, _rık_, _upāh, lbęs_, 
   {{0x22800365,0xdb1c00c5,0xa1f00131,0x04c806c5}},	//   _sık_, birä, ەۋات, خوشي_, 
   {{0x94042f84,0x443c04cc,0x644933ba,0x00000000}},	//   مونه, rsw_, rrgi, --, 
   {{0x5b58025f,0x41b53436,0x96f8022e,0x00000000}},	//   אשון_, исит, _берт_, --, 
   {{0x62813437,0xdb1c0158,0x443c00a3,0x7c38012d}},	//   rvno, mirå, psw_, ątrz, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x22800e2d,0xa0440150,0xe4a4014b,0x00000000}},	//   _tık_, _ەكشە_, _ирҷо, --, 
   {{0x94053438,0xf7700d65,0x429822de,0x28c47e29}},	//   _اوله, חקי_, _جناح_, _रेसि, 
   {{0xee34bbdb,0x4fe8004e,0x00000000,0x00000000}},	//   шню_, кмөн_, --, --, 
   {{0xd1b8034c,0x68ed3439,0xdce40327,0xec74011c}},	//   _حالا_, _nycd, _mniħ, апя_, 
   {{0xefc0001f,0xef140137,0xa03000db,0x9f4801e1}},	//   ስበው_, _кмш_, _نىچت, _àlàa_, 
   {{0xeb95343a,0xdb1c0037,0x29d40135,0xf9340f06}},	//   шир_, virä, rħan_, ихаю, 
   {{0xe9d5343b,0x7d7456b0,0x0d14014b,0xb3740240}},	//   акс_, _ضابط, _гӯрӯ, ረበዳን_, 
   {{0x1cc02fb5,0x9f45343c,0xbb44d90c,0x00000000}},	// [1e100] _གཟི_, _akné_, _кепк, --, 
   {{0xdb1c007b,0xf77000c6,0xf745343d,0xec10030f}},	//   rnró, غاء_, режо, _گوید, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xec100271,0xdb1c0254,0xa61012fa,0x00000000}},	//   _دوید, sirä, іміч, --, 
   {{0x73342002,0x1b440023,0x09880150,0x00000000}},	//   لىشا, _ንምቕያ, _саяқ_, --, 
   {{0xdb20034c,0xacb9343e,0xf771343f,0xfe140d2e}},	//   èwèk, mbût, _باح_, णदास_, 
   {{0x52b00034,0x00000000,0x00000000,0x00000000}},	//   जनेस, --, --, --, 
   {{0x2eec0142,0x844400d1,0xa2d4012d,0x00000000}},	//   _ryff_, شخۇل, _बशर्, --, 
   {{0x737411db,0xa504e017,0x00000000,0x00000000}},	//   _выех, _вета_, --, --, 
   {{0xc4440101,0x00000000,0x00000000,0x00000000}},	//   _ایون_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x91fc002b,0x2ca801f5,0x29d4031c,0x00000000}},	//   _apāv, tycd_, għal_, --, 
   {{0xacb8000f,0x3a2401a6,0xec141b15,0x00000000}},	//   jbût, _čopa_, регә_, --, 
   {{0x2ca8030d,0x00000000,0x00000000,0x00000000}},	//   rycd_, --, --, --, 
   {{0xceb80153,0xa9c53440,0x00000000,0x00000000}},	//   rbęs_, асак, --, --, 
   {{0x5e540244,0x00000000,0x00000000,0x00000000}},	//   _ئجوج_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [1e110] --, --, --, --, 
   {{0xe70816e6,0x00000000,0x00000000,0x00000000}},	//   نتان_, --, --, --, 
   {{0xa6453441,0xa50c00dc,0x6600017a,0xd618007b}},	//   شخان, िश्च_, ïnko, لتنا_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd8380064,0x00000000,0x00000000,0x00000000}},	//   _вэс_, --, --, --, 
   {{0xe7853442,0xfe080016,0xbd000036,0x00000000}},	//   _тумо, _lắp_, ééie, --, 
   {{0xdd2c0024,0x98a00153,0x00000000,0x00000000}},	//   _lėšo, rbią_, --, --, 
   {{0xfe0801fb,0x3f88013d,0x7af81d0e,0x00000000}},	//   _nắp_, _şau_, ýtti, --, 
   {{0x95c8223c,0x44b40588,0xf0a400a7,0x3944002e}},	//   _тура_, _убас, йкъл_, óosi_, 
   {{0xd9c400dc,0x00000000,0x00000000,0x00000000}},	//   _षष्ट, --, --, --, 
   {{0xfe08001e,0x92b4007b,0x00000000,0x00000000}},	//   _bắp_, _وحما, --, --, 
   {{0xed553443,0x7db4035b,0xfe08001e,0x00000000}},	//   бою_, ссоц, _cắp_, --, 
   {{0x3f68228e,0x98a00fcf,0xa6a800eb,0xc1040472}},	//   _било_, mbić_, _গেমট, _اوشي, 
   {{0xdbc8023b,0xfaa53444,0xad9801d3,0x5a3400c7}},	//   рҳод_, баго, lmúl, жьаӡ, 
   {{0xcee83df7,0xab240edb,0x01f800df,0x00000000}},	//   _پرون_, соса_, ָפּל, --, 
   {{0xfd112362,0xfe08004d,0x49942db7,0xdb1c00d0}},	//   _عجب_, _gắp_, ошут, nirú, 
   {{0xb71406b6,0x00000000,0x00000000,0x00000000}},	// [1e120] مباش, --, --, --, 
   {{0xacb8000f,0xe73402dd,0x3694010b,0x91fc00cd}},	//   rbût, йеу_, йшес, _upāv, 
   {{0x6b7813e2,0x7bcc174d,0x7c340368,0x2f38010f}},	//   _גרינ, mibu, _hwyr, רגעד, 
   {{0xd9b408c9,0x7bcd1b6f,0xead00022,0xfe080051}},	//   _بەرد, libu, _хоџь, _xắp_, 
   {{0x53c8013e,0x7bcc009f,0xd3c808ca,0x52b00825}},	//   аҳам_, oibu, ақал_, जन्स, 
   {{0x7bccc51b,0xe3ac5f2e,0x00000000,0x00000000}},	//   nibu, فرى_, --, --, 
   {{0xb2843b1d,0x7d1400a9,0xe6d801e0,0xca2c00d1}},	//   сылк, _ogys, _бѳтә_, ﻧﻤﺎ_, 
   {{0x75d53445,0x27e4007f,0x741411c5,0x00000000}},	//   _ايرا, čnne_, _هورا, --, 
   {{0x7c34015d,0x9f4802f0,0xfe080051,0x7334009f}},	//   _nwyr, šlým_, _rắp_, _هرائ, 
   {{0xfe080016,0x7bcd3446,0x7d147536,0x91fc3da0}},	//   _sắp_, jibu, _agys, _apāt, 
   {{0x7bcc0483,0x7c340368,0xab1801a8,0xa2d000ae}},	//   dibu, _awyr, átíð_, _فيكت, 
   {{0x8cb47df0,0x75213447,0xad640066,0x00000000}},	//   उनलो, ncoz, حاده, --, 
   {{0x6ce456a4,0x9850013d,0x70f41f0d,0xadb400db}},	//   сіне, _oşıy_, _اسائ, _ۇۇدا_, 
   {{0x7d14066d,0x7bcd3448,0x7c340368,0x00000000}},	//   _egys, gibu, _dwyr, --, 
   {{0xc0ec0201,0x7c340042,0xfe080208,0x5ac80064}},	//   ፀዋል_, _ewyr, _tắp_, блём_, 
   {{0x23a804ce,0x7bcc002d,0x9850013d,0x48240116}},	//   _højt_, aibu, _aşıy_, قىرق, 
   {{0x7bcd3449,0x9f4400c6,0x7c340368,0x59f80395}},	// [1e130] bibu, _ghnó_, _gwyr, сетя_, 
   {{0x7bcc0de4,0xaa640023,0x00000000,0x00000000}},	//   cibu, _ምግልጋ, --, --, 
   {{0xd7f9344a,0x7c34012d,0x66180171,0x00000000}},	//   сут_, _zwyr, _čuks, --, 
   {{0x7af9344b,0x75200af2,0xd49801c6,0x93241870}},	//   ütte, gcoz, өрч_, ۋرىن, 
   {{0x1bb81537,0x03a4537c,0xe4c810e8,0xdb1d2924}},	//   _ضایع_, жило, دبان_, virú, 
   {{0x33700364,0x7520011c,0x387000d1,0x83540050}},	//   мҳур, acoz, _юқут, تھرا, 
   {{0xdb1d344c,0x683c0241,0xaaccb1e3,0x00000000}},	//   girù, _fàdá, _हेमक, --, 
   {{0x7bcc016e,0x7520011c,0x41a839bd,0x29d4031c}},	//   zibu, ccoz, рвин_, dħak_, 
   {{0xe294c9c6,0x7bcc3926,0x98a00e3c,0x91fc002b}},	//   рақ_, yibu, rbić_, _apās, 
   {{0x7bcc0381,0xfe4401c0,0xb374001f,0x6d5c06be}},	//   xibu, оноо, ረበውን_, _acqa, 
   {{0x7bcd344d,0xf1a00150,0xa24400e5,0x00000000}},	//   vibu, _ﺃﻗﺩﻡ_, _ایبل_, --, 
   {{0x40940046,0x7bcc0796,0x72600240,0x00000000}},	//   _ولار, wibu, _ደርባዊ_, --, 
   {{0x7bcd344e,0x6da80198,0x00000000,0x00000000}},	//   tibu, nƙay, --, --, 
   {{0x6ee0063f,0x7bcc0393,0x8c00010b,0x70140677}},	//   _ọbel, uibu, нҗыл, _וחסד_, 
   {{0xf6c42fb5,0x3b083417,0x201d344f,0xcc3400c7}},	//   _གཟེང, рево_, lqui_, _ҭхьы, 
   {{0x201c16b8,0xfaa40107,0x91fc002b,0x00000000}},	//   oqui_, баҳо, _upāt, --, 
   {{0x8d280831,0x201d3450,0x7bcc0483,0x03180034}},	// [1e140] _уның_, nqui_, pibu, दशाह_, 
   {{0x3f844ec2,0x201c067c,0x7bcc04ba,0x213c0798}},	//   ndlu_, iqui_, qibu, hauh_, 
   {{0x213c01e4,0x683c01e1,0x161411dc,0x00000000}},	//   kauh_, _pàdá, سساڭ, --, 
   {{0x213c87d3,0x7af80d12,0x00000000,0x00000000}},	//   jauh_, ýttu, --, --, 
   {{0x213c0007,0xb2240436,0x58480022,0x64a13451}},	//   dauh_, klæð, _ыҧан_, маца, 
   {{0x75213452,0x977409a5,0xd7e800cf,0xdb1c036e}},	//   scoz, _этмә, _چوڭۇ_, dhrë, 
   {{0x3f853453,0x290c0010,0x683c01e1,0xc0c400c7}},	//   ddlu_, žgat_, _tàdá, ҧшьқ, 
   {{0x91fd3454,0x3f843af2,0x00000000,0x00000000}},	//   _apār, edlu_, --, --, 
   {{0xe1f40032,0xb22408a5,0x00000000,0x00000000}},	//   өгә_, flæð, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x201c0428,0x12880214,0xdb0801e1,0x9f5c00e5}},	//   aqui_, _دمای_, _àlèj, úság_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x0df8044e,0xdb1c0221,0xa064114b,0x3f840135}},	//   _ወከፍ_, chrë, _маца_, bdlu_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd1c0044e,0xdeec0064,0x9a880395,0x91fc00dc}},	//   _ድሌት_, _цы_, ощта_, _upās, 
   {{0x6d5c03e3,0x00000000,0x00000000,0x00000000}},	//   _ucqa, --, --, --, 
   {{0x7e6c009b,0x290c11ab,0x00000000,0x00000000}},	// [1e150] _ćapi, äga_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfd5400b8,0x05193455,0x213c0007,0x26c401c3}},	//   _agaṇ, مياب_, yauh_, àno_, 
   {{0x36a00075,0x00000000,0x00000000,0x00000000}},	//   رەقق, --, --, --, 
   {{0x1cc02fb5,0xdb1d3456,0x39980375,0x00000000}},	//   _གཟབ_, rnrö, _הירד, --, 
   {{0xe9dc02d2,0x1a6801d3,0x00000000,0x00000000}},	//   _hjú_, _دیہی_, --, --, 
   {{0xf6540364,0x2128030a,0x6704033f,0x48f42c2e}},	//   _нерӯ, ñcho_, वेशक_, ्धको_, 
   {{0x91fc005f,0x00000000,0x00000000,0x00000000}},	//   _spār, --, --, --, 
   {{0x213d3457,0x201c068c,0x91840137,0x00000000}},	//   rauh_, uqui_, بۇنۇ, --, 
   {{0x201d3458,0xdb1c02e2,0x00000000,0x00000000}},	//   rqui_, chrè, --, --, 
   {{0xe9dc4e53,0x201c56ed,0xcce808a8,0x3f84003e}},	//   _ojú_, squi_, _עכ_, rdlu_, 
   {{0xdb1c0597,0xee2c568c,0xfce53459,0x57a80073}},	//   mhré, _үн_, зомо, _गव्ह, 
   {{0x7f95345a,0x201c013c,0x00000000,0x00000000}},	//   _надх, qqui_, --, --, 
   {{0xe9dd345b,0xe81c2aa1,0x63a00c6a,0xa5d000a2}},	//   _ajú_, _बढ़ा_, njnn, _iỳul, 
   {{0x7f40353d,0xfaa401f0,0x00000000,0x00000000}},	//   malq, чаво, --, --, 
   {{0xfce40733,0xe9a1345c,0x7ed400f1,0x00000000}},	//   _нойо, насп, _وزګا, --, 
   {{0xce04009a,0x00000000,0x00000000,0x00000000}},	// [1e160] _تذوي, --, --, --, 
   {{0xe9dc0022,0x7f4003fa,0xae640133,0xaa640023}},	//   _ejú_, nalq, _بڕین_, _ምግምጋ, 
   {{0x91780cad,0x6b78011a,0xd1c00023,0x00000000}},	//   _jẹ́_, _פרטנ, _ድሌቱ_, --, 
   {{0xabe408b0,0x7f40baa1,0xdb1c0332,0x00000000}},	//   ﺎﻟﻤﺎ, halq, dhré, --, 
   {{0xdb1c020c,0x91780241,0x45180006,0x00000000}},	//   thrè, _lẹ́_, іцця_, --, 
   {{0x798401b2,0x1cc00003,0x91fc002b,0x0cd800fe}},	//   _hakw, _གཟན_, _apāp, _সৰুত, 
   {{0x66e1345d,0x7985345e,0xf6c40135,0xdb1cfbcd}},	//   _зора, _kakw, _གཟིང, ghré, 
   {{0xea9c0055,0x6200004e,0x00000000,0x00000000}},	//   _asṛg_, нчыз, --, --, 
   {{0x7f400076,0xdb1d345f,0xd25001b9,0x00000000}},	//   falq, phrè, رنک_, --, 
   {{0x917801e1,0xe3b400d8,0x00000000,0x00000000}},	//   _bẹ́_, _ебу_, --, --, 
   {{0x79853460,0xe294024c,0xdb1c12f2,0x90400133}},	//   _oakw, _наф_, chré, رۆژه, 
   {{0x79853461,0xdd2c0165,0x00000000,0x00000000}},	//   _nakw, tėšk, --, --, 
   {{0xa11005a9,0x48980092,0xefe80092,0x321c5f0b}},	//   _كومت, _መራጮች_, _መጪው_, _huty_, 
   {{0x321c009a,0xe9dc002d,0x7f405941,0x91780248}},	//   _kuty_, _sjú_, calq, _fẹ́_, 
   {{0x321c00e4,0x2cb0012c,0x00000000,0x00000000}},	//   _juty_, _řadě_, --, --, 
   {{0x6724037e,0x2fcc0334,0x7af807c5,0xdb1c010b}},	//   _sfjj, _hmfg_, ütta, mirý, 
   {{0x28c4069f,0x79853462,0x321c0034,0xa2d0a202}},	// [1e170] _रेखि, _dakw, _luty_, _भेन्, 
   {{0x57f40588,0x7984035a,0x9cd8010f,0x917801e1}},	//   епут, _eakw, _מוחה_, _yẹ́_, 
   {{0x321c012d,0xdb1d3463,0x6568031c,0x00000000}},	//   _nuty_, nirý, tfgh, --, 
   {{0x79853464,0xe9dc00d7,0x00000000,0x00000000}},	//   _gakw, _ujú_, --, --, 
   {{0x69cc014b,0xfc44012c,0x1518007b,0x321c013a}},	//   _imce, říve_, أزمة_, _auty_, 
   {{0x321c068f,0x9f4401f1,0x94742f5e,0xdb1c00ae}},	//   _buty_, _okná_, عدنا, thré, 
   {{0x79853465,0xf7700302,0x42081fbe,0x7f40047e}},	//   _yakw, _שקל_, онко_, valq, 
   {{0x798418f7,0x321d3466,0x917801e1,0xd5b84eb1}},	//   _xakw, _duty_, _rẹ́_, _есу_, 
   {{0xc5e80f44,0x004400f1,0x91780248,0x00000000}},	//   टकीय_, ړیږي_, _sẹ́_, --, 
   {{0x321c0198,0xdb1c06af,0x91780248,0x6ee001e1}},	//   _futy_, phré, _pẹ́_, _ọbal, 
   {{0xafe098a4,0x321c010e,0xdb1c00a2,0x00000000}},	//   тоэл, _guty_, girý, --, 
   {{0x442d3467,0x69cc01ab,0x91fc002b,0x00000000}},	//   _kte_, _nmce, _upāp, --, 
   {{0x79853468,0x442c06af,0xa2a00073,0x00000000}},	//   _rakw, _jte_, _कपड्, --, 
   {{0x442c0e39,0x79853469,0x69cc2572,0x321c00e4}},	//   _mte_, _sakw, _amce, _yuty_, 
   {{0x442d346a,0xca74152d,0x7985346b,0x4a744c17}},	//   _lte_, нуты, _pakw, нытт, 
   {{0x442d346c,0xee900014,0xdb1c0254,0x00000000}},	//   _ote_, _شۯُک, lirü, --, 
   {{0x7985346d,0xac8050c0,0x36e4012d,0x00000000}},	// [1e180] _vakw, _агыл, _जुड़ी_, --, 
   {{0x7985346e,0x69cc3b6a,0xf6d40150,0xdb24023a}},	//   _wakw, _emce, وزاد, ärät, 
   {{0x442d346f,0x79853470,0x00000000,0x00000000}},	//   _ate_, _takw, --, --, 
   {{0xd9105d28,0x79840b6f,0x442c05b1,0x00000000}},	//   _میز_, _uakw, _bte_, --, 
   {{0x442d3471,0xa5300d30,0xe8f40408,0xe4e0003b}},	//   _cte_, тніч, тлă_, кішн, 
   {{0x28c43eaf,0xdb1c0022,0x64a00114,0x00000000}},	//   _रेटि, miró, таља, --, 
   {{0x442d3472,0xe2941614,0x00000000,0x00000000}},	//   _ete_, дај_, --, --, 
   {{0xd1300597,0x2bb81fe7,0xa9b8010f,0xf1a8009a}},	//   دمة_, _उत्थ, ַזיר, تاته_, 
   {{0x442d3473,0x20c001c6,0xdb1c3168,0x00000000}},	//   _gte_, всэг, niró, --, 
   {{0xdb1d3474,0xe4000022,0x321c003e,0x00000000}},	//   tirý, _азуп, _tuty_, --, 
   {{0x6260009d,0x00000000,0x00000000,0x00000000}},	//   _авха, --, --, --, 
   {{0x442c0482,0xd130007b,0x00000000,0x00000000}},	//   _yte_, _صمت_, --, --, 
   {{0xdb1c03b9,0xe04001c4,0x00000000,0x00000000}},	//   birü, _анчи, --, --, 
   {{0x69cc0066,0x4f8401d9,0x2fcc02d2,0x00000000}},	//   _smce, _ساتہ, _umfg_, --, 
   {{0xf1b035e8,0x5e800046,0xa00400c6,0xdb1c0005}},	//   _जवान, _ауыз, _تقول_, eiró, 
   {{0x6c6401d3,0x00000000,0x00000000,0x00000000}},	//   _قلعہ_, --, --, --, 
   {{0x58d401a9,0x00000000,0x00000000,0x00000000}},	// [1e190] вотт, --, --, --, 
   {{0xab6004b3,0x48c40124,0x00000000,0x00000000}},	//   _جۇسى, _ҟәба, --, --, 
   {{0x2fdc0c86,0xfc4400bc,0xe5c401c6,0x69cc0432}},	//   intg_, říte_, мсдо, _tmce, 
   {{0x69ccfd4f,0x29d4003d,0x2d880210,0x00000000}},	//   _umce, għat_, ndce_, --, 
   {{0x442c010a,0x3a240010,0x00000000,0x00000000}},	//   _qte_, _čopi_, --, --, 
   {{0x32053475,0xef04004b,0xdec80023,0xf33400b8}},	//   _ahoy_, _مټ_, _ኣሚኑ_, _ruṣā_, 
   {{0x3204062c,0xc68c0131,0xdb1c0a8c,0x37c002dd}},	//   _bhoy_, _ھېچ_, virü, _сәтб, 
   {{0x442d3476,0x32040ec9,0x69dc0194,0x00000000}},	//   _tte_, _choy_, nnqe, --, 
   {{0x442c28b3,0x25bc0198,0xdb1c0254,0x638007a5}},	//   _ute_, _ilul_, tirü, _аҳла, 
   {{0x3fcc00bd,0xa3b801d5,0x9394007b,0x00000000}},	//   রক্ষ, _بارر_, _لجما, --, 
   {{0xf77000c8,0xdb1c000d,0x82640066,0x00000000}},	//   נקט_, rirü, _سهشن, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7fd4005e,0x61f80365,0xdb1c0205,0x00000000}},	//   _пікі, mlul, pirü, --, 
   {{0xae3800e8,0xefc00092,0x00000000,0x00000000}},	//   ññée, ድበው_, --, --, 
   {{0x63702c70,0xdce41505,0xb110063f,0x61f80037}},	//   mını, _obić, tụge, olul, 
   {{0x63703bc2,0x61f93477,0xdb1c96f1,0xee2c0451}},	//   lını, nlul, tiró, _اٽي_, 
   {{0x61f8023a,0x0d6400c7,0xb864027d,0xec6c00ec}},	// [1e1a0] ilul, _рныҟ, عارو, _هٿي_, 
   {{0x61f89ff9,0x637005f3,0x25bd3478,0x81e40154}},	//   hlul, nını, _alul_, ফতি_, 
   {{0xdb1cf27f,0x61f80790,0x7c240175,0x29d40327}},	//   siró, klul, lqkr, għas_, 
   {{0x4ad80014,0x63703bc1,0x1c040b27,0xb9040154}},	//   _زاپھ_, hını, _शीतल_, _ফর_, 
   {{0x61f8136f,0x637045a5,0x20040306,0x17840124}},	//   dlul, kını, _ohni_, _иҳам, 
   {{0x63700365,0xb73423cf,0x25bc000d,0x2d8800bc}},	//   jını, _سفرب, _elul_, zdce_, 
   {{0x6370956f,0x394039ae,0x7ab0000d,0x00000000}},	//   dını, _keks_, ीनिअ, --, 
   {{0x20040055,0xe5a00354,0x909800d8,0xdb1c02d2}},	//   _ahni_, _йиси, двит_, dhrí, 
   {{0x765c0c67,0x63701ae4,0xe45001ed,0x7f60001f}},	//   lupy, fını, _مہنگ, _ጉዳዮች, 
   {{0xad24598b,0x61f81140,0x637070f7,0x35b402e5}},	//   کردو, alul, gını, _अकड़, 
   {{0x32040208,0x1cac0327,0xdb1c0332,0x22100166}},	//   _thoy_, བྱལ_, ghrí, ъфәр, 
   {{0x20040270,0x61f93479,0x63a00124,0x29d40327}},	//   _ehni_, clul, _ақәҧ, hħar_, 
   {{0x63701ae6,0x2e4401e1,0x765c035b,0x5ea011dc}},	//   bını, _bífá_, hupy, _ەمىل, 
   {{0x63704953,0x765c035b,0xc0cc0023,0xdb1c00ae}},	//   cını, kupy, _ኣኺሉ_, bhrí, 
   {{0xda784263,0x2e440ca8,0xdcf0008f,0x9f5c01ed}},	//   нят_, _dífá_, _ĉeĥo, _órás_, 
   {{0x996400cf,0x5b140064,0x00000000,0x00000000}},	//   лтул, умст, --, --, 
   {{0x21280054,0x668001d5,0x48180816,0x5c740024}},	// [1e1b0] ñchi_, گیزل, джаю_, _блыт, 
   {{0xad980162,0x29d40003,0x00000000,0x00000000}},	//   flúg, għar_, --, --, 
   {{0x39404e9b,0xf3f403d4,0x61f9347a,0x65e00124}},	//   _feks_, আষাৰ_, ylul, гәаҧ, 
   {{0x637071e1,0xd6d9347b,0x394001f5,0xa8500131}},	//   zını, хту_, _geks_, _йемә, 
   {{0x637071e1,0x7dc42d3f,0x18a40153,0x61f803e0}},	//   yını, _fósf, _баўм, vlul, 
   {{0x76680108,0x00000000,0x00000000,0x00000000}},	//   öpyö, --, --, --, 
   {{0x765c20a2,0x31640810,0x61f9347c,0x63700baa}},	//   cupy, _bcoz_, tlul, vını, 
   {{0x61f9347d,0x25bc0ac5,0x2004036b,0xdce43341}},	//   ulul, _ulul_, _shni_, _ubić, 
   {{0x63700bfc,0x61f9347e,0xdedc0020,0x00000000}},	//   tını, rlul, ነውን_, --, 
   {{0x6618049b,0x61f9347f,0x94a8010b,0xdb1c5e4f}},	//   _hiuk, slul, _ятса_, thrí, 
   {{0x63700c07,0x61f93480,0x66193481,0x72d000db}},	//   rını, plul, _kiuk, _پەيچ, 
   {{0x63707230,0x3c2400d7,0x61f8ca3c,0x00000000}},	//   sını, _pôv_, qlul, --, 
   {{0xdb1c05a4,0x63702fbe,0x39400072,0x3f68bd91}},	//   firð, pını, _reks_, _жило_, 
   {{0x39413482,0x66193483,0x63706656,0x765c0784}},	//   _seks_, _liuk, qını, yupy, 
   {{0xfb846215,0xad9803b2,0xab2455f3,0xaa40ba0a}},	//   ныңн, gmús, тоса_, иерл, 
   {{0x66193484,0x64493485,0xdc140259,0x2cf00521}},	//   _niuk, ksgi, rşıy, ụhụ_, 
   {{0x394003d4,0xa9200dbe,0x7dc40332,0x29d4031c}},	// [1e1c0] _veks_, рдул, _pósf, għaq_, 
   {{0x6448168c,0xb7140f87,0x394006fd,0xe7340166}},	//   dsgi, نباش, _weks_, веф_, 
   {{0x66180a73,0xaf040086,0x64480158,0xad980419}},	//   _biuk, _ijùñ, esgi, blúd, 
   {{0x765d3486,0xfbcc28fe,0x6448735b,0x00000000}},	//   rupy, होरम, fsgi, --, 
   {{0x672005a1,0x6618065c,0x64487c1d,0x490001c6}},	//   žnja, _diuk, gsgi, _гүтг, 
   {{0x7dc40579,0xd2513487,0xe2a00208,0xad980413}},	//   _hósd, منت_, _trữ_, nmúr, 
   {{0x64493488,0xb284023a,0xe6400798,0x87b802e8}},	//   asgi, тылк, _весп, _чуят_, 
   {{0x6618089c,0x66e13489,0xe1ecbb6f,0x21640063}},	//   _giuk, _тоса, يسي_, вићи_, 
   {{0xb37400db,0xb3841188,0x00000000,0x00000000}},	//   _لداش, _илал, --, --, 
   {{0xb11001f2,0xe0cc027d,0x2d700055,0x00000000}},	//   tụbe, غزي_, _ṇe_, --, 
   {{0xa758008f,0x00000000,0x00000000,0x00000000}},	//   ודיר, --, --, --, 
   {{0xdb1c05f7,0x3165348a,0x00000000,0x00000000}},	//   virð, _ucoz_, --, --, 
   {{0x6ce40046,0x00000000,0x00000000,0x00000000}},	//   тіне, --, --, --, 
   {{0x764c03b2,0xb4b801e1,0x5ed002f2,0xef900244}},	//   _ovby, _rẹ́d, اتیز, _ئیدد, 
   {{0xceb8013d,0x00000000,0x00000000,0x00000000}},	//   _чәп_, --, --, --, 
   {{0x2b0c00dc,0x6449348b,0xad986499,0x00000000}},	//   णेषु_, ysgi, flúe, --, 
   {{0xd484004b,0x764d1c6a,0xdb1c002d,0x66186479}},	// [1e1d0] _بۀ_, _avby, nkrê, _riuk, 
   {{0xb78401d2,0x26e4015b,0x6619348c,0x6280033f}},	//   ләсе_, _করবো_, _siuk, ywno, 
   {{0xd7f9348d,0x6619348e,0x981400c6,0xdec802d3}},	//   тут_, _piuk, شبكا, _ኣዚና_, 
   {{0x6448049f,0x00000000,0x00000000,0x00000000}},	//   tsgi, --, --, --, 
   {{0xad98172e,0x6449348f,0xdb1c00c6,0x43753490}},	//   clúe, usgi, mhrá, гуйт, 
   {{0x64480549,0xdb1c002d,0x69c00356,0x00000000}},	//   rsgi, dkrê, _îneb, --, 
   {{0x66193491,0x64493492,0xa2a00846,0xd68400db}},	//   _tiuk, ssgi, कमध्, _кутп, 
   {{0x7c20011c,0x78a00419,0x00000000,0x00000000}},	//   _èorg, ťove, --, --, 
   {{0x70500c8b,0xad980008,0x7dc4148b,0x758001b9}},	//   منيا, klúb, _jóse, _دینم, 
   {{0x7c2000d8,0x7dc40bcd,0xdb1c03e0,0xd2d400d1}},	//   _éori, _móse, mirö, دغۇب, 
   {{0xc66c044e,0xdb1c0254,0x2ba53493,0x00000000}},	//   _ኣሜሪካ_, lirö, खाना, --, 
   {{0xb2b804ac,0xee340c98,0x00000000,0x00000000}},	//   _אמער, ыню_, --, --, 
   {{0xd1b89347,0xdb1c00ae,0x00000000,0x00000000}},	//   _جالا_, dhrá, --, --, 
   {{0x705024cc,0x8fc40372,0x3f680835,0x00000000}},	//   _انوا, _ۅزۉن, _чико_, --, 
   {{0x91fc00cd,0x6cb001e0,0x00000000,0x00000000}},	//   _apāy, _һөрт, --, --, 
   {{0xf2d000c8,0xdb1c007b,0x7e613494,0x00000000}},	//   צען_, ghrá, mulp, --, 
   {{0xcef400e5,0x00000000,0x00000000,0x00000000}},	// [1e1e0] _مہیش_, --, --, --, 
   {{0x3b853495,0x7dc408a5,0x7aa41422,0xad1808c3}},	//   _слог, _dóse, _биоз, _אופר, 
   {{0xdb1c007b,0xc7642f7c,0x7e613496,0x00000000}},	//   bhrá, شالى, nulp, --, 
   {{0xdb1d3497,0x7dc40077,0xfb840124,0x611800b8}},	//   chrá, _fóse, _рыҩн, _kālī, 
   {{0x49913498,0x7e60606b,0x7afd3439,0x18b400d1}},	//   _بیقر, hulp, _hypt, _тәвр, 
   {{0x7e613499,0x925808ca,0x00000000,0x00000000}},	//   kulp, вакт_, --, --, 
   {{0xad980789,0x69c00311,0x543402f2,0xf1240f06}},	//   nlúc, _înec, ارچر, льпо, 
   {{0x90541789,0x5484001f,0x7e600393,0x88d400b8}},	//   авиц, _በግልፅ_, dulp, _mṛnm, 
   {{0x61180055,0x7afc0200,0xdb1c0022,0x00000000}},	//   _nālī, _lypt, mirõ, --, 
   {{0x53b853b7,0x212c0327,0xdb1d349a,0x26e40154}},	//   _अविश, _efgh_, rkrê, _করতো_, 
   {{0xdb1c002d,0xe29c8726,0x00000000,0x00000000}},	//   skrê, _уð_, --, --, 
   {{0x21280054,0x61401b2e,0x2d9c005a,0x30040572}},	//   ñcht_, _геца, ñue_, _өзег, 
   {{0x5c749e78,0x61180171,0x95740092,0x6f2401af}},	//   блят, _cālī, _የጌታን_, _йєйе, 
   {{0x19580184,0x79980134,0xedd401e0,0xdb1c000d}},	//   ҫары_, _ɔtwe, _әлиә_, hirõ, 
   {{0x7e61349b,0xdb1d349c,0x2b9001b9,0x2ba400bc}},	//   culp, thrá, لیکس, खाबा, 
   {{0x7afc003b,0x6ca40108,0x00000000,0x00000000}},	//   _dypt, _брож, --, --, 
   {{0xd8380323,0xd15000b8,0xad980332,0xdb1c0037}},	// [1e1f0] гэх_, _aṅke_, alúc, dirõ, 
   {{0xc66c0023,0xdb1c01e7,0x27e40037,0x00000000}},	//   _ኣሜርካ_, shrá, õnn_, --, 
   {{0x672005ce,0x611800e2,0x3b84013d,0x998000a2}},	//   žnjo, _zālī, _төяп_, kliň_, 
   {{0x1da8b305,0x04b4d646,0x15a80395,0xf8ac01e2}},	//   गायत, исля, лъчи_, _ښکل_, 
   {{0x7e6001c0,0xf484006c,0x91fc0882,0xdd3c011a}},	//   zulp, لاوی, _upāy, תעדכ, 
   {{0x42541d83,0x78a000d0,0x61180171,0x00000000}},	//   атит, ťovc, _jālū, --, 
   {{0xa04c01f3,0x00000000,0x00000000,0x00000000}},	//   _መነኮሳ, --, --, --, 
   {{0x02040cfc,0x4ed003d4,0x7e6001e4,0x00000000}},	//   јзин, _ৱৰ্ল, vulp, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9474004b,0x7e61349d,0x00000000,0x00000000}},	//   _ددفا, tulp, --, --, 
   {{0xe2300edf,0x925812d7,0xdb1c0036,0x61180171}},	//   _اکتب, _бахт_, rkrë, _sālī, 
   {{0x7e61349e,0x7afcc6fb,0x61180055,0x00000000}},	//   rulp, _rypt, _pālī, --, 
   {{0x6da4052f,0x7e613494,0xd25001d9,0x8cc0043e}},	//   рҙың_, sulp, _ونے_, रैलो, 
   {{0xcee801ed,0x7e61349f,0x611800ef,0x00000000}},	//   ئرین_, pulp, _vālī, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb1d34a0,0x61180055,0x7afc01ef,0xabe40116}},	//   nkré, _tālī, _vypt, ﺎﻟﻐﺎ, 
   {{0xad9800d0,0xdc5400f1,0xfc30007b,0x00000000}},	// [1e200] slúc, _اربک, _بحب_, --, 
   {{0x2ba40a59,0x36942502,0x00000000,0x00000000}},	//   खाणा, ишес, --, --, 
   {{0xfaa534a1,0xeaac0583,0x39e80006,0x00000000}},	//   _тано, _ہٹی_, _адно_, --, 
   {{0x7c34036e,0x00000000,0x00000000,0x00000000}},	//   _ktyr, --, --, --, 
   {{0x53340395,0x23b000ec,0x00000000,0x00000000}},	//   белт, ڊمنس, --, --, 
   {{0xe73534a2,0x240534a3,0x98a00210,0x33f4013d}},	//   _вер_, анчи_, ecić_, шчес, 
   {{0x66e00aa5,0x31c40640,0x00000000,0x00000000}},	//   _дора, исив, --, --, 
   {{0x7c34eb13,0xf1c40131,0xdb1cb0ca,0x00000000}},	//   _otyr, گۈچى_, gkré, --, 
   {{0x36d4ea10,0xdb1c00f2,0x9f5c01ef,0x00000000}},	//   _соңр, skrè, _žrát_, --, 
   {{0xb110063f,0x00000000,0x00000000,0x00000000}},	//   bụne, --, --, --, 
   {{0x7c3534a4,0x38700731,0x00000000,0x00000000}},	//   _atyr, htyr_, --, --, 
   {{0x3870007c,0x00000000,0x00000000,0x00000000}},	//   ktyr_, --, --, --, 
   {{0xafe4988a,0x2d040276,0x7c34013a,0x705002f2}},	//   _кодл, рянг, _ctyr, _بۆخا, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x1ab4241e,0x1f34025d,0x7c340200,0x00000000}},	//   обря, _דרור_, _etyr, --, 
   {{0xd0100451,0x7c340240,0x41a80303,0x00000000}},	//   _بلڪ_, _ftyr, कायस, --, 
   {{0xad980005,0x765c2694,0x00000000,0x00000000}},	// [1e210] clúa, erpy, --, --, 
   {{0xdb1c0109,0x98a04d8c,0x7dc40332,0x00000000}},	//   tirô, ncię_, _iósa, --, 
   {{0xb8fc14cf,0x6680036b,0x98a00210,0x5724215c}},	//   _थे_, غیرل, ycić_, زىنك, 
   {{0x78a002fb,0x7dc40162,0x7c3400e4,0x00000000}},	//   ťova, _kósa, _ytyr, --, 
   {{0x7dc534a5,0xe78401d5,0x00000000,0x00000000}},	//   _jósa, _куво, --, --, 
   {{0x7dc5066d,0x00000000,0x00000000,0x00000000}},	//   _mósa, --, --, --, 
   {{0x5b7c025f,0xdb1c3262,0xb0600166,0xd26800ae}},	//   דרוא, chrä, _şäpt, لصين_, 
   {{0x6e380175,0x00000000,0x00000000,0x00000000}},	//   dptb, --, --, --, 
   {{0x657934a6,0x7dc400c6,0xdb1d34a7,0x00000000}},	//   _ibuh, _nósa, rkré, --, 
   {{0x72400f31,0xdb1c0ab9,0xc02c0023,0x90e421ef}},	//   _کھول, skré, _ተባሂል, تسىن, 
   {{0xf4940014,0xdb1c0036,0x00000000,0x00000000}},	//   _پھۆت_, pkré, --, --, 
   {{0x7dc40085,0x5184cef8,0x38700200,0x00000000}},	//   _bósa, _муча, ytyr_, --, 
   {{0xa3c82ca5,0x906400fb,0x91a400cd,0x00000000}},	//   _लता_, _дњјл, कारै, --, 
   {{0x7dc534a8,0xdee046ee,0x213d34a9,0x00000000}},	//   _dósa, _қоқи, lbuh_, --, 
   {{0x657934aa,0xdce40139,0x290934ab,0x1da802c3}},	//   _obuh, _fbiğ, _azca_, गादत, 
   {{0x3e7028c9,0x3f8534ac,0x38700363,0xad9800ae}},	//   mát_, lelu_, ttyr_, llún, 
   {{0x3e7028c3,0x600c4e9b,0x6b80000f,0x38700076}},	// [1e220] lát_, rømf, _űnge, utyr_, 
   {{0xbb8534ad,0x657934ae,0x387134af,0xf7480f78}},	//   _الدي, _abuh, rtyr_, الاي_, 
   {{0xa4f00dd4,0x3e700765,0x66240790,0xb884013a}},	//   _བཙུག_, nát_, _ırkç, djíž, 
   {{0x3f84123c,0xe0c41ec7,0x7af80112,0x387084ae}},	//   helu_, _فز_, üttu, ptyr_, 
   {{0x3e7000dd,0x6b5c02d3,0x3f840821,0x09881df2}},	//   hát_, _ንምብጻ, kelu_, _таяқ_, 
   {{0x3f841727,0x6578136f,0x3e7028c3,0xe72534b0}},	//   jelu_, _ebuh, kát_, _горд_, 
   {{0x3e70066d,0xdb2400e4,0x00000000,0x00000000}},	//   ját_, _ãrõp, --, --, 
   {{0x3e70102c,0xd4c40daf,0xca6c0023,0x31680fac}},	//   dát_, _мөлк, ስቲኦም_, ушко_, 
   {{0xdce42220,0xa50534b1,0x00000000,0x00000000}},	//   _obiđ, _гета_, --, --, 
   {{0xb7f80918,0x3f8534b2,0x1ac80b6d,0x7dc50aa6}},	//   ्तिम_, gelu_, रनाथ, _rósa, 
   {{0x3e7134b3,0x7dc47c7b,0xfbdc022e,0x213caff4}},	//   gát_, _sósa, diª_, bbuh_, 
   {{0x7dc4007b,0x00000000,0x00000000,0x00000000}},	//   _pósa, --, --, --, 
   {{0x3f8534b4,0x9cc80588,0x5c7534b5,0xb03000ee}},	//   belu_, быра_, плят, _эмлә, 
   {{0x3e7134b6,0xec1401e0,0x00000000,0x00000000}},	//   bát_, сегә_, --, --, 
   {{0x2fdc07c5,0x3e7001d3,0xddd42a9b,0x00000000}},	//   mitg_, cát_, _çaşd, --, 
   {{0x7dc40085,0x26e4015b,0x2fdc04cc,0xb8840118}},	//   _tósa, _করলো_, litg_, zjíž, 
   {{0x6d4d34b7,0xb11002e3,0xc7d8ba0e,0x6e28002f}},	// [1e230] maca, kụme, амах_, _hufb, 
   {{0x6d4d34b8,0x6578031c,0x600c0fac,0xe7081063}},	//   laca, _sbuh, rømg, هتان_, 
   {{0x4a7401d9,0x00000000,0x00000000,0x00000000}},	//   _بُجر, --, --, --, 
   {{0x6d4c5b59,0x3f840296,0x213c0007,0x25c00073}},	//   naca, zelu_, xbuh_, वघेण, 
   {{0x998041d5,0x69dd34b9,0xdd180139,0x3e7001d3}},	//   lmiş_, miqe, _mäşx, zát_, 
   {{0x69dc2beb,0x6d4d34ba,0x6b8402d3,0x3e7001ed}},	//   liqe, haca, nejg, yát_, 
   {{0x6d4c493b,0x9980fccc,0x2fdc07de,0x3e700548}},	//   kaca, nmiş_, ditg_, xát_, 
   {{0x3e70066d,0x657934bb,0x6d4d34bc,0x3f8534bd}},	//   vát_, _ubuh, jaca, welu_, 
   {{0x6e288e11,0x6d4d34be,0x7dc400d8,0x9f480118}},	//   _aufb, daca, _bósn, šlím_, 
   {{0x3e7000dd,0x3dc006d1,0x99812828,0x2fdd34bf}},	//   tát_, wkkw_, kmiş_, gitg_, 
   {{0x6d4d34c0,0x3da80a31,0xfde8005b,0xbd440451}},	//   faca, акно_, идок_, يندي, 
   {{0x3e7003f7,0x6d4d34c1,0x6568016d,0x600c00fe}},	//   rát_, gaca, nggh, døme, 
   {{0x3f840e39,0x3e7134c2,0x61f934c3,0x00e4066d}},	//   pelu_, sát_, moul, _بتای, 
   {{0x61f934c4,0x3a200194,0xdb1c5002,0x3e7001d3}},	//   loul, _sikp_, chrû, pát_, 
   {{0x6d4d34c5,0x69dc0429,0xa0640032,0x7c340010}},	//   baca, fiqe, _таҙа_, _žarč, 
   {{0x6d4d34c6,0x3e540a2b,0x69dc014b,0xfbdc01a9}},	//   caca, māt_, giqe, siª_, 
   {{0x3e540061,0x7df00421,0xdb1c03b2,0x00000000}},	// [1e240] lāt_, gāse, mkrí, --, 
   {{0x61f804c4,0x78a00216,0x998003e3,0xf3ec00cc}},	//   houl, ťovo, bmiş_, _চীনৰ_, 
   {{0x3e5534c7,0x61f8fdaf,0xb63400db,0x6b780a7c}},	//   nāt_, koul, زعات, _דרינ, 
   {{0x3a38003e,0x61f934c8,0xdb1c0162,0x80c8216a}},	//   _itpp_, joul, nkrí, िनाइ, 
   {{0x61f83a3b,0x5334010b,0x18c81cd1,0x00000000}},	//   doul, пелт, _уңай_, --, 
   {{0x3e541991,0x6d4d34c9,0x53341e49,0x929422d7}},	//   kāt_, zaca, чект, закц, 
   {{0x6d4c82aa,0x61f8557b,0xd788004b,0x3e541a14}},	//   yaca, foul, _پنځو_, jāt_, 
   {{0x61f934ca,0x3e540061,0x95b40184,0x7f40010a}},	//   goul, dāt_, _эргә, eblq, 
   {{0x6d4d34cb,0x9980d16c,0x6fe934cc,0x443c0327}},	//   vaca, zmiş_, ифов_, cpw_, 
   {{0x69dd34cd,0x7dc402ea,0x6d4d34ce,0x61f806c8}},	//   ziqe, _bóso, waca, aoul, 
   {{0x61f934cf,0x2fdc1570,0x69dc2798,0x00000000}},	//   boul, ritg_, yiqe, --, 
   {{0x61f934d0,0x7dc401e1,0x2fdc039a,0xa2d0012c}},	//   coul, _dóso, sitg_, _भेट्, 
   {{0x31140882,0x7994003b,0x6b840010,0x2ba40118}},	//   देशः_, ddyw, tejg, खाला, 
   {{0x6d4d34d1,0x998043eb,0x3e54005f,0x69dc0472}},	//   saca, tmiş_, bāt_, wiqe, 
   {{0x656934d2,0x2e480801,0x7dc400db,0x6d4d34d3}},	//   yggh, _тяло_, _góso, paca, 
   {{0x99806f30,0x19a800f7,0x7dc401d3,0x600c072b}},	//   rmiş_, отуп_, _jósl, røme, 
   {{0x6b840200,0x69dc036e,0x99802ca8,0x00000000}},	// [1e250] pejg, riqe, smiş_, --, 
   {{0x7bcc9556,0x69dc6e0e,0x61f8a801,0x799402d0}},	//   chbu, siqe, zoul, adyw, 
   {{0x61f801c8,0xe6a80aac,0xac9401c8,0x00000000}},	//   youl, шъал_, _انڌا_, --, 
   {{0x61f80077,0x443c009a,0x69dc03e3,0x00000000}},	//   xoul, tpw_, qiqe, --, 
   {{0xa484e636,0x03a534d4,0x04440640,0x61f934d5}},	//   تجان, зило, челн, voul, 
   {{0x61f802bd,0x3e540882,0xd7f800fd,0xfcc80092}},	//   woul, yāt_, _дус_, _አዋጀ_, 
   {{0x73302dc3,0x61f934d6,0x443c0175,0x719400f1}},	//   رىيا, toul, spw_, ړنيز_, 
   {{0x3e540a2b,0xd5648e3c,0x29d40135,0xdb1c01e7}},	//   vāt_, _отуп, għax_, thrú, 
   {{0x61f934d7,0x00e534d8,0xe2941c5c,0x21a001b9}},	//   roul, яжин, сақ_, зиқм, 
   {{0x442cacd7,0x3e540318,0x00000000,0x00000000}},	//   _iue_, tāt_, --, --, 
   {{0x442534d9,0xbea43ce7,0x3ea4b5f5,0xfcc8001f}},	//   _iil_, чанк, чинг, _አዋጁ_, 
   {{0x442d34da,0x442534db,0x3e540a2b,0xd24c0075}},	//   _kue_, _hil_, rāt_, _ئۆي_, 
   {{0x442534dc,0x442c015b,0x3e540a30,0x4c3401c0}},	//   _kil_, _jue_, sāt_, дэст, 
   {{0x442534dd,0x442d34de,0x7e54009b,0x00000000}},	//   _jil_, _mue_, _етиц, --, 
   {{0x442d34df,0x7dc40162,0x4f0801ec,0x4a740121}},	//   _lue_, _hósm, _وتىپ_, мытт, 
   {{0x442534e0,0x249d34e1,0x442d34e2,0xe9d4011c}},	//   _lil_, _orum_, _oue_, пкс_, 
   {{0x442d34e3,0x442534e4,0x77c802a9,0x7bcc0175}},	// [1e260] _nue_, _oil_, благ_, phbu, 
   {{0x1cdc025c,0xf77000c6,0xa8002218,0x00000000}},	//   _རྟར_, عاء_, езул, --, 
   {{0x442d34e5,0x7bdc1948,0x3a0534e6,0xdb1c002d}},	//   _aue_, _impu, _فکری_, skrâ, 
   {{0x442534e7,0x442d34e8,0x1dcc00dc,0x00000000}},	//   _ail_, _bue_, ासित, --, 
   {{0x442534e9,0x39510074,0x1cb40327,0x7dc41941}},	//   _bil_, mays_, ྞའི_, _nósm, 
   {{0x442d34ea,0x442534eb,0x395134ec,0x249c0c18}},	//   _due_, _cil_, lays_, _drum_, 
   {{0x442534ed,0x249c008c,0x442d34ee,0x7bdc0a2e}},	//   _dil_, _erum_, _eue_, _mmpu, 
   {{0x442c4888,0x442534ef,0x249c1a56,0x11d80597}},	//   _fue_, _eil_, _frum_, توبة_, 
   {{0x442534f0,0x442d34f1,0x7dc45b84,0x7bdc0c8c}},	//   _fil_, _gue_, _cósm, _ompu, 
   {{0x93c801ed,0x39500009,0x09c82e35,0x00000000}},	//   _بارہ_, hays_, _रत्य, --, 
   {{0x3950079b,0x442d34f2,0x33080c75,0xfe6c00f2}},	//   kays_, _zue_, _اياپ_, لگي_, 
   {{0x442534f3,0x00000000,0x00000000,0x00000000}},	//   _zil_, --, --, --, 
   {{0x44240517,0x442c0421,0x41a833ff,0xb11802dd}},	//   _yil_, _xue_, कारस, _اقشا_, 
   {{0xe10804ac,0x442477f0,0x952c0135,0xb8880020}},	//   _פּאָ, _xil_, _སུའི_, _ምርጫው_, 
   {{0xb93802e3,0x9a8534f4,0x3950058a,0xdeecd594}},	//   _ọmụr, нутл, fays_, _чы_, 
   {{0xad2534f5,0x39500009,0xda040395,0x80c00154}},	//   _عربو, gays_, ечуп, ৎপর্, 
   {{0x290c0628,0x2d8934f6,0x7bdc0077,0x00000000}},	// [1e270] åga_, mece_, _fmpu, --, 
   {{0x442d34f7,0x29040a2b,0x7df00882,0x00000000}},	//   _rue_, āna_, māsa, --, 
   {{0x442534f8,0x26c534f9,0x442d34fa,0x39504f45}},	//   _ril_, áno_, _sue_, bays_, 
   {{0x442c0134,0x2d884dce,0x442534fb,0xdce40034}},	//   _pue_, nece_, _sil_, _wcią, 
   {{0x442534fc,0x7bdc000f,0xe9dc0248,0x5884074d}},	//   _pil_, _ympu, _imú_, _пыра, 
   {{0x442d34fd,0x823534fe,0x2d880921,0x4424fa80}},	//   _vue_, وربا, hece_, _qil_, 
   {{0x44245b47,0x7df00882,0x2d880a73,0x442c003e}},	//   _vil_, hāsa, kece_, _wue_, 
   {{0x44240917,0x442d34ff,0x2d888185,0x92640131}},	//   _wil_, _tue_, jece_, ردىم, 
   {{0x2d88708d,0x442c007d,0x249c0522,0xa244be6e}},	//   dece_, _uue_, _urum_, _کیبل_, 
   {{0x44253500,0x3fcc0c58,0xd3740063,0x00000000}},	//   _uil_, ৰক্ষ, _плућ, --, 
   {{0x2d880ffb,0x200800e2,0xe9dc01e1,0x00000000}},	//   fece_, ēci_, _omú_, --, 
   {{0xfce4aebf,0x7bdc0066,0xdb1c00bc,0xe9dc0248}},	//   домо, _smpu, jkrá, _nmú_, 
   {{0x7dc40579,0x7bdc05b1,0x71703b89,0xffb80354}},	//   _hósk, _pmpu, _شهوا, _мукъ_, 
   {{0x39513501,0x78a002fb,0xe9dc007b,0x80c80073}},	//   ways_, ťovk, _amú_, िनीं, 
   {{0x6b940007,0x7c20011c,0xab2472b2,0x39500175}},	//   _daxg, _èorm, дора_, tays_, 
   {{0x2d893502,0x0eb80139,0x7dc402d2,0xb030008e}},	//   cece_, _хушы_, _mósk, _янәш, 
   {{0x39513503,0x6b940112,0x7df000b8,0x00000000}},	// [1e280] rays_, _faxg, cāsa, --, 
   {{0x77f8069f,0x6b940097,0x7bdd3504,0x39513505}},	//   ्तेक_, _gaxg, _umpu, says_, 
   {{0x39500334,0x00000000,0x00000000,0x00000000}},	//   pays_, --, --, --, 
   {{0xdb1c02fb,0x1cdc031c,0xf5080798,0x6b9401a9}},	//   ckrá, _རྟོ_, онел_, _zaxg, 
   {{0x75200022,0x00000000,0x00000000,0x00000000}},	//   тҟаҵ, --, --, --, 
   {{0x2d891181,0x00000000,0x00000000,0x00000000}},	//   zece_, --, --, --, 
   {{0x41a81fbc,0xe3ac4ce4,0xe734009b,0x2d880205}},	//   कांस, شرو_, _цес_, yece_, 
   {{0x7df00882,0x00000000,0x00000000,0x00000000}},	//   yāsa, --, --, --, 
   {{0x2d893506,0x91c4013d,0xad9803b2,0x00000000}},	//   vece_, _җәйл, slúk, --, 
   {{0x7df00882,0x1cdc031c,0x63810012,0xdb1c0306}},	//   vāsa, _རྟེ_, _игуа, zkrá, 
   {{0xdb1d3507,0xeea800d3,0xad9800ae,0x00000000}},	//   lkræ, іток_, llúi, --, 
   {{0x712401d5,0x600c0450,0x88d400b8,0x00000000}},	//   _قرشل, røma, bṛha, --, 
   {{0x2d891a82,0xad2404d3,0x6218008f,0xdb1c01bf}},	//   rece_, بردو, _וואק, nkræ, 
   {{0x2d880f03,0x7df03a71,0x0a9402e8,0x00000000}},	//   sece_, rāsa, нагю, --, 
   {{0xda7812e7,0x7e640124,0xdb1c0118,0xad980332}},	//   мят_, _зхыҵ, tkrá, hlúi, 
   {{0x99d53508,0x6b9401d9,0x996400a8,0x2ec800cd}},	//   نتقا, _waxg, ктул, ानीत, 
   {{0x2afc29d6,0x481506aa,0xdb1c0306,0x00000000}},	// [1e290] _शुरु_, емас, rkrá, --, 
   {{0xdb1d3509,0xdc3c011a,0xfd50002b,0x00000000}},	//   skrá, _ועזר, dadṛ, --, 
   {{0xfbf001c6,0x00000000,0x00000000,0x00000000}},	//   _сүрь, --, --, --, 
   {{0xe9dc00d2,0xcfe400cc,0x846c0023,0x25a800d1}},	//   _umú_, নকিন, _ትሰርሕ_, غداي_, 
   {{0x69cc0205,0x2ec800cd,0x00000000,0x00000000}},	//   _ilce, ानुत, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x45d5350a,0x569400c7,0x00000000,0x00000000}},	//   _зовс, _иарт, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7f7400a8,0xd83801ef,0x00000000,0x00000000}},	//   нунц, _ččk_, --, --, 
   {{0x64580270,0x6d5c011f,0x0f480023,0x53e401af}},	//   _ivui, _adqa, _ዘበርከ, _ицха, 
   {{0x69cd350b,0x00000000,0x00000000,0x00000000}},	//   _olce, --, --, --, 
   {{0x7dc40174,0x78a00306,0xdbf801ad,0x00000000}},	//   _kósi, ťovi, ंक्ड_, --, 
   {{0x315425f9,0x00000000,0x00000000,0x00000000}},	//   _ניסן_, --, --, --, 
   {{0x6d5c06be,0x00000000,0x00000000,0x00000000}},	//   _edqa, --, --, --, 
   {{0xf984afc4,0x3ea460a1,0xfb840139,0x00000000}},	//   нгво, _чийг, мыңн, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe8f5350c,0xdb1c00b5,0x7dc401e7,0x6738010e}},	// [1e2a0] елт_, xkræ, _rósh, _şuja, 
   {{0xe8e5350d,0x69cc6fa8,0xa3b019cc,0xacf8011a}},	//   хмуд_, _elce, टाफ_, _מהפכ, 
   {{0xd911350e,0x6fb4025c,0xa3b0060c,0x9ba41c3e}},	//   _چیز_, ནྡྲའ, टान_, _كەڭى, 
   {{0xd91029a4,0xdb1c00b5,0x2e38008f,0xb82807a5}},	//   _نیز_, tkræ, לגענ, _номз_, 
   {{0x64a03d89,0x600c01bf,0xe9a000db,0x00000000}},	//   лаца, vømn, _саяп, --, 
   {{0x6fe40129,0x7dc42507,0xdb1cd379,0xad9801e7}},	//   _mécè, _dósi, rkræ, rlúi, 
   {{0xdb1d350f,0x600c01bf,0xf608007b,0x00000000}},	//   skræ, tømn, _فتره_, --, 
   {{0x7dc4a92b,0x80c800cc,0xdb1c005c,0xdce40210}},	//   _fósi, িছন্, pkræ, _wcię, 
   {{0x63a80316,0x600c00ed,0xdb1c5df7,0xd0d40395}},	//   ální, rømn, lkrä, топъ, 
   {{0x99800165,0x2898010f,0x00000000,0x00000000}},	//   lliń_, ליפא, --, --, 
   {{0xdb1c0a40,0xe0cc04fb,0x7df000e2,0x00000000}},	//   nkrä, لزی_, rāsn, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x32040a73,0xdfcc05d9,0xdee80092,0xdb1c007c}},	//   _ikoy_, _ڏين_, ቅተኛ_, hkrä, 
   {{0x6fe420ef,0x09c800dc,0x5f9005a2,0x00000000}},	//   _décè, रस्य, _бишт, --, 
   {{0xdb1c0e78,0xb6040e04,0xce9425ea,0x1f340677}},	//   chrü, _košć, _райъ, _ארור_, 
   {{0x199493fb,0xdb1c01e3,0x994800ae,0x00000000}},	//   лася, dkrä, فلفل_, --, 
   {{0xb60463e0,0x58d4f647,0xd7c800f1,0x00000000}},	// [1e2b0] _mošć, готт, کوله_, --, 
   {{0x1cdc0135,0xb78400fd,0xeb480139,0x7dc41d1d}},	//   _རྟི_, кәсе_, _эчик_, _rósi, 
   {{0x4af806a6,0x7dc53510,0x2d980200,0xdb1c343a}},	//   _ценю_, _sósi, _kaqe_, gkrä, 
   {{0x320402ea,0x7dc4021c,0x957400fd,0xdb24007c}},	//   _nkoy_, _pósi, гышч, åråt, 
   {{0x2d993511,0xdb1c007b,0xe22c004d,0x00000000}},	//   _maqe_, bhró, ợđiệ, --, 
   {{0x320422d0,0xdb1cfc2d,0x00000000,0x00000000}},	//   _akoy_, chró, --, --, 
   {{0xbe102aab,0x99800165,0xdb1c007c,0x96f80150}},	//   _সংসদ_, bliń_, ckrä, _зерт_, 
   {{0x5694fbac,0x7dc406ea,0x2d980200,0x00000000}},	//   _щаст, _hósv, _naqe_, --, 
   {{0xa1840724,0x7fd401ce,0x43940124,0x00000000}},	//   _җыел, віні, _иаас, --, 
   {{0x25bc05c7,0x7dc443e9,0xbfc400d8,0xe4a40117}},	//   _houl_, _jósv, тбок, _орҷо, 
   {{0x2d9819a2,0x25bd3512,0x7c203eb9,0x719401e2}},	//   _baqe_, _koul_, _èori, رنیز_, 
   {{0xb6041505,0x25bd3513,0xdb1c0728,0x2d980200}},	//   _gošć, _joul_, nkrå, _caqe_, 
   {{0x25bd3514,0x2d98002e,0x00000000,0x00000000}},	//   _moul_, _daqe_, --, --, 
   {{0x6c00084c,0x00000000,0x00000000,0x00000000}},	//   изяз, --, --, --, 
   {{0x2d98044e,0x29080de2,0xdb1c0217,0xef1400c7}},	//   _faqe_, _ayca_, kkrå, _имш_, 
   {{0x25bc00a8,0xb2200008,0xf2d00a1e,0x49980166}},	//   _noul_, _þætt, בעל_, нтуя_, 
   {{0xdb1c00c6,0xe6ac013d,0x6cb07f21,0x9ce801d3}},	// [1e2c0] thró, _eçüç, _көрт, _سودے_, 
   {{0xdb1d3515,0x32240327,0xf74400f0,0xb6a41180}},	//   tkrä, _ལངྐར_, тежо, кизл, 
   {{0x25bd3516,0x27e00427,0x9ac4013d,0x00000000}},	//   _boul_, _dmjn_, _синҗ, --, 
   {{0x600cad6a,0x25bd3517,0xdb1c26bc,0x91fc002b}},	//   dømm, _coul_, rkrä, _ivāg, 
   {{0xdb1d3518,0x25bcb3a0,0x20040427,0xb4b054a2}},	//   skrä, _doul_, _okni_, рилә, 
   {{0x25bc0489,0x3dd0015d,0x62000014,0x63800022}},	//   _eoul_, _llyw_, یووٕ, ҳгәа, 
   {{0x25bd3519,0x600c0450,0x6260041b,0x22540b24}},	//   _foul_, røml, авја, نجيب_, 
   {{0x30a5351a,0x2004041a,0x25bc91fa,0x29080142}},	//   вров, _akni_, _goul_, _yyca_, 
   {{0x2ec9351b,0xa0640b7f,0x2474001f,0x7dc403b2}},	//   ान्त, вања_, _የፍርድ_, _jósu, 
   {{0x78a4f232,0xdef402d3,0xb4cc228d,0xdce400e2}},	//   _mrkv, _ወጺኡ_, शनी_, _daiļ, 
   {{0x2d9802d3,0x25bc0489,0xb8cc0327,0x91c401af}},	//   _paqe_, _youl_, _ྒན_, _бәпл, 
   {{0x32047bad,0x3dd003cb,0x00000000,0x00000000}},	//   _ukoy_, _clyw_, --, --, 
   {{0x20040270,0x4bc44d4c,0x7d14068f,0xdce400de}},	//   _fkni_, гөнг, _czys, _gaiļ, 
   {{0x9f300046,0x1ae4015b,0x889400d1,0xceb91196}},	//   _кеші, _গড়ে_, һибх, _зәм_, 
   {{0xa3b00574,0x2d99351c,0x78a4fe1a,0xde90027d}},	//   टात_, _taqe_, _arkv, _نجيب, 
   {{0x3dd00042,0x4c948c2b,0x00000000,0x00000000}},	//   _glyw_, _биис, --, --, 
   {{0x78a404b9,0x39442b76,0x25bc01b8,0x91fc00cd}},	// [1e2d0] _crkv, ñosa_, _roul_, _evāg, 
   {{0xdb1c002d,0x7dc40a87,0xac042bef,0x00000000}},	//   nkrû, _dósu, _جذبو, --, 
   {{0x25bd351d,0x78a403b2,0x00000000,0x00000000}},	//   _poul_, _erkv, --, --, 
   {{0x600c4e9b,0x29080356,0xdef40023,0x7d140432}},	//   vømm, _tyca_, _ወጺኣ_, _yzys, 
   {{0x25bc1570,0xd839351e,0xdb1c00cc,0xd47401c6}},	//   _voul_, _аэс_, rkrå, илцъ, 
   {{0x600c11c0,0x7dc5351f,0x25bd3520,0x91fc0055}},	//   tømm, _hóst, _woul_, _yvāg, 
   {{0x25bcad72,0x7dc401d3,0x932400f1,0xc0040116}},	//   _toul_, _kóst, ټرون, һпик, 
   {{0x600cfb11,0x409400c7,0x00000000,0x00000000}},	//   rømm, грот, --, --, 
   {{0x44f53521,0xe4e410f5,0x7dc49936,0x66193522}},	//   _спас, _рівн, _móst, _ihuk, 
   {{0x7dc40005,0x94180276,0x91fc00b8,0xde40001f}},	//   _lóst, _ажут_, _avād, _የተወለ, 
   {{0x66181682,0x7d14012d,0x00000000,0x00000000}},	//   _khuk, _szys, --, --, 
   {{0x91fc0055,0x00000000,0x00000000,0x00000000}},	//   _rvāg, --, --, --, 
   {{0x407804ac,0x661805b8,0x91fc00dc,0x00000000}},	//   _נאַװ, _mhuk, _dvād, --, 
   {{0x91fc00cd,0x7dc40d12,0xee2c0451,0xf090011a}},	//   _evād, _rósu, _کٽي_, _לנד_, 
   {{0x7dc53523,0x4ea40063,0x661826bb,0x60d93524}},	//   _bóst, _врња, _ohuk, lzum, 
   {{0x7dc4007b,0xf2d0010f,0x00000000,0x00000000}},	//   _cóst, זעל_, --, --, 
   {{0x7d14068f,0xfbd003e6,0xc9544990,0x8d8419c5}},	// [1e2e0] _uzys, _هتد_, ртсы, _ئشىن, 
   {{0x66193525,0xc7640447,0xad980b21,0x60d8037e}},	//   _ahuk, لامى, slút, izum, 
   {{0x66193526,0x7dc40008,0x75440b7b,0x5f440092}},	//   _bhuk, _fóst, гнез, _የአስቸ, 
   {{0xf9913527,0x66193528,0x7c3405d1,0xad980561}},	//   _ابد_, _chuk, _kuyr, llúr, 
   {{0x66193529,0xb4cc01bc,0x78a001e4,0x338401c4}},	//   _dhuk, शने_, ĥovs, гуйв, 
   {{0xe3ac7b70,0x7bcd352a,0x60d8005f,0x661801c6}},	//   كرى_, nkbu, dzum, _ehuk, 
   {{0x60d800e2,0x64a000fb,0x87b80117,0x00000000}},	//   ezum, _һата, _руят_, --, 
   {{0x7c3400ad,0x80dc0154,0x60d8002f,0x521400d8}},	//   _ouyr, মপন্, fzum, јдит, 
   {{0x4fd44727,0x765c000f,0x64a1352b,0x7bcc6672}},	//   ижит, lspy, _лата, kkbu, 
   {{0x66180066,0x7bcc01f5,0x91fc00dc,0x00000000}},	//   _zhuk, jkbu, _svād, --, 
   {{0x67e8031c,0x765d352c,0x00000000,0x00000000}},	//   nżja, nspy, --, --, 
   {{0x7c34a35d,0xad642088,0x7bcc01f5,0x00000000}},	//   _buyr, داده, ekbu, --, 
   {{0xd25000b2,0x7c34010e,0xdb1c002d,0x7dc5352d}},	//   _اچڻ_, _cuyr, pkrû, _róst, 
   {{0x765d352e,0x99d40145,0x7c3403e0,0x7e7c054e}},	//   kspy, ەتكا, _duyr, ăspr, 
   {{0x7dc5352f,0xe57c005f,0x91fc002b,0x67e80327}},	//   _póst, šķir_, _ivāb, jżja, 
   {{0x256801e1,0x765c032e,0x00000000,0x00000000}},	//   _mòlà_, dspy, --, --, 
   {{0x661818f7,0x7c340588,0xb4cc2d3b,0x4c9400f3}},	// [1e2f0] _rhuk, _guyr, शनो_, _типс, 
   {{0x2e38002e,0x7dc41892,0x7bcd3530,0x00000000}},	//   _këf_, _fóss, ckbu, --, 
   {{0x2e381574,0x0554082d,0x38700076,0xbb380375}},	//   _jëf_, атля, auyr_, _בעתי, 
   {{0x1cdc031c,0xa3e41b76,0xff780092,0x00000000}},	//   _རྟཌ_, मोन_, ባሳደሩ_, --, 
   {{0x66180dc9,0x2e380694,0x1bb843fb,0x00000000}},	//   _vhuk, _lëf_, _شایع_, --, 
   {{0x03a53531,0x32ec00ac,0x600c0450,0x00000000}},	//   рико, _bəy_, rømk, --, 
   {{0x66193532,0x070896ec,0x2c7c0109,0x922000ab}},	//   _thuk, _شيري_, hîd_, मगंज_, 
   {{0x661806c8,0x60d91701,0x32f0005e,0x41a837fb}},	//   _uhuk, tzum, تكىز, твин_, 
   {{0xe294040d,0x44380356,0x00000000,0x00000000}},	//   тақ_, _îs_, --, --, 
   {{0x7c34004e,0x3fe47e7e,0x00000000,0x00000000}},	//   _ruyr, ржов, --, --, 
   {{0x6128ec9e,0x7c3403f0,0x91fc00cd,0x60d8167c}},	//   _bölü, _suyr, _dvāb, szum, 
   {{0x2e380de2,0xb2b80302,0x724001ed,0x91fc00dc}},	//   _dëf_, _במער, _بھول, _evāb, 
   {{0x7df04424,0x612803b9,0xdb1c03b2,0x7c34290f}},	//   nāsi, _dölü, lkrø, _quyr, 
   {{0x3f684f33,0xbea40354,0x3e880150,0x00000000}},	//   _рико_, _вакк, _айко_, --, 
   {{0x39453533,0x39540261,0x2e380036,0x7bcc134a}},	//   ñoso_, ињат, _gëf_, rkbu, 
   {{0x213d3534,0xf2d000c8,0x7c340986,0x612871d6}},	//   ncuh_, קען_, _tuyr, _gölü, 
   {{0xb7e40440,0x67e8025c,0x18a800c7,0xf1b0011a}},	// [1e300] ажак, wżja, ыбаҩ_, חסן_, 
   {{0x6578020b,0xdb1c0158,0x2e381bce,0xac140114}},	//   _acuh, kkrø, _yëf_, _коњу_, 
   {{0xdb240acb,0x765c023a,0xb4cc002b,0x00000000}},	//   _دودی, uspy, शन्_, --, 
   {{0x32ec03be,0x65780142,0x765c2268,0x869802d5}},	//   _rəy_, _ccuh, rspy, ытут_, 
   {{0x3940045f,0x998c0024,0x32ec03e3,0xa5040064}},	//   _ifks_, ūdų_, _səy_, аеца_, 
   {{0x27b00075,0x1cdc0327,0xb4b4012d,0x91fc0171}},	//   _мәхс, _རྟབ_, _छपी_, _ovāc, 
   {{0xfe045e58,0x27ec06af,0xf6253535,0x0f140037}},	//   रवास_, ègne_, _вдво, _डरेस_, 
   {{0x91fc00cd,0x7df000de,0x00000000,0x00000000}},	//   _svāb, bāsi, --, --, 
   {{0x91fc002b,0x2e3800e8,0xdb1c01bf,0xfd6000b8}},	//   _avāc, _sëf_, akrø, _udvṛ, 
   {{0x61280205,0x6e440092,0x00000000,0x00000000}},	//   _sölü, _የተገባ, --, --, 
   {{0x612801b8,0xe2940f64,0x7dc408a5,0xc1b8009d}},	//   _pölü, _вах_, _rósr, тлөх_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x5c753536,0x91fc00b8,0xf0b800db,0xe7f800bc}},	//   олят, _evāc, _جااش_, ्वमा_, 
   {{0xce940139,0x9b6801d5,0x00000000,0x00000000}},	//   _гакъ, ишса_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7f9c0023,0x00000000,0x00000000,0x00000000}},	//   _ገበናዊ_, --, --, --, 
   {{0x7afd3537,0x39400067,0x290c01a8,0x9e2400cf}},	// [1e310] _expt, _dfks_, æga_, _بىيو, 
   {{0x39401140,0xcb9800d6,0x7dc53538,0x7df000dc}},	//   _efks_, _свої_, _hósp, vāsi, 
   {{0x29040034,0x1638007b,0x00000000,0x00000000}},	//   łna_, لسنة_, --, --, 
   {{0x31640066,0x600c013c,0x213c011f,0x44b40137}},	//   _ndoz_, rømi, xcuh_, йбес, 
   {{0x434402e8,0x600c03b2,0xa3b00c5a,0xe8540408}},	//   белв, sømi, टाल_, _тĕлн, 
   {{0x3164005a,0x4254487f,0x6fa42c35,0xb6000327}},	//   _adoz_, бтит, _कोलं, _ġġeg, 
   {{0x1cdc031c,0x67e80327,0x77400133,0x00000000}},	//   _རྟན_, lżjo, _رێنم, --, 
   {{0xf8ac0014,0xdce400ef,0xdb1d3539,0x1af80677}},	//   _تکہ_, _gaiķ, rkrø, ימול_, 
   {{0x17240135,0xd498026a,0x91842002,0x213c01ab}},	//   _འཛོམ_, _врх_, تۇنۇ, rcuh_, 
   {{0x6448d000,0x98a0031c,0x53340a5b,0xc3f4009f}},	//   mpgi, sbiħ_, _дефт, _اترڙ, 
   {{0xee35353a,0x3f842da6,0x6e440092,0x6fa401f9}},	//   йнэ_, rflu_, _የተግባ, _कोळं, 
   {{0x7051353b,0xfc44012c,0x62800112,0xe1f006c2}},	//   _کنوا, říme_, mtno, _بسط_, 
   {{0x6281353c,0xb224008c,0xd13801c4,0x00000000}},	//   ltno, snæð, _тхх_, --, 
   {{0x8fa400c6,0xcee9353d,0x6b840175,0x62800175}},	//   _ومنه, ارین_, gfjg, otno, 
   {{0x91fc0a28,0x17240135,0xad98022a,0x00000000}},	//   _uvāc, _འཛེམ_, koúh, --, 
   {{0x628001f5,0xdb1c0098,0xadfc466d,0xdb0c013d}},	//   itno, njré, _उदयन_, _ğiäs, 
   {{0xb4b405f9,0xadd40375,0x62800010,0x00000000}},	// [1e320] _छपे_, _לוקח_, htno, --, 
   {{0x6ec800ac,0xd5b001d9,0x00000000,0x00000000}},	//   bəbd, ڈہس_, --, --, 
   {{0x628001a6,0xaa400a89,0x2f58010f,0x00000000}},	//   jtno, _неэл, רדענ, --, 
   {{0x2508205b,0x628021e3,0xa2a800bc,0xb32000c7}},	//   گرمی_, dtno, झिन्, ҧҟақ, 
   {{0x7994047e,0x62800210,0x00000000,0x00000000}},	//   meyw, etno, --, --, 
   {{0xd37000c6,0x62800e04,0x3a381511,0xe7344575}},	//   ذهب_, ftno, _kupp_, _гер_, 
   {{0x3a39353e,0x32081ebb,0x00000000,0x00000000}},	//   _jupp_, лхин_, --, --, 
   {{0x3a380221,0x66f40375,0xe7f8146b,0x00000000}},	//   _mupp_, _המלא_, ्वथा_, --, 
   {{0x6284014a,0x3a389e50,0xe4c00075,0x00000000}},	//   _äjon, _lupp_, _ейти, --, 
   {{0x2e480801,0x74143090,0x24c400f7,0xa3b000dc}},	//   лямо_, _اوطا, _угуп_, टाः_, 
   {{0x7995353f,0x3a380037,0xceb850e5,0x67b80677}},	//   keyw, _nupp_, рәл_, אמיק, 
   {{0xb2247676,0x600c03b2,0xe714011a,0x00000000}},	//   _умел, dømu, מחיר_, --, 
   {{0xa06405bc,0x6d4c01ab,0xc0a800f2,0xaf5001af}},	//   _гача_, rbca, _پانل_, _енлә, 
   {{0x3a380036,0x60f53540,0x80c40825,0x00000000}},	//   _bupp_, _унія_, िहरे, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3a380fac,0xa92801ec,0x00000000,0x00000000}},	//   _dupp_, гізе_, --, --, 
   {{0x1724003d,0x3a3800e8,0x48c400c7,0x00000000}},	// [1e330] _འཛུམ_, _eupp_, цәна, --, 
   {{0xb8a00020,0x67e8038f,0x62800308,0x00000000}},	//   ፈልጋል_, rżjo, ytno, --, 
   {{0x86993541,0x3a38007c,0x6280dd11,0x799402d0}},	//   ркес_, _gupp_, xtno, beyw, 
   {{0xe6d403b2,0x00000000,0x00000000,0x00000000}},	//   _ítíð, --, --, --, 
   {{0xe7f800dc,0xdeac01e4,0xd1cc02d3,0x22a40051}},	//   ्वदा_, _ĉeƭa, ቤናት_, _sđk_, 
   {{0x3e4400b0,0x6448011c,0xe5e00014,0xa3b00118}},	//   _hēte_, rpgi, _کٲری, टाइ_, 
   {{0x6ec800ac,0x3a380de2,0x6fa40ce0,0x05944ea7}},	//   həbb, _xupp_, _कोइं, _وارگ, 
   {{0x62801cf2,0x6448049f,0x22a40051,0x6ec803e3}},	//   rtno, ppgi, _vđk_, kəbb, 
   {{0x62813542,0x3e4402b5,0x63680e92,0xed5c00b8}},	//   stno, _mēte_, _брег_, daþ_, 
   {{0x249c013c,0x62800fac,0xe3f40066,0x183873cd}},	//   _isum_, ptno, _اثرب, זאזל_, 
   {{0xf7700375,0x600c08cb,0x91fc00cd,0x00000000}},	//   וקי_, dømt, _ivān, --, 
   {{0x3a393543,0x52748944,0x00000000,0x00000000}},	//   _rupp_, _رامز, --, --, 
   {{0xd1b808b0,0x61e8010a,0x3a380f85,0xdb080241}},	//   _دالا_, _imgl, _supp_, _àmúy, 
   {{0x3a3833b8,0xfeb80133,0x031c0456,0x6b8002d2}},	//   _pupp_, _نابت_, _फराह_, _öngl, 
   {{0x3a380140,0xfd6400e4,0x9f54010e,0xca3c0220}},	//   _qupp_, _motẽ, _üzñe_, _ﺟﯩﺮ_, 
   {{0xe9d53544,0x249c166e,0x6ec40316,0x600c0fac}},	//   окс_, _osum_, ाहरु, rømu, 
   {{0x61e805b1,0x6608e741,0x3a3801c7,0x249c058a}},	// [1e340] _mmgl, dogk, _wupp_, _nsum_, 
   {{0x95f40027,0x3a393545,0x27b00166,0xf6d53546}},	//   ेक्ट_, _tupp_, мәсс, يزاد, 
   {{0xb4b000dc,0xa3b0216a,0x249d3547,0xf1e8012d}},	//   टम्_, टाई_, _asum_, जोड़_, 
   {{0xe0c40133,0x91fc002b,0x2474001f,0x34a80114}},	//   _قز_, _avān, _የልምድ_, ивео_, 
   {{0xf49410fe,0x24e4033a,0xe5940150,0x00000000}},	//   تشاد, омци_, ікші_, --, 
   {{0x39513548,0x61e802d0,0xf7700133,0x6f04012d}},	//   lbys_, _amgl, _تاح_, ękcz, 
   {{0x249c0393,0x6608003e,0x00000000,0x00000000}},	//   _esum_, bogk, --, --, 
   {{0xe5743334,0x75d41b45,0x66080098,0x91fc00dc}},	//   _мзс_, _بيرا, cogk, _evān, 
   {{0x50f41de6,0x22a00118,0x00000000,0x00000000}},	//   язит, téká_, --, --, 
   {{0x61e80dd4,0x388c005f,0xdb1c01d3,0x99800165}},	//   _emgl, mērā_, nkró, loiń_, 
   {{0x66000036,0x00000000,0x00000000,0x00000000}},	//   énkg, --, --, --, 
   {{0xdce40306,0xcf200790,0xd34402f2,0x00000000}},	//   _edič, _ışıl_, _بیژه_, --, 
   {{0x395000b5,0x70f40736,0x00000000,0x00000000}},	//   dbys_, _بسائ, --, --, 
   {{0xa3b01d8a,0xdb1d3549,0xc5a00150,0x00000000}},	//   टाए_, skrý, _ﺍﻵﻤﻨ_, --, 
   {{0x600c2188,0x7df03a71,0xa9c48df2,0x61e80042}},	//   rømt, tāst, осак, _ymgl, 
   {{0x39500076,0x00000000,0x00000000,0x00000000}},	//   gbys_, --, --, --, 
   {{0x58842e70,0x3a2003e0,0x818c01ec,0x00000000}},	// [1e350] дыха, _dhkp_, _ﺒﺄﻴﺔ_, --, 
   {{0x6fd406af,0x39500076,0x00000000,0x00000000}},	//   _mâco, abys_, --, --, 
   {{0x3951354a,0xe6b003e6,0x66080098,0xa645354b}},	//   bbys_, بلاگ, togk, زخان, 
   {{0x39500042,0x91fc00cd,0x00000000,0x00000000}},	//   cbys_, _svān, --, --, 
   {{0x6609354c,0xad9800e4,0x00000000,0x00000000}},	//   rogk, boúv, --, --, 
   {{0x61e801a6,0x249c0393,0xdc9c0a7c,0x4254329b}},	//   _smgl, _vsum_, יידל, птит, 
   {{0x96f839fb,0x5b580a7c,0x61e801a9,0x998003e0}},	//   _дерт_, חשון_, аmlа, nliş_, 
   {{0x249c0190,0x016403b7,0x00000000,0x00000000}},	//   _tsum_, чкио, --, --, 
   {{0x249d354d,0x0ff80cb4,0xb60000e4,0x91fc0055}},	//   _usum_, ुवंश_, _áġag, _ivāl, 
   {{0xa3e405f9,0x00000000,0x00000000,0x00000000}},	//   मोश_, --, --, --, 
   {{0xf77000c8,0x2d880175,0x395009ab,0xfe441d0b}},	//   עקט_, ffce_, ybys_, янно, 
   {{0xa3e4330a,0xdb1c0112,0x91fc00cd,0x62880419}},	//   मोर_, rkrü, _jvāl, ľnoč, 
   {{0x61f800a8,0xfce40020,0x7fd4109a,0x7ff438eb}},	//   mnul, _ማውጫ_, _нікі, _ىستا, 
   {{0x600c08d7,0x69c85de3,0x2fdc0036,0xdce400d7}},	//   røms, ögen, chtg_, _udič, 
   {{0x61f8054e,0x91fc0171,0x00000000,0x00000000}},	//   onul, _ovāl, --, --, 
   {{0x69dc0455,0xfbdc022e,0x00000000,0x00000000}},	//   ghqe, shª_, --, --, 
   {{0xad840075,0x61f8013c,0x26c401b8,0x3ec4023b}},	// [1e360] _رايۇ, inul, änon_, _фиқҳ, 
   {{0x395003cb,0x91fc0055,0x6ec800ac,0x00000000}},	//   sbys_, _avāl, ləba, --, 
   {{0x61f9354e,0xdb1c01a8,0x3634178c,0xe7344c92}},	//   knul, rkró, سراس, чех_, 
   {{0xa2bd354f,0x69dc0455,0xd9b41c3e,0x74380023}},	//   वमन्, chqe, _تەرد, _እተገብ, 
   {{0x293404ac,0x383402dd,0x61f80e04,0x6fd40129}},	//   _מאכן_, _ءىسز, dnul, _bâcl, 
   {{0xa3e41cd2,0x91fc00b8,0x61f80334,0x00000000}},	//   मोल_, _evāl, enul, --, 
   {{0x7d1401f4,0xe7f807d0,0x6ec806be,0x61f808a5}},	//   _lyys, ्वरा_, kəba, fnul, 
   {{0x61f93550,0xf770278f,0xe5a00276,0xded40023}},	//   gnul, _تاڭ_, _писи, ርኡን_, 
   {{0x66013551,0x74151647,0x7334446a,0xf1a803e6}},	//   énke, _فورا, _فرائ, لاکه_, 
   {{0x61f93552,0xe4700023,0x91fc00cd,0x00000000}},	//   anul, _ኣርኣያ_, _ivām, --, 
   {{0x600c01bf,0xdef40139,0x00000000,0x00000000}},	//   tømr, зыя_, --, --, 
   {{0x61f80268,0xb22409a5,0x671c13f5,0x56380023}},	//   cnul, _эмел, _भरसक_, _እነንብ, 
   {{0x600c00d4,0xe0cc3090,0x2228179e,0xe1f4009d}},	//   rømr, _مزو_, _ازلی_, _эгц_, 
   {{0xceb81884,0x00000000,0x00000000,0x00000000}},	//   _дәм_, --, --, --, 
   {{0x05dc0037,0x00000000,0x00000000,0x00000000}},	//   _मतलब, --, --, --, 
   {{0x5a3434da,0x7d1402f6,0xa3b087ee,0x09d40154}},	//   енст, _fyys, _जोन_, সোনা, 
   {{0x6d5c031c,0xad980419,0x00000000,0x00000000}},	// [1e370] _ieqa, klúz, --, --, 
   {{0x61f804a7,0x6d5c014f,0x61400008,0x69dc0240}},	//   znul, _heqa, _kíló, shqe, 
   {{0x61f93553,0x6d5c0023,0x998006be,0x00000000}},	//   ynul, _keqa, qliş_, --, 
   {{0xd6d93554,0x6d5c002e,0x44f525ef,0x00000000}},	//   чту_, _jeqa, мпес, --, 
   {{0x03a40d44,0x61f8009b,0x80d00183,0x6d5c0213}},	//   дило, vnul, _তেন্, _meqa, 
   {{0xa3e4068f,0x6d5d3555,0xe3b008de,0x3e440171}},	//   मों_, _leqa, عرش_, _lēta_, 
   {{0x61f808ad,0x91fc0055,0xc20800ec,0xd7f81422}},	//   tnul, _evām, يقتن_, _хуя_, 
   {{0x61f93556,0xe8e80135,0x6d5d3557,0x2000231e}},	//   unul, _ལྟོག, _neqa, čjim_, 
   {{0x61f93558,0x00000000,0x00000000,0x00000000}},	//   rnul, --, --, --, 
   {{0xdb2401d3,0x7d140108,0xfe44009d,0x00000000}},	//   űrés, _ryys, мноо, --, 
   {{0x6d5d3559,0x7d14049b,0x93bc004d,0xa3b000c5}},	//   _beqa, _syys, _khăn, _जोय_, 
   {{0x9f4400c6,0x6458007f,0x7d14023a,0x69c82641}},	//   _imní_, _kwui, _pyys, ögel, 
   {{0x4425355a,0x6d5d355b,0xdd9000e5,0x00000000}},	//   _khl_, _deqa, نڈک_, --, 
   {{0xe8e80327,0x09d400cc,0x7dc400e5,0x00000000}},	//   _ལྟེག, সোমা, _jósz, --, 
   {{0x6d5d355c,0x4425355d,0x6ec806be,0x671c000d}},	//   _feqa, _mhl_, ləbn, _भरषक_, 
   {{0x442403d1,0x93bc004d,0x7d140108,0x68f80064}},	//   _lhl_, _nhăn, _tyys, _žuda, 
   {{0x6b9004f3,0xded402d3,0x6458007f,0xb8641291}},	// [1e380] ädgå, _ይርአ_, _nwui, بازو, 
   {{0xa8009098,0x6d5d355e,0x44240f85,0x00000000}},	//   взул, _zeqa, _nhl_, --, 
   {{0x3a24026a,0x6d5d355f,0xad9802f0,0xd7c40073}},	//   _омог, _yeqa, moúr, लॉगच, 
   {{0x44253560,0x93bc001e,0x16140e8e,0x91fc00b8}},	//   _ahl_, _chăn, رساڭ, _evāj, 
   {{0x4424e775,0x64580066,0xfbd038db,0xc9840798}},	//   _bhl_, _cwui, _हवाम, _џуџи, 
   {{0x44243677,0xe1ec00aa,0xe3ac33d2,0x741000e5}},	//   _chl_, یسي_, لرى_, کوڈا, 
   {{0x44253561,0x0674defb,0x8e2001ec,0x00000000}},	//   _dhl_, _путя, _сiз_, --, 
   {{0x764c02d0,0x44253562,0x91fc002b,0xb060010b}},	//   _itby, _ehl_, _ivāk, _çäks, 
   {{0x64580b45,0x6d5d3563,0xe6140064,0x3e4400ef}},	//   _gwui, _reqa, _цдт_, _rēta_, 
   {{0x6d5d3564,0x60f402d5,0x3e4400de,0x00000000}},	//   _seqa, ьныя_, _sēta_, --, 
   {{0x6d5c0af5,0x600c7eb1,0xaf04d3a6,0x7d1800ac}},	//   _peqa, rømp, ьчик, ətsi, 
   {{0x7bdd3565,0x6d5c013c,0x00000000,0x00000000}},	//   _alpu, _qeqa, --, --, 
   {{0xa3b0202e,0x61413566,0x6d5d3567,0x20500006}},	//   _जोड_, _реча, _veqa, _акія, 
   {{0x6d5c0472,0x15e40220,0x00000000,0x00000000}},	//   _weqa, _ﻋﻠﻴﻬ, --, --, 
   {{0x6d5d3568,0x91fc0055,0x3e440171,0x00000000}},	//   _teqa, _nvāk, _tēta_, --, 
   {{0xb0d00a28,0x6d5d3569,0x7bdd356a,0x91fc0055}},	//   _तथाग, _ueqa, _elpu, _svāj, 
   {{0x91fc002b,0xf8940107,0x6e9001d5,0x00000000}},	// [1e390] _avāk, нгтӯ, _чиқу, --, 
   {{0x99800784,0x00000000,0x00000000,0x00000000}},	//   rmiš_, --, --, --, 
   {{0xd7c85694,0x4424020b,0x6459356b,0x8a1801c0}},	//   بوله_, _rhl_, _swui, _ноос_, 
   {{0x442401e6,0x15b8010b,0x00000000,0x00000000}},	//   _shl_, дышы_, --, --, 
   {{0x44240113,0xf99006a9,0x68300022,0xe9dc0ca8}},	//   _phl_, _ערך_, _аҭат, _ilú_, 
   {{0x7bdc02c4,0x34b000f2,0x00000000,0x00000000}},	//   _xlpu, اموز, --, --, 
   {{0x93bc001e,0x44240171,0xe9dc08ce,0xae0c2ac3}},	//   _thăn, _vhl_, _klú_, सवान_, 
   {{0x00c843ee,0xa3b0012c,0x5695356c,0x28dc033f}},	//   злик_, टाङ_, _шаст, पैथि, 
   {{0x44240108,0x70500472,0x43940024,0x00000000}},	//   _thl_, هنيا, _паас, --, 
   {{0x312000ee,0xb700008e,0x00000000,0x00000000}},	//   ыдыг, _çäçl, --, --, 
   {{0x415402d5,0x6fd4004a,0xdb1cc9df,0xe9dc0cad}},	//   _звес, _mâch, lkrö, _olú_, 
   {{0xed5410f5,0x6fd45725,0x91fc0055,0xa3b00456}},	//   ною_, _lâch, _nvāh, _जोत_, 
   {{0x522c04ac,0x6ec800ac,0x68f807f5,0x315400df}},	//   _וואַ, ləbl, _žudn, _װיצן_, 
   {{0xfaa5356d,0x6ec803e3,0x00000000,0x00000000}},	//   наго, cəbo, --, --, 
   {{0xd004504c,0x1b040166,0x00000000,0x00000000}},	//   _шошқ, түнн, --, --, 
   {{0xe9dc00c6,0xcdf40022,0xe9a00150,0x00000000}},	//   _clú_, _ачьы, ласп, --, 
   {{0x6cb00724,0x6fd4004a,0x91fc00cd,0x00000000}},	// [1e3a0] _йөрт, _bâch, _svāk, --, 
   {{0x91fc00cd,0xe8f4299f,0xec740166,0x7bdc01f4}},	//   _evāh, хлу_, _япь_, _ulpu, 
   {{0x20008356,0x83fc01d3,0x00000000,0x00000000}},	//   čjih_, _evők, --, --, 
   {{0x7c2c03b2,0xfd540055,0x3e4400de,0x00000000}},	//   lmbr, _pyaṇ, _lēto_, --, 
   {{0x6fd4004a,0x7984035a,0x6601356e,0x00000000}},	//   _fâch, _ickw, énka, --, 
   {{0x6fd4004a,0x7c2c007f,0xe9dc00d0,0x91fc00b8}},	//   _gâch, nmbr, _zlú_, _tvāk, 
   {{0x764c77d4,0x741403e6,0xe3ac4fca,0xf1d00137}},	//   _utby, ووڵا, صرو_, лөдө, 
   {{0x9f440109,0x6b8002d2,0x00000000,0x00000000}},	//   _amnà_, _öngv, --, --, 
   {{0x6f84010b,0x62200145,0x2000022e,0xad980419}},	//   нунж, دىيل, еji_, hnúc, 
   {{0x6ec800ac,0x845400db,0xbf7001ec,0x2128473a}},	//   bəbl, _شىمچ, ақшы, ýcha_, 
   {{0x59e0cead,0x7984035a,0xcdc400d1,0x6ec803e3}},	//   नसार, _ockw, вәпп, cəbl, 
   {{0x7c2d356f,0xab18022c,0x78a40841,0x61400354}},	//   embr, ítíð_, _oskv, _беца, 
   {{0x68f801f1,0x20d017b9,0x00000000,0x00000000}},	//   _ľudo, _متوج, --, --, 
   {{0x7984035a,0x91fc00dc,0x68f800c0,0x99800432}},	//   _ackw, _svāh, _žudo, lniň_, 
   {{0x78a403d4,0xe9dc52e1,0x2b9000f2,0x2bc00bae}},	//   _askv, _plú_, نیکس, शाबा, 
   {{0x7af93570,0x7c2c7ffa,0x19a83cbb,0xad980419}},	//   útta, ambr, нтуп_, snúb, 
   {{0x1d080114,0x481401a9,0x9980010e,0x00000000}},	// [1e3b0] _пећи_, вмас, iniň_, --, 
   {{0x798403ac,0x8b840150,0xcb180073,0x00000000}},	//   _eckw, _جەسە_, _धडपड_, --, 
   {{0x98144030,0x78a401e4,0xe9dc0332,0x93bc0051}},	//   ابقا, _eskv, _tlú_, _chăm, 
   {{0xe9dc0093,0x91fc00b8,0x3864031c,0x00000000}},	//   _ulú_, _uvāh, ġorr_, --, 
   {{0x58d4255b,0x6fd407ea,0xf4846b18,0x7580006c}},	//   _боят, _tâch, ناوی, شیلم, 
   {{0x69cc0b91,0xdb1c9632,0x00000000,0x00000000}},	//   _hoce, rkrö, --, --, 
   {{0xdb1c9632,0x6b8112fe,0xb2701de6,0x00000000}},	//   skrö, _öngu, ңләш, --, 
   {{0x69cd3571,0x16341422,0xe7f8095f,0x998000a2}},	//   _joce, _беся, ्वका_, gniň_, 
   {{0x69cd3572,0xc02801c0,0xd5ac01d3,0x7c2c2bd6}},	//   _moce, мжиж_, _رہو_, ymbr, 
   {{0x69cd3573,0xad980419,0x00000000,0x00000000}},	//   _loce, ynúc, --, --, 
   {{0x69cc009a,0x23653574,0x6e600092,0x998000d7}},	//   _ooce, manj_, _ለተግባ, lmiť_, 
   {{0x69cd3575,0x409484df,0x23653576,0x00000000}},	//   _noce, _аркт, lanj_, --, 
   {{0x7c2d3577,0x8e2c022e,0xdb080241,0x5454010a}},	//   tmbr, rzdа_, _ìlúm, _ывăт, 
   {{0x194800b5,0x23640100,0xad980419,0x00000000}},	//   _ｄｅｎ_, nanj_, tnúc, --, 
   {{0x7c2ce2ee,0xaf74008f,0x4a7400b1,0x00000000}},	//   rmbr, _סעקס_, лытт, --, 
   {{0xfaa4016c,0x236402bd,0xa3b004af,0xad980419}},	//   наҳо, hanj_, _जोस_, rnúc, 
   {{0x69cd3578,0x2364b3d2,0x2ca4010b,0x68413579}},	// [1e3c0] _doce, kanj_, _акып_, инта, 
   {{0xd764598b,0x236409a8,0x8d28010b,0xb8c807f7}},	//   انای, janj_, _яның_, _खन_, 
   {{0xc79471fe,0x23640e3c,0x69cc00bc,0x91fc002b}},	//   ырты, danj_, _foce, _ivāv, 
   {{0xd9100424,0xd61800db,0x00000000,0x00000000}},	//   _هیز_, رعاچ_, --, --, 
   {{0x91fc0055,0xf4c00154,0x00000000,0x00000000}},	//   _kvāv, ্ছ্ব, --, --, 
   {{0x69cc009a,0xa4d000d4,0x00000000,0x00000000}},	//   _zoce, роші, --, --, 
   {{0x69cc014b,0xe294147e,0xe73400c0,0x00000000}},	//   _yoce, вај_, _аер_, --, 
   {{0xdec8069c,0xc32c04a9,0x00000000,0x00000000}},	//   _ኢልካ_, سەن_, --, --, 
   {{0x2365357a,0x3d1005d7,0xe1ed357b,0xf8b00037}},	//   banj_, _धुले_, تسو_, ँटिय, 
   {{0x23640007,0x2348036b,0x00000000,0x00000000}},	//   canj_, _قسمی_, --, --, 
   {{0xe0cc073e,0xdea013de,0x68f80419,0x437000db}},	//   مزی_, لیوی, _ľudm, _چۇۇر, 
   {{0x92e405d1,0x437000db,0x6ec803b9,0x00000000}},	//   ışıl, _نۇۇر, ləbk, --, 
   {{0x84700023,0x00000000,0x00000000,0x00000000}},	//   _ብደሓን_, --, --, --, 
   {{0x69cd357c,0x5c040184,0x3d100073,0xfd600055}},	//   _soce, аяса, _धुळे_, _mevṛ, 
   {{0xcfa40116,0x91fc002b,0xce94299f,0xc04c00f1}},	//   _ашқи, _dvāv, _сайъ, _وږی_, 
   {{0xddc80276,0x1f340375,0x91fc00cd,0x80a400c7}},	//   ălţi, _ברור_, _evāv, _ргәҧ, 
   {{0x69ccefa9,0x23640083,0xda34586a,0x00000000}},	// [1e3d0] _voce, yanj_, реты, --, 
   {{0xd774c9a4,0x69cc014b,0x62840fac,0xfca8010f}},	//   لامع, _woce, _åjog, _טיפּ, 
   {{0x2365357d,0x69cc07c5,0xe5c401c6,0x00000000}},	//   vanj_, _toce, ксдо, --, 
   {{0x69cc16b8,0x23640100,0x842400d1,0x00000000}},	//   _uoce, wanj_, گىتن, --, 
   {{0x151402bf,0x236400f3,0x3e780092,0x6b8002d2}},	//   адця, tanj_, _በደስታ_, _öngs, 
   {{0xa3b04103,0xd5b801e0,0x04880166,0x00000000}},	//   _जोश_, есә_, _җәди_, --, 
   {{0x2365357e,0x00000000,0x00000000,0x00000000}},	//   ranj_, --, --, --, 
   {{0xa3b023ef,0x236401fa,0x00000000,0x00000000}},	//   _जोर_, sanj_, --, --, 
   {{0x2365357f,0x25bc7233,0x7fd40046,0x720001d9}},	//   panj_, _inul_, гіні, صوٝم, 
   {{0xbfc400c9,0x00000000,0x00000000,0x00000000}},	//   убок, --, --, --, 
   {{0x92691918,0x25bd3580,0xdce82ca8,0x682803e3}},	//   _арча_, _knul_, _ımız, müdd, 
   {{0x61400075,0xfddc033f,0x91fc00b8,0x7ed40137}},	//   _ئىشە, मसेफ, _svāv, _ۅزبا, 
   {{0xcfa80101,0x206400f3,0x00000000,0x00000000}},	//   رایم_, _рђев, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfe740064,0x00000000,0x00000000,0x00000000}},	//   _сылю, --, --, --, 
   {{0xdef402d3,0x66000036,0x3f840327,0xf32c0023}},	//   _ዋላኳ_, énkl, lglu_, _ብንብዓ, 
   {{0x91fc00b8,0x3f8403e0,0x5fd400bc,0x00000000}},	// [1e3e0] _ivāt, oglu_, _ढकाल, --, 
   {{0x25bc0262,0x3f840978,0xa3b00dad,0x3dd003cb}},	//   _anul_, nglu_, _जोल_, _hoyw_, 
   {{0x7c3c004b,0x91fc00b8,0xdb240244,0xd4540023}},	//   _iipr, _kvāt, _خودی, _ዝተጋህ, 
   {{0x7c3c0175,0x6b9801a6,0xf508014b,0x00000000}},	//   _hipr, đuge, ннел_, --, 
   {{0x7c3d3581,0xb4b00075,0x00000000,0x00000000}},	//   _kipr, силә, --, --, 
   {{0x7c3c025c,0x3dd00042,0x1ccc0327,0xb6a401d5}},	//   _jipr, _loyw_, ྱྀག_, _йигл, 
   {{0x7c3c01e4,0xe7240a0e,0x24901954,0xd25000db}},	//   _mipr, _борд_, _ማይልስ_, زچا_, 
   {{0x7c3d3582,0x85b40640,0x30a42bb7,0x63800124}},	//   _lipr, _кључ, гров, агәа, 
   {{0x4dcc0729,0x2498001f,0xa0641f5a,0x68f800d7}},	//   াসমূ, _ለፍርድ_, гања_, _ľudk, 
   {{0x91fc00b8,0x7c3c29b3,0x3f840de2,0x6814010e}},	//   _avāt, _nipr, gglu_, _işdä, 
   {{0x8e2001ec,0x2bc005c0,0xb7c00150,0x00000000}},	//   _тiл_, शासा, рлiк, --, 
   {{0x32040117,0xa2d016ac,0xad980332,0x6828002f}},	//   _ujoy_, _ديمت, anún, müde, 
   {{0xb3440209,0x50a8b658,0x682805d5,0x91fc00dc}},	//   _geçý, _कनिष, lüde, _dvāt, 
   {{0x91fc00dc,0xab7400db,0x00000000,0x00000000}},	//   _evāt, دۅدا_, --, --, 
   {{0xda7931bb,0x2008004a,0x682841b5,0x58840124}},	//   лят_, écie_, nüde, ҩыуа, 
   {{0x9fc40022,0xdd900014,0xda780306,0x91fc002b}},	//   _агәа_, _ٹوٝ_, áďa_, _ivās, 
   {{0x5d540598,0x7c3c0005,0x6d4c4c3e,0x893801ec}},	// [1e3f0] _укыт, _fipr, mcca, тпас_, 
   {{0x7c3c2819,0x3164005a,0x91fc00b8,0x68280432}},	//   _gipr, _leoz_, _kvās, küde, 
   {{0x6d4c4d72,0x247002d3,0x0994033a,0x00000000}},	//   occa, _ኣይሁድ_, _канџ, --, 
   {{0xa5650d6c,0x7c3c27f6,0x2bc0ad78,0x44b400ee}},	//   ادان, _zipr, शावा, ибес, 
   {{0x7c3c01e2,0x6e3c0477,0xe8e8007b,0x992802e8}},	//   _yipr, _miqb, _أرجو_, _бюра_, 
   {{0xd7e402bf,0x6b840007,0x7c3d3583,0xa3b8007b}},	//   _лісо, ngjg, _xipr, عاشر_, 
   {{0x6ec800ac,0xc22002e5,0xdc3c010f,0xb34400a2}},	//   bəbi, मतलब_, געגר, _seçý, 
   {{0x25bc0262,0x40948970,0x6e3c0548,0x69dc01e2}},	//   _unul_, арот, _niqb, nkqe, 
   {{0x66193584,0x91fc002b,0x3fe42502,0xc46402f2}},	//   _ikuk, _avās, ижив, _ئیتۆ_, 
   {{0x65693585,0x3f8400f3,0x91fc00dc,0xde400092}},	//   lagh, uglu_, _svāt, _ከተወለ, 
   {{0x7c3d3586,0x63a13587,0x661800ca,0x3e4402b1}},	//   _ripr, menn, _kkuk, _kēti_, 
   {{0x63a13588,0x656802a4,0x7c3d3589,0xee347078}},	//   lenn, nagh, _sipr, инэ_, 
   {{0x6280ca53,0x61f9358a,0x661800ec,0x628408fb}},	//   luno, miul, _mkuk, _åjob, 
   {{0x63a1358b,0x61f9358c,0x7051358d,0x6569358e}},	//   nenn, liul, _بنوا, hagh, 
   {{0x6619358f,0x7c3c0a28,0x62813590,0x65693591}},	//   _okuk, _vipr, nuno, kagh, 
   {{0x66193592,0x7c3c0165,0xdb08066a,0x5ec8015b}},	//   _nkuk, _wipr, _ólík, ানদে, 
  
   {{0x63a13593,0x65693594,0x62813595,0x7c3d3596}},	// [1e400] kenn, dagh, huno, _tipr, 
   {{0x63a13597,0x60d80357,0x61f93598,0x65680731}},	//   jenn, iyum, hiul, eagh, 
   {{0x63a13599,0x22a401ed,0x628016a3,0x61f9359a}},	//   denn, _nők_, juno, kiul, 
   {{0x6281359b,0x61f80451,0x60d9359c,0x6569359d}},	//   duno, jiul, kyum, gagh, 
   {{0x63a09b42,0x61f9359e,0x3164030a,0xdb2401b9}},	//   fenn, diul, _reoz_, _خوگی, 
   {{0x63a1359f,0x66182747,0x60d935a0,0x628135a1}},	//   genn, _ekuk, dyum, funo, 
   {{0x628135a2,0x68f801a2,0x656935a3,0x35a468d9}},	//   guno, _ľudi, bagh, _кавг, 
   {{0x91fc00da,0x61f935a4,0x656935a5,0x68f80024}},	//   _avār, giul, cagh, _žudi, 
   {{0x63a135a6,0xb374034c,0x628135a7,0x6e3c0455}},	//   benn, _نداش, auno, _riqb, 
   {{0x628135a8,0x6e3c758d,0x00000000,0x00000000}},	//   buno, _siqb, --, --, 
   {{0x6d4c07d5,0x628135a9,0xf1a80b28,0x91fc0882}},	//   tcca, cuno, _لاشه_, _dvār, 
   {{0x61f935aa,0x60d80796,0x6d4d35ab,0x91fc00cd}},	//   ciul, byum, ucca, _evār, 
   {{0x6d4d35ac,0x3eb8005f,0x60d80230,0x2bc0f397}},	//   rcca, āsta_, cyum, शाला, 
   {{0x6d4d35ad,0xea5400d1,0xab8400db,0x91fc00b8}},	//   scca, изгә_, шумк, _tvās, 
   {{0x656935ae,0xceb850e5,0x6e3c014f,0x8e84007b}},	//   yagh, _сәп_, _tiqb, _العه, 
   {{0x63a135af,0xd6cc0154,0xa3b0000d,0x9f740092}},	//   zenn, লনায, _जोई_, _በበዓሉ_, 
   {{0x63a135b0,0x656935b1,0x3e44f987,0x628004ce}},	// [1e410] yenn, vagh, _rēti_, zuno, 
   {{0x628135b2,0xfe6c01d9,0x2078008f,0x656935b3}},	//   yuno, _تگی_, כאמא, wagh, 
   {{0x656935b4,0x61f80d04,0x24482d75,0x3e4400b0}},	//   tagh, yiul, _søm_, _pēti_, 
   {{0x63a135b5,0x60d935b6,0x61f80077,0x656800ad}},	//   wenn, yyum, xiul, uagh, 
   {{0x656935b7,0x61f935b8,0x628135b9,0x63a01da7}},	//   ragh, viul, wuno, tenn, 
   {{0x60d81459,0x63a00dd4,0x656935ba,0x3e4400b0}},	//   vyum, uenn, sagh, _wēti_, 
   {{0x63a135bb,0x66180270,0x61f935bc,0xf8a00014}},	//   renn, _tkuk, tiul, _وۅہَ, 
   {{0x66188cdb,0x628135bd,0x91fc0aed,0xd5b8084c}},	//   _ukuk, runo, _svār, _ксу_, 
   {{0x62809b94,0x63a135be,0x61f935bf,0x60d80d04}},	//   suno, penn, riul, uyum, 
   {{0x61f935c0,0x60d935c1,0x63a00548,0x00000000}},	//   siul, ryum, qenn, --, 
   {{0x61f8084c,0x60d804ce,0x6ec803b9,0x00000000}},	//   piul, syum, kəbu, --, 
   {{0x60d80309,0xe0d000f2,0x00000000,0x00000000}},	//   pyum, _وزش_, --, --, 
   {{0x91fc002b,0x00000000,0x00000000,0x00000000}},	//   _ivāp, --, --, --, 
   {{0xd9e010b7,0x8fc400db,0x41c40a5a,0x95f4cc41}},	//   नस्ट, _ۇزۉن, वावस, _अष्ट_, 
   {{0xddc400b0,0x91fc002b,0x00000000,0x00000000}},	//   _hunō, _kvāp, --, --, 
   {{0x394535c2,0x249c0381,0xf2d8010f,0x00000000}},	//   снаг, _opum_, אַמל, --, 
   {{0x249c0218,0xdce40006,0xac9400ec,0xb7e400c7}},	// [1e420] _npum_, _keič, _هنيا_, бжак, 
   {{0x3b841614,0x14c804fb,0x69c803fa,0xf9900214}},	//   _улог, یهای_, öger, _کبد_, 
   {{0xc7643baf,0x249c41ec,0xdce400de,0xc6f400d4}},	//   زالى, _apum_, _meič, оїць, 
   {{0xb6a40b01,0xdce40064,0x00000000,0x00000000}},	//   _қибл, _leič, --, --, 
   {{0xe45c7b4e,0xf1c400e4,0x00000000,0x00000000}},	//   _çöl_, ñámi_, --, --, 
   {{0xb9e0069c,0x741400bd,0x91fc0882,0xb9f00092}},	//   _ከሎ_, াষ্ট_, _avāp, _ነሽ_, 
   {{0x925800f7,0x00000000,0x00000000,0x00000000}},	//   шайт_, --, --, --, 
   {{0xded4067d,0x90545336,0x91fc00b0,0x395001f5}},	//   ኮነን_, овиц, _ewān, ncys_, 
   {{0xa3b06a04,0x682935c3,0x91fc002b,0x39500076}},	//   _जोक_, lüda, _dvāp, icys_, 
   {{0x91fc00cd,0x7e6c012d,0x3e4400de,0x00000000}},	//   _evāp, _łapa, _lētu_, --, 
   {{0xfe6c3df2,0x2008315a,0x1dc40490,0x682935c3}},	//   نگي_, écia_, षांत, nüda, 
   {{0x60600330,0x312400db,0x00000000,0x00000000}},	//   _کهول, _лдег, --, --, 
   {{0x682805d5,0x5ce401a9,0x41c43af4,0xa0a00816}},	//   hüda, пюра, वारस, _нацд, 
   {{0x682805d1,0x00000000,0x00000000,0x00000000}},	//   küda, --, --, --, 
   {{0x9b58084c,0xbacc0183,0x1618012d,0x00000000}},	//   сист_, _ৱেবছ, धकार_, --, 
   {{0x5ed00150,0x2604008f,0x00000000,0x00000000}},	//   _ءتوز, aĵoj_, --, --, 
   {{0x02a40bc0,0xceb80153,0x38700432,0xad9802d2}},	// [1e430] _खन्न, lvę_, gsyr_, hnúk, 
   {{0xe9dc0597,0x6828014a,0x8af800a7,0xd1f00023}},	//   _siúd_, füda, _внос_, _ልዝብ_, 
   {{0xa3b01431,0xc5d400d4,0x00000000,0x00000000}},	//   _जोग_, жіль, --, --, 
   {{0x249c05b1,0x2d8935c4,0xd1dc01f3,0xceb80064}},	//   _ppum_, ngce_, ንቀቅ_, ivę_, 
   {{0x58841a6d,0x00000000,0x00000000,0x00000000}},	//   _ныра, --, --, --, 
   {{0x4254054d,0x6828014a,0x91fc002b,0xc0d40092}},	//   отит, büda, _svāp, _ይልማ_, 
   {{0xb9f0001f,0x74100133,0x8234027d,0xdce425ad}},	//   _ነች_, بووا, يربا, _reič, 
   {{0xceb80024,0xbbd40ebb,0x96f82901,0x00000000}},	//   dvę_, _ठक्क, _уест_, --, 
   {{0xdb1c0fac,0x00000000,0x00000000,0x00000000}},	//   sjrø, --, --, --, 
   {{0x0fe80220,0x00000000,0x00000000,0x00000000}},	//   йлық_, --, --, --, 
   {{0x4154277c,0x660001c7,0x91fc0055,0x00000000}},	//   _двес, énkw, _tvāp, --, 
   {{0x80b01fc4,0x0d640108,0x00000000,0x00000000}},	//   _अनपे, зъём, --, --, 
   {{0x7ff4dd6a,0x387c00e2,0x3e440171,0xceb80064}},	//   _وستا, _ātro_, _rētu_, avę_, 
   {{0xdd0c012d,0x4ea803d4,0xbc1801ec,0x3e4400de}},	//   móżc, _ওপৰল, рімі_, _sētu_, 
   {{0x34a41d8a,0xe7fc37d0,0xe8fc003a,0xba180fb4}},	//   _गन्द, ोचना_, _deûm_, ليسا_, 
   {{0x682805d5,0x00000000,0x00000000,0x00000000}},	//   vüda, --, --, --, 
   {{0x7c640aa0,0x97e81ee3,0x3950007c,0x6ec803b9}},	// [1e440] _باعل, блағ_, rcys_, bəbs, 
   {{0xfc3000c6,0xe9dc01e7,0x38700423,0xbb841b80}},	//   _تحب_, _ciúb_, rsyr_, _بلدي, 
   {{0x387135c5,0xba7535c6,0x690003b9,0x00000000}},	//   ssyr_, _باخت, _ətdə, --, 
   {{0xad98007b,0xc95801b9,0x62ec00eb,0x00000000}},	//   miúc, _гўё_, টপাট_, --, 
   {{0xad980597,0x682935c7,0x00000000,0x00000000}},	//   liúc, süda, --, --, 
   {{0x24040b01,0x00000000,0x00000000,0x00000000}},	//   ончи_, --, --, --, 
   {{0x41c428b8,0xad98007b,0x91c44cf3,0x00000000}},	//   वांस, niúc, зәлл, --, 
   {{0xe6140801,0x3e4400de,0x99800210,0x00000000}},	//   _ддс_, _lēts_, lnił_, --, 
   {{0x99800024,0xdb08032e,0x00000000,0x00000000}},	//   lmių_, _ólæk, --, --, 
   {{0xceb80024,0x2898010f,0x68280139,0x00000000}},	//   tvę_, סייא, hüdn, --, 
   {{0x442803f9,0xceb80131,0x682800e5,0x00000000}},	//   ɓa_, сәл_, küdn, --, 
   {{0x7bd935c8,0xd00801e0,0x00000000,0x00000000}},	//   ötun, реүе_, --, --, 
   {{0xceb80024,0xad9801e7,0x2c1401f9,0x00000000}},	//   svę_, nnúi, णवलं_, --, 
   {{0x6b98098d,0xd01000b2,0x212803fa,0x99800153}},	//   đugo, _ڪلڪ_, üche_, kmių_, 
   {{0x99800210,0xda240055,0x00000000,0x00000000}},	//   dnił_, _ṭhaṃ_, --, --, 
   {{0x6ca535c9,0xec680111,0x99807def,0x08540006}},	//   _дрож, _крок_, enił_, зваю, 
   {{0x68f801f1,0x18b80220,0x2b44009d,0x7f4c0166}},	// [1e450] _ľuds, огты_, _мэнг, _şaqi, 
   {{0x9814fe18,0xcb3400a7,0x00000000,0x00000000}},	//   وبلا, _непъ, --, --, 
   {{0xb8a0001f,0xb8d000bc,0x00000000,0x00000000}},	//   ገልገል_, _झै_, --, --, 
   {{0xe9dc01e7,0xe45c2d9a,0x00000000,0x00000000}},	//   _diúc_, _çök_, --, --, 
   {{0x765c00b5,0x58d40150,0x00000000,0x00000000}},	//   appy, _жоят, --, --, 
   {{0xf8d80375,0x00000000,0x00000000,0x00000000}},	//   _החשמ, --, --, --, 
   {{0x682804cc,0xe610e9d0,0xad9800ae,0xdb9c00df}},	//   lüdo, _قشر_, anúi, יסגר, 
   {{0xdce40421,0x41c407f7,0xe4a400f3,0x00000000}},	//   _leiā, वाइस, _мрзо, --, 
   {{0x65780230,0x200800d8,0xba040240,0x00000000}},	//   _iduh, écio_, _ለዎ_, --, 
   {{0x645935ca,0x78a10db0,0x00000000,0x00000000}},	//   _itui, çovi, --, --, 
   {{0xefc401c0,0x66080208,0x00000000,0x00000000}},	//   члэл_, ongk, --, --, 
   {{0xd1b83dca,0x92b40214,0x7050179e,0x00000000}},	//   _وانا_, _زحما, بنیا, --, 
   {{0x53c000dc,0x6e9001ed,0x66080264,0x7bd8005b}},	//   _षोडश, ولیا, ingk, ötuo, 
   {{0x628000a3,0xad980332,0x765c0108,0x00000000}},	//   orno, tiúc, yppy, --, 
   {{0x645801ab,0xc6e40327,0x7ff400ec,0x00000000}},	//   _ltui, སགསུ, _وسڪا, --, 
   {{0xad980491,0x657885bf,0x682801b8,0x9980012d}},	//   riúc, _nduh, füdo, wnił_, 
   {{0xad98007b,0x6608003e,0xac800022,0x04ec0183}},	// [1e460] siúc, dngk, _згыл, জপুৰ_, 
   {{0x657935cb,0x66080472,0x02bc00dc,0x00000000}},	//   _aduh, engk, ्माभ, --, 
   {{0x645935cc,0xba74263d,0x2bf40375,0x4ce000cc}},	//   _atui, _عادت, _זמין_, _পেপু, 
   {{0xac940583,0x645801ab,0xd1dc0023,0xb8a00b82}},	//   _بنیا_, _btui, ንቀቕ_, ገልግል_, 
   {{0x6578089c,0x62804e06,0x41c407f7,0x23c401ad}},	//   _dduh, erno, वाईस, लांद, 
   {{0x657802e3,0xa5301ed2,0x61e801e4,0x645800c6}},	//   _eduh, хніч, _algl, _dtui, 
   {{0x64a000ee,0x4dfc000d,0x00000000,0x00000000}},	//   _җаха, _लगलै_, --, --, 
   {{0x3a200ac5,0x6828008e,0x00000000,0x00000000}},	//   _jkkp_, hüdl, --, --, 
   {{0x764d35cd,0xe0cc03e6,0x3dd00154,0x00000000}},	//   _huby, ۆزی_, াসাল, --, 
   {{0x764d35ce,0x61e80115,0x7bd935cf,0x998000a2}},	//   _kuby, _elgl, ötul, lniń_, 
   {{0xe0cd35d0,0x00000000,0x00000000,0x00000000}},	//   نزی_, --, --, --, 
   {{0x764d35ce,0x9980030a,0x00000000,0x00000000}},	//   _muby, nniń_, --, --, 
   {{0x764d35d1,0x00000000,0x00000000,0x00000000}},	//   _luby, --, --, --, 
   {{0x764d35d2,0x3a20036e,0xb0300166,0x5f900117}},	//   _ouby, _akkp_, _ямлә, _зишт, 
   {{0x660806a3,0x9f980375,0xad2401d5,0x764d35d3}},	//   yngk, _הסופ, ترگو, _nuby, 
   {{0xdb08010e,0x00000000,0x00000000,0x00000000}},	//   _çoýg, --, --, --, 
   {{0x2c2400d6,0xf8b405f5,0xc7d80354,0x6680036b}},	// [1e470] _ньог, мөр_, омах_, کیزل, 
   {{0xad24021a,0x764d35d4,0x9f440232,0x6578036e}},	//   _ورکو, _buby, _plné_, _sduh, 
   {{0x645935d5,0x6828014a,0xa64400d1,0x00000000}},	//   _stui, südo, سخان, --, 
   {{0x764d35d6,0x660803d2,0x3ea0010e,0x00000000}},	//   _duby, ungk, _ähte_, --, 
   {{0x62800cfd,0xb92002e3,0x00000000,0x00000000}},	//   wrno, _mkpị_, --, --, 
   {{0x62800216,0x00000000,0x00000000,0x00000000}},	//   trno, --, --, --, 
   {{0x764d35d7,0x4e1c0034,0xd684010b,0x6608003e}},	//   _guby, नवाई_, _путп, pngk, 
   {{0x65780230,0xc8d02232,0x80b009bb,0x64580332}},	//   _uduh, _सपाट, _अनदे, _ttui, 
   {{0x64580280,0x00c800d4,0x00000000,0x00000000}},	//   _utui, ілок_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6b8001d3,0x00000000,0x00000000,0x00000000}},	//   _öngy, --, --, --, 
   {{0xed542626,0x39440024,0x67240432,0x00000000}},	//   мою_, žosi_, _myjj, --, 
   {{0x518405f5,0xee34cadc,0x7f4c03b9,0x00000000}},	//   _чуха, ьню_, _şaqu, --, 
   {{0xfaa535d8,0xddc40083,0x92c003d4,0xd138014b}},	//   маго, _kiiŋ, ঁহৰ_, _эхх_, 
   {{0x7980002e,0x00000000,0x00000000,0x00000000}},	//   óowo, --, --, --, 
   {{0x764c0530,0xad9800c6,0x80d0012c,0x00000000}},	//   _ruby, liún, _तपाइ, --, 
   {{0xd3780bb8,0x764d35d9,0x17c400c7,0xa2ac0073}},	// [1e480] _hoće_, _suby, нааҭ, ंबड्, 
   {{0xad98007b,0xba5400a7,0xa7a400c7,0x00000000}},	//   niún, _отмъ, мкуа_, --, 
   {{0x644c0789,0x1adc00cc,0xf65800cf,0x00000000}},	//   _écij, _ডেৰা, زجاش_, --, 
   {{0xad9800c6,0x00000000,0x00000000,0x00000000}},	//   hiún, --, --, --, 
   {{0x776c0218,0x25dc000d,0xc64400db,0xb4b135da}},	//   _tebx, _ककरी_, رئمى, тилә, 
   {{0x764d35db,0x533535dc,0x7c2003b2,0xe41c03b9}},	//   _tuby, нелт, _íord, _ətçə, 
   {{0xe28c00c6,0xf1d000f7,0xad987e9b,0x00000000}},	//   لذي_, көдө, diún, --, 
   {{0xddc400e8,0x6aa00036,0x7d1402f0,0xa6c4010a}},	//   _diiŋ, _änfe, _oxys, _юлса_, 
   {{0x741535dd,0x30bc0f22,0x3ea80cf4,0xad980332}},	//   _قورا, েন্স, _ćata_, fiún, 
   {{0xfe6c07a7,0xad9935de,0x91fc00b0,0x73343b89}},	//   ڭگو_, giún, _otāg, _قرائ, 
   {{0xb8e80003,0xdef40953,0x00000000,0x00000000}},	//   _ྲན_, дыя_, --, --, 
   {{0x0e640228,0x7f4c0724,0xd3780841,0x78a4005c}},	//   мкүн, _şaqt, _doće_, _opkv, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe9dc0332,0x92c003d4,0xad980332,0x6e8800f3}},	//   _ciún_, ঁহী_, ciún, _дљив_, 
   {{0x7d14035a,0xadb40e56,0x78a40064,0x3cec06be}},	//   _exys, _قۇدا_, _apkv, _əfvi_, 
   {{0x2d8c037e,0x00000000,0x00000000,0x00000000}},	//   _øge_, --, --, --, 
   {{0xfcc07400,0x5a440006,0x00000000,0x00000000}},	// [1e490] _йәрм, тэра, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd7c81bf4,0x00000000,0x00000000,0x00000000}},	//   ظومه_, --, --, --, 
   {{0x7e6c012d,0x8a1801c4,0x6d400139,0x862400db}},	//   _łapk, _хомс_, _şnay, رباە, 
   {{0x3eb81991,0x00000000,0x00000000,0x00000000}},	//   āsti_, --, --, --, 
   {{0xa73000c7,0x91fc00b8,0xd8380150,0x00000000}},	//   _адгә, _ivāy, _жэс_, --, 
   {{0x387c005f,0x1fb4015b,0xdbcc01e1,0xf770010f}},	//   _ātri_, জামস, _kòòs, _תקל_, 
   {{0x9e4801f1,0x91fc0055,0x27f8012d,0xc22401e2}},	//   _keďž, _kvāy, żyną_, رکاو, 
   {{0x7bd800c5,0x63b000c7,0x00000000,0x00000000}},	//   ötuk, _иааӡ, --, --, 
   {{0x91fc00b8,0xa2ac1fbc,0xf8b005d0,0x25f82356}},	//   _atād, ंबद्, נשי_, लोरी_, 
   {{0xad980597,0x3c3401bf,0x00000000,0x00000000}},	//   riún, næve_, --, --, 
   {{0x02bd35df,0xad980491,0xd378071b,0x81d800bd}},	//   ्मीन, siún, _voće_, ডোজ_, 
   {{0x442535e0,0xad9935e1,0x3c34005c,0x91fc0055}},	//   _kkl_, miúl, hæve_, _nvāy, 
   {{0x44241e5d,0xad9800c6,0x91fc00cd,0x00000000}},	//   _jkl_, liúl, _etād, --, 
   {{0x4a740598,0xad980008,0xf490001f,0xa3e41bbb}},	//   кытт, gnús, _የውስጥ_, _पवन_, 
   {{0xf2d030fb,0xdec8069c,0xad9800c6,0x442535e2}},	//   נען_, _ኢልና_, niúl, _lkl_, 
   {{0x26c0003e,0xded402d3,0xfce535e3,0x442401f4}},	// [1e4a0] _arjo_, _ክርአ_, _чопо, _okl_, 
   {{0x5fb41d8a,0xc7642dfc,0xad98007b,0x4425137e}},	//   _असफल, نامى, hiúl, _nkl_, 
   {{0x7bdc02e8,0x66e008ca,0x91fc00cd,0xeb9400d9}},	//   _iopu, лофа, _evāy, _אדיר_, 
   {{0x7bdc2bae,0x31c4006a,0x4424022e,0xd9b40a52}},	//   _hopu, _mêzä_, _akl_, _جەرد, 
   {{0x7bdd35e4,0xad9800ae,0x058400d4,0x00000000}},	//   _kopu, diúl, туєм, --, 
   {{0xe3ac5f2e,0x7bdd35e5,0x64c00116,0x00000000}},	//   مرى_, _jopu, ايول, --, 
   {{0x7bdd35e6,0x7bc80241,0x00000000,0x00000000}},	//   _mopu, _òfuu, --, --, 
   {{0xe64135e7,0x7bdc049b,0x442535e8,0xf7706abd}},	//   _бесп, _lopu, _ekl_, _جاڭ_, 
   {{0x9444035b,0x92c000fe,0x00000000,0x00000000}},	//   _амаҵ, ঁহে_, --, --, 
   {{0x442401e4,0x91fc005f,0x7bdd35e9,0x69c800e5}},	//   _gkl_, _stād, _nopu, ögez, 
   {{0xded402d3,0x23740214,0x20d0dd55,0x00000000}},	//   _ክርኢ_, _سمند_, نتیج, --, 
   {{0x7bdc00b0,0xfe6c0131,0xad9800c6,0x239000e5}},	//   _aopu, ڭگۈ_, ciúl, rőjű_, 
   {{0xafe535ea,0x7bdd35eb,0xe9dc0332,0x442401f4}},	//   _подл, _bopu, _diúl_, _ykl_, 
   {{0x7bdd35ec,0x614000f0,0x00000000,0x00000000}},	//   _copu, _сеча, --, --, 
   {{0xdeed35ed,0x09c400bd,0x16bc4ff1,0xa9c46aa8}},	//   _сы_, _একবা, ोमोब, нсак, 
   {{0xf1a413b4,0xfc24001f,0x68280254,0x91fc0055}},	//   _कॉमन, ደረገው, müdi, _utād, 
   {{0x6828014a,0x00000000,0x00000000,0x00000000}},	// [1e4b0] lüdi, --, --, --, 
   {{0x7bdd35ee,0x7e6c012d,0x3c34005c,0xd94401f7}},	//   _gopu, _łapi, tæve_, ائِي, 
   {{0x57a535ef,0x4424023a,0xd7f80395,0x97a4013d}},	//   ышта, _rkl_, хут_, ыртл, 
   {{0x7bdc0161,0x572403cc,0x91fc00b8,0x00000000}},	//   _zopu, دىمك, _tvāy, --, 
   {{0x442535f0,0x7bdd35f1,0xc84400d1,0xded40023}},	//   _pkl_, _yopu, _җеңй, _ክርኤ_, 
   {{0x03a41142,0x4734030d,0x68288021,0x00000000}},	//   тико, _ангс, küdi, --, 
   {{0xad9800c6,0x9f4402fb,0x02bccc41,0x442535f2}},	//   tiúl, _plní_, ्मेन, _vkl_, 
   {{0xa73000c7,0x00c8036b,0x52880131,0xee3c02f0}},	//   _адҳә, длик_, رخىپ_, jmý_, 
   {{0xe2941e51,0x25ac07c5,0xad98007b,0x7f4c0dde}},	//   фақ_, megl_, riúl, _şaqq, 
   {{0xe9dc0597,0x25ac1570,0x682829ef,0xad98007b}},	//   _siúl_, legl_, füdi, siúl, 
   {{0x7bdc9154,0x35c4032c,0x6828be52,0x00000000}},	//   _ropu, _रोड़, güdi, --, 
   {{0x7bdc275e,0x91fc002b,0xfce453ef,0x25ad35f3}},	//   _sopu, _etāb, вомо, negl_, 
   {{0xad980120,0x5dc407d2,0x00000000,0x00000000}},	//   ciúm, _ەمبە, --, --, 
   {{0xafe0656c,0x68280793,0x25ac07de,0xff240c60}},	//   _вошл, büdi, hegl_, _имло, 
   {{0xab248bbe,0x5edc0154,0x00000000,0x00000000}},	//   вора_, _ফেরে, --, --, 
   {{0x7bdc02ce,0x00000000,0x00000000,0x00000000}},	//   _wopu, --, --, --, 
   {{0x7bdd35f4,0x3eb8198e,0xaa4135f5,0x25ac04cc}},	// [1e4c0] _topu, āstu_, ретл, degl_, 
   {{0xdb1d35f6,0x6d5800e4,0x00000000,0x00000000}},	//   ndrë, ñuav, --, --, 
   {{0xc81410f5,0xf98535f7,0x387c00de,0x02bc013a}},	//   уєть, _игно, _ātru_, ्मोन, 
   {{0xb86400aa,0x00000000,0x00000000,0x00000000}},	//   _لاسو, --, --, --, 
   {{0x6b8c006a,0x7c2c017a,0x8e2007d5,0xe8f404b1}},	//   _ângô, olbr, _тiе_, _аля_, 
   {{0xe3ac0372,0x87b935f8,0x68e80158,0x00000000}},	//   ۅرۉ_, _пуст_, øgde, --, 
   {{0xc32c3b5f,0xe3ac6722,0x00000000,0x00000000}},	//   كەك_, زرو_, --, --, 
   {{0x7c2c002f,0x00000000,0x00000000,0x00000000}},	//   hlbr, --, --, --, 
   {{0x5edc015b,0xa07064c2,0x44a41867,0x69d001f9}},	//   _ফেলে, агыч, _محلّ, डाती, 
   {{0x68280254,0x00000000,0x00000000,0x00000000}},	//   tüdi, --, --, --, 
   {{0x290406c8,0xeea8003b,0x00000000,0x00000000}},	//   ̄na_, єток_, --, --, 
   {{0xdb1c0023,0x7c2c017a,0x00000000,0x00000000}},	//   adrë, elbr, --, --, 
   {{0x6fb400c6,0x682829ef,0xc90c0154,0xee3c02f0}},	//   _لمشا, südi, _শর্ত_, rmý_, 
   {{0x7c2c0158,0xce9407d5,0x00000000,0x00000000}},	//   glbr, _бакъ, --, --, 
   {{0x2aa4013f,0xcb0800b2,0xdb1d35f9,0xdee00640}},	//   _bεba_, ريرن_, ndrè, _воји, 
   {{0x996535fa,0x7c2c2dba,0xb0b400cd,0x00000000}},	//   итул, albr, _अनाग, --, 
   {{0xd874282b,0x6d5c031c,0x25ac05d5,0x9954084c}},	// [1e4d0] لالب, _ifqa, vegl_, ркуц, 
   {{0xe7080133,0xd9440063,0xbc440117,0x00000000}},	//   وتان_, ређи, _бӯса_, --, 
   {{0x9a84008e,0x57240d1f,0x25ad35fb,0x00000000}},	//   _куял, لىكك, tegl_, --, 
   {{0x95c801ca,0x7bc80241,0x00000000,0x00000000}},	//   куча_, _òfur, --, --, 
   {{0x69cd35fc,0x25ac07de,0xba280451,0xe4c800be}},	//   _ince, regl_, _سسٽم_, ببان_, 
   {{0x25ac05ac,0xa2ac06e3,0x00000000,0x00000000}},	//   segl_, ंबल्, --, --, 
   {{0xd7640244,0x00000000,0x00000000,0x00000000}},	//   _ئۆمی, --, --, --, 
   {{0xd3789ac0,0x2248002f,0xc6a401a9,0x00000000}},	//   _voća_, öck_, _ирғи, --, 
   {{0x69cc0472,0xd4991a8f,0x7c2c0142,0x04e000fe}},	//   _mnce, _арх_, ylbr, _খেৰৰ_, 
   {{0x6d5c03d9,0xed541b1c,0x22b403e3,0x00000000}},	//   _afqa, ғор_, _ləkə_, --, 
   {{0x69cd35fd,0xdb1c01c7,0xfe4514eb,0x00000000}},	//   _once, rdrë, лноо, --, 
   {{0xdb1c01c7,0x6828002f,0x7c2c0142,0xf2d000df}},	//   sdrë, müdu, wlbr, _לעב_, 
   {{0x6da40032,0x63a00e14,0x00000000,0x00000000}},	//   уҙың_, ofnn, --, --, 
   {{0x69cd35fe,0xfce40032,0xe9dc01d3,0x6d5d35ff}},	//   _ance, _ҡойо, _fiúk_, _efqa, 
   {{0xcf24511e,0x3eb8005f,0x682801b8,0xbea400db}},	//   _پروي, āsts_, nüdu, _сайк, 
   {{0xdb1d3600,0x59641219,0x00000000,0x00000000}},	//   ndré, рнағ, --, --, 
   {{0x1ee40244,0xd88400f2,0x387c00de,0xfd48003b}},	// [1e4e0] _سوکی_, شهای, _ātrs_, _язик_, 
   {{0xdb1c0036,0x99800419,0x00000000,0x00000000}},	//   hdré, dliť_, --, --, 
   {{0x95b400d1,0xc49c0150,0x3e7000d7,0x00000000}},	//   ирдә, _ﺍﻻﺨﺘ_, nšt_, --, 
   {{0x3dd00183,0x00000000,0x00000000,0x00000000}},	//   াসকল, --, --, --, 
   {{0x66e0052f,0x94d405f5,0xf50400f7,0x1404010b}},	//   _һора, ролц, ыздо, аҗаг, 
   {{0x799402d0,0x3e7000c0,0x00000000,0x00000000}},	//   lgyw, kšt_, --, --, 
   {{0xe7353601,0x66e0dfe7,0x5334413d,0xdb1c01c7}},	//   _бер_, _лора, шект, fdré, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7640011f,0xe45d3602,0xf3941291,0x3e700064}},	//   mmoy, _çöp_, _مؤاخ, ešt_, 
   {{0x09e0205d,0xad980597,0x69c000b0,0x160007af}},	//   _नव्य, miúi, ēnei, लोरर_, 
   {{0x8f353603,0xb8d40f50,0xad980597,0xceb8767b}},	//   ренц, _ཚག_, liúi, тәл_, 
   {{0x72341291,0x76400205,0x00000000,0x00000000}},	//   _صراط, nmoy, --, --, 
   {{0xad9800c6,0x61b001d9,0xab8400a7,0xa0640107}},	//   niúi, _دٕنا, лувк, _бача_, 
   {{0x3e7000d7,0x00000000,0x00000000,0x00000000}},	//   bšt_, --, --, --, 
   {{0xad9800c6,0x7640003e,0xee84004e,0x998000d7}},	//   hiúi, kmoy, _сыло, zliť_, 
   {{0x65680327,0x00000000,0x00000000,0x00000000}},	//   xbgh, --, --, --, 
   {{0xb6040e04,0xdd9400cf,0x9da802e8,0x764006be}},	// [1e4f0] _mašć, _اجىع, _съща_, dmoy, 
   {{0xad9800c6,0xd7f93604,0xb60401a6,0x7bd80641}},	//   diúi, лух_, _lašć, ötut, 
   {{0x869801e0,0xbb7408c3,0x00000000,0x00000000}},	//   ткес_, _דעתו_, --, --, 
   {{0x99800030,0x69cd3605,0x7640058a,0x3c349f5c}},	//   tliť_, _unce, gmoy, nævn_, 
   {{0xad980597,0x26c4010f,0x795801e1,0x00000000}},	//   giúi, ŭno_, _wùwó, --, 
   {{0x32053606,0x998000d7,0x53c80150,0x0444011c}},	//   _amoy_, rliť_, лгім_, шелн, 
   {{0xb604107d,0x42d40220,0xdb1c0036,0x998000d0}},	//   _bašć, рілу, tdré, sliť_, 
   {{0x00853607,0x68f80024,0x59d801ad,0x998000d7}},	//   алио, _žudy, डायर, pliť_, 
   {{0xb4b53608,0xad9800c6,0x66093609,0xdb1c04e6}},	//   _китә, ciúi, migk, rdré, 
   {{0x25bd360a,0x6609360b,0x3204003e,0x27e001e4}},	//   _haul_, ligk, _emoy_, _jojn_, 
   {{0x02d842e2,0x91fd360c,0x64409a85,0xbea400c0}},	//   _جواب_, _itān, mmni, шанк, 
   {{0x66082a17,0x6441360d,0xc10465d1,0x00000000}},	//   nigk, lmni, _پوتي, --, 
   {{0x25bd360e,0x200807ea,0x249c025c,0x91fc0055}},	//   _maul_, écis_, _jqum_, _ktān, 
   {{0x6609360f,0x644000c6,0x25bc2771,0x70f8011a}},	//   higk, nmni, _laul_, _בהנח, 
   {{0x64413610,0x66085947,0x20053611,0xbb441064}},	//   imni, kigk, _imni_, ревк, 
   {{0xb864103c,0xf6d43c5b,0x80a80037,0x00000000}},	//   لاطو, یزاد, _कहाइ, --, 
   {{0x660803fa,0x79940c8c,0xd9111b04,0x7c9400db}},	// [1e500] digk, rgyw, سیس_, _ئشبا, 
   {{0x6440068f,0xe8c44545,0x18b404a9,0x68e80162}},	//   jmni, шгул_, _қәбр, øgda, 
   {{0x25bd3612,0x66080e78,0x27e0d32e,0xf6243f07}},	//   _baul_, figk, _dojn_, аджо, 
   {{0xad980597,0x25bd2e54,0x985404d3,0x764002ce}},	//   tiúi, _caul_, _هێرش, umoy, 
   {{0x20053613,0x76413614,0x79800de2,0x00000000}},	//   _omni_, rmoy, óowu, --, 
   {{0xad9800c6,0x76b40014,0x3a300076,0x3744030d}},	//   riúi, _پٍرا, llyp_, _кĕлт, 
   {{0x25bd3615,0x66093616,0xad980597,0xb6040cf4}},	//   _faul_, bigk, siúi, _pašć, 
   {{0x25bc065c,0x64413617,0x20053618,0x91fc00dc}},	//   _gaul_, amni, _amni_, _etān, 
   {{0x5eac045e,0x7c3c037e,0x6b54063f,0x00000000}},	//   টিফে, _ohpr, ụgid, --, 
   {{0x200405b1,0x00000000,0x00000000,0x00000000}},	//   _cmni_, --, --, --, 
   {{0x200866ce,0x00000000,0x00000000,0x00000000}},	//   ècia_, --, --, --, 
   {{0x31080032,0x20052495,0xc0d4001f,0x20080129}},	//   _инеп_, _emni_, _ክልሉ_, écir_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf1a8168d,0x3598001f,0x60600b24,0x9ce40212}},	//   _ساڵه_, ቀሳቀስ_, _بهول, іцял, 
   {{0x70b4206b,0xad980332,0x00000000,0x00000000}},	//   _अनुल, diúv, --, --, 
   {{0x7bd93619,0xddc401e4,0x644001b9,0x3a3000a2}},	//   ötur, _kunŝ, zmni, glyp_, 
   {{0x19583e25,0x6441361a,0x5dc817de,0x00000000}},	// [1e510] рауы_, ymni, _ﺩﯗﻧﻴ, --, 
   {{0x25bd361b,0x6608017a,0x8b840eff,0x66c40063}},	//   _saul_, wigk, _دەسە_, иљеж, 
   {{0x6609361c,0x25bc565d,0x2b440c86,0x984800a7}},	//   tigk, _paul_, _ànc_, рята_, 
   {{0x25bc0ac5,0xb0b401ad,0x91fc0055,0x64400142}},	//   _qaul_, _अनंग, _stān, wmni, 
   {{0x9f402655,0x66080e78,0x588409a5,0x6440022e}},	//   ójú_, rigk, _мыра, tmni, 
   {{0x66080730,0x212c143a,0x25f83b90,0xd37800d1}},	//   sigk, _rygh_, लोजी_, қчә_, 
   {{0x6440411f,0x25bc039a,0x00000000,0x00000000}},	//   rmni, _taul_, --, --, 
   {{0xc0d40201,0x25bc0c86,0x4094189d,0x249c025c}},	//   _ክልል_, _uaul_, брот, _tqum_, 
   {{0x91fd361d,0x661800c7,0xc02801c6,0x44f4026b}},	//   _itāl, _ijuk, лжиж_, _упас, 
   {{0x7c200115,0x91fc00b8,0xa4400133,0xb2a400ec}},	//   _ƭorm, _utān, _بێتو, _ڇڏيم_, 
   {{0x6619361e,0x2bc801bc,0x5eac00eb,0x00000000}},	//   _kjuk, ायना, টিভে, --, 
   {{0x7c3c069c,0xbdf816a0,0x7a380054,0x66180a49}},	//   _shpr, اردا_, kïta, _jjuk, 
   {{0x6619361f,0x61f893e0,0x680c0024,0x66000098}},	//   _mjuk, mhul, _kėdė, énky, 
   {{0x61f93620,0x661800f3,0x6b60311c,0x60d80472}},	//   lhul, _ljuk, зкра, mxum, 
   {{0x6618035b,0x60d91473,0xdd04083c,0x25480153}},	//   _ojuk, lxum, ğrıs, lėlį_, 
   {{0x66193621,0xf2d00a7c,0x00000000,0x00000000}},	//   _njuk, העל_, --, --, 
   {{0x60d8b021,0x25480153,0x00000000,0x00000000}},	// [1e520] nxum, nėlį_, --, --, 
   {{0x1b0405f5,0xdb1d3622,0x60d80077,0x3a302744}},	//   _дүгн, ldrí, ixum, slyp_, 
   {{0xd3783879,0x682800c5,0x37380eed,0xb6a402dd}},	//   _reć_, tüdr, учаю_, сиел, 
   {{0xdb1cb9f0,0x76593623,0x60c80175,0x61f883e4}},	//   ndrí, _étym, _orgm, jhul, 
   {{0x61f93624,0x66188bbb,0xd378041a,0xceb80034}},	//   dhul, _djuk, _peć_, zwę_, 
   {{0xb9f00020,0x661800c7,0x60d8058a,0x2934010f}},	//   _ኑሮ_, _ejuk, dxum, _לאכן_, 
   {{0xd37804b9,0x60c93625,0x66180158,0x680c00c0}},	//   _već_, _argm, _fjuk, _dėdė, 
   {{0x61f93626,0x777c0227,0xe5a074be,0xdbd40248}},	//   ghul, lapx, _ниси, _lúàb, 
   {{0x60d93627,0xf1a81056,0x660001c7,0x2bc8194b}},	//   gxum, ناکه_, ënke, ायमा, 
   {{0xd3093628,0x777c0bc9,0x6e3c011f,0x6ee4007b}},	//   _پښتو_, napx, _shqb, مسجل, 
   {{0xb8e807e4,0x61f82935,0xf1a8082a,0x91c41719}},	//   _ིན_, bhul, _ماشه_, _дәпл, 
   {{0x61f93629,0x60d80009,0x6338008f,0xceb8012d}},	//   chul, bxum, _געבױ, rwę_, 
   {{0x777c094a,0x00000000,0x00000000,0x00000000}},	//   kapx, --, --, --, 
   {{0xe12005f5,0x777c0bc9,0x7bd80108,0x00000000}},	//   _эмчи, japx, ötup, --, 
   {{0xead400fe,0xf07400fb,0xceb80121,0x2bc80118}},	//   সন্ম, _тиһә_, _тәп_, ायबा, 
   {{0x41bc00dc,0x7bc802d2,0x00000000,0x00000000}},	//   ्ययस, _ófun, --, --, 
   {{0x6618143a,0x00000000,0x00000000,0x00000000}},	// [1e530] _rjuk, --, --, --, 
   {{0x661833f3,0xab2800c6,0x67f800e4,0x91fc0055}},	//   _sjuk, _مسجل_, _oîje, _stāl, 
   {{0x91fc0421,0x66180064,0x59c40b4e,0x41bc00cd}},	//   _atām, _pjuk, _लोकर, ्यमस, 
   {{0x680c0024,0xfa54020e,0x00000000,0x00000000}},	//   _sėdė, _گریگ, --, --, 
   {{0x61f81682,0x60d8198f,0x039400e2,0xad9800ae}},	//   vhul, xxum, žīmā_, mhúd, 
   {{0x60c80109,0x66180b21,0xf1a4629c,0x00000000}},	//   _rrgm, _wjuk, क्सन, --, 
   {{0x61f9362a,0x6618319f,0x5694d303,0x91fc00b8}},	//   thul, _tjuk, _нарт, _etām, 
   {{0x60d801c4,0x66188507,0x3ea000a2,0x91fc0055}},	//   txum, _ujuk, _ähti_, _utāl, 
   {{0x61f815fa,0x657800b0,0x41050086,0x2d8c03b9}},	//   rhul, _ieuh, юзив, _ögey_, 
   {{0x41b4168d,0x6579362b,0x60d9362c,0x6458003a}},	//   _ژمار, _heuh, rxum, _iuui, 
   {{0x61f9362d,0x6579362e,0x00000000,0x00000000}},	//   phul, _keuh, --, --, 
   {{0x6459362f,0x61f80117,0x62813630,0xad9801e7}},	//   _kuui, qhul, msno, diús, 
   {{0xc0e41f91,0x777c094a,0x6280a1d6,0x657902b3}},	//   _фолк, yapx, lsno, _meuh, 
   {{0x777c0bc9,0x65793631,0x645800d8,0x3f6801fe}},	//   xapx, _leuh, _muui, _тико_, 
   {{0x62813632,0xad980306,0x8fc4009a,0x1ea400ec}},	//   nsno, tiút, _رزون, _ڦاڙي_, 
   {{0x65793633,0x777c0054,0x6e040150,0x00000000}},	//   _neuh, wapx, _وسيە, --, 
   {{0x3ea400c6,0x777d3634,0x64593635,0xf1b027af}},	// [1e540] ltlt_, tapx, _nuui, וסן_, 
   {{0x657800d8,0x2bc8043e,0x59d80118,0x00000000}},	//   _aeuh, ायणा, डाहर, --, 
   {{0x777c094a,0x65780438,0xc76457d7,0xbb4402e8}},	//   rapx, _beuh, سالى, _фенк, 
   {{0x64593636,0x6280508f,0x777c0054,0xad9800c6}},	//   _buui, dsno, sapx, liúr, 
   {{0x777c0227,0x6578d4d6,0x490001c0,0xdb1c35f5}},	//   papx, _deuh, _зүтг, ldrà, 
   {{0x32649403,0xe3ad3637,0x777c094a,0xc32c0e8e}},	//   отив, نرى_, qapx, گەم_, 
   {{0x2bc80316,0xdb1d3638,0x6280017a,0x00000000}},	//   ायता, ndrà, gsno, --, 
   {{0xc32c04a9,0xd37804b9,0x6578507c,0x00000000}},	//   دەم_, _moći_, _geuh, --, 
   {{0x91fc0418,0xf1a43409,0xe1ec0137,0x00000000}},	//   _utām, क्षन, ئسى_, --, 
   {{0xb4d47db3,0xdef0010c,0x00000000,0x00000000}},	//   िमी_, ልጡን_, --, --, 
   {{0xd3781326,0xfbdc16d1,0x65793639,0xad980332}},	//   _noći_, मानम, _yeuh, diúr, 
   {{0x6458037e,0xf1a44707,0x00000000,0x00000000}},	//   _yuui, क्शन, --, --, 
   {{0x212801c7,0xad980332,0x7e6c013a,0x00000000}},	//   ücht_, fiúr, _čape, --, 
   {{0x91fc00b0,0xad99363a,0x7bc81d1d,0x00000000}},	//   _otāk, tiús, _óful, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd37804b9,0x19581c3e,0x91fc005f,0x7e9801ed}},	//   _doći_, жаты_, _stāj, _انٹر_, 
   {{0x62800204,0x6579363b,0x00000000,0x00000000}},	// [1e550] zsno, _reuh, --, --, 
   {{0x65780c6a,0xfe6c036b,0x6458005b,0x2da00150}},	//   _seuh, _جگی_, _ruui, _ﺃﻋﻠﻰ_, 
   {{0xf40000bd,0x6579363b,0xd7c8129e,0x62800076}},	//   ৎকার_, _peuh, توله_, xsno, 
   {{0x64580869,0x9f440030,0x48c400fd,0x80cc00cd}},	//   _puui, _plnú_, _нәза, तिमे, 
   {{0xd1cc044e,0x80a8033f,0x00000000,0x00000000}},	//   ባዕተ_, _कहें, --, --, 
   {{0xc0d4069c,0xdb1d363c,0xe9dc01e7,0xd91804b4}},	//   _ክፍሊ_, ldrá, _tiús_, _фью_, 
   {{0x6578036e,0xa1a00150,0xdb1c01e7,0xc87806be}},	//   _teuh, _ﺍﻋﺭﻑ_, odrá, _çşb_, 
   {{0x4095363d,0xdb1d363e,0x6458096b,0x00000000}},	//   прот, ndrá, _tuui, --, 
   {{0x62800441,0x2164013e,0x439401c4,0x00000000}},	//   ssno, биқи_, _наас, --, 
   {{0x31047626,0x628049f9,0xa7f8008e,0x5eac00eb}},	//   янып_, psno, _duñg, টিসে, 
   {{0xd3a4010b,0x00000000,0x00000000,0x00000000}},	//   _юртп, --, --, --, 
   {{0xc0d40f16,0x0d64005b,0x3338011a,0x00000000}},	//   _ክፍለ_, дъём, _התעמ, --, 
   {{0x9f440200,0xad9806ea,0x00000000,0x00000000}},	//   _konë_, tiúr, --, --, 
   {{0x9f4402d3,0xd37807f5,0xbc1802dd,0x35980023}},	//   _jonë_, _poći_, сімі_, ቀሳቐስ_, 
   {{0xd1cc0023,0x00000000,0x00000000,0x00000000}},	//   ባዕቲ_, --, --, --, 
   {{0x7864206e,0xdb1d363f,0xad9801e7,0x00000000}},	//   зказ, rdrà, siúr, --, 
   {{0x3e6001fb,0xc0d400b7,0xb344013d,0x09c40154}},	// [1e560] _hót_, _ክፍሉ_, _kiçü, _একখা, 
   {{0x2d840325,0xad980af2,0x45280327,0x9980031c}},	//   _ēnei_, chúb, _སྙེར_, lliż_, 
   {{0x41bd3640,0x7c2d3641,0x3e6001d3,0xbb4801d5}},	//   ्यास, mobr, _jót_, _دلدن_, 
   {{0x7c2d3642,0x3e600321,0xad9801e7,0x15b41c3e}},	//   lobr, _mót_, mhúc, بەرس, 
   {{0xb4d4cdf8,0x3e60001e,0x2d84013b,0xe9dc0332}},	//   िमे_, _lót_, _ɛne_, _tiúr_, 
   {{0x7c2d3643,0x3754168d,0x38a400d7,0x00000000}},	//   nobr, _رپرس, môr_, --, 
   {{0xc32c2dfc,0xa2b001ed,0x3e600162,0x9f44036e}},	//   لەك_, ٹینڈ, _nót_, _donë_, 
   {{0x7c2c020c,0xba000023,0x998000c0,0x00000000}},	//   hobr, _ፍን_, mlių_, --, 
   {{0x7c2d3644,0xb3440432,0x5388035b,0x00000000}},	//   kobr, _biçü, _мааҭ_, --, 
   {{0xe9dc0016,0x3e6076ad,0x99800024,0xdb1c00bc}},	//   _khúc_, _bót_, olių_, zdrá, 
   {{0xc0cc069c,0x3e600208,0x38a40142,0x00000000}},	//   ባህለ_, _cót_, hôr_, --, 
   {{0x99813645,0x9f4402d3,0x38a53646,0x3e6008a5}},	//   gliż_, _zonë_, kôr_, _dót_, 
   {{0xc0d40201,0x7c2c0005,0xdb1d3647,0x9f4402e2}},	//   _ክፍል_, fobr, ndræ, _lonè_, 
   {{0xf1d81fe5,0x7c2c0b91,0x998002d5,0x3e60438d}},	//   भावन, gobr, klių_, _fót_, 
   {{0x91fc03a0,0x3e6001fb,0xf15003e6,0xe9dc0208}},	//   _atāi, _gót_, _تێکد, _nhúc_, 
   {{0xa7f93648,0xc0cc02d3,0x38a4143a,0xdb1c01bf}},	//   _muñe, ባህሉ_, fôr_, kdræ, 
   {{0xd378098d,0x7c2d3649,0x00000000,0x00000000}},	// [1e570] _hoću_, bobr, --, --, 
   {{0x7c2c35f5,0xd87531f7,0x9f4402bd,0xd1d002d3}},	//   cobr, عاقب, _bonè_, _እዮብ_, 
   {{0xe9dc0016,0xa7f804d4,0x3e6001fb,0xdb1c0d12}},	//   _chúc_, _nuñe, _xót_, pdrá, 
   {{0xe9dc07ae,0x23140228,0x9f4402d3,0x91fc00b8}},	//   _giúp_, үндө_, _sonë_, _utāh, 
   {{0x99800153,0x00000000,0x00000000,0x00000000}},	//   alių_, --, --, --, 
   {{0x09c4015b,0x99800153,0xf8d8011a,0x00000000}},	//   _একটা, blių_, _וחשמ, --, 
   {{0xd3780989,0x9f4402d3,0x00000000,0x00000000}},	//   _noću_, _vonë_, --, --, 
   {{0x7c2c0419,0x3e61364a,0xe570da67,0x3c340162}},	//   zobr, _rót_, _سطر_, rævi_, 
   {{0x9f44044e,0x3e61364b,0xa7f8013d,0x00000000}},	//   _tonë_, _sót_, _tuñd, --, 
   {{0x3e61364c,0xd7e001f9,0x00000000,0x00000000}},	//   _pót_, नायच, --, --, 
   {{0x7c2c04a7,0x9f440129,0x91dc00fe,0x00000000}},	//   vobr, _koné_, _বতৰ্, --, 
   {{0x7c2c040c,0xdce40327,0x3e600741,0x80cc194b}},	//   wobr, _ufiċ, _vót_, तिदे, 
   {{0x9f4445a7,0x61e800a3,0x7e6002d0,0x26f800fe}},	//   _moné_, _iogl, sqlp, ্থটো_, 
   {{0x41bc06ff,0xad9800c6,0x26c00010,0x3e61364c}},	//   ्यवस, thúc, _osjo_, _tót_, 
   {{0xfe088958,0x61e801bf,0x3d0c098b,0xef0c00f1}},	//   _وقتي_, _kogl, _ढेरे_, _پټي_, 
   {{0x7c2d364d,0x61e9364e,0xc8c806ab,0xaa400209}},	//   sobr, _jogl, रिंट, весл, 
   {{0x61e9364f,0x7c2d3650,0xfc307a39,0x00000000}},	// [1e580] _mogl, pobr, _لحد_, --, 
   {{0xe9dc0016,0x61e80115,0x35c4033f,0xe0c43c5a}},	//   _phúc_, _logl, _रोज़, _یز_, 
   {{0x998002d5,0x61e93651,0x9f453652,0xb4d40882}},	//   ulių_, _oogl, _boné_, िम्_, 
   {{0x61e8105c,0x99800153,0x00000000,0x00000000}},	//   _nogl, rlių_, --, --, 
   {{0x9f4400e8,0x99800024,0x7af8143a,0x00000000}},	//   _doné_, slių_, øttf, --, 
   {{0xe9dc0016,0x92593653,0xa7f83eba,0xb7d93654}},	//   _thúc_, пакт_, _puñe, _بوسا_, 
   {{0xe73413d7,0x3a2005be,0x75dc0356,0xf1d8033f}},	//   _жер_, _kjkp_, _căzâ, भालन, 
   {{0x61e88295,0x75d4009a,0x00000000,0x00000000}},	//   _cogl, _تيرا, --, --, 
   {{0x61e93655,0x92c002f5,0x3d0c000d,0xe1e400f1}},	//   _dogl, ুহে_, _ढेले_, بډلو_, 
   {{0x61e802d0,0x38700076,0xa44001af,0xf2d80244}},	//   _eogl, ipyr_, _ануд, _وباش_, 
   {{0x61e93656,0x6e2c0198,0xdb1d3657,0x9f440de2}},	//   _fogl, tocb, ndrä, _yoné_, 
   {{0x7214374c,0x61e80cfd,0x4c953658,0xd37808a4}},	//   _غذائ, _gogl, нимс, _voću_, 
   {{0x2bc85d9c,0xcf9001d9,0xc0c80023,0x2bb8007b}},	//   ायला, _یژھ_, ኽባር_, ياسة_, 
   {{0xa7f800cd,0x00000000,0x00000000,0x00000000}},	//   _muñc, --, --, --, 
   {{0x61e93659,0xc0480208,0xdb1c007c,0x00000000}},	//   _yogl, _lườn_, jdrä, --, 
   {{0x48c400fd,0x91fc00dc,0xdb1c0267,0x00000000}},	//   нәга, _etāv, ddrä, --, 
   {{0xda3430cb,0xe9dc0016,0x00000000,0x00000000}},	// [1e590] теты, _chúa_, --, --, 
   {{0xd7c80345,0xdb1c002f,0x00000000,0x00000000}},	//   ووقه_, fdrä, --, --, 
   {{0x2ca80066,0xca3006ba,0x03f8009e,0x66000200}},	//   ltcd_, ﺭﻩﺕ_, ্চমী_, ënko, 
   {{0xdb1c145e,0xde580023,0x26c000ef,0x00000000}},	//   kerê, _ከደናግ, _vsjo_, --, 
   {{0x61e9365a,0x2ca80066,0x00000000,0x00000000}},	//   _rogl, ntcd_, --, --, 
   {{0x61e9365b,0x9f440de2,0x7dd40139,0xdb1c0166}},	//   _sogl, _woné_, _küsä, bdrä, 
   {{0x4255365c,0x00000000,0x00000000,0x00000000}},	//   нтит, --, --, --, 
   {{0xdb1c03b7,0x75dc0311,0x543401d5,0xe7f400bc}},	//   ferê, _văzâ, _یرلر, ंघका_, 
   {{0x61e9365d,0xdb1c002d,0x00000000,0x00000000}},	//   _vogl, gerê, --, --, 
   {{0xb1400220,0xbb5800b5,0xca3006ba,0xdb1c4cab}},	//   ыныл, _orgは_, ﺭﺩﺍ_, ldrå, 
   {{0x61e9365e,0x91fc0618,0xef1400a8,0xfbdc1bd6}},	//   _togl, _atāu, емэ_, मासम, 
   {{0x91fc00da,0xdb1c01bf,0x00000000,0x00000000}},	//   _stāv, ndrå, --, --, 
   {{0x7d040165,0xfff80166,0xfb1400ec,0x00000000}},	//   uzks, _нэкъ_, ڱورج, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4fc00075,0x3f85365f,0xdce40327,0xdb1c036e}},	//   _ئەپە, malu_, _ddiġ, merë, 
   {{0x3f8415a5,0x7dd40139,0xdb1c0240,0x6e90009b}},	//   lalu_, _düsä, lerë, _сићу, 
   {{0x7a380227,0xa3cc00dc,0x00000000,0x00000000}},	// [1e5a0] nïti, षया_, --, --, 
   {{0xdb1d3660,0xdbd400d7,0xaa400137,0x00000000}},	//   nerë, _lúúb, _ەچكى, --, 
   {{0xc04801fb,0x7af808fb,0x3f853661,0x6b78011a}},	//   _sườn_, øttd, ialu_, _מרינ, 
   {{0x3f853662,0xb63400db,0xdb1d3663,0x6f040129}},	//   halu_, رعات, rdrä, _hébé, 
   {{0x3f853664,0xc9540953,0xad9800d2,0xb4e80882}},	//   kalu_, _атры, khún, महे_, 
   {{0xf2c4765f,0x3f8405a1,0xc0480016,0xdb1cb7c6}},	//   есин, jalu_, _vườn_, jerë, 
   {{0x3f853665,0x9f440232,0x6f0506f7,0xdb1c0023}},	//   dalu_, _plný_, _mébé, derë, 
   {{0xdb1d3666,0x6f043847,0xf1a81ec7,0x38600010}},	//   terê, _lébé, سابه_, _kukr_, 
   {{0xc8c82cd1,0x3f853667,0x80cc00dc,0xdb1c0240}},	//   रिएट, falu_, तिषे, ferë, 
   {{0xa7f80588,0x91fc00b8,0xe9dc004d,0xdb1c94f5}},	//   _kuña, _atāt, _nhún_, gerë, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe9dc01e1,0x3f840194,0xa7f81bce,0x00000000}},	//   _ahún_, aalu_, _muña, --, 
   {{0x3f853668,0x6f053669,0x61d408a8,0xdb1c02e2}},	//   balu_, _bébé, _רודף_, lerè, 
   {{0x3f85366a,0xdb1c0023,0x80cc00dc,0xad980332}},	//   calu_, cerë, तिरे, chún, 
   {{0xe9dc00c6,0xdb1c56ec,0x2ca80066,0xeacc0154}},	//   _dhún_, nerè, stcd_, রহ্ম, 
   {{0xdb54010b,0x2c00009d,0x00000000,0x00000000}},	//   увсы, түүм, --, --, 
   {{0x08400248,0x6d5c209c,0xa7f8005a,0xdb1c00cf}},	// [1e5b0] _adìẹ_, _igqa, _auña, herè, 
   {{0xc5f8a71d,0xdb1c007f,0xb4e800dc,0x7dd40166}},	//   ंस्य_, kerè, महै_, _tüsä, 
   {{0xa7f82b76,0xf42400eb,0x00000000,0x00000000}},	//   _cuña, যতার_, --, --, 
   {{0x7af814f5,0x44f41d37,0xdb240798,0x00000000}},	//   øtte, кпес, _éráp, --, 
   {{0x3f85366b,0x6d5c009a,0xdb1d366c,0x00000000}},	//   yalu_, _mgqa, rdrå, --, 
   {{0xdb1d366d,0x3f841bce,0x9474015e,0xd83801c6}},	//   ferè, xalu_, ادنا, _зэс_, 
   {{0x3f85366e,0x6d5c0921,0xdecc02d3,0xdb1c004e}},	//   valu_, _ogqa, ባብን_, gerè, 
   {{0xe4e400d6,0x6d5c2d2f,0xd17400ee,0x41b400d8}},	//   _пізн, _ngqa, лыьы, тскт, 
   {{0xdb1c0023,0xa7f80113,0xad98007b,0x75a40022}},	//   terë, _zuña, thún, _шырҧ, 
   {{0x6d5c209c,0xe8fc0b21,0xdb1c067c,0x5fd84eae}},	//   _agqa, _afûk_, berè, बाइल, 
   {{0x3f85366f,0xd1e40020,0x4424090c,0xd4040116}},	//   ralu_, _ዜጎች_, _ijl_, _сяти, 
   {{0x3f853670,0x6f0400e8,0xc114399f,0xdb1c036e}},	//   salu_, _sébé, _имеј, serë, 
   {{0x3f853671,0x61f8055a,0x4a74774d,0xf65000c8}},	//   palu_, mkul, ғыст, יצט_, 
   {{0x6d5c0921,0x63a0020b,0x3f853672,0xdb1c04e6}},	//   _egqa, ngnn, qalu_, leré, 
   {{0x91fc02b1,0x9f440122,0x442401e4,0x38613673}},	//   _itār, _koní_, _mjl_, _sukr_, 
   {{0x61f93674,0x4424090c,0xf2d0008f,0x00000000}},	//   nkul, _ljl_, סען_, --, 
   {{0xf770282b,0xfc0400c7,0xa7f850d4,0x442400f3}},	// [1e5c0] لاا_, _аппо, _suña, _ojl_, 
   {{0xa7f93675,0x4424004b,0x61f8c2f8,0xdb1c00c7}},	//   _puña, _njl_, hkul, heré, 
   {{0x7bdd3676,0x61f93677,0xb6a4506f,0xa7f80113}},	//   _inpu, kkul, тиел, _quña, 
   {{0xc1bc12eb,0xd1e436d7,0x7e6cf232,0x44240ac5}},	//   ्योग, ምታት_, _čapl, _ajl_, 
   {{0xe5a13678,0xdb1c04e6,0xad9800ae,0x00000000}},	//   ричи, deré, dhúl, --, 
   {{0xdb1d3679,0x7bcc3c68,0xa7f9367a,0x61f9367b}},	//   terè, ndbu, _tuña, ekul, 
   {{0xdb1d367c,0x7d0800ac,0x12e00eac,0x44240356}},	//   feré, _əfsa, বন্দ, _djl_, 
   {{0x61f8286b,0x7a380054,0x91fc00b8,0xdb1c01c7}},	//   gkul, rïtw, _atār, geré, 
   {{0x91fc00da,0xe5740798,0x00000000,0x00000000}},	//   _stās, _јзу_, --, --, 
   {{0x61f9367d,0xdb1c24bc,0x845400db,0xc0b400ec}},	//   akul, perè, _مىقچ, اجيڪ, 
   {{0xb8ec031c,0x65840267,0x7bcc03cd,0xe3f400db}},	//   _ྱར_, _örhä, ddbu, _جىلت_, 
   {{0x7bdc01c4,0xdb1c0789,0xe9dc007b,0x2cbc00d8}},	//   _anpu, ceré, _chúl_, çudo_, 
   {{0x21640021,0xfbdc01f9,0x00000000,0x00000000}},	//   _ричи_, मांम, --, --, 
   {{0xdfcc77a7,0x6d5c0334,0x61401789,0x00000000}},	//   _وين_, _wgqa, _теча, --, 
   {{0xdec5367e,0xdeed367f,0x4fc42071,0x6b8400f3}},	//   _ауыл_, _ты_, _асқа, rajg, 
   {{0x7bdc4250,0x6d5c01b3,0x4fc000d1,0x00000000}},	//   _enpu, _ugqa, _ئەھە, --, 
   {{0xf8b40228,0xad242d4b,0xec6801a9,0x00000000}},	// [1e5d0] лөр_, _جرثو, _ўрик_, --, 
   {{0x61f93680,0xdb1c01d3,0x0134010f,0x00000000}},	//   zkul, zeré, אָעט_, --, 
   {{0x61f93681,0xd83802d5,0x8574329b,0x45d40153}},	//   ykul, тэт_, глех, ложс, 
   {{0xfad40375,0x2570abb5,0x2bc807b6,0x442400d7}},	//   _עורך_, рқас, ायका, _sjl_, 
   {{0xe9dc110e,0x5884652e,0xdb1c01ed,0x94a80014}},	//   _inú_, _выса, veré, ناوِ_, 
   {{0xee3c02fb,0x00000000,0x00000000,0x00000000}},	//   hlý_, --, --, --, 
   {{0xdb1c524a,0x61f93682,0xad9800c6,0xc2e8015b}},	//   teré, tkul, thúl, _কেজি_, 
   {{0xf1d84802,0x61f93683,0x00c81586,0xd5b81c56}},	//   भागन, ukul, елик_, _ису_, 
   {{0xb4b46b62,0xee3c0216,0xe9dc0208,0x9f440118}},	//   _йитә, dlý_, _nhúm_, _voní_, 
   {{0xfce40107,0xdb1c2f5e,0xe9dc0332,0x300001c4}},	//   ҳомо, seré, _shúl_, йзыг, 
   {{0x6d400115,0xc2740798,0x00000000,0x00000000}},	//   _ŝnap, _слеј, --, --, 
   {{0x91fc0374,0xfce40ff1,0xe9dc01e1,0xd1b801f7}},	//   _huān, гомо, _nnú_, _لاها_, 
   {{0xa7f8568e,0x11080be2,0xed540212,0xdb1c353e}},	//   _ruñn, _لغوي_, лою_, ldrø, 
   {{0xfaa53684,0x7bcd3685,0x1ee40344,0xafe0010b}},	//   лаго, udbu, _لوتی_, _гошл, 
   {{0x7bcd3686,0xab253687,0x91fc0421,0xdb1c1600}},	//   rdbu, гора_, _muān, ndrø, 
   {{0xad980162,0x00000000,0x00000000,0x00000000}},	//   vkúg, --, --, --, 
   {{0x39440124,0xaa400032,0x00000000,0x00000000}},	// [1e5e0] унаг, сетл, --, --, 
   {{0x9f440004,0xe9dc01e1,0x7bdc72c6,0x00000000}},	//   _gonã_, _enú_, _unpu, --, 
   {{0x09b80154,0x00000000,0x00000000,0x00000000}},	//   ঁয়া, --, --, --, 
   {{0xb8c80183,0xf484109a,0xad9820d2,0x00000000}},	//   _খন_, гукн, rkúg, --, 
   {{0x9f4401e1,0xa3cc00dc,0xe8f40d1d,0x00000000}},	//   _lonà_, षयं_, _бля_, --, 
   {{0x79840373,0x91fc0055,0xbec01bce,0x37440354}},	//   _hekw, _atāp, _ñëwa, _йĕлт, 
   {{0x79853688,0xdb1c08cb,0xe3ad3689,0xa80001d5}},	//   _kekw, gdrø, سرو_, _узрл, 
   {{0x7985368a,0x30e852c0,0x75d425a7,0xe73409a5}},	//   _jekw, ефон_, _حيرا, _сес_, 
   {{0x79843e57,0x00000000,0x00000000,0x00000000}},	//   _mekw, --, --, --, 
   {{0x7985368b,0xdb1c0bc9,0x667000db,0x67d800e2}},	//   _lekw, jerï, _ئگەر, _gājē, 
   {{0xe295368c,0xee3c0419,0x00000000,0x00000000}},	//   _бах_, tlý_, --, --, 
   {{0x7985368d,0x9f4400db,0x0e640145,0x21640063}},	//   _nekw, _donà_, лкүн, _бици_, 
   {{0x9f000ed8,0x00000000,0x00000000,0x00000000}},	//   لویو, --, --, --, 
   {{0x5eac015b,0xee3c02fb,0xe9dc02d2,0xdb1c00e4}},	//   টিজে, slý_, _snú_, rerî, 
   {{0x3dc0009a,0xee3c02fb,0xe0c00ca8,0xdee000f3}},	//   bekw_, plý_, _kò̟ò, _гоји, 
   {{0x4975368e,0x7af9368f,0xa7f81891,0x09741e76}},	//   рлас, øtta, _puño, ргаю, 
   {{0x48153690,0x79853691,0x2d893692,0xd7e00490}},	// [1e5f0] амас, _dekw, mace_, नांच, 
   {{0x2d893693,0xad9800d2,0xb4e800fe,0x7984127b}},	//   lace_, khúk, কনাথ_, _eekw, 
   {{0x9f453694,0x91fc02b5,0x7e6c013a,0xe9dc0051}},	//   _koná_, _ruān, _čapk, _tnú_, 
   {{0x79841af3,0x6a200014,0x2d893695,0x00000000}},	//   _gekw, _اہرم, nace_, --, 
   {{0x56945540,0x69cd3696,0xb5c00212,0x758001b9}},	//   _қатт, _iace, ійшл, زیلم, 
   {{0x69cd12fc,0x7984014b,0x00000000,0x00000000}},	//   _hace, _zekw, --, --, 
   {{0x69cd3697,0x2d893698,0x79853699,0x3dc0009a}},	//   _kace, kace_, _yekw, yekw_, 
   {{0x69cd369a,0xdb1d369b,0xc2441677,0x01640261}},	//   _jace, derì, јник, шкио, 
   {{0xe3b40efb,0x2d89369c,0x69cc62bc,0xdb1c0b1a}},	//   _бұл_, dace_, _mace, sdrø, 
   {{0x69cd369d,0xf07401ed,0xdd4000a2,0x7fd80798}},	//   _lace, جیوں_, _aňşa, тфит_, 
   {{0x69cc9f4e,0x23240064,0x00000000,0x00000000}},	//   _oace, _сфаг, --, --, 
   {{0x69cd369e,0x2d89369f,0x91fc00b8,0xd17536a0}},	//   _nace, gace_, _utāp, _лышы, 
   {{0x798536a1,0xede401e0,0xdb1c0142,0x00000000}},	//   _rekw, рһыҙ_, terï, --, 
   {{0x798536a2,0x69cd36a3,0xbc180220,0x00000000}},	//   _sekw, _aace, тімі_, --, 
   {{0x3ea40228,0xbea536a4,0x3df40241,0x80ccb1e3}},	//   _тийг, _тайк, _ẹyẹ_, तिके, 
   {{0x69cd36a5,0xfaa4016c,0xed1401d3,0xbc640798}},	//   _cace, лаҳо, اہیں_, _квик, 
   {{0xe8f536a6,0xdb1d342d,0x7784cb2b,0x69cd36a7}},	// [1e600] алт_, merí, илаз, _dace, 
   {{0xdb1c26c8,0x798536a8,0x69cc0857,0xb8ec033f}},	//   lerí, _wekw, _eace, _शन_, 
   {{0x69cd36a9,0x798536aa,0x3b080abe,0x36c40228}},	//   _face, _tekw, _рено_, рбег, 
   {{0xdb1c26ce,0x69cd36ab,0x5fd40490,0x6cd00214}},	//   nerí, _gace, _भोसल, _اقیا, 
   {{0x8cd81d15,0xa7f8002b,0x91fc0171,0x2bc801f9}},	//   मियो, _muñj, _duāl, ायचा, 
   {{0x2d880316,0x69cc0b3d,0xdb1d36ac,0xf77057d4}},	//   zace_, _zace, herí, _گاڭ_, 
   {{0x91fc0421,0xdb1d36ad,0x69cd36ae,0x2d8802a8}},	//   _fuāl, lerâ, _yace, yace_, 
   {{0x2d8936af,0xdb1d0983,0x69cc1709,0xc32c3ee0}},	//   xace_, jerí, _xace, رەن_, 
   {{0xdb1d36b0,0x2d8936b1,0x76400162,0x00000000}},	//   derí, vace_, mloy, --, 
   {{0x25085311,0x2d8936b2,0x764136b3,0xdb1c026c}},	//   _شرقی_, wace_, lloy, terì, 
   {{0xdb1d36b4,0x232536b5,0x2d88012c,0x643000db}},	//   ferí, _кофи_, tace_, _بىلئ, 
   {{0xd00801e0,0xdb1d36b6,0x00000000,0x00000000}},	//   теүе_, gerí, --, --, 
   {{0x69ccd2e5,0x614018ec,0x2d8936b7,0x3204022e}},	//   _race, _деца, race_, _iloy_, 
   {{0x69cd36b8,0x2d8936b9,0x764001af,0xdb1c054e}},	//   _sace, sace_, hloy, derâ, 
   {{0x2d8936ba,0xdb1c1280,0x7e6400c7,0x764003b2}},	//   pace_, berí, _лхыҵ, kloy, 
   {{0xdb1d36bb,0x69cc208d,0x9f44003a,0xa7f80055}},	//   cerí, _qace, _bonæ_, _guñj, 
   {{0x69cd36bc,0xdb1c0356,0x76400174,0x7e6c0419}},	// [1e610] _vace, gerâ, dloy, _čapi, 
   {{0x69cd36bd,0xa7f80139,0xad9800ae,0x00000000}},	//   _wace, _tuñm, dhúi, --, 
   {{0x69cd36be,0xed300014,0x5d840150,0x3204022e}},	//   _tace, _دوکھ, _الۋل, _oloy_, 
   {{0xdb1c025a,0xd6d936bf,0xb7c400da,0x69cc003a}},	//   berâ, шту_, _apģē, _uace, 
   {{0x81d42f8b,0xdb1c00d8,0xd94400f0,0x95c8117e}},	//   _সকল_, cerâ, _меџи, руха_, 
   {{0x32052411,0xd7f81d0f,0xd5b80116,0x00000000}},	//   _aloy_, _кус_, гсә_, --, 
   {{0x56946f34,0xdb1d36c0,0x764136c1,0x45d40a5b}},	//   _март, yerí, bloy, _ловс, 
   {{0x1635068d,0x0084b358,0x32040076,0xdb1c056a}},	//   _деся, блио, _cloy_, xerí, 
   {{0xad98007b,0xdb1c3873,0x7fd402dd,0xe9dc2877}},	//   chúi, verí, біні, _chúi_, 
   {{0xc0042c68,0x00000000,0x00000000,0x00000000}},	//   спок, --, --, --, 
   {{0x44f839db,0xdb1c26c8,0x6440022e,0xa7f8002b}},	//   _অধিক_, terí, mlni, _puñj, 
   {{0x644136c2,0xa3cc0490,0x11d536c3,0xdb1c0022}},	//   llni, षयक_, _وتند, herã, 
   {{0xdb1c2d7b,0xe7c4258d,0x70500b28,0x923000f7}},	//   rerí, रजाप, تنیا, _تۉيش, 
   {{0xdb1d36c4,0x92640220,0x7af80fac,0x7f84007b}},	//   serí, _ادەم, øtto, _الثن, 
   {{0xdb1c0261,0x200410f2,0xe0cc0050,0x644001ab}},	//   derã, _ilni_, _رٲژ_, ilni, 
   {{0x3ea536c5,0x84f80073,0xdb1c0022,0x6440022e}},	//   mult_, ्नाट_, eerã, hlni, 
   {{0xdb1c0112,0xac80008e,0x7c9536c6,0x644001a9}},	// [1e620] ldrü, _егыл, _اشبا, klni, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3ea4033d,0x9f44004e,0xdb1c03fa,0x6440e54f}},	//   nult_, _donç_, ndrü, dlni, 
   {{0xad980597,0xdb1d36c7,0x35a4035b,0x644136c8}},	//   thúi, merà, садг, elni, 
   {{0xdb1d36c9,0x7640e5ef,0x3ea426bc,0x64a136ca}},	//   berã, rloy, hult_, зача, 
   {{0x3ea536cb,0xdb1c0120,0x76404cb7,0x04640150}},	//   kult_, cerã, sloy, ітім, 
   {{0xd2500502,0x32041caa,0x3ea52fe0,0x764136cc}},	//   ونت_, _ploy_, jult_, ploy, 
   {{0x644136cd,0x909802f6,0x3ea401ed,0x00000000}},	//   alni, авит_, dult_, --, 
   {{0x621400dc,0xa06400ea,0x00000000,0x00000000}},	//   बोधौ_, бања_, --, --, 
   {{0x224c0077,0xdb1d36ce,0x3ea4fcf4,0xb62002dd}},	//   _ehgk_, ndró, fult_, _ﺨﻁ_, 
   {{0x28cc000b,0x62607696,0x7af803cd,0x11f800f2}},	//   _सैनि, _евха, øttl, _پوشک_, 
   {{0xdb1cf7a4,0xe9dc0208,0x00000000,0x00000000}},	//   derà, _thúi_, --, --, 
   {{0x3ea47d9b,0x3164005a,0x3940030a,0x80e4007b}},	//   ault_, _igoz_, _nyks_, _وأهل, 
   {{0xdcb00372,0xe040288a,0x3ea474b5,0xdb1c0112}},	//   رۉپ_, _енчи, bult_, bdrü, 
   {{0xdb1c652a,0x3ea536cf,0x5fb408c3,0x00000000}},	//   verã, cult_, _ההוא_, --, 
   {{0x26dc0b91,0x7c3c010f,0xddc4033f,0x00000000}},	//   _čuo_, _ekpr, _chiń, --, 
   {{0xa7f802d1,0x9f4456eb,0x644055b3,0x48182d29}},	// [1e630] _huñi, _ponç_, ylni, ажаю_, 
   {{0x2618007d,0xdb1c004e,0x195802dd,0x00000000}},	//   _मगही_, berà, сауы_, --, 
   {{0xa7f80784,0xd7740eff,0xdb1c4a2e,0xb4b400ab}},	//   _juñi, سالع, cerà, _जहॉ_, 
   {{0x7af936d0,0xa9c40502,0xa7f8307d,0xdbd402d2}},	//   ätte, _ازدو, _muñi, _húðb, 
   {{0xdb1d36d1,0x00000000,0x00000000,0x00000000}},	//   merá, --, --, --, 
   {{0xdb1d36d2,0x0ea80406,0x955404fb,0x2c6c15b7}},	//   lerá, _कमंड, سخنا, _müd_, 
   {{0x64400a73,0xf1d819cc,0x601c0241,0xc0dc0092}},	//   rlni, _मोहन, _lámè, ንዲስ_, 
   {{0xdb1c19fd,0x40945549,0x3ea536d3,0x00000000}},	//   nerá, орот, vult_, --, 
   {{0x661936d4,0x64400232,0x2c6c04cc,0x43940276}},	//   _imuk, plni, _nüd_, _маас, 
   {{0x3ea4007d,0x9e8802d3,0x70500338,0x224c00de}},	//   tult_, _መሰልና_, ونيا, _šokē_, 
   {{0x83f8013f,0x2be00307,0xdb1c004e,0x3ea40356}},	//   _nsɑɑ, खाईं_, xerà, uult_, 
   {{0x3d200134,0xdb1d36d5,0x3ea502aa,0x7af8003b}},	//   _pɔw_, rdrü, rult_, øttm, 
   {{0xdb1d36d6,0x6618c6f6,0x3ea536d7,0x70500451}},	//   derá, _mmuk, sult_, _ڪنوا, 
   {{0xdb1d033e,0x3ea536d8,0x3940002d,0x6194001f}},	//   terà, pult_, _ryks_, _ፍትሃዊ_, 
   {{0x66180c8a,0xdb1c3656,0x6b6014a3,0x70503cc6}},	//   _omuk, ferá, дкра, _تنوا, 
   {{0xdb1c0789,0x661800b8,0xa9640395,0x00000000}},	//   gerá, _nmuk, жита_, --, 
   {{0xe0b402f5,0xa7f830df,0xdb1c0109,0x7af801e3}},	// [1e640] জিকভ, _zuñi, serà, ättb, 
   {{0x661936d9,0x39400006,0xdb1c00cf,0xba7425ef}},	//   _amuk, _vyks_, perà, _واجت, 
   {{0xdb1d1291,0xdb24011d,0x3940000f,0x00000000}},	//   berá, _روحی, _wyks_, --, 
   {{0xdb1c30e2,0x4eac008f,0x75445a12,0x661936da}},	//   cerá, רבאַ, онез, _cmuk, 
   {{0x661805b1,0x00000000,0x00000000,0x00000000}},	//   _dmuk, --, --, --, 
   {{0x661936db,0x91fc0374,0x2be0033f,0x78b401bf}},	//   _emuk, _tuāk, खाएं_, mtyv, 
   {{0x78b536dc,0x938808b0,0xa2e00798,0xe72401c4}},	//   ltyv, асқа_, дојд, _дорд_, 
   {{0x65c0d646,0x25840137,0x00000000,0x00000000}},	//   _обса, _ۇچۇپ_, --, --, 
   {{0x78b4023a,0x61400063,0x60f40006,0x00000000}},	//   ntyv, мећа, жныя_, --, 
   {{0xdb1c0745,0x3cdc012c,0x78b400e4,0xe0cc01c8}},	//   zerá, खिने_, ityv, ئزي_, 
   {{0x2c6d36dd,0x78b4023a,0xdb1c01bf,0x00000000}},	//   _süd_, htyv, leræ, --, 
   {{0xceb936de,0x78b402d5,0xdb1c0005,0x00000000}},	//   _һәм_, ktyv, xerá, --, 
   {{0xdb1c1e0b,0x61f000d0,0xdee00023,0x00000000}},	//   verá, želá, ምዃኑ_, --, 
   {{0xa7f936df,0xceb8b132,0x92bc00cc,0x00000000}},	//   _tuñi, _ләм_, ইটী_, --, 
   {{0xdb1c5ced,0xa7f8030a,0x29880640,0x268c0220}},	//   terá, _kuñv, исао_, _ءﺍﺭﻗ, 
   {{0xe9dc004d,0x00000000,0x00000000,0x00000000}},	//   _nhút_, --, --, --, 
   {{0xfcc008b0,0x5e540214,0x00000000,0x00000000}},	// [1e650] _пәрм, _تئور, --, --, 
   {{0x661936e0,0xdb1d36e1,0x7af80112,0xd364215c}},	//   _smuk, será, ättc, _لۇ_, 
   {{0x98bc1991,0x91fc02b1,0xd7ac01f9,0xbd0000e5}},	//   āvā_, _tuāh, _चारच, őéte, 
   {{0xe9dc0016,0xbb380375,0xdd380055,0xad9936e2}},	//   _chút_, _לעתי, _nāśc, mhús, 
   {{0x3cdc1d15,0xdb1c01bf,0x64b4007b,0xf97400d9}},	//   खिये_, geræ, تحضر, _מגרש_, 
   {{0x99800427,0xd838009d,0x78f8011a,0x00000000}},	//   mniš_, _дэс_, _הפשו, --, 
   {{0x99800427,0xb3280092,0x00000000,0x00000000}},	//   lniš_, _ድንገተ, --, --, 
   {{0x661825bf,0xe5e001d9,0xddc40276,0x78a136e3}},	//   _umuk, _تٲری, _munţ, šove, 
   {{0xdce400ef,0x7fd401ec,0x00000000,0x00000000}},	//   _meiģ, піні, --, --, 
   {{0xad9936e4,0x7af8143a,0x00000000,0x00000000}},	//   khús, øttk, --, --, 
   {{0xdb1d36e5,0xddc40311,0x00000000,0x00000000}},	//   merç, _nunţ, --, --, 
   {{0x78b4946c,0xb2b80302,0xad980008,0x9f440241}},	//   ytyv, _למער, dhús, _konú_, 
   {{0xa7f80986,0xc0e4893f,0x25bc020c,0xd7ac00bc}},	//   _huñu, _холк, _mbul_, _चालच, 
   {{0x60d936e6,0x9f440248,0xc0e801f3,0xe4f0000d}},	//   mvum, _monú_, ጅነር_, _आपनि_, 
   {{0xdb1c07b3,0xa7f803f0,0xd1740133,0xdd3800b8}},	//   _üzün, _juñu, _ردۆغ, _yāśc, 
   {{0x78b4049b,0xa7f800e8,0x60d8009f,0xdb1c010b}},	//   ttyv, _muñu, ovum, herç, 
   {{0xa7f80de2,0x80a8009e,0x60d80337,0xdb1c00a2}},	// [1e660] _luñu, কবক্, nvum, kerç, 
   {{0x69c80b21,0xdb1c037e,0x78b4023a,0x68400276}},	//   ôger, veræ, rtyv, енуа, 
   {{0xe9dc07ae,0x78b402f6,0xa7f92cc9,0x9f4401e7}},	//   _phút_, styv, _nuñu, _aonú_, 
   {{0x27308337,0xe3ac3ee0,0xdb1c0158,0xf9c801af}},	//   رىنس, ۇرى_, teræ, _угмк_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa7f81bce,0x60d8003c,0x33f4330e,0x25bd36e7}},	//   _buñu, dvum, ячес, _ebul_, 
   {{0x2c1001e1,0xc0dc001f,0xa3b40592,0x7af8003b}},	//   _jìjọ_, ንዲህ_, ساور_, øtth, 
   {{0x30a421f0,0xc18000dd,0xa7f80de2,0xd7ac05dc}},	//   пров, پیوٹ, _duñu, _चाँच, 
   {{0xe1ec0f78,0x64a107bf,0x92bc0eac,0x60d803b2}},	//   اسى_, _пата, ইটে_, gvum, 
   {{0x9f44011f,0xa7f800e8,0xdb1c00d8,0x00000000}},	//   _innê_, _fuñu, cerç, --, 
   {{0x60d80194,0x93bc054e,0xdb1c3b22,0xe9dc0332}},	//   avum, _amăg, nerä, _mhúr_, 
   {{0x60d80e8a,0x38700200,0x4c940108,0x00000000}},	//   bvum, kqyr_, мимс, --, 
   {{0xdb1c0108,0x00000000,0x00000000,0x00000000}},	//   herä, --, --, --, 
   {{0xb3280489,0x91fc0374,0x9538001f,0xdb1c9226}},	//   _སྨོང_, _puāw, _እናንተ, kerä, 
   {{0xad98002d,0xdb1c00a2,0x00000000,0x00000000}},	//   uhús, jerä, --, --, 
   {{0xad981f60,0x7af8049f,0x48c40724,0x99800841}},	//   rhús, ätta, мәга, tniš_, 
   {{0xad9805f7,0xe9dc01e7,0xceb80153,0x00000000}},	// [1e670] shús, _bhúr_, ltę_, --, 
   {{0xad9936e8,0x9f440ca8,0x2be0012d,0xc0b80092}},	//   chúr, _ronú_, खाओं_, ዲኖሩ_, 
   {{0xdb1d36e9,0xceb80006,0xc5d402bf,0x60d80099}},	//   gerä, ntę_, діль, zvum, 
   {{0xb3280003,0x60d80006,0xceb80024,0xddc48256}},	//   _སྨེང_, yvum, itę_, _kunš, 
   {{0xf8ac01ed,0xa7f80de2,0x92bc0183,0x683000c7}},	//   _نکل_, _suñu, ইটো_, _зҭат, 
   {{0xdb1d36ea,0xe9dc0385,0xa7f803f0,0x03a536eb}},	//   berä, _thús_, _puñu, фико, 
   {{0x626000dd,0xa7f802d1,0xe5f00356,0x425536ec}},	//   _főol, _quñu, _căţă, мтит, 
   {{0x00e49b70,0x9f440093,0xdb1d36ed,0x60d800c5}},	//   джин, _tonú_, serç, tvum, 
   {{0xdb1d36ee,0xceb80024,0xa7f800e8,0x3d0003d4}},	//   perç, etę_, _wuñu, _লেন্_, 
   {{0xad981125,0x60d80393,0x92bc0154,0xdb1c0efa}},	//   skúl, rvum, ইয়ে_, lerå, 
   {{0x60d936ef,0x7d0803e3,0xdbc400c7,0x00000000}},	//   svum, _əfsu, ҭамҩ, --, 
   {{0x38700240,0xdb1c05ac,0x25ac003e,0xd4080150}},	//   yqyr_, nerå, nggl_, _وتەم_, 
   {{0xdb1c3653,0x72402586,0x7ff4007b,0x00000000}},	//   ndrö, _جھول, _يستا, --, 
   {{0xbea40228,0xc0b8001f,0xa7f80165,0x00000000}},	//   _жакк, ዲኖር_, _muñs, --, 
   {{0x3f8536f0,0x3b0800d8,0xceb80393,0x290c01ab}},	//   mblu_, цево_, ctę_, ùgan_, 
   {{0xdb1d36f1,0xfbdc0954,0x703c0092,0x00000000}},	//   verä, _फोरम, _አባታቸ, --, 
   {{0xaa4136f2,0x78643334,0x3944003a,0xdb1c007c}},	// [1e680] тетл, дказ, æos_, derå, 
   {{0xdb1c05ca,0x7c6401ec,0x3f840fac,0x16200037}},	//   terä, _تاعل, nblu_, _मगहर_, 
   {{0xba742310,0xf98536f3,0xf1ac00e1,0x7c2d36f4}},	//   _تاخت, _огно, _टालन, mnbr, 
   {{0xeef4008f,0x499000f2,0xaac800bc,0x00000000}},	//   ומער_, _میفر, ाबरक, --, 
   {{0xe9dc0332,0xdb1c3b22,0xec100133,0x00000000}},	//   _thúr_, serä, _سوێد, --, 
   {{0xdb1c049b,0xceb8fea4,0x8554036b,0xca740244}},	//   perä, ytę_, ریلر_, _تنێک, 
   {{0xc32c12b7,0x7c2cc648,0x92bc009e,0xdb1c005c}},	//   مەك_, inbr, ইট্_, berå, 
   {{0x7c2c0112,0x34a0014b,0xf1a40798,0x00000000}},	//   hnbr, _аҳдҳ, фркн, --, 
   {{0xb59400d1,0xddc4010e,0xd13000db,0x00000000}},	//   _ниңш, _ikiň, دۅش_, --, 
   {{0xc2c81e4a,0x23a40209,0x7c2c01f5,0x250810e8}},	//   تبۇل_, _овуп_, jnbr, _برفی_, 
   {{0x91fc0421,0xad980030,0xe8a800bc,0xe294187f}},	//   _suāu, skúm, _चम्च, _жах_, 
   {{0xceb83920,0x7c2c017a,0x3ce536f5,0xc6240154}},	//   rtę_, enbr, _šova_, যকথা_, 
   {{0x7af804f3,0xceb84f59,0x9d18020a,0x21640a31}},	//   ättn, stę_, доят_, _жици_, 
   {{0x619402d3,0xce94a5cb,0x7c2c03b2,0xceb80210}},	//   _ፍትሓዊ_, _закъ, gnbr, ptę_, 
   {{0xdb1c004a,0xc624009e,0xeacc0183,0x5b2401c6}},	//   nfrè, যকতা_, ৰহ্ম, вьта, 
   {{0x7c2c017a,0x9b5828f3,0xad980022,0x00000000}},	//   anbr, фист_, chúp, --, 
   {{0x9f440036,0xd87400f7,0x0854023a,0xbee80073}},	// [1e690] _annè_, نالب, еваю, टमॅन_, 
   {{0xe7081ca1,0x57240145,0x47d536f6,0x00000000}},	//   يتان_, چىكك, عيار, --, 
   {{0xdb1d36f7,0xdd4000a2,0x56940395,0x0994009b}},	//   terå, _aňňa, вахт, _панџ, 
   {{0x78a00e96,0xa7f805c7,0xa8a40138,0x0cd000eb}},	//   šova, _puñs, _оргк, ামীত, 
   {{0x7eb40724,0xdb1c0ac8,0x7af803cd,0xf318010b}},	//   _küpç, rerå, øttv, үнчә_, 
   {{0xdb1c0250,0xddc40055,0xd800010a,0x00000000}},	//   rdrö, _bhiś, _вăш_, --, 
   {{0x442804b9,0xddc40055,0x6b8000c7,0x997c00b8}},	//   đa_, _chiś, _õngu, _nāśo_, 
   {{0xddc400b8,0x00000000,0x00000000,0x00000000}},	//   _dhiś, --, --, --, 
   {{0x657800ca,0x9f4400c6,0x91fc02b5,0x843402bf}},	//   _ifuh, _inné_, _ruāt, _знає, 
   {{0xb22403b2,0x99800419,0xa2d404af,0x00000000}},	//   tjæð, mniť_, _मनप्, --, 
   {{0x99800030,0xdb1c01c7,0x87c000cd,0x00000000}},	//   lniť_, rfrë, र्यॊ, --, 
   {{0x7cc4013f,0xc32003d4,0xd1b802ef,0xdb1c0036}},	//   _lɔre, _পুথি_, _يانا_, sfrë, 
   {{0x657800ca,0x62800153,0x7c2c0feb,0x00000000}},	//   _mfuh, lpno, tnbr, --, 
   {{0xdb1c04d4,0x3f840135,0x998000dc,0x00000000}},	//   merú, qblu_, bhiś_, --, 
   {{0x91fc0421,0xc32000fe,0x00000000,0x00000000}},	//   _tuāt, _পুতি_, --, --, 
   {{0xdb1ca57f,0x7c3405be,0x6b600228,0x00000000}},	//   nfré, _šarč, укса, --, 
   {{0x16c85b82,0x3f8000c5,0x998000d0,0x1ee416d0}},	// [1e6a0] रब्ब, _õhus_, jniť_, _روکی_, 
   {{0x7d04049b,0x657936f8,0x61e80327,0x9f440129}},	//   myks, _afuh, _lngl, _anné_, 
   {{0x61e936f9,0x7bcd36fa,0x39e8896b,0xa2c02158}},	//   _ongl, mebu, _едно_, ্মুখ, 
   {{0x7af87778,0x00000000,0x00000000,0x00000000}},	//   øttu, --, --, --, 
   {{0x7994b70b,0x7d0536fb,0xa50412e7,0x845400d1}},	//   mayw, nyks, неца_, چىنچ, 
   {{0xdb1c7e02,0x799536fc,0x00000000,0x00000000}},	//   derú, layw, --, --, 
   {{0xdb1d36fd,0xe73536fe,0x7d04023a,0x326400f0}},	//   ffré, _зер_, hyks, нтив, 
   {{0x7bcd36ff,0xb9c802d3,0x79953700,0xa2c000fe}},	//   hebu, _ዲና_, nayw, ্মূখ, 
   {{0x91fc0b23,0x63b402d3,0x76400014,0x386801a9}},	//   _suās, çanë, mooy, _kibr_, 
   {{0x76400050,0x79953701,0x7bcd3702,0x7d04ea7e}},	//   looy, hayw, jebu, dyks, 
   {{0xb8e00135,0x799402d1,0xb8f0031c,0x60c4054e}},	//   _གཱ_, kayw, _ེག_, ăjma, 
   {{0x38693703,0x76413704,0xade81025,0xdb1c00d7}},	//   _libr_, nooy, टाइन_, berú, 
   {{0xdb1d3705,0x7bcc0208,0x79953706,0x6218011a}},	//   zdrô, febu, dayw, _צודק, 
   {{0x7bcd3707,0x38680217,0x76408c88,0x9ac40337}},	//   gebu, _nibr_, hooy, _ŋŋam, 
   {{0x61e800a9,0x998001a2,0x76413708,0xabe801d9}},	//   _yngl, zniť_, kooy, _ہردٕ_, 
   {{0x79953709,0x7cc4016b,0x76400014,0x7d0400b5}},	//   gayw, _sɔre, jooy, byks, 
   {{0x76400050,0xc7d81064,0xf8b5370a,0x0ba40022}},	// [1e6b0] dooy, ммах_, көр_, _иынҭ, 
   {{0x7bcd370b,0x998000d0,0x57b463dd,0xd838009d}},	//   cebu, vniť_, лбут, нэх_, 
   {{0x7994010a,0x38680165,0x76400014,0x69c0013f}},	//   bayw, _dibr_, fooy, ɑnen, 
   {{0x7641370c,0xa645370d,0xc8a81715,0x7cc4013b}},	//   gooy, رخان, _छटपट, _wɔre, 
   {{0x3868007f,0x1b480092,0xbb2c0092,0xda040064}},	//   _fibr_, _መስተካ, ተዋውቁ, _счэп, 
   {{0x8365370e,0x998001f1,0x61e80327,0xb86400f1}},	//   نگال, rniť_, _sngl, _ټاټو, 
   {{0x76409fd3,0x06640588,0x99800030,0x7d05370f}},	//   booy, _ахаҭ, sniť_, zyks, 
   {{0x7bcd3710,0x657800ca,0x628009a8,0xdb1c045f}},	//   zebu, _ufuh, rpno, terú, 
   {{0xdb1c01a8,0x7bcd1d17,0xfbb0190c,0x00000000}},	//   rfré, yebu, _जालम, --, 
   {{0x7d04652e,0x7bcc774c,0xdb1c0022,0x6280d468}},	//   vyks, xebu, rerú, ppno, 
   {{0x7d053711,0x799402d1,0x00000000,0x00000000}},	//   wyks, yayw, --, --, 
   {{0x7d040664,0x61e93712,0x7af801e6,0xdb2401ed}},	//   tyks, _ungl, ättm, árít, 
   {{0x7bcd3713,0x6440033d,0xed5410f5,0x51840364}},	//   tebu, ooni, кою_, _суха, 
   {{0x7d053714,0x79953715,0xfaa53716,0xade800bc}},	//   ryks, wayw, каго, टाउन_, 
   {{0x76413717,0xae1c3d1d,0xbb453718,0xdb1c2b96}},	//   yooy, मोहन_, тевк, nerø, 
   {{0x7bcc8f58,0x6e9000cf,0x7d046e53,0x7640058a}},	//   sebu, _ئليا, pyks, xooy, 
   {{0x64413719,0x7bcc00ca,0x76400076,0x8a180014}},	// [1e6c0] koni, pebu, vooy, رتِس_, 
   {{0x64403aaf,0x76409ad5,0x7bcc014b,0x78a002fb}},	//   joni, wooy, qebu, šovo, 
   {{0x76400050,0x36340344,0xe9dc0241,0x7995371a}},	//   tooy, پراس, _ikún_, payw, 
   {{0x225c2a1f,0xdb1c1477,0x66080098,0x79940309}},	//   jmuk_, derø, gkgk, qayw, 
   {{0x76409fb9,0x8b6400f1,0x00000000,0x00000000}},	//   rooy, _ټایم, --, --, 
   {{0x76400731,0xe8700131,0x3a30010e,0x377401af}},	//   sooy, _ئۆلگ, lnyp_, _шымс, 
   {{0xdb1c1455,0x7414bbed,0x00000000,0x00000000}},	//   gerø, _یورا, --, --, 
   {{0x76400050,0x225c0589,0xa2b0012c,0x066402dd}},	//   qooy, gmuk_, _इमर्, _ماقپ, 
   {{0x64400163,0xb464da1d,0xc4c4004b,0xe9dc0241}},	//   boni, _акал, _متلو, _okún_, 
   {{0x644007ad,0x2129371b,0xdb1c1512,0x73e40354}},	//   coni, úcha_, berø, _шозз, 
   {{0xdef40953,0x3a300af9,0xdb1c003b,0x00000000}},	//   выя_, knyp_, cerø, --, 
   {{0xd3780960,0x3124008e,0x00000000,0x00000000}},	//   _daće_, _идег, --, --, 
   {{0x6ac800cd,0x00000000,0x00000000,0x00000000}},	//   ाब्र, --, --, --, 
   {{0xd01026a6,0x00000000,0x00000000,0x00000000}},	//   _دلت_, --, --, --, 
   {{0xd37805ce,0x9f440789,0xe9f00022,0x9b940114}},	//   _gaće_, _donó_, аҧны, рисц, 
   {{0x5a35371c,0x9a85371d,0xae1c0307,0xeda40124}},	//   анст, рурл, मोशन_, _ршко, 
   {{0x6441371e,0x9f45371f,0xa91802d2,0x7af85522}},	// [1e6d0] yoni, _fonó_, _ofþe, øttr, 
   {{0x64413720,0x195801ec,0xaaa80456,0x00000000}},	//   xoni, тауы_, _छिपक, --, 
   {{0xb7c402dd,0x9848005b,0x44300205,0x00000000}},	//   ыртқ, тята_, _ız_, --, 
   {{0xdb1c0158,0x6ff80327,0xaa4000d1,0x00000000}},	//   verø, ནྡྷུ_, _ئۆرى, --, 
   {{0x64400d63,0x03a4005a,0x00000000,0x00000000}},	//   toni, гило, --, --, 
   {{0xdb1d3721,0x00000000,0x00000000,0x00000000}},	//   terø, --, --, --, 
   {{0x64413722,0x56953723,0xd7f80276,0xa24401ed}},	//   roni, _васт, _руя_, پیشل_, 
   {{0x64413724,0xdb1c03cd,0x69dc0200,0xf07400e5}},	//   soni, rerø, ndqe, گیوں_, 
   {{0xdb1c318c,0x225c039a,0xd37801a6,0x26f80183}},	//   serø, rmuk_, _saće_, _এইটো_, 
   {{0xf07400dd,0x64413725,0x7af8007c,0x00000000}},	//   دیوں_, qoni, ättk, --, 
   {{0x44253726,0xddc40276,0x91fc00b0,0xf2e40451}},	//   _iml_, _chiş, _tuāp, _مکيه_, 
   {{0x009405f5,0x9f440407,0xd17464c2,0x442401f4}},	//   _бидэ, _sonó_, _кышы, _hml_, 
   {{0x61f93727,0x9f453728,0x00000000,0x00000000}},	//   mjul, _inní_, --, --, 
   {{0x44253729,0x9f44011c,0x61f9372a,0x00000000}},	//   _jml_, _donò_, ljul, --, 
   {{0x61f801c8,0xddc4054e,0x926c15b7,0xde4800f1}},	//   ojul, _ghiş, _üşüd, _لیدو_, 
   {{0x4424011c,0xfaa4013e,0x9cb40014,0x00000000}},	//   _lml_, каҳо, _پۅست, --, 
   {{0xf7701b06,0xfce4871a,0x4425372b,0x00000000}},	// [1e6e0] ماا_, _сопо, _oml_, --, 
   {{0x61f9372c,0x9f44011f,0x8b9402f6,0x93bc0311}},	//   hjul, _innâ_, _крюч, _amăn, 
   {{0x2c6c038f,0x7bdc0263,0x249c0393,0xb4640417}},	//   _iżda_, _iapu, _avum_, ңкел, 
   {{0x442400a9,0x4ad801d9,0x61f82252,0xd5b001d3}},	//   _aml_, _شاپھ_, jjul, تہر_, 
   {{0xc32004c5,0x4424010a,0xe5a0d89f,0x00000000}},	//   _পুলি_, _bml_, сичи, --, 
   {{0xf745372d,0x7bdd372e,0x9f440139,0x9981372f}},	//   _бего, _japu, _anní_, skiń_, 
   {{0x0cb13730,0x7af80267,0x61f80fac,0x00000000}},	//   _जम्म, ätth, fjul, --, 
   {{0x44243178,0x61f93731,0x00000000,0x00000000}},	//   _eml_, gjul, --, --, 
   {{0xdb1c0162,0xd13000ae,0x05dc0d2e,0x00000000}},	//   dfrí, تمة_, _नोटब, --, 
   {{0x61f93732,0xee840150,0x00000000,0x00000000}},	//   ajul, лымо, --, --, 
   {{0x9e101152,0x160801ad,0x807800db,0x00000000}},	//   ासंघ_, _वकार_, нбөс_, --, 
   {{0x7bdc1c06,0xdb1c1427,0xad9800e5,0xa18050cb}},	//   _aapu, gfrí, lhúz, _лышл, 
   {{0x7bdd3733,0xa0a0010b,0x44240ea0,0x9cc8010b}},	//   _bapu, _гачд, _yml_, лыра_, 
   {{0x44253734,0x7bdd3735,0x998005d1,0xad98002d}},	//   _xml_, _capu, thiş_, nhúz, 
   {{0x7af81445,0xfbf401f0,0xdf6400ef,0xdeec6171}},	//   øttp, шорӯ, _žāvē_, _уы_, 
   {{0xa2d44c83,0xa2a4daf5,0x00000000,0x00000000}},	//   _मनस्, _घटस्, --, --, 
   {{0x7bdc0270,0x290d3736,0x24593737,0xddb400db}},	// [1e6f0] _fapu, ága_, lême_, _احىب, 
   {{0x7bdd3738,0x2e280100,0xed600024,0xd8a801f7}},	//   _gapu, _fòfè_, ėžė_, اهلو_, 
   {{0x96e92134,0x85740408,0x442402d2,0x1ddc0037}},	//   льца_, алех, _rml_, _बसमत, 
   {{0x7bdc0f03,0xd6d93739,0x15b8748c,0x25700046}},	//   _zapu, ыту_, гышы_, сқас, 
   {{0x442411ce,0x7bdc9b55,0xd7f02302,0x249c003a}},	//   _pml_, _yapu, تكە_, _qvum_, 
   {{0x7e8002b5,0x34b004fb,0x7bdc004e,0xad9831b7}},	//   _hēpe, آموز, _xapu, ghúz, 
   {{0x61f9373a,0xe9dc0270,0x44240334,0x938800f7}},	//   tjul, _kaú_, _vml_, усча_, 
   {{0x0205373b,0x44240327,0x212806ed,0x7af837e9}},	//   рзин, _wml_, úcho_, ätti, 
   {{0x442400e2,0x21c800fd,0xc0940b82,0xdb1c010e}},	//   _tml_, _җыеп_, _ግብጽን_, derý, 
   {{0xe9dd373c,0x44249f65,0x6b940327,0x61f8340f}},	//   _laú_, _uml_, _nexg, sjul, 
   {{0x7bdd373d,0xe2a800db,0x7d440023,0xdb1c0162}},	//   _rapu, _ساان_, _መንጎኦ, tfrí, 
   {{0x91b84d81,0x39a001d3,0xdb1c0432,0xd1b80066}},	//   _مطهر_, _késő_, gerý, _ماها_, 
   {{0x7bdd373e,0xdb1c05f7,0x60c802d0,0x118401e0}},	//   _papu, rfrí, _upgm, _уҙып_, 
   {{0x7bdd373f,0xd3780114,0x78a01d55,0x1ee401d3}},	//   _qapu, _kaća_, šovk, _موتی_, 
   {{0xeb953740,0xe9dc0120,0xdb1d3741,0xcee801c8}},	//   рис_, _baú_, pfrí, _مرين_, 
   {{0x7bdd3742,0xdb1d3743,0xca749c36,0x80d800bc}},	//   _wapu, cerý, суры, _भनाइ, 
   {{0x8cac12eb,0x97a40166,0x00000000,0x00000000}},	// [1e700] _जियो, йлаҗ, --, --, 
   {{0x7bdc003a,0xaffc004d,0x2e280241,0xad9803b2}},	//   _uapu, _khướ, _tòfè_, tjúg, 
   {{0xdb1cac8e,0xbbb017ee,0x00000000,0x00000000}},	//   sfrâ, जलीक, --, --, 
   {{0x06640b28,0x3eb8033f,0x00000000,0x00000000}},	//   مانپ, ństw_, --, --, 
   {{0xb8640814,0x53c8024c,0xdb240174,0xf86801c8}},	//   _ناسو, лҳам_, áræt, _لمحي_, 
   {{0xdb1c00dd,0xa2d4043e,0x00000000,0x00000000}},	//   kerü, _मनश्, --, --, 
   {{0xdb1c4a1f,0xad993744,0xaffc0208,0x00000000}},	//   meró, rhúz, _nhướ, --, 
   {{0xe6413745,0xdb1d3746,0xf7440454,0x24580022}},	//   _десп, derü, _беҳо, vême_, 
   {{0x9f44a4d8,0x847402d3,0x73c00032,0xefb001b9}},	//   _annà_, ጸባርቕ_, _ғәҙе, قیشگ, 
   {{0x667001ec,0xdb1d3747,0x00000000,0x00000000}},	//   _اگەر, neró, --, --, 
   {{0xaffc01fb,0xd37804a7,0xdb1d3748,0xa8540375}},	//   _chướ, _gaća_, gerü, שייה_, 
   {{0x245806af,0xdf5001c6,0xdb1c0124,0xb3680092}},	//   rême_, өнөө, heró, ጠናውን_, 
   {{0x9f4407c5,0x518401af,0xdb1c0210,0x00000000}},	//   _ennà_, _куҙа, keró, --, 
   {{0xeaf8103f,0xdb1d3749,0xddc400f3,0xa9c000d1}},	//   پرست_, berü, _viiš, ﺭﺗﯩﻴ, 
   {{0xda79374a,0xdb1d374b,0x9a8405f5,0x7e809334}},	//   ият_, deró, жуул, _pēpe, 
   {{0xddc40f8b,0x497482de,0xa918032e,0x00000000}},	//   _tiiš, слас, _afþa, --, 
   {{0x39b40491,0x9f440321,0x48140108,0xad98dd18}},	// [1e710] _šŋåң, _inná_, бмас, skús, 
   {{0x57f4009b,0xdb1c0210,0x6b58004e,0x00000000}},	//   опут, geró, _үшүр_, --, 
   {{0xe9dc0093,0xe664136b,0xdc3c0375,0xe5cc0055}},	//   _taú_, атдо, _בעזר, cāśā, 
   {{0x3ce4b2be,0x00000000,0x00000000,0x00000000}},	//   _šovi_, --, --, --, 
   {{0xdb1cfc8a,0xd37801a6,0x7af80267,0x04c83cc6}},	//   beró, _saća_, ättv, اوتي_, 
   {{0xdb1c0210,0xe2d40014,0x00000000,0x00000000}},	//   ceró, لابچ_, --, --, 
   {{0x96f9374c,0xd2980006,0x00000000,0x00000000}},	//   _керт_, атыі_, --, --, 
   {{0x2ba40b7c,0x3ea400fb,0x00000000,0x00000000}},	//   कृता, ҙимг, --, --, 
   {{0xb9dc044e,0xe7a802ab,0xc0f80092,0x7bc801a8}},	//   _ኢዱ_, _चयाप, _ፈጥሮ_, _öfug, 
   {{0xdb1d374d,0xaffc001e,0x045800c6,0xd46800f3}},	//   terü, _phướ, _صلاة_, _виђе_, 
   {{0x2eb4ec85,0xfe4431ee,0xdb1c00e4,0xa28002f2}},	//   _अमृत, йноо, herò, _بیبو, 
   {{0x40340184,0xe9dc001e,0xdb1c3812,0xdce40210}},	//   реүс, _thúy_, zeró, _zgię, 
   {{0xdb1c3f17,0xcfac00d1,0x008521e2,0x626000e5}},	//   serü, _ﻳﯘﺭﺗ, _улло, _főor, 
   {{0xaffc0016,0xdb1d374e,0x3f78008f,0x1b0c0154}},	//   _thướ, perü, _גאַס, _হইবে_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb1c012d,0x36c40022,0x00000000,0x00000000}},	//   weró, ҩбаг, --, --, 
   {{0x1b2009bd,0xdb1d374f,0xd8840214,0xddc401ef}},	// [1e720] _মুখে_, teró, زهای, _kunž, 
   {{0xf7440b7e,0x6fc800dc,0x2cf8010f,0x00000000}},	//   безо, त्पू, _עליא, --, 
   {{0x7c2d3750,0x3b08011c,0x36c40150,0x00000000}},	//   mibr, _сено_, сбег, --, 
   {{0x7c2d3751,0xdb1d3752,0x15b52374,0xd91007d6}},	//   libr, seró, تەرس, _قیز_, 
   {{0xdb1d3753,0xad98004e,0x00000000,0x00000000}},	//   cerò, ljúc, --, --, 
   {{0xc32c3baf,0xa5040640,0xb3400205,0x00000000}},	//   چەك_, сеља_, _üçku, --, 
   {{0xc32c0328,0xe29400d8,0x00000000,0x00000000}},	//   نەك_, бај_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x99800006,0x30680798,0xd70000cc,0x00000000}},	//   lnių_, лјон_, _এইয়া_, --, 
   {{0xd3702002,0x7c2c2ce5,0x99800024,0x00000000}},	//   _قۇش_, jibr, onių_, --, 
   {{0x7c2d3754,0xdb1c0008,0x211401d5,0x78b40051}},	//   dibr, lfræ, لتیب_, huyv, 
   {{0x99800024,0x80a000bc,0x00000000,0x00000000}},	//   inių_, _खिचे, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7c2d3755,0x32040067,0xceb87c4c,0xce94074d}},	//   gibr, _hooy_, _кәм_, _дакъ, 
   {{0x320401f5,0x9f4401bf,0xdb1c03b2,0x802400f2}},	//   _kooy_, _annæ_, tfrá, _برنم, 
   {{0x32041bce,0x7c2c0549,0xdb1c5d7e,0xda7800ee}},	//   _jooy_, aibr, terò, сяр_, 
   {{0x32041105,0xa9c800c7,0x7c2d3756,0x6e2c02d0}},	// [1e730] _mooy_, _ҩымз_, bibr, micb, 
   {{0x7e8002b5,0x32053757,0x2d98036e,0x2078010f}},	//   _hēpa, _looy_, _heqe_, טאמא, 
   {{0x2d9802d3,0xab6002dd,0x6fc8c454,0x998000c0}},	//   _keqe_, _ءۇزى, त्यू, gnių_, 
   {{0xdeb80bd9,0x6e2c00b5,0x32041bce,0xe9dc0022}},	//   רמאל, nicb, _nooy_, _okúi_, 
   {{0x2d9881f1,0xdb1c0008,0x7e8000b0,0xe7853758}},	//   _meqe_, gfræ, _mēpa, _губо, 
   {{0x2d993759,0xd764168d,0x1b0c015b,0xdc9c00df}},	//   _leqe_, _کۆمی, _হইতে_, ריגל, 
   {{0xdc3804ac,0x32040694,0x27e000df,0x8219375a}},	//   זאגט_, _booy_, _iajn_, ицит_, 
   {{0x80a9375b,0x2d9894c8,0x7c2d1774,0xc0300023}},	//   авив_, _neqe_, zibr, _እብራው, 
   {{0x6e2c0cf4,0x32050531,0x7c2c004b,0xdb1c03b2}},	//   dicb, _dooy_, yibr, herð, 
   {{0xa2a83af7,0xa7f800b8,0x00000000,0x00000000}},	//   ींद्, _puñy, --, --, 
   {{0x02d84191,0x9f440421,0x320400e8,0x27e00010}},	//   _خواب_, _nonô_, _fooy_, _majn_, 
   {{0x92b4bbcc,0x32040009,0xeb5c010c,0xee340815}},	//   _رحما, _gooy_, _ተስፋና_, жню_, 
   {{0x042000cd,0x00000000,0x00000000,0x00000000}},	//   _śaṃk, --, --, --, 
   {{0xdb1c2242,0x60d801b2,0x3f69375c,0xeb95375d}},	//   ferð, mwum, _кило_, жир_, 
   {{0xdb1c1c38,0x25bc0998,0x7c2d375e,0x60d8014b}},	//   gerð, _ocul_, ribr, lwum, 
   {{0x2005375f,0x2d980fec,0x3ce53760,0x7c2c18ab}},	//   _honi_, _geqe_, _šovu_, sibr, 
   {{0x9d544451,0x27e0036e,0xbb740117,0x7c2c00c0}},	// [1e740] _رۆست, _bajn_, _мунъ, pibr, 
   {{0x20053761,0x2d98014b,0x7af801e6,0xddc40327}},	//   _joni_, _zeqe_, ätts, _lunż, 
   {{0x20053762,0x25bc01ab,0x2d98014b,0xc7943c1a}},	//   _moni_, _bcul_, _yeqe_, ярты, 
   {{0x20053763,0x60d93764,0x27e0005a,0x99800024}},	//   _loni_, kwum, _eajn_, rnių_, 
   {{0x1cd803bd,0x64a0531d,0x998002d5,0x27e13765}},	//   _ོགས_, дача, snių_, _fajn_, 
   {{0x2004974f,0xdb1c008c,0x60d80134,0x32040694}},	//   _noni_, rfræ, dwum, _sooy_, 
   {{0xdb1c0008,0xe6d801ee,0x00000000,0x00000000}},	//   sfræ, _кѳтә_, --, --, 
   {{0x78a4020c,0xe694016c,0xd2500372,0xdd140030}},	//   _kvkv, _фурӯ, رچا_, pĺňa, 
   {{0x20053766,0xd345353b,0x7e8000b0,0xdb1c3bd2}},	//   _boni_, _کفای, _rēpa, lfrä, 
   {{0x20053767,0xaaa8032c,0x2d98002e,0x1b20015b}},	//   _coni_, _छिलक, _seqe_, _মুছে_, 
   {{0x20053768,0xddc40327,0x3204002e,0x6e2c035a}},	//   _doni_, _funż, _tooy_, ticb, 
   {{0x7c3c0526,0xdb1c008c,0x2004007f,0x60d80223}},	//   _ajpr, verð, _eoni_, bwum, 
   {{0x20053769,0x7521376a,0xafe5376b,0x6e2c02d0}},	//   _foni_, nzoz, _модл, ricb, 
   {{0xa064bafa,0x68f8bbc6,0x2d980117,0xdfcc47ea}},	//   _дача_, _àudi, _weqe_, _ليه_, 
   {{0x5fb40302,0x7e8002b5,0x7c3c00d8,0x2d98036e}},	//   _והוא_, _tēpa, _djpr, _teqe_, 
   {{0x7bd807ea,0x9ef00066,0x00000000,0x00000000}},	//   ôtur, _آسوش, --, --, 
   {{0x7af8049f,0x2005376c,0x481454a0,0x27e00327}},	// [1e750] ättr, _yoni_, пмас, _pajn_, 
   {{0x7521376d,0x7984007f,0x25bc04cc,0x200401d5}},	//   dzoz, _efkw, _scul_, _xoni_, 
   {{0x81e00eac,0x2b4404cc,0x57a40816,0x7d1801e4}},	//   দাত_, _ânc_, ьшта, ŝtst, 
   {{0x7af803d4,0x27e00198,0x75880023,0xae1c5d4f}},	//   åtte, _wajn_, _ዝበልዎ_, मोचन_, 
   {{0xe7841d56,0x27e0025c,0x88b0335b,0x00000000}},	//   _муво, _tajn_, _سیاچ, --, 
   {{0x2eec0115,0xd40803cc,0x9f44005b,0x34b01183}},	//   _orff_, قتىم_, _ynnä_, رمىز, 
   {{0x60d80ba7,0x070816ac,0x00000000,0x00000000}},	//   wwum, _ايزي_, --, --, 
   {{0x2005376e,0x60d801b2,0x25bc82af,0x9324027d}},	//   _soni_, twum, _ucul_, ظرون, 
   {{0x2005376f,0x66193770,0x090c0eac,0x7520012d}},	//   _poni_, _iluk, _সেতু_, czoz, 
   {{0x44dc09a5,0xc3c405f5,0x60d800ca,0xdb1c0267}},	//   _iň_, _хөдл, rwum, lfrå, 
   {{0x66193771,0x200418f7,0x6d5c06be,0x69cc0d2e}},	//   _kluk, _voni_, _azqa, _obce, 
   {{0x44dc033b,0xdb1c4bc1,0x00000000,0x00000000}},	//   _kň_, nfrå, --, --, 
   {{0x317825f9,0xa3dc0574,0x66186922,0xdb1d3772}},	//   _האנד, _तसा_, _mluk, nerö, 
   {{0x6618c56c,0x200401f7,0x44dc007f,0x3ce400e2}},	//   _lluk, _uoni_, _mň_, _šovs_, 
   {{0x66193773,0x6b60470c,0x44dc02e2,0x290c06ea}},	//   _oluk, екра, _lň_, øgan_, 
   {{0x661804ba,0x44dcfda9,0xe9dc032e,0xdb1c3b22}},	//   _nluk, _oň_, _ljúf_, kerö, 
   {{0x0f34044e,0x69cc02c4,0xa9653774,0x44dc02e2}},	// [1e760] _ብመሰረ, _dbce, зита_, _nň_, 
   {{0x9f4402bf,0x3f8406af,0xdb1d3775,0x69cc0205}},	//   _ennå_, nclu_, derö, _ebce, 
   {{0x6618c352,0x44dc0432,0xdb500133,0x00000000}},	//   _bluk, _aň_, _شێر_, --, 
   {{0x44dc033b,0xdb1d3776,0x7520009d,0x786000d0}},	//   _bň_, rfrä, tzoz, dôve, 
   {{0xb4e40406,0xdb1c4a41,0x938801ec,0x00000000}},	//   बटे_, sfrä, ұсқа_, --, 
   {{0x66193777,0x78a00313,0x2f213778,0x87b8457e}},	//   _eluk, šovs, _jégé_, _муст_, 
   {{0x66193779,0xddc40054,0x6b800a85,0x92bc05ac}},	//   _fluk, _ikiņ, _ûnge, েট্_, 
   {{0x44dc033b,0x2f20003e,0xdb1d377a,0x8cac033f}},	//   _fň_, _légé_, berö, _जिलो, 
   {{0x0ef426d9,0x60f402d5,0xdb1c007c,0x00000000}},	//   इम्स_, зныя_, cerö, --, 
   {{0xe0cc3c19,0x251825f9,0xdb1ca1bc,0x35d00037}},	//   ازي_, _הומא, rgrê, _धउड़, 
   {{0x7e74089c,0xdb1c002d,0x1b0c0154,0x3fc807d6}},	//   _biyp, sgrê, _হেসে_, تگنی_, 
   {{0x17d8045e,0x6618031c,0x44dc00ee,0x00000000}},	//   সায়ি, _xluk, _yň_, --, 
   {{0x2f20002e,0x52dc0b8f,0xdb1c0129,0x00000000}},	//   _bégé_, _मनुस, lgrè, --, 
   {{0xad100daf,0xdb1c0254,0x6e2c00b8,0xec14008e}},	//   _үпкә, herõ, _śibī, чегә_, 
   {{0xdb1d377b,0xcb6814d1,0x68ec0332,0xe454010f}},	//   ngrè, زمره_, _srcd, פילט_, 
   {{0xef9001b9,0xdb1c007c,0xdeb8011a,0x00000000}},	//   _تیگد, xfrå, _המהל, --, 
   {{0x58d40c75,0xd7c800f1,0x00000000,0x00000000}},	// [1e770] нотт, ړوله_, --, --, 
   {{0x661817b8,0x2f21246e,0x6b643847,0xd3641c02}},	//   _sluk, _gégé_, gégé, _مۇ_, 
   {{0x44dc007f,0xdb1c0267,0x00000000,0x00000000}},	//   _sň_, tfrå, --, --, 
   {{0x6b80025a,0xdb1c007c,0x00000000,0x00000000}},	//   _ûngb, terö, --, --, 
   {{0xdb1c049f,0xe8e800c6,0xb88002f0,0x00000000}},	//   rfrå, _ارجو_, šírn, --, 
   {{0xdb1d377c,0x66180066,0xe9dc032e,0xd7e40212}},	//   sfrå, _wluk, _bjúg_, _пісо, 
   {{0x661806e4,0x248c05b1,0xdb1d377d,0xcfa000d1}},	//   _tluk, spgm_, ggrè, _ﺋﯘﺯﯗ, 
   {{0x6619377e,0x601c20ef,0x7860002d,0x656c0306}},	//   _uluk, _même, rôve, _úcho, 
   {{0x65781419,0xdb1c90d4,0x44dc010e,0x00000000}},	//   _iguh, lerô, _uň_, --, 
   {{0x4431377f,0x7e74022e,0x0a480092,0x00000000}},	//   _öz_, _siyp, _መኖሪያ, --, 
   {{0x63a13780,0xdb1c04e6,0x2f2001e1,0xe7cc0b02}},	//   mann, rgrë, _régé_, स्यप, 
   {{0x63a13781,0xdb1c01c7,0x1b0c0154,0xc1140798}},	//   lann, sgrë, _হইলে_, _омеј, 
   {{0x63a0011c,0xcfa00131,0xcfd800fe,0x00000000}},	//   oann, _ﺋﯘﺭﯗ, তাজন, --, 
   {{0x7ff403e6,0xdb1d3782,0x00000000,0x00000000}},	//   _زستا, lgré, --, --, 
   {{0x63a13783,0x657804ba,0x00000000,0x00000000}},	//   iann, _oguh, --, --, 
   {{0xdb1d3784,0xad98004e,0x00000000,0x00000000}},	//   ngré, njúl, --, --, 
   {{0x6b6407ea,0x37e401b9,0xbd44009f,0xdb1c9154}},	// [1e780] tégé, моаг, _زندي, verõ, 
   {{0xf7703ccf,0x65780230,0x601c0120,0xdd0c0034}},	//   ناا_, _aguh, _fême, półc, 
   {{0x6b653785,0x601c0120,0xbb441a92,0x1b0c0154}},	//   régé, _gême, _ценк, _হেরে_, 
   {{0x6b6400dd,0xc764278f,0x63a0062c,0xd1c80023}},	//   ségé, رالى, eann, ጽታት_, 
   {{0x63a13786,0x23841bce,0xe5a00d57,0xe9dc01e1}},	//   fann, _bёj_, тичи, _ekús_, 
   {{0x601c2776,0xb4dc007d,0xdb1c000d,0x00000000}},	//   _lêmb, _तनी_, serõ, --, 
   {{0xdb1c9154,0x00000000,0x00000000,0x00000000}},	//   perõ, --, --, --, 
   {{0x63a00eda,0xdb1c0066,0x7f340023,0xdef00023}},	//   aann, ggré, _ኢትዮዽ, ፍኡን_, 
   {{0x63a13787,0x9f440268,0x944400c7,0xe5a001a9}},	//   bann, _innù_, _змаҵ, _шити, 
   {{0x63a13788,0xe3b53789,0x6aa40158,0xedf00ccb}},	//   cann, _обу_, ysjf, چيدگ, 
   {{0x80bc03f4,0xdb1c002d,0xb4dc5572,0xad9808a5}},	//   ্টগ্, rfrû, _तनु_, bjúl, 
   {{0xd37804b9,0x91c4142e,0x7bcc017a,0x78b40306}},	//   _naći_, _чәкл, efbu, kryv, 
   {{0x601c00d8,0x212801e7,0x00000000,0x00000000}},	//   _sême, úcht_, --, --, 
   {{0x5c741422,0x00000000,0x00000000,0x00000000}},	//   клят, --, --, --, 
   {{0x81e000bd,0xd5a40f31,0x00000000,0x00000000}},	//   দার_, _پہ_, --, --, 
   {{0x63a1378a,0x7994e7d9,0x7af82d62,0x6aa403cd}},	//   zann, gbyw, åtta, rsjf, 
   {{0x63a1378b,0xee3c03c6,0xe9dc0030,0xd0bc009e}},	// [1e790] yann, mný_, _skús_, _অনুঘ, 
   {{0xee3c03c6,0x63a1378c,0x9c380a8f,0xd83805f5}},	//   lný_, xann, _опыт_, мэх_, 
   {{0x63a06dc8,0x799401f5,0x93bc0356,0x86500023}},	//   vann, bbyw, _mlăd, _ንኣኻት, 
   {{0xee3c03c6,0x00000000,0x00000000,0x00000000}},	//   nný_, --, --, --, 
   {{0xeb5066a3,0x25707d9d,0x00000000,0x00000000}},	//   _سىڭگ, тқас, --, --, 
   {{0x63a00194,0x02c47863,0x84c400d1,0xdb1c06ea}},	//   uann, ейко, _җәдд, vfrú, 
   {{0xee3c0232,0x6680006c,0xdb1c0036,0x00000000}},	//   kný_, _شیشل, tgré, --, 
   {{0x65783b02,0xee3c04bf,0xd5b8009b,0x00000000}},	//   _uguh, jný_, _осу_, --, 
   {{0xee3c076f,0xdb1d378d,0x212801c3,0xe7cc07b7}},	//   dný_, rgré, àch_, स्थप, 
   {{0x63a032ff,0x93bc0276,0xbc5c001f,0xdb1c0036}},	//   qann, _clăd, _ተፅዕኖ_, sgré, 
   {{0xdb1d378e,0x7ed40116,0x00000000,0x00000000}},	//   sfrú, رزدا, --, --, 
   {{0x9f440240,0xe7cc93c7,0x93bc0356,0xdb1c03b2}},	//   _hanë_, स्तप, _plăg, mfrø, 
   {{0x9f44067d,0xd1b803e6,0xb238008f,0xdb1c0174}},	//   _kanë_, _زانا_, _צענז, lfrø, 
   {{0x9f44067d,0xafe00517,0x00000000,0x00000000}},	//   _janë_, _бошл, --, --, 
   {{0x7e5412e6,0xee3c278a,0x3b08d70d,0xd1f002d3}},	//   _птиц, bný_, чево_, ቃዕቲ_, 
   {{0x13e80729,0xee3c0122,0xbca40597,0x9f440023}},	//   পায়, cný_, _كمبي, _lanë_, 
   {{0x3945378f,0x6e380302,0x4a740b8d,0xa3dc0490}},	// [1e7a0] ços_, _מתקד, тырт, _तसं_, 
   {{0x9f44036e,0xc03c0051,0x3944025c,0x659001a9}},	//   _nanë_, _điệt_, ħos_, қашу, 
   {{0x31b8083c,0x5bdc276a,0xe734011c,0x00000000}},	//   nüzü_, मजीव, неф_, --, 
   {{0xdb1c022c,0x3dc0020c,0x5fcc08dd,0x00000000}},	//   dfrø, ngkw_, त्तल, --, 
   {{0x9f440200,0x8554072d,0x00000000,0x00000000}},	//   _banë_, نیفر_, --, --, 
   {{0xee3c0122,0x93bc054e,0x53353790,0x3744074d}},	//   zný_, _amăr, келт, _пĕлт, 
   {{0xfbd01b61,0xdb1c022c,0x91c40166,0xceb80210}},	//   द्यम, gfrø, вәлл, rzęk_, 
   {{0xee3c00d0,0xa520009d,0x31b80205,0x22b400db}},	//   xný_, _өмсд, düzü_, ردىع_, 
   {{0xee3c278a,0x81e000cc,0x00000000,0x00000000}},	//   vný_, দাং_, --, --, 
   {{0x9f4402e2,0x20d000c6,0x5dd802dd,0x60d000ec}},	//   _kanè_, اتيج, _ﺘﺄﻭﻴ, ازيء, 
   {{0xee3c03c6,0xe29405f5,0x9f44007f,0x93bc0311}},	//   tný_, _зах_, _janè_, _vlăd, 
   {{0x9f44036e,0xe7c41bbb,0x99800055,0xe29800df}},	//   _zanë_, _लाभप, bhiũ_, _זשאר, 
   {{0xee3c0e96,0x9ed40220,0xdda8009d,0x00000000}},	//   rný_, _үміт_, этэл_, --, 
   {{0xee3c0232,0xeea8010b,0x9be438a9,0x3ec80108}},	//   sný_, _етик_, ліск, öttö_, 
   {{0xee3c0232,0x27fc01fb,0xaa640b3b,0x2fdc07c5}},	//   pný_, _đun_, етак, metg_, 
   {{0x2fdc1570,0x9b5802bf,0xaf5000fb,0x705000e5}},	//   letg_, хист_, _инһә, _جنڈا, 
   {{0x49753791,0xfd000117,0xad9808a5,0x00000000}},	// [1e7b0] тлас, _кӯрп, hjúk, --, 
   {{0x29042d2b,0x9f44007f,0x2fdc05d5,0x13e80154}},	//   ćna_, _banè_, netg_, পাড়, 
   {{0x9f440240,0x58840032,0xdcf848a7,0xaaa807f7}},	//   _ranë_, _ҡыра, _قریش_, _छिटक, 
   {{0xdb1c022c,0x2fdc07c5,0x2d88003a,0x84880023}},	//   vfrø, hetg_, ncce_, _ንሰርሕ_, 
   {{0x1b340201,0x8880004b,0x9f440240,0xa91808a5}},	//   _አስተያ, _څیړن, _panë_, _afþv, 
   {{0xe3b0cfc1,0x69dd3792,0x2fdc07c5,0xdb3801d5}},	//   ارش_, leqe, jetg_, _آسیش_, 
   {{0x6728068f,0x92e800c6,0x2fdc07de,0x073400a7}},	//   _ѕαмσ, فريق_, detg_, _ревю, 
   {{0xdb1c0579,0x69dd3793,0xceb8012d,0x00000000}},	//   rfrø, neqe, drę_, --, 
   {{0xe3b0805c,0x9f4402d3,0x0a44001f,0xad9800e4}},	//   _مرض_, _tanë_, _የእስራ, ajúk, 
   {{0x2fdc05d5,0x69dc0240,0x25fc0073,0x9f44013a}},	//   getg_, heqe, ळावी_, _hané_, 
   {{0x69dd3794,0xf07400e5,0x00000000,0x00000000}},	//   keqe, خیوں_, --, --, 
   {{0x9f442a4a,0x69dc014b,0x93bc054e,0xa1840139}},	//   _jané_, jeqe, _umăr, _чыжл, 
   {{0xdf500323,0xd3783421,0x9f440d19,0x2fdc07c5}},	//   _өндө, _daću_, _mané_, betg_, 
   {{0x61e93795,0x9f44020c,0x2d8808e5,0x0c793796}},	//   _hagl, _lané_, acce_, ессы_, 
   {{0xfe4435cb,0x61e93797,0x5e440050,0x601c015d}},	//   _инко, _kagl, _مۆدٕ, _gêma, 
   {{0x61e81574,0x9f4400d2,0x7e8002b1,0x00000000}},	//   _jagl, _nané_, _nēpi, --, 
   {{0x61e93798,0x9f44003a,0xece406d3,0xae54011a}},	// [1e7c0] _magl, _sanè_, _адыл_, _בסקס_, 
   {{0x61e93799,0x7c646ea9,0xe8dc0208,0xdb1c0174}},	//   _lagl, _جاعل, _chực_, lgrí, 
   {{0x9f44020c,0x69dd379a,0x66e00166,0xb9180241}},	//   _bané_, beqe, иофа, _yiyọ_, 
   {{0x61e8bd47,0xdb1d379b,0x2fdc05d5,0xeef4010f}},	//   _nagl, ngrí, zetg_, כמער_, 
   {{0x9f440122,0xe4c08c91,0xdb1c00ae,0x5dd80150}},	//   _dané_, ийци, igrí, _ﺘﺄﻤﻴ, 
   {{0x93bc0276,0x4aa804fb,0xa5040640,0x9f44007f}},	//   _slăb, _تایپ_, теља_, _tanè_, 
   {{0x61e9379c,0x00000000,0x00000000,0x00000000}},	//   _bagl, --, --, --, 
   {{0x61e9379d,0x9f440789,0xad983b7b,0xd4c42f89}},	//   _cagl, _gané_, rjúk, _бөкк, 
   {{0xad981f60,0xe7cc08e6,0x3a200205,0x905400d8}},	//   sjúk, स्वप, _mlkp_, лвиц, 
   {{0x69dc0023,0x61e8adf0,0xb4ac0073,0x4c9400d1}},	//   zeqe, _eagl, कळी_, һимс, 
   {{0x61e82d75,0x2fdc0c86,0x442802a8,0x386801ab}},	//   _fagl, retg_, ɗa_, _mhbr_, 
   {{0x61e9379e,0x93bc0311,0x76400548,0x2fdc04cc}},	//   _gagl, _flăc, nnoy, setg_, 
   {{0x9cc9379f,0x00000000,0x00000000,0x00000000}},	//   кыра_, --, --, --, 
   {{0x69dc014b,0x786000d7,0x00000000,0x00000000}},	//   weqe, dôvo, --, --, 
   {{0xfbd0726e,0x69dd03e0,0x61e937a0,0x76400162}},	//   द्धम, teqe, _yagl, knoy, 
   {{0x2ca800f2,0x61e80067,0x7d1403b2,0x00000000}},	//   pscd_, _xagl, ígsá, --, 
   {{0x69dd37a1,0xda7800ee,0x5fcc0b98,0x9f44013a}},	// [1e7d0] reqe, тяр_, त्वल, _rané_, 
   {{0x69dc01f0,0x9f440129,0x00000000,0x00000000}},	//   seqe, _sané_, --, --, 
   {{0xa6441de0,0x25fc0574,0xdce40327,0xd7c801e2}},	//   پخان, ळाली_, _ifiġ, ضونه_, 
   {{0x69dc9870,0xfb180375,0xd6d80395,0x00000000}},	//   qeqe, _נורמ, ъту_, --, 
   {{0xe8dc01dc,0x316537a2,0x61e937a3,0xf8b401c0}},	//   _thực_, _nzoz_, _ragl, _бөх_, 
   {{0x61e937a4,0xe7840364,0x7e8002b1,0x9f441bce}},	//   _sagl, _шумо, _wēpi, _wané_, 
   {{0x61e810c7,0x7e800093,0x9f4400e8,0x425537a5}},	//   _pagl, _tēpi, _tané_, лтит, 
   {{0x93bc084c,0x6ce0000d,0x00000000,0x00000000}},	//   _plăc, गबाग_, --, --, 
   {{0x61e937a6,0x95c937a7,0xd1cc0092,0xdb1c03b2}},	//   _vagl, _шура_, _በኤች_, vgrí, 
   {{0x61e937a8,0x47e0009e,0xc00400f3,0x21640116}},	//   _wagl, নাকী, упок, ниқи_, 
   {{0x61e937a9,0x0d440020,0x2ba40034,0x6e906f51}},	//   _tagl, _ያስፈል, _औज़ा, یلیا, 
   {{0x80f40066,0x00000000,0x00000000,0x00000000}},	//   _مستض, --, --, --, 
   {{0x518537aa,0x644137ab,0x225c56f8,0x212801c3}},	//   _туха, onni, mluk_, ùchd_, 
   {{0x225d37ac,0x69c800db,0x28a400bc,0x00000000}},	//   lluk_, ògen, गठनि, --, 
   {{0x644137ad,0x225c011f,0x68f8031c,0xcb1401ec}},	//   inni, oluk_, _ġuda, афты, 
   {{0x6e900597,0x5fcd37ae,0x225d37af,0x7e80003a}},	//   _اليا, त्रल, nluk_, _cœpe, 
   {{0x225c005a,0x5fa4033f,0xdb1c002f,0x00000000}},	// [1e7e0] iluk_, _ग़ाल, lfrü, --, 
   {{0x225d37b0,0x3a20012d,0xdd9000f1,0xdb2400e5}},	//   hluk_, _wlkp_, _اوښ_, _نوخی, 
   {{0x225d37b1,0xda740075,0x644000f3,0xdb1d37b2}},	//   kluk_, _نۇسخ, dnni, nfrü, 
   {{0x644137b3,0x3c24002d,0x225d37b4,0xe9dc1d0e}},	//   enni, _dôve_, jluk_, _hjún_, 
   {{0x764137b5,0xb4ac0073,0x00000000,0x00000000}},	//   rnoy, कळे_, --, --, 
   {{0x764137b6,0xf2c40032,0x644004cc,0xdb1c00cf}},	//   snoy, гсин, gnni, ogrà, 
   {{0x47580276,0xa0840220,0x225c0165,0x42a401e0}},	//   _артя_, қсыз_, fluk_, ауығ, 
   {{0x64400ad4,0x7af802f6,0x225c020c,0xa52000fd}},	//   anni, ätty, gluk_, рмәд, 
   {{0x64400198,0x24b40014,0x75440114,0xd010007b}},	//   bnni, _مۆنگ_, _сназ, قلة_, 
   {{0x225c3331,0x054400fb,0x00000000,0x00000000}},	//   aluk_, _әүәл_, --, --, 
   {{0x9f44145e,0x225d37b7,0xa8540375,0x0a300092}},	//   _wanî_, bluk_, רייה_, _በዙሪያ, 
   {{0x506402dd,0xb14401af,0x00000000,0x00000000}},	//   ытқа, _йнел, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa2a80490,0xad240046,0x0ec4012d,0x00000000}},	//   ींच्, _ەردو, लंदड, --, 
   {{0xd1cc001f,0x656c2b57,0x9e2400db,0xa0340115}},	//   _በቤተ_, _úchv, _گىيو, _תאוה_, 
   {{0x29680131,0x9a847577,0xddc403e0,0x00000000}},	//   ﻳﯩﭽﻪ_, сурл, _ikiş, --, 
   {{0x644137b8,0xa91801a8,0x8858009d,0xb3440205}},	// [1e7f0] ynni, _afþr, виас_, lkçı, 
   {{0x9f4408e5,0x225c509e,0xc0c80023,0xdb1c08a5}},	//   _innò_, zluk_, ጽኣሉ_, gfró, 
   {{0xd7c937b9,0x58d402dd,0x98480395,0xb34403b9}},	//   اومه_, _қорт, уята_, nkçı, 
   {{0x7af8019b,0x45d4453f,0xad980124,0x98a00165}},	//   ætte, родс, ajúv, uziă_, 
   {{0x56940364,0x225c0e3c,0xa9040014,0x03a400f3}},	//   _ҳаст, vluk_, _صبحن, аило, 
   {{0x644137ba,0x2280002d,0xdb1c0553,0xf494014d}},	//   unni, _lűke_, lgrá, جپوت_, 
   {{0xdb1c5178,0xb9d00020,0x9f440268,0x225d37bb}},	//   ográ, _ሴት_, _canì_, tluk_, 
   {{0xc0f84be7,0xe1fc09c2,0x64400194,0x225c011f}},	//   _ገብረ_, ñó_, snni, uluk_, 
   {{0x225d37bc,0xdd140030,0x29180784,0x1b0c015b}},	//   rluk_, kúša, nyqa_, _হইছে_, 
   {{0x225d37bd,0x70508b4d,0xe8dc004d,0xb1800267}},	//   sluk_, ينيا, _giục_, ååri, 
   {{0x44244f7f,0x6d5d26ba,0x9f44c375,0x41b4027d}},	//   _ill_, _ayqa, _annò_, _نمار, 
   {{0x442412c6,0x4154c03b,0xdb1c0b70,0x00000000}},	//   _hll_, _квес, rfrü, --, 
   {{0x00e401b9,0xddc40432,0xdb1c0112,0xca7c022e}},	//   _ختای, _ekiş, sfrü, аzоr, 
   {{0x7e800270,0x6d5c02d3,0x69380092,0xbf340214}},	//   _sēpu, _dyqa, _በመጋቢ, _پرتغ, 
   {{0xfaa477f7,0x44240415,0x26c40137,0x7e800374}},	//   рабо, _mll_, ànol_, _pēpu, 
   {{0xceb8068f,0x6da00116,0x6b7400c7,0x00000000}},	//   rzęt_, _диъа, шәыс_, --, 
  
   {{0x442537be,0xe0d002f5,0x9f440407,0x940400ac}},	// [1e800] _oll_, ়িকভ, _maní_, _etmə_, 
   {{0x442537bf,0xad1800df,0x00000000,0x00000000}},	//   _nll_, _סויר, --, --, 
   {{0xddc4054e,0x93bc054e,0x98a0033f,0x00000000}},	//   _ghiţ, _blăn, dzią_, --, 
   {{0x44240d65,0xfbd01b61,0x00000000,0x00000000}},	//   _all_, द्रम, --, --, 
   {{0x261400d8,0x7a2800a2,0x00000000,0x00000000}},	//   _aços_, _aýtg, --, --, 
   {{0x1418007b,0x00000000,0x00000000,0x00000000}},	//   طيبة_, --, --, --, 
   {{0x44240334,0x63001b06,0x7af80158,0x9f4400d7}},	//   _dll_, قوول, åtth, _baní_, 
   {{0x442537c0,0x9f443edd,0x366857c6,0x00000000}},	//   _ell_, _caní_, _рабо_, --, 
   {{0x9f440122,0x44243619,0xe5d801e1,0xa3dc01f9}},	//   _daní_, _fll_, _àsáá, _तसच_, 
   {{0x16040490,0x00000000,0x00000000,0x00000000}},	//   ळावर_, --, --, --, 
   {{0xf2041e76,0x0a44001f,0x5fb40d0d,0xdb1c0388}},	//   _вяло, _የብሔራ, _आयरल, lgræ, 
   {{0x261403e3,0x00000000,0x00000000,0x00000000}},	//   _uçot_, --, --, --, 
   {{0x44240023,0x6d5c036e,0xe7c400bc,0x00000000}},	//   _yll_, _qyqa, _लालप, --, 
   {{0xcef807d6,0x28b40034,0xceb80032,0xac7402d3}},	//   _مفتش_, ेंसि, _йәм_, በረሎም_, 
   {{0x9f300046,0xdd1400d7,0x00000000,0x00000000}},	//   _меші, rúša, --, --, 
   {{0x99d42160,0x7d00005f,0xad24187c,0xdd1400d7}},	//   يتقا, _šose, _نرخو, súša, 
   {{0x6d5c022e,0x00000000,0x00000000,0x00000000}},	// [1e810] _uyqa, --, --, --, 
   {{0x7a280209,0x6b80063f,0x93bc054e,0xdb1c01bf}},	//   _aýtd, ọgbu, _slăn, dgræ, 
   {{0x1cc4031c,0x93bc054e,0x442401f4,0x00000000}},	//   _ཌའོ_, _plăn, _rll_, --, 
   {{0x3f7800c8,0x9f44011f,0x00000000,0x00000000}},	//   אָנע, _yanâ_, --, --, 
   {{0x24e537c1,0xa490380e,0xdb1c6a39,0x00000000}},	//   рцег, زیات, ggræ, --, 
   {{0x9f44a646,0x4424011c,0x00c801b9,0x00000000}},	//   _janã_, _qll_, ҳлик_, --, 
   {{0x9f44012c,0x442417da,0x28b401ad,0x00000000}},	//   _paní_, _vll_, ेंवि, --, 
   {{0xe61c00c6,0xddc4151c,0x44240036,0x00c801b9}},	//   _ôô_, _ohiš, _wll_, глик_, 
   {{0x26d0009d,0x41040aac,0x9f440419,0x250801e2}},	//   ltxo_, ёзов, _vaní_, _ګرځی_, 
   {{0x442537c2,0x00000000,0x00000000,0x00000000}},	//   _ull_, --, --, --, 
   {{0x26d001c0,0x929400c7,0xc10400f2,0x7a28010e}},	//   ntxo_, _дахц, _گوشي, _uýtg, 
   {{0x81b003f4,0xfce40e92,0x27f001ab,0x91f400ae}},	//   ঞ্জ_, бомо, hdxn_, _وأنا, 
   {{0xee3537c3,0x9f440589,0xc10401f7,0x00000000}},	//   сня_, _banã_, _دوشي, --, 
   {{0x7a2801ef,0xcee800ec,0x00000000,0x00000000}},	//   _mýte, _چرين_, --, --, 
   {{0xeb9537c4,0x93380023,0x7a2801ef,0x00000000}},	//   сис_, _እንተታ, _lýte, --, 
   {{0x9b8800f1,0x00000000,0x00000000,0x00000000}},	//   انځل_, --, --, --, 
   {{0x7a2803b2,0xde4800f2,0xa3e41be1,0xad980162}},	// [1e820] _nýte, _میگو_, यजा_, rjút, 
   {{0x81b00c58,0x9f440109,0x00000000,0x00000000}},	//   ঞ্চ_, _kanà_, --, --, 
   {{0x7a2800a2,0xf7701291,0x00000000,0x00000000}},	//   _aýte, سائ_, --, --, 
   {{0x9f440c86,0x98a005be,0xdb1c01bf,0x28b4012d}},	//   _manà_, jzić_, tgræ, ेंशि, 
   {{0x98a0068f,0x2800012c,0xb270134b,0x00000000}},	//   dzić_, ární_, үклә, --, 
   {{0xe3ac3ee0,0xdb1c62b4,0x2bd83599,0x00000000}},	//   ىرى_, rgræ, म्पा, --, 
   {{0xdb1c01bf,0x27e4000d,0xa3e40210,0x00000000}},	//   sgræ, õnne_, यज़_, --, 
   {{0x741400ec,0x00000000,0x00000000,0x00000000}},	//   _ڏورا, --, --, --, 
   {{0x0f2013b4,0xc4c4007b,0xdb1c01e3,0x00000000}},	//   मन्स_, _وتكو, lgrä, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe0ccd653,0xa1540220,0xdb1c6ed3,0x84540137}},	//   وزی_, _қашу_, ngrä, _بىلچ, 
   {{0xddc41ebd,0x7984009a,0xb638037e,0x2bd829c7}},	//   _phiš, _ngkw, _ｆｍ_, म्ना, 
   {{0x3c240109,0x0e640c75,0x25d4008f,0x00000000}},	//   _sôva_, йкүн, זוכן_, --, 
   {{0x798402d0,0xdb1c0036,0x357c0023,0xab600205}},	//   _agkw, kgrä, እስታት_, şüms, 
   {{0x9a842063,0x847802d3,0xa0380375,0x66e4012d}},	//   зуул, ክእሉን_, _תעופ, _टैंक_, 
   {{0x7af80436,0x2e4802e8,0xdb1c01e3,0x3c240051}},	//   ætta, _щяло_, dgrä, _vôva_, 
   {{0x481537c5,0xeb300137,0x00000000,0x00000000}},	// [1e830] омас, زۉڭد, --, --, 
   {{0xfba816d1,0xdb1c0036,0x9f44013a,0x2b44009d}},	//   करणम, fgrä, _haná_, _гэмг, 
   {{0xd7f8010b,0x9f440241,0x93bc0356,0x6f0c0112}},	//   щут_, _kaná_, _clăm, äbch, 
   {{0x26d001c6,0xe9dc032e,0x25a81c3e,0xee3c0432}},	//   rtxo_, _mjúk_, اداي_, niý_, 
   {{0x9f4537c6,0x69cc031c,0x231400f7,0x26d0009d}},	//   _maná_, _icce, өндө_, stxo_, 
   {{0x93bc054e,0x68ec035a,0x3d0800dc,0x9f4400d0}},	//   _flăm, _iscd, ामते_, _laná_, 
   {{0x2bd937c7,0xee3c010b,0x00000000,0x00000000}},	//   म्या, kiý_, --, --, 
   {{0xc1040472,0x7c600092,0x00000000,0x00000000}},	//   قوبي, ደረሰው_, --, --, 
   {{0x98a09358,0x9f4405d5,0x410402bf,0x25ac05d5}},	//   rzić_, _sanà_, ізов, magl_, 
   {{0x25ac05d5,0x2bd82894,0xdb1c01e3,0x00000000}},	//   lagl_, म्मा, mfrö, --, 
   {{0x8478044e,0x69cd37c8,0x91a803d4,0x232411ca}},	//   ክእልን_, _occe, _গাৰ্, _уфаг, 
   {{0x69cc003a,0x25ac04cc,0xdb1c003b,0xdce400de}},	//   _ncce, nagl_, ngrå, _aziā, 
   {{0x2eec01fa,0x9f4402fb,0x2bd839c5,0x3d080073}},	//   _esff_, _daná_, म्भा, ामधे_, 
   {{0x02dc08ec,0x9f4406d9,0x25ac0158,0xbea4074d}},	//   _महाभ, _tanà_, hagl_, _дакк, 
   {{0xee3c00a2,0xdb1c007c,0x920800ef,0x00000000}},	//   biý_, xgrä, brāķ, --, 
   {{0x2bd821b8,0x9f440789,0xdb1c007c,0x00000000}},	//   म्बा, _ganá_, vgrä, --, 
   {{0xe8f405f5,0x1cc4025c,0xd8840214,0xda2800db}},	// [1e840] олт_, _ཌའི_, سهای, _ۇيدۇ_, 
   {{0x69cc43df,0xdb1c01e6,0x201000db,0x93bc054e}},	//   _ecce, tgrä, _òxid_, _plăm, 
   {{0x2810075e,0xf984023a,0x68ec02d0,0x00000000}},	//   بولس, _мгно, _escd, --, 
   {{0x7afc0054,0x2b140316,0x25ac05d5,0xdb1d37c9}},	//   _irpt, नहरु_, gagl_, rgrä, 
   {{0xdb1c5b00,0x95c801e0,0x25fc01f9,0x00000000}},	//   sgrä, ауҙа_, ळाजी_, --, 
   {{0xb6a402e8,0xdb1c007c,0xad9808a5,0x00000000}},	//   _мигл, pgrä, hjúp, --, 
   {{0x55540050,0x795003e6,0xdb240166,0x00000000}},	//   _کھار, _عێڕا, _üsäl, --, 
   {{0xe6c0009f,0x00000000,0x00000000,0x00000000}},	//   _آڪلي, --, --, --, 
   {{0xfdec0034,0x7bdc0393,0x20c001c0,0xe9dc0bcd}},	//   ज़नस_, _obpu, мсэг, _sjúk_, 
   {{0xf3c8021a,0x7bdc017a,0xd370237e,0x7afc03ac}},	//   _خبره_, _nbpu, _كۇش_, _orpt, 
   {{0xe29537ca,0x25fc0490,0x9f440248,0x7c2c0332}},	//   _дах_, ळाची_, _paná_, dhbr, 
   {{0x7bdd37cb,0xdd94013d,0xab600205,0x00000000}},	//   _abpu, маюы, şüks, --, 
   {{0xe0cc0014,0x437000f7,0x00000000,0x00000000}},	//   _لٲن_, _قۇۇر, --, --, 
   {{0xad980124,0xd010b1d7,0x7c2c045a,0x00000000}},	//   ajúp, _سلب_, ghbr, --, 
   {{0x9f440241,0x271c0154,0x00000000,0x00000000}},	//   _taná_, _যেনো_, --, --, 
   {{0x9b5937cc,0xe7082e3e,0x00000000,0x00000000}},	//   цист_, یتان_, --, --, 
   {{0xab8400a8,0x25ac0c86,0x58d40137,0xe89400e5}},	// [1e850] _мунк, vagl_, мотт, زماں_, 
   {{0x7c2d37cd,0x1ce0025c,0xdb1c000f,0x00000000}},	//   chbr, _ྤྱི_, ngrû, --, 
   {{0x98ac00da,0x7afc010a,0x25ac07de,0xfbd0011a}},	//   ālās_, _grpt, tagl_, _אתי_, 
   {{0x69cd37ce,0xdd1400d0,0x3af8010f,0xd61800ae}},	//   _ucce, súťa, _פּיע, يتنا_, 
   {{0xe9dc0248,0x09b0015b,0xa3e4033f,0x25ac07c5}},	//   _ibú_, _ছাপা, यजल_, ragl_, 
   {{0x3e700232,0x32040280,0xe8dc01fb,0x25ac07c5}},	//   máte_, _anoy_, _nhức_, sagl_, 
   {{0x2bd00562,0x3e700122,0x62540798,0x977c030d}},	//   _ताना, láte_, mãoz, _вутă_, 
   {{0x42080063,0xbea40022,0x00000000,0x00000000}},	//   снио_, ҟамк, --, --, 
   {{0xd5b82bbd,0x3e7002fb,0xe9dc01e1,0xc104009f}},	//   _фсс_, náte_, _mbú_, سودي, 
   {{0xe8dc07ae,0x3204003e,0x00000000,0x00000000}},	//   _chức_, _enoy_, --, --, 
   {{0x7a281d1d,0x3e70022a,0xbd88006c,0xe9dc00d7}},	//   _lýta, háte_, ینگن_, _obú_, 
   {{0xfe705167,0xfce410f5,0xee34188c,0x3e70219b}},	//   عدد_, помо, зню_, káte_, 
   {{0x7c2d37cf,0x7a280436,0x70741b12,0x6d200276}},	//   thbr, _nýta, تمیز_, едяз, 
   {{0xeb9537d0,0x3e700232,0x31780302,0xe9dd37d1}},	//   зир_, dáte_, _פרסמ, _abú_, 
   {{0x200537d2,0xab241dde,0x7a28010e,0x3d0800dc}},	//   _inni_, пора_, _aýta, ामहे_, 
   {{0x7c2c0857,0x7a280174,0x63a0003e,0xd910397a}},	//   shbr, _býta, hbnn, پیس_, 
   {{0xa3b80882,0xe8fc0129,0x37e40154,0x3e7000d7}},	// [1e860] _अयं_, _crû_, নাঘর, gáte_, 
   {{0x625400d8,0xdb1c0142,0x7afc00b8,0x00000000}},	//   gãoz, ffrô, _trpt, --, 
   {{0x63a0003e,0xce340214,0x7afc06be,0xc5f40154}},	//   dbnn, _رویک, _urpt, ছানা_, 
   {{0xf48400d8,0x3e700ca8,0x00000000,0x00000000}},	//   пукн, báte_, --, --, 
   {{0x200537d3,0x3668039b,0x2bd00316,0xf4c401e1}},	//   _onni_, _ҳаво_, _तामा, _ṣọdọ, 
   {{0x7bcd37d4,0xc8b40014,0x78b403b2,0xa3f00150}},	//   ngbu, _زلفک, msyv, епші, 
   {{0x66e137d5,0x533537d6,0x3204079b,0x68f80003}},	//   _пора, ьект, _pnoy_, _ġudi, 
   {{0x200537d7,0x90984c6b,0x7994127b,0x00000000}},	//   _anni_, овит_, ncyw, --, 
   {{0x7c3c14dc,0xe8dc001e,0x78b40006,0x09b0009e}},	//   _ompr, _phức_, nsyv, _ছামা, 
   {{0x75200223,0x764001f7,0xe3b53005,0xdb1c002d}},	//   myoz, lioy, _нбу_, ugrû, 
   {{0x9f44006a,0xb8fc0003,0x752000dd,0xdb1d37d8}},	//   _nanä_, _རཱ_, lyoz, rgrû, 
   {{0x200537d9,0x7c3d37da,0x76400113,0x2eb40014}},	//   _enni_, _ampr, nioy, _ہَتھ_, 
   {{0x752137db,0xe8dc07ae,0x40f00124,0xd7cca9ec}},	//   nyoz, _thức_, _аҧыр, ालाच, 
   {{0x68f80261,0x3e7000bc,0xc1700132,0x7bcc248f}},	//   _áudi, váte_, _جگىت, ggbu, 
   {{0x75200369,0xf99802e3,0x5fd80375,0x7640030a}},	//   hyoz, _ọpụp, _החוק, kioy, 
   {{0x3e7137dc,0x7a2801f1,0x9f4537dd,0x27fc20b2}},	//   táte_, _pýta, _sanç_, _şun_, 
   {{0x200400a9,0x1dd82361,0x48181468,0x7af80158}},	// [1e870] _ynni_, _ربيع_, ожаю_, åttr, 
   {{0x3e7002fb,0x7a2800bc,0x601c00d8,0xefcc0023}},	//   ráte_, _výta, _fêmu, ኣትዉ_, 
   {{0x45d40108,0x00000000,0x00000000,0x00000000}},	//   доес, --, --, --, 
   {{0xd7740c75,0x7520007f,0xe9dc0241,0xa3dc2c30}},	//   رالع, fyoz, _ubú_, ध्न_, 
   {{0x7c3d37de,0x7520df45,0xb4b40139,0x986800e5}},	//   _ympr, gyoz, дичә, _کیلے_, 
   {{0x9f44013d,0x00000000,0x00000000,0x00000000}},	//   _yanä_, --, --, --, 
   {{0x3164022e,0x75201418,0x7a280306,0x9f440166}},	//   _ayoz_, ayoz, _mýtn, _xanä_, 
   {{0x02dc2007,0x12c42928,0xd5b8009b,0x00000000}},	//   _महीन, رتىپ, _нсу_, --, 
   {{0x43941c3e,0x7bcc007c,0x44f4010a,0x00000000}},	//   _жазс, ygbu, _юпас, --, 
   {{0x661937df,0x2d9c005a,0x7a2802d2,0x00000000}},	//   _houk, ñuen_, _nýtn, --, 
   {{0x661937e0,0x271c00eb,0x00000000,0x00000000}},	//   _kouk, _যেতো_, --, --, 
   {{0x661937e1,0x92b400c6,0x78b40022,0x2bd8024a}},	//   _jouk, _أحلا, ysyv, म्सा, 
   {{0x644050c8,0x225c0441,0x661937e2,0xdb1c03cd}},	//   oini, mouk_, _mouk, lgrø, 
   {{0x644137e3,0x3b0834d8,0x225d37e4,0x200537e5}},	//   nini, оего_, louk_, _unni_, 
   {{0x75200007,0xa3dc0da5,0xdb1d37e6,0x7074007b}},	//   zyoz, ध्य_, ngrø, _تموز_, 
   {{0x661937e7,0x3cf00109,0x7c3d37e8,0xe9dc0241}},	//   _nouk, _tsyv_, _wmpr, _ojúu_, 
   {{0x644137e9,0x2bd83a19,0x7e740fec,0xb178008f}},	// [1e880] kini, म्हा, _ihyp, ַטער, 
   {{0x644137ea,0x7c3c016c,0x225c0085,0x752000ec}},	//   jini, _umpr, houk_, vyoz, 
   {{0x6618cd62,0x76400481,0x225c007f,0xdce4012d}},	//   _bouk, tioy, kouk_, _dzią, 
   {{0xdb1c0ac7,0x75200223,0x754400a8,0x644137eb}},	//   dgrø, tyoz, мнез, eini, 
   {{0x661937ec,0x75200083,0x7e7402f0,0x2bd8095f}},	//   _douk, uyoz, _mhyp, म्वा, 
   {{0x752137ed,0xdb1c01bf,0xe8dc0051,0x00000000}},	//   ryoz, fgrø, _giốc_, --, 
   {{0x661937ee,0x7e7400c7,0xdb1c95a6,0x91c401e0}},	//   _fouk, _ohyp, ggrø, еҙел, 
   {{0x644137ef,0x661804ce,0x50f45211,0x273001ec}},	//   aini, _gouk, езит, _شىقس, 
   {{0x644137f0,0x60f402d5,0x25d4010f,0x00000000}},	//   bini, дныя_, _קומן_, --, 
   {{0x7e7400e4,0x661937f1,0x64401fd8,0x00000000}},	//   _ahyp, _zouk, cini, --, 
   {{0x661804ce,0x69c00134,0x225d37f2,0x7a28013a}},	//   _youk, ɔnef, bouk_, _nýto, 
   {{0x26c4098d,0x60e401e6,0x7e7537f3,0x00000000}},	//   šnog_, örmå, _chyp, --, 
   {{0x03f0015b,0x2bd021f2,0x9d14003b,0x00000000}},	//   চারী_, _तादा, вдяч, --, 
   {{0x20501945,0xef9002f2,0x00000000,0x00000000}},	//   _үтәр, _جیدد, --, --, 
   {{0x9f440421,0x606000ec,0x00000000,0x00000000}},	//   _manû_, _جهول, --, --, 
   {{0x64408062,0x3e5400da,0xda780276,0x00000000}},	//   zini, tāte_, дяу_, --, 
   {{0x644137f4,0x9a8423c9,0x5d540724,0xa3c00254}},	// [1e890] yini, турл, _икът, ्लम_, 
   {{0x661937f5,0xfbc402f5,0x644137f6,0xd3640137}},	//   _souk, শ্বত, xini, _نۇ_, 
   {{0x661937f7,0x02dc190c,0xceb8033f,0x3e7137f8}},	//   _pouk, _महेन, nsę_, láta_, 
   {{0x644137f9,0x2bd807af,0xdce40034,0x28c40d2e}},	//   wini, म्रा, _wzią, _लिपि, 
   {{0x644137fa,0x6618004c,0xd49801e0,0x290c01e3}},	//   tini, _vouk, үрә_, ågad_, 
   {{0x644020ac,0x661937fb,0x82f41bc4,0x225c02e2}},	//   uini, _wouk, ечиц, wouk_, 
   {{0x661937fc,0x3e7026d3,0x00000000,0x00000000}},	//   _touk, háta_, --, --, 
   {{0x3e7137fd,0x00000000,0x00000000,0x00000000}},	//   káta_, --, --, --, 
   {{0x25bc6368,0x7fd40220,0x6d48341a,0xdce41710}},	//   _idul_, ніні, _žgan, _izić, 
   {{0x644137fe,0x249d37ff,0x3e713800,0x93bc054e}},	//   qini, _itum_, dáta_, _slăv, 
   {{0xfe451d70,0x00000000,0x00000000,0x00000000}},	//   енно, --, --, --, 
   {{0xe9dc0162,0xe50004af,0x00000000,0x00000000}},	//   _mjús_, लिपि_, --, --, 
   {{0x61f84460,0x3e7046dc,0x7a280419,0x00000000}},	//   mdul, gáta_, _sýto, --, 
   {{0x60d93801,0x61f93802,0x9f445a58,0x41d40490}},	//   mtum, ldul, _manú_, _धाडस, 
   {{0x60d93803,0x7e7402ea,0x61f80254,0xe81009ab}},	//   ltum, _thyp, odul, ठाना_, 
   {{0x61f8535e,0x3e70673f,0x7a2802fb,0x25bc01e7}},	//   ndul, báta_, _výto, _ndul_, 
   {{0x60d93804,0x249c003a,0xbd453805,0x61f93806}},	// [1e8a0] ntum, _ntum_, _سپدى, idul, 
   {{0x60d93807,0x25bd3808,0xc7640131,0x61f93809}},	//   itum, _adul_, ھالى, hdul, 
   {{0x60d8102e,0x249c3d27,0x61f822d0,0x290c01e6}},	//   htum, _atum_, kdul, ägar_, 
   {{0x60d9380a,0x61f80841,0xe9dc0a87,0xd9040166}},	//   ktum, jdul, _djús_, _иҗбо, 
   {{0x249c0393,0x61f9380b,0x7e800393,0xb884032e}},	//   _ctum_, ddul, _cœpi, gaíþ, 
   {{0x9f449655,0x60d8002f,0xa29001d3,0xc62000fe}},	//   _danú_, dtum, گجوؤ, পোলা_, 
   {{0xa3b4e647,0x2bd053b7,0xa3dc01ad,0xe85001b9}},	//   راور_, _तासा, ध्ध_, _صنفد, 
   {{0x93bc084c,0x61f90161,0x28c4216a,0x30a428a8}},	//   _alăt, gdul, _लिमि, нров, 
   {{0x60d86129,0x9054399f,0x00000000,0x00000000}},	//   gtum, квиц, --, --, 
   {{0xdd95367e,0x61f80548,0xa3dc3874,0x93bc054e}},	//   ғары, adul, ध्द_, _clăt, 
   {{0x61f9380c,0x71a47ffd,0x7a280209,0xd1e4215c}},	//   bdul, _заез, _aýtm, _لياۋ, 
   {{0x09e402f5,0x60d80009,0x3e7000e4,0x23480066}},	//   _পোনা, btum, táta_, _عسلی_, 
   {{0x60d81730,0x7a2802fb,0xe81000bc,0xa1800354}},	//   ctum, _výtl, ठामा_, _йышл, 
   {{0x3e705956,0x2210008e,0x6c3001d3,0x03b00055}},	//   ráta_, _афәр, اہدا, _klūṃ_, 
   {{0x3e71380d,0xdb580b32,0x00000000,0x00000000}},	//   sáta_, еют_, --, --, 
   {{0x7e640124,0x3e7000c7,0x6a1400f2,0x48c40166}},	//   _ихыҵ, páta_, ربزر, кәга, 
   {{0x1958abba,0x00000000,0x00000000,0x00000000}},	// [1e8b0] еаты_, --, --, --, 
   {{0x61f801ed,0x3e5400e2,0x32d800e8,0x2c04012d}},	//   zdul, māta_, këy_, शाओं_, 
   {{0x249d380e,0x61f9380f,0xc5d4160b,0x88a004d3}},	//   _stum_, ydul, віль, _چیرۆ, 
   {{0xd6d80006,0x8a600345,0x00000000,0x00000000}},	//   эту_, _ئێرۆ, --, --, 
   {{0x3e5400da,0x56940032,0x92e00c58,0x2570504c}},	//   nāta_, _ҡарт, ধটো_, уқас, 
   {{0x03b000b8,0xd7f8084c,0xa6100075,0x588401e0}},	//   _blūṃ_, _пус_, _өзгә, _быса, 
   {{0xdce4006d,0xd56423c9,0xb3d00574,0x425414a4}},	//   _dzię, ктәп, _सारख, ктит, 
   {{0x60d93810,0x7af81f60,0x00e50ed7,0x25bc003e}},	//   ttum, ætti, вжин, _udul_, 
   {{0x21293811,0x61f93812,0x60d8049b,0x93bc084c}},	//   ách_, rdul, utum, _plăt, 
   {{0x60d93813,0x90e50696,0x3e5400e2,0x216400d1}},	//   rtum, اسين, dāta_, миқи_, 
   {{0x11e40150,0x00000000,0x00000000,0x00000000}},	//   _әжім, --, --, --, 
   {{0x60d93814,0xfcc40156,0x00000000,0x00000000}},	//   ptum, གངཅཆ, --, --, 
   {{0xd1b93815,0x60d80cfe,0xee3518cd,0x628803ac}},	//   _سانا_, qtum, тня_, _iigo, 
   {{0x62893816,0x44e8003a,0xa3c00b6d,0x00000000}},	//   _higo, iº_, ्लि_, --, 
   {{0x62889858,0x2bd02886,0x48d000fe,0x6e90009b}},	//   _kigo, _तारा, হবোৰ, _кију, 
   {{0x62893817,0x3e5400de,0x00000000,0x00000000}},	//   _jigo, bāta_, --, --, 
   {{0xf1b004ac,0x78653818,0xca7401c6,0xdb1c0112}},	// [1e8c0] יסן_, вказ, ууры, lgrü, 
   {{0x62893819,0x656c0122,0xecb40a1e,0xb90821b8}},	//   _ligo, _úchy, _שפיץ_, _मह_, 
   {{0xbd44765c,0x6288067c,0xdb1d12c5,0xfaa40845}},	//   _سنگي, _oigo, ngrü, _шано, 
   {{0x6289381a,0x00000000,0x00000000,0x00000000}},	//   _nigo, --, --, --, 
   {{0x7a280306,0x00000000,0x00000000,0x00000000}},	//   _lýtk, --, --, --, 
   {{0x6289381b,0x9f4494f0,0x3e7000d0,0x32d8002e}},	//   _aigo, _fanø_, káto_, tëy_, 
   {{0x6289381c,0xdb1c03b2,0x91c4008e,0x00000000}},	//   _bigo, mgró, гәлл, --, 
   {{0xf50402d7,0xdce40034,0x93bc0356,0x00000000}},	//   _избо, _wzię, _plăs, --, 
   {{0x6289381d,0x2bd03885,0xad980789,0x34840139}},	//   _digo, _ताला, ndúe, _агаг, 
   {{0xc0f002d3,0x6289381e,0xdb1d381f,0x3e5400e2}},	//   ሃህላ_, _eigo, ngró, vāta_, 
   {{0x62893820,0xdb1c002f,0xe1ec01af,0x1f7001f4}},	//   _figo, ggrü, _кѳ_, илья, 
   {{0xb1453821,0x71a402d5,0x3e5400e2,0x23240c60}},	//   _инел, _радз, tāta_, _шохи_, 
   {{0xecc40801,0x9d18661d,0x601c00d8,0x09b000eb}},	//   ъщно, воят_, _têmp, _ছালা, 
   {{0x62893822,0x5f913823,0x3e541c52,0x00000000}},	//   _zigo, _кишт, rāta_, --, 
   {{0x62893824,0xeda4010a,0x00000000,0x00000000}},	//   _yigo, _ишпо, --, --, 
   {{0x62893825,0x05d0012d,0x00000000,0x00000000}},	//   _xigo, _हाइब, --, --, 
   {{0xb3d06c8e,0x497428af,0x6b4001a9,0x9980110c}},	// [1e8d0] _सांख, улас, _dеga, tkiš_, 
   {{0x5bb93826,0x8af81cd0,0x00000000,0x00000000}},	//   _илья_, _знос_, --, --, 
   {{0x58853827,0xad24024e,0x99800e04,0xa3c00073}},	//   рыта, _سرکو, rkiš_, ्लस_, 
   {{0xdbe406af,0xdb1c00ae,0xb0c00a8a,0x00000000}},	//   _rééq, agró, _शिंग, --, 
   {{0xfa3401ec,0x7af80174,0xb63001e1,0x00000000}},	//   _сүті_, ættv, _ńṣor, --, 
   {{0x62893828,0x437400f5,0x00000000,0x00000000}},	//   _sigo, луйт, --, --, 
   {{0xb6c0010b,0xd6d80408,0x00000000,0x00000000}},	//   _гөчд, _итт_, --, --, 
   {{0xc1b80597,0x2bc000dc,0xdb1c002f,0x00000000}},	//   رابط_, वृता, vgrü, --, 
   {{0x62893829,0x0a44001f,0x00000000,0x00000000}},	//   _vigo, _ከእስራ, --, --, 
   {{0x6289382a,0xddc400bc,0xdb1c0112,0x20d400d7}},	//   _wigo, _zmiň, tgrü, jžiš_, 
   {{0x6289382b,0xdce803e0,0xdb1c002f,0x00000000}},	//   _tigo, _ılım, ugrü, --, 
   {{0x23dc5572,0xa3dc298e,0xdb1c03fa,0x62880393}},	//   प्रद, ध्र_, rgrü, _uigo, 
   {{0xdb1c0e78,0xede401e0,0x3a2401b9,0x7050210e}},	//   sgrü, уһыҙ_, қмаг, _گنوا, 
   {{0xd04003be,0x00000000,0x00000000,0x00000000}},	//   kumə, --, --, --, 
   {{0x7a2803b2,0xdb240166,0x00000000,0x00000000}},	//   _hýti, _üsül, --, --, 
   {{0x57cc0037,0x7b0400de,0x00000000,0x00000000}},	//   ाल्ह, _īstā, --, --, 
   {{0xdb1c004e,0x00000000,0x00000000,0x00000000}},	// [1e8e0] ggrò, --, --, --, 
   {{0xe8f46943,0x27e800bc,0xe61c0427,0x7a2802f0}},	//   ылу_, _činí_, _čašč, _mýti, 
   {{0xaa8000ee,0x3e541a5a,0x34843d66,0x7a2803b2}},	//   şýar, nāto_, ңгег, _lýti, 
   {{0x7af80ad9,0x93bc054e,0x7c2c134a,0xdb1c03b2}},	//   ættu, _alăp, lkbr, sgró, 
   {{0x7a282833,0xa5042d1f,0x00000000,0x00000000}},	//   _nýti, леца_, --, --, 
   {{0x7c2c0430,0x2cbc003a,0x00000000,0x00000000}},	//   nkbr, áudi_, --, --, 
   {{0x53350beb,0x32644961,0x3e5448e1,0xad987479}},	//   рейт, лтив, jāto_, ndúc, 
   {{0x7a2806ea,0x3e54411e,0x00000000,0x00000000}},	//   _býti, dāto_, --, --, 
   {{0x7c2c449c,0xf1a81056,0x00000000,0x00000000}},	//   kkbr, واکه_, --, --, 
   {{0xa5200108,0x23300124,0x00000000,0x00000000}},	//   _умуд, рхәр, --, --, 
   {{0x7a2800a2,0xf2a400f3,0x00000000,0x00000000}},	//   _eýti, _сиеп, --, --, 
   {{0x7c2c0549,0x656c00e4,0x61400023,0x00000000}},	//   ekbr, _ãihá, _ንስዉኣ, --, 
   {{0x7a280174,0x940406be,0x2cbc0332,0x6140010a}},	//   _gýti, _sumə_, éud_, _леца, 
   {{0x09dc00dc,0x3e5400ef,0x00000000,0x00000000}},	//   मभ्य, bāto_, --, --, 
   {{0x28c405ba,0xddd037be,0xc90c0316,0x7e640af9}},	//   _लिहि, _çeşm, सम्म_, bokp, 
   {{0x2985382c,0xe3740150,0x00000000,0x00000000}},	//   гызг, _ﺠﺭﻴﺢ_, --, --, 
   {{0xfcc00041,0x9980010b,0x00000000,0x00000000}},	// [1e8f0] _мәрм, ndiň_, --, --, 
   {{0xd838152d,0x57b400d6,0x067c0046,0x69300131}},	//   лэх_, йбут, ﺭﯨﻨﯩ, анғу, 
   {{0xd7c8d91c,0xe6100014,0x28c407af,0x00000000}},	//   طونه_, ٝشش_, _लिवि, --, 
   {{0x17681b16,0xdb1c00db,0x998000a2,0x00000000}},	//   уруп_, pgrò, kdiň_, --, 
   {{0x65c002dd,0x00000000,0x00000000,0x00000000}},	//   _ғұла, --, --, --, 
   {{0x2280002d,0xddb00241,0x7a2802d2,0xe78401e5}},	//   _lűkt_, _mẹẹd, _rýti, _бубо, 
   {{0x7a280174,0x00000000,0x00000000,0x00000000}},	//   _sýti, --, --, --, 
   {{0x04c800aa,0x26d00077,0x42242766,0xe8100ce0}},	//   _لوري_, muxo_, рдив, ठावा_, 
   {{0x26d018f7,0x9f440122,0x998000a2,0x00000000}},	//   luxo_, _daný_, gdiň_, --, 
   {{0x95546d6c,0x2e38002e,0x7a280118,0xb46000f2}},	//   _اخفا, _jëff_, _výti, _وگوه, 
   {{0xef15382d,0xa3a8098a,0x61d400ec,0x00000000}},	//   амэ_, _क्य_, _مهاڳ_, --, 
   {{0xddb00241,0x228420c2,0xca900150,0x7eb800db}},	//   _bẹẹd, _сузг, _ﻓﺎﺘﻪ_, нгүс_, 
   {{0xc10405d9,0x7698010e,0x7c64bfae,0xc0d40023}},	//   _خوشي, _aįyl, لاسل, ያቶም_, 
   {{0x69c867ca,0xfaa40120,0x518401c6,0x490827c6}},	//   ógen, иаго, _ууха, सिनो_, 
   {{0x290c04f3,0x7c2d382e,0x7e64003e,0x81600133}},	//   ågan_, rkbr, pokp, _دۆکۆ, 
   {{0x26d00077,0xbee00073,0x7c2c01e3,0xfde8004e}},	//   duxo_, गझीन_, skbr, _рдик_, 
   {{0x1ce0031c,0x9e64158b,0x00000000,0x00000000}},	// [1e900] _ཤཱི_, _پاژن, --, --, 
   {{0x28c401ad,0x19c401e0,0x00000000,0x00000000}},	//   _लिरि, шәүг, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x74a40a5b,0x672001f4,0x00000000,0x00000000}},	//   ајке, änja, --, --, 
   {{0xb4c005f9,0x9f4401ef,0xa3c007b7,0x00000000}},	//   ्ढे_, _raný_, ्लं_, --, 
   {{0xe3ad382f,0xf2c4006c,0x26d01709,0x2e380221}},	//   ورى_, асин, buxo_, _gëff_, 
   {{0x9f453830,0x1ce0031c,0x00000000,0x00000000}},	//   _manó_, _ཤཱཀ_, --, --, 
   {{0x75d4bf41,0x9f440793,0x61902440,0xf2041b0a}},	//   _خيرا, _danü_, _ቀዳማዊ_, ряко, 
   {{0xd0100597,0xe9dc01e1,0x490849be,0x00000000}},	//   كلة_, _omún_, सियो_, --, 
   {{0x067c005e,0x78a40165,0x3e7000ae,0x00000000}},	//   ﺭﯨﻠﯩ, _mtkv, láth_, --, 
   {{0xcf1402f5,0x200005da,0xabd4036b,0xa0640120}},	//   ান্দ_, ôjia_, یزست, раќа_, 
   {{0x3e7000c6,0x2c100154,0x31680114,0x00000000}},	//   náth_, _হতেই_, _ишло_, --, 
   {{0x26d007a9,0x6ce402dd,0xe8dc0051,0x00000000}},	//   zuxo_, шіне, _khục_, --, 
   {{0x7050121e,0x9f4400cf,0xdce4010f,0x7a2802f0}},	//   _گنڈا, _canó_, _uziĝ, _mýtu, 
   {{0x78a41ffb,0x09e40154,0x7a2808a5,0x98ac00de}},	//   _atkv, _পোষা, _lýtu, _ādā_, 
   {{0x5a340588,0x2bd02052,0xffa401ee,0xea6000e5}},	//   онст, _ताका, _кләү, آپری, 
   {{0x9f4402e2,0x7a280321,0x7c6401d9,0x99993831}},	// [1e910] _abnè_, _nýtu, _گاٹل, ркут_, 
   {{0x9f453832,0x09e4015b,0xe8dc01fb,0x98c401d5}},	//   _ganó_, _পোশা, _nhục_, ўстл, 
   {{0xe6c400f7,0xd7f827a8,0x5804215c,0x00000000}},	//   شتاي, шут_, تولك, --, 
   {{0xea9c00b8,0x26d0056a,0x7a2808ce,0x398c0022}},	//   _ahṇe_, ruxo_, _býtu, _ẽse_, 
   {{0x03a40f4d,0xb9e400db,0x00000000,0x00000000}},	//   било, _اسپى, --, --, 
   {{0x26d01709,0xe8dc001e,0x545401c0,0x00000000}},	//   puxo_, _chục_, овчт, --, 
   {{0x7a280232,0xd7f82e34,0xdef00023,0x5c38011a}},	//   _výtv, _туя_, ሃብን_, שרון_, 
   {{0x73d400fd,0x56940d34,0x5b58011a,0xcfb40150}},	//   адәр_, _фатт, ישון_, _ﺼﺩﺍﻗ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xde2402d3,0xdb1c002f,0x00000000,0x00000000}},	//   _ሲቪካው, mgrö, --, --, 
   {{0x44253833,0xfeb8034c,0x6d5c058a,0xdb1c3b52}},	//   _iol_, داخت_, _axqa, lgrö, 
   {{0x442427cc,0xb8f8031c,0xa3a815e0,0xddd400d7}},	//   _hol_, _ཡྀ_, _क्त_, ťaža, 
   {{0x61e80327,0xdb1c3b52,0x00000000,0x00000000}},	//   _ibgl, ngrö, --, --, 
   {{0x44253834,0x09e4015b,0x067c1884,0x00000000}},	//   _jol_, _পোলা, ﺭﯨﻤﯩ, --, 
   {{0x44253835,0x09a800bd,0xfaa53836,0xdb1d3837}},	//   _mol_, _ওয়া, сабо, marë, 
   {{0xfaa407d6,0x7a2808a7,0x3e701a6b,0x44247d6a}},	//   _қамо, _nýtt, káti_, _lol_, 
   {{0x29093838,0x44253839,0x6d480010,0xf874007b}},	// [1e920] _crca_, _ool_, _žgav, مهرج, 
   {{0x4425383a,0xdb1d383b,0x9f9c004a,0x3e7002fb}},	//   _nol_, narë, _déçu_, dáti_, 
   {{0x65792a0b,0x7a2806ea,0xdce42630,0xe1c40490}},	//   _azuh, _býtt, _iziđ, ळणाघ, 
   {{0x7afc0003,0x442426c2,0x998000e8,0xe0c40c71}},	//   _ispt, _aol_, ndiŋ_, _ىز_, 
   {{0x4425383c,0xe8dc07ae,0xaaf80086,0x290800f3}},	//   _bol_, _phục_, _òeòñ_, _grca_, 
   {{0x4425383d,0x65780263,0x37b0015b,0x61e80112}},	//   _col_, _dzuh, _চাকর, _abgl, 
   {{0x4425383e,0xc5ec03f4,0xe7252a32,0xdb1c0240}},	//   _dol_, ওয়া_, _лорд_, darë, 
   {{0x4424078c,0x36681188,0x3e701427,0x952400e5}},	//   _eol_, _сабо_, báti_, _وکشم, 
   {{0x4425383f,0x5554066d,0xa5053840,0xaa380241}},	//   _fol_, _بھار, _лета_, _díẹ̀_, 
   {{0xdb1c0240,0x250817a5,0x00000000,0x00000000}},	//   garë, _حرفی_, --, --, 
   {{0x657804ba,0xee84329e,0x0a440092,0x00000000}},	//   _zzuh, йымо, _ከብሔራ, --, 
   {{0xdb1d3841,0x44253842,0xad98007b,0x769800a2}},	//   parê, _zol_, adún, _aįyk, 
   {{0x44253843,0x82640050,0x62000014,0xb1840055}},	//   _yol_, _بدلٕ, _رووٕ, _bhåų, 
   {{0x44241574,0xdb1c0200,0x7fb40137,0x00000000}},	//   _xol_, carë, _ۇلۇچ, --, 
   {{0x29040882,0x7a28022c,0xdb1c1e54,0xe45400df}},	//   ānam_, _nýts, narè, צילט_, 
   {{0x7bdc009a,0x9738001f,0x26c41315,0x00000000}},	//   _ecpu, _በሚያስ, ánom_, --, 
   {{0x7a2800ee,0x53c807b7,0x00000000,0x00000000}},	// [1e930] _aýts, रणाश, --, --, 
   {{0xdb1c0100,0x7a2803b2,0x2bd00073,0xddc40064}},	//   karè, _sýtt, _ताटा, _ikiš, 
   {{0x2bac0d79,0x44253844,0x09953845,0x7afc0356}},	//   _ज्या, _rol_, _манџ, _gspt, 
   {{0xdb1d3846,0xa3a80490,0x2d600036,0x3e70003a}},	//   darè, कुन_, céeë_, táti_, 
   {{0x44253847,0x29080276,0xa564027d,0x7a2800a2}},	//   _pol_, _urca_, حدان, _eýts, 
   {{0xdb1d3848,0x7afc0175,0x3e705955,0x25f8012d}},	//   rgrö, _yspt, ráti_, _ईसवी_, 
   {{0xdb1d3849,0x4425384a,0x3e700118,0x00000000}},	//   varë, _vol_, sáti_, --, 
   {{0x4425384b,0x00c8006c,0x00000000,0x00000000}},	//   _wol_, алик_, --, --, 
   {{0xdb1c069c,0x773c0092,0x00000000,0x00000000}},	//   tarë, ያካሂደ, --, --, 
   {{0x44240261,0x3e5400e2,0x62940077,0xb88000bc}},	//   _uol_, māti_, íxos, říva, 
   {{0xdb1c83c5,0x3e5400e2,0xe9dc0419,0x2bd00562}},	//   carè, lāti_, _ocú_, _ताजा, 
   {{0x7afc074d,0xd1b85dc6,0xdb1c036e,0xbe6801c6}},	//   _rspt, _هاها_, sarë, рамж_, 
   {{0xdb1c105e,0x3e550eb3,0x1108004b,0x22480210}},	//   maré, nāti_, _هغوي_, ękką_, 
   {{0xdb1d384c,0xe9dc0332,0x00000000,0x00000000}},	//   laré, _acú_, --, --, 
   {{0xddc4000a,0xe8fc025a,0x26c405ce,0x3e540165}},	//   _ekiš, _asû_, šnoj_, yāth_, 
   {{0xb53001e1,0x3e544974,0xd5d8012d,0xa3a8134e}},	//   _bẹ́l, kāti_, _डाइज, _क्स_, 
   {{0xc7640131,0xdb1c02e2,0xe9d40006,0x00000000}},	// [1e940] ۋامى, zarè, ўку_, --, 
   {{0x3e540aed,0xa3a873ca,0xdb1d372e,0x00000000}},	//   dāti_, कुम_, haré, --, 
   {{0xdb1ca5b2,0x8d700092,0x7afc045a,0x66e00e4e}},	//   karé, _በቦታው_, _uspt, доха, 
   {{0xac946ff0,0xdb1c00db,0x631c0154,0x00000000}},	//   _دنیا_, varè, বনায়_, --, 
   {{0x12c40597,0xe5a0084c,0x3e54005f,0xdb1c08e3}},	//   _ĝĭяĺ_, фичи, gāti_, daré, 
   {{0x48f804ac,0xdb1c067c,0xe3ad0ee6,0x00000000}},	//   _פּרא, tarè, پرو_, --, 
   {{0x75d5384d,0x3e7063dc,0xdb1c00e8,0x00000000}},	//   _ويسا, látu_, faré, --, 
   {{0x30e800c0,0xaa34008f,0x3e5400de,0x00000000}},	//   афон_, ַטיק_, bāti_, --, 
   {{0x320001a2,0xa3a80882,0x3e700122,0xdb1c4bc7}},	//   ľky_, _क्व_, nátu_, sarè, 
   {{0x320003c6,0xdb1d384e,0x12c8015b,0xad9801e7}},	//   žky_, parè, _শহীদ, adúl, 
   {{0xa5040276,0xdb1d384f,0xe4200a98,0x00000000}},	//   _леӂа_, baré, _تکني, --, 
   {{0x3e7002fb,0xdb1c0c6a,0x00000000,0x00000000}},	//   kátu_, caré, --, --, 
   {{0x80a00137,0x00000000,0x00000000,0x00000000}},	//   _كۅين, --, --, --, 
   {{0x26c401a2,0x21280730,0x00000000,0x00000000}},	//   ánok_, äche_, --, --, 
   {{0xb908063f,0xdb240241,0x00000000,0x00000000}},	//   pokọ_, _àsìl, --, --, 
   {{0xaca002e3,0x9a844ecc,0x398c0022,0x00000000}},	//   _ahụg, дуул, _ẽsa_, --, 
   {{0x3e7002f0,0xad9800e4,0x00000000,0x00000000}},	// [1e950] gátu_, ndúm, --, --, 
   {{0x57f4f0c2,0x3e540a2f,0x00000000,0x00000000}},	//   мпут, vāti_, --, --, 
   {{0x7a280306,0xdb1c020c,0xa3a808f2,0x00000000}},	//   _výtr, yaré, _क्ष_, --, 
   {{0x3e5400da,0xfad40302,0x6b40022e,0x3e7002f0}},	//   tāti_, _צורך_, _nеgi, bátu_, 
   {{0xdb1d3850,0x03a45e57,0x2b5c0205,0x00000000}},	//   varé, пило, ğucu_, --, 
   {{0x03a53851,0x3e547106,0xdb1c00d5,0x758007d6}},	//   чико, rāti_, waré, ریلم, 
   {{0xdb1d3852,0x00000000,0x00000000,0x00000000}},	//   taré, --, --, --, 
   {{0x80d80729,0xa3a8330a,0x65840022,0x3e700d12}},	//   _বৈষ্, _क्र_, _дызз, nátt_, 
   {{0x23e401ce,0xd51800ec,0xd9a80037,0x00000000}},	//   _міжв, _وڙهڻ_, _छ्ोट, --, 
   {{0xdb1c0d51,0x3e700d12,0x636800d8,0x70800830}},	//   saré, hátt_, _крег_, нгыз, 
   {{0xdb1d3853,0x3f6817a0,0xed540107,0x00000000}},	//   paré, сино_, ҷоя_, --, 
   {{0x200049ad,0xdb1c011f,0x52740c75,0x683003e0}},	//   žji_, qaré, _قانز, _hıdı, 
   {{0x537c02d3,0x6d481710,0x04f800eb,0xddc800e5}},	//   _ብቕዓት_, _žgar, _আপুর_, ülőh, 
   {{0x32ec03b9,0xb098011a,0xca540220,0x00000000}},	//   _həya_, _פיצר, _ﻋﺒﺭ_, --, 
   {{0x683005d1,0xd9c000fe,0xf410010f,0x00000000}},	//   _mıdı, ইলসম, עפל_, --, 
   {{0xee3c0232,0xb6a40116,0x3e702507,0x00000000}},	//   chý_, җидл, gátt_, --, 
   {{0xaa400b8d,0x394402d5,0x77c801c6,0x00000000}},	// [1e960] хетл, чнаг, йлаг_, --, 
   {{0x3e7003c6,0x9f440793,0xa8013854,0xa9a00724}},	//   rátu_, _danö_, нзул, _җирд, 
   {{0xfa680022,0xbf780208,0x00000000,0x00000000}},	//   _ганк_, _đuốc_, --, --, 
   {{0x6aa02b76,0x25e40037,0x8e2c022e,0x00000000}},	//   _énfa, छ्ली_, ntdа_, --, 
   {{0x5398034b,0x68300205,0x09e40154,0x00000000}},	//   овля_, _bıdı, _পোকা, --, 
   {{0x1ce00156,0xb9e41ee0,0x3e553855,0x683003b9}},	//   _ཤཱན_, _ካሳ_, mātu_, _cıdı, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x35a405f5,0xf744013e,0x714400a7,0xfbc405ac}},	//   _хааг, _деҳо, зхож, শ্চত, 
   {{0x3e5400da,0xd040016b,0x79600023,0x75d400ec}},	//   nātu_, wumɑ, _ዉድባት, _ويڳا, 
   {{0x68300790,0x3208012d,0x00000000,0x00000000}},	//   _gıdı, śby_, --, --, 
   {{0x3dc0014b,0x6b4001d5,0x13c80a59,0x00000000}},	//   fakw_, _tеgi, रणीभ, --, 
   {{0x31242309,0xee3c00bc,0x3e547106,0x9da802e8}},	//   _ндег, uhý_, kātu_, зъра_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3e5400e2,0x683006be,0x0ba400c7,0x00000000}},	//   dātu_, _xıdı, ьымҭ, --, 
   {{0x49f8031c,0xad9800c7,0x00000000,0x00000000}},	//   _ཕྲུལ_, ndúk, --, --, 
   {{0xdb1c0268,0x9b580353,0x00000000,0x00000000}},	//   marì, чист_, --, --, 
   {{0x3204079b,0x88953856,0x290c0321,0x3e5400de}},	// [1e970] _maoy_, диах, íga_, gātu_, 
   {{0x09e40c58,0xb60401a6,0x00000000,0x00000000}},	//   _পোখা, _lešć, --, --, 
   {{0xfbd09b62,0x48f814df,0x26c4038e,0x290c008f}},	//   _בתי_, _उनको_, éno_, ŭga_, 
   {{0x3e5400e2,0x68301ea0,0x00000000,0x00000000}},	//   bātu_, _sıdı, --, --, 
   {{0x69dc0b6f,0x291c036e,0xad9802d2,0x00000000}},	//   mgqe, _çua_, edúk, --, 
   {{0x68400ca8,0x683006be,0x00000000,0x00000000}},	//   _dídù, _qıdı, --, --, 
   {{0xb60401a6,0x947404fb,0x8e2c022e,0x3ea800ef}},	//   _bešć, ردها, ytdа_, _čato_, 
   {{0x9f440548,0xdb1c0268,0x69dc6ae5,0x80a80212}},	//   _manô_, darì, ngqe, овив_, 
   {{0x7fd45cd9,0x94d416a4,0xa2e001d5,0x32ec03e3}},	//   міні, _потц, фоқд, _vəya_, 
   {{0x25bc03bd,0x2efc0204,0x6340002e,0xb8cc0327}},	//   _heul_, fwtf_, _pёnd, _པ༵_, 
   {{0x249c00ca,0x90e404d3,0x3f9000d0,0xe7ec0073}},	//   _huum_, وسین, äzu_, घ्या_, 
   {{0x20081b13,0x25bc00e8,0x249c00c5,0x411800ec}},	//   ści_, _jeul_, _kuum_, _وياج_, 
   {{0x61f93857,0xb308025c,0x2bac45c7,0xf28401d9}},	//   meul, _གནོང_, जुभा, _تھوو_, 
   {{0x61f93858,0x8c9402d5,0x60d93859,0x11840032}},	//   leul, ерсі, muum, _яҙып_, 
   {{0xeb95385a,0x224c020b,0x20042446,0x60d9385b}},	//   дир_, _kmgk_, _iani_, luum, 
   {{0x20041aa1,0x68fc074d,0x25bd385c,0xaf440014}},	//   _hani_, fwqd, _neul_, _زرى۪, 
   {{0x2005385d,0xdb1c2a4d,0x596402dd,0x60d9385e}},	// [1e980] _kani_, marí, хнағ, nuum, 
   {{0x20042e95,0x61f81dd4,0xdb1d385f,0x3e5400e2}},	//   _jani_, heul, larí, rātu_, 
   {{0x61f93860,0x60d93861,0x25bc0192,0x249c003a}},	//   keul, huum, _beul_, _auum_, 
   {{0x60d93862,0x20053863,0xdb1d3864,0x249c0de2}},	//   kuum, _lani_, narí, _buum_, 
   {{0x61f93865,0x20040421,0xdb1c0077,0x64a001ce}},	//   deul, _oani_, iarí, вача, 
   {{0x249d3866,0xdb1d3867,0x60d93868,0xa5040114}},	//   _duum_, harí, duum, феља_, 
   {{0x3e5400da,0xdb1c00e7,0x61f93869,0xb60401a6}},	//   nāts_, karí, feul, _pešć, 
   {{0x2005386a,0x61f9386b,0xdb1c0407,0x249c003a}},	//   _aani_, geul, jarí, _fuum_, 
   {{0x2005386c,0xdb1c5793,0xd13000aa,0xb60400f3}},	//   _bani_, darí, امخ_, _vešć, 
   {{0x2005386d,0x25bd386e,0x33182d8d,0x99800006}},	//   _cani_, _zeul_, _وزاد_, lkių_, 
   {{0x61f83386,0x249c063f,0x62040267,0x9ed40166}},	//   beul, _zuum_, örlä, ммэт_, 
   {{0x7c3c008f,0xdb1c0cc3,0x20040428,0x99800006}},	//   _alpr, garí, _eani_, nkių_, 
   {{0x2005386f,0x60d89d8f,0xad98e680,0x99800064}},	//   _fani_, cuum, ndúi, ikių_, 
   {{0x20053870,0x9f440051,0x09b807b7,0x00000000}},	//   _gani_, _panô_, ेण्य, --, 
   {{0xdb1c2a4d,0x7c3c030d,0x764000aa,0x3e5400e2}},	//   barí, _dlpr, khoy, gāts_, 
   {{0x7c3d3871,0x20053872,0xdb1c09ff,0xea9c0248}},	//   _elpr, _zani_, carí, _aiṣe_, 
   {{0x20053873,0x76413874,0x48153875,0x25bc08c2}},	// [1e990] _yani_, dhoy, нмас, _reul_, 
   {{0x25bd3876,0x200402c4,0x61f93877,0x58d4520c}},	//   _seul_, _xani_, zeul, тофт, 
   {{0x249c0483,0x61f91d8d,0x25bc5e52,0x3e540171}},	//   _suum_, yeul, _peul_, cāts_, 
   {{0x60d93878,0xd6d80354,0x5a34f56c,0x4ddc00cc}},	//   yuum, ьту_, _анют, _বসুৱ, 
   {{0x249d3879,0x25bc01f5,0x60d8011f,0x61f80156}},	//   _quum_, _veul_, xuum, veul, 
   {{0xd378006d,0xdb1c2b76,0x60d81418,0xb8800306}},	//   _być_, zarí, vuum, žíro, 
   {{0x29040325,0xdb1d387a,0x61f9387b,0x25bc0dd4}},	//   ānau_, marã, teul, _teul_, 
   {{0x2005387c,0x4ebc045e,0x249c0483,0x60d9387d}},	//   _sani_, _অমূল, _tuum_, tuum, 
   {{0x66183209,0x61f9387e,0x2c0c0882,0xdb1d387f}},	//   _inuk, reul, ायां_, varí, 
   {{0x44e93880,0xada006ba,0x60d93881,0x20053882}},	//   mú_, ғарл, ruum, _qani_, 
   {{0xefc40323,0xdb1d387f,0x20053883,0x6440379c}},	//   элэл_, tarí, _vani_, mhni, 
   {{0x20053884,0xa3a84103,0x64400477,0xdb1c0124}},	//   _wani_, कुर_, lhni, harã, 
   {{0x20053885,0xdb1d3886,0x44e93887,0x403405a2}},	//   _tani_, rarí, nú_, _педс, 
   {{0x69cd3888,0xdb1c9ccb,0x20040eda,0x3e54005f}},	//   _adce, sarí, _uani_, tāts_, 
   {{0x99800006,0x44e826d8,0xdb1c2137,0xa3e42052}},	//   ykių_, hú_, darã, _भान_, 
   {{0x225c102c,0x661805db,0x69cc0076,0x44e93889}},	//   nnuk_, _nnuk, _cdce, kú_, 
   {{0x44e9388a,0x6440a436,0x7e7400e4,0x225ce9b2}},	// [1e9a0] jú_, khni, _ikyp, inuk_, 
   {{0xdb1d1d9e,0x6619388b,0x44e8b231,0x644009a8}},	//   garã, _anuk, dú_, jhni, 
   {{0x6441388c,0xf0a80428,0x38b401e1,0x00000000}},	//   dhni, _kiàò_, _bùrò_, --, 
   {{0xdb1d388d,0x752001c4,0x7489388e,0x00000000}},	//   marà, txoz, _ﺗﻮﭘﯩ, --, 
   {{0xd2503e58,0xdb1d388f,0x290c0267,0x99800024}},	//   ینت_, barã, ågat_, rkių_, 
   {{0xa3a81715,0x76413890,0x64413891,0x66180083}},	//   कुल_, shoy, ghni, _enuk, 
   {{0x76413892,0x38b40248,0xa0a00220,0xdb1c642b}},	//   phoy, _fùrò_, қшыл, narà, 
   {{0x661800e8,0x44e93893,0x64413894,0xe2941fbe}},	//   _gnuk, bú_, ahni, нај_, 
   {{0xe2100597,0x60f402d5,0x64401554,0x1cac0327}},	//   طبيع, еныя_, bhni, ྕམས_, 
   {{0x64a0085a,0x63b00232,0xdb1c05da,0x7e7400a2}},	//   _сафа, čení, karà, _akyp, 
   {{0xa854011a,0xa3a801f9,0x00000000,0x00000000}},	//   תייה_, कुळ_, --, --, 
   {{0xdb1d3895,0xfe6d3896,0x00000000,0x00000000}},	//   darà, يگي_, --, --, 
   {{0x9ee400f2,0x00000000,0x00000000,0x00000000}},	//   وفیل_, --, --, --, 
   {{0xdb1c8ab9,0x5c0493fb,0x62540356,0x00000000}},	//   farà, ляса, mţoa, --, 
   {{0xfee80220,0xdb1c2852,0x9b6816a4,0x2094104e}},	//   _жуық_, garà, ешта_, _якшы_, 
   {{0xa8a409fe,0x60200124,0xd36400f7,0x44e80022}},	//   ержк, _адәа, _ۇۇ_, yú_, 
   {{0x4ea4052f,0xdb1c06ed,0x58d4ccc5,0x9a8401c0}},	// [1e9b0] _ярҙа, tarã, лотт, уурл, 
   {{0xdb1c8d22,0x44e801a2,0x66193897,0x00000000}},	//   barà, vú_, _snuk, --, 
   {{0xdb1d3898,0xd6d001ed,0x44e857b9,0x225c022e}},	//   rarã, یقے_, wú_, ynuk_, 
   {{0xdb1c0120,0xe9dc002d,0x44e93899,0xe9700451}},	//   sarã, _slúf_, tú_, _منجھ, 
   {{0xdb1d389a,0x6441389b,0x66183831,0x29040f40}},	//   mará, thni, _vnuk, ānas_, 
   {{0xdb1c05a4,0x44e9389c,0x26c401ed,0x43742d29}},	//   lará, rú_, ános_, куйт, 
   {{0x44e9389d,0x49083d1d,0x644000d0,0x96f80798}},	//   sú_, सिको_, rhni, _перт_, 
   {{0x5695389e,0x6441389f,0xdb1d3383,0x44e938a0}},	//   _баст, shni, nará, pú_, 
   {{0x644138a1,0xdb1d38a2,0xd4f406c2,0xd29400c7}},	//   phni, zarà, _مثلث, ыршь, 
   {{0x7e74b189,0xdb1c03df,0x3ea40477,0x00000000}},	//   _skyp, hará, tqlt_, --, 
   {{0xc1d00075,0xdb1d38a3,0x70800139,0x00000000}},	//   _көпә, xarà, ргэз, --, 
   {{0x65780574,0xdb1d38a4,0xd2f800db,0x00000000}},	//   _kyuh, jará, _سةما_, --, 
   {{0xdb1d38a5,0x6ef40793,0xc0e450ce,0xf4240139}},	//   dará, _pübö, _ролк, _ğäzi_, 
   {{0xd0040517,0xff500214,0xdb1d38a6,0xb0340139}},	//   _бошқ, _پخت_, tarà, _имчә, 
   {{0xfaa4932e,0xdb1c02d2,0x00000000,0x00000000}},	//   табо, fará, --, --, 
   {{0xdb1d38a7,0xf2d000c8,0x7e7400ee,0x00000000}},	//   gará, יעל_, _ukyp, --, 
   {{0xe9dc0248,0x657938a8,0xa9241710,0xdb1c35f5}},	// [1e9c0] _amús_, _nyuh, ježđ, sarà, 
   {{0xdb1c26b7,0x00000000,0x00000000,0x00000000}},	//   parà, --, --, --, 
   {{0x657807a8,0x290c049f,0xbb441cd6,0x624400e4}},	//   _ayuh, ågar_, _ренк, _iñof, 
   {{0xdb1c09ff,0x81e8009e,0x7aec010a,0x00000000}},	//   cará, য়ড_, mtbt, --, 
   {{0x65780526,0x83940092,0x00000000,0x00000000}},	//   _cyuh, _ማሳወቅ_, --, --, 
   {{0x657818f7,0x7d140042,0x7e0c28d4,0x00000000}},	//   _dyuh, _mrys, ियुग_, --, 
   {{0x4ebc045e,0x6300868d,0x36945e78,0x59ac19cc}},	//   _অম্ল, لوول, _ашас, टुअर, 
   {{0x7d14127b,0xbb7c0150,0x00000000,0x00000000}},	//   _orys, _ﺤﻭﻟﻪ_, --, --, 
   {{0x1cbc031c,0x25d40375,0x10980063,0x7d1538a9}},	//   ཅེས_, _שומן_, нкић_, _nrys, 
   {{0xdb1d38aa,0xa3a80037,0x00000000,0x00000000}},	//   zará, कुआ_, --, --, 
   {{0xa3e538ab,0x7d1538ac,0x481400c8,0xfe0c0034}},	//   _भात_, _arys, אַרן_, ियंस_, 
   {{0x7d1538ad,0x7c200b45,0xdb1c056a,0x00000000}},	//   _brys, _ɗore, xará, --, 
   {{0x7d1538ae,0x4bc431ee,0xdb1d38af,0x8e7c0115}},	//   _crys, лөнг, vará, juĝe, 
   {{0x81e80729,0x7d1538b0,0x5c7435dd,0x7e6c008f}},	//   য়ণ_, _drys, илят, _ĉape, 
   {{0xdb1d38b1,0x7d14003a,0x5f702cb0,0xdb5401c6}},	//   tará, _erys, _پاور, авры, 
   {{0x7d14193f,0x6e84004b,0x8e7c010f,0xdb1c0174}},	//   _frys, _جمعې_, fuĝe, karæ, 
   {{0xdb1d38b2,0x195938b3,0x7d1538b4,0x97380092}},	// [1e9d0] rará, ваты_, _grys, _በሚወስ, 
   {{0xdb1d38b5,0x57b402bf,0x6578037e,0x27e475ee}},	//   sará, ибут, _ryuh, ünn_, 
   {{0x81e80c58,0xdb1d38b6,0x657938b7,0xc5d401ce}},	//   য়ত_, pará, _syuh, гіль, 
   {{0xe7fc028a,0x8e7c01e4,0x7d140022,0x03240116}},	//   _उसका_, buĝe, _yrys, ғдин, 
   {{0x58d40c04,0x00000000,0x00000000,0x00000000}},	//   _коят, --, --, --, 
   {{0x7d24002d,0x067c00d1,0x7980012d,0x657800b8}},	//   _útsű, ﺭﯨﻜﯩ, żowc, _vyuh, 
   {{0x65780098,0x7a2800a2,0x2604022e,0x00000000}},	//   _wyuh, _aýty, _ичаг, --, 
   {{0x96f821ca,0xe9dc0005,0x998001a6,0x00e401c6}},	//   _шест_, _flúe_, ljiš_, гжин, 
   {{0x6578525e,0x16340212,0x00000000,0x00000000}},	//   _uyuh, _тетя, --, --, 
   {{0x998001a6,0x7d14036e,0x00000000,0x00000000}},	//   njiš_, _rrys, --, --, 
   {{0x01f40064,0x00000000,0x00000000,0x00000000}},	//   _бялю, --, --, --, 
   {{0x7d1538b8,0xad9801d3,0xdb1c3e1f,0x00000000}},	//   _prys, jdús, larç, --, 
   {{0xee3400a8,0x6818005f,0x81e80154,0x940c06be}},	//   уня_, _kādē, য়দ_, _aidə_, 
   {{0x60d938b9,0x7d140151,0x3b080b32,0x96000807}},	//   mrum, _vrys, него_, _ईस्ट_, 
   {{0x60d938ba,0xc608015b,0x00000000,0x00000000}},	//   lrum, _রচনা_, --, --, 
   {{0x7d141106,0xad98002d,0x681800e2,0xdb1d38bb}},	//   _trys, tdút, _lādē, yaræ, 
   {{0x7aec0334,0x7d1400a2,0xdb1c7cd9,0xe7340150}},	// [1e9e0] stbt, _urys, karç, ңеу_, 
   {{0xad98045f,0xdb1c03b2,0x60d80064,0xa874009d}},	//   rdút, varæ, irum, гөст_, 
   {{0x60d938bc,0xdb1d38bd,0xe7340cb6,0xddc4013a}},	//   hrum, darç, леф_, _smiř, 
   {{0x5c4436bc,0xdb1c066a,0xe3ac0131,0x78b401f4}},	//   _ፕሮጀክ, taræ, ۋرى_, ppyv, 
   {{0x81e83857,0x60d80399,0xe5e460bb,0x39340006}},	//   য়া_, jrum, ازمی, _сэнс, 
   {{0xdb1c0174,0x00000000,0x00000000,0x00000000}},	//   raræ, --, --, --, 
   {{0x60d938be,0xf7440b3b,0xad9938bf,0x6840030d}},	//   erum, _сево, ndúr, _унра, 
   {{0x60d938c0,0x7e0c06b1,0xe64000c0,0x3ce003b2}},	//   frum, ियोग_, _лесп, kukv_, 
   {{0xddc4010e,0x21640114,0xdb1c00ee,0x00000000}},	//   _iliň, лићи_, barç, --, 
   {{0xf4240139,0x9054117e,0x00000000,0x00000000}},	//   _şäfi_, рвоц, --, --, 
   {{0x60d938c1,0x9d18020a,0xd9e40073,0xe0cc7611}},	//   arum, ҳоят_, गलात_, يزی_, 
   {{0x60d938c2,0x6ce401ce,0x32ec00ac,0xdf1401d3}},	//   brum, ліге, _nəyi_, اڑوں_, 
   {{0x60d938c3,0x2e381bce,0x628400e4,0xdb1c0139}},	//   crum, _jëfi_, _ëjoa, harä, 
   {{0xdb1d38c4,0x09dc0073,0x9be402dd,0x00000000}},	//   karä, यल्य, йіск, --, 
   {{0xdb1c000f,0x32ec03b9,0xa3e423e9,0x00000000}},	//   lbrê, _bəyi_, _भास_, --, 
   {{0x78a4597f,0xceb83d44,0xdb1c008e,0x00000000}},	//   _bukv, mpę_, darä, --, 
   {{0xdb1c000f,0x2bc80640,0x08547927,0xceb80064}},	// [1e9f0] nbrê, _пуно_, аваю, lpę_, 
   {{0xee3c0316,0x984800a7,0xfbc418cc,0x8f000354}},	//   lký_, ляха_, वरणम, _хiу_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfd5400cd,0xee3c02fb,0x79800034,0x5694d027}},	//   _araṇ, nký_, żowa, бахт, 
   {{0xdb1c0724,0x00000000,0x00000000,0x00000000}},	//   tarç, --, --, --, 
   {{0xee3c0122,0x290800d8,0x60d81355,0xddc4010b}},	//   hký_, _isca_, vrum, _eliň, 
   {{0x2908004e,0xee3c36d1,0x60d938c5,0x16101bbb}},	//   _hsca_, kký_, wrum, _ठोकर_, 
   {{0xa3e4367a,0xfd540055,0x5c440092,0x5b58011a}},	//   _भाव_, _eraṇ, _ፕሮጄክ, טיוב_, 
   {{0x681800da,0xee3c02fb,0x70c401c0,0xe8dc004d}},	//   _tādē, dký_, агыг_, _diệc_, 
   {{0x60d938c6,0xbd8803e6,0xfd5400b8,0x5344035b}},	//   rrum, ێندن_, _graṇ, рхәа, 
   {{0x3f6905c6,0x00000000,0x00000000,0x00000000}},	//   тино_, --, --, --, 
   {{0x60d938c7,0xc17413f3,0x29091375,0xdb1c0158}},	//   prum, _клещ, _osca_, narå, 
   {{0x32ec0213,0x3ea800ef,0x00000000,0x00000000}},	//   _rəyi_, _čatu_, --, --, 
   {{0xafe003a6,0xdb1cf7ca,0x32ec03b9,0x00000000}},	//   _дошл, yarä, _səyi_, --, 
   {{0x29080395,0x62440022,0x19c00327,0xee3c02f0}},	//   _asca_, _iñob, _མབྱབ, bký_, 
   {{0xee3c0745,0xdb1c0036,0x78a400b8,0xad980419}},	//   cký_, lbrë, _pukv, rdúr, 
   {{0x61e8f1b6,0x6e90007b,0xaa40013d,0x00000000}},	// [1ea00] _mcgl, _بليا, цетл, --, 
   {{0x9f4538c8,0x4998023a,0xfde40dba,0xdb1c007c}},	//   _acné_, утся_, _काँस_, tarä, 
   {{0x290938c9,0x00000000,0x00000000,0x00000000}},	//   _esca_, --, --, --, 
   {{0xe0c538ca,0x7afc0109,0xeef4008f,0x00000000}},	//   _وز_, _ippt, ימער_, --, 
   {{0xfd540a28,0x24e40640,0x10b40150,0xad980124}},	//   _praṇ, имци_, _ﹼﺨﺫﻨ, ndúp, 
   {{0x2bac3347,0xee3c00bc,0xded0001f,0xceb80210}},	//   _ज्ञा, zký_, ራለን_, ypę_, 
   {{0xa3e402e5,0xdb1c0309,0xe72538cb,0xfde400e1}},	//   _भार_, qarä, _корд_, _कांस_, 
   {{0x7afc06d9,0x7c2003f9,0xd58801af,0x00000000}},	//   _mppt, _ɗora, _йәлл_, --, 
   {{0xe8dc01dc,0x776c01f5,0x8e7c00df,0xa50401b9}},	//   _việc_, _hxbx, juĝa, _кета_, 
   {{0x7afc174e,0xdb1c000f,0xb4d00073,0x92e400cc}},	//   _oppt, rbrê, वळी_, _ফনী_, 
   {{0xe8dc001e,0x3e7002fb,0xdb1c002d,0xee3c02f0}},	//   _tiệc_, láty_, sbrê, tký_, 
   {{0xd6d81c82,0xdb1d38cc,0x8e7c0115,0xceb800c0}},	//   _সহায, mbrè, fuĝa, rpę_, 
   {{0x776c2963,0x3e7002fb,0xdb1c0100,0xee3c022a}},	//   _lxbx, náty_, lbrè, rký_, 
   {{0xcc8853f3,0xee3c031f,0xe0f80302,0xec140b8d}},	//   انسه_, ský_, _סלול, шегә_, 
   {{0xdb1d38cd,0x81e8015b,0xce9409ac,0xa3a82072}},	//   marû, য়র_, _лакъ, कुट_, 
   {{0x3e700122,0x9f980375,0x00000000,0x00000000}},	//   káty_, _בסופ, --, --, 
   {{0xc8c89717,0x7c3812e8,0xd9140417,0x79800210}},	// [1ea10] اوطن_, åbrø, одты, żown, 
   {{0x7afc003e,0x3e7000bc,0xf1b802dd,0x00000000}},	//   _fppt, dáty_, _ﺤﻘﻴﻘ, --, 
   {{0x78b800bc,0xd7c86ac4,0xd7f80063,0xc5f400cc}},	//   _čtve, شونه_, јуу_, _ঘোষা_, 
   {{0x8f0000c0,0xaa4000d1,0x00000000,0x00000000}},	//   _хiх_, _بۆرى, --, --, 
   {{0x6d4c0007,0xa56538ce,0x3b640014,0x3e7013d5}},	//   nzca, جدان, _نَیہ, gáty_, 
   {{0x1cb80302,0x624400e4,0x00000000,0x00000000}},	//   סלול_, _oñoc, --, --, 
   {{0xddc401e4,0x683000bc,0x82f802c9,0x86c4007b}},	//   _amiŝ, _výdě, ارتز_, _ديزن, 
   {{0x3e700122,0x04c938cf,0x00000000,0x00000000}},	//   báty_, _موري_, --, --, 
   {{0x2e3800e8,0x3120411a,0x81e800cc,0xdb1c01c7}},	//   _jëfu_, здыг, য়ল_, tbrë, 
   {{0x21640058,0xd0740451,0x5454020f,0x00000000}},	//   лиқи_, يپيڊ, _двут, --, 
   {{0xdb1c0036,0x3ea800e2,0x831400e5,0xa2241541}},	//   rbrë, _čats_, _دواؤ, _پراه, 
   {{0x228538d0,0x6340002e,0xcee81f70,0x00000000}},	//   _тузг, _lёnk, گرین_, --, 
   {{0xdb1d38d1,0x52751e4f,0x7c640131,0x28a401ad}},	//   mbré, _بالز, ماسل, _कूलि, 
   {{0xdb1c0221,0x71180302,0x8e7c0115,0xcee80330}},	//   lbré, _תוספ, ruĝa, درین_, 
   {{0xdb1d0ca1,0x00000000,0x00000000,0x00000000}},	//   larú, --, --, --, 
   {{0x3dc4036b,0x00000000,0x00000000,0x00000000}},	//   _уйиг, --, --, --, 
   {{0xdb1c0d12,0xeb9401ec,0xeaac01d9,0x00000000}},	// [1ea20] narú, _қию_, ِٹہ_, --, 
   {{0x3e7002fb,0x00000000,0x00000000,0x00000000}},	//   váty_, --, --, --, 
   {{0x7afd38d2,0xa3a80c2e,0xdb1c0332,0x00000000}},	//   _uppt, कुछ_, harú, --, 
   {{0x7bcd38d3,0x3e700122,0xdb1d38d4,0x00000000}},	//   labu, táty_, karú, --, 
   {{0xcfc802a6,0xddc404ba,0xe9dc002d,0xb4d00490}},	//   _শাসন, _aliŋ, _klún_, वळे_, 
   {{0x7bcd279f,0x3e700e96,0x25b800ac,0x2e380036}},	//   nabu, ráty_, ıqla_, _hëft_, 
   {{0x66e11377,0xe73538d5,0x00000000,0x00000000}},	//   _нора, _лер_, --, --, 
   {{0xf20538d6,0x2e3800e8,0xdb1c0036,0x00000000}},	//   сяко, _yëfu_, gbré, --, 
   {{0x7bcd38d7,0x75447b68,0x81e8009e,0xe5a000c7}},	//   kabu, _уназ, য়ং_, _хиуи, 
   {{0x7bcd38d8,0x76409a43,0xcfc80154,0xabc40150}},	//   jabu, lkoy, _শাহন, _ﺒﺩﻋﺎ, 
   {{0x7bcd38d9,0x8f341614,0x2448cade,0x81080327}},	//   dabu, ценц, _dømd_, _ཀརྨཱ_, 
   {{0x764138da,0x6d4c0113,0x9c8400d1,0x2ce80150}},	//   nkoy, tzca, ۋۇيۈ, льго_, 
   {{0x7bcc0223,0xdb1c08e7,0x00000000,0x00000000}},	//   fabu, marù, --, --, 
   {{0x37dc03d4,0x00000000,0x00000000,0x00000000}},	//   ন্তৰ, --, --, --, 
   {{0x764138db,0x2e38002e,0x39380092,0x5c980064}},	//   kkoy, _sëfu_, _የመወያ, ёкся_, 
   {{0xddc40213,0xeda400d4,0x00000000,0x00000000}},	//   _imiş, _ушко, --, --, 
   {{0x7bcd38dc,0x6218008f,0xda3400fb,0x1994022e}},	// [1ea30] babu, נומק, четы, затя, 
   {{0x999800a8,0x7bcd38dd,0xa3e4d9e5,0xe9dc01e7}},	//   скут_, cabu, _भाइ_, _glún_, 
   {{0xdc38008f,0x00000000,0x00000000,0x00000000}},	//   _לאזט_, --, --, --, 
   {{0x2e380036,0x76400162,0x569406b4,0x9cd40345}},	//   _gëft_, gkoy, пахт, _بڕێژ, 
   {{0x2bbc0b8f,0x6340002e,0x03a40902,0x00000000}},	//   ्रपा, _tёnk, оило, --, 
   {{0x070821e7,0x61b000cd,0xe2740131,0x00000000}},	//   _پيري_, ीर्ष, әшкә_, --, 
   {{0xfd4938de,0x24480158,0x8e7c01e4,0xfd0801ec}},	//   _bulọ, _rømd_, juĝo, _ضﺮﺘ_, 
   {{0x7bcd38df,0x7e6c00df,0x76400076,0x37dc03d4}},	//   zabu, _ĉapo, ckoy, ন্দৰ, 
   {{0x569538e0,0xdb1d38e1,0xa3e40490,0x964400db}},	//   _хатт, rbré, _भाऊ_, _ээрд, 
   {{0xe2942e56,0x7bcc141c,0x8e7c0115,0x81e80154}},	//   шақ_, xabu, fuĝo, য়ই_, 
   {{0x6440068f,0x2bbc2a8c,0x7bcd38e2,0xd3a41214}},	//   mkni, ्रना, vabu, _хруп, 
   {{0x4424b745,0x7bcc895d,0x244803d4,0xdb1cfcf4}},	//   _hnl_, wabu, _døme_, marø, 
   {{0x7bcd38e3,0xe0d004d3,0x225d38e4,0xddc4496e}},	//   tabu, _رزش_, miuk_, _emiş, 
   {{0x225c9585,0x44240076,0xfaa538e5,0x7f44004e}},	//   liuk_, _jnl_, жаво, _мелж, 
   {{0xa3e4534e,0x9eb021bf,0xf21c0c2e,0x644138e6}},	//   _भाई_, _эшлә, _मोड़_, ikni, 
   {{0x7bcd38e7,0x225d38e8,0x00000000,0x00000000}},	//   sabu, niuk_, --, --, 
   {{0x7bcd38e9,0xf7b89fb6,0x442524e5,0x644008ce}},	// [1ea40] pabu, لداش_, _onl_, kkni, 
   {{0x7bcd38ea,0x225c0098,0xdb1c06ea,0x644138eb}},	//   qabu, hiuk_, karø, jkni, 
   {{0x644006af,0x213c0098,0xdb1c0162,0x76400162}},	//   dkni, hyuh_, jarø, tkoy, 
   {{0xd5b032f3,0x644138ec,0x442538ed,0x13b400dc}},	//   رفت_, ekni, _anl_, ुर्भ, 
   {{0x2c0c0574,0x44247e7e,0x764138ee,0x64400036}},	//   ायचं_, _bnl_, rkoy, fkni, 
   {{0x2bbc1fe7,0x442400db,0x64412815,0x764138ef}},	//   ्रया, _cnl_, gkni, skoy, 
   {{0xdb1c03b2,0xfd480241,0x00000000,0x00000000}},	//   garø, _pulọ, --, --, 
   {{0x225c0af5,0x24480158,0xb88000bc,0x442538f0}},	//   giuk_, _røme_, řída, _enl_, 
   {{0x44240eb4,0x2bbc53c3,0xdb1c0086,0xb424007b}},	//   _fnl_, ्रमा, rarù, _وعطو, 
   {{0x644004f3,0xa3e400c5,0x442401e7,0x00000000}},	//   ckni, _भाए_, _gnl_, --, 
   {{0x62440022,0x225c0c6a,0xa6e40051,0xc4302927}},	//   _iñon, biuk_, _ngừ, _سکوت, 
   {{0x2bbc00dc,0x6fb800dc,0xf1a80133,0x225c0064}},	//   ्रभा, _श्रू, _ڵاڵه_, ciuk_, 
   {{0x21280d16,0x44240175,0x00000000,0x00000000}},	//   ächt_, _ynl_, --, --, 
   {{0x24480158,0x6ea8030d,0x2bb4013a,0x00000000}},	//   _tøme_, _къиг_, děcí_, --, 
   {{0x2bbd1586,0x22a400e5,0x00000000,0x00000000}},	//   ्रबा, _tőke_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x644008cb,0x6244035b,0xfbcc02dd,0xc7d820c8}},	// [1ea50] ykni, _oñon, _ﺑﯘﺭﻛ, ймах_, 
   {{0xd874aaab,0xdf1400e5,0x00000000,0x00000000}},	//   والب, _اڑیں_, --, --, 
   {{0xbaac00d1,0x9848003b,0x00000000,0x00000000}},	//   _ﻳﺎﺳﺎ, цята_, --, --, 
   {{0x442538f1,0x624400e4,0xf74802d3,0x64400194}},	//   _snl_, _añon, _መጸዋዕ, wkni, 
   {{0x4424084c,0x225c3209,0xe50400f7,0x97c42dfc}},	//   _pnl_, viuk_, تباي, ستەم, 
   {{0x332c00b5,0x53980023,0xdb1c0162,0x99803b33}},	//   fxfx_, _ቅንያት_, tarø, ldiş_, 
   {{0x644138f2,0x442401f5,0x00000000,0x00000000}},	//   rkni, _vnl_, --, --, 
   {{0x5694005e,0x00c84fe6,0x644138f3,0xdb1c022c}},	//   _жаст, блик_, skni, rarø, 
   {{0x225d38f4,0xddc40e3c,0xdb1c0158,0x64400549}},	//   riuk_, _njiš, sarø, pkni, 
   {{0x225c20ac,0xe7c80243,0xdb1c3a26,0x00000000}},	//   siuk_, िरिप, parø, --, 
   {{0x225c013c,0xd4980212,0x6f6000a8,0xcce80a7c}},	//   piuk_, _єру_, евэз, _תכ_, 
   {{0x225c013c,0x3950033f,0x52240798,0x00000000}},	//   qiuk_, yzys_, _офча, --, 
   {{0x61f938f5,0xe16400c6,0x7f84036b,0xe7c80b02}},	//   mful, _بداي, تلگن, िराप, 
   {{0x7ff42ea3,0x00000000,0x00000000,0x00000000}},	//   _رستا, --, --, --, 
   {{0x61f81418,0x29180166,0x00000000,0x00000000}},	//   oful, evqa_, --, --, 
   {{0x61f8202b,0xeb3000cf,0x00000000,0x00000000}},	//   nful, رىقد, --, --, 
   {{0xdb1cf814,0x61f8003e,0x00000000,0x00000000}},	// [1ea60] mbrí, iful, --, --, 
   {{0x2bbc185d,0x61f8b942,0xad180a7c,0x00000000}},	//   ्रणा, hful, _פויר, --, 
   {{0x39446c85,0xddc4012c,0x475800d4,0x00000000}},	//   šos_, _zjiš, орця_, --, 
   {{0x61f930c9,0x00000000,0x00000000,0x00000000}},	//   jful, --, --, --, 
   {{0xdb1c0597,0x61f83fc1,0xe4c0010b,0xc8c800ec}},	//   ibrí, dful, ейчи, _ووٽن_, 
   {{0x61f80393,0xf2c4001b,0xdb1c0042,0xe5a001c6}},	//   eful, псин, mbrâ, хичи, 
   {{0x61f85930,0x2bbc9d35,0x00000000,0x00000000}},	//   fful, ्रता, --, --, 
   {{0x61f938f6,0xb9e40023,0x066c1884,0x00000000}},	//   gful, _ይን_, ﻳﺎﻟﯩ, --, 
   {{0x6244005a,0x00000000,0x00000000,0x00000000}},	//   _iñol, --, --, --, 
   {{0x61f88c7f,0xdb1c032e,0x00000000,0x00000000}},	//   aful, darþ, --, --, 
   {{0x79840225,0x69c80162,0xdee000d8,0x2324014b}},	//   _lykw, ðgek, ноќи, _нофи_, 
   {{0xb63c037e,0xdb1c01a8,0x00000000,0x00000000}},	//   _ａｃ_, farþ, --, --, 
   {{0xcca400d1,0x00000000,0x00000000,0x00000000}},	//   _ﺋﻮﺭﮔ, --, --, --, 
   {{0xb4b80316,0x2bbce968,0x09d40490,0x00000000}},	//   _अझै_, ्रधा, धण्य, --, 
   {{0xd5cc0cba,0xaca001f2,0x37d0015b,0x00000000}},	//   ाराज, _nkụg, ালার, --, 
   {{0xeda4004e,0x00000000,0x00000000,0x00000000}},	//   _эшко, --, --, --, 
   {{0x2bbce459,0x48440014,0xddc4013a,0x00000000}},	// [1ea70] ्रदा, وپرٲ, _ujiš, --, 
   {{0x5c740a89,0xdb1c00a2,0x00000000,0x00000000}},	//   _плыт, larý, --, --, 
   {{0x61f938f7,0x212801fb,0xdc3c011a,0xb784013d}},	//   yful, ̣ch_, _לעזר, дәте_, 
   {{0xd6d938f8,0x80dc0037,0xdb1c010b,0x00000000}},	//   яту_, _मिलइ, narý, --, 
   {{0x69cd38f9,0x5dfc008f,0x758001b9,0x61f801bf}},	//   _iece, מפאנ, پیلم, vful, 
   {{0x61f820a2,0xd7f938fa,0x69ccc5f8,0x83645dc6}},	//   wful, _нус_, _hece, وگال, 
   {{0x69cc480a,0x61f81cea,0xdb1c00ee,0x00000000}},	//   _kece, tful, karý, --, 
   {{0x69cc0050,0x2fcc007f,0x244938fb,0x61f84894}},	//   _jece, _aefg_, _døma_, uful, 
   {{0x61f938fc,0x660801d3,0xe3c400fb,0xdb1c00a2}},	//   rful, megk, _еҫле_, darý, 
   {{0x69cd38fd,0x06902e56,0xa3e4000d,0x624400c7}},	//   _lece, _ﭘﯩﻜﯩ, _भाट_, _iñom, 
   {{0x64440227,0x2fcc01e4,0x61f938fe,0xdb240162}},	//   _ŋjiw, _defg_, pful, _ósøm, 
   {{0x660801c7,0x61f80327,0x79800210,0xdb1c02d2}},	//   negk, qful, żowi, garý, 
   {{0x62980395,0xd1b8521e,0x11d40fb4,0xed541171}},	//   mmuo, _رانا_, _ستند, доя_, 
   {{0x69cc003a,0x62980006,0xe8dc01fb,0x660801c7}},	//   _aece, lmuo, _chọc_, hegk, 
   {{0x69cd1c1a,0x00000000,0x00000000,0x00000000}},	//   _bece, --, --, --, 
   {{0x69cd38ff,0xeb953900,0x6244035b,0x6608003e}},	//   _cece, фис_, _oñom, jegk, 
   {{0x66080438,0x62980810,0xdb1c0254,0x00000000}},	// [1ea80] degk, imuo, larü, --, 
   {{0xb8f53901,0xd88404fb,0x69cc03ac,0x629804cc}},	//   _सब_, رهای, _eece, hmuo, 
   {{0x69cd3902,0x60c80399,0x624400e4,0x66080036}},	//   _fece, _lwgm, _añom, fegk, 
   {{0x69cd3903,0x24480158,0x3a0401d5,0x660804e6}},	//   _gece, _røma_, _تکسی_, gegk, 
   {{0x1cac0135,0xe5a00c56,0x6298002d,0xdb1c06be}},	//   _ཕངས_, вици, dmuo, harü, 
   {{0x69cc0356,0xdb1c0254,0x00000000,0x00000000}},	//   _zece, karü, --, --, 
   {{0xdb1c24c4,0x62440022,0x69cc0429,0xd05001ec}},	//   maró, _eñom, _yece, _ﯗﺭﯨﭗ_, 
   {{0xaaf49c13,0xdb1d3904,0x714412e7,0xe2941fbe}},	//   şaçı_, laró, дхож, мај_, 
   {{0xefb008dc,0x6e280ca8,0x35a401c4,0x00000000}},	//   نیشگ, _ògbi, _цааг, --, 
   {{0xdb1c00c6,0x24480174,0x62980a89,0x00000000}},	//   naró, _tøma_, amuo, --, 
   {{0x2bbc2cbc,0x047801d9,0x99800165,0x00000000}},	//   ्रसा, _علمک_, leiń_, --, 
   {{0x7bdc0393,0xe0cc0050,0x00000000,0x00000000}},	//   _adpu, _چٲن_, --, --, 
   {{0x9da802e8,0xdb1c0827,0x00000000,0x00000000}},	//   дъра_, karó, --, --, 
   {{0x1938001f,0xe164221d,0xe0413905,0x229000e4}},	//   _አመራሮ, _تضمی, _инчи, rãke_, 
   {{0x69cd3906,0xee706215,0xf424013d,0xdb1c0210}},	//   _pece, _аңны, _ğäli_, daró, 
   {{0x2bbc0a94,0x5e840022,0x00000000,0x00000000}},	//   ्रहा, _иуыз, --, --, 
   {{0x69cd3907,0xfd540882,0x66086316,0x8e7c00df}},	// [1ea90] _vece, ksaṃ, vegk, juĝi, 
   {{0x7e6c008f,0x7bdc0fac,0x69cc79d4,0x2b440139}},	//   _ĉapi, _gdpu, _wece, _жэмг, 
   {{0x69cc0548,0xb8d401b0,0x66092b98,0x537002d3}},	//   _tece, _चू_, tegk, ትራዊት_, 
   {{0x8e7c010f,0x00000000,0x00000000,0x00000000}},	//   fuĝi, --, --, --, 
   {{0x248c02d3,0xe9dc0030,0x6608417b,0x00000000}},	//   _ዝቃለስ_, _idú_, regk, --, 
   {{0xdb1d3908,0x660804e6,0x00000000,0x00000000}},	//   lbrá, segk, --, --, 
   {{0x66080036,0xdb1c0332,0x5c3808c3,0x00000000}},	//   pegk, obrá, ורגן_, --, 
   {{0x00c80131,0xdb1c000d,0xd7940395,0x00000000}},	//   плик_, varü, _рисъ, --, 
   {{0x629802d5,0xdb1c00cf,0x3104013d,0x98ac0055}},	//   rmuo, narò, енып_, _ādī_, 
   {{0x62982e70,0x7ff400d1,0xfd540055,0x00000000}},	//   smuo, رسخا, csaṃ, --, 
   {{0xe9dc143c,0x00000000,0x00000000,0x00000000}},	//   _odú_, --, --, --, 
   {{0xf77025f9,0xee344f88,0x00000000,0x00000000}},	//   רקט_, еню_, --, --, 
   {{0xc0f802d3,0x4128013e,0x425001d9,0xa3b0012d}},	//   ላቶም_, _холо_, _لۆژر, _टला_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x11d40133,0x00000000,0x00000000,0x00000000}},	//   _ستۆد, --, --, --, 
   {{0xf2d000c8,0x4ae00490,0xdb1c033f,0xfe70072d}},	//   טעל_, _फिरव, waró, _حدت_, 
   {{0xdb1d3909,0x6fd402e5,0x7bdcca01,0x7bd803b2}},	// [1eaa0] garò, _मजमू, _tdpu, ótus, 
   {{0x7e65390a,0x0c6802dd,0xe8f40153,0xed54030d}},	//   likp, _озық_, элу_, _чоь_, 
   {{0x9ac404a9,0x27e5390b,0xd9b402dd,0x2bbc11bc}},	//   _шинҗ, ónna_, _لەزد, ्ररा, 
   {{0x7c3d390c,0xdb1d12a0,0x99800165,0xd5a42e3e}},	//   _hopr, barò, teiń_, نلای, 
   {{0x7c3d390d,0x65c09919,0x624400e4,0xc8b42123}},	//   _kopr, убча, _iñoh, _ассы, 
   {{0x69c80579,0x7c3c00da,0x7e640bf1,0x7d14037e}},	//   ðgev, _jopr, hikp, _msys, 
   {{0x6fd409d9,0x7c3c0184,0x38b400ed,0x53340220}},	//   _मजबू, _mopr, _hær_, тейт, 
   {{0x7c3d390e,0xc32c1066,0x38b5390f,0xdecc01f3}},	//   _lopr, تەم_, _kær_, ጣጥና_, 
   {{0x9980038f,0x7c3c017a,0x6dc0063f,0xb7d0009e}},	//   jjiż_, _oopr, ọakw, ালীট, 
   {{0x38b41125,0x7c3d3910,0x2898010f,0xa13001d5}},	//   _mær_, _nopr, ּיטא, چریش, 
   {{0x38b53280,0xb5a8002e,0x7e645537,0x624400c7}},	//   _lær_, _b斡gg, fikp, _oñoh, 
   {{0x7aed3911,0x43740395,0x00000000,0x00000000}},	//   dubt, _руут, --, --, 
   {{0x38b53912,0x7c3c0032,0x32600014,0x63a00022}},	//   _nær_, _bopr, _لچکہ, _иқәҧ, 
   {{0x7c3d3913,0x624400c7,0x7d14062c,0xb800262c}},	//   _copr, _añoh, _dsys, र्मम_, 
   {{0x7c3c7c95,0x8e2c022e,0xabc801ec,0xdb1c03b2}},	//   _dopr, brdа_, _ﺑﯘﻋﺎ, tbrá, 
   {{0x38b40ac8,0x26dc01e4,0x7c3c02d0,0xffe801ee}},	//   _bær_, _ĉuo_, _eopr, _еләҫ_, 
   {{0x6ca49d39,0xeca4119e,0x00000000,0x00000000}},	// [1eab0] _прож, _пјон, --, --, 
   {{0x7c3d3914,0x624400c7,0x38b40fac,0xdb1d3915}},	//   _gopr, _eñoh, _dær_, rarò, 
   {{0x7aec0009,0x207800df,0x00000000,0x00000000}},	//   cubt, לאמא, --, --, 
   {{0x38b41bb0,0x6e3c0477,0x7d140022,0x7c3c0219}},	//   _fær_, _joqb, _ysys, _zopr, 
   {{0x38b4008c,0xdb1c01bf,0x7c3c02d0,0x6e28110e}},	//   _gær_, gbræ, _yopr, _ògbu, 
   {{0x86c4038b,0x624401c4,0xe78441bd,0x7e653916}},	//   _ليسن, _iñoi, _зубо, zikp, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9324004b,0xf1c400d1,0xfcf80092,0x00000000}},	//   ارون, نۈمى_, ቋረጥ_, --, 
   {{0x03f80640,0x841400a7,0x8854001f,0x28200023}},	//   _онај_, _имах, _መከታተ, _ሰማንያ, 
   {{0x66193917,0x20000209,0x8eb00725,0x00000000}},	//   _hauk, ýji_, ڭەيت, --, 
   {{0x66193918,0xaca002e3,0xdb1c008c,0xa3000046}},	//   _kauk, _chọg, jarð, _сүйе, 
   {{0x7c3d3919,0x4f94052f,0x6618b700,0x624400e4}},	//   _sopr, ырыу, _jauk, _oñoi, 
   {{0x0d99391a,0x7c65391b,0x6e3c0455,0x7e640784}},	//   етры_, ناسل, _doqb, rikp, 
   {{0x66181039,0x7e65391c,0x60d9391d,0x7aed391e}},	//   _lauk, sikp, msum, tubt, 
   {{0x38b45573,0xdb1c09cc,0xaca0063f,0x60d9391f}},	//   _sær_, garð, _ghọg, lsum, 
   {{0x66193920,0x7aed3921,0x60d811d4,0x7bc003b9}},	//   _nauk, rubt, osum, _şoud, 
   {{0x7c3d3922,0x7e740124,0xd9b400db,0x6e480240}},	// [1eac0] _topr, _ijyp, _ەەرد, _ዝረኣኽ, 
   {{0x38b45d16,0x60d80eda,0x7c3c01bf,0x7aec0175}},	//   _vær_, isum, _uopr, pubt, 
   {{0x66193923,0x62440022,0x7aec0455,0x00000000}},	//   _bauk, _eñoi, qubt, --, 
   {{0x38b41125,0x60d93924,0x66180055,0xdb1c01bf}},	//   _tær_, ksum, _cauk, tbræ, 
   {{0x66193925,0x60d80113,0x140400ee,0x00000000}},	//   _dauk, jsum, лҗаг, --, 
   {{0xe3ad3926,0xdb1c37e6,0xb7d83089,0x60d80034}},	//   يرى_, rbræ, _زورا_, dsum, 
   {{0x60d81730,0xdb1d3927,0x6350005b,0x8c48010e}},	//   esum, sbræ, ившу, lişý, 
   {{0x52153928,0x66193929,0xf2040104,0xe3b40075}},	//   удит, _gauk, тяко, нбә_, 
   {{0x6fd409d9,0xd0113133,0x60d8c792,0xe5a1392a}},	//   _मजदू, ملة_, gsum, _вити, 
   {{0x661802ce,0x6e3c0455,0xa4f4011a,0x00000000}},	//   _zauk, _soqb, _בצמד_, --, 
   {{0x60d80eda,0x6619392b,0x64a0039b,0x6e3c047e}},	//   asum, _yauk, _тафа, _poqb, 
   {{0x60d8208d,0xdb1c2833,0x6e3c0455,0xd3700451}},	//   bsum, varð, _qoqb, _پڇڻ_, 
   {{0xe0d40323,0x62440086,0x3204003e,0x60d800f3}},	//   _авч_, _añow, _iboy_, csum, 
   {{0x7e740109,0x60d4010f,0xdb1c007c,0x8c4800a2}},	//   _ejyp, _יודא_, kbrä, dişý, 
   {{0x6e3c025c,0x1bd41b0a,0x39540092,0xdb240174}},	//   _toqb, рося, _ለመወያ, ørðs, 
   {{0xddc40171,0xdb1c007c,0x5e84030d,0x00000000}},	//   _aliņ, dbrä, _вуьз, --, 
   {{0x6619392c,0x32040124,0xd8b82099,0xffa401ee}},	// [1ead0] _rauk, _mboy_, ندلا_, _иләү, 
   {{0x6619392d,0x75206041,0x00000000,0x00000000}},	//   _sauk, dvoz, --, --, 
   {{0x6619392e,0x8cb802ab,0x7e7400e4,0x3204007c}},	//   _pauk, _एंडो, _yjyp, _oboy_, 
   {{0x60d9392f,0x0a580107,0x00000000,0x00000000}},	//   ysum, _чамъ_, --, --, 
   {{0x64440227,0x66180810,0x752001a6,0x85040244}},	//   _ŋjiq, _vauk, gvoz, اوتن, 
   {{0x66193930,0xd5b80184,0x60d8036b,0x29080798}},	//   _wauk, нсә_, vsum, _ipca_, 
   {{0x66193931,0x32053932,0x7c2808ce,0x97a4119e}},	//   _tauk, _bboy_, _ófre, _вртл, 
   {{0x60d93933,0x2be00882,0x00000000,0x00000000}},	//   tsum, कृतं_, --, --, 
   {{0x7fd53934,0x60d820ac,0x25bc020b,0xfc440118}},	//   ліні, usum, _iful_, _říma_, 
   {{0x0494fe74,0x60d93935,0xbfc40006,0xdb1c007c}},	//   _صلاح, rsum, ыбок, lbrå, 
   {{0x60d93936,0x2efc010a,0x2908009f,0x3ea46135}},	//   ssum, gttf_, _lpca_, лиог, 
   {{0x60d93937,0x92b400db,0x29093938,0x13d80154}},	//   psum, _ئحلا, _opca_, _সায়, 
   {{0x25bc009a,0xc0e400cf,0xeb9400fb,0x60d80003}},	//   _mful_, _солк, ғит_, qsum, 
   {{0xe9dc0ca8,0x03e403d4,0x00000000,0x00000000}},	//   _olús_, প্ৰণ, --, --, 
   {{0x75200e8a,0x25bc0356,0xdb1c0037,0x00000000}},	//   zvoz, _oful_, harö, --, 
   {{0x1c0000af,0x7e740432,0xddc40171,0xf8e0000d}},	//   _लउकल_, _ujyp, _sliņ, _पिआय, 
   {{0x29080810,0xc8b400c7,0xdee00b01,0xada00818}},	// [1eae0] _cpca_, асхы, _соқи, _лаъл, 
   {{0x69c81ffb,0x25bc0198,0xe9dd3939,0x7520022e}},	//   ðger, _aful_, _slút_, vvoz, 
   {{0xbb445bd7,0xad980077,0x8d8401d3,0xf5e800d8}},	//   _сенк, nfún, _مشین, емел_, 
   {{0xd01c00bd,0xdb1c5df4,0xb908009e,0xe9dc007b}},	//   তায়_, rbrä, _মহ_, _dlús_, 
   {{0x32040286,0x27ec0216,0x66e07d9d,0xdb1c36b2}},	//   _rboy_, álné_, _қота, sbrä, 
   {{0x7521393a,0x00000000,0x00000000,0x00000000}},	//   rvoz, --, --, --, 
   {{0x3d147e29,0x59b806ab,0xb2840124,0x00000000}},	//   _पैसे_, _अलार, лыик, --, 
   {{0x20040429,0x64a000c7,0x00000000,0x00000000}},	//   _abni_, _ҳауа, --, --, 
   {{0xca48001f,0xdb1c0798,0x9054bde1,0xddd00139}},	//   _ዘገባዎ, marõ, ивиц, _şeşl, 
   {{0x78ac014f,0xa0641d39,0xdb1c0254,0x00000000}},	//   _jibv, лања_, larõ, --, 
   {{0x78ac05b8,0xd0102fc0,0xf2040a8d,0x600401c6}},	//   _mibv, ملک_, _бяло, ухыг_, 
   {{0x91c40075,0xdb1c0254,0x78ac01ef,0xbe3400d1}},	//   _тәкл, narõ, _libv, لىپب, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x13d8015b,0xf1d001e0,0x00000000,0x00000000}},	//   _সাড়, _төҫө, --, --, 
   {{0xdb1d393b,0xce9406bb,0x2908017a,0x16040401}},	//   ncrè, _какъ, _spca_, रभार_, 
   {{0x78ac006f,0x20040099,0xdb1c002d,0x00000000}},	//   _aibv, _zbni_, lbrû, --, 
   {{0x1959393c,0xe9dc002d,0xdb1c000d,0x1a78190b}},	// [1eaf0] гаты_, _slús_, darõ, убты_, 
   {{0xe9dc01a8,0x00000000,0x00000000,0x00000000}},	//   _plús_, --, --, --, 
   {{0x78ac014f,0xca64022e,0xdb1c01e3,0x0a94030d}},	//   _dibv, _ishо, tbrå, _ваню, 
   {{0x2bbc3174,0xbb38010f,0x97a5393d,0xf4840014}},	//   ्रका, _סערי, срул, یاوی, 
   {{0xd8780075,0x6aac0472,0xa564030f,0xdb1c369d}},	//   خمەت_, _iicf, ددان, rbrå, 
   {{0x97d9393e,0x6aac00f3,0x02c42bbe,0x229000e4}},	//   _مظفر_, _hicf, айко, tãko_, 
   {{0xd3d8314e,0x42540e58,0xdb1cf635,0x62440124}},	//   ابها_, итит, barõ, _oñot, 
   {{0x00e5393f,0x8234027d,0x00000000,0x00000000}},	//   ажин, شربا, --, --, 
   {{0xddd4003d,0x6ab53940,0x3f8800ef,0xb0f4009f}},	//   ħaża, _luxf, _ņau_, لفيض_, 
   {{0xad9800d2,0x00000000,0x00000000,0x00000000}},	//   tfún, --, --, --, 
   {{0x24842165,0x7f7413e7,0x6fd4012d,0x00000000}},	//   monm_, рупц, _मजरू, --, 
   {{0x6aac01c3,0x248401bf,0x00000000,0x00000000}},	//   _nicf, lonm_, --, --, 
   {{0x62893941,0x9e440131,0x528400c6,0x5fa000db}},	//   _ikgo, لىگۈ, _النك, _گەدم, 
   {{0xcee8158b,0x2484007f,0x2bbc024a,0x00000000}},	//   خرین_, nonm_, ्रगा, --, 
   {{0x05d413b4,0x78ac004c,0xb88000bc,0x6aac0356}},	//   दराब, _ribv, říka, _bicf, 
   {{0x4ed487e3,0x78ac57cb,0xdb1d3942,0x2448022c}},	//   _уюшт, _sibv, ncré, _dømi_, 
   {{0xf864a30d,0xe9dc00ae,0x69213943,0x7864537c}},	// [1eb00] авао, _plúr_, омта, аказ, 
   {{0x78ac014f,0x00000000,0x00000000,0x00000000}},	//   _qibv, --, --, --, 
   {{0x4878023a,0x7bcc0083,0x39e80798,0xdb1c00e4}},	//   устя_, mbbu, _идно_, tarõ, 
   {{0x62893944,0xddc400f3,0xfc44013a,0x00000000}},	//   _nkgo, _ljiž, _říha_, --, 
   {{0x78ac004c,0x00000000,0x00000000,0x00000000}},	//   _tibv, --, --, --, 
   {{0x24053945,0x62893946,0xdb1c00d8,0x00000000}},	//   инчи_, _akgo, sarõ, --, 
   {{0x66e0f1f4,0xe7346566,0xe3cc015b,0x00000000}},	//   _мора, _кер_, _রাখব, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7aec151c,0x62440789,0xdb1d0b13,0x944400c7}},	//   hrbt, _años, scrè, _лмаҵ, 
   {{0x503800d4,0x61f001ef,0x00000000,0x00000000}},	//   упою_, _čelů, --, --, 
   {{0xdb1c000f,0x00000000,0x00000000,0x00000000}},	//   rbrû, --, --, --, 
   {{0xdb1c0385,0xe4d80316,0x7bcc0337,0x6e640212}},	//   sbrû, zšíř, ebbu, ртож, 
   {{0x62440022,0x22480e78,0x7af8002e,0x00000000}},	//   _eños, öcke_, àttn, --, 
   {{0xa0653947,0xddc4002b,0x00000000,0x00000000}},	//   _кача_, _kliś, --, --, 
   {{0xc0d4044e,0x62447db4,0xaa641774,0x26140073}},	//   _ረብሓ_, _iñor, атак, _नसली_, 
   {{0xa92801ec,0x00000000,0x00000000,0x00000000}},	//   кізе_, --, --, --, 
   {{0x6aad3948,0xfe9801d3,0x298800d8,0x2484007f}},	// [1eb10] _vicf, _حصوں_, тсво_, yonm_, 
   {{0x6ab430ad,0x27c4117e,0xded00092,0x00000000}},	//   _tuxf, рщаг, ያገኝ_, --, 
   {{0xfbd00302,0xd1cc0023,0x7c2802d2,0x00000000}},	//   _מתי_, ቡራት_, _ófra, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x62440124,0x2484b238,0xdb1c0142,0xa8a40798}},	//   _oñor, tonm_, ncrî, _врвк, 
   {{0x58d40138,0x2dc80150,0xdb1c0162,0x588400c0}},	//   _форт, _ﺒﻘﻴﻤ, vbrú, _дыса, 
   {{0x2484083a,0x03a400c9,0x43442bb6,0x00000000}},	//   ronm_, щико, сейв, --, 
   {{0x62453949,0xd78800cf,0x97d801d3,0x2484007f}},	//   _añor, _ئنفو_, _مظہر_, sonm_, 
   {{0xbb540116,0x614019c5,0x00000000,0x00000000}},	//   ﺋﺎﻝ_, زىدە, --, --, 
   {{0xdb1d394a,0x00000000,0x00000000,0x00000000}},	//   scré, --, --, --, 
   {{0xdb1c041e,0x00000000,0x00000000,0x00000000}},	//   sbrú, --, --, --, 
   {{0x62880117,0x624400c7,0x7e55394b,0x3e700fda}},	//   _ukgo, _eñor, стоц, kšte_, 
   {{0x2e6400d1,0xdb1c76f7,0xad9800e5,0x00000000}},	//   сияп_, lbrø, lfúj, --, 
   {{0x0c79394c,0x14e00a59,0x00000000,0x00000000}},	//   ассы_, _निघण, --, --, 
   {{0xa2740201,0x0ba800db,0xb0500150,0x4fc004da}},	//   _ይህንን_, لافى_, _ءپىت, _تەپە, 
   {{0xda9002d3,0x00000000,0x00000000,0x00000000}},	//   _መብጽዓ_, --, --, --, 
   {{0xaa41394d,0x00000000,0x00000000,0x00000000}},	// [1eb20] четл, --, --, --, 
   {{0x8e7c01e4,0xdb1c005c,0x00000000,0x00000000}},	//   rsĝe, kbrø, --, --, 
   {{0x3eb000ad,0x370402dd,0xa3c8012d,0x00000000}},	//   _kiyt_, спег, लडन_, --, 
   {{0x6b8000e4,0xdb1c005c,0xf988009f,0xbaac02dd}},	//   _ÿnga, dbrø, _منجي_, _ﺳﺎﺣﺎ, 
   {{0xe3cc015b,0x6fe00118,0x2bbc012a,0x00000000}},	//   _রাজব, nící, ्रचा, --, 
   {{0x3eb00bc9,0x533422c3,0x628400e4,0xded00092}},	//   _liyt_, жект, _êjoj, ያገኙ_, 
   {{0xb5a8002e,0xdb1c037e,0xe7605822,0xc718010b}},	//   _g斡ng, gbrø, _еврп, _кютц_, 
   {{0x069008b0,0x2ba0003e,0xe31000db,0x00000000}},	//   ﯘﺭﻟﯩ, lécé_, سبىب, --, 
   {{0x6fe0038e,0xad980af2,0xb3e800f2,0x250800e5}},	//   jící, tfúm, _معضل_, _مرلی_, 
   {{0xdce4005f,0xb5a800e8,0xe80801ad,0x6fe00118}},	//   _dziļ, _y斡ng, स्पा_, dící, 
   {{0xfbbc9201,0x27e40413,0x00000000,0x00000000}},	//   ्डनम, ónni_, --, --, 
   {{0xe2944ed4,0x3e700118,0x00000000,0x00000000}},	//   _лах_, yšte_, --, --, 
   {{0x62440022,0x8e8401e4,0x21640114,0x00000000}},	//   _iñop, vaĝĉ, _лици_, --, 
   {{0x3a20063f,0xddd001a6,0xe0f80375,0x00000000}},	//   _aakp_, češk, _עלול, --, 
   {{0x4f8401d9,0x00000000,0x00000000,0x00000000}},	//   _باشہ, --, --, --, 
   {{0x95941e38,0x78b80316,0x298459b7,0xddc40115}},	//   ግስትን_, _čtvr, бызг, _kliŝ, 
   {{0x3e70110c,0x290d394e,0xc7d80395,0x00000000}},	// [1eb30] ušte_, ïga_, имах_, --, 
   {{0x2610001e,0x6d4d394f,0x3944005b,0x0cb406e3}},	//   _ảo_, myca, äosa_, ंदीम, 
   {{0x6d4d3950,0x62440124,0x85b800d8,0x26c4036e}},	//   lyca, _oñop, алес_, ëno_, 
   {{0x3e701467,0x2fdc05d5,0xdb1c2b96,0x00000000}},	//   pšte_, hatg_, vbrø, --, 
   {{0x69dc0912,0x6d4c14dc,0x26c40006,0x04440120}},	//   maqe, nyca, ūno_, желн, 
   {{0x38682948,0x69dcdeb6,0xdb1c2dba,0x00000000}},	//   _gmbr_, laqe, tbrø, --, 
   {{0x04c80451,0x6d4c02d0,0x00000000,0x00000000}},	//   _چوري_, hyca, --, --, 
   {{0x04c8e25c,0x6d4d3951,0x69dc02d3,0x00000000}},	//   _نوري_, kyca, naqe, --, 
   {{0x21293952,0xdb1c95b0,0x2fdc0c86,0xaef0015b}},	//   ích_, sbrø, fatg_, _জনগণ_, 
   {{0x6d4c0857,0x69dcb40c,0xca8c0150,0x00000000}},	//   dyca, haqe, _ﺒﻌﻴﺩ_, --, 
   {{0x53353953,0xe8080d0d,0xbea41fac,0xddc40115}},	//   _нефт, स्या_, жанк, _eliŝ, 
   {{0x6d4c03ac,0x00000000,0x00000000,0x00000000}},	//   fyca, --, --, --, 
   {{0xc0f802d3,0x69dc679e,0x6d4c03ac,0xd17401af}},	//   ዋቶም_, daqe, gyca, _нышы, 
   {{0x61f93954,0xf1b00bd9,0x3a200ea0,0xe8081223}},	//   lgul, _חסד_, _sakp_, स्मा_, 
   {{0x69dc02d3,0x6fe000bc,0x3ce402a0,0xb82000cc}},	//   faqe, sící, _झटके_, নামত_, 
   {{0x2a68070d,0x69dc401f,0xf9c800f7,0xd1cc001f}},	//   _cmcb_, gaqe, ргак_, _አቤት_, 
   {{0x38680af2,0x2cb00162,0x6d4c035a,0x5da800cc}},	// [1eb40] _pmbr_, _fixd_, cyca, _ক্ৰু, 
   {{0xd37801fa,0xad9800d7,0x00000000,0x00000000}},	//   _heće_, zfúk, --, --, 
   {{0x69dd23c9,0x490005f5,0xdb240108,0x61f93955}},	//   baqe, _үүсг, örär, kgul, 
   {{0x645c0240,0xdb1c00d8,0x00000000,0x00000000}},	//   ëqin, ncrí, --, --, 
   {{0x61f8005c,0x6a700327,0x34a8300e,0x00000000}},	//   dgul, għfu, авдо_, --, 
   {{0xc0d40201,0xf2c53956,0xd3783c52,0x61f8fd24}},	//   _የሥራ_, осин, _leće_, egul, 
   {{0x2448143a,0x6d4c15c0,0x00000000,0x00000000}},	//   _rømt_, zyca, --, --, 
   {{0xd37804b9,0x61f82f99,0x71093957,0x6b940209}},	//   _neće_, ggul, ахов_, _ýagş, 
   {{0x74140a2c,0x6d4d3958,0x733401ed,0x2fdc05d5}},	//   _وورا, xyca, _ڈرائ, tatg_, 
   {{0x7334092f,0x61f93959,0x00000000,0x00000000}},	//   _ورائ, agul, --, --, 
   {{0x8f35395a,0xb04001fb,0x2fdc07de,0x6d4c012d}},	//   ченц, _chưở, ratg_, wyca, 
   {{0x6d4c0c8c,0x7641395b,0x6fd40490,0xdce400a2}},	//   tyca, njoy, _मजकू, _aziı, 
   {{0x244800ed,0x00000000,0x00000000,0x00000000}},	//   _tømt_, --, --, --, 
   {{0x6d4d395c,0x69dd040e,0x00000000,0x00000000}},	//   ryca, waqe, --, --, 
   {{0x6d4c3cf7,0xd1b001d5,0x00000000,0x00000000}},	//   syca, _تیکک, --, --, 
   {{0xddc40ab7,0x6d4d395d,0x00000000,0x00000000}},	//   _iliş, pyca, --, --, 
   {{0x69dc02d3,0x79e800e5,0x00000000,0x00000000}},	// [1eb50] raqe, صولہ_, --, --, 
   {{0x61f93524,0xddc40790,0x00000000,0x00000000}},	//   zgul, _kliş, --, --, 
   {{0x61f9395e,0xa5d80fb4,0x69dc2a71,0x29180784}},	//   ygul, لبشر_, paqe, swqa_, 
   {{0x69dc014b,0xfb180375,0x2a680142,0xd1cc0092}},	//   qaqe, _פורמ, _umcb_, _አቤቱ_, 
   {{0x9f44007f,0x5dc80150,0x00000000,0x00000000}},	//   _ednè_, _ﺒﺘﻔﺴ, --, --, 
   {{0xe785395f,0xd7f800c0,0x6fd4000d,0x00000000}},	//   _дубо, _мус_, _मजगू, --, 
   {{0x61f93960,0xd4980032,0x45d400d8,0x00000000}},	//   tgul, өрә_, _новс, --, 
   {{0x3e700024,0xdb7c011a,0x00000000,0x00000000}},	//   kšta_, ינוכ, --, --, 
   {{0xe8080b26,0x41b400f8,0xd3780841,0xddc45775}},	//   स्था_, _ہمار, _reće_, _aliş, 
   {{0xd9b86b9b,0x047800ec,0x00000000,0x00000000}},	//   _अल्ट, _اجرڪ_, --, --, 
   {{0x442509c3,0xa2040259,0xe8000034,0xddc40356}},	//   _ial_, şmış_, _लाना_, _cliş, 
   {{0x64400552,0x44253961,0xe8081428,0xb8fc025c}},	//   ljni, _hal_, स्ता_, _ལྦ_, 
   {{0x44253962,0xd3780bb8,0xd50c043b,0x98b40118}},	//   _kal_, _veće_, _kɔ́n, _řeči_, 
   {{0xdb1d3963,0x44253964,0xb0400016,0x6440007c}},	//   scrí, _jal_, _thưở, njni, 
   {{0xf090011a,0xbb440108,0xe0d4009f,0x00000000}},	//   _רנו_, чевк, _اُڻڻ_, --, 
   {{0x44253965,0xaa4018ac,0x7db40214,0x99e413d5}},	//   _lal_, несл, _عصبا, čňov, 
   {{0x44240072,0xdb1c0112,0xddc40356,0x00000000}},	// [1eb60] _oal_, lbrü, _emiţ, --, 
   {{0x44253966,0xc078001e,0x64400113,0x00000000}},	//   _nal_, _điệp_, jjni, --, 
   {{0x225d3967,0x61e805ce,0x7bdd3968,0xb8001fd2}},	//   khuk_, _odgl, _iepu, र्गम_, 
   {{0x44253969,0x7bdd396a,0xdb1c0112,0x00000000}},	//   _aal_, _hepu, ibrü, --, 
   {{0x4425396b,0x7bdc7cba,0x225d396c,0x7641396d}},	//   _bal_, _kepu, dhuk_, rjoy, 
   {{0x4425396e,0x7bdd396f,0x61e93970,0x3950023a}},	//   _cal_, _jepu, _adgl, myys_, 
   {{0x44253971,0xdb1d3972,0x7bdd3973,0x00000000}},	//   _dal_, mbró, _mepu, --, 
   {{0x7bdd3974,0x6b5401b8,0x4424a1bc,0x6d480129}},	//   _lepu, lügö, _eal_, _àgag, 
   {{0x555401d9,0xe8000f44,0xf0740131,0x3950005b}},	//   _تھار, _लामा_, зипә_, nyys_, 
   {{0x44253975,0x61e8740d,0xd3e404fb,0x212c0076}},	//   _gal_, _edgl, _آقای, _drgh_, 
   {{0xb8fc2b65,0x05b000db,0xdb1c002f,0x39500108}},	//   _ལས_, _كۅۅح, gbrü, hyys_, 
   {{0x44253976,0x225d3977,0x7bdc01f7,0x7980033f}},	//   _zal_, chuk_, _aepu, żowy, 
   {{0x44253978,0xd50c1aac,0x7bdc01b9,0xdb1c03b2}},	//   _yal_, _yɔ́n, _bepu, rbrý, 
   {{0x44253979,0x7bdc005f,0x3e700024,0xdb1c002f}},	//   _xal_, _cepu, ršta_, bbrü, 
   {{0x7bdd397a,0x5f9007b5,0x00000000,0x00000000}},	//   _depu, _пишт, --, --, 
   {{0x64400158,0xc6100154,0xea600066,0x588400c7}},	//   zjni, _সোনা_, رپذی, ҽыха, 
   {{0x7bdd266c,0x6440033f,0x9a847125,0x00000000}},	// [1eb70] _fepu, yjni, хурл, --, 
   {{0x7bdc08f7,0x588401c0,0xdb1c03b2,0x0f400023}},	//   _gepu, ныха, gbró, _ንመስከ, 
   {{0x4425397b,0x80c4009e,0x00000000,0x00000000}},	//   _ral_, লীপ্, --, --, 
   {{0x4425397c,0xa3cc0574,0x7bdd397d,0x64400113}},	//   _sal_, वुन_, _zepu, wjni, 
   {{0x7bdc0810,0x213c011f,0xd9400023,0x44240e21}},	//   _yepu, xxuh_, _ኣጸቢቕ, _pal_, 
   {{0x4425397e,0x63e0005e,0xa491397f,0xb38c0023}},	//   _qal_, ريبە, ریات, _ምንዋሕ_, 
   {{0x44253980,0x225c04fb,0x64400267,0x21f0010b}},	//   _val_, thuk_, rjni, еҗес, 
   {{0x56953981,0x44253982,0xddc53983,0x05e400ec}},	//   _заст, _wal_, _omiš, _آڳاٽ, 
   {{0x44253984,0x00180006,0x00000000,0x00000000}},	//   _tal_, оўны_, --, --, 
   {{0x44253985,0x7f74177b,0x225cfa7e,0x00000000}},	//   _ual_, думц, shuk_, --, 
   {{0x7bdd3986,0x225c009a,0x00000000,0x00000000}},	//   _repu, phuk_, --, --, 
   {{0xdb1c6047,0x7bdd3987,0x1ee4066d,0xd2440276}},	//   rbrü, _sepu, _ہوتی_, _пэчи, 
   {{0x7bdd3988,0xdb1d1920,0x212c0142,0x6c9c00b8}},	//   _pepu, sbrü, _urgh_, _sūnṛ, 
   {{0x3950023a,0x31200014,0x4c8002dd,0x7bdc036e}},	//   vyys_, _شہپٲ, лғыз, _qepu, 
   {{0x41d02413,0xab253989,0x450800eb,0x00000000}},	//   _सभास, мора_, লিটক_, --, 
   {{0xe808228d,0x7bdd398a,0xfe70211f,0xceb800c0}},	//   स्सा_, _wepu, _جدت_, avęs_, 
   {{0x7bdc5df1,0xff240133,0x00000000,0x00000000}},	// [1eb80] _tepu, _ربژی, --, --, 
   {{0x7d1400c7,0xd3781710,0x7bdc009f,0x59dc012c}},	//   _ipys, _leća_, _uepu, बरहर, 
   {{0xdb1c0597,0x395002f6,0xddc40010,0x26c401e4}},	//   rbró, syys_, _zmiš, ŭnon_, 
   {{0xdb1c1427,0x98a00064,0x00000000,0x00000000}},	//   sbró, dvią_, --, --, 
   {{0xaa40004e,0x234400d1,0xf51800db,0x00000000}},	//   _реял, ېلىپ_, تتاش_, --, 
   {{0x3e700006,0xdb2402d2,0x00000000,0x00000000}},	//   kšto_, _ásól, --, --, 
   {{0x92940588,0xe80005f9,0x63000372,0xe3ac00f1}},	//   накц, _लाता_, نوول, ټرو_, 
   {{0x35a400db,0xb9e40257,0x06e000cc,0x00000000}},	//   _жабг, _ክን_, মূহি, --, 
   {{0x23cc190c,0x00000000,0x00000000,0x00000000}},	//   _स्वद, --, --, --, 
   {{0x64a00022,0x00000000,0x00000000,0x00000000}},	//   _аауа, --, --, --, 
   {{0x7d142b61,0xddc405ce,0xdbcc01e1,0xc0c80092}},	//   _apys, _smiš, _lóód, _በወር_, 
   {{0x22291655,0x1b140154,0x00000000,0x00000000}},	//   _وزنی_, াটাই_, --, --, 
   {{0x601402e3,0x7ebc02f0,0x660c01e3,0x200c0064}},	//   ụmak, vápň, _öcke, _ūmių_, 
   {{0xceb804b4,0x00000000,0x00000000,0x00000000}},	//   _нәм_, --, --, --, 
   {{0x7d15398b,0x4c9464b6,0x00000000,0x00000000}},	//   _epys, _җинс, --, --, 
   {{0x9a8401c6,0x00000000,0x00000000,0x00000000}},	//   вуул, --, --, --, 
   {{0xa3cc9d6d,0xaca0063f,0xddc42804,0x9980010e}},	// [1eb90] वुड_, _ajụg, _umiš, ngiň_, 
   {{0x5c741fdf,0x2aa8016c,0x00000000,0x00000000}},	//   _альт, стҳо_, --, --, 
   {{0x8440002e,0xade0033f,0x69d80254,0xb90408d1}},	//   _ng斡m, _ख़ान_, _õueo, _यौ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x09a8025c,0x00000000,0x00000000,0x00000000}},	//   _བཛྲ_, --, --, --, 
   {{0x03a4b4cb,0xd3783341,0x00000000,0x00000000}},	//   нило, _seća_, --, --, 
   {{0x260407d8,0xd37801a6,0x3ce40037,0x9980010e}},	//   _очаг, _peća_, _जौने_, egiň_, 
   {{0x96340104,0x6e280332,0xe8080b98,0x02040022}},	//   _инсц, _ógbh, स्रा_, хзин, 
   {{0xd37804b9,0x04c800ec,0x00000000,0x00000000}},	//   _veća_, _روضي_, --, --, 
   {{0x21a001d5,0x708000cf,0x00000000,0x00000000}},	//   ниқм, лгыз, --, --, 
   {{0xe3b13896,0x7d15398c,0xc2f803d4,0x7c28148b}},	//   _شرط_, _spys, _আনকি_, _ófri, 
   {{0x3f98198e,0x3e700024,0x2000031c,0x00000000}},	//   āsu_, ršto_, żji_, --, 
   {{0xee3405c1,0x916c0208,0xfbbc08df,0xfeb80133}},	//   хня_, _gồm_, ्डलम, _کاتت_, 
   {{0x629800a9,0xb60002d2,0x00000000,0x00000000}},	//   lluo, _þávi, --, --, 
   {{0x3f78008f,0x7b98104c,0x00000000,0x00000000}},	//   _מאַס, سپرس_, --, --, 
   {{0x3dd800bd,0xeab4c064,0xad99398d,0x6299398e}},	//   _থাকল, ейс_, tfút, nluo, 
   {{0x62980108,0x2ca80118,0x00000000,0x00000000}},	// [1eba0] iluo, _židů_, --, --, 
   {{0xb880278a,0x00000000,0x00000000,0x00000000}},	//   _čísl, --, --, --, 
   {{0x6299398f,0x00000000,0x00000000,0x00000000}},	//   kluo, --, --, --, 
   {{0x98a00e3c,0x11880241,0x00000000,0x00000000}},	//   kvić_, _ṣíbí_, --, --, 
   {{0xad9810e6,0xa9b8011a,0x00000000,0x00000000}},	//   lfúr, _מזכר, --, --, 
   {{0x1c042e2a,0x87c0030d,0x00000000,0x00000000}},	//   श्चल_, _кăшт_, --, --, 
   {{0xc7953990,0x62993991,0x2894011a,0x00000000}},	//   _арты, fluo, _נדלן_, --, 
   {{0x64a00032,0xe7341fbe,0x2280013d,0x629802d2}},	//   _ҡата, _џет_, луыг, gluo, 
   {{0xe0cc20bf,0x98a001a6,0xe3b400fd,0xe8740092}},	//   یزی_, gvić_, мбә_, _በረጅም_, 
   {{0x752025d0,0x62980108,0xef640b01,0x00000000}},	//   mwoz, aluo, еъмо, --, 
   {{0x1c0413f5,0x629801e4,0x845400db,0xe80005dc}},	//   श्छल_, bluo, _جىلچ, _लासा_, 
   {{0xd37805be,0x75200083,0x62980129,0x1fa0699d}},	//   _hećo_, owoz, cluo, ырыг, 
   {{0xfe6d252c,0x9da80395,0x00000000,0x00000000}},	//   تگو_, еъра_, --, --, 
   {{0xdcf003e0,0x00000000,0x00000000,0x00000000}},	//   şeği, --, --, --, 
   {{0xad9800d2,0x00000000,0x00000000,0x00000000}},	//   tfús, --, --, --, 
   {{0x66e4012c,0x75200083,0x26c40030,0x1f34011a}},	//   _léká, kwoz, ínom_, _טרור_, 
   {{0x3e60032e,0x69d8000d,0xffa401af,0x00000000}},	// [1ebb0] _fótb_, _õuem, _пләү, --, 
   {{0x7520033f,0xf0f4022e,0xad9803b2,0x00000000}},	//   dwoz, g鼠iq_, sfús, --, 
   {{0x6298089c,0x9980549d,0x00000000,0x00000000}},	//   yluo, rdiš_, --, --, 
   {{0xfb1855b4,0xfd5400b8,0xe8002c35,0x2d980200}},	//   _کریں_, _apaṇ, _लावा_, _kyqe_, 
   {{0x5a353992,0x15b93993,0xeb500220,0xa1c002dd}},	//   _снят, нышы_, _شىڭگ, құлд, 
   {{0x68fc058a,0x00000000,0x00000000,0x00000000}},	//   muqd, --, --, --, 
   {{0x070800ec,0x5c380375,0x752004ba,0x8624004b}},	//   _تيزي_, תרון_, awoz, _ټکال, 
   {{0xdec802d3,0x62993994,0x8fd4035b,0x00000000}},	//   _በረኻ_, uluo, қәшә, --, 
   {{0x44b53995,0x7fd402dd,0x00840139,0xd514cfad}},	//   _абас, кіні, клио, _مبلغ, 
   {{0x62980eed,0x26c00055,0x00000000,0x00000000}},	//   sluo, _kujo_, --, --, 
   {{0xf1d008ec,0x2008068f,0x68fc014f,0xdb1c343a}},	//   _ध्वन, ęci_, huqd, lbrö, 
   {{0x27e0038f,0x26c0098d,0xee342b9c,0x0ea400e1}},	//   _lejn_, _mujo_, вню_, _गीदड, 
   {{0x26c0015b,0x42500014,0xc2f800cc,0xdb1d3996}},	//   _lujo_, _مۆژر, _আনটি_, nbrö, 
   {{0x2f080428,0x5a3c001f,0x68fd3997,0xb4f80375}},	//   bùg_, _አለመቻ, duqd, ופשי, 
   {{0xeb953998,0xfe0809fd,0x25bc00ee,0xebe00fac}},	//   вир_, _वापस_, _ogul_, росп, 
   {{0x25bd3999,0x6a80756b,0xc0b8012c,0x2d9000b4}},	//   _ngul_, алса, řádá, ụkụ_, 
   {{0x27e0038f,0xad98172e,0x00000000,0x00000000}},	// [1ebc0] _bejn_, lgún, --, --, 
   {{0x25bc00d5,0xed540375,0xbc6843fb,0xbb8400ae}},	//   _agul_, _סביר_, _آمدن_, _للخي, 
   {{0x7c3d399a,0x26c006ed,0x27e00003,0x370410de}},	//   _inpr, _cujo_, _dejn_, тпег, 
   {{0x956400ee,0x00000000,0x00000000,0x00000000}},	//   лнеҗ, --, --, --, 
   {{0x27e01f21,0x2d8c04ce,0xdb1c007c,0x7c2c02d0}},	//   _fejn_, _øget_, gbrö, odbr, 
   {{0x26c000ec,0xb4b004a9,0x7c2c0f85,0x64a0009d}},	//   _fujo_, шилә, ndbr, аача, 
   {{0xb5c407d6,0x26c00009,0x53ac03ce,0x7c28032e}},	//   _айбл, _gujo_, टेंश, _ófru, 
   {{0xdb1c007c,0x00000000,0x00000000,0x00000000}},	//   bbrö, --, --, --, 
   {{0x30a42cfe,0x00000000,0x00000000,0x00000000}},	//   кров, --, --, --, 
   {{0x27e0038f,0x26c0020c,0xa0641d39,0x0f400023}},	//   _xejn_, _yujo_, кања_, _ንመልከ, 
   {{0x6f080408,0x26c00067,0xb8cc0327,0xcdc400d1}},	//   _qqfc, _xujo_, _ྕེ_, ләпп, 
   {{0x7c3cc22a,0x4374dd5c,0xc2e8007b,0x2004036e}},	//   _anpr, _суут, _أعلم_, _ecni_, 
   {{0xbc5c02d3,0x7c2c01f5,0x826000cf,0xe800107c}},	//   _ታሪኽና_, fdbr, _دۇين, _लाला_, 
   {{0xd011399b,0x5f7004fb,0x6ec91430,0x68fc01d5}},	//   _طلب_, اایر, _संपु, vuqd, 
   {{0x1fa00801,0x27e00115,0xabb000d1,0xa0641f5a}},	//   _кръг, _rejn_, равә, _јаја_, 
   {{0x7c3d399c,0x26c0019f,0x7c2c0a73,0x27e001a6}},	//   _enpr, _rujo_, adbr, _sejn_, 
   {{0x2d8c20ef,0x26c1399d,0x00000000,0x00000000}},	// [1ebd0] _âge_, _sujo_, --, --, 
   {{0x26c109ee,0x68fc7caa,0xdca40114,0x2611399e}},	//   _pujo_, ruqd, _кањи, _ṣo_, 
   {{0x3e6112fe,0x27e1399f,0xab6000d1,0x68fc014f}},	//   _hóta_, _vejn_, _ئۇزى, suqd, 
   {{0x26c00114,0x2d8c00b5,0xcfe8009e,0x3e600241}},	//   _vujo_, _øges_, পলিন, _kóta_, 
   {{0x7c3c002d,0x64700022,0x68fd39a0,0xa56401f7}},	//   _ynpr, аҳау, quqd, خدان, 
   {{0xdb1d39a1,0x3e600252,0x26c00427,0xd838010a}},	//   rbrö, _móta_, _tujo_, _иэс_, 
   {{0xaca001f2,0xd40539a2,0x69cc0327,0xdb1c01e3}},	//   _nkọg, рячи, _kfce, sbrö, 
   {{0x25bc003e,0x422401f4,0xa2300139,0x00000000}},	//   _ugul_, удив, рькә, --, 
   {{0x3e6000c6,0x0134129e,0x614000c7,0x00000000}},	//   _nóta_, اعبد, рҵла, --, 
   {{0x73300131,0x659001ec,0xe8a401ec,0x3e7000c0}},	//   شىۋا, _бағу, ншiк_, mšti_, 
   {{0xa1f005d9,0xa30002dd,0xed5408eb,0x7c3c013a}},	//   _نياڻ, _түйе, қор_, _rnpr, 
   {{0x3e6139a3,0x00000000,0x00000000,0x00000000}},	//   _bóta_, --, --, --, 
   {{0xacb80a85,0x66c0016b,0x52b005a9,0x3e6000ae}},	//   rwûn, rεky, _بەيئ, _cóta_, 
   {{0xd9dc0d2c,0x69cc0009,0x7e640240,0x998000d7}},	//   बर्ट, _afce, shkp, ndiť_, 
   {{0x7c2c2d62,0x7c3c0051,0x7bc003e3,0x00000000}},	//   rdbr, _vnpr, _şous, --, 
   {{0xcfe802a6,0x69cc005a,0x3e700006,0x3e602507}},	//   _খায়_, _cfce, kšti_, _fóta_, 
   {{0x8d281248,0xad9939a4,0x9e740131,0xa9640395}},	// [1ebe0] _аның_, ngúl, _مۇھت, гита_, 
   {{0x88cc03d4,0xc61000cc,0x00000000,0x00000000}},	//   _লিখক, _সোলা_, --, --, 
   {{0x2d8c037e,0xf77000c6,0xc8b52377,0xc32402f2}},	//   _øger_, حاء_, рсты, _بڕ_, 
   {{0x6b7827af,0x89d402bf,0x998000d0,0x2f94010f}},	//   _טרינ, _вірш, ediť_, אכען_, 
   {{0x7e740077,0x00000000,0x00000000,0x00000000}},	//   _mmyp, --, --, --, 
   {{0xb7d939a5,0x1cac031c,0x53700023,0x0584003b}},	//   _سورا_, _ྗེས_, ስያዊት_, шуєм, 
   {{0x870801ed,0x00000000,0x00000000,0x00000000}},	//   _لڑنے_, --, --, --, 
   {{0xe29410fc,0x6568031c,0x649c00e4,0x99800419}},	//   лај_, bzgh, hêih, adiť_, 
   {{0xe1ed39a6,0x0674010b,0xe5a00b00,0x2eec007c}},	//   سسي_, _туря, _гити, _svff_, 
   {{0x2518008f,0x3e6008ce,0xb62c0150,0xb60c0150}},	//   _אומא, _róta_, _ﺒﻔ_, _ﺴﻊ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x22900491,0x38a405da,0x6278010f,0x00000000}},	//   _النس, zôra_, _אנאנ, --, 
   {{0x3e6000c6,0xdfd00153,0x00000000,0x00000000}},	//   _vóta_, _лошы, --, --, 
   {{0x716c001f,0x68ec03ac,0x2aa80114,0x00000000}},	//   ስፋፋት_, _svcd, етао_, --, 
   {{0x290406c8,0xceb80b8d,0x5bb8034b,0x99800030}},	//   ̄nau_, _шәп_, улся_, zdiť_, 
   {{0x7c6539a7,0x00000000,0x00000000,0x00000000}},	// [1ebf0] _چاپل, --, --, --, 
   {{0x7c649a79,0xd3640e56,0x00000000,0x00000000}},	//   _ناپل, _فۇ_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe8900022,0x8a600244,0x00000000,0x00000000}},	//   шаҕь, _بێرۆ, --, --, 
   {{0x7bd00086,0xc9d40131,0x716c001f,0x98a00115}},	//   _òkuñ, _ﭘﻪﻳﻐ, ስፋፉት_, lviĝ_, 
   {{0x3e700006,0x82f40114,0x23cc0073,0xe808012d}},	//   ršti_, ачиц, सुंद, स्खा_, 
   {{0x03a42ec9,0x998000d0,0xdc3c00d9,0x00000000}},	//   шико, rdiť_, תעור, --, 
   {{0x3e700cf4,0x00000000,0x00000000,0x00000000}},	//   pšti_, --, --, --, 
   {{0xb62c0150,0x72b4007b,0x683c0092,0x00000000}},	//   _ﺒﺔ_, جهيز_, _ባሌስት, --, 
   {{0xad9939a8,0x50d8210e,0xb1f003b2,0x00000000}},	//   rgúl, اگنگ_, íðrú, --, 
   {{0xfe441c22,0xdb1c00c6,0xd14803ff,0x00000000}},	//   анно, scrú, نشین_, --, 
   {{0x42a401af,0x00000000,0x00000000,0x00000000}},	//   _тузғ, --, --, --, 
   {{0xc0e539a9,0x92b51e4f,0x1f940137,0x614000db}},	//   _толк, _احلا, _өйдө_, _دىشە, 
   {{0xddc40024,0x00000000,0x00000000,0x00000000}},	//   _kliū, --, --, --, 
   {{0xbea539aa,0x65b800fd,0x00000000,0x00000000}},	//   _какк, _yähü, --, --, 
   {{0xeabc01ab,0x6ec823ef,0x225c009a,0x0ae80ef8}},	//   _ciù_, _संतु, nkuk_, طرفي_, 
  
   {{0xdee139ab,0xeabd39ac,0x00000000,0x00000000}},	// [1ec00] _тоқи, _diù_, --, --, 
   {{0xeabc0ffb,0xf7b939ad,0xb8640b24,0x00000000}},	//   _eiù_, نداش_, جارو, --, 
   {{0x8d8434c9,0x225caac5,0xeabc0e89,0xfaa42bb6}},	//   _نشین, kkuk_, _fiù_, _вано, 
   {{0xeabc00a7,0x3e6139ae,0x7ae00210,0x12d001ec}},	//   _giù_, _móto_, _łotw, _ﻗﺎﻨﻭ, 
   {{0xf9904e76,0xe3cc03d4,0xa50402e8,0x00000000}},	//   _ذبح_, _ৰাজব, иеца_, --, 
   {{0x38a40109,0xb60000bc,0xddc400c0,0x3a300432}},	//   môro_, _řádk, _bliū, ldyp_, 
   {{0x326539af,0x00000000,0x00000000,0x00000000}},	//   итив, --, --, --, 
   {{0x225c020c,0x3e700064,0x00000000,0x00000000}},	//   gkuk_, oštu_, --, --, 
   {{0xdb240008,0x26c402fb,0x66540354,0x00000000}},	//   _ósæm, ínov_, _татă, --, 
   {{0x32c80016,0xd37816a3,0x69d80037,0x00000000}},	//   _tùy_, _leći_, _õuev, --, 
   {{0xe80400e1,0x9f4400d8,0xad98004e,0xc4300133}},	//   शलता_, _henê_, rgúm, _رکوت, 
   {{0x38a40109,0x64c00046,0xe294014b,0x3e700153}},	//   kôro_, _ايەل, _ках_, kštu_, 
   {{0xeabc00a3,0x21a0010a,0xa2bc000d,0x00000000}},	//   _riù_, _дицм, _लूट्, --, 
   {{0x3e6000e4,0x7e6c0327,0xa0640063,0x00000000}},	//   _fóto_, _ċape, _ваља_, --, 
   {{0xeabd39b0,0xdb58169c,0xee841c22,0xa3e40073}},	//   _più_, ают_, _выпо, परत_, 
   {{0x59f81de1,0x7af860d0,0xdef418ce,0x9b583bcd}},	//   иеся_, átta, _тыш_, шист_, 
   {{0x27c407d8,0x9f4400d8,0x7b840075,0x195800db}},	// [1ec10] ащег, _nenê_, _ғәрб_, ааты_, 
   {{0xc31c2158,0x4cdc0eac,0x00000000,0x00000000}},	//   থিতি_, _বিপু, --, --, 
   {{0xc5d44dba,0x00000000,0x00000000,0x00000000}},	//   біль, --, --, --, 
   {{0xdb240158,0x00000000,0x00000000,0x00000000}},	//   ørås, --, --, --, 
   {{0xfd8800d1,0x00000000,0x00000000,0x00000000}},	//   ﺯﻏﺎﻥ_, --, --, --, 
   {{0x80d42158,0xd918010a,0xddc400c0,0x5b340244}},	//   _দিল্, _тью_, _pliū, _اعیر, 
   {{0x7cfc01a8,0x00000000,0x00000000,0x00000000}},	//   _kærð, --, --, --, 
   {{0x569539b1,0xc2443e0c,0x26c40306,0x00000000}},	//   _даст, сник, ínou_, --, 
   {{0x4094014b,0x2fd000a2,0x00000000,0x00000000}},	//   йрот, _şyga_, --, --, 
   {{0x3e600270,0x7cfc01a8,0x225c005a,0x00000000}},	//   _póto_, _lærð, skuk_, --, 
   {{0xa3b800c6,0x02180212,0x00000000,0x00000000}},	//   _شاطر_, _біль_, --, --, 
   {{0x3e600022,0x7cfc032e,0x00000000,0x00000000}},	//   _vóto_, _nærð, --, --, 
   {{0xd37804b9,0x9f4402d3,0x661939b2,0xd1480214}},	//   _reći_, _kenë_, _mbuk, _نشون_, 
   {{0x60d939b3,0x9f44044e,0xd37800f3,0xa3e4726b}},	//   mpum, _jenë_, _seći_, परि_, 
   {{0x661939b4,0xd37856af,0x2efc0618,0x60d939b5}},	//   _obuk, _peći_, crtf_, lpum, 
   {{0x6aac0334,0x661801e1,0x9f44036e,0xcf880139}},	//   _chcf, _nbuk, _lenë_, _әсәд_, 
   {{0xd3781326,0x394406ed,0xa3e42052,0xe8380118}},	// [1ec20] _veći_, ãos_, परा_, _řeší, 
   {{0x7d040664,0x9f4400d8,0x3e700153,0xef28010e}},	//   muks, _renê_, rštu_, _çüý_, 
   {{0x661939b6,0x7d0539b7,0xe7340f25,0x7cfc0008}},	//   _bbuk, luks, йеф_, _færð, 
   {{0x64440248,0x00000000,0x00000000,0x00000000}},	//   _òjij, --, --, --, 
   {{0x7d0539b8,0x9f440200,0x00000000,0x00000000}},	//   nuks, _benë_, --, --, 
   {{0x8454104b,0xe0fc03d4,0x855401d5,0xf744aec3}},	//   يىنچ, ্বাহ_, غیلر_, _лего, 
   {{0x7d0539b9,0x978401e2,0x60d823fc,0x00000000}},	//   huks, _بیاه, epum, --, 
   {{0xba00067d,0x7d0539ba,0x66f4011a,0x92580116}},	//   _ውን_, kuks, _למלא_, раит_, 
   {{0x60d89b41,0x9f440023,0xddc4010e,0x7d043b22}},	//   gpum, _fenë_, _iniň, juks, 
   {{0x7d0539bb,0xb6400efb,0x66180023,0x00000000}},	//   duks, _ﺃﻥ_, _zbuk, --, 
   {{0x7d040254,0xa2d002da,0x00000000,0x00000000}},	//   euks, _فيلت, --, --, 
   {{0x9f4539bc,0x6e6400a7,0x229000c7,0x02a400d4}},	//   _menè_, стож, kãky_, _дрім, 
   {{0xa3cc033d,0xe7e8012c,0x7d044199,0x9d18299f}},	//   वुक_, टरमा_, guks, боят_, 
   {{0xd1e002d3,0xddc401a6,0x1bd41faf,0xad9848bf}},	//   _ዑቕባ_, _gmiž, зоря, ngúi, 
   {{0xa00438eb,0x6014011a,0x7d040064,0xad9800d7}},	//   _اقىل_, _החוף_, auks, nfúz, 
   {{0xbd9800b4,0x12d00150,0x00000000,0x00000000}},	//   ọpụt, _ﻗﺎﻤﻭ, --, --, 
   {{0xad98002d,0x7d0526aa,0xc0c000a2,0x00000000}},	// [1ec30] hfúz, cuks, _üįün, --, 
   {{0x9f4539bd,0xab8539be,0x00000000,0x00000000}},	//   _benè_, _гумк, --, --, 
   {{0x8a1800a8,0x7c3806af,0x9f44036e,0x00000000}},	//   _конс_, ôtre, _renë_, --, 
   {{0xadf87382,0x60d812ed,0xfd600248,0x00000000}},	//   ्लिन_, ypum, _niwọ, --, 
   {{0x17e80c58,0x9f440200,0xdb24007c,0x00000000}},	//   _পাৰি, _penë_, örör, --, 
   {{0x9f44069c,0x58d539bf,0xd37801a6,0x26c41155}},	//   _qenë_, _хорт, _leću_, ínos_, 
   {{0x850539c0,0x436801c0,0x9f440240,0x45d4030d}},	//   _ژورن, райн_, _venë_, _мовс, 
   {{0x661939c1,0xd3780bb8,0xd788708e,0xddc40419}},	//   _ubuk, _neću_, _انفو_, _smiž, 
   {{0x83780201,0x9f44006a,0x60d80194,0x6fd80490}},	//   _እንዲህ_, _tenë_, upum, _म्हं, 
   {{0xe3b012dd,0x60d939c2,0x7d04005b,0x1b1000cc}},	//   _فرض_, rpum, vuks, াবতে_, 
   {{0x9f44020c,0x60d939c3,0xf07401ed,0x7e907bc9}},	//   _kené_, spum, تیوں_, hāpe, 
   {{0x7d04426d,0x60d939c4,0x7e90005f,0x66086085}},	//   tuks, ppum, kāpe, nggk, 
   {{0x4034bafa,0x9f44004a,0x2e3c0139,0x00000000}},	//   _медс, _mené_, _säfä_, --, 
   {{0x212c009a,0x61e9348b,0xf07800fd,0x629939c5}},	//   _isgh_, _hegl, _кичә_, louo, 
   {{0x60c8008c,0x61e939c6,0xe800000d,0x6e9000ec}},	//   _hugm, _kegl, _लाजा_, _ڪليا, 
   {{0x60c139c7,0x60c80099,0x61e939c8,0xaa403f36}},	//   _hinm, _kugm, _jegl, месл, 
   {{0x61e939c9,0x60c80114,0x60c139ca,0x5ca400cf}},	// [1ec40] _megl, _jugm, _kinm, _ىلبە, 
   {{0x61e939cb,0x60c0016d,0xdcb000db,0x284400cf}},	//   _legl, _jinm, _سۉز_, озуп_, 
   {{0xbc691655,0x60c139cc,0x60c939cd,0x629800b0}},	//   _ممکن_, _minm, _lugm, kouo, 
   {{0x60c12f04,0x61e939ce,0xfaa42377,0xfbe000cc}},	//   _linm, _negl, _фамо, _বাটত, 
   {{0x28c003f3,0x9f441df3,0xe4d000db,0x59b401c0}},	//   _वंचि, _dené_, وتوب, _хөвс, 
   {{0x533410e0,0x60c139cf,0x61e8f392,0xdef4001f}},	//   зект, _ninm, _aegl, ላለን_, 
   {{0x61e939d0,0x60c81948,0x3e600051,0xad9801e7}},	//   _begl, _augm, _cótk_, rgúi, 
   {{0x60c139d1,0x7d400020,0x9f44004e,0xa7a402bf}},	//   _ainm, ክርስቲ, _gené_, _єкта_, 
   {{0x61e939d2,0x60c139d3,0xdb1c0332,0xf44800e5}},	//   _degl, _binm, ocró, _پلاٹ_, 
   {{0x60c939d4,0x212c0076,0x60c139d5,0xfd600ca8}},	//   _dugm, _dsgh_, _cinm, _wiwọ, 
   {{0x9eac1682,0x60c139d6,0x61e80c86,0x60c800a3}},	//   _ṱoḓa_, _dinm, _fegl, _eugm, 
   {{0x60c139d7,0x61e939d8,0x00000000,0x00000000}},	//   _einm, _gegl, --, --, 
   {{0xd378098d,0x60c81aef,0x3eb01368,0x6ec800c5}},	//   _veću_, _gugm, _dhyt_, _सूरु, 
   {{0x60c00ecf,0x61e92abb,0x271400bc,0x333c0175}},	//   _ginm, _zegl, něná_, _krtx_, 
   {{0x3eb00076,0x61e939d9,0x60c8002f,0x6608007c}},	//   _fhyt_, _yegl, _zugm, yggk, 
   {{0x63a4037e,0x8cf539da,0xe8e4031c,0x7e90f981}},	//   _øjne, _езиц, _སྦུག, tāpe, 
   {{0x60c0016d,0x00000000,0x00000000,0x00000000}},	// [1ec50] _yinm, --, --, --, 
   {{0xec2000db,0x3eb0036e,0x3ce40200,0x00000000}},	//   _تۉسپ, _zhyt_, _çova_, --, 
   {{0x537c0201,0xd7c8415f,0xd5d801f2,0xc5d4177b}},	//   _እንዴት_, زونه_, _ịrụr, піль, 
   {{0xc6100154,0x00000000,0x00000000,0x00000000}},	//   _সোজা_, --, --, --, 
   {{0xa4300124,0xdec80023,0x00000000,0x00000000}},	//   мҭац, _በየን_, --, --, 
   {{0x61e939db,0x6d4c0369,0x6a1401d3,0x00000000}},	//   _segl, ixca, _ابھر, --, 
   {{0x60c139dc,0x96f8da97,0x62980270,0x29fc012d}},	//   _rinm, _мерт_, touo, ałał_, 
   {{0x60c139dd,0x32240135,0x28ac0034,0xfe08012d}},	//   _sinm, _རྒྱར_, _जीति, _वाइस_, 
   {{0x61e939de,0x60c139df,0x5ba80b8f,0x3eb00363}},	//   _vegl, _pinm, _गर्व, _rhyt_, 
   {{0x60c0014f,0x6298037e,0xd78800e5,0x00000000}},	//   _qinm, souo, _انہو_, --, 
   {{0x60c0b3f8,0x3eb00076,0x6298009f,0x6d4cb71a}},	//   _vinm, _phyt_, pouo, exca, 
   {{0x60c939e0,0x7af8041e,0xd19c00b4,0x61e84d04}},	//   _tugm, áttm, ịbụl_, _uegl, 
   {{0x60c139e1,0x3e6000d2,0x00000000,0x00000000}},	//   _tinm, _jóti_, --, --, 
   {{0x3e601bb0,0x00000000,0x00000000,0x00000000}},	//   _móti_, --, --, --, 
   {{0xe9dc0008,0x4520009e,0x3e6001e1,0x81bc0165}},	//   _snúa_, ফটিক_, _lóti_, zeœl, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe8c400db,0x30d800fe,0x00000000,0x00000000}},	// [1ec60] згул_, _দিৱস, --, --, 
   {{0x44e8068f,0xe8f40006,0x6b980356,0x00000000}},	//   dź_, ялу_, şuga, --, 
   {{0x762539e2,0x271400bc,0xe9dc01e1,0x56640244}},	//   змез, věná_, _inún_, وگرف, 
   {{0x69d80254,0xdb1c01e7,0x00000000,0x00000000}},	//   _õuep, scró, --, --, 
   {{0xa3e400dc,0xe4d402ef,0xc730002e,0x99800003}},	//   परं_, كونت_, _ñéné, ndiż_, 
   {{0xc0d4001f,0xc0f8001f,0x3e6008a5,0x00000000}},	//   _ከሥራ_, _ለሥራ_, _dóti_, --, 
   {{0x3e600e33,0x65cc01ec,0x29fc012d,0x42ac00b8}},	//   _tóth_, _ﯗﻛﯩﻠ, słał_, _ṣoḍh, 
   {{0xe61539e3,0x3e606316,0x066402dd,0xf1a80133}},	//   _ндс_, _fóti_, _قاقپ, یاکه_, 
   {{0xfa580208,0x00000000,0x00000000,0x00000000}},	//   _đập_, --, --, --, 
   {{0xc4c40c8b,0x2934010f,0xee3c015d,0xa3e400cd}},	//   _قتلو, לאפן_, glýn_, परः_, 
   {{0x3f983c7a,0x20e00107,0x00000000,0x00000000}},	//   şsun_, мсӯҳ, --, --, 
   {{0x2c6c0e78,0x00000000,0x00000000,0x00000000}},	//   _müde_, --, --, --, 
   {{0x4cdc0c58,0x626001c0,0x6140119e,0x00000000}},	//   _বিহু, _явца, _пеца, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xaa6504cd,0xceb80116,0x90b40166,0x1ac800c7}},	//   птак, _мәм_, _нәүш, зууп_, 
   {{0x69a801f7,0x00000000,0x00000000,0x00000000}},	//   ماءُ_, --, --, --, 
   {{0xda78010b,0x7c34007c,0x00000000,0x00000000}},	// [1ec70] чяр_, ögrä, --, --, 
   {{0x7e900882,0x2ca40162,0x00000000,0x00000000}},	//   māpa, _ónd_, --, --, 
   {{0xe6c4f67c,0xddc406be,0x00000000,0x00000000}},	//   ستاي, _koiş, --, --, 
   {{0x5d8401d5,0x5694011c,0x00000000,0x00000000}},	//   _آلیل, нахт, --, --, 
   {{0xb6c000f7,0x95c92db4,0x58d4014b,0x00000000}},	//   төрд, чуха_, _поят, --, 
   {{0x9f44026c,0x03a539e4,0x42d80818,0x6d4806af}},	//   _benì_, мило, офия_, _àgau, 
   {{0x7e900882,0x2c1c00dc,0x7e64143a,0x62840ca8}},	//   hāpa, म्यं_, ykkp, _ìjok, 
   {{0x161401ad,0x3cec00c5,0x3e60032e,0x7330215c}},	//   _डायर_, _अबले_, _tóti_, ئىيا, 
   {{0x7e900882,0x56946566,0xdef40023,0x00000000}},	//   jāpa, _чатт, ላወን_, --, 
   {{0x65900150,0x00000000,0x00000000,0x00000000}},	//   _жағу, --, --, --, 
   {{0x4cdc04c5,0x636801c6,0x00000000,0x00000000}},	//   _বিষু, _ураг_, --, --, 
   {{0xd1b801ed,0x41b40633,0x00000000,0x00000000}},	//   _کاما_, _قمار, --, --, 
   {{0x1ee43b8c,0x00000000,0x00000000,0x00000000}},	//   _کوبی_, --, --, --, 
   {{0xcee82491,0x9f440418,0x3f688cff,0x00000000}},	//   _کرون_, _hení_, _мило_, --, 
   {{0xfaa40006,0xddc40356,0x6fd00037,0x00000000}},	//   даво, _foiş, _सलतं, --, 
   {{0x4cdc00bd,0x2c6c0112,0x6e140150,0xfbc40107}},	//   _বিরু, _rüde_, _قيىس_, збҳо, 
   {{0x9f440030,0x16145b82,0x2c6c04e6,0x77380092}},	// [1ec80] _mení_, _डाबर_, _süde_, _የሚመደ, 
   {{0xa920023b,0x00000000,0x00000000,0x00000000}},	//   ъдул, --, --, --, 
   {{0xdb245d8a,0x00000000,0x00000000,0x00000000}},	//   äräs, --, --, --, 
   {{0x9f44038e,0x00000000,0x00000000,0x00000000}},	//   _není_, --, --, --, 
   {{0x6aa00120,0x28ac66eb,0x6d48004e,0x80c84a01}},	//   _ênfa, _जीवि, _àgat, _हंगे, 
   {{0xa4740014,0x7bc006be,0x00000000,0x00000000}},	//   وٝنا_, _şouy, --, --, 
   {{0x3668023b,0x00000000,0x00000000,0x00000000}},	//   _даво_, --, --, --, 
   {{0xd2500597,0x9f4402f0,0xd1340063,0xa440008e}},	//   انة_, _cení_, енић, енәд, 
   {{0xd010007b,0x00000000,0x00000000,0x00000000}},	//   هلة_, --, --, --, 
   {{0x15f869af,0x9f440ffb,0xd9b000eb,0x00000000}},	//   ुलकर_, _tenì_, _কলাম, --, 
   {{0x3e6006ea,0x7d0401c7,0xa06406ed,0xc4c4007b}},	//   _lótu_, erks, фаќа_, _ستكو, 
   {{0x7870037e,0x3940002f,0x00000000,0x00000000}},	//   _hævd, _orks_, --, --, 
   {{0x82080489,0xa1100014,0x39402c95,0x3e6002d2}},	//   _ཁྐྲི_, _لونت, _nrks_, _nótu_, 
   {{0x80d400bd,0x81b400b1,0x00000000,0x00000000}},	//   _দিচ্, _яңыр_, --, --, 
   {{0x260c0c2e,0xdeed39e5,0x69c80010,0x00000000}},	//   _डाली_, _шы_, žgem, --, 
   {{0x7e909db5,0x506401d9,0x7d0401a6,0xef480023}},	//   pāpa, _زاڈِ, brks, _ንመዓል, 
   {{0x4fc00075,0x2bc801a9,0xe7e801f9,0x00000000}},	// [1ec90] _جەھە, _муно_, टरला_, --, 
   {{0xec6800d8,0x00000000,0x00000000,0x00000000}},	//   _фрик_, --, --, --, 
   {{0x39400254,0xee3c0306,0x00000000,0x00000000}},	//   _erks_, hlým_, --, --, 
   {{0xe7dcbc82,0x85b939e6,0xddc4054e,0xee3c0306}},	//   _प्रप, плес_, _uliţ, klým_, 
   {{0x15b80cef,0x286807b5,0x00000000,0x00000000}},	//   мышы_, _дрво_, --, --, 
   {{0x78700158,0x3e6006ea,0xee3c0c5e,0x00000000}},	//   _rævg, _hótt_, dlým_, --, 
   {{0x57a539e7,0x97a42cc8,0x00000000,0x00000000}},	//   _ашта, _артл, --, --, 
   {{0x7af805f7,0x98a0033f,0xf770010f,0x00000000}},	//   átti, twić_, _עקן_, --, 
   {{0x9f440789,0xc0bc02d3,0x00000000,0x00000000}},	//   _vení_, _ተሪር_, --, --, 
   {{0x6ec8012c,0x51a800db,0x53e40064,0x00000000}},	//   _संखु, بدىپ_, _ацца, --, 
   {{0x6724013f,0x7eb40124,0x2360032e,0x00000000}},	//   _jpjj, hápe, _æjj_, --, 
   {{0x3e60008c,0x614000c7,0xddc40064,0x69c80010}},	//   _nótt_, _аҵиа, _ališ, žgej, 
   {{0x6f18074d,0x787004ce,0xddc40010,0x00000000}},	//   attc, _hæve, _bliš, --, 
   {{0x1ee40244,0x29180139,0x00000000,0x00000000}},	//   _قوتی_, dtqa_, --, --, 
   {{0x6f1807d5,0xad980005,0x787003cd,0x5f74315b}},	//   cttc, ugúr, _jæve, _تاشر, 
   {{0xfde8036b,0xddc40216,0xfaa539e8,0x00000000}},	//   _эдик_, _eliš, хабо, --, 
   {{0x67240054,0x3ea00064,0x4f380240,0x00000000}},	// [1eca0] _apjj, mokt_, _ቦርደር, --, 
   {{0xddc4009b,0x3ea00582,0x00000000,0x00000000}},	//   _gliš, lokt_, --, --, 
   {{0x39400076,0x7870005c,0xdb08002f,0x00000000}},	//   _wrks_, _næve, ßläu, --, 
   {{0xb8f403f4,0x3e600413,0xb8d400cc,0x5fdc28d4}},	//   _সব_, _gótt_, _চং_, पुतल, 
   {{0xaa40b754,0x7bd8002e,0x2c6c0205,0x24e4004e}},	//   _сеял, ñtuw, _hüda_, емчи_, 
   {{0x3ea001a4,0x7870005c,0xf314010b,0xf7180006}},	//   hokt_, _bæve, енкә_, _нібы_, 
   {{0x9f4405da,0xf2c4de5f,0x925800f7,0x3ea00250}},	//   _nenà_, нсин, дайт_, kokt_, 
   {{0x04000729,0x2c6c07c5,0x787003cd,0x62d004fb}},	//   ল্লী_, _müda_, _dæve, دآور, 
   {{0x6aa00998,0x64c80a94,0x7c2c5794,0xa5043e4f}},	//   _ínfe, ादृश, kebr, _пета_, 
   {{0x7c2d39e9,0xd25139ea,0xd01008de,0x00000000}},	//   jebr, انک_, جلد_, --, 
   {{0xdef44077,0x3ea001a4,0xee3c0306,0xfa1c0327}},	//   ныя_, fokt_, slým_, ེབཙན_, 
   {{0xddc4151c,0xaca0063f,0x7d0001e4,0xdbc80139}},	//   _sliš, _mmụg, _ĥosr, _möäz, 
   {{0x7c2c51d2,0x3e60659a,0x00000000,0x00000000}},	//   febr, _rótt_, --, --, 
   {{0x3e600008,0x00000000,0x00000000,0x00000000}},	//   _sótt_, --, --, --, 
   {{0xa6e401fb,0x00000000,0x00000000,0x00000000}},	//   _chứ, --, --, --, 
   {{0x9a84a006,0x673800e2,0x9e0800db,0xda3400c0}},	//   гуул, _ņujo, _كيىك_, лесы, 
   {{0xddc41ebd,0x4814376d,0x7c2c013f,0x99d40346}},	// [1ecb0] _tliš, кмас, bebr, اتفا, 
   {{0x7c2d39eb,0x3e6003b2,0xceb8000f,0x7eb402f0}},	//   cebr, _fóts_, stęd_, rápe, 
   {{0x2c6c07c5,0xd3140408,0x00000000,0x00000000}},	//   _güda_, _хiит, --, --, 
   {{0x97a43955,0xc8f400a7,0x787000b5,0x35f00116}},	//   урул, _измъ, _ræve, қпәр, 
   {{0x64c81944,0x69cd39ec,0xddec00c8,0x9f440030}},	//   ादेश, _igce, פֿאָ, _mená_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc2440d4b,0x73d40b8d,0x78703778,0x7c2d39ed}},	//   тник, ндәр_, _væve, zebr, 
   {{0x78700869,0x6ec80037,0x00000000,0x00000000}},	//   _wæve, _संजु, --, --, 
   {{0xe5b057aa,0x787000b5,0x7c2c056a,0x7e900374}},	//   _айғы, _tæve, xebr, tāpo, 
   {{0x44241529,0x7c2c1347,0x3ea139ee,0x2484007f}},	//   _ibl_, vebr, tokt_, minm_, 
   {{0x69cc00f1,0x9f4400e4,0x248400ca,0x7e900374}},	//   _ngce, _cená_, linm_, rāpo, 
   {{0x44240280,0x7c2d39ef,0x2c6c00c5,0xed540395}},	//   _kbl_, tebr, _süda_, воя_, 
   {{0x4a7401ec,0xff24022e,0x00000000,0x00000000}},	//   қыст, _амко, --, --, 
   {{0x4424008c,0x68ec02d0,0xaed006ed,0x3cec01ad}},	//   _mbl_, _awcd, _којш, _अबके_, 
   {{0xf2d000c8,0xbea40228,0x442539f0,0x2ef00166}},	//   שען_, _шайк, _lbl_, _өзәр, 
   {{0x7c2c03cd,0x00000000,0x00000000,0x00000000}},	// [1ecc0] pebr, --, --, --, 
   {{0x69cc01f0,0xa6e4004d,0xc954010b,0x16140037}},	//   _egce, _thứ, ытсы, _डाहर_, 
   {{0x39e8224f,0xf77008de,0xf748007b,0x00000000}},	//   _одно_, جاء_, بلاي_, --, 
   {{0x7af82833,0xdb140428,0x2f58008f,0x00000000}},	//   áttu, _òaña, ודענ, --, 
   {{0x3ce401f9,0xe5a0011c,0x00000000,0x00000000}},	//   जीचे_, аици, --, --, 
   {{0x442539f1,0x0ba80150,0xdef401f3,0x00000000}},	//   _cbl_, _تاۋى_, _ገጹን_, --, 
   {{0x23240640,0x1fe40154,0x00000000,0x00000000}},	//   воји_, পণাস, --, --, 
   {{0x442400a3,0xe2940261,0x00000000,0x00000000}},	//   _ebl_, кај_, --, --, 
   {{0x44240522,0x35a40022,0x3cec000d,0x00000000}},	//   _fbl_, _рааг, _अबगे_, --, 
   {{0xb35401ed,0x00000000,0x00000000,0x00000000}},	//   _لیتا_, --, --, --, 
   {{0x3e700064,0x00000000,0x00000000,0x00000000}},	//   lšty_, --, --, --, 
   {{0x7bdc01bf,0x44240051,0x00000000,0x00000000}},	//   _afpu, _zbl_, --, --, 
   {{0x6e2c0115,0x3e600139,0x9da80395,0x00000000}},	//   recb, _pótr_, въра_, --, 
   {{0x39a80153,0x44251107,0x207000c0,0xdfd0d673}},	//   _mėsą_, _xbl_, _кліў, _кошы, 
   {{0x69cc00a3,0x1af4011c,0x00000000,0x00000000}},	//   _pgce, ипря, --, --, 
   {{0xcfa41638,0xd1cc0020,0x3efc0327,0x2484007f}},	//   _ишқи, _ባሉት_, _དྷིའ_, zinm_, 
   {{0x58d539f2,0x2c186225,0x7e9000e2,0x98f4007b}},	// [1ecd0] иотт, _बापू_, kāpj, لثلا, 
   {{0x632c0092,0x00000000,0x00000000,0x00000000}},	//   ደተጠበ, --, --, --, 
   {{0x7eb539f3,0x2cf002ab,0x44240254,0x00000000}},	//   lápa, _अबुल_, _rbl_, --, 
   {{0x44240354,0x857539f4,0x00000000,0x00000000}},	//   _sbl_, ллех, --, --, 
   {{0x7eb48ef6,0x44240217,0x151400d4,0x55040798}},	//   nápa, _pbl_, идця, ачја, 
   {{0x2c6c05d5,0xaa8000a2,0x03543c1a,0x83380108}},	//   _müdo_, _diýň, лүзә_, ечит_, 
   {{0x44240254,0x88e400eb,0x00000000,0x00000000}},	//   _vbl_, _ফটিক, --, --, 
   {{0x44240419,0x00000000,0x00000000,0x00000000}},	//   _wbl_, --, --, --, 
   {{0x442539f5,0x00c80c72,0xd68539f6,0xd314074d}},	//   _tbl_, нлик_, _турп, _хiот, 
   {{0x3fe43c8f,0xd5b8d10a,0x442539f7,0xe9dc03b2}},	//   ыжов, _рсс_, _ubl_, _lfú_, 
   {{0x8214c009,0x9eb422f9,0x3e88054d,0x3f6801c6}},	//   _مواص, ишмә, ейно_, хино_, 
   {{0xfce539f8,0xcee82c26,0xbd4405d9,0x9f4400a2}},	//   ломо, کرین_, هنجي, _lenç_, 
   {{0x224c00f2,0xeb941ee3,0xccf40220,0x2c6c03e3}},	//   _ingk_, ҳир_, ақы_, _cüdo_, 
   {{0x7f40074d,0xd1b80014,0x00000000,0x00000000}},	//   pvlq, _شانا_, --, --, 
   {{0x5d140075,0x161405f9,0xeb9539f9,0xab2539fa}},	//   _ھېسا, _डालर_, гир_, лора_, 
   {{0x2c6c01b8,0xa3b8007d,0x5fdc0bae,0xb8642b9f}},	//   _füdo_, _घरन_, पुरल, گارو, 
   {{0x394539fb,0xbd8800b2,0x999c0118,0x00000000}},	// [1ece0] íos_, _سندن_, ěvů_, --, 
   {{0xe9dc0093,0xb864a268,0x7af803b2,0xed54010a}},	//   _efú_, دارو, átts, _соь_, 
   {{0xe7e005f9,0x35d003d4,0xd9102bd9,0x394401e4}},	//   गड़ा_, াৰোহ, _ژیر_, ŭos_, 
   {{0xe704141b,0xb3d00131,0x00000000,0x00000000}},	//   اسلی, әййә, --, --, 
   {{0x6aa00998,0xe8f40276,0xae1400df,0x00000000}},	//   _ínfa, _йля_, אַוו_, --, 
   {{0x9f447764,0x7c3d39fc,0x224c003e,0x64a080cd}},	//   _genç_, _japr, _angk_, бача, 
   {{0x7c3cab21,0x7eb40122,0xf4280116,0xe9dc08a5}},	//   _mapr, zápa, _җоел_, _snúi_, 
   {{0x7c3c2178,0x9f44008e,0xd58801e0,0xf0e800d4}},	//   _lapr, _menä_, _иҙел_, ньок_, 
   {{0x7c3c0022,0x63800124,0x73e4014b,0x21a4008e}},	//   _oapr, игәа, _бозз, ләшү_, 
   {{0x224d39fd,0x7eb40113,0x00000000,0x00000000}},	//   _engk_, vápa, --, --, 
   {{0x2c1939fe,0x9f44023a,0xe2700137,0x3a300162}},	//   _बाबू_, _nenä_, ркөө, keyp_, 
   {{0x7eb40030,0xb644037e,0x00000000,0x00000000}},	//   tápa, _ｈａ_, --, --, 
   {{0x7c3c3feb,0xee3c02fb,0x51180006,0x00000000}},	//   _bapr, rdý_, _ролю_, --, 
   {{0xdfcc0491,0x7eb4fd0f,0x00000000,0x00000000}},	//   _فيه_, rápa, --, --, 
   {{0x7c3d1175,0x8cd44a61,0xb818009e,0x7eb400e4}},	//   _dapr, _यूरो, ড়াত_, sápa, 
   {{0x7c3cb4b7,0x00000000,0x00000000,0x00000000}},	//   _eapr, --, --, --, 
   {{0x9fc40022,0x787139ff,0x7af80162,0x00000000}},	// [1ecf0] _игәа_, _sæva, áttr, --, 
   {{0x13cc00bd,0x7c3c003e,0xe7e0009e,0x00000000}},	//   রুয়, _gapr, মণ্য, --, 
   {{0x9f453a00,0x47353a01,0x290400b0,0x00000000}},	//   _genä_, рнес, ōna_, --, 
   {{0x7c3d3a02,0x6e3c003d,0xa6a800f7,0x2c180037}},	//   _zapr, _jaqb, رااق_, _बाडू_, 
   {{0xd6193a03,0x7c3d3a04,0x6e3d3a05,0x2cf001f9}},	//   اتما_, _yapr, _maqb, _अबोल_, 
   {{0x78701b25,0x04453a06,0xe5b0010b,0x9f440139}},	//   _hævn, рекн, айҗы, _yenä_, 
   {{0x224c0ac5,0xd40400f5,0x00000000,0x00000000}},	//   _pngk_, сячи, --, --, 
   {{0x7870037e,0x6e3c102c,0x41040640,0x6d480135}},	//   _jævn, _naqb, азив, _ġgan, 
   {{0x66193a07,0x90e44bcf,0x4094013e,0x00000000}},	//   _icuk, یسین, ирот, --, 
   {{0xceb40184,0xe9dc0248,0x008421cb,0x443002f0}},	//   ҙҙы_, _inúu_, рлоо, _úz_, 
   {{0x7c3d3a08,0x66180036,0x6e3c0009,0x224d3a09}},	//   _rapr, _kcuk, _baqb, _tngk_, 
   {{0x7c3d3a0a,0x787004ce,0xbea46d57,0x6e3c0009}},	//   _sapr, _nævn, рамк, _caqb, 
   {{0x7c3d3a0b,0x61f93a0c,0x9f44d84a,0xc0f80023}},	//   _papr, maul, _senä_, ፋቶም_, 
   {{0x61f93a0d,0x4a74052f,0x0d80052f,0x31780bd9}},	//   laul, ҡытт, яһын, _באנד, 
   {{0x6b613a0e,0x7c3d3a0f,0x6d480bcd,0x9f440139}},	//   окра, _vapr, _ágan, _qenä_, 
   {{0x61f93a10,0x7c3c08bb,0x7e901c52,0x00000000}},	//   naul, _wapr, kāpi, --, 
   {{0xe9d52bf7,0x60d90ad2,0x7c3d3a11,0xa96401d5}},	// [1ed00] рку_, nqum, _tapr, аита_, 
   {{0x66193a12,0x3b8421fa,0x7e7402d2,0x2cf80a7c}},	//   _acuk, _влог, _hlyp, _שליא, 
   {{0x61f93a13,0x7e744673,0x7eb53a14,0x5fa81b57}},	//   kaul, _klyp, nápo, _घुमल, 
   {{0x75453a15,0x6e3c058a,0x89d40212,0xf62409a0}},	//   инез, _xaqb, _гірш, рддо, 
   {{0x61f89b85,0xd3f00248,0xa6300046,0x00000000}},	//   daul, _aṣẹg, інші, --, 
   {{0x6618009a,0xddc4033f,0xa3c000dc,0x649400fb}},	//   _ecuk, _bliź, ृशं_, ҫтәр_, 
   {{0x61f93a16,0x7e742d19,0x7eb53a17,0x00000000}},	//   faul, _olyp, jápo, --, 
   {{0x61f93a18,0x00000000,0x00000000,0x00000000}},	//   gaul, --, --, --, 
   {{0xb5a80597,0x60d81cdf,0x60f40953,0x6e3c0009}},	//   _شارك_, gqum, аныя_, _raqb, 
   {{0x7640022c,0x6e3c102c,0x7e7400ee,0x75209ca2}},	//   ldoy, _saqb, _alyp, mtoz, 
   {{0x7520066d,0x7e7405e4,0x61f85161,0x72047b43}},	//   ltoz, _blyp, baul, _نوام, 
   {{0x76413a19,0x7e742be3,0x661805b1,0x6e3c016d}},	//   ndoy, _clyp, _xcuk, _qaqb, 
   {{0xa180da8f,0x9d144e5a,0x764006af,0x6e3c047e}},	//   _мышл, одяч, idoy, _vaqb, 
   {{0x75200099,0x6e3c0477,0x7eb400e5,0xaf48009d}},	//   itoz, _waqb, bápo, _ачиж_, 
   {{0x705004d3,0x935c001f,0x9b693a1a,0x6e3d3a1b}},	//   _هۆکا, ዳልሆነ_, ашта_, _taqb, 
   {{0x49a40150,0x69a801c8,0x00000000,0x00000000}},	//   бызғ, ناءُ_, --, --, 
   {{0xdebc0302,0x76400429,0x2d8d3a1c,0x787001bf}},	// [1ed10] _במהל, ddoy, _äge_, _vævn, 
   {{0x61f93a1d,0x6568062c,0xd364129d,0x656c010e}},	//   zaul, vygh, _قۇ_, _üchi, 
   {{0x61f80cfe,0x32053a1e,0x75200083,0xfbf001c0}},	//   yaul, _odoy_, etoz, _хүсь, 
   {{0x7640020c,0x60d80309,0x3ed8010f,0x290c00a3}},	//   gdoy, yqum, אַסא, àgas_, 
   {{0x454400c6,0xddc400ef,0x00000000,0x00000000}},	//   إنتق, _eniņ, --, --, 
   {{0x61f83f5d,0x78702c95,0x6568005c,0x6b98054e}},	//   waul, _jævl, rygh, şugu, 
   {{0x61f88243,0x96f91421,0xd5b82c22,0x066400c7}},	//   taul, _вест_, лсә_, _лхаҭ, 
   {{0x6618e276,0x60d80113,0x76400009,0x7dd003b2}},	//   _ucuk, tqum, cdoy, iðsø, 
   {{0x75213a1f,0x7fd402dd,0x8574010a,0x00000000}},	//   ctoz, йіні, _улах, --, 
   {{0xcea800c8,0x3204003e,0x61f89b0d,0x60d8e4a3}},	//   _װי_, _edoy_, saul, rqum, 
   {{0x61f93a20,0x60d80309,0x505802d5,0x6da000d1}},	//   paul, squm, ршыя_, җира, 
   {{0x61f80d04,0x7eb400e5,0x00000000,0x00000000}},	//   qaul, rápo, --, --, 
   {{0x60d80af5,0x62780034,0x7964013f,0xc0e401a9}},	//   qqum, głoś, kɔwa, _уолк, 
   {{0x28d8534e,0x9f453a21,0x64413a22,0x225d3a23}},	//   _बढ़ि, _menú_, ndni, ljuk_, 
   {{0x20040a73,0xdb2400ee,0xccdc0150,0xbb44003b}},	//   _idni_, _ösüm, _ﺘﻭﺼل_, щевк, 
   {{0x225d3a24,0x6aa00998,0xeabd3a25,0x00000000}},	//   njuk_, _ínfl, _chù_, --, 
   {{0xe9dc0561,0x7640022e,0x00000000,0x00000000}},	// [1ed20] _anús_, vdoy, --, --, 
   {{0xe9dc002d,0x644000b5,0xf1b008a8,0xada0030d}},	//   _snút_, jdni, לסן_, _хаьл, 
   {{0x6440049f,0x7aa40139,0xfaa400c0,0x290c00a3}},	//   ddni, _гинз, _гано, àgar_, 
   {{0x64400385,0x35f80150,0x00000000,0x00000000}},	//   edni, اراد_, --, --, 
   {{0x76413a26,0x225c00dd,0x5fd42ac3,0x55580006}},	//   rdoy, djuk_, ठशाल, раля_, 
   {{0x75213a27,0x7e900a26,0x64a00006,0xc0d40023}},	//   rtoz, māpu, пача, _ከብሎ_, 
   {{0xacb8002d,0x00000000,0x00000000,0x00000000}},	//   ktûn, --, --, --, 
   {{0x200401ed,0x644000d0,0x225c01d3,0x6278012d}},	//   _adni_, adni, gjuk_, yłoś, 
   {{0x30a4013d,0x315800c6,0xc0d40023,0x00000000}},	//   йров, اجعة_, _ከብል_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa30801ed,0x92b401ec,0x73980958,0x23242cdd}},	//   _مرنے_, _وڭعا, _стас_, _гохи_, 
   {{0xe1f53a28,0x2c1817c6,0x00000000,0x00000000}},	//   _ггц_, _बाहू_, --, --, 
   {{0x9f4400a7,0x2d9c004a,0x717000db,0x00000000}},	//   _menù_, çue_, _رۇدا, --, 
   {{0xae78009d,0xd8cc01ec,0x00000000,0x00000000}},	//   тсүх_, _ﺒﺎﻻﻟ, --, --, 
   {{0x5f913a29,0xeabc0016,0xdb593a2a,0xa3c80034}},	//   _ништ, _phù_, бют_, रेप_, 
   {{0x64413a2b,0x6fb00014,0x9ed40395,0x00000000}},	//   zdni, _وۅکا, _умът_, --, 
   {{0x19593a2c,0x644020e4,0x2c6c05d5,0x14a80210}},	// [1ed30] баты_, ydni, _lüdi_, गवाण, 
   {{0x81bc00bd,0xee3c0413,0x27c40108,0x00000000}},	//   _আলম_, plýs_, бщег, --, 
   {{0xeabc001e,0x7bf82063,0xad980798,0xab600150}},	//   _thù_, _өнөр_, saúd, _عۇرى, 
   {{0xd7c808f0,0x9f440241,0x00000000,0x00000000}},	//   حومه_, _penú_, --, --, 
   {{0xa3c809bb,0x00000000,0x00000000,0x00000000}},	//   रेन_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x225c00dd,0x02c427a8,0x00000000,0x00000000}},	//   tjuk_, ойко, --, --, 
   {{0x00e53a2d,0x826800d8,0x00000000,0x00000000}},	//   ожин, раив_, --, --, 
   {{0x225c01ed,0x00000000,0x00000000,0x00000000}},	//   rjuk_, --, --, --, 
   {{0xd37804a9,0x225cb6a6,0x047400f7,0xa4400133}},	//   рчә_, sjuk_, _بئرگ, _رێبو, 
   {{0xefc401c6,0x225c00e5,0x00000000,0x00000000}},	//   жлэл_, pjuk_, --, --, 
   {{0x7e7400db,0x00000000,0x00000000,0x00000000}},	//   زاجئ, --, --, --, 
   {{0x763804ac,0x6288010a,0xacb93a2e,0x00000000}},	//   בערג, _imgo, rtûn, --, 
   {{0x91c0052f,0xdfd80801,0xbc1802dd,0xa0200327}},	//   _яҙыл, _съд_, шімі_, _འཁྲང_, 
   {{0x8fc400db,0x2c18000d,0x00000000,0x00000000}},	//   _ىزىن, _बारू_, --, --, 
   {{0xa3c8813f,0x7e913a2f,0x00000000,0x00000000}},	//   रेय_, tāpu, --, --, 
   {{0x7864673b,0xf8640114,0xbbd401af,0x3bd4005a}},	// [1ed40] оказ, овао, _мінњ, _мюнс, 
   {{0x7c2801c0,0x7e913a30,0xddc4cc1a,0x00000000}},	//   _тоог_, rāpu, _kliž, --, 
   {{0x62893a31,0xad980793,0x3604007b,0x00000000}},	//   _omgo, caúb, قواف, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x5fa80073,0x00000000,0x00000000,0x00000000}},	//   _घुसल, --, --, --, 
   {{0x3d100574,0x62880142,0x00000000,0x00000000}},	//   _तिने_, _amgo, --, --, 
   {{0x98a00427,0x00000000,0x00000000,0x00000000}},	//   ntič_, --, --, --, 
   {{0x7874009f,0x00000000,0x00000000,0x00000000}},	//   _اُڳا, --, --, --, 
   {{0x93bc084c,0x2c181715,0xefd4010c,0x7e6c031c}},	//   _scăd, _बालू_, ሪያዊ_, _ċapp, 
   {{0x64a0005e,0x81a80729,0xddc43883,0x62893a32}},	//   _жауа, _গৃহ_, _bliž, _emgo, 
   {{0xf20402e8,0x00000000,0x00000000,0x00000000}},	//   _дяло, --, --, --, 
   {{0xc2ec0118,0xd00801e0,0xa24400cf,0x3e6001ef}},	//   žící, шеүе_, _ورنۇ, _kóty_, 
   {{0xf8a80073,0x00000000,0x00000000,0x00000000}},	//   कवाय, --, --, --, 
   {{0xdee001ec,0xefd40092,0x2c1801f9,0x00000000}},	//   _ﺍﻟﺩﺒ, ሪያዋ_, _बाळू_, --, 
   {{0x628803cb,0x92dc03d4,0xefd40092,0xaa64011c}},	//   _ymgo, তীৰ_, ሪካው_, отак, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6ca40153,0x3e60013a,0x6ee4009f,0x00000000}},	// [1ed50] _мрож, _nóty_, _اسڪل, --, 
   {{0xa3c82765,0xe7e843a2,0x00000000,0x00000000}},	//   रेड_, рфак_, --, --, 
   {{0xe7093a33,0xdee402d3,0x57b40101,0xad9800d7}},	//   شتان_, ማሪኖ_, وحمز, baúc, 
   {{0xc2e800fe,0x9f4401bf,0x56941de6,0x00000000}},	//   _গিলি_, _venø_, махт, --, 
   {{0xba28028e,0x00000000,0x00000000,0x00000000}},	//   _اسپم_, --, --, --, 
   {{0xddc400cd,0x82f402e8,0x00000000,0x00000000}},	//   _aniś, пчиц, --, --, 
   {{0x4368023b,0x00000000,0x00000000,0x00000000}},	//   сайн_, --, --, --, 
   {{0xddc40055,0xb2200395,0x06b400cc,0x00000000}},	//   _cniś, емъл, _জংকি, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe3b0152f,0x3954011a,0xa3c800bc,0x00000000}},	//   _قرض_, פשתם_, रइद_, --, 
   {{0x6b80004d,0x7eb400d8,0xbbb801ad,0xaad8193d}},	//   _ýngh, lápi, _इरेक, _मूलक, 
   {{0xa3c80a28,0x62883058,0xc300015b,0x00000000}},	//   रेण_, _umgo, _এমপি_, --, 
   {{0x1c204ff1,0xee353a34,0x57b80882,0x5fa8000d}},	//   _बादल_, чня_, _अर्ह, _घुरल, 
   {{0x6298495c,0xd1b9207f,0x0c7801f4,0x00000000}},	//   lnuo, _باما_, оссы_, --, 
   {{0x5e640220,0x8fc400f7,0x3f78010f,0x387c00ef}},	//   _ينتە, _ۉزۉن, _לאַס, _ķtr_, 
   {{0xefd40020,0x62980dd4,0xeb9450ae,0xcee80811}},	//   ሪያው_, nnuo, чис_, _برون_, 
   {{0x98a01b5c,0x5c7800d1,0xa3c880a0,0xae180375}},	// [1ed60] stič_, _дәвр_, रेत_, _הופכ, 
   {{0x499800d6,0x629805d5,0xc3000154,0x80c0033f}},	//   іття_, hnuo, _এমনি_, _रीमे, 
   {{0x25bc2d3f,0x7d046525,0x59b00034,0xbb4800c6}},	//   _azul_, lsks, _फ़रवर, _الجن_, 
   {{0xfaa4c719,0xaabc0864,0x7aa41606,0x00000000}},	//   _хамо, ्षणक, _химз, --, 
   {{0x60c00428,0x27ec0118,0x00000000,0x00000000}},	//   _ohnm, ílné_, --, --, 
   {{0x25bc0a2e,0x52a402ab,0x5335026b,0x70b80037}},	//   _dzul_, ऑक्स, дект, _उठेल, 
   {{0xddc40327,0xa3d0004e,0x21c801ec,0x00000000}},	//   _aliż, ношч, _ﻗﺭﺍﺭ, --, 
   {{0x62980c86,0xddc4033f,0x6f000118,0x23800023}},	//   gnuo, _bliż, _líbá, _ክዕዘብ_, 
   {{0xe1ec33f9,0x93bc0356,0xe8dc0051,0x00000000}},	//   دسى_, _abăt, _vjệc_, --, 
   {{0x6d487523,0xe0cc0133,0x39400419,0x00000000}},	//   _ágai, ێزی_, _msks_, --, 
   {{0x09b804e4,0xddc4025c,0xf4900131,0xa3c8c59b}},	//   _आर्य, _eliż, _ﭘﯜﺗﯜ, रेद_, 
   {{0x62980051,0x00000000,0x00000000,0x00000000}},	//   cnuo, --, --, --, 
   {{0x6aa00048,0x6f000241,0x3eb00076,0x00000000}},	//   _ínfi, _bíbá, _dkyt_, --, 
   {{0x38680408,0x40e80244,0x2c140210,0x00000000}},	//   _nobr_, _بووێ_, _ताओं_, --, 
   {{0x39413a35,0x3d100574,0x160c0490,0x00000000}},	//   _asks_, _तिथे_, हणार_, --, 
   {{0x6f180bd7,0x9f98011a,0x00000000,0x00000000}},	//   mutc, _לסופ, --, --, 
   {{0x19593a36,0x6f180083,0x93bc0356,0x7cf001a9}},	// [1ed70] паты_, lutc, _zbăt, qаrо, 
   {{0xaa840014,0x27e400a3,0x00000000,0x00000000}},	//   _کۆرم_, ùnn_, --, --, 
   {{0x386809a8,0x6298fea4,0x00000000,0x00000000}},	//   _dobr_, ynuo, --, --, 
   {{0xd7c800aa,0x00000000,0x00000000,0x00000000}},	//   سونه_, --, --, --, 
   {{0x0444db74,0x6f1802ce,0xabb800d1,0xca540092}},	//   делн, hutc, ﻠﯩﻐﺎ, _ቅሬታዎ, 
   {{0x29180bc9,0x6f180bd7,0x386805c7,0x7eb53a37}},	//   muqa_, kutc, _gobr_, rápi, 
   {{0x29193a38,0x49180034,0x62980051,0x00000000}},	//   luqa_, यूरो_, tnuo, --, 
   {{0x6f181db4,0xddc401e4,0x7d04000f,0xaabc17c6}},	//   dutc, _aniŝ, ysks, ्षिक, 
   {{0x81b40d42,0x78710836,0x29193a39,0x25bc7f0a}},	//   ছেন_, _sævi, nuqa_, _uzul_, 
   {{0x3eb07031,0x62980eed,0x00000000,0x00000000}},	//   _skyt_, snuo, --, --, 
   {{0x3ea4006c,0x29184c27,0xaabc44eb,0xbea4531d}},	//   динг, huqa_, ्षाक, данк, 
   {{0x29193a3a,0xdf5000f7,0xa2800133,0xc0ec0092}},	//   kuqa_, _үндө, _سیخو, ቁማል_, 
   {{0x2b8401d5,0xb81c01ad,0xa2440137,0x7d040254}},	//   _hеch_, _पालम_, _ورچۇ, usks, 
   {{0x7d0428bf,0x6f180810,0x29180309,0x394005c7}},	//   rsks, butc, duqa_, _rsks_, 
   {{0x6f193a3b,0xebe02cfe,0x38680076,0x9f4801e1}},	//   cutc, тосп, _robr_, _ìlàa_, 
   {{0xba1802dd,0x9f453a3c,0x2918014b,0x38680142}},	//   تيرا_, _menü_, fuqa_, _sobr_, 
   {{0x29193a3d,0xad980784,0x6e9000e3,0xd7640345}},	// [1ed80] guqa_, laún, _جليا, کنای, 
   {{0xbb7401b9,0x00000000,0x00000000,0x00000000}},	//   _жумъ, --, --, --, 
   {{0x07f80024,0x3f840327,0xac80009d,0x00000000}},	//   яхты_, nzlu_, _ргэл, --, 
   {{0xd9780032,0x38680368,0x319c02e3,0x00000000}},	//   _ергә_, _wobr_, ịzi_, --, 
   {{0xa3c800ce,0x00000000,0x00000000,0x00000000}},	//   रेस_, --, --, --, 
   {{0x7eb400d2,0xd3e400db,0x00000000,0x00000000}},	//   mápu, رتتۉ, --, --, 
   {{0xf2c40228,0x3f8401ef,0x00000000,0x00000000}},	//   мсин, jzlu_, --, --, 
   {{0x00c000d1,0x66c0000d,0x97a4030d,0x00000000}},	//   ﺮﯨﺸﺘ, tõke, ăрăл, --, 
   {{0x73340451,0x741400f1,0x213c0327,0x00000000}},	//   _ڊرائ, _يورا, gwuh_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe0cc3229,0xdef402d5,0x5ec8015b,0x7eb400e4}},	//   جزي_, мыя_, রআনে, hápu, 
   {{0x6f1801c4,0x291802d1,0x918000db,0x00000000}},	//   rutc, yuqa_, _مۇعۇ, --, 
   {{0xb35404d3,0x7c2c002f,0x04880345,0x00000000}},	//   _ریکا_, ffbr, _بڕۆی_, --, 
   {{0x291823e0,0x6f182e45,0xa3c800dc,0x00000000}},	//   vuqa_, putc, रेव_, --, 
   {{0xe2040034,0xd148004d,0xce94013d,0x00000000}},	//   spół_, _hễ_, _пакъ, --, 
   {{0x291802d1,0x7c2c01bf,0x1ac80022,0x00000000}},	//   tuqa_, afbr, дууп_, --, 
   {{0x68243cc5,0xddc40bbc,0x2c6c03b9,0x00000000}},	// [1ed90] дьез, _iniş, _qüds_, --, 
   {{0xd148004d,0x2918d22f,0x2fd000a2,0x00000000}},	//   _mễ_, ruqa_, _şygy_, --, 
   {{0xd1480016,0x29180067,0x00000000,0x00000000}},	//   _lễ_, suqa_, --, --, 
   {{0xade005d7,0x89d800e5,0x00000000,0x00000000}},	//   कुचन_, _ڈوگر_, --, --, 
   {{0x7eb40005,0x78700fac,0x29193a3e,0x3f84031c}},	//   cápu, _rævv, quqa_, zzlu_, 
   {{0x290801ef,0x00000000,0x00000000,0x00000000}},	//   _ivca_, --, --, --, 
   {{0xd40402bf,0x213c011f,0xa2a800dc,0x00000000}},	//   тячи, wwuh_, ञवल्, --, 
   {{0x7eb425e6,0xeee0000d,0x00000000,0x00000000}},	//   nápt, _गढ़ऽ_, --, --, 
   {{0x44280b45,0x73d40032,0x56953a3f,0xa3b80037}},	//   ƙa_, мдәр_, _ратт, _घरक_, 
   {{0xd14807ae,0xddc40356,0xf948010f,0x00000000}},	//   _dễ_, _aniş, לעפֿ, --, 
   {{0x442406a3,0xa3c842e3,0x00000000,0x00000000}},	//   _icl_, रेश_, --, --, 
   {{0x290804a7,0x92940022,0xad9800d8,0xb778008f}},	//   _ovca_, _иахц, raún, פארש, 
   {{0xa3c80316,0x9f44004e,0x3f840210,0x00000000}},	//   रेर_, _penó_, szlu_, --, 
   {{0x442401ee,0x3f84005a,0xddc41432,0x00000000}},	//   _jcl_, pzlu_, _eniş, --, 
   {{0x44253a40,0x7c2c0036,0xf090011a,0x4f64007b}},	//   _mcl_, rfbr, _תנו_, _لايف, 
   {{0x44244663,0x9e9400db,0xaa40361e,0xfe4400d8}},	//   _lcl_, _جاتچ, лесл, _чнио, 
   {{0xf2d000c8,0x00000000,0x00000000,0x00000000}},	// [1eda0] רען_, --, --, --, 
   {{0x7eb403b2,0x00000000,0x00000000,0x00000000}},	//   rápu, --, --, --, 
   {{0xabf8025f,0xf77019f9,0x7bdc089c,0xddc5079c}},	//   _מהיר, داء_, _igpu, _maiō, 
   {{0xf50415ab,0x44253a41,0xd5b00014,0x80c003ce}},	//   ездо, _acl_, ٔہر_, _रीसे, 
   {{0x44240493,0x66e00184,0x6d48e0e2,0x9f44002e}},	//   _bcl_, _ҡора, _ágat, _menñ_, 
   {{0x61e93a42,0xd14801fb,0x4424045a,0x68f80139}},	//   _afgl, _rễ_, _ccl_, _çuda, 
   {{0xe7341220,0x44242230,0xa3c93a43,0xed640092}},	//   _пер_, _dcl_, रेल_, _ቲያትር_, 
   {{0x7bdc05b1,0x6d4800c7,0xae1c000d,0x00000000}},	//   _lgpu, _âgag, _भाइन_, --, 
   {{0xe5a13a44,0x4424010a,0x9444035b,0x00000000}},	//   _бити, _fcl_, _имаҵ, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe9dc09c2,0x5ef401a9,0x00000000,0x00000000}},	//   _baúl_, нхўр_, --, --, 
   {{0x71700131,0xd1480208,0x00000000,0x00000000}},	//   _مۇبا, _tễ_, --, --, 
   {{0xa1113a45,0x00000000,0x00000000,0x00000000}},	//   _مونت, --, --, --, 
   {{0x7ae000f3,0xa0640902,0xefb80092,0x00000000}},	//   _čotr, _пача_, _ታጋይ_, --, 
   {{0x39ec44fc,0x2ac40114,0x00000000,0x00000000}},	//   _ọzọ_, ељав, --, --, 
   {{0x5e84030d,0x29840026,0x00000000,0x00000000}},	//   _буьз, нызг, --, --, 
   {{0x26c00153,0xee3c010e,0x00000000,0x00000000}},	// [1edb0] _ėjo_, meý_, --, --, 
   {{0x58845316,0xb4b805c0,0xee3c010b,0x00000000}},	//   лыха, घतो_, leý_, --, 
   {{0x44253a46,0xa56403e6,0x00000000,0x00000000}},	//   _rcl_, کدان, --, --, 
   {{0xd6180127,0xee3c010e,0x00000000,0x00000000}},	//   فتها_, neý_, --, --, 
   {{0x57a402dd,0x6abc00cd,0x00000000,0x00000000}},	//   _ұшта, ्षीर, --, --, 
   {{0xd4080ae5,0x7eb402f0,0xee3c010e,0x00000000}},	//   ىتىم_, nápr, heý_, --, 
   {{0xa3c8006d,0x44241fc0,0x03a40107,0xee3c00ee}},	//   रें_, _vcl_, ъико, keý_, 
   {{0x44253a47,0x13a803e6,0xceb800c0,0x10c400d1}},	//   _wcl_, رۆنی_, itęs_, ﺮﯨﺸﻨ, 
   {{0xe9dc0615,0x00c868e4,0x2324039b,0xa0700724}},	//   _raúl_, млик_, фоқи_, гънә, 
   {{0xe9dc04d4,0x6abc00dc,0xddc400ef,0x76440a87}},	//   _saúl_, ्षुर, _noiš, _ókyr, 
   {{0xf4540302,0x2c1852f2,0x00000000,0x00000000}},	//   _שיער_, _बाजू_, --, --, 
   {{0xddc402b1,0x291c01e4,0x26cc003e,0xdb2401d3}},	//   _waiō, _ĥuan_, nmgo_, érít, 
   {{0x212800a3,0xd06401e4,0xceb80064,0xed4001a9}},	//   àchd_, ɾpɾe, etęs_, аняп, 
   {{0xafe000fd,0xa0a400fd,0xcee8397a,0x4c8001ec}},	//   _кошл, _яшел, برین_, йғыз, 
   {{0xab253a48,0x09d8015b,0x3ab40063,0xad9801d3}},	//   кора_, ধুমা, вљат, naúj, 
   {{0xadb0063f,0x00000000,0x00000000,0x00000000}},	//   ụzụa_, --, --, --, 
   {{0xaa4028e5,0x00000000,0x00000000,0x00000000}},	// [1edc0] шетл, --, --, --, 
   {{0x92dc2f8b,0xb864009a,0x00000000,0x00000000}},	//   তীয়_, خارو, --, --, 
   {{0x78700158,0x31bc0882,0xb8640214,0x9f480166}},	//   _bævr, _ऊर्ध, _یاسو, _älän_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc0f802d3,0xe8f4014b,0xa61000d4,0xd5341bf4}},	//   _ወጥሪ_, _иля_, рміч, افتخ, 
   {{0x6aa00998,0x787000b5,0x27fc0208,0xe4c001c6}},	//   _ínfr, _vævs, _đung_, айчи, 
   {{0x40e40150,0x39500064,0x00000000,0x00000000}},	//   қсығ, lvys_, --, --, 
   {{0x12c0015b,0xb2700032,0xb19009a5,0xe3ac009a}},	//   উদ্দ, ркиә, илйә, غرو_, 
   {{0x75d47ae6,0x00000000,0x00000000,0x00000000}},	//   _شيطا, --, --, --, 
   {{0x3ea00036,0x395000c0,0x00000000,0x00000000}},	//   enkt_, ivys_, --, --, 
   {{0x93f001af,0x00000000,0x00000000,0x00000000}},	//   _күҙє, --, --, --, 
   {{0x797800b0,0x3fc4054a,0x5f9000d4,0x30740023}},	//   _kāwā, ырығ, риют, _ይወጽእ_, 
   {{0xddc53a49,0x9df802e8,0x00000000,0x00000000}},	//   _poiš, ънят_, --, --, 
   {{0x8f54034c,0x3950002d,0x656c0129,0x00000000}},	//   _منتش, dvys_, _àche, --, 
   {{0xdee015ed,0x332c0076,0x00000000,0x00000000}},	//   _који, ntfx_, --, --, 
   {{0x5fa8000d,0x00000000,0x00000000,0x00000000}},	//   _घुटल, --, --, --, 
   {{0xaca0063f,0x93bc0311,0x8858009d,0x00000000}},	// [1edd0] _alụg, _scăl, ниас_, --, 
   {{0xb4bc000d,0xf8b4be67,0xeb0401a9,0x00000000}},	//   ीगो_, гөс_, _ичмо, --, 
   {{0x5ba40395,0xcfc00150,0x00000000,0x00000000}},	//   _вряз, _ﺭﺍﻏﺒ, --, --, 
   {{0x0a1400db,0x6f1800a3,0x25d40244,0x00000000}},	//   _حوحح, irtc, نهاگ_, --, 
   {{0x29840022,0x491000c7,0x80c80154,0x345800e5}},	//   _рынг, _ыҟаӡ, রদত্, کسنگ_, 
   {{0xc8c81f6d,0xd7f402f6,0x7a1c054e,0x00000000}},	//   _سوزن_, _взры, pătâ, --, 
   {{0x7bd80024,0xa1f000d1,0x00000000,0x00000000}},	//   žtuv, لۋات, --, --, 
   {{0x8504004b,0xaa780432,0xe5b002dd,0x45d401af}},	//   _مورن, _diýg, _ұйғы, _бобс, 
   {{0x98a0012d,0x00000000,0x00000000,0x00000000}},	//   stią_, --, --, --, 
   {{0x95c8febb,0x21a006dc,0xd498030d,0xe46801a9}},	//   _руса_, лиқм, _ирх_, _ўшал_, 
   {{0x2d880369,0x4ab4012c,0x3cf001e3,0xed54024c}},	//   ezce_, ूताव, _styv_, ҳоя_, 
   {{0x7d000327,0x00000000,0x00000000,0x00000000}},	//   _ħosb, --, --, --, 
   {{0x6f182233,0xed54005a,0x00000000,0x00000000}},	//   artc, гоя_, --, --, 
   {{0x61f93a4a,0x00000000,0x00000000,0x00000000}},	//   lbul, --, --, --, 
   {{0x30d800c8,0x98a00cf4,0x61f93a4b,0x00000000}},	//   _אַהע, ltić_, obul, --, 
   {{0x61f93a4c,0x00000000,0x00000000,0x00000000}},	//   nbul, --, --, --, 
   {{0x81b400bd,0x98a00552,0x2d880034,0xb8185821}},	// [1ede0] ছের_, ntić_, czce_, فتاء_, 
   {{0xa8013a4d,0x79780374,0x3950000f,0x00000000}},	//   йзул, _rāwā, rvys_, --, 
   {{0x61f93a4e,0xacb8003a,0xd91001d3,0x671c0a17}},	//   kbul, rtût, _ڈیز_, मूलक_, 
   {{0x46800046,0x98a00841,0xd910136e,0x89f40153}},	//   оқса, ktić_, _ویز_, _вярц, 
   {{0xaa780209,0x98a03341,0xe5a04623,0xd3680116}},	//   _diýd, jtić_, бици, _қaнч, 
   {{0x61f80083,0xf86401b9,0x00000000,0x00000000}},	//   ebul, _ёвво, --, --, 
   {{0x797804fe,0x00000000,0x00000000,0x00000000}},	//   _wāwā, --, --, --, 
   {{0x75d4021a,0x797804fe,0x61f93a4f,0x98a00558}},	//   _ميزا, _tāwā, gbul, ftić_, 
   {{0x332c02fa,0xd4c41a50,0xad980162,0x34a80114}},	//   stfx_, _көкк, mbúg, _звао_, 
   {{0x61f93a50,0xad9806ea,0xe4d453be,0x7520009f}},	//   abul, lbúg, _موقت_, muoz, 
   {{0x61f93a51,0x8f344d6b,0x81b400cc,0x6f180165}},	//   bbul, шенц, ছেল_, urtc, 
   {{0xaa78010b,0x764000e4,0xad9806ea,0x00000000}},	//   _kiýe, neoy, nbúg, --, 
   {{0xb7f432ed,0xbd0400b8,0x9da8011c,0x00000000}},	//   ेराम_, _niũā, гъра_, --, 
   {{0xa3c842e3,0xaa780432,0x00000000,0x00000000}},	//   रेक_, _miýe, --, --, 
   {{0xc87800a8,0xedd42c22,0x2d88012d,0x00000000}},	//   _îşi_, _өлкә_, szce_, --, 
   {{0x1f101867,0x752000b5,0xdb0c0118,0x00000000}},	//   _ابوج, kuoz, íhán, --, 
   {{0xaa780209,0x76401432,0x290d3a52,0x00000000}},	// [1edf0] _niýe, deoy, éga_, --, 
   {{0xbd0400b8,0x2918031c,0x00000000,0x00000000}},	//   _diũā, rrqa_, --, --, 
   {{0x61f93a53,0x290c0295,0x98a00381,0x6abc00fe}},	//   ybul, ũga_, ntię_, ্দবো, 
   {{0x7640037e,0x7d0c0139,0x00000000,0x00000000}},	//   geoy, _änsä, --, --, 
   {{0x15b93a54,0x00000000,0x00000000,0x00000000}},	//   лышы_, --, --, --, 
   {{0xaa7809a5,0x98a0009b,0x58842401,0xaabc0118}},	//   _diýe, vtić_, _лыса, ्षकक, 
   {{0x61f93a55,0x4368b42d,0x00000000,0x00000000}},	//   tbul, тайн_, --, --, 
   {{0x75200083,0x61f93a56,0x65300451,0x42d401ec}},	//   buoz, ubul, _هڙتا, шілу, 
   {{0x26dc0418,0xd5381f3c,0xaa780432,0x00844623}},	//   _iiuo_, _مثلا_, _giýe, илио, 
   {{0x25bcfbf4,0x32040a73,0x61f93a57,0x98a007f5}},	//   _iyul_, _eeoy_, sbul, rtić_, 
   {{0x98a056c0,0x6440b77d,0xa3c80574,0x7c28007c}},	//   stić_, meni, रेख_, _öfri, 
   {{0x64413a58,0x66088b14,0xee340dce,0x98a0107d}},	//   leni, nagk, аню_, ptić_, 
   {{0xfce42c68,0x25bc022e,0x72d000cf,0x62980153}},	//   рого, _jyul_, _بەيچ, miuo, 
   {{0x629802d5,0x64413a59,0x66093a5a,0xceb8068f}},	//   liuo, neni, hagk, stęp_, 
   {{0x66082819,0x26dc0093,0x00000000,0x00000000}},	//   kagk, _oiuo_, --, --, 
   {{0x64413a5b,0x20040924,0x629802d5,0x26dc01e4}},	//   heni, _heni_, niuo, _niuo_, 
   {{0xf7f53a5c,0x2004069c,0x00000000,0x00000000}},	// [1ee00] لساد, _keni_, --, --, 
   {{0x64402aa3,0x2004044e,0xe1e401d9,0xbd0400b8}},	//   jeni, _jeni_, _ژس_, _viũā, 
   {{0x64413a5d,0xad980579,0x62980006,0x2700007f}},	//   deni, tbúg, kiuo, gŕn_, 
   {{0x25bc00d8,0x64410110,0xaa78010b,0x00000000}},	//   _byul_, eeni, _piýe, --, 
   {{0x64404d9d,0x26dc003a,0xad980174,0xddd000a2}},	//   feni, _diuo_, rbúg, _ýeńj, 
   {{0x20053a5e,0x64413a5f,0x752005d5,0xad980162}},	//   _neni_, geni, ruoz, sbúg, 
   {{0xc7880014,0xaa78010e,0x55544710,0x00000000}},	//   _یخہٕ_, _wiýe, _گھار, --, 
   {{0x20044e12,0x66e002d5,0x62992752,0x66080098}},	//   _aeni_, _фота, giuo, cagk, 
   {{0x30a4722e,0x64413a60,0x20053a61,0x25bc020b}},	//   иров, beni, _beni_, _gyul_, 
   {{0x20053a62,0x656c004a,0x7398010a,0xee3c00a2}},	//   _ceni_, _àcha, _итес_, dnýa_, 
   {{0x22800986,0x1c2000af,0x20644990,0x629800c0}},	//   _wñka_, _बाजल_, ршып_, biuo, 
   {{0x20053a63,0x333c005a,0x62980153,0x98a00210}},	//   _eeni_, _iptx_, ciuo, rtię_, 
   {{0x20053a64,0xf1d018cc,0x98a0012d,0x09b4000d}},	//   _feni_, देशन, stię_, _अँइठ, 
   {{0x20053a65,0x81bc00cc,0x00000000,0x00000000}},	//   _geni_, _আলচ_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x64408864,0x20040fcf,0xa3c83644,0xaca00241}},	//   zeni, _zeni_, रेट_, _imọg, 
   {{0x20053a66,0x64413a67,0x80c800bd,0x4c94447e}},	// [1ee10] _yeni_, yeni, রদর্, _гипс, 
   {{0x29f00a28,0x64413a68,0x20053a69,0xe73000c6}},	//   ṇa_, xeni, _xeni_, قصص_, 
   {{0x4b54009f,0x00000000,0x00000000,0x00000000}},	//   _اَجر, --, --, --, 
   {{0x644003b4,0x25bc020c,0x969400d4,0xdde4002b}},	//   weni, _pyul_, оріш, _ārūp, 
   {{0x6608ccf3,0x1e580375,0x00000000,0x00000000}},	//   ragk, ישאר_, --, --, 
   {{0x66093a6a,0x64406a89,0x00000000,0x00000000}},	//   sagk, ueni, --, --, 
   {{0x6608ddea,0x74102984,0x6298003a,0x2db801ec}},	//   pagk, سويا, tiuo, _ﺤﻜﻴﻤ, 
   {{0x64406d4a,0x26dc0393,0xe4a40124,0x00000000}},	//   seni, _uiuo_, ырҵо, --, 
   {{0x62993a6b,0xa3c81f13,0x764400e5,0x00000000}},	//   riuo, रेज_, _دینِ_, --, 
   {{0x14740491,0x200402d3,0x64400023,0x62980006}},	//   _والج, _qeni_, qeni, siuo, 
   {{0x62980024,0xaac4095f,0x66c0000d,0x9f5406be}},	//   piuo, लताक, jõkk, _üzüb_, 
   {{0x200407a9,0xd10801d5,0xbea53a6c,0x3ea401d5}},	//   _weni_, _چقنه_, самк, симг, 
   {{0x0d993a6d,0x20053a6e,0x52b000db,0x00000000}},	//   атры_, _teni_, _تەيئ, --, 
   {{0x20040393,0x907001ec,0x00000000,0x00000000}},	//   _ueni_, _يۇيش, --, --, 
   {{0xa3c80073,0x8fc40220,0x00000000,0x00000000}},	//   रेच_, _وزىن, --, --, 
   {{0x9ce800e5,0x00000000,0x00000000,0x00000000}},	//   _پودے_, --, --, --, 
   {{0xa9653a6f,0xe8f401c0,0xc4b8012d,0xf2d00a7c}},	// [1ee20] бита_, йлт_, ेताओ, לעל_, 
   {{0xe9d53a70,0xb80840bb,0xc0180183,0x3b84009b}},	//   ску_, ايام_, ত্ৰণ_, _глог, 
   {{0xfaa80be2,0x7e740076,0xcb58002e,0xc3240244}},	//   _مهدي_, _koyp, _w茜r_, _تڕ_, 
   {{0x7e74011c,0xa3c807f7,0xeb38010f,0x00000000}},	//   _joyp, रेछ_, _געטש, --, 
   {{0xe5a00902,0x38540395,0x00000000,0x00000000}},	//   пици, _лъвс, --, --, 
   {{0x21dc00b0,0xe4d53a71,0x7e740174,0x06d40150}},	//   _māhī_, مونت_, _loyp, _ﭘﯩﺸﻪ, 
   {{0xad9803b2,0xa884010a,0x00000000,0x00000000}},	//   laút, _уйра_, --, --, 
   {{0x7e741c06,0xb6840150,0xaa7800a2,0x00000000}},	//   _noyp, _اشسى, _kiýa, --, 
   {{0xe1ec43cd,0x60f40006,0x00000000,0x00000000}},	//   رسي_, бныя_, --, --, 
   {{0xe574013d,0x909800d8,0x00000000,0x00000000}},	//   _узу_, рвот_, --, --, 
   {{0x7e753a72,0x7204007b,0x73c53a73,0x00000000}},	//   _boyp, _هوام, _ايام, --, 
   {{0x7e740076,0xddc4005f,0x491801ad,0xad98041e}},	//   _coyp, _maiņ, _पिलो_, kaút, 
   {{0xa1300502,0x3aec00a2,0x7e7406ea,0xaa780432}},	//   _فروش, _aýp_, _doyp, _niýa, 
   {{0x68f802d3,0x8af800d8,0x66c00037,0x00000000}},	//   _çudi, ингс_, tõkk, --, 
   {{0x80c0134e,0x00000000,0x00000000,0x00000000}},	//   _रीटे, --, --, --, 
   {{0x3d100490,0xaa7800a2,0x00000000,0x00000000}},	//   _तिचे_, _biýa, --, --, 
   {{0x2d8c3c02,0x00000000,0x00000000,0x00000000}},	// [1ee30] _åge_, --, --, --, 
   {{0xaa78010b,0x4af80214,0xd364313e,0x3cec000d}},	//   _diýa, _نکرد_, _كۇ_, _इंते_, 
   {{0xf424025c,0x1ef8010f,0x00000000,0x00000000}},	//   _རྐེད_, ָלדע, --, --, 
   {{0x8a6003e6,0xddc40171,0x290c0332,0x00000000}},	//   _تێرۆ, _daiņ, ágas_, --, 
   {{0xfa4800db,0xaa7800a2,0x842400d1,0x00000000}},	//   _ئشپى_, _giýa, قىشن, --, 
   {{0xad980077,0x82f43dc8,0x7af803b2,0x00000000}},	//   laús, очиц, íttg, --, 
   {{0x21dc00b0,0x0ec89401,0x96f8033a,0xaa78010e}},	//   _māhū_, रताड, _гест_, _ziýa, 
   {{0x656c0129,0x79400023,0x163400c0,0xc0ec0092}},	//   _àcho, _ርክባት, _неся, _ቀለል_, 
   {{0xe570c015,0x637c01e1,0xdee002dd,0x2bf800cd}},	//   _عطر_, _bànú, _ﺍﻟﺘﺒ, ्रां_, 
   {{0x7e740789,0x00000000,0x00000000,0x00000000}},	//   _soyp, --, --, --, 
   {{0xcdc805e1,0xfe444d15,0x5ec400fb,0x00000000}},	//   _סך_, онно, зинғ, --, 
   {{0x7e74047e,0xd378f647,0xeabc0241,0x4f953a74}},	//   _qoyp, _учу_, _nkù_, ярыу, 
   {{0x21dc002b,0x00000000,0x00000000,0x00000000}},	//   _bāhū_, --, --, --, 
   {{0xaa78010e,0x83b4010f,0x00000000,0x00000000}},	//   _riýa, ַפּע_, --, --, 
   {{0x7e7400b5,0xaa780432,0x3a98014b,0xddc40064}},	//   _toyp, _siýa, атаю_, _kniū, 
   {{0x09c4045e,0x39440120,0x3aec0f91,0xddc400e2}},	//   ্শনা, çoso_, _výp_, _raiņ, 
   {{0xddc40171,0xd2c8030d,0x00000000,0x00000000}},	// [1ee40] _saiņ, _тiею, --, --, 
   {{0xeabc0248,0xad9806ea,0xbb44084c,0x7d153a75}},	//   _ekù_, raút, _деок, _ivys, 
   {{0xf5e93a76,0xe9dc00d8,0x8c240327,0x7c3c0332}},	//   амел_, _baús_, _སྐྲྀ_, _ibpr, 
   {{0xddc40171,0x00000000,0x00000000,0x00000000}},	//   _vaiņ, --, --, --, 
   {{0x7c3c0115,0x00000000,0x00000000,0x00000000}},	//   _kbpr, --, --, --, 
   {{0xa3b400e5,0x00000000,0x00000000,0x00000000}},	//   ںاور_, --, --, --, 
   {{0xdb240066,0x00000000,0x00000000,0x00000000}},	//   èrèt, --, --, --, 
   {{0x1fcc03f4,0xb1a00032,0x26080490,0x26c801b9}},	//   রশাস, мһеҙ, ारणी_, _نطقی_, 
   {{0xe5a11fd6,0x7c3d325c,0xceb80032,0xe1ec00d1}},	//   _жити, _obpr, ҙәк_, خسى_, 
   {{0x26081414,0xefb001b9,0x75213a77,0x09dc00cc}},	//   ारथी_, ویشگ, mroz, _ণ্ডা, 
   {{0xf1c400bc,0x752077ad,0x6d4801d3,0x394000ef}},	//   _řádu_, lroz, _ágaz, _lpks_, 
   {{0xd2502fee,0x7c3c002f,0xddc40064,0x00000000}},	//   _سنت_, _abpr, _gniū, --, 
   {{0x7c3c0334,0x627000c6,0x26093a78,0xa2d4cc41}},	//   _bbpr, _تهنئ, ारती_, मगर्, 
   {{0xee3c0122,0x7c3c6035,0x00000000,0x00000000}},	//   mným_, _cbpr, --, --, 
   {{0xee3c0232,0x75200122,0xdb58005b,0x7d1400d7}},	//   lným_, hroz, оют_, _evys, 
   {{0x7c3c030d,0x00000000,0x00000000,0x00000000}},	//   _ebpr, --, --, --, 
   {{0xee3c0122,0x21dc02b1,0x75202f53,0xc8c800ec}},	// [1ee50] nným_, _tāhū_, jroz, مورن_, 
   {{0x27e53a79,0x6d5d3a7a,0x00000000,0x00000000}},	//   ønn_, _irqa, --, --, 
   {{0x7d141d55,0xda700014,0x00000000,0x00000000}},	//   _zvys, رُے_, --, --, 
   {{0xea6010a8,0x7d1400e4,0xee3c13d5,0xd618007b}},	//   _تۇرپ, _yvys, kným_, قتها_, 
   {{0x75213a7b,0xee3c0122,0x2c1c05f9,0x845c02d3}},	//   groz, jným_, _बयां_, _ሶማልን_, 
   {{0xee3c6b07,0x69cd3a7c,0xb9780375,0x437439be}},	//   dným_, _izce, _הנשי, зуит, 
   {{0xe9dc004e,0x00000000,0x00000000,0x00000000}},	//   _taús_, --, --, --, 
   {{0x6d5cf575,0x00000000,0x00000000,0x00000000}},	//   _orqa, --, --, --, 
   {{0x6618ad0c,0x75200356,0xbb300150,0xd04803b9}},	//   _iduk, croz, _ﺭﺤﻡ_, lmdə, 
   {{0xee3401c6,0x00000000,0x00000000,0x00000000}},	//   үнэ_, --, --, --, 
   {{0x6d5d3a7d,0x00000000,0x00000000,0x00000000}},	//   _arqa, --, --, --, 
   {{0xee3c0122,0x00000000,0x00000000,0x00000000}},	//   bným_, --, --, --, 
   {{0xee3c02fb,0x62882ba4,0xeb945183,0x6618d347}},	//   cným_, _ilgo, җит_, _mduk, 
   {{0xaa7800a2,0xd04806be,0x00000000,0x00000000}},	//   _biýo, kmdə, --, --, 
   {{0x0b587196,0x66193a7e,0x6d5d3a7f,0x39413a80}},	//   орты_, _oduk, _erqa, _spks_, 
   {{0x66193a81,0xc5e400aa,0x648c0217,0xfaa401f0}},	//   _nduk, _لړ_, _høid, чабо, 
   {{0xa9653a82,0xaec00801,0xad982200,0xb9c40214}},	// [1ee60] пита_, _ябъл, lbún, ستره, 
   {{0x3ea13a83,0x7c3c03ac,0xe4ec0037,0x00000000}},	//   likt_, _ubpr, _चढ़ि_, --, 
   {{0xee3c02fb,0x6aac0175,0x2580002b,0xb34403b9}},	//   zným_, _fjcf, _līlā_, _maçü, 
   {{0xe7b05d62,0xd5a44f2b,0xacb8002d,0x00000000}},	//   رمند, ولای, nrûn, --, 
   {{0x66181418,0x93bc0356,0x258000b8,0xee3c0419}},	//   _dduk, _ncăr, _nīlā_, xným_, 
   {{0x62893a84,0x7c2d3a85,0x3ea13a86,0x75213a87}},	//   _algo, ngbr, hikt_, rroz, 
   {{0xe724798c,0x7ae40083,0xee3c0209,0x6ac40798}},	//   _норд_, _kikt, liýe_, _órfã, 
   {{0xee3d3a88,0x85e0005e,0x75213a89,0x7ae40003}},	//   tným_, رۋەن, proz, _jikt, 
   {{0x7ae53a8a,0xa50400a7,0x61f000ec,0xee3c010b}},	//   _mikt, _нета_, رسيء, niýe_, 
   {{0x672008ad,0x62893a8b,0x7ae40171,0xf8bd3a8c}},	//   šnje, _elgo, _likt, ्तिय, 
   {{0xee3c0122,0xad980008,0xceb80032,0xa1303687}},	//   sným_, gbún, жәп_, وریش, 
   {{0x7ae53a8d,0xee3d3a8e,0xacb8000f,0x7c2c017a}},	//   _nikt, pným_, grûn, egbr, 
   {{0xaa780209,0xe80c012c,0xf8bc3996,0xfd54002b}},	//   _diýl, िरमा_, ्ताय, _kvaṇ, 
   {{0x7ae53a8f,0x7c2c0250,0x63ac1ea0,0x81a41095}},	//   _aikt, ggbr, _çinç, _تحمل, 
   {{0x7ae44ba8,0xddc400cd,0x00000000,0x00000000}},	//   _bikt, _kaiś, --, --, 
   {{0xacb8002d,0x78bc01f5,0x7ae421fd,0xee3c00a2}},	//   ntûz, eopv, _cikt, fiýe_, 
   {{0x2eed3a90,0x260805f9,0x9f4404cc,0x648c0b1a}},	// [1ee70] _huff_, ारसी_, _agnè_, _høie, 
   {{0x98a00618,0x2eec0162,0x78bc01a4,0x22a001e1}},	//   tuiā_, _kuff_, gopv, _kèkè_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x395002f6,0xfd60063f,0xfd540055,0x7ae403b2}},	//   änsä_, _nkwọ, _avaṇ, _gikt, 
   {{0xa6101248,0x2eec0270,0xee440030,0x69cc00e2}},	//   _үзгә, _luff_, chýň_, _uzce, 
   {{0xfd6001f2,0x2eec0077,0xe1f40562,0x2ca0045f}},	//   _akwọ, _ouff_, ीर्ण_, nijd_, 
   {{0x93bc0311,0xacb8002d,0x58d53a91,0x03240212}},	//   _scăr, ftûz, _чорт, єдин, 
   {{0x66193a92,0x68e40455,0x6b8007c5,0xddc400b8}},	//   _uduk, _hijd, _üngu, _caiś, 
   {{0x3ea0a2ec,0xddc40055,0x614083c9,0x7c2c007c}},	//   vikt_, _daiś, رىدە, ygbr, 
   {{0xf1c000d1,0x2eec2517,0x66c00022,0xad980d12}},	//   _ﮬﻪﻗﻘ, _buff_, rõku, tbún, 
   {{0x3ea0005f,0x68e409b6,0x6d4c0175,0x24840115}},	//   tikt_, _mijd, ewca, mknm_, 
   {{0x2eed3a93,0x68e53a94,0xe8fc002d,0xad980008}},	//   _duff_, _lijd, _krûd_, rbún, 
   {{0x7ae53a95,0x8144035c,0xacb8002d,0x61e93a96}},	//   _rikt, _آنتن, rrûn, _iggl, 
   {{0x3ea05d01,0x2eec0204,0xaa780209,0xad9800d2}},	//   sikt_, _fuff_, _diým, mbúl, 
   {{0x7ae53a97,0x7c2c6eb4,0x2eec04e6,0x3ea0282c}},	//   _pikt, rgbr, _guff_, pikt_, 
   {{0x9f4401e7,0xaa400139,0xed4c1913,0x99800055}},	//   _ngné_, кесл, _چپي_, caiś_, 
   {{0x7ae4c424,0x68e40cf9,0x61e8020c,0x78bc01f5}},	// [1ee80] _vikt, _bijd, _mggl, topv, 
   {{0x68e40007,0x6340013f,0xc9d401d3,0x68ec0051}},	//   _cijd, _mɑnb, رملک, _ducd, 
   {{0x68e4045d,0x78bc0af4,0xe7353a98,0x61e803ac}},	//   _dijd, ropv, дех_, _oggl, 
   {{0xe1e53a99,0xd9108df6,0x61e80214,0x78bc0373}},	//   _لس_, _میر_, _nggl, sopv, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x61e80731,0x68e40369,0x00000000,0x00000000}},	//   _aggl, _gijd, --, --, 
   {{0xb6a40212,0xddc4002b,0x00000000,0x00000000}},	//   _живл, _paiś, --, --, 
   {{0x2eed3a9a,0x6340016b,0x68e40196,0x2908123b}},	//   _ruff_, _bɑnb, _zijd, _ywca_, 
   {{0xddc40882,0xacb8002d,0x2eec03b2,0x23b000d1}},	//   _vaiś, rtûz, _suff_, ىمۇس, 
   {{0x2eec1590,0x83640075,0x61e93a9b,0x6d480022}},	//   _puff_, بدۇل, _eggl, _âgai, 
   {{0xaa78010b,0xddc4002b,0x7334072d,0x00000000}},	//   _diýj, _taiś, _زرائ, --, 
   {{0x2ca00196,0x1fcc015b,0x98a00010,0x2eec03b2}},	//   wijd_, রশংস, drič_, _vuff_, 
   {{0x2ca00460,0x2eec0221,0x38680100,0x00000000}},	//   tijd_, _wuff_, _onbr_, --, 
   {{0x2eec01e6,0xdd900131,0xaa7800a2,0x2ef0013e}},	//   _tuff_, شۈپ_, _giýj, _иҷор, 
   {{0x68e40936,0x2ca00cf9,0x6d4c009a,0x68ec0067}},	//   _rijd, rijd_, swca, _sucd, 
   {{0x68e4009f,0x29840026,0x00000000,0x00000000}},	//   _sijd, мызг, --, --, 
   {{0x5ea40597,0xedd400fb,0xe3c400cc,0x00000000}},	// [1ee90] _جميل, _юлиә_, ষেপব, --, 
   {{0x68e4047e,0x98a40640,0x58840022,0x00000000}},	//   _qijd, виђе, кыха, --, 
   {{0x68e401b9,0xf93401c6,0x1cb816ac,0x00000000}},	//   _vijd, _үүсч_, _تايب_, --, 
   {{0x68e53a9c,0xaa7800a2,0xd7c80472,0x06840116}},	//   _wijd, _miýk, ذونه_, _ﯪﺭﻗﯩ, 
   {{0x68e40460,0x7994068f,0x93bc0276,0xa5640a11}},	//   _tijd, czyw, _scăp, بدان, 
   {{0x635003b9,0x69c003e0,0x00000000,0x00000000}},	//   _hənə, ğned, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x04c83229,0x635003be,0x00e4d021,0xe7e000dc}},	//   _فوري_, _mənə, нжин, _कृता_, 
   {{0xa3d400af,0x4910000d,0x63500213,0xd1c80116}},	//   _सरप_, दीयो_, _lənə, ببىم_, 
   {{0x614013bd,0xee3c02d2,0x00000000,0x00000000}},	//   رىگە, ffý_, --, --, 
   {{0x61e8e0da,0x63500213,0x98a00427,0x00000000}},	//   _uggl, _nənə, vrič_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7afc2a1f,0x31780a1e,0x98a05a54,0xccd4009d}},	//   _ptpt, _מאנד, trič_, вцсы, 
   {{0xceb80083,0xbea40139,0x635006be,0x00000000}},	//   guęs_, _пакк, _bənə, --, 
   {{0xbb74016c,0xa3d405f9,0x7e741eeb,0x3f840142}},	//   _ҷумъ, _सरन_, _سابئ, mylu_, 
   {{0x635003e3,0xaa4000ee,0xa59c3be5,0x00000000}},	// [1eea0] _dənə, ыетл, _खेलौ, --, 
   {{0x79940034,0xe8c40276,0xd05806be,0xc84800c7}},	//   rzyw, егул_, _bivə, моуҧ_, 
   {{0x76240209,0x3f840042,0x63500213,0x7994012d}},	//   емез, nylu_, _fənə, szyw, 
   {{0x635006be,0x00000000,0x00000000,0x00000000}},	//   _gənə, --, --, --, 
   {{0xe8987230,0xee3c00ee,0xba7401ec,0xe69001b9}},	//   _çağı, niýa_, _قاڭت, دلند, 
   {{0x67201326,0x395000a9,0x27e80270,0x3868054e}},	//   šnja, mwys_, āiná_, _unbr_, 
   {{0x395000a9,0xf8bc086b,0xee3c010e,0x00000000}},	//   lwys_, ्तीप, hiýa_, --, 
   {{0x66e13a9d,0xfd9c0150,0xee3c010e,0x00000000}},	//   _боса, _ﺇﺒﺎﻥ_, kiýa_, --, 
   {{0x39500368,0xa680010b,0xd05806be,0x00000000}},	//   nwys_, _ёлуд, _zivə, --, 
   {{0x3f8402f0,0x674401d3,0xe934010f,0x2ea401d3}},	//   fylu_, _írjá, עניץ_, کھتی_, 
   {{0xb190beb4,0xce94011c,0x00000000,0x00000000}},	//   _әллә, ванъ, --, --, 
   {{0xb814000e,0xe29400c0,0xdebc0023,0xe3c53a9e}},	//   ালিত_, _пах_, _ሰፊኑ_, áñez_, 
   {{0xee3c0209,0x9d18136b,0x2a680356,0x216424fc}},	//   giýa_, ноят_, _rncb_, _пици_, 
   {{0x63500cc1,0x2a691746,0xa154009b,0x61400f14}},	//   _sənə, _sncb_, _чашу_, _сеља, 
   {{0x5b244963,0xb81400cc,0x00000000,0x00000000}},	//   льта, ালাত_, --, --, 
   {{0x8d94ed59,0x3950015d,0x635006be,0x9e34010a}},	//   _لٔبت, fwys_, _qənə, _беъч, 
   {{0x39500af9,0x635006be,0x19940395,0x4cb8014b}},	// [1eeb0] gwys_, _vənə, гатя, _олию_, 
   {{0xd05803b9,0x5ec800fe,0x5cb800c0,0x00000000}},	//   _pivə, _ৰূপে, _плыў_, --, 
   {{0x473428fb,0x6f184087,0x63500213,0x99d400d1}},	//   тнес, nstc, _tənə, پقەت, 
   {{0x56953a9f,0xe6c411dc,0x668001d5,0x3950015d}},	//   лахт, رتاي, دیرل, bwys_, 
   {{0xddc4084c,0x00000000,0x00000000,0x00000000}},	//   _iniţ, --, --, --, 
   {{0x03a4013e,0x04440261,0x00000000,0x00000000}},	//   кило, текн, --, --, 
   {{0xb7c422ee,0xe3b00214,0x00000000,0x00000000}},	//   _артқ, درش_, --, --, 
   {{0xf770011a,0x00000000,0x00000000,0x00000000}},	//   _דקל_, --, --, --, 
   {{0xc58801d3,0x00000000,0x00000000,0x00000000}},	//   _تھام_, --, --, --, 
   {{0xaa780510,0x6abc03d4,0x00000000,0x00000000}},	//   _diýi, ্দটো, --, --, 
   {{0x29180113,0x4374009f,0x5f4401c6,0xd17400fb}},	//   hsqa_, _جهار, хүйн_, _ҡышы, 
   {{0xacb8045f,0x417400c6,0x3ea46d64,0x39500142}},	//   brûk, _لاتس, тимг, ywys_, 
   {{0x61f82935,0x69c93aa0,0x5e640150,0x6f180332}},	//   mcul, ügel, _ەنبە, astc, 
   {{0xdce401e4,0xee3c00ee,0x5fa000d1,0x29180166}},	//   _kriĉ, riýa_, _مەخم, dsqa_, 
   {{0xee3c0209,0x61f80857,0xfaa46dac,0x00000000}},	//   siýa_, ocul, ваво, --, 
   {{0xddc40139,0x39500ea0,0xaa7800a2,0xfe4400d8}},	//   _gaiş, twys_, _miýw, _рнио, 
   {{0x61f80005,0xfc0401ee,0x00000000,0x00000000}},	// [1eec0] icul, _иппо, --, --, 
   {{0xe9d53aa1,0x39500151,0xfce40353,0x3b840064}},	//   тку_, rwys_, _шопо, _алог, 
   {{0xc8b402dc,0x773801c6,0xbd8840ab,0xbb74011c}},	//   усты, ьяас_, _رنگن_, _рупъ, 
   {{0x06740276,0x16141c3e,0x34c80118,0x00000000}},	//   лучя, اساڭ, ित्द, --, 
   {{0x89d402dd,0x25340b24,0x00000000,0x00000000}},	//   _бірш, نسوخ_, --, --, 
   {{0x61f80493,0xf7453aa2,0x00000000,0x00000000}},	//   ecul, _иего, --, --, 
   {{0x61f8003a,0x00000000,0x00000000,0x00000000}},	//   fcul, --, --, --, 
   {{0x61f83058,0xaa7800a2,0x6d4800c7,0x00000000}},	//   gcul, _diýw, _ãgag, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x61f93aa3,0x648c03cd,0xf3c929f5,0xe1ec0014}},	//   acul, _høin, _قبضه_, ٝسی_, 
   {{0x61f8ae4d,0x648c03b2,0xddc40356,0x717000f7}},	//   bcul, _køin, _paiş, _چۇبا, 
   {{0x61f82b1d,0x6f193aa4,0xad980008,0xa3d4c4dd}},	//   ccul, rstc, lbúi, _सरत_, 
   {{0x7640009a,0x31140022,0x00000000,0x00000000}},	//   ifoy, _рфес, --, --, 
   {{0x7d000327,0x00000000,0x00000000,0x00000000}},	//   _ħost, --, --, --, 
   {{0x6efc00e2,0x2ac40063,0x2ab40135,0xddc40166}},	//   _bībe, вљав, eħba_, _taiş, 
   {{0x31641326,0x1fb02e47,0x9ab40953,0x291834dd}},	//   _kroz_, _әсәр, айсц, tsqa_, 
   {{0x2ab4003d,0x290c180f,0x6efc0171,0xfd00014b}},	// [1eed0] għba_, èga_, _dībe, _гӯсп, 
   {{0xb60001d3,0x2ca53aa5,0x61f93aa6,0x00000000}},	//   őáll, _önd_, zcul, --, 
   {{0xb8f8107c,0x27e53aa7,0x7640011f,0x29193aa8}},	//   _डी_, änn_, ffoy, ssqa_, 
   {{0x672004b9,0x316401c4,0xacb8002d,0xddc4054e}},	//   šnjo, _oroz_, fsûg, _uniţ, 
   {{0x45440597,0x7c4808fb,0x257001b9,0x15b8010b}},	//   انتق, _åprø, шқас, кышы_, 
   {{0x588400fd,0xf1c4033f,0x00000000,0x00000000}},	//   _кыса, _लड़न, --, --, 
   {{0x44287230,0xddc4013a,0xd7e400d4,0x69a401f9}},	//   ğa_, _mniš, _віто, _घेती, 
   {{0x44293aa9,0x316405ce,0xd6d93aaa,0x61f80ffb}},	//   şa_, _broz_, _ату_, ucul, 
   {{0xddc400c0,0x00000000,0x00000000,0x00000000}},	//   _oniš, --, --, --, 
   {{0x44f82b1d,0x26cc6c17,0x26080709,0xa3a4009b}},	//   _iè_, llgo_, ारकी_, _ијек, 
   {{0x44f93aab,0x25d008e6,0x64400e04,0xa3d412eb}},	//   _hè_, _तरुण, mfni, _सरि_, 
   {{0x44f93aac,0x5ec40116,0x00000000,0x00000000}},	//   _kè_, римғ, --, --, 
   {{0x225c0369,0x44f80cad,0x7d00031c,0x51840114}},	//   mduk_, _jè_, _ħoss, _вуја, 
   {{0x44f93aad,0x225d3aae,0x213c0429,0xa3d40037}},	//   _mè_, lduk_, mtuh_, _सरा_, 
   {{0x44f93aaf,0x213c0548,0xcee805d9,0x6fc807b7}},	//   _lè_, ltuh_, _ڌرين_, _सुपू, 
   {{0x25d0a5aa,0x00000000,0x00000000,0x00000000}},	//   _तरूण, --, --, --, 
   {{0x44f93ab0,0x213d1eec,0xa2a82977,0x0eb80724}},	// [1eee0] _nè_, ntuh_, _जगन्, _шушы_, 
   {{0x213c03a2,0x2ab40003,0x00000000,0x00000000}},	//   ituh_, rħba_, --, --, 
   {{0xfaa4894b,0x213d3ab1,0x2d94013e,0x225d3ab2}},	//   _бано, htuh_, _арӯс, kduk_, 
   {{0x44f93ab3,0x225d3ab4,0x69c0054e,0x158c0150}},	//   _bè_, jduk_, şnea, _ﺒﻐﺭﺽ_, 
   {{0x44f80622,0x76402948,0x55593ab5,0x225d3ab6}},	//   _cè_, rfoy, таля_, dduk_, 
   {{0x44f93ab7,0x18b4723c,0x00000000,0x00000000}},	//   _dè_, _тәбр, --, --, 
   {{0xf2c53ab8,0x764000ca,0x44f80ca8,0x92593ab9}},	//   лсин, pfoy, _eè_, вайт_, 
   {{0x44f813ca,0xb0300598,0xc04c00aa,0xf608004b}},	//   _fè_, әмнә, ېږي_, _ستره_, 
   {{0x213c0548,0x44f93aba,0xaa7800a2,0x6600004e}},	//   gtuh_, _gè_, _iiýt, _ыпта, 
   {{0x61d40006,0x00000000,0x00000000,0x00000000}},	//   ымыя_, --, --, --, 
   {{0x44f8033b,0xdef402d5,0x81e405ac,0xceb80210}},	//   _zè_, лыя_, _ব্দ_, kręt_, 
   {{0x307402d3,0xc0ec001f,0x213c0327,0x44f93ab7}},	//   _ክወጽእ_, _ሀገረ_, btuh_, _yè_, 
   {{0xeda53abb,0x213c0548,0xe0cc004b,0xacb800e4}},	//   ушно, ctuh_, _ډزو_, irûv, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69f0004e,0x00000000,0x00000000,0x00000000}},	//   йүнт, --, --, --, 
   {{0x9a8400f7,0x5a3402e8,0x9f0000f1,0x4a5400ea}},	//   буул, йнст, _اويو, јкас, 
   {{0x481406b3,0xdd1402fb,0x1ed8007b,0xc8c80451}},	// [1eef0] имас, _zúže, _حبوب_, نورن_, 
   {{0x44f84e53,0xddc41326,0xfcc00116,0x00000000}},	//   _rè_, _uniš, _дәсм, --, 
   {{0x44f93abc,0xe8fc0a85,0x5ba53992,0x2d88003a}},	//   _sè_, _grûn_, _гряз, lyce_, 
   {{0x44f93abd,0xd7c937b9,0x213c0429,0x225c007c}},	//   _pè_, دومه_, ytuh_, xduk_, 
   {{0x298429a3,0x225c0327,0xa3d400bc,0x00000000}},	//   _сынг, vduk_, _सरह_, --, 
   {{0x44f802bd,0x6fc80a28,0xd4d802bf,0xdce40327}},	//   _vè_, _सुभू, льщі_, _rriċ, 
   {{0x44f93abe,0x43740017,0x64413abf,0x7c28045f}},	//   _wè_, рулт, rfni, _ôfre, 
   {{0x44f93ac0,0x213c102c,0x8504216b,0xb6840050}},	//   _tè_, ttuh_, _نورن, _پھٔل_, 
   {{0x73d40184,0x225d3ac1,0x44f8067c,0x6fc800e1}},	//   лдәр_, rduk_, _uè_, _सुबू, 
   {{0x69cd3ac2,0xd148038b,0x213c0548,0x225d3ac3}},	//   _myce, اشين_, rtuh_, sduk_, 
   {{0xd4980116,0x213d3ac4,0x6368010b,0x00000000}},	//   _срт_, stuh_, _яраг_, --, 
   {{0x69cc02d0,0x527400db,0x00000000,0x00000000}},	//   _oyce, _гушу, --, --, 
   {{0xc0c80201,0xc0ec0020,0x69cc0100,0xfca80b24}},	//   _አገር_, _ሀገር_, _nyce, ناسو_, 
   {{0xf36002d3,0x442413eb,0xede40032,0xed54399f}},	//   _ተርእዮ_, _jdl_, шһыҙ_, јор_, 
   {{0x93bc0276,0x1dd80073,0xacb800e4,0x709000d8}},	//   _scăz, _ठरवत, yrûv, _фајф, 
   {{0x4424e432,0xb7e4045e,0x69c005d1,0x69cc01bf}},	//   _ldl_, খুঁত_, ğnen, _byce, 
   {{0xe8f405f5,0x69cd3ac5,0x44240042,0xdc0c0024}},	// [1ef00] илт_, _cyce, _odl_, lėči, 
   {{0xed4c034c,0xdce48c17,0x44240f85,0x692001ec}},	//   _کپی_, _krič, _ndl_, імха, 
   {{0x3604027d,0x7f400175,0xdc0c0064,0x27300116}},	//   لواف, ntlq, nėči, قىلس, 
   {{0xaa780209,0xd61800db,0x98a00064,0x00000000}},	//   _diýs, اعاچ_, drią_, --, 
   {{0xb6040064,0xe5a0e4ae,0x00000000,0x00000000}},	//   _rašę, оици, --, --, 
   {{0xad9800d2,0x6efc00ef,0xdc0c0153,0x7348003b}},	//   mbút, _lība, kėči, вчив_, 
   {{0x44253ac6,0x2d893ac7,0xded402d3,0x87b807d5}},	//   _ddl_, zyce_, ረሽን_, _бутт_, 
   {{0x6b8035fb,0x7144330e,0xa2a80490,0xe7d80cf1}},	//   _ànge, ахож, _जगण्, _भरतप, 
   {{0x4424067c,0x35a401c6,0x74540108,0xb354179e}},	//   _fdl_, _тааг, _въех, _چیتا_, 
   {{0x64a0052f,0x44253ac8,0xacb8002d,0xb35401d5}},	//   _дауа, _gdl_, nrût, _نیتا_, 
   {{0x26080490,0x99800024,0xacb800e4,0x00000000}},	//   ारची_, ogių_, irût, --, 
   {{0x2d88068f,0x99800024,0x44253ac9,0xa2c41546}},	//   tyce_, ngių_, _zdl_, ावण्, 
   {{0xa2a8102f,0xf07401af,0x998000c0,0x00000000}},	//   _जगत्, _вилә_, igių_, --, 
   {{0xc0c8001f,0x69cc9b0e,0x2d88012d,0xdce53aca}},	//   _አፈር_, _ryce, ryce_, _frič, 
   {{0xdce53acb,0x2078010f,0x69cc01ef,0x00000000}},	//   _grič, _באגא, _syce, --, 
   {{0x81400345,0x00000000,0x00000000,0x00000000}},	//   _بۆین, --, --, --, 
   {{0xad9809c2,0xaa7800a2,0xa2c400dc,0xda786bcd}},	// [1ef10] scúb, _biýr, ावत्, шяр_, 
   {{0xa3d44ff1,0x69cc02fb,0xdc740124,0x98740e92}},	//   _सरल_, _vyce, _дгьы, олуц, 
   {{0xd7f93acc,0x44253acd,0xab6008b0,0xaa78010e}},	//   руу_, _rdl_, _بۇزى, _diýr, 
   {{0x44253ace,0xd6d93acf,0x546c0092,0x00000000}},	//   _sdl_, атч_, ተጠበቀ_, --, 
   {{0x44253ad0,0xd6181ec7,0x6b8001e1,0x00000000}},	//   _pdl_, شتنا_, _àngb, --, 
   {{0xe7853ad1,0x26001682,0x58d40801,0x9b440014}},	//   _кубо, ṱo_, _моят, _انێو, 
   {{0xa3d40490,0xa2a800cd,0x00000000,0x00000000}},	//   _सरळ_, _जगद्, --, --, 
   {{0x1634100e,0xad9803b2,0xe80c0118,0x00000000}},	//   _меся, nbús, िरका_, --, 
   {{0x00c80c72,0x55581d5b,0xdce40024,0x00000000}},	//   ллик_, _катя_, _srič, --, 
   {{0xdce42aa3,0x44244b84,0xb6000241,0x98a000c0}},	//   _prič, _udl_, _àári, prią_, 
   {{0x6fc839d7,0x3f9013d5,0x939408de,0x00000000}},	//   _सुदू, ázu_, _وجما, --, 
   {{0xdc0c0006,0x00000000,0x00000000,0x00000000}},	//   rėči, --, --, --, 
   {{0xaa7802fb,0xcdc402dd,0xc1040be2,0x62980051}},	//   _ohýb, жаяқ, _اوتي, mhuo, 
   {{0xdce40232,0xfce53ad2,0x98a001a6,0x10640014}},	//   _trič, сого, mrić_, _وُنُ, 
   {{0xeb953ad3,0xbe680323,0xab253ad4,0xa06401ee}},	//   бир_, _байж_, йора_, _баҙа_, 
   {{0x629802f6,0x00000000,0x00000000,0x00000000}},	//   nhuo, --, --, --, 
   {{0xc310015b,0x7c9404fb,0xacb8002d,0x00000000}},	// [1ef20] সূচি_, _هشدا, trût, --, 
   {{0xaa7801f1,0x961028d4,0x00000000,0x00000000}},	//   _chýb, ार्ट_, --, --, 
   {{0x98a005be,0xacb8045f,0x25bc054e,0xe7e00fe3}},	//   hrić_, rrût, _axul_, केला_, 
   {{0x26dc05d9,0x98a00640,0xad991d9e,0x648c0158}},	//   _chuo_, krić_, mbúr, _høih, 
   {{0x98a00b4b,0xb38401c0,0x28000118,0x998000c0}},	//   jrić_, өлдл, érní_, rgių_, 
   {{0xb8940491,0x98a0098d,0x25093ad5,0x00000000}},	//   _السع, drić_, ارنی_, --, 
   {{0x25bc0381,0x81e400fe,0xe3ac00e5,0x00000000}},	//   _exul_, _ব্ল_, ٹرو_, --, 
   {{0xe3ac0e53,0x1fcc0183,0x7d140857,0xa7a400db}},	//   عرو_, ৰশাস, _owys, _укса_, 
   {{0xd0100597,0x90993ad6,0x66e0139b,0x2afc0406}},	//   ولة_, ивит_, _хота, _शंभु_, 
   {{0x26dc0198,0x656c0005,0x21293ad7,0x161010eb}},	//   _zhuo_, _ácha, ácha_, ारकर_, 
   {{0x7520929f,0x914800d1,0x28780a7c,0x4e781cd0}},	//   lsoz, учқа_, אנימ, айню_, 
   {{0x62993ad8,0x7d1400a9,0x98a02375,0xb8d80327}},	//   chuo, _bwys, brić_, _ཅམ_, 
   {{0xc1a400c7,0xd3700133,0xf1e400fe,0x00000000}},	//   _мышқ, _رێکک, _গ্ৰহ_, --, 
   {{0x67200bb8,0x7d14015d,0x2bc8005b,0x00000000}},	//   šnji, _dwys, губо_, --, 
   {{0x752001a9,0x5fcc0037,0x69c003e0,0x00000000}},	//   hsoz, _सुपल, ğnem, --, 
   {{0x75213ad9,0x7d140042,0x00000000,0x00000000}},	//   ksoz, _fwys, --, --, 
   {{0xad980321,0xaa7800a2,0xad2401d3,0x7d14015d}},	// [1ef30] rbús, _diýp, _اربو, _gwys, 
   {{0x6d5d3ada,0x81e400bd,0xad980d12,0x00000000}},	//   _isqa, বুক_, sbús, --, 
   {{0x23a40d5f,0xe8fc002d,0x7d1404cc,0x6298023a}},	//   _केंद, _krûk_, _zwys, yhuo, 
   {{0x09ac00cc,0x00000000,0x00000000,0x00000000}},	//   _কঁঠা, --, --, --, 
   {{0xa2c41b61,0x5fcc007d,0x6fc807b6,0xdb1001e1}},	//   ावस्, _सुनल, _सुसू, _àfòf, 
   {{0x98a00552,0xaa7802f0,0xaca001e1,0xb34403e3}},	//   vrić_, _uhýb, _olọg, kaçı, 
   {{0x68fc074d,0x62993adb,0x26dd3adc,0xa5c0068f}},	//   lqqd, thuo, _thuo_, _łódz, 
   {{0x98a01674,0x41053add,0x21ec0166,0x6d5c0139}},	//   trić_, озив, _nöhü_, _osqa, 
   {{0xaca0063f,0x62980156,0xad9800d7,0x00000000}},	//   _alọg, rhuo, zbúr, --, 
   {{0xaca00521,0x6298023a,0x7d1403cb,0x80a8005b}},	//   _blọg, shuo, _rwys, рвов_, 
   {{0x66193ade,0x6d5c4ce9,0xe8fc045f,0x629801fb}},	//   _keuk, _asqa, _brûk_, phuo, 
   {{0x7d140cfd,0x66180430,0x00000000,0x00000000}},	//   _pwys, _jeuk, --, --, 
   {{0x6618003e,0x7c3c00f3,0x435402d3,0x52c8009f}},	//   _meuk, _pcpr, _መርበባ, _اِنّ_, 
   {{0x6618d947,0xdce400ef,0x71700633,0x00000000}},	//   _leuk, _briā, _آهوا, --, 
   {{0x6d5c003a,0x503800cf,0x46c8012c,0x28bc00dc}},	//   _esqa, _ايىڭ_, िकाह, ्वनि, 
   {{0x2dc802e3,0x24bc009e,0xfa340131,0x4af80276}},	//   ụlọ_, ইতিহ, تىرج, сэря_, 
   {{0xf8a87e1b,0x00000000,0x00000000,0x00000000}},	// [1ef40] авак_, --, --, --, 
   {{0xacb8002d,0x25800055,0xad9800e4,0x00000000}},	//   lsûn, _mūlā_, mbúp, --, 
   {{0x66193adf,0xc81400d6,0x7e7463cd,0xad98004e}},	//   _beuk, яєть, _knyp, ncún, 
   {{0x7bdd2777,0x66193ae0,0x752037ae,0xacb8002d}},	//   _izpu, _ceuk, tsoz, nsûn, 
   {{0x66193ae1,0x09ac02f5,0x2d8c0166,0x2a5400d9}},	//   _deuk, _কুঠা, _üget_, _ובכן_, 
   {{0x75213ae2,0xc8b40022,0xb9f800b7,0x33284c92}},	//   rsoz, _ессы, _ቆላ_, ацин_, 
   {{0x661805c7,0x75200112,0x7e7402d0,0x7e6402d0}},	//   _feuk, ssoz, _onyp, kdkp, 
   {{0x661801f7,0x938800d1,0x491000bc,0x00000000}},	//   _geuk, исқа_, दीको_, --, 
   {{0xa504a8de,0xacb8002d,0xe1ed3ae3,0x60f40006}},	//   _мета_, dsûn, پسي_, оныя_, 
   {{0x7e753ae4,0x661801c0,0x00000000,0x00000000}},	//   _anyp, _zeuk, --, --, 
   {{0xd7d005ba,0x3244cf10,0x66193ae5,0xd0101bf3}},	//   _तुमच, _межг, _yeuk, ولک_, 
   {{0xeea93ae6,0x00000000,0x00000000,0x00000000}},	//   рток_, --, --, --, 
   {{0xa2c407b7,0x6fc93ae7,0xc2e834f6,0x28bc00dc}},	//   ावर्, _सुरू, _اعلم_, ्वमि, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9b693ae8,0xce953ae9,0x6f840276,0x106401d9}},	//   ошта_, _накъ, _фулж, _وُچُ, 
   {{0x6d5c0589,0x00000000,0x00000000,0x00000000}},	//   _tsqa, --, --, --, 
   {{0x6d5c02d1,0x66180942,0x6f080175,0xdfcc215c}},	// [1ef50] _usqa, _reuk, _htfc, _كيۇ_, 
   {{0x66193aea,0x648c0158,0xe7680063,0x9ca801f7}},	//   _seuk, _høiv, ијек_, _وهيل_, 
   {{0x6618023a,0xd1f80092,0x00000000,0x00000000}},	//   _peuk, ፈሩት_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x66193aeb,0xeabc0241,0xf0780240,0x00000000}},	//   _veuk, _ijù_, _ብጻዕሪ_, --, 
   {{0x320405da,0xd83805f5,0x8cc000e1,0x00000000}},	//   _afoy_, _мэс_, लकटो, --, 
   {{0x66193aec,0x250807d6,0xa354b9ff,0xd5b82cc8}},	//   _teuk, ارچی_, تیاط_, йсә_, 
   {{0x661801c4,0x67e0022e,0x00000000,0x00000000}},	//   _ueuk, nеjm, --, --, 
   {{0xa3d40cb4,0xfdc403d4,0xfbd0000d,0x00000000}},	//   _सरक_, _এণ্ড, _दुनम, --, 
   {{0x7e753aed,0xef2403e3,0x00000000,0x00000000}},	//   _snyp, _şüar_, --, --, 
   {{0xacb8002d,0xeabc0248,0x4abc11a6,0x00000000}},	//   tsûn, _ojù_, ्काव, --, 
   {{0x29080030,0x25800055,0xef0c004e,0x00000000}},	//   _otca_, _tūlā_, _үм_, --, 
   {{0xacb8000f,0x6d200276,0x7eb40427,0xf2d0010f}},	//   rsûn, ндяз, jšpe, _װעג_, 
   {{0xacb8002d,0x00000000,0x00000000,0x00000000}},	//   ssûn, --, --, --, 
   {{0x2908070d,0xeb940c17,0x2004022f,0xad980005}},	//   _atca_, пир_, _ifni_, lcúl, 
   {{0x244c0bc7,0xab6001c6,0x7e7402d0,0x39940023}},	//   lımı_, эвсл, _unyp, _ዘመርቲ_, 
   {{0x7c28002d,0x5fcc00c5,0xe8f407a5,0xad99014e}},	// [1ef60] _ôfro, _सुतल, злу_, ncúl, 
   {{0x244c4953,0xeabc01e1,0xf1cc05f9,0xf7e8007b}},	//   nımı_, _ejù_, _हँसन, مرضى_, 
   {{0xdb242444,0xabf802e4,0x3b08026a,0x69c80112}},	//   _توجی, _להיר, _ћемо_, üger, 
   {{0x06b000d1,0x244c4dd9,0x00000000,0x00000000}},	//   ﺳﺎﺳﻪ, hımı_, --, --, 
   {{0x244c0365,0x20053aee,0x00000000,0x00000000}},	//   kımı_, _ofni_, --, --, 
   {{0x7afc069c,0xb4d408a3,0x244c03e0,0x00000000}},	//   _kupt, सते_, jımı_, --, 
   {{0x289825f9,0x244c3bc1,0xe73400f3,0x00000000}},	//   _פילא, dımı_, _нер_, --, 
   {{0x20053aef,0x7afd3af0,0x00000000,0x00000000}},	//   _afni_, _mupt, --, --, 
   {{0x7afce179,0xe5a00276,0x65680175,0x244c03e0}},	//   _lupt, _зити, cvgh, fımı_, 
   {{0xe7e0012c,0x244c236c,0x00000000,0x00000000}},	//   केका_, gımı_, --, --, 
   {{0x7afcd1fe,0x739805f5,0x00000000,0x00000000}},	//   _nupt, _утас_, --, --, 
   {{0x200400fc,0x1fcc03d4,0x00000000,0x00000000}},	//   _efni_, ৰশংস, --, --, 
   {{0x7afc0093,0xfba80154,0x244c0b97,0x00000000}},	//   _aupt, _খুলত, bımı_, --, 
   {{0x6d4800e4,0x3ea8002e,0xa065319c,0x20000156}},	//   _ãgam, _ňatt_, _нача_, ñjit_, 
   {{0x7afc084c,0x60600be2,0xdfd02f89,0x00000000}},	//   _cupt, _سهيل, _пошы, --, 
   {{0x2908003e,0x00000000,0x00000000,0x00000000}},	//   _ptca_, --, --, --, 
   {{0xda08104c,0xda700050,0x7bd81427,0x00000000}},	// [1ef70] سيله_, ھُے_, ýtur, --, 
   {{0xad9800d2,0xb4d4cb91,0x6ecc00b8,0x00000000}},	//   ncúm, सतो_, _ṛbha, --, 
   {{0x7afd3af1,0x3db000cc,0x00000000,0x00000000}},	//   _gupt, _টুপল, --, --, 
   {{0x940c0cc1,0xd7741216,0x244c3361,0x648c03cd}},	//   _ildə_, عالع, zımı_, _løit, 
   {{0x290800dd,0x244c3361,0x00000000,0x00000000}},	//   _utca_, yımı_, --, --, 
   {{0x482400cf,0xb97808c3,0x437400d8,0x00000000}},	//   _زىرق, _ונשי, дуит, --, 
   {{0x42e8005b,0x00000000,0x00000000,0x00000000}},	//   омко_, --, --, --, 
   {{0xd04806be,0x00000000,0x00000000,0x00000000}},	//   mldə, --, --, --, 
   {{0x26cd0587,0x244c0259,0x00e401c0,0x6aac03ac}},	//   mogo_, tımı_, мжин, _mmcf, 
   {{0x26cd3af2,0x998002b5,0x3de40150,0xe4a400db}},	//   logo_, waiū_, _ﺍﺭﯨﻘ, _эрбо, 
   {{0x244c050e,0x26cc009b,0xddf8013d,0x83e0000d}},	//   rımı_, oogo_, зьгә_, _फरिआ, 
   {{0x26cd3af3,0x244ceaab,0xee3c02d2,0x00000000}},	//   nogo_, sımı_, ggý_, --, 
   {{0x7afd3af4,0x244c03ee,0x6288068c,0x00000000}},	//   _supt, pımı_, _iogo, --, 
   {{0x26cc014c,0x62893af5,0xa28004fb,0x7afc00df}},	//   hogo_, _hogo, _آیکو, _pupt, 
   {{0xcee83a25,0x9f40049b,0x62893af6,0x648c03cd}},	//   ترین_, äjä_, _kogo, _høis, 
   {{0x62893af7,0xc5e4004b,0x26cc6085,0x7afc365a}},	//   _jogo, _مړ_, jogo_, _vupt, 
   {{0x62893af8,0xdebc069c,0x26cc00b2,0x6a8000d2}},	// [1ef80] _mogo, _ደሊና_, dogo_, _sífû, 
   {{0xddc42195,0x7afc0656,0x6efc00cd,0xbca43319}},	//   _kniž, _tupt, _bībh, _آمدي, 
   {{0x26cc315a,0xfaa53af9,0x62880430,0x27b000d1}},	//   fogo_, _жано, _oogo, вәтс, 
   {{0x6288d8b3,0x26cd3afa,0xbc3801ed,0xb4d400cd}},	//   _nogo, gogo_, _اسکا_, सत्_, 
   {{0xf1e01a04,0x2ab40003,0x76440108,0xb85000e5}},	//   _परधन, għbu_, _ökym, _لڑاک, 
   {{0x62880170,0x6340013f,0xe8f42218,0x00000000}},	//   _aogo, _nɑns, _оля_, --, 
   {{0x62893afb,0x26cd3afc,0xf6241677,0xd3704e2e}},	//   _bogo, bogo_, _одво, اهب_, 
   {{0xd0480213,0x6a9800df,0x00000000,0x00000000}},	//   ələy, ַשינ, --, --, 
   {{0x041c00bd,0xc0c80020,0x50f4368e,0x61f000ec}},	//   _নারী_, _አለም_, нзит, پسيء, 
   {{0x62880428,0x2978010f,0x00000000,0x00000000}},	//   _eogo, קטיא, --, --, 
   {{0x62884800,0xa8340302,0xceb83052,0x00000000}},	//   _fogo, וריד_, зәп_, --, 
   {{0x62893afd,0xaa7802f0,0xd05c06be,0xc0c80092}},	//   _gogo, _chýl, _əzər, _አወል_, 
   {{0x7bd828bc,0xf1e0bde7,0x9d18013e,0x00000000}},	//   ütun, _परिन, моят_, --, 
   {{0x62884520,0x6efc00e2,0x26cd3afe,0x9df800d4}},	//   _zogo, _lībi, zogo_, ьнят_, 
   {{0x62893aff,0x1bd422e9,0x28bc00cd,0x00000000}},	//   _yogo, воря, ्वसि, --, 
   {{0x62893b00,0x26cc0005,0xf1e13b01,0x81e000fe}},	//   _xogo, xogo_, _परान, _দলত_, 
   {{0xddc4b515,0xaaa807f7,0x00000000,0x00000000}},	// [1ef90] _zniž, घोषक, --, --, 
   {{0x26cc0337,0xeb04bb65,0x00000000,0x00000000}},	//   wogo_, _очмо, --, --, 
   {{0x26cd3b02,0xe7082a60,0x9c440124,0x2008012d}},	//   togo_, زتان_, _рхыл, ścig_, 
   {{0x56953b03,0xbb38010f,0x00000000,0x00000000}},	//   кахт, _צערי, --, --, 
   {{0x628803b4,0x26cd3b04,0x27fc05d1,0x3e7805d5}},	//   _rogo, rogo_, _şunu_, lütà_, 
   {{0x62893b05,0xc8c93b06,0x26cd3b07,0x648c03cd}},	//   _sogo, _روزن_, sogo_, _røis, 
   {{0x62888847,0x72a00873,0x26cd3b08,0x57e80108}},	//   _pogo, گەنن, pogo_, _ждём_, 
   {{0x28bc1944,0x628801a9,0xb5d00116,0x00000000}},	//   ्ववि, _qogo, _ﭘﺮﯦﺰ, --, 
   {{0x62893b09,0xddc4d392,0xaa7800a2,0x72a000d1}},	//   _vogo, _sniž, _biýz, دەنن, 
   {{0x62893b0a,0x93bc084c,0xb978011a,0x00000000}},	//   _wogo, _adău, פנתי, --, 
   {{0x62893b0b,0xe7e00490,0x7eb40153,0xd6d8030d}},	//   _togo, केचा_, ešpa, _атă_, 
   {{0x98a00270,0x62880024,0xf770010f,0x00000000}},	//   isiā_, _uogo, אקט_, --, 
   {{0xc0c80092,0x00000000,0x00000000,0x00000000}},	//   _አለሙ_, --, --, --, 
   {{0xd1b81066,0xddc4031c,0x75f53b0c,0x7ae40076}},	//   _تاما_, _iniż, _hüzü, _shkt, 
   {{0x7ae40477,0xddc400a2,0xa9a001d5,0x00000000}},	//   _phkt, _uniž, ҳитд, --, 
   {{0xdce40cf4,0xf9841188,0xfeb800f2,0x6e40014b}},	//   _orić, нгбо, _ژاکت_, _беъз, 
   {{0x0d640124,0x510c008f,0xddc4031c,0x75f40205}},	// [1efa0] _аныҟ, ַהאַ, _jniż, _müzü, 
   {{0xe9dc5c17,0xddc40135,0xe1e40137,0xee3c0419}},	//   _abús_, _mniż, _ۅس_, chýb_, 
   {{0x78bc074d,0xe8fc002d,0x68ec0118,0xeb94010a}},	//   rnpv, _brûs_, _řidí, _зиэ_, 
   {{0xe1e53b0d,0x98c0825f,0xd911370e,0xf6d4abd7}},	//   _مس_, ırıp_, _نیر_, رزاد, 
   {{0x28bc2314,0x00000000,0x00000000,0x00000000}},	//   ्वशि, --, --, --, 
   {{0xf3653b0e,0x34c805f9,0xf74401af,0x69c00205}},	//   етин, ाकेद, _пего, ğnet, 
   {{0x75f40b97,0x6f9c0150,0x28bc4e6d,0xddc40210}},	//   _büzü, _ﺇﻁﺎﻋ_, ्वरि, _aniż, 
   {{0xa2c4190c,0xb1a001e0,0x7ea409e8,0x38693b0f}},	//   ावग्, лһеҙ, _hópf, _habr_, 
   {{0x75f4ec3e,0xfbd0000d,0x00000000,0x00000000}},	//   _düzü, _दुसम, --, --, 
   {{0x3a200066,0x386801d5,0xaa78010e,0x6d4800e4}},	//   _lekp_, _jabr_, _diýy, _ãgai, 
   {{0xdd940046,0x733446c6,0xda200ce0,0x331802f2}},	//   қары, _سرائ, बरात_, _رزاد_, 
   {{0x76413b10,0x3a200099,0x38680381,0x75f40205}},	//   ngoy, _nekp_, _labr_, _güzü, 
   {{0x3cf8007f,0x99c40eac,0x42500137,0x76400162}},	//   _bipv_, ্ধুক, _ئچىر, igoy, 
   {{0x7eb4627e,0x6598008f,0x386801bf,0x00000000}},	//   ršpa, ליכק, _nabr_, --, 
   {{0x5f700228,0x75f40365,0xdc740c98,0xddc4033f}},	//   _ماير, _yüzü, ыгры, _zniż, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2008006d,0x28bc0b02,0xdde40139,0x00000000}},	// [1efb0] ście_, ्वलि, _бәрү, --, 
   {{0x290c00da,0xc6186bcf,0x61ec00ac,0x58d80108}},	//   īga_, दर्य_, üklə, едуя_, 
   {{0xdce4107d,0xd83828fc,0x98c400d8,0x00000000}},	//   _srić, ээт_, устл, --, 
   {{0xd7c815fa,0xdce407f5,0x76400429,0x316401c6}},	//   رونه_, _prić, ggoy, _osoz_, 
   {{0x38681676,0x00000000,0x00000000,0x00000000}},	//   _fabr_, --, --, --, 
   {{0x64c8190c,0x75f47a36,0xdce401a6,0xfd640055}},	//   िवेश, _süzü, _vrić, _chuṣ, 
   {{0x3164009a,0x066407dd,0xf7881432,0xe8bc0073}},	//   _asoz_, _ихаҭ, rkçü_, ्वीच, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x44f53b11,0x21280221,0x45d40276,0x7ea403b2}},	//   _апас, éch_, _роас, _hópg, 
   {{0x3eb13b12,0xfd6400b8,0x00000000,0x00000000}},	//   _smyt_, _ghuṣ, --, --, 
   {{0x5334016c,0x7c28045f,0x6b8004cc,0xacb8002d}},	//   _бехт, _ôfri, _àngh, brûz, 
   {{0x64413b13,0xd36c02dd,0x2a6800a3,0xddc40003}},	//   lgni, _ءۇي_, _nacb_, _tniż, 
   {{0x6298009f,0x225c003e,0x6efc0153,0x64400162}},	//   mkuo, meuk_, _rūbe, ogni, 
   {{0x64413b14,0xfce4262e,0x225d3b15,0x7f84007b}},	//   ngni, того, leuk_, _للتن, 
   {{0x64413b16,0x213c0098,0xfbd007f7,0x76400205}},	//   igni, luuh_, _दुशम, ygoy, 
   {{0x225d3b17,0x386801b9,0x6298652e,0x3eb000ee}},	//   neuk_, _sabr_, nkuo, _umyt_, 
   {{0x62993b18,0x2a68009f,0x3cc800a7,0x00000000}},	// [1efc0] ikuo, _dacb_, _олио_, --, 
   {{0x3a200099,0xb794026a,0x225c003e,0x386801d5}},	//   _wekp_, крећ, heuk_, _qabr_, 
   {{0x213c05b1,0xdd90004b,0x225c0098,0x62983110}},	//   huuh_, _خوښ_, keuk_, kkuo, 
   {{0x2a6800a3,0x225c017a,0xef2403e3,0x00000000}},	//   _gacb_, jeuk_, _şükr_, --, 
   {{0x76413b19,0xa0240eac,0x213c002d,0x225c00d5}},	//   rgoy, _মানব_, juuh_, deuk_, 
   {{0x644004f3,0x65913b1a,0x213c020b,0x7ea40174}},	//   ggni, рашу, duuh_, _hópd, 
   {{0x61f403be,0xdef8001f,0xb364011c,0x00000000}},	//   əblə, ጋለን_, тълк, --, 
   {{0xe8fc002d,0x225c003e,0x52cc0073,0x6440dd75}},	//   _krûp_, geuk_, ावेस, agni, 
   {{0xb4653b1b,0x6fc801ad,0x31c402e8,0xd25000f1}},	//   _икал, _सुजू, ъскв, لنګ_, 
   {{0x9f44007b,0xc5d40816,0x629801f4,0x918000db}},	//   _ngnó_, _сісь, akuo, _ۇۇعۇ, 
   {{0x225d3ae0,0xa3440022,0xb4cca9ec,0xfbd0000d}},	//   beuk_, _азха_, रवी_, _दुलम, 
   {{0x225c0098,0xabd80150,0xdef8064e,0x00000000}},	//   ceuk_, _ﺃﺜﻨﺎ, кыя_, --, 
   {{0x614002d5,0x2cb001a9,0x00000000,0x00000000}},	//   _веча, аndа_, --, --, 
   {{0xe0cc02e9,0xa0a010fc,0xa1c00166,0x00000000}},	//   _وزو_, _ваљд, _әбәд, --, 
   {{0x5064005e,0x9f640eff,0xada409f3,0xa2c407b7}},	//   _атқа, _арыз_, _brúð, ावच्, 
   {{0x5a34ab01,0xda340139,0x64400210,0x00000000}},	//   инст, иесы, zgni, --, 
   {{0x49753b1c,0x644012ed,0x9a84010b,0x09740108}},	// [1efd0] ылас, ygni, шурл, ыгаю, 
   {{0xace8027d,0x225c005a,0xab6000d1,0x00000000}},	//   _تربل_, zeuk_, _پۇرى, --, 
   {{0x6d4d3b1d,0x2a68005a,0x644005d5,0x225c00d5}},	//   ltca, _tacb_, vgni, yeuk_, 
   {{0x2a680048,0x00000000,0x00000000,0x00000000}},	//   _uacb_, --, --, --, 
   {{0x6d4c14dc,0xdd0c01e1,0xd54800c6,0x644005d5}},	//   ntca, _góńg, نجوم_, tgni, 
   {{0x6d4c76d1,0x64400e78,0x225c0098,0x00000000}},	//   itca, ugni, weuk_, --, 
   {{0x225d3b1e,0x64413b1f,0x6d4c0036,0x6298b0cb}},	//   teuk_, rgni, htca, tkuo, 
   {{0x56953b20,0x77000014,0x6d4c13eb,0x3d940220}},	//   _каст, _اژٕن, ktca, _ﮔﺮﯞﭘ, 
   {{0x225d3b21,0x569400f7,0x62980962,0xd6d8014b}},	//   reuk_, _татт, rkuo, _ртр_, 
   {{0xf9900302,0x3d2800d2,0x9f4407c5,0x62993b22}},	//   צרי_, _lîwá_, _tgnü_, skuo, 
   {{0x7ea4097a,0x44251672,0x225c0438,0x00000000}},	//   _lópe, _iel_, peuk_, --, 
   {{0x44253b23,0x6d4c1ba0,0x9258007b,0x7eb40419}},	//   _hel_, ftca, _لشهر_, ršpo, 
   {{0x6d4c074d,0x44242045,0x91853b24,0xf2d0010f}},	//   gtca, _kel_, _نجوم, _פעד_, 
   {{0x442404b9,0x3ebc066d,0xe8bc000b,0xbb441468}},	//   _jel_, őtt_, ्वोच, легк, 
   {{0x44253b25,0xfaa40006,0x6d4c03ac,0xada42507}},	//   _mel_, гаво, atca, _prúð, 
   {{0x44253b26,0x7f413b27,0xaf0002e8,0x00000000}},	//   _lel_, mulq, _упъл, --, 
   {{0x6d4d3b28,0xee353b29,0x44241028,0x47dc00fe}},	// [1efe0] ctca, _сны_, _oel_, _বলগী, 
   {{0x44253b2a,0xe9d49205,0x81c4015b,0xb9e40132}},	//   _nel_, уку_, _এরা_, _ەسسى, 
   {{0xada405f7,0x6efc00b8,0xcbf0030d,0x00000000}},	//   _trúð, _kūba, _маьι, --, 
   {{0x4424b446,0xddc40356,0x7ea4032e,0xf62421b5}},	//   _ael_, _gaiţ, _hópb, уддо, 
   {{0x44253b2b,0x261005f9,0x93bc0311,0x4eac010f}},	//   _bel_, दड़ी_, _adăp, ובאַ, 
   {{0x44253b2c,0xb4cd3b2d,0x7f4002d1,0xdce401ef}},	//   _cel_, रवे_, kulq, _osič, 
   {{0x7c28002d,0x24f402dd,0x6d480254,0x00000000}},	//   _ôfru, ыншы_, _ägav, --, 
   {{0xd6c4016c,0x44253b2e,0x7f413b2f,0x7bdc037e}},	//   _тибқ, _eel_, dulq, _mypu, 
   {{0x44253b30,0xe6900491,0x2bd81df1,0x7bdc0200}},	//   _fel_, _القد, _मुना, _lypu, 
   {{0x44246c81,0x00000000,0x00000000,0x00000000}},	//   _gel_, --, --, --, 
   {{0x2aa40037,0x2d8c013d,0xd54401e1,0x00000000}},	//   _hõbe_, _ügez_, bẹ̀j, --, 
   {{0x6d4c074d,0x44253b31,0x2f2c0210,0x00000000}},	//   ttca, _zel_, ręg_, --, 
   {{0x442429ef,0x21280597,0x7bdc0309,0x6d4c03ac}},	//   _yel_, ácht_, _aypu, utca, 
   {{0x6d4c7635,0x44241574,0x3074026a,0xee3c00d7}},	//   rtca, _xel_, _људс, chýn_, 
   {{0x6d4c6460,0xa0c10fec,0x7f40d2f3,0x6ae80798}},	//   stca, _ديوو, culq, еќав_, 
   {{0x7ea40022,0x81c40183,0x6d4c0857,0xace4030d}},	//   _pópe, _এৰি_, ptca, ăмра_, 
   {{0xe9dc00ae,0x00000000,0x00000000,0x00000000}},	// [1eff0] _gcúl_, --, --, --, 
   {{0xc538001f,0xdf1400e5,0x00000000,0x00000000}},	//   _አልቻሉ, _جڑیں_, --, --, 
   {{0x44253b32,0x46141291,0x81c400fe,0xaae401f6}},	//   _rel_, لوار, _এৰা_, _مسحو, 
   {{0xaa641f91,0x6624282b,0x00000000,0x00000000}},	//   _сток, اراك, --, --, 
   {{0x44251b40,0x84240075,0xa2b0068f,0xddc53b33}},	//   _pel_, لىشن, इफस्, _kaiš, 
   {{0x65c00046,0x4424016d,0x3f80032e,0x75d0009a}},	//   _құла, _qel_, _áhug_, غيوا, 
   {{0x44253b34,0xddc40006,0x98a00006,0xf4840cbe}},	//   _vel_, _maiš, usią_, شاوی, 
   {{0x44253b35,0xddc53b36,0x96f80334,0x98a0012d}},	//   _wel_, _laiš, _бест_, rsią_, 
   {{0x00c91e12,0xdce40115,0xf990008f,0x00000000}},	//   клик_, _ariĝ, ַרט_, --, 
   {{0x40945f3c,0x44240483,0xddc41b24,0xdce53b37}},	//   ррит, _uel_, _naiš, _briĝ, 
   {{0x5fcc4709,0xd69401e0,0xd49808ca,0x06b001e1}},	//   _सुखल, hынд, _ёру_, _àísí_, 
   {{0x7bdc007f,0x3f6406af,0x5ec400d1,0x764401f4}},	//   _rypu, _vœu_, симғ, _ökyt, 
   {{0x2bd81533,0xee34021b,0x7c380077,0xe9dc8ebf}},	//   _मुबा, шня_, ótro, _nyú_, 
   {{0x7bdc0124,0xbd800023,0x00000000,0x00000000}},	//   _pypu, _ክኸፍሉ_, --, --, 
   {{0xbea42081,0x7f400477,0xab24c6e2,0x00000000}},	//   _вайк, qulq, иора_, --, 
   {{0x7bdc0122,0x00000000,0x00000000,0x00000000}},	//   _vypu, --, --, --, 
  
   {{0x23640369,0x7bdc033f,0x290c00df,0x00000000}},	// [1f000] hwnj_, _wypu, ŭgan_, --, 
   {{0xddc4143f,0x7d1402d0,0x26c40561,0xbcd800ec}},	//   _gaiš, _itys, énon_, _جذبا_, 
   {{0x59d81524,0x291c0240,0x31e001ad,0x09c80154}},	//   _भँवर, _çuan_, _पर्ध, _শরণা, 
   {{0x98a02220,0xe7353b38,0xb4cc01ad,0x00000000}},	//   ksić_, рец_, रव्_, --, 
   {{0x68e801d3,0x041c00cc,0x00000000,0x00000000}},	//   üldé, _নাজী_, --, --, 
   {{0xe4c013f3,0x39500024,0x24e53b39,0x00000000}},	//   ойчи, mtys_, амчи_, --, 
   {{0xb7d93b3a,0x39500731,0x00000000,0x00000000}},	//   _شورا_, ltys_, --, --, 
   {{0x984800aa,0xe3ac027d,0x2aa40254,0x00000000}},	//   _جګړې_, ظرو_, _tõbe_, --, 
   {{0x39513b3b,0xe5a13b3c,0x00000000,0x00000000}},	//   ntys_, _дити, --, --, 
   {{0x92c809bd,0x39513b3d,0x06b001e1,0x251800d9}},	//   োগে_, itys_, _àírí_, _סובא, 
   {{0xa0853b3e,0x8c00015b,0x7d1400a2,0xddc40024}},	//   рсыз_, ্রমন_, _atys, _raiš, 
   {{0x22900bbf,0xc3b801c0,0x39500153,0xddc400de}},	//   _وللس, _сууц_, ktys_, _saiš, 
   {{0xce94020a,0x4f8401d9,0xddc400c0,0x00000000}},	//   _ҳайъ, _گاشہ, _paiš, --, 
   {{0x656c0042,0xef2403e3,0x20d0007b,0x00000000}},	//   _âche, _şüur_, _وتوج, --, 
   {{0x7d14002d,0xddc40024,0x60140375,0xa0a000d8}},	//   _etys, _vaiš, _דחוף_, _фајд, 
   {{0x5fcc0490,0x39500175,0x6f1802d0,0x5e840354}},	//   _सुटल, ftys_, mptc, _дуьз, 
   {{0xddc406be,0x885801c6,0xc8c801f7,0x395000c0}},	// [1f010] _ibiş, лиас_, هورن_, gtys_, 
   {{0x8c18215e,0x6d5c014f,0xc02c02d3,0x195924fa}},	//   _حيدر_, _ipqa, _ሰበስል, рафы_, 
   {{0x7ea40321,0xb7840ce8,0x86c400ec,0x00000000}},	//   _hópa, бәте_, ٽيشن, --, 
   {{0x7ea40008,0xd6180b73,0xcfa8015b,0x00000000}},	//   _kópa, لتها_, _ওখান, --, 
   {{0x2bd8068f,0x39500076,0x298473b5,0x00000000}},	//   _मुता, ctys_, _тынг, --, 
   {{0x8364dffc,0x0708007b,0x00000000,0x00000000}},	//   مدعل, _ميسي_, --, --, 
   {{0x42d81c3f,0xddc40276,0x43753b3f,0xa2b007f7}},	//   лфия_, _obiş, султ, इफल्, 
   {{0x22480639,0x00000000,0x00000000,0x00000000}},	//   ück_, --, --, --, 
   {{0x5fcc06ab,0x07a44445,0x20001a48,0x95c81180}},	//   _सुजल, _таңн, žjim_, _куфа_, 
   {{0x65788aa7,0x95c80408,0xd3780131,0x6830013d}},	//   _iruh, _туса_, учә_, _uñdı, 
   {{0x7d153b40,0xbef402e8,0x427401ee,0x00000000}},	//   _stys, йчмъ, _гѳлс, --, 
   {{0x69cc0066,0x395002f6,0x403401e0,0x00000000}},	//   _oxce, ytys_, шеүс, --, 
   {{0xee3c0122,0xe164004b,0x66d400b4,0x69c8045f}},	//   chým_, _خداي, ụkwa, ûgel, 
   {{0x6578009f,0x7ea402d2,0x6aa42374,0x00000000}},	//   _mruh, _dópa, ەشكە, --, 
   {{0x69cc102c,0x5fcc041c,0xdce40205,0x213c485b}},	//   _axce, _सुचल, _eriğ, lruh_, 
   {{0x39500363,0xad980798,0x64d0033f,0x65780055}},	//   ttys_, rcúr, दकुश, _oruh, 
   {{0x213d3b41,0x7e6401f2,0x3950062c,0x3f5003b2}},	// [1f020] nruh_, mekp, utys_, láu_, 
   {{0x39513b42,0x00000000,0x00000000,0x00000000}},	//   rtys_, --, --, --, 
   {{0x65793b43,0x6d48049f,0x39513b44,0xc81400d6}},	//   _aruh, _ägar, stys_, юєть, 
   {{0x7c2c2b76,0x65793b45,0xad980005,0x39500024}},	//   labr, _bruh, ocúp, ptys_, 
   {{0xaa780174,0x1dc81788,0x213c558c,0x3f500142}},	//   _skýg, रपित, jruh_, háu_, 
   {{0x65780745,0xe0c53b46,0x4a240003,0x6efc0248}},	//   _druh, _رز_, _འབོལ_, _kàbì, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6b8029ac,0x7c2d3b47,0x16841acf,0xc32c00d1}},	//   _ánge, habr, _باسێ, ئەن_, 
   {{0x7c2d3b48,0x65788bbb,0xe3b40daf,0x7cf02d8b}},	//   kabr, _gruh, ибә_, mærf, 
   {{0xdce401a6,0x307800c6,0x7ea406ea,0x7af53b49}},	//   _oriđ, احظة_, _rópa, hmyt, 
   {{0x7c2c8a18,0x6efc01e1,0x3f500042,0x7ea408ce}},	//   dabr, _nàbì, gáu_, _sópa, 
   {{0x4a24025c,0xa7780375,0xa3c40490,0x9cc80032}},	//   _འབེལ_, ארטפ, ोअर_, ҡыра_, 
   {{0x51d40014,0xca4801b9,0x00000000,0x00000000}},	//   _گۯکھ_, یلسه_, --, --, 
   {{0x7c2d3b4a,0x3e5c00b0,0x34b40490,0x7af4005c}},	//   gabr, _rātō_, _अगोद, emyt, 
   {{0x3f500142,0xa054123b,0x00000000,0x00000000}},	//   cáu_, _הסוד_, --, --, 
   {{0x7ea401a8,0xe8dc0051,0x00000000,0x00000000}},	//   _hópn, _voọc_, --, --, 
   {{0x7c2d3b4b,0x26c420ef,0xa3dc1e61,0xcf9001d9}},	// [1f030] babr, énom_, _धुन_, _رژھ_, 
   {{0x6f0803f9,0xdc740588,0x6e2c01ab,0xaa7800d7}},	//   _kufc, _егьы, lacb, _chýr, 
   {{0x6aa0054e,0x7bd8000d,0x00000000,0x00000000}},	//   _înfo, ütut, --, --, 
   {{0xd1c0001f,0x65780122,0x3204014f,0x6e2c0014}},	//   _ትልቁ_, _pruh, _ngoy_, nacb, 
   {{0x5bc402dd,0xdb080241,0x00000000,0x00000000}},	//   _وقۋل, _ìmòy, --, --, 
   {{0x2ecc03f4,0x3204089c,0x833877c6,0x6578014b}},	//   রতিষ, _agoy_, ачит_, _vruh, 
   {{0x3ea00008,0x213c04fb,0xd5b8a262,0x81c40154}},	//   ykkt_, wruh_, исә_, _এরই_, 
   {{0x29013b4c,0x29093b4d,0x213ce59e,0x65793b4e}},	//   _hija_, _kuca_, truh_, _truh, 
   {{0x65780537,0x290007a8,0x7c2d3b4f,0x29080276}},	//   _uruh, _kija_, yabr, _juca_, 
   {{0x29093b50,0x29013b51,0x3f500368,0x61e80219}},	//   _muca_, _jija_, táu_, _vzgl, 
   {{0x29013b52,0x29093b53,0x3e893b54,0x61e8068f}},	//   _mija_, _luca_, айно_, _wzgl, 
   {{0x29013b55,0x6f08058a,0x213d3b56,0x62880306}},	//   _lija_, _dufc, pruh_, ánoč, 
   {{0x7c2d3b57,0x77e451a5,0x29000086,0x29093b58}},	//   tabr, _कर्क_, _oija_, _nuca_, 
   {{0x4a24003d,0xdce41050,0x2bd8084a,0x6f08003a}},	//   _འབུལ_, _priđ, _मुहा, _fufc, 
   {{0x7ed40150,0x29085d7e,0x200416b8,0xa3dcb213}},	//   _وزبا, _auca_, _igni_, _धुम_, 
   {{0x29081675,0x7c2d3b59,0xd1c00201,0x7d090cc2}},	//   _buca_, sabr, _ትልቅ_, _книг_, 
   {{0x290011f9,0x29093b5a,0x7ea403b2,0x7cf0948c}},	// [1f040] _bija_, _cuca_, _hópo, jærg, 
   {{0x29093b5b,0x26dc0134,0x290005a1,0xf2100248}},	//   _duca_, _akuo_, _cija_, _fọwọ, 
   {{0x29013b5c,0xb7153b5d,0x7cf01347,0x78bc01a4}},	//   _dija_, زباش, tærf, ripv, 
   {{0x2f5804ac,0x2900005b,0x7cf001bf,0x00000000}},	//   ידענ, _eija_, færg, --, 
   {{0x2004cb08,0x2908015c,0x29013b5e,0x200009a8}},	//   _ogni_, _guca_, _fija_, žjih_, 
   {{0x26dc016b,0x6b8000d2,0x2004002e,0x64a08ca3}},	//   _ekuo_, _ángc, _ngni_, мача, 
   {{0xe7340d44,0xb6a40212,0xc7940304,0x660c0153}},	//   _мер_, _дивл, _ерты, _šikš, 
   {{0x29013b5f,0x20053b60,0x7cf00b1a,0x2908c5da}},	//   _zija_, _agni_, bærg, _yuca_, 
   {{0x2900016d,0x2908008e,0xe61400d8,0x00000000}},	//   _yija_, _xuca_, _фду_, --, 
   {{0x656c015d,0xa44000f3,0x00000000,0x00000000}},	//   _âcha, _онуд, --, --, 
   {{0x733400dd,0x73c40ee8,0xe4d406c2,0x04f801f7}},	//   _ذرائ, _بيام, _بولت_, _اولڊ_, 
   {{0x32041c06,0x957002d3,0x7eb4005f,0x20053b61}},	//   _ugoy_, _ባይቶን_, kšpu, _egni_, 
   {{0x6e2ca278,0xd370009f,0x00000000,0x00000000}},	//   racb, _آڇڻ_, --, --, 
   {{0x290807a8,0xa0653b62,0x7ea402d2,0xd1cc0023}},	//   _ruca_, _мача_, _hópl, _ኣሉታ_, 
   {{0x290003d1,0x29093b63,0x6eec0268,0x6abc0009}},	//   _rija_, _suca_, rùbb, tiqf, 
   {{0x290808ad,0x2c0c012d,0x00000000,0x00000000}},	//   _puca_, तुजू_, --, --, 
   {{0x29013b64,0x2bd861ef,0x7cf0037e,0xaa780030}},	// [1f050] _pija_, _मुरा, færd, _akýc, 
   {{0xab844dba,0x29090f51,0x26dc01e4,0x7cf0005c}},	//   _думк, _vuca_, _skuo_, værg, 
   {{0x29000978,0x8c0000eb,0x2dd400e5,0x00000000}},	//   _vija_, ্রহন_, _دُکھ_, --, 
   {{0xe8184195,0xea9c0055,0x2900014f,0xf1c807b6}},	//   _प्रा_, _doṣe_, _wija_, ापान, 
   {{0xa56406a0,0x29013b65,0x7cf00b1a,0x65680076}},	//   تدان, _tija_, bærd, uwgh, 
   {{0x9848766f,0x134802d3,0x00000000,0x00000000}},	//   _мяса_, _ዘይጎነ, --, --, 
   {{0x74113b66,0x9474029c,0x00000000,0x00000000}},	//   رويا, بدنا, --, --, 
   {{0x059401ed,0x73c00124,0x00000000,0x00000000}},	//   _ٹارگ, хәуе, --, --, 
   {{0x7cf01512,0x44b40395,0x00000000,0x00000000}},	//   lære, _ебас, --, --, 
   {{0xaf380201,0xdce4006d,0x7fd49abc,0x23745230}},	//   _በተመለ, _ksią, зімі, _واضح, 
   {{0x2bd82274,0x7cf008d7,0x69c003e0,0xf8b0011a}},	//   _मुला, nære, ğney, גשי_, 
   {{0xe50c2314,0x00000000,0x00000000,0x00000000}},	//   ादपि_, --, --, --, 
   {{0xed548985,0x7cf13b67,0x0d980104,0x95700023}},	//   поя_, hære, отры_, _ባይታን_, 
   {{0x71180302,0x7ea402ea,0xdce40034,0x200419f5}},	//   _הוספ, _tópo, _osią, _ugni_, 
   {{0x7cf13b68,0xafe05ff5,0x7ea402d2,0xbea4014b}},	//   værd, _пошл, _hópm, _накк, 
   {{0xe3380020,0x2bd80490,0x7e24010b,0x7cf05522}},	//   _አይደሉ, _मुळा, _эдиж, dære, 
   {{0xf2d004ac,0xf77001d3,0x7cf05522,0xaa7800d7}},	// [1f060] גען_, کاء_, tærd, _skýc, 
   {{0x7e753b69,0x7cf012ed,0xea9c0055,0x00000000}},	//   _hayp, fære, _poṣe_, --, 
   {{0x7e741bb7,0x49003baf,0x7cf0005c,0x768401ec}},	//   _kayp, түрг, gære, зылж, 
   {{0x7e740784,0x6b8000c7,0x27f40214,0x00000000}},	//   _jayp, _ánga, سفند_, --, 
   {{0x7e753b6a,0xc954269c,0x27ec0210,0x00000000}},	//   _mayp, _отры, ęgna_, --, 
   {{0x7cf012ed,0x00000000,0x00000000,0x00000000}},	//   bære, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7e74014f,0x00000000,0x00000000,0x00000000}},	//   _nayp, --, --, --, 
   {{0x61ec0166,0x50f400f5,0x30e40150,0x00000000}},	//   _ğilä, мзит, зінб, --, 
   {{0x7e7400e8,0x63c53b6b,0x00000000,0x00000000}},	//   _aayp, árná, --, --, 
   {{0xe1fc01a8,0xe190009d,0x00000000,0x00000000}},	//   þór_, длөө, --, --, 
   {{0xeea93b6c,0x6efc06c8,0xe29407d5,0xb62c00b5}},	//   сток_, _kūbi, _нах_, _ｒｔ_, 
   {{0x7e7400b5,0xa13000c6,0x21640305,0x9da80395}},	//   _dayp, _كروش, _ници_, пъра_, 
   {{0xf1a803e6,0x00000000,0x00000000,0x00000000}},	//   _پاڵه_, --, --, --, 
   {{0xaa780432,0xabb000d1,0xad240066,0x00000000}},	//   _akýa, хавә, _کربو, --, 
   {{0x7cf0b59a,0x49a40220,0xdee400f3,0x96b00210}},	//   være, мызғ, _поји, ंसफॉ, 
   {{0x4c9401d5,0x00000000,0x00000000,0x00000000}},	// [1f070] _жипс, --, --, --, 
   {{0x7cf008d7,0x7c643500,0x00000000,0x00000000}},	//   tære, _قاپل, --, --, 
   {{0x0674c8cb,0xace80014,0x7e74022e,0x7cf012ed}},	//   дуля, _پرکل_, _yayp, bærb, 
   {{0x7cf000b5,0x00000000,0x00000000,0x00000000}},	//   rære, --, --, --, 
   {{0x7cf012e8,0xdce40210,0x00000000,0x00000000}},	//   sære, _wsią, --, --, 
   {{0x7cf0332e,0x69cc031c,0x00000000,0x00000000}},	//   pære, ġieġ, --, --, 
   {{0xa5d0010e,0x6efc00b8,0xdce40210,0x00000000}},	//   _aỳtm, _tūbh, _usią, --, 
   {{0x656c0042,0x6d4000dc,0x00000000,0x00000000}},	//   _âcho, _ānan, --, --, 
   {{0x2038001f,0x7e74013d,0x3d100456,0x2a940092}},	//   _በአማር, _rayp, _धंधे_, _ዘፈኖች_, 
   {{0x7e753b6d,0x7c2000f3,0x00000000,0x00000000}},	//   _sayp, _đoro, --, --, 
   {{0x7e753b6e,0xf4100375,0x00000000,0x00000000}},	//   _payp, _ספא_, --, --, 
   {{0x7e740784,0x7eb40153,0x00000000,0x00000000}},	//   _qayp, ešpr, --, --, 
   {{0x63a13b6f,0x7ea4032e,0x00000000,0x00000000}},	//   lynn, _hópk, --, --, 
   {{0x7e753b70,0x3b080902,0x6eec00a3,0x00000000}},	//   _wayp, жево_, rùba, --, 
   {{0x7e753b71,0x6fb0007b,0x7cf02b96,0x3a30002e}},	//   _tayp, _لموا, tærb, tayp_, 
   {{0xf210063f,0x00000000,0x00000000,0x00000000}},	//   _họrọ, --, --, --, 
   {{0xb9053b72,0x63a00042,0x00000000,0x00000000}},	// [1f080] дзак, hynn, --, --, 
   {{0x63a13b73,0xfc053b74,0xe8f53b75,0xb8653b76}},	//   kynn, _оппо, длу_, بارو, 
   {{0x7c3c44b6,0x373814a3,0x00000000,0x00000000}},	//   _idpr, ючаю_, --, --, 
   {{0x63a13b77,0x00000000,0x00000000,0x00000000}},	//   dynn, --, --, --, 
   {{0x23c07e29,0x656c0042,0x39e001ee,0x00000000}},	//   _वेबद, _âchl, _рҙағ, --, 
   {{0x63a000a9,0xf21001f2,0x00000000,0x00000000}},	//   fynn, _nọrọ, --, --, 
   {{0x63a0964d,0x31a41944,0x7c3c0334,0x00000000}},	//   gynn, गन्ध, _mdpr, --, 
   {{0x6efc0171,0xe7b00066,0x00000000,0x00000000}},	//   _tūbi, _شمقد, --, --, 
   {{0x7c3d3b78,0xaa78013a,0x00000000,0x00000000}},	//   _odpr, _okýn, --, --, 
   {{0x63a000a9,0x26c400d7,0xb384009d,0x00000000}},	//   bynn, énov_, _олзл, --, 
   {{0xf21001f2,0x63a00368,0x75200115,0x00440124}},	//   _dọrọ, cynn, lpoz, хьыҟ, 
   {{0x7c3ca0b9,0x00000000,0x00000000,0x00000000}},	//   _adpr, --, --, --, 
   {{0xf21027dd,0x6aa00276,0x6ce402bf,0xa2a401d9}},	//   _fọrọ, _înfi, діве, _زُوٕ_, 
   {{0xdce4068f,0x00000000,0x00000000,0x00000000}},	//   _księ, --, --, --, 
   {{0xad9801f1,0x4de000c5,0x00000000,0x00000000}},	//   ncúz, _गँवई_, --, --, 
   {{0x7c3c0526,0xe928025c,0x78ac2937,0x00000000}},	//   _edpr, _སྦུབ_, _albv, --, 
   {{0x19593b79,0x63a0033f,0x00000000,0x00000000}},	// [1f090] маты_, zynn, --, --, 
   {{0x29053b7a,0x752001e4,0x6b8000e4,0x63a0005b}},	//   öna_, dpoz, _ángo, yynn, 
   {{0x7ea400d2,0x00000000,0x00000000,0x00000000}},	//   _bóph, --, --, --, 
   {{0x316407ab,0x09e002f5,0x4438045f,0xdce4107d}},	//   _opoz_, _মৃণা, _śs_, _psić, 
   {{0x7cf0cefd,0x63a00368,0xb4e80073,0x00000000}},	//   læra, wynn, टतंय_, --, 
   {{0x63a006a3,0x48253b7b,0x00000000,0x00000000}},	//   tynn, _سىرق, --, --, 
   {{0x7cf000cc,0x9f493b7c,0xf8b0011a,0x00000000}},	//   næra, ülük_, _גשם_, --, 
   {{0x63a13b7d,0x96f805c1,0x1648004e,0x24980064}},	//   rynn, _жест_, _очуп_, _žymą_, 
   {{0x21293b7e,0x41046145,0x66193b7f,0xf07400dd}},	//   èch_, нзив, _ifuk, ڑیوں_, 
   {{0x7cf003b2,0x00000000,0x00000000,0x00000000}},	//   kæra, --, --, --, 
   {{0x7ea405f7,0x26cc1132,0xada0036b,0x7cf00158}},	//   _hópi, ongo_, қарл, jæra, 
   {{0x26cd3b80,0x7ea40030,0x9f440240,0xaa7803b2}},	//   nngo_, _kópi, _hynë_, _skýn, 
   {{0x62893b81,0x66180451,0x26cd3b82,0xd148036b}},	//   _ingo, _mfuk, ingo_, _قشون_, 
   {{0x26cc24ba,0xf07800fd,0xd1b8007b,0x7cf001a8}},	//   hngo_, _ничә_, _غانا_, færa, 
   {{0xfaf411ed,0x66193b83,0x75200609,0x7ea40241}},	//   ечаю, _ofuk, zpoz, _lópi, 
   {{0x628806a3,0x66185b52,0x987400ef,0x00000000}},	//   _jngo, _nfuk, džās_, --, 
   {{0xe9d53b84,0x6288090c,0xa9646ff7,0xfaa4016c}},	// [1f0a0] ект_, _mngo, нита_, _ҷано, 
   {{0x66193b85,0x2bd838d2,0x26cc2e80,0x7c3c00b5}},	//   _afuk, _मुका, engo_, _udpr, 
   {{0x62893b86,0xfaa40364,0x3878003e,0xe8500133}},	//   _ongo, _зано, rdpr_, انمد, 
   {{0xdce40006,0x62893b87,0x7c942b3c,0x00000000}},	//   _priė, _nngo, _آشکا, --, 
   {{0x7ea40261,0x998000e2,0xddc45106,0x00000000}},	//   _cópi, laiž_, _laiž, --, 
   {{0x26cd3b88,0x661804ba,0x7ea41d1d,0x6ec8012d}},	//   ango_, _efuk, _dópi, rębi, 
   {{0x6618025c,0x31640118,0x6d400055,0x870400cf}},	//   _ffuk, _spoz_, _ānam, ربۅل, 
   {{0x17c40022,0x91c40352,0x00000000,0x00000000}},	//   _заҳҭ, кәлл, --, --, 
   {{0x62880649,0x25e4033f,0x752003b9,0x00000000}},	//   _dngo, _छुपी_, qpoz, --, 
   {{0x62893b89,0xe57400fd,0x92c00eac,0xe1d402d5}},	//   _engo, _язу_, ংকে_, эдыі_, 
   {{0xceb82de8,0x1be000c5,0x6ec8013a,0x00000000}},	//   дәп_, _खुलल_, hřbe, --, 
   {{0x23484876,0x7ae40280,0x2bd87220,0xabb00131}},	//   _رسمی_, _nkkt, _मुगा, қабә, 
   {{0x10746a46,0x21700798,0x00000000,0x00000000}},	//   _аллю, _бујр, --, --, 
   {{0x7cf00ac8,0x26cc00ca,0x6efc0153,0x00000000}},	//   tæra, zngo_, _rūbu, --, 
   {{0x1bd53b8a,0x6288045f,0x2bd81408,0xee3c00bc}},	//   горя, _yngo, _मुखा, lkým_, 
   {{0xe8b81a55,0x9f440306,0xda78084c,0xf3500023}},	//   ोच्च, _uzná_, няу_, _ዘይተሓ, 
   {{0x7cf00217,0xee3c022a,0x00000000,0x00000000}},	// [1f0b0] mærn, nkým_, --, --, 
   {{0x6d4cb761,0x225c0007,0x7ea40162,0x7cf0003b}},	//   muca, zfuk_, _rópi, lærn, 
   {{0x66193b8b,0x26cc02c4,0xee3c0306,0x7ea403b2}},	//   _pfuk, tngo_, hkým_, _sópi, 
   {{0x26cd3b8c,0xbb380a7c,0xee3c0306,0x38b800e4}},	//   ungo_, _קערי, kkým_, týrõ_, 
   {{0x7ac00e76,0x6d4c00b8,0x00000000,0x00000000}},	//   _төра, nuca, --, --, 
   {{0xe730911a,0x628802fa,0x35a0036b,0x1fd8009e}},	//   _مصر_, _sngo, рашг, ডেটস, 
   {{0x0ee0069f,0xdce40003,0x38b800e4,0x9324216b}},	//   नवाड, _spiċ, sýrõ_, هرين, 
   {{0x7ea53b8d,0x6d4c6580,0x66193b8e,0xddc4139f}},	//   _tópi, kuca, _ufuk, _raiž, 
   {{0x6d4d3b8f,0x6aa0054e,0x00000000,0x00000000}},	//   juca, _înfu, --, --, 
   {{0x6d4d3b90,0xaa781d1d,0x00000000,0x00000000}},	//   duca, _skýl, --, --, 
   {{0xaa7801f1,0x628805b1,0xfbc4015b,0x6eec0268}},	//   _akým, _tngo, _শুনত, pùbl, 
   {{0x6d4c0268,0x527469d8,0xddc400c0,0x00000000}},	//   fuca, _бушу, _vaiž, --, 
   {{0xee3c03c6,0xb0600724,0xb19400c7,0x00000000}},	//   ckým_, ğäri, _илцә, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x61e93b91,0x6d4c02d0,0x7cf002d2,0x00000000}},	//   _hygl, auca, bærn, --, 
   {{0x6d4c0028,0xdb8c0023,0x7c2000a2,0x00000000}},	//   buca, _ሓካይም_, _şord, --, 
   {{0x6d4d3b92,0x592400e5,0x00000000,0x00000000}},	// [1f0c0] cuca, اوئے, --, --, 
   {{0x61e808a5,0x7cf02d8b,0xf6d400d1,0x00000000}},	//   _mygl, mæro, ھزاد, --, 
   {{0xee3c0118,0xe1e401f7,0x00000000,0x00000000}},	//   zkým_, _چس_, --, --, 
   {{0xe1e4f7f5,0xfaa41836,0xd910004b,0x4758084c}},	//   _نس_, _рамо, _هیر_, эруя_, 
   {{0x6d4038af,0x00000000,0x00000000,0x00000000}},	//   _ānak, --, --, --, 
   {{0x53340228,0xf3640261,0xdce40306,0x2f1800e2}},	//   гект, втин, _opič, _līga_, 
   {{0x7ea409f3,0x291c7b25,0x6d4c0034,0x64a01d39}},	//   _hópu, _çuar_, zuca, раја, 
   {{0xee3c01a2,0x61e8dac1,0x7ea40162,0x6d4cc5f8}},	//   tkým_, _bygl, _kópu, yuca, 
   {{0x7cf000b5,0x61e800a2,0x00000000,0x00000000}},	//   værn, _cygl, --, --, 
   {{0x6d4d3b93,0x61e85d1d,0xddc4012d,0x00000000}},	//   vuca, _dygl, _wciś, --, 
   {{0x61e93b94,0xee3c0122,0x6d4d3b95,0xaa780162}},	//   _eygl, ským_, wuca, _ským, 
   {{0x79840c8c,0x61e803b2,0x656c00e4,0x2aa4000d}},	//   _orkw, _fygl, _êihá, _tõbi_, 
   {{0x2bd8007d,0xf0740131,0x38b403b2,0x42500137}},	//   _मुजा, _аилә_, _kærd_, _اچىر, 
   {{0x6d4d3b96,0xdd900131,0x00000000,0x00000000}},	//   ruca, زۈپ_, --, --, 
   {{0xc3380316,0x798403ac,0x6d4d3b97,0xb9180241}},	//   žívá, _arkw, suca, _tayọ_, 
   {{0x6d4c0b91,0x7cf03a26,0x7c20013d,0x2984013d}},	//   puca, lærl, _ğore, кызг, 
   {{0x7ea40077,0xda793b98,0x00000000,0x00000000}},	// [1f0d0] _cópu, ъяр_, --, --, 
   {{0x6d4002b5,0x7ea40174,0x7cf001bf,0x00000000}},	//   _ānah, _dópu, nærl, --, 
   {{0x645400f7,0xd7c800f1,0xe7e808ca,0x00000000}},	//   òxim, پونه_, ффак_, --, 
   {{0xd7f93b99,0x7c2000f3,0x0a940064,0x032401d5}},	//   туу_, _đori, _самю, қдин, 
   {{0x49a402dd,0x7cf13b9a,0xc1e00b27,0x00000000}},	//   _сынғ, kærl, _पडेग, --, 
   {{0x61e84f5d,0x7cf0143a,0xe8040bca,0x7ea402d2}},	//   _rygl, jærl, _वृथा_, _hópt, 
   {{0x43680323,0x61e80fac,0xf8b400fd,0x00000000}},	//   хайн_, _sygl, _сөт_, --, 
   {{0x4ee4015b,0x3f893b9b,0x2bd807f7,0xaa7801a8}},	//   নগুল, _čau_, _मुछा, _skýj, 
   {{0x2f180029,0x00e53b9c,0xaa780030,0x38b400b5}},	//   _rīga_, лжин, _akýk, _færd_, 
   {{0x3eb0017a,0x7cf001bf,0x212c002f,0x00000000}},	//   _slyt_, gærl, _vwgh_, --, 
   {{0x42553b9d,0x61e8068f,0xbea53b9e,0x3ea401b9}},	//   _منار, _wygl, ганк, гинг, 
   {{0x7cf00158,0x61e801e3,0xc1b81fbe,0xde040022}},	//   tæro, _tygl, _плех_, ионҩ, 
   {{0x80a42158,0xee340006,0x38b401bf,0x8c2400cc}},	//   গোষ্, ыня_, _hære_, _বয়ন_, 
   {{0x38b404ce,0xd1b83004,0x60c000d2,0x8fc53b9f}},	//   _kære_, _جاما_, _umnm, ازین, 
   {{0x2aa40037,0x7ea402d2,0xfb1475b0,0x62980064}},	//   _lõbu_, _sópu, اورج, ojuo, 
   {{0x9d5404d3,0x7ea40393,0xd99803e6,0x6298005b}},	//   _پۆست, _pópu, پۆست_, njuo, 
   {{0x38b439c2,0x7cf0383d,0xddc40055,0xb92400db}},	// [1f0e0] _lære_, lærm, _vaių, افئي, 
   {{0xe81c02ab,0x26c4067c,0x00000000,0x00000000}},	//   मुला_, ènon_, --, --, 
   {{0x38b45b47,0x2d8c00db,0x7d153ba0,0x7cf02b96}},	//   _nære_, _àger_, _huys, nærm, 
   {{0xb6353ba1,0x3634005e,0x7d147dcd,0x38b40162}},	//   اعات, اراس, _kuys, _særd_, 
   {{0x629801fa,0x7d14062c,0x7ea401a8,0x00000000}},	//   djuo, _juys, _hóps, --, 
   {{0x38b432b8,0x7d140113,0x6aa00276,0x7cf0037e}},	//   _bære_, _muys, _înfr, kærm, 
   {{0x38b404ce,0x7cf02f48,0x19c400fb,0x92940114}},	//   _værd_, værl, _сәңг, иакц, 
   {{0xd250004b,0xa520013d,0x00000000,0x00000000}},	//   څنګ_, шмәд, --, --, 
   {{0xd0113133,0x7cf00b1a,0x00000000,0x00000000}},	//   يلة_, tærl, --, --, 
   {{0x9cec0489,0x6298005b,0x55e40454,0x212800e4}},	//   _རེཊས, ajuo, _боғб, ãcha_, 
   {{0x09d0228a,0x39505a29,0x38b401bf,0xc0e00092}},	//   _सख्य, huys_, _gære_, _ሐኪም_, 
   {{0x7d152e16,0xc13400b2,0x00000000,0x00000000}},	//   _buys, _چونڊ, --, --, 
   {{0x9d181d56,0xd048016b,0x7d1400a2,0x7ea406ea}},	//   лоят_, fodɔ, _cuys, _rópt, 
   {{0x7d1456f8,0x7cf05f03,0xa1540b3b,0x00000000}},	//   _duys, bærm, _сашу_, --, 
   {{0xaa642708,0x2cb00208,0x28a53ba2,0x00000000}},	//   лтак, _vlxd_, қшаг, --, 
   {{0x7ea41427,0xf3f40154,0x00000000,0x00000000}},	//   _dóps, _চলার_, --, --, 
   {{0x9f4801ed,0x6d4c0306,0xfc400014,0x3950045a}},	// [1f0f0] ülök_, ýkač, _ژھِپ, guys_, 
   {{0x6d5c0357,0xea600b38,0x65c40150,0x00000000}},	//   _iqqa, _گۇرپ, _ﯨﺮﯨﻠ, --, 
   {{0x2f1800e8,0x39500076,0x99800010,0x06140108}},	//   _jëg_, auys_, rbiš_, адею, 
   {{0x17f806d5,0x39500076,0x2f1800e2,0x7ea402d2}},	//   اركة_, buys_, _līgo_, _hópr, 
   {{0x38b412ed,0x7d140208,0xd54850ea,0x00000000}},	//   _sære_, _xuys, هجوم_, --, 
   {{0x38b408cb,0x03a400a8,0x04880166,0x00000000}},	//   _pære_, иило, ъәби_, --, 
   {{0x5564044e,0x291801b9,0x3e8400e5,0x00000000}},	//   _መግለጺ, lqqa_, lítő_, --, 
   {{0x38b53ba3,0x6d5d3ba4,0x953c001f,0x7cf001bf}},	//   _være_, _oqqa, _አግኝተ, værm, 
   {{0xd6d831de,0x69c8547d,0x3e8401d3,0x569400fb}},	//   _стр_, _सेमी, nítő_, _уатт, 
   {{0x2f181bce,0x65793ba5,0x7d147899,0x38b40fac}},	//   _bëg_, _isuh, _ruys, _tære_, 
   {{0x6d5c0eda,0x7d153ba6,0x6eec0086,0xb4f8008f}},	//   _aqqa, _suys, nùbw, _ספעי, 
   {{0x417407d2,0x2f181bce,0x7d140309,0x32640014}},	//   _ناتس, _dëg_, _puys, _ننمہ, 
   {{0x91840517,0x7d153ba7,0x80c40118,0x00000000}},	//   _هجوم, _quys, ाफदे, --, 
   {{0x7cf0019b,0x8108025c,0x00000000,0x00000000}},	//   mærk, _གངྒཱ_, --, --, 
   {{0x6d5c32ff,0x46b4044b,0x6eec0428,0x7cf00ac8}},	//   _eqqa, ंसाह, jùbw, lærk, 
   {{0x3a24eab5,0xba24e407,0x6eec0428,0x7d140784}},	//   рмаг, рдак, dùbw, _tuys, 
   {{0xada0a3c3,0x657800ca,0x213c0ac5,0x3e8401ed}},	// [1f100] _маъл, _nsuh, nsuh_, gítő_, 
   {{0xa9653ba8,0x2f180694,0x00000000,0x00000000}},	//   рифа_, _yëg_, --, --, 
   {{0x29180d04,0x7c2c02d0,0x00000000,0x00000000}},	//   aqqa_, mbbr, --, --, 
   {{0x9f440316,0x7c2c002f,0xea9c00dc,0x00000000}},	//   _nyní_, lbbr, _raṇe_, --, 
   {{0x9784034c,0x7c2c062c,0x64c000ec,0xf5040153}},	//   _گیاه, obbr, ڪيول, аздо, 
   {{0xd31401ec,0x00000000,0x00000000,0x00000000}},	//   _сiлт, --, --, --, 
   {{0x386800ca,0xe73402f6,0xaa78032e,0x27e40112}},	//   _ibbr_, _вес_, _skýi, ünnt_, 
   {{0x66e00713,0xa3c40034,0xb28464c2,0x36680064}},	//   _доса, _उधर_, рыкк, _шабо_, 
   {{0xf5093ba9,0x2f180de2,0xf5d002f2,0x00000000}},	//   _анал_, _sëg_, _بڵاگ, --, 
   {{0xe1ec0f1b,0x6d5c01d5,0x00000000,0x00000000}},	//   بسى_, _rqqa, --, --, 
   {{0x7244035c,0x7cf003cd,0x3e8401d3,0x291801d5}},	//   _نپال, mærh, zítő_, zqqa_, 
   {{0x7cf021e3,0x7ea402d2,0x00000000,0x00000000}},	//   bærk, _sópr, --, --, 
   {{0x9ed8447e,0x7c20bd89,0x00000000,0x00000000}},	//   рмят_, _şora, --, --, 
   {{0x6ce40046,0x3f840455,0x7cf003cd,0x81a400f1}},	//   ріме, bvlu_, nærh, _دحمل, 
   {{0x6d404607,0x2ac40114,0x60f8011a,0x00000000}},	//   _ānau, аљав, _שהוק, --, 
   {{0xddc40311,0x3e8400e5,0x2918022e,0x9e34030d}},	//   _uciş, títő_, tqqa_, _деъч, 
   {{0xae0013b4,0x9f053baa,0xb7840184,0x6d5c01a9}},	// [1f110] रेशन_, _بويو, ҙәре_, _uqqa, 
   {{0x6eec0086,0xdca40640,0x291801d5,0x3e8401d3}},	//   tùbw, _мањи, rqqa_, rítő_, 
   {{0x3e8401ed,0x46153bab,0x00000000,0x00000000}},	//   sítő_, موار, --, --, 
   {{0x6d4c01e7,0x213c011f,0x3e8401d3,0x95900092}},	//   orca, ysuh_, pítő_, _ሁላችን_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7cf004ce,0x2ecc0c58,0x6d4c0f85,0x00000000}},	//   værk, ৰতিষ, irca, --, 
   {{0x25e407f7,0x4428008f,0xf48400f2,0x00000000}},	//   _छुरी_, ĝa_, صاوی, --, 
   {{0x7cf0a248,0x6b802b76,0x6d4c04a7,0x6578037e}},	//   tærk, _ángu, krca, _tsuh, 
   {{0x65780117,0x7cf001bf,0x00000000,0x00000000}},	//   _usuh, bærh, --, --, 
   {{0x1ac40882,0x213c03a2,0x38b40ad9,0x40940116}},	//   _षष्ठ, rsuh_, _kæra_, срит, 
   {{0x1488004b,0x213c102c,0x6d4c0857,0x00000000}},	//   _خپلي_, ssuh_, erca, --, 
   {{0x7ea400db,0xbd8805d9,0x38b4032e,0x9f440166}},	//   _cópp, هنجن_, _mæra_, _uyní_, 
   {{0x38b4394a,0x7cf12c8e,0xe8044244,0x0a1c015b}},	//   _læra_, læri, वेता_, তরাং_, 
   {{0x4540069c,0xb12400f1,0x99800419,0x6d400055}},	//   _ኣይነበ, _اړين_, nbiť_, _ānat, 
   {{0x6d4d3bac,0x7cf010b8,0x9f480209,0xbea43d2a}},	//   arca, næri, ýläk_, _гайк, 
   {{0x6b6002d5,0x6d4c01ab,0x8e54010a,0xcf2406c2}},	//   якса, brca, _мĕсл, _بروي, 
   {{0x7cf0437d,0x00000000,0x00000000,0x00000000}},	// [1f120] hæri, --, --, --, 
   {{0x38b405ac,0x7cf098b1,0xfe4000e5,0x00000000}},	//   _bæra_, kæri, _بکھی, --, 
   {{0xbb853bad,0xe7e805f9,0x7cf008fb,0x00000000}},	//   _الجي, _जुदा_, jæri, --, 
   {{0xe7341b10,0xef10008f,0x00000000,0x00000000}},	//   сец_, פּע_, --, --, 
   {{0x6bd43ee6,0x7cf00b1a,0x952401b9,0x6d48007c}},	//   _نویس_, tærh, تکزم, _ågat, 
   {{0x38b40008,0x7cf001a8,0x00000000,0x00000000}},	//   _færa_, færi, --, --, 
   {{0xf2c427c8,0x7cf000b5,0xf62402e8,0x00000000}},	//   йсин, gæri, _гдбо, --, 
   {{0x57b40073,0xe45400c7,0x00000000,0x00000000}},	//   ंनीह, ажә_, --, --, 
   {{0xe0cc00aa,0x905400d4,0x00000000,0x00000000}},	//   کزي_, овпц, --, --, 
   {{0x7cf08ecc,0x6d4c01a6,0xe9dc0248,0xe454030d}},	//   bæri, vrca, _odún_, _гжф_, 
   {{0xd01000c6,0xa08420b0,0xe9dc00ae,0x656c0142}},	//   بلد_, ссыз_, _ndún_, _âchr, 
   {{0x6d4c05a1,0x37b800cc,0x00000000,0x00000000}},	//   trca, _আশাৰ, --, --, 
   {{0x6d4c127b,0xb03001af,0x6d4000b8,0x91c401ee}},	//   urca, _емлә, _ānas, _фәйл, 
   {{0x9d181fce,0x9cc80150,0x00000000,0x00000000}},	//   сорт_, быса_, --, --, 
   {{0xaa780022,0xa0a00f14,0x7ea4002e,0x00000000}},	//   _okýt, _хајд, _tópp, --, 
   {{0xeaf81617,0xd1c0001f,0x6d4c107d,0x998000d7}},	//   ارست_, _ስልት_, prca, zbiť_, 
   {{0x6ce400d3,0x38b408ce,0x2024032e,0xee3c010b}},	// [1f130] _гіне, _særa_, _ávið_, maý_, 
   {{0xee3c00ee,0x38b4003b,0x1d0800f3,0x00000000}},	//   laý_, _pæra_, _лењи_, --, 
   {{0x564402d3,0xb0480092,0x00000000,0x00000000}},	//   _ከምዝበ, _በአንፃ, --, --, 
   {{0xaa280014,0x38b40217,0xd6180b73,0x7cf00eef}},	//   _حسدٕ_, _væra_, متها_, væri, 
   {{0xceb80064,0x00000000,0x00000000,0x00000000}},	//   lpęs_, --, --, --, 
   {{0x9b440014,0x7cf00194,0xf9900375,0xee3c00a2}},	//   _بنێو, tæri, _קרם_, haý_, 
   {{0x5c5c008f,0x2bcc08a3,0xca6401a9,0x0708004b}},	//   אדוק, _हेमा, _muhо, _نيسي_, 
   {{0x7f40074d,0x6e380ad9,0xc2c4009f,0xee3c0432}},	//   vslq, ðubl, تيبي, jaý_, 
   {{0x26cc2d3f,0xee3c0209,0x7cf00b1a,0xc1040338}},	//   migo_, daý_, mærv, يوبي, 
   {{0x26cd3bae,0x7cf02b96,0x7c200139,0x00000000}},	//   ligo_, lærv, _ğoro, --, 
   {{0xd49831a8,0x3f693baf,0x7c900092,0x00000000}},	//   _урт_, шино_, _ማሻሻል_, --, 
   {{0x26cd3bb0,0xdce4005f,0x6d407bc9,0x7cf00623}},	//   nigo_, _oriģ, _ānar, nærv, 
   {{0xe29c008c,0x7a4400e5,0x98a00064,0x00000000}},	//   öðu_, _jétő, lpią_, --, 
   {{0x26cd3bb1,0x442400b5,0xc104007b,0x00000000}},	//   higo_, _jfl_, _بوتي, --, 
   {{0xbea4564f,0x44253bb2,0x26cd3bb3,0x7cf0005c}},	//   _макк, _mfl_, kigo_, kærv, 
   {{0x3f480943,0x26cc151c,0xdce400ef,0xeab4578a}},	//   _ṱuwe_, jigo_, _briģ, ойс_, 
   {{0x26cd3bb4,0x442401a8,0xfe701079,0xaa780419}},	// [1f140] digo_, _ofl_, _فدک_, _akýs, 
   {{0x4424b189,0xcd2800b2,0xaa793bb5,0xe7e80210}},	//   _nfl_, _اسين_, _skýt, _जुहा_, 
   {{0xfaa4921a,0xf7702961,0x26cc009f,0x7aa409a0}},	//   _дано, باء_, figo_, _динз, 
   {{0x26cd3bb6,0x4424045a,0x7958010a,0x00000000}},	//   gigo_, _afl_, _кимĕ, --, 
   {{0x44253bb7,0xe6148595,0xe5a00835,0xbb180150}},	//   _bfl_, әдә_, мици, _ﺷﯩﻼ_, 
   {{0x44253bb8,0x7af53bb9,0x73480212,0xe8f40108}},	//   _cfl_, llyt, ачив_, _мля_, 
   {{0x26cd3bba,0xb4c8068f,0x7cf001bf,0x7af40064}},	//   bigo_, _लगी_, bærv, olyt, 
   {{0x6b80006a,0x44253bbb,0x71453bbc,0x7af53bbd}},	//   _ânge, _efl_, охож, nlyt, 
   {{0xe6c005d9,0xd1c00023,0x395000ad,0xe9dc0332}},	//   _تڪلي, _ስልቲ_, nrys_, _ndúl_, 
   {{0x7af4a77f,0x395000ad,0xe5740798,0x00000000}},	//   hlyt, irys_, _фзф_, --, 
   {{0xb4d42413,0xee3c00ee,0x7cf003b2,0x7af400c0}},	//   ाची_, taý_, næru, klyt, 
   {{0xe294d808,0x39500076,0x00000000,0x00000000}},	//   _мах_, krys_, --, --, 
   {{0xaa7800e4,0xdb080ca8,0x22e40244,0x00000000}},	//   _okýr, _àlùk, _بتلێ, --, 
   {{0x26cd3bbe,0x26c4067c,0x7cf00d12,0x7af40419}},	//   zigo_, énoz_, kæru, elyt, 
   {{0x26cc6466,0x00000000,0x00000000,0x00000000}},	//   yigo_, --, --, --, 
   {{0x7af405ac,0x9e740c75,0xceb80064,0x00000000}},	//   glyt, _قۇپت, rpęs_, --, 
   {{0x26cd3bbf,0x38b400b5,0xad240b24,0xaa7802d2}},	// [1f150] vigo_, _værn_, _بربو, _skýs, 
   {{0x26cd0d0e,0x67880b01,0x7cf008a5,0x00000000}},	//   wigo_, иёев_, færu, --, 
   {{0x26cd3bc0,0xddc42625,0xab60005e,0x395000ad}},	//   tigo_, _ibiš, _تۇزى, arys_, 
   {{0x442405d5,0x9f4801ed,0xf21001e1,0x7af53bc1}},	//   _sfl_, ülék_, _gọgọ, clyt, 
   {{0x26cd3bc2,0x6b80025a,0x395000ad,0x00000000}},	//   rigo_, _ângb, crys_, --, 
   {{0x26cd3bc3,0x25ac0368,0x961800d1,0x7cf01d1d}},	//   sigo_, rygl_, مغۇر_, bæru, 
   {{0x5c380302,0x26cd3bc4,0x290005be,0x44240112}},	//   חרון_, pigo_, _ihja_, _vfl_, 
   {{0xc244524d,0x7cf00fac,0x44240112,0x63440023}},	//   чник, lært, _wfl_, _ከይገበ, 
   {{0x00c86f63,0xddc41fe6,0x1b840055,0x00000000}},	//   йлик_, _obiš, _kṣāṃ_, --, 
   {{0x64549ace,0xdce4003d,0x44240334,0x7cf00fac}},	//   óxid, _oriġ, _ufl_, nært, 
   {{0x7af4117e,0x82140127,0x00000000,0x00000000}},	//   ylyt, _فواص, --, --, 
   {{0x39500731,0x00000000,0x00000000,0x00000000}},	//   yrys_, --, --, --, 
   {{0x290001a4,0x7cf000b5,0x68f40175,0x7af521fa}},	//   _ohja_, kært, klxd, vlyt, 
   {{0xff24023a,0x98a000f3,0x2484003a,0x7cf0143a}},	//   _емко, mpić_, ndnm_, jært, 
   {{0x3950037e,0x7af402d0,0xe7e8012d,0xf42800a2}},	//   wrys_, tlyt, _जुला_, lmäñ_, 
   {{0xaa78008c,0x39500368,0x2900000d,0x1f2001d9}},	//   _skýr, trys_, _ahja_, _ٹِکہ, 
   {{0x7af53bc5,0xc5f000cc,0x39500076,0x39440129}},	// [1f160] rlyt, জেতা_, urys_, éos_, 
   {{0xb4c8534e,0x39501368,0x2900265a,0xdce4025c}},	//   _लगे_, rrys_, _chja_, _friġ, 
   {{0x7c3c0029,0xe80499b6,0x7af53bc6,0x9f4400ee}},	//   _iepr, वेला_, plyt, _dynç_, 
   {{0x7c3c0649,0x395138b4,0x29000115,0x1b8400dc}},	//   _hepr, prys_, _ehja_, _eṣāṃ_, 
   {{0x7c3d3bc7,0xab9001d5,0x7cf021e3,0x00000000}},	//   _kepr, _قلیغ, bært, --, 
   {{0xb4d42413,0xf744c89b,0x7c3d3bc8,0x7cf00b1a}},	//   ाचे_, _него, _jepr, mærs, 
   {{0x7c3cb673,0x7cf00158,0x6c78010f,0x00000000}},	//   _mepr, lærs, מאספ, --, 
   {{0x52b8033f,0xe8040073,0x00000000,0x00000000}},	//   ेफेस, वेळा_, --, --, 
   {{0x7cf02b96,0x00000000,0x00000000,0x00000000}},	//   nærs, --, --, --, 
   {{0x764000fb,0xe7d000db,0x00000000,0x00000000}},	//   laoy, _تۅۅگ, --, --, 
   {{0xd58403e6,0xf2100241,0xf1a80133,0xdfd4009d}},	//   _رێژه_, _sọdọ, شاکه_, зъя_, 
   {{0x940c013f,0x764001f7,0x536c010c,0x670c0073}},	//   _dodɔ_, naoy, _ሰርዓት_, िषयक_, 
   {{0x7c3d3bc9,0xf1f8282b,0x71f80c75,0xd0ac013f}},	//   _bepr, _اعات_, _اراس_, _wɔɑk, 
   {{0x76400d04,0x212800c6,0x7c3c0427,0xdce40135}},	//   haoy, íche_, _cepr, _priġ, 
   {{0x76400333,0xc0f40020,0x7cf01cf3,0xbb200356}},	//   kaoy, ለኝም_, vært, _ţîrl, 
   {{0x290005b1,0x7cf00008,0x9a8419bb,0x5b140b80}},	//   _shja_, færs, нуул, емст, 
   {{0x7cf012ed,0x68f40175,0x3878002f,0xe9d016ac}},	// [1f170] tært, tlxd, fepr_, رغر_, 
   {{0x7c3d259f,0xddc401fa,0x6e3c0455,0xdbdc01e1}},	//   _gepr, _ubiš, _heqb, bààr, 
   {{0x6e3c036e,0x7cf001bf,0x8a1800d8,0x00000000}},	//   _keqb, rært, _монс_, --, 
   {{0x6e3c014f,0x7c3c00f1,0x7cf028b3,0x2128054e}},	//   _jeqb, _zepr, bærs, ţchi_, 
   {{0x752001f0,0x7c3c51d2,0x3618035c,0x6e3c047e}},	//   gqoz, _yepr, زرنگ_, _meqb, 
   {{0x0394036b,0xfb1801d3,0x7cf001bf,0xd7c83451}},	//   дрия, _دریں_, lærr, _کوفه_, 
   {{0x5f0000cd,0xd06003b9,0x7c200139,0x00000000}},	//   रतम्_, _ötən, _şork, --, 
   {{0x41b402bf,0x9bbc00df,0x00000000,0x00000000}},	//   дсот, מצופ, --, --, 
   {{0xaca00521,0x66180223,0x21280a40,0x00000000}},	//   _anọg, _iguk, ëch_, --, 
   {{0x73300075,0xa42407d5,0x2f180171,0x00000000}},	//   رىۋا, _хьал, _līgu_, --, 
   {{0x64406937,0x6e3c0455,0x98a028b5,0xd49801c0}},	//   mani, _beqb, spić_, _эрт_, 
   {{0x7c3d3bca,0x00000000,0x00000000,0x00000000}},	//   _sepr, --, --, --, 
   {{0x7c3d3bcb,0x940c016b,0x64400b23,0x225c003e}},	//   _pepr, _wodɔ_, oani, mguk_, 
   {{0x64413bcc,0xd1b80dd8,0x7cf02ab7,0x00000000}},	//   nani, _عانا_, værs, --, 
   {{0x7c3c069c,0x66180337,0x6440e690,0x00000000}},	//   _vepr, _oguk, iani, --, 
   {{0x7c3d3bcd,0x7cf011c0,0xeff40023,0x88c400cd}},	//   _wepr, tærs, ለፍዎ_, _āśay, 
   {{0xf2d005e1,0xa9653bce,0x7c3d3bcf,0xbc180111}},	// [1f180] דען_, мита_, _tepr, _міні_, 
   {{0x661844c8,0x7c3d3bd0,0x76400083,0xac75161b}},	//   _aguk, _uepr, waoy, _قاپش, 
   {{0x64413bd1,0x38780158,0x225c525e,0xb6a4084c}},	//   dani, repr_, kguk_, мижл, 
   {{0x6b802776,0xb4d401bc,0x64413bd2,0xfa34007b}},	//   _ânga, ाच्_, eani, _تردد, 
   {{0x64413bd3,0xeff40023,0xdce40210,0x00000000}},	//   fani, ወልደ_, _spię, --, 
   {{0x65913bd4,0x38b4005c,0x00000000,0x00000000}},	//   ташу, _mærk_, --, --, 
   {{0xc32c0d1f,0x38b401bf,0x00000000,0x00000000}},	//   مەل_, _lærk_, --, --, 
   {{0x225d3bd5,0x64413bd6,0xf21001f2,0xa2e003b7}},	//   gguk_, aani, _rọbọ, којд, 
   {{0x64553bd7,0xb464010b,0xca64022e,0xe64001ec}},	//   óxic, _окал, _muhа, _шетп, 
   {{0x25e402e5,0xeff40257,0x98a0012d,0xe5741608}},	//   _छुटी_, ወልዱ_, tpię_, _юзу_, 
   {{0x64a0566d,0x93541077,0xf268084c,0xdef80023}},	//   _шафа, _سراچ, _мижл_, ለጽን_, 
   {{0x229000c6,0x6e3c014f,0xf1a803e6,0x98a00210}},	//   _للمس, _qeqb, _واشه_, rpię_, 
   {{0x2f1800e2,0xb1b4210e,0x00000000,0x00000000}},	//   _rīgu_, _تحاش, --, --, 
   {{0x48b800cc,0x00000000,0x00000000,0x00000000}},	//   _আদ্ৰ, --, --, --, 
   {{0x7cf00fac,0xae000037,0xdfcc00db,0x00000000}},	//   tærr, रेजन_, _ръ_, --, 
   {{0x5f041b6b,0x59d005f9,0xeaf8078a,0x81c00154}},	//   _изја, _सेहर, ्षेत_, ঃপর_, 
   {{0x2bcc00ab,0x00000000,0x00000000,0x00000000}},	// [1f190] _हेरा, --, --, --, 
   {{0x6440fd96,0xb6a047b3,0x225c0007,0x8ec000cc}},	//   xani, ғишл, zguk_, _উদিগ, 
   {{0x64403351,0x6ea005d7,0x97240fb4,0x7cf001bf}},	//   vani, गापु, نفلو, pærr, 
   {{0x64413bd8,0x7cf00fac,0x00000000,0x00000000}},	//   wani, lærp, --, --, 
   {{0x64413bd9,0xeabc01e1,0x7c200356,0x00000000}},	//   tani, _ilù_, _şori, --, 
   {{0xf59068cf,0x7cf003cd,0x0b640092,0x644002d0}},	//   الوج, nærp, _ድልድይ_, uani, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x64413bda,0x6618f320,0x225c0194,0x56940022}},	//   sani, _uguk, uguk_, _иаст, 
   {{0xe2940efb,0x225c011f,0xfbd437d0,0x7cf001bf}},	//   зақ_, rguk_, _डेनम, kærp, 
   {{0x80b80034,0xe2a800dd,0x7cf00158,0xc104007b}},	//   इसें, _ڈاؤن_, jærp, عودي, 
   {{0xdef802d3,0x3f9013d5,0x53440408,0x00000000}},	//   ወጽእ_, ízu_, _ахча, --, 
   {{0xee341ed2,0xeabc0248,0xa28001d3,0x00000000}},	//   нню_, _nlù_, _شیخو, --, 
   {{0xd0a93bdb,0x916401d5,0xd2440166,0xc5f00154}},	//   سطین_, _لهنه, _рэхи, জেরা_, 
   {{0x315425f9,0x38b4037e,0x71d4010f,0x98a00327}},	//   _ניצן_, _værk_, _אונד_, rqiċ_, 
   {{0xeb948e6d,0xeabd3bdc,0x3b080798,0x2d9c0112}},	//   нир_, _blù_, зево_, äuer_, 
   {{0xfd4806bb,0xeabc01ab,0x8f7400d4,0x00000000}},	//   _език_, _clù_, _руші, --, 
   {{0x6cb005f5,0xeabc00a3,0x7cf01347,0xb8540640}},	// [1f1a0] _өөрт, _dlù_, bærp, еђењ, 
   {{0xe8f53bdd,0x3b8533c2,0x38b41d1d,0x00000000}},	//   елу_, _злог, _kæri_, --, 
   {{0xeabc00a3,0xf0b4008f,0x00000000,0x00000000}},	//   _flù_, עלער_, --, --, 
   {{0xc76404a9,0x75440153,0x00000000,0x00000000}},	//   ئالى, ендз, --, --, 
   {{0x38b40321,0x00000000,0x00000000,0x00000000}},	//   _læri_, --, --, --, 
   {{0x64a0b6cb,0x79853bde,0x00000000,0x00000000}},	//   лача, _iskw, --, --, 
   {{0xc5f003f4,0x00000000,0x00000000,0x00000000}},	//   জেলা_, --, --, --, 
   {{0x78ac0810,0xc614015b,0x1cc0031c,0x00000000}},	//   _hobv, াড়া_, _གཞའ_, --, 
   {{0x63000f1b,0x78ac0810,0x80c803d4,0x99800153}},	//   دويل, _kobv, িচন্, mbių_, 
   {{0x78ad3bdf,0xfbb0102f,0x99800006,0x38b408a5}},	//   _jobv, ीनाम, lbių_, _bæri_, 
   {{0x78ac0099,0x2d8c0428,0x320002fb,0xe2800075}},	//   _mobv, _ũge_, ťky_, _әлчи, 
   {{0x828800d6,0x798400b5,0x228001a9,0xc32c0244}},	//   _осіб_, _oskw, _бушг, _بڕو_, 
   {{0x91c40131,0x7cf00b1a,0x59d01fd2,0x00000000}},	//   _шәкл, tærp, _सेलर, --, 
   {{0x38b40008,0x78ac014f,0xd36c0354,0x00000000}},	//   _færi_, _nobv, _хiуъ, --, 
   {{0x8d9c001f,0x7984127b,0x00000000,0x00000000}},	//   ገራቸው_, _askw, --, --, 
   {{0xddcc0166,0x00000000,0x00000000,0x00000000}},	//   _çişt, --, --, --, 
   {{0xd5a40014,0x699000c7,0x8d0801af,0x00000000}},	// [1f1b0] _اہ_, ылаӡ, _офоҡ_, --, 
   {{0x1cc0031c,0x4bb4004e,0x4c9402e8,0x6f0c02d0}},	//   _གཞར_, _айос, _риос, lmcc, 
   {{0xd8753be0,0x79853be1,0x5ea402f2,0x00000000}},	//   طالب, _eskw, _شمیل, --, 
   {{0xc5d400d6,0x46153be2,0x78ac0010,0x6f0c035a}},	//   кіль, نوار, _eobv, nmcc, 
   {{0x1a682be7,0x84240131,0x940c03b9,0x00000000}},	//   _سیلی_, نىشن, _ində_, --, 
   {{0x78ac0099,0x00000000,0x00000000,0x00000000}},	//   _gobv, --, --, --, 
   {{0x7984045a,0x03a4010b,0x65680003,0x00000000}},	//   _zskw, тийо, stgh, --, 
   {{0xcfb804c5,0x78ac090c,0x93250b35,0x37c002dd}},	//   ুপান, _zobv, درون, _тәуб, 
   {{0x78ac0099,0x36240014,0x65680327,0xd350010a}},	//   _yobv, _شولہ, qtgh, _цiоц, 
   {{0x40940abe,0x6aad3be3,0xe9dc00a2,0x00000000}},	//   трит, _locf, _geúe_, --, 
   {{0xefc401c0,0x00000000,0x00000000,0x00000000}},	//   влэл_, --, --, --, 
   {{0x38b400fc,0x1f9400f7,0x2f187acb,0xcce800d9}},	//   _væri_, _үйдө_, _pūga_, _וכ_, 
   {{0x00840fab,0x0d980aec,0x62893be4,0xee3400a7}},	//   _алло, нтры_, _iago, ъня_, 
   {{0x62893be5,0xf1c402f0,0x38b402d2,0x7c5800f2}},	//   _hago, šáci_, _tæri_, بلسر_, 
   {{0x62893be6,0x99800006,0x78ac7c97,0xfaf40212}},	//   _kago, ybių_, _robv, вчаю, 
   {{0x7db53be7,0x62893be8,0x9b380323,0x2f180421}},	//   _асоц, _jago, мүүс_, _tūga_, 
   {{0x2d853be9,0x56940952,0x6920ee72,0x20000327}},	// [1f1c0] _айып_, ғалт, имта, żjid_, 
   {{0x62893bea,0x26c402d3,0x6cb00032,0x78ac014f}},	//   _lago, ënon_, _көст, _qobv, 
   {{0x78ac006f,0xbb340150,0x00000000,0x00000000}},	//   _vobv, _ﻗﯩﻢ_, --, --, 
   {{0x78ac006f,0xe73434da,0x798403ac,0x26c800e5}},	//   _wobv, тец_, _tskw, وطنی_, 
   {{0x78ac004c,0x99800024,0x00000000,0x00000000}},	//   _tobv, rbių_, --, --, 
   {{0x62880280,0x855400f2,0xe450004e,0xd42800cf}},	//   _aago, ایلر_, акшы, رتتۅ_, 
   {{0x62893beb,0x636401c6,0x6f0c035a,0xf7442901}},	//   _bago, врыг_, ymcc, _шево, 
   {{0x62893bec,0xe7e805f9,0xa4e8033f,0xd250007b}},	//   _cago, _जुटा_, टवॉच_, حنة_, 
   {{0x62893bed,0x7e600022,0x50f4329b,0x00000000}},	//   _dago, _ñopy, лзит, --, 
   {{0x62880083,0x00000000,0x00000000,0x00000000}},	//   _eago, --, --, --, 
   {{0x62893bee,0x0f1400cf,0x00000000,0x00000000}},	//   _fago, лмою, --, --, 
   {{0xe80405d7,0xa0d40014,0xdb1c002f,0x00000000}},	//   वेटा_, _یِنا_, nzrä, --, 
   {{0xd13105b8,0x11540801,0x59c4012d,0xe1340024}},	//   _امت_, _склю, लैमर, _азіі_, 
   {{0x62893bef,0x9d181ee3,0x38b40321,0x2094004e}},	//   _zago, коят_, _kæru_, _акшы_, 
   {{0xaa6412c1,0xce940408,0x9b2402ac,0x9d18009d}},	//   ктак, _байъ, ифтл, торт_, 
   {{0x62880548,0x7c205397,0x6014011a,0x00000000}},	//   _xago, _şort, _בחוף_, --, 
   {{0x38b406ea,0x5a440006,0x00000000,0x00000000}},	// [1f1d0] _læru_, рэса, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x47d40472,0x6d4000cd,0xefe80092,0x00000000}},	//   ديار, _ānay, _መያዣ_, --, 
   {{0x1cc0031c,0x070808f0,0xc014010f,0x00000000}},	//   _གཞོ_, ريشي_, אַנק_, --, 
   {{0x62893bf0,0x07901e4a,0xe80401ad,0xd6180127}},	//   _rago, _گۇاڭ, वेजा_, نتها_, 
   {{0x62893bf1,0x58fc031c,0xe73025ef,0x38b402d2}},	//   _sago, _ཐེགས_, _نصر_, _bæru_, 
   {{0x58d49fb8,0xd7f80a31,0x437401c0,0x82f401f4}},	//   _торт, _аут_, уулт, лчиц, 
   {{0xd7c93bf2,0xa28000f2,0xd04803b9,0x00000000}},	//   _شوقه_, شیتو, midə, --, 
   {{0xc0dc0023,0xd04803e3,0xeff80023,0x00000000}},	//   _ዓማር_, lidə, ፊካዊ_, --, 
   {{0x62893bf3,0xb0e4b0d5,0x63d000aa,0x657800e4}},	//   _wago, лдыз_, _پښتا, _ipuh, 
   {{0x62893bf4,0xd04803be,0x38b402d2,0xa300008e}},	//   _tago, nidə, _gæru_, _күке, 
   {{0xf21027dd,0x6288003a,0x69080139,0x00000000}},	//   _kọlọ, _uago, lüed, --, 
   {{0xeb9405c2,0xd04800ac,0x38b42fca,0xd1c80133}},	//   қит_, hidə, _kært_, _لبوم_, 
   {{0xbfb53bf5,0x65780526,0xb14001c6,0xd04803e3}},	//   _محبت, _mpuh, _уншл, kidə, 
   {{0xa3e000dc,0x5e3400e5,0x00000000,0x00000000}},	//   नपि_, _پڑجا, --, --, 
   {{0x38b4003b,0x20053bf6,0x6fa400cc,0xd04803e3}},	//   _lært_, _izni_, খনশৈ, didə, 
   {{0xe9a13bf7,0x00000000,0x00000000,0x00000000}},	// [1f1e0] батп, --, --, --, 
   {{0x3eb13bf8,0xd5a4ca19,0x38b44675,0x32d801e1}},	//   _hoyt_, یلای, _nært_, _kàyè_, 
   {{0x65781c06,0xbb44023a,0x7c2c02d0,0x00000000}},	//   _apuh, _щенк, mcbr, --, 
   {{0xaa7800a2,0xd9781de6,0xbbb003ce,0xe1e428f4}},	//   _okýy, _иргә_, ीनीक, _هس_, 
   {{0x7d1d3bf9,0x7af4011f,0x38b40fac,0x60c002d0}},	//   _kips, moyt, _bært_, _olnm, 
   {{0x533402d5,0x69080005,0x7af53bfa,0x7d1d3bfb}},	//   аект, güed, loyt, _jips, 
   {{0x27f403c6,0x7d1c00f2,0xefdc02d3,0x53340220}},	//   čené_, _mips, _ሓጋዚ_, шейт, 
   {{0x7d1d3bfc,0x38b40008,0x7af40548,0x64a00032}},	//   _lips, _væru_, noyt, _һауа, 
   {{0x38b408a7,0xaf5041fd,0x200405b1,0xf044010b}},	//   _fært_, әнмә, _azni_, лэно, 
   {{0x64a13bfd,0x7af4011f,0x7d1c01f4,0xd1d401f3}},	//   _лауа, hoyt, _nips, ርነቱ_, 
   {{0x7af53bfe,0xdd940184,0x00000000,0x00000000}},	//   koyt, ҙары, --, --, 
   {{0x1cc00003,0xdd9400c7,0x00000000,0x00000000}},	//   _གཞུ_, әары, --, --, 
   {{0x7af40429,0xf0753bff,0x61540050,0x00000000}},	//   doyt, _билә_, _مٔنز_, --, 
   {{0x32d80241,0xab840dce,0xdd900131,0x00000000}},	//   _fàyè_, лубк, سۈپ_, --, 
   {{0x7d1d3c00,0x2bb8007b,0xdb5401c4,0x00000000}},	//   _dips, راسة_, йвры, --, 
   {{0x7af40548,0xdb2400e7,0xf2100241,0x9b240120}},	//   goyt, árás, _lọmọ, сфрл, 
   {{0x2008068f,0x19593c01,0x3cf80010,0x00000000}},	// [1f1f0] ęcie_, латы_, _fkpv_, --, 
   {{0x6f1c0477,0x6d4d3c02,0x787803cd,0x88a00150}},	//   _hiqc, msca, _røvæ, _ﺍﻷﺒﻌ_, 
   {{0x64541a36,0x6d4d3c03,0xf2100521,0x7af4011f}},	//   óxim, lsca, _sọlọ, boyt, 
   {{0x7d1d3c04,0xa6453c05,0x38b4022c,0xfd640055}},	//   _zips, اخان, _sært_, _ajuṣ, 
   {{0x6d4d3c06,0x7d1c014b,0x49a401e0,0x00000000}},	//   nsca, _yips, _тынғ, --, 
   {{0x6d4c003a,0xf40c03d4,0x04780092,0x00000000}},	//   isca, িখনৰ_, _የሬዲዮ_, --, 
   {{0x38b410f5,0x2cb0022e,0xf8b40075,0x6d4c01e7}},	//   _vært_, _moxd_, _төт_, hsca, 
   {{0xe77400c7,0x68f4022e,0xf21001e1,0x00000000}},	//   _иаҳә_, loxd, _tọlọ, --, 
   {{0x67253c07,0x3eb00204,0x93bc0311,0x657801a6}},	//   _hujj, _royt_, _sfăt, _upuh, 
   {{0x6f1c0369,0x6d4c127b,0x67242252,0xa6a40154}},	//   _aiqc, dsca, _kujj, _খতিয়, 
   {{0x6d4d3c08,0x7d1cb6a5,0x672402a8,0xfd4801f2}},	//   esca, _rips, _jujj, balị, 
   {{0x7d1c2b92,0xef1400a8,0x67253c09,0x7af40175}},	//   _sips, имэ_, _mujj, xoyt, 
   {{0x67240337,0x6d4c01f5,0x3eb00162,0x7d1c0108}},	//   _lujj, gsca, _voyt_, _pips, 
   {{0x6f1c0369,0x7b2c00e4,0x26c4036e,0x28b40118}},	//   _eiqc, _aĝua, ënoj_, _आकषि, 
   {{0x6d4d3c0a,0x3b100334,0x03e80154,0xbb453c0b}},	//   asca, tmyq_, য়েরী_, ребк, 
   {{0x6d4d3c0c,0x7d1c0582,0x00000000,0x00000000}},	//   bsca, _wips, --, --, 
   {{0x7d1d3c0d,0x6d4c0857,0x7af4022c,0x88c005ac}},	// [1f200] _tips, csca, royt, োচনক, 
   {{0x67240a49,0xe8c53c0e,0xff38001f,0x6cd0007b}},	//   _bujj, агул_, _የተሰኘ, _وقيا, 
   {{0x38b403d4,0x6c580375,0x6f1c0477,0x3f50025c}},	//   _særs_, _בדיח, _yiqc, nġu_, 
   {{0x24940214,0x7af508b4,0x00000000,0x00000000}},	//   ینند_, qoyt, --, --, 
   {{0x7bcd3c0f,0x1fa800fe,0x00000000,0x00000000}},	//   lzbu, খনিস, --, --, 
   {{0x38b4003b,0x00000000,0x00000000,0x00000000}},	//   _værs_, --, --, --, 
   {{0xf2c53c10,0x7bcc34eb,0x67240337,0x19c40ce8}},	//   исин, nzbu, _gujj, _тәңг, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6f1d3c11,0x3f500003,0x00000000,0x00000000}},	//   _riqc, eġu_, --, --, 
   {{0x6f1c014f,0x6d4c0332,0x67240055,0x00000000}},	//   _siqc, vsca, _yujj, --, 
   {{0x6f1c0113,0x672401b9,0xf2100241,0x6d4c045a}},	//   _piqc, _xujj, _kọkọ, wsca, 
   {{0x6d4d3c12,0xf1a803e6,0xa3e01c5d,0x00000000}},	//   tsca, _لاته_, नपर_, --, 
   {{0xb9100a28,0x7bcc045a,0x6d4c0857,0x2cb0022e}},	//   śaṃ_, ezbu, usca, оndа_, 
   {{0x6d4c0c8c,0xf21001e1,0x39bc00b8,0xa154008e}},	//   rsca, _lọkọ, _māsā_, _ташу_, 
   {{0x6d4d3c13,0x2a6801f7,0xcb3400a7,0x6f1c047e}},	//   ssca, _pccb_, себъ, _tiqc, 
   {{0x6d4d3c14,0xad440354,0x00000000,0x00000000}},	//   psca, _кхок, --, --, 
   {{0xd7bc013f,0x67253c15,0x39bc002b,0xe9440107}},	// [1f210] _mbrε, _sujj, _nāsā_, рхбо, 
   {{0x7bcc0cf4,0x00000000,0x00000000,0x00000000}},	//   bzbu, --, --, --, 
   {{0x68f40369,0xab840351,0x2a680051,0xd918009d}},	//   roxd, _тупк, _tccb_, рьт_, 
   {{0x2a680998,0x5a3807d5,0x00000000,0x00000000}},	//   _uccb_, _вырă, --, --, 
   {{0x67240de2,0x522c0092,0x00000000,0x00000000}},	//   _wujj, _ተሳፋሪ, --, --, 
   {{0x67240a49,0x39bc0055,0x00000000,0x00000000}},	//   _tujj, _dāsā_, --, --, 
   {{0x14740592,0x1cb00327,0x93bc054e,0xdd2c0153}},	//   تانج, _ྒོལ_, _sfăr, _mėšl, 
   {{0x86e40014,0xd3b80220,0xf77000d9,0x00000000}},	//   _آرو, руші_, _מקל_, --, 
   {{0xddc40055,0x44b4004e,0x3f500135,0x606000d1}},	//   _ddiś, _лбас, wġu_, قۇشل, 
   {{0x1f2802d3,0x2375050d,0x00000000,0x00000000}},	//   _ተቃወም, _ناصح, --, --, 
   {{0x44253c16,0x25d819e5,0xdce400d0,0x533400d4}},	//   _igl_, _खेती_, _priľ, _дехт, 
   {{0x7bcc0122,0xf4180c58,0x1cc0025c,0x3f500003}},	//   vzbu, নুহৰ_, _གཞང_, rġu_, 
   {{0x44253c17,0xb8d80327,0xf2d0011a,0x00000000}},	//   _kgl_, _མྭ_, _צעד_, --, 
   {{0x7bcd3c18,0x44253c19,0xa2d02cfd,0x93240132}},	//   tzbu, _jgl_, बोर्, _ارەن, 
   {{0x8b953c1a,0x2d980309,0xfaa53c1b,0x7dfc0064}},	//   ортч, _erqe_, баво, _sąsą, 
   {{0x3a253c1c,0xfe44084c,0x7bcd3c1d,0xfbc4013e}},	//   смаг, _унио, rzbu, абҳо, 
   {{0xee34052f,0x442405d5,0xe9a03f3a,0x00000000}},	// [1f220] _уны_, _ogl_, патп, --, 
   {{0xa9640ff1,0x095400db,0x00000000,0x00000000}},	//   сифа_, زىمڭ, --, --, 
   {{0xdb1c02d3,0xf770027a,0xe9640116,0x00000000}},	//   nyrë, ثاء_, _һаял_, --, 
   {{0x44241570,0x00000000,0x00000000,0x00000000}},	//   _agl_, --, --, --, 
   {{0x6738098d,0x44253c1e,0xe9640116,0x00000000}},	//   _čuje, _bgl_, _лаял_, --, 
   {{0x6fc809d9,0x44253c1f,0xa8b005f5,0x39bc00b8}},	//   ानमं, _cgl_, _нөхц, _vāsā_, 
   {{0xdb1c0023,0xe44c0fb4,0x44253c20,0xf2100241}},	//   jyrë, رضو_, _dgl_, _tọkọ, 
   {{0x44249c6e,0xb18801c6,0x3950062c,0xdb1c036e}},	//   _egl_, гсож_, osys_, dyrë, 
   {{0x39513c21,0x11d800c6,0x75d400ec,0xdce400de}},	//   nsys_, شودة_, _ايذا, _briļ, 
   {{0xc0e8001f,0x39503deb,0x63b40200,0x00000000}},	//   _መቻል_, isys_, ëanë, --, 
   {{0xd3e410e8,0x09e800cc,0x20000135,0x00000000}},	//   _بقای, _খৰাং_, żjin_, --, 
   {{0xeea93c22,0x41d87dad,0x00000000,0x00000000}},	//   уток_, _बेवस, --, --, 
   {{0x2008006d,0x26c40023,0x2b50007c,0xef90085b}},	//   ęcia_, ënoi_, _svxc_, زیکد, 
   {{0xa110ee63,0x6ce40220,0xefd40092,0x00000000}},	//   _فونت, сіме, ርሰው_, --, 
   {{0x3a340521,0x2ac40063,0xf41800cc,0x00000000}},	//   _ọgụ_, бљав, _ন্তৰ_, --, 
   {{0x298400f7,0x00000000,0x00000000,0x00000000}},	//   йызг, --, --, --, 
   {{0xc95800d1,0x00000000,0x00000000,0x00000000}},	// [1f230] شلاش_, --, --, --, 
   {{0x0f3c0092,0x35e000cc,0x00000000,0x00000000}},	//   _የተሰየ, _বৰ্হ, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x395003cd,0x00000000,0x00000000,0x00000000}},	//   bsys_, --, --, --, 
   {{0xd7580075,0x3950015d,0x00000000,0x00000000}},	//   للەت_, csys_, --, --, 
   {{0x03a427a8,0x044400d8,0x00000000,0x00000000}},	//   жико, цекн, --, --, 
   {{0xca3c17de,0x44253c23,0x1cb8031c,0xf484030f}},	//   ﻟﺴﺎ_, _vgl_, _ཚྭས_, زاوی, 
   {{0x6b8006ed,0x44243a7c,0x415400d8,0x00000000}},	//   _ângu, _wgl_, отоѓ, --, 
   {{0x00c8b38e,0x0594034c,0x44249877,0x7b2c00df}},	//   илик_, _بازگ, _tgl_, _aĝul, 
   {{0x44301248,0xdb1c02d3,0x44253c24,0xf6c4031c}},	//   _üz_, tyrë, _ugl_, _གཞོང, 
   {{0x2484d609,0xe9dc04d4,0x94a93c25,0x0f04012d}},	//   menm_, _seúl_, _утта_, रतूस_, 
   {{0x9d980023,0xd1b90220,0x66f81fd2,0x00000000}},	//   _ጎነጻዊ_, _گاما_, ौतिक_, --, 
   {{0x0d8001e0,0x7c380165,0x00000000,0x00000000}},	//   еһын, ñtro, --, --, 
   {{0x2f080428,0xd1b80244,0xccf400c7,0x00000000}},	//   rùga_, _داما_, зқь_, --, 
   {{0xdb1c0240,0x39500142,0xcee800f2,0x7ad800d8}},	//   qyrë, wsys_, _گرون_, аќат_, 
   {{0x1ee819bc,0x394402d5,0x39500042,0x00000000}},	//   _دوبی_, жнаг, tsys_, --, 
   {{0xdce4031c,0xcee804fb,0x39500153,0x4ab80395}},	// [1f240] _esiġ, _درون_, usys_, щуря_, 
   {{0x395003cb,0xe9d46dac,0x6248010e,0x00000000}},	//   rsys_, цку_, _ỳolb, --, 
   {{0x24ac009e,0x39500072,0x00000000,0x00000000}},	//   কসাহ, ssys_, --, --, 
   {{0x3950702b,0x41c80864,0x58fc0327,0x66e0bbb8}},	//   psys_, िनास, _ཐེམས_, моха, 
   {{0xe69012dd,0x41d802ab,0x690403b2,0x00000000}},	//   بلند, _बेलस, ørdí, --, 
   {{0x690800fd,0x00000000,0x00000000,0x00000000}},	//   lüen, --, --, --, 
   {{0x92580228,0x09bc0327,0x00000000,0x00000000}},	//   байт_, _ཀཎྜ_, --, --, 
   {{0xe3ac0451,0x2d880210,0x00000000,0x00000000}},	//   ئرو_, ywce_, --, --, 
   {{0x76413c26,0x30e80395,0xdb1c00e5,0x00000000}},	//   mboy, ифон_, gyré, --, 
   {{0x23645160,0x2ec000dc,0x20080210,0x00000000}},	//   bunj_, शस्त, ęcin_, --, 
   {{0x23640007,0xe1ec104c,0x00000000,0x00000000}},	//   cunj_, فسی_, --, --, 
   {{0x76413c27,0x437421f3,0xa24400f7,0x00000000}},	//   nboy, _хуфт, _ۇرۇۇ, --, 
   {{0x73c0052f,0xdce4031c,0x91c42cc8,0x656c002f}},	//   _хәҙе, _ssiġ, _хәйл, _ächt, 
   {{0x6fb400c6,0x60940014,0x20d0007b,0x7640022e}},	//   _ومشا, _وننس_, _يتوج, hboy, 
   {{0xa0300137,0x44380213,0x9b5822c3,0x00000000}},	//   _تۉپت, _əs_, жист_, --, 
   {{0x69081daa,0xd1e00023,0x25d800c5,0x00000000}},	//   güen, _ዓራት_, _खइली_, --, 
   {{0x2484083a,0x76400162,0x7bc803b9,0x00000000}},	// [1f250] yenm_, dboy, _üfun, --, 
   {{0xf6c4025c,0x5d840133,0x00000000,0x00000000}},	//   _གཞུང, _کلیل, --, --, 
   {{0xf72c0023,0x00000000,0x00000000,0x00000000}},	//   _ብኣወን, --, --, --, 
   {{0xeabc0e89,0x2484009a,0xaabc146c,0x6680036b}},	//   _diùc_, wenm_, _एकिक, بیرل, 
   {{0x1a6801ed,0x2484007f,0x06bc00fe,0x00000000}},	//   _ذیلی_, tenm_, _আগদি, --, 
   {{0x6fc89ad9,0x03793c28,0x00000000,0x00000000}},	//   ानां, محبت_, --, --, 
   {{0xb3e4003d,0x2484083a,0xaabc06ff,0x764004ba}},	//   _སྨྱུ, renm_, _एकाक, bboy, 
   {{0x88ac0183,0x48f492c1,0xd7c8029e,0x00000000}},	//   _গতিক, ्तको_, _بوفه_, --, 
   {{0xa3d80bb2,0xdc192877,0x2128002d,0x85040ed8}},	//   _ढेर_, _दण्ड_, êch_, _فورن, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x64413c29,0x00000000,0x00000000,0x00000000}},	//   mbni, --, --, --, 
   {{0x644001a9,0xdb1c035b,0x41d80210,0x00000000}},	//   lbni, pyré, _बेअस, --, 
   {{0x260c0073,0x05bc1c15,0x00000000,0x00000000}},	//   तेची_, ्निब, --, --, 
   {{0x213c4694,0xddc400ee,0x644001ab,0x21280118}},	//   mpuh_, _ediş, nbni, íchu_, 
   {{0x2d8c0086,0x690800fd,0x26cc009a,0x213c0477}},	//   _âgen_, tüen, khgo_, lpuh_, 
   {{0xaf74008f,0x00000000,0x00000000,0x00000000}},	//   _זעקס_, --, --, --, 
   {{0xa9200030,0xaa44084c,0x213c0455,0x25d80456}},	// [1f260] _šľah, япта_, npuh_, _खेली_, 
   {{0x64400200,0xe1fc0210,0x00000000,0x00000000}},	//   jbni, żów_, --, --, 
   {{0xda280137,0x00000000,0x00000000,0x00000000}},	//   _ويدۇ_, --, --, --, 
   {{0x69093c2a,0x6844069d,0x00000000,0x00000000}},	//   qüen, _ኪሎሜት, --, --, 
   {{0x764001d5,0xa9a00725,0xa530177b,0x213c016d}},	//   rboy, _зияд, еніч, jpuh_, 
   {{0x92c8015b,0x93100241,0x00000000,0x00000000}},	//   _ঈদে_, _ọ̀pá, --, --, 
   {{0x1cc06d7e,0xb628004d,0xb86400ec,0x00000000}},	//   _གཞན_, _chợđ, _واڳو, --, 
   {{0x994c0038,0x26cc010a,0x7640102c,0x6440058a}},	//   _môže_, chgo_, qboy, abni, 
   {{0x9574044e,0x644001e6,0x213c0477,0x35c80114}},	//   _የልቦን_, bbni, gpuh_, _угао_, 
   {{0xa56005d9,0x2f1800de,0x0f3c0092,0x00000000}},	//   _سگهن, _lūgt_, _የተለየ, --, 
   {{0xb2253c2b,0xb9dc0092,0xd31401ec,0x00000000}},	//   _емел, _ጣጣ_, _тiпт, --, 
   {{0x80a0466d,0xdce400ef,0x00000000,0x00000000}},	//   _कोठे, _kriķ, --, --, 
   {{0x91d44284,0x2de400f1,0x00000000,0x00000000}},	//   _बेचै, سوسۍ_, --, --, 
   {{0x71a40588,0x2ce80b32,0x31140209,0x69080077}},	//   _маҵз, сьмо_, _эфес, güel, 
   {{0xdde400fd,0x25ac0477,0x2c0400e5,0x00000000}},	//   _җәяү, zxgl_, سٹری_, --, 
   {{0x8f5400ec,0x00000000,0x00000000,0x00000000}},	//   _فنڪش, --, --, --, 
   {{0x644002f0,0x8cf401af,0x00000000,0x00000000}},	// [1f270] ybni, _озиц, --, --, 
   {{0x5a3405f5,0x00000000,0x00000000,0x00000000}},	//   _үнэт, --, --, --, 
   {{0xaac4143e,0x64400427,0x00000000,0x00000000}},	//   _فتحن, vbni, --, --, 
   {{0x96b8004e,0x00000000,0x00000000,0x00000000}},	//   зушу_, --, --, --, 
   {{0x8c183ee6,0xc51802d5,0x6440022e,0x6e380162}},	//   _ديگر_, оўкі_, tbni, ðuby, 
   {{0x8338eba2,0x64400e78,0x34f00131,0xd61834f7}},	//   очит_, ubni, вҗут, ستنا_, 
   {{0x64413c2c,0x29000240,0x00000000,0x00000000}},	//   rbni, _ikja_, --, --, 
   {{0x56951185,0xa1f00075,0x61400248,0x64413c2d}},	//   _паст, ىۋات, _nílò, sbni, 
   {{0x3324002e,0xd25404fb,0xe3ac01d3,0x7d0000ae}},	//   _diox_, ریوش_, ئرڈ_, _íosg, 
   {{0x213c0098,0x6568016d,0x93c40051,0xb1640023}},	//   rpuh_, mugh, _khẳ, _ተነጽሎ_, 
   {{0x3e882564,0x65693c2e,0xdbcc09f3,0x14745e75}},	//   ойно_, lugh, jóða, _سالج, 
   {{0xee353c2f,0x00000000,0x00000000,0x00000000}},	//   мню_, --, --, --, 
   {{0x26dc4d11,0x780828d4,0xbea801d5,0x65693c30}},	//   _mmuo_, _वर्क_, مهگن_, nugh, 
   {{0x6568062c,0x06b001ef,0x00000000,0x00000000}},	//   iugh, _šílí_, --, --, 
   {{0x6568143e,0xa3bc3599,0xb114d98f,0x212d3c31}},	//   hugh, ुनि_, _تقوا_, _hugh_, 
   {{0x21240016,0x656802ce,0x29000432,0x80c4012c}},	//   _hinh_, kugh, _akja_, िसके, 
   {{0x212401dc,0x656819f5,0x20040023,0xaadc0fe6}},	// [1f280] _kinh_, jugh, _hyni_, _नगरक, 
   {{0xd911370e,0xa3bc1a47,0x212c047e,0x690800cf}},	//   ایس_, ुना_, _mugh_, qüel, 
   {{0x212407ae,0x212d0189,0x6568062c,0x93c4004d}},	//   _minh_, _lugh_, eugh, _chẳ, 
   {{0x212407ae,0x65693c32,0xd9b434b1,0x212c003e}},	//   _linh_, fugh, _كەزد, _ough_, 
   {{0x46800efb,0x212c016d,0xca740c75,0xdb1c03b2}},	//   ықта, _nugh_, _سەلت_, nyrí, 
   {{0x21240016,0x64a063e6,0x7b2c0022,0x26dc01e4}},	//   _ninh_, кача, _aĝui, _emuo_, 
   {{0x212c062c,0x925800f7,0x65680076,0x20053c33}},	//   _augh_, пайт_, augh, _nyni_, 
   {{0x212401ab,0x6b8001e6,0xd2500228,0x65693c34}},	//   _ainh_, _änge, اچا_, bugh, 
   {{0x20053c35,0x21253c36,0x66000e76,0x212c062c}},	//   _ayni_, _binh_, _апта, _cugh_, 
   {{0xd1d41b49,0x212c014f,0x1cc8031c,0x3dc400a2}},	//   ይነቱ_, _dugh_, ཉིས_, _ýowy_, 
   {{0x21253c37,0x20040142,0x845419c5,0x212c0112}},	//   _dinh_, _cyni_, _سىنچ, _eugh_, 
   {{0x798401a4,0x41d8033f,0xea9d3c38,0x2004012d}},	//   _opkw, _बेकस, _maṣe_, _dyni_, 
   {{0x200403be,0xefe8001f,0x00000000,0x00000000}},	//   _eyni_, _መያዝ_, --, --, 
   {{0xc0e41e38,0xe0cc0228,0xec140352,0xea9c0055}},	//   ምበር_, _ۅزۉ_, дегә_, _vaṭe_, 
   {{0xc058496f,0x9be4109a,0x65680327,0x00000000}},	//   _хіі_, вітк, zugh, --, 
   {{0x69a800ec,0xdbcc1427,0xea9c002b,0x893801f0}},	//   ياءُ_, róða, _taṭe_, зпас_, 
   {{0x2bfc4103,0xaca000b4,0xb50c00cd,0x9b240798}},	// [1f290] _शुरू_, _abụg, िताय_, тфрл, 
   {{0x2734038f,0x212407ae,0xdce40115,0x00000000}},	//   _aħna_, _xinh_, _psiĥ, --, 
   {{0x656802e3,0xab6002dd,0x00000000,0x00000000}},	//   wugh, _جۇزى, --, --, 
   {{0xb11002e3,0x65693c39,0x00000000,0x00000000}},	//   bụgb, tugh, --, --, 
   {{0x6b80007c,0x00000000,0x00000000,0x00000000}},	//   _ängb, --, --, --, 
   {{0x65693c3a,0x212c014f,0x93c40208,0x6d580022}},	//   rugh, _rugh_, _thẳ, ġuah, 
   {{0x212401fb,0x212c014f,0x577801d5,0x1cb80677}},	//   _rinh_, _sugh_, _обрў_, ולגל_, 
   {{0x212401dc,0x212d3c3b,0x65693c3c,0x00000000}},	//   _sinh_, _pugh_, pugh, --, 
   {{0x212c016d,0x20053c3d,0x6568014f,0x733000d1}},	//   _qugh_, _syni_, qugh, پىۋا, 
   {{0x200406a3,0x6380022e,0x00000000,0x00000000}},	//   _pyni_, _аҳка, --, --, 
   {{0x21240016,0xf8b002e4,0x14ac078a,0x00000000}},	//   _vinh_, אשי_, चारण, --, 
   {{0x212c0842,0x81d4023a,0x37d8010f,0x00000000}},	//   _tugh_, _поех, פֿיע, --, 
   {{0x212407ae,0x212c0066,0xed54022e,0x1f240014}},	//   _tinh_, _uugh_, ноя_, _یِتہ, 
   {{0x629801c4,0x00000000,0x00000000,0x00000000}},	//   lduo, --, --, --, 
   {{0x200401b9,0x4f9400fb,0x00000000,0x00000000}},	//   _uyni_, _арыу, --, --, 
   {{0x62993c3e,0x6d400069,0x451409bd,0xdfcc00ec}},	//   nduo, _ōnae, াদিক_, _ميڙ_, 
   {{0x6a804033,0x62980208,0x00000000,0x00000000}},	// [1f2a0] ылта, iduo, --, --, 
   {{0xf7f40131,0xdce401e4,0x62980051,0x00000000}},	//   ىساد, _priĵ, hduo, --, 
   {{0xe728081f,0xb80800c6,0x62980115,0x00000000}},	//   _སྤྱན_, أيام_, kduo, --, 
   {{0x38653c3f,0x6b800124,0xd32000b8,0x80a000bc}},	//   şor_, _ãnga, _kṛśo_, _कोसे, 
   {{0xec10004b,0x65c400b8,0xdb1c0022,0x00000000}},	//   _لوید, _nīhā, pyrâ, --, 
   {{0x62980064,0x00000000,0x00000000,0x00000000}},	//   eduo, --, --, --, 
   {{0xd3706073,0x2ca40005,0xb9fc0092,0x92940024}},	//   شۇش_, _ónde_, _ሁል_, вайц, 
   {{0x62993c40,0xd2500597,0xf5e80276,0xe7280327}},	//   gduo, جنة_, _ембл_, _སྤྲན_, 
   {{0xd250004b,0x672001f5,0x80a001ad,0x521402e8}},	//   هنګ_, ïnje, _कोहे, ъдит, 
   {{0x7e74010e,0xb6c800e5,0x00000000,0x00000000}},	//   _acyp, _باڑے_, --, --, 
   {{0x71f8e7c8,0xa30801d3,0xe19001c6,0x00000000}},	//   _کراس_, _کرلے_, влөө, --, 
   {{0x229001e2,0x62980051,0x6abc01f9,0x247000e5}},	//   _ملمس, cduo, _एकेर, rőmű_, 
   {{0xc0bc1c5c,0x9be402dd,0x61413c41,0xfe6c0ccb}},	//   ﺭﺳﻪﺗ, ңіск, _беча, زگي_, 
   {{0x7e740117,0xd32000b8,0x66d00139,0x00000000}},	//   _ecyp, _dṛśo_, _içke, --, 
   {{0xdfcc02e8,0xdd9800c7,0x00000000,0x00000000}},	//   _съ_, _ҧшь_, --, --, 
   {{0x3f8002b1,0xdcf00115,0x7c6401d5,0x00000000}},	//   _ähua_, _ĉeĥl, _یاپل, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [1f2b0] --, --, --, --, 
   {{0x62980006,0x5dd00150,0xdb1c00e4,0xef1c0b97}},	//   zduo, _ﮔﻮﻣﻴ, tyrã, lmü_, 
   {{0x62980208,0x47d400ae,0x00000000,0x00000000}},	//   yduo, خيار, --, --, 
   {{0xf41400eb,0x00000000,0x00000000,0x00000000}},	//   াশার_, --, --, --, 
   {{0xeabc0489,0xa3d033ee,0x66d000a2,0x7d0000ae}},	//   _ioù_, सैन_, _nçke, _íosc, 
   {{0xeabc0489,0x30cc0150,0x850400be,0xdb1c035b}},	//   _hoù_, _ﯗﺭﻻﻧ, خوتن, pyrã, 
   {{0xd04c013f,0xef1c3535,0x66d00205,0x62980051}},	//   _ɔkɔb, kmü_, _açke, tduo, 
   {{0x2f080086,0xb5c80248,0x6abc0037,0x273403e0}},	//   bùgi_, _kẹ́t, _एकोर, _içn_, 
   {{0x62980953,0xe29417de,0x7170038b,0x857400d8}},	//   rduo, дақ_, لهيا, _шлах, 
   {{0x7e740381,0xb5c80ca8,0x00000000,0x00000000}},	//   _scyp, _mẹ́t, --, --, 
   {{0x6448353f,0x69080005,0x66d0008e,0xb5c80241}},	//   čnič, güei, _eçke, _lẹ́t, 
   {{0xfe7000c6,0x65c400b0,0x80242418,0x00000000}},	//   جدد_, _tīhā, _یرغم, --, 
   {{0xa070010a,0xdb0803b2,0x00000000,0x00000000}},	//   _йӳнч, ólív, --, --, 
   {{0xccf40046,0x71d4008d,0x00a00244,0x00000000}},	//   лқы_, _בונד_, _ئیدێ, --, 
   {{0xef1c06be,0x7f740395,0x00000000,0x00000000}},	//   bmü_, _рулц, --, --, 
   {{0xddc40171,0x00000000,0x00000000,0x00000000}},	//   _reiņ, --, --, --, 
   {{0x3a253c42,0xeabc001e,0x8d8401b9,0x00000000}},	// [1f2c0] тмаг, _giùm_, _یشین, --, 
   {{0xa9653c43,0xe8f40354,0x6b98012d,0xada0010a}},	//   тифа_, влу_, ługa, _таьл, 
   {{0xbb44df30,0x00000000,0x00000000,0x00000000}},	//   _шенк, --, --, --, 
   {{0xc7946943,0x2bf40375,0xe660059f,0x6b8001e3}},	//   ыруы, _ימין_, атшо, _änga, 
   {{0x65780113,0x3a040b28,0x1db400dc,0x66f0023e}},	//   _cquh, _شکری_, ुहित, _अदरक_, 
   {{0x80a0503c,0x00000000,0x00000000,0x00000000}},	//   _कोले, --, --, --, 
   {{0x2898008f,0x4384074d,0xe73400d4,0x20380092}},	//   _קילא, лăрт, _аес_, _አሠራር, 
   {{0xf1a53c44,0xb28400f7,0x39400165,0x00000000}},	//   врон, тыкк, _ktks_, --, 
   {{0x7c3c03ac,0x61400798,0x00000000,0x00000000}},	//   _ofpr, аења, --, --, 
   {{0x30a43678,0xd01001b9,0xe1ec02ef,0x23300124}},	//   трив, یلک_, تسى_, ыхәр, 
   {{0xc1b801c0,0x250801d5,0x7d0c0175,0x712401b9}},	//   длөх_, _آرقی_, dlbs, _یرتل, 
   {{0x7c3c037e,0xf204004e,0x229000db,0x00000000}},	//   _afpr, _ияло, _ۅلۅس, --, 
   {{0xef1c0c3c,0x1b08009e,0x00000000,0x00000000}},	//   rmü_, লগাই_, --, --, 
   {{0xdb1d20c2,0x6ce40220,0x75e4022e,0x02400014}},	//   vyrá, тіме, _gаze, _پێیَ, 
   {{0xfc4400d0,0x48c402dd,0x011400c0,0x00000000}},	//   _číta_, қшағ, _сьцю, --, 
   {{0x5f700133,0x63b4007c,0x00000000,0x00000000}},	//   _ئاور, äxni, --, --, 
   {{0x5a353c45,0x195809a5,0xda0815f2,0x00000000}},	// [1f2d0] рнут, каты_, نيفه_, --, 
   {{0x290406d9,0x00000000,0x00000000,0x00000000}},	//   ôna_, --, --, --, 
   {{0x7d0001e7,0x00000000,0x00000000,0x00000000}},	//   _íosa, --, --, --, 
   {{0xdea40b45,0x46146dd7,0x257804cc,0xdb1c00c7}},	//   _bunƙ, هوار, têl_, pyrá, 
   {{0xdea40198,0x6f0caf88,0x6bd400e5,0xdb080241}},	//   _cunƙ, ilcc, _ستھر, _àlák, 
   {{0xb978025f,0xdea403f9,0x1afc0011,0xf990011a}},	//   _אנשי, _dunƙ, ্ষণে_, _הרך_, 
   {{0x67900214,0x1cbc010f,0x00000000,0x00000000}},	//   _خیاط, ומגע, --, --, 
   {{0x6d5c07d6,0x25780042,0x00000000,0x00000000}},	//   _ovqa, pêl_, --, --, 
   {{0x0134027d,0x00000000,0x00000000,0x00000000}},	//   دعبد, --, --, --, 
   {{0x4094721f,0xb3080327,0x00000000,0x00000000}},	//   урит, གཞུང_, --, --, 
   {{0xefc405f5,0xff2401c6,0x00000000,0x00000000}},	//   глэл_, лмоо, --, --, 
   {{0x6f0c02fa,0x6568084c,0x7ed53c46,0xdea40b45}},	//   glcc, orgh, ازدا, _yunƙ, 
   {{0xceb40831,0xeff402d3,0xdd2c0153,0x00000000}},	//   рҙы_, ፈልየ_, _vėžl, --, 
   {{0x656836f4,0x00000000,0x00000000,0x00000000}},	//   irgh, --, --, --, 
   {{0xbea53c47,0x6b6000d6,0x394001bf,0x940c06be}},	//   _байк, йкра, _stks_, _badə_, 
   {{0x5a441669,0xe8e53c48,0xfeb80633,0x00000000}},	//   рмағ, ҳмуд_, _سابت_, --, 
   {{0x20080034,0x39400194,0xa9640cb6,0x3f50005f}},	// [1f2e0] ęciu_, _qtks_, лита_, lšu_, 
   {{0x6aac0158,0x00000000,0x00000000,0x00000000}},	//   _encf, --, --, --, 
   {{0x3f5000da,0xdea40198,0x2ca40174,0xbb3402dd}},	//   nšu_, _sunƙ, _ónda_, _ﺗﯩﻢ_, 
   {{0xeb940474,0x00000000,0x00000000,0x00000000}},	//   _сию_, --, --, --, 
   {{0x7ae40227,0x98940139,0xf484009d,0x00000000}},	//   _imkt, _кувә, гуйн, --, 
   {{0x3f50005f,0xb344010e,0x940c03e3,0x81b800eb}},	//   kšu_, _neçü, _zadə_, ঘনা_, 
   {{0x3328084c,0x3f5000f3,0x65683e79,0x79940042}},	//   нцин_, jšu_, argh, lwyw, 
   {{0xdea40198,0xe8053c49,0x37040108,0xd5a400e5}},	//   _tunƙ, _снсд_, _спбг, _پلئی, 
   {{0x3f500029,0xe5a13c4a,0xff500092,0x79940175}},	//   ešu_, _лити, _መተማመ, nwyw, 
   {{0xe97800c8,0x66d000a2,0x00000000,0x00000000}},	//   עניש, _içka, --, --, 
   {{0xa0a00046,0x33f53c4b,0x3f50005f,0xa08420b0}},	//   сшыл, _счас, gšu_, усыз_, 
   {{0x690851e6,0x00000000,0x00000000,0x00000000}},	//   lüet, --, --, --, 
   {{0x95700092,0xfc440419,0x00000000,0x00000000}},	//   _ጥቃቅን_, _číra_, --, --, 
   {{0x9ae80364,0x940c00ac,0x799403cb,0x3f500171}},	//   ҳфуз_, _sadə_, dwyw, bšu_, 
   {{0xd5a455b4,0x1bd40276,0xdb1c01f4,0x1fa00024}},	//   _کہ_, боря, kyrä, _грыг, 
   {{0x3d180c2e,0x5bb807d8,0x6b98033f,0xbd540133}},	//   _मीठे_, ылся_, ługo, درێژ, 
   {{0x0854230c,0x28686a0c,0x00000000,0x00000000}},	// [1f2f0] иваю, ерео_, --, --, 
   {{0xaa7802f0,0x18680114,0x00000000,0x00000000}},	//   _zmýl, лађи_, --, --, 
   {{0x656c0295,0x66d0013d,0x2bc800d8,0x00000000}},	//   _ächz, _açka, _чупо_, --, 
   {{0xe7081158,0x6aac02d0,0x00000000,0x00000000}},	//   رتان_, _uncf, --, --, 
   {{0x28682424,0x00000000,0x00000000,0x00000000}},	//   _прво_, --, --, --, 
   {{0x69093c4c,0x656801ab,0x4aa80037,0x3f5000d7}},	//   güet, rrgh, _चोतव, yšu_, 
   {{0xd7f885c6,0x00000000,0x00000000,0x00000000}},	//   _бут_, --, --, --, 
   {{0x05140d42,0x3f5007f5,0xa2801bc6,0xd5b802dd}},	//   াদের_, všu_, صیتو, _өсу_, 
   {{0x514401ec,0x00000000,0x00000000,0x00000000}},	//   бдығ, --, --, --, 
   {{0xc0e4004e,0x00e401b9,0x00c807a5,0xc0040166}},	//   роок, ржон, тлок_, иппк, 
   {{0x3f508731,0xc2c4d712,0x6908000d,0x00000000}},	//   ušu_, _پيشي, lües, --, 
   {{0x3f50005f,0x7c2001e4,0x7338010f,0x357c0092}},	//   ršu_, _ŝoro, _סענס, _የልብስ_, 
   {{0x816003e6,0x92b4708e,0xc0dc0023,0x00000000}},	//   _بۆخۆ, _دحلا, _ሕጽር_, --, 
   {{0x7ae40ac5,0x00000000,0x00000000,0x00000000}},	//   _smkt, --, --, --, 
   {{0x6b8001e6,0x60c00192,0xdb1c01f4,0x00000000}},	//   _ängl, _ionm, yyrä, --, 
   {{0x60c0b1fa,0x6d5800e4,0x00000000,0x00000000}},	//   _honm, ġuar, --, --, 
   {{0x60c13c4d,0xab24064d,0xd3140408,0x00000000}},	// [1f300] _konm, рота_, _тiет, --, 
   {{0x60c13c4e,0x690804cc,0x79946b95,0x6e380419}},	//   _jonm, dües, rwyw, ľube, 
   {{0x60c007e0,0xd910040b,0x3eb0050a,0x7ae400b5}},	//   _monm, _ہیر_, _knyt_, _tmkt, 
   {{0xfaa43f9b,0x60c13c4f,0x5ca400f7,0x3704411a}},	//   _тамо, _lonm, _ئلگە, шпег, 
   {{0x6908feac,0xd9101a4b,0x60c00857,0x39440332}},	//   gües, _فیر_, _oonm, íosd_, 
   {{0xf3653c50,0x60c13c51,0x53353c52,0x7af53c53}},	//   атин, _nonm, бект, lnyt, 
   {{0xdb1d1397,0x690800e4,0x76b400d8,0x7af40064}},	//   pyrä, rüet, _кљац, onyt, 
   {{0x7af4049b,0xdb1d34d2,0x28100014,0x60c00332}},	//   nnyt, byrå, _ذوقس, _aonm, 
   {{0x60c13c54,0x690804cc,0x15b400cf,0x10c4004e}},	//   _bonm, müer, _دەشس, йөко, 
   {{0x60c0ef5e,0xb0c41468,0x7af40108,0x2618012d}},	//   _conm, рщик, hnyt, _बरती_, 
   {{0x836811c7,0x7af53c55,0x60c13c56,0xe5a00276}},	//   _مصنف_, knyt, _donm, _лиӂи, 
   {{0x27e53c57,0x31e800b1,0x00000000,0x00000000}},	//   únni_, _имеп_, --, --, 
   {{0x60c13c58,0x7af43e04,0x80a00456,0x00000000}},	//   _fonm, dnyt, _कोके, --, 
   {{0x7d0006d5,0x60c13c59,0xe1f4010b,0x7af400c0}},	//   _íosl, _gonm, _әгә_, enyt, 
   {{0x5ba40e0d,0x2ab4013d,0xa06400d8,0x00000000}},	//   ортз, аңны_, _таја_, --, 
   {{0x7af40158,0x60c001f5,0xdee40063,0xda340139}},	//   gnyt, _zonm, _моји, жеты, 
   {{0x7af800fc,0x60c0f5a0,0xac8401af,0xec6800f3}},	// [1f310] étta, _yonm, _кѳнл, _ирнк_, 
   {{0x60c00175,0xac7001e2,0x00000000,0x00000000}},	//   _xonm, _بندګ, --, --, 
   {{0xfc440122,0xdbf80055,0x5ba40139,0xd7c8004b}},	//   číte_, _bāõa, _дряз, ټونه_, 
   {{0x2d8c004a,0xfd64002b,0x690835f5,0x5fa40073}},	//   _âges_, _amuṣ, güer, गितल, 
   {{0x044400a7,0xfb18011a,0x00000000,0x00000000}},	//   белн, _תורמ, --, --, 
   {{0x690804cc,0xb0a403ce,0x00000000,0x00000000}},	//   rües, _कोलग, --, --, 
   {{0x93580184,0x60c00455,0x9a900023,0x84c400d1}},	//   арыу_, _ronm, _ምኽኣል_, _қәдд, 
   {{0x1bf804ae,0xc244399b,0xfbb821b8,0x00000000}},	//   יצור_, щник, _उपसम, --, 
   {{0x60c00455,0x6908ba0a,0x00e4004e,0x00000000}},	//   _ponm, qües, йжин, --, 
   {{0x66193c5a,0x60c0047e,0x855400e5,0x00000000}},	//   _izuk, _qonm, _نیچر_, --, 
   {{0x03e40183,0x60c13c5b,0x3ea53c5c,0x7af4005b}},	//   _পুৰণ, _vonm, бинг, ynyt, 
   {{0x52740510,0x60c00100,0x547001ee,0xe81c012d}},	//   _душу, _wonm, _еңәс, _भरना_, 
   {{0x7d1c0408,0x60c00100,0x81440472,0x00000000}},	//   _phps, _tonm, _انتن, --, 
   {{0x66182ce9,0x22900d28,0x66d020a9,0x00000000}},	//   _mzuk, _دلچس, _oçko, --, 
   {{0x7af4a2ec,0x69c800b5,0xef0c00f1,0x7d0000ae}},	//   tnyt, øgen, _ګټي_, _íosm, 
   {{0x1ee86112,0x6618009a,0x7db400ec,0x00000000}},	//   _خوبی_, _ozuk, _همعص, --, 
   {{0x66180521,0xcdc412d7,0x7af40250,0xcab80124}},	// [1f320] _nzuk, _маъқ, rnyt, шырц_, 
   {{0x7af53c5d,0x9cb400db,0xc0c80023,0x00000000}},	//   snyt, _بۅست, ኽበሉ_, --, 
   {{0x66193c5e,0x628801e1,0x77840108,0x69080205}},	//   _azuk, _obgo, слез, tüer, 
   {{0x3a980408,0x673801a6,0xa3a89a53,0xdb1c00e4}},	//   _стою_, _čujt, खिन_, hyrú, 
   {{0xdb140086,0xb4b00131,0x88d40055,0x00000000}},	//   _õaña, зилә, _mṛjj, --, 
   {{0x62880086,0x661800c0,0xc0680240,0x00000000}},	//   _abgo, _dzuk, _ተጠሊሙ_, --, 
   {{0x66180472,0xe6140107,0xf07400fb,0x00000000}},	//   _ezuk, _ҳдт_, ҙинә_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7bcc0122,0x6eec0100,0x15e00073,0xaa7801ef}},	//   hybu, _lòbè, _खेचर_, _smýk, 
   {{0x1ce40003,0x76413c5f,0x3d00033f,0xe81c302b}},	//   ྩིས_, lcoy, लकों_, _भरमा_, 
   {{0x7334007b,0xd5c400b8,0x00000000,0x00000000}},	//   _طرائ, bdāñ_, --, --, 
   {{0xf1a8caf7,0x7bcd3c60,0x09cc0154,0x76413c61}},	//   _ماته_, dybu, _রেফা, ncoy, 
   {{0x108801af,0x00000000,0x00000000,0x00000000}},	//   _көнк_, --, --, --, 
   {{0xa3bc0490,0xdb1c0124,0x2618012d,0x00000000}},	//   ुनच_, pyrû, _बरसी_, --, 
   {{0xaa640139,0x1bd40815,0x80a01025,0xcb08009f}},	//   йтак, поря, _कोटे, ليسن_, 
   {{0x75e4022e,0x705001e2,0xe81c000d,0x00000000}},	//   _nаzo, _بنډا, _भरबा_, --, 
   {{0x5ed40220,0x1ef800c6,0x00000000,0x00000000}},	// [1f330] _ءتىز, _دعوة_, --, --, 
   {{0x4aa829da,0xa3a81df1,0x00000000,0x00000000}},	//   _चोरव, खिम_, --, --, 
   {{0x6618006d,0x00000000,0x00000000,0x00000000}},	//   _szuk, --, --, --, 
   {{0xaa7800c7,0xca7c01a9,0x668001b9,0x00000000}},	//   _omýi, _hisо, ثیرل, --, 
   {{0x9b4400aa,0xd7f800d1,0xddc406be,0x21d40150}},	//   _ونیو, _ғур_, _meiş, _ﺘﻁﺎﻭ, 
   {{0x58840046,0x38700075,0xddd4025c,0xf8ac029c}},	//   _ныса, _оқут, _ħaże, _لکم_, 
   {{0x2aac0139,0x58d802e8,0x42d80139,0x00000000}},	//   _göbä_, _удря_, ифия_, --, 
   {{0x6618005a,0x42c86e47,0xd3b80150,0x00000000}},	//   _tzuk, ргин_, суші_, --, 
   {{0x66193c62,0xe1fc00cf,0xd1491cc7,0x80f800d8}},	//   _uzuk, çó_, یشین_, ихот_, 
   {{0x00d800f2,0xc0e400d4,0x00000000,0x00000000}},	//   شبخت_, іонк, --, --, 
   {{0x932401d9,0xdb1c0022,0xf8dc00cd,0x00000000}},	//   _کرٕن, ryrú, फोटय, --, 
   {{0x7bcc1155,0x00000000,0x00000000,0x00000000}},	//   vybu, --, --, --, 
   {{0x69c8019b,0x30a40014,0xddc403e0,0xdb1c00c7}},	//   øgel, _ڈلنہ, _deiş, pyrú, 
   {{0x644101dd,0x225d3c63,0x30a401d9,0x00000000}},	//   ncni, lauk_, _ولنہ, --, 
   {{0x6440007b,0x213c025c,0x387c0432,0x00000000}},	//   icni, lquh_, _ötri_, --, 
   {{0x225c28b5,0x6fc40316,0x7bcc0034,0xb4c477d7}},	//   nauk_, ाहरू, rybu, _उक्_, 
   {{0x7bcc003a,0x3f84025c,0x00000000,0x00000000}},	// [1f340] sybu, ltlu_, --, --, 
   {{0x3f840270,0x225c0158,0x6eec007f,0x3c6400d4}},	//   otlu_, hauk_, _tòbè, _ьког, 
   {{0xbb8426c0,0x225c0270,0x3f84004b,0xdb2401d3}},	//   _بلجي, kauk_, ntlu_, írós, 
   {{0x3f840357,0xd88800ec,0x00000000,0x00000000}},	//   itlu_, _گھرن_, --, --, 
   {{0xf5046fd2,0x76413c64,0x00000000,0x00000000}},	//   оздо, rcoy, --, --, 
   {{0xeabc01c3,0x764001b8,0x37e43f0f,0x4990104c}},	//   _fiùs_, scoy, _догг, _سیمر, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x225d3c65,0x3f84025c,0xe7340395,0xb6d4072d}},	//   gauk_, dtlu_, _фет_, _بقرع, 
   {{0x3f84031c,0x00000000,0x00000000,0x00000000}},	//   etlu_, --, --, --, 
   {{0x75e00139,0x3d18000d,0x2de400d1,0x00000000}},	//   _нәһҗ, _मीले_, ﻏﻼﻧﻤ, --, 
   {{0x32080034,0x7bd8026c,0x75e4022e,0xbf040073}},	//   łby_, ùtul, _mаzm, रवून_, 
   {{0x71700228,0x6b80000d,0xcd940114,0x00000000}},	//   _قۇبا, _ängi, памћ, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa11000cf,0xad240066,0xa2180354,0x70500345}},	//   _قونت, ترجو, _тачă_, _تۆدا, 
   {{0x2ac40063,0x6ae80798,0x00000000,0x00000000}},	//   ољав, аќав_, --, --, 
   {{0xa3a8242e,0x00000000,0x00000000,0x00000000}},	//   खित_, --, --, --, 
   {{0x9f045230,0x09753c66,0xaa78013a,0xe8482e28}},	// [1f350] _تويو, ягаю, _omýv, لجان_, 
   {{0xa9b805d7,0xec683b7e,0x9a8801d9,0x6d4c01ef}},	//   _ईपीए, _трик_, ٝنہٕ_, mpca, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x316407d6,0x03a4016c,0x00000000,0x00000000}},	//   _ovoz_, ҷико, --, --, 
   {{0x225c0153,0x04442083,0x00000000,0x00000000}},	//   vauk_, пелн, --, --, 
   {{0x03a45cf0,0x19581507,0x04440166,0x49041291}},	//   зико, _фары_, чекн, _روزق, 
   {{0x213c0548,0x225c05ac,0x6441041e,0x00000000}},	//   wquh_, tauk_, rcni, --, 
   {{0x5694084c,0x6b8000e4,0x9324475d,0x644000d7}},	//   _оаст, _ãngu, ورين, scni, 
   {{0x225d3c67,0xdb1c0158,0x6ebc043e,0x95d80117}},	//   rauk_, ryrø, षानु, _ддтт_, 
   {{0x3120765f,0x225c13bb,0x213c031c,0x00000000}},	//   ндыг, sauk_, rquh_, --, 
   {{0x3f840d04,0xbbb82977,0x3ea53c68,0xbea42472}},	//   utlu_, _उपेक, пинг, панк, 
   {{0x3ea40137,0x3f841432,0xaa7800d7,0x21b4072d}},	//   чимг, rtlu_, _zmýv, _وپاک_, 
   {{0x213c05b1,0xf28405d9,0xaa78032e,0x3f840135}},	//   qquh_, _رھيو_, _klýf, stlu_, 
   {{0xed1401d3,0x00000000,0x00000000,0x00000000}},	//   ےہیں_, --, --, --, 
   {{0xfe70495f,0x1ee803e6,0x316400d7,0x3f84025c}},	//   _كدة_, _ووتی_, _zvoz_, qtlu_, 
   {{0x394487b7,0xcee84cec,0x00000000,0x00000000}},	//   знаг, _ورين_, --, --, 
   {{0xcf253c69,0x00000000,0x00000000,0x00000000}},	// [1f360] _تروي, --, --, --, 
   {{0xe9d48456,0xee3c02fb,0xa3d80d2e,0x00000000}},	//   чку_, ndýn_, डना_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7d0d3c6a,0xaa7801ef,0x00000000,0x00000000}},	//   lobs, _smýv, --, --, 
   {{0xaa7808ce,0x3f40032e,0x4eac00df,0x00000000}},	//   _blýf, _lóu_, יבאַ, --, 
   {{0x7d0c5909,0x5fc80d0a,0x13953c6b,0xbb58001f}},	//   nobs, ाहाल, дикю, _ገብተዋ, 
   {{0x3984e67e,0x3f4002d2,0xa2b000e5,0x3164013a}},	//   lôs_, _nóu_, کینڈ, _svoz_, 
   {{0xe3ac4609,0x77f80bae,0x2a680051,0x00000000}},	//   ارو_, ्थीक_, _xdcb_, --, 
   {{0x75e401a9,0x7108e0a5,0x3984c4e9,0x33a800ec}},	//   _mаzk, йхов_, nôs_, _گهاٽ_, 
   {{0xaa7801f1,0xe9dc01e1,0x00000000,0x00000000}},	//   _umýv, _ofún_, --, --, 
   {{0x7d0c0998,0xe9dc01e1,0x95540023,0x212800e4}},	//   dobs, _nfún_, _ዝተኣሰ, ïcha_, 
   {{0x7a2402b5,0x3f413c6c,0x6e380419,0x00000000}},	//   _kōtī, _dóu_, ľubo, --, 
   {{0x6448002e,0x6d4c03ac,0x00000000,0x00000000}},	//   _élié, upca, --, --, 
   {{0xc7340020,0x7a2402b5,0x6d4d3c6d,0x00000000}},	//   _እነዚህ, _mōtī, rpca, --, 
   {{0x9b5824a9,0x6d4c00db,0x3f4002d2,0x00000000}},	//   зист_, spca, _góu_, --, 
   {{0x9c4401c6,0x1aa40114,0x00000000,0x00000000}},	//   _үхэл, нјуг, --, --, 
   {{0x6f0d3c6e,0x7d0c022e,0x44280051,0x00000000}},	// [1f370] mocc, bobs, ̀a_, --, 
   {{0x6f0d3c6f,0x66d03535,0x6d4000b0,0x00000000}},	//   locc, _içki, _ōnaw, --, 
   {{0xb7845dc9,0x00000000,0x00000000,0x00000000}},	//   мәте_, --, --, --, 
   {{0x39840798,0xa2600208,0x00000000,0x00000000}},	//   bôs_, _chồ, --, --, 
   {{0x1a680405,0xdb1c00e4,0xdc800240,0x00000000}},	//   _ریلی_, nyrý, _ይምህር_, --, 
   {{0x1ce4025c,0xaa7803b2,0x6f0d3c70,0x00000000}},	//   ྩིག_, _blýg, hocc, --, 
   {{0xf8b004ae,0x70600092,0x00000000,0x00000000}},	//   _בשם_, ጋጀታቸ, --, --, 
   {{0xd6d80046,0x6f0cf1da,0xdb1c00c7,0xdb080162}},	//   _ету_, jocc, kyrý, óløv, 
   {{0x6f0d3c71,0x3f4006ea,0xf91803e6,0x85040244}},	//   docc, _sóu_, _درێژ_, _قورن, 
   {{0xaa780bcd,0x6f0c0381,0x40940395,0xdb1c0432}},	//   _flýg, eocc, фрит, dyrý, 
   {{0x7d0d3c72,0x00000000,0x00000000,0x00000000}},	//   vobs, --, --, --, 
   {{0x6f0c011c,0x00000000,0x00000000,0x00000000}},	//   gocc, --, --, --, 
   {{0xed541621,0x6298009f,0x7d0c5bc6,0xdb1c00ee}},	//   моя_, meuo, tobs, gyrý, 
   {{0xc1053c73,0xee340953,0xddc40311,0x62986330}},	//   _توتي, ьня_, _adiţ, leuo, 
   {{0x6f0d3c74,0x7d0d3c75,0xbea4499d,0x709000f3}},	//   bocc, robs, _жайк, _рајф, 
   {{0xe3ac02a6,0xdce40960,0x62980368,0x7d0c00d8}},	//   _কথাব, _ivič, neuo, sobs, 
   {{0xd7f80356,0x290489e3,0x00000000,0x00000000}},	// [1f380] _ţă_, čnan_, --, --, 
   {{0xddc4084c,0x09cc0154,0x629803cb,0x00000000}},	//   _ediţ, _রেহা, heuo, --, 
   {{0x3b6401d9,0x65c400b8,0x00000000,0x00000000}},	//   _تُجِ, _lūhā, --, --, 
   {{0x39840120,0x00000000,0x00000000,0x00000000}},	//   pôs_, --, --, --, 
   {{0x62980042,0xe5a04ea0,0x00000000,0x00000000}},	//   deuo, кици, --, --, 
   {{0x8b6458ae,0xa53002bf,0x73484a03,0x39500076}},	//   _تایم, вніч, очив_, mpys_, 
   {{0xb9f80020,0xaa780174,0x6f0c72ab,0x3950062c}},	//   _ዘር_, _flýd, yocc, lpys_, 
   {{0x316801c6,0x00000000,0x00000000,0x00000000}},	//   ошоо_, --, --, --, 
   {{0x6f0cf996,0xdd1400d0,0x51f80108,0x00000000}},	//   vocc, dĺžn, янию_, --, 
   {{0xa5213c76,0xa124007b,0x00000000,0x00000000}},	//   _амуд, وكيل_, --, --, 
   {{0xdce40232,0x6f0d3c77,0xfe6c1c5c,0xca3c0952}},	//   _cvič, tocc, ڭگى_, ﻟﻪﺭ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdce402f0,0x00000000,0x00000000,0x00000000}},	//   _evič, --, --, --, 
   {{0x6f0d3c78,0xdb1c00c7,0xa1900114,0xe81c098b}},	//   socc, ryrý, _рашч, _भरला_, 
   {{0x6f0ca723,0x9d1864cd,0x1fa045fb,0xdb1c00e4}},	//   pocc, форт_, _арыг, syrý, 
   {{0xefe80020,0x5fc83885,0xdb1c0124,0xb0600139}},	//   ሆነው_, ाहरल, pyrý, _ğäys, 
   {{0xeabc001e,0x6820022e,0x2724000d,0xb0600139}},	// [1f390] _chùa_, mеdi, lõng_, _şäys, 
   {{0xaf28044e,0xad24fae3,0x987400a7,0x31280092}},	//   ተፈላለ, _تربو, клуц, _ትብብር, 
   {{0xacb000db,0x00000000,0x00000000,0x00000000}},	//   _كەڭب, --, --, --, 
   {{0x3324004d,0xab8c0023,0x236002d2,0xc8c857fb}},	//   _nhox_, _ምልዓል_, _æjji_, _کوسن_, 
   {{0x67293c79,0x00000000,0x00000000,0x00000000}},	//   rmgj, --, --, --, 
   {{0x6b813c7a,0x7eb40793,0xa3a806e3,0x7d00007b}},	//   _ängs, _küpä, खिल_, _íost, 
   {{0x2900031c,0x62980618,0xaa7800ee,0x2ca40162}},	//   _ijja_, teuo, _elýe, _óndu_, 
   {{0x339026c0,0x65c400b0,0x33240213,0x5c3873cd}},	//   اليز, _pūhā, _chox_, ורון_, 
   {{0x7af800fc,0x62980368,0xddc40030,0xe61001d9}},	//   étti, reuo, _odiš, _ششر_, 
   {{0x629800a9,0xd3780075,0x00000000,0x00000000}},	//   seuo, ччә_, --, --, 
   {{0x26dc0793,0xd04806be,0x00000000,0x00000000}},	//   _kluo_, nkdə, --, --, 
   {{0xe0bc015b,0x65c402b1,0x7ce0017a,0x00000000}},	//   ইসেন, _tūhā, _môre, --, 
   {{0x29000a49,0x00000000,0x00000000,0x00000000}},	//   _ojja_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69c80598,0x75e4036b,0x7a2801d3,0x26dd3c7b}},	//   ägen, _vаzi, köté, _oluo_, 
   {{0x29002f99,0xb0600724,0xbea400c7,0xbb3400d1}},	//   _ajja_, _şäxs, _чаик, _ﺗﯩﻞ_, 
   {{0x7e640357,0x00000000,0x00000000,0x00000000}},	// [1f3a0] makp, --, --, --, 
   {{0x7e653c7c,0x26dc5719,0x39500096,0x37e4004e}},	//   lakp, _aluo_, rpys_, нозг, 
   {{0x7c3c7bad,0x26dc00df,0xeabc0241,0x2724000d}},	//   _igpr, _bluo_, _ihùn_, kõnd_, 
   {{0x7e653c7d,0x29013c7e,0x07000022,0xeabc0208}},	//   nakp, _ejja_, аҧсо, _thùa_, 
   {{0x7ce00086,0x6fe40098,0x7c3c037e,0x7af45431}},	//   _eôre, _kécé, _kgpr, miyt, 
   {{0x26dc0810,0x6fe4003e,0x7af40309,0x7ce13c7f}},	//   _eluo_, _jécé, liyt, _fôre, 
   {{0x26dd3c80,0x7e64bf25,0x7c3c0175,0x6fe406af}},	//   _fluo_, kakp, _mgpr, _mécé, 
   {{0x6b80049f,0x31c4a15c,0x26dc0115,0x6fe40098}},	//   _ånge, есов, _gluo_, _lécé, 
   {{0x34387965,0x7e653c81,0x394003cd,0x66e13c82}},	//   _فساد_, dakp, _juks_, _сота, 
   {{0x63b40137,0x7c3c003e,0x7af4edf8,0x6fe406af}},	//   çanè, _ngpr, hiyt, _nécé, 
   {{0x7af402d1,0xdf1801d3,0xe57c0171,0x00000000}},	//   kiyt, کڑوں_, _āķis_, --, 
   {{0x75380323,0x7e640d04,0xb8d02fb5,0x437400db}},	//   _hitz, gakp, _དལ_, _шуут, 
   {{0x75393c83,0x7eb401b8,0xc2e80aaa,0x7af401c8}},	//   _kitz, _süpä, _تعلم_, diyt, 
   {{0x777c0bc9,0x6fe40c6a,0x7538f5ac,0xeabd3c84}},	//   kupx, _cécé, _jitz, _chùn_, 
   {{0x6fe45725,0x75393c85,0xeabc0e89,0x2d880d0d}},	//   _décé, _mitz, _dhùn_, stce_, 
   {{0x9a8495de,0x753805f5,0x39400793,0x7c3c0098}},	//   луул, _litz, _buks_, _egpr, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [1f3b0] --, --, --, --, 
   {{0x753801c4,0x39413c86,0xddc407f5,0x50b000cd}},	//   _nitz, _duks_, _udiš, जयिष, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x97a41248,0x753805f5,0xd7f801c6,0x7d000332}},	//   ырул, _aitz, хуу_, _íosr, 
   {{0x75381906,0x6b8001e3,0x44380241,0x00000000}},	//   _bitz, _ångb, _ńs_, --, 
   {{0xdb1c0008,0x6d5c007f,0x7e640cf4,0x00000000}},	//   lyrð, _mwqa, zakp, --, 
   {{0xc1c8fdeb,0x753805f5,0x7e653c87,0x986801d3}},	//   ाङ्ग, _ditz, yakp, _سینے_, 
   {{0x291018f7,0x3940020b,0x753801c4,0x6d5c0009}},	//   loxa_, _yuks_, _eitz, _owqa, 
   {{0x7e640357,0x72c00c75,0xaa781155,0xceac06be}},	//   vakp, рбыз, _zlýc, ddә_, 
   {{0xb9f8044e,0x29100227,0x75380334,0xe9dc01d3}},	//   _ዘይ_, noxa_, _gitz, _pfúj_, 
   {{0x673800c8,0x6618105c,0x6d5c0986,0x6fe44de4}},	//   _kiuj, _hyuk, _awqa, _récé, 
   {{0x753805f5,0x291001f0,0x6618dfae,0xc0e40023}},	//   _zitz, hoxa_, _kyuk, ዝበላ_, 
   {{0x7e640054,0x673800ec,0x69c93c88,0x75380784}},	//   rakp, _miuj, ägel, _yitz, 
   {{0x66193c89,0x7e653c8a,0x7af402d1,0x65680332}},	//   _myuk, sakp, wiyt, isgh, 
   {{0x6b613c8b,0x7e646d1f,0x7af53c8c,0x75f00166}},	//   икра, pakp, tiyt, _kızç, 
   {{0x7b2c0115,0x67393c8d,0x3940000d,0x66180205}},	//   _aŝur, _niuj, _puks_, _oyuk, 
   {{0x7af53c8e,0x66193c8f,0xa9653c90,0xf2d000c8}},	// [1f3c0] riyt, _nyuk, кита_, בען_, 
   {{0x7af53c91,0xc0e40023,0x00000000,0x00000000}},	//   siyt, ዝበሉ_, --, --, 
   {{0x67380007,0x75393c92,0x66193c93,0x4424020c}},	//   _biuj, _ritz, _ayuk, _nzl_, 
   {{0x75380639,0x66180230,0x673895bb,0x39413c94}},	//   _sitz, _byuk, _ciuj, _tuks_, 
   {{0x75393c95,0x66180223,0x7af8008c,0x777c0227}},	//   _pitz, _cyuk, éttu, supx, 
   {{0x66193c96,0xaa7800a2,0xb3d00131,0xb4b004a9}},	//   _dyuk, _ilýa, ийлә, рикә, 
   {{0x67381509,0x656801e7,0x9294688a,0xa7a40108}},	//   _fiuj, asgh, гайц, _икра_, 
   {{0x753801cf,0x67393c97,0x1fc400cc,0x00000000}},	//   _witz, _giuj, শনাস, --, 
   {{0xe5a13c98,0xe0cc0451,0x44240166,0x75800214}},	//   _кити, ڪزي_, _ezl_, _ضیغم, 
   {{0x75380936,0x44a469d2,0x33f42077,0x00000000}},	//   _uitz, _محمّ, _ичес, --, 
   {{0x287806a9,0x20c000f7,0xa8780a7c,0x442403e0}},	//   ונימ, рсыг, ואיר, _gzl_, 
   {{0x73353c99,0xeabc0e89,0x00000000,0x00000000}},	//   _شرائ, _chùl_, --, --, 
   {{0xdf0805f5,0xee3c035b,0x00000000,0x00000000}},	//   тээл_, ndýi_, --, --, 
   {{0x29101717,0x2368005b,0x8c4800a2,0x00000000}},	//   xoxa_, _äijä_, daşý, --, 
   {{0xa3a86495,0xaa780209,0x29100117,0x44240175}},	//   खिए_, _alýa, voxa_, _xzl_, 
   {{0xaa780d12,0x5e84030d,0x00000000,0x00000000}},	//   _blýa, _куьз, --, --, 
   {{0xd5a4aaac,0xef1c029f,0x2d0401c6,0x69c001f9}},	// [1f3d0] _بہ_, mlü_, _аянг, रमधी, 
   {{0xd8740a2c,0x6618019b,0x67380399,0xef1c0259}},	//   لامب, _ryuk, _siuj, llü_, 
   {{0x06741f09,0x67380869,0x68f486da,0x29100005}},	//   гуля, _piuj, rixd, roxa_, 
   {{0xef1c06b9,0x6568014f,0x661800b8,0x00000000}},	//   nlü_, tsgh, _pyuk, --, 
   {{0x1ce40156,0x44253c9a,0x00000000,0x00000000}},	//   ྩིཝ_, _szl_, --, --, 
   {{0x44246278,0x63a0015d,0x0474132f,0x00000000}},	//   _pzl_, twnn, ائشگ, --, 
   {{0x673800c8,0xef1c4a4a,0x1ccc031c,0x57a401ce}},	//   _tiuj, klü_, _ྲོལ_, _кшта, 
   {{0x7ce00109,0x41a8010b,0x75f00139,0xd3b8cea4}},	//   _môra, евин_, _qızç, туші_, 
   {{0x44240175,0x66193ba0,0xef1c03b9,0x7170009f}},	//   _wzl_, _uyuk, dlü_, مهيا, 
   {{0xeabc01c3,0xf1f401d9,0x5344035b,0xf3f40150}},	//   _shùl_, ھکۆش_, ыхәа, _өңі_, 
   {{0xef1c0790,0xc274033a,0xc35400f0,0x00000000}},	//   flü_, _блеј, _скеј, --, 
   {{0xef1d3c9b,0xd39801af,0x00000000,0x00000000}},	//   glü_, _рәшә_, --, --, 
   {{0xeabd3c9c,0xeb940daf,0xa3a81b76,0x24e80055}},	//   _chùm_, һир_, खिक_, _śaṃś, 
   {{0x717004fb,0x4df41468,0x3f693c9d,0x90e400cf}},	//   _اهوا, ряют, _зико_, _ۅسۉن, 
   {{0x75e800dd,0xeb953c9e,0x6fb06dd7,0xff500efe}},	//   _közé, лир_, _هموا, _اخت_, 
   {{0xef1c03be,0x7ce00030,0xaa7800a2,0x6a80009d}},	//   clü_, _dôra, _plýa, йлса, 
   {{0xf2d000c8,0x6b98084c,0xadb40451,0x3a240334}},	// [1f3e0] זען_, ăuga, _مهيا_, умаг, 
   {{0x7ce00158,0xe8f53c9f,0xb6000306,0x00000000}},	//   _fôra, глу_, ňáko, --, 
   {{0x69c8037e,0xfa693ca0,0x7a680798,0x00000000}},	//   øger, _панк_, _пинг_, --, 
   {{0xeabc01ab,0x3ea03b3b,0xaa7808a5,0x6b8001e3}},	//   _gnù_, nekt_, _hlýn, _ånga, 
   {{0xa8840131,0x00000000,0x00000000,0x00000000}},	//   _әйса_, --, --, --, 
   {{0xf1a41ee3,0xef1c2fbe,0x1ccc0327,0x00000000}},	//   ҳрон, zlü_, _ྲོས_, --, 
   {{0xf1d00323,0xaa7800bc,0xef1c083c,0x37e4341e}},	//   өөдө, _mlýn, ylü_, _совг, 
   {{0xe7353ca1,0xa3b401d3,0x91741d39,0x59c83d22}},	//   _бес_, ااور_, агиц, रमपर, 
   {{0x3ea0de16,0x78ac004c,0xf508023a,0x00000000}},	//   dekt_, _kabv, _знал_, --, 
   {{0x30a53ca2,0x544400db,0x50f51483,0xdb1c0022}},	//   урив, _ئچشك, рзот, myrõ, 
   {{0x78ad0ed2,0xef1c05d1,0x00000000,0x00000000}},	//   _mabv, tlü_, --, --, 
   {{0x78ac00e2,0x6ad0b7b0,0x00000000,0x00000000}},	//   _labv, _सवेर, --, --, 
   {{0xef1c0365,0x232400d8,0x00000000,0x00000000}},	//   rlü_, _соци_, --, --, 
   {{0x78ac014f,0xef1c05d1,0xeff0001f,0x6ce402dd}},	//   _nabv, slü_, ልሰው_, уіме, 
   {{0xef1c1570,0x3ea00139,0x00000000,0x00000000}},	//   plü_, bekt_, --, --, 
   {{0x4a553ca3,0x7e9802b5,0xdf7002c9,0x00000000}},	//   ркас, _pāpō, _ادوب, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [1f3f0] --, --, --, --, 
   {{0x8bd879ea,0x5a3404b0,0xa3c001ef,0x0b4402f2}},	//   _амос_, снут, _ráží_, _پردێ, 
   {{0x09cc0154,0x0a940816,0x7c8c0240,0x6e380419}},	//   _রেখা, _каню, _ዝምባለ_, ľubu, 
   {{0x7e9802b5,0x682001d5,0x2ca0036e,0x00000000}},	//   _tāpō, fеdr, lejd_, --, 
   {{0x29883da1,0x00000000,0x00000000,0x00000000}},	//   _ясно_, --, --, --, 
   {{0x2ca00267,0xa3c00118,0xb97873cd,0x00000000}},	//   nejd_, _váží_, _בנשי, --, 
   {{0x3ea03c1e,0x00000000,0x00000000,0x00000000}},	//   yekt_, --, --, --, 
   {{0x6aac0067,0x41b40966,0x634001d3,0xd7f40166}},	//   _jacf, لمعر, _nőne, _узсы, 
   {{0x6aad3ca4,0xa4840597,0xc994001f,0x00e4084c}},	//   _macf, _مجان, _ኃላፊው_, ижин, 
   {{0x3ea009b6,0x7fb40006,0xa2a40210,0x00000000}},	//   wekt_, аёмі, _फ़ोर्, --, 
   {{0x660001ee,0x00000000,0x00000000,0x00000000}},	//   _тоҡҡ, --, --, --, 
   {{0x6aac058a,0x00000000,0x00000000,0x00000000}},	//   _nacf, --, --, --, 
   {{0x3ea0f189,0xaa7800a2,0xe57802d3,0x3d100073}},	//   rekt_, _alýo, _ብሰፊሑ_, णवले_, 
   {{0xed553ca5,0x3ea000cc,0x7ff4034c,0xd54401e1}},	//   рор_, sekt_, _پستا, _lé̟y, 
   {{0x3ea10e86,0x78ac004c,0xfaf40826,0xaca00241}},	//   pekt_, _rabv, ачаю, _gbọg, 
   {{0xb90800b4,0xaa4002ac,0x5a4401ec,0x00000000}},	//   bakọ_, жетл, смағ, --, 
  
   {{0xe9d4531f,0x78642082,0x6288f733,0x78ac004c}},	// [1f400] акт_, иказ, _mcgo, _pabv, 
   {{0x78ac014f,0x5ca41c3e,0x98b8007f,0xaa7808a5}},	//   _qabv, _الدە, _tirč_, _hlýl, 
   {{0x6c7827af,0x78ac0433,0x00000000,0x00000000}},	//   _בריד, _vabv, --, --, 
   {{0x78ad3ca6,0x7ce00419,0xeb9438be,0xdb1c00c7}},	//   _wabv, _kôro, _тию_, tyrõ, 
   {{0xe6906a15,0x78ac004c,0x7ae40205,0x00000000}},	//   تلند, _tabv, _ilkt, --, 
   {{0x55c41df2,0x00000000,0x00000000,0x00000000}},	//   _қазғ, --, --, --, 
   {{0x272400af,0x636405f5,0xb4e40073,0x04641cd0}},	//   sõna_, арыг_, _पती_, стім, 
   {{0xf1a802f2,0x00000000,0x00000000,0x00000000}},	//   ناخه_, --, --, --, 
   {{0xa4241b49,0xc0dc0023,0x00000000,0x00000000}},	//   _ትዕግስ, _ዕሽሽ_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x853401d5,0x7e7403b9,0x0f14004e,0x651000e5}},	//   _اولچ, _bdyp, ймою, _بولئ, 
   {{0xd9f80073,0x09cc00fe,0x00000000,0x00000000}},	//   ूपात_, _ৰেফা, --, --, 
   {{0xfe6c04fb,0x6aac0067,0x71700131,0x11540006}},	//   ژگی_, _racf, _بۇخا, _уклю, 
   {{0x7ae4127b,0xaa7800a2,0xa0a0014b,0x00000000}},	//   _alkt, _plýo, _мачд, --, 
   {{0x6aac0526,0x2b4405f5,0x2128004a,0x2ca13ca7}},	//   _pacf, рэгг, îche_, rejd_, 
   {{0x7ce00077,0x93bc0083,0xb908063f,0x49a40220}},	//   _fôro, _kyăb, pakọ_, йызғ, 
   {{0x09cc015b,0x2ca0009b,0x8d94007b,0x4f3401d3}},	// [1f410] _রেজা, pejd_, _الخش, _پڑھئ, 
   {{0x7ae400e8,0xab84e017,0x6b80007c,0xa8a400f0}},	//   _elkt, _кумк, _ångo, јрак, 
   {{0xc6900020,0xe70810de,0x6aad3ca8,0xe784490c}},	//   _የምርጫ_, پتان_, _tacf, рузо, 
   {{0x6aac45a7,0x6680036b,0xebc001ee,0x00000000}},	//   _uacf, تیرل, _ләғн, --, 
   {{0x02c4012c,0x3944007b,0xeabc0051,0x00000000}},	//   वासभ, íost_, _nhùi_, --, 
   {{0x58849db8,0xdb1c00e4,0x00000000,0x00000000}},	//   _мыса, syrô, --, --, 
   {{0xe3b004fb,0xb600031c,0xd7e40212,0x00000000}},	//   ترش_, _ġġed, _діто, --, 
   {{0xa28012ea,0x00000000,0x00000000,0x00000000}},	//   زیتو, --, --, --, 
   {{0xeabc004d,0x932400d1,0x00000000,0x00000000}},	//   _chùi_, غرىن, --, --, 
   {{0xdce401a6,0x1724031c,0x00c8011b,0x00000000}},	//   _ivić, _འཚོམ_, улок_, --, 
   {{0x004400f1,0xbe680fac,0x00000000,0x00000000}},	//   لیږي_, ланж_, --, --, 
   {{0x6714b381,0x7ce001f1,0x82c00327,0x00000000}},	//   तविक_, _pôro, _མོིའ, --, 
   {{0x6d482047,0xd1b80d00,0x225d3ca9,0x93bc0083}},	//   _égal, _پانا_, mbuk_, _gyăb, 
   {{0xa2801bf3,0x0c781def,0x6da00120,0x225c025c}},	//   _ایکو, иссы_, џира, lbuk_, 
   {{0x60c13caa,0x225c011f,0x6b8001e3,0x00000000}},	//   _innm, obuk_, _ångl, --, 
   {{0x612c95a0,0x1724025c,0xaa7801a8,0x00000000}},	//   følg, _འཚེམ_, _hlýj, --, 
   {{0xab24b19d,0x00000000,0x00000000,0x00000000}},	// [1f420] сота_, --, --, --, 
   {{0xb4e512e7,0x3eb003f0,0xc984007b,0xe1e401d9}},	//   _पते_, _hayt_, تشفي, _ہس_, 
   {{0x225cc227,0x3f853cab,0x3eb13cac,0xc7642dfc}},	//   kbuk_, nulu_, _kayt_, قانى, 
   {{0x612c28b3,0xe1e53cad,0xe7340117,0xee3c010e}},	//   bølg, _فس_, бех_, leýa_, 
   {{0x3f853cae,0x3eb00bc9,0x60c000c6,0xd9109f6d}},	//   hulu_, _mayt_, _onnm, _قیر_, 
   {{0x3f853caf,0xe9900150,0x888000d1,0x3eb006be}},	//   kulu_, _ءۇلگ, _оғул, _layt_, 
   {{0x3f853cb0,0x98b8002b,0xe3ad0565,0x00000000}},	//   julu_, _girā_, فري_, --, 
   {{0x3f853cb1,0xcfd02f8b,0x386894e7,0x5eb00183}},	//   dulu_, ানমন, _hebr_, টাডে, 
   {{0xfc4402fb,0xa6c407d5,0x69f8010f,0xf4940108}},	//   _čína_, _улта_, ָליק, _грею, 
   {{0x3f853cb2,0x386800a2,0x96d400c7,0x612c06ea}},	//   fulu_, _jebr_, _усҳә, jøld, 
   {{0x3f853cb3,0x8f353cb4,0x3eb01ba4,0x225c0548}},	//   gulu_, женц, _bayt_, bbuk_, 
   {{0xceb88055,0x60c13cb5,0x59c841ac,0xaf4c001f}},	//   рәк_, _ennm, रमार, _አደረገ, 
   {{0x3f8406c8,0xaa7808a5,0x1acc00fe,0x709826c6}},	//   aulu_, _flýj, ৰোৱা, _منشأ_, 
   {{0x3f853cb6,0xdd9004a9,0x7ce13cb7,0xcfd000eb}},	//   bulu_, رۈپ_, _fôrm, ানবন, 
   {{0x3f853cb8,0xe0f80375,0xce940354,0x5f701095}},	//   culu_, _גלגל, _дайъ, _فاير, 
   {{0x3eb00076,0x6ee407d6,0x6b80007c,0xb8e801d9}},	//   _gayt_, _دستل, _ångm, یبٕے_, 
   {{0x3868030a,0xfd640ca8,0x98b80055,0xda340166}},	// [1f430] _bebr_, _oluṣ, _sirā_, зеты, 
   {{0x6d4c0369,0x1ccc031c,0x17240327,0x48c400c7}},	//   mqca, _ྲོག_, _འཚུམ_, цәма, 
   {{0x38680165,0xab6002dd,0xdce416a3,0xad242d56}},	//   _debr_, _ءۇرى, _svić, _پرکو, 
   {{0xca3c0131,0x85b8030d,0x00000000,0x00000000}},	//   ﻟﻪﺕ_, илес_, --, --, 
   {{0x3f853cb9,0x38693cba,0x2ed42982,0x00000000}},	//   zulu_, _febr_, _डकैत, --, 
   {{0x3f840357,0xeff0001f,0x38681543,0x00000000}},	//   yulu_, ውሰድ_, _gebr_, --, 
   {{0x69c8007c,0x00000000,0x00000000,0x00000000}},	//   ågef, --, --, --, 
   {{0x3f853cbb,0x386805c7,0x00000000,0x00000000}},	//   vulu_, _zebr_, --, --, 
   {{0x9a90069c,0x3f840364,0xe5c405c5,0x225d3cbc}},	//   _ዝኽእል_, wulu_, _усво, rbuk_, 
   {{0x3eb13cbd,0x3f853cbe,0x225c0438,0x612c00b5}},	//   _sayt_, tulu_, sbuk_, køle, 
   {{0x612d3cbf,0x225c1c06,0x3eb001b9,0xca3c0ae5}},	//   vøld, pbuk_, _payt_, ﻟﺪﺍ_, 
   {{0x7d1c074d,0xf77000c8,0x3f853cc0,0x1ccc031c}},	//   _skps, וקט_, rulu_, _ྲོང_, 
   {{0x3f853cc1,0x6b840369,0xa2240bbf,0x00000000}},	//   sulu_, eujg, _اراه, --, 
   {{0x3f853cc2,0x612c0ac7,0x3eb0e483,0x98b80356}},	//   pulu_, føle, _wayt_, _miră_, 
   {{0x3f846ae5,0x3eb0ef70,0x7fd40826,0x2d4c0254}},	//   qulu_, _tayt_, _філі, _eüe_, 
   {{0xb4e411b1,0x3eb0022e,0x7ce000d7,0x386803b9}},	//   _पत्_, _uayt_, _kôrk, _sebr_, 
   {{0x2d4c00e4,0x38693cc3,0x301000fb,0x00000000}},	// [1f440] _güe_, _pebr_, _ндәр, --, 
   {{0xe8c51741,0x00000000,0x00000000,0x00000000}},	//   огул_, --, --, --, 
   {{0xd1dc02d3,0x69e40010,0x59c83cbe,0x00000000}},	//   _ዕውት_, _čreš, रमहर, --, 
   {{0xe9dc0ca8,0x762401f0,0xc7641fd6,0x00000000}},	//   _igún_, омез, سامى, --, 
   {{0x3868030a,0xb4b0ecb2,0xfd6400b8,0x00000000}},	//   _tebr_, дилә, _pluṣ, --, 
   {{0x38680223,0x91b00208,0xa9646a7a,0x6db40139}},	//   _uebr_, _đài_, _фира_, lğaç, 
   {{0x80cc0825,0x366808ca,0x79953cc4,0x00000000}},	//   ताने, _вабо_, ltyw, --, 
   {{0x3164007f,0x17240327,0x68400006,0xb6700240}},	//   _pwoz_, _འཚིམ_, _інта, _ኣጽኒዑ_, 
   {{0x7108419d,0x79953cc5,0x00000000,0x00000000}},	//   ихов_, ntyw, --, --, 
   {{0x85e002dd,0xe9dc0ca8,0x7994127b,0x34180024}},	//   _سۋىن, _ogún_, ityw, _кіеў_, 
   {{0xf1a8b184,0xefdc0023,0x21280124,0xb3540244}},	//   _چاته_, _ዕርዲ_, îcha_, _بیبا_, 
   {{0x7994068f,0x7ce003cd,0xf1a80133,0x00000000}},	//   ktyw, _fôrk, _ناته_, --, 
   {{0xe1ec004b,0xf0741de6,0x25300023,0x00000000}},	//   _لسو_, _дилә_, _ይሃብኩ, --, 
   {{0x2a68026c,0xd1b85dcd,0x612c2d8b,0x6b80007c}},	//   _secb_, _پاچا_, tøle, _ångk, 
   {{0xc0a804fb,0x7bcc0009,0xaa78032e,0x799402d0}},	//   _دانل_, gxbu, _hlýi, etyw, 
   {{0xb6041f7f,0xd1380006,0x202000d0,0x612c01bf}},	//   _kršć, lmą_, íriť_, røle, 
   {{0xe9dc0241,0xde04009b,0x00000000,0x00000000}},	// [1f450] _egún_, _опћи, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7994033f,0x0fe800cc,0x00000000,0x00000000}},	//   atyw, _পশুধ, --, --, 
   {{0xd7c80244,0xd7f801c6,0xe610114f,0x00000000}},	//   تومه_, цуу_, وشش_, --, 
   {{0x3aec03b2,0x69c801bf,0x25a80114,0x00000000}},	//   _dýpd_, åged, рђен_, --, 
   {{0xe78422f7,0xd138012d,0x00000000,0x00000000}},	//   _мубо, jmą_, --, --, 
   {{0xda940023,0xdce40135,0x43680395,0x00000000}},	//   _ውሽጥና_, _swiċ, щайн_, --, 
   {{0xaa7802d2,0x42c8010b,0x070801f7,0x00000000}},	//   _blýi, сгин_, _ايري_, --, 
   {{0x444400dd,0x02040116,0x56940166,0x00000000}},	//   _فراہ, язин, _юатт, --, 
   {{0x25bc92d6,0x3f7402b5,0xd1380064,0xa34400c0}},	//   _irul_, tāu_, gmą_, _дэдл, 
   {{0x25fc0490,0x80cc033f,0x7994012d,0x00000000}},	//   _शेती_, ताबे, ztyw, --, 
   {{0x25bc0b4f,0xc0e804fb,0xd1380024,0x442403e3}},	//   _krul_, _گفتن_, amą_, _iyl_, 
   {{0xbd340395,0x00000000,0x00000000,0x00000000}},	//   зхвъ, --, --, --, 
   {{0xee353cc6,0x2c54012c,0x44253cc7,0x6298002d}},	//   яня_, vědí_, _kyl_, lfuo, 
   {{0x62980618,0x938c0240,0x00000000,0x00000000}},	//   ofuo, _ዘይሳነ_, --, --, 
   {{0x44253cc8,0x62993cc9,0x00000000,0x00000000}},	//   _myl_, nfuo, --, --, 
   {{0x6a800276,0xe9a13cca,0xa2b0194b,0x00000000}},	// [1f460] элта, натп, _आसन्, --, 
   {{0x23d80316,0x44253ccb,0x79952c5c,0x00000000}},	//   बहाद, _oyl_, rtyw, --, 
   {{0x2d8c049f,0x69c93ccc,0x799472c4,0x442462f1}},	//   _äger_, äger, styw, _nyl_, 
   {{0xe7341f91,0xd1386dd2,0x25bc1a10,0x79940857}},	//   пех_, zmą_, _brul_, ptyw, 
   {{0xd1380006,0x44240009,0xb060008e,0xa2bc00cd}},	//   ymą_, _ayl_, _şäms, वयन्, 
   {{0x4424038e,0xddc4054e,0x7ce000d7,0xf748027d}},	//   _byl_, _zeiţ, _bôri, _هجره_, 
   {{0x4424045a,0xb7d4eead,0xf1a80133,0x00000000}},	//   _cyl_, _عقرب, ڕاده_, --, 
   {{0xd25000c6,0x44253ccd,0x00000000,0x00000000}},	//   خنة_, _dyl_, --, --, 
   {{0x7ce00428,0x44253cce,0x34840022,0x256400d8}},	//   _eôri, _eyl_, _нгаг, _натп_, 
   {{0x6298011c,0xddc4031c,0x4424a98d,0x7ce0143a}},	//   afuo, _ddiż, _fyl_, _fôri, 
   {{0xd1386b82,0x27000109,0x442400a2,0x00000000}},	//   rmą_, lŕna_, _gyl_, --, 
   {{0xd1380006,0xb6040841,0x00000000,0x00000000}},	//   smą_, _tršć, --, --, 
   {{0x44253ccf,0x7ce00109,0x0f0c012d,0x00000000}},	//   _zyl_, _zôri, _हदीस_, --, 
   {{0xa1113419,0xe7ec012c,0x442400ee,0x26c00064}},	//   _كونت, चनमा_, _yyl_, _ėjom_, 
   {{0x44240334,0x20d001f7,0x5064022e,0x00000000}},	//   _xyl_, _ستوج, _етқа, --, 
   {{0x2d9d3cd0,0x622000d1,0xe3c41bce,0x00000000}},	//   çues_, _تۈۋە, ññiy_, --, 
   {{0xdb2401ed,0xe84800d1,0xa8a461ac,0x00000000}},	// [1f470] írás, مجان_, зрек, --, 
   {{0x99d40594,0x2b4401c6,0xca300150,0x00000000}},	//   رتقا, _нэмг, _ﺨﺎﺼ_, --, 
   {{0x2d893cd1,0x5eb0015b,0x3aec00c7,0xa2bc0b98}},	//   luce_, টারে, _sýpe_, वयम्, 
   {{0x25bd3cd2,0x3aec0022,0x00000000,0x00000000}},	//   _prul_, _pýpe_, --, --, 
   {{0x442411d3,0xddc40171,0x5e9c00df,0x00000000}},	//   _syl_, _keiš, מבאק, --, 
   {{0x44253cd3,0x662000df,0xeabc0192,0x3aec00e4}},	//   _pyl_, _ĉukĉ, _thùs_, _výpe_, 
   {{0x2d880117,0x6298002d,0x7af80036,0x93247ba2}},	//   huce_, tfuo, ëttg, کرون, 
   {{0xddc53cd4,0x612c05ac,0x2d893cd5,0x86c401c8}},	//   _afiŝ, døla, kuce_, _تيرن, 
   {{0x05944a4b,0x25bc009a,0x44253cd6,0x7af80268}},	//   _تازگ, _urul_, _wyl_, ètti, 
   {{0xddc402d5,0x2d893cd7,0x6298ec01,0x3fe41985}},	//   _neiš, duce_, sfuo, джов, 
   {{0x44242112,0x612c0162,0x00000000,0x00000000}},	//   _uyl_, gøla, --, --, 
   {{0x2008054e,0xafe00166,0x00000000,0x00000000}},	//   ăci_, тоюл, --, --, 
   {{0x2d881326,0x1ccc025c,0xddc40064,0x80cc3ec5}},	//   guce_, _ྲོད_, _beiš, तादे, 
   {{0x3f6800f5,0x00000000,0x00000000,0x00000000}},	//   _дико_, --, --, --, 
   {{0x007c00d1,0x00000000,0x00000000,0x00000000}},	//   _ﻣﯘﺷﯘ, --, --, --, 
   {{0x2d893cd8,0x41d00490,0x290c0098,0xfaa4074d}},	//   buce_, _तपास, égan_, ьабо, 
   {{0x394447c1,0x00000000,0x00000000,0x00000000}},	// [1f480] днаг, --, --, --, 
   {{0x499834d8,0x37e4020a,0x3f853cd9,0x9774010b}},	//   ятся_, мозг, orlu_, етдә, 
   {{0xaa780432,0x62840153,0xca300150,0x00000000}},	//   _alýu, ėjoj, _ﺨﺎﺹ_, --, 
   {{0x66e00212,0x3f8400e8,0xf5240327,0x00000000}},	//   коха, irlu_, _སེངྒ_, --, 
   {{0xeabc01ab,0x65900214,0x3f84031c,0xb8642824}},	//   _thùr_, نجور, hrlu_, _ياسو, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x1ccc0327,0x3694013d,0x00000000,0x00000000}},	//   _ྲོན_, _ошас, --, --, 
   {{0x27e48784,0xaa7800a2,0x25a40451,0x6b94010e}},	//   ønne_, _flýu, _ڊگهي_, _çagş, 
   {{0xaa7800a2,0xf1dc01f9,0x00000000,0x00000000}},	//   _glýu, _फॅशन, --, --, 
   {{0x16041dd1,0x2d881505,0xaa780008,0x1c005360}},	//   _शेयर_, vuce_, _hlýt, ोपाल_, 
   {{0xddc40006,0x2d880198,0xb4e83f2c,0xb4a85219}},	//   _reiš, wuce_, मसी_, गजी_, 
   {{0x2d893cda,0xd6bc00fe,0x64300137,0xddc400ef}},	//   tuce_, _অকুপ, _شىنئ, _seiš, 
   {{0x3f853cdb,0x612c06ea,0x7bd81577,0x91c40166}},	//   arlu_, søla, ätun, _чәйл, 
   {{0x9cc8010b,0xee3c00a2,0x70500244,0x00000000}},	//   мыса_, leýk_, _جۆدا, --, 
   {{0x5c040006,0x2d883858,0xa0a000d8,0x00000000}},	//   вята, suce_, _рајд, --, 
   {{0xabb00022,0x9a8400db,0x00000000,0x00000000}},	//   наҳә, куул, --, --, 
   {{0x4428004d,0xddc40064,0x7d0c03b2,0x00000000}},	// [1f490] ́a_, _teiš, ónsá, --, 
   {{0xc8c813f5,0x6d5d3cdc,0x0bb40276,0x5a3485c0}},	//   राइट, _itqa, _збою, тнут, 
   {{0x007c0131,0x00000000,0x00000000,0x00000000}},	//   _ﻣﯘﺳﯘ, --, --, --, 
   {{0xaa7800a2,0x98b800c0,0x5c7c0240,0x00000000}},	//   _plýu, _mirę_, _እምነታ_, --, 
   {{0x7af80a40,0x7ce0003a,0x5a440006,0x29840139}},	//   ëtte, _eôru, _аэра, _юынг, 
   {{0x98c409fe,0x6d4806af,0x25ac0042,0x3f84015d}},	//   _иссл, _égau, rwgl_, yrlu_, 
   {{0xaa780008,0x6d5c0135,0x25fc01ad,0x9f5c01bf}},	//   _flýt, _ltqa, _शेरी_, _ærøs_, 
   {{0xaa7800a2,0xe63402dd,0x6d5c0139,0x00000000}},	//   _doýg, _قۋات_, _otqa, --, 
   {{0x73301e87,0x6d5c025c,0x75800214,0xaa78032e}},	//   دىيا, _ntqa, _مینم, _hlýs, 
   {{0xddc53cdd,0x67280200,0x41b40150,0x3cfc00c5}},	//   _afiş, llgj, _ۋمار, _उगें_, 
   {{0xd4993cde,0x2c1c0490,0x6d5c008e,0xaa78010e}},	//   _юрт_, _मुलं_, _atqa, _goýg, 
   {{0x2ca4e090,0x80cc0073,0x00000000,0x00000000}},	//   _ında_, ताहे, --, --, 
   {{0xfc440122,0xf8d02efd,0x00000000,0x00000000}},	//   číme_, सामय, --, --, 
   {{0x7bd8005b,0x290c0129,0x27240254,0x00000000}},	//   ätuo, égal_, mõnu_, --, 
   {{0x6d5d3cdf,0xfaa4016c,0xbea453ac,0xfe700066}},	//   _etqa, наво, _зайк, _یدک_, 
   {{0x1ccc0327,0xaa7800a2,0x00000000,0x00000000}},	//   _ྲོམ_, _noýd, --, --, 
   {{0x5a4401e0,0xf864005b,0x25fc0210,0xfd101a9b}},	// [1f4a0] тмағ, евзо, _शेली_, _مجد_, 
   {{0x3c644dba,0xee342912,0x3f8001e3,0xaa780c5e}},	//   _яког, _яны_, _åhus_, _blýs, 
   {{0x61f400ac,0xaa793ce0,0xdb2412ea,0x7c293ce1}},	//   _əxla, _boýd, _لودی, _хонг_, 
   {{0x6b780302,0xc8c801ad,0x419c02dd,0x0834009d}},	//   _צרכנ, राउट, _ﺃﺴﺎﺱ_, тхуя, 
   {{0x19440022,0xd944035b,0xc95520cb,0xaa78010e}},	//   _аҭан, _аҵаи, _атсы, _doýd, 
   {{0xb4e80b7d,0x853401b9,0x25fc0073,0x00000000}},	//   मसे_, نونچ, _शेळी_, --, 
   {{0x65780564,0xc7943c85,0xdec002d3,0xaa780413}},	//   _evuh, _ирты, ትሕን_, _glýs, 
   {{0x39493ce2,0xf744074d,0xaa793ce3,0xeb90010f}},	//   _hibs_, _чебо, _goýd, אָץ_, 
   {{0x39493ce4,0x5f900131,0xe5a13ce5,0x00000000}},	//   _kibs_, қият, _йити, --, 
   {{0x69f802e4,0x60f4005b,0x6908031c,0x00000000}},	//   פליק, енья_, rżeg, --, 
   {{0xa0a0005e,0x7bd88b82,0x612c2188,0xe1ec6ee9}},	//   ушыл, ätul, møll, لسی_, 
   {{0xb1840055,0x3948045a,0xe0cc0137,0xee3c0432}},	//   _adåų, _libs_, _ۇزى_, leýi_, 
   {{0x427401af,0x00000000,0x00000000,0x00000000}},	//   _рѳхс, --, --, --, 
   {{0xe7e000bc,0xee3c010e,0x00000000,0x00000000}},	//   कङमा_, neýi_, --, --, 
   {{0x67285f94,0xefc93ce6,0x80cc5572,0x290c00e8}},	//   ylgj, _хулк_, तारे, égam_, 
   {{0x612c06ea,0x27440241,0xb3240327,0x998400d7}},	//   høll, _mìnì_, རཞིང_, _šmš_, 
   {{0x7ce00268,0x6d5c03f0,0x612c072b,0x00000000}},	// [1f4b0] _côrs, _utqa, køll, --, 
   {{0x99840a2c,0x612c0feb,0xae7000d1,0x00000000}},	//   اللو, jøll, _جۇڭغ, --, 
   {{0x39481caa,0x1be4022e,0x2e380241,0x00000000}},	//   _dibs_, _бўяг, bàfé_, --, 
   {{0x39b00100,0xb6000118,0x3aec032e,0x497401a9}},	//   _fņs_, _čárk, _týpa_, _илмс, 
   {{0xa2bc06ff,0x69080171,0x00000000,0x00000000}},	//   वयस्, dļev, --, --, 
   {{0x6b813ce7,0x39484fc3,0xd618221c,0x00000000}},	//   _ångs, _gibs_, رتنا_, --, 
   {{0x2b48009f,0x947404fb,0x29000240,0xb4a800ab}},	//   _kicc_, ادها, _imja_, गड़े_, 
   {{0xaa78010e,0x00000000,0x00000000,0x00000000}},	//   _foýe, --, --, --, 
   {{0x2b48026c,0xc68c004b,0x612c005c,0xa50410de}},	//   _micc_, _هېڅ_, bøll, _كىرە_, 
   {{0xc0e4009b,0x00000000,0x00000000,0x00000000}},	//   тоок, --, --, --, 
   {{0x272400af,0x53a400c6,0x2900009f,0xf534008f}},	//   sõnu_, _مملك, _mmja_, _סטער_, 
   {{0x7bd80254,0xf40c02f2,0x00000000,0x00000000}},	//   ätum, _بڤه_, --, --, 
   {{0xdce404b9,0xee3400d4,0x00000000,0x00000000}},	//   _sviđ, кню_, --, --, 
   {{0x2b480649,0xda1c0cb4,0xaa78010e,0xc1040472}},	//   _aicc_, _भुगत_, _noýb, _جوتي, 
   {{0xeb953ce8,0x39493ce9,0x69c801bf,0x00000000}},	//   кир_, _ribs_, ågen, --, 
   {{0x6a8005f5,0x69c00882,0x26dc0381,0x39b0007f}},	//   илса, ānen, _nouo_, _pņs_, 
   {{0xaa7800a2,0x00000000,0x00000000,0x00000000}},	// [1f4c0] _boýb, --, --, --, 
   {{0xa9a001b9,0xfe1c0b27,0x00000000,0x00000000}},	//   рифд, _युएस_, --, --, 
   {{0xdce40384,0x612c022c,0x68e0553f,0xeabc0248}},	//   _uviđ, vøll, önda, _ikùn_, 
   {{0x6d493cea,0x224c0263,0x27e42dba,0xaa78010e}},	//   _égar, _nggk_, ønna_, _poýe, 
   {{0x6b8001e6,0xdb24114f,0x00000000,0x00000000}},	//   _ångr, _لوگی, --, --, 
   {{0xaa780209,0x394805ac,0x8b6401d5,0x00000000}},	//   _goýb, _uibs_, _جایم, --, 
   {{0x925800cf,0xb6f800db,0x3cf8012d,0xaa7800a2}},	//   найт_, _قىسا_, _उतने_, _woýe, 
   {{0x66e13ceb,0x7af40158,0x98a40153,0x00000000}},	//   _коса, nhyt, _ėmę_, --, 
   {{0x66e0e9ed,0xe6940364,0x754400c7,0xab8c0023}},	//   _тота, _шурӯ, _аназ, _ዝውዕል_, 
   {{0x64a0b392,0x3db800cc,0x3364022e,0x00000000}},	//   _вафа, ুহাল, _авжг, --, 
   {{0xd3e40acb,0x0fd00eac,0x7af4007c,0xd01000ae}},	//   _حقای, ান্ধ, khyt, صلح_, 
   {{0xb8ec025c,0xf1a400c7,0x00000000,0x00000000}},	//   _ྱལ_, _аркн, --, --, 
   {{0x7af40fac,0xa2f4011a,0x80bc17ee,0x00000000}},	//   dhyt, _במאה_, _वोके, --, 
   {{0x48bc00bd,0x7af40fac,0x00000000,0x00000000}},	//   _আক্র, ehyt, --, --, 
   {{0x2b480de2,0x5c7400d8,0x00000000,0x00000000}},	//   _picc_, рлст, --, --, 
   {{0x29f00a28,0xeabc0241,0x80c803d4,0x7af46f66}},	//   ṇam_, _ekùn_, াউণ্, ghyt, 
   {{0x2b4801d3,0x81400133,0x7bd80162,0x00000000}},	// [1f4d0] _vicc_, _خۆین, øtur, --, 
   {{0x2b493cec,0x6908012d,0x00000000,0x00000000}},	//   _wicc_, dżec, --, --, 
   {{0x26dc06c8,0x612c1477,0xb7841945,0x2b48002e}},	//   _pouo_, følj, ләте_, _ticc_, 
   {{0x7af40232,0x2ca000cc,0x00000000,0x00000000}},	//   chyt, lfjd_, --, --, 
   {{0x6908003d,0x44300010,0x64700022,0x5694004e}},	//   rżeb, _šz_, иҳау, рачт, 
   {{0x2d883e7c,0x03940166,0xd4c400d1,0x00000000}},	//   irce_, грия, لغىي, --, 
   {{0x212405b1,0x00000000,0x00000000,0x00000000}},	//   _rknh_, --, --, --, 
   {{0x99680014,0x5c380375,0x425433ae,0x00000000}},	//   _سمہٕ_, כרון_, دنظر, --, 
   {{0x67380526,0xe8fc0086,0x0614005b,0x43940150}},	//   _ihuj, _itûb_, _сдаю, _ﯛﺷﯩﻦ_, 
   {{0x6618014b,0x7fd40220,0x4174485f,0x7bd80108}},	//   _ixuk, гімі, پاکس, ätuk, 
   {{0x2d88014b,0x312001c6,0x7af401f4,0x00000000}},	//   erce_, сдэг, yhyt, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6738009f,0x2fd400f2,0xcd3000d1,0xed54014b}},	//   _mhuj, نوید_, ﺸﻨﯩﯔ_, лоя_, 
   {{0x61f93ced,0x4d14074d,0x00000000,0x00000000}},	//   mzul, аьст, --, --, 
   {{0x2d889dfd,0x80c80154,0x61f8002f,0x7af4b4fe}},	//   arce_, াউদ্, lzul, thyt, 
   {{0x29100472,0xcfd000fe,0x00000000,0x00000000}},	//   enxa_, ানখন, --, --, 
   {{0x61f8c111,0x4a753cee,0x7af49af9,0x20b4b702}},	// [1f4e0] nzul, рыст, rhyt, _असाध, 
   {{0x67380526,0xd9113cef,0x7af403cd,0x61f8005a}},	//   _ahuj, زیز_, shyt, izul, 
   {{0x7e741bb0,0x673800dc,0x77853cf0,0x6b80007c}},	//   _keyp, _bhuj, улез, _ångp, 
   {{0x29100054,0x67393cf1,0x61f8020b,0x7e7400e4}},	//   anxa_, _chuj, kzul, _jeyp, 
   {{0x6738020c,0x61f80023,0xec103b7a,0xdcc8012c}},	//   _dhuj, jzul, _نوید, िएपछ, 
   {{0x7e753cf2,0x61f93cf3,0xf75430a7,0x81a80154}},	//   _leyp, dzul, _منسج, খটা_, 
   {{0x66180472,0xdec0001f,0x73493cf4,0x7bd80108}},	//   _exuk, ትንና_, нчив_, ätuh, 
   {{0x81cc015b,0x61f80112,0x91c401e0,0x7e740064}},	//   রহন_, fzul, иҙел, _neyp, 
   {{0xdce4006d,0x50f42218,0x61f8002f,0xe6140064}},	//   _zwią, изит, gzul, _бдт_, 
   {{0x67393cf5,0x2d8805ce,0x69c0033f,0x00000000}},	//   _zhuj, vrce_, łneg, --, 
   {{0x3364026a,0x251808a8,0xe8d40a7c,0x7e7403e0}},	//   _свег, _טומא, אויר_, _beyp, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2d893cf6,0xaa78010b,0x62840153,0x61f8012d}},	//   urce_, _noýa, ėjot, czul, 
   {{0x2d88062c,0xf07401af,0x00000000,0x00000000}},	//   rrce_, _сикә_, --, --, 
   {{0x2d880b4b,0xc0f4001f,0x2c1c00dc,0x00000000}},	//   srce_, ገኝም_, _मुखं_, --, 
   {{0xaa78010b,0xae98007b,0x00000000,0x00000000}},	//   _boýa, _أضغط_, --, --, 
   {{0x3c1001ed,0xe9dc0208,0xdfcc0137,0x91f400bc}},	// [1f4f0] tővé_, _ngút_, _ويۇ_, इनिज_, 
   {{0x67393cf7,0xd8740137,0xaa78010e,0x53b401ad}},	//   _shuj, مامب, _doýa, ंबाश, 
   {{0x61f808e5,0x7e74009a,0x399c00e4,0x00000000}},	//   zzul, _yeyp, tãsã_, --, 
   {{0x6618022e,0x899401af,0xf3f800eb,0x7bd80677}},	//   _pxuk, _кимє, ইপার_, _סקרו, 
   {{0xaa7800ee,0x1efc010f,0x25fc000d,0x69c8005c}},	//   _goýa, עלדע, _शेखी_, æged, 
   {{0x61f8a67c,0xbf0052f2,0x03b400ae,0x00000000}},	//   vzul, _लग्न_, لإبد, --, 
   {{0x67393cf8,0x61f801f7,0x82f40063,0x00000000}},	//   _thuj, wzul, ичиц, --, 
   {{0x61f93cf9,0x67393cfa,0x661801c6,0x41a88726}},	//   tzul, _uhuj, _txuk, ввин_, 
   {{0x61f93cfb,0x66180113,0x7194004b,0x7e753cfc}},	//   uzul, _uxuk, لنيز_, _reyp, 
   {{0x61f93cfd,0x7e74014f,0x410499a4,0x00000000}},	//   rzul, _seyp, рзов, --, 
   {{0x61f93cfe,0x7e740784,0x8cd909f5,0x00000000}},	//   szul, _peyp, मानो, --, 
   {{0xfe443f51,0xeabc0165,0x00000000,0x00000000}},	//   инно, _naù_, --, --, 
   {{0x2164b7f5,0x612c0174,0x41a8000d,0xef140395}},	//   _стег, høli, _कहिस, рмя_, 
   {{0x68e001a8,0x612c005c,0x78a001a6,0x225ce0ea}},	//   öndl, køli, đovk, lcuk_, 
   {{0x7af80036,0xaa78010e,0x612c6066,0x5eb00154}},	//   ëtto, _soýa, jøli, য়াবে, 
   {{0x225d3cff,0x41a80cb4,0x80cc00af,0x2c800213}},	//   ncuk_, _कहास, ताके, _açdı_, 
   {{0x5f4400dd,0x2d4c0327,0xb9040408,0xb8540063}},	// [1f500] _پچھل, _iżen_, азак, ађењ, 
   {{0xe8f53d00,0x394c01e3,0x00000000,0x00000000}},	//   алу_, öfs_, --, --, 
   {{0xcaa400d1,0xbd4400ec,0x7aa401f4,0x49000733}},	//   شلەۋ, _ٽنگي, _кинз, чүрг, 
   {{0x38780ffb,0xaa7800a2,0xb6a401d5,0x00000000}},	//   sapr_, _toýa, ридл, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x612c03b2,0x69080210,0x00000000,0x00000000}},	//   bøli, lżen, --, --, 
   {{0x2ca403ee,0xb6000327,0x00000000,0x00000000}},	//   _önde_, _ġġud, --, --, 
   {{0xf1a53d01,0x16040490,0x27e40822,0xb1a40798}},	//   арон, _शेअर_, änne_, ашок, 
   {{0xe8fc0295,0xeabc0051,0x7164007b,0x00000000}},	//   _iwûr_, _chùy_, جابك, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc1b801c0,0xe934010f,0xdef80023,0xbb2c0150}},	//   влөх_, שניץ_, ገጽን_, _ﺩﻭﻡ_, 
   {{0x2324013e,0xa3c00807,0x7af804e6,0x71a40006}},	//   _кохи_, एटर_, ëttl, _вадз, 
   {{0xaa78010b,0xe1f400f5,0x00000000,0x00000000}},	//   _boýn, _кгц_, --, --, 
   {{0x61406147,0x69080210,0x00000000,0x00000000}},	//   _деча, eżen, --, --, 
   {{0x81cc09bd,0xdb593d02,0x7bc802d2,0x00000000}},	//   রহণ_, иют_, _áful, --, 
   {{0xa3d451a5,0x4a553d03,0x8e8400c6,0x00000000}},	//   ामत_, скас, _الظه, --, 
   {{0x4c953d04,0x00000000,0x00000000,0x00000000}},	// [1f510] _липс, --, --, --, 
   {{0xe8493d05,0xaa78010b,0x29053d06,0x4cb80a89}},	//   نجان_, _goýn, òna_, _слою_, 
   {{0xe2880118,0x69c801bf,0xd87400cf,0x00000000}},	//   íčků_, ægeb, زالب, --, 
   {{0x31640210,0x00000000,0x00000000,0x00000000}},	//   _otoz_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x438400c6,0x437400d8,0x00000000,0x00000000}},	//   ملتق, буит, --, --, 
   {{0x31648d68,0x5eb0015b,0x13680640,0xf8b0011a}},	//   _atoz_, য়াতে, ашњи_, _משם_, 
   {{0x56943a22,0x82346e0d,0x53c400d1,0xa1f000d1}},	//   _маст, یرکا, ززىق, يۋات, 
   {{0x7dcc006a,0x2248049f,0xa4845a9d,0xe7ec012c}},	//   _môsô, äck_, _نجان, चनका_, 
   {{0xa3d411b1,0xa2b00b02,0xbb2c0150,0x00000000}},	//   ामद_, _आसक्, _ﺩﻭﻤ_, --, 
   {{0x90e401ec,0x1ee80811,0xaa7800a2,0x6908012d}},	//   تسين, لودی_, _noýo, yżen, 
   {{0xeabc001e,0x612c0158,0x78a0009b,0x53b401ad}},	//   _thùy_, jølv, đovi, ंबरश, 
   {{0x01653d07,0xdce40034,0x4ae032ed,0x00000000}},	//   _укло, _zwię, _नवजव, --, 
   {{0x63a0022f,0xdb1c00d7,0x5d0800c7,0x61401870}},	//   otnn, dvrá, рҭон_, _بىتە, 
   {{0x7dcc145e,0xa3d40a28,0x7f840491,0x0b581def}},	//   _bôsô, ामि_, _البن, ирты_, 
   {{0xdb0801b8,0x00000000,0x00000000,0x00000000}},	//   _älük, --, --, --, 
   {{0xaa403e1f,0x69083af2,0xaa780432,0x301001ee}},	// [1f520] зетл, rżen, _toýn, _мдәр, 
   {{0xa3d53d08,0x23b40574,0xb4b40490,0x00000000}},	//   ामा_, _आनंद, _जसे_, --, 
   {{0x27fc03f9,0x80a800dc,0x2d8402b5,0x7d0c017a}},	//   _ƙuna_, ज्ये, _ānei_, mibs, 
   {{0x7d0d3d09,0x7bd80108,0x00000000,0x00000000}},	//   libs, ätuu, --, --, 
   {{0xbc3800e5,0x00000000,0x00000000,0x00000000}},	//   _جسکا_, --, --, --, 
   {{0x69080327,0xb8f4007b,0x7d0c4831,0x00000000}},	//   nżel, _اكسب, nibs, --, 
   {{0x31640421,0x3aec00a2,0x00000000,0x00000000}},	//   _stoz_, _aýpi_, --, --, 
   {{0x7ae48d0f,0x7d0c03b9,0x00000000,0x00000000}},	//   _jokt, hibs, --, --, 
   {{0x7ae46327,0x799402d1,0x612c0162,0x00000000}},	//   _mokt, nuyw, hølu, --, 
   {{0x3aec0d12,0x7ae53d0a,0x60f402d5,0x7d0c0009}},	//   _dýpi_, _lokt, йныя_, jibs, 
   {{0xe4d45a1a,0xdce46f39,0x128804fb,0x79940113}},	//   _دولت_, _etiċ, _نمای_, huyw, 
   {{0x799403f0,0x2ec000cd,0xf59c0240,0x00000000}},	//   kuyw, षयेत, _ዋርድያ_, --, 
   {{0x612c0162,0x00000000,0x00000000,0x00000000}},	//   vølv, --, --, --, 
   {{0x7d0c002f,0xb4b400bc,0xdd58009d,0x8cd80b67}},	//   gibs, _जसो_, сарч_, माधो, 
   {{0xe7e02f8b,0x7ae53d0b,0x3cf80c2e,0x00000000}},	//   _মধ্য, _bokt, _उतरे_, --, 
   {{0x7ae53d0c,0x799401f0,0xaa7800ee,0xca2001ec}},	//   _cokt, fuyw, _goýl, _ﺸﻬﺭ_, 
   {{0x7d0c00c6,0x6f0d3d0d,0x7994009a,0x00000000}},	// [1f530] bibs, micc, guyw, --, 
   {{0x6f0d3d0e,0x7d0c0369,0x6b4c01e1,0x612c143a}},	//   licc, cibs, _bògì, sølv, 
   {{0x7ae40093,0xa4200eac,0xc690001f,0xc6b40092}},	//   _fokt, _পণ্য_, _ከምርጫ_, _ለምርጫ_, 
   {{0x6f0d3d0f,0x79944b2a,0x9f5c0158,0x41a8007d}},	//   nicc, buyw, _årås_, _कहलस, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6f0d3d10,0x7ae40165,0x6d44033b,0x293400d1}},	//   hicc, _zokt, nmja, ﻗﯘﭖ_, 
   {{0x7ae40365,0x7b000724,0x6f0c568a,0xc05803e6}},	//   _yokt, _äytü, kicc, یشدا_, 
   {{0x68e40030,0x01640120,0x7d0c01a9,0xddc400de}},	//   _hojd, окио, zibs, _reiž, 
   {{0x4428006d,0x0edc038e,0xfd600241,0x69c002b5}},	//   ła_, यानड, _dawọ, ānew, 
   {{0x6728069c,0x25bc0014,0x68e4047e,0xaa78010e}},	//   logj, _isul_, _jojd, _soýl, 
   {{0x68e53d11,0x6f0d3d12,0xd9d0013f,0xd54800cf}},	//   _mojd, ficc, _ɑnɑɑ, _اللو_, 
   {{0x68e40455,0x6f0c00b5,0x63b00022,0x6d44000d}},	//   _lojd, gicc, _маҷӡ, emja, 
   {{0x62440014,0x7ae432bd,0x63640205,0x7d0c571b}},	//   _آشہ_, _rokt, _bıng, tibs, 
   {{0x68e4014f,0x6298000f,0x7ae405d1,0x7994009a}},	//   _nojd, lguo, _sokt, vuyw, 
   {{0x6f0cc044,0x7d0d3d13,0x60c001ab,0xaa78010b}},	//   bicc, ribs, _ianm, _toýl, 
   {{0x6f0d3d14,0xeb940474,0x672825a9,0xba180d2f}},	//   cicc, юис_, jogj, ليزا_, 
   {{0x60c13d15,0xaa780209,0x612c06ea,0x68e40427}},	// [1f540] _kanm, _goým, sølu, _bojd, 
   {{0x60c13d16,0x00000000,0x00000000,0x00000000}},	//   _janm, --, --, --, 
   {{0x60c13d17,0x7ae42af2,0x25bd3d18,0x68e4ea1f}},	//   _manm, _tokt, _asul_, _dojd, 
   {{0x60c044d1,0x27e4049f,0x7c3cc7da,0x7c940b29}},	//   _lanm, änna_, _izpr, _اشکا, 
   {{0x60c0334b,0x79940784,0x16040bc0,0x62ec009e}},	//   _oanm, quyw, _शेखर_, টফাট_, 
   {{0x60c13d19,0xf3653d1a,0x6f0c0268,0xdce416a3}},	//   _nanm, отин, zicc, _otič, 
   {{0x6298002d,0xdb1c005c,0x63640205,0xa3e400c7}},	//   fguo, rvræ, _nınd, жьыз_, 
   {{0x60c03441,0x91c400fd,0x6f0c02d0,0x6fe806be}},	//   _aanm, зәкл, xicc, həcc, 
   {{0x60c10435,0x6f0d3d1b,0xc5ec004b,0x68e40477}},	//   _banm, vicc, _مړو_, _yojd, 
   {{0x60c13d1c,0x30e800fb,0x63641ea0,0x612c00b5}},	//   _canm, рфин_, _bınd, døls, 
   {{0x60c13d1d,0x6f0d3d1e,0x8f3400c7,0xb4b40034}},	//   _danm, ticc, зенц, ज़ी_, 
   {{0xceb91de3,0x60c0127b,0x612c072b,0x63640139}},	//   сәк_, _eanm, føls, _sıng, 
   {{0x60c0505b,0x6f0d3d1f,0x7c3c03b9,0x00000000}},	//   _fanm, ricc, _azpr, --, 
   {{0x60c13d20,0x80a005f9,0x6364029f,0xaa780432}},	//   _ganm, _खाये, _fınd, _goýj, 
   {{0x6f0d3d21,0x5f700a52,0x63640139,0x67280066}},	//   picc, _قاير, _gınd, yogj, 
   {{0x60c13d22,0xda0c006d,0x68e4045d,0x3cf80477}},	//   _zanm, _सेहत_, _sojd, _elpv_, 
   {{0x60c13d23,0x68e53d24,0x63649ca3,0x88940395}},	// [1f550] _yanm, _pojd, _tıng, зизх, 
   {{0xeea001ec,0x60c006be,0xa86800c7,0x00000000}},	//   _ﺃﻋﻠﻥ_, _xanm, ршаз_, --, 
   {{0x5eb00154,0x68e40419,0x9f04136e,0x9ee800e5}},	//   য়ারে, _vojd, _رویو, _طفیل_, 
   {{0xd7c8004b,0x68e53d25,0x28dc0210,0x00000000}},	//   غونه_, _wojd, पॉजि, --, 
   {{0x6728547b,0x68e4022e,0xc1a8012d,0xb4b4012d}},	//   rogj, _tojd, _कहेग, ज़ू_, 
   {{0x9f453d26,0x69cd3d27,0x04c800ec,0xd1d40092}},	//   ájú_, _irce, صوبي_, ጭነት_, 
   {{0x60c13d28,0x6298002d,0x442002d1,0xd7f800d8}},	//   _ranm, tguo, çh_, _дут_, 
   {{0xdce40010,0x63640166,0xae182982,0x00000000}},	//   _rtič, _rınd, नपान_, --, 
   {{0x93240128,0x60c13d29,0xdce53d2a,0x6364b8f1}},	//   برون, _panm, _stič, _sınd, 
   {{0xdce41a48,0xf5a8012c,0x60c13d2b,0xaa7800a2}},	//   _ptič, ížeč_, _qanm, _boýk, 
   {{0x60c13d2c,0x6d480129,0x636406be,0x00000000}},	//   _vanm, _égay, _qınd, --, 
   {{0x69cc0c8c,0xdce409a8,0x60c00784,0xf438011a}},	//   _orce, _vtič, _wanm, _התעש, 
   {{0x60c13d2d,0xf2d0008f,0x7338008f,0x7c3c012d}},	//   _tanm, _רעד_, _פענס, _szpr, 
   {{0x66d40a28,0xb6040308,0xa3cc0d0a,0x60c0332e}},	//   ḥkha, _ukáž, शिप_, _uanm, 
   {{0x69cd3d2e,0xdce42aef,0x82b8003d,0x69c8005c}},	//   _arce, _utič, _དྲོའ, ægen, 
   {{0x612c28b3,0x7c3c1155,0x00000000,0x00000000}},	//   pøls, _vzpr, --, --, 
   {{0x8cd8033f,0x38593d2f,0x00000000,0x00000000}},	// [1f560] माशो, مشاد_, --, --, 
   {{0x49981c31,0x69cc0118,0x2de400f1,0x00000000}},	//   ются_, _drce, _روپۍ_, --, 
   {{0x69cc0c8c,0x02bc228a,0x3f853d30,0x63640205}},	//   _erce, ्याभ, nslu_, _yıne, 
   {{0x628c67ca,0x6aac010a,0x7e6401f5,0xa3cc2c2e}},	//   ócol, _gbcf, nckp, शिन_, 
   {{0x69cc0fcf,0x5be401d9,0x69c80267,0x82b80327}},	//   _grce, _رتھہ, åget, _དྲེའ, 
   {{0x3f841039,0xb4b4033f,0xa9653d31,0xa3d400cd}},	//   kslu_, ज़े_, _хира_, ामं_, 
   {{0x7af80036,0x366801a9,0x00000000,0x00000000}},	//   ëttw, _габо_, --, --, 
   {{0x7af53d32,0x3aec02d2,0x00000000,0x00000000}},	//   nkyt, _týpu_, --, --, 
   {{0x7af400c0,0x00000000,0x00000000,0x00000000}},	//   ikyt, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa3d40882,0xce9402e8,0x3f8408ce,0x00000000}},	//   ामः_, манъ, gslu_, --, 
   {{0xf1a804d3,0x00000000,0x00000000,0x00000000}},	//   _هاته_, --, --, --, 
   {{0xe2953d33,0xc30406c2,0x00000000,0x00000000}},	//   _хач_, _تبلو, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xef641d18,0xfcc00022,0x00000000,0x00000000}},	//   _эъло, тәым, --, --, 
   {{0x6efc0036,0x636403e0,0x69cc01ef,0xd138bfb6}},	//   _bëbe, _hınc, _prce, llą_, 
   {{0x88e401ec,0xd1380064,0x00000000,0x00000000}},	// [1f570] _ﺍﻷﺭﻀ, olą_, --, --, 
   {{0x98b80006,0xa3cc0a8a,0x00000000,0x00000000}},	//   _mirė_, शिम_, --, --, 
   {{0x6d5c02d1,0x0a58013e,0x6d5403ac,0x47d4027d}},	//   _huqa, _манъ_, _iixa, بيار, 
   {{0x6d5c0928,0x6aac0998,0x69cc01fa,0x69c801e6}},	//   _kuqa, _ubcf, _trce, åges, 
   {{0x69cd3d34,0xd13802d5,0x6d5c0455,0x9f5401e3}},	//   _urce, klą_, _juqa, _åxå_, 
   {{0x6d5d3d35,0x3f853d36,0x6efc002e,0x6d5401a9}},	//   _muqa, yslu_, _jëbb, _jixa, 
   {{0x6d553d37,0x6d5d3d38,0x68e00008,0x6fe80213}},	//   _mixa, _luqa, öndu, yəca, 
   {{0x6d553d39,0x2910004b,0x99680014,0xd138012d}},	//   _lixa, lixa_, _ذمہٕ_, elą_, 
   {{0x6d5c3959,0x7f540784,0xb39802d3,0x00000000}},	//   _nuqa, _riyq, _ወይውን_, --, 
   {{0x51440046,0x65781ab4,0x29100bc9,0x3f853d3a}},	//   ндығ, _iwuh, nixa_, tslu_, 
   {{0xbfd800c6,0x6d5c02d1,0x7af40108,0x00000000}},	//   _ỗỗớ_, _auqa, ykyt, --, 
   {{0x3f84bb00,0x6d5400db,0x62880067,0x7f5401a9}},	//   rslu_, _aixa, _udgo, _qiyq, 
   {{0x29102e95,0x6efc00e8,0xfd740588,0x6d5d3d3b}},	//   kixa_, _bëbb, ьынџ, _cuqa, 
   {{0x6d5d3d3c,0x29100054,0x657800ca,0x246400e8}},	//   _duqa, jixa_, _mwuh, _jёm_, 
   {{0x6efc002e,0x2910005a,0x7af40108,0x00000000}},	//   _dëbb, dixa_, tkyt, --, 
   {{0x6d5c006c,0x6d540137,0x4424067c,0x2910d829}},	//   _fuqa, _eixa, _mxl_, eixa_, 
   {{0x7af4e720,0xfe453d3d,0x442400d8,0x29100381}},	// [1f580] rkyt, _юнио, _lxl_, fixa_, 
   {{0x7af53d3e,0xaa400220,0x6d54005a,0x291001c4}},	//   skyt, теул, _gixa, gixa_, 
   {{0x65793d3f,0x7ae000c5,0x69c8007c,0x00000000}},	//   _awuh, öots, åger, --, 
   {{0x6d5c4f6b,0x6d540944,0x6efc002e,0x00000000}},	//   _yuqa, _zixa, _tëbe, --, 
   {{0xd5b012dd,0x2910005a,0x3eb00240,0x4eac008f}},	//   افت_, bixa_, _mbyt_, מבאַ, 
   {{0x29100077,0x6d540561,0xb4b00116,0x79940042}},	//   cixa_, _xixa, тикә, mryw, 
   {{0x6578209c,0x44245c5e,0x53353d40,0xaa7800a2}},	//   _ewuh, _cxl_, нект, _soýi, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd1b0b9ff,0x79940042,0xf20401f4,0x00000000}},	//   ایتک, nryw, ьяко, --, 
   {{0x442419f5,0x6d5d3d41,0x2d9c067c,0x98b800c0}},	//   _fxl_, _ruqa, àuem_, _virė_, 
   {{0x6d5406e4,0xb064013d,0x6efc00e8,0x6d5d3d42}},	//   _rixa, _ahäñ, _rëbb, _suqa, 
   {{0x6d553d43,0x79953d44,0x29113d45,0x6d5ca3ff}},	//   _sixa, kryw, zixa_, _puqa, 
   {{0xa2d002dd,0xcca42002,0x3eb00076,0x6d5cca3c}},	//   _جينت, ىڭدى, _dbyt_, _quqa, 
   {{0x79953d46,0x6d54208d,0x3dd00042,0xb030104e}},	//   dryw, _qixa, _dryw_, _имлә, 
   {{0x636405d1,0x0ef80408,0x6d540055,0x00000000}},	//   _kına, _некъ_, _vixa, --, 
   {{0xa3cc23ef,0x2910094a,0x6d553d47,0x09b8031c}},	//   शित_, wixa_, _wixa, _ཙརྱ_, 
   {{0x1ed8b745,0x6d553d48,0x2910094a,0x79953d49}},	// [1f590] _زبيب_, _tixa, tixa_, gryw, 
   {{0x657800ca,0x3eb00034,0x00000000,0x00000000}},	//   _rwuh, _zbyt_, --, --, 
   {{0x29180952,0x29100bc9,0xef1c04cc,0x00000000}},	//   ﺴﯩﭗ_, rixa_, onü_, --, 
   {{0x29113d4a,0x3de400cc,0xef1c06be,0x00000000}},	//   sixa_, _পেটল, nnü_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa3c00316,0x2910094a,0x44240334,0x04440a0e}},	//   _září_, qixa_, _pxl_, нелн, 
   {{0xeabc08e7,0x44250a47,0xf4842bd9,0x57a4ed16}},	//   _ijùb_, _qxl_, راوی, _ишта, 
   {{0xe0b8015b,0x44253d4b,0xf770011a,0x00000000}},	//   _অচেন, _vxl_, _תקן_, --, 
   {{0x65793d4c,0x606000d1,0x00000000,0x00000000}},	//   _uwuh, نۇشل, --, --, 
   {{0x31213d4d,0xa3cc02ab,0x442404ce,0x3fe49842}},	//   лдыг, शिद_, _txl_, ежов, 
   {{0x3ea53d4e,0x7994068f,0xbea424db,0xf8b00a7c}},	//   нинг, zryw, нанк, נשט_, 
   {{0xef1c07de,0x63640139,0x1cb80327,0x94045dc6}},	//   gnü_, _gına, _ཛིང_, _جومه, 
   {{0x0d800831,0xa3d4166d,0x6fe806be,0x00000000}},	//   аһын, ामक_, ləcl, --, 
   {{0x7994017a,0x7c38000d,0x00000000,0x00000000}},	//   vryw, ütro, --, --, 
   {{0x3dd00142,0x00000000,0x00000000,0x00000000}},	//   _wryw_, --, --, --, 
   {{0x7994684b,0x636403e3,0x7bcc01e3,0x00000000}},	//   tryw, _xına, rvbu, --, 
   {{0x394406ae,0xdbcc0241,0x79940142,0x69c801e3}},	// [1f5a0] енаг, _pòór, uryw, ågep, 
   {{0x02bc1025,0xe8c53d4f,0xa9640b01,0x0928009a}},	//   ्युन, нгул_, хифа_, وسلي_, 
   {{0x7a6807d6,0x2a680175,0x6c780375,0x7af801c7}},	//   _нинг_, _ffcb_, _מאיפ, ëtts, 
   {{0xaa780510,0xb5a80491,0x3cdc00af,0x6d493d50}},	//   _boýu, كاتك_, खावे_, _ègar, 
   {{0x6720020c,0x00000000,0x00000000,0x00000000}},	//   énja, --, --, --, 
   {{0x63644952,0x6efc00e8,0x98a40024,0xaa780432}},	//   _sına, _mëba, _ėmė_, _doýu, 
   {{0x636405d1,0x69201bc4,0x02bc8004,0x24540022}},	//   _pına, _смра, ्यून, нашь_, 
   {{0x3dc01390,0xaffc004d,0x63640213,0x320821f3}},	//   kwkw_, _ngướ, _qına, зхон_, 
   {{0xaa7809a5,0x00000000,0x00000000,0x00000000}},	//   _goýu, --, --, --, 
   {{0x27d40014,0xdb1c0158,0xb7e02cc5,0x73e400d8}},	//   _تِہج_, avrø, পনীয়, _позз, 
   {{0xe3ac009e,0x80a000bc,0x63641ea0,0x00000000}},	//   কিউব, _खारे, _tına, --, 
   {{0x42a40023,0x43740117,0x00000000,0x00000000}},	//   _ዉጽኢት_, _руфт, --, --, 
   {{0x9df80801,0xef1c07de,0x91c400fb,0xadb419c5}},	//   енят_, rnü_, _рәйл, رۇدا_, 
   {{0xef1c3361,0x00000000,0x00000000,0x00000000}},	//   snü_, --, --, --, 
   {{0x3fc457aa,0xf8cc00c5,0xdbcc01e1,0x6538010f}},	//   _арығ, _होइय, _sòòr, פעלד, 
   {{0xfb38001f,0x00000000,0x00000000,0x00000000}},	//   _የቴክኒ, --, --, --, 
   {{0x199400ee,0x4a54b1da,0x00000000,0x00000000}},	// [1f5b0] латя, ткас, --, --, 
   {{0xab600ed1,0x3fa4003a,0x5a3421db,0xe7840114}},	//   _مۇسى, _æquè_, унут, еудо, 
   {{0x2d88068f,0x3cdcacd2,0x69080034,0xb7840daf}},	//   lsce_, खारे_, dżet, кәте_, 
   {{0xa3cc6407,0xdbcc01e1,0x8cd80118,0x00000000}},	//   शिस_, _tòòr, माको, --, 
   {{0x6efc002e,0x970401d9,0x7be40356,0xa61000c7}},	//   _xëba, دِنى, ăruş, ыздә, 
   {{0x2d893d51,0x00000000,0x00000000,0x00000000}},	//   isce_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x02bc739b,0xb9ec0023,0xaa78010b,0x00000000}},	//   ्येन, _ሓቁ_, _toýu, --, 
   {{0x2d88068f,0x5694010b,0x059400db,0xf2c0009d}},	//   jsce_, _щатт, _جازگ, рөхи, 
   {{0xe6900184,0x0518007b,0x00000000,0x00000000}},	//   _шиғы, _غياب_, --, --, 
   {{0x24841d59,0xddc40276,0x2d88f225,0x6efc0240}},	//   manm_, _ofiţ, esce_, _sëba, 
   {{0xaa7800a2,0x248400a2,0x00000000,0x00000000}},	//   _moýs, lanm_, --, --, 
   {{0xceb40184,0x9d18037e,0x3cdc00bc,0xa3cc16ae}},	//   уҙы_, _hがin, खाले_, शिव_, 
   {{0xed553d52,0xd1cc001f,0xc2c40451,0x24840100}},	//   коя_, _ጠብቆ_, _سيڪي, nanm_, 
   {{0xff242c1d,0x7090041b,0xeff00023,0x00000000}},	//   _имко, _тајф, ፍተይ_, --, 
   {{0x24840100,0xc0dc0092,0x00000000,0x00000000}},	//   hanm_, ንዱም_, --, --, 
   {{0xbb5000b5,0xf1c805f7,0xfd100aaa,0xaa7800a2}},	// [1f5c0] _canは_, mráð_, _نجد_, _roýt, 
   {{0xbd880014,0x24840100,0xd8840214,0xf1c80162}},	//   _ٹنگن_, janm_, اهای, lráð_, 
   {{0x24845062,0xc8b53d53,0xdb240b28,0x3b080a5b}},	//   danm_, ысты, _مودی, _жено_, 
   {{0x98b800c7,0x02bc00dc,0x00000000,0x00000000}},	//   _mirĩ_, ्योन, --, --, 
   {{0xa2b53d54,0xb8653d55,0x248402e2,0x00000000}},	//   ्जन्, _لازو, fanm_, --, 
   {{0xa5303981,0x24840100,0x00000000,0x00000000}},	//   аніч, ganm_, --, --, 
   {{0x3ce80220,0x580410cf,0xaa780432,0xc17c0092}},	//   _ءﻭﺯ_, _совғ, _goýs, _የሐረሪ_, 
   {{0xf59400c6,0x63640139,0x81cc03d4,0x316800db}},	//   _للرج, _tınn, ৰহন_, мшоо_, 
   {{0x71440150,0x00000000,0x00000000,0x00000000}},	//   кхож, --, --, --, 
   {{0xa3cc09d9,0xdb1c000f,0xaa78010e,0xc4c41291}},	//   शिश_, nwrâ, _inýe, _متمو, 
   {{0xe1ec08f0,0x251808a8,0x2ca4013d,0xe2c405af}},	//   مسی_, _קובא, _öndi_, رویو_, 
   {{0xa3cc1fd2,0x69080210,0xf1c8032e,0x00000000}},	//   शिर_, nżer, gráð_, --, 
   {{0x2d880381,0x716400db,0x71f806c2,0x9da8011c}},	//   usce_, _شاشك, _تراس_, къра_, 
   {{0xa19000cf,0xb8000456,0x00000000,0x00000000}},	//   _ташч, लनाम_, --, --, 
   {{0xf1c802d2,0xdd58009d,0x00000000,0x00000000}},	//   bráð_, тарч_, --, --, 
   {{0x99800034,0x7af80036,0xdb240241,0xdee400f3}},	//   dził_, ëttp, _ìsìl, _воћи, 
   {{0x9a853d56,0xaa7800a2,0x6908033f,0x2484007f}},	// [1f5d0] русл, _boýr, dżer, yanm_, 
   {{0xfd6000b8,0x00000000,0x00000000,0x00000000}},	//   _nuvṛ, --, --, --, 
   {{0x24853d57,0xaa78010e,0x6720020c,0xe7849130}},	//   vanm_, _doýr, énjo, тузо, 
   {{0xebc00184,0x636403e0,0x2484007f,0x81b800cc}},	//   _йәғн, _dınl, wanm_, ঙিত_, 
   {{0x2484007f,0x1a6811c5,0x00000000,0x00000000}},	//   tanm_, _شیلی_, --, --, 
   {{0xa3cc0b40,0xd6d81945,0x6b80005c,0x15a002dd}},	//   शिल_, етә_, _ængs, _ﺍﻻﺗﯩ, 
   {{0x2484007f,0x00000000,0x00000000,0x00000000}},	//   ranm_, --, --, --, 
   {{0x24853d58,0xf36404fb,0x7fd401ec,0x00000000}},	//   sanm_, دئوی, ңіні, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x98b80022,0xc1040691,0x00000000,0x00000000}},	//   _pirĩ_, اودي, --, --, 
   {{0x7ff42162,0xf1c803b2,0x00000000,0x00000000}},	//   اسخا, tráð_, --, --, 
   {{0x6efc0023,0xddc400e2,0x903400c7,0x92940064}},	//   _dëbo, _afiš, рхьч, _вацц, 
   {{0x29013d59,0xf1c809f3,0xbe80bb89,0x00000000}},	//   _olja_, rráð_, аққи, --, 
   {{0x2b480175,0x7a180248,0x00000000,0x00000000}},	//   _ahcc_, _níbẹ, --, --, 
   {{0xf4280166,0x00000000,0x00000000,0x00000000}},	//   _ikäü_, --, --, --, 
   {{0xdce4098d,0x2b493d5a,0x21240208,0x29013d5b}},	//   _otić, _chcc_, _hjnh_, _alja_, 
   {{0x7a180241,0x3948020b,0x59b40032,0xeab400f7}},	// [1f5e0] _bíbẹ, _phbs_, шөнс, ыйт_, 
   {{0x9dac00dc,0x69080327,0x00000000,0x00000000}},	//   _aṅgā, wżer, --, --, 
   {{0xc7640533,0xc954001a,0xb0a445c7,0xdb1c002d}},	//   لانى, ртты, _खासग, rwrâ, 
   {{0x2900a3e1,0xdb1c002d,0x21240051,0xfd60002b}},	//   _elja_, swrâ, _ljnh_, _suvṛ, 
   {{0x394801ab,0x00000000,0x00000000,0x00000000}},	//   _thbs_, --, --, --, 
   {{0x26dc00df,0x6364c8d8,0xddcc00cd,0x00000000}},	//   _enuo_, _tınl, _śiśu, --, 
   {{0xe3ac00c6,0xb9dc0023,0x00000000,0x00000000}},	//   كري_, _ኢሰ_, --, --, 
   {{0xaa7801a2,0x7c3c0175,0x26dc01e4,0x31c40798}},	//   _inýc, _mypr, _gnuo_, гсов, 
   {{0x76246eec,0x290002d2,0xdec00023,0x00000000}},	//   _смаз, _ylja_, ስንን_, --, 
   {{0x64a00166,0xe6146c66,0xa2e001d5,0xb88401ef}},	//   _гафа, _сду_, _қочд, btíž, 
   {{0x7c3cb6c9,0x40e46518,0x2050010a,0xd1300014}},	//   _nypr, рсығ, йкья, ٝمک_, 
   {{0xceb810db,0x6fe803b9,0x00000000,0x00000000}},	//   тәк_, nəci, --, --, 
   {{0x7c3c035a,0xb644037e,0x00000000,0x00000000}},	//   _aypr, _ｋｈ_, --, --, 
   {{0x656c20ef,0x9cc81367,0x00000000,0x00000000}},	//   _éche, лыса_, --, --, 
   {{0xe0cc0e53,0x81cc0c58,0x40840022,0x212801c7}},	//   _رزو_, ৰহণ_, _тәым_, éche_, 
   {{0x7c3d3d5c,0x3f6406af,0x2f1000d1,0x7a180241}},	//   _dypr, _bœuf_, _چېگر, _síbẹ, 
   {{0xad253d5d,0x7c3c03ac,0x6fe806be,0x00000000}},	// [1f5f0] _مردو, _eypr, dəci, --, 
   {{0x0edc05ba,0x21240208,0x63640dde,0x00000000}},	//   याकड, _xjnh_, _sınm, --, 
   {{0xdce405ce,0x7c3cbb8d,0x6fe806be,0x00000000}},	//   _stić, _gypr, fəci, --, 
   {{0x7538324c,0x00000000,0x00000000,0x00000000}},	//   _aktz, --, --, --, 
   {{0xd79400c2,0x00000000,0x00000000,0x00000000}},	//   _қитъ, --, --, --, 
   {{0xd1f0069c,0x290004b9,0x80a800dc,0x69c801bf}},	//   ፍነት_, _ulja_, ज्ञे, ægeu, 
   {{0x86e400f1,0x6364013d,0x00000000,0x00000000}},	//   _پړاو, _tınm, --, --, 
   {{0x41b49370,0x85753d5e,0x26dc010f,0x21240051}},	//   асот, _влах, _unuo_, _sjnh_, 
   {{0x75380109,0x316407c5,0xf1842e9a,0x6738037e}},	//   _fktz, _cuoz_, айыл_, _ikuj, 
   {{0xe7e41d4c,0x00000000,0x00000000,0x00000000}},	//   পনীয, --, --, --, 
   {{0x256803cd,0x6568031c,0xd1c801c4,0x00000000}},	//   _høl_, lqgh, влөе_, --, 
   {{0xc0cc069c,0x63a13d5f,0x3ea44a2f,0x256800b5}},	//   _ኢዮም_, munn, шимг, _køl_, 
   {{0x63a13d60,0xc0e4ca40,0x21240051,0xcd5400d1}},	//   lunn, _волк, _tjnh_, ﻘﻨﯩﯔ_, 
   {{0x61f871aa,0x256801bf,0x00000000,0x00000000}},	//   myul, _møl_, --, --, 
   {{0x63a13d61,0x67393d62,0x31640c86,0x61f82819}},	//   nunn, _okuj, _zuoz_, lyul, 
   {{0x7c3c0232,0x67387294,0x63a00140,0xff513d63}},	//   _vypr, _nkuj, iunn, _بخت_, 
   {{0x63a13d64,0xcf245706,0x7c3c068f,0x2568143a}},	// [1f600] hunn, _دروي, _wypr, _nøl_, 
   {{0xe9d48456,0x67381629,0x63a13d65,0x61f80d04}},	//   шку_, _akuj, kunn, iyul, 
   {{0xcd2836e9,0x63a13d66,0xbb4453e9,0xf7700137}},	//   _حسين_, junn, _венк, زاا_, 
   {{0x63a13d67,0x61f85c5d,0xdb240cad,0x00000000}},	//   dunn, kyul, _ìsàl, --, 
   {{0xb0c40156,0x63a000d5,0x468001ec,0x00000000}},	//   _ཀྲའེ, eunn, яқта, --, 
   {{0x67381cdf,0x63a13d68,0x61f800aa,0xa9300064}},	//   _ekuj, funn, dyul, _меўш, 
   {{0x63a13d69,0xb4e40c2e,0x33283802,0x64a00063}},	//   gunn, _बची_, кцин_, цаја, 
   {{0x316405d5,0x256828b3,0xaa7800a2,0x65680135}},	//   _puoz_, _føl_, _knýa, bqgh, 
   {{0x61f801d3,0x66540354,0x00000000,0x00000000}},	//   gyul, _ватă, --, --, 
   {{0x63a13d6a,0xd1f002d3,0x00000000,0x00000000}},	//   bunn, ፍነቱ_, --, --, 
   {{0x63a02b1d,0x61f80083,0x3f6406af,0x7b08010e}},	//   cunn, ayul, _nœud_, _gýug, 
   {{0xe294074d,0xaa780432,0x00000000,0x00000000}},	//   _вац_, _onýa, --, --, 
   {{0x730400f1,0xfe6c57fb,0x00000000,0x00000000}},	//   _مځکې_, رگي_, --, --, 
   {{0xa1300137,0x7b08010e,0x00000000,0x00000000}},	//   _وروش, _lýud, --, --, 
   {{0x9b681b88,0xaf48009d,0xa78402dd,0x00000000}},	//   ишта_, _ичиж_, _ﻗﻨﺎﺓ_, --, 
   {{0x5f711488,0xd48400f1,0x00000000,0x00000000}},	//   _باور, _ښۀ_, --, --, 
   {{0xf8b40323,0xd5a47fc5,0x63a001c7,0x00000000}},	// [1f610] өөр_, _تہ_, zunn, --, 
   {{0x673800e2,0x63a13d6b,0x00000000,0x00000000}},	//   _skuj, yunn, --, --, 
   {{0x7b080432,0x3ebc01ed,0x2568143a,0x06740816}},	//   _býud, őtte_, _søl_, буля, 
   {{0x63a13d6c,0xb8fc2007,0xb60401fa,0x7bd80375}},	//   vunn, _दो_, _opšć, _עקרו, 
   {{0x63a00221,0x290c068c,0xdb2401e1,0x00000000}},	//   wunn, ègas_, _ìsál, --, 
   {{0x27e40267,0x256803b2,0x093400db,0x61f8022e}},	//   änns_, _vøl_, _چىڭح, vyul, 
   {{0xaca005db,0x63a020ac,0xb864004b,0xe2940b01}},	//   _adịg, uunn, _داټو, ҳақ_, 
   {{0x63a13d6d,0x67393d6e,0x61f93d6f,0x256806ea}},	//   runn, _ukuj, tyul, _tøl_, 
   {{0x63a00af5,0x61f80357,0x95c800d3,0x91840145}},	//   sunn, uyul, _вуха_, قۇنۇ, 
   {{0x25bc3743,0x61f873d8,0xb9dc0023,0x00000000}},	//   _ipul_, ryul, _ኢደ_, --, 
   {{0x63a13d70,0x61f80083,0x3f900306,0xcdc8011a}},	//   qunn, syul, ézu_, _רך_, 
   {{0x61f80004,0x00000000,0x00000000,0x00000000}},	//   pyul, --, --, --, 
   {{0xa3cc0f4a,0x8cd8012c,0x6fb001d3,0x035401af}},	//   शिक_, _फोहो, _ہموا, _күҫә_, 
   {{0xcfa801b9,0xa3a80d0a,0x5eb000cc,0x00000000}},	//   دایم_, कंप_, _জোখে, --, 
   {{0x6fb001d9,0xeb941171,0xd13800d8,0xe8140037}},	//   _فموا, йир_, _тхц_, _धेला_, 
   {{0x25bc0098,0x6ab80784,0x8bc402d5,0xcfa80345}},	//   _opul_, _ñufl, ўсёд, _ئاوم_, 
   {{0x6364000f,0xf2d0010f,0x00000000,0x00000000}},	// [1f620] _hűnd, הען_, --, --, 
   {{0xb4e41533,0xe8f4009b,0x00000000,0x00000000}},	//   _बचे_, блу_, --, --, 
   {{0x25bc003a,0x69c8005c,0x56680124,0x8cac0a59}},	//   _apul_, æger, азеҭ_, _जातो, 
   {{0xa3a805d7,0x89a801d9,0x87b80107,0xb6a4013d}},	//   कंन_, _چھلہ_, руфт_, сидл, 
   {{0xe5a04a35,0x00000000,0x00000000,0x00000000}},	//   зичи, --, --, --, 
   {{0x8b645fc4,0x659000d8,0x00000000,0x00000000}},	//   _دایم, чашу, --, --, 
   {{0x25bc003e,0xf74400f3,0xad985923,0x00000000}},	//   _epul_, _гево, nzúr, --, 
   {{0xf1a4190d,0x79853aec,0x628c0077,0x7b0800a2}},	//   брон, _kwkw, ócop, _hýub, 
   {{0xe29c05a4,0x32002b57,0x31c40107,0x00000000}},	//   óða_, áky_, ёсив, --, 
   {{0x656c0231,0xdce400c0,0x3dbc00cc,0x00000000}},	//   _écha, _buič, ইটাল, --, 
   {{0x320003c6,0x85340228,0xc1b801c6,0x00000000}},	//   šky_, _بولچ, глөх_, --, 
   {{0x71a402d5,0x7b0800a2,0x212800c7,0xce580395}},	//   _гадз, _lýub, ĩcha_, ианц_, 
   {{0x71f821ec,0x835001d9,0x67200066,0x00000000}},	//   _حراس_, _تھوا, énji, --, 
   {{0xd130007b,0x13ac00cc,0x00000000,0x00000000}},	//   _تمت_, _কৈয়, --, --, 
   {{0x79853d71,0x0eb005b5,0x00000000,0x00000000}},	//   _awkw, _झापड, --, --, 
   {{0xae9800c6,0x80240451,0xaca001e1,0xad2401d5}},	//   _إضغط_, _برهم, _idọg, _گربو, 
   {{0xb4f8000d,0x00000000,0x00000000,0x00000000}},	// [1f630] ्साय_, --, --, --, 
   {{0x29053d72,0xb88001f1,0x6364002d,0xd378107d}},	//   óna_, _šírk, _hűne, _zrće_, 
   {{0x25bcd503,0xd8741b06,0x31ac02f5,0x5eb00154}},	//   _spul_, سالب, কবিশ, _জোটে, 
   {{0x6364000f,0x17f800c6,0x7b08010e,0x5694003b}},	//   _jűne, حركة_, _eýub, зацт, 
   {{0xa3a82699,0x3cdc0490,0x76440014,0x00000000}},	//   कून_, खाचे_, ۅیہِ_, --, 
   {{0x6efc0240,0x836433d2,0x00000000,0x00000000}},	//   _dëbi, يدعل, --, --, 
   {{0x69cc0477,0x00000000,0x00000000,0x00000000}},	//   _hsce, --, --, --, 
   {{0x6ac40037,0x00000000,0x00000000,0x00000000}},	//   _लसोर, --, --, --, 
   {{0x6364045f,0x224801e3,0xad9800d7,0x86240244}},	//   _sűnd, åck_, zzúr, _بکال, 
   {{0xc1040597,0x69cc0142,0x80f80124,0xd378013d}},	//   زوجي, _msce, рхит_, шчә_, 
   {{0xd8d8008f,0x78b801d3,0x6aac03ac,0x1ee80271}},	//   מוזט_, _ötve, _occf, مودی_, 
   {{0x69cd3d73,0xcce8011a,0x2000031c,0x00000000}},	//   _osce, _בכ_, ġji_, --, 
   {{0xee34242f,0x200009a8,0x6364000f,0x6288035a}},	//   жня_, šji_, _wűnd, _iego, 
   {{0x628801c0,0xa2800345,0x00000000,0x00000000}},	//   _hego, _بیکو, --, --, 
   {{0x6364002d,0x628846a3,0x69cd3d74,0xeb94030d}},	//   _fűne, _kego, _asce, жис_, 
   {{0xb4e40034,0xa1a8013d,0x00000000,0x00000000}},	//   _बच्_, lğış_, --, --, 
   {{0x62893d75,0xa3a80c4c,0x6f54007b,0xad9800e5}},	// [1f640] _mego, कंड_, _بليز_, szúr, 
   {{0x62893d76,0x7b08010e,0xbca400c6,0x69cc01ef}},	//   _lego, _býuc, _بمدي, _dsce, 
   {{0x69cc5410,0x00000000,0x00000000,0x00000000}},	//   _esce, --, --, --, 
   {{0x62893d77,0x36940150,0x00000000,0x00000000}},	//   _nego, ішес, --, --, 
   {{0x7ae40c8c,0x87b801a9,0xa2ac0118,0x00000000}},	//   _inkt, _қурт_, ूभन्, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x62893d78,0x6364009d,0x00000000,0x00000000}},	//   _bego, орыг_, --, --, 
   {{0x2810040b,0xe7353d79,0x6288617f,0x06080032}},	//   _کوہس, _дес_, _cego, рмәҫ_, 
   {{0x62893d7a,0xe57406ed,0xa3a8146c,0x00000000}},	//   _dego, _мзт_, कूब_, --, 
   {{0x6364002d,0x6288058a,0x7bdc02d0,0x00000000}},	//   _sűne, _eego, _orpu, --, 
   {{0xceb8e695,0x62880363,0x128800f2,0xc87803e3}},	//   бәп_, _fego, _همای_, _əş_, 
   {{0x62893d7b,0x00000000,0x00000000,0x00000000}},	//   _gego, --, --, --, 
   {{0xe0cd3d7c,0x7bdd3d7d,0x2e483da1,0xde6402e8}},	//   رزی_, _arpu, ряно_, дърп, 
   {{0x7ae53d7e,0x62893d7f,0x22480730,0xfa2800b7}},	//   _ankt, _zego, ücke_, _ተመራማ, 
   {{0x6ab00154,0x1bd40395,0x00000000,0x00000000}},	//   ঁড়ফো, моря, --, --, 
   {{0xb8801d55,0x7bdc0332,0x497401a9,0x00000000}},	//   _šípk, _drpu, злас, --, 
   {{0x7bdd3d80,0x5d8400c6,0x00000000,0x00000000}},	// [1f650] _erpu, _قليل, --, --, 
   {{0x2bc80574,0xaa780030,0x6aac00b5,0x00000000}},	//   ाबदा, _iným, _wccf, --, 
   {{0x6d444d3c,0x2bc93a28,0xf1c80150,0x00000000}},	//   mlja, _тупо_, _ﻓﻴﻔﻘ, --, 
   {{0x6d453d81,0x97a4010b,0x63640205,0x7b080118}},	//   llja, ьрул, _mınt, _výuc, 
   {{0x62893d82,0x69cd3d83,0xeabc01e1,0x6d440ea0}},	//   _rego, _usce, _ibù_, olja, 
   {{0x62893d84,0xe9dc110e,0x88580353,0x293400d1}},	//   _sego, _irú_, _гигс_, ﺗﯘﭖ_, 
   {{0xe7306640,0x57b41d39,0xe8c401f9,0x00000000}},	//   _قصر_, _обрт, रजीच, --, 
   {{0x656cff09,0x6d440219,0x00000000,0x00000000}},	//   _écho, hlja, --, --, 
   {{0x67280183,0x6d441a48,0x62880099,0x91b001fb}},	//   mngj, klja, _vego, _đại_, 
   {{0xa3b8036d,0x62893d85,0xbef40c6f,0x514402dd}},	//   _ناصر_, _wego, ुघ्न_, мдығ, 
   {{0x62893d86,0x00000000,0x00000000,0x00000000}},	//   _tego, --, --, --, 
   {{0x6728778a,0xe9dc01e1,0x2f2c0210,0x00000000}},	//   nngj, _orú_, tęga_, --, 
   {{0x68e40399,0xa22407c0,0x672806ea,0x273801f2}},	//   _onjd, _براه, ingj, ụnwa_, 
   {{0x657805d9,0x6d4446aa,0x518401c6,0xec7400d8}},	//   _mtuh, glja, _цуца, зпр_, 
   {{0xe8dc0016,0xe9dc0332,0x3f980153,0xdce403e0}},	//   _ngực_, _arú_, ąsus_, _etiğ, 
   {{0xe9dd3d87,0x7e98007b,0x00000000,0x00000000}},	//   _brú_, _انظر_, --, --, 
   {{0x6d444859,0x65793d88,0x63a002fb,0xe9dc0332}},	// [1f660] blja, _ntuh, hrnn, _crú_, 
   {{0x67280369,0x7bdc01a6,0xe8f4468b,0x6efc0240}},	//   engj, _trpu, плу_, _dëbu, 
   {{0x65793d89,0xbb453d8a,0xe9dc0248,0x7d1d3d8b}},	//   _atuh, _неок, _erú_, _imps, 
   {{0x7ae53d8c,0xe9dc0321,0xe1e4007b,0xe3c00154}},	//   _unkt, _frú_, _كس_, ্মাব, 
   {{0x39a0040b,0xe7340835,0x94d4009d,0x00000000}},	//   _سیاہ, чец_, долц, --, 
   {{0xb4d4142d,0x098800c2,0xb7d805d9,0x00000000}},	//   िये_, _фарқ_, _ٿورا_, --, 
   {{0x65793d8d,0x53353d8e,0xdec002d3,0x00000000}},	//   _etuh, мект, ድሕን_, --, 
   {{0xe9dc00e4,0xf1a41f99,0x6d445160,0x91c4013d}},	//   _yrú_, прон, zlja, дәкл, 
   {{0xd5c0033d,0x79940034,0xd528004d,0x7d1c035a}},	//   _एहिज, nsyw, _cộn, _omps, 
   {{0xdce42630,0x85540014,0x63640205,0xf528027d}},	//   _otiđ, _ہیۆر_, _cıns, _اثره_, 
   {{0xe1ed3d8f,0x8f353b8a,0xa0a08984,0x65780118}},	//   نسی_, денц, хшыл, _ztuh, 
   {{0x7d1d3d90,0x00000000,0x00000000,0x00000000}},	//   _amps, --, --, --, 
   {{0x3cf8009d,0xaa7800a2,0x10680150,0x6ce40212}},	//   _bopv_, _goýy, _وڭدى_, піве, 
   {{0xf4280135,0xd378107d,0xee3c0022,0x6d44000d}},	//   _སྨོད_, _zrća_, ngýi_, ulja, 
   {{0x6d4404a7,0x7940017a,0x00000000,0x00000000}},	//   rlja, hôws, --, --, 
   {{0x6d441326,0x5bb8034b,0x7d1c03ac,0x290c00e2}},	//   slja, ялся_, _emps, īgam_, 
   {{0x5a3460d5,0x2bc80034,0x63a002fb,0x7bd80158}},	// [1f670] ентт, ाबहा, zrnn, åtur, 
   {{0xb4d47b05,0x58d400d4,0xed30132f,0x00000000}},	//   ियो_, ноут, _سوجھ, --, 
   {{0x0698007b,0x7b080432,0x28680124,0x672803b2}},	//   قناة_, _iýun, арҵо_, tngj, 
   {{0xe9dd3d91,0xdd7401d9,0x7b0800a2,0xba1800ec}},	//   _trú_, _تھێک, _hýun, _ڀيٽا_, 
   {{0xfd6400dc,0x67280240,0xe9dc01e7,0x00000000}},	//   _anuṣ, rngj, _urú_, --, 
   {{0x04440120,0xd5280208,0xb88002f0,0x998414af}},	//   мелн, _rộn, šíro, _سلفو, 
   {{0xb0a40073,0x7b0800a2,0x00000000,0x00000000}},	//   _खाजग, _mýun, --, --, 
   {{0x07080491,0xd7f4013d,0x051c0154,0xb4d4012d}},	//   _بيري_, _язсы, দকের_, ियॉ_, 
   {{0x7b080209,0x59e0073d,0x44b53d92,0x65793d93}},	//   _oýun, नियर, _обас, _utuh, 
   {{0xf1d0006d,0x312000ee,0x7b0802d2,0xd04806be}},	//   तिजन, кдыг, _nýun, lddə, 
   {{0x3ea4c51a,0xbea4e13e,0x855401ed,0x00000000}},	//   минг, манк, _فیچر_, --, 
   {{0x0640044e,0x425400f2,0x7bd80162,0xd04803e3}},	//   _ንሓድነ, _قنار, ætum, nddə, 
   {{0x0fc40220,0x7b080162,0x8e540212,0xbe380212}},	//   _үйін, _býun, етрі, ючої_, 
   {{0x63640139,0xd04806be,0x00000000,0x00000000}},	//   _tıns, hddə, --, --, 
   {{0x7fd40212,0x59e00118,0x00000000,0x00000000}},	//   _цілі, निभर, --, --, 
   {{0x69c0054e,0xac0400d4,0x00000000,0x00000000}},	//   ănen, єнта_, --, --, 
   {{0x3958039a,0x776d3d94,0x7d1c010a,0xb8b40640}},	// [1f680] tmps_, _subx, _tmps, дсећ, 
   {{0xbd4438b7,0x7d1c0857,0x00000000,0x00000000}},	//   _زنجي, _umps, --, --, 
   {{0x7a68006c,0x799403ac,0x00000000,0x00000000}},	//   _минг_, ssyw, --, --, 
   {{0x35a4141c,0x799403ac,0x00000000,0x00000000}},	//   дадг, psyw, --, --, 
   {{0xc76412b7,0x8ac400d1,0xfd64002b,0x00000000}},	//   رامى, _яқта_, _snuṣ, --, 
   {{0x69d81cba,0x00000000,0x00000000,0x00000000}},	//   निरी, --, --, --, 
   {{0xe3ad3445,0x24540276,0x292400d0,0xa96400d8}},	//   لري_, машь_, ývať_, _цира_, 
   {{0xa6c401b9,0xdb08005b,0x00000000,0x00000000}},	//   _олса_, _äläk, --, --, 
   {{0xaa7803b2,0xda0000bc,0x00000000,0x00000000}},	//   _snýk, ोनित_, --, --, 
   {{0xe9dc0ca8,0xef90006c,0x00000000,0x00000000}},	//   _oyún_, نیتد, --, --, 
   {{0xe1dc00b5,0x00000000,0x00000000,0x00000000}},	//   _ke系_, --, --, --, 
   {{0xe280084c,0xb35400f2,0x56380023,0x00000000}},	//   _алци, _تیبا_, _እናዓበ, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2bc82435,0x32c0022e,0xd1300244,0x00000000}},	//   ाबला, lаy_, _حمت_, --, 
   {{0x2518008d,0x636406be,0x8c2400f2,0x00000000}},	//   קולא, _zınq, رفره, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7b08010b,0x2cb00051,0x00000000,0x00000000}},	// [1f690] _iýul, _tcxd_, --, --, 
   {{0x19581219,0x00000000,0x00000000,0x00000000}},	//   дауы_, --, --, --, 
   {{0x18a402bf,0x0a940064,0x00000000,0x00000000}},	//   таєм, _паню, --, --, 
   {{0x5378044e,0xddc400ef,0x874400db,0x00000000}},	//   _ኢሰያስ_, _dziņ, رعاۅ, --, 
   {{0x96f801b9,0x7b0800a2,0x00000000,0x00000000}},	//   بعلر_, _mýul, --, --, 
   {{0xaab801ed,0x00000000,0x00000000,0x00000000}},	//   _ادھر_, --, --, --, 
   {{0x69a400af,0x7b0800a2,0x8858009d,0x00000000}},	//   टंकी, _oýul, _хивс_, --, 
   {{0x708000fd,0x8cb000ab,0xaacc0073,0x35f00139}},	//   ңгыз, _अफ़सो, हजिक, тпәр, 
   {{0x56953d95,0x016400d8,0x00000000,0x00000000}},	//   _шатт, нкио, --, --, 
   {{0xd2001823,0x7f540023,0x69a428fe,0x00000000}},	//   рүшк, _shyq, _चिनी, --, 
   {{0xff24747d,0x7b08010e,0x00000000,0x00000000}},	//   емно, _býul, --, --, 
   {{0x6efc0200,0x00000000,0x00000000,0x00000000}},	//   _sëbr, --, --, --, 
   {{0xa3a80490,0xbd340801,0x00000000,0x00000000}},	//   कूर_, ехвъ, --, --, 
   {{0x23d013f5,0x69c0054e,0x00000000,0x00000000}},	//   _दनाद, ănel, --, --, 
   {{0xefd402d3,0xfce40107,0x95941ef7,0x00000000}},	//   ራእየ_, _ҷопо, _ልደትን_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4a74005e,0xdc3c0960,0xe9a13d96,0xcee845cf}},	// [1f6a0] тыст, _išča, латп, _زرين_, 
   {{0x8d280efb,0xa92000db,0x00000000,0x00000000}},	//   _оның_, гдул, --, --, 
   {{0x8cd8433a,0x9dac0055,0x69200352,0x00000000}},	//   _फोटो, _oṅkā, ымфа, --, 
   {{0xe7353d97,0xd6d0adf3,0xefd40023,0x00000000}},	//   нех_, شقت_, ራእዩ_, --, 
   {{0xade00037,0xa68001c6,0xb7c000eb,0x00000000}},	//   खियन_, улчд, োমেট, --, 
   {{0x2910f063,0x9dac00b8,0xe51800bc,0x00000000}},	//   chxa_, _aṅkā, भोलि_, --, 
   {{0xa3a807c1,0xdc3c0419,0xa594031c,0xdec00092}},	//   कूल_, _ošča, ċċaħ, ድንና_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe7353d98,0xa6c53d99,0x7b080162,0xe9dc00e5}},	//   _чет_, _ялта_, _nýum, _nyúl_, 
   {{0x25a400b2,0x00000000,0x00000000,0x00000000}},	//   _سگهي_, --, --, --, 
   {{0x5f913d9a,0x00000000,0x00000000,0x00000000}},	//   лиэт, --, --, --, 
   {{0x290c00e2,0xaadc0406,0x37e00154,0x00000000}},	//   īgai_, _पोंक, _যথার, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe0d00640,0xa27402d3,0xe214011a,0x2164014b}},	//   _бошњ, _ጭቆናን_, _אקדח_, _зичи_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe29c2833,0x6080001f,0xa8a4010a,0x48ec0490}},	// [1f6b0] óði_, _የበጀት_, ерек, घालो_, 
   {{0x656c06af,0x00000000,0x00000000,0x00000000}},	//   _échi, --, --, --, 
   {{0x212806af,0x5bc401b9,0x00000000,0x00000000}},	//   échi_, _یقیل, --, --, 
   {{0x6364002d,0x5d849b17,0x00000000,0x00000000}},	//   _rűno, _جلیل, --, --, 
   {{0xfd981df2,0x1cb80066,0x00000000,0x00000000}},	//   ﭘﻘﺎﻥ_, _غایب_, --, --, 
   {{0x03a53d9b,0xf9901203,0x38780354,0xa4907ba2}},	//   вико, _דרך_, ccpr_, ایات, 
   {{0x195806a6,0x22a401e1,0x63e000db,0x3f50032e}},	//   _чары_, _nìkà_, ايبە, dáun_, 
   {{0x72a000d1,0x73c018c7,0x00000000,0x00000000}},	//   لەمن, рәфе, --, --, 
   {{0x26cd3d9c,0x60080793,0xdce40327,0x7b0800ee}},	//   mego_, kömö, _lwiġ, _býuj, 
   {{0x26cd3d9d,0x8cac0073,0x00000000,0x00000000}},	//   lego_, _जागो, --, --, 
   {{0xb4f8008f,0x4394014b,0x00000000,0x00000000}},	//   _קלער, _раес, --, --, 
   {{0x26cd3d9e,0x27e4005b,0x00000000,0x00000000}},	//   nego_, änny_, --, --, 
   {{0x25ac05d5,0xce68023a,0xb1940139,0xaa7800a2}},	//   nugl_, ерёд_, _алчә, _kaýf, 
   {{0x26cc5bae,0x00000000,0x00000000,0x00000000}},	//   hego_, --, --, --, 
   {{0x26cce367,0xad9801ed,0x00000000,0x00000000}},	//   kego_, nyúj, --, --, 
   {{0x3f853d9f,0x26cc068f,0x7b0800a2,0x00000000}},	//   mplu_, jego_, _týum, --, 
   {{0x26cd3da0,0x6b600cab,0x6dd0009f,0x39453da1}},	// [1f6c0] dego_, ркта, _نقيض, внаг, 
   {{0xfb80350a,0x37e4004e,0x00000000,0x00000000}},	//   _نگری, козг, --, --, 
   {{0x3f84009d,0x26cc00d8,0x59e000bc,0x00000000}},	//   nplu_, fego_, निहर, --, 
   {{0x26cc1ebd,0x25ac383d,0xec340375,0x00000000}},	//   gego_, fugl_, _יאיר_, --, 
   {{0x7b08010e,0x752000c7,0xa9a001a9,0x00000000}},	//   _lýuk, аҟаҵ, _кияд, --, 
   {{0x9a540124,0xe4c04c91,0x00000000,0x00000000}},	//   _ахҳә, ийчи, --, --, 
   {{0x26cd3da2,0x59e080f3,0xad9800e5,0x00000000}},	//   bego_, निवर, gyúj, --, 
   {{0x26cc068f,0x17c40124,0xd1d40023,0x12d4004e}},	//   cego_, _иаҳҭ, ራህቱ_, ужия, 
   {{0x22a401e1,0x00000000,0x00000000,0x00000000}},	//   _sìkà_, --, --, --, 
   {{0xaa7808a5,0x63ac0162,0x00000000,0x00000000}},	//   _hnýt, ðinø, --, --, 
   {{0xb4ac5345,0xce945c08,0xaa78022c,0xdb1c002d}},	//   कली_, ланъ, _knýt, rtrê, 
   {{0xb224656c,0x43740117,0x00000000,0x00000000}},	//   _имел, _суфт, --, --, 
   {{0x98b80055,0x91c41a98,0xd1d40023,0x3c0401a9}},	//   _chrī_, _сәйл, ራህቲ_, қўрғ, 
   {{0x26cd3da3,0xeff00092,0x00000000,0x00000000}},	//   zego_, ቃሴው_, --, --, 
   {{0x21293da4,0x26cd3da5,0x00000000,0x00000000}},	//   èche_, yego_, --, --, 
   {{0x79801682,0x26cd3da6,0xdb1cfc7a,0xabb00124}},	//   ̭owe, xego_, ntrè, лаҳә, 
   {{0x26cd3da7,0xd010004b,0x00000000,0x00000000}},	// [1f6d0] vego_, _خلګ_, --, --, 
   {{0x26cd3da8,0x2ba80c2e,0x25ac07de,0x00000000}},	//   wego_, _छिपा, vugl_, --, 
   {{0x26cd3da9,0xd77410e0,0xbd3402dd,0x58d40d99}},	//   tego_, لانع, _сүру_, рохт, 
   {{0x2904000d,0x00000000,0x00000000,0x00000000}},	//   önab_, --, --, --, 
   {{0xe9453daa,0x5a340108,0xfb18011a,0x00000000}},	//   _ахво, _внят, _נושמ, --, 
   {{0x26cd3941,0xaa780432,0xa92400d7,0xf574007b}},	//   sego_, _baýg, _boľš, دموع_, 
   {{0x26cce367,0xe7841614,0x27f400dd,0xf8b004ae}},	//   pego_, _југо, _جہاد_, _לשם_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xaa7886fa,0x00000000,0x00000000,0x00000000}},	//   _hnýs, --, --, --, 
   {{0xf8c41a3e,0xaa780432,0x00840137,0xa4900244}},	//   र्पय, _haýd, ылоо, _ئیغت, 
   {{0x28a8033f,0xaa78010b,0xd9d007f7,0x00000000}},	//   _चयनि, _gaýg, _हन्ट, --, 
   {{0x7b0802fd,0x52753dab,0x3ce40790,0xaa78010b}},	//   _výuk, _кушу, _şov_, _jaýd, 
   {{0xe29c05f7,0xdb1c3621,0xaa78010b,0x00000000}},	//   óðu_, strë, _maýd, --, 
   {{0x3f8400e8,0x00000000,0x00000000,0x00000000}},	//   pplu_, --, --, --, 
   {{0xace40588,0xcff4004b,0xdb1c06af,0xf0900375}},	//   ымра_, _نيوک, ltré, _פנה_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb1d3dac,0x7a04013f,0x6aa8007b,0x00000000}},	// [1f6e0] ntré, kɔte, ógfa, --, 
   {{0xe9d42ecc,0xaa7868f1,0x00000000,0x00000000}},	//   ыку_, _snýt, --, --, 
   {{0xaa780209,0x00000000,0x00000000,0x00000000}},	//   _baýd, --, --, --, 
   {{0x2f2c0210,0x00000000,0x00000000,0x00000000}},	//   tęgi_, --, --, --, 
   {{0xaa780432,0x95640139,0x00000000,0x00000000}},	//   _saýg, андҗ, --, --, 
   {{0xb864b386,0xaa7800a2,0xdb1c01e7,0xa92400d7}},	//   _مازو, _paýg, dtré, _poľš, 
   {{0xf07400d1,0xf5300092,0x00000000,0x00000000}},	//   һипә_, ክለኛነ, --, --, 
   {{0xaa780209,0xb18801c6,0xf7441422,0x3f5008a5}},	//   _gaýd, нсож_, _себо, fáum_, 
   {{0xf5e8660c,0xf07400d1,0x46dc2052,0x00000000}},	//   _ямал_, липә_, _नोटह, --, 
   {{0xdb1d26bb,0x77600356,0x00000000,0x00000000}},	//   strè, lmox, --, --, 
   {{0xf8c408dd,0xb2c40b24,0x728854e7,0x00000000}},	//   र्यय, _مغشو, _збег_, --, 
   {{0xe454010f,0x7760022e,0x00000000,0x00000000}},	//   _גיבט_, nmox, --, --, 
   {{0x656c1fe8,0xe298008f,0xa13001d5,0xcfc800db}},	//   _écht, _טשאר, شریش, راگۅ_, 
   {{0x61d806a9,0x21280a40,0x30753dad,0xaa7800a2}},	//   _נקוד, écht_, _судс, _maýe, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd5d41fbc,0x316d3dae,0xf3e403d4,0xddd4010b}},	//   _धनंज, _hifz_, _কথাৰ_, _ýaşb, 
   {{0x9a842097,0xaa793daf,0xf8c46766,0xfc280092}},	// [1f6f0] сусл, _snýs, र्भय, ደሚገል, 
   {{0xb4ac145f,0xd1f0069d,0xaa78010e,0x00000000}},	//   कलो_, _ፀጥታ_, _saýd, --, 
   {{0x6d453db0,0xaa78010b,0x27e400ae,0x00000000}},	//   moja, _paýd, ínn_, --, 
   {{0x58d40220,0xaa780432,0xdb1c013a,0x79cc0150}},	//   _қост, _baýe, ytré, _ﺗﻴﯩﻤ, 
   {{0x66240a11,0x1b0800db,0x50c48153,0x00000000}},	//   دراك, _сээп_, वभाष, --, 
   {{0x6d453db1,0x290c00da,0xd8740214,0xd6d8035b}},	//   noja, īgas_, _هافب, втә_, 
   {{0xd7e4dbe2,0xaa780209,0x7b0800a2,0x59e001f9}},	//   _літо, _taýd, _sýui, निअर, 
   {{0x29013db2,0x6d453db3,0xaa78010b,0x63640205}},	//   _hoja_, hoja, _haýb, _hınz, 
   {{0x29001326,0x6364000f,0x44280227,0x92e800c6}},	//   _koja_, _jűni, ńa_, طريق_, 
   {{0x6d449333,0x67293db4,0xdb1c03f7,0x29000124}},	//   joja, ligj, rtré, _joja_, 
   {{0x29013db5,0x6d4447c0,0x26dc0069,0xdb1d3db6}},	//   _moja_, doja, _kauo_, stré, 
   {{0x29013db7,0xf3b4008f,0x67293db8,0x004400f1}},	//   _loja_, _כּדי_, nigj, هیږي_, 
   {{0x6d453db9,0x62993dba,0xfccc0023,0x1ee801b9}},	//   foja, mauo, _ብናጻ_, نوگی_, 
   {{0xfce400f7,0x7f440113,0xaa780432,0x62980064}},	//   шого, sokq, _naýb, lauo, 
   {{0x8fc404fb,0x00000000,0x00000000,0x00000000}},	//   _هزين, --, --, --, 
   {{0x6728069c,0x62993dbb,0x4f9400ee,0x2bc407c1}},	//   jigj, nauo, _уршу, _लहरा, 
   {{0x29003858,0x67293dbc,0x394805b1,0xaa78010e}},	// [1f700] _boja_, digj, _pkbs_, _baýb, 
   {{0x62981e0d,0x236c02d3,0x29013dbd,0x6cb13dbe}},	//   hauo, _ligj_, _coja_, _мөст, 
   {{0x6298166a,0x290002d3,0x6e900220,0xc95400cf}},	//   kauo, _doja_, _الۋا, стты, 
   {{0xc76407a7,0x26dc003a,0x7c3c0327,0x27e401a8}},	//   مانى, _cauo_, _ixpr, ænna_, 
   {{0x29000115,0xa5d400db,0x212401e4,0x3634ee63}},	//   _foja_, لبور_, _omnh_, جراس, 
   {{0x29013dbf,0x62980076,0x2ed01bd6,0x00000000}},	//   _goja_, eauo, _तस्त, --, 
   {{0xf8c42432,0x26dc0421,0xa50410fc,0x00000000}},	//   र्णय, _fauo_, реја_, --, 
   {{0x31c486f8,0x925800f7,0x6d453dc0,0x65600208}},	//   асов, лайт_, zoja, amnh, 
   {{0x6d453dc1,0x290007a8,0xf8c44407,0x798402d0}},	//   yoja, _yoja_, र्थय, _jtkw, 
   {{0x6b813dc2,0x798403ac,0x290001d5,0x00000000}},	//   _éngg, _mtkw, _xoja_, --, 
   {{0x656c04cc,0x21280ba1,0xf1a81e4b,0xd3e400f2}},	//   _ècha, ècha_, راکه_, _دقای, 
   {{0x62980333,0x6d441d3b,0xf8c400dc,0xea9c0055}},	//   cauo, woja, र्तय, _meṣe_, 
   {{0x6d44df4d,0x2f18002e,0xea9c0241,0x6720020c}},	//   toja, _lëgg_, _leṣe_, ènji, 
   {{0x67280b21,0x6d440006,0xcb0800ec,0xa3a80073}},	//   zigj, uoja, گيرن_, कंच_, 
   {{0x6d453dc3,0x29013dc4,0x1fa000c0,0xce940395}},	//   roja, _roja_, _дрыг, _лайъ, 
   {{0x29013dc5,0x200c0232,0x5b144d15,0x6d453dc6}},	//   _soja_, íliš_, омст, soja, 
   {{0x29013dc7,0x6728002d,0x00000000,0x00000000}},	// [1f710] _poja_, vigj, --, --, 
   {{0x2f183d27,0x7c3c05b1,0x6ca40b7e,0xad2428ee}},	//   _bëgg_, _fxpr, _триж, _خربو, 
   {{0x26dc00ca,0x29013dc8,0x67293dc9,0x2d880010}},	//   _pauo_, _voja_, tigj, lpce_, 
   {{0x636400dd,0x2f181574,0x3f78010f,0x00000000}},	//   _tűni, _dëgg_, אָסע, --, 
   {{0x290004cc,0x67293dca,0x04880022,0x00000000}},	//   _toja_, rigj, гәеи_, --, 
   {{0x2f180de2,0x15a80801,0x039400a7,0x67280023}},	//   _fëgg_, ръци_, брия, sigj, 
   {{0x82a53dcb,0x62993dcc,0x672803cd,0x00000000}},	//   байж, tauo, pigj, --, 
   {{0x5c380302,0xd4082f7c,0x00000000,0x00000000}},	//   ירון_, شتىم_, --, --, 
   {{0x9324bb6f,0x212400d8,0x62993dcd,0xe4c84caa}},	//   ترون, _pmnh_, rauo, _لبان_, 
   {{0x2f18002e,0x62980175,0x7fd4346d,0x00000000}},	//   _yëgg_, sauo, бімі, --, 
   {{0x2d88014b,0x62980064,0x00000000,0x00000000}},	//   epce_, pauo, --, --, 
   {{0x69cc1e31,0xdb241432,0xf454011a,0x00000000}},	//   _opce, ürür, _היער_, --, 
   {{0x7a040085,0xc0e53dce,0x0d98005b,0xcd540116}},	//   kɔta, _голк, итры_, ﺘﻨﯩﯔ_, 
   {{0x4d3811ed,0x61e80332,0x7b0800a2,0x61f86fa3}},	//   аяся_, _irgl, _lýut, mxul, 
   {{0x673802e3,0xdf0409a5,0x69cc00e2,0xb09804ae}},	//   _ojuj, _дүнй, _apce, _עיקר, 
   {{0x67384dfc,0x9f493dcf,0x7c50001f,0xab24014b}},	//   _njuj, _orné_, _መድረሱ, боса_, 
   {{0x61f8021a,0xb68441fa,0x2f1800e8,0xfde800cf}},	// [1f720] nxul, ەشتى, _sëgg_, _сдпк_, 
   {{0x673800b4,0xd378107d,0x25e801ad,0xd54401e1}},	//   _ajuj, _zrću_, चिनी_, _mẹ́y, 
   {{0xd5440241,0x3154010f,0x3098010f,0xbb4436ca}},	//   _lẹ́y, ציען_, רשעמ, _генк, 
   {{0x7bdc04b9,0x61e93dd0,0x00000000,0x00000000}},	//   _ispu, _orgl, --, --, 
   {{0xdb1d1a82,0x7bdc0175,0x2f1800e8,0x61f80327}},	//   ntrí, _hspu, _wëgg_, jxul, 
   {{0x673800e4,0xe0c400c6,0x2f180de2,0xdb1c01e7}},	//   _ejuj, _عز_, _tëgg_, itrí, 
   {{0xb3c80323,0x61e80368,0xaa78010b,0xf3c8007b}},	//   уулж_, _argl, _haýa, ابته_, 
   {{0xe3ad3dd1,0xe6148dcb,0x52143580,0x61e80010}},	//   ررى_, рдә_, ждит, _brgl, 
   {{0x67200023,0xded802d3,0x61f8009a,0x66000276}},	//   ënje, ኮናን_, gxul, _епта, 
   {{0x7e746aad,0xd37801a6,0xaa78010b,0x64a001ec}},	//   _agyp, _tuć_, _maýa, _науа, 
   {{0x32c845b3,0xedd410db,0x00000000,0x00000000}},	//   _было_, әлгә_, --, --, 
   {{0xd54401e1,0x229001d3,0xe454011a,0x00000000}},	//   _fẹ́y, _فلمس, _פיאט_, --, 
   {{0x7bdc6ef0,0x98d800e1,0xade0012c,0x7b08010e}},	//   _aspu, ड़ाए, खिइन_, _lýus, 
   {{0x7e753dd2,0x53dc01f9,0xbe300022,0x00000000}},	//   _egyp, _मनाश, ьҭыш, --, 
   {{0xdb1c09c2,0xd138fea4,0x7b0802d2,0x6f8441b9}},	//   atrí, mną_, _nýus, _уулж, 
   {{0xd1393dd3,0xaa78010b,0x15f8012d,0x00000000}},	//   lną_, _baýa, ंमार_, --, 
   {{0x7bdd3dd4,0xd1388327,0x6b500205,0x00000000}},	// [1f730] _espu, oną_, nçgi, --, 
   {{0xd138033f,0xaa7800ee,0x00000000,0x00000000}},	//   nną_, _daýa, --, --, 
   {{0x47d42674,0xd1383f05,0x00000000,0x00000000}},	//   تيار, iną_, --, --, 
   {{0x6364002d,0x46140451,0xaa7800a2,0xd1384632}},	//   _jűnt, يوار, _faýa, hną_, 
   {{0x69c00311,0x61f80941,0xaa780432,0xa6d80154}},	//   ănes, xxul, _gaýa, ণালয়, 
   {{0xd1380034,0x5e58010f,0x842400d1,0x00000000}},	//   jną_, ציגע_, يىشن, --, 
   {{0xd138068f,0x9f6001d3,0xd54401e1,0xaa78010b}},	//   dną_, őség_, _sẹ́y, _zaýa, 
   {{0x17693dd5,0x41a93dd6,0xd13802d5,0x61f867b0}},	//   _груп_, авин_, eną_, txul, 
   {{0xdb1cc17e,0x9f440118,0x9eb400d1,0xf8c408df}},	//   ltrã, íjí_, үшмә, र्वय, 
   {{0x61e80219,0x291001e2,0x61f93dd7,0xe9dc00d0}},	//   _vrgl, nkxa_, rxul, _msú_, 
   {{0x65781cbe,0xf8b002e4,0xdb1c00d8,0x636400e5}},	//   _huuh, ושי_, ntrã, _bűnt, 
   {{0x65793dd8,0xd138033f,0xe9dc01e1,0x00000000}},	//   _kuuh, aną_, _osú_, --, 
   {{0xd138033f,0x61e803ac,0xfe440212,0x00000000}},	//   bną_, _urgl, інго, --, 
   {{0x3f653dd9,0xaa780209,0x637401f2,0x657833eb}},	//   _cœur_, _raýa, _ụnya, _muuh, 
   {{0x3a98023a,0x90e412ea,0xaa7800ee,0x65793dda}},	//   итаю_, _رسون, _saýa, _luuh, 
   {{0xaa78010e,0x80c4012d,0x2ba80118,0x00000000}},	//   _paýa, ़्रे, _छिरा, --, 
   {{0xfce53ddb,0xf2d010df,0xee900014,0x7b093ddc}},	// [1f740] _допо, וען_, _تۯُک, _býur, 
   {{0xe8f53ddd,0xb8540640,0x00000000,0x00000000}},	//   олу_, ођењ, --, --, 
   {{0x7bdc098d,0xf8c400cd,0x00000000,0x00000000}},	//   _uspu, र्षय, --, --, 
   {{0x65786bb3,0xdb1c3c6b,0xd1380034,0xaa78010b}},	//   _buuh, strâ, zną_, _taýa, 
   {{0xe5a13dde,0xd138d591,0xade00118,0x00000000}},	//   дичи, yną_, खिएन_, --, 
   {{0xb7d85220,0x6578003e,0x6b8000d2,0xf8c400cd}},	//   _پورا_, _duuh, _éngc, र्शय, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf1a523a6,0x65a001f2,0xd1380034,0xdb1c56ed}},	//   орон, _ọher, wną_, ntrà, 
   {{0xd1380034,0x6364000f,0xe614239a,0x59e007af}},	//   tną_, _rűnt, _ддт_, निटर, 
   {{0x71093ddf,0x61402377,0x7124009a,0x00000000}},	//   рхив_, мења, تربل, --, 
   {{0x7a04013f,0xd138d591,0x2878011a,0xa878010f}},	//   kɔto, rną_, ינימ, יאיר, 
   {{0x6364002d,0xd1380034,0x3f64004a,0x22e403e6}},	//   _dűns, sną_, _sœur_, _وتنێ, 
   {{0x22480730,0x2ce4031c,0xaa7800a2,0x712400f1}},	//   ückt_, _སྣུབ, _baýn, _ورتل, 
   {{0x21640b87,0xad6400ae,0x00000000,0x00000000}},	//   _дичи_, تاجه, --, --, 
   {{0x7c2002a8,0x704400f7,0xd010007b,0x64280023}},	//   _ƙora, _بئشك, _سلة_, _እንተኼ, 
   {{0x7b0800a2,0x98c000b8,0x00000000,0x00000000}},	//   _sýur, _āsām_, --, --, 
   {{0xd5a40583,0xdcfc0166,0x18800023,0x3f580241}},	// [1f750] _جہ_, _üzğa, _ይቑጸር_, _ṣuga_, 
   {{0x29042200,0x65793de0,0xd8780131,0xaa78010b}},	//   ðna_, _ruuh, ەمەت_, _gaýn, 
   {{0x65781073,0x31c0015b,0x69a400cd,0x00000000}},	//   _suuh, ্টিশ, _चिकी, --, 
   {{0x65793de1,0x00000000,0x00000000,0x00000000}},	//   _puuh, --, --, --, 
   {{0xd61812e3,0xbaf80375,0x361800ec,0x00000000}},	//   يتها_, _ההרש, ٽرنگ_, --, 
   {{0xb9780375,0xe2340023,0x00000000,0x00000000}},	//   _לנשי, _ይስማዓ, --, --, 
   {{0x8ccd3de2,0xdb1c629e,0xe2340023,0x1ad003d4}},	//   द्यो, ltrá, _ይስመዓ, ৱাৰা, 
   {{0x6578105c,0xd3d800c6,0xaa78010e,0xdc3c011a}},	//   _tuuh, تبها_, _maýo, יעור, 
   {{0xdb1ce4dc,0x00000000,0x00000000,0x00000000}},	//   ntrá, --, --, --, 
   {{0xba8c08b0,0xd04806be,0x80f80798,0x00000000}},	//   _ﺑﯩﻠﮕ, ledə, схит_, --, 
   {{0xf8b000df,0x42740150,0x00000000,0x00000000}},	//   עשט_, _егес, --, --, 
   {{0xdb1c0122,0xdbd00122,0x22480e78,0xc2c40592}},	//   ktrá, užív, ücks_, _ريتي, 
   {{0xee3400d6,0xaa78010e,0x8188009a,0x00000000}},	//   зня_, _paýn, _انتق_, --, 
   {{0xc0e451af,0xd14800cf,0xc0d40092,0x719c010e}},	//   _хокк, _وشون_, ራትም_, _çykỳ, 
   {{0xb098011a,0x3f6800f3,0x00000000,0x00000000}},	//   _היצר, _лико_, --, --, 
   {{0xef1c04cc,0xaa78010e,0x00000000,0x00000000}},	//   chü_, _daýo, --, --, 
   {{0x3ea0d821,0x3a253de3,0x9f500124,0xba24010b}},	// [1f760] makt_, чмаг, _ñañe_, чдак, 
   {{0xdb1c66ce,0x3ea001a4,0xe73401e0,0xaa7800a2}},	//   strà, lakt_, үеф_, _haýl, 
   {{0xd04806be,0x00000000,0x00000000,0x00000000}},	//   fedə, --, --, --, 
   {{0xaa780209,0x6b800098,0x940c0213,0xd0480213}},	//   _jaýl, _énga, _gedə_, gedə, 
   {{0x7ae4369d,0x6720f428,0xaa78010e,0x00000000}},	//   _iakt, ënja, _maýl, --, 
   {{0xb3b40003,0x3ea13de4,0x366801b9,0x7ae52c65}},	//   _དཀྱུ, hakt_, _ғазо_, _hakt, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7ae53de5,0x66e033e2,0x3ea0ce29,0x81d40154}},	//   _jakt, _поса, jakt_, হিন_, 
   {{0x7ae53de6,0x3ea13de7,0x51f800d4,0xc32c215c}},	//   _makt, dakt_, іною_, جەن_, 
   {{0xf5580597,0x28cc2232,0x00000000,0x00000000}},	//   _الطب_, स्पि, --, --, 
   {{0xb3b40003,0xaa780209,0xdb1d3de8,0x250801d5}},	//   _དཀྲུ, _baýl, mtræ, _ارقی_, 
   {{0x7ae53de9,0xe0cc034c,0x2f180de2,0xdb1d3dea}},	//   _nakt, پزی_, _bëga_, ltræ, 
   {{0x63000228,0x211401d5,0x00000000,0x00000000}},	//   _سوول, زتیب_, --, --, 
   {{0xdb1c005c,0x9344013d,0x224400db,0xd0d40395}},	//   ntræ, _энҗе, _эпчи_, _цокъ, 
   {{0x7ae53deb,0x3ea0143a,0xaa7800ee,0x9f4801ef}},	//   _bakt, bakt_, _faýl, _zrní_, 
   {{0x7ae4044e,0xaa7800a2,0x28cc00b8,0x00000000}},	//   _cakt, _gaýl, स्नि, --, 
   {{0xdb1c01bf,0xa3e0012d,0x3dc802dd,0xcd6c0092}},	// [1f770] ktræ, _पैन_, _ﺑﻴﯖﺘ, በረውና_, 
   {{0x7ae403ac,0x5a34ef04,0xdb1d3dec,0x00000000}},	//   _eakt, хнут, jtræ, --, 
   {{0xdb1d3ded,0xdbdc0789,0x59ac0406,0x00000000}},	//   strá, báñe, _चिअर, --, 
   {{0x7c3806ea,0x45d4010b,0x554c0023,0x7ae40064}},	//   útre, дцкт, _ንሃገሮ, _gakt, 
   {{0x84e403b7,0xdb1c9574,0x80bc27f2,0xd77400db}},	//   долж, ftræ, _शाले, رامع, 
   {{0x3ea0f6d2,0x7ae53dee,0xaa780432,0xdb1c0450}},	//   zakt_, _zakt, _maým, gtræ, 
   {{0x96180058,0x7ae53def,0x53dc07b6,0x9f4801ef}},	//   يغۇر_, _yakt, _मनःश, _srní_, 
   {{0x68e53df0,0x7ae40724,0x6abc0369,0xc5a80014}},	//   _hajd, _xakt, ngqf, _وُزن_, 
   {{0xc2449db1,0x3ea01f53,0xdb1c01bf,0x8f800150}},	//   ьник, vakt_, btræ, ққыл, 
   {{0xaa7809a5,0x80bc0574,0x68e48da5,0x3ea001a4}},	//   _saýl, _शाळे, _jajd, wakt_, 
   {{0x68e53df1,0x3ea13df2,0x2d98011f,0xaa780209}},	//   _majd, takt_, _awqe_, _paýl, 
   {{0xaa78010e,0x9f4801ef,0x00000000,0x00000000}},	//   _baým, _trní_, --, --, 
   {{0x7ae53df3,0x68e4022e,0x27240042,0x00000000}},	//   _rakt, _oajd, lŵns_, --, 
   {{0x68e48be0,0x28cd3df4,0xaa7800a2,0xd52c01e1}},	//   _najd, स्मि, _daým, _mó̟l, 
   {{0x7ae53df5,0x3ea13df6,0x8ccc0146,0xf0900375}},	//   _pakt, pakt_, द्धो, _ינג_, 
   {{0x2d900598,0x6d48032e,0x00000000,0x00000000}},	//   äneñ_, _ígan, --, --, 
   {{0x7ae53df7,0x68e40135,0xaa780432,0x9e7400cf}},	// [1f780] _vakt, _bajd, _gaým, _سۇست, 
   {{0xe1e53df8,0x68e40218,0xdb50168d,0xe9440ec9}},	//   _یس_, _cajd, _ڕێز_, ورلی, 
   {{0x7ae53df9,0x68e4047e,0x36c406a6,0x3b080798}},	//   _takt, _dajd, дбег, _дено_, 
   {{0x7ae53dfa,0x65a0063f,0xe7353dfb,0xaa780432}},	//   _uakt, _ọhar, мех_, _onýy, 
   {{0xd6e003f4,0x68e53dfc,0x9f9d3dfd,0x00000000}},	//   ণালয, _fajd, _déét_, --, 
   {{0xa504026a,0x96e801e2,0x00000000,0x00000000}},	//   деља_, _ډبرې_, --, --, 
   {{0xdb1c04ce,0x9f4804cc,0xb9dc0023,0x00000000}},	//   rtræ, _ornà_, _ብህ_, --, 
   {{0xdb1c9573,0x9f9c01c7,0x68e53dfe,0x27b000c7}},	//   stræ, _géét_, _zajd, _шәус, 
   {{0xdb1c1ed1,0xaa78010e,0x68e40477,0x9174011c}},	//   mträ, _baýj, _yajd, нгиц, 
   {{0xdb1c5df4,0x61ec003a,0x25e800c5,0xaa7800a2}},	//   lträ, æcla, चिरी_, _raým, 
   {{0x64a02e9a,0x3d00bfc8,0xaa780432,0x824c0023}},	//   _раха, शाने_, _saým, _ምድልዳ, 
   {{0xdb1d3dff,0x7d1d3e00,0x733400c6,0x00000000}},	//   nträ, _alps, _غرائ, --, 
   {{0xdb1c03fa,0xa2b01a47,0x95940240,0x00000000}},	//   iträ, _इयत्, _ውደባን_, --, 
   {{0xfd64002b,0xdb1c002f,0x0dd00023,0xa3e0012d}},	//   _kauṣ, hträ, _ብኣፍ_, _पैड_, 
   {{0x68e5215e,0x2ca0009b,0xdb1c0267,0x13dc0b8f}},	//   _rajd, rajd_, kträ, _मनोभ, 
   {{0x1cd00156,0x68e53e01,0x7d1c0857,0xdb6800a8}},	//   ུབཔ_, _sajd, _elps, друл_, 
   {{0x68e53e02,0xda340daf,0xdb1c40fc,0xaa78010e}},	// [1f790] _pajd, веты, dträ, _haýk, 
   {{0x9f480589,0x9f9d3e03,0xdb1c0112,0x00000000}},	//   _trnã_, _séét_, eträ, --, 
   {{0x656c0395,0x6aa804c5,0xe7849cb8,0xdb1c03fa}},	//   _èchi, ঙ্গো, фузо, fträ, 
   {{0x81d439db,0x395805d5,0xaa780432,0xdb1c26bc}},	//   হিত_, alps_, _maýk, gträ, 
   {{0x68e53e04,0xdce40327,0x46c401ec,0x00000000}},	//   _tajd, _htiġ, _үшбұ, --, 
   {{0x9f9c017a,0x00000000,0x00000000,0x00000000}},	//   _wéét_, --, --, --, 
   {{0x43740276,0xfd6400b8,0x39440129,0xdb1c3bba}},	//   нуит, _cauṣ, éose_, bträ, 
   {{0xb9dc0020,0x645c00ac,0xc2c400c6,0xfd64002b}},	//   _ብቅ_, əqil, ريخي, _dauṣ, 
   {{0x28cd3e05,0x05b4007b,0x00000000,0x00000000}},	//   स्थि, _سماح, --, --, 
   {{0xaa78010e,0xdb1c3b3b,0x3d0c00af,0xc0e42218}},	//   _baýk, mtrå, _हवें_, хоок, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x28cc1b61,0x3078001f,0x7b3c0419,0x00000000}},	//   स्ति, _አጠገብ_, aďuj, --, 
   {{0xdb1c7c52,0x90e53e06,0xd05806be,0xc5cc0011}},	//   ntrå, رسین, _mavə, লিকপ, 
   {{0x2ef8009a,0x5238007b,0x9f80014b,0x28cc06e3}},	//   _enqf_, _تسمح_, _иҳод, _सॉलि, 
   {{0xbb447555,0xfaf47927,0xdb1c007c,0x00000000}},	//   еевк, нчаю, yträ, --, 
   {{0xdb1d3e07,0x00000000,0x00000000,0x00000000}},	//   murë, --, --, --, 
   {{0x6df00597,0xaa442bbd,0xdb1d3e08,0x00000000}},	// [1f7a0] _مكيا, епта_, jtrå, --, 
   {{0xdb1c3e04,0xbd440451,0xaa78010e,0x7d1c03ac}},	//   dtrå, _سنجي, _laýh, _ulps, 
   {{0xdb1d3e09,0x49002374,0xe50000dc,0x27b0a857}},	//   tträ, шүрг, लानि_, ләтс, 
   {{0x6840b4f7,0xc7641a02,0xd9b421ea,0xe70401d3}},	//   ынха, نانى, _لەرد, ٹسمی, 
   {{0xdb1d3e0a,0xca74035b,0x18c80ed0,0xfd6400b8}},	//   rträ, _ауры, _оңай_, _sauṣ, 
   {{0xdb1d3e0b,0x62893e0c,0xfd64002b,0x26f000fe}},	//   strä, _afgo, _pauṣ, _অকণো_, 
   {{0xe3ac2781,0xdb1c01e6,0xaa780432,0x00000000}},	//   مري_, pträ, _baýh, --, 
   {{0xdb1c0023,0x7228005b,0xfd6400b8,0xee3c010e}},	//   durë, зцов_, _vauṣ, haýa_, 
   {{0xaa7800ee,0xe64002dd,0x28c400bc,0xee3c010b}},	//   _daýh, _бетп, _लामि, kaýa_, 
   {{0x64a032b1,0xa570009f,0x00000000,0x00000000}},	//   _бафа, _مُقت, --, --, 
   {{0xdd940046,0xdb1c0023,0xd05803b9,0xee3c00ee}},	//   ғасы, gurë, _yavə, daýa_, 
   {{0xf1a842b5,0xd05806be,0x2ed800cd,0x00000000}},	//   _فاته_, _xavə, यजेत, --, 
   {{0xe33400c8,0xe2942374,0xf1a8004b,0x67d000bc}},	//   _אראפ_, _чач_, _راشه_, mějš, 
   {{0x6aac00b5,0xe04001c6,0xee3c00a2,0x00000000}},	//   _sdcf, _өнчи, gaýa_, --, 
   {{0x21280036,0x6d4802d2,0x00000000,0x00000000}},	//   ëche_, _ígam, --, --, 
   {{0x67d0038e,0xdbdc04d4,0xdd900014,0x5c740395}},	//   nějš, _cáña, _گوٝ_, улст, 
   {{0xee3c00a2,0x00000000,0x00000000,0x00000000}},	// [1f7b0] baýa_, --, --, --, 
   {{0xad248074,0x00000000,0x00000000,0x00000000}},	//   _سرخو, --, --, --, 
   {{0xe8dc01fb,0xa04c001f,0x11240023,0x28c40210}},	//   _ngục_, _ማንነታ, _ሽወደና, _लाठि, 
   {{0x8ccc89f0,0xdbdc0077,0x97c401d5,0x81700055}},	//   द्रो, _gáña, طقهو, _māvṛ, 
   {{0xdbdc2507,0x00000000,0x00000000,0x00000000}},	//   _háða, --, --, --, 
   {{0xdb1c7fff,0x43f8ae2b,0x00000000,0x00000000}},	//   rtrå, дхия_, --, --, 
   {{0xaa78010e,0xd918005b,0x94a801d9,0x817000b8}},	//   _saýh, _чья_, راوِ_, _nāvṛ, 
   {{0xdb1d3e0d,0x28c40ce0,0xaa7800ee,0x00000000}},	//   ptrå, _लाडि, _paýh, --, 
   {{0x85740588,0x00000000,0x00000000,0x00000000}},	//   _алах, --, --, --, 
   {{0xdb1c02d3,0x514421f7,0x6d5400f1,0xddc406be}},	//   turë, лдығ, _nkxa, _ayiş, 
   {{0x81700055,0xdbdc08ce,0xded80023,0x67d0013a}},	//   _cāvṛ, _náða, _ርኢኻ_, bějš, 
   {{0xdb1c02d3,0x00000000,0x00000000,0x00000000}},	//   rurë, --, --, --, 
   {{0xdb1c0200,0xd47401af,0x00000000,0x00000000}},	//   surë, _иҙәш_, --, --, 
   {{0xdbdc08a7,0xaa7800ee,0xb198011a,0x00000000}},	//   _báða, _haýw, _חיסכ, --, 
   {{0xfaa42e01,0x3f84031c,0x00000000,0x00000000}},	//   каво, qqlu_, --, --, 
   {{0xdbdc02d2,0xdb1c03b2,0xe40c0055,0x00000000}},	//   _dáða, ltrú, _ṃśuk, --, 
   {{0xdc3c00d0,0xcee800e3,0xfd4801d5,0xfe4400d8}},	// [1f7c0] _ušľa, _سرين_, _озик_, _шнио, 
   {{0xa9213e0e,0x4a7402dd,0x6aa803b2,0xefb80092}},	//   адул, уыст, ógfr, ታገዝ_, 
   {{0xb9080254,0xb8c8cc41,0x47880150,0x00000000}},	//   _मस_, _गज_, есім_, --, 
   {{0xeabc01ab,0xf8c400dc,0x7bcc0334,0x00000000}},	//   _clùd_, र्जय, mtbu, --, 
   {{0xd0580085,0x67d00316,0x34a00107,0xdb1c0022}},	//   _bavɛ, vějš, иҳаҳ, juré, 
   {{0xaef80086,0x7a04016b,0xe56c027d,0xf8640818}},	//   nmùr, wɔtw, يطو_, _авго, 
   {{0x7bcd3e0f,0xeabc08e7,0x41840046,0x67d0012c}},	//   ntbu, _imùr_, қтығ, tějš, 
   {{0x7bcc01a4,0x25b40213,0x04340023,0xdb1c02d2}},	//   itbu, üdlü_, _ክንጽዕ, furé, 
   {{0xe734005e,0x28cc0b7c,0xdb1d3e10,0xb4d416ac}},	//   _рет_, स्वि, guré, _لغات, 
   {{0x7bcd3e11,0xdb1c067c,0xdbe401e1,0xf8c400cd}},	//   ktbu, surè, _téèp, र्चय, 
   {{0x7bcc2e10,0xa5047160,0x7a180055,0xfe740107}},	//   jtbu, _шефа_, _hātā, қӯъ_, 
   {{0x7a1802b5,0xdbdc066a,0xdb1c002d,0x7bcc002f}},	//   _kātā, _ráða, rtrû, dtbu, 
   {{0x7bcc017a,0xdb1cd927,0xaa7800a2,0x7a1800cd}},	//   etbu, strû, _haýv, _jātā, 
   {{0x7a193e12,0xdd953e13,0x2228006c,0x3eb00076}},	//   _mātā, рары, _غزنی_, _edyt_, 
   {{0xad9800d2,0xaf4801c0,0xd138fea4,0x7bcc01bf}},	//   nyúz, _очиж_, mią_, gtbu, 
   {{0xd13879a9,0xdbdc0174,0x81d40154,0x00000000}},	//   lią_, _váða, হির_, --, 
   {{0x28a41de1,0x7bcc03b2,0x00000000,0x00000000}},	// [1f7d0] вшег, atbu, --, --, 
   {{0x6d54094a,0xd1383920,0x6160001f,0xe7ec00af}},	//   _ukxa, nią_, _ወጣቶች, छिला_, 
   {{0x7bcc34b9,0x58840022,0x00000000,0x00000000}},	//   ctbu, рыуа, --, --, 
   {{0xaab800e5,0xdb1c00d7,0x00000000,0x00000000}},	//   _کدھر_, ztrú, --, --, 
   {{0xd13802d5,0xaa651e67,0xb0c001ad,0xda783740}},	//   kią_, _шток, _शांग, _аяр_, 
   {{0x04447136,0xdbe4003e,0x7a18002b,0x03a400f3}},	//   лелн, _séép, _dātā, гико, 
   {{0x38640198,0xd1380210,0xd7e40064,0x00000000}},	//   ƙora_, dią_, _кіто, --, 
   {{0xdb1d3e14,0xd6d8013d,0x00000000,0x00000000}},	//   turé, _иту_, --, --, 
   {{0xa3e01533,0x78b0008c,0xd138033f,0x7a180055}},	//   _पैर_, _ákvö, fią_, _gātā, 
   {{0x410402f6,0x31200137,0xd138fea4,0xdb1d3e15}},	//   узов, йдыг, gią_, ruré, 
   {{0x3ea4006c,0xdb1cdf44,0x42d40220,0x4394013d}},	//   линг, suré, _білу, _саес, 
   {{0xdb1d3e16,0xaa7800a2,0x3b8401b9,0x3f9000e2}},	//   strú, _haýu, ғлаг, īzu_, 
   {{0x629883b3,0xd1380034,0xef140c9e,0x21280561}},	//   mbuo, bią_, умя_, èchs_, 
   {{0x7bcc7944,0x6298011c,0xccf40588,0xd1380034}},	//   ttbu, lbuo, ақь_, cią_, 
   {{0x6298004d,0x3944024c,0x937c1cce,0x6e2003b9}},	//   obuo, ҳнаг, _üşüt, _ənbi, 
   {{0x7bcd3e17,0xac053e18,0x20cc17c6,0x1ee856ee}},	//   rtbu, ынса_, त्रध, _شوخی_, 
   {{0x39446bd5,0x6b60236f,0x00000000,0x00000000}},	// [1f7e0] гнаг, скта, --, --, 
   {{0x28cc0cb4,0x7a1802b5,0x8ca42144,0x00000000}},	//   स्लि, _rātā, करणो, --, 
   {{0x79946a8a,0x7a180055,0x363400be,0x00000000}},	//   spyw, _sātā, گراس, --, 
   {{0x273802e3,0x79948010,0x76240209,0x7a192c45}},	//   ụnna_, ppyw, лмез, _pātā, 
   {{0x36353e19,0x35b44b8c,0xdb1c1347,0x00000000}},	//   دراس, ущес, dtrø, --, 
   {{0xa504b25a,0x6ef80432,0x7a1800cd,0x00000000}},	//   леча_, _käbä, _vātā, --, 
   {{0x79853e1a,0xf7441ee3,0xc7646073,0xdb1c0b1a}},	//   _hukw, _бево, _چاقى, ftrø, 
   {{0xd3793e1b,0xdc0800da,0x6298b35f,0xd1380034}},	//   _opće_, dēļa, gbuo, wią_, 
   {{0x798405d9,0xb4f004da,0xda0404aa,0xd1380210}},	//   _jukw, _гүлч, रमित_, tią_, 
   {{0x79853e1c,0x3dc00472,0x6b8000f2,0x3208033f}},	//   _mukw, dukw_, _èngg, ćby_, 
   {{0xd1386b82,0x79853e1d,0xaa7800a2,0x25180a7c}},	//   rią_, _lukw, _haýt, _רובא, 
   {{0xd13802d5,0x6b8000d2,0x3dc0090c,0x206407ee}},	//   sią_, _éngi, fukw_, ышып_, 
   {{0x79841419,0x2ab80241,0xd1393e1e,0xaa78010e}},	//   _nukw, _làbà_, pią_, _jaýt, 
   {{0x6ef80139,0x61407b0a,0xb28400c7,0xaa7800a2}},	//   _bäbä, _леча, _рыҧк, _maýt, 
   {{0xaca0063f,0x79853e1f,0x5c04005b,0xd5280051}},	//   _ngụg, _aukw, бята, _cổn, 
   {{0x9b593e20,0x9504031c,0x2ab42cc8,0x984c0171}},	//   гист_, _ཙོའི_, ыңмы_, _dēļa_, 
   {{0xaca0063f,0x79840198,0x33cc03b9,0x00000000}},	// [1f7f0] _agụg, _cukw, _dəxi_, --, 
   {{0x7984015c,0x2ab80ca8,0xdb080118,0x9a8401a9}},	//   _dukw, _bàbà_, ělát, _ҳурл, 
   {{0xb7840184,0x7aec02f6,0x7d1801e6,0x58d40107}},	//   иәте_, öntä, ötse, сохт, 
   {{0xef1c4953,0xd7740eff,0x798401c8,0x4b200131}},	//   nkü_, مانع, _fukw, _بېرە, 
   {{0x798425ca,0x3f64004a,0x836400f2,0x00000000}},	//   _gukw, _vœux_, یدعل, --, 
   {{0xe4a417d8,0xb604032e,0x959800e5,0x00000000}},	//   урдо, _smáþ, ائنز_, --, 
   {{0x6ef81248,0x629807d6,0x798400ca,0x1b740a98}},	//   _xäbä, tbuo, _zukw, _خدیج, 
   {{0x6298000f,0x5c380375,0x86c40472,0x00000000}},	//   ubuo, טרון_, _خيرن, --, 
   {{0x629802d5,0xaa780209,0x00000000,0x00000000}},	//   rbuo, _gaýt, --, --, 
   {{0xdb1c2ab7,0xaa780209,0x6298002d,0x00000000}},	//   strø, _haýs, sbuo, --, 
   {{0xaa780432,0x55041a71,0x24440114,0x00000000}},	//   _kaýs, _учта, _схаг, --, 
   {{0x200805be,0x6fd401ad,0x6368010e,0x2f1800e8}},	//   ćci_, _बहरू, _döný, _yëgi_, 
   {{0x6ef80724,0xe3c409bd,0xaa780432,0x3d00694b}},	//   _säbä, _শনিব, _maýs, शाले_, 
   {{0x79853e21,0x29cc07c5,0xc0d40092,0x00000000}},	//   _rukw, düa_, ያትም_, --, 
   {{0xbb5400c6,0x79853e22,0xb88002fb,0x3dc00472}},	//   لنسب, _sukw, šíko, sukw_, 
   {{0x7984017a,0x92900248,0xeab47701,0x00000000}},	//   _pukw, _iṣẹ́_, ийс_, --, 
  
   {{0x29cc00e4,0xbee0012d,0x9f4800d7,0x00000000}},	// [1f800] güa_, गजीन_, _ornú_, --, 
   {{0x79840564,0x8304031c,0xd528004d,0x61e80175}},	//   _vukw, _མོའུ_, _tổn, _msgl, 
   {{0xeb180882,0x79851c93,0xaa780432,0xc764005e}},	//   ṇyaṃ_, _wukw, _saýt, ڭالى, 
   {{0xaa7809a5,0x7bdd3e23,0x79853e24,0x61e80142}},	//   _paýt, _ippu, _tukw, _osgl, 
   {{0x3b00009a,0x7f4400f1,0xdb1c0240,0x7c2c1196}},	//   _inkq_, inkq, hrrë, lzbr, 
   {{0xb7940640,0xa9a13e25,0xa5300212,0xb864135f}},	//   _враћ, _фирд, оніч, _نازو, 
   {{0xb224008c,0x61e80142,0x7c2c324c,0xdb1c0356}},	//   kvæð, _asgl, nzbr, murâ, 
   {{0x6b8125a0,0xdb1c0240,0x7c2d3e26,0x060801e0}},	//   _ènge, drrë, izbr, тмәҫ_, 
   {{0x71440cb9,0xaa7800ee,0x34a8014b,0x00000000}},	//   ихож, _haýr, _авзо_, --, 
   {{0x7bdd3e27,0xdb1c95fc,0x33d400d6,0x7f4400f1}},	//   _oppu, durí, _відт, enkq, 
   {{0x61e80228,0x77601709,0xaa780432,0xe3a400f2}},	//   _esgl, olox, _jaýr, _نشنی, 
   {{0x644c033f,0xaa78010e,0x7c2c00ef,0xdb1c02d2}},	//   _ścig, _maýr, dzbr, furí, 
   {{0x28c407f7,0xef1c029f,0xdb1c02f0,0xc3040338}},	//   _लालि, rkü_, gurí, _دبلو, 
   {{0xf07424ce,0xfe6c00cf,0x621800d9,0x61d8011a}},	//   _килә_, ةگى_, _בודק, _סקוד, 
   {{0xab844990,0xaa7800a2,0xa00408de,0x00000000}},	//   ругк, _naýr, _نقول_, --, 
   {{0x61e8015d,0x20780a7c,0x25ac015d,0x00000000}},	//   _ysgl, _באוא, ysgl_, --, 
   {{0x7bdd3e28,0x7d1804cc,0xea6001d3,0xd01002cb}},	// [1f810] _eppu, ötsc, تھدی, _ذلک_, 
   {{0xaa78010b,0x29cc04cc,0xdb1c054e,0x6b8000e4}},	//   _baýr, rüa_, gurâ, _ũngu, 
   {{0x6d4404b9,0x25ac0142,0x00000000,0x00000000}},	//   mnja, wsgl_, --, --, 
   {{0xd7f830af,0x6d453e29,0x77600789,0x17840220}},	//   шуу_, lnja, glox, ігім, 
   {{0xd5e80e26,0xdc3c031c,0xd5b83c1a,0xdb1c0413}},	//   لعون_, _iġġa, ңсә_, ntrý, 
   {{0x6d453e2a,0xdb1c0356,0xd6d80022,0x00000000}},	//   nnja, curâ, гтә_, --, 
   {{0x29000944,0x6d440649,0xaa78010b,0x3324012d}},	//   _inja_, inja, _gaýr, _blox_, 
   {{0x77600077,0xc5a80014,0x6d4401a6,0xdb1c0022}},	//   clox, _مُرن_, hnja, murã, 
   {{0x2f18002e,0x6d44b2a0,0x11a80220,0x67200200}},	//   _jëgu_, knja, айық_, ënju, 
   {{0x6d44009b,0xaa7800a2,0x332401ef,0xdb1c0162}},	//   jnja, _yaýr, _elox_, vurí, 
   {{0x6d440552,0x4384007b,0x332400d7,0x00000000}},	//   dnja, _الصق, _flox_, --, 
   {{0x6d440b4f,0xdb1d3e2b,0xbf20190e,0xb7d808a8}},	//   enja, turí, मसेन_, נקרי, 
   {{0x29013e2c,0xa18400fd,0x717001d5,0xdb1c03b2}},	//   _onja_, _тыел, تهیا, gtrý, 
   {{0x409503d6,0xb224008c,0xa91800b8,0x7c2c0112}},	//   _الغر, svæð, _duþk, tzbr, 
   {{0x7760959f,0xbea42218,0x7c2c0165,0x6e4001b9}},	//   ylox, _лайк, uzbr, قچیم, 
   {{0x6d453e2d,0x2f1800e8,0x3868054e,0x7c2c002f}},	//   anja, _bëgu_, _rzbr_, rzbr, 
   {{0x6d4407f5,0xf9881c36,0xfa680588,0x3948020c}},	// [1f820] bnja, اخره_, уаак_, _pjbs_, 
   {{0x6d440989,0x5fd837d0,0xaa78010e,0x00000000}},	//   cnja, _बहाल, _paýr, --, 
   {{0x7bdd3e2e,0xf744023a,0xdb1c00e4,0x00000000}},	//   _uppu, бежо, rurâ, --, 
   {{0x940c016b,0xd3783c52,0x290001a6,0x99800030}},	//   _medɔ_, _opća_, _enja_, dziť_, 
   {{0xdee4069c,0x989400d1,0xdb1c00e8,0x00000000}},	//   _ዝዀነ_, _мувә, murà, --, 
   {{0xdb1c0037,0x00000000,0x00000000,0x00000000}},	//   htrü, --, --, --, 
   {{0x3324020c,0x3958020c,0xd370143e,0xaa78010e}},	//   _plox_, mops_, وهت_, _haýp, 
   {{0x6d4408ad,0x2f1800e8,0x39580f85,0xf2e53e2f}},	//   znja, _yëgu_, lops_, сюко, 
   {{0x28cc4f18,0x6d446c27,0xdb1c1f6f,0x84800023}},	//   स्कि, ynja, ltró, _ሓዳርን_, 
   {{0xdee402d3,0x644c0034,0x39580793,0xa3e005b3}},	//   _ዝዀኑ_, _ście, nops_, _पैक_, 
   {{0x6d445946,0xdb1d3e30,0x15f005d7,0x00000000}},	//   vnja, arré, चिकर_, --, 
   {{0x39593e31,0x6d44eab1,0xd37002f2,0x00000000}},	//   hops_, wnja, _تێبک, --, 
   {{0xe2843321,0x39593e32,0x11f80133,0x00000000}},	//   _اطمی, kops_, _خوشک_, --, 
   {{0xdb1d3e33,0x6d4401f4,0x9cc841e5,0xee3c00a2}},	//   ktró, unja, йыса_, naýi_, 
   {{0x7d1801e3,0x00000000,0x00000000,0x00000000}},	//   ötsa, --, --, --, 
   {{0x6d443ad4,0xdb1c05d5,0xeaf8bfb2,0x37cc0154}},	//   snja, gurà, درست_, রবার, 
   {{0x75380194,0x3e400165,0x6ce40024,0x9f4c007c}},	// [1f830] _omtz, _gɔt_, _ліне, ålåk_, 
   {{0xeabc01ab,0xa1240092,0x7bd8025c,0x00000000}},	//   _glùn_, _ስለሚሆ, ħtur, --, 
   {{0xee3c00a2,0x00000000,0x00000000,0x00000000}},	//   daýi_, --, --, --, 
   {{0xdee40023,0xdb1c0022,0x00000000,0x00000000}},	//   _ዝዀና_, rurã, --, --, 
   {{0x29000421,0x39580332,0x00000000,0x00000000}},	//   _tnja_, bops_, --, --, 
   {{0x15a800a7,0x49040c75,0xdb1d3e34,0x67280200}},	//   съци_, _بوسق, murá, shgj, 
   {{0xdb1d3e35,0x613c01e1,0xd7f80f64,0x60e403e3}},	//   ctró, _lálè, _лут_, _öpmə, 
   {{0x65a0063f,0xa124001f,0x387c01d3,0x7c38000f}},	//   _ọhur, _ስለመሆ, _útra_, útri, 
   {{0x73300075,0xe6102ab5,0x67393e36,0x0204109a}},	//   بىيا, _عشر_, _imuj, ізон, 
   {{0xdb1c7d47,0x00000000,0x00000000,0x00000000}},	//   ntrò, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb1d3e37,0x00000000,0x00000000,0x00000000}},	//   kurá, --, --, --, 
   {{0xada0010b,0xdb1d3e38,0x0cd4043e,0x00000000}},	//   маял, jurá, धभूम, --, 
   {{0xdb1d3e39,0x51940354,0xb1e001c8,0x83dc134e}},	//   strü, _хăра, _آڻيو, _महाआ, 
   {{0xe8dc01fb,0x67380a49,0x3f680261,0x71700592}},	//   _ngốc_, _omuj, _кико_, _تهوا, 
   {{0xff5121e7,0xdb1c02d2,0x00000000,0x00000000}},	//   _تخت_, furá, --, --, 
   {{0xd1c402d3,0xdb1d3e3a,0xbadc0150,0xf8a80022}},	// [1f840] _ጸወታ_, gurá, _ﺇﺤﺼﺎ, ивак_, 
   {{0xd9103cc4,0x00000000,0x00000000,0x00000000}},	//   ریز_, --, --, --, 
   {{0xded80023,0x3154011a,0x00000000,0x00000000}},	//   _ርኢና_, קיען_, --, --, 
   {{0xadc00ca8,0x2c140316,0x39580175,0xdb1c02f0}},	//   _afẹf, नहरू_, sops_, burá, 
   {{0x3958037e,0xdb1d3e3b,0x7af40024,0x00000000}},	//   pops_, stró, mdyt, --, 
   {{0xdb1c0372,0x7af402d5,0x6738cf1a,0xe3ac0131}},	//   ctrò, ldyt, _emuj, ھرى_, 
   {{0xc32c12b7,0x94a80220,0xe3ac1371,0x33293e3c}},	//   گەن_, атқа_, نري_, ицин_, 
   {{0xd37004a9,0x7af53e3d,0x5214fe1c,0xb6a4005b}},	//   رۇش_, ndyt, здит, _фиал, 
   {{0xe64010e0,0xc32c3b5f,0x7af400c0,0x00000000}},	//   _жетп, دەن_, idyt, --, 
   {{0x7af402f6,0xe9fc01fb,0xe1ec01f7,0x64a0022e}},	//   hdyt, _liếc_, ئسي_, _жафа, 
   {{0xe51c1161,0x28cc023e,0x7af40006,0xdb1c00e5}},	//   _भवति_, स्टि, kdyt, zurá, 
   {{0xeea8084c,0xd5280208,0x33cc0213,0xdb1c1427}},	//   шток_, _hồn, _fəxr_, luræ, 
   {{0x7af40fac,0x60e433b8,0x00000000,0x00000000}},	//   ddyt, ørmå, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9b94361e,0xe9fc004d,0x62840118,0x2aa80063}},	//   дисц, _biếc_, ějov, итао_, 
   {{0x7af40153,0xd5280051,0x9954010e,0x00000000}},	//   gdyt, _lồn, läň_, --, 
   {{0xaa78010b,0xe9fc0051,0x00000000,0x00000000}},	// [1f850] _obýe, _diếc_, --, --, 
   {{0x6350054e,0xd484004b,0x6738036e,0xdb1c03b2}},	//   măne, _لۀ_, _smuj, rurá, 
   {{0x4b200075,0xad2404fb,0xddc48185,0x7af40024}},	//   _كېسە, _هرگو, _iziš, bdyt, 
   {{0x2d180764,0xdb1d0a04,0x6fb0012d,0x998c00a2}},	//   _नकुल_, strò, _आबनू, _ülşi_, 
   {{0xfa940bd9,0x5efc08a8,0xf6b01291,0x9954010e}},	//   _מדרש_, יפאד, رموج, käň_, 
   {{0x6d880327,0x99540432,0x00000000,0x00000000}},	//   _eżag, jäň_, --, --, 
   {{0x5ef000dc,0xee3c00a2,0x00000000,0x00000000}},	//   ेयम्_, maýu_, --, --, 
   {{0x673801aa,0x7af8013f,0xeabc0393,0xe9fc004d}},	//   _umuj, _ɔtto, _olùm_, _xiếc_, 
   {{0xe2940046,0xc244234c,0x00000000,0x00000000}},	//   бақ_, яник, --, --, 
   {{0x28cc0118,0x995400a2,0x00000000,0x00000000}},	//   स्चि, gäň_, --, --, 
   {{0xaac8012c,0x7af4023a,0xd91c0375,0x5ec40116}},	//   िलाक, ydyt, יוזל, минғ, 
   {{0xdb1c525f,0x63500311,0x00000000,0x00000000}},	//   murç, făne, --, --, 
   {{0x6350054e,0xfaa40107,0xee200108,0x9954010e}},	//   găne, ҷабо, емяп, bäň_, 
   {{0x61f82782,0x28c4012c,0x23cc01bc,0x3b940798}},	//   mvul, _लागि, संपद, зјат, 
   {{0xf0900302,0xfaa4adc9,0xfb6800c6,0x00000000}},	//   _אנו_, забо, مصرى_, --, 
   {{0xacf401ed,0x61f80472,0x7af40153,0x6350054e}},	//   _ہسپت, ovul, udyt, băne, 
   {{0x61f808f7,0x42a002d3,0x7af40024,0x2b480118}},	// [1f860] nvul, _ግድነት_, rdyt, _šicí_, 
   {{0x26dc0521,0x3cc800db,0x00000000,0x00000000}},	//   _abuo_, _улоо_, --, --, 
   {{0xe9fc001e,0x356c001f,0x907002d3,0xd5280208}},	//   _tiếc_, ስገባት_, _ባዕዳዊ_, _rồn, 
   {{0x61f8dba0,0x00000000,0x00000000,0x00000000}},	//   kvul, --, --, --, 
   {{0x61f801a4,0xdb1c03b2,0x00000000,0x00000000}},	//   jvul, turæ, --, --, 
   {{0x644c068f,0x61f80af2,0xe50000bc,0x00000000}},	//   _ścia, dvul, लागि_, --, 
   {{0xb8640244,0xd5280051,0x30a4010b,0xdb1d3e3e}},	//   _راسو, _cốn, үров, ruræ, 
   {{0xdb253e3f,0x26dc02e3,0x31c53e40,0x00000000}},	//   érès, _gbuo_, псов, --, 
   {{0x61f81a7c,0x46d00892,0xf1a8a5d1,0x00000000}},	//   gvul, _हातह, حابه_, --, 
   {{0x7d18049f,0x6d8800e2,0xdb1d3e41,0x2d180210}},	//   ötsl, _kļav, lurä, _नकेल_, 
   {{0x78ac0810,0x61f8013c,0xdb1c00db,0x733401d3}},	//   _mebv, avul, curç, _ٹرائ, 
   {{0x63500356,0x7334007b,0x00000000,0x00000000}},	//   tăne, _عرائ, --, --, 
   {{0xdf0805f5,0x28ac000d,0x00000000,0x00000000}},	//   чээл_, टरमि, --, --, 
   {{0x78ac004c,0x6350054e,0xd0102d4b,0xa1180118}},	//   _nebv, răne, _للت_, ěňát, 
   {{0x60d80375,0xddc400d7,0xdb1c01f4,0xa9c401e2}},	//   _הקונ, _vziš, kurä, ړزاو, 
   {{0xae980597,0xaca00241,0x6350054e,0x511c000d}},	//   _اضغط_, _ifọg, păne, _पकुआ_, 
   {{0x29100bc9,0x78ac01e4,0xdebc0375,0xa3b000af}},	// [1f870] tjxa_, _bebv, _המחל, _जौन_, 
   {{0x26dc04cc,0x00000000,0x00000000,0x00000000}},	//   _sbuo_, --, --, --, 
   {{0x29040abc,0x78ac014f,0x57a402d5,0xc1d8095f}},	//   ına_, _debv, ешча, _बङ्ग, 
   {{0xd8753e42,0x9c8400b0,0xee3c00a2,0x00000000}},	//   رالب, āōti, baýt_, --, 
   {{0xa3cc05ba,0xd52801fb,0x3d000073,0xbaf8011a}},	//   वून_, _sốn, शाचे_, _והרש, 
   {{0xf9900bd9,0x98b00841,0x61f80a49,0x00000000}},	//   _ברך_, _ćaća_, vvul, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x61f88638,0x9f4c0790,0x0204c6c2,0x00000000}},	//   tvul, çlük_, дзин, --, 
   {{0xe4e41fe2,0xdb2401ed,0x78ac004c,0x86240a98}},	//   _ніжн, érés, _yebv, _تکال, 
   {{0x61f93e43,0x00000000,0x00000000,0x00000000}},	//   rvul, --, --, --, 
   {{0x61f93e44,0xd5280208,0x63500356,0x4adc043e}},	//   svul, _uốn, gănc, मभाव, 
   {{0x26cd3e45,0xdb1c01e3,0x00000000,0x00000000}},	//   nggo_, ltrö, --, --, 
   {{0xee341e18,0x6ecc190c,0xd0ac00cc,0x00000000}},	//   дня_, _थारु, _খাৰঘ, --, 
   {{0xdb1c007c,0x01d00116,0x00000000,0x00000000}},	//   ntrö, _ﻛﻪﻳﻨ, --, --, 
   {{0xa280036b,0x00000000,0x00000000,0x00000000}},	//   _تیکو, --, --, --, 
   {{0x7e98f85d,0xdb1c007c,0xa2880240,0x00000000}},	//   _بنظر_, htrö, _መሳኪን_, --, 
   {{0x78ac0810,0xf2d000c8,0x6d8800de,0xdb1c007c}},	// [1f880] _pebv, כען_, _bļau, ktrö, 
   {{0xbca440c7,0x6d88005f,0x00000000,0x00000000}},	//   _تمدي, _pļav, --, --, 
   {{0x62893e46,0x6f0800d2,0x78ac0099,0x8b94005b}},	//   _oggo, _úmcá, _vebv, _пряч, 
   {{0x6288034c,0xb6a40139,0x00000000,0x00000000}},	//   _nggo, фидл, --, --, 
   {{0xd064013f,0xdb1c26bc,0x00000000,0x00000000}},	//   _ɑsɑs, ftrö, --, --, 
   {{0x62893e47,0x00000000,0x00000000,0x00000000}},	//   _aggo, --, --, --, 
   {{0x929400c0,0xef1c000d,0x00000000,0x00000000}},	//   найц, _पवलऽ_, --, --, 
   {{0x81fc025c,0xe8700014,0xd5280051,0xe2340023}},	//   _ཙནྡྲ_, _شۆنگ, _bỗn, _እትመሓ, 
   {{0x51f80212,0x00000000,0x00000000,0x00000000}},	//   їною_, --, --, --, 
   {{0x62893e48,0xd1304e77,0x00000000,0x00000000}},	//   _eggo, امد_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb22425ff,0x248001ef,0x00000000,0x00000000}},	//   _омел, _újma_, --, --, 
   {{0x6e5002d3,0xde6402e8,0xaa7800a2,0x00000000}},	//   _ዘንጸባ, върп, _obýa, --, 
   {{0x63500311,0x4c6c0220,0x00000000,0x00000000}},	//   măna, _ﺴﻭﺍﺀ_, --, --, 
   {{0x1bd47863,0x62880076,0xaf504caf,0x212806af}},	//   коря, _yggo, _инкә, êche_, 
   {{0xae30021a,0xa3cc073d,0x0ba40022,0x00000000}},	//   _لوبډ, वंत_, _ҿымҭ, --, 
   {{0x49753e49,0x0974034b,0x53700092,0x6d8800e2}},	// [1f890] елас, егаю, ስረዳት_, _pļau, 
   {{0xb6a010cf,0xe6a4547d,0xe06800db,0xa3cc0073}},	//   қишл, खर्ज, _اشۇۇ_, वूड_, 
   {{0x6aac00d8,0x1eb80137,0x58d4119e,0x48c4008e}},	//   _tecf, _экөө_, тохт, _җәза, 
   {{0x06741422,0x00000000,0x00000000,0x00000000}},	//   нуля, --, --, --, 
   {{0xba980375,0xae0c76d2,0xdb1c01e3,0x00000000}},	//   _מסרי, ामिन_, ttrö, --, 
   {{0xc4c801ad,0x19e40022,0x00000000,0x00000000}},	//   रलेख, _шәсҳ, --, --, 
   {{0x58d53e4a,0xf8b0008d,0xdb1d3e4b,0xaa780432}},	//   _шорт, _תשל_, rtrö, _naýz, 
   {{0xdb1d3e4c,0xae0c36c7,0x00000000,0x00000000}},	//   strö, ामान_, --, --, 
   {{0xe29404a2,0x6350054e,0x23c001d9,0x7d18007c}},	//   пақ_, găna, رٕکہ, ötsk, 
   {{0x637400c7,0xa3cc0a8a,0x00000000,0x00000000}},	//   kãng, वंद_, --, --, 
   {{0xeabc0ca8,0xa2d42677,0x00000000,0x00000000}},	//   _odù_, _याप्, --, --, 
   {{0xdb1d3e4d,0xad980af2,0x62880869,0xaa78010b}},	//   ntrô, dvúb, _uggo, _daýz, 
   {{0x1fdc02f5,0x5fd8000d,0x00000000,0x00000000}},	//   বয়ংস, _बहकल, --, --, 
   {{0x527411fc,0xaa7800a2,0x72180375,0x6d880171}},	//   _شانز, _faýz, _מונח, _aļas, 
   {{0xed553e4e,0xec7448bd,0xdb1c0109,0xaa7800a2}},	//   хор_, епр_, ktrô, _gaýz, 
   {{0xaa7800ee,0xeb1c1cd2,0xc62400fe,0xc8dc19cc}},	//   _haýy, _यकृत_, _মইনা_, न्सट, 
   {{0xb0b41533,0xa2d4228a,0xaa78010b,0x8e540153}},	// [1f8a0] _आजमग, _यान्, _kaýy, _атэі, 
   {{0x0d640124,0x3eb000a2,0xaa7800ee,0xd52c01e1}},	//   _иныҟ, _heyt_, _jaýy, _mọ́l, 
   {{0x7d1d3e4f,0xacd400c8,0x3eb0022e,0xaa78010b}},	//   _iops, _אויפ_, _keyt_, _maýy, 
   {{0x7bcd3e50,0xaa780209,0xa29c00bc,0x00000000}},	//   mubu, _laýy, _ग्ल्, --, 
   {{0x7d1d3e51,0x393401c0,0x041c00cc,0x273000cf}},	//   _kops, _зэвс, _ভেলী_, دىنس, 
   {{0x7d1c01e4,0x7f4403f0,0x66000640,0xaa78010b}},	//   _jops, hikq, упља, _naýy, 
   {{0x7bcd3e52,0x533402de,0x7f4400b5,0x399401bf}},	//   nubu, кект, kikq, _hæs_, 
   {{0xdc1000cd,0xf1a4013e,0x7d1c1337,0x3eb00162}},	//   _aśīt, нрон, _lops, _neyt_, 
   {{0x320003c6,0x7bcc50f9,0x7d1d3e53,0xaa78010b}},	//   íky_, hubu, _oops, _baýy, 
   {{0x7d1c005b,0xaa7800a2,0x00000000,0x00000000}},	//   _nops, _paýz, --, --, 
   {{0x399407ad,0x64a06286,0x8f341d39,0xaa78010b}},	//   _læs_, _саха, венц, _daýy, 
   {{0xd3782808,0x7bcc8683,0xdb1c0428,0x15f4772c}},	//   _opći_, dubu, rurû, _इनार_, 
   {{0xdb1c011f,0x01f400c7,0x3994148b,0x21a001c6}},	//   burú, _аҭыш_, _næs_, _бичм, 
   {{0x7d1d3e54,0x7bcc0337,0xaa780432,0x21280221}},	//   _cops, fubu, _gaýy, ëcht_, 
   {{0x7bcd3e55,0xf420015b,0x46d13e56,0x77600009}},	//   gubu, _ভেতর_, _हालह, koox, 
   {{0xdb680276,0x6374035b,0x00000000,0x00000000}},	//   ерул_, rãng, --, --, 
   {{0x7d1c0373,0xd5a432db,0x7f780150,0x00000000}},	// [1f8b0] _fops, _دہ_, _ﺃﺼل_, --, 
   {{0x7bcd3e57,0xf1cc04a2,0x399402d2,0x00000000}},	//   bubu, _ﻛﻪﻟﺘ, _dæs_, --, 
   {{0x7bcd3e58,0x6d453e59,0x00000000,0x00000000}},	//   cubu, mija, --, --, 
   {{0x7d1c090c,0x7de4013f,0x7c58009f,0x00000000}},	//   _zops, _wɔse, _آلٽر_, --, 
   {{0xb784052f,0x6f1c022e,0x7d1c022e,0x39953e5a}},	//   тәре_, _moqc, _yops, _gæs_, 
   {{0x2ebc00cd,0xe854030d,0x2ab80241,0x00000000}},	//   ्लुत, _пĕлн, bàbí_, --, 
   {{0xaca001f2,0xdce400e2,0xaa7800a2,0x00000000}},	//   _akịd, _etiķ, _raýy, --, 
   {{0x490405ba,0x07093e5b,0x05c8257b,0x4908012c}},	//   _होतो_, _تيري_, _रिपब, साको_, 
   {{0x44293e5c,0x6d453e5d,0xb6040232,0x7bcd3e5e}},	//   ņa_, kija, _pláž, zubu, 
   {{0x6d453e5f,0xbed00150,0x7bcc0a1d,0x312000c7}},	//   jija, _ارﻗﯩ, yubu, идыг, 
   {{0x7d1c1225,0x65613e60,0x6f1c2a89,0x3ea53e61}},	//   _rops, monh, _boqc, кинг, 
   {{0x65602508,0x7d1c1467,0x7bcd3e62,0x00000000}},	//   lonh, _sops, vubu, --, 
   {{0xb6b80302,0x6f1c047e,0x733800c8,0x7bcc3389}},	//   וצרי, _doqc, _קענס, wubu, 
   {{0x6da0896b,0xada0c9d8,0x7bcd3e63,0x6d453e64}},	//   рира, рарл, tubu, gija, 
   {{0x4a740046,0x7d1c084c,0x8cb40a89,0x00000000}},	//   ғытт, _vops, ысяч, --, 
   {{0x62993e65,0x7760102c,0x200816a3,0x656001f4}},	//   ncuo, xoox, čkić_, honh, 
   {{0x6d453e66,0x7d1d3e67,0x7bcd3e68,0x65613e69}},	// [1f8c0] bija, _tops, subu, konh, 
   {{0x7bcce19c,0x7d1c2aef,0x65613e6a,0x4d140108}},	//   pubu, _uops, jonh, _бьют, 
   {{0x65613e6b,0x7bcd3e6c,0xc9543452,0xdce400ef}},	//   donh, qubu, утты, _stiķ, 
   {{0x5eb000cc,0xd9b400d1,0x237c0210,0x00000000}},	//   _কাঁই, _مەرد, jmuj_, --, 
   {{0xca740b8d,0x38680042,0x6560072d,0xfbdc00eb}},	//   _буры, _wybr_, fonh, ডিওত, 
   {{0x65613e6d,0xc5f402dd,0x77600009,0xe7d000cf}},	//   gonh, ығу_, soox, _چۅلگ, 
   {{0xa9640022,0x8554006c,0xe7d000cf,0x19c50fbf}},	//   _рира_, دیلر_, _نۅلگ, _шәңг, 
   {{0x51f81c22,0xb284004e,0x00000000,0x00000000}},	//   ению_, кыпк, --, --, 
   {{0x875406bb,0x6d4468c5,0x65613e6e,0xa3b00d2e}},	//   _сърц, yija, bonh, जीब_, 
   {{0x65600261,0xa3cc00af,0xe5742de5,0x6f1c1ffc}},	//   conh, वंश_, _азу_, _soqc, 
   {{0x6f1c014f,0x00000000,0x00000000,0x00000000}},	//   _poqc, --, --, --, 
   {{0x6d453e6f,0x62993e70,0xe9fc01fb,0x6f1c014f}},	//   wija, ccuo, _giặc_, _qoqc, 
   {{0xa2d41f14,0x6d453e71,0x6f1c014f,0x2ef801a9}},	//   _यात्, tija, _voqc, _vaqf_, 
   {{0x32040004,0x61413214,0xdb1c0e78,0xd1300b73}},	//   _iroy_, _кеча, hrrä, _دمت_, 
   {{0xa1740375,0xa15401ec,0xabb0013d,0x00000000}},	//   _שעוד_, _шашу_, рабә, --, 
   {{0x6d453e72,0x7f54044e,0x65613e73,0xaca00241}},	//   sija, _gjyq, zonh, _ikọd, 
   {{0x00843c1a,0x183465dc,0x48c40131,0x05d0000d}},	// [1f8d0] _икәү, یرمح, ләва, _समइब, 
   {{0x6d440240,0xdb1c005b,0xe84806c2,0x00000000}},	//   qija, errä, وجان_, --, 
   {{0x237c033f,0x62980051,0x656000e5,0x00000000}},	//   ymuj_, ycuo, vonh, --, 
   {{0xa75c00a2,0x99d400cf,0xab6000d1,0xab84030d}},	//   _öpüň_, اقەت, _ئۇرى, _шупк, 
   {{0x65613e74,0x645c0213,0xbb3808c3,0x00000000}},	//   tonh, əqiy, _נעשי, --, 
   {{0x15a800a7,0x5574009d,0x00000000,0x00000000}},	//   тъци_, агчт, --, --, 
   {{0x25ec0034,0x58842e70,0x62980208,0xdb1c0fac}},	//   _इनकी_, _выта, tcuo, turø, 
   {{0x65613e75,0xd3781e31,0x82180261,0xaac0449f}},	//   sonh, _opću_, ецот_, षणिक, 
   {{0xaca00241,0x629807de,0x6560315a,0x237c033f}},	//   _akọd, rcuo, ponh, rmuj_, 
   {{0x62985256,0x603003be,0x6d54009a,0x320403b2}},	//   scuo, ləmə, _njxa, _droy_, 
   {{0xaac04c5b,0x7e740210,0x00000000,0x00000000}},	//   षणाक, _szyp, --, --, 
   {{0xc27400fb,0xbeec012d,0x603006be,0x00000000}},	//   _йылъ, ज़ेन_, nəmə, --, 
   {{0xc0e53e76,0xc5f8010f,0x67200200,0x6c7801ec}},	//   _болк, עפֿט, ënjy, _ﺤﺭﻭﺏ_, 
   {{0xeabc0241,0x603003b9,0x00000000,0x00000000}},	//   _olùs_, həmə, --, --, 
   {{0xdb1c007c,0x603006be,0x00000000,0x00000000}},	//   yrrä, kəmə, --, --, 
   {{0x25bcba9c,0x6d88025c,0x3f900115,0x00000000}},	//   _ovul_, _użan, ŭzus_, --, 
   {{0xdee41ee3,0xa3b01bf9,0x6f0c0118,0x603003b9}},	// [1f8e0] _боқи, जीत_, šicí, dəmə, 
   {{0xa9205976,0xdedc0150,0xdbb82a9d,0x00000000}},	//   бдул, _ﺃﻋﺠﺒ, _итмә_, --, 
   {{0xe1e405d9,0xbb4411f7,0x61e80205,0x7ae40051}},	//   _ڏس_, _бенк, _lpgl, _tbkt, 
   {{0x478802bf,0x61e83a65,0xe7340354,0x00000000}},	//   всім_, _opgl, лех_, --, 
   {{0xae0409ab,0x25bc0356,0x3f800010,0x2508036b}},	//   शियन_, _cvul_, imku_, کرنی_, 
   {{0x2004022e,0x8a100131,0x00000000,0x00000000}},	//   _orni_, _بېكت, --, --, 
   {{0xf3653e77,0x25bc0311,0x61e800e2,0x00000000}},	//   лтин, _evul_, _apgl, --, 
   {{0xc6d402dd,0x6840010a,0xe614104e,0x00000000}},	//   _ەتەت, _унса, тдә_, --, 
   {{0x798d3e78,0x20053e79,0xe7341789,0xd57c030d}},	//   _kibw, _arni_, _сет_, _зiак, 
   {{0x200401a6,0xd38801ec,0x00000000,0x00000000}},	//   _brni_, _ﺗﯟﯨﺖ_, --, --, 
   {{0x20042d2b,0x798c0085,0x03c40212,0x00000000}},	//   _crni_, _mibw, _всім, --, 
   {{0x798c043b,0x6d880327,0xe294074d,0x32040f85}},	//   _libw, _eżal, _бац_, _troy_, 
   {{0x20053e7a,0x32040117,0x3c780131,0x14c80073}},	//   _erni_, _uroy_, ﻠﯩﺸﻰ_, रणपण, 
   {{0x798c2da1,0xdd953e7b,0x3f80058a,0x998c00a2}},	//   _nibw, сары, amku_, _ülňi_, 
   {{0xf16001d9,0x00000000,0x00000000,0x00000000}},	//   _پُژپ, --, --, --, 
   {{0x7de40134,0x798c009f,0xdb1c007f,0x69dc025c}},	//   _wɔsa, _aibw, nsrè, ttqe, 
   {{0x798d3e7c,0xa9944028,0x5ed40150,0xa2d5087b}},	// [1f8f0] _bibw, اشرت, _اتىز, _यास्, 
   {{0xeabc003a,0x8c480166,0xe8ac04af,0x7d18007c}},	//   _plùs_, _poşı, टरेच, ötst, 
   {{0x798c382f,0x603000ac,0xa3b00037,0x8c480139}},	//   _dibw, təmə, _जौं_, _qoşı, 
   {{0x798c0295,0x57b4010b,0x76b400d1,0x2d813e7d}},	//   _eibw, сбцт, қләр_, lmje_, 
   {{0xfad41a4c,0x5d843886,0x2578025a,0xeabc01c3}},	//   _דורך_, _خلیل, hêle_, _flùr_, 
   {{0x6b94009a,0x98a4014b,0x00000000,0x00000000}},	//   _kuxg, _гиёе, --, --, 
   {{0x1959338b,0x6d88025c,0x9cd800d9,0x00000000}},	//   _сары_, _nżam, אווה_, --, 
   {{0xc32444b2,0x798c645f,0xb9dc02d3,0x00000000}},	//   рмик, _zibw, _ኣባ_, --, 
   {{0x798c01b2,0x3c781c5c,0x20043421,0x6b9404e6}},	//   _yibw, ﻠﯩﺴﻰ_, _srni_, _luxg, 
   {{0x3fe400a7,0xdb1c00a2,0xfd5400cd,0x00000000}},	//   ажов, durý, bhaṅ, --, 
   {{0x27340139,0x9968008f,0x7578010f,0xfd540055}},	//   _eçne_, רייַ_, _סטעפ, chaṅ, 
   {{0x200409a8,0x2d80002d,0x3f813e7e,0x6b8c01c3}},	//   _vrni_, emje_, umku_, _nicg, 
   {{0x6d880003,0xefb802d3,0x3f80193c,0xdb1c010e}},	//   _eżam, ዳለወ_, rmku_, gurý, 
   {{0x6b943ae4,0xd138d061,0x00000000,0x00000000}},	//   _buxg, chą_, --, --, 
   {{0x798c00ca,0x3ea4ae94,0x20053e7f,0xbea53e80}},	//   _ribw, _кийг, _urni_, _кайк, 
   {{0x798d3e81,0xccf47d9d,0x00000000,0x00000000}},	//   _sibw, _ққс_, --, --, 
   {{0x39453e82,0x00000000,0x00000000,0x00000000}},	// [1f900] анаг, --, --, --, 
   {{0xf09000c8,0x798c0477,0x00000000,0x00000000}},	//   ַנד_, _qibw, --, --, 
   {{0x798c01f7,0xa8840395,0x00000000,0x00000000}},	//   _vibw, айфа_, --, --, 
   {{0x798c0230,0x6b8c06be,0xbb84009f,0x01540023}},	//   _wibw, _gicg, _خلجي, _ዝጥቀም, 
   {{0x798d3e83,0x257800d2,0x9dec0327,0x3f500327}},	//   _tibw, zêle_, རསྲེ, rġuh_, 
   {{0x9570001f,0x00000000,0x00000000,0x00000000}},	//   _ቤቶችን_, --, --, --, 
   {{0x6d880327,0xb604032e,0x383400d1,0xdb1c0254}},	//   _bżaj, _bláþ, _ئىزز, kurü, 
   {{0xdb1d07a7,0x00000000,0x00000000,0x00000000}},	//   muró, --, --, --, 
   {{0xe5a13e84,0x7bcd3e85,0xdb1d3e86,0xa2d409ab}},	//   _мити, hrbu, luró, _यार्, 
   {{0x7bcc0427,0xe85000e5,0xa3b0012d,0x00000000}},	//   krbu, _انہد, जीह_, --, 
   {{0xb4d0098b,0x3d080b3c,0xee3c0022,0xf0740166}},	//   वली_, ायने_, mbýi_, ринә_, 
   {{0xeda4016c,0xa0853e87,0x2250020c,0xb28400cf}},	//   ишго, шсыз_, èaké_, _кылк, 
   {{0x9df85252,0x7bcc382c,0xd1e0001f,0xd34400f1}},	//   анят_, erbu, ዓቶች_, _پیښه_, 
   {{0xefb80020,0xa3b00412,0xd7a8002e,0x00000000}},	//   ዳለው_, जीव_, _ñoηa, --, 
   {{0x2d800b21,0x00000000,0x00000000,0x00000000}},	//   rmje_, --, --, --, 
   {{0xdb1c02d2,0x00000000,0x00000000,0x00000000}},	//   duró, --, --, --, 
   {{0x7bcc089c,0x6ce40845,0x6b8c0115,0x89d800e3}},	// [1f910] arbu, _кіне, _vicg, طوار_, 
   {{0xa8a53e88,0x28a40006,0x59d40efe,0x00000000}},	//   ррак, ршаг, تغفر, --, 
   {{0xd618028e,0x00000000,0x00000000,0x00000000}},	//   یتها_, --, --, --, 
   {{0x4b340066,0x00000000,0x00000000,0x00000000}},	//   _اکسس, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb1d3e89,0xe4e402bf,0xd5080131,0x63500356}},	//   buró, рідн, لغىن_, măni, 
   {{0xd7f93e8a,0xdb1c0077,0x63500356,0x00000000}},	//   _кут_, curó, lăni, --, 
   {{0xa9240419,0xdef40023,0x00000000,0x00000000}},	//   _daľš, ሌትን_, --, --, 
   {{0x163400c9,0x00000000,0x00000000,0x00000000}},	//   _детя, --, --, --, 
   {{0x23e400d6,0xd51805d9,0x6d880327,0xdedc0023}},	//   _відв, _پڙهڻ_, _wżaj, _ንዑኡ_, 
   {{0x40493e8b,0xe8dc07ae,0x24440022,0x63500356}},	//   упно_, _ngọc_, _тхаг, hăni, 
   {{0x6d88025c,0x427400db,0x8fd40124,0xee3c010b}},	//   _użaj, _лгес, цәшә, laýy_, 
   {{0xa3b00027,0x6ce01fd2,0x00000000,0x00000000}},	//   जीर_, गभंग_, --, --, 
   {{0x7de40134,0x52740214,0xdb1c000d,0x00000000}},	//   _wɔso, _بامز, surü, --, 
   {{0xdb1d3e8c,0x7bcc017a,0x05d0000d,0x00000000}},	//   xuró, urbu, _समझब, --, 
   {{0x63500356,0x7bcc69a5,0xee3c00a2,0x00000000}},	//   făni, rrbu, haýy_, --, 
   {{0x4ab810a7,0xcee800db,0x63740124,0xee3c010e}},	// [1f920] руся_, _ئرىن_, hãno, kaýy_, 
   {{0x3f909b2e,0xee3460c6,0x00000000,0x00000000}},	//   _hiyu_, _ыны_, --, --, 
   {{0xa5d43baf,0x3f900139,0x02f8102f,0x7c2800f3}},	//   ەبىر_, _kiyu_, ्याह_, _сонг_, 
   {{0x98b8046c,0x3f900455,0x074400d4,0x00000000}},	//   ızın_, _jiyu_, охім, --, 
   {{0x3f913e8d,0x7c2c03ac,0xcff0009e,0x6350054e}},	//   _miyu_, lybr, টিয়_, căni, 
   {{0xb4d0c775,0x7af53e8e,0xe9a13e8f,0xe7340131}},	//   वले_, leyt, _харп, _һес_, 
   {{0xa3b025c9,0x2934010f,0x15f400af,0x7c2c514c}},	//   जील_, _פאלן_, _इनकर_, nybr, 
   {{0xe44c0491,0x7af53e90,0xe7343c1b,0x66e13e91}},	//   عضو_, neyt, _лес_, _носа, 
   {{0x5f1c00dc,0xee3c00a2,0x00000000,0x00000000}},	//   यान्_, baýy_, --, --, 
   {{0x3ea0002f,0x7af401f4,0x00000000,0x00000000}},	//   eckt_, heyt, --, --, 
   {{0x3f904437,0x7af53e92,0x61ec0139,0x00000000}},	//   _biyu_, keyt, _ƅilä, --, 
   {{0xeea811db,0xd4c400aa,0x257800d2,0x6d88031c}},	//   ыток_, _دغړي, mêla_, _iżai, 
   {{0x51190edd,0x3f913e93,0x78bc017a,0x28c800dc}},	//   _волю_, _diyu_, kapv, ाणमि, 
   {{0x39480d27,0x3ea00036,0xeda4013e,0x00000000}},	//   _nmbs_, ackt_, ишҳо, --, 
   {{0x332401d9,0x244802d3,0x3f900083,0xcb6801b9}},	//   _koox_, _ንቕድሚ, _fiyu_, لمسه_, 
   {{0x39480ba1,0x332400e8,0x63500356,0xbfd802f2}},	//   _ambs_, _joox_, tăni, _ئاوڕ_, 
   {{0x9aa403e6,0xdb1c004e,0x628c0419,0x00000000}},	// [1f930] سملو, turò, žcov, --, 
   {{0xaa780232,0x3324300b,0x7c2c55ad,0xbd0000d8}},	//   _obýv, _loox_, bybr, _àépo, 
   {{0x228c3361,0x0a94ae2e,0x60c4033f,0x3f90047e}},	//   _kökü_, _маню, ójmi, _yiyu_, 
   {{0x2d9802d3,0xf8ac01d9,0x96b800cf,0x4cf400e5}},	//   _kuqe_, فکہ_, бушу_, _آگئ, 
   {{0x2c813e94,0xaef8030a,0x4658003b,0x00000000}},	//   bédé_, goùi, шадю_, --, 
   {{0xd6d803a5,0x2c801e4f,0x6abc037e,0x00000000}},	//   атә_, cédé_, laqf, --, 
   {{0xa3b00d01,0x5f1c0a28,0x3ea001e6,0x3d0800dc}},	//   जीं_, याम्_, yckt_, ायते_, 
   {{0x29013e95,0x2d9000d8,0x644c033f,0x68f40175}},	//   _haja_, _lixe_, _ścis, lexd, 
   {{0x29013e96,0x3324a121,0x7c2c012d,0xe4e400c0}},	//   _kaja_, _doox_, zybr, _гіен, 
   {{0x2578145e,0x6d880327,0xe3b0007b,0x2d90002f}},	//   bêla_, _użah, _فرص_, _nixe_, 
   {{0x3f901f06,0xdb1c0ad9,0x33240009,0x7af40784}},	//   _piyu_, kurð, _foox_, yeyt, 
   {{0x7c2c0122,0x3f693e97,0x2d90005a,0xb7d80a1e}},	//   vybr, римо_, _aixe_, סקרי, 
   {{0x7af53e98,0x7c2c0368,0x6abc022f,0xaa78012c}},	//   veyt, wybr, daqf, _zbýv, 
   {{0x29013e99,0x61f93e9a,0x7af4300b,0x3f90014f}},	//   _naja_, mwul, weyt, _wiyu_, 
   {{0x69c800bd,0x7af4049b,0x33253e9b,0xdb1c0008}},	//   ágen, teyt, _yoox_, furð, 
   {{0xdb1c2242,0x2d9115ab,0x7c2d3e9c,0x61f81418}},	//   gurð, _eixe_, rybr, owul, 
   {{0x29013e9d,0x2d913e9e,0x7af42833,0x7c2c0789}},	// [1f940] _baja_, _fixe_, reyt, sybr, 
   {{0x29013e9f,0x21253ea0,0x2b480ac5,0x257800d2}},	//   _caja_, _jonh_, _emcc_, yêla_, 
   {{0x29013ea1,0x61f894fe,0x212401ee,0xdb1c066a}},	//   _daja_, hwul, _monh_, burð, 
   {{0x21240ba1,0x7af53ea2,0x2c800129,0x00000000}},	//   _lonh_, qeyt, sédé_, --, 
   {{0x29013ea3,0x393401c0,0xef1c1cce,0x00000000}},	//   _faja_, _дэвс, kmün_, --, 
   {{0x29013ea4,0x257800d2,0x2d90004a,0xaef80165}},	//   _gaja_, têla_, _xixe_, roùi, 
   {{0x6d88025c,0x61f804ba,0xb4b809bb,0x00000000}},	//   _eżaw, ewul, _अजी_, --, 
   {{0x31c41830,0xa3b800c5,0x00000000,0x00000000}},	//   осов, _अबर_, --, --, 
   {{0x316c05b1,0x29013ea5,0x61f80472,0x65c00a93}},	//   _pkfz_, _yaja_, gwul, _обта, 
   {{0x30880395,0x925801ec,0x00000000,0x00000000}},	//   ищно_, _қалт_, --, --, 
   {{0x21240369,0x2d980a73,0x61f822a9,0x7538009d}},	//   _donh_, _suqe_, awul, _iltz, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x76413ea6,0x2124013f,0x2d900175,0x63500356}},	//   nzoy, _fonh_, _pixe_, gănu, 
   {{0x76400810,0x00000000,0x00000000,0x00000000}},	//   izoy, --, --, --, 
   {{0x29008616,0xeb480724,0xabd45e79,0xdb1c01a8}},	//   _raja_, ачак_, غزست, turð, 
   {{0x29013ea7,0x2d98208d,0x63500356,0x92cc00fe}},	//   _saja_, _tuqe_, bănu, শ্ৰ_, 
   {{0x29013ea8,0x7538de20,0x00000000,0x00000000}},	// [1f950] _paja_, _oltz, --, --, 
   {{0x26dc0592,0x2900016d,0x2d84007f,0x490400af}},	//   _scuo_, _qaja_, _òne_, _होखो_, 
   {{0xab853ea9,0x2900007d,0xd1f802d3,0x00000000}},	//   _мумк, _vaja_, ዋህበ_, --, 
   {{0x29013eaa,0x753801c0,0xdb140008,0x6abc022f}},	//   _waja_, _altz, _þaða, qaqf, 
   {{0x5f1c1161,0xe4f42871,0xfb1808c3,0x00000000}},	//   यात्_, ंजलि_, _הורמ, --, 
   {{0x6020013f,0xd4980032,0x00000000,0x00000000}},	//   wɑmm, ҙрә_, --, --, 
   {{0xd4980daf,0xc2e84352,0x199422c3,0x00000000}},	//   әрә_, معظم_, _царя, --, 
   {{0x2a78001f,0x7538009d,0x61f8020c,0x42253eab}},	//   _ቡድኖች_, _eltz, twul, здив, 
   {{0xe4e43bb3,0x2124067c,0x6d880327,0x00000000}},	//   _міжн, _ponh_, _użaw, --, 
   {{0x67380165,0x6020016b,0x61f93eac,0xa2d406b1}},	//   _hluj, sɑmm, rwul, _याक्, 
   {{0xa300005e,0x6738030a,0x00000000,0x00000000}},	//   _жүйе, _kluj, --, --, 
   {{0x6440022e,0x00000000,0x00000000,0x00000000}},	//   mzni, --, --, --, 
   {{0x01a80451,0x64400010,0xef1c0790,0xc0f80b82}},	//   _اُتي_, lzni, mmül_, ላስል_, 
   {{0x67380309,0x6e2800e4,0x00000000,0x00000000}},	//   _lluj, _ũmbá, --, --, 
   {{0x673807f5,0x5f1c0882,0x25f805d7,0x1f8401ee}},	//   _oluj, याद्_, लौती_, _оҫон, 
   {{0x2ee80175,0xe8f401c6,0x00000000,0x00000000}},	//   cfcf_, үлт_, --, --, 
   {{0xdb1c00c5,0x00000000,0x00000000,0x00000000}},	// [1f960] kurö, --, --, --, 
   {{0x01bc0d42,0x673807b4,0xbd440451,0x6bd40014}},	//   _আমাদ, _aluj, _رنجي, _کوَس_, 
   {{0xfaa4b40e,0x6b8002b5,0xb17808d8,0x67380200}},	//   _нано, _ūnge, צטער, _bluj, 
   {{0x6738084c,0x6e2800d2,0x644000e2,0xe9fc0208}},	//   _cluj, _émbá, dzni, _giắc_, 
   {{0xec10006c,0x4a7410de,0x00000000,0x00000000}},	//   _قوید, _жырт, --, --, 
   {{0x673800c5,0x76401afe,0xcc0800f2,0x00000000}},	//   _eluj, rzoy, _ازین_, --, 
   {{0xe3ac774e,0x673804cf,0x73483da1,0x3de000fe}},	//   هري_, _fluj, йчив_, যবিল, 
   {{0x6738030a,0xb6a402e8,0x5214ec1c,0x795002f2}},	//   _gluj, _хиал, ддит, _تێڕا, 
   {{0x64413ead,0x6b8001c7,0xd25003e6,0x3168009d}},	//   azni, _ënge, خۆش_, йшоо_, 
   {{0xe1ec1bb1,0x64a13eae,0x75393eaf,0x12cc009e}},	//   اسي_, _зафа, _ultz, লভেদ, 
   {{0x6440006d,0xaf500598,0x7e7400a2,0xdb1c0254}},	//   czni, еннә, _ayyp, lurõ, 
   {{0xa8540375,0xe478010f,0x2324014b,0xd3700345}},	//   לייה_, _פראכ, _нохи_, _جێبک, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb4b807b7,0xef1c15b7,0x00000000,0x00000000}},	//   _अजो_, mmüm_, --, --, 
   {{0xf1a80345,0x3084010a,0x00000000,0x00000000}},	//   _ئاڵه_, _хăвс, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd1f80023,0xd484004b,0x644001f5,0x68e0067c}},	// [1f970] ዋህቦ_, _څۀ_, zzni, òndo, 
   {{0x67382c05,0xdb1c000d,0x00000000,0x00000000}},	//   _sluj, durõ, --, --, 
   {{0x67387172,0x99e400bc,0xa0980a7c,0xfaec01e2}},	//   _pluj, ěňat, ציאט, دګۍ_, 
   {{0x067461cc,0x6d880003,0x644002fb,0xc6240154}},	//   муля, _eżat, vzni, _মেগা_, 
   {{0xdb1c0332,0x00000000,0x00000000,0x00000000}},	//   arró, --, --, --, 
   {{0x6440002f,0x00000000,0x00000000,0x00000000}},	//   tzni, --, --, --, 
   {{0x6440030a,0xdb1c03f2,0x4da803d4,0x00000000}},	//   uzni, lsrá, _কটোৱ, --, 
   {{0x613c145e,0x67393eb0,0x7c280798,0x42d40a4a}},	//   _mêle, _uluj, _àfre, фіку, 
   {{0x64413eb1,0xef1c0790,0x82f8073e,0xdb1c03b2}},	//   szni, rmül_, مرکز_, nsrá, 
   {{0xdb1c00d8,0x7e74005b,0x00000000,0x00000000}},	//   lurô, _ryyp, --, --, 
   {{0xece0015b,0x637400e4,0x7e740108,0x00000000}},	//   য়াড, hãni, _syyp, --, 
   {{0xd3d800c6,0x00000000,0x00000000,0x00000000}},	//   _ربما_, --, --, --, 
   {{0xc0e40137,0x88d40154,0x3d0800bc,0x527400d8}},	//   _жолк, স্যক, ायले_, _пушу, 
   {{0x52840184,0x80244f4e,0xad9800e4,0x00000000}},	//   _яҡын_, _يرغم, yvúv, --, 
   {{0x7ff4aaa5,0x63a00098,0xfaa41503,0x3b080353}},	//   _آستا, nqnn, дабо, оево_, 
   {{0x7e74049b,0xf09002e4,0xf4280139,0x00000000}},	//   _tyyp, _בנו_, ldäñ_, --, 
   {{0xdb1c2200,0xdb1400e4,0xdef40240,0x00000000}},	// [1f980] gsrá, _ñaín, _ልኢኹ_, --, 
   {{0xe9d53eb2,0xd9109fb2,0xbd4400ec,0xada0030d}},	//   ьку_, دیس_, _آندي, _шаьл, 
   {{0xad180bd9,0xbb447549,0x3b853eb3,0x9aa80132}},	//   _וויר, _женк, _олог, _ىندە_, 
   {{0x6d880135,0x00000000,0x00000000,0x00000000}},	//   _wżat, --, --, --, 
   {{0x3f481682,0xe5a1116b,0xa2d400dc,0x00000000}},	//   ṱuwa_, вичи, _याज्, --, 
   {{0x1cbc0003,0x06653eb4,0x6d88003d,0x00000000}},	//   _ཆབས_, رانپ, _użat, --, 
   {{0xdedc0092,0x290401e4,0xd8840220,0x00000000}},	//   ንንና_, ɾna_, _ﺩﺍﻣﯟ, --, 
   {{0xe3ac3b98,0xf1a40c60,0x00000000,0x00000000}},	//   جرو_, мрон, --, --, 
   {{0xd57c074d,0x00000000,0x00000000,0x00000000}},	//   _дiак, --, --, --, 
   {{0x63c405ac,0xf8dc000d,0x00000000,0x00000000}},	//   ærnæ, मलिय, --, --, 
   {{0x25082c26,0x3f50009b,0xa2d41fbc,0xe8d40375}},	//   _برقی_, ršun_, _याच्, וויר_, 
   {{0x2a9c01e1,0xdb1c03f2,0xa3b0228d,0xef1c010e}},	//   _m̀bá_, lsræ, जीओ_, mmük_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd010528e,0xdb1c0162,0x61100024,0x00000000}},	//   _ملت_, nsræ, _адшу, --, 
   {{0xdd953eb5,0xd138012d,0xa14800e5,0x60d8011a}},	//   тары, mką_, _بسنے_, _וקונ, 
   {{0xd138d591,0xdb1c1427,0x00000000,0x00000000}},	//   lką_, tsrá, --, --, 
   {{0x9e24215c,0x49d801ca,0xdebc011a,0xa2a00118}},	// [1f990] _لىيو, ядаю_, _ומחל, छुट्, 
   {{0xd138d5fb,0x2008033f,0xdb1c1427,0x00000000}},	//   nką_, łcie_, rsrá, --, 
   {{0xc32404c5,0xd1380024,0x290400d0,0xdca40798}},	//   বসতি_, iką_, ľna_, _шаќи, 
   {{0xdce400ef,0xcfe00154,0x00000000,0x00000000}},	//   _buiķ, _বনান, --, --, 
   {{0xfad40302,0xd1380210,0xdb1c08a5,0x00000000}},	//   _אורך_, kką_, fsræ, --, 
   {{0xc7480014,0xdb1c03b2,0xd138012d,0x00000000}},	//   _کٔرو_, gsræ, jką_, --, 
   {{0xd138033f,0x099001ec,0xe8c801f9,0x00000000}},	//   dką_, _ﺑﻮﻳﻼ_, ाणीच, --, 
   {{0x02053eb6,0xd6d800cf,0xdedc0023,0x984801d9}},	//   езин, _оту_, ንዕና_, _کلہٕ_, 
   {{0xd774a2ee,0x95c8004e,0x00000000,0x00000000}},	//   _شافع, _жуха_, --, --, 
   {{0x7fd53934,0x6ab80183,0xd5ac00e5,0xd684014b}},	//   німі, ইলটো, _بہو_, _русп, 
   {{0xd54800f1,0x9404009f,0x00000000,0x00000000}},	//   _تللو_, _لوله, --, --, 
   {{0x9f4804ce,0xf3f40330,0x53140117,0x00000000}},	//   _opnå_, _ستمک, _афшу, --, 
   {{0xee353eb7,0xada006b4,0xd1380210,0xbe340c75}},	//   еня_, лаял, bką_, رىسب, 
   {{0xd138d061,0xc0f80092,0x3864054e,0xc0e4004e}},	//   cką_, ላትም_, şori_, _чокк, 
   {{0x769406be,0x00000000,0x00000000,0x00000000}},	//   _küyü, --, --, --, 
   {{0xab24cea2,0x11d419c5,0x32d803b9,0x00000000}},	//   носа_, _ستۇد, müyü_, --, 
   {{0x6b600372,0xdcd80316,0xfe7000c6,0x4ae002e5}},	// [1f9a0] укта, _भएपछ, _حدث_, _फारव, 
   {{0x2bfc00cc,0x00000000,0x00000000,0x00000000}},	//   _উপৰে_, --, --, --, 
   {{0x313400c8,0xdb1c0174,0x32d80205,0x00000000}},	//   ענעם_, vsræ, nüyü_, --, 
   {{0xe7b0014d,0xcc34035b,0xe2845262,0x38c80133}},	//   امند, _рхьы, _مذ_, زاڕی_, 
   {{0xba7410fe,0x6a980302,0xa6c40228,0x6b8002b5}},	//   _ساحت, _משכנ, روول_, _ënga, 
   {{0x32d80205,0x00000000,0x00000000,0x00000000}},	//   küyü_, --, --, --, 
   {{0x7694079d,0x292400d7,0x00000000,0x00000000}},	//   _büyü, úvať_, --, --, 
   {{0xd138033f,0x769406be,0x637400e4,0x32d803e3}},	//   wką_, _cüyü, kãnu, düyü_, 
   {{0xd250034c,0x6b580724,0xd1380034,0x76940213}},	//   شند_, lägä, tką_, _düyü, 
   {{0xe5a0c649,0xd1380006,0x69c93eb8,0xdb1c01e3}},	//   _сифи, uką_, ágei, lsrä, 
   {{0xd1393eb9,0x20100005,0x7ae53eba,0x853400cf}},	//   rką_, _áxil_, _ockt, _جولچ, 
   {{0xd138d5fb,0xdb1c893b,0x93400131,0x1c1407f7}},	//   ską_, nsrä, ﻪﻳﺪﯗ_, डिनल_, 
   {{0x6b4000af,0x31f8025c,0xd138012d,0xd204014b}},	//   _jõge, _དགྲར_, pką_, _рӯйк, 
   {{0x10751ed9,0x7ae4127b,0x00000000,0x00000000}},	//   _иллю, _ackt, --, --, 
   {{0x291c0016,0xf15003e6,0xdb1c01e3,0x769403b9}},	//   _đua_, _لێکد, ksrä, _yüyü, 
   {{0xd01016cb,0x8e14084c,0xaf342f84,0x0e1400f3}},	//   _ملڪ_, _адиц, _سرعت, _амиџ, 
   {{0xdb1c049f,0x6b400037,0x00000000,0x00000000}},	// [1f9b0] dsrä, _nõge, --, --, 
   {{0x22a40ca8,0x00000000,0x00000000,0x00000000}},	//   _kíkó_, --, --, --, 
   {{0x6ab800fe,0x00000000,0x00000000,0x00000000}},	//   েলবো, --, --, --, 
   {{0x257800d2,0xcb3400a7,0x613c39b4,0xca8401c0}},	//   mêli_, _ремъ, _mêla, _үгүй, 
   {{0x5b1406bb,0x9a853ebb,0x84e40408,0x680c00dc}},	//   _смят, _бурл, волж, _ṛddh, 
   {{0x6b580139,0xbf1c0118,0x00000000,0x00000000}},	//   bägä, _बच्न_, --, --, 
   {{0x32053ebc,0x69dc014b,0x637400c7,0xf5300120}},	//   _asoy_, luqe, kãnt, рејќ, 
   {{0x258400bc,0xd7880137,0xd794014b,0x00000000}},	//   _bílý_, _كەلۉ_, _бисъ, --, 
   {{0x33900597,0x93242dfc,0x15f40b61,0x64440327}},	//   جليز, ارىن, _مسلح, _żjid, 
   {{0x613c025a,0xdb1d3ebd,0x00000000,0x00000000}},	//   _bêla, msrå, --, --, 
   {{0x5ec404a9,0x3f680640,0x83a4035b,0x76940205}},	//   линғ, дино_, _рызҵ, _tüyü, 
   {{0x69dc0912,0x32d80205,0x9954013d,0x00000000}},	//   kuqe, rüyü_, käş_, --, 
   {{0xdb1c21e3,0xadf001b9,0xf8e000dc,0x7ff42e0b}},	//   nsrå, апўш, _पालय, رسگا, 
   {{0x99540166,0x32d806be,0x00000000,0x00000000}},	//   däş_, püyü_, --, --, 
   {{0x60c0000f,0x2d9c067c,0xa2800101,0x00000000}},	//   _ienm, íuer_, _جیکو, --, 
   {{0xdb1ce155,0x2004068c,0x60c00072,0x25bc002e}},	//   ksrå, _isni_, _henm, _owul_, 
   {{0x60c044b6,0xdb1c049f,0x69dc0b6f,0xb9e8010b}},	// [1f9c0] _kenm, vsrä, guqe, ьмаз_, 
   {{0xdb1d3ebe,0x60c0014f,0xaca0010e,0x0c940166}},	//   dsrå, _jenm, _diỳd, _әшья, 
   {{0x60c13ebf,0x25bc00e8,0xdb1c5b00,0x6b400254}},	//   _menm, _awul_, tsrä, _sõge, 
   {{0x60c13ec0,0x69dc0117,0x6b4000af,0xfaa53ec1}},	//   _lenm, buqe, _põge, _шамо, 
   {{0xc7646abd,0x7bd93ec2,0xe0c40214,0xe73801d9}},	//   دالى, štud, _پز_, بتٕچ_, 
   {{0x60c0014f,0x20053ec3,0xa5040114,0xdb1d2985}},	//   _nenm, _osni_, веља_, ssrä, 
   {{0xf3644eca,0x250801d5,0xa7a53ec4,0xf87408f0}},	//   ктин, برنی_, _акса_, _شهرج, 
   {{0x2fdc03a2,0x7280001f,0x00000000,0x00000000}},	//   vutg_, _የታወቀ_, --, --, 
   {{0x35a42b39,0x20053ec5,0xfbb400fe,0x12ac02dd}},	//   _разг, _asni_, _জয়মত, _ﺴﺘﻜﻭ, 
   {{0x60c000b8,0x6444025c,0x61440248,0x867400c0}},	//   _cenm, _żjie, _rélù, _сысц, 
   {{0x8f353ec6,0x64a13ec7,0x32040108,0xd2502927}},	//   генц, _таха, _wsoy_, شنگ_, 
   {{0x6b800053,0x60c00ae3,0x62040724,0x20040263}},	//   _īngo, _eenm, ärlä, _dsni_, 
   {{0x77613ec8,0x23481973,0x60c02a01,0x63740022}},	//   inox, _تسلی_, _fenm, rãnt, 
   {{0x60c13ec9,0x6140041b,0x00000000,0x00000000}},	//   _genm, _веља, --, --, 
   {{0x69dc379d,0x600401c4,0x00000000,0x00000000}},	//   wuqe, _ахыг_, --, --, 
   {{0xeab00491,0x69dd3eca,0x60c00108,0xa094011a}},	//   شعر_, tuqe, _zenm, _בדוק_, 
   {{0x5a34e0a6,0xdb1c002d,0x60c005d1,0x293006ba}},	// [1f9d0] антт, lsrû, _yenm, ﺭﺍﭖ_, 
   {{0x58b80491,0x99540724,0x69dc011f,0xc0140183}},	//   نامج_, räş_, ruqe, াহৰণ_, 
   {{0x5cc4004e,0x1af800eb,0x00000000,0x00000000}},	//   _тсыз, ঁয়ে_, --, --, 
   {{0xdb1c78d0,0x6d443619,0x4a7458c5,0xf3f803d4}},	//   tsrå, lhja, _مُجر, ্মাৰ_, 
   {{0x96043009,0x6d44005b,0xd5e84677,0xe7fc000d}},	//   لبوم, ohja, نعون_, _ईनका_, 
   {{0x04c80338,0x41b40075,0xdb1c007c,0x00000000}},	//   روبي_, қсит, rsrå, --, 
   {{0x60c00d29,0x6d480006,0xd4e40229,0x00000000}},	//   _renm, _įgal, рючи, --, 
   {{0x442804b9,0x60c13ecb,0x6d440ffb,0x42080640}},	//   ća_, _senm, hhja, енио_, 
   {{0x60c13ecc,0xa504035b,0x5695022d,0x9b640055}},	//   _penm, _аҵла_, _ватт, _ḍukṛ, 
   {{0x814485d4,0x65840124,0x200400ae,0x00000000}},	//   اندن, _рыбз, _psni_, --, 
   {{0x60c00100,0xb4b4104e,0x6fb13ecd,0x00000000}},	//   _venm, _сихә, یمیا, --, 
   {{0x29cc00da,0x60c003f9,0xa2443321,0x00000000}},	//   kļa_, _wenm, _لیبل_, --, 
   {{0x60c13ece,0x8e5400d4,0x00000000,0x00000000}},	//   _tenm, атрі, --, --, 
   {{0xada13ecf,0x6da13ed0,0x6d453ed1,0xf8e009ab}},	//   сарл, сира, ghja, _पाइय, 
   {{0x69cc0175,0x65600eef,0x7fd400fa,0x00000000}},	//   _avce, innh, _сілі, --, 
   {{0x8b6400db,0xd0842ecb,0x6aac0334,0x65600175}},	//   لاقم, _тычи, _cfcf, hnnh, 
   {{0xeaac01d3,0xdb1c00ae,0x5fdc01f9,0x4a9400d8}},	// [1f9e0] سٹل_, osrú, पूरल, ајфу, 
   {{0x6d453ed2,0x9d5425ba,0x81e405ac,0x7c280129}},	//   chja, _ئۆست, _পনা_, _àfro, 
   {{0x69cc0205,0x3f500064,0x00000000,0x00000000}},	//   _evce, ešui_, --, --, 
   {{0x35a405f5,0x65600208,0x29cc00ef,0x00000000}},	//   гадг, ennh, bļa_, --, 
   {{0x81a839db,0x7bcc1654,0xb4b01cd1,0x00000000}},	//   গীত_, lsbu, билә, --, 
   {{0xf3f8025c,0x69c80327,0x8c4803b9,0x00000000}},	//   _ྒྱུད_, ġget, qişü, --, 
   {{0x7bcd3ed3,0x395800f2,0xa9653ed4,0x00000000}},	//   nsbu, mips_, _сира_, --, 
   {{0x6560014b,0x722932ba,0x53353ed5,0x39580afa}},	//   annh, ецов_, реит, lips_, 
   {{0xd130007b,0x7bcc0327,0x00000000,0x00000000}},	//   قمة_, hsbu, --, --, 
   {{0x7bcd3ed6,0xdb1c002d,0x317c01c4,0x39583046}},	//   ksbu, tsrû, ultz_, nips_, 
   {{0x7bcd3ed7,0xb4c01fc4,0x00000000,0x00000000}},	//   jsbu, ्णी_, --, --, 
   {{0xa0853ed8,0x7bccfbd4,0x39593ed9,0xb28400ee}},	//   ысыз_, dsbu, hips_, _йылк, 
   {{0xbbc0037e,0x6d453eda,0x9f5412fa,0xabc000d1}},	//   _ｍプ_, thja, свяч, _ﺩﯨﻴﺎ, 
   {{0x3958017a,0x00000000,0x00000000,0x00000000}},	//   jips_, --, --, --, 
   {{0x7bcd3edb,0x4c940212,0x6f0c03ac,0x99900139}},	//   gsbu, ривс, pdcc, _şaşa_, 
   {{0x6d453edc,0x7c3803cd,0x0ab40798,0x6e280241}},	//   shja, øtra, рбаџ, _àgbo, 
   {{0x3f4001e1,0x7bcc00a3,0x6d44035a,0xdb14010e}},	// [1f9f0] _kóun_, asbu, phja, _ýaýa, 
   {{0x6d440054,0x3958054e,0x29cc00de,0x00000000}},	//   qhja, gips_, rļa_, --, 
   {{0x6d553edd,0xef1c0793,0x1ce0031c,0x28840640}},	//   _imxa, glüg_, _ཤྰི_, ућав, 
   {{0x3f400ca8,0x0eb4012d,0x00000000,0x00000000}},	//   _lóun_, ंडिड, --, --, 
   {{0x3d0805ba,0x65600175,0xd7f00116,0x00000000}},	//   ायचे_, tnnh, قكە_, --, 
   {{0xef1cc022,0x290c005f,0xeb9c0fac,0x93a801b9}},	//   blüg_, ēgas_, _hiø_, گاوف_, 
   {{0x04441b0a,0x29040142,0x885800d8,0x00000000}},	//   рейн, ônau_, _ривс_, --, 
   {{0x613c0798,0x94740214,0x3e3c0092,0x39300092}},	//   _pêlo, حدها, አካባቢ, _በጊዜያ, 
   {{0xaca00241,0x3f4001e1,0x73302002,0x00000000}},	//   _ajọd, _bóun_, تىيا, --, 
   {{0x7bcd3ede,0xe9fc001e,0x00000000,0x00000000}},	//   ysbu, _giấc_, --, --, 
   {{0xff241f99,0xdcec01ef,0xd3d81bf4,0x00000000}},	//   амно, _řiďt, _مبنا_, --, 
   {{0x8bfc02a6,0x6d5401d9,0x00000000,0x00000000}},	//   ুমান_, _amxa, --, --, 
   {{0x93940d28,0x7bcc50eb,0xd94c0092,0xbb4c0150}},	//   _اجلا, wsbu, _ሁለቱን, _ﺃﺒﻨ_, 
   {{0x7bcd3edf,0xdb1c0158,0xe8280b82,0x6b80036e}},	//   tsbu, lsrø, _ተጋድሎ, _ëngj, 
   {{0xdd140030,0x4078010f,0x00000000,0x00000000}},	//   _túžb, _באַװ, --, --, 
   {{0x7bcd3ee0,0xdb1c6066,0x35c4012d,0x00000000}},	//   rsbu, nsrø, रीड़, --, 
   {{0xeb94c8c4,0x3958a68b,0x7bcd3ee1,0x3a24c00e}},	// [1fa00] рит_, tips_, ssbu, шмаг, 
   {{0x7bcc0522,0x3f8089b9,0x00000000,0x00000000}},	//   psbu, llku_, --, --, 
   {{0x39593ee2,0x3f800009,0xdb1c01bf,0x6c5801e1}},	//   rips_, olku_, ksrø, _tìlẹ, 
   {{0xd910021a,0xf7440063,0xf0900677,0x69c80327}},	//   _ډیر_, једо, קנא_, ġger, 
   {{0x16880032,0x613c0af9,0x7af4000f,0x3f810531}},	//   уҡай_, _pêll, mfyt, ilku_, 
   {{0x30e80882,0xb4c04668,0xc68c00f1,0x36680124}},	//   ज्ञः_, ्णे_, رېل_, наҵо_, 
   {{0x0fe06569,0xb7d8021a,0x5334e349,0xd4c401e0}},	//   _বন্ধ, _جوزا_, йект, _һөйк, 
   {{0x32080034,0xe7349102,0x7af40af9,0x66e00b00}},	//   łbym_, _кес_, nfyt, _моса, 
   {{0xd5a404fb,0xf50800c7,0xe7353ee3,0x3f4001e1}},	//   _طلای, _инал_, _тет_, _póun_, 
   {{0x457001ec,0x3f813ee4,0x64a0014b,0x00000000}},	//   _еңір, elku_, _дафа, --, 
   {{0x73340952,0xb4c01524,0x7af4002d,0xdb1c01bf}},	//   _پىشا, ंरी_, kfyt, bsrø, 
   {{0x71243b7a,0xc2e8007b,0x03a800ec,0x00000000}},	//   ارکل, _معهم_, _صدمو_, --, 
   {{0xf1a82d8d,0xee8411db,0xdd100419,0x3f400ca8}},	//   _شاشه_, рыно, _dľžk, _tóun_, 
   {{0xf1900050,0x73f80eac,0xa11001d9,0x3f800067}},	//   _بُتھ, ্মীয়_, _وونت, alku_, 
   {{0x92e802f5,0x2f880114,0x00000000,0x00000000}},	//   মজী_, _иљин_, --, --, 
   {{0xa098011a,0x998001e4,0x00000000,0x00000000}},	//   _ביוט, rviŝ_, --, --, 
   {{0x06dc045e,0xa8a4072c,0xe290010f,0xede401a9}},	// [1fa10] ণ্ডি, арек, ַװע_, _тўйн, 
   {{0x6d54009a,0xb4c000cd,0x3f500327,0x00000000}},	//   _umxa, ्णो_, wġux_, --, 
   {{0x2d8008ad,0xd7c8027d,0x6824035b,0x00000000}},	//   mlje_, لوله_, шьаз, --, 
   {{0x3984006a,0x2d813ee5,0x668001d5,0x00000000}},	//   bôso_, llje_, قیزل, --, 
   {{0xa99442c2,0x2d8008fb,0xdb1d3ee6,0xbb4c0150}},	//   _نشست, olje_, vsrø, _ﺃﺒﻠ_, 
   {{0xa8500058,0x3a3402e4,0x03a403f5,0x035400fd}},	//   _дегә, _הרשם_, бико, әүдә_, 
   {{0x58d4084c,0x3f800014,0x1958e738,0x00c8010b}},	//   _фост, ylku_, _тары_, ңлик_, 
   {{0x2d800010,0x00000000,0x00000000,0x00000000}},	//   hlje_, --, --, --, 
   {{0xdb1c0174,0x14e00073,0x3c7800d1,0xb060000d}},	//   rsrø, _नाचण, ﺠﯩﺴﻰ_, äänu, 
   {{0x66193ee7,0xdd0400e2,0x6b040327,0xdb1c03cd}},	//   _iruk, ēsīb, _ཅིའོ_, ssrø, 
   {{0x3ea4006c,0xdb240023,0x2d800010,0x6618032e}},	//   йинг, ërës, dlje_, _hruk, 
   {{0x2d80045f,0x3f800009,0x00000000,0x00000000}},	//   elje_, ulku_, --, --, 
   {{0xade000e1,0x2d800010,0x00000000,0x00000000}},	//   कूलन_, flje_, --, --, 
   {{0x66193ee8,0x7c380158,0x2d800010,0x00000000}},	//   _mruk, øtro, glje_, --, 
   {{0x7af4002d,0x10080150,0x0c980092,0x4418010f}},	//   tfyt, _ەتۋى_, _ሆናለች_, װוּס, 
   {{0x6b8c01ab,0x2d800b21,0xa3dc146c,0x7aa402e8}},	//   _chcg, alje_, _तिन_, сиаз, 
   {{0x2d80041a,0x81a8015b,0x7af53ee9,0xfce41f5a}},	// [1fa20] blje_, গীর_, rfyt, _лопо, 
   {{0xeee80016,0xf8c800bc,0xaa400276,0x00000000}},	//   ượng_, ktéž_, чеул, --, 
   {{0x66193eea,0xbdf81079,0x276801d5,0x00000000}},	//   _aruk, _شرکا_, گشلی_, --, 
   {{0x66193eeb,0x68e0067c,0x00000000,0x00000000}},	//   _bruk, òndr, --, --, 
   {{0xb4b03ad0,0x29200332,0x00000000,0x00000000}},	//   пилә, áraí_, --, --, 
   {{0x9878013d,0x35a401d5,0xe8500271,0x00000000}},	//   _кәеф_, _ҳааг, _کنفد, --, 
   {{0x68e13eec,0x628805c7,0x66185cb6,0x00000000}},	//   ónde, _azgo, _eruk, --, 
   {{0x66183402,0xd1d801af,0xda1c0073,0x5f18012d}},	//   _fruk, адиц_, निपत_, _बोल्_, 
   {{0x2d800225,0xf1a868c0,0xb514000d,0x00000000}},	//   ylje_, دابه_, _धोअय_, --, 
   {{0xf8b805d7,0x70e00490,0x250801b9,0x00000000}},	//   ेरिय, पलेल, _مرمی_, --, 
   {{0x2d800bb8,0xe1ec3ccd,0xe97800c8,0x62880175}},	//   vlje_, وسی_, רניש, _ezgo, 
   {{0x075401e1,0x00000000,0x00000000,0x00000000}},	//   _àìté_, --, --, --, 
   {{0x2d80110c,0x3f50262b,0x7bd92ee9,0x6fd806e3}},	//   tlje_, ešus_, átun, _भिवं, 
   {{0x21644358,0x2d80045f,0xd7d80073,0x69f001c6}},	//   _личи_, ulje_, डळाच, үүнт, 
   {{0x7bd81674,0x2d800841,0x00000000,0x00000000}},	//   štun, rlje_, --, --, 
   {{0x2d802630,0x9b580117,0x00000000,0x00000000}},	//   slje_, бист_, --, --, 
   {{0x3f50110c,0x1ed91695,0x00000000,0x00000000}},	// [1fa30] ršut_, _طبيب_, --, --, 
   {{0x99803361,0x66180200,0x205001af,0x00000000}},	//   rviş_, _rruk, _фтәр, --, 
   {{0x4c94f7cf,0xe7841ed2,0x66193eed,0x00000000}},	//   _финс, будо, _sruk, --, 
   {{0x66193eee,0x4dec00e1,0x7c3801f4,0x00000000}},	//   _pruk, _जमाई_, ätre, --, 
   {{0xd7f806dc,0x00000000,0x00000000,0x00000000}},	//   _қур_, --, --, --, 
   {{0xe4e4cea6,0x1ddc0243,0x00000000,0x00000000}},	//   сідн, _बिसत, --, --, 
   {{0xf8ac3cc4,0x00000000,0x00000000,0x00000000}},	//   _شکل_, --, --, --, 
   {{0x66193eef,0x85b808da,0x00000000,0x00000000}},	//   _truk, _влас_, --, --, 
   {{0xe4e8495f,0x6618a257,0x26cd3ef0,0x422402bf}},	//   _معاه_, _uruk, mago_, ідов, 
   {{0x26cd3ef1,0x62880fb7,0x00c80aac,0xa5000327}},	//   lago_, _vzgo, шлок_, _ཚིིག_, 
   {{0x02d8e5e7,0x2444009d,0x00000000,0x00000000}},	//   _نواب_, _ухаг, --, --, 
   {{0x26cd3ef2,0x7c280137,0x533401ce,0x764c0205}},	//   nago_, _àfri, _нехт, _önyü, 
   {{0x26cc005a,0x41293ef3,0xf8ac00fe,0xa06400c7}},	//   iago_, _воло_, গৰিথ, раҟа_, 
   {{0x26cd3ef4,0x00000000,0x00000000,0x00000000}},	//   hago_, --, --, --, 
   {{0x26cd3ef5,0x409458c5,0x00000000,0x00000000}},	//   kago_, _بلغر, --, --, 
   {{0xeee8001e,0x26cc310a,0x7bd80024,0x3f504a38}},	//   ưỡng_, jago_, štuo, ršus_, 
   {{0x26cd3ef6,0xcee81411,0xf294010f,0xdb1c0200}},	// [1fa40] dago_, _ارىن_, ַכער_, lprë, 
   {{0x6e380112,0xaef8030a,0xceac03b9,0x00000000}},	//   äube, riùe, ndәn_, --, 
   {{0xb900006d,0xfaa456b2,0x7aa53ef7,0x26cd3ef8}},	//   _नए_, _мано, _минз, fago_, 
   {{0x26cd3ef9,0xdb1c34eb,0x00000000,0x00000000}},	//   gago_, nsrü, --, --, 
   {{0x2b44054e,0xbbd801ef,0x00000000,0x00000000}},	//   _înca_, _बटुक, --, --, 
   {{0x26cc04ba,0x382c02d3,0xca7403e6,0x18b400c7}},	//   aago_, _ተዋሂብ, _ژنێک, _хәар, 
   {{0xf7440ce4,0x26cd3efa,0x00000000,0x00000000}},	//   _дево, bago_, --, --, 
   {{0x26cd3efb,0x75d408f0,0x70e008a3,0xa854011a}},	//   cago_, _ويزا, पल्ल, _וילה_, 
   {{0x247c001f,0xcc900055,0x00000000,0x00000000}},	//   ይመለስ_, _hṛto_, --, --, 
   {{0x60f4040e,0xcc9000cd,0x6e280241,0xb5940244}},	//   онья_, _kṛto_, _àgbi, _بێتا_, 
   {{0xdef402d3,0xdb1c0129,0xb22408a5,0x00000000}},	//   ልጦን_, rprê, ftæð, --, 
   {{0xa3dc000d,0x71a402d5,0x23240107,0x93bc0356}},	//   _तित_, _дадз, _мохи_, _prăf, 
   {{0x33253efc,0xdb1d3efd,0xe1f40148,0xeda40108}},	//   _inox_, mprè, _мгц_, юшно, 
   {{0x26cc01c6,0x00000000,0x00000000,0x00000000}},	//   zago_, --, --, --, 
   {{0x26cd3efe,0x33241590,0x93bc0276,0xaef801ab}},	//   yago_, _knox_, _drăg, riùb, 
   {{0x26cc0548,0xdb1c033b,0x6d480153,0x609c0023}},	//   xago_, nprè, _įgau, _ፍሉጣት_, 
   {{0xaf493eff,0xc8d80212,0x7ae000e8,0x1f7404b4}},	// [1fa50] _مشکل_, ймає_, óota, _юлъя, 
   {{0x26cc0f8b,0xb78400fd,0x27140051,0x00000000}},	//   wago_, җәсе_, _ển_, --, 
   {{0x26cd3f00,0x6b8002b5,0x00000000,0x00000000}},	//   tago_, _ūngu, --, --, 
   {{0xaca001f2,0x5ba402e8,0x48fc0037,0x00000000}},	//   _chụd, _оряз, _रउवो_, --, 
   {{0x26cc5114,0x00000000,0x00000000,0x00000000}},	//   rago_, --, --, --, 
   {{0x93bc054e,0xd6d80022,0x03a45c83,0x00000000}},	//   _orăd, бтә_, пико, --, 
   {{0x26cd3f01,0x2b482a1f,0x00000000,0x00000000}},	//   pago_, _klcc_, --, --, 
   {{0x0a400092,0x00000000,0x00000000,0x00000000}},	//   _የመስራ, --, --, --, 
   {{0x93bc054e,0x6b800022,0x00000000,0x00000000}},	//   _arăd, _ëngu, --, --, 
   {{0xe3b02088,0x93bc054e,0x2b480042,0x5574005b}},	//   _قرص_, _brăd, _llcc_, _жгут, 
   {{0x48fc0782,0x00840137,0x00000000,0x00000000}},	//   र्यो_, ялоо, --, --, 
   {{0x3f683b55,0xdb1c0112,0x7bd801d3,0x33f8011a}},	//   симо_, usrü, átum, _להענ, 
   {{0xdb1c01c7,0xc0ec0092,0x926800f3,0x00000000}},	//   sprë, _ፀጉር_, _мрља_, --, 
   {{0xdb1d3f02,0xb224008c,0x7bd802d5,0x450800fe}},	//   mpré, stæð, štum, লাকক_, 
   {{0x93bc084c,0x7c640075,0xed540fc0,0xca7c022e}},	//   _grăd, ساسل, чор_, _sosа, 
   {{0x8b953f03,0xf41000c8,0xe8b4025c,0x99800034}},	//   друч, עפן_, _བཅུག, zwiń_, 
   {{0x950c025c,0x93bc054e,0x00000000,0x00000000}},	// [1fa60] _གྲའི_, _trăg, --, --, 
   {{0xe9d401ce,0xfa6801d5,0x1ee80066,0xef1c2791}},	//   яку_, _ҳамк_, _اوکی_, nlün_, 
   {{0xdb2400dd,0x68e0041e,0x6d38011a,0x48fc00c5}},	//   _ہوگی, ónda, _התינ, _रउरो_, 
   {{0xdb1d3f04,0xe1b401a9,0xcc90002b,0x00000000}},	//   kpré, _o想_, _vṛto_, --, 
   {{0x39480a73,0x00000000,0x00000000,0x00000000}},	//   _tlbs_, --, --, --, 
   {{0xe3ad3f05,0x00000000,0x00000000,0x00000000}},	//   گرو_, --, --, --, 
   {{0xe4d00150,0x53353f06,0x692000d1,0x00000000}},	//   رتوب, дейт, _ямра, --, 
   {{0xe3ad3f07,0x075401e1,0x475800c0,0x00000000}},	//   درو_, _àìpé_, _друя_, --, 
   {{0xdb1d3f08,0x32000109,0x00000000,0x00000000}},	//   rprè, ïky_, --, --, 
   {{0x25f810f7,0xdb1d3f09,0x764000ca,0xdcfc01e4}},	//   ोबरी_, sprè, myoy, borĉ, 
   {{0x764003f9,0x93bc0356,0x00000000,0x00000000}},	//   lyoy, _brăe, --, --, 
   {{0xb8cc003d,0x753801c0,0x76400198,0xdb080214}},	//   _པུ_, _hotz, oyoy, _élèk, 
   {{0x76403142,0x75393f0a,0x48fc166d,0x00000000}},	//   nyoy, _kotz, र्डो_, --, 
   {{0x753805f5,0x93bc0311,0x61d800d9,0xe29800d9}},	//   _jotz, _trăd, _פקוד, _השדר, 
   {{0x75393f0b,0x317c01c0,0xa13004d3,0x5c040024}},	//   _motz, motz_, _سروش, нята, 
   {{0x753801c0,0x76400083,0x317cf2f1,0x950c0327}},	//   _lotz, kyoy, lotz_, _གིའི_, 
   {{0x7760172c,0xad24e750,0x6b40000d,0x49d80108}},	// [1fa70] diox, _فردو, _jõgi, юдаю_, 
   {{0x1cac003d,0xbb2c040d,0x75380a40,0x317d3f0c}},	//   _བུར_, ﯩﻠﻰ_, _notz, notz_, 
   {{0x6b400254,0x00000000,0x00000000,0x00000000}},	//   _lõgi, --, --, --, 
   {{0x317c01c6,0xbbd4008f,0x2b48007f,0x6d453f0d}},	//   hotz_, _קורץ_, _ulcc_, lkja, 
   {{0x76401c06,0x75380221,0x1a6801ed,0xb78402d9}},	//   gyoy, _botz, _ٹیلی_, фәре_, 
   {{0x6d453f0e,0x398400d2,0x49053f0f,0x6e280248}},	//   nkja, yôsi_, _توسق, _àgbu, 
   {{0xe9fc0016,0x753866e5,0x1cac025c,0xf7f005d9}},	//   _khắc_, _dotz, _བུལ_, _لڳند, 
   {{0x96f80364,0x76400083,0x64a001e0,0x6d440254}},	//   _нест_, byoy, маҙа, hkja, 
   {{0x6d453f10,0x753817da,0xe604005b,0xecbc0b27}},	//   kkja, _fotz, öpää, ्राफ, 
   {{0xdb1d3f11,0x753801c6,0x98480014,0x6738037e}},	//   rpré, _gotz, _بلہٕ_, _houj, 
   {{0xdb1c0372,0x656003b7,0x673804ce,0x5f4801c6}},	//   spré, minh, _kouj, зүйн_, 
   {{0x65613f12,0xe9fc001e,0x6738037e,0x7bd80006}},	//   linh, _nhắc_, _jouj, štuk, 
   {{0xdb080438,0x64413f13,0x93bc0311,0x673800b5}},	//   _élék, lyni, _grăb, _mouj, 
   {{0x65613f14,0x67380369,0xada03947,0x00000000}},	//   ninh, _louj, каял, --, 
   {{0xada13f15,0x628c0989,0x64413f16,0x70501b45}},	//   тарл, škoć, nyni, _لنوا, 
   {{0x65613f17,0xe9fc07ae,0x67380430,0xaef807c5}},	//   hinh, _chắc_, _nouj, liùn, 
   {{0x65613f18,0x64400142,0xb3400139,0x00000000}},	// [1fa80] kinh, hyni, _äçet, --, 
   {{0x65613f19,0x6440ac1d,0x764001f7,0x6d444d57}},	//   jinh, kyni, vyoy, ckja, 
   {{0x65613f1a,0x673802bd,0x2464016b,0x75381543}},	//   dinh, _bouj, _nɑm_, _rotz, 
   {{0x67380369,0x64413dd3,0x753801c4,0x317c005a}},	//   _couj, dyni, _sotz, zotz_, 
   {{0x67393f1b,0xe60c2be7,0x65613f1c,0x237c0369}},	//   _douj, لشو_, finh, douj_, 
   {{0x65601f44,0x1cac0003,0x644000a9,0x34493992}},	//   ginh, _བུས_, fyni, жчин_, 
   {{0x7df00085,0x67380165,0x317c067c,0x75380112}},	//   _dɛsɛ, _fouj, votz_, _votz, 
   {{0x27f4038e,0x67393f1d,0x237c0007,0x93bc0311}},	//   žení_, _gouj, gouj_, _prăb, 
   {{0x6d4431ac,0x65613f1e,0x644000ad,0x75393f1f}},	//   ykja, binh, ayni, _totz, 
   {{0x65600261,0x93bc0276,0x64405129,0xaef807c5}},	//   cinh, _crăc, byni, giùn, 
   {{0x67393f20,0x237c0007,0x317c009d,0x93bc0356}},	//   _youj, bouj_, rotz_, _drăc, 
   {{0xceb80598,0x6d440bc9,0x63b400d7,0x00000000}},	//   чәк_, wkja, žané, --, 
   {{0x6d4403b2,0x00000000,0x00000000,0x00000000}},	//   tkja, --, --, --, 
   {{0xefcc0092,0x00000000,0x00000000,0x00000000}},	//   ባሪው_, --, --, --, 
   {{0x6d441f60,0x88cc04c5,0xe9fc0051,0x7c440c5e}},	//   rkja, _লালক, _phắc_, _čurá, 
   {{0x65613f21,0x6d441f60,0x160032ed,0xd1d40092}},	//   zinh, skja, ोबार_, _የሴት_, 
   {{0x64400034,0x656051b0,0xef1c1b0d,0xfe7401f0}},	// [1fa90] zyni, yinh, nlüm_, _зӯр_, 
   {{0x65613f22,0x67380369,0xd48400aa,0x9dd80a1e}},	//   xinh, _souj, _نۀ_, _חוזק_, 
   {{0x65613f23,0xe9fc0016,0x5c74084c,0x673840e8}},	//   vinh, _thắc_, _алэт, _pouj, 
   {{0x64400024,0x65600810,0x1cac031c,0xaef80c86}},	//   vyni, winh, _བོུ_, ziùn, 
   {{0x65613f24,0x644000a9,0x7df0016b,0x6738030a}},	//   tinh, wyni, _pɛsɛ, _vouj, 
   {{0x64413f25,0x3fbc0075,0x67380099,0xd6d80075}},	//   tyni, ﻠﻪﺭﻧ, _wouj, птә_, 
   {{0x67393f26,0x65613f27,0x57b53f28,0x32053f29}},	//   _touj, rinh, _абст, _apoy_, 
   {{0x65613f2a,0x64413f2b,0xe8d00014,0x7c2802d2}},	//   sinh, ryni, _سۅچھ, _áfre, 
   {{0x65613f2c,0x64413f2d,0x85740124,0x237c0100}},	//   pinh, syni, _злах, rouj_, 
   {{0x64400652,0xd5b801ec,0x00000000,0x00000000}},	//   pyni, _ісу_, --, --, 
   {{0x1ee8034d,0x25bc0254,0xdb1c007c,0x00000000}},	//   وودی_, _htul_, msrö, --, 
   {{0xd49836ca,0xaef805d5,0xe8c800b8,0x20bc47b8}},	//   _цру_, siùn, िरुच, _श्रध, 
   {{0xefdc02d3,0x25bc0327,0xd29400c7,0x200800e8}},	//   ሓለወ_, _jtul_, _иршь, ňci_, 
   {{0x61f93f2e,0xe9fc0208,0xdb1c01e3,0xbd3400db}},	//   mtul, _chậc_, nsrö, رىزع, 
   {{0x80d4015b,0x3b9406ed,0x7ff4007b,0x1ddc012d}},	//   _দাপ্, ејат, _أستا, _बिकत, 
   {{0x61f93f2f,0x29000037,0x98b80327,0x200406be}},	//   otul, _abja_, _torċ_, _ipni_, 
   {{0x61f93f30,0x3f813f31,0xe8c84688,0x6b400254}},	// [1faa0] ntul, moku_, िरूच, _nõgu, 
   {{0x3f813f32,0xdb1c056a,0x61f93f33,0xa3dc0073}},	//   loku_, mprí, itul, तळा_, 
   {{0x25bc0198,0x3634dc7e,0x61f800c5,0xef1c1432}},	//   _atul_, کراس, htul, zlüm_, 
   {{0x61f93f34,0x25bc2948,0x3f8104aa,0x7c380158}},	//   ktul, _btul_, noku_, øtru, 
   {{0x499007d6,0xdb1c03b2,0x61f93f35,0xf62000c7}},	//   _چیقر, nprí, jtul, ыҧаҿ, 
   {{0x3f813f36,0x7d0c0086,0xdcfc00d0,0x61f8031c}},	//   hoku_, nebs, korč, dtul, 
   {{0x3f8004ce,0x61f93f37,0xdcfc00f3,0xef1c15b7}},	//   koku_, etul, jorč, rmüz_, 
   {{0x31c53f38,0xdcfc0cf4,0x3f800214,0x61f8054e}},	//   нсов, dorč, joku_, ftul, 
   {{0x61f93f39,0x95a40022,0x16840133,0xdb1c00d0}},	//   gtul, _алаҵ, _شارێ, jprí, 
   {{0xdb1c0419,0x00000000,0x00000000,0x00000000}},	//   dprí, --, --, --, 
   {{0xdfd4052f,0xdcfc892f,0xef1c1b0d,0x3f800200}},	//   нъя_, gorč, slüm_, foku_, 
   {{0x3f813f3a,0x33f800e8,0x61f80327,0xef1c9c11}},	//   goku_, mëx_, btul, mlük_, 
   {{0x61f93f3b,0xdb1c43e9,0xef1c75d4,0x00000000}},	//   ctul, gprí, llük_, --, 
   {{0xdcfd1bb5,0x2330035b,0xec1404b4,0x00000000}},	//   borč, _ахәр, негә_, --, 
   {{0xef1c36b5,0xdd953f3c,0x3f813f3d,0xeb480858}},	//   nlük_, уары, boku_, пчак_, 
   {{0x3f80eda4,0xcb081541,0x00000000,0x00000000}},	//   coku_, بيرن_, --, --, 
   {{0x6f0d3f3e,0x7d0c06be,0xef1c06be,0xd1380064}},	// [1fab0] mecc, bebs, hlük_, oją_, 
   {{0x6f0cebee,0xc608015b,0xef1c1432,0xd6c400d1}},	//   lecc, লিমা_, klük_, қишқ, 
   {{0x2d813f3f,0x25bd3f40,0x00000000,0x00000000}},	//   moje_, _stul_, --, --, 
   {{0x61f93f41,0x2d813f42,0xa78401d5,0x6b400037}},	//   ytul, loje_, رشاو, _põgu, 
   {{0xd77434f6,0x61f85ec3,0xdcfc8ead,0x7bd803b2}},	//   دالع, xtul, zorč, átuv, 
   {{0x2d813f43,0x69cc004b,0x3f80019b,0x29cc012d}},	//   noje_, _iwce, zoku_, mża_, 
   {{0x4374084c,0x3f813f44,0x98a40107,0x74100633}},	//   куит, yoku_, _биёе, لووا, 
   {{0x2d813f45,0x6f0c19c6,0x03253f46,0xd138033f}},	//   hoje_, jecc, тдин, eją_, 
   {{0x2d813f47,0x6f0c3b24,0x25bc0098,0x29cce35f}},	//   koje_, decc, _utul_, nża_, 
   {{0x2d800953,0xd6853f48,0xb88002fb,0xdcfc8c05}},	//   joje_, _сусп, číva, torč, 
   {{0xf8b00bd4,0x6f0c4c25,0x2d813f49,0x93bc0311}},	//   ישי_, fecc, doje_, _hrăn, 
   {{0x61f93f4a,0x7d0d3f4b,0x44253f4c,0xd1380034}},	//   ptul, webs, _irl_, ają_, 
   {{0x3f813f4d,0x2d8000c8,0x61f80cfe,0xee3501eb}},	//   roku_, foje_, qtul, вня_, 
   {{0x4d1400e6,0x3f80105c,0x2d813f4e,0xd138068f}},	//   льст, soku_, goje_, cją_, 
   {{0x6f0c0c95,0x3f813f4f,0xdbcc0005,0x63a8030a}},	//   becc, poku_, _póñe, _kign, 
   {{0xe3e0000e,0xdc8c0020,0x6f0d3f50,0x63a80276}},	//   _মহাব, _መድረክ_, cecc, _jign, 
   {{0x63a93f51,0xf2d004ac,0xef1c2c44,0x2d803974}},	// [1fac0] _mign, יען_, zlük_, boje_, 
   {{0x63a9008c,0x6288019b,0xddc800e5,0x2d813f52}},	//   _lign, _mygo, _élől, coje_, 
   {{0x69cc0472,0x63a93f53,0x62893f54,0x44253f55}},	//   _ewce, _oign, _lygo, _nrl_, 
   {{0x63a93f56,0x93bc0356,0xd138033f,0x29cc0135}},	//   _nign, _brăn, zją_, bża_, 
   {{0x628805ac,0x44240205,0xd138012d,0xaa780419}},	//   _nygo, _arl_, yją_, _vdýc, 
   {{0x63a93f57,0x6f0c0622,0x442438cb,0x2d4c04cc}},	//   _aign, zecc, _brl_, _lüen_, 
   {{0x6f0d3f58,0x6b800af2,0x62880009,0xb86402f2}},	//   yecc, _íngc, _aygo, _شاسو, 
   {{0x2d813f59,0x63a93f5a,0x6f0c172e,0x62893f5b}},	//   zoje_, _cign, xecc, _bygo, 
   {{0x63a93f5c,0x6f0d3c77,0x2d8001f7,0x93bc0356}},	//   _dign, vecc, yoje_, _grăn, 
   {{0x63a93f5d,0x4424002d,0x2d800023,0x62880142}},	//   _eign, _frl_, xoje_, _dygo, 
   {{0x6f0c0540,0x2d80e0d4,0xc4440050,0x63a93f5e}},	//   tecc, voje_, _میون_, _fign, 
   {{0x63a93f5f,0xd138033f,0x3f7400b0,0x2d813f60}},	//   _gign, sją_, tāua_, woje_, 
   {{0x2d813f61,0x21141b12,0x7bdc00ef,0xa2b800b8}},	//   toje_, رتیب_, _avpu, _ष्ट्, 
   {{0xe9fc01dc,0x6f0d3f62,0x63a93f63,0xd0d40395}},	//   _nhạc_, secc, _zign, _сокъ, 
   {{0x2d807da8,0x2f740124,0x06dc00fe,0x497401b9}},	//   roje_, _аҩны_, ণ্টি, ҳлас, 
   {{0x2d813f64,0xaa7800a2,0xc60803d4,0x63a80009}},	//   soje_, _adýa, লিতা_, _xign, 
   {{0x2d813160,0xef1c03e0,0x00000000,0x00000000}},	// [1fad0] poje_, mdü_, --, --, 
   {{0x29cd3f65,0xef1c046c,0xe9fc0208,0x2d800200}},	//   rża_, ldü_, _chạc_, qoje_, 
   {{0x1cac025c,0xef1c0793,0x1dac012d,0x28a40166}},	//   _བུག_, odü_, _टूटत, тшаг, 
   {{0x7c281873,0xef1d3f66,0xaa780432,0x00000000}},	//   _áfra, ndü_, _edýa, --, 
   {{0x44253f67,0x63a801a8,0x00000000,0x00000000}},	//   _srl_, _rign, --, --, 
   {{0x75d000c6,0xc8c93f68,0x62893f69,0xdb1c04d4}},	//   حيوا, _سورن_, _rygo, mprá, 
   {{0x63a93f6a,0xdcfc005f,0xad9804d4,0xef1c03e3}},	//   _pign, norā, ctúe, kdü_, 
   {{0xb880b7f2,0x93bc001e,0x62880295,0xaad13f6b}},	//   číta, _trăn, _pygo, तरिक, 
   {{0x63a93f6c,0x28a42efd,0xe50400cf,0xd04806be}},	//   _vign, _कृति, _لباي, madə, 
   {{0x98b802b1,0x442401c8,0xe2942e56,0x74c80882}},	//   _korā_, _trl_, нақ_, _स्पृ, 
   {{0x63a93f6d,0x6288068f,0xe654001f,0xb5a80150}},	//   _tign, _wygo, _ገልጠዋ, _ﺷﻮﻣﻌ, 
   {{0x6288068f,0xd04800ac,0x2bb400c5,0x81d46c9c}},	//   _tygo, nadə, _अढ़ा, _бодх, 
   {{0x1cac0135,0x6f6035c7,0x628801a9,0xce340014}},	//   _བུང_, связ, _uygo, لوَک, 
   {{0xd0480213,0x3d0c012d,0x00000000,0x00000000}},	//   hadə, ाजें_, --, --, 
   {{0x3b093f6e,0x717000f1,0xef1c06be,0x00000000}},	//   нево_, _دهوا, bdü_, --, 
   {{0xff5002da,0x00000000,0x00000000,0x00000000}},	//   _دخت_, --, --, --, 
   {{0xaec0040e,0x596414d4,0x3a24004e,0x4ab800d4}},	// [1fae0] _убыл, анағ, íop_, туся_, 
   {{0xe8f53f6f,0xbd0002fb,0x7bd81ac9,0x16cc15c0}},	//   ллу_, _šéfo, átus, ार्ब, 
   {{0xd0480cc1,0x7d1c03ac,0x6cf80a7c,0x00000000}},	//   fadə, _iaps, _אפיס, --, 
   {{0x27e53f70,0xf6d53ecd,0xc7951741,0xdb500244}},	//   ánna_, ازاد, арчы, _بێر_, 
   {{0x16353f71,0x6b8000d2,0xe9fc01fb,0xd9108341}},	//   реля, _ínga, _thạc_, _ویر_, 
   {{0x7af531b0,0xef1c1cce,0x7d1c01f4,0x00000000}},	//   lgyt, zdü_, _japs, --, 
   {{0x7d1c517e,0x53340124,0xb7940640,0x91cc00ab}},	//   _maps, иект, _браћ, _दौड़े, 
   {{0x7d1c3859,0xb6a53f72,0x75d43e45,0x7280001f}},	//   _laps, _библ, _ميرا, _ከታወቀ_, 
   {{0x31681515,0x39b00100,0xad98002d,0x7d1c035a}},	//   ешно_, _fņse_, ntúc, _oaps, 
   {{0x7d1d3f73,0x69f8008f,0x3d0c033f,0x35a41075}},	//   _naps, עליק, ाजों_, _сазг, 
   {{0xb4c009d9,0xdb1d3f74,0xaef801c3,0xfff405af}},	//   ूरी_, zprá, liùi, لکيت_, 
   {{0x3cf800db,0x7d1c017a,0xdb1c005c,0x64a00150}},	//   _acpv_, _aaps, lpræ, _уаха, 
   {{0xef1c4a4a,0x7d1d3f75,0x6ce401ca,0x00000000}},	//   rdü_, _baps, ліве, --, 
   {{0x74c82314,0xd0480213,0xdb1c01bf,0x00000000}},	//   _स्मृ, zadə, npræ, --, 
   {{0x7d1c0165,0x5d64005b,0x5f740330,0xe8e80014}},	//   _daps, стяз, _گاور, ہراو_, 
   {{0x7d1d3f76,0xdcfd3f77,0x7af40072,0x00000000}},	//   _eaps, rorā, ggyt, --, 
   {{0x7bd805f7,0x5f743418,0x7c74001f,0x28a403ce}},	// [1faf0] átur, _داور, ተላለፍ_, केनि, 
   {{0x6f1c047e,0x48c40220,0x998000ee,0x29053f78}},	//   _haqc, ршағ, ntiň_, ýna_, 
   {{0xdb1d3f79,0x6f1c0309,0x48141093,0x00000000}},	//   sprá, _kaqc, рмес, --, 
   {{0xd7c8b184,0x6f1c0455,0x7d1c00bc,0x00000000}},	//   اونه_, _jaqc, _zaps, --, 
   {{0x7d1c05d1,0x6f1c0455,0xa3d4033f,0x96f82bef}},	//   _yaps, _maqc, ़ीन_, اعمر_, 
   {{0x6f1c014f,0xdcfc0356,0xa6c4010a,0x00000000}},	//   _laqc, moră, ăлча_, --, 
   {{0x56941d56,0x93bc054e,0x00000000,0x00000000}},	//   _ҳатт, _frăm, --, --, 
   {{0x29101925,0x0a5c0020,0x6f1c014f,0x93bc054e}},	//   lexa_, _ለመስራ, _naqc, _grăm, 
   {{0xdb1c01bf,0x56941c0d,0xdcfc0356,0x00000000}},	//   bpræ, _гатт, noră, --, 
   {{0x6618cd7e,0x2910cdcf,0x68f40369,0x016400cf}},	//   _isuk, nexa_, ngxd, ркоо, 
   {{0x98b80356,0x00000000,0x00000000,0x00000000}},	//   _horă_, --, --, --, 
   {{0x7d1c0986,0x3f6864b3,0xbea40395,0xf8b000cd}},	//   _saps, тимо_, ианк, _जल्प, 
   {{0x92b41b06,0x6f1c0455,0x7d1d3f7a,0x2fdc04cc}},	//   _احما, _daqc, _paps, astg_, 
   {{0x66193f7b,0x00000000,0x00000000,0x00000000}},	//   _msuk, --, --, --, 
   {{0x7fd4005e,0x7d1d3f7c,0x4c34013d,0x28a419cc}},	//   _тілі, _vaps, бэтт, केमि, 
   {{0x7d1d3f7d,0x66193f7e,0xe9440517,0xc4d0547d}},	//   _waps, _osuk, یرلی, हरुख, 
   {{0x66193f7f,0xfce53f80,0x7af45d1d,0xaa452360}},	// [1fb00] _nsuk, _копо, rgyt, апта_, 
   {{0x7c280005,0x7c74001f,0xe8c44703,0xad984dda}},	//   _áfro, ተላልፍ_, игул_, rtúc, 
   {{0x66193f81,0xad980030,0x00000000,0x00000000}},	//   _asuk, stúc, --, --, 
   {{0x66182a1f,0xf624496c,0xdcfc054e,0x6c7802e4}},	//   _bsuk, идео, boră, _יריד, 
   {{0xdee4044e,0xa7100046,0x291002b9,0x661801d3}},	//   _ዜናን_, імші, bexa_, _csuk, 
   {{0x6e3841ba,0xb4c05572,0xaef801ab,0xf9600345}},	//   äubi, ूरे_, riùi, _بۆئێ, 
   {{0x66193f82,0xa9653f83,0xad9804d4,0xdb1c3774}},	//   _esuk, _тира_, ntúa, rpræ, 
   {{0x53340022,0xdb1c3c38,0x722801f4,0x00000000}},	//   сеит, spræ, вцов_, --, 
   {{0x6f1c0309,0xd13000c6,0xa3d400ab,0xdb1d3f84}},	//   _raqc, كمة_, ़ीब_, ppræ, 
   {{0x6f1c0455,0xdb1c1ba6,0x7a0800de,0xf8d4000d}},	//   _saqc, lprä, mētā, धरिय, 
   {{0xceb8723c,0x73346e9a,0x6f1cc329,0x7a08005f}},	//   ләп_, _پرائ, _paqc, lētā, 
   {{0x6f1c014f,0xdb1c0e78,0x29100165,0x3e480153}},	//   _qaqc, nprä, zexa_, kėtą_, 
   {{0x661805b1,0x7a08005f,0xceb80032,0x6f1c014f}},	//   _xsuk, nētā, _ҙән_, _vaqc, 
   {{0xe294496c,0x6f1c03f0,0x21641586,0xdcfc054e}},	//   _тач_, _waqc, _кичи_, voră, 
   {{0x6f1c036b,0x5ea8015b,0x29113f85,0xcc880133}},	//   _taqc, কুলে, vexa_, انزه_, 
   {{0x291002c4,0x93bc0311,0x28a46611,0xdcfc0356}},	//   wexa_, _prăj, _कृषि, toră, 
   {{0x29100005,0xdef80108,0x3e4800c0,0xdde401ee}},	// [1fb10] texa_, _тыщ_, gėtą_, _мәрү, 
   {{0x93bc0311,0xe9fc004d,0x7a0800e2,0x00000000}},	//   _vrăj, _nhấc_, dētā, --, 
   {{0xe6540201,0x29100f71,0x6b800af2,0xad9809c2}},	//   _ገልጸዋ, rexa_, _íngo, ctúa, 
   {{0x29101709,0xca7c01a9,0xdb1c0036,0xf8b401ec}},	//   sexa_, _insо, gprä, _ғөф_, 
   {{0x6d400227,0xd7f01b56,0xef1c06be,0x00000000}},	//   _ŋnay, ككە_, llüs_, --, 
   {{0x7ae40175,0xa50401a9,0x5e58010f,0x00000000}},	//   _zdkt, рядл, סיגע_, --, 
   {{0x04453f86,0x1cac0327,0xdb1c002f,0xd9180166}},	//   сейн, _བུབ_, bprä, _тья_, 
   {{0x66193f87,0xd3b801ec,0x7a0800de,0x00000000}},	//   _tsuk, шуші_, bētā, --, 
   {{0x6618fd4f,0x8c484dd9,0x04c801c8,0xd7640345}},	//   _usuk, _haşı, _موذي_, _بۆنی, 
   {{0x00c8656c,0xaca00241,0x8c4803ee,0x00000000}},	//   ылок_, _amọd, _kaşı, --, 
   {{0x04951fa6,0x5edc0011,0xcea802e4,0x00000000}},	//   _الاح, _ভাবে, _ני_, --, 
   {{0x8c4803be,0x09cc00bd,0x6d553f88,0x00000000}},	//   _maşı, _লিনা, _alxa, --, 
   {{0x1db80490,0x8c480139,0xef1c03e0,0x00000000}},	//   _आढळत, _laşı, vlüt_, --, 
   {{0x1cacb444,0x7c6400d1,0x6fb00633,0x00000000}},	//   _བུད_, مازل, _کميا, --, 
   {{0x7a0800e2,0x8c4825a8,0x6aa400d1,0x2bd00118}},	//   zētā, _naşı, ەشلە, धीला, 
   {{0x6e440240,0xfbc40107,0x6d540213,0x0b5838be}},	//   ërbë, ибҳо, _elxa, аруы_, 
   {{0xeb953f89,0xb9080daf,0x225c0205,0x31b8010f}},	// [1fb20] сит_, лназ_, nzuk_, ָזענ, 
   {{0x8c484947,0xad980077,0x6e380375,0x7a0800e2}},	//   _başı, ptúa, _עתיד, vētā, 
   {{0x1bec3276,0xdb1c1196,0x98b80153,0x00000000}},	//   _जटिल_, tprä, _norą_, --, 
   {{0x8c480cc1,0xb6a401ee,0xe1e400cf,0xef1c013d}},	//   _daşı, биел, _ىس_, llür_, 
   {{0xdb1d3f8a,0xca753f8b,0x4a7400c7,0x00000000}},	//   rprä, _дуры, _дырт, --, 
   {{0xdb1c0730,0x7a0800da,0x225c01fa,0xaef800a3}},	//   sprä, rētā, dzuk_, liùt, 
   {{0xf3648374,0x4cdc00fe,0x8c48008e,0xdb1c01e3}},	//   йтин, _বামু, _gaşı, pprä, 
   {{0x1cac0003,0x60c002d0,0x00000000,0x00000000}},	//   _བུན_, _afnm, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8c480baf,0x3f481682,0x09cc03d4,0x00000000}},	//   _yaşı, ṱula_, _লিমা, --, 
   {{0xb9dc0020,0x48fc1524,0xb3c87579,0x00000000}},	//   _እጅ_, र्टो_, _слез_, --, 
   {{0xad9802d2,0x00000000,0x00000000,0x00000000}},	//   gtún, --, --, --, 
   {{0x2d4c0561,0xdb040129,0xee8402dd,0x200001d9}},	//   _yüeh_, mmiè, сыно, _ہِوِ, 
   {{0xb4e4038e,0xe2813f8c,0xdb04067c,0x00000000}},	//   _भयो_, _элчи, lmiè, --, 
   {{0x93bc0276,0xcc90002b,0x00000000,0x00000000}},	//   _brăi, _mṛgo_, --, --, 
   {{0x93bc0356,0x00000000,0x00000000,0x00000000}},	//   _crăi, --, --, --, 
   {{0xda340153,0xc8d800d4,0xd91000f1,0x00000000}},	// [1fb30] петы, имає_, ډیټ_, --, 
   {{0xef1c07c5,0xcc900055,0x28a40108,0xde952357}},	//   plüs_, _nṛgo_, бшег, _عجيب, 
   {{0x225c01ed,0x8c480213,0xad64d712,0xd7c87b63}},	//   zzuk_, _qaşı, _ناگه, موله_, 
   {{0x93bc054e,0xd7f82bd4,0x8c4806be,0x18a400d4}},	//   _grăi, суф_, _vaşı, чаєм, 
   {{0x76b424ce,0x2d4c0ba1,0xfd64002b,0x260401a9}},	//   әләр_, _aüei_, _aduṣ, счег, 
   {{0x8c4904ff,0x98b80024,0xfd2401e1,0x00000000}},	//   _taşı, _porą_, _àìto_, --, 
   {{0x58d53f8d,0xdb1d3f8e,0xcaa00150,0x03a40395}},	//   _хост, språ, _ﺃﻭﺠﻪ_, оико, 
   {{0x225c0323,0x00000000,0x00000000,0x00000000}},	//   tzuk_, --, --, --, 
   {{0x85740022,0x6b800124,0xcc900055,0x00000000}},	//   _длах, _êngu, _hṛdo_, --, 
   {{0xded402d3,0x3f7402b5,0x00000000,0x00000000}},	//   ራዉን_, māui_, --, --, 
   {{0xa2240832,0x00000000,0x00000000,0x00000000}},	//   _گراه, --, --, --, 
   {{0xa6d4015b,0x99540030,0xefc00092,0x9474007b}},	//   _হাঁট, mäť_, ሻሻያ_, _عدلا, 
   {{0xad9801a8,0x21c80139,0x09b40073,0x00000000}},	//   rtún, _сыеп_, _अंगठ, --, 
   {{0xad9882e3,0xd1b800f2,0x00000000,0x00000000}},	//   stún, _طاها_, --, --, 
   {{0x14ac01f9,0x9f4c00e5,0x00000000,0x00000000}},	//   टेपण, álók_, --, --, 
   {{0x9eb40cef,0xb37c0092,0x00000000,0x00000000}},	//   _эшкә, _ዕቅድን_, --, --, 
   {{0x1cac3ae9,0x5ea800bd,0x39453f8f,0x0cd800fe}},	// [1fb40] _བུམ_, _ক্রে, онаг, _তাৰত, 
   {{0x1b4401d9,0xad986d6c,0x00000000,0x00000000}},	//   _کھسُ, ntúl, --, --, 
   {{0x93bc084c,0x4cdc0154,0xaa600092,0x3b84009b}},	//   _trăi, বলশু, _መዘርጋ, _млог, 
   {{0xad98007b,0x00000000,0x00000000,0x00000000}},	//   htúl, --, --, --, 
   {{0x7bcc0175,0xfd2401e1,0xdb1c00e5,0x00000000}},	//   lpbu, _àìso_, őzón, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x37542ea3,0x32093f90,0xdb040129,0xf7541291}},	//   _بپرس, ахон_, umiè, _بنرج, 
   {{0xdb053f91,0xceb801e0,0xe3ac36fe,0x25080214}},	//   rmiè, ҙәй_, خرو_, _چرمی_, 
   {{0x250840bf,0xaa3400df,0xf8c8141f,0xd76402f2}},	//   _نرمی_, קטיק_, िडिय, _بۆچی, 
   {{0x5ea8045e,0xb4e40a8a,0x00000000,0x00000000}},	//   _ক্লে, भणी_, --, --, 
   {{0xdb0804fb,0xd9f0000d,0x9f600241,0xfda4035b}},	//   _èlèk, _चिढत_, _òsìn_, ҧырҟ, 
   {{0xe29407d5,0x9df8447e,0xe2c80244,0x00000000}},	//   _дац_, онят_, _ئامۆ_, --, 
   {{0x6ad01533,0x22485df7,0x660c26bc,0x00000000}},	//   तर्र, äcke_, _äcke, --, 
   {{0x5c053f92,0xaa7800a2,0x15fc012d,0x00000000}},	//   мята, _keýg, उंडर_, --, 
   {{0x7de400e5,0x5ba435ce,0x00000000,0x00000000}},	//   _کسٹم, друз, --, --, 
   {{0x3a240158,0x2aa83da1,0x00000000,0x00000000}},	// [1fb50] åopp_, ртво_, --, --, 
   {{0x91ac03d4,0x2008012d,0xdcfc00c0,0x00000000}},	//   ছৱৰ্, ńcie_, korę, --, 
   {{0xab60247f,0x4c94004e,0x00000000,0x00000000}},	//   _قۇسى, _хинс, --, --, 
   {{0x99540030,0x7c384bc1,0xdb1c00d7,0x00000000}},	//   väť_, åtre, zprú, --, 
   {{0xbb3804ae,0x04c81e5a,0x8eac015b,0x5f004466}},	//   _הערי, موشي_, কুরগ, ष्ट्_, 
   {{0x5ae80003,0x48c40022,0x070921e7,0x00000000}},	//   _འཇོམ, _хәаа, _گيري_, --, 
   {{0xaa78010b,0x28a40b67,0x00000000,0x00000000}},	//   _beýg, केशि, --, --, 
   {{0xc244c43c,0x85b8228e,0x96f800c9,0x07081b45}},	//   зник, _глас_, _мест_, _ديري_, 
   {{0x95c93f93,0x3f481682,0x64cc0490,0xc0f40023}},	//   _духа_, ṱuka_, _स्थळ, _ገመል_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x41280364,0xad980137,0xff2c00b7,0x39840109}},	//   _ҳоло_, rtúl, _ሽማግሌ, gôsy_, 
   {{0x7c282cd7,0x93bc0356,0x0c980092,0x00000000}},	//   _áfri, _prăv, _መስራች_, --, 
   {{0x41280484,0xdb1c21e3,0xa8002b93,0xa3d4012d}},	//   _голо_, mprø, _şılt, ़ीर_, 
   {{0xaa780209,0xdb1c0ac8,0x39840109,0x05dc0118}},	//   _meýd, lprø, bôsy_, नीयब, 
   {{0xdb1c005c,0x7bcc0334,0x00000000,0x00000000}},	//   oprø, upbu, --, --, 
   {{0xdb1c0212,0x7bcc01f5,0x93bc0356,0xac04010a}},	//   nprø, rpbu, _grău, янса_, 
   {{0xee2c0451,0x00000000,0x00000000,0x00000000}},	// [1fb60] _مٽي_, --, --, --, 
   {{0x7bcc4fc4,0x00000000,0x00000000,0x00000000}},	//   ppbu, --, --, --, 
   {{0xdb1c21e3,0x5ba400fb,0x28a41100,0x00000000}},	//   kprø, _олоғ, केलि, --, 
   {{0xbb180150,0xaa78010b,0xb6a40798,0x00000000}},	//   _ازدا_, _beýd, пиел, --, 
   {{0xba74bfba,0xdb1c08d7,0xaa7800a2,0xdcfc0210}},	//   _راحت, dprø, _reýg, worę, 
   {{0x6a98011a,0x00000000,0x00000000,0x00000000}},	//   _לשכנ, --, --, --, 
   {{0x2934008f,0xe9a079ea,0xdb1c005c,0xaa7800a2}},	//   _צאלן_, _чарп, fprø, _peýg, 
   {{0x0b80001f,0xdb1c1347,0x3264d646,0x46f401f4}},	//   _የብድር_, gprø, зтов, _очут, 
   {{0x4cdc045e,0x93bc084c,0xaa78010b,0x00000000}},	//   _বাসু, _arăt, _geýd, --, 
   {{0x39493f94,0x8d9c001f,0x93bc054e,0x61ec0332}},	//   _jobs_, ለከተው_, _brăt, ácla, 
   {{0x237402e1,0xaa7800a2,0x00000000,0x00000000}},	//   _کمند_, _zeýd, --, --, 
   {{0x27e4438d,0xb8fc025c,0x6438008f,0xaa7800a2}},	//   ánni_, _ཤབ_, _לעבנ, _heýe, 
   {{0x398403d1,0xad981e0b,0x00000000,0x00000000}},	//   sôsy_, stúm, --, --, 
   {{0x61400b46,0xf8d40210,0x00000000,0x00000000}},	//   _печа, धरोप, --, --, 
   {{0x93bc0311,0xaa7800a2,0x00000000,0x00000000}},	//   _grăt, _meýe, --, --, 
   {{0x33240254,0x49d80108,0x00000000,0x00000000}},	//   _jaox_, ждаю_, --, --, 
   {{0x48c40139,0x00000000,0x00000000,0x00000000}},	// [1fb70] дәба, --, --, --, 
   {{0xaca0063f,0xa8a53f95,0xd1f000b7,0x394806be}},	//   _akụd, прек, _ቀጥታ_, _cobs_, 
   {{0x39480ba1,0xbd040055,0x27e400e8,0xaa78010b}},	//   _dobs_, _deũā, énn_, _seýd, 
   {{0xaa7809a5,0x3150044e,0x99800fcf,0xaa400131}},	//   _peýd, _ዝገበር, rviš_, _كۆزى, 
   {{0x9a840598,0x5a342626,0xaa780432,0x20080356}},	//   _зурл, _знят, _beýe, ăcii_, 
   {{0xd6d800c7,0x00000000,0x00000000,0x00000000}},	//   отә_, --, --, --, 
   {{0xa3d4007d,0x2b480de2,0xdb1c143a,0xf5300798}},	//   ़ीं_, _kocc_, tprø, тејќ, 
   {{0x39488c16,0x00000000,0x00000000,0x00000000}},	//   _zobs_, --, --, --, 
   {{0x5edc02a6,0x2b480ac5,0xdb1c1477,0xaa7800a2}},	//   _ভালে, _mocc_, rprø, _feýe, 
   {{0xdb1c28b3,0x3f900076,0xaa78010b,0xc8dc07f7}},	//   sprø, _skyu_, _geýe, यरिट, 
   {{0x6b8000d2,0x212800bc,0xdb1c143a,0x00000000}},	//   _íngw, ěch_, pprø, --, 
   {{0x25bd3f96,0x02600133,0x821400ae,0x00000000}},	//   _kuul_, _لێبێ, _يواص, --, 
   {{0x25bd3f97,0xb60407f5,0x93bc0356,0x6f6002d5}},	//   _juul_, _gušć, _frăs, твяз, 
   {{0x61f93f98,0x26dc04cc,0x93bc0276,0x25bd1bfd}},	//   muul, _leuo_, _grăs, _muul_, 
   {{0x61f93f99,0x2b493f9a,0x25bc0067,0x39493f9b}},	//   luul, _bocc_, _luul_, _robs_, 
   {{0xf090025f,0xfb1410fe,0x2124001e,0x2b480051}},	//   _שנה_, بورج, _hanh_, _cocc_, 
   {{0x61f82252,0x4a740184,0xb22401a8,0x00000000}},	// [1fb80] nuul, ныфт, mræð, --, 
   {{0x26dc0393,0xaa78010e,0xf9880b24,0x32100166}},	//   _aeuo_, _beýb, آخره_, _äyye_, 
   {{0x2124001e,0xb8f4033d,0x39480334,0x61f93f9c}},	//   _manh_, _सभ_, _vobs_, huul, 
   {{0x2b480004,0x25bc2db1,0x2124001e,0xdb24005b}},	//   _gocc_, _buul_, _lanh_, ärär, 
   {{0x315002d3,0x7c2c17b8,0x66e13f9d,0x212401fb}},	//   _ዝገብር, lvbr, точа, _oanh_, 
   {{0x61f93f9e,0x25bd3f9f,0x7f940077,0x200401a9}},	//   duul, _duul_, máqu, _oqni_, 
   {{0x13953fa0,0x2508036b,0x00000000,0x00000000}},	//   никю, ترنی_, --, --, 
   {{0x25bc0449,0xb604107d,0x61f82252,0x2b4800e8}},	//   _fuul_, _pušć, fuul, _xocc_, 
   {{0x21253fa1,0x25bd3fa2,0x61f93fa3,0xaa78010e}},	//   _banh_, _guul_, guul, _teýe, 
   {{0x21253fa4,0x2248049f,0xe5a000c7,0xf1c400d1}},	//   _canh_, äcka_, _аиуи, كۈچى_, 
   {{0x212407ae,0xb22400fc,0x75385844,0x4cdc0154}},	//   _danh_, fræð, _intz, _বালু, 
   {{0x61f82f99,0xb2240008,0x45400022,0xa8000205}},	//   buul, græð, _аҕәа, _şıkt, 
   {{0x21240097,0x93bc0311,0xad98007b,0xf254103c}},	//   _fanh_, _trăs, ltúi, _تضاد, 
   {{0x2b48002e,0x2124004d,0xe2100022,0x93bc054e}},	//   _socc_, _ganh_, _рмшы, _urăs, 
   {{0xad9800c6,0x77600117,0xeb9112cd,0x9be4443f}},	//   ntúi, khox, نظر_, кітк, 
   {{0x7c380158,0x00000000,0x00000000,0x00000000}},	//   åtra, --, --, --, 
   {{0x75393fa5,0xad98007b,0x44280208,0x9f600241}},	// [1fb90] _ontz, htúi, ̉a_, _òsán_, 
   {{0x212407ae,0x00000000,0x00000000,0x00000000}},	//   _xanh_, --, --, --, 
   {{0x6ec009d9,0x2b480268,0x25bc7902,0x61f82252}},	//   रखपु, _tocc_, _suul_, zuul, 
   {{0x75380323,0xd5b80607,0x61f804ba,0x25bc0254}},	//   _antz, _aiā_, yuul, _puul_, 
   {{0xf8ac040b,0xb7840139,0x00000000,0x00000000}},	//   لکہ_, хәре_, --, --, 
   {{0x78a000bc,0x236c03cd,0x6d440083,0x61f8009d}},	//   řova, _smgj_, njja, vuul, 
   {{0x77600b6f,0x212401fb,0x61f80337,0x6d4401f4}},	//   bhox, _ranh_, wuul, ijja, 
   {{0x61f93fa6,0x75393fa7,0x212401fb,0x25bc00c5}},	//   tuul, _entz, _sanh_, _tuul_, 
   {{0x6b800af2,0x2c64022e,0xa3b8012d,0x21240051}},	//   _íngu, _dеdi_, _इंक_, _panh_, 
   {{0x61f93fa8,0xdcfc0115,0x80d40154,0x00000000}},	//   ruul, forĝ, _দাঙ্, --, 
   {{0x61f93fa9,0x5f4801c0,0x21240208,0xad9801e7}},	//   suul, дүйн_, _vanh_, ctúi, 
   {{0x67284cab,0x69cc801c,0xf8b0010f,0xdd040205}},	//   ndgj, _otce, טשי_, _ısıl, 
   {{0x212417f5,0x3f9c0029,0xeb600020,0x61f801d9}},	//   _tanh_, ētu_, _ማረጋገ, quul, 
   {{0xd1380034,0x6560004d,0x7f9400d8,0x4d140166}},	//   gląd_, nhnh, váqu, кьст, 
   {{0xada0f6c8,0x69cd3faa,0x44253fab,0x6da0214f}},	//   уарл, _atce, _jsl_, уира, 
   {{0xbea527dd,0x44253fac,0x6d400428,0x7760009a}},	//   _пайк, _msl_, _ònan, xhox, 
   {{0xf2d005e1,0x40b401d9,0xdb1c002f,0xcfa80244}},	// [1fba0] טען_, _تھکھ_, mprü, _تاوم_, 
   {{0x44253fad,0x673800dc,0x7f940113,0xa2a400dc}},	//   _osl_, _anuj, ráqu, _चरन्, 
   {{0x69cd3fae,0x77600f85,0xdd100064,0x00000000}},	//   _etce, thox, _lžūk, --, 
   {{0xd5b80421,0xdb1c0e78,0xf0b4010f,0x00000000}},	//   _siā_, nprü, גלער_, --, 
   {{0x44253faf,0x7760004b,0xe8f407d5,0xe60c0066}},	//   _asl_, rhox, ллă_, مشو_, 
   {{0x764001a9,0x344800d4,0x96d00401,0x00000000}},	//   rxoy, зчин_, _ड्रॉ, --, 
   {{0x77606f4f,0x93bc054e,0x12780023,0x00000000}},	//   phox, _crăp, _ክትካእ_, --, 
   {{0x44253fb0,0xdb1d3fb1,0xad98007b,0x9944010e}},	//   _dsl_, mpró, rtúi, _söň_, 
   {{0xd1300597,0x6d440054,0xdb1d3fb2,0x4424045a}},	//   لمة_, yjja, lpró, _esl_, 
   {{0x753801c6,0x06640150,0x40f00588,0xdd1000ef}},	//   _untz, _شاقپ, аҧшр, _džūk, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb284084c,0x4668030d,0x00000000,0x00000000}},	//   _пылк, _ирĕм_, --, --, 
   {{0x6d440054,0x01e40137,0x68e0022e,0x00000000}},	//   tjja, _айчү, аndl, --, 
   {{0x71240014,0xaef804cc,0xdb1c03b2,0x00000000}},	//   _سرتل, chùn, rprý, --, 
   {{0x4424010a,0x7bd80421,0x4c953fb3,0xdb1cf49e}},	//   _xsl_, âtup, тивс, bprü, 
   {{0xddd000bc,0x5bb8005b,0xa09800d9,0x00000000}},	//   řeši, елся_, _מיוט, --, 
   {{0x6d440bc9,0xaa780209,0xe6ac0171,0x00000000}},	// [1fbb0] pjja, _beýa, _ņižņ, --, 
   {{0x999800a8,0x644001a9,0x2024032e,0x67393fb4}},	//   екут_, yxni, _ívið_, _snuj, 
   {{0xdb1c01ed,0xa64450c9,0x00000000,0x00000000}},	//   gpró, کخان, --, --, 
   {{0x2464002e,0x0a5801a9,0x00000000,0x00000000}},	//   _jёme_, _жамъ_, --, --, 
   {{0xd7f004da,0x44246fb0,0x96b80137,0x00000000}},	//   لكە_, _ssl_, нушу_, --, 
   {{0x44253fb5,0xaa4c02d3,0x93bc0311,0x6440004e}},	//   _psl_, _ዘመሓላ, _prăp, txni, 
   {{0xd7f815ed,0x04443d2a,0x58840024,0x00000000}},	//   _пут_, тейн, _быта, --, 
   {{0x03940801,0x673800df,0x44240427,0xdb1c0100}},	//   ърля, _unuj, _vsl_, lprò, 
   {{0x237c17ee,0xd3b400c7,0xa280072d,0x00000000}},	//   rnuj_, ысшь, دیشو, --, 
   {{0xe294040d,0xd04803e3,0x00000000,0x00000000}},	//   мақ_, lbdə, --, --, 
   {{0x44253fb6,0xdb1c002f,0xf53400df,0x00000000}},	//   _usl_, tprü, _שטער_, --, 
   {{0x78b8790f,0xe9dc0241,0x00000000,0x00000000}},	//   _útve, _owú_, --, --, 
   {{0xdb1c0730,0x25f403ce,0x00000000,0x00000000}},	//   rprü, उंटी_, --, --, 
   {{0xdb1c0730,0x5344035b,0xf1b8004d,0x018801ec}},	//   sprü, _ахәа, _giơ_, _تپتى_, 
   {{0x69c8db0c,0xe9dc01e1,0x8ff8035b,0xaa7800a2}},	//   ígen, _awú_, _зхыу_, _reýa, 
   {{0xef14014b,0x00000000,0x00000000,0x00000000}},	//   _амъ_, --, --, --, 
   {{0xeb953fb7,0xb904011b,0x3fcc0131,0xaa78010e}},	// [1fbc0] тит_, кзак, ﯖﯩﺰﻧ, _peýa, 
   {{0xe8f53fb8,0x075401e1,0x00000000,0x00000000}},	//   клу_, _àìjé_, --, --, 
   {{0xe9dc01e1,0x3f800067,0x00000000,0x00000000}},	//   _ewú_, onku_, --, --, 
   {{0xe81005f9,0xdb1d3728,0x276801d5,0x78a00118}},	//   _ठहरा_, rpró, وشنی_, řovo, 
   {{0x660c01e6,0x3f800014,0xdb1c438d,0xaa7800a2}},	//   _äckl, inku_, spró, _heýn, 
   {{0x6e28145e,0xdb1c0579,0x6b803756,0x00000000}},	//   _âgbe, ppró, _íngr, --, 
   {{0x847802d3,0xaa780022,0xdef80240,0x00000000}},	//   _እንከላ_, _jeýn, _ገጸን_, --, 
   {{0x040c07ae,0x99800165,0xe734030d,0x00000000}},	//   _hướn, stiń_, _иес_, --, 
   {{0xf1a46d07,0x27b011ca,0xb1100051,0x00000000}},	//   крон, _тәфс, _dụng, --, 
   {{0x3f813fb9,0x998c0419,0x00000000,0x00000000}},	//   enku_, álňu_, --, --, 
   {{0x25093fba,0xa3b883e3,0x00000000,0x00000000}},	//   _ترقی_, _इंच_, --, --, 
   {{0x28a41cd2,0xee70010b,0xd0100220,0xee840eed}},	//   केटि, иңйы, _ۇلت_, выго, 
   {{0xaa7800e4,0x31680137,0x00000000,0x00000000}},	//   _ndýp, _ошко_, --, --, 
   {{0x6fc81cb7,0x3f813fbb,0x040c001e,0x81e402f5}},	//   _संपू, anku_, _nướn, বংশ_, 
   {{0x1b0c03d4,0x00000000,0x00000000,0x00000000}},	//   হজনে_, --, --, --, 
   {{0xe0b400c8,0x05a828fe,0x00000000,0x00000000}},	//   _בלוט_, _चीनब, --, --, 
   {{0x5f747735,0x040c004d,0x00000000,0x00000000}},	// [1fbd0] _خاور, _bướn, --, --, 
   {{0x29041570,0x5a34010b,0xd7c800f1,0x00000000}},	//   üna_, шнут, چوله_, --, 
   {{0x2d800989,0xc7f4026a,0xaa780432,0xd7c800f1}},	//   mnje_, узећ, _geýn, نوله_, 
   {{0x29053fbc,0xdee41b49,0x44393fbd,0xd7f8010b}},	//   żna_, _ሞትን_, _čs_, туф_, 
   {{0xd6240a2c,0x25702dce,0x2d80002d,0x940c06be}},	//   لعوي, ақас, onje_, _iydə_, 
   {{0xc3c401c6,0x2d800165,0x58d40334,0x998000ef}},	//   гөдл, nnje_, _ворт, etiņ_, 
   {{0x3f80033f,0x1d18011a,0x00000000,0x00000000}},	//   ynku_, דקור_, --, --, 
   {{0x03253fbe,0x2d813fbf,0x82a4010b,0xe784009b}},	//   удин, hnje_, лайж, _руго, 
   {{0xad98007b,0xddd400d0,0x00000000,0x00000000}},	//   ntús, _ťažb, --, --, 
   {{0x2d800b91,0x66193fc0,0x7fd40046,0x040c01fb}},	//   jnje_, _ipuk, лімі, _xướn, 
   {{0x3f80020c,0x950801d3,0x82d8014b,0x00000000}},	//   tnku_, _شکوہ_, _здес_, --, 
   {{0x6618006a,0x3f800067,0x82341a9b,0x00000000}},	//   _kpuk, unku_, _مرتا, --, 
   {{0x9f600008,0xee340cc9,0xaa7800a2,0x3f800210}},	//   _þrír_, гня_, _seýn, rnku_, 
   {{0x66186616,0xc0e40137,0x8e740845,0xaa78010e}},	//   _mpuk, _сокк, руюч, _peýn, 
   {{0xeb0c0b4e,0x00000000,0x00000000,0x00000000}},	//   ाभूत_, --, --, --, 
   {{0xab24d558,0xc5e400aa,0x040c001e,0x61f80194}},	//   лоса_, _وړ_, _sướn, orul, 
   {{0xa3a8084a,0xaa400d31,0x2d800219,0x5a4400fb}},	// [1fbe0] _गठन_, бетл, bnje_, шмағ, 
   {{0x09cc02a6,0x61f805b1,0xb88000bc,0x7c2801c6}},	//   _লিখা, irul, římn, _зоог_, 
   {{0x66193fc1,0x040c01fb,0x61f86035,0xad993a2e}},	//   _apuk, _vướn, hrul, rtút, 
   {{0x61f93fc2,0xbb453fc3,0x8ae400c0,0x00000000}},	//   krul, _семк, _віёл, --, 
   {{0x040c0016,0xe70407d6,0x61f801e4,0x83cc0220}},	//   _tướn, اسمی, jrul, _ﻗﺎﺭﺳ, 
   {{0xad993fc4,0x7ae53fc5,0xaa78010b,0x98780419}},	//   ltúr, _hekt, _meýl, láča_, 
   {{0x66193fc6,0x61f93fc7,0x499001b9,0xaa780432}},	//   _epuk, erul, _بیلر, _leýl, 
   {{0x2d801225,0xad9801a2,0x7ae53fc8,0xa854011a}},	//   znje_, ntúr, _jekt, _גילה_, 
   {{0x7ae41432,0x61f93fc9,0xd25035e6,0xc32c08b0}},	//   _mekt, grul, زند_, بەن_, 
   {{0xb424838a,0xd1300f01,0xdb041611,0x917401c6}},	//   _معصو, آمد_, lmiä, ргоц, 
   {{0xad98c2f1,0x61f93fca,0xddd01674,0x62880789}},	//   ktúr, arul, _češl, _exgo, 
   {{0xaa7809a5,0x61f93fcb,0x7ae53fcc,0x43740137}},	//   _beýl, brul, _nekt, _кучт, 
   {{0x6d400428,0x61f80311,0xb64400b5,0x2a7c00d7}},	//   _ònak, crul, _ｈｂ_, _ľubo_, 
   {{0xa900068f,0x7ae4005a,0xaa7800a2,0xd0d40395}},	//   _लाइफ_, _aekt, _deýl, _токъ, 
   {{0x2d8080b6,0xad98032e,0x00000000,0x00000000}},	//   rnje_, hrúg, --, --, 
   {{0x2d8005a1,0x7ae4f77f,0x2aa801e1,0x5dd400cc}},	//   snje_, _cekt, _nòbí_, _তিৰু, 
   {{0x2d813fcd,0x7ae4b294,0x7bc88607,0xaa78010e}},	// [1fbf0] pnje_, _dekt, _éfun, _geýl, 
   {{0xd9440063,0xad9800d7,0xdee42829,0x6eec01e1}},	//   беђи, atúr, _ሞትና_, bòbí, 
   {{0xe9700b38,0x290c033f,0xa8a53fce,0x7ae53fcf}},	//   لۇڭد, ęga_, урак, _fekt, 
   {{0x7ae53fd0,0x61f93fd1,0x661800e4,0x9814007b}},	//   _gekt, yrul, _ppuk, إبلا, 
   {{0xd7f8052f,0xaa78010b,0x5884190b,0x9f4c00e5}},	//   _ҙур_, _keým, _ғыра, álék_, 
   {{0x61f81432,0xaa7839cb,0x7ae4036e,0x00000000}},	//   vrul, _jeým, _zekt, --, 
   {{0xfd6001f2,0x7ae53fd2,0x62880175,0x64c0004b}},	//   _agwọ, _yekt, _sxgo, ليږل, 
   {{0x78b8148b,0x68e53fd3,0xad980162,0x00000000}},	//   _útva, _hejd, brúg, --, 
   {{0xe66521ee,0x163448a5,0x661800c7,0x85b841e5}},	//   _ство, _летя, _upuk, _алас_, 
   {{0x61f93fd4,0xc10426c0,0x68e5175e,0xe7840fc0}},	//   rrul, جودي, _jejd, _руҳо, 
   {{0x68e53fd5,0xad98ec21,0x3f68119e,0x5ec40116}},	//   _mejd, ytúr, вино_, йинғ, 
   {{0x68e497e7,0xad9800d0,0xbf580212,0x00000000}},	//   _lejd, xtúr, трої_, --, 
   {{0xb05003e6,0x90340022,0xede401e0,0x69c801e4}},	//   مپیت, _ҳхыч, аһыҙ_, ŭgej, 
   {{0x7ae53fd6,0x68e4031d,0x99e801ef,0x00000000}},	//   _sekt, _nejd, _luňá, --, 
   {{0xad9826b8,0x2ba40037,0x987800d7,0x00000000}},	//   ttúr, _कीहा, táča_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
  
   {{0x7ae53fd7,0x68e53fd8,0xad9865ff,0xaa780432}},	// [1fc00] _vekt, _bejd, rtúr, _heýj, 
   {{0x7ae41060,0xad993fd9,0xaa78010b,0xa9640124}},	//   _wekt, stúr, _geým, аиуа_, 
   {{0x7ae53fda,0xad993fdb,0x68e402f0,0x00000000}},	//   _tekt, ptúr, _dejd, --, 
   {{0xe1e53fdc,0x7ae40217,0xcb800022,0xe734b7f5}},	//   _وس_, _uekt, _еқсп, иех_, 
   {{0x1634dfe7,0xaa7800a2,0x24cc03d4,0xad980162}},	//   селя, _leýj, _ৰাজহ, brúd, 
   {{0x795003e6,0xad9800ae,0x68e400d7,0x41400023}},	//   _گێڕا, crúd, _gejd, _ንገሊኦ, 
   {{0xf8a817cb,0xf3653fdd,0x2aa801e1,0x00000000}},	//   _करिय, итин, _tòbí_, --, 
   {{0xe3ac5706,0x60c003ac,0x91c400fd,0x0bb000d1}},	//   وري_, _agnm, бәкл, _ﺳﺎﻟﻮ, 
   {{0x68e4014f,0x9f600241,0x00000000,0x00000000}},	//   _yejd, _òsùn_, --, --, 
   {{0xf8a84928,0x35a53fde,0x86980006,0x00000000}},	//   _कराय, _тазг, _стст_, --, 
   {{0x8f3413d6,0xd2501e2f,0x6d4001ab,0xcc900055}},	//   бенц, زنگ_, _ònai, _gṛho_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x60180793,0x7c2005a1,0x15fc02a0,0x511800d3}},	//   _pämö, _ćora, उंटर_, _болю_, 
   {{0xa154f46d,0x2d440092,0x26cc0334,0x00000000}},	//   _вашу_, _ሚሊኒየ, zcgo_, --, 
   {{0x7bc800d2,0x92e8015b,0xaa7800a2,0x68e40306}},	//   _éful, বলী_, _geýj, _rejd, 
   {{0x5f74c344,0x68e53fdf,0xdb6800a8,0x2bb8007b}},	//   _واير, _sejd, арул_, ئاسة_, 
   {{0x68e40cf4,0x2ee009b4,0x5a34728c,0x2d6800e8}},	// [1fc10] _pejd, परीत, онтт, 茜ey_, 
   {{0xaef801ab,0xaa78010b,0x8504072a,0x00000000}},	//   dhùi, _heýk, _राइट_, --, 
   {{0xe72402bf,0x68e51b83,0x69d00427,0xaa780432}},	//   иєдн, _vejd, _žgeč, _keýk, 
   {{0x68e53fe0,0xab600046,0xaa78010e,0x00000000}},	//   _wejd, _بۇرى, _jeýk, --, 
   {{0x9a853fe1,0xfb180375,0x68e435dc,0xdb1c007c}},	//   _дурл, _גורמ, _tejd, tprö, 
   {{0xaa7800a2,0x00000000,0x00000000,0x00000000}},	//   _leýk, --, --, --, 
   {{0x99e80118,0xdb1c01e3,0x7d18000d,0x00000000}},	//   _tuňá, rprö, õtsi, --, 
   {{0xeacc00e4,0xe6340451,0xb5a800db,0xdb1c007c}},	//   _eỹva_, _پيئڻ_, _ەپكە_, sprö, 
   {{0xaab40f44,0xaef801ab,0xdb1c007c,0xad9800c7}},	//   अधिक, chùi, pprö, ytúp, 
   {{0x01647616,0x3ea40327,0xaa7800a2,0x9554007b}},	//   скоо, _ġot_, _peýj, _وخلا, 
   {{0xaa7800a2,0xefc4009d,0x00000000,0x00000000}},	//   _beýk, йлэл_, --, --, 
   {{0x1b1c00fe,0x3d180b98,0xd18400cf,0x00000000}},	//   _পোনে_, म्ने_, йлөй, --, 
   {{0x52740075,0x00000000,0x00000000,0x00000000}},	//   _мушу, --, --, --, 
   {{0x5fcc0490,0x78a00118,0x00000000,0x00000000}},	//   _संपल, řovi, --, --, 
   {{0x850406e3,0x00000000,0x00000000,0x00000000}},	//   _राईट_, --, --, --, 
   {{0x256839c2,0xad9801a2,0x7f843296,0xaa7800a2}},	//   _følg_, stúp, _دلبن, _keýh, 
   {{0xe8f405f5,0x25680162,0xdd1c00bc,0x93bc054e}},	// [1fc20] өлт_, _køld_, mážd, _prăz, 
   {{0xad98056a,0x2e34010f,0xeaac01d3,0xaa78010e}},	//   trúe, _פריש_, رٹل_, _meýh, 
   {{0xb1781a4c,0xdb0400ae,0x00000000,0x00000000}},	//   נטער, imiú, --, --, 
   {{0x22bc0055,0xdb0400ae,0x00000000,0x00000000}},	//   _kākī_, hmiú, --, --, 
   {{0x93bc0356,0x35a400db,0x00000000,0x00000000}},	//   _trăz, бадг, --, --, 
   {{0x78b800dd,0x22bc00b0,0x7f5401a9,0x52e01152}},	//   _útvo, _mākī_, _loyq, नर्स, 
   {{0xad980332,0xdc3c013a,0x00000000,0x00000000}},	//   lrúc, káče, --, --, 
   {{0x51f834d8,0x7f54014f,0x636401c0,0xaa78010e}},	//   анию_, _noyq, йрыг_, _beýh, 
   {{0x4ddc045e,0xdc3c0306,0x00000000,0x00000000}},	//   _বিভূ, dáče, --, --, 
   {{0x3d180ce0,0x02a405f5,0x92e80011,0xaa7800a2}},	//   म्मे_, өрөм, বলে_, _seýk, 
   {{0x99800006,0x7f5401d5,0xe93408a8,0xaa780432}},	//   lvių_, _boyq, זניץ_, _peýk, 
   {{0xad980030,0x99800064,0x00000000,0x00000000}},	//   krúc, ovių_, --, --, 
   {{0xdcfc0024,0xaa7800a2,0xd70800fe,0x3d1800cd}},	//   norė, _geýh, _ৰোৱা_, म्भे_, 
   {{0xf9f4031c,0x99800024,0x00000000,0x00000000}},	//   _བྷེན_, ivių_, --, --, 
   {{0x35a00020,0xabb000d1,0xaa78010e,0xad9819cd}},	//   ግሥታት_, завә, _teýk, trúb, 
   {{0x9528038f,0x317d3fe2,0xd0500085,0xbe9801f2}},	//   _རིའི_, litz_, ́fɛl, ọhụr, 
   {{0x25680158,0xad993fe3,0x9ed80209,0xaa780432}},	// [1fc30] _høle_, rrúb, _умыт_, _keýi, 
   {{0x317d3fe4,0xb88004bf,0xd05800ac,0x256800b5}},	//   nitz_, čína, _sevə, _køle_, 
   {{0xaa780209,0x6d5402d0,0x00000000,0x00000000}},	//   _meýi, _ioxa, --, --, 
   {{0x6d5402b9,0x317c01c6,0x9980010e,0xef1c0205}},	//   _hoxa, hitz_, hriň_, znün_, 
   {{0x6d5402c4,0xf8ac3321,0x5fcc05b3,0x85b80484}},	//   _koxa, _یکم_, _संभल, алдс_, 
   {{0x6d553fe5,0x7bd80008,0xb5a8002e,0x842400d1}},	//   _joxa, ítug, _w斡nd, قىتن, 
   {{0x92e81c82,0x22bc0374,0x6d553fe6,0x317c81ed}},	//   বলৈ_, _mākū_, _moxa, ditz_, 
   {{0x7760002f,0x78a8002f,0x05a8000d,0xdcfc0064}},	//   ckox, üfve, _चीरब, borė, 
   {{0xaa7809a5,0x9f4d3fe7,0xdc3c00bc,0x5fa400d1}},	//   _beýi, álík_, váče, ۋەتم, 
   {{0x6d552229,0x7f5400ac,0xa020025c,0x317c01c4}},	//   _noxa, _soyq, _འགྱང_, gitz_, 
   {{0xcea8159d,0xdb040597,0xdc3c012c,0x7c203421}},	//   _סי_, rmiú, táče, _ćoro, 
   {{0x317c01c4,0x7f54014f,0xdf48013e,0xd1480220}},	//   aitz_, _qoyq, сҷид_, _ۇشىن_, 
   {{0x317cb7ad,0xdc3c022a,0x93947b8f,0x00000000}},	//   bitz_, ráče, _عجما, --, 
   {{0x25680e38,0x6d553fe8,0xaa7800ee,0xaabc190c}},	//   _føle_, _coxa, _geýi, ्शनक, 
   {{0x6d541574,0x6da0bf29,0x7b540640,0xa0200327}},	//   _doxa, фира, ођач, _འགྲང_, 
   {{0xd9111655,0x237c010f,0x9d540050,0x99800153}},	//   کیس_, niuj_, _کۆست, yvių_, 
   {{0xe9d4d3a6,0x225d3fe9,0xd1f00020,0x4f081411}},	// [1fc40] жку_, nyuk_, _ሀብት_, _اتىپ_, 
   {{0x6d553fea,0xc7642002,0xa92008ca,0xceb80118}},	//   _goxa, ۋانى, мдул, ýře_, 
   {{0xad98007b,0x7bcc0327,0x225c22d5,0x7d180254}},	//   srúc, qqbu, hyuk_, õtsu, 
   {{0x7c3c01e4,0x6d540472,0x99800024,0xdcfc0024}},	//   _irpr, _zoxa, tvių_, torė, 
   {{0x6d553feb,0xe60c6ea9,0x7d1d3fec,0x776001c4}},	//   _yoxa, نشو_, _kbps, rkox, 
   {{0x6d553fed,0x37e4030d,0x00000000,0x00000000}},	//   _xoxa, _могг, --, --, 
   {{0x317d3fee,0x7c3c0175,0xaa7800a2,0x69c803b2}},	//   vitz_, _jrpr, _beýw, ígev, 
   {{0x7c20107d,0xaa7800ee,0xca740023,0x00000000}},	//   _ćorl, _seýi, በልኩም_, --, 
   {{0x225c0357,0xaa78010e,0x25680fac,0x317c009d}},	//   gyuk_, _deýw, _søle_, titz_, 
   {{0xc50802f2,0xce94013e,0xb5cc02dd,0x00000000}},	//   _هتمل_, ҷамъ, _ﻗﻮﻳﻌ, --, 
   {{0x317d3fef,0x6d553ff0,0x237c0369,0x3a2005b1}},	//   ritz_, _roxa, biuj_, _lpkp_, 
   {{0xa2d07427,0xdea40198,0x317d3ff1,0x225c0066}},	//   _قيمت, _haiƙ, sitz_, byuk_, 
   {{0x63640054,0x224801e6,0x6d540077,0x22bc00b0}},	//   _uñna, äckt_, _poxa, _pākū_, 
   {{0xdb053ff2,0xb054030f,0x09a8000d,0x00000000}},	//   lliè, _وپشت, _कठेय, --, 
   {{0xdea40198,0xaa7800c7,0xe88800d0,0x6d54022e}},	//   _maiƙ, _jeýv, _ťažš, _voxa, 
   {{0xe848cb3a,0x3a200263,0x9cb400db,0x2eec02d2}},	//   یجان_, _bpkp_, بۅپت, _þgf_, 
   {{0x7c3c0ade,0x6d540de2,0xdcfc0139,0xef1c03b9}},	// [1fc50] _erpr, _toxa, _äzğa, nnüm_, 
   {{0xad9800fc,0x00000000,0x00000000,0x00000000}},	//   brúa, --, --, --, 
   {{0xf8b400f7,0xdb5001d9,0x27e40100,0xa3a8000d}},	//   зөт_, رَے_, ènn_, _गठल_, 
   {{0x225c0548,0x00000000,0x00000000,0x00000000}},	//   yyuk_, --, --, --, 
   {{0x66240597,0x7ae00077,0x29051c14,0x00000000}},	//   تراك, ñote, ònas_, --, 
   {{0xa27c02d3,0xf9f40327,0x1be801ad,0xcfb003d4}},	//   _ንስኻን_, _བྷིན_, टीवल_, ছদিন, 
   {{0xaa7800a2,0x5824014b,0x00000000,0x00000000}},	//   _peýw, _омёб, --, --, 
   {{0x42d400d4,0xf2e80051,0x80b805ac,0x00000000}},	//   чіку, _đâù_, _ইভল্, --, 
   {{0x225c0357,0x85740408,0x99800205,0x977c0408}},	//   uyuk_, _елах, ntiş_, _турă_, 
   {{0xd1cc02d3,0x237c0369,0xefdc001f,0x95c81422}},	//   _አብቲ_, siuj_, ናገድ_, _фута_, 
   {{0x225d3ff3,0xdb040129,0x41c40014,0x237c012d}},	//   syuk_, bliè, _کٲتِ, piuj_, 
   {{0x88d000bd,0x71740882,0xdb04c474,0x22480267}},	//   িরিক, rīkṣ, cliè, äcks_, 
   {{0x21c80166,0x122800d4,0x00000000,0x00000000}},	//   _тыеп_, _моїй_, --, --, 
   {{0xad980008,0x3ce4033f,0x5bb40027,0xf650011a}},	//   trúa, करें_, ंग्व, עצם_, 
   {{0xdb042a59,0x93bc054e,0xdcfc00e2,0x00000000}},	//   llié, _isăr, lorī, --, 
   {{0x3a200ac5,0xdcfc01fa,0xe518228d,0xaff800c8}},	//   _ppkp_, mirč, प्ति_, _פּוי, 
   {{0x3f813ff4,0xb9c400db,0xab580139,0x7bd80174}},	// [1fc60] miku_, سقاي, _tiün, ítub, 
   {{0xa3c80764,0xf1cc012d,0x00000000,0x00000000}},	//   लदा_, _हंसन, --, --, 
   {{0x18280214,0x7c3c0857,0xdc3c00d7,0x00000000}},	//   تقای_, _urpr, _káča, --, 
   {{0x3d10000d,0xcc2400e5,0x00000000,0x00000000}},	//   _ताडे_, _کریٹ, --, --, 
   {{0xdc3c00d7,0x98b80171,0x00000000,0x00000000}},	//   _máča, _korī_, --, --, 
   {{0x3f803266,0x7bc53ff5,0xb4b01206,0xdcfc0064}},	//   hiku_, _hiku, нилә, kirč, 
   {{0x6ba40261,0x3f8025a9,0x799c01f5,0x8554036b}},	//   _órgã, kiku_, mopw, بیلر_, 
   {{0x23440075,0x7bc420ee,0xdea403f9,0x3f80005c}},	//   كلىپ_, _jiku, _waiƙ, jiku_, 
   {{0x784c01ed,0x68e0002d,0xad980332,0xe0e000cc}},	//   _fővá, űnde, drún, _মাজভ, 
   {{0x7bc53ff6,0x799c0099,0x3ce4012d,0x00000000}},	//   _liku, nopw, करों_, --, 
   {{0x3f813ff7,0x7bc40588,0xfbbcdd06,0xab580139}},	//   fiku_, _oiku, ्दाम, _biül, 
   {{0x7bc53ff8,0xdb0420ef,0x7528004d,0xaa7800a2}},	//   _niku, blié, lefz, _keýt, 
   {{0xaa7800e4,0x799d1c08,0x88d00183,0x024801c8}},	//   _jeýt, kopw, িৰিক, _وجهو_, 
   {{0x7bc53ff9,0x25680162,0xdcfc0427,0x62300eed}},	//   _aiku, _køla_, birč, _чешу, 
   {{0x7bc40a03,0xdd953ffa,0x5eec0154,0xaa78010e}},	//   _biku, хары, _কারও_, _leýt, 
   {{0x7bc53ffb,0xd1380024,0x3f809e11,0xcb08009a}},	//   _ciku, ldą_, ciku_, تيرن_, 
   {{0x2aa93ffc,0x89d80597,0xceb8b392,0x3d18447d}},	// [1fc70] ство_, زوار_, _фән_, म्हे_, 
   {{0x7bc53ffd,0xd13802d5,0x799d3ffe,0x92e8009e}},	//   _eiku, ndą_, gopw, বলয়_, 
   {{0x2d8039eb,0x7bc53fff,0xd1380024,0x99801432}},	//   mije_, _fiku, idą_, stiş_, 
   {{0x7bc54000,0x6d4c0fcf,0x6f0c009a,0xaa780432}},	//   _giku, škač, ngcc, _beýt, 
   {{0x80c40c58,0x00000000,0x00000000,0x00000000}},	//   লুপ্, --, --, --, 
   {{0x7bc41b33,0xd138033f,0xaa7800a2,0xdcfc00e2}},	//   _ziku, jdą_, _deýt, vorī, 
   {{0x69c40472,0x7c200e3c,0x7bc54001,0x3f814002}},	//   _iije, _ćork, _yiku, yiku_, 
   {{0xc24456de,0x69cd4003,0x69c54004,0x7bc40564}},	//   дник, _kuce, _hije, _xiku, 
   {{0x2d800537,0x44294005,0x69c54006,0x69cc1711}},	//   kije_, ňa_, _kije, _juce, 
   {{0x2d814007,0x69c54008,0x3f814009,0x69cd400a}},	//   jije_, _jije, wiku_, _muce, 
   {{0x2d8008ad,0x69c5400b,0x25680162,0xaa78010e}},	//   dije_, _mije, _gøla_, _zeýt, 
   {{0x69c4036f,0x442406a3,0x6f0c074d,0x69cd400c}},	//   _lije, _ipl_, ggcc, _ouce, 
   {{0x7bc44375,0x69cd400d,0x69c400e4,0xf8a808d1}},	//   _riku, _nuce, _oije, _कर्प, 
   {{0x2d81400e,0x69c4d82d,0x3f81400f,0x4424049b}},	//   gije_, _nije, siku_, _kpl_, 
   {{0x69cd4010,0x7bc54011,0x8c954012,0x0c94084c}},	//   _auce, _piku, ерті, ештя, 
   {{0x63b94013,0x6f0c074d,0x69cd4014,0x6728044e}},	//   nmun, cgcc, _buce, jegj, 
   {{0x2d814015,0x7bc54016,0x69c54017,0x69cc084c}},	// [1fc80] bije_, _viku, _bije, _cuce, 
   {{0x69c4036f,0x69cd4018,0x44254019,0x63b9401a}},	//   _cije, _duce, _opl_, hmun, 
   {{0x7bc5401b,0x69c5401c,0xb8f41b37,0x69cd401d}},	//   _tiku, _dije, _हल_, _euce, 
   {{0x69ccdb10,0xade839de,0x69c401c7,0xd1380024}},	//   _fuce, जीवन_, _eije, zdą_, 
   {{0x69c40851,0x69cc01b2,0x2ba41a22,0x256806ea}},	//   _fije, _guce, _कीटा, _søla_, 
   {{0x69c400ee,0x63b80393,0x00000000,0x00000000}},	//   _gije, emun, --, --, 
   {{0x4425401e,0x69cc04cc,0x6729401f,0xaa7800a2}},	//   _cpl_, _zuce, begj, _feýs, 
   {{0x69c54020,0x44243743,0xf6241614,0x66080004}},	//   _zije, _dpl_, _одбо, bugk, 
   {{0x44254021,0x2d800223,0x69c54022,0x35a40137}},	//   _epl_, yije_, _yije, _жааг, 
   {{0x7bdc0989,0x61e80399,0x63b8022f,0x256803b2}},	//   _otpu, _dwgl, amun, _tøla_, 
   {{0x2d800bb8,0x44254023,0xd1380006,0xaa7800e4}},	//   vije_, _gpl_, rdą_, _jeýr, 
   {{0x2d800223,0xb50c00c5,0xaa7800a2,0x00000000}},	//   wije_, _साँय_, _meýr, --, 
   {{0x61e80142,0x7bdc3e9d,0x3eb00210,0xc0640023}},	//   _gwgl, _atpu, _czyt_, _ዝዘርግ, 
   {{0x601400b4,0x3d183cbe,0x69cc01ef,0x7d180254}},	//   ụmah, म्ले_, _ruce, õtsp, 
   {{0x69c4036f,0xfe6c5311,0x442402fa,0x23800008}},	//   _rije, لگی_, _xpl_, _þrjú_, 
   {{0x2d8008ad,0x69c54024,0x69cd4025,0x49d81e76}},	//   sije_, _sije, _puce, здаю_, 
   {{0x99d400d1,0xaa78010e,0xade800ce,0x90740066}},	// [1fc90] نتلا, _reýs, जीशन_, _زهکش, 
   {{0x69cd4026,0x63b94027,0xaa78010e,0xab580055}},	//   _vuce, zmun, _beýr, _kiük, 
   {{0x69c54028,0xa8a54029,0x63b9402a,0x672802d3}},	//   _vije, фрак, ymun, tegj, 
   {{0x44244e3d,0x69c5402b,0xe9dc00d0,0xee3c0306}},	//   _rpl_, _wije, _prúd_, ový_, 
   {{0x69c4036f,0x4425402c,0x6729402d,0xa645402e}},	//   _tije, _spl_, regj, بخان, 
   {{0x66080e29,0x4425402f,0x63b94030,0xe9dc0241}},	//   rugk, _ppl_, wmun, _itú_, 
   {{0x63b94031,0x03a54032,0xb5c00006,0x00000000}},	//   tmun, нико, ыйшл, --, 
   {{0x4254048a,0xad9801a8,0x66080098,0x00000000}},	//   етот, drúm, pugk, --, 
   {{0xaa78010b,0xad981427,0x00000000,0x00000000}},	//   _zeýr, trúl, --, --, 
   {{0x63b94033,0x4424010a,0x78a00311,0xa2b800cd}},	//   smun, _tpl_, şove, शेष्, 
   {{0x63b94034,0xad9802d2,0x00000000,0x00000000}},	//   pmun, grúm, --, --, 
   {{0x907c00b7,0xdb04026c,0xc27407b5,0xad980332}},	//   ኖሚያዊ_, gliì, _плеј, srúl, 
   {{0x6f600a89,0x9f600241,0xdcf400d7,0x00000000}},	//   увяз, _ìrís_, šačo, --, 
   {{0x28dcf5d8,0x00000000,0x00000000,0x00000000}},	//   _प्लि, --, --, --, 
   {{0x7c654035,0xe9dc0418,0x3f68026a,0x00000000}},	//   راسل, _atú_, _нико_, --, 
   {{0xe9dc0174,0x00000000,0x00000000,0x00000000}},	//   _btú_, --, --, --, 
   {{0x39454036,0x5fac07f7,0xaa7800ee,0x00000000}},	// [1fca0] ннаг, _टीएल, _seýr, --, 
   {{0xdff076f8,0xdcfc00b8,0x00000000,0x00000000}},	//   _आबाद_, birā, --, --, 
   {{0xbd80069c,0x77c80a89,0xe9dc0332,0xdcfc00cd}},	//   _ካብቶም_, члег_, _crúb_, cirā, 
   {{0x68e01ae6,0x2b480048,0xd6c43cb9,0xf770009a}},	//   ında, _gncc_, نمای, دائ_, 
   {{0x163480df,0x7af4d24d,0x4ad80a81,0x16c401e0}},	//   теля, mayt, _تاپھ_, тҡан, 
   {{0x7af54037,0x66e00032,0xdb040de2,0x00000000}},	//   layt, _ҡоса, mmiñ, --, 
   {{0x53340801,0xad980162,0x00000000,0x00000000}},	//   вейт, muút, --, --, 
   {{0xe7340209,0x256806ea,0xaa78010b,0x1be807f7}},	//   _пес_, _høll_, _keýp, टीएल_, 
   {{0xaa7800e4,0xdb040077,0x65680332,0x00000000}},	//   _jeýp, nmiñ, ámhó, --, 
   {{0x7af54038,0xbbbc08df,0xad9803b2,0x6590009b}},	//   hayt, ्दुक, trúm, _бађу, 
   {{0x7af45435,0x256803cd,0xd5b8002b,0xddc4010e}},	//   kayt, _møll_, _ihā_, _iriň, 
   {{0x753801c4,0xee3c02fb,0x7af54039,0xddc400d0}},	//   _hatz, tvý_, jayt, _hriň, 
   {{0x7539403a,0x7af4102c,0xdecc02d3,0xd5b80055}},	//   _katz, dayt, በርካ_, _khā_, 
   {{0x753801c4,0x23440150,0xa1100133,0xad980162}},	//   _jatz, _يلەپ_, _موهت, juút, 
   {{0x3d107f1a,0x7539403b,0x5c040024,0xbbbc04af}},	//   _तारे_, _matz, лята, ्दूक, 
   {{0x7af51d68,0x9b59403c,0x7539403d,0xf1a803e6}},	//   gayt, нист_, _latz, _باڵه_, 
   {{0xad241ec7,0x28c00f90,0x00000000,0x00000000}},	// [1fcb0] _كردو, वेनि, --, --, 
   {{0x93bc0276,0x753864cb,0x7684022e,0xad9803b2}},	//   _spăl, _natz, _mаyd, guút, 
   {{0xdecc02d3,0x48c46518,0x7af4022e,0xf8ac01d9}},	//   በርኩ_, тшағ, bayt, ۅکہ_, 
   {{0x6384034c,0x7af43a73,0x00000000,0x00000000}},	//   _mènè, cayt, --, --, 
   {{0x7538152d,0xd5b800b8,0x2568003b,0x9bc801ec}},	//   _batz, _bhā_, _føll_, _سۇكە_, 
   {{0x7538026c,0xd5b8002b,0x0cc40154,0xab580055}},	//   _catz, _chā_, ্রীত, _siüh, 
   {{0x7539403e,0x63840066,0xd4e402bf,0xd5b8002b}},	//   _datz, _nènè, уючи, _dhā_, 
   {{0xd5b80069,0x753801c4,0xddc400a2,0x68f4058a}},	//   _ehā_, _eatz, _eriň, laxd, 
   {{0x7539403f,0x45d400d6,0x569473b3,0x3d1000e1}},	//   _fatz, _розс, _батт, _ताले_, 
   {{0x67394040,0x66186e0e,0x753801c6,0x98480014}},	//   _hauj, _iquk, _gatz, _تلہٕ_, 
   {{0x638400f2,0x673800e2,0x4430007f,0x7af403f0}},	//   _cènè, _kauj, _èz_, yayt, 
   {{0x6738ff44,0x7af54041,0x75394042,0xd138033f}},	//   _jauj, xayt, _zatz, wląt_, 
   {{0x673811e6,0x0ea4000d,0x7af401d5,0x00000000}},	//   _mauj, _गुदड, vayt, --, 
   {{0x61f82747,0x67394043,0x7af54044,0x7e640158}},	//   msul, _lauj, wayt, rykp, 
   {{0x68f40050,0x7af54045,0x61f94046,0xa3c40073}},	//   daxd, tayt, lsul, ोआप_, 
   {{0x67384077,0xfe444640,0x66180921,0xab2419c3}},	//   _nauj, _анио, _oquk, коса_, 
   {{0xee34e88a,0x7af45d7a,0x81e4015b,0xdb040005}},	// [1fcc0] _аны_, rayt, _ফিড_, umiñ, 
   {{0x7af54047,0xbc654048,0x61f94049,0xbef00574}},	//   sayt, _авок, isul, _अजुन_, 
   {{0x67380097,0x61f8f575,0x6619404a,0x7af40986}},	//   _bauj, hsul, _aquk, payt, 
   {{0x61f8d36c,0x753803fa,0x7af5404b,0x67380055}},	//   ksul, _satz, qayt, _cauj, 
   {{0x67380beb,0x75380065,0xd1f8001f,0x68f40014}},	//   _dauj, _patz, ጋጅቶ_, baxd, 
   {{0x61f828b3,0x49180ebb,0x00000000,0x00000000}},	//   dsul, _पायो_, --, --, 
   {{0xbef00574,0x66180944,0xe9dc0016,0x61f9404c}},	//   _अजून_, _equk, _trúc_, esul, 
   {{0xd5b80053,0x6739404d,0x2810006c,0x7684022e}},	//   _whā_, _gauj, _خوفس, _pаyd, 
   {{0x61f9404e,0x758126b1,0x7539404f,0x6384020c}},	//   gsul, _پیغم, _tatz, _sènè, 
   {{0x6738b7f2,0x63840066,0x00000000,0x00000000}},	//   _zauj, _pènè, --, --, 
   {{0x7bd94050,0x61f94051,0x76414052,0xad9803b2}},	//   ítul, asul, lvoy, kuúr, 
   {{0x6fdc0055,0x00000000,0x00000000,0x00000000}},	//   _nīce, --, --, --, 
   {{0x5f954053,0x76414054,0xa130005e,0x638400f2}},	//   рият, nvoy, ارۋش, _wènè, 
   {{0x02c400d1,0x6384007f,0x828401b9,0xa1e001af}},	//   _сичү, _tènè, _حجمل, _тәъҫ, 
   {{0x08f000bd,0x49a40220,0xe8bc0327,0xad9801e7}},	//   _চালু_, ңызғ, _མཛེག, nrúi, 
   {{0xdb051cdd,0xf9b40107,0x3de000eb,0x00000000}},	//   glià, қахӯ, _বিরল, --, 
   {{0x67394055,0xdb041f60,0x3324010a,0xe9dc032e}},	// [1fcd0] _rauj, rmið, _mbox_, _brúa_, 
   {{0xdb042833,0xe9dc0005,0x2d84f3aa,0x0a58013e}},	//   smið, _crúa_, _öne_, _ҷамъ_, 
   {{0x68f54056,0x61f8003e,0x00000000,0x00000000}},	//   raxd, zsul, --, --, 
   {{0xad98004e,0x68f40067,0xdcfc0356,0x45d4005b}},	//   drúi, saxd, piră, годс, 
   {{0x61f81571,0x1a9400c0,0xef1c06be,0x1b1c00cc}},	//   xsul, _ваяў, lnüs_, _পোকে_, 
   {{0xe9dc2760,0xd6d80588,0x09ac009e,0x61f80158}},	//   _grúa_, нтә_, _কংকা, vsul, 
   {{0xdb0400dd,0x33254057,0x61f80113,0xd91800d8}},	//   lliá, _bbox_, wsul, _шорц_, 
   {{0x61f94058,0x3324a8cf,0x6680036b,0x03a8036b}},	//   tsul, _cbox_, _پیتل, رگاو_, 
   {{0x61f94059,0x66180944,0x33240112,0x163401b9}},	//   usul, _uquk, _dbox_, _кетя, 
   {{0x61f9405a,0xc104212d,0xf1b80208,0xe4680798}},	//   rsul, دودي, _chơ_, _ошел_, 
   {{0x61f9405b,0xbfc40801,0x33240175,0x51540032}},	//   ssul, лбок, _fbox_, ртыу, 
   {{0xeee801dc,0x3325405c,0x13682310,0xdb04005b}},	//   ường_, _gbox_, _ишчи_, lmiö, 
   {{0x5fcc28d4,0x24400205,0x61f8022e,0x6440007c}},	//   _संकल, _hım_, qsul, lvni, 
   {{0xee240451,0x5d842b8d,0x2bc400d1,0x24400205}},	//   اڻيو_, рғож, ғлуп_, _kım_, 
   {{0x7c200cf4,0x7f441367,0xad9800d7,0x83b400df}},	//   _ćors, _бейж, dsúd, ָפּע_, 
   {{0xf090025f,0x290000dd,0xfaa433a6,0xdb2401b8}},	//   _לנו_, _adja_, габо, _äsüm, 
   {{0xf2d030fb,0xeb95405d,0xdb0401d3,0xad9803f2}},	// [1fce0] מען_, уит_, gliá, ruúr, 
   {{0x26dc013f,0xeac0010b,0x764001b9,0xf5e401ec}},	//   _afuo_, сбуп, vvoy, ңілм, 
   {{0x24400139,0xf744a99d,0x00000000,0x00000000}},	//   _nım_, лежо, --, --, 
   {{0xeabc0428,0xe9dc04d4,0x6fdc0055,0xdb05405e}},	//   _ibùn_, _irún_, _hīcc, bliá, 
   {{0xe9dc01a8,0x6440b251,0x15180395,0x00000000}},	//   _trúa_, evni, волъ_, --, 
   {{0x332402fa,0xad9800c6,0x290001a6,0x7641405f}},	//   _sbox_, trúi, _gdja_, rvoy, 
   {{0xb42411c7,0x28c006ff,0xb40801c6,0x24400205}},	//   اعتو, वेदि, хэлж_, _cım_, 
   {{0x2440013d,0xad9801e7,0x00000000,0x00000000}},	//   _dım_, rrúi, --, --, 
   {{0x64400030,0x7544010b,0x31c40da9,0xc6a40014}},	//   avni, _йназ, лсов, _پۯوٕ_, 
   {{0xaa34008f,0x332401f4,0xad980332,0x07a4014b}},	//   נטיק_, _wbox_, prúi, _баӣн, 
   {{0xddc404ba,0x33240175,0x612401c0,0x987800d0}},	//   _eriŋ, _tbox_, уцыг_, háľa_, 
   {{0x6b480793,0xdb040254,0x00000000,0x00000000}},	//   _mögä, omiõ, --, --, 
   {{0xf1b80016,0x21240175,0x80c4015b,0x3cb00150}},	//   _thơ_, _fbnh_, লুল্, _ﺼﺭﺍﺤ, 
   {{0x24400205,0x50854060,0xec14104e,0xdd840150}},	//   _yım_, _پاتې, легә_, бысп, 
   {{0xeb494061,0x09dc0073,0xad980162,0x00000000}},	//   нчак_, यऱ्य, krúv, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x60d40023,0x4a54e584,0xa14000de,0x00000000}},	// [1fcf0] _çamë, шкас, _šķip, --, 
   {{0x64414062,0x6b480139,0xad980124,0x00000000}},	//   yvni, _bögä, erúv, --, 
   {{0xde94129e,0xc6d40114,0x00000000,0x00000000}},	//   _نجیب, ажећ, --, --, 
   {{0xdb040077,0x78ac5f03,0x24400139,0x668001b9}},	//   pliá, _dybv, _rım_, میزل, 
   {{0x256806ea,0x7b8401e0,0xedf001ef,0xbaf8011a}},	//   _høli_, _тәрб_, _अबोध_, _בהרש, 
   {{0x58d54063,0x644001fa,0x6aac0076,0x36640120}},	//   _горт, tvni, _iycf, рашо_, 
   {{0x7d08045f,0x644005d5,0xaabc00bc,0x00000000}},	//   _ôfse, uvni, ्शकक, --, 
   {{0x64414064,0x26dc009f,0xe7842c25,0x00000000}},	//   rvni, _ufuo_, _суго, --, 
   {{0xc6180276,0xf8c80332,0x00000000,0x00000000}},	//   _шоах_, _tséú_, --, --, 
   {{0x20000219,0xd2000131,0x24400139,0x6b480166}},	//   šjim_, чүшк, _tım_, _yögä, 
   {{0x212412ea,0x00000000,0x00000000,0x00000000}},	//   نيکی_, --, --, --, 
   {{0xfe44036b,0x7bd800df,0x00000000,0x00000000}},	//   анмо, ŭtuk, --, --, 
   {{0xee341fac,0x8e741a71,0xdb054065,0x00000000}},	//   аня_, бурч, lliç, --, 
   {{0xeee807ae,0xc0e49d73,0x5db800db,0x8e7428f6}},	//   ưởng_, _токк, اپسڭ_, суюч, 
   {{0xed554066,0xfaf4005b,0xb8800118,0xb60800d1}},	//   шор_, ичаю, řízn, _ﺳﯘ_, 
   {{0x3d1002e5,0xeb9401c6,0xb5c401ec,0xb098011a}},	//   _ताके_, аис_, _ﺨﺎﻁﺌ, _שיקר, 
   {{0xe9d54067,0x00000000,0x00000000,0x00000000}},	// [1fd00] икт_, --, --, --, 
   {{0x256806ea,0x99442a9b,0xef1c00a2,0xfd48011c}},	//   _føli_, _döş_, lnüp_, _рзок_, 
   {{0x59d80c2e,0x98b94068,0x499800d6,0xd1f8001f}},	//   _भंवर, _borġ_, уття_, _ወዴት_, 
   {{0x70d00bc0,0xaf040295,0xbb4457c6,0x00000000}},	//   _सल्ल, _itùñ, _темк, --, 
   {{0x1dbc6b9b,0x4ab82038,0x994400a2,0xa68001c6}},	//   ोगपत, _буря_, _göş_, олцд, 
   {{0x6b480724,0x383400cf,0x83cc0150,0x00000000}},	//   _tögä, _پىرز, _ﺗﺎﺭﺳ, --, 
   {{0x63a80175,0xdb040254,0xef2400a2,0x00000000}},	//   _bkgn, smiõ, lküň_, --, 
   {{0x98b80327,0x6fdc0b13,0x234400d1,0x1ae40154}},	//   _gorġ_, _nīca, للىپ_, গণকে_, 
   {{0xd2514069,0x0ea42232,0xab5800e5,0x00000000}},	//   سند_, _गुंड, _kiür, --, 
   {{0xdb05406a,0x00000000,0x00000000,0x00000000}},	//   bliç, --, --, --, 
   {{0xad980332,0x00000000,0x00000000,0x00000000}},	//   hsúc, --, --, --, 
   {{0x256805ac,0xe1900137,0xad9802d2,0x00000000}},	//   _røli_, йлөө, hrút, --, 
   {{0x290401ed,0xad98be08,0x72340214,0x6378011a}},	//   ónak_, krút, _خراط, _בנאד, 
   {{0x2bd81098,0x1af000cc,0x00000000,0x00000000}},	//   _मंदा, _ছাগে_, --, --, 
   {{0xdd945fd0,0xef1c00e5,0xdb040166,0x998000a2}},	//   цары, niük_, kliä, msiň_, 
   {{0xad980022,0x9980010e,0x00000000,0x00000000}},	//   erút, lsiň_, --, --, 
   {{0x4975406b,0xf1b80034,0x00000000,0x00000000}},	// [1fd10] блас, _उठान, --, --, 
   {{0xdcf40135,0x0a9401d5,0xdcfc0327,0x1c1406e3}},	//   _ċaħd, _ҳамю, porġ, तूहल_, 
   {{0xeabc0086,0xab59406c,0x708402d3,0xaaa40fe3}},	//   _ibùm_, _diür, _ኣሕሊፉ_, _कुरक, 
   {{0x205408a8,0x0708028e,0xe70801c8,0x9944008e}},	//   ייבל_, ايشي_, ئتان_, _töş_, 
   {{0xab5804cc,0x572405a9,0x5fd02052,0x99800432}},	//   _chüe, تىنك, _संघल, ksiň_, 
   {{0x49040372,0x6014063f,0x27040208,0x04c80ccb}},	//   _دوسق, ụmih, ốn_, هوشي_, 
   {{0x28c00ad7,0x7b0400e5,0x9f44036e,0xd83801f4}},	//   वेशि, _áttö, ëjë_, _кэт_, 
   {{0x32c80cad,0x00000000,0x00000000,0x00000000}},	//   _ẹya_, --, --, --, 
   {{0x6d14033f,0x41a81d0f,0x7ae0005a,0x42c801af}},	//   _तांग_, лвин_, ñoti, ыгин_, 
   {{0xe2947a32,0x66e00055,0xe4a5406d,0x98b80055}},	//   лақ_, _dãkų, _крео, _harā_, 
   {{0x3f6801c0,0x98b9406e,0x64a800f3,0x00000000}},	//   гино_, _karā_, _рђав_, --, 
   {{0xad98002d,0x34b40375,0x002c001f,0xdb040e07}},	//   krús, _הפעם_, _እያከና, poié, 
   {{0xaaa40574,0x4129406f,0xe9dc0413,0xc2c40451}},	//   _कुलक, _боло_, _brúm_, _ايشي, 
   {{0x3d1000e1,0x00000000,0x00000000,0x00000000}},	//   ़लें_, --, --, --, 
   {{0xd1b80075,0x3b094070,0x256803b2,0xdb041572}},	//   _ئانا_, лево_, _følv_, yliä, 
   {{0xa3b40882,0x98b800cd,0x00000000,0x00000000}},	//   छति_, _narā_, --, --, 
   {{0xf2d8010f,0x00000000,0x00000000,0x00000000}},	// [1fd20] אַבל, --, --, --, 
   {{0xd9100405,0xe8f45970,0xe7cc0873,0x3d1000c5}},	//   بیس_, йлу_, _ﺑﺎﺭﻟ, _ताटे_, 
   {{0x0a50044e,0xa3b44466,0x98b800ef,0xbd8800e5}},	//   _ሃዋርያ, छता_, _barā_, _لنکن_, 
   {{0x7c3c04b9,0xc7642dfc,0xc7954071,0x98b800b8}},	//   _ispr, يانى, орчы, _carā_, 
   {{0x200009a8,0x00000000,0x00000000,0x00000000}},	//   šjih_, --, --, --, 
   {{0x7c3c0100,0xb7d8ce83,0x3eb00108,0xe5a03425}},	//   _kspr, _موسا_, _myyt_, пичи, 
   {{0xe3acc4f2,0xf7449ada,0x3eb00254,0xe88001f4}},	//   کرو_, _лево, _lyyt_, _егрп, 
   {{0x98b800e2,0x75d45edc,0x00000000,0x00000000}},	//   _garā_, _هيرا, --, --, 
   {{0xf1a4ef0c,0xaa7800a2,0x00000000,0x00000000}},	//   йрон, _beýy, --, --, 
   {{0x25681088,0x7c3d4072,0x32080122,0x768401a9}},	//   _sølv_, _ospr, čby_, _hаyo, 
   {{0xa3dc1533,0xd25055de,0x7c3c002f,0x3d100d79}},	//   _धूप_, سنگ_, _nspr, _ताजे_, 
   {{0x28980bd9,0xf1b800c5,0x985c00ef,0x00000000}},	//   ריטא, _उठवन, dāļa_, --, 
   {{0x49f40327,0xaaa427f2,0x49187271,0x71a40006}},	//   _བསེལ_, _कुंक, _पालो_, _ладз, 
   {{0x61414073,0x7684022e,0x00000000,0x00000000}},	//   _неча, _lаyo, --, --, 
   {{0x256803b2,0x00000000,0x00000000,0x00000000}},	//   _gølu_, --, --, --, 
   {{0x7c3c00b5,0x00000000,0x00000000,0x00000000}},	//   _dspr, --, --, --, 
   {{0x7c3d4074,0x98b802b5,0xeab000c6,0x09e000cc}},	// [1fd30] _espr, _rarā_, سعر_, মীনা, 
   {{0x88940801,0x27300208,0x98b80055,0x00000000}},	//   оизх, _ản_, _sarā_, --, 
   {{0x27e4092e,0x7684022e,0x1ac80116,0x98b800dc}},	//   ënn_, _bаyo, _қуюп_, _parā_, 
   {{0x290c09a5,0x99e805ac,0x00000000,0x00000000}},	//   şga_, _পিৰক, --, --, 
   {{0x98b83da0,0x00000000,0x00000000,0x00000000}},	//   _varā_, --, --, --, 
   {{0x7c3d4075,0x04c800f1,0x070801e2,0x00000000}},	//   _yspr, ټوبي_, _ږيري_, --, 
   {{0x98b800b0,0x398007d6,0x98480276,0x7c3c0334}},	//   _tarā_, _تیلف, _лята_, _xspr, 
   {{0x69dc0194,0x42080063,0x00000000,0x00000000}},	//   oqqe, анио_, --, --, 
   {{0x25680579,0x93bc0276,0xe1200327,0xc19800d4}},	//   _sølu_, _apăs, _འཁྱད_, итої_, 
   {{0xc0054076,0x93bc054e,0x741000db,0x00000000}},	//   опок, _spăt, سوۋا, --, 
   {{0xe9dc022c,0x3eb0023a,0x98b80356,0x00000000}},	//   _brúk_, _syyt_, _iară_, --, 
   {{0x42541ec7,0x81d40672,0x00000000,0x00000000}},	//   _ونار, _додх, --, --, 
   {{0x7c3c0175,0xfce400db,0x00000000,0x00000000}},	//   _sspr, жого, --, --, 
   {{0x7c3c0076,0x00000000,0x00000000,0x00000000}},	//   _pspr, --, --, --, 
   {{0x69dc0194,0xa3dc60c7,0x49f4031c,0x24a8015b}},	//   eqqe, _धूम_, _བསུལ_, গেরহ, 
   {{0xdb040597,0xfb140228,0x7d1c009a,0x00000000}},	//   lliú, تورج, _wcps, --, 
   {{0x7d1c011c,0x98b80276,0x28ac00c5,0x00000000}},	// [1fd40] _tcps, _oară_, _जुबि, --, 
   {{0xad98007b,0x7c3c0a9c,0xb8b40063,0xed54030d}},	//   lsún, _tspr, осећ, _доь_, 
   {{0xb17800c8,0xdb0400c6,0x69dc0194,0xf7440108}},	//   סטער, iliú, aqqe, жеео, 
   {{0xd3780bb8,0x0a540014,0xba1800ec,0x00000000}},	//   _kuće_, _کھٲج, _پيسا_, --, 
   {{0x98b8054e,0x93bc0356,0x36350716,0xc87803b9}},	//   _bară_, _opăr, تراس, _əşi_, 
   {{0x1dbc084a,0xb4b14077,0x98b80356,0x00000000}},	//   ोगित, милә, _cară_, --, 
   {{0x29dc2776,0x98b80356,0xf7180024,0x00000000}},	//   _zîa_, _dară_, _візы_, --, 
   {{0x93bc00a8,0x6d4003b2,0x36686584,0x2bbc00cd}},	//   _apăr, _ónav, _кабо_, ्षया, 
   {{0xa5f403b7,0x1dbc07d0,0x98b80356,0x613c0153}},	//   _меѓу_, ोगात, _fară_, kšlė, 
   {{0x28ac07f7,0x98b8054e,0x31680114,0x00000000}},	//   _जुडि, _gară_, ршио_, --, 
   {{0x25680158,0x2bbc16d1,0xb4e45b99,0x00000000}},	//   _vølt_, ्षमा, पडी_, --, 
   {{0x77603d20,0xceb800fb,0x2bd800cd,0xdef94078}},	//   njox, йәп_, _मूषा, жыр_, 
   {{0x3ce49736,0x00000000,0x00000000,0x00000000}},	//   _şova_, --, --, --, 
   {{0xd37801a6,0xad98007b,0x614000ea,0x3ce409ab}},	//   _duće_, asún, _жеља, जुले_, 
   {{0x7684036b,0x1be800c7,0xabb00022,0x00000000}},	//   _sаyl, жьуп_, ҧаҳә, --, 
   {{0x7d08000f,0xd1b80116,0x00000000,0x00000000}},	//   _ôfsn, _ئاچا_, --, --, 
   {{0x4974d4d0,0xe8d000dc,0x9a842502,0x2bbc0118}},	// [1fd50] плас, तश्च, муфл, ्षबा, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d5400aa,0x98b8054e,0x00000000,0x00000000}},	//   _inxa, _rară_, --, --, 
   {{0x6d454079,0xd7f800f7,0x17f800c6,0x98b80356}},	//   ldja, юуу_, تركة_, _sară_, 
   {{0x49f42fb5,0xf8ac9105,0x98b8054e,0xdb240158}},	//   _བསིལ_, نکہ_, _pară_, ærår, 
   {{0x6d45407a,0x65a80114,0x55880006,0x044400f3}},	//   ndja, штег_, обім_, зекн, 
   {{0x32040585,0x6d45106b,0x98b80276,0x980401b9}},	//   _avoy_, idja, _vară_, _оятд, 
   {{0x6d440066,0xd7f80816,0x93bc054e,0x4428031c}},	//   hdja, _фур_, _spăr, ċa_, 
   {{0x56940e76,0xdb0405d5,0x668001b9,0x44280083}},	//   _жатт, gliù, _تیشل, ŋa_, 
   {{0x22a00064,0x00000000,0x00000000,0x00000000}},	//   _rūką_, --, --, --, 
   {{0xa34405f5,0xcea8008f,0x2bd83347,0x409404a9}},	//   _мэдл, _עי_, _मूला, ярит, 
   {{0x6d540548,0x3ea402ec,0xc2c401c8,0xdb0401e7}},	//   _anxa, зимг, _فيضي, sliú, 
   {{0x09e0009e,0x00000000,0x00000000,0x00000000}},	//   মীতা, --, --, --, 
   {{0x317c01f7,0xd37801a6,0x00000000,0x00000000}},	//   chtz_, _vuće_, --, --, 
   {{0x6da0096f,0xada0fa84,0x98b83ee4,0x400801f7}},	//   хира, харл, _karą_, _ايبٽ_, 
   {{0x6d55407b,0x3ea40323,0xbea400d6,0x6ea51afa}},	//   _enxa, _нийг, _найк, _टुकु, 
   {{0xe9d5407c,0x225c0429,0x98b80064,0x00000000}},	// [1fd60] зку_, nxuk_, _marą_, --, 
   {{0xad9801ed,0xaec00daf,0x7bd806ea,0x00000000}},	//   nsúl, _ябыл, ítus, --, 
   {{0xeb9c03b2,0xeaac1c3b,0x44240051,0x00000000}},	//   _fjø_, نٹہ_, _nql_, --, 
   {{0x2bbc7922,0xeb9cb3f8,0x6e9000f2,0x5bc401c8}},	//   ्षणा, _gjø_, _آلیا, _آڪسف, 
   {{0x7bdd407d,0x442401b9,0xe60c036b,0xc7640145}},	//   _hupu, _aql_, هشو_, بالى, 
   {{0x2005407e,0xef1c07c5,0x6d400162,0x44240208}},	//   _ovni_, chüf_, _ónat, _bql_, 
   {{0x798d407f,0x7bdd4080,0x32040139,0x98b800c0}},	//   _imbw, _jupu, _svoy_, _barą_, 
   {{0x7bdd4081,0xd7780014,0x06d000eb,0x00000000}},	//   _mupu, _بٔرژ_, াড়ি, --, 
   {{0x7bdd4082,0x20054083,0x2bbc1b61,0xd69800e5}},	//   _lupu, _avni_, ्षता, _بھاؤ_, 
   {{0xad980491,0x7bdc0280,0xe57400fa,0x00000000}},	//   gsúl, _oupu, _езу_, --, 
   {{0x798c0943,0x45640014,0x7bdd4084,0xb5cc02dd}},	//   _mmbw, _تھنہ, _nupu, _ﺗﻮﻳﻌ, 
   {{0x64a001c0,0x98b80064,0xb4c87688,0xa0844f3f}},	//   _яаха, _garą_, ोशी_, ясыз_, 
   {{0x20041125,0x7bdc0751,0xe9dc01a8,0x798d4085}},	//   _evni_, _aupu, _trúi_, _ombw, 
   {{0x7bdd4086,0x6d440357,0x7d080b21,0xeb9c4673}},	//   _bupu, udja, _ôfsl, _sjø_, 
   {{0x6d454087,0x7bdd4088,0xd25000f1,0x2bb800ae}},	//   rdja, _cupu, _سنګ_, مارة_, 
   {{0x798d4089,0x1fa402d5,0x7bdd408a,0x17c400b8}},	//   _ambw, _прыг, _dupu, _ṛṣīṃ, 
   {{0x7bdc00e4,0xda35408b,0xdb500014,0x4dc401af}},	// [1fd70] _eupu, неты, ھَے_, _ороҡ, 
   {{0x7bdc0032,0x6d540921,0x610c02ea,0x682402d5}},	//   _fupu, _unxa, _pɔlɔ, зьдз, 
   {{0x7bdd408c,0xad980077,0x7bd801e4,0xf1b8000d}},	//   _gupu, nsúm, ŭtur, _उठईन, 
   {{0xef1c05bb,0x798c0337,0xd7f02374,0x00000000}},	//   ngü_, _embw, چكە_, --, 
   {{0x6b8c009a,0xb860001f,0x29040332,0x00000000}},	//   _imcg, ደርገው_, ónas_, --, 
   {{0x7bdc022e,0xb4c80118,0x00000000,0x00000000}},	//   _yupu, ोशू_, --, --, 
   {{0x7bdc18f7,0x98b87063,0x03a5408d,0x0444005b}},	//   _xupu, _parą_, мико, фейн, 
   {{0x225c01c4,0x42840150,0x00000000,0x00000000}},	//   txuk_, _ﺨﻁﻭﻁ_, --, --, 
   {{0x57242dfc,0x00000000,0x00000000,0x00000000}},	//   _سىلك, --, --, --, 
   {{0xb6840014,0xdef802d3,0x237c0784,0xef1c06be}},	//   _تھٔل_, ላዉን_, shuj_, hhüd_, 
   {{0xe9dc0241,0x98b80064,0x46e01116,0x7c3c0092}},	//   _irúu_, _tarą_, _फलाह, _ያካሄዱ, 
   {{0x5434109c,0xbef800cd,0x00000000,0x00000000}},	//   _سرمر, ्णेन_, --, --, 
   {{0x7bdd408e,0x8e540212,0x00000000,0x00000000}},	//   _supu, нтрі, --, --, 
   {{0xdc3c0419,0x59d807af,0x00000000,0x00000000}},	//   _váľa, _भूगर, --, --, 
   {{0x7bdc0309,0x2ae802e3,0x798c035a,0x00000000}},	//   _qupu, _ụkọ_, _rmbw, --, 
   {{0x05dc1533,0xd37804b9,0x7bdc0564,0x798c02d0}},	//   मदाब, _kuća_, _vupu, _smbw, 
   {{0xeb940075,0xdaa40588,0x39440d30,0xdfa801d9}},	// [1fd80] фит_, хгаҩ, мнаг, _وُڈو_, 
   {{0xd01000c6,0x7bdd408f,0xc9440107,0x46b0000d}},	//   _çلè_, _tupu, ндуқ, _जड़ह, 
   {{0x6b8c0334,0x7bdd4090,0xc9d40066,0xfbc4014b}},	//   _fmcg, _uupu, رممک, _обоо, 
   {{0x29040436,0x00000000,0x00000000,0x00000000}},	//   ónar_, --, --, --, 
   {{0x7af40124,0xeb380375,0x41ac07f7,0x7bc401f4}},	//   mbyt, _ועכש, ङवास, _ihku, 
   {{0x798c5a6d,0x7af4007c,0x49980108,0x00000000}},	//   _umbw, lbyt, _ется_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd37805be,0x32084f85,0x7af411ad,0xc0bc001f}},	//   _buća_, охон_, nbyt, _ተራራ_, 
   {{0x3f814091,0x00000000,0x00000000,0x00000000}},	//   dhku_, --, --, --, 
   {{0xd37801a6,0x78a14092,0x799c007f,0x65c001f0}},	//   _duća_, şovu, nnpw, _абуа, 
   {{0x7bc4037e,0x80c80406,0xe9dc02d2,0x8640010c}},	//   _ohku, हेले, _hrút_, _ባርነት, 
   {{0x7d08000f,0xe9dc03b2,0x98b800ef,0x00000000}},	//   _ôfsj, _krút_, _anrī_, --, 
   {{0x7af54093,0x9df813f3,0x9258010b,0xef1c0342}},	//   dbyt, мнят_, _халт_, rgü_, 
   {{0xfc481b49,0x3f8000b5,0x6fdc0171,0x8fd000fb}},	//   _ብልጽግ, ahku_, _līci, _әҙмә, 
   {{0x60400022,0x6b8c0175,0xdcfc007f,0x4de0000d}},	//   _ахыз, _pmcg, chrč, _गंवई_, 
   {{0x7af42bac,0x5ba408ca,0x00000000,0x00000000}},	//   gbyt, вруз, --, --, 
   {{0x27fc002e,0x2bc000cd,0x00000000,0x00000000}},	// [1fd90] _ňun_, _वीणा, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7af42f48,0x4c9400a8,0xddc400ef,0xd7e40a4a}},	//   bbyt, _чинс, _briņ, вічо, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xaaa4e079,0xd5e80372,0x2d800108,0x28c0134e}},	//   _कुचक, وعون_, ohje_, वेजि, 
   {{0xddc400ef,0xd6040408,0x85041291,0x761459e1}},	//   _eriņ, _гiов, روبن, رقىز_, 
   {{0x69c54094,0x00000000,0x00000000,0x00000000}},	//   _ihje, --, --, --, 
   {{0xc24405c5,0xd04c013f,0xdb0803cd,0x98b80153}},	//   еник, _ɛkɔb, øløv, _narę_, 
   {{0xe9dc03b2,0xd79402e8,0xad9803b2,0x00000000}},	//   _trúu_, _ритъ, gsúk, --, 
   {{0x02d800aa,0x72c08dc7,0x8064082d,0x91b401fb}},	//   _ځواب_, ыбыз, евож, _đẹp_, 
   {{0x2d80069c,0xe9dd4095,0x2bd8012d,0x998003e0}},	//   dhje_, _krús_, _मंगा, hriş_, 
   {{0x45640014,0x64c83f2c,0x00000000,0x00000000}},	//   _تھچہ, ाधीश, --, --, 
   {{0x69c40664,0x63b932c2,0x7d080b21,0xdb04010b}},	//   _ohje, mlun, _ôfsk, gliý, 
   {{0x63b94096,0x7bc4069c,0x3f80044e,0x2d800c95}},	//   llun, _shku, shku_, ghje_, 
   {{0x63b94097,0x28ac0e49,0x00000000,0x00000000}},	//   olun, _जुलि, --, --, 
   {{0x63b94098,0xdb1c03e3,0xee2c00ec,0xdb04010b}},	//   nlun, _özül, _ڇٽي_, bliý, 
   {{0xfce453ab,0x63b80639,0xe3a43b5f,0x0e440022}},	// [1fda0] _попо, ilun, _ەر_, _амыҟ, 
   {{0x63b94099,0x2d81409a,0x69c42b1d,0xe9dc004e}},	//   hlun, chje_, _chje, _arús_, 
   {{0x69c4044e,0x63b9409b,0xe9dc0162,0x3e8406af}},	//   _dhje, klun, _brús_, _fêté_, 
   {{0xb6a5409c,0xdd2016f0,0x68f801a6,0x7bc40641}},	//   ниел, _बाँध_, _đude, _uhku, 
   {{0x63b9409d,0x2bbc4c83,0x19440124,0x69200139}},	//   dlun, ्षरा, _иҭан, _әмса, 
   {{0x69c40ba3,0x63b9409e,0x65bc006a,0xb8f4007b}},	//   _ghje, elun, sêhn, _سكرب, 
   {{0xc8b5409f,0x63b940a0,0xe9a140a1,0xa9a00aac}},	//   _асты, flun, _сарп, _сирд, 
   {{0x326517e8,0x394940a2,0xe9dc004d,0xa3dc01f9}},	//   етов, _habs_, _trút_, _धूळ_, 
   {{0xe1ed40a3,0xdb0540a4,0xc32c16a0,0xdd201d72}},	//   یسی_, llió, تەن_, _बांध_, 
   {{0x63b940a5,0x764005b8,0x39480100,0xad9806ea}},	//   alun, mwoy, _jabs_, rsúk, 
   {{0x63b940a6,0x4f080372,0x98b80034,0x3948045a}},	//   blun, үнүн_, _parę_, _mabs_, 
   {{0x394940a7,0x63b8025c,0xda100073,0xa13001d3}},	//   _labs_, clun, ाळात_, پریش, 
   {{0x2d80044e,0x59b00574,0x76400198,0x30c000eb}},	//   thje_, जकार, nwoy, োডেস, 
   {{0x76400198,0x43cc02dd,0x6ce80118,0x00000000}},	//   iwoy, _ﺗﺎﯕﺪ, जुंग_, --, 
   {{0x68f40175,0x2bbc00bc,0x2174011a,0xad9800ae}},	//   vbxd, ्षला, _אתגר_, nsúi, 
   {{0x2d80044e,0x20540375,0x3948005c,0x764140a8}},	//   shje_, _טיול_, _aabs_, kwoy, 
   {{0x394940a9,0x00000000,0x00000000,0x00000000}},	// [1fdb0] _babs_, --, --, --, 
   {{0x3948030d,0x63b80007,0x28a40150,0xb34400fd}},	//   _cabs_, zlun, ншег, luçı, 
   {{0x4ac4069f,0x63b803cb,0x39480fac,0x7ae000e2}},	//   लेजव, ylun, _dabs_, žota, 
   {{0xb34400fd,0x98150030,0xdb1402d2,0x00000000}},	//   nuçı, ابلا, _áaða, --, 
   {{0x69c4044e,0x3948123b,0x5a38010a,0x00000000}},	//   _thje, _fabs_, _пырă, --, 
   {{0xcfe9161d,0xe4e410f5,0xd37801a6,0x39480e78}},	//   কীয়_, хідн, _bućo_, _gabs_, 
   {{0x63b940aa,0xa4900405,0x2b48009f,0xad98007b}},	//   tlun, دیات, _kacc_, gsúi, 
   {{0x63b80481,0x76400223,0x27e0010f,0x2900aa9a}},	//   ulun, bwoy, _iujn_, _heja_, 
   {{0x63b832ff,0x290140ab,0x2b49090f,0x3cf401bc}},	//   rlun, _keja_, _macc_, ्रमे_, 
   {{0x63b940ac,0x290000c7,0x19cc0150,0x7c380205}},	//   slun, _jeja_, _ﺒﺎﻟﻠ, çtrk, 
   {{0x63b940ad,0xc9cc0075,0x7d08002d,0x00000000}},	//   plun, _ﺑﻮﻟﻐ, _ôfsi, --, 
   {{0x2b4940ae,0x290140af,0x63b80309,0xafe403b2}},	//   _nacc_, _leja_, qlun, _skøð, 
   {{0x2bd8000d,0x27e00200,0x64400142,0x00000000}},	//   _मंजा, _lujn_, lwni, --, 
   {{0x2b480c6a,0x290140b0,0xdb0801e1,0x00000000}},	//   _aacc_, _neja_, _ìlúk, --, 
   {{0x2b4805da,0x6440007f,0x6fdc00de,0xb344013d}},	//   _bacc_, nwni, _pūce, buçı, 
   {{0x2b481028,0x26dd40b1,0x394940b2,0x236c020c}},	//   _cacc_, _nguo_, _sabs_, _jogj_, 
   {{0x290140b3,0x76900139,0xb340008e,0x00000000}},	// [1fdc0] _beja_, _mıyç, _öçes, --, 
   {{0x29000407,0x7d5400c8,0x2b480009,0xdcfc00dc}},	//   _ceja_, _ייִד_, _eacc_, bhrā, 
   {{0x290140b4,0x2b4800e8,0x6840014b,0x6b8c0162}},	//   _deja_, _facc_, инфа, ðigá, 
   {{0x2b480998,0x39480204,0x7c2c6144,0x7640002e}},	//   _gacc_, _wabs_, mtbr, twoy, 
   {{0x394940b5,0x290002d3,0xdb04004e,0xba7400cf}},	//   _tabs_, _feja_, bliò, _شاحت, 
   {{0x290140b6,0x427c0020,0x236c0477,0xd37805be}},	//   _geja_, ባይነት_, _aogj_, _pućo_, 
   {{0xdb0540b7,0x7c2d40b8,0x76400687,0xe3ac00ec}},	//   lliñ, ntbr, swoy, ڊري_, 
   {{0xe3ac0979,0x2b4800e8,0x7c2c257c,0x80b400e1}},	//   يري_, _xacc_, itbr, _उड़े, 
   {{0xe64002de,0x6b800276,0x7d08002d,0x31c46af7}},	//   _кетп, _înge, _ôfsw, ксов, 
   {{0xd13140b9,0x7c2c713c,0xe28c07c0,0x26140bae}},	//   حمد_, ktbr, غذي_, _निती_, 
   {{0x64a00266,0x21600f15,0x00000000,0x00000000}},	//   _кафа, ртыг, --, --, 
   {{0x7c2c2305,0x828000d1,0x63540354,0xc0c4035b}},	//   dtbr, рқәд, _ашшĕ, ышық, 
   {{0xb3440724,0x2b4800db,0x7c2c0072,0xd5b80171}},	//   ruçı, _racc_, etbr, _kkā_, 
   {{0x2b48002e,0x236c0240,0x00000000,0x00000000}},	//   _sacc_, _zogj_, --, --, 
   {{0x290140ba,0x2b480de2,0xd010007b,0x7c2c01bf}},	//   _reja_, _pacc_, _الب_, gtbr, 
   {{0x290140bb,0x5b15337d,0x09bc725a,0x7ae000e2}},	//   _seja_, имст, ्ग्य, žotn, 
   {{0x290140bc,0x699000c7,0x26140073,0x1bd436ca}},	// [1fdd0] _peja_, алаӡ, _निधी_, ротя, 
   {{0x6ac04c83,0x2bc03347,0x64400034,0x2b480de2}},	//   _शरीर, _वीरा, ywni, _wacc_, 
   {{0x29000cfc,0x481540bd,0xdb040077,0x4cd00154}},	//   _veja_, умес, aliñ, _ত্রু, 
   {{0xd5b818a6,0xdb041709,0x2b480998,0x2440002d}},	//   _akā_, bliñ, _uacc_, _rűm_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6b80006a,0x82340131,0xad98035b,0x00000000}},	//   _îngb, ۇرخا, asúv, --, 
   {{0xddc40055,0x644001f5,0x7684022e,0xd4082b62}},	//   _ariś, uwni, _sаyt, پتىم_, 
   {{0x823401b9,0xd5b800cd,0x768401a9,0x644066fe}},	//   هرخا, _ekā_, _pаyt, rwni, 
   {{0x6cf00490,0x768401d5,0x00000000,0x00000000}},	//   _अभंग_, _qаyt, --, --, 
   {{0x98b801e4,0x45d400cf,0x7c2c007c,0xf1f40066}},	//   _larĝ_, _созс, ytbr, اکنش_, 
   {{0xb34003e0,0x00000000,0x00000000,0x00000000}},	//   şçak, --, --, --, 
   {{0x3e880108,0x00000000,0x00000000,0x00000000}},	//   еймо_, --, --, --, 
   {{0x6e2c00b5,0x626400cf,0xd228007b,0x21240051}},	//   gtcb, _جااق, _لكنه_, _tcnh_, 
   {{0x7c2c0738,0x412800d8,0x00000000,0x00000000}},	//   ttbr, _чоко_, --, --, 
   {{0xa6b8015b,0x5194074d,0x70740133,0x998000d7}},	//   েশিয়, _тăра, _مموز_, ntiť_, 
   {{0xef1c03e3,0xdb0408a5,0x00000000,0x00000000}},	//   lhün_, glið, --, --, 
   {{0x7c2d40be,0x98f40075,0x7bb800ee,0xfaa800ec}},	// [1fde0] stbr, لغاچ, _җынс_, رهئي_, 
   {{0xdb040077,0x7c2c002f,0x49001075,0x00000000}},	//   rliñ, ptbr, жүрг, --, 
   {{0xb178008f,0xe81c39a7,0xdb0403b2,0x8120000d}},	//   עטער, मूला_, blið, _माईओ_, 
   {{0xf7b940bf,0xf0b4008f,0xe9dc0332,0x27f400f2}},	//   رداش_, אלער_, _trúp_, افند_, 
   {{0xbb48036b,0x998000d0,0x69d000e4,0xdcfc0166}},	//   _قلگن_, etiť_, ëjeý, lorı, 
   {{0x7684022e,0x98c00ac1,0xd6e403d4,0x00000000}},	//   _bаyr, şsın_, মৰূপ, --, 
   {{0x70a0000d,0x6e380327,0x00000000,0x00000000}},	//   _ओखेल, ħubi, --, --, 
   {{0x521505c6,0x7684022e,0xad980162,0xa6800166}},	//   адит, _qаys, lsút, рләд, 
   {{0xb4640046,0x1db401ad,0x62a001e1,0x00000000}},	//   _әкел, ंकात, _àto̟, --, 
   {{0xc33801d3,0x8ee803d4,0xad980162,0xdcfc00c0}},	//   áírá, পৰাগ, nsút, mirė, 
   {{0xad98000f,0xb0cc033f,0x2934008f,0x98b8008e}},	//   isút, हेंग, נאטן_, _korı_, 
   {{0xe19000f7,0xd00801e0,0xddc400cd,0x00000000}},	//   илөө, неүе_, _triś, --, 
   {{0x5f9540c0,0x957c068f,0x5e8501be,0xcd740092}},	//   сият, _ciąg, бурз, _ያለውና_, 
   {{0xef1c07c5,0x00000000,0x00000000,0x00000000}},	//   chün_, --, --, --, 
   {{0xe0cc00cf,0xd8c8313e,0x00000000,0x00000000}},	//   _ىزى_, _ﺩﺍﻻﻟ, --, --, 
   {{0xaa7800a2,0x00000000,0x00000000,0x00000000}},	//   _agýa, --, --, --, 
   {{0xdb0409f3,0x00000000,0x00000000,0x00000000}},	// [1fdf0] rlið, --, --, --, 
   {{0xdb0405a4,0xddc40115,0x6dc4036b,0x998000d0}},	//   slið, _kriŝ, _حزبل, ytiť_, 
   {{0xdca40120,0x00000000,0x00000000,0x00000000}},	//   _гаќи, --, --, --, 
   {{0x20540375,0xaef800e4,0xe15c0023,0xda000037}},	//   טיבל_, ajùv, _ንወንጌ, _लौकत_, 
   {{0x96b80228,0xd138033f,0x00000000,0x00000000}},	//   лушу_, ciąg_, --, --, 
   {{0x7d080b21,0x441498cc,0xddc401e4,0x2bbc1df0}},	//   _ôfst, афит, _oriŝ, ्षका, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7c2c0166,0xdcfc0064,0x998000d7,0x00000000}},	//   _çirş, birė, rtiť_, --, 
   {{0x998001f1,0x4174014d,0x161c00af,0x42c802e8}},	//   stiť_, لادس, _नियर_, ъгин_, 
   {{0xae1c012c,0xdb1c0139,0xb61c01ec,0x00000000}},	//   _बमजन_, _özöl, _ﺤﺩ_, --, 
   {{0x6fdc00cd,0x07900241,0x00000000,0x00000000}},	//   _sūca, _àìsí_, --, --, 
   {{0x527540c1,0x98b80166,0xd4980117,0x00000000}},	//   _گامز, _xorı_, _сру_, --, 
   {{0x24a400e2,0x01644a03,0x00000000,0x00000000}},	//   šumā_, _вкло, --, --, 
   {{0x8cb01d15,0x00000000,0x00000000,0x00000000}},	//   _आँखो, --, --, --, 
   {{0x6da023b3,0xe0d00214,0x3b940063,0xada0ccc3}},	//   цира, _ازش_, ајат, царл, 
   {{0x2bbc23fd,0x6fb000c6,0x66d8013d,0x00000000}},	//   ्षगा, _وموا, _xäkü, --, 
   {{0xcf2400cf,0x0ae86ea9,0x2ba402e5,0xb9042c25}},	// [1fe00] _ارىي, ارفي_, _गदरा, изак, 
   {{0xe8f540c2,0x42a0001f,0x98b8013d,0x00000000}},	//   илу_, _ውድነት_, _sorı_, --, 
   {{0xad1808a8,0x4a7401e0,0xad9803b2,0xf1c408a5}},	//   _בויר, _һырт, rsút, _þáer_, 
   {{0x2614069f,0x7c3c038f,0x237c009b,0x98b8013d}},	//   _निशी_, _ippr, jkuj_, _qorı_, 
   {{0xe7e800ab,0xad9801d3,0x69f001f0,0x00000000}},	//   _जूठा_, csús, _дӯхт, --, 
   {{0x3cd83fae,0x7b3c0034,0x261401ad,0xad9803b2}},	//   _ব্যৱ, _dłuż, _निरी_, lsúr, 
   {{0xdcfc0153,0xe46402e8,0x3a303bba,0xf7440dab}},	//   sirė, ишъл_, ltyp_, _кево, 
   {{0xd3780bb8,0x00000000,0x00000000,0x00000000}},	//   _kući_, --, --, --, 
   {{0xf1a41086,0xe3acaca6,0x3a3140c3,0x657807c5}},	//   ирон, برو_, ntyp_, üchö, 
   {{0x7c3d40c4,0xddc40115,0xd37801a6,0xe29c01a8}},	//   _oppr, _priŝ, _mući_, úða_, 
   {{0xb36402e8,0x66d80139,0xdb04000d,0x161c0d2e}},	//   _вълк, _täkü, lliõ, _निडर_, 
   {{0xef9001b9,0x00000000,0x00000000,0x00000000}},	//   تیبد, --, --, --, 
   {{0x71a40153,0x00000000,0x00000000,0x00000000}},	//   _кадз, --, --, --, 
   {{0xe7e4069f,0x6140cfa1,0x50580014,0xe2c803e6}},	//   _ओढला_, _меча, _مٔتس_, _شانۆ_, 
   {{0xdb04067c,0x9da801c6,0x23b00244,0xdda8011c}},	//   oniè, ръяа_, _امۆس, ртял_, 
   {{0xdb041e4f,0xd378107d,0xceb800d1,0x7e6015ad}},	//   nniè, _bući_, _бәг_, _šope, 
   {{0x29040589,0x3a30b188,0x7c3c045a,0xdb0401f4}},	// [1fe10] ºna_, gtyp_, _eppr, yliö, 
   {{0x29050ca1,0xddc42b24,0xdebc0375,0xad9900fd}},	//   úna_, _iriş, _במחל, asúr, 
   {{0x7b3c068f,0xca240150,0x00000000,0x00000000}},	//   _służ, _ﹼﺤﺩ_, --, --, 
   {{0x75380036,0xd7741075,0xddc540c5,0x2904012d}},	//   _abtz, يانع, _kriş, źna_, 
   {{0xbb3800c8,0x2570036b,0x88b001d9,0x00000000}},	//   _גערי, оқас, _کیاچ, --, 
   {{0x2b3c01f2,0xdde402f0,0xf4a00023,0xda000037}},	//   _ịgụọ_, _úsťo, _ዝቕመጥ_, _लौटत_, 
   {{0xaad940c6,0x039540c7,0x25e40037,0x00000000}},	//   _मृतक, йрия, _छूरी_, --, 
   {{0xe7843a29,0x7c28143a,0xdb040129,0x13680063}},	//   _туго, _åfre, gniè, ишњи_, 
   {{0xe7e80dad,0x673940c8,0x41b4004e,0x00000000}},	//   _जूता_, _ibuj, йсот, --, 
   {{0x237d40c9,0xdb0406af,0x82a402dd,0x00000000}},	//   skuj_, aniè, _қалж, --, 
   {{0xab580036,0xc35400a7,0x200140ca,0x417400f2}},	//   _jhüs, _гълъ, èji_, لاگس, 
   {{0xddc400a2,0x058401b9,0x00000000,0x00000000}},	//   _briş, _туғм, --, --, 
   {{0x673940cb,0xee340251,0xddc40311,0x31d007d6}},	//   _mbuj, бня_, _criş, تقیز, 
   {{0x61f82f2b,0x00000000,0x00000000,0x00000000}},	//   mpul, --, --, --, 
   {{0x7ff540cc,0x67382252,0x61f940cd,0xddc403ee}},	//   _استا, _obuj, lpul, _eriş, 
   {{0x61f940ce,0xd3780cf4,0xeb9540cf,0xddc40356}},	//   opul, _pući_, бис_, _friş, 
   {{0x61f940d0,0x2efc0077,0xddc4013d,0x00000000}},	// [1fe20] npul, ñufe_, _griş, --, 
   {{0x673940d1,0xbd4529f5,0xfaa540d2,0x61f80270}},	//   _abuj, _اندي, _ҳамо, ipul, 
   {{0x7c3d40d3,0xab5807c5,0x2bc00d2c,0x3a305df7}},	//   _uppr, _chüs, _वीका, styp_, 
   {{0x7d0d40d4,0xd37805a1,0x3f80023a,0xdcfc1d86}},	//   labs, _tući_, nkku_, kirī, 
   {{0x3f8140d5,0x7bd400b5,0xd138012d,0x00000000}},	//   ikku_, mmyu, niąc_, --, 
   {{0x673806cc,0x7d0c20c7,0x9f480200,0x00000000}},	//   _ebuj, nabs, _bunë_, --, 
   {{0x855401b9,0xe44c00ae,0x00000000,0x00000000}},	//   تیلر_, فضي_, --, --, 
   {{0x799c0451,0x7d0c0014,0x9378084c,0x61f801e4}},	//   lipw, habs, рбит_, fpul, 
   {{0xdb042047,0x7d0d40d6,0x61f940d7,0x0798004e}},	//   rniè, kabs, gpul, _търъ_, 
   {{0x67380219,0xdb0401e4,0x43e800ec,0xca240150}},	//   _zbuj, sniè, _ڦرلٽ_, _ﺼﺤﺔ_, 
   {{0x61f80c89,0x999000b8,0x00000000,0x00000000}},	//   apul, _śaśa_, --, --, 
   {{0xddc42b24,0x799c127b,0x00000000,0x00000000}},	//   _priş, hipw, --, --, 
   {{0x9f480240,0x7d0c002f,0xddc403e3,0x98b800ef}},	//   _zunë_, fabs, _qriş, _karē_, 
   {{0x799c0161,0x32040477,0x00000000,0x00000000}},	//   jipw, _iwoy_, --, --, 
   {{0x8f340395,0xd6c000eb,0xa064009b,0x00000000}},	//   _дейц, েশিয, _гаја_, --, 
   {{0xddc4054e,0xad9800c7,0x8af940d8,0x9b941c90}},	//   _triş, asúp, рнас_, писц, 
   {{0x6f0d40d9,0x7d0d40da,0x20080210,0x097401f4}},	// [1fe30] macc, babs, ćcie_, огаю, 
   {{0x6f0d40db,0xab580c86,0x7d080b21,0x7d0c679e}},	//   lacc, _chür, _ôfsp, cabs, 
   {{0x2d80045f,0x4ab40037,0xd1380064,0x00000000}},	//   mkje_, _अँकव, ifą_, --, 
   {{0x6f0d40dc,0xd3780bb8,0x6d4540dd,0xe7093bf2}},	//   nacc, _kuću_, leja, اتان_, 
   {{0x2d8001f5,0x61f940de,0x6bd41c3b,0xda7801af}},	//   okje_, xpul, _پتھر, _ляр_, 
   {{0x9f48044e,0x2d8140df,0x61f80158,0x00000000}},	//   _punë_, nkje_, vpul, --, 
   {{0x6f0d40e0,0x2d8140e1,0x69d40135,0xe5040137}},	//   kacc, ikje_, mmxe, _ۇباي, 
   {{0x67382da1,0x6f0c08e5,0x9f480240,0x6d4400c7}},	//   _ubuj, jacc, _vunë_, heja, 
   {{0x6d4540e2,0x2d800183,0xe6640845,0x7d1800d0}},	//   keja, kkje_, _утво, ótsk, 
   {{0x2d800196,0x6d440124,0xdb0540e3,0x00000000}},	//   jkje_, jeja, rnié, --, 
   {{0x6f0d40e4,0xd138033f,0x00000000,0x00000000}},	//   facc, wiąc_, --, --, 
   {{0x6f0d40e5,0x61f940e6,0x2d8096eb,0x672805b1}},	//   gacc, ppul, ekje_, nggj, 
   {{0x63b80585,0x3f8032cb,0x2d80000f,0x7d0c0112}},	//   moun, rkku_, fkje_, tabs, 
   {{0x6f0c074d,0x63b940e7,0x6d4540e8,0x61e80393}},	//   aacc, loun, geja, _iugl, 
   {{0x7d0d40e9,0xd1380034,0x61e940ea,0xaad4012c}},	//   rabs, siąc_, _hugl, ढेसक, 
   {{0x6f0d40eb,0xbea4bf80,0x61e140ec,0x63b940ed}},	//   cacc, _майк, _hinl, noun, 
   {{0x6d4540ee,0x60c00649,0x61e940ef,0xcfa80345}},	// [1fe40] beja, _hynm, _jugl, _داوم_, 
   {{0x61e00cad,0x61e84e9e,0x60c006a3,0x6d4540f0}},	//   _jinl, _mugl, _kynm, ceja, 
   {{0x61e940f1,0x61e140f2,0x63b940f3,0x799c004c}},	//   _lugl, _minl, koun, ripw, 
   {{0x60c006a3,0x9f4800e8,0xbd4540f4,0x61e140f5}},	//   _mynm, _buné_, _انگي, _linl, 
   {{0x63b81280,0xab5803fa,0x61e940f6,0x61e002d0}},	//   doun, _thür, _nugl, _oinl, 
   {{0x61e140f7,0x6f0c0ffb,0x00000000,0x00000000}},	//   _ninl, zacc, --, --, 
   {{0x61e800fc,0x6f0c0882,0x00000000,0x00000000}},	//   _augl, yacc, --, --, 
   {{0x61e940f8,0x63b940f9,0x61e140fa,0xb4b80b4c}},	//   _bugl, goun, _ainl, _घडी_, 
   {{0x6f0d40fb,0x316823b3,0x61e842bc,0x61e003ee}},	//   vacc, ашно_, _cugl, _binl, 
   {{0x61e938e6,0x6f0d40fc,0x61e01b0d,0x6d44b7c8}},	//   _dugl, wacc, _cinl, xeja, 
   {{0x6f0d40fd,0x61e04a98,0x6d4540fe,0x61e940ff}},	//   tacc, _dinl, veja, _eugl, 
   {{0x61e94100,0x61e14101,0x63b94102,0x6d454103}},	//   _fugl, _einl, coun, weja, 
   {{0x61e93f5a,0xc0d0001f,0xa3b40c4c,0x3f900240}},	//   _gugl, _የዘር_, चकर_, ëzua_, 
   {{0x61e14104,0x2d81293e,0x60c0017a,0x61540014}},	//   _ginl, ukje_, _fynm, _ؤنز_, 
   {{0xfe6d23d4,0x2d814105,0x6728cf55,0x6f0d4106}},	//   نگی_, rkje_, yggj, pacc, 
   {{0xddc40054,0x2d814107,0x8e147327,0x61e00d27}},	//   _asiń, skje_, _едиц, _zinl, 
   {{0x61e02d64,0x6ce54108,0x68e40789,0x7f400986}},	// [1fe50] _yinl, _міне, _pgjd, _ñoqa, 
   {{0x67f0038f,0x63b94109,0x6b9c009a,0xabe80050}},	//   _aħja, zoun, siqg, _پردٕ_, 
   {{0x63b9410a,0x9f4817bb,0x74b4000d,0x00000000}},	//   youn, _suné_, _ऊँगृ, --, 
   {{0xab607a32,0x63b80005,0x7c2803cd,0xad2400f1}},	//   _تۇرى, xoun, _åfra, _ارکو, 
   {{0x63b81709,0xe7e8000d,0xaad40118,0x00000000}},	//   voun, _जूरा_, ढेशक, --, 
   {{0x61e9410b,0xf1c40118,0x00000000,0x00000000}},	//   _rugl, _žánr_, --, --, 
   {{0x61e9410c,0x61e1410d,0x63b9410e,0xd7f801af}},	//   _sugl, _rinl, toun, _мут_, 
   {{0x61e9410f,0x05954110,0xdcfc00c7,0x00000000}},	//   _pugl, _کارگ, rirĩ, --, 
   {{0x61e01512,0x7dd0037e,0x20040142,0x60c14111}},	//   _pinl, læse, _swni_, _synm, 
   {{0x60c00652,0x61e86c0e,0x270800bc,0xdcfc0022}},	//   _pynm, _vugl, _हजुर_, pirĩ, 
   {{0x61e14112,0x63b94113,0x61e801a4,0x00000000}},	//   _vinl, poun, _wugl, --, 
   {{0x61e94114,0x61e0ba54,0x60c00153,0xf438011a}},	//   _tugl, _winl, _vynm, _לתעש, 
   {{0xee354115,0x60c14116,0xfce40108,0xdcfc00ef}},	//   пня_, _wynm, зого, ekrā, 
   {{0x11f80133,0xbfa80166,0x00000000,0x00000000}},	//   _بووک_, ртүе_, --, --, 
   {{0xaffc01dc,0x519800f2,0xa28000e5,0x00000000}},	//   _trướ, _بخند_, _ریگو, --, 
   {{0xeb941639,0xdfd80244,0x00000000,0x00000000}},	//   пис_, _باتڵ_, --, --, 
   {{0xbea4ca5f,0x3a24010b,0x01f8010f,0xaa4020c2}},	// [1fe60] _хапк, ямаг, מפּל, нетл, 
   {{0x99806b92,0x7f546064,0x00000000,0x00000000}},	//   stiž_, _hayq, --, --, 
   {{0x3e400134,0x7f540986,0x6d78011a,0x00000000}},	//   _dɔte_, _kayq, _האיח, --, 
   {{0xdb240403,0x3cf407b6,0x00000000,0x00000000}},	//   _توحی, ्रके_, --, --, 
   {{0x7f540bf1,0xad980789,0x66000b95,0x00000000}},	//   _mayq, spúe, епча, --, 
   {{0x7f5402d1,0x3668023b,0xb9b40214,0x00000000}},	//   _layq, _қазо_, _رمزع, --, 
   {{0x6d880254,0x7af4045a,0xae900022,0x00000000}},	//   _jüaa, ocyt, tỹka, --, 
   {{0x7af54117,0x51f94118,0x7f54047e,0xa7a40276}},	//   ncyt, онию_, _nayq, _екса_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x54f005f9,0x69100022,0x00000000,0x00000000}},	//   _चलिए_, _iñeñ, --, --, 
   {{0x741401d9,0x7f54ffa6,0x00000000,0x00000000}},	//   _روشا, _bayq, --, --, 
   {{0xdef868dc,0x6fdc0171,0x00000000,0x00000000}},	//   зыр_, _kūci, --, --, 
   {{0x54f01d8a,0x51181cb5,0x23240107,0x00000000}},	//   _चलाए_, _долю_, _хочи_, --, 
   {{0x614000f3,0x00000000,0x00000000,0x00000000}},	//   _зеља, --, --, --, 
   {{0x21540d17,0x6fdc0171,0x00000000,0x00000000}},	//   _رجوع_, _lūci, --, --, 
   {{0x09c40b9c,0x7dd04e95,0x69100588,0x00000000}},	//   वत्य, væse, _oñeñ, --, 
   {{0x9f4804cc,0xaee0030c,0x00000000,0x00000000}},	// [1fe70] _munì_, _سۋسى, --, --, 
   {{0x61ec0077,0xddc400e2,0xda0816ac,0x00000000}},	//   ícli, _asiņ, سيمه_, --, 
   {{0x47354119,0x691000c7,0x2cf8012c,0x70200023}},	//   днес, _añeñ, ्रील_, _ተሰዊኦ, 
   {{0x6d55411a,0x3e400134,0x7dd000b5,0xa61000fd}},	//   _haxa, _wɔte_, ræse, ездә, 
   {{0x6d55411b,0x6fdc0171,0x85b800d8,0x00000000}},	//   _kaxa, _cūci, олдс_, --, 
   {{0x6d540694,0x98b80024,0x00000000,0x00000000}},	//   _jaxa, _narė_, --, --, 
   {{0x6d540d62,0x29102e95,0x6a800248,0x161c000d}},	//   _maxa, maxa_, _fífú, _निअर_, 
   {{0x2911411c,0xd7f9411d,0x170801d3,0x00000000}},	//   laxa_, _хур_, _فہمی_, --, 
   {{0x5695411e,0x6d55411f,0x6d4003e0,0x00000000}},	//   _затт, _oaxa, _ınan, --, 
   {{0x6d549c7c,0x29100054,0x7f543792,0x008401c6}},	//   _naxa, naxa_, _sayq, длоо, 
   {{0xff24656c,0x7f554120,0xeb9c01bf,0x98b80153}},	//   ммно, _payq, _omø_, _darė_, 
   {{0x2910094a,0x6d540548,0x6b800276,0x3ea4036b}},	//   haxa_, _aaxa, _îngh, димг, 
   {{0x6d554121,0x29101269,0x417433d2,0x00000000}},	//   _baxa, kaxa_, _ياتس, --, 
   {{0x2910094a,0x6d540429,0x7f5402d1,0x00000000}},	//   jaxa_, _caxa, _wayq, --, 
   {{0xef1c2c6f,0x29100050,0x6d554122,0x7f54016d}},	//   mkün_, daxa_, _daxa, _tayq, 
   {{0x7e600077,0x6d400784,0xfce401f0,0xef1c15b7}},	//   _áopo, _ñnan, зоҳо, lkün_, 
   {{0x6d54102c,0x2910005a,0x7dd001bf,0x59643452}},	// [1fe80] _faxa, faxa_, ræsb, ннағ, 
   {{0x26142068,0xe9d54123,0x29114124,0x7af4012d}},	//   _निजी_, дку_, gaxa_, scyt, 
   {{0x6fdc00cd,0x3d0808a3,0x00000000,0x00000000}},	//   _sūci, वरीं_, --, --, 
   {{0x28100451,0xb6a4010a,0x6d554125,0x6fdc00ef}},	//   ئونس, миел, _zaxa, _pūci, 
   {{0x6d554126,0x39e00184,0xeb954127,0x29112ab5}},	//   _yaxa, _аҙағ, _ция_, baxa_, 
   {{0x6d554128,0x29100789,0x6a8001e1,0x391401e2}},	//   _xaxa, caxa_, _wífú, _زورز, 
   {{0xb174001e,0x00000000,0x00000000,0x00000000}},	//   _nhượ, --, --, --, 
   {{0xb9dc001f,0x6d894129,0xd370007b,0x260801f9}},	//   _ቦሌ_, _nüan, اهة_, ठीही_, 
   {{0x9f4800db,0x91c5412a,0xd130007b,0xe2240064}},	//   _cuní_, нәкл, همة_, мюэл_, 
   {{0xef1c0790,0xdb0802d2,0x28b401f9,0x00000000}},	//   hhüt_, _ílæk, _ॅडमि, --, 
   {{0x6d5456d7,0x8f34868f,0x67400137,0xb1740051}},	//   _raxa, ненц, _سپەك, _chượ, 
   {{0x59d01533,0x6d55412b,0x291002c4,0xab580205}},	//   _तीसर, _saxa, zaxa_, _akün, 
   {{0x6d55412c,0x2910094a,0x5f95412d,0x29cc05d5}},	//   _paxa, yaxa_, тият, düan_, 
   {{0x6d5447ad,0x705410fe,0x2911412e,0x2cf837d0}},	//   _qaxa, _ينشا, xaxa_, ्रेल_, 
   {{0x6d5418f7,0x4c941f5a,0x00000000,0x00000000}},	//   _vaxa, хивс, --, --, 
   {{0x6d55412f,0x29100054,0x798c03cb,0xe4540115}},	//   _waxa, waxa_, _albw, וילט_, 
   {{0x6d554130,0x29100bc9,0x92ac015b,0x768401d5}},	// [1fe90] _taxa, taxa_, _গরু_, _tаyy, 
   {{0xe29c041e,0xddc401ef,0x00000000,0x00000000}},	//   úði_, _osiř, --, --, 
   {{0x29114131,0x8b8400cf,0x00000000,0x00000000}},	//   raxa_, _كەسە_, --, --, 
   {{0x29102e95,0xef1c05d5,0x6d5802b5,0x161007f7}},	//   saxa_, chüt_, ēuau, ठीभर_, 
   {{0x2910094a,0x9f980677,0xbaf8011a,0x00000000}},	//   paxa_, ודאה_, _מהרש, --, 
   {{0x29100bc9,0x00000000,0x00000000,0x00000000}},	//   qaxa_, --, --, --, 
   {{0xf9900375,0x57f4399f,0x00000000,0x00000000}},	//   _גרם_, _апст, --, --, 
   {{0xe6643da1,0x00000000,0x00000000,0x00000000}},	//   _отзо, --, --, --, 
   {{0x26080073,0xdb0400e5,0xd7640345,0x00000000}},	//   ठीशी_, nniá, _جۆنی, --, 
   {{0x66194132,0xf99000c8,0x2cf81715,0xb174001e}},	//   _ivuk, ָרט_, ्रोल_, _phượ, 
   {{0x2cf92ab6,0xef1c3361,0xf07400e5,0x00000000}},	//   ्रैल_, rkün_, فیوں_, --, 
   {{0xf8b000c8,0x6d880ba1,0xad9801d3,0xef1c15b7}},	//   רשט_, _qüan, csúz, skün_, 
   {{0x5ec8015b,0x09e40154,0x00000000,0x00000000}},	//   রেনে, _পৌছা, --, --, 
   {{0xef1c066d,0xb1740016,0x66194133,0x70800724}},	//   lkül_, _thượ, _mvuk, _әгъз, 
   {{0x394c06be,0xbb441422,0x00000000,0x00000000}},	//   _ölsə_, невк, --, --, 
   {{0x661801f0,0xffd40953,0x6d880254,0xf410011a}},	//   _ovuk, _яўля, _hüal, טפל_, 
   {{0xeb954134,0xeab40372,0x6fdc0055,0x2cbc2737}},	// [1fea0] хит_, ейт_, _cūcu, ğuda_, 
   {{0xb9c4049e,0x9c1400d1,0x92ac03d4,0xa9a0009d}},	//   رقاي, _ичмә, _গৰু_, гиуд, 
   {{0x66194135,0x6d8800ac,0x6cb00032,0xef1c1cce}},	//   _avuk, _müal, _бөтт, kkül_, 
   {{0x29040008,0x98b800b8,0x00000000,0x00000000}},	//   ðnar_, _harī_, --, --, 
   {{0x7bc54136,0xb8f42f8b,0x7c2d4137,0x46800046}},	//   _ikku, _হল_, lubr, ақта, 
   {{0xb4b07cdd,0x7c2c030a,0x499000e5,0x00000000}},	//   лилә, oubr, _پیمر, --, 
   {{0x7c2d4138,0x66194139,0xa420035b,0xab580205}},	//   nubr, _evuk, гьыл, _okül, 
   {{0x72283cc5,0x09b400cc,0x00000000,0x00000000}},	//   пцов_, _জীপা, --, --, 
   {{0xe3e401b9,0x7c2c07de,0x12d40395,0x00000000}},	//   رکمن_, hubr, ъжия, --, 
   {{0xd130b991,0x7c2d413a,0x0ef825c9,0x3d08033f}},	//   جمد_, kubr, ंड्स_, वरों_, 
   {{0x7bc50412,0x6618abea,0x5ec8015b,0x00000000}},	//   _okku, _zvuk, রেমে, --, 
   {{0xe1ec00b2,0xdd940220,0x00000000,0x00000000}},	//   _ڏسو_, қасы, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7bc4683c,0x98b80055,0x61d400d4,0x91c418c7}},	//   _akku, _carī_, _змія_, _шәйл, 
   {{0x7c2d413b,0x98b80055,0x00000000,0x00000000}},	//   gubr, _darī_, --, --, 
   {{0x5ba4e99a,0x9e8404d3,0x8d6c0092,0x4ad40037}},	//   груз, _ڕاپۆ, ጠማቸው_, _दरदव, 
   {{0x7c2c06af,0x00000000,0x00000000,0x00000000}},	// [1feb0] aubr, --, --, --, 
   {{0x7bc42f99,0x7dc82776,0xdd040276,0x7dd0037e}},	//   _ekku, rösê, ărăr, læsn, 
   {{0x7bc40418,0x7c2d413c,0x4c94035b,0x6618110c}},	//   _fkku, cubr, _ринс, _svuk, 
   {{0x6d8806be,0xc2200037,0x161c0210,0x00000000}},	//   _müam, _मिलब_, _निखर_, --, 
   {{0xd7c81fa1,0x00000000,0x00000000,0x00000000}},	//   روهه_, --, --, --, 
   {{0x7e600427,0x00000000,0x00000000,0x00000000}},	//   _šopk, --, --, --, 
   {{0x7bc4008c,0xff1400b5,0x69c53070,0x355000f1}},	//   _ykku, _logの, _ikje, شنيز, 
   {{0xc245413d,0xca240150,0xa24403c7,0x00000000}},	//   вник, _ﹼﻤﺕ_, فیصل_, --, 
   {{0x6619413e,0x07a40046,0x7c2c03fa,0x6b800311}},	//   _uvuk, _заңн, zubr, _îngu, 
   {{0x9f48c1a8,0x69c403b2,0x225c0327,0xa070008e}},	//   _sunà_, _jkje, rvuk_, гъмә, 
   {{0xe0cc00bd,0xc21c013f,0x98b802b5,0x00000000}},	//   রশ্ন, _mmɔɔ_, _rarī_, --, 
   {{0xe2a801ed,0x0fc807f7,0x7c2c03b2,0x00000000}},	//   _ٹاؤن_, रतगढ, vubr, --, 
   {{0xde48004b,0x1f180014,0x41b401af,0xdb0420b2}},	//   ریدو_, وٹھک_, _искт, lniç, 
   {{0xe9dc02d2,0xad980332,0x00000000,0x00000000}},	//   _spún_, spún, --, --, 
   {{0x7118008d,0x9f4804cc,0xed544ae5,0x6adc0154}},	//   _חוצפ, _tunà_, ъор_, _ফ্লো, 
   {{0xee2c05d9,0x916001e1,0xdd9001d3,0xddc40064}},	//   _ڀٽي_, _kò̟_, جوڑ_, _kriū, 
   {{0x6a81413f,0x3f900113,0x0ba80a11,0x25a401f5}},	// [1fec0] алта, _ilyu_, رافى_, kinl_, 
   {{0xca740831,0xaa4000fd,0x00000000,0x00000000}},	//   ыусы, рефл, --, --, 
   {{0xfce400ea,0x1ee801e2,0x00000000,0x00000000}},	//   _јоно, _توکی_, --, --, 
   {{0xabe00075,0x7bc54140,0xb86407d6,0xef1c123d}},	//   _ﺋﺎﻳﺎ, _ukku, _یازو, yküm_, 
   {{0x8ae400c0,0xc8b40150,0x00000000,0x00000000}},	//   _біёл, _ұсты, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7f8400d8,0xe9a04eb1,0xdb0400d8,0x58e000fe}},	//   _hóqu, _тарп, gniç, _প্ৰী, 
   {{0xc32c0aaf,0xafe40162,0xb4b000d1,0x00000000}},	//   كەم_, _mjøð, лиһә, --, 
   {{0x66e00276,0xc64400f7,0xa6c4009b,0x7dd0005c}},	//   _вота, _مئلى, _алта_, væsn, 
   {{0x69c00fb7,0x11d800c6,0xef1c03e0,0x00000000}},	//   čneg, عودة_, rküm_, --, 
   {{0xb62c02dd,0x00000000,0x00000000,0x00000000}},	//   _ﻓﻘ_, --, --, --, 
   {{0x9f48003a,0x02a402dd,0xd00800fb,0xa6b000fe}},	//   _lunæ_, _өрім, меүе_, _জৰিয়, 
   {{0xddc40153,0x7dd001bf,0x00000000,0x00000000}},	//   _griū, ræsn, --, --, 
   {{0xbb6800b5,0x21a01f5a,0xceb80139,0x80d000cf}},	//   _netゲ_, _кичм, _җәм_, _گۅپچ, 
   {{0xe0cc10fe,0x194c001f,0xebc40640,0x6aa80a59}},	//   _وزى_, _አማራጮ, вљан, चप्र, 
   {{0x69c4fbe0,0x9f4800d7,0x00000000,0x00000000}},	//   _skje, _tuná_, --, --, 
   {{0x7d014141,0xc0580150,0x00000000,0x00000000}},	// [1fed0] _şose, _жіө_, --, --, 
   {{0x25a402c4,0xafe40174,0x00000000,0x00000000}},	//   xinl_, _fjøð, --, --, 
   {{0xd7f8376d,0xee3c02f0,0x00000000,0x00000000}},	//   вуч_, ltý_, --, --, 
   {{0x7e602aac,0xdcfc012d,0x00000000,0x00000000}},	//   _šopi, dkrę, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69c4319f,0x845801f4,0x17680352,0xdb042330}},	//   _ukje, ерит_, ерәп_, tniç, 
   {{0x03a4bc3c,0x25a40175,0x7b08008e,0x00000000}},	//   лико, rinl_, _íqtí, --, 
   {{0xdb040724,0x91600241,0xdb0c03b2,0x00000000}},	//   rniç, _pò̟_, ðhøl, --, 
   {{0xab58063f,0x01141f09,0x78a001e4,0xee3c01ef}},	//   _akük, льню, ĝove, jtý_, 
   {{0xd6d80f14,0x7dd00008,0xdd3c0024,0x78a001e4}},	//   _ртс_, gæsl, _sąži, ŝove, 
   {{0x80a4038b,0xa3000220,0x00000000,0x00000000}},	//   امجن, _күйе, --, --, 
   {{0x7c2803cd,0x16100073,0xddc40153,0x00000000}},	//   _åfri, ठीवर_, _triū, --, 
   {{0x3b8401b9,0x707401d5,0x00000000,0x00000000}},	//   қлаг, نمیز_, --, --, 
   {{0xd24c04d3,0xbe8000d1,0x00000000,0x00000000}},	//   _کۆی_, иққи, --, --, 
   {{0x7dd000b5,0x9e9400d1,0x8cb80014,0xd0580064}},	//   sæso, _چاخچ, ندِس_, _арыі_, 
   {{0x3f900113,0x7f840789,0x8b9400fd,0xdb200432}},	//   _ulyu_, _póqu, аруч, _öwüs, 
   {{0x3994019b,0x62985bd9,0xdcfc012d,0x394400c7}},	// [1fee0] _læse_, nzuo, zkrę, лнаг, 
   {{0xd910e7c8,0x0418009e,0x00000000,0x00000000}},	//   تیس_, _ধমনী_, --, --, 
   {{0x8cb43c85,0x399400b5,0xed540a7c,0x23c0521a}},	//   _всяч, _næse_, _גביר_, शवाद, 
   {{0x30d8008f,0x7f840798,0x6c78008f,0xdc3c0010}},	//   ײַבע, _tóqu, _נאכפ, nšče, 
   {{0xca754142,0x4a740137,0x2efc002e,0x00000000}},	//   _куры, _кырт, ñufi_, --, 
   {{0x236c0369,0x6b80084c,0x3ea402d2,0x00000000}},	//   _angj_, _îngr, _þotu_, --, 
   {{0xe3ac021a,0x00000000,0x00000000,0x00000000}},	//   ګرو_, --, --, --, 
   {{0xee3c02fb,0xdcfc002d,0x3208792f,0x00000000}},	//   ytý_, rkrę, нхон_, --, 
   {{0x62201e87,0xe3ac16ac,0x98b800c0,0xd25000db}},	//   مىيل, ثرو_, _karį_, تچا_, 
   {{0xc0bc0092,0x00000000,0x00000000,0x00000000}},	//   _ሰራሽ_, --, --, --, 
   {{0xd0d400d1,0x21614143,0xa5040120,0x62980064}},	//   ронъ, стыг, _сеха_, azuo, 
   {{0x9f3401ec,0x00000000,0x00000000,0x00000000}},	//   беюі, --, --, --, 
   {{0x9df83da1,0x5ec80154,0x6454031c,0x00000000}},	//   лнят_, রেসে, ħxie, --, 
   {{0xee3c01a8,0x98b80153,0xeea8013d,0x00000000}},	//   rtý_, _narį_, _үтик_, --, 
   {{0xee3c02fd,0x272c0790,0xd5b80171,0x00000000}},	//   stý_, nönü_, _mjā_, --, 
   {{0xf1a804d3,0x7c3801c3,0x28d8000d,0x00000000}},	//   _تاڵه_, àtra, _भरबि, --, 
   {{0xd5b80055,0x893800db,0xfe740117,0x00000000}},	// [1fef0] _ojā_, кпас_, _кӯр_, --, 
   {{0x69a80451,0xd5b80171,0x00000000,0x00000000}},	//   راءُ_, _njā_, --, --, 
   {{0x62994144,0xe784034b,0x00000000,0x00000000}},	//   zzuo, лудо, --, --, 
   {{0x4b7800c8,0x9f4800a2,0x37254145,0xd5b90e0c}},	//   _סאָו, _gunä_, لومې, _ajā_, 
   {{0x6fcc01c3,0x00000000,0x00000000,0x00000000}},	//   rùch, --, --, --, 
   {{0x36180d28,0x9f480790,0x899401ee,0x00000000}},	//   ئرنگ_, _tunç_, _тигє, --, 
   {{0x03954146,0x76440014,0xb3440166,0x00000000}},	//   ирия, ُیہِ_, ksçı, --, 
   {{0x672800c6,0x42254147,0x39f00220,0x629801c6}},	//   _яαмσ, адив, _اۋەز, tzuo, 
   {{0x96440323,0xdc3c0010,0x20d001e1,0x41b40117}},	//   _гэхд, všče, _ṣi_, исот, 
   {{0x45d4013d,0xddc400b8,0x079001e1,0x00000000}},	//   _тозс, _triũ, _àìbí_, --, 
   {{0x5f4801c0,0x4430030a,0x7bc803b2,0x00000000}},	//   гүйн_, _êz_, _ífug, --, 
   {{0x6e3c0175,0x44d40051,0x00000000,0x00000000}},	//   _bqqb, _í_, --, --, 
   {{0xdc3c09a8,0x0eb94148,0x00000000,0x00000000}},	//   ršče, гуры_, --, --, 
   {{0xc0e4529e,0x61f94149,0xf2d023e4,0x00000000}},	//   _колк, mqul, _ועד_, --, 
   {{0x61f80a4d,0x7c3c010a,0x7dd001bf,0x00000000}},	//   lqul, _qqpr, læsk, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x61f9414a,0x29040259,0x6e90009b,0x00000000}},	// [1ff00] nqul, ınan_, _мићу, --, 
   {{0xdb04007b,0x00000000,0x00000000,0x00000000}},	//   nniú, --, --, --, 
   {{0x67380010,0x9f40023a,0x44d401e1,0xdb0400ae}},	//   _bcuj, _tiiä_, _ń_, iniú, 
   {{0xf7440138,0xf6280212,0x75380175,0xdb0401e7}},	//   редо, віки_, _sctz, hniú, 
   {{0x7f400789,0x61f8014f,0x1ae403d4,0x44d40208}},	//   _ñoqu, jqul, _ফ্ৰা, _á_, 
   {{0x78040014,0x3448a229,0x7c2d414b,0x066800db}},	//   _نظرٕ, вчин_, orbr, الوۋ_, 
   {{0x2ed0197e,0x00000000,0x00000000,0x00000000}},	//   _सर्त, --, --, --, 
   {{0x7c2d414c,0x61f806be,0x00000000,0x00000000}},	//   irbr, fqul, --, --, 
   {{0x61f8014b,0x8ccc5690,0x87b80408,0x7c2c0112}},	//   gqul, _दुनो, _сурт_, hrbr, 
   {{0x776001f5,0x48a40092,0x764001d5,0x27280241}},	//   ldox, _ጋዜጦች_, mtoy, _tònà_, 
   {{0x7640300e,0x61f80194,0x3948045a,0x00000000}},	//   ltoy, aqul, _mbbs_, --, 
   {{0x3948003e,0xbde000db,0xddc40205,0xad980332}},	//   _lbbs_, üènc, _psiş, mpúi, 
   {{0x7c2d414d,0x6d8803be,0xd01126b1,0xe29401ee}},	//   erbr, _müav, _کلب_, _кац_, 
   {{0x320540d7,0xdb0400c6,0x62000014,0x44d401fb}},	//   _itoy_, cniú, _بووٕ, _ý_, 
   {{0x9d19414e,0xe6d0227c,0xd7b8041c,0xd5a401d3}},	//   рост_, _तर्ज, ेकाच, _ےہ_, 
   {{0x5bb8e1a6,0xd1380153,0x00000000,0x00000000}},	//   ался_, lgą_, --, --, 
   {{0xa90415fa,0x7c2c000f,0x00000000,0x00000000}},	// [1ff10] لبان, arbr, --, --, 
   {{0xd13802d5,0xe8e804d3,0x764000d8,0x00000000}},	//   ngą_, نراو_, dtoy, --, 
   {{0x39480175,0xd1380064,0x00000000,0x00000000}},	//   _dbbs_, igą_, --, --, 
   {{0x32040098,0x33241574,0x6d45414f,0x61f8544b}},	//   _otoy_, _ndox_, lfja, yqul, 
   {{0x39480158,0xda7800a8,0x00000000,0x00000000}},	//   _fbbs_, _кяр_, --, --, 
   {{0x61f8036b,0x7dd008cb,0x28680022,0x78a001e4}},	//   vqul, væsk, _ирбо_, ŝova, 
   {{0x88e40d42,0xe8dc07ae,0xd6d80588,0x320401a9}},	//   _প্রক, _trực_, лтә_, _atoy_, 
   {{0x69a000bc,0x97a400f3,0x1768026b,0x61f801a9}},	//   छोरी, _друл, _круп_, tqul, 
   {{0x957c068f,0x56954150,0x3948002f,0xad980332}},	//   _piąt, _датт, _ybbs_, apúi, 
   {{0xdd00005f,0x91842002,0x6d4401a4,0x61f94151}},	//   ātīg, يۇنۇ, jfja, rqul, 
   {{0x32040139,0x2b1401ad,0x61f94152,0xf99005d0}},	//   _etoy_, तराँ_, squl, פרט_, 
   {{0xd4994153,0xd1380024,0x64414154,0xd6b803d4}},	//   _тру_, agą_, mtni, _জৰিয, 
   {{0x61f80eda,0x4ca4015b,0x6d440327,0x39942507}},	//   qqul, _খুলু, ffja, _læsa_, 
   {{0x237c09a8,0xd0a80f01,0x64402646,0x6d44036e}},	//   ljuj_, اطین_, otni, gfja, 
   {{0x6da14155,0x7dd00194,0xada14156,0x2b480010}},	//   чира, næsi, чарл, _bbcc_, 
   {{0x64400d04,0x237d4157,0x200401a9,0x76400076}},	//   itni, njuj_, _itni_, ytoy, 
   {{0xd1e002d3,0x64414158,0x764006af,0x7d0d4159}},	// [1ff20] _ዓረብ_, htni, xtoy, pbbs, 
   {{0xf2d004ac,0xaef804cc,0x2004022e,0xac14012d}},	//   לען_, ndùn, _ktni_, _żółc, 
   {{0x64409e25,0x237c0ac5,0x611006be,0x00000000}},	//   jtni, kjuj_, lәlә, --, 
   {{0x764020ef,0x998000d0,0x30d8010f,0x00000000}},	//   ttoy, driť_, אַדע, --, 
   {{0xc7644d2d,0x2a68070d,0x6441415a,0xd1380006}},	//   تالى, _grcb_, etni, ygą_, 
   {{0xb9940491,0x6440ef77,0x7641415b,0x2005415c}},	//   _السب, ftni, rtoy, _otni_, 
   {{0x644004ce,0x7641415d,0x3205415e,0x3994032e}},	//   gtni, stoy, _stoy_, _gæsa_, 
   {{0x764000b5,0x6d880254,0x237c0200,0x00000000}},	//   ptoy, _hüat, gjuj_, --, 
   {{0x3e4002ea,0x644401b8,0x2005415f,0x64400802}},	//   _fɔti_, _äjin, _atni_, atni, 
   {{0x6440151c,0xd1380024,0x75d4007b,0x998000d7}},	//   btni, ugą_, _ايطا, briť_, 
   {{0x644001f5,0xe978008f,0xd1386dd3,0x00000000}},	//   ctni, אניש, rgą_, --, 
   {{0x3ae000b0,0xa0a00121,0x237c0210,0x00000000}},	//   _kōpī_, яшыл, cjuj_, --, 
   {{0xeabc0248,0x20054160,0x32041c06,0x82940066}},	//   _adùn_, _etni_, _utoy_, _وهمچ, 
   {{0xd0103adf,0x1df8d5de,0xd1ec0023,0x00000000}},	//   _قلت_, серы_, ቀምቲ_, --, 
   {{0x6d440008,0xd250004b,0x2b480100,0xa9c0009e}},	//   rfja, _رنګ_, _pbcc_, ্গমঞ, 
   {{0x399402d2,0x00000000,0x00000000,0x00000000}},	//   _ræsa_, --, --, --, 
   {{0x9e2400db,0x00000000,0x00000000,0x00000000}},	// [1ff30] _فىيو, --, --, --, 
   {{0x8c8800c7,0x00000000,0x00000000,0x00000000}},	//   _кәба_, --, --, --, 
   {{0x88581d0f,0xc6f80354,0x6440ada3,0x00000000}},	//   риес_, анех_, xtni, --, 
   {{0x9be4063b,0x195801ec,0x6440022e,0x00000000}},	//   _ніяк, _қасы_, vtni, --, 
   {{0xbb3800c8,0xa50400d1,0x00000000,0x00000000}},	//   _דערי, مىشە_, --, --, 
   {{0x64414161,0x99800030,0x00000000,0x00000000}},	//   ttni, triť_, --, --, 
   {{0x04454162,0x00000000,0x00000000,0x00000000}},	//   цейн, --, --, --, 
   {{0xab5800e4,0x02054163,0x64414164,0x7d18b2fe}},	//   _iküs, озин, rtni, ótsz, 
   {{0x200401a9,0x42540212,0xef1c002b,0x00000000}},	//   _stni_, ітит, daü_, --, 
   {{0x0594d653,0x6d8803be,0x41a802a9,0x644001a6}},	//   _بارگ, _müas, рвон_, ptni, 
   {{0xadf0033f,0x644001d5,0xf07400e5,0x00000000}},	//   _इंजन_, qtni, قیوں_, --, 
   {{0x442401c7,0x3ce40115,0xfe4511a0,0xbe6801c6}},	//   _ivl_, _ŝovo_, онмо, аамж_, 
   {{0x3ae00374,0x63a8010a,0xee34d646,0x00000000}},	//   _kōpū_, _imgn, оня_, --, 
   {{0x6d400205,0x00000000,0x00000000,0x00000000}},	//   _önal, --, --, --, 
   {{0x90e405a9,0xff0836b1,0x00000000,0x00000000}},	//   _ىسىن, _кейк_, --, --, 
   {{0xeb9403f6,0x7f744130,0xef1c00b8,0x00000000}},	//   оис_, _фукц, caü_, --, 
   {{0x442400da,0xaa414165,0x69c00030,0xab580205}},	// [1ff40] _lvl_, метл, čnen, _aküs, 
   {{0x3f80098d,0x276807d6,0x6d88067c,0x00000000}},	//   ljku_, یشنی_, _qüat, --, 
   {{0xfce448bd,0x44244cdf,0x20cc04e4,0x00000000}},	//   _фоно, _nvl_, _सुमध, --, 
   {{0x3f8016a3,0x012c0b82,0xdb240327,0xe7341422}},	//   njku_, _ተጠቀም, _འཇིཌ_, жец_, 
   {{0xe1e40d62,0xa6100212,0x00000000,0x00000000}},	//   _ٲس_, дміч, --, --, 
   {{0x7bd54166,0x079001e1,0xef1c03b9,0x00000000}},	//   llyu, _àìní_, nkür_, --, 
   {{0xe0c4006c,0x00000000,0x00000000,0x00000000}},	//   _آز_, --, --, --, 
   {{0xe7354167,0x8c480724,0xa5200139,0x00000000}},	//   _мес_, leşü, пмәд, --, 
   {{0xef1c4ba9,0xd2500502,0x3a30045f,0x442401f4}},	//   kkür_, رند_, nryp_, _evl_, 
   {{0xf044040e,0x442403cd,0x29cc180f,0xd5a4028e}},	//   оэмо, _fvl_, qüat_, _علای, 
   {{0xc44401d5,0x7bd4022e,0x00000000,0x00000000}},	//   _فیون_, klyu, --, --, 
   {{0x03c40046,0xefb802d3,0x92d800cc,0x00000000}},	//   _есім, _ሰማዒ_, _ালী_, --, 
   {{0x442402f0,0x6260011c,0x00000000,0x00000000}},	//   _zvl_, _овца, --, --, 
   {{0x012c0023,0x00000000,0x00000000,0x00000000}},	//   _ተጠቂም, --, --, --, 
   {{0x9b0802e3,0x442404cc,0x63a80042,0xd250009f}},	//   _ọhịa_, _xvl_, _ymgn, _آنڪ_, 
   {{0xf1a803e6,0x3aec00c7,0x48e0000d,0x00000000}},	//   _حاڵه_, _ẽpa_, _करबो_, --, 
   {{0x3a3070da,0x38740092,0xef1c0205,0x00000000}},	// [1ff50] gryp_, _የሚረዱ_, sküs_, --, 
   {{0xddc40171,0x00000000,0x00000000,0x00000000}},	//   _apiņ, --, --, --, 
   {{0x3ae00325,0x00000000,0x00000000,0x00000000}},	//   _rōpū_, --, --, --, 
   {{0x44240254,0xddc40064,0x00000000,0x00000000}},	//   _rvl_, _iriš, --, --, 
   {{0xddc506ae,0x44240334,0x68f82ba3,0x45d403c5}},	//   _hriš, _svl_, _şudu, подс, 
   {{0xd5e80720,0x07a40014,0xf9f8011a,0x5ec800eb}},	//   يعون_, _کمرُ, _להשמ, রেকে, 
   {{0x58d54168,0x9f4801bf,0x00000000,0x00000000}},	//   _жорт, _tunø_, --, --, 
   {{0x9f40026c,0x7dd095aa,0x175407d8,0xaa780432}},	//   _ghiè_, læst, _овся, _ezýe, 
   {{0x461404d3,0x3ae00374,0x3e714169,0x00000000}},	//   _روار, _tōpū_, _môtô_, --, 
   {{0x44241509,0x98480014,0xddc40010,0x7dd0366f}},	//   _tvl_, _دلہٕ_, _oriš, næst, 
   {{0x3f69416a,0x98782630,0x442403b2,0x31207a6f}},	//   бино_, ršća_, _uvl_, эдэг, 
   {{0x3a300209,0x64480030,0xad980419,0x00000000}},	//   yryp_, ľnič, zpút, --, 
   {{0x644846aa,0x63b9416b,0x7ff5416c,0x00000000}},	//   žnič, mnun, _کستا, --, 
   {{0x80ac01bc,0x2d800240,0x63b8950c,0x00000000}},	//   ुपदे, gjje_, lnun, --, 
   {{0x7bd4022e,0x90e400cf,0xdb0400a2,0xe2c400f1}},	//   tlyu, _ۉسۉن, aniý, _اوږو_, 
   {{0x6d88067c,0xcfa8004b,0x3a30002d,0x50b80214}},	//   _qüar, _وايم_, tryp_, _بدهد_, 
   {{0x63b9416d,0x7dd000b5,0x799c03cb,0x00000000}},	// [1ff60] inun, fæst, thpw, --, 
   {{0x63b9416e,0xddc42230,0x7dd000b5,0xfce4023b}},	//   hnun, _friš, gæst, _нопо, 
   {{0x63b9416f,0xacf80375,0xddc44e96,0x00000000}},	//   knun, _להיכ, _griš, --, 
   {{0x63b8038f,0x7d1c0365,0xad98682a,0xdb0400e5}},	//   jnun, _heps, spút, nniü, 
   {{0x63b94170,0x7d1c7c46,0x9f400129,0x00000000}},	//   dnun, _keps, _chié_, --, 
   {{0x7dd004ce,0x63b94171,0x7d1c005c,0xa68001c6}},	//   mæss, enun, _jeps, элчд, 
   {{0x63b94172,0x39580099,0x7dd0005c,0xb7d801e2}},	//   fnun, meps_, læss, _هوسا_, 
   {{0xc32cf2e7,0x48e00574,0x7d1c7730,0x39580a73}},	//   لەم_, _करतो_, _leps, leps_, 
   {{0xdcfc00da,0x61e0030d,0x91c53298,0x7d1c017a}},	//   nkrē, _bhnl, мәкл, _oeps, 
   {{0x63b94173,0x7d1d4174,0xfdc4012d,0x00000000}},	//   anun, _neps, लकोफ, --, 
   {{0x8f3520f2,0xf8bc0f4c,0x63b80254,0x216400d8}},	//   менц, ्थिय, bnun, чиќи_, 
   {{0xceb800c7,0x63b94175,0x00000000,0x00000000}},	//   жәо_, cnun, --, --, 
   {{0x7d1d4176,0x39580064,0x74d40116,0x00000000}},	//   _beps, keps_, _ﯞﯨﻼﻳ, --, 
   {{0xddc4ca39,0x7d1d03fa,0xf8bc0782,0x61e000a3}},	//   _priš, _ceps, ्थाय, _ghnl, 
   {{0xfe6c0066,0x00000000,0x00000000,0x00000000}},	//   هگی_, --, --, --, 
   {{0xaca001f2,0x69c00dfe,0xddc405ce,0x7d1c127b}},	//   _haịd, čnem, _vriš, _eeps, 
   {{0xc6100154,0x2d0401c6,0x00000000,0x00000000}},	// [1ff70] _হয়না_, _нянг, --, --, 
   {{0x39580354,0xad980077,0x290407c5,0x7d1c1b99}},	//   geps_, rpús, ùna_, _geps, 
   {{0x4af94177,0x63b8bd89,0x7dd09574,0x22a00241}},	//   _меню_, ynun, ræst, _kèké_, 
   {{0xdee8044e,0x7d1c033f,0x66e001e1,0x67e000c7}},	//   _ሙሉእ_, _zeps, _nìkí, kõje, 
   {{0x63b80579,0x7d1c014b,0x6f1c0455,0x09c401ec}},	//   vnun, _yeps, _meqc, _قۇرۋ_, 
   {{0x39580d63,0x00000000,0x00000000,0x00000000}},	//   ceps_, --, --, --, 
   {{0x66e00241,0x00000000,0x00000000,0x00000000}},	//   _bìkí, --, --, --, 
   {{0x7c3800cf,0x63b84627,0x42080114,0x5ec80154}},	//   àtri, unun, онио_, রেটে, 
   {{0x45d40276,0x00000000,0x00000000,0x00000000}},	//   _жоас, --, --, --, 
   {{0x66194178,0x63b94179,0x741000cf,0x00000000}},	//   _iwuk, snun, روۋا, --, 
   {{0x66180810,0x6f1c014f,0x399403cd,0x00000000}},	//   _hwuk, _beqc, _bæsj_, --, 
   {{0x7d1c069c,0x661802e3,0x97140521,0xdde400b5}},	//   _seps, _kwuk, _ọṅụṅ, t版os_, 
   {{0x69c0994e,0x22a001e1,0xdb040034,0x399403cd}},	//   čnej, _dèké_, znió, _dæsj_, 
   {{0xe9fc01dc,0x66180230,0xfce5417a,0x00000000}},	//   _hoặc_, _mwuk, дого, --, 
   {{0x225c0066,0x395805ac,0x00000000,0x00000000}},	//   lwuk_, veps_, --, --, 
   {{0x6619417b,0x7d1d417c,0xebe08148,0x00000000}},	//   _owuk, _weps, восп, --, 
   {{0x6d4c09f3,0x4f6400db,0x3dc401b9,0x3958045a}},	// [1ff80] únað, _سايف, _ойиг, teps_, 
   {{0x7dd001bf,0x00000000,0x00000000,0x00000000}},	//   ræss, --, --, --, 
   {{0x776406bb,0x39580354,0x66182935,0xe80400d0}},	//   дълж, reps_, _awuk, _púšť, 
   {{0x661800ca,0x39580072,0x00000000,0x00000000}},	//   _bwuk, seps_, --, --, 
   {{0x35a40c60,0x66e00241,0x00000000,0x00000000}},	//   мадг, _rìkí, --, --, 
   {{0x6618033f,0xb4b07853,0x61c42429,0xe3ac00f1}},	//   _dwuk, килә, रकोष, یري_, 
   {{0x6618379d,0xe3ac05d9,0xad9800c7,0x00000000}},	//   _ewuk, ڌري_, ipúp, --, 
   {{0x281400e5,0x00000000,0x00000000,0x00000000}},	//   _آہنگ_, --, --, --, 
   {{0x27300150,0x754402e8,0x622015bf,0x051c05ac}},	//   _جىقس, _оназ, نىيل, _নাৰৰ_, 
   {{0x3cf80456,0x67e000e4,0x48e40118,0x00000000}},	//   ्डों_, rõje, झेको_, --, 
   {{0x6f1c0477,0xa44001c0,0xb0c4023a,0x21600137}},	//   _peqc, _анхд, ьщик, ттыг, 
   {{0x6f1c014f,0x5ec80154,0xe3f40c75,0x43e800ec}},	//   _qeqc, রেছে, _قىلت_, _فرنٽ_, 
   {{0xdef9417d,0x16dc0da8,0xf1a810c4,0x00000000}},	//   дыр_, _बरोब, _واته_, --, 
   {{0x051c00cc,0x00000000,0x00000000,0x00000000}},	//   _নাৱৰ_, --, --, --, 
   {{0x72a00131,0xd1b001d5,0x00000000,0x00000000}},	//   _سەھن, _لیکک, --, --, 
   {{0x7bc8032e,0xb5d00150,0x80ac00bc,0x00000000}},	//   _íful, _ﺘﻬﻴﺌ, ुपरे, --, 
   {{0xad100116,0x8af80213,0xb7c40356,0x497436da}},	// [1ff90] _иппә, nfəə, inţă, нлас, 
   {{0x6618d00b,0x195814d4,0x00000000,0x00000000}},	//   _rwuk, мауы_, --, --, 
   {{0x4735417e,0x00000000,0x00000000,0x00000000}},	//   енес, --, --, --, 
   {{0xd7c92914,0x9af404da,0x4ee0009e,0xab60030c}},	//   ووله_, ركەت, ণশীল, _جۇرى, 
   {{0x4ca400cc,0x00000000,0x00000000,0x00000000}},	//   _খুচু, --, --, --, 
   {{0x3ce40115,0x00000000,0x00000000,0x00000000}},	//   _ŝovi_, --, --, --, 
   {{0x5634044e,0xddc4002b,0xeb9c1600,0xdc3c07f5}},	//   _ኣይክእ, _apiś, _klø_, ršće, 
   {{0x61c40cf1,0x00000000,0x00000000,0x00000000}},	//   रक्ष, --, --, --, 
   {{0x6619417f,0xaa78010e,0x00000000,0x00000000}},	//   _uwuk, _yzýa, --, --, 
   {{0x20300020,0x0084004e,0xd67801c8,0x33f400db}},	//   _በተለይ, елоо, _تحفا_, мчөс, 
   {{0xe0cc0183,0x06d00154,0x69c000d7,0x00000000}},	//   ৰশ্ন, ়েশি, čneh, --, 
   {{0x3f684c04,0x00000000,0x00000000,0x00000000}},	//   чимо_, --, --, --, 
   {{0xdb040407,0x8f8002dd,0x7e7400db,0x00000000}},	//   xniñ, рқыл, راحئ, --, 
   {{0xede40032,0x012c0023,0x8c480166,0x614019c5}},	//   нһыҙ_, _ተጠቒም, _oeşı, _شىبە, 
   {{0x16dc1df1,0xeb9c33b8,0xbad80150,0x3cf80118}},	//   _बर्ब, _blø_, _ﺃﻭﺘﺎ, ्डौं_, 
   {{0x399400b5,0xaa7800a2,0xfce40107,0xe898013d}},	//   _tæsk_, _szýa, доҳо, _şağı, 
   {{0xee340124,0x00000000,0x00000000,0x00000000}},	// [1ffa0] _зны_, --, --, --, 
   {{0xe9d54180,0xdb04056a,0xd910b24a,0xada0b6d4}},	//   еку_, rniñ, شیر_, _баьл, 
   {{0xeb9c0158,0x9f400165,0xc70c010e,0x00000000}},	//   _flø_, _hiiñ_, _ỳaỳr, --, 
   {{0x36c4944f,0xaef801ab,0x24680023,0x00000000}},	//   нбег, reùg, _ዶላራት_, --, 
   {{0x9f400de2,0xf60801d5,0xeb954181,0x3994032e}},	//   _jiiñ_, ستشه_, _чия_, _læsi_, 
   {{0xa7a40022,0xe734009d,0x00000000,0x00000000}},	//   _ҧкра_, _үер_, --, --, 
   {{0x9f4000e8,0xddc40064,0x00000000,0x00000000}},	//   _liiñ_, _asiū, --, --, 
   {{0xdef802d3,0x93bc0083,0xa6800166,0x00000000}},	//   ፋሉን_, _mwăg, тләд, --, 
   {{0x798c0085,0x00000000,0x00000000,0x00000000}},	//   _kobw, --, --, --, 
   {{0x798c002f,0xaef80022,0x00000000,0x00000000}},	//   _jobw, ndùv, --, --, 
   {{0x798d4182,0x0044004b,0xc0cc0023,0x00000000}},	//   _mobw, نیوي_, _ኣኸለ_, --, 
   {{0x9f400de2,0x69c8019f,0x9f480ffb,0x798d2f68}},	//   _biiñ_, îgez, _sunò_, _lobw, 
   {{0x9f48026c,0x00000000,0x00000000,0x00000000}},	//   _punò_, --, --, --, 
   {{0x99800006,0x798d4183,0x71640150,0x00000000}},	//   irių_, _nobw, _ساتك, --, 
   {{0x21640640,0x6140009b,0x00000000,0x00000000}},	//   _чији_, _сеја, --, --, 
   {{0x9500025c,0x957c0210,0x00000000,0x00000000}},	//   _ཝུའི_, _ciąz, --, --, 
   {{0x798c0083,0xda354184,0x99800327,0x48dc00cc}},	// [1ffb0] _bobw, леты, briż_, _বলেৰ, 
   {{0xa3e40c66,0x798c0076,0xddc400d0,0x2d8400c7}},	//   _मीन_, _cobw, _priť, _õne_, 
   {{0x99d40058,0x798c0428,0x2ca428b3,0x99800064}},	//   اتقا, _dobw, _ånd_, erių_, 
   {{0x798c08e7,0x3b1c0208,0xa80000cf,0x00000000}},	//   _eobw, _đtqg_, _ۅكسۉ, --, 
   {{0x6b8c03ac,0x1a940153,0x00000000,0x00000000}},	//   _iocg, _баяў, --, --, 
   {{0x69f0008e,0x00000000,0x00000000,0x00000000}},	//   _сүзт, --, --, --, 
   {{0x03a40334,0x689000e5,0xd8380108,0x00000000}},	//   кико, _حیائ, _пэт_, --, 
   {{0x58d4a396,0x798c02ce,0x399402d2,0x38b800e4}},	//   _сост, _zobw, _ræsi_, sýrô_, 
   {{0xb3814185,0x798d4186,0x00000000,0x00000000}},	//   рлыл, _yobw, --, --, 
   {{0xe4a440cd,0x6b8c0076,0x00000000,0x00000000}},	//   _прео, _locg, --, --, 
   {{0xe7b004c5,0x23a0030a,0x9f40002e,0xc444035b}},	//   টকীয, _añje_, _siiñ_, _шьақ, 
   {{0x90340124,0x00000000,0x00000000,0x00000000}},	//   ыхьч, --, --, --, 
   {{0x0164014b,0x53380354,0x48dc00cc,0x00000000}},	//   _акло, _чухă, _বলোৰ, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4a740046,0x798c00ca,0xd1d4001f,0x3d240014}},	//   қытт, _robw, ረኮች_, ى۪کی_, 
   {{0xd24c04d3,0x798c007f,0x99800024,0x5ca410e0}},	//   _بۆی_, _sobw, yrių_, _ەلدە, 
   {{0xe8700020,0x798c0bd7,0x00000000,0x00000000}},	// [1ffc0] _የሚገኝ_, _pobw, --, --, 
   {{0x957c033f,0x3ce401e4,0x00000000,0x00000000}},	//   _wiąz, _ŝovu_, --, --, 
   {{0xc9554187,0xfbc46d98,0x46800150,0x00000000}},	//   ытты, _абно, ұқта, --, 
   {{0x798c02ce,0x7e740839,0x27301884,0x00000000}},	//   _wobw, _kryp, لىمس, --, 
   {{0x6cd00b43,0x2904029f,0x798d4188,0x4a7401e0}},	//   _مقیا, ınar_, _tobw, _йырт, 
   {{0x35b40801,0xe530005b,0x89f40064,0x00000000}},	//   ъщес, аешь, _бясц, --, 
   {{0x563402d3,0x67e00037,0xe3ac0451,0xa8200214}},	//   _ኣይኽእ, sõja, ڪرو_, _نکنن, 
   {{0x68e14189,0x3209418a,0x2ca475d4,0xe5740139}},	//   ünde, мхон_, _ünde_, езә_, 
   {{0xe3ac00b2,0xdb040208,0x69c00010,0x00000000}},	//   ترو_, thiê, čnev, --, 
   {{0xa3e434f8,0xb4f000cf,0x00000000,0x00000000}},	//   _मीठ_, _күлч, --, --, 
   {{0x7e75418b,0x25d40375,0xe28c01d3,0x00000000}},	//   _aryp, _יומן_, مذی_, --, 
   {{0x7c2803cd,0xdb040254,0x00000000,0x00000000}},	//   _åfry, oniõ, --, --, 
   {{0x9258010b,0xdb040254,0x31c400f3,0x00000000}},	//   _чалт_, nniõ, _искв, --, 
   {{0x7bc5418c,0xdb05418d,0x00000000,0x00000000}},	//   _ajku, lhiè, --, --, 
   {{0x1df9418e,0x2065418f,0xdb0401f5,0x5c04974c}},	//   теры_, _ашып_, chië, ията, 
   {{0x9f400ffb,0x9b594190,0xdb040ba1,0x7e740153}},	//   _ghià_, кист_, nhiè, _fryp, 
   {{0x7bc40810,0x5b2401c0,0x7e754191,0x49300023}},	// [1ffd0] _djku, рьса, _gryp, _ኣምልኾ, 
   {{0x20500184,0x7ae800f1,0x00000000,0x00000000}},	//   _стәр, رولې_, --, --, 
   {{0x4c954192,0x00000000,0x00000000,0x00000000}},	//   _синс, --, --, --, 
   {{0x070806f6,0x7e7400c7,0xc48401d5,0xd1e80092}},	//   ريتي_, _yryp, ғлик, _ዘገበ_, 
   {{0x9a84f880,0xe9440c60,0x76440014,0x00000000}},	//   _курл, _ихво, ێیہِ_, --, 
   {{0x69c801ed,0x00000000,0x00000000,0x00000000}},	//   éged, --, --, --, 
   {{0x69c4208d,0x7ae8002d,0xe4a45cfa,0xdb0401f4}},	//   _ijje, ęfte, ърдо, rniö, 
   {{0x9f44006a,0xdc6c0023,0x20300092,0x82180120}},	//   ömü_, _ትግባረ_, _በሰማይ, нцот_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x972401ed,0x7e740200,0x00000000,0x00000000}},	//   _مفہو, _rryp, --, --, 
   {{0xb3a00184,0xe3c40032,0x8414a401,0x00000000}},	//   рлөһ, _иҫке_, _смех, --, 
   {{0xdb94069c,0x6d554193,0xdb041497,0xaa7800a2}},	//   _ዘለዎም_, _abxa, chiè, _gyýg, 
   {{0x69c40337,0x2bc49f23,0x52742a77,0x38740092}},	//   _ojje, रचना, _پانز, _የሚሄዱ_, 
   {{0xa3e400af,0x7e740ea0,0xc0e54194,0x00000000}},	//   _मीत_, _vryp, _йолк, --, 
   {{0x6a800220,0x7d002b93,0x8c9400d4,0x00000000}},	//   ұлта, _şoss, арті, --, 
   {{0x39954195,0x69c40a55,0x6d880213,0xf41008a8}},	//   _læst_, _ajje, _müay, מפל_, 
   {{0x4e1c068f,0x39e80063,0x70840023,0x00000000}},	// [1ffe0] बीआई_, едао_, _ንመሰሉ_, --, 
   {{0x3f914196,0x399409f3,0xdee40131,0xae1800df}},	//   _hoyu_, _næst_, _йоқи, _רויכ, 
   {{0xd1e80020,0x3f9005d1,0x3198010f,0x7c3800d7}},	//   _ዘገባ_, _koyu_, עבענ, štrb, 
   {{0x7bc54197,0x69c54198,0x3f900de2,0x7c2d4199}},	//   _ujku, _ejje, _joyu_, msbr, 
   {{0x3f90002e,0x7bd5419a,0x3995419b,0x00000000}},	//   _moyu_, moyu, _bæst_, --, 
   {{0x3dc4045e,0x74680fbe,0x91600241,0x7bd40790}},	//   _শীতল, ерив_, _mọ̀_, loyu, 
   {{0x18b40022,0xab580205,0x66e021f3,0xaef800e4}},	//   _тәар, _aküy, _ҳота, ndùr, 
   {{0x684009a5,0xa3e400af,0xb9dc1772,0x7bd5419c}},	//   _ынса, _मीद_, _ኤሪ_, noyu, 
   {{0xf1247724,0x399408a7,0xaa7800a2,0x66e00024}},	//   льно, _fæst_, _gyýd, _гота, 
   {{0x3994037e,0x7c2d419d,0x764005d1,0x39480ea0}},	//   _gæst_, ksbr, muoy, _jcbs_, 
   {{0x3f904a4a,0x7c2c5d2e,0x7bd4891b,0x41840961}},	//   _boyu_, jsbr, koyu, ртығ, 
   {{0x7c2c019b,0x289808a8,0x77600077,0x9f400051}},	//   dsbr, גיטא, neox, _phiá_, 
   {{0x3f90002e,0xef1c01ed,0xdb0400e4,0xeabc0154}},	//   _doyu_, ljük_, chié, _আর্ম, 
   {{0xfe740364,0x660c0036,0x7c2ce6e0,0x00000000}},	//   рӯъ_, _écke, fsbr, --, 
   {{0xd010211f,0xef1c00e5,0xa06400f3,0x00000000}},	//   _بلب_, njük_, _баја_, --, 
   {{0x7bd4011f,0x40240116,0xa4b4011a,0xd1e80092}},	//   goyu, _өзәң, אללה_, _ዘለቀ_, 
   {{0x7761419e,0x394801ee,0x99640daf,0x4ea40220}},	// [1fff0] deox, _bcbs_, әтул, _әрқа, 
   {{0x5f74030c,0x7c2c01bf,0x28a401ec,0x00000000}},	//   _ناۋر, bsbr, лшег, --, 
   {{0x3f9000e8,0x39942507,0x7bd401e1,0x00000000}},	//   _yoyu_, _ræst_, boyu, --, 
   {{0x2d91419f,0x6d4541a0,0x3994022c,0x316c022e}},	//   _hoxe_, lgja, _sæst_, _lafz_, 
   {{0x394801b8,0x752801f5,0xb7840139,0x00000000}},	//   _fcbs_, fafz, шәре_, --, 
   {{0x2d9141a1,0x070805d9,0xd61800c6,0x27200051}},	//   _joxe_, ريڪي_, اتنا_, ằn_, 
   {{0xd6d815cf,0x2d900109,0x69d4056a,0xaa7800a2}},	//   ктә_, _moxe_, moxe, _dyýe, 
   {{0x69d541a2,0x320414e0,0x42540aa8,0xf8b0011a}},	//   loxe, _buoy_, атот, _ושל_, 
   {{0x672941a3,0x3f9003a2,0x9f84495b,0x016402e8}},	//   magj, _royu_, lıç_, акпо, 
   {{0x672941a4,0x7c2c026c,0x2d900356,0x3f902ca8}},	//   lagj, ysbr, _noxe_, _soyu_, 
   {{0x65610267,0x27fc04ac,0xc0e41871,0x9f840724}},	//   menh, _kiun_, ронк, nıç_, 
   {{0x656141a5,0x27fc003e,0x7c2cbc1c,0x69d40117}},	//   lenh, _jiun_, vsbr, hoxe, 
   {{0x644141a6,0x63b941a7,0x7c2c01a4,0x69d401c4}},	//   luni, miun, wsbr, koxe, 
   {{0x6d4541a8,0x7c2d41a9,0x63b941aa,0x27fc07c5}},	//   ggja, tsbr, liun, _liun_, 
   {{0x69d49d2b,0x6440d2ba,0x2d901bce,0x672941ab}},	//   doxe, nuni, _doxe_, kagj, 
   {{0x63b941ac,0x200404c9,0x65601196,0x644001ab}},	//   niun, _iuni_, henh, iuni, 
  
   {{0x644141ad,0x7bd4d136,0x7c2d41ae,0x656141af}},	// [20000] huni, royu, ssbr, kenh, 
   {{0x64405b36,0x200541b0,0x63b941b1,0x27fc067c}},	//   kuni, _kuni_, hiun, _aiun_, 
   {{0xddc541b2,0x21252a45,0x63b941b3,0x786409a5}},	//   _križ, _menh_, kiun, ркез, 
   {{0x200541b4,0x644141b5,0x63b805d9,0x394802fa}},	//   _muni_, duni, jiun, _wcbs_, 
   {{0x200541b6,0x63b941b7,0x2d900564,0x65600112}},	//   _luni_, diun, _yoxe_, fenh, 
   {{0x644141b8,0x2004092e,0x2d9141b9,0xef1c00dd}},	//   funi, _ouni_, _xoxe_, tjük_, 
   {{0x63b941ba,0x644141bb,0x200541bc,0x67280438}},	//   fiun, guni, _nuni_, bagj, 
   {{0x63b941bd,0x27fd41be,0xef1c00dd,0x752801f7}},	//   giun, _giun_, rjük_, safz, 
   {{0x65605268,0x200402a8,0x212401fb,0x76400113}},	//   benh, _auni_, _benh_, quoy, 
   {{0x200541bf,0x27fc07c5,0xf0380092,0x00000000}},	//   _buni_, _ziun_, _በተለም, --, 
   {{0x644141c0,0x63b941c1,0x2d9002b9,0x200541c2}},	//   cuni, biun, _roxe_, _cuni_, 
   {{0x63b941c3,0x200541c4,0x6fb000db,0x00000000}},	//   ciun, _duni_, تۅبا, --, 
   {{0x200401c7,0x6d4541c5,0x00000000,0x00000000}},	//   _euni_, tgja, --, --, 
   {{0x200541c6,0x69d42798,0x67280023,0x1aec00cc}},	//   _funi_, xoxe, zagj, কশাই_, 
   {{0x6d4541c7,0xddc40989,0x2d900564,0x200541c8}},	//   rgja, _friž, _voxe_, _guni_, 
   {{0x656141c9,0x2d900564,0x6d440436,0x6e2c01e2}},	//   zenh, _woxe_, sgja, pscb, 
   {{0x644141ca,0x69d4056a,0x2d9002c4,0x2124016b}},	// [20010] zuni, toxe, _toxe_, _yenh_, 
   {{0x63b941cb,0x644141cc,0x200541cd,0x27fc01ab}},	//   ziun, yuni, _yuni_, _siun_, 
   {{0x69d463ce,0x656141ce,0x27fc04cc,0x6728659a}},	//   roxe, venh, _piun_, tagj, 
   {{0x644141cf,0x63b941d0,0xd5b80055,0x5edc02c3}},	//   vuni, xiun, _amā_, _गुड्_, 
   {{0x65601cea,0x63b8bca1,0xd7740137,0x672941d1}},	//   tenh, viun, تالع, ragj, 
   {{0x26dc0451,0x67280023,0x629801f7,0x656032e9}},	//   _vyuo_, sagj, vyuo, uenh, 
   {{0x63b941d2,0x656141d3,0x27fc04ac,0x644141d4}},	//   tiun, renh, _tiun_, uuni, 
   {{0x656141d5,0x644141d6,0xd5b941d7,0xee3c0306}},	//   senh, runi, _emā_, krý_, 
   {{0x644141d8,0x212541d9,0x63b941da,0x00000000}},	//   suni, _penh_, riun, --, 
   {{0x63b941db,0x200541dc,0xee3c0232,0x12c40131}},	//   siun, _puni_, drý_, تتىپ, 
   {{0x63b941dd,0xddc541de,0x200416a6,0x644141df}},	//   piun, _priž, _quni_, quni, 
   {{0x200423e0,0x63b80194,0x4424ddf6,0x03e400cc}},	//   _vuni_, qiun, _iwl_, _পূৰণ, 
   {{0x442401bf,0x200541e0,0x00000000,0x00000000}},	//   _hwl_, _wuni_, --, --, 
   {{0x200541e1,0x723401d9,0x6da40184,0xb274008f}},	//   _tuni_, _آور_, йҙың_, _לענג_, 
   {{0x200541e2,0xfce42e82,0xdbc8016c,0xdf04010b}},	//   _uuni_, сово, иҳод_, _мүнй, 
   {{0xee3c03c6,0x4424c87f,0x7b9804fb,0x00000000}},	//   brý_, _mwl_, دپرس_, --, 
   {{0xddc40003,0x4424002f,0x68e0002f,0xef140108}},	// [20020] _kriż, _lwl_, ündn, _умы_, 
   {{0x44248173,0x0ae8007b,0x00000000,0x00000000}},	//   _owl_, شرقي_, --, --, 
   {{0x442402c4,0x49000145,0x69c80129,0xb4d40073}},	//   _nwl_, дүрг, égea, _सडे_, 
   {{0xbb840491,0xa3e41533,0xf74541e3,0x06d000bd}},	//   _الحي, _मील_, седо, ়েছি, 
   {{0x163541e4,0x93bc0083,0x44246035,0xddc40327}},	//   целя, _bwăn, _awl_, _oriż, 
   {{0x44246688,0x344805f5,0x00000000,0x00000000}},	//   _bwl_, гчин_, --, --, 
   {{0xb89400c6,0x44240042,0xa9a0010b,0x00000000}},	//   _الزع, _cwl_, _эирд, --, 
   {{0x5214a29d,0x53980801,0xddc40327,0x44240042}},	//   одит, рвия_, _ariż, _dwl_, 
   {{0xb6a40022,0xaa78010b,0x69040332,0x360402cb}},	//   _уиал, _kyýa, _árdá, _طواف, 
   {{0xd1f0001f,0x442400ae,0x91b80798,0x31680114}},	//   _ቃሊቲ_, _fwl_, ргот_, ушио_, 
   {{0x98b82258,0xd01000c6,0x1bf82980,0x00000000}},	//   _karı_, بلج_, ंगाल_, --, 
   {{0xd0080032,0xee3c02fb,0x15b800fb,0x00000000}},	//   леүе_, trý_, _сығы_, --, 
   {{0xeabc01ab,0xddc4025c,0xb7c4054e,0x12940120}},	//   _ceùl_, _friż, miţă, _филџ, 
   {{0xaa780209,0xddc40135,0x98b87975,0x1708031c}},	//   _nyýa, _griż, _ları_, _ཆུའམ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x09d00073,0xe7d40150,0xf1a802f2,0x00000000}},	//   तक्य, _ﺘﻌﺎﻟ, _جاڵه_, --, 
   {{0x3f9c013f,0xddd406be,0xa90400ae,0x37bc00eb}},	// [20030] ɔtu_, _çaşb, مبان, ইকার, 
   {{0x5a342d30,0xaa7802fb,0x7c4403b2,0x9a2400e5}},	//   янут, _ozýv, ðurø, سٹمن, 
   {{0x98b80598,0x482400d1,0x00000000,0x00000000}},	//   _barı_, زىشق, --, --, 
   {{0xe00835e8,0xefb80023,0x940c03b9,0x00000000}},	//   _संसद_, _ደማዊ_, _ölər_, --, 
   {{0x442541e5,0x98b8294f,0x5a44010b,0x96b800db}},	//   _swl_, _darı_, _нэра, йушу_, 
   {{0x44147136,0xaa780432,0x44240042,0x9f60452d}},	//   офит, _gyýa, _pwl_, _ösön_, 
   {{0xddc40135,0xb63c0023,0x98b803e0,0xe68400d1}},	//   _rriż, _ኣይክህ, _farı_, _گۆشى_, 
   {{0xd054016b,0x57a413b1,0xaa780209,0x44240112}},	//   _ɔbɔa, _ешуа, _zyýa, _vwl_, 
   {{0xddc4025c,0x569401af,0x00000000,0x00000000}},	//   _priż, _еатт, --, --, 
   {{0x98b80e2d,0x00000000,0x00000000,0x00000000}},	//   _zarı_, --, --, --, 
   {{0x98b871e1,0x00000000,0x00000000,0x00000000}},	//   _yarı_, --, --, --, 
   {{0x98b806be,0x12c400db,0x00000000,0x00000000}},	//   _xarı_, تتۉپ, --, --, 
   {{0xddc401a6,0x00000000,0x00000000,0x00000000}},	//   _asiš, --, --, --, 
   {{0xbbd00b02,0x4adc000d,0x00000000,0x00000000}},	//   थक्क, _मड़व, --, --, 
   {{0x3b940cfc,0x68e003fa,0x3b0941e6,0x00000000}},	//   ојат, ündl, иево_, --, 
   {{0x7ff4d302,0xaa7809a5,0x7c38041a,0x00000000}},	//   _بستا, _syýa, štro, --, 
   {{0xaa78010b,0x00000000,0x00000000,0x00000000}},	// [20040] _pyýa, --, --, --, 
   {{0xbd4541e7,0x98b871e1,0xbc6541e8,0xae4001d9}},	//   _بندي, _sarı_, _двок, _کھێو, 
   {{0x6fb003e6,0x98b80139,0x00000000,0x00000000}},	//   _رمیا, _parı_, --, --, 
   {{0x98b80f77,0xddc400b8,0x00000000,0x00000000}},	//   _qarı_, _trių, --, --, 
   {{0x98b806be,0x00000000,0x00000000,0x00000000}},	//   _varı_, --, --, --, 
   {{0xe5a00d57,0x00000000,0x00000000,0x00000000}},	//   мичи, --, --, --, 
   {{0xaa780432,0x53348a63,0x5edc012d,0x98b8013d}},	//   _dzýu, пейт, _गुस्_, _tarı_, 
   {{0xaa7802f0,0x92941fbe,0x68b4011a,0x957c0210}},	//   _vzýv, заиц, _וללא_, _skąd, 
   {{0xa3b501e2,0x9f4000ae,0x326400d4,0x00000000}},	//   تاور_, _fhiú_, ітив, --, 
   {{0x64940184,0xe29c0579,0xa6940375,0x764001d5}},	//   стәр_, øða_, _וכמה_, mroy, 
   {{0x2d840086,0x51780014,0x764003b2,0x00000000}},	//   _ònei_, لٕکس_, lroy, --, 
   {{0x3cdc00ab,0x00000000,0x00000000,0x00000000}},	//   _गड़े_, --, --, --, 
   {{0xd2500597,0xaa7800a2,0x5f9450ce,0x7ae00327}},	//   _أنت_, _ayýn, фият, żotj, 
   {{0x2a7c01fa,0xdd840220,0x2c240124,0x00000000}},	//   _šubo_, мысп, жьаг, --, 
   {{0xc0c01540,0x7640022e,0x4c9400d4,0xa7640092}},	//   ስተር_, hroy, чивс, ደቀጠለ_, 
   {{0x48c400fd,0xaa7800a2,0x68e00037,0x6b800248}},	//   җәга, _dyýn, ündm, _ọgbi, 
   {{0x2d040323,0xdc3c005f,0x69c806af,0xa92000d7}},	// [20050] _мянг, kšķe, égeo, ížoc, 
   {{0x29043ad2,0x2afc00dc,0x764141e9,0x00000000}},	//   øna_, _शृणु_, droy, --, 
   {{0xaa7800a2,0x764000e4,0x00000000,0x00000000}},	//   _gyýn, eroy, --, --, 
   {{0xaba400db,0x76400129,0x00000000,0x00000000}},	//   _بۇرم_, froy, --, --, 
   {{0x7640a061,0x00000000,0x00000000,0x00000000}},	//   groy, --, --, --, 
   {{0x5a341feb,0x9964223a,0xbaf80375,0x9f400e89}},	//   _інст, _отсл, _להרש, _dhiù_, 
   {{0x1854036b,0x00000000,0x00000000,0x00000000}},	//   _оврў, --, --, --, 
   {{0x7640022c,0x9f4001ab,0xdb04067c,0x00000000}},	//   broy, _fhiù_, lhiá, --, 
   {{0x764007ea,0x66740244,0x00000000,0x00000000}},	//   croy, _بدزر, --, --, 
   {{0x661803b4,0xdb04e0fe,0x6b080327,0x74a8008e}},	//   _ituk, nhiá, _ཀུའོ_, рсәң_, 
   {{0xc8bc012c,0x00e401b9,0x69a0000d,0x00000000}},	//   ्पिट, яжон, _गवनी, --, 
   {{0x94051386,0xe3b0446a,0x7c640131,0x200401f4}},	//   _قوله, _غرض_, ۋازل, ömi_, 
   {{0x705003e6,0x64dc0073,0x63a941ea,0x8e740116}},	//   ونیا, _पुतळ, _ilgn, мурч, 
   {{0x644141eb,0x66189ea8,0x67e00037,0xc8bc07b7}},	//   orni, _mtuk, mõju, ्पाट, 
   {{0xd1b941ec,0x66180083,0x0c787694,0x644001ab}},	//   _بانا_, _ltuk, осты_, nrni, 
   {{0x661941ed,0x644141ee,0xd5c80051,0xc02c0023}},	//   _otuk, irni, jền_, ተብሂል, 
   {{0x644141ef,0xfe70007b,0x00000000,0x00000000}},	// [20060] hrni, _أدب_, --, --, 
   {{0x6738020c,0xfd4801b9,0x3ea003cd,0x644001a9}},	//   _aduj, _узок_, mykt_, krni, 
   {{0x8d78069c,0xfce40323,0x3ea141f0,0x684000c0}},	//   _ብምባል_, _хоно, lykt_, енха, 
   {{0xf7700a2c,0x64400219,0xe734c70f,0xd6c4030f}},	//   عاا_, drni, зец_, ومای, 
   {{0x644141f1,0x76400099,0xa61002bf,0x00000000}},	//   erni, uroy, еміч, --, 
   {{0x764082e0,0x63a800c5,0xe1e541f2,0xc5f400d1}},	//   rroy, _algn, _سس_, дғу_, 
   {{0x661941f3,0x764006ea,0x64400010,0x86400023}},	//   _etuk, sroy, grni, _ኣይክት, 
   {{0x764141f4,0x973404fb,0xa85402e4,0x94a80220}},	//   proy, _آکاا, _מילה_, йтқа_, 
   {{0x6440e80c,0xe9fc0208,0xe64000d8,0x00000000}},	//   arni, _hoạc_, _петп, --, 
   {{0x7d18045f,0x748c00d1,0x00000000,0x00000000}},	//   űtsj, _ﻛﯧﭽﯩ, --, --, 
   {{0x7ae541f5,0xe8dc001e,0x4cc0015b,0x64400841}},	//   _lykt, _trục_, _শুনু, crni, 
   {{0x4f080228,0xd3340066,0x00000000,0x00000000}},	//   өнүн_, _آباژ, --, --, 
   {{0xe3b004ac,0x7ae40267,0xddd00153,0x00000000}},	//   _אױף_, _nykt, _šešk, --, 
   {{0xd0ac013f,0x9d1941f6,0x00000000,0x00000000}},	//   _wɔɑh, зорт_, --, --, 
   {{0xd5c801dc,0x7ae40227,0x60400022,0x628c00d7}},	//   yền_, _aykt, _зхыз, äcov, 
   {{0x9b940395,0x00000000,0x00000000,0x00000000}},	//   нисц, --, --, --, 
   {{0x5f74ba84,0x49749532,0xaa7800a2,0xdb04007f}},	// [20070] _ساير, млас, _gyýl, nkiè, 
   {{0x7ae541f7,0x644141f8,0xad2000db,0x66e002d2}},	//   _dykt, yrni, _سۉرى, _líkþ, 
   {{0x3ea40029,0x661941f9,0x00000000,0x00000000}},	//   _ļoti_, _stuk, --, --, 
   {{0x644141fa,0x98c4039b,0x7c3806af,0x8b84215c}},	//   vrni, хсул, âtre, _تەرە_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x644141fb,0x00000000,0x00000000,0x00000000}},	//   trni, --, --, --, 
   {{0x644141fc,0x18b80124,0x00000000,0x00000000}},	//   urni, _егры_, --, --, 
   {{0x644141fd,0x661804ba,0x823436fe,0x6738000d}},	//   rrni, _ttuk, ورخا, _uduj, 
   {{0x661941fe,0x58040150,0x644001d5,0xdb2400e5}},	//   _utuk, _سوكك, srni, árér, 
   {{0xa2e0006c,0x23c0007f,0x65ac0158,0x64400010}},	//   моқд, _bèjè_, _bøhe, prni, 
   {{0x3ea0000f,0xaa7800a2,0xe9fc0051,0x00000000}},	//   wykt_, _syýl, _xoạc_, --, 
   {{0x7c380e3c,0x3ea00158,0xd498300e,0x387c0419}},	//   štrk, tykt_, _эру_, _štrk_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7ae44e97,0x00000000,0x00000000,0x00000000}},	//   _rykt, --, --, --, 
   {{0x7ae40b21,0xed54448e,0x3ea01445,0x70b000ae}},	//   _sykt, ьор_, sykt_, _لموض, 
   {{0x7ae40024,0xf090011a,0x00000000,0x00000000}},	//   _pykt, _ינו_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [20080] --, --, --, --, 
   {{0x7ae40024,0xaa78010e,0xee340166,0x00000000}},	//   _vykt, _gyým, _юнь_, --, 
   {{0x7ae4002d,0xdb0400f2,0xf86800d1,0x00000000}},	//   _wykt, zkiè, تماي_, --, 
   {{0xfaa4006c,0x7ae541ff,0x36c42a9d,0xb9040c70}},	//   _жамо, _tykt, мбег, _पड_, 
   {{0xb86400aa,0xa84400d1,0x00000000,0x00000000}},	//   _ښارو, كلەم_, --, --, 
   {{0xaca000a2,0xe9fc0051,0x00000000,0x00000000}},	//   _goỳd, _toạc_, --, --, 
   {{0xa5040114,0x00000000,0x00000000,0x00000000}},	//   меља_, --, --, --, 
   {{0xa82000f1,0x00000000,0x00000000,0x00000000}},	//   _شکمن, --, --, --, 
   {{0x75d410fe,0x961800bd,0x3168237b,0x65ac01bf}},	//   _قيرا, _ডটকম_, ошно_, _søhe, 
   {{0xb5a800c6,0xd2502586,0x998000c0,0x00000000}},	//   _بارك_, پنگ_, msių_, --, 
   {{0x853401d9,0x22a00241,0x998000c0,0x00000000}},	//   _سونچ, _pékú_, lsių_, --, 
   {{0x73349f21,0x64a14200,0x68e14201,0x00000000}},	//   _آرائ, _шаха, ündi, --, 
   {{0xa3e47a48,0x69c801ed,0x683c02d3,0xfd640055}},	//   _मीट_, égek, _ኣውስት, _hyuṣ, 
   {{0x290402d5,0xd0d400a7,0x99800064,0x00000000}},	//   žnai_, _полъ, isių_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd1b842ad,0x04540240,0x00000000,0x00000000}},	//   _باچا_, _ዘይጠቕ, --, --, 
   {{0xfcc80020,0x7d0001e4,0x2aa80212,0xa3dc0073}},	// [20090] _በውጭ_, _ĝose, цтво_, णवत_, 
   {{0xaca001f2,0x7d00010f,0x00000000,0x00000000}},	//   _arụg, _ŝose, --, --, 
   {{0xf7380023,0x998000c0,0x00000000,0x00000000}},	//   _ከምዝዕ, esių_, --, --, 
   {{0x68e40122,0x6f180986,0xda7001d9,0x00000000}},	//   _vyjd, ñuch, دُے_, --, 
   {{0x68e486df,0xfb180a7c,0x386c025c,0x00000000}},	//   _wyjd, _מורמ, ħfra_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7d180309,0x00000000,0x00000000,0x00000000}},	//   ñtsi, --, --, --, 
   {{0x8d78044e,0xe3bc0086,0xe64800ac,0xf8b0011a}},	//   _ብዝብል_, òñ_, şdığ, _עשן_, 
   {{0xca9402d3,0x85b8030d,0x00000000,0x00000000}},	//   _መጺኦም_, _елас_, --, --, 
   {{0x7c380e3c,0x95d8023a,0xe4a403f6,0x00000000}},	//   štri, _ждут_, _орео, --, 
   {{0x444401d3,0x00000000,0x00000000,0x00000000}},	//   _سراہ, --, --, --, 
   {{0xa3e40073,0xe28000fb,0x00000000,0x00000000}},	//   _मीच_, _ағин, --, --, 
   {{0xee354202,0x00000000,0x00000000,0x00000000}},	//   ння_, --, --, --, 
   {{0x7c201591,0x4cc0015b,0xc0dc0023,0xc0c80092}},	//   _čorb, _শুধু, _ሓሚሙ_, _አጉል_, 
   {{0x11f80244,0xdda000d7,0x00000000,0x00000000}},	//   _تووک_, šňov_, --, --, 
   {{0xebe14203,0x296802d3,0xac04e91f,0xaa7800a2}},	//   госп, _ጽሑፈይ_, енса_, _gyýk, 
   {{0x6b614204,0xaa40376d,0x660c020c,0xbea464c2}},	// [200a0] ыкта, летл, _éckh, _чапк, 
   {{0x7e7400e4,0x00000000,0x00000000,0x00000000}},	//   _isyp, --, --, --, 
   {{0x7c9400c6,0xee3c00a2,0x00000000,0x00000000}},	//   _أشخا, myýa_, --, --, 
   {{0xdb5004d3,0x15cc00d1,0x00000000,0x00000000}},	//   _خێر_, ﺒﺎﺩﻩ, --, --, 
   {{0x998002d5,0xc7640131,0xe7b00ca5,0x00000000}},	//   usių_, ئامى, دمند, --, 
   {{0x99800024,0x00000000,0x00000000,0x00000000}},	//   rsių_, --, --, --, 
   {{0x6e38031c,0x253403c7,0x00000000,0x00000000}},	//   ġubi, رسوخ_, --, --, 
   {{0xfd64002b,0x00000000,0x00000000,0x00000000}},	//   _vyuṣ, --, --, --, 
   {{0xee3c00a2,0x00000000,0x00000000,0x00000000}},	//   kyýa_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69c801ed,0x7e7400a2,0xd0d40395,0x00000000}},	//   égei, _asyp, тонъ, --, 
   {{0xb4bc02a0,0x60400022,0x00000000,0x00000000}},	//   ीपी_, ыхьз, --, --, 
   {{0x71a40953,0x00000000,0x00000000,0x00000000}},	//   _падз, --, --, --, 
   {{0xa2f000c0,0x00000000,0x00000000,0x00000000}},	//   _спіч, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x15cc00d1,0xc0a800f2,0x00000000,0x00000000}},	//   ﺒﺎﺭﻩ, _تاهل_, --, --, 
   {{0x4fc00075,0xce9402e8,0x00000000,0x00000000}},	// [200b0] _مەھە, _рапъ, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2c500023,0x00000000,0x00000000,0x00000000}},	//   _ዝፍጽም, --, --, --, 
   {{0x7e7400c7,0xfd64010e,0x01c000cc,0x00000000}},	//   _ysyp, _oktỳ, _উৱাদ, --, 
   {{0xfd4c0208,0xa9280153,0x00000000,0x00000000}},	//   _nghệ, _ніве_, --, --, 
   {{0xb6a09098,0x65ac0158,0x1a68dbc3,0x48240150}},	//   ришл, _bøha, _سیمی_, _لىسق, 
   {{0xf8ac05af,0x00000000,0x00000000,0x00000000}},	//   _وکم_, --, --, --, 
   {{0x68e00730,0x614021ea,0xd49801c0,0x00000000}},	//   ündu, گىدە, эрч_, --, 
   {{0xd7f94205,0x85754206,0x10c801ec,0x00000000}},	//   _чур_, _илах, _ﺨﺒﺭﻨ, --, 
   {{0x9264e540,0x67d002f4,0x25ec0073,0x82a4013d}},	//   اديم, _роғу, ेगळी_, ешүе, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x40340032,0x7e740175,0x00000000,0x00000000}},	//   неүс, _psyp, --, --, 
   {{0x7ed400cf,0x8f800150,0x00000000,0x00000000}},	//   ئزجا, сқыл, --, --, 
   {{0x7e7402f0,0x00000000,0x00000000,0x00000000}},	//   _vsyp, --, --, --, 
   {{0xfce42e82,0x6cc0009d,0x7e740210,0x00000000}},	//   тово, айра, _wsyp, --, 
   {{0x98b800b8,0xdb0401e7,0x00000000,0x00000000}},	//   _ndrā_, mhiú, --, --, 
   {{0x7e740210,0x00000000,0x00000000,0x00000000}},	// [200c0] _usyp, --, --, --, 
   {{0xe9d45e3e,0xd9111488,0x9f40004e,0xa92000a8}},	//   вку_, صیر_, _thió_, идул, 
   {{0x2fd404d3,0x00000000,0x00000000,0x00000000}},	//   _سوید_, --, --, --, 
   {{0x7bd84afb,0x7c383b7b,0xb098008f,0xac740150}},	//   étud, átru, ויער, _شاپش, 
   {{0x66714207,0x9f84eabc,0xeb954208,0xeab4013d}},	//   لدور, nıñ_, _рия_, _айя_, 
   {{0x7c38b515,0x94d401c6,0x93c800e5,0x00000000}},	//   štru, лолц, کاتہ_, --, 
   {{0x499001d5,0xb4b06b62,0xb4bc00dc,0xe5a00063}},	//   _دیلر, рийә, ीपे_, рији, 
   {{0xe8f406a6,0xaac406b1,0xdb040332,0x9f840139}},	//   _рлс_, _रेडक, dhiú, kıñ_, 
   {{0x91c4053f,0x066404d3,0xe7340046,0x00000000}},	//   ләкл, _مالپ, _шет_, --, 
   {{0x7c3c02d0,0x90980120,0x7760045a,0xdb040332}},	//   _ovpr, евот_, lfox, fhiú, 
   {{0x8f354209,0x00000000,0x00000000,0x00000000}},	//   ленц, --, --, --, 
   {{0x798c035a,0x1b1803d4,0x024800ec,0x00000000}},	//   _lnbw, তৰতে_, _ڳجهو_, --, 
   {{0xecd81533,0x7c200030,0x7c3c238a,0x798c007f}},	//   _मुजफ, _čora, _avpr, _onbw, 
   {{0x6cb00022,0xdb040332,0xee3c00a2,0x00000000}},	//   аигӡ, bhiú, byýn_, --, 
   {{0x9d19420a,0xdd946f32,0xdb0400ae,0xa0a0119e}},	//   тост_, шары, chiú, _вајд, 
   {{0x23a00227,0xe9a9420b,0x9b240166,0x9f840139}},	//   _uñjt_, ژدان_, ифул, bıñ_, 
   {{0x7c3c03ac,0x5b1401f0,0xe9f00022,0xb4bc0118}},	// [200d0] _evpr, рмут, иҧмы, ँछु_, 
   {{0xe29c0579,0xab580112,0x00000000,0x00000000}},	//   øði_, _gmün, --, --, 
   {{0x2905420c,0xf8b431ee,0x4cc0015b,0x981400c6}},	//   äna_, гөт_, _শুরু, لبنا, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9f44004a,0x7bd8004a,0xeb1c01f9,0x00000000}},	//   ômé_, étue, बडीत_, --, 
   {{0x89640050,0x00000000,0x00000000,0x00000000}},	//   _حُسن, --, --, --, 
   {{0x386800cd,0x54340124,0x00000000,0x00000000}},	//   _gpbr_, ахыу, --, --, 
   {{0xaca0063f,0x58d40184,0x29040024,0xfbc44c5b}},	//   _abịd, _тост, žnas_, रोपम, 
   {{0x07401c5c,0xa5642bc0,0xb3800352,0x00000000}},	//   _ﻛﻪﯓ_, _لدان, слыл, --, 
   {{0xdb0400c6,0xc0bc001f,0x00000000,0x00000000}},	//   thiú, _ደካማ_, --, --, 
   {{0xcea804ac,0x4aa40073,0xd498fa58,0x95c803ea}},	//   _צי_, _गॅसव, _ирц_, _рута_, 
   {{0x61400d1f,0x00000000,0x00000000,0x00000000}},	//   دىگە, --, --, --, 
   {{0xe2a800f7,0x7f8401d5,0xdb0401e7,0x00000000}},	//   _تاان_, نلگن, shiú, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbb45420d,0x225cf6ff,0x798c02d0,0x90e5420e}},	//   левк, ltuk_, _rnbw, _پسون, 
   {{0x3a20020b,0x6d400086,0x237c0399,0xdb040162}},	//   _ptkp_, _ônan, nduj_, skií, 
   {{0x225cf72d,0x7d1c00b5,0xdd04510c,0x65ac0fac}},	// [200e0] ntuk_, _tfps, ırıs, _røhn, 
   {{0x6b8c00d2,0x7c3c107d,0x237c047e,0x02d0000d}},	//   _encg, _tvpr, hduj_, _तखैन, 
   {{0x6b8c00e4,0x3134010f,0x00000000,0x00000000}},	//   _fncg, רנעם_, --, --, 
   {{0x225d420f,0xeb940724,0x3dc80083,0x00000000}},	//   ktuk_, _бию_, libw_, --, 
   {{0x56953cf9,0x237c014f,0xe990313e,0x55594210}},	//   ралт, dduj_, _گۇلگ, валя_, 
   {{0x69c801ed,0xb4b00116,0x225c01d3,0xa2d400bc}},	//   éget, йилә, dtuk_, मपन्, 
   {{0x66700075,0x29040427,0xe9d40108,0xe8f40064}},	//   لدۈر, žnar_, _скр_, _блр_, 
   {{0x72291dc3,0x00000000,0x00000000,0x00000000}},	//   нцов_, --, --, --, 
   {{0x65ac01bf,0x349000d1,0xd2140114,0x00000000}},	//   _køhl, рақр, јмоћ, --, 
   {{0x64940184,0x237c00f3,0x845400db,0x33f4013d}},	//   ттәр_, aduj_, _چىلچ, _өчес, 
   {{0x65ac05ac,0x317c0421,0x7bc54211,0xd7b80073}},	//   _møhl, rdtz_, _omku, _आताच, 
   {{0x764403cd,0x00000000,0x00000000,0x00000000}},	//   _åkys, --, --, --, 
   {{0x206402dd,0x00000000,0x00000000,0x00000000}},	//   _ұшып_, --, --, --, 
   {{0x7bc401f7,0xab5803e0,0x00000000,0x00000000}},	//   _amku, _emül, --, --, 
   {{0x2a6800a3,0x00000000,0x00000000,0x00000000}},	//   _spcb_, --, --, --, 
   {{0xa9c00131,0x247406be,0x00000000,0x00000000}},	//   ﻣﺌﯩﻴ, _qəmə_, --, --, 
   {{0x65ac143a,0x37c80183,0x80a80183,0x65600042}},	// [200f0] _bøhl, িকাৰ, _ছেপ্, yfnh, 
   {{0x60d000da,0x19586f78,0x7bc40036,0xef1c0790}},	//   ņemš, лауы_, _emku, lcü_, 
   {{0x65ac01bf,0xf81401d5,0x237c0455,0xa2c82e2a}},	//   _søho, لسنگ, yduj_, _तेन्, 
   {{0x225c0429,0xab600220,0xef1c2ca8,0x00000000}},	//   ytuk_, _دۇرى, ncü_, --, 
   {{0x69c801ed,0x237c014f,0xbb38011a,0x00000000}},	//   éges, vduj_, _שעשי, --, 
   {{0x320c03d1,0x00000000,0x00000000,0x00000000}},	//   _nify_, --, --, --, 
   {{0x758007d6,0x986801d3,0x80a800cc,0x00000000}},	//   تیلم, _میلے_, _ছেন্, --, 
   {{0xc2454212,0x225c01ed,0x3dc80083,0x00000000}},	//   аник, ttuk_, zibw_, --, 
   {{0x225c003e,0x00000000,0x00000000,0x00000000}},	//   utuk_, --, --, --, 
   {{0xaca001e1,0xd268038b,0x237c014f,0x225d4213}},	//   _abọd, اصين_, sduj_, rtuk_, 
   {{0x225d4214,0x320c05da,0x7c2001fa,0xf07401ed}},	//   stuk_, _dify_, _čoro, لیوں_, 
   {{0x7d000115,0x237c016d,0x225c00e5,0x00000000}},	//   _ŝoso, qduj_, ptuk_, --, 
   {{0x225c0d04,0x69c41711,0x44254215,0x939401e2}},	//   qtuk_, _omje, _htl_, _دجلا, 
   {{0xe29c0579,0x291c03ee,0x7bc4003e,0x44240064}},	//   øðu_, _şuan_, _smku, _ktl_, 
   {{0x4424002f,0x7c04007b,0x03bc002b,0xd498010a}},	//   _jtl_, لبرك, _śoṣa, _урă_, 
   {{0x4424aa0e,0x69c405c7,0xaca00cad,0x00000000}},	//   _mtl_, _amje, _gbọd, --, 
   {{0x3f901c06,0x6a814216,0xeb300e8e,0x44254217}},	// [20100] _inyu_, олта, زىلد, _ltl_, 
   {{0x65ac1347,0x00000000,0x00000000,0x00000000}},	//   _bøhm, --, --, --, 
   {{0x44240770,0x98b84baa,0xc7400023,0x3f800009}},	//   _ntl_, _odrą_, _ከምዝህ, odku_, 
   {{0x7bc4d739,0x69c4f32f,0xa2c800dc,0x3f800135}},	//   _umku, _emje, _तेभ्, ndku_, 
   {{0x7bd40b6f,0xaa9401e0,0x3f80058a,0x393401c6}},	//   mnyu, _кѳрә, idku_, _вэбс, 
   {{0x44254218,0xef1c0790,0x7874211f,0x92580124}},	//   _btl_, zcü_, _پُرا, ҳаит_, 
   {{0x44240408,0xb7940063,0x00000000,0x00000000}},	//   _ctl_, _краћ, --, --, 
   {{0x7bd42f99,0x44240334,0x660001d4,0x3f900083}},	//   nnyu, _dtl_, amnk, _nnyu_, 
   {{0x0ec401ad,0xaa7800a2,0x7bd40009,0xd58800fb}},	//   _लेंड, _hyýr, inyu, _бәйл_, 
   {{0x442401e4,0x3f800014,0xb1a40d99,0xf1a53247}},	//   _ftl_, edku_, ршик, ррин, 
   {{0x41840046,0xd010007b,0x60f40108,0x7bd54219}},	//   стығ, ثلج_, инья_, knyu, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x44240395,0xef1c0c3c,0x625000d7,0x12f4009f}},	//   _ztl_, rcü_, ržoá, _اتاھ, 
   {{0xbe2404c5,0x3f900433,0x442403ee,0xafe4022c}},	//   _বিশদ_, _enyu_, _ytl_, _bløð, 
   {{0xd138033f,0x00000000,0x00000000,0x00000000}},	//   ając_, --, --, --, 
   {{0x69c41727,0x7bd401d3,0x00000000,0x00000000}},	//   _smje, gnyu, --, --, 
   {{0x8af800d1,0xfbc40b98,0xcb000412,0x00000000}},	// [20110] унас_, रोधम, लेंड_, --, 
   {{0x7bd40083,0xafe40162,0xdd94010b,0x28840640}},	//   anyu, _fløð, _даьы, ићев, 
   {{0xafe40162,0x2d8001f5,0x00000000,0x00000000}},	//   _gløð, mdje_, --, --, 
   {{0x4425421a,0x8c44052f,0x93bc0311,0x2d81421b}},	//   _rtl_, _кеүе, _stăn, ldje_, 
   {{0x2d800d27,0xd7c80691,0xf8ac01ed,0x574802dd}},	//   odje_, جونه_, وکہ_, рзім_, 
   {{0x69c4036f,0x2d81421c,0x44240270,0x3a240077}},	//   _umje, ndje_, _ptl_, íope_, 
   {{0x58d4676b,0x69d4004b,0x2d81421d,0x4424045a}},	//   _дорт, mnxe, idje_, _qtl_, 
   {{0x76b49e04,0x4425421e,0x00000000,0x00000000}},	//   рләр_, _vtl_, --, --, 
   {{0x1cb00156,0x27fd421f,0x44240175,0x00000000}},	//   དགོ_, _ihun_, _wtl_, --, 
   {{0x2d800cf9,0xddc42a0d,0x3f80058a,0x00000000}},	//   jdje_, _opiš, wdku_, --, 
   {{0x27fc138f,0x44240083,0x99800309,0xc0e4014b}},	//   _khun_, _utl_, npiš_, сонк, 
   {{0x2d8012fb,0x7bd4020c,0x00000000,0x00000000}},	//   edje_, xnyu, --, --, 
   {{0x63b94220,0xaac405d7,0x2d8001a4,0x7bd4005a}},	//   mhun, _रेलक, fdje_, vnyu, 
   {{0x2d801727,0x63b94221,0xc2c40451,0x61400139}},	//   gdje_, lhun, _پيڪي, _qílı, 
   {{0x27fc4e53,0x62881710,0xefb001d5,0x00000000}},	//   _ohun_, _hrgo, زییگ, --, 
   {{0x3f9001f9,0x2d800d27,0x27fc003e,0x69d40077}},	//   _unyu_, adje_, _nhun_, enxe, 
   {{0x63b8245f,0x20014222,0x3944da20,0xd5440241}},	// [20120] ihun, _ihii_, йнаг, _jẹ̀w, 
   {{0x27fd4223,0xbdf8038b,0x62881a48,0x63b80208}},	//   _ahun_, _حربا_, _mrgo, hhun, 
   {{0x7bd515be,0x63b84ec2,0x27fc7ea1,0x80a8009e}},	//   pnyu, khun, _bhun_, _ছেত্, 
   {{0x27fd4224,0x62894225,0xb7380597,0x24840564}},	//   _chun_, _orgo, اثاء_, dvnm_, 
   {{0x63b8d5a5,0x27fc08c2,0x200001ab,0xa84400d1}},	//   dhun, _dhun_, _mhii_, للەم_, 
   {{0x27fd4226,0x63b80e78,0x00000000,0x00000000}},	//   _ehun_, ehun, --, --, 
   {{0x62894227,0x63b81aa1,0xe7d001d9,0x01cc00eb}},	//   _argo, fhun, _کۅنگ, রকাদ, 
   {{0x63b94228,0x68e00b21,0xc32c4418,0xd54401e1}},	//   ghun, ûnde, نەم_, _bẹ̀w, 
   {{0xd1300597,0x91b8004e,0x32087125,0x16840345}},	//   ومة_, игит_, лхон_, _بازێ, 
   {{0x20014229,0x7641422a,0x30f40014,0x00000000}},	//   _ahii_, msoy, یوکھ_, --, 
   {{0x63b81992,0x7640022c,0x2d8001fa,0x74146d69}},	//   bhun, lsoy, vdje_, _اوصا, 
   {{0x7539422b,0x20000e8a,0x43740117,0x00000000}},	//   _hetz, _chii_, _мучт, --, 
   {{0xceb84701,0xddc401f1,0x2001422c,0xb62804ce}},	//   рәй_, _spiš, _dhii_, _ｔｋ_, 
   {{0x753891e1,0x7bd9422d,0x998002d1,0x00000000}},	//   _jetz, étun, ypiš_, --, 
   {{0x75383bbe,0x2d81422e,0x39580327,0xdb0401f4}},	//   _metz, rdje_, dgps_, hkiä, 
   {{0x75388505,0xddc40fb7,0x7640007f,0x5ba40395}},	//   _letz, _vpiš, ksoy, пруз, 
   {{0x6efc01e1,0x27fca4fd,0x9bc4014b,0xd5b800ef}},	// [20130] _dàbí, _rhun_, чёрк, _olā_, 
   {{0x75380639,0x27fd422f,0x63b94230,0x8f54e218}},	//   _netz, _shun_, zhun, _انکش, 
   {{0x63b87cea,0xddc404b9,0x27fc001e,0x99d400f7}},	//   yhun, _upiš, _phun_, ستكا, 
   {{0x64c005ba,0x63b94231,0xd5b80171,0x7640008e}},	//   _वेगळ, xhun, _alā_, fsoy, 
   {{0x63b94232,0x45440131,0x764000ad,0x99800427}},	//   vhun, قچاق, gsoy, spiš_, 
   {{0xbc6401d9,0x63b900dd,0xd54401e1,0x00000000}},	//   _دۅہن_, whun, _rẹ̀w, --, 
   {{0x75394233,0x27fd4234,0x76400083,0x788000e4}},	//   _detz, _thun_, asoy, rãvá, 
   {{0x42240d44,0xdcfc0882,0x753801a4,0x27fc0098}},	//   одив, ndrā, _eetz, _uhun_, 
   {{0x63b94235,0x76400076,0x75394236,0xdcfc00de}},	//   rhun, csoy, _fetz, idrā, 
   {{0x63b94237,0x75385909,0x81c94238,0x6738003e}},	//   shun, _getz, ргов_, _heuj, 
   {{0x63b849e1,0x673831e5,0x2bf801bc,0xd54401e1}},	//   phun, _keuj, ्षां_, _wẹ̀w, 
   {{0x62888847,0xe3b008f4,0x66194239,0x63b89e39}},	//   _trgo, _عرض_, _kuuk, qhun, 
   {{0x644010d1,0x6619423a,0x67380438,0xe8680092}},	//   lsni, _juuk, _meuj, _አፋጣኝ_, 
   {{0x4128094e,0x6619423b,0x69c8020c,0x7654002e}},	//   _токо_, _muuk, ègel, àyyi, 
   {{0x6441423c,0x6619423d,0x705000c6,0x200000a3}},	//   nsni, _luuk, _قنوا, _thii_, 
   {{0x200003a0,0xdb0401f4,0x00000000,0x00000000}},	//   _uhii_, ykiä, --, --, 
   {{0x64400649,0x661941d4,0x00000000,0x00000000}},	// [20140] hsni, _nuuk, --, --, 
   {{0xefd0001f,0x764003b2,0x644c0055,0x00000000}},	//   _የጊዜ_, vsoy, _ācin, --, 
   {{0x7539423e,0xa2c80316,0x64407c1b,0x6efc0241}},	//   _retz, _तेस्, jsni, _tàbí, 
   {{0x75385370,0x6619423f,0x76414240,0x6440508f}},	//   _setz, _buuk, tsoy, dsni, 
   {{0x7538324c,0x7c2d4241,0x67380165,0x644000e2}},	//   _petz, lpbr, _deuj, esni, 
   {{0x64414242,0x66180a55,0xdb0400fd,0xc7b801ed}},	//   fsni, _duuk, rkiä, _elő_, 
   {{0x75394243,0x81c00eac,0x764081f1,0xdb040108}},	//   _vetz, ্কা_, ssoy, skiä, 
   {{0x75394244,0x6738003e,0x66194245,0xa2c80316}},	//   _wetz, _geuj, _fuuk, _तेह्, 
   {{0xe3ac30a3,0x64400009,0xf1a94246,0x386c031c}},	//   ئرى_, asni, لاده_, ħfru_, 
   {{0x6738030a,0x64400153,0x75392aa7,0xc0b80092}},	//   _zeuj, bsni, _uetz, _ሲልም_, 
   {{0x661804ba,0xe1ec009f,0xdee80240,0x00000000}},	//   _zuuk, خسي_, _መዚኑ_, --, 
   {{0xa2c805ba,0x6618019b,0xe4301e24,0x00000000}},	//   _तेव्, _yuuk, _آفند, --, 
   {{0x6618011f,0xf1a803e6,0x5e84004e,0x929401c4}},	//   _xuuk, _پاشه_, мурз, _халц, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2ba4399f,0x00000000,0x00000000,0x00000000}},	//   ојав, --, --, --, 
   {{0xcfe88316,0x00000000,0x00000000,0x00000000}},	//   _دفعه_, --, --, --, 
   {{0x67380438,0x7c2c017a,0xb340031c,0x00000000}},	// [20150] _reuj, apbr, ħħho, --, 
   {{0x66194247,0x3a2401e7,0xbd800354,0x00000000}},	//   _ruuk, íopa_, _пӳск, --, 
   {{0x66194248,0x673800d5,0x7d780375,0xe84800be}},	//   _suuk, _peuj, _הנתו, شجان_, 
   {{0x8698005e,0x661816ca,0x644001e3,0xd7c800f1}},	//   йкес_, _puuk, vsni, يوله_, 
   {{0x39480098,0x66180548,0xd62400cf,0x316c0419}},	//   _fdbs_, _quuk, وعوي, _obfz_, 
   {{0x64401e10,0xdb04056a,0x661860bd,0x00000000}},	//   tsni, chiñ, _vuuk, --, 
   {{0xa49000f9,0x6738c52a,0x8cd02356,0xd6d80ce8}},	//   بیات, _teuj, _डेमो, йтә_, 
   {{0x64414249,0xb78400ee,0x4254004e,0x00000000}},	//   rsni, _нәче_, птот, --, 
   {{0x6441424a,0xa2c800bc,0x831400e5,0x04fc00eb}},	//   ssni, _तेश्, _ہواؤ, ুডের_, 
   {{0x64400953,0x05d8009f,0x00000000,0x00000000}},	//   psni, _ادرڪ_, --, --, 
   {{0xa2c800bc,0x00000000,0x00000000,0x00000000}},	//   _तेर्, --, --, --, 
   {{0xb4f80375,0x00000000,0x00000000,0x00000000}},	//   _הפעי, --, --, --, 
   {{0x16000412,0x3fa0013d,0x80a800cc,0x00000000}},	//   _लीडर_, _ıruğ_, _ছেশ্, --, 
   {{0xd18400d4,0x7c2c0022,0x00000000,0x00000000}},	//   _олій, tpbr, --, --, 
   {{0x3154008f,0xaf440014,0x00000000,0x00000000}},	//   _זיצן_, _کرى۪, --, --, 
   {{0x3a24c3ef,0xba25424b,0xfbc40456,0x00000000}},	//   змаг, здак, रोंम, --, 
   {{0x7c2c014b,0x4de40150,0x00000000,0x00000000}},	// [20160] spbr, _ﺍﻳﯩﻨ, --, --, 
   {{0xa96467d7,0x7c2c007c,0xef1c2093,0xbc6400f3}},	//   зифа_, ppbr, ndün_, _евок, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x787008a5,0x00000000,0x00000000,0x00000000}},	//   _aðvö, --, --, --, 
   {{0x256d0356,0x2bf8043e,0x00000000,0x00000000}},	//   kılı_, ्षरं_, --, --, 
   {{0x4a000022,0x00000000,0x00000000,0x00000000}},	//   _аҟуа, --, --, --, 
   {{0xbb341c5c,0x236c0175,0x256c06be,0x00000000}},	//   ﺮﮔﻪ_, _bbgj_, dılı_, --, 
   {{0xf2c400d4,0x2bcc0825,0xb7d87cda,0x00000000}},	//   зсон, सोपा, _اورا_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x64640e33,0x256c236c,0x00000000,0x00000000}},	//   ériá, gılı_, --, --, 
   {{0xcf900014,0x2d84032e,0xe574009d,0x00000000}},	//   ن٘د_, _ónei_, _хзх_, --, 
   {{0x09b9424c,0xa4f80a1e,0x6498008f,0xdcfc0356}},	//   _इत्य, _פלאט, _ליבה, zdră, 
   {{0x5f941fc5,0xb63c00b5,0x8364036b,0x957c0210}},	//   хият, _ａｄ_, _آدمل, _ukąs, 
   {{0xab580112,0x2b480f85,0x2bcc000d,0x256c1cce}},	//   _klüg, _sdcc_, सोना, cılı_, 
   {{0xeb48008e,0x00000000,0x00000000,0x00000000}},	//   йчак_, --, --, --, 
   {{0x23cc0aff,0x60d8011a,0x00000000,0x00000000}},	//   तोपद, _לקונ, --, --, 
   {{0x81c00154,0xad2400cf,0xda78187f,0x00000000}},	// [20170] ্কর_, _ىردو, зях_, --, 
   {{0xaca001f2,0x7a140100,0x2dd401d9,0xdebc011a}},	//   _asụg, _pņta, _ژُکھ_, _למחל, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x256c0259,0x00000000,0x00000000,0x00000000}},	//   zılı_, --, --, --, 
   {{0x256c0365,0x1a940006,0x00000000,0x00000000}},	//   yılı_, _заяў, --, --, 
   {{0xdbdc0248,0xfa540133,0x00000000,0x00000000}},	//   _láìn, _کرێگ, --, --, 
   {{0x7dc005da,0xd8382e80,0x00000000,0x00000000}},	//   _fôsf, _нэт_, --, --, 
   {{0x059400ec,0x00000000,0x00000000,0x00000000}},	//   _ڪارگ, --, --, --, 
   {{0xb3800bb0,0x256c05d1,0x27ec07de,0x020401af}},	//   тлыл, tılı_, mogn_, мзин, 
   {{0xab5803fa,0x27ed424d,0x00000000,0x00000000}},	//   _flüg, logn_, --, --, 
   {{0xab580793,0x256c2fbe,0x410400c9,0xef1c0b97}},	//   _glüg, rılı_, ьзов, rdün_, 
   {{0x256c510c,0xdcfc0153,0x27ec0162,0x00000000}},	//   sılı_, ndrą, nogn_, --, 
   {{0xee3495be,0x63a803d5,0x256c2d1c,0x53340137}},	//   мня_, _iogn, pılı_, _чечт, 
   {{0x63a83619,0xef1c010e,0x00000000,0x00000000}},	//   _hogn, ldül_, --, --, 
   {{0x2c84012c,0x00000000,0x00000000,0x00000000}},	//   vídá_, --, --, --, 
   {{0x70742101,0x31b0054e,0xa9e400d1,0x02b00118}},	//   _آميز_, _râzi_, ۈزلۈ, _जथाभ, 
   {{0x63a9424e,0xab580bac,0x27ec0c86,0xaa41424f}},	// [20180] _mogn, _amüs, dogn_, кетл, 
   {{0x63a94250,0x7e740588,0x2bcc0b4c,0xe2bc01e1}},	//   _logn, _ipyp, सोबा, _èṣùú_, 
   {{0x63a8058a,0x98b94251,0x00000000,0x00000000}},	//   _oogn, _terč_, --, --, 
   {{0x27ec0c86,0x63a94252,0xe7354253,0x00000000}},	//   gogn_, _nogn, дец_, --, 
   {{0x3d2000bc,0xca7400c0,0xa93400db,0x00000000}},	//   _मलाइ_, _пуры, سبەچ, --, 
   {{0x63a9177a,0x279004b4,0xf200012d,0x00000000}},	//   _aogn, ешәр, _रीढ़_, --, 
   {{0x63a94254,0x27ec04cc,0x6484009d,0x00000000}},	//   _bogn, bogn_, дсыг_, --, 
   {{0x63a83dda,0xa520013d,0x00000000,0x00000000}},	//   _cogn, нмәд, --, --, 
   {{0x63a94255,0x592c0327,0x366821f3,0xb284013d}},	//   _dogn, _ཧྥོས_, _фазо_, фыйк, 
   {{0xea98010f,0x00000000,0x00000000,0x00000000}},	//   קסיש, --, --, --, 
   {{0x7e7400e4,0x63a94256,0x00000000,0x00000000}},	//   _apyp, _fogn, --, --, 
   {{0x63a8c7cc,0x00000000,0x00000000,0x00000000}},	//   _gogn, --, --, --, 
   {{0x31c40b3b,0xcf900014,0xde640395,0xd25000ae}},	//   _оскв, ن٘گ_, кърп, _إنت_, 
   {{0xe0cc58ae,0x63a94257,0xef1c0205,0x00000000}},	//   ازی_, _zogn, mdüm_, --, 
   {{0x7e740022,0xef1c2ca8,0x644c0055,0x00000000}},	//   _epyp, ldüm_, _ācik, --, 
   {{0x3eac0023,0x7c20009b,0xf1a80133,0x1f741de6}},	//   ëjtë_, _čort, _داڵه_, _алъя, 
   {{0x27ec1512,0xef1c2fbe,0x7d0001e4,0x3a30017a}},	// [20190] vogn_, ndüm_, _ŝost, gpyp_, 
   {{0xda794258,0xd71000fe,0x7d0c03b2,0x00000000}},	//   ьяс_, হুৱা_, ónsæ, --, 
   {{0x6fa002db,0x00000000,0x00000000,0x00000000}},	//   गापू, --, --, --, 
   {{0x7e740022,0x957c012d,0xef1c371e,0x00000000}},	//   _ypyp, _skąp, kdüm_, --, 
   {{0xefc402d3,0xc5f402e8,0x00000000,0x00000000}},	//   _ጽኑዕ_, някъ, --, --, 
   {{0x63a94259,0x27ec026c,0x0578007b,0x00000000}},	//   _sogn, sogn_, سمعة_, --, 
   {{0x63a9425a,0x44150286,0xd9140024,0x00000000}},	//   _pogn, нфит, _адры, --, 
   {{0xab5807de,0x7c2800d8,0xd78800db,0x84b800a2}},	//   _flüe, _éfre, _يەلۉ_, _ďîćŕ, 
   {{0x63a82ab7,0x7bd80129,0xab5803e0,0x8574c978}},	//   _vogn, étui, _klüb, _плах, 
   {{0xe504004b,0x63a801f5,0x5bdc00dc,0x0038001f}},	//   _قباي, _wogn, _यद्व, _የተከና, 
   {{0x2c1c00cd,0x29cc0210,0x00000000,0x00000000}},	//   _मूलं_, eżak_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x53440022,0x00000000,0x00000000,0x00000000}},	//   _рхха, --, --, --, 
   {{0x88c40154,0x00000000,0x00000000,0x00000000}},	//   _এখনক, --, --, --, 
   {{0xfe2800b5,0xaa7800a2,0xca4c0150,0x00000000}},	//   _w杯_, _gyýz, _ﺍﺫﺍ_, --, 
   {{0x4fc00075,0x7a140100,0x3a30009a,0xfaa5425b}},	//   _نەپە, _pņto, tpyp_, набо, 
   {{0xf41000c8,0x395403b7,0x1ee804fb,0x6e90680d}},	// [201a0] רפן_, ењет, _زودی_, _مليا, 
   {{0xfaa4016c,0x3a302744,0x00000000,0x00000000}},	//   _ҷамо, rpyp_, --, --, 
   {{0x5be402dd,0xbb4448e5,0xef1c4a0f,0x00000000}},	//   _айнұ, _пенк, zdüm_, --, 
   {{0xfaa43048,0xf7f41d37,0x7aa4033a,0x00000000}},	//   _замо, رساد, _зимз, --, 
   {{0x98ac03be,0x7bd5425c,0x91b40034,0xcb140006}},	//   ğlıq_, miyu, ेसमै, _афры, 
   {{0x7bd5425d,0x98ac654f,0xa2c00e49,0xf65000ec}},	//   liyu, şlıq_, ाईन्, نئڻ_, 
   {{0x3c3c00bc,0x69c800e8,0x643000ec,0x52b80b4c}},	//   nův_, ëgee, هريء, इन्स, 
   {{0x23446886,0x7bd5425e,0xd6400408,0x00000000}},	//   ىلىپ_, niyu, _гiаж, --, 
   {{0x27e5425f,0x7bd4009a,0x91c400b1,0x66540354}},	//   énne_, iiyu, кәкл, _патă, 
   {{0xb5c87c04,0xef1c3630,0x3c3cfc95,0xc5ec004b}},	//   _عوام_, rdüm_, kův_, _وړو_, 
   {{0x7bd54260,0x1ccc0003,0x41840220,0x8f340024}},	//   kiyu, ྱགས_, ттығ, кенц, 
   {{0x77614261,0x09dc3f55,0xa2c800bc,0x3c3c013a}},	//   ngox, _मद्य, _तेक्, dův_, 
   {{0x7bd54262,0xef1c0205,0xe2940c5c,0x00000000}},	//   diyu, ldük_, _пац_, --, 
   {{0x01f40022,0xaa780432,0x628400e2,0xdd8404b3}},	//   _иҭыш_, _gyýy, ājot, лысп, 
   {{0x317c0b94,0x7bd54263,0x7d1c02d0,0xd1386dd3}},	//   metz_, fiyu, _dgps, mbą_, 
   {{0x7bd40cfe,0x317cc474,0xd1380006,0x80a800fe}},	//   giyu, letz_, lbą_, _ছেক্, 
   {{0x66d0066d,0x7c3c0076,0x290000e5,0x00000000}},	// [201b0] _műkö, _ewpr, _szja_, --, 
   {{0x317d4264,0xab58002f,0x3c3c01ef,0x00000000}},	//   netz_, _blüc, bův_, --, 
   {{0x6d454265,0x98b800b0,0x7bd419a0,0x38c401e1}},	//   maja, _perā_, biyu, _ríré_, 
   {{0x6d454266,0xe7cc015b,0x00000000,0x00000000}},	//   laja, িক্য, --, --, 
   {{0x63c001e0,0x257008eb,0x6d44000d,0xba1800ec}},	//   ҫалҡ, лқас, oaja, _ڊيٽا_, 
   {{0x6d454267,0xab5822f8,0xe69000fd,0x9a84094f}},	//   naja, _flüc, киҗы, _суюл, 
   {{0x69d54268,0xab580639,0x317c180f,0x592c031c}},	//   mixe, _glüc, detz_, _ཧྥིས_, 
   {{0x6d454269,0x69d5426a,0x437400f7,0xaa7800a2}},	//   haja, lixe, тукт, _syýy, 
   {{0x224804c4,0xd7e401ce,0x317c0066,0x69d4004e}},	//   éck_, _сіро, fetz_, oixe, 
   {{0x6d45426b,0x93bc0311,0x69d40472,0xdcfc010f}},	//   jaja, _stăt, nixe, serĉ, 
   {{0x6d45426c,0x7bd41459,0xf99023e4,0xc0e412e7}},	//   daja, yiyu, ברי_, тонк, 
   {{0x69d5426d,0x7bd40009,0xcdc40150,0x00000000}},	//   hixe, xiyu, қасқ, --, 
   {{0x63b9426e,0x6d45426f,0x317c0ba1,0x69d54270}},	//   mkun, faja, betz_, kixe, 
   {{0x6d454271,0x409400e4,0x7bd54272,0xfce4ea5a}},	//   gaja, _арит, wiyu, вого, 
   {{0x7bd40bf1,0x6da0442d,0x69d52311,0xada14273}},	//   tiyu, шира, dixe, шарл, 
   {{0x63b94274,0x6d440194,0x69d40137,0x3c3c0118}},	//   nkun, aaja, eixe, rův_, 
   {{0x6d454275,0x69d44a1f,0x7bd54276,0x63b94277}},	// [201c0] baja, fixe, riyu, ikun, 
   {{0x6d441326,0xab58e4e6,0x63b94278,0x91d41d15}},	//   caja, _plüc, hkun, योपै, 
   {{0x63b94279,0x225c0548,0x7bd45c5d,0xa965427a}},	//   kkun, huuk_, piyu, тиха_, 
   {{0x63b80986,0x7bd41364,0x225d427b,0x00000000}},	//   jkun, qiyu, kuuk_, --, 
   {{0x63b9427c,0xd1383ee4,0x69d401bf,0x6fa001f9}},	//   dkun, ybą_, bixe, गातू, 
   {{0x63b9427d,0xe60c16ac,0x34380736,0x00000000}},	//   ekun, يشو_, وسعد_, --, 
   {{0x63b9427e,0xc0b80125,0x317c180f,0xa9640354}},	//   fkun, _ዲግሪ_, vetz_, _шира_, 
   {{0x6d440400,0x64a0026a,0xef1d2af5,0x225c011f}},	//   zaja, раћа, rdük_, fuuk_, 
   {{0x6d45427f,0x225c0194,0x317c0ba1,0x00000000}},	//   yaja, guuk_, tetz_, --, 
   {{0x63b94280,0x6454056a,0x00000000,0x00000000}},	//   akun, áxic, --, --, 
   {{0x317d4281,0xd13802d5,0x63b94282,0xaa1c00bc}},	//   retz_, rbą_, bkun, _बढ्छ_, 
   {{0x317c1859,0x6d454283,0x63b94284,0x225c7bc3}},	//   setz_, waja, ckun, buuk_, 
   {{0x6d454285,0x69d54286,0xc0b80092,0xdef8013d}},	//   taja, yixe, _ዲግረ_, выр_, 
   {{0x69d40548,0xd1b001d5,0xe1ed4287,0x00000000}},	//   xixe, _چیکک, _وسو_, --, 
   {{0x6d454288,0xdb040209,0x69d40077,0x518402dd}},	//   raja, rkiý, vixe, _ауқа, 
   {{0x69d4009a,0x00000000,0x00000000,0x00000000}},	//   wixe, --, --, --, 
   {{0x69d54289,0x4975428a,0x00000000,0x00000000}},	// [201d0] tixe, ллас, --, --, 
   {{0x63b8152d,0x6d45428b,0x68000241,0x00000000}},	//   zkun, qaja, _ọjó, --, 
   {{0x63b84375,0x9b640075,0x69d4c0f1,0xe8dc004d}},	//   ykun, _ھۆكۈ, rixe, _trọc_, 
   {{0x7c28020c,0xeb0400ee,0x69d4004b,0x98b80356}},	//   _éfra, _ачго, sixe, _seră_, 
   {{0x63b80158,0xe6c400d1,0x1aa401af,0x00000000}},	//   vkun, ختاي, _кјрг, --, 
   {{0x63b9428c,0x48240617,0x29cc0327,0x80c400cd}},	//   wkun, _مىسق, vżaw_, ानमे, 
   {{0x63b9428d,0x58849480,0xeb9c03b2,0x29cc0135}},	//   tkun, _кыта, _knø_, wżaw_, 
   {{0x93bc0276,0x225c04ba,0x00000000,0x00000000}},	//   _stăr, tuuk_, --, --, 
   {{0xd3a40220,0xdcfc025c,0x00000000,0x00000000}},	//   рлық, terċ, --, --, 
   {{0x67d00ae5,0x008405f5,0x9f60056a,0x225c0548}},	//   _соғу, глоо, _ásúa_, ruuk_, 
   {{0x63b80cfe,0x4375428e,0x3f680a5b,0xf99000d9}},	//   pkun, _булт, нино_, זרי_, 
   {{0x63b81bb7,0x4425428f,0xdcfc0327,0x3ea401d5}},	//   qkun, _iul_, serċ, гимг, 
   {{0x44254290,0xa28002f2,0x7ed40066,0x00000000}},	//   _hul_, _ئیخو, ازجا, --, 
   {{0x44254291,0x4ed402bf,0x00000000,0x00000000}},	//   _kul_, рюют, --, --, 
   {{0x44254292,0xa3c400bc,0x00000000,0x00000000}},	//   _jul_, _उता_, --, --, 
   {{0x44254293,0x81c0009e,0x00000000,0x00000000}},	//   _mul_, ্কও_, --, --, 
   {{0xdcfc0232,0x44254294,0x98b800c0,0x91c803d4}},	// [201e0] merč, _lul_, _merą_, ৰকৰ্, 
   {{0x9f400227,0x44254295,0x3f814296,0xdcfc007f}},	//   _ikiñ_, _oul_, leku_, lerč, 
   {{0x31b800c8,0xdcf801ed,0xd91030fe,0x00000000}},	//   עזענ, _شہرت_, زیر_, --, 
   {{0x3f814297,0x81c002a6,0x36c40228,0xab580254}},	//   neku_, ্কট_, лбег, _tlüa, 
   {{0x44241c1d,0x66701b06,0xeb9c01bf,0x27e400d5}},	//   _aul_, مدور, _ohøj_, énna_, 
   {{0x44254298,0x3f814299,0xd5b0007b,0x00000000}},	//   _bul_, heku_, تفت_, --, 
   {{0x4425429a,0xe56c0451,0x3f81429b,0x798c02d0}},	//   _cul_, سطو_, keku_, _iabw, 
   {{0x4425429c,0x539880df,0x3f8022c1,0x1684168d}},	//   _dul_, твия_, jeku_, _پارێ, 
   {{0x4424ce5b,0x3f800083,0x316800a7,0x57a401e0}},	//   _eul_, deku_, ншно_, _йыҡҡ, 
   {{0x798c016d,0xdb040784,0xd2500451,0xd5b80303}},	//   _jabw, nkiñ, ٽنگ_, _अविज, 
   {{0x798d429d,0x998000c0,0x00000000,0x00000000}},	//   _mabw, lpių_, --, --, 
   {{0x798d429e,0xddc40327,0x98b80006,0x232403f6}},	//   _labw, _epiż, _gerą_, _боци_, 
   {{0xab5801b8,0x4425429f,0x958c1772,0x00000000}},	//   _blün, _zul_, _መሬትን_, --, 
   {{0x44240598,0x798c856f,0xeb9c03a1,0x64600427}},	//   _yul_, _nabw, _snø_, žviž, 
   {{0x442542a0,0xd1ec001f,0x7e600158,0x3f811667}},	//   _xul_, _ቅሬታ_, _åopn, beku_, 
   {{0x798c0083,0xc0a80be2,0x3f80825a,0xdcfc0c5e}},	//   _aabw, _جاهل_, ceku_, cerč, 
   {{0x798d42a1,0x1dc40372,0xaca00241,0x00000000}},	// [201f0] _babw, рөөн, _irọg, --, 
   {{0xab5807c5,0xab80001f,0x5b140eba,0xa904413a}},	//   _glün, ርበዋል_, смут, هبان, 
   {{0x2d8019f6,0x798d42a2,0xd7c804fb,0x2dd40014}},	//   meje_, _dabw, گونه_, _لُکھ_, 
   {{0x442542a3,0x2d8142a4,0x5cc42f09,0x5fa80073}},	//   _rul_, leje_, _ысыз, गायल, 
   {{0x442542a5,0xd7c8021a,0x6b8c0998,0x798c03cb}},	//   _sul_, دونه_, _iacg, _fabw, 
   {{0x442542a6,0x2d8142a7,0x798c04ba,0x93bd42a8}},	//   _pul_, neje_, _gabw, _stăp, 
   {{0x442542a9,0x75d01e5a,0x00000000,0x00000000}},	//   _qul_, تيوا, --, --, 
   {{0x442542aa,0xfa780201,0x2d8142ab,0xddc448ba}},	//   _vul_, _አካባቢ_, heje_, _spiż, 
   {{0x2d8142ac,0x6b8cf588,0x798d42ad,0x64a09246}},	//   keje_, _macg, _yabw, рақа, 
   {{0x2d8142ae,0x41b542af,0x442542b0,0x7a14007f}},	//   jeje_, рсит, _tul_, _dņtw, 
   {{0x2d801a58,0x442542b1,0x543401d5,0x3fe44316}},	//   deje_, _uul_, _هرنر, ижов, 
   {{0xdb04005a,0x00000000,0x00000000,0x00000000}},	//   zkiñ, --, --, --, 
   {{0xab592a6e,0xdb040309,0x05d8000d,0x00000000}},	//   _plün, ykiñ, _भगाब, --, 
   {{0x2d80015c,0x3f8142b2,0x628801d9,0x6b8c0139}},	//   geje_, seku_, _isgo, _aacg, 
   {{0x798c0086,0x9ba40ed1,0x93bc054e,0x6b8c0051}},	//   _rabw, مەدى, _ouăl, _bacg, 
   {{0x798d42b3,0xd24c03e6,0x9980025c,0x00000000}},	//   _sabw, _تۆی_, spiż_, --, 
   {{0xeab40372,0x798d42b4,0x2d8142b5,0x3944d39c}},	// [20200] айт_, _pabw, beje_, инаг, 
   {{0x9d5404d3,0x798c047e,0xab580205,0xada0074d}},	//   _دۆست, _qabw, _flüo, _даьл, 
   {{0xab5829ef,0x798c0083,0xfeb810e8,0xfb800244}},	//   _klül, _vabw, _ساکت_, _وگری, 
   {{0x6e90130e,0x798d42b6,0x628942b7,0x29cc0135}},	//   _الیا, _wabw, _osgo, wżat_, 
   {{0x798d42b8,0x64540005,0x569542b9,0x7bc542ba}},	//   _tabw, áxin, салт, _ilku, 
   {{0x7bc402c4,0xb86542bb,0x99800153,0x00000000}},	//   _hlku, _پاسو, rpių_, --, 
   {{0x628942bc,0x292401f1,0xf74400d8,0xe9d400d4}},	//   _asgo, ávať_, _вебо, _ткр_, 
   {{0x87f80276,0x68e142bd,0x6b8c013d,0x00000000}},	//   _бэут_, únde, _xacg, --, 
   {{0x2d8142be,0xa3c4924b,0x250801b9,0xd6040408}},	//   yeje_, _उतर_, _یرمی_, _дiав, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x628942bf,0x2d8142c0,0x7bc4012d,0x00000000}},	//   _esgo, veje_, _olku, --, 
   {{0x2d8142c1,0xa854011a,0xd370009f,0x00000000}},	//   weje_, סיכה_, _رهت_, --, 
   {{0x2d8142c2,0x5f940c04,0x925942c3,0x600805f5}},	//   teje_, цият, _салт_, рхэг_, 
   {{0x7bc542c4,0x9df81214,0xef1c0790,0xab5800e5}},	//   _alku, инят_, ddüt_, _elül, 
   {{0x2d8142c5,0xfe6c7eee,0xef240036,0x32100073}},	//   reje_, وگی_, üüss_, डगीळ_, 
   {{0x62880f7b,0xe45400c8,0x5ba400cf,0x6e2800e5}},	//   _ysgo, יילט_, оруз, _égbo, 
   {{0xceb84da8,0xa2600208,0xc0e400e5,0x2c00004e}},	// [20210] _сән_, _ngồ, _نہین_, йүүм, 
   {{0x7bc401e4,0x2d800023,0x99d4004b,0x00000000}},	//   _elku, qeje_, يتلا, --, 
   {{0x6d5400ac,0xeef001ed,0xabb0013d,0x4c941422}},	//   _idxa, _ديکھ, _данә, _уинс, 
   {{0x20140228,0x6b8c02d0,0x6ec807f7,0x00000000}},	//   _èxit_, _uacg, हनपु, --, 
   {{0xdcfc00de,0x5fa80073,0xf42401f4,0x00000000}},	//   merā, गातल, öäni_, --, 
   {{0x6830031c,0x00000000,0x00000000,0x00000000}},	//   _aħde, --, --, --, 
   {{0x69c46607,0xdb040174,0xd1f801f3,0x986800e5}},	//   _ilje, mjiá, ለኮት_, _نیلے_, 
   {{0x69c42f61,0xab5800af,0xc24402bf,0xdcfc005f}},	//   _hlje, _olüm, бник, nerā, 
   {{0xdd2c02d5,0x6584100e,0x69c416a3,0xd6c401d9}},	//   vėži, _выез, _klje, _وۅمی, 
   {{0x41a808ca,0x7dc000d7,0x74a8008e,0x00000000}},	//   увон_, _rôso, тсәң_, --, 
   {{0x69c41711,0xf07400dd,0x7dc001f1,0xab58029f}},	//   _mlje, میوں_, _dôsl, _alüm, 
   {{0x7dc001a2,0x6d550a65,0xab580112,0x60300356}},	//   _pôso, _adxa, _blüm, _năme, 
   {{0x69c478d0,0xdcfc005f,0x628805c7,0xe2a80137}},	//   _olje, derā, _usgo, _جاان_, 
   {{0xb6d8008f,0x225c2ba3,0xe41400b8,0x6fe8033f}},	//   אַלט, mruk_, _dṛśī_, ręca, 
   {{0xdb8401b9,0x717000ec,0x8c9400d4,0xdcfc00de}},	//   оҳни, _رهيا, орті, ferā, 
   {{0xab5805d5,0xe53000fd,0xdb2404f2,0x81600345}},	//   _flüm, _mäñğ, زوئی, _بۆگۆ, 
   {{0xeb947edd,0x69c4c75b,0xab5805d5,0xeb3015c3}},	// [20220] щит_, _blje, _glüm, سىلد, 
   {{0x3f9142c6,0x7e640522,0x4ab80816,0xdb0401f4}},	//   _hayu_, mukp, шуся_, kkiö, 
   {{0x3f90ae00,0x7e640d04,0x64540077,0xd8840214}},	//   _kayu_, lukp, áxil, تهای, 
   {{0x3f900309,0x7bc401a6,0x225d42c7,0xef1c1b0d}},	//   _jayu_, _ulku, kruk_, mdür_, 
   {{0x3f9142c8,0xa3a87f1a,0x7e641c06,0x27684d2f}},	//   _mayu_, खान_, nukp, اشمی_, 
   {{0xe3a4034c,0xe1e542c9,0x225c057b,0xb6a41b6d}},	//   _בر_, _رس_, druk_, _қизл, 
   {{0x2bbc16f0,0xef1c47af,0x578400f1,0x2d8400d1}},	//   _एकमा, ndür_, _ودرې, ﻪﺗﻨﻰ_, 
   {{0xa8540302,0x69c401fa,0x7e640784,0xca24247f}},	//   _לילה_, _zlje, kukp, _اۋەن_, 
   {{0xdbdc01e1,0x36c400f7,0x225d42ca,0x69c40076}},	//   _báún, _убаг, gruk_, _ylje, 
   {{0x90547843,0x7e64be79,0xf1a4001b,0xddd40139}},	//   овоц, dukp, срин, _ğaşe, 
   {{0x64a080e2,0x3f900687,0x225c20ac,0x2eb0194b}},	//   _нафа, _bayu_, aruk_, ुन्त, 
   {{0x225c78d0,0x3f900548,0xab5804cc,0xef1c06be}},	//   bruk_, _cayu_, _plüm, ddür_, 
   {{0x3f9142cb,0x39483341,0x2bbc1524,0x225c0098}},	//   _dayu_, _oebs_, _एकबा, cruk_, 
   {{0x30a43a17,0x2bb13e05,0xd0100451,0x3c2c02f0}},	//   _грив, ीस्थ, _ڪلب_, _býv_, 
   {{0x3f90addf,0xdcfd42cc,0x70c4004b,0xebc410fc}},	//   _fayu_, terā, _دهغې_, бљан, 
   {{0x69c41727,0x3f90208d,0xa3a843de,0x00000000}},	//   _slje, _gayu_, खाय_, --, 
   {{0x69c40b91,0x49d80816,0x394801bf,0xdb200241}},	// [20230] _plje, адаю_, _bebs_, _áwìt, 
   {{0x28a4034b,0xcd80030c,0xa8a41367,0xef1c03b9}},	//   йшег, _تۇسۋ, йрек, bdür_, 
   {{0x3f900214,0x660002fb,0x2010012d,0x225c01a9}},	//   _yayu_, vlnk, łnił_, zruk_, 
   {{0x332542cd,0x225c2ac2,0x2e2c03e0,0x29cc031c}},	//   _ngox_, yruk_, _küf_, rżaq_, 
   {{0x394942ce,0xe5300139,0x00000000,0x00000000}},	//   _febs_, _säñğ, --, --, 
   {{0x39480793,0x35a04eb0,0x84580108,0x00000000}},	//   _gebs_, дашг, арит_, --, 
   {{0xddcc0953,0x6b5c01e1,0xd5b80165,0xdcfc0356}},	//   _žiūr, _gàgà, _tiān_, meră, 
   {{0x225d42cf,0x2d90172e,0x76b40724,0x2ca40de2}},	//   truk_, _laxe_, сләр_, _àndu_, 
   {{0x27fd42d0,0x660001a2,0x3f9142d1,0x2b48011c}},	//   _ikun_, plnk, _rayu_, _mecc_, 
   {{0x3f9142d2,0x225d42d3,0x2d9142d4,0x4038001f}},	//   _sayu_, rruk_, _naxe_, _የተገኙ, 
   {{0x3f9142d5,0xc35400a7,0x67f401f2,0x225c7cd8}},	//   _payu_, _дълъ, ụjua, sruk_, 
   {{0x27fc038f,0x7e64020b,0x3f90014f,0x2b487e9e}},	//   _jkun_, tukp, _qayu_, _necc_, 
   {{0xf8a40574,0x2d90005a,0xdb100162,0x290000c0}},	//   _गप्प, _baxe_, _ófød, _lyja_, 
   {{0x2b4804d4,0x3f9142d6,0x00000000,0x00000000}},	//   _aecc_, _wayu_, --, --, 
   {{0x3f9142d7,0xab592295,0xdcfc054e,0x27fc0cad}},	//   _tayu_, _glük, deră, _okun_, 
   {{0x7e640521,0x27fd42d8,0xef1c1432,0x00000000}},	//   pukp, _nkun_, rdür_, --, 
   {{0x2d90102c,0xaf440050,0xba1800e3,0xdcfc0356}},	// [20240] _faxe_, _برى۪, ليرا_, feră, 
   {{0x27fd42d9,0x7dc00109,0x84e8060c,0xdcfc0356}},	//   _akun_, _môsk, टपाट_, geră, 
   {{0x15b4751f,0x2b4800e8,0xe8f44143,0xe9441b12}},	//   ۋەرس, _fecc_, олф_, زرلی, 
   {{0x39484a29,0x290002d3,0xfaa542da,0x02c823c1}},	//   _webs_, _dyja_, _дамо, िनाभ, 
   {{0x2bbc278e,0xdcfc054e,0x290009e8,0xdb040139}},	//   _एकता, beră, _eyja_, djiç, 
   {{0x27fc0248,0x00000000,0x00000000,0x00000000}},	//   _ekun_, --, --, --, 
   {{0xab580e78,0x20000036,0x29000064,0x00000000}},	//   _blüh, _okii_, _gyja_, --, 
   {{0x2b4800e8,0x883401c6,0x8c4800a2,0x292403e0}},	//   _xecc_, _хэрц, luşý, ğtaş_, 
   {{0xe3ac082e,0xa3d805f9,0x66e002dd,0x00000000}},	//   ضري_, _डगर_, _жота, --, 
   {{0x200142db,0x00000000,0x00000000,0x00000000}},	//   _akii_, --, --, --, 
   {{0xeb0419e5,0x2e2c01b8,0xeabcf483,0xab5803b9}},	//   _शर्त_, _süf_, _ngùn_, _qlük, 
   {{0x2d9142dc,0xa3a80490,0xab583262,0x2e2c05d1}},	//   _saxe_, खाण_, _glüh, _püf_, 
   {{0xceb80831,0xd5b80418,0xaca002e3,0x69c80ea0}},	//   сәй_, _koā_, _mpụg, ëgek, 
   {{0xf1a87cbc,0x2000b137,0xe73c000d,0x451000eb}},	//   _خاصه_, _ekii_, _õõv_, _স্টক_, 
   {{0x2b480de2,0x2bbc0490,0xeb48009b,0x00000000}},	//   _pecc_, _एकदा, ичак_, --, 
   {{0x2d910114,0x29003f05,0x35800092,0xdcfc00ef}},	//   _waxe_, _ryja_, ረሱበት_, edrē, 
   {{0x2d9142dd,0xad2542de,0xb4c40316,0xa3a80490}},	// [20250] _taxe_, _وردو, उनु_, खात_, 
   {{0xaca001f2,0x68300135,0x20501945,0x2b4800e8}},	//   _apụg, _aħda, _этәр, _wecc_, 
   {{0x2b4800e8,0x52b80073,0x00000000,0x00000000}},	//   _tecc_, ेनुस, --, --, 
   {{0xc5f400dc,0xdcfc0356,0x00000000,0x00000000}},	//   ेत्य_, seră, --, --, 
   {{0xdcfc054e,0xfb340677,0x375005af,0x00000000}},	//   peră, _מארש_, رپوس, --, 
   {{0x3ab800d9,0xb0c800cd,0x00000000,0x00000000}},	//   _המשנ, ानाग, --, --, 
   {{0x27fc1f21,0xd83805f5,0xddc400dc,0x187408da}},	//   _tkun_, _мэт_, _aviś, _огря, 
   {{0x27fd42df,0xc244cb3d,0x3988012d,0x00000000}},	//   _ukun_, пник, rósł_, --, 
   {{0xa2a80a59,0x41d800cd,0x00000000,0x00000000}},	//   जमध्, योऽस, --, --, 
   {{0xddc4002b,0x69c8017a,0x5bb81cd2,0x7dc00208}},	//   _dviś, ëgeh, _इक्व, _gôsh, 
   {{0x41040510,0x00000000,0x00000000,0x00000000}},	//   язов, --, --, --, 
   {{0x6030054e,0x00000000,0x00000000,0x00000000}},	//   _căma, --, --, --, 
   {{0x46bc3347,0xe7f00037,0x00000000,0x00000000}},	//   ्निह, _अदना_, --, --, 
   {{0xd24401c6,0x62980051,0x00000000,0x00000000}},	//   _цэци, mvuo, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x20000270,0xbc1801ec,0xc848069d,0x629801f4}},	//   _ukii_, сігі_, _ምሁራን, ovuo, 
   {{0x629802f6,0x6b600024,0x20400092,0xa0a001a9}},	// [20260] nvuo, экта, _የተባረ, _хақд, 
   {{0x9d5404d3,0xefd0001f,0x4de402dd,0xbd880244}},	//   _زۆرت, _ከጊዜ_, _ойың, _اندن_, 
   {{0x77845211,0x3e74365a,0xd9112b63,0x00000000}},	//   злез, læt_, ئیز_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc6143857,0xca7400c7,0x00000000,0x00000000}},	//   াদনা_, _оуры, --, --, 
   {{0x7c240221,0x46380212,0x35b428e8,0x427c0092}},	//   _hikr, іччя_, ящес, ጣይነት_, 
   {{0xf74542e0,0xb4c4038e,0x7c240451,0x39a00139}},	//   _нево, उने_, _kikr, _eçsä_, 
   {{0x779142e1,0x7c2542e2,0x32640828,0x12d401ec}},	//   _سیتا, _jikr, птов, _ﺘﻁﻭﺭ, 
   {{0xe3ad42e3,0xf1a8d36d,0x6030084c,0x2bbc25fe}},	//   ارى_, ماده_, _răma, _एकसा, 
   {{0x7c2542e4,0x7dc00109,0xa63802e4,0xd7880137}},	//   _likr, _fôsi, _לגמר, _دەچۉ_, 
   {{0x7c240076,0x61ec06af,0xd0d402e8,0x629801f4}},	//   _oikr, écla, фонъ, avuo, 
   {{0x7c245f6c,0xc1540092,0x00000000,0x00000000}},	//   _nikr, _መጠየቃ, --, --, 
   {{0x71a542e5,0xd00801e0,0x62980051,0xabb000c7}},	//   _надз, йеүе_, cvuo, ҭагә, 
   {{0x9e7415bf,0x00000000,0x00000000,0x00000000}},	//   رۇپت, --, --, --, 
   {{0x7c2542e6,0x60300356,0x4f840014,0xebc40063}},	//   _bikr, _tăma, _ہاکہ, пљан, 
   {{0xf1a803e6,0x8f5401d3,0x00000000,0x00000000}},	//   _خاڵه_, _کنکش, --, --, 
   {{0x61e800dd,0x7a14007f,0x1bd400f5,0x7cb40092}},	// [20270] _állí, _pņtp, хотя, ፈላለግ_, 
   {{0x9aa4c344,0xeb9c00b5,0x7c24143a,0x2bbc01bc}},	//   عملو, _skød_, _eikr, _एकवा, 
   {{0x7c2542e7,0xc79402dd,0x9a2400e5,0x00000000}},	//   _fikr, дрлы, رٹمن, --, 
   {{0x7c240230,0x62980024,0xab580205,0xb4c400bc}},	//   _gikr, yvuo, _alüv, उनै_, 
   {{0x7dc005da,0x920c05f9,0xa3a80073,0x9a84edb4}},	//   _sôsi, हताज_, खास_, _пурл, 
   {{0xb6a006b3,0x1db000dc,0x1a6803e6,0xe61001d5}},	//   тишл, ञायत, _ریمی_, رشش_, 
   {{0xe4a400f7,0x441400d8,0x00000000,0x00000000}},	//   ярдо, мфит, --, --, 
   {{0x7c240564,0xd8385ce3,0xd7940395,0x629801f4}},	//   _xikr, _хэр_, _писъ, tvuo, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x62980024,0x3e7401bf,0x00000000,0x00000000}},	//   rvuo, væt_, --, --, 
   {{0x9fa00c6a,0x6298023a,0x00000000,0x00000000}},	//   _héés_, svuo, --, --, 
   {{0x3e74037e,0x80780116,0xb4f8011a,0x34f8011a}},	//   tæt_, ббүс_, _ופעי, _והעד, 
   {{0x7c2542e8,0x7e740113,0x230800cf,0x00000000}},	//   _rikr, _qqyp, _اتاي_, --, 
   {{0x7c2542e9,0x3e74037e,0xf28400ec,0x02c807b7}},	//   _sikr, ræt_, _آھيو_, िनीन, 
   {{0x3e7404ce,0x3b9403b7,0x7c2542ea,0xc30400cc}},	//   sæt_, мјат, _pikr, _উলটি_, 
   {{0xbd4405d9,0xfaa401b9,0x7ff4007b,0x00000000}},	//   _ڪندي, мабо, _تستا, --, 
   {{0x7c2542eb,0x2bbcc4dd,0x9fa001c7,0x2bdc1221}},	// [20280] _vikr, _एकरा, _néés_, _नगरा, 
   {{0x7c240687,0x98f400d1,0xd9b4075e,0x00000000}},	//   _wikr, ىغاچ, رەزد, --, 
   {{0x7c2542ec,0x8cb41d8a,0x2fd400f2,0x00000000}},	//   _tikr, _उपयो, _روید_, --, 
   {{0x9fa000e8,0xb0b4008f,0xf0b4010f,0xf7440117}},	//   _béés_, ופעס_, ולער_, федо, 
   {{0x667050e4,0xab5805d5,0x12e8015b,0xf6543b8f}},	//   ندور, _plüv, _পর্দ, фтею, 
   {{0xe5a04d47,0x60300356,0x00000000,0x00000000}},	//   кичи, _nămo, --, --, 
   {{0x69208b88,0x52b809ab,0x533441e5,0x89a801d9}},	//   _амра, ेन्स, нейт, _ژھۅہ_, 
   {{0x7c2800d8,0xf2c401c6,0x00000000,0x00000000}},	//   _éfru, дсон, --, --, 
   {{0x8cb43b90,0x00000000,0x00000000,0x00000000}},	//   _उपभो, --, --, --, 
   {{0xe29c008c,0xdd1400d7,0x00000000,0x00000000}},	//   æða_, dĺžo, --, --, 
   {{0x91d40034,0x6fe80210,0x00000000,0x00000000}},	//   योगै, lęci, --, --, 
   {{0x72c42082,0x32c8023a,0x9fa000e8,0xf0fc01f9}},	//   _обез, _мыло_, _yéés_, _उडीद_, 
   {{0xa3a80c2e,0x7640037e,0x88d400b8,0x7c3c139f}},	//   खार_, npoy, _hṛtk, _atpr, 
   {{0x4c94e3cc,0xa2a8216a,0xdcfc00c0,0x00000000}},	//   нигс, जमर्, ndrė, --, 
   {{0xdcfc00c0,0x6fe80210,0xabb00022,0x00000000}},	//   idrė, hęci, ҭаҳә, --, 
   {{0xcbcc00bd,0x60280066,0xd0104363,0x70c835e0}},	//   রচ্ছ, rèmè, _حلب_, ानील, 
   {{0x6fe8006d,0xda78fc21,0x7c3c02d0,0x00000000}},	// [20290] jęci, дях_, _etpr, --, 
   {{0x7c3c00e4,0x627402e4,0x5d540139,0x7c38008f}},	//   _ftpr, וגמא_, _икьт, ŭtra, 
   {{0x6d4542ed,0xab5803fa,0x29040008,0x9fa00036}},	//   mbja, _blüt, æna_, _séés_, 
   {{0x6d4542ee,0xaba404b3,0x69c8002d,0x57a40124}},	//   lbja, _تۇرم_, êgeb, ҵшәа, 
   {{0xb9047f1a,0x1dd840bf,0x00000000,0x00000000}},	//   _बे_, _ربیع_, --, --, 
   {{0xfa8802d3,0x3f9c02b5,0x97a42cc8,0x12e803d4}},	//   _ምርኣይ_, ētui_, ерәл, _পৰ্দ, 
   {{0xab5942ef,0x9fa004e6,0x774003e6,0xa3a942f0}},	//   _flüt, _wéés_, _ڕێنم, खाल_, 
   {{0xab5821c6,0xd7f942f1,0x176800cf,0xd1380210}},	//   _ilüs, _жуу_, _оруп_, ecą_, 
   {{0x7e84013f,0xb38039fb,0x42246d5f,0x224801c7}},	//   _kɔpe, улыл, ндив, èck_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x14749fb1,0x81441079,0xd498009d,0x00000000}},	//   _لانج, ونکن, _орц_, --, 
   {{0x644142f2,0x14d80490,0xa3a80073,0x00000000}},	//   mpni, _भेटण, खाळ_, --, 
   {{0x63a942f3,0x3f9c00bc,0x64408aac,0x53342d4f}},	//   _ingn, ětu_, lpni, _речт, 
   {{0x68300327,0x644005ac,0x051003d4,0x6d4402d2}},	//   _aħdm, opni, াশীৰ_, gbja, 
   {{0xb0400016,0xd1b81367,0x6fe8012d,0x00000000}},	//   _trưở, _تانا_, zęci, --, 
   {{0x644142f4,0x6444031c,0x21280118,0x00000000}},	//   ipni, _ħjil, ěchu_, --, 
   {{0xdc880023,0x6d44072d,0x00000000,0x00000000}},	// [202a0] _ምፍራይ_, bbja, --, --, 
   {{0x67380083,0xef14b40e,0x224802f0,0x6eac00bc}},	//   _afuj, _ямы_, ácky_, ुहरु, 
   {{0xab5942f5,0xfce542f6,0x63a942f7,0x7dc000d0}},	//   _plüt, _чоно, _ongn, _dôst, 
   {{0x93bc054e,0xe7340064,0x00000000,0x00000000}},	//   _luăr, еец_, --, --, 
   {{0x56944889,0xd1380210,0x00000000,0x00000000}},	//   талт, ycą_, --, --, 
   {{0xab580730,0x63a942f8,0x67385cb6,0x4b500014}},	//   _flüs, _angn, _efuj, _مێہر, 
   {{0x66700075,0xab5807c5,0xa3a83ee1,0xb0dc2232}},	//   ندۈر, _glüs, खां_, _फेंग, 
   {{0xd138033f,0xa8780a7c,0x00000000,0x00000000}},	//   wcą_, _מאלר, --, --, 
   {{0x6440002d,0x6fac2d81,0x00000000,0x00000000}},	//   apni, टासं, --, --, 
   {{0x63a8009a,0x649401e0,0xe57400d8,0x00000000}},	//   _engn, фтәр_, _пзу_, --, 
   {{0x317c009f,0xddcc03e0,0x6d4406ea,0xd1380210}},	//   rftz_, _şişt, vbja, rcą_, 
   {{0xa3a800cd,0xef1c03e0,0xc0c004b4,0x00000000}},	//   खाः_, mdüz_, рәши, --, 
   {{0xd25000db,0x5e8400d8,0x15e4023e,0x00000000}},	//   _ئنت_, лурз, _कगार_, --, 
   {{0xa190049e,0x00000000,0x00000000,0x00000000}},	//   _башч, --, --, --, 
   {{0xef1c1ae4,0x63a80076,0xf1a40a8a,0x00000000}},	//   ndüz_, _yngn, _कोयन, --, 
   {{0x321c007f,0x6d440fc7,0x00000000,0x00000000}},	//   lmty_, sbja, --, --, 
   {{0x7dc142f9,0xdc740124,0x0e141fbe,0x00000000}},	// [202b0] _pôst, _ҩыџь, _имиџ, --, 
   {{0xab5942fa,0x64401445,0x20400092,0x00000000}},	//   _plüs, ypni, _የተቀረ, --, 
   {{0x2ac40241,0x00000000,0x00000000,0x00000000}},	//   _bíbú_, --, --, --, 
   {{0x7e84013f,0xbcb4011a,0x00000000,0x00000000}},	//   _wɔpe, _ספרו_, --, --, 
   {{0xab58013d,0xad245035,0x69c8017a,0x00000000}},	//   _flür, _ترکو, ëges, --, 
   {{0xeabc004d,0xe9dc02d2,0x00000000,0x00000000}},	//   _ngùi_, _stúf_, --, --, 
   {{0x02c80882,0xf1b80051,0xf5300798,0x00000000}},	//   िन्न, _giơi_, шејќ, --, 
   {{0x644142fb,0x673801f7,0x514402dd,0x3d1c00fe}},	//   rpni, _ufuj, ңдығ, বুক্_, 
   {{0xa2805a51,0xa5e40220,0xd9d40137,0x644001e3}},	//   ایتو, _كورە_, _جەەگ, spni, 
   {{0x644142fc,0x00000000,0x00000000,0x00000000}},	//   ppni, --, --, --, 
   {{0x660142fd,0xf07401ed,0x7f440220,0x00000000}},	//   monk, نیوں_, кенж, --, 
   {{0x66002747,0x63a942fe,0x237c0369,0x34b40375}},	//   lonk, _ungn, qfuj_, _בפעם_, 
   {{0x29cc031c,0x66000037,0x00000000,0x00000000}},	//   bżax_, oonk, --, --, 
   {{0x66001311,0x00000000,0x00000000,0x00000000}},	//   nonk, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x660142ff,0x7dc005d5,0x7c3800df,0x00000000}},	//   honk, _pôss, ŭtro, --, 
   {{0x1ee850c9,0xaca0010e,0xab5803b9,0xe4e00037}},	// [202c0] _سودی_, _baỳd, _plür, _केसि_, 
   {{0x6600000f,0xdcfc00da,0x00000000,0x00000000}},	//   jonk, ndrī, --, --, 
   {{0x66014300,0xdcfc005f,0x69c001e3,0x00000000}},	//   donk, idrī, önea, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa3a809d9,0xb4a800dc,0x660085aa,0x3f800009}},	//   खाई_, खम्_, fonk, ifku_, 
   {{0x66014301,0xe4e00316,0xb86416ac,0xaca0010e}},	//   gonk, _केहि_, _لارو, _gaỳd, 
   {{0xb7d80046,0xe0c40137,0xab5803e0,0x00000000}},	//   _قوسا_, _ئز_, _klüp, --, 
   {{0x7bd54302,0xdcfc00e2,0x29cc0327,0x00000000}},	//   nhyu, edrī, wżax_, --, 
   {{0x76254303,0x66002939,0xd0481870,0x00000000}},	//   _амаз, bonk, ﯩﺘﯩﭗ_, --, 
   {{0x66000286,0xf1a412e7,0x35a40022,0x645001d3}},	//   conk, трин, _шазг, údió, 
   {{0x7bd54304,0x7d18022c,0x00000000,0x00000000}},	//   khyu, ýtsl, --, --, 
   {{0xd5b800b8,0x68e000e4,0x00000000,0x00000000}},	//   _bhāg_, úndi, --, --, 
   {{0xdbdc09f3,0x63000133,0x00000000,0x00000000}},	//   _ráðn, _پوول, --, --, 
   {{0x3f800009,0x30a4005a,0x00000000,0x00000000}},	//   afku_, _арив, --, --, 
   {{0x5d542309,0xe7f0012d,0x00000000,0x00000000}},	//   ркст, _अदला_, --, --, 
   {{0x66014305,0xef6406bb,0xa3a85d4f,0x00000000}},	//   zonk, _ръко, खाए_, --, 
   {{0x66014306,0x7e60168c,0xaca00241,0xd5b80055}},	// [202d0] yonk, _åopp, _isọg, _khād_, 
   {{0xe8e81176,0x00000000,0x00000000,0x00000000}},	//   وراو_, --, --, --, 
   {{0x660007a9,0x7bd400dc,0x0ce000cc,0x00000000}},	//   vonk, bhyu, _মুৰত, --, 
   {{0x66003917,0x2d800d27,0x7bd4003e,0x9f6001d3}},	//   wonk, lfje_, chyu, őrös_, 
   {{0xd7c8182f,0x68f80882,0xe8b40327,0x1da807f7}},	//   خونه_, _śudd, དདངག, _छोडत, 
   {{0x09ac015b,0x9a852da5,0xd6c40075,0xdb0400a2}},	//   _গতকা, _туюл, ришқ, njiý, 
   {{0x66014307,0x2d8001f5,0xc92000fe,0x00000000}},	//   ronk, ifje_, _প্ৰত_, --, 
   {{0x6600bb20,0x76b4c7e0,0x97a40064,0x00000000}},	//   sonk, тләр_, _крул, --, 
   {{0x56954308,0x6600151c,0x823465d7,0x963413d6}},	//   _катт, ponk, دربا, _внуц, 
   {{0xe5701aa3,0x2d800d27,0x66014309,0x36240014}},	//   _خطر_, jfje_, qonk, _موقہ, 
   {{0x80ac03f3,0xd5b80055,0x41d800cd,0x00000000}},	//   टमें, _dhād_, योगस, --, 
   {{0xeb9c04ce,0x2d800d27,0xbe6801c6,0xd3340139}},	//   _skøn_, efje_, намж_, _кэшы, 
   {{0x63b9430a,0xee3400a7,0x60300311,0xdce80205}},	//   mjun, лня_, _mămi, _ılık, 
   {{0x63b9430b,0xfce5430c,0x90e44144,0xcdf40166}},	//   ljun, гого, اسین, ачсы, 
   {{0x7bd44429,0x63b800b5,0x00000000,0x00000000}},	//   thyu, ojun, --, --, 
   {{0x63b9430d,0xb7bc2158,0xeb94cc5a,0x2d8001a4}},	//   njun, _অষ্ট, лис_, afje_, 
   {{0x63b8013c,0xe7f400e1,0x4b5400a7,0xbea43edd}},	// [202e0] ijun, ंचना_, ръст, _сапк, 
   {{0x7bd44c99,0x63b82b1d,0xfd4802bf,0xc9440116}},	//   shyu, hjun, _язок_, идуқ, 
   {{0x394400c8,0x63b809f3,0x7bd402c4,0x3e50007f}},	//   ĝos_, kjun, phyu, lņt_, 
   {{0x60300311,0x6289430e,0x63b9430f,0x394400df}},	//   _cămi, _opgo, jjun, ŝos_, 
   {{0x7f5427b3,0x63b94310,0x3864002e,0x00000000}},	//   _meyq, djun, ōor_, --, 
   {{0x7f540309,0x00000000,0x00000000,0x00000000}},	//   _leyq, --, --, --, 
   {{0x39594311,0xf48405f5,0x48780276,0x63b808a5}},	//   maps_, уулн, _истя_, fjun, 
   {{0x63b92ee9,0x00000000,0x00000000,0x00000000}},	//   gjun, --, --, --, 
   {{0xd1300597,0x68e000d2,0x05840014,0xdcfc00df}},	//   يمة_, úndv, _چشمَ, verĝ, 
   {{0x63b80eda,0x60300356,0x00000000,0x00000000}},	//   ajun, _zămi, --, --, 
   {{0xddc4010e,0x1c04141f,0xc4c54312,0x3384011c}},	//   _itiň, लवाल_, _پتلو, _булв, 
   {{0x09c070b0,0xe48c02d3,0x39585880,0xdc880023}},	//   _शक्य, _መርኣያ_, haps_, _ምልላይ_, 
   {{0x39586194,0xdef94313,0xceb829db,0x7f5406be}},	//   kaps_, гыр_, тәй_, _deyq, 
   {{0x23244b7d,0xf074013d,0xdcfc01e4,0x9e340798}},	//   _сочи_, _бикә_, serĝ, серч, 
   {{0xa1540302,0x2d8001f5,0x4c940212,0x5184022e}},	//   _גבוה_, rfje_, шивс, _буқа, 
   {{0x7e84016b,0x00000000,0x00000000,0x00000000}},	//   _wɔpa, --, --, --, 
   {{0x98b80064,0x6e280241,0x00000000,0x00000000}},	// [202f0] _kerė_, _ègbo, --, --, 
   {{0x99540276,0x00000000,0x00000000,0x00000000}},	//   йкуц, --, --, --, 
   {{0x63b80cc0,0x473400c0,0xa8a41999,0x98b800c0}},	//   yjun, анес, ырак, _merė_, 
   {{0x15b80184,0x39580036,0x6d554314,0x2bbc0073}},	//   ғышы_, aaps_, _hexa, _एकटा, 
   {{0x6d5401c6,0x69d4022f,0x395800db,0x58840220}},	//   _kexa, phxe, baps_, _қыра, 
   {{0x39594315,0x6d5400e8,0x5e58008f,0xef1c0165}},	//   caps_, _jexa, ריגע_, leüs_, 
   {{0x63b94316,0x6d54fd96,0xd918994d,0x044401c4}},	//   tjun, _mexa, _борц_, шейн, 
   {{0x6d554317,0x63b80140,0xddc400a2,0x999800a2}},	//   _lexa, ujun, _etiň, _kirş_, 
   {{0xd7f94318,0x7f5406be,0xb7c000b8,0x00000000}},	//   _сур_, _reyq, _ũãgh, --, 
   {{0x6d5476eb,0xbbd006ff,0x008400f7,0x7f54014f}},	//   _nexa, _सत्क, алоо, _seyq, 
   {{0xf9900302,0xd4e54319,0xa1c001ec,0x00000000}},	//   חרי_, _люци, _ғұнд, --, 
   {{0x40340032,0x6d540332,0xff241c35,0xa3a8012d}},	//   леүс, _aexa, имно, खाओ_, 
   {{0x9404e549,0x6d55431a,0x2bbc54cb,0x00000000}},	//   _اونه, _bexa, _एकजा, --, 
   {{0xda14000d,0xdcfc0139,0x225c00a2,0x00000000}},	//   _तींत_, gerğ, msuk_, --, 
   {{0x225c0548,0x7de401ec,0x00000000,0x00000000}},	//   lsuk_, гіңд, --, --, 
   {{0x3958020b,0xbc180220,0x6d540067,0xbadc00eb}},	//   waps_, тігі_, _eexa, _ভুগছ, 
   {{0xeb95431b,0x225d431c,0x6d54002e,0x7ed404d3}},	// [20300] шит_, nsuk_, _fexa, _ڕزگا, 
   {{0xe9d5431d,0x6d54102c,0xa040001f,0xb86416ac}},	//   аку_, _gexa, _የተነሳ, لاصو, 
   {{0xd91060b3,0x2bbc02c3,0x00000000,0x00000000}},	//   سیر_, _एकचा, --, --, 
   {{0x225d431e,0x39580b6f,0x6d5401e2,0x9f440100}},	//   ksuk_, saps_, _zexa, òmè_, 
   {{0xeb940801,0x3695431f,0x6d55289a,0xec100133}},	//   _тия_, ршес, _yexa, _گوێد, 
   {{0xf488005b,0x00000000,0x00000000,0x00000000}},	//   вщик_, --, --, --, 
   {{0xdff828d4,0x00000000,0x00000000,0x00000000}},	//   ीवाद_, --, --, --, 
   {{0xb9f002d3,0xe9dc00c7,0x80a828d4,0x05b402dd}},	//   _ዞም_, _itúa_, टिने, _ۇگىت_, 
   {{0xdb10014a,0xf1a92914,0x00000000,0x00000000}},	//   _äfäg, ناده_, --, --, 
   {{0x60300311,0x31c54320,0x91b8af15,0xef1c0165}},	//   _lămu, рсив, угот_, zeüs_, 
   {{0x225c0194,0x6d540108,0x00000000,0x00000000}},	//   asuk_, _rexa, --, --, 
   {{0x6d554321,0x2254004b,0xf18c0150,0x733400d1}},	//   _sexa, _چلند_, _ﺒﻤﻬﻤ_, _ئىشا, 
   {{0x6d55153e,0xab5800a2,0xe7f400e1,0x00000000}},	//   _pexa, _boün, ंचता_, --, 
   {{0x71700220,0x00000000,0x00000000,0x00000000}},	//   _بۇدا, --, --, --, 
   {{0x6d554322,0x61ec07ea,0xd9cc015b,0x6218011a}},	//   _vexa, ècle, লফাম, _שווק, 
   {{0x6d54009a,0x00000000,0x00000000,0x00000000}},	//   _wexa, --, --, --, 
   {{0x6d554323,0x00000000,0x00000000,0x00000000}},	// [20310] _texa, --, --, --, 
   {{0xe29c31ac,0xa8a54324,0xc95859e1,0x6d540381}},	//   æði_, ирек, الاش_, _uexa, 
   {{0x9a880014,0xf8b4004e,0x00000000,0x00000000}},	//   ُنہٕ_, бөт_, --, --, 
   {{0x225c0548,0x00000000,0x00000000,0x00000000}},	//   ysuk_, --, --, --, 
   {{0xfbb4011a,0xc688009d,0x00000000,0x00000000}},	//   _הפרת_, уйлж_, --, --, 
   {{0xaca002e3,0x80a861ef,0x00000000,0x00000000}},	//   _ndịd, टिमे, --, --, 
   {{0xa4901550,0x00000000,0x00000000,0x00000000}},	//   تیات, --, --, --, 
   {{0x225c01d3,0x00000000,0x00000000,0x00000000}},	//   tsuk_, --, --, --, 
   {{0xa5641b8f,0x64a00220,0xc6f80b2c,0xc7a404b4}},	//   _ندان, сақа, _снах_, _киңк, 
   {{0x225d4325,0x41b40884,0xd6280063,0x7c380115}},	//   rsuk_, ссит, _вође_, ŭtri, 
   {{0x225d4326,0x95c84eca,0x054401af,0x00000000}},	//   ssuk_, _тута_, _күҙл_, --, 
   {{0xcdc8025f,0xc88403e0,0x00000000,0x00000000}},	//   _אך_, maşı_, --, --, 
   {{0xdb241ae4,0x225c031c,0xc8844283,0x0244009f}},	//   üsün, qsuk_, laşı_, _اَتَ, 
   {{0x7e84013f,0xddd40030,0x6220030c,0xd1b800f2}},	//   _wɔpo, ťažo, _بوتە, _پاها_, 
   {{0xc88400ac,0xdcfc01a6,0x2fd450d8,0x7f740064}},	//   naşı_, terđ, _گويد_, _лупц, 
   {{0xfe4400d8,0x00000000,0x00000000,0x00000000}},	//   _лнио, --, --, --, 
   {{0xbdf94327,0xcee80451,0xa0640150,0x00000000}},	// [20320] _مردا_, _پرين_, _сақа_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfbd0951c,0x0c040014,0x00000000,0x00000000}},	//   _فتح_, _ژوپُ, --, --, 
   {{0xc88447af,0xe4f800bc,0x864c0240,0x00000000}},	//   daşı_, एपनि_, _ዝተኸድ, --, 
   {{0x7bc40083,0xb6f819c5,0x00000000,0x00000000}},	//   _ioku, دىشا_, --, --, 
   {{0x7bc54328,0x00000000,0x00000000,0x00000000}},	//   _hoku, --, --, --, 
   {{0xe9d54329,0x00000000,0x00000000,0x00000000}},	//   _укр_, --, --, --, 
   {{0x7bc5432a,0x00000000,0x00000000,0x00000000}},	//   _joku, --, --, --, 
   {{0x7bc5432b,0xe1ed13e2,0x7228009d,0x00000000}},	//   _moku, کسي_, лцов_, --, 
   {{0x7bc42ffc,0x9f400086,0xc88443dd,0x32fc01f2}},	//   _loku, _amià_, başı_, ịyo_, 
   {{0x7bc5432c,0xf1a835cd,0x1c080764,0x30e401ec}},	//   _ooku, ناگه_, वकाल_, сіпб, 
   {{0x7bc51c96,0x4e1000ab,0xf1a80133,0x00000000}},	//   _noku, _दीजै_, _ڕابه_, --, 
   {{0xdcfc02b5,0xb8d8031c,0x925801c6,0x5f940395}},	//   kerē, _ཆཌ_, _талт_, чият, 
   {{0x270401dc,0x7bc44ede,0xe9dc307d,0x00000000}},	//   ống_, _aoku, _atún_, --, 
   {{0x7bc53f82,0xdcfc005f,0xab580166,0x00000000}},	//   _boku, derē, _ilüz, --, 
   {{0x4a540006,0x7bc5432d,0x00000000,0x00000000}},	//   жкас, _coku, --, --, 
   {{0x5a341768,0x9be40212,0xdf0801c6,0x271405dc}},	// [20330] знут, чірк, _гээл_, _तरेर_, 
   {{0x4c9400c7,0x7bc5432e,0xdb1400a2,0xeb3000cf}},	//   _диос, _eoku, _çaýa, تۉڭد, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7bc5432f,0xc884029f,0x7d18000d,0x00000000}},	//   _goku, vaşı_, ütse, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7bc429e5,0xdcfc005f,0x9628007b,0x00000000}},	//   _zoku, cerē, مكنك_, --, 
   {{0x7bc53385,0x00000000,0x00000000,0x00000000}},	//   _yoku, --, --, --, 
   {{0xc2454330,0x69c54331,0x7bc40724,0x00000000}},	//   оник, _hoje, _xoku, --, 
   {{0x69c404b9,0x85b94332,0x00000000,0x00000000}},	//   _koje, _клас_, --, --, 
   {{0x27ec8c75,0x80641de1,0x8c000154,0xc1e8009d}},	//   lign_, овож, ্ষিন_, рдож_, 
   {{0x69c410b3,0xd5b94333,0xcea802e4,0x26cc00c0}},	//   _moje, _уст_, _שי_, lygo_, 
   {{0x27ecbed5,0x69c54334,0x94740244,0x42d40064}},	//   nign_, _loje, _ردما, _мілу, 
   {{0x7bc54335,0x7c2804cc,0xab580139,0x7f18155b}},	//   _roku, _èfri, _flüz, ріну_, 
   {{0x7bc4fd68,0x69c54336,0xed5411ac,0x4128ff8f}},	//   _soku, _noje, жор_, _коло_, 
   {{0x7bc54337,0xc05800db,0xb2240451,0x0244009f}},	//   _poku, _ئشتا_, _بڻيل_, _اَڪَ, 
   {{0x7bc40309,0x3d1800af,0x1b040131,0xd24c0345}},	//   _qoku, _धरीं_, зүмн, _جۆی_, 
   {{0x7bc405b8,0xb9e80209,0x27ec05d5,0x39e80063}},	// [20340] _voku, амаз_, dign_, адао_, 
   {{0x6e90cc7b,0x69c54338,0x26cc3f05,0xfd10007b}},	//   _کلیا, _coje, dygo_, _يجد_, 
   {{0x69c4341a,0x7bc54339,0x4d14a318,0x62980810}},	//   _doje, _toku, _ньют, hwuo, 
   {{0x510c04ac,0x7bc4009a,0x629801f2,0x27ec07c5}},	//   נהאַ, _uoku, kwuo, gign_, 
   {{0x69c5433a,0xca742cc8,0x00000000,0x00000000}},	//   _foje, _нуры, --, --, 
   {{0x69c5433b,0xafe403b2,0x746810d6,0x00000000}},	//   _goje, _knøð, арив_, --, 
   {{0xe9640c60,0x00000000,0x00000000,0x00000000}},	//   _фасл_, --, --, --, 
   {{0x3264a5ce,0x69c40200,0x00000000,0x00000000}},	//   отов, _zoje, --, --, 
   {{0xc6440372,0x00000000,0x00000000,0x00000000}},	//   _فئلى, --, --, --, 
   {{0x27300051,0x00000000,0x00000000,0x00000000}},	//   _ảng_, --, --, --, 
   {{0x4db42b1b,0x00000000,0x00000000,0x00000000}},	//   ুসমূ, --, --, --, 
   {{0xe3a40014,0x00000000,0x00000000,0x00000000}},	//   _وشنی, --, --, --, 
   {{0x71a40064,0x00000000,0x00000000,0x00000000}},	//   _мадз, --, --, --, 
   {{0x2b5c01a6,0x27ece0c9,0xceb800fb,0x8244030d}},	//   _žuc_, zign_, _ғәм_, _хĕрч, 
   {{0x69c5433c,0xa174025f,0x271401ad,0x00000000}},	//   _roje, _ועוד_, _तर्र_, --, 
   {{0x69c5433d,0x00000000,0x00000000,0x00000000}},	//   _soje, --, --, --, 
   {{0x69c48ead,0xdb041497,0x27ec05d5,0xee3c02f0}},	// [20350] _poje, ndiè, vign_, ovým_, 
   {{0x7d1807c5,0xda7001d9,0x294800d8,0x00000000}},	//   ütsc, کُے_, рџан_, --, 
   {{0xe7f4069f,0x69c5433e,0xd1440023,0x26cc015d}},	//   ंचला_, _voje, _የጠቓል, wygo_, 
   {{0x69c4068f,0x798c2f63,0xab58014a,0x00000000}},	//   _woje, _ebbw, _moük, --, 
   {{0x69c4035b,0x78ac03ac,0x27ed433f,0x78000107}},	//   _toje, _erbv, rign_, хӯра, 
   {{0x27ec011a,0x6034054e,0x6aac0205,0x84580835}},	//   sign_, _lămp, _ircf, брит_, 
   {{0x5924031c,0x98480d1d,0x43685a8e,0x00000000}},	//   _འཛགས_, _мята_, байн_, --, 
   {{0xb60001a8,0x00000000,0x00000000,0x00000000}},	//   ðárk, --, --, --, 
   {{0x37d8008f,0xa260004d,0x48f4012c,0x69c8002d}},	//   _פֿלע, _giố, ्थको_, êgew, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd26400db,0x00000000,0x00000000,0x00000000}},	//   пкөй, --, --, --, 
   {{0xc0e40201,0xc5bc04c5,0x00000000,0x00000000}},	//   _ምክር_, _অতিপ, --, --, 
   {{0xc32800c6,0x27e400d7,0x00000000,0x00000000}},	//   _اكشن_, énny_, --, --, 
   {{0xee4400ee,0x27fd4340,0x00000000,0x00000000}},	//   ýýar_, _ljun_, --, --, 
   {{0x6b8c4539,0x6aac00e5,0x00000000,0x00000000}},	//   _bbcg, _arcf, --, --, 
   {{0x27fc0427,0x2d84496e,0x00000000,0x00000000}},	//   _njun_, _önen_, --, --, 
   {{0x5924025c,0xba1802eb,0xbe6400ec,0x00000000}},	// [20360] _འཛངས_, ميرا_, _عهدي, --, 
   {{0xdb0471da,0x27fd4341,0xdee408ca,0x5eb40154}},	//   ndié, _ajun_, _ноқи, ুনদে, 
   {{0x6aac03ac,0x6d380375,0xe94401b9,0xbb440395}},	//   _ercf, _לתינ, سرلی, _ненк, 
   {{0xf1b801fb,0x999801d9,0xae640345,0x00000000}},	//   _nhơn_, _ژھار_, _بڕێن_, --, 
   {{0x27fc0135,0x6cd00046,0x7e64072b,0x24e40075}},	//   _djun_, _يقۋا, nskp, үмчи_, 
   {{0x7c3d4342,0x00000000,0x00000000,0x00000000}},	//   _kupr, --, --, --, 
   {{0x20000521,0x7c3c0098,0xeb9c3c38,0x7bd40083}},	//   _ojii_, _jupr, _djøf_, okyu, 
   {{0x7c3d346d,0x7bd54343,0x53352a41,0xf1b80208}},	//   _mupr, nkyu, мейт, _chơn_, 
   {{0xe3ac092f,0xdb0407ea,0x7c3d0d90,0x7bd404ba}},	//   طري_, udiè, _lupr, ikyu, 
   {{0x7c3caae5,0x11d800c6,0xdb054344,0x2afc000d}},	//   _oupr, زوجة_, rdiè, _रखसु_, 
   {{0xd5b94345,0x7bd54346,0xef1d4347,0x7c3c174b}},	//   _inā_, kkyu, rfüm_, _nupr, 
   {{0x09b80a28,0xdcfc0064,0x289800df,0x00000000}},	//   _उच्य, lerė, זיטא, --, 
   {{0x7c3c20ef,0x33188ea0,0xe294fba7,0x76402a7b}},	//   _aupr, _ازاد_, _нац_, nqoy, 
   {{0x224801f1,0x7bd40083,0x2e48013e,0x98b80064}},	//   ícke_, ekyu, ияҳо_, _nerį_, 
   {{0x7c3d4348,0x6b8c007f,0x00000000,0x00000000}},	//   _cupr, _pbcg, --, --, 
   {{0xd0114349,0x7c3c40e8,0x00000000,0x00000000}},	//   _جلب_, _dupr, --, --, 
   {{0xd5b8b1a8,0xd1e4001f,0xdcfc00c0,0x00000000}},	// [20370] _onā_, _ምሽት_, kerė, --, 
   {{0x7c3c0393,0x6b8c037e,0x6fe8012d,0x00000000}},	//   _fupr, _wbcg, jęcz, --, 
   {{0x7c3c0687,0x6e3c0455,0x291c010f,0xdcfc0153}},	//   _gupr, _huqb, _ĝuas_, derė, 
   {{0xd5b80053,0x80bc0073,0x00000000,0x00000000}},	//   _anā_, षमते, --, --, 
   {{0xe7081411,0xdb040112,0x00000000,0x00000000}},	//   حتان_, meiß, --, --, 
   {{0x6d440034,0x6e340135,0xdb040e78,0xdcfc0024}},	//   ncja, _jixb, leiß, gerė, 
   {{0x18a4016c,0x6e340798,0x69c001f4,0x00000000}},	//   _паём, _mixb, öneu, --, 
   {{0x27fc004b,0x6e340009,0xd5b800b8,0x7e64002d}},	//   _ujun_, _lixb, _enā_, yskp, 
   {{0x6e3c047e,0x6d44033f,0x6738002b,0x22480221}},	//   _nuqb, kcja, _iguj, ëck_, 
   {{0xdb0403fa,0x6e34031c,0xa0803007,0x95d8005b}},	//   heiß, _nixb, еңке, _едут_, 
   {{0x6561434a,0xdb040789,0xeb9c0162,0xd5b8994d}},	//   manh, rdié, _gjøg_, _эст_, 
   {{0x6561434b,0x44280428,0x6e3c0477,0x00000000}},	//   lanh, _òa_, _buqb, --, 
   {{0x644001b9,0x6e3c0009,0xeb9c5522,0xafe01318}},	//   lqni, _cuqb, _mjød_, тоял, 
   {{0x6561434c,0x6e340007,0x6e3c0455,0x2544002e}},	//   nanh, _cixb, _duqb, _jёl_, 
   {{0x67380337,0x7c3c0455,0x912800f7,0x00000000}},	//   _oguj, _qupr, _ىسىق_, --, 
   {{0x6739434d,0x7c3c07a9,0x6561434e,0x237c0240}},	//   _nguj, _vupr, hanh, nguj_, 
   {{0x6561434f,0x6e340036,0x6440022e,0x00000000}},	// [20380] kanh, _fixb, hqni, --, 
   {{0x67394350,0x7c3c036b,0x6d44025c,0x00000000}},	//   _aguj, _tupr, ccja, --, 
   {{0x6560aa9e,0xd91004fb,0x59c410eb,0xab6400e2}},	//   danh, ایز_, लॉगर, _beļģ, 
   {{0x3eb00122,0xdecc02d3,0xe60c1927,0x6e3c014f}},	//   _kryt_, _ኣሜን_, یشو_, _yuqb, 
   {{0x65614351,0x7c24003e,0x60082ca8,0x00000000}},	//   fanh, _ihkr, mımd, --, 
   {{0x65614352,0x6738014b,0x3448998c,0x65900372}},	//   ganh, _eguj, очин_, نجىر, 
   {{0xf7714353,0x6fe80034,0x76400113,0xa8840064}},	//   _لاء_, ręcz, sqoy, _ойра_, 
   {{0xb7d88891,0x2ca42776,0xd76400dd,0x600806b9}},	//   _بورا_, _ânde_, _سنئی, nımd, 
   {{0x65614354,0xf2054355,0x6d44012d,0xdcfc0064}},	//   banh, дяно, ycja, perė, 
   {{0xe57422bf,0xd5b8003a,0x6e3c0455,0x60084dd9}},	//   _озу_, _unā_, _ruqb, hımd, 
   {{0x3eb00109,0x600805d1,0x386803b2,0x6e3c047e}},	//   _aryt_, kımd, _jvbr_, _suqb, 
   {{0x3eb14356,0x6e3c0978,0x68200254,0x600803e0}},	//   _bryt_, _puqb, põde, jımd, 
   {{0x60084674,0x6e34f17d,0x5e854357,0xa13000e5}},	//   dımd, _pixb, курз, ٹریش, 
   {{0x6fdc1bce,0xdb040e78,0x00000000,0x00000000}},	//   _bëcc, weiß, --, --, 
   {{0xa0a00046,0x2d8403ee,0x2bb800c6,0x2ba40261}},	//   _ашыл, _önem_, يارة_, мјав, 
   {{0xd5b800b8,0x6e3c047e,0x3eb00240,0x6008236c}},	//   _bhāk_, _tuqb, _fryt_, gımd, 
   {{0x65614358,0xb0600598,0x39480115,0x3eb07328}},	// [20390] yanh, _şähr, _bfbs_, _gryt_, 
   {{0x237c0007,0x64400784,0x9df80166,0x65600208}},	//   zguj_, yqni, _оныт_, xanh, 
   {{0x65601cbd,0xaca001f2,0xe8488efb,0xc794151e}},	//   vanh, _mpịg, زجان_, ерлы, 
   {{0x48243baf,0x6560016b,0x60082ca8,0x00000000}},	//   رىشق, wanh, cımd, --, 
   {{0x65614359,0x394805ac,0xd8780131,0x69c8002d}},	//   tanh, _ffbs_, كمەت_, êges, 
   {{0x6440022e,0x65600051,0xc91c00cc,0x00000000}},	//   tqni, uanh, _তলীত_, --, 
   {{0x6561435a,0x64400d04,0xfc4401f1,0x6fdc1bce}},	//   ranh, uqni, žíva_, _xëcc, 
   {{0x6561435b,0x67385628,0x42540353,0x42c9435c}},	//   sanh, _uguj, нтот, згин_, 
   {{0x6561435d,0x66f010eb,0x2b4801a6,0x60080790}},	//   panh, _अधिक_, _mfcc_, nıme, 
   {{0x600807b3,0x758004fb,0x24400205,0x606000d1}},	//   zımd, _میهم, _hımm_, نۇتل, 
   {{0x94a8034b,0x60081cce,0x00000000,0x00000000}},	//   _отца_, yımd, --, --, 
   {{0x78b801ed,0x6fdc0de2,0x6008d7c2,0xa31000fd}},	//   _átve, _rëcc, xımd, _иялә, 
   {{0x81d4a2ed,0x37d800df,0x00000000,0x00000000}},	//   _подх, פֿטע, --, --, 
   {{0x7c24067d,0x00000000,0x00000000,0x00000000}},	//   _shkr, --, --, --, 
   {{0x442d435e,0xfce431d5,0x6008029f,0x00000000}},	//   ome_, хово, tımd, --, 
   {{0x442c079d,0xf0600801,0xeb9c0450,0xfe4000f1}},	//   nme_, _скъп, _skør_, _مکسی, 
   {{0x442d435f,0xba254360,0x60080ba5,0x3a254361}},	// [203a0] ime_, едак, rımd, емаг, 
   {{0x442d4362,0x2b480b45,0x600805d1,0x7b04002b}},	//   hme_, _efcc_, sımd, _āstā, 
   {{0x442d4363,0x2b480354,0x6d40002d,0x81b00183}},	//   kme_, _ffcc_, _ûnaa, _টকা_, 
   {{0x442d4364,0x3f814365,0xe850cf73,0x69c14366}},	//   jme_, ngku_, انند, öner, 
   {{0x442d4367,0x24540022,0x00000000,0x00000000}},	//   dme_, ҭашь_, --, --, 
   {{0x442d4368,0x79540014,0x00000000,0x00000000}},	//   eme_, _سَرا, --, --, 
   {{0xdcfc00da,0x442c01a4,0xb7940640,0x0f1c0d2e}},	//   derī, fme_, _праћ, _नर्स_, 
   {{0xc5bc0154,0xf2c400f0,0x00000000,0x00000000}},	//   _অতঃপ, есон, --, --, 
   {{0xe61400fd,0xfe0000bc,0x23240114,0xf5e829ee}},	//   ьдә_, ोवास_, ноћи_, _емал_, 
   {{0x442d4369,0xef1d436a,0xf1b8001e,0x224825f7}},	//   ame_, ngüe_, _thơm_, ícka_, 
   {{0x33d410f5,0x442d436b,0x600806be,0x00000000}},	//   _підт, bme_, dımb, --, 
   {{0x442d436c,0x3f8000f2,0x00000000,0x00000000}},	//   cme_, ggku_, --, --, 
   {{0x0cc81161,0x00000000,0x00000000,0x00000000}},	//   रह्म, --, --, --, 
   {{0x799c002d,0xdcfc0171,0x00000000,0x00000000}},	//   jepw, cerī, --, --, 
   {{0xa0a00a5b,0xb0600139,0x3b4cd1f7,0x00000000}},	//   _бајд, _ğäwr, _ọyọ_, --, 
   {{0x9d18013e,0x7a2000e4,0x00000000,0x00000000}},	//   хост_, vôta, --, --, 
   {{0x1dc42be5,0xda78f571,0xe3c00790,0x637800fd}},	// [203b0] төөн, еях_, lgıç_, länü, 
   {{0x5b140276,0xa90400d1,0x00000000,0x00000000}},	//   умут, ىبان, --, --, 
   {{0xe3c070f7,0xaca002e3,0x60080205,0x00000000}},	//   ngıç_, _kpọg, sıme, --, 
   {{0x2d81436d,0xd8740a2c,0x442d436e,0x29040135}},	//   lgje_, االب, xme_, ħna_, 
   {{0x1d98001f,0x2aa84137,0x442d1ec3,0x600805d1}},	//   _ህዝቦች_, _этно_, vme_, lımc, 
   {{0x2d81436f,0x799c02d0,0x442d4370,0xd1380064}},	//   ngje_, cepw, wme_, ndąs_, 
   {{0x442d4371,0x2d80002d,0xd61856e6,0x60080790}},	//   tme_, igje_, رتها_, nımc, 
   {{0x6b9c074d,0xf2840014,0xd7f8009d,0x4438007c}},	//   neqg, چھوو_, _зуу_, ös_, 
   {{0xd3c400db,0xd6d80108,0x64a14372,0x00000000}},	//   اتىى, _птф_, тақа, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x442d4373,0x981400e5,0x63780166,0x00000000}},	//   pme_, _شبہا, gänü, --, 
   {{0x2d800a85,0xbb340ed1,0x82d800c7,0x442d4374}},	//   egje_, _ﻗﻮﻱ_, _одес_, qme_, 
   {{0x63a8127b,0x00000000,0x00000000,0x00000000}},	//   _iagn, --, --, --, 
   {{0x2d800183,0x6288014b,0x63a94375,0xfca94376}},	//   ggje_, _iqgo, _hagn, وازو_, 
   {{0x63a800e8,0x228808fb,0x00000000,0x00000000}},	//   _kagn, løk_, --, --, 
   {{0x63a94377,0xeb954378,0x2d8063de,0x7ff40271}},	//   _jagn, кис_, agje_, _جستا, 
   {{0x63a94379,0xe7f406ab,0xd5b800b0,0xaa40010b}},	// [203c0] _magn, ूचना_, _whāi_, иетл, 
   {{0x63a9437a,0x38540395,0x00000000,0x00000000}},	//   _lagn, въдс, --, --, 
   {{0x6841437b,0xfeb8107f,0xa9a094c9,0xfc04004e}},	//   анха, _راکت_, рихд, _апно, 
   {{0x63a9437c,0x9f4c020c,0xf0900115,0x00000000}},	//   _nagn, èlèk_, שנא_, --, 
   {{0x59240489,0xe7f0068f,0xe735437d,0x34d8012c}},	//   _འཛམས_, _आगरा_, вец_, बन्द, 
   {{0xa61002d5,0x387c003b,0xa93400cf,0x00000000}},	//   аміч, _åtro_, ربەچ, --, 
   {{0x63a8c5ec,0x52140131,0x68200254,0x00000000}},	//   _bagn, һдит, sõda, --, 
   {{0x63a9437e,0xab581570,0x79800198,0x2d80045f}},	//   _cagn, _gnüd, ɗowa, zgje_, 
   {{0x35a40124,0xa52000fd,0x00000000,0x00000000}},	//   _иааг, лмәд, --, --, 
   {{0xf1b801fb,0x63a81cf8,0x64941de6,0x60080205}},	//   _khơi_, _eagn, хтәр_, yımc, 
   {{0xf5540201,0x63a86ab1,0x64a0074d,0xb3844bb1}},	//   _ግንኙነ, _fagn, _ваха, _алел, 
   {{0x63a9437f,0xe3c0236c,0x00000000,0x00000000}},	//   _gagn, rgıç_, --, --, 
   {{0xd2514380,0x00000000,0x00000000,0x00000000}},	//   _انت_, --, --, --, 
   {{0x63a82b5d,0x3324022e,0x2d8001a4,0x60080205}},	//   _zagn, _izox_, ugje_, tımc, 
   {{0x2d814381,0x823c069c,0x63a80ede,0x2f7400c7}},	//   rgje_, _ኣተሓሳ, _yagn, _иҩны_, 
   {{0x600803ee,0x63a80429,0x321c01ab,0x59d401b9}},	//   rımc, _xagn, llty_, یغلر, 
   {{0x41a802e5,0x2d8000cc,0x9ce80150,0x00000000}},	// [203d0] _कसमस, pgje_, _ﺍﻁﻼﻋ, --, 
   {{0x9f400137,0x600805d1,0x78b80c5e,0x00000000}},	//   _aliè_, pımc, _štva, --, 
   {{0xf1b801dc,0xa8a41086,0x60082791,0x00000000}},	//   _chơi_, ърак, lıma, --, 
   {{0x0134008f,0xfd640055,0x00000000,0x00000000}},	//   אָנט_, dasṛ, --, --, 
   {{0x63a94382,0xe9443461,0x60080c07,0xeb9c0158}},	//   _ragn, _ахбо, nıma, _gjøa_, 
   {{0x63a94383,0xbaa401b9,0x00000000,0x00000000}},	//   _sagn, _суюқ, --, --, 
   {{0x63a94384,0x48a40092,0x00000000,0x00000000}},	//   _pagn, _ወላጆች_, --, --, 
   {{0x228806ea,0x321c0afa,0xdcfc00e2,0x60080139}},	//   tøk_, elty_, ngrā, kıma, 
   {{0x63a94385,0xdcfc0022,0x61f0022e,0x00000000}},	//   _vagn, rerĩ, аdlа, --, 
   {{0x2288168c,0x00c81f42,0xb0ac6ea8,0xfcc80092}},	//   røk_, елок_, टिंग, _አውጪ_, 
   {{0x63a94386,0x22894387,0x7050b184,0xa4900133}},	//   _tagn, søk_, ینیا, _ئیعت, 
   {{0x321c0204,0xd04803b9,0x00000000,0x00000000}},	//   alty_, nydə, --, --, 
   {{0xab580036,0x62c4007b,0xfeb80214,0x94100073}},	//   _onüb, _جزاك, راحت_, ावरच_, 
   {{0x1c1c0037,0x7270009f,0x00000000,0x00000000}},	//   _भीजल_, _اهوض, --, --, 
   {{0xd1b800f4,0x443c0098,0x66000217,0xa3c4190e}},	//   _جانا_, _kiw_, innk, _ऋचा_, 
   {{0xfaa4c9b5,0x443ca758,0xbc242544,0xbea40022}},	//   лабо, _jiw_, ارسى, _баик, 
   {{0xfe70b075,0x443c0978,0xac041507,0x59640961}},	// [203e0] _ادب_, _miw_, унта_, инағ, 
   {{0xf1b801fb,0x7a200030,0xd6c404fb,0x443d4388}},	//   _phơi_, rôto, یمای, _liw_, 
   {{0x443c0083,0xdcb000db,0x00000000,0x00000000}},	//   _oiw_, _بۉز_, --, --, 
   {{0x4b540801,0x6600009a,0x443d4389,0xebe0010b}},	//   _върт, ennk, _niw_, _гоюп, 
   {{0xeb9c0158,0x7d1c003a,0xddc409a8,0xb864004b}},	//   _kjøn_, _hyps, _zviš, _څارو, 
   {{0xb86531b7,0xe9dc0597,0x7d1c02f6,0x443c0432}},	//   _مارو, _dtús_, _kyps, _aiw_, 
   {{0xe0c5438a,0x0988039b,0x2a040212,0x8a1000f1}},	//   _از_, _шарқ_, _серп_, _بېلت, 
   {{0x443d438b,0x61e00076,0x321c0175,0x00000000}},	//   _ciw_, _alnl, wlty_, --, 
   {{0x443d438c,0x370506ea,0x7d1c382d,0x81cc0154}},	//   _diw_, _спаг, _lyps, রসন_, 
   {{0xe615438d,0x00000000,0x00000000,0x00000000}},	//   _бду_, --, --, --, 
   {{0xe978010f,0x92d400eb,0x00000000,0x00000000}},	//   ענטש, সছে_, --, --, 
   {{0x8f34084c,0x600808a9,0x00000000,0x00000000}},	//   иенц, tıma, --, --, 
   {{0x98b80003,0xddc5438e,0xe410009f,0x00000000}},	//   _ferħ_, _sviš, _اِنج, --, 
   {{0xf1a8208f,0x60083bc1,0x6ca40022,0x00000000}},	//   _ساته_, rıma, лрбж, --, 
   {{0x443d438f,0xe814012c,0x6218011a,0xd25001f7}},	//   _yiw_, तवमा_, _רווק, _انڪ_, 
   {{0x2518010f,0xd6e4024a,0x00000000,0x00000000}},	//   גולא, कनाथ_, --, --, 
   {{0xc0dc00b7,0xe5180cb4,0x3f6400cf,0x00000000}},	// [203f0] ንደር_, _पुनि_, _өтөб, --, 
   {{0xcf900014,0xdcfc005f,0x28694390,0x48c400c7}},	//   _اژھ_, sgrā, ердо_, қәҳа, 
   {{0x9b940075,0xdb0404d4,0x7d1c2bab,0x00000000}},	//   شلەت, rdiá, _gyps, --, 
   {{0x9f4006af,0xd9188fdf,0x00000000,0x00000000}},	//   _plié_, уьу_, --, --, 
   {{0x257002dd,0x443c0142,0xe3b401ec,0x60080139}},	//   йқас, _riw_, ғұл_, kımn, 
   {{0x443d4391,0xab580e78,0x940c06be,0x76b40131}},	//   _siw_, _unüb, _ipdə_, шһур_, 
   {{0x82342e6b,0x27b000fb,0x443d4392,0x6f180210}},	//   یرخا, _гәлс, _piw_, żuch, 
   {{0x7d180254,0x00000000,0x00000000,0x00000000}},	//   ütsi, --, --, --, 
   {{0x443c007f,0x05140154,0x00000000,0x00000000}},	//   _viw_, াধের_, --, --, 
   {{0x43752283,0x96b8221c,0x443c0042,0x026800d1}},	//   _چهار, _حافز_, _wiw_, ншүй_, 
   {{0x43743738,0x443c013f,0xc00421d7,0x00000000}},	//   _نهار, _tiw_, ипок, --, 
   {{0xd7c80490,0x7d1d4393,0x00000000,0x00000000}},	//   ळायच, _ryps, --, --, 
   {{0x7d1c71d4,0x81cc0154,0x987401ef,0x60080166}},	//   _syps, রসব_, _rýče_, bımn, 
   {{0xdb040120,0x7d1d4394,0x60080139,0x00000000}},	//   ldiç, _pyps, cımn, --, 
   {{0x7f74c663,0x59dc298e,0x15f80210,0x00000000}},	//   _купц, _मकबर, ्चतर_, --, 
   {{0xdb040cfc,0xac045080,0x78b801f1,0xef1c03fa}},	//   ndiç, анса_, _štvo, rfür_, 
  
   {{0xbea4969c,0x4b5400a7,0xaa454395,0xff080114}},	// [20400] _тапк, съст, ипта_, _шеик_, 
   {{0x7d1c01e3,0x9998013a,0x00000000,0x00000000}},	//   _typs, _virů_, --, --, 
   {{0x987400bc,0xef1d0fe1,0xeb9c2147,0xf7480133}},	//   _týče_, ngün_, _kjøl_, نجشه_, 
   {{0x37e40f5c,0xa6e40051,0x7b9400d4,0x00000000}},	//   јодг, _trứ, _трої, --, 
   {{0xeb9d00b0,0xef1c010e,0x00000000,0x00000000}},	//   _mjøl_, hgün_, --, --, 
   {{0x6600026b,0x07dc0ca8,0x00000000,0x00000000}},	//   опча, _àìná_, --, --, 
   {{0x81fc009e,0xe4641367,0x2b600118,0x7a2000d7}},	//   ুতাপ_, ашыл_, ůrců_, hôtk, 
   {{0x6d3400df,0x00000000,0x00000000,0x00000000}},	//   סטקא_, --, --, --, 
   {{0x66e0f489,0xe7348f3a,0x00000000,0x00000000}},	//   _дота, _вет_, --, --, 
   {{0x4788010a,0x00000000,0x00000000,0x00000000}},	//   _ӳсĕм_, --, --, --, 
   {{0x33a80fc0,0xa5040395,0x73e40108,0x00000000}},	//   _аъло_, _кефа_, _кожз, --, 
   {{0x3adc02b5,0xdb040254,0x00000000,0x00000000}},	//   _kāpā_, odiä, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe21000db,0x60082573,0x2324340b,0xddc400b8}},	//   _وبوع, lıml, _точи_, _itiś, 
   {{0xeb9c03cd,0x00000000,0x00000000,0x00000000}},	//   _fjøl_, --, --, --, 
   {{0x600807c4,0x6fdc0036,0xe05018a2,0xdd140116}},	//   nıml, _mëck, _بخوب, تۈپخ, 
   {{0x15f84540,0x497530c8,0xdee4009b,0x00000000}},	// [20410] ्चार_, йлас, _моћи, --, 
   {{0x957c020c,0x7e6000ee,0x00000000,0x00000000}},	//   _sląn, _çopa, --, --, 
   {{0x600803ee,0xe4f80316,0x18a400d4,0x889400c7}},	//   kıml, एपछि_, жаєм, сиех, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xef1ce35c,0x60080213,0x75d0004b,0x07080ccb}},	//   zgün_, dıml, ړيوا, ديشي_, 
   {{0xbb380375,0x0444036b,0xeb5002dd,0x195801af}},	//   _תעשי, бекн, _دىڭگ, _вары_, 
   {{0xddc400cd,0xe784011b,0x7e780210,0x00000000}},	//   _atiś, _вузо, ątpi, --, 
   {{0x6fdc04e6,0x05946ea9,0xdb040139,0x6008c8d8}},	//   _dëck, _گارگ, bdiä, gıml, 
   {{0xdb040120,0x68f40006,0x45d40276,0xae1401ad}},	//   rdiç, žadė, _лоас, णवान_, 
   {{0x81c81064,0xeb9c168c,0x6fdc01c7,0xdb040798}},	//   угов_, _sjøl_, _hëch, sdiç, 
   {{0x273001dc,0x3f694396,0x6ab80419,0xc4580117}},	//   _ảnh_, лино_, _šufl, _сиех_, 
   {{0xef1d17cb,0xa24401d3,0x1ee80ed8,0x60080205}},	//   rgün_, _پیدل_, لوجی_, cıml, 
   {{0x6fdc0221,0x60080213,0xd1dc001f,0xe51809ab}},	//   _mëch, sımo, _ሕጎች_, _पुति_, 
   {{0x6fdc0036,0x5be02e35,0x00000000,0x00000000}},	//   _lëch, नस्व, --, --, 
   {{0xed554397,0x60080205,0x80a400ec,0xef1d4398}},	//   сос_, lımm, _چمڪن, lgül_, 
   {{0x51080408,0x00000000,0x00000000,0x00000000}},	//   _тĕсĕ, --, --, --, 
   {{0x6b600372,0xef1cbd89,0x60080205,0xe08001f7}},	// [20420] якта, ngül_, nımm, _اجڙي, 
   {{0xe9d49785,0x60080c3c,0x6f5401d3,0x00000000}},	//   бку_, zıml, _پلیز_, --, 
   {{0x60084a4a,0x6fdc0036,0x7c9430a7,0xd91017a5}},	//   yıml, _bëch, _اشخا, ذیر_, 
   {{0x3adc9e00,0x6fdc01c7,0x2d8405d1,0x81cc015b}},	//   _pāpā_, _rëck, _öner_, রসি_, 
   {{0x3694023a,0x7c341368,0xca7400c0,0xb71402c9}},	//   сшес, mmyr, _муры, حظات, 
   {{0x7c354399,0xb2a801b9,0x60080205,0x00000000}},	//   lmyr, ҳтож_, dımm, --, 
   {{0x6008cdfe,0x387c08ce,0x00000000,0x00000000}},	//   tıml, _ítr_, --, --, 
   {{0xe8f40323,0x7c347edd,0x779004d3,0x3adc02b5}},	//   _улс_, nmyr, _ریتا, _tāpā_, 
   {{0x6009439a,0x7c3400ad,0xab5800a2,0x59dc00cd}},	//   rıml, imyr, _onün, _मकार, 
   {{0x31c5439b,0x60082c78,0x9099439c,0x51f80212}},	//   ссив, sıml, авот_, рною_, 
   {{0x203c0092,0x600803e0,0x7c340432,0x00000000}},	//   አብሄር, pıml, kmyr, --, 
   {{0x1ac80316,0x7c340158,0x836400db,0xefe80472}},	//   रमाथ, jmyr, _ۇدۇل, اعدو_, 
   {{0x9f40003a,0x7c3403cd,0x22542651,0x00000000}},	//   _aliâ_, dmyr, _هلند_, --, 
   {{0x7c340076,0x421400f1,0x3d18000d,0x00000000}},	//   emyr, _وسوځ, _मुहे_, --, 
   {{0x9cc80006,0xa13000cf,0x00000000,0x00000000}},	//   быта_, _ىرىش, --, --, 
   {{0xbb341c5c,0xa850010b,0x417c00d1,0x7c34311d}},	//   _ﻗﻮﻝ_, җедә, _ﻣﯘﮬﯩ, gmyr, 
   {{0x4420013f,0xfe74014b,0x00000000,0x00000000}},	// [20430] _ɔh_, _мӯр_, --, --, 
   {{0x6fdc0221,0xeb9c0158,0x798c03ac,0x497403de}},	//   _sëch, _kjøk_, _ccbw, ілес, 
   {{0xec14bcf5,0x5e5401ed,0x600803e0,0x00000000}},	//   _генә_, _وئیر, zımm, --, 
   {{0xe769439d,0x60080205,0x00000000,0x00000000}},	//   احان_, yımm, --, --, 
   {{0x9a84ade9,0x798c03ac,0x6b8c03ac,0x00000000}},	//   _нурл, _fcbw, _iccg, --, 
   {{0xdcfc025c,0x88c400ec,0x00000000,0x00000000}},	//   lerġ, _وڪال, --, --, 
   {{0x6fdc0036,0xd454010b,0x8c48013d,0x64b006e3}},	//   _tëch, птыь, _uyşı, ंटेश, 
   {{0xd7948c98,0xd064013f,0xdcfc0135,0x00000000}},	//   _нисъ, _ɔsɔr, nerġ, --, 
   {{0xf34c063f,0x00000000,0x00000000,0x00000000}},	//   _rụtụ_, --, --, --, 
   {{0x569400c2,0xef1c51c8,0x4ad000c5,0xb2200166}},	//   _хафт, rgül_, _सपनव, ммыл, 
   {{0x15b0313e,0x7c350e15,0x00000000,0x00000000}},	//   _سەيس, ymyr, --, --, 
   {{0x7a200109,0xcdc800d9,0x999800c0,0x9f400055}},	//   rôti, _בך_, _mirš_, _smiñ_, 
   {{0xbea400c7,0x00000000,0x00000000,0x00000000}},	//   әаҳк, --, --, --, 
   {{0xc0e4fbaa,0x81cc0154,0x4df4005b,0x00000000}},	//   _молк, রসহ_, пяст, --, 
   {{0x51841f67,0x88d400b8,0xfce40cc9,0xee3401ca}},	//   _хуча, _dṛkk, цово, інс_, 
   {{0xf34c00b4,0x00000000,0x00000000,0x00000000}},	//   _hụrụ_, --, --, --, 
   {{0xeab40372,0xf34c01f2,0x7c340209,0x6aac0175}},	// [20440] ойт_, _kụrụ_, rmyr, _cscf, 
   {{0xf34c02e3,0x7c34cf52,0xbb4800b5,0x6d880023}},	//   _jụrụ_, smyr, _daiの_, ንቀውታ_, 
   {{0xf34c0521,0xb178008f,0xab582305,0xdb0403b2}},	//   _mụrụ_, שטער, _knül, ndiú, 
   {{0xf34c02e3,0xdb04007b,0xb098008f,0xf7440798}},	//   _lụrụ_, idiú, ייער, цедо, 
   {{0xdb0400ae,0x00000000,0x00000000,0x00000000}},	//   hdiú, --, --, --, 
   {{0xac940014,0xf34c02e3,0x72f801e1,0x00000000}},	//   _انێا_, _nụrụ_, _ẹfò, --, 
   {{0x37e400d6,0x00000000,0x00000000,0x00000000}},	//   _довг, --, --, --, 
   {{0x68e010b8,0x64300451,0x6d4000ae,0x00000000}},	//   ønde, وريء, _únae, --, 
   {{0xf34c44fc,0x77600077,0x32080b01,0x09bc00eb}},	//   _bụrụ_, mbox, ихон_, _আকতা, 
   {{0x256401ca,0x91800137,0x00000000,0x00000000}},	//   _мауп_, رۇعۇ, --, --, 
   {{0x7bc5439e,0x7e7400e4,0x3d180490,0x9f400a87}},	//   _onku, _avyp, _मुले_, _smið_, 
   {{0x387c05ac,0x776001e3,0xfcc80092,0x88d400b8}},	//   _åtru_, nbox, _አልጋ_, _sṛkk, 
   {{0x7760007c,0xdcfc031c,0xe29400d8,0x00000000}},	//   ibox, verġ, _мац_, --, 
   {{0x7bc5439f,0xf34c02e3,0x77600334,0x00000000}},	//   _anku, _gụrụ_, hbox, --, 
   {{0x77607664,0xdcfc031c,0x68200254,0x00000000}},	//   kbox, terġ, sõdi, --, 
   {{0xf34c02e3,0x3d180490,0x4a540153,0x00000000}},	//   _zụrụ_, _मुळे_, зкас, --, 
   {{0x2aa84c70,0xdd3800b8,0x60080205,0x00000000}},	// [20450] штво_, _kāśa, zımk, --, 
   {{0x7bc45a26,0x5a3448a9,0xddc40205,0x5ea403ff}},	//   _enku, днут, _itiş, _کمیل, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x99980006,0x7e740588,0x77600175,0xbb340131}},	//   _virš_, _yvyp, gbox, ﺗﻪﻥ_, 
   {{0x68e0553d,0x28a8033f,0xe7080244,0x00000000}},	//   øndb, _टैरि, جتان_, --, 
   {{0xeabc01e1,0xdd3800dc,0xbb3800d9,0x00000000}},	//   _irù_, _nāśa, _לערי, --, 
   {{0xf34c0521,0x00000000,0x00000000,0x00000000}},	//   _rụrụ_, --, --, --, 
   {{0xd7f80323,0xab5800a2,0x77600051,0xca200150}},	//   _дуу_, _onüm, cbox, _ﺸﺭﺥ_, 
   {{0xf34c00b4,0x27e41bce,0x00000000,0x00000000}},	//   _pụrụ_, ënnu_, --, --, 
   {{0x95c8074d,0xdd38002b,0x00846be2,0x73e40228}},	//   _муха_, _cāśa, плоо, _ۉيلۅ, 
   {{0x203c0020,0x69c543a0,0xdd38002b,0xddc406be}},	//   አብሔር, _mnje, _dāśa, _atiş, 
   {{0xdb040f33,0x24740311,0xeabc01e1,0xed540107}},	//   rdiú, măm_, _orù_, ҷор_, 
   {{0x69c4401f,0xf34c0521,0x24740311,0x7f1943a1}},	//   _onje, _tụrụ_, lăm_, сіну_, 
   {{0xed550085,0xf31800d1,0x224800d0,0x7258011a}},	//   зор_, _унчә_, ícku_, _הכספ, 
   {{0x225c0998,0x24740311,0xa3cc0d2c,0xddc4010e}},	//   lpuk_, năm_, शाप_, _etiş, 
   {{0x69c543a2,0xeabc01ab,0x6d5402d0,0x78b801d3}},	//   _anje, _brù_, _efxa, _átvi, 
   {{0x225c020c,0xdd380055,0xba4400e5,0x00000000}},	// [20460] npuk_, _yāśa, سناٹ, --, 
   {{0xeb300447,0xe9d4234c,0x77600175,0x69c40200}},	//   رىلد, пку_, wbox, _cnje, 
   {{0xeabc0241,0x52a86859,0x24740311,0x00000000}},	//   _erù_, _कन्स, jăm_, --, 
   {{0x7bc40aa5,0x225c08cd,0xeabc026c,0x2474054e}},	//   _unku, kpuk_, _frù_, dăm_, 
   {{0xa3cc0b7d,0x569418b6,0x00000000,0x00000000}},	//   शान_, фалт, --, --, 
   {{0x69c42630,0x7760fdbd,0xe5b00006,0x746800d4}},	//   _gnje, sbox, ейшы, брив_, 
   {{0x2474084c,0xdd38002b,0xe3780092,0x00000000}},	//   găm_, _rāśa, _ተቀመጠ_, --, 
   {{0xa6d000bd,0x27e40a40,0x6ab801a6,0xdd3800b8}},	//   _দেওয়, ënnt_, _šufi, _sāśa, 
   {{0x69c46c03,0xdd3800cd,0x00000000,0x00000000}},	//   _ynje, _pāśa, --, --, 
   {{0x2474054e,0x51f800d4,0x71700137,0x00000000}},	//   băm_, інню_, رۇبا, --, 
   {{0x24740276,0x92cc015b,0xc0e400b7,0xdd38002b}},	//   căm_, রনে_, _ዝክረ_, _vāśa, 
   {{0xa2600208,0x6e240175,0x00000000,0x00000000}},	//   _khố, wljb, --, --, 
   {{0x2348107f,0x61f400e2,0x6d1c0037,0x00000000}},	//   _اسمی_, _žalū, _मँहग_, --, 
   {{0xa19000c0,0x00000000,0x00000000,0x00000000}},	//   _зашч, --, --, --, 
   {{0x321c03d1,0x1df8a863,0xe3ac0154,0x00000000}},	//   moty_, черы_, কারব, --, 
   {{0x69c41711,0x1bd46690,0x39480e78,0x321c21ed}},	//   _snje, нося, _agbs_, loty_, 
   {{0x9f40003a,0x24740311,0x49d800f5,0x00000000}},	// [20470] _aliæ_, zăm_, одаю_, --, 
   {{0x394801ab,0x386801f5,0x00000000,0x00000000}},	//   _cgbs_, _bwbr_, --, --, 
   {{0x5c74084c,0xd7c80073,0x24740356,0x00000000}},	//   _плэт, ळांच, xăm_, --, 
   {{0xded4067d,0xc5e40882,0x321c2320,0xeabc004d}},	//   _ካልእ_, कस्य_, hoty_, _trù_, 
   {{0x321d43a3,0xa260004d,0x00000000,0x00000000}},	//   koty_, _chố, --, --, 
   {{0x24740276,0x69c4209c,0x2cb00051,0x321c00d7}},	//   tăm_, _unje, _ksxd_, joty_, 
   {{0x5884467b,0x92cc015b,0x27e40036,0x00000000}},	//   _пыта, রনো_, ënns_, --, 
   {{0x24740276,0xf8b00375,0x17f8007b,0x600806be}},	//   răm_, _בשל_, _فرقة_, pımi, 
   {{0x24740311,0x6008002d,0x9f6401c7,0x9f402b24}},	//   săm_, nűme, _ëwéi_, _iliç_, 
   {{0x00e47de7,0x225c020c,0xdb040fac,0x321c1e0b}},	//   джон, rpuk_, rdiø, goty_, 
   {{0x660143a4,0x6820000d,0x00000000,0x00000000}},	//   mink, sõdu, --, --, 
   {{0x3518008f,0x65c40241,0x00000000,0x00000000}},	//   _ווענ, béhà, --, --, 
   {{0x321c3676,0x3dd80175,0x00000000,0x00000000}},	//   boty_, _popw_, --, --, 
   {{0x660143a5,0x27fc0098,0x3cc8ada8,0x00000000}},	//   nink, _lmun_, олго_, --, 
   {{0x6e4000a8,0x00000000,0x00000000,0x00000000}},	//   терз, --, --, --, 
   {{0x660143a6,0x2245361a,0x39480472,0x00000000}},	//   hink, _hink_, _sgbs_, --, 
   {{0x660143a7,0x224543a8,0x1ee8035c,0xab24361e}},	// [20480] kink, _kink_, _رودی_, дота_, 
   {{0x27fd43a9,0xbd8800ec,0xa7840150,0x00000000}},	//   _amun_, _بندن_, _ﻗﺩﺭﺓ_, --, 
   {{0x6600f4d5,0x224403f0,0xb77800b8,0x00000000}},	//   dink, _mink_, _liṅā, --, 
   {{0x68e02d75,0xeabc01e1,0xa2600208,0x66012528}},	//   ønda, _iyùn_, _phố, eink, 
   {{0x660143aa,0x22440077,0xb11002e3,0x09bc0154}},	//   fink, _oink_, rụic, _আকরা, 
   {{0xc76543ab,0x9f400ba1,0x27fd43ac,0xa6c40408}},	//   _ۋاقى, _eliç_, _emun_, ьлча_, 
   {{0x64a00640,0x321c02fb,0x00000000,0x00000000}},	//   ваја, voty_, --, --, 
   {{0x224400d5,0x29240030,0xa260004d,0x7bd400b5}},	//   _aink_, ívať_, _thố, njyu, 
   {{0xe3ac05e6,0x22444e13,0xe6148595,0x2324026a}},	//   شري_, _bink_, ядә_, моћи_, 
   {{0x200143ad,0x660021ed,0xe6140c9e,0xddc40153}},	//   _amii_, cink, _жду_, _aviž, 
   {{0x22440591,0xeb9d43ae,0x321c1be1,0x02a401ec}},	//   _dink_, _kjøt_, roty_, _үрім, 
   {{0xd0101375,0x27fc0135,0xb28400db,0x321d43af}},	//   الح_, _xmun_, _жыкк, soty_, 
   {{0x321d43b0,0x224543b1,0xe81c000b,0xddc4570b}},	//   poty_, _fink_, यकता_, _dviž, 
   {{0x06e02aab,0x22440064,0xf1a8007b,0x00000000}},	//   _মেডি, _gink_, _ذاته_, --, 
   {{0x9f40013d,0x00000000,0x00000000,0x00000000}},	//   _aliä_, --, --, --, 
   {{0x660143b2,0x224543b3,0x1bb800c6,0xa4b4011a}},	//   zink, _zink_, واقع_, וללה_, 
   {{0x66006fc3,0xa3cc0574,0x5eb401e0,0xb060013d}},	// [20490] yink, शात_, _айыт, _ğäyr, 
   {{0xddc41b24,0xa904208f,0x27fd046f,0x66000009}},	//   _zviž, وبان, _smun_, xink, 
   {{0x66013041,0xf8ac01d3,0x21240051,0x00000000}},	//   vink, یکہ_, _xynh_, --, 
   {{0x660143b4,0x2b48016b,0x7d18000f,0xd1e40023}},	//   wink, _ugcc_, ûtse, _ዝጽበ_, 
   {{0x660143b5,0x7af4a719,0x7e900134,0xafd8037e}},	//   tink, czyt, _pɛpɛ, mmød, 
   {{0x04b400a7,0xd6c400d1,0xdb0400ee,0x00000000}},	//   есия, тишқ, ndiý, --, 
   {{0xa3e0007d,0x660143b6,0x27fc031c,0x437400d1}},	//   _नकद_, rink, _tmun_, нупт, 
   {{0x660143b7,0x27fc6092,0x22449982,0xafd8005c}},	//   sink, _umun_, _sink_, nmød, 
   {{0x3d0410f7,0x6600cc62,0xc2441830,0x569400c7}},	//   _हेने_, pink, нник, _иатт, 
   {{0x66000054,0xeb9c33b8,0xddc40306,0xe69001ec}},	//   qink, _kjøs_, _sviž, _пиғы, 
   {{0x2000020b,0x80c802ab,0x84c4010b,0xa3cc2450}},	//   _pmii_, िमें, _яшаҗ, शाद_, 
   {{0x224543b8,0xeb9c03cd,0x52b000f7,0xb7780055}},	//   _wink_, _mjøs_, _چەيئ, _tiṅā, 
   {{0x63b943b9,0x22440a85,0xeb9c0158,0xfd940032}},	//   mdun, _tink_, _ljøs_, нөнә_, 
   {{0x63b943ba,0x40940cca,0xc0a8aaab,0x7bd40007}},	//   ldun, _зрит, _فاعل_, wjyu, 
   {{0x66e406c8,0xa3e00574,0x629943bb,0x50b40032}},	//   _hīkā, _नका_, ltuo, _асыу, 
   {{0x63b806fa,0xba740592,0xafd801bf,0x629943bc}},	//   ndun, فائت, gmød, otuo, 
   {{0x629943bd,0x63b943be,0xc4bc00dc,0x2ec800dc}},	// [204a0] ntuo, idun, ्मुख, ामृत, 
   {{0x63b89c5f,0x81e000bd,0x7af4012d,0x62980153}},	//   hdun, নোর_, rzyt, ituo, 
   {{0x7af543bf,0x629800c5,0x63b802c9,0x7784011c}},	//   szyt, htuo, kdun, елез, 
   {{0x29152272,0x62980006,0xe8f401c0,0x6abc0175}},	//   رقند_, ktuo, элх_, bvqf, 
   {{0x7c24025c,0xeb9c005c,0xafd80174,0x6008236c}},	//   _ikkr, _smøg_, smøg, lıms, 
   {{0xb90403f4,0x63b943c0,0x6298089c,0xba1801ec}},	//   _বই_, edun, dtuo, _ريزا_, 
   {{0xf77002eb,0x6298005b,0x60080342,0xf48400f3}},	//   _ماء_, etuo, nıms, хулн, 
   {{0x63b8ab8b,0x32646830,0xb9e80020,0xd37000c6}},	//   gdun, нтов, _ኖሮ_, جهة_, 
   {{0x629851e2,0xeb9c2c95,0xa7a406b5,0xc0340023}},	//   gtuo, _kjør_, _якта_, _ባህላው, 
   {{0x63b943c1,0x2004007f,0xddc400ef,0x6008236c}},	//   adun, èjin_, _huiņ, kıms, 
   {{0xeb9c0158,0x63b80381,0x40f00124,0x629804b1}},	//   _mjør_, bdun, иҧшр, atuo, 
   {{0xdb0543c2,0x8534036b,0x63b943c3,0x600806be}},	//   ndió, _شونچ, cdun, dıms, 
   {{0x629943c4,0x437543c5,0x92940022,0x98b800fd}},	//   ctuo, _рухт, _ралц, _merı_, 
   {{0x67f0010e,0x01e4004e,0x00000000,0x00000000}},	//   _içje, _ийчү, --, --, 
   {{0xafd8005c,0x00000000,0x00000000,0x00000000}},	//   tmød, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xafd8037e,0xeb9c08fb,0xe9840640,0x16201bbb}},	// [204b0] rmød, _sjøs_, ећен, मकार_, 
   {{0xafd8037e,0x7c24010f,0x63b80399,0x00000000}},	//   smød, _ekkr, zdun, --, 
   {{0x78b801a2,0xd7c871c5,0x63b943c6,0xafd800b5}},	//   _štvr, کونه_, ydun, pmød, 
   {{0x6b6407ea,0x3d180490,0x629943c7,0x4b78008f}},	//   _dégâ, _मुटे_, ytuo, _קאָו, 
   {{0xeb9c0579,0x2128001e,0xddd400d0,0xd1d40023}},	//   _fjør_, ́ch_, ťaťo, ርሓት_, 
   {{0xddc4000a,0xeb9c10f5,0x2bbc063f,0x63b855e3}},	//   _kwiš, _gjør_, _ọchi_, wdun, 
   {{0x63b943c8,0x66e4005f,0x81e000fe,0x00000000}},	//   tdun, _sīkā, নোঁ_, --, 
   {{0x629943c9,0xd6d800bd,0x7800013e,0x63b80393}},	//   ttuo, _দেওয, _кӯча, udun, 
   {{0x63b943ca,0xd3a40220,0x629804cc,0x60081cce}},	//   rdun, улық, utuo, zıms, 
   {{0x3d18006d,0x6298aa4c,0x63b943cb,0xa3cc0210}},	//   _मुझे_, rtuo, sdun, शाह_, 
   {{0x629943cc,0x23e400d6,0x008400a7,0xa48400e5}},	//   stuo, _підв, ълно, _سجان, 
   {{0x629943cd,0x0d800184,0x66e402b1,0x939469a6}},	//   ptuo, ҡһын, _tīkā, _مجها, 
   {{0x442d43ce,0x64480280,0x3d18012d,0x5efc28fe}},	//   mle_, _iigi, _मुजे_, _लेख्_, 
   {{0x644943cf,0xdb040037,0x60080205,0xde4801e2}},	//   _higi, rdiü, tıms, ژیکو_, 
   {{0x442d43d0,0x64481283,0x7b9400d6,0x53440022}},	//   ole_, _kigi, краї, _ихәа, 
   {{0x442d43d1,0x644943d2,0x60086d5b,0xa2b40b02}},	//   nle_, _jigi, rıms, ्टप्, 
   {{0x442d43d3,0x644943d4,0xa9240064,0x06e00154}},	// [204c0] ile_, _migi, _ložė, _মেসি, 
   {{0x644943d5,0x442d43d6,0x394c01bf,0x3878002f}},	//   _ligi, hle_, øfs_, tspr_, 
   {{0x442d43d7,0x64480194,0x6cb005a2,0x00000000}},	//   kle_, _oigi, _көтт, --, 
   {{0x442d43d8,0x644943d9,0xdb0400d8,0xc8b401ec}},	//   jle_, _nigi, udió, ысуы, 
   {{0x442d43da,0xdb041ada,0x00000000,0x00000000}},	//   dle_, rdió, --, --, 
   {{0x64483dc2,0xfbdc01ad,0x38780076,0x7e600205}},	//   _aigi, फॉरम, pspr_, _çopu, 
   {{0x64480516,0xeb9c1a82,0x442c55fd,0x9f400332}},	//   _bigi, _kjøp_, fle_, _cliú_, 
   {{0x68e143db,0x644943dc,0xe4e000d6,0x533543dd}},	//   ände, _cigi, рішн, лейт, 
   {{0x644943de,0xab5805d5,0xf484004b,0x00000000}},	//   _digi, _inüt, راډی, --, 
   {{0x644943df,0xdb041709,0x9f4000ae,0xa694011a}},	//   _eigi, ndiñ, _fliú_, _בכמה_, 
   {{0x442d43e0,0x644943e1,0x9f4001e7,0xf8e00210}},	//   ble_, _figi, _gliú_, पहिय, 
   {{0x644943e2,0x442d43e3,0xb4cc39de,0x2fdc0436}},	//   _gigi, cle_, शमी_, ðug_, 
   {{0x32d4036b,0x81e00154,0xa3cc0b03,0xddc400d7}},	//   _جزاس, নোই_, शार_, _swiš, 
   {{0x6448985a,0x511814a3,0x9da80395,0x00000000}},	//   _zigi, _полю_, къса_, --, 
   {{0x644943e4,0xdc74023a,0xafd8332e,0x271c000d}},	//   _yigi, игры, rmøb, _बड्र_, 
   {{0x644943e5,0xafd801bf,0x00000000,0x00000000}},	//   _xigi, smøb, --, --, 
   {{0x43880131,0xda7802e8,0x9b4000cd,0x00000000}},	// [204d0] ﯖﺪﯨﻦ_, вях_, _kāṣā, --, 
   {{0x442d43e6,0x00000000,0x00000000,0x00000000}},	//   zle_, --, --, --, 
   {{0x442d43e7,0xa3e005f9,0x9b400055,0x5a440006}},	//   yle_, _नकल_, _māṣā, рэта, 
   {{0x442d43e8,0xdb0426b7,0xa9240153,0xa2b41408}},	//   xle_, rdiò, _rožė, ्टम्, 
   {{0x64482b00,0x25700fc0,0x5b1400f5,0x68e026bc}},	//   _rigi, иқас, _вмят, ändb, 
   {{0x1a68034c,0x9f4008c2,0x00000000,0x00000000}},	//   _شیمی_, _cliù_, --, --, 
   {{0x442d43e9,0x644943ea,0x18b8049b,0x58d543eb}},	//   tle_, _pigi, _игры_, _корт, 
   {{0xab5807c5,0x64489634,0x00000000,0x00000000}},	//   _gnüt, _qigi, --, --, 
   {{0x442d43ec,0x644943ed,0x42241cc9,0x06e00154}},	//   rle_, _vigi, лдив, _মেরি, 
   {{0x442d43ee,0x644943ef,0xab5804cc,0x41b4413f}},	//   sle_, _wigi, _knüs, усит, 
   {{0x442d43f0,0x147543f1,0x00000000,0x00000000}},	//   ple_, _نانج, --, --, 
   {{0xbb340952,0x644943f2,0x7ff400db,0x269002d3}},	//   _ﺗﻮﻱ_, _uigi, اسدا, _ግሃድኤ_, 
   {{0x3f9c0034,0xe0b00154,0x00000000,0x00000000}},	//   ętu_, টমেন, --, --, 
   {{0xdb0543f3,0x8634008f,0x8e7400d4,0x3e340ee8}},	//   leiç, טאָג_, шуюч, افسر, 
   {{0x0c78a97f,0x00000000,0x00000000,0x00000000}},	//   ксты_, --, --, --, 
   {{0xf0900375,0x7f7403f6,0x1b6400c7,0x00000000}},	//   _הנה_, _сукц, рнаҭ, --, 
   {{0xab580205,0xf9c943f4,0x00000000,0x00000000}},	// [204e0] _anüs, нгак_, --, --, 
   {{0xc98401c8,0x00000000,0x00000000,0x00000000}},	//   لشمي, --, --, --, 
   {{0x2fd40502,0xdb0543f5,0x06e00729,0xfce4a839}},	//   _شوید_, rdiñ, _মেলি, _соно, 
   {{0xdb040120,0x00000000,0x00000000,0x00000000}},	//   jeiç, --, --, --, 
   {{0x4a7445b3,0xf6280212,0xab5800b8,0xba746e25}},	//   _выст, ніки_, _saüg, _حاجت, 
   {{0x68e0002f,0x32640022,0x00000000,0x00000000}},	//   ändc, қтив, --, --, 
   {{0xdb0406ed,0x1cdc025c,0xb4cc0243,0x344873b3}},	//   feiç, ྡའི_, शमे_, нчин_, 
   {{0xd1d41e38,0x3a2943f6,0xc8f80014,0xf74543f7}},	//   ርዓት_, _hkbp_, _شوقچ_, _бебо, 
   {{0x9b40002b,0x36680107,0x00000000,0x00000000}},	//   _pāṣā, _чазо_, --, --, 
   {{0xe70400ec,0xc0d80092,0x00000000,0x00000000}},	//   _حڪمن_, ዮጲስ_, --, --, 
   {{0x64a143f8,0xd1300346,0xc32400fe,0xc5ec00f1}},	//   _гаха, تمد_, মেলি_, _زړو_, 
   {{0xa3cc00dc,0x00000000,0x00000000,0x00000000}},	//   शाः_, --, --, --, 
   {{0xbd9c0020,0x807801f0,0x00000000,0x00000000}},	//   _ሌሎችም_, нбӯс_, --, --, 
   {{0x600805d1,0x27200208,0x68e001bf,0x290400e5}},	//   sımp, ựng_, øndk, únak_, 
   {{0x99980064,0x00000000,0x00000000,0x00000000}},	//   _birž_, --, --, --, 
   {{0xf1d0c853,0x3a280263,0xe0cc0150,0x00000000}},	//   तावन, _akbp_, _رزى_, --, 
   {{0x49747724,0x0974034b,0x98b800e2,0x93280092}},	// [204f0] илас, игаю, _ogrē_, _ሲንቀሳ, 
   {{0x091c00cc,0xfec8010f,0xab5800b8,0xdb1400a2}},	//   _ভৃগু_, _ימפּ, _saüd, _ýaýn, 
   {{0x67f0010e,0x6e24014f,0x6838010e,0x5d64013d}},	//   _açja, mojb, _nädý, _утыз, 
   {{0x97bc0150,0x04fc00b8,0x00000000,0x00000000}},	//   ершi, cāṃs, --, --, 
   {{0x7c385725,0x3a28030d,0x6fa4547d,0x1a940064}},	//   ître, _fkbp_, ट्यू, _лаяў, 
   {{0xbaa40131,0x00000000,0x00000000,0x00000000}},	//   _туюқ, --, --, --, 
   {{0xaef801ab,0x20040100,0x00000000,0x00000000}},	//   ncùb, èjik_, --, --, 
   {{0xd6d80046,0xca2817de,0xd39801e0,0x6e24047e}},	//   _өту_, ﻤﯩﺰ_, гәшә_, hojb, 
   {{0x45d413b1,0x9264006c,0xdb040ba1,0x00000000}},	//   _коас, یدیم, reiç, --, 
   {{0x020543f9,0xe6100b24,0xb34403e0,0x00000000}},	//   рзон, _اشر_, _suçü, --, 
   {{0x3f69406d,0x26e002e3,0x00000000,0x00000000}},	//   кино_, ̣rọ_, --, --, 
   {{0xd1d401f3,0x00000000,0x00000000,0x00000000}},	//   ርዓቱ_, --, --, --, 
   {{0xa2640108,0x00000000,0x00000000,0x00000000}},	//   _съел, --, --, --, 
   {{0xabdc01ec,0x00000000,0x00000000,0x00000000}},	//   _ﺇﻗﻨﺎ, --, --, --, 
   {{0x443c0070,0x61e143fa,0x00000000,0x00000000}},	//   _khw_, _ionl, --, --, 
   {{0x61e000dd,0xafd80b1a,0x1ee800e5,0xb098011a}},	//   _honl, lmøn, _موبی_, _סיפר, 
   {{0x39540cfc,0x61e143fb,0x443c009a,0x34d000bc}},	// [20500] ањет, _konl, _mhw_, _थप्द, 
   {{0x61e0c108,0x6a8001ec,0x00000000,0x00000000}},	//   _jonl, ілха, --, --, 
   {{0x61e143fc,0x443c01f5,0x6fc80073,0x00000000}},	//   _monl, _ohw_, _तोडू, --, 
   {{0xb8cc09d9,0x443c0cfd,0x61e143fd,0xb8fc09ae}},	//   _कह_, _nhw_, _lonl, _तप_, 
   {{0xb864021a,0x61e08045,0xb4cc00dc,0xafd801bf}},	//   _چارو, _oonl, शम्_, kmøn, 
   {{0x61e143fe,0xb8650001,0x443c031c,0xd1d0001f}},	//   _nonl, _نارو, _ahw_, ጥበት_, 
   {{0x443c0a2e,0xab580e78,0x00000000,0x00000000}},	//   _bhw_, _knüp, --, --, 
   {{0xe8d40302,0x443c0368,0x61e00332,0x00000000}},	//   _דולר_, _chw_, _aonl, --, 
   {{0x61e143ff,0x443d4400,0xa34001c0,0x67f0010e}},	//   _bonl, _dhw_, жээл, _uçja, 
   {{0x61e0b9f5,0xceb80124,0x00000000,0x00000000}},	//   _conl, ҳәо_, --, --, 
   {{0xe978008f,0x6e254401,0xaa34010f,0x00000000}},	//   כניש, vojb, שטיק_, --, 
   {{0x61e13e73,0x99980064,0xb1800055,0x00000000}},	//   _eonl, _kirų_, _ũådr, --, 
   {{0x61e14402,0x6e24154c,0x14b401f9,0xe294009b}},	//   _fonl, tojb, ंबवण, _вач_, 
   {{0x61e00205,0xa154026b,0xdb040037,0xa1914403}},	//   _gonl, _кашу_, ndiõ, _дашч, 
   {{0x6e254404,0xdb0406af,0x8fd000fb,0x00000000}},	//   rojb, lfiè, _еҙнә, --, 
   {{0x61e0e8eb,0xab5800b8,0x00000000,0x00000000}},	//   _zonl, _saüb, --, --, 
   {{0x7d1c0175,0x61e14405,0xdb04002f,0x81b800eb}},	// [20510] _exps, _yonl, zdiö, ঙার_, 
   {{0xf8b405f5,0x61e001b9,0x1a6801b9,0x00000000}},	//   өөс_, _xonl, شیفی_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x443c01ee,0x2c0401d3,0x9a8401f4,0x00000000}},	//   _rhw_, _مٹھی_, _мурл, --, 
   {{0x64a00032,0xa2b400dc,0x443c01ef,0x00000000}},	//   ҡаҙа, ्टस्, _shw_, --, 
   {{0x61e001a9,0xd5b800ef,0x00000000,0x00000000}},	//   _ronl, _akās_, --, --, 
   {{0x61e126a0,0x1d180375,0xd79400a7,0xa5140490}},	//   _sonl, יקור_, _мисъ, _तशीच_, 
   {{0x61e14406,0xf1d00574,0xafd8005c,0x00000000}},	//   _ponl, तांन, tmøn, --, 
   {{0x6738110c,0x61e0fa80,0x00000000,0x00000000}},	//   _izuj, _qonl, --, --, 
   {{0x61e14407,0x443c0112,0xafd80b34,0x00000000}},	//   _vonl, _thw_, rmøn, --, 
   {{0xafd82d75,0xbe6801c0,0x00000000,0x00000000}},	//   smøn, ламж_, --, --, 
   {{0xa280158b,0x61e14408,0x00000000,0x00000000}},	//   _بیخو, _tonl, --, --, 
   {{0x4e183334,0xfce54409,0x7ff4fd61,0xa3cc37d0}},	//   аюся_, бого, _گستا, शाक_, 
   {{0x409406d5,0xa2b400dc,0x06a42d40,0x00000000}},	//   _العر, ्टव्, ﺎﻧﻨﯩ, --, 
   {{0x06bc015b,0x673801a6,0xd25401d5,0xeb940075}},	//   _আপনি, _ozuj, _دییش_, йис_, 
   {{0x68e05df4,0x0c940023,0xba1831b1,0xab580055}},	// [20520] ändn, _ይግለጽ_, هيرا_, _saüc, 
   {{0xdb04004a,0xb9540114,0x00000000,0x00000000}},	//   nfié, стаћ, --, --, 
   {{0x224801f1,0xb178008f,0x6d380092,0xb4b40037}},	//   ícky_, רטער, _በስፖር, _छने_, 
   {{0xfaa4022e,0x56680023,0x288845cc,0x00000000}},	//   _ламо, _ዝተወጠ, اصلی_, --, 
   {{0x67380034,0xe0c42354,0x78740014,0xad8400d1}},	//   _czuj, _کز_, _گُزا, _ئاۋۇ, 
   {{0x91ac04c5,0xdcfc0790,0x00000000,0x00000000}},	//   _কোনখ, lerı, --, --, 
   {{0xdb05440a,0x00000000,0x00000000,0x00000000}},	//   rdiõ, --, --, --, 
   {{0xb9e40020,0x00000000,0x00000000,0x00000000}},	//   _ራሱ_, --, --, --, 
   {{0x7d180a85,0x6d400122,0x51f8014b,0x0cc40037}},	//   ûtsj, _únav, инию_, _लछ्म, 
   {{0x753801c7,0xdb04068c,0x7761440b,0x00000000}},	//   _tztz, rfiè, lcox, --, 
   {{0xa3cc2ce6,0xdcfc0205,0xb0300139,0x00000000}},	//   शाख_, kerı, змнә, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7334034c,0x9cc801e0,0xdcfc1ea0,0x69d80aa2}},	//   _ارائ, ҙыра_, derı, नामी, 
   {{0xe7cc04fa,0xa2b41f13,0x23240063,0x817400db}},	//   _सोनप, ्टर्, _уочи_, _ۇنۇچ, 
   {{0x317d440c,0xdcfc0166,0x00000000,0x00000000}},	//   matz_, ferı, --, --, 
   {{0x317d440d,0x999400bc,0xdcfc013d,0x00000000}},	//   latz_, _češi_, gerı, --, 
   {{0x7c3806af,0x7e740142,0x5f443e52,0x20d00137}},	// [20530] îtra, _gwyp, _ىنىل, _وقۇس, 
   {{0x317d440e,0x68e0007c,0x00000000,0x00000000}},	//   natz_, ändo, --, --, 
   {{0x6d540944,0x67380327,0xdcfc0205,0x00000000}},	//   _igxa, _szuj, berı, --, 
   {{0x317d440f,0xd8754410,0x47354411,0xed300014}},	//   hatz_, سامب, онес, _ووکھ, 
   {{0x21f8019f,0xe708034c,0xe784036b,0x317d4412}},	//   _hêhe_, دتان_, _қуво, katz_, 
   {{0x317c2508,0x63a805b1,0x19580024,0x00000000}},	//   jatz_, _sbgn, _гары_, --, 
   {{0xe7840aa5,0x6d540408,0x44280016,0x06a40075}},	//   _гузо, _mgxa, _ưa_, ﺎﻧﻠﯩ, 
   {{0x68e0365a,0x00000000,0x00000000,0x00000000}},	//   øndu, --, --, --, 
   {{0xafd85522,0xd7f801c0,0x317c067c,0x821800d8}},	//   rmøl, _уур_, fatz_, ицот_, 
   {{0x6d542d2f,0x008401c0,0x317d4413,0x80a94414}},	//   _ngxa, олоо, gatz_, авов_, 
   {{0xf9901203,0x7e7406f2,0x362401d9,0x312001c6}},	//   ורי_, _swyp, _بولہ, ддэг, 
   {{0x6d54009a,0x41c40014,0xf1d000bc,0xeabc0248}},	//   _agxa, _ژٲشِ, ताउन, _osù_, 
   {{0x317c0ba1,0x403401e0,0xddc40356,0xd1b92f7e}},	//   batz_, йеүс, _cuiş, _گانا_, 
   {{0x317d4415,0x7c649fbd,0xd44400cd,0x409400f0}},	//   catz_, قارل, _iṣṭv, _дрит, 
   {{0xd1b94416,0x68e14417,0x8c48013d,0x02a8000d}},	//   _دانا_, ändl, _oxşı, _कहुन, 
   {{0x6d54009a,0xaef80051,0x00000000,0x00000000}},	//   _egxa, mcùn, --, --, 
   {{0xb4b402f8,0xaf0002e8,0x00000000,0x00000000}},	// [20540] _छन्_, _опъл, --, --, 
   {{0xe9d50878,0xaa4001ec,0x00000000,0x00000000}},	//   оку_, деул, --, --, 
   {{0xd910dbb4,0x9f400432,0x00000000,0x00000000}},	//   ریر_, _iliñ_, --, --, 
   {{0x656001fb,0xb8e001ad,0x317c068c,0x85741954}},	//   ecnh, _ऍन_, zatz_, _ጽሕፈቱ_, 
   {{0xf6243a49,0x7c346282,0x00000000,0x00000000}},	//   оддо, mlyr, --, --, 
   {{0x7c354418,0xb4b004a9,0x533401e0,0x00000000}},	//   llyr, дикә, үект, --, 
   {{0x317c067c,0x00000000,0x00000000,0x00000000}},	//   vatz_, --, --, --, 
   {{0x88800050,0x00000000,0x00000000,0x00000000}},	//   _سیٖن, --, --, --, 
   {{0x317c068c,0xb6a40108,0x00000000,0x00000000}},	//   tatz_, _физл, --, --, 
   {{0x51f80a4a,0x7c3402d0,0x00000000,0x00000000}},	//   сною_, hlyr, --, --, 
   {{0x317d4419,0x69d80574,0x69b40375,0x7c340098}},	//   ratz_, नाती, חליף_, klyr, 
   {{0x317d441a,0x00000000,0x00000000,0x00000000}},	//   satz_, --, --, --, 
   {{0x317c07c5,0x38680332,0x7c340857,0x00000000}},	//   patz_, _ltbr_, dlyr, --, 
   {{0xc0d41540,0x317c0200,0x00000000,0x00000000}},	//   ርሃም_, qatz_, --, --, 
   {{0x49740598,0x712400c6,0x7c3403cb,0x9e340114}},	//   җлес, _برشل, flyr, ферч, 
   {{0x6024026a,0x3eb00334,0x704400db,0x9f4000a2}},	//   _одја, _fpyt_, _بئتك, _eliñ_, 
   {{0x8e140276,0xdb04002f,0x00000000,0x00000000}},	// [20550] _ндиц, rgiß, --, --, 
   {{0x6d548891,0xf4280327,0x5fac0210,0x00000000}},	//   _ugxa, _སྩལད_, ट्ठल, --, 
   {{0x2905441b,0x9f4001a8,0x7c34127b,0x5fd00073}},	//   àna_, _hlið_, blyr, _तोडल, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7bd80302,0xd8780075,0x06e003d4,0xad240fa2}},	//   _הקרו, ممەت_, _মেজি, _درکو, 
   {{0x290400c6,0x6d400789,0xc8c80451,0x68e012e8}},	//   únas_, _únas, _ٿورن_, ønds, 
   {{0x57e402dd,0x6f0006be,0x00000000,0x00000000}},	//   _ﺍﻗﯩﺮ, _ənca, --, --, 
   {{0xc2c4007b,0x461404f2,0x9d1c0115,0x00000000}},	//   كيبي, _کوئر, יווט, --, 
   {{0xc6f801c6,0x237d441c,0x00000000,0x00000000}},	//   _унах_, rauj_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf9901a4c,0x3eb1441d,0x7c340204,0x9f40032e}},	//   ערט_, _spyt_, ylyr, _alið_, 
   {{0xa3b8b460,0xab580055,0x00000000,0x00000000}},	//   _خاطر_, _saün, --, --, 
   {{0x442d14c9,0x225c0194,0xd1f80092,0x833401c4}},	//   moe_, qquk_, ገሮች_, _эндх, 
   {{0x442c0184,0xfce5441e,0x6220030c,0x00000000}},	//   loe_, пого, _توتە, --, 
   {{0x7c3806af,0x7c35441f,0xf1b00375,0xfce400d4}},	//   îtro, tlyr, _נסה_, чово, 
   {{0xb9180521,0xebe00e48,0xdff4010a,0x3944035b}},	//   anyị_, носп, _цӏоь, ҧнаг, 
   {{0x9f400174,0x6ff8011a,0xf9903346,0x7c34035a}},	// [20560] _glið_, _להקפ, فبا_, rlyr, 
   {{0x442d4420,0x3f814421,0xdcfc85a2,0x7c3402d0}},	//   hoe_, laku_, larč, slyr, 
   {{0x442d4422,0x83bc0073,0x2cb00051,0x7c28011c}},	//   koe_, ्याआ, _gpxd_, _гонг_, 
   {{0x3f814423,0x442d4424,0x9f400ecf,0x2a680334}},	//   naku_, joe_, _goiã_, _ftcb_, 
   {{0x442d4425,0x3f8000b0,0x29040252,0x00000000}},	//   doe_, iaku_, únar_, --, 
   {{0x7bc54426,0x3f814427,0x9f400137,0x57e40150}},	//   _haku, haku_, _moià_, _ﺍﺗﯩﺮ, 
   {{0x3f814428,0x442c1140,0xdcfd4429,0x00000000}},	//   kaku_, foe_, karč, --, 
   {{0x442c0032,0x293400c8,0x12d40395,0xc76400d1}},	//   goe_, _זאלן_, джия, _ياقى, 
   {{0x3f81442a,0xdcfc5a54,0x7228005b,0x59e007b6}},	//   daku_, darč, йцов_, नापर, 
   {{0xf124030d,0x055c0150,0x716000db,0x00000000}},	//   зьмо, _күшi_, رھتە, --, 
   {{0x68f802a8,0x3f81442b,0x713c02d3,0x7bc5442c}},	//   _ƙudi, faku_, _ባዕላቶ, _oaku, 
   {{0x3f80105c,0x442d442d,0x84542002,0xdcfc00f3}},	//   gaku_, coe_, _قىلچ, garč, 
   {{0xab580793,0xdef9442e,0x00000000,0x00000000}},	//   _daül, пыр_, --, --, 
   {{0x7bc40bd7,0xdcfc00de,0x00000000,0x00000000}},	//   _aaku, cgrī, --, --, 
   {{0x3f81442f,0xe0cc4fca,0xa0a0041b,0xe7cc00dc}},	//   baku_, _مزي_, _зајд, _सोऽप, 
   {{0x7bc54430,0x9d180107,0xd1b80116,0x00000000}},	//   _caku, чост_, _داچا_, --, 
   {{0x4a554431,0x7bc54432,0xdd0c012d,0x00000000}},	// [20570] дкас, _daku, góła, --, 
   {{0x7bc40086,0x5a34026a,0x442d4433,0xa2bc2713}},	//   _eaku, енут, zoe_, _वनस्, 
   {{0x2d814434,0x7bc54435,0xbd3402dd,0x442c037e}},	//   maje_, _faku, _жүру_, yoe_, 
   {{0x2d814436,0x7bc54437,0x260c01ad,0x7d182268}},	//   laje_, _gaku, थोनी_, útse, 
   {{0x442d4438,0x7b6401d9,0xc0dc010c,0xe698033f}},	//   voe_, _تاپٕ, _ኒውስ_, _żołą, 
   {{0x7bc4856e,0x2d814439,0x3f81443a,0xdcfc09a8}},	//   _zaku, naje_, zaku_, zarč, 
   {{0x442d443b,0xc8c90935,0x69c40472,0x3f81443c}},	//   toe_, _بوزن_, _iaje, yaku_, 
   {{0x2d81443d,0x6b9c0399,0x3f80005a,0x7bc5443e}},	//   haje_, ngqg, xaku_, _xaku, 
   {{0x69c5443f,0x442d4440,0x2d80b8b7,0x3f814441}},	//   _kaje, roe_, kaje_, vaku_, 
   {{0x69c54442,0x442c052f,0x3f814443,0x46140691}},	//   _jaje, soe_, waku_, _غوار, 
   {{0x3f814444,0x442d4445,0xab58004e,0xdcfc0024}},	//   taku_, poe_, _paül, tarč, 
   {{0x69c54446,0x00000000,0x00000000,0x00000000}},	//   _laje, --, --, --, 
   {{0x7bc54447,0x63b94448,0x69c4030a,0x35d0000d}},	//   _raku, meun, _oaje, _धोड़, 
   {{0x7bc54449,0x2d81444a,0x3f81444b,0x63b9444c}},	//   _saku, gaje_, saku_, leun, 
   {{0xed55444d,0x3f81444e,0x7bc4f313,0xab58004e}},	//   дор_, paku_, _paku, _taül, 
   {{0x63b83386,0x7bc5444f,0x60c001e1,0x3f80004b}},	//   neun, _qaku, _isnm, qaku_, 
   {{0x7bc54450,0xd24c0272,0x2d80d499,0x69c46677}},	// [20580] _vaku, _خۆی_, baje_, _baje, 
   {{0x7bc51018,0x69c54451,0x63b83386,0x98b00331}},	//   _waku, _caje, heun, žači_, 
   {{0x7bc54452,0x69c430b6,0x63b83386,0x00000000}},	//   _taku, _daje, keun, --, 
   {{0x63b94453,0x69c40363,0xdd0c0210,0x00000000}},	//   jeun, _eaje, póła, --, 
   {{0x63b94454,0x69c54455,0xf62802dd,0x56954456}},	//   deun, _faje, يستى_, халт, 
   {{0x69c54457,0x63b80381,0x74690e16,0x00000000}},	//   _gaje, eeun, орив_, --, 
   {{0x628c3822,0x63b80de2,0x87d80c75,0x69d80b9a}},	//   ácon, feun, تبەس_, नारी, 
   {{0x69c41326,0x63b94458,0x00000000,0x00000000}},	//   _zaje, geun, --, --, 
   {{0x69c54459,0xe7d000db,0x2d81445a,0x66e40171}},	//   _yaje, _جۅنگ, yaje_, _cūkā, 
   {{0xc6440e56,0x00000000,0x00000000,0x00000000}},	//   _كئلى, --, --, --, 
   {{0x2d81445b,0x63b94454,0x64a0fbd3,0x798c02d0}},	//   vaje_, beun, _ааха, _mdbw, 
   {{0x68e1445c,0x2d81445d,0x6298089c,0x63b91b97}},	//   ändi, waje_, buuo, ceun, 
   {{0xfe6c0517,0xe28001c6,0x00000000,0x00000000}},	//   یگی_, _алчи, --, --, 
   {{0x798c03ac,0x00000000,0x00000000,0x00000000}},	//   _ndbw, --, --, --, 
   {{0x2d81445e,0x69c5445f,0x628c00e2,0xebc40063}},	//   raje_, _raje, ākoņ, мљан, 
   {{0x2d814460,0x69c54461,0xa0080597,0xaf514462}},	//   saje_, _saje, _يقول_, _инйә, 
   {{0x69c407e4,0x2d814463,0x69d817ee,0x00000000}},	// [20590] _paje, paje_, नाली, --, 
   {{0x69c422a9,0x1e14084c,0x63b8005a,0x00000000}},	//   _qaje, _амья, zeun, --, 
   {{0x69c4004c,0x61e4049f,0x63b800d5,0xf8b40228}},	//   _vaje, öjli, yeun, нөт_, 
   {{0x69c54464,0x5fbc00df,0x00000000,0x00000000}},	//   _waje, ַצונ, --, --, 
   {{0xd7c8b184,0x63b80481,0xade0012d,0x00000000}},	//   بونه_, veun, खापन_, --, 
   {{0x63b83386,0x69c401c8,0x35a001d5,0x00000000}},	//   weun, _uaje, гашг, --, 
   {{0x63b94465,0x68f80b45,0x66e40171,0x3a2400e4}},	//   teun, _ƙudu, _sūkā, éope_, 
   {{0x66e402b5,0xee3c01f1,0x321d4466,0x63b80c6a}},	//   _pūkā, dtým_, enty_, ueun, 
   {{0x63b94467,0x27fc009d,0x17f800c6,0x00000000}},	//   reun, _ilun_, _غرفة_, --, 
   {{0xddc40bb8,0x63b94468,0xa5448f6e,0xdb04b38d}},	//   _otiš, seun, _قضاو, nfiá, 
   {{0xdcfd0e34,0x63b83386,0x27fc06a3,0x9324dc96}},	//   karā, peun, _klun_, فرین, 
   {{0x66e402b5,0x6adc07f7,0x70500133,0x00000000}},	//   _tūkā, _नपूर, ێنیا, --, 
   {{0xddc54469,0x66dc0085,0xafd80b1a,0xdcfc0b13}},	//   _atiš, _bákɔ, kløf, darā, 
   {{0x27fc00a9,0xb7d40241,0xd0680220,0x00000000}},	//   _llun_, _iṣey, _ﺍﻟﯩﭗ_, --, 
   {{0x27fc07c4,0xafd80450,0xf0a4002e,0xd1640395}},	//   _olun_, dløf, _ñàpp_, _ръчи, 
   {{0x8b9454c9,0x2fc80175,0x9f940022,0x798c02d0}},	//   круч, cdcg_, _рыкә, _sdbw, 
   {{0x2000003a,0xeb94084c,0x6c3045cc,0xddc400c0}},	// [205a0] _ilii_, эит_, افقا, _etiš, 
   {{0x27fd446a,0xd00404c5,0xa9a001c0,0x2f44010b}},	//   _alun_, _উদয়_, лиуд, _япып_, 
   {{0x27fc0175,0xcee8158b,0x3e54013a,0xdcfc002b}},	//   _blun_, _فرین_, _větě_, barā, 
   {{0x27fc015d,0x08080d2f,0xe1e40133,0x69200124}},	//   _clun_, وزني_, _ڵس_, ымха, 
   {{0xafd8332c,0x321c03a2,0x3e64002e,0xe78400f1}},	//   mmøt, ynty_, _jôt_, رپوه_, 
   {{0x7af4005b,0x3e64004d,0xafd8143a,0xee3c02f0}},	//   myyt, _môt_, lmøt, ytým_, 
   {{0x2000198f,0x27fc01b8,0xb7d40cad,0x3e640100}},	//   _olii_, _flun_, _aṣey, _lôt_, 
   {{0xafd87e78,0x27fc3a45,0xf60808dc,0x3d0c012c}},	//   mløg, _glun_, _کتره_, _सधैं_, 
   {{0xe3ac3b6c,0x3e64932f,0x656c054e,0x7af40108}},	//   صري_, _nôt_, _şche, nyyt, 
   {{0x2001446b,0xb9fc0092,0xf1a41171,0xe7340120}},	//   _alii_, _ቀኑ_, хрин, _џеф_, 
   {{0x76580472,0x200001c3,0xd3a4035b,0x7af4005b}},	//   _iity, _blii_, _алеқ, hyyt, 
   {{0x200083bf,0x765800b5,0x7af4023a,0xdb0400e4}},	//   _clii_, _hity, kyyt, heiñ, 
   {{0xdcfc0882,0xee3c0122,0x76582252,0x200000a3}},	//   varā, stým_, _kity, _dlii_, 
   {{0xf1a800aa,0x2000208d,0xe12005f5,0x6ce402dd}},	//   _راته_, _elii_, _өмчи, нібе, 
   {{0xc0c40588,0xdcfc0882,0x7659446c,0xb35401b9}},	//   _ашық, tarā, _mity, _تیکا_, 
   {{0x7658b432,0xafd811c0,0x00000000,0x00000000}},	//   _lity, dløg, --, --, 
   {{0x3e65446d,0x765800c7,0x7538005c,0x00000000}},	// [205b0] _gôt_, _oity, _lytz, --, 
   {{0x76580a28,0xafd80174,0x6ce40064,0x00000000}},	//   _nity, fløg, _зіме, --, 
   {{0xdcfc3a6e,0xfcc000d1,0x7c5c001f,0xafd8383d}},	//   parā, _кәтм, ዲኖረው_, rløf, 
   {{0x7659446e,0xafd82ab7,0x2001446f,0x7af4005b}},	//   _aity, sløf, _xlii_, byyt, 
   {{0x76594470,0xafd8143a,0xd73400c7,0xb7f0012d}},	//   _bity, pløf, лхшь, _अकरम_, 
   {{0xdb040008,0x04b400c2,0xca4801b9,0x628c00d8}},	//   meið, всия, _آلسه_, ácom, 
   {{0xdb041bb0,0x58d40348,0x76594471,0x7580035c}},	//   leið, _йорт, _dity, شینم, 
   {{0x1958b71d,0x9a8801d9,0x76580024,0x27fc53d5}},	//   _часы_, _زنہٕ_, _eity, _ulun_, 
   {{0x7c3820ef,0x76584e79,0x86542cdd,0xa2cc00eb}},	//   îtri, _fity, _аках, াঙ্খ, 
   {{0x3e64002d,0x76594472,0x00000000,0x00000000}},	//   _rôt_, _gity, --, --, 
   {{0xdb04066a,0x20000254,0xafd803b2,0xd5b83dad}},	//   heið, _plii_, klød, _яст_, 
   {{0xdb041f60,0x3e64002d,0x76594473,0x673800b5}},	//   keið, _pôt_, _zity, _kyuj, 
   {{0x76580fec,0x6738037e,0x00000000,0x00000000}},	//   _yity, _jyuj, --, --, 
   {{0xeff002d3,0x7af4023a,0x53e4035b,0x62200137}},	//   _ግዳይ_, vyyt, _ацәа, _حوتە, 
   {{0x15f422e3,0xafd83c38,0xc6bc00cc,0x00000000}},	//   _अवसर_, flød, _আপোচ, --, 
   {{0x3e654474,0x200003a0,0x2bc401f9,0x00000000}},	//   _tôt_, _ulii_, _लसणा, --, 
   {{0xafd85792,0x6b614475,0xef1c030a,0xdb0403b2}},	// [205c0] rmøt, ркуа, laün_, geið, 
   {{0xafd8dd44,0xaf440050,0x7af40108,0x3c6400f3}},	//   smøt, _جرى۪, ryyt, _иког, 
   {{0x7af402f6,0xeb9c037e,0xafd94476,0x67380055}},	//   syyt, _blød_, pmøt, _ayuj, 
   {{0xdb045573,0x76585f79,0x59e0038e,0x67394477}},	//   beið, _sity, नाहर, _byuj, 
   {{0x76594478,0x673800ca,0x75385d2e,0xeb9c06ea}},	//   _pity, _cyuj, _sytz, _sløg_, 
   {{0x7d0003f9,0xafd80162,0x00000000,0x00000000}},	//   _ƙosh, nmør, --, --, 
   {{0x34494479,0x7659447a,0xeb9c01bf,0x52bc0e49}},	//   мчин_, _vity, _flød_, ्ट्स, 
   {{0x67381509,0xb7d9447b,0x76588cf6,0xeb9c2ab7}},	//   _fyuj, _تورا_, _wity, _glød_, 
   {{0x7538000f,0x7659447c,0xb6a401b9,0xf2041b0a}},	//   _wytz, _tity, _шиал, вяно, 
   {{0x765802e2,0xe7240835,0x952c01f3,0x00000000}},	//   _uity, _роуд_, ትራክተ, --, 
   {{0xa99800c8,0x00000000,0x00000000,0x00000000}},	//   וביר, --, --, --, 
   {{0xeb9c00ed,0x2d8400d7,0xaf50008e,0x00000000}},	//   _kløe_, _žne_, иннә, --, 
   {{0x43740107,0x9294d3ff,0x5f940395,0xceb804b4}},	//   _сухт, _салц, шият, хәй_, 
   {{0x41c00003,0x3f90009a,0xdb042833,0x00000000}},	//   _ཀིརྟ, _edyu_, veið, --, 
   {{0x5e58084c,0x91ec01e4,0xc0d4001f,0xe6bc610a}},	//   тиря_, _riցh, ይቃል_, _एन्ज, 
   {{0xa4b40375,0x00000000,0x00000000,0x00000000}},	//   כללה_, --, --, --, 
   {{0xafd801bf,0x70900117,0x00000000,0x00000000}},	// [205d0] rlød, _сақф, --, --, 
   {{0xdb041bb0,0x973c1772,0x673804ce,0x00000000}},	//   reið, _ኢሳያስ, _ryuj, --, 
   {{0x9964ca77,0x2ba81152,0xabb000fd,0x6738344a}},	//   ртул, _छापा, _канә, _syuj, 
   {{0xafd8005c,0x8a600133,0x00000000,0x00000000}},	//   lløb, _هێرۆ, --, --, 
   {{0xd6a80bce,0xdcfc054e,0x9a84014b,0xd75801f7}},	//   ندوم_, pară, _вусл, نجها_, 
   {{0x68e0049f,0x7c2001e4,0xafd8005c,0xd1bc0023}},	//   änds, _ĉori, nløb, ዳድባ_, 
   {{0x195800cf,0x43682a68,0x15800150,0x00000000}},	//   _аары_, найн_, _ﺮﻩﺗﯩ, --, 
   {{0x42c89d11,0x957c0064,0x00000000,0x00000000}},	//   егин_, _anąd, --, --, 
   {{0xe0640125,0x66800133,0x42540484,0x00000000}},	//   _ተቃዋሚ_, _ئیتل, лтот, --, 
   {{0xb7d40241,0x00000000,0x00000000,0x00000000}},	//   _iṣay, --, --, --, 
   {{0x43940166,0xafd8005c,0x00000000,0x00000000}},	//   _баес, dløb, --, --, 
   {{0xb600025c,0xb7d400dc,0xb4f8010f,0x00000000}},	//   _ġġie, _kṣay, _אלער, --, 
   {{0x81d4010b,0x9d200154,0x00000000,0x00000000}},	//   _бцйц, _ধরেন_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xafd811c0,0x6f0003b9,0x00000000,0x00000000}},	//   rmør, _ənci, --, --, 
   {{0xeb9c7a1e,0xafd80ac8,0xa964136b,0x00000000}},	//   _smør_, smør, ҳифа_, --, 
   {{0x629802f6,0xfba8c6e5,0x3a240440,0x3cfc01a6}},	// [205e0] nruo, ङ्गम, гмаг, štv_, 
   {{0xaf0000cf,0xca9001ec,0xee3c00e4,0x62980064}},	//   _ыпыл, _ﺟﻪﺗﻪ_, ytýi_, iruo, 
   {{0x3ea1447d,0xb7d40ca8,0x00000000,0x00000000}},	//   lukt_, _aṣay, --, --, 
   {{0x2ba8590f,0x69c1447e,0x62980024,0xa3d400c5}},	//   _छाया, ôner, kruo, ायफ_, 
   {{0xa3d40cb4,0x68e001e6,0x6359447f,0x369403f6}},	//   ायन_, ändr, _jānī, ушес, 
   {{0x6fd80166,0x7c3400ad,0xd474074d,0x1dd400cd}},	//   _käcä, loyr, алкъ, दयित, 
   {{0x64480ac5,0x2a38011a,0xca340150,0x00000000}},	//   _bhgi, _נעלמ, _ﺯﺍﺀ_, --, 
   {{0x68e0aa94,0x6448010a,0x2ca41512,0x13f425ea}},	//   ånde, _chgi, _ånde_, рзия, 
   {{0x62980024,0x63580055,0x1dd407b7,0x38ac00a2}},	//   gruo, _nānī, दयात, lýr_, 
   {{0x51f80212,0x7c344cb7,0x521417cd,0x25d8098a}},	//   тною_, hoyr, рдот, _गोपी_, 
   {{0xaca001f2,0xe0210676,0x6fd80166,0x6298005b}},	//   _kwụg, मचंद_, _näcä, aruo, 
   {{0x3ea00158,0x7c3401c4,0x62980153,0x2fdc1bce}},	//   fukt_, joyr, bruo, ñug_, 
   {{0x63580055,0xafd801bf,0x00000000,0x00000000}},	//   _cānī, tløb, --, --, 
   {{0xd2502961,0x6fd80139,0x635800b8,0x00000000}},	//   _بنت_, _bäcä, _dānī, --, 
   {{0xafd8037e,0xab58068c,0x5ce493fb,0x7c340076}},	//   rløb, _laüt, бюта, foyr, 
   {{0x69a4033d,0x38ac2200,0xddd40cf4,0x3ea12d6d}},	//   _चाही, dýr_, đašn, bukt_, 
   {{0xafd800b5,0xdb04180f,0xc90000cc,0x00000000}},	// [205f0] pløb, ngiè, _এখেত_, --, 
   {{0x1cb80489,0x38ac03b2,0xb7d40055,0x0c7400f2}},	//   _ཚརཝ_, fýr_, _rṣay, _نگرد, 
   {{0xe1dc037e,0x7c34011f,0x6fd80139,0xc5cc0154}},	//   _av系_, boyr, _gäcä, লামপ, 
   {{0x62980024,0x7c34062c,0x63580055,0xda7001d9}},	//   yruo, coyr, _hānū, تُے_, 
   {{0x68e00450,0xb78400fd,0xd774007b,0x00000000}},	//   åndb, рәсе_, صانع, --, 
   {{0x6298a8ca,0x635800b8,0x57a4035b,0x2128054e}},	//   vruo, _jānū, ашәа, şchi_, 
   {{0x2aac03be,0xdb0401f5,0x6fd80139,0x00000000}},	//   lüb_, ygië, _xäcä, --, 
   {{0xaca0063f,0x443800d8,0xc2c4007b,0x7b080790}},	//   _gwụg, ôs_, ليبي, _öptü, 
   {{0x02054480,0x49180574,0x2aac0213,0x62980153}},	//   изин, _येतो_, nüb_, uruo, 
   {{0x62981f15,0x00000000,0x00000000,0x00000000}},	//   rruo, --, --, --, 
   {{0x62982e70,0x6eec0166,0x4048004e,0x00000000}},	//   sruo, _sеbе, кпоо_, --, 
   {{0x44d4123c,0x6fd8013d,0x635800cd,0x2aac03e3}},	//   _iā_, _räcä, _pānī, küb_, 
   {{0xc0cc069c,0x44d54481,0x6fd8014a,0xfe4401b9}},	//   _እዞም_, _hā_, _säcä, инмо, 
   {{0x44d54482,0xee354483,0x6fd80793,0x3ea14484}},	//   _kā_, иня_, _päcä, rukt_, 
   {{0x44d400da,0x20d000ef,0x00000000,0x00000000}},	//   _jā_, _uģi_, --, --, 
   {{0x44d54485,0x0cb8009e,0x635800b8,0x3da400c7}},	//   _mā_, ুমূত, _tānī, ырҭб, 
   {{0x70514486,0x44d4123c,0xf9900f87,0x25d800af}},	// [20600] _بنيا, _lā_, قبا_, _गोभी_, 
   {{0x0b594487,0x44d40421,0x7e754488,0xa3d4012d}},	//   урсы_, _oā_, _ityp, ायड_, 
   {{0x44d54489,0xfce5448a,0xab5800b8,0xbd440633}},	//   _nā_, _тоно, _saüt, _خندي, 
   {{0xfaa50be9,0xf0b4008f,0x1b040166,0x68400117}},	//   _камо, ילער_, _лүбн, онха, 
   {{0xe7b0aaa2,0xba5402e8,0x2aac03b9,0xe73400d8}},	//   تمند, _втвъ, cüb_, аец_, 
   {{0xa61000d6,0x44d40055,0x38ac0d4e,0x00000000}},	//   оміч, _bā_, pýr_, --, 
   {{0xe0c440c8,0x648401c0,0x7e74010a,0x44d400dc}},	//   _بز_, асыг_, _ltyp, _cā_, 
   {{0xe44c143e,0x44d4002b,0xdb04068c,0x643000ec}},	//   وضي_, _dā_, tgiè, يريء, 
   {{0x44d45632,0x7d180b21,0x52140b32,0x394801a6}},	//   _eā_, útsj, йдит, _hzbs_, 
   {{0x44d5448b,0x00000000,0x00000000,0x00000000}},	//   _fā_, --, --, --, 
   {{0x7e7446dc,0x44d4002b,0xc5ec00f1,0x00000000}},	//   _atyp, _gā_, _سړو_, --, 
   {{0xa3d402e5,0x7e740334,0x2aac0213,0xb6140150}},	//   ायण_, _btyp, yüb_, _ﹸﻡ_, 
   {{0x69a44614,0x44d40109,0x7e740334,0x09c00327}},	//   _चाली, _zā_, _ctyp, _ཁྲྀ_, 
   {{0x27200016,0x44d40882,0x71640131,0x2114036b}},	//   ằng_, _yā_, _ئاشك, اتیب_, 
   {{0x6adc0d26,0x00000000,0x00000000,0x00000000}},	//   नम्र, --, --, --, 
   {{0x7e740334,0x27200030,0x00000000,0x00000000}},	//   _ftyp, nčnú_, --, --, 
   {{0xa3d400ce,0xc61c009e,0x2964399f,0x8c0800eb}},	// [20610] ायत_, দকতা_, ањев, রচলন_, 
   {{0x2aac00ac,0x4c9400c7,0x69a40073,0xb6000413}},	//   rüb_, _лиос, _चाळी, _óáhu, 
   {{0x76b80882,0xdcfc107d,0x27200419,0x00000000}},	//   hāyā, varć, kčnú_, --, 
   {{0x44d41f4c,0xe5300248,0x00000000,0x00000000}},	//   _rā_, _èbéè, --, --, 
   {{0x44d40a28,0xe7084111,0xd66800f1,0xdcfc0153}},	//   _sā_, ختان_, لمنو_, darę, 
   {{0x44d473cf,0x7b4400db,0x1a680244,0x00000000}},	//   _pā_, _دئپل, _ئیلی_, --, 
   {{0xd5e800db,0x18a40024,0x98a4014b,0x15a8011c}},	//   شعون_, _маём, _миёе, ръчи_, 
   {{0x44d41161,0xa6a80616,0x6e2401e7,0x957c012d}},	//   _vā_, _لائق_, hnjb, _pnąc, 
   {{0x44d5448c,0xe5c4815c,0x00000000,0x00000000}},	//   _wā_, _всео, --, --, 
   {{0x44d5448d,0x232402a9,0x814400e5,0x27200419}},	//   _tā_, лоқи_, ینکن, ačnú_, 
   {{0x7e75448e,0x6e240175,0xa3d4033f,0x707407d6}},	//   _styp, dnjb, ायद_, یمیز_, 
   {{0x6e240369,0xdb04007b,0x7e740175,0x263c012d}},	//   enjb, rfiú, _ptyp, _dłoń_, 
   {{0x443c0280,0x237c0023,0xdb0400e5,0x76b80055}},	//   _ikw_, mbuj_, sfiú, cāyā, 
   {{0x3f9c0365,0x81b40154,0x00000000,0x00000000}},	//   ştu_, _চোর_, --, --, 
   {{0x61e1448f,0xdc100055,0x1ee804fb,0xd1b930ed}},	//   _innl, _aśās, _چوبی_, _خانا_, 
   {{0x06f80034,0xb0980a1e,0xafd8366f,0x00000000}},	//   ्नाव_, _עיפר, lløn, --, 
   {{0xfe7000c6,0xed540220,0xefa40150,0x443d4490}},	// [20620] _عدة_, _қою_, _اجىۋ, _mkw_, 
   {{0x443c03fa,0x00000000,0x00000000,0x00000000}},	//   _lkw_, --, --, --, 
   {{0xa3d54491,0x443c2252,0x25e800e1,0xfaa4013e}},	//   ाया_, _okw_, चानी_, раҷо, 
   {{0x9f4006d9,0x2ca40158,0x68e010d1,0x3b08014b}},	//   _anié_, _ånda_, ånda, _бемо_, 
   {{0xc76404a9,0x61e007ab,0xeb9c0162,0x569401c6}},	//   زانى, _onnl, _kløn_, цалт, 
   {{0x443c02e3,0xb86456e8,0x25d88061,0xa9640354}},	//   _akw_, _هارو, _गोदी_, _гира_, 
   {{0x443c05d5,0x00000000,0x00000000,0x00000000}},	//   _bkw_, --, --, --, 
   {{0x3a38049f,0x61e14492,0x76b80882,0x59e00864}},	//   lopp_, _annl, tāyā, नाकर, 
   {{0x27200419,0xa340009d,0x263c0210,0x00000000}},	//   rčnú_, зээл, _słoń_, --, 
   {{0x443c014b,0x3a394493,0xafd80162,0xd0780092}},	//   _ekw_, nopp_, gløn, _የተለዩ_, 
   {{0xd48801c6,0x00000000,0x00000000,0x00000000}},	//   _төлж_, --, --, --, 
   {{0x3a386afa,0x6fe801f0,0x00000000,0x00000000}},	//   hopp_, уфов_, --, --, 
   {{0x3a38713c,0xcfac00d1,0x260c00bc,0x00000000}},	//   kopp_, _ﺳﯚﻫﺒ, थोकी_, --, 
   {{0x76440153,0x00000000,0x00000000,0x00000000}},	//   _ūkyj, --, --, --, 
   {{0x1df80108,0x00000000,0x00000000,0x00000000}},	//   щеры_, --, --, --, 
   {{0xd70821bd,0x1f74013d,0x13ac00eb,0x00000000}},	//   वनाथ_, _елъя, _খসড়, --, 
   {{0x6965178c,0x61e003ac,0x00000000,0x00000000}},	// [20630] مداق, _ynnl, --, --, 
   {{0x1a68114f,0x00000000,0x00000000,0x00000000}},	//   صیفی_, --, --, --, 
   {{0x237c033f,0x9b940116,0x00000000,0x00000000}},	//   ybuj_, زلەت, --, --, 
   {{0xd83801c6,0x00000000,0x00000000,0x00000000}},	//   бэч_, --, --, --, 
   {{0x321c037e,0x3a38002e,0x46a400d4,0x00000000}},	//   kity_, bopp_, іакв, --, 
   {{0xc8c94494,0x443c0af9,0x00000000,0x00000000}},	//   _پورن_, _skw_, --, --, 
   {{0x443d4495,0xaa7803b2,0x321d4496,0xf8ac0451}},	//   _pkw_, _brýg, dity_, _لکن_, 
   {{0x6680066d,0x07351ee7,0x321c0064,0x00000000}},	//   _فیصل, _дебю, eity_, --, 
   {{0xaa7808ce,0x42080063,0x321c2f53,0x00000000}},	//   _drýg, инио_, fity_, --, 
   {{0xaa7803b2,0x443c002f,0xe4a400f0,0x00000000}},	//   _trýf, _wkw_, _грдо, --, 
   {{0xafd94497,0x443d4498,0xaa780162,0x8cc800ab}},	//   rløn, _tkw_, _frýg, _हैलो, 
   {{0x443d4499,0xafd9449a,0x321c0022,0x00000000}},	//   _ukw_, sløn, aity_, --, 
   {{0x614083c9,0x321ce16e,0x00000000,0x00000000}},	//   تىگە, bity_, --, --, 
   {{0xfce405f5,0x61e04606,0xafd803b2,0x00000000}},	//   оого, _unnl, lløl, --, 
   {{0xe7e402dd,0xab58002b,0x3cf403ce,0x00000000}},	//   _ﺍﺗﺎﻟ, _saüp, ीनें_, --, 
   {{0x3868003a,0x200400e2,0xade0012c,0xebe00fac}},	//   _rubr_, ījis_, खाउन_, мосп, 
   {{0x3a38910b,0x0c9402d3,0x00000000,0x00000000}},	// [20640] topp_, _ክግለጽ_, --, --, 
   {{0x2cb0145e,0x38680175,0xae34013e,0x3ea00076}},	//   öndö_, _pubr_, _дӯст_, mrkt_, 
   {{0x3a38a2ec,0xaca000a2,0x38680139,0xb77800cd}},	//   ropp_, _duỳg, _qubr_, _niṣā, 
   {{0x321c0865,0x3a384098,0x00000000,0x00000000}},	//   zity_, sopp_, --, --, 
   {{0x6670a3a9,0x3f800009,0xaa9401ee,0xdb200108}},	//   ودور, ibku_, _мѳрә, äväy, 
   {{0xd1ec02d3,0x321c783a,0x3a0453b2,0x1fb8033f}},	//   ሆታት_, xity_, _بکری_, ेजुड, 
   {{0x321d449b,0x00000000,0x00000000,0x00000000}},	//   vity_, --, --, --, 
   {{0xaa78012c,0x321c033f,0xd5b800b8,0x77840798}},	//   _frýd, wity_, _smād_, _флаз, 
   {{0xd5b80421,0x7bd4009a,0x321c336b,0x00000000}},	//   _amāe_, idyu, tity_, --, 
   {{0x49002d81,0x00000000,0x00000000,0x00000000}},	//   वैको_, --, --, --, 
   {{0x321cb98f,0xb3c814a4,0x3cf40034,0x3ea001c7}},	//   rity_, _влез_, ीनों_, erkt_, 
   {{0x321c0d8b,0x8f346179,0x1cb80327,0xddc402f0}},	//   sity_, земц, _ཛྱེ_, _ctiž, 
   {{0x321d449c,0xa3d41b76,0xdcf000dc,0x73340116}},	//   pity_, ायर_, _ādāy, _بىشا, 
   {{0xdb0402d2,0x00000000,0x00000000,0x00000000}},	//   ffiþ, --, --, --, 
   {{0x48c403f4,0x3f800a2e,0x3ea004e6,0x7ae00419}},	//   _এপ্র, bbku_, arkt_, ťotl, 
   {{0x7bd4089c,0xfb88267c,0xe8e81046,0xf334002b}},	//   gdyu, йруқ_, یراو_, ciṣā_, 
   {{0x671c00ab,0xdcfc01e4,0xaa7800a2,0x00000000}},	// [20650] _मेढक_, marĝ, _orýe, --, 
   {{0xa904027d,0xdcfc00df,0xcfdc0154,0x29fc0210}},	//   يبان, larĝ, _ডকিন, kłań_, 
   {{0x2d8002d3,0x18a402bf,0xe51c00bc,0x00000000}},	//   mbje_, даєм, यपछि_, --, 
   {{0xaa7803f2,0x15e0924b,0xdb0400a2,0x00000000}},	//   _prýd, _गोबर_, lfiý, --, 
   {{0xb77800b8,0x442800a2,0xe6c42309,0x00000000}},	//   _siṣā, _ıa_, تتاي, --, 
   {{0x19a80353,0x00000000,0x00000000,0x00000000}},	//   _мтсп_, --, --, --, 
   {{0xa3d40d01,0xf1ac00bc,0x00000000,0x00000000}},	//   ायल_, ज्छन, --, --, 
   {{0x25d851a5,0x3ea1449d,0x33900131,0x98e4007b}},	//   _गोरी_, yrkt_, ىلىز, _تكفو, 
   {{0x29fc033f,0x850400f1,0x72c00166,0xc32401f4}},	//   ałań_, توګن, ебыз, ямик, 
   {{0xddc40bb8,0x4614141d,0x00000000,0x00000000}},	//   _stiž, _عوار, --, --, 
   {{0xc0e4316e,0xafd80217,0xcea80a7c,0x00000000}},	//   чонк, lmøy, _תי_, --, 
   {{0x4429449e,0xafd9449f,0xd4c4f7c2,0xd3d800f2}},	//   _ña_, bløm, _юсуп, _وبنا_, 
   {{0x63b944a0,0x4ed401d5,0x00000000,0x00000000}},	//   mfun, мюрт, --, --, 
   {{0x63b93e38,0x7c640131,0x40947b0e,0x04ec00fe}},	//   lfun, كارل, _ерит, জনীৰ_, 
   {{0x63b83bf2,0x00000000,0x00000000,0x00000000}},	//   ofun, --, --, --, 
   {{0x7bd4079b,0x2d80002d,0x90e469f2,0xb098011a}},	//   udyu, abje_, _آسون, _היקר, 
   {{0x63b944a1,0xd91000e5,0x00000000,0x00000000}},	// [20660] ifun, ھیر_, --, --, 
   {{0x25d8084a,0xd910a675,0x63b8002f,0x00000000}},	//   _गोली_, پیر_, hfun, --, 
   {{0x26dc063f,0x63b944a2,0xa96400a7,0x8d4441e5}},	//   _aruo_, kfun, чиха_, _жүрг_, 
   {{0x26dd44a3,0x9f400165,0xfb8001d3,0xb7d400b8}},	//   _bruo_, _hoiñ_, _سگری, _kṣiy, 
   {{0x63b80327,0xafd8037e,0xb60544a4,0x3714000d}},	//   dfun, fløj, зяйк, _देखअ_, 
   {{0xe3c00724,0xddc40327,0x63b92c51,0x466802dd}},	//   ybıç_, _ntiż, efun, ірім_, 
   {{0xa3d40882,0xef1c0ba1,0x25d80073,0x00000000}},	//   ायं_, laüt_, _गोळी_, --, 
   {{0xc68d44a5,0x00000000,0x00000000,0x00000000}},	//   _چېن_, --, --, --, 
   {{0x798c04ba,0x26dc0115,0x81d40f22,0x93c801ed}},	//   _kebw, _gruo_, হান_, ماکہ_, 
   {{0x06641178,0x63b81418,0x90980261,0xe29c0252}},	//   _قالپ, afun, овот_, áða_, 
   {{0x09e4025c,0xd25000dd,0x733401ed,0xe5a001c4}},	//   _ཨོྃ_, ٹنگ_, _کرائ, _чихи, 
   {{0xa3d40882,0xe7ecb1e3,0xc4c400ae,0x00000000}},	//   ायः_, छाया_, _تتكو, --, 
   {{0xf204156b,0xeb9c00b5,0x656c0356,0xafd93a90}},	//   _няко, _fløj_, _şchi, lløk, 
   {{0xef1c0428,0x798c0337,0x02a402dd,0x00000000}},	//   daüt_, _nebw, _ірім, --, 
   {{0xafd80fac,0x9e2400db,0x00000000,0x00000000}},	//   nløk, رىفو, --, --, 
   {{0x9c440408,0x00000000,0x00000000,0x00000000}},	//   ехул, --, --, --, 
   {{0x798c1682,0xa9c411f7,0x6e280ca8,0x00000000}},	// [20670] _bebw, зсек, _ìgbo, --, 
   {{0x63b80369,0x6f0c2ca8,0xed88117e,0x00000000}},	//   zfun, ıncı, _усик_, --, 
   {{0x798d44a6,0xf8b40228,0xd7c8004b,0x63b9348b}},	//   _debw, мөт_, ګونه_, yfun, 
   {{0x2904038f,0xdcfc0724,0x26dc0115,0x7af000bc}},	//   ġna_, larğ, _pruo_, _šetř, 
   {{0x798c0085,0xd7c800aa,0xdb040798,0x63b805ac}},	//   _febw, ثونه_, rgiã, vfun, 
   {{0xafd87dfa,0x04c8009f,0x28680395,0x00000000}},	//   rmøy, قوتي_, _грао_, --, 
   {{0x63b81cea,0x2904168c,0x24500022,0xafd801bf}},	//   tfun, ønad_, hãme_, rløj, 
   {{0x798c0083,0x26dc010f,0x63b944a7,0x25e81fca}},	//   _zebw, _truo_, ufun, चाही_, 
   {{0x63b944a8,0x98b80024,0x60c00175,0x798c0455}},	//   rfun, _vyrą_, _spnm, _yebw, 
   {{0x63b80d12,0x82344667,0xaa780030,0xb6840023}},	//   sfun, بربا, _zrýc, _ዝሰኣኑ_, 
   {{0x63b944a9,0x9f4144aa,0xa48544ab,0xc60825fe}},	//   pfun, _oniã_, _رجان, वसीय_, 
   {{0x81b400bd,0x63b80200,0x00000000,0x00000000}},	//   _চোখ_, qfun, --, --, 
   {{0x645944ac,0xdcfc00b8,0x00000000,0x00000000}},	//   mmui, dbrā, --, --, 
   {{0x6458cdc8,0xeb9c03b2,0xcdf40137,0x62880142}},	//   lmui, _fløk_, нчсы, _iwgo, 
   {{0x442d44ad,0x798c02e2,0x3dc80083,0x6b8c0051}},	//   one_, _rebw, rebw_, _becg, 
   {{0xed547850,0x798d44ae,0x628944af,0x3dc80083}},	//   фос_, _sebw, _kwgo, sebw_, 
   {{0x442d44b0,0x64580810,0x7e5421fa,0xf1e0000d}},	// [20680] ine_, imui, _отоц, _कोड़_, 
   {{0x2efc03fa,0x798c0477,0x645801ab,0xdb0443e9}},	//   äufe_, _qebw, hmui, ggiá, 
   {{0x442d44b1,0xdb04026c,0x798c014f,0xe94421f4}},	//   kne_, sgià, _vebw, ورمی, 
   {{0x442d44b2,0x798d44b3,0x645944b4,0x62880009}},	//   jne_, _webw, jmui, _owgo, 
   {{0x442c0030,0x798d160e,0x6458ebb3,0x00000000}},	//   dne_, _tebw, dmui, --, 
   {{0x64580618,0xafd808fb,0x00000000,0x00000000}},	//   emui, tløk, --, --, 
   {{0x442d44b5,0x1dc00a28,0x62880067,0xef1c067c}},	//   fne_, श्यत, _awgo, naür_, 
   {{0x442d44b6,0x68e0019b,0xdb040005,0xaa7800d0}},	//   gne_, ænde, lfiñ, _urýc, 
   {{0xeb9c0162,0xafd87e78,0x00000000,0x00000000}},	//   _sløk_, sløk, --, --, 
   {{0x442d44b7,0x64580421,0xf124005b,0x50f4020f}},	//   ane_, amui, дьмо, езот, 
   {{0x25e812eb,0xe81802ab,0xd4c400f7,0x25081888}},	//   चारी_, पोवा_, _чөлк, _ورمی_, 
   {{0x76480042,0xc4c40b24,0x24500588,0x602400e5}},	//   llfy, _ستمو, tãme_, tőma, 
   {{0x2bdc06ab,0xaa7800a2,0x00000000,0x00000000}},	//   _पोषा, _orýa, --, --, 
   {{0xddc400e2,0x68e00fac,0x2450035b,0x00000000}},	//   _puiš, åndk, rãme_, --, 
   {{0x62300220,0xe0cc01ec,0x00000000,0x00000000}},	//   _шешу, _ەزۋ_, --, --, 
   {{0x2bdc07af,0x245000c7,0x5ba4014b,0x00000000}},	//   _पोशा, pãme_, круз, --, 
   {{0x4a541c56,0xdd3800ef,0x04180055,0x6b8c0171}},	// [20690] екас, _gāža, _vīḷa, _vecg, 
   {{0x2bdc0073,0x64580356,0x5a340108,0x00000000}},	//   _पोरा, zmui, внут, --, 
   {{0x442d44b8,0xdb0401ed,0xfcc00131,0x91d803d4}},	//   yne_, rgiá, _йәтм, তাপখ, 
   {{0x442d44b9,0x9f400004,0x473544ba,0x4ed00154}},	//   xne_, _uniã_, ннес, ামীল, 
   {{0x442c74f4,0x68e001bf,0x00000000,0x00000000}},	//   vne_, ændb, --, --, 
   {{0x442d44bb,0x0574315b,0x310c00cd,0x00000000}},	//   wne_, راتد, ानाः_, --, 
   {{0x442d44bc,0xdcfc0311,0x18b800ee,0xf990010f}},	//   tne_, mbră, _огры_, _תרל_, 
   {{0x442d44bd,0x675410e5,0x64580393,0x82f400d8}},	//   une_, _قیاس_, umui, ечоц, 
   {{0x442cad6a,0xd5b800cd,0xf770010f,0xe4e80037}},	//   rne_, _imān_, _תקמ_, _झपकि_, 
   {{0x442ca1f5,0x645800c6,0xee3d21a6,0x00000000}},	//   sne_, smui, yrýa_, --, 
   {{0x76c80014,0x64580156,0x68e00fac,0xd5b8003b}},	//   _وُہہ_, pmui, åndh, _юст_, 
   {{0xbea400c7,0x439405f5,0x442d44be,0x3ce40306}},	//   намк, _чадс, qne_, _čov_, 
   {{0x8eb008b0,0x2ac0005f,0x00000000,0x00000000}},	//   لەيت, nībā_, --, --, 
   {{0xa3d4d3a8,0x135400f7,0x00000000,0x00000000}},	//   ायक_, _شئنج, --, --, 
   {{0x81d4015b,0x00000000,0x00000000,0x00000000}},	//   হাদ_, --, --, --, 
   {{0x21c40150,0x00000000,0x00000000,0x00000000}},	//   _ﺒﻤﺠﺭ, --, --, --, 
   {{0xf41000c8,0xaa7800a2,0x76480142,0x00000000}},	// [206a0] אפן_, _prýa, ylfy, --, 
   {{0xe9d521ee,0x2ac0005f,0x3da800cf,0x00000000}},	//   нку_, dībā_, _экоо_, --, 
   {{0x3f900a73,0x00000000,0x00000000,0x00000000}},	//   _keyu_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x281002da,0xca746171,0x00000000,0x00000000}},	//   دونس, _аусы, --, --, 
   {{0x3f900286,0xaa7944bf,0x00000000,0x00000000}},	//   _leyu_, _krýn, --, --, 
   {{0x18b40588,0xdcfc00b0,0x058401ec,0x77840092}},	//   _шәар, marē, туім, _ይጠይቁ_, 
   {{0xf744013e,0xd1d40023,0x64c001e2,0x00000000}},	//   _зебо, ክዓት_, اييل, --, 
   {{0x2ac000da,0x1cc00135,0xc32c0952,0xa2d05c8d}},	//   cībā_, _གདའ_, يەم_, _बैद्, 
   {{0xb60c02dd,0xafd801bf,0x00000000,0x00000000}},	//   _ﹰﹰ_, nløv, --, --, 
   {{0x64a144c0,0x3f90011f,0x427441b9,0xdb040166}},	//   _баха, _beyu_, нгөс, lgiä, 
   {{0xdcfc0311,0x80b0134e,0xee3c0162,0xf8e005ac}},	//   zbră, _अमरे, grýn_, _যথাথ, 
   {{0xdcfcff26,0xeb9c03cd,0xab5806be,0xb8d00327}},	//   karē, _kløv_, _abün, _དའ_, 
   {{0xaa780252,0x00000000,0x00000000,0x00000000}},	//   _brýn, --, --, --, 
   {{0x9cc944c1,0x2ac000e2,0x98b80064,0x00000000}},	//   ныта_, zībā_, _tyrę_, --, 
   {{0x1bd41b0a,0x00000000,0x00000000,0x00000000}},	//   лося, --, --, --, 
   {{0xdf0805f5,0xdcfc00ef,0x00000000,0x00000000}},	// [206b0] _зээл_, farē, --, --, 
   {{0x2bcc0034,0x9aa4dcb5,0x48c46ba3,0xd5b8002b}},	//   हजहा, املو, кәба, _smān_, 
   {{0xab58145e,0xe82401d5,0x00000000,0x00000000}},	//   _gbün, нфдо, --, --, 
   {{0xab602dc3,0xc6080882,0x2ac0005f,0x2d9017da}},	//   _مۇزى, वस्य_, tībā_, _hexe_, 
   {{0xd9b802f5,0x00000000,0x00000000,0x00000000}},	//   ীয়ম, --, --, --, 
   {{0x2ac0005f,0x2fd80327,0x290407c5,0x80b00011}},	//   rībā_, _laqg_, ùnas_, _জনস্, 
   {{0xda340aec,0x2d900120,0x2ac0005f,0xf990011a}},	//   _серы, _mexe_, sībā_, _כרם_, 
   {{0x1cc00135,0x6e240455,0xab5800b8,0x54340124}},	//   _གདལ_, hijb, _saüy, лхыу, 
   {{0xb9ec069c,0x27fc0295,0x65c00046,0x42542a20}},	//   _ሓቂ_, _ioun_, _бұла, ктот, 
   {{0x2d9000db,0x12c401b9,0xed840023,0x74a80139}},	//   _nexe_, اتيپ, ማንበክ_, чсәң_, 
   {{0x27fd44c2,0x3f900de2,0xe4e8000d,0x00000000}},	//   _koun_, _peyu_, _झपटि_, --, 
   {{0x5154052f,0x27fd44c3,0xdcfc00e2,0x947406c2}},	//   ытыу, _joun_, zarē, _صدما, 
   {{0x27fc13ca,0xde3c001f,0x9394007b,0x00000000}},	//   _moun_, _የህይወ, _إجما, --, 
   {{0x27fd44c4,0xdda00419,0xef1c0205,0xa0680022}},	//   _loun_, ľňou_, mbül_, ьаҟа_, 
   {{0xdcfc00da,0x62980006,0xef1c3361,0xdde400e5}},	//   varē, lsuo, lbül_, ésőb, 
   {{0x27fc37b6,0x20d0054e,0xd16400a7,0x629801f4}},	//   _noun_, _iţi_, _съчи, osuo, 
   {{0xab240288,0x6298b71d,0x2d900694,0x22440ea0}},	// [206c0] вота_, nsuo, _fexe_, _kknk_, 
   {{0x200144c5,0x2d900548,0x27fc0165,0xaa781427}},	//   _hoii_, _gexe_, _aoun_, _trýn, 
   {{0x27fd44c6,0x940c00ac,0xac9c02d3,0xcee944c7}},	//   _boun_, _evdə_, ልኣለም_, _قرین_, 
   {{0x62980006,0xeb9c072b,0xb8c80490,0x37043004}},	//   ksuo, _sløv_, _गट_, кпег, 
   {{0x27fc0c3a,0x2d9018f7,0x200144c8,0xb6f800db}},	//   _doun_, _yexe_, _moii_, بىشا_, 
   {{0x200003a0,0x00000000,0x00000000,0x00000000}},	//   _loii_, --, --, --, 
   {{0x27fc3759,0x624c072b,0x629800c0,0x64440055}},	//   _foun_, røol, esuo, _ījir, 
   {{0x34c01533,0x27fc039a,0x20000276,0x52d807d8}},	//   _शहीद, _goun_, _noii_, емию_, 
   {{0x20d0084c,0x629822d0,0xf1a88150,0x68e020e4}},	//   _aţi_, gsuo, واده_, åndv, 
   {{0x245000c7,0xe734009b,0x00000000,0x00000000}},	//   rãma_, _реу_, --, --, 
   {{0x25d8069f,0x27fc0d29,0x1fdc0729,0x2000b900}},	//   _गोटी_, _youn_, ধানস, _boii_, 
   {{0x2d9144c9,0x80b004c5,0xaa78012c,0x200000b5}},	//   _sexe_, _জনশ্, _brýl, _coii_, 
   {{0x22440327,0x2d900694,0x78bc0332,0x00000000}},	//   _fknk_, _pexe_, htpv, --, 
   {{0x7bc402a8,0x00000000,0x00000000,0x00000000}},	//   _abku, --, --, --, 
   {{0x20d00bbd,0x6e2401a4,0x20000356,0xa3d40073}},	//   _نتيج, rijb, _foii_, ायच_, 
   {{0x91fc0882,0x2d900564,0xaca00521,0x865c0092}},	//   smād, _wexe_, _ntụg, _ህፃናት, 
   {{0x81d403f4,0x27fd1f98,0x2d901bce,0xaa7803f2}},	// [206d0] হার_, _roun_, _texe_, _grýl, 
   {{0x69643955,0xaca00521,0x27fd44ca,0xbfd800b5}},	//   نداق, _atụg, _soun_, _ray版_, 
   {{0xd87424b3,0x27fd44cb,0xeb9c003b,0x00000000}},	//   لانب, _poun_, _bløt_, --, 
   {{0xafd84e9b,0xc48401b9,0x62980108,0x4b7800df}},	//   mløs, қлик, ysuo, _ראָו, 
   {{0x1dc000dc,0x1cb0025c,0xafd820e4,0xad242586}},	//   श्वत, _ནའོ_, lløs, _سرگو, 
   {{0x27fc0086,0xfb18008f,0x75b40116,0xee3c02f0}},	//   _woun_, _טורמ, лғут_, krým_, 
   {{0x27fd44cc,0x5e5800c8,0xafd922c5,0xeb9cb3f8}},	//   _toun_, דיגע_, nløs, _fløt_, 
   {{0x629944cd,0x9a880014,0xee3c0306,0x7ae40162}},	//   tsuo, _سنہٕ_, drým_, _yrkt, 
   {{0xc2451bd7,0x611000ac,0x47341d5b,0x00000000}},	//   лник, mələ, _снас, --, 
   {{0x572404a9,0x61100cc1,0x20000c88,0x62980c98}},	//   _ئىكك, lələ, _soii_, rsuo, 
   {{0xc1d018ce,0x629944ce,0x69c40023,0x98480311}},	//   _һөнә, ssuo, _mbje, _uşă_, 
   {{0xaa7800e4,0xafd944cf,0x611000ac,0x387c06af}},	//   _arým, dløs, nələ, _étre_, 
   {{0x82a433d2,0x7658023a,0xe24802d3,0x0eb80a89}},	//   _салж, _yhty, _ምጥርና, куры_, 
   {{0x611003be,0xee3c0122,0x200001f5,0xafd80174}},	//   hələ, brým_, _woii_, fløs, 
   {{0x61100cc1,0x200144d0,0xafd944d1,0xd244084c}},	//   kələ, _toii_, gløs, _тэци, 
   {{0x69c544d2,0x00000000,0x00000000,0x00000000}},	//   _abje, --, --, --, 
   {{0x611003be,0x8fc400cf,0xb9e800ee,0xafd80174}},	// [206e0] dələ, _ئزىن, нмаз_, rløt, 
   {{0xafd944d3,0xb6840131,0x00000000,0x00000000}},	//   bløs, ۇشتى, --, --, 
   {{0x611003be,0x778544d4,0x7e740208,0xd5b80055}},	//   fələ, глез, _huyp, _rcā_, 
   {{0x7658044e,0x178401b9,0x7e7544d5,0xf0b4008f}},	//   _shty, рҳам, _kuyp, טלער_, 
   {{0x7e740bc9,0xe8a000d1,0x00000000,0x00000000}},	//   _juyp, لمەپ, --, --, 
   {{0x7874007b,0x00000000,0x00000000,0x00000000}},	//   _مُسا, --, --, --, 
   {{0x611003be,0x68e020e4,0xeb9c0162,0xf77000e3}},	//   bələ, åndt, _gløs_, _هاء_, 
   {{0x61100cc1,0x69c40841,0x280000bc,0xd53801d5}},	//   cələ, _zbje, ěrná_, _یغاچ_, 
   {{0xe7341dc8,0x5214ebb2,0x66e144d6,0x3264449b}},	//   _бет_, идит, _лота, лтов, 
   {{0xee3c0306,0x20040108,0x00000000,0x00000000}},	//   trým_, ömin_, --, --, 
   {{0x7c247c52,0xdb040162,0x92e400fe,0x91fc00de}},	//   _omkr, ggiú, নহে_, emāc, 
   {{0x7e7544d7,0xafd80450,0x2934010f,0x00000000}},	//   _buyp, vløs, ראטן_, --, 
   {{0x7e742112,0x1cc0025c,0x1cb0025c,0x437544d8}},	//   _cuyp, _གདུ_, _ནའུ_, _тухт, 
   {{0x7e74047e,0x611000ac,0xafd80450,0xde500023}},	//   _duyp, zələ, tløs, _ማእከል, 
   {{0x611000ac,0x4c953c68,0x00000000,0x00000000}},	//   yələ, рибс, --, --, 
   {{0xafd84e9b,0xe1f40124,0x00000000,0x00000000}},	//   rløs, _агә_, --, --, 
   {{0xafd84e9b,0xdcfc0006,0xeb9c33b8,0x611000ac}},	// [206f0] sløs, karė, _blør_, vələ, 
   {{0x4c9544d9,0xafd8a8b2,0x7c240036,0xe29c09f3}},	//   _киос, pløs, _emkr, áði_, 
   {{0xc794385e,0x611003be,0x6368467d,0xdcfc0024}},	//   арлы, tələ, _könü, darė, 
   {{0x9964cd5c,0xe84944da,0xbd3402dd,0x7e740022}},	//   стул, رجان_, _түсу_, _yuyp, 
   {{0x611003be,0x9a84426c,0xdd1c0153,0x636803e0}},	//   rələ, _гусл, _išša, _mönü, 
   {{0x61100cc1,0x69c544db,0xeb9c0158,0xfd6400b8}},	//   sələ, _ubje, _glør_, _aruṣ, 
   {{0x195944dc,0xe784759d,0xd618007b,0x290401e3}},	//   _бары_, _бузо, دتنا_, änad_, 
   {{0x611003be,0x673801d4,0xb77402dd,0xdd480092}},	//   qələ, _txuj, _көшу_, _መድሀኒ, 
   {{0x2bc40574,0x6680678a,0xd83801c0,0x021800d4}},	//   ऱ्या, _ایتل, _сэр_, вінь_, 
   {{0x420801c0,0xd2000145,0x00000000,0x00000000}},	//   тноо_, зүшк, --, --, 
   {{0x7e74014f,0x00000000,0x00000000,0x00000000}},	//   _suyp, --, --, --, 
   {{0x7e740309,0x9f4000a2,0x4428007c,0xb4f8011a}},	//   _puyp, _iniú_, _öa_, _בפעי, 
   {{0x6368a2d4,0x7e740784,0x00000000,0x00000000}},	//   _dönü, _quyp, --, --, 
   {{0x91fc11f9,0xc0e40408,0x00000000,0x00000000}},	//   rmāc, _вокк, --, --, 
   {{0x3b9423a4,0xafd80fac,0x6da00395,0x00000000}},	//   ијат, rlør, юира, --, 
   {{0x636845e3,0xafd895a0,0x3b8544dd,0xa9240006}},	//   _gönü, slør, рлаг, _mažė, 
   {{0x3a243c25,0x644800b5,0xafd8143a,0xba24db2e}},	// [20700] амаг, _mkgi, mløp, адак, 
   {{0x237c0007,0xafd8143a,0x6af400db,0x00000000}},	//   hcuj_, lløp, جىكس_, --, 
   {{0x63680259,0x00000000,0x00000000,0x00000000}},	//   _yönü, --, --, --, 
   {{0x7c2544de,0xdb2001ed,0x64480175,0xafd82dba}},	//   _umkr, ítóg, _nkgi, nløp, 
   {{0x2bdc0490,0xdcfc0024,0x9f400332,0xe6900efc}},	//   _पोटा, tarė, _aniú_, قلند, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8c64036b,0xfd6400b8,0xe9a0010a,0x00000000}},	//   _خطین, _pruṣ, _фасп, --, 
   {{0x7c3400a9,0xb7d80014,0x88800014,0xf2c456a1}},	//   nnyr, _جورا_, _ریٖن, асон, 
   {{0xafd803cd,0xdb0403b2,0xf748c35c,0x7c3401f4}},	//   dløp, ggiø, _شجره_, inyr, 
   {{0x636851c8,0x82500240,0x00000000,0x00000000}},	//   _sönü, _ሕብርታ, --, --, 
   {{0x84143c1a,0x00000000,0x00000000,0x00000000}},	//   рмөх, --, --, --, 
   {{0x6b240327,0xfd6400b8,0x00000000,0x00000000}},	//   _ལྟའོ_, _uruṣ, --, --, 
   {{0xaa780022,0x92b402dd,0x935400db,0x00000000}},	//   _isýg, _اڭعا, _اراچ, --, 
   {{0x7124004b,0xdd952fca,0xadb4129d,0x30e858e5}},	//   _پرتل, жары, جۇدا_, _афин_, 
   {{0xaa7803b2,0xac253038,0x7c340142,0x00000000}},	//   _trýk, афак, fnyr, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xda78e1b8,0x200c013f,0x7c3887ef,0x00000000}},	// [20710] аях_, ɔdi_, étra, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x290544df,0x1cc00327,0x66f401e1,0x00000000}},	//   âna_, _གདག_, _o̟kù, --, 
   {{0x668001d5,0x00000000,0x00000000,0x00000000}},	//   قیرل, --, --, --, 
   {{0xb7840166,0xd7740c75,0x00000000,0x00000000}},	//   сәсе_, زانع, --, --, 
   {{0xaa7800e4,0x70b4185d,0xb6a0086f,0xb0b402ab}},	//   _asýg, _अमूल, чишл, _अमंग, 
   {{0x4904036b,0x13300092,0x00000000,0x00000000}},	//   _اوزق, _እስከዚ, --, --, 
   {{0xd1300092,0x00000000,0x00000000,0x00000000}},	//   _ጥያቄው, --, --, --, 
   {{0x03a401a9,0x00000000,0x00000000,0x00000000}},	//   _ғило, --, --, --, 
   {{0xe6113c28,0xdb0403cd,0x00000000,0x00000000}},	//   _بشر_, rgiø, --, --, 
   {{0x7c349c91,0xafd803cd,0xb634010f,0x00000000}},	//   ynyr, tløp, _פרעס_, --, 
   {{0x6018035b,0x00000000,0x00000000,0x00000000}},	//   _sãmb, --, --, --, 
   {{0x1cb0038f,0x1cc0025c,0xafd808fb,0x2128030a}},	//   _ནའང_, _གདང_, rløp, ńch_, 
   {{0x442d44e0,0xe29c0008,0xafd808fb,0x00000000}},	//   lie_, áðu_, sløp, --, 
   {{0x442d44e1,0x0c7944e2,0x91800137,0xafd8143a}},	//   oie_, исты_, _تۇپۇ, pløp, 
   {{0x442d44e3,0xaf4401d9,0x9c6400db,0x1dc4000d}},	//   nie_, _گرى۪, تۇجو, _लउकत, 
   {{0xf9900aa0,0x7c340006,0x442d44e4,0xd5b800b8}},	// [20720] كبا_, rnyr, iie_, _imāv_, 
   {{0x442d44e5,0xc30000bd,0x3ea0691c,0xaf440014}},	//   hie_, এনপি_, mskt_, _درى۪, 
   {{0x442d44e6,0x3ea144e7,0xf8a80063,0x68e001e3}},	//   kie_, lskt_, увек_, åndp, 
   {{0x442d44e8,0x00000000,0x00000000,0x00000000}},	//   jie_, --, --, --, 
   {{0x442d44e9,0x3ea140d3,0xdcfc00da,0xddc4005f}},	//   die_, nskt_, karī, _muiž, 
   {{0x442cfeeb,0x7bd49e87,0x3ea1126e,0x00000000}},	//   eie_, leyu, iskt_, --, 
   {{0x442d44ea,0xdcfc00da,0x344801c0,0xc0f00092}},	//   fie_, darī, лчин_, ልፃሉ_, 
   {{0x442d44eb,0x7bd40083,0x3ea00162,0x9378013d}},	//   gie_, neyu, kskt_, шбит_, 
   {{0x3864049f,0x00000000,0x00000000,0x00000000}},	//   mmor_, --, --, --, 
   {{0x442d44ec,0x3f80033f,0x3ea001e3,0x15e0012d}},	//   aie_, ecku_, dskt_, _गोचर_, 
   {{0x442d44ed,0x577c0023,0x7bd4010a,0x386401ab}},	//   bie_, _ብሓንቲ_, keyu, omor_, 
   {{0x442d44ee,0x386544ef,0x799c004c,0x76480175}},	//   cie_, nmor_, hapw, lofy, 
   {{0x799d44f0,0x7bd544f1,0x38640165,0x3d8801ec}},	//   kapw, deyu, imor_, _ﺒﺸﻲﺀ_, 
   {{0x76482c1a,0xdcfc002b,0x00000000,0x00000000}},	//   nofy, carī, --, --, 
   {{0x3b2c001f,0x9d18009d,0x00000000,0x00000000}},	//   _በመገኘ, борт_, --, --, 
   {{0x7bd4020c,0x00000000,0x00000000,0x00000000}},	//   geyu, --, --, --, 
   {{0x764944f2,0x38644515,0xe77401d9,0xead400eb}},	// [20730] kofy, dmor_, ۅلاں_, সম্ম, 
   {{0x442d44f3,0x7e60011c,0x999800db,0x00000000}},	//   zie_, _èopp, йкут_, --, 
   {{0x02c40882,0x442d44f4,0x7bd544f5,0xc0f00092}},	//   _वह्न, yie_, beyu, ልፃል_, 
   {{0x3864365a,0x442c82bf,0x13e000cc,0xdb04010b}},	//   gmor_, xie_, ভাড়, lgiý, 
   {{0x442c0fa9,0xc58800d1,0x00000000,0x00000000}},	//   vie_, لھام_, --, --, 
   {{0x442d44f6,0x2d800034,0x764944f7,0xa2d007f7}},	//   wie_, ncje_, gofy, _बैग्, 
   {{0x442d44f8,0x91fc0882,0x69d544f9,0x1a68be6e}},	//   tie_, tmān, mexe, _ایلی_, 
   {{0x3ea00579,0xd7f801c0,0xb0c4031c,0x442c8f24}},	//   yskt_, _луу_, _ཀྱེེ, uie_, 
   {{0x2d80068f,0x764801c8,0x7d0c012d,0x00000000}},	//   kcje_, bofy, zybs, --, 
   {{0x442d44fa,0x7bd41ab4,0x00c800f5,0x00000000}},	//   sie_, zeyu, алок_, --, 
   {{0x442d44fb,0x7bd490d7,0xf6c4031c,0xaca00432}},	//   pie_, yeyu, _གདོང, _meỳd, 
   {{0xe29c0008,0x442c036e,0x69d544fc,0x245000e4}},	//   áðs_, qie_, hexe, kãmi_, 
   {{0xdcfc0882,0x63b944fd,0xb7d80375,0x74100133}},	//   parī, mgun, בקרי, _زووا, 
   {{0x5fdc7aa4,0x3ea144fe,0x7bd41418,0x3864e2ee}},	//   _बसवल, rskt_, weyu, zmor_, 
   {{0x7c3944ff,0x386403cb,0x63b8009a,0x69d54500}},	//   étro, ymor_, ogun, dexe, 
   {{0x61e14501,0x799c01c8,0x26dc00f3,0x81d4009e}},	//   _hanl, wapw, _osuo_, হাও_, 
   {{0x61e14502,0x26dc013f,0x8fc40150,0xf6c40135}},	// [20740] _kanl, _nsuo_, _رزين, _གདེང, 
   {{0x63b9122c,0x7bd4cf3e,0x61e000ee,0x69d4009a}},	//   hgun, seyu, _janl, gexe, 
   {{0x799c0433,0x63b91ca9,0x386403cd,0xd9980137}},	//   rapw, kgun, tmor_, _ۇچات_, 
   {{0xb8f014cf,0x61e14503,0x7bd40113,0x81d40f22}},	//   _वह_, _lanl, qeyu, হাট_, 
   {{0x61e14504,0xd1e002d3,0xaa78010b,0x69d4c990}},	//   _oanl, ሓስብ_, _brýu, bexe, 
   {{0x61e14505,0x63b94506,0x389001f3,0x3cfc000d}},	//   _nanl, egun, ምህርቱ_, _उपाइ_, 
   {{0x18b40724,0xa5d4009f,0x63b802d2,0x00000000}},	//   _хәзр, زبور_, fgun, --, 
   {{0x61e0225e,0x87b80364,0xf7440334,0x76494507}},	//   _aanl, _гуфт_, _дебо, sofy, 
   {{0xa340152d,0x75d54508,0x76494509,0x2d800034}},	//   дээл, _ويرا, pofy, ycje_, 
   {{0x61e1450a,0x63b9450b,0x31680c56,0x99980064}},	//   _canl, agun, ишно_, _ikrų_, 
   {{0x63b805f5,0x64a00228,0x20c000e8,0xe7ed450c}},	//   bgun, _жаха, gñi_, _घोडा_, 
   {{0x68e0019b,0x61e0035a,0x69d5450d,0xb4d413f7}},	//   ændi, _eanl, zexe, िबी_, 
   {{0x733411c7,0x61e007d6,0x81d40011,0xf204005b}},	//   _برائ, _fanl, হাজ_, _мяко, 
   {{0xd3440502,0x61e1450e,0x2e480801,0xee3c00e4}},	//   _ویژه_, _ganl, рямо_, yrýu_, 
   {{0xdb040209,0x23b00150,0x69d40393,0x2d80012d}},	//   rgiý, _ءمۇس, vexe, rcje_, 
   {{0x61e1450f,0x69d401e2,0x25180a7c,0x24500022}},	//   _zanl, wexe, בולא, tãmi_, 
   {{0x61e007c4,0x69d54510,0xaca14511,0x8ae803e3}},	// [20750] _yanl, texe, _iwọg, _azәr, 
   {{0x63b94512,0x61e02523,0x6b9c0455,0x28dc0037}},	//   zgun, _xanl, saqg, _ननदि, 
   {{0x69d4cdcf,0xf6c4025c,0xa3a8007d,0x63b94513}},	//   rexe, _གདུང, _कएल_, ygun, 
   {{0x69d54514,0xaa78148b,0x00000000,0x00000000}},	//   sexe, _brýt, --, --, 
   {{0xd7c8021a,0x69d478aa,0x00000000,0x00000000}},	//   تونه_, pexe, --, --, 
   {{0x6b80043b,0x63b83018,0x20c003f0,0x97a4008e}},	//   ɛnga, wgun, yñi_, прәл, 
   {{0x91fc0061,0x63b915f9,0x1cc0025c,0xdd4802d3}},	//   rmāl, tgun, _གདབ_, _መድሓኒ, 
   {{0x61e14515,0x63b94516,0x78b800cc,0xd5b800b8}},	//   _sanl, ugun, _åtva, _smāt_, 
   {{0x61e07de9,0xaa794517,0x00000000,0x00000000}},	//   _panl, _grýt, --, --, 
   {{0x321d4518,0x63b94519,0x61e06656,0x20c01bce}},	//   ghty_, sgun, _qanl, tñi_, 
   {{0xa3b86f43,0x940405d9,0xaa79451a,0xd87401d3}},	//   _ناشر_, _ڪونه, _ysýc, _راہب, 
   {{0x61e1451b,0xd3b802bf,0x2ee80076,0x00000000}},	//   _wanl, _душі_, fvcf_, --, 
   {{0x61e0006c,0xe80060c7,0x20c00784,0x9404009f}},	//   _tanl, _रचना_, sñi_, _تونه, 
   {{0x321d451c,0x4df44f55,0x0084011c,0x00000000}},	//   chty_, мяст, _елко, --, 
   {{0x20c00113,0xab580205,0x01e00154,0xcdc40022}},	//   qñi_, _obüs, বাদদ, ьарқ, 
   {{0x1b0400eb,0x00000000,0x00000000,0x00000000}},	//   _রেগে_, --, --, --, 
   {{0xfd9400d1,0x29040309,0x00000000,0x00000000}},	// [20760] _нөвә_, änan_, --, --, 
   {{0x6f60008e,0x00000000,0x00000000,0x00000000}},	//   _явыз, --, --, --, 
   {{0x1b0400bd,0xab5805d5,0x63a80010,0xef1c1cce}},	//   _রেখে_, _sbüt, _odgn, bbüs_, 
   {{0x628807c5,0xdd380055,0xaa780a87,0xef1c03e0}},	//   _otgo, _nāũa, _prýt, mbür_, 
   {{0xd9b40075,0xe7348c72,0x41bc01bc,0x00000000}},	//   _يەرد, пец_, ्भास, --, 
   {{0x63a80381,0xba19451d,0x1dc000dc,0x00000000}},	//   _adgn, _ايسا_, श्चत, --, 
   {{0x6289451e,0x70d800af,0xa5040063,0xc6880240}},	//   _atgo, _बनेल, зеја_, _ዝደልያ_, 
   {{0x1cc01b4b,0xab580086,0xa2d0012c,0xaa7803b2}},	//   _གདན_, _ibür, _बैङ्, _trýt, 
   {{0x27f4038e,0xdd3800b8,0xfbcc00dc,0xafd83bb4}},	//   šení_, _dāũa, ह्यम, lnøg, 
   {{0xe6142e70,0xd5a400f2,0xc7b800e5,0xb1a4008e}},	//   _еду_, _آلای, _előd_, чшик, 
   {{0xb0300598,0x00000000,0x00000000,0x00000000}},	//   емнә, --, --, --, 
   {{0x321c0200,0x00000000,0x00000000,0x00000000}},	//   shty_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x60d400e4,0x30a400f3,0x00000000,0x00000000}},	//   ñamí, _ерив, --, --, 
   {{0x624c072b,0x00000000,0x00000000,0x00000000}},	//   møop, --, --, --, 
   {{0x5c7447bf,0xaa78010e,0x99d401d3,0x00000000}},	//   елст, _asýa, ہتما, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [20770] --, --, --, --, 
   {{0x638002d2,0xef1c03b9,0x99d4085b,0x00000000}},	//   _kínó, bbür_, فتما, --, 
   {{0x02d802f8,0xb4d40037,0x91fc00e2,0xd1500023}},	//   _भन्न, िबो_, tmāj, _ሃንቀው, 
   {{0x638002d2,0x2c240354,0x00000000,0x00000000}},	//   _mínó, _хьог, --, --, 
   {{0xd874ce83,0x91b403d4,0x00000000,0x00000000}},	//   رامب, জ্যখ, --, --, 
   {{0xafd800b5,0x2bc80a59,0x00000000,0x00000000}},	//   lnød, ाभवा, --, --, 
   {{0x48246886,0xaa780579,0x0444d4e4,0x628805d5}},	//   _قىسق, _trýs, мекн, _stgo, 
   {{0xfca81a4c,0x76b43531,0x984806be,0x00000000}},	//   קיפּ, чләр_, _işğ_, --, 
   {{0xf3440395,0x00000000,0x00000000,0x00000000}},	//   мпъл_, --, --, --, 
   {{0xafd80217,0x80a8005b,0x148800f1,0x00000000}},	//   mløy, овов_, _ځپلي_, --, 
   {{0xafd8143a,0x00000000,0x00000000,0x00000000}},	//   lløy, --, --, --, 
   {{0xea9c002b,0xbea40022,0x00000000,0x00000000}},	//   _guṇe_, мамк, --, --, 
   {{0x6289451f,0xafd800cc,0x6d540213,0x00000000}},	//   _utgo, nløy, _ayxa, --, 
   {{0x6d54007c,0x98b800c0,0x5344030d,0x00000000}},	//   _byxa, _gyrė_, _яхха, --, 
   {{0x91fc00e2,0x00000000,0x00000000,0x00000000}},	//   zmāk, --, --, --, 
   {{0xafd80158,0x00000000,0x00000000,0x00000000}},	//   kløy, --, --, --, 
   {{0x1cc03ae9,0x2efc03fa,0x1cb0031c,0xdb0403b2}},	// [20780] _གདམ_, äuft_, _ནའམ_, ggið, 
   {{0xee354520,0xe9d54123,0xafd805ac,0x42a80116}},	//   _оны_, мку_, dløy, _ﺋﻪﻟﭽ, 
   {{0x499802bf,0xdb0401c4,0x9f4000a2,0x3c6401f4}},	//   яття_, rgiñ, _iniñ_, _оког, 
   {{0x9f414521,0xafd87f4f,0xaa7800e4,0x9ba400d1}},	//   _unió_, rnøg, _isýn, _سەئى, 
   {{0xd6d0a012,0xafd94522,0x2bc805c0,0x00000000}},	//   اقت_, snøg, ाभरा, --, 
   {{0xe8dc01fb,0xd1e00023,0xaa780174,0xafd8005c}},	//   _luộc_, ሓትት_, _trýr, pnøg, 
   {{0x1cdc1f21,0x68e0037e,0xf8d00ce0,0xca6400c7}},	//   _ལགས_, ændt, _सहिय, _черқ, 
   {{0xe614febe,0x9fd0009e,0x69cc0b4c,0x70d805dc}},	//   здә_, িযুগ, ठ्ठी, _बनौल, 
   {{0x9f400086,0xe7345de4,0x99e8010e,0xb5c40139}},	//   _oniñ_, _жет_, _giňä, _ойал, 
   {{0xf8d01f14,0xc0c0001f,0xc76415bf,0x00000000}},	//   _सहाय, ቻለሁ_, _ساقى, --, 
   {{0xd13006d5,0xe8dc0016,0x25a404fb,0xe4c0010a}},	//   امج_, _buộc_, _آگهي_, _айхи, 
   {{0xe8dc07ae,0x9f400139,0xeb9c1445,0x2494ba4f}},	//   _cuộc_, _aniñ_, _fløy_, _آنند_, 
   {{0xb0640227,0x98b800c0,0x5f9401f0,0x00000000}},	//   _axäñ, _tyrė_, ъият, --, 
   {{0xafd801bf,0x00000000,0x00000000,0x00000000}},	//   wnød, --, --, --, 
   {{0xaa780124,0x222800f2,0x9cc801ec,0x00000000}},	//   _arýp, _بزنی_, мыта_, --, 
   {{0x21b400dd,0xe8dc0051,0x1bd4026b,0x00000000}},	//   _ٹھیک_, _guộc_, кося, --, 
   {{0xe9a94523,0xafd81600,0x6e640108,0x00000000}},	// [20790] قدان_, rnød, _отож, --, 
   {{0xe9d000c6,0xaa7803b2,0xafd80b1a,0x2d840f7d}},	//   ضغط_, _drýp, vløy, _üne_, 
   {{0x58843c1b,0x00000000,0x00000000,0x00000000}},	//   выча, --, --, --, 
   {{0xafd82d8b,0x99654524,0x00000000,0x00000000}},	//   tløy, ттул, --, --, 
   {{0x2b4401c0,0xfbb4011a,0x00000000,0x00000000}},	//   _цэнг, _אפרת_, --, --, 
   {{0x68e004ce,0xafd8332c,0x2ba40490,0x7ae000d8}},	//   ænds, rløy, गणका, çote, 
   {{0x19594525,0xafd84673,0x98c401a9,0x00000000}},	//   _жары_, sløy, _истл, --, 
   {{0xafd803d4,0x58d40111,0x00000000,0x00000000}},	//   pløy, _шост, --, --, 
   {{0x7c3803b7,0x45d4084c,0x00000000,0x00000000}},	//   étri, _поас, --, --, 
   {{0x56940364,0x41054526,0xa3a8000d,0x00000000}},	//   _рафт, езов, _कएक_, --, 
   {{0xc8782791,0x70c401c6,0x00000000,0x00000000}},	//   _kiş_, нгэг_, --, --, 
   {{0xcdc8025f,0x00000000,0x00000000,0x00000000}},	//   _לך_, --, --, --, 
   {{0xef154527,0x932400aa,0xc87815b7,0x00000000}},	//   емя_, _لرون, _miş_, --, 
   {{0x64594528,0xc8780139,0x00000000,0x00000000}},	//   llui, _liş_, --, --, 
   {{0x51854529,0xe8dc004d,0x64583b17,0x52742614}},	//   _руча, _tuộc_, olui, _شاهز, 
   {{0x6458cdce,0xebe1452a,0x9034035b,0xec7400d8}},	//   nlui, лосп, _ахьч, епс_, 
   {{0xbdf8bab9,0x6458023a,0xbea800ec,0xef1c0205}},	// [207a0] _فردا_, ilui, _عهدن_, ncül_, 
   {{0x6459452b,0xafd801bf,0x00000000,0x00000000}},	//   hlui, rnøe, --, --, 
   {{0xf1c08054,0xc87800fd,0x6458057b,0x6574001f}},	//   _शासन, _biş_, klui, ጠናቀቅ_, 
   {{0x69e0013f,0xad340375,0x00000000,0x00000000}},	//   _ɔteɛ, _טניס_, --, --, 
   {{0xc878e03b,0x7bc46605,0x68e000b5,0x6459452c}},	//   _diş_, _icku, ændr, dlui, 
   {{0x9f40004e,0x6458257c,0x555802e8,0x00000000}},	//   _maià_, elui, маля_, --, 
   {{0xaa40d645,0xc954273e,0xe3ac00d1,0xc87803e0}},	//   _серл, _атты, ڭرى_, _fiş_, 
   {{0x6b7800c8,0xb86410e5,0x6459452d,0xe46401ec}},	//   ּרינ, _سازو, glui, ншыл_, 
   {{0xe5741de6,0xf7440798,0xa2c40166,0x00000000}},	//   мзә_, _џезо, нуэз_, --, 
   {{0x9fd011ba,0x6459452e,0x06cc04c5,0xe5a00117}},	//   িযোগ, alui, লিখি, _бифи, 
   {{0xe4d05821,0x7bc5452f,0x645801ab,0x9f40041e}},	//   _مقلد, _ocku, blui, _snið_, 
   {{0x64585599,0xc04c00aa,0xb6380220,0x00000000}},	//   clui, يږي_, _ﺘﻡ_, --, 
   {{0xdef94530,0x7c34022e,0xe8dc0051,0x00000000}},	//   ныр_, diyr, _buớc_, --, 
   {{0x7bc54531,0xe0cc40ec,0xdb04000d,0x78bc01ef}},	//   _acku, جزی_, ngiõ, kupv, 
   {{0x7ae54532,0x40e414d4,0xa1541a5c,0x84700023}},	//   _askt, _асығ, _пашу_, ብረሉን_, 
   {{0x291c02b5,0xa3340023,0xf66c0150,0x00000000}},	//   _āua_, _እትበሃ, _ﺷﻮﮔﻪ_, --, 
   {{0x320c0109,0x9f4000cf,0xceb80131,0x4a548f3a}},	// [207b0] _kofy_, _gaià_, _юән_, вкас, 
   {{0x5a354533,0x7bc402d0,0xc8780139,0x00000000}},	//   гнут, _ecku, _siş_, --, 
   {{0x7ae40857,0x205400fb,0x4c94009b,0x00000000}},	//   _eskt, _штәр, _шинс, --, 
   {{0x22a40241,0x78780118,0x7d1803cd,0x00000000}},	//   _jìká_, _půva, øtse, --, 
   {{0x6d60009b,0xb78400fd,0x7c380129,0xfbc800cc}},	//   štać, тәсе_, ètre, _লোকত, 
   {{0x320c0170,0x00000000,0x00000000,0x00000000}},	//   _nofy_, --, --, --, 
   {{0x64594534,0xe8b8031c,0x9f4c00bc,0x48c40124}},	//   tlui, _པའིག, ědé_, _шәаа, 
   {{0x64594535,0xa85009a5,0x00000000,0x00000000}},	//   ului, _себә, --, --, 
   {{0x64580af5,0xd7c800aa,0x320c0109,0xc2454536}},	//   rlui, _سوله_, _bofy_, кник, 
   {{0x6458292b,0x00000000,0x00000000,0x00000000}},	//   slui, --, --, --, 
   {{0x64584345,0x133000b7,0xff3c001f,0x9ec00150}},	//   plui, _ኢንጂነ, _ያስመዘ, _ﺟﻪرد, 
   {{0x387c0129,0x43942bbd,0xdf580139,0x00000000}},	//   _ètre_, _радс, еягә_, --, 
   {{0x69c41727,0xc1d001af,0x00000000,0x00000000}},	//   _ocje, _көнә, --, --, 
   {{0x6a680112,0x00000000,0x00000000,0x00000000}},	//   lüff, --, --, --, 
   {{0xed547136,0x6da00b2b,0x7de401ec,0x7c343be8}},	//   вор_, риса, ніңд, tiyr, 
   {{0x44f0031c,0x2f5000b4,0xfce40107,0xca480150}},	//   _mġ_, ụmụ_, ноҳо, _ﺇﺜﺭ_, 
   {{0xf9914537,0x6a8005f5,0xc1e4443a,0x7c340113}},	// [207c0] لبا_, илта, _कसाब_, riyr, 
   {{0xceb8038e,0xee340262,0x13300092,0x7c3401f4}},	//   áře_, _ань_, _ኢንጅነ, siyr, 
   {{0x25a4033b,0x68e001bf,0xad6c030d,0x00000000}},	//   danl_, ændp, _маьl, --, 
   {{0x7ae40280,0x7bc401fa,0xdb5004d3,0x78bc00b5}},	//   _tskt, _ucku, _هێز_, rupv, 
   {{0x7ae402d0,0x98a40209,0xa5d400d1,0x00000000}},	//   _uskt, тиҗе, چبىر_, --, 
   {{0x4a7434d8,0xe5b065a7,0xe60c0e26,0xca744b00}},	//   _быст, айшы, قشى_, _бусы, 
   {{0x320c05da,0xdb0400d8,0xa884030d,0x00000000}},	//   _rofy_, rgiõ, _айса_, --, 
   {{0x44f00135,0xe44cac15,0xa964234c,0xd2c801c6}},	//   _dġ_, يضي_, _риса_, _хvлэ, 
   {{0x326465cb,0x35a40022,0x66e0cffc,0x00000000}},	//   ктов, _аазг, _кота, --, 
   {{0x05c80034,0x00000000,0x00000000,0x00000000}},	//   _रायब, --, --, --, 
   {{0xdb04068c,0x6a68002f,0xdcfc0064,0x00000000}},	//   saiè, büff, mbrė, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x05c82d8f,0x84200e26,0x91c40032,0x00000000}},	//   _रामब, _دۉين, _йәнл, --, 
   {{0xa130158b,0xef1c0790,0x91fc0171,0x00000000}},	//   اریش, lcük_, gmāt, --, 
   {{0xab84024c,0xdd58009d,0x91fc00ef,0x00000000}},	//   вузк, варч_, elāg, --, 
   {{0xa1740375,0x21740375,0x00000000,0x00000000}},	//   _בעוד_, _בתור_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [207d0] --, --, --, --, 
   {{0xaa7800e4,0x4d9802bf,0xad64007b,0x787801ef}},	//   _isýk, _якою_, _لاجه, _bůvo, 
   {{0xf8b40228,0x06cc03d4,0x25a40100,0x00000000}},	//   лөт_, লিছি, vanl_, --, 
   {{0x78780316,0xdb040356,0xd7f800db,0x00000000}},	//   _důvo, maiî, куч_, --, 
   {{0x175400d4,0x00000000,0x00000000,0x00000000}},	//   авця, --, --, --, 
   {{0x69c41e31,0x44f0031c,0x199405c1,0xbb74011a}},	//   _ucje, _pġ_, _варя, _תעשו_, 
   {{0xdcf000b8,0xda3401ee,0x00000000,0x00000000}},	//   _ādīy, _теры, --, --, 
   {{0xf48403e6,0x97c4247f,0xdd3800de,0x42e8f69e}},	//   داوی, _ەتەم, _jāša, емио_, 
   {{0x27fc01e1,0xa30000ee,0xc30407fc,0x00000000}},	//   _inun_, рүле, ابعو, --, 
   {{0xb2200228,0x95d8034b,0x020401f0,0x969010e8}},	//   ймыл, _идут_, узон, _بیوش, 
   {{0xe4c862a9,0xb4b404a9,0x660001af,0x00000000}},	//   _زبان_, _бихә, _йоҡҡ, --, 
   {{0x619000f1,0xdd380171,0x91fc00ef,0x00000000}},	//   داکړ, _nāša, elād, --, 
   {{0x6728002d,0xf3e403d4,0x4154009d,0x26cc0205}},	//   nzgj, কাশৰ_, _өвдс, ntgo_, 
   {{0x6728002d,0xf1c40118,0xaaa400bc,0x5194030d}},	//   izgj, žáru_, गठनक, _вăра, 
   {{0x27fc373d,0x91fc198e,0xb11413f9,0x70900120}},	//   _onun_, rmāt, _مقوا_, _лајф, 
   {{0xbfb44bf3,0x91fc0882,0x8b954538,0x3088001f}},	//   _صحبت, smāt, ируч, _አሰጣጥ_, 
   {{0x20002878,0x6728036e,0x00000000,0x00000000}},	// [207e0] _inii_, jzgj, --, --, 
   {{0x78780316,0xef1c0790,0x27fc01f4,0x00000000}},	//   _půvo, zcük_, _anun_, --, 
   {{0x19c40116,0xca754539,0x3234010f,0x6a6806be}},	//   ләңг, руты, נטען_, düfd, 
   {{0xdd3800ef,0x38586640,0x22440051,0x00000000}},	//   _gāša, رشاد_, _ljnk_, --, 
   {{0x27140154,0x00000000,0x00000000,0x00000000}},	//   _দেবো_, --, --, --, 
   {{0x80a8000e,0x7e7c038f,0x27fc0098,0xf1c00210}},	//   _কমন্, _jipp, _enun_, _शाइन, 
   {{0xa965453a,0x83fc00dd,0x2000fe84,0x7e7d2d25}},	//   _бира_, klőd, _onii_, _mipp, 
   {{0x7e7d453b,0x3a39453c,0x27fc2556,0x83fc01ed}},	//   _lipp, lipp_, _gnun_, jlőd, 
   {{0xe3ac18a1,0xb5f001ec,0xef1c0205,0x2810009a}},	//   سري_, _гүлі, ccüh_, _اوقس, 
   {{0x2001453d,0xf1c40316,0x3a3800c5,0x356c0b82}},	//   _anii_, _část_, nipp_, _ትዕቢት_, 
   {{0x73c40fb4,0x12dc0150,0x2a540677,0x00000000}},	//   _ميام, _ﺃﻴﻬﻭ, רבין_, --, 
   {{0x7e7d453e,0x7088001f,0x96c800bc,0x91fc00de}},	//   _aipp, _አደረጉ_, _रमाउ, gmār, 
   {{0x6a6805d1,0x3a380036,0xfbb800bc,0xe294dd58}},	//   lüfe, kipp_, ेलनम, _бач_, 
   {{0x20001132,0x7e7d453f,0xaa7800e4,0xc0c0001f}},	//   _enii_, _cipp, _ipýg, ቻለም_, 
   {{0x7e7d4540,0xec694541,0x50a40032,0xdd954542}},	//   _dipp, ерак_, _тулҡ, сасы, 
   {{0x60dc066d,0x20000de2,0x7e7c0036,0x6e240113}},	//   őzmé, _gnii_, _eipp, shjb, 
   {{0x76594543,0x7e7c1bce,0x9f400ba1,0xdfd802e8}},	// [207f0] _okty, _fipp, _raiç_, _същ_, 
   {{0x321c068f,0xc7b801d3,0xaa7800d7,0x00000000}},	//   nkty_, _elől_, _hrýz, --, 
   {{0xe7080b28,0x27ec00b5,0x83fc00e5,0x00000000}},	//   کتان_, tdgn_, llőe, --, 
   {{0x7e7d4544,0xd8753a03,0xc79002d3,0x7d7801d5}},	//   _zipp, مانب, _ዝበዝሑ_, _جمپر_, 
   {{0x179800ee,0x00000000,0x00000000,0x00000000}},	//   увчы_, --, --, --, 
   {{0x672802d3,0xbb380bd9,0x7e7c00e8,0x04b42cdd}},	//   rzgj, _יערי, _xipp, асия, 
   {{0xd5b800de,0x26cc01a9,0x6728036e,0x84c40166}},	//   _klāj_, stgo_, szgj, рәзд, 
   {{0x321c033f,0x29040374,0x19580166,0x27fd4545}},	//   ekty_, änau_, _сасы_, _unun_, 
   {{0x387c011c,0xaa7800e4,0x9848084c,0x74114546}},	//   _ètra_, _asýi, _сяра_, تويا, 
   {{0x6a68002f,0xbbe00118,0xe4a4009b,0x67fc01e1}},	//   büfe, _पस्क, _брдо, bàjà, 
   {{0xaa7800e4,0xb5f800c8,0x9eb47b80,0x9324006c}},	//   _epýg, _שלעכ, әшмә, لرین, 
   {{0x43754547,0x7e7d4548,0x91fc005f,0x6e3400ae}},	//   _култ, _sipp, glāb, _amxb, 
   {{0x7e7d4549,0x82a4084c,0xe7d4072e,0x7658010e}},	//   _pipp, _талж, ण्यप, _ykty, 
   {{0x6da0c77e,0x7e7c0194,0xada0bc62,0x12dc01ec}},	//   жира, _qipp, жарл, _ﺃﺴﻠﻭ, 
   {{0x7e7c07ad,0x92680f14,0xc0a802da,0xfce40fac}},	//   _vipp, _срца_, _شاغل_, шово, 
   {{0x7e7d454a,0x2001454b,0xaa7800e4,0x00000000}},	//   _wipp, _unii_, _ypýg, --, 
  
   {{0x7e7d454c,0xa0a016c3,0x3a38a72b,0xafd803b2}},	// [20800] _tipp, _тақд, tipp_, inøl, 
   {{0x7e7c0140,0x308800fd,0xaa7800e4,0x41bc12eb}},	//   _uipp, _яшәү_, _ysýi, _एएफस, 
   {{0x78a001fa,0x6fd02802,0x3a3889b7,0x77840064}},	//   ćovo, ध्वं, ripp_, алез, 
   {{0xe8dc004d,0x3a3805ac,0x28d4302b,0x00000000}},	//   _cuốc_, sipp_, _ठहरि, --, 
   {{0x7bd402a8,0xe7b401ec,0xa6c40484,0x00000000}},	//   mfyu, ргіш_, илца_, --, 
   {{0x7c240589,0xd1d00023,0x6670009a,0x00000000}},	//   _hlkr, ጦታት_, يدور, --, 
   {{0x290401e6,0xaa780162,0x7af5454d,0xf77000ec}},	//   änat_, _spýg, lvyt, _ڀاء_, 
   {{0x6a6803fa,0xe8dc0208,0xef1c03e0,0x00000000}},	//   rüfe, _guốc_, rbüz_, --, 
   {{0xf5e8192a,0xf205454e,0x69c0067c,0xd58801af}},	//   _имал_, аяно, óneg, _йәйл_, 
   {{0x7c68001f,0x71240736,0x76580055,0x00000000}},	//   _ተብሏል_, لرجل, _ukty, --, 
   {{0x74146dd7,0x321c00cc,0x00000000,0x00000000}},	//   _پوشا, rkty_, --, --, 
   {{0x91fc00e2,0xc3000154,0x00000000,0x00000000}},	//   flāc, এনজি_, --, --, 
   {{0x1cdc0156,0x7af401ef,0x00000000,0x00000000}},	//   _ལགཔ_, jvyt, --, --, 
   {{0xf1a800aa,0x7c25454f,0x7af40064,0x00000000}},	//   _شاته_, _alkr, dvyt, --, 
   {{0x2ba40b7f,0xe7d4102f,0xaa7802f0,0x00000000}},	//   ијав, ण्डप, _trýz, --, 
   {{0x5bb94550,0xa904129e,0x9f440118,0x2bb8007b}},	//   ился_, یبان, žmá_, ضارة_, 
   {{0x3cf8004e,0xe9840640,0xe8dc0208,0xc79401ec}},	// [20810] _erpv_, аћен, _ruốc_, ұрлы, 
   {{0x7c254551,0xeb9c00b5,0x00000000,0x00000000}},	//   _elkr, _snød_, --, --, 
   {{0xda78a2ed,0xe84800d1,0x00000000,0x00000000}},	//   рят_, پجان_, --, --, 
   {{0xe8dc01dc,0x4dfc00bc,0x00000000,0x00000000}},	//   _quốc_, _लफडै_, --, --, 
   {{0xdcfc01e4,0x6a68002f,0x00000000,0x00000000}},	//   rarĥ, rüfb, --, --, 
   {{0xaa780124,0x48c400c7,0x29043400,0x799c03ac}},	//   _asýv, _гәда, änas_, cbpw, 
   {{0x95c800fd,0x29048b8a,0x27b0010b,0xe8dc0051}},	//   руча_, ånad_, _дәлс, _tuốc_, 
   {{0xd4e40212,0xd7f807ee,0x00000000,0x00000000}},	//   юючи, _куу_, --, --, 
   {{0xd8380323,0x56954552,0xafd803b2,0x00000000}},	//   _тэр_, _матт, rnøl, --, 
   {{0x78680306,0xdcf400d7,0x00000000,0x00000000}},	//   mýva, _ďaľe, --, --, 
   {{0x786813d5,0x7f8407d6,0x00000000,0x00000000}},	//   lýva, یلگن, --, --, 
   {{0x7af531e4,0x00000000,0x00000000,0x00000000}},	//   yvyt, --, --, --, 
   {{0x2bc8bd8d,0x21a001e0,0x2284013d,0xb6300244}},	//   िलना, _һиҙм, _туег, _بکۆش, 
   {{0x62994553,0x9f40003a,0x90e41dd8,0xa2c000b1}},	//   mpuo, _kaiú_, حسین, _ләүк, 
   {{0x7c654554,0xefe00023,0x9ba400d1,0x5108030d}},	//   مارل, ምዕዎ_, يەدى, _кĕрĕ, 
   {{0x61b453b7,0x3b849128,0x62980108,0x70800166}},	//   _आयुष, слаг, opuo, _эгъз, 
   {{0x6298023a,0x39441b15,0xba74009f,0x7bd40946}},	// [20820] npuo, әнег, مائت, rfyu, 
   {{0xfb844445,0x7de8023a,0x00000000,0x00000000}},	//   рыңн, _смог_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa96400a7,0xfb8003e6,0x20f4054e,0xbb7402e8}},	//   щиха_, _رگری, _măi_, _гугъ, 
   {{0x2904049f,0x628cebee,0x2ca401bf,0x00000000}},	//   änar_, ícol, _ændr_, --, 
   {{0x6448004e,0xcff00154,0x00000000,0x00000000}},	//   _ajgi, টায়_, --, --, 
   {{0x62980024,0x64a00114,0xe9a001a9,0x00000000}},	//   epuo, паја, _хасп, --, 
   {{0x94181de1,0x78694555,0xafd80158,0x667000d1}},	//   ржит_, býva, boøy, يدۈر, 
   {{0xef1c06be,0x00000000,0x00000000,0x00000000}},	//   ncüt_, --, --, --, 
   {{0x6494052f,0x20f40276,0xa694011a,0x00000000}},	//   штәр_, _băi_, _לכמה_, --, 
   {{0x20f40311,0xae054556,0x224800d0,0x00000000}},	//   _căi_, शासन_, écka_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb8f82b88,0xafd8003b,0x00000000,0x00000000}},	//   _འད_, lnøk, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x78680313,0x9f4c00bc,0x00000000,0x00000000}},	//   zýva, ědá_, --, --, 
   {{0xd010007b,0x00000000,0x00000000,0x00000000}},	//   _آلة_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [20830] --, --, --, --, 
   {{0x78680022,0x00000000,0x00000000,0x00000000}},	//   výva, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7aed4557,0x7d194558,0x2b9001b9,0x4f380092}},	//   äntä, ätse, _ریئس, _አንዳር, 
   {{0xdb1402d2,0xe6c40210,0x00000000,0x00000000}},	//   _íaða, _żołę, --, --, 
   {{0x78690749,0xd774b6a9,0xeb280092,0x00000000}},	//   rýva, سانع, ዲያገለ, --, 
   {{0xafd804ce,0x286800d8,0x786800e4,0x00000000}},	//   rnøj, _брао_, sýva, --, 
   {{0x4824049e,0xaca0063f,0x4438067c,0x20f4054e}},	//   _بىرق, _ntọg, òs_, _răi_, 
   {{0xc7b800dd,0x26dc0421,0x20f40276,0x00000000}},	//   _idő_, _upuo_, _săi_, --, 
   {{0x80cc02a6,0xaca027dd,0x20f40311,0x82354559}},	//   ়বস্, _atọg, _păi_, تربا, 
   {{0x6299455a,0xd61811dc,0x741012ea,0x00000000}},	//   spuo, _اتقا_, سویا, --, 
   {{0x62980a4f,0x20f40356,0x92b803d4,0xe8dc0208}},	//   ppuo, _văi_, _চহৰ_, _chỉa_, 
   {{0x442c7e9f,0x82340efb,0x64592c5b,0x00000000}},	//   mhe_, _ورتا, moui, --, 
   {{0x442d455b,0x6289455c,0x63a80a87,0x20f40311}},	//   lhe_, _iugo, _hegn, _tăi_, 
   {{0x6281455d,0x442c00fb,0x518402e9,0x2bf80037}},	//   _iino, ohe_, _عشوق, _लोहू_, 
   {{0x6459455e,0x6289455f,0x442d4560,0xd1c80023}},	//   noui, _kugo, nhe_, _ጠመተ_, 
   {{0x63a94561,0x442d4562,0xcf580153,0x00000000}},	// [20840] _megn, ihe_, _грэч_, --, 
   {{0x628813b6,0x63a94563,0x62814564,0x64580ffb}},	//   _mugo, _legn, _jino, houi, 
   {{0x442c124c,0x64588943,0xbb8400ae,0x00000000}},	//   khe_, koui, _ولدي, --, 
   {{0x442c5eca,0x64585725,0x63a800e8,0xafd80158}},	//   jhe_, joui, _negn, vnøk, 
   {{0x62814565,0x62880194,0x645839b4,0x628c01e4}},	//   _oino, _nugo, doui, ŭcoj, 
   {{0x62814566,0x442c0124,0xdb040077,0x63a80037}},	//   _nino, ehe_, caiá, _aegn, 
   {{0x64594567,0x442c06d6,0x63a94568,0x6288005f}},	//   foui, fhe_, _begn, _augo, 
   {{0x442d4569,0x6289456a,0x6281456b,0xb4b80490}},	//   ghe_, _bugo, _aino, _अटी_, 
   {{0x6280420d,0x63a9456c,0xaa780022,0x628801a6}},	//   _bino, _degn, _isýr, _cugo, 
   {{0x3865456d,0x63a9362c,0x442d456e,0x63b403f9}},	//   llor_, _eegn, ahe_, _ɗanɗ, 
   {{0x442d456f,0x93540dd2,0x2fc8074d,0x69f825f9}},	//   bhe_, _کراچ, tgcg_, בליק, 
   {{0x63a94172,0x64a14570,0x64580393,0x741403e6}},	//   _gegn, _цаца, coui, _گوڵا, 
   {{0x62814571,0xe1ec2b7e,0x3864084c,0x62894572}},	//   _fino, رسی_, ilor_, _gugo, 
   {{0x62814573,0x63a918a7,0x00000000,0x00000000}},	//   _gino, _zegn, --, --, 
   {{0xfe6c9cc8,0x76480158,0x628934a7,0x00000000}},	//   دگي_, infy, _zugo, --, 
   {{0x62814574,0x38643421,0x8c88035b,0x889400d1}},	//   _zino, jlor_, _ҳәаа_, җидх, 
   {{0x94ec0085,0x62880077,0x62814575,0xc9580131}},	// [20850] tɛɛ_, _xugo, _yino, ڭلاش_, 
   {{0x442d3b5c,0x7d194576,0xaa7806c6,0x6280004e}},	//   zhe_, ätsc, _asýr, _xino, 
   {{0x94ec0605,0x58d402ff,0x442d4577,0x00000000}},	//   rɛɛ_, дохт, yhe_, --, 
   {{0x442d4578,0x38642c1e,0xfcf8010f,0x00000000}},	//   xhe_, glor_, _פּיל, --, 
   {{0x63a94579,0x442c0084,0x1fb004c5,0x6459457a}},	//   _regn, vhe_, _কামস, voui, 
   {{0x63a9457b,0x6289457c,0x442d457d,0x6a680793}},	//   _segn, _rugo, whe_, müfo, 
   {{0x442d457e,0x62801cbd,0x6289457f,0x63a807c5}},	//   the_, _rino, _sugo, _pegn, 
   {{0x62889969,0x38640064,0x442d4580,0xd8380ce1}},	//   _pugo, clor_, uhe_, _дэу_, 
   {{0x63a94581,0x442d4582,0x6458bcf6,0x22480030}},	//   _vegn, rhe_, roui, écko_, 
   {{0x628819a2,0x63a826c5,0x6280013c,0xd6280640}},	//   _vugo, _wegn, _qino, _дође_, 
   {{0x442c0f3f,0x63a94583,0x6458004a,0x91fc00e2}},	//   phe_, _tegn, poui, plān, 
   {{0x62814584,0xe8dc05db,0x25b40014,0x63a80450}},	//   _wino, _ahịa_, _اۆژھ_, _uegn, 
   {{0x62801cbd,0x78a000f3,0x74100244,0x00000000}},	//   _tino, ćovi, _سووا, --, 
   {{0xe8dc01f2,0x628034a2,0x3f9c01e4,0x8634010f}},	//   _chịa_, _uino, ŝtu_, לאָג_, 
   {{0xeb9c0158,0x6fa800fe,0x00000000,0x00000000}},	//   _snøa_, _কাৰে, --, --, 
   {{0xdddc0122,0x443c01f5,0x4f940276,0x918000cf}},	//   zorň, _jmw_, _орьу, _جۇپۇ, 
   {{0xd5b8005f,0xdb1ce03b,0x3a244120,0x443c003e}},	// [20860] _klāt_, _üzül, пмаг, _mmw_, 
   {{0x443c0051,0x38640332,0x00000000,0x00000000}},	//   _lmw_, wlor_, --, --, 
   {{0xae1800c8,0x443c0a49,0x69c004d4,0x12dc0150}},	//   _הויכ, _omw_, ónea, _ﺃﺴﻁﻭ, 
   {{0x1cbc0327,0x00000000,0x00000000,0x00000000}},	//   _ངྷར_, --, --, --, 
   {{0x38654585,0xb86401d3,0xdb840022,0xf77000e5}},	//   rlor_, _ہارو, _цҳаи, راؤ_, 
   {{0xb7d8132f,0x386401e3,0x00000000,0x00000000}},	//   _گورا_, slor_, --, --, 
   {{0x443d4586,0xb864446a,0x38641529,0xc8b407d8}},	//   _bmw_, _فارو, plor_, _осты, 
   {{0xb7d94587,0xf2c4004e,0x00000000,0x00000000}},	//   _دورا_, псон, --, --, 
   {{0xdddc02f0,0x787801ef,0x87b80798,0x00000000}},	//   porň, _důvt, _фуст_, --, 
   {{0xafd808fb,0x00000000,0x00000000,0x00000000}},	//   nnøv, --, --, --, 
   {{0x64a14588,0xb3840276,0x1ad80154,0x6a682ca8}},	//   _заха, _елел, সিয়া, düfl, 
   {{0x35d00c2e,0xa3e0107c,0x00000000,0x00000000}},	//   _साड़, _पॉप_, --, --, 
   {{0xaa7800d7,0x00000000,0x00000000,0x00000000}},	//   _osýp, --, --, --, 
   {{0x1fa40022,0x00000000,0x00000000,0x00000000}},	//   _ҧрыг, --, --, --, 
   {{0x61d80bd4,0x2d9c00e4,0x9b68035b,0x5ce4011c}},	//   _הקוד, ĝue_, ҧшуа_, нюта, 
   {{0xaa7800c7,0x7d194589,0x00000000,0x00000000}},	//   _asýp, ätsa, --, --, 
   {{0x35d02871,0xdb541669,0x00000000,0x00000000}},	// [20870] _साढ़, евты, --, --, 
   {{0x91fc0029,0x6da001d9,0xda7808fc,0x2e2c0790}},	//   klām, _سۅرم, пях_, _büfe_, 
   {{0x1a680345,0x00000000,0x00000000,0x00000000}},	//   سیفی_, --, --, --, 
   {{0x6fbc07af,0x86240014,0x713c0240,0x00000000}},	//   ्लिं, ژکال, _ኣንስቶ, --, 
   {{0xaa400075,0x1a684605,0x1a9400c0,0x00000000}},	//   _كۆرى, _کیلی_, _паяў, --, 
   {{0x443c020b,0xf8ac15b4,0x9aa41bf4,0x00000000}},	//   _smw_, _چکن_, _سمفو, --, 
   {{0xf8ac0214,0xd5b800ef,0x17bc00fe,0x00000000}},	//   _نکن_, _alās_, _ইউৰি, --, 
   {{0xb7c40116,0x7a4001e1,0xc43400cf,0x00000000}},	//   _оруқ, _títè, بةتت, --, 
   {{0xaa7800e4,0x7c38004e,0x00000000,0x00000000}},	//   _ysýp, ètri, --, --, 
   {{0x80d802bf,0x00000000,0x00000000,0x00000000}},	//   оєму_, --, --, --, 
   {{0x443c011c,0x06c400eb,0x00000000,0x00000000}},	//   _tmw_, _এনটি, --, --, 
   {{0x443d458a,0x46d0cad6,0x3f683752,0x5ec400d1}},	//   _umw_, _समाह, жимо_, нимғ, 
   {{0xb7d8011a,0xd04803e3,0x00000000,0x00000000}},	//   חקרי, ntdə, --, --, 
   {{0xfce400d6,0x00000000,0x00000000,0x00000000}},	//   мого, --, --, --, 
   {{0x91fc00da,0x043400b8,0x00000000,0x00000000}},	//   klāj, _śoṣi, --, --, 
   {{0x3ea40205,0xebe07b0e,0xd04803b9,0x00000000}},	//   _çoto_, косп, ktdə, --, 
   {{0x13e00154,0x3a0400f2,0x00000000,0x00000000}},	// [20880] _মোড়, وکسی_, --, --, 
   {{0x7e7400f7,0xb34000a2,0x9ba400db,0x00000000}},	//   _تابئ, _üçes, بەڭى, --, 
   {{0xafd80174,0xb864009a,0x00000000,0x00000000}},	//   rnøv, واصو, --, --, 
   {{0xec300022,0xfbb00034,0x06c4015b,0x59cc00bc}},	//   _анџь, _ज़िम, _এনজি, ालहर, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb778002b,0x940800ac,0xafd808fb,0xceb800bc}},	//   _akṣā, əhət_, lnøt, áři_, 
   {{0xa9640a8f,0xd910cdb5,0x91fc0171,0x00000000}},	//   _жира_, _حیض_, blāj, --, 
   {{0xa80006bb,0xe4640150,0x66706c68,0x00000000}},	//   _изсл, мшыл_, ىگەر, --, 
   {{0xe3ad19b2,0xf1a80c8b,0xd6c46b18,0x00000000}},	//   جرى_, ياده_, _سمای, --, 
   {{0xf504014b,0x00000000,0x00000000,0x00000000}},	//   _оззо, --, --, --, 
   {{0xafd803b2,0x7ae40064,0x00000000,0x00000000}},	//   knøt, _lpkt, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdef9458b,0x7334215c,0x00000000,0x00000000}},	//   мыр_, _تىشا, --, --, 
   {{0xdb04068c,0xe0cc082a,0x741001d3,0x00000000}},	//   mbiè, دزی_, _سوڈا, --, 
   {{0xdd94e9ae,0xd2500014,0x00000000,0x00000000}},	//   тасы, _لچھ_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69c004d4,0xeda40107,0x00000000,0x00000000}},	// [20890] óneo, _ошно, --, --, 
   {{0x9ee800e5,0x00000000,0x00000000,0x00000000}},	//   _کفیل_, --, --, --, 
   {{0x91fc00e2,0x18a400d4,0x00000000,0x00000000}},	//   elāk, ваєм, --, --, 
   {{0x2c2410f5,0x6d54031c,0xd8741411,0xa178010f}},	//   _цьог, _ixxa, نانب, קטאט, 
   {{0xaab4012d,0x91fc00de,0x00000000,0x00000000}},	//   ेंओक, glāk, --, --, 
   {{0x7ae0025c,0x00000000,0x00000000,0x00000000}},	//   ħott, --, --, --, 
   {{0x27140154,0x00000000,0x00000000,0x00000000}},	//   _দেখো_, --, --, --, 
   {{0xb3e84933,0x9f402b1d,0x2901458c,0x91fc00ef}},	//   _རྒྱུ, _maiò_, _irja_, blāk, 
   {{0xe8dc001e,0x93d40055,0x25f437f3,0x786800d0}},	//   _khỏa_, _aṃse, _एसपी_, zývk, 
   {{0x290001bf,0xaac50457,0xdcf000d7,0x00000000}},	//   _krja_, _लिनक, _čeľj, --, 
   {{0xc10400ae,0x00000000,0x00000000,0x00000000}},	//   روحي, --, --, --, 
   {{0x44f04077,0xb4f80375,0x00000000,0x00000000}},	//   _iš_, _מפעי, --, --, 
   {{0xaa780022,0x935800c0,0x00000000,0x00000000}},	//   _apým, _оршу_, --, --, 
   {{0xb8e00135,0x8f8002dd,0x2901458d,0xdb0405e4}},	//   _གྷ_, шқыл, _orja_, sbië, 
   {{0xdb05458e,0xafd803cd,0x290000ef,0x016401a9}},	//   mbié, tnøt, _nrja_, _якко, 
   {{0x9f600428,0x44f00122,0x3c2c0030,0x00000000}},	//   _ũrõr_, _mš_, _býva_, --, 
   {{0x2900003d,0x6d540429,0x44f00114,0x00000000}},	// [208a0] _arja_, _exxa, _lš_, --, 
   {{0xeb940724,0xcee876e1,0xafd87dfa,0xab74009a}},	//   _җир_, _آرين_, snøt, رملا_, 
   {{0x05c806b1,0x51ac01ec,0x96240171,0x00000000}},	//   _राजब, _ﺳﯘﻳﺸ, _šņor, --, 
   {{0x9f4003a2,0xfaa40024,0x00000000,0x00000000}},	//   _haiñ_, _памо, --, --, 
   {{0xdcfc0cc1,0x44f00953,0xb684525b,0x29000135}},	//   marı, _aš_, ىشتى, _erja_, 
   {{0xdcfc8e8e,0xdddc00b0,0xafd803cd,0x00000000}},	//   ları, korō, nnør, --, 
   {{0x7a300393,0x00000000,0x00000000,0x00000000}},	//   _cæte, --, --, --, 
   {{0xdcfc0abc,0xe6140075,0x44f03493,0x00000000}},	//   narı, ддә_, _dš_, --, 
   {{0x44f005be,0x53345e2d,0xe7340faa,0xdc780092}},	//   _eš_, тепт, _зет_, _በእስር_, 
   {{0xdb043d0a,0x44f00010,0xdcfc1b0d,0x290002d2}},	//   rbiè, _fš_, harı, _yrja_, 
   {{0xdcfc0365,0x44f005be,0xb3e40327,0x25b400f2}},	//   karı, _gš_, སབྱུ, _سهند_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x44f00122,0xdcfc0259,0xc1d802dd,0x00000000}},	//   _zš_, darı, _ﺃﻫﺩﺍ, --, 
   {{0xeda406a6,0x6830010e,0xf28400ec,0x00000000}},	//   эшмо, _içde, _ڪپڙو_, --, 
   {{0x9f400086,0xdcfc2791,0x4c9401a9,0x00000000}},	//   _daiñ_, farı, тибс, --, 
   {{0xdcfc0724,0xafd801bf,0xa068009b,0x00000000}},	//   garı, rnøs, _паја_, --, 
   {{0xa9c5458f,0x2bc14590,0xdd3001ef,0x00000000}},	// [208b0] есек, षणबा, _měřt, --, 
   {{0x7d3c001f,0x798c02d0,0xfca800ec,0x00000000}},	//   _አትሌቲ, _cgbw, _ڪاٿو_, --, 
   {{0xdcfc9d58,0x23c401e1,0x7d1805ac,0x25f407f7}},	//   barı, _jìjà_, øtst, _एसबी_, 
   {{0x612855e1,0x5ea420bf,0x1cbc025c,0xdcfc00ac}},	//   lölö, _جمیل, _ངྷི_, carı, 
   {{0xe8dc0016,0x7a302dba,0x44f02e31,0x00000000}},	//   _thỏa_, _sæte, _sš_, --, 
   {{0xb5c0242f,0x44f00010,0x9a840024,0x83fc00e5}},	//   айшл, _pš_, _бусл, plők, 
   {{0x19594591,0x00000000,0x00000000,0x00000000}},	//   _зары_, --, --, --, 
   {{0xd138068f,0x44f002fb,0x00000000,0x00000000}},	//   dzą_, _vš_, --, --, 
   {{0x8554040b,0x3e080150,0x27ec0c86,0x164800f1}},	//   ریچر_, _ءﺟﺯ_, megn_, _ګټلي_, 
   {{0xdcfc3bc2,0x27ed4592,0x44f00165,0x26cd203e}},	//   zarı, legn_, _tš_, mugo_, 
   {{0xf9900302,0xdcfc71e1,0x44b40276,0x00000000}},	//   ירי_, yarı, _рбес, --, 
   {{0xdcfc03be,0x23c401e1,0x27ec6c77,0xef5c0023}},	//   xarı, _dìjà_, negn_, _መቕዘፍ, 
   {{0x26cd4593,0xdcfc3e67,0xeb9c143a,0xf5e40150}},	//   nugo_, varı, _enøk_, _ستەۋ, 
   {{0x27ed4594,0x23c401e1,0x7c654595,0x4df54596}},	//   hegn_, _fìjà_, چارل, ляст, 
   {{0xdcfc3235,0xd1380034,0x7c646c68,0x00000000}},	//   tarı, czą_, نارل, --, 
   {{0x51843bb3,0x6b8c074d,0x26cd4597,0x3154008f}},	//   _суча, _cgcg, kugo_, _שיקן_, 
   {{0xdcfc8e8e,0x3b842df7,0x27ec05d5,0xba7400ec}},	// [208c0] rarı, тлаг, degn_, نائت, 
   {{0x26cd4598,0xdcfc0365,0x999800b0,0x7a3001bf}},	//   dugo_, sarı, _torō_, _sætb, 
   {{0xdcfc06b9,0xee340276,0xaca00432,0x00000000}},	//   parı, _рнэ_, _diỳe, --, 
   {{0x26cc0451,0x80a80c58,0x27ec07c5,0xb6a4ff76}},	//   fugo_, _কমঞ্, gegn_, видл, 
   {{0xfaa41677,0x27b13bff,0x57040124,0x00000000}},	//   _јаго, рәсс, ыҟаз, --, 
   {{0xa9a14599,0x18b4013d,0x7c34007c,0x6b7401af}},	//   _вирд, _бәдр, lhyr, _рәсс_, 
   {{0xaa41459a,0x4990b4a9,0x7a3001bf,0x26cc0064}},	//   _терл, _ایمر, _tætb, augo_, 
   {{0x7c340cfd,0x13f5459b,0xa504026a,0x26cc0a49}},	//   nhyr, узия, ђења_, bugo_, 
   {{0xdd300118,0x00000000,0x00000000,0x00000000}},	//   _věřt, --, --, --, 
   {{0x52140b01,0x22a40241,0x50f400d8,0x046400db}},	//   удот, _síkò_, гзот, ктөм, 
   {{0xc4c48a91,0x645404d4,0x30a40395,0x00000000}},	//   _متنو, éxic, ърпв, --, 
   {{0xd1380034,0x00000000,0x00000000,0x00000000}},	//   rzą_, --, --, --, 
   {{0xd138068f,0x00000000,0x00000000,0x00000000}},	//   szą_, --, --, --, 
   {{0x27ec05d5,0xdd1c0118,0x835001d3,0xa19054e7}},	//   zegn_, láře, _چھیا, _кашч, 
   {{0x71700131,0x22a401e1,0x00000000,0x00000000}},	//   _خۇدا, _tíkò_, --, --, 
   {{0x26cc5f78,0x7c341368,0xdd1c0118,0x00000000}},	//   yugo_, ghyr, náře, --, 
   {{0x9b940323,0x27ec0c86,0x26cc021c,0xf1b4041c}},	// [208d0] риуц, vegn_, xugo_, _आजान, 
   {{0x5a35407c,0x26cc2da1,0x6e4000d1,0x6fa80154}},	//   анут, vugo_, _ئۆسم, _কায়ে, 
   {{0x27ed459c,0x98481432,0x99d5459d,0xae7000d1}},	//   tegn_, _ağı_, شتلا, _مۇڭغ, 
   {{0x26cc00ca,0x56642099,0x7c3439cb,0x00000000}},	//   tugo_, یدوف, chyr, --, 
   {{0x27ed459e,0xe70825f4,0xeb9c01bf,0x6aac0332}},	//   regn_, بتان_, _ifø_, _uwcf, 
   {{0xd7740597,0xbb38008f,0x96040131,0x27ed459f}},	//   جامع, _טערי, لبىم, segn_, 
   {{0x26cc1c06,0x0444535f,0x27ec05d5,0x00000000}},	//   sugo_, лекн, pegn_, --, 
   {{0x91fc0421,0xa3e002ab,0xa8500116,0x00000000}},	//   ilāu, _पॉश_, _тебә, --, 
   {{0xaa7800e4,0x00000000,0x00000000,0x00000000}},	//   _apýi, --, --, --, 
   {{0x7d180267,0x00000000,0x00000000,0x00000000}},	//   ätsk, --, --, --, 
   {{0x358c044e,0xeb9c01bf,0x7c340022,0x00000000}},	//   _ሓሳባት_, _ofø_, yhyr, --, 
   {{0xbea545a0,0x3ea4670b,0xb81401ad,0x7a300aab}},	//   ламк, лимг, णायम_, _mæta, 
   {{0xed541b74,0x7a300393,0xed880092,0x2128007f}},	//   ҳор_, _læta, ኒስቴር_, ņch_, 
   {{0x62200075,0xc10400ec,0xfca90fec,0xf774008f}},	//   _خوتە, _موتي, فارو_, טערי_, 
   {{0x442d45a1,0x6da0016c,0xc0e44dbb,0x224800d0}},	//   oke_, сиса, _сойк, écku_, 
   {{0x442d45a2,0x5ba43419,0x00000000,0x00000000}},	//   nke_, рлағ, --, --, 
   {{0xf99145a3,0xeb9c0158,0x7c34e042,0x5a443419}},	// [208e0] مبا_, _dfø_, rhyr, амағ, 
   {{0xe9d40a16,0x442d45a4,0x7a3008a5,0x7c340363}},	//   лку_, hke_, _bæta, shyr, 
   {{0x442d45a5,0x7c3545a6,0x00000000,0x00000000}},	//   kke_, phyr, --, --, 
   {{0x442d45a7,0x3eb02960,0xa3e00412,0x00000000}},	//   jke_, _kwyt_, _पॉल_, --, 
   {{0x442d45a8,0x786c022e,0xe9d40131,0x00000000}},	//   dke_, _dеvо, _әкс_, --, 
   {{0x442c7890,0xe60c21ea,0x7af403cb,0xd91000ec}},	//   eke_, كشى_, mwyt, _وڌا_, 
   {{0x442d45a9,0x7af40368,0xdd1c0118,0xf4880229}},	//   fke_, lwyt, táře, нщик_, 
   {{0x7bd545aa,0x442c3386,0xe8080073,0x1784030d}},	//   ngyu, gke_, _सोपा_, _кӳлм, 
   {{0x91fc00da,0x386545ab,0x7af40368,0x35a40139}},	//   klāt, moor_, nwyt, _базг, 
   {{0xe29c19cf,0x3865270e,0x3f900280,0x00000000}},	//   íða_, loor_, _agyu_, --, 
   {{0x7af4033f,0x2ab80241,0x9f4c0118,0x00000000}},	//   hwyt, _kàbá_, ědý_, --, 
   {{0x764945ac,0x38640151,0x6a680e78,0x418401ec}},	//   lify, noor_, lüft, штығ, 
   {{0xab581570,0xe80804fa,0x00000000,0x00000000}},	//   _adün, _सोफा_, --, --, 
   {{0xe8081533,0x386465c7,0x22480a40,0x3eb00042}},	//   _सोना_, hoor_, éckt_, _dwyt_, 
   {{0xed740020,0x38649e7a,0xdd5801c6,0x25f4230e}},	//   _በድጋሚ_, koor_, гарч_, _एससी_, 
   {{0x386545ad,0xa3e41f13,0x7af40042,0x7a3008a5}},	//   joor_, म्प_, fwyt, _ræta, 
   {{0x386545ae,0x7af40142,0x7a3001a8,0x00000000}},	// [208f0] door_, gwyt, _sæta, --, 
   {{0x442d45af,0x38640af9,0x49a402dd,0xe9b40583}},	//   zke_, eoor_, рыағ, اناں_, 
   {{0x29052875,0x442d45b0,0x7648b3ad,0x1c000cb3}},	//   ína_, yke_, dify, _लोकल_, 
   {{0x386545b1,0x7af40175,0x7a3003b2,0x83fc00e5}},	//   goor_, bwyt, _væta, nlőt, 
   {{0x6f181a80,0x7648007f,0x290401e4,0x00000000}},	//   äuch, fify, ŭna_, --, 
   {{0xa3e4906f,0xaa780124,0x199402bf,0x442c0210}},	//   म्न_, _apýv, _гаря, wke_, 
   {{0x442c3466,0x386545b2,0x845945b3,0x69d4209c}},	//   tke_, boor_, крит_, mgxe, 
   {{0x6a6803fa,0x5fd437c8,0x91fc00e2,0x00000000}},	//   rüfu, _थाइल, klās, --, 
   {{0xe80831a0,0x01dc00cc,0x42540902,0xa30000fb}},	//   _सोया_, _ভোগদ, итот, сүле, 
   {{0x442c08d7,0x69d40928,0x27fd45b4,0xc24545b5}},	//   ske_, ngxe, _haun_, рнок, 
   {{0x1ddc0490,0xc0e40229,0xbd880092,0x00000000}},	//   _बाबत, шонк, ናንተም_, --, 
   {{0xd71c00bd,0x27fd45b6,0xdcfc003a,0x442cdea7}},	//   _দেয়া_, _jaun_, scrī, qke_, 
   {{0x27fd45b7,0x63b945b8,0x93943b7a,0x224801c7}},	//   _maun_, maun, _اجما, écks_, 
   {{0x63b945b9,0x27fd45ba,0x62989c4a,0x3cf945bb}},	//   laun, _laun_, mquo, _pspv_, 
   {{0xa244004b,0xaa7800c7,0x32f4033f,0xe8080037}},	//   _لیکل_, _ypýv, _zły_, _सोभा_, 
   {{0x63b945bc,0x27fd45bd,0xbb7400a7,0x7c3800e2}},	//   naun, _naun_, аузъ, ītro, 
   {{0xeb9545be,0xa3e4043e,0x386545bf,0x629945c0}},	// [20900] риу_, म्य_, voor_, nquo, 
   {{0x63b945c1,0x7af400a9,0xab581666,0x764803ac}},	//   haun, rwyt, _idül, xify, 
   {{0x41dc2072,0x27fd45c2,0x20010ff3,0x386545c3}},	//   _मानस, _baun_, _kaii_, toor_, 
   {{0xa3e4038e,0x63b800da,0xa964241e,0x629802d0}},	//   म्म_, jaun, шиха_, kquo, 
   {{0x764945c4,0x63b945c5,0x200145c6,0x386545c7}},	//   tify, daun, _maii_, roor_, 
   {{0x63b80418,0x3864526b,0x00000000,0x00000000}},	//   eaun, soor_, --, --, 
   {{0x764945c8,0x63b945c9,0x386545ca,0x26dd45cb}},	//   rify, faun, poor_, _equo_, 
   {{0x63b803b4,0x27fc0c3a,0x764945cc,0x20000270}},	//   gaun, _gaun_, sify, _naii_, 
   {{0x55c46518,0x26dc0208,0x68300432,0x00000000}},	//   _газғ, _gquo_, _uçda, --, 
   {{0xa3e411a0,0x27fc0e78,0x00000000,0x00000000}},	//   म्ब_, _zaun_, --, --, 
   {{0x63b945cd,0x7bc545ce,0x9f400109,0x27fc0c67}},	//   baun, _odku, _abià_, _yaun_, 
   {{0xd5e80943,0x20005ec3,0xaa7800e4,0x00000000}},	//   _miḓ, _caii_, _upýv, --, 
   {{0x62983ae2,0xa8540375,0x7a301427,0xea9c0055}},	//   cquo, שיכה_, _rætn, _puṭe_, 
   {{0x7a3004ce,0x00000000,0x00000000,0x00000000}},	//   _sætn, --, --, --, 
   {{0x20001132,0xc21001d9,0xec68010b,0x248c15b7}},	//   _faii_, _رٔٹ_, врак_, _ümmü_, 
   {{0x2000003a,0x00000000,0x00000000,0x00000000}},	//   _gaii_, --, --, --, 
   {{0x27fd45cf,0xaa7801f1,0x207c00c8,0x01dc02f5}},	// [20910] _raun_, _opýt, _באהא, _ভোটদ, 
   {{0x63b823db,0x27fd45d0,0x83fc00e5,0x00000000}},	//   zaun, _saun_, nlőr, --, 
   {{0x27fd45d1,0x63b80357,0x26dc180f,0xa3e402ab}},	//   _paun_, yaun, _squo_, म्ड_, 
   {{0xd7c945d2,0xdd1c012c,0x765802d3,0x9f040b8a}},	//   لومه_, _nářa, _ajty, _اویو, 
   {{0x999801f1,0xd7f82a65,0x248c002d,0x27fc05d5}},	//   _smrť_, рух_, _rigm_, _vaun_, 
   {{0x63b945d3,0x27fc015d,0xa8a400f0,0x6a680112}},	//   waun, _waun_, _врак, rüfs, 
   {{0x27fd45d4,0x63b945d5,0xdb0400e4,0xf4f00124}},	//   _taun_, taun, mbiá, зҧхь, 
   {{0x63b80421,0x62980381,0x195945d6,0xd808010a}},	//   uaun, tquo, _тасы_, _кхул_, 
   {{0x63b945d7,0xc244255b,0x47350c35,0xdb04004e}},	//   raun, йник, _унас, laiò, 
   {{0x62980231,0xe4e410f5,0x200145d8,0xb06002f6}},	//   rquo, _відн, _saii_, äänt, 
   {{0x63b945d9,0x6298b1e1,0x5558084c,0xa3dc0f4a}},	//   paun, squo, _кафя_, _ताप_, 
   {{0x44e145da,0xaac43806,0x73300075,0x6da0013e}},	//   mó_, _लिंक, تىۋا, ҷира, 
   {{0x69c42804,0x44e145db,0x200145dc,0x438400c6}},	//   _odje, ló_, _vaii_, _الشق, 
   {{0x69c4069c,0x6da145dd,0xd148721b,0x00000000}},	//   _ndje, зира, اشین_, --, 
   {{0x44e145de,0x20000421,0x7fd420c8,0x00000000}},	//   nó_, _taii_, _ліпі, --, 
   {{0x44e00789,0xbea444e4,0x00000000,0x00000000}},	//   ió_, _лаик, --, --, 
   {{0xa3dc725e,0x69c40841,0xb9e809a5,0xb994007b}},	// [20920] _तान_, _bdje, лмаз_, مشاغ, 
   {{0x18b40588,0xa2cc012c,0x26cc0219,0xa3e40254}},	//   жәар, _दिन्, drgo_, म्त_, 
   {{0x44e145df,0x31b804ac,0x490000db,0x7d0401f7}},	//   jó_, רזענ, мүрг, _اِجه, 
   {{0x44e145e0,0xaa7945e1,0x69c40455,0x00000000}},	//   dó_, _spýt, _edje, --, 
   {{0xd5b800b0,0x44e00077,0x4b5402e8,0x00000000}},	//   _peā_, eó_, _дърт, --, 
   {{0x44e145e2,0xe1e403e6,0x5be40050,0x69c401a6}},	//   fó_, _عس_, _اتھہ, _gdje, 
   {{0x44e145e3,0x96c40034,0x7c250c91,0xdb04004e}},	//   gó_, _रिकॉ, _kokr, paió, 
   {{0x69c545e4,0xafd80158,0x7c2545e5,0x00000000}},	//   _zdje, mhøg, _jokr, --, 
   {{0x326468df,0xaa780022,0xafd83619,0x30a405a2}},	//   йтов, _ipýr, lhøg, әров, 
   {{0x44e145e6,0x41dc05ba,0x11d80597,0x7c248f24}},	//   bó_, _माणस, جودة_, _lokr, 
   {{0x44e145e7,0x7c2545e8,0xb3c80166,0x7a3003b2}},	//   có_, _ookr, _блез_, _rætl, 
   {{0x7c2545e9,0xf1a803e6,0xe3b40108,0xe1ec01e2}},	//   _nokr, _ڵاته_, _гбц_, وسۍ_, 
   {{0xb37400f7,0xdb04005a,0xe36001af,0x2d8000d1}},	//   _اداش, kaiñ, _екци, ﻨﯩﻨﻰ_, 
   {{0xccfc013b,0xafd805ac,0xcda80592,0x4c9400d4}},	//   _hyɛɛ_, khøg, شهره_, живс, 
   {{0x7c2545ea,0xccfc013f,0xc0c40022,0xdf00031c}},	//   _bokr, _kyɛɛ_, _дшық, ċċax_, 
   {{0x7c24194f,0x318c0213,0x00000000,0x00000000}},	//   _cokr, məz_, --, --, 
   {{0x44e0066d,0x7a30032e,0x00000000,0x00000000}},	// [20930] zó_, _tætl, --, --, 
   {{0x98b84ba9,0x44e145eb,0xaa780022,0x00000000}},	//   _ayrı_, yó_, _apýr, --, 
   {{0xda78223a,0xc7945aba,0x44e00548,0x48c803d4}},	//   сят_, орлы, xó_, ৰব্ৰ, 
   {{0x44e145ec,0xccfc013f,0xdb0400e4,0x00000000}},	//   vó_, _nyɛɛ_, sbiá, --, 
   {{0x21c8013f,0x00000000,0x00000000,0x00000000}},	//   _wɔhɔ_, --, --, --, 
   {{0x44e000f8,0xaa7800e4,0x3e500100,0x290401e3}},	//   tó_, _epýr, pņte_, ånas_, 
   {{0x5e58008f,0x92e80183,0x00000000,0x00000000}},	//   זיגע_, মটো_, --, --, 
   {{0x44e0102c,0x42c945ed,0xf8aceb63,0x613c0241}},	//   ró_, агин_, _شکم_, _lálé, 
   {{0x44e145ee,0xe5c80724,0x825001f3,0xa08400ee}},	//   só_, _быел_, _ንብረታ, үңле, 
   {{0x44e145ef,0x318c0213,0x00000000,0x00000000}},	//   pó_, fəz_, --, --, 
   {{0x44e00429,0xaa7800c7,0x147401d3,0xf65005d0}},	//   qó_, _ypýr, _کالج, _קצב_, 
   {{0x44c4005f,0xafd80158,0x92e80154,0x00000000}},	//   mē_, onøy, ময়ে_, --, 
   {{0x44c400da,0x7c2545f0,0x6448e9af,0xafd80217}},	//   lē_, _rokr, _imgi, nnøy, 
   {{0x64a001a6,0xafd80158,0xdb0522c4,0x00000000}},	//   _gđic, yhøg, daið, --, 
   {{0x8c0003f4,0x44c4005f,0x00000000,0x00000000}},	//   _একজন_, nē_, --, --, 
   {{0xeb9545f1,0xafd800cc,0xeb9c3c02,0x1c14000d}},	//   жит_, knøy, _snør_, डाइल_, 
   {{0xdb040120,0x613c01e1,0xba2545f2,0x00000000}},	// [20940] ibiç, _fálé, одак, --, 
   {{0x44c42df9,0x7c2401bf,0xafd82147,0x0b580153}},	//   kē_, _wokr, thøg, ёрты_, 
   {{0x64485629,0x7c2545f3,0x47b404c5,0xded002d3}},	//   _omgi, _tokr, ুলনী, _እቲኣ_, 
   {{0xdb2401ed,0x44c4005f,0x9ba40131,0xafd8143a}},	//   _فوجی, dē_, _رەئى, rhøg, 
   {{0xfaa40139,0xaac40316,0x290410d1,0xafd808fb}},	//   _фаго, _लिएक, ånar_, shøg, 
   {{0xa3e48a4f,0x644945f4,0xafd82ab7,0x91fc00b0}},	//   म्स_, _amgi, niør, roāk, 
   {{0xaa780022,0xc8b40153,0x00000000,0x00000000}},	//   _ipýp, _нсты, --, --, 
   {{0x68e145f5,0xf2c545f6,0xb7d8004b,0x318c0213}},	//   ànde, осон, _خورا_, vəz_, 
   {{0xe734020f,0x91c40075,0x98a400fb,0x00000000}},	//   _дет_, пәйл, _фиғе, --, 
   {{0x64490187,0xc764247f,0x55c400fb,0x00000000}},	//   _emgi, _راقى, _хажғ, --, 
   {{0xfbc807b7,0xa3e40ce0,0x44c400e2,0xa9980a7c}},	//   िणाम, म्ह_, cē_, יביר, 
   {{0x04640150,0x00000000,0x00000000,0x00000000}},	//   _етім, --, --, --, 
   {{0xa3e002ab,0xaa7800e4,0xa3dc00dc,0xe6780208}},	//   _पॉट_, _opýp, _तात_, _hưở, 
   {{0xafd83c38,0xdef80953,0x318c03e3,0x00000000}},	//   tiøs, цыю_, pəz_, --, 
   {{0xdd9545f7,0x5e580276,0x64480042,0xacf40116}},	//   дары, циря_, _ymgi, әнғу_, 
   {{0xaa7800c7,0x2904003a,0x00000000,0x00000000}},	//   _apýp, ænam_, --, --, 
   {{0xe9a810e0,0x44c4005f,0xafd808fb,0x200401e4}},	// [20950] لدان_, zē_, siøs, ɾmi_, 
   {{0xd9981e4a,0xda782f34,0x00000000,0x00000000}},	//   ەنەت_, оях_, --, --, 
   {{0x7a3001bf,0xda08009a,0x00000000,0x00000000}},	//   _mæth, تيله_, --, --, 
   {{0xaa7800e4,0x44c400e2,0x7d1803cd,0x2b44009d}},	//   _epýp, vē_, åtse, _дэгг, 
   {{0x039400fd,0x44c402b5,0x00000000,0x00000000}},	//   үрия, wē_, --, --, 
   {{0xdb5800c6,0xafd8964d,0x386400f3,0x44c400e2}},	//   _фюю_, rnøy, čora_, tē_, 
   {{0x19587595,0x1a68036b,0x44c43495,0xafd808fb}},	//   _дары_, _بیلی_, uē_, snøy, 
   {{0x4438f274,0xd5080131,0x57f41677,0x44c4005f}},	//   ós_, زغىن_, _опст, rē_, 
   {{0x44c4005f,0x45d400a8,0xaa7800c7,0x00000000}},	//   sē_, _ноас, _ypýp, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7a3002d2,0x00000000,0x00000000,0x00000000}},	//   _sætk, --, --, --, 
   {{0x6448209c,0x3e7401a8,0x1474113e,0x28a00037}},	//   _umgi, mæti_, _قانج, _ओढनि, 
   {{0x20040038,0x3e740252,0x64589663,0x00000000}},	//   ľmi_, læti_, mnui, --, 
   {{0x20043883,0x64580254,0xc0e800ec,0xa3e40c87}},	//   žmi_, lnui, _هفتن_, म्र_, 
   {{0xafd90df5,0xd24c0133,0x4dec000d,0x00000000}},	//   riør, _ڕۆی_, _चउरई_, --, 
   {{0x645945f8,0xaac4068f,0xfaa40022,0x7aa545f9}},	//   nnui, _लिखक, заао, зиаз, 
   {{0x6b6145fa,0xbd8801d9,0x64580356,0xf090011a}},	// [20960] екта, _گندن_, inui, _אנה_, 
   {{0x91fc0421,0x64580afe,0x7a3002d2,0x3e7403b2}},	//   toāi, hnui, _kæti, kæti_, 
   {{0x64580a73,0x00000000,0x00000000,0x00000000}},	//   knui, --, --, --, 
   {{0xdb040cf9,0xfc300597,0x7a300008,0x00000000}},	//   ncië, _أحد_, _mæti, --, 
   {{0x7c3545fb,0x7a3145fc,0x4cb0015b,0x628002f0}},	//   mkyr, _læti, _জয়পু, _ohno, 
   {{0xe8dc07ae,0x64580334,0x7e6c047e,0x00000000}},	//   _giữa_, enui, nobp, --, 
   {{0x659145fd,0x34481ef5,0x645945fe,0x5398001f}},	//   нашу, йчин_, fnui, _መታየት_, 
   {{0x7c3545ff,0x62800036,0xb3c41dd1,0x7a3008fb}},	//   nkyr, _ahno, रृंख, _sæth, 
   {{0xe3ac5734,0x888001d9,0x317800d0,0x00000000}},	//   درى_, _شیٖن, _špz_, --, 
   {{0x62803e7c,0x7a300008,0xc04c00aa,0x7c34013f}},	//   _chno, _bæti, یږي_, hkyr, 
   {{0x7c3401f4,0xf074104e,0xd0101bf4,0x00000000}},	//   kkyr, зинә_, نلد_, --, 
   {{0xe1ec7f05,0x251808a8,0x73e40024,0x64a0009d}},	//   پسی_, _לובא, _ходз, _чаца, 
   {{0xee8402f6,0x7c3400cc,0x7a30005c,0xf2680484}},	//   зыво, dkyr, _tæth, _лидл_, 
   {{0xd25012a4,0x62800e89,0x6ca4082d,0x7a30032e}},	//   _جنت_, _ghno, зраж, _fæti, 
   {{0xa154b3ee,0xe9fc001e,0x7a3001a8,0x108801e0}},	//   _нашу_, _ngạc_, _gæti, _мөмк_, 
   {{0xb3082fb5,0x31c40316,0x7c340158,0x3a280205}},	//   _ཀློང_, bízí_, gkyr, _aobp_, 
   {{0xdb054600,0xa3dc0574,0x00000000,0x00000000}},	// [20970] nciè, _तास_, --, --, 
   {{0xe29c09f3,0x91fc02b1,0x68302a9b,0xa2cc07b6}},	//   íði_, roāw, _içdi, _दिस्, 
   {{0xd7c800f1,0x00000000,0x00000000,0x00000000}},	//   ړونه_, --, --, --, 
   {{0x7c341368,0x00000000,0x00000000,0x00000000}},	//   ckyr, --, --, --, 
   {{0x7c384056,0x070801d5,0x41dc0118,0x00000000}},	//   être, تيشي_, _मालस, --, 
   {{0xab5801b8,0xa3dc05f9,0xa9a40022,0x80bc3be5}},	//   _veüd, _ताह_, _хәаҧ_, वीडे, 
   {{0xa874103c,0x00000000,0x00000000,0x00000000}},	//   _فطرت, --, --, --, 
   {{0x6280138f,0x64584a3e,0x7a3008a5,0x00000000}},	//   _shno, unui, _ræti, --, 
   {{0x62800656,0x64594601,0x7a3001a8,0xd8384f41}},	//   _phno, rnui, _sæti, _ээр_, 
   {{0x6458084c,0x00c81f42,0xa3dd1ada,0xe7840107}},	//   snui, олок_, _ताव_, _дуҷо, 
   {{0xa2cc29d9,0x412801c0,0x95c4a864,0x64580175}},	//   _दिव्, цоно_, _سينه, pnui, 
   {{0xcdc8025f,0x83186449,0xefd40092,0x00000000}},	//   _כך_, _وقار_, _ይታይ_, --, 
   {{0x9db80003,0xdb040196,0x7c3403d4,0x66fc05d7}},	//   _དབྱེ, rcië, vkyr, ोटिक_, 
   {{0x443c025c,0x999802f0,0x7a3002d2,0xc1040472}},	//   _hlw_, _smrž_, _tæti, _يوشي, 
   {{0x6da14602,0xb2f8003d,0x443c511d,0xa2a40014}},	//   тиса, _དགོང_, _klw_, _بُڈٕ_, 
   {{0x41dc0b67,0x957c0210,0x00000000,0x00000000}},	//   _माँस, _zbąs, --, --, 
   {{0x29014603,0x7c354604,0xfaa800f2,0x70500633}},	// [20980] _asja_, rkyr, زهاي_, _جنيا, 
   {{0xf990594c,0x7c3402d5,0xdb041184,0xb1100131}},	//   نبا_, skyr, ncié, _سوۋغ, 
   {{0x443c0c8a,0xae1800c8,0x7c28022e,0xf77000e5}},	//   _olw_, _וויכ, _донг_, ھاؤ_, 
   {{0x68e14605,0xe8dc004d,0x443d4606,0xd6c40022}},	//   ànda, _giửa_, _nlw_, еидқ, 
   {{0x41dc1546,0x290002d2,0xabf8011a,0x00000000}},	//   _मांस, _esja_, _והכר, --, 
   {{0x28d81d8a,0xe60c3ed0,0xc7641473,0x443c0368}},	//   मूहि, لشى_, رانى, _alw_, 
   {{0xb8640a2c,0x443c009f,0xe0c40cd6,0xab5817da}},	//   _قارو, _blw_, _جز_, _geüb, 
   {{0xb3080003,0x539802d3,0xda1c00c5,0xdb04004e}},	//   _ཀླུང_, _መዳያት_, नावत_, tciè, 
   {{0xa3dc8061,0x35a40228,0x443c0036,0x30a001ec}},	//   _तार_, _жазг, _dlw_, _ﺍﻟﺸﻴ_, 
   {{0xa68025a2,0xdb04503f,0x443c0368,0xa2cc0709}},	//   _алуд, rciè, _elw_, _दिर्, 
   {{0x733400b2,0x443c5c74,0xa2bc01ad,0xfe201684}},	//   _ڪرائ, _flw_, लीब्, मानस_, 
   {{0x443c5ee5,0xd2501f0d,0x00000000,0x00000000}},	//   _glw_, ئنگ_, --, --, 
   {{0x91c40131,0xb4dc095f,0x73344710,0x00000000}},	//   _пәнл, _तमु_, _ترائ, --, 
   {{0xe210035b,0x00000000,0x00000000,0x00000000}},	//   _амшы, --, --, --, 
   {{0xd30801dc,0xde9424cd,0x960000fe,0x80bc66c0}},	//   _hệ_, тарњ, _এচাম_, वीदे, 
   {{0xd308001e,0x7d180158,0xdddc01e4,0x7a3009e8}},	//   _kệ_, åtsa, morŝ, _mætu, 
   {{0x7a300008,0x8f34010a,0x00000000,0x00000000}},	// [20990] _lætu, _чепц, --, --, 
   {{0xdd90004b,0xb4dc012c,0xd3080051,0x00000000}},	//   اوې_, _तमू_, _mệ_, --, 
   {{0xd3080016,0xa3dc0acd,0x7a30066a,0x286800f7}},	//   _lệ_, _ताल_, _nætu, ордо_, 
   {{0xa2cc52be,0xdcf801d3,0xe5300cad,0x00000000}},	//   _दिल्, _کریش_, _ìbéè, --, 
   {{0x443c0076,0x995800d0,0x6d4402d0,0x30a00150}},	//   _rlw_, háňa_, lzja, _ﺍﻟﺴﻴ_, 
   {{0x29005613,0xfb14008f,0x7a3001a8,0x6aac02d0}},	//   _tsja_, _אַלט_, _bætu, _itcf, 
   {{0x6d44038f,0x29000113,0x03a4010b,0x443c003a}},	//   nzja, _usja_, нийо, _plw_, 
   {{0xd308004d,0x83fc01d3,0x7a3008a5,0x00000000}},	//   _bệ_, llőz, _dætu, --, 
   {{0x443c06ed,0xae0c7875,0xa300013d,0x00000000}},	//   _vlw_, ायान_, түле, --, 
   {{0x7a3001a8,0x6d44036e,0xb380d8fd,0x00000000}},	//   _fætu, kzja, ылыл, --, 
   {{0xdb051904,0x7a3005f7,0x443c002f,0x069001ec}},	//   rcié, _gætu, _tlw_, _ﺟﻮﻳﯩ, 
   {{0x7a3000fc,0x3f680063,0xdb04067c,0x443c0142}},	//   _hætt, зимо_, scié, _ulw_, 
   {{0x7a308ecc,0x00000000,0x00000000,0x00000000}},	//   _kætt, --, --, --, 
   {{0x09d47f53,0xe29c09f3,0x7a3001bf,0x00000000}},	//   স্তা, íðu_, _jætt, --, 
   {{0x7a30008c,0x91fc00b0,0xa2cc01ef,0x00000000}},	//   _mætt, roāt, _míčů_, --, 
   {{0x7a300579,0x31540a7c,0xbbc801f9,0xafe0022e}},	//   _lætt, _ריקן_, िणेक, _боъл, 
   {{0xcaa400e3,0xd308004d,0x30580115,0x3e74032e}},	// [209a0] نصلي, _xệ_, _מדקד, fætt_, 
   {{0xab5805d5,0x7a3000b5,0x3e7403b2,0xa5d8012d}},	//   _adüs, _nætt, gætt_, _नागौ, 
   {{0xa3dc810c,0xab5800db,0x6aac02d0,0x224800d0}},	//   तला_, _peüc, _etcf, écky_, 
   {{0x7a3001a8,0xe97005af,0x00000000,0x00000000}},	//   _rætu, دهمد, --, --, 
   {{0x7a3001a8,0xf09000df,0x3e7402d2,0xc60800eb}},	//   _bætt, אנא_, bætt_, লানা_, 
   {{0x63a8a46e,0x7a30022c,0xb90402f5,0xdb140124}},	//   _afgn, _pætu, _ভন_, _ñaño, 
   {{0xafd80158,0xd3080051,0xa96403c2,0xa50400d8}},	//   dhøn, _sệ_, _зира_, ееја_, 
   {{0xdb0400db,0x7a3003b2,0xa3dc00dc,0x87b801d5}},	//   nciï, _vætu, _ताः_, _жуфт_, 
   {{0x6d44003d,0xdb08004a,0x7a304c5d,0xb5f00220}},	//   zzja, élèv, _fætt, _бүлі, 
   {{0xd30807ae,0x7a314607,0x00000000,0x00000000}},	//   _vệ_, _gætt, --, --, 
   {{0xb4f0004e,0x00000000,0x00000000,0x00000000}},	//   _сүйч, --, --, --, 
   {{0xd308001e,0x65380375,0xefc40023,0xe538011a}},	//   _tệ_, _מעבד, ጽሕዎ_, _מתבר, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d447b58,0xdddc00df,0x2c0401d3,0x00000000}},	//   tzja, porŝ, کٹری_, --, 
   {{0x7a3003b2,0xd25000e5,0x00000000,0x00000000}},	//   _læts, _مچھ_, --, --, 
   {{0xcb0800ec,0x6d440003,0x00000000,0x00000000}},	//   ويزن_, rzja, --, --, 
   {{0x3e7401a8,0xda1c0a8a,0x6d440210,0x00000000}},	// [209b0] tætt_, नांत_, szja, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7a301125,0xe61c0016,0x3e740436,0x98485775}},	//   _rætt, _đô_, rætt_, _aşı_, 
   {{0x7a314608,0x2544002e,0xa3dc0406,0xa8a000db}},	//   _sætt, _jёle_, _ताइ_, _ۅلسۉ, 
   {{0xbaa407dd,0x00000000,0x00000000,0x00000000}},	//   _аусқ, --, --, --, 
   {{0x58840032,0xa3b03337,0x56942fe5,0xb6a001b9}},	//   _ҡыта, जुन_, гачт, шишл, 
   {{0x7a300d12,0xcfd800fe,0xc7640137,0xaaa406e3}},	//   _vætt, ধ্যন, راچى, _कंडक, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7a314609,0x88cc0150,0x72c02eca,0xa2300139}},	//   _tætt, _ءﯗﻳﻰ_, абыз, гьнә, 
   {{0xe610e5e7,0x932401b9,0xa28005af,0x00000000}},	//   _حشر_, چرین, دیتو, --, 
   {{0xafd8005c,0xe8dc004d,0x9324516c,0xa3dc012d}},	//   rhøn, _khựa_, _ەرىن, _ताऊ_, 
   {{0x7998000f,0x3ea47de7,0xeabc01e1,0xafd801bf}},	//   _útwe, кимг, _owù_, shøn, 
   {{0x683045d8,0xd9cc0154,0x00000000,0x00000000}},	//   _uçdu, র্টম, --, --, 
   {{0xafd80162,0x7d18007c,0x00000000,0x00000000}},	//   lhøl, åtso, --, --, 
   {{0x4048004e,0x313000d8,0xd04806be,0x00000000}},	//   _опко_, _вејр, hrdə, --, 
   {{0xe8dc001e,0xafd8022c,0xb0600108,0x00000000}},	//   _nhựa_, nhøl, äätt, --, 
   {{0xb4dc0882,0xa3dc1fca,0x99980356,0x00000000}},	// [209c0] _तम्_, _ताई_, _borş_, --, 
   {{0xd5e01d8a,0xe9d5460a,0x3e74005c,0x00000000}},	//   _नाइज, кку_, ræts_, --, 
   {{0x4dd800c8,0x7a30005c,0x48a8cea4,0x78a001e4}},	//   _אַרױ, _sæts, етім_, ĉovo, 
   {{0xbb84007b,0xd04806be,0x00000000,0x00000000}},	//   _للجي, frdə, --, --, 
   {{0x1784020a,0x4af80276,0x7a30032e,0x2a6c0100}},	//   уҳам, _пэря_, _dætr, èlbè_, 
   {{0xb4b00022,0xeb9408da,0x00000000,0x00000000}},	//   аикә, _шия_, --, --, 
   {{0xa2bc0034,0x7f4800ac,0x7a3001bf,0xca6401d5}},	//   लीस्, _əfqa, _fætr, _серқ, 
   {{0xe61400fd,0x7a30005c,0x00000000,0x00000000}},	//   едә_, _tæts, --, --, 
   {{0xe8080ce0,0x00000000,0x00000000,0x00000000}},	//   _सोटा_, --, --, --, 
   {{0x99980166,0x00000000,0x00000000,0x00000000}},	//   _xorş_, --, --, --, 
   {{0xd3e4104a,0x320801f1,0xe5a13e40,0x7d1801e3}},	//   _مقای, ľby_, _тихи, åtsl, 
   {{0x3208076f,0xe53400c8,0xdddc0356,0xe3b400d8}},	//   žby_, _שטאט_, torş, _абц_, 
   {{0x43b0052f,0x733400cf,0xef640107,0x91fc00ef}},	//   _уҡыр, _جىشا, тъно, gnāc, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb0601073,0xe808007d,0xe2980375,0x68f8107d}},	//   ääst, _सोझा_, _קשור, _ćudo, 
   {{0xe1f400c7,0xd5a401d9,0x00000000,0x00000000}},	//   _згә_, _ژہ_, --, --, 
   {{0x91fc00de,0x00000000,0x00000000,0x00000000}},	// [209d0] cnāc, --, --, --, 
   {{0x7a30037f,0x3ed8008f,0x42700023,0x0ba400c7}},	//   _sætr, _אַטא, _ስእነት_, _әынҭ, 
   {{0xda786582,0xe7b004a9,0xb7840032,0x29040109}},	//   тят_, للاھ, ғәте_, ìna_, 
   {{0x8234001f,0x6ab80200,0x00000000,0x00000000}},	//   _ይወስዳ, _çufo, --, --, 
   {{0xe5a01f71,0x44200016,0x442800df,0xf1e0190c}},	//   қиқи, _đh_, _ĵa_, पलान, 
   {{0xafd801bf,0x00000000,0x00000000,0x00000000}},	//   lkød, --, --, --, 
   {{0xfba80dba,0x00000000,0x00000000,0x00000000}},	//   _कलमम, --, --, --, 
   {{0xe8081d15,0xa56403e6,0x00000000,0x00000000}},	//   _सोचा_, _یدان, --, --, 
   {{0xd064013f,0xafd8022c,0xefc40023,0x00000000}},	//   _ɑsɔr, rhøl, ጽንዕ_, --, 
   {{0x42244294,0xa3dc1431,0xafd80174,0x48e40154}},	//   удов, _ताक_, shøl, নবীর, 
   {{0xa2cc878d,0x569402f4,0x95c80354,0x3eb00162}},	//   _दिक्, _тафт, _шута_, _styt_, 
   {{0xab58180f,0x44280254,0xafd8005c,0xcee80014}},	//   _reün, _õa_, lhøj, ھرُن_, 
   {{0x63b8080b,0x3ce40490,0xa300010b,0x00000000}},	//   mbun, जूने_, _түпе, --, 
   {{0x63b9460b,0xe76008e7,0xb06000c5,0xc0e4074d}},	//   lbun, nòñò, äärt, _бокк, 
   {{0xcdc43daf,0x63b8216b,0x19cc0220,0x00000000}},	//   расқ, obun, _ﻗﯘﻟﺠ, --, 
   {{0x63b9460c,0x51840b3b,0x2cb00051,0x00000000}},	//   nbun, _туча, _dtxd_, --, 
   {{0x63b80639,0x3b8405f5,0xe7600428,0x64a000e5}},	// [209e0] ibun, улаг, kòñò, _főig, 
   {{0x01d4015b,0xc878013d,0xb6a401b9,0x996c00e2}},	//   ত্রদ, _akş_, ҳидл, _vēža_, 
   {{0x63b9460d,0x64b4008f,0xafd801bf,0x68400116}},	//   kbun, nĝiĝ, dhøj, әнча, 
   {{0x2d940131,0x3dc80083,0xa3dc0ce0,0x37a001ec}},	//   _ﻛﯜﻧﻰ_, labw_, _ताग_, сқағ, 
   {{0xa2cc53a5,0x63b8037e,0x7bc400de,0xe60c00f1}},	//   _दिग्, dbun, _ieku, ړشي_, 
   {{0x63b9460e,0x7bc402d3,0xa9a1460f,0xe9a00dce}},	//   ebun, _heku, _гирд, _гарп, 
   {{0x7bc447d8,0xa3dc08e6,0x63b84985,0xafd8072b}},	//   _keku, तलं_, fbun, lkøe, 
   {{0x63b94610,0x7bc4035b,0x3dc80083,0x00000000}},	//   gbun, _jeku, habw_, --, 
   {{0x7bc54611,0xdb04311a,0xe3e400f1,0x00000000}},	//   _meku, mbió, اکمن_, --, 
   {{0x7bc54612,0x63b80393,0x456001d9,0x50f4030d}},	//   _leku, abun, _ژھٹہ, азот, 
   {{0xc5ec03d4,0x7bc4002d,0xd4c41945,0x00000000}},	//   _টোকা_, _oeku, _төлк, --, 
   {{0x7bc54613,0xa3b89f56,0xa3b005dc,0xab5800e5}},	//   _neku, _अभय_, जुद_, _beül, 
   {{0xdef818ce,0xa8540375,0x64b401e4,0x00000000}},	//   лыр_, ריכה_, aĝiĝ, --, 
   {{0x7bc40022,0x92594614,0xecb80956,0xef6401f0}},	//   _aeku, _шалт_, فطرت_, въҳо, 
   {{0x7bc42747,0xdb053474,0x0c94036b,0xd13000ae}},	//   _beku, rbiý, لدرگ, _ذمة_, 
   {{0xa2240124,0x00000000,0x00000000,0x00000000}},	//   _ажәа_, --, --, --, 
   {{0x7bc54615,0x320c0198,0x4a5404f0,0xafd94616}},	// [209f0] _deku, _kafy_, акас, gkøe, 
   {{0x320c05da,0x63b80276,0x2b480208,0x5a341b0a}},	//   _jafy_, zbun, _đhcđ_, бнут, 
   {{0x320c1311,0x7bc54617,0xd9183de2,0x63b886df}},	//   _mafy_, _feku, льц_, ybun, 
   {{0x7bc404d1,0x320c06d9,0xafd800b5,0xf8b422fd}},	//   _geku, _lafy_, lkøb, рөр_, 
   {{0x63b81512,0x7a3001bf,0x668001b9,0xafd801bf}},	//   vbun, _tætp, میرل, thøj, 
   {{0xf4240bc9,0x5a440276,0xafd8143a,0x1cb80244}},	//   ñäni_, _лэса, riøy, _جایب_, 
   {{0x7bc54618,0x69c54619,0x63b8bb30,0xafd8037e}},	//   _yeku, _ieje, tbun, rhøj, 
   {{0x69c44fdf,0x7998002d,0xafd800b5,0xa3dc05d7}},	//   _heje, _útwa, shøj, _ताओ_, 
   {{0x63b8d108,0xd7f811f7,0x00000000,0x00000000}},	//   rbun, _щур_, --, --, 
   {{0x69c5461a,0xdb040765,0x63b9461b,0xab58004e}},	//   _jeje, nciá, sbun, _reül, 
   {{0x69c5461c,0xafd804ce,0x320d461d,0x9f40011c}},	//   _meje, dkøb, _dafy_, _scià_, 
   {{0x69c5461e,0x64b400df,0xe8dc0208,0xc39401af}},	//   _leje, rĝiĝ, _giụa_, _кјлњ, 
   {{0x387c9083,0x7bc5461f,0x442d4620,0x320c0109}},	//   _être_, _reku, mje_, _fafy_, 
   {{0x7bc54621,0x69c40316,0x66014622,0x6ed42dc5}},	//   _seku, _neje, nenk, _बिरु, 
   {{0x7bc54623,0x4b400020,0x442c02d5,0x660001f5}},	//   _peku, _የመጨረ, oje_, ienk, 
   {{0x66014624,0xfce41b74,0x44f00016,0x69c40076}},	//   henk, лоҳо, _mơ_, _aeje, 
   {{0x69c54625,0x7bc54626,0x44f001fb,0xb9e8010b}},	// [20a00] _beje, _veku, _lơ_, кмаз_, 
   {{0x442d4627,0x7bc54628,0xe3a54629,0xdb0435f5}},	//   hje_, _weku, _ژر_, rcià, 
   {{0x442d462a,0x7bc5462b,0x6458013c,0xdb04026c}},	//   kje_, _teku, kiui, scià, 
   {{0x442d462c,0xf09000c8,0x69c5462d,0x66000472}},	//   jje_, ַנג_, _eeje, eenk, 
   {{0x442d462e,0x69c5462f,0x66014630,0xa3dc121d}},	//   dje_, _feje, fenk, _ताज_, 
   {{0x66014631,0x442c068f,0x44f001fb,0x499001ed}},	//   genk, eje_, _bơ_, _کیمر, 
   {{0x44f001dc,0x442d4632,0x0988013e,0xdb040077}},	//   _cơ_, fje_, _барқ_, mbiñ, 
   {{0x442d4633,0x69c54634,0x64580311,0x44f0004d}},	//   gje_, _zeje, giui, _dơ_, 
   {{0x32651e06,0x69c4f3bc,0x33840816,0x00000000}},	//   итов, _yeje, шукв, --, 
   {{0x442d4635,0x66010d2e,0x38641529,0xe5a010e2}},	//   aje_, cenk, lnor_, _дифи, 
   {{0x442d4636,0x38640165,0x44f00051,0x30a001ec}},	//   bje_, onor_, _gơ_, _ﺍﻟﺒﻴ_, 
   {{0x442c14cf,0x38654637,0xd2640046,0x6458e775}},	//   cje_, nnor_, ркүй, ciui, 
   {{0xfe210204,0x6f848743,0x11f80214,0xafd8005c}},	//   मांस_, рунж, _موشک_, tkøb, 
   {{0x30a4a752,0x23494638,0x00000000,0x00000000}},	//   _крив, _جسمی_, --, --, 
   {{0x69c53722,0x44f001fb,0xafd800b5,0xebc40114}},	//   _reje, _xơ_, rkøb, иљан, 
   {{0xe51419e5,0x69c432b9,0x38640240,0xafd8005c}},	//   थिति_, _seje, jnor_, skøb, 
   {{0x69c54639,0x2288168c,0x6601463a,0xee8431af}},	// [20a10] _peje, søke_, yenk, _выно, 
   {{0x442d463b,0x3864a010,0xdde401af,0x6ce40064}},	//   zje_, enor_, _мәсү, _кіме, 
   {{0x69c5463c,0x442d463d,0xf8b40137,0x19a9463e}},	//   _veje, yje_, йөт_, ртуп_, 
   {{0x6601463f,0x38654640,0x69c54641,0x44f0004d}},	//   wenk, gnor_, _weje, _rơ_, 
   {{0x66014642,0x69c54643,0x442d4644,0x44f007ae}},	//   tenk, _teje, vje_, _sơ_, 
   {{0x69c4019f,0x66000112,0x28ac01ad,0x386426de}},	//   _ueje, uenk, _जंपि, anor_, 
   {{0x442d4645,0x58d54646,0x64594647,0xdb041d0e}},	//   tje_, _морт, tiui, lbið, 
   {{0x442c0953,0x76b424a5,0x44f001fb,0x7d180423}},	//   uje_, шләр_, _vơ_, åtsi, 
   {{0x442c193f,0x66014648,0x64583805,0xd7f800d8}},	//   rje_, penk, riui, _њус_, 
   {{0x442c193f,0x44f001fb,0x64580869,0x66008faf}},	//   sje_, _tơ_, siui, qenk, 
   {{0x442d4649,0x3624121e,0x3f84a2ef,0x6458003a}},	//   pje_, _دولہ, _šou_, piui, 
   {{0x442c02d3,0x32080134,0xa3b84466,0x80bc012d}},	//   qje_, _ɔhyɛ_, _अभि_, वीगे, 
   {{0x9475464a,0xab580793,0x14740597,0x6f600962}},	//   _بدلا, _deük, _بالج, звяз, 
   {{0x92940153,0xf4f80241,0xf77400df,0x00000000}},	//   _дачц, _òṣì_, מערי_, --, 
   {{0x3864ecbb,0x22440334,0xc10400ec,0x00000000}},	//   ynor_, _ilnk_, _چوڪي, --, 
   {{0x28a800d1,0x00000000,0x00000000,0x00000000}},	//   ﻴﻪﺗﻠ, --, --, --, 
   {{0xab24343d,0x7ed5464b,0x9ce8015b,0xd1f8001f}},	// [20a20] бота_, _ازبا, খবেন_, ላጆች_, 
   {{0x23980006,0x00000000,0x00000000,0x00000000}},	//   mąjį_, --, --, --, 
   {{0xa9a005f5,0xdb045594,0x38640175,0x00000000}},	//   чихд, rbiñ, tnor_, --, 
   {{0xb748010b,0x37e401d5,0x3178010f,0xb178010f}},	//   лпез_, содг, ארעמ, אטער, 
   {{0x3865464c,0x66e021fa,0x6ec8539d,0x23980153}},	//   rnor_, зоча, तीपु, nąjį_, 
   {{0x38645522,0x91fc00e2,0xca740166,0xb7b885cf}},	//   snor_, gnāl, _дусы, ুলেট, 
   {{0x1fe000fe,0xaa4400f3,0x53900092,0x2a6c398f}},	//   য্যস, _упра_, _ነቢያት_, égbe_, 
   {{0xb9f407db,0xafd803d4,0xf7440120,0x50e4000d}},	//   _ምስ_, lhøv, _лебо, _कमौआ_, 
   {{0xe3ac384b,0x23980024,0x00000000,0x00000000}},	//   رري_, jąjį_, --, --, 
   {{0x23980153,0x6b880174,0x00000000,0x00000000}},	//   dąjį_, ýggi, --, --, 
   {{0x76580024,0x216021d7,0x6ec80073,0x00000000}},	//   _imty, зтяг, तीनु, --, 
   {{0x2ca400e4,0x76a00ca8,0x00000000,0x00000000}},	//   _éndi_, bíyè, --, --, 
   {{0xceb80184,0xb8e8031c,0x28ac07c1,0xe3bc0de2}},	//   шәй_, _ཊས_, _जूनि, ññe_, 
   {{0x25f800ce,0xdef000db,0x00000000,0x00000000}},	//   ल्पी_, رۋپ_, --, --, 
   {{0x64a00e3c,0xec682b95,0x00000000,0x00000000}},	//   _uđit, грак_, --, --, 
   {{0xa2bc04af,0x00000000,0x00000000,0x00000000}},	//   लीक्, --, --, --, 
   {{0x7e7c0270,0x7659464d,0x9d1801b9,0xab6000d1}},	// [20a30] _fkpp, _omty, _ғоят_, سۇسى, 
   {{0x48c400c7,0xdb040162,0x5a340229,0x00000000}},	//   жәаа, rbið, пнут, --, 
   {{0x2d840162,0x00000000,0x00000000,0x00000000}},	//   _áne_, --, --, --, 
   {{0x76580921,0xb7cc00d1,0x07e400f1,0x239c0055}},	//   _amty, _ﻗﯩﺮﻏ, تېری_, _yājī_, 
   {{0xd7f80364,0xd5b8002b,0x76440153,0x7d18007c}},	//   сух_, _enām_, _įkyr, åtsv, 
   {{0x04b40117,0x228803b2,0xa8a400f3,0x1a940006}},	//   осия, køka_, _грак, _наяў, 
   {{0x91fc00da,0x290c1a14,0xf4f00022,0x34b01bf4}},	//   rnāl, āgas_, дҧхь, وموز, 
   {{0x765801e2,0x99541e76,0x22440477,0x68e000db}},	//   _emty, _эксц, _slnk_, àndu, 
   {{0xb9f0069c,0xe73041ff,0x7c380129,0x67280477}},	//   _ነታ_, _عصر_, êtri, qxgj, 
   {{0x22900295,0xe4e40212,0xa2bc1414,0xc59400d8}},	//   dûkù_, _гідн, लीग्, _дизј, 
   {{0xe3b0c015,0x78a000d0,0x00000000,0x00000000}},	//   _فرش_, ňove, --, --, 
   {{0x23980153,0x00000000,0x00000000,0x00000000}},	//   tąjį_, --, --, --, 
   {{0x6e35464e,0x9f4404cc,0x52b000db,0x7658010b}},	//   _boxb, ümà_, _كەيئ, _ymty, 
   {{0xec7c00e4,0xe8dc004d,0x23980153,0x239c00b8}},	//   _akÿ_, _chừa_, rąjį_, _vājī_, 
   {{0xada0e9b3,0x6da01ff0,0x6e340007,0x00000000}},	//   дарл, дира, _doxb, --, 
   {{0xfbd0036b,0xbc180150,0x00000000,0x00000000}},	//   بتآ_, шігі_, --, --, 
   {{0xe7fc0918,0xafd8022c,0xe3a800cc,0x5a4400fb}},	// [20a40] ोजना_, thøv, _গজাব, пмағ, 
   {{0x25f8084a,0xceb800bc,0xafd801bf,0x29040327}},	//   ल्मी_, íře_, nkøn, ħnan_, 
   {{0x3dd801e2,0xafd8022c,0x00000000,0x00000000}},	//   _idpw_, rhøv, --, --, 
   {{0x77841e28,0x6b80063f,0xafd80feb,0x91fc00ef}},	//   олез, ọgas, shøv, gnāj, 
   {{0x7c25464f,0xd6d001d5,0xafd80162,0x4ab80108}},	//   _inkr, ءقت_, kkøn, _гуся_, 
   {{0x6b894650,0x7af400c0,0x00000000,0x00000000}},	//   ügge, mtyt, --, --, 
   {{0x34494651,0xf1a94652,0x65914653,0x867402d5}},	//   ичин_, یاده_, машу, чыцц, 
   {{0x692001c0,0x53340a0e,0x99900419,0x00000000}},	//   _юмса, зеит, _čaňa_, --, 
   {{0xf20448a5,0xd6c403e6,0x7af54654,0xe3ad4655}},	//   ояно, _رمای, ntyt, خرى_, 
   {{0x7af40953,0x765800f1,0x2288022c,0x78bc05ac}},	//   ityt, _umty, tøka_, oppv, 
   {{0x7c254656,0x6e354657,0xb08801f4,0x00000000}},	//   _onkr, _roxb, иёме_, --, 
   {{0xa3b14658,0x22883619,0x8cb00073,0x7af4007c}},	//   _قٍمت, røka_, _आंबो, ktyt, 
   {{0x09d400bd,0x7d1c0857,0x2898008f,0x22883619}},	//   স্টা, _arps, ייטא, søka_, 
   {{0x7c254659,0xe2940229,0xf1a802f2,0x00000000}},	//   _ankr, _дач_, _ئاشه_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa3b02645,0xdd94008e,0x00000000,0x00000000}},	//   _ज्ञ_, фасы, --, --, 
   {{0xe8dc0016,0x7d1c04cc,0x452c0092,0x00000000}},	// [20a50] _thừa_, _erps, ዳልነበ, --, 
   {{0x7c25465a,0x98b80166,0x6f1c01a9,0x2c1801f9}},	//   _enkr, _axrı_, _irqc, _पोरं_, 
   {{0xe8dc0208,0x7d18007c,0xa3a804af,0x91fc00ef}},	//   _khứa_, åtst, _खलल_, enāk, 
   {{0x83fc00e5,0x00000000,0x00000000,0x00000000}},	//   tnőm, --, --, --, 
   {{0xafd8005c,0xc8c80066,0x2ab001c8,0x00000000}},	//   lhøs, _گوزن_, _آڌرڀ, --, 
   {{0xbb3805d0,0x453408da,0xb0d82052,0x00000000}},	//   _העשי, зхит, _भिंग, --, 
   {{0x0445465b,0x7c24000f,0xafd8003b,0x35a08fa3}},	//   зейн, _ynkr, nhøs, нашг, 
   {{0x2afc3105,0xaadc0073,0xdd3001ef,0x00000000}},	//   _उहाँ_, _फटाक, _jěšt, --, 
   {{0x27fc0086,0x28ac5a30,0x6ed4230e,0x78a000d7}},	//   _ibun_, _जूति, _बिगु, ňovc, 
   {{0xe4a40022,0x45d47125,0x00000000,0x00000000}},	//   _дрдо, _хожс, --, --, 
   {{0x0518007b,0xafd80174,0x00000000,0x00000000}},	//   _دياب_, rkøn, --, --, 
   {{0xe8dc0016,0xbba802a0,0xafd8a8b2,0xb4f8011a}},	//   _chứa_, _कलेक, skøn, _לפעי, 
   {{0x7d1d3b4d,0x6449465c,0x27fc00c6,0x25f805f9}},	//   _srps, _ilgi, _mbun_, ल्थी_, 
   {{0xe7c802dd,0x00000000,0x00000000,0x00000000}},	//   _ﻗﯩﺰﺟ, --, --, --, 
   {{0x27fc013f,0x2740002b,0x00000000,0x00000000}},	//   _obun_, _hīnā_, --, --, 
   {{0x7af403cd,0xc7a401d3,0xafd801bf,0xe4e0000d}},	//   ttyt, _لڑ_, nkøl, _गिनि_, 
   {{0xab24dcf2,0x7af401f5,0xa2bc0490,0x83fc01d3}},	// [20a60] пота_, utyt, लीच्, tnőj, 
   {{0x27fc0c09,0x6a80084c,0x7af42bab,0xacc8012d}},	//   _abun_, елуа, rtyt, _żółw, 
   {{0x7af5465d,0x6449465e,0xafd8072b,0x2e38011a}},	//   styt, _olgi, mhør, _הגינ, 
   {{0xfaa480e2,0x7c2448b3,0xafd8fb11,0xd7640e60}},	//   _намо, _unkr, lhør, ونای, 
   {{0x2000002e,0xafd8005c,0x76a001e1,0x00000000}},	//   _mbii_, dkøl, _níyì, --, 
   {{0x64480006,0x27fc0ca8,0xafd8072b,0x060400c7}},	//   _algi, _ebun_, nhør, мҕуп_, 
   {{0x68f4035a,0x00000000,0x00000000,0x00000000}},	//   ctxd, --, --, --, 
   {{0x68e030cf,0x27fc01e1,0x80d40892,0x9a780092}},	//   ánde, _gbun_, _भिजे, ያገኘው_, 
   {{0x644803b2,0x00000000,0x00000000,0x00000000}},	//   _dlgi, --, --, --, 
   {{0x6449465f,0x78ac1cbd,0x25f806ab,0x20014660}},	//   _elgi, _kubv, ल्दी_, _abii_, 
   {{0x68300432,0x64b000bc,0xafd8072b,0x00000000}},	//   _açdy, _přiř, dhør, --, 
   {{0x78ac0e8a,0xaf514661,0x00000000,0x00000000}},	//   _mubv, енмә, --, --, 
   {{0xa85402e4,0xafd801bf,0xdd940022,0x00000000}},	//   ליטה_, fhør, ҵары, --, 
   {{0x8cb03eaf,0xfba8000d,0x6398011a,0x00000000}},	//   _आंदो, _कलउम, _הסדנ, --, 
   {{0xd7cc0574,0x5e58084c,0xa3b01d68,0x62840327}},	//   ाराच, чиря_, जुक_, ċjot, 
   {{0x3cfc7dad,0xafd80fac,0xa06800d8,0x00000000}},	//   _लहरे_, rhøs, _наја_, --, 
   {{0xe9a94662,0x6fc06225,0x91fc005f,0xdd300118}},	// [20a70] مدان_, _व्यं, ciāc, _věšt, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdd30013a,0x00000000,0x00000000,0x00000000}},	//   _těšt, --, --, --, 
   {{0xd5b8442c,0x99647753,0x00000000,0x00000000}},	//   _afā_, хтул, --, --, 
   {{0xea60215c,0xefdc0023,0x09b400eb,0x00000000}},	//   _كۇرپ, _ንኢድ_, টরবা, --, 
   {{0x9a8401c0,0xd7741c3e,0x00000000,0x00000000}},	//   _зусл, رانع, --, --, 
   {{0x78a00232,0x57a40124,0x00000000,0x00000000}},	//   ňova, мшәа, --, --, 
   {{0x27fc8a67,0x03254663,0x443809f3,0x54e41a02}},	//   _ubun_, ддин, ðs_, رسىق, 
   {{0xafd869e8,0x00000000,0x00000000,0x00000000}},	//   rkøl, --, --, --, 
   {{0x6ed41b90,0x2ee80175,0xbba8cc41,0xafd81924}},	//   _बिजु, ducf_, _कल्क, skøl, 
   {{0x741076a7,0xafd80fac,0x00000000,0x00000000}},	//   رویا, vhør, --, --, 
   {{0x1fc801d9,0xb92000b4,0x6aa40d27,0xe3b000c6}},	//   लरेड, _akpọ_, _lijf, _أرض_, 
   {{0x2da4013f,0x63a802d0,0xdb0400ae,0x200000ef}},	//   ɛteɛ_, _iggn, sciú, _vbii_, 
   {{0x6aa4000f,0xc0e400f7,0x3d081a22,0x160007f7}},	//   _nijf, _жокк, ाबले_, ल्पर_, 
   {{0x6280009a,0xafd820e4,0x5a380092,0x19d000d1}},	//   _ikno, rhør, _በማሻሻ, ﮕﻪﻧﻠ, 
   {{0xd9f03bca,0x78ac0099,0x7998045f,0x2000003a}},	//   _चाहत_, _rubv, _útwi, _ubii_, 
   {{0xfeb800b2,0xd9106aa5,0x50480150,0xafd80ec3}},	// [20a80] _بابت_, گیز_, _ءجىپ_, phør, 
   {{0xe8dc0016,0x6aa40cf9,0xab58068c,0x6aac0009}},	//   _chữa_, _cijf, _reüt, _ducf, 
   {{0xfbc4b33f,0x6280009a,0xd9101af5,0x00000000}},	//   _обно, _mkno, دیز_, --, 
   {{0xe3a4d719,0x313404ac,0xf748113e,0x7d240022}},	//   _لر_, ונעם_, يلاي_, _ефҭе, 
   {{0x3944005f,0x62800419,0xa3c03507,0x7c3400a2}},	//   ņos_, _okno, ्रन_, mjyr, 
   {{0xab5829ef,0x7c3400a2,0x00000000,0x00000000}},	//   _veüt, ljyr, --, --, 
   {{0x77f400ea,0x00000000,0x00000000,0x00000000}},	//   _оџац, --, --, --, 
   {{0x628001e4,0x6484009d,0xd3140395,0x7c34543d}},	//   _akno, мсыг_, емиъ, njyr, 
   {{0x25f8d44d,0xb6680022,0xc6080154,0xa2f000ec}},	//   ल्ही_, _диаз_, লাজা_, نڊوڪ, 
   {{0xd2509010,0x51f802bf,0x2460007f,0x04fc0154}},	//   اند_, чною_, _pèmè_, ংয়ের_, 
   {{0x6280009f,0xf074134b,0x00000000,0x00000000}},	//   _dkno, динә_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x628003a0,0xafd8005c,0x00000000,0x00000000}},	//   _fkno, lkøk, --, --, 
   {{0x6280037e,0xb7cc00d1,0xc0f00240,0x00000000}},	//   _gkno, _ﻗﯩﺰﻏ, ግሃም_, --, 
   {{0x1df80ce6,0x6ca4cffc,0xab5800a2,0xcc240124}},	//   ьеры_, драж, _neür, нчаҩ, 
   {{0xceb005d9,0x7c340200,0x00000000,0x00000000}},	//   _مڙس_, gjyr, --, --, 
   {{0xab580ba1,0xfe180c4c,0xfe6c57be,0x92b003d4}},	// [20a90] _reüs, _फोकस_, شگی_, টীৰ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa3c02ce6,0x6aa40cf9,0x87b80120,0x00000000}},	//   ्रम_, _vijf, пулт_, --, 
   {{0x6aa401a4,0x78a00030,0x883401d3,0xc79401ec}},	//   _wijf, ňovn, رکزئ, нрлы, 
   {{0xe708b6a9,0x7d001050,0xd7880137,0x00000000}},	//   تتان_, _ćosi, ونمو_, --, 
   {{0xb7840304,0x00000000,0x00000000,0x00000000}},	//   хәсе_, --, --, --, 
   {{0xd91400c7,0x4ab4000d,0xafd80162,0xf3f803d4}},	//   _идры, _अंडव, gkøk, ্যনৰ_, 
   {{0xe8c80490,0x628000b5,0xafd8005c,0x00000000}},	//   ाठीच, _skno, skøj, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x649400c7,0xd6e40064,0xd04806be,0x00000000}},	//   kãig, _бiтв, msdə, --, 
   {{0xb14001c0,0xd04806be,0x00000000,0x00000000}},	//   гнэл, lsdə, --, --, 
   {{0x4374074d,0xdde402b5,0x7694035b,0x00000000}},	//   _пулт, ārōr, tâyg, --, 
   {{0x443c0086,0xd9f00490,0xafd80162,0xdd040205}},	//   _iow_, _चालत_, rhøp, _ısım, 
   {{0x443c025f,0x6280b244,0x926400db,0xafd803b2}},	//   _how_, _ukno, _لدىم, shøp, 
   {{0x7c954664,0x443d4665,0x28ac3c20,0x4b5c0092}},	//   ерац, _kow_, _जूलि, _ለመጨረ, 
   {{0x443d4666,0x7e74009b,0x217004a9,0xe8dc004d}},	//   _jow_, _šapč, _пуқр, _chửa_, 
   {{0x3a249794,0xfe70b3cc,0x443c0363,0xba2424c9}},	// [20aa0] нмаг, _مدد_, _mow_, ндак, 
   {{0x443c0302,0x7c34168c,0xf990143e,0x69b800bc}},	//   _low_, sjyr, هبا_, शुली, 
   {{0xeabc00a3,0x443c5604,0xa964abb5,0xb7e400ee}},	//   _crùb_, _oow_, нифа_, ежек, 
   {{0x443c025f,0x3eb14667,0x1d840092,0xc76400d1}},	//   _now_, _kuyt_, _የቤቶች_, ھانى, 
   {{0x7bd46018,0x91fc00e2,0x78a002fb,0xa874009d}},	//   mayu, onāt, ňovo, хөрт_, 
   {{0x25f8534e,0xe60c3abe,0x443c01a4,0xad8400d1}},	//   ल्ली_, مشى_, _aow_, _تاۋۇ, 
   {{0xb8643ccf,0xa5d400f7,0x3eb10e94,0x443c1382}},	//   _كارو, ربور_, _luyt_, _bow_, 
   {{0x7bd54668,0xd0480213,0x443c123b,0xafd8005c}},	//   nayu, bsdə, _cow_, rkøk, 
   {{0x57cc0316,0xa3b400c6,0x3864735c,0xa34001c6}},	//   ारीह, راير_, mior_, гээл, 
   {{0x38654669,0x7bd5466a,0x443c08e7,0xa6804ea0}},	//   lior_, hayu, _eow_, _блуд, 
   {{0x7bd5466b,0xa3b00316,0x443c00ad,0x00000000}},	//   kayu, जुङ_, _fow_, --, 
   {{0xd250dc6f,0x443c1368,0xa3c00bae,0x3865466c}},	//   انگ_, _gow_, ्रण_, nior_, 
   {{0x4ab40c2e,0x7bd5466d,0xdd940220,0x00000000}},	//   _अंधव, dayu, ғаты, --, 
   {{0x3865466e,0x7bc00005,0x22e403e6,0x224801c7}},	//   hior_, ñoun, _ستهێ, ëckt_, 
   {{0x443c1bce,0xeabc026c,0x5ce5466f,0x00000000}},	//   _yow_, _stù_, люта, --, 
   {{0x7bd54670,0x3864026c,0xdc88084c,0x649400e4}},	//   gayu, jior_, есул_, rãig, 
   {{0x386416b8,0xeab000c6,0xf09c19f5,0x09b40154}},	// [20ab0] dior_, اعر_, mmà_, টরসা, 
   {{0xda794671,0x83fc00dd,0xf09d4672,0xe18c010b}},	//   нях_, lnőt, lmà_, lỳar_, 
   {{0x29054673,0x1a685194,0x8c880022,0x7bd54674}},	//   ïna_, ریفی_, _жәаа_, bayu, 
   {{0xdd9800ee,0x6d454675,0x387001ec,0x688400cf}},	//   _яшы_, myja, ақст, رجاق, 
   {{0x2ca80472,0xd8741819,0x443c7156,0x1030001f}},	//   _iicd_, دالب, _row_, _እየተዘ, 
   {{0x99d4179c,0x443d4676,0x59d48b29,0xf7414677}},	//   _متفا, _sow_, _مغفر, решо, 
   {{0x443d4678,0x69d400aa,0xc8a40588,0x199409a5}},	//   _pow_, maxe, _ауаҩ, _баря, 
   {{0x3864e03c,0x58840184,0x569401e0,0x00000000}},	//   cior_, _быуа, _ҡатт, --, 
   {{0x443d4679,0x228803b2,0xe18c00a2,0x814401e2}},	//   _vow_, løki_, dỳar_, ږندن, 
   {{0x69d4172e,0x7bd40451,0x443d467a,0xe604005b}},	//   naxe, zayu, _wow_, äpää, 
   {{0x3eb04c27,0xa3c00c6f,0xe4c89cc3,0x7bd5467b}},	//   _suyt_, ्रद_, _ربان_, yayu, 
   {{0x20040745,0xd56542e5,0x2ca80048,0x3f6825fc}},	//   ými_, _ступ, _nicd_, димо_, 
   {{0x7bd5467c,0x249d467d,0x69d5467e,0x63b8e34f}},	//   vayu, mmum_, kaxe, mcun, 
   {{0x63b9467f,0x2ca80421,0x249d4680,0x7bd54681}},	//   lcun, _aicd_, lmum_, wayu, 
   {{0x69d40067,0x6d454682,0x4094ad15,0x91fc0a2f}},	//   daxe, gyja, _ирит, rnāt, 
   {{0x63b94683,0xa3c01157,0xaa780022,0x38640393}},	//   ncun, ्रि_, _yvýg, xior_, 
   {{0x38654684,0x249c08a7,0x63b80113,0x05d003ce}},	// [20ac0] vior_, imum_, icun, हराब, 
   {{0x7bd54685,0x69d4f0ba,0xbea428f1,0xefd0001f}},	//   sayu, gaxe, _шапк, ያዘው_, 
   {{0x7bd54686,0x38641730,0xa3c01a47,0x249d4687}},	//   payu, tior_, ्रा_, kmum_, 
   {{0x0928b745,0xb9081810,0x7bd40986,0x38640393}},	//   عسلي_, _मि_, qayu, uior_, 
   {{0x69d52ab5,0x63b89b1f,0x00000000,0x00000000}},	//   baxe, dcun, --, --, 
   {{0x38654688,0xc5f40075,0xab5804cc,0x63b80381}},	//   sior_, лғу_, _sfüg, ecun, 
   {{0x38654689,0x2c040c58,0x63b8003a,0x2790104e}},	//   pior_, ৱাৰে_, fcun, лшәр, 
   {{0x63b9468a,0xe4e03156,0x764801e3,0x00000000}},	//   gcun, _गिरि_, skfy, --, 
   {{0x6d44068f,0xf67801d5,0xa2b000e5,0xa2600208}},	//   zyja, _قمرب_, لینڈ, _trồ, 
   {{0x91fc0029,0xd05c03be,0x63b804cc,0x249c0393}},	//   ciāl, əyəc, acun, amum_, 
   {{0x63b804cc,0x00000000,0x00000000,0x00000000}},	//   bcun, --, --, --, 
   {{0xdb0426c8,0x63b819f5,0x6d44f4d5,0x69d40005}},	//   nció, ccun, vyja, zaxe, 
   {{0x73345167,0xf09d468b,0xdb0409c2,0xdef89490}},	//   _جرائ, rmà_, ició, кыр_, 
   {{0x69d45693,0xf09c04cc,0x6d45468c,0x64940022}},	//   xaxe, smà_, tyja, rãie, 
   {{0xdb0400dd,0x69d5468d,0x7690013d,0x614000f3}},	//   kció, vaxe, _zıyä, _веја, 
   {{0x6d44035a,0x5c740c56,0x57cc197c,0x69d40472}},	//   ryja, алст, ारोह, waxe, 
   {{0x2de5468e,0x2c74003d,0x76900139,0x6d4402d0}},	// [20ad0] _июнг, għda_, _xıyä, syja, 
   {{0x68e01280,0x63b80007,0x91fc00b0,0xfd7801ec}},	//   ándo, zcun, kiām, _ﭼﯟﺍﻥ_, 
   {{0x69d5468f,0x63b80309,0xefd40023,0xdec00023}},	//   raxe, ycun, _ክሳድ_, _ዶብና_, 
   {{0x69d54690,0x63b80399,0x228806ea,0x9af400f7}},	//   saxe, xcun, røki_, اكەت, 
   {{0xa3c05612,0xf3f80183,0xa61029dc,0x649400e4}},	//   ्रस_, ্যাৰ_, издә, hãic, 
   {{0xdb0428f2,0x45194691,0x649400e4,0x9b640116}},	//   ació, еция_, kãic, _ئۆكۈ, 
   {{0x58d439b0,0x91fc0029,0xa8a43338,0x28a40ede}},	//   _вост, riāl, _арак, _ашаг, 
   {{0xdb054692,0xafd82d75,0x63b80393,0x00000000}},	//   cció, ljøf, ucun, --, 
   {{0x79980b21,0x249c0a86,0xda9802d3,0x76900139}},	//   _útwr, rmum_, _ፈሊጥና_, _qıyä, 
   {{0x63b94693,0xa3c072d0,0x249c16b8,0x00000000}},	//   scun, ्रह_, smum_, --, 
   {{0x332407c5,0x649400e4,0x00000000,0x00000000}},	//   _erox_, gãic, --, --, 
   {{0xcea81a4c,0xf99006a9,0x63b80369,0x94040691}},	//   _זי_, מרי_, qcun, _نومه, 
   {{0x16002122,0xe27401af,0x00000000,0x00000000}},	//   ल्वर_, _ишкә_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8cb4011c,0x00000000,0x00000000,0x00000000}},	//   истч, --, --, --, 
   {{0x09cc015b,0x3dc40116,0xdbc40022,0xde3c0092}},	//   _লাগা, _өйиг, рааҩ, _ያገኘው, 
   {{0x9f400268,0x78a000d0,0x00000000,0x00000000}},	// [20ae0] _odié_, ňovk, --, --, 
   {{0x57cc00dc,0x00000000,0x00000000,0x00000000}},	//   ार्ह, --, --, --, 
   {{0xd9106bde,0x18b40166,0x00000000,0x00000000}},	//   غیر_, рәгр, --, --, 
   {{0x60c00270,0xa9640114,0x00000000,0x00000000}},	//   _mtnm, ћица_, --, --, 
   {{0xdb040895,0xe0c54694,0x4c3400db,0x36680108}},	//   rció, _گز_, _тээт, надо_, 
   {{0xb4b00daf,0x00000000,0x00000000,0x00000000}},	//   бикә, --, --, --, 
   {{0xdb0499d5,0xe0c54695,0x81a800fe,0xaa400137}},	//   pció, _دز_, গুত_, _اچقى, 
   {{0x33254696,0x168403e6,0x80780055,0x00000000}},	//   _prox_, داڵێ, _ṣṭhā, --, 
   {{0x78a14697,0xafd81477,0xe70401d5,0x00000000}},	//   mmov, ljøg, _مسلی, --, 
   {{0x78a14698,0xb6a407d6,0xe6148540,0xdb04056a}},	//   lmov, _сизл, _йду_, nciñ, 
   {{0x78a001a4,0xaa34010f,0x00000000,0x00000000}},	//   omov, אטיק_, --, --, 
   {{0x78a14699,0xb4c0146b,0x995800d0,0x649400c7}},	//   nmov, ्ठी_, káža_, rãic, 
   {{0x78a00120,0x25f80562,0xa2e00354,0xa3c006b1}},	//   imov, ल्की_, _гочд, ्रर_, 
   {{0x98bc0316,0x78a047b1,0xdddc0311,0x00000000}},	//   ávě_, hmov, vorţ, --, 
   {{0x78a00fb7,0xeabc01c3,0xac7401e2,0x00000000}},	//   kmov, _crùn_, هارش, --, 
   {{0x78a0041a,0x09dc0c93,0xa0c00150,0x00000000}},	//   jmov, मण्य, _اييو, --, 
   {{0x24580241,0xcf900a81,0xe3bc1574,0x1dc430ab}},	// [20af0] _hàmù_, _گژھ_, ññi_, шөөн, 
   {{0x9f4003fa,0x00000000,0x00000000,0x00000000}},	//   _heiß_, --, --, --, 
   {{0x69b8033f,0xda780351,0xbaa40116,0x00000000}},	//   शुगी, уят_, рутқ, --, 
   {{0xdddd469a,0x81b4015b,0xafd80158,0xc90441d8}},	//   porţ, _ছড়া_, sjøf, _रहीम_, 
   {{0x7bd802e4,0xcb68d675,0x2b45469b,0xe3b401ec}},	//   _בקרו, _شمسه_, _сэнг, құл_, 
   {{0xafd8383d,0xb5c002bf,0x78a002f0,0x5a38010a}},	//   ljød, ойшл, amov, _йысă, 
   {{0x78a00381,0xa3c0547d,0x245801e1,0x00000000}},	//   bmov, ्रल_, _nàmù_, --, 
   {{0x98b4107d,0x78a001e4,0x04441422,0xc984022e}},	//   _šeću_, cmov, реин, _буғи, 
   {{0xdddc0306,0x00000000,0x00000000,0x00000000}},	//   horš, --, --, --, 
   {{0x2124b8ff,0xdddc5a54,0xafd803b2,0x64a001ec}},	//   _prnh_, korš, kkøs, шақа, 
   {{0xafd803d4,0xdddc1050,0x2590009f,0x00000000}},	//   lhøy, jorš, _اهاڳ, --, 
   {{0xff2407d6,0x8234a638,0x00000000,0x00000000}},	//   аммо, ارکا, --, --, 
   {{0xef143c85,0x99980219,0xafd803cd,0x00000000}},	//   амя_, _morš_, nhøy, --, 
   {{0x78a0019b,0x2288022c,0x8cb00034,0x4e18109a}},	//   zmov, tøku_, _आंखो, люся_, 
   {{0xdddc1b24,0x78a08e94,0xcdc401ec,0x00000000}},	//   gorš, ymov, сасқ, --, 
   {{0xec74030d,0xafd8143a,0x90e40472,0x00000000}},	//   апс_, gjød, _اسون, --, 
   {{0xeab5469c,0x22880174,0x28ac01f9,0x00000000}},	// [20b00] ийт_, søku_, _जंजि, --, 
   {{0x995800d0,0xdbb800fd,0xafd803cd,0xeabc0208}},	//   ráža_, _әтнә_, dhøy, _trùn_, 
   {{0x78a00e04,0xaa78012c,0xdb040077,0xb7c000d8}},	//   tmov, _svýc, rciñ, çãom, 
   {{0xafd800b5,0x78a0013a,0x00000000,0x00000000}},	//   lkør, umov, --, --, 
   {{0x2bd013b4,0x78a00232,0x75d400ec,0x00000000}},	//   तररा, rmov, ليشا, --, 
   {{0xd9f00ce0,0xafd801bf,0x39140244,0x00000000}},	//   _चाटत_, nkør, _پورز, --, 
   {{0xa3c00a28,0xafd82759,0xb4c028b8,0x999800ef}},	//   ्रं_, ljøe, ्ठे_, _forš_, 
   {{0x9418023a,0x68e1469d,0xb86403e6,0x9168004d}},	//   ужит_, ânde, _ئاسو, _lực_, 
   {{0xa2b00a8f,0xafd80217,0x9f40002f,0x245801e1}},	//   обыч, chøy, _reiß_, _sàmù_, 
   {{0x22880158,0x00000000,0x00000000,0x00000000}},	//   døks_, --, --, --, 
   {{0xafd800b5,0x00000000,0x00000000,0x00000000}},	//   dkør, --, --, --, 
   {{0xa3c00882,0xe19001c6,0xdd30013a,0xb38400f3}},	//   ्रः_, өлөө, _běžt, _клел, 
   {{0xe8dc0208,0x22880feb,0xdb200241,0x00000000}},	//   _thủa_, tøkt_, _òwèr, --, 
   {{0x9f400639,0x9168004d,0x64a001d3,0xee85469e}},	//   _weiß_, _cực_, _főis, рымо, 
   {{0x25f81715,0x22890d70,0xafd80158,0xc9040037}},	//   ल्टी_, røkt_, tjød, _रहेम_, 
   {{0x22882c95,0xafd8003b,0x4fd4292c,0x00000000}},	//   søkt_, yhøy, _ужит, --, 
   {{0xafd80158,0x91fc02b1,0x4a540107,0x9e840133}},	// [20b10] rjød, tiāh, бкас, _ژاپۆ, 
   {{0x89d86824,0xafd80fac,0x5a3400f5,0xc0f00092}},	//   اوار_, sjød, онут, _ቁጥሩ_, 
   {{0xc7b80241,0xb4c000cd,0xa3e4000d,0x00000000}},	//   _èéká, ्ठो_, _बयल_, --, 
   {{0xafd81477,0x4734247f,0xe8dc0051,0x00000000}},	//   ljøb, йнес, _nhụa_, --, 
   {{0x07082998,0x57e80220,0xdd2800e2,0x00000000}},	//   ايتي_, рдім_, mēša, --, 
   {{0x9a85469f,0xdd2800da,0xafd84606,0x4f3c001f}},	//   _дусл, lēša, rhøy, _ቢያደር, 
   {{0xafd803cd,0x7a880107,0x00000000,0x00000000}},	//   shøy, _сиёҳ_, --, --, 
   {{0xdd28005f,0x2c040183,0xafd8143a,0x9cd8011a}},	//   nēša, ৱাকৈ_, phøy, בוהה_, 
   {{0x9f444a4a,0x82343918,0x00000000,0x00000000}},	//   ümü_, مردا, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00840228,0x91680051,0xd69800c0,0x00000000}},	//   йлоо, _rực_, _лiто, --, 
   {{0xede401e0,0x7ae000ef,0x42746c68,0xc05802f2}},	//   ҡһыҙ_, šoti, ргүс, اشدا_, 
   {{0x645835ab,0xf58c044e,0xdd28005f,0xc2c40efc}},	//   mhui, _ምሕደራ_, dēša, _ايتي, 
   {{0xc0f00201,0x64580d47,0xc10400e3,0x7e988fde}},	//   _ቁጥር_, lhui, _هوتي, انسر_, 
   {{0xafd81924,0x91680208,0xdd2800de,0x00000000}},	//   rkør, _vực_, fēša, --, 
   {{0x645823e3,0xafd800b5,0x00000000,0x00000000}},	//   nhui, skør, --, --, 
   {{0x64580af9,0xa0c000ec,0x4bd801f4,0x00000000}},	// [20b20] ihui, _ايڊو, рься_, --, 
   {{0xe9d4255b,0x3f9146a0,0x6458000d,0x00000000}},	//   йку_, _iyyu_, hhui, --, 
   {{0x64580652,0xafd8168c,0x996c00ef,0xeaac00e5}},	//   khui, sjøe, _bēša_, رٹم_, 
   {{0xdd28005f,0x7d1ca16d,0x645801a4,0x00000000}},	//   cēša, _isps, jhui, --, 
   {{0x645946a1,0xafd801bf,0x20380092,0x00000000}},	//   dhui, ljøc, _እየተረ, --, 
   {{0x645946a2,0x89f402d5,0x7af402d1,0x09ac00eb}},	//   ehui, _мясц, muyt, গড়া, 
   {{0xe8703253,0x645946a3,0xd910023f,0x987c0419}},	//   _کۆنگ, fhui, _زیش_, líč_, 
   {{0xdd1c0122,0x649400e4,0x00000000,0x00000000}},	//   káže, sãin, --, --, 
   {{0x35f862ac,0xd1300092,0x8cb00073,0x6d580022}},	//   _مراد_, _ሥራቸው, _आंघो, ĝuai, 
   {{0xdd28005f,0x645802d0,0x00000000,0x00000000}},	//   zēša, ahui, --, --, 
   {{0x7af546a4,0x00000000,0x00000000,0x00000000}},	//   huyt, --, --, --, 
   {{0x645946a5,0x3200012c,0x7af40bf1,0xf0749735}},	//   chui, řky_, kuyt, симә_, 
   {{0x7d1c0175,0xdd28005f,0x37b800cc,0x81a800eb}},	//   _asps, vēša, _উজাৰ, গুল_, 
   {{0x5eb8015b,0xd0d42d1f,0x7d1c0200,0x7af40051}},	//   _অবশে, _докъ, _bsps, duyt, 
   {{0xdd28005f,0x200400db,0x71700137,0x9cc84137}},	//   tēša, òmic_, _رۇحا, йыта_, 
   {{0x60c4012c,0x67ec01e1,0xa174011a,0x00000000}},	//   íjme, _mòjà, _לעוד_, --, 
   {{0xdd2800da,0x7d1d46a6,0xeabc001e,0xf3f8015b}},	// [20b30] rēša, _esps, _trùm_, _আসার_, 
   {{0xdd2800e2,0x64580200,0x00000000,0x00000000}},	//   sēša, zhui, --, --, 
   {{0xefd4069c,0xdd2800e2,0x6458017a,0x1d080120}},	//   _ክሳዕ_, pēša, yhui, _леќи_, 
   {{0x19a820c8,0x9f0407d6,0xd9a802a9,0x987c00bc}},	//   ступ_, _بویو, съуд_, bíč_, 
   {{0x15940131,0x20380092,0x00000000,0x00000000}},	//   ﻜﯩﺘﯩ, _እየቀረ, --, --, 
   {{0x7d1c0334,0x645946a7,0xe7840454,0x00000000}},	//   _ysps, whui, _ғубо, --, 
   {{0xf5300cfc,0x845946a8,0xaa7800e4,0x17680116}},	//   дејќ, ирит_, _yvýn, ирәп_, 
   {{0x6458017a,0x68f403b9,0x00000000,0x00000000}},	//   uhui, muxd, --, --, 
   {{0x645946a9,0x12940023,0xe3b401ec,0xb68400e5}},	//   rhui, _ምእካብ_, _құп_, _ڈھول_, 
   {{0x645946aa,0xdd1c0122,0x00e4001b,0x00000000}},	//   shui, váže, ожон, --, 
   {{0x645827bb,0x00000000,0x00000000,0x00000000}},	//   phui, --, --, --, 
   {{0xd5480066,0xcdc801e4,0x00000000,0x00000000}},	//   _دلمو_, _יך_, --, --, 
   {{0x6f601e76,0xd49801b9,0xdb0400d8,0x5274158b}},	//   двяз, _урф_, nciô, _کانز, 
   {{0xdd1c0308,0xa3c09856,0x00000000,0x00000000}},	//   ráže, ्रक_, --, --, 
   {{0x7164010b,0xfca88863,0xc2c401c8,0x00000000}},	//   _машг_, لارو_, _ايڪي, --, 
   {{0x2244002d,0x2abc0142,0x2f8801f2,0x7e6c020c}},	//   _honk_, _bîb_, ụnọ_, sibp, 
   {{0xf4100bd4,0x3f900e14,0x224546ab,0xc0580014}},	// [20b40] ופן_, _uyyu_, _konk_, _مشکا_, 
   {{0x22441ee7,0x7af40113,0x27fd46ac,0x290c0356}},	//   _jonk_, ruyt, _acun_, ăgan_, 
   {{0x1dd00316,0xafd8383d,0x7af40309,0x22440e21}},	//   _त्यत, ljøa, suyt, _monk_, 
   {{0x68e0145e,0x224546ad,0x9f48001e,0x7af402d1}},	//   ânda, _lonk_, _điêu_, puyt, 
   {{0xfaa546ae,0x7af40784,0x66e00114,0x163414a3}},	//   _мамо, quyt, доча, зеля, 
   {{0xe60c581f,0xf4e946af,0x200004ba,0x29000200}},	//   نشى_, афий_, _lcii_, _fqja_, 
   {{0x26180316,0x0b30001f,0x00000000,0x00000000}},	//   _यसरी_, _ሠራተኛ, --, --, 
   {{0xe3ac00ec,0x00000000,0x00000000,0x00000000}},	//   ھري_, --, --, --, 
   {{0x91fc00e2,0x78a00306,0xe3ac76e1,0xbb380150}},	//   mnāz, ňovs, پري_, _ﺒﻠﻊ_, 
   {{0x200001ab,0x22440076,0xc0e80092,0xc0bc0092}},	//   _acii_, _conk_, _ሙሴም_, _ተከላ_, 
   {{0x224546b0,0xa9b8008f,0x21601468,0x91fc00ef}},	//   _donk_, יזיר, дтяг, diāt, 
   {{0xe0cc7254,0x17280135,0xdfd80395,0x00000000}},	//   کزی_, _རློམ_, жър_, --, 
   {{0x22440694,0xabd001ec,0xdb1001e1,0x00000000}},	//   _fonk_, _ﺘﺘﻨﺎ, _ìfèg, --, 
   {{0x7bc531e2,0x22440165,0x00000000,0x00000000}},	//   _afku, _gonk_, --, --, 
   {{0xec6946b1,0x80c009b4,0x00000000,0x00000000}},	//   арак_, _रूपे, --, --, 
   {{0x224546b2,0xa0681677,0x00000000,0x00000000}},	//   _zonk_, _маја_, --, --, 
   {{0xd5b80421,0xb60401f1,0x22442d2f,0x4a5428e5}},	// [20b50] _ogā_, _kráľ, _yonk_, пкас, 
   {{0xd5b946b3,0x224400e8,0x27fc0332,0x60e000a2}},	//   _ngā_, _xonk_, _scun_, _äwmä, 
   {{0x481546b4,0x2d84004a,0x37d00183,0x00000000}},	//   змес, _âne_, _হাজৰ, --, 
   {{0x765946b5,0x91fc0a28,0x68f401d9,0x20006a89}},	//   _alty, bhāg, ruxd, _xcii_, 
   {{0x9c64009f,0x91fc0055,0x00000000,0x00000000}},	//   _آهُو, chāg, --, --, 
   {{0x274002b5,0xd5b801e0,0x649400e4,0x00000000}},	//   _rūnā_, ҙсә_, rãim, --, 
   {{0xd5b81cd1,0x69c4025c,0x27400055,0x649400c7}},	//   әсә_, _ifje, _sūnā_, sãim, 
   {{0x68e02b76,0x7580970b,0x27fc00ac,0x765800a2}},	//   ándu, رینم, _ucun_, _elty, 
   {{0x320c0175,0x224546b6,0x6e3402d0,0x2c74031c}},	//   _bbfy_, _ponk_, _onxb, għdi_, 
   {{0x2000008f,0x5bb807d0,0xc2b801e2,0x00000000}},	//   _scii_, _अल्व, ټاکئ_, --, 
   {{0x22441a78,0x00000000,0x00000000,0x00000000}},	//   _vonk_, --, --, --, 
   {{0xe3b02885,0x224546b7,0x00000000,0x00000000}},	//   _قرش_, _wonk_, --, --, 
   {{0x2244b24f,0x91cc06ff,0x7498010f,0x76580108}},	//   _tonk_, _द्वै, _פינפ, _ylty, 
   {{0xf7cc0952,0x68e40301,0x74d00b7c,0x00000000}},	//   _ﺗﯩﻠﻪ, _ovjd, णीकृ, --, 
   {{0xed54e21a,0x16001d72,0x6da146b8,0xafd80158}},	//   пор_, ल्टर_, еира, sjøa, 
   {{0x91fc0a28,0x3cc80107,0x00000000,0x00000000}},	//   thāg, илҳо_, --, --, 
   {{0x51f402dd,0x6d400129,0xb9e800ee,0x91fc00cd}},	// [20b60] _ءسۇر, _ànan, ймаз_, bhād, 
   {{0x950c031c,0xb60402f0,0x91fc00cd,0x00000000}},	//   _གྱའི_, _kráž, chād, --, 
   {{0xd910b9ff,0xaef807c5,0x7bc00005,0x20e401a6}},	//   خیز_, nzùn, ñous, nđi_, 
   {{0xc86400c6,0x7178008f,0x7bc403e0,0x649400e4}},	//   وطني, זנעס, _ufku, sãij, 
   {{0x7c240649,0xafd84673,0x47a401ec,0xa9a000fd}},	//   _iakr, kjøn, мышұ, _җитд, 
   {{0x7c24020c,0x91fc00b0,0x00000000,0x00000000}},	//   _hakr, hiār, --, --, 
   {{0x7c2546b9,0x67280162,0x00000000,0x00000000}},	//   _kakr, avgj, --, --, 
   {{0xadc00241,0x7c2400ef,0x5334011c,0x00000000}},	//   _diẹd, _jakr, деит, --, 
   {{0x55c40046,0xa3c0276a,0x00000000,0x00000000}},	//   _жазғ, ्रज_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x935400b2,0xcfe000bd,0x69c0151c,0x00000000}},	//   _ڪراچ, _ভাবন, žneg, --, 
   {{0x7c2546ba,0xe3a468cf,0xb6040122,0x60c40f91}},	//   _nakr, _کشمی, _dráž, íjma, 
   {{0x61ec00ee,0xaa78012c,0xafd80158,0xb3540133}},	//   ýilý, _svým, bjøn, _ریدا_, 
   {{0x7c2405ac,0x55200cf1,0x65840200,0x00000000}},	//   _aakr, _मनाए_, _ëshë, --, 
   {{0x7c2546bb,0x4c94154e,0x622038eb,0xfc5c0092}},	//   _bakr, дивс, _سىيل, _ማከፋፈ, 
   {{0x7c2546bc,0x7998002d,0xdd946135,0x00000000}},	//   _cakr, _útwy, хасы, --, 
   {{0x7c2546bd,0xb60401f1,0xafd811c0,0x950c0327}},	// [20b70] _dakr, _zráž, ljøo, _གཱའི_, 
   {{0xd5a40a81,0x68e00311,0xaa7801ef,0x6b6c0153}},	//   _مہ_, ândo, _tvým, jėgū, 
   {{0xb3e00154,0x00000000,0x00000000,0x00000000}},	//   _যানজ, --, --, --, 
   {{0xc7b01d93,0x00000000,0x00000000,0x00000000}},	//   نّا_, --, --, --, 
   {{0x649400e4,0x00000000,0x00000000,0x00000000}},	//   sãik, --, --, --, 
   {{0x7c24239b,0x248c02d3,0xf1b801fb,0x69c405ac}},	//   _zakr, _ምቅላስ_, _ngơ_, _ufje, 
   {{0x7c2546be,0x7c38007b,0x0444665a,0xbb380150}},	//   _yakr, _úcrá, дейн, _ﺒﻠﻐ_, 
   {{0xb0e80135,0x42c8030d,0xdddc06be,0x00000000}},	//   _རྗེེ, огин_, kirş, --, 
   {{0xb60400bc,0xaa44001f,0xafd8143a,0xabd00150}},	//   _sráž, _በማስፋ, tjøn, _ﺘﺘﻤﺎ, 
   {{0xdddc010e,0xd20000db,0x680c0055,0x00000000}},	//   dirş, гүшк, _ṛdhi, --, 
   {{0xe4a42083,0x00000000,0x00000000,0x00000000}},	//   _ердо, --, --, --, 
   {{0x20e404a7,0xb6041155,0x4cb00150,0x00000000}},	//   rđi_, _vráž, _ﺳﺎﻻﻻ, --, 
   {{0x7c2546bf,0xafd80f0a,0x91fc00b0,0xeabc01e1}},	//   _rakr, mjøl, whāe, _nuù_, 
   {{0xafd81477,0xdb080098,0x64480143,0x00000000}},	//   ljøl, _éléh, _hogi, --, 
   {{0x644946c0,0x7c2546c1,0xb60402fb,0x68e000d2}},	//   _kogi, _pakr, _uráž, ândl, 
   {{0x644946c2,0x8c9401ec,0xc7a400e5,0x00000000}},	//   _jogi, еруі, _مڑ_, --, 
   {{0x7c2499b4,0xeb9546c3,0x3a2546c4,0x2bd010eb}},	// [20b80] _vakr, дит_, ммаг, तरजा, 
   {{0x7c2546c5,0xafd8003b,0x851c00bc,0x649400c7}},	//   _wakr, hjøl, पबाट_, sãih, 
   {{0x7c2546c6,0xafd878d9,0x644946c7,0x2c740003}},	//   _takr, kjøl, _oogi, eħdu_, 
   {{0x644946c8,0x00000000,0x00000000,0x00000000}},	//   _nogi, --, --, --, 
   {{0x7bd546c9,0xe78146ca,0x2c740003,0x00000000}},	//   mbyu, кушо, għdu_, --, 
   {{0x644801ab,0xb0600432,0x00000000,0x00000000}},	//   _aogi, mmäň, --, --, 
   {{0x644946cb,0x7af4005c,0x69200c82,0xafd852fd}},	//   _bogi, lryt, _имра, fjøl, 
   {{0x644946cc,0x88e002f5,0xafd8022c,0x7af40034}},	//   _cogi, মূহক, gjøl, oryt, 
   {{0x644808e7,0x6aa800d2,0x7bd400ca,0xb28402d5}},	//   _dogi, _úmfú, ibyu, дынк, 
   {{0x64480428,0x45700046,0xf6240212,0x00000000}},	//   _eogi, _өңір, _ідео, --, 
   {{0x644946cd,0x91fc0882,0xafd8a98d,0x00000000}},	//   _fogi, thāb, bjøl, --, 
   {{0xcfac045e,0x6448015d,0x27400064,0x00000000}},	//   _ক্ষন, _gogi, būną_, --, 
   {{0x9f4024ba,0xafd80fac,0x00000000,0x00000000}},	//   _ndiä_, sjøo, --, --, 
   {{0xb1900724,0x7af546ce,0x6448036e,0x6398011a}},	//   _иллә, dryt, _zogi, _וסדנ, 
   {{0x6449190d,0xdd9546cf,0xafd82188,0x71642dfc}},	//   _yogi, вары, ljøm, _تاشك, 
   {{0xaa780232,0x39380020,0x7af402d3,0x7bd40af9}},	//   _zvýh, _የሚያያ, fryt, gbyu, 
   {{0x7af4a5b6,0x1dd000dc,0xcfac00eb,0x00000000}},	// [20b90] gryt, _त्वत, _ক্রন, --, 
   {{0x99d546d0,0x00000000,0x00000000,0x00000000}},	//   نتما, --, --, --, 
   {{0x290546d1,0x7af40076,0x7bd416e2,0x8d9400f2}},	//   îna_, aryt, bbyu, _سلحش, 
   {{0x7af40efa,0xe7740014,0xae04012d,0x00000000}},	//   bryt, ولاں_, षभकन_, --, 
   {{0x4f74001f,0x00000000,0x00000000,0x00000000}},	//   _አንበሳ_, --, --, --, 
   {{0xf5e40131,0x00000000,0x00000000,0x00000000}},	//   ىتىۋ, --, --, --, 
   {{0x04b546d2,0x1a68006c,0xab58002f,0x84b40108}},	//   нсия, _تیلی_, _sfüh, нщиц, 
   {{0x032546d3,0x443946d4,0xa3fc0729,0xa9240024}},	//   един, ñs_, ্য্য_, _vežė, 
   {{0x200c01ed,0x644946d5,0x00000000,0x00000000}},	//   ődik_, _vogi, --, --, 
   {{0x60c401f1,0xafd805ac,0x4208009d,0x00000000}},	//   íjmo, mkøy, чноо_, --, 
   {{0x6448096b,0xafd8a934,0x7ec80150,0x00000000}},	//   _togi, lkøy, _ﺒﻨﻘﻁ, --, 
   {{0x200400ee,0x64480024,0xb6000135,0x7af40108}},	//   ümi_, _uogi, _ħġie, yryt, 
   {{0xafd800cc,0x6da000d1,0x00000000,0x00000000}},	//   nkøy, ғита, --, --, 
   {{0xd1c80201,0xf7d00046,0x20040003,0x00000000}},	//   _በመቶ_, _ﺟﯩﻠﺪ, żmi_, --, 
   {{0x40941e80,0x05900023,0xcdc401ec,0x7bd4022e}},	//   _прит, _ምዕቃብ_, тасқ, tbyu, 
   {{0x7af454d0,0xafd803cd,0x00000000,0x00000000}},	//   tryt, kkøy, --, --, 
   {{0x7bd40280,0xe1600451,0x3b846f34,0xc5e401e2}},	// [20ba0] rbyu, _سگھي, хлаг, _پړ_, 
   {{0x7af546d6,0xafd80158,0xaa780022,0xe3a400f7}},	//   rryt, dkøy, _yvýi, _ۅر_, 
   {{0xab5807c5,0x7af4007c,0xfb840166,0x00000000}},	//   _agüd, sryt, фыңн, --, 
   {{0x7af401bf,0x99c00154,0xbb44014b,0x00000000}},	//   pryt, ইরেক, _земк, --, 
   {{0xf7700a2c,0x3eb801c7,0x68f406be,0x81e400eb}},	//   داا_, _kipt_, arxd, _ফান_, 
   {{0xf5240798,0x00000000,0x00000000,0x00000000}},	//   ефин, --, --, --, 
   {{0xa9a04a4d,0xe9a146d7,0x6590265b,0x68f40175}},	//   _бирд, _барп, лашу, crxd, 
   {{0x2bd00316,0x2ba40037,0x3eb80419,0x27680101}},	//   धुपा, _खरमा, _lipt_, _کشفی_, 
   {{0xf204a163,0xd6c40aac,0xb5a800e8,0xd370007b}},	//   няно, _ризқ, g斡ra, شهد_, 
   {{0x3eb87668,0xc76402dd,0xe714009f,0x00000000}},	//   _nipt_, _شاقى, _سيمت_, --, 
   {{0xd5a40d01,0xab5800e4,0x651001d5,0x4fe80137}},	//   _ओरिज, _igüe, _مولئ, үмүн_, 
   {{0x20b40006,0x33840395,0xed5c0419,0x00000000}},	//   лёўс, _пулв, áľmi_, --, 
   {{0xe44494d2,0xafd82d75,0x64a0074d,0x00000000}},	//   _سلوى_, ljøk, _саца, --, 
   {{0x3eb8003e,0x00000000,0x00000000,0x00000000}},	//   _cipt_, --, --, --, 
   {{0x6ca40410,0x649400c7,0xeca41d39,0x00000000}},	//   ераж, rãiv, ејан, --, 
   {{0x321c489c,0x64940124,0x00000000,0x00000000}},	//   lety_, sãiv, --, --, 
   {{0x200c0cc1,0x6fe40154,0x6c300014,0x54e40046}},	// [20bb0] ədi_, _কাপড়_, نہگا, _ﺍﻹﺴﻼ, 
   {{0x321d46d8,0xafd808fb,0x00000000,0x00000000}},	//   nety_, kjøk, --, --, 
   {{0xaa780022,0x23c40241,0x00000000,0x00000000}},	//   _ovýv, _jíjó_, --, --, 
   {{0xab5946d9,0x321d46da,0x87b4031c,0x00000000}},	//   _agüe, hety_, _བུདྡ, --, 
   {{0x321c0232,0x58b800c6,0xf8b546db,0xded4001f}},	//   kety_, رامج_, төр_, ራፊክ_, 
   {{0xafd82d8b,0xf1b0043e,0x00000000,0x00000000}},	//   rkøy, ुखान, --, --, 
   {{0xd5e88073,0xafd82dba,0x23c40ca8,0x64940022}},	//   رعون_, skøy, _níjó_, kãit, 
   {{0xafd805ac,0x00000000,0x00000000,0x00000000}},	//   pkøy, --, --, --, 
   {{0xfd6001e1,0x321d46dc,0xe7840354,0x00000000}},	//   _buwọ, fety_, _чуво, --, 
   {{0xd3a40046,0x321c45be,0xcfe0009e,0x78a80030}},	//   ылық, gety_, _ভাষন, čovň, 
   {{0x3eb80334,0x9f6001e1,0x00000000,0x00000000}},	//   _ript_, _àsún_, --, --, 
   {{0x26dc0521,0x950c031c,0x00000000,0x00000000}},	//   _kwuo_, _གྱིི_, --, --, 
   {{0x442d46dd,0xf8b004ac,0xe81000a5,0x645946de}},	//   mde_, ישט_, ण्या_, mkui, 
   {{0x443c01f5,0x645946df,0x9e6c0092,0x321c0055}},	//   _hnw_, lkui, _አቅምና_, cety_, 
   {{0x443d46e0,0x61e146e1,0xaa7800e4,0x00c801d5}},	//   _knw_, _ienl, _yvýv, _ўлик_, 
   {{0x61e146e2,0x26dc016b,0x645946e3,0x51840114}},	//   _henl, _owuo_, nkui, _љуља, 
   {{0x61e146e4,0x60c0022f,0x3eb801a4,0x5ba41219}},	// [20bc0] _kenl, _hunm, _tipt_, улағ, 
   {{0x442d46e5,0x60c0008f,0x9c1400d1,0x37dc0154}},	//   hde_, _kunm, _өчмә, _ডাইর, 
   {{0x64582a7f,0x442d46e6,0x61e146e7,0x443c01f5}},	//   kkui, kde_, _menl, _onw_, 
   {{0x442d46e8,0x321c233e,0x61e00280,0xfa20009e}},	//   jde_, zety_, _lenl, নাইল_, 
   {{0x442d46e9,0xe1e43345,0x91fc0a28,0xf11c0fc8}},	//   dde_, _پس_, dhān, _बन्द_, 
   {{0x98e40014,0x64580af9,0x66000162,0x61e00200}},	//   _مغرۆ, ekui, ggnk, _nenl, 
   {{0x442c2253,0x321d46ea,0x60c146eb,0x06640214}},	//   fde_, vety_, _nunm, دانپ, 
   {{0x61e00036,0x6ab80077,0xafd80158,0x443c0129}},	//   _aenl, _éufr, rjøk, _cnw_, 
   {{0x61e146ec,0x321d46ed,0x26dc063f,0x37040f4d}},	//   _benl, tety_, _gwuo_, _шпаг, 
   {{0x386546ee,0x442d46ef,0x443c0cfd,0x61e146f0}},	//   lhor_, ade_, _enw_, _cenl, 
   {{0x442d46f1,0x60c005d5,0xafd80ac8,0x61e00bbc}},	//   bde_, _cunm, ljøi, _denl, 
   {{0x864403a5,0x386546f2,0x321c44f1,0x68e0ca3b}},	//   _аҟәа_, nhor_, sety_, ândi, 
   {{0x321c489c,0x61e146f3,0xc2f40451,0x6f8401d5}},	//   pety_, _fenl, _مينڊ, тунж, 
   {{0x61e146f4,0x60c146f5,0x6fd00a5a,0x443c01f5}},	//   _genl, _funm, _भ्रू, _znw_, 
   {{0x60c14544,0x386546f6,0xe8102e37,0x7af800cd}},	//   _gunm, khor_, ण्डा_, _ātta, 
   {{0xdd900075,0x00000000,0x00000000,0x00000000}},	//   تۈپ_, --, --, --, 
   {{0x386546f7,0x9be40220,0xeea81789,0x61e000a2}},	// [20bd0] dhor_, ріск, _оток_, _yenl, 
   {{0x442d46f8,0xf09d46f9,0x60c146fa,0x99980024}},	//   zde_, llà_, _yunm, _norų_, 
   {{0x442d46fb,0x98e40d3c,0xd7c800f1,0x64580022}},	//   yde_, لكلو, ږونه_, ykui, 
   {{0x3864014f,0xd8380139,0x00000000,0x00000000}},	//   ghor_, кэч_, --, --, 
   {{0x442c1fcd,0xf09c004e,0x20580677,0x00000000}},	//   vde_, ilà_, כיאל_, --, 
   {{0x442d46fc,0x91fc04fe,0xd6c400d1,0x7c200115}},	//   wde_, whān, шишқ, ĵore, 
   {{0x442c09a5,0x91fc0882,0x61e03e04,0x9f40004e}},	//   tde_, thān, _renl, _veié_, 
   {{0x61e146fd,0x27b0035f,0x386546fe,0x6458017a}},	//   _senl, _кәлс, chor_, ukui, 
   {{0x60c146ff,0x64594700,0x3e64004a,0x61e0a4fd}},	//   _sunm, rkui, _hôte_, _penl, 
   {{0x442cbae7,0x3e64006a,0x64594701,0x60c001e4}},	//   sde_, _kôte_, skui, _punm, 
   {{0x61e14702,0x442c0209,0xf09c05d5,0x60c0daaa}},	//   _venl, pde_, flà_, _qunm, 
   {{0x44e00953,0x8334913f,0x442c0369,0xf09c07c5}},	//   mų_, _مرتض, qde_, glà_, 
   {{0x44e002d5,0x249c08a7,0x61e14703,0x38bc013a}},	//   lų_, mlum_, _tenl, _můra_, 
   {{0x249d4704,0x3f9c4424,0xf09c354d,0x60c14705}},	//   llum_, ātu_, alà_, _tunm, 
   {{0x44e00953,0xf09c05d5,0x249c003a,0xeb940b01}},	//   nų_, blà_, olum_, қиф_, 
   {{0xf09ccd00,0x3864009a,0x249c0162,0x78a000d7}},	//   clà_, xhor_, nlum_, ňovz, 
   {{0x6f0c074d,0x69c00030,0x29040192,0xac9400db}},	// [20be0] ctcc, ľnen, ànan_, انقا_, 
   {{0xfeb85024,0x44e00953,0x9e740075,0x249d4706}},	//   _ثابت_, kų_, _ئۇست, hlum_, 
   {{0x44e00953,0x3e654707,0x38654708,0x8d4400fb}},	//   jų_, _côte_, thor_, _күрг_, 
   {{0x44e002d5,0x684001c0,0xab58002f,0x249c0327}},	//   dų_, йнха, _pfüt, jlum_, 
   {{0x249d4709,0x99980153,0x38640115,0x2ca40200}},	//   dlum_, _porų_, rhor_, _ënda_, 
   {{0x249c4264,0x3865470a,0x44e00153,0x1da8000d}},	//   elum_, shor_, fų_, _गरात, 
   {{0x3865470b,0x44e002d5,0xdef4001f,0x10dc02dd}},	//   phor_, gų_, _ውሣኔ_, _ﺃﺨﺫﻨ, 
   {{0x5455470c,0xafd92c8e,0x249d470d,0x8cb80e5b}},	//   рвит, ljøv, glum_, ्दयो, 
   {{0x3959470e,0x6840d808,0xb6a46128,0xaa7800e4}},	//   lyps_, _унта, _биал, _ivýr, 
   {{0x44e00006,0x249d470f,0x2ba407f7,0x91fc0055}},	//   bų_, alum_, _खरसा, chāl, 
   {{0x3de03fa7,0x74f001ec,0x85e002dd,0x64940124}},	//   _বাংল, _اۋبا, _بۋىن, rãir, 
   {{0xf09c19f5,0x249c0381,0x64a00354,0x649400c7}},	//   ulà_, clum_, _лаха, sãir, 
   {{0xf09c0c95,0xd9e406ab,0x6438008f,0xc33801d3}},	//   rlà_, गरात_, _רעדנ, őírá, 
   {{0x7c38013f,0x2c7c00fd,0x00000000,0x00000000}},	//   _ɔtre, kädä_, --, --, 
   {{0xf09cf5c6,0x00000000,0x00000000,0x00000000}},	//   plà_, --, --, --, 
   {{0x2d9c00b0,0xfa54036b,0x00000000,0x00000000}},	//   āue_, یرلگ, --, --, 
   {{0x998c0cf4,0x44e00153,0x00000000,0x00000000}},	// [20bf0] _ćoše_, zų_, --, --, 
   {{0x249d4710,0x06bc01ec,0x2c7c013d,0x00000000}},	//   zlum_, _ﺠﺎﻫﺩ, fädä_, --, 
   {{0x47d54711,0x39580165,0x497406ed,0xda080472}},	//   ليار, gyps_, јлес, ايمه_, 
   {{0x2c2410f5,0x44e002d5,0x4735063f,0x9dd403e6}},	//   _сьог, vų_, инес, _پزیش, 
   {{0x9c383da1,0x9b58665a,0xd7f801c6,0x769400e4}},	//   _спят_, _бият_, уух_, tâyp, 
   {{0x44e00953,0x249c0649,0xa2c002db,0x56940212}},	//   tų_, wlum_, रदस्, бачт, 
   {{0x58d4ac8a,0xafd81347,0x249d4712,0x2c7c0724}},	//   _гост, ljøu, tlum_, cädä_, 
   {{0x99840491,0x44e002d5,0x68e14713,0x249c003a}},	//   _الفو, rų_, ându, ulum_, 
   {{0x44e00006,0x249d4714,0x72c04990,0xd3980ce8}},	//   sų_, rlum_, обыз, ләшә_, 
   {{0xaa786b07,0x249d4715,0x42554716,0x44e00006}},	//   _zvýr, slum_, ртит, pų_, 
   {{0xd668511e,0x249c7295,0xaa780124,0x008418cd}},	//   _حملو_, plum_, _yvýr, илоо, 
   {{0x3de0045e,0xcea806a9,0x439400f3,0x00000000}},	//   _বাইল, _חי_, _каес, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3ebc06e6,0x00000000,0x00000000,0x00000000}},	//   ött_, --, --, --, 
   {{0xfce4c417,0x7c7400d8,0xdb200ca8,0x3a04072d}},	//   робо, аѓач, _òwúr, یکسی_, 
   {{0x2fdc08a7,0x00000000,0x00000000,0x00000000}},	//   ðugt_, --, --, --, 
  
   {{0x91fc00da,0x999800a2,0xaa7800a2,0xabd00150}},	// [20c00] bkād, _barş_, _swýa, _ﺘﺘﻌﺎ, 
   {{0xe9d46f00,0xf9d40108,0x00000000,0x00000000}},	//   ику_, рцаю, --, --, 
   {{0x151803d4,0x00000000,0x00000000,0x00000000}},	//   থিৱী_, --, --, --, 
   {{0x7d1c0194,0xafd80fac,0x7c940101,0x00000000}},	//   _ipps, sjøv, _خشخا, --, 
   {{0x28114717,0xbb2400d1,0x00000000,0x00000000}},	//   تونس, ﻠﻠﻪ_, --, --, 
   {{0xafd85c04,0xe6940a4a,0xa680009d,0x649c0055}},	//   ljøt, авіш_, олчд, _ṭipp, 
   {{0x2bd07e7c,0xd54800ec,0x91fc00cd,0x00000000}},	//   धुवा, العو_, bhāj, --, 
   {{0x2c6400c5,0x048802dd,0xe6140139,0x00000000}},	//   _tõde_, лшық_, гдә_, --, 
   {{0x78a14718,0x8ccc00af,0xe70400e5,0x00000000}},	//   mlov, _दूनो, _نسلی, --, 
   {{0x7d1cfbe0,0x6d4003b2,0xb6a4008e,0xab580205}},	//   _opps, _ánag, _тизл, _ogün, 
   {{0x78a14719,0xafd878d9,0x25080517,0xd5a440ec}},	//   olov, kjøt, _لرنی_, _الای, 
   {{0x78a0d114,0x3208033f,0x601c01bf,0x00000000}},	//   nlov, żby_, _råmæ, --, 
   {{0x7d1d471a,0x78a1471b,0x5f95471c,0x68e02959}},	//   _apps, ilov, жият, ándz, 
   {{0x78a1471d,0xa2c005f9,0xdb200241,0x00000000}},	//   hlov, रदर्, _òwùr, --, 
   {{0x78a1471e,0x921c033f,0x00000000,0x00000000}},	//   klov, _बॉयज_, --, --, 
   {{0x78a056c0,0xbad001ec,0xdd940166,0x00000000}},	//   jlov, _ﺘﺨﺒﺎ, цасы, --, 
   {{0x78a03d1a,0x69c05a54,0xce580064,0xdee4009b}},	// [20c10] dlov, žnem, _бапц_, _доњи, 
   {{0x7539471f,0x7c2000df,0x00000000,0x00000000}},	//   _ortz, ĵora, --, --, 
   {{0xec1418ce,0x78a00306,0x87f801c6,0x00000000}},	//   _кенә_, flov, гэлт_, --, 
   {{0x2b0401ad,0x9d1800cf,0x06f4007b,0x00000000}},	//   िंदु_, _тоют_, مستج, --, 
   {{0xafd83c12,0x75394720,0x2b4405f5,0x7d1c0010}},	//   ljøs, _artz, _тэнг, _zpps, 
   {{0x78a042bb,0xa50400d1,0x3cfc02f0,0x7b4401c8}},	//   alov, لىتە_, štve_, _ائٽل, 
   {{0x81e404c5,0x27f401d3,0x96080006,0x00000000}},	//   _ফাল_, _نہاد_, рэча_, --, 
   {{0x78a0cc62,0x0444039e,0x84290e16,0xe1680240}},	//   clov, сеин, ужив_, ትግባሩ_, 
   {{0x9f400004,0x753805f5,0xdbf4015b,0x2910005a}},	//   _meiã_, _ertz, ঙ্কস_, ltxa_, 
   {{0x67394721,0x00000000,0x00000000,0x00000000}},	//   _iruj, --, --, --, 
   {{0x29114722,0x2554012c,0x753801f5,0x3e6400d7}},	//   ntxa_, _dělá_, _grtz, _nôta_, 
   {{0x67380023,0x00000000,0x00000000,0x00000000}},	//   _kruj, --, --, --, 
   {{0x69c000d0,0x00000000,0x00000000,0x00000000}},	//   ľnej, --, --, --, 
   {{0x29100227,0x6738020c,0x78a14723,0xafd80158}},	//   ktxa_, _mruj, zlov, fjøs, 
   {{0x78a14724,0x5274f1ba,0x71d40677,0x00000000}},	//   ylov, _بانز, _פוקד_, --, 
   {{0x417416cb,0x3fe407fa,0x67394725,0xa3e400bc}},	//   _پاڪس, _ужив, _oruj, भरि_, 
   {{0x6e20000f,0xf090011a,0x59e80124,0xbf6401e2}},	// [20c20] _űnbe, _מנה_, илаҭ_, _ددغو, 
   {{0x3de003d4,0x00000000,0x00000000,0x00000000}},	//   _বাকল, --, --, --, 
   {{0x7d1d4726,0x67394727,0x91fc00b0,0xa3e41fd2}},	//   _upps, _aruj, whāk, भरा_, 
   {{0xafd828b3,0x78a0013a,0x00000000,0x00000000}},	//   ljør, ulov, --, --, 
   {{0x78a00b9d,0x7bc47bad,0x29100227,0x67380407}},	//   rlov, _igku, atxa_, _cruj, 
   {{0x78a0b832,0x67394728,0x9f40004e,0x13e000dc}},	//   slov, _druj, _meià_, नर्भ, 
   {{0x7bc4089c,0x7a3c00fd,0x5fc812eb,0xf41400cc}},	//   _kgku, _eçtä, रखाल, _দোষৰ_, 
   {{0xafd828b3,0x78a001b9,0xd664030d,0x00000000}},	//   hjør, qlov, lама, --, 
   {{0xe734e1a6,0x53341f5c,0x67394729,0xafd81700}},	//   _лет_, цепт, _gruj, kjør, 
   {{0x69c00724,0x7c38013f,0xf7cc1d00,0x50f42b2e}},	//   ñnex, _ɔtra, _ﺗﯩﻜﻪ, озот, 
   {{0xe6906d69,0x753801c6,0x7334014d,0x6a98010f}},	//   _علمد, _urtz, _گرائ, רשינ, 
   {{0x7bc4003e,0xd3440214,0x25a46ea9,0x00000000}},	//   _ngku, _وفای, _اگهي_, --, 
   {{0xdef83838,0xafd938fb,0x2aac03e0,0xdddc0055}},	//   йыр_, fjør, lübe_, cirū, 
   {{0xafd9472a,0x29100054,0x9f4000db,0x92a4033f}},	//   gjør, ytxa_, _deià_, ółdz, 
   {{0x7bc40801,0xf424003d,0x6d406e98,0x2aac00e5}},	//   _bgku, _རྒོད_, _šnab, nübe_, 
   {{0x9cc82d31,0x8bd9472b,0x00000000,0x00000000}},	//   сыра_, рмас_, --, --, 
   {{0xafd85792,0xd1380006,0x4a549100,0xab6000a2}},	// [20c30] bjør, lvą_, окас, _ozüň, 
   {{0x9f400004,0xe9a820d4,0xa9c4008e,0x1ed80d2f}},	//   _weiã_, هدان_, ссак, _ابيب_, 
   {{0x99d404a9,0x320c0109,0xddcc0986,0x6e24014f}},	//   ستلا, _mcfy_, _ñišq, mejb, 
   {{0x6e24c1b4,0x2911472c,0x6739472d,0x58b803e6}},	//   lejb, rtxa_, _pruj, مانج_, 
   {{0xf4240dd4,0x29100bc9,0x19580032,0xac940451}},	//   _རྒེད_, stxa_, _һары_, _ننڍا_, 
   {{0x673800f3,0x26c80798,0x6e240455,0x38ac00e4}},	//   _vruj, _écom_, nejb, výre_, 
   {{0x69c42a1e,0xc878013d,0x1958e738,0x00000000}},	//   _igje, _tmş_, _лары_, --, 
   {{0x6e24047e,0xe784010a,0x20cc0cba,0x38ac00c7}},	//   hejb, _лузо, _संबध, týre_, 
   {{0x27ece0c0,0x67380230,0x6e240306,0xf1d80073}},	//   magn_, _uruj, kejb, _म्हन, 
   {{0x27ed472e,0x995800d0,0xb38000ee,0x38ac00e4}},	//   lagn_, láša_, ьлыл, rýre_, 
   {{0xdddc0006,0x404810ae,0xded40023,0x38ac0022}},	//   sirū, апно_, ራዊን_, sýre_, 
   {{0xe45c00af,0x995801f1,0x38ac0124,0x8ca8012d}},	//   ööd_, náša_, pýre_, _झीलो, 
   {{0xa3a40150,0x69c000d0,0xafd8d142,0xd1380064}},	//   _احان, žneh, tjør, avą_, 
   {{0x2bbc543b,0x69c40023,0x644812fe,0x27ec07de}},	//   ्शना, _ngje, šnič, hagn_, 
   {{0xed55472f,0x2c6400c5,0xd9e8009e,0xafd80162}},	//   оор_, _sõda_, _পালম, rjør, 
   {{0x69c4044e,0xafd8022c,0x9f4000db,0x7c200115}},	//   _agje, sjør, _teià_, ĵoro, 
   {{0x3b8405f5,0x27ec07c5,0x90082309,0x20e401ed}},	// [20c40] цлаг, dagn_, _ازىق_, lői_, 
   {{0x60c4208d,0xafd84675,0x89f40006,0xaa440124}},	//   _hiim, ljøp, зяцц, опуа_, 
   {{0x60c54730,0xd91003e6,0x2fd0007c,0xed540064}},	//   _kiim, عیر_, _ängö_, _доэ_, 
   {{0x27ec05d5,0x60c40009,0x69c42fce,0x7e6c0175}},	//   gagn_, _jiim, _egje, lhbp, 
   {{0x41c8000b,0x60c46f52,0x7c3400ee,0x00000000}},	//   रशास, _miim, mdyr, --, 
   {{0x7c352880,0x60c433eb,0xd1380024,0x6d4c0356}},	//   ldyr, _liim, yvą_, ţiaţ, 
   {{0xf4240003,0xafd8119a,0xb06000fd,0x27ec07de}},	//   _རྒུད_, kjøp, çäkt, bagn_, 
   {{0x69c4069c,0x7c340510,0x60c54731,0xb4240214}},	//   _zgje, ndyr, _niim, زعبو, 
   {{0x1b0c0c58,0x28114732,0x00000000,0x00000000}},	//   _সৈতে_, _توقس, --, --, 
   {{0x60c40099,0xfbd800cd,0x7c3400a2,0x00000000}},	//   _aiim, युतम, hdyr, --, 
   {{0x60c54733,0x7c34010b,0x00000000,0x00000000}},	//   _biim, kdyr, --, --, 
   {{0x60c4300b,0xd1380153,0x00000000,0x00000000}},	//   _ciim, rvą_, --, --, 
   {{0x60c54734,0x628d4735,0x7c354736,0x6e2542ed}},	//   _diim, écoc, ddyr, tejb, 
   {{0x7c343deb,0x27ec030a,0x8f900055,0x00000000}},	//   edyr, zagn_, _āśāk, --, 
   {{0x60c538de,0xab6402d3,0x91fc0374,0xd108009f}},	//   _fiim, ተውዕል_, whāw, _اقعه_, 
   {{0x60c54737,0x9f400432,0x69c40200,0xea6000e5}},	//   _giim, _ediñ_, _sgje, ڈپری, 
   {{0x27ed4738,0x69c40789,0x00000000,0x00000000}},	// [20c50] vagn_, _pgje, --, --, 
   {{0x60c54739,0x00000000,0x00000000,0x00000000}},	//   _ziim, --, --, --, 
   {{0x91fc1161,0x27ed473a,0x00000000,0x00000000}},	//   bhāv, tagn_, --, --, 
   {{0xd87404d3,0x60c4a121,0xab6001ec,0x6fac0073}},	//   وانب, _xiim, _قۇزى, _घरां, 
   {{0x27ed473b,0x20e401d3,0x00000000,0x00000000}},	//   ragn_, zői_, --, --, 
   {{0x27ed1cad,0x69c4143a,0xb78400fd,0x00000000}},	//   sagn_, _ugje, чәсе_, --, 
   {{0xc7d801af,0xf53000d8,0x00000000,0x00000000}},	//   _гмбх_, еејќ, --, --, 
   {{0x20e401ed,0xd7f0007b,0x17f8007b,0xaaac00ce}},	//   vői_, _لكِ_, _ورقة_, _जीतक, 
   {{0xded40092,0x60c5473c,0x00000000,0x00000000}},	//   ራዊና_, _riim, --, --, 
   {{0x60c5473d,0x20e401ed,0xdddc0022,0x3e640051}},	//   _siim, tői_, pirũ, _rôto_, 
   {{0x60c4d62e,0x23780210,0x00000000,0x00000000}},	//   _piim, _żyję_, --, --, 
   {{0x60c5473e,0x43741d39,0x00000000,0x00000000}},	//   _qiim, _нулт, --, --, 
   {{0x60c42053,0x7c340b34,0x00000000,0x00000000}},	//   _viim, vdyr, --, --, 
   {{0xafd80158,0x91fc0aea,0xf774010f,0x3de00154}},	//   sjøp, lkān, לערי_, _বাঙল, 
   {{0x91fc0882,0x7c340209,0x7dd001a8,0xa24400f2}},	//   thāv, tdyr, _aðsó, _هیکل_, 
   {{0xa2c00a94,0x6da1473f,0x21700107,0x6cc05b66}},	//   रदक्, хиса, _нуқр, ейса, 
   {{0x7c3504e8,0x38ac00c7,0x00000000,0x00000000}},	// [20c60] rdyr, jýra_, --, --, 
   {{0x7c354740,0xee340276,0x38ac08a5,0x00000000}},	//   sdyr, _ень_, dýra_, --, 
   {{0xee34152d,0x7c340209,0x7e7c82be,0x7c280064}},	//   _энэ_, pdyr, _impp, _лонг_, 
   {{0xe60c0131,0x224400e2,0x00000000,0x00000000}},	//   ۇشى_, _lnnk_, --, --, 
   {{0x163480df,0xd7f800fb,0x67500345,0x00000000}},	//   деля, буҙ_, فخور, --, 
   {{0x98ac4a4a,0xa63002dd,0x98a4010b,0x00000000}},	//   ılır_, енші, чиҗе, --, 
   {{0x37e43304,0xa4d000d4,0x7af40064,0x00000000}},	//   _новг, нощі, lsyt, --, 
   {{0x7bd400ca,0xc9540006,0x52d87938,0x00000000}},	//   ncyu, _ўтры, омию_, --, 
   {{0x38640d73,0x7e7c0108,0xe44c007b,0x87f80024}},	//   mkor_, _ompp, اضى_, _фэст_, 
   {{0x38654741,0x7af400c0,0x658400e5,0x00000000}},	//   lkor_, isyt, árhá, --, 
   {{0x91fc0a28,0x05b40137,0xefc80023,0x00000000}},	//   dhāt, _ۉگۉت_, _ቡሉይ_, --, 
   {{0x38654742,0x7af402f6,0xdfd800a7,0xd3700133}},	//   nkor_, ksyt, зър_, _لێبک, 
   {{0x76594743,0x53340a83,0x84541e87,0x833000c7}},	//   _koty, _целт, _تىنچ, _аҽых, 
   {{0x6b6000d2,0x6444005f,0x91fc0882,0x386401b9}},	//   _lígú, ējie, ghāt, hkor_, 
   {{0x76584f59,0x38654744,0x32d00208,0xec6875e1}},	//   _moty, kkor_, _hây_, брак_, 
   {{0x76594745,0x69b0000d,0x7e7c01f4,0x00000000}},	//   _loty, _अरबी, _empp, --, 
   {{0x38654746,0x7af408fb,0x7658035a,0xab6000d1}},	// [20c70] dkor_, gsyt, _ooty, رۇسى, 
   {{0x32d00016,0x76594747,0x91fc55cd,0x38ac00e4}},	//   _mây_, _noty, chāt, výra_, 
   {{0x32d001fb,0x7af4062c,0x6dc00327,0x2d8400e4}},	//   _lây_, asyt, _qċaċ, _ãne_, 
   {{0x38654748,0x6e340369,0x7bd400b8,0x00000000}},	//   gkor_, _haxb, ccyu, --, 
   {{0x76594749,0x00000000,0x00000000,0x00000000}},	//   _boty, --, --, --, 
   {{0x7659474a,0x8d7c1ee0,0xdd1c0118,0xaa7802d2}},	//   _coty, _ኩንታል_, láše, _stýf, 
   {{0x7659474b,0x6e35474c,0x19946be2,0xaa780022}},	//   _doty, _maxb, _заря, _atýg, 
   {{0x386404f3,0x32d00016,0xdd1c012c,0x58840022}},	//   ckor_, _bây_, náše, _зыуа, 
   {{0x32d007ae,0x76580142,0x91fc1c52,0xec780051}},	//   _cây_, _foty, rkān, _đốc_, 
   {{0x76580588,0x32d00016,0x00000000,0x00000000}},	//   _goty, _dây_, --, --, 
   {{0x717802d3,0x4428056a,0x9f4c00ac,0xc0e40395}},	//   _ኣንፈት_, _ºa_, şdü_, ьонк, 
   {{0x76581bc6,0x91fc02b5,0x4429474d,0x91e40055}},	//   _zoty, whāt, _úa_, _īśeś, 
   {{0x32d007ae,0xd3d800c6,0x7e7c0066,0x765801e2}},	//   _gây_, _ربنا_, _pmpp, _yoty, 
   {{0x6e340007,0x3865474e,0x249d474f,0x00000000}},	//   _caxb, zkor_, loum_, --, 
   {{0x6da0055f,0x6e340007,0xada14750,0x386401d3}},	//   вира, _daxb, варл, ykor_, 
   {{0x91fc0882,0xbbe8aeda,0x38654751,0xae1c0883}},	//   bhās, ترسم_, xkor_, म्बन_, 
   {{0x32d007ae,0x6e3402fa,0x249c0086,0x20d14752}},	// [20c80] _xây_, _faxb, ioum_, _hãi_, 
   {{0x6b6000d2,0x7af54753,0x249d4754,0x7e7c127b}},	//   _sígú, rsyt, houm_, _umpp, 
   {{0x249d32e2,0x7af43b22,0x47200b82,0x7298010f}},	//   koum_, ssyt, _ሰልፈኛ, קסעס, 
   {{0x20d007ae,0x315400c8,0xdbcc0077,0x7658022e}},	//   _mãi_, ויען_, póño, _soty, 
   {{0x38654755,0x20d0001e,0x249d4756,0xc3240154}},	//   rkor_, _lãi_, doum_, বিডি_, 
   {{0x38654757,0x32d00208,0x00000000,0x00000000}},	//   skor_, _rây_, --, --, 
   {{0x65600368,0x3cf80010,0x7658062c,0x20d00208}},	//   gynh, _jvpv_, _voty, _nãi_, 
   {{0x68413c10,0x628c07ea,0x7658bc61,0xa92000d0}},	//   _инса, écon, _woty, _úľav, 
   {{0x7658a86f,0x91fc0a28,0x41c81b51,0xb05910d1}},	//   _toty, dhār, रशंस, lmäg, 
   {{0x20d0001e,0x32d001fb,0x95e801d3,0x15b40150}},	//   _bãi_, _vây_, _ربطہ_, _كەشس, 
   {{0x20d0001e,0x249c6ede,0x6e3401d5,0x059c07d2}},	//   _cãi_, boum_, _raxb, _ﭘﺎﺳﭙ, 
   {{0x32d007ae,0x20d0004d,0x6e340009,0xb058000d}},	//   _tây_, _dãi_, _saxb, imäg, 
   {{0x04080dd4,0xf09c0109,0x00000000,0x00000000}},	//   _ཁྐྲམ_, roà_, --, --, 
   {{0x64c0030c,0xb0582123,0x00000000,0x00000000}},	//   _كيەل, kmäg, --, --, 
   {{0x20d0004d,0x332401bf,0xb7a803d4,0x9b9401d9}},	//   _gãi_, _hpox_, _ওলোট, ۆلِت, 
   {{0x6e340a81,0xabb00116,0x38bc013a,0x91fc0055}},	//   _waxb, вабә, _kůru_, chār, 
   {{0xd5a41973,0x6e34010a,0x2bb8007b,0xdd1c0306}},	// [20c90] _چہ_, _taxb, زارة_, ráše, 
   {{0xd5a54758,0x249c0198,0x38bc01ef,0xa9280150}},	//   _نہ_, zoum_, _můru_, жіде_, 
   {{0xa0081968,0xcf240451,0x249ce815,0x00000000}},	//   _عقیل_, _آرڊي, youm_, --, 
   {{0x765c023a,0x00000000,0x00000000,0x00000000}},	//   öpyn, --, --, --, 
   {{0x249c007f,0x65600042,0x7bd8011a,0xe9d000ae}},	//   voum_, wynh, _מקרו, _لغز_, 
   {{0x8cb837cc,0xb05800fd,0x453400a7,0x290513b0}},	//   ्दको, lmäd, ехит, ànas_, 
   {{0x35a007d6,0x249d4759,0x00000000,0x00000000}},	//   лашг, toum_, --, --, 
   {{0x20d0001e,0x65600042,0x00000000,0x00000000}},	//   _rãi_, rynh, --, --, 
   {{0x249d475a,0x27fd475b,0x6d4000f3,0x20d00051}},	//   roum_, _idun_, _šnal, _sãi_, 
   {{0xc0e4fe22,0x20d00022,0x91fc02b1,0x249caf7a}},	//   ноок, _pãi_, whār, soum_, 
   {{0x0084623a,0x2c0c0243,0xd1b40014,0xc3240154}},	//   елно, िलां_, نیٖک, বিধি_, 
   {{0x90e44354,0x20d001fb,0x00000000,0x00000000}},	//   کسین, _vãi_, --, --, 
   {{0x442d475c,0xd3b40022,0xf8b0010f,0x212802e2}},	//   mee_, _исшь, טשט_, ňch_, 
   {{0x442d475d,0x8235475e,0xd2440124,0x20d000c7}},	//   lee_, _سرتا, _амшқ, _tãi_, 
   {{0x27fc110e,0x26147db3,0xfcb40c9e,0x442d475f}},	//   _odun_, _नानी_, ещаю, oee_, 
   {{0x26dc013f,0x27fc0241,0xb0580254,0x00000000}},	//   _otuo_, _ndun_, vmäg, --, 
   {{0xeb9403a5,0xdb1d17cf,0x64480a2e,0xab2493fb}},	// [20ca0] еит_, _özüm, _mngi, нота_, 
   {{0x442d4760,0x27fd4761,0xb0580ede,0x6aa400d1}},	//   hee_, _adun_, tmäg, ىشلە, 
   {{0x64494762,0xaa5401a9,0x27b00032,0x7050105d}},	//   _ongi, علما_, ғәтс, _شنیا, 
   {{0x442d4763,0x64494764,0xb0590b4e,0x7d0c1c06}},	//   jee_, _nngi, rmäg, mubs, 
   {{0x442d4765,0x7d0d4766,0x2ba4000d,0xdac401ee}},	//   dee_, lubs, _कुपा, _аҡай, 
   {{0x64494767,0x27fd4768,0xe45c02f6,0x20000263}},	//   _angi, _edun_, öön_, _ldii_, 
   {{0x442d4769,0x20000134,0x7d0d476a,0x999802b1}},	//   fee_, _odii_, nubs, _marū_, 
   {{0x442d476b,0x2000090c,0xe9a00354,0xafd806ea}},	//   gee_, _ndii_, _сасп, mdøg, 
   {{0x76080276,0xb058023a,0xafd80217,0xe3ac0451}},	//   _неаг_, nmäe, ldøg, ٽري_, 
   {{0x6449476c,0x20008ebb,0xda101f14,0x75d400c6}},	//   _engi, _adii_, ालित_, _أيضا, 
   {{0x442d476d,0x85340014,0xb0580036,0x2ba47ef5}},	//   bee_, _لولچ, hmäe, _कुना, 
   {{0x442c102c,0x78a004ba,0x84c0035b,0x7d0c0009}},	//   cee_, noov, _кәыд, dubs, 
   {{0xb8f031d9,0x68e000d2,0x26141414,0xda1006e3}},	//   _ེང_, ândz, _नामी_, ालात_, 
   {{0x20000810,0x78a000c5,0xb640037e,0x62300107}},	//   _edii_, hoov, _ｏａ_, _бешу, 
   {{0xdd95476e,0x6449476f,0xdf1801d3,0xec6800ee}},	//   гары, _yngi, وڑیں_, прак_, 
   {{0x7eb001bf,0x78a00254,0x6d4002d2,0x00000000}},	//   ræpa, joov, _ánam, --, 
   {{0xb05800fd,0x78a14770,0xfc500023,0x9f680064}},	// [20cb0] rmäd, doov, _ኣየጸግ, _зрэз_, 
   {{0x442d4771,0x6f0c00dc,0x27fc04cc,0xd5b800e2}},	//   zee_, mucc, _sdun_, _abām_, 
   {{0x6f0d4772,0x4c940124,0x00000000,0x00000000}},	//   lucc, _аинс, --, --, 
   {{0x442d4773,0xdddc02d5,0x7644013b,0x78a00472}},	//   xee_, mirš, _ɔkye, goov, 
   {{0x442d4774,0x6f0d4775,0xab854776,0x64480649}},	//   vee_, nucc, _чунк, _rngi, 
   {{0x442d4777,0x108c1df2,0x6f0c0268,0x78a00083}},	//   wee_, ﺗﺎﺭﯨ, iucc, aoov, 
   {{0x442d4778,0x78a001fa,0x628c06af,0x48c401e0}},	//   tee_, boov, écom, _ашағ, 
   {{0x044400e4,0xc324015b,0x91fc00b0,0x442d4779}},	//   теин, বিসি_, whāp, uee_, 
   {{0x2ba41715,0x442d477a,0x91fc0882,0x6f0c19f5}},	//   _कुमा, ree_, thāp, jucc, 
   {{0x442d477b,0x9325477c,0x2001477d,0xa4400133}},	//   see_, ارين, _sdii_, _ڕێبو, 
   {{0x442d477e,0x644803a2,0x2000003e,0x84140124}},	//   pee_, _tngi, _pdii_, _амех, 
   {{0x6449477f,0x2614081e,0x442d4780,0xb0580108}},	//   _ungi, _नाडी_, qee_, ymäe, 
   {{0x6f0c037e,0x93e401a9,0x00000000,0x00000000}},	//   gucc, _сўхл, --, --, 
   {{0x78a00472,0x00000000,0x00000000,0x00000000}},	//   zoov, --, --, --, 
   {{0xa28000aa,0x78a0009f,0xf3f403e6,0x0d982f23}},	//   _لیکو, yoov, _ستۆک, етты_, 
   {{0x6f0d4781,0x823400b2,0x2000009f,0xafd805ac}},	//   bucc, _سرڪا, _udii_, kjøy, 
   {{0x7d0d4782,0x6b614783,0x6f0c08e5,0xab614784}},	// [20cc0] subs, акта, cucc, автл, 
   {{0x63a80280,0x00000000,0x00000000,0x00000000}},	//   _mygn, --, --, --, 
   {{0x2ba4e079,0xe3a41ba4,0xb0588234,0x8d440116}},	//   _कुठा, _چر_, smäe, _йүрг_, 
   {{0xf91400c6,0xe3a50536,0x684000c7,0xafd80162}},	//   _нєαя, _نر_, инха, rdøg, 
   {{0x62800030,0x78a11d58,0xafd87dfa,0xb058002f}},	//   _omno, roov, sdøg, lmäc, 
   {{0xb7d000bd,0x78a000af,0x7c2001e4,0xf52401d5}},	//   ারেট, soov, ĵoru, вфин, 
   {{0xb0580086,0x91fc005f,0x6f0d3f62,0xafd805ac}},	//   nmäc, skāk, zucc, ldøe, 
   {{0xfaa4016c,0x62814785,0x00000000,0x00000000}},	//   _чаҳо, _amno, --, --, 
   {{0x63a94786,0xa7a51379,0x6280022f,0x87240b61}},	//   _cygn, _акта_, _bmno, _معلم, 
   {{0x63a8049f,0x6f0d4787,0xc5d400c0,0x00000000}},	//   _dygn, vucc, _біць, --, 
   {{0x26148919,0xfee002f5,0x7c240dfe,0x63a80174}},	//   _नाती_, _বিষধ, _obkr, _eygn, 
   {{0x6f0d4788,0x6280e970,0xdddc0006,0x64a14789}},	//   tucc, _emno, virš, _каха, 
   {{0xee84023a,0x00000000,0x00000000,0x00000000}},	//   выво, --, --, --, 
   {{0x6f0d478a,0x7c240086,0x00000000,0x00000000}},	//   rucc, _abkr, --, --, 
   {{0x6f0d478b,0x7c2401c4,0x63a80066,0xeca406ed}},	//   succ, _bbkr, _zygn, вјан, 
   {{0x62800010,0xd010007b,0x63a8010b,0x00000000}},	//   _zmno, _الة_, _yygn, --, 
   {{0xfe6d478c,0x9cc83d58,0x09bc33ff,0xaa78010b}},	// [20cd0] زگی_, тыра_, ्ख्य, _atýa, 
   {{0x2ba410f4,0xafd803cd,0xdddc0153,0x994800d7}},	//   _कुणा, sdød, pirš, _kóňa_, 
   {{0xef1c5775,0x272000d0,0x00000000,0x00000000}},	//   ltü_, _očný_, --, --, 
   {{0xd8b824e0,0xd5e80208,0xdb500014,0x00000000}},	//   ندنا_, _đón, حَے_, --, 
   {{0xef1c0259,0xb8f801b0,0x9b940276,0x00000000}},	//   ntü_, _डू_, _вияц, --, 
   {{0x63a8037e,0x00000000,0x00000000,0x00000000}},	//   _rygn, --, --, --, 
   {{0x63a9478d,0x1a690d6c,0xef1c0205,0x1fc028f0}},	//   _sygn, _جیلی_, htü_, _एण्ड, 
   {{0xef1c05d1,0x00000000,0x00000000,0x00000000}},	//   ktü_, --, --, --, 
   {{0x8234dc6f,0x42c903dd,0x5885478e,0x82a400c7}},	//   هردا, нгин_, _тыра, лаиж, 
   {{0x78a133a6,0x3cfc0427,0x00000000,0x00000000}},	//   čove, štvi_, --, --, 
   {{0xd6684fca,0x1a9c010f,0x63a80210,0x00000000}},	//   _جملو_, ויזע, _wygn, --, 
   {{0x3f9c05d1,0x82d802e8,0xef1c03e0,0x00000000}},	//   ştum_, _зддс_, ftü_, --, 
   {{0x443c0477,0xd04803b9,0x00000000,0x00000000}},	//   _iaw_, nqdə, --, --, 
   {{0x6281478f,0x1ee8158b,0xb1940131,0x0eb8010b}},	//   _umno, _یوبی_, _өлчә, вусы_, 
   {{0x443d4790,0x00000000,0x00000000,0x00000000}},	//   _kaw_, --, --, --, 
   {{0x2390044e,0x6458003b,0xb0580112,0x443d4791}},	//   _ዝስዕብ_, njui, rmäc, _jaw_, 
   {{0x4bd83f51,0x3a254792,0x443d4793,0xab580c86}},	// [20ce0] ться_, лмаг, _maw_, _sgür, 
   {{0x443c0c3e,0xfaa804fb,0x645801f4,0x00000000}},	//   _law_, رهاي_, hjui, --, 
   {{0xa9650924,0xae18008f,0xb058005b,0x00000000}},	//   лифа_, _אויכ, lmäa, --, 
   {{0x443d4794,0xfc3106d4,0xeb9c0158,0xb7d0015b}},	//   _naw_, _احد_, _sdøe_, ার্ট, 
   {{0x4b5400a7,0x00000000,0x00000000,0x00000000}},	//   _кърт, --, --, --, 
   {{0x443d4795,0x56941fbe,0x6d400064,0x00000000}},	//   _aaw_, јакт, _šnai, --, 
   {{0x443d4796,0x38ac0162,0xaa7800a2,0xb05801f4}},	//   _baw_, hýri_, _utýa, hmäa, 
   {{0xdd040953,0x443d4797,0x26c8011c,0x35b002dd}},	//   ūrėt, _caw_, _ècon_, _құйр, 
   {{0x443d4798,0x6300fa9a,0xf2c54799,0x9c88010e}},	//   _daw_, مويل, лсон, _goōš, 
   {{0x59b8e079,0x6458005b,0xa760013d,0x87b85b66}},	//   _अरार, ajui, _укуд, _руст_, 
   {{0x9f60025a,0x443d479a,0x1da431a0,0xe5a00c69}},	//   _âsên_, _faw_, _खुलत, _лифи, 
   {{0x443d479b,0xef1d479c,0x07a400c7,0x37d00154}},	//   _gaw_, ttü_, _саӡн, ারকর, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xef1c0724,0x630000f1,0xd2500efe,0x443c15c0}},	//   rtü_, _اوول, _ذنب_, _zaw_, 
   {{0xef1d479d,0x443d479e,0xac245b0f,0xab780092}},	//   stü_, _yaw_, лфак, ዲያድግ_, 
   {{0x443d479f,0x00000000,0x00000000,0x00000000}},	//   _xaw_, --, --, --, 
   {{0x99900552,0x16040073,0x99980118,0xb80800eb}},	// [20cf0] _čaša_, रणार_, _barů_, রভাত_, 
   {{0x2c6400c5,0xdb2401d3,0x6b700116,0x00000000}},	//   _rõdu_, ásán, алғу, --, 
   {{0x628c07ea,0x09ac0183,0x2ba400ab,0x2c640254}},	//   écoi, কেনা, _कँवा, _sõdu_, 
   {{0x26142d6c,0xaf980020,0x19a80228,0x645800b5}},	//   _नाही_, _ዋስትና_, утуп_, xjui, 
   {{0x07a42424,0x3e6405d5,0x443c0c18,0x00000000}},	//   јалн, _gôts_, _raw_, --, 
   {{0x443d47a0,0x645801f5,0x170800e5,0x00000000}},	//   _saw_, wjui, اہلی_, --, 
   {{0x443d47a1,0x6458023a,0x2bbc041c,0x00000000}},	//   _paw_, tjui, ्शका, --, 
   {{0x291018f7,0x443c0978,0x0708004b,0xb058005b}},	//   muxa_, _qaw_, _ليري_, ymäa, 
   {{0x645947a2,0x4375099b,0x443c01af,0x291007a9}},	//   rjui, руйт, _vaw_, luxa_, 
   {{0x443d47a3,0x161c06ab,0x3f9c0790,0x850400f2}},	//   _waw_, _नायर_, ştuk_, _نوطن, 
   {{0x443d47a4,0x291147a5,0x00000000,0x00000000}},	//   _taw_, nuxa_, --, --, 
   {{0x38ac022c,0x2004003c,0x3f680640,0x00000000}},	//   týri_, ûmi_, вимо_, --, 
   {{0xc1d0053f,0x42b4030d,0x200c236c,0x00000000}},	//   _мөнә, _кёку, ğdi_, --, 
   {{0x200d47a6,0x6738009f,0x29100472,0xfca80849}},	//   şdi_, _msuj, kuxa_, چارو_, 
   {{0xfca8aaa2,0xb05947a7,0xd14800ec,0x00000000}},	//   نارو_, mmän, _مشين_, --, 
   {{0xb05947a8,0x8fd41945,0x6738110c,0xac0401a9}},	//   lmän, _гәрә, _osuj, инса_, 
   {{0x67381418,0x290401ab,0xb8800118,0x764c1d1d}},	// [20d00] _nsuj, ánan_, říko, _óbyg, 
   {{0xab2547a9,0x291002c4,0xb058311d,0x0b58010b}},	//   рофа_, fuxa_, nmän, ырсы_, 
   {{0x6d400010,0x67380821,0xe1a800bc,0x9998013a}},	//   _šnav, _asuj, _घुमघ, _varů_, 
   {{0xb058005b,0x2ba41b51,0x00000000,0x00000000}},	//   hmän, _कुवा, --, --, 
   {{0xeb941b2e,0x91680208,0x1af00154,0xa7a40798}},	//   _вия_, _mức_, _চমকে_, акца_, 
   {{0x29100005,0xc5f401d5,0xca74009d,0x4a740150}},	//   buxa_, йғу_, _лусы, _лыст, 
   {{0x2614228d,0xb05947aa,0xa5040120,0x3854074d}},	//   _नारी_, dmän, аеја_, _къас, 
   {{0x1cb41f21,0xb0580108,0xa7600166,0x00000000}},	//   _ཞེས_, emän, скәд, --, 
   {{0xe734b32f,0xb0580e78,0xb77800dc,0xd250007b}},	//   _кет_, fmän, _doṣā, كنة_, 
   {{0x32640131,0xdd1c0030,0xb05800a2,0x00000000}},	//   ртив, _záťa, gmän, --, 
   {{0xf1500133,0x91680208,0x00000000,0x00000000}},	//   ڵێکد, _bức_, --, --, 
   {{0x6a780548,0x673800b5,0xb05800c5,0x00000000}},	//   _gîff, _ysuj, amän, --, 
   {{0x291018f7,0xc1a402dd,0xc4c4004b,0x733400ae}},	//   zuxa_, _қышқ, _اتلو, _خرائ, 
   {{0x29100054,0x2ba4012d,0x38ac0162,0x00000000}},	//   yuxa_, _कुषा, mýru_, --, 
   {{0x1df8c1a1,0x3e640165,0x307800c6,0x2910009a}},	//   ресы_, _pôtr_, _لحظة_, xuxa_, 
   {{0x5c74b576,0x00000000,0x00000000,0x00000000}},	//   олст, --, --, --, 
   {{0xa9e400c6,0x26140d0d,0xb0580108,0x00000000}},	// [20d10] لثان, _नाली_, lmäo, --, 
   {{0x29100227,0x6d4016a3,0xdbd8022a,0xd138033f}},	//   tuxa_, _šnau, rťák, ową_, 
   {{0x2ba4038e,0x47d400ec,0xdbd80c5e,0x00000000}},	//   _कुरा, ميار, sťák, --, 
   {{0x2910094a,0x00000000,0x00000000,0x00000000}},	//   ruxa_, --, --, --, 
   {{0x29100227,0xd83805f5,0xbc240150,0x6d440162}},	//   suxa_, рэх_, _ارپى, lvja, 
   {{0x78a003c6,0xbb3800c8,0x394801e4,0x29100077}},	//   čova, _געשי, _frbs_, puxa_, 
   {{0x2b4802ce,0x0744004b,0x19943da1,0x195947ab}},	//   _hrcc_, شنګټ, _даря, _кары_, 
   {{0xe784224f,0x673804ce,0x58840032,0xa3a80073}},	//   _кузо, _tsuj, _дыуа, _गडद_, 
   {{0x6738860b,0x00000000,0x00000000,0x00000000}},	//   _usuj, --, --, --, 
   {{0xb38147ac,0x9168004d,0x91fc0171,0x00000000}},	//   ялыл, _sức_, dkās, --, 
   {{0xb05947ad,0x6d44031c,0xb7780055,0x00c8005a}},	//   rmän, jvja, _toṣā, ллок_, 
   {{0xf9900302,0xb058712c,0x00000000,0x00000000}},	//   לרי_, smän, --, --, 
   {{0xb05802f6,0x2ba406ff,0x00000000,0x00000000}},	//   mmäl, _कुला, --, --, 
   {{0xfbf00cf9,0xb0585d8a,0xb5a8002e,0xaad809bb}},	//   _ak몰_, lmäl, _m斡ne, _बढ़क, 
   {{0xfce43f2a,0x01c40eac,0x628c004a,0x9168004d}},	//   собо, _শ্রদ, écou, _tức_, 
   {{0xb05947ae,0x91fc0882,0x0c7802dd,0x7f440477}},	//   nmäl, dhāy, асуы_, pvkq, 
   {{0x237c012d,0x7e74007b,0x200400d7,0x91fc0055}},	// [20d20] nzuj_, _هادئ, ómiu_, bjād, 
   {{0x7b1c0166,0xb05947af,0x81cc03d4,0x2f5800d9}},	//   _açuç, hmäl, ষুণ_, _עדינ, 
   {{0x9d780058,0x2b480198,0xab2407d6,0xbd444c11}},	//   _ئەزا_, _ercc_, _қора_, _انجي, 
   {{0x91fc00da,0x39480393,0x3ea80112,0x7188010f}},	//   nkār, _vrbs_, lobt_, נװײַ, 
   {{0x9f4006a3,0x366947b0,0xd138033f,0x39a01c3b}},	//   _keiñ_, ладо_, zwą_, _کیاہ, 
   {{0x7c340363,0xa3a800ab,0xa3c800ab,0x237c00d7}},	//   leyr, _गड़_, लधन_, dzuj_, 
   {{0x39481730,0x91fc1c52,0xbac801ec,0x2be4000d}},	//   _urbs_, kkār, _ﺑﻮﺳﺎ, _छ्ँू_, 
   {{0x7c3547b1,0xb1740016,0x61e0062c,0xb89400c6}},	//   neyr, _ngượ, _afnl, _الرع, 
   {{0x09ac02f5,0x91fc0171,0x00000000,0x00000000}},	//   _কৃপা, dkār, --, --, 
   {{0x0664034c,0x317c01c7,0xd138012d,0x7c3547b2}},	//   _والپ, tztz_, twą_, heyr, 
   {{0xd010314e,0x909806ed,0x6e240175,0x00000000}},	//   ولد_, ивот_, vfjb, --, 
   {{0x6d440003,0xd1380210,0x2be4000d,0x00000000}},	//   vvja, rwą_, _छ्ंू_, --, 
   {{0x5f9448c6,0x9f400649,0x7c340731,0xe4c46646}},	//   зият, _beiñ_, deyr, _اصلی, 
   {{0xfbbc29c7,0x6d440135,0xe294014b,0xb058010b}},	//   ्धनम, tvja, _лач_, mmäm, 
   {{0x7c340008,0xb05947b3,0xa1900024,0x00000000}},	//   feyr, lmäm, _нашч, --, 
   {{0x2b48070d,0xdd95476e,0x7c3400ad,0x91fc00ef}},	//   _prcc_, часы, geyr, ckār, 
   {{0x5eb800bd,0x290c0210,0xb058010b,0x00000000}},	// [20d30] _ইংরে, ągam_, nmäm, --, 
   {{0x91fc0882,0xc0bc001f,0xab180162,0x00000000}},	//   thāy, _ደረሰ_, _ótíð_, --, 
   {{0xb0583f47,0x9f400162,0x7c352d3d,0x78a03ebb}},	//   ymäl, _heið_, beyr, čovn, 
   {{0x9f40005a,0x7c340213,0xb4e40037,0x1ae800cc}},	//   _zeiñ_, ceyr, _बढ़े_, _পিৰা, 
   {{0x9c440323,0xbc1805d0,0x00000000,0x00000000}},	//   _эхэл, _דורש, --, --, 
   {{0xc0c802d3,0xfd6400b8,0x68e4022e,0x1b7c069d}},	//   _ቡዙሕ_, _atuṣ, _ttjd, _ጥርጣሬ_, 
   {{0x9f402242,0xf55400c6,0x00000000,0x00000000}},	//   _leið_, قلوب_, --, --, 
   {{0xd5b800de,0x00000000,0x00000000,0x00000000}},	//   _abās_, --, --, --, 
   {{0x61e00092,0xf48401ed,0xb05947b4,0x434402e8}},	//   _pfnl, تاوی, rmäl, цепв, 
   {{0x410472c5,0xb05947b5,0xe7840107,0x765c0108}},	//   озов, smäl, _куҷо, öpyt, 
   {{0x9f4003bd,0x91fc0a54,0xbba4012c,0x5eb800fe}},	//   _reiñ_, tkār, _खड्क, _ইংলে, 
   {{0x437547b6,0x9f4001a8,0x835400db,0xafe001f0}},	//   _мулт, _beið_, _وپاا, моюл, 
   {{0x99980552,0x91fc00e2,0x3ea802c1,0x7c340072}},	//   _marš_, rkār, tobt_, veyr, 
   {{0x91fc0aed,0xafd80158,0xc5f8010f,0x00000000}},	//   skār, ldøl, יפֿט, --, 
   {{0x7c34df7f,0x04200882,0x538c0023,0xc30400e5}},	//   teyr, _śaṅk, _ንስደት_, _آڈی, 
   {{0xafd80158,0x91b856e8,0xc6b80327,0x7c34062c}},	//   ndøl, _اطهر_, _བེའུ, ueyr, 
   {{0x7c3547b7,0xd91001d3,0x00000000,0x00000000}},	// [20d40] reyr, کیز_, --, --, 
   {{0x7c3547b8,0xcee801e2,0xef0c00f1,0x00000000}},	//   seyr, _ارين_, _ګټی_, --, 
   {{0x649400da,0x05a8375c,0x7c340129,0x7c2947b9}},	//   rģij, _चुलब, peyr, _конг_, 
   {{0xcfac0eac,0x6ef402e3,0x78a002fb,0x161c012d}},	//   _গণতন, ụbeg, čovo, _नाहर_, 
   {{0x6d400162,0xb60002d2,0xb6a428e5,0xdb240108}},	//   _ánar, _íákv, оидл, öräp, 
   {{0x6b600006,0xad8400d1,0xfd640055,0x00000000}},	//   _ўкра, _داۋۇ, _stuṣ, --, 
   {{0x1cd80d46,0x692147ba,0x385815e4,0xdddc01d3}},	//   _ོངས_, _омра, _краю_, nkrő, 
   {{0x168404d3,0xafd800cc,0x999800de,0x2aac0112}},	//   _کارێ, gdøl, _garš_, sübt_, 
   {{0xd5a411fc,0x533400a8,0x00000000,0x00000000}},	//   _کلای, чепт, --, --, 
   {{0x3f804d9a,0x9f400aab,0x00000000,0x00000000}},	//   dzku_, _reið_, --, --, 
   {{0x9f4003b2,0xaa7802f0,0x00000000,0x00000000}},	//   _seið_, _stýk, --, --, 
   {{0xb0586c0f,0x3b100240,0xe45c0821,0xb3900023}},	//   mmäk, kryq_, ööt_, ልላይን_, 
   {{0xb058e9b1,0x3244014b,0x00000000,0x00000000}},	//   lmäk, _медг, --, --, 
   {{0x290400dd,0xafd803b2,0x9f4002d2,0x1df80958}},	//   ának_, mdøm, _veið_, жеры_, 
   {{0xafd8022c,0xb058023a,0xe28401d5,0x3f800210}},	//   ldøm, nmäk, _بطنی, azku_, 
   {{0x1ae402f5,0x602406ea,0xe50c00a2,0x9f4002d2}},	//   গঠনে_, rímó, _düňň, _teið_, 
   {{0x26c40589,0x3f80033f,0xb058005b,0x78a00427}},	// [20d50] ymno_, czku_, hmäk, čovl, 
   {{0xf9f40729,0x68e01709,0x602403b2,0x7bd806be}},	//   _চাউল_, índo, pímó, _ştut, 
   {{0x05a803f3,0xafd806ea,0x00000000,0x00000000}},	//   _चुंब, ydøl, --, --, 
   {{0x1cb40327,0x68e00115,0xa3f800d7,0x38bc0118}},	//   _ཞེག_, ŭndo, _ťaží_, _kůry_, 
   {{0x4bc401c0,0xfc58011a,0x99980171,0x00000000}},	//   _хөвг, _הכרמ, _varš_, --, 
   {{0x26c40427,0x83c8012d,0x38bc01ef,0x00000000}},	//   umno_, ाइसआ, _můry_, --, 
   {{0x2d800034,0x00000000,0x00000000,0x00000000}},	//   nzje_, --, --, --, 
   {{0xd7f805f5,0xd8741075,0xcae00154,0xe630032e}},	//   _муу_, _قاقب, মীণফ, _árþú, 
   {{0xab5804cc,0xafd80217,0xb0584268,0x00000000}},	//   _agüz, gdøm, amäk, --, 
   {{0xaa7800ee,0xb0581cb2,0xafd82d8b,0x72c0004e}},	//   _duýg, lmäh, sdøl, нбыз, 
   {{0x850429aa,0x91fc00da,0xe45c00c5,0x31200de7}},	//   _روشن, rkāp, öös_, ндэг, 
   {{0x2d800b21,0xb0580e78,0x44280208,0x00000000}},	//   dzje_, nmäh, _ùa_, --, 
   {{0xc31803f4,0xaa786f88,0x2d800b21,0x43b80131}},	//   _তৈরি_, _guýg, ezje_, ﻧﯩﯖﺪ, 
   {{0x1cb40135,0xb0580086,0x437400d1,0xc10401c8}},	//   _ཞེང_, hmäh, _муһт, _فوتي, 
   {{0x3f804579,0x00000000,0x00000000,0x00000000}},	//   szku_, --, --, --, 
   {{0x787800c7,0x35880023,0x00000000,0x00000000}},	//   _oïva, _ንዕቀት_, --, --, 
   {{0x60c547bb,0x2d800a85,0x5a446518,0x3b84009d}},	// [20d60] _ihim, azje_, ммағ, члаг, 
   {{0xb0583b22,0xe50c00a2,0x00000000,0x00000000}},	//   ymäk, _tüňň, --, --, 
   {{0x60c547bc,0xe85004fb,0xfeb804fb,0xb8d45f6b}},	//   _khim, کنند, _پاکت_, ستاش, 
   {{0x60c401e4,0x960401ad,0x394400df,0x7eb003b2}},	//   _jhim, रण्ट_, ĉos_, ræpu, 
   {{0x60c547bd,0x09ac009e,0x26140037,0x00000000}},	//   _mhim, কেলা, _नाखी_, --, 
   {{0x60c40363,0x27b00075,0x45640014,0xb05833fe}},	//   _lhim, хәсс, ژھنہ, tmäk, 
   {{0x60c547be,0xe9a147bf,0xaa7800ee,0xf4880108}},	//   _ohim, _зарп, _duýd, йщик_, 
   {{0x60c547c0,0x2bc00b7d,0x3a3947c1,0xafd80158}},	//   _nhim, _शरमा, lepp_, tdøm, 
   {{0xb0583b22,0xfbbc08df,0x7608010a,0x23200166}},	//   smäk, ्धिम, _гезг_, нфэг, 
   {{0xb0580664,0x2d80000f,0xaa78010e,0xbd040055}},	//   mmäi, yzje_, _guýd, _kuũā, 
   {{0x24940502,0x60c547c2,0xb058005b,0xafd801bf}},	//   _کنند_, _bhim, lmäi, sdøm, 
   {{0x60c547c3,0xc1b801c0,0x3a3801c7,0xfbbc06ff}},	//   _chim, өлөх_, hepp_, ्धाम, 
   {{0x60c547c4,0xafd801bf,0xb0580108,0x3a383400}},	//   _dhim, ldøk, nmäi, kepp_, 
   {{0x60c404ce,0x00000000,0x00000000,0x00000000}},	//   _ehim, --, --, --, 
   {{0x60c4025c,0x3a3947c5,0xb0580036,0x78a00841}},	//   _fhim, depp_, hmäi, čovj, 
   {{0x60c547c6,0x2d800a85,0x4bc401c6,0x7bd8372c}},	//   _ghim, rzje_, дөгг, _ştur, 
   {{0x3f9c0365,0x3a38002e,0x2ba4000d,0x00000000}},	// [20d70] ştur_, fepp_, _कुखा, --, 
   {{0x60c40198,0x1ab4084c,0x321c0208,0x64940356}},	//   _zhim, ебуя, ngty_, mţie, 
   {{0x290547c7,0x5f740131,0x20d40356,0x9a840116}},	//   éna_, _ياۋر, _oţil_, хутл, 
   {{0x6a702fbe,0x28cc0131,0x9f0547c8,0x60c4036e}},	//   _sıfı, _ﺑﺎﺷﻠ, _تویو, _xhim, 
   {{0x64940276,0x60e001ec,0xb058002f,0x00000000}},	//   nţie, _ﺍﻟﺤﺸ, rmäh, --, 
   {{0xaa7800c7,0x6a7003b9,0xb0580108,0x00000000}},	//   _atýv, _qıfı, smäh, --, 
   {{0xafd800b5,0xf53000d8,0x00000000,0x00000000}},	//   rdøj, вејќ, --, --, 
   {{0xaa7800a2,0x00000000,0x00000000,0x00000000}},	//   _duýe, --, --, --, 
   {{0x27fc003e,0x60c40142,0x8388011c,0xb058008e}},	//   _ieun_, _rhim, юбив_, lmäw, 
   {{0x27fc003e,0x569401d5,0x00e401d5,0x00000000}},	//   _heun_, _заут, мжон, --, 
   {{0x60c547c9,0x27fc3386,0x93244fdc,0x415800d4}},	//   _phim, _keun_, ورین, ішою_, 
   {{0x660147ca,0x27fd47cb,0xf4b40214,0x3a38025c}},	//   lank, _jeun_, _قشنگ, zepp_, 
   {{0x442d47cc,0x27fc1bce,0x00000000,0x00000000}},	//   mfe_, _meun_, --, --, 
   {{0x660147cd,0x442d47ce,0x60c41590,0x27fc0489}},	//   nank, lfe_, _whim, _leun_, 
   {{0x60c547cf,0x008400f7,0x442c0548,0x64940311}},	//   _thim, _олко, ofe_, aţie, 
   {{0x224547d0,0x60c4556c,0x27fc03fa,0x6b9801a6}},	//   _hank_, _uhim, _neun_, _žuga, 
   {{0x660147d1,0x6494084c,0x442d47d2,0x26dc003a}},	// [20d80] kank, cţie, ife_, _nuuo_, 
   {{0x22440bc9,0x200147d3,0x41d00490,0x442c28e9}},	//   _jank_, _heii_, _सणास, hfe_, 
   {{0x660147d4,0x224470cd,0x27fca87b,0x20000093}},	//   dank, _mank_, _beun_, _keii_, 
   {{0x224547d5,0x3a3947d6,0x67000521,0x6600017a}},	//   _lank_, sepp_, _ọkar, eank, 
   {{0x660147d7,0x27fd47d8,0x442d47d9,0x20000036}},	//   fank, _deun_, dfe_, _meii_, 
   {{0x442d47da,0x660147db,0x27fc0dd4,0x200147dc}},	//   efe_, gank, _eeun_, _leii_, 
   {{0x442d47dd,0xb05947de,0xaee000dc,0x0b300092}},	//   ffe_, mmäv, _bhṛg, _አራተኛ, 
   {{0x27fd47df,0x442d47e0,0xb0581611,0x64a010fc}},	//   _geun_, gfe_, lmäv, каја, 
   {{0x22452ccb,0x7ae0007b,0x28100c75,0x76240395}},	//   _bank_, íoth, _جوقس, _омаз, 
   {{0x224400ca,0x442d47e1,0x660042b2,0x77600117}},	//   _cank_, afe_, cank, mxox, 
   {{0x224547e2,0x765947e3,0x20000036,0x27fd47e4}},	//   _dank_, _inty, _beii_, _yeun_, 
   {{0x386547e5,0x73c45706,0x7e7c005b,0x764801e3}},	//   njor_, _قيام, _alpp, ldfy, 
   {{0x53340598,0x20000036,0x2244fb0e,0x212401ab}},	//   _челт, _deii_, _fank_, _eqnh_, 
   {{0x224547e6,0x7e7c007f,0x64940356,0x6260009b}},	//   _gank_, _clpp, rţie, _авља, 
   {{0xf1a8bc3d,0xec680640,0x2ba44196,0xd5b8002b}},	//   _باشه_, орак_, _कुजा, _jyā_, 
   {{0x660006e4,0x22440086,0x64940311,0x386547e7}},	//   zank, _zank_, pţie, jjor_, 
   {{0x660147e8,0x224547e9,0x76580af9,0x27fc5e52}},	// [20d90] yank, _yank_, _onty, _reun_, 
   {{0x27fc0151,0x660147ea,0xadf1193c,0x2000054e}},	//   _seun_, xank, _अभिन_, _zeii_, 
   {{0x3e640109,0x442d47eb,0x27fc0098,0xf09c5bac}},	//   _nôty_, yfe_, _peun_, onà_, 
   {{0x765947ec,0x660147ed,0x38640023,0xe7d004f2}},	//   _anty, wank, gjor_, نماگ, 
   {{0x77601cdf,0x785c0276,0xd5b800b8,0xf09c04cc}},	//   gxox, _săvâ, _ayā_, inà_, 
   {{0x66000dd4,0x27fca0a5,0xf09c04cc,0x940406be}},	//   uank, _weun_, hnà_, mimə_, 
   {{0x27fd47ee,0xf09c05da,0x22440375,0x94040213}},	//   _teun_, knà_, _rank_, limə_, 
   {{0x66001813,0x224547ef,0x765947f0,0x3e6405da}},	//   sank, _sank_, _enty, _dôty_, 
   {{0x660147f1,0x442d47f2,0x76b40598,0x224400af}},	//   pank, rfe_, ьләр_, _pank_, 
   {{0x66007492,0x442d47f3,0xa800013d,0xb3800139}},	//   qank, sfe_, _ğıys, ульл, 
   {{0x442d47f4,0x22440489,0x6d48033b,0x672803cd}},	//   pfe_, _vank_, _ņgan, ltgj, 
   {{0x224402d1,0xf09d47f5,0xb0580e78,0x95c40451}},	//   _wank_, gnà_, hläf, _شينه, 
   {{0x249d47f6,0xada007d6,0x76589466,0x6da0039b}},	//   mnum_, ҳарл, _ynty, ҳира, 
   {{0x249c0008,0xf09c0268,0x20000036,0x78a00308}},	//   lnum_, anà_, _weii_, čovi, 
   {{0x6da07995,0x249d47f7,0x1cb40135,0xada00209}},	//   гира, onum_, _ཞེད_, гарл, 
   {{0x249c1c38,0xe97803ee,0xd09400c7,0x67289f65}},	//   nnum_, _şaşı, _ашьы, ktgj, 
   {{0x249d47f8,0xb09804ae,0xd1f80092,0xf4280166}},	// [20da0] inum_, _מיקר, ጋጆች_, lsäñ_, 
   {{0x67280a64,0x7e7c035a,0xef14008e,0x00000000}},	//   dtgj, _ulpp, _ямь_, --, 
   {{0x249c1873,0x38640137,0xf2e80086,0xb7780055}},	//   knum_, tjor_, _kiâò_, _kaṇā, 
   {{0xab580139,0x67280fac,0x940406be,0x3f78010f}},	//   _izün, ftgj, bimə_, ּאַס, 
   {{0xb0580724,0x249d47f9,0x7c24035a,0x672803b2}},	//   mmät, dnum_, _ickr, gtgj, 
   {{0x249c1730,0xfc4001ed,0xb058023a,0x776000b5}},	//   enum_, _جھڑپ, lmät, rxox, 
   {{0x764947fa,0x249c008c,0xafd800b5,0x290400e5}},	//   rdfy, fnum_, leøe, ánat_, 
   {{0x249d47fb,0x5454470c,0xb05833fe,0xd5b800b8}},	//   gnum_, твит, mläg, _vyā_, 
   {{0x1cb4003d,0xb058049f,0x6cc80150,0x00000000}},	//   _ཞེན_, lläg, _ﻓﻬﺯﻴ, --, 
   {{0x249c1730,0xb058005b,0xaa7800a2,0x7658002f}},	//   anum_, hmät, _kuýa, _unty, 
   {{0xb05947fc,0xf09c04cc,0x7c240857,0xca280150}},	//   nläg, tnà_, _ockr, _ﺤﻴﺯ_, 
   {{0x69c00034,0xf09c6c0e,0x249d47fd,0x33f4007b}},	//   żneg, unà_, cnum_, _أساس, 
   {{0xb05947fe,0x7eb0037e,0xf09d47ff,0x00000000}},	//   hläg, tæpp, rnà_, --, 
   {{0xb0594800,0x7c254801,0xe280009d,0x00000000}},	//   kläg, _ackr, _йлчи, --, 
   {{0xfe6c38b7,0x4c940212,0x61400114,0x00000000}},	//   تگي_, вивс, _беја, --, 
   {{0xdcb80c04,0xb0593c88,0xb77800cd,0x94040213}},	//   ещу_, dläg, _gaṇā, timə_, 
   {{0x6494084c,0x00000000,0x00000000,0x00000000}},	// [20db0] nţia, --, --, --, 
   {{0xaa780a2a,0x7c2402d0,0x940400ac,0xb0580112}},	//   _atýr, _eckr, rimə_, rmäu, 
   {{0xc95802ef,0xb05801e3,0x249c148b,0xaa78013a}},	//   بلاش_, gläg, ynum_, _stýs, 
   {{0xb0581b5d,0x6728022c,0xaa780432,0x87b80276}},	//   mmäs, ttgj, _duýa, мулт_, 
   {{0xb0594802,0x249c022c,0xe7c80210,0x00000000}},	//   lmäs, vnum_, ़ेंप, --, 
   {{0xe9d0b460,0x67280fac,0x290401e7,0xb058008e}},	//   _مغز_, rtgj, ánas_, lläd, 
   {{0x6728b545,0x249d4803,0xb0594804,0xaa78010e}},	//   stgj, tnum_, nmäs, _guýa, 
   {{0x20c403a2,0x58d4d221,0xb0594805,0x00000000}},	//   kñia_, _бост, nläd, --, 
   {{0x249d4806,0xb460035b,0xb058023a,0x4954001f}},	//   rnum_, ркыл, hmäs, _የሚቀጥ, 
   {{0xb0594800,0x249d4807,0x42540120,0x00000000}},	//   zmät, snum_, ттит, --, 
   {{0xb0594808,0x249c066a,0xf49400ec,0xb7780055}},	//   kläd, pnum_, _ڌانڌ, _paṇā, 
   {{0x339128dc,0x649400e2,0xe350136e,0xb058007c}},	//   الیز, rģis, _معتک, dmäs, 
   {{0xab5801ed,0xcdc402dd,0x00000000,0x00000000}},	//   _szün, ғатқ, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x29040311,0x91180022,0xb05833fe,0x4d143e28}},	//   ânal_, _зцыу_, gmäs, льтт, 
   {{0x7f840597,0xb0580267,0x64494809,0xdd0c012d}},	//   _للبن, gläd, _jagi, _półe, 
   {{0x6449480a,0xb058089d,0x3a25480b,0xba24010b}},	// [20dc0] _magi, rmät, кмаг, кдак, 
   {{0xaa7809cc,0xeb3041fa,0xb059480c,0x6a81480d}},	//   _stýr, شىمد, smät, алуа, 
   {{0xaa40081d,0xb058088f,0x644803ac,0xaa7801ef}},	//   рехл, mmär, _oagi, _ptýr, 
   {{0x6449480e,0xb059480f,0x7f5402d3,0xe8e80327}},	//   _nagi, rläg, _kryq, རྩེག, 
   {{0xb058338d,0x00000000,0x00000000,0x00000000}},	//   släg, --, --, --, 
   {{0x7bc40f72,0xb0594810,0x64494811,0xfaa400c0}},	//   _izku, pläg, _aagi, _раго, 
   {{0xc5d403f4,0xb8800077,0x7af40c4e,0x29040010}},	//   _স্বপ, üísm, lpyt, šnar_, 
   {{0x64494812,0xe9a002dd,0xb0580112,0xaa780419}},	//   _cagi, _тасп, hmär, _utýr, 
   {{0xb0594813,0xef1c01b8,0x5ea80154,0x00000000}},	//   kmär, gzül_, _গঠনে, --, 
   {{0x78a14814,0x64940276,0x64494815,0xb058e9b1}},	//   lnov, rţia, _eagi, ymäs, 
   {{0xb0594816,0x64940356,0x78a001ef,0xe5a000f3}},	//   yläd, mţin, onov, _кифи, 
   {{0x78a14817,0xa19001ce,0xb0594818,0x64940356}},	//   nnov, раюч, kläe, pţia, 
   {{0x78a14819,0xbe280023,0xb354085b,0x20c40139}},	//   inov, _ድምጽታ, _شیدا_, рсэг, 
   {{0x6449481a,0x649400a8,0xb059481b,0x78a1481c}},	//   _zagi, nţin, tmäs, hnov, 
   {{0x64488875,0xdd9527c9,0x7bc401c6,0xaa7800a2}},	//   _yagi, аары, _azku, _buýn, 
   {{0xb059481d,0xaa780124,0x64480429,0x00000000}},	//   rmäs, _atýp, _xagi, --, 
   {{0xb059481e,0x83fc00e5,0x00000000,0x00000000}},	// [20dd0] smäs, tkőz, --, --, 
   {{0x9b4400dd,0x75380356,0x78a03493,0xdb580454}},	//   ؤنلو, _optz, enov, ъюс_, 
   {{0x7bc401c0,0x83fc01ed,0x7af40124,0x9e04004e}},	//   _ezku, rkőz, apyt, _тчыл, 
   {{0x78a1481f,0x64854820,0x7d18007b,0xb05821c6}},	//   gnov, _iñig, átse, lläb, 
   {{0x64494821,0x38ac0118,0x48c401ec,0x69e40117}},	//   _ragi, nýry_, _ұшағ, _аюбз, 
   {{0x64494822,0x00000000,0x00000000,0x00000000}},	//   _sagi, --, --, --, 
   {{0x78a04be9,0xc87803e0,0xe66c08a5,0x98d800db}},	//   bnov, _aişe_, _þríþ, ربۅز_, 
   {{0x69c44d3c,0xfd5c02e3,0x64480548,0xafd80158}},	//   _izje, _anyị, _qagi, ndøs, 
   {{0x83642a9f,0x00000000,0x00000000,0x00000000}},	//   ادعل, --, --, --, 
   {{0x6448992e,0x6d5400ac,0xc8780205,0x00d800f2}},	//   _wagi, _orxa, _dişe_, کبخت_, 
   {{0xe4e410f5,0xab58066d,0x44f40801,0x69c40158}},	//   _різн, _szül, _спес, _jzje, 
   {{0xc8780276,0x64494823,0xb6000118,0x7e9c0150}},	//   _fişe_, _uagi, ťátk, _ﺍﻳﺘﺎ_, 
   {{0xed540364,0x6d554824,0xc87803e0,0xb05826bc}},	//   қот_, _arxa, _gişe_, tmär, 
   {{0x78a08e70,0x00000000,0x00000000,0x00000000}},	//   znov, --, --, --, 
   {{0x6494084c,0x78a14825,0x25e800af,0xb058e489}},	//   nţio, ynov, _चलनी_, rmär, 
   {{0xb058007d,0x78a01654,0xaa780051,0x00000000}},	//   smär, xnov, _quýn, --, 
   {{0x78a02753,0xb058049f,0x69c4025c,0x00000000}},	// [20de0] vnov, pmär, _azje, --, 
   {{0x78a00306,0xb058005b,0x6f0c0118,0x7af40153}},	//   wnov, lmäp, řicí, rpyt, 
   {{0x78a14826,0xdce8005f,0x67394827,0x7af400d7}},	//   tnov, ēlēt, _apuj, spyt, 
   {{0x7af54828,0x3da400c7,0x78a00099,0xab580139}},	//   ppyt, _арҭб, unov, _byüd, 
   {{0x7bc54829,0xbb740fc0,0x20c402d1,0xafd801bf}},	//   _uzku, _сунъ, yñin_, ldør, 
   {{0xb059482a,0x4a7450d5,0x69c124b2,0xc5f4144d}},	//   hmäp, _кыст, ünec, иғу_, 
   {{0xafd839c2,0x7ae402d1,0x3a2805be,0x64940276}},	//   ndør, _hukt, _icbp_, rţin, 
   {{0x6494084c,0x6280fb44,0x78a00122,0xfaa40107}},	//   sţin, _alno, čovs, _раҳо, 
   {{0x7ae40113,0xf204a818,0xb05802c1,0x00000000}},	//   _jukt, ляно, hläc, --, 
   {{0x7ae5482b,0x39480607,0x02c40075,0xafd803cd}},	//   _mukt, _ksbs_, ақчи_, kdør, 
   {{0x64940311,0xc5ec00aa,0xb4240014,0x067400ee}},	//   cţio, _غړو_, _مٹاو, _тутя, 
   {{0x6494084c,0xafd81600,0xc878054e,0xb62c0220}},	//   nţil, ddør, _tişe_, _ﺒﻪ_, 
   {{0x7ae5482c,0x8d0400b8,0x00000000,0x00000000}},	//   _nukt, bhṛṅ, --, --, 
   {{0xb059482d,0x8d040055,0xf4840345,0x00000000}},	//   fläc, chṛṅ, _جاڕی, --, 
   {{0x7ae5482e,0xdb20006a,0x6ca5482f,0x3948003b}},	//   _aukt, _âwês, граж, _nsbs_, 
   {{0x7ae45df1,0xb058000d,0x0bf4003b,0x00000000}},	//   _bukt, släb, рпаю, --, 
   {{0x4bc40323,0x8bd94830,0x3a28009b,0xafd826ff}},	// [20df0] рөнг, тмас_, _bcbp_, rdøs, 
   {{0x7ae54831,0xaa78010e,0x9b680137,0x6494054e}},	//   _dukt, _guýl, ышса_, eţil, 
   {{0x1af4009e,0x25e80037,0xe9a800db,0x00000000}},	//   েংগে_, _चलबी_, ردئن_, --, 
   {{0x7ae4910b,0xe84801ec,0x3948072b,0x9be40212}},	//   _fukt, عجان_, _dsbs_, _гірк, 
   {{0x22980248,0x6f0c02d0,0x00000000,0x00000000}},	//   _jákè_, nscc, --, --, 
   {{0x6e240007,0x64940356,0x7d000210,0x00000000}},	//   ngjb, aţil, _łosi, --, 
   {{0xb058023a,0x00000000,0x00000000,0x00000000}},	//   ymäp, --, --, --, 
   {{0x7ae40a28,0x6494054e,0x628000d7,0x00000000}},	//   _yukt, rţio, _slno, --, 
   {{0x03a41f0a,0x62800232,0x68e401fa,0x257801e1}},	//   рипо, _plno, _hujd, _bàlú_, 
   {{0x68e4044e,0x64940276,0xe6b000db,0xc0e00092}},	//   _kujd, pţio, _الئگ, _ሐረር_, 
   {{0x95e40014,0x64940276,0x628013d5,0x00000000}},	//   _آمى, lţim, _vlno, --, 
   {{0x229801e1,0x62814832,0x68e54833,0x4094014b}},	//   _bákè_, _wlno, _mujd, ррот, 
   {{0x62800270,0xe3b0c009,0xa068035b,0x49041546}},	//   _tlno, _ارض_, ваҟа_, हीतो_, 
   {{0x613801b8,0x68e4b433,0x628000df,0x290001f5}},	//   _cälö, _oujd, _ulno, _owja_, 
   {{0x7c954834,0x2b480b23,0x68e4047e,0x7ae54835}},	//   арац, _ascc_, _nujd, _sukt, 
   {{0xafd82ab7,0xaa78010b,0x7ae40139,0x70b0007b}},	//   rdør, _duým, _pukt, _وموض, 
   {{0x29000113,0x3948003b,0xafd80ac8,0xb0580267}},	// [20e00] _awja_, _ssbs_, sdør, släc, 
   {{0x1cd80dd4,0x68e4cf04,0x61e00ac5,0xef1c01ed}},	//   _ོངམ_, _bujd, _jgnl, zzük_, 
   {{0xaa780432,0xc0c80023,0xf8040798,0x00000000}},	//   _guým, _በሊሕ_, ачлн, --, 
   {{0x7ae54836,0x2b4807ab,0x313400c8,0x68e4016d}},	//   _tukt, _fscc_, ינעם_, _dujd, 
   {{0x7ae40cfe,0x6494084c,0x7c340217,0x36680120}},	//   _uukt, rţil, mfyr, кадо_, 
   {{0x667003cc,0x254401d3,0x7c35348b,0xa6c41180}},	//   قدىر, _ből_, lfyr, алча_, 
   {{0xa964b9ed,0x69d801e4,0x6494054e,0xe9a0014b}},	//   _кира_, _ĝueg, pţil, _дарп, 
   {{0x7c340579,0x6b983421,0xaee000b8,0xb74400db}},	//   nfyr, _žugi, _hiṅg, _پئرو, 
   {{0x69e00311,0xaee00055,0x00000000,0x00000000}},	//   şteş, _kiṅg, --, --, 
   {{0xab58066d,0x87b8059f,0xc79400fb,0xef1c00e5}},	//   _szük, _суст_, _урсы, szük_, 
   {{0x25e8547d,0x00000000,0x00000000,0x00000000}},	//   _चलती_, --, --, --, 
   {{0xaee00882,0xc87800a2,0x00000000,0x00000000}},	//   _liṅg, _kişa_, --, --, 
   {{0x7c3403cd,0x99980153,0x00000000,0x00000000}},	//   dfyr, _karų_, --, --, 
   {{0x61e00083,0xd25001d9,0xe2954837,0x6f0c00d8}},	//   _ggnl, _رنب_, _кач_, rscc, 
   {{0x98b8033b,0x6ce40046,0x6d440d27,0x7c340368}},	//   _aprč_, ріге, uwja, ffyr, 
   {{0x64840309,0xdc880276,0xaa78010e,0x00000000}},	//   _iñic, асул_, _guýj, --, 
   {{0xdb541669,0x4fc002dd,0x00000000,0x00000000}},	// [20e10] овты, _رەسە, --, --, 
   {{0x68e54838,0x2bd8206b,0x999800c0,0xf1b809ab}},	//   _pujd, _मृणा, _narų_, _उडान, 
   {{0x68e4014f,0x29640640,0xed30210e,0xe818000d}},	//   _qujd, шњав, _بوجھ, _पएदा_, 
   {{0x254401d3,0x00000000,0x00000000,0x00000000}},	//   _ről_, --, --, --, 
   {{0x984800a7,0x999800c0,0x00000000,0x00000000}},	//   ряха_, _barų_, --, --, 
   {{0x7bd80302,0x68e4014f,0xa3c407f7,0x00000000}},	//   _תקשו, _tujd, ोइस_, --, 
   {{0xf40003d4,0x2bd80846,0xef1c15b7,0x97a40304}},	//   োলনৰ_, _मृता, hrü_, йрәл, 
   {{0xc8780276,0x07081e2f,0xef1c0342,0xf1b8012d}},	//   _fişa_, _ميري_, krü_, _उड़न, 
   {{0x67b92242,0xb3d000e1,0x8eac009e,0x437400f5}},	//   _شارح_, देलख, _গঠনগ, суйт, 
   {{0x254401ed,0x5694222a,0x99980024,0x03a401b9}},	//   _től_, _даут, _garų_, _қило, 
   {{0x60e002dd,0x7c340042,0x00000000,0x00000000}},	//   _ﺍﻟﺒﺸ, yfyr, --, --, 
   {{0x3024004e,0xef1c2791,0x00000000,0x00000000}},	//   боюп_, frü_, --, --, 
   {{0x42d400d6,0x78b80a87,0xef1c0139,0x00000000}},	//   _ліку, _ítve, grü_, --, 
   {{0x41280902,0x00000000,0x00000000,0x00000000}},	//   _боко_, --, --, --, 
   {{0xb0580724,0x80f4eb7c,0xfca800ec,0xd14800ec}},	//   mlän, _استض, هارو_, _نشين_, 
   {{0xb0594839,0x6e3800f3,0xc00400d8,0xb9300092}},	//   llän, đuba, _упик, _አላማዎ, 
   {{0x7c35483a,0xed5401b9,0xaee000cd,0xef1c06be}},	// [20e20] rfyr, _ғоя_, _piṅg, crü_, 
   {{0x7c34148b,0xab25483b,0x00000000,0x00000000}},	//   sfyr, софа_, --, --, 
   {{0xb058687f,0xfeb85285,0x00000000,0x00000000}},	//   ilän, _لاگت_, --, --, 
   {{0xb059483c,0x00000000,0x00000000,0x00000000}},	//   hlän, --, --, --, 
   {{0xb0580598,0x68f86b48,0xc87806be,0x68408e21}},	//   klän, _čude, _qişa_, янца, 
   {{0xe60c0c50,0xc7641473,0x00000000,0x00000000}},	//   ىشى_, تامى, --, --, 
   {{0xb058049f,0xe60c2756,0x00000000,0x00000000}},	//   dlän, رشو_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc445483d,0x77840640,0x88800014,0x5a60001f}},	//   زیون_, _улаз, _زیون, _ለማስቻ, 
   {{0xb059483e,0x60f40724,0xef1c00ac,0x16840133}},	//   glän, өнья_, vrü_, _بارێ, 
   {{0xd5a5483f,0xaab8008f,0x00000000,0x00000000}},	//   _بلای, רזיכ, --, --, 
   {{0x85e00046,0x628c067c,0x00000000,0x00000000}},	//   _تۋىن, ècor, --, --, 
   {{0xb058007c,0x00000000,0x00000000,0x00000000}},	//   blän, --, --, --, 
   {{0xef1c07c5,0x00000000,0x00000000,0x00000000}},	//   rrü_, --, --, --, 
   {{0x64844f6b,0x00000000,0x00000000,0x00000000}},	//   _uñic, --, --, --, 
   {{0xa0a40cfc,0xd0100dd2,0xef1c05d1,0x00000000}},	//   _најд, _کلک_, prü_, --, 
   {{0xf09d4840,0xb0580108,0x00000000,0x00000000}},	// [20e30] mià_, lläo, --, --, 
   {{0xf09d4841,0x69d801e4,0x7d240162,0x00000000}},	//   lià_, _ĝueb, ðusø, --, 
   {{0xa90403c7,0x00000000,0x00000000,0x00000000}},	//   صبان, --, --, --, 
   {{0x50c80303,0xfca8021a,0xb05800fd,0xf09d4842}},	//   रतिष, _ناټو_, zlän, nià_, 
   {{0xb05800fd,0xd83805f5,0x442800a2,0x1a68072d}},	//   ylän, сэх_, _ĸa_, _گیلی_, 
   {{0xf09c86ed,0xb058007c,0x3af8010f,0xf5e400d1}},	//   hià_, xlän, _כּלע, يتىۋ, 
   {{0x1a681547,0xefb80023,0xdb2401f4,0x00000000}},	//   _دیلی_, _ሰሚዔ_, öröp, --, 
   {{0x83380261,0xf09c0ffb,0x317c01f7,0x00000000}},	//   ачот_, jià_, dytz_, --, 
   {{0xf09d4843,0xb0580724,0x64940276,0x58d47264}},	//   dià_, tlän, nţii, _хотт, 
   {{0xe8e4031c,0x92e800ae,0x00000000,0x00000000}},	//   _སྤོག, حريق_, --, --, 
   {{0xb0594844,0x31200323,0xf09c00db,0x65a807d5}},	//   rlän, мдэг, fià_, _стаг_, 
   {{0xf09cdb60,0x00000000,0x00000000,0x00000000}},	//   già_, --, --, --, 
   {{0xb0594845,0x443c0083,0x2ca40022,0xafd8005c}},	//   plän, _ibw_, _êndy_, leøj, 
   {{0x249c0de4,0xb7d80375,0xb0594846,0x00000000}},	//   lium_, יקרי, lläl, --, 
   {{0xf09c521d,0x987c0419,0x69c0000d,0x00000000}},	//   bià_, víľ_, ünel, --, 
   {{0x249c0de4,0xf09d4847,0xd1740022,0x00000000}},	//   nium_, cià_, _хышы, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [20e40] --, --, --, --, 
   {{0x249c0393,0x443c2ae9,0x00000000,0x00000000}},	//   hium_, _lbw_, --, --, 
   {{0x443c2f99,0x249d4848,0x6494054e,0xefb80023}},	//   _obw_, kium_, aţii, _ሰሚዐ_, 
   {{0xab58013d,0xd7f0007b,0xda0801d5,0x00000000}},	//   _iyün, ركت_, شيچه_, --, 
   {{0x64940276,0x249c26c2,0xf09008a8,0x00000000}},	//   cţii, dium_, ונא_, --, 
   {{0xf09d4849,0xb058023a,0x443d484a,0x4ac401f9}},	//   zià_, yläo, _abw_, वतःव, 
   {{0x29040311,0x249c0393,0x8a1000d1,0xa2ac00cd}},	//   ânat_, fium_, _سېنت, ुवन्, 
   {{0x249c0483,0x443d484b,0x68400276,0xefb80023}},	//   gium_, _cbw_, _онса, _ሰሚዑ_, 
   {{0xb6a5484c,0xe3ac00dd,0x68400953,0x443c01f5}},	//   _диал, ہری_, _інфа, _dbw_, 
   {{0xa5f4026a,0xdeb403f9,0x443c017a,0xd250388d}},	//   _међу_, ƙaƙa, _ebw_, رنج_, 
   {{0x249c1730,0xe3ac2263,0x64852deb,0xf09c354d}},	//   bium_, فری_, _iñin, tià_, 
   {{0x249c0de4,0x443c0998,0xb4e4b658,0x3208012d}},	//   cium_, _gbw_, पदी_, źby_, 
   {{0xf09d484d,0x925801c0,0x5f9450ce,0x999801ef}},	//   rià_, _галт_, дият, _obrů_, 
   {{0x62602083,0xf09d484e,0xb05800a2,0x00000000}},	//   _овча, sià_, mläm, --, 
   {{0xb059484f,0xeff002d3,0xf09c08e5,0x00000000}},	//   lläm, ሃራይ_, pià_, --, 
   {{0x51841b74,0x6fd04da4,0xafd8143a,0x443c01bf}},	//   _муқа, _सरपं, neøk, _xbw_, 
   {{0x9f040228,0xb058005b,0x7c20002e,0x25e80037}},	// [20e50] _قويو, nläm, óora, _चलली_, 
   {{0x249d4850,0xa9c458a8,0x64940356,0x7c8400c7}},	//   zium_, осек, rţii, оуӡе, 
   {{0x5f7404fb,0xb0594851,0x2904180f,0xafd80fac}},	//   _فایر, yläl, èna_, keøk, 
   {{0xf780040d,0x249c16b8,0xb0594852,0x6494054e}},	//   ﯩﻠﯩﻚ_, xium_, kläm, pţii, 
   {{0x249c0483,0xae1c22e3,0xd87400cf,0x1798005b}},	//   vium_, _बयान_, بالب, овцы_, 
   {{0x443c0607,0x7bd80302,0xab380092,0x595400f1}},	//   _sbw_, _לקרו, _ሥርዓቱ, _ښکنځ, 
   {{0x249c0de4,0xb058023a,0x64b00356,0x286800f3}},	//   tium_, eläm, hăie, _крао_, 
   {{0x249c0381,0x443c0051,0x58d4026b,0x073400c0}},	//   uium_, _qbw_, _жост, _небю, 
   {{0x249d4853,0x49700092,0xb0580139,0x00000000}},	//   rium_, _ለሚቀጥ, gläm, --, 
   {{0xc87854ee,0xa5642f15,0x6484002e,0xca280150}},	//   _hoş_, _ودان, _gñin, _ﺤﺴﺏ_, 
   {{0x249c1730,0xb058081d,0xc87871d5,0x41d40d2e}},	//   pium_, lmäy, _koş_, डेंस, 
   {{0x44f003c1,0x443c0796,0xafd8013c,0xc878010e}},	//   _iá_, _ubw_, ceøk, _joş_, 
   {{0x44f00cfc,0xc8780311,0x442c03e0,0x31300066}},	//   _há_, _moş_, mge_, وفیز, 
   {{0x442c0ff7,0x44f0110e,0xc87803e0,0xc7b800e5}},	//   lge_, _ká_, _loş_, _időd_, 
   {{0x44f14854,0x52754855,0x442c343b,0x00000000}},	//   _já_, _تانز, oge_, --, 
   {{0xc0054856,0xc87800a2,0x2ca4002e,0xb0580139}},	//   _эпик, _noş_, ёnd_, kmäy, 
   {{0x44f14857,0x442d4858,0xbae40f1b,0x64b0054e}},	// [20e60] _lá_, ige_, سكاي, căie, 
   {{0x442c0093,0xab58013d,0x26c40010,0x3ea40798}},	//   hge_, _iyül, jlno_, _ѕинг, 
   {{0x44f14859,0xc87836b5,0x23d80882,0x3f800153}},	//   _ná_, _boş_, मेतद, lyku_, 
   {{0xc879485a,0xb05800fd,0x26c40010,0x00000000}},	//   _coş_, yläm, elno_, --, 
   {{0x442d485b,0x44f1485c,0x64940311,0xb05800fd}},	//   dge_, _aá_, nţiu, xläm, 
   {{0x44f04e53,0x7bc40309,0xab5801ed,0xaa78010b}},	//   _bá_, _iyku, _ezüs, _buýu, 
   {{0x44f13367,0x7bc400c7,0x442d485d,0xb4e4043e}},	//   _cá_, _hyku, fge_, पदे_, 
   {{0x44f1485e,0x442c08d7,0x7bc40083,0xc87800ee}},	//   _dá_, gge_, _kyku, _goş_, 
   {{0x44f00270,0x64840113,0x68404627,0x00000000}},	//   _eá_, _iñil, _янта, --, 
   {{0x442d485f,0x44f14860,0x7bc54861,0xb05833f7}},	//   age_, _fá_, _myku, rläm, 
   {{0x44f14862,0xf1a4ecbd,0x442d4863,0x7648009f}},	//   _gá_, ярин, bge_, mefy, 
   {{0xc87800ac,0x78a00306,0x76482a3e,0x7bc40205}},	//   _xoş_, niov, lefy, _oyku, 
   {{0xe30803bd,0xb05802f6,0x7bc40413,0x44f00306}},	//   _གསརཔ_, lläk, _nyku, _zá_, 
   {{0x9f400093,0x1df8471f,0x76494864,0xb62c037e}},	//   _afió_, зеры_, nefy, _ｒｖ_, 
   {{0x7bc4a8cc,0x44f001fb,0x3f800113,0xc0c802d3}},	//   _ayku, _xá_, ayku_, በሎም_, 
   {{0x5d544889,0xd1380024,0x3f80020c,0xa03400db}},	//   экст, mtą_, byku_, _كۉپت, 
   {{0x64940276,0xd1380006,0x4a554865,0xc878e07a}},	// [20e70] cţiu, ltą_, мкас, _roş_, 
   {{0x442d4866,0x6ce400d6,0x64840113,0xae000131}},	//   zge_, _німе, _añil, _سۈرى, 
   {{0xd13802d5,0x442c0724,0x4c948a0f,0x7bc54867}},	//   ntą_, yge_, _жинс, _eyku, 
   {{0x44f0158a,0x78a00395,0x99d447b3,0x320c06d9}},	//   _rá_, giov, رتلا, _lefy_, 
   {{0x2d800953,0x44f14868,0x7bc400a2,0xb05801f4}},	//   lyje_, _sá_, _gyku, eläk, 
   {{0x44f14869,0xd13802d5,0x320c0109,0x7649486a}},	//   _pá_, ktą_, _nefy_, gefy, 
   {{0x442d486b,0x2d8002d5,0x3f81486c,0x44f00208}},	//   tge_, nyje_, zyku_, _qá_, 
   {{0x44f1486d,0x442d486e,0x78a02195,0x27b01870}},	//   _vá_, uge_, ciov, _пәлс, 
   {{0x44f00570,0x26c40122,0x76b40724,0xafd833b8}},	//   _wá_, plno_, яләр_, nfød, 
   {{0x44f1486f,0x442d4870,0xb05802f6,0x7d1801f1}},	//   _tá_, sge_, lläh, átsk, 
   {{0x320cfe70,0x44f00418,0x362401d9,0x442c0267}},	//   _defy_, _uá_, _زونہ, pge_, 
   {{0x7fd40046,0x167000c7,0x2d800024,0xb058023a}},	//   дігі, _ақәр, dyje_, nläh, 
   {{0x320c03d1,0x00000000,0x00000000,0x00000000}},	//   _fefy_, --, --, --, 
   {{0xafd811c0,0x64940311,0x7bc400c7,0x80cc5b29}},	//   dfød, rţiu, _ryku, _धीरे, 
   {{0xed554871,0x8db40046,0x7bc54872,0xb0580036}},	//   мор_, есті, _syku, kläh, 
   {{0x78a00005,0x64940356,0x00000000,0x00000000}},	//   xiov, pţiu, --, --, 
   {{0x60c54873,0xab5801ed,0x67280438,0x92c003d4}},	// [20e80] _ikim, _szür, jugj, ংগৰ_, 
   {{0x7bc54874,0xab5800dd,0x068000d1,0x2d800064}},	//   _vyku, _gyüm, ﯩﺰﻧﯩ, byje_, 
   {{0x7bc4033f,0x78a000f5,0xafd80162,0x00000000}},	//   _wyku, tiov, tføg, --, 
   {{0x6729078b,0xaa7800ee,0x7bc54875,0xb058007c}},	//   fugj, _buýs, _tyku, vläk, 
   {{0x78a14876,0x60c401c8,0x7bc54877,0x69c400a2}},	//   riov, _mkim, _uyku, _eyje, 
   {{0xd1387063,0xaa78010e,0x6ee8031c,0x78a001f4}},	//   ytą_, _duýs, _użbe, siov, 
   {{0x60c54878,0x320c06d9,0x250401ed,0xb058002f}},	//   _okim, _refy_, ورٹی_, bläh, 
   {{0x60c497a0,0xb0580267,0x09e000cc,0x9378447e}},	//   _nkim, rläk, মুহা, збит_, 
   {{0x320c05da,0xb0583407,0xaa78010e,0x7648c17a}},	//   _pefy_, släk, _guýs, pefy, 
   {{0x490400bc,0x00000000,0x00000000,0x00000000}},	//   हीको_, --, --, --, 
   {{0xb0594879,0xd1380024,0x11f801d9,0x010401d9}},	//   lläi, utą_, _ہوشک_, ى۪وو_, 
   {{0xd1392a40,0xeb9c00d4,0x2d800024,0xa504368e}},	//   rtą_, _edøy_, vyje_, _цеца_, 
   {{0xd138d5fb,0x320c05da,0x6494054e,0xa8000139}},	//   stą_, _tefy_, rţit, _şıks, 
   {{0x60c5487a,0x2d8002d5,0xe2801f10,0xd1380006}},	//   _ekim, tyje_, _илчи, ptą_, 
   {{0x68f84d3c,0x6494054e,0xb059487b,0xdd58009d}},	//   _čudo, mţir, hläi, марч_, 
   {{0x961400bd,0x2d8002d5,0x8f34084c,0x6494054e}},	//   সলিম_, ryje_, _зеиц, lţir, 
   {{0x5ce428e5,0x69c400e4,0x92c000fe,0x2d81487c}},	// [20e90] тюра, _syje, ংগী_, syje_, 
   {{0xdddc05a1,0x2d800006,0x69c4a4bf,0x64940311}},	//   skrš, pyje_, _pyje, nţir, 
   {{0xaa7800ee,0xb058023a,0xafd9487d,0x00000000}},	//   _buýr, eläi, geøv, --, 
   {{0xc87843eb,0x3cfc01ed,0x69c40308,0x60c40076}},	//   _kişi_, ítve_, _vyje, _xkim, 
   {{0x59d41094,0xd7c804d3,0xf8b405f5,0x69c40034}},	//   _थरथर, وومه_, хөр_, _wyje, 
   {{0xb0581073,0x92c000cc,0x00000000,0x00000000}},	//   släh, ংগু_, --, --, 
   {{0xafd8168c,0x67280200,0xf9b4014b,0x6f1800d7}},	//   rdøy, sugj, _зарӯ, šuch, 
   {{0x64840309,0xaa780a2a,0xc1d001e0,0xf99002e4}},	//   _iñik, _guýr, һөйә, _ערן_, 
   {{0xd7f805f5,0x80b40037,0xdef80092,0xb0580166}},	//   _цус_, _उदबे, ላዊና_, lläw, 
   {{0x60c5487e,0x3f8c0421,0xd9b003d4,0x4104117e}},	//   _skim, _āfu_, _কৰিম, нзов, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc87805d1,0x68f801ef,0x439400c0,0x00000000}},	//   _bişi_, _čudl, _паес, --, 
   {{0x64940311,0x6458003e,0x130400c0,0x00000000}},	//   bţir, mdui, _азім, --, 
   {{0x64588753,0xc879487f,0xe81c00cd,0xb05800fd}},	//   ldui, _dişi_, मृता_, kläw, 
   {{0xf1c40316,0x515401e0,0x645801ab,0x00000000}},	//   _रुपन, _атыу, odui, --, 
   {{0x60c54880,0x64583046,0xc87803e0,0xafd801bf}},	//   _ukim, ndui, _fişi_, veøv, 
   {{0x6458023a,0xbdf800db,0xd9a800bc,0x00000000}},	// [20ea0] idui, _ىردا_, कप्ट, --, 
   {{0x248c0042,0x64594881,0x00000000,0x00000000}},	//   _llgm_, hdui, --, --, 
   {{0x7e7c003a,0x6ee80135,0xdde8004b,0xc8780356}},	//   _iopp, _iżba, _کرښه_, _zişi_, 
   {{0x7e7c9966,0xa29c15e0,0x6458054e,0xafd801bf}},	//   _hopp, गोत्, jdui, reøv, 
   {{0x17540b32,0x17c8016c,0xaa840131,0xdab82a8b}},	//   твля, фҳаи_, بنەم_, _قۇرت_, 
   {{0x64580430,0x6f1800d8,0xb0594882,0x66e000d4}},	//   edui, áuci, rläi, гоча, 
   {{0x7e7c703e,0x6458017a,0xb05801f4,0x00000000}},	//   _mopp, fdui, släi, --, 
   {{0x7e7d4883,0x64580d47,0x3af401bf,0xb058248c}},	//   _lopp, gdui, _kæp_, lläv, 
   {{0x6d580618,0x7e7cb730,0x68e001a4,0x69c00254}},	//   āuai, _oopp, ïnde, ünev, 
   {{0x7e7c1574,0x645803d5,0x45a000d1,0x91c4104e}},	//   _nopp, adui, _ھەيك, кәйл, 
   {{0x76580649,0xc568007b,0x6494054e,0x28b40037}},	//   _iaty, _يحمل_, rţir, _अदमि, 
   {{0x76594884,0x682801b8,0x73c400cf,0x00000000}},	//   _haty, mödü, _كيام, --, 
   {{0x7e7d4885,0x76594886,0xceb80b65,0x28980a7c}},	//   _bopp, _katy, дән_, ליטא, 
   {{0xa6e4001e,0x7e7d4887,0x765800c7,0x2bd800cd}},	//   _nhữ, _copp, _jaty, _मृगा, 
   {{0x76594888,0x7e7d4889,0xa2ac08f8,0x20f40356}},	//   _maty, _dopp, ुवर्, _tăia_, 
   {{0x7659488a,0xc0c40022,0xcca400cf,0x00000000}},	//   _laty, _ишық, ئڭدى, --, 
   {{0x7e7d488b,0x26ec0118,0x00000000,0x00000000}},	// [20eb0] _fopp, _चढेर_, --, --, 
   {{0x7659488c,0x64580276,0xa6e40208,0x00000000}},	//   _naty, zdui, _chữ, --, 
   {{0x48142e3f,0x5e9c0375,0x9d189d7d,0xaa7800a2}},	//   вмес, _מבזק, _поэт_, _duýp, 
   {{0x7e7c77d9,0x6d55488d,0x5c740108,0x00000000}},	//   _zopp, _isxa, _блют, --, 
   {{0x1835488e,0x7659488f,0x3fd408b0,0x7e7c01a9}},	//   ارمح, _baty, ﻘﻘﺎﻧ, _yopp, 
   {{0xaa780124,0x765800b5,0xb058002f,0xf6200117}},	//   _guýp, _caty, mläu, адшо, 
   {{0x39340124,0x64594890,0x04b54891,0xf4f00588}},	//   _аҧхь_, tdui, ксия, аҧхь, 
   {{0x76589c80,0x6458005b,0x00000000,0x00000000}},	//   _eaty, udui, --, --, 
   {{0x64594892,0x73301e87,0x437435dd,0x765800a2}},	//   rdui, لىيا, туйт, _faty, 
   {{0x09e400bd,0x64594893,0x76594894,0x64b0054e}},	//   _প্যা, sdui, _gaty, căin, 
   {{0x81c80d42,0xb0580e78,0x2bb00208,0x27380051}},	//   লেন_, hläu, ệch_, lên_, 
   {{0x7e7c3d27,0x7e08069f,0xdebc00b7,0x76594895}},	//   _sopp, वर्ग_, ሲዮን_, _zaty, 
   {{0x6d545283,0x76594896,0x00000000,0x00000000}},	//   _asxa, _yaty, --, --, 
   {{0x7e7cf681,0xb058002f,0x00000000,0x00000000}},	//   _qopp, dläu, --, --, 
   {{0xada005f5,0x527434b1,0x6da00022,0x00000000}},	//   аарл, _حانز, аира, --, 
   {{0xb1100131,0x7e7c002e,0xb058002f,0x5a600092}},	//   _ئويغ, _wopp, fläu, _ለማመቻ, 
   {{0x5a45367e,0xf41004ac,0xb058365d,0x8fd4053f}},	// [20ec0] лмағ, יפן_, gläu, _бәрә, 
   {{0x7e7d4897,0xab2400c0,0x00000000,0x00000000}},	//   _uopp, тофа_, --, --, 
   {{0x76594898,0xceb800bc,0x18b40124,0x00000000}},	//   _raty, éře_, гәар, --, 
   {{0x76594899,0x1ad4036b,0xb0580112,0xc95412b9}},	//   _saty, тўғр, bläu, ытуы, 
   {{0x7659489a,0xda480150,0x00000000,0x00000000}},	//   _paty, _пүаж_, --, --, 
   {{0xb0580598,0x9634272a,0x3568205a,0x6b885f03}},	//   llät, ункц, дрин_, øgge, 
   {{0x64b0084c,0x7538010a,0x7659489b,0x69c1489c}},	//   răin, _qqtz, _vaty, ünet, 
   {{0x7659489d,0xc7b801d3,0xf36435ce,0x545400d8}},	//   _waty, _időn_, втон, увит, 
   {{0xd25000c6,0x27380142,0x81c80011,0xe73400db}},	//   منة_, cên_, লেম_, _иет_, 
   {{0xe3ad1fdc,0x00000000,0x00000000,0x00000000}},	//   ترى_, --, --, --, 
   {{0xa3b400f2,0xb059489e,0xa694011a,0x00000000}},	//   فایر_, klät, _שכבה_, --, 
   {{0x20c40138,0xa1304d2f,0xfce400d1,0x00000000}},	//   исяг, گریش, _ﺋﺎﻻﻫ, --, 
   {{0x9e80044e,0x00000000,0x00000000,0x00000000}},	//   _ዓለምና_, --, --, --, 
   {{0xa13001d5,0x64b0054e,0x63ac00d7,0x00000000}},	//   دریش, hăil, úcne, --, 
   {{0xe29400d8,0xb059489f,0x00000000,0x00000000}},	//   _јај_, flät, --, --, 
   {{0x273801dc,0x3cfc01ed,0xb0582305,0x3f9c01e4}},	//   yên_, ítva_, tläu, ŝtua_, 
   {{0x1af4dcd7,0x00000000,0x00000000,0x00000000}},	// [20ed0] иптя, --, --, --, 
   {{0xb05803fa,0x6ee8031c,0x6d5406be,0xd1cc01f3}},	//   rläu, _iżbo, _tsxa, _ባላት_, 
   {{0xb0580e78,0x6b8800cc,0xbb3c0092,0x1ac80116}},	//   blät, øggb, _አያውቁ, тутп_, 
   {{0x47d4143e,0x5c0400a7,0xa3e001ad,0x00000000}},	//   هيار, _вяра, फेड_, --, 
   {{0xb05948a0,0x57a40640,0x7d1c0010,0xd83801c6}},	//   lläs, ишља, _zvps, тэх_, 
   {{0x255403be,0x39480098,0xb3c40cb4,0x78a01d55}},	//   _hələ_, _fpbs_, _लड़ख, ďova, 
   {{0xc8780139,0xe180001f,0xb0583b52,0x255406be}},	//   _bişt_, ሬክተሩ_, nläs, _kələ_, 
   {{0xc1d001e0,0x00000000,0x00000000,0x00000000}},	//   ҙөлә, --, --, --, 
   {{0x27fd48a1,0xb05948a2,0xb4610b59,0x986800e5}},	//   _ifun_, hläs, скыл, _جینے_, 
   {{0x2b4803a2,0x425419a5,0x255406be,0xb05948a3}},	//   _mpcc_, утит, _lələ_, kläs, 
   {{0xa29c033d,0xd68400db,0xb05807d9,0x00e4001b}},	//   गोष्, _тутп, ylät, лжон, 
   {{0x67280023,0x91fc00ef,0x00000000,0x00000000}},	//   orgj, edād, --, --, 
   {{0x27fc02b9,0xb0580267,0x00000000,0x00000000}},	//   _mfun_, poän, --, --, 
   {{0xb05948a4,0xd3d80014,0x2560510c,0x91fc00ef}},	//   wlät, _شبنا_, _kıl_, gdād, 
   {{0x2b480048,0x290000fb,0x6ee80327,0xb0587a45}},	//   _apcc_, _ntja_, _iżbl, gläs, 
   {{0x27fc0248,0x7c6401e2,0xa29c024a,0x00000000}},	//   _nfun_, داسل, गोर्, --, 
   {{0x2900003e,0xab24d4d5,0x200148a5,0xeb9548a6}},	// [20ee0] _atja_, лота_, _ifii_, гит_, 
   {{0x27fc01e2,0xd99804d3,0x2bc43baf,0xb0583468}},	//   _afun_, پۆرت_, улуп_, bläs, 
   {{0xb05948a7,0x64b0054e,0xd1c8001f,0x8fc402f2}},	//   plät, tăil, _አመቺ_, _مزین, 
   {{0xb0580598,0x25540213,0x64b00356,0xa9340014}},	//   llär, _gələ_, făim, ابٕچ, 
   {{0x290148a8,0x7c34015d,0x2d84496e,0x69c0000d}},	//   _etja_, mgyr, _üner_, üner, 
   {{0x27fc0472,0x7c3548a9,0x25600166,0xfaa4cde5}},	//   _efun_, lgyr, _bıl_, _саго, 
   {{0x200148aa,0x6728000f,0x18b400c7,0xa9640354}},	//   _ofii_, argj, _кәдр, _йира_, 
   {{0x15f0033f,0x98940166,0x7c3548ab,0x00000000}},	//   _चलकर_, _тугә, ngyr, --, 
   {{0xb05948ac,0x36347175,0x7aec011f,0xc64400db}},	//   klär, _مراس, _kibt, _چئمى, 
   {{0x200003a0,0x7aec00b5,0xb058e9b1,0x7c340142}},	//   _afii_, _jibt, yläs, hgyr, 
   {{0xaf5047da,0xe3ad48ad,0x25600166,0xb444008e}},	//   әнгә, قری_, _gıl_, _бэлк, 
   {{0xb05948ae,0xfdac00cc,0x00000000,0x00000000}},	//   vläs, _গৰ্ড, --, --, 
   {{0xb4c005ba,0xcfcc0154,0xb058008e,0x00000000}},	//   ृती_, রেনন, flär, --, 
   {{0x25600e42,0x2000016b,0x3ea803fa,0x7aec100c}},	//   _yıl_, _efii_, gibt_, _nibt, 
   {{0xec68008e,0x00000000,0x00000000,0x00000000}},	//   нрак_, --, --, --, 
   {{0xb05948af,0x7c340731,0x2b4800cf,0xd138033f}},	//   rläs, ggyr, _ppcc_, rząd_, 
   {{0xb05833fe,0x7aec123b,0xdd900050,0x81c80154}},	// [20ef0] släs, _bibt, _ہوٝ_, লেদ_, 
   {{0xd1c80201,0x7c3548b0,0x2900007c,0xb05833fe}},	//   _አመት_, agyr, _ptja_, pläs, 
   {{0x7aec1232,0x8938030c,0x9e040139,0x255403b9}},	//   _dibt, тпес_, _учыл, _tələ_, 
   {{0xabb00724,0x2134008f,0x25600139,0xdca400f3}},	//   _гамә, רטאל_, _rıl_, _гаџи, 
   {{0x2ee00175,0x00000000,0x00000000,0x00000000}},	//   omjf_, --, --, --, 
   {{0x7aed48b1,0x83fc00dd,0xa9c800c7,0x672948b2}},	//   _gibt, zdőd, _зыбз_, rrgj, 
   {{0xd61800c6,0x97a405a2,0xc7b801d3,0x25600bb9}},	//   اتها_, ирәл, _időm_, _qıl_, 
   {{0xc484d560,0x03241515,0xb0580598,0x27fc0472}},	//   рлик, адин, zlär, _ufun_, 
   {{0xb058f4b5,0x81c80154,0x69c8002f,0x35b00166}},	//   ylär, লো_, ßgef, йбәр, 
   {{0xb3c42ba1,0x648400eb,0xab5806be,0x2560008e}},	//   рльз_, _añit, _hyüs, _tıl_, 
   {{0x26c548b3,0xb60002f0,0x3da800cc,0x00000000}},	//   mono_, ťáck, _খুনল, --, 
   {{0x26c548b4,0xaca001f2,0xafd8003b,0x00000000}},	//   lono_, _brọd, rføn, --, 
   {{0x7fd4005e,0xb0580598,0xf3180131,0x00000000}},	//   ріні, tlär, _анчә_, --, 
   {{0x26c548b5,0x94180605,0xafd8072b,0xa4400244}},	//   nono_, ɑrɑ_, mføl, _ئێکو, 
   {{0xb0581248,0xa280323b,0x26c548b6,0x5fd80490}},	//   rlär, _نیکو, iono_, _ठरवल, 
   {{0xb05948b7,0x648402d1,0x628148b8,0x20000ba7}},	//   slär, _iñis, _hono, _ufii_, 
   {{0x26c548b9,0x628148ba,0xb05948bb,0xafd83b97}},	// [20f00] kono_, _kono, plär, nføl, 
   {{0x628148bc,0x26c402d5,0xb0587edd,0xf99148bd}},	//   _jono, jono_, lläp, يبا_, 
   {{0x26c548be,0x7c340209,0xe3a40451,0x83fc00e5}},	//   dono_, pgyr, _ڀر_, időb, 
   {{0x628148bf,0xafd80fac,0xe60c00d1,0xdc5400f2}},	//   _lono, kføl, ۈشى_, _اردک, 
   {{0x26c548c0,0x628148c1,0x15e802ab,0xe73548c2}},	//   fono_, _oono, टेनर_, иец_, 
   {{0xafd84e9b,0xf52548c3,0xb05804cc,0xfaa40063}},	//   dføl, афин, hläp, _ђаво, 
   {{0xa3e002ab,0xb05800a2,0x00000000,0x00000000}},	//   फेस_, kläp, --, --, 
   {{0x628148c4,0xfaa412d7,0xb4c000dc,0xe3cc0154}},	//   _aono, _саҳо, ृते_, াইনব, 
   {{0x628148c5,0x26c4e163,0x80c8033f,0xb05801e3}},	//   _bono, bono_, रवनइ, dläp, 
   {{0x628148c6,0x26c548c7,0x35a548c8,0xab580139}},	//   _cono, cono_, _казг, _kyür, 
   {{0x628148c9,0x7c2548ca,0xd1380034,0x799c0175}},	//   _dono, _odkr, dząc_, nzpw, 
   {{0x6280b3be,0xb9200248,0x30a4022e,0xc9c80150}},	//   _eono, _sopọ_, рров, _ﺒﺼﻴﻐ, 
   {{0x628148cb,0xb9200241,0x00000000,0x00000000}},	//   _fono, _popọ_, --, --, 
   {{0x7c240156,0x628148cc,0x630148cd,0xef1c0342}},	//   _adkr, _gono, _بوول, rsü_, 
   {{0x64840124,0x6ca4d31a,0xeca40e92,0xef1c5d34}},	//   _iñir, араж, ајан, ssü_, 
   {{0x26c548ce,0x628148cf,0x64840309,0x99b003d4}},	//   zono_, _zono, _uñit, _কৰ্ক, 
   {{0x26c548d0,0x4bc4009d,0x00000000,0x00000000}},	// [20f10] yono_, сөнг, --, --, 
   {{0xd138033f,0xd010073e,0x628001d5,0x00000000}},	//   cząc_, _بلک_, _xono, --, 
   {{0x26c548d1,0x68e0017a,0x00000000,0x00000000}},	//   vono_, ïndo, --, --, 
   {{0x26c548d2,0x628402d3,0xb4c000cd,0x00000000}},	//   wono_, _ዝገደደ_, ृतो_, --, 
   {{0x26c548d3,0xc7b801d3,0x68f800d0,0x00000000}},	//   tono_, _idők_, _čudu, --, 
   {{0x26c40418,0xafd80158,0xd7740137,0x00000000}},	//   uono_, vføl, تامع, --, 
   {{0x09e548d4,0x26c548d5,0x1a680502,0x628148d6}},	//   _প্রা, rono_, _خیلی_, _rono, 
   {{0xef1c01d3,0xafd80fac,0x7794013d,0xe7a40116}},	//   gyük_, tføl, ркәр_, _پۇتى_, 
   {{0x26c548d7,0xb850001f,0x42c948d8,0x03a4a514}},	//   pono_, _መምጣቱ, лгин_, сипо, 
   {{0xafd84c2e,0x62800842,0x26c40014,0x3cdc0037}},	//   rføl, _qono, qono_, _कीने_, 
   {{0x6280a3b6,0x2c1409b4,0x83fc00e5,0x00000000}},	//   _vono, तरां_, rdőb, --, 
   {{0x628148d9,0xafd803a1,0x4ad8012d,0x00000000}},	//   _wono, pføl, _बीसव, --, 
   {{0xafd8019b,0x628148da,0x443c020b,0x719400aa}},	//   lføj, _tono, _icw_, لنیز_, 
   {{0x648402d1,0xb05801e6,0x0eb80032,0x81c8009e}},	//   _iñiq, släp, аусы_, লেষ_, 
   {{0x7c9548db,0x64840bc9,0x69a435e8,0x26c8031c}},	//   брац, _uñis, _टेली, _ཆེནཔ, 
   {{0xa5c0033f,0xd138033f,0x00000000,0x00000000}},	//   ciół, sząc_, --, --, 
   {{0x3a2481db,0xba2548dc,0xbea4022e,0x00000000}},	// [20f20] ймаг, йдак, _гапк, --, 
   {{0x850400b5,0x00000000,0x00000000,0x00000000}},	//   _i用f面_, --, --, --, 
   {{0x81c80d42,0x443d48dd,0x64480036,0x997c00e2}},	//   লের_, _ocw_, _obgi, sāža_, 
   {{0x443c0441,0x644800ca,0x20f4054e,0x7c2401bf}},	//   _ncw_, _nbgi, _căii_, _udkr, 
   {{0xe204012d,0x00000000,0x00000000,0x00000000}},	//   _ziół_, --, --, --, 
   {{0xb4c0cdf8,0x443d00d7,0x64480b70,0xc76400d1}},	//   ृत्_, _acw_, _abgi, غانى, 
   {{0x443c010a,0x25e03be6,0xdcfc0024,0x3d14000d}},	//   _bcw_, टेली_, tyrę, _तबों_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf2c548de,0xb778002b,0xa3e00401,0xb4c000cd}},	//   йсон, _kaṭā, फेल_, ृतौ_, 
   {{0xe7b02ad5,0xb77800cd,0x068000d1,0x87b801f0}},	//   _عملد, _jaṭā, ﯩﺰﻟﯩ, _туст_, 
   {{0x06640150,0x30e40150,0x00000000,0x00000000}},	//   _باقپ, йімб, --, --, 
   {{0x6ee8025c,0xd7dc01f9,0x00000000,0x00000000}},	//   _iżbi, _बराच, --, --, 
   {{0x648400c7,0x09c40490,0xf2e401f4,0x00000000}},	//   _iñip, _वड्य, _люко, --, 
   {{0x3868013f,0x835005d9,0x63b002f0,0x00000000}},	//   _ɔbra_, _آھيا, šená, --, 
   {{0x321c3c30,0xdd943ae0,0xaa780432,0xc2ec0118}},	//   maty_, пары, _guýy, řící, 
   {{0x321d48df,0x8f3400c7,0xa06800f3,0x00000000}},	//   laty_, _деиц, _гаћа_, --, 
   {{0x3cf800db,0xbd0001f2,0xaae432f7,0x00000000}},	// [20f30] _eupv_, _ọktọ, مسئو, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x290548e0,0xab5803e0,0x00000000,0x00000000}},	//   ëna_, _eyüp, --, --, 
   {{0x29040f40,0x321d48e1,0x24d00131,0xe3c40153}},	//   īna_, haty_, ﯚﺭﯗﻟ, ūčių_, 
   {{0x69c803fa,0x321d48e2,0x290455a0,0x20f4054e}},	//   ßgeb, katy_, ūna_, _văii_, 
   {{0x443c0050,0x5a44010b,0x321d4898,0x00000000}},	//   _scw_, _нэса, jaty_, --, 
   {{0xf8ac121e,0x443c0175,0x7d000030,0x3cdc01ad}},	//   رکہ_, _pcw_, _čosk, _कीडे_, 
   {{0x44881069,0x8774004b,0x92b800cc,0x76b0012d}},	//   рбин_, _ویاړ_, চতো_, głyb, 
   {{0x321c0170,0x443c0051,0x62840254,0xaabc243c}},	//   faty_, _vcw_, öjoo, ्वपक, 
   {{0x321d48e3,0x81bc015b,0xd3a401ec,0xf3340055}},	//   gaty_, _আরব_, ялық, caṭā_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x437406f6,0x321c035b,0x212802e2,0x00000000}},	//   _وهار, aaty_, čch_, --, 
   {{0x321d48e4,0x6b8800cc,0x8f9802e8,0x81c800fe}},	//   baty_, øggl, бърт_, লেং_, 
   {{0x321c0055,0x00000000,0x00000000,0x00000000}},	//   caty_, --, --, --, 
   {{0xb778002b,0x00000000,0x00000000,0x00000000}},	//   _kaṣā, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbea400c7,0xb778002b,0x00000000,0x00000000}},	// [20f40] _маик, _paṭā, --, --, 
   {{0xf8d000cd,0x00000000,0x00000000,0x00000000}},	//   तत्प, --, --, --, 
   {{0xa96400a7,0xbd4401f7,0xb7780055,0x00000000}},	//   жиха_, _بنجي, _vaṭā, --, 
   {{0x20c4002e,0x76b00210,0x00000000,0x00000000}},	//   tñiy_, kłyc, --, --, 
   {{0xf7701b06,0xb77800b8,0x321d48e5,0x00000000}},	//   باا_, _taṭā, yaty_, --, 
   {{0x2a6005be,0x6b8801e6,0x995800d7,0x00000000}},	//   _gajb_, ägge, ešťa_, --, 
   {{0x321d48e6,0x6b980432,0xa5040798,0x00000000}},	//   vaty_, _ýugr, оеја_, --, 
   {{0x7348084c,0xe9d402bf,0x321c0210,0x00000000}},	//   ачов_, _єкт_, waty_, --, 
   {{0x61ec03be,0xc444619c,0x76b0033f,0x386401d5}},	//   əklə, سیون_, głyc, mdor_, 
   {{0x7f44074d,0x386548e7,0xe61548e8,0x00000000}},	//   dtkq, ldor_, _мду_, --, 
   {{0x321d48e9,0xdd1c0030,0xf1a80345,0x76480142}},	//   raty_, yšše, شاده_, mffy, 
   {{0x321d48ea,0x7648ed0c,0x00000000,0x00000000}},	//   saty_, lffy, --, --, 
   {{0xb284004e,0x00000000,0x00000000,0x00000000}},	//   _мыкк, --, --, --, 
   {{0xf1a8004b,0x6b880158,0x76480042,0x00000000}},	//   _پاته_, øggm, nffy, --, 
   {{0x7bd800c8,0x386403a2,0xe29400d8,0x00000000}},	//   _ŝtup, kdor_, _фај_, --, 
   {{0x76480142,0x00000000,0x00000000,0x00000000}},	//   hffy, --, --, --, 
   {{0x386548eb,0xe0d062a9,0xea640114,0x00000000}},	// [20f50] ddor_, _جزو_, жњен, --, 
   {{0x1b040f22,0x8eb40014,0x00000000,0x00000000}},	//   _লিখে_, _ژٕکت, --, --, 
   {{0xad2424c5,0xa90426a8,0xcfcc0154,0x3864022e}},	//   _برخو, زبان, রেশন, fdor_, 
   {{0x6d44002f,0x18a400d4,0x79e800e5,0x7ccc00c0}},	//   mtja, маєм, حومہ_, gėrę, 
   {{0xb900069f,0x6d4548ec,0x7d0001fa,0x69c80b7c}},	//   _नी_, ltja, _čosi, _तुरी, 
   {{0x386548ed,0x246401fb,0x569401af,0x6d440037}},	//   ador_, _ốm_, мачт, otja, 
   {{0x6d44bfd6,0x3864036b,0x00000000,0x00000000}},	//   ntja, bdor_, --, --, 
   {{0x6d4548ee,0x54e415eb,0xd7f86c49,0x00000000}},	//   itja, وسيق, _дуф_, --, 
   {{0xf09c0268,0x42d4443f,0x6d44000d,0x176800d8}},	//   dhà_, зіну, htja, _мрфп_, 
   {{0x76b0012d,0x6d44007c,0x00000000,0x00000000}},	//   rłyc, ktja, --, --, 
   {{0x41b404a9,0x33240036,0x76b00034,0x8840001f}},	//   ясит, _evox_, słyc, _የምትሰ, 
   {{0x76b0012d,0x00000000,0x00000000,0x00000000}},	//   płyc, --, --, --, 
   {{0x94400022,0x6d4402d0,0x4308009f,0x00000000}},	//   _рҭыж, etja, _ايتَ_, --, 
   {{0x4b0803d4,0x4528025c,0x91fc005f,0x249c068c}},	//   _লিংগ_, _ལྷོར_, ndāl, lhum_, 
   {{0x7c943bb3,0x33240204,0xe7e81f13,0x386548ef}},	//   прац, _zvox_, जेता_, ydor_, 
   {{0x249c0cfc,0xf09c0c86,0xd1b818fd,0x3ce00208}},	//   nhum_, chà_, _باها_, _qhkv_, 
   {{0x21240051,0x7648015d,0xb81800cc,0x00000000}},	// [20f60] _hvnh_, yffy, _ডালত_, --, 
   {{0x386548f0,0x249c022e,0x00000000,0x00000000}},	//   wdor_, hhum_, --, --, 
   {{0xb9040212,0xd91148f1,0xcee801f7,0xcfa80214}},	//   їздк, ئیر_, _برين_, _هایم_, 
   {{0xf74400d8,0x81bc00eb,0x00000000,0x00000000}},	//   зедо, _আরা_, --, --, 
   {{0x386548f2,0xa000015b,0xe7340262,0xafd80162}},	//   rdor_, _্যাব_, зеч_, rgøg, 
   {{0x2d8400cf,0xafd803b2,0x661001ef,0x8a3800c0}},	//   _ànec_, sgøg, _čeké, _мяст_, 
   {{0x249d48f3,0x76480042,0xd5b000ae,0x00000000}},	//   fhum_, rffy, ضفة_, --, 
   {{0xf74425fc,0xd738001f,0x957c0034,0x5398036b}},	//   _небо, _የግልነ, _rząd, жвия_, 
   {{0xd5b800b8,0xa340009d,0xa8780354,0x00000000}},	//   _adāt_, нээл, _ултă_, --, 
   {{0x9f400de2,0x6d4548f4,0xd8b8009f,0x00000000}},	//   _ngiñ_, ytja, _انڱڻ_, --, 
   {{0xaabc1223,0x66e000d8,0x249c00cd,0x00000000}},	//   ्वतक, _џоха, bhum_, --, 
   {{0x249d48f5,0x92ac0f22,0x64a0519c,0xb0580166}},	//   chum_, ককে_, _паха, lläz, 
   {{0x9f402b1d,0xbd0001f2,0x68e0257c,0x91fc00e2}},	//   _sgiò_, _ọkpọ, ïndi, ldām, 
   {{0x6d4548f6,0x6f0c05e4,0xc7b801ed,0x00000000}},	//   ttja, rpcc, _időt_, --, 
   {{0xcfb403d4,0xe80c00bc,0x00000000,0x00000000}},	//   _ঘৰখন, ाडमा_, --, --, 
   {{0x6d4548f7,0x9f4001c4,0x6f0c00f2,0xdc8916db}},	//   rtja, _egiñ_, ppcc, псул_, 
   {{0x6d4548f8,0x00000000,0x00000000,0x00000000}},	// [20f70] stja, --, --, --, 
   {{0xbd000789,0x6d4548f9,0x00000000,0x00000000}},	//   ñéca, ptja, --, --, 
   {{0xc9580131,0xb05948fa,0x14cc27c6,0x00000000}},	//   تلاش_, gnäg, ावाण, --, 
   {{0xa80000cf,0x48c40166,0x00000000,0x00000000}},	//   ركتۉ, фәга, --, --, 
   {{0xabe801d9,0x6b700032,0xafd8003b,0xd7f80408}},	//   _دردٕ_, _яһау, teøy, чух_, 
   {{0x4528025c,0x00000000,0x00000000,0x00000000}},	//   _ལྷུར_, --, --, --, 
   {{0xd6241b06,0x249d48fb,0xa8a400fd,0x04c8027d}},	//   رعوي, thum_, _ерак, يوتي_, 
   {{0x58d47b0e,0x00000000,0x00000000,0x00000000}},	//   _зост, --, --, --, 
   {{0xc87805d1,0xb46064c2,0x7d1800e5,0x00000000}},	//   _inş_, ткыл, átsz, --, 
   {{0x249d48fc,0xaabc16d1,0x00000000,0x00000000}},	//   shum_, ्विक, --, --, 
   {{0x249d48fd,0xeb9c03cd,0xbbb817cb,0xb058040e}},	//   phum_, _veøy_, _इश्क, lläy, 
   {{0x249c0472,0x44b40276,0xa244004b,0x00000000}},	//   qhum_, _юбес, _کیدل_, --, 
   {{0xaabc00dc,0xc7b801d3,0xafe000db,0x8f980395}},	//   ्वाक, _idős_, коюл, пърт_, 
   {{0x83fc01ed,0x81c80183,0x645948fe,0x00000000}},	//   zdől, লেগ_, leui, --, 
   {{0xb05948ff,0x2c080521,0x9f4006ea,0x1f180014}},	//   goäs, _ụjọ_, _egið_, _کعبک_, 
   {{0xcfcc0154,0xed540395,0xb0580166,0x00000000}},	//   রেইন, ьос_, gnäd, --, 
   {{0x9f454900,0xbdf80220,0x6f6000fd,0x69c0000f}},	// [20f80] ämä_, _وردا_, _авыз, ûnen, 
   {{0x6f54021a,0x6b8801e6,0x91fc00e2,0x62840108}},	//   _کلیز_, ägga, edāj, öjoh, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb0580112,0x2810c019,0x499000f2,0x00000000}},	//   rnäg, نومس, دیفر, --, 
   {{0x64580098,0xb8d4012d,0x00000000,0x00000000}},	//   deui, _छग_, --, --, 
   {{0x9f4024d1,0x7bc4031c,0xafd80158,0xb0580254}},	//   _azië_, _ixku, mføt, noär, 
   {{0x64594901,0x3d100574,0xceb800bc,0xa6c40244}},	//   feui, धीचे_, éři_, بوول_, 
   {{0x64580438,0x3328009d,0x00000000,0x00000000}},	//   geui, оцон_, --, --, 
   {{0x3580001f,0x78a14902,0x68e0054e,0xb05801e3}},	//   ያውቁት_, mhov, înde, mläx, 
   {{0x78a002c4,0x6b880174,0x00000000,0x00000000}},	//   lhov, øggi, --, --, 
   {{0x98440092,0x64641572,0x00000000,0x00000000}},	//   _የምትቀ, öriä, --, --, 
   {{0x78a14903,0x6458276b,0x468000c7,0xafd80158}},	//   nhov, ceui, _ақәа, kføt, 
   {{0xb4c80bae,0xdb240241,0x00000000,0x00000000}},	//   लकी_, _ìsèj, --, --, 
   {{0x78a042c9,0x6384067c,0x8e8401d5,0x00000000}},	//   hhov, sénç, رلزه, --, 
   {{0xa2c90a71,0x1df8d705,0x216004f0,0xb05801e3}},	//   सकर्, деры_, _атыг, kläx, 
   {{0x78a00b94,0x2054013d,0x5cc4010b,0x00000000}},	//   jhov, _акъя, всуз, --, 
   {{0xdb041e54,0x4c940107,0x00000000,0x00000000}},	// [20f90] nziè, _ҷинс, --, --, 
   {{0x5a343967,0xdb040129,0xb0580037,0x92bc00cc}},	//   кнут, iziè, snäd, _আঠু_, 
   {{0x7bc46d37,0xbb340131,0x00000000,0x00000000}},	//   _exku, ﺮﻗﻰ_, --, --, 
   {{0x6d540054,0x78a0016d,0x64589ec6,0x5f7402dd}},	//   _ipxa, ghov, xeui, _ساۋر, 
   {{0x64580a73,0xfcc000fb,0x00000000,0x00000000}},	//   veui, _сәрм, --, --, 
   {{0x81c809bd,0x45194904,0x0b54001f,0xd87401d5}},	//   লেট_, пция_, _ምርታማ, _یاقب, 
   {{0xccfc0134,0x64594905,0x32f4033f,0x76b0012d}},	//   _brɛɛ_, teui, _płyn_, płyn, 
   {{0x78a0076f,0x69c40327,0x355000f1,0x91fc00b8}},	//   chov, _ixje, انيز, bdāk, 
   {{0x64594906,0x68e00549,0xeac000fe,0x00000000}},	//   reui, ïndu, ্গীম, --, 
   {{0x2d1c05f9,0x577800c6,0x41a832c0,0x00000000}},	//   _बबूल_, _تصفح_, звон_, --, 
   {{0xccfc0134,0x312001c6,0xb48001e0,0x00000000}},	//   _frɛɛ_, лдэг, ткөһ, --, 
   {{0x7ea005da,0x25080214,0x00000000,0x00000000}},	//   _môpe, _هرچی_, --, --, 
   {{0x6d540bc9,0x9f4c864e,0x14cc206b,0x091400fe}},	//   _apxa, _ölüm_, ावरण, _ডিফু_, 
   {{0x78a00232,0xb0500150,0x822c0023,0x00000000}},	//   zhov, _ەپيت, _ተጠቒሶ, --, 
   {{0x69c4044e,0x6b88049f,0x69c80e78,0x57dc4ead}},	//   _nxje, äggn, ßgel, _बर्ह, 
   {{0x78a0036e,0x00000000,0x00000000,0x00000000}},	//   xhov, --, --, --, 
   {{0xfa347f51,0x69c803ee,0x60c54907,0x6cd00e56}},	// [20fa0] فراد, şgel, _ijim, اققا, 
   {{0x39a401e1,0xafd87e78,0xaa4001ec,0xab74009a}},	//   _nísé_, rføt, леул, عملا_, 
   {{0xf294008f,0x00000000,0x00000000,0x00000000}},	//   עכער_, --, --, --, 
   {{0x60c40083,0xb05804ef,0xbdf80150,0x78d42162}},	//   _jjim, mnäc, _ورگا_, رغائ, 
   {{0x78a14908,0x69c40789,0x60c4009f,0xe80c1d15}},	//   rhov, _exje, _mjim, ाड़ा_, 
   {{0x648403f0,0x60c400f3,0x00000000,0x00000000}},	//   _iñiy, _ljim, --, --, 
   {{0x78a0049f,0xafd84098,0x3dd80175,0x60c402d0}},	//   phov, nfør, _jypw_, _ojim, 
   {{0xb4c803e5,0x00000000,0x00000000,0x00000000}},	//   लके_, --, --, --, 
   {{0xe7340577,0xb9cc1772,0x36c40212,0x76140153}},	//   _пет_, _ሱር_, _збаг, _зьех, 
   {{0xafd9449a,0x9294026a,0x81c802f5,0xdb040129}},	//   kfør, таоц, লেছ_, rziè, 
   {{0xdebc044e,0x5f940b01,0x00000000,0x00000000}},	//   ተዀነ_, қирт, --, --, 
   {{0xafd8708a,0x64840784,0x00000000,0x00000000}},	//   dfør, _oñiy, --, --, 
   {{0x60c54909,0x83fc01d3,0x00000000,0x00000000}},	//   _djim, zdők, --, --, 
   {{0x60c5490a,0x94b007f7,0xafd8005c,0xedd405a2}},	//   _ejim, _जगुआ, ffør, елгә_, 
   {{0xafd9490b,0x09b400eb,0x00000000,0x00000000}},	//   gfør, _জুনা, --, --, 
   {{0x60c402d3,0x7ea0000f,0x61d808c3,0x4bc401c4}},	//   _gjim, _rôpe, _מקוד, вөгг, 
   {{0xafd803b2,0x00000000,0x00000000,0x00000000}},	// [20fb0] rføs, --, --, --, 
   {{0xa9c4f112,0xafd80162,0x00000000,0x00000000}},	//   нсек, sføs, --, --, 
   {{0x7dc8145e,0xb810015b,0xa7840344,0xd13800c0}},	//   rösë, _হয়ত_, کشاو, nrą_, 
   {{0xb4c802f8,0x4c942369,0x6e244a5e,0x39a401e1}},	//   लको_, _римс, lajb, _sísé_, 
   {{0x9be4155b,0xb4c80550,0x99d400db,0x5c74011c}},	//   _бірк, लकै_, _ەتقا, _слят, 
   {{0x6e25490c,0xd1380006,0x6b880174,0x00000000}},	//   najb, krą_, øggu, --, 
   {{0x1958b0b9,0x6abc6385,0x4904013e,0xf5300120}},	//   _пары_, ्वीर, _рӯзг, аејќ, 
   {{0x98f5490d,0xd138762b,0x6e24014f,0x5d7c0a7c}},	//   _مثقا, drą_, hajb, לאוק, 
   {{0x29000181,0x27fd490e,0x34800166,0x00000000}},	//   _huja_, _igun_, ргыг, --, 
   {{0x2901490f,0x60c4017a,0x672803cd,0x00000000}},	//   _kuja_, _sjim, msgj, --, 
   {{0x29005c7e,0xbbdc66c0,0x68f80037,0x9ffc0327}},	//   _juja_, _मर्क, _kiud, _དཔྱང_, 
   {{0x29014910,0x3208013f,0xafd812e8,0x8334014b}},	//   _muja_, _ɑhyɛ_, vfør, _андх, 
   {{0x2900016d,0x68f810d8,0x6f6002d5,0x65600175}},	//   _luja_, _miud, авяз, lwnh, 
   {{0x68f80006,0xafd808fb,0xd138d061,0x15e80d79}},	//   _liud, tfør, brą_, टेकर_, 
   {{0x27fc110e,0x29014911,0x60c4007f,0x41b4036b}},	//   _ogun_, _nuja_, _tjim, _جمغر, 
   {{0xafd89f65,0x60c54912,0x6cc14913,0x67280162}},	//   rfør, _ujim, айса, ksgj, 
   {{0x67280a85,0xafd94914,0xab24a319,0x6e2478e0}},	// [20fc0] jsgj, sfør, кота_, bajb, 
   {{0x27fc020c,0x68f94915,0xafd84098,0x672800fe}},	//   _agun_, _aiud, pfør, dsgj, 
   {{0x290006ed,0x68f80006,0x56940220,0x39454916}},	//   _cuja_, _biud, ғайт, тнег, 
   {{0x68f94917,0x2900014f,0x00000000,0x00000000}},	//   _ciud, _duja_, --, --, 
   {{0x68f8032b,0x64840784,0x22440334,0x67294918}},	//   _diud, _uñiy, _ocnk_, gsgj, 
   {{0x27fc152d,0x66700533,0x20000589,0x68e005e4}},	//   _egun_, لدىر, _lgii_, ïndr, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x68f92135,0x20001bce,0x69bc0073,0x00000000}},	//   _giud, _ngii_, वपरी, --, 
   {{0x248c0393,0x17c4035b,0x65600042,0x6e24016d}},	//   _dogm_, _сааҭ, awnh, yajb, 
   {{0xe3acf01a,0xd1380006,0x68f801c4,0xb5f002dd}},	//   غري_, trą_, _ziud, _күлі, 
   {{0x290000e8,0xefc40023,0xf1a4033a,0x50f40395}},	//   _xuja_, ኸይድ_, трпн, лзот, 
   {{0x68f80051,0x00000000,0x00000000,0x00000000}},	//   _xiud, --, --, --, 
   {{0x53354919,0xb4bd0ebe,0xdfd800a7,0xb4dc0073}},	//   _селт, ँची_, вър_, णती_, 
   {{0x20000e14,0xa2900212,0x91fc00ef,0xd1380064}},	//   _egii_, _ваші, edāv, prą_, 
   {{0x6fd0424e,0xec680a5b,0xf1a802f2,0x00000000}},	//   _धुरं, мрак_, _تاشه_, --, 
   {{0x290007a8,0xdd940d0e,0x6ce40220,0xcca416a0}},	//   _ruja_, шасы, тіге, اڭدى, 
   {{0x2901491a,0x68f843c2,0x4a55491b,0x77a401a9}},	// [20fd0] _suja_, _riud, лкас, _mаxs, 
   {{0x2901491c,0x68f9491d,0xaca00ca8,0xdee41f5a}},	//   _puja_, _siud, _isọd, _коњи, 
   {{0x8834009d,0xf7300092,0x00000000,0x00000000}},	//   гэлц, _አልፈዋ, --, --, 
   {{0x6b880158,0x9814484d,0xa850008e,0x91fc002b}},	//   øggs, لبها, редә, bdāv, 
   {{0x68f8fb19,0x320c9834,0x98480395,0xab2800ae}},	//   _viud, _offy_, тяха_, _تسجل_, 
   {{0x2901491e,0x490405af,0xb600013a,0x00000000}},	//   _tuja_, _موسق, _žáru, --, 
   {{0x68f9491f,0xe824016c,0xb810015b,0x0ba40022}},	//   _tiud, _афзо, _হযরত_, _рыҽҭ, 
   {{0x27fc003e,0xf554007b,0x5dfc011a,0x00000000}},	//   _ugun_, اليب_, ופונ, --, 
   {{0x638007d6,0xe7b406ff,0x659000bc,0x00000000}},	//   рҳла, _अधिप, _běhá, --, 
   {{0x45454920,0x67d00131,0x437401e0,0x00000000}},	//   _منطق, _боғу, _ҡулт, --, 
   {{0xaca001e1,0xba040020,0xa5040e56,0xd6e400c0}},	//   _asọd, _ጉዞ_, _شىشە_, _лiтв, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x66e00574,0x91a00c22,0x00000000,0x00000000}},	//   गतिक_, खनशै, --, --, 
   {{0xada0b32f,0x6da062bd,0xed5428cf,0x6abc00dc}},	//   барл, бира, лор_, ्वैर, 
   {{0x0ca80b24,0x00000000,0x00000000,0x00000000}},	//   نطقي_, --, --, --, 
   {{0x30d8008f,0xdb2000ee,0x00000000,0x00000000}},	// [20fe0] _אַזע, _öwür, --, --, 
   {{0xb0594921,0x00000000,0x00000000,0x00000000}},	//   nnän, --, --, --, 
   {{0xd9104bcf,0x7c28c2f3,0x6b880158,0xeef4011a}},	//   تیز_, _понг_, øggr, _תמיר_, 
   {{0xe60c005e,0xad640006,0xb05801f4,0x483400f1}},	//   ۋشى_, _саюз_, hnän, لومړ, 
   {{0x7c2400e2,0xec7402e8,0xeb954922,0x178401a9}},	//   _iekr, _спя_, _бия_, шқаг, 
   {{0x3568e77b,0xa7a400f7,0x2c6001d9,0xf56800ee}},	//   ерин_, ыкча_, _پگہُ, ешик_, 
   {{0x7c24194f,0xc68d1f2d,0xdddc00b0,0x00000000}},	//   _kekr, بېل_, kerō, --, 
   {{0xb4dcdc75,0x2978010f,0xf36401c4,0x060800fb}},	//   णते_, _אטלא, гтон, нмәҫ_, 
   {{0xd3700075,0xb35400f2,0x00000000,0x00000000}},	//   تۇش_, ایتا_, --, --, 
   {{0x7c254923,0x59b83d1d,0x32644143,0x00000000}},	//   _lekr, _आधार, утив, --, 
   {{0x7c2475e2,0xb4f000d1,0x84540137,0x00000000}},	//   _oekr, _лүкч, _چىمچ, --, 
   {{0x7c2405ce,0x69c0012d,0xe7e80118,0x628401e3}},	//   _nekr, źneg, जेका_, öjor, 
   {{0x91fc005f,0x59ac000d,0x00000000,0x00000000}},	//   edāt, _टेघर, --, --, 
   {{0x7c24009d,0x00000000,0x00000000,0x00000000}},	//   _aekr, --, --, --, 
   {{0xe1ec00d1,0xdd58009d,0x00000000,0x00000000}},	//   _ىسى_, ларч_, --, --, 
   {{0x7c243e24,0xd5a401d9,0x6f84030d,0x00000000}},	//   _cekr, _ہہ_, _буож, --, 
   {{0xb60402fb,0xe1f404a9,0x442800b0,0xc87806be}},	// [20ff0] _zváž, _игә_, _ɾa_, _mhşt_, 
   {{0xf09c0109,0x91fc002b,0x00000000,0x00000000}},	//   lkà_, bdāt, --, --, 
   {{0x7c254924,0xedf00214,0xd138012d,0x68e00356}},	//   _fekr, _ديدگ, cząt_, îndo, 
   {{0x7c254925,0xb4bc515b,0x3ae405da,0xc79467b0}},	//   _gekr, ँचो_, rôpa_, ирлы, 
   {{0x6abc0c58,0x97d82d29,0x442800d7,0xb05801f4}},	//   ্তবো, льшу_, _ľa_, hnäo, 
   {{0xca483e58,0x7c253a47,0x89640014,0x453409ac}},	//   _جلسه_, _zekr, _پُرن, ахит, 
   {{0x7c24a0a5,0x7740001f,0x1994010a,0x00000000}},	//   _yekr, _የግለሰ, _ларя, --, 
   {{0xf8b4dfe6,0xa4200f22,0x00000000,0x00000000}},	//   _көч_, ফল্য_, --, --, 
   {{0xd05c03be,0xf8ac00f1,0xb60401ef,0x00000000}},	//   _üzər, _تکل_, _sváž, --, 
   {{0x81b80198,0xdcfc0153,0xa92400d7,0x69c8002f}},	//   _haɓɗ, byrė, _guľá, ßgew, 
   {{0x0084094c,0xcf8800d9,0x00000000,0x00000000}},	//   ално, _קט_, --, --, 
   {{0x442808a5,0x91fc00ef,0x7f940124,0x00000000}},	//   _þa_, edās, ҳаҭх, --, 
   {{0x81bc03f4,0x249d4926,0x7c6401b9,0x644800a2}},	//   _আরও_, mkum_, یارل, _icgi, 
   {{0x249c022c,0x3cdc01ad,0x2bf800dc,0x00000000}},	//   lkum_, _कीजे_, ्शनं_, --, 
   {{0xb6040306,0xfcb4005b,0x249c002e,0x76b0012d}},	//   _uváž, ащаю, okum_, aływ, 
   {{0x249d4927,0xb05895da,0x00000000,0x00000000}},	//   nkum_, nnäl, --, --, 
  
   {{0x3b854928,0x64494929,0xeb940588,0xba24242d}},	// [21000] шлаг, _mcgi, аит_, идак, 
   {{0xeb31492a,0x5e64005e,0x249c2cad,0x7c24b930}},	//   زىمد, _اندە, hkum_, _wekr, 
   {{0x249c59ec,0x7c240365,0x3234010f,0x2e38011a}},	//   kkum_, _tekr, שטען_, _בגינ, 
   {{0x315400c8,0x249d492b,0xed55492c,0x1b0400d1}},	//   ייען_, jkum_, _тою_, _гүан, 
   {{0x91fc4424,0x6ab001bf,0x00000000,0x00000000}},	//   ndār, ødfø, --, --, 
   {{0xfaa4055f,0x6448009f,0x8a180014,0x249d28ca}},	//   _таго, _acgi, _متِس_, ekum_, 
   {{0xe5a00114,0x00000000,0x00000000,0x00000000}},	//   жији, --, --, --, 
   {{0xb059492d,0x00000000,0x00000000,0x00000000}},	//   gnäl, --, --, --, 
   {{0xf2c4016c,0x36343cc6,0x83fc00e5,0xb0580166}},	//   исон, _نراس, ddős, liäg, 
   {{0x249c0009,0xb0580254,0x6b88007c,0x00000000}},	//   akum_, tnäo, äggi, --, 
   {{0x69100135,0x8a78010f,0x57a401af,0x86f401c8}},	//   _għed, אָרק, _тыңҡ, _ايلچ, 
   {{0x644802fa,0xd13001ed,0xb0580037,0xe0440a5b}},	//   _gcgi, _ہمت_, rnäo, онџи, 
   {{0xb058023a,0x93140b24,0x00000000,0x00000000}},	//   snäo, _اوتش, --, --, 
   {{0xd06403be,0xf1a80b28,0xb058007c,0x00000000}},	//   _əsər, _لابه_, mnäm, --, 
   {{0x926806ba,0x61100276,0xdd98c719,0x61400b3e}},	//   _арқа_, _căld, ашт_, _деја, 
   {{0x76b0033f,0xafd803b2,0xb0580166,0x91fc00dc}},	//   pływ, ngøk, diäg, bdār, 
   {{0xb059484f,0xcfe87286,0x00000000,0x00000000}},	// [21010] nnäm, _حفظه_, --, --, 
   {{0xda7809fe,0x9b58016c,0x249c00bc,0xb0580166}},	//   иях_, рифт_, zkum_, fiäg, 
   {{0x83fc00dd,0xb0580166,0x00000000,0x00000000}},	//   ndőr, giäg, --, --, 
   {{0x0a5405d9,0xea600a81,0xb058007c,0x00000000}},	//   _گھرج, _ژھای, knäm, --, 
   {{0xd87400f7,0x7aec01ab,0x6448003a,0x6d540e04}},	//   تالب, _fhbt, _rcgi, žbač, 
   {{0xa91400f2,0x83fc00e5,0x79c800d1,0x5a4400c0}},	//   _نظرش, zdős, _ﯪﻟﯩﻤ, _мэса, 
   {{0x249c06a3,0x04b46150,0xd5481541,0x0564022e}},	//   tkum_, йсия, لجيم_, ёвин, 
   {{0xc485492e,0x00000000,0x00000000,0x00000000}},	//   слик, --, --, --, 
   {{0x249d492f,0x666407d8,0x9f4401b8,0xb38004b4}},	//   rkum_, _въез, ämü_, злыл, 
   {{0x249d4930,0x2d840129,0xb058007c,0xdb0400d7}},	//   skum_, _ànew_, snäl, nziá, 
   {{0xd5ac01d3,0x270c00fe,0x15a80395,0xb0580166}},	//   _لہو_, _সিটো_, _къци_, kiäd, 
   {{0x147405d4,0x2004022c,0xd3080051,0x00000000}},	//   _وانج, ømi_, _iện_, --, 
   {{0x442d4931,0x7fd4005e,0xf45465dc,0x7ea00109}},	//   mae_, сіні, _طلوع_, _fôpl, 
   {{0xd3080051,0x00000000,0x00000000,0x00000000}},	//   _kện_, --, --, --, 
   {{0x0d98496b,0x61100356,0x26c4058a,0xb0580139}},	//   атты_, _băle, inno_, fiäd, 
   {{0x442d4932,0xb058adae,0x61100356,0x00000000}},	//   nae_, hnäj, _căle, --, 
   {{0x7e98db01,0x442c16b8,0x26c40165,0x6b98031c}},	// [21020] _منظر_, iae_, knno_, _żugr, 
   {{0x442d4933,0xe3a4c0f9,0xe7d800ab,0x99d415bf}},	//   hae_, _ہر_, _बड़प, ەتچا, 
   {{0x61100356,0x5ca40150,0xd3080208,0xb0580139}},	//   _făle, _ۇلگە, _nện_, biäd, 
   {{0xe3a44d4e,0x5e6400cf,0x26c5372f,0x61100356}},	//   _فر_, _انگە, enno_, _găle, 
   {{0x62814934,0x30d8010f,0x66dc0022,0x00000000}},	//   _onno, אַגע, hêku, --, 
   {{0xcd286ff0,0x442c42fb,0x2dc80150,0xfaa406ed}},	//   _حسین_, eae_, _جاۋۋ_, _ѓаво, 
   {{0x442d4935,0x7ea00109,0xb99400c6,0xe1e40150}},	//   fae_, _rôpl, _الزب, _ءس_, 
   {{0x5fc80316,0xfaa412d7,0x7f44009a,0x26c4058a}},	//   रपाल, _таҳо, kukq, anno_, 
   {{0x78a00122,0x6910031c,0xf364036b,0xa884084c}},	//   mkov, _għeb, ётин, _уйта_, 
   {{0x78a14936,0x02c407d6,0x442d4937,0x38654938}},	//   lkov, оқчи_, aae_, leor_, 
   {{0x442d4939,0xb059493a,0x3fe40150,0x75d4007b}},	//   bae_, snäm, _ﺍﺭﺍﻧ, _ايضا, 
   {{0x442d493b,0x6281493c,0x38646a89,0x83fc00e5}},	//   cae_, _enno, neor_, rdőr, 
   {{0xe3600276,0x78a00124,0x764801bf,0x00000000}},	//   _нкци, ikov, ogfy, --, 
   {{0x3a280099,0xe3340375,0x78a04a1a,0x9e140212}},	//   _nebp_, _פרופ_, hkov, здрі, 
   {{0x6ca4d888,0xb058049b,0x78a0023a,0xeca400f0}},	//   браж, nnäk, kkov, бјан, 
   {{0x3eb8003a,0x00000000,0x00000000,0x00000000}},	//   _empt_, --, --, --, 
   {{0x78a00232,0x3865493d,0x6281493e,0xfe6cf05c}},	// [21030] dkov, deor_, _ynno, رگی_, 
   {{0x442c98df,0xb0580724,0x6b5c062d,0x78a000d7}},	//   zae_, siäd, _açgö, ekov, 
   {{0x4c95493f,0x78a0655f,0x442c218d,0xdb0400d0}},	//   _динс, fkov, yae_, rziá, 
   {{0x6d454940,0xec682e3f,0x442c16b8,0x3864003e}},	//   muja, _срок_, xae_, geor_, 
   {{0x6d440cad,0x442d4941,0x20580375,0x00000000}},	//   luja, vae_, מיאל_, --, 
   {{0x442d4942,0x2904fafe,0x69c80e78,0x78a14943}},	//   wae_, ínas_, ßges, akov, 
   {{0x442d4944,0x6d454945,0x78a00122,0x3864003a}},	//   tae_, nuja, bkov, beor_, 
   {{0x78a0f2c9,0x77941945,0x2d8400db,0x38640393}},	//   ckov, скәр_, _àneu_, ceor_, 
   {{0x6d454946,0x9868066d,0x00000000,0x00000000}},	//   huja, _دینے_, --, --, 
   {{0x6d454947,0x442d4948,0xaab805d7,0xb058000d}},	//   kuja, sae_, ोचिक, lnäh, 
   {{0x442d4949,0xc0ec044e,0x61100311,0xd2002002}},	//   pae_, _ቀሊል_, _sălb, нүшк, 
   {{0x6d4401a2,0x3eb8020b,0xafd808fb,0x442c003a}},	//   duja, _smpt_, lføy, qae_, 
   {{0x63e400cf,0x6110054e,0x32f4033f,0x00000000}},	//   _اساك, _bălc, _płyt_, --, 
   {{0x78a00232,0x62807291,0x61100311,0xafd80217}},	//   zkov, _unno, _călc, nføy, 
   {{0x78a1494a,0x6d45494b,0x80e4007b,0x6b800051}},	//   ykov, guja, _وأعل, ̀ngt, 
   {{0x7ea000d7,0x00000000,0x00000000,0x00000000}},	//   _kôpk, --, --, --, 
   {{0x3eb856e4,0x78a1494c,0xe61c01fb,0x6d440024}},	// [21040] _tmpt_, vkov, _đôn_, auja, 
   {{0x61e1494d,0xea848c91,0xaec05e82,0xb05801f4}},	//   _kynl, обул_, _обыл, ynäk, 
   {{0x78a00e9a,0x3865494e,0x61e0010b,0xb058002f}},	//   tkov, teor_, _jynl, fnäh, 
   {{0x3a280158,0xb7e5494f,0x61e000ad,0x2be001f9}},	//   _webp_, ожек, _mynl, _खरचं_, 
   {{0x78a00e9a,0x21240097,0x3864f182,0x61e0037e}},	//   rkov, _lwnh_, reor_, _lynl, 
   {{0x76480175,0xab2403f6,0xb05801f4,0x00000000}},	//   ugfy, _фора_, tnäk, --, 
   {{0x78a02a92,0xeb9c33b8,0x1dbc08df,0xb864e7e1}},	//   pkov, _ufør_, ोपित, _وارو, 
   {{0xf7440364,0x7648015d,0x00000000,0x00000000}},	//   _мебо, sgfy, --, --, 
   {{0xf36402bf,0xb058005b,0x6d440210,0x00000000}},	//   ітин, snäk, zuja, --, 
   {{0xb7c400de,0x00000000,0x00000000,0x00000000}},	//   riģē, --, --, --, 
   {{0x61e00f7b,0xafd80158,0x2f0c0254,0x938801ec}},	//   _cynl, ngøv, _süg_, рсқа_, 
   {{0x61e00142,0x61100356,0x316c00d7,0x6d454950}},	//   _dynl, _sălc, _vsfz_, vuja, 
   {{0xe3ac71c5,0x6d44a84e,0xb058023a,0x68e00356}},	//   _لرو_, wuja, nnäi, îndi, 
   {{0x6d454951,0x61e0062c,0xe2803dad,0x00000000}},	//   tuja, _fynl, _олчи, --, 
   {{0x61e000a9,0x9f40008e,0x00000000,0x00000000}},	//   _gynl, _aziä_, --, --, 
   {{0x91fc02b5,0xd6d000fe,0xb0580254,0xaac400f1}},	//   neām, িতিয, knäi, ښتان, 
   {{0x4cdc0154,0x6d580124,0x00000000,0x00000000}},	// [21050] _মওদু, ̃uah, --, --, 
   {{0xd30801fb,0x00000000,0x00000000,0x00000000}},	//   _nệm_, --, --, --, 
   {{0x89d80597,0x981802e3,0x6d440140,0x91fc00b0}},	//   حوار_, _ịtụg, quja, keām, 
   {{0x6b8801e6,0x7d1800e5,0x00000000,0x00000000}},	//   äggs, ítse, --, --, 
   {{0x7c2009ff,0xb0580e78,0x61100356,0xd7c8027d}},	//   ñore, rnäh, _măla, يومه_, 
   {{0x9b6400d1,0xb0583f17,0x00000000,0x00000000}},	//   _تۆكۈ, snäh, --, --, 
   {{0x09b400cc,0xda24003b,0x00000000,0x00000000}},	//   _জঁকা, _ієро, --, --, 
   {{0x998407d6,0x61e0002d,0xc8c8036b,0x91fc00de}},	//   _تلفو, _rynl, _اورن_, reāl, 
   {{0xff14037e,0x00000000,0x00000000,0x00000000}},	//   _orgの, --, --, --, 
   {{0x61e0138f,0x00000000,0x00000000,0x00000000}},	//   _pynl, --, --, --, 
   {{0x61100311,0x1a9c010f,0x00000000,0x00000000}},	//   _băla, ייזע, --, --, 
   {{0x61e00076,0x6110054e,0x3f694952,0x439424fc}},	//   _vynl, _căla, бимо_, _наес, 
   {{0x7ea14953,0xdd3802b1,0x61e00ea0,0xd3780116}},	//   _hôpi, _tāūn, _wynl, _ңчә_, 
   {{0x6458017a,0xa2441079,0xe4d400f1,0x3ea4009d}},	//   lfui, _بیدل_, _اوچت_, чигг, 
   {{0x64580618,0x00000000,0x00000000,0x00000000}},	//   ofui, --, --, --, 
   {{0xcfcc00fe,0xa2c000cd,0x00000000,0x00000000}},	//   ৰেইন, िचक्, --, --, 
   {{0x64580421,0x69c00005,0x00000000,0x00000000}},	// [21060] ifui, únen, --, --, 
   {{0x2ca800f2,0x7b1000e4,0x00000000,0x00000000}},	//   _elcd_, _añuã, --, --, 
   {{0x7b3c054e,0x69c0002d,0xb884010b,0xa96402e8}},	//   dăuţ, ûnep, зулй, зиха_, 
   {{0xa2b80825,0x29d00150,0xe88c0171,0x00000000}},	//   षोत्, رينس, _pīšļ, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x64580381,0xf314010b,0xb0594954,0x674005a9}},	//   efui, үнйә_, rnäi, رپىك, 
   {{0x7d040585,0xd910006c,0xb0580037,0x00000000}},	//   _kiks, _شیش_, snäi, --, 
   {{0x7d04003d,0x00000000,0x00000000,0x00000000}},	//   _jiks, --, --, --, 
   {{0x7d054955,0xf1a80133,0x00000000,0x00000000}},	//   _miks, ڵاده_, --, --, 
   {{0x7d044e97,0x64580083,0x61100311,0x76140408}},	//   _liks, afui, _săla, _хьах, 
   {{0x2240012d,0xd5a40244,0x00000000,0x00000000}},	//   ójka_, _تلای, --, --, 
   {{0x7d054956,0x00000000,0x00000000,0x00000000}},	//   _niks, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xef1c0213,0x7d040153,0x00000000,0x00000000}},	//   rpü_, _aiks, --, --, 
   {{0x7d054957,0x6ca4d4b0,0xeca40798,0x00000000}},	//   _biks, праж, пјан, --, 
   {{0x7f540175,0x2a7c05d1,0x00000000,0x00000000}},	//   _fqyq, _şub_, --, --, 
   {{0x7d054958,0x2ca8007c,0xaa640150,0xadb400db}},	// [21070] _diks, _vlcd_, зтек, زۇڭا_, 
   {{0x7d040217,0xee700724,0xa5742375,0xb0580139}},	//   _eiks, _яңгы, ščić, gnäv, 
   {{0xa9041a73,0x98b80205,0x9f4401f4,0x00000000}},	//   سبان, _asrı_, ämö_, --, 
   {{0x7ea00109,0x58d4013e,0x7b440451,0x2d554959}},	//   _rôpi, нохт, _ڪئٽل, mçe_, 
   {{0x2d55495a,0x69100135,0xc81001e1,0x00000000}},	//   lçe_, _għen, _èèmé, --, 
   {{0x644402d5,0x4519495b,0xe90800c7,0x7d05495c}},	//   ėjim, оция_, _гхак_, _ziks, 
   {{0x2d541248,0x00000000,0x00000000,0x00000000}},	//   nçe_, --, --, --, 
   {{0x03180fa2,0xdddc0171,0x00000000,0x00000000}},	//   يتخت_, berņ, --, --, 
   {{0x2d540365,0x733031f0,0x645816b8,0x98480014}},	//   hçe_, نىيا, rfui, _ژلہٕ_, 
   {{0x2d549d82,0x645848fc,0x957c033f,0xfa840023}},	//   kçe_, sfui, _cząs, _ነየናይ_, 
   {{0xb058002f,0x2d540200,0x00000000,0x00000000}},	//   hnäu, jçe_, --, --, 
   {{0xcea81229,0x25ac91fc,0xf990011a,0x2d54013d}},	//   _די_, ımlı_, דרט_, dçe_, 
   {{0x443c0112,0xb05801f4,0x00000000,0x00000000}},	//   _idw_, ynäv, --, --, 
   {{0x7d05495d,0x2d540e2d,0x412800d8,0x22500210}},	//   _siks, fçe_, _доко_, óbkę_, 
   {{0x7d05495e,0xfce44a33,0xee05495f,0xbd340372}},	//   _piks, дово, дерл_, بىزع, 
   {{0x7d040200,0xb058013d,0x00000000,0x00000000}},	//   _qiks, liän, --, --, 
   {{0x46dc0027,0x00000000,0x00000000,0x00000000}},	// [21080] यवाह, --, --, --, 
   {{0x7d054960,0xafd80174,0x2d540139,0x63ac00d7}},	//   _wiks, rgøt, bçe_, úcny, 
   {{0x7d054961,0xd910221d,0x443d47b2,0xb0580108}},	//   _tiks, ایر_, _odw_, rnäv, 
   {{0xf7454962,0x00000000,0x00000000,0x00000000}},	//   дедо, --, --, --, 
   {{0xafd800b5,0x67502162,0xb058007c,0xe7340395}},	//   lgør, نخور, mnät, деч_, 
   {{0xb05801e3,0x00000000,0x00000000,0x00000000}},	//   lnät, --, --, --, 
   {{0xafd84c2e,0x443c0327,0xb0580139,0x00000000}},	//   ngør, _bdw_, diän, --, 
   {{0xb0586c31,0xb8651cc1,0x545402e8,0x53980d1d}},	//   nnät, _تاسو, хвит, звия_, 
   {{0x443ccba5,0xd708015b,0xdb0400d7,0xb0580166}},	//   _ddw_, রীড়া_, dziú, fiän, 
   {{0xc7940bd6,0xb05808e2,0xa79805d0,0x83540137}},	//   _ярсы, hnät, _ושמח, رپپا, 
   {{0x6910031c,0xb05801e3,0x00000000,0x00000000}},	//   _nħel, knät, --, --, 
   {{0x3cf80034,0x3f843881,0xafd8005c,0x00000000}},	//   ्दों_, _šoua_, dgør, --, 
   {{0x5f946fad,0x2d540724,0x4fa40014,0xb0580139}},	//   вият, wçe_, رٕسٕ, biän, 
   {{0x2d543279,0xafd800b5,0x30f400ec,0x00000000}},	//   tçe_, fgør, _ڪوبھ_, --, 
   {{0xafd804ce,0x9d1855c3,0x443c0368,0x00000000}},	//   ggør, дост_, _ydw_, --, 
   {{0x2d554963,0xb058007c,0xd13800c0,0x00000000}},	//   rçe_, gnät, msą_, --, 
   {{0x7c203a6c,0xd1380024,0x999803e0,0x00000000}},	// [21090] ñora, lsą_, _perş_, --, 
   {{0x2d545775,0xd1383f05,0x61340166,0x78b80153}},	//   pçe_, osą_, _эчәр_, _įtva, 
   {{0x69100003,0xd1387502,0xdb0407c5,0x00000000}},	//   _għel, nsą_, nziù, --, 
   {{0x2d18063f,0x47d40131,0xd1380153,0x00000000}},	//   _ụgwụ_, ىيار, isą_, --, 
   {{0x2b54bc3d,0x443c0d27,0xbc180375,0xc8c80014}},	//   _زیاد_, _rdw_, _מורש, _ہوسن_, 
   {{0xd1380024,0x443c0327,0x6d44849f,0x00000000}},	//   ksą_, _sdw_, orja, --, 
   {{0xb058c6cb,0xf8ac0451,0x29100327,0xd91400c0}},	//   nnäs, _ڏکن_, qqxa_, _адсы, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd1380024,0x1ac403d4,0x6d44002f,0xb05839fa}},	//   esą_, ্তৰা, hrja, hnäs, 
   {{0x42540131,0x572401ec,0xb058007c,0x765c00e4}},	//   хтит, _شىمك, knäs, õpyt, 
   {{0x2a6005b1,0xc8781ae4,0xb3940092,0x56940b01}},	//   _mbjb_, _kaş_, _ጉዞውን_, _шафт, 
   {{0x8cc000ab,0xb0580724,0x3f68a30d,0x302400db}},	//   रोमो, siän, пимо_, ноюп_, 
   {{0xb05864d4,0xdb0405d5,0x6d440327,0xf494132f}},	//   miäl, aziù, erja, _سپوت_, 
   {{0xafd94964,0xb0580166,0xe2800117,0x00000000}},	//   tgør, liäl, _рғон, --, 
   {{0xdb040c86,0xb0591bdd,0x00000000,0x00000000}},	//   cziù, tnät, --, --, 
   {{0xfce40aa5,0xafd800b5,0x903400c7,0xc8794965}},	//   хобо, rgør, _ихьч, _naş_, 
   {{0x6d4400ad,0xd9b40131,0xb0580267,0x00000000}},	// [210a0] arja, ھەرد, rnät, --, 
   {{0x6910025c,0xafd800b5,0x6d440158,0xba1c0011}},	//   _iħej, pgør, brja, দণ্ড_, 
   {{0xc8794966,0x6b800053,0xb0580598,0x67380200}},	//   _baş_, ānga, mnär, _avuj, 
   {{0x69100135,0x3b083fa4,0xb058007c,0x00000000}},	//   _għem, _немо_, lnär, --, 
   {{0xc8794967,0xb0594968,0x6910025c,0xbb54019b}},	//   _daş_, onär, _jħej, _webサ_, 
   {{0xb0580598,0x6910025c,0x7c354969,0x2f38010f}},	//   nnär, _mħej, layr, לגנד, 
   {{0xe96410ec,0xc878a75a,0xa96400f3,0xb0580166}},	//   _парл_, _faş_, _пира_, fiäl, 
   {{0xb059496a,0xc8780432,0x7c34594a,0x00000000}},	//   giäl, _gaş_, nayr, --, 
   {{0xd0100f00,0x69100327,0x13f4024c,0x00000000}},	//   یلد_, _nħej, ъзия, --, 
   {{0x27681f6d,0x6d45496b,0xd2503be1,0x95e801ed}},	//   _عشقی_, yrja, جند_, _قبضہ_, 
   {{0xe3ad40a3,0xc8780bcc,0x51f802bf,0x7c340784}},	//   لری_, _yaş_, ьною_, kayr, 
   {{0xe61c07ae,0x7c3401b9,0xd1380006,0x00000000}},	//   _đôi_, jayr, rsą_, --, 
   {{0xb4bc0642,0xd13804cc,0x925801ec,0x00000000}},	//   ुची_, ssą_, _жалт_, --, 
   {{0xdb0407c5,0xb814015b,0xe295496c,0x7c2002d1}},	//   pziù, ারিত_, _пач_, ñorn, 
   {{0x1df8005b,0x6278011a,0x68e8b4c8,0x00000000}},	//   ееры_, _מנגנ, ylgd, --, 
   {{0xdef8038f,0x61400640,0xb05801e3,0x7afc045a}},	//   ċċa_, _сећа, rnäs, empt, 
   {{0x69100135,0x4a547ce9,0xb058007c,0x00000000}},	// [210b0] _għej, ккас, snäs, --, 
   {{0x6f040241,0x9b4404fb,0xb9fc0055,0x6d440135}},	//   _débì, انلو, _hāṃ_, prja, 
   {{0x7c35496d,0xb9fc002b,0xc8780432,0x00000000}},	//   bayr, _kāṃ_, _paş_, --, 
   {{0x7c340429,0x7afc0ea0,0xc8785043,0x50e007b7}},	//   cayr, ampt, _qaş_, नविष, 
   {{0xb9fc0882,0x7afc0175,0x00000000,0x00000000}},	//   _māṃ_, bmpt, --, --, 
   {{0xec30185e,0x2aac012d,0x5694004e,0x00000000}},	//   _جوڭگ, yżby_, лачт, --, 
   {{0xc8781918,0x7ea00419,0xc9e4007b,0x1ae4009d}},	//   _taş_, _kôpr, _شكرً, _соём, 
   {{0xc48443ee,0xb9fc002b,0x673801ef,0x00000000}},	//   тлик, _nāṃ_, _tvuj, --, 
   {{0x673801f7,0xb058005b,0x00000000,0x00000000}},	//   _uvuj, ynär, --, --, 
   {{0x8cc0687b,0x237c02f0,0x17f8007b,0x490800bc}},	//   रोतो, rvuj_, _سرقة_, िदको_, 
   {{0x7c340280,0x3dc4015b,0x3cf400af,0x61100356}},	//   yayr, _শুনল, ्षमे_, _tălm, 
   {{0x24480150,0x7c340009,0xd49800d8,0x00000000}},	//   _ءجاي_, xayr, _прч_, --, 
   {{0x7fd4005e,0xb05801e6,0x80c80dad,0xb9fc0055}},	//   тіні, tnär, ाचौं, _dāṃ_, 
   {{0x01646d2b,0x7c35496e,0xc2c4009f,0xdcec00d7}},	//   _акко, wayr, _جيتي, úhľo, 
   {{0xed54404e,0xb0593c88,0x26c40093,0xdcc800fd}},	//   кор_, rnär, iino_, еңне_, 
   {{0x26c40924,0xf990da6d,0xb9fc00cd,0x69100135}},	//   hino_, یبا_, _gāṃ_, _tħej, 
   {{0x7c35496f,0x60c4a087,0x8cb80014,0x7f740064}},	// [210c0] rayr, _imim, ردِس_, _руйц, 
   {{0x26c54970,0x7c354971,0xee346a24,0x00000000}},	//   jino_, sayr, _инь_, --, 
   {{0x80c40fc8,0x7c354972,0xdb0400e5,0xb9fc00cd}},	//   _लगाइ, payr, nyié, _yāṃ_, 
   {{0xd30801fb,0xfbc40064,0x00000000,0x00000000}},	//   _hệt_, _абмо, --, --, 
   {{0x26c54973,0x60c54974,0xcee82651,0x2c14012d}},	//   fino_, _mmim, _زرین_, धुओं_, 
   {{0xe60c005e,0xb0594975,0x1b0400fd,0x3948010b}},	//   يشى_, hnäp, _сүзн, _озго_, 
   {{0xd308001e,0x60c54976,0xb0584a41,0x00000000}},	//   _mệt_, _omim, knäp, --, 
   {{0xe6154977,0xb4bc50dc,0x982801d3,0x93780902}},	//   ндә_, ुचे_, _سترہ_, ебит_, 
   {{0xc76431f0,0xd7f000b2,0x37048ca3,0xb9fc0055}},	//   _مالى, _اڃا_, _апаг, _rāṃ_, 
   {{0x26c54978,0x35a407dd,0x60c54979,0xb9fc0055}},	//   cino_, _иазг, _amim, _sāṃ_, 
   {{0xa3e402ab,0xaa34008f,0x83fc01d3,0xb05801f4}},	//   _मुठ_, כטיק_, gfőb, siäm, 
   {{0x6abc1d8a,0x03c40046,0x60c402d3,0xd251497a}},	//   _एग्र, _өсім, _cmim, جنگ_, 
   {{0xc0d002d3,0xd308004d,0x60c80100,0xb9fc00cd}},	//   _ረቛሒ_, _bệt_, èjma, _vāṃ_, 
   {{0x60c5497b,0x41dc0d5f,0x00000000,0x00000000}},	//   _emim, _नुकस, --, --, 
   {{0xe1ec0efb,0xb9fc0882,0xd30801fb,0x9e34005b}},	//   _وسى_, _tāṃ_, _dệt_, ресч, 
   {{0x26c5497c,0xf044c38a,0x1cb8072d,0x905400f3}},	//   zino_, _рэко, ناقب_, _свиц, 
   {{0x09bc0db3,0x26c5497d,0x072c0131,0x6b8002b1}},	// [210d0] ्प्य, yino_, ﯩﺪﯗ_, āngo, 
   {{0x26c5497e,0xb05801f4,0x00000000,0x00000000}},	//   xino_, kiäk, --, --, 
   {{0x26c5497f,0x60c54980,0xb0580108,0x00000000}},	//   vino_, _ymim, viäj, --, 
   {{0x26c54981,0x3cf40a94,0xd8880014,0x4c941608}},	//   wino_, ्षणे_, پھٲن_, _симс, 
   {{0x26c54982,0x9c140cad,0x00000000,0x00000000}},	//   tino_, _kọnp, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x26c54983,0x4dc000cc,0xf53000d8,0x00000000}},	//   rino_, _এডুৱ, бејќ, --, 
   {{0x588401ee,0x00000000,0x00000000,0x00000000}},	//   _кыуа, --, --, --, 
   {{0x26c54984,0x68f8014b,0xeabc0086,0x3cf400dc}},	//   pino_, _ihud, _itùb_, ्षते_, 
   {{0xd7f94985,0x60c40ffb,0x68f804ba,0x6b64005f}},	//   _рус_, _smim, _hhud, mīgā, 
   {{0x68f94986,0xd308004d,0x6b6400e2,0x00000000}},	//   _khud, _rệt_, līgā, --, 
   {{0x442809a5,0xd308004d,0x60c4036e,0x40941188}},	//   _ýa_, _sệt_, _qmim, урот, 
   {{0x68f882cc,0x6b6400e2,0x61100356,0x7c200113}},	//   _mhud, nīgā, _măli, ñorm, 
   {{0x63b87f88,0x68f87cce,0x91fc00e2,0xc1d00139}},	//   mzun, _lhud, teāt, _гөмә, 
   {{0xc8780365,0x270c0fc8,0x63b90d09,0xd308004d}},	//   _ekşi_, ादुर_, lzun, _vệt_, 
   {{0x60c54987,0x63b801f7,0xec74299f,0x68f80142}},	//   _umim, ozun, лпс_, _nhud, 
   {{0x63b94988,0x2d80000f,0xf410008f,0xbea402dd}},	// [210e0] nzun, avje_, מפן_, _бапк, 
   {{0xfeb80502,0x68f8016b,0x63b94989,0x6b6400e2}},	//   _ساخت_, _ahud, izun, dīgā, 
   {{0xaa55498a,0x7e7c0a73,0xdb50168d,0x784405f5}},	//   الما_, _iapp, _ژێر_, гэлж, 
   {{0x270c0d01,0x68f9498b,0x7e7d498c,0x61100276}},	//   ादूर_, _chud, _happ, _căli, 
   {{0x7e7d498d,0x68f86d80,0x3d182ba2,0xe9a000d1}},	//   _kapp, _dhud, _मंडे_, _һарп, 
   {{0x7e7d498e,0x68f8014b,0x63b9498f,0x66e031af}},	//   _japp, _ehud, dzun, боча, 
   {{0x7e7d4990,0x3a38007c,0x00000000,0x00000000}},	//   _mapp, mapp_, --, --, 
   {{0x68f80455,0x3dc404c5,0x3a380250,0x63b80e78}},	//   _ghud, _এডাল, lapp_, fzun, 
   {{0x6b64005f,0xa3e41a04,0xa5040063,0xdddc010f}},	//   cīgā, _मुद_, ћења_, verŝ, 
   {{0x7e7d4991,0xf124d3a6,0x248c04e6,0xe31000c6}},	//   _napp, льмо, _engm_, حبيب, 
   {{0xdddc008f,0xd58403e6,0xb058005b,0x00000000}},	//   terŝ, _ڕێژه_, liäi, --, 
   {{0xb384a2f2,0x7e7c0af5,0x3a394992,0x68f8036e}},	//   _مجته, _aapp, happ_, _xhud, 
   {{0x3a387163,0x7e7c020b,0xdb0456b1,0xceb80075}},	//   kapp_, _bapp, nzió, вән_, 
   {{0x7e7d4993,0x02c443c2,0xa5c00210,0x00000000}},	//   _capp, _кичү, skół, --, 
   {{0x7e7d4994,0x61cc012c,0xdddc00df,0xe0d000f1}},	//   _dapp, हपृष, perŝ, _ډزي_, 
   {{0xd5e806d6,0x7e7d3a3b,0x2d8026e3,0xacf400cf}},	//   _nnḓ, _eapp, rvje_, اسست, 
   {{0x765802d0,0x68f94995,0x709001a9,0x00000000}},	// [210f0] _octy, _rhud, _вақф, --, 
   {{0x1f74ac51,0x61100311,0x6b6400e2,0xdb04012d}},	//   _улья, _săli, vīgā, dzió, 
   {{0x1ed8501f,0x68f827be,0x49754996,0x7dd001ed}},	//   _حبيب_, _phud, рлес, rűsé, 
   {{0x7e7d4997,0x4bc473e5,0x76580072,0x6b6400e2}},	//   _zapp, _көзг, _acty, tīgā, 
   {{0x68f80dc9,0x3a38010a,0x7e7d4998,0x4e183b90}},	//   _vhud, bapp_, _yapp, _दलाई_, 
   {{0x6b6400da,0xe4603535,0x63b94999,0x7e7c0036}},	//   rīgā, şmüş, vzun, _xapp, 
   {{0x5e5800c8,0x68f9499a,0x04b5499b,0x84b4011c}},	//   טיגע_, _thud, исия, ищиц, 
   {{0x63b9499c,0x68f9499d,0x00000000,0x00000000}},	//   tzun, _uhud, --, --, 
   {{0x63b9499e,0xdddc0205,0x4dc000cc,0x00000000}},	//   uzun, kerş, _এডোৱ, --, 
   {{0x63b9499f,0x98480050,0x7980033f,0x82f40640}},	//   rzun, _للہٕ_, łowe, јчиц, 
   {{0x7c200113,0x4adc0243,0x63b81f96,0xdddc0139}},	//   ñork, _मदनव, szun, derş, 
   {{0x7e7d49a0,0xc8b401ad,0xc0e493e4,0x00000000}},	//   _sapp, ंसिट, ромк, --, 
   {{0xd4e40014,0x3a38090c,0x765802d0,0x00000000}},	//   _آنپ, yapp_, _ycty, --, 
   {{0x442d49a1,0xceb40184,0x321c030d,0x7e7c5c40}},	//   lbe_, йҙы_, ccty_, _qapp, 
   {{0x3c4000dd,0x6e340175,0x7e7c0e03,0x442c1418}},	//   _lévő_, _dexb, _vapp, obe_, 
   {{0x442d49a2,0x7e7d49a3,0xed5403b7,0x8cc007f7}},	//   nbe_, _wapp, јот_, रोलो, 
   {{0x442d49a4,0x5a4463eb,0x75c803b9,0x00000000}},	// [21100] ibe_, ймағ, _vәzi, --, 
   {{0x442c27cc,0xb05801f4,0x00000000,0x00000000}},	//   hbe_, viäi, --, --, 
   {{0x442c01ed,0x3a3949a5,0xeabc01ab,0x00000000}},	//   kbe_, rapp_, _stùc_, --, 
   {{0x442c0978,0x9c1400b4,0x3a386445,0xb058005b}},	//   jbe_, _kọmp, sapp_, tiäi, 
   {{0x442d49a6,0xdddc00dd,0xf7700137,0x3a3835f8}},	//   dbe_, merő, تاا_, papp_, 
   {{0x6b88019b,0x442d49a7,0xdb0401ed,0xb058005b}},	//   ægge, ebe_, rzió, riäi, 
   {{0x38540801,0x442c0295,0x66708207,0x00000000}},	//   _възс, fbe_, زدور, --, 
   {{0x442c0570,0xa3e40c2e,0xf3642c51,0xf7703592}},	//   gbe_, _मुह_, атон, _واء_, 
   {{0x38647a1e,0xeabc0428,0xb4d42aa1,0x8880158f}},	//   mfor_, _iwùr_, _सदी_, _ریون, 
   {{0x442d49a8,0xf20485c4,0x386549a9,0xc5fc015b}},	//   abe_, ияно, lfor_, ুড়া_, 
   {{0x442d49aa,0xdddd49ab,0xdb04005a,0xf424005b}},	//   bbe_, verş, nziñ, ääsi_, 
   {{0x38641477,0x61100356,0x7528002f,0x437000db}},	//   nfor_, _nălu, mpfz, تۇۇر, 
   {{0xb37400f2,0xe3b400f3,0x00000000,0x00000000}},	//   _خداش, _кбц_, --, --, 
   {{0xdb04005a,0x386400e4,0x00000000,0x00000000}},	//   kziñ, hfor_, --, --, 
   {{0xf1a80133,0x4c94003b,0x00000000,0x00000000}},	//   _جاشه_, бивс, --, --, 
   {{0xd9040799,0xdddc01ed,0x61100311,0x9f40005a}},	//   _زی_, gerő, _călu, _eziñ_, 
   {{0x2fcc049f,0x38640142,0x00000000,0x00000000}},	// [21110] _ägg_, dfor_, --, --, 
   {{0xe9840640,0x00000000,0x00000000,0x00000000}},	//   ићен, --, --, --, 
   {{0x442d49ac,0x38644cab,0x99d400d1,0xdd840153}},	//   ybe_, ffor_, يتما, _дыяп, 
   {{0xf09d49ad,0x61100356,0x442cb516,0x00000000}},	//   njà_, _gălu, xbe_, --, 
   {{0x3248044e,0x442d49ae,0x3cf41fbc,0x98141291}},	//   ሓሳስባ, vbe_, ्षरे_, زبنا, 
   {{0xb6a149af,0xf09c2b1d,0xd6d80032,0x69c00005}},	//   зишл, hjà_, ҫтә_, únes, 
   {{0x442d49b0,0xd3080051,0x0444068e,0x7c4408a5}},	//   tbe_, _rệp_, бейн, _átrö, 
   {{0x442d19e6,0x9dd80375,0x80c4033f,0x7980012d}},	//   ube_, יווק_, _लगें, łowc, 
   {{0x442d49b1,0x7c202b76,0xd6980064,0x00000000}},	//   rbe_, ñori, _мiро, --, 
   {{0x442c0978,0xf42400c5,0x78b85b7c,0x1634014b}},	//   sbe_, ääri_, _įtvi, _меуя, 
   {{0x442c0978,0x69100327,0x00e401b9,0xd29802d5}},	//   pbe_, _għet, йжон, ртыі_, 
   {{0x9c14063f,0xafd803cd,0xb9dc0092,0x442c0978}},	//   _pọmp, lgøy, _ኤያ_, qbe_, 
   {{0xd308004d,0x80a4036b,0x939408f4,0x249d045b}},	//   _tệp_, لمگن, _وجها, mjum_, 
   {{0x249d49b2,0xafd80217,0x61100356,0x65600051}},	//   ljum_, ngøy, _bălt, otnh, 
   {{0xb05837e9,0x3cf400bc,0x3864015d,0x00000000}},	//   viäv, ्षले_, yfor_, --, 
   {{0xd09400c7,0x249d49b3,0x00000000,0x00000000}},	//   _дшьы, njum_, --, --, 
   {{0xeb940598,0x3864083a,0x8fd549b4,0x22442a1f}},	// [21120] бит_, vfor_, _дәрә, _kdnk_, 
   {{0x61100311,0xeb301b56,0xb05817da,0xdb04005a}},	//   _fălt, سىمد, ghäf, tziñ, 
   {{0xfce549b5,0x8fc4034c,0x249c09f3,0x3864168c}},	//   _гоно, _هزین, kjum_, tfor_, 
   {{0xb4c402e5,0xaef805d5,0x249c002e,0x00000000}},	//   _उगे_, ntùn, jjum_, --, 
   {{0x38645d16,0xb0580724,0xa3e445c7,0x249d49b6}},	//   rfor_, miät, _मुल_, djum_, 
   {{0xafd80158,0xd1d0001f,0xb05802c1,0x66e00212}},	//   ggøy, _ብርቱ_, chäf, поча, 
   {{0x249c01a8,0x38640158,0x89a801d9,0x65600175}},	//   fjum_, pfor_, _پھلہ_, gtnh, 
   {{0x249c08a7,0xb0580724,0x00000000,0x00000000}},	//   gjum_, niät, --, --, 
   {{0x644d49b7,0xb68800ec,0x6d4800dc,0x36341410}},	//   ócia, _ٽپال_, _āgam, _هراس, 
   {{0xe3ac2834,0xe6406ff7,0x2244005a,0x88c4031c}},	//   عري_, _неуп, _cdnk_, _གཏོར, 
   {{0xf09c0228,0xf4841621,0x6a98008f,0x00000000}},	//   tjà_, _гулн, אשינ, --, 
   {{0x9c14063f,0x64a07760,0x249c0210,0xb05800a2}},	//   _dọkp, _наха, cjum_, lnäz, 
   {{0x33f400f9,0x2e4802e8,0x61100356,0xdcfc0356}},	//   _اساس, ляво_, _sălt, zvră, 
   {{0xf1a86e0d,0xf09c0561,0x6110054e,0xd130007b}},	//   _مابه_, sjà_, _pălt, _قمت_, 
   {{0xb0581f65,0x00000000,0x00000000,0x00000000}},	//   vhäf, --, --, --, 
   {{0x8cf41ed2,0x50ac0490,0xa3e40037,0x00000000}},	//   ізац, _चविष, _मुँ_, --, 
   {{0xab8406bb,0x5b143da1,0xe7a401ad,0xa4b40375}},	// [21130] щувк, змут, _कॅंप, צלמה_, 
   {{0x249c0034,0x94f80327,0x00000000,0x00000000}},	//   zjum_, _ཕེའི_, --, --, 
   {{0x249c01a8,0x2d8549b8,0xafd803b2,0xb058007c}},	//   yjum_, _éne_, saød, rhäf, 
   {{0xb05800fd,0x48c400c7,0x00000000,0x00000000}},	//   miäs, цәга, --, --, 
   {{0x46a400a7,0xa2b800bc,0x249c01d5,0xb0580716}},	//   жалв, एसम्, vjum_, liäs, 
   {{0x79800034,0xe9381374,0x00000000,0x00000000}},	//   łowa, _مسرت_, --, --, 
   {{0xf40c04d3,0x045800c6,0x00000000,0x00000000}},	//   ۆڤه_, للغة_, --, --, 
   {{0x032549b9,0x6728525d,0x443949ba,0xb05801f4}},	//   один, ppgj, ús_, nhäd, 
   {{0x249c008c,0x00000000,0x00000000,0x00000000}},	//   rjum_, --, --, --, 
   {{0x68e80225,0x02c410f5,0x42c949bb,0xd5b949bc}},	//   logd, ійно, ргон_, рсә_, 
   {{0x6aa40427,0xcf880a7c,0x1a9c00df,0x00000000}},	//   _mojf, _שט_, טיזע, --, 
   {{0xc6a40116,0x43940a5b,0xc104007b,0x249c031c}},	//   _урғи, _маес, توجي, qjum_, 
   {{0xb058023a,0xe9fc004d,0xe1f00066,0x00000000}},	//   nnäy, _trặc_, _کسش_, --, 
   {{0x645949bd,0xa524003d,0xb058013d,0x00000000}},	//   lgui, _ལྕོག_, fiäs, --, 
   {{0x628149be,0xb058008e,0x00000000,0x00000000}},	//   _iano, giäs, --, --, 
   {{0x628149bf,0x717000b2,0x4554044e,0x64586e16}},	//   _hano, _آهيا, _ዘይነበ, ngui, 
   {{0x628149c0,0xdb70001f,0x6458bf8c,0xbb480a11}},	// [21140] _kano, _አያያዝ_, igui, شلان_, 
   {{0x628149c1,0xb4d409fa,0x6458f17d,0xfaf4109a}},	//   _jano, _सद्_, hgui, ічаю, 
   {{0xb058049f,0xd91050c9,0x628027f8,0x68e82b27}},	//   miär, فیس_, _mano, fogd, 
   {{0xe3a4f122,0xd72401e1,0xb05949c2,0xe88c00ef}},	//   _قر_, _aṣọg, chäd, _pūšļ, 
   {{0x6aa4010f,0x645949c3,0x56942ec9,0xf77000ec}},	//   _fojf, dgui, залт, ڃاڻ_, 
   {{0x628149c4,0xf5241def,0xcb8000d1,0x645800e4}},	//   _nano, офин, _яқуп, egui, 
   {{0xe1e549c5,0x68e83306,0x645801ab,0x2b4c0118}},	//   _آس_, bogd, fgui, ělců_, 
   {{0x628149c6,0x6458efdc,0xe8a002d3,0x798c02d0}},	//   _aano, ggui, ጋጊጾም_, _irbw, 
   {{0xed84001f,0x69100327,0x78a00117,0xa3e400e1}},	//   ፖርተር_, _għeq, mjov, _मुआ_, 
   {{0x62802679,0x64583bd4,0x78a03341,0x63000472}},	//   _cano, agui, ljov, وويل, 
   {{0x628149c7,0x7c240036,0x00000000,0x00000000}},	//   _dano, _ofkr, --, --, 
   {{0x628000fb,0x78a149c8,0x96b80116,0x00000000}},	//   _eano, njov, _туғу_, --, 
   {{0x628149c9,0xb9200ca8,0x00000000,0x00000000}},	//   _fano, _papọ_, --, --, 
   {{0x628149ca,0x7c2549cb,0x798c02d0,0xdb1001e1}},	//   _gano, _afkr, _orbw, _ìdèy, 
   {{0xeca407fa,0xa1303090,0x6ca40945,0x24500150}},	//   ојан, _قريش, ораж, _ءنۇس, 
   {{0x6aa401e4,0xb0580108,0x00000000,0x00000000}},	//   _sojf, ynäy, --, --, 
   {{0x628149cc,0xb058f4b5,0xd13001d9,0xc0d0001f}},	// [21150] _yano, siäs, _غمک_, _የዛሬ_, 
   {{0x6281489f,0xb05801e3,0x6e4002f2,0x00000000}},	//   _xano, ciär, _زۆرم, --, 
   {{0x645949cd,0xec140598,0xd6d0015b,0x6aa401e4}},	//   ygui, _менә_, াকায, _vojf, 
   {{0xd1c402d3,0x78a00023,0x7c200784,0xd7c800f1}},	//   ጸልታ_, gjov, ñort, ښونه_, 
   {{0xb05804e6,0x68e84a97,0x64580728,0x00000000}},	//   chäe, rogd, vgui, --, 
   {{0x3ae40109,0xa524031c,0xd6a800d1,0xb7d03997}},	//   kôpy_, _ལྕུག_, قدىم_, عقوب, 
   {{0x628149ce,0x64581654,0xb058023a,0x044401f4}},	//   _rano, tgui, snäy, пейн, 
   {{0x628149cf,0x645949d0,0xe8d001d9,0x99680014}},	//   _sano, ugui, _کۅچھ, _گمہٕ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x628032ff,0x99680050,0x6b8c0076,0x64581e3d}},	//   _qano, _دمہٕ_, _mrcg, sgui, 
   {{0x62812ef9,0x99980022,0x64580267,0x64b4007b}},	//   _vano, _perũ_, pgui, _وحصر, 
   {{0x628149d1,0x97d801d3,0x82d80166,0x00000000}},	//   _wano, _اظہر_, рдүс_, --, 
   {{0x628149d2,0x443c06a3,0xdd0c0034,0x644802d0}},	//   _tano, _iew_, różn, _idgi, 
   {{0x628003a0,0x443d49d3,0x2bec00af,0xfe4401c6}},	//   _uano, _hew_, _आड़ू_, янго, 
   {{0x443c02bd,0x6b8c045a,0xb058000d,0x7cf8010e}},	//   _kew_, _arcg, riär, bïrl, 
   {{0x443c9560,0x290400cf,0x27fcd96c,0xed540120}},	//   _jew_, ïnal_, _ozun_, џот_, 
   {{0xeb94d1a6,0xd70803d4,0x3058011a,0x00000000}},	// [21160] пит_, ৰীয়া_, _הדפד, --, 
   {{0xbb501c5c,0x9e7402dd,0xb05804e6,0x3000008e}},	//   ﺎﺗﻰ_, _تۇست, rhäe, _языг, 
   {{0x6448e0db,0xbd8949d4,0x00000000,0x00000000}},	//   _odgi, _انجن_, --, --, 
   {{0x443d49d5,0xfce405c5,0x6b8c0076,0x2bc40c6f}},	//   _new_, _хомо, _frcg, _रेका, 
   {{0x7d1c8943,0x00000000,0x00000000,0x00000000}},	//   _hups, --, --, --, 
   {{0xab240c04,0x7d1c02ce,0x443c0798,0xabf8011a}},	//   _хора_, _kups, _aew_, _להכר, 
   {{0x6e200a85,0x443d2bd1,0xeab549d6,0x78a00006}},	//   _ûnbe, _bew_, _эйр_, pjov, 
   {{0x7d1c1682,0x443c020b,0x00000000,0x00000000}},	//   _mups, _cew_, --, --, 
   {{0xe73549d7,0x443d49d8,0x91fc0421,0x395805d5}},	//   _нет_, _dew_, ogāg, lups_, 
   {{0x7d1c127b,0x644949d9,0x00000000,0x00000000}},	//   _oups, _edgi, --, --, 
   {{0x2000009a,0x443cb904,0x7d1d49da,0x066401ec}},	//   _azii_, _few_, _nups, _تاقپ, 
   {{0x443d49db,0x00000000,0x00000000,0x00000000}},	//   _gew_, --, --, --, 
   {{0xe3ac032f,0x3958045a,0xb7c40055,0x00000000}},	//   _مرو_, hups_, bhãų, --, 
   {{0x395949dc,0x443c0210,0x00000000,0x00000000}},	//   kups_, _zew_, --, --, 
   {{0xdd94a373,0x443d49dd,0x61140356,0x00000000}},	//   нары, _yew_, _tălp, --, 
   {{0x6d7002d3,0x443c1574,0x7d1d49de,0x39580327}},	//   _ኣካይዳ_, _xew_, _dups, dups_, 
   {{0x2bc40db3,0x9cc80588,0x9f5402d5,0x7f440175}},	// [21170] _रेखा, чыра_, _звыч, cskq, 
   {{0x50580050,0xf40c03d4,0x00000000,0x00000000}},	//   _أکس_, _সভাৰ_, --, --, 
   {{0x6cb00022,0xb058002f,0x6d5402f0,0x8c18009f}},	//   _зинӡ, chäc, ýbač, _ويدر_, 
   {{0x47d4314c,0xda0807c0,0x00000000,0x00000000}},	//   ويار, سينه_, --, --, 
   {{0x443d49df,0x6d4517df,0x9be402bf,0x3ebc0153}},	//   _rew_, lsja, _зірк, šytų_, 
   {{0x443d49e0,0x6f1c02b9,0x9a84e450,0x00000000}},	//   _sew_, _muqc, _пусл, --, 
   {{0x6d4549e1,0x443c0204,0x7c20627e,0x850403e6}},	//   nsja, _pew_, žore, ووتن, 
   {{0x76b424a5,0x443c0393,0x27fc005a,0xdbe4020c}},	//   зләр_, _qew_, _tzun_, féèr, 
   {{0xa3e42068,0x27fd49e2,0xd5b800b8,0x6f1c014f}},	//   _मुख_, _uzun_, _agād_, _nuqc, 
   {{0x443c4c86,0x04fc015b,0x6d440037,0xe3c001c6}},	//   _wew_, ঁদের_, ksja, дрүү, 
   {{0x443c0134,0xc0e40261,0x6d4416a3,0x00000000}},	//   _tew_, донк, jsja, --, 
   {{0x6448019b,0x6f1c0477,0x7d1d1d50,0x6d44229b}},	//   _udgi, _buqc, _rups, dsja, 
   {{0x39580036,0x6d4402d0,0x91fc00de,0x00000000}},	//   zups_, esja, egād, --, 
   {{0x6f1c014f,0x6738009f,0xa3d00254,0x00000000}},	//   _duqc, _mwuj, _हेय_, --, 
   {{0x914c1aac,0x9fa149e3,0xd1240150,0x92880a7b}},	//   _tɛ́_, _méér_, _كةيى, _رئوف_, 
   {{0xc1040597,0x9fa000e8,0x51a80150,0xe8dc010e}},	//   _توبي, _léér_, _ءدوپ_, _maỳa_, 
   {{0x6d4400af,0xd05c016b,0x6f140175,0xa3d009fa}},	// [21180] asja, hosɛ, _fixc, _हेम_, 
   {{0xd9c404c5,0x7d1c1577,0x6d4402d0,0x4bd80108}},	//   ্থসম, _tups, bsja, чься_, 
   {{0x67383731,0xa96400a7,0x00000000,0x00000000}},	//   _awuj, диха_, --, --, 
   {{0x67380223,0x395949e4,0x6f1c0477,0x674000d1}},	//   _bwuj, rups_, _yuqc, ھپىك, 
   {{0xb9041dd1,0x7c340588,0x3b080276,0x00000000}},	//   _पद_, mbyr, _мемо_, --, 
   {{0x395949e5,0x7c346525,0x66700222,0xd05c013f}},	//   pups_, lbyr, ندىر, fosɛ, 
   {{0x6738014b,0x692001c6,0xa9200153,0x00000000}},	//   _ewuj, _амса, _адсл, --, 
   {{0x2eb810eb,0x7c344699,0xd2500214,0x00000000}},	//   _उत्त, nbyr, گند_, --, 
   {{0xc4442756,0x13f549e6,0x00000000,0x00000000}},	//   ریون_, эзия, --, --, 
   {{0xd2500502,0x27b119ba,0x6d4402d0,0xa3e4000d}},	//   دند_, _шәхс, ysja, _मुओ_, 
   {{0x6f140784,0x6f1cdaaa,0x3f840010,0x0664568c}},	//   _rixc, _suqc, _šoup_, _سالپ, 
   {{0xe5e50b79,0x9fa001a4,0x6f1c0455,0x674400a2}},	//   _غزلی, _zéér_, _puqc, _ärjä, 
   {{0x7c3400b5,0x6f1549e7,0xd2500014,0xb4d80073}},	//   dbyr, _pixc, _یچھ_, डची_, 
   {{0x6d4549e8,0x7c34062c,0x00000000,0x00000000}},	//   tsja, ebyr, --, --, 
   {{0xf1a002ab,0x6f1c0455,0x737400c7,0xaef801ab}},	//   _ओपिन, _wuqc, _хыҵх, ntùi, 
   {{0x6d4549e9,0x7c3549ea,0x6f1c0455,0x7c200309}},	//   rsja, gbyr, _tuqc, ñorp, 
   {{0xce9400a7,0xaa642be9,0xaf0400db,0x4bf8009f}},	// [21190] _запъ, дтек, _очок, سبرگ_, 
   {{0x67380223,0x91fc00e2,0x6d4403ac,0x00000000}},	//   _rwuj, pgād, psja, --, 
   {{0x7c340363,0x9fa0002e,0x644c01d3,0xad2405af}},	//   bbyr, _réér_, ócik, _ترخو, 
   {{0x2bc80640,0xa3e4033f,0x18a40212,0x48242b62}},	//   _дуго_, _मुझ_, каєм, رىتق, 
   {{0x981406f6,0x2d840142,0x00000000,0x00000000}},	//   نبها, _âneb_, --, --, 
   {{0xc8c8009a,0x5694004e,0x00000000,0x00000000}},	//   _کورن_, качт, --, --, 
   {{0x47dc00cc,0x00000000,0x00000000,0x00000000}},	//   _বৰশী, --, --, --, 
   {{0x9fa149eb,0x9f440200,0x00000000,0x00000000}},	//   _wéér_, çmë_, --, --, 
   {{0x67390d18,0xd05c0134,0x668001b9,0x58d4030d}},	//   _uwuj, sosɛ, _لیشل, _ротт, 
   {{0x237c0034,0x8c480139,0x02b80ebb,0x81c857c6}},	//   rwuj_, _huşı, इसेन, згов_, 
   {{0xe4a549ec,0x56940f5c,0x2bc40406,0x8c4800fd}},	//   _ордо, _јахт, _रेघा, _kuşı, 
   {{0xf99004ac,0xc610009e,0xdbe549ed,0x00000000}},	//   ארט_, _স্থা_, séér, --, 
   {{0xe8dc00b4,0x42cc00bd,0x7c34007c,0x00000000}},	//   _abịa_, রকৌশ, vbyr, --, 
   {{0x3ebc066a,0x7d040327,0x83fc01d3,0x00000000}},	//   ótt_, _shks, ggőe, --, 
   {{0xb8d0031c,0xa3d002ab,0x7c34369d,0xb0583bba}},	//   _ཟྭ_, _हेत_, tbyr, mhän, 
   {{0x6d480882,0xb0583b52,0xd17401ee,0xd1b80244}},	//   _āgat, lhän, _рышы, _تاها_, 
   {{0x2b480165,0xcee80451,0xbb500150,0x00000000}},	// [211a0] _cvcc_, _ڪرين_, _ﺎﻋﻲ_, --, 
   {{0xea8549ee,0xb05949ef,0x25a80055,0x0ae80472}},	//   нбул_, nhän, _māṇṭ, ورلي_, 
   {{0xcee84957,0xb0582305,0xe94400f2,0xdb100ca8}},	//   _ترين_, ihän, فرنی, _ìdíy, 
   {{0xb058002f,0x00000000,0x00000000,0x00000000}},	//   hhän, --, --, --, 
   {{0x2ce80135,0xeb9549f0,0x68e149f1,0x00000000}},	//   _རྩིབ, _зия_, énda, --, 
   {{0xc8e8230e,0x387000b8,0x00000000,0x00000000}},	//   टकॉम_, _śarā_, --, --, 
   {{0xd94400c7,0xb058343a,0xd5b0007b,0xd488009d}},	//   _рҵеи, dhän, شفة_, дөлж_, 
   {{0xb4d80073,0xaef800a3,0x00000000,0x00000000}},	//   डचे_, rtùi, --, --, 
   {{0xb0581021,0xe61419b8,0xa34001c0,0x00000000}},	//   fhän, мдә_, лээл, --, 
   {{0x168404d3,0x00000000,0x00000000,0x00000000}},	//   _جارێ, --, --, --, 
   {{0x6d1c032c,0x5f94039b,0xd5a4136e,0x00000000}},	//   _मूंग_, ҳият, _جلای, --, 
   {{0xd25008f0,0x00000000,0x00000000,0x00000000}},	//   دنگ_, --, --, --, 
   {{0xb0580730,0x5f940801,0xdd9402dd,0xdddc0064}},	//   bhän, гият, қаты, berū, 
   {{0xb0581452,0xb60402f0,0x6aac0210,0x00000000}},	//   chän, _etáž, _टवेर, --, 
   {{0x418460c6,0x202400ae,0x6d4800b8,0x6260119e}},	//   _атығ, íriú_, _āgas, _свја, 
   {{0xdc8800a8,0x6380035b,0x7ae0003e,0xad1000d1}},	//   нсул_, _ргәа, éotn, упбә, 
   {{0xd1d40092,0x00000000,0x00000000,0x00000000}},	// [211b0] _የራቀ_, --, --, --, 
   {{0xdef800b7,0x8b700023,0x00000000,0x00000000}},	//   ሊዝኛ_, _ስክፍታ_, --, --, 
   {{0x2d900005,0x00000000,0x00000000,0x00000000}},	//   _urxe_, --, --, --, 
   {{0x2b48011c,0x87f805f5,0x38bc00b0,0x8c4800fd}},	//   _tvcc_, мэлт_, _pïra_, _quşı, 
   {{0xd83801c6,0x81e000fe,0xb05801f4,0x00000000}},	//   хэх_, _দৰা_, yhän, --, 
   {{0xd8b40327,0x44280327,0xf8b400cd,0x26e8230e}},	//   དྲཏྲ, _ża_, _अकथय, टवेर_, 
   {{0x38bc00b0,0xb5c002bf,0x00000000,0x00000000}},	//   _wïra_, ийшл, --, --, 
   {{0x58840032,0xb05949f2,0x00000000,0x00000000}},	//   _йыуа, whän, --, --, 
   {{0xd7740c75,0x99980356,0xb058002f,0x00000000}},	//   _مالع, _terţ_, thän, --, 
   {{0xb9d402d3,0xb60402fb,0xb0581196,0x290c01a9}},	//   _ጸባ_, _stáž, nkäf, lmga_, 
   {{0x76c801d9,0xb0587a45,0xafd803b2,0x00000000}},	//   _تُلہ_, rhän, saøl, --, 
   {{0x290c0093,0xb05949f3,0x3cc400e1,0x00000000}},	//   nmga_, shän, रोफ़ा, --, 
   {{0xb05801e6,0x00000000,0x00000000,0x00000000}},	//   mhäl, --, --, --, 
   {{0x7980068f,0xb05801e3,0x6d480055,0x00000000}},	//   łowi, lhäl, _āgar, --, 
   {{0x3f8002c4,0x200401f1,0xb0580e78,0x290c022e}},	//   swku_, ťmi_, chäo, kmga_, 
   {{0xb0583b52,0x5dc401ec,0x290c022e,0x00000000}},	//   nhäl, _ەمدە, jmga_, --, 
   {{0x2abc00d2,0x2c0400cd,0x2004000d,0x00000000}},	// [211c0] _sîba_, _शरणं_, ümid_, --, 
   {{0xb058002f,0xca6401ec,0xeac000d8,0x00000000}},	//   hhäl, леуқ, абуп, --, 
   {{0x692149f4,0xae540375,0x7d080640,0x41c00764}},	//   амха, _בסיס_, _оног_, शनिस, 
   {{0x290c089c,0xe6900214,0xab800092,0x00000000}},	//   gmga_, یلند, _ዓዋዲው_, --, 
   {{0xf090008d,0xdd3c0113,0xb058007c,0x567800f5}},	//   ינא_, yńśy, dhäl, ебля_, 
   {{0xc5ac00fe,0x00000000,0x00000000,0x00000000}},	//   _কেইপ, --, --, --, 
   {{0xa9a149f5,0xb0583b52,0x00000000,0x00000000}},	//   _кирд, fhäl, --, --, 
   {{0x2a040032,0x01d4009e,0xf1c4022a,0xb4bc012d}},	//   _респ_, _সুভদ, ťáku_, ीफे_, 
   {{0xc32c4d2d,0x69e40311,0xa5040063,0xb0580139}},	//   كەن_, ăreţ, њења_, lkäg, 
   {{0x55c400d1,0xe7340835,0xb0580139,0x00000000}},	//   _йазғ, _реф_, ahäl, --, 
   {{0xe3ad49f6,0xb464ee17,0xb0580139,0x00000000}},	//   مری_, _акел, bhäl, --, 
   {{0xa3d0000d,0xb058002f,0x83fc01d3,0x8f3400d8}},	//   _हेव_, chäl, tfőt, лемц, 
   {{0xe700004d,0x00000000,0x00000000,0x00000000}},	//   _hướ, --, --, --, 
   {{0x290c2dbe,0xafd80162,0x9f345074,0xb058013d}},	//   zmga_, laøk, рері, kkäg, 
   {{0x1df8b0b9,0xacf401b9,0x4fc000d1,0x00000000}},	//   веры_, نسرت, شەھە, --, 
   {{0xe0d01c4e,0x2d1801f2,0x00000000,0x00000000}},	//   _وزي_, _ụgbụ_, --, --, 
   {{0xe7000208,0x31e110af,0x290c022e,0xb058007c}},	// [211d0] _lướ, _पशुध, vmga_, nhäm, 
   {{0x5a3549b9,0x00000000,0x00000000,0x00000000}},	//   инут, --, --, --, 
   {{0x68e01280,0xe70001fb,0xafd803b2,0xb0587f4e}},	//   éndo, _nướ, kaøk, rkäf, 
   {{0x4bc4013d,0x6830035b,0xad6400ec,0x00000000}},	//   _йөзг, рҭат, _ٻاگه, --, 
   {{0xe9fc001e,0xa2600208,0x2fc8010a,0x999802f0}},	//   _trắc_, _buồ, nzcg_, _verš_, 
   {{0xe700004d,0xa2600051,0xda340006,0x290c5ee1}},	//   _bướ, _cuồ, _веры, smga_, 
   {{0x451949f7,0xb0592671,0xe7000208,0x9a8549f8}},	//   нция_, thäl, _cướ, _туял, 
   {{0xc48549f9,0xe700004d,0xe57401e1,0x00000000}},	//   улик, _dướ, _òyíì, --, 
   {{0xb05949fa,0x00000000,0x00000000,0x00000000}},	//   rhäl, --, --, --, 
   {{0xd6d801c0,0x56940276,0xb058343a,0x572400d1}},	//   _итх_, _каут, shäl, _ئىلك, 
   {{0x0164173d,0xa3d000bc,0x312001c6,0xb3400135}},	//   ыкно, _हेर_, йдэг, ħħal, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb0580e78,0x7fd402dd,0x00000000,0x00000000}},	//   chäm, уіні, --, --, 
   {{0x442d49fb,0x12c400db,0x00000000,0x00000000}},	//   lce_, _ۅتۉپ, --, --, 
   {{0x8db402bf,0x527549fc,0x442c0072,0x6b980135}},	//   асті, _خانز, oce_, _ġuga, 
   {{0xfca80014,0x69100135,0x6b9839ae,0x00000000}},	//   رازو_, _għex, _šuga, --, 
   {{0x60c549fd,0x5ba40184,0x26c549fe,0x442d49ff}},	// [211e0] _ilim, шлағ, khno_, ice_, 
   {{0xdd04538f,0x442d4a00,0x26c409a8,0x02e028d4}},	//   ırır, hce_, jhno_, _पदोन, 
   {{0x442c038e,0x26c54a01,0xd9101208,0xafd803b2}},	//   kce_, dhno_, قیس_, yaøk, 
   {{0x442d4a02,0x6fa8015b,0xb0583407,0x4c340153}},	//   jce_, _চেয়ে, rkäg, _вэрт, 
   {{0x60c45053,0x442cb7f9,0xa3d004fa,0xe80c00af}},	//   _mlim, dce_, _हेल_, ़ेला_, 
   {{0x60c54a03,0xf62807d2,0x442d4a04,0x75880798}},	//   _llim, رستى_, ece_, есив_, 
   {{0xadc00022,0x00000000,0x00000000,0x00000000}},	//   _osẽg, --, --, --, 
   {{0xc7641e4a,0x26c4058a,0x29045c17,0x6900000d}},	//   _چالى, ahno_, ïnat_, nõel, 
   {{0xeabc0428,0xc7640ef6,0xafd80162,0xb06000a2}},	//   _itùr_, _نالى, raøk, njäň, 
   {{0x60c54a05,0x442d4a06,0x26c40316,0x386400a9}},	//   _alim, ace_, chno_, lgor_, 
   {{0x60c54a07,0x442c0316,0xb05801e3,0x00000000}},	//   _blim, bce_, shäm, --, 
   {{0x442d4a08,0x38654a09,0x2bec00bd,0x76480252}},	//   cce_, ngor_, চেয়ে_, lafy, 
   {{0x60c40083,0xa504030d,0xde500240,0xd54401e1}},	//   _dlim, _сеца_, _ክምዝገ, bẹ̀h, 
   {{0x386403cb,0xb64404ce,0xdef80137,0xb0580166}},	//   hgor_, _ｉｔ_, гыс_, hiäx, 
   {{0x60c4038f,0xd1304bf3,0xe7d8012c,0xb05801f4}},	//   _flim, _بمب_, _मेनप, nhäk, 
   {{0xd1387063,0xd7c40490,0xf044023a,0x9c454a0a}},	//   mpą_, वनाच, _сэко, йхул, 
   {{0xafd8037e,0xd1380024,0x386401d5,0x00000000}},	// [211f0] dbøg, lpą_, dgor_, --, 
   {{0x442d4a0b,0xb05801b8,0x6e640063,0xceb800b1}},	//   zce_, skäd, _стиж, _рәм_, 
   {{0x442d4a0c,0x60c402f6,0xda794a0d,0x76494a0e}},	//   yce_, _ylim, ыят_, dafy, 
   {{0x60c40395,0x3864c8bb,0x442c0548,0x4c954357}},	//   _xlim, ggor_, xce_, _тимс, 
   {{0x07a44140,0xa3d02ce1,0xc7a47ffd,0x764802d2}},	//   ралн, _हें_, рилк, fafy, 
   {{0x05554a0f,0x764807a8,0xeabc0086,0x442c0034}},	//   атия, gafy, _etùr_, wce_, 
   {{0x442c03f8,0xf09c067c,0x2904068c,0x386401a9}},	//   tce_, nmàs_, ïnas_, bgor_, 
   {{0x442d4a10,0x4734154e,0x26c4013f,0xb058013d}},	//   uce_, _внас, shno_, ciäx, 
   {{0x442d4a11,0x68f94a12,0xd79400a7,0x2b9c037e}},	//   rce_, _ikud, _литъ, のcd_, 
   {{0x442d4a13,0x60c54a14,0x27fd4a15,0xd7f800a8}},	//   sce_, _slim, _iyun_, _сус_, 
   {{0x60c54a16,0x442c0b9d,0x00e401a9,0x6f7c0150}},	//   _plim, pce_, ижон, _ﺩﻴﻨﺎ_, 
   {{0x65614a17,0x272804ce,0x84240075,0x27fc00f2}},	//   munh, _køn_, _ئىشن, _kyun_, 
   {{0x68f801f7,0xef1c0213,0x6f600138,0x65600108}},	//   _mkud, vvür_, овяз, lunh, 
   {{0x291c57f0,0x63b94a18,0x27283774,0x94a80022}},	//   _liua_, myun, _møn_, _атәа_, 
   {{0x68f889da,0x27294a19,0x63b94a1a,0x60c402c4}},	//   _okud, _løn_, lyun, _tlim, 
   {{0x60c54a1b,0xdcfc1326,0x27fd487f,0x22454a1c}},	//   _ulim, tvrđ, _oyun_, _henk_, 
   {{0x63b94a1d,0xfa354a1e,0x27fc020c,0x65614a1f}},	// [21200] nyun, لراد, _nyun_, hunh, 
   {{0xc8794a20,0x63b80357,0x291c7d7d,0x68f92ff9}},	//   _abş_, iyun, _aiua_, _akud, 
   {{0x63b94a21,0x27fd4a22,0x21242508,0x21200c6a}},	//   hyun, _ayun_, _junh_, _kiih_, 
   {{0x63b94a23,0x656005b8,0x27fc213f,0x27294a24}},	//   kyun, dunh, _byun_, _bøn_, 
   {{0x38654a25,0x163406bb,0x291c0393,0x63b80113}},	//   rgor_, беля, _diua_, jyun, 
   {{0x68f83e6e,0x63b94a26,0x2244525e,0x65600099}},	//   _ekud, dyun, _nenk_, funh, 
   {{0x65600f71,0x27fc0241,0x63b82ad1,0x386403cb}},	//   gunh, _eyun_, eyun, pgor_, 
   {{0x2000013f,0x21200fe3,0x291c01fb,0x7980033f}},	//   _oyii_, _niih_, _giua_, łows, 
   {{0x22454a27,0x63b94a28,0xdddc01e4,0x20000248}},	//   _benk_, gyun, derŭ, _nyii_, 
   {{0x291c00a8,0x65611ca2,0x248c0042,0x2244e0ea}},	//   _ziua_, bunh, _eagm_, _cenk_, 
   {{0x22454a29,0x65611b8c,0x200000ca,0x21614a2a}},	//   _denk_, cunh, _ayii_, отяг, 
   {{0x64a14a2b,0x63b94a2c,0xd1380153,0xb05801f4}},	//   _маха, byun, rpą_, ohäi, 
   {{0xceb919ba,0xd5e80084,0x22454a2d,0x63b81e91}},	//   гән_, _maḓ, _fenk_, cyun, 
   {{0x22454a2e,0x00000000,0x00000000,0x00000000}},	//   _genk_, --, --, --, 
   {{0x20003185,0xec694a2f,0xd5b80171,0x6f7c0150}},	//   _eyii_, крак_, _ogām_, _ﺩﻴﻬﺎ_, 
   {{0x91fc02b5,0xa13002da,0xdddc0c5e,0x00000000}},	//   ngām, _بروش, bdrž, --, 
   {{0x89d94a30,0x291c00b0,0x32000131,0x4a5400cf}},	// [21210] گوار_, _riua_, _دېھق, йкас, 
   {{0x68f94a31,0x291c1132,0xd5b80055,0x6560014f}},	//   _skud, _siua_, _agām_, yunh, 
   {{0x89d9069e,0x2728eda6,0x291c5427,0x63b80369}},	//   دوار_, _søn_, _piua_, zyun, 
   {{0x65614a32,0x63b8011f,0x00000000,0x00000000}},	//   vunh, yyun, --, --, 
   {{0x291c068c,0x2bc80064,0x63b84f74,0x88bc0055}},	//   _viua_, _руно_, xyun, _niśe, 
   {{0x65614a33,0xdc3c031c,0xec3001ec,0x070806c2}},	//   tunh, _iġġo, _دوڭگ, ديتي_, 
   {{0xa8a54a34,0x22454a35,0xdddd4a36,0xc0ec001f}},	//   _крак, _renk_, zdrž, ቆጠሩ_, 
   {{0x68f94a37,0x2244c87c,0x63b94a38,0x65614a39}},	//   _ukud, _senk_, tyun, runh, 
   {{0x63b80cfe,0x27fc6b86,0x22454a3a,0x6560067c}},	//   uyun, _uyun_, _penk_, sunh, 
   {{0x65614a3b,0x212006d1,0x984801d9,0x88bc0055}},	//   punh, _siih_, _ملہٕ_, _diśe, 
   {{0x63b94a3c,0x95c84bea,0x2244007f,0x7ae10ac7}},	//   syun, _куца_, _venk_, éoti, 
   {{0x39780302,0x200002c4,0x224405e4,0x63b94a3d}},	//   נטרנ, _pyii_, _wenk_, pyun, 
   {{0x22454a3e,0x63b94a3f,0x80a82f0a,0xd178009d}},	//   _tenk_, qyun, टाबे, гөөх_, 
   {{0x91fc00e2,0x02c4004e,0x13040153,0x00000000}},	//   igāj, _ыйло, _дзім, --, 
   {{0xed554a40,0xdc3c003d,0x7194cf73,0x00000000}},	//   йор_, _aġġo, _هنوز_, --, 
   {{0xbc180220,0xfc24015b,0xb05801f4,0xa2800066}},	//   гізі_, বর্ষ_, yhäi, _ایگو, 
   {{0x8b641955,0xa0040014,0xbf64007b,0xc10400ec}},	// [21220] قالم, _گژھى, _ادعو, _پوکي, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc0ec001f,0xef1400a8,0xb05800b0,0x00000000}},	//   ቆጠር_, _ымь_, whäi, --, 
   {{0xa3c40490,0xafd80158,0x77c8005b,0x00000000}},	//   ईना_, sbøe, ллег_, --, 
   {{0x7d14e1ef,0x4b540801,0x00000000,0x00000000}},	//   mmys, _мърт, --, --, 
   {{0xf1c8038e,0xf87400b2,0x356800d8,0xe71431b1}},	//   ानमन, _گهرج, грин_, مينت_, 
   {{0xb0594a41,0xe9fc0208,0x667000db,0x00000000}},	//   chäw, _trạc_, سدور, --, 
   {{0x82540020,0x7d154a42,0xe9d4014b,0x52c00709}},	//   _መሠረታ, nmys, _укс_, एस्स, 
   {{0x060801e0,0xe49450c0,0x00000000,0x00000000}},	//   лмәҫ_, скыч_, --, --, 
   {{0x88bc0a28,0x52d80212,0x92580120,0x80d401ad}},	//   _viśe, рмою_, јант_, मोसे, 
   {{0x6e20000f,0x3604088c,0x32080b1a,0xe5a00108}},	//   _ûnbi, _اواف, åby_, _нифи, 
   {{0x7c24003e,0xa5040b87,0x92a801d3,0xc61000cc}},	//   _ngkr, _леха_, ائکہ_, _স্কা_, 
   {{0x68e13675,0x7d140306,0x74140472,0xa4f80677}},	//   éndi, dmys, _اوشا, _גלאט, 
   {{0x7d1401f1,0x931401d5,0x91fc0374,0x9e349960}},	//   emys, _بوتش, ngāk, зерч, 
   {{0x91fc005f,0x7d1402d0,0x00000000,0x00000000}},	//   zgāj, fmys, --, --, 
   {{0xd9054a43,0x00000000,0x00000000,0x00000000}},	//   _سی_, --, --, --, 
   {{0x88bc0034,0x75214a44,0x00000000,0x00000000}},	// [21230] _liśc, _mioz, --, --, 
   {{0x61fc01d3,0x7d140363,0x9be40212,0xa92801ec}},	//   _ízlé, amys, чіск, гіде_, 
   {{0x88bc0882,0x798c02d0,0x3ebd4a45,0x65bc01e1}},	//   _niśc, _csbw, ötte_, _màhú, 
   {{0x75200109,0xe8494a46,0xdddc0356,0x07a4035b}},	//   _nioz, اجان_, serţ, ҩаҧн, 
   {{0xdddc0311,0x19580150,0x00000000,0x00000000}},	//   perţ, _қаты_, --, --, 
   {{0x91fc005f,0xe80c0034,0xe6640107,0xb6a00116}},	//   rgāj, ़ेगा_, стдо, дишл, 
   {{0x03185d28,0x5fe002ab,0xb0580112,0x1efc010f}},	//   یتخت_, _पेनल, lhäu, אלגע, 
   {{0x9a880050,0x00000000,0x00000000,0x00000000}},	//   _پنہٕ_, --, --, --, 
   {{0x42c83db0,0xb05803fa,0x752001c6,0x732401c6}},	//   игин_, nhäu, _dioz, ожыг_, 
   {{0xe8d001d9,0x7d154a47,0x798c015d,0x00000000}},	//   _بۅچھ, zmys, _ysbw, --, 
   {{0x75200109,0x7d154a48,0x91fc02b5,0xdddd4a49}},	//   _fioz, ymys, ngāh, kerš, 
   {{0xb058023a,0x2d0005d7,0x6b8c0210,0x00000000}},	//   tkäa, लतोल_, _oscg, --, 
   {{0xfc4401a2,0xb7780055,0x00000000,0x00000000}},	//   šíka_, _veṇā, --, --, 
   {{0x64494a4a,0xc0cc02d3,0x752001c4,0x00000000}},	//   _hegi, _ጥዑም_, _zioz, --, 
   {{0x644844bf,0xdddc110c,0x7d1440d6,0xc8b8033f}},	//   _kegi, ferš, tmys, _आवंट, 
   {{0xb0594a4b,0x200c0213,0x00000000,0x00000000}},	//   lkän, ədin_, --, --, 
   {{0xeb954a4c,0x7d14311d,0xb058002f,0x00000000}},	// [21240] оит_, rmys, ghäu, --, 
   {{0x7d1400bc,0xb0594a4d,0xafe0010a,0x00000000}},	//   smys, nkän, _цоьл, --, 
   {{0xdddc5160,0xe9441079,0x798c02d0,0xd5d8000d}},	//   berš, قرنی, _qsbw, _भेंज, 
   {{0x64494a4e,0xa8a04c70,0xb178008f,0xb0580113}},	//   _negi, дршк, יטער, hkän, 
   {{0xeb954a4f,0xb0594a50,0x16c401e0,0x16340395}},	//   _дия_, phäv, пҡан, пеля, 
   {{0x64494a51,0xb0580bc9,0x798c02d0,0x4a740150}},	//   _aegi, jkän, _tsbw, _ныст, 
   {{0xb058049f,0xe5a00640,0x91fc1c52,0xb4b000d1}},	//   dkän, дији, rgāk, дийә, 
   {{0x64494a52,0xb05801f4,0x54540902,0xa7600139}},	//   _cegi, nhät, чвит, чкәд, 
   {{0x64494a53,0xfd4c02e3,0x68e0026c,0xe7354a54}},	//   _degi, takị, ènde, _мет_, 
   {{0x645402a8,0x6448e381,0x68e000d2,0xb0580267}},	//   _ɗaiɗ, _eegi, éndv, gkän, 
   {{0x64480436,0x75200798,0x76580175,0x88bd4a55}},	//   _fegi, _tioz, _idty, _hiśa, 
   {{0x6ab42d8f,0xd5b80053,0xefd00020,0x64486729}},	//   _आक्र, _ngāi_, _ከላይ_, _gegi, 
   {{0xe4d40345,0x00000000,0x00000000,0x00000000}},	//   _بونت_, --, --, --, 
   {{0xf1a804d3,0xd244001f,0x69b8012d,0xb058002f}},	//   _نابه_, _የበኩሉ, _एथली, vhäu, 
   {{0x3f9c04fe,0xdd986b10,0x64494a56,0x77600007}},	//   ātua_, ошт_, _yegi, hrox, 
   {{0xe9a86c72,0xb0580112,0xfee80150,0x00000000}},	//   یدان_, thäu, _қуық_, --, 
   {{0x60c036bf,0xd13c001f,0x88bc00cd,0xb05801f4}},	// [21250] ömme, _የተቃው, _niśa, lkäo, 
   {{0xfd540882,0x77614a57,0xb0580112,0x7c3806be}},	//   hmaṇ, drox, rhäu, _ğtre, 
   {{0xb0580112,0x7c380356,0xdddc58b9,0xf1c800cd}},	//   shäu, _ştre, perš, ानिन, 
   {{0xb0581a80,0x7644013f,0x76580334,0x6d5402d0}},	//   chät, _ɑkye, _adty, _ivxa, 
   {{0x6b8c02d0,0xb0581b99,0x77600166,0xd838009d}},	//   _uscg, lhäs, grox, цэх_, 
   {{0x64494a58,0xf1c8543b,0xf424023a,0x88bc00dc}},	//   _segi, ानान, ääni_, _diśa, 
   {{0x64494a59,0x19583c8f,0xb05801e3,0x758000e5}},	//   _pegi, _мары_, vkän, ٹینم, 
   {{0xe78416c3,0xa3c400bc,0x00000000,0x00000000}},	//   _музо, ईनल_, --, --, 
   {{0x64494a5a,0xb0580724,0x7760004e,0xb0ac00ab}},	//   _vegi, tkän, crox, टानग, 
   {{0x04fc00bd,0x6738d853,0x4254b190,0x91fc0374}},	//   ুদের_, _ituj, чтит, ngāw, 
   {{0x64494a5b,0xb0594a5c,0x68e8004d,0x00000000}},	//   _tegi, rkän, ongd, --, 
   {{0xb0594a5d,0x147418fd,0xeb9c01bf,0xb4b40304}},	//   skän, _يانج, _orø_, _нихә, 
   {{0xa3d00574,0xb0580bc9,0x2004008c,0x03a400c2}},	//   _हेच_, pkän, æmi_, _хило, 
   {{0xb0594a5e,0x62200150,0x614004b3,0x2a740092}},	//   lkäl, _قوشە, _قىتە, _አማኞች_, 
   {{0x6da06145,0x77600369,0x7c880023,0xb05801e3}},	//   нира, zrox, _ብጽሑፍ_, ghäs, 
   {{0xb0580822,0x00000000,0x00000000,0x00000000}},	//   nkäl, --, --, --, 
   {{0x67380211,0xf2e4036b,0xbb484caa,0xe7d8000d}},	// [21260] _ntuj, _ذکیه_, صلان_, _मेलप, 
   {{0x80a80d01,0x3f907004,0xec1001d5,0xb0581572}},	//   टावे, _isyu_, رولد, hkäl, 
   {{0x67394a5f,0x98b00552,0xafd8072b,0x83fc00e5}},	//   _atuj, šači_, nbøn, gfőz, 
   {{0xeb9c2188,0x88bc00b8,0xb05801e3,0x00000000}},	//   _frø_, _piśa, lhär, --, 
   {{0x656003fa,0x569401c0,0x3eb80171,0xb058007c}},	//   ernh, далт, _kopt_, dkäl, 
   {{0x9964012c,0x7e6c0098,0x7c34036e,0x77614a60}},	//   může_, ngbp, lcyr, rrox, 
   {{0x67394a61,0x9d00015b,0xe1e415eb,0xc95438be}},	//   _etuj, ্দীন_, _أس_, _отты, 
   {{0x77614a62,0x7afd4a63,0x3eb80477,0xf3641c56}},	//   prox, lopt, _lopt_, птон, 
   {{0xc32c49c6,0xfa281e81,0x687031f6,0xfd540a28}},	//   لەن_, _སྔོན_, _سُلط, rmaṇ, 
   {{0xd2500214,0xe3ac01d3,0x765801bf,0xb05801f4}},	//   خند_, چری_, _udty, yhäs, 
   {{0xe3ad4a64,0xf5a404a9,0xa6380375,0xb05804ab}},	//   نری_, _хәлқ_, _הגבר, dhär, 
   {{0x7afd4a65,0x234404fb,0xa190177b,0xc85000b7}},	//   hopt, _کلوپ_, хаюч, _ቅዱሳን, 
   {{0x3eb8004e,0xa4b40375,0x71240014,0x00000000}},	//   _bopt_, _מלאה_, _کرتل, --, 
   {{0x3eb80276,0xe2954a66,0xafd8003b,0xe1ec01b9}},	//   _copt_, _нач_, bbøn, ئسی_, 
   {{0x68e94a67,0x3ebcee18,0x200c00ac,0x3eb80175}},	//   yngd, ötta_, ədim_, _dopt_, 
   {{0xfbdc0574,0x3eb80c67,0x40e40220,0xf1b801fb}},	//   _नेहम, _eopt_, _осығ, _ngơi_, 
   {{0xaca0063f,0xb0594a68,0xc0d00092,0x7afc002f}},	// [21270] _nsụd, shäs, _ከዛሬ_, fopt, 
   {{0xb0585cf5,0x7afd4a69,0x88bc0034,0x6e400014}},	//   chär, gopt, _ciśn, _سۆرم, 
   {{0x67380a2e,0xb0594a6a,0x00000000,0x00000000}},	//   _stuj, ykäl, --, --, 
   {{0x2ee00cf9,0xec6853ef,0x673809a8,0xdb040005}},	//   lijf_, _урок_, _ptuj, rxiá, 
   {{0x66cc08fb,0x37500131,0xf4240254,0x2c1800cc}},	//   _løke, پپىس, ääli_, _ফ্ৰে_, 
   {{0x25540276,0x00000000,0x00000000,0x00000000}},	//   tăl_, --, --, --, 
   {{0xb05802f6,0x2ee00175,0x00000000,0x00000000}},	//   tkäl, iijf_, --, --, 
   {{0xc4843159,0x2ee00196,0xc8c80330,0x91fc02b5}},	//   флик, hijf_, _بورن_, ngāu, 
   {{0x6738337a,0xb0580724,0x814400aa,0x00000000}},	//   _utuj, rkäl, ژندن, --, 
   {{0x66cc1a82,0xb0580267,0xe9280327,0xe784013e}},	//   _bøke, skäl, _སྤོབ_, _муҷо, 
   {{0x3eb8000f,0xaef805d5,0x80a805d7,0xb05800e4}},	//   _ropt_, trùn, टाले, akäm, 
   {{0xafd803cd,0xf09c01ab,0x55580006,0x9554007b}},	//   rbøn, slàn_, _хаця_, _أخلا, 
   {{0x7afc06f2,0xb05826bc,0xafd803cd,0x7fd4187f}},	//   yopt, thär, sbøn, фіні, 
   {{0xafd94a6b,0xc5f8010f,0x00000000,0x00000000}},	//   mbøl, ַפּט, --, --, 
   {{0x32d80014,0xb058343a,0x99994a6c,0x88bc0055}},	//   _بدنک_, rhär, _serž_, _niśo, 
   {{0x7afd4a6d,0xb05826bc,0x6ea400bc,0x99980064}},	//   wopt, shär, खाउँ, _perž_, 
   {{0xb0580730,0xfa28025c,0xafd80158,0x7c342bd6}},	// [21280] phär, _སྔུན_, nbøl, rcyr, 
   {{0xa114021a,0x27380276,0xaa400166,0x00000000}},	//   _غوښت, _mână_, вефл, --, 
   {{0x27380356,0x6900000d,0x7c28f53b,0xf98800db}},	//   _lână_, jões, _монг_, تناي_, 
   {{0x7afd4a6e,0x2b480286,0xfce401c0,0x88bc39bc}},	//   sopt, _fwcc_, _цомо, _diśo, 
   {{0xba540801,0xb0580724,0x6e20002d,0x690000c5}},	//   _отвъ, xkäm, _ûnbr, võet, 
   {{0xb5a401c0,0xafd80ac8,0x68e00066,0x7afc0477}},	//   дрий, dbøl, éndr, qopt, 
   {{0x91fc0383,0xdddc0306,0x00000000,0x00000000}},	//   ngāt, berť, --, --, 
   {{0xb058023a,0x66cc1445,0xf770009f,0x00000000}},	//   tkäm, _røke, _لائ_, --, 
   {{0x66cc174e,0xd5b800b8,0xd764136e,0x00000000}},	//   _søke, _agāt_, _سنای, --, 
   {{0xa760004e,0x00000000,0x00000000,0x00000000}},	//   _шкуд, --, --, --, 
   {{0xb0594a6f,0x23c00ca8,0x00000000,0x00000000}},	//   skäm, _péjú_, --, --, 
   {{0x30a52db5,0xe4a00022,0x5fe003ce,0x00000000}},	//   фров, _аршо, _पेहल, --, 
   {{0x60c001e6,0xb058005b,0xe3ac103f,0x399c0153}},	//   ömma, lkäk, _نرو_, _lįs_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7c394a70,0x2ee00d27,0x630095af,0xb058005b}},	//   _ştra, rijf_, _جوول, nkäk, 
   {{0xb0580065,0xa18001af,0x00000000,0x00000000}},	//   chäp, _рышл, --, --, 
   {{0x8bd801d5,0x00000000,0x00000000,0x00000000}},	// [21290] чмас_, --, --, --, 
   {{0x2b9c04ce,0xb05801f4,0x00000000,0x00000000}},	//   のcm_, kkäk, --, --, 
   {{0xae180034,0x6efc012c,0xd0100244,0x00000000}},	//   फेशन_, rábě, _جلک_, --, 
   {{0x88bc00cd,0xa3cc0037,0x00000000,0x00000000}},	//   _viśo, _रहलs_, --, --, 
   {{0xb058005b,0xd5b800ef,0x00000000,0x00000000}},	//   tkäj, _ogās_, --, --, 
   {{0x66cc143a,0x2d8406af,0x69000254,0x00000000}},	//   _søkb, _ânes_, tões, --, 
   {{0x1a68158b,0x26c40219,0x00000000,0x00000000}},	//   _زینی_, rkno_, --, --, 
   {{0x273800a8,0x44380393,0x76b40166,0x7dec00e5}},	//   _până_, ùs_, дләр_, lősé, 
   {{0x03254a71,0x659003be,0x03a400b1,0xd83801c0}},	//   ндин, _məhə, хипо, _цэс_, 
   {{0x7dec00dd,0xe3c00228,0x99980024,0xafd85522}},	//   nősé, ерүү, _gerų_, rbøl, 
   {{0xafd81600,0x7bd400b5,0x22240014,0x00000000}},	//   sbøl, zzyu, بٲدی_, --, 
   {{0xf9d800c8,0x65900213,0xb058005b,0xafd801bf}},	//   פֿיל, _nəhə, nkäh, mbøj, 
   {{0xada0036b,0xb19400fd,0xafd800b5,0xe81400e1}},	//   қатл, _үлчә, lbøj, _तरफा_, 
   {{0x9f94035b,0xb0580254,0x00000000,0x00000000}},	//   ныҳә, shäp, --, --, 
   {{0xc0e48bc6,0x00000000,0x00000000,0x00000000}},	//   _покк, --, --, --, 
   {{0x91fc0f40,0x659000ac,0x2ca80356,0x3cf8000d}},	//   rgāt, _cəhə, _cncd_, ंवें_, 
   {{0x2ca80789,0x62800076,0x91ec01e4,0x6b60717e}},	// [212a0] _dncd_, _kbno, _veցe, лкта, 
   {{0xd1ec00b7,0x6fac00bc,0x88bc012d,0xb05801f4}},	//   _ቅርብ_, ुहरू, _wiśl, ykäk, 
   {{0x2ca80100,0x91fc00e2,0x5ea400db,0x00000000}},	//   _fncd_, lgār, _كۅڭل, --, 
   {{0xafd801bf,0xd1d40023,0x00000000,0x00000000}},	//   dbøj, _ከካብ_, --, --, 
   {{0x1c1c96e3,0x684000f7,0x91fc0374,0x99980064}},	//   पेशल_, унча, ngār, _perų_, 
   {{0x659000ac,0xb058023a,0x799c0175,0xdcf40115}},	//   _zəhə, tkäk, pvpw, ĝaĵo, 
   {{0xa2c01f14,0xafd8005c,0xdcf40115,0x659003b9}},	//   ाउन्, gbøj, ŝaĵo, _yəhə, 
   {{0x62814a72,0xb0580847,0x5fd00b4c,0xc4440066}},	//   _abno, rkäk, हनाल, پیون_, 
   {{0xb6680022,0x87040e56,0xa884030d,0x00000000}},	//   _ниаз_, ربۇل, _яйта_, --, 
   {{0xdc100055,0xb0580254,0xa2f000cf,0x00000000}},	//   _aśīr, mkäi, лпыч, --, 
   {{0xb3d018ce,0x250801ed,0xb0581073,0x06642309}},	//   _әйлә, _کرلی_, lkäi, _جاقپ, 
   {{0x3cf80034,0x674401e3,0x83fc00e5,0x00000000}},	//   ंवों_, _årjä, ggős, --, 
   {{0x09dc5b67,0xafd803cd,0xb0580e03,0xdcec008e}},	//   _मध्य, mbøk, nkäi, _şiğr, 
   {{0x61e800dd,0x659000ac,0x79800034,0xb058023a}},	//   állá, _səhə, łowy, ikäi, 
   {{0xe29800c8,0xe29410f3,0xb058005b,0x2de400f1}},	//   _זשור, _чај_, hkäi, رورۍ_, 
   {{0xb05802f6,0x88bc012d,0xe1080120,0x659003b9}},	//   kkäi, _piśm, _пејд_, _qəhə, 
   {{0x7dec066d,0xaa654a73,0x66cc0158,0xea640640}},	// [212b0] tősé, етек, _løka, ењен, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7d040270,0xafd80158,0xb0580e03,0x5520000d}},	//   _fkks, kbøk, tkäh, मगाए_, 
   {{0xa9054a74,0x7dec01d3,0x00000000,0x00000000}},	//   ربان, sősé, --, --, 
   {{0xafd808fb,0xd05c0134,0xb05839fa,0x00000000}},	//   dbøk, wnsɛ, rkäh, --, 
   {{0x66cc0158,0xbaa40124,0x88bc0055,0x00000000}},	//   _bøka, _иусқ, _kiśk, --, 
   {{0x1af50c27,0x69c0014a,0xb0580254,0x00000000}},	//   _спря, äned, akäi, --, 
   {{0xafd94a75,0xd5b8009d,0x88bc0210,0x00000000}},	//   gbøk, эсч_, _miśk, --, 
   {{0x58d42ba5,0x073462d9,0xe8dc004d,0x15a00116}},	//   _сотт, _резю, _giỡn_, _ﺋﯧﺸﯩ, 
   {{0x17980139,0x9724bd62,0x00000000,0x00000000}},	//   _явуы_, _مفقو, --, --, 
   {{0xa5640244,0x00000000,0x00000000,0x00000000}},	//   _سدان, --, --, --, 
   {{0xc0e49ada,0xca74022e,0xf9900375,0x1474009f}},	//   томк, _nizо, ברט_, _ماهج, 
   {{0x83fc01d3,0xd52c0241,0x7c3800a2,0x4ac000cd}},	//   rgős, _tọ́j, _ştro, _एवंव, 
   {{0x200c0a2b,0x0eb81507,0x98a4007f,0x19ec03d4}},	//   ādi_, нусы_, _rimč_, _কৰোঁ_, 
   {{0x443d4a76,0xfce4292c,0x00000000,0x00000000}},	//   _kfw_, вово, --, --, 
   {{0x443c020b,0x98b8005f,0xdc1000b8,0xefdc0023}},	//   _jfw_, _otrā_, _uśīr, _ሓልዩ_, 
   {{0x5ba457aa,0x443c15c0,0xcf5800c0,0xac8000d8}},	// [212c0] ылағ, _mfw_, _прэч_, јгул, 
   {{0xc8780139,0x80a800bc,0xb058000d,0xeb940114}},	//   _bmşo_, टाके, vkäi, ђих_, 
   {{0x443c0c67,0xcfa82354,0x98b800b8,0x91fc02b5}},	//   _ofw_, _قایم_, _atrā_, ngāp, 
   {{0xf7440abe,0xa8454a77,0xb05816ca,0x00000000}},	//   ведо, پلوم_, tkäi, --, 
   {{0xb8e802ab,0xe7343576,0x092800c6,0x66cc00cc}},	//   _लक_, веч_, رسمي_, _søka, 
   {{0xa68001c0,0xb0581b99,0x00000000,0x00000000}},	//   илчд, rkäi, --, --, 
   {{0xb05800c5,0xafd80217,0xd5b0007b,0x443c002f}},	//   skäi, tbøk, صفة_, _bfw_, 
   {{0x69c002f6,0x60c00e78,0xb058005b,0x53980395}},	//   änee, ömml, lkäv, евия_, 
   {{0x64a00f5c,0xafd87dfa,0x443c045a,0x31c800dc}},	//   рања, rbøk, _dfw_, ान्ध, 
   {{0x2570872b,0x91b806ed,0x66cc0174,0xef1c002f}},	//   _چهلس, егот_, _tøka, hwür_, 
   {{0x28c401ad,0x443c002f,0xb5c802da,0xe574014b}},	//   लसचि, _ffw_, _توام_, _азх_, 
   {{0xef90035c,0x2508179e,0x00000000,0x00000000}},	//   لیبد, _قرنی_, --, --, 
   {{0xa29400e5,0x00000000,0x00000000,0x00000000}},	//   رئیر_, --, --, --, 
   {{0xf1a499ce,0x623001ec,0xa2c03f6f,0xb1a400f3}},	//   _арин, _кешу, ाउण्, _ашик, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x48bc09bd,0x9d189088,0xd90479f8,0x69c00158}},	//   _আগ্র, вост_, _ذی_, ønem, 
   {{0x99d54a78,0x00000000,0x00000000,0x00000000}},	// [212d0] یتما, --, --, --, 
   {{0xf09d4a79,0x00000000,0x00000000,0x00000000}},	//   ldà_, --, --, --, 
   {{0x1a9401b9,0x00000000,0x00000000,0x00000000}},	//   рахў, --, --, --, 
   {{0xf09d4a7a,0x48e000bd,0x0134008f,0x6d454a7b}},	//   ndà_, যক্র, אָסט_, mpja, 
   {{0xb0580724,0x00000000,0x00000000,0x00000000}},	//   skäw, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3f9c00b0,0xd57800e5,0x00000000,0x00000000}},	//   ātui_, نلوڈ_, --, --, 
   {{0x394400f3,0xd7740137,0x00000000,0x00000000}},	//   ćost_, _چالع, --, --, 
   {{0xe6b004fb,0xf09c08e5,0x443c4f1a,0xb0580e78}},	//   _پلاگ, ddà_, _vfw_, nkäu, 
   {{0xf09c0137,0x6460025c,0x290c9323,0x00000000}},	//   edà_, _żwiġ, llga_, --, 
   {{0x693401a6,0xfad402e4,0xdc1002e5,0xc0d0069d}},	//   _oćem, רותך_, _ार्ड_, _ከማል_, 
   {{0x3f68562a,0xe7b40490,0x3ea406be,0x43754a7c}},	//   нимо_, _आपाप, _şot_, _букт, 
   {{0x249d4a7d,0xa2c002ab,0x290c00a3,0x6d4400de}},	//   mdum_, ाउद्, ilga_, epja, 
   {{0x249d4a7e,0xd9c4045e,0xf09c05da,0x88bc00b8}},	//   ldum_, _এইসম, adà_, _diśi, 
   {{0x42084316,0x290c01d5,0x237c0210,0xf65008c3}},	//   _янко_, klga_, ltuj_, מצם_, 
   {{0x249d47f6,0x724000dd,0xee340124,0xd1b806c2}},	//   ndum_, _پھیل, _ҩны_, _جاها_, 
   {{0x237d4a7f,0x249c0393,0xb0580108,0x00000000}},	// [212e0] ntuj_, idum_, tkäv, --, 
   {{0x66cc1a82,0x290ca87b,0x249c031c,0xfe7000ae}},	//   _søkn, elga_, hdum_, _ادة_, 
   {{0xfce54a80,0x237c014f,0x00000000,0x00000000}},	//   _боно, htuj_, --, --, 
   {{0x237c8864,0xb0581611,0x28dc28d4,0x249c01ef}},	//   ktuj_, skäv, पोलि, jdum_, 
   {{0x0a3c001f,0x249d4a81,0x4b5400a7,0x6d90002e}},	//   _ይጀምራ, ddum_, _въст, nʧan, 
   {{0x3b0834d8,0x249c016b,0xafd80158,0xb058081d}},	//   _чего_, edum_, gaøy, lkät, 
   {{0x66cc0579,0xa2d4041c,0x290c022e,0x39a000e5}},	//   _tøkn, यसन्, blga_, _دیاہ, 
   {{0xa5040063,0xb058403a,0x25b40014,0x249c06ea}},	//   леја_, nkät, انٹھ_, gdum_, 
   {{0xf65016cb,0x6840030c,0xb058007c,0x41380092}},	//   _هئا_, _ынта, ljäg, _በሃገሪ, 
   {{0x249c0393,0x66cc0162,0x6b78010f,0xe734041b}},	//   adum_, _jøkl, ערינ, _сеф_, 
   {{0x66cc0158,0x50f4013e,0xb058002f,0x75440064}},	//   _møkl, изот, njäg, _снез, 
   {{0x249c16b8,0xf09c04cc,0x74f00150,0x88bc002b}},	//   cdum_, udà_, _دۋبا, _piśi, 
   {{0xf09d4a82,0xee9c0150,0x00000000,0x00000000}},	//   rdà_, _ﻀﻤﻭﻥ_, --, --, 
   {{0xe1f405f5,0x88bc0882,0x66cc08fb,0xf09c07c5}},	//   _өгч_, _viśi, _nøkl, sdà_, 
   {{0x1df94a83,0x02b00490,0xb19001e0,0x290c01a9}},	//   геры_, जारभ, _ѳлкә, ylga_, 
   {{0x6d454a84,0xdddc139f,0x00000000,0x00000000}},	//   rpja, berž, --, --, 
   {{0x6d454a85,0x00000000,0x00000000,0x00000000}},	// [212f0] spja, --, --, --, 
   {{0xb0592671,0x6d440003,0x249c0bbc,0x00000000}},	//   rkäu, ppja, zdum_, --, 
   {{0x249d2828,0x66cc00b5,0x6f040455,0x80a80ebb}},	//   ydum_, _søko, mojc, _जोडे, 
   {{0x237c0034,0x249d4a86,0x0a3c0092,0x683000c7}},	//   ytuj_, xdum_, _ይጀመራ, сҭат, 
   {{0xb0581b5d,0xa2d4227c,0x58840eed,0x249c0162}},	//   lkäs, यसम्, сыха, vdum_, 
   {{0x88bc002b,0x46a41d0f,0x290c022e,0x00000000}},	//   _niśv, ракв, slga_, --, 
   {{0xb05836be,0x249c00ac,0x3ebd4a87,0x823415b4}},	//   nkäs, tdum_, ötti_, یردا, 
   {{0x88bc00dc,0x249c2619,0x6f040455,0x58d402e8}},	//   _aiśv, udum_, hojc, _лост, 
   {{0x249d4a88,0xb05808a1,0x68e800c0,0x00000000}},	//   rdum_, hkäs, migd, --, 
   {{0x237c068f,0x68e94a89,0x770000aa,0xdddc0024}},	//   rtuj_, ligd, _وژون, verž, 
   {{0x69c00158,0x237d4a8a,0xb05801f4,0x00000000}},	//   øneh, stuj_, ykät, --, 
   {{0x237d276b,0x68e82595,0x68e0020c,0x86e401b9}},	//   ptuj_, nigd, èndh, _сўғд, 
   {{0x64594a8b,0x00000000,0x00000000,0x00000000}},	//   maui, --, --, --, 
   {{0x68e9279f,0x64594a8c,0x995400bc,0x392c0092}},	//   higd, laui, _rýže_, _እነዚያ, 
   {{0xed554a8d,0x68e8409c,0x64580418,0x66cc0fac}},	//   иор_, kigd, oaui, _røkl, 
   {{0x64594a8e,0xb058007c,0xdddc13f1,0x00000000}},	//   naui, vjäg, perž, --, 
   {{0x68e94a8f,0x6f040e3c,0x60c40421,0xb0580724}},	// [21300] digd, bojc, _ioim, rkät, 
   {{0x64580069,0x60c4325e,0xb0594a90,0x00000000}},	//   haui, _hoim, skät, --, 
   {{0x6458123c,0x60c54a91,0x70500137,0xb058010b}},	//   kaui, _koim, _انۋا, mkär, 
   {{0xa965363d,0x200c03be,0x4c3405f5,0xafd80217}},	//   рица_, ədir_, _гэрт, rbøv, 
   {{0x64580393,0x02b400e1,0x3f800306,0xdcfc007f}},	//   daui, _अचंभ, ntku_, ntrč, 
   {{0x60c54a92,0x3f800ac5,0x58fc025c,0xef1c0793}},	//   _loim, itku_, ྐོངས_, rtüg_, 
   {{0x64580b23,0x60c400e4,0xafd8072b,0xb86405af}},	//   faui, _ooim, lbøt, _پازو, 
   {{0x60c49971,0x798c020c,0x64580381,0xe3e40154}},	//   _noim, _ipbw, gaui, _পড়ব, 
   {{0xe61424ce,0xb05837e9,0x6f0402d1,0x17e403d4}},	//   лдә_, kkär, yojc, _ফুৰি, 
   {{0x78a14a93,0xf2c4505c,0x60c400b0,0xa6e022d7}},	//   ldov, рсин, _aoim, _джул, 
   {{0x52440201,0x60c49d8d,0x6f040989,0x88bc0a28}},	//   _የአፍሪ, _boim, vojc, _viśv, 
   {{0x60c43c5d,0x645816b8,0x7b3400ef,0x00000000}},	//   _coim, caui, _kņud, --, 
   {{0x60c54a94,0x6f040023,0x68e000cf,0x78a001a9}},	//   _doim, tojc, èndi, idov, 
   {{0xb058023a,0xedd400fb,0x00000000,0x00000000}},	//   tkäs, алгә_, --, --, 
   {{0x3f814a95,0x60c40093,0xd2f800dd,0xdef94a96}},	//   atku_, _foim, _لکھا_, рыя_, 
   {{0x78a0a355,0xb058e9b1,0x60c54a97,0x00000000}},	//   jdov, rkäs, _goim, --, 
   {{0x78a002e8,0x798c02d0,0x68e94a98,0xb0594a99}},	// [21310] ddov, _apbw, vigd, skäs, 
   {{0x60c402ce,0x68e801f5,0xbb780014,0xb058007c}},	//   _zoim, wigd, الٕچ_, ckär, 
   {{0xc2680020,0x60c402ce,0x68e80f49,0xb78400fb}},	//   _ተጠቃሚ_, _yoim, tigd, ҙәте_, 
   {{0x87f805f5,0xa3c44328,0x271c0358,0x3c2c0022}},	//   лэлт_, _उथल_, यग्र_, _ẽve_, 
   {{0x2d814a9a,0x07a54a9b,0xf09c00db,0xc7a4bf73}},	//   ltje_, салн, llàs_, силк, 
   {{0xd6a816a0,0x2d8009b6,0x98bc0f40,0x68e80ea0}},	//   لدىم_, otje_, īvā_, sigd, 
   {{0x2d814a9c,0x64594a9d,0x7c38716b,0x00000000}},	//   ntje_, taui, _ştri, --, 
   {{0x66cc019b,0x2d800d27,0x7644016b,0x3f80239b}},	//   _køkk, itje_, _ɑkyi, ytku_, 
   {{0x60c54a9e,0x32d0019f,0x64586704,0x68f94a9f}},	//   _roim, _câyo_, raui, _ijud, 
   {{0xd7f80323,0x64594aa0,0x66cc4606,0x60c54aa1}},	//   _тус_, saui, _møkk, _soim, 
   {{0x66cc69e8,0x2d814aa2,0x64594aa3,0x60c54aa4}},	//   _løkk, jtje_, paui, _poim, 
   {{0x60c40113,0x2d800582,0x699c000d,0x00000000}},	//   _qoim, dtje_, _गईनी, --, 
   {{0x60c4049b,0x66cc6536,0x68f8014b,0x2d814aa5}},	//   _voim, _nøkk, _mjud, etje_, 
   {{0x66cc1b3c,0x291c0218,0x78a01b5c,0x3f814aa6}},	//   _søkj, _lhua_, zdov, rtku_, 
   {{0x60c43859,0x291d4aa7,0x3f806075,0x68f8014b}},	//   _toim, _ohua_, stku_, _ojud, 
   {{0xb0594aa8,0x68f80de2,0x66cc2147,0x291c004d}},	//   skär, _njud, _bøkk, _nhua_, 
   {{0x63b94aa9,0x2d800cf9,0x21200395,0x69c14aaa}},	// [21320] nxun, atje_, _ihih_, änen, 
   {{0x68f94aab,0xf410159d,0x291d4aac,0xd05c03be}},	//   _ajud, לפן_, _ahua_, disə, 
   {{0x68f8049f,0x21200649,0xdb054aad,0x27fc6184}},	//   _bjud, _khih_, nvié, _axun_, 
   {{0x291d4aae,0x63a83aaa,0x7c9402ec,0x66cc03cd}},	//   _chua_, _orgn, _اشدا, _føkk, 
   {{0x68f80066,0xe964020a,0xafd82b96,0x073800ec}},	//   _djud, _қатл_, lbør, لينڊ_, 
   {{0x68f94aaf,0x96f806ed,0x80a80807,0x4a7401ec}},	//   _ejud, јект_, _जोसे, _мыст, 
   {{0x20000393,0x63a94ab0,0xa2a808df,0x00000000}},	//   _lxii_, _argn, जयन्, --, 
   {{0x63a80263,0xf09c01ab,0xd05c06be,0x5fb80118}},	//   _brgn, hlàr_, bisə, आमाल, 
   {{0x68e0044e,0xd2500491,0x63b80fec,0xa5040640}},	//   ënde, ونة_, gxun, љења_, 
   {{0x2d814ab1,0x63a93a2b,0xa56000db,0x00000000}},	//   ytje_, _drgn, زگۅن, --, 
   {{0x93881884,0x765802d0,0xdb040129,0xef9405a2}},	//   усқа_, _iety, rviè, әйгә_, 
   {{0xafd85b47,0x76580124,0x63b80005,0xdef80032}},	//   dbør, _hety, bxun, ҡыр_, 
   {{0xdfd806bb,0x76594ab2,0x2000003a,0x2d814ab3}},	//   бър_, _kety, _cxii_, wtje_, 
   {{0x66cc022c,0xef2400a2,0x2d803674,0x00000000}},	//   _røkk, krüň_, ttje_, --, 
   {{0x76594ab4,0x2d800d27,0x66cc6066,0x98a4033f}},	//   _mety, utje_, _søkk, _zimą_, 
   {{0x2d814ab5,0x76594ab6,0x2120047e,0xd05c00ac}},	//   rtje_, _lety, _ghih_, yisə, 
   {{0x2d814ab7,0x75394ab8,0x00000000,0x00000000}},	// [21330] stje_, _lutz, --, --, 
   {{0x76594ab9,0xf418015b,0x27fc022e,0x753812e8}},	//   _nety, _ডলার_, _rxun_, _outz, 
   {{0x753809f0,0x291c01d4,0x7e68002d,0xcd800150}},	//   _nutz, _phua_, _ôfpa, _تۇزۋ, 
   {{0x6d540054,0x291c0070,0x47d40075,0x48154aba}},	//   _iwxa, _qhua_, ييار, омес, 
   {{0x76594abb,0x20014abc,0x7538005a,0x6134010e}},	//   _bety, _xxii_, _autz, _iţle, 
   {{0x76594abd,0x7538324c,0x66cc0174,0x00000000}},	//   _cety, _butz, _køki, --, 
   {{0x7658069c,0xd05c03be,0x291d4abe,0x233c01e1}},	//   _dety, sisə, _thua_, _ìjẹù, 
   {{0x68f94abf,0xf99004ae,0x765802d0,0x75380e78}},	//   _ujud, _קרן_, _eety, _dutz, 
   {{0xdcfc4114,0x03a53ddb,0x68e00ffb,0x66cc06ea}},	//   ntrā, ципо, èndu, _løki, 
   {{0xdddc00dd,0x76594ac0,0x2120e004,0x75394ac1}},	//   zerű, _gety, _shih_, _futz, 
   {{0x67f004fb,0x63b80077,0xb0594ac2,0x04c801c8}},	//   _בَرב_, sxun, tkäp, _پوشي_, 
   {{0x67394ac3,0x76580472,0x7e7c037e,0x63a804a7}},	//   _kuuj, _zety, _scpp, _trgn, 
   {{0xa3b853e2,0x76594ac4,0x7538005a,0x44282a78}},	//   _حاضر_, _yety, _zutz, _àa_, 
   {{0x67380050,0xb9dc00b7,0xb05801c7,0xc0d00092}},	//   _muuj, _ኦፍ_, skäp, _ከዛም_, 
   {{0x6da07737,0xada14ac5,0x20000009,0x00000000}},	//   мира, марл, _wxii_, --, 
   {{0xafd86a47,0xff2401f0,0x00000000,0x00000000}},	//   rbør, смҳо, --, --, 
   {{0xafd8365a,0x67380067,0x9eb401ec,0x7f180153}},	// [21340] sbør, _nuuj, _ешнә, _віну_, 
   {{0x86280092,0xeab4004e,0x00000000,0x00000000}},	//   ትመንት, ойу_, --, --, 
   {{0x76594ac6,0x7c380356,0x00000000,0x00000000}},	//   _rety, _ştru, --, --, 
   {{0x76594ac7,0xef240209,0xd05c013f,0x00000000}},	//   _sety, rrüň_, disɛ, --, 
   {{0x76594ac8,0x6738002e,0x75394ac9,0x00000000}},	//   _pety, _cuuj, _sutz, --, 
   {{0x3568c018,0x7d154aca,0x75394acb,0x8d8400f2}},	//   арин_, llys, _putz, _بشین, 
   {{0xa964b33f,0x76594acc,0x98c400c7,0x69c033b8}},	//   _мира_, _vety, _еивҵ, ønet, 
   {{0x7658009a,0x64a00114,0xa3c400cd,0x00000000}},	//   _wety, даћа, ैनं_, --, 
   {{0x753802c1,0x765800c7,0xdb04004e,0x7d154acd}},	//   _wutz, _tety, nviï, ilys, 
   {{0xc0dc069c,0x7d145129,0xd564084c,0x00000000}},	//   _ሓምለ_, hlys, _еӂип, --, 
   {{0xd250121e,0xdb040077,0x7d140153,0x66e000e4}},	//   ونک_, nxiñ, klys, sãkõ, 
   {{0x6738037e,0x66cc0174,0xe57400d8,0xc17000cf}},	//   _yuuj, _røki, _фзц_, رگىت, 
   {{0x75200526,0x66cd38fb,0xb28400f7,0x7d154ace}},	//   _ihoz, _søki, _дыйк, dlys, 
   {{0xe2954acf,0xd6d803d4,0x7d14cc26,0x00000000}},	//   _мач_, _তদুপ, elys, --, 
   {{0x752072e9,0x9e343605,0xd0d402e8,0x2cc401a9}},	//   _khoz, дерч, _нокъ, оqdа_, 
   {{0xd5a4c5bc,0x7d154ad0,0x69c005e3,0x3c2c0588}},	//   _یہ_, glys, änem, _ẽva_, 
   {{0x28a8375c,0x00000000,0x00000000,0x00000000}},	// [21350] _घोषि, --, --, --, 
   {{0x67380140,0x7d14bb16,0xd05c013b,0x66cc0174}},	//   _ruuj, alys, yisɛ, _tøki, 
   {{0xdcfd34c7,0x67380140,0x752002d0,0x7d14cc92}},	//   strā, _suuj, _ohoz, blys, 
   {{0x6738427f,0xfe6c01d9,0xeb9c01bf,0x75200051}},	//   _puuj, _لگہ_, _tsø_, _nhoz, 
   {{0x67380140,0x00000000,0x00000000,0x00000000}},	//   _quuj, --, --, --, 
   {{0x752001c0,0x28dc07f7,0xdd3800b8,0xb8d00118}},	//   _ahoz, पोजि, _nāśn, _झो_, 
   {{0x7520009a,0x59f8010b,0x00000000,0x00000000}},	//   _bhoz, _деря_, --, --, 
   {{0x75214ad1,0x6738058a,0x5dfc00d9,0xf53000d8}},	//   _choz, _tuuj, יפונ, нејќ, 
   {{0x15a00131,0x00000000,0x00000000,0x00000000}},	//   _ﺋﯧﺘﯩ, --, --, --, 
   {{0xdd380055,0x2b480208,0x00000000,0x00000000}},	//   _cāśn, _mtcc_, --, --, 
   {{0x7d154ad2,0xdcfc0356,0x00000000,0x00000000}},	//   ylys, ntră, --, --, 
   {{0x2b4802fa,0x75214ad3,0x63b00022,0x7d140450}},	//   _otcc_, _ghoz, _жәох, xlys, 
   {{0xaef807de,0x7d154ad4,0x4e1000bc,0x42d412fa}},	//   rsùn, vlys, _दुबै_, _ніку, 
   {{0xaef805d5,0x7d14037e,0x75200200,0x00000000}},	//   ssùn, wlys, _zhoz, --, 
   {{0x7d146282,0x41294ad5,0xed5400d8,0x2b483b64}},	//   tlys, _локо_, зос_, _atcc_, 
   {{0xb058023a,0x75200200,0x7cf4010e,0x00000000}},	//   ljän, _xhoz, dürä, --, 
   {{0x66cc03b2,0x98a40153,0xc5f803d4,0x30780677}},	// [21360] _høku, _gimę_, েইটা_, _האפנ, 
   {{0x7d154ad6,0x66cc022c,0xdb04005a,0x0ae8009a}},	//   slys, _køku, txiñ, يرلي_, 
   {{0xeb30278f,0x2d900077,0xdb040077,0x66cc03b2}},	//   رىمد, _gpxe_, uxiñ, _jøku, 
   {{0x68402081,0x9cb40137,0xb058005b,0x00000000}},	//   енца, _تۅرت, hjän, --, 
   {{0x68e14ad7,0xacb800d2,0x66cc03b2,0x2b480051}},	//   ënda, _khûn, _løku, _gtcc_, 
   {{0x66e00845,0x75206394,0x00000000,0x00000000}},	//   ноча, _shoz, --, --, 
   {{0x66cc0579,0xdddc0374,0x363400e5,0x987000d7}},	//   _nøku, karō, _ہراس, lúči_, 
   {{0x68100034,0xe8f40798,0x8d600023,0x00000000}},	//   _będą, _елс_, _ገብሪሂ, --, 
   {{0x75214ad8,0x9418013f,0xb4b000fd,0x00000000}},	//   _vhoz, ɛrɛ_, _җилә, --, 
   {{0x66cc0579,0x35a43004,0xdb2400f2,0x51f80212}},	//   _bøku, _назг, ésèn, жною_, 
   {{0x74154ad9,0xb4e0063f,0x21600395,0x00000000}},	//   _کوشا, áàsh, нтяг, --, 
   {{0xacb8006a,0x693422c1,0xe538011a,0x25d4011a}},	//   _ahûn, _kćer, _התאר, _מובן_, 
   {{0xd46800ee,0xdfd800a7,0x7aec02d0,0x799c0142}},	//   _гиҗе_, пър_, _ombt, hwpw, 
   {{0xb8dc0c99,0xf1a8030f,0x2404004e,0x69c0f6b3}},	//   _ཇོ_, _هابه_, _энчи_, änek, 
   {{0xec694ada,0x2b4801e3,0x00000000,0x00000000}},	//   йрак_, _stcc_, --, --, 
   {{0x7aec0196,0x00000000,0x00000000,0x00000000}},	//   _ambt, --, --, --, 
   {{0x5c7405f5,0x00000000,0x00000000,0x00000000}},	// [21370] элтт, --, --, --, 
   {{0xa3bc023e,0x00000000,0x00000000,0x00000000}},	//   ीहत_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdcfc084c,0xc994004b,0xf09c0051,0xb0580108}},	//   stră, _ښارګ, goài_, yjän, 
   {{0x66cc5792,0x00000000,0x00000000,0x00000000}},	//   _nøkt, --, --, --, 
   {{0x19940108,0x00000000,0x00000000,0x00000000}},	//   _паря, --, --, --, 
   {{0x66cc03b2,0x44382b96,0x6aa40e79,0x00000000}},	//   _røku, øs_, _hajf, --, 
   {{0xb05804f3,0x6aa4031c,0x64a14adb,0x03242360}},	//   tjän, _kajf, дақа, мдин, 
   {{0x290d4adc,0x2bdc0316,0xdee0001f,0x61540092}},	//   loga_, पैया, ፒዮና_, _የሰይጣ, 
   {{0x290c0421,0xdb2401ed,0xb05895da,0x6d48033b}},	//   ooga_, ésén, rjän, _ōgan, 
   {{0x290c2f06,0x6aa40369,0xb40c063f,0x43740137}},	//   noga_, _lajf, ịpịa_, _жукт, 
   {{0x0598069c,0x290d4add,0x03a4084c,0x00000000}},	//   _መርበብ_, ioga_, _цило, --, 
   {{0x290d4ade,0x614067d1,0xb058005b,0x622002dd}},	//   hoga_, _كىتە, ljäl, _كوشە, 
   {{0x290d4adf,0xe8dc0051,0x51940408,0xef1c0205}},	//   koga_, _nhữn_, _пăра, ptün_, 
   {{0xb058023a,0x66cc0174,0x290d4ae0,0x00000000}},	//   njäl, _køks, joga_, --, 
   {{0x290d4ae1,0xbb480f1b,0xec104e74,0x6aa400f3}},	// [21380] doga_, زلان_, پولد, _bajf, 
   {{0xe3a404d3,0xb05833da,0x66cc05ac,0xaf74010f}},	//   _یر_, hjäl, _møks, _קעיס_, 
   {{0x290c096b,0xacb800d2,0x62800789,0xfce4e7ec}},	//   foga_, _khûl, _mcno, _жоно, 
   {{0xa3bc05f9,0x00000000,0x00000000,0x00000000}},	//   ीहा_, --, --, --, 
   {{0x6aa4010f,0x98a400bc,0x00000000,0x00000000}},	//   _fajf, _zimě_, --, --, 
   {{0x290c096b,0x7aec035a,0x00000000,0x00000000}},	//   aoga_, _umbt, --, --, 
   {{0x290d4ae2,0x66cc022c,0xb05801e3,0xc764005e}},	//   boga_, _røkt, fjäl, _ۋاكى, 
   {{0x3eb805b1,0x290c00ca,0x66ccb02f,0xb8643c5a}},	//   _lnpt_, coga_, _søkt, _زارو, 
   {{0x628001b8,0x8de40150,0x533400c7,0x00000000}},	//   _bcno, _ﺍﻁﻤﺄ, неит, --, 
   {{0xc32c24a7,0xa82000f2,0x00000000,0x00000000}},	//   مەن_, _شکنن, --, --, 
   {{0xe3ac82e7,0xb058007c,0x00000000,0x00000000}},	//   هری_, bjäl, --, --, 
   {{0x69c0005b,0x00000000,0x00000000,0x00000000}},	//   änei, --, --, --, 
   {{0x3eb8020b,0x5ea8015b,0xe360004e,0x00000000}},	//   _bnpt_, খানে, _акчи, --, 
   {{0xe1ec58ae,0x290d4ae3,0x3eb80077,0x628000ae}},	//   اسی_, zoga_, _cnpt_, _gcno, 
   {{0x9f354ae4,0x290d4ae5,0x6aa400f3,0xeca40e92}},	//   тері, yoga_, _rajf, мјан, 
   {{0xe7a801f1,0x6aa54ae6,0xa3d800cd,0x00000000}},	//   _ďaľš, _sajf, णैव_, --, 
   {{0x290d4ae7,0xb0594ae8,0x6aa4007c,0x00000000}},	// [21390] voga_, njäm, _pajf, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x290d4ae9,0xb058023a,0x68e00023,0xef1c07c5}},	//   toga_, yjäl, ëndo, ntüm_, 
   {{0x66cc022c,0x290c0618,0xa9bc04af,0x00000000}},	//   _nøkr, uoga_, _एपीए, --, 
   {{0x290d4aea,0x6aa54aeb,0x3c0401d5,0x00000000}},	//   roga_, _tajf, _зўрғ, --, 
   {{0x290d4aec,0x79e801d3,0xef1c03e0,0x00000000}},	//   soga_, _کوفہ_, ktüm_, --, 
   {{0xda340598,0x628031c4,0x290d4aed,0x66cc31a2}},	//   _аеры, _rcno, poga_, _søks, 
   {{0x290c022e,0xc48401d5,0x00000000,0x00000000}},	//   qoga_, хлик, --, --, 
   {{0x58854aee,0xb058005b,0x00000000,0x00000000}},	//   _шыра, rjäl, --, --, 
   {{0x66cc022c,0xb0594aef,0xcfe403d4,0x888001d3}},	//   _vøks, själ, নপান, _شیڈن, 
   {{0xb0594a5e,0x00000000,0x00000000,0x00000000}},	//   lkäy, --, --, --, 
   {{0x26c404b9,0x98b800da,0x00000000,0x00000000}},	//   ljno_, _kurā_, --, --, 
   {{0xb05802f6,0x00000000,0x00000000,0x00000000}},	//   nkäy, --, --, --, 
   {{0x98b80055,0x0eb80166,0x443c0210,0x00000000}},	//   _murā_, мусы_, _hgw_, --, 
   {{0x3eb801fb,0xd2440276,0x32d8011a,0xeaf81c54}},	//   _vnpt_, _рэчи, _מחסנ, ्वैत_, 
   {{0xb058248c,0x68e00221,0xdda00419,0x00000000}},	//   kkäy, ëndl, šňou_, --, 
   {{0xeb954af0,0x6448010a,0xe0d00014,0xebe00137}},	// [213a0] нит_, _mfgi, _مٲژ_, готп, 
   {{0xec4401c0,0x4e10012c,0x3ea4119e,0xbea400d8}},	//   _үзэл_, _दुवै_, _џинг, _џанк, 
   {{0xd9114af1,0xae58025f,0x443c2f99,0x64480221}},	//   لیس_, _מכיר, _ogw_, _ofgi, 
   {{0x443d4af2,0x91fc02b5,0xa3bc00bc,0xdb500133}},	//   _ngw_, kaān, ँमा_, _نێر_, 
   {{0xcc354af3,0x00000000,0x00000000,0x00000000}},	//   _ахры, --, --, --, 
   {{0x64494af4,0x56954af5,0xb5a54af6,0xdddc0210}},	//   _afgi, такт, ерий, marł, 
   {{0xab2412d7,0x7bd40548,0xe9900150,0xe1e4007b}},	//   _чора_, lyyu, _مۇلگ, _إس_, 
   {{0x690001e4,0x28c407d0,0xb05801e3,0x00000000}},	//   lĵen, _रचयि, tjäm, --, 
   {{0x7bd40198,0x66cc0174,0xb28400ee,0x69c00254}},	//   nyyu, _vøkr, нынк, änev, 
   {{0x443c01c7,0x7bd4208d,0xc8000116,0xef1c0205}},	//   _egw_, iyyu, _әҗәп, ttüm_, 
   {{0x5260001f,0xb05801e3,0xdfd40150,0x00000000}},	//   _ለአፍሪ, sjäm, қоры, --, 
   {{0x443c04ba,0x30a400f5,0xfbb00073,0x00000000}},	//   _ggw_, хров, ीमाम, --, 
   {{0xddcc012c,0xef1d4af7,0xb0580108,0xe3ad4af8}},	//   _čišt, stüm_, ljäk, _هرو_, 
   {{0x38644230,0x00000000,0x00000000,0x00000000}},	//   haor_, --, --, --, 
   {{0xdd947ced,0x7bd4208d,0xef1c01d3,0x00000000}},	//   лары, eyyu, ltük_, --, 
   {{0xb0594af9,0x6fd4031c,0xd5b80055,0xa1800153}},	//   ykäy, ུརྱའ, _iyād_, _сышл, 
   {{0x317c0198,0xb058023a,0xffc01075,0x26c4012d}},	// [213b0] lutz_, hjäk, _көрп, yjno_, 
   {{0xacb800d2,0x00000000,0x00000000,0x00000000}},	//   _khûk, --, --, --, 
   {{0x7bd40ba7,0x317d4afa,0xc878010e,0x98b8002b}},	//   ayyu, nutz_, _alşa_, _surā_, 
   {{0x98b80882,0xda08004b,0xf09c026c,0xab601df2}},	//   _purā_, رينه_, neà_, _مۇرى, 
   {{0x317c2426,0x07a4334a,0xc7a40801,0xdb040077}},	//   hutz_, талн, тилк, sviá, 
   {{0xa5d000a2,0x317c005a,0x00000000,0x00000000}},	//   _aỳak, kutz_, --, --, 
   {{0x1a68006c,0x443c010a,0x2d4400c5,0xb058023a}},	//   _سینی_, _pgw_, _jõe_, skäy, 
   {{0x76b40348,0x317c068c,0x7c20202a,0x69c001f4}},	//   еләр_, dutz_, żore, äneu, 
   {{0x47354afb,0x2ca94afc,0x69d40393,0xf50402e8}},	//   _анас, _macd_, lyxe, ънъл_, 
   {{0x57f54afd,0xb0594afe,0xdcfc00df,0xe3c0009d}},	//   _спут, ljäh, rurĉ, врүү, 
   {{0xc0e406a6,0x317c054e,0x0494007b,0x00000000}},	//   вонк, gutz_, _للاح, --, 
   {{0x3f6815ab,0x200d3056,0xb0580e78,0x833000b8}},	//   мимо_, şdim_, njäh, _dātṛ, 
   {{0xefc407d8,0xefcc02d3,0xb0580e78,0x249c4264}},	//   влял_, _ቤተይ_, ijäh, meum_, 
   {{0x249d4aff,0x7c800201,0x317c0221,0x41b40022}},	//   leum_, _ይችላል_, butz_, _асит, 
   {{0x925800c6,0x0d987bf7,0xdb0400d8,0xb77800cd}},	//   _أشهر_, нтты_, lviç, _keṣā, 
   {{0x249c1730,0xdddc012d,0xc3380118,0x00000000}},	//   neum_, tarł, řídá, --, 
   {{0x59a4012c,0xa2b400dc,0xb7780055,0x00000000}},	// [213c0] _ऐनहर, ्ञप्, _meṣā, --, 
   {{0x249d4b00,0xb0580108,0x00000000,0x00000000}},	//   heum_, yjäk, --, --, 
   {{0xa96400a7,0xef1c01ed,0x249c0098,0xafd803cd}},	//   виха_, ztük_, keum_, dbøy, 
   {{0x249c0098,0xb0580112,0xdddc0210,0x00000000}},	//   jeum_, gjäh, parł, --, 
   {{0xd79422cd,0x386400ae,0xf6c80166,0x00000000}},	//   التخ, raor_, дыйк_, --, 
   {{0x98b8020c,0x7c254b01,0x2fcc00e8,0x67d14b02}},	//   _bură_, _izkr, _àgge_, рошу, 
   {{0xe94401b9,0x98b8054e,0x69c0000d,0xdb040139}},	//   _لرقی, _cură_, änet, eviç, 
   {{0x249c0098,0xef1c01ed,0x98b8054e,0xb05801f4}},	//   geum_, ttük_, _dură_, rjäk, 
   {{0xd5b80882,0x7d04037e,0xd2500133,0x00000000}},	//   _syād_, _mjks, مۆش_, --, 
   {{0x98b8054e,0xef1c9482,0x69c0007c,0x00000000}},	//   _fură_, rtük_, åneg, --, 
   {{0x98b80311,0xf09c0ffb,0x249c54b2,0xe640234c}},	//   _gură_, teà_, beum_, _техп, 
   {{0xdb0402f6,0x249d4b03,0x317d4b04,0x82800124}},	//   lviä, ceum_, rutz_, ақәд, 
   {{0xf09c00db,0xeff40023,0x92940153,0x00000000}},	//   reà_, _ወላዲ_, _балц, --, 
   {{0x7d0401e4,0x2d454b05,0x6d400687,0x88bc00b8}},	//   _ajks, _põe_, _énak, _diśy, 
   {{0xafe406ea,0xe294399f,0x68e0002e,0xb05801f4}},	//   _brøð, _рај_, ëndk, hjäi, 
   {{0x5c7421fa,0x00000000,0x00000000,0x00000000}},	//   илст, --, --, --, 
   {{0x0bb40108,0x00000000,0x00000000,0x00000000}},	// [213d0] ыбаю, --, --, --, 
   {{0xd1f80201,0x249c8dd4,0x2d440037,0x3f78010f}},	//   _ወራት_, zeum_, _tõe_, _אָטע, 
   {{0x7c24030a,0xafe40174,0x91fc00b0,0x49754b06}},	//   _ezkr, _frøð, kaām, улес, 
   {{0xafe40174,0x249c003a,0x00000000,0x00000000}},	//   _grøð, xeum_, --, --, 
   {{0xb0594b07,0x249c0381,0x00000000,0x00000000}},	//   rjäh, veum_, --, --, 
   {{0xed9400b7,0xb0580e78,0x98b8054e,0xaef800e4}},	//   _ሄክታር_, sjäh, _pură_, asùv, 
   {{0xa8a54b08,0x249c26fc,0x69c00450,0xafd803cd}},	//   _ирак, teum_, åned, rbøy, 
   {{0xd76404d3,0xd9280276,0x15b8d655,0x249c0c6a}},	//   _چۆنی, _ацул_, тышы_, ueum_, 
   {{0x249d4454,0x58d54b09,0x42d454be,0x668001b9}},	//   reum_, _тотт, гіну, _نیشل, 
   {{0xdb040cfc,0x5694010b,0x81c80fbe,0x98b80356}},	//   rviç, _вафт, егов_, _tură_, 
   {{0xb7780a28,0xe8dc01f2,0x249c0393,0xd40800f2}},	//   _teṣā, _ndịa_, peum_, فتیم_, 
   {{0xcea81203,0x75801893,0xeabc0154,0xc0e400c7}},	//   _מי_, _ایٹم, _ইতোম, уомк, 
   {{0x64594b0a,0x90c40220,0x00000000,0x00000000}},	//   mbui, рғыз_, --, --, 
   {{0x64594b0b,0x00000000,0x00000000,0x00000000}},	//   lbui, --, --, --, 
   {{0xfce42830,0x64594b0c,0xa1c00150,0x00000000}},	//   гово, obui, _тұнд, --, 
   {{0xee34084c,0x6458282c,0xd174f4e3,0x98b800c0}},	//   унс_, nbui, _тышы, _kurą_, 
   {{0x8b640075,0xa3e01a04,0x00000000,0x00000000}},	// [213e0] لالم, ननि_, --, --, 
   {{0x3f814b0d,0xb6000798,0xab747b81,0x7c2400d0}},	//   muku_, _àágu, املا_, _vzkr, 
   {{0x64580b4f,0xafe40174,0x00000000,0x00000000}},	//   kbui, _trøð, --, --, 
   {{0xa3e0068f,0x975402d3,0x645801f5,0xb7e40209}},	//   नना_, _ዝተወስ, jbui, лжек, 
   {{0x3f814b0e,0x69c14b0f,0x7c24005f,0x7d14cf6d}},	//   nuku_, äner, _uzkr, moys, 
   {{0x7d154b10,0x645816b8,0xaa4041e5,0xb058005b}},	//   loys, ebui, _герл, rjäi, 
   {{0x3f814b11,0x645800a3,0xdcfc0219,0x98b80064}},	//   huku_, fbui, hurč, _aurą_, 
   {{0x7d14011f,0xb0583167,0x00000000,0x00000000}},	//   noys, ljäv, --, --, 
   {{0xb5c40046,0x3f80019b,0x78a14b12,0xe8d40375}},	//   _әйел, juku_, meov, _עומר_, 
   {{0x3f814b13,0x78a14b14,0x7d14011f,0xdcfc02fb}},	//   duku_, leov, hoys, durč, 
   {{0x64580083,0x98b80153,0xf1ac00bc,0x6654030d}},	//   bbui, _eurą_, टिइन, _сахă, 
   {{0x3f814b15,0xd5b800b0,0x7d14035a,0xf30001c6}},	//   fuku_, _irā_, joys, ржүү, 
   {{0x3f814b16,0x7d140429,0x5f954b17,0x32940050}},	//   guku_, doys, бият, _مٔشر, 
   {{0xceb803a5,0xf1a41d39,0xb64400b5,0xe670013d}},	//   тәи_, _брин, _ｋｊ_, _mäşğ, 
   {{0x59a4006d,0x6300a675,0x3f80000d,0x0e0401f0}},	//   _गैलर, _دوول, auku_, рӯпо, 
   {{0xd9041af6,0x3f814b18,0x7d146928,0xdb040ea0}},	//   _ری_, buku_, goys, bwië, 
   {{0x78a14b19,0x3f80548c,0xa06816a4,0x20540166}},	// [213f0] deov, cuku_, _сања_, _укыя, 
   {{0x32e0025c,0x682400c7,0x00000000,0x00000000}},	//   _སཾསྐ, қьез, --, --, 
   {{0xad24abd7,0xd01001d9,0x7d140429,0x4c940114}},	//   _مرحو, _دلک_, boys, _кинс, 
   {{0x2d8033c8,0x4c8400d1,0x683800a2,0x00000000}},	//   muje_, _өлүв, _nädü, --, 
   {{0xd5b80325,0xd91001d9,0x00000000,0x00000000}},	//   _arā_, سیٰ_, --, --, 
   {{0xd5b8002b,0x7ac00139,0x00000000,0x00000000}},	//   _brā_, _мөха, --, --, 
   {{0x3f814b1a,0x2d80489c,0x64580b4f,0x7ce8032e}},	//   zuku_, nuje_, tbui, _dýrf, 
   {{0x09e06385,0x3f801556,0x79e801d9,0xd5b8002b}},	//   पनीय, yuku_, _شوقہ_, _syāc_, 
   {{0x2d80db0e,0xe7854b1b,0x64594b1c,0x3f80013e}},	//   huje_, _љубо, rbui, xuku_, 
   {{0x3f814b1d,0x64594b1e,0x00000000,0x00000000}},	//   vuku_, sbui, --, --, 
   {{0x41052ebd,0x645847b4,0x3d1c0054,0x3f814b1f}},	//   изов, pbui, sïwi_, wuku_, 
   {{0x3f814b20,0xdddc0010,0x98b80153,0x43940064}},	//   tuku_, jgrš, _turą_, _вадс, 
   {{0x09d80183,0x00000000,0x00000000,0x00000000}},	//   _ধেমা, --, --, --, 
   {{0x2d814b21,0xef14084c,0x91fc02b5,0x78a001a6}},	//   fuje_, имя_, kaāh, zeov, 
   {{0x3f800163,0x7d14011f,0x78a02251,0x5ea8015b}},	//   suku_, toys, yeov, খালে, 
   {{0x3f814b22,0x2c780248,0xec74011c,0x3da80107}},	//   puku_, _ràdà_, ипс_, нкҳо_, 
  
   {{0x7d145573,0x2b8c06be,0x00000000,0x00000000}},	// [21400] roys, güc_, --, --, 
   {{0x2d80a895,0xeb954b23,0x63a80334,0x9e740131}},	//   buje_, риф_, _msgn, _دۇست, 
   {{0xe9440517,0xb05801e3,0x69c0000d,0x00000000}},	//   لرنی, rjäv, änep, --, 
   {{0x7c940246,0x7d140429,0x69200107,0x00000000}},	//   _троц, qoys, омха, --, 
   {{0x78a0011a,0x4b5400a7,0xb8cc43d1,0xb058007c}},	//   reov, _гъст, _कस_, mjät, 
   {{0x78a0074d,0xb058403a,0xd5b800b8,0xb880013a}},	//   seov, ljät, _prā_, _řídk, 
   {{0x78a005be,0xafd800b5,0xc7b801d3,0x8554036b}},	//   peov, ncør, _erő_, میلر_, 
   {{0x7ce803f2,0x1cdc0327,0xb0580108,0x00000000}},	//   _dýrg, འིི_, njät, --, 
   {{0xb4d40574,0xa878011a,0xa5040063,0x68380139}},	//   _हवी_, _שאמר, јења_, _vädü, 
   {{0x2d814b24,0x4ac82e3c,0xb1e4007b,0xd5b80055}},	//   yuje_, रायव, لأجه, _trā_, 
   {{0x2d800306,0xb058007c,0xd5b800ef,0x00000000}},	//   xuje_, kjät, _urā_, --, 
   {{0x2d8003c6,0x6740030c,0x12c400d1,0xa5500244}},	//   vuje_, _اپەك, ﯩﯖﻼﺭ, _بکوڵ, 
   {{0x61fc03be,0x2d800034,0x4ac81cba,0x7ce808a5}},	//   _əylə, wuje_, रामव, _mýrd, 
   {{0xf2340139,0x00000000,0x00000000,0x00000000}},	//   _колә_, --, --, --, 
   {{0x91fc00b0,0x1df807e6,0xa2540677,0xdef80023}},	//   kaāi, аеры_, _דבוק_, ጊምካ_, 
   {{0x5cc4004e,0x00000000,0x00000000,0x00000000}},	//   осуз, --, --, --, 
   {{0x9cc94b25,0x720004d3,0x39580036,0x518400fb}},	// [21410] шыра_, _دوژم, epps_, _туҙа, 
   {{0xd8b800e5,0x00000000,0x00000000,0x00000000}},	//   یدنا_, --, --, --, 
   {{0x29854b26,0x60d80129,0x00000000,0x00000000}},	//   рызг, _àamé, --, --, 
   {{0x6d5401c0,0x7e68045f,0x8c1800ec,0x2004012d}},	//   _itxa, _ôfpr, _ميجر_, źmie_, 
   {{0x39582b1d,0x7ce80174,0xb058023a,0xb89000db}},	//   apps_, _dýrd, ljäs, سلوع, 
   {{0x9a84e89b,0x00000000,0x00000000,0x00000000}},	//   _мусл, --, --, --, 
   {{0xb05801f4,0xa2b400cd,0x00000000,0x00000000}},	//   njäs, ्ञस्, --, --, 
   {{0x490400e5,0x00000000,0x00000000,0x00000000}},	//   _اورق, --, --, --, 
   {{0x317c6df3,0xb058023a,0xb4600137,0x3390007b}},	//   ertz_, hjäs, чкыл, كليز, 
   {{0x5924025c,0x6d5401c6,0xd5b80055,0x24740208}},	//   _འཚོས_, _otxa, _iyān_, ểm_, 
   {{0x6d540457,0x62200137,0xb05801f4,0x00000000}},	//   _ntxa, تودە, yjät, --, 
   {{0xdf5800fd,0xef1c03e0,0x91fc002b,0x00000000}},	//   иягә_, ktüs_, dbād, --, 
   {{0x6d55472c,0x91fc00b0,0xfe7802d5,0xb058007c}},	//   _atxa, kaāw, лёвы_, vjät, 
   {{0x9f6001e1,0xa2800244,0x4254009a,0x00000000}},	//   _èsín_, _بیدو, _انغر, --, 
   {{0x8db402bf,0x00000000,0x00000000,0x00000000}},	//   ості, --, --, --, 
   {{0x59240327,0x80640108,0x315401f7,0x00000000}},	//   _འཚེས_, _увиж, _اليج_, --, 
   {{0x60c54b27,0x6d5401c0,0x6d480618,0xb0580108}},	// [21420] _inim, _etxa, _ōgat, rjät, 
   {{0x4bd8023a,0xff240262,0xb05833b4,0x00000000}},	//   шься_, _ымпо, sjät, --, 
   {{0x7ce800a2,0x2f38011a,0xb058000d,0xdd9000d1}},	//   _aýre, _תגיד, mjär, _تۈز_, 
   {{0xb4d4d825,0xef1c1570,0xb0594b28,0xa9641920}},	//   _हवे_, stüt_, ljär, сица_, 
   {{0xb3f41161,0xa77001ce,0xce640150,0xb7940640}},	//   kṣaṇ, зліч, _ادۋى, срећ, 
   {{0xef1c0365,0xb05870a2,0x4ac80b02,0xeb940063}},	//   ltür_, njär, राणव, _ћир_, 
   {{0x18b400fd,0x6d4000d8,0x7afc0477,0x00000000}},	//   _мәдр, _énat, mipt, --, 
   {{0xef1d4b29,0x98bc005f,0x60c54b2a,0xb0580267}},	//   ntür_, īvē_, _nnim, hjär, 
   {{0xe44c082e,0x66700075,0x6ee8b44b,0x7e6c005f}},	//   رضي_, زگەر, _hübe, kabp, 
   {{0x60c54b2b,0x6ee94b2c,0xc32c43d2,0x7afd4b2d}},	//   _anim, _kübe, نەن_, nipt, 
   {{0x5244001f,0x6154001f,0xef1d4b2e,0xb058000d}},	//   _ከአፍሪ, _የተውጣ, ktür_, djär, 
   {{0xa1903334,0x7afd4b2f,0x2a380a7c,0x6ee80205}},	//   чаюч, hipt, טעימ, _mübe, 
   {{0x7afd4b30,0x5f95471c,0x6ee94b31,0xb0580267}},	//   kipt, пият, _lübe, fjär, 
   {{0x7afd4b32,0xdef94b33,0x92591ea9,0xf1b8004d}},	//   jipt, быс_, _такт_, _trơ_, 
   {{0xab594b34,0x1b0000fe,0x7afc0784,0xa1346071}},	//   _krüg, ্তাই_, dipt, تریش, 
   {{0x1cdc0156,0x2d702625,0x60c40055,0xb0583b22}},	//   འིཊ_, rće_, _gnim, rjäs, 
   {{0x09e01fbc,0x2d7000f3,0x8af94b35,0x7afc054e}},	// [21430] पन्य, sće_, анас_, fipt, 
   {{0x2d70d418,0x7afd4b36,0x90a400db,0xceb80ce8}},	//   pće_, gipt, _اڭگم, _тәм_, 
   {{0x6d540054,0x6ee827ac,0x60c401a9,0x39491107}},	//   _utxa, _cübe, _ynim, _cubs_, 
   {{0xad252596,0x6ee8b1e1,0x3948039a,0x00000000}},	//   _درخو, _dübe, _dubs_, --, 
   {{0x7ce80162,0xfca80244,0x00000000,0x00000000}},	//   _fýrb, _ئاپو_, --, --, 
   {{0xab580639,0x3948014b,0x8578005b,0x7ce80419}},	//   _prüf, _fubs_, асит_, _výre, 
   {{0xdddc0a28,0x68e14b37,0x6ee800a2,0xab587a78}},	//   darś, ënds, _gübe, _brüg, 
   {{0xdcfc054e,0x5dfc011a,0xd61800ae,0x00000000}},	//   mură, טפונ, حتها_, --, 
   {{0xed8c044e,0x291c00c7,0x68f80ca8,0x60c401d5}},	//   _ዝግበር_, _ikua_, _imud, _rnim, 
   {{0x60c40bb8,0x237c0a2e,0x2b480694,0x6ee80112}},	//   _snim, rruj_, _mucc_, _lübb, 
   {{0x68f80263,0x1d700023,0xb058007c,0x00000000}},	//   _kmud, _እግዚኣ_, vjär, --, 
   {{0x36240014,0x80f80395,0x9634009d,0x00000000}},	//   _بومہ, рхот_, _энхц, --, 
   {{0x63c0052f,0x68f94b38,0xb058049f,0x7afc01ed}},	//   _халҡ, _mmud, tjär, yipt, 
   {{0xfca800ec,0x00000000,0x00000000,0x00000000}},	//   ڌارو_, --, --, --, 
   {{0xcd3804a2,0x291c0086,0x98a40006,0x68f82252}},	//   ﻣﻨﯩﯔ_, _okua_, _gimė_, _omud, 
   {{0x394830c3,0xb058b302,0x291c013f,0x2b4805d5}},	//   _rubs_, sjär, _nkua_, _bucc_, 
   {{0x39494b39,0x6ee804e6,0x90e40150,0x7afc544b}},	// [21440] _subs_, _dübb, _ءسىن, tipt, 
   {{0x291c4774,0x68f94b3a,0xef1d2704,0x39494b3b}},	//   _akua_, _amud, stür_, _pubs_, 
   {{0xdcfc0276,0xcee83cc6,0x00000000,0x00000000}},	//   gură, _درين_, --, --, 
   {{0xab5803fa,0x3198008f,0x3f802ce5,0x8328031c}},	//   _brüd, יבענ, orku_, _ཤེའུ_, 
   {{0x7afc0113,0x3d1c0142,0x00000000,0x00000000}},	//   pipt, bïwr_, --, --, 
   {{0x7afc067d,0x39494b3c,0x68f94b3d,0x6bd40014}},	//   qipt, _tubs_, _emud, _بڈِس_, 
   {{0xab5800af,0x39480c6a,0xdcfc0311,0xf4e801b9}},	//   _prüg, _uubs_, cură, ифий_, 
   {{0x1cc80003,0xd25004fb,0xf8ac000d,0x00000000}},	//   _ཉོས_, کند_, _घसिय, --, 
   {{0xdcfc00de,0x17d800cc,0x00000000,0x00000000}},	//   ltrē, _দেৰি, --, --, 
   {{0xe3ac3738,0x91fc02b5,0xa6800107,0x3f9c0356}},	//   ئري_, kaāt, _олуд, ătul_, 
   {{0x162802dd,0xab581d13,0x291c0124,0xdcfc00e2}},	//   _اياۋ_, _trüg, _ykua_, ntrē, 
   {{0xb7bc009e,0xd5b80055,0x00000000,0x00000000}},	//   ্নীয়, _jyām_, --, --, 
   {{0xceb949b4,0x74154b3e,0x69000115,0x7c200135}},	//   бән_, _بوشا, mĵet, żorj, 
   {{0x690001e4,0xfbc000cc,0xe294009b,0x00000000}},	//   lĵet, োনাত, _даљ_, --, 
   {{0x2b4802e8,0x254401ed,0x3f807ca1,0x30f40014}},	//   _succ_, _tőle_, arku_, _ووتھ_, 
   {{0x610401ed,0x7c3801e4,0xfbd4009e,0x690000df}},	//   tőle, _ŝtra, _সেইত, nĵet, 
   {{0x200c0cc1,0xdddc00df,0xa1340244,0xd5b800b8}},	// [21450] şdir_, marŝ, _تروش, _syāl_, 
   {{0x291c0076,0xaca001e1,0xdcfc054e,0xdb240cad}},	//   _skua_, _iwọd, tură, _àsìk, 
   {{0xaca001f2,0x2d8400e4,0x3d1c0142,0x00000000}},	//   _ahụb, _êne_, rïwr_, --, 
   {{0xab58002f,0x00000000,0x00000000,0x00000000}},	//   _prüd, --, --, --, 
   {{0xab5804cc,0x9954012c,0xd5b800b8,0xdcfc054e}},	//   _brüe, _výše_, _dyām_, sură, 
   {{0x26e02f04,0x7bd80375,0x2d80000f,0x44280135}},	//   কোনো_, _הקשו, orje_, _ġa_, 
   {{0x7ce803b2,0x44287167,0x05a801d5,0x00000000}},	//   _hýra, _ša_, ёвий_, --, 
   {{0x68f94b3f,0x291c0869,0x3f814b40,0xab580139}},	//   _umud, _ukua_, yrku_, _erüe, 
   {{0x461410e5,0x76c801d9,0x00000000,0x00000000}},	//   _کوار, _گُلہ_, --, --, 
   {{0xd4080c50,0xab58002f,0x7ce80252,0xa28000e5}},	//   تتىم_, _grüe, _mýra, ذیبو, 
   {{0xaca001f2,0x42240212,0x3f800009,0x00000000}},	//   _awọd, ядов, wrku_, --, 
   {{0xb0600166,0x00000000,0x00000000,0x00000000}},	//   _çälp, --, --, --, 
   {{0x2d814b41,0x7ce81427,0x3f814b42,0x98b800dc}},	//   erje_, _nýra, urku_, _strī_, 
   {{0x63b94b43,0x3f80aaad,0x00000000,0x00000000}},	//   mvun, rrku_, --, --, 
   {{0x7ce809a5,0x63b94b44,0x69c001e3,0x00000000}},	//   _aýra, lvun, ånel, --, 
   {{0x7ce80162,0x63b8009f,0x31780375,0x02600244}},	//   _býra, ovun, _האקד, _تێگێ, 
   {{0x2d800225,0x3b854b45,0x63b804ba,0x0ba800d1}},	// [21460] arje_, ялаг, nvun, ياكى_, 
   {{0xe81c09fd,0x7ce81f60,0x63b94b46,0x5924031c}},	//   _बड़ा_, _dýra, ivun, _འཚངས_, 
   {{0x7ce80209,0x6ed80375,0xdb240241,0x4ea400ea}},	//   _eýra, _החיפ, _àsík, _црња, 
   {{0x3ea803fa,0xab5803fa,0x7ce80174,0x2d8400ee}},	//   lebt_, _drüb, _fýra, _эйюп_, 
   {{0xdcfc0029,0xab580112,0x7dd403e0,0x00000000}},	//   strē, _erüb, büsç, --, 
   {{0x6ee94b47,0x63b8192e,0x00000000,0x00000000}},	//   _küba, dvun, --, --, 
   {{0xc98494d2,0x6670004e,0xab580ade,0xe9a007a5}},	//   _يشفي, ردور, _grüb, _парп, 
   {{0x6ee80cc1,0xaa4000d1,0x3ea80e78,0x91fc00b0}},	//   _müba, _чесл, hebt_, kaār, 
   {{0x87b801f0,0x6900010f,0x63b81d0e,0x00000000}},	//   _муфт_, rĵet, gvun, --, 
   {{0x7c2405b1,0xd25001ed,0x2d813070,0x2fc4004d}},	//   _mykr, کنگ_, yrje_, _ăng_, 
   {{0x63b80869,0xab580112,0x6ee803b9,0x00000000}},	//   avun, _krüc, _nüba, --, 
   {{0x63b81cbd,0x6e9c0316,0x3d14033f,0xb1080154}},	//   bvun, ख्नु, थकों_, রত্ব_, 
   {{0x75200189,0x7c24037e,0x43b001ee,0x00000000}},	//   _ikoz, _nykr, _аҡыр, --, 
   {{0x3ea801ab,0xdef81075,0x7ce802d2,0xf15401af}},	//   gebt_, пыс_, _rýra, _епкә_, 
   {{0x9f054855,0x06fc0316,0x75200083,0x2d80002d}},	//   روفو, _říká_, _kkoz, urje_, 
   {{0x2d80044e,0x7c240ea0,0xd6c4009e,0x6ef00432}},	//   rrje_, _bykr, ্সিয, _dünỳ, 
   {{0x75200161,0x6ab40175,0x00000000,0x00000000}},	// [21470] _mkoz, tdxf, --, --, 
   {{0x7ce803c6,0xa3bc3f6f,0x7c24036e,0x00000000}},	//   _výra, ुमत_, _dykr, --, 
   {{0x75214b48,0xab5822f8,0x68e00120,0x63b80369}},	//   _okoz, _brüc, êndo, zvun, 
   {{0x7ce87755,0x75214b49,0x61440066,0x88d400b8}},	//   _týra, _nkoz, lèlè, _mṛgh, 
   {{0xab580730,0x63b80399,0x7ce808ce,0x60280118}},	//   _drüc, xvun, _kýrn, _témž, 
   {{0x75214b4a,0xea6000dd,0xefdc1b49,0xab580e78}},	//   _akoz, _سپری, _ዓውደ_, _trüb, 
   {{0x752001fa,0xdb040077,0xab5803fa,0x9f454b4b}},	//   _bkoz, avió, _früc, ámé_, 
   {{0x63b8000d,0x00000000,0x00000000,0x00000000}},	//   tvun, --, --, --, 
   {{0x63b94b4c,0x81d800cc,0x00000000,0x00000000}},	//   uvun, _ঠেং_, --, --, 
   {{0x75201aac,0x569407d8,0x7ce808a5,0x732401c4}},	//   _ekoz, _паут, _nýrn, мжыг_, 
   {{0xa56404d3,0x61440066,0x63b81057,0x00000000}},	//   _ردان, dèlè, svun, --, 
   {{0xa48401ec,0x63b801e4,0x6ee803b9,0x3ea8002f}},	//   _ءجان, pvun, _rüba, webt_, 
   {{0x147421ef,0x64480429,0x63b80007,0x6ee80205}},	//   _سانج, _iggi, qvun, _süba, 
   {{0x4ed40a89,0x6144020c,0xdddc56f8,0x00000000}},	//   нюст, gèlè, garş, --, 
   {{0x3ea80e78,0x7c254b4d,0x88d400b8,0xa4400345}},	//   rebt_, _sykr, _kṛdh, _تێکو, 
   {{0xefdc02d3,0x00000000,0x00000000,0x00000000}},	//   _ዓውዲ_, --, --, --, 
   {{0xeb954b4e,0x83b4008f,0x4ac80073,0x88d4002b}},	// [21480] мит_, ופּע_, रांव, _mṛdh, 
   {{0x7c240122,0x6ee80b70,0xbe64cbad,0xdb254b4f}},	//   _vykr, _tüba, _تهدي, روای, 
   {{0x64494b50,0x7c240034,0x810005f9,0xd88400f2}},	//   _oggi, _wykr, _लगाओ_, فهای, 
   {{0x6448034c,0xa3bc0316,0xc3380118,0x71d40677}},	//   _nggi, ुमा_, říhá, וועד_, 
   {{0x32c40075,0x8a180014,0x00000000,0x00000000}},	//   _ﺩﯦﮕﻪ, _ہتِس_, --, --, 
   {{0x64480c04,0x75200fb7,0xdb04381a,0x6ee80342}},	//   _aggi, _skoz, rvió, _lübn, 
   {{0xc8b40133,0xaa5400f2,0x610400e5,0x00000000}},	//   بلۆک, _آلفا_, zőla, --, 
   {{0x93b40395,0x00000000,0x00000000,0x00000000}},	//   ебиц, --, --, --, 
   {{0x38654b51,0xdb040005,0x88d400b8,0xdb24032e}},	//   mbor_, lviñ, _dṛdh, _ásók, 
   {{0xacb800d2,0xc8c40131,0x3864005a,0x51f800d4}},	//   _nkûn, _يۈەن_, lbor_, зною_, 
   {{0xe8dc001e,0xdb040077,0x752001a6,0xb5f002dd}},	//   _hiền_, nviñ, _tkoz, _шүкі, 
   {{0x38654b52,0x752055fa,0x88d400cd,0xe8dc0208}},	//   nbor_, _ukoz, _gṛdh, _kiền_, 
   {{0x7ce800a2,0x7760005a,0x64a00063,0x00000000}},	//   _aýro, npox, _јача, --, 
   {{0xe8dc0016,0x386403a2,0x61480165,0x00000000}},	//   _miền_, hbor_, tèlè, --, 
   {{0xe8dc0016,0xdd954b53,0x38640263,0xdddc03e0}},	//   _liền_, кары, kbor_, rarş, 
   {{0x30a40b7f,0x61e400b5,0x7aed3837,0x719401d3}},	//   _цркв, øjle, _albt, _فنڈز_, 
   {{0x61480066,0x765803ac,0xe8dc0051,0x62a0032e}},	// [21490] sèlè, _ofty, _niền_, _þvoð, 
   {{0x4ac81533,0xdcfc0024,0x61480066,0xc8780139}},	//   राइव, ktrė, pèlè, _moşe_, 
   {{0x5a440276,0x00000000,0x00000000,0x00000000}},	//   вэца, --, --, --, 
   {{0x1cc80135,0x7aec32e4,0x765802d0,0xe8dc0208}},	//   _ཉོག_, _elbt, _afty, _biền_, 
   {{0xc76801c0,0x7ce802d2,0xd138012d,0x00000000}},	//   чилж_, _mýrl, mtąd_, --, 
   {{0xd7c800ec,0xf8149924,0x00000000,0x00000000}},	//   بوهه_, رسنگ, --, --, 
   {{0x38654b54,0x6ee80139,0xb6d000db,0x00000000}},	//   bbor_, _lübo, اقىع, --, 
   {{0x188806d3,0x00000000,0x00000000,0x00000000}},	//   _осуп_, --, --, --, 
   {{0x290d4b55,0x88d4002b,0x00000000,0x00000000}},	//   mnga_, _vṛdh, --, --, 
   {{0x290d4b56,0x00000000,0x00000000,0x00000000}},	//   lnga_, --, --, --, 
   {{0xf09cb269,0xb2f8031c,0x93240214,0xafe002dd}},	//   ffà_, ྒྲེང_, خرين, қорл, 
   {{0x290d4b57,0x64494b58,0xe7c02b1b,0x59240327}},	//   nnga_, _uggi, ্নীয, _འཚབས_, 
   {{0x290d4b59,0x03a401b9,0x7194004b,0xe8dc0208}},	//   inga_, _чило, ونیز_, _xiền_, 
   {{0x290c00ca,0x38640306,0x7ce800a2,0x1cc80327}},	//   hnga_, zbor_, _eýrl, _ཉོང_, 
   {{0xada14b5a,0x6da00f43,0x290d4b5b,0x3b0401e1}},	//   ларл, лира, knga_, _lípè_, 
   {{0x7ce80745,0xe058034c,0x91c8036b,0x7760009a}},	//   _výro, _زیست_, _آذوق_, ypox, 
   {{0xbb48fe81,0x290c089c,0x21a01607,0x6ee8b1e1}},	// [214a0] سلان_, dnga_, _чиқм, _kübl, 
   {{0x290d4b5c,0xfe400214,0x88d400b8,0xa3b4000d}},	//   enga_, _مکزی, _nṛbh, _चनन_, 
   {{0x38640649,0x6a8004a9,0x290ce14a,0xfce40f06}},	//   tbor_, улха, fnga_, _зоно, 
   {{0xab5800e4,0x3eb801f5,0xdb040005,0x91fc0055}},	//   _irün, _hapt_, rviñ, dbāl, 
   {{0x3eb805e4,0x38641c2e,0x56943425,0x00000000}},	//   _kapt_, rbor_, валт, --, 
   {{0x38654b5d,0xe8dc01fb,0x356834cb,0x855407d6}},	//   sbor_, _viền_, прин_, چیلر_, 
   {{0x290c0083,0x77600077,0x499407d5,0x249c0162}},	//   bnga_, spox, _иштт, ffum_, 
   {{0xe8dc01dc,0xb8646aea,0x29040129,0x00000000}},	//   _tiền_, _سارو, énat_, --, 
   {{0xe4d000cf,0x872400cf,0xb058008e,0x00000000}},	//   اتىب, رعۇم, ldäg, --, 
   {{0x98a40064,0x7ce808a5,0x733000cf,0x00000000}},	//   _kimį_, _sýrl, دۉتا, --, 
   {{0xb0594b5e,0x6ee80205,0x7e980150,0x00000000}},	//   ndäg, _dübl, _ﺘﺤﻘﻕ_, --, 
   {{0x6ee80793,0x2d8403cd,0xef1c0112,0x00000000}},	//   _pübo, _ånei_, grün_, --, 
   {{0xa30800f8,0xb3f40a28,0xe8dc0016,0x3eb8003a}},	//   _کرنے_, kṣiṇ, _hiển_, _bapt_, 
   {{0xab594b5f,0x290d4b60,0xf09d4b61,0xd5b800b8}},	//   _brün, znga_, sfà_, _dyāv_, 
   {{0x3eb94b62,0x290c0649,0xdd8400f7,0x717002dd}},	//   _dapt_, ynga_, лытп, _حۇجا, 
   {{0x6ee804cc,0xdbe401e1,0x81d800cc,0xe8dc0051}},	//   _zübl, _kèèm, _ঠেক_, _miển_, 
   {{0x3eb800a8,0x8f3400c7,0x00000000,0x00000000}},	// [214b0] _fapt_, _иеиц, --, --, 
   {{0xab5804cc,0x9c440108,0xaa7001e2,0x00000000}},	//   _frün, ухсл, اناډ, --, 
   {{0xab580639,0x290c2ecd,0xdb0408a7,0x2d8400e4}},	//   _grün, tnga_, rvið, _íne_, 
   {{0x6f0438c6,0xdb0409f3,0x3b040241,0x3eb94b63}},	//   lijc, svið, _pípè_, _zapt_, 
   {{0x3eb80bc9,0x9b5802e8,0x290d4b64,0x68300124}},	//   _yapt_, _пият_, rnga_, уҭат, 
   {{0xe8dc07ae,0xb05801b8,0x04ec015b,0xd7f450c0}},	//   _biển_, ldäd, _ওদের_, ызчы, 
   {{0x5b142424,0x290cb137,0xab580254,0x6ee803b9}},	//   _смрт, pnga_, _krüo, _rübl, 
   {{0xc8c8004b,0x6f040113,0x290c009a,0xe8dc0208}},	//   _تورن_, hijc, qnga_, _diển_, 
   {{0x249d4b65,0x758402d3,0x7ce80162,0xef1c0213}},	//   rfum_, _ነይርዎ_, _býrj, vrün_, 
   {{0xacb8045f,0x249c003a,0xbb4c0150,0x33900133}},	//   _skûl, sfum_, _ﺍﺘﻔ_, گلیز, 
   {{0x9f454b66,0x67214b67,0xe4e402bf,0x95c81d39}},	//   ámí_, monj, _підн, _пуца_, 
   {{0x3eb80311,0x00000000,0x00000000,0x00000000}},	//   _sapt_, --, --, --, 
   {{0x6f040010,0xb0580139,0x00000000,0x00000000}},	//   fijc, ddäd, --, --, 
   {{0x672144a8,0x6458054e,0x38c001d3,0xdb2401d3}},	//   nonj, lcui, mérő_, ésün, 
   {{0x7c94a4cb,0xe8dc0051,0xdb0831b7,0x00000000}},	//   крац, _xiển_, ólít, --, 
   {{0x67214b68,0x64594b69,0xf09c05d5,0xd5b8002b}},	//   honj, ncui, liàn_, _iyāt_, 
   {{0x67214b6a,0x3eb9161c,0xdb04005b,0x645802d0}},	// [214c0] konj, _tapt_, iviö, icui, 
   {{0x67214b6b,0xd9780166,0x00000000,0x00000000}},	//   jonj, ердә_, --, --, 
   {{0x67214b6c,0xd9100330,0xd1d0001f,0x00000000}},	//   donj, میس_, _እይታ_, --, 
   {{0xa96433fa,0xb7e4010b,0x37e40108,0x00000000}},	//   тица_, кжек, коег, --, 
   {{0x67214b6d,0x4c3401c6,0xbc1800d4,0xd1d40092}},	//   fonj, _бэрт, _ціні_, _ይዞት_, 
   {{0x67214b6e,0x5924081f,0x7bc54b6f,0x7c20003d}},	//   gonj, _འཚམས_, _irku, żors, 
   {{0x66e003b7,0xe1e435ea,0x80b0473c,0x00000000}},	//   роја, _ئس_, ज़ाइ, --, 
   {{0x64580007,0x6f04549d,0x799c03ac,0xe8dc0051}},	//   gcui, zijc, mtpw, _viển_, 
   {{0x27303baf,0x78a00960,0x67214b70,0x782407d6}},	//   _چىقس, mfov, bonj, _شعرل, 
   {{0x67200276,0x78a0245e,0xe8dc0051,0xf2c4fb90}},	//   conj, lfov, _tiển_, тсин, 
   {{0xc878496e,0x00000000,0x00000000,0x00000000}},	//   _hoşa_, --, --, --, 
   {{0x7bc54b71,0x64594b72,0x7ce8148b,0xab580b70}},	//   _orku, ccui, _dýrk, _brül, 
   {{0x7bd40218,0x60f831af,0x68e00798,0xc878010e}},	//   jxyu, тняя_, êndi, _joşa_, 
   {{0x7ce803b2,0x02b4014b,0x00000000,0x00000000}},	//   _fýrk, _бишӯ, --, --, 
   {{0x5e5810f5,0x7bc54b73,0x6f0415ad,0xdef80953}},	//   тися_, _arku, rijc, тыя_, 
   {{0xa1800bd6,0xdb040037,0xca4c01ec,0x2210013d}},	//   _тышл, iviõ, _ﺍﻨﺘ_, _әфәр, 
   {{0x7bc40010,0x67202252,0x9f0801d9,0x7e602d9a}},	// [214d0] _crku, yonj, رقہٕ_, _şope, 
   {{0xe8dc07ae,0x5f7404a9,0xfc440005,0x3f9c054e}},	//   _miễn_, _ئاير, ñían_, ătut_, 
   {{0xd010021a,0x67214b74,0x7bc54b75,0x6ee8002f}},	//   _خلک_, vonj, _erku, _lübk, 
   {{0x67200bd7,0xf09c7172,0xc878029f,0x572401d5}},	//   wonj, mnàs_, _boşa_, یروق, 
   {{0x67214b76,0x07a41d83,0x7d1800d2,0xab580e78}},	//   tonj, уалн, étse, _krüm, 
   {{0xd6a816a0,0xb058023a,0xa80403e3,0x6ee80205}},	//   ندىم_, rjäy, _arıç, _sübj, 
   {{0x67214b77,0x6458054e,0xe81c00c5,0x00000000}},	//   ronj, tcui, _बडका_, --, 
   {{0x67214b78,0x1cc8031c,0x69c54b79,0x38c001ed}},	//   sonj, _ཉོབ_, _irje, térő_, 
   {{0xd5b80882,0x67214b7a,0xd7c800aa,0xdb04023a}},	//   _syāt_, ponj, _ټوله_, rviö, 
   {{0xe8dc01dc,0x64594b7b,0x26040137,0xdb040108}},	//   _diễn_, scui, _ичег, sviö, 
   {{0x0494027a,0xc0e40f30,0xdcf401e4,0xbb240150}},	//   _ملاح, гонк, ŝaĉo, _ﺠﺭﻴ_, 
   {{0x69c40728,0x9f84013e,0xdb2408a5,0x00000000}},	//   _mrje, аҳид, _ásök, --, 
   {{0xdcfc0318,0x82a46efa,0xc87803b9,0x68e0036e}},	//   strī, _балж, _xoşa_, ëndy, 
   {{0x69c54b7c,0xff240798,0x00000000,0x00000000}},	//   _orje, умго, --, --, 
   {{0x7ce84eb4,0x1cc80327,0x00000000,0x00000000}},	//   _hýri, _ཉོད_, --, --, 
   {{0xa3b4375c,0xdcfc0115,0x7ce802d2,0xca4c0150}},	//   _चना_, burĝ, _kýri, _ﺍﺨﺘ_, 
   {{0x8fd4052f,0x69c54b7d,0xf06000ee,0x69c001bf}},	// [214e0] _кәрә, _arje, _укып, ænen, 
   {{0x7bc401a6,0x7ce80d12,0x8e74013d,0xc5e803d4}},	//   _vrku, _mýri, _куюч, _কইনা_, 
   {{0xd1d4001f,0x69c401a6,0x4ac808a3,0x00000000}},	//   _ይዞታ_, _crje, राजव, --, 
   {{0xcd280014,0xc8780139,0x69c40200,0xb058007c}},	//   _لسُن_, _poşa_, _drje, mdäc, 
   {{0x7bc54b7e,0x69c47536,0x78a00306,0x5704035b}},	//   _urku, _erje, rfov, аҟаз, 
   {{0x69c40a85,0xf3642310,0x3f7000e2,0x8d700092}},	//   _frje, қтин, iņu_, _ጠብቀው_, 
   {{0x69c41710,0xc7b801d3,0x6a980375,0xa6c4007b}},	//   _grje, _eső_, _רשלנ, طويل_, 
   {{0x628000a9,0x28a806ab,0x54540276,0x3f7000e2}},	//   _adno, _टॉपि, швит, kņu_, 
   {{0xd2500491,0x1cc8003d,0x00000000,0x00000000}},	//   ينة_, _ཉོན_, --, --, 
   {{0xe8dc0016,0x7ce80ad9,0x69c40363,0xb05801e3}},	//   _viễn_, _dýri, _yrje, kdäc, 
   {{0xf1a803e6,0x74a401ee,0xf07400b1,0x3f700171}},	//   راده_, _бјле, линә_, eņu_, 
   {{0x62800100,0xe8dc001e,0x7f540139,0x7ce80162}},	//   _edno, _tiễn_, _buyq, _fýri, 
   {{0xab581570,0xe478008f,0x00000000,0x00000000}},	//   _prüm, _טראכ, --, --, 
   {{0xef1c54de,0xf09c04cc,0x1dd010eb,0x7f540051}},	//   mrük_, gnàr_, हमंत, _duyq, 
   {{0xccfc0134,0x9f4400bc,0xeca406ed,0x73740022}},	//   _hwɛɛ_, ámá_, лјан, _рыҵх, 
   {{0x69c4044e,0x00000000,0x00000000,0x00000000}},	//   _rrje, --, --, --, 
   {{0xe8dc01dc,0x1bd40801,0xab580112,0xe45c00e4}},	// [214f0] _hiện_, ботя, _trüm, ñöi_, 
   {{0xe8dc07ae,0x69c40841,0xd5b402ab,0xee700166}},	//   _kiện_, _prje, ंबाज, _ыңгы, 
   {{0x1cc80489,0x7e7401c0,0x0854023a,0xc5e80154}},	//   _ཉོཝ_, _өгөх, авею, _কেনা_, 
   {{0x9bbc0cf9,0x69c4549d,0xe8dc004d,0xec6801f0}},	//   ta는b, _vrje, _miện_, _ярок_, 
   {{0x6d554b7f,0x6d4c01e2,0xe7a40131,0x3af40393}},	//   _huxa, _iica, اپتۇ_, _sæpe_, 
   {{0x6d554b80,0x6d4d4b81,0x69c00158,0x7ce8032e}},	//   _kuxa, _hica, ånes, _rýri, 
   {{0x7ce802fb,0x6d5430bc,0x69c46e05,0xc5d40212}},	//   _sýri, _juxa, _urje, ріль, 
   {{0x6d554b82,0x5694085a,0xc4e431a8,0x15b80032}},	//   _muxa, _ҳафт, ржий, уышы_, 
   {{0x6d554b83,0x999800a2,0x54a4007b,0x00000000}},	//   _luxa, _kyrş_, صحيف, --, 
   {{0x6d4d4b84,0x42548fad,0xe8dc001e,0x0514015b}},	//   _lica, штит, _biện_, াতের_, 
   {{0xc7b801ed,0xab5803e0,0x44b40395,0x00000000}},	//   _győr_, _brük, _вбес, --, 
   {{0x6d4c07dd,0xe8dc07ae,0x3f70005f,0xb0600139}},	//   _nica, _diện_, tņu_, _şärq, 
   {{0x3208016b,0xbb3c0131,0x3f7000e2,0x00000000}},	//   _ɛhyɛ_, ﻟﯘﻡ_, uņu_, --, 
   {{0x6d554b85,0x7d040ac5,0x3f7000e2,0x6ee8013d}},	//   _buxa, _smks, rņu_, _yübi, 
   {{0x6d4d4b86,0x6d54056a,0x7d040139,0x00000000}},	//   _bica, _cuxa, _pmks, --, 
   {{0xbc6466d1,0x3fe402bf,0x7c640150,0xb0594b87}},	//   рвак, _вжив, شارل, rdäc, 
   {{0x6d4d4b88,0x9f60023a,0xbb840131,0x8b640a11}},	// [21500] _dica, örät_, شلاي, مالم, 
   {{0x6d55153e,0xfde800c7,0xdcfc0139,0x00000000}},	//   _fuxa, _адок_, burğ, --, 
   {{0x6d4c0cfc,0x9a540022,0x0ce400cc,0x91fc00b8}},	//   _fica, ахҵә, _নগৰত, ccād, 
   {{0xdbdc03c6,0x6d4c01b2,0x7c3800df,0x5d1400f1}},	//   lšíc, _gica, _ŝtru, _اېرا, 
   {{0x7d14002d,0x3a240210,0x69c04836,0xea880220}},	//   mnys, łop_, åner, _ﻗﯘﺭﯞ, 
   {{0x6d4d4b89,0x6d5403be,0xdbdc0122,0x7d14010b}},	//   _zica, _yuxa, nšíc, lnys, 
   {{0x6d4c2dab,0x99e80432,0xd5b000c6,0x7d154b8a}},	//   _yica, _deňä, سفة_, onys, 
   {{0x6d400395,0x7d154b8b,0x54b80801,0xab580112}},	//   _ènat, nnys, угия_, _brüh, 
   {{0x7ce80174,0x7d153187,0xc7a815f8,0xb74800db}},	//   _fýrv, inys, _مدلل_, _апаз_, 
   {{0xdbdc0232,0xb5f00220,0x0074004d,0x7d140076}},	//   jšíc, _мүлі, _được, hnys, 
   {{0x3f8c0421,0x7d154b8c,0xdbdc02fb,0x7ce80174}},	//   _āfua_, knys, dšíc, _hýru, 
   {{0xb3548235,0xab580639,0xe8dc07ae,0x6d554b8d}},	//   _پیدا_, _früh, _viện_, _ruxa, 
   {{0x32940014,0x6d554b8e,0xf1a80345,0xa4f80115}},	//   _نٔشر, _suxa, راگه_, _בלאט, 
   {{0x6d4d4b8f,0xe8dc07ae,0x6d54d02b,0x7ce803f2}},	//   _sica, _tiện_, _puxa, _mýru, 
   {{0xab594b90,0x6d54011f,0xfff4028e,0x00000000}},	//   _trük, _quxa, لکیت_, --, 
   {{0x26f00a28,0x6d5407a9,0x7d140072,0x00000000}},	//   _अत्र_, _vuxa, gnys, --, 
   {{0x6d4d4b91,0xa2c80490,0xdbdc0306,0x6d5479d4}},	// [21510] _vica, _थोड्, bšíc, _wuxa, 
   {{0x6d4d4b92,0x7d14000f,0x6d541bce,0xaa64d027}},	//   _wica, anys, _tuxa, ртак, 
   {{0x6d4c029f,0x7ce800a2,0x00000000,0x00000000}},	//   _tica, _aýru, --, --, 
   {{0x6d4c003a,0x00000000,0x00000000,0x00000000}},	//   _uica, --, --, --, 
   {{0xb50000c6,0x7af000e5,0x00000000,0x00000000}},	//   _èٌنç_, áktó, --, --, 
   {{0x7ce80321,0x7c28002f,0x3f78010f,0xb88008a5}},	//   _dýru, ßfre, אָקע, _þíni, 
   {{0x6d4005d5,0x00000000,0x00000000,0x00000000}},	//   _ènas, --, --, --, 
   {{0x7ce80162,0x03954b93,0x05140154,0xf554007b}},	//   _fýru, броя, াত্র_, حليب_, 
   {{0x4438369d,0x00000000,0x00000000,0x00000000}},	//   ås_, --, --, --, 
   {{0xc87806be,0x7d140118,0xded41954,0x00000000}},	//   _heş_, znys, ረታን_, --, 
   {{0xdbdc0030,0xc8780139,0x25600790,0x7d145873}},	//   všíc, _keş_, _bıle_, ynys, 
   {{0x3f68026a,0xab58000d,0x43943f1b,0xf9900a7c}},	//   лимо_, _trüh, _гадс, הרט_, 
   {{0xdbdc219b,0xc8780139,0x753400df,0x00000000}},	//   tšíc, _meş_, _פאנד_, --, 
   {{0x93248194,0xc8781ea0,0x7d1400ad,0x08f40154}},	//   _ورون, _leş_, wnys, েকটু_, 
   {{0xdbdc0232,0xc8780166,0x7d140363,0x00000000}},	//   ršíc, _oeş_, tnys, --, 
   {{0x2ca80175,0x7d140363,0x00000000,0x00000000}},	//   _cbcd_, unys, --, --, 
   {{0xdbdc0232,0xed5402dd,0x7d154b94,0x91fc0055}},	// [21520] pšíc, _қоя_, rnys, ccāb, 
   {{0x7d154b95,0x3f800b91,0xb0585f76,0x2ca80066}},	//   snys, msku_, ndän, _ebcd_, 
   {{0xc8784a4a,0xb8654b96,0x7ce809e8,0x69c001e3}},	//   _beş_, ماشو, _sýru, ånep, 
   {{0x7c94a517,0x3f80033f,0xfe70136e,0x00000000}},	//   _уроц, osku_, _بدک_, --, 
   {{0xeb9401ee,0x7ce803b2,0xb098011a,0x9e4400d1}},	//   _лия_, _dýrt, רינר, _دىگۈ, 
   {{0x98b80053,0x3f814b97,0x7ce81155,0x3b08005b}},	//   _kurī_, isku_, _výru, _сего_, 
   {{0xb0580139,0xdddc002b,0x00000000,0x00000000}},	//   ddän, darū, --, --, 
   {{0x391417ae,0x7ce803b2,0x3f812b8f,0xf75400f2}},	//   _اورز, _týru, ksku_, _هنرج, 
   {{0x3f801326,0x39454b98,0x77840124,0x00000000}},	//   jsku_, mmos_, _ылаз, --, 
   {{0x3f80098d,0x7ce802d2,0xfd4c002b,0x52140395}},	//   dsku_, _kýrs, _vihṛ, ждот, 
   {{0xd25056e1,0xc87820a9,0x6ee82d9a,0x00000000}},	//   بند_, _alşy_, _mübt, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3944dd69,0xb2700166,0x28cc0562,0x00000000}},	//   imos_, _еклә, _सोफि, --, 
   {{0x28cc0412,0x69c000b5,0x39440051,0x00000000}},	//   _सोनि, ænek, hmos_, --, 
   {{0x3f800067,0x7ce801ef,0x00000000,0x00000000}},	//   asku_, _nýrs, --, --, 
   {{0x3f801155,0xe214011a,0x6ee806be,0x00000000}},	//   bsku_, _לקוח_, _rübu, --, 
   {{0x6ee800ac,0x3944030a,0x09c80327,0xc8780166}},	// [21530] _sübu, dmos_, ིཀྐ_, _reş_, 
   {{0x39450983,0xc8780139,0x00000000,0x00000000}},	//   emos_, _seş_, --, --, 
   {{0x9fa0068c,0xb7e400cc,0xdcfc00e2,0x09b003d4}},	//   _pèça_, _খেলত_, gurē, ছিভা, 
   {{0x7ce80a87,0x39440816,0x00000000,0x00000000}},	//   _dýrs, gmos_, --, --, 
   {{0xdb0400a2,0x00000000,0x00000000,0x00000000}},	//   lwiý, --, --, --, 
   {{0x85b94b99,0x2d8001a4,0xc87800a2,0x3af408a5}},	//   لابس_, osje_, _weş_, _tæpa_, 
   {{0x2d800385,0x1994d77e,0x05780597,0x286807fa}},	//   nsje_, _наря, جمعة_, _брзо_, 
   {{0xf8ac021a,0x3f814b9a,0x2d814b9b,0x6ab40120}},	//   _لکه_, ysku_, isje_, lexf, 
   {{0x290d4b9c,0xe3dc0183,0x6ee800a2,0x00000000}},	//   miga_, _বেজব, _jübs, --, 
   {{0x290d4b9d,0x2d80334b,0x41a802a9,0x818403c5}},	//   liga_, ksje_, авон_, огож, 
   {{0x461404d3,0x2d8009b6,0x290c04c9,0x3f800210}},	//   _بوار, jsje_, oiga_, wsku_, 
   {{0x290d4b9e,0x3f8004b9,0xa4f4034c,0x2d800b21}},	//   niga_, tsku_, _دکتر_, dsje_, 
   {{0x2d814b9f,0x254401d3,0xd3a801c6,0xe8dc0208}},	//   esje_, _dőlt_, _хvрэ, _chỉn_, 
   {{0x290d4ba0,0x3f814ba1,0x7ce80008,0x63b94ba2}},	//   higa_, rsku_, _nýrr, mwun, 
   {{0x6ab40175,0x63b80036,0xded00023,0x28cc00bc}},	//   dexf, lwun, ብስኻ_, _सोभि, 
   {{0x3f802d2b,0x63b800e8,0x244c0205,0x00000000}},	//   psku_, owun, _gömü_, --, 
   {{0x290d4ba3,0x2d800225,0x63b94ba4,0xb05801b8}},	// [21540] diga_, asje_, nwun, idäl, 
   {{0x60c54ba5,0xacb80225,0xdcfc00da,0x63b80a40}},	//   _haim, _skût, turē, iwun, 
   {{0x290d4ba6,0xfce54ba7,0xf86817de,0x63b80e78}},	//   figa_, _доно, لماي_, hwun, 
   {{0x63b800b4,0x60c54ba8,0x290d4ba9,0x39446b78}},	//   kwun, _jaim, giga_, umos_, 
   {{0x39454baa,0x60c54bab,0xdb042a28,0x7ce803b2}},	//   rmos_, _maim, ntië, _fýrr, 
   {{0x394474c3,0x60c54bac,0x290c096b,0xab5807c5}},	//   smos_, _laim, aiga_, _prüv, 
   {{0x290d4bad,0x6ee80724,0xbbb8007d,0x63b804ba}},	//   biga_, _kübr, _उनुक, ewun, 
   {{0x443c0639,0x290d4bae,0x93780108,0xb0580166}},	//   _bzw_, ciga_, ббит_, gdäl, 
   {{0x443c033f,0xe61400fd,0x63b80327,0x00000000}},	//   _czw_, йдә_, gwun, --, 
   {{0x2d800225,0xc5e8015b,0xf1a4033a,0x12240014}},	//   ysje_, _কইরা_, ормн, ۪ٹھَ, 
   {{0x60c54baf,0x63b8fa60,0x28cc07af,0x3668014b}},	//   _baim, awun, _सोडि, _баҷо_, 
   {{0x60c40e89,0xab580793,0x63b83a41,0xb10800fe}},	//   _caim, _krüt, bwun, ৰত্ব_, 
   {{0x2904020c,0x00000000,0x00000000,0x00000000}},	//   ènai_, --, --, --, 
   {{0x2d80334b,0xd3a801c6,0xdd7401d9,0x00000000}},	//   tsje_, _хvсэ, ژھُک, --, 
   {{0x290d4bb0,0x60c54bb1,0x443c281e,0x2d8001f5}},	//   yiga_, _faim, _zzw_, usje_, 
   {{0x290c102c,0x60c54bb2,0x2d814bb3,0xe9b40014}},	//   xiga_, _gaim, rsje_, ۪ناں_, 
   {{0x2d44015d,0xb0594bb4,0x2d8001f5,0x6ab40175}},	// [21550] _bŵer_, ndäm, ssje_, texf, 
   {{0xdb051954,0xad64092f,0x2d814bb5,0x290d4bb6}},	//   ntiè, _واجه, psje_, wiga_, 
   {{0xb0591fe7,0x60c497bb,0x63b803fa,0xdb041e54}},	//   ydäl, _yaim, zwun, itiè, 
   {{0x636401f1,0x60c4056a,0x290c0618,0x6ee8029f}},	//   nčný, _xaim, uiga_, _gübr, 
   {{0x290d4bb7,0xde954bb8,0x867402d3,0x98140633}},	//   riga_, _عجیب, _ጽሕፍቲ_, وبها, 
   {{0x290d4bb9,0xbaa400d1,0xb0594bba,0x00000000}},	//   siga_, _нусқ, ddäm, --, 
   {{0x290c00b2,0x3a800014,0x443c01a4,0x25600166}},	//   piga_, _سینِ, _szw_, _bıla_, 
   {{0x290ca617,0xab5807c5,0x63b80526,0x9f445f48}},	//   qiga_, _früt, twun, ámú_, 
   {{0xf8b401c0,0x68f94bbb,0xab580b70,0xdddc00e4}},	//   _хөх_, _ilud, _grüt, rarũ, 
   {{0x60c4c2b3,0x443c0196,0x63b94bbc,0x68f80393}},	//   _saim, _vzw_, rwun, _hlud, 
   {{0x68f94bbd,0xe8dc01fb,0x63b8f1d3,0xab58000d}},	//   _klud, _nhịn_, swun, _krüs, 
   {{0x443c0034,0x60c406be,0xbae001ec,0x00000000}},	//   _tzw_, _qaim, _ﺍﻷﺤﺎ, --, 
   {{0x60c54bbe,0x291c009f,0x26c4058a,0x00000000}},	//   _vaim, _mjua_, odno_, --, 
   {{0x60c54bbf,0xdb0401f5,0x68f911b1,0x636400d0}},	//   _waim, rtië, _llud, ačný, 
   {{0x60c54bc0,0x68f94bc1,0x57b8068f,0xcdc54bc2}},	//   _taim, _olud, _इन्ह, марқ, 
   {{0x60c4952b,0x8ae40150,0x614415bf,0x00000000}},	//   _uaim, _ﺍﻷﻨﻅ, _تىبە, --, 
   {{0x212000f2,0x2d4403cb,0x50380150,0x28cc00bc}},	// [21560] _ijih_, _pŵer_, _ويىڭ_, _सोधि, 
   {{0x291c009f,0x934400d1,0x00000000,0x00000000}},	//   _ajua_, ﺮﯨﺪﯗ_, --, --, 
   {{0xd910020e,0x291c0036,0xc4bc012d,0xef1c0205}},	//   نیس_, _bjua_, ्याओ, rrüt_, 
   {{0x7e7c28ac,0x68f94bc3,0xa3d80316,0x26c40009}},	//   _hepp, _clud, डमा_, edno_, 
   {{0x7e7d4bc4,0x68f8009a,0xab580086,0x2ca40213}},	//   _kepp, _dlud, _drüs, ənd_, 
   {{0x7e7d4bc5,0x25600790,0x16341422,0x00000000}},	//   _jepp, _sıla_, меля, --, 
   {{0x68f94bc6,0x7e7d4bc7,0x2ca80332,0xe7340798}},	//   _flud, _mepp, _éidí_, џеј_, 
   {{0x7e7d4bc8,0x68f94bc9,0xab594bca,0x01d0009e}},	//   _lepp, _glud, _grüs, াহাদ, 
   {{0x38640077,0xdb0406af,0xef24010e,0x00000000}},	//   mcor_, ttiè, lpüň_, --, 
   {{0xe3ac75a6,0xb0580598,0x7e7d4bcb,0x98b802d5}},	//   اري_, rdäm, _nepp, _kurį_, 
   {{0xb5c89ce2,0xdb054bcc,0x291c0022,0xb058343a}},	//   _دوام_, rtiè, _yjua_, sdäm, 
   {{0xdb054bcd,0x386490bf,0xc8780166,0xb0580432}},	//   stiè, ncor_, _poşi_, mdäk, 
   {{0x7e7d4bce,0xdb04004a,0x636400d0,0x3ce402dd}},	//   _bepp, ptiè, rčný, _ﺍﺠﺘﻤ, 
   {{0x7e7c6933,0x83300022,0x91fc0055,0x00000000}},	//   _cepp, _иҽых, bbāp, --, 
   {{0x7e7d4bcf,0xb05809a5,0x1df94bd0,0xb63c00b5}},	//   _depp, ndäk, перы_, _ｂｈ_, 
   {{0x26c40427,0x7e7c38e1,0x00000000,0x00000000}},	//   zdno_, _eepp, --, --, 
   {{0x7e7c00e8,0xb0594bd1,0x00000000,0x00000000}},	// [21570] _fepp, hdäk, --, --, 
   {{0x7658074d,0x68f86a88,0x7e7c011c,0xb05800ee}},	//   _ngty, _slud, _gepp, kdäk, 
   {{0x68f94bd2,0x386419f5,0x26c40010,0xdddc00e5}},	//   _plud, fcor_, vdno_, bbrő, 
   {{0xf09d4bd3,0x765800ee,0x481409a5,0x63800241}},	//   ngà_, _agty, ммес, _jìná, 
   {{0x2b914bd4,0x7e7d4bd5,0xf09c0268,0x07a4bde0}},	//   _سیاس, _yepp, igà_, фалн, 
   {{0x2a700175,0x76b40116,0xdb0402f0,0x45d40902}},	//   qbxb_, мһур_, ytié, дцит, 
   {{0x49053b7b,0x1a680133,0x765806be,0x291c0200}},	//   _قوسق, _رینی_, _dgty, _tjua_, 
   {{0x68f94bd6,0x38640bfa,0x00000000,0x00000000}},	//   _ulud, ccor_, --, --, 
   {{0x25a40196,0x10a00075,0xe7740014,0x6e340267}},	//   stnl_, _ﺋﯚﺯﯨ, _رلاں_, _lyxb, 
   {{0xf09d4bd7,0xa2801d0a,0xdcfc00c0,0x00000000}},	//   egà_, ریبو, burė, --, 
   {{0x7e7d4bd8,0x612800fd,0x68400248,0x05c0012c}},	//   _repp, nılg, _fìdí, _शनिब, 
   {{0xdb042760,0x7e7d4bd9,0xf09c026c,0xe50400c6}},	//   rtié, _sepp, ggà_, _عباي, 
   {{0x76580209,0xe8dc01fb,0x7e7c202b,0x82a400db}},	//   _ygty, _nhọn_, _pepp, _жалж, 
   {{0x249d4bda,0xdb040113,0x6e34007c,0x026002f2}},	//   lgum_, ywiñ, _byxb, _جێدێ, 
   {{0xada028a9,0x6da01cc9,0x00000000,0x00000000}},	//   карл, кира, --, --, 
   {{0x249c11c3,0x7e7c009a,0xc8780790,0x00000000}},	//   ngum_, _wepp, _koşu_, --, 
   {{0xe8dc01dc,0x38c40024,0xef1c0205,0x00000000}},	// [21580] _chọn_, _jūrų_, rrür_, --, 
   {{0xdb1c01d3,0xb05801f4,0xef1c4e7e,0xf9f8009a}},	//   _ízül, ydäk, lsün_, يراث_, 
   {{0xf8d80073,0x89f40006,0x5ec40154,0x6128013d}},	//   णालय, няцц, শাদে, gılg, 
   {{0xef1c4e7e,0x274401ef,0x8a4400db,0x00000000}},	//   nsün_, _lůně_, رئلم, --, 
   {{0x7658010a,0x249d10de,0x25600139,0xd6b400a7}},	//   _pgty, dgum_, _bılo_, ейлъ, 
   {{0x38654bdb,0xdcfc0006,0x35694bdc,0x98b80064}},	//   scor_, turė, орин_, _turį_, 
   {{0x94180cc1,0x28cc06ab,0xef1c03e0,0x671c000d}},	//   ərə_, _सोवि, ksün_, _बदरक_, 
   {{0x61280ba5,0xb0594bdd,0x249d4bde,0xab581d13}},	//   nıld, rdäk, ggum_, _krüp, 
   {{0x69e00276,0xef1c06be,0x00000000,0x00000000}},	//   ăteş, dsün_, --, --, 
   {{0xb5d82d4b,0xdcfc0153,0xbb8801ec,0x2d5c00a2}},	//   _وباء_, purė, _ﺗﻪﻟﻪ_, lçeň_, 
   {{0xf09c1570,0x612803ee,0x91fc0055,0x66e001af}},	//   tgà_, kıld, ccāl, _шофа, 
   {{0xbae00220,0x35140066,0x00000000,0x00000000}},	//   _ﺍﻷﺴﺎ, _غذاس, --, --, 
   {{0xf09c1186,0x752001d5,0x61280213,0x1fb40a89}},	//   rgà_, _ijoz, dıld, ксёр, 
   {{0xf09c0109,0x649401ee,0x00000000,0x00000000}},	//   sgà_, _етәр_, --, --, 
   {{0x9e35352b,0x5e580276,0x88d4002b,0x00000000}},	//   верч, диря_, _kṛth, --, 
   {{0xf09c067c,0x25dc01ad,0x6128008e,0x00000000}},	//   riàs_, कमती_, gıld, --, 
   {{0xf09c381a,0xc87803e3,0x8ca408df,0x3c800150}},	// [21590] siàs_, _xoşu_, ङ्गो, _ﺩﻩﺷﻰ_, 
   {{0xaa0000f1,0x00000000,0x00000000,0x00000000}},	//   پېري, --, --, --, 
   {{0xb0580036,0x7c2402f0,0xed3000e5,0x249c0174}},	//   edäi, _exkr, _لودھ, ygum_, 
   {{0x09b000bd,0x61280724,0x752001c8,0xfdf40375}},	//   ছিলা, rılg, _njoz, _נצרת_, 
   {{0xab58002f,0x7e6006be,0x00000000,0x00000000}},	//   _grüp, _şopi, --, --, 
   {{0xb6a03773,0xc8780276,0x8578084c,0x69c0005c}},	//   гишл, _roşu_, псит_, ænes, 
   {{0x05554bdf,0xe610107f,0xa8a54be0,0x249d4be1}},	//   нтия, خشش_, _орак, tgum_, 
   {{0xf5300120,0x58d400f3,0x00000000,0x00000000}},	//   лејќ, _иост, --, --, 
   {{0x249d4be2,0x57a54be3,0xbb3c0131,0x61280205}},	//   rgum_, _ашха, ﻟﯘﻕ_, nıle, 
   {{0x75202572,0x61281b07,0xc2c4007b,0x4ad40037}},	//   _ejoz, zıld, ريجي, _डोमव, 
   {{0x61289d58,0x274400bc,0xe3ac0451,0xb0580142}},	//   yıld, _vůně_, ارڊ_, ndäw, 
   {{0xcea80d65,0x61280c3c,0x6f1801e4,0xa48400e5}},	//   _לי_, xıld, ɩuci, _آجان, 
   {{0xd3c40220,0xef1d2828,0x9484010b,0x8f8002dd}},	//   _ақыл_, rsün_, _рыхд, ақыл, 
   {{0x82a4010b,0x61e4005c,0x612803e0,0x00000000}},	//   _чакж, øjls, dıle, --, 
   {{0x61280d9c,0x00000000,0x00000000,0x00000000}},	//   tıld, --, --, --, 
   {{0x28cc0254,0x261400c5,0x00000000,0x00000000}},	//   _सोलि, _भइनी_, --, --, 
   {{0x61281ae9,0x8b654be4,0x7118011a,0x00000000}},	// [215a0] rıld, نالم, _מוקפ, --, 
   {{0x6128247e,0x20ac02a0,0xafe0074d,0x00000000}},	//   sıld, ट्रध, _соьл, --, 
   {{0x61284953,0x91fc00e2,0x00000000,0x00000000}},	//   pıld, ecāj, --, --, 
   {{0xab58000d,0xe9700214,0x612803e0,0xef1c03e0}},	//   _ksül, اهند, bıle, hsül_, 
   {{0x69c0037e,0x7d14a6a6,0x00000000,0x00000000}},	//   æner, miys, --, --, 
   {{0x66e02401,0xb05801c7,0x7d143d3c,0x00000000}},	//   лоча, rdäi, liys, --, 
   {{0xaa409cf3,0x88d40a28,0x256003e0,0x00000000}},	//   _берл, _pṛth, _fılm_, --, 
   {{0xdb080598,0x7bc40a73,0x273801fb,0x80c805d7}},	//   şlär, _ksku, hênh_, ियों, 
   {{0xefcc00b7,0x7aec058a,0x88d400cd,0x00000000}},	//   _ብፁዕ_, _kobt, _vṛth, --, 
   {{0x7aec1308,0x78a025d8,0x51f80212,0x853401b9}},	//   _jobt, lgov, дною_, _یولچ, 
   {{0x9f44012c,0x7aec3733,0x7bc403b2,0x066400db}},	//   ámý_, _mobt, _lsku, _شالپ, 
   {{0x78a14be5,0x7bc54be6,0x7aed30ba,0xdb04003a}},	//   ngov, _osku, _lobt, ntiâ, 
   {{0x7d154be7,0x78a00810,0xb0580793,0xdfd80395}},	//   diys, igov, veäd, нър_, 
   {{0xb9000003,0x68e000d2,0x7aec047e,0x799c0099}},	//   _ཧོ_, êndz, _nobt, kupw, 
   {{0x7bc4044e,0x32180022,0x00000000,0x00000000}},	//   _asku, _ãpy_, --, --, 
   {{0x23b40d5f,0xd90404fb,0x7d140205,0xb060013d}},	//   _अहमद, _طی_, giys, _şäfq, 
   {{0x7aed4be8,0xe8dc0208,0xef1c2ca8,0x61280139}},	// [215b0] _bobt, _nhền_, lsüm_, bılb, 
   {{0xd5b800ef,0x612803e0,0x35940240,0x00000000}},	//   _opā_, rıle, ዘኒታት_, --, 
   {{0x7bc4152d,0x7aed4be9,0xef1c07c5,0x89d8cdd6}},	//   _esku, _dobt, nsüm_, بوار_, 
   {{0x78a00d04,0xdd980598,0x87b801af,0x24640ca8}},	//   ggov, _яшь_, дукт_, _mímó_, 
   {{0xd5b8f4b4,0x46a43c18,0xdddc8e50,0x7d180100}},	//   _apā_, валв, parţ, ètse, 
   {{0x7aed4bea,0x07086762,0x00000000,0x00000000}},	//   _gobt, بيتي_, --, --, 
   {{0x50b00c66,0xd1dc0023,0x00000000,0x00000000}},	//   जभाष, ዕቃብ_, --, --, 
   {{0x69c4943f,0x78a001fa,0xdddc00c0,0x00000000}},	//   _isje, cgov, narš, --, 
   {{0xd46800c6,0xb3812e74,0xd7f8014b,0x18b800ee}},	//   رحيم_, алыл, _пуф_, _ягты_, 
   {{0xdcfc005f,0xded00b82,0x42e800d4,0x051000eb}},	//   turī, ብትን_, ємно_, হকের_, 
   {{0x6d4002b1,0x412801c6,0x6b9c0477,0xef1c0166}},	//   _īnan, доно_, huqg, gsüm_, 
   {{0xdddc009b,0x741003e6,0x00000000,0x00000000}},	//   jarš, اویا, --, --, 
   {{0xaca001f2,0x03a4084c,0xab58000d,0xdddc0427}},	//   _chọb, _рило, _asüm, darš, 
   {{0x69c4036f,0x78a004b9,0x00000000,0x00000000}},	//   _osje, zgov, --, --, 
   {{0x7aeca82c,0x7d151b34,0x23a801bf,0x5348030d}},	//   _robt, tiys, løj_, _чăрă, 
   {{0x62814beb,0x7aec1e7b,0xdddc00e2,0x7bc400ef}},	//   _heno, _sobt, garš, _psku, 
   {{0x7aec01d4,0x7d154bec,0x69c4002d,0x6b614bed}},	// [215c0] _pobt, riys, _asje, икта, 
   {{0x62814bee,0x799c00ec,0xef1401c0,0x7d14a6a6}},	//   _jeno, tupw, _амь_, siys, 
   {{0x62814bef,0x23a869e8,0xc5e4004b,0x7bc4012d}},	//   _meno, høj_, _اړ_, _wsku, 
   {{0xdcb000db,0x799c0455,0x3b8401d5,0xe8dc0051}},	//   _دۉر_, rupw, _илмг, _phền_, 
   {{0x7bc54bf0,0x62812c5b,0x7aec0455,0x56954bf1}},	//   _usku, _oeno, _tobt, галт, 
   {{0x62814bf2,0x799c030d,0x78a001e4,0xd1d40240}},	//   _neno, pupw, sgov, _ክሞቱ_, 
   {{0xa56007d6,0xf8640107,0x49901f7e,0xb0580139}},	//   لگنن, _авбо, _هیلر, ldät, 
   {{0xe0e402f5,0xef1c0213,0x00000000,0x00000000}},	//   মসুন, vsüm_, --, --, 
   {{0x62814bf3,0x61280ac4,0x3668036b,0x53340d1d}},	//   _beno, zılc, _жазо_, леит, 
   {{0x9af002a8,0xb8840162,0x28100116,0x00000000}},	//   _ƙaƙa_, _fríø, _ئوكس, --, 
   {{0x11d800c6,0xb9d802d3,0xf0741321,0xb0580108}},	//   روحة_, _አነ_, кинә_, hdät, 
   {{0x62814bf4,0x798c02d0,0x61280790,0xd6c400fe}},	//   _eeno, _mvbw, vılc, _এচিয, 
   {{0xef1c1cce,0xdd900050,0x00000000,0x00000000}},	//   ssüm_, ۪وِ_, --, --, 
   {{0x62814bf5,0x24640241,0x802400ec,0xb058013d}},	//   _geno, _tímó_, ارٽم, ddät, 
   {{0xdddc0232,0x4c940212,0xd0d40354,0x3ebc0254}},	//   tarš, ливс, _бойъ, õtta_, 
   {{0x62814bf6,0x7e60054e,0x271c012d,0x61280205}},	//   _zeno, _şopt, _बद्र_, rılc, 
   {{0xc0cc001f,0x6280fed7,0x00000000,0x00000000}},	// [215d0] ብንም_, _yeno, --, --, 
   {{0xdd1c02fb,0xd5b40490,0x61280205,0x00000000}},	//   _vášn, ूबाज, pılc, --, 
   {{0x61280bfc,0xae000131,0x00000000,0x00000000}},	//   lıla, _ئۈزى, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x61288eb9,0x1be407d6,0x97c400cf,0x9b680c75}},	//   nıla, _кўрг, لتوم, _ашса_, 
   {{0x69c54bf7,0x9b640075,0x7bd8010f,0x00000000}},	//   _tsje, _ئۆلۈ, _אַלק, --, 
   {{0xdb040120,0x7ce80209,0x69c41710,0x99646be2}},	//   stiã, _aýry, _usje, _втул, 
   {{0x62814bf8,0x23a8019b,0x044443cf,0x61280259}},	//   _seno, tøj_, лейн, kıla, 
   {{0x62814bf9,0xa2802be7,0xa83401d5,0xc7d8dfe7}},	//   _peno, لیشو, _شعرش, _ямах_, 
   {{0x61289d58,0x00000000,0x00000000,0x00000000}},	//   dıla, --, --, --, 
   {{0x62814bfa,0x00000000,0x00000000,0x00000000}},	//   _veno, --, --, --, 
   {{0x62814bfb,0xb0580108,0x3ce001ec,0x40b401d9}},	//   _weno, ydät, _ﺇﻗﺎﻤ, چھکھ_, 
   {{0x62814bfc,0x6128247e,0x9f6056f8,0xb058008e}},	//   _teno, gıla, _örüp_, ddäs, 
   {{0x33914bfd,0x6f040268,0x6280a952,0x0eb80500}},	//   _الوز, ghjc, _ueno, кусы_, 
   {{0xb174001e,0xeb94723c,0x25600139,0x1c0c000d}},	//   _trượ, һит_, _bıli_, _सेजल_, 
   {{0x61285531,0x2c1c03d4,0xb27001af,0xb0580139}},	//   bıla, _দৰেই_, _кләш, gdäs, 
   {{0x6128708d,0x00000000,0x00000000,0x00000000}},	// [215e0] cıla, --, --, --, 
   {{0x6f040ffb,0x6720003e,0xb058f7ca,0x300000ee}},	//   chjc, jnnj, rdät, _ызыг, 
   {{0x443c0142,0x00000000,0x00000000,0x00000000}},	//   _lyw_, --, --, --, 
   {{0xfce40364,0x3234010f,0xb5a401d5,0x00000000}},	//   _сомо, אטען_, ҳрий, --, 
   {{0x443c04ba,0xdb040022,0x06cc0011,0xb0580166}},	//   _nyw_, atiá, লানি, ldär, 
   {{0x78b40055,0x00000000,0x00000000,0x00000000}},	//   _śavā, --, --, --, 
   {{0xe1e54bfe,0x61280baf,0x443c1e92,0xb0594bff}},	//   _اس_, zıla, _ayw_, ndär, 
   {{0x443c0cfd,0x612871e1,0x1ccc025c,0x318c0165}},	//   _byw_, yıla, _ྲིས_, vęz_, 
   {{0xb1913298,0x443c03cb,0x612800ac,0xb284010a}},	//   әлмә, _cyw_, xıla, лынк, 
   {{0xc87847af,0xf2c54c00,0x443c0368,0x929410fc}},	//   _inşa_, усин, _dyw_, јанц, 
   {{0xb4f00209,0xb058adae,0xef1c01d3,0xf3380023}},	//   _гүйч, ydäs, ssük_, _ከባቢና, 
   {{0x61283e67,0x443c00a9,0x00000000,0x00000000}},	//   tıla, _fyw_, --, --, 
   {{0x6b480e78,0xe3ac3b8c,0x443c0042,0x88340240}},	//   lüge, _فرو_, _gyw_, _እናተሰ, 
   {{0x61282c70,0xb8240154,0xdb040162,0x00000000}},	//   rıla, _বরাত_, ytiá, --, 
   {{0x6b480730,0x61294c01,0xf19000e5,0x00000000}},	//   nüge, sıla, _اُبھ, --, 
   {{0x61280ab7,0xab5800c5,0x8c1800ec,0x00000000}},	//   pıla, _tsük, پيئر_, --, 
   {{0x443c0218,0x3cf400c5,0xa0740139,0x7d18007f}},	// [215f0] _xyw_, _एकरे_, _угыч, ètsa, 
   {{0x91a817e6,0x7320031c,0xdf743090,0x00000000}},	//   _कमाई, _ཤམྦྷ_, _اديب, --, 
   {{0x06cc2aab,0xab5804cc,0x8938004b,0x49a401ec}},	//   লামি, _krüz, نګرس_, рызғ, 
   {{0xbb3c0ed1,0xdb040561,0x00000000,0x00000000}},	//   ﻟﻘﻰ_, rtiá, --, --, 
   {{0xdb040615,0x2560002d,0x6ee80205,0x91fc00b8}},	//   stiá, _műle_, _süby, ccāv, 
   {{0x6b480639,0x443c0368,0x859400ea,0xfbd00118}},	//   füge, _ryw_, ашиц, सिरम, 
   {{0x5a444077,0x00000000,0x00000000,0x00000000}},	//   _гэта, --, --, --, 
   {{0x19580220,0x76b40116,0xd618007b,0x00000000}},	//   _басы_, гләр_, دتها_, --, 
   {{0xab5800af,0x74e401c0,0x3af408a5,0x9cd8011a}},	//   _psüh, рдыг_, _tæpt_, רוחה_, 
   {{0x82f44fdb,0x57f40640,0x6b480e78,0xd7f40166}},	//   рчиц, _упут, büge, _узуы, 
   {{0xf2e400f2,0x3cf40bae,0x00000000,0x00000000}},	//   شکوه_, _एकले_, --, --, 
   {{0xab5805d5,0x2a4402d3,0x7f5c022e,0x00000000}},	//   _crüz, _ንኢትዮ, _sipq, --, 
   {{0xd36c0220,0xefc4020f,0x61280139,0x00000000}},	//   _كۇي_, алял_, bıln, --, 
   {{0x2ca80334,0x7f5c047e,0x00000000,0x00000000}},	//   _accd_, _qipq, --, --, 
   {{0x764c02fb,0x1ce40327,0x0d981075,0x00000000}},	//   _úbyt, _ྩོད_, лтты_, --, 
   {{0xb0594c02,0x02c42435,0x00000000,0x00000000}},	//   rdär, _वसुन, --, --, 
   {{0xed55439c,0xa114021a,0xb0582e23,0x6b48f6d6}},	// [21600] рот_, _پوښت, leän, züge, 
   {{0xe8a40023,0x00000000,0x00000000,0x00000000}},	//   _ዘምለጡ_, --, --, --, 
   {{0x2560013d,0x16140210,0x00000000,0x00000000}},	//   _kılu_, तज़ार_, --, --, 
   {{0x3f90002b,0x6ee80139,0x2734013a,0x00000000}},	//   _kvyu_, _sübx, hýně_, --, 
   {{0xeb9401fc,0xb81403e5,0x7d054c03,0x98940116}},	//   _кия_, _देशम_, _ilks, _қувә, 
   {{0x7bd4019f,0xb0583b22,0x5ec40154,0x00000000}},	//   mvyu, keän, শাকে, --, 
   {{0xf5e40220,0xdddc00b8,0x00000000,0x00000000}},	//   рілм, dbrū, --, --, 
   {{0x6d4000b0,0x6b48061f,0x048400b1,0xa50400d8}},	//   _īnak, rüge, бәши_, иеја_, 
   {{0xacb8002d,0xd250004b,0x6b4805d5,0xdb041347}},	//   _sjûk, ګند_, süge, rtiæ, 
   {{0xf1a801d5,0xf744e78a,0x4ec800fe,0x3264854b}},	//   پاده_, _тезо, শাৱল, штив, 
   {{0xb0580732,0x8ad8008f,0x7d040857,0x27301b56}},	//   geän, אַרפ, _olks, _بىلس, 
   {{0xe5a0010a,0x799c015d,0xb06801d5,0x00000000}},	//   _фици, irpw, ърож_, --, 
   {{0x8534571d,0xaf34009a,0x91fc00de,0x00000000}},	//   _اونچ, لرست, ecāt, --, 
   {{0x61294c04,0x7d054c05,0xc0c00092,0xa2d04fde}},	//   lıll, _alks, _ትዳር_, _وينت, 
   {{0xe294026a,0x7d0402d0,0xb0580309,0xdd940c75}},	//   _тај_, _blks, rdäq, жасы, 
   {{0xb89800b8,0xd2500a81,0xdb0401f4,0x00000000}},	//   _biḍā, _وچھ_, htiä, --, 
   {{0xea64a4e3,0xab84011b,0x8bd85e82,0x00000000}},	// [21610] ањен, рубк, ымас_, --, 
   {{0xed5c0165,0x261400af,0x7d040171,0x612803e0}},	//   _wiþ_, _भइली_, _elks, hıll, 
   {{0x612803e0,0x91fc00b8,0x00000000,0x00000000}},	//   kıll, ccāt, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb0580036,0xdb04008e,0x612808a9,0x00000000}},	//   zeän, ftiä, zılo, --, 
   {{0x612800ac,0x00000000,0x00000000,0x00000000}},	//   yılo, --, --, --, 
   {{0xa490dd80,0xc5d40845,0xe8dc01fb,0x19952eab}},	//   قیات, сіль, _nhện_, _маря, 
   {{0x28cc1715,0x1cb40327,0x6ac4121d,0x06cc00cc}},	//   _सोचि, ྟུར_, _रघुर, লাধি, 
   {{0x2614012c,0xf1c402f0,0xf4540055,0x00000000}},	//   _भेरी_, šálu_, biḍā_, --, 
   {{0x3f901529,0xdb054c06,0x25600166,0x7bd8010f}},	//   _rvyu_, rtiç, _sılu_, אַטק, 
   {{0xdb040261,0x6b9c0175,0x68400419,0x61280139}},	//   stiç, hrqg, _dídž, bıll, 
   {{0xdb0403cd,0x2560013d,0x61280213,0x91fc0171}},	//   mtiå, _qılu_, cıll, ecās, 
   {{0x1cb40135,0xb058023a,0xa06800c7,0xaaa40118}},	//   ྟུལ_, seän, лаҟа_, खलाक, 
   {{0x64494c07,0x84e405f9,0xb0584e14,0x11f803e6}},	//   _izgi, कावट_, rdäp, اوێک_, 
   {{0x7d0400da,0xf2d000c8,0xfce416ab,0xb0583f50}},	//   _plks, _מעג_, бово, sdäp, 
   {{0x3c640953,0x4094007b,0x6d4d4c08,0xbc642151}},	//   скаг, _الظر, _chca, свак, 
   {{0x6128050e,0x6d4c3e7b,0xbea45541,0xebe01d39}},	// [21620] nılm, _dhca, _лапк, потп, 
   {{0xa0300020,0x1ce4031c,0x7bd54c09,0x91fc002b}},	//   ተያየቶ, _ྩོམ_, rvyu, ccās, 
   {{0x6d4c01ab,0x612843bc,0x26140037,0x00000000}},	//   _fhca, yıll, _भेली_, --, 
   {{0x612803ee,0x644801b9,0x6d4c00a3,0xc98400c6}},	//   kılm, _ozgi, _ghca, تشكي, 
   {{0xf7446392,0x3b90001f,0xab5807c5,0xdb040108}},	//   бедо, ምጃዎች_, _spüe, ttiä, 
   {{0x612803be,0x00000000,0x00000000,0x00000000}},	//   dılm, --, --, --, 
   {{0x64494c0a,0x69040120,0x29d4031c,0xdb0400fd}},	//   _azgi, órdã, _għa_, rtiä, 
   {{0x5398a4cb,0xdb04adae,0x00000000,0x00000000}},	//   авия_, stiä, --, --, 
   {{0xe61449c6,0xe8dc001e,0xe81c0cb4,0xe9445ec2}},	//   идә_, _nhộn_, _मइया_, _طرفی, 
   {{0x91b80120,0x6128236c,0xe3ac00e5,0x00000000}},	//   агот_, sıll, ڈری_, --, 
   {{0xe3ad4c0b,0x64480790,0xeb380a7c,0x00000000}},	//   وری_, _ezgi, רעיש, --, 
   {{0xd3e4028e,0x6128c8d8,0x6eb800cd,0x00000000}},	//   _وقای, bılm, श्नु, --, 
   {{0x64a00209,0x3454027d,0x00000000,0x00000000}},	//   _хача, _انشأ, --, --, 
   {{0x6d4d4c0c,0x59c8012c,0x00000000,0x00000000}},	//   _shca, रबार, --, --, 
   {{0x6d4c01ab,0x29040024,0xb058005b,0x00000000}},	//   _phca, ūnai_, meäm, --, 
   {{0x3ea80076,0x9d186a7c,0x90981078,0x6448010e}},	//   agbt_, бост_, _твит_, _yzgi, 
   {{0x6a64cfc7,0x91fc00cd,0x00000000,0x00000000}},	// [21630] مطال, ccār, --, --, 
   {{0xaa654c0d,0xeea81d0f,0x00000000,0x00000000}},	//   стак, _стик_, --, --, 
   {{0x612871e1,0x6d4c01ab,0x5f754c0e,0x2bb800c5}},	//   zılm, _thca, _وایر, _उहवा, 
   {{0x6ca412a2,0x61283bc2,0x1ccc031c,0xdcfc00e2}},	//   _урож, yılm, _ྲིག_, rurģ, 
   {{0x612800ac,0xc68801c6,0x06cc0011,0xfbcc00ec}},	//   xılm, айлж_, লাসি, _لڪل_, 
   {{0xab5800dd,0x2bcc00e1,0xdb040217,0xb0583b22}},	//   _csüt, _सैया, ttiå, jeäm, 
   {{0x1a68179e,0x00000000,0x00000000,0x00000000}},	//   _ایمی_, --, --, --, 
   {{0x612871e1,0x49054c0f,0xdb0403cd,0xb3140327}},	//   tılm, _بورق, rtiå, ྲིའང_, 
   {{0x5884010a,0x00000000,0x00000000,0x00000000}},	//   _хыса, --, --, --, 
   {{0x61283bc2,0x4224e4a2,0x56950e28,0xdb04068c}},	//   rılm, ждов, _наут, guiè, 
   {{0x61287975,0x26041ee1,0x8fc400c7,0x00000000}},	//   sılm, _учаг, ҟарҵ, --, 
   {{0xf990025f,0x61294c10,0x92e80150,0xb0580108}},	//   ורט_, pılm, _ۇرىق_, peäl, 
   {{0x20054c11,0x147436fe,0x00000000,0x00000000}},	//   ámi_, _رانج, --, --, 
   {{0x26c47bd6,0x1ccc0327,0xb7d8011a,0x00000000}},	//   neno_, _ྲིང_, בקשי, --, 
   {{0x6cf400bc,0x20040419,0x00000000,0x00000000}},	//   ीसंग_, šmi_, --, --, 
   {{0x26c54c12,0x3b8401c0,0xf1b0011a,0x00000000}},	//   heno_, жлаг, _חסה_, --, 
   {{0x26c54c13,0x5ba43419,0x00000000,0x00000000}},	// [21640] keno_, ялағ, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x26c41d2d,0xb9c400db,0xc87800a2,0xf9c81075}},	//   deno_, تقاي, _hoşy_, ргек_, 
   {{0xdb040597,0x31b800c8,0x6d400055,0x00000000}},	//   ntiú, יזענ, _ūnav, --, 
   {{0x26c54c14,0x6b48000d,0xb8f05a17,0x00000000}},	//   feno_, süga, _वस_, --, 
   {{0x6b480254,0x00000000,0x00000000,0x00000000}},	//   püga, --, --, --, 
   {{0xaa402ba5,0x80a8000d,0xb058005b,0x957c012d}},	//   _жерл, कलाइ, veäm, _mrąg, 
   {{0xf1c402f0,0xef1c0790,0xa96401af,0x00000000}},	//   šáku_, nsür_, _фита_, --, 
   {{0x39454c15,0x26c54c16,0xab58000d,0xf8c401f9}},	//   mlos_, beno_, _tsüt, ळजीप, 
   {{0x39445df0,0x00000000,0x00000000,0x00000000}},	//   llos_, --, --, --, 
   {{0xdb054c17,0xb5c80214,0x39440393,0xe8dc0208}},	//   guié, _خوام_, olos_, _nhớn_, 
   {{0x39440639,0x33840022,0xdcfc0205,0xb05801f4}},	//   nlos_, _дукв, ktrı, seäm, 
   {{0x7f74052f,0xb0580108,0x8d780092,0x394400c0}},	//   пҡыр_, peäm, ራጅተው_, ilos_, 
   {{0xdb054c18,0xf1a40063,0xb058005b,0x3944014f}},	//   quiè, _дрин, leäk, hlos_, 
   {{0x39440953,0xe1ec01c8,0x6230013d,0x91fc002b}},	//   klos_, _لسي_, _оешу, ccāp, 
   {{0xd9054c19,0xdb040597,0x26c54c1a,0x39440218}},	//   _شی_, ctiú, zeno_, jlos_, 
   {{0x39454c1b,0x26c40bd7,0xc878010e,0x612803e0}},	// [21650] dlos_, yeno_, _goşy_, zılk, 
   {{0x26c54c1c,0x39442760,0xa2440228,0xdcfc0135}},	//   xeno_, elos_, _ارۇۇ, rurġ, 
   {{0xdb04003a,0x3944002f,0xb05801f4,0xda780395}},	//   ntiù, flos_, keäk, юят_, 
   {{0x26c5455d,0x00000000,0x00000000,0x00000000}},	//   weno_, --, --, --, 
   {{0x4b2004a9,0x26c54c1d,0x60dc00c8,0xb89000cf}},	//   _كېرە, teno_, יקאנ, رلوع, 
   {{0x39440077,0x00000000,0x00000000,0x00000000}},	//   alos_, --, --, --, 
   {{0x39454c1e,0x06cc04c5,0x6b48000d,0x00000000}},	//   blos_, লালি, lügo, --, 
   {{0x39442137,0xf8acbe60,0x2f0c01ed,0x317c0334}},	//   clos_, _مکه_, _függ_, dptz_, 
   {{0x26c433dc,0x00000000,0x00000000,0x00000000}},	//   peno_, --, --, --, 
   {{0xcfd00f22,0x290c022e,0x00000000,0x00000000}},	//   ামান, lhga_, --, --, 
   {{0xd5b800f3,0xb4500092,0x00000000,0x00000000}},	//   _мсц_, _የዳርፉ, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd5142e6f,0x238001d9,0x8f7400d3,0xdb040332}},	//   _تبلغ, _کٔڈِ, дусі, rtiú, 
   {{0x3f9c0232,0x3ebc08a7,0xe7f04328,0x237c036e}},	//   čtu_, ýtt_, _आपना_, mpuj_, 
   {{0xdb054c1f,0x3240b328,0x3944a09e,0x3f68013e}},	//   quié, _пешг, ylos_, риҳо_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x0ba8afd5,0x3944ec0b,0xdddc00e5,0x6e3803e0}},	// [21660] قالى_, vlos_, rcrő, ğuba, 
   {{0x2e24016b,0xe81c1fc4,0x39440009,0xdb0401bf}},	//   _fεf_, _मेधा_, wlos_, ntiø, 
   {{0x42780020,0x39450388,0x6bd40014,0x00000000}},	//   _የአንድ_, tlos_, _ہوَس_, --, 
   {{0xaa54007b,0x237c0477,0x3cf401f9,0x6b48f02d}},	//   سلنا_, kpuj_, _एकटे_, lügl, 
   {{0xf74451a7,0xb814000d,0xb05801f4,0x00000000}},	//   педо, _देखम_, veäk, --, 
   {{0x3db80489,0x39454c20,0xe734299f,0xd944010b}},	//   _བྱོན, slos_, печ_, чеҗи, 
   {{0x39454c21,0x55540ee8,0x00000000,0x00000000}},	//   plos_, وپتر, --, --, 
   {{0x93794c22,0x290c036b,0x290402d3,0xb86400f1}},	//   обит_, chga_, ënat_, _رارو, 
   {{0xb05801f4,0x00000000,0x00000000,0x00000000}},	//   reäk, --, --, --, 
   {{0xa3a8006d,0xc7640447,0x957c033f,0x2f0c0139}},	//   गढ़_, _قالى, _prąd, _küge_, 
   {{0xb0580108,0xb46401af,0x00000000,0x00000000}},	//   peäk, _екел, --, --, 
   {{0x2f0c0790,0x00000000,0x00000000,0x00000000}},	//   _müge_, --, --, --, 
   {{0xe8dc01fb,0xdb0404cc,0x2f0c0112,0x15e401f9}},	//   _nhờn_, stiù, _lüge_, कमकर_, 
   {{0x290c0240,0x957c033f,0xdb0401ab,0x00000000}},	//   zhga_, _trąd, ptiù, --, 
   {{0xa2b8011a,0x00000000,0x00000000,0x00000000}},	//   _המוט, --, --, --, 
   {{0x61440261,0x9d184109,0x00000000,0x00000000}},	//   _пеја, пост_, --, --, 
   {{0xe8dc004d,0x6d400055,0x5ba401f4,0x00000000}},	// [21670] _chờn_, _ūnas, ерхз, --, 
   {{0xceb80166,0x21b400e5,0x00000000,0x00000000}},	//   _ьәм_, _بھیک_, --, --, 
   {{0x997401ec,0x00000000,0x00000000,0x00000000}},	//   еуіш, --, --, --, 
   {{0xdbcc01e1,0xb058007c,0x00000000,0x00000000}},	//   _kòìp, rfäf, --, --, 
   {{0x333c01c4,0x290c04ce,0x98f4d1ee,0x00000000}},	//   kotx_, rhga_, عثما, --, 
   {{0x290d4c23,0x85794c24,0x2f0cbff7,0x9b594c25}},	//   shga_, осит_, _füge_, _ният_, 
   {{0x29040af9,0x4614009a,0x00000000,0x00000000}},	//   ënas_, بوغر, --, --, 
   {{0xe0e84251,0x6b480730,0x290400e2,0x1cb40327}},	//   _পত্ন, zügl, īnas_, ྟུག_, 
   {{0x291c0751,0x19594c26,0x29040006,0x2f0c0e78}},	//   _imua_, _хаты_, ūnas_, _züge_, 
   {{0x68f94c27,0xdddc0024,0x291c0208,0x7d1801d3}},	//   _houd, varž, _hmua_, étsz, 
   {{0x68f94ab4,0xdebc0023,0x00000000,0x00000000}},	//   _koud, _ሲኢኑ_, --, --, 
   {{0x68f94c28,0x66e401e1,0x00000000,0x00000000}},	//   _joud, békà, --, --, 
   {{0x68f94c29,0x291c013f,0x67200076,0xe3b00214}},	//   _moud, _mmua_, oinj, _سرش_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdd1c0232,0x1ccc025c,0x644c0e3c,0x66014c2a}},	//   _vážn, _ྲིད_, škić, nynk, 
   {{0x68f94c2b,0x2f0c002f,0x00000000,0x00000000}},	//   _noud, _rüge_, --, --, 
   {{0x67214c2c,0x21200c6a,0x30e8012d,0x00000000}},	// [21680] kinj, _imih_, टारः_, --, 
   {{0x68f800c6,0x291d4c2d,0x67214c2e,0x00000000}},	//   _aoud, _amua_, jinj, --, 
   {{0x5a340588,0x3ebc00c5,0x2364036e,0x66000108}},	//   хьаӡ, õttu_, _minj_, jynk, 
   {{0x68f94c2f,0x6600068f,0x00000000,0x00000000}},	//   _coud, dynk, --, --, 
   {{0x68f94c30,0xac7539ad,0xdb054c31,0x22440208}},	//   _doud, _تاپش, nrië, _lynk_, 
   {{0x291d4c32,0xdddc033f,0x6600017a,0xe714007b}},	//   _emua_, karż, fynk, وينت_, 
   {{0x68f94c33,0xe57401e0,0x66e01d39,0x00000000}},	//   _foud, үзә_, тоја, --, 
   {{0x68f94c34,0xe81d4c35,0xa6e000c7,0x00000000}},	//   _goud, _मेवा_, ежәл, --, 
   {{0x67214c36,0x68412e8f,0x1ccc025c,0x248c0009}},	//   binj, _анта, _ྲིན_, _degm_, 
   {{0x67200b91,0x68f80936,0x23640007,0x21214c37}},	//   cinj, _zoud, _cinj_, _amih_, 
   {{0x68f94c38,0x23640399,0x360446e6,0x66e00e92}},	//   _youd, _dinj_, _تواف, _јоха, 
   {{0x7bc401f5,0x26142ce6,0xd130007b,0x957c012d}},	//   _opku, _भेटी_, امح_, _trąb, 
   {{0xdb040b21,0x74154c39,0x61140276,0x957c0210}},	//   rriê, _توشا, тдяу, _frąc, 
   {{0x212000d5,0x23640036,0x8458009d,0x00000000}},	//   _emih_, _ginj_, _эрхт_, --, 
   {{0x7bc4005f,0x9e240212,0xe8dc0051,0x00000000}},	//   _apku, вєтк, _nhởn_, --, 
   {{0xdb041a78,0x23640240,0x69100432,0x9d540014}},	//   brië, _zinj_, _içeg, ٖنِت, 
   {{0x68f94c3a,0x672120db,0x6600012d,0x61280139}},	// [21690] _roud, yinj, zynk, gılu, 
   {{0x68f94c3b,0x291d4c3c,0x67200009,0xb05801e3}},	//   _soud, _smua_, xinj, rfäd, 
   {{0x68f94c3d,0x4c94892a,0xdb040129,0x506401d5}},	//   _poud, _пинс, iriè, _ўтқа, 
   {{0x2d8056d4,0x6eb80c00,0x67200526,0xe7f0033f}},	//   mpje_, श्रु, winj, _आपदा_, 
   {{0x68f94c3e,0x2d8001a4,0x07a54c3f,0x2614033f}},	//   _voud, lpje_, халн, _भेजी_, 
   {{0xe7302550,0x2d8001f5,0x45d40e58,0x66014c40}},	//   خصص_, opje_, ецит, tynk, 
   {{0x67214c41,0xe81d4c42,0x68f94c43,0x236402d3}},	//   rinj, _मेरा_, _toud, _rinj_, 
   {{0x67214c44,0x66014c45,0x6d400998,0x23654c46}},	//   sinj, rynk, _ínad, _sinj_, 
   {{0x984801d9,0x660001f4,0x47340153,0x957c0210}},	//   _ہلہٕ_, synk, _знас, _prąc, 
   {{0xfbd00302,0x660006a3,0x212005b1,0xf7700375}},	//   נתי_, pynk, _smih_, _עקב_, 
   {{0x7df002dd,0x2d8001a4,0x56940117,0x00000000}},	//   _ءﻭﯕﯩ, jpje_, _рахт, --, 
   {{0xab5803fa,0xe8dc01fb,0x69c4025c,0xdb040373}},	//   _spül, _khốn_, _mpje, trië, 
   {{0xdb042508,0x2d800d27,0x13f40801,0x2bcc03ce}},	//   briè, epje_, _изця, _सैला, 
   {{0x63b94c47,0x69c54c48,0xdb054c49,0xfe4417b4}},	//   mtun, _opje, criè, енго, 
   {{0x63b94c4a,0x7bc4009a,0x7194007b,0xc4640345}},	//   ltun, _spku, _كنوز_, _تیکۆ_, 
   {{0x63b8009f,0x61442ba5,0x00000000,0x00000000}},	//   otun, _جىبە, --, --, 
   {{0x60c42001,0xe81c1b51,0x2d805d2e,0x69c401e3}},	// [216a0] _ibim, _मेला_, apje_, _apje, 
   {{0x63b94c4b,0x69c40129,0xe8dc0051,0x00000000}},	//   itun, _bpje, _phởn_, --, 
   {{0x63b94c4c,0xfd4800a7,0x3a04335b,0x18b400c7}},	//   htun, _нзок_, رکسی_, кәар, 
   {{0x63b94c4d,0xd9114c4e,0xf1b0025d,0xe4dc00c5}},	//   ktun, جیر_, רסא_, _खोलि_, 
   {{0x60c54c4f,0xe8dc01fb,0x2a7c05d1,0x63b83854}},	//   _mbim, _chốn_, _şube_, jtun, 
   {{0x63b94c50,0xb0582306,0x00000000,0x00000000}},	//   dtun, lfäc, --, --, 
   {{0x60c54c51,0x63b912c5,0xdb04004a,0x9f400129}},	//   _obim, etun, vriè, _crié_, 
   {{0x63b94c52,0xaa400209,0x680400cd,0x7954010e}},	//   ftun, _сесл, _bījā, _düwý, 
   {{0xdb0407ea,0x61e00158,0x88d8030d,0x00000000}},	//   triè, _arnl, _юьрт_, --, 
   {{0x60c54c53,0x2d814c54,0xd94400d1,0x7614c133}},	//   _abim, ypje_, _чеғи, _пьех, 
   {{0xdb054c55,0x63b94c56,0xe5a14c57,0x3438072d}},	//   rriè, atun, _бихи, _کساد_, 
   {{0x63b80014,0x612803b9,0x00000000,0x00000000}},	//   btun, dıls, --, --, 
   {{0x75200472,0x63b94c58,0xdb054c59,0x61280205}},	//   _imoz, ctun, ntió, vılt, 
   {{0x60c54c5a,0xdef8c5dc,0xdb05407e,0x94d40451}},	//   _ebim, ныс_, brié, _سيڪش, 
   {{0x7520022e,0xdb040129,0x9e354c5b,0x61280166}},	//   _kmoz, crié, герч, gıls, 
   {{0x2d800d27,0xdb054c5c,0x60c40241,0x00000000}},	//   rpje_, rtiý, _gbim, --, 
   {{0x69c54c5d,0x612800fd,0x2d80045f,0x98b8008e}},	// [216b0] _spje, rılt, spje_, _nurı_, 
   {{0x91a405dc,0x61281bc5,0x00000000,0x00000000}},	//   _खटाई, bıls, --, --, 
   {{0x63b81ac7,0x75200083,0x798c015d,0x7d1801c7}},	//   ztun, _omoz, _cwbw, ëtsc, 
   {{0x63b94c5e,0x998401f7,0x798c0042,0x20040267}},	//   ytun, النو, _dwbw, ämig_, 
   {{0xa25c36d7,0xb058005b,0x38700116,0x22480208}},	//   _ሱዳንን_, meäs, рқут, ́ck_, 
   {{0x75201418,0x9f400129,0xb0580108,0x00000000}},	//   _amoz, _prié_, leäs, --, 
   {{0xa3b00574,0x798c03cb,0x75d01e5a,0xdb040162}},	//   जून_, _gwbw, ليوا, atió, 
   {{0xe8dc004d,0x0444109a,0x00000000,0x00000000}},	//   _thốn_, кейн, --, --, 
   {{0x63b8049b,0x75200334,0x3e28001f,0xdb04b724}},	//   utun, _dmoz, ደሚደረ, ctió, 
   {{0x63b94c5f,0xd7c8036b,0xdb0406af,0x6b480e78}},	//   rtun, _سومه_, trié, fügi, 
   {{0x5ee00eac,0x691003e0,0x98b80139,0xb0580108}},	//   _নকলে, _içeb, _zurı_, keäs, 
   {{0x8e7404a9,0x468001d5,0x00000000,0x00000000}},	//   ғурч, _ёққа, --, --, 
   {{0x63b80cfe,0x65680270,0xbb2c0150,0x00000000}},	//   qtun, _iigh, _ﺨﻼﻑ_, --, 
   {{0x4ed4e29b,0xdb040231,0x65694c60,0x31c40014}},	//   люст, prié, _high, رتۯُ, 
   {{0x65694c61,0x60c401ab,0xcdc40124,0x00000000}},	//   _kigh, _tbim, ларқ, --, 
   {{0x60c40526,0x65694c62,0x6128719a,0xed540c54}},	//   _ubim, _jigh, rıls, вос_, 
   {{0x65694c63,0xeb954c64,0x612803e0,0xb058002f}},	// [216c0] _migh, кит_, sıls, rfäc, 
   {{0xe04449d2,0x65694c65,0x64484161,0x798c0857}},	//   _инқи, _ligh, _mygi, _pwbw, 
   {{0x644802d5,0x65684695,0x1cb40135,0xee340276}},	//   _lygi, _oigh, ྟུད_, _анэ_, 
   {{0x65694c66,0xdcfc005f,0x6448022e,0x2ba8483e}},	//   _nigh, bprā, _oygi, _चमचा, 
   {{0x68414c67,0x6b494c68,0x16c401e0,0x00000000}},	//   анца, zügi, лҡан, --, 
   {{0x75200ffb,0xfaa4034b,0xdb04a308,0xca7407d2}},	//   _smoz, _шаго, quià, _مەكت_, 
   {{0xdb0428f2,0x6568016d,0x6d404a1f,0xe8dc004d}},	//   stió, _bigh, _ínac, _chồn_, 
   {{0x98b80598,0x64494c69,0x293400d1,0x75c803e3}},	//   _turı_, _bygi, _ﮔﻪﭖ_, _ləzg, 
   {{0x65694c6a,0x7e7c0066,0xdb040077,0x779003e6}},	//   _digh, _ofpp, ltiñ, _ئیتا, 
   {{0xd2513115,0x65686adb,0x51f80212,0x64487a9a}},	//   ینک_, _eigh, еною_, _dygi, 
   {{0xdb04172e,0x65694c6b,0x644813b3,0x00000000}},	//   ntiñ, _figh, _eygi, --, 
   {{0x691003ee,0x656800a3,0xdb040077,0x30e80166}},	//   _içec, _gigh, itiñ, ффон_, 
   {{0xceb9240a,0x6b480254,0xef1c2ca8,0xb0580108}},	//   нән_, sügi, msüz_, veäs, 
   {{0x65694c6c,0xefe0001f,0xef1ce2ff,0xceb80022}},	//   _zigh, _ምነው_, lsüz_, хәи_, 
   {{0x06cc02f5,0x65680978,0x75c803e3,0x7e900ef6}},	//   লাচি, _yigh, _dəzg, _ﺑﯘﻻﻕ_, 
   {{0xe7f00574,0xa1e00032,0x7d153330,0xc8780205}},	//   _आपला_, _тәьҫ, ghys, _kaşe_, 
   {{0xb05801f4,0x00000000,0x00000000,0x00000000}},	// [216d0] reäs, --, --, --, 
   {{0xf1b4276a,0x20040e78,0xb058023a,0x63ac004e}},	//   _अमान, ämie_, seäs, àcni, 
   {{0xaa645b8e,0xdcfc00e2,0xb058005b,0x69100166}},	//   ттак, sprā, peäs, _rçeb, 
   {{0x88340323,0x7d154c6d,0x48154c6e,0x7e7c0427}},	//   лэлц, chys, лмес, _zfpp, 
   {{0x6568c337,0xfd5410df,0xab841515,0x00000000}},	//   _righ, _תשרי_, _шунк, --, 
   {{0xea540022,0x656898dc,0xe8dc004d,0x64494c6f}},	//   _азгә_, _sigh, _phồn_, _rygi, 
   {{0xdb042137,0x65694c70,0x8a180120,0x199400c0}},	//   quiá, _pigh, _џобс_, _вася, 
   {{0x65680455,0xab58002f,0xf5e40228,0xaab00b4c}},	//   _qigh, _spüh, اتوۋ, ुभवक, 
   {{0x65680842,0x4344005b,0xd9d400cf,0x00000000}},	//   _vigh, леив, _مەەگ, --, 
   {{0x65680978,0x64494c71,0xbb3c02dd,0x69100139}},	//   _wigh, _vygi, _ﯞﯨﻦ_, _uçeb, 
   {{0xaca00241,0xaaa81d8a,0x65694c72,0x016400db}},	//   _akọb, _चयनक, _tigh, лкоо, 
   {{0x65694c73,0x7e7c02d0,0x212400a3,0x7fb40006}},	//   _uigh, _sfpp, òmh_, лёгі, 
   {{0xb600025c,0xaee00055,0xd178009d,0x200400e4}},	//   _ġġib, _saṁg, нөөх_, âmi_, 
   {{0x7d1403ac,0x54680024,0x00000000,0x00000000}},	//   whys, _раім_, --, --, 
   {{0xc0e54c74,0xdb0406ed,0xada00209,0x75c80213}},	//   _бойк, luiç, йарл, _gəzd, 
   {{0x9f40004e,0xb0580112,0xc878008e,0x00000000}},	//   _triï_, mfän, _yaşe_, --, 
   {{0x66e80db6,0xdb0406ed,0xb0594c75,0xbb8400cf}},	// [216e0] _kēkē, nuiç, seär, الئي, 
   {{0xbb48581f,0x3f900810,0x0ce000fe,0xef1d4c76}},	//   رلان_, _iwyu_, _যকৃত, zsüz_, 
   {{0xb0580e78,0xa3b00073,0xd88400f2,0xef1c03e0}},	//   nfän, जूत_, لهای, ysüz_, 
   {{0xdb041709,0xc9542e5d,0x2f0c07de,0xe94400f1}},	//   rtiñ, атчы, _lügl_, هرنی, 
   {{0xdb04eb7b,0x569405f5,0x80dc0eac,0xe9a002dd}},	//   stiñ, аалт, যাপ্, _қатп, 
   {{0x1cb40327,0x6b48002f,0x00000000,0x00000000}},	//   ྟུམ_, fügu, --, --, 
   {{0xec100133,0xef1c03e0,0x00000000,0x00000000}},	//   _نوێد, tsüz_, --, --, 
   {{0x338c044e,0xfaa400c2,0x0a180014,0x36680107}},	//   _ዓሰርተ_, _шаҳо, _شفقک_, _ҷазо_, 
   {{0x39454c77,0xdb0406ed,0x2f0c07c5,0xf3654c78}},	//   moos_, guiç, _bügl_, лтон, 
   {{0x39454c79,0x81cc015b,0xa80000ee,0xb35401d3}},	//   loos_, রিন_, _узул, دیتا_, 
   {{0x80dc03f4,0xd2500502,0x65e0035b,0xb9fc02d3}},	//   যান্, تند_, _гәыҧ, _ዀነ_, 
   {{0xdb054c7a,0xaca001f2,0x394459c4,0x00000000}},	//   buiç, _kwụd, noos_, --, 
   {{0xa3b009d9,0x09d04e8f,0x3e501ef7,0x00000000}},	//   जूद_, _सन्य, _መስከር, --, 
   {{0xaca0063f,0x3dd817da,0x3944fb94,0x6b48002f}},	//   _mwụd, _bspw_, hoos_, nügt, 
   {{0x627806a9,0x3945201b,0x00000000,0x00000000}},	//   _אנונ, koos_, --, --, 
   {{0x394400d8,0xc1a402dd,0x91040133,0x00000000}},	//   joos_, _тышқ, _خستۆ, --, 
   {{0x39454c7b,0xa13403e6,0x2aa80452,0x00000000}},	// [216f0] doos_, _دروش, етео_, --, 
   {{0xe81c28d4,0x00000000,0x00000000,0x00000000}},	//   _मेगा_, --, --, --, 
   {{0x39440e14,0x20dc0073,0x00000000,0x00000000}},	//   foos_, _बसमध, --, --, 
   {{0x39442878,0x00000000,0x00000000,0x00000000}},	//   goos_, --, --, --, 
   {{0xab58642b,0x6b480112,0xaee00055,0x00000000}},	//   _aqüe, fügt, _gaṃg, --, 
   {{0xa994004b,0xf3f800eb,0x2b54552d,0x00000000}},	//   _مشرت, ইনার_, _صیاد_, --, 
   {{0x3944067c,0x9f4400bc,0x6b9c0175,0x00000000}},	//   boos_, ímé_, lsqg, --, 
   {{0xdb0403b7,0x81cc015b,0xded00092,0x6b480022}},	//   tuiç, রিম_, ሥትና_, rügu, 
   {{0x80dc00bd,0xab5800db,0x75c806be,0xb460011c}},	//   যাম্, _eqüe, _cəzb, окъл, 
   {{0x03254c7c,0xdb04315a,0x6ab40007,0xc3254c7d}},	//   рдон, ruiç, ngxf, рмок, 
   {{0x850401d9,0xc1043997,0x00000000,0x00000000}},	//   _پوشن, لودي, --, --, 
   {{0x75c80cc1,0x31b404c5,0x290c7de7,0xf1b43309}},	//   _qəze, জবংশ, nkga_, _अमरन, 
   {{0x2fd80327,0x947445d7,0xdb04067c,0x6b48002f}},	//   _csqg_, _ادما, quiç, nügs, 
   {{0xb0594c7e,0x39440005,0xf8d0298e,0x6adc00cd}},	//   pfän, zoos_, _सस्प, नयोर, 
   {{0x9f400589,0xaee00882,0xb05803fa,0x7c940e92}},	//   _ariã_, _saṃg, lfäl, ирац, 
   {{0x39444852,0x00c80116,0xdb0433b4,0xb05801f4}},	//   xoos_, _рлик_, ntiö, peäp, 
   {{0xbea54c7f,0xc5e4021a,0xb0594c80,0x2fd41371}},	// [21700] _капк, _کړ_, nfäl, _نويد_, 
   {{0xdb04023a,0x3058011a,0x00000000,0x00000000}},	//   htiö, _בדפד, --, --, 
   {{0x39454c81,0xb058002f,0xdb04002f,0x00000000}},	//   toos_, hfäl, ktiö, --, 
   {{0xfce54c82,0xf8694c83,0x39440c9e,0xb3a405f9}},	//   _томо, نماي_, шнег, _खिलख, 
   {{0x39454c84,0xdb500133,0x00000000,0x00000000}},	//   roos_, _فێر_, --, --, 
   {{0xb5a47d60,0xadc00241,0x39440218,0x2d54004e}},	//   арий, _atẹg, soos_, nçen_, 
   {{0xab2424ce,0xa9a00220,0x69102e11,0xa3b0466d}},	//   _тора_, _мирд, _içen, जूस_, 
   {{0xb0582ba9,0xdb0400d8,0x80dc0154,0x6284030a}},	//   ffäl, briã, যাড্, ñjon, 
   {{0xb05826bc,0x2d5403e0,0x00000000,0x00000000}},	//   gfäl, kçen_, --, --, 
   {{0xe81c007a,0xd2500014,0xd90c00e5,0x00000000}},	//   _मेटा_, ۪نگ_, _زیڈ_, --, 
   {{0x443c0334,0xaee000cd,0x7124007b,0xc8782093}},	//   _exw_, _jaṅg, لرحل, _haşa_, 
   {{0xaee000dc,0xb0580112,0x00000000,0x00000000}},	//   _maṅg, bfäl, --, --, 
   {{0xb2840137,0xaee000cd,0xd250e750,0x00000000}},	//   _кыйк, _laṅg, تنگ_, --, 
   {{0x9f400268,0xc8789f9f,0x232400f0,0x7b10032e}},	//   _crià_, _maşa_, _кочи_, _sæun, 
   {{0x84240014,0xaee00055,0x9f3400d4,0xf1d80118}},	//   _پى۪ن, _naṅg, цері, _बनिन, 
   {{0xdc886141,0xe1ec103c,0x6ce40150,0x00000000}},	//   исул_, _آسو_, шіге, --, 
   {{0xc8780356,0xa06800f3,0x00000000,0x00000000}},	// [21710] _naşa_, _каћа_, --, --, 
   {{0xf1d8006d,0xaee00055,0xa3d40490,0xeab000be}},	//   _बनान, _baṅg, ाबत_, تعر_, 
   {{0xda78084c,0x00000000,0x00000000,0x00000000}},	//   ряу_, --, --, --, 
   {{0xc8794c85,0x69100724,0xdb040798,0x41a8012d}},	//   _başa_, _eçen, triã, _किसस, 
   {{0x26e805c7,0xa9280131,0x290c022e,0xb05801e3}},	//   _ཡོདཔ, ىزچە_, rkga_, xfäl, 
   {{0x81cc03f4,0xc8794c86,0x4ee400cc,0xb058007c}},	//   রিত_, _daşa_, _নকুল, vfäl, 
   {{0xe7f0006d,0xdb0402f6,0xaee00882,0x95980032}},	//   _आपका_, ttiö, _gaṅg, атыу_, 
   {{0xd5b805f9,0xb0594c87,0xfd88010f,0x76b40166}},	//   _इमरज, tfäl, נטפּ, аләр_, 
   {{0xb3800724,0x443c020c,0xdb04067c,0x74e401c0}},	//   плыл, _qxw_, lriá, сдыг_, 
   {{0xc2e822f3,0x22a8016b,0xb0594b87,0xd83801c6}},	//   اعظم_, _kɔkɔ_, rfäl, _тэс_, 
   {{0xb0594c88,0x26c40427,0x7d000254,0x00000000}},	//   sfäl, mfno_, öosk, --, 
   {{0x443c0218,0x9f8416c3,0xc8787a36,0x80f806ed}},	//   _txw_, оҳид, _yaşa_, ухот_, 
   {{0x438406d5,0xc0c0001f,0xe8dc0208,0x7f5c02d0}},	//   _التق, _ስኳር_, _ngọa_, _phpq, 
   {{0x80dc00cc,0xdb2000d7,0x00000000,0x00000000}},	//   যাধ্, štúd, --, --, 
   {{0xb8d8025c,0xe81c0764,0xa3b02ce1,0x9f4000d8}},	//   _ཙྰ_, _मेघा_, जूर_, _criá_, 
   {{0xdb054c89,0xaee000cd,0xa2bc0b02,0x81cc00eb}},	//   driá, _raṅg, वभक्, রিদ_, 
   {{0xed540cfc,0x3f54037e,0xaee00882,0xba740137}},	// [21720] сот_, læum_, _saṅg, ماات, 
   {{0x388002d3,0xaee000b8,0xe3a400cf,0x66e4000d}},	//   ሕድሕዱ_, _paṅg, _ۉر_, _टोलक_, 
   {{0x9cb40014,0xfaa40107,0xc87940c5,0x00000000}},	//   _وۅست, _қаво, _saşa_, --, 
   {{0x75c803be,0xe3a40372,0xc878e2ff,0xa96402e8}},	//   _nəza, _ىر_, _paşa_, биха_, 
   {{0xe1e481cd,0x7d04009a,0x76584579,0x69100f7d}},	//   _کس_, _ioks, _szty, _içel, 
   {{0xdb0404d4,0x7d04ea7d,0x69100139,0xaee00055}},	//   briá, _hoks, _uçen, _taṅg, 
   {{0x3ce00fcf,0x99980006,0x69100166,0xf5e401ec}},	//   _kakv_, _vyrų_, _kçel, сілм, 
   {{0x75c803be,0x7d044db0,0x62814c8a,0x26c4058a}},	//   _cəza, _joks, _afno, afno_, 
   {{0x7d054c8b,0xacb8000f,0xa3b00cb4,0xb6a40209}},	//   _moks, _smûk, जूल_, _гизл, 
   {{0x7d054c8c,0xfa240135,0xaab00316,0x8704004b}},	//   _loks, _རྟོན_, ुभएक, _وبلل, 
   {{0x7d04127b,0x75c803e3,0x00000000,0x00000000}},	//   _ooks, _fəza, --, --, 
   {{0x7d042147,0xb05801b8,0x7d18000f,0xe4a001f4}},	//   _noks, sfäm, ūtsj, _ершо, 
   {{0x321c0034,0xf1d8000d,0xaf3401e2,0x43e801c8}},	//   szty_, _बनवन, مرست, _پرنٽ_, 
   {{0x2bb40cb4,0x69100205,0x63ac0419,0x00000000}},	//   इंसा, _açel, ácne, --, 
   {{0xdd947e3a,0x3ce0017a,0x37bc015b,0xdeb40137}},	//   засы, _bakv_, _ইনফর, ябры, 
   {{0x75c803b9,0xdcfc0139,0x00000000,0x00000000}},	//   _xəza, furı, --, --, 
   {{0x6d400998,0xab58068c,0x21f000db,0x99980014}},	// [21730] _ínam, _aqüa, _وكۇس, ۅپٕر_, 
   {{0x69100139,0xdb054c8d,0x66e4012d,0x00000000}},	//   _eçel, triá, _टोंक_, --, 
   {{0x7d054c8e,0x00000000,0x00000000,0x00000000}},	//   _foks, --, --, --, 
   {{0xf09c002e,0xf40000ef,0x35c0012d,0x00000000}},	//   naà_, _kuģī_, _शहज़, --, 
   {{0x2b90b649,0x6d4c009a,0xab58180f,0x22a80134}},	//   _ریاس, _ikca, _eqüa, _wɔkɔ_, 
   {{0x691003e0,0xdb0400d7,0x957c0210,0xc768009d}},	//   _içem, priá, _osąd, шилж_, 
   {{0x45194c8f,0x7d040365,0xdbd40d12,0x62840165}},	//   иция_, _yoks, _húða, ñjom, 
   {{0x75c803be,0x7d04022e,0x6a6001d5,0x2d540139}},	//   _qəza, _xoks, lеfo, kçem_, 
   {{0x47340022,0x83380798,0x09c8000d,0x00000000}},	//   _днас, ичот_, _रहुय, --, 
   {{0xd1dc001f,0x81c94c90,0xe9840023,0xb0580112}},	//   ንቃቄ_, агов_, _ዝቐነየ_, mfäh, 
   {{0xc5d8df9c,0x75c80213,0x80dc0011,0xdbd4032e}},	//   _خواص_, _təza, যাস্, _lúða, 
   {{0x6d4c004b,0xdb24014a,0x00000000,0x00000000}},	//   _nkca, _äsök, --, --, 
   {{0xb0580e78,0x62814c91,0x249c003a,0x00000000}},	//   nfäh, _tfno, maum_, --, 
   {{0x249d4c92,0x7d054c93,0x946401d9,0x6d4c0205}},	//   laum_, _soks, _ژھیۆ, _akca, 
   {{0x6d4c0175,0x7d0426bb,0x69100166,0xb058002f}},	//   _bkca, _poks, _pçel, hfäh, 
   {{0x925800c6,0x249c0393,0xdbd401a8,0x00000000}},	//   _اشهر_, naum_, _búða, --, 
   {{0x7d04fb11,0x7c648659,0xdbd40077,0x865c001f}},	// [21740] _voks, زارل, _púña, _ኃጢአት, 
   {{0x249c0457,0x7d041028,0xab5803fa,0xc03c001f}},	//   haum_, _woks, _spür, _ያስታወ, 
   {{0x7d054c94,0x6910013d,0xaa740014,0xdb054c95}},	//   _toks, _eçem, زمنؔ_, hriç, 
   {{0xb0580112,0x7d040064,0x15680116,0x00000000}},	//   ffäh, _uoks, _ﺷﺎﺋﯩ, --, 
   {{0xb0580e78,0xf7443cc5,0x2f0c0254,0x00000000}},	//   gfäh, оедо, _sügi_, --, 
   {{0xfdfc1094,0x39900023,0xc86416ac,0xeb940305}},	//   _उपास_, ምህርቲ_, سطني, _фир_, 
   {{0xd5b00597,0xf8f80354,0x00000000,0x00000000}},	//   رفة_, _кхаъ_, --, --, 
   {{0x249c05ac,0x00000000,0x00000000,0x00000000}},	//   gaum_, --, --, --, 
   {{0xdddc1591,0xdb0403cd,0xeacc03d4,0xb058007c}},	//   jbrž, rriæ, ৰাৰম, rfäk, 
   {{0xa3c80d2e,0x00000000,0x00000000,0x00000000}},	//   _लहर_, --, --, --, 
   {{0xdcfc0006,0x249c061f,0xf09c026c,0x66000261}},	//   sprę, baum_, taà_, _опфа, 
   {{0xb058006a,0x0b30001f,0x33b00131,0x249c00d8}},	//   ngäg, _በየትኛ, _قەبر, caum_, 
   {{0xb4d41889,0x5f954c96,0xb4b40d35,0xdb0406ed}},	//   ाजी_, мият, जली_, criç, 
   {{0xa3d419e5,0xd744010a,0x00000000,0x00000000}},	//   ाबर_, lата, --, --, 
   {{0xe0d004c5,0xc87806be,0xdbd401a8,0x00000000}},	//   িয়ভ, _başl_, _súða, --, 
   {{0x71640137,0x81cc015b,0xdbd4032e,0x00000000}},	//   _باتك, রিশ_, _púða, --, 
   {{0xd25000f1,0xea888fda,0x2d540139,0x00000000}},	// [21750] _تنګ_, لخان_, lçek_, --, 
   {{0x81cc00bd,0x249d4c97,0x00000000,0x00000000}},	//   রির_, zaum_, --, --, 
   {{0xb3c0009e,0xe94401c6,0xe9a85dc6,0x80dc0154}},	//   ্টিজ, охдо, شدان_, যার্, 
   {{0x249c0218,0xb0580112,0x9f400108,0xa8a40150}},	//   xaum_, tfäh, _eriä_, ірек, 
   {{0xb058002f,0x00000000,0x00000000,0x00000000}},	//   ufäh, --, --, --, 
   {{0xb0580e78,0x2d5405d1,0x04140327,0x75c803b9}},	//   rfäh, kçek_, ིརྣམ_, _vəzn, 
   {{0xb05803fa,0xa8a53c4a,0x249c0798,0xc878013d}},	//   sfäh, _мрак, taum_, _yaşl_, 
   {{0xdb044e52,0xc8c800ec,0x00000000,0x00000000}},	//   triç, _دورن_, --, --, 
   {{0x249d4c98,0x481407d6,0x00000000,0x00000000}},	//   raum_, _эмас, --, --, 
   {{0x249c01d4,0xd7740a52,0xb05801b8,0xdb0400d8}},	//   saum_, _قالع, igäd, rriç, 
   {{0x7bc80356,0xe4e400d4,0xc0e404b1,0x00000000}},	//   ăfui, _мідн, понк, --, 
   {{0x6af8031c,0x75c803e3,0xdb040200,0x81cc00eb}},	//   _ནོའོ_, _məzl, priç, রিল_, 
   {{0x237c0455,0x82344e10,0x80dc00eb,0x00000000}},	//   qquj_, ترکا, যাল্, --, 
   {{0xb4d4023e,0xe6280092,0x00000000,0x00000000}},	//   ाड़ी_, _እንኳን, --, --, 
   {{0xefe8001f,0x4208084c,0x00000000,0x00000000}},	//   _ሄደው_, _ынко_, --, --, 
   {{0x3b854c99,0x20040174,0x00000000,0x00000000}},	//   злаг, ømis_, --, --, 
   {{0x2ca80175,0x00000000,0x00000000,0x00000000}},	// [21760] _ddcd_, --, --, --, 
   {{0xdb1c344b,0x00000000,0x00000000,0x00000000}},	//   _üzüm, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa96406da,0xb80803d4,0x7f4c014f,0x2ca80051}},	//   пиха_, _শেষত_, lobq, _gdcd_, 
   {{0xdb054c9a,0x80cc3f55,0x7d0001f4,0x7d1400a2}},	//   nsië, ध्ये, öosu, mkys, 
   {{0x7bc40113,0x7d14d008,0x7f4c014f,0x75c803b9}},	//   _iqku, lkys, nobq, _fəzl, 
   {{0xdb04049f,0xf77005d9,0x9f4005e4,0xd1dc0023}},	//   rriä, واڻ_, _asië_, ንቃቕ_, 
   {{0xdce4b485,0x7d154c9b,0xb4b5450c,0xb4d4c488}},	//   kmič, nkys, जले_, ाजे_, 
   {{0x73f804c5,0x78a00618,0xa3b03166,0xa9646e27}},	//   ইন্ট_, maov, जंग_, _хита_, 
   {{0xdce4bc56,0x78a003d1,0x75c803b9,0x00000000}},	//   dmič, laov, _həzm, --, 
   {{0x9f400ffb,0x86740953,0x75c806be,0x65c400e4}},	//   _isiè_, _жыцц, _xəzl, rĩhá, 
   {{0x78a01311,0x2d554c9c,0x81cc015b,0xaa340a7c}},	//   naov, rçek_, রিং_, לטיק_, 
   {{0x75c803be,0x7bc4009a,0xdb040ea0,0x09c800bc}},	//   _məzm, _nqku, rsiê, _रह्य, 
   {{0x70743bbf,0xf1a409a5,0xd90404d3,0x78a00109}},	//   _کاغذ, _ерин, _ڵی_, haov, 
   {{0x78a051e1,0x7bc403f0,0xe1ec0633,0x9f4400bc}},	//   kaov, _aqku, _مسي_, ímá_, 
   {{0x9ce40276,0xa3b00073,0x75c806be,0x89d801d9}},	//   нцул, जूक_, _nəzm, ۪وار_, 
   {{0x6fb4025c,0xc24401af,0x00000000,0x00000000}},	// [21770] _བཀྲའ, _нмәҫ, --, --, 
   {{0x9c6401d5,0x15680150,0x00000000,0x00000000}},	//   رهلو, _ﺷﺎﺑﯩ, --, --, 
   {{0xdb0420ef,0x78a00421,0x89d90220,0xcdc400cf}},	//   isiè, faov, توار_, _تۇزۇ_, 
   {{0xa2d00412,0x75c806be,0x00000000,0x00000000}},	//   _बॉन्, _vəzl, --, --, 
   {{0xc6151487,0x2f0c17da,0x178401ec,0xe61000e5}},	//   तन्य_, _fügt_, егім, کشش_, 
   {{0xfec8008f,0x798c002d,0x1a6801b9,0xd1dc0023}},	//   ַמפּ, ânwû, _کیمی_, ንቃቐ_, 
   {{0x78a14c9d,0xf8ac0e60,0x48c401ec,0x00000000}},	//   baov, _چکه_, _ошағ, --, 
   {{0x838827cf,0xf8ac0133,0xc8780432,0x75c80213}},	//   обив_, _نکه_, _maşk_, _gəzm, 
   {{0xb4d400e1,0x461400ec,0x00000000,0x00000000}},	//   ाड़े_, _ڪوار, --, --, 
   {{0xdef8044e,0x00000000,0x00000000,0x00000000}},	//   ወሳኺ_, --, --, --, 
   {{0x4614aaab,0x957c0006,0xaacc23c1,0x31680334}},	//   _توار, _drąs, स्यक, fmcz_, 
   {{0xcea80d65,0x841401f0,0x00000000,0x00000000}},	//   _כי_, _омех, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x63b94c9e,0xdce446aa,0xdb0405e4,0x78a00109}},	//   muun, rmič, rsië, zaov, 
   {{0x63b94c9f,0xc1040597,0xdb040d27,0xdce49ae3}},	//   luun, _يوتي, ssië, smič, 
   {{0x8d554ca0,0x00000000,0x00000000,0x00000000}},	//   етуч, --, --, --, 
   {{0x63b8331b,0x3ce40038,0x8fd40598,0x7d14b22c}},	// [21780] nuun, ľov_, _пәрә, rkys, 
   {{0xd9114ca1,0x7d154ca2,0x3ce401f1,0xa2d02c35}},	//   گیر_, skys, žov_, _बॉम्, 
   {{0x42780020,0x78a00851,0x429c0020,0x63b88ebb}},	//   _ከአንድ_, taov, _ለአንድ_, huun, 
   {{0xd910d653,0x63b94ca3,0x60c40334,0x61e14ca4}},	//   دیر_, kuun, _jcim, _msnl, 
   {{0x60c41cdf,0xdb040597,0x31d81be1,0xacb8002d}},	//   _mcim, iriú, _बन्ध, _slûg, 
   {{0x63b94ca5,0x78a00109,0x758802bf,0x66e00640}},	//   duun, saov, осив_, воља, 
   {{0x60c408ad,0x78a00109,0x75c803e3,0xb058013d}},	//   _ocim, paov, _təzm, lfät, 
   {{0x63b94ca6,0x38c801ed,0x9f4001e7,0xa56001b9}},	//   fuun, _گاڑی_, _criú_, نگنن, 
   {{0x63b94ca7,0x54540276,0xa7a40798,0x36c40395}},	//   guun, эвит, _окта_, _обаг, 
   {{0x60c403b7,0xd5680055,0xc7642374,0x667000d1}},	//   _acim, _dṛṅ_, _كالى, رگەر, 
   {{0x65c0baec,0xdb054ca8,0x9f400332,0x00000000}},	//   _абха, rsiè, _friú_, --, 
   {{0xdb054ca9,0x60c4010a,0xd4c40137,0x201c06be}},	//   ssiè, _ccim, _чөкк, _əviv_, 
   {{0x60c40175,0x63b80067,0x957c0064,0x2894011a}},	//   _dcim, cuun, _trąs, ודכן_, 
   {{0xdef8005e,0x60c40857,0x9f600248,0x00000000}},	//   мыс_, _ecim, _ìsìn_, --, 
   {{0x798c00ca,0xdb0400c6,0xa2b8011a,0x6fdc012d}},	//   _ntbw, briú, _ומוט, _पैरं, 
   {{0x8228031c,0x60c401e7,0xc0e4069d,0xe7dc0037}},	//   _སྟྲི_, _gcim, ሜትር_, _खईला_, 
   {{0xe0d00137,0x23480244,0x9cc800c7,0x00000000}},	// [21790] _ئزى_, _اسۆی_, ьыра_, --, 
   {{0xc878084c,0x60c4009a,0xdef80139,0x00000000}},	//   _iaşi_, _zcim, _жыю_, --, 
   {{0x63b8063f,0x00000000,0x00000000,0x00000000}},	//   zuun, --, --, --, 
   {{0x63b94caa,0x00000000,0x00000000,0x00000000}},	//   yuun, --, --, --, 
   {{0x63b80050,0x7644013b,0xd7f80063,0x00000000}},	//   xuun, _ɛkye, дуј_, --, 
   {{0x63b80a49,0xc8780139,0xb058007c,0xef1c03e0}},	//   vuun, _maşi_, lfäs, mpüs_, 
   {{0x9f4001ab,0xc878054e,0x63b82252,0xe7dc17ee}},	//   _criù_, _laşi_, wuun, _खैरा_, 
   {{0x6d8001e4,0x5a240014,0x63ac0306,0x333c0334}},	//   _nĵam, _شفقٕ, ácno, entx_, 
   {{0x291d4cab,0x68f94cac,0x7ac407f7,0xa24401d3}},	//   _ilua_, _inud, र्कअ, ڈیشل_, 
   {{0x020473b7,0x60c54cad,0x291c0211,0x63b80eda}},	//   езон, _scim, _hlua_, ruun, 
   {{0x63b94cae,0x9f4000ae,0xdb0401e7,0x00000000}},	//   suun, _triú_, triú, --, 
   {{0xaacc7220,0xdb040c6a,0x63b80821,0xd4f4004e}},	//   स्तक, rsié, puun, _аяшы, 
   {{0x63b94caf,0xdb0406af,0x61e80024,0xc8780205}},	//   quun, ssié, _žolė, _başi_, 
   {{0x3dc805ac,0x00000000,0x00000000,0x00000000}},	//   ttbw_, --, --, --, 
   {{0x291c18a6,0x68f80342,0xdb2400e4,0xc87806be}},	//   _olua_, _onud, _äsék, _daşi_, 
   {{0x83900020,0x71440092,0x00e4004e,0x00000000}},	//   _የነዳጅ_, _ሪፖርቶ, _чжин, --, 
   {{0x6b4801ed,0x00000000,0x00000000,0x00000000}},	// [217a0] lügy, --, --, --, 
   {{0x291d4cb0,0x68f94cb1,0xa3b4060c,0xdddc002d}},	//   _alua_, _anud, _छिन_, sbrű, 
   {{0x13d80c58,0x81cc00bd,0x291c010f,0xf99000db}},	//   তিয়, রিক_, _blua_, ابئ_, 
   {{0x80dc00bd,0x291c004e,0x2db4010f,0xa88401af}},	//   যাক্, _clua_, _אלטן_, ейца_, 
   {{0x85881c5c,0xb05801e6,0xc87800fd,0xdab80131}},	//   _ﻗﺎﺭﺍ_, lfär, _yaşi_, _يۇرت_, 
   {{0x291c0751,0x21200429,0x68f802d0,0x75c80213}},	//   _elua_, _llih_, _enud, _həzi, 
   {{0xd9114cb2,0x291d4cb3,0x21214cb4,0xb0585df7}},	//   _پیش_, _flua_, _olih_, nfär, 
   {{0x6d400998,0xdb040077,0x81100154,0x33c801ec}},	//   _ínat, muiñ, হফুজ_, _ﻓﻪﺭﻣ, 
   {{0x75c803b9,0x00000000,0x00000000,0x00000000}},	//   _məzi, --, --, --, 
   {{0x21214cb5,0x9f4001ab,0x68f821ed,0x75c806be}},	//   _alih_, _triù_, _znud, _ləzi, 
   {{0x5f9407d6,0xe61400ea,0x80c800cc,0x6b4800e5}},	//   ғист, _пдф_, িজন্, gügy, 
   {{0xb0580267,0xaac42ac3,0x75c803e3,0x00000000}},	//   dfär, _लाभक, _nəzi, --, 
   {{0xceb8ae3e,0xc8780311,0x77788fc6,0xdb040784}},	//   мән_, _paşi_, _kitx, huiñ, 
   {{0xb0585df4,0x53340ce8,0x787406be,0x2d5403e0}},	//   ffär, _шелт, _züvü, hçet_, 
   {{0x1df94cb6,0x777801c6,0x75c800ac,0x4fc00131}},	//   неры_, _mitx, _bəzi, _ھەسە, 
   {{0x81cc03f4,0x7658002d,0x212009a8,0x777801c4}},	//   রিখ_, _myty, _glih_, _litx, 
   {{0x518401e0,0xc8780205,0xb05801e3,0x00000000}},	// [217b0] _яуҙа, _taşi_, rfäs, --, 
   {{0x8e140022,0x7778009d,0x291c007b,0x212007f5}},	//   _адоц, _nitx, _slua_, _zlih_, 
   {{0xaca002e3,0x291d4cb7,0xdb053a68,0x1044001f}},	//   _amụb, _plua_, guiñ, _ያስቀመ, 
   {{0x777801c4,0x3f540393,0x75c80213,0x481400f7}},	//   _aitx, bæus_, _gəzi, кмес, 
   {{0x6720044e,0x777805f5,0x7658086f,0x6b4800e5}},	//   thnj, _bitx, _ayty, zügy, 
   {{0xd6a80075,0x45d40c56,0x765835dc,0x67540345}},	//   ىدىم_, вцит, _byty, ریاس_, 
   {{0x7778009d,0x5a440276,0x75c806be,0x9b4456e8}},	//   _ditx, _бэта, _yəzi, _صنفو, 
   {{0x672002d3,0x291cb452,0x68f94cb8,0x777801c4}},	//   shnj, _ulua_, _unud, _eitx, 
   {{0x7778b144,0x9a880014,0xab5800db,0x2d540023}},	//   _fitx, _آنہٕ_, _aqüi, lçes_, 
   {{0x7658044e,0x777801c6,0x82f43da1,0x02bc00bc}},	//   _fyty, _gitx, тчиц, ्भेन, 
   {{0x2d54004e,0x5694e2d2,0x765800a2,0x33603163}},	//   nçes_, _сахт, _gyty, рвэг, 
   {{0x777801c4,0x6b4800e5,0x00000000,0x00000000}},	//   _zitx, rügy, --, --, 
   {{0xab5800d8,0x75c803b9,0x2d540200,0x20300023}},	//   _eqüi, _rəzi, hçes_, _ብኸመይ, 
   {{0xdb2408fb,0xb0585b00,0x6910013d,0x04c80451}},	//   _åsøk, tfär, _kçes, _روڪي_, 
   {{0x6da002e8,0xb3400432,0x00000000,0x00000000}},	//   иира, _üçar, --, --, 
   {{0xb0594cb9,0x2120020c,0x3f540140,0x6acc00fe}},	//   rfär, _ulih_, tæus_, _হোলো, 
   {{0x75c80cc1,0xed540a16,0xb0594cba,0xac814cbb}},	// [217c0] _vəzi, тот_, lgän, ргул, 
   {{0xba7400cf,0x935802d3,0x3f5401bf,0xef1c0112}},	//   ناات, _ምብትታ, ræus_, spür_, 
   {{0xb0582776,0x777801c4,0x69100166,0x75c803e3}},	//   ngän, _ritx, _nçes, _təzi, 
   {{0x3f540158,0x675000f2,0xb0580112,0x00000000}},	//   pæus_, یخور, igän, --, 
   {{0x765802f6,0x77784530,0xdb040077,0x81cc015b}},	//   _syty, _pitx, suiñ, রিট_, 
   {{0x76580588,0x80dc0eac,0x6910013d,0xb058010e}},	//   _pyty, যাট্, _sçet, kgän, 
   {{0xe9a14cbc,0xdb041709,0xf56801af,0x35680107}},	//   _васп, quiñ, мшик_, мрин_, 
   {{0xaa414cbd,0x563800b7,0x76580306,0x067800d1}},	//   _тесл, _እንክብ, _vyty, ﻧﯘﻧﯩ, 
   {{0x7658033f,0x281065dc,0x00000000,0x00000000}},	//   _wyty, _پولس, --, --, 
   {{0xd764034c,0xab5805d5,0xb0580036,0xc8780356}},	//   _صنای, _spüz, fgän, _caşu_, 
   {{0x691046cf,0x3f900270,0x91743633,0x4d6c02dd}},	//   _içer, _atyu_, лгоц, _ﺳﺎﯞﯨ, 
   {{0x69100166,0x00000000,0x00000000,0x00000000}},	//   _uçet, --, --, --, 
   {{0x75200472,0x46c80ebb,0xa92000d0,0x7414114f}},	//   _iloz, _रामह, úžia, _جوشا, 
   {{0x81cc015b,0x75200165,0xb058002f,0x00000000}},	//   রিজ_, _hloz, bgän, --, 
   {{0x75214cbe,0x2e2401a9,0x9e3400d8,0x00000000}},	//   _kloz, _nеft_, аерч, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7520009f,0x69114cbf,0x0bf40108,0x00000000}},	// [217d0] _mloz, _oçer, ыпаю, --, 
   {{0xd5a455b4,0xed3001ed,0x75200200,0xeda41de6}},	//   _وہ_, _چودھ, _lloz, _ишмо, 
   {{0x9a840323,0xdde400fd,0x99980014,0xfe9800d9}},	//   руул, _кәтү, نپٕر_, _איתמ, 
   {{0x99d404d3,0x2d54511a,0x81cc00eb,0x00000000}},	//   شتما, rçes_, রিচ_, --, 
   {{0x75c800ac,0x2aa8009b,0x00000000,0x00000000}},	//   _məzu, _отво_, --, --, 
   {{0x6d5d4cc0,0x75200083,0xb6a00139,0xf3f800eb}},	//   llqa, _aloz, бишл, েনার_, 
   {{0xa4903765,0x442801f1,0x75214cc1,0x98280014}},	//   لیات, _ťa_, _bloz, ى۪ہہ_, 
   {{0x752007ab,0x29f0009b,0x6910013d,0x1a68158b}},	//   _cloz, _ića_, _eçer, _شینی_, 
   {{0xd3a40220,0xef1c00ac,0x9f4000a2,0xd6a800d1}},	//   алық, vqün_, _ariý_, ردۈم_, 
   {{0xb0594cc2,0x95c400ec,0x00000000,0x00000000}},	//   tgän, _چيله, --, --, 
   {{0x46154cc3,0x80dc009e,0x00000000,0x00000000}},	//   _حوار, যাঘ্, --, --, 
   {{0xb0594cc4,0xa2d006ab,0x75214cc5,0x69c800af}},	//   rgän, _बॉर्, _gloz, _हमनी, 
   {{0x65680194,0xb0594cc6,0xc878013d,0x75c803b9}},	//   _ihgh, sgän, _taşu_, _qəzv, 
   {{0x81cc0c58,0xdb040194,0x75214cc7,0x63b94cc8}},	//   ৰিব_, tsií, _zloz, mrun, 
   {{0x63b94cc9,0xbcf80022,0xb058013d,0x00000000}},	//   lrun, нхац_, lgäl, --, 
   {{0x63b80140,0x80dc015b,0xed554cca,0x25e8000d}},	//   orun, যাঙ্, гос_, _अईनी_, 
   {{0xb7bc2f8b,0x63b94ccb,0x2d9001c0,0xb0594ccc}},	// [217e0] _ইন্ট, nrun, _etxe_, ngäl, 
   {{0x63b80036,0x6d5c02d0,0x7de80024,0x00000000}},	//   irun, alqa, _змог_, --, 
   {{0x63b94ccd,0x248c0077,0xe944036b,0x00000000}},	//   hrun, _ofgm_, گرلی, --, 
   {{0xb95800c6,0x3ea804e6,0x00000000,0x00000000}},	//   رجاء_, labt_, --, --, 
   {{0x6d540a1e,0x63b80784,0xe944bd8e,0x00000000}},	//   _תיכף_, jrun, درلی, --, 
   {{0xca7400db,0x00000000,0x00000000,0x00000000}},	//   _چەكت_, --, --, --, 
   {{0x63b94cce,0x7520030a,0xb4b000d1,0x69100139}},	//   erun, _ploz, бийә, _vçer, 
   {{0x7aed4ccf,0x3ea80730,0x248c00db,0x63b94cd0}},	//   _habt, habt_, _cfgm_, frun, 
   {{0xb9d00201,0x7aed4cd1,0x77903e58,0x656801ab}},	//   _ሺህ_, _kabt, _ایتا, _dhgh, 
   {{0x51f802bf,0x7aed4cd2,0x69100139,0xc8440166}},	//   вною_, _jabt, _uçer, _әҗәл_, 
   {{0x63b94cd3,0x7aec011f,0xe3ac56a7,0x00000000}},	//   arun, _mabt, يری_, --, 
   {{0x7aed4cd4,0x6568047e,0x9f40004e,0xda3c010e}},	//   _labt, _ghgh, _orió_, _barº, 
   {{0x63b8054e,0xdfd800a7,0x2934008f,0xe28c43fb}},	//   crun, лър_, ראכן_, غذی_, 
   {{0x7aed4cd5,0xd370d712,0x2c680241,0x6d5c058a}},	//   _nabt, _بهت_, _lòdí_, wlqa, 
   {{0xa340004b,0xd130009f,0xdce40210,0x00000000}},	//   _دپوه, _ومت_, zmią, --, 
   {{0x4c94010b,0xc0c00092,0xdd58009d,0xb058010e}},	//   риас, ስቷል_, гасч_, lgäm, 
   {{0x7aed4cd6,0x9f400789,0x64480036,0xda3c00a2}},	// [217f0] _babt, _crió_, _xxgi, _garº, 
   {{0x7aec102c,0x63ac04d4,0xaca00ca8,0xb05833fe}},	//   _cabt, ácni, _ijọb, ngäm, 
   {{0x7aec0457,0x97c4005e,0xaa654cd7,0x83a00092}},	//   _dabt, ەتىم, утак, _ለነዚህ_, 
   {{0x9f400789,0x837c001f,0xc79510b2,0x00000000}},	//   _frió_, _ከነዚህ_, аркы, --, 
   {{0xd9980075,0xbc44014b,0x00000000,0x00000000}},	//   ننەت_, _кӯфа_, --, --, 
   {{0xf79449c2,0x81cc0183,0x65681713,0x7aec757e}},	//   جنوب_, ৰিত_, _shgh, _gabt, 
   {{0x63b94cd8,0x05280166,0xe6c803b2,0x199468eb}},	//   wrun, кокк_, _ábíð, _гася, 
   {{0xdb054cd9,0xc4842fd0,0x7aec0198,0xe7840276}},	//   brió, шлик, _zabt, _бужо, 
   {{0xc3254cda,0x03247b45,0xf5740597,0x7aec0429}},	//   имик, идин, جميع_, _yabt, 
   {{0x63b94cdb,0xadf404af,0xb9d0010c,0xa56403e6}},	//   rrun, ुमान_, _ስብ_, _ڵدان, 
   {{0x6b881125,0xaca00241,0x412840f8,0xd40800db}},	//   íggj, _ajọb, воно_, _ەتىم_, 
   {{0x63b94cdc,0x212400ae,0xddd4031c,0x00000000}},	//   prun, ómh_, ħażl, --, 
   {{0x03a402f4,0x26c40270,0x7fd40220,0x63b80113}},	//   _тило, ogno_, шіні, qrun, 
   {{0x26c54cdd,0x442d4cde,0x8234034c,0x228401b9}},	//   ngno_, mze_, _پرتا, _судг, 
   {{0x7aed4cdf,0x442d4ce0,0x26c40395,0x62814ce1}},	//   _rabt, lze_, igno_, _igno, 
   {{0x5a4401e0,0x00000000,0x00000000,0x00000000}},	//   ҡмағ, --, --, --, 
  
   {{0x442d4ce2,0x7aec047e,0xdce41710,0x7ed40212}},	// [21800] nze_, _pabt, hmić, _кінч, 
   {{0x7aec0a81,0x442d4ce3,0x6aa401fa,0x3e680137}},	//   _qabt, ize_, _cejf, _үшүн_, 
   {{0xf9900220,0xe3a401ed,0xd88400f2,0x00000000}},	//   زبا_, _ڈر_, مهای, --, 
   {{0x442c05dd,0xdb04d3eb,0x6280010a,0xdce407f5}},	//   kze_, trió, _lgno, dmić, 
   {{0x7aed4ce4,0x442d4ce5,0xec44023a,0x56940026}},	//   _tabt, jze_, _взял_, балт, 
   {{0x442d4ce6,0x58047a32,0xdb054ce7,0x00000000}},	//   dze_, _қозғ, rrió, --, 
   {{0xe1e54ce8,0xf5254ce9,0xdce40cf4,0x442d4cea}},	//   _بس_, ифин, gmić, eze_, 
   {{0x62814ceb,0x00000000,0x00000000,0x00000000}},	//   _agno, --, --, --, 
   {{0x39450e09,0x77c81fbe,0x442c00ef,0x00000000}},	//   mnos_, _шлаг_, gze_, --, 
   {{0xdb040077,0x9f400165,0xf3640b3e,0x394446e4}},	//   oriñ, _oriñ_, јтин, lnos_, 
   {{0x442d4be1,0x1ad40c58,0x51182401,0x1154004e}},	//   aze_, _হোৱা, гоню_, йкою, 
   {{0x39454cec,0x6280025c,0x442d4ced,0xdb040005}},	//   nnos_, _egno, bze_, iriñ, 
   {{0x442c14cf,0x39454cee,0x9f40005a,0xaac4134e}},	//   cze_, inos_, _ariñ_, _लालक, 
   {{0x39440368,0x23240114,0x2d8400e5,0x00000000}},	//   hnos_, _вољи_, _ének_, --, 
   {{0xa6940302,0xeca42424,0x62300364,0x28d44697}},	//   שכלה_, ијан, _мешу, ण्डि, 
   {{0x394400dd,0xdb054cef,0xa12800cf,0x6aa54cf0}},	//   jnos_, driñ, _ۅكۉل_, _sejf, 
   {{0x6d8001e4,0xf09c08e5,0x957c033f,0x3c1c0055}},	// [21810] _aĵat, mbà_, _brąz, _nāvā_, 
   {{0x39454cf1,0x6aa40023,0x00000000,0x00000000}},	//   enos_, _qejf, --, --, 
   {{0x442d4cf2,0x5f749805,0x9f400418,0xdb054cf3}},	//   zze_, _باير, _usiá_, griñ, 
   {{0x39454cf4,0x442d4cf5,0x00000000,0x00000000}},	//   gnos_, yze_, --, --, 
   {{0xdb054cf6,0x6aa401d3,0x00000000,0x00000000}},	//   ssiá, _tejf, --, --, 
   {{0xdb04056a,0x442c1a33,0x7c641d0a,0x3c1c0171}},	//   briñ, vze_, _داپل, _dāvā_, 
   {{0x7af809f3,0xdb040ba1,0x00000000,0x00000000}},	//   _ótta, priò, --, --, 
   {{0x442d4cf7,0x628007c5,0x7c2012ed,0xdce401a6}},	//   tze_, _sgno, øorg, rmić, 
   {{0x442d4cf8,0x9f4003b2,0xf8ac00ec,0x84580022}},	//   uze_, _orið_, _سکن_, ыркт_, 
   {{0x442c0918,0x580402dd,0xc1e801c6,0xb0580432}},	//   rze_, _بوكك, гдож_, mgäh, 
   {{0x442d4cf9,0x568c00c8,0xc104007b,0xd618210e}},	//   sze_, _סטאַ, مودي, _پتلا_, 
   {{0xf09c0570,0x9f4002d2,0x442c0036,0x00000000}},	//   gbà_, _arið_, pze_, --, 
   {{0x249d4cfa,0x628004cc,0x437400db,0xb0580108}},	//   mbum_, _tgno, _лукт, ngäh, 
   {{0x249d4cfb,0x39454cfc,0x00000000,0x00000000}},	//   lbum_, znos_, --, --, 
   {{0xe1644876,0xf09c5bd6,0x39440024,0xada00c5c}},	//   _وضعی, bbà_, ynos_, засл, 
   {{0x92680120,0xf65000df,0x00000000,0x00000000}},	//   _трча_, פצן_, --, --, 
   {{0xeab40228,0xdb054cfd,0x0ba81411,0xeb954cfe}},	// [21820] өйт_, nsiç, لالى_, йит_, 
   {{0xdb054cff,0x9f400413,0xfaa54d00,0xfaa80214}},	//   isiç, _grið_, сажо, اهاي_, 
   {{0x39454d01,0xa2cc00cd,0xdce40210,0x00000000}},	//   tnos_, _दान्, zmię, --, 
   {{0xdb054d02,0x39454d03,0x247c002b,0x00000000}},	//   rriñ, unos_, _kāmī_, --, 
   {{0x670025c9,0x00000000,0x00000000,0x00000000}},	//   लांक_, --, --, --, 
   {{0x39454d04,0x96f800a8,0x3c1c0421,0x249c0393}},	//   snos_, рект_, _vāvā_, ebum_, 
   {{0x9f400108,0x26000166,0x158c02dd,0x00000000}},	//   _isiä_, зчыг, _ﻗﺎﺷﯩ, --, 
   {{0x77854d05,0x35a401d5,0x00000000,0x00000000}},	//   _глаз, _ҳажг, --, --, 
   {{0x5638001f,0xa3b40037,0x00000000,0x00000000}},	//   _እንዲበ, _छिः_, --, --, 
   {{0x6b88022c,0x53340024,0xd90c00e5,0xa2d007af}},	//   íggi, іент, _سیڈ_, ब्ल्, 
   {{0x71240597,0x66e0016c,0x9f4400bc,0x249c03f2}},	//   مرحل, _хоха, ímý_, bbum_, 
   {{0x71094d06,0xdb0401f4,0x90840150,0x00000000}},	//   ухов_, lsiä, _ﺭﻏﺒﺔ_, --, 
   {{0xa2d034ef,0xf09d4672,0x247c0055,0xb9d00092}},	//   _बॉक्, rbà_, _cāmī_, _ስጥ_, 
   {{0x5638044e,0xdb040724,0xaac401ad,0xb19001e0}},	//   _እንዳበ, nsiä, _लाइक, _елкә, 
   {{0x333c031c,0xd0d4030d,0x9f3400d4,0x00000000}},	//   mitx_, _дойъ, чері, --, 
   {{0x9f400166,0x614416a4,0x333c031c,0x00000000}},	//   _asiä_, _неја, litx_, --, 
   {{0xdb054d07,0x636c0b1a,0xa2cc024a,0x247c00b8}},	// [21830] ksiä, bønd, _दाम्, _gāmī_, 
   {{0x9f4003b2,0x333d4d08,0x00000000,0x00000000}},	//   _urið_, nitx_, --, --, 
   {{0x9cb43ce1,0xf40c00fe,0x00000000,0x00000000}},	//   زمەت, িনিৰ_, --, --, 
   {{0x27280158,0x247c0055,0x00000000,0x00000000}},	//   _møne_, _yāmī_, --, --, 
   {{0x272805ac,0xb8800030,0x333c005a,0x321c0306}},	//   _løne_, _šíri, kitx_, hyty_, 
   {{0x321c0124,0xf40c00fe,0x03d00055,0x00000000}},	//   kyty_, িনাৰ_, cāṅg, --, 
   {{0x46145ff0,0xf590b74b,0x36fc05b3,0x333c031c}},	//   توغر, ولوج, लाड़ी_, ditx_, 
   {{0x58d44b7d,0x321c0034,0x272803cd,0x76b40131}},	//   _ност, dyty_, _sønd_, бләр_, 
   {{0x249c0483,0x636c5522,0x668000e5,0x00000000}},	//   rbum_, høne, _ٹیبل, --, 
   {{0x6680006c,0xc2442377,0x247c0171,0x97c43cc6}},	//   _عیبل, жнок, _rāmī_, _رقمو, 
   {{0x636c0158,0xf2e40066,0x00000000,0x00000000}},	//   jøne, زکوه_, --, --, 
   {{0x2ca8014b,0x00000000,0x00000000,0x00000000}},	//   _necd_, --, --, --, 
   {{0x6f148d75,0x333d1984,0x444401d3,0x636c01bf}},	//   _boxc, bitx_, _براہ, tønd, 
   {{0x321d4d09,0x05dc28b8,0x6f140076,0x672001a6}},	//   byty_, _महाब, _coxc, nknj, 
   {{0x6f140007,0x0d98abba,0x636c2b96,0x321d4d0a}},	//   _doxc, йтты_, rønd, cyty_, 
   {{0x417410fe,0x2ca801e7,0x636c0ac8,0x00000000}},	//   _باتس, _cecd_, sønd, --, 
   {{0x6f154d0b,0xcb040034,0xeb940276,0xefd40023}},	// [21840] _foxc, रांड_, жиу_, ይቶይ_, 
   {{0x3a984eb1,0x00000000,0x00000000,0x00000000}},	//   ртаю_, --, --, --, 
   {{0xb9e94d0c,0x67200010,0x00000000,0x00000000}},	//   рмез_, dknj, --, --, 
   {{0x69c80ce0,0x00000000,0x00000000,0x00000000}},	//   _हमरी, --, --, --, 
   {{0x7d04f9db,0xdb040598,0x321c033f,0x00000000}},	//   _inks, tsiä, zyty_, --, 
   {{0x2ca8009a,0x7bd401e2,0x56954d0d,0xdb0401f4}},	//   _zecd_, mtyu, чакт, usiä, 
   {{0x2ca8009a,0x188429dc,0xafe406ea,0x333c7c3f}},	//   _yecd_, _еңен, _kvøð, vitx_, 
   {{0xdb040724,0x636c0158,0x80d80154,0x00000000}},	//   ssiä, jønb, _বোস্, --, 
   {{0x78a14d0e,0x73f811ba,0xacb8002d,0x321c0210}},	//   mbov, েন্ট_, _slûk, wyty_, 
   {{0x7bd54d0f,0x1fd00f22,0x38a001d5,0x7d040175}},	//   ityu, িবাস, _hаr_, _lnks, 
   {{0x7d04545b,0xaacc0358,0x333d1984,0x65c400e4}},	//   _onks, स्टक, ritx_, rũhá, 
   {{0x321d29af,0x69c009a8,0xa50407d8,0xe5a14d10}},	//   ryty_, šneg, _меха_, _цици, 
   {{0xe978010f,0x00000000,0x00000000,0x00000000}},	//   ינטש, --, --, --, 
   {{0x7d054d11,0x321c0588,0xcf900014,0x333c0327}},	//   _anks, pyty_, ٘ژھ_, qitx_, 
   {{0x7bd54d12,0xdef80953,0xdd941885,0xf1a80345}},	//   etyu, цыя_, дасы, _ئاته_, 
   {{0x636c0b1a,0x4adc00cd,0x80d000f7,0x7bd40139}},	//   røne, न्नव, _كۅپچ, ftyu, 
   {{0x92ac045e,0xac740799,0x636c0158,0x78a00306}},	// [21850] গলী_, زارش, søne, dbov, 
   {{0xcb0428d4,0x25e8000d,0xea640114,0x00000000}},	//   राइड_, _अईली_, оњен, --, 
   {{0x4c940276,0x6720020c,0x00000000,0x00000000}},	//   _нинс, vknj, --, --, 
   {{0xefcc001f,0xafe403b2,0xa9040cd2,0x00000000}},	//   _እሁድ_, _gvøð, غبان, --, 
   {{0x269c0020,0x07a43576,0xdb0405d5,0x06741870}},	//   _ግንዛቤ_, чалн, vriö, ﻤﯩﻨﯩ, 
   {{0x3eb80ac5,0x4b78010f,0x00000000,0x00000000}},	//   _xdpt_, _לאָו, --, --, 
   {{0x7d040162,0x00000000,0x00000000,0x00000000}},	//   _ynks, --, --, --, 
   {{0x34b0c9c6,0xb0580112,0xf5e54d13,0x00000000}},	//   ىمىز, lgäu, ستىۋ, --, 
   {{0x69d401c4,0xdce40115,0xe5a006dc,0xb4600395}},	//   ltxe, jmiĝ, чиқи, нкъл, 
   {{0x27fd4d14,0xfbd006a9,0xe9fc004d,0xdb0400d8}},	//   _irun_, עתי_, _quặc_, briõ, 
   {{0x4adc543b,0x69d401c6,0xecc8033f,0x80d8009e}},	//   न्यव, ntxe, िलाफ, _বোষ্, 
   {{0x27fc0036,0x69d4005a,0x8dd402dd,0x00000000}},	//   _krun_, itxe, _ﺘﺴﺘﻁ, --, 
   {{0xdce401e4,0x00000000,0x00000000,0x00000000}},	//   gmiĝ, --, --, --, 
   {{0xe7e016f0,0x78a000d0,0xafe403b2,0xf0340023}},	//   _गहना_, zbov, _svøð, _ኣትሒዝ, 
   {{0x69d401d4,0x78a14d15,0x00000000,0x00000000}},	//   jtxe, ybov, --, --, 
   {{0x80d800bd,0x61e001e1,0x051c0183,0x27fd4d16}},	//   _বোর্, _ipnl, বোৰৰ_, _orun_, 
   {{0xe8dc001e,0x69d401c6,0x78a00306,0xbb8418fd}},	// [21860] _ngựa_, etxe, vbov, سلاي, 
   {{0xd9e0015b,0x59d000e1,0x69100205,0xdb0401e7}},	//   ণিসম, _हमदर, _içey, lsiú, 
   {{0x27fd4d17,0x7bd54d18,0x158c00d1,0x78a000d7}},	//   _arun_, styu, _ﻗﺎﺋﯩ, tbov, 
   {{0xd9114d19,0x7d054d1a,0x2000c088,0xdb04007b}},	//   خیر_, _unks, _krii_, nsiú, 
   {{0x78a0a3e4,0x27fc01c3,0xdb04007b,0xe7b00214}},	//   rbov, _crun_, isiú, فمند, 
   {{0x27fc04c4,0xe3c00eac,0xeb954d1b,0x78a14d1c}},	//   _drun_, ্বাব, _хир_, sbov, 
   {{0xa5d400c6,0x27fd4d1d,0x7ae800f1,0xdb040254}},	//   كبير_, _erun_, _پوځې_, uriõ, 
   {{0x53994d1e,0x743802d3,0x27fc3672,0x00000000}},	//   овия_, _እትገብ, _frun_, --, 
   {{0x27fd4d1f,0x798c047e,0xb05801f4,0x5334004e}},	//   _grun_, _hubw, ngät, депт, 
   {{0x59d0006d,0x798c4180,0xf748036b,0x91b806ed}},	//   _हमार, _kubw, _اجره_, огот_, 
   {{0x20014d20,0x26b00014,0xc5ec00f1,0xdce40327}},	//   _arii_, _سٕنز, _نړي_, gliċ, 
   {{0x798d4d21,0xd5b800cd,0x00000000,0x00000000}},	//   _mubw, _ivā_, --, --, 
   {{0x798c1418,0x27282147,0x64a105c4,0x293400df}},	//   _lubw, _høna_, _чача, לאטן_, 
   {{0xdce54d22,0xd5b8002b,0x03c401ec,0x84700092}},	//   rmiĝ, _kvā_, _ісім, _ብትሆን_, 
   {{0x798c01aa,0xdce40115,0x22f4011a,0x00000000}},	//   _nubw, smiĝ, _מזגן_, --, 
   {{0x20000e14,0x2028030a,0x00000000,0x00000000}},	//   _frii_, ñviñ_, --, --, 
   {{0x31ac00bd,0x2728cc33,0x636c0162,0x00000000}},	// [21870] _কমিশ, _løna_, løna, --, 
   {{0x798c0337,0x69d4025c,0x00000000,0x00000000}},	//   _bubw, ttxe, --, --, 
   {{0xa2cd4d23,0xdb0407c5,0x20000332,0x00000000}},	//   _दास्, nsiù, _zrii_, --, 
   {{0x798c0455,0x69d4009d,0x27fd4d24,0xe8a40073}},	//   _dubw, rtxe, _prun_, खरेच, 
   {{0xd5b94d25,0xde3c0020,0x6d5d4d26,0x798c03ac}},	//   _avā_, _የሆነው, moqa, _eubw, 
   {{0x6d5d4d27,0x27283619,0x27fc0221,0x572400d1}},	//   loqa, _bøna_, _vrun_, فرىق, 
   {{0x798c0083,0xc5d401ce,0x6d5c0194,0x636c00cc}},	//   _gubw, філь, ooqa, jøna, 
   {{0x27fc1570,0x92ac015b,0x76b54077,0x6d5cca88}},	//   _trun_, গলো_, пләр_, noqa, 
   {{0x47d45713,0x27fd4d28,0x68e80114,0x798c00ca}},	//   _زيار, _urun_, megd, _zubw, 
   {{0x68e94d29,0x798c0223,0xd83801c0,0x6b840009}},	//   legd, _yubw, _ээс_, _jijg, 
   {{0x6d5c0140,0xd3b40124,0xd54800f1,0x20000051}},	//   koqa, _ҧсшь, _کلنو_, _srii_, 
   {{0x6b840369,0x68e816a3,0x4adcc6e5,0x6d5c0140}},	//   _lijg, negd, न्तव, joqa, 
   {{0x6d5c01b9,0xdb052c64,0xde4800f1,0xb058007c}},	//   doqa, asiù, ړیدو_, dgäs, 
   {{0x68e8017a,0xef8002d5,0x6b854d2a,0x636c03b2}},	//   hegd, кляп, _nijg, bøna, 
   {{0x8e540efb,0x56380023,0x00000000,0x00000000}},	//   етті, _እንነብ, --, --, 
   {{0x798c0526,0x6d5d4d2b,0x2000009f,0x04200165}},	//   _rubw, goqa, _trii_, _ōaṅk, 
   {{0x3b840323,0x6b840cf9,0x68e94d2c,0x798c2238}},	// [21880] длаг, _bijg, degd, _subw, 
   {{0x6b840369,0x6d5c0194,0xdb04143a,0xdce402f0}},	//   _cijg, aoqa, nsiø, mlič, 
   {{0x63a80097,0xfe7000c6,0x81cc0c58,0x68e800f3}},	//   _lwgn, _جدة_, ৰিক_, fegd, 
   {{0xeb9c4c2e,0x6d5c0333,0x2d54003d,0x00000000}},	//   _brød_, coqa, għed_, --, 
   {{0x798c00ca,0xdb040fac,0xd5b8002b,0xb05826bc}},	//   _wubw, ksiø, _svā_, lgär, 
   {{0x6b840369,0x798c0428,0x4adc0303,0x65780254}},	//   _gijg, _tubw, न्दव, emuh, 
   {{0xdce40122,0x158c0046,0xb0594d2d,0x75c803b9}},	//   hlič, _ﻗﺎﺗﯩ, ngär, _həzz, 
   {{0xdce4151c,0x6b8401a4,0x7d154d2e,0x13f482c8}},	//   klič, _zijg, njys, езия, 
   {{0xeb9c00b5,0x00000000,0x00000000,0x00000000}},	//   _grød_, --, --, --, 
   {{0x5214165d,0xdce40122,0x6d5c0107,0x636c143a}},	//   едот, dlič, zoqa, tøna, 
   {{0xb9d4067d,0xa2cc906f,0x91c411ca,0x75c80213}},	//   _ኸኣ_, _दार्, хәлл, _ləzz, 
   {{0xf30001c0,0xdb0405d5,0x65780009,0x00000000}},	//   хжүү, rsiù, cmuh, --, 
   {{0xdce40232,0x6d5d4d2f,0xc87800ee,0xdb0407de}},	//   glič, voqa, _başy_, ssiù, 
   {{0x636ceda6,0x2728e73f,0x68e80d27,0xd8e80327}},	//   lønn, _lønn_, zegd, _ལིཀྲ, 
   {{0x1df94d30,0x6d5c0eda,0xe1ec0691,0x6b840d27}},	//   меры_, toqa, _نسي_, _rijg, 
   {{0xdce48841,0x81cc0c58,0xc44404fb,0x5cc50b93}},	//   blič, ৰিখ_, _آیین_, ксуз, 
   {{0xd25000aa,0x158c0ed1,0x6d5c84d3,0xb05826bc}},	// [21890] _جنګ_, _ﻗﺎﺑﯩ, roqa, rgäs, 
   {{0x6d5c32ff,0xb05801e6,0x200400b5,0xc878010e}},	//   soqa, sgäs, æmie_, _gaşy_, 
   {{0x6d5c013c,0x27284606,0x636c00b5,0x6b8401a4}},	//   poqa, _bønn_, kønn, _vijg, 
   {{0x636c964d,0x6d5caa20,0x6b8401f5,0x99d4dd6a}},	//   jønn, qoqa, _wijg, ئتلا, 
   {{0x68e94d31,0x6b84f48c,0x272833b8,0xc878010e}},	//   regd, _tijg, _dønn_, _yaşy_, 
   {{0x12e002a6,0x68e80ea0,0x00000000,0x00000000}},	//   বযুদ, segd, --, --, 
   {{0xacb8004a,0x91c021f2,0x00000000,0x00000000}},	//   _flût, _विषै, --, --, 
   {{0x85080ebb,0x7c2001f4,0x00000000,0x00000000}},	//   वाइट_, äorg, --, --, 
   {{0x65794d32,0x2bc417cb,0x00000000,0x00000000}},	//   rmuh, _लिफा, --, --, 
   {{0x657822d0,0xdce484c4,0xded00023,0x00000000}},	//   smuh, vlič, እትን_, --, 
   {{0x636c28b3,0x00000000,0x00000000,0x00000000}},	//   bønn, --, --, --, 
   {{0xdce4151c,0x15b000d1,0x00000000,0x00000000}},	//   tlič, _ئەيس, --, --, 
   {{0xdce40552,0x6ac4015b,0x2afc02e5,0x00000000}},	//   ulič, র্যো, ईयाँ_, --, 
   {{0xdce40e9a,0xb059493a,0xbf14030f,0x00000000}},	//   rlič, tgär, روزب, --, 
   {{0xfce42c68,0x6e914d33,0xdce4abea,0x8db54012}},	//   ново, الفا, slič, ксті, 
   {{0xb0594d34,0xdce4655f,0x2d540135,0x00000000}},	//   rgär, plič, eħeb_, --, 
   {{0x7d14493a,0x7ff400c6,0x27283778,0x81cc0183}},	// [218a0] rjys, _أسبا, _rønn_, ৰিও_, 
   {{0x27280212,0xeab42be9,0x7c340210,0x00000000}},	//   _sønn_, ейф_, rzyr, --, 
   {{0x3f9005d9,0x46c8041c,0x6ac40154,0x00000000}},	//   _huyu_, _राजह, র্ভো, --, 
   {{0x69c009ff,0x3f914d35,0xd8840bce,0xf090010f}},	//   ánea, _kuyu_, نهای, ָנג_, 
   {{0xdec002d3,0xdb840588,0xeb9402e8,0xad18011a}},	//   _ድሓን_, _аҳаи, _пия_, _זוכר, 
   {{0xa84436e7,0x3f904376,0x6ac400eb,0x00000000}},	//   علوم_, _muyu_, র্বো, --, 
   {{0x3f914d36,0x636c05ac,0xded00023,0x00000000}},	//   _luyu_, tønn, እስና_, --, 
   {{0xe8f4011c,0x00000000,0x00000000,0x00000000}},	//   _плс_, --, --, --, 
   {{0x39454d37,0x636c0ac7,0x3f912ab4,0x937800f3}},	//   mios_, rønn, _nuyu_, мбит_, 
   {{0x39454d38,0x636c072b,0x00000000,0x00000000}},	//   lios_, sønn, --, --, 
   {{0x6ed54d39,0xb2c400f2,0x5f1400cd,0xf5e8011c}},	//   _बाबु, وغگو, दान्_, _хмел_, 
   {{0x39454d3a,0x00000000,0x00000000,0x00000000}},	//   nios_, --, --, --, 
   {{0x5f954d3b,0xb9f8001f,0x83f400c7,0x00000000}},	//   лият, _መጣ_, _аҵыс_, --, 
   {{0x3f90d376,0x3168010a,0x39454d3c,0xc0540092}},	//   _duyu_, slcz_, hios_, _የፕሮግ, 
   {{0x394402d5,0xeb9cdd74,0x80a047b8,0xe0b000cc}},	//   kios_, _stø_, _क्वे, _কাৰন, 
   {{0x9d18334a,0x3f9003f9,0xe800190e,0x00000000}},	//   ност_, _fuyu_, लिमा_, --, 
   {{0xeb90036d,0x3f914d3d,0x70bc02e5,0xacb8000f}},	// [218b0] اظر_, _guyu_, ्लील, _slûs, 
   {{0xeea94d3e,0xdb5801ee,0x00000000,0x00000000}},	//   _этик_, нюх_, --, --, 
   {{0x39454d3f,0x75c800ac,0x5f780014,0x00000000}},	//   fios_, _təzy, _سۅٲس_, --, 
   {{0x3f914d40,0xe1fc012d,0x298400c7,0x696400f7}},	//   _yuyu_, łóg_, хызг, رداق, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2d88015b,0xd83801c0,0xd6180214,0x59740133}},	//   _hice_, ээх_, کتها_, ندۆز, 
   {{0x58840184,0xdb040209,0x2d880064,0x857800c7}},	//   _ҡыуа, nsiý, _kice_, мсит_, 
   {{0x39445599,0x2d9007a9,0xded00023,0xf5300798}},	//   cios_, _muxe_, እትና_, иејќ, 
   {{0x80a02366,0x2d914d41,0x68f8009a,0x2d894d42}},	//   _क्षे, _luxe_, _iaud, _mice_, 
   {{0x2d880bb8,0x68f94d43,0x291c1132,0xa24401ed}},	//   _lice_, _haud, _houa_, ٹیبل_, 
   {{0x3f914d44,0x68f94d45,0x2d894d46,0x291d0da2}},	//   _suyu_, _kaud, _oice_, _koua_, 
   {{0x68f81494,0x3f914d47,0x291c0129,0x00000000}},	//   _jaud, _puyu_, _joua_, --, 
   {{0x68f94d48,0x20054d49,0x2d90c0f1,0x291d4d4a}},	//   _maud, ími_, _auxe_, _moua_, 
   {{0x63b94d4b,0x68f94d4c,0x2d880fa3,0x291d4d4d}},	//   msun, _laud, _aice_, _loua_, 
   {{0x2d892d1c,0x63b87a11,0x291c0270,0x3f9000e8}},	//   _bice_, lsun, _ooua_, _wuyu_, 
   {{0x68f94d4e,0x291d4d4f,0x39454d50,0x3f900589}},	//   _naud, _noua_, xios_, _tuyu_, 
   {{0x63b94d51,0x39454d52,0xab580793,0x2d894d53}},	// [218c0] nsun, vios_, _ovüd, _dice_, 
   {{0x63b94d54,0x21200399,0x2d900077,0x291c030a}},	//   isun, _hoih_, _fuxe_, _aoua_, 
   {{0x68f94d55,0x2d880c09,0x7e54af9e,0x63b80205}},	//   _baud, _fice_, _штиц, hsun, 
   {{0x68f94d56,0x2d8801b2,0x291cc4e9,0x6d400064}},	//   _caud, _gice_, _coua_, _įnag, 
   {{0x39444dce,0x68f94d57,0x291c0262,0xded0001f}},	//   rios_, _daud, _doua_, _እሱን_, 
   {{0x39440953,0x63b94d58,0x2d88084c,0x21200007}},	//   sios_, dsun, _zice_, _loih_, 
   {{0x39450e09,0x68f820ef,0x291d4d59,0x2d8800ca}},	//   pios_, _faud, _foua_, _yice_, 
   {{0xf484ff8f,0x80a017c6,0xc32c0131,0xaa40215c}},	//   купн, _क्ले, ۋەن_, _ئچكى, 
   {{0x63b8286b,0xb8654d5a,0xc9541fe9,0x7784014b}},	//   gsun, _شارو, _стры, _алаз, 
   {{0x68f94d5b,0xa6c40a31,0x3ea80175,0x00000000}},	//   _zaud, _алфа_, jbbt_, --, 
   {{0x7c380cc1,0x63b80af5,0x68f94d5c,0xdb0409ff}},	//   _ətra, asun, _yaud, lsió, 
   {{0x21200399,0x2d900005,0x216416ab,0x7658035a}},	//   _coih_, _ruxe_, итяг, _ixty, 
   {{0xdb0538aa,0xb4ac1fd5,0x21200399,0x2d888a83}},	//   nsió, करी_, _doih_, _rice_, 
   {{0x2d880316,0x2d900798,0x91c40032,0xe8003409}},	//   _sice_, _puxe_, _йәмл, लिता_, 
   {{0xdb043d0a,0xf15401af,0x00000000,0x00000000}},	//   mpiè, _ипкә_, --, --, 
   {{0x5d54ddef,0xc8d00d0d,0x9d540014,0x00000000}},	//   акст, _हाइट, ٔنِت, --, 
   {{0x2d894d5d,0x68f94d5e,0xd1e8044e,0xdb040209}},	// [218d0] _vice_, _raud, ዛእቲ_, ssiý, 
   {{0x69c03a64,0x1fa406bb,0x2d894d5f,0x291d0caf}},	//   áneo, _тръг, _wice_, _soua_, 
   {{0x2d881326,0x68f94d60,0xaca001f2,0x291d4d61}},	//   _tice_, _paud, _alụb, _poua_, 
   {{0xacb8000f,0x63b80eef,0x2d880393,0x8f4802d3}},	//   _glûp, ysun, _uice_, _ካብኣቶ, 
   {{0x68f94d62,0xeb9c00cc,0x291c0311,0x6ed407f7}},	//   _vaud, _frøa_, _voua_, बलपु, 
   {{0xeb9c0158,0x68f87805,0xe7045bb8,0xd87400be}},	//   _grøa_, _waud, کسچی, جامب, 
   {{0x68f94d63,0x291c2df9,0xdb0404d4,0xd05c013f}},	//   _taud, _toua_, asió, tesɛ, 
   {{0x63b94d64,0x38314d65,0x00000000,0x00000000}},	//   tsun, рнәр, --, --, 
   {{0x74e405f5,0x63b820ac,0xd05c016b,0x212000ad}},	//   удыг_, usun, resɛ, _roih_, 
   {{0x63b94d66,0xae102e05,0x8af803b9,0x01a8011c}},	//   rsun, डमान_, _fləş, нкок_, 
   {{0xe8dc001e,0x8184d073,0x569464ab,0xd5b8009d}},	//   _ngừa_, лгож, _тахт, _асч_, 
   {{0x7fd42355,0x63b94d67,0xa2cc01bc,0x6d4802bd}},	//   лігі, psun, _दाक्, _ňgan, 
   {{0xb1401d5a,0x212001f4,0x63b8031c,0xc8d0166d}},	//   снял, _voih_, qsun, _हाईट, 
   {{0xacb8000f,0x80d4043e,0x00000000,0x00000000}},	//   _slûp, _भावे, --, --, 
   {{0xe8dc063f,0x69c000d2,0xe51400dc,0x00000000}},	//   _amọn_, ánel, थापि_, --, 
   {{0xdb04b4a3,0x00000000,0x00000000,0x00000000}},	//   mpié, --, --, --, 
   {{0xed5416c3,0x60c54d68,0x6bd40014,0x00000000}},	// [218e0] уот_, _idim, ێوہس_, --, 
   {{0x60c40327,0x590c031c,0x63ac0419,0x6ac40154}},	//   _hdim, _གོངས_, ácny, র্সো, 
   {{0x60c40139,0x00000000,0x00000000,0x00000000}},	//   _kdim, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x60c40bd7,0x95780023,0x00000000,0x00000000}},	//   _mdim, ርከብን_, --, --, 
   {{0xdb0499d5,0x60c401d5,0xeb9c03b2,0x862c0023}},	//   rsió, _ldim, _krøn_, ታፍነት, 
   {{0xdb04022c,0x60c54d69,0xe9a002d5,0x75891b52}},	//   ssió, _odim, _гасп, нсив_, 
   {{0xb4ac3eaf,0x60c54d6a,0x80d40574,0xdb0400e4}},	//   करे_, _ndim, _भाषे, psió, 
   {{0x79800b45,0xb6a410cf,0x338400d8,0x00000000}},	//   mmow, _бизл, луов, --, 
   {{0x79814d6b,0x70bc0254,0xd94400d1,0x7658022e}},	//   lmow, ्ल्ल, _сеғи, _txty, 
   {{0xe69006d5,0xd4c457d7,0xf6540212,0x00000000}},	//   _المد, _көпк, _стаю, --, 
   {{0x6ed404e4,0x79800198,0xdb04068c,0x644c0419}},	//   _बाहु, nmow, spiè, úcic, 
   {{0x9f400054,0x60c4e22b,0x995c0419,0xe7a4010a}},	//   _asiñ_, _ddim, ríň_, _ывăл_, 
   {{0x60c54d6c,0xdef94d6d,0x88bc068f,0xc0dc1772}},	//   _edim, лыс_, _kośc, _ሕዳር_, 
   {{0x2bc438bf,0x752000b5,0x9e353e84,0xc0c0001f}},	//   _लिहा, _kooz, берч, ቻሉም_, 
   {{0x7980068f,0x27280158,0xeb9c01bf,0x88bc012d}},	//   jmow, _pønk_, _drøn_, _mośc, 
   {{0x75200218,0xdb040005,0x00000000,0x00000000}},	// [218f0] _mooz, esiñ, --, --, 
   {{0xf09c6457,0x9b4400c6,0x69c00219,0xe9fc0208}},	//   lcà_, منقو, šnem, _quắc_, 
   {{0xdb5809fe,0xeb9d4d6e,0xc8b40d31,0x60c4022e}},	//   уют_, _grøn_, аслы, _ydim, 
   {{0x75214d6f,0xf09d4d70,0x9a844f41,0xb4ac1a75}},	//   _nooz, ncà_, суул, करो_, 
   {{0xfcc00598,0x80c00729,0xf09c026c,0x27c4005b}},	//   _фәсм, ষ্ক্, icà_, ущег, 
   {{0x8cac012c,0x79800332,0x41c400cd,0x00000000}},	//   जरको, amow, _विलस, --, 
   {{0x389c0521,0x9b580131,0xb784151e,0x45340139}},	//   _ịre_, _сирт_, рәте_, ихит, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x75205ffe,0xe8dc01fb,0x60c4022e,0x636c06ea}},	//   _dooz, _ngứa_, _rdim, løni, 
   {{0x6ac40154,0xf6f400cf,0x96f91b44,0x8234007b}},	//   র্রো, _ۅزۅگ, _معمر_, لرجا, 
   {{0x88bc068f,0x7520022f,0xe5ec01f4,0x67fc0241}},	//   _gośc, _fooz, ökää, bàjá, 
   {{0x0084094c,0x2b140034,0x752006be,0x23900055}},	//   илно, नाडु_, _gooz, _ṛjur_, 
   {{0x65682784,0xe7b002a8,0x43744964,0x9948012d}},	//   _ikgh, _ƙaƙƙ, _кукт, _późn_, 
   {{0x82a4ac58,0x7980068f,0xf09c0ffb,0x272803b2}},	//   _такж, zmow, acà_, _bøni_, 
   {{0x69c054b0,0x636c0158,0x32400209,0x60c4022e}},	//   šnej, jøni, _мешг, _tdim, 
   {{0xf09c2b1d,0x8cb46ee2,0x249d4d71,0xdce40064}},	//   ccà_, йсуч, ncum_, klią, 
   {{0xeb9400c7,0x249c0393,0x3cf003b2,0x00000000}},	// [21900] иит_, icum_, reyv_, --, 
   {{0xa2f0012c,0xbd4457fb,0xdb04032e,0x00000000}},	//   _असोज_, _چندي, gsið, --, 
   {{0xfce54d72,0xb17c0092,0x8c5400e5,0x00000000}},	//   _коно, _የቃጠሎ_, لئےا, --, 
   {{0xdb054d73,0xeb9c01bf,0x7980012d,0x00000000}},	//   rsiñ, _krøl_, umow, --, 
   {{0x7980068f,0x75214d74,0x68400024,0x2bc40064}},	//   rmow, _rooz, онца, _кляп_, 
   {{0x88bc033f,0x249c0381,0x636c0162,0xb4ac05c0}},	//   _pośc, ecum_, bøni, कर्_, 
   {{0x8d840133,0xa2cc0118,0x00000000,0x00000000}},	//   _خشین, _दाज्, --, --, 
   {{0x393401c0,0xf41c00fe,0x00000000,0x00000000}},	//   _тэгс, _বেগৰ_, --, --, 
   {{0xa5040f14,0x6ed4012c,0x00000000,0x00000000}},	//   рења_, _बालु, --, --, 
   {{0x28114d75,0x752004ba,0x249c0393,0xaaac012d}},	//   _بوكس, _wooz, acum_, टरएक, 
   {{0x75214d76,0xf3c80133,0x00000000,0x00000000}},	//   _tooz, ربکه_, --, --, 
   {{0x249d4d71,0x2bc48d1b,0xeb9c072b,0x88bc00cd}},	//   ccum_, _लिला, _brøl_, _kośa, 
   {{0xceb94d77,0xe538025f,0xf09c0c95,0x00000000}},	//   лән_, _בתאר, rcà_, --, 
   {{0xe30c0156,0xf09c2b1d,0x320801c6,0xb4e00950}},	//   _ཏོགཔ_, scà_, _ахин_, क्रय_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69c0c68d,0x4c9400a7,0x2d8d4d78,0xfccc0023}},	//   šnek, сиас, öge_, _ብሕጂ_, 
   {{0xdb0403b2,0x00000000,0x00000000,0x00000000}},	// [21910] tsið, --, --, --, 
   {{0x636c005c,0xea884e85,0x00000000,0x00000000}},	//   tøni, نخان_, --, --, 
   {{0x249c003a,0xdb040413,0x00000000,0x00000000}},	//   ycum_, rsið, --, --, 
   {{0x6dbc0882,0x48141fd4,0x1d6c0092,0x00000000}},	//   ṇasy, ймес, _ደሴቶች_, --, 
   {{0x98e400c6,0x88bc0055,0x00000000,0x00000000}},	//   تكنو, _cośa, --, --, 
   {{0x57241b16,0x25f001f9,0x57a40006,0x00000000}},	//   يىنك, ंबली_, ішча, --, 
   {{0x9b640075,0x310400dc,0x00000000,0x00000000}},	//   _بۆلۈ, षयाः_, --, --, 
   {{0x1e580375,0xa2cc00bc,0x00000000,0x00000000}},	//   ישור_, _दाङ्, --, --, 
   {{0x249d4d79,0x64a14d7a,0xe6c49dc7,0x88bc002b}},	//   rcum_, бақа, _نتاي, _gośa, 
   {{0x249c1730,0x569400c2,0xe73092f9,0x66640354}},	//   scum_, _дафт, _بصر_, _къез, 
   {{0x412801c0,0x016400f7,0x9324e9d0,0x614400d1}},	//   гоно_, йкоо, ترين, قىدە, 
   {{0x049400c6,0xe5c80022,0x00000000,0x00000000}},	//   _الإح, _ñañá, --, --, 
   {{0x69c00419,0x00000000,0x00000000,0x00000000}},	//   šneh, --, --, --, 
   {{0xd17801c6,0xed5400fb,0x00000000,0x00000000}},	//   лөөх_, ҡор_, --, --, 
   {{0x442d4d7b,0xeb9c4e9b,0x5348074d,0x0d9801af}},	//   lye_, _drøm_, _тăрă, итты_, 
   {{0xd1d40092,0xbc1843e1,0x00000000,0x00000000}},	//   _ጨረቃ_, лізі_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [21920] --, --, --, --, 
   {{0x442d4d7c,0x272803b2,0xbfa8008e,0x0eb80166}},	//   iye_, _kønu_, _итүе_, _куюы_, 
   {{0x442d4d7d,0xd9100502,0xf9914d7e,0xdce4041a}},	//   hye_, ویس_, سبا_, jlić, 
   {{0x442d4d7f,0x272803b2,0xbd440832,0x00000000}},	//   kye_, _mønu_, _چنگي, --, 
   {{0x3eb94d80,0x442d4d81,0xdce401a6,0x636c03b2}},	//   _kept_, jye_, noič, lønu, 
   {{0x442c7fef,0x71a40020,0x7bd403f0,0x44e403d4}},	//   dye_, _ወደፊት_, muyu, _খোলক_, 
   {{0x7bd54d82,0x442c01d9,0xdce40e3c,0x77914d83}},	//   luyu, eye_, glić, _کیتا, 
   {{0x442c21a5,0xfccc044e,0xb0580724,0xdce4009b}},	//   fye_, _ብሕጊ_, rgäz, koič, 
   {{0x442d4d84,0x7bd50173,0x78a00122,0xf3654d85}},	//   gye_, nuyu, mcov, йтон, 
   {{0x78a00122,0x636c03b2,0x87244954,0x00000000}},	//   lcov, kønu, _وعلم, --, 
   {{0x442d4d86,0x74140133,0xded81954,0x14c80345}},	//   aye_, _گوشا, ኮንን_, _نهای_, 
   {{0x442d4d87,0x7bd54d88,0x78a003c6,0xeb9c01bf}},	//   bye_, kuyu, ncov, _drøj_, 
   {{0x442d4d89,0x7bd54d8a,0x00000000,0x00000000}},	//   cye_, juyu, --, --, 
   {{0xb8f849a6,0x7bd40724,0xa8540375,0x78a000d8}},	//   _འཐ_, duyu, מיכה_, hcov, 
   {{0x3eb94d8b,0x9e34341e,0x78a00175,0x00000000}},	//   _dept_, перч, kcov, --, 
   {{0x78a02b57,0x00000000,0x00000000,0x00000000}},	//   jcov, --, --, --, 
   {{0x7bd54d8c,0x78a00313,0xdce40fcf,0x2728005c}},	// [21930] guyu, dcov, zlić, _kønt_, 
   {{0x78a00306,0x15f801f9,0x00000000,0x00000000}},	//   ecov, ंबार_, --, --, 
   {{0x442c434d,0x4c9429cc,0x636c00b5,0x272800b5}},	//   zye_, _минс, mønt, _mønt_, 
   {{0x442c74fa,0x7bd400d5,0x27280174,0xdce416a3}},	//   yye_, buyu, _lønt_, vlić, 
   {{0x442c0067,0x219c01ec,0x7bd40205,0xe848009a}},	//   xye_, _ﺍﻟﻤﺴ_, cuyu, دجان_, 
   {{0x442d4d8d,0xdce408a4,0xf41c00eb,0x00000000}},	//   vye_, tlić, ধনার_, --, 
   {{0x442d4d8e,0x78a025f7,0x2b9c16b8,0x61380055}},	//   wye_, bcov, _hîc_, _lãla, 
   {{0x442c87cc,0xdce458af,0xd0b00213,0x052804b4}},	//   tye_, rlić, _təəc, роик_, 
   {{0x442d4d8f,0x69d407a9,0xdce42625,0x9ac40083}},	//   uye_, luxe, slić, ŋŋet, 
   {{0xb9f007db,0x442d4d90,0x27fd4d91,0x77680407}},	//   _ነቲ_, rye_, _isun_, cofx, 
   {{0x442d1175,0x2d541f21,0xeb9c0158,0x69d41195}},	//   sye_, għek_, _brøk_, nuxe, 
   {{0x442d4d92,0x3eb94d93,0x00000000,0x00000000}},	//   pye_, _sept_, --, --, 
   {{0x41c40cb4,0x2ce4025c,0xe8dc01fb,0x78b403b2}},	//   _विकस, _སྡེབ, _ngửa_, ðyvi, 
   {{0x69d4004b,0xdce40427,0x78a00306,0xa0680022}},	//   kuxe, roič, zcov, иаҟа_, 
   {{0x6da016c3,0x272811c0,0x27fc022e,0x88bc033f}},	//   диса, _høns_, _lsun_, _rośn, 
   {{0x0d994d94,0x7bd54d95,0x69d416b8,0x2ac002ea}},	//   стры_, tuyu, duxe, yébí_, 
   {{0x0ba94d96,0x78a00122,0xac0434cd,0x3eb80064}},	// [21940] مالى_, vcov, онта_, _tept_, 
   {{0x636c5b47,0x7bd54d97,0xfa3400f7,0x20014d98}},	//   møns, ruyu, يراد, _isii_, 
   {{0x272805ac,0x27fc0821,0x7bd54d99,0x78a14d9a}},	//   _løns_, _asun_, suyu, tcov, 
   {{0x69c087e0,0x7cd94d9b,0x7bd40784,0xaca000a2}},	//   ânea, _өмүр_, puyu, _duỳd, 
   {{0xa8154d9c,0x6b80063f,0x7bd40113,0x7768037e}},	//   قتور_, ọgar, quyu, tofx, 
   {{0x20000418,0xdb040428,0xb5a4b389,0x69d4031c}},	//   _msii_, tsiõ, орий, buxe, 
   {{0x27fc0248,0x78a01d55,0x20dc063f,0x891400d1}},	//   _esun_, pcov, ụiyi_, تبەئ, 
   {{0x20014d9d,0xacb8000f,0x80d418cc,0x636c005c}},	//   _osii_, _slûz, _भागे, køns, 
   {{0x20014d9e,0x636c05ac,0x957c0153,0xdb040037}},	//   _nsii_, jøns, _spąs, ssiõ, 
   {{0x3328030d,0xdb04000d,0x00000000,0x00000000}},	//   рцин_, psiõ, --, --, 
   {{0x20014d9f,0x6a980677,0xe3ac02f2,0xceb800fb}},	//   _asii_, ישינ, _یرو_, ҙәп_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe58400db,0x2cbc0419,0x3ea403b9,0x31680210}},	//   _بۅيۉ_, _ľud_, _şota_, rocz_, 
   {{0x246000c0,0x91cc01af,0x00000000,0x00000000}},	//   _dūmą_, _йәмh, --, --, 
   {{0x20000134,0x00000000,0x00000000,0x00000000}},	//   _esii_, --, --, --, 
   {{0x636c01bf,0x69d401e3,0x6ed4000d,0xe7fc0118}},	//   bøns, vuxe, _बाकु, ोटमा_, 
   {{0x69d40472,0x00000000,0x00000000,0x00000000}},	// [21950] wuxe, --, --, --, 
   {{0x425001d5,0x69d4005a,0x00000000,0x00000000}},	//   _آچیر, tuxe, --, --, 
   {{0x7bc40205,0x7c3803e3,0x9cb400d1,0x00000000}},	//   _evku, _ətri, سمەت, --, 
   {{0x69d54da0,0xe7a40131,0x29840022,0x00000000}},	//   ruxe, قۇرى_, цызг, --, 
   {{0x9f400086,0xab600046,0xdb040086,0x46a400a7}},	//   _tsiô_, _قۇرى, tsiô, палв, 
   {{0xdb040798,0x69d4056a,0x46a402e8,0x070801f7}},	//   rpiã, puxe, чакв, صيبي_, 
   {{0x2728005c,0x00000000,0x00000000,0x00000000}},	//   _søns_, --, --, --, 
   {{0xdb0400e5,0x00000000,0x00000000,0x00000000}},	//   mpiá, --, --, --, 
   {{0x27fc102c,0xa300010b,0x64a14da1,0x00000000}},	//   _usun_, дүле, пақа, --, 
   {{0xc2454da2,0xb380151e,0xaac807d0,0x6ed401f9}},	//   знок, нлыл, ाणिक, _बागु, 
   {{0xe8000db3,0x04946bcc,0x2000387a,0x42540126}},	//   लिका_, _فلاح, _ssii_, ятит, 
   {{0x67202481,0xdce400b0,0x158c0220,0x00000000}},	//   ljnj, koiā, _ﺗﺎﺳﯩ, --, 
   {{0x88bc068f,0x1400010b,0xeb9c0162,0x932401b9}},	//   _rośl, _аҗыг, _frøi_, سرین, 
   {{0x69c41711,0x6720002e,0x636c12e8,0x00000000}},	//   _ovje, njnj, røns, --, 
   {{0x636c0158,0x88bc033f,0xdbd002f0,0xb2b800d9}},	//   søns, _pośl, ržít, _המצר, 
   {{0x2bc4ec8c,0xc0c80023,0x409400cf,0xc09400ae}},	//   _लिखा, ኽቦም_, _эркт, _عجبت, 
   {{0x68e845a7,0x20014da3,0x69c0002d,0x00000000}},	// [21960] dfgd, _usii_, ânen, --, 
   {{0x3a994da4,0x00000000,0x00000000,0x00000000}},	//   стаю_, --, --, --, 
   {{0x69c439ca,0x00000000,0x00000000,0x00000000}},	//   _cvje, --, --, --, 
   {{0x69c41e31,0xbc185eb4,0x00000000,0x00000000}},	//   _dvje, _лігі_, --, --, 
   {{0x69c42dba,0xa96428a8,0x29c401e4,0x5ca4021f}},	//   _evje, чица_, aĵa_, _ىلگە, 
   {{0x7d054da5,0x00000000,0x00000000,0x00000000}},	//   _haks, --, --, --, 
   {{0x7d054da6,0x63a81570,0xbab80116,0x00000000}},	//   _kaks, _atgn, _ﺧﯘﺷﺎ, --, 
   {{0x7d054da7,0xe60d4da8,0x64c00131,0x394800c7}},	//   _jaks, اشو_, ىيىل, _узбо_, 
   {{0x69c51f18,0xad18011a,0x00000000,0x00000000}},	//   _zvje, מוקר, --, --, 
   {{0x63a8003e,0x64300451,0xa800008e,0x6d400064}},	//   _dtgn, عريء, _язул, _įnam, 
   {{0x658401a8,0x7d0403ac,0xb4f0009d,0x00000000}},	//   árhæ, _oaks, _зүйч, --, 
   {{0x3f8802c4,0x63a80334,0xfbb00154,0x6e280241}},	//   embu_, _ftgn, _চিনত, _ńgbo, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7d04079b,0xeb9c022c,0x00000000,0x00000000}},	//   _aaks, _krøv_, --, --, 
   {{0x6300ba49,0x9e1402bf,0xdef80006,0x00000000}},	//   _سويل, ндрі, чыя_, --, 
   {{0xf408025c,0x7d054da9,0x88bc0210,0x00000000}},	//   _ཀློད_, _caks, _pośm, --, 
   {{0x69c4036f,0x7d054daa,0xc0e40023,0x00000000}},	// [21970] _svje, _daks, ምኦም_, --, 
   {{0x69c00798,0x7d04127b,0x00000000,0x00000000}},	//   âneo, _eaks, --, --, 
   {{0x6b80063f,0x7050009f,0x00000000,0x00000000}},	//   ọgor, _آنڌا, --, --, 
   {{0xa1380083,0x5e8401e0,0x7a406791,0x00000000}},	//   _kuηa, _яуыз, _síté, --, 
   {{0x6d4ca061,0x5f74315b,0x482400cf,0xfc70022e}},	//   _imca, _زایر, بىشق, _ақтў, 
   {{0xeb9c0174,0x69c40427,0x7d054dab,0x69c00162}},	//   _brøv_, _tvje, _zaks, ánes, 
   {{0x69c4036f,0x7a400998,0x7d04884d,0x6d4c0200}},	//   _uvje, _víté, _yaks, _kmca, 
   {{0x6d4c0100,0x69c000e2,0xdb0801f4,0x00000000}},	//   _jmca, šnes, ölös, --, 
   {{0x6d4c0327,0x42d40111,0x7a4001e1,0x00000000}},	//   _mmca, міну, _títé, --, 
   {{0x81c94dac,0x00000000,0x00000000,0x00000000}},	//   огов_, --, --, --, 
   {{0x6ed41af8,0xeb9c0174,0x6d4c6b53,0x5b900150}},	//   _बाजु, _grøv_, _omca, _ﺒﺎﻴﻊ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7d0411f9,0xdce400df,0x6ac400fe,0x00000000}},	//   _raks, gliĝ, ৰ্যো, --, 
   {{0x6d4d4dad,0x4f940276,0x4374010f,0xf45405d0}},	//   _amca, ерсу, _קײַן_, _קיסר_, 
   {{0x7d054dae,0x4df400d6,0xfce448ab,0xcdf40228}},	//   _paks, нятт, мово, нчты, 
   {{0x6d4c0334,0xdce4010f,0x2a440092,0x7cd80b73}},	//   _cmca, bliĝ, ፒዩተሮ, تورز_, 
   {{0x7d054daf,0xed547f66,0x30014db0,0x00000000}},	// [21980] _vaks, фот_, _азыг, --, 
   {{0x6d4c293d,0x7d054db1,0x9f48023a,0xab600107}},	//   _emca, _waks, öhän_, ввул, 
   {{0x7d054db2,0xcfa8004b,0xf3300092,0xefb80092}},	//   _taks, _وایم_, _ይገባና, ታዊው_, 
   {{0x7d04143a,0x2b500175,0xe9448863,0x2de400f1}},	//   _uaks, aixc_, ورنی, _غوټۍ_, 
   {{0xf7446763,0x00000000,0x00000000,0x00000000}},	//   медо, --, --, --, 
   {{0xeb9c3570,0x2fcc01bf,0xa844027d,0xe7340139}},	//   _prøv_, _ægge_, ظلوم_, меч_, 
   {{0x1cdc025c,0x6d4c02d0,0xca64014b,0x00000000}},	//   _རྐོ_, _ymca, _зерқ, --, 
   {{0x38340131,0xf4080327,0xc7a800f7,0x00000000}},	//   _قىزز, _ཀླུད_, زدۇل_, --, 
   {{0x1418007b,0xb36402e8,0x00000000,0x00000000}},	//   سيدة_, дънк, --, --, 
   {{0xf77019f9,0x00000000,0x00000000,0x00000000}},	//   _شاء_, --, --, --, 
   {{0xd2514db3,0xdb04005b,0x00000000,0x00000000}},	//   انج_, mpiä, --, --, 
   {{0xdce401e4,0x00000000,0x00000000,0x00000000}},	//   tliĝ, --, --, --, 
   {{0xb4d805f9,0x1cdc0327,0xf1900050,0x64a036cb}},	//   ़ली_, _རྐེ_, _یُتھ, _рача, 
   {{0x5f954db4,0x09e4015b,0xdce40115,0xb27001ee}},	//   кият, নবতা, rliĝ, _иклә, 
   {{0xf20406bb,0x7bd40066,0x22f405d0,0x00000000}},	//   _цяло, eryu, _חזון_, --, 
   {{0x9d186fad,0x2c080490,0xdce401e4,0x2d54031c}},	//   мост_, हटलं_, pliĝ, jħet_, 
   {{0x37bc0154,0x7ae800f1,0x00000000,0x00000000}},	// [21990] _উৎসর, ړولې_, --, --, 
   {{0x9ac40083,0xea6000f2,0xeda401d5,0x00000000}},	//   ŋŋnt, نپذی, _ошмо, --, 
   {{0x7bd40d04,0xe9a94db5,0x6d4c010a,0x00000000}},	//   aryu, زدان_, _tmca, --, 
   {{0x9a8430af,0x6d4d0c26,0xdce403ee,0xeb9c00d4}},	//   туул, _umca, mliğ, _brøt_, 
   {{0xdce40365,0x6d5c676c,0x00000000,0x00000000}},	//   lliğ, mnqa, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdce40365,0x9f440129,0x2d540135,0x75d03bd7}},	//   nliğ, îmé_, bħet_, هيوا, 
   {{0xd6180b73,0x070800f1,0x65a403e0,0xa4914db6}},	//   بتها_, _ډيري_, _cıha, نیات, 
   {{0x47d54db7,0xeb9c1445,0x0354013d,0x00000000}},	//   _سيار, _grøt_, нүдә_, --, 
   {{0x422412b4,0xdce403ee,0x58852632,0x6d400356}},	//   едов, kliğ, _рыса, _înaf, 
   {{0x443800da,0x44b40798,0x00000000,0x00000000}},	//   šs_, _збес, --, --, 
   {{0xa44003e6,0xc0dc0023,0x91040014,0x98a40171}},	//   _لێبو, _ሕታም_, ن٘پو, _komā_, 
   {{0x98a4005f,0xa2d402ab,0x65780003,0xd12c00db}},	//   _jomā_, _मयप्, mluh, تۅي_, 
   {{0xa3540502,0x6d5c0472,0xcad4015b,0xdce40790}},	//   _تخصص, enqa, স্তফ, fliğ, 
   {{0x44fc0003,0x1cdc0135,0x98a400de,0x00000000}},	//   _དྲོར_, _རྐུ_, _lomā_, --, 
   {{0x628004b9,0x2d54031c,0x00000000,0x00000000}},	//   _izno, xħet_, --, --, 
   {{0xd24c168d,0x2ef00175,0x65781e82,0x3b840153}},	// [219a0] _هۆی_, _fbxf_, iluh, елаг, 
   {{0xdce47236,0x65784c86,0x6d5c03ac,0xb2000432}},	//   bliğ, hluh, anqa, _çüýl, 
   {{0x65794db8,0x2d540135,0x00000000,0x00000000}},	//   kluh, tħet_, --, --, 
   {{0xe1fc068f,0x3f994db9,0xa9654dba,0x00000000}},	//   łów_, _hipu_, ниха_, --, 
   {{0x3f992994,0xeb9c0158,0x65780009,0x2d540327}},	//   _kipu_, _drøs_, dluh, rħet_, 
   {{0x98a4005f,0x3f9801f7,0x56781e76,0x628004a7}},	//   _domā_, _jipu_, мбля_, _ozno, 
   {{0x6b605436,0x3f98009a,0x7afc020c,0x65794dbb}},	//   _скра, _mipu_, mept, fluh, 
   {{0x6578c900,0x3f994dbc,0x34240166,0xa5d40873}},	//   gluh, _lipu_, ефов, ربىر_, 
   {{0xe3ac58ae,0xdce403ee,0xa9654dbd,0xa3e40640}},	//   یری_, zliğ, _чита_, едња_, 
   {{0x3f994dbe,0x65780009,0x7afd4dbf,0xc32c00d1}},	//   _nipu_, aluh, nept, يەن_, 
   {{0xb5f00046,0x6578058a,0x06800150,0x00000000}},	//   _сүйі, bluh, _ﺯﺍﻳﯩ, --, 
   {{0x88bc068f,0x3f9801c4,0x7afc0af9,0x64a07b1b}},	//   _dośw, _aipu_, hept, _баца, 
   {{0x7afcde75,0x00000000,0x00000000,0x00000000}},	//   kept, --, --, --, 
   {{0x15f40807,0x7afc002d,0xdce405d1,0x6fd401ad}},	//   _आहार_, jept, tliğ, _बिठू, 
   {{0x3f98004e,0xa2b80030,0xe1ec00f1,0xe210007b}},	//   _dipu_, äčše, _هسي_, _مبيع, 
   {{0xdce40365,0x71249b26,0x00000000,0x00000000}},	//   rliğ, _سربل, --, --, 
   {{0xdce405d1,0x1bd408da,0x82400023,0x00000000}},	// [219b0] sliğ, лотя, _ኣቦታቶ, --, 
   {{0xeb9c05ac,0xdce405d1,0x6d640306,0xacb80129}},	//   _brør_, pliğ, _špač, _août, 
   {{0xaa641621,0x6578058a,0x98a40a88,0x00000000}},	//   хтак, yluh, _somā_, --, 
   {{0x99d40075,0xacb8ff0c,0x3f994dc0,0xd7c8004b}},	//   اتلا, _coût, _zipu_, ځونه_, 
   {{0xe9440af6,0xd7c8088c,0x7afd4dc1,0x18800092}},	//   ورچی, فونه_, bept, _ይናገር_, 
   {{0xfc38001f,0x6578058a,0x69d4035a,0xd87400db}},	//   _የመጣው, wluh, prxe, دامب, 
   {{0x6578113c,0xeb9c0174,0xf7400395,0x59d80118}},	//   tluh, _grør_, рещо, _डियर, 
   {{0xacb820ef,0x199400ee,0x6578003e,0x7cdc0356}},	//   _goût, _бася, uluh, mărâ, 
   {{0x99643d5e,0xd90c3b8c,0x59640395,0x398002f2}},	//   _стрл, _ریو_, _съра, _ئینف, 
   {{0x88bc0034,0x00000000,0x00000000,0x00000000}},	//   _pośw, --, --, --, 
   {{0xb38005f5,0x3f994dc2,0x657800d7,0x00000000}},	//   рлэл, _ripu_, pluh, --, 
   {{0x26c54dc3,0x7afc76fc,0x3f980270,0xb4b4035b}},	//   lano_, zept, _sipu_, _аицә, 
   {{0xf99004ac,0x3f980841,0x6280033f,0x00000000}},	//   ירט_, _pipu_, _wzno, --, 
   {{0x26c54dc4,0x6fd14dc5,0x00000000,0x00000000}},	//   nano_, _तिरं, --, --, 
   {{0x26c54dc6,0x62800841,0x016401b9,0x3f994dc7}},	//   iano_, _uzno, _икко, _vipu_, 
   {{0x307001f2,0xdce401a6,0x7c340108,0x158c0ed1}},	//   ụlụ_, tliđ, tyyr, _ﺗﺎﺟﯩ, 
   {{0x3f994dc8,0x7afc00a8,0xfaa54dc9,0x00000000}},	// [219c0] _tipu_, tept, вазо, --, 
   {{0x60c40a32,0x8c940845,0x80b8012d,0x52ac0150}},	//   _heim, урсі, ऊरके, _ﺳﺘﯟﺩ, 
   {{0x60c54dca,0x7afd4dcb,0x6bd40014,0x3ce83885}},	//   _keim, rept, _یوَس_, _छापे_, 
   {{0x6be000db,0xd88400f2,0x5d1401e2,0x00000000}},	//   اكەم, ههای, _حېرا, --, 
   {{0xb9094dcc,0x60c54dcd,0xacb806af,0x7afd4dce}},	//   _मा_, _meim, _voût, pept, 
   {{0x26c54dcf,0x60c54dd0,0x3d1432ed,0xeb9c05ac}},	//   gano_, _leim, _पोते_, _trør_, 
   {{0x98a40311,0x8a7801f0,0x00000000,0x00000000}},	//   _comă_, _зиёӣ_, --, --, 
   {{0x60c54dd1,0xeb9c0fac,0xc4440014,0x00000000}},	//   _neim, _krøp_, گیٖن_, --, 
   {{0x3ce82ba2,0xe4e0000d,0xa680013d,0x00000000}},	//   _छाने_, _गारि_, лләд, --, 
   {{0x394403b7,0x91b806ed,0x1868022e,0x00000000}},	//   lhos_, нгот_, _жағи_, --, 
   {{0x60c48323,0x53d40574,0x95540214,0xa3b46646}},	//   _beim, _दिवश, _یخچا, _یاور_, 
   {{0x39440cfc,0x60c437a8,0x65a40205,0xd4c441e5}},	//   nhos_, _ceim, _mıhl, _сөкк, 
   {{0x60c54dd2,0x2ba402ab,0xa5040354,0x00000000}},	//   _deim, _कंधा, _шеца_, --, 
   {{0x69d006ab,0xdef8035b,0xee84005b,0x00000000}},	//   _डिली, кыс_, выбо, --, 
   {{0xe2c400aa,0x394401e2,0x60c54dd3,0x00000000}},	//   _شويو_, khos_, _feim, --, 
   {{0x60c54dd4,0xdb0513b0,0x00000000,0x00000000}},	//   _geim, mpiù, --, --, 
   {{0x26c54dd5,0x394400f2,0x2ac40063,0x5ba40022}},	// [219d0] yano_, dhos_, вљев, архз, 
   {{0x26c54dd6,0x7cdc084c,0x60c40036,0x00000000}},	//   xano_, tărâ, _zeim, --, 
   {{0x26c54dd7,0x60c403d7,0x995c00bc,0x298400c7}},	//   vano_, _yeim, líř_, ҭыҵг, 
   {{0x26c54dd8,0x39440978,0x98a4054e,0x7e7802dd}},	//   wano_, ghos_, _romă_, _ﺤﺼﻠﺕ_, 
   {{0x26c54dd9,0x9bc402d5,0x00000000,0x00000000}},	//   tano_, _вёск, --, --, 
   {{0xa03c0302,0x394401a6,0x7d000115,0x00000000}},	//   ועדפ, ahos_, ĵose, --, 
   {{0x3944014f,0x00000000,0x00000000,0x00000000}},	//   bhos_, --, --, --, 
   {{0x394511f8,0x98a40356,0x00000000,0x00000000}},	//   chos_, _vomă_, --, --, 
   {{0x26c54dda,0x9f401f60,0xf8ac5220,0x291d4ddb}},	//   pano_, _opið_, _رکن_, _inua_, 
   {{0x60c54ddc,0x2d880036,0xe78408ca,0x26c40067}},	//   _seim, _lhce_, _рубо, qano_, 
   {{0x60c54ddd,0x8234141d,0xc104027d,0x00000000}},	//   _peim, ارخا, هودي, --, 
   {{0xe4c88117,0x2d44000d,0xdd0000e2,0x290d4dde}},	//   _آبان_, _jõed_, ētīb, ndga_, 
   {{0x60c403b4,0x63c001e0,0x0fc401ec,0x00000000}},	//   _veim, _талҡ, ақып_, --, 
   {{0x823402da,0x00000000,0x00000000,0x00000000}},	//   _مربا, --, --, --, 
   {{0x60c54ddf,0x291c016b,0x6e401429,0x92e8007b}},	//   _teim, _onua_, берз, _شروق_, 
   {{0x2d88489c,0x291c0134,0x3f68016c,0x39440472}},	//   _chce_, _nnua_, фиҳо_, xhos_, 
   {{0x21214de0,0x0ba813ef,0x290c0142,0x7ff4007b}},	// [219e0] _inih_, نالى_, ddga_, _إسبا, 
   {{0xec754de1,0x291c009f,0x8b68010b,0x42d400fe}},	//   упу_, _anua_, впуң_, ত্ৰশ, 
   {{0x2120012c,0xfce44164,0x00000000,0x00000000}},	//   _knih_, _йоно, --, --, 
   {{0x81b4009e,0xf8680131,0x53d4134e,0xe89000c7}},	//   _ছটা_, ىماي_, _दिलश, әашь, 
   {{0x7e7d4de2,0x00000000,0x00000000,0x00000000}},	//   _hypp, --, --, --, 
   {{0x291d4de3,0x96f80484,0x39454de4,0xf65000e5}},	//   _enua_, тект_, shos_, یئں_, 
   {{0x21201326,0x39454de5,0xc5c4035b,0x00000000}},	//   _onih_, phos_, арыҩ, --, 
   {{0x774801e1,0x291c01e4,0xb9280055,0xa6e00124}},	//   _dàbọ, _gnua_, _nauḥ_, ажәл, 
   {{0x78640f30,0x7784c1ef,0xdd040153,0xb864007b}},	//   _сказ, _блаз, ūrės, _صارو, 
   {{0x6b7409a5,0x2120011f,0xd90c01d3,0x66e00120}},	//   _işgä, _anih_, _ریڈ_, _гофа, 
   {{0x77480241,0x7e7c005b,0xe714011a,0x00000000}},	//   _gàbọ, _nypp, _תחבר_, --, 
   {{0x5edc0154,0x00000000,0x00000000,0x00000000}},	//   ম্মে, --, --, --, 
   {{0xceb8767b,0xf1a00150,0x251800df,0x257001f7}},	//   кән_, _ﺍﻟﻌﻤ_, _רודא, _اهنس, 
   {{0x21214de6,0x92948c67,0x00000000,0x00000000}},	//   _enih_, _калц, --, --, 
   {{0x1df94de7,0xa3600014,0x3d140073,0x6494008e}},	//   леры_, _دُوو, _पोहे_, _итәр_, 
   {{0x7e7c12ed,0x716402dd,0xb928002b,0x5cc400db}},	//   _dypp, _حاتك, _gauḥ_, йсуз, 
   {{0xf1d809ab,0x00000000,0x00000000,0x00000000}},	// [219f0] _भिडन, --, --, --, 
   {{0x9504031c,0x291c0332,0xb05801f4,0x00000000}},	//   _ཙིའི_, _snua_, jaäi, --, 
   {{0x9b68e465,0x7e7c03b2,0x7d0c0108,0x00000000}},	//   ушта_, _gypp, önsä, --, 
   {{0x48154de8,0x992853d9,0xda78084c,0x7d0001e4}},	//   имес, люча_, уяу_, ĵosc, 
   {{0x290c01d5,0x00000000,0x00000000,0x00000000}},	//   rdga_, --, --, --, 
   {{0x7bd80375,0x45d4311b,0x290c022e,0x98a400c0}},	//   _בקשו, ацит, sdga_, _romą_, 
   {{0x9a847314,0x27ec00db,0x2d440254,0xb058343a}},	//   _гутл, stgn_, _tõed_, lbäd, 
   {{0x291c04ac,0x00000000,0x00000000,0x00000000}},	//   _unua_, --, --, --, 
   {{0x43680484,0x61380208,0xb058002f,0x00000000}},	//   каин_, _xãlu, nbäd, --, 
   {{0x05240154,0xb058002f,0xb9280055,0x00000000}},	//   বসের_, ibäd, _sauḥ_, --, 
   {{0x572400d1,0xe6640798,0xcf480240,0x00000000}},	//   _دىلك, _стао, _ሓለፋታ, --, 
   {{0x7e7c005b,0x98a400c0,0x00000000,0x00000000}},	//   _rypp, _tomą_, --, --, 
   {{0x52740075,0xafe0004e,0x00000000,0x00000000}},	//   _қушу, ооял, --, --, 
   {{0x3f9d4de9,0x7f740395,0x543400f2,0x6fd40f4a}},	//   ötu_, румц, _درمر, _बिरू, 
   {{0x427800c8,0xef140e92,0xf1c402f0,0x00000000}},	//   _באַג, јмс_, ďáci_, --, 
   {{0x21200010,0xc0e40023,0x7d041d39,0x71714dea}},	//   _unih_, ዝቦም_, јзаж, _وهوا, 
   {{0x90e410de,0x2ca4aa50,0x00000000,0x00000000}},	// [21a00] _اسىن, ркуп_, --, --, 
   {{0x7e7d4deb,0x973c16a3,0x2d840036,0xbe880166}},	//   _typp, _kiće, _ënen_, _үсүе_, 
   {{0x6ed80302,0x3a9801a9,0x00000000,0x00000000}},	//   _בחיפ, ттаю_, --, --, 
   {{0x8304025c,0x00000000,0x00000000,0x00000000}},	//   _མིའུ_, --, --, --, 
   {{0x9b1c0085,0x88bc0034,0x7e600055,0x00000000}},	//   ɛ́nɛ, _pośr, _śoph, --, 
   {{0xdce401e4,0xbb440139,0x00000000,0x00000000}},	//   dniĉ, _тегк, --, --, 
   {{0x35681513,0xe73449b6,0x35440a93,0x94d40153}},	//   крин_, реј_, ихив, бойц, 
   {{0xa7a40022,0xb80400e5,0x00000000,0x00000000}},	//   ыкәа_, _نکتے_, --, --, 
   {{0xf364016c,0xe56c05d9,0xf6d402f2,0xc4b00116}},	//   итон, بطو_, _نزاد, _ﭼﻪﺗﺌ, 
   {{0x79800c18,0x973c2220,0xd9440075,0x77903b93}},	//   llow, _biće, _теғи, _بیتا, 
   {{0x16b4000d,0x3604027d,0x00000000,0x00000000}},	//   ुरीब, _خواف, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x75214dec,0x32014ded,0x74154dee,0x00000000}},	//   _inoz, ňky_, _خوشا, --, 
   {{0x798000fb,0x973c01a6,0xf1a54def,0x00000000}},	//   hlow, _fiće, _крин, --, 
   {{0xd37804b9,0xcda8004b,0x7980033f,0xd5b80055}},	//   moć_, اهره_, klow, _drāg_, 
   {{0xe29805d0,0xdcb80138,0x61f400fd,0x95f800fe}},	//   _בשור, ищу_, _äxla, _আছাম_, 
   {{0x7520022a,0x9cc802dc,0x2d440254,0x79800210}},	// [21a10] _mnoz, рыса_, _põeb_, dlow, 
   {{0xd3781050,0x98b80325,0xd5a401ed,0xb058007c}},	//   noć_, _ērā_, _يہ_, rbäd, 
   {{0x752052f4,0xb058007c,0xa9280150,0x00000000}},	//   _onoz, sbäd, кіде_, --, 
   {{0x3e14008f,0x79814df0,0xdb0400ee,0xd8b81a9b}},	//   _פֿיל_, glow, mpiý, لدها_, 
   {{0xd3783c52,0x00000000,0x00000000,0x00000000}},	//   koć_, --, --, --, 
   {{0x752005b8,0x048807dd,0x79802df3,0x4428003d}},	//   _anoz, қәеи_, alow, _ħa_, 
   {{0xb7840184,0x79800034,0xeb000b03,0xd5e8007b}},	//   сәте_, blow, रजीत_, لعين_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x68f94df1,0x973c009b,0x2eb4146b,0x461453a2}},	//   _ibud, _siće, _अभूत, _گوار, 
   {{0x75214df2,0x27fd4df3,0x1cdc025c,0x973c07f5}},	//   _enoz, _ipun_, _རྐན_, _piće, 
   {{0x4615131f,0x00000000,0x00000000,0x00000000}},	//   _دوار, --, --, --, 
   {{0x75214df4,0x973c00f3,0x7a3001a9,0x00000000}},	//   _gnoz, _viće, _mаtе, --, 
   {{0x44282047,0x68f83dc1,0x62e401d9,0x65a40790}},	//   _ça_, _mbud, _نِشہ_, _sıhh, 
   {{0x63b94df5,0xafe41125,0x27fc0214,0x798015c0}},	//   mpun, _støð, _mpun_, zlow, 
   {{0x68f89464,0x63b867c3,0x79814df6,0x6e4001f4}},	//   _obud, lpun, ylow, перз, 
   {{0x68f80521,0xed54136b,0x63b94df7,0x27fc054e}},	//   _nbud, бос_, opun, _opun_, 
   {{0x63b94df8,0x8fd40032,0x00000000,0x00000000}},	// [21a20] npun, _мәрә, --, --, 
   {{0x68f94df9,0x7981090f,0x18280133,0x63b817ef}},	//   _abud, wlow, یقای_, ipun, 
   {{0x79814dfa,0x27fd4686,0x63b84a14,0xbd4485e2}},	//   tlow, _apun_, hpun, _هندي, 
   {{0x68f82de1,0x79800161,0xe4445230,0x6d38001f}},	//   _cbud, ulow, _فض_, _በሪፖር, 
   {{0xacf42ad5,0x63b802d1,0x6fc87220,0x27fc007c}},	//   _اسپت, jpun, तीपू, _cpun_, 
   {{0x63b94dfb,0x68f94dfc,0xdce40003,0xb05801e3}},	//   dpun, _ebud, kniċ, lbäc, 
   {{0x63b8257c,0xfaa401b9,0x00000000,0x00000000}},	//   epun, _ваҳо, --, --, 
   {{0x63b8257c,0x93b40212,0xb058aa9a,0x00000000}},	//   fpun, обиц, nbäc, --, 
   {{0x63b8da76,0x65680175,0xf8b401e0,0xa504033a}},	//   gpun, _djgh, _көҙ_, сења_, 
   {{0xdb054dfd,0x96e8021a,0x68f83f5c,0x51f80212}},	//   mpió, _خبرې_, _zbud, аною_, 
   {{0x63b94dfe,0x20014dff,0x00000000,0x00000000}},	//   apun, _apii_, --, --, 
   {{0x7144656c,0x73e40953,0x93880220,0x75214e00}},	//   схож, _годз, ысқа_, _unoz, 
   {{0x96ac012c,0x2b8c0205,0xdfd80395,0x00000000}},	//   _चलाउ, lüce_, йър_, --, 
   {{0xc90400e1,0xd5b800b8,0x00000000,0x00000000}},	//   _रस्म_, _ktā_, --, --, 
   {{0x2000007f,0xe3102e0b,0x00000000,0x00000000}},	//   _epii_, _ربوب, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x68f80055,0x09d001f9,0xf080072d,0x00000000}},	// [21a30] _rbud, हळ्य, _ریسپ, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x27fd4e01,0x1cdc0327,0x63b80112,0x6f04310a}},	//   _spun_, _རྐམ_, zpun, mejc, 
   {{0x63b82576,0x6f0406d8,0x00000000,0x00000000}},	//   ypun, lejc, --, --, 
   {{0xd5b803a0,0x6d5d4e02,0xdd980262,0x65a401d3}},	//   _atā_, miqa, _ышь_, _műhe, 
   {{0x6d5d4e03,0x6f04a5fd,0x68f8033f,0xd6c40116}},	//   liqa, nejc, _wbud, пишқ, 
   {{0x27fc05b1,0xc5d402bf,0x00000000,0x00000000}},	//   _wpun_, ціль, --, --, 
   {{0x63b804b9,0x6d5c0cfe,0xff1804ce,0x6f04c329}},	//   tpun, niqa, _macで, hejc, 
   {{0x63b802f6,0xd5b800cd,0x4438003a,0x1c1c2ac3}},	//   upun, _etā_, âs_, नियल_, 
   {{0x63b94e04,0x6d5d4e05,0x69c438ed,0xb3814e06}},	//   rpun, hiqa, _kwje, млыл, 
   {{0x63b94e07,0x6d5d4e08,0x6f04012c,0x2000009a}},	//   spun, kiqa, dejc, _spii_, 
   {{0x63b94e09,0xaca001e1,0x41580212,0xdce4025c}},	//   ppun, _alọb, ршою_, rniċ, 
   {{0x63b802d1,0x65780af9,0x6d5c058a,0x00000000}},	//   qpun, mouh, diqa, --, 
   {{0x63a81c06,0x973c00f3,0x65794e0a,0x6d900129}},	//   _iugn, _kića, louh, nçaf, 
   {{0x4175252c,0x63a94e0b,0x3390034c,0x63a00869}},	//   _وابس, _hugn, _تلوز, _iinn, 
   {{0x63a14e0c,0x6d5c0357,0x6d40084c,0x973c00f3}},	//   _hinn, giqa, _înal, _mića, 
   {{0x63a14e0d,0x442d4e0e,0x63a807ab,0x62800368}},	// [21a40] _kinn, nxe_, _jugn, _hyno, 
   {{0x63a14e0f,0x63a80395,0x62814e10,0xd9107b02}},	//   _jinn, _mugn, _kyno, کیر_, 
   {{0x63a8049f,0xdce54e11,0x63a048ed,0x65780419}},	//   _lugn, lnič, _minn, kouh, 
   {{0x63a034a6,0x6d5ccc94,0x62806da7,0xdce40e3c}},	//   _linn, ciqa, _myno, onič, 
   {{0x63a81c06,0x63a001e7,0x7d1400c0,0x510c00df}},	//   _nugn, _oinn, mdys, טהאַ, 
   {{0x63a14e12,0x1754824c,0xadc00ca8,0x442c01c4}},	//   _ninn, явля, _afẹd, dxe_, 
   {{0xe1e40a81,0x62800c58,0x63a938e6,0xe9d433ac}},	//   _تس_, _nyno, _augn, _мкр_, 
   {{0x7d154e13,0xdb04bc9f,0x63a94e14,0x63a01552}},	//   ndys, mpiñ, _bugn, _ainn, 
   {{0x63a06d9f,0xdce40b91,0x63a94e15,0x62800009}},	//   _binn, jnič, _cugn, _ayno, 
   {{0x63a0387b,0x63a94e16,0x6d5d4e17,0xb7440372}},	//   _cinn, _dugn, ziqa, _بئرو, 
   {{0x442c172e,0x628000a9,0xd5b80a26,0x6d5d4e18}},	//   axe_, _cyno, _utā_, yiqa, 
   {{0x63a000fc,0x628000a9,0x6d5c022f,0xeb9c1445}},	//   _einn, _dyno, xiqa, _drøy_, 
   {{0x63a0ee18,0x63a8011c,0x7d154e19,0x6d5d4e1a}},	//   _finn, _gugn, ddys, viqa, 
   {{0x63a14e1b,0xeb9c0217,0x6280017a,0x5fdc28d4}},	//   _ginn, _frøy_, _fyno, _बिरल, 
   {{0x6d5d4e1c,0x62814e1d,0x6d914e1e,0x68e80267}},	//   tiqa, _gyno, nçag, yggd, 
   {{0x63a14e1f,0x63a89420,0xe6c4448b,0x21640108}},	//   _zinn, _yugn, _रज्ज, _отыг, 
   {{0x6d5d4e20,0x63a14e21,0x7124004b,0xdce40306}},	// [21a50] riqa, _yinn, _هرکل, cnič, 
   {{0xce9406bb,0x7d140076,0x6d5d4e22,0x63a00a55}},	//   _напъ, adys, siqa, _xinn, 
   {{0x5f7400db,0x6d5c0784,0x6578fecd,0x7d140064}},	//   _تاير, piqa, youh, bdys, 
   {{0x6d5c07d6,0x442c022f,0x88940276,0x6ee41fae}},	//   qiqa, yxe_, пиех, _اسکل, 
   {{0x65794e23,0xd7c80691,0x973c01a6,0x442c011f}},	//   vouh, قونه_, _sića, xxe_, 
   {{0x63a94e24,0x973c01a6,0x00000000,0x00000000}},	//   _rugn, _pića, --, --, 
   {{0x63a94e25,0xb6a06d8c,0x6d90036e,0x65780108}},	//   _sugn, нишл, rçaf, touh, 
   {{0x63a94e26,0x442c4ecc,0x63a0982e,0x2bfc007d}},	//   _pugn, txe_, _sinn, _उहां_, 
   {{0x442c06ed,0x63a14e27,0x65794e28,0x446416ab}},	//   uxe_, _pinn, rouh, явив, 
   {{0x442c172e,0xdce4e64e,0x6d914e29,0x63a00af5}},	//   rxe_, vnič, lçad, _qinn, 
   {{0x63a14e2a,0x7d154e2b,0x442c00b5,0x65780165}},	//   _vinn, ydys, sxe_, pouh, 
   {{0xdce40bb8,0x6d914e2c,0x63a94e2d,0x63a14e2e}},	//   tnič, nçad, _tugn, _winn, 
   {{0x63a8079b,0x8234bc3d,0x62800034,0x442c208d}},	//   _uugn, زرگا, _wyno, qxe_, 
   {{0x63a10186,0x28d8193d,0xdb0402d1,0xe5d000a2}},	//   _uinn, मृति, ypiñ, _tüńń, 
   {{0xf26401af,0x6d90013d,0x00000000,0x00000000}},	//   _нишл_, kçad, --, --, 
   {{0xed54d74f,0xb0594e2f,0xdce54e30,0x00c8022e}},	//   пос_, mbän, pnič, _улик_, 
   {{0x7d154e31,0xdb040309,0xb0594e32,0x6fb000ae}},	// [21a60] rdys, wpiñ, lbän, _كميا, 
   {{0x7d1406ea,0x1ee80214,0x00000000,0x00000000}},	//   sdys, _بودی_, --, --, 
   {{0xb058dca6,0x2f38011a,0x00000000,0x00000000}},	//   nbän, _הגיד, --, --, 
   {{0xdb046bdf,0x2d440037,0x00000000,0x00000000}},	//   rpiñ, _jõel_, --, --, 
   {{0xdb040227,0xe78001d3,0x2b241884,0xad18011a}},	//   spiñ, کلوپ, تكەپ_, _הוכר, 
   {{0x6d900120,0xeb954e33,0x84880023,0x00000000}},	//   açad, _ния_, _ምስራዕ_, --, 
   {{0xb4b004a9,0xf77001d9,0x6d9006be,0x00000000}},	//   нийә, ٘اں_, bçad, --, 
   {{0x6d914e34,0xe5a00640,0xe9900220,0x2d440254}},	//   rçag, нији, _كۇلگ, _nõel_, 
   {{0x7bd49f40,0x00000000,0x00000000,0x00000000}},	//   nsyu, --, --, --, 
   {{0x39454e35,0x3328084c,0x366800d8,0x36341411}},	//   lkos_, сцин_, _лазо_, _ىراس, 
   {{0x62841f21,0x7bd40a2e,0xb6880f87,0x326520bf}},	//   żjon, hsyu, _اپال_, ятив, 
   {{0x394402d5,0x7bd54e36,0x98cc0118,0x00000000}},	//   nkos_, ksyu, ारिए, --, 
   {{0x39454e37,0x2d840374,0xa30801ed,0x00000000}},	//   ikos_, _ënei_, _گرنے_, --, 
   {{0x973c0cf4,0xab5800fd,0xb058007c,0xdfa4041b}},	//   _mićo, _itüg, bbän, ејсо, 
   {{0x39440a55,0x00000000,0x00000000,0x00000000}},	//   kkos_, --, --, --, 
   {{0x3944547b,0x8fd001af,0xe21000ae,0x216800f3}},	//   jkos_, _иҙмә, _أبوع, _нији_, 
   {{0xb3080dd4,0xdbc80086,0xaac40a2c,0x39441979}},	// [21a70] _ཀྲོང_, _bôñe, كتان, dkos_, 
   {{0xa2bc0b7d,0x2aa8026a,0xe1a80307,0x39452049}},	//   लुप्, стао_, _घूँघ, ekos_, 
   {{0x3944017a,0xaa8403e6,0x99d40244,0x1fb80154}},	//   fkos_, سۆرم_, فتنا, _জিএস, 
   {{0x39442889,0x9f48023a,0x298400c7,0x00000000}},	//   gkos_, öhön_, чызг, --, 
   {{0x6d914e38,0xab60198a,0x2ba40490,0x00000000}},	//   rçad, _كۇرى, _कंटा, --, 
   {{0xab5804cc,0xd8740424,0x98c400ee,0x394401f4}},	//   _stüf, رانب, _үстл, akos_, 
   {{0x6f14102c,0xf8ac00dd,0xb308025c,0x6d914e39}},	//   _maxc, اکہ_, _ཀྲེང_, pçad, 
   {{0x973c01a6,0x394422d9,0x5a340816,0x00000000}},	//   _fićo, ckos_, _янст, --, 
   {{0x07081e5a,0x4814010b,0x6f1402d0,0xc8680244}},	//   _ويري_, _юмас, _oaxc, _بڕاو_, 
   {{0x6f154e3a,0xc245277b,0x2d440254,0xb058002f}},	//   _naxc, днок, _sõel_, tbän, 
   {{0x6b98011c,0x69d40077,0xe8e8031c,0xc0e4072c}},	//   _èugu, nsxe, _ལྐོག, монк, 
   {{0xb0592341,0x7bd40113,0xdc3c0419,0x5fdc000d}},	//   rbän, ysyu, _sáčo, _बिआल, 
   {{0x6f140429,0x1b140011,0x00000000,0x00000000}},	//   _baxc, ঠাতে_, --, --, 
   {{0xd4980323,0x53340166,0xd7e0000d,0x00000000}},	//   _эрх_, _печт, _निसच, --, 
   {{0xa508031c,0x6ab40175,0xab580254,0x394401e3}},	//   _ཁྲོག_, dcxf, _mtüd, ykos_, 
   {{0xdb240101,0x00000000,0x00000000,0x00000000}},	//   کوئی, --, --, --, 
   {{0x7bd400b5,0x6f140419,0xcfb40154,0xb058002f}},	// [21a80] usyu, _faxc, জীবন, nbäl, 
   {{0x7bd433cb,0xeb94084c,0x7f5c02d0,0xc0e800f2}},	//   rsyu, диу_, _umpq, _افکن_, 
   {{0x973c00f3,0x39454e3b,0x00000000,0x00000000}},	//   _sićo, tkos_, --, --, 
   {{0x394402d5,0x7bd402d1,0x3f88031c,0xceb80118}},	//   ukos_, psyu, llbu_, ěře_, 
   {{0x3944ea8b,0x6f14011f,0x59e001f9,0x00000000}},	//   rkos_, _yaxc, _पटवर, --, 
   {{0x39454e3c,0x56954e3d,0x88800116,0x68400395}},	//   skos_, налт, уғул, ънча, 
   {{0x1c1c012d,0x2ba400cd,0x39440064,0x00000000}},	//   निवल_, _कूटा, pkos_, --, 
   {{0xe944129e,0xab58aead,0x6920004e,0x00000000}},	//   _قرقی, _etüd, _имса, --, 
   {{0xb308038f,0x6284025c,0x00000000,0x00000000}},	//   _ཀྲུང_, żjol, --, --, 
   {{0x628c0034,0xf74801b9,0x00000000,0x00000000}},	//   ęcon, _بجره_, --, --, 
   {{0x6f140de2,0x5fdc00bc,0x75b401a9,0x00000000}},	//   _raxc, _बिउल, _ўғит_, --, 
   {{0xe5e401b9,0x2d4400d8,0xab594e3e,0x00000000}},	//   _آزلی, _põem_, _itüe, --, 
   {{0x6d4000a8,0x3eb80175,0x170c031c,0xe5a0011c}},	//   _înai, _bfpt_, _གྲོམ_, _рици, 
   {{0xe1ec6103,0xb35400f2,0x00000000,0x00000000}},	//   دسی_, _آیدا_, --, --, 
   {{0x6f140066,0xa6d00011,0x707400ec,0x2658010f}},	//   _vaxc, _সাময়, _ڪاغذ, ַכמא, 
   {{0x98a40100,0x3f880ffb,0x6f154e3f,0xdd944990}},	//   _anmč_, albu_, _waxc, васы, 
   {{0x6f140789,0x2bb8007b,0x00000000,0x00000000}},	// [21a90] _taxc, تازة_, --, --, 
   {{0x7bd800b0,0x6a654e40,0x25ec00e1,0x00000000}},	//   _ātut, وطال, _इमली_, --, 
   {{0xe8e80003,0xecb001af,0x8e8c0116,0x00000000}},	//   _ལྐུག, _аҡбы, ﻨﯩﯖﭽ, --, 
   {{0xab59063e,0x7e98011a,0x00000000,0x00000000}},	//   _stüd, _מסתו, --, --, 
   {{0x6d4c0395,0x5f740214,0x69d40076,0x00000000}},	//   _ilca, _سایر, ssxe, --, 
   {{0xae000574,0x00000000,0x00000000,0x00000000}},	//   _लहान_, --, --, --, 
   {{0xa50849a6,0x9a841422,0x69d40135,0x00000000}},	//   _ཁྲུག_, _аутл, qsxe, --, 
   {{0x592808ea,0xf5e40075,0x1a682a77,0x00000000}},	//   _རོགས_, رتىۋ, _تیمی_, --, 
   {{0xf8b00a1e,0x58d401ec,0xdb0401f4,0xd918010a}},	//   _תשמ_, _шотт, rpiö, _юьр_, 
   {{0x7d0001e4,0x62840327,0x00000000,0x00000000}},	//   ĵosi, żjom, --, --, 
   {{0x26c40fb7,0x6d4d4e41,0xb058002f,0xd78801e2}},	//   mbno_, _olca, sbäl, _غنمو_, 
   {{0x36180302,0x00000000,0x00000000,0x00000000}},	//   _מועד, --, --, --, 
   {{0x75340677,0x00000000,0x00000000,0x00000000}},	//   _ראנד_, --, --, --, 
   {{0x6d4cebee,0x26c40427,0x9578009d,0x00000000}},	//   _alca, nbno_, _нөөс_, --, 
   {{0xfd940b7e,0x68440055,0x5fac0073,0x26c40009}},	//   ешаю, _hīdā, _टंकल, ibno_, 
   {{0x65a401d3,0x00c800db,0x00000000,0x00000000}},	//   _műho, _элик_, --, --, 
   {{0xec740262,0xed554e42,0x7ed41cb8,0x33f8010f}},	// [21aa0] епт_, хот_, _пінч, ּהענ, 
   {{0x6d4d1d0a,0xbb847c8a,0xac8000cf,0x00000000}},	//   _elca, رلاي, угул, --, 
   {{0x2d701050,0xba740451,0xe94407d6,0xeef40375}},	//   mćen_, رائت, کرلی, _אמיר_, 
   {{0x6d4c01ab,0xcee801ed,0xb4dc0243,0x6d900790}},	//   _glca, _ٹرین_, _तये_, rçac, 
   {{0x170c025c,0xab5804cc,0x108800d1,0xe7b40150}},	//   _གྲུམ_, _stüe, ﺑﯩﺪﯨ, егіш_, 
   {{0xf09004ac,0x1b1403d4,0x00000000,0x00000000}},	//   אנד_, ঠাহে_, --, --, 
   {{0x3870084c,0x5fd00490,0xeb954e43,0x00000000}},	//   _ţară_, तीतल, _чир_, --, 
   {{0xe9a0005e,0x684400de,0x56943c1a,0x51c80150}},	//   _басп, _bīdā, наһт, _ﺒﺈﻨﺸ, 
   {{0x88814e44,0xc8f800db,0x79805dd4,0x32e40241}},	//   _پیون, _توقچ_, moow, _níyà_, 
   {{0xb5f00046,0x973c00f3,0x79814e45,0x00000000}},	//   _бүкі, _mićk, loow, --, 
   {{0xc7640952,0x925801af,0x00000000,0x00000000}},	//   _شاكى, фант_, --, --, 
   {{0x79814e46,0x00000000,0x00000000,0x00000000}},	//   noow, --, --, --, 
   {{0xf1a8d36d,0xa508025c,0xe5380375,0x00000000}},	//   _کاته_, _ཁྲིག_, _מתאר, --, 
   {{0x64a08743,0xd0ec0490,0x37d003d4,0x7980b061}},	//   _сача, _झाकण_, _সমাৰ, hoow, 
   {{0x7980d912,0x717000d1,0x91b801a9,0x00000000}},	//   koow, _مۇدا, _ўгит_, --, 
   {{0xcacc0eac,0xc0c001ee,0x7bd8002b,0xad4000db}},	//   _লাইফ, _вәри, _ātur, دىرۉ, 
   {{0x79814e47,0xe7cc0034,0x1b6c02d3,0x61ec012d}},	// [21ab0] doow, _सौंप, _ተረኽቦ_, ącle, 
   {{0xab594e48,0x00000000,0x00000000,0x00000000}},	//   _stüb, --, --, --, 
   {{0x26c409a8,0x2ebc4668,0xe9a94e49,0x7980058a}},	//   vbno_, ्रीत, سدان_, foow, 
   {{0x79814e4a,0x6d4c02d0,0xdb500014,0xcb0800ec}},	//   goow, _ulca, َٔے_, _ڪيسن_, 
   {{0x399c00bc,0xcba400d1,0xa158011a,0x00000000}},	//   _růst_, _җаңй, עבדה_, --, 
   {{0xe9d01291,0x00000000,0x00000000,0x00000000}},	//   _مغر_, --, --, --, 
   {{0xc8f40c04,0x26c409a8,0x79803010,0x68440055}},	//   _извъ, rbno_, boow, _sīdā, 
   {{0xb8b00046,0x2ebc0b7c,0x798027a2,0x76b40075}},	//   _көші, ्रुत, coow, нләр_, 
   {{0x290d4e4b,0x670068b2,0x98a400e2,0x039402e8}},	//   mega_, _бүлб, _domē_, кроя, 
   {{0x290d4e4c,0x42240212,0x00000000,0x00000000}},	//   lega_, вдов, --, --, 
   {{0x170c031c,0x2d7000f3,0x27ec01e3,0x00000000}},	//   _གྲིམ_, vćen_, lugn_, --, 
   {{0x290d4e4d,0xf1b801fb,0x00000000,0x00000000}},	//   nega_, _trơn_, --, --, 
   {{0x27ec0036,0x00000000,0x00000000,0x00000000}},	//   nugn_, --, --, --, 
   {{0x290d4e4e,0xef8001d5,0x00000000,0x00000000}},	//   hega_, иляп, --, --, 
   {{0x290d4e4f,0x5ed403f4,0x79814e50,0x021800d4}},	//   kega_, _তাদে, yoow, _ціль_, 
   {{0x290d4e51,0x798000e8,0x71740166,0xd1cc0092}},	//   jega_, xoow, _үбәр_, ጣኖች_, 
   {{0x290c033d,0x6da14e52,0xada03522,0x3b8480a2}},	// [21ac0] dega_, рита, ратл, влаг, 
   {{0x290d4e53,0x27ec04cc,0x79814e54,0x6d90004e}},	//   eega_, dugn_, woow, rçaa, 
   {{0xab580639,0x290d4e55,0xbea41677,0x79807e37}},	//   _stüc, fega_, _јанк, toow, 
   {{0x290d4e56,0x6d914e57,0xadd40a7c,0x6920010a}},	//   gega_, lçan, _בוטח_, имха, 
   {{0x6b840649,0x79810e48,0x27ec05d5,0xe7b08074}},	//   _fkjg, roow, gugn_, لمند, 
   {{0x6d904683,0x290c00c5,0x79814e58,0x39e803f6}},	//   nçan, aega_, soow, _одго_, 
   {{0x290d4e59,0x6f000ab7,0xca740723,0x7864022e}},	//   bega_, _önce, _буты, _sаvd, 
   {{0x290d4e5a,0x94181064,0x973c009b,0x7c2401c7}},	//   cega_, ежит_, _mići, _krkr, 
   {{0xa8854e5b,0xa9654e5c,0x3f98014f,0xa5040640}},	//   _айта_, _рита_, _ohpu_, тења_, 
   {{0x5fdc028a,0x00000000,0x00000000,0x00000000}},	//   _बिजल, --, --, --, 
   {{0xe73514ba,0xb5f00220,0x98a40171,0xd0d40395}},	//   _шеф_, _түйі, _tomē_, лонъ, 
   {{0xb4640daf,0xf3e401b9,0x046401ec,0x00000000}},	//   _икел, _аждо, _өтім, --, 
   {{0x6fb00073,0x00000000,0x00000000,0x00000000}},	//   _आढळू, --, --, --, 
   {{0x290d4e5d,0x973c04a7,0x6438008f,0x2ebc227c}},	//   zega_, _bići, _קעגנ, ्रेत, 
   {{0x1df811db,0x290d4e5e,0x606c0092,0x00000000}},	//   керы_, yega_, ሰራጨት_, --, 
   {{0x2cad4e5f,0x926801b9,0x6d9000d8,0xb060005b}},	//   øgd_, _орқа_, açan, ääss, 
   {{0x290d4e60,0x9da800a7,0x6d9006be,0x00000000}},	// [21ad0] vega_, търа_, bçan, --, 
   {{0x290d4e61,0x27ec07de,0xdca40063,0x207c0a7c}},	//   wega_, vugn_, рађи, _קאזא, 
   {{0x290d4e62,0x7c2403fa,0x4f840014,0xd5b80055}},	//   tega_, _erkr, _لاگہ, _drāk_, 
   {{0x290c0421,0xa6cc015b,0xc4cc0154,0x00000000}},	//   uega_, _রাইট, _রঞ্জ, --, 
   {{0x5fdc00e1,0x7d0001e4,0x5c18010a,0x00000000}},	//   _बिछल, ĵost, _итрĕ, --, 
   {{0x290d4e63,0x26d00005,0xab640171,0x00000000}},	//   sega_, úxo_, _boļš, --, 
   {{0x290d4e64,0xf8ac021a,0xdce40003,0x27ec007c}},	//   pega_, _ځکه_, lliġ, sugn_, 
   {{0xacb80140,0xf8ac0133,0x27ec0076,0x02bc194b}},	//   _inûs, _فکه_, pugn_, ोर्न, 
   {{0x42d438a9,0xaaa400dc,0x39800214,0xd7f8994d}},	//   ліну, _कृतक, _اینف, _аух_, 
   {{0x81c85fce,0x2ebc4f3c,0xb9ec01f3,0xd7c8135f}},	//   нгов_, ्रोत, _ዕብ_, _شومه_, 
   {{0xfb1400c8,0xb38001c0,0x6d900200,0xe5740117}},	//   אַכט_, слэл, vçan, _иҷк_, 
   {{0xeb9c0579,0xc4580395,0xb63c0150,0x00000000}},	//   _spøl_, _пиех_, _ﻀﺕ_, --, 
   {{0xd9e00d0b,0x31b80171,0x00000000,0x00000000}},	//   _पट्ट, _vīza_, --, --, 
   {{0x973c16a3,0x06e400bd,0x645800ec,0x5ed40154}},	//   _pići, প্রি, mzui, _তাহে, 
   {{0x6d914e65,0xfce44834,0x8db45566,0xb06000af}},	//   rçan, лово, исті, äärs, 
   {{0x8d554e66,0xee34084c,0xfce400d8,0x00000000}},	//   атуч, ынс_, ѓозо, --, 
   {{0x645801a4,0xdce54e67,0x1b6400c7,0xd5b800cd}},	// [21ae0] nzui, hnić, анаҭ, _prāk_, 
   {{0x6d901ae4,0x6458009f,0x603403b9,0xc7b800e5}},	//   lçal, izui, _cəmş, _erők_, 
   {{0xeb940640,0xdce416a3,0x699c0073,0x0e740006}},	//   ћих_, jnić, _ओळखी, _выяў, 
   {{0x6d914e68,0xfd1000ae,0x00000000,0x00000000}},	//   nçal, _اجد_, --, --, 
   {{0xf7454e69,0x4c340276,0xab5800fd,0xef0c00f1}},	//   ледо, _кэрт, _itün, _بټۍ_, 
   {{0xa7700826,0xe7340801,0x6d40054e,0x6d900205}},	//   бліч, леч_, _înar, hçal, 
   {{0x64580d27,0x1c1c6b9b,0x398c01a8,0xb0580221}},	//   ezui, निकल_, hýsi_, rbäi, 
   {{0x64580196,0x06e4015b,0xaee000b8,0x398c0118}},	//   fzui, প্লি, _kiṃd, kýsi_, 
   {{0x38540801,0x645801f5,0xbec0002e,0x00000000}},	//   _съвс, gzui, _ñëwl, --, 
   {{0xe3bc1709,0x00000000,0x00000000,0x00000000}},	//   íña_, --, --, --, 
   {{0x9294189d,0x6d9003b9,0x00000000,0x00000000}},	//   ранц, fçal, --, --, 
   {{0x25f0069f,0xd4c4837a,0x2b8c03fa,0x6458054e}},	//   ्झरी_, _төкк, tück_, bzui, 
   {{0x45a000db,0x533400f3,0x7648010e,0x00000000}},	//   _بەيك, _велт, lyfy, --, 
   {{0x2b8d4e6a,0x23240640,0xa3f40375,0x00000000}},	//   rück_, _бољи_, _עמוק_, --, 
   {{0xd904066d,0x6d9003b9,0xd82401e2,0xed040798}},	//   _ٹی_, bçal, _کۍ_, лџан, 
   {{0x9d183169,0xd904030f,0x00000000,0x00000000}},	//   лост_, _عی_, --, --, 
   {{0xdd954e6b,0x5ed400bd,0xdce40cf4,0x61100327}},	// [21af0] саты, _তারে, znić, _ཏྲིཾ_, 
   {{0xacb8002d,0x3168033f,0xceb800fb,0x00000000}},	//   _saûd, licz_, _шәм_, --, 
   {{0xdce4012d,0xec14008e,0x6d91126b,0xcd9400f3}},	//   hnię, _өенә_, lçam, _ванћ, 
   {{0xf09c0295,0x973c0960,0xdce40034,0x88bc0055}},	//   beàt_, _miću, knię, _maśg, 
   {{0x6d914e6c,0xda7802dd,0x00000000,0x00000000}},	//   nçam, _ұят_, --, --, 
   {{0x6458036b,0x6d90068c,0x5fbc008f,0xc7a4de2f}},	//   vzui, içam, עצונ, шилк, 
   {{0x764803cb,0x055402e8,0x85784130,0x00000000}},	//   gyfy, ития, ксит_, --, 
   {{0xdce54e6d,0x2d4400d8,0x645801f5,0x4528010b}},	//   rnić, _iões_, tzui, тжин_, 
   {{0x68f807a8,0x291c166a,0xdce54e6e,0xf8b4009d}},	//   _icud, _iaua_, snić, _төх_, 
   {{0xe7853a70,0x02045e3e,0x291d4e6f,0x64580196}},	//   _субо, азон, _haua_, rzui, 
   {{0x291d4e70,0x46141c93,0xb68432db,0x5ed40154}},	//   _kaua_, _خوار, _پھول_, _তালে, 
   {{0x291c0407,0xa1c001ec,0x81600133,0x00000000}},	//   _jaua_, _құмд, تۆبۆ, --, 
   {{0x291d4e71,0x6d90ec86,0x61440ae5,0x54c401af}},	//   _maua_, rçal, لىگە, _уңын_, 
   {{0x291d4e72,0x2d880316,0x25ac00f3,0x63b800f1}},	//   _laua_, _akce_, _higl_, mqun, 
   {{0x6d914e73,0x63b8198f,0x88bc00b8,0x68f802d0}},	//   pçal, lqun, _gaśg, _ocud, 
   {{0x291d4e74,0x58f80327,0xfa340330,0x00000000}},	//   _naua_, ྔུབས_, یراد, --, 
   {{0x63b94e75,0x3af49392,0x0d980006,0x00000000}},	// [21b00] nqun, ияжс, утры_, --, 
   {{0x68f94e76,0x212084d6,0xd1f80023,0x7e7400db}},	//   _acud, _haih_, _ገረብ_, _ناجئ, 
   {{0x291c04cc,0xab58008e,0x63b801a9,0x00000000}},	//   _baua_, _itül, hqun, --, 
   {{0x6d40084c,0x68f801ab,0x291c0393,0x6fb000f1}},	//   _înap, _ccud, _caua_, _دمیا, 
   {{0x21209280,0x63b80784,0xa8154e77,0x00000000}},	//   _maih_, jqun, لتور_, --, 
   {{0x21200270,0x7bc4023a,0x59280327,0x69c00118}},	//   _laih_, _itku, _རོམས_, ínec, 
   {{0x291c4894,0x25ac00f3,0x65c00e92,0xbd980092}},	//   _faua_, _bigl_, обја, _ሁኔታም_, 
   {{0x25ad4e78,0x291d4e79,0x69c00115,0x00000000}},	//   _cigl_, _gaua_, ŭnec, --, 
   {{0x25ac1675,0x63b81cdf,0x973c05a1,0xf8b40032}},	//   _digl_, gqun, _siću, _йөҙ_, 
   {{0x31680034,0x291c01f7,0xf09c067c,0xe76012e7}},	//   wicz_, _zaua_, zeàs_, _двуп, 
   {{0x21214e7a,0x25ac07de,0x291c00ec,0x63b80194}},	//   _baih_, _figl_, _yaua_, aqun, 
   {{0x7bc404b9,0x21200076,0x63b8208d,0x25e8012d}},	//   _otku, _caih_, bqun, _घटती_, 
   {{0xb4d05d4f,0x21200097,0xdfd80395,0x00000000}},	//   वरी_, _daih_, иър_, --, 
   {{0x6d9035f5,0xa2d00137,0x00000000,0x00000000}},	//   rçam, _ۇيۇت, --, --, 
   {{0x2120062c,0x7bc40fda,0x2b404b16,0x44240133}},	//   _faih_, _atku, _rojc_, _پرۆف, 
   {{0x21200076,0x5d780f30,0xaaa4c853,0x88bc0055}},	//   _gaih_, айся_, _कृषक, _kaśe, 
   {{0x291c0053,0xaac41fd6,0x7e7c0175,0x6284031c}},	// [21b10] _raua_, لتان, _expp, żjot, 
   {{0x291c1140,0x8ee40131,0xee8407e6,0x00000000}},	//   _saua_, _دېسە_, _вымо, --, 
   {{0x99d49b83,0x291d4e7b,0xfee802dd,0xf3fc0154}},	//   قتنا, _paua_, _суық_, ্টির_, 
   {{0xaca001f2,0x63b80309,0xb058008e,0x00000000}},	//   _anụb, yqun, bbät, --, 
   {{0xd5b81140,0x27fc06af,0x9be40212,0x00000000}},	//   _auā_, _qqun_, _мірк, --, 
   {{0x6138044e,0xf3fc00bd,0x291d4e7c,0x25ac0c86}},	//   _ብዛዕባ, ্টার_, _waua_, _sigl_, 
   {{0x291d4e7d,0x25ac1570,0x84e401d5,0x00000000}},	//   _taua_, _pigl_, бойж, --, 
   {{0x291c0053,0x69c54e7e,0xe3bc1709,0x5e780375}},	//   _uaua_, _itje, íño_, יתון_, 
   {{0x21214e7f,0x69c41f7f,0x25ac07de,0xb3c400c7}},	//   _raih_, _htje, _vigl_, блыз_, 
   {{0x212000ad,0x88bc00b8,0x63b803f0,0x65a80150}},	//   _saih_, _daśe, rqun, _ﺷﯟﯨﻠ, 
   {{0x25ac07de,0x63b93a3e,0x41a801d5,0x6d900200}},	//   _tigl_, squn, лвон_, rçaj, 
   {{0xf6500bd4,0xab580793,0x04c80f84,0x25ac05d5}},	//   _מצב_, _stül, _صوتي_, _uigl_, 
   {{0x63b8c203,0x21200007,0x3a3800b5,0x5fb80073}},	//   qqun, _vaih_, zxpp_, _आढळल, 
   {{0x69c41711,0x398c148b,0xa0040014,0x2f2800c0}},	//   _otje, lýst_, ٕژھى, jėgė_, 
   {{0x6b6c0006,0x212000b8,0x412801af,0x00000000}},	//   _mėgė, _taih_, _бойо_, --, 
   {{0x04f400cc,0x00000000,0x00000000,0x00000000}},	//   _আসুৰ_, --, --, --, 
   {{0x69c54e80,0x7cf001a9,0xb27001af,0x00000000}},	// [21b20] _atje, _dаrа, _мләш, --, 
   {{0xb058049f,0x8b6424ae,0x398c0413,0x2ca40006}},	//   rbät, يالم, hýst_, скуп_, 
   {{0x3f894e81,0x72d8010f,0x00000000,0x00000000}},	//   mobu_, רקעג, --, --, 
   {{0x3f8807b4,0xb0594e82,0x69c000c6,0x7bc4007c}},	//   lobu_, mbär, ínea, _ttku, 
   {{0x7d140050,0x69c40209,0x60c54e83,0x7bc54a3d}},	//   meys, _etje, _mfim, _utku, 
   {{0x7d154e84,0x3f8804ce,0x61e001bf,0xdedc0023}},	//   leys, nobu_, _ovnl, _ንዓኣ_, 
   {{0x60c4215a,0xd5b8003a,0xb059493a,0x88bc00b8}},	//   _ofim, _quā_, nbär, _saśe, 
   {{0x7d154e85,0xb4d01b6e,0xb7d8009f,0x3f880254}},	//   neys, वरे_, _مورا_, hobu_, 
   {{0x68413718,0x61e0022e,0x795003e6,0xb058002f}},	//   _ента, _avnl, _وێڕا, hbär, 
   {{0x60c54e86,0x7d149fb9,0xd5b80618,0x3f8802f0}},	//   _afim, heys, _tuā_, jobu_, 
   {{0x7d1401d9,0x3f880122,0x00000000,0x00000000}},	//   keys, dobu_, --, --, 
   {{0x7864022e,0x7d14058a,0xb058007c,0x71340166}},	//   _jаvo, jeys, dbär, сҗит_, 
   {{0x7d154e87,0xab5801b8,0x3f880268,0x62000014}},	//   deys, _stüm, fobu_, _ہووٕ, 
   {{0x60c40085,0x88bc0882,0x3f88c32b,0x752005c7}},	//   _efim, _kaśc, gobu_, _haoz, 
   {{0x752007e4,0x2bd800e1,0x6d9000db,0x836401d5}},	//   _kaoz, मीना, lçai, _بدنل, 
   {{0x7d140050,0x75200109,0x7cf001a9,0x88bc012d}},	//   geys, _jaoz, _qаrа, _maśc, 
   {{0x6d914e88,0x69c40627,0x6ff0025c,0xa2bcf5d8}},	// [21b30] nçai, _stje, _བཀྲུ_, लुक्, 
   {{0x75214e89,0x3f880ffb,0xb05801e3,0x00000000}},	//   _laoz, cobu_, sbäs, --, 
   {{0x7d1401d9,0xc8b40209,0x60c40175,0x7cf001a9}},	//   beys, ослы, _yfim, _tаrа, 
   {{0x99d54e8a,0x752001a2,0x7d140014,0xddcc0bf1}},	//   ستما, _naoz, ceys, _ñišp, 
   {{0x2618069f,0x48241e87,0x786401a9,0x1b0000fe}},	//   _मनही_, تىشق, _dаvo, ৈয়ে_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69c41f7f,0x67200b91,0xb6a14e8b,0xd5e89f9c}},	//   _utje, rdnj, мишл, معين_, 
   {{0x19590bea,0x6ec83abc,0x00000000,0x00000000}},	//   _ласы_, _त्सु, --, --, 
   {{0x75200109,0xdce40115,0x398c03b2,0x6d900200}},	//   _daoz, jniĝ, rýst_, rçah, 
   {{0xd6d80120,0x7864022e,0x7d142a87,0xd5b800ef}},	//   _гтц_, _zаvo, zeys, _prāt_, 
   {{0x7d1401d9,0xc41801d3,0xc7b801d3,0x00000000}},	//   yeys, _چغتا_, _erőt_, --, 
   {{0x75200dd4,0x7d1401d9,0x1648104b,0x3f880117}},	//   _gaoz, xeys, _учуп_, wobu_, 
   {{0x65694e8c,0x3f8819a2,0x7d154e8d,0xdce40115}},	//   _imgh, tobu_, veys, gniĝ, 
   {{0x83fc00dd,0x7d140014,0x752001e4,0x55541c3e}},	//   rződ, weys, _zaoz, _وپەر, 
   {{0x73301b16,0x3f894e8e,0x7d154e8f,0xfce4004e}},	//   _زىيا, robu_, teys, жобо, 
   {{0xed540323,0x60c404cc,0xb0580267,0x3f894e90}},	//   оос_, _ufim, rbär, sobu_, 
   {{0x7d154e91,0xed540261,0xb0583b52,0x6cb001c6}},	// [21b40] reys, цот_, sbär, дөрт, 
   {{0x7d140014,0x786401a9,0xb058007c,0x00000000}},	//   seys, _dаvl, pbär, --, 
   {{0x3ea40601,0x2bd800bc,0xbea401f4,0x00000000}},	//   _финг, मीबा, _фанк, --, 
   {{0x7d1401d9,0x25ec0490,0x00000000,0x00000000}},	//   qeys, ींनी_, --, --, 
   {{0x752003d1,0x88bc0055,0x3178010f,0x00000000}},	//   _raoz, _saśc, סאנד, --, 
   {{0xe3a54e92,0x752003bd,0x88bc0882,0xeb943f07}},	//   _زر_, _saoz, _paśc, _мия_, 
   {{0x7520dacc,0xe28401d5,0x75780023,0x00000000}},	//   _paoz, _آذ_, _ይህልዎ_, --, 
   {{0xb4b004a9,0x7018000d,0x00000000,0x00000000}},	//   мийә, _पईलख_, --, --, 
   {{0xdedc0023,0x00000000,0x00000000,0x00000000}},	//   _ንዓኺ_, --, --, --, 
   {{0xd764ff22,0xc7b801ed,0x6d9006af,0xf20401f0}},	//   _عنای, _erős_, rçai, оямо, 
   {{0xab5801b8,0x752006d9,0x88bc0055,0xf1b80208}},	//   _stük, _taoz, _haśa, _quơ_, 
   {{0x9cfc015b,0x88bc00b8,0x3168009d,0xb46c01af}},	//   ঁজুন_, _kaśa, ршоо_, _икеh, 
   {{0xceb94e93,0x80f00022,0x00000000,0x00000000}},	//   йән_, хҿых, --, --, 
   {{0x6d914e94,0xdedc02d3,0xdce4008f,0x88bc002b}},	//   nçav, _ንዓኻ_, rniĝ, _maśa, 
   {{0xd2509d9a,0x5f940022,0x00000000,0x00000000}},	//   _سنة_, фирт, --, --, 
   {{0x6ec807af,0x7f90003a,0x2d8c0b21,0xd130007b}},	//   _त्रु, dæqu, ôge_, _أمة_, 
   {{0xc8780598,0x06e402f5,0x88bc00b8,0x2cac007c}},	// [21b50] _keşe_, প্টি, _naśa, ägd_, 
   {{0x4428010f,0x5b154e95,0x2618000d,0x00000000}},	//   _ɩa_, ммут, _मनली_, --, 
   {{0xae000131,0xc87803e0,0x00000000,0x00000000}},	//   _تۈزى, _meşe_, --, --, 
   {{0xc8794965,0xe8700a7b,0xefb80092,0x00000000}},	//   _leşe_, وناگ, ዳጊው_, --, 
   {{0x88bc002b,0x3d380375,0x58b80133,0x97c4009a}},	//   _caśa, _הגרס, زانج_, وتوم, 
   {{0x88bc0882,0xc8780afb,0x848802d3,0x70b4c853}},	//   _daśa, _neşe_, _ምስማዕ_, ःशुल, 
   {{0xdb20110e,0x00000000,0x00000000,0x00000000}},	//   _àwár, --, --, --, 
   {{0x04440022,0xab580e78,0x786401a9,0x6d9000d8}},	//   зеин, _stüh, _mаvj, açav, 
   {{0x25d808f2,0x443800d8,0xc8780205,0x00000000}},	//   _गौरी_, ãs_, _beşe_, --, 
   {{0xdce405d1,0x83380131,0x00000000,0x00000000}},	//   kniğ, счит_, --, --, 
   {{0x44b4010b,0xe67400f1,0x823400f2,0xf55401b9}},	//   _ебес, _بلاګ_, سردا, زلیب_, 
   {{0x88bc00dc,0x00000000,0x00000000,0x00000000}},	//   _yaśa, --, --, --, 
   {{0x44280a62,0x6d901e54,0x75980a1e,0x6d5c0009}},	//   _éa_, nçau, _פינח, dhqa, 
   {{0x8c2003d4,0xab580166,0x6578666d,0x00000000}},	//   নমান_, _itüw, lnuh, --, 
   {{0x61440131,0xcdc401ec,0x7b980014,0xfbd000e5}},	//   _يىتە, дасқ, ۅپرس_, ڑتا_, 
   {{0x65794e96,0x6d5c016d,0x6b500139,0x3cf4033f}},	//   nnuh, ghqa, _lıgı, इलें_, 
   {{0x65794e97,0x69c000df,0x00000000,0x00000000}},	// [21b60] inuh, ŭnel, --, --, 
   {{0x6b5000fd,0x0c780006,0x88bc00b8,0x00000000}},	//   _nıgı, істы_, _raśa, --, 
   {{0x4cac00cc,0x88bc00cd,0x00000000,0x00000000}},	//   টুলু, _saśa, --, --, 
   {{0xf9914e98,0xeb9c0158,0x6d5cbfbe,0x88bc00cd}},	//   ربا_, _spøt_, chqa, _paśa, 
   {{0x1818a9dc,0x63a003ac,0x28c82a27,0x65794e99}},	//   تراک_, _ohnn, ाड़ि, dnuh, 
   {{0xbb480491,0x7c200393,0x63a00051,0x88bc00dc}},	//   _الآن_, æoru, _nhnn, _vaśa, 
   {{0xfaa4039b,0x6d9017cd,0x4a740137,0x6b500205}},	//   _хаво, rçav, _жытт, _dıgı, 
   {{0xc8780139,0xb28400c7,0x00000000,0x00000000}},	//   _seşe_, ҷымк, --, --, 
   {{0xc87803e0,0x31b80171,0x00000000,0x00000000}},	//   _peşe_, _mūze_, --, --, 
   {{0xe3ac04d3,0x63a000a3,0x65780009,0xc8780139}},	//   ێری_, _chnn, anuh, _qeşe_, 
   {{0x6578058a,0xc8780139,0xb6580108,0x00000000}},	//   bnuh, _veşe_, _ушах_, --, 
   {{0x6d905c17,0x65780067,0x3cf4033f,0xa638011a}},	//   nçat, cnuh, इलों_, _לגבר, 
   {{0x62800407,0x64a14e9a,0xa2bc095f,0xc87820b2}},	//   _exno, _заца, लुङ्, _teşe_, 
   {{0xd3700502,0x61f00598,0x2324023a,0x05b801ec}},	//   _جهت_, çelä, _ночи_, _ادەت_, 
   {{0x9e35368c,0x6398123b,0x00000000,0x00000000}},	//   нерч, _הסגנ, --, --, 
   {{0x2004004e,0xdce40205,0x00000000,0x00000000}},	//   àmic_, rniğ, --, --, 
   {{0x88bc012d,0x81b400cc,0xde280023,0x00000000}},	// [21b70] _baśn, _চৌক_, _ትውክል, --, 
   {{0x6d5d4e9b,0xfe6c03e6,0x15180011,0x5fdc00d9}},	//   shqa, اگی_, থায়ী_, _החזק, 
   {{0x65780050,0x3cd40150,0x49d8003b,0x00000000}},	//   ynuh, _ﺘﻘﺩﻤ, іддю_, --, 
   {{0x1a6875ab,0x246c0b23,0x6b50c8d8,0x00000000}},	//   سیقی_, lēmū_, _sıgı, --, 
   {{0x7b00023a,0x657803b2,0x57e80150,0x00000000}},	//   äytö, vnuh, здім_, --, 
   {{0x2ee001f7,0x88bc012d,0x00000000,0x00000000}},	//   najf_, _gaśn, --, --, 
   {{0xa3dc0a8a,0x271c00cc,0x00000000,0x00000000}},	//   धीन_, পালো_, --, --, 
   {{0x76a000d2,0x19947df2,0x63a001ab,0x657800b0}},	//   _síyí, _зася, _shnn, unuh, 
   {{0x65794e9c,0xf59000c6,0x6b600241,0x6d903535}},	//   rnuh, خليج, _gígù, lças, 
   {{0xc1e8009d,0x00000000,0x00000000,0x00000000}},	//   одож_, --, --, --, 
   {{0x6d914e9d,0x995c0306,0x00000000,0x00000000}},	//   nças, líš_, --, --, 
   {{0x348c0521,0x48200092,0x427400db,0x00000000}},	//   ịdị_, _ተልዕኮ, згүс, --, 
   {{0x995c13d5,0x6d900205,0x00000000,0x00000000}},	//   níš_, hças, --, --, 
   {{0x442c0bd5,0x8f800046,0x26c40427,0x6d9000fd}},	//   mve_, лқыл, ncno_, kças, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6da14e9e,0xada122d4,0x00000000,0x00000000}},	//   виса, васл, --, --, 
   {{0xfca94e9f,0x442d4ea0,0x995c0306,0x7b480276}},	// [21b80] زارو_, nve_, jíš_, опаг_, 
   {{0x442d4ea1,0xeb9c964d,0xa3dc0f4c,0x995c0122}},	//   ive_, _spør_, धीय_, díš_, 
   {{0x442d4ea2,0x00000000,0x00000000,0x00000000}},	//   hve_, --, --, --, 
   {{0x442c05ce,0x98a02a57,0xfbc435dd,0x88bc1b6e}},	//   kve_, žič_, _обмо, _daśo, 
   {{0x442c044e,0xe94401b9,0x6d9056eb,0x00000000}},	//   jve_, برلی, rçat, --, 
   {{0x75c8045f,0x442d4ea3,0xab5807c5,0x26c4009a}},	//   _lęze, dve_, _stüv, gcno_, 
   {{0xe1e400f8,0x442d4ea4,0x3f480943,0xb5a401c0}},	//   _جس_, eve_, ṱuwo_, мрий, 
   {{0x6d90004e,0x995c13d5,0x00000000,0x00000000}},	//   lçar, bíš_, --, --, 
   {{0x442d4ea5,0x88bc012d,0xa8000395,0x995c01ef}},	//   gve_, _maśl, _изтл, cíš_, 
   {{0x6d9059f9,0x786401a9,0x88bc00cd,0x1868022e}},	//   nçar, _nаvi, _yaśo, _дағи_, 
   {{0x442d4ea6,0x66e0f426,0xe3ad4ea7,0x386401a9}},	//   ave_, _роха, جري_, lzor_, 
   {{0x442d4ea8,0x9f4056eb,0x39454ea9,0xf8dc5b82}},	//   bve_, _avià_, njos_, मरिय, 
   {{0x39440120,0xb59400c7,0xaf354eaa,0xe4a00454}},	//   ijos_, _еиҧш, ورست, _иршо, 
   {{0x69c001d3,0x3864022e,0x00000000,0x00000000}},	//   ínek, izor_, --, --, 
   {{0xaee00055,0x00000000,0x00000000,0x00000000}},	//   _neṅg, --, --, --, 
   {{0xf1a803e6,0x386401a9,0xa18803f6,0x00000000}},	//   _باته_, kzor_, _обја_, --, 
   {{0xdd94df3d,0x38640427,0xc878013d,0x3944031c}},	// [21b90] таты, jzor_, _oeşa_, djos_, 
   {{0x386523fa,0x995c02fb,0x88bc002b,0x00000000}},	//   dzor_, víš_, _paśo, --, 
   {{0x442d4eab,0x2bdc44d0,0x5f745a16,0xaee00055}},	//   zve_, _पौरा, _جاير, _ceṅg, 
   {{0x442d4eac,0x9cb42dfc,0x6d914ead,0x995c02fb}},	//   yve_, رمەت, rças, tíš_, 
   {{0x7c5801c8,0x00000000,0x00000000,0x00000000}},	//   _فلٽر_, --, --, --, 
   {{0x442d4eae,0x2d982a71,0x995c00d0,0x98c401e0}},	//   vve_, llqe_, ríš_, нсәл, 
   {{0x995c03c6,0x442c1529,0x68440055,0x00000000}},	//   síš_, wve_, _sūdā, --, 
   {{0x442d4eaf,0x995c0122,0x38640334,0x88bc002b}},	//   tve_, píš_, bzor_, _kaśm, 
   {{0x442d1265,0x76b49816,0xe8c80073,0x386406d8}},	//   uve_, мләр_, ाडीच, czor_, 
   {{0x442d4eb0,0xc244657c,0x64a074f0,0x82680120}},	//   rve_, енок, нақа, заов_, 
   {{0x442d4eb1,0x7864022e,0x6d0c07b7,0xf2e41bf4}},	//   sve_, _rаvi, ाभाग_, رکوه_, 
   {{0x9f40b269,0x290c01a9,0x4094190b,0x442c00e5}},	//   _svià_, nfga_, ергт, pve_, 
   {{0x9f401497,0x442d4eb2,0x940400ae,0x00000000}},	//   _aviá_, qve_, _لونه, --, 
   {{0x75c94eb3,0xdcec00d7,0x00000000,0x00000000}},	//   _węze, íhľo, --, --, 
   {{0x38654eb4,0xf1c40aff,0x4278010f,0xcc0801e2}},	//   zzor_, _रूपन, _מאַג, ېزمن_, 
   {{0xab5803b9,0x00000000,0x00000000,0x00000000}},	//   _otüs, --, --, --, 
   {{0x2bd80316,0x502401ec,0x317800df,0x00000000}},	// [21ba0] मीला, _азығ, _מאקד, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfce4ccfb,0x6d914eb5,0x4ae07039,0x394400cf}},	//   _поно, rçar, _फ़रव, tjos_, 
   {{0xab586047,0x6a802d31,0x70742c26,0x3864005a}},	//   _stüt, ылха, _آمیز_, tzor_, 
   {{0x7d04127b,0x39440024,0x31b86e98,0x00000000}},	//   _icks, rjos_, _mūza_, --, 
   {{0xa5080135,0x96f94eb6,0x38640200,0x00000000}},	//   _གཡུག_, фект_, rzor_, --, 
   {{0x386401d3,0x4a9400d8,0x88bc0210,0x00000000}},	//   szor_, _ајту, _zaśm, --, 
   {{0x65a4009d,0xf5080137,0x00000000,0x00000000}},	//   нтыг_, سزبى_, --, --, 
   {{0x6ae000fe,0x2db4010f,0x00000000,0x00000000}},	//   _পাতো, עלפן_, --, --, 
   {{0x66e001f0,0x00000000,0x00000000,0x00000000}},	//   _бофа, --, --, --, 
   {{0x7d054eb7,0xd0d400a7,0x6fa54eb8,0x35a40108}},	//   _ocks, конъ, _गठबं, _зажг, 
   {{0x7c243242,0xf48407d5,0xe80c0306,0xc1b000d1}},	//   _oskr, _пулн, lášť, _ﭼﯩﺮﺍ, 
   {{0xc5680592,0x00000000,0x00000000,0x00000000}},	//   _تحلل_, --, --, --, 
   {{0x7d04127b,0xe2800131,0x88bc00dc,0x00000000}},	//   _acks, _өлчи, _raśm, --, 
   {{0x59b07c33,0x7c254eb9,0x8cc800e5,0x00000000}},	//   जगार, _askr, ِورق_, --, 
   {{0xdd94916f,0xe29805d0,0xdd9814b3,0xe1ec0472}},	//   гасы, _משור, ешу_, _اسو_, 
   {{0x290c022e,0x00000000,0x00000000,0x00000000}},	// [21bb0] vfga_, --, --, --, 
   {{0x7d054eba,0x200c054e,0x00000000,0x00000000}},	//   _ecks, ădit_, --, --, 
   {{0x7c254ebb,0xab5804cc,0xe73c0051,0x00000000}},	//   _eskr, _stüs, _đõ_, --, 
   {{0x88bc033f,0xc4cc03d4,0x00000000,0x00000000}},	//   _taśm, _ৰঞ্জ, --, --, 
   {{0x6d4d4ebc,0x86c400ec,0x00000000,0x00000000}},	//   _ioca, نيشن, --, --, 
   {{0x6d4c0365,0x88bc0210,0x91fc00ef,0x00000000}},	//   _hoca, _kaśk, ezām, --, 
   {{0x6d4d4ebd,0x9a854ebe,0x88bc0210,0x00000000}},	//   _koca, _бутл, _jaśk, --, 
   {{0x6d4c13fd,0xdb0801d3,0xc8e8009f,0x00000000}},	//   _joca, ülöt, _آڙاه_, --, 
   {{0xc8940214,0xc3240154,0x42d402d5,0x00000000}},	//   _شارژ, বাসি_, кіну, --, 
   {{0xe7314ebf,0x98740006,0x0a580092,0xfca800df}},	//   _حصر_, _слуц, _ለሩስያ, ויפּ, 
   {{0x36240050,0x80dc0073,0x6d4c02d0,0x00000000}},	//   _لولہ, परले, _ooca, --, 
   {{0xb9dc2295,0x00000000,0x00000000,0x00000000}},	//   _ብዙ_, --, --, --, 
   {{0xd72400fe,0x00000000,0x00000000,0x00000000}},	//   পাৰা_, --, --, --, 
   {{0x3ebc6536,0x6d4c035a,0x00000000,0x00000000}},	//   øtt_, _aoca, --, --, 
   {{0x6d4d4ec0,0xfce40126,0xd72c0023,0x00000000}},	//   _boca, ково, _ተኽእሎ, --, 
   {{0x2bc089b2,0x6d4c24b6,0x41741c3e,0xee3402e8}},	//   _वंशा, _coca, _جاتس, ънс_, 
   {{0x6d4c1261,0x6d900200,0xbb8400d1,0x00000000}},	// [21bc0] _doca, rçap, پلاي, --, 
   {{0x6b614ec1,0xab5803fa,0xab6004a9,0x6d4c38a6}},	//   акуа, _stür, авул, _eoca, 
   {{0x6d4d4ec2,0xeb94026a,0x7c240210,0x00000000}},	//   _foca, њих_, _wskr, --, 
   {{0x6d4d4ec3,0x7d040857,0x29080205,0x3234010f}},	//   _goca, _ucks, _öcal_, כטען_, 
   {{0xf7440a16,0x7c24098d,0x6e9039b1,0xab5804cc}},	//   кедо, _uskr, _ملیا, _vtür, 
   {{0x6d4d4ec4,0xfaa400c7,0xe73450c0,0x9f4c0139}},	//   _zoca, _ааго, кеч_, _üläm_, 
   {{0xc76431f0,0xaa40074d,0xe9d80014,0xe734399f}},	//   دانى, _керл, _ٲدِچ_, теј_, 
   {{0x59b40eff,0x6d4d4ec5,0xa5040063,0x00000000}},	//   _сөзс, _xoca, већа_, --, 
   {{0x7bd4089c,0x1418007b,0xb3640395,0x7980e729}},	//   npyu, ريدة_, вънк, mnow, 
   {{0xab5801b8,0x7980012d,0xa2600208,0xe7a4014b}},	//   _luün, lnow, _trố, _авул_, 
   {{0x7980012d,0x03b401ec,0xc0c81ef7,0x00000000}},	//   onow, ықшы_, _ጠላም_, --, 
   {{0x79814ec6,0xaaa40ebb,0x42a400fb,0x2ed800cd}},	//   nnow, केटक, ыуығ, भर्त, 
   {{0x250801ed,0x90940023,0x88bc0055,0x79800210}},	//   _آرمی_, _ግዚያዊ_, _saśk, inow, 
   {{0x64a0f07c,0x88bc0055,0x798002d0,0x61e801bf}},	//   _тача, _paśk, hnow, ællæ, 
   {{0xd37807f5,0x79814ec7,0xb1a400d1,0x43840354}},	//   mić_, know, _ишик, _сăрт, 
   {{0x7980068f,0xc0c00116,0x9d194ec8,0x6d4c00ac}},	//   jnow, _гәри, кост_, _qoca, 
   {{0x6d4c6e16,0xd0103dca,0xc8780205,0x9cc801ec}},	// [21bd0] _voca, _الخ_, _reşo_, тыса_, 
   {{0x6d4c0472,0x79812abb,0xf0e0033f,0x00000000}},	//   _woca, enow, _ख़ुद_, --, 
   {{0xf8dc00dc,0xdce4010f,0x00000000,0x00000000}},	//   मरूप, liiĝ, --, --, 
   {{0xd3782ce2,0x6d4c1730,0x79800034,0x9608015b}},	//   hić_, _uoca, gnow, লবাম_, 
   {{0xd3781326,0xd8b80a8e,0xdce40115,0x9be412fa}},	//   kić_, ندها_, niiĝ, _віск, 
   {{0xd3780bb8,0xdedc044e,0x79814ec9,0xa9200154}},	//   jić_, _ንዓና_, anow, ফাইড_, 
   {{0xd3780bb8,0xb0e065c5,0xd5e800c6,0x79800210}},	//   dić_, पराग, نعين_, bnow, 
   {{0xc3d802bf,0x823400d1,0x00000000,0x00000000}},	//   ньої_, ۇرجا, --, --, 
   {{0x83fc01d3,0x8cd400bc,0x0354013d,0x00000000}},	//   pzőm, युयो, лүдә_, --, 
   {{0xd3782ce2,0x88bc0055,0x823400ae,0x00000000}},	//   gić_, _naśi, هرجا, --, 
   {{0xdb1c019f,0x236c02d3,0x28ac07f7,0x04d80798}},	//   _birê, _ብገዛእ_, जेरि, _змеј_, 
   {{0x7410034c,0x8cd40b4c,0x00000000,0x00000000}},	//   جویا, युमो, --, --, 
   {{0xd3787308,0xa3dc6a04,0x15b00150,0x6cc40150}},	//   bić_, धीश_, _بەيس, _ﯨﺴﺘﻴ, 
   {{0xd378068f,0x72a00131,0x60940023,0xc8780166}},	//   cić_, _گەپن, _መንግስ_, _reşl_, 
   {{0x98a4b872,0x38b8e090,0xa3dc17cb,0x79814eca}},	//   _mamā_, _kürü_, धीर_, ynow, 
   {{0xab5804cc,0x3fc4136e,0x98a400ef,0x72a000d1}},	//   _stüp, _مگسی_, _lamā_, _دەپن, 
   {{0x6da14ecb,0xada03298,0x95f00490,0xdce4010f}},	// [21be0] сита, сатл, _घट्ट_, ciiĝ, 
   {{0x7bd40194,0x98a4005f,0x7980033f,0x5e648818}},	//   rpyu, _namā_, wnow, _ەنگە, 
   {{0x79800354,0xdb1c0200,0x44e800cc,0x00000000}},	//   tnow, _hirë, _গানক_, --, 
   {{0xd3794ecc,0x786800dd,0xa9654ecd,0x79800099}},	//   zić_, _növé, лиха_, unow, 
   {{0x79814ece,0x6fb0179e,0x28ac3d1d,0xf6c8013d}},	//   rnow, _خمیا, जेलि, ныйк_, 
   {{0xdb1c044e,0x7bc54ecf,0xfee0015b,0x79814ed0}},	//   _mirë, _iuku, _বাঁধ, snow, 
   {{0xd3780bb8,0x6b614ed1,0xb9082f8b,0xe60c52c8}},	//   vić_, _укра, _মা_, كشي_, 
   {{0x1db405ba,0x13f41914,0xd378068f,0x786401a9}},	//   ंगित, азия, wić_, _dаvr, 
   {{0xd37804b9,0x7bc54ed2,0xa3dc0574,0x3f9802e3}},	//   tić_, _juku, धील_, _okpu_, 
   {{0x52154ed3,0x06b8015b,0x00000000,0x00000000}},	//   адот, ঁড়ি, --, --, 
   {{0xd37804b9,0x7bc54ed4,0xc7640075,0xb6a40276}},	//   rić_, _luku, _ئاقى, _сижл, 
   {{0xf1a94ed5,0xdb1ce64a,0xd5b800cd,0x7bc48586}},	//   عاده_, _birë, _asāv_, _ouku, 
   {{0xd3792a51,0x15f40073,0x98a4002b,0x00000000}},	//   pić_, ींवर_, _yamā_, --, 
   {{0x6fa400aa,0xdce400df,0x00000000,0x00000000}},	//   انسې_, riiĝ, --, --, 
   {{0x7bc54ed6,0x795800b0,0x6ae003d4,0xdce401e4}},	//   _auku, _tïwh, _পালো, siiĝ, 
   {{0x7bc54ed7,0x86780023,0x61f0009f,0x00000000}},	//   _buku, _እንብሎ_, _اسوء, --, 
   {{0x7bc46865,0x00000000,0x00000000,0x00000000}},	// [21bf0] _cuku, --, --, --, 
   {{0x7bc54ed8,0x332c025c,0x88bc033f,0xb4c0024a}},	//   _duku, _jafx_, _zaśw, ्डु_, 
   {{0xdb1c068c,0x7bc405c7,0x4f840014,0xd7f80131}},	//   _mirè, _euku, _ماگہ, ғуч_, 
   {{0x7bc4105c,0xdc340232,0x24780b82,0xa3a800ab}},	//   _fuku, _zúča, _እድሪስ_, _कीन_, 
   {{0xac0800c6,0x7bc45b9c,0x3b08004e,0x83fc00e5}},	//   _яѕне_, _guku, _fcbq_, rzők, 
   {{0x6b480086,0x6f040007,0xf7d008b0,0x38b8083c}},	//   _dögû, ngjc, ﻟﻪﻣﺪ, _sürü_, 
   {{0x7bc54ed9,0x170801ed,0xb4c01428,0x88bc00b8}},	//   _zuku, اہمی_, ्डू_, _naśv, 
   {{0x7bc54eda,0x44154edb,0x6d5c00f1,0x6b94022e}},	//   _yuku, афот, nkqa, loxg, 
   {{0x7bc40a81,0x68e94edc,0x98a41140,0x69c401f7}},	//   _xuku, magd, _tamā_, _huje, 
   {{0x69c54edd,0x23a8005c,0x00000000,0x00000000}},	//   _kuje, køje_, --, --, 
   {{0x67214ede,0xdb1d3b7e,0x69c40789,0x38b805d1}},	//   menj, _dirè, _juje, _türü_, 
   {{0x69c4db55,0x67214edf,0xdc3401a2,0x68e94ee0}},	//   _muje, lenj, _súča, nagd, 
   {{0x66014ee1,0x69c54ee2,0x3f98020b,0x657800b0}},	//   lunk, _luje, _pkpu_, miuh, 
   {{0x67214ee3,0x68e8ad43,0x69c40022,0x8f740212}},	//   nenj, hagd, _ouje, бусі, 
   {{0x7bc54ee4,0x66014ee5,0x69c54ee6,0x68e8089c}},	//   _suku, nunk, _nuje, kagd, 
   {{0x7bc54ee7,0x67214ee8,0x65780069,0x00000000}},	//   _puku, henj, niuh, --, 
  
   {{0x6720193f,0x66014ee9,0x68e94eea,0x31541d57}},	// [21c00] kenj, hunk, dagd, _خليج_, 
   {{0x66014eeb,0x7bc54eec,0x69c54eed,0xdb1c020c}},	//   kunk, _vuku, _buje, _kiré, 
   {{0x3a251b45,0x6720341a,0x69c40b91,0x66014eee}},	//   рмег, denj, _cuje, junk, 
   {{0xd9114eef,0x69c40477,0x66014ef0,0x88bc00b8}},	//   ثیر_, _duje, dunk, _laśu, 
   {{0x7bc40280,0x69c54ef1,0xdb1c0098,0x67214ef2}},	//   _uuku, _euje, _liré, fenj, 
   {{0xfe88006a,0xebe00139,0x61e0127b,0xa7700a4a}},	//   _gbïä_, _форп, _ownl, оліч, 
   {{0x69c54ef3,0x66014ef4,0x60c40083,0xf6280212}},	//   _guje, gunk, _ogim, тіли_, 
   {{0x60c54ef5,0xdb1d4ef6,0xb4c0687b,0x00000000}},	//   _ngim, _sirè, ्डे_, --, 
   {{0x69c401fa,0x61e03cf7,0xa68000fd,0xdb1d4ef7}},	//   _zuje, _awnl, йләд, _pirè, 
   {{0x66011633,0x67200bb8,0x60c54ef8,0x88bc002b}},	//   bunk, cenj, _agim, _paśv, 
   {{0x64580d04,0x92941f85,0xdb1c0494,0x60c40175}},	//   ayui, санц, _virè, _bgim, 
   {{0xdb1c032b,0x98a40311,0x645801f5,0x60c400ef}},	//   _diré, _gamă_, byui, _cgim, 
   {{0xb90c0248,0xb4c05345,0xc4c4868d,0x60f84f35}},	//   _bajẹ_, ंशी_, _اتمو, шняя_, 
   {{0x60c54ef9,0xdb1c011f,0x9f98084c,0x7c340153}},	//   _egim, _firé, ивяу_, dvyr, 
   {{0xdef80953,0x7d14002d,0x68e80098,0xc8780139}},	//   шыя_, ffys, yagd, _peşk_, 
   {{0x672005a1,0x69c54efa,0x23a800b5,0x6f040175}},	//   zenj, _ruje, røje_, sgjc, 
   {{0x69c41e4f,0x67214efb,0x66014efc,0x2ac4026a}},	// [21c10] _suje, yenj, zunk, аљев, 
   {{0x66014efd,0x4f840014,0x69c4004e,0xb4c060d3}},	//   yunk, _دابہ, _puje, ंशु_, 
   {{0x67214efe,0x68e94eff,0x7d14010a,0xc87875c0}},	//   venj, tagd, bfys, _ieşi_, 
   {{0x69c401a6,0x67214f00,0xb4c0d295,0x19c401ec}},	//   _vuje, wenj, ्डो_, ібім, 
   {{0x68e88b14,0x67200219,0xd7c800aa,0x682400c9}},	//   ragd, tenj, لونه_, рьез, 
   {{0x69c54f01,0x68e8c95a,0xb8fc00cd,0x00000000}},	//   _tuje, sagd, _द्_, --, 
   {{0x672008ad,0x68e8e9a6,0x65794f02,0x00000000}},	//   renj, pagd, tiuh, --, 
   {{0x66014f03,0x45294f04,0xdb1c00c7,0x199402d5}},	//   runk, ужин_, _riré, _дася, 
   {{0x67214f05,0x44394f06,0x65794f07,0xdb1c0306}},	//   penj, ís_, riuh, _siré, 
   {{0x60c47312,0x67200107,0xb4e40034,0xdb1c00c7}},	//   _sgim, qenj, _बड़ी_, _piré, 
   {{0x65794f08,0xb060023a,0x66000309,0x06640022}},	//   piuh, ääns, qunk, _ухаҭ, 
   {{0xdb1c06af,0xd05c0213,0x73300131,0x823400cf}},	//   _viré, lasə, قىۋا, _ۇربا, 
   {{0xdb1c003e,0x61440131,0xc8780b97,0x00000000}},	//   _wiré, مىگە, _beşi_, --, 
   {{0x98a0071b,0xdb1c004a,0x7878008f,0xdce40010}},	//   žić_, _tiré, אָלו, rhič, 
   {{0xdb1c07a8,0xc878084c,0x6d9015b7,0xc0e40153}},	//   _birî, _deşi_, lçay, _лойк, 
   {{0x00e4ac40,0x00000000,0x00000000,0x00000000}},	//   _ужин, --, --, --, 
   {{0x7d1403cb,0x8db401ec,0x6d904dd9,0x00000000}},	// [21c20] rfys, іссі, nçay, --, 
   {{0x7d154f09,0x2b4000db,0x6b5800c7,0x6d480267}},	//   sfys, _cnjc_, _oîgu, ögar, 
   {{0x98a47502,0x6b880de2,0x00000000,0x00000000}},	//   _mamą_, égga, --, --, 
   {{0xb4e422e3,0xab240220,0x00000000,0x00000000}},	//   _बजे_, _қоса_, --, --, 
   {{0x3cf4000d,0xad34011a,0x00000000,0x00000000}},	//   ेलीं_, _הנכס_, --, --, 
   {{0x98a40024,0x39140133,0xb4c01788,0x00000000}},	//   _namą_, _گورز, ्ड्_, --, 
   {{0xd5b14f0a,0xf3880570,0x00000000,0x00000000}},	//   وفت_, nṣe_, --, --, 
   {{0xe730013f,0xdb1c00e4,0xa96404c2,0xb4c000cd}},	//   adε_, _kirï, _лиса_, ंशे_, 
   {{0x78645882,0x95c80032,0x080800e3,0xb4c0012c}},	//   _указ, ыуҙа_, _نزلي_, ्डौ_, 
   {{0xf3880882,0xd05c06be,0xda1c0037,0x00000000}},	//   kṣe_, casə, _नहात_, --, 
   {{0x6b9800c8,0x00000000,0x00000000,0x00000000}},	//   רשיד, --, --, --, 
   {{0xb0600108,0x91fc00ef,0x00000000,0x00000000}},	//   ääos, dzāt, --, --, 
   {{0xf8b81f13,0xe1ec0133,0xc8780205,0x99900055}},	//   ेशिय, وسێ_, _peşi_, _śaśo_, 
   {{0x955c001f,0x25ec0490,0xec6800fd,0x995c00bc}},	//   ታዎችን_, ींची_, ңрак_, jíž_, 
   {{0x8678044e,0x995c00bc,0x23483321,0x6d90025c}},	//   _እንተሎ_, díž_, _حسنی_, nħag, 
   {{0xa3dc0bae,0x15e402dd,0x00000000,0x00000000}},	//   धीक_, _ﺍﻹﻟﻬ, --, --, 
   {{0xd05c0cc1,0xd25001d9,0xcb540114,0x60c0022e}},	// [21c30] yasə, _رچھ_, оваћ, оmmu, 
   {{0x518400fb,0x00000000,0x00000000,0x00000000}},	//   _ыуҙа, --, --, --, 
   {{0x88bc0055,0x49740108,0x00000000,0x00000000}},	//   _naśr, олжс, --, --, 
   {{0xad24d653,0x9cc8010b,0xfa5401b9,0x00000000}},	//   _اردو, _гыра_, غرلگ, --, 
   {{0xe7a40075,0xb4e41d15,0x5c0401c0,0xa3a80037}},	//   مۇرى_, _बड़े_, _няра, _कीऽ_, 
   {{0x45d54f0b,0x2d98036e,0x8cd4276a,0x00000000}},	//   оцит, loqe_, युरो, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdeec001f,0x98a4033f,0xdb200cad,0x00000000}},	//   ጅትና_, _samą_, _àwòr, --, 
   {{0xe7080451,0x77780175,0xd7240154,0x00000000}},	//   _متان_, _fmtx, পাড়া_, --, 
   {{0x6d914f0c,0x2d98014b,0x6b580124,0xf8ac3321}},	//   lħad, hoqe_, _tîgu, _شکن_, 
   {{0x91fc00ef,0x00000000,0x00000000,0x00000000}},	//   dzās, --, --, --, 
   {{0x261003b7,0x8cd80bc0,0x25a800f2,0x6d90025c}},	//   mão_, _फ्लो, _صداي_, nħad, 
   {{0x261003b7,0xafe007d6,0x44294f0d,0x2d980200}},	//   lão_, моял, _èa_, doqe_, 
   {{0xfe454f0e,0x53345ba8,0xdb1c0ffb,0x443c0037}},	//   онго, _нечт, _cirì, _irw_, 
   {{0x443d4f0f,0x3ebd4f10,0x261006ed,0xbc64001f}},	//   _hrw_, ätt_, não_, ቸውንና_, 
   {{0x443c00b5,0x2d98014b,0x3cf400c5,0xaf540092}},	//   _krw_, goqe_, ेलें_, _ያገለገ, 
   {{0x261006ed,0x0d74010b,0x00000000,0x00000000}},	// [21c40] hão_, чыря, --, --, 
   {{0x443c09c2,0x26100165,0x69c800c5,0xdb500133}},	//   _mrw_, kão_, _तूही, رێز_, 
   {{0x261006ed,0xd05c016b,0x06840131,0x995c00d0}},	//   jão_, kasɛ, ﻪﺭﻧﯩ, ríž_, 
   {{0x261003b7,0x2d980a73,0x443c1418,0xc32402f5}},	//   dão_, coqe_, _orw_, বাটি_, 
   {{0x443d4f11,0xc8780166,0x88bc00cd,0x00000000}},	//   _nrw_, _oeşu_, _saśr, --, 
   {{0x29d4025c,0x26100120,0xf7d01884,0x00000000}},	//   _bħad_, fão_, ﻟﻪﻳﺪ, --, 
   {{0x26100261,0x35694f12,0x443d4f13,0xfa3400db}},	//   gão_, ирин_, _arw_, _بىزج, 
   {{0x54553e40,0x443c0606,0xa9200114,0xbee401f9}},	//   звит, _brw_, _одсл, करुन_, 
   {{0x443c0286,0xe9443629,0x00000000,0x00000000}},	//   _crw_, _ظرفی, --, --, 
   {{0x261006ed,0x75c8002d,0xab5805d5,0x443c0142}},	//   bão_, _lęzi, _stüz, _drw_, 
   {{0x26100261,0x29d4003d,0xddd00209,0x443c5fc7}},	//   cão_, _għad_, _ýeňi, _erw_, 
   {{0x443c01aa,0x00000000,0x00000000,0x00000000}},	//   _frw_, --, --, --, 
   {{0xdb1c007b,0x443c015d,0xbee40073,0xc3240154}},	//   _airí, _grw_, करून_, বাজি_, 
   {{0x53354f14,0x91fc0882,0x7ad80490,0x2324005b}},	//   _хект, tyād, _प्लॅ, _мочи_, 
   {{0xdb1c0077,0x9e354f15,0xb3d001af,0x00000000}},	//   _cirí, мерч, _эйһә, --, 
   {{0x3dd80472,0xdb1c09ff,0x91fc0882,0xc87800a2}},	//   _dtpw_, _dirí, ryād, _keşt_, 
   {{0x26100261,0x20040137,0xdb1c0008,0x00000000}},	// [21c50] zão_, àmit_, _eirí, --, 
   {{0x628808a4,0xdb1c01e1,0x92dc03d4,0x00000000}},	//   šloš, _firí, তৃৰ_, --, 
   {{0x261003b7,0xdb1c019f,0x6d900135,0x00000000}},	//   xão_, _birâ, tħad, --, 
   {{0x26100120,0x2d980117,0x00000000,0x00000000}},	//   vão_, qoqe_, --, --, 
   {{0x8ebc009e,0x00000000,0x00000000,0x00000000}},	//   _অভিগ, --, --, --, 
   {{0x26100a16,0x443c0175,0x97d800f2,0xad240066}},	//   tão_, _rrw_, زظهر_, _ارگو, 
   {{0xb6f43baf,0xf1c402ab,0x443c0175,0x98a40210}},	//   سىيا_, _रंगन, _srw_, _mamę_, 
   {{0x26100cfc,0x443c003a,0xc8c831f6,0x00000000}},	//   rão_, _prw_, _طوطن_, --, 
   {{0x26100cfc,0x68f94f16,0xd05c013f,0x74e401c6}},	//   são_, _idud, rasɛ, чдыг_, 
   {{0x26114f17,0x6d90038f,0x9a880014,0xa6440cbb}},	//   pão_, nħab, _انہٕ_, _وخان, 
   {{0x68f94f18,0x88bc012d,0x00000000,0x00000000}},	//   _kdud, _zaśp, --, --, 
   {{0xe0580acb,0xdb1c00e4,0x00000000,0x00000000}},	//   قیعت_, _rirí, --, --, 
   {{0x291d4f19,0x443cbf65,0x68f87f88,0x6568007b}},	//   _mbua_, _urw_, _mdud, _ilgh, 
   {{0xc0bc001f,0xdb1c01d3,0x108400c7,0x00000000}},	//   _ተኩል_, _pirí, ьҩык_, --, 
   {{0x442c2ffc,0x7330425b,0xf2d000c8,0x291c00ca}},	//   lwe_, _سىيا, _טעג_, _obua_, 
   {{0xdb1c4ac2,0x291c0134,0x68f94f1a,0xfe44016c}},	//   _virí, _nbua_, _ndud, онҳо, 
   {{0x442d4f1b,0xed554f1c,0x7ed410de,0xdb1c0055}},	// [21c60] nwe_, чот_, _ىزدا, _nirã, 
   {{0x442d4f1d,0x291c01f2,0x68f94f1e,0x6ab801e4}},	//   iwe_, _abua_, _adud, _ŝufa, 
   {{0x442d4f1f,0xdb1d4f20,0x3ea4014b,0x83fc00e5}},	//   hwe_, _pirâ, _хинг, nyőb, 
   {{0xd8841888,0x00000000,0x00000000,0x00000000}},	//   وهای, --, --, --, 
   {{0x442d4f21,0x6d380375,0x2d840134,0x68f94f22}},	//   jwe_, _התכנ, ɑne_, _ddud, 
   {{0x21203223,0x442c1813,0x68f80117,0xf3880882}},	//   _lbih_, dwe_, _edud, kṣa_, 
   {{0x442c0151,0x7578044e,0xc8780139,0x00000000}},	//   ewe_, _ክህልዎ_, _seşt_, --, 
   {{0x442d4f23,0xb06002f6,0xe9a06a09,0x786401a9}},	//   fwe_, ääks, _засп, _mаvz, 
   {{0x442d4f24,0x66000113,0x0a40001f,0xe3ac27dc}},	//   gwe_, arnk, _የሚሰራ, گري_, 
   {{0x27f4038e,0x79814f25,0x21214f26,0x656803cd}},	//   ření_, liow, _abih_, _elgh, 
   {{0xe3ac2266,0x442d4f27,0xdb1c1186,0xf49400e5}},	//   دري_, awe_, _mirà, _کشاد, 
   {{0x442d12f1,0x7980068f,0x7aed4f28,0x00000000}},	//   bwe_, niow, _lebt, --, 
   {{0x442d4f29,0xe3ac01d3,0x20540a93,0x30a54f2a}},	//   cwe_, ضری_, нтёр, яров, 
   {{0xd2502be7,0x798002b1,0x70a4001f,0x7aec00a2}},	//   _لنت_, hiow, _ማድረጉ_, _nebt, 
   {{0xd78801dc,0x21203ad4,0x9f400137,0x07045444}},	//   yển_, _fbih_, _avió_, _राघव_, 
   {{0x7aec01c4,0x00000000,0x00000000,0x00000000}},	//   _aebt, --, --, --, 
   {{0xdb1c01e1,0x79814f2b,0x2d840e04,0x6d90025c}},	// [21c70] _birà, diow, đne_, tħab, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb1c381a,0xd5b800b8,0x29d40135,0x7aec2517}},	//   _dirà, _apām_, _sħab_, _debt, 
   {{0xdb1c00d8,0x798001f5,0x9a8401c6,0x660002f0}},	//   _pirã, giow, хуул, vrnk, 
   {{0x442d4f2c,0xda700050,0xd7640133,0x00000000}},	//   xwe_, نُے_, کۆلی, --, 
   {{0xdb1d4f2d,0x442d4f2e,0x705c001f,0x25600139}},	//   _girà, vwe_, ህርታቸ, _iñli_, 
   {{0x442d4f2f,0xd6c40131,0x7980012d,0x7cfc0419}},	//   wwe_, нишқ, biow, bárč, 
   {{0x1a681f7b,0x7980068f,0x68f94f30,0xdb1c07de}},	//   _عینی_, ciow, _udud, _zirà, 
   {{0x442d4f31,0x2120b0e8,0xf1c41889,0x6e9c0406}},	//   uwe_, _rbih_, _रंजन, _खुसु, 
   {{0xdb1c00dd,0x258002e2,0x21200b94,0xf8b002e4}},	//   _kirá, _bèlè_, _sbih_, _ישן_, 
   {{0x656801ab,0x412801c0,0xdb1c0216,0x290c0009}},	//   _tlgh, ооно_, _jirá, ogga_, 
   {{0x442d4f32,0xdb1c09c2,0xe50402dd,0xb36c001f}},	//   pwe_, _mirá, _ءباي, _ብዙውን_, 
   {{0x442d32a0,0x290c0014,0xa4240408,0xcfd800eb}},	//   qwe_, igga_, _хьел, _তিউন, 
   {{0x9f4019f5,0xdb1c0789,0x7980012d,0x00000000}},	//   _aviò_, _oirá, ziow, --, 
   {{0x258001e1,0xddd40030,0x69d800b0,0x6d4000b0}},	//   _gèlè_, ňažn, _ōuen, ēnan, 
   {{0x7aed4f33,0xd2c8009d,0xaad80118,0x518400f3}},	//   _sebt, _зvгэ, मुसक, _пуња, 
   {{0x6da14f34,0x7aec0218,0xdb1c00cf,0xada14f35}},	// [21c80] тита, _pebt, _pirà, татл, 
   {{0x79814f36,0x290c01d9,0x2c080608,0x7e98121a}},	//   wiow, egga_, تعفی_, _ونظر_, 
   {{0x798003ac,0xb3400139,0x00000000,0x00000000}},	//   tiow, _äçer, --, --, 
   {{0xf8680952,0x7aed4f37,0xdb1c09c2,0xab58013d}},	//   يماي_, _webt, _dirá, _suüt, 
   {{0x2bac4c3d,0xdb1c004e,0x79814f38,0x7c94033a}},	//   _जीवा, _tirà, riow, _црнц, 
   {{0x6cb00b8d,0x63a0003e,0x290c058a,0x79810a5a}},	//   _рөст, _nknn, agga_, siow, 
   {{0xdb1c0005,0x79800034,0x59940451,0x00000000}},	//   _girá, piow, _ٻڌاء, --, 
   {{0x65a401c6,0xafd802ed,0xc4440014,0x00000000}},	//   мтыг_, lvøe, کیٖن_, --, 
   {{0xf8b00c2e,0xb8648c6b,0x246001e1,0x00000000}},	//   _जरिय, _غارو, _rémú_, --, 
   {{0xd370afbd,0xb2849c36,0xaee000b8,0xc0d40092}},	//   اهد_, дымк, _dhṛd, ራካሪ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7c2494f0,0xef240327,0xc87800a2,0x47e000cc}},	//   _opkr, _སིངྐ_, _keşp_, _নিতী, 
   {{0x75214f39,0xf1e0033f,0xaee00055,0x00000000}},	//   _iboz, कीज़_, _ghṛd, --, 
   {{0x69c001d3,0x92947abe,0x00000000,0x00000000}},	//   ínez, _палц, --, --, 
   {{0x290c450f,0x7c240fda,0xb1900352,0xed5c0419}},	//   ygga_, _apkr, _илкә, áľov_, 
   {{0x6ab801e4,0xd2500451,0x00000000,0x00000000}},	//   _ŝufo, _لنڪ_, --, --, 
   {{0x75214f3a,0x9f40030a,0xea9c00b8,0x00000000}},	// [21c90] _mboz, _eviñ_, bhṛd_, --, 
   {{0xfccc2295,0x09b800dc,0x6e28002e,0x290c0009}},	//   _እንጂ_, ेद्य, ёlbé, wgga_, 
   {{0x75214f3b,0xaea00150,0x00000000,0x00000000}},	//   _oboz, _شەري, --, --, 
   {{0xdb1c00dd,0x00000000,0x00000000,0x00000000}},	//   _virá, --, --, --, 
   {{0x9f4008a5,0x8b8400cf,0x290c01a9,0x0cc400f1}},	//   _kvið_, _كەرە_, rgga_, _سيسټ, 
   {{0x75214f3c,0xbc34010b,0x00000000,0x00000000}},	//   _aboz, _яҗуч_, --, --, 
   {{0xb6a007d6,0xfccc0092,0x00000000,0x00000000}},	//   лишл, _እንጃ_, --, --, 
   {{0x69c001f5,0x673c012d,0x00000000,0x00000000}},	//   ïned, _żyją, --, --, 
   {{0x63a005b1,0xfccc001f,0xaad000ce,0x00000000}},	//   _pknn, _እንጅ_, _तलाक, --, 
   {{0x57b54f3d,0x00000000,0x00000000,0x00000000}},	//   _абут, --, --, --, 
   {{0x80c006ab,0x24980153,0x61440116,0x00000000}},	//   रेने, _žymę_, نىدە, --, 
   {{0xe21c0073,0x5f140154,0x85b800cf,0x00000000}},	//   _बहीण_, াড়াও_, _элес_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6da0013e,0x75214f3e,0xd1cc0092,0xaadc00cd}},	//   ҳиса, _zboz, ጣለች_, _प्लक, 
   {{0xeb4c01f3,0x69c8000d,0x00000000,0x00000000}},	//   _አረጋገ, _तंगी, --, --, 
   {{0xed548162,0xf65000c8,0xb3500124,0xada00153}},	//   нос_, נצן_, _акәш, гасл, 
   {{0xfca808f0,0xd910104c,0x00000000,0x00000000}},	// [21ca0] سارو_, ییس_, --, --, 
   {{0xdb1c2d9a,0xc0bc0257,0x00000000,0x00000000}},	//   _mirç, ተክል_, --, --, 
   {{0x5f440075,0x91fc0882,0xdce401fa,0xe97001c8}},	//   _كۆڭل, hyān, lkič, گهند, 
   {{0x7f5c047e,0x00000000,0x00000000,0x00000000}},	//   _hopq, --, --, --, 
   {{0x1e2c001f,0xe970104c,0x00000000,0x00000000}},	//   _ሥልጠና, دهند, --, --, 
   {{0x752007c5,0x84880023,0xb4b000d1,0x6d900327}},	//   _sboz, _ንስራሕ_, һийә, nħan, 
   {{0xc7640075,0xdb1c01bf,0x5ec000eb,0x00000000}},	//   خانى, _piræ, ্রকে, --, 
   {{0xdb1c0365,0xb4b00075,0x18843c1a,0x00000000}},	//   _birç, лийә, _иңен, --, 
   {{0x70ac22e3,0x37e400ee,0x69c00549,0x00000000}},	//   _घरेल, _чозг, ïnee, --, 
   {{0x6c78008f,0xdbf4013d,0xdb1c0213,0xc8b401af}},	//   פריד, _işäy, _dirç, _рссы, 
   {{0x38642171,0xfd780a28,0x66e000c2,0x00000000}},	//   lyor_, ṣṭhi, _соха, --, 
   {{0x32002d2a,0x9f4001a8,0xdb1c0205,0x00000000}},	//   čky_, _svið_, _firç, --, 
   {{0xacb8145e,0xdb1c0598,0x38654f3f,0x1b08009e}},	//   _abûn, _kirä, nyor_, র্যই_, 
   {{0xdb1c0166,0x6d90031c,0x200400d7,0x00000000}},	//   _jirä, għan, ámia_, --, 
   {{0x644400da,0x1dac02ab,0xdb1c0139,0xdecc0023}},	//   ājie, चतंत, _mirä, ቢልካ_, 
   {{0x29d4025c,0xdda8084c,0x91c401ee,0x00000000}},	//   _bħan_, етул_, _шәпл, --, 
   {{0xf1bc28be,0xdd943452,0x386401a9,0x1ae80154}},	// [21cb0] mmá_, уаты, jyor_, _পাড়া, 
   {{0xf1bd4f40,0xe1cc00ab,0xdb1c010e,0x9cb400d1}},	//   lmá_, _सूँघ, _nirä, ھمەت, 
   {{0xc8f4013e,0x7c200200,0x00000000,0x00000000}},	//   взеъ, çorr, --, --, 
   {{0xf1bc0113,0x3864022e,0x9aa40214,0x1e2c0092}},	//   nmá_, fyor_, دممو, _ሥልጣና, 
   {{0x29d4038f,0x77680158,0xdb1c00fd,0x0f340023}},	//   _għan_, fkfx, _birä, _ብምሕረ, 
   {{0xdb1c0166,0x21040153,0x070800ec,0x00000000}},	//   _cirä, mčių_, ذيبي_, --, 
   {{0x6f14003a,0x21040024,0xdb1c010e,0xf1bc02f0}},	//   _mcxc, lčių_, _dirä, kmá_, 
   {{0x91fc0882,0xf1bc02f0,0x210400c0,0x00000000}},	//   tyān, jmá_, očių_, --, 
   {{0x21040953,0x02c81b76,0x47342a83,0xf1bc0548}},	//   nčių_, रश्न, _инас, dmá_, 
   {{0x21040006,0xdb1c010e,0xc244003b,0x00000000}},	//   ičių_, _girä, внок, --, 
   {{0x91fc0882,0xc0e40828,0x7f5c014f,0x944000c7}},	//   syān, конк, _ropq, _ҳҭыж, 
   {{0x7f5c047e,0x74101176,0x21040153,0xdb1c008e}},	//   _sopq, دویا, kčių_, _zirä, 
   {{0x6e340009,0x25bc88cc,0x940401f7,0x00000000}},	//   _asxb, mmul_, _مونه, --, 
   {{0xa280034c,0x25bc084c,0x6f140393,0xafe070e6}},	//   _میخو, lmul_, _ccxc, рорл, 
   {{0xbea47863,0x21040006,0xd4c40724,0xdce40e3c}},	//   тавк, ečių_, _исәп, skič, 
   {{0x3864036b,0x41b400dd,0x25bc0e14,0x00000000}},	//   yyor_, _جمعر, nmul_, --, 
   {{0x29d49c13,0x7f5c022e,0x25bc0254,0x21040064}},	// [21cc0] _aça_, _topq, imul_, gčių_, 
   {{0xeb940124,0x764c09e8,0x00000000,0x00000000}},	//   виу_, _ábyg, --, --, 
   {{0x25bc0113,0x00000000,0x00000000,0x00000000}},	//   kmul_, --, --, --, 
   {{0x38654f41,0xdb1c00fd,0xa92400d4,0x6d90025c}},	//   tyor_, _sirä, віше_, nħal, 
   {{0x29d4021c,0x88bc00cd,0xed540064,0x1d840092}},	//   _eça_, _kaśy, _роя_, _ከብቶች_, 
   {{0x56940323,0x386438bc,0x25bc00e8,0xdb1c0166}},	//   лалт, ryor_, emul_, _qirä, 
   {{0xe9d422f7,0x6aa00730,0xf1bc0113,0x88c400d1}},	//   _акс_, ünft, ymá_, نتۇل, 
   {{0x74682cb9,0x3864020c,0x47e00154,0x00000000}},	//   дров_, pyor_, _নিরী, --, 
   {{0xdb1d4f42,0x98a40166,0x00000000,0x00000000}},	//   _tirä, _tomı_, --, --, 
   {{0xc44453f3,0xc5ec021a,0x25bc2db1,0x88bc00cd}},	//   ایون_, _کړو_, amul_, _naśy, 
   {{0x761400c7,0x1664010a,0x91fc0055,0x00000000}},	//   _шьах, _сĕнӳ, cyāl, --, 
   {{0x21040024,0x6d4002b5,0x6d900135,0xf1bc0118}},	//   yčių_, ēnak, għal, umá_, 
   {{0xf1bc0429,0xe5a0011c,0x33f4010a,0xa194013d}},	//   rmá_, _тици, _рчес, раяч, 
   {{0x29d4038f,0x65b400c7,0x00000000,0x00000000}},	//   _bħal_, rãhe, --, --, 
   {{0xa3a80210,0x00000000,0x00000000,0x00000000}},	//   _कीट_, --, --, --, 
   {{0xdd9400cf,0xdd980114,0x3ebc03b2,0x00000000}},	//   аасы, вшу_, ýtta_, --, 
   {{0x9f4000c7,0x4ec4015b,0xf09c0ba1,0x21040024}},	// [21cd0] _aviõ_, ্রেল, rgàs_, učių_, 
   {{0xaac45767,0x29d4004e,0x21040024,0xea88015e}},	//   نتان, _pça_, rčių_, وخان_, 
   {{0x29d43aaf,0xe8c841ac,0x210402d5,0x00000000}},	//   _għal_, िश्च, sčių_, --, 
   {{0xe7a40131,0x21040024,0xdea40345,0xa9042e0b}},	//   چۇرى_, pčių_, _ئیفی, ئبان, 
   {{0x6d4ca3d6,0xb80802ab,0x99940356,0x00000000}},	//   _inca, हंगम_, _ţeţu_, --, 
   {{0x463800a8,0x4b78010f,0x00000000,0x00000000}},	//   ечия_, _טאָו, --, --, 
   {{0x25bc0311,0xa9c54f43,0x29d403b9,0x00000000}},	//   tmul_, _асак, _uça_, --, 
   {{0x845803b7,0x25bc0356,0xdb1c0055,0x00000000}},	//   ерот_, umul_, _virå, --, 
   {{0x60a00020,0x6d4d4f44,0x321c04d4,0x27b001ee}},	//   _ፍላጎት_, _mnca, etty_, _кәкс, 
   {{0x25bc00a8,0x00000000,0x00000000,0x00000000}},	//   smul_, --, --, --, 
   {{0x6d4d4f45,0x43680116,0x56954f46,0x8188007b}},	//   _onca, _җайн_, _кафт, فندق_, 
   {{0xd4d40153,0x00000000,0x00000000,0x00000000}},	//   _кішэ, --, --, --, 
   {{0x88bc0a28,0xaac0038e,0xa3001cd1,0x6d90031c}},	//   _paśy, वेतक, _күпе, għam, 
   {{0x6d4d4f47,0x9f8408ca,0x05740345,0x00000000}},	//   _anca, рҳод, _جاڕد, --, 
   {{0x88bc00cd,0x45b400df,0x739800df,0x00000000}},	//   _vaśy, ָפּל_, _אױסצ, --, 
   {{0x27fc0205,0x00000000,0x00000000,0x00000000}},	//   _ovun_, --, --, --, 
   {{0xcdc50213,0xac0400d8,0x00000000,0x00000000}},	// [21ce0] ратқ, лнта_, --, --, 
   {{0x6d4d4f48,0x9f4002ea,0x20000093,0x7b640014}},	//   _enca, _otié_, _ivii_, دارٕ, 
   {{0x3f880526,0xb90830e3,0x27fc005b,0xdb1c00e5}},	//   mibu_, енез_, _avun_, _kirú, 
   {{0xed554f49,0xd91023cf,0x999001f1,0x00000000}},	//   _бою_, تیر_, ťaži_, --, 
   {{0xe1e400ec,0x178408ca,0xeb5000cf,0xdbc801a9}},	//   _گس_, аҳам, _گۉلگ, _аҳад_, 
   {{0x7d154f4a,0xfaa42401,0x3f894f4b,0x321c023a}},	//   lgys, _баго, nibu_, ytty_, 
   {{0xe1e400dd,0x27fc02b9,0xeb954f4c,0x7bcc002e}},	//   _دس_, _evun_, _сир_, _iibu, 
   {{0x7d154f4d,0x6a8005f5,0x3f8801c8,0x56940ce8}},	//   ngys, _улса, hibu_, лаһт, 
   {{0x7bcc44c8,0xb7140597,0x20040306,0x3f88037e}},	//   _kibu, _مباش, ámil_, kibu_, 
   {{0x3f8800b2,0x7bcd4f4e,0x61e00175,0x14c00b7c}},	//   jibu_, _jibu, _btnl, शेषण, 
   {{0x7bcd4f4f,0x6b7810df,0x20008437,0x06841c5c}},	//   _mibu, גרינ, _avii_, ﻪﺭﻟﯩ, 
   {{0x7bcd4f50,0xdb1c617f,0x6d900327,0x3cec012d}},	//   _libu, _cirú, tħam, जरों_, 
   {{0x20014f51,0x29d4031c,0x22440254,0x7d14015d}},	//   _cvii_, _rħam_, _ernk_, dgys, 
   {{0x7bcd4f52,0xdb1c003a,0x7d14017a,0xdd9401e0}},	//   _nibu, _virû, egys, ҡары, 
   {{0x630000c6,0x00000000,0x00000000,0x00000000}},	//   _طويل, --, --, --, 
   {{0x7bcd4f53,0x7d1426de,0x3f894f54,0x00000000}},	//   _aibu, ggys, aibu_, --, 
   {{0x7bcc5137,0x3f88770e,0x2000009f,0x0a40001f}},	// [21cf0] _bibu, bibu_, _gvii_, _የሚመራ, 
   {{0x4f8401d9,0x3f880171,0x00000000,0x00000000}},	//   _خابہ, cibu_, --, --, 
   {{0x5f754f55,0x2000006f,0x60a0001f,0xdd900014}},	//   _داير, _zvii_, _ፍላጐት_, زوے_, 
   {{0xe9a94f56,0x7bcc00b5,0x2bb400af,0x65b40022}},	//   ردان_, _eibu, _अठवा, kãha, 
   {{0x2b8c0210,0x48c40139,0x00000000,0x00000000}},	//   eżce_, рәва, --, --, 
   {{0x7bcc7bc3,0x1ae401c6,0x00000000,0x00000000}},	//   _gibu, _гоём, --, --, 
   {{0xea600014,0x67200200,0x00000000,0x00000000}},	//   _اپزی, rfnj, --, --, 
   {{0x3f882f99,0x05654f57,0x23a801bf,0x00000000}},	//   zibu_, рвин, højt_, --, 
   {{0x7bcd4f58,0x76b54f59,0xb0c40d2c,0x67100073}},	//   _yibu, лләр_, रेमग, _ठाऊक_, 
   {{0x42254f5a,0x7bcc0564,0xd05c0b45,0xd7c80fc6}},	//   адов, _xibu, lasɗ, _موقه_, 
   {{0x45d53376,0xe6b001ec,0x6d900327,0x3f894f5b}},	//   _тоес, _الاگ, għak, vibu_, 
   {{0x257801e1,0xd47400fb,0x00000000,0x00000000}},	//   _dàlù_, рҙәш_, --, --, 
   {{0x3f8800b2,0x63e0237e,0xdb1d4f5c,0x955416ac}},	//   tibu_, _ايتە, _virú, _دخلا, 
   {{0xd5ac0014,0x00000000,0x00000000,0x00000000}},	//   _ٲہی_, --, --, --, 
   {{0x3f894f5d,0xdb1c0086,0xc0e54f5e,0xafd803b2}},	//   ribu_, _girù, _койк, lvøl, 
   {{0x3f894f5f,0x4aa805f9,0x7d140024,0x32980115}},	//   sibu_, _कड़व, ugys, _שבקד, 
   {{0x3b854f60,0x46d40d2c,0x7bcc0098,0x3f8802d1}},	// [21d00] алаг, दशाह, _pibu, pibu_, 
   {{0xe94415f6,0x29d40327,0x6ff8008d,0x1db80490}},	//   یرنی, _għak_, _שפיג, _आठवत, 
   {{0x7bcc27d0,0x3f98014f,0xe730016b,0xafd80162}},	//   _vibu, _ijpu_, deε_, hvøl, 
   {{0xafd80579,0xfd1000c6,0x7bcc22bd,0x6e9c0037}},	//   kvøl, _بجد_, _wibu, _खुटु, 
   {{0x7bcd4f61,0x9f5801e7,0x584800c7,0x00000000}},	//   _tibu, _ózón_, ыҧан_, --, 
   {{0xe3a47ce3,0x7bcc02d0,0x6e3001d3,0xfd44009d}},	//   _ذر_, _uibu, _újbó, _сэүн, 
   {{0x23a801bf,0x00000000,0x00000000,0x00000000}},	//   højs_, --, --, --, 
   {{0xfaa42c1d,0x342412e7,0xa9640a93,0x13f401d5}},	//   _баҳо, афов, _киса_, бзия, 
   {{0xafd8022c,0xdb1c03cd,0xa3e40640,0x77c801c6}},	//   gvøl, _birø, адња_, _алаг_, 
   {{0xf3642077,0xb35400f2,0x65b40124,0xe808012d}},	//   ртин, شیبا_, rãha, _हटता_, 
   {{0xb7780055,0x853401b9,0xd0d402e8,0x7d040210}},	//   _arṇā, _گونچ, йонъ, _odks, 
   {{0xa19400d3,0xa504010a,0x00000000,0x00000000}},	//   жаюч, _веца_, --, --, 
   {{0xdb1c0221,0x00000000,0x00000000,0x00000000}},	//   _chrë, --, --, --, 
   {{0xd2f88083,0x00000000,0x00000000,0x00000000}},	//   _секц_, --, --, --, 
   {{0xdb1c0142,0x23a8005c,0x00000000,0x00000000}},	//   _thrê, røjt_, --, --, 
   {{0x2bac0dad,0x9d30037e,0xa2c087ea,0x00000000}},	//   _जीजा, _aｌbe, रधर्, --, 
   {{0xdb0803b9,0x00000000,0x00000000,0x00000000}},	// [21d10] _əlöv, --, --, --, 
   {{0xdef8008e,0x00000000,0x00000000,0x00000000}},	//   _кыю_, --, --, --, 
   {{0x4f8468e7,0x00000000,0x00000000,0x00000000}},	//   _ناگہ, --, --, --, 
   {{0x9a8405f5,0xc62400cc,0x00000000,0x00000000}},	//   цуул, _মছলা_, --, --, 
   {{0x5c0401c4,0x00000000,0x00000000,0x00000000}},	//   _мяра, --, --, --, 
   {{0x9f500e2d,0x17840153,0x2918031c,0x00000000}},	//   ğaça_, огім, żqa_, --, 
   {{0xaac066eb,0xeae00073,0x8c080154,0x00000000}},	//   वेशक, गडीत_, _রঙিন_, --, 
   {{0xe730016b,0x78740209,0x1e9800d9,0xd5e94f62}},	//   seε_, рйәр_, יכול_, جعون_, 
   {{0x261031a0,0x9f44036e,0x00000000,0x00000000}},	//   _धमकी_, ëmë_, --, --, 
   {{0x8338034b,0xafd80162,0x00000000,0x00000000}},	//   учит_, rvøl, --, --, 
   {{0x81c94f63,0x82a54f64,0xafd80174,0xf7cc0220}},	//   лгов_, санж, svøl, _ﺗﻮﻣﻪ, 
   {{0x23a8005c,0x00000000,0x00000000,0x00000000}},	//   tøjs_, --, --, --, 
   {{0xdce40064,0x00000000,0x00000000,0x00000000}},	//   nkią, --, --, --, 
   {{0x2bd809d9,0x53340cca,0x64494f65,0xe3b01291}},	//   _बढ़ा, _мечт, _irgi, _برص_, 
   {{0xfce400d4,0x6d900327,0x00000000,0x00000000}},	//   йово, nħaw, --, --, 
   {{0x65794f66,0x443c0210,0x3fe40108,0x00000000}},	//   nhuh, _ksw_, _лжив, --, 
   {{0x7a4000e4,0x443c6e4a,0x00000000,0x00000000}},	// [21d20] kãtá, _jsw_, --, --, 
   {{0x3b94001f,0xfaa4299f,0x443d4f67,0xf1c808a5}},	//   ማሪዎች_, базо, _msw_, _tjáð_, 
   {{0x6578180e,0xfe4001b9,0xab2402e8,0xeb940114}},	//   khuh, _عکسی, соха_, љих_, 
   {{0xf8f800c6,0x443c01ab,0x00000000,0x00000000}},	//   اءات_, _osw_, --, --, 
   {{0x65794f68,0x443c02b7,0x4f641bf4,0x00000000}},	//   dhuh, _nsw_, _طایف, --, 
   {{0x68400479,0xdcf4010f,0x00000000,0x00000000}},	//   янча, ĉaĵo, --, --, 
   {{0x7afd4f69,0xf6282e51,0x443c66e4,0x6d90031c}},	//   mapt, استى_, _asw_, għaw, 
   {{0xe60c0c50,0x65794f6a,0xb9940597,0x00000000}},	//   رشى_, ghuh, _الرب, --, 
   {{0x443c0014,0x9c2c02dd,0x38700158,0x00000000}},	//   _csw_, ерiн, øyrd_, --, 
   {{0x7afd4f6b,0xf7480b8a,0xdb1c007b,0x65780798}},	//   napt, _حجره_, _bhré, ahuh, 
   {{0x64494f6c,0x65780522,0xdb1d4f6d,0xf5e8020f}},	//   _ergi, bhuh, _chré, _смел_, 
   {{0x7afd4f6e,0x657803fa,0xdb1c00ae,0xafd812ed}},	//   hapt, chuh, _dhré, svøm, 
   {{0x7afd4f6f,0x64482375,0x443d4f70,0xafd803b2}},	//   kapt, _grgi, _gsw_, mvøk, 
   {{0xdb1c00ae,0x17cc03d4,0xafd803b2,0x00000000}},	//   _fhré, ৰীৰি, lvøk, --, 
   {{0x7afd4f71,0xdb1c00c6,0x91c40075,0xa2900212}},	//   dapt, _ghré, _мәмл, _наші, 
   {{0xd010bd62,0x00000000,0x00000000,0x00000000}},	//   _قلب_, --, --, --, 
   {{0x7bd802b5,0xd2500214,0x7afc054e,0x8af94f72}},	// [21d30] _ōtur, _رنک_, fapt, инас_, 
   {{0xeb9c005c,0x7afc0142,0x91780248,0x00000000}},	//   _svøb_, gapt, bẹ́_, --, 
   {{0xce580c56,0x657800c7,0x00000000,0x00000000}},	//   _танц_, yhuh, --, --, 
   {{0xdd2c0064,0x00000000,0x00000000,0x00000000}},	//   _tėšk, --, --, --, 
   {{0x7afd4f73,0x657806d6,0x91fc002b,0x00000000}},	//   bapt, vhuh, cyāv, --, 
   {{0xd7c8021a,0x6d90025c,0x00000000,0x00000000}},	//   مونه_, tħaw, --, --, 
   {{0x657806a3,0x443d4f74,0x00000000,0x00000000}},	//   thuh, _ssw_, --, --, 
   {{0x1a682c04,0x657800d8,0x499001b9,0xafd80174}},	//   _دیمی_, uhuh, _کیچر, gvøk, 
   {{0x75c8068f,0x6578d811,0x04440395,0x00000000}},	//   _języ, rhuh, цепн, --, 
   {{0x65794f75,0x02054f76,0x68f801c3,0x2b400219}},	//   shuh, озон, _heud, _jajc_, 
   {{0x6578021a,0xd7c86e0c,0x68f80098,0x64580334}},	//   phuh, _اوله_, _keud, sxui, 
   {{0x68f94f77,0x443c0070,0xa4f42fee,0x64480219}},	//   _jeud, _tsw_, _اکثر_, _trgi, 
   {{0x7afd4f78,0x443c0730,0x68f94f79,0xdce405be}},	//   yapt, _usw_, _meud, lkić, 
   {{0x9474165e,0x68f80192,0xdb1d4f7a,0x7d0401d3}},	//   _عدنا, _leud, _thré, _mérő, 
   {{0xa5242fb5,0xdce40063,0x6e4018ac,0x30940023}},	//   _རྡོག_, nkić, мерз, _ዘዕግብ_, 
   {{0x291c0070,0x66000218,0xdb1c00a2,0x7afc02d1}},	//   _ncua_, isnk, _dirý, wapt, 
   {{0x7afd4f7b,0x21200c6a,0xfb8804f0,0x7ed40153}},	// [21d40] tapt, _icih_, абак_, _мінч, 
   {{0x2fd404fb,0x236400e8,0xbd88132f,0x00000000}},	//   _گوید_, _jonj_, _چندن_, --, 
   {{0x7afd4f7c,0x39441064,0xdce40558,0xdb1c00ee}},	//   rapt, жнег, jkić, _girý, 
   {{0x7afd4f7d,0x68f80e89,0x2364007f,0x00000000}},	//   sapt, _ceud, _lonj_, --, 
   {{0x68f94f7e,0xa5240135,0xe944036b,0x7afc02d1}},	//   _deud, _རྡེག_, ترلی, papt, 
   {{0x7afd0c13,0xbb540ada,0x00000000,0x00000000}},	//   qapt, _بنسب, --, --, 
   {{0x21200098,0x637c017a,0xe78400f1,0x7e78010f}},	//   _ocih_, _kênf, تپوه_, יאַז, 
   {{0x68f80098,0x2b400427,0x7d0400e5,0x00000000}},	//   _geud, _zajc_, _férő, --, 
   {{0x23640399,0x91fc0882,0x66000218,0x39440153}},	//   _bonj_, hyāt, asnk, mdos_, 
   {{0x39454f7f,0x21200098,0x68f801c0,0x23640798}},	//   ldos_, _acih_, _zeud, _conj_, 
   {{0x3944003a,0xe3ac31ed,0xafd80162,0x68f94f80}},	//   odos_, خري_, pvøk, _yeud, 
   {{0xe1ed4ca1,0x2120007f,0xe8fc0086,0x23640175}},	//   کسی_, _ccih_, _ôût_, _eonj_, 
   {{0x39454f81,0xaf3478f5,0xdb1c0724,0x1728025c}},	//   idos_, يرست, _birü, _ལྡོམ_, 
   {{0x23640007,0xacb800d2,0x2d8801ab,0xdb1c7bd7}},	//   _gonj_, _mbût, _smce_, _miró, 
   {{0xed88648a,0x3dc00112,0xe29400f3,0x00000000}},	//   асак_, _bhkw_, _маљ_, --, 
   {{0xdb1c0077,0x2364f8e3,0xf8c808df,0x418401af}},	//   _oiró, _zonj_, िधाय, _нтығ, 
   {{0x0bd40597,0xef6400a7,0xdd9402d9,0xdb1d4f82}},	// [21d50] سياح, _дъно, фаты, _niró, 
   {{0x39440261,0x68f94f83,0x291c05d5,0x4fc01c3e}},	//   edos_, _seud, _scua_, _سەزە, 
   {{0x17280135,0x68f80789,0x2d88010e,0x91fc0055}},	//   _ལྡེམ_, _peud, _tmce_, cyāt, 
   {{0x777801c0,0x6d900003,0x00000000,0x00000000}},	//   _altx, għat, --, --, 
   {{0x68f80165,0x45e40150,0x37e400eb,0x00000000}},	//   _veud, _ﺍﻨﻘﻼ, _নিউর, --, 
   {{0x39441a36,0xd8740a2c,0x29d40135,0x68f8003e}},	//   ados_, بامب, _bħat_, _weud, 
   {{0xd6d94f84,0x39442819,0xdb1c0005,0x68f94f85}},	//   әтә_, bdos_, _eiró, _teud, 
   {{0x777801c4,0x236405c7,0xdce416a3,0x3ebc03f2}},	//   _eltx, _sonj_, rkić, ýtti_, 
   {{0xdb1d069d,0x6fa82232,0x23640010,0x00000000}},	//   _giró, चकां, _ponj_, --, 
   {{0x660005b1,0xa2c001e0,0x65cc02dd,0xb3805b0f}},	//   psnk, үәҫк, _ﺗﯟﯨﻠ, ельл, 
   {{0x637c145e,0x29d4038f,0x236409a8,0x41a821f3}},	//   _lêng, _għat_, _vonj_, йвон_, 
   {{0xdb1d4f86,0xcf88008d,0x00000000,0x00000000}},	//   _jirò, _גט_, --, --, 
   {{0x43754f87,0x21200076,0xa73c0131,0x04c8009a}},	//   _нукт, _vcih_, ﻨﺠﺎﯓ_, _اوشي_, 
   {{0xdb1c00a3,0x39440024,0xe29402dd,0x2bb4000d}},	//   _chrì, zdos_, _қақ_, _अठगा, 
   {{0x272c07c4,0x3ebc77d4,0xdb1c03ee,0x4278008f}},	//   mını_, ått_, _virü, _לאַג, 
   {{0x272c47af,0xc0040536,0x23840210,0x00000000}},	//   lını_, _епик, żują_, --, 
   {{0x39440472,0x80c00037,0x21e00150,0x00000000}},	// [21d60] vdos_, रेखे, _ﺍﻟﺠﺭ, --, 
   {{0xdb1c067c,0x272c046c,0xfaa40395,0x9cfc0154}},	//   _airò, nını_, пазо, ইলেন_, 
   {{0x6ed80375,0x7e7400cf,0x0ae80b24,0xfce401f0}},	//   _לחיפ, _رادئ, ترقي_, _ноно, 
   {{0xdb1d4f88,0x39440006,0x5fc01157,0x272c3535}},	//   _piró, udos_, _शीतल, hını_, 
   {{0x1728003d,0x29d40135,0x272c719a,0x00000000}},	//   _ལྡུམ_, _bħas_, kını_, --, 
   {{0x272c03ee,0x39454f89,0xeb9c0162,0xdb1cea19}},	//   jını_, sdos_, _hvøn_, _viró, 
   {{0x272c2c6f,0x637c006a,0x3944089c,0x98ac887f}},	//   dını_, _zêng, pdos_, ılıq_, 
   {{0x637c145e,0xdb1d4f8a,0xacb80428,0xb7d85dc6}},	//   _lênd, _tiró, _ibûr, _هورا_, 
   {{0x272c1ae4,0xa9a0010b,0x00000000,0x00000000}},	//   fını_, _читд, --, --, 
   {{0x68414f8b,0x29d4038f,0xa8780375,0x272c2ac2}},	//   _януа, _għas_, _האמר, gını_, 
   {{0x0cb8aeb8,0xe7340166,0xdb1c002e,0xe4e40037}},	//   _आर्म, _хех_, _jirñ, _ट्कि_, 
   {{0xb5c400fb,0xb46401af,0x00000000,0x00000000}},	//   _эйел, _нкел, --, --, 
   {{0x637c2776,0x752007a8,0x272c1d89,0x9514002b}},	//   _bênd, _icoz, bını_, _aṅge, 
   {{0x272c029f,0xdb1c007b,0x311c00dc,0x00000000}},	//   cını_, _bhrí, _भावः_, --, 
   {{0x637c2776,0xdb1d4f8c,0x256000a2,0xad0801c6}},	//   _sêng, _chrí, _añly_, йхаж_, 
   {{0x91fc0882,0xdc141f02,0x15d402dd,0xe298011a}},	//   syās, _aşıy, _ﺟﺎﺯﺩ, _לשור, 
   {{0x102800b2,0x2004634d,0x91fc002b,0x00000000}},	// [21d70] _بڻجي_, ámit_, cyār, --, 
   {{0xad24168d,0x6d90025c,0xd1bc0023,0x00000000}},	//   _کردو, għar, ሰኽቲ_, --, 
   {{0xdb1d3fe3,0x29d4025c,0x83fc00e5,0x00000000}},	//   _pirò, _rħas_, nyőr, --, 
   {{0x272c4a4a,0x29d4025c,0x3ebc061f,0x9aa40472}},	//   zını_, _bħar_, ütte_, رمنو, 
   {{0x272cc5d2,0x99d54f8d,0xc76801c6,0x21e00046}},	//   yını_, رتما, жилж_, _ﺍﻟﺤﺭ, 
   {{0xfcc016c8,0xaca0063f,0x387000cc,0x80c007af}},	//   _рәсм, _laịb, øyra_, रेटे, 
   {{0xdb1c067c,0xda3402d5,0x9a2801b9,0xb6a001d5}},	//   _tirò, _перы, _ноёб_, кишл, 
   {{0x99980276,0x6fac0490,0xdb1c0321,0x00000000}},	//   _екст_, ंकडू, _hirð, --, 
   {{0x272c0c07,0x69c94f8e,0xf1e402dd,0x00000000}},	//   tını_, mmge, _ﺍﻟﻨﻘ, --, 
   {{0x29d4003d,0x75214f8f,0x69c9337a,0x616002d3}},	//   _għar_, _ecoz, lmge, _ሲቪላዊ_, 
   {{0x272c596c,0xaca000b4,0xb7200214,0x69c85a29}},	//   rını_, _baịb, _شکوه, omge, 
   {{0x272c82aa,0x637c2776,0x00000000,0x00000000}},	//   sını_, _sênd, --, --, 
   {{0x656808c2,0x637c0798,0x272c0c3c,0x04440120}},	//   _iogh, _pênd, pını_, _целн, 
   {{0xdb1d4f90,0x65694f91,0x69c8002f,0xdddc00a2}},	//   _phrí, _hogh, hmge, gyrş, 
   {{0x91fc0882,0x656800a3,0xfce54f92,0x80c0473c}},	//   syār, _kogh, добо, रेजे, 
   {{0xed5422f7,0x8db402dd,0x65694f93,0xe2a40214}},	//   мос_, есуі, _jogh, _واژن_, 
   {{0x65694f94,0x6d900003,0x00000000,0x00000000}},	// [21d80] _mogh, għaq, --, --, 
   {{0x65694f95,0x7f8407d6,0x69c928bb,0xdb1c00ae}},	//   _logh, _آلدن, emge, _thrí, 
   {{0x637d4f96,0x65694f97,0xbea402e8,0xdb1c00d7}},	//   _gêne, _oogh, _цанк, _uhrí, 
   {{0x65694f98,0xed540220,0xdb1c032e,0x3ebc1427}},	//   _nogh, _жою_, _eirð, ýttu_, 
   {{0xb8f40574,0xdb1c041e,0xeb9c0162,0x6d38011a}},	//   _सण_, _firð, _kvøl_, _ותכנ, 
   {{0x75214f99,0x656800a3,0x69c8017a,0xdb1c0252}},	//   _scoz, _aogh, amge, _girð, 
   {{0x65694f9a,0xe7340a5b,0x00000000,0x00000000}},	//   _bogh, феј_, --, --, 
   {{0x65694f9b,0xdecc0023,0x7954009f,0xdddc00e5}},	//   _cogh, ቢልና_, _تَرا, nyrő, 
   {{0x65694f9c,0xe7d00137,0x00000000,0x00000000}},	//   _dogh, رۅۅگ, --, --, 
   {{0x656837a8,0x7980017a,0x765c01f4,0x00000000}},	//   _eogh, lhow, äpys, --, 
   {{0x65683c5d,0xe7142abb,0x00000000,0x00000000}},	//   _fogh, _زينت_, --, --, 
   {{0x7980010b,0x65694f9d,0x637c06af,0xafd80174}},	//   nhow, _gogh, _rêne, kvøt, 
   {{0x637c63cd,0xdb1c01ab,0xe3ac1b2c,0x21e00150}},	//   _sêne, _ohrà, طری_, _ﺍﻟﺼﺭ, 
   {{0x656801af,0xd2514f9e,0xd90401ed,0x91fc0055}},	//   _zogh, _منت_, _ھی_, byāp, 
   {{0xd9043821,0xdfd47798,0x6568427d,0xaca0063f}},	//   _پی_, торы, _yogh, _mbụb, 
   {{0x65694f9f,0x00000000,0x00000000,0x00000000}},	//   _xogh, --, --, --, 
   {{0xdb1c0e89,0xc0c000d1,0x79814fa0,0x20040841}},	// [21d90] _bhrà, _бәри, dhow, šmir_, 
   {{0xa3c003ba,0xdb1c08c2,0x60c14fa1,0x798001ab}},	//   ्षय_, _chrà, ümme, ehow, 
   {{0xdb1d4fa2,0xc914026a,0xdce401e4,0x00000000}},	//   _virð, едећ, lkiĝ, --, 
   {{0xaca002e3,0x79800076,0x69c8002f,0x00000000}},	//   _abụb, ghow, umge, --, 
   {{0x65694fa3,0xa3c04d53,0x69c94fa4,0xdb1c00a3}},	//   _rogh, ्षम_, rmge, _fhrà, 
   {{0x65694fa5,0xdb1c0e89,0x952c0327,0x00000000}},	//   _sogh, _ghrà, ྦུའི_, --, 
   {{0x45d464e1,0xaca002e3,0x65694fa6,0x79804e2b}},	//   нцит, _maọb, _pogh, bhow, 
   {{0x79814fa7,0x91fc0882,0x6568016d,0x9a8801d9}},	//   chow, vyāp, _qogh, _کنہٕ_, 
   {{0x65694fa8,0xdbe4007f,0x21e00220,0x0394011c}},	//   _vogh, tèén, _ﺍﻟﺸﺭ, ерня, 
   {{0xd70800f3,0x00000000,0x00000000,0x00000000}},	//   _онђе_, --, --, --, 
   {{0x65694fa9,0x28c8000d,0x00000000,0x00000000}},	//   _togh, ़ेरि, --, --, 
   {{0xe504009f,0x00000000,0x00000000,0x00000000}},	//   _آباي, --, --, --, 
   {{0x50b405f5,0x91fc0882,0xdecc0020,0xafe002e8}},	//   всру, syāp, ቢውን_, лоял, 
   {{0xdb1c02fb,0x63b0151e,0x79814faa,0x80c01411}},	//   _ohrá, _шәйх, zhow, _ەڭسە, 
   {{0xf77025f9,0x79806974,0xc12000fb,0x00000000}},	//   נקל_, yhow, _йүнһ, --, 
   {{0xdb1c08c2,0x918000d1,0x614400d1,0x00000000}},	//   _shrà, _نۇپۇ, _شىخە, --, 
   {{0xada00f25,0xdb1c00a3,0x06fc01ef,0x823401c8}},	// [21da0] уатл, _phrà, _číná_, _آرڪا, 
   {{0x60c50ad2,0xdb1c00c6,0xafd80162,0x00000000}},	//   _izim, _bhrá, rvøt, --, 
   {{0xdb1c03c6,0x61e80311,0x79814fab,0x20f40073}},	//   _chrá, _înlă, thow, _आभाळ_, 
   {{0x7f84036b,0xdb1c00ae,0x387005ac,0xc9540139}},	//   _آلگن, _dhrá, øyro_, ктчы, 
   {{0xdb1c0e89,0xafd83a26,0x21e001ec,0xf1e40046}},	//   _thrà, lvør, _ﺍﻟﺴﺭ, _ﺍﻟﻤﻘ, 
   {{0x60c45053,0x63a0003e,0xdb1c00ae,0xf644030d}},	//   _mzim, _njnn, _fhrá, ехин, 
   {{0xdb1d4fac,0xfaa4016c,0x91ec01e4,0xe28400c6}},	//   _birö, _чаво, _orցa, _إذ_, 
   {{0xfaa4006c,0xc0bc02d3,0x00000000,0x00000000}},	//   _жаҳо, ሰርሕ_, --, --, 
   {{0xafd80579,0x00000000,0x00000000,0x00000000}},	//   hvør, --, --, --, 
   {{0x81b802f5,0x643005d9,0xc7940124,0x88340006}},	//   _অংগ_, اريء, _ирхы, _шэсц, 
   {{0x60c54fad,0xf65400d4,0x00000000,0x00000000}},	//   _azim, _ятаю, --, --, 
   {{0xafd803b2,0x00000000,0x00000000,0x00000000}},	//   dvør, --, --, --, 
   {{0x06d40eac,0x63a00334,0xeb9c2b96,0x00000000}},	//   _স্পি, _fjnn, _svøm_, --, 
   {{0xa3c00d0d,0x60c54fae,0xc4cc0a81,0xdce40115}},	//   ्षण_, _dzim, _بےٚ_, rkiĝ, 
   {{0x60c4a21d,0xdce400c8,0x5e580276,0x9e340354}},	//   _ezim, skiĝ, ниря_, лерч, 
   {{0x905400c7,0x3eb80212,0x3ebc07c5,0x00000000}},	//   _авиц, _dypt_, ütta_, --, 
   {{0xafd85522,0xdb1c007b,0xdbe401e1,0x321c0609}},	// [21db0] rvøs, _shrá, _jèèj, luty_, 
   {{0xdb1c01e7,0x333c025c,0x00000000,0x00000000}},	//   _phrá, netx_, --, --, 
   {{0x321d4faf,0x60c404ba,0xf0400014,0xa3c03409}},	//   nuty_, _zzim, _شٹھی, ्षत_, 
   {{0x6f04014f,0x1a6879f8,0x00000000,0x00000000}},	//   lajc, ریقی_, --, --, 
   {{0x57e802dd,0x5c7400f5,0x00000000,0x00000000}},	//   едім_, _блят, --, --, 
   {{0xdb1c00c6,0x321c3e91,0xab8400db,0x6f054fb0}},	//   _thrá, kuty_, _чумк, najc, 
   {{0xdb1c0306,0x69c0004e,0xc0bc0023,0xf1b000cd}},	//   _uhrá, ïnes, ሰርሐ_, ीतान, 
   {{0x321c0589,0x99d51147,0x6f054fb1,0x00000000}},	//   duty_, _متقا, hajc, --, 
   {{0x6f040b67,0x00000000,0x00000000,0x00000000}},	//   kajc, --, --, --, 
   {{0x27fc01e1,0xc1e8009d,0x00000000,0x00000000}},	//   _iwun_, мдож_, --, --, 
   {{0x6f0401f1,0x60c401ed,0x00000000,0x00000000}},	//   dajc, _szim, --, --, 
   {{0x04b400a7,0xc0bc0023,0xa1440022,0x00000000}},	//   _исля, ሰርሑ_, уҭие, --, 
   {{0x321c00b5,0x1b0c015b,0xf4840424,0x333c00db}},	//   auty_, স্টে_, _لاوی, betx_, 
   {{0x425400a8,0x1c040b40,0xb38802d3,0x321c0d0d}},	//   _атит, शीफल_, _ንብዙሕ_, buty_, 
   {{0xafd8022c,0x637c004a,0x00000000,0x00000000}},	//   tvør, _gêna, --, --, 
   {{0x61e00280,0x69d80eda,0x65780004,0x409400c6}},	//   _iunl, _niue, nkuh, _للعر, 
   {{0x2a740020,0x6f04208d,0x61e14fb2,0xebe006ed}},	// [21dc0] _በሚገባ_, bajc, _hunl, иотп, 
   {{0x442d4fb3,0x6f040bb8,0x61e14fb4,0x69d800a3}},	//   ite_, cajc, _kunl, _aiue, 
   {{0x442d4fb5,0x65794fb6,0x27fd4fb7,0xdce41224}},	//   hte_, kkuh, _awun_, ljič, 
   {{0x2000004b,0x69d80381,0x61e14fb8,0xfce4c02c}},	//   _kwii_, _ciue, _munl, _шомо, 
   {{0x69d94fb9,0x61e14fba,0xdce415ad,0x69c006af}},	//   _diue, _lunl, njič, înea, 
   {{0x442d4fbb,0xbb740801,0x20000099,0x68e801ab}},	//   dte_, _румъ, _mwii_, acgd, 
   {{0x442d4fbc,0x61e1446d,0xb5a41985,0x6ad40408}},	//   ete_, _nunl, крий, _амрă, 
   {{0x65794fbd,0x69d801ab,0x00000000,0x00000000}},	//   gkuh, _giue, --, --, 
   {{0x442d4fbe,0x37e400d6,0x234400dd,0x61e000ad}},	//   gte_, _розг, چسپی_, _aunl, 
   {{0x61e00baf,0x637c06ed,0x51f80212,0x00000000}},	//   _bunl, _pêna, нною_, --, 
   {{0x442d4fbf,0x61e005d5,0xa3e42122,0x06640451}},	//   ate_, _cunl, _मूठ_, _ٽالپ, 
   {{0x442d4fc0,0x6f054f03,0x00000000,0x00000000}},	//   bte_, wajc, --, --, 
   {{0x53354fc1,0x61e001c3,0x6f054fc2,0xe3ac00e5}},	//   _белт, _eunl, tajc, _ڈرو_, 
   {{0x321d4fc3,0xe3ac4fe0,0x61e0879d,0x00000000}},	//   puty_, _ورو_, _funl, --, 
   {{0x61e021d8,0xb800107c,0x6f040210,0xf7cc0220}},	//   _gunl, रीतम_, rajc, _ﺗﻮﻟﻪ, 
   {{0x2000090c,0xa3e4447d,0x6f041fde,0xf1a88b25}},	//   _fwii_, _मूड_, sajc, _تاته_, 
   {{0x6e400075,0x5c7405f5,0x69d8c52c,0xdc754fc4}},	// [21dd0] _ھۆرم, алтт, _riue, агты, 
   {{0x61e14fc5,0x69d80093,0x657809a8,0x6e400014}},	//   _yunl, _siue, zkuh, _پۆرم, 
   {{0x442d4fc6,0xf1bc011f,0x69d801ab,0xe79001d5}},	//   zte_, olá_, _piue, یاتک, 
   {{0x442d4fc7,0x59f80276,0xdb1c00d7,0x00000000}},	//   yte_, теця_, _sirô, --, 
   {{0x442d4fc8,0x69d94fc9,0xd7c81056,0x6b9402d0}},	//   xte_, _viue, چونه_, pixg, 
   {{0xd7c8021a,0x442c0232,0xf1bd4fca,0x07083092}},	//   نونه_, vte_, hlá_, ريبي_, 
   {{0xf1bd4fcb,0x442d4fcc,0x69d94fcd,0x98c418c7}},	//   klá_, wte_, _tiue, лсәл, 
   {{0x69d816b8,0xa3e40833,0x6578009a,0x00000000}},	//   _uiue, _मंद_, ukuh, --, 
   {{0x442d4fce,0xf1bc0038,0x76b4468c,0x44394fcf}},	//   ute_, dlá_, кләр_, ïs_, 
   {{0x64a0d63d,0x65794fd0,0x61e14fd1,0xf1bc0093}},	//   лақа, skuh, _punl, elá_, 
   {{0x61e0047e,0x4128009d,0x15cc0150,0x13e8004e}},	//   _qunl, ноно_, _ﺗﯟﺍﺩ, нмөй_, 
   {{0x442d4fd2,0x06d4000e,0x733004a9,0x61e0062c}},	//   pte_, _স্থি, لىۋا, _vunl, 
   {{0x442d4fd3,0x94041410,0x00000000,0x00000000}},	//   qte_, _نونه, --, --, 
   {{0x7498b4a1,0x25bd4fd4,0x61e14fd5,0xf1bc011f}},	//   _אינפ, llul_, _tunl, alá_, 
   {{0x61e01c06,0xf1bc0548,0x020401d5,0xd3d81410}},	//   _uunl, blá_, _ёзин, _شبها_, 
   {{0x17280489,0x38640267,0x645c00e8,0x25bc01f5}},	//   _ལྡནམ_, yxor_, _àqis, nlul_, 
   {{0x25bd4fd6,0xa2d80b02,0x3864022e,0x00000000}},	// [21de0] ilul_, नशक्, xxor_, --, 
   {{0xdd042c70,0x69c0004a,0x1b040183,0x25bd4fd7}},	//   ısın, înen, _লাহে_, hlul_, 
   {{0x0ea800db,0x00000000,0x00000000,0x00000000}},	//   _үкөй_, --, --, --, 
   {{0x38654fd8,0x00000000,0x00000000,0x00000000}},	//   txor_, --, --, --, 
   {{0xed542621,0x88c40b38,0x9f4001ab,0x7d054fd9}},	//   _соя_, ۇتۇل, _stiù_, _ieks, 
   {{0xa88400fd,0xc4c000cc,0x00000000,0x00000000}},	//   ыйча_, _উলংঙ, --, --, 
   {{0x7d054fda,0xfbdc31c1,0xf1bc011f,0x25bc0356}},	//   _keks, _iiª_, ylá_, flul_, 
   {{0x746834d8,0x78240597,0xc0bc2e1f,0x65a405f5}},	//   еров_, _معطل, ደርስ_, лтыг_, 
   {{0x18b40184,0x499004d3,0x5fb407f7,0xa3e40406}},	//   _тәжр, _بینر, ंकाल, _मूद_, 
   {{0x7d054fdb,0x25bd4fdc,0xb9dc02d3,0xe7b0009f}},	//   _leks, alul_, _ኤረ_, _همقد, 
   {{0xf1bd4fdd,0x25bc0311,0x8534036b,0x637c0051}},	//   tlá_, blul_, _چومچ, _tênn, 
   {{0x7d054fde,0x25bc0276,0xd0d402e8,0x00000000}},	//   _neks, clul_, ионъ, --, 
   {{0x33f40276,0x637c00d8,0x85354fdf,0x00000000}},	//   _счес, _gêno, _خونچ, --, 
   {{0xf1bc0313,0x7c740092,0x00000000,0x00000000}},	//   slá_, _የመላው_, --, --, 
   {{0x7d054fe0,0xa3c004af,0x22542085,0xf1bc02fb}},	//   _beks, ्षर_, _مجيب_, plá_, 
   {{0xdd954fe1,0xf1bc0548,0x7d0403b9,0xe2111b44}},	//   басы, qlá_, _ceks, _ابوع, 
   {{0x7d054fe2,0xd0107e89,0x00000000,0x00000000}},	// [21df0] _deks, _بلخ_, --, --, 
   {{0x7d04127b,0xaac402e9,0x09ac0073,0x3ce400d7}},	//   _eeks, هتان, टक्य, ľova_, 
   {{0x7d054fe3,0x25bc011f,0x3ce402f0,0xc0d40092}},	//   _feks, ylul_, žova_, ያያል_, 
   {{0xa9054fe4,0x7d054fe5,0x99d42303,0x00000000}},	//   ابان, _geks, متنا, --, 
   {{0x6d4d4fe6,0x9cc801af,0x00000000,0x00000000}},	//   _iaca, _быра_, --, --, 
   {{0x6d4d4fe7,0x07a406ed,0x17f8007b,0x7d0401d5}},	//   _haca, јакн, ارنة_, _zeks, 
   {{0x6d4d4fe8,0x25bc084c,0x7d054fe9,0x5a38010a}},	//   _kaca, tlul_, _yeks, _йытă, 
   {{0x6d4d4fea,0x6aa80154,0xe1f40b01,0x25bc0356}},	//   _jaca, _করপো, қҳи_, ulul_, 
   {{0x6d4d4feb,0x25bc0de2,0x00000000,0x00000000}},	//   _maca, rlul_, --, --, 
   {{0xa7541345,0x6d4d4fec,0x6d900327,0xd7f80114}},	//   _حضرت, _laca, għaz, _љут_, 
   {{0xb1100521,0x25bd4fed,0x2d98011f,0x016421fa}},	//   _tụle, plul_, kiqe_, акно, 
   {{0x6d4d4fee,0xc0bc001f,0x00000000,0x00000000}},	//   _naca, ደርሱ_, --, --, 
   {{0x764c26b8,0x7d04008c,0x00000000,0x00000000}},	//   _ábyr, _reks, --, --, 
   {{0x91fc0882,0x6d4c03ac,0x387000cc,0x6449236b}},	//   hyāy, _aaca, øyri_, _isgi, 
   {{0x3ebc2242,0x7d054fef,0xfd940006,0x2d98011f}},	//   ætt_, _peks, ашаю, fiqe_, 
   {{0x6d4d4ff0,0x847c0023,0x00000000,0x00000000}},	//   _caca, ንጋርን_, --, --, 
   {{0x6d4c1dcd,0x7d054ff1,0x19580220,0xece4084c}},	// [21e00] _daca, _veks, ғалы_, рдул_, 
   {{0x64480502,0x6d4d4ff2,0xab614ff3,0x29d40327}},	//   _msgi, _eaca, овул, _għaz_, 
   {{0x7d054ff4,0x6d4d4ff5,0xeb94026a,0xa3e400af}},	//   _teks, _faca, јих_, _मूस_, 
   {{0x6d4d4ff6,0x7d04289d,0x323400c8,0x443c0332}},	//   _gaca, _ueks, יטען_, _opw_, 
   {{0xdc840b8d,0x6b90005c,0x00000000,0x00000000}},	//   _уңай, ødgø, --, --, 
   {{0xfb8003e6,0x4ad001d3,0x21e001ec,0x00000000}},	//   _بگری, _کےمط, _ﺍﺟﺎﺭ, --, 
   {{0x6d4c03b4,0xeb954ff7,0x64494ff8,0x9b4400aa}},	//   _yaca, _тир_, _asgi, _پنځو, 
   {{0xfa64044e,0x6d4c0077,0xa3e400e1,0xe9442e07}},	//   _ሰሚናር_, _xaca, _मूह_, _پرفی, 
   {{0x53342ba5,0xa3c00a94,0xb714034c,0xf48462d9}},	//   бепт, ्षं_, _نباش, руйн, 
   {{0x443c009a,0x66e00798,0x2d980240,0x94240022}},	//   _dpw_, _дофа, ziqe_, амҩе, 
   {{0x443c05b1,0x754410d9,0xdb1c007b,0x644803cb}},	//   _epw_, _внез, _bhrú, _esgi, 
   {{0xdb1c01e7,0x76580857,0xa3e400e1,0x3f88031c}},	//   _chrú, _irty, _मूव_, ehbu_, 
   {{0x44e401d9,0x7bcc05b1,0x259001d9,0xdb1c0332}},	//   _اسمٲ, _ohbu, _بٔنز, _dhrú, 
   {{0x6d4d4ff9,0xa3c00882,0x613c037e,0x765800b8}},	//   _saca, ्षः_, _pålæ, _krty, 
   {{0xf2040801,0x2d980113,0xa3b0012d,0xed0400f0}},	//   _тяло, tiqe_, झकर_, иџан, 
   {{0xdb1c00c6,0x2d440020,0x64480042,0x765800b8}},	//   _ghrú, _ሚሌኒየ, _ysgi, _mrty, 
   {{0x7bcc05be,0x69c007ea,0x656c0112,0xfd4c00b8}},	// [21e10] _bhbu, înem, öchi, _jahṛ, 
   {{0xe0d0004b,0x7658cc92,0x2d980240,0x92e803d4}},	//   _غزي_, _orty, siqe_, বৰৰ_, 
   {{0x6d4d4ffa,0xaa643594,0x76580055,0xe9446d5f}},	//   _taca, штак, _nrty, ихдо, 
   {{0x6d4d325c,0x2d9937f6,0x00000000,0x00000000}},	//   _uaca, qiqe_, --, --, 
   {{0x76594ffb,0x91fc0882,0x7afc02d0,0x00000000}},	//   _arty, ryāy, bbpt, --, 
   {{0x5e5400e5,0x1c00000d,0x00000000,0x00000000}},	//   _ائیر, _लौटल_, --, --, 
   {{0xe734052f,0x6f14003a,0x443d4ffc,0x355001e2}},	//   геҙ_, _mdxc, _spw_, ړنيز, 
   {{0x6d90031c,0x8548020f,0x00000000,0x00000000}},	//   għax, узив_, --, --, 
   {{0xb4601cb3,0x00000000,0x00000000,0x00000000}},	//   зкыл, --, --, --, 
   {{0xd7740491,0xdb1c08c2,0xd7e400d4,0x00000000}},	//   _والع, _bhrù, _фіто, --, 
   {{0x29d4031c,0xdb1d4ffd,0x0a3002d3,0xa3e402ab}},	//   _bħax_, _chrù, _ኣሜሪካ, _मूर_, 
   {{0xdb1c00a3,0x443c0332,0x53c84530,0x151800ae}},	//   _dhrù, _tpw_, лгөм_, _نزهة_, 
   {{0x6448014b,0x20041497,0x30e40150,0x00000000}},	//   _usgi, èmi_, _ﺍﯞﻻﻧ, --, 
   {{0xee3400d1,0x00000000,0x00000000,0x00000000}},	//   әнт_, --, --, --, 
   {{0xdb1c1db0,0xd5ac01d3,0x733004da,0xb88002f0}},	//   _ghrù, _سہی_, _رىيا, _čímk, 
   {{0x29d4038f,0x41040116,0x41740133,0x9f840139}},	//   _għax_, _узив, _چاکس, köç_, 
   {{0x3b854ffe,0x80240220,0x3ce54fff,0xa22000ec}},	// [21e20] благ, _ارعم, žovo_, _ارڙه, 
   {{0xc3180154,0x92e803d4,0xfeb8009a,0x00000000}},	//   ত্রি_, বৰী_, _ماجت_, --, 
   {{0x3f980526,0x195801e0,0x00000000,0x00000000}},	//   _impu_, ғаһы_, --, --, 
   {{0xed5c00d0,0xeaac00e5,0xa96401d5,0x00000000}},	//   ážte_, رٹن_, йиха_, --, 
   {{0xe8081533,0xa3e42cfd,0x7afc00b5,0xada0009d}},	//   _सौदा_, _मूल_, pbpt, _хаял, 
   {{0xe3a4ad99,0x9f40004e,0x81ac2b1b,0x76580055}},	//   _رر_, _juià_, কতি_, _prty, 
   {{0x3f9805b1,0x2d840356,0xef10010f,0xfd4c002b}},	//   _mmpu_, _înec_, פּס_, _sahṛ, 
   {{0x9f8402f6,0xf4e40154,0xfd4c00b8,0x13f5032c}},	//   löä_, নর্ব, _pahṛ, озия, 
   {{0x39455000,0x77c82ccb,0x9f40013d,0xdb1c01ab}},	//   meos_, _благ_, _btiü_, _shrù, 
   {{0xeb9c1125,0x39455001,0xa3e40574,0x52140a93}},	//   _hvør_, leos_, _मूळ_, одот, 
   {{0x3cfc0208,0xbb7c0150,0x00000000,0x00000000}},	//   _đtvn_, _ﺤﺠﻤﻪ_, --, --, 
   {{0x7980068f,0x3f9802d1,0x92e80154,0x00000000}},	//   nkow, _ampu_, বরে_, --, 
   {{0x798004cc,0x9f84005b,0xf1e402dd,0xcfe00116}},	//   ikow, köä_, _ﺍﻟﻌﻘ, _ﺋﻮﺭﺗ, 
   {{0xd8e80156,0x925800c2,0xdb1c00a3,0x3944003a}},	//   _སུའི, _вакт_, _thrù, heos_, 
   {{0xdb1c02e2,0x79815002,0x39440309,0xfbbc00cd}},	//   _ikrè, kkow, keos_, ्तनम, 
   {{0x3f980214,0xdd955003,0x7980033f,0x00000000}},	//   _empu_, пасы, jkow, --, 
   {{0x79801afd,0x95140055,0x8c195004,0xc0c00150}},	// [21e30] dkow, _aṅke, شيار_, _жәри, 
   {{0xaa640026,0x7980012d,0x00000000,0x00000000}},	//   йтек, ekow, --, --, 
   {{0x39442b76,0x42a40023,0x28a41de6,0x00000000}},	//   feos_, _ዋንነት_, әшег, --, 
   {{0x9a8405f5,0x39455005,0x7980003e,0x2b5000b5}},	//   чуул, geos_, gkow, sdxc_, 
   {{0x6e240477,0x577400f1,0xf1e40046,0xa3c80b67}},	//   lujb, ړپوړ, _ﺍﻟﻔﻘ, लतम_, 
   {{0xa09c00c8,0x79800210,0x00000000,0x00000000}},	//   ניגט, akow, --, --, 
   {{0xf8ac3bd6,0x394430df,0x7980012d,0x00000000}},	//   _یکه_, beos_, bkow, --, 
   {{0xdb1c1f5d,0x39455006,0x7980033f,0xc48401d5}},	//   _akrè, ceos_, ckow, жлик, 
   {{0xd8380323,0x387005ac,0x21e00220,0xe7280244}},	//   _гэх_, øyrt_, _ﺍﻟﺘﺭ, _مساو_, 
   {{0x290d5007,0x9f6000d7,0x00000000,0x00000000}},	//   laga_, žrút_, --, --, 
   {{0x290c04c9,0x3cf000b5,0x6aa800cc,0x04f40153}},	//   oaga_, ycyv_, _কৰতো, _дзею, 
   {{0x637c0165,0x98a40135,0x15a802e8,0x80cc0a8a}},	//   _mêni, _qamħ_, _лъчи_, _सरदे, 
   {{0xafd84673,0x6e240007,0x290c235a,0x4374405c}},	//   lvøy, eujb, iaga_, _мукт, 
   {{0x290d5008,0xfe88145e,0x7980033f,0x394401a6}},	//   haga_, _ndïä_, zkow, zeos_, 
   {{0x290d5009,0xdda00209,0x7980033f,0x00000000}},	//   kaga_, _öňki_, ykow, --, 
   {{0xa3c02d8f,0x72400f31,0x52753c44,0x3944003a}},	//   ्षक_, _کھیل, _хушу, xeos_, 
   {{0x290d500a,0xada1500b,0x9f8402f6,0x91280150}},	// [21e40] daga_, фатл, töä_, _اسىق_, 
   {{0x61e5500c,0x290c0b23,0x3f99500d,0x79800034}},	//   _hiil, eaga_, _umpu_, wkow, 
   {{0x7980006d,0x61e5500e,0x290d500f,0x9f400120}},	//   tkow, _kiil, faga_, _guiá_, 
   {{0x290d5010,0x61e55011,0x522c008f,0x9f40010e}},	//   gaga_, _jiil, רואַ, _itiñ_, 
   {{0x61e55012,0x3944b1a3,0x79815013,0x96f80395}},	//   _miil, reos_, rkow, белт_, 
   {{0x3944ef5e,0x61e418a6,0x60c55014,0x79815015}},	//   seos_, _liil, _myim, skow, 
   {{0x290d5016,0x39455017,0xe60c07c0,0x637c0120}},	//   baga_, peos_, نشي_, _gêni, 
   {{0x61e444fc,0x290d5018,0x60c49748,0x00000000}},	//   _niil, caga_, _oyim, --, 
   {{0x60c55019,0x7c340925,0xdb1c065c,0xf4b80c58}},	//   _nyim, ntyr, _akré, ুশ্ব, 
   {{0x61e5177a,0x00000000,0x00000000,0x00000000}},	//   _aiil, --, --, --, 
   {{0x61e5501a,0x60c43926,0x326400d6,0xa3a802ab}},	//   _biil, _ayim, ітов, _गदर_, 
   {{0x60c40230,0x61e40014,0x656c002f,0xe5640117}},	//   _byim, _ciil, öcht, _михд_, 
   {{0x60c40230,0x00000000,0x00000000,0x00000000}},	//   _cyim, --, --, --, 
   {{0x290cbe2c,0xdc740020,0x60c402c4,0x9294084c}},	//   zaga_, _አመራር_, _dyim, _налц, 
   {{0x61e5501b,0x60c5501c,0xad08009d,0x00000000}},	//   _fiil, _eyim, ихаж_, --, 
   {{0x1b041d4c,0x61e5501d,0x290c009d,0x7c34036e}},	//   _লাগে_, _giil, xaga_, ftyr, 
   {{0x6eb819e5,0x290d501e,0x637c0798,0x6e240477}},	// [21e50] _शुरु, vaga_, _sêni, sujb, 
   {{0x290d501f,0x637c06ed,0x61e40472,0x00000000}},	//   waga_, _pêni, _ziil, --, 
   {{0x290d5020,0x9f400162,0x61e40067,0x6e240455}},	//   taga_, _itið_, _yiil, qujb, 
   {{0xad24154b,0x61e40009,0x290c000d,0x00000000}},	//   _بردو, _xiil, uaga_, --, 
   {{0x290d5021,0x2d880205,0xdd105c82,0x391000f1}},	//   raga_, _ilce_, _užši, رووز, 
   {{0x290d5020,0x637c0261,0x37240135,0x2edc00cc}},	//   saga_, _têni, _རྐྱལ_, _ব্যষ, 
   {{0x290d5022,0xa9280064,0x00000000,0x00000000}},	//   paga_, _візе_, --, --, 
   {{0x290c036b,0xafd80158,0x00000000,0x00000000}},	//   qaga_, rvøy, --, --, 
   {{0x7b00008e,0x00000000,0x00000000,0x00000000}},	//   _íxtí, --, --, --, 
   {{0x61e55023,0x60c40526,0x4420000d,0x00000000}},	//   _siil, _ryim, _मिठऊ_, --, 
   {{0x61e416b5,0xb38001c0,0x656c0112,0x00000000}},	//   _piil, хлэл, öchs, --, 
   {{0x7c355024,0x644c04ce,0x61e54d26,0xdddc0588}},	//   ytyr, æcis, _qiil, pyrũ, 
   {{0x61e55025,0xb4b400c7,0x55ac010f,0xb6000003}},	//   _viil, _еицә, _דיאַ, ġġen, 
   {{0x61e40050,0x60c407a8,0xdce407f5,0x2d8800d8}},	//   _wiil, _vyim, ljić, _alce_, 
   {{0x61e4e885,0x6458017a,0x00000000,0x00000000}},	//   _tiil, lvui, --, --, 
   {{0xdce40384,0x60c40309,0x9f401d0e,0xf650008f}},	//   njić, _tyim, _etið_, עצן_, 
   {{0x3b855026,0x60c55027,0x7c34062c,0xd1d40092}},	// [21e60] плаг, _uyim, utyr, _የረባ_, 
   {{0x7c355028,0xe7ec0c2e,0xa3c800cd,0x00000000}},	//   rtyr, _चढ़ा_, लति_, --, 
   {{0xe8b407e4,0xbd880451,0x64580108,0x00000000}},	//   _བཙུག, _هندن_, hvui, --, 
   {{0xb4e8069f,0x7c34062c,0x00000000,0x00000000}},	//   _मले_, ptyr, --, --, 
   {{0xa3c8447d,0x2810009f,0x00000000,0x00000000}},	//   लता_, فونس, --, --, 
   {{0x68fc03be,0xa84403cc,0x00000000,0x00000000}},	//   ıqda, سلىم_, --, --, 
   {{0x6b615029,0xaa41502a,0x00000000,0x00000000}},	//   _якра, _перл, --, --, 
   {{0x645801f5,0xf7c80116,0x00000000,0x00000000}},	//   fvui, ﻪﻟﻠﻪ, --, --, 
   {{0x6458017a,0x00000000,0x00000000,0x00000000}},	//   gvui, --, --, --, 
   {{0xfbbc2432,0x00000000,0x00000000,0x00000000}},	//   ्तिम, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa3e41889,0x32000306,0xc79400db,0x06d40154}},	//   _मूक_, ďky_, _ىشەب, _স্কি, 
   {{0x5335502b,0xfbbc1944,0x777801c6,0x00000000}},	//   _желт, ्ताम, _kotx, --, 
   {{0xc444006c,0xa0340137,0x00000000,0x00000000}},	//   _کیین_, رۉپت, --, --, 
   {{0x77782be5,0x38a001a9,0xe3b0008f,0x00000000}},	//   _motx, _fаrg_, _אױס_, --, 
   {{0xb60416a3,0xc0bc0092,0x00000000,0x00000000}},	//   mošć, ደርም_, --, --, 
   {{0xb6041505,0x9f4003b2,0x6cb00022,0xdd943947}},	// [21e70] lošć, _ttið_, хиаӡ, хаты, 
   {{0xf1bc03a0,0xeb986722,0xc2c800cf,0x2fc4004d}},	//   loá_, حضرت_, _ابۇل_, _óng_, 
   {{0xb6040989,0x00000000,0x00000000,0x00000000}},	//   nošć, --, --, --, 
   {{0xf09c0428,0xf1bd502c,0xdb1c007b,0x00000000}},	//   baàt_, noá_, _bhró, --, 
   {{0xdb1d502d,0x777809a0,0x2bc801a9,0x00000000}},	//   _chró, _botx, _гуво_, --, 
   {{0x77780228,0xb6042375,0xa3e40073,0x00000000}},	//   _cotx, košć, _मूग_, --, 
   {{0xf1bc0270,0x7778005a,0x45d4329b,0x00000000}},	//   koá_, _dotx, мцит, --, 
   {{0xb604041a,0x497402d5,0xb8840118,0xd6240137}},	//   došć, _ўлас, _sjíž, رعىي, 
   {{0xd7c8a766,0x74100c8b,0x473407d6,0x64580a73}},	//   _کوله_, نويا, _онас, uvui, 
   {{0x6459502e,0x9a880014,0x98480050,0x637c0051}},	//   rvui, _بنہٕ_, _ڈلہٕ_, _nênt, 
   {{0xb605502f,0x3ce401f1,0x98480014,0x64595030}},	//   gošć, ľovi_, _ولہٕ_, svui, 
   {{0x7778005a,0x3ce400d0,0x625401e1,0xa2d000f1}},	//   _zotx, žovi_, _ṣos, ويښت, 
   {{0x25bd5031,0xe4c87af8,0xbf640633,0x00000000}},	//   moul_, _ابان_, ودسو, --, 
   {{0x637c00d8,0xafe0036b,0x25bcdbd9,0xb884013a}},	//   _cênt, коял, loul_, _ujíž, 
   {{0xafe0425c,0xb22001a8,0x92e82f84,0x38a0022e}},	//   торл, þætt, _عروق_, _tаrg_, 
   {{0x25bd5032,0x637c00d8,0x00000000,0x00000000}},	//   noul_, _vênu, --, --, 
   {{0xb8800f91,0x00000000,0x00000000,0x00000000}},	// [21e80] číko, --, --, --, 
   {{0x25bd5033,0x637c00d8,0x60c0002f,0xd7f40022}},	//   houl_, _tênu, ümmu, ҕзкы, 
   {{0xdb1c1554,0x25bd5034,0x00000000,0x00000000}},	//   _bhrò, koul_, --, --, 
   {{0xdb1c07f0,0xa3cc0073,0x00000000,0x00000000}},	//   _phró, _वीस_, --, --, 
   {{0xb8f4534e,0xdb1c00a3,0x25bd5035,0x777801c4}},	//   _हर_, _dhrò, doul_, _potx, 
   {{0x4b5400a7,0x00000000,0x00000000,0x00000000}},	//   _пъст, --, --, --, 
   {{0xa3e40d62,0x25bc07ab,0x00000000,0x00000000}},	//   _मंज_, foul_, --, --, 
   {{0xb60407f5,0xbf080490,0x5454c5fa,0xdb1c3e79}},	//   vošć, वरुन_, евит, _ghrò, 
   {{0xa8c065c2,0x777822cb,0x644c0381,0x00000000}},	//   _айтд, _totx, æcip, --, 
   {{0xb60407f5,0xa87800d9,0xdb1c00d7,0x00000000}},	//   tošć, _ואמר, _okrí, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x25bc054e,0xb604110c,0xde4c0023,0xe50800f7}},	//   coul_, rošć, _ምልካው, _ۇعۇۇ_, 
   {{0xa3e409d9,0xbf080574,0xd5b80055,0xdb1c02d2}},	//   _मंच_, वरून_, _avāg_, _akrí, 
   {{0xc0c80020,0x53340228,0x5ec8009e,0x06d4015b}},	//   _በጋራ_, _чект, লধনে, _স্টি, 
   {{0x9e355036,0xf1bd1b8c,0x5e580276,0x82440354}},	//   керч, poá_, миря_, _пĕрч, 
   {{0x637c017a,0xb1e00131,0xa1a802dd,0xeff40023}},	//   _fêns, _шәпқ, _отыз_, ላማይ_, 
   {{0x7d0009c2,0x60c0002f,0x00000000,0x00000000}},	// [21e90] ñosa, ümmt, --, --, 
   {{0xdb1c01c3,0x25bc007f,0xea888944,0x00000000}},	//   _shrò, zoul_, يخان_, --, 
   {{0xb50c1d7d,0xdb1c0192,0x25bc007f,0x00000000}},	//   सराय_, _phrò, youl_, --, 
   {{0x99d40472,0xfff40244,0x00000000,0x00000000}},	//   نتنا, _تکێت_, --, --, 
   {{0xe8481870,0x00000000,0x00000000,0x00000000}},	//   تجان_, --, --, --, 
   {{0xb17808cb,0xfcc001e0,0x25bd1de1,0x99648715}},	//   lmåd, _сәсм, woul_, етәл, 
   {{0xfbbc0b33,0xb6f40e26,0x25bd5032,0xdb1c00a3}},	//   ्तरम, رىيا_, toul_, _thrò, 
   {{0xd928030d,0x00000000,0x00000000,0x00000000}},	//   _оцул_, --, --, --, 
   {{0x25bd5037,0x68f89e80,0x675000c7,0xf3f402dd}},	//   roul_, _ifud, _инаӡ, еңі_, 
   {{0x69c95038,0x27fd5039,0x25bd3275,0x57a40075}},	//   llge, _itun_, soul_, _ишха, 
   {{0x69c805e4,0x57a400c7,0x25bd503a,0xa800013d}},	//   olge, _ршта, poul_, _ğıyr, 
   {{0xa3cc9507,0xafd82d8b,0x30840023,0xf65000d9}},	//   _वीर_, ntøf, _ዚመጽእ_, _תצא_, 
   {{0x6569503b,0x044403fb,0xdb1d503c,0x69c80f09}},	//   _ingh, _челн, _skrí, ilge, 
   {{0x442d503d,0x69c803fa,0x00000000,0x00000000}},	//   mue_, hlge, --, --, 
   {{0x442d503e,0xf5440ca8,0x00000000,0x00000000}},	//   lue_, _àṣà_, --, --, 
   {{0x291c013f,0x68f81418,0x3370035b,0x5274007b}},	//   _ndua_, _nfud, _агәр, _جاهز, 
   {{0x65680a2e,0xcdc4035b,0x442d503f,0x6cb00228}},	// [21ea0] _mngh, татқ, nue_, гөрт, 
   {{0x291d5040,0x69c95041,0x68f80337,0x65680ffb}},	//   _adua_, elge, _afud, _lngh, 
   {{0x442d4345,0x27fd5042,0x3ea55043,0x65695044}},	//   hue_, _atun_, _чинг, _ongh, 
   {{0x442c07dd,0xb178049f,0x69c8005c,0x00000000}},	//   kue_, rmåg, glge, --, 
   {{0x7d140a81,0x442d5045,0xe808b213,0x00000000}},	//   mays, jue_, सीला_, --, 
   {{0x7d155046,0x65695047,0x291d5048,0x69c95049}},	//   lays, _angh, _edua_, alge, 
   {{0x442d504a,0x20000113,0xbbbc5cea,0x21200c6a}},	//   eue_, _ltii_, ्तीक, _odih_, 
   {{0x7d15504b,0x442d504c,0x20000381,0x7bdc0254}},	//   nays, fue_, _otii_, lmpu, 
   {{0x442cb0a4,0x7d140175,0x7bdc0254,0xa3c801f9}},	//   gue_, iays, ompu, लतं_, 
   {{0x656800a9,0x7d15504d,0x2120007f,0xa7a40022}},	//   _engh, hays, _adih_, _зкуа_, 
   {{0x2001504e,0x7d14529b,0x442d504f,0xf2c406d3}},	//   _atii_, kays, aue_, эсин, 
   {{0x442c07dd,0x5f94ff23,0x7aec03ac,0xbbbc227c}},	//   bue_, қист, _lgbt, ्तुक, 
   {{0x442d5050,0x7d155051,0xe3ac7ba2,0x00000000}},	//   cue_, days, شری_, --, 
   {{0x91fc0882,0x2120003e,0xfc4c001f,0x7d140076}},	//   tvād, _edih_, _ምርጫው, eays, 
   {{0x65680cfd,0x7d140014,0x2120005c,0x7ea40116}},	//   _yngh, fays, _fdih_, вутҗ, 
   {{0x7d140050,0x7c20003d,0x7bdc0472,0x01c40124}},	//   gays, ġorn, empu, _ирыҭ, 
   {{0xb178007c,0xab840395,0x00000000,0x00000000}},	// [21eb0] rmåd, нужк, --, --, 
   {{0xb178037e,0x69c80067,0x291c036e,0x00000000}},	//   småd, wlge, _sdua_, --, 
   {{0x80a402a6,0x7d155052,0x442d5053,0x69c80083}},	//   _গুপ্, bays, zue_, tlge, 
   {{0x7d1401d9,0x442d5054,0x27fc06d1,0x00000000}},	//   cays, yue_, _ptun_, --, 
   {{0xe10c00c8,0x442d5055,0xafd801bf,0x00000000}},	//   פּאָ, xue_, gtøg, --, 
   {{0x442d5056,0xa3cc0034,0x6568003e,0x9be40006}},	//   vue_, _वीं_, _sngh, _біск, 
   {{0xe8dc0241,0x442c063f,0x98c47c4c,0xd6c40075}},	//   _ibọn_, wue_, ксәл, лишқ, 
   {{0x27fc005a,0xabb00124,0x05655057,0x68f95058}},	//   _ttun_, _раҳә, твин, _ufud, 
   {{0x6d800165,0x27fc00d5,0x199400ee,0x4438003a}},	//   _hõas, _utun_, _сатя, îs_, 
   {{0x442d5059,0xa6e00154,0x823400f2,0x00000000}},	//   rue_, নুষট, پردا, --, 
   {{0x2000084c,0x442d505a,0x7d15505b,0x41280868}},	//   _stii_, sue_, yays, моно_, 
   {{0x442d505c,0x6569505d,0x7d14cd78,0x2a64007c}},	//   pue_, _ungh, xays, änby_, 
   {{0x442d505e,0x7d14014b,0x21200010,0x00000000}},	//   que_, vays, _vdih_, --, 
   {{0x7d15505f,0x03a4390e,0xdb1c0216,0x00000000}},	//   ways, _шило, _okrá, --, 
   {{0x7d155060,0x224401c4,0x7d0009c2,0xf77008d8}},	//   tays, _upnk_, ñoso, סקל_, 
   {{0x12e800c8,0x2000022f,0x013464c8,0x00000000}},	//   _אַפּ, _ttii_, _شعبد, --, 
   {{0x7d14cd76,0x20015061,0xac8000ee,0xa2a801f9}},	// [21ec0] rays, _utii_, агтл, ीअक्, 
   {{0x7d155062,0xb17800b5,0x7c200010,0x7e9800ae}},	//   says, rmåe, šoro, _ينظر_, 
   {{0x39400020,0x7d155063,0x00000000,0x00000000}},	//   _የፌዴራ, pays, --, --, 
   {{0x7d141af4,0x7bdc020c,0x00000000,0x00000000}},	//   qays, smpu, --, --, 
   {{0xe94401ed,0x2d840134,0x00000000,0x00000000}},	//   ئرمی, ɔne_, --, --, 
   {{0xfaa40364,0x8b040198,0xe8dc0241,0x6cb15064}},	//   _ҷаҳо, ƙƙau, _gbọn_, _төст, 
   {{0xfaa4016c,0xafd805ac,0x69f4010a,0x00000000}},	//   _раво, støg, _ансă, --, 
   {{0x1dd801ad,0xfaa401d5,0xaa540066,0x65a4009d}},	//   _भीमत, _заҳо, _جلفا_, ктыг_, 
   {{0xf65016cb,0xdb1c012c,0xb4b000d1,0xa7880150}},	//   ائڻ_, _zkrá, рипә, _ﺒﻠﺩﺓ_, 
   {{0xf364074d,0x00000000,0x00000000,0x00000000}},	//   ттин, --, --, --, 
   {{0xc6840a81,0x00000000,0x00000000,0x00000000}},	//   _مێون_, --, --, --, 
   {{0x6aa0002d,0x201c0055,0x00000000,0x00000000}},	//   únfi, _āvir_, --, --, 
   {{0x752002e3,0x00000000,0x00000000,0x00000000}},	//   _idoz, --, --, --, 
   {{0x326401af,0xde4c0023,0x00000000,0x00000000}},	//   _атив, _ሕልኽል, --, --, 
   {{0x3940001f,0x9e78022e,0x00000000,0x00000000}},	//   _የፌደራ, larª_, --, --, 
   {{0x91d003d4,0xd130007b,0xaf500124,0x00000000}},	//   _সূৰ্, _امة_, ынҳә, --, 
   {{0xdb1c19cf,0x7e7805ac,0x409401d3,0x3cfc0051}},	// [21ed0] _skrá, øtpr, _ملٹر, _đtvt_, 
   {{0x8f5410f5,0xeda4013e,0x00000000,0x00000000}},	//   _свої, хшҳо, --, --, 
   {{0x75215065,0x93840240,0x00000000,0x00000000}},	//   _odoz, _ዝወሰነ_, --, --, 
   {{0x75215066,0xafd8e2ba,0xeb9c3c38,0xdb1c01ef}},	//   _ndoz, stød, _stød_, _vkrá, 
   {{0x48d0015b,0xac10010a,0x00000000,0x00000000}},	//   িশ্র, _тĕле_, --, --, 
   {{0x75215067,0xfd540055,0x00000000,0x00000000}},	//   _adoz, daaṇ, --, --, 
   {{0xb6a05026,0xdb1c26f6,0xc0c80092,0x00000000}},	//   йишл, _ukrá, _በዋስ_, --, 
   {{0x6d5c03ac,0x00000000,0x00000000,0x00000000}},	//   ndqa, --, --, --, 
   {{0x69d802e3,0x00000000,0x00000000,0x00000000}},	//   _ihue, --, --, --, 
   {{0x75215068,0x18b800c7,0xbd640092,0x00000000}},	//   _edoz, _ргуы_, _ዳዊትም_, --, 
   {{0x1638007b,0xe204012d,0x69d80051,0x00000000}},	//   _لسنة_, _ogół_, _khue, --, 
   {{0xd7f010de,0x00000000,0x00000000,0x00000000}},	//   _اكە_, --, --, --, 
   {{0x44295069,0xf4843016,0x434428a8,0x65788e5d}},	//   _ía_, _ماوی, _белв, mjuh, 
   {{0x94744cf2,0x65793003,0xa2c80b4c,0x94d4003b}},	//   _خدما, ljuh, _हडप्, _точц, 
   {{0xc2c414a0,0x4df5506a,0x69d8023a,0x7338008f}},	//   _حيثي, иятт, _ohue, _נעקס, 
   {{0x6579506b,0x443c0784,0xf1b84ea9,0x80a4009e}},	//   njuh, _kqw_, _उदयन, _গুণ্, 
   {{0x5ba46f78,0x2004007b,0x61440b01,0xfca9506c}},	// [21ee0] алағ, ímid_, _беқа, رارو_, 
   {{0x69d801f7,0x28b405b3,0x3098011a,0x6578000d}},	//   _ahue, _आख़ि, _נשימ, hjuh, 
   {{0x69d800c6,0xba24084c,0xee340276,0x6d5c0175}},	//   _bhue, удек, _йнэ_, bdqa, 
   {{0x69d9506d,0x6449506e,0x7f5c022e,0x7d5402bf}},	//   _chue, _opgi, _hapq, _стої, 
   {{0x69d8020c,0x657800c5,0xafd80158,0x00000000}},	//   _dhue, djuh, støe, --, 
   {{0x69d80069,0xdb1d506f,0xda7005d9,0x6db40e04}},	//   _ehue, _skræ, _وڏا_, nćan, 
   {{0x56955070,0x64480024,0x7f5c3af1,0x99a40210}},	//   райт, _apgi, _mapq, ętła_, 
   {{0xacb8019f,0x69d8062c,0x779121a1,0x65795071}},	//   _acûy, _ghue, _گیتا, gjuh, 
   {{0xb46405af,0x00000000,0x00000000,0x00000000}},	//   ادبه, --, --, --, 
   {{0x7f5c0455,0xf2051d3d,0x77903ee6,0x6578035b}},	//   _napq, лямо, _دیتا, ajuh, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdef83088,0xe8080316,0x98a400ac,0xf0741321}},	//   ғыр_, सीका_, _hamı_, гимә_, 
   {{0xa3cc02a0,0xd5840133,0x64a00354,0x00000000}},	//   _वीक_, _مێژه_, _лаца, --, 
   {{0x765804ce,0xd37000c6,0x00000000,0x00000000}},	//   _ksty, _ذهب_, --, --, 
   {{0x92580139,0x00000000,0x00000000,0x00000000}},	//   _райт_, --, --, --, 
   {{0x6ce40220,0x321c44ef,0x00000000,0x00000000}},	//   гізе, msty_, --, --, 
   {{0xa1340137,0x00000000,0x00000000,0x00000000}},	// [21ef0] _ارىش, --, --, --, 
   {{0x76595072,0x6d5c0113,0x98a40205,0xafd8005c}},	//   _osty, sdqa, _namı_, støb, 
   {{0x4a555073,0x321c05da,0x00000000,0x00000000}},	//   ркес, nsty_, --, --, 
   {{0xda08088c,0x25f80034,0x9f6001d3,0x321c0210}},	//   اينه_, _लंबी_, örös_, isty_, 
   {{0x76585364,0x65780037,0x7f5c014f,0x6f14007c}},	//   _asty, vjuh, _yapq, _kexc, 
   {{0x321c0034,0xd7c85767,0x98a40790,0x97d800d4}},	//   ksty_, هونه_, _camı_, льщу_, 
   {{0x69d95074,0x01d40f22,0x76580175,0x0674010b}},	//   _thue, _সংসদ, _csty, руля, 
   {{0xfbf00150,0x22980248,0x228801e1,0x398000e5}},	//   _اۋەج, _láké_, _lòkú_, _ویلف, 
   {{0x99840597,0x76580368,0x437490b1,0x48c402dd}},	//   _القو, _esty, аунт, _тәжа, 
   {{0x1cdc0003,0x657805a7,0x7658010a,0xc244e65c}},	//   རྟི_, sjuh, _fsty, анок, 
   {{0xe3c00228,0x321c4e13,0x7f5c0455,0x00000000}},	//   ирүү, gsty_, _rapq, --, 
   {{0xc0e55075,0x7f5c7769,0xa5e4010b,0xed5c00b8}},	//   ионк, _sapq, _сюзл, _naþ_, 
   {{0x321d4df7,0x2004002e,0x9404009f,0x00000000}},	//   asty_, ëmi_, _هونه, --, 
   {{0x442c7205,0x76580cfd,0x7f5d5076,0x200400e2}},	//   mre_, _ysty, _qapq, īmi_, 
   {{0x22980cad,0x442d5077,0x76590ae4,0x00000000}},	//   _dáké_, lre_, _xsty, --, 
   {{0x442d5078,0xb2b8011a,0x00000000,0x00000000}},	//   ore_, _במצר, --, --, 
   {{0x6db405ce,0x7f5c0724,0xed555079,0xb8800118}},	// [21f00] pćan, _tapq, шот_, řízl, 
   {{0x442d507a,0xeb940124,0xb17812e8,0x00000000}},	//   ire_, аиу_, nmån, --, 
   {{0x442d507b,0x5e6400db,0xb4b0012d,0x00000000}},	//   hre_, _انجە, _ऐश्_, --, 
   {{0x442d507c,0xdb1c049f,0xd5b80055,0x00000000}},	//   kre_, _skrä, _avān_, --, 
   {{0x442d507d,0xed55507e,0x6f140548,0x4bd001ed}},	//   jre_, _тоя_, _yexc, _کےلئ, 
   {{0x442c7214,0x321c033f,0xb8cc00af,0x3dd00042}},	//   dre_, ysty_, _ओइ_, llyw_, 
   {{0x70d00316,0x66000261,0x66c802d2,0x6750029e}},	//   _सर्ल, опја, _rökþ, زخور, 
   {{0x442d507f,0x74695080,0x55740209,0xf5e401ec}},	//   fre_, вров_, сгит, шілм, 
   {{0x442d5081,0x7658033f,0x321c0076,0xd370007b}},	//   gre_, _wsty, wsty_, كهة_, 
   {{0x93795082,0xdb1c0036,0xb6a43ae4,0xb89800b8}},	//   убот_, _ukrä, _кизл, _jaḍā, 
   {{0x442cb6b2,0x321d5083,0x38641f53,0x81c0015b}},	//   are_, usty_, lvor_, ্গন_, 
   {{0x442d5084,0xc0c82295,0x321d5085,0x39455086}},	//   bre_, _በኋላ_, rsty_, nfos_, 
   {{0x38655087,0x9f840008,0x2fc401fb,0x7334185e}},	//   nvor_, töð_, _ưng_, _نىشا, 
   {{0xe2f402dd,0x63800022,0xb89800b8,0x88bc012d}},	//   _кеші_, _ҳгәа, _naḍā, _odśn, 
   {{0x22543b6c,0x9f8401a8,0x00000000,0x00000000}},	//   _نجيب_, röð_, --, --, 
   {{0xdd995088,0x200400cf,0x42900023,0x228801e1}},	//   ашу_, ímic_, _ምሉኣት_, _wòkú_, 
   {{0x6f140548,0xdd955089,0xed5c00b8,0xa068119e}},	// [21f10] _texc, цаты, _vaþ_, _вања_, 
   {{0x38645302,0x9af43b5f,0xea640640,0x388c00e2}},	//   dvor_, ەكەت, ињен, _mērā_, 
   {{0x442d15bc,0xf09c0268,0xdb591196,0x39440042}},	//   zre_, lzà_, шют_, ffos_, 
   {{0x442d508a,0xd5b8002b,0x00000000,0x00000000}},	//   yre_, _svān_, --, --, 
   {{0xdb1c3c12,0xf09d508b,0x9f400137,0x38640158}},	//   _skrå, nzà_, _guió_, gvor_, 
   {{0x442d508c,0xd874221d,0x67440006,0x2058010f}},	//   vre_, تامب, рэдз, יידל_, 
   {{0xcae4015b,0x06080063,0x03fc01e1,0x00000000}},	//   _প্রফ, ћник_, _ìjẹm, --, 
   {{0x91fc0882,0xa3cc0490,0xdeb80375,0x00000000}},	//   tvān, _वीज_, יפוח_, --, 
   {{0x442d508d,0x290c0810,0x53b407d0,0xe7740014}},	//   ure_, mbga_, ुवंश, _پلاں_, 
   {{0x442d508e,0x290c01a9,0x9f8401f4,0x00000000}},	//   rre_, lbga_, löö_, --, 
   {{0x442d508f,0xe6b04e5c,0xb17810d1,0x26c00194}},	//   sre_, _بلاگ, rmån, _âjo_, 
   {{0xacb80086,0x568c00c8,0xb17826cc,0x741002cb}},	//   _adûm, _שטאַ, smån, _کووا, 
   {{0xb1781512,0x94d40354,0x00000000,0x00000000}},	//   mmål, _доцц, --, --, 
   {{0x4f955090,0xb178713c,0xed5401e0,0xa3cc0118}},	//   орсу, lmål, ҙоу_, _वीच_, 
   {{0x38655091,0xddf8008e,0x6ce40116,0x00000000}},	//   zvor_, рьгә_, ەزلە, --, 
   {{0x6da15092,0xada15093,0x4094f086,0x0d982de5}},	//   писа, пасл, _грот, атуы_, 
   {{0x249c1711,0xd14800cf,0xeb9c03cd,0xb6000327}},	// [21f20] nzum_, _ئشىن_, _støa_, ġġin, 
   {{0xafd80162,0x00000000,0x00000000,0x00000000}},	//   ltøn, --, --, --, 
   {{0xb17848a1,0xfaa80214,0x00000000,0x00000000}},	//   kmål, دهاي_, --, --, 
   {{0x38642d2b,0x1d780092,0x91fc0a88,0x00000000}},	//   tvor_, _አለቆች_, dvāl, --, 
   {{0xb1781347,0x39455094,0x2b8c0205,0xb898002b}},	//   dmål, rfos_, _bıcı_, _taḍā, 
   {{0x38655095,0xbb8400c6,0x00000000,0x00000000}},	//   rvor_, _الآي, --, --, 
   {{0xf09d4849,0x249c000f,0x388c030a,0xdb1c0030}},	//   zzà_, ezum_, _sērā_, _okrú, 
   {{0x388c0325,0x9f400165,0xd5b0007b,0x00000000}},	//   _pērā_, _muiñ_, ظفة_, --, 
   {{0x8d8c001f,0xe3ac8e33,0x539812e7,0x249c0139}},	//   _ዘገባው_, کري_, ивия_, gzum_, 
   {{0x388c00da,0xe73400d8,0x00000000,0x00000000}},	//   _vērā_, _геф_, --, --, 
   {{0xc7640a52,0x388c0374,0x7544537c,0x0df0001f}},	//   _باقى, _wērā_, _гнез, ግለፅ_, 
   {{0x388c1f4c,0x7c355096,0xb9d00023,0xf09c00cf}},	//   _tērā_, kuyr, _ድኻ_, tzà_, 
   {{0x4290044e,0x7bcc00b5,0x3384009d,0x6ab401f9}},	//   ምልከት_, _okbu, _гуйв, _ॅड्र, 
   {{0x929414a4,0xf09c42bc,0x2004004e,0x00000000}},	//   _малц, rzà_, ímia_, --, 
   {{0xceb81a98,0x00000000,0x00000000,0x00000000}},	//   рәп_, --, --, --, 
   {{0x7bcc08a9,0xeff55097,0x2280a0d5,0x32ec03b9}},	//   _akbu, ዋማይ_, _хушг, məy_, 
   {{0x52c4004b,0x7c340022,0xf1a802f2,0x9f840037}},	// [21f30] _دښکل, guyr, _لاکه_, vöö_, 
   {{0xdea429a4,0x94f8025c,0x2d980200,0x00000000}},	//   _کیفی, _པུའི_, shqe_, --, 
   {{0x9f8400af,0xdcf4c6da,0x249c003a,0x290c022e}},	//   töö_, _çağa, zzum_, tbga_, 
   {{0x8f5404fb,0x7bcc01e4,0x9e8403e6,0x00000000}},	//   _انگش, _ekbu, _راپۆ, --, 
   {{0xb17801e3,0x00000000,0x00000000,0x00000000}},	//   vmål, --, --, --, 
   {{0xc68801c6,0x290c922f,0x9f84000d,0xf4b000cc}},	//   ийлж_, sbga_, söö_, _চৰ্ব, 
   {{0x81c00729,0xb178a075,0x9ad4007b,0x89d80066}},	//   ্গত_, tmål, _فتفض, _نوآر_, 
   {{0x6b840007,0x959801e0,0x84290e16,0x00000000}},	//   _hojg, йтыу_, ажив_, --, 
   {{0x69c95098,0xb1783c12,0x76b4151e,0x2bbc00dc}},	//   moge, rmål, йләр_, ्वपा, 
   {{0x42255099,0xb1780a64,0xdb1c0ad9,0x69c872a1}},	//   одов, smål, _skrú, loge, 
   {{0xb1793721,0x09b400c8,0xf48404fb,0x361801b9}},	//   pmål, ַפֿט_, مایی, _نرنگ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9f4002d2,0xafd801bf,0xbfe000c7,0x00000000}},	//   _buið_, rtøn, ҟәҩҩ, --, 
   {{0x69c9509a,0xafd80b34,0x32ec0213,0xeb9c01bf}},	//   hoge, støn, bəy_, _støn_, 
   {{0x2bbc17c6,0x8e74005b,0xf770011a,0x32ec06be}},	//   ्वना, путч, וקם_, cəy_, 
   {{0x69c80a49,0xee340276,0xafd803b2,0xe6240208}},	//   joge, юнс_, ltøl, _đổ_, 
   {{0x69c9509b,0x3b84339e,0x6b840810,0x49f4031c}},	// [21f40] doge, олаг, _bojg, _བཤུལ_, 
   {{0xdce404ac,0x6b840369,0x9f400165,0x70500244}},	//   ndiĉ, _cojg, _tuiñ_, _کنیا, 
   {{0x69c9509c,0x5f880014,0x1ee8598f,0xed5c0118}},	//   foge, _نٕکہ_, _دودی_, ážce_, 
   {{0x69c9509d,0xfd10007b,0x3d340553,0x00000000}},	//   goge, _تجد_, _بعدس, --, 
   {{0xe8f40b8d,0x4c3405f5,0x00000000,0x00000000}},	//   әлә_, _нэрт, --, --, 
   {{0x6b840007,0x81c0015b,0xf09004ae,0x6d480254}},	//   _gojg, ্গি_, ונד_, õgav, 
   {{0x69c9509e,0x41c80aa2,0x00000000,0x00000000}},	//   boge, रवास, --, --, 
   {{0x69c9509f,0xd5b800dc,0x3424119e,0x00000000}},	//   coge, _tvām_, офов, --, 
   {{0xb864397a,0x81c00eac,0x37540344,0xd6c4072d}},	//   _بازو, ্গা_, _وپرس, _کمای, 
   {{0x77900502,0x2bbc0b7c,0xa3e40640,0xafd806ea}},	//   _زیبا, ्वया, одња_, gtøl, 
   {{0x69c00789,0x78a002f0,0x20040162,0x00000000}},	//   éneg, lzov, ímin_, --, 
   {{0xa1941fe2,0x798150a0,0x3f980171,0xe57430c7}},	//   даюч, njow, _alpu_, _мзх_, 
   {{0x78a150a1,0x2bbc859c,0xb600031c,0x00000000}},	//   nzov, ्वमा, ġġun, --, 
   {{0x69c950a2,0x78a0006f,0xd90400f1,0x00000000}},	//   zoge, izov, _ڼی_, --, 
   {{0x69c950a3,0x7c241f53,0xdef406a6,0x00000000}},	//   yoge, _avkr, дпры, --, 
   {{0x3f989407,0x2bbc0882,0xafd805ac,0xc44402f2}},	//   _elpu_, ्वभा, mtøm, _بیین_, 
   {{0x69c950a4,0x78a00b4b,0xd5b80055,0x7980025c}},	// [21f50] voge, jzov, _avāk_, djow, 
   {{0x69c82252,0x78a150a5,0x9e3400ec,0x7980012d}},	//   woge, dzov, _ڪوٽڙ, ejow, 
   {{0x69c8e4f5,0x2bbc1bd6,0x00000000,0x00000000}},	//   toge, ्वबा, --, --, 
   {{0x5974004e,0x00000000,0x00000000,0x00000000}},	//   дышу, --, --, --, 
   {{0x6d4c02d0,0xfb741c3e,0x00000000,0x00000000}},	//   _ibca, تپەگ, --, --, 
   {{0x69c950a6,0x00000000,0x00000000,0x00000000}},	//   soge, --, --, --, 
   {{0xb7840166,0x00000000,0x00000000,0x00000000}},	//   чәте_, --, --, --, 
   {{0xc4840faa,0xafd801bf,0x78a001a9,0x7980012d}},	//   злик, dtøm, bzov, cjow, 
   {{0x5ae80c99,0xdce401e4,0x78a000d7,0x00000000}},	//   _འཛོམ, tdiĉ, czov, --, 
   {{0xf8ac05ae,0x64580810,0x00000000,0x00000000}},	//   _حکم_, rwui, --, --, 
   {{0xd7c8006c,0x6d4c33c8,0x42540138,0xafd80162}},	//   _بوله_, _obca, чтпт, rtøl, 
   {{0xafd82dcb,0xeb9c2dba,0xc19800d4,0x00000000}},	//   støl, _støl_, стої_, --, 
   {{0xb4f80302,0x15b00150,0x059402f2,0x00000000}},	//   _הפני, _جەيس, _واڵگ, --, 
   {{0x6d4c0363,0x9f58ffea,0x8eac00cc,0xafa000c7}},	//   _abca, _özün_, _গড়গ, еқьқ, 
   {{0x5ae80135,0x78a00306,0x6d4d50a7,0xf770010f}},	//   _འཛེམ, zzov, _bbca, עקל_, 
   {{0xafd801bf,0x00000000,0x00000000,0x00000000}},	//   ntøj, --, --, --, 
   {{0x6d4c02b9,0x61e4379d,0xada03298,0x6da150a8}},	// [21f60] _dbca, _ihil, хатл, хита, 
   {{0x60c402b9,0x6d4ce047,0x0ba803cc,0x6b600116}},	//   _ixim, _ebca, يالى_, нкуа, 
   {{0x61e550a9,0x6d4c0175,0xafd8005c,0x5de401af}},	//   _khil, _fbca, ktøj, _ойоғ, 
   {{0x78a002f0,0xdce4025c,0x00000000,0x00000000}},	//   tzov, ndiċ, --, --, 
   {{0x61e40bec,0xafd801bf,0x00000000,0x00000000}},	//   _mhil, dtøj, --, --, 
   {{0x78a00c53,0xf0900a1e,0x00000000,0x00000000}},	//   rzov, ענג_, --, --, 
   {{0x9f48110e,0x91fc0aed,0x61e49665,0x68400116}},	//   óhùn_, rvāk, _ohil, _үнса, 
   {{0x2ab80302,0x60c550aa,0xfaa41086,0x6a80a229}},	//   _המלא, _oxim, _даҳо, _ялса, 
   {{0x3a38038f,0xa5040640,0xb17801bf,0x00000000}},	//   lupp_, чења_, småk, --, 
   {{0xe44c0491,0x61e550ab,0xc7640136,0x00000000}},	//   اضي_, _ahil, _يالى, --, 
   {{0x61e550ac,0x2bbc07b7,0x60c550ad,0x7dd80549}},	//   _bhil, ्वता, _axim, eïsm, 
   {{0x61e550ae,0x23980092,0xf5e80108,0xdef80022}},	//   _chil, _ሕገወጥ_, _умел_, ҧыс_, 
   {{0x61e550af,0xafd805ac,0x00000000,0x00000000}},	//   _dhil, støm, --, --, 
   {{0x61e550b0,0x64440311,0x60c4010a,0x3a3811ad}},	//   _ehil, ăjit, _dxim, kupp_, 
   {{0x60c550b1,0x61e4327f,0xafd8022c,0xb63c037e}},	//   _exim, _fhil, ltøk, _ａｆ_, 
   {{0x61e467de,0x5d6400a7,0x00000000,0x00000000}},	//   _ghil, нтуз, --, --, 
   {{0xafd80579,0x60c40472,0x5ae8031c,0x6d48022e}},	// [21f70] ntøk, _gxim, _འཛུམ, еgar, 
   {{0x61e40200,0x0ed40073,0x2bbc00cd,0x00000000}},	//   _zhil, _धडपड, ्वधा, --, 
   {{0x6d480037,0x8f5401d3,0xd9e801f9,0x00000000}},	//   õgas, _فنکش, _ओळखत_, --, 
   {{0x4c9401c6,0xafd81445,0x61e4036e,0x6d4c03ac}},	//   _жимс, ktøk, _xhil, _ubca, 
   {{0xd7140154,0x2bbc00cd,0x7c380171,0x00000000}},	//   _সাড়া_, ्वदा, _ātrg, --, 
   {{0x2d882ce2,0xafd80158,0x3a4401f4,0x00000000}},	//   _hoce_, dtøk, öppö_, --, 
   {{0x6b80008c,0xfd4c0055,0x6e2403cd,0x2d8815c0}},	//   öngu, _abhṛ, nsjb, _koce_, 
   {{0x2d8950b2,0x00000000,0x00000000,0x00000000}},	//   _joce_, --, --, --, 
   {{0x2d8823e0,0xafd89e56,0x68f86206,0x00000000}},	//   _moce_, rtøj, _igud, --, 
   {{0x61e550b3,0x291c02b5,0x2d880005,0xeb9c037e}},	//   _shil, _heua_, _loce_, _støj_, 
   {{0x61e41be9,0xd7c804d3,0x2a60003e,0xafd8005c}},	//   _phil, _عومه_, _jsjb_, ptøj, 
   {{0x2d8950b4,0x61e402d1,0x27fd2e0c,0x00000000}},	//   _noce_, _qhil, _kuun_, --, 
   {{0x61e406d6,0x81c000bd,0x4dc404c5,0x7ce400b0}},	//   _vhil, ্গল_, ্ষাং, _kōrū, 
   {{0x823401b9,0x672150b5,0x61e420c6,0x27fc049b}},	//   _قربا, nanj, _whil, _muun_, 
   {{0x0204006c,0x61e550b6,0x7ce400b0,0x68f8877b}},	//   _ўзин, _thil, _mōrū, _ogud, 
   {{0x291c01d4,0x2d8950b7,0x61e403c1,0x23640158}},	//   _neua_, _coce_, _uhil, _hanj_, 
   {{0x672150b8,0x2d886899,0xbfc550b9,0x27fc198f}},	// [21f80] kanj, _doce_, _обик, _nuun_, 
   {{0xd9b81b76,0x38a0022e,0x3a380162,0x7c380171}},	//   ेक्ट, _mаrt_, tupp_, _ātrd, 
   {{0x23640fb7,0x2d8950ba,0x7dd80227,0x39442e70}},	//   _manj_, _foce_, nïsk, днег, 
   {{0x2d88821e,0x20000418,0x3a3950bb,0x23653513}},	//   _goce_, _kuii_, rupp_, _lanj_, 
   {{0x260150bc,0x672150bd,0x212150be,0x7d140393}},	//   _año_, fanj, _meih_, mbys, 
   {{0x31b92877,0x7dd80227,0x20000418,0x68f83c05}},	//   _उद्ध, kïsk, _muii_, _egud, 
   {{0x291d50bf,0xaa4550c0,0x88bc033f,0x7c3403ac}},	//   _feua_, _опра_, _odśw, lryr, 
   {{0xafd8022c,0x68f80083,0x21200109,0x09c8012c}},	//   ttøk, _ggud, _neih_, िकृय, 
   {{0x13f550c1,0x68400075,0x26000124,0x27fc058a}},	//   нзия, _инта, _eño_, _guun_, 
   {{0xafd80579,0x68f80276,0x27040de2,0xe7041b12}},	//   rtøk, _zgud, _gёn_, _قسمی, 
   {{0x212000ad,0x777801c6,0xf2c4011b,0xeb9c0174}},	//   _beih_, _intx, ьсин, _støk_, 
   {{0x20000083,0xafd8022c,0xdb1c0037,0x92e40790}},	//   _buii_, ptøk, _akrü, _ışıl, 
   {{0xdb1d50c2,0x2d880316,0x21200399,0x23640007}},	//   _skrý, _roce_, _deih_, _fanj_, 
   {{0x23640369,0x2000e775,0x7c3406d9,0xef640107}},	//   _ganj_, _duii_, dryr, ӯъҳо, 
   {{0x212150c3,0x2bbd50c4,0x2d880cf4,0x7c34000f}},	//   _feih_, ्वसा, _poce_, eryr, 
   {{0x2364e3ec,0x7d1405e4,0x212150c5,0x7c34036e}},	//   _zanj_, gbys, _geih_, fryr, 
   {{0x2d8950c6,0xf1bc0232,0x672150c7,0x200150c8}},	// [21f90] _voce_, mná_, yanj, _guii_, 
   {{0x9b743306,0xf1bc0e96,0x291c00f7,0x68f808c2}},	//   َالص, lná_, _seua_, _sgud, 
   {{0x2d88011c,0xdb1c02fb,0xf1bc0429,0xc9542e70}},	//   _toce_, _ukrý, oná_, етлы, 
   {{0x6720806e,0x777801c0,0x764800b5,0x2d8816b8}},	//   wanj, _antx, dtfy, _uoce_, 
   {{0x67201326,0xf1bc0093,0x5c0550c9,0xd8b82bd8}},	//   tanj, iná_, _аяса, ودها_, 
   {{0xf1bc9655,0x00000000,0x00000000,0x00000000}},	//   hná_, --, --, --, 
   {{0x672150ca,0xf1bc0122,0x291d50cb,0x2364022e}},	//   ranj, kná_, _teua_, _ranj_, 
   {{0x236550cc,0xf1bc04bf,0x777801c4,0xdce41b5c}},	//   _sanj_, jná_, _entx, zdič, 
   {{0xf1bc076f,0x212150cd,0x630000d1,0x00000000}},	//   dná_, _reih_, نۈشل, --, 
   {{0x21200399,0x9cd80375,0x67210a09,0x00000000}},	//   _seih_, ווחה_, qanj, --, 
   {{0x236550ce,0xfbd00302,0x88bc00cd,0x7d140118}},	//   _vanj_, רתי_, _deśe, ybys, 
   {{0x569550cf,0xd5740124,0x20000311,0x73300131}},	//   _шахт, _аушь, _puii_, نىۋا, 
   {{0x25bc00a8,0x212002a4,0x2000026c,0x439402d5}},	//   mnul_, _veih_, _quii_, _падс, 
   {{0x2d8d50d0,0xe8dc0521,0x212150d1,0x81c0009e}},	//   ögen_, _arịa_, _weih_, ্গই_, 
   {{0xf1bd50d2,0x25bc0276,0x21200076,0x7ce800e5}},	//   bná_, onul_, _teih_, köré, 
   {{0xf1bd50d3,0x20001132,0x25bcd99c,0x016400d8}},	//   cná_, _tuii_, nnul_, _чкио, 
   {{0x25bc0548,0x00000000,0x00000000,0x00000000}},	// [21fa0] inul_, --, --, --, 
   {{0x7d140cfd,0x8c08045e,0x6c300597,0x7c34736e}},	//   sbys, _লিখন_, افلا, rryr, 
   {{0xdb1c0034,0x3dc000b5,0x25bc0118,0x6cc802dd}},	//   _skró, _tjkw_, knul_, _ﺒﻜﺜﻴ, 
   {{0xb8640fb4,0x7c340455,0xaa54007b,0x00000000}},	//   فاتو, pryr, علنا_, --, 
   {{0x69c0004a,0x25bc0118,0x2bbc17c6,0xd5b01888}},	//   énea, dnul_, ्वशा, یفت_, 
   {{0xf1bc04bf,0x764801e6,0x25bc01a4,0xac64010b}},	//   zná_, ttfy, enul_, _яҗуҗ_, 
   {{0x2bbc0a94,0x6db401fa,0xdb1c0034,0xf1bc102c}},	//   ्वरा, mćar, _wkró, yná_, 
   {{0xacb808e7,0x25bc0311,0xf1bc0030,0x545400d1}},	//   _idûr, gnul_, xná_, ввит, 
   {{0xf1bc6b07,0x89a80050,0x764826cc,0xb77800b8}},	//   vná_, _تھلہ_, stfy, _nqṇā, 
   {{0x25bd50d4,0x777801c4,0x91fc00e2,0xa85400d9}},	//   anul_, _untx, kvāt, _אימה_, 
   {{0xf1bc03c6,0x363452d4,0xe7380014,0xe734e06a}},	//   tná_, _سراس, _رتٕچ_, _чех_, 
   {{0xf5e800ee,0x00000000,0x00000000,0x00000000}},	//   _эмел_, --, --, --, 
   {{0xf1bc03c6,0x612801c0,0xb178007c,0x00000000}},	//   rná_, эцэг_, dmåt, --, 
   {{0xe47805e1,0xf1bc0232,0xceb88dcb,0xb8a00020}},	//   _מרדכ, sná_, дәм_, _ገልጿል_, 
   {{0xf1bc0232,0xade400a7,0x00000000,0x00000000}},	//   pná_, ецак, --, --, 
   {{0x63800588,0x75200100,0xf1bc0548,0x00000000}},	//   _агәа, _jeoz, qná_, --, 
   {{0xe7e0012c,0x7bc80427,0x2bbc11bc,0x00000000}},	// [21fb0] गतमा_, čfun, ्वला, --, 
   {{0x752000d8,0x09c817c6,0x00000000,0x00000000}},	//   _leoz, िक्य, --, --, 
   {{0x7ce801d3,0xe8dc0208,0x25bc02f0,0x8c080154}},	//   töré, _trịa_, ynul_, _লিওন_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xacb80428,0x6d5d50d5,0x5ce40600,0x273c0092}},	//   _edûr, meqa, _бюра, _ባቀረበ, 
   {{0x6d5d4d27,0xb1780267,0x98147b8f,0x00000000}},	//   leqa, llåd, ابنا, --, 
   {{0x58840588,0x36640801,0x752001a9,0x5a38010a}},	//   _ҩыуа, ващо_, _beoz, _пытă, 
   {{0x6d5c0680,0xf8ac2832,0x25bc0276,0xb178007c}},	//   neqa, حکہ_, unul_, nlåd, 
   {{0x25bc084c,0x5648044e,0x00000000,0x00000000}},	//   rnul_, _ዘይክእ, --, --, 
   {{0x437550d6,0x61bc00dc,0x6d5c0194,0xb178007c}},	//   туит, ोक्ष, heqa, hlåd, 
   {{0xe0fc1e81,0x6d5d50d7,0xb4e000db,0x25bc0118}},	//   _དཔྱད_, keqa, çàri, pnul_, 
   {{0x75200998,0x7af9271d,0x6d5cc069,0x2d8c0112}},	//   _geoz, _útte, jeqa, ögel_, 
   {{0x6d5cd5f5,0x656801ab,0x442804cc,0x044400d8}},	//   deqa, _iagh, _ìa_, _релн, 
   {{0x656950d8,0xdc981772,0x752001c6,0x6448022e}},	//   _hagh, _ግርማይ_, _zeoz, _iqgi, 
   {{0x6d5c20ac,0xb1780728,0xd5b800b8,0x00000000}},	//   feqa, flåd, _tvāt_, --, 
   {{0xfce48807,0x656950d9,0x91fc0aed,0x6d5c20ac}},	//   вобо, _jagh, rvāt, geqa, 
   {{0xb17893e0,0x3dd00142,0x3fe4119e,0x00000000}},	// [21fc0] rmåt, royw_, _ижив, --, 
   {{0x656950da,0xb178168c,0x9f4c02f6,0xdb2403e6}},	//   _lagh, småt, ödä_, اوای, 
   {{0x3ea550db,0x6d5c0107,0x91fc005f,0x8fc400c6}},	//   _ринг, beqa, lvār, _حزين, 
   {{0x656950dc,0x6d5c208d,0x3f880960,0xb1787c1d}},	//   _nagh, ceqa, ljbu_, lmår, 
   {{0x91fc00da,0xf7e833f9,0x68404a48,0xb17801bf}},	//   nvār, ورتى_, инца, slåg, 
   {{0x244804ce,0xafd832b8,0x656950dd,0xeb9c28b3}},	//   døm_, støv, _aagh, _støv_, 
   {{0x656950de,0xacb8004a,0x3ad401e2,0x68340023}},	//   _bagh, _jeûn, _شيرز, _ኣይርድ, 
   {{0x7bdd50df,0x65680731,0x39406066,0x00000000}},	//   llpu, _cagh, _øks_, --, 
   {{0x656950e0,0x91fc00e2,0x3d18000d,0xf484013d}},	//   _dagh, jvār, _बभने_, туйн, 
   {{0xb4e0177c,0x65681368,0x75200472,0xc76438eb}},	//   _धरी_, _eagh, _weoz, _مامى, 
   {{0x656950e1,0x6d5c379d,0x7520e30c,0x675401ed}},	//   _fagh, yeqa, _teoz, _شیٹس_, 
   {{0x656800b4,0x6464f4b5,0x00000000,0x00000000}},	//   _gagh, äriä, --, --, 
   {{0x6d5c0af5,0xe3ad50e2,0x88bc0882,0xb17801e6}},	//   veqa, صری_, _keśa, vlåd, 
   {{0x656950e3,0x6d5c014b,0x76580055,0x92e000cc}},	//   _zagh, weqa, _kpty, _থলী_, 
   {{0x6d5c32ff,0xbb6800b5,0xdeb41e76,0xb1780267}},	//   teqa, _outケ_, абры, tlåd, 
   {{0x6d5c013c,0x7bdc5d2e,0x622000db,0x46b400af}},	//   ueqa, elpu, _ئىيل, _अइसह, 
   {{0x6d5d50e4,0x0b78013e,0xb17801e3,0x00000000}},	// [21fd0] reqa, нбаъ_, rlåd, --, 
   {{0x6d5c0af5,0x76580034,0x5b1402bf,0xb1780267}},	//   seqa, _opty, имут, slåd, 
   {{0xce9550e5,0x6d5c0869,0xb1780267,0x63ac00db}},	//   _санъ, peqa, plåd, ècni, 
   {{0x6d5c013c,0xb178007c,0xed4c00e5,0xb4e001f9}},	//   qeqa, blåe, _گھڑ_, _धरू_, 
   {{0x656950e6,0x765805e4,0x00000000,0x00000000}},	//   _ragh, _apty, --, --, 
   {{0x656950e7,0xed4c00e5,0x00000000,0x00000000}},	//   _sagh, _دھڑ_, --, --, 
   {{0x65687004,0x88bc0882,0x45d40c56,0x1a694db6}},	//   _pagh, _deśa, лцит, _لیلی_, 
   {{0xc87805d1,0x6568016d,0x056401b9,0x1994014b}},	//   _ayşe_, _qagh, увин, _кася, 
   {{0x656950e8,0x199484cf,0x00000000,0x00000000}},	//   _vagh, _татя, --, --, 
   {{0x244930b6,0x656950e9,0x242405f5,0x76580175}},	//   røm_, _wagh, нхүү_, _fpty, 
   {{0x656950ea,0xf48523dd,0x24482b96,0xa6500244}},	//   _tagh, نایی, søm_, _ئێعت, 
   {{0x656801c3,0x959400f3,0x00000000,0x00000000}},	//   _uagh, _вршљ, --, --, 
   {{0xad991c67,0x91fc0882,0x00000000,0x00000000}},	//   _miúd, tvār, --, --, 
   {{0x442d50eb,0xafd81445,0x74980a7c,0x6d48007f}},	//   mse_, dtøs, _ריספ, ògan, 
   {{0x442d50ec,0xd5ac066d,0x63a00194,0x5348030d}},	//   lse_, _رہی_, _ilnn, _шăрă, 
   {{0x442d50ed,0x69c001ed,0x7ed40137,0x00000000}},	//   ose_, énel, _ۅزجا, --, 
   {{0x70740597,0x705000ec,0x00000000,0x00000000}},	// [21fe0] _مميز_, _هنيا, --, --, 
   {{0x3ce401e4,0xc0c80092,0xd884085b,0x00000000}},	//   ĥov_, _ሠላሳ_, یهای, --, 
   {{0x442d50ee,0xb178037e,0x8ad40953,0x38bc00e4}},	//   hse_, slåe, аюцц, kârô_, 
   {{0x442d50ef,0xafd950f0,0xeb9c318c,0x00000000}},	//   kse_, støt, _støt_, --, 
   {{0x442d50f1,0xb4e005f9,0x63a00083,0xe94417a5}},	//   jse_, _धरे_, _olnn, ارمی, 
   {{0x442d50f2,0xafd80ac8,0x56940588,0xe3a4166b}},	//   dse_, ltør, иалт, _طر_, 
   {{0xfaa43461,0x442d50f3,0x499001d3,0x88bc002b}},	//   _саво, ese_, _ڈیلر, _veśa, 
   {{0x442d50f4,0xafd808cb,0xad98007b,0xaee00055}},	//   fse_, ntør, _giúd, _amṛd, 
   {{0x442d50f5,0x92e02b1b,0xb7e400c7,0x56480023}},	//   gse_, _থলে_, _бжак, _ዘይኽእ, 
   {{0x394550f6,0x53340063,0x4ad80073,0x00000000}},	//   lgos_, јент, _बुडव, --, 
   {{0x442d50f7,0xafd800ed,0x63a001ab,0x394400c0}},	//   ase_, ktør, _dlnn, ogos_, 
   {{0x394550f8,0x442d047b,0xa504010a,0xade0000d}},	//   ngos_, bse_, _беца_, _कींन_, 
   {{0x88bc0034,0x39440eab,0xafd801bf,0x2ce000bc}},	//   _leśn, igos_, dtør, _खरेल_, 
   {{0x63a00076,0xacb80129,0xe4f8011a,0x2cbc00c0}},	//   _glnn, _deûl, _נפגש, _žudo_, 
   {{0x59d417c6,0x3864002f,0x4ad8000d,0x99780153}},	//   धकार, hwor_, _बुढव, nčų_, 
   {{0xf1240212,0xdd9000d1,0x00000000,0x00000000}},	//   _сько, كۈپ_, --, --, 
   {{0x69c150f9,0xc0c004a9,0x394550fa,0x00000000}},	// [21ff0] énem, _дәри, dgos_, --, 
   {{0x394550fb,0x8f540212,0xca4c02dd,0x00000000}},	//   egos_, _твої, _ﺃﻤﺭ_, --, 
   {{0x442c0bbc,0x5fdc0375,0xdb0801d3,0xafd812e8}},	//   zse_, _אחזק, ólás, trøf, 
   {{0x442d50fc,0x6fd8003a,0x00000000,0x00000000}},	//   yse_, rîcu, --, --, 
   {{0x442d50fd,0xca4c02dd,0x92e000cc,0x00000000}},	//   xse_, _ﺃﺤﺩ_, _থলো_, --, 
   {{0x394402d5,0x442d50fe,0x23b801e1,0xdb1c5f47}},	//   agos_, vse_, _májè_, _skrö, 
   {{0x46a401a9,0x00000000,0x00000000,0x00000000}},	//   райв, --, --, --, 
   {{0x38640086,0x2bbc2e35,0x7af950ff,0xafd875f9}},	//   bwor_, ्वका, _útta, brøg, 
   {{0x69d889e7,0x442d5100,0xad9800a2,0xd838009d}},	//   _ikue, use_, _giúe, _бэх_, 
   {{0xd3a40220,0xfc5c001f,0x03955101,0xafd8072b}},	//   йлық, ገልፃለ, ррия, nrød, 
   {{0x88bc00b8,0x823400e5,0x00000000,0x00000000}},	//   _keśo, جرخا, --, --, 
   {{0x442d5102,0x41b400f7,0xf4847e2c,0xafd812ed}},	//   pse_, рсот, _چاوی, hrød, 
   {{0x15f41c40,0xf48403e6,0x442d5103,0x644c00db}},	//   _اسلح, _ناوی, qse_, àcid, 
   {{0x7fd40046,0x741003e6,0x39455104,0xbf1400ae}},	//   рімі, _بووا, zgos_, شورب, 
   {{0x394402d5,0x7db55105,0x69d95106,0xafd812ed}},	//   ygos_, асац, _okue, ttør, 
   {{0x4ad82450,0x62840108,0x00000000,0x00000000}},	//   _बुधव, äjou, --, --, 
  
   {{0x5ba41b74,0xafd922c5,0xfaf820d3,0x6da00713}},	// [22000] блағ, rtør, چراغ_, цита, 
   {{0x69d80af5,0xeb9c05ac,0xafd800b5,0xad9801e7}},	//   _akue, _stør_, grød, _ciúb, 
   {{0x34e00918,0xc87856f8,0x0b582de5,0x2f38011a}},	//   _पर्द, _arş_, ырты_, _בגיד, 
   {{0x394402d5,0x16c40032,0xafd801bf,0x00000000}},	//   ugos_, ҡҡан, trøg, --, 
   {{0xafd811c0,0x88bc0055,0x9a500092,0xad640150}},	//   brød, _deśo, _ማግኘቱ, _таяз_, 
   {{0x3944b0eb,0x69d80124,0xafd803b2,0x38640142}},	//   sgos_, _ekue, ntøp, rwor_, 
   {{0x69d80270,0x56948339,0xb5a41ebb,0xb86401d3}},	//   _fkue, сайт, ирий, _ھارو, 
   {{0xb8655107,0x00000000,0x00000000,0x00000000}},	//   _پارو, --, --, --, 
   {{0x88bc006d,0xf770027d,0xf744119e,0x48c001af}},	//   _jeśl, _وائ_, _везо, _нәша, 
   {{0x37e4010b,0xa7c401af,0x00000000,0x00000000}},	//   _тозг, _крєҫ, --, --, 
   {{0xe3ac188d,0x69d800e4,0x88380092,0x6d480115}},	//   بري_, _ykue, _አልተሰ, ĵgaz, 
   {{0x4ad8000d,0x00000000,0x00000000,0x00000000}},	//   _बँसव, --, --, --, 
   {{0x30e402dd,0x00000000,0x00000000,0x00000000}},	//   рінб, --, --, --, 
   {{0x644c0228,0xe3ac16cc,0x00000000,0x00000000}},	//   àcie, _يرو_, --, --, 
   {{0xa9200f91,0xc04c00f1,0xe29400f3,0x00000000}},	//   ážka, وږی_, _вај_, --, 
   {{0x4ea4e17f,0xd6e802f5,0xdda800a8,0xad400137}},	//   арға, _পলায, атул_, تىرۉ, 
   {{0xdfd000aa,0x1df95108,0x9f080014,0xdc7401ec}},	// [22010] سيې_, реты_, اقہٕ_, огты, 
   {{0x69d817c1,0xafd8072b,0x00000000,0x00000000}},	//   _skue, frøe, --, --, 
   {{0x290c074d,0x78580882,0xafd84c5d,0x4a54ee9d}},	//   tcga_, hāvā, grøe, скес, 
   {{0xad980332,0xc8780790,0x0ea8004e,0x00000000}},	//   _diúc, _prş_, _акүй_, --, 
   {{0xad980332,0x00000000,0x00000000,0x00000000}},	//   _tiúb, --, --, --, 
   {{0x78580029,0xc79800e5,0x00000000,0x00000000}},	//   dāvā, دھرا_, --, --, 
   {{0x69d800b5,0xf1a407f7,0x98c400b1,0xda3400c0}},	//   _tkue, खसान, йсәл, _меры, 
   {{0x69d80117,0xfed000d1,0x863c0023,0x00000000}},	//   _ukue, ﺘﯩﯟﺍ, _ከይከድ, --, 
   {{0x76b4c7e0,0xb5c401d9,0xc878010e,0x34800139}},	//   иләр_, صوٝم_, _urş_, згыг, 
   {{0x83889551,0xd75801f7,0xc878010e,0x47d400ec}},	//   убов_, _نجما_, _gyşa_, _ايئر, 
   {{0xb38001c0,0x412809a0,0x48f0012c,0x00000000}},	//   члэл, лоно_, ेशको_, --, 
   {{0x13e8004e,0x785800b8,0x00000000,0x00000000}},	//   лмөй_, bāvā, --, --, 
   {{0x55ac010f,0x78580055,0x00000000,0x00000000}},	//   _ביאַ, cāvā, --, --, 
   {{0xf4100302,0xe29401e0,0x00000000,0x00000000}},	//   _צפו_, _ҡаҙ_, --, --, 
   {{0xafd80158,0xdde40118,0x38ac00e5,0x00000000}},	//   frøb, írůs, _köré_, --, 
   {{0xdce405ce,0xeb9c003b,0xafd833b8,0xb178376e}},	//   ndić, _støp_, støp, llån, 
   {{0xad98007b,0x0d0800d1,0x00000000,0x00000000}},	// [22020] _siúc, рдуқ_, --, --, 
   {{0xa11400aa,0xb1780158,0x8fb400f1,0x7f7400d8}},	//   _اوښت, nlån, _وليږ, _ѓупц, 
   {{0x1ee95109,0x2bbc17c6,0x00000000,0x00000000}},	//   _خودی_, ्वजा, --, --, 
   {{0x705032de,0xfc5c0023,0x00000000,0x00000000}},	//   _بنیا, ገልግል, --, --, 
   {{0x4c34084c,0x37e401a9,0xbb740395,0x00000000}},	//   _мэрт, бодг, _лувъ, --, 
   {{0x7af8002d,0xad9800ae,0x3f78010f,0x00000000}},	//   _útto, _tiúc, ראַס, --, 
   {{0xb17801bf,0x649401a9,0xb6040395,0x67500116}},	//   dlån, 知inl, щялк, سخور, 
   {{0x7c240810,0x65a401c0,0x2c7c00b5,0xc9780063}},	//   _kwkr, йтыг_, のdc_, _кључ_, 
   {{0xc7e80050,0x00000000,0x00000000,0x00000000}},	//   دى۪ن_, --, --, --, 
   {{0xb178003b,0x00000000,0x00000000,0x00000000}},	//   glån, --, --, --, 
   {{0xe7140375,0xe44c04f2,0xd6c40244,0x00000000}},	//   _החבר_, وضی_, _بمای, --, 
   {{0xf1a4023b,0xdbd0032e,0x00000000,0x00000000}},	//   срон, gþús, --, --, 
   {{0x53343aeb,0x00000000,0x00000000,0x00000000}},	//   _делт, --, --, --, 
   {{0x33f42424,0x00000000,0x00000000,0x00000000}},	//   _учес, --, --, --, 
   {{0x23440a52,0x9e04fb7e,0xafd833b8,0x00000000}},	//   _الىپ_, зчул, trøb, --, 
   {{0xd130cf73,0xb60401a6,0x3cec0241,0x00000000}},	//   _کمک_, mišć, _ọrọ̀_, --, 
   {{0xb60428b5,0xd011510a,0xf1bd510b,0xdd941507}},	// [22030] lišć, _تلخ_, miá_, чаты, 
   {{0xf1bd510c,0x00000000,0x00000000,0x00000000}},	//   liá_, --, --, --, 
   {{0x3cdc0574,0xb604107d,0x68340023,0x88bc00cd}},	//   _कुठे_, nišć, _ኣይሁድ, _veśm, 
   {{0xcd800952,0xf1bd510d,0x00000000,0x00000000}},	//   _تۇرۋ, niá_, --, --, 
   {{0xf09d510e,0x6d4c025c,0x6e380118,0xb17801e3}},	//   nyà_, _icca, říčí_, ylån, 
   {{0xf1bc0418,0x31cc015b,0xca7c0023,0x00000000}},	//   hiá_, রতিশ, _ኩሉኹም_, --, 
   {{0xf1bc0093,0x00000000,0x00000000,0x00000000}},	//   kiá_, --, --, --, 
   {{0x8459510f,0xb60463e0,0x7ae80e78,0xf09c00cf}},	//   арот_, dišć, üfte, ncàs_, 
   {{0xf1bd5110,0xdce416a3,0xb178007c,0x00000000}},	//   diá_, rdić, tlån, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf1bc03a0,0x6d4cb8b6,0x6b8001ed,0x81c845b5}},	//   fiá_, _occa, öngy, игов_, 
   {{0xf1bc351f,0xc104007b,0xc0e40137,0x7d004a38}},	//   giá_, توحي, жомк, žosi, 
   {{0x25bc0276,0x91fc0374,0xb1780267,0x62840fac}},	//   miul_, iwāh, plån, åjob, 
   {{0x6d4d5111,0x25bc084c,0x249d5112,0x6ed80037}},	//   _acca, liul_, myum_, _मुहँ, 
   {{0xf1bd5113,0xd3d81291,0xefe80092,0x249d5114}},	//   biá_, _ابنا_, ጄሪያ_, lyum_, 
   {{0x25bc00a8,0xf1bd5115,0x00000000,0x00000000}},	//   niul_, ciá_, --, --, 
   {{0x249d5116,0x7d0401ee,0x5ba401e0,0xec740064}},	// [22040] nyum_, _vgks, плағ, опт_, 
   {{0x249c0333,0x25bc0276,0x764c08fb,0x6d4d5117}},	//   iyum_, hiul_, _åbyg, _ecca, 
   {{0xcfa81b0e,0x29e000b8,0x00000000,0x00000000}},	//   _دايم_, _ṛcaḥ_, --, --, 
   {{0xd37808a4,0x249c0784,0xb8640472,0x00000000}},	//   moće_, kyum_, قاتو, --, 
   {{0x25bc00a8,0x999c01d3,0x00000000,0x00000000}},	//   diul_, évő_, --, --, 
   {{0x91fc0374,0x249d5118,0xe7b04cec,0x00000000}},	//   awāh, dyum_, ومند, --, 
   {{0x7bccbbb0,0xd37816a3,0x2cbc00d7,0x00000000}},	//   _ijbu, noće_, _ľudi_, --, 
   {{0x2cbc16a3,0x25bc0276,0xad9800c6,0xb604107d}},	//   _žudi_, giul_, _liún, višć, 
   {{0xf1bc180f,0xe9905f32,0xd37801a6,0x38a0022e}},	//   viá_, _تۇنگ, hoće_, _nаrx_, 
   {{0xd3780e04,0xb6041710,0x644c1497,0x00000000}},	//   koće_, tišć, àcia, --, 
   {{0x25bd5119,0xf1bd511a,0x249c1bce,0x91c40116}},	//   biul_, tiá_, ayum_, зәпл, 
   {{0xb605511b,0x25bc00a8,0xc0c8001f,0x53c814fb}},	//   rišć, ciul_, _ሠላም_, ргүм_, 
   {{0xf1bc2508,0x7e7c02d0,0x6d4d231f,0x00000000}},	//   riá_, _arpp, _rcca, --, 
   {{0xad9800ae,0xf1bd511c,0x320807d5,0x00000000}},	//   _ciún, siá_, _кхин_, --, 
   {{0xceb8151e,0x6d4c0332,0x71702ba5,0xafd803b2}},	//   сәп_, _pcca, _قۇدا, luøk, 
   {{0x321c0d6b,0xea880133,0x3f8c01e1,0x00000000}},	//   mpty_, یخان_, _òfun_, --, 
   {{0xad99511d,0xf1a8158b,0xd7bc1546,0x00000000}},	// [22050] _fiún, _ماکه_, ्चाच, --, 
   {{0xf09c067c,0xee840eed,0x25bc054e,0x00000000}},	//   scàs_, _дымо, ziul_, --, 
   {{0x249c0790,0xad24247f,0xdd9001d3,0x290001e1}},	//   zyum_, _ورحو, روے_, _ńja_, 
   {{0x249d2f65,0xafd803b2,0x25bc054e,0x6d4d511e}},	//   yyum_, kuøk, xiul_, _ucca, 
   {{0x25bd231e,0x88bc002b,0x98f40006,0xafd80162}},	//   viul_, _keśi, мяшч, juøk, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe734052f,0x25bc0276,0xd7740f87,0xb900cace}},	//   беҙ_, tiul_, بانع, _नु_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x25bc00a8,0x249c0d04,0x69c9511f,0x69c040e8}},	//   riul_, uyum_, mnge, éneu, 
   {{0x69c95120,0x9f4c0793,0x249d5121,0x25bc054e}},	//   lnge, ödü_, ryum_, siul_, 
   {{0x69c95122,0x249d5123,0x25bc084c,0x04fc015b}},	//   onge, syum_, piul_, ীরের_, 
   {{0x69c95124,0x98a40055,0xad980332,0xe7e000bc}},	//   nnge, _hemā_, _siún, गतका_, 
   {{0x69c95125,0x668003e6,0x00000000,0x00000000}},	//   inge, _ریکل, --, --, 
   {{0x69c95126,0xd9b81b61,0x4abd5127,0xd3780e04}},	//   hnge, _अष्ट, ्पाव, toće_, 
   {{0x69c95128,0x88bc00cd,0x00000000,0x00000000}},	//   knge, _deśi, --, --, 
   {{0x69c95129,0xa3b40406,0xcd74001f,0x0f4002d3}},	//   jnge, घोर_, _የቻይና_, _ንዝርከ, 
   {{0xbc1802dd,0xad9800ae,0x91c0000d,0x00000000}},	// [22060] сібі_, _tiún, _लगतै, --, 
   {{0xa3c80490,0x61ac00dc,0xd37801a6,0x2d8c3b52}},	//   रचि_, _चतुष, poće_, öger_, 
   {{0x98b0098d,0x3f980b23,0x69c802d2,0x00000000}},	//   đači_, _iopu_, fnge, --, 
   {{0x3f98092b,0x27e40165,0x69c8d4ca,0x00000000}},	//   _hopu_, elnn_, gnge, --, 
   {{0x3f99512a,0xa3c80574,0x37e4b149,0x7d1400a2}},	//   _kopu_, रचा_, подг, mcys, 
   {{0x3f98005a,0x699001e0,0xafd803b2,0x00000000}},	//   _jopu_, дрәх, vuøk, --, 
   {{0x7bdc4d11,0x69c9512b,0x7c344cab,0x3f980f53}},	//   mopu, bnge, lsyr, _mopu_, 
   {{0x69c000dd,0x3f99512c,0xe60c104c,0x94180108}},	//   énet, _lopu_, دشو_, ожит_, 
   {{0x7c35512d,0xdce40006,0x00000000,0x00000000}},	//   nsyr, keič, --, --, 
   {{0x7bdd512e,0x78a0036b,0x3f9800e4,0x6d400153}},	//   nopu, myov, _nopu_, ėnai, 
   {{0xc765512f,0xf2c4036b,0xb17801bf,0x9648030d}},	//   _زالى, ясин, slåm, _хiаъ_, 
   {{0x7bdd5130,0xafd808d7,0x7c355131,0xb3541fb8}},	//   hopu, grøn, ksyr, _کیدا_, 
   {{0x7bdd5132,0x76495133,0x78a15134,0xad9800c6}},	//   kopu, lufy, nyov, _diúl, 
   {{0x69c80007,0xf1a803e6,0x00000000,0x00000000}},	//   znge, _گاته_, --, --, 
   {{0x69c95135,0x3f980c95,0xafd82ab7,0xdfd40276}},	//   ynge, _dopu_, brøn, хоры, 
   {{0xf1a803e6,0x0dbc0092,0xdd9814b3,0x00000000}},	//   _داته_, _ተጽፎ_, пшу_, --, 
   {{0xe1f001f7,0x7bdc000d,0x4fd40395,0x8c191f21}},	// [22070] _حسو_, fopu, _ожит, زيار_, 
   {{0x7bdd5136,0x69c803a2,0x2a600263,0x09c40490}},	//   gopu, wnge, _ppjb_, लच्य, 
   {{0xdce401e4,0x2cbc00d0,0x764803b2,0x00000000}},	//   mdiĝ, _ľudu_, jufy, --, 
   {{0x69c95137,0xdce400df,0xad44014b,0x7c34010e}},	//   unge, ldiĝ, _эхок, bsyr, 
   {{0x69c95138,0x3f98020c,0x7bdd5139,0x78a00216}},	//   rnge, _yopu_, bopu, gyov, 
   {{0xdce400c8,0x7bdd513a,0x69c806a3,0x2cf801ad}},	//   ndiĝ, copu, snge, ्शील_, 
   {{0x76480204,0x69c80369,0x69c1513b,0x88bc0055}},	//   gufy, pnge, énes, _neśv, 
   {{0x69c80007,0xc48401b9,0x19584eb1,0x3ebc1427}},	//   qnge, длик, _насы_, útti_, 
   {{0xad9800ae,0x00000000,0x00000000,0x00000000}},	//   _niúm, --, --, --, 
   {{0xad98007b,0xa3b4012d,0x00000000,0x00000000}},	//   _siúl, घों_, --, --, 
   {{0x3f99513c,0xd7f88488,0x88bc00b8,0x814412ea}},	//   _ropu_, _хут_, _ceśv, وندن, 
   {{0x3f981132,0x7bdd513d,0xa07400d1,0x7c35513e}},	//   _sopu_, zopu, нъгә, ysyr, 
   {{0xafd9513f,0xad980120,0x7bdd5140,0x00000000}},	//   rrøn, _ciúm, yopu, --, 
   {{0x02c40372,0x3e8800db,0x00000000,0x00000000}},	//   _ойло, ойго_, --, --, 
   {{0xafd803cd,0x7c340042,0x78a001a9,0x733015bf}},	//   ntøy, wsyr, zyov, _شىيا, 
   {{0x69bc3eaf,0xdb1c0553,0x7af806ea,0x7c3406d9}},	//   लोमी, _imré, _útti, tsyr, 
   {{0x3f995141,0x61e55142,0xad9801e7,0xb4f8010f}},	// [22080] _topu_, _ikil, _giúm, ַלער, 
   {{0xfaa416c3,0x78a001c8,0x7c355143,0x00000000}},	//   мазо, vyov, rsyr, --, 
   {{0x7c34074d,0x7c38005f,0x00000000,0x00000000}},	//   ssyr, _ātru, --, --, 
   {{0x7bdd5144,0x6aa00158,0x986c0419,0x78a0bf19}},	//   sopu, ønfa, _vôľa_, tyov, 
   {{0xf770aaac,0xa8140f87,0x61e46ea9,0xafd80fac}},	//   ہاں_, وتور_, _mkil, krøl, 
   {{0xe3a55145,0x69c03b47,0xd3782375,0xa7700d30}},	//   _شر_, éner, koća_, кліч, 
   {{0xf7700583,0xe6140724,0x78a000d7,0x00000000}},	//   فاں_, үдә_, syov, --, 
   {{0x61e55146,0x76481446,0x320c0395,0xab740092}},	//   _nkil, rufy, _rufy_, _የጊዜው_, 
   {{0xdb1c020c,0x88bc0055,0x69080677,0x00000000}},	//   _amré, _seśv, _וּבְ, --, 
   {{0x61e55147,0xf3640c17,0xb5d402dd,0x36687579}},	//   _akil, фтин, _ﺀﺳﯩﺰ, _мазо_, 
   {{0x3168033f,0x00000000,0x00000000,0x00000000}},	//   tecz_, --, --, --, 
   {{0xda64022e,0x00000000,0x00000000,0x00000000}},	//   _ko叢i_, --, --, --, 
   {{0x0cc800bd,0x9554129e,0xafd812e8,0x3cdc00cd}},	//   _শর্ত, _يخچا, brøl, _कुले_, 
   {{0xe4c4221d,0xedc4043e,0xa3b43b98,0xe3ac00f7}},	//   _تصمی, रच्छ, _ياور_, _ۅرۉ_, 
   {{0x61e403a0,0x2fc001f5,0xdce4010f,0xca4c0220}},	//   _fkil, rijg_, rdiĝ, _ﺃﻤﺎ_, 
   {{0xdd900075,0x00000000,0x00000000,0x00000000}},	//   لۈپ_, --, --, --, 
   {{0xf8dc000d,0x00000000,0x00000000,0x00000000}},	// [22090] _फुलय, --, --, --, 
   {{0xaac424bd,0xafd805ac,0xe45400df,0x00000000}},	//   وتان, ytøy, וימט_, --, 
   {{0xafd8168c,0x00000000,0x00000000,0x00000000}},	//   nrøm, --, --, --, 
   {{0xad240fb4,0x4c94147e,0x6d4800ae,0x29840022}},	//   _تردو, _зимс, ógad, ьызг, 
   {{0x2d8803ee,0x7e600cf4,0x00000000,0x00000000}},	//   _ince_, _ćopi, --, --, 
   {{0xdce40ab7,0xafd803cd,0x9b6801d5,0xb8700150}},	//   ldiğ, ttøy, _ошса_, ығуы, 
   {{0x4ad80cb4,0x2fd00009,0x00000000,0x00000000}},	//   _बँटव, _mjxg_, --, --, 
   {{0xdce40365,0xafd862ad,0xd37800f3,0x99640139}},	//   ndiğ, drøm, voća_, _итул, 
   {{0x44395148,0x4268044e,0xafd878d9,0xeb9c08fb}},	//   és_, ሲደንት_, støy, _støy_, 
   {{0x57f40276,0xd37816a3,0x58d40cc9,0xafd833b8}},	//   _апут, toća_, _роут, ptøy, 
   {{0x2d88eb56,0x98a40311,0x96900214,0xd7940395}},	//   _once_, _temă_, _نیوش, _шифъ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb274013d,0xfd5400b8,0x00000000,0x00000000}},	//   _үкчә, ccaṇ, --, --, 
   {{0x2d880c3a,0xd3780841,0x64580549,0xad9801d3}},	//   _ance_, poća_, mtui, _fiúk, 
   {{0x64595149,0x2d8803e0,0x00000000,0x00000000}},	//   ltui, _bnce_, --, --, 
   {{0x6579514a,0x61e400ec,0x62803eba,0x6459514b}},	//   nduh, _ukil, _irno, otui, 
   {{0x3b85514c,0x48b003d4,0x628001ef,0x7c3800ef}},	// [220a0] нлаг, জপুৰ, _hrno, _ātrs, 
   {{0x6579514d,0x2d890f19,0x6459514e,0x628000bc}},	//   hduh, _ence_, itui, _krno, 
   {{0x6459514f,0xc10400f1,0x3944f086,0xfe7000f2}},	//   htui, _توکي, енег, _صدد_, 
   {{0x64595150,0xdc84059f,0xfaa40107,0xed5c00d7}},	//   ktui, _иқбо, маҷо, ížte_, 
   {{0x64580d27,0x65787aac,0x00000000,0x00000000}},	//   jtui, dduh, --, --, 
   {{0x62815151,0x8880136b,0x00000000,0x00000000}},	//   _orno, шғул, --, --, 
   {{0x56955152,0x64595153,0x0a38013d,0x91c00037}},	//   тайт, etui, _очты_, _लगलै, 
   {{0x65782819,0x4ad8012c,0x6d5800c7,0xd9100133}},	//   gduh, _बुटव, _ñuat, _ئیش_, 
   {{0xb88402fd,0x64595154,0xa3c80073,0x659000db}},	//   _blíž, gtui, रचं_, اجىر, 
   {{0xafd81512,0xdce40790,0x00000000,0x00000000}},	//   trøm, zdiğ, --, --, 
   {{0x62800bb8,0x6458ad5e,0xdce40790,0x00000000}},	//   _crno, atui, ydiğ, --, 
   {{0x64580660,0x7778005a,0x628014b2,0xafd803cd}},	//   btui, _hatx, _drno, rrøm, 
   {{0x77795155,0xdce403ee,0x628003ac,0x00000000}},	//   _katx, vdiğ, _erno, --, 
   {{0x7778005a,0x24940014,0xe0580b28,0x74140133}},	//   _jatx, _سن٘د_, ریپت_, _قوڵا, 
   {{0x77795156,0xe1f000b2,0xafd80162,0x4f3401d9}},	//   _matx, _ڏسي_, lrøk, ى۪کھ_, 
   {{0xc0d00020,0x777801c4,0x00000000,0x00000000}},	//   _የሚሉ_, _latx, --, --, 
   {{0xdce40ab7,0xd824004b,0xafd80162,0xbc1400f1}},	// [220b0] rdiğ, _دۍ_, nrøk, نسلګ, 
   {{0x4fc004a9,0x6578f1d2,0x777801c4,0x7658013d}},	//   _ئەسە, zduh, _natx, _oqty, 
   {{0xad980332,0x4a54ce96,0xad6400ec,0x00000000}},	//   _liúi, ткес, _ٻاجه, --, 
   {{0x2d88039a,0xafd80158,0xa9e4a012,0x00000000}},	//   _unce_, krøk, رثان, --, 
   {{0x77781c13,0x76580139,0xad980332,0xd7c800f1}},	//   _batx, _aqty, _niúi, ډونه_, 
   {{0x777800db,0x5c0401c6,0x0ba40022,0x6578031c}},	//   _catx, _бяса, _рымҭ, wduh, 
   {{0x06755157,0x7778005a,0xafd800b5,0x00000000}},	//   туля, _datx, trøj, --, 
   {{0x64595158,0xafd8143a,0xbc6400db,0x6280036e}},	//   ttui, frøk, _سۅۅن_, _rrno, 
   {{0x64595159,0x7779515a,0xad98007b,0xe7080345}},	//   utui, _fatx, _ciúi, _فتان_, 
   {{0x6459515b,0x9a880050,0x6280020c,0x7778009d}},	//   rtui, _تنہٕ_, _prno, _gatx, 
   {{0x6459515c,0xafd800b5,0x42d80139,0xc0d00092}},	//   stui, prøj, ьфия_, _የዚሁ_, 
   {{0xc0d00201,0x628005be,0x6459515d,0xcd6c001f}},	//   _የሚል_, _vrno, ptui, _አሪዞና_, 
   {{0x64583209,0x7778094a,0x98a40006,0x99e80030}},	//   qtui, _yatx, _temą_, liňá, 
   {{0x443d515e,0x43440f4e,0x00000000,0x00000000}},	//   _ivw_, _рекв, --, --, 
   {{0x6608409c,0x62807209,0xa1c402dd,0xbe4c0023}},	//   _kigk, _urno, _бұнд, _ንዜጋታ, 
   {{0xb600008c,0x008400e4,0x443c0076,0xed41515f}},	//   _þátt, _алио, _kvw_, инсп, 
   {{0xff255160,0x973c071b,0x00000000,0x00000000}},	// [220c0] _импо, _hoće, --, --, 
   {{0x66095161,0xac800209,0xdd9000f1,0xd5b80055}},	//   _ligk, шгул, جوړ_, _ntān_, 
   {{0x777800db,0xb1780158,0x6d4800ae,0x4e180064}},	//   _ratx, rlåv, ógac, _піяр_, 
   {{0xdb1c007b,0x7778022e,0xdbc40154,0x00000000}},	//   _imrí, _satx, ্তেফ, --, 
   {{0xb82003f4,0x777801c0,0x281000cf,0x7c2001e7}},	//   _নিহত_, _patx, لونس, íord, 
   {{0xb178049f,0xd7f4e8fc,0x9f4c0139,0xbb5405af}},	//   llåt, ызлы, _äläm_, _جنسب, 
   {{0x973d5162,0x66095163,0xc0d00020,0xd04c03f9}},	//   _noće, _bigk, _የዚህ_, _fyaɗ, 
   {{0x557418ec,0x9928004b,0xd5b800cd,0xafd87dfa}},	//   угит, _سترې_, _etān_, trøk, 
   {{0x660805e4,0xb7d807d2,0x77795164,0x00000000}},	//   _digk, _قورا_, _tatx, --, 
   {{0xafd95165,0xa8540a7c,0xdc1800ef,0x58040150}},	//   msøg, _בימה_, _zāģl, _созғ, 
   {{0x69bc02ab,0xb5f001ec,0xc64400f7,0xafd95166}},	//   लोवी, _күкі, _مئنى, lsøg, 
   {{0x973c05be,0xad980332,0x00000000,0x00000000}},	//   _doće, _tiúi, --, --, 
   {{0xafd8037e,0xdb1c02d2,0xb178248f,0x758000e5}},	//   nsøg, _amrí, dlåt, _میںم, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9f345566,0x443c01f5,0xde580212,0xb17808fb}},	//   ресі, _zvw_, карі_, flåt, 
   {{0x30a4dba2,0x61b40150,0x2b500175,0x1df8defb}},	//   _аров, _نەپا, wgxc_, весы_, 
   {{0x69c020ef,0x8cf4084c,0x408400fb,0x00000000}},	// [220d0] ènem, узац, _йәрм_, --, 
   {{0xafd80174,0x7bd0002b,0xd01000e5,0x00000000}},	//   dsøg, _ākuñ, _پلگ_, --, 
   {{0x07a40032,0x5c04034b,0xb1781f53,0x00000000}},	//   ғайн, рята, blåt, --, 
   {{0x9a844ecc,0x6b802776,0xe80c0c4c,0x00000000}},	//   шуул, ôngb, ादला_, --, 
   {{0x66080770,0xafd8037e,0x1ae40eac,0x2b915167}},	//   _rigk, gsøg, কেলে_, _پیاس, 
   {{0x76480042,0x660802d2,0xd7f4004e,0xa4903dbb}},	//   frfy, _sigk, азчы, ییات, 
   {{0xb1780726,0x443c002f,0x3664011c,0x00000000}},	//   nlås, _svw_, гащо_, --, 
   {{0xafd8037e,0x00000000,0x00000000,0x00000000}},	//   bsøg, --, --, --, 
   {{0x291c03a0,0x7af80174,0x8234009f,0x00000000}},	//   _ifua_, _úttr, گرخا, --, 
   {{0x973c16a3,0x443c01f5,0xe7b401bc,0x6700004e}},	//   _poće, _vvw_, _अतिप, _күлб, 
   {{0x6608089c,0x443c01f5,0x57240131,0x02c400d4}},	//   _tigk, _wvw_, _ئىمك, уйно, 
   {{0x973c041a,0x3f84467d,0xd6d807d8,0xe570007b}},	//   _voće, _şou_, _рту_, _خطط_, 
   {{0x291c3e17,0xb178007c,0x00000000,0x00000000}},	//   _mfua_, vlåt, --, --, 
   {{0x200d2295,0x78780fac,0x0b140154,0xfce40454}},	//   ödi_, _høvå, িরুল_, ҳобо, 
   {{0x291c03a0,0xb17801e3,0xbe141291,0x00000000}},	//   _ofua_, tlåt, اورع, --, 
   {{0xfce4283c,0xafd803b2,0x00000000,0x00000000}},	//   гобо, ysøg, --, --, 
   {{0x2120011f,0xb17801e6,0x3dd003cb,0x00000000}},	// [220e0] _ifih_, rlåt, rnyw_, --, 
   {{0xb34403b7,0x291cb452,0xb178ce29,0x787803cd}},	//   moçõ, _afua_, slåt, _løvå, 
   {{0x3ea43b39,0xfaf484da,0xb1780267,0x7c200332}},	//   _синг, учаю, plåt, íorb, 
   {{0xafd83c38,0xb17803cd,0x83fc00e5,0x00000000}},	//   tsøg, llår, ltőd, --, 
   {{0xc8780356,0x6b800208,0xafd80162,0x4c3400c0}},	//   _csş_, ôngc, usøg, _вэст, 
   {{0xafd95168,0x291d5169,0x82540023,0xf42000cc}},	//   rsøg, _efua_, _ጉባኤኹ, _মিলৰ_, 
   {{0xad98617f,0xafd83b97,0xf608009d,0x00000000}},	//   _viúv, ssøg, нхий_, --, 
   {{0x291c0270,0x38341178,0xafd8022c,0x2a041f39}},	//   _gfua_, _مىرز, psøg, _бесп_, 
   {{0xe3ac00aa,0x672c08e7,0xd80800c7,0xb17805ac}},	//   ګري_, ñijù, _амаҵ_, klår, 
   {{0x2120102c,0xc76416a0,0xafd801bf,0xbb4c01ec}},	//   _afih_, _نامى, lrøv, _ﺍﻛﻪ_, 
   {{0x636401c6,0xafd801bf,0xd130009f,0x00000000}},	//   урыг_, nsøe, يمد_, --, 
   {{0xe3ac0050,0x5f9400fb,0x00000000,0x00000000}},	//   ٲری_, ҙист, --, --, 
   {{0xe3ad516a,0x33840334,0x1394010a,0x00000000}},	//   زری_, _буйв, _вилю, --, 
   {{0xad980332,0xa50426c7,0x00000000,0x00000000}},	//   _liút, _сеча_, --, --, 
   {{0xceb92282,0xed88769e,0xafd80162,0x00000000}},	//   тәп_, нсак_, krøv, --, 
   {{0xafd800b5,0xb1787fff,0x00000000,0x00000000}},	//   jrøv, rlås, --, --, 
   {{0xeb49516b,0xafd8072b,0xb1784836,0xac7400f2}},	// [220f0] ечек_, drøv, slås, دازش, 
   {{0x91fc0029,0x610c0171,0xb1783bdc,0x6ee400ae}},	//   stād, _dēlī, plås, _مسجل, 
   {{0x20d51655,0x9b68ed36,0xafd801bf,0x00000000}},	//   _نتیج, ышта_, rsød, --, 
   {{0x7aec005c,0x997c02dd,0xafd8bc85,0x7c200332}},	//   _dybt, етшi, grøv, íorc, 
   {{0x3d38011a,0x48e400d8,0x00000000,0x00000000}},	//   _בגרס, јолв, --, --, 
   {{0x6abc009e,0xdd1c0024,0x281065dc,0x3cdc0b4c}},	//   ্থবো, _iššo, لوچس, _कुटे_, 
   {{0xafd806ea,0x1a6826a6,0xd5b8002b,0xd6c40131}},	//   brøv, _میلی_, _etām_, йишқ, 
   {{0x291c0618,0xdb080158,0x4ae4022e,0x00000000}},	//   _ufua_, ålåt, _бўға, --, 
   {{0x984806bb,0x03940d30,0xaa4401ee,0x00000000}},	//   _бяха_, арня, _шоңҡ_, --, 
   {{0x69c9516c,0x00000000,0x00000000,0x00000000}},	//   lige, --, --, --, 
   {{0x27e43462,0x412800e4,0xd668114f,0x00000000}},	//   monn_, коно_, _مملو_, --, 
   {{0x69c9516d,0x27e40100,0x00844a46,0x7ae8002f}},	//   nige, lonn_, алмо, üfti, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69c9516e,0x973c01a6,0x6d48007b,0x27e40165}},	//   hige, _koća, ógan, nonn_, 
   {{0x69c9516f,0x63a00876,0x09b40574,0xa28001d3}},	//   kige, _ionn, ंसाठ, _ایجو, 
   {{0x63a15170,0x27e404c4,0x32d80375,0x973c07f5}},	//   _honn, honn_, _שחקנ, _moća, 
   {{0x63a15171,0x69c95172,0x27e55173,0xafd801bf}},	// [22100] _konn, dige, konn_, vrøv, 
   {{0x63a037e9,0xbb44011b,0x59a800ab,0x610c0171}},	//   _jonn, режк, _ककहर, _vēlī, 
   {{0x69c95174,0x973c0552,0x27e407ab,0xad980332}},	//   fige, _noća, donn_, _bhúd, 
   {{0x63a15175,0x69c820c7,0xad9800ae,0xafd8005c}},	//   _lonn, gige, _diús, rsøe, 
   {{0x27e55176,0x91fc00da,0x63a15177,0xad980332}},	//   fonn_, ltāc, _oonn, _shúg, 
   {{0x63a15178,0x27e55179,0x98a4012c,0x973c623e}},	//   _nonn, gonn_, _země_, _boća, 
   {{0x69c8d938,0xafd839c2,0xfaa402f4,0x91fc0f40}},	//   bige, prøv, _таво, ntāc, 
   {{0xd37804b9,0x69c9517a,0xafd808fb,0xca64022e}},	//   moći_, cige, lrøt, mchа, 
   {{0x63a06dc8,0x75fc0023,0x27e52d23,0x79800327}},	//   _bonn, hëzg, bonn_, mdow, 
   {{0x63a1517b,0x7980738d,0xe3ac00e3,0x91fc19ae}},	//   _conn, ldow, ِرَ_, ktāc, 
   {{0x63a1517c,0xd3780552,0xc79401c6,0xca64022e}},	//   _donn, noći_, _урты, nchа, 
   {{0x7c240bb8,0x7981517d,0x63a1517e,0x31c4e11f}},	//   _otkr, ndow, _eonn, рсов, 
   {{0x63a1517f,0x457400f1,0x00000000,0x00000000}},	//   _fonn, _دپنځ, --, --, 
   {{0x63a15180,0xe3b400c0,0x00000000,0x00000000}},	//   _gonn, _кліч_, --, --, 
   {{0x69c8015c,0x7c24b700,0xe3ac00aa,0x63980375}},	//   yige, _atkr, _زرو_, _בסגנ, 
   {{0x63a15181,0x69c81dcd,0x4254066d,0x27e412ba}},	//   _zonn, xige, _انٹر, zonn_, 
   {{0x63a15182,0x69c84535,0x79800548,0x27e40bc2}},	// [22110] _yonn, vige, ddow, yonn_, 
   {{0x69c95183,0xafd8f8c6,0x63a001a9,0xb178007c}},	//   wige, grøt, _xonn, koåk, 
   {{0x69c95184,0x764c00b5,0xad98e851,0xad24a012}},	//   tige, _åbyh, _diúr, _پرجو, 
   {{0x79815185,0x8d94007b,0x69c8062c,0x27e55186}},	//   gdow, _الحش, uige, wonn_, 
   {{0xe6c82242,0xfd940302,0x27e52d23,0x195856f3}},	//   _íbúð, _הדרך_, tonn_, рачы_, 
   {{0xad980332,0x7980d530,0x31cc00fe,0x00000000}},	//   _giúr, adow, ৰতিশ, --, 
   {{0x63a15187,0x27e55188,0xdb1c0436,0x69c95189}},	//   _ronn, ronn_, _umrá, pige, 
   {{0x27e4157e,0x973d0889,0xc1c40034,0x00000000}},	//   sonn_, _voća, _लगेग, --, 
   {{0x27e45079,0x63a1518a,0xd8a838b7,0x48a400cc}},	//   ponn_, _ponn, _پهلو_, _খেৰৰ, 
   {{0xaca002e3,0x63a00a4d,0x68f80841,0xd75800db}},	//   _adịb, _qonn, _izud, _ەلەت_, 
   {{0x63a0b6c4,0x420801c6,0x88d800eb,0x00000000}},	//   _vonn, лноо_, _তরিক, --, 
   {{0x63a1518b,0x41b5518c,0x6d4800e5,0x052801c4}},	//   _wonn, ссот, ógal, _ёолк_, 
   {{0x63a1518d,0x973c098d,0x4428b032,0x644c578d}},	//   _tonn, _moćn, _ïa_, ácid, 
   {{0x7fd40220,0x7980033f,0x79540240,0x00000000}},	//   сімі, zdow, ቀሳቐስ, --, 
   {{0x69d8035b,0x7981518e,0xc5f800df,0x0244009f}},	//   _ojue, ydow, ָפּט, _اَبَ, 
   {{0x973c0bb8,0x68f9518f,0xe0585598,0xad9801e7}},	//   _noćn, _ozud, _پیست_, _siúr, 
   {{0x6da0a76a,0x68f806d6,0xada15190,0xafd803cd}},	// [22120] чита, _nzud, чатл, trøt, 
   {{0x79815191,0xad9801e7,0x00000000,0x00000000}},	//   wdow, _chúb, --, --, 
   {{0x68f804ba,0x69d801c7,0xad9800ae,0xd9780131}},	//   _azud, _bjue, _dhúb, ирдә_, 
   {{0x68f800b5,0x7e7c03ac,0xdd900131,0xca64022e}},	//   _bzud, _ispp, _تۈر_, rchа, 
   {{0x798035c2,0xa3e417e6,0x60000fe7,0xafd8003b}},	//   rdow, पवा_, römf, prøt, 
   {{0x68f806d6,0x79815192,0xafd80623,0x569400db}},	//   _dzud, sdow, lrør, жакт, 
   {{0x7980b12d,0x68f80083,0xc764278f,0x22b40213}},	//   pdow, _ezud, تانى, bəkə_, 
   {{0xb8cc00bd,0x69d80023,0x7e7c0175,0x7ae80112}},	//   _ওই_, _gjue, _mspp, üftu, 
   {{0x69c104dd,0xd4780166,0x00000000,0x00000000}},	//   ënee, рәеш_, --, --, 
   {{0x2d8402b1,0x00000000,0x00000000,0x00000000}},	//   ēnei_, --, --, --, 
   {{0xd2f95193,0xdddc0219,0xdce4003d,0x00000000}},	//   ренц_, zvrš, ffiċ, --, 
   {{0xdb1c00fc,0x7520020c,0xad9800ae,0xe5a03acc}},	//   _umræ, _ufoz, _mhúc, _нихи, 
   {{0xafd817c1,0x30e40220,0x7e7c0205,0x73e40816}},	//   drør, сінб, _aspp, _лодз, 
   {{0xafd803b2,0x4ea40150,0x00000000,0x00000000}},	//   vrøs, ұрға, --, --, 
   {{0x7d10013f,0x60000267,0x658402d2,0xe29400ea}},	//   ɛesɛ, dömd, _árhú, _гај_, 
   {{0x7e7c02d0,0x333c005a,0xf4240327,0xafd8143a}},	//   _dspp, latx_, _རྕོད_, grør, 
   {{0x7e7c02d0,0xdb1c007c,0xe1680244,0x1df801f4}},	// [22130] _espp, _omrä, _اڵپه_, сеты_, 
   {{0x69d95194,0x333c01c4,0x2d84687b,0x8f542c37}},	//   _sjue, natx_, śne_, _بندش, 
   {{0xafd80158,0x973c01a6,0x00000000,0x00000000}},	//   brør, _poćn, --, --, 
   {{0xd3780bb8,0xad98007b,0x2d9c00c5,0x4c9401af}},	//   moću_, _dhúc, _õue_, _димс, 
   {{0x973c56af,0x333c0327,0x00000000,0x00000000}},	//   _voćn, katx_, --, --, 
   {{0xf4240327,0x00000000,0x00000000,0x00000000}},	//   _རྕེད_, --, --, --, 
   {{0x69d82dba,0x600005d5,0xd37816a3,0xf41400cc}},	//   _tjue, sömg, noću_, _দৌলৰ_, 
   {{0xdb1c00a2,0x6aa00158,0x00000000,0x00000000}},	//   _emrä, ønfu, --, --, 
   {{0x68f80139,0x00000000,0x00000000,0x00000000}},	//   _uzud, --, --, --, 
   {{0xd874006c,0xd3780331,0x57b40108,0x00000000}},	//   _عاقب, koću_, _ебут, --, 
   {{0xafd80158,0x4df8033f,0x656800a2,0xdd3c012d}},	//   yrør, ंताई_, _tbgh, tążk, 
   {{0xc0ec0020,0x65bc01e1,0xb6400150,0xc49402e8}},	//   _ቀላል_, _dàhù, _ﺃﺸ_, _миещ, 
   {{0xa4840472,0xdce4025c,0xca343769,0x00000000}},	//   _دجان, rfiċ, ﯖﺪﺍ_, --, 
   {{0x1ae4015b,0x60000139,0x00000000,0x00000000}},	//   কেটে_, köme, --, --, 
   {{0x624401d9,0xd37891aa,0x3da8368e,0xafd805ac}},	//   _آبہ_, goću_, акво_, trør, 
   {{0x442d5195,0x6000049f,0xa08401af,0x00000000}},	//   ope_, döme, _еңме, --, 
   {{0x442d5196,0xae1c0412,0xad980332,0xafd887c2}},	// [22140] npe_, _मंथन_, _shúc, rrør, 
   {{0x442c7cfb,0x91fc3a71,0xafd83619,0x2cac2d8b}},	//   ipe_, ntān, srør, øgda_, 
   {{0xafd8168c,0x60000fe7,0x442d5197,0x3eac08a5}},	//   prør, römd, hpe_, _æft_, 
   {{0x442d144f,0xafd805ac,0x00000000,0x00000000}},	//   kpe_, nsøn, --, --, 
   {{0x442c0d27,0x91fc0882,0x00000000,0x00000000}},	//   jpe_, ktān, --, --, 
   {{0x442d5198,0xe790026a,0x00000000,0x00000000}},	//   dpe_, дишњ, --, --, 
   {{0x442d5199,0x333c031c,0x00000000,0x00000000}},	//   epe_, vatx_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x442c1c06,0x276804f2,0x637c0064,0xefb80023}},	//   gpe_, _چشمی_, kšnė, _ሰምዑ_, 
   {{0xe734084c,0xdb1c00a2,0x00000000,0x00000000}},	//   _меу_, _umrä, --, --, 
   {{0x442d519a,0x333c01c4,0x3864a3d6,0xf12400c7}},	//   ape_, ratx_, ltor_, жьго, 
   {{0x442d519b,0x3864000d,0xddd400a2,0x00000000}},	//   bpe_, otor_, _ĸaşa, --, 
   {{0x38651a3b,0x333c0227,0x321c0334,0x842000db}},	//   ntor_, patx_, sqty_, _كۉين, 
   {{0xba000020,0x3865519c,0xd37801a6,0xb35402f2}},	//   _ውጪ_, itor_, toću_, _بیدا_, 
   {{0x88bc002b,0x3864036e,0x00000000,0x00000000}},	//   _deśy, htor_, --, --, 
   {{0xdd95519d,0xdd99519e,0x6000006a,0xd3780034}},	//   масы, ошу_, gömb, leć_, 
   {{0x3a28113c,0xf1bc00c6,0x386402d3,0x00000000}},	// [22150] _atbp_, mhá_, jtor_, --, 
   {{0xf1bcf882,0xd378107d,0x2bb8007b,0x1ae40154}},	//   lhá_, poću_, جارة_, কেছে_, 
   {{0x3865519f,0x9ba40014,0xe9e4009d,0x442cfbd3}},	//   etor_, بٕلى, оцдо, zpe_, 
   {{0x442d51a0,0x7e7800c8,0xf1bc6819,0x600151a1}},	//   ype_, _פארז, nhá_, röme, 
   {{0x998401b9,0xd8b80b73,0x386400a2,0x00000000}},	//   بلنو, يدها_, gtor_, --, 
   {{0xf09c004e,0xd37951a2,0x6fb84142,0x69bc6d65}},	//   ixà_, jeć_, उसिं, लोजी, 
   {{0x386551a3,0x1f3800d9,0x00000000,0x00000000}},	//   ator_, חרור_, --, --, 
   {{0x38647db2,0xdb1c002d,0xd5e800c6,0x1958b4c7}},	//   btor_, _omrû, يعين_, _масы_, 
   {{0x442c07ea,0x91fc0882,0x362401d9,0x00000000}},	//   upe_, ttān, _ہولہ, --, 
   {{0x9814bf4e,0x00000000,0x00000000,0x00000000}},	//   _قبلا, --, --, --, 
   {{0x442d51a4,0x00000000,0x00000000,0x00000000}},	//   spe_, --, --, --, 
   {{0x91fc0aed,0xc0e0001f,0xd5b8005f,0x1634010a}},	//   stān, ነርሱ_, _stāv_, _цеця, 
   {{0x439551a5,0xd37801a6,0xafd82b96,0x00000000}},	//   _надс, beć_, rsøn, --, 
   {{0xafd80158,0x3f680063,0x1de421bd,0x7c200332}},	//   ssøn, љиво_, कक्ष_, íorm, 
   {{0x06ac0c58,0xafe151a6,0xf1bc0548,0x9324004b}},	//   _কেতি, хорл, bhá_, _غرون, 
   {{0xf1bc1bb7,0x91fc0f40,0x386551a7,0xada151a8}},	//   chá_, ntāl, ytor_, насл, 
   {{0x386401b9,0x25bc0ac5,0x600151a9,0xdce401e4}},	// [22160] xtor_, ihul_, römb, beiĝ, 
   {{0x724001d3,0x38640010,0x00000000,0x00000000}},	//   _تھیل, vtor_, --, --, 
   {{0x3864e24e,0x2efc02a8,0x25bd51aa,0xec101e2f}},	//   wtor_, ƙufa_, khul_, رومد, 
   {{0x386551ab,0x25bc2a6d,0xd3780034,0x6e9800d9}},	//   ttor_, jhul_, zeć_, _הבטח, 
   {{0xafd9225f,0x25bc04fb,0x91fc00e2,0x039400e2}},	//   ksøl, dhul_, dtāl, _ķīnā_, 
   {{0x386551ac,0x69c01184,0xf668007b,0x00000000}},	//   rtor_, èner, محبه_, --, 
   {{0x999800b0,0xd3782630,0xad98007b,0x83fc00e5}},	//   _hurō_, već_, _mhún, ttőn, 
   {{0x25bd51ad,0x636405f5,0x26000724,0xe9d4af42}},	//   ghul_, үрэг_, нчыг, _екс_, 
   {{0x6d4800c6,0x78b40158,0x00000000,0x00000000}},	//   ógai, øyvd, --, --, 
   {{0xad980016,0xeb9c0158,0x644d51ae,0x93c801d9}},	//   _nhún, _buøy_, ácia, تابہ_, 
   {{0x7bcc0a2e,0xc7642033,0x25bd51af,0xd3780841}},	//   _mmbu, _تاقى, bhul_, reć_, 
   {{0x22440048,0x25bd51b0,0x7bcc056a,0xf1bc00bc}},	//   _dvnk_, chul_, _lmbu, uhá_, 
   {{0x9a9402d3,0x93c801d9,0x65100137,0xe2800139}},	//   _መዋእል_, _واتہ_, _كومئ, _үлчи, 
   {{0xad9801dc,0xf2e45c08,0xf1bc011f,0xf09c00db}},	//   _chún, _нюйо, shá_, rxà_, 
   {{0xad98007b,0x23e801d5,0xd25000f1,0xf1bc0332}},	//   _dhún, _اذنی_, _ړنګ_, phá_, 
   {{0x40ec05db,0x22f40302,0xafd80194,0x7bcc6c01}},	//   ọrọ_, _מזון_, msøm, _ambu, 
   {{0xf1a804d3,0x00000000,0x00000000,0x00000000}},	// [22170] _ناکه_, --, --, --, 
   {{0x91fc00e2,0xad980332,0x09b400cd,0x290000c0}},	//   itām, _ghún, ंस्य, _ąja_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7bcd51b1,0xec140075,0xcd8002dd,0xdddc00d7}},	//   _embu, _немә_, _جۇرۋ, tvrť, 
   {{0x6d5c01b3,0x6f050ac7,0x25bd0d6f,0x600001f4}},	//   mgqa, bébé, vhul_, löma, 
   {{0xbcb40375,0x9984012d,0x00000000,0x00000000}},	//   _חפשו_, _kimś_, --, --, 
   {{0x6000014a,0x574401b9,0x00000000,0x00000000}},	//   nöma, رخوف, --, --, 
   {{0x6d5d51b2,0x75fc02d3,0xafd80158,0x6b8551b3}},	//   ngqa, tëza, ruøy, _hajg, 
   {{0x91fc0029,0x6b840331,0xdebc001f,0x25bd51b4}},	//   rtāl, _kajg, _ሰውን_, rhul_, 
   {{0x25bc005c,0x91fc1a14,0x78b42d8b,0x75fc0200}},	//   shul_, stāl, øyve, rëza, 
   {{0x6b840007,0xafd886ee,0x25bc0472,0x75fc0200}},	//   _majg, rsøl, phul_, sëza, 
   {{0x44b409fe,0x60000267,0xa5e4010b,0xafd803b2}},	//   _обес, döma, _эюзл, ssøl, 
   {{0x764c0158,0x6b84022e,0x6578003e,0xd5b800b8}},	//   _åbyr, _oajg, meuh, _etās_, 
   {{0x657800d5,0x98a400e2,0x62200046,0x8d940092}},	//   leuh, _zemē_, _كوتە, _መቻቻል_, 
   {{0x6458735c,0xbf840037,0x00000000,0x00000000}},	//   luui, _डाo_, --, --, 
   {{0x6280022e,0x70ec02e3,0x657951b5,0xcd740092}},	//   _isno, ụrụi, neuh, _ከቻይና_, 
   {{0x3b846180,0xb0580724,0x645804c9,0x7080326b}},	// [22180] млаг, nzäl, nuui, _агыз, 
   {{0x973ce108,0x657951b6,0x6b8400f3,0x69c00036}},	//   _voćk, heuh, _cajg, ënen, 
   {{0x6b840369,0xad9800d2,0x657800d5,0x6f04003e}},	//   _dajg, _khúl, keuh, rébé, 
   {{0x645951b7,0x65780438,0xa82001d5,0x00000000}},	//   kuui, jeuh, چکلن, --, 
   {{0x6b8551b8,0x657800d5,0xdb1c21e3,0x1cb80327}},	//   _fajg, deuh, _omrø, _མཎི_, 
   {{0x7bcc124c,0x6b845c68,0x6458003a,0x95f828f0}},	//   _umbu, _gajg, duui, ुष्ट_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x973c110c,0x657800d5,0x34244a03,0xafd8005c}},	//   _moći, geuh, мфов, gsøj, 
   {{0x6458013c,0x628151b9,0xb86401f7,0x00000000}},	//   guui, _asno, _تازو, --, 
   {{0x7bdd51ba,0x6000005b,0xa8000150,0x00000000}},	//   nnpu, yöma, _азул, --, 
   {{0xc76431f0,0x973c05a1,0x657800d5,0x7bdc1f15}},	//   _سالى, _noći, beuh, inpu, 
   {{0xa1941fe2,0xad9800c6,0x6459180f,0x6578003e}},	//   ваюч, _chúl, buui, ceuh, 
   {{0x62800bfa,0x6458003a,0x64a000c7,0xad980332}},	//   _esno, cuui, _иаца, _dhúl, 
   {{0x60005f95,0x7bdc01f5,0xafd951bb,0xb178007c}},	//   töma, jnpu, msøk, goår, 
   {{0xafd85792,0x91fc1a14,0x7c880116,0x00000000}},	//   lsøk, ntāk, үшуң_, --, 
   {{0x973c00f3,0x60000267,0x7bdc017a,0x6b840e10}},	//   _doći, röma, enpu, _sajg, 
   {{0xafd895b0,0x50d40014,0x75fc0240,0x00000000}},	// [22190] nsøk, _سٲدر, hëzo, --, 
   {{0x91fc1a14,0xc878010e,0xb058002f,0x75fc0200}},	//   ktāk, _gyşy_, nzäm, këzo, 
   {{0x6b8551bc,0xb178119a,0x63a40267,0x657800d5}},	//   _vajg, pnåd, öjni, yeuh, 
   {{0xafd84098,0x6ce40220,0x7bdc35e5,0x9ae80b01}},	//   ksøk, _жіге, anpu, ффуз_, 
   {{0xe7e8069f,0x6d4d51bd,0x99d4c320,0x00000000}},	//   टवला_, _idca, ختلا, --, 
   {{0xd7c928dc,0xafd800ed,0xb89000db,0xe798007b}},	//   وونه_, dsøk, الوع, تخصص_, 
   {{0x6578003e,0x75fc036e,0x91fc00ef,0x00000000}},	//   teuh, gëzo, gtāk, --, 
   {{0xc48551be,0x91fc00da,0x644c0030,0x645951bf}},	//   елик, stāj, ácio, tuui, 
   {{0x6000049f,0x65780438,0xafd888d9,0x83fc00e5}},	//   dömn, reuh, gsøk, stőm, 
   {{0x42c951c0,0x657800d5,0x324c0092,0x7c200332}},	//   згон_, seuh, _በተመጣ, íori, 
   {{0xd7c8f061,0x6458013c,0x142400f7,0x65780098}},	//   _توله_, suui, ндөм, peuh, 
   {{0x64580194,0x999803e3,0x00000000,0x00000000}},	//   puui, _mtrş_, --, --, 
   {{0x62800042,0xb1400006,0x83fc01d3,0x7bdc01e3}},	//   _wsno, ынял, ntők, ynpu, 
   {{0x6d4c20a2,0xdb1c022c,0x973c0841,0x26c4110c}},	//   _adca, _umrø, _poći, ozno_, 
   {{0x670c000b,0x628001ef,0x00000000,0x00000000}},	//   ाधिक_, _usno, --, --, 
   {{0x443c0c6a,0x0d4c02d3,0x973c01a6,0x80640114}},	//   _kww_, _ንኽፈል, _voći, _звиж, 
   {{0x443c00b5,0xe294504c,0x00000000,0x00000000}},	// [221a0] _jww_, _хақ_, --, --, 
   {{0xbb840f1b,0x7bdc282c,0x31052b03,0x6b600139}},	//   علاي, unpu, _янып_, лкуа, 
   {{0x443d51c1,0x00000000,0x00000000,0x00000000}},	//   _lww_, --, --, --, 
   {{0xb1782b96,0x78a0022e,0x00000000,0x00000000}},	//   pnåe, txov, --, --, 
   {{0x26c45f40,0x06ac00fe,0xad180375,0xdb840022}},	//   ezno_, _কেলি, _מוכר, _иҳаи, 
   {{0x1ce00003,0x61e4597f,0xafd80579,0xe3a48b29}},	//   _སྨར_, _ljil, vsøk, _صر_, 
   {{0x6448cf77,0x443c045a,0x61e551c2,0xebe004b3}},	//   _avgi, _aww_, _ojil, _сорп, 
   {{0x75fc044e,0xe7a4468c,0xab98001f,0x60000793}},	//   rëzo, двәл_, _ለጊዜው_, kömo, 
   {{0x394551c3,0x91fc00da,0x6f0401e1,0x00000000}},	//   maos_, stāk, _kébí, --, 
   {{0x61e400b2,0xafd8174e,0xf3649709,0x92940114}},	//   _ajil, rsøk, хтин, ваоц, 
   {{0x443c0280,0x36943298,0x26c4a735,0xafd8143a}},	//   _eww_, _яшас, czno_, ssøk, 
   {{0x394551c4,0xafd808fb,0x764803cd,0x2508029e}},	//   naos_, psøk, msfy, _کرمی_, 
   {{0x61e4009b,0x443c01f5,0x64b03b89,0x600010ee}},	//   _djil, _gww_, _محور, römn, 
   {{0x6d4d51c5,0x394428dc,0xade0000d,0x41d006e3}},	//   _sdca, haos_, _गदहन_, दोबस, 
   {{0x61e40a85,0x59e0085c,0x00000000,0x00000000}},	//   _fjil, पचार, --, --, 
   {{0x61e402d3,0xcc88004b,0x394551c6,0x00000000}},	//   _gjil, ونزه_, jaos_, --, 
   {{0x394551c7,0x614400d8,0x00000000,0x00000000}},	// [221b0] daos_, _сења, --, --, 
   {{0x973c01a6,0x764803b2,0x00000000,0x00000000}},	//   _koću, ksfy, --, --, 
   {{0x48bc0154,0x6d4801e7,0x00000000,0x00000000}},	//   _আখের, ógas, --, --, 
   {{0x764800cc,0x00000000,0x00000000,0x00000000}},	//   dsfy, --, --, --, 
   {{0x2d88003a,0x9d180108,0xdd94009d,0xdde400fb}},	//   _iace_, _поют_, _саяы, _сәрү, 
   {{0x2d880d42,0x78b40158,0x83fc00e5,0x764802d2}},	//   _hace_, øyva, rtők, fsfy, 
   {{0x2d8951c8,0x973c0e3c,0x91fc0270,0xfd4c00b8}},	//   _kace_, _noću, atāi, _adhṛ, 
   {{0x2d88ec00,0x39440789,0x644c04a7,0xe9dc00e4}},	//   _jace_, caos_, šcim, _ñú_, 
   {{0x26c551c9,0x2d8951ca,0x48140124,0xd8749cc3}},	//   szno_, _mace_, _амас, _مالب, 
   {{0x1ce0031c,0x039551cb,0x2d880e21,0xb058002f}},	//   _སྨས_, трия, _lace_, mzäh, 
   {{0xad9800c7,0x920c0034,0x68f800b8,0x00000000}},	//   _chúk, सगंज_, _hyud, --, 
   {{0x644951cc,0xafd800cc,0xb22402d2,0x60000108}},	//   _tvgi, mrøy, _skæð, tömo, 
   {{0x443c0036,0xafd805ac,0xb0580112,0x00000000}},	//   _uww_, lrøy, nzäh, --, 
   {{0x68f8009a,0x2b4009a8,0x7fd40220,0x2d880139}},	//   _myud, _nejc_, тімі, _aace_, 
   {{0x2d8951cd,0x61e551ce,0x291c48bf,0xafd805ac}},	//   _bace_, _tjil, _ogua_, nrøy, 
   {{0x291d51cf,0x2d8951d0,0x61e40113,0xdcc82cc8}},	//   _ngua_, _cace_, _ujil, еңме_, 
   {{0x2d883142,0x68f951d1,0x6000007c,0x25ad51d2}},	// [221c0] _dace_, _nyud, lömm, _mogl_, 
   {{0x291c421d,0x2d88020b,0x6d4808a7,0xafd80158}},	//   _agua_, _eace_, ógar, krøy, 
   {{0x68f951d3,0x2d892178,0x394426b1,0x0b580006}},	//   _ayud, _face_, внег, эрты_, 
   {{0x68f951d4,0x2d8951d5,0xafd80158,0xb0580112}},	//   _byud, _gace_, drøy, fzäh, 
   {{0x394551d6,0x68f8037e,0x187551d7,0xf8d000dc}},	//   raos_, _cyud, угля, _देशय, 
   {{0x2d8951d8,0x291c00c7,0x7c3551d9,0xa3d00764}},	//   _zace_, _egua_, mpyr, सोम_, 
   {{0x2d883142,0x68f802b9,0x7c3420a2,0xaa4031e2}},	//   _yace_, _eyud, lpyr, _весл, 
   {{0x1ce049a6,0x2120020c,0x2d880077,0x7c340076}},	//   _སྨོ_, _ngih_, _xace_, opyr, 
   {{0x68f951da,0xe3ac00b2,0xd910006c,0xe8f47a16}},	//   _gyud, ڪري_, _ایش_, _алт_, 
   {{0x212005b1,0x888001d9,0x764805ac,0x7c340022}},	//   _agih_, _دیٖن, psfy, ipyr, 
   {{0xe3ac082e,0x25ac04cc,0x66e0dbcb,0x2768006c}},	//   تري_, _fogl_, _кофа, _تشقی_, 
   {{0x25ac0334,0xafd80b1a,0xb05801c7,0x040c0051}},	//   _gogl_, nsøv, lzäi, _kườn, 
   {{0x2d88b8c9,0x656c068c,0x6e240175,0x845400f7}},	//   _race_, òche, wqjb, _مىنچ, 
   {{0x2d880c09,0x1ce00135,0x040c004d,0xb0580221}},	//   _sace_, _སྨེ_, _mườn, nzäi, 
   {{0x040c01fb,0x6018010b,0x2b400010,0xc0c0001f}},	//   _lườn, торя_, _rejc_, _ሻውል_, 
   {{0x2120020c,0xd84951db,0xb0580036,0x5d545e0c}},	//   _ggih_, kọ_, hzäi, икст, 
   {{0x1df818ce,0xafd801bf,0x2d880200,0x040c0051}},	// [221d0] теты_, dsøv, _vace_, _nườn, 
   {{0x2d880c09,0xad9800c6,0x09bc121d,0x7d0400ef}},	//   _wace_, _mhúi, ्फ्य, _dzks, 
   {{0xacb8145e,0x2d8951dc,0x68f87dcc,0xc95459e6}},	//   _afût, _tace_, _syud, гтлы, 
   {{0x2d8845a7,0x68f951dd,0x7ae800aa,0xafd805ac}},	//   _uace_, _pyud, رونې_, gsøv, 
   {{0x040c0016,0x7c2000c6,0x332c0175,0xb05801c7}},	//   _cườn, íort, _offx_, fzäi, 
   {{0xb058245f,0x040c001e,0xd83805f5,0x25ac05d5}},	//   rzäh, _dườn, тэц_, _sogl_, 
   {{0x25ac04cc,0xb0580112,0x9a8551de,0x56640b24}},	//   _pogl_, szäh, _кутл, لديف, 
   {{0x44881586,0xafd80217,0x291c0124,0xad9801e7}},	//   ебин_, rrøy, _ugua_, _bhúi, 
   {{0x68f951df,0xad980597,0x986800dd,0xafd800fe}},	//   _uyud, _chúi, _لینے_, srøy, 
   {{0xd7740152,0xca3008b0,0x38602d8b,0xad98007b}},	//   _نامع, _ﺭﻩﺕ_, _åkra_, _dhúi, 
   {{0xc0d0001f,0xc0f40092,0xae1c0037,0xae0006e3}},	//   _ከዚሁ_, _ለዚሁ_, _मंगन_, लतान_, 
   {{0x600001e6,0xcf8802e4,0xc0d00092,0x7c3400c7}},	//   römm, _מט_, _ከሚል_, ypyr, 
   {{0xe3b151e0,0xad980332,0x040c0051,0xb3400166}},	//   _پرش_, _ghúi, _xườn, _şçes, 
   {{0xfce402f4,0x64580430,0x24500214,0x2d8c002d}},	//   қозо, mrui, _منچس, ôgen_, 
   {{0x3ebc2242,0x64581a7c,0xdf0400ee,0x4278010f}},	//   átt_, lrui, рүнй, _טאַג, 
   {{0x6458b98d,0x2120003e,0xd848413b,0xb1780158}},	//   orui, _ugih_, yọ_, pnåa, 
   {{0x645951e1,0x7c3400e4,0x7fd40064,0xca300150}},	// [221e0] nrui, upyr, _біні, _ﺭﺩﺍ_, 
   {{0x7c3403a2,0x6458017a,0xbea40166,0x040c0051}},	//   rpyr, irui, _баок, _rườn, 
   {{0x7c3551e2,0x645800c6,0xdb1c0e78,0xc10400ec}},	//   spyr, hrui, _umrü, _جوکي, 
   {{0x91fd05bd,0x64582595,0x3a04d653,0xd848c380}},	//   stāv, krui, اکسی_, tọ_, 
   {{0x645801f5,0xb05801c7,0xafd803b2,0x00000000}},	//   jrui, tzäi, rsøv, --, 
   {{0x91fc0029,0x645951e3,0x368951e4,0x2c9000e4}},	//   ltāt, drui, есин_, _ñehẽ_, 
   {{0xc0d00201,0xc0f40201,0x7c240784,0xad98007b}},	//   _ከዚህ_, _ለዚህ_, _hukr, _shúi, 
   {{0xb058092e,0x7c2551e5,0x645951e6,0x040c0016}},	//   szäi, _kukr, frui, _tườn, 
   {{0x7c2403a2,0x89d40220,0x973c009b,0x645951e7}},	//   _jukr, _тірш, _anće, grui, 
   {{0x7c2551e8,0xc7640131,0xdb1c1427,0xd7b809fa}},	//   _mukr, _پاكى, _umró, _अविच, 
   {{0x91800075,0x64580140,0x75fc0023,0x28101af5}},	//   قۇغۇ, arui, hëzi, _اولس, 
   {{0x645951e9,0xf1a551ea,0x75fc036e,0xad9801e7}},	//   brui, урон, këzi, _thúi, 
   {{0x645951eb,0x7c2551ec,0x75fc0200,0x00000000}},	//   crui, _nukr, jëzi, --, 
   {{0x53349c52,0xdb1c08a5,0xefc80023,0xc0c80092}},	//   _тект, _alrí, ጢምዎ_, _አጋራ_, 
   {{0x7c2551ed,0x9f3551ee,0xef9001b9,0x28d808ec}},	//   _aukr, сесі, لیکد, _मेनि, 
   {{0x7c2551ef,0xabb007dd,0x30a49785,0x98c4033f}},	//   _bukr, әажә, _бров, वनाए, 
   {{0xa0681677,0x75fc0240,0xf1bc0419,0x00000000}},	// [221f0] _бања_, gëzi, mká_, --, 
   {{0xf1bc012c,0x7c240006,0x00000000,0x00000000}},	//   lká_, _dukr, --, --, 
   {{0x7c2551f0,0xf1bc02f0,0x00000000,0x00000000}},	//   _eukr, oká_, --, --, 
   {{0xf1bd51f1,0x3ebc6ab9,0xd7080183,0x645801f5}},	//   nká_, øtte_, ৰুৱা_, yrui, 
   {{0x481401c6,0x645801ab,0x00000000,0x00000000}},	//   амдс, xrui, --, --, 
   {{0x75200099,0xf1bc0122,0x1ce0025c,0x99644640}},	//   _agoz, hká_, _སྨི_, атәл, 
   {{0xf1bc99a0,0x79800005,0x2c6d51f2,0xf4080154}},	//   kká_, beow, lüd_, রদার_, 
   {{0x7c240784,0x82344c8b,0x00000000,0x00000000}},	//   _yukr, یرجا, --, --, 
   {{0xf1bc0122,0x85b804fb,0x645951f3,0x27b00166}},	//   dká_, فاکس_, urui, _гәйс, 
   {{0x645951f4,0x752001c6,0x660800e2,0xb058002f}},	//   rrui, _egoz, _šokē, nzäu, 
   {{0x64581fe8,0xd7c87b8f,0x2c6c008e,0x97a401af}},	//   srui, _حوله_, hüd_, _уртл, 
   {{0x645951f5,0xd6d951f6,0x2d8c0165,0xd36400c7}},	//   prui, _сту_, ôgel_, ақәa_, 
   {{0x03a41d18,0x044551f7,0x9a940092,0xf49400ec}},	//   _вило, _телн, _መዋዕለ_, _پانڌ, 
   {{0x25bc0793,0x91fc00da,0xf1bc02ea,0x4ab401ad}},	//   lkul_, tuāc, aká_, ंहाव, 
   {{0x7c2413aa,0x6000014a,0xf1bc02f0,0x00000000}},	//   _sukr, nömi, bká_, --, 
   {{0xf1bc0745,0x25bd51f8,0x2c6c014a,0x671425fe}},	//   cká_, nkul_, füd_, धेयक_, 
   {{0x7f741e76,0x8fc400f2,0x2c6c0139,0x00000000}},	// [22200] _кунц, _گزين, güd_, --, 
   {{0x75fc044e,0x91fc0318,0x7c2407a9,0x29d8063f}},	//   rëzi, grāf, _vukr, ụala_, 
   {{0x3ea407d6,0x25bc0694,0x7980011c,0xae1c05f9}},	//   _тинг, kkul_, teow, _मंचन_, 
   {{0x2c6c014a,0x7c2403f0,0xb8640ee8,0xd378110c}},	//   büd_, _tukr, لاتو, miće_, 
   {{0xd3781225,0xa96551f9,0x83fc01ed,0xe8f551fa}},	//   liće_, рича_, ntős, алц_, 
   {{0x91fc11f9,0x7520011c,0x1ce0025c,0xf1bc00bc}},	//   ntār, _sgoz, _སྨག_, zká_, 
   {{0xd3780384,0xe28400d1,0xf1bce81d,0x00000000}},	//   niće_, _بذ_, yká_, --, 
   {{0xd91151fb,0xa3d00c2e,0x25bc7dec,0xafd8143a}},	//   _فیض_, सोस_, gkul_, nsør, 
   {{0x91fc0a30,0x656c91ef,0x69180254,0xf1bc00d7}},	//   ktār, òcha, _väeü, vká_, 
   {{0xa504026a,0xd37801a6,0xcfe401ec,0x00000000}},	//   шења_, kiće_, _ﺍﻳﺎﻗ, --, 
   {{0xe7e0069f,0xf1bc0313,0xd378110c,0x7624010b}},	//   कचरा_, tká_, jiće_, _тмез, 
   {{0x28d84d53,0xd3781591,0x75200099,0x25bd51fc}},	//   _मेडि, diće_, _ugoz, ckul_, 
   {{0xe3ac41b3,0xf1bc0ab9,0x65d001c8,0x00000000}},	//   سری_, rká_, _بينط, --, 
   {{0xf1bc03c6,0x24540276,0xd37804a7,0xc43001d3}},	//   ská_, _ташь_, fiće_, _ڈکیت, 
   {{0x83fc01d3,0xf1bc02f0,0x938801ec,0x346001f7}},	//   rtőt, pká_, _асқа_, _اهڙِ, 
   {{0x2c6c05d5,0x1ce00327,0x24340092,0x00000000}},	//   tüd_, _སྨང_, _የነፃነ, --, 
   {{0x91fc4424,0xc0c80092,0x00000000,0x00000000}},	// [22210] stās, _አፋር_, --, --, 
   {{0x60c0eda6,0xd3781050,0xafd805ac,0x2d8c0427}},	//   ømme, biće_, rsøs, žge_, 
   {{0x2c6c0793,0xad980332,0x75fc036e,0x00000000}},	//   süd_, _bhút, lëzu, --, 
   {{0xad9832d8,0x99980276,0x00000000,0x00000000}},	//   _chút, икхт_, --, --, 
   {{0xad9801e7,0x29180309,0x00000000,0x00000000}},	//   _dhút, äqa_, --, --, 
   {{0x57241e87,0x600002f6,0xdb1c01ab,0x1a68030f}},	//   يرىق, tömi, _flrà, _چیلی_, 
   {{0x25bcada3,0x75fc0240,0x45d400a7,0x1a682099}},	//   tkul_, hëzu, йцит, _نیلی_, 
   {{0x49e401d9,0x96b80137,0x60000108,0x75fc0200}},	//   _آرٕ, рушу_, römi, këzu, 
   {{0x600029ef,0xad980241,0xd3783421,0x75fc0200}},	//   sömi, _ikúd, ziće_, jëzu, 
   {{0x84e40046,0x25bc9ca6,0xd7f82c31,0x7dc80432}},	//   _қолж, skul_, _кух_, _iýse, 
   {{0x5694c051,0x00000000,0x00000000,0x00000000}},	//   _мафт, --, --, --, 
   {{0xd37838bb,0x69c80007,0xad98007b,0x94a80014}},	//   viće_, nhge, _mhús, _چاوِ_, 
   {{0x6e34003b,0x94a801d9,0x74105d95,0x75fc0240}},	//   _atxb, _ناوِ_, تویا, gëzu, 
   {{0xd3780552,0x6d4809f3,0x9f580023,0x442c072c}},	//   tiće_, ðgan, morë_, mqe_, 
   {{0x82342b1f,0x75fc02d3,0x442d1f25,0x9f580240}},	//   _ارتا, rëzv, lqe_, lorë_, 
   {{0xd3780552,0x29d801f2,0x81e4015b,0x91800228}},	//   riće_, ụaja_, _বীর_, _قۇپۇ, 
   {{0xd37817a3,0x9f5802d3,0xafd828b3,0x442d51fd}},	// [22220] siće_, norë_, rsør, nqe_, 
   {{0xbb4951fe,0x7f840597,0xd3780552,0x611801e1}},	//   الان_, _الدن, piće_, _e̟lò, 
   {{0x9f58036e,0x6b80000d,0x00000000,0x00000000}},	//   horë_, õnga, --, --, 
   {{0xfce5122b,0x9f5802d3,0xdb1c01e6,0x91fc00e2}},	//   _гомо, korë_, _omrö, huān, 
   {{0xad980174,0xb4d400e1,0x9f580200,0xa874007b}},	//   _skúg, _सधे_, jorë_, محور_, 
   {{0xab2551ff,0xfaa4ae50,0x7f4c0477,0x9f58036e}},	//   _гора_, _лаго, nabq, dorë_, 
   {{0x7bdd5200,0x7dc95201,0x442c0548,0xd8880014}},	//   mipu, _týsd, eqe_, _چھتن_, 
   {{0x7bdc07e2,0x69c95202,0x7f4c014f,0x9f58036e}},	//   lipu, chge, habq, forë_, 
   {{0xacb8006a,0x6fc80213,0x9f580200,0xdddc00e5}},	//   _ngûl, _hüce, gorë_, ntrő, 
   {{0x7bdd5203,0x38640ac5,0xdebc03f9,0xe6900241}},	//   nipu, muor_, sarƙ, _fáàá, 
   {{0x386405b1,0x442c011f,0xad980332,0x47bc00cc}},	//   luor_, aqe_, _mhúr, ্চশী, 
   {{0x7bdc034c,0x31c40b32,0x6fc805d1,0x75fc0240}},	//   hipu, ссов, _müce, tëzu, 
   {{0x7bdd5204,0xf5055205,0x644c04d4,0xdef80032}},	//   kipu, _уздо, ácit, ҡыс_, 
   {{0x75fc0023,0x7bdc01f7,0x69c8e2ee,0x9f344f32}},	//   rëzu, jipu, zhge, зері, 
   {{0x7bdd5206,0xe3aca5f4,0x91fc0061,0x63740302}},	//   dipu, _سرو_, trād, _הגוף_, 
   {{0x3ebc03d4,0x7bdc017a,0x75fc0200,0x09bc00fe}},	//   øtta_, eipu, pëzu, _আগভা, 
   {{0x6f84084c,0x7bdd5207,0x29d800b4,0xad9803b2}},	// [22230] _лунж, fipu, ụaka_, _shús, 
   {{0x7bdcf169,0xad980597,0x2bb800c6,0xb4d4302b}},	//   gipu, _chúr, دارة_, _सधै_, 
   {{0x5edc00fe,0x9f58036e,0x442cf06d,0x6fc803e0}},	//   _মুঠে, zorë_, zqe_, _cüce, 
   {{0x3864914f,0x7bdc0b4f,0xc0c80092,0x442c5d49}},	//   fuor_, aipu, _አላህ_, yqe_, 
   {{0x7bdc04fb,0xdd980276,0xe6900241,0x00000000}},	//   bipu, _ушэ_, _sáàá, --, 
   {{0x69c804fb,0xad980225,0x7bdc34fe,0x9848100e}},	//   shge, _thús, cipu, сяца_, 
   {{0x442c0429,0xdce401e4,0xdb1c032e,0x6fc80205}},	//   wqe_, ifiĝ, _alræ, _güce, 
   {{0x9f5802d3,0x060807b5,0x3dc40327,0x00000000}},	//   torë_, јник_, _ċowk_, --, 
   {{0x91fc00b0,0x6fc80205,0x75d00137,0x00000000}},	//   tuān, _mücb, بييا, --, 
   {{0xa3d01533,0x442d5208,0x9f580023,0x6fc805d1}},	//   सों_, rqe_, rorë_, _yüce, 
   {{0x9f5802d3,0x442c036e,0xf218033f,0xe3b40150}},	//   sorë_, sqe_, नगढ़_, _ғұн_, 
   {{0x7bdce42b,0x9f580113,0x97c40150,0x442c0477}},	//   zipu, moré_, _وتەم, pqe_, 
   {{0x69d8a5e6,0xe504247f,0x9f585f72,0x442d5209}},	//   _mmue, _اباي, loré_, qqe_, 
   {{0xd7ac0073,0x78b405ac,0x91fc00e2,0x03a4011c}},	//   चायच, øyvi, grāb, _фико, 
   {{0x9f59520a,0x7bdd520b,0x69d80083,0xafd803cd}},	//   noré_, vipu, _omue, rsøp, 
   {{0x80640b46,0x6da1520c,0xada1520d,0xd3781b24}},	//   _движ, миса, масл, mića_, 
   {{0x7bdd520e,0xd3780989,0x11e80592,0xfc18007b}},	// [22240] tipu, lića_, _دعوي_, لقرب_, 
   {{0x69d9520f,0x9f58019f,0xd91001d3,0xaba4457e}},	//   _amue, koré_, ہیز_, овуз_, 
   {{0x7bdd5210,0xd378098d,0x9f580129,0xdddc00e5}},	//   ripu, nića_, joré_, strő, 
   {{0x7bdd5211,0x38641730,0x83280135,0xa9655212}},	//   sipu, tuor_, _ལུའུ_, жица_, 
   {{0x7bdd5213,0x91fc00da,0xd378a720,0xdcc80166}},	//   pipu, duāl, hića_, _уңае_, 
   {{0xd3780552,0x5694e0a6,0x7bdc0309,0xb098010f}},	//   kića_, закт, qipu, יינר, 
   {{0xd3781591,0x3a28089c,0xa3bc00af,0x6fc84dd9}},	//   jića_, _uubp_, ीसन_, _hücc, 
   {{0xd3780bb8,0x69d8009a,0xb17803cd,0xa96400d8}},	//   dića_, _gmue, rnåk, _миса_, 
   {{0xb7e4ce59,0x38640d63,0x37e40798,0x33a80454}},	//   _джак, quor_, _доаг, аъно_, 
   {{0xd37805ce,0x9f595214,0xa76000cf,0x00000000}},	//   fića_, boré_, _окуд, --, 
   {{0xd3781505,0x94a8040d,0x9f5806af,0x51f80a4a}},	//   gića_, ртқа_, coré_, йною_, 
   {{0xfec0015b,0x20180240,0x1aec0154,0x00000000}},	//   োপাধ, emri_, _করাই_, --, 
   {{0xa5040e91,0x60f89f4d,0x00000000,0x00000000}},	//   _деца_, жняя_, --, --, 
   {{0x425400dd,0xd37805ce,0x60c00158,0x00000000}},	//   _کنٹر, bića_, ømma, --, 
   {{0x91fc005f,0xd378110c,0x9258d4de,0xdd9000d1}},	//   grāc, cića_, _уайт_, چۈپ_, 
   {{0x81700131,0xdd900131,0xad985e4f,0x4ea55215}},	//   _كۆپچ, نۈپ_, _chúp, орға, 
   {{0x1ce0038f,0xdfd0004b,0x30f40014,0xdc980150}},	// [22250] _སྨད_, ريې_, _گوکھ_, овті_, 
   {{0x69d80421,0xaac55216,0x91fc00e2,0x6abc0183}},	//   _smue, يتان, zuāl, _এইবো, 
   {{0x37c0015b,0x0af8007b,0x60015217,0x2aa80114}},	//   ্চার, حفاظ_, römt, штао_, 
   {{0x9f580129,0x99d414af,0xad6400f2,0xdea40244}},	//   voré_, وتنا, _باده, _تیفی, 
   {{0xc7a4cf99,0x07a4c050,0xd3780960,0xc0c80092}},	//   зилк, залн, zića_, _አዋሳ_, 
   {{0x9f595218,0xfcbc1954,0x00000000,0x00000000}},	//   toré_, _ደርጃ_, --, --, 
   {{0x91fc00da,0x7dc803b2,0x28d82356,0xdd380055}},	//   tuāl, _hýsa, _मेरि, _nāśo, 
   {{0xd3780bb8,0x78a43a4a,0x9964004e,0x69d801e1}},	//   vića_, _škve, _отул, _umue, 
   {{0xe5a01f71,0xd83805f5,0x9f5906cd,0xdb1c01e3}},	//   зиқи, _дэх_, soré_, _elrä, 
   {{0xd3782d2b,0xdce40374,0x47d50696,0x9f5800d8}},	//   tića_, ngiā, _عيار, poré_, 
   {{0x1ce0038f,0x850525d0,0xc2c55219,0x7dc8041e}},	//   _སྨན_, _کوشن, سيحي, _lýsa, 
   {{0xd3780989,0x793c00b7,0x00000000,0x00000000}},	//   rića_, ርስቶስ, --, --, 
   {{0xd37805ce,0x6578014b,0x7dc802d2,0x1aec00fe}},	//   sića_, mfuh, _nýsa, _কৰাই_, 
   {{0x43741a4c,0x78a4008c,0xd378041a,0x65780327}},	//   _זײַן_, _ákve, pića_, lfuh, 
   {{0x9f580356,0x91fc00e2,0x00000000,0x00000000}},	//   borî_, urāc, --, --, 
   {{0xc8bc3eaf,0x6281521a,0x65780112,0x00000000}},	//   ्नाट, _ipno, nfuh, --, 
   {{0xc0e415bd,0x28d821b8,0x3c640024,0x00000000}},	// [22260] _хопк, _मेलि, якаг, --, 
   {{0x600033da,0xb098011a,0x00000000,0x00000000}},	//   röms, _פייר, --, --, 
   {{0x3f880066,0xa3c0000d,0x00000000,0x00000000}},	//   mebu_, _एकन_, --, --, 
   {{0x3f89521b,0x62800109,0xcd280014,0x3234010f}},	//   lebu_, _mpno, _وسُن_, לטען_, 
   {{0x68411376,0x00000000,0x00000000,0x00000000}},	//   енча, --, --, --, 
   {{0x62800a85,0x3f880368,0x00000000,0x00000000}},	//   _opno, nebu_, --, --, 
   {{0x65780327,0x7d0401f4,0x67501bf4,0x00000000}},	//   ffuh, _hyks, رخور, --, 
   {{0x7469521c,0x6fc82fbe,0x3f89521d,0x7d05521e}},	//   бров_, _müca, hebu_, _kyks, 
   {{0xfcbc02d3,0x3f8824be,0x00000000,0x00000000}},	//   _ደርጊ_, kebu_, --, --, 
   {{0x3f8816a3,0xe410010b,0x6f780150,0x00000000}},	//   jebu_, ндыь, _ﺠﻤﺎﻋ_, --, 
   {{0x3f881459,0x7d05521f,0xd6c40edf,0x6578002f}},	//   debu_, _lyks, _تمای, bfuh, 
   {{0x91fc00b0,0x7c3800bc,0x853400db,0x00000000}},	//   muāk, _čtrn, _قومچ, --, 
   {{0x64a15220,0x7d055221,0x05a8095f,0x00000000}},	//   _паца, _nyks, कारब, --, 
   {{0x3f88af98,0x24040408,0x00000000,0x00000000}},	//   gebu_, _енчи_, --, --, 
   {{0xddd04031,0xd37801a6,0xdcf40135,0x00000000}},	//   _šeši, lićo_, _ħaġa, --, 
   {{0x6fc806be,0x00000000,0x00000000,0x00000000}},	//   _düca, --, --, --, 
   {{0x3f88016b,0x7d04010e,0xab295222,0x9a780092}},	// [22270] bebu_, _cyks, مسال_, _ያልከው_, 
   {{0xfe6d5223,0x7d040b21,0x92c0045e,0x7dc802fb}},	//   دگی_, _dyks, ূপী_, _výsa, 
   {{0xc95804a9,0x7d0401a8,0x00000000,0x00000000}},	//   قلاش_, _eyks, --, --, 
   {{0x3ebd5224,0x7d0405ac,0x195800c0,0x00000000}},	//   ätte_, _fyks, зацы_, --, 
   {{0x6d4c00de,0x88180006,0x00000000,0x00000000}},	//   _ieca, оўку_, --, --, 
   {{0x6d4d5225,0x4638005b,0xdddc0171,0x00000000}},	//   _heca, очия_, gurņ, --, 
   {{0x6d4c032b,0x4ac414fe,0x05a8000d,0x7dc802d2}},	//   _keca, _غيرق, कालब, _mýsn, 
   {{0x84595226,0x7dc803b2,0x19940006,0x600001f4}},	//   орот_, _lýsn, _пася, hömp, 
   {{0x65780327,0x00000000,0x00000000,0x00000000}},	//   rfuh, --, --, --, 
   {{0x6d4d5227,0x65780112,0x00000000,0x00000000}},	//   _leca, sfuh, --, --, 
   {{0x65780810,0x6d4c02d0,0xd77410e0,0xa6440133}},	//   pfuh, _oeca, _سالع, _رخان, 
   {{0x3f895058,0xd6182363,0x00000000,0x00000000}},	//   webu_, _فتنا_, --, --, 
   {{0x66191e0d,0x955404fb,0x7dc808a5,0xb6240150}},	//   mmuk, _سخنا, _býsn, _ﺭﺭ_, 
   {{0x7d055228,0x66195229,0x443c0129,0xa5580092}},	//   _ryks, lmuk, _itw_, _ፍትሃዊ, 
   {{0x6d4d522a,0x7d04049b,0x3f89522b,0x443cb1e1}},	//   _beca, _syks, rebu_, _htw_, 
   {{0x6d4d522c,0x6619522d,0x3f88009f,0xa3c005dc}},	//   _ceca, nmuk, sebu_, _एकड_, 
   {{0x6d4d522e,0x66180099,0x3f880158,0x5ba400fb}},	// [22280] _deca, imuk, pebu_, нлағ, 
   {{0x8bf003f4,0x7d0402d5,0x310401ee,0x00000000}},	//   _জীবন_, _vyks, _юнып_, --, 
   {{0x1ee80cb8,0xb0580793,0x443c007f,0x3d20013f}},	//   _روحی_, nyän, _ltw_, sɔw_, 
   {{0x6d4d522f,0x661805b1,0x443c0083,0x3d200134}},	//   _geca, jmuk, _otw_, pɔw_, 
   {{0x443d5230,0xa3bc46c7,0x91fc0882,0x661807f5}},	//   _ntw_, ीसा_, krān, dmuk, 
   {{0x6d4c00f1,0x6618013f,0xb8d405b3,0x38580092}},	//   _zeca, emuk, _छप_, _ኃይለሥ, 
   {{0xd6d00597,0x443d5231,0x6d4c4242,0x64480067}},	//   طقة_, _atw_, _yeca, _awgi, 
   {{0xd5b006d5,0x66195232,0x6d4c004e,0x443c2238}},	//   افة_, gmuk, _xeca, _btw_, 
   {{0x443c0332,0x91fc00ef,0x00000000,0x00000000}},	//   _ctw_, frān, --, --, 
   {{0x394402d5,0xe8d402e4,0xc8b4008e,0x00000000}},	//   lbos_, _חומר_, _яссы, --, 
   {{0x443c0112,0x9f5800c7,0x00000000,0x00000000}},	//   _etw_, korâ_, --, --, 
   {{0x39455233,0x38640295,0xf1a55234,0x38c404ce}},	//   nbos_, oror_, фрон, のrss_, 
   {{0x92c00183,0x443c020b,0x3944928f,0x7dc8010b}},	//   ূপে_, _gtw_, ibos_, _aýso, 
   {{0x6d4d5235,0x91fc00e2,0x250843fb,0xb0580139}},	//   _seca, ntāz, _برمی_, byän, 
   {{0x9f58004e,0x9f3402dd,0xe1f0004b,0x00000000}},	//   corí_, тесі, اسۍ_, --, 
   {{0x386401b9,0x00000000,0x00000000,0x00000000}},	//   kror_, --, --, --, 
   {{0x6d4d5236,0x62940077,0x656c0561,0xf1a802f2}},	// [22290] _veca, _áxor, òchi, _هاکه_, 
   {{0x2fc401dc,0x60c15237,0x6d4d5238,0xaae41ec7}},	//   _ông_, ämme, _weca, وساو, 
   {{0x38655239,0x6d4d523a,0x5b2405f5,0xf09d523b}},	//   eror_, _teca, вьца, lvà_, 
   {{0x386400a9,0x78a45c9a,0x32080175,0x6d4c03ac}},	//   fror_, _škva, nlcy_, _ueca, 
   {{0x3864067c,0xf09c04cc,0xbd000306,0x7dc802d2}},	//   gror_, nvà_, žérn, _mýsl, 
   {{0x9f580ed2,0x999803b9,0x2b5401e2,0x00000000}},	//   morã_, _turş_, _آیاد_, --, 
   {{0x443c2a9c,0x91fc02b1,0xb17803cd,0x5a342b2e}},	//   _stw_, puāh, nnås, _анст, 
   {{0x38645629,0x9f5801a2,0x3944009a,0x7dc802d2}},	//   bror_, vorí_, cbos_, _nýsl, 
   {{0xf6980086,0x91fc0882,0xa3e00ebb,0x9f5800e4}},	//   òùrö_, trān, _नगद_, norã_, 
   {{0x78a4008c,0xd8780014,0xc0c8001f,0x6619523c}},	//   _ákva, _آمٕت_, _አላማ_, smuk, 
   {{0x443c0af9,0x00000000,0x00000000,0x00000000}},	//   _wtw_, --, --, --, 
   {{0xad98002d,0xafd82d8b,0x443c0477,0x9f580124}},	//   _skún, msøy, _ttw_, korã_, 
   {{0xc0c80020,0x443c00ca,0xafd82d8b,0xe3b402dd}},	//   _አቋም_, _utw_, lsøy, _жұп_, 
   {{0x98b80882,0x9f5800e4,0xa3e0000d,0x00000000}},	//   _śrī_, dorã_, _नगि_, --, 
   {{0x394402d5,0x249d523d,0xdb1c05d1,0xafd80158}},	//   ybos_, lvum_, üzün, nsøy, 
   {{0xdb1cff0c,0x7dc80306,0x3864007c,0x83fc00e5}},	//   _forê, _výso, yror_, jtőz, 
   {{0xa3c005ba,0x3dd00f7b,0xa3e00764,0x5f880014}},	// [222a0] _एका_, rhyw_, _नगा_, _ہٕکہ_, 
   {{0xeb94084c,0x2d8c000f,0xafd803cd,0x249c0162}},	//   ниу_, ôger_, ksøy, ivum_, 
   {{0x384802d3,0xc8780724,0x9f59523e,0xb17801e3}},	//   _ዝተራእ, _aqş_, morà_, pnåt, 
   {{0x3945523f,0x3f995240,0x38655241,0x7c28014b}},	//   ubos_, _hapu_, tror_, _номг_, 
   {{0x3f995242,0xa92410f5,0x9f580589,0xb34406ed}},	//   _kapu_, ніше_, corã_, niçõ, 
   {{0x3f9800c7,0x9f5805d5,0xb1780fac,0x4cd800cc}},	//   _japu_, norà_, nnår, _ভুকু, 
   {{0xdb1c02d3,0xafd80158,0x249c003a,0x7dd801ef}},	//   _morë, gsøy, evum_, bůst, 
   {{0x3f995243,0x28d8547d,0x386401e3,0x91fc00ef}},	//   _lapu_, _मेकि, pror_, grāl, 
   {{0xf7700a2c,0x249c022c,0x7e6c00d2,0x941801c0}},	//   _ماا_, gvum_, hubp, мжит_, 
   {{0xb344315a,0x3f9803f0,0x7dc809f3,0xd5b001ed}},	//   diçõ, _napu_, _sýsl, افک_, 
   {{0xc7640202,0x249c003a,0xe1cc0892,0x91fc0171}},	//   _جاقى, avum_, ासंघ, brāl, 
   {{0x3f980069,0x7c340240,0xa19400d3,0xe3ac5f32}},	//   _aapu_, kqyr, гаюч, _ۇرى_, 
   {{0x7dc803c6,0x3f980ffb,0x9f580109,0xdb1c0240}},	//   _výsl, _bapu_, forà_, _borë, 
   {{0xb4bc02ab,0x3f982b1d,0x6fc803be,0xf09d4d70}},	//   ीनी_, _capu_, _gücl, rvà_, 
   {{0xdb1d5244,0x3f98047e,0xee70fb04,0x5cc4010b}},	//   _dorë, _dapu_, ыңны, ңсуз, 
   {{0xdd94e181,0xb34403b7,0x3ebc049f,0x60c02305}},	//   ласы, biçõ, ätta_, ämmc, 
   {{0xdb1c00e8,0x9f586679,0x9ed8010b,0x00000000}},	// [222b0] _forë, borà_, _үмыт_, --, 
   {{0xdb1d5245,0x9f592e49,0x91fc00b0,0x00000000}},	//   _korè, corà_, tuāw, --, 
   {{0x16200d79,0x9f5800e4,0x00000000,0x00000000}},	//   मगार_, sorã_, --, --, 
   {{0x3f980099,0xaf4801ed,0xdb1c0241,0xafd803cd}},	//   _zapu_, _بشکل_, _morè, vsøy, 
   {{0x3f980054,0xdb1c0066,0x83fc01ed,0x7dd800bc}},	//   _yapu_, _lorè, rtőz, růst, 
   {{0x91fc00b0,0xafd80158,0xb05801f4,0xa09c00df}},	//   puāw, tsøy, jyäm, פיוט, 
   {{0x91fc0a30,0x5ba40395,0x7d000327,0x00000000}},	//   trāl, _сряз, żost, --, 
   {{0xc4855246,0xafd803cd,0xad9801e1,0x6a1400f2}},	//   влик, rsøy, _okúm, _سبزر, 
   {{0x91fc3a71,0xf8ac208f,0xafd80217,0x91a8004d}},	//   grām, _وکه_, ssøy, _giả_, 
   {{0xad981125,0x249d5247,0xafd805ac,0x69c8017a}},	//   _skúl, rvum_, psøy, lkge, 
   {{0x3f980325,0x27e55248,0xdb1c180f,0xd7f801fc}},	//   _rapu_, minn_, _corè, _чут_, 
   {{0x27e55249,0xb34406ed,0x69c90388,0x26c40153}},	//   linn_, tiçõ, nkge, myno_, 
   {{0x3f9818a6,0x26c40024,0x69c801a4,0x0bb40150}},	//   _papu_, lyno_, ikge, _ﹼﺠﺎﻫ, 
   {{0xb3440261,0x3f980227,0x27e5524a,0xdb1d524b}},	//   riçõ, _qapu_, ninn_, _forè, 
   {{0xb3440261,0xdb1d524c,0x64580b4f,0xad9801e1}},	//   siçõ, _gorè, lsui, _ikúj, 
   {{0x27e40876,0x69c80d27,0x3f980309,0xdce40841}},	//   hinn_, jkge, _wapu_, ngić, 
   {{0x3f99524d,0x27e4008c,0x6459524e,0x6cc1524f}},	// [222c0] _tapu_, kinn_, nsui, айта, 
   {{0x64595250,0xfaa40249,0xdb1c00d5,0x3c3400b5}},	//   isui, казо, _horé, _væv_, 
   {{0x7c3402d3,0x27e55251,0xdb1c032b,0x61e4025c}},	//   sqyr, dinn_, _koré, _kmil, 
   {{0x64595252,0x27e401ab,0x3c34005c,0x26c40153}},	//   ksui, einn_, _tæv_, dyno_, 
   {{0xf770036d,0x27e55253,0x61e469b2,0x64595254}},	//   لاغ_, finn_, _mmil, jsui, 
   {{0x27e55255,0xf0900bd9,0x91fc0421,0x69c80549}},	//   ginn_, ינד_, luāt, akge, 
   {{0x7dc809f3,0xebe098a4,0xf10c00e1,0x67d002bf}},	//   _nýsk, _торп, _सर्द_, рощу, 
   {{0xad9801e1,0x69c82155,0xd3782630,0xdb1c003e}},	//   _akúj, ckge, mići_, _noré, 
   {{0xb4bd5256,0xd3780552,0x533484d0,0x79815257}},	//   ीने_, lići_, лепт, mfow, 
   {{0x61e48f27,0x79815258,0x27e40192,0x28d809ab}},	//   _amil, lfow, cinn_, _मेटि, 
   {{0xd6c47935,0xa3e022e3,0xa3c0033d,0x78a00122}},	//   _حمای, _नगर_, _एकर_, lvov, 
   {{0xdb1d5259,0xb178003b,0x79810254,0x00000000}},	//   _coré, gnåp, nfow, --, 
   {{0xdb1d525a,0xd3780841,0x645801e7,0xefc40023}},	//   _doré, hići_, csui, _ጽሓይ_, 
   {{0x60c0049f,0xdb1c0214,0xd37804a7,0x78a000e4}},	//   ämma, _torè, kići_, ivov, 
   {{0xd37805a1,0xc0c004a9,0xdb1d525b,0x6fc80112}},	//   jići_, _һәри, _foré, _hück, 
   {{0xd378098d,0x27e40585,0xdb1c0438,0x973c107d}},	//   dići_, zinn_, _goré, _inću, 
   {{0xdd944b18,0x78a00114,0x27e4007f,0x82500023}},	// [222d0] шаты, jvov, yinn_, _መተሓሳ, 
   {{0xd3782220,0x79800472,0x9f58056a,0x6fc80e78}},	//   fići_, efow, porá_, _mück, 
   {{0xdf540323,0x27e5525c,0x8ee0015b,0x6fc803fa}},	//   _өнөө, vinn_, _মুরগ, _lück, 
   {{0x27e403fa,0x64580af9,0x5edc009e,0x00000000}},	//   winn_, ysui, _মুকে, --, 
   {{0x27e5525d,0x69c808f7,0x26c40cfd,0xa3c003f8}},	//   tinn_, rkge, wyno_, _एकल_, 
   {{0xd37808ad,0x869817a0,0x60c008fb,0x69c8002d}},	//   bići_, етит_, ømmi, skge, 
   {{0x27e5525e,0xa260004d,0x6458c973,0xda7802e8}},	//   rinn_, _cuố, wsui, _ият_, 
   {{0xaf88069c,0x27e5525f,0x64595260,0xd8755261}},	//   _ህዝብና_, sinn_, tsui, _چالب, 
   {{0x27e55262,0x64580194,0xc7f802bf,0xad98dcf0}},	//   pinn_, usui, _знає_, _akúk, 
   {{0x61e4378c,0x0394136b,0x64581905,0xdb1d5263}},	//   _smil, урия, rsui, _soré, 
   {{0x5694b6f0,0x645832ff,0x422428cf,0xdb1c0a62}},	//   _вахт, ssui, лдов, _poré, 
   {{0x7dc80313,0x2ca402ea,0x6458bb8d,0x06e403d4}},	//   _výsk, ́nda_, psui, _পুথি, 
   {{0x6fc80730,0xd37805a1,0xdb1c00c7,0x25ad5264}},	//   _küch, zići_, _voré, _ingl_, 
   {{0x7dc95265,0x8334008f,0x7fd402dd,0x6fc8002f}},	//   _týsk, _גאַס_, уімі, _jüch, 
   {{0xdb1c82af,0x78a00099,0x61e40076,0x91fd0651}},	//   _toré, zvov, _tmil, tuāt, 
   {{0xd3780b91,0x68f800ac,0x6fc80b8b,0x00000000}},	//   vići_, _oxud, _lüch, --, 
   {{0x3b840323,0x6da00801,0xb884012c,0xb140005b}},	// [222e0] ллаг, щита, _kníž, _уныл, 
   {{0x7f755266,0xd37805ce,0x6fc817da,0xb2240162}},	//   _суиц, tići_, _nüch, _tjæð, 
   {{0x68f836ed,0x7dc809cc,0x592c0135,0xab740046}},	//   _axud, _lýsi, _སུངས_, امما_, 
   {{0x9f5800f7,0xd37805ce,0x91fc0882,0x2b4405d1}},	//   forç_, rići_, grāh, ınca_, 
   {{0x1754453f,0x6fc95267,0xa3c000dc,0xd378110c}},	//   авля, _büch, _एकं_, sići_, 
   {{0x6fc80639,0x78a00122,0xd37807f5,0x25ad5268}},	//   _rück, rvov, pići_, _angl_, 
   {{0x68f80b1d,0xf7700a81,0xb6840aaf,0x7c2c8faf}},	//   _exud, لاں_, اشتى, _iibr, 
   {{0x7c2d5269,0x326401d5,0xa2d400cd,0x00000000}},	//   _hibr, қтов, मनन्, --, 
   {{0xf7448af4,0xd3700075,0x7a380055,0x6fc80112}},	//   _безо, قۇش_, _kįto, _füch, 
   {{0x25ac016b,0x3dc0014b,0xa3c00882,0x91fc0a30}},	//   _engl_, _lokw_, _एकः_, prāk, 
   {{0x7c2c025c,0x777803ac,0x25900050,0xd2f801af}},	//   _mibr, _ictx, _گٔنز, тенц_, 
   {{0x3dc0014b,0x6fc808d5,0xdb1c0042,0x7dc808ce}},	//   _nokw_, _züch, _lorï, _fýsi, 
   {{0x7c2c0491,0x00000000,0x00000000,0x00000000}},	//   _oibr, --, --, --, 
   {{0x7c2c0009,0x91fc00ef,0x00000000,0x00000000}},	//   _nibr, guār, --, --, 
   {{0xb644037e,0x25ac015d,0xe29400f0,0x00000000}},	//   _ｋｋ_, _yngl_, _бај_, --, 
   {{0x7c2c0597,0xb88401f1,0xe818033f,0x00000000}},	//   _aibr, _zníž, _पीना_, --, 
   {{0x7c2c5931,0xd7f80356,0x00000000,0x00000000}},	// [222f0] _bibr, _ojă_, --, --, 
   {{0x7c2d526a,0x00000000,0x00000000,0x00000000}},	//   _cibr, --, --, --, 
   {{0x7c2d526b,0xc955526c,0xdb1c0142,0x00000000}},	//   _dibr, атлы, _dorï, --, 
   {{0xaca0063f,0xd378041a,0x77780175,0x6fc80ade}},	//   _agụb, miću_, _actx, _süch, 
   {{0xd3781591,0x6e2c009a,0x6fc805d5,0x99840311}},	//   liću_, _iicb, _püch, _simţ_, 
   {{0x07a46f36,0xc7a5526d,0x6e2c05d2,0x25e40037}},	//   ракн, рикк, _hicb, _जगही_, 
   {{0x45d44170,0xd37805ce,0x3dc0014b,0xd7583592}},	//   ицит, niću_, _yokw_, اجها_, 
   {{0x7c2c0165,0xb884012c,0x6e34036b,0x4465526e}},	//   _zibr, _sníž, _muxb, авив, 
   {{0x6e340a40,0xd37805be,0x6fc80e78,0x7c2c0009}},	//   _luxb, hiću_, _tüch, _yibr, 
   {{0x66804a23,0x7c2d526f,0xd37808a4,0x1b1800fe}},	//   _هیتل, _xibr, kiću_, _তলতে_, 
   {{0xd37807f5,0xb92800cd,0x00000000,0x00000000}},	//   jiću_, _syuḥ_, --, --, 
   {{0xd3780989,0xe7e83174,0x60c001e3,0x25ac02d2}},	//   diću_, _झगडा_, ämmo, _ungl_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6e3400c6,0xd37805ce,0xf4b40214,0xf1ac00bc}},	//   _buxb, fiću_, _خشمگ, टाउन, 
   {{0xd3780fcf,0x7c2d5270,0x660802d0,0x939400f1}},	//   giću_, _ribr, _kkgk, _دجنا, 
   {{0x91fc005f,0x7c2d5271,0x8fd400d1,0x3f9c0153}},	//   suār, _sibr, _һәсә, žtu_, 
   {{0x7c2c0076,0xdb343fe6,0x00000000,0x00000000}},	// [22300] _pibr, مذاک, --, --, 
   {{0xd37807f5,0x7c2cbdad,0x15ec0073,0x8fd400fb}},	//   biću_, _qibr, _जगभर_, _ләсә, 
   {{0xeb955272,0x6e2c01ab,0xd37800f3,0x75fc005f}},	//   рих_, _ficb, ciću_, līze, 
   {{0x7c2d5273,0xed5418bc,0x973c04a7,0xb7580051}},	//   _wibr, _кою_, _maće, _thừơ, 
   {{0x7c2d5274,0xad9801e1,0xdb1c015d,0xb8fc00e4}},	//   _tibr, _akúw, _torï, pỹmí, 
   {{0x600002f6,0x7c2d5275,0xd78801d5,0xdb1c00d8}},	//   tömy, _uibr, انغو_, _horí, 
   {{0xd9102b7e,0xdb1c0248,0xdd1400d7,0x79b400e5}},	//   _کیش_, _korí, _sĺňa, _پھاڑ_, 
   {{0xe8180037,0x06e400cc,0x00000000,0x00000000}},	//   _पीठा_, _পুহি, --, --, 
   {{0xdb1d5276,0xd3780e3c,0x48ec05dc,0x68440023}},	//   _morí, ziću_, _आइयो_, ከኣለት, 
   {{0xdb1c01e1,0xe3c400b8,0x2bf800cd,0x75fc00de}},	//   _lorí, _nañā_, ्वयं_, dīze, 
   {{0xe734da2c,0xd7f005d9,0x7dc80162,0x533401e0}},	//   _тех_, _وڃڻ_, _hýsu, _һелт, 
   {{0xd3780bb8,0x66080098,0x973c0cf4,0x168403e6}},	//   viću_, _gkgk, _daće, _ناڵێ, 
   {{0xe8195277,0x6e3401d5,0x6fc80205,0xe4e0003b}},	//   _पीडा_, _suxb, _mücv, _мішн, 
   {{0xd37856af,0xdb1d5278,0xe4e8000d,0x00000000}},	//   tiću_, _morâ, _जइति_, --, 
   {{0x6378008d,0xdb1c01ed,0x6e2c0175,0x7dc82507}},	//   _סנהד, _borí, _picb, _lýsu, 
   {{0xd3780552,0xdb1c0120,0x00000000,0x00000000}},	//   riću_, _corí, --, --, 
   {{0xd904323b,0x6f841250,0x75fc00e2,0x62240228}},	// [22310] _آی_, _кунж, cīze, _بىيل, 
   {{0x9f4c025a,0xd37807f5,0x6e340129,0x91fc1c52}},	//   ôdô_, piću_, _tuxb, grāv, 
   {{0xd8b804fb,0xdb1c0241,0x6e2c0332,0x00000000}},	//   یدها_, _forí, _ticb, --, 
   {{0x77340020,0xad9800e4,0xce480139,0x9984b1d7}},	//   _ብሄረሰ, _akúv, _изүе_, قلمو, 
   {{0x2d880218,0x7ae00115,0x93f800cd,0xc768009d}},	//   _ibce_, ĝota, ुवाच_, гилж_, 
   {{0xe784490c,0xdce4010f,0x97c40145,0xc3200011}},	//   рудо, ngiĝ, قتىم, পুটি_, 
   {{0x5a4402d5,0x764400e5,0x00000000,0x00000000}},	//   _мэта, میلِ_, --, --, 
   {{0xdce80034,0x13a803e6,0x00000000,0x00000000}},	//   śląs, یۆنی_, --, --, 
   {{0x6fc803be,0x95c810f3,0x6abc03d4,0x58d40408}},	//   _hücu, руја_, _এইটো, _дотт, 
   {{0x7dc808ce,0x2ca80051,0x00000000,0x00000000}},	//   _hýst, _mrcd_, --, --, 
   {{0x2d895279,0x42e855f3,0x03a421f3,0xf40c0133}},	//   _obce_, умно_, _ҳило, رڤه_, 
   {{0xa3c00e49,0x2ca80153,0xe81815e0,0xf1bc032e}},	//   _एकक_, _orcd_, _पीता_, gjá_, 
   {{0xcf2c00ac,0x25bc0158,0x9f5801ed,0x91fc02b5}},	//   əşəm_, mjul_, morú_, ruāp, 
   {{0x248c05b1,0x7dc80ad9,0xdb1c0139,0x25bd527a}},	//   _ipgm_, _lýst, _sorí, ljul_, 
   {{0x44240036,0xdb1d527b,0xafe001a9,0x00000000}},	//   mml_, _porí, чорл, --, 
   {{0x25bc5d69,0xfe440364,0x2d880175,0xad9801a8}},	//   njul_, инҳо, _cbce_, _ljúf, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [22320] --, --, --, --, 
   {{0x44240113,0x83fc00e5,0x7dc8013a,0x00000000}},	//   nml_, lsőb, _rýsu, --, 
   {{0x25bc072b,0xdb1d1e04,0x00000000,0x00000000}},	//   kjul_, _torí, --, --, 
   {{0xb865527c,0xdb1c00c7,0xeb940116,0xad9806ea}},	//   ماتو, _aorã, _қис_, _skúv, 
   {{0x06e42f8b,0x260800e1,0xa9647228,0x3dd00334}},	//   _পুলি, ावनी_, сича_, mkyw_, 
   {{0x44240944,0x7dc802fd,0xdb1c00d8,0x6b500790}},	//   jml_, _výsu, _corã, rıgü, 
   {{0xf608352d,0x44240204,0x91fc00e2,0xad9802d2}},	//   лхий_, dml_, nsāc, _djúf, 
   {{0x82e4031c,0x2f200129,0x9f5801d3,0x00000000}},	//   _སྟེའ, légé_, gorú_, --, 
   {{0xdb1d527d,0x2888036b,0xad983d64,0x656c7479}},	//   _forã, _مصلی_, _ikút, ócha, 
   {{0x25bc0311,0x91fc005f,0x764811ad,0x93bc0356}},	//   ajul_, ksāc, ppfy, amăn, 
   {{0x51f800d6,0x91fc005f,0x9f5801d3,0x6fc803e3}},	//   иною_, krāt, ború_, _müct, 
   {{0xdb1c004e,0x00000000,0x00000000,0x00000000}},	//   _morà, --, --, --, 
   {{0x91fc0f40,0xdb1c0241,0xf1bc03b2,0xe3ac04f2}},	//   drāt, _lorà, rjá_, ذری_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xed88a4f0,0xdce400df,0xad9801e1,0x00000000}},	//   лсак_, rgiĝ, _okút, --, 
   {{0x720401ed,0x8e140111,0x00000000,0x00000000}},	//   _دفعہ_, ідац, --, --, 
   {{0x3208068f,0xdb24025c,0x91a801fb,0xad9808a5}},	// [22330] mocy_, _འཛུཌ_, _giá_, _ljúg, 
   {{0xad99527e,0x00000000,0x00000000,0x00000000}},	//   _akút, --, --, --, 
   {{0xad253115,0x99995087,0x9cc801e0,0xad98032e}},	//   _گردو, _gurū_, _һыра_, _rjúf, 
   {{0x6fc80365,0x3dd00036,0xdbdc01e1,0x00000000}},	//   _vücu, ckyw_, _láèl, --, 
   {{0x7dc80e96,0x6d5c31ec,0xdb1d527f,0xe8e80e53}},	//   _výst, maqa, _porã, دراو_, 
   {{0xad985fde,0x6d5d5280,0x44243c36,0x00000000}},	//   _ekút, laqa, xml_, --, 
   {{0x1a6800f1,0x00000000,0x00000000,0x00000000}},	//   _هیلی_, --, --, --, 
   {{0x6d5d5281,0x3ebc023a,0x99640276,0xa2d400dc}},	//   naqa, ätti_, _нтул, मनस्, 
   {{0x44255282,0x6d5c0af5,0x22440073,0x44380120}},	//   tml_, iaqa, _stnk_, ês_, 
   {{0xdb1d5283,0xd6d95284,0x6d5d5285,0x91fc1c52}},	//   _horá, ртә_, haqa, krās, 
   {{0xdb1c26f6,0x442401e0,0x6d5cb1b3,0x23c00014}},	//   _korá, rml_, kaqa, قٕکہ, 
   {{0x6d5c0869,0x538402d3,0x41281f5a,0x00847c3f}},	//   jaqa, _ክጻወት_, ионо_, олмо, 
   {{0xdb1d5286,0xe4c81867,0x850433d2,0x2bf800cd}},	//   _morá, _حبان_, _بوشن, ्वां_, 
   {{0x34b01060,0x999800b0,0xad980419,0x00000000}},	//   _آموز, _purū_, _okús, --, 
   {{0x63a15287,0x6d5d5288,0x0eb86f65,0xad980241}},	//   _iann, faqa, буты_, _ojúd, 
   {{0x6578a7ea,0x6d5c0af5,0x40945928,0x33701945}},	//   nguh, gaqa, _дрот, _егәр, 
   {{0x2f2007ea,0x973c00f3,0xbc68fc25,0xad980419}},	// [22340] tégé_, _laća, شمان_, _akús, 
   {{0x63a15289,0xad98765a,0x6d5c0140,0xdb1c0332}},	//   _jann, _skút, aaqa, _aorá, 
   {{0x63a1528a,0x6d5d4e17,0x91fc0318,0x384802d3}},	//   _mann, baqa, prāt, _ዝተላእ, 
   {{0x63a13844,0xdb1d528b,0xb17801e3,0x6d5cdd5e}},	//   _lann, _corá, rhåg, caqa, 
   {{0x63a1528c,0xdb1c0306,0xdbdc0ca8,0x6fc803b9}},	//   _oann, _dorá, _láél, _gücs, 
   {{0x6fc803ee,0xf645528d,0xdb1c004e,0x656c012d}},	//   _hücr, охин, _torà, óchn, 
   {{0xdb1c00c6,0xe7e80037,0x00000000,0x00000000}},	//   _forá, _झगरा_, --, --, 
   {{0x3940033d,0x6579528e,0xe4e802e5,0xdb1c00d7}},	//   _üks_, gguh, _जेहि_, _gorá, 
   {{0x628003e3,0x6fc806be,0xc8380023,0x00000000}},	//   _aqno, _mücr, ጸባርቕ, --, 
   {{0x63a1528f,0xbf180490,0xad980174,0x7a38002b}},	//   _cann, _धरून_, _tjúg, _pįth, 
   {{0x6d5d5290,0x973c16a3,0xefc80b82,0xc76407d2}},	//   yaqa, _gaća, በታዊ_, _رالى, 
   {{0x26080073,0xf1bc01e7,0xd2500014,0xb05800a2}},	//   ावणी_, amán_, ٘نگ_, dyär, 
   {{0x63a15291,0x6d5d5292,0xa3c00574,0x2d8401d3}},	//   _fann, vaqa, _एकच_, őnek_, 
   {{0x63a15293,0x6d5d5294,0x630000f1,0x00000000}},	//   _gann, waqa, _ښوول, --, 
   {{0x9f34005e,0x6d5d5295,0x00000000,0x00000000}},	//   дері, taqa, --, --, 
   {{0x63a0cf79,0xad980ca8,0x29d55296,0x7bc801a8}},	//   _zann, _ojúe, _açan_, öfun, 
   {{0x6d5d5297,0x63a15298,0xad9801a2,0x6b940076}},	// [22350] raqa, _yann, _skús, texg, 
   {{0x6d5d5299,0x7bdd529a,0xdb1c00dd,0xeb49109f}},	//   saqa, ghpu, _sorá, рчак_, 
   {{0x6578089c,0xdb1c4dab,0x6d5d529b,0x48ec000d}},	//   yguh, _porá, paqa, _आइहो_, 
   {{0xfe9800c8,0x6d5d529c,0xf1bd529d,0x00000000}},	//   _פירמ, qaqa, zmán_, --, 
   {{0xbd000129,0xdb1c01ef,0xb0580139,0x00000000}},	//   ééta, _vorá, lxäb, --, 
   {{0x7bdd529e,0xd7c88b4d,0x60c033eb,0x0c040014}},	//   chpu, يونه_, ämmi, _روزُ, 
   {{0x63a1529f,0x656c0332,0x765c0022,0xad2453a2}},	//   _rann, ócho, ápyp, _درگو, 
   {{0xd6a81066,0xe81800c5,0x00000000,0x00000000}},	//   زدىم_, _पीरा_, --, --, 
   {{0x69d86458,0xe7847ce9,0x657802c3,0xd90c072d}},	//   _ilue, _мужо, rguh, _پیو_, 
   {{0x9a880014,0x291c01c4,0x63a152a0,0x76c80014}},	//   _دنہٕ_, _izua_, _qann, _گُمہ_, 
   {{0x63a152a1,0x42082be5,0x981401d5,0x00000000}},	//   _vann, йноо_, _آبقا, --, 
   {{0x63a152a2,0xdb1c019b,0xf1bc04d4,0x00000000}},	//   _wann, _foræ, smán_, --, 
   {{0x82341973,0x7bd80227,0x6568014f,0xe4a41d4a}},	//   _کرتا, _ŋtum, _idgh, _фрео, 
   {{0x63a00af5,0x69d8db0c,0x443c002d,0xbb4800b5}},	//   _uann, _llue, _iuw_, _mahポ_, 
   {{0x443d52a3,0x69d952a4,0x00000000,0x00000000}},	//   _huw_, _olue, --, --, 
   {{0x443c013b,0x291c043b,0xdb1c062c,0xf1bc0008}},	//   _kuw_, _ozua_, _horç, nmál_, 
   {{0xdb1d52a5,0x443c002d,0x5ba40032,0xb14801af}},	// [22360] _korç, _juw_, млағ, _уныh, 
   {{0x69d952a6,0x443c0526,0xe81805f9,0x3120010b}},	//   _alue, _muw_, _पीला_, _ядыг, 
   {{0x291d52a7,0x69d952a8,0xfa34ad68,0x443d52a9}},	//   _azua_, _blue, سراد, _luw_, 
   {{0x7bdc9323,0x201801a8,0xa96400f3,0xdce8b097}},	//   shpu, llri_, зица_, şlıs, 
   {{0x443d52aa,0x00000000,0x00000000,0x00000000}},	//   _nuw_, --, --, --, 
   {{0x69d952ab,0x29d44a98,0xc70c00b8,0x00000000}},	//   _elue, _uçan_, _ṣaṭc, --, 
   {{0x69d952ac,0x291c02ea,0x443c01f5,0x644952ad}},	//   _flue, _ezua_, _auw_, _atgi, 
   {{0x69d8efa3,0x9f9426bb,0x75e40006,0x667000cf}},	//   _glue, _hää_, яўле, ردىر, 
   {{0xdb1d52ae,0x5ed0009e,0x9f940139,0x00000000}},	//   _borç, _হেমে, _gäç_, --, 
   {{0x9f940d77,0x443c00a9,0xdb1c004e,0x7f5c0455}},	//   _jää_, _duw_, _corç, _nepq, 
   {{0xa2600032,0x6448485b,0x9f94005b,0x6b6401d3}},	//   нъял, _etgi, _mää_, légí, 
   {{0x394474c3,0x443c013f,0x46a800bc,0x91fc00ef}},	//   ncos_, _fuw_, किरह, asān, 
   {{0xdb1d078c,0x7f5c0455,0xf8bc1b57,0x74f00150}},	//   _forç, _bepq, ्हिय, _سۋدا, 
   {{0xdb1d52af,0xad980022,0x386405b1,0x9f94c6cb}},	//   _korä, _akúp, isor_, _nää_, 
   {{0xb178037e,0x38640455,0x5a7401e1,0x00000000}},	//   rhåb, hsor_, _ọlọṣ, --, 
   {{0x20180998,0x38646521,0xad9802d2,0x00000000}},	//   alri_, ksor_, _sjúb, --, 
   {{0x9f9400a2,0x38640455,0x6fb000db,0x50f4003b}},	// [22370] _bää_, jsor_, _كۅحا, _ізот, 
   {{0x394552b0,0x69d8002d,0x00000000,0x00000000}},	//   ecos_, _slue, --, --, 
   {{0xdb580b32,0xc84c02d3,0xdd0c0034,0x200552b1}},	//   яют_, _ዝተላዕ, góło, émie_, 
   {{0xc8340023,0x2bfc0154,0x00000000,0x00000000}},	//   _ክቡራን, ্গেই_, --, --, 
   {{0x07a552b2,0x2d98011f,0xc7a44727,0x78a400d0}},	//   далн, meqe_, дилк, _škvr, 
   {{0x394552b3,0x443c01a4,0x2d980548,0x27c4023a}},	//   acos_, _ruw_, leqe_, ящег, 
   {{0x443c0209,0x3864437d,0x64480c86,0x65680175}},	//   _suw_, asor_, _stgi, _pdgh, 
   {{0x394552b4,0x443d52b5,0x291c005a,0xdb1d52b6}},	//   ccos_, _puw_, _tzua_, _sorç, 
   {{0xdb1c06ed,0x443ca4e6,0xf8ad52b7,0x00000000}},	//   _porç, _quw_, _پکن_, --, 
   {{0xf1bc09f3,0xc244d4e4,0xdb1c03b9,0x2d980200}},	//   smál_, мнок, _qorç, heqe_, 
   {{0x2d9952b8,0x91fc0882,0x443c020c,0xfbd00375}},	//   keqe_, trāp, _wuw_, דתי_, 
   {{0xaca001e1,0x7f5c0455,0x32e001e1,0x6568002b}},	//   _afọb, _sepq, _séyé_, _udgh, 
   {{0x64484374,0xdb1d52b9,0x2018022e,0x55ac00df}},	//   _utgi, _torç, tlri_, _ליאַ, 
   {{0x7f5c0455,0x2ce8031c,0x1fd800bc,0xad9800d7}},	//   _qepq, _ལྟེབ, डसेड, _skúp, 
   {{0x91fc0882,0x29d40139,0x83fc01d3,0x9f940139}},	//   prāp, _açam_, lsőo, _näå_, 
   {{0x261006ed,0x9f9402f6,0x3864bde2,0x1894001f}},	//   mãos_, _sää_, ysor_, _መፍጠር_, 
   {{0x39a40953,0xdbdc0ca8,0x9f94023a,0x32e000e8}},	// [22380] _jūsų_, _fáìl, _pää_, _téyé_, 
   {{0x39a40953,0xafd832b8,0x3ebc0267,0x39440042}},	//   _mūsų_, spør, ätts_, wcos_, 
   {{0x9f940254,0xaf0000c0,0x00000000,0x00000000}},	//   _vää_, _апэл, --, --, 
   {{0xb51c4709,0x00000000,0x00000000,0x00000000}},	//   _परलय_, --, --, --, 
   {{0x9f9402f6,0x7ed404d3,0x68340240,0x00000000}},	//   _tää_, _رزگا, _እተመስ, --, 
   {{0x386552ba,0x9f583eba,0xdb1c00c7,0x9f4c007f}},	//   rsor_, moró_, _porä, òdè_, 
   {{0xdb1d52bb,0x9f580407,0x56941bbc,0x3944007c}},	//   _borå, loró_, хайт, pcos_, 
   {{0x74684834,0x2610d02b,0xf1bc00d7,0x00000000}},	//   оров_, dãos_, tmám_, --, 
   {{0xdbdc01e1,0x386418dd,0x00000000,0x00000000}},	//   _láíl, qsor_, --, --, 
   {{0xf1bc0122,0x26100798,0xd37004fb,0xd90c00e5}},	//   rmám_, fãos_, دهد_, _پیڈ_, 
   {{0xdb1c17c1,0x261006ed,0xc7940cef,0x00000000}},	//   _forå, gãos_, _ярты, --, 
   {{0x38380023,0x83fc00e5,0x00000000,0x00000000}},	//   _እተቐበ, lsől, --, --, 
   {{0x9f580407,0xc04c004b,0x7a3800b8,0x26087512}},	//   joró_, یږی_, _kįts, ावरी_, 
   {{0x75206d5f,0x2d98014b,0xd0100efc,0xb35403e6}},	//   _izoz, weqe_, الآ_, _تیدا_, 
   {{0x1d4c01f2,0x2d98020c,0x24740092,0x00000000}},	//   _ọdịm, teqe_, _በሐሰት_, --, 
   {{0xd83801a6,0xa440013d,0x00000000,0x00000000}},	//   _lič_, _янәд, --, --, 
   {{0x2d9819a2,0x4bb400d1,0xd0d40395,0x1df80108}},	// [22390] reqe_, нйас, _чопъ, феты_, 
   {{0xd838b8dd,0x752000ec,0x00000000,0x00000000}},	//   _nič_, _mzoz, --, --, 
   {{0x49746a46,0x00000000,0x00000000,0x00000000}},	//   елес, --, --, --, 
   {{0x9f5952bc,0x752152bd,0x3ebc08fb,0x9b243bcd}},	//   boró_, _ozoz, åtte_, тфул, 
   {{0x75201446,0xd83802f0,0x00000000,0x00000000}},	//   _nzoz, _bič_, --, --, 
   {{0x39500790,0x2be000cd,0x00000000,0x00000000}},	//   ıysa_, _गतिं_, --, --, 
   {{0x752152be,0x26080db3,0xd8380122,0x00000000}},	//   _azoz, ावली_, _dič_, --, 
   {{0x7a3800b8,0x00000000,0x00000000,0x00000000}},	//   _vįtt, --, --, --, 
   {{0x68300588,0x0e8402d3,0xd83800f3,0xf1bc0548}},	//   _амаӡ, _ዝግበኦ_, _fič_, mmáh_, 
   {{0x75200810,0xe190004d,0x00000000,0x00000000}},	//   _dzoz, _cẳng_, --, --, 
   {{0x752152bf,0xca3801e4,0xf4840133,0xe1900208}},	//   _ezoz, _kiŝ_, وایی, _dẳng_, 
   {{0xd54800f2,0x00000000,0x00000000,0x00000000}},	//   _قلمو_, --, --, --, 
   {{0x661952c0,0x26100798,0x644c0077,0x91c001e0}},	//   mluk, sãos_, ícid, рҙыл, 
   {{0x66194db1,0x00000000,0x00000000,0x00000000}},	//   lluk, --, --, --, 
   {{0x66180641,0x68e403e3,0x00000000,0x00000000}},	//   oluk, _əjda, --, --, 
   {{0x661952c1,0x6da152c2,0x22280014,0x91f40022}},	//   nluk, лиса, _تٲبی_, _аџьш, 
   {{0x91fc00da,0x6618023a,0xe604113e,0xdce40327}},	// [223a0] ksāj, iluk, _ەش_, ffiġ, 
   {{0x66182935,0x0d440020,0xb1780ec3,0xbea4573e}},	//   hluk, ያስፈል, nhån, _заок, 
   {{0xdb1c01a2,0x9f58011c,0xd83801a6,0xd52c01e1}},	//   _horú, borò_, _rič_, _kọ́k, 
   {{0xacb8019f,0xad98022c,0xdb1c1f08,0x66180960}},	//   _izûn, _hjún, _korú, jluk, 
   {{0x661952c3,0x6d380375,0xb1780fac,0x3854005b}},	//   dluk, _מתכנ, khån, хъес, 
   {{0xfb5443fb,0xdddc55a0,0x6618000d,0xd7940395}},	//   _سپرد, kurū, eluk, тикъ, 
   {{0xca3801e4,0xd6d000c6,0xd8380219,0xdb1c0ca8}},	//   _fiŝ_, شقة_, _vič_, _lorú, 
   {{0xf1bd52c4,0x499000f9,0x7bcc00af,0xe8900092}},	//   rmák_, _نیمر, _hobu, ዘነጋም_, 
   {{0xb4d80c2e,0x97a40116,0xd8380427,0x52b807af}},	//   ठने_, _илаҗ, _tič_, इम्स, 
   {{0x66180357,0x7bcc084c,0x0e84044e,0xdecc02d3}},	//   aluk, _jobu, _ዝግብኦ_, በኣና_, 
   {{0x7bcd52c5,0x35b00220,0x91c40131,0x66188d53}},	//   _mobu, _бұйр, вәпл, bluk, 
   {{0x7bcc2747,0x7520014b,0xf1a432c0,0xd2640220}},	//   _lobu, _tzoz, хрон, нкүй, 
   {{0x7520d9f2,0x9f58011c,0x7bcc04ba,0x78a0045a}},	//   _uzoz, vorò_, _oobu, nwov, 
   {{0x644d52c6,0xdb1c0241,0x7bcd0768,0xa3d40490}},	//   ície, _dorú, _nobu, _सवय_, 
   {{0x798054ef,0xe28c00c6,0x20040030,0x42a401af}},	//   kgow, _هذي_, émia_, _ауығ, 
   {{0xf1a870c8,0xad9800e4,0xdb1d52c7,0xdda80262}},	//   _رابه_, _ejún, _forú, нтул_, 
   {{0xc0c0804b,0x6ce400d4,0x00000000,0x00000000}},	// [223b0] _кәри, хіве, --, --, 
   {{0x7bcd52c8,0x66180790,0xc84c02d3,0x7980012d}},	//   _cobu, zluk, _ዝሰማዕ, egow, 
   {{0x29d403ee,0x7bcd52c9,0xbff001ec,0xff880023}},	//   _uçak_, _dobu, _түрш, _ዕምባባ_, 
   {{0x9f58008c,0x7980102c,0x6ee00139,0xdb1c0248}},	//   lorð_, ggow, _fеbr, _yorú, 
   {{0xc0c8044e,0x991402bf,0x66180e3c,0x00000000}},	//   _ጽባሕ_, льші, vluk, --, 
   {{0x7bcd52ca,0xdb1c01e1,0xb6740240,0xcb680066}},	//   _gobu, _lorù, _ከይኮኑ_, _زمره_, 
   {{0x661818f7,0x29d40421,0xda780153,0xeb3433ae}},	//   tluk, _lçai_, _пят_, _سرسخ, 
   {{0x7bcc0928,0x661952cb,0x3c2552cc,0x79800165}},	//   _zobu, uluk, rôve_, cgow, 
   {{0x6618122d,0x7bcc1253,0xb0580054,0xb460035b}},	//   rluk, _yobu, wxän, акыл, 
   {{0x9aa40f31,0x00000000,0x00000000,0x00000000}},	//   _جمہو, --, --, --, 
   {{0xb17895a0,0x29d400d8,0xa2b0044b,0xdef40023}},	//   rhån, _açai_, ेमध्, _ግቡኡ_, 
   {{0x999800da,0xdb1d52cd,0xb17820e4,0x5ed000eb}},	//   _kurš_, _corù, shån, _হইলে, 
   {{0xb1780267,0xdbdc01e1,0x94d40354,0x9f5801a8}},	//   mhål, _láál, _йоцц, forð_, 
   {{0xb0580bc9,0xadc001e1,0xc2c431b1,0x7980033f}},	//   pxän, _irẹd, _ليتي, zgow, 
   {{0x7bcc0d63,0x00000000,0x00000000,0x00000000}},	//   _robu, --, --, --, 
   {{0x7bcd52ce,0xb1780267,0xbea4013e,0xa1c402dd}},	//   _sobu, nhål, наҳк, _сұмд, 
   {{0x9f581f60,0xf0a438ce,0x3b848e9e,0x9894001f}},	// [223c0] borð_, _акыл_, клаг, _መፍትሔ_, 
   {{0xdb1c0158,0x7bcd52cf,0xada000d0,0xf21000fe}},	//   _korø, _qobu, _žĺtk, সগৃহ_, 
   {{0xdb1c0570,0xec10b94d,0x7bcc004c,0xad9808a5}},	//   _yorù, جولد, _vobu, _kjúl, 
   {{0x7bccf64b,0x7db40022,0x78a002e2,0x00000000}},	//   _wobu, _рсоц, twov, --, 
   {{0x7bcd52d0,0x6b8401ab,0xa96552d1,0x798152d2}},	//   _tobu, _fcjg, тича_, rgow, 
   {{0x6a2400c6,0x78a0232c,0x4c3401c6,0x798152d3}},	//   _āҝŗã_, rwov, _бэст, sgow, 
   {{0xdef4044e,0x973c0cf4,0xad980ca8,0x78a0014f}},	//   _ግቡእ_, _jaći, _ojúl, swov, 
   {{0xe60c188d,0xab2486e5,0xb1780267,0x78a00100}},	//   يشي_, _роса_, ghål, pwov, 
   {{0xe96401af,0xc7e801d9,0xdb1c01e1,0xd6d00014}},	//   _шатл_, بى۪ن_, _rorù, شقک_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x51f82626,0x7cd8002b,0xe81809bb,0xaaa800bc}},	//   енню_, _hārā, _पीटा_, छिएक, 
   {{0x973c16a3,0xd5880116,0x91a80208,0x7cd800cd}},	//   _naći, _чәкл_, _khả_, _kārā, 
   {{0x6abc0574,0x69c00073,0x7cd81619,0x9f580162}},	//   _एप्र, ळाती, _jārā, torð_, 
   {{0xdb1c0e38,0x20040086,0x7cd825fa,0x998401ef}},	//   _forø, ũmin_, _mārā, _ohmů_, 
   {{0x320805f5,0x9f5809f3,0x973c0841,0x92945172}},	//   _охин_, rorð_, _baći, _сайц, 
   {{0xe1f00849,0xecb001e0,0x3ebc248f,0x00000000}},	//   _وسي_, аҡмы, åtta_, --, 
   {{0x7cd80882,0x9e34004e,0x00000000,0x00000000}},	// [223d0] _nārā, ретч, --, --, 
   {{0x8c18785c,0x2f3c063f,0xdbdc01e1,0x00000000}},	//   ريار_, ọgbu_, _páál, --, 
   {{0x91fc0171,0x00000000,0x00000000,0x00000000}},	//   drāz, --, --, --, 
   {{0x973c1591,0x7cd800b8,0x60e80205,0x00000000}},	//   _gaći, _bārā, _örmü, --, 
   {{0x38c80424,0x7cd8002b,0x6d4c02d0,0x91a80208}},	//   فاوی_, _cārā, _ifca, _chả_, 
   {{0x0e04013e,0x7cd8002b,0xc48401b9,0xe1f800a2}},	//   _рӯҳо, _dārā, ҳлик, _ỳüpe, 
   {{0xb1780267,0x28a005dc,0x00000000,0x00000000}},	//   thål, _खैरि, --, --, 
   {{0xc48552d4,0x96b830e3,0xad980241,0xd9440798}},	//   глик, тушу_, _ojúm, _веѓи, 
   {{0xb17804f3,0x6d4c0009,0x434400a7,0xdb1c01bf}},	//   rhål, _mfca, лепв, _sorø, 
   {{0xb178049f,0xdb1c0ac8,0xa2814ad9,0x6d4c00d8}},	//   shål, _porø, لیتو, _lfca, 
   {{0x17f80597,0xad9800e4,0xd7f80f7e,0xb178007c}},	//   _شركة_, _ajúm, _рут_, phål, 
   {{0x41740451,0xa44003e6,0xdddc0022,0x63e000cf}},	//   دادس, _پێدو, purũ, ايگە, 
   {{0xdb1c0ba1,0x20048607,0xca4001ec,0x656c0332}},	//   _enrè, émio_, _ﺜﻘﺔ_, óchu, 
   {{0x75fc00da,0x6d4c058a,0xa2a8c853,0x9f580240}},	//   vīzi, _afca, _जनप्, mirë_, 
   {{0xe81805f9,0x973c00f3,0xad98032e,0x9f580200}},	//   _पीछा_, _paći, _tjúl, lirë_, 
   {{0xc0cc36bc,0x52754308,0x6d4c005a,0x5f4400f1}},	//   ብሔር_, _тушу, _cfca, انځل, 
   {{0xa3d41e61,0xed4c1e2f,0xfc280064,0x1b640022}},	// [223e0] _सवा_, سپل_, ежак_, инаҭ, 
   {{0x61e40032,0x7cd800b0,0x93bc0311,0x8fd401af}},	//   _hlil, _rārā, lmăr, _кәсә, 
   {{0x61e40793,0x9f580240,0xdce40024,0x8e74013d}},	//   _klil, hirë_, maič, _куяч, 
   {{0xaa546d6c,0x7cd90e97,0xdce40024,0xfce400f5}},	//   النا_, _pārā, laič, _бомо, 
   {{0x61e552d5,0xf770036b,0x00000000,0x00000000}},	//   _mlil, ماغ_, --, --, 
   {{0x61e552d6,0xdce40024,0xf1bc01d3,0x76a8228c}},	//   _llil, naič, lmát_, етив_, 
   {{0xab244ed8,0x61e552d7,0xeb94010b,0x66700338}},	//   _бора_, _olil, _щир_, مدير, 
   {{0x9f580240,0x7bdc007c,0x7cd92c45,0x91a80051}},	//   firë_, lkpu, _tārā, _thả_, 
   {{0xd910bc28,0xe56c0451,0xdce40024,0xaee00055}},	//   _بیش_, سطي_, kaič, _kaṃd, 
   {{0x644d52d8,0x289808a8,0xe8f418a4,0xc2fc00fe}},	//   ícia, _אימא, _слу_, ঁথনি_, 
   {{0x7bdc0ac5,0x06640014,0x9644010b,0x929400c0}},	//   ikpu, _نانپ, _тмеҗ, шанц, 
   {{0x61e401ab,0x644c01e4,0xf6240107,0xf484009b}},	//   _clil, ŭcia, _ёддо, _букн, 
   {{0xb03000fd,0x7bdc26ae,0x74540108,0x00000000}},	//   йммә, kkpu, _съех, --, 
   {{0x533552d9,0x61e53f82,0xdb1c002e,0xc4c400f1}},	//   _келт, _elil, _enré, _ختمو, 
   {{0x61e40221,0x8f3431d5,0x00000000,0x00000000}},	//   _flil, ревц, --, --, 
   {{0x7bdc27bb,0x61e400a3,0x3c2400c7,0xf31401ee}},	//   ekpu, _glil, vôva_, _инһә_, 
   {{0x8f54d4cd,0xad980008,0x9f580100,0x9f9400a2}},	// [223f0] _پنجش, _hjúk, kirè_, _häý_, 
   {{0xad980008,0x4fc007d2,0x3168033f,0xb1780267}},	//   _kjúk, _بەسە, lacz_, skåd, 
   {{0xddd409a5,0x973c96c0,0x61e4023a,0x9f580200}},	//   _ýaşa, _kaću, _ylil, zirë_, 
   {{0x69640137,0x69c80399,0xad980252,0x3168033f}},	//   اداق, ujge, _mjúk, nacz_, 
   {{0x973c0e04,0xad980008,0xc0cc0023,0x9bc400db}},	//   _maću, _ljúk, _ብቐስ_, _گەلۉ, 
   {{0x7bdc1196,0xee3c00a2,0xad980241,0x9be41cb8}},	//   ckpu, _hiý_, _ojúk, _ліск, 
   {{0x4af800a7,0x26c40009,0x786000d1,0xdb1c0c5e}},	//   _ревю_, uxno_, مگەك, _korý, 
   {{0x9f5802d3,0x91fc0882,0x049402d5,0x31680332}},	//   tirë_, prāy, ароў, jacz_, 
   {{0xa7843345,0x03c80432,0x3168012d,0x81441046}},	//   _مشاو, _göỳb, dacz_, یندن, 
   {{0x61e41caa,0x9f580240,0x7410027d,0x00000000}},	//   _slil, rirë_, يويا, --, 
   {{0x020552da,0x9f580023,0xdce40006,0x61e4010f}},	//   изон, sirë_, vaič, _plil, 
   {{0x9f580129,0x63e001ec,0x3168012d,0x00000000}},	//   miré_, _گيتە, gacz_, --, 
   {{0x93bc0311,0x9f5952db,0x61e46b92,0xb2241d0e}},	//   rmăr, liré_, _vlil, _smæð, 
   {{0x3ebc0158,0xad98032e,0x00000000,0x00000000}},	//   åtto_, _fjúk, --, --, 
   {{0x3168006d,0x61e418d6,0x42080276,0x3f8c02d2}},	//   bacz_, _tlil, _инко_, _öfum_, 
   {{0x23640007,0xaee00882,0x260846c7,0xdce40153}},	//   _henj_, _saṃd, ावटी_, saič, 
  
   {{0x224406f2,0x9f5800f2,0xee3c0432,0x518400f7}},	// [22400] _hunk_, hiré_, _diý_, _اشىق, 
   {{0x2d88d1a3,0x973c0cf4,0x9f580066,0x25ac00a2}},	//   _ecce_, _zaću, kiré_, _lagl_, 
   {{0x2018105c,0x0ba80372,0x2240000d,0x7bdc0af9}},	//   mori_, داقى_, _kiik_, rkpu, 
   {{0x224552dc,0x2364b002,0x9f5952dd,0xf294008f}},	//   _munk_, _lenj_, diré_, יכער_, 
   {{0x22413cd9,0xa8840b30,0x6cb01cd1,0x00000000}},	//   _miik_, ийца_, _мөфт, --, 
   {{0x201952de,0x224000c5,0x00000000,0x00000000}},	//   nori_, _liik_, --, --, 
   {{0xf7701973,0x25ac00a2,0x9f5952df,0x35e40798}},	//   ماں_, _bagl_, giré_, ицив, 
   {{0x201952e0,0x7c2c02c4,0x2240013c,0xeff00023}},	//   hori_, _hhbr, _niik_, _ግዱድ_, 
   {{0xad981bb0,0x23640007,0x25ac05d5,0x22440789}},	//   _sjúk, _benj_, _dagl_, _aunk_, 
   {{0x9f5952e1,0xf1bc01ed,0x3168033f,0x22443046}},	//   biré_, ymás_, wacz_, _bunk_, 
   {{0x28100328,0x201952e2,0x2240d0ed,0x91fc00da}},	//   _بولس, dori_, _biik_, ksāt, 
   {{0x22400098,0xdb1c0aef,0x25ac0c86,0x22440f85}},	//   _ciik_, _horó, _gagl_, _dunk_, 
   {{0xdb1d52e3,0x2edc0882,0x291c0218,0x95c801af}},	//   _koró, नन्त, _xyua_, _ауҙа_, 
   {{0x23640399,0xdb1c8ebf,0xad9806ea,0x00000000}},	//   _genj_, _joró, _tjúk, --, 
   {{0xdb1c2e27,0x22440327,0x2240009f,0xb8d0025c}},	//   _moró, _gunk_, _fiik_, _ྟར_, 
   {{0xaac4583f,0x5d78656c,0x2ca8039a,0x236417c4}},	//   یتان, ийся_, _pscd_, _zenj_, 
   {{0x29d40139,0x00000000,0x00000000,0x00000000}},	// [22410] _oçar_, --, --, --, 
   {{0x201803b4,0x7c2c0129,0xee3c0432,0x00000000}},	//   cori_, _chbr, _wiý_, --, 
   {{0x442802a8,0x291c020c,0x2ac40640,0xdb1d52e4}},	//   _ɗa_, _syua_, шљав, _torý, 
   {{0x29d40fb9,0x99d552e5,0x8d780092,0x2d880055}},	//   _açar_, يتنا, ርናቸው_, _ucce_, 
   {{0xa8a43a58,0x9cc80166,0x08440014,0xdb1c0c57}},	//   ррек, _кыра_, حنتُ, _boró, 
   {{0x9f5952e6,0xb9840588,0x2d9c01f2,0x25ac07c5}},	//   tiré_, атәқ, _ịzụọ_, _sagl_, 
   {{0xe8dc01e1,0xdb1c0210,0x00000000,0x00000000}},	//   _igọn_, _doró, --, --, 
   {{0x2364e27e,0x644c4456,0x9f580214,0x6d5c0175}},	//   _senj_, ício, riré_, nbqa, 
   {{0x2240007d,0x201952e7,0x9f5952e8,0x224450eb}},	//   _riik_, yori_, siré_, _sunk_, 
   {{0x2240045f,0xdb1c01e1,0x9f5952e9,0x22445f5c}},	//   _siik_, _goró, piré_, _punk_, 
   {{0x23640369,0xdb1c00cf,0x25ac07de,0x814401b9}},	//   _venj_, _horò, _tagl_, ینگن, 
   {{0x23640007,0x2019304c,0x2244054e,0x00000000}},	//   _wenj_, wori_, _vunk_, --, 
   {{0xdce400b0,0x2240000d,0x9f940139,0xf1bc01d3}},	//   kaiā, _viik_, _täü_, tmár_, 
   {{0x645952ea,0x22440054,0xdb1ce0fd,0xe8dc001e}},	//   mpui, _tunk_, _morò, _ngọn_, 
   {{0xc254ebc2,0x2240091d,0xec1401f2,0x93240046}},	//   _اختت, _tiik_, ọọch, _ورىن, 
   {{0xdb1c48b3,0x645952eb,0x93bc0311,0x00000000}},	//   _vorü, opui, plăc, --, 
   {{0x201952ec,0x6e2c01ab,0x72000014,0xfca80451}},	// [22420] pori_, _dhcb, _روٝم, دازو_, 
   {{0x201952ed,0x6458005a,0xad9801e1,0x00000000}},	//   qori_, ipui, _ojúw, --, 
   {{0xfe7152ee,0xeb944caf,0x66e000e8,0x6c3000c6}},	//   _عدد_, сих_, _dёkk, أفلا, 
   {{0xeb303b5f,0x18200073,0x368808ca,0xfaa408ca}},	//   سىند, यत्व_, ҳсин_, _қабо, 
   {{0xdb1d52ef,0xad980248,0x22b40208,0x00000000}},	//   _poró, _ajúw, _lăk_, --, 
   {{0xba6800c6,0x3f880c6a,0x75fc00ef,0x00000000}},	//   _محرك_, ngbu_, dūza, --, 
   {{0xb86400f2,0x00000000,0x00000000,0x00000000}},	//   _گازو, --, --, --, 
   {{0x545552f0,0xdb1c02e2,0xb9e401ec,0xb9949924}},	//   овит, _forò, _اسسى, _دلرب, 
   {{0x92a80034,0x645952f1,0xdb1c0210,0x00000000}},	//   _małż, gpui, _toró, --, 
   {{0x29d4d91f,0x13f402bf,0xa4a00014,0xb80414af}},	//   _uçar_, ізня, سیى۪, _ابره, 
   {{0x6d5c0014,0xd770001f,0xdbdc0332,0x00000000}},	//   ybqa, ጠበቂያ_, _báúl, --, 
   {{0x3f880327,0x75fc00c0,0x00000000,0x00000000}},	//   egbu_, būza, --, --, 
   {{0x76400472,0x64a001c0,0x9f580022,0x05c44f71}},	//   _iioy, _наца, rirî_, वारब, 
   {{0x752001f0,0x16100073,0x631400cc,0xf2c401ee}},	//   _iyoz, ावकर_, ডেইট_, _гсин, 
   {{0x6394011a,0x00000000,0x00000000,0x00000000}},	//   _הדוא_, --, --, --, 
   {{0x4cd0015b,0xc118063f,0x00000000,0x00000000}},	//   _সেগু, ọdụr, --, --, 
   {{0xfc780cf9,0x764152f2,0xb7780882,0xdce400b0}},	// [22430] _x폭x_, _mioy, _guṇā, taiā, 
   {{0xdb1c6bdf,0x7a2800e4,0x83fc00e5,0x00000000}},	//   _enrí, výta, lsőr, --, 
   {{0xc9580058,0xe7c4068f,0x752001b9,0x98540023}},	//   للاش_, लासप, _lyoz, _ዝተማህ, 
   {{0x3ebc04ce,0x752006cc,0xad9800e4,0x7640002e}},	//   ætte_, _oyoz, _ajúv, _nioy, 
   {{0x7bd40162,0xb17800b8,0x00000000,0x00000000}},	//   øguú, bhåv, --, --, 
   {{0xe7846c48,0xcb68bf4e,0x2bc82afd,0x7a2800e4}},	//   судо, _خمسه_, _сумо_, rýta, 
   {{0x752152f3,0x76400363,0xdddc0cf4,0xad245837}},	//   _ayoz, _bioy, lurš, _خرگو, 
   {{0x752000ca,0x91a801fb,0x7a280030,0x645801f5}},	//   _byoz, _nhà_, pýta, tpui, 
   {{0x764152f4,0x66dc01e1,0x9f580ffb,0xdee802d3}},	//   _dioy, _bàkú, firì_, _ማይን_, 
   {{0x229c005b,0x00000000,0x00000000,0x00000000}},	//   _näkö_, --, --, --, 
   {{0x645952f5,0x752006cc,0xd77400db,0x420801c6}},	//   spui, _eyoz, _رالع, иноо_, 
   {{0xbba403f3,0x645952f6,0xdb1c0ad9,0xb3444e7e}},	//   _ऑस्क, ppui, _morð, _akçı, 
   {{0x661952f7,0xad980022,0xd4080214,0xb64001ec}},	//   mouk, _yjúv, شتیم_, _ﺍﺭ_, 
   {{0x65680978,0x644816b8,0x661952f8,0xb1400816}},	//   _hegh, _iugi, louk, ьнял, 
   {{0xdb1c19cf,0x644952f9,0x644152fa,0x65682a1f}},	//   _norð, _hugi, _iini, _kegh, 
   {{0x6448633d,0x644152fb,0x661952fc,0x823445b6}},	//   _kugi, _hini, nouk, _برتا, 
   {{0x656952fd,0x44249352,0x644952fe,0x7fd40220}},	// [22440] _megh, oll_, _jugi, _діні, 
   {{0x656952ff,0x9f580491,0x64415300,0x64495301}},	//   _legh, oirí_, _jini, _mugi, 
   {{0x44255302,0x64495303,0x66195304,0x65680076}},	//   ill_, _lugi, kouk, _oegh, 
   {{0x65695305,0x661802f6,0x64480165,0x44241368}},	//   _negh, jouk, _ougi, hll_, 
   {{0x7640036b,0x66195306,0x64415307,0xe94410e8}},	//   _rioy, douk, _oini, زرنی, 
   {{0xdb1c1f60,0xe3a400f1,0x7520037e,0x76400241}},	//   _forð, _غر_, _ryoz, _sioy, 
   {{0x644802d5,0x6568011c,0x66180118,0xe7d000db}},	//   _augi, _begh, fouk, بۅلگ, 
   {{0x6448cbdc,0x64415308,0x787401d9,0x6618002e}},	//   _bugi, _aini, _وُزا, gouk, 
   {{0x64415309,0x6448aa3b,0x6569309e,0x76400363}},	//   _bini, _cugi, _degh, _vioy, 
   {{0x3a25530a,0x6449530b,0x6441530c,0x656800ad}},	//   llop_, _dugi, _cini, _eegh, 
   {{0x6619530d,0x644802ea,0x656808e5,0x6441530e}},	//   bouk, _eugi, _fegh, _dini, 
   {{0x6441530f,0x64495310,0x76586605,0xa844005e}},	//   _eini, _fugi, _itty, _الەم_, 
   {{0x64415311,0xe3ad5312,0x47ac015b,0x644819a0}},	//   _fini, رری_, চারী, _gugi, 
   {{0x64415313,0xd2500597,0x343401d9,0xb4d41d94}},	//   _gini, _كنت_, _بٲتھ_, सही_, 
   {{0x3a255314,0xd90403e6,0x389c00e2,0xad9801e1}},	//   klop_, _ڤی_, lārā_, _ojút, 
   {{0x64487d74,0x64414e22,0x2d8d5315,0xc338012c}},	//   _yugi, _zini, üge_, čítá, 
   {{0x64415316,0x25d40a1e,0x389c00e2,0xa1280150}},	// [22450] _yini, קומן_, nārā_, _وكىل_, 
   {{0x64415317,0x60c0037e,0x6618037e,0x7658035a}},	//   _xini, æmme, zouk, _otty, 
   {{0x67ec997d,0x43800075,0xad98032e,0x6618037e}},	//   _højg, ﯩﺪﯨﻦ_, _bjút, youk, 
   {{0xdb1c022c,0xda780845,0x75fc0153,0xdddc00c0}},	//   _vorð, іях_, dūzo, purš, 
   {{0x44255318,0x65695319,0xad9801ed,0x7659395d}},	//   yll_, _regh, _amúg, _atty, 
   {{0x6449531a,0x27c41de1,0x6568016d,0x6618002e}},	//   _rugi, ющег, _segh, wouk, 
   {{0x6449531b,0x6441531c,0xfbd0025f,0x6619531d}},	//   _sugi, _rini, _אתם_, touk, 
   {{0x6449531e,0xad9800e4,0x3a24004e,0x65680135}},	//   _pugi, _ijús, clop_, _qegh, 
   {{0x6441531f,0x65695320,0x389c4670,0x7658127b}},	//   _pini, _vegh, gārā_, _etty, 
   {{0x65695321,0x64415322,0x64495323,0xd6d95324}},	//   _wegh, _qini, _vugi, стә_, 
   {{0x44255325,0x656819f5,0x04c8d712,0x66180124}},	//   rll_, _tegh, _گوشي_, pouk, 
   {{0x64415326,0x64495327,0x91a80208,0x15a802e8}},	//   _wini, _tugi, _phá_, _мъчи_, 
   {{0x9f5800ae,0xa3a8012d,0x389c002b,0x00000000}},	//   sirí_, ख़द_, cārā_, --, 
   {{0x64415328,0x32085c00,0xad980241,0x00000000}},	//   _uini, ancy_, _ojús, --, 
   {{0xf1bc0491,0x3ebc2833,0xe7f0033d,0x92655329}},	//   mlán_, ítt_, _अतना_, _قديم, 
   {{0x67ec04ce,0x4095532a,0x6d48151c,0xcdc40220}},	//   _højd, _ерот, žgan, масқ, 
   {{0x3a24bff2,0xf1bc0332,0xf1b0011a,0x00000000}},	// [22460] vlop_, olán_, _טסה_, --, 
   {{0xdb1c0267,0x46bc2802,0xeb95532b,0x70f8011a}},	//   _morö, ्माह, зиф_, _להפח, 
   {{0x3ce5532c,0xf1bc0005,0x9f59532d,0x6a81532e}},	//   šov_, ilán_, mirà_, елха, 
   {{0x628c068f,0xad98032e,0xf1bc00ae,0x00000000}},	//   ńcow, _djús, hlán_, --, 
   {{0x9f940139,0x3a25532f,0xb17812e8,0xe7c401f9}},	//   _däö_, rlop_, dkål, लांप, 
   {{0x9f595330,0x3a255331,0xb178cc6e,0xad9803b2}},	//   nirà_, slop_, nhår, _fjús, 
   {{0x3a24b629,0xad98032e,0x00000000,0x00000000}},	//   plop_, _tjút, --, --, 
   {{0x9f595332,0x389c411e,0x8b3001d3,0x00000000}},	//   hirà_, tārā_, _شہنش, --, 
   {{0x67ec01bf,0xb05801e3,0xa3d40037,0x00000000}},	//   _bøjd, mväg, _सवख_, --, 
   {{0x9f580ffb,0xb05801e6,0xf1bc01e7,0x8d900092}},	//   jirà_, lväg, glán_, ኝበታል_, 
   {{0xa7580302,0x9f584b84,0x66e13566,0xc79401af}},	//   _הדבר, dirà_, _пофа, _юрты, 
   {{0xb05801e6,0xf1bc0332,0x00000000,0x00000000}},	//   nväg, alán_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf1bd5333,0x9f595334,0xe478010f,0xb058007c}},	//   clán_, girà_, _פרוכ, hväg, 
   {{0xb8dc003d,0xa3b401d9,0x91fc0882,0xb05801e3}},	//   _ཀན_, _راور_, tpād, kväg, 
   {{0xad9800e4,0x3ebd5335,0xb63c00b5,0x67ec01bf}},	//   _ajúr, ætta_, _ｂｉ_, _iøje, 
   {{0x67ec019b,0x9f586641,0xdb1c0022,0x88e0009e}},	// [22470] _høje, birà_, _morõ, _মেনক, 
   {{0x9f5802e8,0x67ec005c,0x6f6007d2,0xd6ec25c9}},	//   cirà_, _køje, _سۇرم, जनाथ_, 
   {{0xbd000d27,0x17f800dc,0x9b680ce8,0x00000000}},	//   _éénm, ्चैव_, яшта_, --, 
   {{0x9f582cd7,0xcdc400cf,0xb058007c,0x00000000}},	//   mirá_, _تۇرۇ_, gväg, --, 
   {{0x9f580407,0xad980174,0x2868094e,0x67ec005c}},	//   lirá_, _fjúr, ёрдо_, _løje, 
   {{0xb05801e3,0x699c000d,0x00000000,0x00000000}},	//   aväg, _गउवी, --, --, 
   {{0x9f587d3d,0x67ec037e,0x9f640066,0xb058007c}},	//   nirá_, _nøje, éwék_, lväd, 
   {{0x04c850a3,0xdb1c40fc,0x00000000,0x00000000}},	//   قوبي_, _porö, --, --, 
   {{0xf1bd5336,0x69d80381,0xb1780158,0xad9800e4}},	//   tlán_, _ioue, rkål, _yjúr, 
   {{0x69d95337,0x67ec00b5,0x9f58004e,0xdb1c08a5}},	//   _houe, _bøje, xirà_, _vorö, 
   {{0x69d95338,0xf1bc1d0e,0xd83805f5,0x00000000}},	//   _koue, rlán_, _хэт_, --, 
   {{0x69d95339,0xd6d834d8,0x9f5867c9,0xb11002e3}},	//   _joue, _эту_, dirá_, nụwa, 
   {{0x69d9533a,0x9f5812d9,0x67ec005c,0xb178007c}},	//   _moue, tirà_, _tøjd, thår, 
   {{0x69d9533b,0x67ec00b5,0xdb1c0165,0x27e40076}},	//   _loue, _højb, _korô, nknn_, 
   {{0x9f59533c,0xb058007c,0x00000000,0x00000000}},	//   rirà_, yväg, --, --, 
   {{0x69d9533d,0x27040134,0xad98022c,0x9f58e74b}},	//   _noue, _mɑn_, _sjúr, sirà_, 
   {{0x9f585bd9,0xaca0063f,0x20040129,0xad9802d2}},	// [22480] pirà_, yaụf, émis_, _pjúr, 
   {{0x9f5809ff,0x69d8030a,0xd52c01e1,0x00000000}},	//   birá_, _aoue, _ló̟k, --, 
   {{0x69d80dd4,0x9f582b76,0xfaa800f2,0xb05801e3}},	//   _boue, cirá_, تهاي_, tväg, 
   {{0xa964094c,0x69d806af,0xef140953,0xfce400f7}},	//   дица_, _coue, _імя_, _жомо, 
   {{0x69d80dd4,0xb058049f,0xe9fc001e,0xf77002f2}},	//   _doue, rväg, _giận_, ناغ_, 
   {{0x2704016b,0x56943395,0xb058049f,0xad98032e}},	//   _bɑn_, еакт, sväg, _hjúp, 
   {{0x69d9533e,0xb110063f,0x67d0010b,0xab25533f}},	//   _foue, bụwa, тощу, _жора_, 
   {{0x69d807e4,0xb0580254,0x260000db,0x00000000}},	//   _goue, lväe, кчыг, --, 
   {{0xdb1c05da,0x9f580798,0x692001c0,0x648401c6}},	//   _eorô, zirá_, _амта, мсэг_, 
   {{0x88bc068f,0x69d80dd4,0x77902be7,0xb05801f4}},	//   _myśl, _zoue, _شیبا, nväe, 
   {{0x9f58056a,0x69d80489,0x00000000,0x00000000}},	//   xirá_, _youe, --, --, 
   {{0x48a40020,0x9f58d3eb,0xdb1c0267,0x66e00107}},	//   _ለውጦች_, virá_, _inrä, _шоха, 
   {{0x60f80aec,0xe3ac005e,0x61e0007c,0x00000000}},	//   дняя_, ارۋ_, ömla, --, 
   {{0x9f58f466,0x67ec037e,0xb4a800c5,0x00000000}},	//   tirá_, _tøje, खबी_, --, 
   {{0x2004642b,0xf1bc01d3,0x00000000,0x00000000}},	//   èmia_, llám_, --, --, 
   {{0x9f5867c9,0x20040129,0x88d400cd,0xf1a40a5b}},	//   rirá_, émir_, _kṛti, _цркн, 
   {{0x69d95340,0xad982833,0x6b8000d2,0x74540092}},	// [22490] _roue, _djúp, óngo, _የቁጥጥ, 
   {{0x69d95341,0x1f755342,0x88d400b8,0xb05801e3}},	//   _soue, _илья, _mṛti, rväd, 
   {{0x69d95343,0x64900153,0xb058007c,0xd1300345}},	//   _poue, mžiš, sväd, _جمک_, 
   {{0xf1bd5344,0x09cc00fe,0xedc401e2,0x00000000}},	//   klám_, লস্থ, _تېري_, --, 
   {{0x69d95345,0x07a41b10,0xf3f8031c,0xdb1c007c}},	//   _voue, еалн, ྒྲོད_, _anrä, 
   {{0x69d80221,0xf1bc02fb,0xd52c01e1,0x00000000}},	//   _woue, dlám_, _só̟k, --, 
   {{0x69d95346,0xda795347,0x7de4037e,0x1ab40395}},	//   _toue, _оят_, にscr, _ибря, 
   {{0x99980006,0x69d80393,0x1a6801d5,0x9984007b}},	//   _durų_, _uoue, _آینی_, _للفو, 
   {{0x99980024,0x00000000,0x00000000,0x00000000}},	//   _eurų_, --, --, --, 
   {{0xf1bc011f,0x88d40055,0xfbd0095f,0x64900419}},	//   mmáy_, _dṛti, सायम, jžiš, 
   {{0xe9fc0016,0xfbd00302,0x67ec005c,0xbb38010f}},	//   _giản_, אתי_, _tøjb, ּערי, 
   {{0x70c95348,0x6d480010,0xb6b8011a,0x00000000}},	//   ामूल, žgaj, _מצעי, --, 
   {{0xea9c1682,0x6f1400b5,0xb17808fb,0xa28075f5}},	//   _miṱa_, _axxc, rhåp, ریکو, 
   {{0x7fd4187f,0x00000000,0x00000000,0x00000000}},	//   хімі, --, --, --, 
   {{0xdd040205,0xb0580254,0x00000000,0x00000000}},	//   _ısık, vväe, --, --, 
   {{0xc1b87146,0x3ec000e2,0x108800d1,0x00000000}},	//   _رابط_, _īstā_, _ﺑﻪﺩﯨ, --, 
   {{0x88bc012d,0xc10401c8,0xfbc401d5,0x7f7401c4}},	// [224a0] _byśm, _سودي, нбао, _пунц, 
   {{0x60c55349,0xed54013d,0x3ebc01e3,0x00000000}},	//   _irim, _җор_, åtts_, --, 
   {{0x79a5534a,0x88bc068f,0x60c400ad,0x11f801d9}},	//   ерле, _wyśl, _hrim, _رویک_, 
   {{0xd9105533,0x7075534b,0xb0581577,0x88d4002b}},	//   لیز_, _تمیز_, sväe, _nṛsi, 
   {{0x31780375,0x499001d5,0xa3bc0550,0xf7700014}},	//   פרסמ, شیلر, ँया_, ۆاں_, 
   {{0x60c4216e,0xe7c400ab,0x10881870,0xf7700014}},	//   _mrim, लागप, _ﺑﻪﺯﯨ, چاں_, 
   {{0xf7701973,0x96f81f10,0x2b75534c,0x75fc00e2}},	//   ناں_, ьект_, _سینگ_, lūzi, 
   {{0xaa41534d,0x60c5534e,0x7af0247e,0x9f580139}},	//   _бесл, _orim, ıktı, lirä_, 
   {{0xd3701823,0x60c40214,0xb4a802e5,0x7c3c01f5}},	//   لۇش_, _nrim, खबे_, ompr, 
   {{0xa878025f,0x324c001f,0xa5311dbc,0x7c3c007f}},	//   _מאמר, _አሰልጣ, ыныч, nmpr, 
   {{0x1cc0003d,0x60c5534f,0x7c3d5350,0x91ac012d}},	//   _གནའ_, _arim, impr, ज़लै, 
   {{0x60c55351,0x47a402f5,0x066461be,0x10880220}},	//   _brim, _গোপী, _شامپ, _ﺑﻪﺭﯨ, 
   {{0x60c50f14,0x70c805d7,0x67ec005c,0xf1bd5352}},	//   _crim, ामेल, _høja, llák_, 
   {{0x60c55353,0x7c3c01f5,0x00000000,0x00000000}},	//   _drim, jmpr, --, --, 
   {{0x60c55354,0xb8d031d9,0x9f580139,0x00000000}},	//   _erim, _ཟར_, dirä_, --, 
   {{0x7c3c5178,0x7a28041e,0xaf500139,0x80bc012d}},	//   empr, býti, _әннә, शिशे, 
   {{0x60c55355,0x9f580166,0x2d840205,0x00000000}},	// [224b0] _grim, firä_, ğne_, --, 
   {{0x2d855356,0x00000000,0x00000000,0x00000000}},	//   şne_, --, --, --, 
   {{0x67ec037e,0x4974ca08,0x60c4ac72,0x34bc00cd}},	//   _nøja, влес, _zrim, ौमुद, 
   {{0x246401e1,0xf1bc0306,0x88bc012d,0x00000000}},	//   _jímò_, dlák_, _wyśm, --, 
   {{0x1cc0031c,0x6d4c6b53,0x9a8401e0,0x24640248}},	//   _གནར_, _igca, _ҙурл, _mímò_, 
   {{0xd83802e2,0x07a4d9c5,0xc7a55357,0x57e802dd}},	//   _chč_, такн, тикк, ндім_, 
   {{0xa2e00118,0x46380395,0x00000000,0x00000000}},	//   táčí_, мчия_, --, --, 
   {{0x7ae80e38,0x246401e1,0x00000000,0x00000000}},	//   øfte, _nímò_, --, --, 
   {{0x6d4c00c6,0x58840024,0x00000000,0x00000000}},	//   _mgca, _быха, --, --, 
   {{0xd7f8487f,0x60c4bd71,0xf1bd5358,0x00000000}},	//   _пух_, _rrim, lláh_, --, 
   {{0x60c40687,0x00000000,0x00000000,0x00000000}},	//   _srim, --, --, --, 
   {{0x6d4c00aa,0x18b40022,0x427400db,0xdb0800e5}},	//   _ngca, _рҳәы_, нгүс, álét, 
   {{0x60c46064,0x00000000,0x00000000,0x00000000}},	//   _qrim, --, --, --, 
   {{0x13040046,0x60c55359,0x25840248,0x7a280252}},	//   _өзім, _vrim, _fìlà_, rýti, 
   {{0x91fc00da,0xf1bc011f,0x60c40165,0x7a2800d7}},	//   mpān, kláh_, _wrim, sýti, 
   {{0x60c5535a,0xb1100521,0xb2701945,0x00000000}},	//   _trim, tụta, _өләш, --, 
   {{0x60c5535b,0xf1bc00d0,0x5ba4329e,0x6b780055}},	// [224c0] _urim, dláh_, ллағ, _ṅgad, 
   {{0x0b581e76,0x98940116,0x7c3c127b,0x8fd4586a}},	//   ерцы_, ғудә, umpr, _йәсә, 
   {{0x7c3d22b1,0xeb95535c,0xb11000b4,0xef140276}},	//   rmpr, тих_, bụsa, _амэ_, 
   {{0x7c6400aa,0x2d8c0086,0xa27802d3,0xb11005db}},	//   _لاسل, òget_, _ኮይነን_, pụta, 
   {{0xdce405ce,0x79a401e0,0x00000000,0x00000000}},	//   obič, ерһе, --, --, 
   {{0xf1bc011f,0xc86400c6,0x6b602d29,0x00000000}},	//   aláh_, اطني, _вкра, --, 
   {{0x7bcd535d,0xeb95535e,0xeab4030d,0x989401ec}},	//   _inbu, _шир_, _ийр_, _әубә, 
   {{0x6ad800bd,0x54b9535f,0xe5c00395,0x9b9400ec}},	//   _যেকো, егия_, асьо, _جهڳڙ, 
   {{0x41d4000b,0xb110063f,0x67ec005c,0xf1bc0306}},	//   धानस, hụra, _iøjn, slák_, 
   {{0x38655360,0x52d80212,0x67ec005c,0x888001d3}},	//   mpor_, емою_, _højn, _ایون, 
   {{0x38655361,0xf1bc011f,0xdce402f0,0x00000000}},	//   lpor_, qlák_, dbič, --, 
   {{0xad980241,0x00000000,0x00000000,0x00000000}},	//   _amún, --, --, --, 
   {{0x3864083a,0x7bcc017a,0x00000000,0x00000000}},	//   npor_, _onbu, --, --, 
   {{0x7bcc00b5,0xf2c4300e,0x35680023,0x630000d1}},	//   _nnbu, _асин, _ደቀባት_, _ھويل, 
   {{0xdbdc066a,0xd3780034,0x3864003e,0x246401e1}},	//   _ráðl, mać_, hpor_, _tímò_, 
   {{0x7bcd5362,0x228007d6,0xd3780034,0xf1bc03b2}},	//   _anbu, _тушг, lać_, klái_, 
   {{0x5d555363,0xf9f800eb,0x00000000,0x00000000}},	// [224d0] ркут, েকাল_, --, --, 
   {{0xd378068f,0x38642e31,0x998001e4,0xab6000d1}},	//   nać_, dpor_, ĵiŝ_, شۇرى, 
   {{0xf09cb272,0x67ec00b5,0xe2880118,0x00000000}},	//   ltà_, _bøjn, _účtů_, --, 
   {{0xd3795364,0xf1bd1b71,0x7bcd5365,0x38640048}},	//   hać_, ndá_, _enbu, fpor_, 
   {{0xf09d5366,0xd378068f,0x9d140212,0xbb180131}},	//   ntà_, kać_, _вдяч, ﺷﻨﻰ_, 
   {{0xf09d5367,0x97c40131,0xd378033f,0xe784004e}},	//   ità_, لتىم, jać_, тудо, 
   {{0xd378006d,0x9b640131,0xdb1c0165,0x1cc0031c}},	//   dać_, _ئۆمۈ, _larê, _གནོ_, 
   {{0xd7c8036b,0xdce40427,0xb38000fb,0xf1bc00d7}},	//   _یوقه_, zbič, ҡлыл, jdá_, 
   {{0x4374516e,0x93bc0311,0xdce40306,0x45283a49}},	//   лунт, hlău, ybič, эжин_, 
   {{0xd3780034,0x76a803b9,0x00000000,0x00000000}},	//   gać_, _bəyd, --, --, 
   {{0x42081342,0xf09c43df,0xc2445fce,0x67ec01bf}},	//   енно_, età_, лнок, _højo, 
   {{0x28c427a6,0x09b00154,0x76a803e3,0xf1bd0ca8}},	//   लिपि, ছাকা, _dəyd, gdá_, 
   {{0xdb1d5368,0x03a4cbbe,0x7a2c022e,0xd378012d}},	//   _carê, _било, _mеtо, bać_, 
   {{0xf1bc0309,0x23b400dc,0xd378033f,0x25bc054e}},	//   kláw_, _असिद, cać_, ldul_, 
   {{0x44255369,0x249d536a,0x82a405f5,0x93243418}},	//   mol_, ltum_, _сайж, _پرون, 
   {{0x4425536b,0x25bd536c,0xdce402fb,0xdb1c0fac}},	//   lol_, ndul_, sbič, _inrø, 
   {{0x249cc51b,0xf09d536d,0xb05833b4,0x7a0c010f}},	// [224e0] ntum_, ctà_, lvän, nŝte, 
   {{0x4425536e,0x249d536f,0xad9800d2,0xeb94084c}},	//   nol_, itum_, _umún, лиу_, 
   {{0xb05801e6,0x249d5370,0x44240076,0x93bc0356}},	//   nvän, htum_, iol_, clău, 
   {{0x44255371,0xb864168d,0x249d5372,0xd3780034}},	//   hol_, هاتو, ktum_, zać_, 
   {{0x58d4052f,0x25bc0de2,0x37e401d5,0x00000000}},	//   ролт, ddul_, лодг, --, 
   {{0x7bcd5373,0xb0580793,0xf1bc02fb,0x249c003a}},	//   _unbu, kvän, zdá_, dtum_, 
   {{0x44255374,0x09a803f4,0x38655375,0xf1bc0548}},	//   dol_, ওয়া, spor_, ydá_, 
   {{0xd37814cf,0x44241509,0x25bc409c,0x249c08a7}},	//   wać_, eol_, gdul_, ftum_, 
   {{0x44240cfd,0x249d5376,0xd378068f,0x644c4c25}},	//   fol_, gtum_, tać_, ícip, 
   {{0x4424e7dc,0x3a255377,0xad980241,0xa1580046}},	//   gol_, loop_, _amúl, ғару_, 
   {{0x25bd5378,0x249c1730,0x5334074d,0xd3780034}},	//   bdul_, atum_, рент, rać_, 
   {{0xf09c9773,0x91c481fc,0xd378068f,0x3a255379}},	//   ttà_, рәкл, sać_, noop_, 
   {{0x249cc51b,0x4425537a,0xf1bd537b,0xf09c0268}},	//   ctum_, bol_, rdá_, utà_, 
   {{0x4425537c,0xf09d537d,0x3a2405e4,0xf1d00032}},	//   col_, rtà_, hoop_, рөҫө, 
   {{0xf09d537e,0x3a242595,0xa36c01f1,0x7a2806ea}},	//   stà_, koop_, äčši, nýts, 
   {{0xf09c07de,0x2ca9537f,0x28c40acd,0xdd94004e}},	//   ptà_, _ppcd_, लिमि, йасы, 
   {{0x3a2405e4,0x9f4d5380,0x67ec00b5,0xdb1c0240}},	// [224f0] doop_, òdò_, _bøjl, _farë, 
   {{0x32095381,0x3eb8030d,0xdb1d5382,0x3d1402ab}},	//   licy_, _fspt_, _karè, _नखरे_, 
   {{0xddd00365,0xdb1c033b,0x28c4012c,0xaee002dd}},	//   _çeşi, _jarè, लिभि, _اۋزى, 
   {{0x32080034,0x249d5383,0xdb1d5384,0x4c94a3ae}},	//   nicy_, ytum_, _marè, _кимс, 
   {{0x44255385,0x249c1730,0xdb1c24bc,0x6ce4f791}},	//   yol_, xtum_, _larè, _сіне, 
   {{0x44246270,0xc5ec020d,0xb058005b,0x00000000}},	//   xol_, जस्य_, yvän, --, 
   {{0x5884005e,0x44255386,0xfbd0227c,0x249c0208}},	//   _қыта, vol_, सारम, wtum_, 
   {{0x44255387,0x249d5388,0xc48407d6,0x3ebc09f3}},	//   wol_, ttum_, алик, ætti_, 
   {{0x44255389,0x25bd538a,0x6b800296,0x47d405d9}},	//   tol_, rdul_, óngw, _پيار, 
   {{0x249d538b,0x44240368,0xdb1d0b13,0x7a0c0115}},	//   rtum_, uol_, _barè, rŝte, 
   {{0x249d538c,0xc5d44dba,0xad9801e1,0xdb1d0baf}},	//   stum_, _віль, _amúm, _carè, 
   {{0x4425538d,0x249d538e,0xb05804f3,0xdb1c0066}},	//   sol_, ptum_, rvän, _darè, 
   {{0x4425538f,0x249c0357,0xb05801e6,0xdb1c02d3}},	//   pol_, qtum_, svän, _parë, 
   {{0x88bc068f,0x64581730,0x44255390,0x65795391}},	//   _wyśw, mqui, qol_, lauh, 
   {{0x64584888,0xdb1d5392,0x24580051,0x32095393}},	//   lqui, _garè, _hêm_, bicy_, 
   {{0x8e555394,0x64595395,0x65795396,0x67ec00b5}},	//   стрі, oqui, nauh, _søjl, 
   {{0xed543290,0x2458017a,0xb058023a,0x195802dd}},	// [22500] роу_, _jêm_, nväl, қалы_, 
   {{0x65795397,0x61e55398,0x30780302,0xdb1d5399}},	//   hauh, _hoil, _שאינ, _haré, 
   {{0x6578123c,0xdb1c0438,0x703800dd,0x61e5539a}},	//   kauh, _karé, _جسٹس_, _koil, 
   {{0x6579209e,0xb179539b,0x7051539c,0xb058049f}},	//   jauh, lkår, _دنیا, kväl, 
   {{0x3a241af3,0xdb1d539d,0x61e400c6,0x245801fb}},	//   roop_, _maré, _moil, _nêm_, 
   {{0x61e5539e,0x64581730,0xb2241f60,0xf090011a}},	//   _loil, dqui, _klæð, קנו_, 
   {{0x61e402a4,0x6d480427,0x3b09532b,0x00000000}},	//   _ooil, žgat, _рево_, --, 
   {{0x6579539f,0x68e8b5a3,0x61e48d61,0x786400d6}},	//   gauh, bygd, _noil, _вказ, 
   {{0xdb1d53a0,0xb178007c,0x7ae801e3,0x00000000}},	//   _sarè, kkår, äftf, --, 
   {{0xdb1c0699,0x6284003d,0x2458017a,0x61e436f4}},	//   _parè, ġjon, _dêm_, _aoil, 
   {{0x64580d04,0x78a153a1,0xdb1c4542,0xec340302}},	//   aqui, ltov, _baré, שאיר_, 
   {{0x61e553a2,0xdb1d53a3,0x94c8004b,0xf508084c}},	//   _coil, _caré, _ماتې_, _инел_, 
   {{0x78a002fb,0x61e553a4,0x6458efa9,0xdb1cd71f}},	//   ntov, _doil, cqui, _daré, 
   {{0x78a153a5,0xb2240252,0xb17803cd,0xddc400a2}},	//   itov, _blæð, gkår, lmiň, 
   {{0x61e553a6,0x34b407f8,0xdb1c0005,0x78a153a7}},	//   _foil, _अनुद, _faré, htov, 
   {{0x78a002fb,0x61e553a8,0x30e8035b,0xdb1d53a9}},	//   ktov, _goil, _афон_, _garé, 
   {{0x78a153aa,0x621c0a7c,0x7ae8072b,0x24580051}},	// [22510] jtov, _שוחק, øftn, _xêm_, 
   {{0xeb9112cd,0x61e553ab,0xb22401a8,0x00000000}},	//   تظر_, _zoil, _flæð, --, 
   {{0x65780cfe,0x64583eba,0x5bc401d5,0xff6400c7}},	//   yauh, zqui, تقلل, _уэыҟ, 
   {{0xd7c800aa,0x34b40034,0x61e4005a,0x6458c5e5}},	//   یونه_, _अनूद, _xoil, yqui, 
   {{0x65783209,0x1cc00f50,0xb05801e6,0xf1bc01ed}},	//   vauh, _གནག_, kväm, llás_, 
   {{0xe7340032,0xf1bc0005,0x67ec005c,0x68e80174}},	//   һеҙ_, xoán_, _tøjm, rygd, 
   {{0x657953ac,0x68e8037e,0x67ec00b5,0xf1bc00e5}},	//   tauh, sygd, _højk, nlás_, 
   {{0x64580cfe,0xdb1d53ad,0x657800d8,0x78a001d5}},	//   tqui, _karî, uauh, btov, 
   {{0x657953ae,0xf1bc01f1,0xdb1d0ac7,0x78a002f0}},	//   rauh, hlás_, _raré, ctov, 
   {{0x61e553af,0xdb1c5f14,0x245806ed,0x657953b0}},	//   _soil, _saré, _vêm_, sauh, 
   {{0x645953b1,0x61e553b2,0xdb1d53b3,0xd7c953b4}},	//   squi, _poil, _paré, _خوله_, 
   {{0x245803b7,0xb0c153b5,0xdb0801ed,0xd174021f}},	//   _têm_, शिंग, ülés, жыры, 
   {{0x61e553b6,0xad9800d2,0x64580140,0x7a0c0115}},	//   _voil, _emúk, qqui, nŝta, 
   {{0x7afd53b7,0x76a80cc1,0x00000000,0x00000000}},	//   yzpt, _həya, --, --, 
   {{0x61e553b8,0xdb1d53b9,0x78a00010,0xf1bc00e5}},	//   _toil, _taré, ztov, glás_, 
   {{0x78a003c6,0xb17821e3,0x7a0c01e4,0x22800db1}},	//   ytov, skår, kŝta, mık_, 
   {{0x228153ba,0x3b8484e5,0x78a00232,0x2240020c}},	// [22520] lık_, йлаг, xtov, _ihik_, 
   {{0x78a0009b,0x7a0c0115,0x76a80213,0x72a00133}},	//   vtov, dŝta, _ləya, _بڕین, 
   {{0xee440209,0x228003ee,0xae4001ed,0xf1bc01e7}},	//   şýar_, nık_, تھیو, clás_, 
   {{0x7db553bb,0x78a0447e,0x67ec037e,0x3ebc0252}},	//   _اصدا, ttov, _højh, ættu_, 
   {{0xe3a40583,0x1754021b,0x78a0a088,0x00000000}},	//   _ٹر_, овля, utov, --, 
   {{0x78a153bc,0xe3a53bf2,0xdb1403a2,0x201953bd}},	//   rtov, _عر_, _ïaïo, nnri_, 
   {{0x78a153be,0x76a803be,0x7c2c0204,0x3dc0003a}},	//   stov, _bəya, _ikbr, _kakw_, 
   {{0x2280a493,0x78a153bf,0x2240020c,0xf1bc00c6}},	//   dık_, ptov, _nhik_, hlár_, 
   {{0x628153c0,0x342400a7,0x32640daf,0xad9803b2}},	//   _avno, йфов, әтов, _smúk, 
   {{0x224003b9,0x228003e0,0xfbcc0c87,0x00000000}},	//   _ahik_, fık_, _होमम, --, 
   {{0xd7f80356,0x00000000,0x00000000,0x00000000}},	//   _ilă_, --, --, --, 
   {{0xc05c0597,0x224153c1,0xe3ac021a,0x46c4085c}},	//   ʊɖǟ_, _chik_, ورۍ_, विरह, 
   {{0x4de02158,0x224153c2,0x25b424c5,0x656c0489}},	//   নসমূ, _dhik_, _دهند_, ñche, 
   {{0x765953c3,0x777801c4,0xb058005b,0xf1bc01d3}},	//   _kuty, _jetx, lväk, tlás_, 
   {{0x228003ee,0x0cd02c2e,0x777864cb,0xdb1c00e4}},	//   cık_, सम्म, _metx, _sarî, 
   {{0x765953c4,0xf1bc00dd,0x6460066a,0x76a800ac}},	//   _muty, rlás_, _óvið, _xəya, 
   {{0x683c000f,0x13ac015b,0x765953c5,0xf1bc950c}},	// [22530] lêde, _কোয়, _luty, slás_, 
   {{0x76580ea0,0xd15000cd,0x4fc00131,0x28c41b76}},	//   _outy, _aṅga_, _غەزە, लिसि, 
   {{0x1dc49201,0x76580153,0xe0d002f2,0x00000000}},	//   _लोकत, _nuty, _قزی_, --, 
   {{0x7c2c010f,0x7778005a,0xad980022,0xdb1c0332}},	//   _ekbr, _aetx, _omúi, _anró, 
   {{0x22801918,0x7778022e,0x28a4023a,0x67ec01bf}},	//   zık_, _betx, сшег, _høji, 
   {{0x765953c6,0x26c40e3c,0x76a800ac,0xfe6c0014}},	//   _buty, tvno_, _səya, _سگہ_, 
   {{0x298400ee,0x4e0c09bb,0x7a0c01e4,0xf7400108}},	//   _гызг, _सगाई_, sŝta, мешо, 
   {{0x7ae953c7,0x76580526,0x291c0211,0x62840030}},	//   äfte, _duty, _txua_, ájom, 
   {{0x76580381,0x7778005a,0x201803b2,0xe87002f2}},	//   _euty, _fetx, ynri_, _رناگ, 
   {{0x228027a7,0x777801c0,0x224153c8,0xd83801c6}},	//   tık_, _getx, _shik_, _лэх_, 
   {{0x76585ba3,0xa5042928,0xe9fc001e,0x28c4d59c}},	//   _guty, شىگە_, _nhẫn_, लिवि, 
   {{0x22801918,0x00000000,0x00000000,0x00000000}},	//   rık_, --, --, --, 
   {{0xdb1c0268,0x04c8511e,0xf6c4025c,0x228005d1}},	//   _aarì, _خوشي_, _གནོང, sık_, 
   {{0x8db40220,0x628153c9,0x683c002d,0xb1787813}},	//   үсті, _tvno, bêde, skåp, 
   {{0x224153ca,0xf1bc01e7,0x00000000,0x00000000}},	//   _thik_, rlár_, --, --, 
   {{0xc1b953cb,0x660805b1,0x1cb0025c,0xed5553cc}},	//   _ضابط_, _jmgk, _ྒྱུ_, жот_, 
   {{0xdb1c025a,0x21200548,0x67ec01bf,0x00000000}},	// [22540] _parï, _uxih_, _tøjh, --, 
   {{0x9f60adae,0xe8dc004d,0x3b8553cd,0x00000000}},	//   ärät_, _ngốn_, ілег, --, 
   {{0x8b642db0,0x34b41df1,0xdb1c0165,0xb058023a}},	//   سالم, _अन्द, _varï, yväk, 
   {{0x76591f3e,0xfe4000e5,0x00000000,0x00000000}},	//   _ruty, _آکسی, --, --, 
   {{0x765807ab,0x2db40302,0x777851cd,0x7ae8007c}},	//   _suty, _ולכן_, _petx, äftb, 
   {{0xdb1d53ce,0x3688036b,0x67d0d873,0x624c00a2}},	//   _harí, асин_, дошу, _ỳola, 
   {{0x569553cf,0xdb1d53d0,0x26c0107d,0x41c82894}},	//   чайт, _enrò, _šjor_, ियास, 
   {{0x7a0c01e4,0x28c421f2,0x00000000,0x00000000}},	//   mŝto, लिशि, --, --, 
   {{0xdb1d53d1,0xe9fc001e,0x8ccc0034,0x7778005a}},	//   _marí, _hiến_, सियो, _tetx, 
   {{0xe9fc07ae,0xf74553d2,0x765953d3,0x683c000f}},	//   _kiến_, _дезо, _tuty, têde, 
   {{0x7a0c0115,0xd3700066,0x00000000,0x00000000}},	//   nŝto, وهک_, --, --, 
   {{0x320953d4,0xe9fc004d,0x683c000f,0xf204109a}},	//   рхон_, _miến_, rêde, іяно, 
   {{0xdb1c0268,0x2bb8012c,0xe9fc0051,0x00000000}},	//   _sarì, _उसला, _liến_, --, 
   {{0xb05953d5,0xdb1c026c,0xe9fc01fb,0x7a0c01e4}},	//   hwäg, _parì, _phẫn_, kŝto, 
   {{0x226001f1,0xdb1c0248,0xe294147e,0x00000000}},	//   ľské_, _barí, _дај_, --, 
   {{0xdb1d53d6,0x22614555,0xf0f001ec,0xd6bc05ac}},	//   _carí, žské_, _жүмы, _অপায, 
   {{0xdb1c09ff,0x62240150,0x2bd43507,0x00000000}},	// [22550] _darí, _تىيل, ठाला, --, 
   {{0xe9fc01fb,0xaca001f2,0x7640062c,0x67ec005c}},	//   _biến_, _nhục, _lhoy, _højv, 
   {{0xdb1d53d7,0xc9581955,0x4a5401df,0xea880244}},	//   _farí, ملاش_, чкес, شخان_, 
   {{0xaca0063f,0xe9fc004d,0xdb1c0789,0xd6e00154}},	//   _ahục, _khẩn_, _garí, বনায, 
   {{0x7e6009a8,0x00000000,0x00000000,0x00000000}},	//   _čopi, --, --, --, 
   {{0x7640013f,0xb05801f4,0xca3402dd,0x00000000}},	//   _ahoy, rväh, _ﻗﺼﺩ_, --, 
   {{0xea6000dd,0xb05953d8,0x00000000,0x00000000}},	//   _آپری, sväh, --, --, 
   {{0xdb1d53d9,0x764153da,0x9f58011c,0xc1d8012d}},	//   _farâ, _choy, nirò_, _बचेग, 
   {{0x764153db,0xdb1c000f,0x6fc81fbc,0x588402d5}},	//   _dhoy, _garâ, ायां, _жыха, 
   {{0x76400076,0xd78800db,0x00000000,0x00000000}},	//   _ehoy, _ونقو_, --, --, 
   {{0x97a553dc,0xb38001c0,0x2d880332,0x00000000}},	//   _юртл, элэл, _odce_, --, 
   {{0x7640062c,0xdb1c0055,0x00000000,0x00000000}},	//   _ghoy, _harã, --, --, 
   {{0xdb1c0998,0x661953dd,0xe9fc01fb,0xdce404a7}},	//   _rarí, mnuk, _chẩn_, mbić, 
   {{0x2d880113,0x644c0137,0x661800c5,0x83a400c7}},	//   _adce_, ïcid, lnuk, _хыдҵ, 
   {{0xdb1d53de,0x644000b5,0x6618009f,0xb1780158}},	//   _parí, _ihni, onuk, sjåa, 
   {{0x661953df,0x9f583eba,0x3c6402d5,0xdb1c0166}},	//   nnuk, tiró_, зкаг, _qarí, 
   {{0xdb1d53e0,0x64400652,0x661953e1,0xb05802f6}},	// [22560] _varí, _khni, inuk, yväi, 
   {{0xdb1c52c0,0x76a80213,0xb14000fb,0x0ba800d1}},	//   _narã, _bəyl, _яныл, قامى_, 
   {{0xdb1c0724,0x66180280,0x05bc2e3b,0x00000000}},	//   _tarí, knuk, ्याब, --, 
   {{0xad980248,0xdb1c0120,0x9f58004e,0x7a0c0115}},	//   _alúf, _parâ, piró_, rŝto, 
   {{0x644011c4,0xdb1c0120,0x91fc1a14,0x661953e2}},	//   _ohni, _barã, mpāt, dnuk, 
   {{0xe9fc07ae,0x764153e3,0x6d380375,0x1cb00327}},	//   _tiến_, _shoy, _לתכנ, _ྒྱག_, 
   {{0xdb1d53e4,0x764153e5,0xb05801f4,0x6618032e}},	//   _warâ, _phoy, rväi, fnuk, 
   {{0x64404e3d,0x76400113,0xba1953e6,0x661800e8}},	//   _ahni, _qhoy, _ايرا_, gnuk, 
   {{0x1ce40135,0xdb1d53e7,0x656d53e8,0xb058007c}},	//   ྨའི_, _harà, ñcha, lväv, 
   {{0xdb1c05da,0x644003d5,0x661953e9,0x4a08025c}},	//   _karà, _chni, anuk, _གཏོལ_, 
   {{0x644001ab,0x661953ea,0x764000ad,0xe3ac01d3}},	//   _dhni, bnuk, _thoy, ھری_, 
   {{0x79800451,0x35a405f5,0x752001c4,0xe3ac21f4}},	//   naow, _хадг, _txoz, پری_, 
   {{0x644001ab,0xb4b05183,0x00000000,0x00000000}},	//   _fhni, _чилә, --, --, 
   {{0x644008c2,0xad980174,0x28bc0118,0x00000000}},	//   _ghni, _klúg, _एनसि, --, 
   {{0x798153eb,0x9f58011c,0x67ec005c,0x7ea40116}},	//   kaow, tirò_, _tøjv, мутҗ, 
   {{0x67ec04ce,0x76a803e3,0xe9fc0208,0x644000d7}},	//   _højt, _rəyl, _thẩn_, _zhni, 
   {{0x9f580395,0x7980009a,0x76a80213,0x6ce400d4}},	// [22570] rirò_, daow, _səyl, чіве, 
   {{0xdb1c05da,0xad980ca8,0x4f8400e5,0x00000000}},	//   _barà, _olúg, _کاکہ, --, 
   {{0xdb1c0228,0x9f58011c,0x6618fcad,0x00000000}},	//   _carà, pirò_, ynuk, --, 
   {{0x7ae801e6,0xdb1c0241,0x67ec005c,0x00000000}},	//   äfta, _darà, _løjt, --, 
   {{0x76a80213,0x1a6801d3,0x25b806be,0xbb3400d1}},	//   _dəym, _ہیلی_, _öylə_, ﻗﻨﻰ_, 
   {{0xdb1c00cf,0xee840873,0xc7980014,0x00000000}},	//   _farà, ﺭﮔﻪﻥ_, تھرا_, --, 
   {{0xdb1c0798,0x00000000,0x00000000,0x00000000}},	//   _varã, --, --, --, 
   {{0x661953ec,0x644153ed,0xad9801e7,0x00000000}},	//   unuk, _shni, _imús, --, 
   {{0x661953ee,0x644003a2,0xdb1c007b,0xb0580e78}},	//   rnuk, _phni, _iará, hwäb, 
   {{0xdb1d53ef,0xad98022c,0xe9fc0051,0x9f5801e7}},	//   _hará, _flúg, _khắn_, thrí_, 
   {{0xdb1c00dd,0x49100490,0x661953f0,0x94a80014}},	//   _kará, _देतो_, pnuk, _ہاوِ_, 
   {{0x7ae84673,0xcf8808a8,0xb17800fe,0x00a003e6}},	//   øfti, _כט_, sjån, نیبێ, 
   {{0x03a4074d,0x850401d5,0x644001ab,0x9f5803b2}},	//   _жило, _توشن, _thni, firð_, 
   {{0xad9800db,0xdb1c1d0e,0x00000000,0x00000000}},	//   _llúd, _lará, --, --, 
   {{0xe9fc07ae,0xc2081a4d,0x67ed53f1,0x63a002d0}},	//   _nhắn_, _وقتن_, _højs, _icnn, 
   {{0xdb1cd827,0xdd1c01ef,0x00000000,0x00000000}},	//   _rarà, _vážo, --, --, 
   {{0xbc686a72,0xad9801e1,0xb05801c7,0x00000000}},	// [22580] زمان_, _amús, twäe, --, 
   {{0x60c553f2,0xdb1d1e55,0x7b1400c6,0xad980030}},	//   _isim, _parà, وظائ, _smút, 
   {{0xdb1d53f3,0xe9fc0016,0xfe4405f5,0x79800083}},	//   _bará, _chắn_, _оноо, taow, 
   {{0xdb1d12c0,0xad9800c6,0xf99006f6,0x60c401a9}},	//   _cará, _clúd, ئبا_, _ksim, 
   {{0x6ef4014a,0x3950023a,0xdb1d53f4,0x67ec01bf}},	//   pübö, äys_, _dará, _nøjs, 
   {{0x60c405d9,0xdb1c004e,0xe8dc0208,0xe60c00f1}},	//   _msim, _tarà, _ngổn_, یشي_, 
   {{0xdb1d53f5,0xe81c8061,0xd6d112cd,0xad980241}},	//   _fará, _बदरा_, اقب_, _imúr, 
   {{0x60c553f6,0xdb1c19fd,0xad9800d2,0xf7700451}},	//   _osim, _gará, _umút, راڻ_, 
   {{0x60c553f7,0xc7e80050,0xd4540114,0x00000000}},	//   _nsim, تى۪ن_, нкић, --, 
   {{0xdb1d53f8,0x6840f35c,0xb0581a80,0x00000000}},	//   _zará, _ануа, hwäc, --, 
   {{0xb3740092,0x00000000,0x00000000,0x00000000}},	//   _የአይን_, --, --, --, 
   {{0xb9d402d3,0x69000205,0x00000000,0x00000000}},	//   _ኸአ_, _övdü, --, --, 
   {{0xb05800d7,0x6ad81be1,0x00000000,0x00000000}},	//   jvät, _यप्र, --, --, 
   {{0x67ec019b,0x9a8c02d3,0x644c0113,0x48f8010f}},	//   _højr, _ኣፍደገ_, ìcit, פּרא, 
   {{0x60c553f9,0x630002f2,0xceb800d1,0xb058002f}},	//   _esim, _لوول, чәп_, fwäc, 
   {{0x60c40175,0x6c7402dd,0x00000000,0x00000000}},	//   _fsim, _ﺠﻨﻭﺏ_, --, --, 
   {{0xe81d53fa,0x84240014,0xad9802d2,0xea9c00b8}},	// [22590] _बदला_, _تى۪ن, _smús, _viṭa_, 
   {{0xba180113,0x91fc00ef,0x00000000,0x00000000}},	//   _ma鯵a, cpār, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9d541c3e,0x00000000,0x00000000,0x00000000}},	//   رنەت, --, --, --, 
   {{0x9f580597,0xdb1c01ed,0x00000000,0x00000000}},	//   mhrá_, _vará, --, --, 
   {{0xb0582c4f,0xe9fc004d,0x67ec005c,0xa09c010f}},	//   lväs, _thắn_, _røjs, קיוט, 
   {{0xad9953fb,0x29100227,0x656c0156,0xdb1c299d}},	//   _umús, ńxa_, ñcho, _tará, 
   {{0xad98682a,0x2bd4033f,0x2ba808df,0xb058007c}},	//   _flúe, ठाका, घ्रा, nväs, 
   {{0x69d953fc,0xad9801a8,0x69c80112,0xb05801f4}},	//   _inue, _klúb, mdge, iväs, 
   {{0x69c953fd,0x60c4013c,0x75407d2c,0xa28004fb}},	//   ldge, _rsim, ыныз, نیتو, 
   {{0x69d80221,0x60c553fe,0x9814007b,0x670401f9}},	//   _knue, _ssim, _شبكا, _वेचक_, 
   {{0x69c809f9,0x60c405ce,0x67ec00b5,0xb0580108}},	//   ndge, _psim, _tøjs, yvät, 
   {{0xe9fc01dc,0xb05811ab,0x3b0401e1,0xad980248}},	//   _nhận_, dväs, _kípé_, _olúb, 
   {{0x91a806c8,0xd9bc02ab,0x60c413d5,0x03a40818}},	//   _akā_, _ईस्ट, _vsim, _чико, 
   {{0xb058002f,0x00000000,0x00000000,0x00000000}},	//   twäc, --, --, --, 
   {{0x71a02c1d,0x60c553ff,0xfce55400,0x91fc005f}},	//   _баъз, _tsim, нобо, spār, 
   {{0xdef80201,0x60c40a29,0x28bc1d8a,0xf650008f}},	// [225a0] ለቲካ_, _usim, _शैलि, רצן_, 
   {{0x69d80069,0x7ae801e6,0x69c80549,0xdb1c00a2}},	//   _anue, äfto, edge, _jarç, 
   {{0xdb1d5401,0x69c80d27,0xb0595402,0x7a0c01e4}},	//   _març, fdge, svät, lŝti, 
   {{0xeb300aaf,0x69c8ef24,0xb0580267,0x00000000}},	//   دىمد, gdge, mvär, --, 
   {{0xb0595403,0x7af400b8,0xed5401f4,0x00000000}},	//   lvär, _ũatā, _пою_, --, 
   {{0xfaa55404,0xb6c405f5,0x69d8035a,0x69c805e4}},	//   _паго, есий, _enue, adge, 
   {{0xab241a92,0xba1800e8,0xb0595405,0x69c80009}},	//   _зора_, _sa鯵a, nvär, bdge, 
   {{0xc1c83be5,0x25843ee0,0xaee00055,0x491029d9}},	//   ियोग, ىنىپ_, _asṛg, _देवो_, 
   {{0xdb1d5406,0x9404016b,0x7954010b,0x9f580124}},	//   _barç, wumɑ_, _düwü, mirõ_, 
   {{0xb0595407,0x656801a6,0xc33800bc,0x1cb00327}},	//   kvär, _efgh, číná, _ྒྱབ_, 
   {{0xb058023a,0xc76402dd,0x67ec01bf,0xdb1c03b9}},	//   yväs, _شالى, _tøjr, _darç, 
   {{0xb0595408,0x76a80213,0x67ec01bf,0x00000000}},	//   dvär, _nəyi, _højp, --, 
   {{0xad992ed2,0x3864016d,0x43e80451,0xb0580037}},	//   _llúc, nqor_, _ڪرنٽ_, evär, 
   {{0xdb1d5409,0xe9fc0051,0x53340256,0x00000000}},	//   _garç, _khản_, _иелт, --, 
   {{0xb8d00135,0x9f5802e2,0x76a80213,0x3864022e}},	//   _ཐཱ_, nkrè_, _bəyi, hqor_, 
   {{0xdb1c15ca,0xe9fc0016,0x2d8c000f,0x67ec01bf}},	//   _marä, _phận_, ûge_, _løjp, 
   {{0x76a80cc1,0x1cb0025c,0xf1bd540a,0x072c005e}},	// [225b0] _dəyi, _ྒྱད_, meá_, ﺩﯨﯔ_, 
   {{0xb604041a,0x69d805d5,0x9c390bea,0x16fc0327}},	//   lešć, _snue, епут_, ྐྱོམ_, 
   {{0xdb1c00c7,0xb0583400,0xf09c04cc,0xdce401e4}},	//   _narä, sväs, luà_, mbiĝ, 
   {{0xe9fc001e,0x3b040248,0xf1bc0332,0x00000000}},	//   _thận_, _sípé_, neá_, --, 
   {{0x07a5540b,0xf09d540c,0x5f44036b,0x998400e3}},	//   валн, nuà_, _لنیل, الهو, 
   {{0xdb1c0139,0xf1bc0f47,0x9f5800e4,0x76a806be}},	//   _barä, heá_, rirö_, _zəyi, 
   {{0x96946874,0xad980332,0xb854431a,0xbfac00cc}},	//   грыш, _glúc, خلوص_, _ছোঁঘ, 
   {{0x9b580364,0x69d8008f,0xb6042630,0x99843ded}},	//   _чист_, _unue, ješć, _ملفو, 
   {{0xdb1d540d,0xf1bc01f1,0xe5a000d1,0x3b040241}},	//   _parç, deá_, виқи, _típé_, 
   {{0x814404d3,0x47d40451,0xdb1ca75a,0x7bd801e1}},	//   ێندن, _جيئر, _qarç, _òtut, 
   {{0xfbd00302,0x569416c3,0xf1bd540e,0xdb1c008e}},	//   בתי_, _бахт, lláy_, _garä, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x28c42232,0xdb1c03e0,0x25bd540f,0x7e7c0142}},	//   लिटि, _tarç, meul_, _swpp, 
   {{0x50582e01,0x25bc054e,0x249c003a,0x76a806be}},	//   ешся_, leul_, muum_, _səyi, 
   {{0x0eb84b2c,0xb05801e6,0xf7700375,0xb604107d}},	//   нуты_, tvär, שקל_, bešć, 
   {{0xf1bd5410,0x25bc5785,0xcdc40046,0x00000000}},	//   ceá_, neul_, ласқ, --, 
   {{0x249d5411,0xb058049f,0xdb1c0158,0xad980030}},	// [225c0] nuum_, rvär, _marå, _slúc, 
   {{0xb0595412,0x25bc0438,0xad9801e7,0xb7780055}},	//   svär, heul_, _plúc, _puṭā, 
   {{0x20195413,0x3dd00156,0x76a803be,0xb05801e6}},	//   miri_, ཏཐདན, _təyi, pvär, 
   {{0xd9108a41,0xb0580e78,0x00000000,0x00000000}},	//   میز_, nwän, --, --, 
   {{0x25bd5414,0xdb1c0309,0x249c0009,0x9f580022}},	//   deul_, _sarä, juum_, rirõ_, 
   {{0x20195415,0xe9fc07ae,0x249c1730,0xdb1c0a40}},	//   niri_, _phản_, duum_, _parä, 
   {{0xf1bc011f,0x25bc0311,0x00000000,0x00000000}},	//   aláy_, feul_, --, --, 
   {{0x20195416,0x7c3d5417,0x25bd5418,0x4f68001f}},	//   hiri_, llpr, geul_, ዳንዶቹ_, 
   {{0x69d00232,0xb60417a3,0xf1bc0093,0x3eb80175}},	//   ádež, vešć, veá_, _lppt_, 
   {{0x20195419,0xe9fc01fb,0x66d000ec,0x91a4000d}},	//   jiri_, _thản_, _ھينئ, _काहै, 
   {{0x25bd541a,0xd5a5541b,0x7c3c7421,0xf1bd1980}},	//   beul_, _ملای, ilpr, teá_, 
   {{0x25bc0276,0x249d541c,0xf09d536d,0x7c3c2ad7}},	//   ceul_, buum_, tuà_, hlpr, 
   {{0x2019541d,0x249d52ac,0xef380020,0x3eb82040}},	//   firi_, cuum_, _የኤኮኖ, _appt_, 
   {{0x2019541e,0x3eb80263,0xf09c004e,0x904400f2}},	//   giri_, _bppt_, ruà_, انسه, 
   {{0xa2c40220,0xb6040841,0x7a0c01e4,0xdce400df}},	//   _ауыз_, pešć, lŝtu, rbiĝ, 
   {{0x7c3c7585,0x41a8012a,0x00000000,0x00000000}},	//   elpr, _कायस, --, --, 
   {{0xf09c468a,0x6ab805d7,0x8bd85a5b,0xe9fc0208}},	// [225d0] quà_, ईब्र, нмас_, _nhạn_, 
   {{0x2019541f,0x25bc084c,0x99d41bf4,0x7c3c0171}},	//   ciri_, zeul_, یتنا, glpr, 
   {{0x4974026a,0x09b002f5,0x656c0054,0x41a81fad}},	//   глес, _ঘোষা, ñchk, _कामस, 
   {{0x7c3cf612,0x249c0009,0x00000000,0x00000000}},	//   alpr, yuum_, --, --, 
   {{0x689001d3,0x249c0393,0xa8a40d1d,0x76a803e3}},	//   شیائ, xuum_, трек, _məyu, 
   {{0x3eb80098,0x02d400dc,0xb77800b8,0x00000000}},	//   _yppt_, धिमभ, _ruṣā, --, 
   {{0xdb1c0428,0x25bd5420,0x249c0083,0xa9c55421}},	//   _marû, teul_, wuum_, _исак, 
   {{0x20195422,0x249c1730,0x25bc0c6a,0x09b00154}},	//   ziri_, tuum_, ueul_, _ঘোরা, 
   {{0x20195423,0x25bd5424,0x644c381a,0xf5e40e56}},	//   yiri_, reul_, ïcio, اتىۋ, 
   {{0x3fcc00bd,0x25bc0276,0x249d5425,0xdce4005f}},	//   _রক্ষ, seul_, ruum_, nciā, 
   {{0x20195426,0x25bd5427,0x249c0381,0xb05801c7}},	//   viri_, peul_, suum_, twän, 
   {{0x20195428,0x249c16b8,0xb778002b,0x00000000}},	//   wiri_, puum_, _tuṣā, --, 
   {{0x20195429,0x6579542a,0xdb1c0086,0x249c1730}},	//   tiri_, mbuh, _barû, quum_, 
   {{0xc3041867,0x93bc0356,0x3518011a,0x6579542b}},	//   _مبعو, rnăc, _אוננ, lbuh, 
   {{0x657808ad,0xb0580036,0x7db44f55,0x2bc421b8}},	//   obuh, pwän, лсац, रजना, 
   {{0x2019542c,0x65780ecf,0xf1bc02f0,0xef200092}},	//   siri_, nbuh, soár_, ደሚያው, 
   {{0x271c2068,0x2019542d,0xc0592a2a,0xfbd00014}},	// [225e0] यपुर_, piri_, _проц_, ٝتا_, 
   {{0x2019542e,0xbb85542f,0xb05803fa,0xaa5403cc}},	//   qiri_, الاي, nwäl, ۇللا_, 
   {{0x657822d0,0x7c3c0334,0xdb24bd8e,0xdb1c0162}},	//   kbuh, rlpr, جوای, _harú, 
   {{0x3f895430,0xdb1c9f88,0x6e980375,0x7c640131}},	//   labu_, _karú, _אבטח, _ماسل, 
   {{0x81cc00bd,0xddc40034,0x17840107,0xcdc401ec}},	//   রাপ_, rmiń, иҳам, _таяқ, 
   {{0x3f8804ce,0xe9a002dd,0xdb1c01e1,0x7a840472}},	//   nabu_, _қауп, _marú, _مشرم, 
   {{0x7bcc0280,0x601403b9,0x00000000,0x00000000}},	//   _iabu, _cümə, --, --, 
   {{0x3f895431,0x7bcd5432,0x6578d622,0xa2d400cd}},	//   habu_, _habu, gbuh, यिन्, 
   {{0x3f895433,0xad9801e1,0xdb1c0419,0x00000000}},	//   kabu_, _olún, _narú, --, 
   {{0x7bcd5434,0x78a03993,0x3f8800ec,0x81cc015b}},	//   _jabu, muov, jabu_, রাফ_, 
   {{0x7bcd5435,0x81cc015b,0x3f895436,0x65782988}},	//   _mabu, রান_, dabu_, bbuh, 
   {{0xf0741cd1,0xdb1c007b,0x00000000,0x00000000}},	//   лимә_, _barú, --, --, 
   {{0x78a04d16,0xdef802dd,0xdb1c0332,0xad98032e}},	//   nuov, қыр_, _carú, _blún, 
   {{0xdb1c0241,0x3f880083,0x5eb400d1,0xd5b4000d}},	//   _darú, gabu_, әйтт, _अउँज, 
   {{0x78a15437,0x00000000,0x00000000,0x00000000}},	//   huov, --, --, --, 
   {{0x7bcd5438,0x78a15439,0x2bc40b7d,0x228001c6}},	//   _aabu, kuov, रजभा, _уушг, 
   {{0x3f8800b2,0x656d543a,0xdb1c02d2,0x78a0af5f}},	// [225f0] babu_, ñchi, _garú, juov, 
   {{0x5d551421,0x3f880117,0xad9800ae,0x00000000}},	//   скут, cabu_, _glún, --, 
   {{0x7bcd543b,0xdce4005f,0xdb1c0ca8,0xe8e803e6}},	//   _dabu, rciā, _karù, کراو_, 
   {{0x7c3000ef,0x00000000,0x00000000,0x00000000}},	//   _čerņ, --, --, --, 
   {{0x7bcd543c,0xdb1c0086,0xb058324c,0x30f400cd}},	//   _fabu, _marù, hwäm, ुनिः_, 
   {{0x7bcd543d,0xd15000b8,0x76a803e3,0xec1401af}},	//   _gabu, _aṅka_, _nəys, _сегә_, 
   {{0x8ccc6236,0x65780327,0x00000000,0x00000000}},	//   सिको, tbuh, --, --, 
   {{0x5b1535ea,0x6b840cf4,0x3f89543e,0x78a00308}},	//   _умст, _hejg, zabu_, buov, 
   {{0x81cc0d42,0x3f89543f,0xdee0001f,0x65780009}},	//   রাম_, yabu_, _ነውን_, rbuh, 
   {{0x6b8438c6,0x7bcc0009,0xad9801e1,0x601406be}},	//   _jejg, _xabu, _olúo, _tümə, 
   {{0xdb1c0086,0x42255440,0x657822d0,0xe9fc004d}},	//   _barù, идов, pbuh, _chần_, 
   {{0x3f895441,0xc1040597,0x7ae803fa,0x244800fe}},	//   wabu_, لوجي, äfti, døme_, 
   {{0x3f895442,0x66195443,0x437400db,0x00000000}},	//   tabu_, miuk, _куйт, --, 
   {{0x661802d5,0x3940005c,0x9f5801e7,0xdb1c01a8}},	//   liuk, _økse_, mhrú_, _varú, 
   {{0x3f895444,0x35d805f9,0x64a00032,0x442401f5}},	//   rabu_, _मोड़, _таҙа, mnl_, 
   {{0x7bcd5445,0x3f880451,0x66180006,0x4eb800cc}},	//   _sabu, sabu_, niuk, ুমূল, 
   {{0x6b84003d,0xdb1c05ac,0x7fb400c0,0x00000000}},	// [22600] _bejg, _harø, _кёні, --, 
   {{0x9f4c22ec,0x7bcd5446,0x3f895447,0x66180821}},	//   ódó_, _qabu, qabu_, hiuk, 
   {{0x66195448,0x7bcd5449,0x4424002f,0x00000000}},	//   kiuk, _vabu, inl_, --, 
   {{0x7bcc7b1e,0xdb1d172f,0x78a00122,0x66180083}},	//   _wabu, _marø, tuov, jiuk, 
   {{0x6619544a,0x6fc80073,0x58d400ee,0x61e0007c}},	//   diuk, ायचं, солт, ömly, 
   {{0x7bcc0481,0xccf400d1,0x44240175,0xe3a42a9f}},	//   _uabu, _уқу_, jnl_, _ظر_, 
   {{0xddc400da,0x66180194,0xe7d000cf,0x00000000}},	//   rmiņ, fiuk, تۅلگ, --, 
   {{0x8880066d,0x2b440790,0xab243de2,0x6619544b}},	//   _کیون, ünce_, _тоса_, giuk, 
   {{0xdb1c03cd,0x34254c90,0x78a0003a,0xa56001d5}},	//   _aarø, ифов, quov, زگنن, 
   {{0xe9fc01dc,0xf365544c,0x00000000,0x00000000}},	//   _phần_, штин, --, --, 
   {{0x32641677,0x53348c6d,0x00000000,0x00000000}},	//   јтов, сент, --, --, 
   {{0x9f580597,0xd5b03d93,0x66180024,0xa18404b3}},	//   bhrú_, _رفت_, ciuk, жырл, 
   {{0x3dd00042,0x9f580332,0xa50400f3,0x00000000}},	//   ddyw_, chrú_, _кеца_, --, 
   {{0xe9fc07ae,0xad9800d2,0xb6200131,0x32645740}},	//   _thần_, _elúl, _ﻧﻰ_, _ктив, 
   {{0x3a24257d,0x3dd400d1,0x00000000,0x00000000}},	//   knop_, ﻟﻠﯩﻘ, --, --, 
   {{0x683c002d,0xe9fc004d,0xe1f0009f,0x00000000}},	//   rêdi, _khấn_, _يسي_, --, 
   {{0x6b8402d3,0x8f5400f2,0xde5800d4,0x00000000}},	// [22610] _pejg, _گندش, раті_, --, 
   {{0x81cc00bd,0x2d700882,0x66180024,0x00000000}},	//   রাণ_, ṇe_, ziuk, --, 
   {{0x6d8802d3,0xf09c00cf,0x6b84005c,0x63b4007c}},	//   _ንጎይታ_, lrà_, _vejg, _öxne, 
   {{0xa2d43711,0x00000000,0x00000000,0x00000000}},	//   यित्, --, --, --, 
   {{0xe9fc0016,0x49100034,0x6b85544d,0x6ce50086}},	//   _nhấn_, _देखो_, _tejg, _тіне, 
   {{0x0c040050,0xf09ccb2a,0x4c053016,0x00000000}},	//   _اوسُ, irà_, _اِسل, --, 
   {{0xdee00020,0x6619544e,0xfec8008f,0x81cc0011}},	//   _ነውና_, tiuk, ָמפּ, রাত_, 
   {{0xc485544f,0x9f5800c6,0xad980248,0xc6a4035b}},	//   блик, thrú_, _olúm, арҩи, 
   {{0xe9fc001e,0x66195450,0x442401f5,0x88d4002b}},	//   _chấn_, riuk, tnl_, _kṛmi, 
   {{0xf09d5451,0x6a700135,0x840436ca,0x66195452}},	//   drà_, _eħfe, спож, siuk, 
   {{0xd7f91e3c,0xf09c8295,0x7c2020ef,0x442401e0}},	//   _тут_, erà_, éori, rnl_, 
   {{0xe1f802f4,0xf09c29b1,0x2280002d,0x44255453}},	//   рҳи_, frà_, rűk_, snl_, 
   {{0xf09d5454,0xad9800ae,0x442401f5,0x312000d4}},	//   grà_, _clúm, pnl_, здяг, 
   {{0x43840597,0x249d5455,0x81cc00bd,0xb058002f}},	//   _الثق, mrum_, রাধ_, nwäh, 
   {{0xf09d5456,0x249c38aa,0x09cc0154,0xa2440137}},	//   arà_, lrum_, _রচনা, _ورعۇ, 
   {{0x249d5457,0xf09d5458,0xeb940588,0xf1bc03b2}},	//   orum_, brà_, ҩит_, pnáa_, 
   {{0x61e55459,0x249d545a,0xf09c19f5,0xe29408b0}},	// [22620] _inil, nrum_, crà_, _сақ_, 
   {{0xf1bc0597,0x61e40306,0xed5476b8,0xed4c05af}},	//   nnán_, _hnil, соу_, رپل_, 
   {{0x249d545b,0x61e5545c,0xfe40c45e,0x9e9403e6}},	//   hrum_, _knil, _فکری, _باخچ, 
   {{0x249c0579,0xf1bc00ae,0x255c00b8,0xdce40210}},	//   krum_, hnán_, _kālī_, ecią, 
   {{0x249d545d,0x61e4002e,0x3e6c03b2,0x7f500150}},	//   jrum_, _mnil, _hýt_, _ﺠﻌل_, 
   {{0x2bb4012c,0x3a240158,0x255c00b8,0xaa480eff}},	//   _věcí_, snop_, _mālī_, _ەسكە_, 
   {{0x61e5545e,0x249c003a,0x3b080798,0xf1bc01ef}},	//   _onil, erum_, _сево_, dnán_, 
   {{0x61e44d11,0xe9fc001e,0xa7a40124,0x3e6c013a}},	//   _nnil, _phấn_, акәа_, _mýt_, 
   {{0xb905545f,0x249d5460,0x32ec00ac,0xd910c5f2}},	//   _узак, grum_, məyi_, _تیش_, 
   {{0xf09d5461,0x32ec0213,0xe8f53ec4,0x366801d5}},	//   vrà_, ləyi_, _улу_, _бажо_, 
   {{0x249c0483,0x7afc002d,0x3e6d1e50,0x66e00107}},	//   arum_, nypt, _nýt_, _нофа, 
   {{0xf09d5462,0x249c1730,0xad98002d,0x80a800cc}},	//   trà_, brum_, _plúm, _চৈধ্, 
   {{0x249c1730,0x41a95463,0x61e40076,0x3e6c010b}},	//   crum_, _कारस, _dnil, _aýt_, 
   {{0xf09cc5ec,0x3e6c038e,0x61e400a9,0xb27001af}},	//   rrà_, _být_, _enil, _еккә, 
   {{0xb8f8031c,0x7afc0240,0x00000000,0x00000000}},	//   _འན_, jypt, --, --, 
   {{0xf09d5464,0x5eb40b30,0x61e40427,0x7afc017a}},	//   prà_, яйст, _gnil, dypt, 
   {{0xb0580221,0x3e6c00a2,0x0bf40108,0x32ec06be}},	// [22630] hwäi, _eýt_, опаю, dəyi_, 
   {{0x4fc00131,0x8b8400cf,0x00000000,0x00000000}},	//   _تەسە, تەسە_, --, --, 
   {{0x7afd5465,0x998c01a6,0xa7200154,0xeb48f3f0}},	//   gypt, _šoša_, _ফর্ম_, учак_, 
   {{0x249d45fc,0xdb1c0008,0xe818012d,0x2bc4a88c}},	//   yrum_, _farþ, भोना_, रजहा, 
   {{0x38c92b47,0xb0595466,0x249d5467,0x100c13e0}},	//   لاوی_, dväz, xrum_, _हताश_, 
   {{0x86995468,0x249cd559,0x6d643361,0xb0580036}},	//   атит_, vrum_, şsağ, fwäi, 
   {{0x2d88601a,0x255c0421,0x41a95469,0x59d40254}},	//   _kece_, _mālū_, _कालस, _ठोकर, 
   {{0x249d546a,0xb0580730,0x32ec00ac,0xdb1c0124}},	//   trum_, swäh, cəyi_, _jarý, 
   {{0x2d8803f9,0x66804d2f,0x61e4022e,0x249cef15}},	//   _mece_, _کیبل, _rnil, urum_, 
   {{0x61e460e2,0x249d546b,0xb880001f,0x2d880e04}},	//   _snil, rrum_, _ይሰጣል_, _lece_, 
   {{0xf1bc5207,0x61e40223,0x2d880561,0x81cc015b}},	//   rnán_, _pnil, _oece_, রাস_, 
   {{0x2d8808ad,0xd175546c,0x249cef15,0xb110063f}},	//   _nece_, зыры, prum_, pụla, 
   {{0x3e6c03b2,0x13a40133,0xf1bc01d3,0x00000000}},	//   _sýt_, _کۆپی_, mnál_, --, 
   {{0xee3c01f1,0xf1bc01d3,0x255c002b,0x00000000}},	//   _aký_, lnál_, _vālī_, --, 
   {{0xdb1c0209,0x8234004b,0xad9802d2,0xb05801f4}},	//   _barý, _وربا, _glúk, nväy, 
   {{0x2d89546d,0xf1bc01d3,0x81cc0154,0x88d4002b}},	//   _cece_, nnál_, রাহ_, _vṛji, 
   {{0x2d89546e,0xee340826,0x2240003e,0xdb1c010e}},	// [22640] _dece_, іну_, _ikik_, _darý, 
   {{0x224005c7,0x41a81d8a,0x7afd546f,0xb05800d7}},	//   _hkik_, _काँस, typt, zväz, 
   {{0x2d88f2de,0xf1bc01ed,0x32ec0213,0x38b003cb}},	//   _fece_, knál_, təyi_, wâr_, 
   {{0x2d884953,0xdb1c010e,0x7afd3cc4,0x38b0015d}},	//   _gece_, _garý, rypt, târ_, 
   {{0xf1bc01d3,0x7afc02f0,0x00000000,0x00000000}},	//   dnál_, sypt, --, --, 
   {{0x2d88084c,0x7ae80267,0xb0580036,0xdb1c010e}},	//   _zece_, äfts, twäi, _zarý, 
   {{0xdb1d5470,0x22402045,0xab255471,0x41a81fad}},	//   _mbrë, _okik_, _дора_, _कांस, 
   {{0xf1bc25fd,0x4a740276,0xb0580036,0x93bc054e}},	//   gnál_, _хырт, rwäi, rnăm, 
   {{0x79815472,0xe9fc004d,0xad9803b2,0xd8840214}},	//   mbow, _nhẹn_, _slúk, _رهای, 
   {{0x224000dd,0x78a1393a,0x798074ae,0x34481fbe}},	//   _akik_, mrov, lbow, јчин_, 
   {{0xa2d40882,0x28115473,0xb05801e3,0x00000000}},	//   यिष्, _تولس, mväx, --, 
   {{0x601004f3,0xdb1c0a40,0x78a00122,0x3f9803b9}},	//   _jämf, _abrë, orov, _adpu_, 
   {{0x2d895474,0x22400194,0x398001a9,0xd4080451}},	//   _rece_, _dkik_, _mаs_, _هڪدم_, 
   {{0xb4d40cb3,0x2d88f086,0x78a15475,0xee3c08ce}},	//   ाटी_, _sece_, irov, _ský_, 
   {{0x78a15476,0x2d895477,0xdb1d5478,0xed88026a}},	//   hrov, _pece_, _maró, исак_, 
   {{0xdb1c0639,0x91a4000d,0x00000000,0x00000000}},	//   _darü, _काटै, --, --, 
   {{0x2d8805a1,0x78a11872,0xc0c00075,0x88d4002b}},	// [22650] _vece_, jrov, _пәри, _gṛhi, 
   {{0xdb1d5479,0x9f582242,0x2d880066,0x2fc4004d}},	//   _naró, skrá_, _wece_, _úng_, 
   {{0x81cc00bd,0x78a00124,0x3ce401e4,0xb05801e3}},	//   রার_, erov, ĥova_, dväx, 
   {{0xdb1d547a,0x78a00306,0x2658002b,0x3ce402f0}},	//   _mbrè, frov, _kṛśā, ťova_, 
   {{0x78a00232,0x00000000,0x00000000,0x00000000}},	//   grov, --, --, --, 
   {{0xdb1c1709,0x6d4c0407,0x46f400a7,0xf1bc26f6}},	//   _caró, _izca, зчит, dnám_, 
   {{0x78a00170,0x1ab5547b,0x79800083,0xf1bc01d3}},	//   arov, _обря, bbow, tnál_, 
   {{0xc48411ac,0xdce40034,0x2600005a,0xad9801e7}},	//   плик, ecię, _iñok_, _blúi, 
   {{0xdb1d547c,0xf1bd547d,0xad9800ae,0x48141a71}},	//   _abrè, rnál_, _clúi, _емас, 
   {{0x2240f5ca,0xf1bc01ed,0xb68401ed,0xad9800ae}},	//   _skik_, snál_, _کھول_, _dlúi, 
   {{0xb11001f2,0x362401d9,0xf1bc00e5,0x00000000}},	//   bụka, _کونہ, pnál_, --, 
   {{0xdb1c0034,0x2704002e,0xad9813db,0x6d4d547e}},	//   _zaró, _lёnk_, _flúi, _ozca, 
   {{0xdb1c067c,0xad9800c6,0x81cc0154,0xded80b82}},	//   _ebrè, _glúi, রাল_, ቭዥን_, 
   {{0xdb1d547f,0x2658002b,0x944000c7,0x00000000}},	//   _parü, _dṛśā, _иҭыж, --, 
   {{0x6d4ce709,0x6e2c003e,0x7980033f,0xed540107}},	//   _azca, _bjcb, ybow, ҷот_, 
   {{0xe9fc004d,0x00000000,0x00000000,0x00000000}},	//   _thẹn_, --, --, --, 
   {{0x7a4000d2,0xed555480,0x21680116,0x3f9801d5}},	// [22660] _lítî, зот_, _лиқи_, _tdpu_, 
   {{0x60c55481,0xad980cad,0x50240150,0x00000000}},	//   _ipim, _olúw, _озығ, --, 
   {{0xf1bc0122,0xd9100f01,0xb058007c,0x00000000}},	//   znám_, چیز_, vväx, --, 
   {{0xeb301a59,0xdb1d5482,0xd910438b,0x6ab807f5}},	//   رىند, _barò, نیز_, _ćuft, 
   {{0xdb1c01f6,0x7e64009a,0x60100724,0xdce40034}},	//   _paró, _iikp, _cämg, ycię, 
   {{0x60c55483,0x660800c5,0x9f5800b5,0xf1bc6fa2}},	//   _mpim, _algk, rkræ_, vnám_, 
   {{0x7e655484,0xdb1c2b76,0xb05801e6,0x60c400d8}},	//   _kikp, _varó, rväx, _lpim, 
   {{0x78a15485,0x60c55486,0xdb1c004e,0xf1bc7385}},	//   prov, _opim, _farò, tnám_, 
   {{0xd3700e26,0xdb1c068c,0xb4d4fe2f,0xb05801e6}},	//   نۇش_, _garò, ाटे_, pväx, 
   {{0xf1bc3b7b,0xdb1c4e01,0x660833b8,0x00000000}},	//   rnám_, _abré, _elgk, --, 
   {{0x60c55487,0xad980332,0x60100166,0xdb1c0055}},	//   _apim, _ilúv, _mämd, _karñ, 
   {{0xb0595488,0x7c3c0175,0x7e640113,0x891800f1}},	//   hwät, hopr, _nikp, _اغېز_, 
   {{0x76415489,0x92cc0eac,0xf1bc00e5,0x00000000}},	//   _ikoy, রমে_, lnák_, --, 
   {{0xdb1c00e4,0x644ce5ce,0x7c3c3e24,0x601001e3}},	//   _ebré, ïcit, jopr, _nämd, 
   {{0x7e642af2,0xf1bc28be,0x764004ba,0x63a4012d}},	//   _bikp, nnák_, _kkoy, ójne, 
   {{0x7e6405b1,0x77f81b87,0x316801f4,0x00000000}},	//   _cikp, ्सुक_, _ушко_, --, 
   {{0x1df8023a,0x7e64002b,0x7c3c0210,0x00000000}},	// [22670] четы_, _dikp, fopr, --, 
   {{0x7c3c01e4,0x6010013d,0xdde000bc,0x00000000}},	//   gopr, _cämd, ětše, --, 
   {{0x7641548a,0xf1bc00d7,0x7ae801e3,0x00000000}},	//   _okoy, piád_, äftp, --, 
   {{0x7641548b,0xdb1d548c,0xc8780432,0xddc400a2}},	//   _nkoy, _parò, _arşa_, mmiş, 
   {{0xddc441d5,0xf8b401c0,0x7c3c02f0,0x6d4c3bfb}},	//   lmiş, дөх_, bopr, _uzca, 
   {{0x7640aef1,0x7c3d548d,0x1ca804d3,0xb11001f2}},	//   _akoy, copr, _رێمی_, rụha, 
   {{0xddc44953,0x99640184,0xf4100154,0x00000000}},	//   nmiş, мтәл, িচার_, --, 
   {{0xc4e51b54,0x490400cf,0xd6d80116,0xda780166}},	//   джий, _قوزق, ятч_, _хяр_, 
   {{0x69c9548e,0xdb1c09cc,0xda340b32,0x601002f6}},	//   mege, _harð, _четы, _häme, 
   {{0xfa0808ea,0x7641548f,0x69c86945,0xddc41b0d}},	//   _གཞོན_, _ekoy, lege, kmiş, 
   {{0xdb1c26b8,0x60c55490,0xf1bc011f,0x60100641}},	//   _jarð, _spim, onáh_, _jäme, 
   {{0x69c803bd,0xf1bc0548,0x7af81574,0x6010010e}},	//   nege, nnáh_, _àtte, _mäme, 
   {{0x20040261,0x7c3c2895,0x51550398,0x69c94eff}},	//   êmio_, yopr, етру, iege, 
   {{0x69c95491,0x200cfd99,0x81cc00bd,0x7e64020c}},	//   hege, ódi_, রাই_, _sikp, 
   {{0x69c95492,0x7c3c95b5,0x601000ee,0xfd4801f2}},	//   kege, vopr, _näme, bulọ, 
   {{0x69c95493,0x7c3c02bd,0xfa08031c,0xfce4023b}},	//   jege, wopr, _གཞེན_, мобо, 
   {{0x69c95494,0x7c3d5495,0x60c54133,0x6568067c}},	// [22680] dege, topr, _upim, _mggh, 
   {{0x6440022e,0xf1bc011f,0x8fd40116,0x69c8fb0e}},	//   _jkni, ynák_, _пәсә, eege, 
   {{0x65680268,0x69c81308,0x7e64005f,0x6440022e}},	//   _oggh, fege, _tikp, _mkni, 
   {{0x69c95496,0xb9255497,0xbd455498,0x00000000}},	//   gege, وفاي, _يندي, --, 
   {{0x64409eb3,0x00000000,0x00000000,0x00000000}},	//   _okni, --, --, --, 
   {{0x6568b2cc,0x93bc0311,0xdb1c0252,0x76400174}},	//   _aggh, lnăv, _farð, _skoy, 
   {{0xdb1c2242,0x6b615499,0xeab401c0,0xbb4406ed}},	//   _garð, _акра, _ойр_, _цевк, 
   {{0x64400054,0xb05803fa,0xf1bd5352,0x00000000}},	//   _akni, nwär, rnák_, --, 
   {{0xde50001f,0x64a00261,0x6568010e,0x7d140210}},	//   _በእንግ, вања, _dggh, nzys, 
   {{0x656800b5,0x7e7c0158,0xb059549a,0x6011549b}},	//   _eggh, _otpp, hwär, _lämb, 
   {{0xad9808ce,0x6010013d,0xc7641884,0x00000000}},	//   _klút, _xäme, _كامى, --, 
   {{0x53800201,0x7641549c,0x64402eb1,0x36240014}},	//   _የአዲስ_, _ukoy, _ekni, _کوچہ, 
   {{0x64410065,0xb4b00116,0xb0580112,0x6e3c014f}},	//   _fkni, _рилә, dwär, voqb, 
   {{0x69c9549d,0xddc40259,0x64400036,0x53340353}},	//   zege, tmiş, _gkni, _пелт, 
   {{0x69c9549e,0x6010025a,0xb05848b3,0xad980241}},	//   yege, _bämb, fwär, _olút, 
   {{0xddc42c6f,0x69c80429,0xb0581196,0x6011549f}},	//   rmiş, xege, twäs, _räme, 
   {{0x69c889b3,0xd90554a0,0xde6400a7,0xfcc019b8}},	// [22690] vege, _ئی_, търп, ләрм, 
   {{0x60100793,0x9a7c02d3,0x7e7c00e4,0xab081df2}},	//   _päme, _ብኣካል_, _ftpp, يتاق_, 
   {{0x69c86f2e,0xf1bd54a1,0x6e3c014f,0xb058002f}},	//   tege, ofá_, poqb, bwär, 
   {{0xdb1c2242,0xc8b40276,0x69c83f42,0x6fb800cd}},	//   _varð, ескы, uege, श्रू, 
   {{0x69c954a2,0x7d14068f,0xad9800c6,0xbb340131}},	//   rege, czys, _dlút, ﺗﻨﻰ_, 
   {{0xdce400c8,0x76a806be,0x6010013d,0xf1bc0332}},	//   nciĝ, _həyy, _täme, hfá_, 
   {{0x69c954a3,0x6010006a,0xf740026b,0x76a806be}},	//   pege, _yämb, лешо, _zəyz, 
   {{0xad9954a4,0x23d400af,0x19a80137,0x60100139}},	//   _glút, _भोजद, _отуп_, _xämb, 
   {{0xf1bc007b,0xdce40115,0x48180064,0x00000000}},	//   dfá_, kciĝ, _ежаю_, --, 
   {{0xf4ac00d1,0xb058002f,0x00000000,0x00000000}},	//   _ﻳﻪﺗﻜ, zwär, --, --, 
   {{0xd7740046,0xb7840166,0x00000000,0x00000000}},	//   _شالع, _чәче_, --, --, 
   {{0x7d146b7e,0xf674010f,0xa3c800dc,0xc1a8012d}},	//   yzys, _װײסט_, _लसक_, कलेग, 
   {{0x37000135,0x97c40150,0x25bc0076,0x03a40c54}},	//   _མཎྜལ_, _ستەم, mful_, _зило, 
   {{0x25bd54a5,0x3f9c006a,0xefb8001f,0x34f8011a}},	//   lful_, ûtu_, _ሲታይ_, _מהנד, 
   {{0x76a806be,0x643000db,0xb0580112,0x7e54009b}},	//   _bəyy, _كىچئ, twär, етац, 
   {{0x25bd54a6,0xf1bc0332,0xa3e013e0,0x00000000}},	//   nful_, cfá_, _पोत_, --, 
   {{0x442554a7,0xbc6954a8,0x25bc06df,0xb05954a9}},	// [226a0] oil_, سمان_, iful_, rwär, 
   {{0x7d1414cf,0x442554aa,0x25bd54ab,0xad9954ac}},	//   rzys, nil_, hful_, _slút, 
   {{0xa3b405ba,0xad9954ad,0x93bc0276,0x25bc020c}},	//   _छान_, _clús, mnăt, kful_, 
   {{0x442554ae,0xf99154af,0x6b8000fd,0x13d80f22}},	//   hil_, ابا_, ınga, তায়, 
   {{0x442554b0,0x25bc03cb,0x00000000,0x00000000}},	//   kil_, dful_, --, --, 
   {{0x442554b1,0xed4c0050,0xad98000f,0xe8f401c0}},	//   jil_, _چھے_, _flús, элч_, 
   {{0xa3b00307,0x25bc0356,0xe9fc0051,0x00000000}},	//   टलन_, fful_, _chẳn_, --, 
   {{0xfa08025c,0xe9d436dd,0x76a803b9,0x667000db}},	//   _གཞིན_, _пкс_, _xəyy, ددور, 
   {{0xdb1c0332,0xad9802d2,0x00000000,0x00000000}},	//   _mbrí, _klúr, --, --, 
   {{0x3a240175,0x25bc0051,0x00000000,0x00000000}},	//   liop_, aful_, --, --, 
   {{0xdb1d54b2,0xb05954b3,0xaca00208,0xb6a400db}},	//   _obrí, ltäg, _phịc, _чиел, 
   {{0x442554b4,0x8398001f,0xad98004e,0x91c40d52}},	//   ail_, _መጠየቅ_, _llúr, тәкл, 
   {{0x442554b5,0xf1bc007b,0xb058002f,0x00000000}},	//   bil_, rfá_, ntäg, --, 
   {{0x442554b6,0xdb1c6bdf,0xa3d0036b,0x76a80213}},	//   cil_, _abrí, _бошч, _səyy, 
   {{0x9f34005e,0xdce40115,0x630002f2,0xaca00208}},	//   гері, rciĝ, _موول, _thịc, 
   {{0xe7e405f9,0xdef400ee,0xb05800fd,0x93bc054e}},	//   _टोना_, ыпсы, ktäg, rnău, 
   {{0xd2f800dd,0x9054b9b0,0x3a24f2fe,0xad9803b2}},	// [226b0] _رکھا_, _ивиц, diop_, _slús, 
   {{0xad98032e,0x6ca400d1,0x2bb8007b,0x00000000}},	//   _plús, _ﺷﻪﺧﺴ, ثارة_, --, 
   {{0xd0107f05,0x25bd54b7,0x76a800ac,0x00000000}},	//   _ملک_, yful_, _təyy, --, 
   {{0x25bc63b3,0xb0580139,0x00000000,0x00000000}},	//   xful_, ftäg, --, --, 
   {{0x1cb01e81,0x442554b8,0xfd940bd4,0x6010260b}},	//   _དཀར_, yil_, _בדרך_, _häma, 
   {{0x442554b9,0x25bd54ba,0x60100432,0xf8ac072d}},	//   xil_, wful_, _käma, تکف_, 
   {{0x25bd54bb,0x442554bc,0xb9080cad,0xcb0801c8}},	//   tful_, vil_, _kikọ_, _غيرن_, 
   {{0x442554bd,0xd6a80447,0x7af80de2,0xdce40205}},	//   wil_, ردىم_, _àtta, nciğ, 
   {{0x442554be,0x69d80270,0x25bd522e,0x00000000}},	//   til_, _iaue, rful_, --, 
   {{0x69d80323,0x25bd54bf,0x442554c0,0x3fcc0183}},	//   _haue, sful_, uil_, _ৰক্ষ, 
   {{0x69d954c1,0x442554c2,0x25bc062c,0xe3d000cc}},	//   _kaue, ril_, pful_, ়ালব, 
   {{0x442554c3,0x69d807de,0x412802bf,0x25bc031c}},	//   sil_, _jaue, домо_, qful_, 
   {{0x442554c4,0x69d954c5,0x63c00032,0x839800b7}},	//   pil_, _maue, _балҡ, _መጠይቅ_, 
   {{0x4425536b,0x69d954c6,0x02c554c7,0x00000000}},	//   qil_, _laue, _айко, --, 
   {{0xf1bc24c7,0x7db46156,0x60100166,0xf85000d0}},	//   mián_, ксац, _cäma, úžiť_, 
   {{0xf1bc3a6c,0x6578c3e7,0x244806ea,0xa3b40dba}},	//   lián_, ncuh, dømi_, _छाड_, 
   {{0x8e5400d6,0x3b941b88,0x6b940077,0x93bc0311}},	// [226c0] утрі, вјет, faxg, mnăr, 
   {{0x9e740075,0x81cc015b,0xed5401e0,0xf1bc068c}},	//   _مۇست, রাও_, тоу_, nián_, 
   {{0x69d8103d,0x93bc0311,0xcaf80073,0xcc3400c0}},	//   _baue, onăr, ंहगड_, ухты, 
   {{0x69d954c8,0xb05800fd,0xdb1c00d8,0x02a8012c}},	//   _caue, ttäg, _abrã, _किनभ, 
   {{0x69d954c9,0xa9644623,0x93bc0356,0xe9fc0051}},	//   _daue, вица_, inăr, _chằn_, 
   {{0xad980030,0xdbe001e1,0x569400f7,0x81cc015b}},	//   _hlúp, _kìís, гакт, রাট_, 
   {{0xf1bd54ca,0x69d954cb,0x19c404a9,0xb05948ae}},	//   dián_, _faue, _бәлг, stäg, 
   {{0x69d954cc,0x7bdc282c,0xf1bc00e5,0xca640150}},	//   _gaue, ldpu, nnát_, _бесқ, 
   {{0x2600db58,0x78640006,0xb058005b,0x1cb00327}},	//   _años_, _аказ, ltäe, _དཀས_, 
   {{0xad98004e,0x69d954cd,0x00000000,0x00000000}},	//   _llúp, _zaue, --, --, 
   {{0x7e90013f,0x69d8003e,0xb058005b,0xad990d3f}},	//   bɛpɑ, _yaue, ntäe, _olúp, 
   {{0xe8dc004d,0xf0740131,0xe5a001af,0x00000000}},	//   _uyển_, кимә_, _вици, --, 
   {{0xf1bd4050,0x16d004ce,0xd4c450c0,0x6b94058a}},	//   bián_, _sのｃｍ_, _сөйк, yaxg, 
   {{0x601001b8,0xf1bc0077,0xb4bc13f5,0x7bdc0267}},	//   _päma, cián_, ँझी_, jdpu, 
   {{0x5f9554ce,0x81cc015b,0x260001c4,0x8f3400d8}},	//   рист, রাজ_, _iñor_, уевц, 
   {{0x6ce40220,0xdda800a8,0xf1bc02f0,0x5e840e58}},	//   кізе, ктул_, gnát_, рурз, 
   {{0x69d80053,0x7bdc01f5,0x5c74009d,0x00000000}},	// [226d0] _raue, fdpu, илтт, --, 
   {{0x601154cf,0xd7c401f9,0x00000000,0x00000000}},	//   _täma, ल्मच, --, --, 
   {{0xd1d402d3,0x69d954d0,0xd1300014,0xb4cc00ab}},	//   _ርሑቕ_, _paue, _خمک_, शबु_, 
   {{0xb05954d1,0x601001e6,0xf73001f3,0x00000000}},	//   städ, _jämn, ሬዚደን, --, 
   {{0x69d80421,0x621c008f,0x2448013c,0xf09c007f}},	//   _vaue, וואק, sømi_, zyàn_, 
   {{0x60100628,0xf1bc0005,0x6b940334,0x00000000}},	//   _lämn, xián_, qaxg, --, 
   {{0x69d954d2,0x969554d3,0x1cb00327,0xf1bd54d4}},	//   _taue, арыш, _དཀོ_, vián_, 
   {{0x6010049f,0xb4cc05f9,0x2bb01fbc,0x9b440137}},	//   _nämn, शबू_, ुभवा, _ئنفو, 
   {{0x0444fba5,0x58d404bb,0x81cc0c58,0x0e20001f}},	//   леин, _котт, ৰাম_, _ተገናኝ, 
   {{0x6a700327,0xa8500166,0xd6a800f7,0x00000000}},	//   _aħfi, _тезә, ردۉم_, --, 
   {{0xf1bd54d5,0xb0580598,0xb7d80375,0x00000000}},	//   rián_, ktäb, _רקעי, --, 
   {{0xf1bc068c,0xa3e02980,0x00000000,0x00000000}},	//   sián_, _पोर_, --, --, 
   {{0x93bc0311,0x555401d9,0xdb1c00ae,0x00000000}},	//   rnăr, _پھٹر, _mbrá, --, 
   {{0x932407d6,0xb0580108,0x00000000,0x00000000}},	//   ارین, ytäe, --, --, 
   {{0xc0580efb,0xdb1c0745,0xe630001f,0xa248004b}},	//   дің_, _obrá, _ይህንን, _لیدل_, 
   {{0x1e4c02d3,0x6010007c,0xf1bc0cde,0xc104007b}},	//   _መብጽዓ, _gämn, niál_, _موبي, 
   {{0xee3441bd,0x4094036b,0x39e001e0,0xf1bd54d6}},	// [226e0] унт_, _ёрит, ҙҙағ, rnát_, 
   {{0xb05802f6,0xdb1c0332,0x00000000,0x00000000}},	//   ttäe, _abrá, --, --, 
   {{0x7bdd54d7,0xf730001f,0x60100112,0x00000000}},	//   rdpu, ሬዚዳን, _hämo, --, 
   {{0xe9442580,0xbd440592,0xf1bd5352,0xb0580108}},	//   گرمی, _منجي, lnár_, rtäe, 
   {{0xa3b00574,0xbf100184,0xe3a405d9,0x37a002dd}},	//   टला_, _түңә, _ٿر_, йқағ, 
   {{0xa3e038d2,0x628020b2,0xdb1c013a,0x3154010f}},	//   _पोल_, _otno, _ebrá, ניסן_, 
   {{0x96f80228,0xf64554d8,0xb0580267,0x8ad400ee}},	//   тейт_, лхин, ltäc, _кютц, 
   {{0x1ad401a9,0x00000000,0x00000000,0x00000000}},	//   _йўғр, --, --, --, 
   {{0x27ec038e,0x2018c1e5,0xb3bc031c,0x60100139}},	//   ální_, khri_, _མཁྱུ, _rämn, 
   {{0xd94400d1,0x779043fb,0xd5a401d3,0x88800101}},	//   _беғи, _ایثا, _چلای, _بیون, 
   {{0xfbc433ff,0xe9fc001e,0xdddc09a8,0x20180240}},	//   र्यम, _chặn_, zprš, dhri_, 
   {{0xf1bd54d9,0x00000000,0x00000000,0x00000000}},	//   ciál_, --, --, --, 
   {{0x64a000ee,0x00000000,0x00000000,0x00000000}},	//   _гача, --, --, --, 
   {{0xddd008a4,0x601017da,0xfbc411bc,0x4384030d}},	//   _češk, _dämo, र्मम, _вăрт, 
   {{0x1cb0025c,0x60100139,0xce940395,0xf1bc00d7}},	//   _དཀུ_, _tämn, рабъ, liám_, 
   {{0x7c2001e4,0xf1bc00e5,0x00000000,0x00000000}},	//   ɨori, rnás_, --, --, 
   {{0xb0580724,0xfbc4c853,0xd0d402e8,0xddc40210}},	// [226f0] rtäb, र्भम, _топъ, dliń, 
   {{0x7d00023a,0x60100267,0xb05954da,0x81cc03d4}},	//   äosa, _jäml, stäb, ৰাণ_, 
   {{0xdddc07f5,0xf09d54db,0x49746179,0x6010013d}},	//   sprš, lsà_, алес, _mäml, 
   {{0xdb14010b,0x00000000,0x00000000,0x00000000}},	//   _ýaýl, --, --, --, 
   {{0x02d0102f,0xf09d54dc,0x200c0267,0xa8500139}},	//   _तन्न, nsà_, ödig_, бедә, 
   {{0x601154dd,0xa3e00307,0x57e802dd,0x2d980200}},	//   _näml, _पों_, лдім_, laqe_, 
   {{0xa3b0000d,0x81cc03d4,0x4ac80073,0x00000000}},	//   टलस_, ৰাত_, _रहिव, --, 
   {{0x7ae954de,0xf1bc0030,0xdb1c0306,0xc6040354}},	//   æfte, fiám_, _ubrá, рзий, 
   {{0xf1bc4ec5,0xc7d80801,0xddd0031c,0x845954df}},	//   riál_, _имах_, _ħeżi, крот_, 
   {{0x6d4c04ce,0x2d980117,0x4ac80073,0x03a400ea}},	//   _myca, haqe_, _रहाव, јино, 
   {{0x6d4c0393,0xfbd00302,0x244954e0,0x85b800a8}},	//   _lyca, חתי_, dømt_, _алес_, 
   {{0x9358052f,0x01646582,0x601029ef,0x63a00036}},	//   ырыу_, икно, _pämo, _wdnn, 
   {{0x20184ec2,0xf1bc0030,0xb140efcc,0xe504007b}},	//   thri_, ciám_, жнял, _حباي, 
   {{0x0fd954e1,0x81cc03d4,0x00000000,0x00000000}},	//   льсы_, ৰাধ_, --, --, 
   {{0x249d54e2,0xf09c0109,0x6280000f,0x09cc0183}},	//   lsum_, asà_, _utno, _ৰচনা, 
   {{0x249d54e3,0x201801b9,0x2d98d709,0x409477a4}},	//   osum_, shri_, gaqe_, _крот, 
   {{0x5ba46f78,0x601154e4,0xbca400d1,0x6d4d54e5}},	// [22700] йлағ, _hämm, شماي, _cyca, 
   {{0x601154e6,0x249d398b,0xb05801e3,0x9f4c0210}},	//   _kämm, isum_, rtäc, ólów_, 
   {{0x8d800020,0xf1e82871,0x249c002d,0xb0583bd2}},	//   ያስችል_, _जोड़_, hsum_, stäc, 
   {{0xb058049f,0x2d980481,0x601000ee,0x249c219c}},	//   ptäc, caqe_, _mämm, ksum_, 
   {{0x6010049b,0xf864050b,0x7ae8005c,0xddc40210}},	//   _lämm, авдо, æftb, rliń, 
   {{0xb8cd54e7,0xb8fd12e7,0x249c000f,0x3ad43090}},	//   _कि_, _तन_, dsum_, _پيرز, 
   {{0xfbc40882,0x569410d9,0x6010e263,0x249d398b}},	//   र्णम, щайт, _nämm, esum_, 
   {{0x6aa0002d,0x29b40150,0x6010002f,0xf5e401ec}},	//   ânfe, _ەجەڭ, _säml, рікм, 
   {{0xfbc40882,0xa964e41f,0x69d80073,0xd7f80051}},	//   र्थम, _вита_, _नसती, _chăc_, 
   {{0xf1bc3afd,0xc8b400cf,0x1418007b,0xdce40171}},	//   riám_, _ыссы, ايدة_, daiļ, 
   {{0x91c47ced,0x249c0381,0xf74406ed,0x2d980113}},	//   бәпл, asum_, _тежо, yaqe_, 
   {{0x60102ba9,0x320954e8,0x75441f5a,0xfbc4859c}},	//   _dämm, тхон_, _кнез, र्तम, 
   {{0x60113c88,0xf07404a9,0xdce40171,0x00000000}},	//   _täml, ригә_, gaiļ, --, 
   {{0xf09cdb40,0xf044084c,0x00000000,0x00000000}},	//   rsà_, рэмо, --, --, 
   {{0xf09d54e9,0x6d4c55e3,0x244811c0,0xa3b01b76}},	//   ssà_, _syca, rømt_, टलर_, 
   {{0x1cb00327,0x82c00327,0x6010007c,0x00000000}},	//   _དྀང_, _མྱིའ, _jämj, --, 
   {{0xddc400e2,0x6010013d,0x00000000,0x00000000}},	// [22710] kliņ, _zämm, --, --, 
   {{0xc8780356,0xe0d001f7,0x6d4c00d7,0x00000000}},	//   _urşi_, _آزي_, _vyca, --, 
   {{0x2d980113,0x80dc00cc,0xfbc408df,0x60100139}},	//   paqe_, মমণ্, र्धम, _xämm, 
   {{0x249c148b,0xe9a801f7,0xd7c401f9,0x7cc800ef}},	//   ysum_, ئدان_, ल्सच, fērā, 
   {{0xa3b4375c,0x48e4b6c2,0x59c40150,0x6d4c0113}},	//   _छाल_, солв, تينك, _uyca, 
   {{0x98f400c6,0x7ae8005c,0x249c01b9,0xfbc407b7}},	//   تثما, æftc, vsum_, र्दम, 
   {{0x9a8554ea,0xf1bc00e5,0xddd400a2,0x00000000}},	//   _мутл, giák_, _ýaţa, --, 
   {{0x249d54eb,0x1f38011a,0x00000000,0x00000000}},	//   tsum_, ירור_, --, --, 
   {{0x588431af,0xf4840424,0x249d54ec,0xddc400ef}},	//   _дыха, یایی, usum_, bliņ, 
   {{0x249d54ed,0xf8ac3cb9,0x00000000,0x00000000}},	//   rsum_, _سکه_, --, --, 
   {{0x249d54ee,0xc87800a2,0x81cc03d4,0xc2446d64}},	//   ssum_, _huş_, ৰাস_, йнок, 
   {{0x249c1730,0xc87805d1,0x00000000,0x00000000}},	//   psum_, _kuş_, --, --, 
   {{0x66188b3b,0x212408c2,0x249c0135,0x00000000}},	//   mhuk, àmh_, qsum_, --, 
   {{0x6010023a,0x661954ef,0xc8780790,0x24482b96}},	//   _tämm, lhuk, _muş_, røms_, 
   {{0xf770011a,0x3e3400ae,0x00000000,0x00000000}},	//   לקם_, مفسر, --, --, 
   {{0x661954f0,0xf2d000c8,0x22280014,0x5fc40037}},	//   nhuk, _זעה_, _خٲبی_, _लउकल, 
   {{0x7fd41c26,0xb058348c,0x601001e3,0xc0c00257}},	// [22720] _ліні, stäa, _jämk, ስቶም_, 
   {{0xe7e400af,0x0ba954f1,0xb0589ea5,0x60100139}},	//   _टोला_, لامى_, ltän, _mämk, 
   {{0x6618f3dd,0xd14801d3,0x00000000,0x00000000}},	//   khuk, _مشین_, --, --, 
   {{0xc878fd2a,0xd9b410e0,0xb058c9d9,0xb2b8010f}},	//   _buş_, تەرد, ntän, טמער, 
   {{0x3f9954f2,0x661954f3,0xb05801f4,0x00000000}},	//   _kepu_, dhuk, itän, --, 
   {{0xc87875d4,0xf0900375,0xb058005b,0x3f980200}},	//   _duş_, לנד_, htän, _jepu_, 
   {{0x661818f7,0x3f98004c,0x80d80c70,0xb05954f4}},	//   fhuk, _mepu_, _पैसे, ktän, 
   {{0x3f98221e,0x661851e2,0xf1bc01ed,0xdb14010e}},	//   _lepu_, ghuk, riák_, _ýañl, 
   {{0xa3b00574,0xc878010b,0x00000000,0x00000000}},	//   टलं_, _guş_, --, --, 
   {{0x78a0047e,0x66180270,0x79800034,0x00000000}},	//   msov, ahuk, lcow, --, 
   {{0x66180a68,0x78a154f5,0x51f80845,0xf1bc067c}},	//   bhuk, lsov, анню_, liái_, 
   {{0x661954f6,0xb05801b8,0x78a0110c,0xa18404b3}},	//   chuk, gtän, osov, зырл, 
   {{0x3f980477,0xf1bc067c,0xc6440228,0xc878008e}},	//   _bepu_, niái_, _بئلى, _xuş_, 
   {{0x3f9954f7,0xefd40020,0x96dc012c,0x798001f5}},	//   _cepu_, ርስዎ_, _मनाउ, hcow, 
   {{0xb8d80d46,0x59c8189a,0x3f9954f8,0xdef954f9}},	//   _མའ_, रभार, _depu_, быт_, 
   {{0x9e041586,0xb62800b5,0x4c9401d5,0x00000000}},	//   пчул, _ｔｍ_, жиас, --, 
   {{0xdb24006a,0xde580212,0x5c740798,0x79800210}},	// [22730] _âsêh, саті_, злут, dcow, 
   {{0x78a154fa,0x66180564,0x916c004d,0x2fc40051}},	//   dsov, zhuk, _nổi_, _ùng_, 
   {{0x6a700327,0x78a002fb,0x256c0166,0xe378010f}},	//   _aħfr, esov, _kölü_, ארבר, 
   {{0x78a001f5,0x66180200,0xa2b800df,0x00000000}},	//   fsov, xhuk, רמאט, --, 
   {{0xab8418ac,0x5f7402dd,0xc8780213,0xddd4010e}},	//   _губк, _باۋر, _quş_, _ýaša, 
   {{0x661802c4,0x00000000,0x00000000,0x00000000}},	//   whuk, --, --, --, 
   {{0x661954fb,0xb058049b,0x97c479af,0xdb58014b}},	//   thuk, ytän, ستوم, _гют_, 
   {{0xc48554fc,0x9a8554fd,0xf1bc067c,0xc8781b0d}},	//   олик, _хурл, biái_, _tuş_, 
   {{0xfbc42f2e,0x7c44002d,0xad981f08,0x195809a5}},	//   र्वम, _útrô, _blúz, _гаты_, 
   {{0x661954fe,0x42c8016c,0x78a4005c,0x290c0142}},	//   shuk, агон_, _ækva, myga_, 
   {{0xb058049b,0xd7f954ff,0x290d5500,0x256c0205}},	//   ttän, _khăn_, lyga_, _bölü_, 
   {{0x3f980421,0xb68400dd,0x66195501,0x290c0009}},	//   _sepu_, _بھول_, qhuk, oyga_, 
   {{0x03a4baa7,0x362401d9,0xb0595502,0x3f989154}},	//   _дило, _بونہ, rtän, _pepu_, 
   {{0xb0595503,0x60100209,0x63e00150,0xc4bc00d1}},	//   stän, _kämi, _ريبە, _ﻣﻪﺳﺌ, 
   {{0x3f680697,0x8e7400f7,0xb058b691,0x6010005b}},	//   риво_, зууч, ptän, _jämi, 
   {{0x3f995504,0xd7f801fb,0x78a002fb,0x256c1b0d}},	//   _wepu_, _nhăn_, ysov, _gölü_, 
   {{0x3f995505,0x61e403a2,0xfc283298,0x69ac146c}},	// [22740] _tepu_, _iail, ажак_, ुलनी, 
   {{0xb05802f6,0x60c4031c,0x19580032,0x88c000fe}},	//   ntäl, _iqim, ҙалы_, োটাক, 
   {{0x61e55506,0x60100793,0xfe44329b,0x290c0067}},	//   _kail, _nämi, _мноо, eyga_, 
   {{0x61e55507,0xd7f8001e,0xad980248,0xb05801f4}},	//   _jail, _chăn_, _olúy, htäl, 
   {{0x60c40327,0x78a002fb,0x7980033f,0x20c40108}},	//   _jqim, usov, rcow, nöi_, 
   {{0x61e55508,0x78a15509,0x76a9550a,0xf1bd550b}},	//   _lail, rsov, атив_, riái_, 
   {{0xad980784,0x7bcc0135,0x61e40076,0x01b0009e}},	//   _alúy, _ibbu, _oail, ট্যদ, 
   {{0x60c5550c,0xdb1c0030,0x60100166,0x61e5550d}},	//   _oqim, _obrú, _dämi, _nail, 
   {{0x7aec151c,0x60c4031c,0x80d8033f,0x00000000}},	//   _hrbt, _nqim, _पैले, --, 
   {{0x61e5550e,0xdb1c0120,0x281001ec,0x44e800d7}},	//   _aail, _acré, _قوقس, _dĺ_, 
   {{0x61e43c65,0x60c44cd5,0x6010010b,0x6b780a7c}},	//   _bail, _aqim, _gämi, ירינ, 
   {{0x61e5550f,0xe69069a6,0x72294177,0xe5e401d5}},	//   _cail, _آلند, рцов_, _وزنی, 
   {{0x1fe4045e,0x61e55510,0x660c893b,0x7bcc0083}},	//   মানস, _dail, öcke, _obbu, 
   {{0xcbd403f4,0x61e40363,0x60c000e8,0xa3b4012d}},	//   _হচ্ছ, _eail, àmma, _छाए_, 
   {{0x61e55511,0x60c40869,0xa3e00b03,0xc87803b9}},	//   _fail, _eqim, _पोट_, _msşa_, 
   {{0x61e55512,0x7bcd5513,0xdb1c0332,0x00000000}},	//   _gail, _abbu, _gcré, --, 
   {{0xb058023a,0x02f400db,0x7ae8005c,0x00000000}},	// [22750] ltäm, _وقۇڭ, æftn, --, 
   {{0x61e405f5,0x60d4009f,0x96bc0118,0x00000000}},	//   _zail, _آزيء, ्झाउ, --, 
   {{0x61e55514,0xb05802f6,0x801800f1,0x00000000}},	//   _yail, ntäm, _دريځ_, --, 
   {{0x7bcc0a49,0x98a4a75a,0x60100716,0x290c2b15}},	//   _ebbu, _azmı_, _rämi, tyga_, 
   {{0xb0595515,0x7aec002f,0x6010013d,0x00000000}},	//   ytäl, _erbt, _sämi, --, 
   {{0x2050069c,0xa2a81428,0x290d5516,0xddc40b67}},	//   _ማእሰር, _झिल्, ryga_, kliś, 
   {{0x1cb8025c,0x60100166,0xd7f80208,0xb178007c}},	//   _ཚའོ_, _qämi, _thăn_, tdål, 
   {{0xa3e01025,0xaca00208,0x06bc00cc,0xddc40210}},	//   _पोज_, _chệc, _আনদি, dliś, 
   {{0x6d400730,0xa5040131,0x61e4cd6c,0xddc4012d}},	//   ßnah, زىدە_, _rail, eliś, 
   {{0xd8755517,0x69c95518,0xb4615519,0x61e5551a}},	//   _قالب, lfge, нкыл, _sail, 
   {{0xb058338d,0xded8010c,0x69c801c7,0xddc4012d}},	//   rtäl, ርብን_, ofge, gliś, 
   {{0xb059551b,0x61e40a73,0x601001e3,0x20c40108}},	//   stäl, _qail, _jämv, töi_, 
   {{0xd174b1b1,0x61e5551c,0xf9900375,0xb224032e}},	//   дыры, _vail, ערך_, _snæð, 
   {{0x61e5551d,0xe3b004fb,0x81cc0183,0xb058023a}},	//   _wail, _آرش_, ৰাই_, ltäj, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbc7400c6,0x69c801a4,0x61e4cb6c,0xb058023a}},	//   كهرب, jfge, _uail, ntäj, 
   {{0x22400066,0xee3402bf,0xcfd00eac,0x72180375}},	// [22760] _ijik_, їну_, ায়ন, _לוקח, 
   {{0x69c80b4f,0xb058005b,0x39500210,0x00000000}},	//   efge, htäj, żysk_, --, 
   {{0x69c80112,0x26c40010,0xa3e0000d,0xed4c0014}},	//   ffge, jtno_, _पोछ_, نپہ_, 
   {{0x7e7d551e,0x00000000,0x00000000,0x00000000}},	//   _iupp, --, --, --, 
   {{0xb4c800af,0x051c0154,0x00000000,0x00000000}},	//   _ऊहे_, দপুর_, --, --, 
   {{0xfaa532c6,0xb05802f6,0x7e7d551f,0xddc4033f}},	//   _наго, ytäm, _kupp, yliś, 
   {{0x7c2d5520,0x7e7c016d,0xeb94104e,0x00000000}},	//   _imbr, _jupp, _хис_, --, 
   {{0x7e7c4a41,0xda1000e1,0x00000000,0x00000000}},	//   _mupp, _ावित_, --, --, 
   {{0x26c40066,0xaa40036b,0xd910179e,0x00000000}},	//   atno_, _четл, _جیش_, --, 
   {{0xb0580664,0x2240009a,0x68b401d9,0x2bcc3166}},	//   ttäm, _ajik_, _رُمس_, स्पा, 
   {{0x7e7c0641,0x660c0112,0x00000000,0x00000000}},	//   _nupp, öckc, --, --, 
   {{0x25082580,0xa1941fe2,0xb05802f6,0x7c2c0175}},	//   _گرمی_, наюч, rtäm, _lmbr, 
   {{0xb0595521,0xddc40210,0xf1bc00e5,0x00000000}},	//   stäm, koił, diát_, --, 
   {{0x2240009a,0x7e7c0036,0xaf50151e,0x250800f2}},	//   _ejik_, _bupp, енгә, _درمی_, 
   {{0x7e7d5522,0x741404d3,0xdb1c003a,0xb058005b}},	//   _cupp, _ووڵا, _scrî, ltäk, 
   {{0x7e7d5523,0xd2500f84,0x2bcc4668,0x66e43b36}},	//   _dupp, _جنب_, स्ना, léká, 
   {{0xfcc0053f,0xb05808ae,0xb4c800c5,0xe0d0030f}},	// [22770] кәрм, ntäk, _ऊहो_, _یزی_, 
   {{0x26c55524,0x6f00004e,0xf1bc00d8,0x7e7d5525}},	//   ytno_, _ànco, lgá_, _fupp, 
   {{0x7e7d5526,0xd7f80016,0x3dc0002f,0xb0580108}},	//   _gupp, _chăm_, _fckw_, ytäj, 
   {{0xf1bc1aac,0x7c2d5527,0x69c80e78,0x7ae8004b}},	//   ngá_, _embr, ufge, غونې_, 
   {{0x7e7d5528,0x7c2c01f5,0xf1bc01d3,0x597418bc}},	//   _zupp, _fmbr, liás_, нышу, 
   {{0x7e7d5529,0x9be42080,0xb058007c,0x00000000}},	//   _yupp, _піск, dtäk, --, 
   {{0xb058049b,0x7e7c0de2,0x69c80112,0x66e400e5}},	//   ttäj, _xupp, pfge, déká, 
   {{0x4489087d,0x601004f3,0x26c40f03,0x67200010}},	//   обин_, _hämt, rtno_, rznj, 
   {{0x26c40fb7,0x04880588,0xf2b40f22,0xf1bc0548}},	//   stno_, цәеи_, _জনগণ, dgá_, 
   {{0xc0cc0020,0x601001e6,0xb05802f6,0x7d00023a}},	//   _እነሱ_, _jämt, stäj, äosi, 
   {{0x2bcc3af4,0x569415ed,0xa5040075,0x96f9552a}},	//   स्या, _захт, زىگە_, _нефт_, 
   {{0xf1bd552b,0x7e7d552c,0x60100139,0x60c000e8}},	//   ggá_, _rupp, _lämt, àmmo, 
   {{0x7e7d552d,0xf1bc0548,0x6ea80037,0xe2a401ec}},	//   _supp, nnáy_, _छिउँ, _ﻋﻨﻬﻡ_, 
   {{0x2bcc0882,0x25bd552e,0xe468023a,0xb058005b}},	//   स्मा, lgul_, _ушел_, ntäh, 
   {{0x7e7d552f,0x41c40034,0x6aa0002d,0x25bc00e8}},	//   _qupp, _वापस, ânfl, ogul_, 
   {{0x8e5402dd,0x7c2c03b2,0x7ae801bf,0x660800e5}},	//   етуі, _smbr, æftm, _jogk, 
   {{0xed5403b7,0x7e7c2caa,0xf1bc5955,0xb0580254}},	// [22780] дот_, _wupp, riát_, ktäh, 
   {{0x25bc0205,0x00000000,0x00000000,0x00000000}},	//   hgul_, --, --, --, 
   {{0xb9e400d6,0x7e7c013c,0x6608057b,0x7c2c0393}},	//   діли, _uupp, _oogk, _vmbr, 
   {{0x8b655530,0xd37805ce,0xb0580108,0xd910028e}},	//   رالم, meće_, ytäk, هیز_, 
   {{0xd378597f,0x1cb80135,0xdb1c00e4,0x41c43c71}},	//   leće_, _ཚའི_, _icrí, _वानस, 
   {{0xd7f80016,0x368802bf,0x7c2c0d63,0x25bc002e}},	//   _thăm_, осин_, _umbr, egul_, 
   {{0x6a80bdf4,0xd37817a3,0x66095531,0x7c3c01e3}},	//   _алса, neće_, _bogk, mnpr, 
   {{0x25bc534b,0x973c04b9,0xd5b001ed,0xb0595532}},	//   ggul_, _neće, اہش_, ttäk, 
   {{0x7c3c0c8c,0x60103f64,0x66e4295a,0x953800fb}},	//   onpr, _jäms, téká, язит_, 
   {{0x25bd5533,0xefd41ee0,0x7c3c9f0f,0x201801e4}},	//   agul_, ይትድ_, nnpr, jkri_, 
   {{0xd3783d67,0x7c3c127b,0xb0585d8a,0x281000db}},	//   jeće_, inpr, stäk, _جولس, 
   {{0xd37804b9,0x7c3c0112,0x00000000,0x00000000}},	//   deće_, hnpr, --, --, 
   {{0xdb1c0ffb,0x76415534,0xf1bc0789,0xb0581577}},	//   _scrì, _ijoy, rgá_, ltäi, 
   {{0xf1bd5535,0xdb1d5536,0x7c3c01a4,0x00000000}},	//   tiás_, _acrí, jnpr, --, 
   {{0x66080218,0xb058005b,0x16dc8497,0xe7ec00bc}},	//   _yogk, ntäi, _मनोब, चयता_, 
   {{0x60115537,0xf1bd5538,0x7c3c005a,0x7e640175}},	//   _sämt, riás_, enpr, _chkp, 
   {{0x9cc80a8f,0xb0580108,0xf1bc0561,0xdd8401ec}},	// [22790] дыха_, htäi, siás_, тысп, 
   {{0x2bb800c6,0xf1bc01d3,0x00000000,0x00000000}},	//   تارة_, piás_, --, --, 
   {{0x6e2c020b,0x764000c7,0xd3780e04,0x916c004d}},	//   _tmcb, _ojoy, beće_, _hồi_, 
   {{0xdb1c00c6,0x7c3c62f1,0x06bc0154,0x00000000}},	//   _gcrí, anpr, _আনলি, --, 
   {{0x60100139,0xb6a0010b,0xb05801f4,0xa8a40a5b}},	//   _tämt, ңишл, etäi, фрек, 
   {{0x76415539,0x660802d2,0x07a40022,0x84e400c7}},	//   _ajoy, _sogk, хакн, ҵоиж, 
   {{0x0b1001ec,0x60100139,0xb05816ca,0x00000000}},	//   _حۋاڭ, _kämr, rtäh, --, 
   {{0xb05833eb,0xfcf80092,0x4904005e,0x6010013d}},	//   stäh, _ሊሰጥ_, _كوزق, _yäms, 
   {{0x2bccd034,0x25bd553a,0x03a40276,0xfbc41223}},	//   स्था, rgul_, нипо, र्कम, 
   {{0xd3780989,0x76400117,0xe8700066,0x00000000}},	//   zeće_, _ejoy, _شناگ, --, 
   {{0x973c01a6,0x66085522,0x00000000,0x00000000}},	//   _peće, _togk, --, --, 
   {{0x2bcc0dad,0x7af801d3,0xad98032e,0xfb18011a}},	//   स्ता, _átte, _hnúf, פורמ, 
   {{0x973c0b91,0xd3780552,0xd4082e3e,0x7c3c017a}},	//   _veće, veće_, ستیم_, ynpr, 
   {{0xdb1c0491,0x7ae801bf,0x00000000,0x00000000}},	//   _scrí, æftk, --, --, 
   {{0xd3782220,0xd50c043b,0x601001e6,0x6440014f}},	//   teće_, mɔ́n, _säms, _ijni, 
   {{0x2019553b,0xd50c043b,0x7c3d553c,0x00000000}},	//   skri_, lɔ́n, wnpr, --, 
   {{0xd37805ce,0x0f3c02d3,0xc7a401ed,0x33700022}},	// [227a0] reće_, _የድልየ, _پڑ_, _игәр, 
   {{0x25ac2e6e,0xd50c043b,0x8eb00131,0xb058023a}},	//   _ldgl_, nɔ́n, _ھەقت, ytäi, 
   {{0xc0cc4be7,0x7c3d553d,0xeb95553e,0xe8007f90}},	//   _እነሆ_, rnpr, хих_, लाना_, 
   {{0x3945553f,0x23cc00dc,0x01b00154,0x3a0456a7}},	//   ннег, त्तद, ট্রদ, رکزی_, 
   {{0xd50c0085,0x644019d6,0x6cb00cc8,0x052000fe}},	//   kɔ́n, _ojni, _бөхт, মপুৰ_, 
   {{0xb0580664,0xf6e4084c,0x7d14023a,0xb8655540}},	//   ttäi, ецин, myys, راشو, 
   {{0x7bdd5541,0x7d14023a,0xd7f801d5,0x916c0051}},	//   mepu, lyys, зуқ_, _mối_, 
   {{0x7bdd5542,0x644001e4,0xcfe8015b,0x94d40276}},	//   lepu, _ajni, খায়_, воиц, 
   {{0xdb24025a,0x2bc447d0,0xdb1c0798,0xb0595543}},	//   _âsâh, _लामा, _ucrâ, stäi, 
   {{0xe8d40302,0xb0582c4f,0x09d402f5,0x916c004d}},	//   _אומר_, ltäv, _সোপা, _rồi_, 
   {{0x7bdc017a,0xb5f001ec,0x00000000,0x00000000}},	//   iepu, _бүйі, --, --, 
   {{0x2bc4069f,0x76400921,0x53800020,0xb05802f6}},	//   _लाभा, _ujoy, _ከአዲስ_, ntäv, 
   {{0x7bdd5544,0x1ccc1b4b,0xb4b03786,0x1cac0135}},	//   kepu, ྱངས_, _силә, ྗེས_, 
   {{0xb058049b,0x6010049f,0x7bdc0124,0xe8000034}},	//   htäv, _sämr, jepu, लाया_, 
   {{0xb900025c,0x81cc0183,0xdb1c01e7,0xb058007c}},	//   _ཨག_, ৰাজ_, _mbró, ktäv, 
   {{0x09d42aab,0xddc55545,0xc150063f,0x7d1401f4}},	//   _সোনা, rliş, ọkọr, fyys, 
   {{0xd90416e0,0xe8000316,0xe8dc063f,0xdb1c033f}},	// [227b0] _ای_, लामा_, _kwụa_, _obró, 
   {{0x7bdd5546,0x25850ac3,0x916c0051,0x00000000}},	//   gepu, _kíló_, _gối_, --, 
   {{0xdef804b4,0x00000000,0x00000000,0x00000000}},	//   _зыя_, --, --, --, 
   {{0xad98002d,0xddc4054e,0x50640131,0x601001f4}},	//   _snúf, rmiţ, _ятқа, _hämp, 
   {{0xf1d000dc,0x258401e1,0x7bdc0254,0xb17801e3}},	//   ध्यन, _líló_, bepu, leåb, 
   {{0x7bdc0262,0xe784c4b4,0x601001f4,0xd8b800db}},	//   cepu, худо, _jämp, رپىچ_, 
   {{0x248c01bf,0x291803f0,0xddc45bf7,0x00000000}},	//   _stgm_, šqa_, lmiš, --, 
   {{0x60115547,0xc8b80dba,0xc8f40395,0x00000000}},	//   _lämp, _उटपट, _избъ, --, 
   {{0x200d5548,0xb0580054,0xd50c02ea,0x5a44ede6}},	//   ödik_, qtäw, tɔ́n, _сэра, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfbc41f13,0x916c0208,0xb46000b1,0x00000000}},	//   र्टम, _rối_, ркэл, --, 
   {{0x7ae95549,0x7bdc033f,0xb17801bf,0x00000000}},	//   æfti, zepu, deåb, --, 
   {{0xdb1c05d5,0x31e0009e,0x66193948,0xc6440228}},	//   _sbrü, যাংশ, mkuk, _كئچى, 
   {{0x09d44251,0x3f68a90c,0x644003f0,0x7d14005b}},	//   _সোমা, диго_, _ujni, vyys, 
   {{0x63a00b21,0x60100d11,0xb05802f6,0x4425554a}},	//   _ienn, _dämp, ytäv, mhl_, 
   {{0x6619554b,0x6281554c,0x7bdd554d,0x2bcc8004}},	//   nkuk, _iuno, wepu, स्सा, 
   {{0x6281554e,0x63a1554f,0x973c0960,0x916c004d}},	// [227c0] _huno, _kenn, _meća, _tối_, 
   {{0x63a15550,0x6280006f,0xd3780552,0x973c107d}},	//   _jenn, _kuno, leća_, _leća, 
   {{0xb0580664,0x62815551,0x66195552,0x7bdd5553}},	//   ttäv, _juno, kkuk, repu, 
   {{0x63a15554,0x62815555,0x973c2375,0xe3a49cce}},	//   _lenn, _muno, _neća, _ھر_, 
   {{0xe3a45155,0x62815556,0x7bdd5557,0xb0582c4f}},	//   _پر_, _luno, pepu, rtäv, 
   {{0x63a15558,0xb058049b,0x62800ea0,0x66180083}},	//   _nenn, stäv, _ouno, ekuk, 
   {{0x62815559,0x973c05a1,0x4ab8084c,0xdb1c00a3}},	//   _nuno, _beća, _путя_, _ucrà, 
   {{0xd3781727,0x6619555a,0x63a1555b,0xb0587a45}},	//   jeća_, gkuk, _aenn, ltät, 
   {{0xd3781326,0x6281555c,0x2bcc1788,0x916c004d}},	//   deća_, _auno, स्वा, _mỗi_, 
   {{0x63a1555d,0x6281555e,0x6619555f,0xb0595560}},	//   _cenn, _buno, akuk, ntät, 
   {{0x62815561,0x601000c5,0xa6c4010b,0x53340276}},	//   _cuno, _rämp, _алха_, уент, 
   {{0x62815562,0x63a0208d,0x6010005b,0x916c0208}},	//   _duno, _eenn, _sämp, _nỗi_, 
   {{0x63a15563,0x62800393,0x3dd00142,0x00000000}},	//   _fenn, _euno, dfyw_, --, 
   {{0x63a065d0,0xe44c44c2,0x6280005a,0x44255564}},	//   _genn, _وضو_, _funo, chl_, 
   {{0x62815565,0x3a2403a2,0xe80002a0,0xb920110e}},	//   _guno, khop_, लाता_, _pupọ_, 
   {{0x63a15566,0x63740375,0xdd9000d1,0xf1b4000d}},	//   _zenn, _בגוף_, يۈپ_, _अयिन, 
   {{0x63a15567,0xa13405d9,0xde5802bf,0xb0580112}},	// [227d0] _yenn, _پريش, таті_, ftät, 
   {{0x62815568,0xddc55569,0xb05804ef,0xabb00588}},	//   _yuno, rmiš, ttäu, ражә, 
   {{0xfe6d556a,0x6281556b,0x9be41ac3,0x661803f0}},	//   تگی_, _xuno, шітк, ykuk, 
   {{0x3a240280,0xd04c0198,0xea9c00b8,0xdb685f18}},	//   ghop_, _tsaɓ, _akṣa_, трул_, 
   {{0xb0581196,0x00000000,0x00000000,0x00000000}},	//   stäu, --, --, --, 
   {{0xd3780bb8,0x973cbc04,0xab843546,0x2a6c0077}},	//   zeća_, _seća, _шумк, smgb_, 
   {{0x6619556c,0xded0044e,0x973c0fcf,0xd6a85712}},	//   tkuk, _እተን_, _peća, نديم_, 
   {{0x63a1556d,0x6281556e,0x3a25556f,0x2bcc0882}},	//   _senn, _runo, chop_, स्रा, 
   {{0x6281145c,0x66195570,0x34b00597,0xd3780552}},	//   _suno, rkuk, مميز, veća_, 
   {{0x66195571,0xaca0063f,0xf3e000c7,0xb05801f4}},	//   skuk, _nkọc, бжьо, itäs, 
   {{0xc5d410f5,0x44255572,0xd37817a3,0xb178005c}},	//   _біль, rhl_, teća_, kdås, 
   {{0x63a15573,0xaca0063f,0x62800d81,0xe1f8016c}},	//   _wenn, _akọc, _vuno, тҳи_, 
   {{0x63a15574,0xb058023a,0xa24801ed,0xd37816a3}},	//   _tenn, ytät, ٹیکل_, reća_, 
   {{0x62815575,0x34b0034c,0xd3780960,0x63a000fd}},	//   _tuno, _اموز, seća_, _uenn, 
   {{0xb058363f,0xd3a801c6,0xa30001ec,0x628001f4}},	//   kräf, _бvтэ, _түне, _uuno, 
   {{0xfce55576,0x23cc1d2e,0xa3a80490,0x3f680107}},	//   лобо, त्रद, गणक_, диҳо_, 
   {{0xb0595577,0x823401d5,0xad9802f0,0x00000000}},	// [227e0] ttät, _لرکا, _poúr, --, 
   {{0x30981203,0xefc00020,0x6cd000c6,0xb178007c}},	//   _רשימ, ቻቸው_, إقلا, rdåt, 
   {{0xb0585df7,0x3a24045a,0x3a140479,0x60642d40}},	//   rtät, thop_, льдс, _مۇڭل, 
   {{0xb0595578,0xebe00046,0xdce400e2,0x00000000}},	//   stät, _қосп, obiļ, --, 
   {{0x522c00c8,0xb178007c,0xa9640a5b,0x00000000}},	//   וואַ, ldår, гица_, --, 
   {{0x3a24da3c,0xb05800fd,0xd7f80051,0xb6c4009d}},	//   shop_, ltär, _nhăt_, гсий, 
   {{0x0b587ef9,0x56955579,0x3a244c28,0xb178005c}},	//   _арты_, шайт, phop_, ndår, 
   {{0xb059557a,0xa920013d,0x00000000,0x00000000}},	//   ntär, рдәл, --, --, 
   {{0x3944026a,0x2e3c0139,0x00000000,0x00000000}},	//   _снаг, läfä_, --, --, 
   {{0x250401ed,0x03b40220,0xea9c0055,0x00000000}},	//   ارٹی_, ақшы_, _ukṣa_, --, 
   {{0xb059557b,0xb178005c,0x00000000,0x00000000}},	//   ktär, ydås, --, --, 
   {{0x387c0427,0x6ea401ad,0xb94800c7,0xb05801f4}},	//   _hitr_, टीफु, tỹhá, ytäs, 
   {{0xf1bc9a14,0x41c40d79,0xb058007c,0x00000000}},	//   bhán_, _वारस, dtär, --, 
   {{0xf1bc0491,0xb0580e78,0xddc400a2,0x00000000}},	//   chán_, etär, lniň, --, 
   {{0xb059557c,0x21d001ec,0x00000000,0x00000000}},	//   hräg, _ﻛﯚﺍﺭ, --, --, 
   {{0xb0581611,0xad980419,0x9258010a,0xddc400a2}},	//   ttäs, _snúb, _шайт_, nniň, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [227f0] --, --, --, --, 
   {{0xb05801e6,0xe7bc015b,0xb17801bf,0xeb48004e}},	//   dräg, _ইস্য, sdås, нчек_, 
   {{0xb059557d,0xe8001f13,0x00000000,0x00000000}},	//   stäs, लासा_, --, --, 
   {{0x973c0d0f,0x2bc40490,0x636c01d3,0x31e00154}},	//   _pećn, _लावा, lóné, যাকশ, 
   {{0x38c9557e,0x07a401c6,0x387c007c,0x9df8005b}},	//   ناوی_, аалн, _bitr_, _снят_, 
   {{0x973c009b,0x00000000,0x00000000,0x00000000}},	//   _većn, --, --, --, 
   {{0x76b4010b,0x969401f4,0x00000000,0x00000000}},	//   ңләр_, брыш, --, --, 
   {{0x9b59557f,0x04c8088c,0x06747aa6,0x9b44114f}},	//   _сист_, نوبي_, шуля, _انفو, 
   {{0xf1bc00c6,0xc734001f,0xb4a40022,0x00000000}},	//   thán_, _እንዲህ, акыз_, --, 
   {{0x08400014,0xb058002f,0x44140117,0x00000000}},	//   _گۆڈُ, nräd, рфит, --, 
   {{0x2a7c0ac5,0xb0595580,0xdec00023,0x00000000}},	//   _kiub_, iräd, ትወና_, --, 
   {{0xa300052f,0xe8001431,0x2d84012d,0xb0580139}},	//   _ғүме, लावा_, śnej_, hräd, 
   {{0xb058007c,0x00000000,0x00000000,0x00000000}},	//   kräd, --, --, --, 
   {{0xd138001f,0x00000000,0x00000000,0x00000000}},	//   _አንችል, --, --, --, 
   {{0xb05802f6,0x4374008f,0xbea40a89,0x3ea401d5}},	//   ttär, _דײַן_, рабк, рибг, 
   {{0x644c20ef,0xc104035d,0x09d40154,0x00000000}},	//   écif, _نوبي, _সোসা, --, 
  
   {{0xc0e55581,0xb05826bc,0xefd40023,0xad980332}},	// [22800] _топк, rtär, ይድዎ_, _snúc, 
   {{0xb0595582,0x3b9400d8,0x00000000,0x00000000}},	//   stär, рјат, --, --, 
   {{0x79a55583,0xc878010b,0x69cc03e0,0xf1d000cd}},	//   арле, _urşy_, _ıcer, ध्वन, 
   {{0xb0595584,0xf8a8027d,0x00000000,0x00000000}},	//   träg, ندته_, --, --, 
   {{0xb0580267,0x09d40154,0x387d5585,0xd79402e8}},	//   bräd, _সোহা, _pitr_, билъ, 
   {{0xdb0c006a,0x2810f18a,0x81d802f5,0xeb943460}},	//   _âhïn, يونس, _ডোম_, _вир_, 
   {{0x973c05ce,0x387d5586,0x57a404a9,0xad9802d2}},	//   _većo, _vitr_, ашқа, _hnúa, 
   {{0xb0592341,0xd84801f2,0x6b600212,0x387c0208}},	//   präg, wọd_, _єкта, _witr_, 
   {{0xb0580598,0x387c0165,0x74685348,0xf50800db}},	//   ktäp, _titr_, кров_, ئزبى_, 
   {{0xa92000d0,0x00000000,0x00000000,0x00000000}},	//   úžen, --, --, --, 
   {{0xf1bc011f,0xc7946550,0xb178072b,0xe80003ba}},	//   bhál_, _ырты, geån, लारा_, 
   {{0x11d8007b,0xb1a40818,0x00000000,0x00000000}},	//   دوحة_, шшок, --, --, 
   {{0xc5ec00aa,0xfd5402e3,0xb0580036,0x2bc43166}},	//   _سړي_, robị, hräe, _लाला, 
   {{0x25180a1e,0x00000000,0x00000000,0x00000000}},	//   _בודא, --, --, --, 
   {{0x63640801,0xb0580267,0x81d40154,0xee840006}},	//   _кръг_, vräd, _সফর_, рыго, 
   {{0x30a41e18,0x97380020,0xdd995587,0x9e0400f7}},	//   _кров, _እንድት, ишу_, очул, 
   {{0xb058049f,0x8bd95588,0x5da40014,0x660c002f}},	// [22810] träd, лмас_, زملٕ, öcki, 
   {{0xd3a8009d,0xa06800d8,0x00000000,0x00000000}},	//   _бvхэ, _кања_, --, --, 
   {{0xb0583468,0xd84802e3,0x97380092,0xc87806be}},	//   rräd, kọb_, _እንዴት, _msşt_, 
   {{0x497408e0,0xb058007c,0x00000000,0x00000000}},	//   блес, sräd, --, --, 
   {{0xe8000490,0x7ae800b5,0x00000000,0x00000000}},	//   लाला_, æftr, --, --, 
   {{0xdec0001f,0x6d4c05c7,0xb05802c1,0xd6e000fe}},	//   ትገኝ_, _ixca, bräe, ভিনয, 
   {{0x2a7c2a1f,0x6db8033f,0xfbcc00ec,0x00000000}},	//   _tiub_, ałał, _سڪل_, --, 
   {{0x85e85232,0x656c0f91,0x41c412eb,0x00000000}},	//   удив_, ýcho, _वाइस, --, 
   {{0x638007d6,0x69d800e4,0xf1bc03b2,0x80b406e3}},	//   оҳла, _ibue, rhál_, _अटें, 
   {{0x9b4400f8,0x98155589,0x68f80323,0x9f4c04bf}},	//   _انہو, _وبلا, _irud, ždé_, 
   {{0x68f80122,0x00000000,0x00000000,0x00000000}},	//   _hrud, --, --, --, 
   {{0x68f9558a,0xb40401b9,0x18b00032,0x6d4c035a}},	//   _krud, _қўчқ, _эҙәр, _oxca, 
   {{0x8504c3d2,0x69d9558b,0xf1bc02fb,0xaee00055}},	//   _دوشن, _mbue, chám_, _tdṛd, 
   {{0x3cfc012c,0x6568031c,0x68f801f7,0x6010013d}},	//   _čtv_, _izgh, _mrud, _hämz, 
   {{0x69d84e07,0xb05801b8,0x66f48098,0xed5401e0}},	//   _obue, puän, ंटिक_, ҡос_, 
   {{0x68f9558c,0xb0594366,0x53480354,0x00000000}},	//   _orud, gräb, _тăсă, --, 
   {{0x60100139,0x00000000,0x00000000,0x00000000}},	// [22820] _mämz, --, --, --, 
   {{0x69d9558d,0x3b08e8bb,0xaa400032,0x09d40154}},	//   _abue, лезо_, үефл, _সোলা, 
   {{0x68f9558e,0xad980241,0xf0140375,0x0c784eb1}},	//   _arud, _inún, _הקיץ_, рсты_, 
   {{0x68f9558f,0xb34406ed,0x7af803b2,0x6010008e}},	//   _brud, leçõ, _áttm, _nämz, 
   {{0x656c01f1,0x7e740158,0x68f95590,0xad9802d2}},	//   ýchl, mmyp, _crud, _knún, 
   {{0xe604034c,0xe4455591,0x69d80086,0x7e741f06}},	//   _בش_, _رض_, _ebue, lmyp, 
   {{0x68f95592,0x6db8012d,0xd83800d7,0x00000000}},	//   _erud, słał, _vmč_, --, 
   {{0x54b810e4,0x00000000,0x00000000,0x00000000}},	//   агия_, --, --, --, 
   {{0x9b44021a,0x80a809ab,0x00000000,0x00000000}},	//   _انځو, जीमे, --, --, 
   {{0xb3440798,0x7bcc0175,0xc61800cc,0xdd1c01ef}},	//   jeçõ, _jcbu, তোলা_, _váňo, 
   {{0x2bf40375,0x7bcc0175,0x68f801ef,0x67d001af}},	//   זמין_, _mcbu, _zrud, _хоєу, 
   {{0xad9803b7,0x7c3ccf76,0xb0580267,0x925801c6}},	//   _anún, hipr, kräc, рамт_, 
   {{0x7c3d5593,0xf78800a2,0xdef801e0,0x601001f4}},	//   kipr, _geçý_, ҙыр_, _hämy, 
   {{0x9738001f,0xf07404a9,0x973c01a6,0x00000000}},	//   _እንዳት, сигә_, _nećk, --, 
   {{0x7c3d5594,0x644cff0c,0x643800c8,0xceb80032}},	//   dipr, écie, _געגנ, шәп_, 
   {{0x6d4c004e,0xdda95595,0x7c3c0b4f,0x6010013d}},	//   _pxca, йтул_, eipr, _xämz, 
   {{0x7c3d5596,0x973c8bbb,0x6b843f9f,0xe1f001c8}},	// [22830] fipr, _bećk, مشال, _سسي_, 
   {{0xb3440798,0x7c3c045b,0x68f80023,0x2c6c0205}},	//   ceçõ, gipr, _rrud, küde_, 
   {{0x68f8107d,0x207c008f,0x601000a2,0x7ae8005c}},	//   _srud, _גאזא, _nämy, æftp, 
   {{0xe9a9464b,0x31b55597,0x7c3c017a,0x68f95598}},	//   ادان_, _अयोध, aipr, _prud, 
   {{0x7c3d5599,0xbf180055,0x6010008e,0xbffc03d4}},	//   bipr, _eṣās, _rämz, ুসৰণ_, 
   {{0x7c3d559a,0x5ca41086,0x68f80489,0xb0580254}},	//   cipr, _хиёб, _vrud, kuäm, 
   {{0x69a805d9,0x012c0092,0x00000000,0x00000000}},	//   _ماءُ_, ብርተኝ, --, --, 
   {{0x68f9559b,0xbaa40b01,0xf7300240,0x00000000}},	//   _trud, _фурқ, _ክንዝን, --, 
   {{0x68f9559c,0x290803b9,0xd7f80051,0x00000000}},	//   _urud, _çca_, _thăp_, --, 
   {{0xb46000c7,0xa78001ee,0x00000000,0x00000000}},	//   мкыл, _эҫке, --, --, 
   {{0x27e5559d,0x69c9559e,0xdb1c0597,0x42081d5b}},	//   menn_, ogge, _scrú, анно_, 
   {{0x69c8032b,0x27e407e4,0x7c3d4b89,0xad9809e8}},	//   ngge, lenn_, zipr, _snún, 
   {{0xa565559f,0x26c555a0,0x2124007b,0xb3440798}},	//   _ادان, luno_, ámh_, teçõ, 
   {{0x27e403bd,0x7c3c004e,0x26c40077,0xb0582ad7}},	//   nenn_, xipr, ouno_, quäl, 
   {{0x26c555a1,0x7c3c00dc,0xb3440120,0x27e40156}},	//   nuno_, vipr, reçõ, ienn_, 
   {{0x27e555a2,0xb05955a3,0xa3d40073,0x9f4c09e8}},	//   henn_, träc, ाभव_, _ólík_, 
   {{0x7c3d55a4,0x27e54d92,0x26c555a5,0x22a401ed}},	// [22840] tipr, kenn_, huno_, lők_, 
   {{0x27e407e4,0x26c555a6,0x69c80363,0xebe11f59}},	//   jenn_, kuno_, egge, моуп, 
   {{0x27e407e4,0x7c3d55a7,0xd14955a8,0x682c005c}},	//   denn_, ripr, _نشین_, _kødf, 
   {{0x26c555a9,0x7c3d55aa,0x27e50334,0xb058002f}},	//   duno_, sipr, eenn_, präc, 
   {{0x27e40dd4,0xed545d99,0x00000000,0x00000000}},	//   fenn_, _мою_, --, --, 
   {{0x26c555ab,0x27e40dd4,0x973c01fa,0xfaa49c12}},	//   funo_, genn_, _heći, _маго, 
   {{0x26c555ac,0x628406c8,0x81041098,0x00000000}},	//   guno_, _oiio, शमुख_, --, 
   {{0x22a401ed,0x630c0154,0x66703cc6,0x2c6c9d06}},	//   dők_, ানায়_, ودير, rüde_, 
   {{0x27e555ad,0xa504026a,0xb80804fb,0xf7b80014}},	//   benn_, жења_, _پيام_, _نداش_, 
   {{0xd37808ad,0x26c555ae,0x6aa40218,0xa7a40022}},	//   leći_, buno_, _ywjf, _мкуа_, 
   {{0x26c45909,0x2bcc25fe,0xe81c00dc,0x00000000}},	//   cuno_, स्टा, _भवता_, --, 
   {{0xd37808ad,0xa19412fa,0x6d400205,0x00000000}},	//   neći_, маюч, ğnaz, --, 
   {{0xc5c403bd,0xa1840209,0x682c3c02,0x00000000}},	//   _ཁྐྲི, дырл, _dødf, --, 
   {{0x45700184,0xb600012c,0x1cac0327,0xddc40153}},	//   _яңыр, řádk, ྗེན_, bliū, 
   {{0x69c839c2,0x973c0558,0x6e3c036b,0x628401ab}},	//   ygge, _beći, tiqb, _fiio, 
   {{0x27e555af,0xd378098d,0x4c947ffd,0x3ebd55b0}},	//   zenn_, jeći_, зиас, átta_, 
   {{0xd37804b9,0x27e4662e,0x26c4005a,0x918000cf}},	// [22850] deći_, yenn_, zuno_, _سۇسۇ, 
   {{0x26c555b1,0xad9806ed,0xf09c2b1d,0x6e3c047e}},	//   yuno_, _inúm, mpà_, siqb, 
   {{0x27e555b2,0xce5805f5,0x013c02d3,0xf09d55b3}},	//   venn_, _ганц_, _ኣስተም, lpà_, 
   {{0x26c555b4,0x656c0030,0x682c01bf,0xae0000d1}},	//   vuno_, ýchk, _kødg, _تۈرى, 
   {{0x27e555b5,0x22a400dd,0x26c4090c,0x69c8257c}},	//   tenn_, zők_, wuno_, rgge, 
   {{0x27e403bd,0x26c555b6,0xbff00521,0xf09c04cc}},	//   uenn_, tuno_, _ọṅụ_, ipà_, 
   {{0x27e555b7,0xbaa4472b,0xd3781050,0x26c4107d}},	//   renn_, _нутқ, beći_, uuno_, 
   {{0x27e465f8,0x0608816b,0x26c555b8,0x22a401ed}},	//   senn_, сник_, runo_, vők_, 
   {{0x27e555b9,0x682d55ba,0xd8480521,0xf1bc0124}},	//   penn_, _rødf, mọn_, chái_, 
   {{0x26c4d290,0x22a400dd,0x2bcc07f7,0xd8480521}},	//   puno_, tők_, स्चा, lọn_, 
   {{0x62840093,0xda700050,0x26c4009a,0x00000000}},	//   _piio, _سُے_, quno_, --, 
   {{0xe80003f8,0x6284437d,0x22a401d3,0xf2d000e5}},	//   लाका_, _qiio, rők_, رآپ_, 
   {{0x62840254,0x22a401d3,0xdb0c02d2,0xda040055}},	//   _viio, sők_, _áhön, _śrūṇ, 
   {{0xd3781225,0x249d55bb,0xd84801f2,0xb4f802e4}},	//   zeći_, mpum_, họn_, _לפני, 
   {{0x973c0552,0x442555bc,0xd84801f2,0xad9801e1}},	//   _peći, mkl_, kọn_, _inúj, 
   {{0x41c402ab,0xb2b80375,0x682c03b2,0x7af801a8}},	//   _वाटस, _המקר, _hødd, _átti, 
   {{0x973c04b9,0xd37808ad,0xd84801f2,0x682c003b}},	// [22860] _veći, veći_, dọn_, _kødd, 
   {{0xb058007c,0xb7c400eb,0x00000000,0x00000000}},	//   lrän, _এস্ট, --, --, 
   {{0xd378098d,0x629555bd,0x682c366f,0x0ba800cf}},	//   teći_, _éxod, _mødd, زالى_, 
   {{0x98a086f5,0xddc401a6,0x682c03b2,0xb058002f}},	//   šič_, lmiž, _lødd, nrän, 
   {{0xd3780b91,0x58d47c85,0x39500076,0x00000000}},	//   reći_, фолт, çys_, --, 
   {{0xd37808ad,0xb0582155,0x44245ba2,0x682c037e}},	//   seći_, hrän, jkl_, _nødd, 
   {{0x1ccc0dd4,0xb05955be,0x44240ac5,0xd37807f5}},	//   ྱངམ_, krän, dkl_, peći_, 
   {{0xf7700d62,0xfaa4136b,0x2c6c04cc,0xf1bc0332}},	//   واں_, _маҳо, müda_, phái_, 
   {{0xe60c594c,0x2c6c014a,0xb0581196,0x682c2b96}},	//   اشى_, lüda_, drän, _bødd, 
   {{0x6ecc0605,0x682c0ac7,0x3a2509cf,0xb9f80b82}},	//   _wɔbɛ, _rødg, lkop_, _ሙሳ_, 
   {{0xe7b155bf,0x644c2047,0x682c0158,0x249c003a}},	//   _سمند, écia, _dødd, apum_, 
   {{0xb05804f3,0x3a240549,0x75d401ec,0x4424005a}},	//   grän, nkop_, _ءيشا, akl_, 
   {{0x682d55c0,0x2bac068f,0x3a2405e4,0x2c6c07c5}},	//   _fødd, टरमा, ikop_, hüda_, 
   {{0xf09cb269,0x682c03b2,0x44240112,0x60c001d3}},	//   rpà_, _gødd, ckl_, ámma, 
   {{0xb0594bba,0xbd98063f,0xf09c1186,0xd848063f}},	//   brän, _ọpụt, spà_, yọn_, 
   {{0xdef402d3,0xf09d54dc,0x290c022e,0x00000000}},	//   _ልኡኽ_, ppà_, yxga_, --, 
   {{0x5d54e772,0x905400f3,0x8c24009a,0x00000000}},	// [22870] ектт, _овиц, وفره, --, 
   {{0x682c037e,0x2c6c29ef,0xad9803b2,0x9bf40131}},	//   _køde, füda_, _knúk, нзуч, 
   {{0x682c08d7,0x3a24017a,0x2bac0118,0x53d407b7}},	//   _jøde, fkop_, टरबा, _दानश, 
   {{0x682c019b,0x3a24113c,0x44240472,0xf1bc04e4}},	//   _møde, gkop_, zkl_, ्लिन, 
   {{0xd37805a1,0xf8ad2689,0x682c05ac,0xd848063f}},	//   meću_, لکل_, _løde, rọn_, 
   {{0x3a2403a2,0xd3780960,0x290c022e,0x2bc40073}},	//   akop_, leću_, rxga_, _लाटा, 
   {{0x682d55c1,0x2d9c00c5,0xf1bc3af4,0xfad40107}},	//   _rødd, _õues_, ्लान, _обрӯ, 
   {{0xe0e402f5,0xd37800f3,0x00000000,0x00000000}},	//   মিতভ, neću_, --, --, 
   {{0xa5040075,0x7bc955c2,0x03a400d8,0x442555c3}},	//   سىدە_, ófug, мипо, tkl_, 
   {{0x0325012c,0x682c037e,0x82b8025c,0xc3240395}},	//   ддон, _bøde, _དྷུའ, дмок, 
   {{0x4424aa86,0xb05955c4,0x28740022,0x682c0174}},	//   rkl_, trän, _дыҧр, _vødd, 
   {{0x442555c5,0xd37839ca,0x682c4c2e,0x672003a2}},	//   skl_, jeću_, _døde, mynj, 
   {{0xd3781591,0xb058ee1f,0x442555c6,0xb6000118}},	//   deću_, rrän, pkl_, řáck, 
   {{0x682c4c2e,0xb0583400,0xb178007c,0x764c032e}},	//   _føde, srän, dfåd, _íbyr, 
   {{0x682c005c,0x25ac03b2,0xb05833b4,0x42540f06}},	//   _kødb, _kegl_, ntäy, _отит, 
   {{0x2c6c07c5,0x0204c45c,0xf1bc1bbf,0x00000000}},	//   vüda_, _цзин, lkán_, --, 
   {{0x22400eda,0x25ac04cc,0x614400db,0xb05801f4}},	// [22880] _imik_, _megl_, _سىدە, htäy, 
   {{0xf1bcc00f,0x93bc0311,0xfaa401d5,0x81d40154}},	//   nkán_, lhăr, дажо, _সফট_, 
   {{0x672003a2,0x248402bd,0x3a240b4f,0xfeb8028e}},	//   jynj, _minm_, tkop_, _باخت_, 
   {{0x2c6c05d5,0x25acc300,0x682c0450,0x3a24017a}},	//   rüda_, _negl_, _nødb, ukop_, 
   {{0x2bc439a1,0x3a2555c7,0x22400194,0x2c6c0793}},	//   _लाचा, rkop_, _mmik_, süda_, 
   {{0x37040d1d,0xb178007c,0x00000000,0x00000000}},	//   дчив, sfåg, --, --, 
   {{0x7c2c011c,0x25ac07c5,0x224029ef,0x3a2555c8}},	//   _ilbr, _begl_, _omik_, pkop_, 
   {{0x248450c2,0x682c2142,0x7bdc0af9,0xca740150}},	//   _ainm_, _røde, lfpu, _كەلت_, 
   {{0x25ac011c,0x682c21e3,0xb21801bf,0xb058007c}},	//   _degl_, _søde, lmæg, fräl, 
   {{0xd3780552,0x224155c9,0xdb1c0200,0xb058007c}},	//   zeću_, _amik_, _ndrë, gräl, 
   {{0x25ac0c86,0x78a155ca,0x3668010a,0xf748007b}},	//   _fegl_, lpov, _дажо_, _بلاي_, 
   {{0xd2505312,0x7af80008,0x273007d2,0x78a0010a}},	//   انح_, _áttu, _جىمس, opov, 
   {{0xd84802e3,0xe8000490,0xd37807f5,0x7c2d55cb}},	//   họm_, लाचा_, veću_, _olbr, 
   {{0xd5e806d6,0x656c0730,0xd84801f2,0x240401f0}},	//   _muḓ, üche, kọm_, _ончи_, 
   {{0xd7f80165,0x2d8808c2,0xd37800f3,0xb05800e4}},	//   _maă_, _pgce_, teću_, kuäv, 
   {{0x82b80135,0xddc4033f,0xad9808a5,0xd1d40023}},	//   _དྷིའ, enił, _knúi, ክሕቲ_, 
   {{0x78a056af,0xd37808ad,0x7bdd55cc,0x3f98017a}},	// [22890] jpov, reću_, ffpu, _ffpu_, 
   {{0x78a003c6,0x9f4c0232,0x6f000077,0xb0580108}},	//   dpov, ždá_, _ánco, ytäy, 
   {{0x44280165,0x09d80327,0xc61800cc,0x00000000}},	//   _ɓa_, _འཁྱ_, তোটা_, --, 
   {{0xd5e81682,0xdb1c6bdf,0x8c4805d1,0x506401d5}},	//   _buḓ, _acró, _başö, _ютқа, 
   {{0x682c11aa,0x78a00115,0x25ad55cd,0x6ab40175}},	//   _rødb, gpov, _regl_, ssxf, 
   {{0x25ad55ce,0xd848063f,0x46f402bf,0xb058c6cb}},	//   _segl_, bọm_, ечит, ttäy, 
   {{0x25ac04cc,0x973c0023,0x78a00022,0x66f006be}},	//   _pegl_, _ክንወስ, apov, _kəkə, 
   {{0x248c05b1,0x0ae800aa,0x09d8031c,0x00000000}},	//   _pugm_, _ورځي_, _འཁྲ_, --, 
   {{0xc4843085,0xdb1c0699,0x25ac1570,0xf990008f}},	//   нлик, _adrè, _vegl_, _תרמ_, 
   {{0x672003a2,0xe70955cf,0x25ac04e6,0xb0580267}},	//   pynj, _وتان_, _wegl_, främ, 
   {{0xa5040075,0xb05801b8,0x25ac08cb,0xdb080158}},	//   سىگە_, gräm, _tegl_, øløs, 
   {{0x25ac04cc,0x00000000,0x00000000,0x00000000}},	//   _uegl_, --, --, --, 
   {{0x660813e1,0x2bfc00e1,0xad9801e7,0x066400db}},	//   _ingk, ईयां_, _gnúi, _قاچپ, 
   {{0x26c406bb,0x95cc03be,0x00000000,0x00000000}},	//   orno_, _çərç, --, --, 
   {{0x88e400fe,0x4374008f,0x78a01d33,0x3fe000e5}},	//   ফটিক, _אײַן_, zpov, نےکے, 
   {{0x9f5955d0,0x224024e7,0xe7dc0b02,0x66f006be}},	//   ndré_, _umik_, प्तप, _cəkə, 
   {{0x61e555d1,0x66083223,0xed5555d2,0xfc28010b}},	// [228a0] _ibil, _mngk, еот_, пжак_, 
   {{0x6608003e,0x9eb40352,0x00000000,0x00000000}},	//   _lngk, _ишмә, --, --, 
   {{0x660955d3,0x61e40280,0xdb1c381a,0x8b640131}},	//   _ongk, _kbil, _acrò, پالم, 
   {{0x6608020c,0xcee82304,0x78a094b3,0xb21801bf}},	//   _nngk, _کرین_, tpov, rmæg, 
   {{0x61e555d4,0x26c555d5,0x7e640327,0xb21800b5}},	//   _mbil, erno_, _ikkp, smæg, 
   {{0x66091a3b,0xb0580598,0xd5e80943,0x7c2d55d6}},	//   _angk, yräm, _vuḓ, _ulbr, 
   {{0x78a01225,0xad9801a8,0x67b400ae,0x00000000}},	//   spov, _snúi, راوح_, --, 
   {{0x78a155d7,0x3dd00369,0xdb1c01e7,0x00000000}},	//   ppov, ngyw_, _ndré, --, 
   {{0x54552b64,0x37e40798,0xa7600166,0x00000000}},	//   квит, _поаг, ккәд, --, 
   {{0x66083aad,0xdb1d55d8,0x26c4b820,0x00000000}},	//   _engk, _adré, brno_, --, 
   {{0x6fd4007d,0x61e4025c,0x26c40841,0x92584d01}},	//   _बाबू, _bbil, crno_, дант_, 
   {{0x61e4009a,0xb0580958,0x00000000,0x00000000}},	//   _cbil, rräm, --, --, 
   {{0x64a0a31e,0x61e46eb6,0x764155d9,0x66f003e3}},	//   _бача, _dbil, _imoy, _rəkə, 
   {{0x61e48e9b,0xb0583b52,0xceb80bd6,0xf1bc02f0}},	//   _ebil, präm, мәм_, mkám_, 
   {{0x53340e76,0x682d43ae,0x2bac2cce,0x042c02d3}},	//   _шект, _jøda, टरसा, _ብሪጣን, 
   {{0x61e40248,0x4fc00116,0x00000000,0x00000000}},	//   _gbil, _ھەزە, --, --, 
   {{0x7640090c,0xf1bc03f7,0xfff423cf,0xb058055e}},	// [228b0] _mmoy, nkám_, رکیت_, nräk, 
   {{0x61e555da,0xf1bc0030,0xbb500150,0xdd8401ec}},	//   _zbil, chár_, _ﺎﺌﻲ_, уысп, 
   {{0x76400944,0x8f340276,0x2c6c0793,0x66f00213}},	//   _omoy, _ренц, südo_, _təkə, 
   {{0xaca0063f,0x6a6401b9,0x62480205,0xb059489e}},	//   _amục, رطال, lıor, kräk, 
   {{0xfd6402e3,0x99d555db,0x26c4058a,0xdb5001d9}},	//   _mkpị, اتما, wrno_, لَے_, 
   {{0x764155dc,0x682c0158,0xb0580267,0x69d00073}},	//   _amoy, _bøda, dräk, _डावी, 
   {{0x644c004a,0x57a40024,0x26c40009,0x996401e0}},	//   écim, ушча, urno_, ктәл, 
   {{0x59d802ab,0x26c40200,0xf1bc00d7,0xe9dc0241}},	//   _डायर, rrno_, fkám_, _ùú_, 
   {{0xc7f40114,0x7af808a5,0x62480205,0xdb200241}},	//   _изаћ, _áttr, kıor, _ìwòr, 
   {{0x61e45bd9,0x682c0158,0x26c40427,0xfcc00092}},	//   _sbil, _føda, prno_, ስረጃ_, 
   {{0x6fdc06ab,0xe6c4157c,0x61e4003a,0x00000000}},	//   _पॉइं, _ستاي, _pbil, --, 
   {{0x6608f1af,0x61e40327,0x78740022,0xb0580166}},	//   _ungk, _qbil, râve, bräk, 
   {{0xf1bc0332,0x95c80395,0x00000000,0x00000000}},	//   thár_, _чуха_, --, --, 
   {{0xadc00248,0xf5340375,0xe2840075,0x83a400c7}},	//   _ijẹb, _ברנז_, _әһми, _рыдҵ, 
   {{0x644155dd,0x61e555de,0xd84801f2,0xf1bc03b2}},	//   _imni, _tbil, wọk_, rhár_, 
   {{0x61e408a4,0xfce555df,0x00000000,0x00000000}},	//   _ubil, кобо, --, --, 
   {{0x3e5800bc,0x0f3c0023,0x8e7401c6,0x3c640139}},	// [228c0] jďte_, _ከድልየ, уурч, вкаг, 
   {{0x65680363,0x92e40183,0x4c34009d,0x62480205}},	//   _mygh, নিৰ_, лэхт, pıos, 
   {{0x3da8656c,0x3ea405f5,0x8144e4c4,0xbea555e0}},	//   _окно_, _шинг, _سنگن, _шанк, 
   {{0x682c03cd,0x16c401e0,0xb05807d9,0x9cb400cf}},	//   _røda, ҫҡан, yräk, _مۅرت, 
   {{0x644155e1,0xb1785b47,0x682c0158,0x00000000}},	//   _omni, leår, _søda, --, 
   {{0x7d0555e2,0xf1bc02fb,0x76400162,0xddc40356}},	//   _irks, vkám_, _smoy, bliţ, 
   {{0xd7f85894,0xbb4401af,0x00000000,0x00000000}},	//   дуқ_, _ревк, --, --, 
   {{0xf1bc02fb,0x656955e3,0x6fdc01f9,0xb05801e3}},	//   tkám_, _bygh, _पॉईं, träk, 
   {{0xd91155e4,0x8cd407f7,0x00000000,0x00000000}},	//   _دیش_, यूपो, --, --, 
   {{0x656c04cc,0xf1bc0306,0xad9808a5,0x00000000}},	//   ücha, rkám_, _hnút, --, 
   {{0x64400334,0xb17800cc,0xf1bc03da,0xb05955e5}},	//   _dmni, jeår, skám_, lsäg, 
   {{0x764155e6,0xf3000323,0x644155e7,0xddc400e2}},	//   _umoy, гжүү, _emni, lniņ, 
   {{0x7d0403cd,0xb4b050e5,0xb05955e8,0xe3f401b9}},	//   _nrks, _тилә, lräi, رعیش_, 
   {{0xa4b4011a,0xf07404a9,0x00000000,0x00000000}},	//   _ילדה_, тигә_, --, --, 
   {{0x7d0555e9,0x69d000af,0xb1780623,0xf1bc01d3}},	//   _arks, _डाली, geår, nkák_, 
   {{0x2d8c04ce,0x64400034,0x682c143a,0x611406be}},	//   øge_, _zmni, _nødn, _bəlğ, 
   {{0xdd94e17f,0xfcc05393,0x644110de,0xb1780158}},	// [228d0] рауы, йәрм, _ymni, reås, 
   {{0x6b840220,0x4fc034b1,0xb0589e50,0x00000000}},	//   نشال, _دەسە, kräi, --, 
   {{0x613801d3,0x7d0555ea,0x71241079,0xb058265c}},	//   _túlé, _erks, _سرکل, buär, 
   {{0x69d00073,0xb4f0012d,0xc9580145,0xddc40171}},	//   _डाळी, _अनूप_, ىلاش_, eniņ, 
   {{0x682c072b,0x4bc40139,0xfa5401b9,0xb05801e3}},	//   _dødn, _бөег, درلگ, gsäg, 
   {{0xb05804e6,0x1a6807d6,0x656801bf,0x3e580306}},	//   fräi, _ییلی_, _rygh, rďte_, 
   {{0x682c00cc,0xddc40309,0xb0580221,0xfc240092}},	//   _fødn, lliš, gräi, _ደረጃው, 
   {{0x644005b1,0x682c00b5,0xad9801e7,0x85b80014}},	//   _smni, _gødn, _inús, رابس_, 
   {{0x4ce000cc,0x5a440006,0x45840108,0x00000000}},	//   নিকু, _тэра, ыгив, --, 
   {{0xf8ac168d,0xb05955eb,0x6568062c,0xad980aab}},	//   _رکه_, bräi, _vygh, _knús, 
   {{0xddc41ebd,0x00000000,0x00000000,0x00000000}},	//   hliš, --, --, --, 
   {{0x823555ec,0xddc4e28b,0xe7dc1b61,0xb178143a}},	//   اردا, kliš, प्रप, veår, 
   {{0x661955ed,0x3c34037e,0x656955ee,0x2c480153}},	//   mjuk, _hæve_, _uygh, _kėdė_, 
   {{0x64402747,0xddc40316,0x661955ef,0xb1780ac8}},	//   _umni, dliš, ljuk, teår, 
   {{0x3ebc008c,0x661801f4,0x00000000,0x00000000}},	//   étt_, ojuk, --, --, 
   {{0x661850f9,0xb17955f0,0x7d0401ab,0xb058fba5}},	//   njuk, reår, _prks, ysäg, 
   {{0x682c03cd,0x8c940111,0xb1784cab,0xddc40024}},	// [228e0] _rødn, архі, seår, gliš, 
   {{0xad980b21,0x6618d62e,0xea880150,0x7d040055}},	//   _snút, hjuk, _ﺑﺎﺭﯞ, _vrks, 
   {{0xdec002d3,0x3c3401bf,0x8cd407f7,0x15781884}},	//   ስለኒ_, _næve_, यूबो, ﻧﯩﺴﯩ, 
   {{0xb059557b,0xca7400fd,0x66182252,0xddc40010}},	//   tsäg, аучы, jjuk, bliš, 
   {{0xad9801a2,0x627c0034,0x7d04002d,0xd91401c0}},	//   _vnút, _głoś, _urks, рдлы, 
   {{0xb05955f1,0x28f4005b,0x661800c0,0x00000000}},	//   rsäg, уешь_, ejuk, --, 
   {{0xa3d446c7,0xddc4005f,0x627c033f,0x368802ec}},	//   िलन_, rniņ, _złoś, нсин_, 
   {{0x47c40729,0xb05955f2,0xdc3400d0,0xf2c40aac}},	//   ল্লী, psäg, _múčn, қсон, 
   {{0xb05801c7,0xdc340419,0xf1bc01d3,0x00000000}},	//   sräi, _lúčn, skák_, --, 
   {{0xb1780fac,0xb05955f3,0x6618035b,0xa920004e}},	//   deåp, präi, ajuk, _удул, 
   {{0xd37155f4,0xddc44ec5,0xf5e40046,0x2810004b}},	//   تهد_, zliš, _білм, _دولس, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf1bc00e5,0x92d400eb,0x00000000,0x00000000}},	//   nkái_, হবে_, --, --, 
   {{0x682c2142,0xdb1c02d2,0x00000000,0x00000000}},	//   _nødl, _adrí, --, --, 
   {{0xd90555f5,0x9f345566,0xb4b00032,0xf1bc030a}},	//   _کی_, бері, _тиһә, hkái_, 
   {{0xddc4009b,0x99b800cc,0x00000000,0x00000000}},	//   tliš, ীভুক, --, --, 
   {{0xc0c01884,0xad9803b2,0x0bb4005b,0x4bb400ee}},	// [228f0] _мәри, _snús, ибаю, ийас, 
   {{0xad987c36,0x682c037e,0x91e00073,0x00000000}},	//   _saúd, _rødo, ग्रज_, --, 
   {{0x20040085,0xddc409a8,0x682d55f6,0xd010004b}},	//   ɛmi_, sliš, _sødo, _هلک_, 
   {{0xb0580267,0x3c34005c,0xdb6955f7,0x0cd410e4}},	//   gräv, _ræve_, урул_, _комю, 
   {{0x1a6800f2,0xdef40092,0x2c6c0166,0x00000000}},	//   ایقی_, _ልቡና_, hüdi_, --, 
   {{0x870446c6,0xab84003b,0x00000000,0x00000000}},	//   لبعل, _бубк, --, --, 
   {{0x661955f8,0xbf3c0092,0xdb58117e,0x00000000}},	//   tjuk, _አድናቆ, _бют_, --, 
   {{0x060825f2,0x680800e2,0x9a8401c6,0x787400e4}},	//   тник_, _sēdē, _гуул, râva, 
   {{0x68080029,0x661955f9,0x27b00daf,0x195800fb}},	//   _pēdē, rjuk, _ләйс, _баты_, 
   {{0x66191c32,0x9f580004,0x039555fa,0x2c6c0793}},	//   sjuk, ndrã_, шрия, füdi_, 
   {{0x9f4c01f1,0xb0580e78,0x57a555fb,0xb38001c6}},	//   ždú_, nräu, _ышта, жлэл, 
   {{0xe1f80107,0xb058002f,0xb178007c,0x00000000}},	//   уҳи_, iräu, rfån, --, 
   {{0x85040ca5,0xb058002f,0x9f580332,0x724000e5}},	//   _خوشن, hräu, rdrí_, تھول, 
   {{0x98a004b9,0x82345311,0x03a555fc,0x7fd40220}},	//   šić_, ارگا, _тико, шімі, 
   {{0x6fd41d8a,0x682c0ef9,0x3f686f61,0x683c0024}},	//   _बारू, _rødl, тиво_, _išdė, 
   {{0xbe340075,0xfbb0015b,0x682c01bf,0xb218005c}},	//   جىرب, _চাইত, _sødl, lmæn, 
   {{0x68f804ba,0x3b941d39,0x3d1401f9,0x00000000}},	// [22900] _nsud, ајет, नमधे_, --, 
   {{0x69d955fd,0xb05955fe,0x00000000,0x00000000}},	//   _acue, fräu, --, --, 
   {{0x68f955ff,0xc0dc02d3,0xb4c000dc,0xb0585b00}},	//   _asud, ሕዶም_, _ऌट्_, träv, 
   {{0xfca88863,0x00000000,0x00000000,0x00000000}},	//   _لاسو_, --, --, --, 
   {{0x9f5835fb,0xe0e404c5,0x656c0112,0xed540107}},	//   ldrà_, মিকভ, üchl, _воя_, 
   {{0x56955600,0x69d804d4,0xb0593f8a,0xcd1401c8}},	//   бакт, _ecue, bräu, _اسٽڊ, 
   {{0x9f595601,0xe3b80154,0xb21801bf,0x17c40124}},	//   ndrà_, ংলাব, dmæn, _ҳазҭ, 
   {{0x7aec0175,0xb0585b00,0x00000000,0x00000000}},	//   _ipbt, lrät, --, --, 
   {{0xa29c0150,0xb0580112,0xf8b80037,0x667000d1}},	//   _ﺍﻟﺨﺒ_, nsäc, _उबिय, غدىر, 
   {{0x4ce003d4,0xb0595602,0xb218005c,0xb8640345}},	//   নিচু, nrät, gmæn, _ئارو, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb0580166,0x00000000,0x00000000,0x00000000}},	//   hrät, --, --, --, 
   {{0xd848063f,0xb218005c,0x473411dc,0xb058007c}},	//   bọt_, bmæn, _پرەز, krät, 
   {{0xa17400d4,0xf1a44f3c,0x00000000,0x00000000}},	//   ігрі, _क्रन, --, --, 
   {{0xe2940cfc,0xb059493a,0x644c004e,0x00000000}},	//   _кај_, drät, ècie, --, 
   {{0xdd955603,0xdda8084c,0x71440b87,0x682c1512}},	//   жаты, итул_, _вхож, _rødm, 
   {{0x387c0109,0xdc980220,0x682c0627,0x1df8005b}},	// [22910] _ohtr_, ивті_, _sødm, шеты_, 
   {{0x69d804cc,0xb0583468,0x8f343b8f,0x00000000}},	//   _scue, träu, _геоц, --, 
   {{0xddc47e2a,0x7aec0194,0xaac51b48,0x9b68074d}},	//   nniś, _cpbt, شتان, ашца_, 
   {{0xb0580112,0xad98032e,0x00000000,0x00000000}},	//   rräu, _gnúp, --, --, 
   {{0xbb4c08b0,0xb0595604,0x606c001f,0x5f4401d5}},	//   ﺍﻟﻰ_, sräu, ደረጉት_, _هنیل, 
   {{0x9f5809d7,0x7dd0022e,0x68f8013a,0x00000000}},	//   ldrá_, _hаsа, _vsud, --, 
   {{0xad9806ed,0xd1cc0020,0x7dd0022e,0x0708007b}},	//   _gaúc, ባሉት_, _kаsа, ايبي_, 
   {{0x9f58612f,0x5f082871,0x682c005c,0x68f80332}},	//   ndrá_, हित्_, _kødk, _tsud, 
   {{0x68f804a7,0x7dd001d5,0xe5a00131,0x00000000}},	//   _usud, _mаsа, биқи, --, 
   {{0x80ccf5d8,0x00000000,0x00000000,0x00000000}},	//   _तिबे, --, --, --, 
   {{0x2a7c0211,0xe2780184,0xb218037e,0xded80023}},	//   _khub_, ишмә_, rmæn, ክብን_, 
   {{0xb218037e,0x4cac00eb,0x00000000,0x00000000}},	//   smæn, _চিনু, --, --, 
   {{0x682c072b,0x5fdc1b76,0x00000000,0x00000000}},	//   _nødk, _बादल, --, --, 
   {{0xb21808a7,0xf66801a8,0xb059481b,0x00000000}},	//   lmæl, phæð_, vsäc, --, 
   {{0xdb1c0122,0xb05801e6,0xdec0001f,0x00000000}},	//   _odrá, vrät, ስፈን_, --, 
   {{0xb05901c7,0x2a7c0218,0x9f5800db,0x682c005c}},	//   fräs, _nhub_, rdrà_, _bødk, 
   {{0xbb480014,0xbc748ee7,0xb0583648,0x00000000}},	// [22920] گلان_, مهرب, trät, --, 
   {{0x60c42aa4,0x8fd401d2,0x83f8013f,0xb0583468}},	//   _ivim, _мәсә, frɑɑ, rsäc, 
   {{0xb0595605,0xd84800b4,0x60c4032e,0xbb4802da}},	//   rrät, zọs_, _hvim, دلان_, 
   {{0xb0581433,0x2a7c0072,0x72d8010f,0x787400e4}},	//   srät, _chub_, טקעג, tâvo, 
   {{0xa3d41d34,0xb0595606,0x2a7c0009,0x27e400b5}},	//   िला_, prät, _dhub_, ffnn_, 
   {{0xeb941eb8,0xfca80451,0x27040051,0x2b5c0055}},	//   _гир_, _لاڳو_, _bđn_, _śuce_, 
   {{0xab2409ac,0x777803ac,0x27040051,0xb21801a8}},	//   _лора_, _qztx, _cđn_, fmæl, 
   {{0x60c404a7,0xf1bc01ed,0xd84801f2,0x5988013d}},	//   _ovim, nkát_, tọs_, _көлн_, 
   {{0x60c40810,0x00000000,0x00000000,0x00000000}},	//   _nvim, --, --, --, 
   {{0x682c0627,0x9f5800d0,0xdb1c0306,0x00000000}},	//   _nødh, zdrá_, _zdrá, --, 
   {{0x60c55607,0x88803ee6,0xd84801f2,0xc4440214}},	//   _avim, _تیون, sọs_, تیون_, 
   {{0xe714025f,0xfbdc015b,0xdef40023,0x00000000}},	//   _לחבר_, ড়িত, ልእን_, --, 
   {{0xd838033b,0x06640150,0xf50400db,0x779001e2}},	//   _klč_, _بالپ, _ыздо, _بیګا, 
   {{0xf1d801f9,0xdb1c04ce,0xfd48063f,0x644c06af}},	//   _भावन, _idræ, splọ, écit, 
   {{0x60c55608,0x9f3402bf,0xf15004d3,0x80cc0490}},	//   _evim, пері, تێکد, _तिथे, 
   {{0x3c341445,0xb0580267,0x3f9c030a,0x00000000}},	//   _ræva_, träs, ñtur_, --, 
   {{0x3b2c0020,0xf1bc0093,0xd7c80490,0xb60416a3}},	// [22930] _በሚገኘ, maá_, रणाच, mašć, 
   {{0xb6042220,0xf1bc0093,0x2a7c058a,0x6e400014}},	//   lašć, laá_, _shub_, _کۆرم, 
   {{0x60c40e8a,0x2a7c03d5,0xe7a400d1,0xca3001ec}},	//   _zvim, _phub_, ەپتۇ_, _ﺨﻁﺭ_, 
   {{0x2a7c01d4,0x4974084c,0xb05817da,0xf1bc2c98}},	//   _qhub_, олес, präs, naá_, 
   {{0x4ac4069f,0x2d04b8d1,0x70b40073,0xb218072b}},	//   _लटकव, _уянг, _अबोल, vmæl, 
   {{0xf1bc0418,0x3c3400b5,0x96500150,0x00000000}},	//   haá_, _hævn_, _ﯗﺯﺍﭖ_, --, 
   {{0x46387c0c,0x682c0ac8,0xb2182833,0xf1bc01d3}},	//   ичия_, _jødi, tmæl, nkás_, 
   {{0x3c3400b5,0x0a580107,0xe78401d5,0x00000000}},	//   _jævn_, _табъ_, _ғузо, --, 
   {{0xd83802e2,0x84595609,0xb219560a,0xd1f0001f}},	//   _flč_, ирот_, rmæl, ውንት_, 
   {{0xb218d379,0x00000000,0x00000000,0x00000000}},	//   smæl, --, --, --, 
   {{0xfbd006a9,0xe7740014,0xf1bc0270,0x682c0450}},	//   ותי_, _الاں_, faá_, _rødh, 
   {{0xe5ec02f6,0x3c3400b5,0x00000000,0x00000000}},	//   äkää, _nævn_, --, --, 
   {{0x644c0231,0xb14124cf,0x427435e3,0xd7e01414}},	//   écis, днял, йгүс, _नामच, 
   {{0x25bd560b,0xb0580108,0x00000000,0x00000000}},	//   laul_, tsäa, --, --, 
   {{0x249c01b9,0xf6941d00,0xf1bc00e5,0x00000000}},	//   lqum_, _ﻗﺎﻟﭙ, tkát_, --, 
   {{0x25bd560c,0x3d040490,0x5fdc01ad,0x682c01bf}},	//   naul_, हटले_, _बावल, _dødi, 
   {{0xaf4c0201,0x60c419ad,0xf1bc01d3,0xbca445f9}},	// [22940] _አድርገ, _uvim, yház_, زماي, 
   {{0xb0580267,0x682c0162,0x25bc0036,0xac8001ca}},	//   lsän, _fødi, haul_, дгул, 
   {{0x249c0113,0x629400db,0x25bc01c7,0xf1bc00e5}},	//   hqum_, _èxod, kaul_, ckás_, 
   {{0xb058014a,0x2c6c29ef,0x25bc0098,0xb90800d8}},	//   nsän, füds_, jaul_, инез_, 
   {{0x1cd40dd4,0xe9f4005e,0xb059560d,0xfbe08109}},	//   _ེའི_, інші_, isän, _पापम, 
   {{0xb8f04da1,0x7e740c8c,0x56940137,0xf1bc1f08}},	//   _वि_, llyp, пакт, nkár_, 
   {{0xb059560e,0xd83828b5,0xd6d000c6,0xf1bc01ed}},	//   ksän, _vlč_, رقة_, rház_, 
   {{0x25bd560f,0xd4b80b87,0xfa342a8b,0xe9d4578a}},	//   gaul_, блиц_, _بىرج, _мкс_, 
   {{0x25e8367a,0xd7644354,0x249c009a,0xf1bc01d3}},	//   _अउरी_, _کنای, gqum_, pház_, 
   {{0x7e7406a3,0xb71401b9,0x4ad001bc,0x7c3c0208}},	//   hlyp, _وباش, _हिमव, nhpr, 
   {{0xd250a8b4,0xe7f41889,0x25bc0099,0xf1bceff0}},	//   فند_, ंजरा_, baul_, taá_, 
   {{0xdb1c0139,0x25bc054e,0xb058007c,0xe61401a9}},	//   _idrä, caul_, gsän, _мдх_, 
   {{0xb60405a1,0x91e052be,0xa6300212,0x44a000cf}},	//   rašć, ग्गज_, _інші, _كۅيق, 
   {{0x9f4c0e96,0xdef402d3,0xf1bc0093,0xb0580139}},	//   ždý_, ልጥን_, saá_, asän, 
   {{0xf1bc0418,0xb6042625,0x7e7403cd,0x533402e8}},	//   paá_, pašć, flyp, _хейт, 
   {{0x4d9825ec,0x9f5800d8,0x717000db,0xf1bc00e5}},	//   скаю_, oerê_, _يۇدا, rkás_, 
   {{0x2d8d5610,0xf1bc01d3,0x00000000,0x00000000}},	// [22950] äge_, skás_, --, --, 
   {{0xd1f002d3,0xdb1c007c,0x25bc0356,0x656c0112}},	//   ውንቲ_, _odrä, zaul_, üchi, 
   {{0x7e740c8c,0x2b4407c5,0x3ff80375,0xdc080472}},	//   blyp, ànc_, _הפתע, تقلو_, 
   {{0xddc40311,0x7e74035a,0x4c9401f0,0x00000000}},	//   mniş, clyp, _нимс, --, 
   {{0x25bc039a,0xc7a4005b,0x46dc00bc,0x4c9400f0}},	//   vaul_, пилк, नूनह, _хигс, 
   {{0xc7a52ee4,0x7c3c31fb,0x25bc002e,0xddc40356}},	//   чикк, chpr, waul_, oniş, 
   {{0x2b5404fb,0x25bc0158,0x2d8c0150,0x00000000}},	//   _بیاد_, taul_, _ﻓﻭﻀﻰ_, --, 
   {{0x682c39c2,0x00000000,0x00000000,0x00000000}},	//   _nødv, --, --, --, 
   {{0x25bd223c,0xe3c000f7,0x3d0c000d,0xddc40356}},	//   raul_, үрүү, ठिये_, hniş, 
   {{0x25bc0810,0x00000000,0x00000000,0x00000000}},	//   saul_, --, --, --, 
   {{0x25bd5611,0xb058005b,0x249c0309,0x26c00cad}},	//   paul_, tsän, squm_, _ìjo_, 
   {{0x3e7c0054,0xdb1c000f,0x00000000,0x00000000}},	//   kïta_, _berê, --, --, 
   {{0xb0593c88,0x682c005c,0x249d5612,0xf1bd5352}},	//   rsän, _dødv, qqum_, tkár_, 
   {{0xb0595613,0x2d340092,0x00000000,0x00000000}},	//   ssän, _የመካከ, --, --, 
   {{0xfbd000dd,0x13a403e6,0x9f580240,0x62240150}},	//   ہتا_, _تۆپی_, merë_, _يوتە, 
   {{0x9f580200,0xb05804ab,0x00000000,0x00000000}},	//   lerë_, lsäl, --, --, 
   {{0xdb1d5614,0x7e74127b,0x628401ab,0xb058002f}},	// [22960] _gerê, rlyp, _ihio, präp, 
   {{0xb0580793,0x628400a3,0x9f580240,0x6da00116}},	//   nsäl, _hhio, nerë_, _җира, 
   {{0xeb94f884,0xef14084c,0xb4d800dc,0xfbe03885}},	//   чих_, _емэ_, _ॡङ्_, _पाठम, 
   {{0xdb1c02d3,0x9f580023,0x7c3d37b5,0xbdf80137}},	//   _herë, herë_, shpr, _اردا_, 
   {{0x62840fa3,0xb0580958,0x00000000,0x00000000}},	//   _mhio, ksäl, --, --, 
   {{0x9f580023,0x62840363,0xfca800f1,0xa81400d1}},	//   jerë_, _lhio, _پاڼو_, كتىر_, 
   {{0xe3c009bd,0xb17851dc,0x6284035a,0x682c2b96}},	//   ্ভাব, mgåe, _ohio, _nødu, 
   {{0x9f58145e,0x628400ad,0x1514023b,0xe94401d3}},	//   terê_, _nhio, ддия, _کرفی, 
   {{0x682d4094,0xa3d40a94,0x7bdc017a,0xb218005c}},	//   _rødv, िलं_, ogpu, smæk, 
   {{0x7bdd5615,0x628403a0,0x53341ff0,0x644c07ea}},	//   ngpu, _ahio, деот, écip, 
   {{0x62840876,0xd2502832,0xd67801ec,0x78a00946}},	//   _bhio, ہنگ_, _وڭعا_, lqov, 
   {{0x62855616,0xa778008f,0x9f580100,0xc76400d1}},	//   _chio, _פראפ, merè_, _غالى, 
   {{0xdb1c002e,0x62847ea6,0xc6440228,0xc5e40154}},	//   _berë, _dhio, _تئلى, _খোকা_, 
   {{0x62855617,0x9f580023,0x38a00174,0x09b8012c}},	//   _ehio, cerë_, _mðr_, _उज्य, 
   {{0x628450c2,0xdb1d5618,0xead40c58,0xb17804ce}},	//   _fhio, _derë, _সন্ম, dgåe, 
   {{0xddc55619,0x2ac001e1,0x9e05561a,0x1fa401c6}},	//   rniş, _lébá_, нчул, _үрэг, 
   {{0xdb1c00cf,0xb05801e3,0x00000000,0x00000000}},	// [22970] _herè, lsäm, --, --, 
   {{0x3e7c0bc9,0xdb1d561b,0x7bdc4bc1,0xb178072b}},	//   rïta_, _kerè, ggpu, ggåe, 
   {{0x682c037e,0x3e7c0054,0xdb1c0100,0x7ac0004e}},	//   _mødt, sïta_, _jerè, көта, 
   {{0xdb1d561c,0x7bdc017a,0x99d402da,0x00000000}},	//   _merè, agpu, فتها, --, 
   {{0x99840316,0xb0580108,0x00000000,0x00000000}},	//   _domů_, ysäl, --, --, 
   {{0x97c417de,0xddc40e3c,0x5f7400db,0x682c21e3}},	//   ىتىم, moiš, _تاۋر, _nødt, 
   {{0xe784072c,0xb17801bf,0x00000000,0x00000000}},	//   чудо, ngåb, --, --, 
   {{0x6680036b,0xfcc00092,0x7f780116,0x00000000}},	//   ریشل, ድረጉ_, ﻠﯩﯟﯦ, --, 
   {{0x9f59561d,0xc484f307,0x58d5561e,0x29080066}},	//   terë_, млик, _потт, _éca_, 
   {{0x6285561f,0xdb1c007f,0x42c80228,0x9f58003a}},	//   _shio, _berè, огон_, berè_, 
   {{0xb0583623,0x6fd40574,0x62855620,0x682c01bf}},	//   rsäl, _बाजू, _phio, _dødt, 
   {{0x5eac00bd,0xb059489e,0xdb1c005c,0x055402e8}},	//   _ছিলে, ssäl, _udrå, _отля, 
   {{0xdb1c044e,0x682c20e4,0x05280e58,0x62840076}},	//   _perë, _født, _фолк_, _vhio, 
   {{0x62840374,0x9f588abd,0x468000d1,0x25081f70}},	//   _whio, leré_, _яққа, _پرچی_, 
   {{0x62855621,0xdb1d5622,0xe730013f,0x26c4110c}},	//   _thio, _verë, nyε_, nsno_, 
   {{0x44240161,0x682c00b5,0x9f580214,0x7874003a}},	//   ljl_, _køds, neré_, râvi, 
   {{0x61e40117,0xfca8004b,0xdb1d5623,0xb178795b}},	// [22980] _icil, تازو_, _zerè, tgåe, 
   {{0xdb1c2af5,0x3eb80120,0x26c41a48,0xe730016b}},	//   _heré, _twpt_, ksno_, kyε_, 
   {{0xdb1d5624,0x0ba82dfc,0xf09004ae,0xb1785629}},	//   _keré, سالى_, _שנת_, rgåe, 
   {{0xfcc02295,0xdb1c0124,0xb17893e0,0x9f584db4}},	//   ድረግ_, _jeré, sgåe, jeré_, 
   {{0x682c1512,0x9f58067c,0xdb1c01d3,0xc1e4000d}},	//   _nøds, deré_, _meré, _कानब_, 
   {{0x76a83523,0x9f580699,0xcee8ca19,0x7a1c0356}},	//   отив_, terè_, _برین_, _bătâ, 
   {{0x9f595625,0xebe015bf,0x61e55626,0x682c0450}},	//   feré_, _шорп, _ocil, _rødt, 
   {{0x61e55627,0x682c00b5,0x9f5859b3,0x1c1c00c5}},	//   _ncil, _bøds, geré_, नावल_, 
   {{0xdb1c0100,0x9f5800db,0x26c50531,0xddc40118}},	//   _serè, serè_, asno_, kliž, 
   {{0x61e55628,0x682c708a,0xdb1c204d,0x9f5835b2}},	//   _acil, _døds, _perè, perè_, 
   {{0xdb1d5629,0x394404d4,0xe6000014,0x7348026b}},	//   _beré, lzos_, رِیَ, ючив_, 
   {{0x682c708a,0xd5b0ffc5,0x61e400a3,0xb05833da}},	//   _føds, _صفت_, _ccil, rsäm, 
   {{0xdb1c7739,0x3945562a,0x656c2155,0xe5a00276}},	//   _deré, nzos_, ücht, _ричи, 
   {{0x61e400b5,0xdb1c7d47,0xddc40010,0x101800e1}},	//   _ecil, _terè, gliž, दाइश_, 
   {{0x32640801,0xdb1d562b,0x61e4003a,0x682c01bf}},	//   _отив, _feré, _fcil, _kødr, 
   {{0xdb1d562c,0x3a24013f,0xe31462a9,0x61e51e7a}},	//   _geré, jjop_, _آغوش_, _gcil, 
   {{0xddc476e0,0x682c7eb1,0xb058403a,0x00000000}},	// [22990] bliž, _mødr, nsäk, --, 
   {{0xdb1c04c4,0x682c0fac,0x394400e2,0x00000000}},	//   _zeré, _lødr, dzos_, --, 
   {{0xdb1c002e,0x39440171,0x00000000,0x00000000}},	//   _yeré, ezos_, --, --, 
   {{0x7bcc02d0,0x06ac009e,0x682c2b96,0xb0580267}},	//   _edbu, _গিলি, _nødr, ksäk, 
   {{0xda08e42d,0x00000000,0x00000000,0x00000000}},	//   بينه_, --, --, --, 
   {{0x682c28b3,0xee3c032e,0xb058007c,0x00000000}},	//   _røds, _hlý_, dsäk, --, 
   {{0x9f59562d,0xb05801f4,0x00000000,0x00000000}},	//   teré_, tsäj, --, --, 
   {{0xc5e400fe,0xf1d833ee,0xb05801e3,0xf5e40395}},	//   _খোজা_, _भागन, fsäk, емъл_, 
   {{0x61e4062c,0x26c40175,0x394400ae,0xb058007c}},	//   _rcil, ssno_, czos_, gsäk, 
   {{0x61e5562e,0xc324035b,0x9f589e9e,0x03240f4d}},	//   _scil, емок, seré_, едон, 
   {{0xdb1cc1c3,0x442401e0,0x9f580789,0xb4ac000d}},	//   _peré, rjl_, peré_, _ओढ़ी_, 
   {{0x656c0112,0xbb3800df,0x51a801f4,0x00000000}},	//   üchs, פערי, дъём_, --, 
   {{0xef4c0092,0xb7e400fe,0x6d5800c0,0xdb1d562f}},	//   _አስወግ, _গোটত_, _žuan, _veré, 
   {{0xf8b00302,0xc5e4009e,0x00000000,0x00000000}},	//   רשם_, _খোচা_, --, --, 
   {{0xdb1c1dee,0x93240efc,0x394405d5,0xee3c02d2}},	//   _teré, _لرين, zzos_, _blý_, 
   {{0x61e40e3c,0xa3d40b7d,0x614400cf,0xf1bc00e5}},	//   _ucil, िलक_, _لىبە, lján_, 
   {{0x22415630,0xf7880166,0x3a24014f,0xb05801f4}},	// [229a0] _ilik_, _kiçü_, vjop_, ksäh, 
   {{0x6cd0f0bd,0x224005c7,0xec741b4f,0x06c40011}},	//   اقلا, _hlik_, епу_, _এমনি, 
   {{0xb17800cc,0xac9414d1,0x290c022e,0xf1bc00e4}},	//   mgåa, رنما_, evga_, iján_, 
   {{0x4ad00574,0x9fb8015b,0xba740b6c,0xb1780158}},	//   _हिरव, _জায়গ, راات, lgåa, 
   {{0xa3cc3174,0x224001b9,0x39440077,0x682c0fac}},	//   षणा_, _mlik_, uzos_, _rødr, 
   {{0x39455631,0x7bcc04ce,0x7d04127b,0x7a3800b0}},	//   rzos_, _udbu, _isks, _tïto, 
   {{0x2240014a,0x7c2c00a3,0x394401d3,0x5b2401d3}},	//   _olik_, _iobr, szos_, _جہال, 
   {{0xb218037e,0x7c2d5632,0xa920151e,0x224001a9}},	//   mlæg, _hobr, тдәл, _nlik_, 
   {{0x7c2d5633,0xb218037e,0x1fd802f5,0xca7400c0}},	//   _kobr, llæg, দ্যস, _руры, 
   {{0xb05804f3,0xb804066d,0x2240014a,0x7c2d49c3}},	//   rsäk, _سکتے_, _alik_, _jobr, 
   {{0x22415634,0xb2189573,0x7c2c01af,0xb0582c4f}},	//   _blik_, nlæg, _mobr, ssäk, 
   {{0x22402b53,0x916c01fb,0xe5a00063,0xddc40003}},	//   _clik_, _nội_, _бици, gliż, 
   {{0x682c005c,0xb0580221,0xa19428f6,0xb218032e}},	//   _kødp, lsäi, лаюч, hlæg, 
   {{0x7c2d5635,0x22415636,0xb4bc0490,0xb1780158}},	//   _nobr, _elik_, ेळी_, ggåa, 
   {{0xb1900348,0xddc40034,0x7d040857,0x59d01fbc}},	//   _өлкә, bliż, _asks, हणार, 
   {{0xb218f4d8,0x7c2c00a3,0xdb1c003a,0x5f94009b}},	//   dlæg, _aobr, _perî, уист, 
   {{0x9f5807c5,0xc0c00ce8,0x25f001ef,0x00000000}},	// [229b0] lerì_, _вәси, ्जती_, --, 
   {{0x7c2c0f85,0x6f000798,0x682c21e3,0x224001d5}},	//   _cobr, _ânco, _nødp, _zlik_, 
   {{0xfbe00a5a,0x7d0403ac,0x224001a9,0xb21869d9}},	//   _पारम, _esks, _ylik_, glæg, 
   {{0xb0580036,0x224001a9,0xce5801c6,0x999400c0}},	//   dsäi, _xlik_, _цамц_, _šešt_, 
   {{0x7c2c0618,0x59741e49,0xb218037e,0xb058005b}},	//   _fobr, лышу, lmæs, tsäh, 
   {{0x46f402bf,0xdb1c01e1,0xb0580036,0x7c2d5637}},	//   вчит, _kerì, fsäi, _gobr, 
   {{0x6e2c0427,0xb21801bf,0x00000000,0x00000000}},	//   _kocb, nmæs, --, --, 
   {{0x7c2c8ea8,0x9f580ffb,0xb058023a,0xdb1c01e1}},	//   _zobr, derì_, ssäh, _merì, 
   {{0x98f4bed4,0x2240036b,0x76203f6e,0xf1bc43e5}},	//   _مثلا, _rlik_, рмыз, tján_, 
   {{0x2240a1e9,0xb0580221,0x6e2d5638,0x9f59379e}},	//   _slik_, bsäi, _locb, ferì_, 
   {{0xb2194195,0x22400034,0xf1c0004d,0xb17805ac}},	//   klæd, _plik_, _trở_, vgåa, 
   {{0x6e2c01ab,0x224001a9,0xb21801bf,0x2314004e}},	//   _nocb, _qlik_, dmæs, _үндө_, 
   {{0xf1bc00dd,0xb1780158,0xd05c06be,0xfbe017ee}},	//   pján_, tgåa, ltsə, _पालम, 
   {{0x66095639,0x4ad00406,0x3f9c06ea,0x00000000}},	//   _hagk, _हिंव, øtu_, --, 
   {{0x7c2c0c67,0x6608089c,0xb17800cc,0xdb1c01bf}},	//   _robr, _kagk, rgåa, _udrø, 
   {{0xb179563a,0x2240168c,0xb21800b5,0x00000000}},	//   mgån, _ulik_, glæd, --, 
   {{0x6609563b,0xed541679,0x7c2d563c,0xada0e3e9}},	// [229c0] _magk, вот_, _pobr, раул, 
   {{0x14d40574,0x1c1c00af,0x5fdc0490,0xf1bc03b2}},	//   _दिसण, नाइल_, _बाटल, hjál_, 
   {{0x9f48049b,0xb1780267,0x7f4402dd,0x916c0208}},	//   ähän_, ngån, _ренж, _tội_, 
   {{0x6608256c,0xb219563d,0xd83828b5,0x2810485f}},	//   _nagk, rlæg, _miče_, یونس, 
   {{0xb219563e,0xd83808a4,0x7e6401f5,0x7c2d563f}},	//   slæg, _liče_, _ijkp, _tobr, 
   {{0xb8d80316,0x7c2c08a4,0x9f580561,0xdb1d4875}},	//   _अझ_, _uobr, herí_, _herí, 
   {{0x66095640,0xd8380960,0xeb9400f3,0xdb1c01d3}},	//   _bagk, _niče_, _аир_, _kerí, 
   {{0xb0580221,0xb17801e6,0x6d480428,0x6b800112}},	//   rsäi, dgån, ùgag, ünge, 
   {{0x66095641,0xb0580a40,0x25f000e1,0xe60c03e6}},	//   _dagk, ssäi, ्ज़ी_, ڕشی_, 
   {{0x590c025c,0xe944006c,0xdb1c299d,0xd83802f0}},	//   _གླགས_, _شرقی, _lerí, _biče_, 
   {{0x6608383d,0x9f580789,0xb21801bf,0x5fdc0037}},	//   _fagk, ferí_, dmær, _बाजल, 
   {{0xb270446e,0xb218005c,0x45400022,0xb0580108}},	//   ркмә, vmæs, рҕәа, nsäv, 
   {{0x76415642,0x200c022e,0x00000000,0x00000000}},	//   _iloy, оdi_, --, --, 
   {{0x76415643,0xdb1c026c,0xb21800b5,0x6e2d5644}},	//   _hloy, _perì, gmær, _socb, 
   {{0x9f58bb68,0x92595645,0xb8ec025c,0x764003b2}},	//   berí_, _пакт_, _ྱས_, _kloy, 
   {{0xdb1c002d,0x9f340220,0x9f5800d0,0x30a55646}},	//   _oerâ, шесі, cerí_, _иров, 
   {{0xd90475e5,0xebc415ed,0xb21800b5,0x7640009f}},	// [229d0] _بی_, вљен, smæs, _mloy, 
   {{0x76415647,0x7d000798,0x91a80051,0xb21801bf}},	//   _lloy, çosa, _hoà_, slæd, 
   {{0x054c044e,0xb0580054,0x98b8005f,0x76400cad}},	//   _ንድሕሪ, wsäw, _ārā_, _oloy, 
   {{0xdb1c067c,0x764001e1,0x99e800d7,0x00000000}},	//   _gerí, _nloy, vaňá, --, 
   {{0xdb1caa3a,0x6608003e,0xf8b401c0,0x4cac00fe}},	//   _cerâ, _ragk, гөх_, _চিকু, 
   {{0x76415648,0x66095649,0xf09c0ba1,0xb05801f4}},	//   _aloy, _sagk, lvàs_, asäv, 
   {{0x660810c7,0x9f580004,0x764003b2,0x00000000}},	//   _pagk, merã_, _bloy, --, 
   {{0xdb1c002d,0x76400072,0xd83805be,0xc4e401c0}},	//   _ferâ, _cloy, _riče_, гжий, 
   {{0x03a43dc8,0x9f580030,0xb0580e78,0xdb1c00d8}},	//   липо, verí_, lsäu, _gerâ, 
   {{0x68f80086,0x7641564a,0x66080af9,0xb1780267}},	//   _ipud, _eloy, _wagk, tgån, 
   {{0xc7346680,0x6609564b,0xb0580e78,0x00000000}},	//   _حفاظ, _tagk, nsäu, --, 
   {{0x7641564c,0x68f8063f,0xb17801e6,0xd83807f5}},	//   _gloy, _kpud, rgån, _viče_, 
   {{0x51543cdf,0xb4b40661,0xb21800b5,0x7fd4109a}},	//   атру, _бичә, tmær, ліві, 
   {{0xdb1c28f2,0xb1780267,0x9f580022,0x7f740f06}},	//   _serí, pgån, verâ_, губц, 
   {{0xdb1c93c8,0xb21800b5,0x6440dea4,0x9f5800e4}},	//   _perí, rmær, _ilni, derã_, 
   {{0x68f80086,0xb21800b5,0x200c00d7,0x9f59564d}},	//   _opud, smær, ždi_, eerã_, 
   {{0xdb1d564e,0xc0e402d3,0x5194074d,0xb218005c}},	// [229e0] _verí, _ምባሉ_, _вăта, pmær, 
   {{0xc005564f,0x00000000,0x00000000,0x00000000}},	//   _спок, --, --, --, 
   {{0xdb1d5650,0x91a8e47b,0x68f95651,0x0fc40032}},	//   _terí, _hoá_, _apud, _өйөн, 
   {{0x9f595652,0xfe409b17,0xb5140dba,0x00000000}},	//   merà_, _اکسی, तिमय_, --, 
   {{0x9f595653,0x64400477,0x00000000,0x00000000}},	//   lerà_, _olni, --, --, 
   {{0xfd300cf9,0xeab401d2,0x76400174,0xb0580108}},	//   _mc물_, _әйт_, _sloy, ssäv, 
   {{0x9f595654,0x764006f2,0xb0585b00,0xbb4406ed}},	//   nerà_, _ploy, msät, _севк, 
   {{0x64415655,0x96344f4c,0xb05801e6,0x7c3c0b4f}},	//   _alni, рниц, lsät, lkpr, 
   {{0x9f595656,0xdb1c00db,0xa3cc00dc,0xa96409ac}},	//   herà_, _herà, षणं_, _бита_, 
   {{0x54540801,0xb0585de3,0x644000a3,0x2b5c002b}},	//   рвот, nsät, _clni, _śuci_, 
   {{0xdb1c00db,0x9f580268,0xd2506ea9,0x7c3c017a}},	//   _jerà, jerà_, قند_, ikpr, 
   {{0x9f584d72,0x64415657,0x35a4b25a,0x76402d2f}},	//   derà_, _elni, _садг, _uloy, 
   {{0xe3ac0e83,0xc0e4044e,0xf1bc00dd,0x7c3c037f}},	//   غری_, _ምባል_, lják_, kkpr, 
   {{0x7c3c01f5,0xa3cc00dc,0x00000000,0x00000000}},	//   jkpr, षणः_, --, --, 
   {{0x9f595658,0x5ed405f5,0xb0583894,0xb21801bf}},	//   gerà_, йжру, dsät, rlæb, 
   {{0x7c3c27bb,0xded00092,0x00000000,0x00000000}},	//   ekpr, ብሪካ_, --, --, 
   {{0xad980005,0xe1f05298,0xb0580112,0xdb1c012d}},	// [229f0] _naút, _رسي_, fsät, _odró, 
   {{0xb0595659,0x9f588421,0xdd9402dd,0x13c80154}},	//   gsät, berà_, сауы, _শাড়, 
   {{0x68f837ca,0x9f58b2cc,0xdb1c0137,0xcb54026a}},	//   _spud, cerà_, _cerà, јвећ, 
   {{0xdb1c03b7,0xf1bc01ed,0xb0580e78,0x7c3c0373}},	//   _serã, dják_, rsäu, akpr, 
   {{0x9f59565a,0xb058002f,0x91a80051,0x00000000}},	//   merá_, ssäu, _xoá_, --, 
   {{0x7c3d565b,0x9f5800d8,0x39991c1a,0xb05801f4}},	//   ckpr, lerá_, _süsü_, msäs, 
   {{0xdb1c0261,0x659802b5,0xf1bc01d3,0x25f000bc}},	//   _verã, _māhū, gják_, ्जली_, 
   {{0xea61565c,0x644000d0,0x2f040142,0xdb54009d}},	//   _اپری, _slni, _mŵg_, _увсы, 
   {{0xdb1d565d,0xdee4044e,0x9f58011c,0x64400122}},	//   _terã, _ምዃን_, zerà_, _plni, 
   {{0xdb1d565e,0xad980241,0xf1c40005,0x09cc009e}},	//   _herá, _haús, ñáns_, _িউটা, 
   {{0x9f580137,0xad982b57,0x6441565f,0xdb1c01d3}},	//   xerà_, _zaút, _vlni, _kerá, 
   {{0x69c95660,0x9f595661,0xdb1d5662,0xb0580108}},	//   nage, verà_, _jerá, ksäs, 
   {{0x9f587c36,0x0084036b,0xdb1c05d5,0xf26464b6}},	//   derá_, илмо, _sdrü, риял_, 
   {{0x69c95663,0x9f595664,0xe46800fd,0x64401d9e}},	//   hage, terà_, _яшел_, _ulni, 
   {{0x69c95665,0x9f5800d7,0xb05801e3,0x00000000}},	//   kage, ferá_, vsät, --, 
   {{0x9f595666,0x6da15667,0xbc680075,0xada0036b}},	//   rerà_, жита, ھمان_, жатл, 
   {{0xfbd05841,0xb058ee1f,0x9f595668,0xdb1c5b80}},	// [22a00] قتا_, tsät, serà_, _serà, 
   {{0x9f5861a5,0xdb1c00c6,0x49183c71,0x00000000}},	//   perà_, _aerá, पिनो_, --, 
   {{0xb0595669,0x9f59566a,0x7c3c0373,0x7e740589}},	//   rsät, berá_, rkpr, poyp, 
   {{0x60c5566b,0x9f585599,0xdb1c3c80,0xfce4fedc}},	//   _kwim, cerá_, _cerá, _комо, 
   {{0xb0585b00,0x7c940798,0x00000000,0x00000000}},	//   psät, _врвц, --, --, 
   {{0x60c5566c,0xf1bc00dd,0xdb1c0137,0xa88400f7}},	//   _mwim, tják_, _terà, айча_, 
   {{0x69c9566d,0x60c4004b,0x7d15566e,0xf6440354}},	//   bage, _lwim, lvys, ихин, 
   {{0x69c9566f,0xf1bc01ed,0xb05801e3,0x6670009f}},	//   cage, rják_, nsär, يدير, 
   {{0x37e411ed,0x490001c0,0x64300451,0x7d14062c}},	//   _возг, _нүцг, ڪريء, nvys, 
   {{0x9f5801f1,0xf1bc01d3,0xc9547a6f,0x673003b2}},	//   zerá_, pják_, _утсы, ðdjó, 
   {{0x60c40054,0x63a00ac5,0xb6a43e64,0x643000ec}},	//   _awim, _dgnn, _тиел, تريء, 
   {{0x60c40230,0xdb1c0005,0x9f580005,0xceb805a2}},	//   _bwim, _xerá, xerá_, һәм_, 
   {{0xdee4067d,0x9f580261,0x659800b0,0x49181524}},	//   _ምዃኑ_, verá_, _pāhū, पियो_, 
   {{0x69c95670,0xceb881fc,0x7d140419,0x00000000}},	//   zage, ләм_, dvys, --, 
   {{0x69c90746,0x9f582cd7,0x60c4013f,0xa2e003b7}},	//   yage, terá_, _ewim, _дојд, 
   {{0xb0595671,0xb17945fb,0x69c95672,0xf8a446c7}},	//   tsäs, ngåk, xage, खदाय, 
   {{0x09dc2158,0xf1bd5673,0x69c95674,0x60c40165}},	// [22a10] ণ্ডা, mbá_, vage, _gwim, 
   {{0x69c95675,0xdb1c28f2,0x29f40882,0xb059493a}},	//   wage, _será, _ṃa_, rsäs, 
   {{0x69c95676,0xb058c6cb,0x9f580798,0xdb1c3873}},	//   tage, ssäs, perá_, _perá, 
   {{0x6e4001d9,0xb05801f4,0x00000000,0x00000000}},	//   _بۆرم, psäs, --, --, 
   {{0xdb1d5677,0x696400e5,0x00000000,0x00000000}},	//   _verá, جداق, --, --, 
   {{0x195800fd,0x97a401e0,0xfd94011a,0xaab40066}},	//   шачы_, ҙрәл, _לדרך_, _نصرت, 
   {{0xdb1c4ac2,0x69c95678,0xdee4044e,0x63a003ac}},	//   _terá, page, _ምዃና_, _rgnn, 
   {{0xca3801e4,0x69c801f0,0x99d4007b,0xc8c801c8}},	//   _fiŝa_, qage, _وتقا, _مورن_, 
   {{0xc0dc069d,0x04c8027d,0x00000000,0x00000000}},	//   ንቶስ_, دوخي_, --, --, 
   {{0x60c40230,0xd8380427,0x04440114,0x00000000}},	//   _rwim, _tiča_, сеон, --, 
   {{0x9f580228,0x60c55679,0x662457d4,0xf09c007f}},	//   merç_, _swim, _پراك, twàn_, 
   {{0x7d140108,0x00000000,0x00000000,0x00000000}},	//   yvys, --, --, --, 
   {{0x25bd4687,0xdd0000e2,0x03a43866,0x00000000}},	//   mbul_, ātīb, _лило, --, 
   {{0x25bd567a,0xf1bc0120,0x00000000,0x00000000}},	//   lbul_, abá_, --, --, 
   {{0xf1bcba10,0x3e8400c6,0x25bc01ab,0xb21801bf}},	//   bbá_, مشرف, obul_, mlæn, 
   {{0x25bc0ab7,0x60c41419,0xb218037e,0x0eb8010b}},	//   nbul_, _twim, llæn, руры_, 
   {{0x60c40230,0xdb1c0072,0x7d140076,0x6fc801ec}},	// [22a20] _uwim, _kerç, uvys, _ﺑﯘﺭﺷ, 
   {{0xb21800b5,0x7d14002d,0xb059567b,0x28a8000d}},	//   nlæn, rvys, ssär, _चढ़ि, 
   {{0xdb1d567c,0xb0980302,0x25bd567d,0xd91001d3}},	//   _merç, _תייר, kbul_, ڈیز_, 
   {{0xd911567e,0x9f58003a,0x00000000,0x00000000}},	//   ویز_, teræ_, --, --, 
   {{0xed55567f,0xa96410fc,0x17c8013e,0x6ab80427}},	//   _гоя_, бица_, иҳаи_, _čufe, 
   {{0xb05801f4,0x00000000,0x00000000,0x00000000}},	//   nsäp, --, --, --, 
   {{0x3d3c02b1,0x98b80790,0x61b81bbb,0xb218005c}},	//   _wāwā_, ızım_, _आभूष, dlæn, 
   {{0x3ea00227,0x5ca402d3,0xf77000e5,0x00000000}},	//   _jikt_, _ፈረንሳ_, ياں_, --, 
   {{0xdb1d5680,0x3ea0282c,0x394401c0,0x9f5800a2}},	//   _berç, _mikt_, _унаг, lerä_, 
   {{0x3ea15681,0xb21800b5,0x23e002bf,0x25bc0014}},	//   _likt_, glæn, піюв, abul_, 
   {{0x25bc8677,0xd76400dd,0x92955682,0xf784038b}},	//   bbul_, _بنای, жанц, _الاَ, 
   {{0x3ea0068f,0xb21801bf,0xfbac0154,0x495400f1}},	//   _nikt_, alæn, গরিত, _اخېس, 
   {{0xdb1c049b,0xf594007b,0xb21801bf,0xcfe00154}},	//   _herä, _الشج, blæn, ম্ফন, 
   {{0xdb1d5683,0xb1780158,0x9f580166,0x00000000}},	//   _gerç, ngåi, kerä_, --, 
   {{0x3ea0007c,0x00000000,0x00000000,0x00000000}},	//   _bikt_, --, --, --, 
   {{0xdb1c0166,0x2fdc0356,0x6cb000c7,0x9f58008e}},	//   _merä, şug_, зиаӡ, derä_, 
   {{0x3ea05243,0xdd955684,0xb6040024,0xaac40133}},	// [22a30] _dikt_, заты, mišę, ڵتان, 
   {{0x25bc1210,0xdb1c06be,0x57b408ec,0x00000000}},	//   zbul_, _xerç, ुरोह, --, 
   {{0xd1d00020,0x15f80073,0x25bc0205,0x9f58008e}},	//   _ሦስት_, ंभार_, ybul_, gerä_, 
   {{0x3ea15685,0x7d0c1611,0xd8380064,0x00000000}},	//   _gikt_, änsä, _bičo_, --, 
   {{0xf8ac0583,0xc7a400d8,0x00000000,0x00000000}},	//   نکل_, оилк, --, --, 
   {{0xdb1d5686,0x25b000dc,0xcb0805d9,0xee3c010e}},	//   _berä, ीर्ण, _پيرن_, _diýe_, 
   {{0x387c003e,0x25bd4ca4,0x920400ef,0x9f580139}},	//   _dktr_, tbul_, _krāč, cerä_, 
   {{0xdb1c2ac2,0xd8380010,0xb0580e78,0x25bc0af9}},	//   _serç, _fičo_, lpäd, ubul_, 
   {{0xdb1d5687,0x25bd5688,0x22a0007f,0x2a7c0240}},	//   _perç, rbul_, kèkè_, _ikub_, 
   {{0x994800c6,0x25bc0014,0xb058002f,0xae18000d}},	//   _الكل_, sbul_, npäd, _पोसन_, 
   {{0xdb1d5689,0xb21804ce,0xc5d40212,0x96b80244}},	//   _gerä, rlæn, _діль, _هانز_, 
   {{0xacb8045f,0x25bc3792,0x2ca001f5,0xb51402c3}},	//   _krûd, qbul_, _lijd_, तिशय_, 
   {{0xdb1d568a,0x3ea01511,0x28cc01bc,0xb21800b5}},	//   _terç, _rikt_, _सौमि, plæn, 
   {{0x3ea0ce29,0xff24023b,0x43440064,0xf8b0011a}},	//   _sikt_, омго, _мелв, ושך_, 
   {{0x032400d6,0x3ea03a65,0xc05801ec,0x6b800036}},	//   _єдин, _pikt_, гің_, üngl, 
   {{0x00e545f1,0x67240de2,0xb058005b,0x322800db}},	//   _джин, _àjju, ssäp, _ۅتۋۋ_, 
   {{0x3ea0049f,0xdb1c143a,0x00000000,0x00000000}},	// [22a40] _vikt_, _merå, --, --, 
   {{0x2a7d568b,0x9f580724,0x394000af,0x3ea1568c}},	//   _akub_, terä_, _üksi_, _wikt_, 
   {{0xad9801e1,0x3ea1568d,0x2be82de3,0xeaac00e5}},	//   _abúd, _tikt_, _चारू_, نٹل_, 
   {{0x387c0263,0xdb1c10d1,0x84600092,0x00000000}},	//   _sktr_, _nerå, ትዌሩን_, --, 
   {{0x80b0012d,0x9f5801f4,0xf1bc00e5,0x2a0400cf}},	//   _इंफे, serä_, mját_, زقوپ_, 
   {{0xdb1c049b,0xca38010f,0x9f58023a,0x59b8012c}},	//   _perä, _fiŝo_, perä_, उँहर, 
   {{0x2a7c020c,0xb1780217,0xd1d00092,0x00000000}},	//   _fkub_, rgåi, _ሦስቱ_, --, 
   {{0xdb1d568e,0x3eb80200,0xf1bcd11c,0x00000000}},	//   _verä, _mtpt_, nját_, --, 
   {{0x7469568f,0xad9801e1,0xb1780158,0xb0580036}},	//   иров_, _gbúd, lgåv, lpäe, 
   {{0x81e000bd,0xdb1c5d8a,0x00000000,0x00000000}},	//   ন্ম_, _terä, --, --, 
   {{0xad980162,0xb178007c,0xf1bc00e5,0x00000000}},	//   _tbúg, ngåv, kját_, --, 
   {{0xb9f40020,0xc764247f,0x00000000,0x00000000}},	//   _ማን_, _عالى, --, --, 
   {{0x2be80574,0xd8380010,0x54b8005b,0xd57c074d}},	//   _चालू_, _koč_, _угля_, _тiак, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd8395690,0x2ca00196,0x9f580100,0x3eb80051}},	//   _moč_, _rijd_, nfrè_, _ctpt_, 
   {{0x5f955691,0x3eb80175,0xb058000d,0xf1bc00e5}},	//   фист, _dtpt_, dpäe, gját_, 
   {{0x8bd95692,0xb0580254,0xb19001af,0x00000000}},	// [22a50] ймас_, epäe, _юлиә, --, 
   {{0xd838151c,0x2a7d55e3,0x4fc005a9,0x00000000}},	//   _noč_, _skub_, _سەرە, --, 
   {{0xa1340133,0xb0580112,0xf1bc00e5,0x00000000}},	//   _فریش, rpäd, bját_, --, 
   {{0x2ca067c3,0xb0591a73,0xee8000d1,0x00000000}},	//   _wijd_, späd, ﯩﻜﻪﻥ_, --, 
   {{0x2ca00460,0xd8380010,0xfcc06bcd,0xb0580254}},	//   _tijd_, _boč_, _зәхм, apäe, 
   {{0x9f58011c,0x00000000,0x00000000,0x00000000}},	//   ffrè_, --, --, --, 
   {{0x442807ae,0x1af55693,0x00000000,0x00000000}},	//   _đa_, _опря, --, --, 
   {{0x2a7c01e2,0xecdc0034,0x9b640131,0x286800c7}},	//   _ukub_, _फटाफ, _تۆمۈ, ырҵо_, 
   {{0x81e003f4,0xdb1c0fac,0xb21803b2,0xad980419}},	//   ন্ড_, _verå, glæm, _ubúd, 
   {{0xd83800f3,0xf4840092,0x00000000,0x00000000}},	//   _goč_, _ርብርብ_, --, --, 
   {{0x588402d5,0x00000000,0x00000000,0x00000000}},	//   _цыта, --, --, --, 
   {{0x291c0200,0x00000000,0x00000000,0x00000000}},	//   _krua_, --, --, --, 
   {{0xdb1c002d,0xa56404fb,0xb1400945,0x69d8009f}},	//   _berû, _بدان, енял, _mdue, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb1c002d,0xf1bc00e5,0xc0d40092,0x4344011c}},	//   _derû, tját_, ራረመ_, _хейв, 
   {{0x69d80369,0x291c01f2,0x932405af,0xc1e4000d}},	//   _ndue, _orua_, _آرون, _काटब_, 
   {{0xdb1c045f,0x16c802ab,0xbca400d1,0x6ab80010}},	// [22a60] _ferû, _रब्ब, سماي, _čufa, 
   {{0x69d95694,0xb1784535,0xac800f32,0x8cdc1d8a}},	//   _adue, tgåv, егул, _पिरो, 
   {{0x291d5695,0x0b580c98,0xdb240344,0xd83813d5}},	//   _arua_, орцы_, بوای, _roč_, 
   {{0x212003a2,0x291d5696,0x20195697,0xdb1c0162}},	//   _krih_, _brua_, ldri_, _kerú, 
   {{0x291c0597,0xb058007d,0xfde400aa,0x69d80142}},	//   _crua_, späe, _وکړو_, _ddue, 
   {{0x291c0333,0xb1792b8c,0x69d80077,0x21200066}},	//   _drua_, pgåv, _edue, _mrih_, 
   {{0x291d5698,0xbbb845c7,0x7bcd5699,0xe7341677}},	//   _erua_, ेरीक, _iebu, зеј_, 
   {{0x291c008f,0x80bc07f7,0xd4b9569a,0xe45000c7}},	//   _frua_, ्ठाइ, олиц_, ҵкьы, 
   {{0x7bcc44bf,0x291c02d3,0xb178168c,0x66703b5f}},	//   _kebu, _grua_, ngåt, عدىر, 
   {{0x7bcd569b,0xe8700131,0x20180327,0x00000000}},	//   _jebu, _كۆنگ, jdri_, --, 
   {{0x7bcc98b8,0x21200066,0xf365569c,0x67b80375}},	//   _mebu, _arih_, ятин, _המבק, 
   {{0x7bcd569d,0x9f5800d0,0x20181207,0x00000000}},	//   _lebu, berú_, edri_, --, 
   {{0xf1bc08a5,0x00000000,0x00000000,0x00000000}},	//   fjár_, --, --, --, 
   {{0xdb1c045f,0x64a0064d,0x2cbc0240,0xb1780250}},	//   _derú, _зача, _çudi_, dgåt, 
   {{0x81e02f04,0xb4b40014,0x702401d9,0x59cc01bc}},	//   ন্ধ_, _بُڈا_, _ہردٕ, ारार, 
   {{0x7bcc0393,0x20180ffb,0xdb1c002d,0x22940395}},	//   _aebu, adri_, _werû, _пищя, 
   {{0x7bcd569e,0x2d8c7c52,0x21200076,0xa6940375}},	// [22a70] _bebu, åge_, _grih_, לכלה_, 
   {{0x2d850e36,0x80b00307,0x7bcd569f,0xb21801bf}},	//   āne_, _इंते, _cebu, klæk, 
   {{0x2b4401d3,0x7af801e3,0xbff044a5,0x00000000}},	//   ánc_, _ättl, _шүрш, --, 
   {{0x291c0395,0x3208004a,0xb2180158,0x00000000}},	//   _prua_, necy_, dlæk, --, 
   {{0x7bcd56a0,0x28a4023a,0xdb5001d9,0x00000000}},	//   _febu, чшег, نَے_, --, 
   {{0x7bcd2026,0x91c4045e,0x320800ca,0xacb8000f}},	//   _gebu, ্লিখ, hecy_, _trûb, 
   {{0x76b40724,0xee3c00a2,0xb21802d2,0x00000000}},	//   үләр_, _ziýa_, glæk, --, 
   {{0x291d56a1,0xddc40311,0x04b4013e,0xb17803cd}},	//   _trua_, mniţ, мсоя, ngås, 
   {{0xe77468e7,0x7bcd56a2,0x7cdc0276,0x6fbcda03}},	//   _کلاں_, _yebu, părţ, ्रां, 
   {{0x43440fbe,0x6570002b,0xb46000cf,0x00000000}},	//   деов, _āghā, ккыл, --, 
   {{0x42083b55,0x68e956a3,0x212005b1,0xfbd00375}},	//   онно_, lugd, _srih_, כתי_, 
   {{0x9f580789,0xdb1cfb29,0x51b8005b,0x290c0067}},	//   perú_, _perú, зыря_, owga_, 
   {{0xdb1c0428,0x68e851e2,0x290c01af,0x9f5801bf}},	//   _derù, nugd, nwga_, lerø_, 
   {{0x2d340092,0x00000000,0x00000000,0x00000000}},	//   _ከመካከ, --, --, --, 
   {{0x7bcd56a4,0xee3c00a2,0x00000000,0x00000000}},	//   _rebu, _siýa_, --, --, 
   {{0x7bccfdcb,0xd8380010,0x00000000,0x00000000}},	//   _sebu, _pičk_, --, --, 
   {{0x628556a5,0x7bcd56a6,0xdb1c332c,0x409428ed}},	// [22a80] _ikio, _pebu, _herø, _орот, 
   {{0x290c058a,0xb1780250,0xddc40356,0xd57c074d}},	//   dwga_, rgåt, fniţ, _тiек, 
   {{0x3ce805f9,0xb05801e3,0xddc40356,0x9f5801bf}},	//   _चमके_, späc, gniţ, jerø_, 
   {{0x7bcd56a7,0x1bf00c2e,0x9f580162,0xb1782611}},	//   _webu, _चावल_, derø_, mgår, 
   {{0x644c005f,0x628401f7,0xb17956a8,0xdb1c03cd}},	//   īcij, _mkio, lgår, _lerø, 
   {{0x59cc038e,0xdb240311,0x7bcc002f,0x00000000}},	//   ारहर, ăsân, _uebu, --, 
   {{0x628556a9,0xb1781654,0x9f5808fb,0xe70001d3}},	//   _okio, ngår, gerø_, نسٹی, 
   {{0x151556aa,0xb21956ab,0x6f000139,0x356801a9}},	//   едия, rlæk, _änce, жрон_, 
   {{0xd8380552,0xa5040f5c,0xb2180321,0x20d00073}},	//   _liči_, дења_, slæk, तीमध, 
   {{0x628556ac,0xdb1c708a,0xb1787c1d,0x14c40118}},	//   _akio, _berø, kgår, लीगण, 
   {{0x8c24031c,0x6fbc085c,0xb178005c,0x00000000}},	//   སྐྲྀ_, ्रसं, jgår, --, 
   {{0xb1781654,0x754400a7,0xab24012d,0x65c00153}},	//   dgår, _онез, _złóż_, _абца, 
   {{0xa1943334,0xdb1c003a,0x61f400d0,0xb1780fac}},	//   каюч, _verù, _želá, egår, 
   {{0x6284005a,0xb178007c,0xf0740166,0x00000000}},	//   _ekio, fgår, фигә_, --, 
   {{0x75200232,0xb1780726,0x7d040139,0xdef8190b}},	//   _hroz, ggår, _apks, мыт_, 
   {{0x7520bb75,0xe0d00133,0x91680208,0x60384283}},	//   _kroz, دزێ_, _lửa_, _aşmı, 
   {{0xddc40227,0x00000000,0x00000000,0x00000000}},	// [22a90] khiņ, --, --, --, 
   {{0x2ca556ad,0x752156ae,0xdd941219,0x91680208}},	//   önd_, _mroz, тауы, _nửa_, 
   {{0x2cbc031c,0x00000000,0x00000000,0x00000000}},	//   _ħudu_, --, --, --, 
   {{0x7520914d,0xddc4054e,0x82400092,0x2be80c70}},	//   _oroz, rniţ, _ይከሰታ, _चाकू_, 
   {{0xa8007764,0xcee001ec,0x00000000,0x00000000}},	//   _çıkt, _шұңқ, --, --, 
   {{0x68e956af,0xddc449ad,0x9168004d,0xc71406ed}},	//   rugd, mniš, _cửa_, еќињ, 
   {{0xddc40fb7,0x68e82819,0x7520e231,0x1ab400c0}},	//   lniš, sugd, _aroz, _абся, 
   {{0x3ce40030,0xddc556b0,0x69300133,0x453455f3}},	//   šove_, oniš, _لکتر, ехот, 
   {{0x752156b1,0xdb1c03b2,0x940c03e3,0x00000000}},	//   _croz, _serø, lmdə_, --, 
   {{0x628404ca,0xb17801bf,0xe7a40116,0xab240210}},	//   _skio, ygår, _قۇشى_, _ułóż_, 
   {{0x752156b2,0xddc409a8,0xe61001d5,0xb178007c}},	//   _eroz, hniš, _لشش_, xgår, 
   {{0x752156b3,0x23bc878d,0xd83816a3,0xdb1c03b2}},	//   _froz, _श्रद, _riči_, _verø, 
   {{0x752156b4,0x1bf0069f,0xddc48e70,0x66180064}},	//   _groz, _चालल_, jniš, mduk, 
   {{0xddc44d3c,0x44f956b5,0x661956b6,0xdb1c0158}},	//   dniš, mè_, lduk, _terø, 
   {{0x44f93aac,0x3ebc0a40,0x75208864,0xa284135f}},	//   lè_, ëtt_, _zroz, _لیدو, 
   {{0x62840af5,0xb1788ce1,0x82345d62,0xd83800c0}},	//   _ukio, rgår, _سربا, _viči_, 
   {{0x44f956b7,0xb058023a,0x00840139,0xc0dc0023}},	// [22aa0] nè_, mpän, _плио, ንቶም_, 
   {{0x3154008f,0x6618023a,0x44f8004e,0xd8380427}},	//   _ניין_, hduk, iè_, _tiči_, 
   {{0x1db8012c,0x44f84db4,0x91680051,0x00000000}},	//   _अलपत, hè_, _rửa_, --, 
   {{0xddc40f72,0x66182375,0xacb800e4,0x9168004d}},	//   bniš, jduk, _irûn, _sửa_, 
   {{0x44f80699,0x66182f99,0xccf40116,0xb178003b}},	//   jè_, dduk, _иқт_, ngåp, 
   {{0x66180522,0xa9640127,0x00000000,0x00000000}},	//   eduk, عموم_, --, --, 
   {{0x2ba407d0,0x75200b9b,0xdb1c02d2,0x940c03e3}},	//   _कृपा, _sroz, _herþ, cmdə_, 
   {{0x66182819,0x44f802bd,0xb9c400ec,0x00000000}},	//   gduk, fè_, _ستره, --, 
   {{0x44f80100,0x6aa00373,0x752006be,0x648c7e78}},	//   gè_, ïnfe, _qroz, røin, 
   {{0xeb5000db,0x752156b8,0x758c0240,0x00000000}},	//   _جۉۅگ, _vroz, _ዘዳለዎ_, --, 
   {{0xddc4151c,0x394401ed,0x66e156b9,0xf41003d4}},	//   zniš, lyos_, _боха, ়ালৰ_, 
   {{0x752156ba,0x44f956bb,0x93440139,0xadec000d}},	//   _troz, bè_, енүе, _छाइन_, 
   {{0x394556bc,0xad980241,0x44f82b1d,0x75200456}},	//   nyos_, _abún, cè_, _uroz, 
   {{0xacb8045f,0xc5686640,0xca3801e4,0x00000000}},	//   _brûn, _تحمل_, _viŝi_, --, 
   {{0xddd416a3,0x00000000,0x00000000,0x00000000}},	//   _šaša, --, --, --, 
   {{0xddc449ad,0xb64000b5,0x39440254,0x00000000}},	//   tniš, _ｏｃ_, kyos_, --, 
   {{0xe1f00132,0xde5800d4,0x00000000,0x00000000}},	// [22ab0] _اسى_, хаті_, --, --, 
   {{0xddc4151c,0x39440280,0xea9c00b8,0xabb000c7}},	//   rniš, dyos_, _koṇa_, уажә, 
   {{0xddc405ce,0x5b2556bd,0xacb80b21,0x66192055}},	//   sniš, льца, _grûn, yduk, 
   {{0x44f956be,0xd83828b5,0xddc415ad,0x3ce80490}},	//   yè_, _miču_, pniš, _चमचे_, 
   {{0x626400e5,0x61e003b2,0x00000000,0x00000000}},	//   dőol, ómli, --, --, 
   {{0x59540b82,0x44f956bf,0xe7cc0154,0xb05801f4}},	//   ፋሚካኤ, vè_, রল্য, tsäy, 
   {{0x394422d0,0xd8380e3c,0x44f956c0,0xb05801f4}},	//   ayos_, _niču_, wè_, ypän, 
   {{0x44f80699,0x9a84a006,0x3944020c,0x66180810}},	//   tè_, _буул, byos_, uduk, 
   {{0xa50556c1,0x661956c2,0x195800cb,0xd05c0213}},	//   رىدە_, rduk, _заты_, susə, 
   {{0x44f956c3,0xd83800f3,0x03a4026a,0x032401d5}},	//   rè_, _biču_, кипо, вдон, 
   {{0x44f8f0b6,0x66180024,0x0394036b,0x670000cf}},	//   sè_, pduk, ърия, _сүйб, 
   {{0x44f956c4,0xd838033b,0x41b402e8,0xa78001af}},	//   pè_, _chčf_, ъсот, _иҫһе, 
   {{0xd1180a28,0x21240597,0x9f582880,0x44f8011c}},	//   दिगण_, ímh_, rfrí_, qè_, 
   {{0xb0594a6f,0x68f80009,0x00000000,0x00000000}},	//   spän, _mqud, --, --, 
   {{0xdb1c09a5,0xee3c0432,0x9f4c04cc,0xb0580108}},	//   _berý, _boý_, üdà_, ppän, 
   {{0x337402e4,0x3944208d,0x02040124,0x7af801e3}},	//   _בעצם_, yyos_, _рзин, _ätti, 
   {{0xdb1c00ee,0xed4156c5,0x3e6c0092,0x2d880210}},	// [22ac0] _derý, антп, _በወረዳ_, _cyce_, 
   {{0x224018a6,0xf1a4012c,0xb058007c,0xec74117e}},	//   _hoik_, _गणतन, npäl, впу_, 
   {{0x22400037,0x00000000,0x00000000,0x00000000}},	//   _koik_, --, --, --, 
   {{0x224003cd,0x9f58004e,0xdb1c00a2,0xee3c00ee}},	//   _joik_, mfrà_, _gerý, _goý_, 
   {{0xb058006a,0x224156c6,0xdb1cbf58,0xee340276}},	//   kpäl, _moik_, _herü, _рня_, 
   {{0xdb1d56c7,0x39440280,0x22400254,0x370453ef}},	//   _kerü, ryos_, _loik_, вчив, 
   {{0x7c2d56c8,0x9f5956c9,0xdb08adae,0xeab401f4}},	//   _inbr, meró_, äläs, _айс_, 
   {{0xeb941c03,0x9f5956ca,0xdb1c01d3,0xe6b800d1}},	//   _рис_, derü_, _merü, _ﻧﺎﮬﺎ, 
   {{0x4a7556cb,0x68f8009a,0xca7556cc,0xe8f401c6}},	//   _сырт, _gqud, _суры, _илт_, 
   {{0x9f5800eb,0xddd401e4,0x00000000,0x00000000}},	//   neró_, _ĥaŝa, --, --, 
   {{0xad980cad,0x9f58013d,0x00000000,0x00000000}},	//   _abúl, gerü_, --, --, 
   {{0xdb1d56cd,0xacb85725,0xd05c0134,0x00000000}},	//   _heró, _brûl, busɛ, --, 
   {{0xf1a90339,0x7c2c0d47,0x2164e9bd,0x74140066}},	//   باده_, _onbr, атрг, _لوشا, 
   {{0xd83808ad,0xdb1d56ce,0x2d880493,0xee3c00a2}},	//   _tiču_, _berü, _ryce_, _soý_, 
   {{0x9f5809d7,0x09dc04c5,0x2d880076,0xeea80212}},	//   deró_, ণ্টা, _syce_, дтак_, 
   {{0x7c2d56cf,0x320c066d,0x6340013f,0xdb1c01ed}},	//   _anbr, _úgy_, bɑnb, _derü, 
   {{0xad980241,0xcc980640,0xc3a401ee,0x00000000}},	// [22ad0] _gbúl, евац_, _иләҫ, --, 
   {{0x2d88039a,0x4f8401d9,0xd7f80356,0xef640c60}},	//   _vyce_, _ماجہ, _ncă_, _аъмо, 
   {{0xdb1c3262,0x2d88039a,0xdb14041e,0xee3c00ee}},	//   _gerü, _wyce_, ðaði, _toý_, 
   {{0x7c2d21f6,0x3ce495d8,0xb2180388,0x2d88013a}},	//   _enbr, šova_, mlæs, _tyce_, 
   {{0xacb8000f,0x9f583d5a,0x99d4029e,0x00000000}},	//   _krûm, beró_, شتنا, --, 
   {{0x9f5956d0,0x7778002f,0x46f4005b,0xdb1c03e3}},	//   merò_, _bxtx, гчит, _yerü, 
   {{0x9f58011c,0xb21801bf,0x00000000,0x00000000}},	//   lerò_, nlæs, --, --, 
   {{0xd05c016b,0xa41800af,0x2bc85edd,0x00000000}},	//   tusɛ, _भोजप_, िरका, --, 
   {{0x271403be,0xc48446b2,0x7c2c0b21,0x2ba40882}},	//   _mənə_, ллик, _ynbr, _कृता, 
   {{0x9f580598,0x22400793,0x42c896da,0x635000ac}},	//   terü_, _soik_, нгон_, lənə, 
   {{0x25ac0a2e,0x9f5802e8,0xa5043ee0,0xdb1c004e}},	//   _tggl_, herò_, رىگە_, _herò, 
   {{0xb21800b5,0x26c54ebc,0x27140213,0xdb1c0210}},	//   dlæs, mpno_, _nənə_, _zeró, 
   {{0x224001b8,0xb058005b,0xdb1c0790,0x69c80112}},	//   _voik_, ppäl, _serü, ibge, 
   {{0x9f588d2c,0xdb1d56d1,0x27201ea0,0xb218005c}},	//   derò_, _xeró, _kın_, flæs, 
   {{0x2d8c481f,0x9f580407,0xed541086,0x635003b9}},	//   ügen_, veró_, ҳот_, kənə, 
   {{0xad9801e1,0xdb1c5380,0x27200139,0x00000000}},	//   _ibúj, _verü, _mın_, --, 
   {{0x61e556d2,0x9f5800eb,0xdb1c0428,0xed5556d3}},	// [22ae0] _idil, teró_, _nerò, гот_, 
   {{0xdb1d56d4,0xb218f113,0xada03e64,0xd9cc0d2e}},	//   _terü, blæs, саул, ार्ट, 
   {{0x27200baf,0xdb1c00cf,0x3f6800b1,0x6e2c03ac}},	//   _nın_, _aerò, _чино_, _fncb, 
   {{0xdb1d56d5,0x9f58011c,0xb21923cb,0xfce40032}},	//   _berò, berò_, llær, _йомо, 
   {{0x1ae02cd1,0x9f583d35,0x60c401d5,0x8d6c0092}},	//   _पटकथ, peró_, _jtim, _በመቶው_, 
   {{0x60c556d6,0xdb1c02e2,0x7d140368,0x61e401b9}},	//   _mtim, _derò, mwys, _ldil, 
   {{0xeb9556d7,0xdb1d56d8,0x61e556d9,0x60c45178}},	//   _бир_, _veró, _odil, _ltim, 
   {{0x61e556da,0x60c41fbe,0xdb1c1f3f,0x272008a9}},	//   _ndil, _otim, _ferò, _dın_, 
   {{0x545556db,0x60c45679,0xb2180ac8,0x7d1556dc}},	//   ивит, _ntim, klær, nwys, 
   {{0x59cc047f,0xdb1c032e,0xe96400f3,0x00000000}},	//   ारकर, _afré, _саул_, --, 
   {{0x60c556dd,0x61e52597,0xb21956de,0x27200166}},	//   _atim, _bdil, dlær, _gın_, 
   {{0x61e401ab,0xc7640131,0x31c4329e,0x00000000}},	//   _cdil, _ئاكى, ысов, --, 
   {{0x61e400a9,0x153801ed,0x00000000,0x00000000}},	//   _ddil, _جزاک_, --, --, 
   {{0x61e454de,0x764156df,0x9f5802e8,0xb2181347}},	//   _edil, _hooy, verò_, glær, 
   {{0xda040141,0x7640299d,0x69c80067,0x6e2c0051}},	//   रभात_, _kooy, ybge, _pncb, 
   {{0x9f580395,0x68e8022c,0x76413aef,0x7d1448e9}},	//   terò_, yrgd, _jooy, fwys, 
   {{0x764156e0,0xb21956e1,0x2be80261,0x7d140af9}},	// [22af0] _mooy, blær, еќен_, gwys, 
   {{0x9f5802e8,0x764156e2,0xb21801bf,0x941c03e3}},	//   rerò_, _looy, plæs, _pivə_, 
   {{0x8af80d08,0x9f5956e3,0x9504025c,0xdb1c004e}},	//   тнес_, serò_, _ཙཱའི_, _serò, 
   {{0xea8956e4,0x7f3800c8,0x9f580f7e,0xd0109105}},	//   رخان_, _סערו, però_, _الگ_, 
   {{0x65a809a5,0xdb1c010e,0x69c80112,0x63500213}},	//   _möhü, _derñ, rbge, rənə, 
   {{0xb3440365,0xdb1c35f5,0x635000ac,0x201c0162}},	//   _kaçı, _verò, sənə, _óvit_, 
   {{0xdb1c0de2,0x764156e5,0x39bc02e3,0x7c3800a3}},	//   _ferñ, _booy, _ịse_, _òtra, 
   {{0xb34403ee,0x76401368,0xdb1c004e,0x26c40219}},	//   _maçı, _cooy, _terò, rpno_, 
   {{0x764002a4,0xdb1c05f7,0xb3446656,0x61e401a9}},	//   _dooy, _herð, _laçı, _rdil, 
   {{0x61e556e6,0x446400d3,0x26c401ab,0x2720008e}},	//   _sdil, рвов, ppno_, _tın_, 
   {{0xacb8334b,0x76400a55,0x437414fb,0xb2183619}},	//   _brûk, _fooy, рупт, vlær, 
   {{0x7640273f,0x569400e4,0xdb0c003b,0x656c002d}},	//   _gooy, _лахт, _åhån, ûchs, 
   {{0x2d8c03fa,0x95c89842,0xb218bc85,0xa8000139}},	//   ügel_, _суха_, tlær, _çıst, 
   {{0x25bd56e7,0x9f5805a4,0x7e6405b1,0x76400472}},	//   lcul_, ferð_, _smkp, _zooy, 
   {{0xdb1c24ba,0x9f581bb0,0x76403d27,0xb218f5b8}},	//   _afrî, gerð_, _yooy, rlær, 
   {{0x25bc47d8,0x61e40b6f,0xb2180feb,0x60c556e8}},	//   ncul_, _udil, slær, _ttim, 
   {{0x644046bd,0x60c556e9,0xb2181a82,0xbc641774}},	// [22b00] _koni, _utim, plær, авак, 
   {{0x644156ea,0x7d140151,0xdb1c08ce,0x3ce40306}},	//   _joni, rwys, _berð, šovo_, 
   {{0x644156eb,0x9f4c0724,0xb9c404b3,0x0c7956ec}},	//   _moni, üdä_, لقاي, усты_, 
   {{0x644156ed,0xeb301a59,0x0ae801e2,0x91680051}},	//   _loni, تىمد, ارلي_, _hứa_, 
   {{0xd3781326,0x644156ee,0x764156ef,0x2ba425c9}},	//   maće_, _ooni, _rooy, केबा, 
   {{0xdb1c19cf,0x644156f0,0x764156f1,0xa96407d6}},	//   _ferð, _noni, _sooy, шича_, 
   {{0xdb1c1c38,0xd7f8036b,0x7640062c,0xb34403b9}},	//   _gerð, вуқ_, _pooy, _xaçı, 
   {{0x644156f2,0x963556f3,0x7e7556f4,0x76400067}},	//   _aoni, сниц, nnyp, _qooy, 
   {{0x3ce0020c,0x993400dd,0x76400076,0x00000000}},	//   _jvkv_, _دہشت, _vooy, --, 
   {{0x76401bce,0x656d56f5,0x644026c2,0x25bc054e}},	//   _wooy, úcha, _coni, acul_, 
   {{0x36352c73,0xd3780960,0x7e7408c8,0x764156f6}},	//   _پراس, kaće_, knyp, _tooy, 
   {{0x644008e7,0xd3782220,0x9f580008,0xefe002d3}},	//   _eoni, jaće_, verð_, _ዝሓዘ_, 
   {{0xd378041a,0xb34406b9,0x00000000,0x00000000}},	//   daće_, _saçı, --, --, 
   {{0x64c0088c,0x64a156f7,0x9168004d,0xf1bd1f29}},	//   _بيول, _дача, _vừa_, scá_, 
   {{0xa5000867,0xb05802f6,0x6e64188c,0xb344afeb}},	//   _མདོག_, npäi, атаж, _qaçı, 
   {{0x644156f8,0x63741fc7,0xd378009b,0x28d400ab}},	//   _zoni, _әсәр_, gaće_, _डबलि, 
   {{0x644156f9,0x2d8c04ce,0xefe00023,0x00000000}},	// [22b10] _yoni, æge_, _ዝሓዙ_, --, 
   {{0x6440036b,0xd1f00023,0x6064009f,0xb0580254}},	//   _xoni, ፍንቲ_, _وهيل, kpäi, 
   {{0x2d1c0020,0x6aa00d27,0xd3783421,0x2d84033f}},	//   ስተካከ, ïnfo, baće_, łne_, 
   {{0xdb1d56fa,0xd37800f3,0xb0581b99,0x7f8400e4}},	//   _verð, caće_, dpäi, ẽvèv, 
   {{0xdb1c0142,0xb05801f4,0x7e98011a,0x4d2400fb}},	//   _ffrï, epäi, _תסרו, _уянғ, 
   {{0x1ed8bd8e,0x29c01682,0x0c7556fb,0x764401f4}},	//   _حبیب_, ṱa_, _اگرد, ökyn, 
   {{0x644156fc,0x81e02f8b,0x5494001f,0xd7f828f6}},	//   _roni, ন্ট_, _ምሥራቅ_, руч_, 
   {{0x44283e1f,0xb05956fd,0x00000000,0x00000000}},	//   _şa_, späh, --, --, 
   {{0x25bd56fe,0x448826ef,0xb05801f4,0x200c000d}},	//   rcul_, лбин_, ppäh, õdik_, 
   {{0x25bd56ff,0x2ab40327,0xd3783341,0x644001b9}},	//   scul_, _aħbi_, zaće_, _qoni, 
   {{0x64415700,0x62580077,0xa8000724,0xd7c80345}},	//   _voni, _nãoc, _çıqt, _ئومه_, 
   {{0x64415701,0x425409ed,0x7af808fb,0x9f5800fe}},	//   _woni, стот, _åtte, nfrå_, 
   {{0xb9dc044e,0xd3780989,0x2ba40574,0x64415702}},	//   _ኢድ_, vaće_, केता, _toni, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd378248d,0x9f5805ac,0xdb1c02d2,0xddc4054e}},	//   taće_, kfrå_, _herö, ghiş, 
   {{0x9f583167,0x339033ae,0x00000000,0x00000000}},	//   kerö_, _عليز, --, --, 
   {{0x6da15703,0xd3781591,0xfbd0c723,0xada0010b}},	// [22b20] зита, raće_, كتا_, затл, 
   {{0xd3780960,0x7e74017a,0xb0580108,0x00000000}},	//   saće_, snyp, ypäi, --, 
   {{0xff2455cc,0xd37839ae,0xddc40356,0x715801f0}},	//   _умно, paće_, chiş, _арӯс_, 
   {{0xeb9405b0,0xb34400a2,0x00000000,0x00000000}},	//   щих_, luçö, --, --, 
   {{0xdce80421,0xad64008e,0xfb8001d9,0xb4e4000d}},	//   ālēs, _гаяз_, _کۯای, _बटे_, 
   {{0x3eb80010,0x67d06f9f,0x31280092,0xb05801f4}},	//   _kupt_, пошу, _ሲያቀር, tpäi, 
   {{0x6b615704,0x7bdd5705,0x36895706,0x39500006}},	//   _екра, mapu, лсин_, šys_, 
   {{0x7bdd5707,0xdb1c049f,0x6b80045f,0xab60009d}},	//   lapu, _berö, ûnge, _эвсл, 
   {{0x06d41c82,0xb0595708,0x37e40209,0x3eb8054e}},	//   সংগি, späi, _гозг, _lupt_, 
   {{0x7bdd5709,0xb05802f6,0xb89400c6,0xa800013d}},	//   napu, ppäi, _الطع, _çıpt, 
   {{0x539800d6,0xdb1c068c,0x3eb80381,0xe9fc01fb}},	//   рвня_, _ofrí, _nupt_, _xoắn_, 
   {{0x916801fb,0x00000000,0x00000000,0x00000000}},	//   _nữa_, --, --, --, 
   {{0x7bdd570a,0x31686e27,0xdb1c0e78,0x317c00d8}},	//   kapu, ушно_, _gerö, çuz_, 
   {{0x7bdd570b,0xdb1d570c,0xddc40205,0x00000000}},	//   japu, _afrí, thiş, --, 
   {{0x9f59570d,0x91680208,0x00000000,0x00000000}},	//   ngrè_, _bữa_, --, --, 
   {{0x6374011a,0x00000000,0x00000000,0x00000000}},	//   _לגוף_, --, --, --, 
   {{0x1dc43306,0x8bd801a9,0x00000000,0x00000000}},	// [22b30] سْلِ, имас_, --, --, 
   {{0xad9800d7,0x00000000,0x00000000,0x00000000}},	//   _obúv, --, --, --, 
   {{0x39bc01f2,0x200400ac,0xd01010e5,0x00000000}},	//   _ịsa_, əmi_, _فلک_, --, 
   {{0x188802d3,0x79e800e5,0x00000000,0x00000000}},	//   _ንሃገር_, لومہ_, --, --, 
   {{0x7bdc000a,0x6b802776,0xad2400c6,0x3eb800d8}},	//   bapu, ûngb, _ارجو, _zupt_, 
   {{0x91a806c8,0x4e0400bc,0x00000000,0x00000000}},	//   _inā_, ह्रै_, --, --, 
   {{0x656c0589,0x8a180139,0xf7400395,0xc8c800ec}},	//   ºcho, _ковс_, дещо, _چورن_, 
   {{0x24582047,0xdb1d570e,0x656c553e,0x7994033f}},	//   _même_, _perö, úcho, żywa, 
   {{0x69d80368,0x6f18033f,0x04f803d4,0x00000000}},	//   _ieue, łuch, ্ট্ৰ_, --, 
   {{0x69d80438,0xdb1cb74f,0x291d49d0,0x395000cc}},	//   _heue, _verö, _isua_, øyse_, 
   {{0xf8ac39b1,0x69d800d5,0xe7740022,0x2c085347}},	//   _شکه_, _keue, _уажә_, स्यं_, 
   {{0x7bdd570f,0x7de400dd,0xdb1c03ee,0x3eb80276}},	//   zapu, _késő, _terö, _rupt_, 
   {{0x3eb80ecf,0x7bdd5710,0xdb1c0109,0x69d90163}},	//   _supt_, yapu, _herô, _meue, 
   {{0x9f595711,0x200c0209,0xf4842304,0x372402d3}},	//   lgré_, ýdi_, _واوی, _ተርእዮ, 
   {{0x7bdd5712,0xc2c431ed,0xdb1c00d8,0x44240036}},	//   vapu, _بيبي, _jerô, mdl_, 
   {{0x69d95713,0x7bdd5714,0xbdc805f5,0x44255715}},	//   _neue, wapu, ргаж_, ldl_, 
   {{0xd37805ce,0x82343296,0x9f580022,0x00000000}},	// [22b40] maća_, _هرکا, verõ_, --, 
   {{0x21215716,0xefe40020,0xe0589f6d,0x7c940006}},	//   _isih_, ማቸው_, _ایست_, ірац, 
   {{0x20195717,0x291d5718,0x69d95719,0xdb1c05da}},	//   meri_, _asua_, _beue, _nerô, 
   {{0x2019571a,0x7bdd571b,0x212003a2,0x69d8003e}},	//   leri_, sapu, _ksih_, _ceue, 
   {{0x7bdc9390,0x69d803bd,0xcaa40597,0xa965571c}},	//   papu, _deue, أصلي, оица_, 
   {{0xdb1c045f,0x7bdc104d,0x2120b8ff,0xd378b0e8}},	//   _berô, qapu, _msih_, haća_, 
   {{0x69d9571d,0x20193547,0x291c0356,0xad9801e7}},	//   _feue, ieri_, _esua_, _gcúb, 
   {{0x2019571e,0xdb1c000f,0x291c0194,0x69d9571f}},	//   heri_, _derô, _fsua_, _geue, 
   {{0xd3781e31,0x648c2dba,0xdb1c00d8,0xd99800cf}},	//   daća_, jøis, _verõ, _اچات_, 
   {{0xddc41b5c,0x34495720,0x69d95721,0x3a24257c}},	//   jniž, рчин_, _zeue, ldop_, 
   {{0x21215722,0x5334889a,0x92940354,0x69d80051}},	//   _asih_, чент, занц, _yeue, 
   {{0x91c424a5,0x3a2401f5,0x941806be,0x40840022}},	//   чәкл, ndop_, _əzər_, ҟәым_, 
   {{0xe3ac00dd,0xdb1c0109,0xe9fc0051,0x00000000}},	//   ٹری_, _zerô, _hoản_, --, 
   {{0x20195723,0xe3ac7d76,0xd58403e6,0x609801d9}},	//   geri_, عری_, _وێژه_, ٲنِس_, 
   {{0x21200214,0xb05800d0,0x00000000,0x00000000}},	//   _esih_, dpät, --, --, 
   {{0xceb807dd,0x201804ba,0x00000000,0x00000000}},	//   _ҳәа_, aeri_, --, --, 
   {{0x20195724,0x69d95725,0xee3c00a2,0x3a24017a}},	// [22b50] beri_, _reue, _biýr_, ddop_, 
   {{0x20195726,0x69d95727,0x9f580022,0x00000000}},	//   ceri_, _seue, terô_, --, 
   {{0x69d95728,0xee3c010b,0x00000000,0x00000000}},	//   _peue, _diýr_, --, --, 
   {{0x626401d3,0xda780395,0x00000000,0x00000000}},	//   lőor, ояч_, --, --, 
   {{0xdb1d5729,0x69d80137,0x620000dc,0xda080472}},	//   _serô, _veue, ष्टौ_, تينه_, 
   {{0xeaf856b0,0xb8f000d1,0xb0580108,0x9f5800e4}},	//   _پرست_, ركىب, mpäs, perô_, 
   {{0x69d9572a,0x6eac01ad,0x44240427,0xabd00150}},	//   _teue, ंगपु, vdl_, _ﺟﯘﻗﺎ, 
   {{0xe9dc0f99,0x2019572b,0x7af945fb,0x291c0211}},	//   _þú_, zeri_, _åtta, _tsua_, 
   {{0x19580aec,0x1a683cb9,0xd37805ce,0x291c0421}},	//   _даты_, _بینی_, vaća_, _usua_, 
   {{0x201818f7,0x7a3001d5,0xd838009d,0x00000000}},	//   xeri_, lаtа, _мэх_, --, 
   {{0x442400fb,0xe7740014,0xd3780cf4,0x2a7c0010}},	//   rdl_, _بلاں_, taća_, _kjub_, 
   {{0x21200427,0x3ce402fb,0x2c0800dc,0xb058a62c}},	//   _psih_, šovi_, स्तं_, zpät, 
   {{0xd37805ce,0x04c801c8,0x98b800ef,0xb0580108}},	//   raća_, _اوتي_, _ārī_, ypät, 
   {{0x2a7c09a8,0x3ea000b5,0x201841ec,0x147400ec}},	//   _ljub_, _shkt_, ueri_, _ٺاهج, 
   {{0x2019572c,0x437404ac,0x9f5803cd,0xdb1c01e7}},	//   reri_, _מײַן_, nfrø_, _ofrá, 
   {{0xf1bc04d4,0x2a7c0694,0x2120014f,0x75f41b0d}},	//   ldán_, _njub_, _tsih_, müzü, 
   {{0x21200113,0x06d40154,0xb058002f,0x200c01a9}},	// [22b60] _usih_, সূচি, gpäs, еdit_, 
   {{0xf1bd572d,0x2a7c003e,0x20180023,0xee3c0030}},	//   ndán_, _ajub_, qeri_, _chýb_, 
   {{0x2ba40d01,0xacb8002d,0x75f41432,0x76440108}},	//   केला, _brûs, nüzü, ökyk, 
   {{0x6b80019f,0xb0580054,0xa3dc0037,0x00000000}},	//   ûnga, spät, _त़ऽ_, --, 
   {{0x9f440724,0x3a24057b,0xb058023a,0x499000f2}},	//   şmä_, rdop_, mpär, نیفر, 
   {{0x2a7d572e,0x7c5800c6,0x3cd401b9,0x7994012d}},	//   _ejub_, _السر_, _мўҳт, żywo, 
   {{0x8c180c58,0x98a40311,0x00000000,0x00000000}},	//   ঠাখন_, _armă_, --, --, 
   {{0xb8648d6a,0xddc40034,0xe66002bf,0xe72c4609}},	//   _کارو, jniż, етьо, اصو_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe9fc0208,0x66c40205,0x00000000,0x00000000}},	//   _toản_, _sıke, --, --, 
   {{0xe9fc01fb,0xe7340ebe,0xb058000d,0x00000000}},	//   _hoạn_, _неф_, kpär, --, 
   {{0xd5a401d9,0xf1bc00ae,0x636401c6,0xa7a40354}},	//   _قلای, adán_, ярыг_, _экха_, 
   {{0x35a80c58,0x0665572f,0x00000000,0x00000000}},	//   _গ্ৰহ, _تالپ, --, --, 
   {{0x75215730,0xa3b42832,0xb218005c,0x00000000}},	//   _isoz, _ٹاور_, knæg, --, 
   {{0xe9fc0016,0x9f344e19,0xdd980124,0x00000000}},	//   _loạn_, нері, ҧшу_, --, 
   {{0x5f955731,0x5eb412b4,0xddc400a2,0x00000000}},	//   хист, ейст, njiň, --, 
   {{0xefb8044e,0xad980241,0xd838007f,0xee3c0432}},	// [22b70] ዳላይ_, _abúr, _onč_, _diýp_, 
   {{0x75200161,0x09d4193d,0xb0580e03,0xb3080327}},	//   _msoz, दर्य, rpäs, _ཀྱོང_, 
   {{0xa134424b,0x7520022e,0x00000000,0x00000000}},	//   _قریش, _lsoz, --, --, 
   {{0xb058023a,0x4974010b,0x1fa40166,0x6ce420c8}},	//   ppäs, млес, _ярыг, _ніге, 
   {{0x7520513a,0xa3dc4f4b,0x00000000,0x00000000}},	//   _nsoz, तरम_, --, --, 
   {{0x395005ac,0x689003c7,0x75f403e0,0x5d48030d}},	//   øysa_, ریائ, yüzü, _хăшĕ, 
   {{0x75215732,0xaa6407d6,0x6340013f,0xad980241}},	//   _asoz, _етак, rɑnk, _gbúr, 
   {{0x2a7d5733,0xe81c0243,0x9f5821e3,0x3830013d}},	//   _ujub_, _मघवा_, rfrø_, енәр, 
   {{0x9f580158,0xad9800d0,0x2dd001ec,0x00000000}},	//   sfrø_, _zbúr, _ﺘﺘﻤﺤ, --, 
   {{0x43740120,0x75f40205,0x00000000,0x00000000}},	//   думт, tüzü, --, --, 
   {{0x3480152d,0x58840953,0xf1bd5734,0xddc40135}},	//   тгэг, _чыта, rdán_, tniż, 
   {{0xd34001d3,0xd7f8054e,0x00000000,0x00000000}},	//   اہٹی, _umăr_, --, --, 
   {{0x98a4084c,0x66195735,0xb1404979,0xcfb400fe}},	//   _urmă_, meuk, внял, জুমন, 
   {{0x66195736,0x50b55737,0xf09d5738,0x00000000}},	//   leuk, ессу, stàn_, --, 
   {{0x2dc844fc,0x92e80597,0x04c801f7,0x00000000}},	//   _ụlọ_, _فريق_, _اوڪي_, --, 
   {{0x66195739,0xf1bc3b0f,0xa5080327,0xbe140066}},	//   neuk, ndál_, _ཁྱོག_, بورع, 
   {{0x3121573a,0xb059573b,0xb538010f,0x008402e8}},	// [22b80] _адыг, rpär, ֿגעש, _олио, 
   {{0xb059573c,0xada147ac,0x2ca41985,0x00000000}},	//   spär, таул, дкуп_, --, 
   {{0xe9fc0016,0x6619573d,0xb05802f6,0x428c02d3}},	//   _soạn_, keuk, ppär, _ሓቅነት_, 
   {{0x6618003e,0x62980798,0xbdf802e9,0xb218005c}},	//   jeuk, _êxod, _بردا_, rnæg, 
   {{0xe3e009bd,0x661929ee,0xf1bc0548,0xddc40153}},	//   _মানব, deuk, ddál_, snių, 
   {{0x7af80267,0xb8e402c3,0xdb1c02d2,0x00000000}},	//   _åtto, _ईं_, _rfræ, --, 
   {{0xeb944d75,0x75201418,0x56940fca,0xe73416a4}},	//   _жир_, _ssoz, накт, деј_, 
   {{0x66180451,0xacb8045f,0xe5c002e8,0x3ce5573e}},	//   geuk, _krûp, ксьо, šovu_, 
   {{0xe7cce698,0x00000000,0x00000000,0x00000000}},	//   _स्वप, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x661800d5,0xd37000c6,0x3cd002dd,0xb4ac01f9}},	//   beuk, اهج_, _ﺘﻨﺴﺤ, _कळी_, 
   {{0x5f140729,0x66180098,0xdef40023,0xceb80022}},	//   াটাও_, ceuk, ፍእን_, ҟәо_, 
   {{0xacb8006a,0x75209716,0x2d840205,0x00000000}},	//   _asûn, _usoz, ğnek_, --, 
   {{0xa3dc9e51,0x66c403e0,0x24140150,0x626400e5}},	//   तरण_, _hıka, _жошы_, sőop, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf18c010a,0x00000000,0x00000000,0x00000000}},	//   _кιел_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [22b90] --, --, --, --, 
   {{0x661801c4,0xdb1c007c,0x00000000,0x00000000}},	//   zeuk, _ofrä, --, --, 
   {{0xaca001f2,0x661805b8,0xa3dc0d2c,0xad9800ae}},	//   _nrụb, yeuk, तरत_, _gcún, 
   {{0x5928003d,0x5ba4084c,0xdd9001d3,0x00000000}},	//   _རླངས_, труз, اوے_, --, 
   {{0x4f840014,0x66180099,0xb4ac01f9,0x00000000}},	//   _زاگہ, veuk, _कळू_, --, 
   {{0x07a402d7,0xa1580375,0x66180098,0x00000000}},	//   налн, ובדה_, weuk, --, 
   {{0x6619573f,0x69a805d9,0x66c40205,0x00000000}},	//   teuk, _ڀاءُ_, _bıka, --, 
   {{0xa508025c,0x66c405d1,0x1c100490,0x53780023}},	//   _ཁྱུག_, _cıka, ठ्ठल_, _ኢስያስ_, 
   {{0x24980020,0x66195740,0x05745085,0x78a40064}},	//   _ህብረት_, reuk, عابد, _ūkve, 
   {{0x6618ce67,0xe5a001d5,0x22840205,0x3480004e}},	//   seuk, ниқи, dıka_, лгыг, 
   {{0x66195741,0x9f4c1cce,0x54c401ec,0x85b801ec}},	//   peuk, üdü_, нбөб, _елес_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb1c04f3,0xc19800d4,0x00000000,0x00000000}},	//   _ifrå, ятої_, --, --, 
   {{0x7644005b,0x00000000,0x00000000,0x00000000}},	//   ökyv, --, --, --, 
   {{0x6d4829ef,0x66c403ee,0x00000000,0x00000000}},	//   ägan, _yıka, --, --, 
   {{0x22840205,0x00000000,0x00000000,0x00000000}},	//   bıka_, --, --, --, 
   {{0x6e915742,0x628401e1,0x8c080011,0xb05801f4}},	// [22ba0] القا, _ijio, রজনন_, ppäp, 
   {{0x7994033f,0xf2e40811,0xa3dc072e,0x44dc00a2}},	//   żywk, _تکیه_, तरि_, iň_, 
   {{0x2d8d5743,0xb34406ed,0x62740198,0xee2001e0}},	//   üger_, maçõ, rƙoƙ, _өмэп, 
   {{0xb3440261,0x5ea80451,0x00000000,0x00000000}},	//   laçõ, _آگسٽ_, --, --, 
   {{0xa3dc1b6e,0x3f9800e4,0x9f580c86,0xb4dc00af}},	//   तरा_, _hypu_, lgrà_, _तबे_, 
   {{0xeee40502,0xb34406ed,0x3178008f,0x66c40790}},	//   _تغیی, naçõ, האנד, _sıka, 
   {{0xf09005e1,0x44dc0030,0xd8380150,0x00000000}},	//   אנג_, eň_, зэқ_, --, 
   {{0x96341d83,0x35455744,0x7afc6ce1,0x00000000}},	//   тниц, ехов, mupt, --, 
   {{0x7afc0483,0xea74011a,0x24e0009d,0xa50400d8}},	//   lupt, _נגמר_, лцэг, еења_, 
   {{0x54544170,0xdb1c02d3,0x7e740309,0x3f980477}},	//   твот, _ngrë, hiyp, _oypu_, 
   {{0xd2515745,0xb3440120,0x7afc003a,0x7e740309}},	//   لند_, daçõ, nupt, kiyp, 
   {{0x78b95746,0xdb1c0036,0xa75802e4,0x44dc007f}},	//   _hitv, _agrë, _מדבר, bň_, 
   {{0x7afc014f,0xa18473b5,0xf1bc00e5,0x00000000}},	//   hupt, гырл, ldák_, --, 
   {{0x7afd5747,0xb3455748,0xb2700184,0x628401e1}},	//   kupt, gaçõ, _әкиә, _ejio, 
   {{0x61f401e6,0x78b8cc35,0x66c40139,0x15f40037}},	//   ådlö, _mitv, _lıkn, _इयार_, 
   {{0x9e0443be,0xd13400f3,0xe398011a,0x92940354}},	//   лчул, _анић, _משוכ, _шайц, 
   {{0x3f9c09f3,0xb4dc007d,0x200c00cf,0xad9800ae}},	// [22bb0] ýtur_, _तबो_, òdic_, _gcúl, 
   {{0xb34403b7,0x78b80055,0x6b8400d1,0x2bb800ae}},	//   caçõ, _nitv, ىشال, ساطة_, 
   {{0x7afc00dc,0x84780240,0x00000000,0x00000000}},	//   gupt, _ክብሪን_, --, --, 
   {{0x78b80153,0x00000000,0x00000000,0x00000000}},	//   _aitv, --, --, --, 
   {{0x78b800bc,0x48c40124,0x65c001ec,0x38c802f2}},	//   _bitv, тәба, құла, واوی_, 
   {{0x78b800de,0x00000000,0x00000000,0x00000000}},	//   _citv, --, --, --, 
   {{0xdb1c00f2,0x78b95749,0xd7ac0073,0xa27406be}},	//   _ngrè, _ditv, टेलच, _nəşə_, 
   {{0xb3440cfc,0x78b802d0,0xe3e00154,0x85040b24}},	//   zaçõ, _eitv, _মাধব, نوبن, 
   {{0xc485574a,0xdb1d574b,0x9a8517ea,0x78b803b9}},	//   клик, _agrè, _сурл, _fitv, 
   {{0xad9800d2,0xb3440798,0xe7a40046,0x00000000}},	//   _ncúm, xaçõ, _كۇشى_, --, 
   {{0x27e5574c,0x6ab80451,0xb34406ed,0x93580276}},	//   mann_, _kiuf, vaçõ, еряу_, 
   {{0x27e5574d,0xad980120,0x45d40c9e,0xdb1c0158}},	//   lann_, _acúm, _родс, _ufrå, 
   {{0xb34403b7,0x2720002d,0x6d4807de,0xd41c0154}},	//   taçõ, _hűn_, ägal, তাড়ি_, 
   {{0x27e40491,0x6ab9574e,0x7e740113,0x00000000}},	//   nann_, _liuf, wiyp, --, 
   {{0xb34403b7,0xafe02e82,0x2720045f,0xa284221d}},	//   raçõ, росл, _jűn_, _میدو, 
   {{0x27e5574f,0x6ab82b92,0xdcf405be,0xb3440120}},	//   hann_, _niuf, žačk, saçõ, 
   {{0xb34406ed,0xfbd13093,0x27e55750,0xf1bc28be}},	// [22bc0] paçõ, لتا_, kann_, ddáh_, 
   {{0x61e523ba,0x27e55751,0x3f982a5c,0x7afd5752}},	//   _heil, jann_, _typu_, tupt, 
   {{0x61e55753,0x27e55754,0x60c55755,0x78b95756}},	//   _keil, dann_, _huim, _ritv, 
   {{0x60c55757,0x0ba81cbf,0x6ab95758,0x78b80af9}},	//   _kuim, رالى_, _ciuf, _sitv, 
   {{0x27e470cd,0x7afd5759,0xd91405f5,0x78b81ab0}},	//   fann_, supt, удлы, _pitv, 
   {{0x61e5575a,0xcee8397d,0x27e5575b,0x60c5575c}},	//   _leil, _ترین_, gann_, _muim, 
   {{0x78b8488a,0x60c4007b,0x61e406af,0x7afc4376}},	//   _vitv, _luim, _oeil, qupt, 
   {{0xfaa5575d,0x61e5575e,0x6ab8b56d,0xdb1c0b73}},	//   _рабо, _neil, _giuf, _ngré, 
   {{0xd3782d2b,0x27e5575f,0x47e000bd,0x78b84198}},	//   maći_, bann_, _নারী, _titv, 
   {{0x78b81aa7,0xdb1c20ef,0x8478044e,0x27e55760}},	//   _uitv, _agré, _ክብርን_, cann_, 
   {{0x61e55761,0x60c40607,0xe44c6762,0x91c4535f}},	//   _beil, _auim, تضي_, ләпл, 
   {{0xd378071b,0x61e55762,0x60c4304f,0x66c40139}},	//   naći_, _ceil, _buim, _zıko, 
   {{0x61e55763,0x60c40ea3,0xd2515764,0x24e40022}},	//   _deil, _cuim, لنگ_, _амчи_, 
   {{0x5928081f,0xe5a01808,0x3944fecb,0x60c41af3}},	//   _རླབས_, _тичи, ixos_, _duim, 
   {{0x61e55765,0x260c07af,0x6eac0c4c,0xf1bc0548}},	//   _feil, थ्वी_, ंगलु, ydáh_, 
   {{0x61e55766,0x60c55767,0x27e55768,0x7bcc3b9d}},	//   _geil, _fuim, zann_, _afbu, 
   {{0x60c55769,0x27e5190d,0xd3780841,0x23780023}},	// [22bd0] _guim, yann_, daći_, _ብመደብ_, 
   {{0x61e5576a,0x6ab80b23,0xbdb80014,0x00000000}},	//   _zeil, _siuf, رنٕچ_, --, 
   {{0x27e5576b,0x61e40a73,0x39440005,0x00000000}},	//   vann_, _yeil, exos_, --, 
   {{0x27e5576c,0x2720000f,0x60c400b5,0x99d412e3}},	//   wann_, _rűn_, _yuim, لتها, 
   {{0x27e5576d,0x69c804c4,0xee3c01a2,0xa3e000ab}},	//   tann_, rcge, _iný_, _फजल_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x27e5576e,0xa5040075,0x6ab9576f,0xd8740127}},	//   rann_, ھىدە_, _tiuf, جانب, 
   {{0x27e55770,0xa5040131,0xa784006c,0x00000000}},	//   sann_, پىدە_, _یشاو, --, 
   {{0x61e55771,0x27e4753f,0x2720045f,0xe94400f1}},	//   _reil, pann_, _wűn_, _ګرځی, 
   {{0x60c41aa7,0x61e55772,0xe3e0015b,0x27e40194}},	//   _ruim, _seil, _মাহব, qann_, 
   {{0x60c55773,0x290d04ee,0xfeac2d40,0x490001af}},	//   _suim, ltga_, _ﺳﺎﯞﺍ, _түҙг, 
   {{0x60c522eb,0x290c01a9,0x00000000,0x00000000}},	//   _puim, otga_, --, --, 
   {{0x61e55774,0x60c45c2f,0x290d5775,0x00000000}},	//   _veil, _quim, ntga_, --, 
   {{0x290c04cc,0xf42401a9,0x00000000,0x00000000}},	//   itga_, _бошл_, --, --, 
   {{0x61e55776,0xc298656c,0x2d88102c,0xd24c0133}},	//   _teil, _птиц_, _axce_, سۆی_, 
   {{0x60c55777,0x61e404cc,0x7af811ad,0xfe4402dd}},	//   _tuim, _ueil, _åtti, ынбо, 
   {{0x0eb8b46b,0x22415778,0x66c405d1,0xd3780e04}},	// [22be0] туры_, _inik_, _sıkl, vaći_, 
   {{0xefe4001f,0xec740166,0xbb440108,0x00000000}},	//   ዛቸው_, гпу_, лезк, --, 
   {{0xd3780384,0x2d88003a,0x22415779,0xfaa40640}},	//   taći_, _exce_, _knik_, гажо, 
   {{0x39440137,0x66c40790,0x290c01d5,0x00000000}},	//   txos_, _cıkm, ftga_, --, 
   {{0xed551535,0xf9904ddd,0xd37816a3,0x00000000}},	//   _боя_, حبا_, raći_, --, 
   {{0x66c40ab7,0xf7704ff6,0xf728170a,0x4d140166}},	//   _tıkl, یاں_, еций_, _тьют, 
   {{0x224029ef,0xd3780331,0xa8440e76,0x290c022e}},	//   _onik_, paći_, الىم_, atga_, 
   {{0x7c2d577a,0x22400194,0xeb947b0e,0x00000000}},	//   _habr, _nnik_, _сис_, --, 
   {{0x7c2d577b,0x290c074d,0xca741248,0xa3dc0882}},	//   _kabr, ctga_, _туры, तरं_, 
   {{0x2241577c,0x7c2d577d,0xdb1c026c,0xd3700075}},	//   _anik_, _jabr, _sfrù, يۇش_, 
   {{0x7c2d577e,0x36055745,0xa15802dd,0x66c40790}},	//   _mabr, _مواف, қару_, _yıkm, 
   {{0x7c2d577f,0x9294030d,0xee3c0051,0xb178007c}},	//   _labr, рамц, _phým_, nbåg, 
   {{0x667800c8,0x74155780,0xe69050ea,0x224000d7}},	//   _אטאק, _موشا, _الند, _dnik_, 
   {{0x22400429,0x533432eb,0xa3dc0a94,0xee3c032e}},	//   _enik_, _вект, तरः_, _sný_, 
   {{0xe7f44d53,0x3dc0003e,0x31695781,0xeea87a94}},	//   ीलता_, _bgkw_, szcz_, етак_, 
   {{0x7c2d5782,0x290c036b,0xee3c0208,0x00000000}},	//   _aabr, ytga_, _thým_, --, 
   {{0x3cec006d,0x7c2c0064,0x2118036b,0x21a80139}},	// [22bf0] ेंगे_, _babr, _یتیب_, _бәрү_, 
   {{0x66c405d1,0x93bc054e,0x08bc01ec,0x00000000}},	//   _sıkm, bdăt, _ﺠﺎﻫﺯ, --, 
   {{0x7c2c0a55,0xe0d00799,0x9b5802e8,0x00000000}},	//   _dabr, _وزی_, лифт_, --, 
   {{0xad9800d2,0x4e040228,0x7c2c01ab,0xabb000c7}},	//   _mbúz, _өзүб, _eabr, _ҳагә, 
   {{0xd37805ce,0x99d401b9,0xc928009d,0x5974004e}},	//   maću_, صتنا, толж_, йышу, 
   {{0x290d5783,0xabb000c7,0x9bc80150,0xd7f80114}},	//   rtga_, _гагә, _مۇكە_, гућ_, 
   {{0x290d5784,0xf8b40228,0x6e2c0067,0xc7a45a52}},	//   stga_, рөт_, _kacb, шикк, 
   {{0x7c2c0f5f,0xcd540020,0x290c07de,0x6e2c058a}},	//   _zabr, _የመንገ, ptga_, _jacb, 
   {{0x44655785,0x6e2d5786,0x7c2c014f,0x497402e8}},	//   ивив, _macb, _yabr, _тлас, 
   {{0xd378b0e8,0x2240017a,0xa5040131,0x7c2d5787}},	//   haću_, _snik_, پىگە_, _xabr, 
   {{0xb9dc069c,0xacb8000f,0x63c00032,0xd378110c}},	//   _ኣቦ_, _brûz, _һалҡ, kaću_, 
   {{0xd37800f3,0x6e2c0009,0xc5b40a89,0x66800133}},	//   jaću_, _nacb, _кёль, _دیبل, 
   {{0xdb1c0268,0xd37807f5,0x044401c6,0x9f58007c}},	//   _agrì, daću_, _велн, nfrö_, 
   {{0xad9800c6,0xb4f80375,0x1b48010c,0x8338be67}},	//   _gcúi, _יפני, _ነጸብራ, _ачит_, 
   {{0xd5b80724,0x82a401af,0x6e2c0051,0xe3b11147}},	//   _исә_, _какж, _bacb, _ارش_, 
   {{0x6e2c004d,0x00000000,0x00000000,0x00000000}},	//   _cacb, --, --, --, 
  
   {{0x7c2d5788,0x37e4015b,0x5e6402dd,0x3bd4036b}},	// [22c00] _pabr, _নাসর, _ۇندە, لغاس, 
   {{0xc0d40020,0x7c2d5789,0x6e2c01ab,0x3eb063cd}},	//   ካከል_, _qabr, _eacb, smyt_, 
   {{0x7c2d578a,0xd378110c,0x2d840112,0x93bc0356}},	//   _vabr, baću_, ßner_, ldăr, 
   {{0xeb94c1a2,0x7c2c009f,0xeb3000d1,0x00000000}},	//   ших_, _wabr, غىند, --, 
   {{0x7c2d578b,0x93bc0276,0xcaa4027d,0xb178007c}},	//   _tabr, ndăr, حصلي, rbåg, 
   {{0x7c2c0944,0x19c400fd,0x2c00012d,0x00000000}},	//   _uabr, рәңг, _लाएं_, --, 
   {{0xf1bc00e5,0xdb20007c,0x00000000,0x00000000}},	//   ldát_, ötäc, --, --, 
   {{0x66c40205,0x00000000,0x00000000,0x00000000}},	//   _zıkk, --, --, --, 
   {{0xf1bc0646,0x00000000,0x00000000,0x00000000}},	//   ndát_, --, --, --, 
   {{0xb804034c,0x3cfc012c,0xd378009b,0xb7940640}},	//   _خبره, _लिने_, zaću_, _крећ, 
   {{0x7e6402d0,0xbb280092,0x82400023,0x33840395}},	//   _olkp, _ታውቃላ, _ክረምታ, рупв, 
   {{0xdb1c01e7,0xd9f8007a,0x00000000,0x00000000}},	//   _ngrí, ुलित_, --, --, 
   {{0x7641578c,0x94d402dd,0xd37808a4,0xdb1c01c3}},	//   _inoy, _ايتش, vaću_, _sgrì, 
   {{0x2518008d,0xf1bc0548,0x6e2ca887,0xf2c41513}},	//   _סווא, ddát_, _sacb, _ксин, 
   {{0x6e2c01e4,0xd3780cf4,0xe3ac00f7,0x00000000}},	//   _pacb, taću_, _ۉرۉ_, --, 
   {{0x93bc0356,0x66c40205,0x00000000,0x00000000}},	//   bdăr, _sıkk, --, --, 
   {{0xd9041af6,0xd37808a4,0xebc40640,0xa4100b7d}},	// [22c10] _تی_, raću_, аљен, त्वप_, 
   {{0xd3783421,0xb17800b5,0x6e2c0009,0x66c40205}},	//   saću_, rbåd, _wacb, _fıkh, 
   {{0x76400084,0x6e2c3a73,0xca1402e8,0xdef82fe5}},	//   _onoy, _tacb, йджъ, _кыя_, 
   {{0xaa0000d1,0xb178007c,0xf1bc00e5,0x00000000}},	//   تېري, pbåd, bdát_, --, 
   {{0x3cfc006d,0x66c40139,0xc4d40150,0xe8dc0051}},	//   _लिये_, _tıkk, _ﺜﻨﺎﺌ, thực_, 
   {{0x2bc80aa5,0x7641578d,0xf1bc01ed,0x97c40ae5}},	//   _шумо_, _anoy, ldás_, يتىم, 
   {{0xf09c01ab,0x19a800fb,0x9f58007c,0x7c3808ce}},	//   ltàs_, лтәп_, sfrö_, _ótra, 
   {{0xe3e0045e,0xf1bc01d3,0xb05802d1,0xdef40023}},	//   _মাইব, ndás_, rpäy, ግብኦ_, 
   {{0x2afc02e5,0xf09c004e,0x58d40354,0x00000000}},	//   शंकु_, ntàs_, _мотт, --, 
   {{0x764002d0,0xe3c001c0,0x04481d0b,0xb0580108}},	//   _enoy, өрүү, упок_, ppäy, 
   {{0x57cc010f,0x00000000,0x00000000,0x00000000}},	//   _סמאַ, --, --, --, 
   {{0x99800038,0x176822c3,0xf1bc0548,0x74c001e2}},	//   žiť_, _труп_, ydát_, _کښين, 
   {{0xf6500302,0xd5488a91,0x36240014,0xf4840133}},	//   _מצא_, _نجوم_, _دونہ, شایی, 
   {{0x753400c8,0x200d578e,0x93bc0311,0xdb1c01e7}},	//   _לאנד_, üdi_, rdăr, _sgrí, 
   {{0x4425578f,0xa1c4005e,0x147428ee,0xa3b8041c}},	//   mel_, _мұнд, _بانج, _अणि_, 
   {{0x291c0069,0x3b840032,0xcdc401ec,0x00000000}},	//   _opua_, ҙлег, жатқ, --, 
   {{0x291c0070,0x3b841b15,0x7e6400b5,0x4424017a}},	// [22c20] _npua_, әлег, _vlkp, oel_, 
   {{0xa3a852f2,0xc004ccfb,0x80a400f1,0x22840205}},	//   _खरा_, _упок, _دمخن, dıki_, 
   {{0xb9c4cd65,0x291c049b,0xdb241547,0x7e640270}},	//   مقاي, _apua_, توای, _tlkp, 
   {{0x44255790,0x20195791,0x3944e9ea,0x00000000}},	//   hel_, lfri_, йнег, --, 
   {{0x44255792,0x64415793,0xfaa41b74,0x98a400b8}},	//   kel_, _onni, _ҳаво, _asmā_, 
   {{0xbb447724,0x00000000,0x00000000,0x00000000}},	//   _легк, --, --, --, 
   {{0xf1bc01f1,0x291c009f,0xebe01c7b,0xfaa402d5}},	//   ndár_, _epua_, _хосп, _гаво, 
   {{0x4424b104,0xbcf4031c,0x14f80063,0xa6c4007b}},	//   eel_, _བྷོཊ_, анић_, حويل_, 
   {{0x786408a5,0xf98800f2,0x201801e3,0xaa54020c}},	//   _eðva, _صخره_, kfri_, _القا_, 
   {{0x44246945,0xe8d40375,0x2bd800dc,0x68f00118}},	//   gel_, _לומר_, मुपा, ředí, 
   {{0x21200c6a,0x64400175,0x2018005c,0x9f580332}},	//   _apih_, _dnni, dfri_, agrú_, 
   {{0x326479e5,0x64415794,0x466800d6,0x2120020b}},	//   стов, _enni, _крім_, _bpih_, 
   {{0x4424228f,0x2018003d,0x28c800dc,0x76f800cc}},	//   bel_, ffri_, ादयि, _আহিছ_, 
   {{0x44255795,0xe8180a8a,0x20182611,0xdfd400ee}},	//   cel_, प्पा_, gfri_, зоры, 
   {{0xf20406a6,0x94d400ec,0x00000000,0x00000000}},	//   _ляпо, _ايڪش, --, --, 
   {{0xb638037e,0x00000000,0x00000000,0x00000000}},	//   _ｆａ_, --, --, --, 
   {{0x21200048,0xdb1c0137,0x3a240194,0x6440000f}},	// [22c30] _gpih_, _agrà, deop_, _ynni, 
   {{0xb21801bf,0x6f8400db,0x61e00205,0x00000000}},	//   knæk, _гумж, ımle, --, 
   {{0x89d811e6,0x00000000,0x00000000,0x00000000}},	//   لوار_, --, --, --, 
   {{0x44255796,0xaee00055,0xdb1c02d2,0xf81401d9}},	//   zel_, _aiṇe, _afró, ۪سنگ, 
   {{0x44255797,0x2b900014,0xa2bc008f,0x5fd01b76}},	//   yel_, _کیاس, אמאט, तुकल, 
   {{0x44255798,0x66c4002d,0x07082e8e,0x2d880135}},	//   xel_, _lűke, ليتي_, ġieġ_, 
   {{0x44255799,0x2bdc09bb,0xfbcc0451,0x2284002d}},	//   vel_, _प्या, _شڪل_, lűke_, 
   {{0x4425579a,0xd04c03f9,0x00000000,0x00000000}},	//   wel_, _kwaɓ, --, --, 
   {{0xdb1c0f53,0x7af80158,0x3ebc026c,0x395000fe}},	//   _igrá, _åttr, ìtti_, øyst_, 
   {{0xd6d9579b,0x4425579c,0x8458104e,0xe27001e1}},	//   штә_, uel_, ррит_, _ṣàpo, 
   {{0x44241da7,0x98481945,0x201805ac,0x64400051}},	//   rel_, _уята_, vfri_, _vnni, 
   {{0x4425579d,0x7af8d060,0x00000000,0x00000000}},	//   sel_, _ætte, --, --, 
   {{0x44242d61,0xdb1c05d5,0xf46c0023,0x00000000}},	//   pel_, _sfrü, _ብሙሉእ_, --, 
   {{0x6441579e,0x44240978,0xe3e000cc,0x00000000}},	//   _unni, qel_, _মাকব, --, 
   {{0xe81838db,0x2018072b,0x749808a8,0x7e541376}},	//   प्या_, rfri_, _דיספ, отац, 
   {{0x00c81159,0xf1bc810d,0xdb1c00ae,0x6d5c035a}},	//   _клик_, meán_, _ngrá, fyqa, 
   {{0x63a10e6d,0xf1bc0597,0x21200c6a,0xada00395}},	// [22c40] _hynn, leán_, _upih_, датл, 
   {{0x63a1579f,0xdb1d57a0,0x6f040210,0xad8400db}},	//   _kynn, _agrá, bujc, زاقۇ, 
   {{0xddc40311,0xdce42634,0xad9800ae,0xf1bc01e7}},	//   ghiţ, dzią, _scút, neán_, 
   {{0x63a157a1,0x6b800332,0x00000000,0x00000000}},	//   _mynn, únga, --, --, 
   {{0x63a006a3,0x522c010f,0x7c381427,0xf1bc01e7}},	//   _lynn, טואַ, _ótro, heán_, 
   {{0x3a24020b,0x63a006ea,0x7d140158,0xe9442a9f}},	//   seop_, _oynn, mtys, ترمی, 
   {{0x7d1557a2,0xe8900022,0x00000000,0x00000000}},	//   ltys, ьашь, --, --, 
   {{0xf1bc0597,0xddc4054e,0x00000000,0x00000000}},	//   deán_, chiţ, --, --, 
   {{0x7d1557a3,0x7af8041e,0x63a00067,0xa9640354}},	//   ntys, _ættb, _aynn, _дита_, 
   {{0xb86557a4,0x31e038db,0x63a157a5,0x66c4002d}},	//   _بارو, पर्ध, _bynn, _sűke, 
   {{0x63a00f7b,0x7d149da5,0xcfc40154,0xf1bc0332}},	//   _cynn, htys, ্রমন, geán_, 
   {{0x247c0020,0x63a00368,0x7d1557a6,0x00000000}},	//   _እጥረት_, _dynn, ktys, --, 
   {{0x63a002d2,0x6aa00356,0xb0580139,0x00000000}},	//   _eynn, înfi, dqär, --, 
   {{0x6f053d25,0x63a157a7,0x1418007b,0x7d1401bf}},	//   tujc, _fynn, _طيبة_, dtys, 
   {{0x63a00f7b,0x66c4002d,0x630157a8,0x9f34d5d9}},	//   _gynn, _tűke, _قوول, мері, 
   {{0x2ce40135,0x1b200154,0x6d5c0c8c,0x00000000}},	//   _སྦུབ, নটাই_, tyqa, --, 
   {{0x6f04f30e,0xa3dc01f9,0x7d1557a9,0x00000000}},	// [22c50] sujc, तरच_, gtys, --, 
   {{0xacb8006a,0x752157aa,0x2ba4026a,0xc8a800e1}},	//   _asûr, _mpoz, ојев, _चींट, 
   {{0xdeb403f9,0x7d140b21,0x6f04014f,0x357c0092}},	//   _ƴaƴa, atys, qujc, _እስቴት_, 
   {{0xf1ac1d8a,0x5ac801ec,0x9f040133,0x6e400244}},	//   _घरान, ілім_, _کوێو, _تۆرم, 
   {{0xcfbc1d4c,0xa038044e,0x6d48049f,0x7d140076}},	//   _অভিন, _ብምእታ, ågad, ctys, 
   {{0x60dc00d9,0x00000000,0x00000000,0x00000000}},	//   סקונ, --, --, --, 
   {{0x752157ab,0xad9800c6,0x6288003e,0x00000000}},	//   _apoz, _gcúr, éjok, --, 
   {{0x63a157ac,0x7d00000a,0xdb1c00dd,0xea9c00cd}},	//   _rynn, šose, _ugrá, _doṣa_, 
   {{0x63a157ad,0xf8ac04d3,0x4584023a,0x8548023b}},	//   _synn, _ڵکه_, ягив, ёзов_, 
   {{0x63a00652,0xf1bc00c6,0x66c40790,0x37280023}},	//   _pynn, teán_, _bıkt, _ተሞኩሮ, 
   {{0x66c40790,0xb38001c6,0x00000000,0x00000000}},	//   _cıkt, елэл, --, --, 
   {{0xf1bc0597,0x7d1402f6,0x66d401f2,0x63a0062c}},	//   reán_, ytys, _ụkwa, _vynn, 
   {{0xf1bc0597,0x661957ae,0x63a157af,0x2d8c000f}},	//   seán_, mfuk, _wynn, ûgel_, 
   {{0x63a0930a,0x09a80034,0xae680131,0xb1780267}},	//   _tynn, _औरैय, ەشكە_, taår, 
   {{0xbba801b0,0x75200118,0xeff40092,0x00000000}},	//   _करेक, _zpoz, ቋሚያ_, --, 
   {{0x7d1557b0,0xe818d722,0xb17957b1,0xef140a89}},	//   ttys, प्ता_, mbån, ямс_, 
   {{0xf1bc0597,0x7d1413eb,0x01640014,0x66180099}},	// [22c60] neál_, utys, _رُدَ, ifuk, 
   {{0x7d141368,0x66c40790,0xc0040108,0xddc40064}},	//   rtys, _yıkt, _эпок, lkiū, 
   {{0x7d1557b2,0x6d484d03,0xbea41515,0xab2400a7}},	//   stys, ägar, _наок, зоха_, 
   {{0x7d1510de,0x0ae800c6,0xdce40cf4,0xea9c0055}},	//   ptys, تركي_, jzić, _roṣa_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2bd89417,0xa3a80490,0x28f402f6,0xddc403f0}},	//   मुदा, _खरं_, чешь_, chiš, 
   {{0xa81557b3,0x752010bf,0x56940372,0xcc080014}},	//   ستور_, _spoz, макт, _بزُن_, 
   {{0xb1784e9b,0x7bc8029f,0x25ac17da,0x00000000}},	//   dbån, şluğ, _bzgl_, --, 
   {{0x66c40e2d,0x00000000,0x00000000,0x00000000}},	//   _sıkt, --, --, --, 
   {{0xba00001f,0xb21800b5,0x66180083,0xa9a00276}},	//   _ግራ_, nnæv, afuk, _чиуд, 
   {{0xacb8002d,0x92948e38,0x661800b5,0xa6c47701}},	//   _opûn, данц, bfuk, _елха_, 
   {{0xe7048a41,0xad980005,0xbba807f7,0x00000000}},	//   _رسمی, _ocúp, _करैक, --, 
   {{0xb1780fac,0xf1bc0332,0x7f840092,0x00000000}},	//   gaåp, ceál_, _አስከፊ_, --, 
   {{0x61e00259,0x257000cf,0xa11400d1,0x00000000}},	//   ımla, _سۇپس, رۈپت, --, 
   {{0x25ad57b4,0xb218005c,0x54b401af,0x00000000}},	//   _zzgl_, dnæv, _нәүф, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xddc4000a,0xd904020e,0xd7cc0073,0x00000000}},	// [22c70] thiš, _حی_, ाशाच, --, 
   {{0xdb1c0267,0xb218005c,0x00000000,0x00000000}},	//   _ogrä, gnæv, --, --, 
   {{0xaac4be91,0x3ea00010,0x3e6c00d7,0x06cc01ec}},	//   ستان, _fkkt_, _sýte_, _ﻗﺎﻋﺩ, 
   {{0x37e400bd,0xdb1c634d,0x00000000,0x00000000}},	//   _নাগর, ázán, --, --, 
   {{0xdb1c01c7,0xad9801e7,0x66181141,0x00000000}},	//   _agrä, _gcúp, vfuk, --, 
   {{0xad980241,0xc7a400d6,0x07a41f91,0x00000000}},	//   _adúg, милк, малн, --, 
   {{0xdce40034,0x66181cea,0x00000000,0x00000000}},	//   dzię, tfuk, --, --, 
   {{0xa46802d3,0x7af808a7,0xa3dc0073,0x66c403e0}},	//   _ስለዘሎ_, _ætta, धुन_, _sıks, 
   {{0x661957b5,0xdce40cf4,0x48143e4f,0x00000000}},	//   rfuk, rzić, _омас, --, 
   {{0xe5a00131,0x38b000c7,0x00000000,0x00000000}},	//   миқи, târe_, --, --, 
   {{0x661957b6,0x981402da,0x28c800cd,0x00000000}},	//   pfuk, _سبلا, ादवि, --, 
   {{0xd04d1c46,0x38b03cb7,0xcfc4015b,0xb1780450}},	//   _kwaɗ, râre_, ্রান, rbån, 
   {{0x66c403ee,0x25a80150,0xbba828e0,0xb1785522}},	//   _fıkr, _اداي_, _कर्क, sbån, 
   {{0xacb8002d,0x036801a9,0x00000000,0x00000000}},	//   _spûn, _милк_, --, --, 
   {{0x4f9557b7,0x8284007b,0x3f681fbe,0xa2480244}},	//   ерту, _يجعل, циво_, _فیدل_, 
   {{0xe05804fb,0x8fd4008e,0xb80400fe,0x00000000}},	//   _کیست_, _җәрә, ল্পত_, --, 
   {{0xc1b89b83,0xb21800b5,0x8c0803d4,0x1d840133}},	// [22c80] _ظابط_, tnæv, ৰজনন_, ردرێ, 
   {{0x2a7c00e8,0xc0f8001f,0x6454004e,0x3f9c0254}},	//   _amub_, ላከል_, _òxid, ütus_, 
   {{0x20d557b8,0xb218005c,0x8c4000c7,0x00000000}},	//   _häi_, rnæv, ыҵре, --, 
   {{0x20d400c5,0x4a740137,0xb218005c,0xa3a80037}},	//   _käi_, нычт, snæv, _खरई_, 
   {{0x20d418db,0x2bdc09ab,0x58440022,0x209c00b8}},	//   _jäi_, _प्वा, нҭав, _ṛṣid, 
   {{0x20d40a40,0x4c340262,0x16840133,0x00000000}},	//   _mäi_, _пэст, کاتێ, --, 
   {{0x656c01ab,0x00000000,0x00000000,0x00000000}},	//   ùchn, --, --, --, 
   {{0xa3c005b3,0x66c40166,0x27b00022,0xdce40210}},	//   ्शन_, _sıkr, тәус, wzię, 
   {{0x20d40793,0x00000000,0x00000000,0x00000000}},	//   _näi_, --, --, --, 
   {{0xc9540166,0x2db4011a,0x00000000,0x00000000}},	//   _ятсы, ולפן_, --, --, 
   {{0xdb1c0036,0x00000000,0x00000000,0x00000000}},	//   _ugrä, --, --, --, 
   {{0x20d40221,0x47580276,0x2aa4000d,0x00000000}},	//   _bäi_, _эруя_, tõbi_, --, 
   {{0xf1a90404,0xd8380427,0xcfc403d4,0x66c4013d}},	//   تاده_, _kač_, ্ৰান, _tıkr, 
   {{0x20d40a40,0x398001a9,0xb80c033f,0xdedc0023}},	//   _däi_, _kаsb_, सलिम_, ንገን_, 
   {{0xd83808a4,0xdfd45f69,0x00000000,0x00000000}},	//   _mač_, тосы, --, --, 
   {{0xd838007f,0x2258007b,0x9e0400cf,0x00000000}},	//   _chčz_, _يجيب_, кчул, --, 
   {{0xd130129e,0xb3d0012d,0xefc82ec9,0x00000000}},	// [22c90] _صمد_, _सलाख, _мунк_, --, 
   {{0xd83801ef,0x00000000,0x00000000,0x00000000}},	//   _nač_, --, --, --, 
   {{0x95940023,0x21580066,0x00000000,0x00000000}},	//   _ውድብን_, _فجیع_, --, --, 
   {{0x2bdc1562,0xdd140038,0x00000000,0x00000000}},	//   _प्रा, _súťa, --, --, 
   {{0x5ed4015b,0xd83957b9,0xa8500166,0x00000000}},	//   ধীদে, _bač_, кедә, --, 
   {{0xd7342440,0x00000000,0x00000000,0x00000000}},	//   _ኮሚሽነ, --, --, --, 
   {{0x46a43529,0x8ccc00dc,0x00000000,0x00000000}},	//   накв, तदवो, --, --, 
   {{0x2a7c0066,0xcd700092,0xcc840133,0x3e6d57ba}},	//   _umub_, _ለመንገ, _تۆڕه_, _kýta_, 
   {{0x2bc14c35,0x683000c7,0x00000000,0x00000000}},	//   _वृता, _имаӡ, --, --, 
   {{0xb17803cd,0x14000022,0xe8c801f9,0x00000000}},	//   rbål, аҧшн, ादीच, --, 
   {{0x20d404c4,0x68f800fe,0xca3801e4,0x3e6c0413}},	//   _säi_, _hvud, _kaŝ_, _lýta_, 
   {{0xd8380306,0x20d401f4,0x85743893,0x00000000}},	//   _zač_, _päi_, _плех, --, 
   {{0x3e6c09cc,0xa5640345,0xcfe000fe,0xd6184710}},	//   _nýta_, _تدان, _বয়ন, _آتما_, 
   {{0x2bdc547d,0x00000000,0x00000000,0x00000000}},	//   _प्ला, --, --, --, 
   {{0x62580798,0x20d401c7,0xd7f80208,0x2aa40254}},	//   _mãoz, _wäi_, _hoăc_, lõbu_, 
   {{0x68f80083,0x3e6c06ea,0x38c40241,0x20d41b99}},	//   _ovud, _býta_, _kírì_, _täi_, 
   {{0x68f81418,0x62880129,0x98a40153,0xdd4c0092}},	// [22ca0] _nvud, éjou, _esmę_, _አዘጋጆ, 
   {{0x69d957bb,0xbca557bc,0xe8dc0051,0x3198011a}},	//   _afue, رماي, chức_, _מבפנ, 
   {{0x68f80337,0xf0600276,0xd8380427,0x00000000}},	//   _avud, _скэп, _rač_, --, 
   {{0xfce557bd,0x68f80433,0xb2185c04,0xd8380010}},	//   _помо, _bvud, lnær, _sač_, 
   {{0xa9640fcb,0xd8380fb7,0xb218318c,0x3e6c03b2}},	//   ница_, _pač_, onær, _gýta_, 
   {{0x69d957be,0x62580798,0xe940004b,0x6aa00356}},	//   _efue, _cãoz, انوپ, înfr, 
   {{0xab2557bf,0x7bcd57c0,0x68f81418,0xb6c557c1}},	//   _пора_, _igbu, _evud, нсий, 
   {{0xb684075e,0x00000000,0x00000000,0x00000000}},	//   ةشتى, --, --, --, 
   {{0x394557c2,0x98c40022,0xdb1c007b,0xf09c004e}},	//   _янаг, _аиаҵ, _ngrú, dràn_, 
   {{0x998002d5,0x00000000,0x00000000,0x00000000}},	//   žių_, --, --, --, 
   {{0xdb1c0005,0x7bcc01f2,0xb21800cc,0x00000000}},	//   _agrú, _mgbu, dnær, --, 
   {{0x69d80332,0xf1a41f39,0x45400022,0xd0d4011c}},	//   _xfue, ергн, уҕәа, комъ, 
   {{0x7bccec6e,0xf4841575,0x06640a52,0x38c401e1}},	//   _ogbu, _пукн, _جالپ, _gírì_, 
   {{0xf09c067c,0x05b401ec,0xb218143a,0x00000000}},	//   aràn_, _جگىت_, gnær, --, 
   {{0x53342ae3,0xc90c0316,0x5f943298,0x3e6c4eb4}},	//   _рейт, _सम्म_, гирт, _sýta_, 
   {{0x7bcd57c3,0xd25000aa,0xb21957c4,0x3e6c00d0}},	//   _agbu, _څنګ_, rnæs, _pýta_, 
   {{0x7e60023a,0x2bc03409,0x00000000,0x00000000}},	// [22cb0] öopa, वेना, --, --, 
   {{0xf09c0022,0x9c380114,0xf1a835aa,0x00000000}},	//   kuài_, нпут_, _واکه_, --, 
   {{0x68f80989,0x69d802c4,0x7af805f7,0x00000000}},	//   _svud, _pfue, _ættl, --, 
   {{0x7bcc0521,0x636801ed,0x2bd083e3,0x5f7403e6}},	//   _egbu, lönö, _तलवा, _ڤایر, 
   {{0x625800d8,0x00000000,0x00000000,0x00000000}},	//   _pãoz, --, --, --, 
   {{0xcd70001f,0x38c40241,0x38b000e4,0x00000000}},	//   _ለመናገ, _rírì_, târa_, --, 
   {{0xd8740f87,0x00000000,0x00000000,0x00000000}},	//   دانب, --, --, --, 
   {{0xabb000c7,0x69d801c7,0x9e840023,0x99d4007b}},	//   _ааҳә, _ufue, _ነብስና_, _متكا, 
   {{0x38b0145e,0xdef40092,0x493801f4,0x00000000}},	//   sâra_, ግብና_, _юзаю_, --, 
   {{0x4464ba7d,0x290d57c5,0x58d41b10,0x63b00daf}},	//   твов, muga_, _софт, ләйх, 
   {{0xfbd0025f,0xdce4008f,0xf09c0ba1,0xb218143a}},	//   יתי_, dziĝ, tràn_, vnær, 
   {{0x290c0421,0x00000000,0x00000000,0x00000000}},	//   ouga_, --, --, --, 
   {{0x290d57c6,0xb2180217,0x00000000,0x00000000}},	//   nuga_, tnær, --, --, 
   {{0x290c096b,0xc4c4025c,0x00000000,0x00000000}},	//   iuga_, _གངྒཱ, --, --, 
   {{0xb2180ac8,0x290d57c7,0x6d4801e3,0x00000000}},	//   rnær, huga_, ågan, --, 
   {{0x290c00af,0x6d400882,0xb60557c8,0xb2180b34}},	//   kuga_, ānan, mpáñ, snær, 
   {{0x62840428,0xfd940032,0x290d57c9,0x5108074d}},	// [22cc0] _imio, төнә_, juga_, _пĕтĕ, 
   {{0x290d57ca,0x20040006,0x00000000,0x00000000}},	//   duga_, ėmis_, --, --, 
   {{0xbb48a9e7,0xb9c40116,0x00000000,0x00000000}},	//   بلان_, چقاي, --, --, 
   {{0x290d57cb,0xe8dc01f2,0xf988b94d,0x39e001e0}},	//   fuga_, _erọn_, وناي_, рҙағ, 
   {{0x290d57cc,0x978400f2,0x1944035b,0x2bc001f9}},	//   guga_, گیاه, ыҭан, वेबा, 
   {{0xa3c07db3,0x7bcc0521,0x3178010f,0x92cc0154}},	//   ्शा_, _ugbu, ואנד, শীয়_, 
   {{0x62840086,0x290c03ef,0xe810000d,0xc5e800eb}},	//   _omio, auga_, _ठारा_, _গাজা_, 
   {{0x290d57cd,0x96340556,0x3e6c0306,0x32d80055}},	//   buga_, униц, _mýto_, _nīya_, 
   {{0xe60c71f1,0x290c0205,0xa5d40116,0x00000000}},	//   زشي_, cuga_, خبىر_, --, 
   {{0x628557ce,0xf65005d9,0xdb1c0192,0xe87000db}},	//   _amio, _ھئا_, _sgrù, _ۅچۉگ, 
   {{0xd2505a1a,0x64a003b7,0xacb8002d,0x82fc031c}},	//   مند_, раќа, _spûk, _དྷཱུ_, 
   {{0xa778008f,0x35f800f2,0xb5240354,0xf5040024}},	//   _קראפ, _آراد_, _аькк, _аздо, 
   {{0x7e740175,0x00000000,0x00000000,0x00000000}},	//   dhyp, --, --, --, 
   {{0xa3d157cf,0x62840295,0xa3a80490,0x7c3c01f5}},	//   _кошч, _emio, _खरच_, jdpr, 
   {{0xdef957d0,0x3ce005e4,0x290c02e3,0x7c3c0fac}},	//   кыт_, _atkv_, zuga_, ddpr, 
   {{0x3cfc1533,0x290d57d1,0x636801d3,0x7c3c51a0}},	//   _लिखे_, yuga_, sönö, edpr, 
   {{0x7c3c0d27,0xf1bc011f,0x290c004e,0x4cb8005b}},	// [22cd0] fdpr, ydáy_, xuga_, елаю_, 
   {{0x290c633d,0xf08003e6,0x7c3c01f5,0x3ce00051}},	//   vuga_, _ئیسپ, gdpr, _dtkv_, 
   {{0x290c015c,0x6ec4007b,0xcfac00cc,0x00000000}},	//   wuga_, _لتحق, _খলকন, --, 
   {{0x290d57d2,0x998402d5,0xd94c001f,0x49741cd6}},	//   tuga_, _namų_, _ሁላችን, ллес, 
   {{0xe8dc001e,0x290c0b23,0x1a0400fa,0xba9400ec}},	//   _trọn_, uuga_, рпім, دالڪ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x290d57d3,0xd7c80330,0x6d00012d,0xa4f400f2}},	//   suga_, نوهه_, _लिँग_, چکتر_, 
   {{0x290d57d4,0xe66000c7,0xddc400a2,0x00000000}},	//   puga_, реиҿ, njiş, --, 
   {{0x9a84006c,0xaca0063f,0x62840194,0x99840064}},	//   _турл, _nrịb, _rmio, _damų_, 
   {{0x628403d5,0x4614004b,0x18b80139,0x00000000}},	//   _smio, _څوار, _агуы_, --, 
   {{0x461557d5,0xd7f8404b,0x7e7557d6,0x00000000}},	//   _موار, _шут_, yhyp, --, 
   {{0x6d006f64,0xc0e557d7,0x28c8012c,0xe6c4027d}},	//   _लिंग_, ломк, ादकि, _شتاي, 
   {{0x2bc017c6,0xc6002ef1,0x3e6c0419,0x00000000}},	//   वेता, ोलीय_, _sýto_, --, 
   {{0xd09557d8,0x7e74045a,0xd4980ce8,0xa4400244}},	//   ашсы, whyp, _үрә_, _ئێدو, 
   {{0xafe001b9,0x9f580240,0x7e74003a,0x78a4032e}},	//   сосл, marë_, thyp, _íkve, 
   {{0xa3dc43aa,0x9f580023,0x93bc0311,0x7c647577}},	//   धुर_, larë_, sfăc, گارل, 
   {{0x261849fc,0x65780e78,0xfce40120,0xfaa40107}},	// [22ce0] _यानी_, nzuh, уозо, қадо, 
   {{0x7e741250,0x9f580023,0x7c64185e,0x7af802d2}},	//   shyp, narë_, دارل, _ættk, 
   {{0x7c3d0d0a,0x6578002f,0x7e740857,0xbb8431e4}},	//   rdpr, hzuh, phyp, دلاي, 
   {{0x6ab957d9,0xa81400d1,0x00000000,0x00000000}},	//   _chuf, ۇتىر_, --, --, 
   {{0x6ab957da,0x26e0013f,0xa03802d3,0xd7f409a5}},	//   _dhuf, ɔsoɔ_, _ብምንታ, азлы, 
   {{0x9f580240,0x00000000,0x00000000,0x00000000}},	//   jarë_, --, --, --, 
   {{0x6ab80943,0x9f5802d3,0x2bc08004,0x00000000}},	//   _fhuf, darë_, वेदा, --, 
   {{0xfaa43971,0x19c40058,0x65780e78,0x6d4801bf}},	//   _сабо, _кәлг, fzuh, ægag, 
   {{0x37e557db,0x091800c7,0x9f580023,0x00000000}},	//   _бозг, _ацхы_, farë_, --, 
   {{0xd5c019e5,0xc7640075,0x9f580240,0x7bdc01e4}},	//   शेषज, _ھالى, garë_, ncpu, 
   {{0x5fa4069f,0x7afc02c4,0xad9801e7,0xc76405a9}},	//   _खुलल, nspt, _ndún, _پالى, 
   {{0xd7f801fb,0x6ab80240,0x44b400cf,0x00000000}},	//   _xoăn_, _xhuf, лбөс, --, 
   {{0x57a40184,0x418457aa,0xd2501e2f,0xd0d40395}},	//   _сыҡҡ, атрғ, منگ_, рогъ, 
   {{0xdeec0023,0x00000000,0x00000000,0x00000000}},	//   ህሪኡ_, --, --, --, 
   {{0xb4c005f9,0xfc6402d3,0x6d400882,0x9f580ffb}},	//   ्दी_, _ዘረጋግ, ānam, narè_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6ab80368,0xb7f41a47,0x0bf4117e,0x00000000}},	// [22cf0] _rhuf, ीणाम_, ипаю, --, 
   {{0x6ab957dc,0xd01135c6,0xf1c00024,0xea9c00b8}},	//   _shuf, _بلد_, ėšė_, _kaṇa_, 
   {{0xdd940220,0xdef801e0,0x65780327,0x00000000}},	//   _ғары, _йыя_, zzuh, --, 
   {{0xb4c05219,0x9f58026c,0x99d40214,0x00000000}},	//   ्दु_, darè_, متها, --, 
   {{0x6ab80084,0xa3a80316,0x7fa404d3,0x0c040014}},	//   _vhuf, _कुन_, _ملیۆ, _پوزُ, 
   {{0x1bd4cf02,0x2bd80b7c,0xee3c010b,0xea54010b}},	//   _горя, मुखा, _haý_, _өзгә_, 
   {{0x19a823c9,0x9f5957dd,0x00000000,0x00000000}},	//   ктәп_, garè_, --, --, 
   {{0xee3c00ee,0x599c0092,0x6578002f,0xddc40064}},	//   _jaý_, ቃላችሁ_, tzuh, lkiš, 
   {{0xb4c04284,0x9f5957de,0xf1c401ad,0x070897d1}},	//   ्दू_, tarë_, रेमन, ريکي_, 
   {{0x03247f55,0x291c0086,0xddc40006,0x9f580100}},	//   адон, _iqua_, nkiš, barè_, 
   {{0xe70803e6,0x32d800e8,0x9f58026c,0xee3c0030}},	//   _ستان_, _cëy_, carè_, _akým_, 
   {{0x32d800e8,0x82a428fc,0x9f580200,0x00000000}},	//   _dëy_, рамж, sarë_, --, 
   {{0x9f5957df,0xd17557e0,0x201c007c,0x00000000}},	//   maré_, быры, _övik_, --, 
   {{0x26ccc437,0x9f5957e1,0x44e8010e,0xb4f8011a}},	//   _higo_, laré_, _iº_, _ספצי, 
   {{0x26cc0a03,0xee3c00ee,0xea9c002b,0x5348030d}},	//   _kigo_, _baý_, _gaṇa_, _йăрă, 
   {{0x26cc23db,0x7af809f3,0x9f5957e2,0x82355497}},	//   _jigo_, _ætti, naré_, _ضربا, 
   {{0x291c0218,0xbdc801c6,0x00000000,0x00000000}},	// [22d00] _nqua_, тгаж_, --, --, 
   {{0x26cd57e3,0x22400158,0x9f587541,0xec7557e4}},	//   _ligo_, _haik_, haré_, апу_, 
   {{0x26cc0407,0x32d81bce,0x2d8c002d,0x7bdc00b5}},	//   _oigo_, _xëy_, ûger_, rcpu, 
   {{0x9f580407,0xee3c010e,0x3944004e,0x8b6400ae}},	//   jaré_, _gaý_, инег, حاكم, 
   {{0x44e81a36,0x224157e5,0x9f5957e6,0x7a4401d3}},	//   _nº_, _maik_, daré_, jétő, 
   {{0x201957e7,0x22402af2,0x26cd57e8,0x37053992}},	//   ngri_, _laik_, _aigo_, ачив, 
   {{0x26cd57e9,0x291ced23,0x9f580de2,0xb1780efa}},	//   _bigo_, _equa_, faré_, lbåt, 
   {{0x224157ea,0xeb9400d6,0x44e80789,0x26cc0301}},	//   _naik_, _тис_, _bº_, _cigo_, 
   {{0x26cc9ace,0x44e800e4,0x9f580ffb,0x32d80694}},	//   _digo_, _cº_, sarè_, _sëy_, 
   {{0xb4c157eb,0x26cd57ec,0x9f58026c,0x2bc061f2}},	//   ्दे_, _eigo_, parè_, वेवा, 
   {{0x224027ed,0x9f582a4a,0x394402d5,0x06dc0729}},	//   _baik_, baré_, lvos_, ণীবি, 
   {{0xb17800cc,0x453000db,0x4424032e,0x4ad8000d}},	//   kbåt, تۉۇر, afl_, _बंसव, 
   {{0x224157ed,0xd5b04c8b,0x6d4157ee,0x39440005}},	//   _daik_, _عفت_, ānak, nvos_, 
   {{0x4424009a,0x26cc009f,0x32d8002e,0xee3c010e}},	//   cfl_, _zigo_, _tëy_, _saý_, 
   {{0x06fc012c,0x3eb04606,0x22404498,0xcf140eac}},	//   žívá_, flyt_, _faik_, াব্দ_, 
   {{0x26cc058a,0x39450031,0x2019201b,0x00000000}},	//   _xigo_, kvos_, agri_, --, 
   {{0xddc40552,0xdb1c0034,0xb1786525,0x91680051}},	// [22d10] tkiš, _ogró, gbåt, _dựa_, 
   {{0x9f58dd69,0x2240a0f0,0xee3c0432,0x00000000}},	//   zaré_, _zaik_, _waý_, --, 
   {{0x291c0354,0x3944003a,0x9f5800f2,0x9cc957ef}},	//   _squa_, evos_, yaré_, рыта_, 
   {{0xdb1c09c2,0x9f5800db,0x2bc001bc,0xbb780150}},	//   _agró, xaré_, वेषा, _ﹼﺒﻌﻪ_, 
   {{0x26cd57f0,0xf09c004e,0x9f589223,0xddc40064}},	//   _rigo_, quàs_, varé_, pkiš, 
   {{0x26cd57f1,0xb4c01d27,0x10a001ec,0x59d400d1}},	//   _sigo_, ्दो_, _ﺍﻳﺪﯨ, مغۇر, 
   {{0xb4c002f8,0x26180574,0x9f5957f2,0x26cd57f3}},	//   ्दै_, _यादी_, taré_, _pigo_, 
   {{0x29840598,0x9f5957f4,0x9a8405f5,0x201828b5}},	//   _кызг, karî_, _дуул, zgri_, 
   {{0x26cc36ed,0xc484cb67,0x9f5957f5,0x497557f6}},	//   _vigo_, йлик, raré_, _улас, 
   {{0x26cc01c8,0x9f5957f7,0xb21801a8,0x224157f8}},	//   _wigo_, saré_, nhæf, _saik_, 
   {{0x42c93b99,0x224157f9,0x69c82314,0x26cd57fa}},	//   лгон_, _paik_, _तृती, _tigo_, 
   {{0x7d000024,0x442557fb,0x290c8477,0x00000000}},	//   šosi, sfl_, orga_, --, 
   {{0x2240abe6,0x044400ee,0x200c00d8,0x3eb0017a}},	//   _vaik_, _гелн, ódio_, vlyt_, 
   {{0xafe068e4,0xa08402dd,0xb178143a,0x290c1eca}},	//   зорл, іңне, vbåt, irga_, 
   {{0xb21804ce,0x22400ac5,0x8ed80212,0x290c035c}},	//   dhæf, _taik_, ифту_, hrga_, 
   {{0x9f58025a,0x39440024,0xbda400c6,0xb178a075}},	//   barî_, yvos_, محذو, tbåt, 
   {{0xed5557fc,0x61e557fd,0xb9e4005e,0xfc2800ee}},	// [22d20] бот_, _ifil, ەستى, лжак_, 
   {{0xb1789c2a,0xa3a82f0a,0x44f803d4,0x3eb0017a}},	//   rbåt, कअप_, _আমাক_, slyt_, 
   {{0xbea4035b,0xdb1c00db,0xdb74001f,0x3f6957fe}},	//   _ганк, _agrò, _በዚያም_, _сино_, 
   {{0x9a140075,0x290c022e,0x2010012d,0x403401af}},	//   تېرغ, frga_, łnią_, _теүс, 
   {{0x19580efb,0x61e5078a,0x2c6c0205,0x39440108}},	//   ралы_, _mfil, _bıdı_, uvos_, 
   {{0x394557ff,0x7e640165,0xa9640063,0x00000000}},	//   rvos_, _hokp, сиља_, --, 
   {{0x39455800,0xb5a40323,0x61e55801,0xbee40073}},	//   svos_, өрий, _ofil, _ओझोन_, 
   {{0x61e4067c,0x3e6c79a2,0x290c0f89,0xb4c000cd}},	//   _nfil, _býti_, brga_, ्द्_, 
   {{0x7e64fe8c,0x7d140548,0xf628030c,0x00000000}},	//   _mokp, nuys, _ەستى_, --, 
   {{0x10a00150,0xe56c00ae,0x00000000,0x00000000}},	//   _ﺍﻳﺮﯨ, عطي_, --, --, 
   {{0x940c016b,0x7d1401f5,0xe6900451,0x925801c6}},	//   dodɔ_, huys, _کلند, аант_, 
   {{0x61e40175,0x04f805d9,0x7d140309,0x7af80252}},	//   _cfil, _چونڊ_, kuys, _ættu, 
   {{0x61e40005,0xe5a00022,0x2bac2052,0x00000000}},	//   _dfil, _еици, _जुना, --, 
   {{0x994c0030,0x7d140790,0x2518010f,0x9ccc01ec}},	//   _vôňa_, duys, _עווא, _ﺒﺎﻻﻋ, 
   {{0x61e400a9,0x7640003e,0x7e655802,0xae2801c0}},	//   _ffil, _kaoy, _bokp, лцаж_, 
   {{0x5f94326d,0xb21803b2,0x290d5803,0x00000000}},	//   чист, giæt, yrga_, --, 
   {{0x7e640158,0x261801ad,0x290c022e,0x6ce401ec}},	// [22d30] _dokp, _यासी_, xrga_, сібе, 
   {{0xf21c0cb4,0x9d195804,0xebc40640,0xaae400c6}},	//   _भाड़_, софт_, бљен, مسؤو, 
   {{0xb2180008,0xdb1c01ab,0x290c003e,0xddd445d8}},	//   rhæf, _sgrò, wrga_, _çaşa, 
   {{0x7d14089c,0x290c3ae4,0x764004ce,0x61e4036e}},	//   buys, trga_, _naoy, _xfil, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x76400076,0x26180073,0x0c7400f2,0x290c0327}},	//   _aaoy, _याही_, _بگرد, rrga_, 
   {{0x76401aac,0x60c0017a,0x2c6c0205,0x290c01a9}},	//   _baoy, ïmmi, _vıdı_, srga_, 
   {{0xc4e47d60,0xb21803b2,0x00000000,0x00000000}},	//   ожий, nhæd, --, --, 
   {{0x76b40032,0x67200010,0x6aa8005c,0x00000000}},	//   өләр_, stnj, mogf, --, 
   {{0x61e55805,0x44894ecb,0x98740276,0x26180073}},	//   _sfil, рбон_, _елуц, _यावी_, 
   {{0xe7ec0574,0x61e418f7,0xf1c40db3,0x0ce40154}},	//   _घ्या_, _pfil, रेसन, _ফটোত, 
   {{0x17688867,0xf1bc0789,0x6aa80810,0xf6540107}},	//   _уруп_, rfán_, nogf, _мехӯ, 
   {{0xd5480517,0xd174273e,0x3cdc012d,0xe3b00101}},	//   _هجوم_, пыры, _कंधे_, _کرش_, 
   {{0x66182641,0xb17803cd,0x00000000,0x00000000}},	//   lguk, tbår, --, --, 
   {{0x6440e690,0x7e655806,0x76415807,0x6aa80fac}},	//   _iani, _pokp, _yaoy, kogf, 
   {{0x64415808,0x61e4e3cb,0xfde95809,0x15b00075}},	//   _hani, _ufil, рдак_, _تەۋس, 
   {{0x6441580a,0xa3c00cb4,0x7fd41feb,0x2bac0c2e}},	// [22d40] _kani, ्शक_, _міні, _जुबा, 
   {{0x64402e95,0x66180d04,0x7e641028,0x73300075}},	//   _jani, hguk, _wokp, _رىۋا, 
   {{0x7e641028,0x7d140205,0x00000000,0x00000000}},	//   _tokp, suys, --, --, 
   {{0x6441580b,0xee34651a,0x6aa80174,0xb219580c}},	//   _lani, _дню_, gogf, liær, 
   {{0x64406eea,0x78a80b4f,0xe9d400fb,0x00000000}},	//   _oani, tofv, әкә_, --, 
   {{0x6441580d,0xb9000bae,0x9f580548,0x8c94dcc6}},	//   _nani, _नं_, marâ_, _ерсі, 
   {{0xe3a405d3,0x7c2c025c,0x19580032,0xeb940982}},	//   _آر_, _ibbr, раһы_, _дир_, 
   {{0x644022a9,0x6619580e,0x6d400882,0xba1847ea}},	//   _aani, gguk, ānav, _خيرا_, 
   {{0x6441580f,0x261802e5,0x9f595810,0x39940345}},	//   _bani, _यारी_, darí_, _بڵاگ_, 
   {{0x64415811,0x66195812,0x64a00798,0xed540115}},	//   _cani, aguk, мања, קסיז_, 
   {{0x66180d04,0x64440109,0xb2185522,0x9f595813}},	//   bguk, ôjia, diær, harâ_, 
   {{0x64404d79,0x9f5800e4,0x00000000,0x00000000}},	//   _eani, karâ_, --, --, 
   {{0x64415814,0x7980172b,0x7c2c0731,0x759405d9}},	//   _fani, nzow, _obbr, _بجاء, 
   {{0x64415815,0xdfd80801,0x79800099,0x3e6c02f0}},	//   _gani, жът_, izow, _mýtu_, 
   {{0x6e655816,0x00000000,0x00000000,0x00000000}},	//   отаж, --, --, --, 
   {{0x7c2d5817,0xf1a80133,0x9f6001d3,0xdb0801e1}},	//   _abbr, _پابه_, úrás_, _àlùw, 
   {{0xd90432de,0x644081f1,0xc0a801d9,0x9f5800e4}},	// [22d50] _جی_, _yani, _گاٹل_, garâ_, 
   {{0x64415818,0xeb489226,0xa0680063,0xc8780205}},	//   _xani, ичек_, _мања_, _kuşe_, 
   {{0x89d8040b,0xab082aaf,0xb218022c,0x6aa80240}},	//   موار_, شتاق_, phæd, togf, 
   {{0x7c2c3633,0x00000000,0x00000000,0x00000000}},	//   _ebbr, --, --, --, 
   {{0xad24027d,0xcdc40075,0x6aa8005c,0xf77000e5}},	//   _برجو, _хәвп, rogf, ہاٹ_, 
   {{0x6d4c0857,0xad9800ae,0x00000000,0x00000000}},	//   _irca, _ndúi, --, --, 
   {{0x644008ad,0xb900007d,0x6d4c0e04,0xaac8012c}},	//   _rani, _नू_, _hrca, िषदक, 
   {{0x769c0882,0x644017ce,0x6d4c07f5,0x66180194}},	//   tīya, _sani, _krca, uguk, 
   {{0x6d4c02fa,0x7980068f,0x4974a3f8,0xf09c004e}},	//   _jrca, czow, _элас, nràs_, 
   {{0x64415819,0x9f580022,0xfd54011a,0x030800c5}},	//   _qani, narã_, פשתי_, _विआह_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x64402c62,0x6d4c0cf9,0x6e2d581a,0x9f58035b}},	//   _wani, _orca, _nbcb, harã_, 
   {{0x6441581b,0x5bb806ff,0x5fa409bb,0x9f5800c7}},	//   _tani, _अर्व, _खुजल, karã_, 
   {{0xf09c170c,0x6441581c,0x3e6c0162,0x9f580022}},	//   dràs_, _uani, _lýtt_, jarã_, 
   {{0xe7c800dc,0x7981581d,0x00000000,0x00000000}},	//   ाधिप, zzow, --, --, 
   {{0x3e6c1bb0,0x6d4c3116,0x6e2c0175,0x79800210}},	//   _nýtt_, _brca, _cbcb, yzow, 
   {{0xed55581e,0x6d4c01ab,0xada0008e,0x6da000c7}},	// [22d60] пот_, _crca, еатл, еита, 
   {{0xe058598b,0x6e2c0408,0x6d4c01e4,0x7c2c0165}},	//   _بیست_, _ebcb, _drca, _qbbr, 
   {{0x3e6c022c,0x2bac05f9,0xf09c004e,0x6d4d581f}},	//   _býtt_, _जुदा, aràs_, _erca, 
   {{0xf09c0137,0xbea4020a,0x9f582531,0x6e2c02d0}},	//   bràs_, _хамк, marà_, _gbcb, 
   {{0x9f595820,0x6d4c01a6,0xbc240137,0x6d48248f}},	//   larà_, _grca, _ىرسى, ågat, 
   {{0xf7715821,0x79800034,0xd04406be,0x00000000}},	//   فاع_, rzow, _bihə, --, 
   {{0xa3a835e8,0x9f595822,0x67d15823,0x7980a735}},	//   _कुल_, narà_, ношу, szow, 
   {{0x7e7400b5,0x3e6c03b2,0xaa40010b,0x09d00154}},	//   nkyp, _gýtt_, _песл, াড়া, 
   {{0x9f5807c5,0x555400e5,0x00000000,0x00000000}},	//   harà_, بھار, --, --, 
   {{0xd250006c,0x2bc019cc,0x29780115,0x00000000}},	//   چند_, वेका, _הטמא, --, 
   {{0xd2502cb0,0x9f595824,0x00000000,0x00000000}},	//   نند_, jarà_, --, --, 
   {{0x9f595825,0xa7580375,0x11d800c6,0x36c400cf}},	//   darà_, _לדבר, توحة_, _эбег, 
   {{0x66600014,0x4ddc00fe,0x00000000,0x00000000}},	//   _سُوٕ, বৰুৱ, --, --, 
   {{0x9f5800db,0x9cec0327,0xf07400d1,0x6744032e}},	//   farà_, རེནས, чигә_, _órjú, 
   {{0x9f595826,0x6d4c05a1,0xd158001f,0x00000000}},	//   garà_, _srca, ገራቸው, --, 
   {{0xe2980b3e,0xf09c004e,0x00000000,0x00000000}},	//   _нај_, tràs_, --, --, 
   {{0xd0ac013f,0xf09c004e,0x9f5800c7,0x00000000}},	// [22d70] _wɔɑw, uràs_, tarã_, --, 
   {{0x2478069c,0x9f5835fb,0xf09c1e7b,0xebc40640}},	//   _ብዙሓት_, barà_, rràs_, пљен, 
   {{0x9f595827,0x00000000,0x00000000,0x00000000}},	//   carà_, --, --, --, 
   {{0x6d4c08ad,0x25800241,0x2bc007b6,0x00000000}},	//   _trca, _jèlé_, वेगा, --, 
   {{0x9f5912c0,0x6d400882,0x6d4c0276,0xe9a8129e}},	//   mará_, ānas, _urca, حدان_, 
   {{0x66080a2e,0x9f580a90,0x1cbc025c,0x00000000}},	//   _sdgk, lará_, _ཅེར_, --, 
   {{0x3e6c0174,0x04f80154,0x00000000,0x00000000}},	//   _týtt_, _আমের_, --, --, 
   {{0x9f58f466,0x7874010b,0xf644010a,0x00000000}},	//   nará_, зйәр_, çхин, --, 
   {{0x69d95828,0x9f595829,0x9f4cf9d1,0xa87401af}},	//   _igue, iará_, údú_, _нөкт_, 
   {{0xc0d00020,0xd7c9582a,0x68f80295,0x2b400327}},	//   _ጨምሮ_, _کومه_, _iwud, _ksjc_, 
   {{0x9f580137,0xaca002e3,0xb38001c0,0x2b40037e}},	//   xarà_, _nnọc, влэл, _jsjc_, 
   {{0x9f59582b,0x68f8063f,0xb8800306,0x69d80332}},	//   jará_, _kwud, žítk, _jgue, 
   {{0x9f584dce,0xaca002e3,0x515400a8,0xdc080154}},	//   dará_, _anọc, нтру, র্টস_, 
   {{0x9f59582c,0x333c0175,0x04c801f7,0x00000000}},	//   tarà_, bwtx_, _بوتي_, --, 
   {{0x69d807dd,0x98a40024,0x9f5800db,0xafe068eb}},	//   _ogue, _esmė_, uarà_, тосл, 
   {{0x9f59582d,0x69d9582e,0x68f8014b,0x00000000}},	//   gará_, _ngue, _owud, --, 
   {{0x9f59582f,0x68f8063f,0xfbd15830,0xe8dc001e}},	// [22d80] sarà_, _nwud, چتا_, _trộn_, 
   {{0x69d95831,0x9f594672,0xfbd005ae,0x114801ec}},	//   _ague, parà_, نتا_, _ءجيى_, 
   {{0x68f95832,0x9f5912c0,0xab2400a7,0x0ae800c6}},	//   _awud, bará_, доха_, كرني_, 
   {{0x9f589312,0x00000000,0x00000000,0x00000000}},	//   cará_, --, --, --, 
   {{0xa96407fa,0xdb1c00d8,0xca0400cf,0x00000000}},	//   мица_, _agrô, ركوۋ, --, 
   {{0x69d90d56,0xd838007f,0x68f8033f,0x47b803d4}},	//   _egue, _ejčn_, _dwud, েখনী, 
   {{0x68f80117,0xb6c42920,0x00000000,0x00000000}},	//   _ewud, мсий, --, --, 
   {{0x38b00142,0x2da40241,0x00000000,0x00000000}},	//   târs_, _ìweé_, --, --, 
   {{0x1cdc0867,0x7d140493,0x6920014b,0x00000000}},	//   _ལངས_, nrys, _имта, --, 
   {{0x1cbc038f,0x9f595833,0x16200574,0xa85000c7}},	//   _ཅེས_, zará_, _यावर_, _аҵшә, 
   {{0x7d155834,0x9f580407,0xd2500133,0x00000000}},	//   hrys, yará_, ۆنگ_, --, 
   {{0x9f58617f,0x7d141f53,0xd2506568,0xf30001c6}},	//   xará_, krys, چنگ_, нжүү, 
   {{0x9f584dce,0x15bc0131,0xc87800a2,0x60f8005b}},	//   vará_, ﻧﯩﯖﻐ, _huşa_, мняя_, 
   {{0x656c2155,0x7d153070,0xc878294f,0xe45000db}},	//   äche, drys, _kuşa_, _акшы, 
   {{0x9f5874c3,0x387c0589,0xb4c80490,0xfd4c0521}},	//   tará_, _mltr_, लगी_, pokọ, 
   {{0x7d155835,0xad9802f0,0x5e58005b,0xb80400cc}},	//   frys, _neúc, мися_, োভিত_, 
   {{0x9f5879c7,0xdd943c1b,0xad9801e7,0x00000000}},	// [22d90] rará_, ваты, _ndút, --, 
   {{0x9f584dce,0x69d80ffb,0xdfd0004b,0xac640023}},	//   sará_, _sgue, ايې_, _ሰጊሮም_, 
   {{0x9f589ace,0x7d140b21,0x00000000,0x00000000}},	//   pará_, arys, --, --, 
   {{0xb4c80d01,0x387d5836,0x00000000,0x00000000}},	//   लगु_, _altr_, --, --, 
   {{0x7d1414e0,0xa3a80ce0,0x64540022,0xdb1c0142}},	//   crys, _कुई_, _óxig, _sgrô, 
   {{0x2b4000cf,0xc87803b9,0x00000000,0x00000000}},	//   _tsjc_, _buşa_, --, --, 
   {{0xcb68a706,0x4ad8012d,0xd8000408,0x65b800d1}},	//   _عمره_, _बंटव, рăс_, ﺧﺸﯩﻠ, 
   {{0x06095837,0x68f80810,0x69d894e8,0xc87925bb}},	//   чник_, _twud, _ugue, _duşa_, 
   {{0x2a7c409c,0x68f95838,0x1a6802f2,0x00000000}},	//   _ilub_, _uwud, _تینی_, --, 
   {{0x2a7c0190,0xb88002f0,0x00000000,0x00000000}},	//   _hlub_, žírk, --, --, 
   {{0xe77401d9,0xe6646eec,0x9f58067c,0xc87800a2}},	//   _تلاں_, _отдо, març_, _guşa_, 
   {{0x7d155839,0xfbd0011a,0x00000000,0x00000000}},	//   yrys, טתי_, --, --, 
   {{0x2c0c0882,0x70a80034,0xc68c00f1,0xe6dc000d}},	//   ाणां_, चकूल, _پېښ_, _पंुज, 
   {{0x0a04009e,0x7d14017a,0x30a060c6,0x00000000}},	//   উলিং_, vrys, лғығ, --, 
   {{0x2a7c0cc1,0x2bac35e8,0xea9c1682,0x68301ae4}},	//   _olub_, _जुला, _laṱa_, mıdı, 
   {{0x9f5c427e,0x683041d5,0xb218037e,0x7d15583a}},	//   _því_, lıdı, lhæn, trys, 
   {{0x7d149af9,0x00000000,0x00000000,0x00000000}},	// [22da0] urys, --, --, --, 
   {{0x7d15583b,0x64549ace,0xb21804ce,0x6830046c}},	//   rrys, _óxid, nhæn, nıdı, 
   {{0x2a7d583c,0xeb940032,0xe8dc0208,0xaee000b8}},	//   _blub_, ниф_, _trớn_, _puṅg, 
   {{0x7d15583d,0x2a7d583e,0x3a300209,0xb9044b2c}},	//   prys, _club_, ýyp_, ездк, 
   {{0xf9909cc3,0xed540e1f,0x7d140334,0x68304dd9}},	//   دبا_, _зоя_, qrys, kıdı, 
   {{0x3b082b39,0x00000000,0x00000000,0x00000000}},	//   _него_, --, --, --, 
   {{0xb21800b5,0xc878a75a,0xaee0002b,0x68304dd9}},	//   dhæn, _quşa_, _tuṅg, dıdı, 
   {{0x7c3d583f,0x2a7cfb0e,0x675131be,0x00000000}},	//   lepr, _glub_, اخور, --, 
   {{0xb21804ce,0xe9a00eff,0x69f0013e,0xa9a001a9}},	//   fhæn, _батп, _сӯхт, _битд, 
   {{0xc87856a3,0xb218005c,0x68300205,0x00000000}},	//   _tuşa_, ghæn, gıdı, --, 
   {{0xd7652371,0x7c3c7824,0xd90c01d3,0xd7c800f1}},	//   _جنای, iepr, _ایڈ_, _کوڅه_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x68304e7e,0x00000000,0x00000000,0x00000000}},	//   bıdı, --, --, --, 
   {{0xf1c40034,0xe3ac004b,0x68301432,0x9f5800e4}},	//   रेगन, شرۍ_, cıdı, karä_, 
   {{0x9f340164,0x7c3c0c8c,0x98a40055,0xada00030}},	//   лері, depr, _asmī_, zlúč, 
   {{0x2284030d,0x9f58008e,0x00000000,0x00000000}},	//   _буьг, darä_, --, --, 
   {{0xad986b3c,0x7c3d5840,0x9e3400ee,0x00000000}},	// [22db0] _adúr, fepr, ыетч, --, 
   {{0x2a7c0210,0x00000000,0x00000000,0x00000000}},	//   _slub_, --, --, --, 
   {{0x2a7c01ab,0x57580023,0x00000000,0x00000000}},	//   _plub_, ግራፊካ, --, --, 
   {{0x49744ad0,0x68300c3c,0x2a7c025c,0x32d80055}},	//   клес, zıdı, _qlub_, _yūya_, 
   {{0x68307236,0x64440109,0x2ebc043e,0x5d380354}},	//   yıdı, ôjik, ्षीत, _пурĕ, 
   {{0x475801fc,0x58d4004e,0x9f580139,0x00000000}},	//   дрия_, гочт, barä_, --, 
   {{0x942403be,0xd8b82f84,0xf8b400f7,0x68300205}},	//   _ötən_, ردها_, төт_, vıdı, 
   {{0xada000d7,0xe8000037,0x00000000,0x00000000}},	//   plúč, _रजवा_, --, --, 
   {{0x68300ac1,0xb21801bf,0x00000000,0x00000000}},	//   tıdı, thæn, --, --, 
   {{0x9b4401ed,0x78780158,0x70a802e5,0x6e3c0477}},	//   _جنہو, røvæ, चकोल, heqb, 
   {{0x6830046c,0x4e20012c,0x7024015b,0xb218005c}},	//   rıdı, यलाई_, য়াজ_, rhæn, 
   {{0x68304a4a,0x7c3c068f,0x00000000,0x00000000}},	//   sıdı, zepr, --, --, 
   {{0x9ffc003d,0xb21800b5,0xb140bcf8,0x7c3d5841}},	//   _དབྱང_, phæn, анял, yepr, 
   {{0xdee402d3,0x00000000,0x00000000,0x00000000}},	//   ምጻእ_, --, --, --, 
   {{0x7c3d5842,0x3eb003b2,0x00000000,0x00000000}},	//   vepr, toyt_, --, --, 
   {{0x9f5800e4,0x00000000,0x00000000,0x00000000}},	//   varä_, --, --, --, 
   {{0x7c3d5843,0xf1bc0042,0x93bc0356,0x008401d5}},	// [22dc0] tepr, ffáu_, sfăt, _алпо, 
   {{0x711800c8,0xac801774,0x7c3c017a,0x00000000}},	//   _קויפ, агул, uepr, --, 
   {{0x7c3d5844,0xbea40124,0xf014011a,0xbb855845}},	//   repr, _аанк, _בקיץ_, خلاي, 
   {{0xbdf80133,0xb21801bf,0x9f5800e4,0x00000000}},	//   _تردا_, jhæl, rarä_, --, 
   {{0x7c3cee07,0x00000000,0x00000000,0x00000000}},	//   pepr, --, --, --, 
   {{0x2cb000d7,0xfbc47ce9,0xa8c0009d,0x00000000}},	//   coxd_, _абго, айчд, --, 
   {{0x56955846,0xfb148efb,0x3f880369,0xe7340120}},	//   лакт, _جوزج, nzbu_, веј_, 
   {{0xb21801bf,0x33980150,0x00000000,0x00000000}},	//   ghæl, _ﺘﺒﻨﻲ_, --, --, 
   {{0x39400100,0xf4851486,0x00000000,0x00000000}},	//   _èks_, вунн, --, --, 
   {{0xe8c40276,0xddc400c0,0x00000000,0x00000000}},	//   _агул_, lkių, --, --, 
   {{0x26180574,0xb5f00220,0xcd3c001f,0xad980306}},	//   _याची_, _күйі, ስተናገ, _neún, 
   {{0x3f885edb,0xddc400c0,0x00000000,0x00000000}},	//   dzbu_, nkių, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xaee000dc,0x00000000,0x00000000,0x00000000}},	//   _niṣe, --, --, --, 
   {{0x53341411,0xf2c55847,0xe208033f,0x5f94035b}},	//   _сейт, _исин, _stół_, аирт, 
   {{0x2ebc07f8,0x630004a9,0xaee00248,0xad1000d1}},	//   ्षेत, _ئويل, _aiṣe, ипбә, 
   {{0xd250004b,0x09e401a9,0x00000000,0x00000000}},	// [22dd0] _ننګ_, қолн, --, --, 
   {{0x209800c7,0xc32c03e6,0x20c401f4,0x9bf401f4}},	//   _акьы_, _بڕی_, löin_, изуч, 
   {{0xb2180fac,0x00000000,0x00000000,0x00000000}},	//   yhæl, --, --, --, 
   {{0xb21804ce,0xe8340020,0x00000000,0x00000000}},	//   skæf, _ጣቢያዎ, --, --, 
   {{0xba500035,0x00000000,0x00000000,0x00000000}},	//   صنوع, --, --, --, 
   {{0x1cbc0327,0xb218005c,0x00000000,0x00000000}},	//   _ཅེག_, lkæd, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb218005c,0x00000000,0x00000000,0x00000000}},	//   nkæd, --, --, --, 
   {{0x2498001f,0xb2188ecc,0x00000000,0x00000000}},	//   _ኅብረት_, rhæl, --, --, 
   {{0x04c81d57,0xe5a00058,0x348004f0,0x00000000}},	//   عودي_, лиқи, йгыг, --, 
   {{0xe0e000fe,0xea9c0055,0x00000000,0x00000000}},	//   _ভবেন, ciṣe_, --, --, 
   {{0xad9868b1,0xd7c8129e,0x9324030f,0x00000000}},	//   _reún, _شونه_, گرین, --, 
   {{0x9f595848,0xc87001e1,0x128800d1,0x09b40154}},	//   mbré_, _ko̟_, тияқ_, জেরা, 
   {{0xd378033f,0xc87001e1,0x44e889b4,0x81d400cc}},	//   być_, _jo̟_, _iú_, াঁল_, 
   {{0xa3a8982f,0x44e95849,0xaee000b8,0x9f580332}},	//   _कुच_, _hú_, _riṣe, larú_, 
   {{0x44e9584a,0xc87001e1,0x44240175,0xaee000b8}},	//   _kú_, _lo̟_, lgl_, _siṣe, 
   {{0x44e9584b,0x6285584c,0xa3e44284,0x442404cc}},	// [22de0] _jú_, _ilio, _भला_, ogl_, 
   {{0x44e80570,0x4425584d,0xd1c8001f,0x00000000}},	//   _mú_, ngl_, በኞች_, --, 
   {{0x44e9584e,0x6285584f,0x8fd40131,0x9f58007b}},	//   _lú_, _klio, _вәтә, harú_, 
   {{0xa3a88d8b,0x44e95850,0xdb1c0240,0x4df40006}},	//   _कुछ_, _oú_, _hyrë, _вярт, 
   {{0x44e86984,0xd378068f,0x628400ec,0xb21800b5}},	//   _nú_, zyć_, _mlio, skæg, 
   {{0x62844159,0x44240010,0x9f5801e7,0x2bac00ce}},	//   _llio, jgl_, darú_, _जुका, 
   {{0x62855851,0x44e803a0,0x09b400bd,0xf1bc00d0}},	//   _olio, _aú_, জেলা, nfár_, 
   {{0x44e95852,0x442407de,0x00000000,0x00000000}},	//   _bú_, egl_, --, --, 
   {{0x44e95853,0xd95403e6,0x98c4030c,0x81e80154}},	//   _cú_, _خۆشخ, _көкж, যরা_, 
   {{0x62855854,0x27f4038e,0x44e95855,0xd94400d1}},	//   _alio, čení_, _dú_, _йеғи, 
   {{0x62841a56,0x44e801f1,0xb21800b5,0x00000000}},	//   _blio, _eú_, shæm, --, 
   {{0x6284a66a,0xf1241fe2,0x3a240004,0x32655856}},	//   _clio, льго, ngop_, утов, 
   {{0xdef8c5dc,0x44e95857,0x628401c3,0xd378033f}},	//   ғыс_, _gú_, _dlio, syć_, 
   {{0x62855858,0x32d801e1,0x1cb0031c,0x64a00798}},	//   _elio, _bàyì_, ྒོས_, _лача, 
   {{0x628400a3,0x44e801e7,0xb21801bf,0x20c401f4}},	//   _flio, _zú_, tkæd, pöin_, 
   {{0x62855859,0xe3108d1a,0x2bac107c,0x44e80248}},	//   _glio, _ابوب, _जुगा, _yú_, 
   {{0x320938ae,0xe214951b,0xd8380306,0xb218005c}},	// [22df0] macy_, _طبيع, _obč_, rkæd, 
   {{0xac740efb,0x3208033f,0xb21800b5,0x00000000}},	//   دارش, lacy_, skæd, --, 
   {{0x6284049b,0x2bac07f7,0x6ec41291,0x00000000}},	//   _ylio, _जुखा, _متحق, --, 
   {{0x89d88eef,0xdb1c0023,0x6398008f,0x78b8036e}},	//   نوار_, _zyrë, עסאנ, _aktv, 
   {{0x442400a9,0xdb1c00d0,0x2bb406e3,0x00000000}},	//   ygl_, _vzrá, _अडवा, --, 
   {{0x070800aa,0x44e8110e,0x99d483fa,0x0715585a}},	//   نيتي_, _rú_, حتما, афия, 
   {{0x44e9585b,0x3cdc02c3,0xe0b8010f,0x00000000}},	//   _sú_, _कूटे_, אלגט_, --, 
   {{0xd838007f,0x3dc40034,0x44e80306,0x3208033f}},	//   _ebč_, żowe_, _pú_, jacy_, 
   {{0xc485585c,0x6ab9585d,0x26c000da,0xe8dc001e}},	//   илик, _ikuf, ējo_, _trốn_, 
   {{0x99840491,0x461404d3,0x44e8001e,0x62841552}},	//   _الكو, _چوار, _vú_, _slio, 
   {{0x4425585e,0x6285585f,0x6ab804ba,0x38682508}},	//   rgl_, _plio, _kkuf, _òbra_, 
   {{0x44e95860,0xc5d410f5,0x67215861,0x290c0421}},	//   _tú_, _кіль, munj, osga_, 
   {{0x67200161,0x113812c4,0x6ab801c8,0x44e80270}},	//   lunj, ляры_, _mkuf, _uú_, 
   {{0x144801a9,0x00000000,0x00000000,0x00000000}},	//   _бошқ_, --, --, --, 
   {{0x67207807,0x6ab95862,0x65795863,0x3209078a}},	//   nunj, _okuf, lyuh, bacy_, 
   {{0x628400b2,0x6ab95864,0xc1780022,0x5ba40032}},	//   _ulio, _nkuf, _асоц_, ҡлағ, 
   {{0x61e55865,0xb2b80302,0x67215866,0xee340640}},	// [22e00] _igil, _במקר, hunj, јну_, 
   {{0xed555867,0x6ab95868,0xf1bd5869,0xe29802dd}},	//   шоу_, _akuf, ogán_, _шақ_, 
   {{0x6721586a,0xf1bc6791,0x657800ca,0xb41400df}},	//   junj, ngán_, hyuh, שקעס_, 
   {{0x67200fcf,0x657800b5,0x290c01a9,0x00000000}},	//   dunj, kyuh, fsga_, --, 
   {{0x656c097d,0x3a2477d0,0xdb1c0332,0x00000000}},	//   ächl, rgop_, _myré, --, 
   {{0x6ab9586b,0xfb24034c,0x6579586c,0x672000d2}},	//   _ekuf, _پرسپ, dyuh, funj, 
   {{0x6721586d,0x61e5586e,0x3944003e,0x6578058a}},	//   gunj, _ogil, swos_, eyuh, 
   {{0xfaa43014,0x2bac1b37,0x290c01b9,0xb2181d0e}},	//   _табо, _जुटा, bsga_, rhæk, 
   {{0x3209586f,0x65780280,0x54b95870,0x00000000}},	//   vacy_, gyuh, лгия_, --, 
   {{0x61e55871,0x3f68166a,0x78b800dc,0x37b0015b}},	//   _agil, _oʝu_, _uktv, টেগর, 
   {{0xb648009d,0xe4646171,0x6c7800df,0x00000000}},	//   _аялж_, ршыл_, דריד, --, 
   {{0x48fc038e,0xdb1c0166,0x00000000,0x00000000}},	//   रीको_, _izrä, --, --, 
   {{0x32095872,0x3f68166a,0xe2980953,0x65780230}},	//   racy_, _aʝu_, раў_, cyuh, 
   {{0x61e55873,0x65380bd9,0x041c015b,0x2bac12eb}},	//   _egil, _סעוד, ব্বী_, _जुझा, 
   {{0xa3b55874,0x32095875,0x8d70001f,0x92595876}},	//   _پاور_, pacy_, _ባላቸው_, _байт_, 
   {{0xdef81cd1,0x3e6c01ef,0x290c022e,0x00000000}},	//   рыр_, _kýty_, ysga_, --, 
   {{0xa2c40da5,0x290c01d5,0x00000000,0x00000000}},	// [22e10] रतर्, xsga_, --, --, 
   {{0x3e6c02fb,0x6720004b,0x00000000,0x00000000}},	//   _mýty_, yunj, --, --, 
   {{0xf1bc031c,0x00000000,0x00000000,0x00000000}},	//   ġġuk_, --, --, --, 
   {{0x67215877,0x6d480321,0x290c01a9,0x6ff0013a}},	//   vunj, ægas, tsga_, běcí, 
   {{0x67206ca2,0xc8780356,0xd9e80037,0x3e6c013a}},	//   wunj, _huşi_, _ओलरत_, _nýty_, 
   {{0x672050f9,0x776800b5,0x290c01d5,0xd918009d}},	//   tunj, fxfx, rsga_, рьц_, 
   {{0x65786085,0x290c01a9,0x00000000,0x00000000}},	//   wyuh, ssga_, --, --, 
   {{0x6ab88cdb,0x46495878,0xddc40010,0x93bc0356}},	//   _ukuf, узин_, ljiš, rgăl, 
   {{0x1fd41944,0x61e401a9,0x290c01d5,0x940c0213}},	//   _दण्ड, _rgil, qsga_, lidə_, 
   {{0xd8740491,0x61e55879,0x5f180034,0x6578f32c}},	//   _والب, _sgil, _फिल्_, ryuh, 
   {{0xdb1d587a,0x67200921,0x657911ae,0x940c03e3}},	//   _pyré, qunj, syuh, nidə_, 
   {{0xbb380a1e,0x00000000,0x00000000,0x00000000}},	//   נערי, --, --, --, 
   {{0x940c00ac,0x61e40327,0xe81800bc,0x00000000}},	//   hidə_, _vgil, _नयाा_, --, 
   {{0x0379587b,0x940c0213,0x932400ec,0x00000000}},	//   _محبت_, kidə_, _ڀرين, --, 
   {{0x61e404cc,0xe3b04ce4,0xf1bc01d3,0xd24c0133}},	//   _tgil, _برش_, lgál_, رۆی_, 
   {{0x61e40117,0x6e380789,0x6818005f,0x020406b3}},	//   _ugil, _ñubl, lādē, _узин, 
   {{0xa284030f,0x00000000,0x00000000,0x00000000}},	// [22e20] _هیگو, --, --, --, 
   {{0x3154008d,0x7de40220,0xb140009d,0x00000000}},	//   _פיין_, ріңд, _эньл, --, 
   {{0x6f60084c,0x80b401f9,0x00000000,0x00000000}},	//   _евэз, ृतीं, --, --, 
   {{0x09d0015b,0x6d6401e7,0x00000000,0x00000000}},	//   িশনা, óraí, --, --, 
   {{0x9f580332,0x00000000,0x00000000,0x00000000}},	//   ibrí_, --, --, --, 
   {{0x96f802d5,0xf090010f,0x940c03b9,0x00000000}},	//   аект_, ּנה_, bidə_, --, 
   {{0xd6d0a554,0xbb8400c6,0xb218037e,0xc75800e2}},	//   وقت_, _الأي, mhæv, šīnā, 
   {{0xdd080038,0x994c01f1,0x83e40150,0xeb9400f3}},	//   _môže, môže_, _ﺍﺯﺍﻳ, _уис_, 
   {{0x092800ec,0x25b40014,0xb99400ae,0x00000000}},	//   _نسلي_, ٝنٹھ_, _الذب, --, 
   {{0x344805f5,0x68180171,0x00000000,0x00000000}},	//   учин_, gādē, --, --, 
   {{0x1cbc025c,0x36040214,0x00000000,0x00000000}},	//   _ཅེན_, _هواف, --, --, 
   {{0xc878054e,0xc7640228,0x00000000,0x00000000}},	//   _ruşi_, _باكى, --, --, 
   {{0x940c0213,0xe5e456a7,0x75d5587c,0xa18400cb}},	//   zidə_, _ازمی, _ايشا, пырл, 
   {{0xc878054e,0xdb14010b,0x2fc40051,0x00000000}},	//   _puşi_, _şaýo, _ơng_, --, 
   {{0x7d0402d0,0xdef8411a,0xe4340375,0x643400df}},	//   _awks, йыт_, _הרוח_, _לאגא_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xcc980063,0xcc740114,0x00000000,0x00000000}},	// [22e30] авац_, огаћ, --, --, 
   {{0xa3cc03e5,0x7c2c009f,0x5c7400d4,0x00000000}},	//   _शरम_, _ccbr, плут, --, 
   {{0x7bd80122,0x44f803d4,0x2fc4004d,0x9cc800b1}},	//   _útul, _ইয়াক_, _áng_, сыта_, 
   {{0x940c0213,0x3dc4033f,0x00000000,0x00000000}},	//   ridə_, żowa_, --, --, 
   {{0xfa5401b9,0x482400d1,0xdb5001d9,0xbb4000d1}},	//   ترلگ, قىشق, وَے_, ﻛﻠﻰ_, 
   {{0x46f47843,0x6d4d587d,0xaf7c001f,0xfcf800df}},	//   очит, _isca, _ዓመትና_, _כּלל, 
   {{0xdb587e79,0x0cc48109,0x940c06be,0x00000000}},	//   _лют_, वतीम, qidə_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x44880228,0xd8780014,0x74e4009d,0x00000000}},	//   ибин_, _گمٕت_, одыг_, --, 
   {{0x6d4c05da,0x7af00109,0xada002f0,0x00000000}},	//   _msca, _ôktô, moúč, --, 
   {{0x9f880321,0x681800e2,0x98140244,0x66e000e5}},	//   jóða_, rādē, _ربلا, _főka, 
   {{0x6d4d587e,0xdb200129,0x00000000,0x00000000}},	//   _osca, étée, --, --, 
   {{0xbbc403ba,0x826401b9,0x00000000,0x00000000}},	//   _वर्क, مهگن, --, --, 
   {{0x6e2c00e4,0xf17c00d1,0x00000000,0x00000000}},	//   _accb, _ﮬﻮﻗﯘ, --, --, 
   {{0x6d4d587f,0xafe0f819,0x93580276,0xe3d40eac}},	//   _asca, дорл, _грыу_, _দ্রব, 
   {{0xada000d7,0x00000000,0x00000000,0x00000000}},	//   koúč, --, --, --, 
   {{0x6608066d,0xed54009d,0xc8780205,0x00000000}},	// [22e40] _megk, оот_, _huşu_, --, 
   {{0x8520951e,0x660800dd,0xc8782737,0xd5b80408}},	//   _मिनट_, _legk, _kuşu_, _тiео, 
   {{0x81d4000e,0x6d4c9efb,0xb21801bf,0x00000000}},	//   াঁও_, _esca, rhæv, --, 
   {{0x1cdc0489,0x6d4c004e,0x9f5804cc,0xd9c0009e}},	//   _ལངམ_, _fsca, mbrà_, েশসম, 
   {{0x195956cb,0x7e647a55,0x291802d1,0xe3cc0154}},	//   салы_, _inkp, šqan_, রশিব, 
   {{0x7c2c0051,0xed5400d8,0x00000000,0x00000000}},	//   _ucbr, _ќор_, --, --, 
   {{0x3688ace2,0x8cb82802,0x660801e3,0x00000000}},	//   исин_, ्तरो, _begk, --, 
   {{0x9f582e27,0x7bcd5880,0x6b60036b,0x6d4c02d0}},	//   laró_, _izbu, _юкса, _ysca, 
   {{0xe9a00eff,0x66095881,0xe8f4014b,0x00000000}},	//   _жатп, _degk, _млт_, --, 
   {{0x7afc143a,0xc87806be,0x00000000,0x00000000}},	//   oppt, _buşu_, --, --, 
   {{0xa3cc39de,0x00000000,0x00000000,0x00000000}},	//   _शरण_, --, --, --, 
   {{0xc87800a2,0xd6040354,0x00000000,0x00000000}},	//   _duşu_, _цiав, --, --, 
   {{0x168403e6,0xe44c01d3,0xb21801bf,0x9f5800e5}},	//   _واڵێ, رضی_, dhæt, karó_, 
   {{0x7e640165,0xf8c809bb,0x00000000,0x00000000}},	//   _ankp, ितिय, --, --, 
   {{0x7bcc0004,0x6d4d5882,0x8c080011,0x232400f3}},	//   _nzbu, _ssca, _লালন_, _доји_, 
   {{0xe2986fbd,0xf1bc4e82,0xa3cc00af,0xb2180140}},	//   _мај_, ngák_, _शरत_, thæu, 
   {{0x7bcc009b,0xf8c809b4,0x6fb805b3,0x52d000fe}},	// [22e50] _azbu, िताय, _शुरू, _সংপৃ, 
   {{0x7e6401c7,0x9f5800db,0xebc40640,0x656c0112}},	//   _enkp, garó_, ољен, ächi, 
   {{0xf09c067c,0x6e2c035a,0xc878010e,0xaa4800d4}},	//   ssàs_, _tccb, _muşt_, иїде_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d4c084c,0x660805e4,0xe9a84310,0x9f5800d8}},	//   _usca, _regk, جدان_, mbrá_, 
   {{0x6d5800e4,0xe7002099,0xe0fc011a,0x00000000}},	//   _ġuah, وسعی, סלול, --, 
   {{0xeab01063,0x00000000,0x00000000,0x00000000}},	//   _قعر_, --, --, --, 
   {{0x7a140210,0x00000000,0x00000000,0x00000000}},	//   rętó, --, --, --, 
   {{0x66095883,0xb3400327,0xe8d001d9,0x00000000}},	//   _vegk, _ġħan, _ہۅچھ, --, 
   {{0x68f95884,0x66095885,0xa3cc3644,0xefe82440}},	//   _itud, _wegk, _शरद_, ሄራዊ_, 
   {{0x6608b59b,0x699c012c,0xc8782b93,0x8698004e}},	//   _tegk, _खेती, _quşu_, _лкжс_, 
   {{0x9f58003a,0xd7c802f2,0x27140356,0xb21801bf}},	//   rarü_, _بومه_, măn_, skæn, 
   {{0x9f580268,0xf484029e,0x00000000,0x00000000}},	//   jarò_, زایی, --, --, 
   {{0x68f80161,0xb4f80375,0xc8780790,0xb21801bf}},	//   _mtud, _הפסי, _tuşu_, lkæl, 
   {{0x14755886,0x9f5801d3,0x00000000,0x00000000}},	//   _تانج, varó_, --, --, 
   {{0x88d009bd,0xb21801bf,0x00000000,0x00000000}},	//   াদিক, nkæl, --, --, 
   {{0x9f5800f7,0x68f95887,0x93ec016b,0xcdc401ec}},	// [22e60] taró_, _ntud, andε_, датқ, 
   {{0x3134025f,0xec74094e,0x67200219,0x3dc40210}},	//   _צריך_, ппу_, krnj, żowo_, 
   {{0x30780302,0x68f95888,0x7afc1b47,0x6fc008e9}},	//   _האינ, _atud, uppt, _षडयं, 
   {{0xcee8d618,0x7bcc6185,0xfce55889,0xb110036b}},	//   _گرین_, _vzbu, _номо, _تویغ, 
   {{0x9f59588a,0xf1bc0548,0x78a8005a,0x7bcc033f}},	//   paró_, ggáh_, tnfv, _wzbu, 
   {{0x8c4000c7,0xcee80066,0x00000000,0x00000000}},	//   _иҵуе, _درین_, --, --, 
   {{0xab247ffa,0x68f9588b,0x2240014a,0xa73400c6}},	//   _нора_, _etud, _obik_, كثير_, 
   {{0x98ac70f7,0x68f80393,0x66e000f0,0x00000000}},	//   ılıp_, _ftud, ноја, --, 
   {{0x7aec6c5d,0x00000000,0x00000000,0x00000000}},	//   _hubt, --, --, --, 
   {{0x672016a3,0x22400139,0xc824af9d,0xe7cc00d1}},	//   brnj, _abik_, _озуқ, _ﺗﯜﺭﻟ, 
   {{0x28100150,0xdecc001f,0x798070b6,0x7d14002f}},	//   _سونس, ቢሎን_, lyow, hsys, 
   {{0x7d15588c,0x75d4188d,0xb19029db,0x7aec01a9}},	//   ksys, _فيضا, елмә, _mubt, 
   {{0x7aec01d4,0x7980055a,0x31c4b3eb,0x00000000}},	//   _lubt, nyow, ясов, --, 
   {{0x2240009a,0xe4d404fb,0xe3ac2ab4,0x7d155791}},	//   _ebik_, _فونت_, ئری_, dsys, 
   {{0x64380375,0x9f59588d,0x7d141543,0x7aec0393}},	//   _העונ, warò_, esys, _nubt, 
   {{0x8c080f22,0xa9200030,0x7d1413ee,0xf09c00e8}},	//   _লাইন_, ôžko, fsys, rsàq_, 
   {{0xad9802f0,0x00000000,0x00000000,0x00000000}},	// [22e70] _neút, --, --, --, 
   {{0x9f580086,0x79800014,0xda3c00a2,0x00000000}},	//   rarò_, dyow, _gurº, --, 
   {{0x4fc00131,0xcb080451,0x00000000,0x00000000}},	//   _شەرە, زيشن_, --, --, 
   {{0x7aed588e,0x9f58b503,0x67200f03,0x29180784}},	//   _dubt, parò_, vrnj, šqam_, 
   {{0x4f8401d9,0xdb1c0022,0x00000000,0x00000000}},	//   _راگہ, _pyrã, --, --, 
   {{0x2b4000ca,0x7aec003a,0x6720002d,0xb21801bf}},	//   _tpjc_, _fubt, trnj, dkæm, 
   {{0x7aec0014,0xb21801bf,0x00000000,0x00000000}},	//   _gubt, ekæm, --, --, 
   {{0x0564005b,0xc56421f3,0x67200200,0x1aa400f3}},	//   двин, дкик, rrnj, _зјуг, 
   {{0x68f82dab,0x1995588f,0xb218f113,0x00000000}},	//   _utud, _затя, rkæl, --, 
   {{0xb218037e,0x9f580bcd,0x00000000,0x00000000}},	//   skæl, karð_, --, --, 
   {{0xdc38008f,0xec2400e4,0x7d14002f,0x00000000}},	//   לאזט_, _ẽỹre_, zsys, --, 
   {{0x569464ab,0x258000e5,0x00000000,0x00000000}},	//   _пахт, _célú_, --, --, 
   {{0xea9c0055,0x00000000,0x00000000,0x00000000}},	//   _naṭa_, --, --, --, 
   {{0x7d145794,0x9f5803b2,0xb460004e,0x656c002f}},	//   vsys, farð_, _акшл, ächu, 
   {{0xf48440ec,0x9f580436,0x7d1401f5,0xb21812e8}},	//   _زاوی, garð_, wsys, rhær, 
   {{0x7aec0429,0xad980122,0x79800548,0xb2180b1a}},	//   _rubt, _neús, yyow, shær, 
   {{0x6da000a8,0x66f80a28,0xada15890,0xe8dc01e1}},	// [22e80] вита, ṃkhy, ватл, _apọn_, 
   {{0x79800451,0xd8380cf4,0xbc68249f,0x7aec6b0b}},	//   vyow, _omča_, غمان_, _pubt, 
   {{0xbb495891,0x7aed1663,0x00000000,0x00000000}},	//   تلان_, _qubt, --, --, 
   {{0x8b643dca,0xf988215c,0x7980020c,0xb21801bf}},	//   عالم, يناي_, tyow, ykæm, 
   {{0xd9103629,0x2b2400d1,0x00000000,0x00000000}},	//   ایط_, ككەپ_, --, --, 
   {{0x7aec0ecf,0xa96401f4,0xb8f4000d,0x00000000}},	//   _tubt, ьича_, _सठ_, --, 
   {{0xfaa4006c,0x93bc0311,0x00000000,0x00000000}},	//   _жаво, ngăt, --, --, 
   {{0x7c3cb594,0xb86405d9,0x96344bea,0xfce401f0}},	//   lfpr, _ڪارو, хниц, _хоҳо, 
   {{0xb4240a2c,0xc0e0069d,0x00000000,0x00000000}},	//   وعدو, _ሞገስ_, --, --, 
   {{0xb21800b5,0x54540024,0x00000000,0x00000000}},	//   rkæm, хвот, --, --, 
   {{0xd2500b61,0xb218005c,0x8574009d,0x92580139}},	//   هند_, skæm, длөх, пант_, 
   {{0xc0e8001f,0x3264da48,0x00000000,0x00000000}},	//   _ሙከራ_, фтов, --, --, 
   {{0x656d5892,0x7640014b,0x630000f1,0xb78401af}},	//   ächt, _iboy, _یوول, _хәҙе_, 
   {{0x7c3c01f5,0xc7e400db,0x7e7400e4,0x00000000}},	//   jfpr, _تۉۉن_, ejyp, --, 
   {{0x237028fa,0x9f340220,0xc17001d5,0xad981155}},	//   _لايح, кері, نگیت, _neúr, 
   {{0x7c3c01a4,0xea9c00b8,0x7e740200,0xd04c06be}},	//   efpr, _paṭa_, gjyp, _əhər, 
   {{0x7bc82155,0x76400588,0xefe87427,0x93bc054e}},	// [22e90] üfun, _mboy, _وعدو_, rgău, 
   {{0xe1d80006,0xdb1c00d7,0xea9c00b8,0x00000000}},	//   _ідэі_, _syrá, _vaṭa_, --, 
   {{0x76400085,0x9be40006,0x00000000,0x00000000}},	//   _oboy, віцк, --, --, 
   {{0xce94013e,0xea9c00b8,0x00000000,0x00000000}},	//   _чамъ, _taṭa_, --, --, 
   {{0xaca0063f,0xdb1c04bf,0xa508025c,0xddc40205}},	//   _abục, _vyrá, _གསེག_, mdiş, 
   {{0x76415893,0xf8b405f5,0xddc403e0,0xb7a800cc}},	//   _aboy, нөх_, ldiş, _ওৰেট, 
   {{0x76415894,0xf85000d0,0xf1bc0142,0x00000000}},	//   _bboy, ážať_, mgáu_, --, 
   {{0xea9c0241,0x8cb80aff,0x78740209,0xe81800af}},	//   _daṣa_, ्तको, дйәр_, _नयका_, 
   {{0xd8380100,0x05a8036b,0xc4e401c0,0x2be000dc}},	//   _imčn_, явий_, нжий, _कृतं_, 
   {{0xa3fc045e,0x764002ea,0xe58021cb,0x9f5800e4}},	//   ূল্য_, _eboy, етүү, marö_, 
   {{0xb38005f5,0x3d141d8a,0x9f58007c,0x7cd403b9}},	//   глэл, _पौने_, larö_, lərü, 
   {{0x656c04ef,0x7af801ed,0x76400248,0xc59400d8}},	//   ächs, _étte, _gboy, _пиеј, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb80001ad,0x00000000,0x00000000,0x00000000}},	//   रुपम_, --, --, --, 
   {{0x64400327,0xb40401b9,0x25d807f7,0xf8b0011a}},	//   _ibni, _чўчқ, खेरी_, אשם_, 
   {{0xf770008f,0xa1880220,0x93bc0311,0xdb1c010e}},	//   נקן_, _жұма_, rgăt, _hyrç, 
   {{0xb22006a6,0x699c0dba,0xeff40023,0x00000000}},	// [22ea0] _смыл, _खेली, _ፈልዩ_, --, 
   {{0xfbd001f7,0x7c3c002f,0x3154010f,0x00000000}},	//   هتا_, ufpr, _טיפן_, --, 
   {{0xcb080212,0x93bc054e,0x3098010f,0x9f5c0051}},	//   дхід_, lgăr, _זשימ, _ývà_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe94400dd,0x64415895,0x93bc0356,0xaa54007b}},	//   ٹرنی, _obni, ngăr, علها_, 
   {{0x64400135,0x00000000,0x00000000,0x00000000}},	//   _nbni, --, --, --, 
   {{0x5694ec03,0xf6e400a8,0xa5080327,0xc60003d4}},	//   какт, нцин, _གསུག_, _এয়া_, 
   {{0x1cb00003,0x64415896,0x6bd400db,0x00000000}},	//   ྒོམ_, _abni, _سوقس_, --, 
   {{0x66701e4a,0x74a4399f,0x9f580022,0x88c400cf}},	//   ادىر, ејне, marõ_, رتۇل, 
   {{0xd1d402d3,0x628001b8,0x64a00640,0x93f402e8}},	//   ረክብ_, ömon, лања, ъпоц, 
   {{0xad9800e4,0x92955897,0xa3d80073,0xddc403e0}},	//   _leúp, ванц, ढेल_, ydiş, 
   {{0x76400944,0x248402d3,0x00000000,0x00000000}},	//   _uboy, _ዝወርድ_, --, --, 
   {{0xd2500502,0xad9802fb,0x853401d9,0xdb1c01f4}},	//   هنگ_, _neúp, _لونچ, _hyrä, 
   {{0x212400c6,0x644001ab,0xdb1d5898,0x9f580022}},	//   ámha_, _gbni, _gyrç, harõ_, 
   {{0xd904051c,0x6e64863f,0xda100490,0xdb1c023a}},	//   _گی_, нтаж, ारात_, _jyrä, 
   {{0x41dc29da,0x3860016b,0xf4840014,0xdb1c01f4}},	//   नेहस, _ɔkra_, _زاڈی, _myrä, 
   {{0xd9055899,0xdd95589a,0xf2dc0548,0xac25589b}},	// [22eb0] _دی_, гаты, mmâ_, ефек, 
   {{0x387d589c,0x9df801c0,0xdb1c0166,0x00000000}},	//   _notr_, _үнэт_, _oyrä, --, 
   {{0x3ea00175,0x6209195a,0x00000000,0x00000000}},	//   _fmkt_, _íslí, --, --, 
   {{0xaac4a675,0x00000000,0x00000000,0x00000000}},	//   رتان, --, --, --, 
   {{0x9f580158,0x9cb40131,0x00000000,0x00000000}},	//   rbrå_, خمەت, --, --, 
   {{0x07a42e58,0xad9801e1,0x387c19f5,0xaca0063f}},	//   калн, _afúg, _cotr_, _kpọb, 
   {{0x6b80049f,0x981404fb,0x9f5801b8,0x1bd5589d}},	//   ängd, ابها, sarö_, _боря, 
   {{0xd90d589e,0x48d0015b,0xf1bd589f,0xdb1c0432}},	//   _کیو_, াদের, ngás_, _syrç, 
   {{0x387c14b2,0xe7e800f3,0x00000000,0x00000000}},	//   _fotr_, _ефек_, --, --, 
   {{0x39400139,0xf5280240,0x00000000,0x00000000}},	//   _äksa_, _ተነጽሎ, --, --, 
   {{0xd04c013f,0x2a7c02e2,0xe70802f2,0x66100014}},	//   _ɔkɔn, _koub_, _رتان_, _یژکا, 
   {{0x05747092,0x3dc4012d,0x00000000,0x00000000}},	//   _لاتد, żowi_, --, --, 
   {{0xa508025c,0x00000000,0x00000000,0x00000000}},	//   _གསིག_, --, --, --, 
   {{0xa28401ed,0x93bc0356,0x706000c7,0x26dc00c0}},	//   ئیکو, rgăr, аҕьҵ, lmuo_, 
   {{0x3f9c026c,0x9f5800e4,0x53480354,0x00000000}},	//   àtu_, yarõ_, _пăрă, --, 
   {{0x2ee8007f,0x6d580124,0x00000000,0x00000000}},	//   _cicf_, _ġuar, --, --, 
   {{0xee340395,0x9f5800c7,0x80d404af,0x00000000}},	// [22ec0] ънт_, varõ_, _मीथे, --, 
   {{0xdbe40241,0x00000000,0x00000000,0x00000000}},	//   _yèèk, --, --, --, 
   {{0x9f580022,0x26dc0064,0x00000000,0x00000000}},	//   tarõ_, kmuo_, --, --, 
   {{0x201958a0,0x387c0175,0x852001ad,0xca742477}},	//   lari_, _sotr_, _मिंट_, лучы, 
   {{0x2a7c033b,0x2018009d,0x26dc0024,0xf1bc01d3}},	//   _doub_, oari_, dmuo_, lgár_, 
   {{0x68408cc7,0x3eb001bf,0xdb1c0108,0x00000000}},	//   инча, lnyt_, _pyrä, --, 
   {{0x2018009d,0x387c0129,0xe7540212,0xf090011a}},	//   iari_, _votr_, вищі_, שנו_, 
   {{0x201958a1,0x6b8158a2,0x3eb0049b,0xe66000a7}},	//   hari_, änge, nnyt_, атьо, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x201958a3,0x3eb0049b,0xbb380220,0xf1bc01d3}},	//   jari_, hnyt_, _ءﯨﺴﻮ, zgás_, 
   {{0x53340006,0xddc401ef,0x00000000,0x00000000}},	//   ыент, jjiž, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x20193417,0xf2dc0393,0x3eb158a4,0xf1bc03b2}},	//   fari_, rmâ_, dnyt_, vgás_, 
   {{0x201958a5,0x64a04fd5,0xf36558a6,0x533558a7}},	//   gari_, _кача, _атин, _бект, 
   {{0x2ca0025c,0xb8fc0327,0xee7001ec,0x59a4000d}},	//   _rmjd_, _ྣེ_, аңны, _खेसर, 
   {{0x9e74049e,0x201958a8,0x91c400d1,0x5eb558a9}},	//   لۇپت, aari_, _бәгл, айст, 
   {{0x201958aa,0xd1d40023,0xf1bc00e5,0x00000000}},	// [22ed0] bari_, ረርቲ_, rgás_, --, 
   {{0x6538011a,0x9f5800e4,0x00000000,0x00000000}},	//   ועמד, tarô_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7e980a28,0xda080b24,0x00000000,0x00000000}},	//   ṃpra, نيمه_, --, --, 
   {{0x6b8001e3,0x9aa41291,0x00000000,0x00000000}},	//   ängb, جمنو, --, --, 
   {{0x99d40346,0x2bd80807,0x00000000,0x00000000}},	//   جتما, _भरपा, --, --, 
   {{0x46a558ab,0x84c40131,0x9be40816,0x2dc80150}},	//   лакв, қәдд, _вітк, _ﺒﻜﻠﻤ, 
   {{0x85780261,0xeb0c0490,0x00000000,0x00000000}},	//   есот_, ाठीत_, --, --, 
   {{0x201958ac,0x98a40064,0x1a683c5a,0x00000000}},	//   yari_, _gpmį_, _جینی_, --, 
   {{0x201958ad,0x291c0481,0x00000000,0x00000000}},	//   xari_, _ivua_, --, --, 
   {{0x3eb00664,0xaab41414,0x58840354,0x00000000}},	//   ynyt_, _अदाक, _тыта, --, 
   {{0xe2842097,0xfbd00375,0x00000000,0x00000000}},	//   рғин, מתי_, --, --, 
   {{0x3618193a,0x04444f55,0xf2a000d1,0x41dc012d}},	//   _سرنگ_, _белн, сияп, नेंस, 
   {{0x03180491,0x291c0451,0x50b558ae,0x201958af}},	//   _كتبت_, _mvua_, ассу, uari_, 
   {{0x3eb00334,0x935801e0,0xdbe401e1,0x03a400f5}},	//   tnyt_, _арыу_, _tèék, _щико, 
   {{0x4fc00116,0x00000000,0x00000000,0x00000000}},	//   تەپە, --, --, --, 
   {{0xa3e40562,0xafe004a9,0xdbdc02fb,0x3eb0005c}},	// [22ee0] _मृत_, _қоюл, _vším, rnyt_, 
   {{0x201958b0,0x3eb0005c,0x00000000,0x00000000}},	//   qari_, snyt_, --, --, 
   {{0x3ea558b1,0x3eb001bf,0x99800003,0x00000000}},	//   _бинг, pnyt_, żiż_, --, 
   {{0x7e540f37,0xfd94013d,0x1a040022,0x00000000}},	//   _стоц, _йөзә_, рҿам, --, 
   {{0xa96440cd,0xada0010b,0x6fb00214,0x2fd40682}},	//   лица_, _гаял, _نمیا, _لوید_, 
   {{0x6b80007c,0x81b400eb,0x00000000,0x00000000}},	//   ängc, _ঝরা_, --, --, 
   {{0xb6c401c6,0x32080210,0x00000000,0x00000000}},	//   лсий, ybcy_, --, --, 
   {{0x21201326,0xdb081bce,0x00000000,0x00000000}},	//   _ovih_, _ñoña, --, --, 
   {{0xddc4038f,0x3f880122,0xf48558b2,0xf6084fe0}},	//   jjiż, hybu_, гунн, وتکه_, 
   {{0xb80800c6,0xe80810eb,0x2bd8012d,0x00000000}},	//   _أيام_, _स्पा_, _भरमा, --, 
   {{0x7ae0396f,0xdce400e2,0x00000000,0x00000000}},	//   omot, dziļ, --, --, 
   {{0x7bcc0ea0,0x81ac0011,0x3f880064,0x00000000}},	//   _mybu, কথন_, dybu_, --, 
   {{0x7ae13053,0xe5a01f5a,0x60f8005b,0xa5040114}},	//   imot, _лици, лняя_, _беча_, 
   {{0x92b400bd,0x7ae158b3,0x00000000,0x00000000}},	//   ঝতে_, hmot, --, --, 
   {{0x7ae0049f,0xdb1c08a5,0x929558b4,0x5ec00154}},	//   kmot, _eyrú, _вайц, ্ষনে, 
   {{0x5e5800d6,0x00000000,0x00000000,0x00000000}},	//   лися_, --, --, --, 
   {{0x21200399,0x7bcc01a9,0x7ae0b180,0x00000000}},	// [22ef0] _gvih_, _aybu, dmot, --, 
   {{0x7ae158b5,0x7bcc12e8,0x00000000,0x00000000}},	//   emot, _bybu, --, --, 
   {{0xef6402e8,0x7bcc0210,0x00000000,0x00000000}},	//   _съпо, _cybu, --, --, 
   {{0x7bcd30d8,0x7ae158b6,0x4e78008f,0x24840023}},	//   _dybu, gmot, _סאָצ, _ዝወስድ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7ae158b7,0x4bc40139,0x78a8007c,0xcb0801f7}},	//   amot, _көег, gifv, _ليسن_, 
   {{0x7ae01d47,0x00000000,0x00000000,0x00000000}},	//   bmot, --, --, --, 
   {{0x068558b8,0x1ac800cf,0x00000000,0x00000000}},	//   ргин, _бууп_, --, --, 
   {{0xbaa406dc,0xd40c0154,0x00000000,0x00000000}},	//   _турқ, _শাড়ি_, --, --, 
   {{0x6aa8a3ba,0xdb1c0022,0xc4b0033f,0x25d8033f}},	//   ligf, _ryrú, ीकेख, खेगी_, 
   {{0x21201326,0x55c558b9,0xe7440150,0x00000000}},	//   _svih_, _қашғ, _сүйе_, --, 
   {{0xd5b801c6,0x6aa8002f,0xb380187f,0x842400db}},	//   _өсч_, nigf, ілял, دىگن, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x66180962,0x7ae00552,0xdb1c00d7,0xf8b0010f}},	//   lauk, zmot, _vyrú, ַשן_, 
   {{0xc0580efb,0x7ae158ba,0x349000d8,0x00000000}},	//   нің_, ymot, _фајр, --, 
   {{0x661958bb,0x932465dc,0x7bcc03cb,0x3afc00b8}},	//   nauk, _ارون, _rybu, _nįpa_, 
   {{0xb2180579,0x6aa8007c,0x7d24009a,0x7de8009d}},	// [22f00] rkæt, digf, شفان, тмаг_, 
   {{0x661958bc,0x628558bd,0x59dc0dba,0x00000000}},	//   hauk, _hoio, _बरबर, --, 
   {{0x661958be,0x62840374,0xeb312374,0x41a800dc}},	//   kauk, _koio, قىلد, _चेतस, 
   {{0x0b5877de,0x661958bf,0x7bcc0122,0x6b80049f}},	//   ыруы_, jauk, _vybu, änga, 
   {{0x661958c0,0x7bcc0034,0xc878010e,0xd1440023}},	//   dauk, _wybu, _huşy_, _ንዋታው, 
   {{0x628460a1,0x7bcc0158,0x6aa801ab,0xb2181924}},	//   _loio, _tybu, aigf, nkær, 
   {{0x19580184,0x78a958c1,0x661801f4,0xee4802d2}},	//   таһы_, rifv, fauk, _þýð_, 
   {{0x628558c2,0x35442b45,0x356846e0,0x661958c3}},	//   _noio, ахов, врон_, gauk, 
   {{0x7d0405b1,0x24580024,0xa50406ed,0x00000000}},	//   _jtks, kšmė_, аења_, --, 
   {{0xd83800f3,0xdb1c005c,0x661812c1,0x66d400e4}},	//   _omči_, _byrø, aauk, rãka, 
   {{0x628558c4,0x661869a9,0xb218005c,0xd9b80154}},	//   _boio, bauk, dkær, _জরিম, 
   {{0x66181fc4,0xdb1c03cd,0xa3e400c7,0x00000000}},	//   cauk, _dyrø, шьыз_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc87800a2,0x00000000,0x00000000,0x00000000}},	//   _buşy_, --, --, --, 
   {{0xdbfc015b,0x60180276,0xb4c004fa,0x62840356}},	//   ইরাস_, рося_, ंवी_, _foio, 
   {{0x628558c5,0xc87800a2,0xf1a400f3,0xc04c01e2}},	//   _goio, _duşy_, _врон, وږۍ_, 
   {{0xb21801bf,0x9df82f5c,0xa1840153,0x00000000}},	// [22f10] bkær, рнут_, _дыэл, --, 
   {{0x6618a013,0x7d00007b,0x5c7400f0,0x00000000}},	//   zauk, íosa, олут, --, 
   {{0x66180357,0x6a140597,0x7bd80268,0x6f60129d}},	//   yauk, لبشر, _ùtul, _بۇزم, 
   {{0x752007d6,0x66180227,0x49740ed0,0x89d800ec}},	//   _ovoz, xauk, йлес, هوار_, 
   {{0x661958c6,0x6aa80165,0xfafc00b8,0x00000000}},	//   vauk, rigf, _śīte_, --, 
   {{0x661958c7,0xab84a6bb,0x5ec0015b,0x6d4c035a}},	//   wauk, _кубк, ্ষণে, _ipca, 
   {{0x661958c8,0x75202a4e,0x6d4d58c9,0x00000000}},	//   tauk, _avoz, _hpca, --, 
   {{0x78a40024,0x661801f4,0xdb10007c,0x06d80166}},	//   _įkve, uauk, öfåg, ыфлы_, 
   {{0x661958ca,0xdb1c00e4,0x195800fd,0x62840165}},	//   rauk, _kyrÿ, _каты_, _roio, 
   {{0x661958cb,0x75202375,0x69d8005a,0x52d00154}},	//   sauk, _dvoz, _izue, _সংগৃ, 
   {{0x6618049b,0xe64047af,0x4614004b,0x628401e4}},	//   pauk, şmış, _هوار, _poio, 
   {{0x6d4d58cc,0x71640022,0x00000000,0x00000000}},	//   _opca, әарг_, --, --, 
   {{0x75202220,0x85041077,0x6284054e,0x742800a2}},	//   _gvoz, _اوتن, _voio, _ỳaşl, 
   {{0x6ab002a0,0x6ab802d2,0x41840023,0xb978011a}},	//   ंचुर, _ljuf, _ዝኸፍእ_, אנשי, 
   {{0x826805f5,0x752158cd,0x628558ce,0x6d4c0857}},	//   _байв_, _zvoz, _toio, _apca, 
   {{0xb218553d,0x6ab801fa,0xee3558cf,0x00000000}},	//   skær, _njuf, йнс_, --, 
   {{0x6b8158d0,0xb4f8010f,0x00000000,0x00000000}},	// [22f20] ängn, ָלער, --, --, 
   {{0xa3a81d8a,0x8db4454e,0x6f100005,0x201c01a8}},	//   _गधा_, істі, ñecé, _þvi_, 
   {{0x6d4c0204,0x69d80789,0xa3d80073,0xf1bc0327}},	//   _epca, _azue, ढेच_, ġġek_, 
   {{0x8aa40212,0x2f58011a,0x2b2800f1,0x00000000}},	//   орід, _עדכנ, اغلی_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe4440127,0x00000000,0x00000000,0x00000000}},	//   _عض_, --, --, --, 
   {{0x656958d1,0x9f580407,0x29180309,0x7520013a}},	//   _argh, mbró_, šqap_, _svoz, 
   {{0x6d4c0857,0x6ab80200,0x675000d1,0x00000000}},	//   _ypca, _gjuf, سخىر, --, 
   {{0xb4b0010b,0x9d4c01ec,0xf76400ec,0x555400e5}},	//   зипә, есiн, _گهاٽ, تھار, 
   {{0xb4c02de3,0x81ac0eac,0x00000000,0x00000000}},	//   ंवे_, কথা_, --, --, 
   {{0x656878ec,0x0a400092,0x6c78010f,0xe4640150}},	//   _ergh, _የምሥራ, אריד, сшыл_, 
   {{0x3208009d,0x44b4004e,0x2bd8000d,0x00000000}},	//   ыхон_, йбөс, _भरसा, --, 
   {{0xad984714,0xe2980953,0x71700137,0x00000000}},	//   _afún, саў_, سۇدا, --, 
   {{0xacb8145e,0x13943943,0xf8b812eb,0x00000000}},	//   _avûn, _милю, ेविय, --, 
   {{0x6d4c00d8,0x5f94b849,0x00000000,0x00000000}},	//   _spca, пирт, --, --, 
   {{0xdef90bf3,0x835001d9,0x00000000,0x00000000}},	//   сыр_, _کھیا, --, --, 
   {{0xad980241,0x00000000,0x00000000,0x00000000}},	// [22f30] _efún, --, --, --, 
   {{0xb324031c,0x6b8001e3,0x00000000,0x00000000}},	//   _རྗོང_, ängo, --, --, 
   {{0x9de80014,0x60c000e5,0x00000000,0x00000000}},	//   لفہٕ_, émme, --, --, 
   {{0xe808813f,0x38c8065f,0x00000000,0x00000000}},	//   सुना_, یاوی_, --, --, 
   {{0x2bd82017,0xe9a802e9,0x2004012d,0x6d4c0857}},	//   _भरवा, ددان_, śmie_, _upca, 
   {{0x9f58011c,0xd8380cf4,0xcc8403e6,0xb4c000e1}},	//   mbrò_, _omču_, _گۆڕه_, ंवो_, 
   {{0xdb1c00e4,0xed5c02d2,0x00000000,0x00000000}},	//   _kyrý, _hsþ_, --, --, 
   {{0x69d801c4,0x4528a8dc,0xd1e00023,0x00000000}},	//   _tzue, ажин_, ናራት_, --, 
   {{0xd50801d5,0x00000000,0x00000000,0x00000000}},	//   یغین_, --, --, --, 
   {{0x032410f9,0xc324487f,0x588401c0,0xdce4031c}},	//   одон, омок, _ныха, vviċ, 
   {{0x68f802f6,0xf8b0011a,0x8ddc01ec,0x00000000}},	//   _huud, _קשב_, _ﺃﻭﺴﻁ, --, 
   {{0x68f958d2,0x6fa00150,0xbb38010f,0x00000000}},	//   _kuud, _ﺎﺒﻘﺎ_, סערי, --, 
   {{0x68f958d3,0x656958d4,0xa5640753,0xd3f800fe}},	//   _juud, _urgh, _ددان, _আজৰি_, 
   {{0x68f9197c,0x00000000,0x00000000,0x00000000}},	//   _muud, --, --, --, 
   {{0x6b8158d5,0x93241b45,0x68f958d6,0x4ac8085c}},	//   ängl, _فرين, _luud, िकाव, 
   {{0x35cc0307,0xc4c400db,0xd3d800ae,0x00000000}},	//   _हुड़, _اتچو, _ابها_, --, 
   {{0x24841d59,0xb1100075,0x270401fb,0x9f5804cc}},	// [22f40] _konm_, _قويغ, _hđnd_, scrà_, 
   {{0xad9800d2,0x40940a15,0xec740ff1,0xd91001ed}},	//   _tfún, _фрит, опу_, ہیر_, 
   {{0x67200427,0x7de402dd,0x04f400cc,0x00000000}},	//   jsnj, сіңд, _ইবোৰ_, --, 
   {{0x3f6800df,0x68f958d7,0xdb1c00a2,0xd910b32a}},	//   _iĝu_, _buud, _gyrý, فیر_, 
   {{0x18741ed2,0x68f8058a,0xfce4baed,0x7c940798}},	//   згля, _cuud, _момо, _дрвц, 
   {{0xf72817fb,0x24852ef5,0x68f881f1,0x67200b4b}},	//   аций_, _nonm_, _duud, fsnj, 
   {{0xab2558d8,0x69e00153,0xdce4022a,0x781828fe}},	//   _мора_, _įvež, nvič, _नजीक_, 
   {{0x68f80a55,0x224005b1,0x80c405d7,0x6b6001d5}},	//   _fuud, _ncik_, लकुं, _ўкта, 
   {{0x2484033b,0x68f958d9,0xe80817c6,0xdce40118}},	//   _bonm_, _guud, _स्वा_, hvič, 
   {{0x224158da,0x39442e03,0xdce4cc1a,0xf4880138}},	//   _acik_, mtos_, kvič, рщик_, 
   {{0xf96003e6,0x12f00014,0x00000000,0x00000000}},	//   _رۆژێ, ى۪تھ, --, --, 
   {{0x68f8022f,0x39440006,0xdce40219,0xf09c00a3}},	//   _yuud, otos_, dvič, mpài_, 
   {{0x28dc3fec,0xfd4c01f2,0xdb1c00e4,0x68f80009}},	//   _पीडि, rikọ, _ryrý, _xuud, 
   {{0x394558db,0xf8c805f9,0x24840100,0xdb1c0022}},	//   itos_, ाकिय, _gonm_, _syrý, 
   {{0x07f80156,0xeea958dc,0x3944003a,0x929400c7}},	//   _ཕུལཝ_, атак_, htos_, _накц, 
   {{0x394558dd,0x248437b6,0x717004b3,0x52143cc5}},	//   ktos_, _zonm_, _قۇجا, _эдит, 
   {{0x3ebc0008,0x39440e79,0x6ab4000d,0xdb1c013a}},	// [22f50] étta_, jtos_, _अदौर, _vyrý, 
   {{0x68f958de,0xa3cc3885,0x00000000,0x00000000}},	//   _ruud, _वुड_, --, --, 
   {{0x5184006c,0x68f958df,0x3944003a,0xdce40122}},	//   _фуқа, _suud, etos_, cvič, 
   {{0x68f8033d,0xdb1c102c,0x39447e2b,0x6720d5e4}},	//   _puud, _ayró, ftos_, vsnj, 
   {{0x68f80014,0xb3400213,0x394456ce,0xd6d00154}},	//   _quud, əçev, gtos_, াগায, 
   {{0x26cc00f3,0x00000000,0x00000000,0x00000000}},	//   _skgo_, --, --, --, 
   {{0x39440393,0x2484007f,0x68f80254,0x00000000}},	//   atos_, _ronm_, _wuud, --, 
   {{0x2484083a,0x06083580,0x68f958e0,0x39446e98}},	//   _sonm_, щник_, _tuud, btos_, 
   {{0x394558e1,0x24840100,0xdce402f0,0x04440395}},	//   ctos_, _ponm_, zvič, пепн, 
   {{0x580400d1,0x00000000,0x00000000,0x00000000}},	//   _يوقك, --, --, --, 
   {{0x42c89c22,0x270401fb,0x0a40001f,0x7c2803b2}},	//   йгон_, _qđnd_, _የምስራ, ófri, 
   {{0xe730016b,0x24840100,0x00000000,0x00000000}},	//   mrε_, _wonm_, --, --, 
   {{0x248558e2,0xdb240332,0xc0bc01f3,0x31200139}},	//   _tonm_, ásúl, _ሶሻል_, ндяг, 
   {{0xdce41758,0x03a4084c,0x7eb401b8,0x00000000}},	//   tvič, _нило, küpä, --, 
   {{0x394400dd,0xe8002983,0x2d8c005c,0x00000000}},	//   ztos_, _ललना_, øgen_, --, 
   {{0x2241436e,0x39440024,0x7ff400db,0x00000000}},	//   _ucik_, ytos_, تسڭا, --, 
   {{0xd83801ef,0x00000000,0x00000000,0x00000000}},	// [22f60] _mmčr_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6ff805d0,0x3944045a,0x6e2c01e3,0x00000000}},	//   _להיפ, wtos_, ånbö, --, 
   {{0x394413fd,0x6f00003e,0x9e7419c5,0x8b64007b}},	//   ttos_, _énca, _تۇرت, ظالم, 
   {{0x394558e3,0x90a42651,0x8eb0237e,0x00000000}},	//   utos_, _رحیم, _شەكت, --, 
   {{0x6d4006c8,0xe730013f,0x7ce00fac,0x00000000}},	//   ̄nak, frε_, fôre, --, 
   {{0x7e6402d1,0x7c3c010a,0xf1d0000d,0x76a82901}},	//   _kakp, mgpr, _धुनन, йтив_, 
   {{0x7e64ac66,0xdb1c0034,0x6fe40098,0x7c3c072b}},	//   _jakp, _wyró, lécé, lgpr, 
   {{0x7e643209,0xf7f406d0,0x7c3c017a,0x59a400dc}},	//   _makp, _فساد, ogpr, _खेचर, 
   {{0x7c3c14dc,0x7ce00295,0x00000000,0x00000000}},	//   ngpr, bôre, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x36340150,0xc76400f7,0x00000000,0x00000000}},	//   _ءراس, _زامى, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x53340228,0xb190010b,0xfbbc08df,0x6b8001e3}},	//   _жект, _үлкә, ्थाम, ängk, 
   {{0xa9200153,0x96b00118,0xf42000cc,0x00000000}},	//   ėžia, _जगाउ, _মাপৰ_, --, 
   {{0x7c3c00ef,0x00000000,0x00000000,0x00000000}},	//   egpr, --, --, --, 
   {{0x7e64e3ba,0xad9800d2,0x5d5558e4,0x98dc012d}},	// [22f70] _dakp, _tfúm, нктт, यताए, 
   {{0x7e640857,0x7c3c3402,0x00000000,0x00000000}},	//   _eakp, ggpr, --, --, 
   {{0x7e640270,0x53701ef7,0x00000000,0x00000000}},	//   _fakp, _ስራዊት_, --, --, 
   {{0x7c3c0196,0xee3c0022,0xbf5400e5,0x00000000}},	//   agpr, _omýi_, _کریں, --, 
   {{0xf42003d4,0xd9140006,0xc928009d,0x00000000}},	//   _মানৰ_, едчы, цолж_, --, 
   {{0x764000e4,0xb34406be,0x00000000,0x00000000}},	//   _acoy, _keçı, --, --, 
   {{0xee3c00e4,0x00000000,0x00000000,0x00000000}},	//   _amýi_, --, --, --, 
   {{0x1b2004c5,0xa3e42802,0x00000000,0x00000000}},	//   মূহে_, _मृग_, --, --, 
   {{0xc4e405f5,0x00000000,0x00000000,0x00000000}},	//   мжий, --, --, --, 
   {{0x764003ac,0x00000000,0x00000000,0x00000000}},	//   _ecoy, --, --, --, 
   {{0x6b8001e3,0x31a80154,0xd7f873b3,0xd54801d3}},	//   ängh, _গুলশ, _хуу_, _ہجوم_, 
   {{0xd6d8084c,0xdb1c09e8,0x00000000,0x00000000}},	//   _етч_, _myrð, --, --, 
   {{0x7e6558e5,0x8ec404c5,0xf48403e6,0xd1745550}},	//   _rakp, ্ষাগ, سایی, ныры, 
   {{0x7e6558e6,0x4420032e,0x66800066,0xb4f8011a}},	//   _sakp, _þh_, _آیکل, _ופסי, 
   {{0x7e64b4bf,0xb82003d4,0x64400332,0xdb1c02d2}},	//   _pakp, _নামত_, _icni, _nyrð, 
   {{0x3d0060d3,0x00000000,0x00000000,0x00000000}},	//   _वंदे_, --, --, --, 
   {{0x6fe473a0,0x00000000,0x00000000,0x00000000}},	// [22f80] técé, --, --, --, 
   {{0xb21804ce,0x7e6558e7,0x80a558e8,0xdb1c148b}},	//   hjæl, _wakp, _آمدن, _byrð, 
   {{0x644158e9,0x30780302,0xbea4247f,0x7c3c0373}},	//   _mcni, _ואינ, _жанк, rgpr, 
   {{0xeb94023a,0x00000000,0x00000000,0x00000000}},	//   ьих_, --, --, --, 
   {{0x6440054e,0x00000000,0x00000000,0x00000000}},	//   _ocni, --, --, --, 
   {{0xf2b81524,0x7640062c,0xdb1c03b2,0xecb000c7}},	//   _उद्घ, _scoy, _fyrð, _иӡхы, 
   {{0x6b60be72,0xdb1c0a87,0x00000000,0x00000000}},	//   _икра, _gyrð, --, --, 
   {{0xa800151e,0x2b44002e,0x00000000,0x00000000}},	//   нзәл, ànce_, --, --, 
   {{0xca7401e0,0x00000000,0x00000000,0x00000000}},	//   _яуры, --, --, --, 
   {{0xad9800d7,0x00000000,0x00000000,0x00000000}},	//   _sfúk, --, --, --, 
   {{0xb218005c,0x79800139,0x00000000,0x00000000}},	//   bjæl, lxow, --, --, 
   {{0x6b8158ea,0x6440036e,0x84540137,0x62800108}},	//   ängi, _ecni, _ۋىنچ, ömop, 
   {{0x7c2cb485,0x7980011f,0xb34406be,0x00000000}},	//   _odbr, nxow, _seçı, --, 
   {{0xb3d00116,0x91c40116,0x61f80006,0x00000000}},	//   _ийлә, _җәмл, ьняў_, --, 
   {{0xdfd80801,0xf2c558eb,0xb5940133,0xdfd40006}},	//   дът_, _осин, _رێگا_, воры, 
   {{0x7c2c0334,0x00000000,0x00000000,0x00000000}},	//   _adbr, --, --, --, 
   {{0x3d180316,0xd90487a9,0xe2c800db,0x00000000}},	// [22f90] मीले_, _خی_, _تويو_, --, 
   {{0x61e037be,0xed5c0419,0x00000000,0x00000000}},	//   ümle, šľou_, --, --, 
   {{0x2b440356,0xcb0801f7,0x00000000,0x00000000}},	//   înc_, سيشن_, --, --, 
   {{0x7c2c03ac,0xdf580066,0x00000000,0x00000000}},	//   _edbr, _کشیش_, --, --, 
   {{0x7980004b,0x00000000,0x00000000,0x00000000}},	//   gxow, --, --, --, 
   {{0xf09c381a,0xdde43c1a,0x26f4000d,0x00000000}},	//   mpàs_, _рәсү, ँद्र_, --, 
   {{0x46f558ec,0xb904038e,0x1ca80014,0x86f400d8}},	//   нчит, _यी_, _تێلی_, нџич, 
   {{0x0564026a,0x28dc05d7,0x1ac80137,0x4428002b}},	//   евин, _पीरि, _жууп_, _śa_, 
   {{0x04b43993,0x5a4402d5,0x64400205,0x00000000}},	//   есня, _шэра, _pcni, --, 
   {{0xb21804ce,0xd874212d,0x1ccc0135,0xd90c1424}},	//   sjæl, _لامب, ྲོར_, _بیو_, 
   {{0xb218005c,0x00000000,0x00000000,0x00000000}},	//   pjæl, --, --, --, 
   {{0x3ce4033f,0x00000000,0x00000000,0x00000000}},	//   _जीने_, --, --, --, 
   {{0x36180a7c,0x00000000,0x00000000,0x00000000}},	//   _זונד, --, --, --, 
   {{0x09a8031c,0x00000000,0x00000000,0x00000000}},	//   _བཟླ_, --, --, --, 
   {{0x1ccc038f,0x1474215c,0xada0036b,0xf4841550}},	//   ྲོལ_, _جانج, ҳатл, _ساوی, 
   {{0x7c6407d6,0x29180784,0xad980241,0xdb1c0108}},	//   کارل, šqay_, _ogúd, _kyrö, 
   {{0xed540cfc,0xd164005e,0x6da00faa,0xee352163}},	// [22fa0] нот_, _анық, гита, энт_, 
   {{0x61e558ed,0xad8421ef,0xfbbc095f,0xe0580345}},	//   _izil, راقۇ, ्थलम, _تیست_, 
   {{0x20180135,0x442558ee,0x00000000,0x00000000}},	//   mbri_, ial_, --, --, 
   {{0xa3c00118,0x4a742fe5,0x2018000d,0x6fb40208}},	//   káží_, кычт, lbri_, _ýnhữ, 
   {{0xfaa40aa5,0x2c1c1c82,0x7d0001ab,0xd83801ef}},	//   _ҷаво, _পাৰে_, ìosd, _alča_, 
   {{0x7c2c04ce,0x61e42251,0xb764b42d,0x20180100}},	//   _udbr, _mzil, етий, nbri_, 
   {{0x59dc1533,0xf0900302,0x67d158ef,0x3ce400c5}},	//   _बरकर, רנו_, лошу, _जीये_, 
   {{0x61e558f0,0x44240731,0x41b00490,0x0a380139}},	//   _ozil, eal_, ीपास, _очуы_, 
   {{0x442558f1,0x61e40085,0x3a240589,0x6af400db}},	//   fal_, _nzil, maop_, _سىكس_, 
   {{0x442558f2,0x1828034c,0x53900023,0x00000000}},	//   gal_, _آقای_, _ዝመውት_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x442558f3,0x3dc4033f,0x2018025c,0x6fe401ef}},	//   aal_, żowy_, ebri_, _lécí, 
   {{0x442558f4,0x00000000,0x00000000,0x00000000}},	//   bal_, --, --, --, 
   {{0x442558f5,0x61e558f6,0x00000000,0x00000000}},	//   cal_, _dzil, --, --, 
   {{0x61e41373,0x70500133,0xee3c01ef,0x2370007b}},	//   _ezil, نۆکا, _omýt_, _مايح, 
   {{0x5e680640,0x00000000,0x00000000,0x00000000}},	//   нјуг_, --, --, --, 
   {{0x20180622,0xcdc400d1,0x614400f3,0x00000000}},	// [22fb0] bbri_, тәнп, _бења, --, 
   {{0x2d849ac0,0xc60c242e,0xc33c001f,0x00000000}},	//   ćne_, _सभ्य_, _በተጠቀ, --, 
   {{0xf09c5c17,0xe9dc0419,0x00000000,0x00000000}},	//   spàs_, _šú_, --, --, 
   {{0x442558f7,0xd9300023,0xb60400c0,0x00000000}},	//   zal_, _ብተዘዋ, nešę, --, 
   {{0x442558f8,0x6d4801c3,0x00000000,0x00000000}},	//   yal_, àgad, --, --, 
   {{0x442558f9,0xf8ac00f1,0xa3c00118,0x00000000}},	//   xal_, يکل_, váží_, --, 
   {{0x23cc3a19,0x46a41b10,0xf89006ed,0xe7b000db}},	//   _सुंद, какв, рајќ, دۅاد, 
   {{0x442558fa,0x6b802e1b,0x78740209,0x00000000}},	//   wal_, ängu, ейәр_, --, 
   {{0x7af80268,0x00000000,0x00000000,0x00000000}},	//   _ètta, --, --, --, 
   {{0xa3c0219b,0xee3c02d2,0x44252d09,0xe580009d}},	//   ráží_, _flýg_, ual_, втүү, 
   {{0x61e400dd,0xf8ac04fb,0xa3c00216,0xd6d958fb}},	//   _szil, _بکن_, sáží_, ьтә_, 
   {{0xddc400a8,0x201803a2,0x66d4035b,0x00000000}},	//   ndiţ, wbri_, tãku, --, 
   {{0xe3d000cf,0x00000000,0x00000000,0x00000000}},	//   _өйдө, --, --, --, 
   {{0x44248e3d,0x04c8082e,0x90c40220,0x4384007b}},	//   qal_, _توتي_, лғыз_, _للتق, 
   {{0x03a41b74,0xadc001e1,0x2018036e,0x00000000}},	//   _шико, _ibẹb, rbri_, --, 
   {{0x5ba43e64,0x41b4007b,0xf7700677,0xcf243592}},	//   ңлағ, _لمعر, סקן_, طرفي, 
   {{0x61e558fc,0x00000000,0x00000000,0x00000000}},	// [22fc0] _uzil, --, --, --, 
   {{0xdee401b9,0x00000000,0x00000000,0x00000000}},	//   тоғи, --, --, --, 
   {{0x69d80098,0x00000000,0x00000000,0x00000000}},	//   _ayue, --, --, --, 
   {{0x2b4407de,0x7f4c0334,0x00000000,0x00000000}},	//   ànca_, mtbq, --, --, 
   {{0x204802d3,0xd954fae3,0x8ac400d1,0xa9643eae}},	//   _ዝምስክ, انتخ, уқта_, кица_, 
   {{0xf770f082,0xa8140131,0x69d80142,0x7d14152c}},	//   لاع_, پتور_, _dyue, mpys, 
   {{0x6b805df4,0xb6c558fd,0x7d14007c,0x00000000}},	//   ängt, ксий, lpys, --, 
   {{0x7d14002d,0x3ce54eb8,0xee3c013a,0x00000000}},	//   opys, _जीते_, _umýt_, --, 
   {{0x69d80369,0x7d14005b,0x23640200,0x8e6c0023}},	//   _gyue, npys, _asnj_, _ትኽእሉ_, 
   {{0xf42003d4,0xb864732b,0x7d1400c7,0xf8b40037}},	//   _মাহৰ_, _جارو, ipys, _अगिय, 
   {{0x387c0262,0x92945ce6,0x291c0036,0xe46401ec}},	//   _intr_, ганц, _zwua_, тшыл_, 
   {{0xf30005f5,0x387c05b1,0x1db407b6,0x00000000}},	//   лжүү, _hntr_, ूपात, --, 
   {{0xe2980953,0x75e4022e,0x985c00de,0x853558fe}},	//   таў_, kаzi, _lāči_, _مونچ, 
   {{0x64a00063,0x5edc00cc,0x00000000,0x00000000}},	//   _ваља, _মংগে, --, --, 
   {{0xf1d05690,0xddc400a2,0x75e001f9,0x636401c4}},	//   _धुरन, lgiň, _परुळ, _арыг_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdef958ff,0xacb8019f,0xdd9400db,0x00000000}},	// [22fd0] тыр_, _rwûb, ааты, --, 
   {{0xf2dd5900,0xb9080241,0x05d4000d,0x00000000}},	//   llâ_, _wakọ_, _डँसब, --, 
   {{0x7d140022,0x6b6c00b8,0x00000000,0x00000000}},	//   apys, _ṛgbh, --, --, 
   {{0x9f600158,0x387d5901,0x46e0000d,0x4ee000cc}},	//   ørås_, _antr_, _पठइह, _মূৰল, 
   {{0x7d00007b,0xdd840139,0x00000000,0x00000000}},	//   íost, _кырп, --, --, 
   {{0x69d802c4,0x6b805df4,0x7e6001e4,0x00000000}},	//   _vyue, ängs, ĵope, --, 
   {{0xaa6400f3,0x00000000,0x00000000,0x00000000}},	//   _итак, --, --, --, 
   {{0xdb2406d5,0x387c9ec6,0xddc400c0,0x00000000}},	//   _úsái, _entr_, ldiš, --, 
   {{0x3ebc01a8,0x7c3002d2,0x940c06be,0x00000000}},	//   étti_, _ákrö, lkdə_, --, 
   {{0x2a7c0b89,0x823435e6,0xddc55902,0x00000000}},	//   _hnub_, گردا, ndiš, --, 
   {{0x6f000005,0xf2dc011f,0xe3d8009e,0xddc400c0}},	//   _énch, flâ_, ডেনব, idiš, 
   {{0x97a4b6c2,0xaad04a18,0x38a003b2,0x163400c0}},	//   _трул, तविक, _iðra_, _веця, 
   {{0x66195903,0xd4695904,0xd1c402d3,0x00000000}},	//   mbuk, رحیم_, _ሸፋቱ_, --, 
   {{0x66187d06,0x26dc003a,0xddc40427,0x4344041b}},	//   lbuk, lluo_, jdiš, _бекв, 
   {{0x4f9418bc,0x2d8d5905,0x3f9c0232,0xf8b00302}},	//   арту, ägen_, átu_, משך_, 
   {{0x66195906,0x00000000,0x00000000,0x00000000}},	//   nbuk, --, --, --, 
   {{0x661800ec,0x3ea00270,0x21200098,0xcd800092}},	// [22fe0] ibuk, _vlkt_, _uwih_, _ናቸውና_, 
   {{0x2a7c0280,0x6618020b,0xbc6833d2,0xe2c800ec}},	//   _anub_, hbuk, عمان_, _سوڌو_, 
   {{0xeb942c1d,0xddd40034,0xefb802d3,0x7de401ec}},	//   лиф_, _łańc, ሰነየ_, тіңд, 
   {{0xd9106ff0,0xdce4110c,0x7ce00419,0x00000000}},	//   قیر_, kvić, pôro, --, 
   {{0x38a02242,0x2a7c0135,0x1dc800c5,0x661801e3}},	//   _aðra_, _dnub_, _रखित, dbuk, 
   {{0x4638001f,0x66180175,0x3154008f,0x00000000}},	//   _በሀገራ, ebuk, ריסן_, --, 
   {{0xd6d0d371,0x26dc008f,0x7d040158,0xf2dc011f}},	//   يقت_, fluo_, _huks, ylâ_, 
   {{0x66195907,0x6b80049f,0xad9800d2,0x56940075}},	//   gbuk, ånge, _tfút, раит, 
   {{0x7d04a9b2,0x6a800408,0x00000000,0x00000000}},	//   _juks, _улта, --, --, 
   {{0x7d055908,0x66180158,0xb88002fb,0x344801c6}},	//   _muks, abuk, čísl, хчин_, 
   {{0x7d055909,0xc0c80201,0x66186c29,0x128c0023}},	//   _luks, _በሌላ_, bbuk, _ንረክብ_, 
   {{0x66e1590a,0x26dc00d8,0xddc44bee,0x2bf4011a}},	//   _лоха, cluo_, zdiš, טמין_, 
   {{0x7d05590b,0x65100451,0x66d0009f,0x00000000}},	//   _nuks, _هونئ, _اينئ, --, 
   {{0x92b42158,0xc5ec00aa,0xef6402e8,0xb62c02dd}},	//   জকে_, _غړي_, лъбо, _ﺒﻨ_, 
   {{0x7d042ba4,0x2894010f,0x64c00769,0x00000000}},	//   _auks, נדלן_, _ديول, --, 
   {{0x7520006f,0x93e4036b,0x8e15590c,0x00000000}},	//   _kwoz, _йўқл, рдац, --, 
   {{0x01e401ec,0x00000000,0x00000000,0x00000000}},	// [22ff0] _ﺍﺭﻳﻨ, --, --, --, 
   {{0x7521590d,0xd2500014,0x2a7c0076,0x7d0402d3}},	//   _mwoz, _اچھ_, _snub_, _duks, 
   {{0x0a1407c0,0xdce40cf4,0xddc4bdd8,0x66191cd5}},	//   لواح, zvić, rdiš, ybuk, 
   {{0x752004ba,0x49745e0c,0x6e6400f3,0x00000000}},	//   _owoz, илес, _стож, --, 
   {{0x48242928,0x6b8001e3,0x00000000,0x00000000}},	//   لىشق, ångb, --, --, 
   {{0x661804ba,0x25e80a8a,0x475801f4,0x00000000}},	//   wbuk, _चरबी_, врия_, --, 
   {{0x7521590e,0xad9800d2,0x07a5590f,0x2d4c00fd}},	//   _awoz, _tfús, райн, lüe_, 
   {{0x7d0407d6,0x75215910,0xe7680150,0x1a68030f}},	//   _yuks, _bwoz, _ۋحان_, _میمی_, 
   {{0x66182c62,0x1ac8004e,0x00000000,0x00000000}},	//   rbuk, _сурп_, --, --, 
   {{0x1ccc1b4b,0x57a40588,0x00000000,0x00000000}},	//   ྲོག_, ршәа, --, --, 
   {{0x23cc1a04,0x75215911,0x74e401c6,0x070800ec}},	//   _सुखद, _ewoz, рдэг_, _شيشي_, 
   {{0x45d404f0,0x85b86dc2,0x48c001af,0x00000000}},	//   _коес, _илес_, _ыҙҙа, --, 
   {{0x7520007f,0x6fd804fa,0x2d8d5912,0xb1400229}},	//   _gwoz, _मुबं, ägel_, онял, 
   {{0x7d046bd6,0xb4b43531,0x8234014d,0x00000000}},	//   _ruks, _кичә, درگا, --, 
   {{0x7d055913,0x00000000,0x00000000,0x00000000}},	//   _suks, --, --, --, 
   {{0xee355914,0x7d055915,0x3f68013e,0x00000000}},	//   инс_, _puks, ниҳо_, --, 
  
   {{0x2d4d3b5a,0x00000000,0x00000000,0x00000000}},	// [23000] güe_, --, --, --, 
   {{0xed54136b,0x6568010a,0x2ca400c7,0x7ce000d7}},	//   роф_, _msgh, акуп_, môrk, 
   {{0x9f4c0598,0x80a53bdb,0xb2180fac,0x6b80007c}},	//   ädä_, _ممکن, rjæv, ängp, 
   {{0x1ccc0003,0xad980248,0xfaa40261,0x3ce401f9}},	//   ྲོང_, _igún, јадо, _जीरे_, 
   {{0x2d8c00b5,0xfd9400d1,0x6fb00214,0x19595916}},	//   øget_, _төвә_, _همیا, уалы_, 
   {{0x75200810,0x00000000,0x00000000,0x00000000}},	//   _rwoz, --, --, --, 
   {{0x2b7404f2,0x56955917,0x00000000,0x00000000}},	//   _پینگ_, йакт, --, --, 
   {{0x39140ee8,0x50540023,0xd0000154,0xaa40db2e}},	//   _نورز, _ምዝንባ, ্রয়_, _месл, 
   {{0xa96418d9,0x74c40801,0x7ae15918,0xe9640818}},	//   _кита_, ищож, mlot, _катл_, 
   {{0xed540375,0xad9801e1,0xa8440228,0xf7d40024}},	//   סביר_, _ogún, _ەلەم_, _кіеў, 
   {{0x7ae0011c,0x00000000,0x00000000,0x00000000}},	//   olot, --, --, --, 
   {{0x7ae04a5e,0xee3c00a2,0x87b8009d,0x00000000}},	//   nlot, _olýa_, _суут_, --, 
   {{0xad980241,0x752000ca,0x7ae15919,0xc1a40150}},	//   _agún, _uwoz, ilot, бырқ, 
   {{0x7ae1591a,0xe4d043f6,0x672c005b,0x7bcc02d0}},	//   hlot, _وتوب, _äijä, _oxbu, 
   {{0x9f340046,0xee3c010e,0x92940108,0x00000000}},	//   жесі, _alýa_, _гайц, --, 
   {{0x27e004ce,0x320c01d3,0x03c40111,0x7ae001d3}},	//   _øjne_, _ügy_, _усім, jlot, 
   {{0x7ae1591b,0x6d4c0408,0xad980ca8,0xaee0002b}},	// [23010] dlot, _qqca, _egún, _akṣe, 
   {{0x7ae1591c,0x6db40e51,0x7778005a,0x1ccc0327}},	//   elot, _ağaç, _ortx, ྲོཊ_, 
   {{0x7ae1591d,0xd838007f,0xcb540640,0xef6402e8}},	//   flot, _elčk_, свећ, _тъпо, 
   {{0x7ae0579d,0x2d8c00b5,0xaea00150,0xceb8008e}},	//   glot, øges_, _بەري, _сәг_, 
   {{0x777805f5,0x7ea80162,0x200c00d0,0xe9a801c8}},	//   _artx, _dýpd, ždie_, خدان_, 
   {{0x7ae1591e,0xdf742e07,0xe1180375,0x2c5401ef}},	//   alot, _ادیب, סקופ_, _dědí_, 
   {{0x98480212,0x205800df,0x00000000,0x00000000}},	//   ряча_, ייגל_, --, --, 
   {{0x2c1c0154,0xe8000037,0x00000000,0x00000000}},	//   _পায়ে_, _ललका_, --, --, 
   {{0x7778005a,0xdb243b7b,0x00000000,0x00000000}},	//   _ertx, ásöl, --, --, 
   {{0x44880107,0x00000000,0x00000000,0x00000000}},	//   убон_, --, --, --, 
   {{0x69b80490,0xd87400db,0xe74402dd,0x00000000}},	//   _शेती, _باقب, _түйе_, --, 
   {{0x656801ee,0xd3982cc8,0x00000000,0x00000000}},	//   _tsgh, рәшә_, --, --, 
   {{0x65680477,0xa5643c97,0x7778022e,0x00000000}},	//   _usgh, _خدان, _zrtx, --, 
   {{0x03a8210e,0x1e20033f,0xf8b0010f,0xa4400244}},	//   _مدعو_, बर्ष_, ִשן_, _بێدو, 
   {{0x6d4801ab,0x34900798,0x00000000,0x00000000}},	//   àgan, _хајр, --, --, 
   {{0x422448ad,0x7ce00109,0x3ea41bce,0x00000000}},	//   _удив, môri, óot_, --, 
   {{0x7d24136e,0x6285591f,0x7ae001f5,0x518406ed}},	// [23020] صفان, _inio, vlot, _дуќа, 
   {{0xada0008e,0x6cb000db,0x00000000,0x00000000}},	//   чаул, пөст, --, --, 
   {{0x7ae083c6,0x2d8c04ce,0xeb30581f,0xed54185c}},	//   tlot, øger_, كىلد, _қор_, 
   {{0x6b8001e6,0x7ae122eb,0x00000000,0x00000000}},	//   ånga, ulot, --, --, 
   {{0xb954026a,0x6284009f,0x203c0023,0x00000000}},	//   стећ, _mnio, _ክምስር, --, 
   {{0x7ae15920,0x35681ee3,0x2c540118,0x3aec00e4}},	//   slot, ҳрон_, _vědí_, dýpe_, 
   {{0x7ae05cd5,0x6c800014,0xee3c0118,0x00000000}},	//   plot, _علِم, _mlýn_, --, 
   {{0xf6680722,0x15140117,0x953801f4,0x00000000}},	//   احثه_, одия, азит_, --, 
   {{0xe60c3c19,0xb2180a64,0x4ab80276,0x6a8001a9}},	//   رشي_, kjær, _туря_, _элта, 
   {{0x62852c5c,0xe8f4009b,0x394400c0,0xb82000cc}},	//   _anio, _глу_, muos_, _নাকত_, 
   {{0x7ce00109,0x7778009d,0x39455921,0x3aec00e4}},	//   gôri, _urtx, luos_, aýpe_, 
   {{0x628400ae,0x00000000,0x00000000,0x00000000}},	//   _cnio, --, --, --, 
   {{0x39455922,0x611400bc,0xb218143a,0x6284012d}},	//   nuos_, vělý, fjær, _dnio, 
   {{0x6284127b,0xb21808fb,0xf42003d4,0x2ba80da5}},	//   _enio, gjær, _মাকৰ_, चनमा, 
   {{0xe45400c8,0xf1a804d3,0xdcf406be,0x6018026b}},	//   _ליגט_, _ڕاده_, _şağa, сося_, 
   {{0x62840e89,0xf1a454fe,0xe41400f2,0x394400c0}},	//   _gnio, _грон, _پکیچ_, kuos_, 
   {{0xd83805be,0x78b8007c,0x39440153,0x00000000}},	// [23030] _elči_, _omtv, juos_, --, 
   {{0x39442cd7,0x3b08036e,0x2ca406ea,0x8c5800ae}},	//   duos_, _bubq_, ónd_, ؤلاء_, 
   {{0xce9406bb,0x4af804fb,0x6a142d4b,0xce580a5b}},	//   _данъ, لکرد_, مبشر, _канц_, 
   {{0xdb0801ed,0xdb14010e,0x39440064,0x00000000}},	//   álás, _çaýl, fuos_, --, 
   {{0x39455923,0xdce4008f,0x78b80051,0x00000000}},	//   guos_, lviĝ, _bmtv, --, 
   {{0x58d51ed9,0x7ea802f0,0x07140107,0xe7840118}},	//   почт, _výpe, офия, _váží, 
   {{0x7c3806d9,0x0ac40022,0x1a6801b9,0x00000000}},	//   _ôtra, _дшаҭ, _گینی_, --, 
   {{0x39440115,0x45342be9,0x3aec035b,0x7ea80c5e}},	//   buos_, охот, týpe_, _týpe, 
   {{0x1a6820bf,0x6ab95924,0x3af8008f,0x39440393}},	//   _دینی_, _imuf, _כּמע, cuos_, 
   {{0x62855925,0xd8380427,0xdce400df,0x3aec0124}},	//   _snio, _gdč_, kviĝ, rýpe_, 
   {{0x42c95926,0x290c022e,0x3aec00c7,0x1818009a}},	//   игон_, lqga_, sýpe_, _طآلب_, 
   {{0x3aec0588,0x00000000,0x00000000,0x00000000}},	//   pýpe_, --, --, --, 
   {{0x6ab81418,0xee3c00a2,0xb2180158,0x052804b1}},	//   _mmuf, _alýo_, tjær, _толк_, 
   {{0x03a55927,0x6284068f,0x93246f5d,0x1ccc0327}},	//   _мило, _wnio, _کرون, ྲོབ_, 
   {{0x6ab80a49,0x628401ab,0xc4380131,0x00000000}},	//   _omuf, _tnio, _ﻣﯘﺷﯘ_, --, 
   {{0xa44003e6,0x00000000,0x00000000,0x00000000}},	//   _بێگو, --, --, --, 
   {{0x6b8001e3,0x00000000,0x00000000,0x00000000}},	// [23040] ångn, --, --, --, 
   {{0x6ab8d3e5,0x61e55928,0xfca801f7,0xfbc401f4}},	//   _amuf, _iyil, جارو_, обзо, 
   {{0x60dd5929,0x15f0000d,0x00000000,0x00000000}},	//   morm, _चरभर_, --, --, 
   {{0x38e00ed9,0x60dd592a,0x61e40083,0x3945592b}},	//   _སེངྒ, lorm, _kyil, tuos_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6ab8016b,0x96f807dd,0xbef8005f,0x61e400a3}},	//   _emuf, әеит_, žģīt, _myil, 
   {{0xf0901a4c,0xfaa5592c,0x59a80316,0xd8380010}},	//   ונג_, _даво, कनहर, _vdč_, 
   {{0x60dc8590,0x96341d11,0x61e54b80,0x7e740124}},	//   horm, чниц, _oyil, ndyp, 
   {{0xe60c0058,0x61e5592d,0x39441730,0x60dc01ed}},	//   خشى_, _nyil, quos_, korm, 
   {{0x59c011b1,0x5fbc5690,0x60dd592e,0xe56c00ae}},	//   _शेयर, ोपाल, jorm, ئطي_, 
   {{0x61e4cf3e,0xdecc02d3,0x64a00120,0x64b0007b}},	//   _ayil, ኣምን_, фаќа, بحير, 
   {{0x61e5592f,0xa9040046,0x00000000,0x00000000}},	//   _byil, _ايەل_, --, --, 
   {{0x61e40230,0x7ce0003a,0x00000000,0x00000000}},	//   _cyil, lôru, --, --, 
   {{0x60dc20ac,0x6ab41af8,0xd838033b,0x00000000}},	//   gorm, _आग्र, _elčv_, --, 
   {{0x61e40944,0xb4e40574,0xd2f801c6,0xb4c40073}},	//   _eyil, पती_, _лекц_, ईची_, 
   {{0xdce400df,0x22b800ae,0x00000000,0x00000000}},	//   rviĝ, _وديع_, --, --, 
   {{0xf1a804d3,0x60dd5930,0x61e401ed,0x98bc12eb}},	// [23050] _ڕاگه_, borm, _gyil, ्चाए, 
   {{0x637401e1,0xf0400014,0x00000000,0x00000000}},	//   _ẹnu, _کٹھی, --, --, 
   {{0x0a54001f,0x00000000,0x00000000,0x00000000}},	//   _የምርጫ, --, --, --, 
   {{0xe8c000cd,0x9f60007c,0x00000000,0x00000000}},	//   वच्च, ärås_, --, --, 
   {{0x811c000d,0x00000000,0x00000000,0x00000000}},	//   _बढ़ाओ_, --, --, --, 
   {{0x61e000ee,0xcb340395,0x00000000,0x00000000}},	//   ümli, _негъ, --, --, 
   {{0xd8740014,0xdb5401c6,0x00000000,0x00000000}},	//   بانب, _овры, --, --, 
   {{0x60dd5931,0x6ab95932,0x5b3445cc,0xdecc0023}},	//   zorm, _umuf, _زعفر, ኣምኖ_, 
   {{0x60dd5933,0xf42003d4,0x286800f3,0x00000000}},	//   yorm, _মাজৰ_, _врео_, --, 
   {{0xa78442b5,0x5ae80327,0x60dc02d0,0x00000000}},	//   _وشاو, _འཚོམ, xorm, --, 
   {{0x60dc1df7,0x61e40092,0x00000000,0x00000000}},	//   vorm, _syil, --, --, 
   {{0x60dd5934,0x00000000,0x00000000,0x00000000}},	//   worm, --, --, --, 
   {{0xd17543c5,0x15b90624,0x95c800f3,0x00000000}},	//   мыры, _мышы_, _муља_, --, 
   {{0x65780223,0x00000000,0x00000000,0x00000000}},	//   mvuh, --, --, --, 
   {{0x60dd5935,0x6b8001e6,0x932400e3,0x7ea8010e}},	//   rorm, ångl, _قرين, _aýpa, 
   {{0x60dc373f,0xf770008f,0xafe0360a,0x5ae80327}},	//   sorm, עקן_, хосл, _འཚེམ, 
   {{0x60dcd6a5,0x61e50a07,0x7e755936,0x7ce0002d}},	// [23060] porm, _uyil, rdyp, kôrt, 
   {{0xb1780bd9,0xa6b0009e,0x317802e4,0x3aec03b2}},	//   _פטיר, ুকিয়, _פרימ, dýpa_, 
   {{0x30980302,0xeaac01ed,0x81dc00fe,0xee3c1155}},	//   _השימ, گٹن_, থেশ_, _zlým_, 
   {{0xf42003d4,0x00000000,0x00000000,0x00000000}},	//   _মাছৰ_, --, --, --, 
   {{0xbef81533,0x81dc015b,0xade005dc,0x18740138}},	//   ्दीन_, থের_, _कुपन_, дгля, 
   {{0x65780165,0xbab40811,0x6cb0013d,0xaa4001c6}},	//   dvuh, _کمرب, _пөхт, _үерл, 
   {{0x7c2c005f,0xa8300137,0x00000000,0x00000000}},	//   _iebr, رعوش, --, --, 
   {{0x1ccc03bd,0x7c2ce6a6,0xe7d000db,0x00000000}},	//   ྲོམ_, _hebr, رۅنگ, --, 
   {{0x7c2c3743,0x7ce000e4,0x00000000,0x00000000}},	//   _kebr, sôru, --, --, 
   {{0x7c2d5937,0xb4e4a782,0xa92002fb,0xb4c40073}},	//   _jebr, पते_, ážen, ईचे_, 
   {{0x7c2c013f,0x3f9c03b2,0x00000000,0x00000000}},	//   _mebr, øtul_, --, --, 
   {{0x7c2d5938,0x65cc01ec,0xe73400d8,0x00000000}},	//   _lebr, _ﯗﻟﯩﻠ, _хец_, --, 
   {{0x457039fb,0xa18482df,0x6ef00205,0x00000000}},	//   _аңыр, нырл, nçbe, --, 
   {{0x200c3a4a,0x7c2d5939,0x7ea80306,0xf9ec00fe}},	//   ždin_, _nebr, _rýpa, _ওলাল_, 
   {{0x71247c12,0x81dc00eb,0xa0c44cec,0x00000000}},	//   _کربل, থেল_, ريفو, --, 
   {{0xdce40bb8,0x7c2d593a,0xa2e40120,0x101c06e3}},	//   dviđ, _aebr, _појд, _ब्रश_, 
   {{0x7c2d593b,0x1df8a97f,0xcc982096,0x00000000}},	// [23070] _bebr, зеты_, овац_, --, 
   {{0xd01055de,0x7c2d593c,0x7ea80122,0xf2dc014b}},	//   _جلد_, _cebr, _výpa, loâ_, 
   {{0x7c2d593d,0xe1f000e5,0x00000000,0x00000000}},	//   _debr, _لسی_, --, --, 
   {{0x7c2c062c,0x7ea8032e,0x3aec00e4,0x657803b2}},	//   _eebr, _týpa, týpa_, yvuh, 
   {{0xceac03b9,0x71680092,0x00000000,0x00000000}},	//   _ilә_, ሳተፉት_, --, --, 
   {{0x7c2d593e,0x26f40027,0x9d1801c0,0x99d5593f}},	//   _gebr, ुद्र_, _хорт_, رتنا, 
   {{0x6b80037e,0xca480fb4,0x1bd40212,0x3aec00e4}},	//   ængd, _ولسه_, _зоря, sýpa_, 
   {{0x7c2d5940,0x05a801b9,0x00000000,0x00000000}},	//   _zebr, жвий_, --, --, 
   {{0x7c2d5941,0x6e2c029f,0xde540023,0x59c4007b}},	//   _yebr, _mecb, _ዝኽእል, _كيفك, 
   {{0x03a40139,0x6e2c01ef,0x00000000,0x00000000}},	//   диоо, _lecb, --, --, 
   {{0x657825c6,0x26cc00d8,0x367000f2,0x00000000}},	//   svuh, _tjgo_, رهیز, --, 
   {{0x6e2c0067,0x6b800108,0x3f9c0174,0x00000000}},	//   _necb, ängy, øtum_, --, 
   {{0x6b80007c,0xbbd83174,0x00000000,0x00000000}},	//   ångj, _भड्क, --, --, 
   {{0x1dd81533,0x26dc0a73,0x93bc0356,0x00000000}},	//   _भुगत, louo_, mbăn, --, 
   {{0x7c2d5942,0x44255943,0xafe15944,0x793c0023}},	//   _rebr, mbl_, ворл, _ኣይትስ, 
   {{0x4424010a,0x8e740137,0xbef800cd,0x66d400e4}},	//   lbl_, нууч, ्देन_, tãky, 
   {{0x7c2d5945,0xed555946,0xd83809a8,0x814400f1}},	// [23080] _pebr, мот_, _hoče_, _غندن, 
   {{0x7c64d471,0xd8380010,0x7c2c06be,0x00000000}},	//   بارل, _koče_, _qebr, --, 
   {{0xbb843009,0xd8380010,0x44240332,0x18b4035b}},	//   بلاي, _joče_, ibl_, ҕәар, 
   {{0xe604006c,0x201833e7,0xb9e80107,0xb9c4007b}},	//   _لش_, lcri_, омез_, وقاي, 
   {{0x7c2d2cb9,0x2d8c0267,0xd8380010,0xe7c0072a}},	//   _tebr, äget_, _loče_, _वेबप, 
   {{0x20195947,0x44240010,0x7c2cafa3,0x00000000}},	//   ncri_, jbl_, _uebr, --, 
   {{0xd83809a8,0x4424005c,0x2ebc03d4,0x67d000db}},	//   _noče_, dbl_, _আৱিষ, кошу, 
   {{0x7d415948,0x6b80019b,0xb5a55949,0x557400d8}},	//   _ክርስቲ, ænge, дрой, егит, 
   {{0xac9401d3,0x00000000,0x00000000,0x00000000}},	//   _عنہا_, --, --, --, 
   {{0x66080fac,0x6d480e89,0xf8a80244,0x284400db}},	//   _eggk, àgai, _بدره_, _озуп_, 
   {{0xf770d55f,0x3945594a,0x80d80154,0x7ea801ef}},	//   _جاء_, lros_, ণগঞ্, _rýpn, 
   {{0x3944009f,0x200c0306,0x3a24022e,0x00000000}},	//   oros_, ždil_, nbop_, --, 
   {{0xbef80316,0x00000000,0x00000000,0x00000000}},	//   ्दैन_, --, --, --, 
   {{0x394410b4,0xd838193c,0x741000f1,0x5334004e}},	//   iros_, _foče_, _ګوډا, _зект, 
   {{0x3944003a,0x00000000,0x00000000,0x00000000}},	//   hros_, --, --, --, 
   {{0x3945594b,0x81dc015b,0x00000000,0x00000000}},	//   kros_, থেই_, --, --, 
   {{0x2fdc068f,0xf1a402bf,0xa2dc2802,0x394418dd}},	// [23090] ług_, _ірин, नवर्, jros_, 
   {{0x20180784,0xebc40063,0x2be800d8,0x00000000}},	//   ccri_, мљен, оќен_, --, 
   {{0x3945594c,0x201000d0,0x2fc5594d,0x260c0037}},	//   eros_, áliť_, _äng_, _डलली_, 
   {{0xefb8001f,0x3eb002f0,0x9a85594e,0xc954004e}},	//   ሰነው_, chyt_, кучл, еткы, 
   {{0x44240368,0x20d40014,0x20100419,0x00000000}},	//   ybl_, _ستیج, šliť_, --, 
   {{0x99d4034c,0x2b4407de,0x8c240214,0x9af4515c}},	//   ختما, àncs_, _سفره, ىكەت, 
   {{0x7c740092,0xb8901c3e,0x00000000,0x00000000}},	//   _የዛሬው_, الىع, --, --, 
   {{0x26dc0618,0x06e4009e,0xee3c02d2,0x4424015d}},	//   uouo_, _পূজি, _blýi_, wbl_, 
   {{0xacb80086,0x38a006ea,0xd8380427,0x44242caa}},	//   _itûb, _aðru_, _soče_, tbl_, 
   {{0x03249fcc,0x291c5686,0xd83805a1,0x93bc054e}},	//   ндон, _itua_, _poče_, rbăn, 
   {{0x442401e0,0xc2c40597,0x9f4c0793,0x02c54355}},	//   rbl_, فيدي, ädü_, ейно, 
   {{0xefcc1772,0x93240d73,0xc5d40845,0x574802dd}},	//   _ባርያ_, کرین, _піль, _ізім_, 
   {{0x04441d0f,0x00000000,0x00000000,0x00000000}},	//   _зелн, --, --, --, 
   {{0xd8380010,0xa4f448a7,0x200c0162,0x00000000}},	//   _toče_, _تکبر_, ødi_, --, 
   {{0xd8380e04,0x1fbc01ad,0x3a240fac,0x3eb00042}},	//   _uoče_, ोपेड, ybop_, thyt_, 
   {{0x291c0924,0x7ea80232,0x2019594f,0xf1bc3b82}},	//   _otua_, _výpo, scri_, mbán_, 
   {{0x291c0211,0xcdc40058,0xf1bc04d4,0x39440a55}},	// [230a0] _ntua_, ватқ, lbán_, xros_, 
   {{0x39455950,0x21200327,0xee3c00a2,0x6ce400d1}},	//   vros_, _itih_, _edý_, ىزلە, 
   {{0x291d5951,0x2d8c69e3,0x236405b1,0xfaa41086}},	//   _atua_, äger_, _jpnj_, нажо, 
   {{0x394474c3,0x9e740202,0x00000000,0x00000000}},	//   tros_, _جۇرت, --, --, 
   {{0x39455952,0xada04bec,0xf60801c0,0x195805a2}},	//   uros_, _баял, үхий_, фалы_, 
   {{0x39440aef,0x224001b9,0xa92000d0,0xf72800a8}},	//   rros_, _ldik_, ážan, пций_, 
   {{0x37040dbb,0x291d5953,0x6cb0013d,0xe7c06c52}},	//   нчив, _etua_, _сөтт, _वेदप, 
   {{0x3944382f,0x224000f2,0x21200098,0x2b440118}},	//   pros_, _ndik_, _otih_, ánce_, 
   {{0x7ae00a4d,0x291c0048,0xddc40327,0x00000000}},	//   moot, _gtua_, jdiż, --, 
   {{0x2241542a,0x7ae0d4f8,0xed540375,0xddc4025c}},	//   _adik_, loot, עביר_, ddiż, 
   {{0x212000d5,0xca3002dd,0x59a80118,0x00000000}},	//   _atih_, _ﮫﺗﺪ_, कनकर, --, 
   {{0x1ce0003d,0x7ae15954,0xb38401c6,0x00000000}},	//   _སྩལ_, noot, _үлдл, --, 
   {{0x7ea80122,0x88bc0055,0x00000000,0x00000000}},	//   _výpl, _avśy, --, --, 
   {{0x22415955,0x7ae0198f,0x00000000,0x00000000}},	//   _edik_, hoot, --, --, 
   {{0x7ae15956,0xdfd402d5,0x49400023,0xdd840150}},	//   koot, горы, _ኣይትብ, қытп, 
   {{0x224001b8,0x7ae05bce,0x00000000,0x00000000}},	//   _gdik_, joot, --, --, 
   {{0x7ae00a55,0xdce4068f,0xad980332,0xb40001c6}},	// [230b0] doot, zwią, _ngút, _шүүд, 
   {{0xd7b023e9,0xd6b800cc,0x00000000,0x00000000}},	//   जनाच, ুকিয, --, --, 
   {{0x7ae15957,0xab0801ec,0x291d5958,0x224001d5}},	//   foot, ستاق_, _stua_, _ydik_, 
   {{0x7ae15959,0xaae5595a,0x00000000,0x00000000}},	//   goot, رساو, --, --, 
   {{0xdd8401af,0x9d180117,0x00000000,0x00000000}},	//   _йырп, _поят_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7ae1595b,0xa9700116,0xadf800c5,0x13b800eb}},	//   boot, _әвзә, ्शकन_, ঁপড়, 
   {{0x7ae06475,0x0684036b,0x05640334,0xddc400c0}},	//   coot, тгин, ввин, leiš, 
   {{0x291d0230,0x355000aa,0x2364013c,0x7000063f}},	//   _utua_, لنيز, _spnj_, ọchu, 
   {{0xd87459c8,0x00000000,0x00000000,0x00000000}},	//   _مامب, --, --, --, 
   {{0x21201050,0x68e01948,0xb96001e1,0xca400150}},	//   _stih_, mond, _íìri, _ﻛﻪﺕ_, 
   {{0x68e074ed,0x00000000,0x00000000,0x00000000}},	//   lond, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x68e1595c,0xd839595d,0xf1bc02f0,0x66180205}},	//   nond, _koča_, mbál_, lcuk, 
   {{0x7ae1595e,0x7e5432f1,0x7c380109,0x04440116}},	//   yoot, ктац, _ôtri, _зеһн, 
   {{0x68e1595f,0x7ae07644,0x224030b5,0xf1bc011f}},	//   hond, xoot, _udik_, obál_, 
   {{0x68e15960,0x212005b1,0xada0d5aa,0x00000000}},	// [230c0] kond, _utih_, аатл, --, 
   {{0x3134025f,0x68e00fc0,0x7ae05a84,0x7d140200}},	//   _שנים_, jond, woot, rqys, 
   {{0xfe44f613,0x7ae15961,0x6618004b,0x6d4c01e4}},	//   _инно, toot, kcuk, _ĝiaŭ, 
   {{0x3dc40323,0x6a803edb,0x68e001f5,0xccf800b8}},	//   _аймг, илха, eond, _īśe_, 
   {{0x7ae056ca,0xa9542f84,0xe3a400ec,0xddc400c0}},	//   root, نجور_, _ڦر_, beiš, 
   {{0x7ae15962,0x00000000,0x00000000,0x00000000}},	//   soot, --, --, --, 
   {{0xb8e8084a,0x7ae15963,0xe3a40228,0x386c0334}},	//   _लग_, poot, _ئر_, refr_, 
   {{0x7ae035a3,0x59c00073,0x6d4800e4,0x00000000}},	//   qoot, _शेअर, ágag, --, 
   {{0x68e15964,0xb9040588,0xa53000fd,0xb21801bf}},	//   bond, _азак, аныч, ndæe, 
   {{0xe8f47cbb,0x68e15965,0xd8395966,0x3d1805d7}},	//   _алу_, cond, _foča_, _बढने_, 
   {{0x92595967,0xb9cc1772,0x857401c6,0x00000000}},	//   нант_, _ዶር_, влөх, --, 
   {{0x66e002bf,0xb6a402dd,0x661800e8,0xc76400db}},	//   _коха, _шиел, ccuk, _حاكى, 
   {{0xc64800c6,0x764000e4,0x00000000,0x00000000}},	//   _أجمل_, _idoy, --, --, 
   {{0x75200bdd,0x30c000cc,0x92b40154,0x00000000}},	//   _itoz, োত্স, ড়কে_, --, 
   {{0xb4dc069f,0xdfa4033a,0x3d180210,0x00000000}},	//   थकी_, ајто, _बढऩे_, --, 
   {{0x68e15968,0xf1bc0118,0x00000000,0x00000000}},	//   zond, lbám_, --, --, 
   {{0x68e09d24,0xddc40770,0xad9802d2,0xe2c91b9d}},	// [230d0] yond, teiš, _agúr, _جويو_, 
   {{0x6ad810fa,0x752001f7,0x68e15969,0x0f340133}},	//   यक्र, _mtoz, xond, _مکرد, 
   {{0x68e1596a,0xddc402d5,0x76400014,0xe034009d}},	//   vond, reiš, _odoy, _өмөө, 
   {{0x68e1596b,0x7641596c,0x6d4800a3,0xce940117}},	//   wond, _ndoy, àgas, _самъ, 
   {{0x68e1596d,0x752002e3,0x3ebd596e,0xd8380219}},	//   tond, _ntoz, ëtte_, _soča_, 
   {{0x76400429,0xf8b405f5,0x68e0009f,0x48e00154}},	//   _adoy, лөх_, uond, যগ্র, 
   {{0xdce4068f,0x752053f4,0x57a4026a,0xf1bc02f0}},	//   jwię, _atoz, ишћа, dbám_, 
   {{0xca487b63,0x9a8400cf,0x00000000,0x00000000}},	//   _سلطه_, _куул, --, --, 
   {{0x68e1596f,0x764004ba,0x66195970,0xdce4033f}},	//   pond, _ddoy, rcuk, ewię, 
   {{0x68e08cdb,0xd8380427,0x661801f4,0x00000000}},	//   qond, _toča_, scuk, --, 
   {{0x752001f2,0x00000000,0x00000000,0x00000000}},	//   _etoz, --, --, --, 
   {{0x85b80114,0x00000000,0x00000000,0x00000000}},	//   _плес_, --, --, --, 
   {{0xfdbc0f22,0x7e640109,0x00000000,0x00000000}},	//   _আড্ড, _rbkp, --, --, 
   {{0x43840597,0x3e6c00e4,0x7ea802f0,0x7f741b0a}},	//   _ملتق, _ẽt_, _týpk, лубц, 
   {{0x64415971,0x79800433,0xbf140966,0x28d805dc}},	//   _idni, zvow, اورب, _बदनि, 
   {{0xcf24007b,0x6d5c03e3,0x00000000,0x00000000}},	//   شرفي, ftqa, --, --, 
   {{0x6e90007b,0x6b80005c,0x00000000,0x00000000}},	// [230e0] حلقا, ængn, --, --, 
   {{0x71b8011a,0x00000000,0x00000000,0x00000000}},	//   _נציג, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf1bc02f0,0xd1d40092,0xfe7006c2,0x00000000}},	//   zbám_, _ከሩቅ_, _ادد_, --, 
   {{0xacb8019f,0x4a755972,0x64415973,0x1994373e}},	//   _itûn, рыхт, _odni, раля, 
   {{0x3ea00036,0xf7708a61,0x8d44010a,0x00000000}},	//   _hokt_, ماع_, _тĕшш, --, 
   {{0x7d0c01d9,0xf6e43529,0x3ea01511,0x69d80381}},	//   _iibs, лцин, _kokt_, _exue, 
   {{0x64415974,0x7d0c036b,0xee3c02d2,0x1ab821f6}},	//   _adni, _hibs, _hlýr_, _आतिथ, 
   {{0xf7701973,0x7d0c009f,0xf1bc02f0,0xdef80023}},	//   شاں_, _kibs, tbám_, _ገጽና_, 
   {{0x3ea001a4,0x7ea81d0e,0x7d0c0009,0x00000000}},	//   _lokt_, _dýpi, _jibs, --, 
   {{0x7d0c007f,0x94a80022,0x281000f1,0xf1bc00d7}},	//   _mibs, етҟа_, _اومس, rbám_, 
   {{0x7d0c0135,0x387c03d1,0x3ea00115,0x64400010}},	//   _libs, _hatr_, _nokt_, _edni, 
   {{0xf4855975,0x752025d0,0xb7f403d4,0x7d0c00a3}},	//   _буйн, _utoz, _চলিত_, _oibs, 
   {{0xaca0063f,0x00000000,0x00000000,0x00000000}},	//   _kwụb, --, --, --, 
   {{0x387d5976,0xa3c80034,0x3ea00d27,0x80b417cb}},	//   _matr_, _रेप_, _bokt_, _उतरे, 
   {{0x7d0c01ab,0x387c0113,0xdec801c6,0x00000000}},	//   _aibs, _latr_, гуул_, --, 
   {{0xdd955977,0xdef863eb,0x7d0d5978,0x00000000}},	// [230f0] баты, уыр_, _bibs, --, 
   {{0x6db40139,0x7d0c0142,0xd2501291,0x00000000}},	//   _aşaç, _cibs, _انک_, --, 
   {{0x60c15979,0x3ea001f5,0x7d0c0009,0x7e600115}},	//   ëmme, _fokt_, _dibs, ĵopr, 
   {{0x2f080248,0xa3c0012c,0x00000000,0x00000000}},	//   _dògì_, náší_, --, --, 
   {{0xaca0063f,0x3ce80427,0xdea401d5,0x6f0c0356}},	//   _awụb, _fkbv_, _ایقی, _iicc, 
   {{0x07a40c04,0x6b80049f,0x6f0d5590,0xb4dc00bc}},	//   иалн, ångs, _hicc, थको_, 
   {{0x6f0c037e,0x64440407,0xd8380010,0xe7e00154}},	//   _kicc, ójim, _točn_, মধ্য, 
   {{0xd83801fa,0x6f0c031c,0x69d8005a,0x46a41ab7}},	//   _fočo_, _jicc, _txue, раив, 
   {{0x6f0c0ba3,0x69d8005a,0x7d0c022e,0x00000000}},	//   _micc, _uxue, _yibs, --, 
   {{0x99d453e2,0x7ea80232,0x2a7c0211,0x6f0d597a}},	//   _اتفا, _výpi, _haub_, _licc, 
   {{0x2a7c01d4,0x7de0024a,0x00000000,0x00000000}},	//   _kaub_, _खड्ग_, --, --, 
   {{0x6f0d597b,0x97a414fb,0xf55401d3,0xd7c8029e}},	//   _nicc, _урул, دلیب_, _حومه_, 
   {{0x2a7c01d4,0x7ea802d2,0x147414af,0x00000000}},	//   _maub_, _kýpv, _گانج, --, 
   {{0x2a7c0211,0x6f0c00b8,0x04c801f7,0xff2401f0}},	//   _laub_, _aicc, _جوتي_, имго, 
   {{0x6f0d597c,0x2d8d597d,0x7d0c0369,0x6b80005c}},	//   _bicc, ågen_, _ribs, ængl, 
   {{0x7d0c0585,0x2a7c004e,0xcc14015b,0x73340139}},	//   _sibs, _naub_, িরোধ_, _өзәр_, 
   {{0x23b80241,0x8fd40032,0x3ea003cd,0x77500023}},	// [23100] _fájé_, _ғәрә, _vokt_, _ዘይሕሰ, 
   {{0xf1bc00d7,0x00000000,0x00000000,0x00000000}},	//   zbák_, --, --, --, 
   {{0x6f0d14d7,0x387c020c,0x3ea0143a,0xd8380010}},	//   _ficc, _ratr_, _tokt_, _sočo_, 
   {{0x2a7c01d4,0x79a50743,0x0ae80fb4,0x387c01a9}},	//   _caub_, ирле, هرني_, _satr_, 
   {{0x7d0c01d4,0x2a7d597e,0x387ce9bc,0xa0440023}},	//   _tibs, _daub_, _patr_, _ንምንዳ, 
   {{0x4a740220,0xca740150,0xfe7001f7,0x00000000}},	//   _қыст, _қусы, _ادگ_, --, 
   {{0xeb9514a9,0x81a80f22,0xba1847ed,0x00000000}},	//   _кир_, _গেম_, _ليزا_, --, 
   {{0xb4dc00dc,0xd8380427,0x00000000,0x00000000}},	//   थक्_, _točo_, --, --, 
   {{0xd8380010,0x9f600129,0xf1bc00d7,0x387c0b67}},	//   _hočm_, érêt_, rbák_, _tatr_, 
   {{0x2a7c0457,0xf8a817cb,0xb354136e,0xf788010a}},	//   _zaub_, _कविय, لیتا_, _аçи_, 
   {{0xf1bc00c7,0x00000000,0x00000000,0x00000000}},	//   mbái_, --, --, --, 
   {{0xf2c5597f,0x2a7c0218,0x7ea801a8,0x23b80248}},	//   рсон, _xaub_, _kýpu, _sájé_, 
   {{0x6f0d5980,0xf8a802a0,0x81a800cc,0x00000000}},	//   _ricc, _कवाय, _গেব_, --, 
   {{0x6f0d5981,0x3d182871,0xd8380100,0x24140166}},	//   _sicc, _बढ़े_, _alčz_, _кошы_, 
   {{0x6f0d5982,0xd83856c0,0x00000000,0x00000000}},	//   _picc, _meč_, --, --, 
   {{0x5eb42e3f,0x92580588,0xd838242b,0x00000000}},	//   ойст, _саит_, _leč_, --, 
   {{0x2a7d5983,0x63040328,0x6f0d5984,0x1ce00327}},	// [23110] _raub_, _بويل, _vicc, _སྩང_, 
   {{0x2a7c0070,0xca3800df,0xa3c80bc0,0x383c0092}},	//   _saub_, _poŝo_, _रेड_, ጠበቅበ, 
   {{0x2a7c0b89,0x6f0d5985,0x00000000,0x00000000}},	//   _paub_, _ticc, --, --, 
   {{0x2a7c0211,0x00000000,0x00000000,0x00000000}},	//   _qaub_, --, --, --, 
   {{0xd8380552,0xf1bc0296,0x48240131,0xda78667a}},	//   _beč_, nzá_, مىشق, рях_, 
   {{0x2d8800f3,0x7ea803b2,0xd1d40092,0x58d400cf}},	//   _irce_, _dýpu, _ጭነት_, оочт, 
   {{0x2a7c0457,0x07a4023b,0x00000000,0x00000000}},	//   _taub_, сайн, --, --, 
   {{0x1a68104c,0x02c4000d,0x00000000,0x00000000}},	//   _نیمی_, _लगेन, --, --, 
   {{0x7af8002e,0x8be80154,0x49d80108,0x00000000}},	//   _ëtta, কেশন_, _сдаю_, --, 
   {{0x984800a8,0xd1f80092,0x00000000,0x00000000}},	//   _вяца_, ለክት_, --, --, 
   {{0x74e401c0,0xd8340150,0x00000000,0x00000000}},	//   сдэг_, _بۋىش_, --, --, 
   {{0xfbd00302,0xe70842b5,0x2d88054e,0x56945dbf}},	//   לתי_, _شتان_, _orce_, _махт, 
   {{0x2d8c01e3,0x00000000,0x00000000,0x00000000}},	//   ågel_, --, --, --, 
   {{0xf4a002d3,0x25bc022e,0x35a001c6,0xa3c80210}},	//   _ዝፈልጥ_, mzul_, _хашг, _रेथ_, 
   {{0xf4100d65,0x4369137a,0x2d895986,0x200d5987}},	//   _צפה_, _сайн_, _arce_, ädi_, 
   {{0x93255988,0xfca801d9,0x2d883f69,0x160407c1}},	//   _برون, گارو_, _brce_, शेवर_, 
   {{0xa3c80c2e,0x61440131,0x00000000,0x00000000}},	// [23120] _रेत_, _بىخە, --, --, 
   {{0xfca81fb8,0xb21801bf,0x00000000,0x00000000}},	//   دارو_, ndæn, --, --, 
   {{0x7f840491,0xd8382402,0xad64020a,0x272003e0}},	//   _الجن, _reč_, _қарз_, _yıne_, 
   {{0x93bc00a8,0xba1400bd,0xd8380306,0x00000000}},	//   mbăt, ার্ড_, _seč_, --, 
   {{0x2fd4424b,0xd83809a8,0x7ea81427,0x93bc0356}},	//   _نوید_, _peč_, _dýpt, lbăt, 
   {{0x52a403f3,0x7e740436,0x7ea80306,0x3eb001f4}},	//   _ऑक्स, leyp, _výpu, lkyt_, 
   {{0xd8384859,0xf1bc066d,0x7c3d5989,0x7c840166}},	//   _več_, zzá_, mapr, _куңе, 
   {{0x7c3d598a,0x7e75598b,0xd5880032,0xb864132f}},	//   lapr, neyp, иҙел_, _گارو, 
   {{0x7c3c004e,0xf4840117,0x00000000,0x00000000}},	//   oapr, бунн, --, --, 
   {{0x7c3d598c,0xb86417b9,0x3b0401b9,0x39ac0171}},	//   napr, _دارو, lmoq_, _vēsā_, 
   {{0xd2500acb,0x7e75598d,0xd3440133,0xb80401d3}},	//   وند_, keyp, ڕیژه_, _اکشے_, 
   {{0x7c3c0882,0x3b0401d5,0x00000000,0x00000000}},	//   hapr, nmoq_, --, --, 
   {{0x7c3d598e,0x55c41cd1,0xb2180194,0xe70443fb}},	//   kapr, _фәйз, bdæn, _اسلی, 
   {{0x7c3d598f,0x3b040007,0x2d8c01bf,0x5334009b}},	//   japr, hmoq_, ågem_, _дект, 
   {{0x7c3d5990,0xb4c40dba,0x9f3402dd,0xddc40115}},	//   dapr, ैची_, зесі, rgiŝ, 
   {{0xd25000f8,0xee3c00a2,0x3b04014f,0x00000000}},	//   _کچھ_, _boýa_, jmoq_, --, 
   {{0x7c3c27c4,0xdd9413c6,0xb2180393,0x00000000}},	// [23130] fapr, паты, ldæo, --, 
   {{0x7c3d5991,0xee3c00a2,0x00000000,0x00000000}},	//   gapr, _doýa_, --, --, 
   {{0x0a38013d,0x25bc01a9,0x00000000,0x00000000}},	//   ачлы_, zzul_, --, --, 
   {{0x2d880e3c,0x7ea8032e,0xceb80139,0x00000000}},	//   _trce_, _dýps, _тәг_, --, 
   {{0x7c3d5992,0x2d88910e,0xee3c00a2,0x6e3c31c5}},	//   bapr, _urce_, _goýa_, maqb, 
   {{0x7c3c3386,0x02c4a3a7,0x2204020c,0x2c1c00cd}},	//   capr, _लग्न, lèhé_, मुखं_, 
   {{0xf52002e3,0x6fcc10eb,0x98486156,0x00000000}},	//   _rịọr, _हेमं, сяча_, --, 
   {{0x25bc054e,0xc68c00f1,0x8548003b,0x00000000}},	//   tzul_, کېچ_, азив_, --, 
   {{0x99d40491,0x7ea80162,0x93bc054e,0x00000000}},	//   _فتكا, _kýpr, zbăt, --, 
   {{0x6e3c014f,0xc4c8009d,0x00000000,0x00000000}},	//   haqb, рлож_, --, --, 
   {{0x47d4004b,0x03a4034f,0x220400f2,0x29055993}},	//   _بيار, цино, kèhé_, mmna_, 
   {{0x7c3d5994,0x611400a2,0x2904003e,0x42085549}},	//   zapr, _ańla, lmna_, инно_, 
   {{0x7c3c0882,0x04444727,0x29040332,0x00000000}},	//   yapr, _делн, omna_, --, 
   {{0xbf003806,0x65780223,0x3b043c0e,0x6fc001a9}},	//   लग्न_, mwuh, zmoq_, _kеch, 
   {{0x7c3d5995,0x6d495996,0x2904003e,0xc05801ec}},	//   vapr, ágan, imna_, лің_, 
   {{0x93bc084c,0x7c3c30b5,0x29040327,0x00000000}},	//   rbăt, wapr, hmna_, --, 
   {{0x7c3d5997,0x628406a3,0xa1f40150,0x3eb012c4}},	// [23140] tapr, _iaio, _رۋست, rkyt_, 
   {{0x62855998,0xfbd15999,0x93bc0276,0x3eb14093}},	//   _haio, وتا_, mbăr, skyt_, 
   {{0x7c3d599a,0x6285599b,0x3ea5599c,0x220400f2}},	//   rapr, _kaio, _динг, bèhé_, 
   {{0x7c3d599d,0xd838151c,0x628401c0,0x657800ca}},	//   sapr, _točk_, _jaio, kwuh, 
   {{0x6285599e,0x7c3d599f,0x3b04036b,0xa3c81bf9}},	//   _maio, papr, rmoq_, _रेस_, 
   {{0x628559a0,0xed400845,0xf1b0011a,0x7c3c0455}},	//   _laio, _інсп, וסד_, qapr, 
   {{0x62840086,0x6b60822f,0xd8380010,0x3b04022e}},	//   _oaio, _окра, _joči_, pmoq_, 
   {{0xd839108f,0x3568016c,0xcc080014,0x628559a1}},	//   _moči_, арон_, _دزُن_, _naio, 
   {{0xd8380219,0x00000000,0x00000000,0x00000000}},	//   _loči_, --, --, --, 
   {{0x62840e39,0xc9d404fb,0xa3c000bc,0xa3c800e1}},	//   _aaio, _عملک, láří_, _रेह_, 
   {{0x628559a2,0xd83809a8,0xbf080073,0xe85000f2}},	//   _baio, _noči_, _वळून_, _زنند, 
   {{0x6b8004ce,0xc7640150,0x6284021c,0xd25001ed}},	//   ængi, _ءالى, _caio, ڈنگ_, 
   {{0xa18559a3,0x77906f51,0xd250034c,0x628559a4}},	//   мырл, _ریکا, ونگ_, _daio, 
   {{0x6fc0022e,0xa3c821f2,0x00000000,0x00000000}},	//   _yеch, _रेव_, --, --, 
   {{0x62841132,0x2720456f,0x6e3c0009,0x60200241}},	//   _faio, _kına_, taqb, _sàmó, 
   {{0x628404c9,0x99840327,0xd8380841,0x34a8000d}},	//   _gaio, _bemż_, _doči_, _चकुद, 
   {{0x78b87cf7,0x28d80ebb,0x27200205,0x00000000}},	// [23150] _oltv, _बदलि, _mına_, --, 
   {{0xd8395966,0x628401c0,0x2204020c,0x27200139}},	//   _foči_, _zaio, sèhé_, _lına_, 
   {{0x7ea80232,0x62847805,0xe0d000e3,0x00000000}},	//   _výpr, _yaio, _جزي_, --, 
   {{0x78b87a84,0xf1bc011f,0x63a400b5,0x3f780a7c}},	//   _altv, bbát_, øjni, _פארס, 
   {{0x99d4009f,0xd83800d7,0xf1bd57a0,0x00000000}},	//   وتها, _zoči_, mbás_, --, 
   {{0x29040098,0xcb58002e,0xb218005c,0xefcc0240}},	//   umna_, r茜b_, ddæm, _ባርዕ_, 
   {{0x27200139,0x1b78007b,0x29040010,0xcb340395}},	//   _bına_, _وصفة_, rmna_, _хебъ, 
   {{0x78b826b0,0x1ac800c7,0xd9ec000d,0x7c900092}},	//   _eltv, _дууп_, _छुवत_, ቆጠረው_, 
   {{0x628559a5,0x44280b45,0xe84803e6,0x27200139}},	//   _raio, _ƙa_, _نجان_, _dına_, 
   {{0x628559a6,0x83c40452,0x28b4132f,0x00000000}},	//   _saio, збож, _بحرح, --, 
   {{0x46147b32,0x628559a7,0xf8b008a8,0x00000000}},	//   _فوار, _paio, _רשב_, --, 
   {{0x27200598,0x00000000,0x00000000,0x00000000}},	//   _gına_, --, --, --, 
   {{0x361805e1,0x628559a8,0xd83819d6,0x6d480599}},	//   _הונד, _vaio, _soči_, ágal, 
   {{0x628559a9,0x6ab8004e,0xd8380b3d,0x93bc054e}},	//   _waio, _lluf, _poči_, rbăr, 
   {{0x628559aa,0x00000000,0x00000000,0x00000000}},	//   _taio, --, --, --, 
   {{0xd83801f1,0x628405b1,0x272003b9,0x00000000}},	//   _voči_, _uaio, _xına_, --, 
   {{0xee3559ab,0x814400c6,0xb2b8011a,0x00000000}},	// [23160] янт_, _عندن, _למקר, --, 
   {{0x6ab959ac,0xac80855e,0x61e559ad,0xf1bd59ae}},	//   _aluf, нгул, _ixil, rbát_, 
   {{0xd838098d,0x6194004b,0x6ab82b00,0x442401ab}},	//   _uoči_, _راکړ, _bluf, icl_, 
   {{0xe80c4d53,0x6ab80286,0x44240208,0x60dc01ab}},	//   ाधना_, _cluf, hcl_, lnrm, 
   {{0x27200139,0xdce40135,0x0a8800db,0x00000000}},	//   _rına_, ntiċ, تئلى_, --, 
   {{0x6ab80270,0x272159af,0x00000000,0x00000000}},	//   _eluf, _sına_, --, --, 
   {{0xf0900302,0xa3c81dd1,0xa844007b,0x2a9400db}},	//   תנו_, _रेल_, سليم_, تدەڭ, 
   {{0x6ab85804,0x272000fd,0x00000000,0x00000000}},	//   _gluf, _qına_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb2180008,0x394559b0,0xe56d0565,0x00000000}},	//   rdæm, msos_, اطي_, --, 
   {{0x61e45178,0x81a800bd,0x99840006,0x2d8400b0}},	//   _axil, _গেল_, _temų_, ānei_, 
   {{0x32640c9e,0x0cb800e1,0x3a2559b1,0x442401ab}},	//   чтов, _इत्म, ncop_, acl_, 
   {{0x71700372,0xb21800b5,0xf5040108,0x442401ef}},	//   رۇدا, ldæk, _ездо, bcl_, 
   {{0x64a00953,0x00000000,0x00000000,0x00000000}},	//   _пача, --, --, --, 
   {{0x39440455,0xc5ec00f1,0xb21801bf,0x5f9400db}},	//   hsos_, _مړی_, ndæk, нирт, 
   {{0x672401ed,0xf2040024,0x00000000,0x00000000}},	//   _éjje, _няпо, --, --, 
   {{0x61e4401f,0xd83801a6,0x3a24020c,0x646002d2}},	// [23170] _gxil, _hoču_, dcop_, _ývið, 
   {{0xad9844d5,0x5ce40b2c,0x39440477,0x00000000}},	//   _azúc, нюха, dsos_, --, 
   {{0x6ab959b2,0x39440006,0x0a54001f,0xe7e40154}},	//   _pluf, esos_, _ከምርጫ, _পণ্য, 
   {{0xf8ac3a56,0xb218005c,0xea9c0055,0xd8380419}},	//   یکل_, ddæk, _meṇa_, _moču_, 
   {{0x0ef802ab,0x2d9c036e,0xd83800ef,0x00000000}},	//   ंतीस_, _çue_, _loču_, --, 
   {{0xee3c010b,0xb21801bf,0x00000000,0x00000000}},	//   _heý_, fdæk, --, --, 
   {{0x4ac401d5,0xee3c0432,0xa3c801ad,0xb218005c}},	//   _قيسق, _keý_, _रें_, gdæk, 
   {{0x6ab8b452,0x2bd0007d,0x4528b3eb,0x00000000}},	//   _uluf, _धेया, ожин_, --, 
   {{0x26c00953,0x442559b3,0xee3c010e,0x394401d3}},	//   ėjo_, tcl_, _meý_, csos_, 
   {{0x032401a9,0x93bc0356,0x00000000,0x00000000}},	//   мдон, rcăn, --, --, 
   {{0x442559b4,0x9d94013b,0x291c009f,0xdce40135}},	//   rcl_, _ɑnɑɑ_, _huua_, wtiċ, 
   {{0xd77559b5,0x291c0451,0x4424004d,0xdce40003}},	//   _سامع, _kuua_, scl_, ttiċ, 
   {{0xf65002e4,0x291c00c5,0x00000000,0x00000000}},	//   _יצא_, _juua_, --, --, 
   {{0xd83801fa,0x291c0194,0xdce40135,0x93253ecd}},	//   _foču_, _muua_, rtiċ, برین, 
   {{0xdce4003d,0x291c00af,0xee3c0432,0x92bc00cc}},	//   stiċ, _luua_, _beý_, _আদৰ_, 
   {{0x291c0093,0x61e401c6,0x394400d7,0x00000000}},	//   _ouua_, _txil, ysos_, --, 
   {{0xf1bcd3eb,0x61e40472,0x291c003a,0x0204036b}},	// [23180] lcán_, _uxil, _nuua_, _юзин, 
   {{0x31541a4c,0x24840d29,0xec7559b6,0xa0340137}},	//   _קיין_, _janm_, мпу_, _سۉرت, 
   {{0x24845062,0x22400522,0xfaa43f07,0x3098011a}},	//   _manm_, _keik_, мажо, _ושימ, 
   {{0x248544a6,0x291c01af,0x21200092,0xee3c0432}},	//   _lanm_, _buua_, _kuih_, _geý_, 
   {{0x39784b08,0x3a2559b7,0x394559b8,0xdce40960}},	//   تصاد_, rcop_, usos_, ltič, 
   {{0x3a2559b9,0x224159ba,0x21202b10,0x248402bd}},	//   scop_, _leik_, _muih_, _nanm_, 
   {{0x394559bb,0x21200066,0x6b8000b5,0x3704537c}},	//   ssos_, _luih_, ængt, мчив, 
   {{0xf52559bc,0x39441fba,0xb21800b5,0xea9c0055}},	//   мфон, psos_, rdæk, _reṇa_, 
   {{0x78642f33,0x248402bd,0x15151fa8,0xb218037e}},	//   _оказ, _banm_, ндия, sdæk, 
   {{0x24840205,0xb21801bf,0x00000000,0x00000000}},	//   _canm_, pdæk, --, --, 
   {{0x2484b8ab,0x22400204,0x366959bd,0x12d41422}},	//   _danm_, _beik_, _мажо_, ежня, 
   {{0x21212c40,0xe690007b,0x6d4800e5,0xe7340354}},	//   _buih_, _للمد, ágak, _цец_, 
   {{0x248559be,0xf5b42172,0x2120020c,0xf1bc0154}},	//   _fanm_, _تصاد, _cuih_, acán_, 
   {{0x2120003e,0x741559bf,0xb7580208,0x91e400c7}},	//   _duih_, _قوشا, _ngừơ, доҭе, 
   {{0x21200098,0x224159c0,0xeea86aec,0xee3c00a2}},	//   _euih_, _feik_, отак_, _peý_, 
   {{0x24840100,0xc0640023,0x1dd0012d,0x00000000}},	//   _zanm_, _ዝዝርግ, _सेहत, --, 
   {{0x2028022c,0x248402e2,0x6fcc01f9,0x00000000}},	// [23190] ævið_, _yanm_, _हेरं, --, 
   {{0xac7439b8,0x224001f5,0x88bc00b8,0xee3c010e}},	//   بارش, _zeik_, _kuśe, _weý_, 
   {{0x291c013c,0xf2dc011f,0xe1f004fb,0x4a5400db}},	//   _suua_, onâ_, _مسی_, екес, 
   {{0x291c0194,0xf2dc0548,0x00000000,0x00000000}},	//   _puua_, nnâ_, --, --, 
   {{0xdbd0032e,0x00000000,0x00000000,0x00000000}},	//   fþór, --, --, --, 
   {{0x6b80037e,0xbd0000d0,0x80a0012d,0xdbd008a5}},	//   ængs, žéro, खाये, gþór, 
   {{0x9bc800cf,0x88bc0055,0xaa642e8d,0x00000000}},	//   _قۇكە_, _nuśe, _отак, --, 
   {{0x291d59c1,0x248402e2,0xf4040154,0x45840108}},	//   _tuua_, _sanm_, োডার_, егив, 
   {{0x224159c2,0x93bc0311,0x26cc0098,0x09d800eb}},	//   _reik_, scăl, _vmgo_, _তরকা, 
   {{0xf2dc0548,0x224027b2,0xddc400d7,0x00000000}},	//   enâ_, _seik_, nfiš, --, 
   {{0x224005ac,0x00000000,0x00000000,0x00000000}},	//   _peik_, --, --, --, 
   {{0x248405b1,0xf2dc0393,0xdce40219,0xf1bc01e7}},	//   _wanm_, gnâ_, vtič, rcán_, 
   {{0xf1bc00c6,0x224159c3,0x24840100,0x4680681b}},	//   scán_, _veik_, _tanm_, _аққа, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2240014a,0x21205552,0x2d8c037e,0xf8500030}},	//   _teik_, _wuih_, ægen_, ížiť_, 
   {{0xdce4cc1a,0x00000000,0x00000000,0x00000000}},	//   rtič, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [231a0] --, --, --, --, 
   {{0x26dc05a1,0x00000000,0x00000000,0x00000000}},	//   hnuo_, --, --, --, 
   {{0x26dc098d,0x00000000,0x00000000,0x00000000}},	//   knuo_, --, --, --, 
   {{0xe6040597,0x00000000,0x00000000,0x00000000}},	//   _مش_, --, --, --, 
   {{0xd6d02fee,0xb0d4130b,0x2d8c7c52,0xd9107b02}},	//   یقت_, _डगमग, åget_, لیر_, 
   {{0x25f0000d,0x4c140137,0x00000000,0x00000000}},	//   _ंड़ी_, ربەس, --, --, 
   {{0xf2dc011f,0x3f78010f,0x00000000,0x00000000}},	//   ynâ_, לאַס, --, --, 
   {{0x26dc041a,0x00000000,0x00000000,0x00000000}},	//   gnuo_, --, --, --, 
   {{0xacb80428,0x88bc0055,0x00000000,0x00000000}},	//   _itûr, _suśe, --, --, 
   {{0x6d4959c4,0x779079af,0x7534010e,0xf77000e5}},	//   ágai, _میتا, _çyzm, _ماؤ_, 
   {{0x925959c5,0x7e6403ac,0xc764215c,0x00000000}},	//   мант_, _ockp, _لانى, --, 
   {{0x66e159c6,0x26dc16a3,0xf2dc003e,0x3668030d}},	//   _йоха, cnuo_, unâ_, _хадо_, 
   {{0xf2dc003a,0x5f940075,0x999806be,0x00000000}},	//   rnâ_, қитт, _ərş_, --, 
   {{0x7e640857,0x13f40801,0x00000000,0x00000000}},	//   _ackp, _изля, --, --, 
   {{0x76400076,0xdc8c0023,0x40840124,0xaf051d0b}},	//   _keoy, _ዘማራይ_, тәым_, ечак, 
   {{0x752001c8,0xf2dc011f,0x25e40073,0x79800210}},	//   _kuoz, qnâ_, _जखमी_, kwow, 
   {{0x75200006,0x76400076,0xdde4013d,0x00000000}},	// [231b0] _juoz, _meoy, гәрү, --, 
   {{0x26dc07f5,0x7e644431,0x00000000,0x00000000}},	//   znuo_, _eckp, --, --, 
   {{0x4fc00131,0xeae00022,0x00000000,0x00000000}},	//   _ئەزە, гӡаҩ, --, --, 
   {{0x76403eba,0x2d8c005c,0x48240116,0x00000000}},	//   _neoy, åges_, چىشق, --, 
   {{0x79801c06,0x48241ca1,0x00000000,0x00000000}},	//   gwow, نىشق, --, --, 
   {{0x6d5c0bc9,0xacb80295,0xb91001f2,0x00000000}},	//   muqa, _etûr, monụ_, --, 
   {{0x07a40058,0x26dc08a4,0x764000ad,0x6d5d59c7}},	//   тайн, tnuo_, _beoy, luqa, 
   {{0x75203eb9,0xf1b02ecf,0x26dc00df,0x00000000}},	//   _buoz, ुनान, unuo_, --, 
   {{0x6d5c37e2,0x26dc0552,0x752007de,0x754159c8}},	//   nuqa, rnuo_, _cuoz, аныз, 
   {{0x26dc05ce,0x88bc00cd,0x00000000,0x00000000}},	//   snuo_, _duśc, --, --, 
   {{0x6d5c4f6b,0x26dc110c,0xa3c805f9,0x74e4009d}},	//   huqa, pnuo_, _रेख_, тдэг_, 
   {{0x6d5c8cdb,0x76400076,0xd7f80137,0x611400a2}},	//   kuqa, _geoy, _чуу_, _ińli, 
   {{0xf48559c9,0x7520045f,0xd1743e64,0xad9801d3}},	//   رایی, _guoz, лыры, _szún, 
   {{0x764001e2,0x03940166,0x6d5c7a06,0x00000000}},	//   _zeoy, _ария, duqa, --, 
   {{0x644159ca,0x7640009a,0x752004cc,0x00000000}},	//   _ieni, _yeoy, _zuoz, --, 
   {{0x644159cb,0xdc3400d0,0x7980012d,0x41b40117}},	//   _heni, rúčk, ywow, _асот, 
   {{0x644159cc,0xd1f8044e,0xf1840228,0x6d5c3a73}},	// [231c0] _keni, ወርቂ_, _айыл_, guqa, 
   {{0xed540116,0x20040213,0x00000000,0x00000000}},	//   тоф_, əmin_, --, --, 
   {{0x90e406f6,0x2d8c0726,0xc7a400e5,0x59c40709}},	//   _حسين, åger_, _اڑ_, वनभर, 
   {{0x644159cd,0x6d5c0944,0x79800034,0x65680327}},	//   _leni, buqa, twow, _oqgh, 
   {{0x644159ce,0x25689b7b,0xf2d000df,0x00000000}},	//   _oeni, jøl_, סעד_, --, 
   {{0x644004ac,0x7980068f,0x7640037e,0x25685f03}},	//   _neni, rwow, _seoy, døl_, 
   {{0xbb44009b,0xd7f4035b,0xa02400cc,0x00000000}},	//   _шевк, ызкы, _বজাব_, --, 
   {{0x644159cf,0x752005d5,0xebe03004,0xd1f8069d}},	//   _aeni, _puoz, _тосп, ወርቅ_, 
   {{0x644159d0,0x7ae159d1,0x75203fa8,0x76400076}},	//   _beni, mnot, _quoz, _veoy, 
   {{0x644159d2,0x7ae159d3,0x00000000,0x00000000}},	//   _ceni, lnot, --, --, 
   {{0x644159d4,0xf4280139,0x7ae0bb46,0x92bc0154}},	//   _deni, _ahäñ_, onot, _আদৌ_, 
   {{0x644159d5,0x6d5c0309,0xdc180171,0x00000000}},	//   _eeni, yuqa, _zāģm, --, 
   {{0xb35559d6,0x7c2c0a40,0x7af800e8,0x32080139}},	//   ریکا_, _ofbr, _ëttu, ьхон_, 
   {{0x88bc0882,0x6d5c0481,0xf3f4013d,0x00000000}},	//   _kuśa, vuqa, _имлә_, --, 
   {{0x251810df,0x7ae159d7,0x929405f5,0x6e6559d8}},	//   _קווא, knot, _байц, ктаж, 
   {{0x644159d9,0x7c2d59da,0x6d5d59db,0xa3c82f0a}},	//   _zeni, _afbr, tuqa, _रेट_, 
   {{0x644159dc,0x7ae0076f,0x7c2c00d8,0x7b181165}},	// [231d0] _yeni, dnot, _bfbr, _půun, 
   {{0x644159dd,0x7ae159de,0x6d5c42b2,0xdd9400fb}},	//   _xeni, enot, ruqa, шауы, 
   {{0xaca0063f,0x6d5c3877,0x88bc002b,0x00000000}},	//   _ntụb, suqa, _nuśa, --, 
   {{0x7ae159df,0xcb0805d9,0x25f0000d,0x81a800eb}},	//   gnot, ريشن_, _ंडली_, _গেট_, 
   {{0xaca001f2,0x6d5d59e0,0x9a842e36,0x9e8402f2}},	//   _atụb, quqa, рухл, _ئاپۆ, 
   {{0x7ae159e1,0x25680194,0x6c6401ed,0x6d4c02d0}},	//   anot, vøl_, _جلسہ_, _ivca, 
   {{0x644159e2,0x8af803be,0x98480212,0x9b680408}},	//   _reni, _atəş, тяча_, _ишта_, 
   {{0x7ae0022f,0xea60004b,0x068559e3,0x25683ad2}},	//   cnot, _خپری, угин, tøl_, 
   {{0xd874129d,0x00000000,0x00000000,0x00000000}},	//   _چامب, --, --, --, 
   {{0x644002d3,0x69c80369,0x27b00139,0x256803cd}},	//   _qeni, mzge, _вәис, røl_, 
   {{0x69c80b70,0x256833b8,0x47347579,0xd90c1e4b}},	//   lzge, søl_, _снес, _تیو_, 
   {{0x644159e4,0x6d4c110c,0xd83808a4,0xf1bc011f}},	//   _weni, _ovca, _inča_, ocáh_, 
   {{0x644159e5,0x69c80ade,0x2d84033f,0x68e00e89}},	//   _teni, nzge, łnej_, onnd, 
   {{0x644159e6,0x69c8000f,0x7ae000e2,0x04440353}},	//   _ueni, izge, znot, _секн, 
   {{0xbd00056a,0x68e159e7,0x7ae159e8,0x93a8007b}},	//   ñémo, innd, ynot, _لايف_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xed5559e9,0xada159ea,0x6da0a338,0xfce40276}},	// [231e0] лот_, батл, бита, гоао, 
   {{0x7ae01071,0x7ff40597,0x00000000,0x00000000}},	//   wnot, _مسجا, --, --, 
   {{0x7ae159eb,0xad980154,0x60c00a40,0xeb312374}},	//   tnot, _ayúd, ëmmu, مىلد, 
   {{0xbea43b2b,0x68e00007,0x39481a39,0x80a0c4dd}},	//   _самк, ennd, ездо_, खावे, 
   {{0x7ae159ec,0xab2401e0,0x88bc002b,0x00000000}},	//   rnot, _ҡора_, _suśa, --, 
   {{0x7ae159ed,0xb764009d,0x00000000,0x00000000}},	//   snot, гтий, --, --, 
   {{0xe3a43108,0xb21828b3,0x5784010b,0x6cc0010a}},	//   _ار_, ndær, рңев, _уйра, 
   {{0x81a804c5,0x68e00332,0xe8f40150,0x00000000}},	//   _গেছ_, annd, _ұлу_, --, 
   {{0xdbd002d2,0x00000000,0x00000000,0x00000000}},	//   gþör, --, --, --, 
   {{0xe8f40a31,0xe9d4a30d,0x2978010f,0xdc3c00ef}},	//   _блу_, _ску_, _אטמא, _išēm, 
   {{0xf77000ae,0x00000000,0x00000000,0x00000000}},	//   _داء_, --, --, --, 
   {{0xa194035b,0x00000000,0x00000000,0x00000000}},	//   әарч, --, --, --, 
   {{0x3f9c0158,0x59c41fe7,0x632c0092,0x00000000}},	//   åtun_, वनिर, _በኃጢአ, --, 
   {{0x1be403f3,0xf1bc0051,0x00000000,0x00000000}},	//   कपाल_, ncái_, --, --, 
   {{0xc3f400ec,0x00000000,0x00000000,0x00000000}},	//   _پتوڙ, --, --, --, 
   {{0xeaa00220,0x59c43517,0xceb80022,0x00000000}},	//   _ﺍﻗﺎﯞ, वनार, тәо_, --, 
   {{0x720401d3,0x00000000,0x00000000,0x00000000}},	// [231f0] _حفظہ_, --, --, --, 
   {{0x0f34034c,0x60c00221,0x00000000,0x00000000}},	//   _نکرد, ëmmt, --, --, 
   {{0xe9a8030f,0xce580022,0x4af802f2,0xdd9001e2}},	//   کدان_, _ианц_, نکرد_, يوې_, 
   {{0x69c959ee,0x6d4c020c,0x0e6400f7,0xce9559ef}},	//   tzge, _tvca, _өкүн, _тамъ, 
   {{0x69c80165,0x0ef001f9,0x00000000,0x00000000}},	//   uzge, चवीस_, --, --, 
   {{0x69c959f0,0x2d880010,0x68e00fac,0x637801f4}},	//   rzge, _isce_, unnd, _jänö, 
   {{0x2b900330,0xef1c002b,0x38c84d66,0x00000000}},	//   _دیاس, _kiü_, ضاوی_, --, 
   {{0xdd1c0064,0x00000000,0x00000000,0x00000000}},	//   _iššl, --, --, --, 
   {{0xd6a810e0,0xe4b4008e,0x00000000,0x00000000}},	//   ادىم_, гънә_, --, --, 
   {{0x04b559f1,0x00000000,0x00000000,0x00000000}},	//   рсия, --, --, --, 
   {{0xf8ad59f2,0xf1bc00e4,0xe69001f0,0x00000000}},	//   _تکن_, mbáy_, _гулӯ, --, 
   {{0x2d883673,0x88bc00b8,0x41280835,0x00000000}},	//   _osce_, _kuśo, комо_, --, 
   {{0x656c01ab,0xd430009d,0x00000000,0x00000000}},	//   àchd, _зvрх, --, --, 
   {{0xf4800092,0x00000000,0x00000000,0x00000000}},	//   ያቀርብ_, --, --, --, 
   {{0x2d88011c,0xef1c013d,0xeaa002dd,0x42e8022e}},	//   _asce_, _biü_, _ﺍﺗﺎﯞ, _имко_, 
   {{0xaec04705,0x939400f1,0xb218005c,0x00000000}},	//   обсл, _دجها, rdær, --, 
   {{0xef1c0139,0x60c004e6,0x00000000,0x00000000}},	// [23200] _diü_, ëmms, --, --, 
   {{0x3b940640,0x4e187927,0x00000000,0x00000000}},	//   ијет, уюся_, --, --, 
   {{0x2d88f2de,0x0c78005e,0x3b840b65,0x60dc8be8}},	//   _esce_, ысты_, рлег, mirm, 
   {{0x60dd59f3,0xcee801d9,0xc0d00023,0xdfd000f1}},	//   lirm, _مرُن_, ኩዎም_, _ويښ_, 
   {{0xe3a80c58,0x3f98a068,0xed5559f4,0x3ea009b6}},	//   খনিব, _hrpu_, _коя_, _inkt_, 
   {{0x60dd59f5,0x3f9807f5,0xe8f41cd0,0x00000000}},	//   nirm, _krpu_, аніч_, --, 
   {{0xdb5001d9,0xb6c47a16,0x7c3c0076,0x93bc0356}},	//   _رێش_, исий, mbpr, ncăt, 
   {{0x60dd59f6,0x9634241e,0xa6c40120,0x00000000}},	//   hirm, щниц, илја_, --, 
   {{0x74a400f0,0xeab4010a,0x00000000,0x00000000}},	//   ајне, _тйт_, --, --, 
   {{0x60dc0ffb,0x3f980477,0xc8881063,0xb8640472}},	//   jirm, _orpu_, _مخمل_, _خارو, 
   {{0x60dce35c,0x929414b7,0x628001e4,0x00000000}},	//   dirm, банц, ĵmon, --, 
   {{0x2b44054e,0xdbd400ae,0x00000000,0x00000000}},	//   ânci_, _núío, --, --, 
   {{0xd534193a,0x20b41d7d,0xf300009d,0xf2040fac}},	//   _افتخ, ुसंध, йжүү, ряно, 
   {{0x60dd59f7,0xfbc4012c,0x00000000,0x00000000}},	//   girm, लनाम, --, --, 
   {{0x232430ba,0xb4e00490,0xf1c81d1d,0x7c3c0f85}},	//   _који_, नची_, _bráð_, dbpr, 
   {{0x60dc0192,0x46a800bc,0xb40401d5,0x7144010a}},	//   airm, कायह, _йўққ, _кхож, 
   {{0x60dd59f8,0xd00802dd,0xc0f00023,0x00000000}},	// [23210] birm, теңе_, ሂሮም_, --, 
   {{0x60dd59f9,0x3ea00036,0x93bc0356,0x7534010e}},	//   cirm, _enkt_, scău, _çyzu, 
   {{0xef1c0166,0x88bc002b,0x00000000,0x00000000}},	//   _tiü_, _suśo, --, --, 
   {{0xda78010b,0x2360002e,0xea600228,0x00000000}},	//   ияч_, àjji_, تۇرپ, --, 
   {{0xe0d004d3,0x2d8959fa,0x7c3c7c1d,0x1a68315b}},	//   _رزی_, _usce_, bbpr, شیلی_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xcb68b327,0x2a6400a7,0xd874fc20,0x00000000}},	//   _حمزه_, _възг, تانب, --, 
   {{0xe8dc0cad,0x60dc03e0,0x6d5c06be,0x00000000}},	//   _iwọn_, zirm, orqa, --, 
   {{0x60dc00ac,0x00000000,0x00000000,0x00000000}},	//   yirm, --, --, --, 
   {{0x60dc0077,0x18b40022,0x985c00ef,0x00000000}},	//   xirm, _ҳҳәы_, _vāģi_, --, 
   {{0xaca002e3,0x27b001d2,0x60dc06b9,0x3fe402dd}},	//   _adịc, _фәлс, virm, _ﺍﻣﺎﻧ, 
   {{0x60dc0009,0x00e001ec,0x00000000,0x00000000}},	//   wirm, _ﺍﻳﺘﺘ, --, --, 
   {{0x60dd23f5,0xe4b0013d,0x00000000,0x00000000}},	//   tirm, _дөнъ, --, --, 
   {{0xdce400f3,0x63c001af,0x5058117e,0x00000000}},	//   mtić, _малҡ, ишся_, --, 
   {{0xbea43aeb,0x60dd59fb,0xe8dc01e1,0x00000000}},	//   бавк, rirm, _nwọn_, --, 
   {{0x60dc011f,0x93bc054e,0x88bc00b8,0x00000000}},	//   sirm, rcăt, _suśl, --, 
   {{0xe8dd59fc,0x60dd59fd,0x93bc0276,0x7d0c00a3}},	// [23220] _awọn_, pirm, scăt, _phbs, 
   {{0x60dc01b9,0x00000000,0x00000000,0x00000000}},	//   qirm, --, --, --, 
   {{0x6d5c0194,0x3f980784,0x93bc054e,0xf1c80174}},	//   arqa, _urpu_, lcăr, _tráð_, 
   {{0xdce4107d,0xec10df98,0x00000000,0x00000000}},	//   ktić, سوند, --, --, 
   {{0xdce40114,0x93bc0311,0x00000000,0x00000000}},	//   jtić, ncăr, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2f0000d8,0x797800b0,0x6cc000ee,0x7c40007f}},	//   _órfã_, wāwā, _эйра, čtrč, 
   {{0xdce40cf4,0xcd2803e6,0x797800b0,0xbb280220}},	//   ftić, _حسێن_, tāwā, _ﺤﺘﻰ_, 
   {{0xd9980133,0x00000000,0x00000000,0x00000000}},	//   _خۆشت_, --, --, --, 
   {{0xb4e00490,0xb3544e5c,0x9378442d,0x00000000}},	//   नचे_, میتا_, абот_, --, 
   {{0xe56c2099,0x6e3c0175,0x31b0194b,0x00000000}},	//   وطی_, ybqb, ुन्ध, --, 
   {{0xd5a559fe,0x78a80419,0x00000000,0x00000000}},	//   _ولای, šovč, --, --, 
   {{0x3168005b,0x00000000,0x00000000,0x00000000}},	//   ышно_, --, --, --, 
   {{0xdc3c00c0,0x92d80154,0x2eb02802,0x00000000}},	//   _išėm, ়কে_, ीस्त, --, 
   {{0x64c00150,0x1cb8031c,0xfb0400e8,0x00000000}},	//   _ءيىل, ཛིན_, _ñëwi_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x226402fb,0xf424031c,0xfbd4015b,0xf2dc003a}},	// [23230] šské_, _རྔོད_, _তুলত, miâ_, 
   {{0xf1bc0085,0xf2dd59ff,0xddd00276,0xcfa400c7}},	//   myá_, liâ_, ţeşt, _дымҩ, 
   {{0x6f0c00a3,0x00000000,0x00000000,0x00000000}},	//   _thcc, --, --, --, 
   {{0xf2dd5a00,0x00000000,0x00000000,0x00000000}},	//   niâ_, --, --, --, 
   {{0xda78cb76,0xf1bc02d1,0xad24179e,0x00000000}},	//   сях_, nyá_, _درجو, --, 
   {{0x4758156b,0xdce400f3,0x5f745d95,0x07a401d5}},	//   ария_, vtić, _بایر, жакн, 
   {{0x5ef00882,0xf1bc0113,0x66c4010e,0x00000000}},	//   _इदम्_, hyá_, _añka, --, 
   {{0xf1bc0309,0x857806ed,0x0554030d,0x2b44054e}},	//   kyá_, асот_, отоя, âncu_, 
   {{0xf2dc0393,0xfc4800d7,0x00000000,0x00000000}},	//   diâ_, stíž_, --, --, 
   {{0xdce42630,0x290001e1,0x00000000,0x00000000}},	//   rtić, _ója_, --, --, 
   {{0xdce40bb8,0xd54401e1,0x00000000,0x00000000}},	//   stić, _pẹ̀t, --, --, 
   {{0xf2dc003a,0xdce401a6,0x108400c7,0x00000000}},	//   giâ_, ptić, ҧҩык_, --, 
   {{0x412825fc,0x26dc00b5,0xb140084c,0xddc40210}},	//   рого_, miuo_, мнял, zaił, 
   {{0x93bc0311,0x00000000,0x00000000,0x00000000}},	//   rcăr, --, --, --, 
   {{0x93bc084c,0xf2dc208d,0x200c013c,0xd5440241}},	//   scăr, biâ_, ådi_, _tẹ̀t, 
   {{0x20040a28,0xf4100302,0xf2dc003a,0x00000000}},	//   āmi_, _קפה_, ciâ_, --, 
   {{0x12c40220,0x00000000,0x00000000,0x00000000}},	// [23240] _ءتىپ, --, --, --, 
   {{0x7c641c02,0x81c011ba,0xac804df8,0x2ca4004e}},	//   تارل, ্পদ_, мгул, окуп_, 
   {{0xbb84a482,0xfb88acb9,0xeb94a0bf,0x25bc0ac5}},	//   تلاي, рбек_, жих_, hyul_, 
   {{0xb9c453f0,0x536c010f,0x00000000,0x00000000}},	//   يقاي, רכאַ, --, --, 
   {{0x2d8c037e,0x7b0803b2,0x05d828fe,0x00000000}},	//   æget_, býun, _बेलब, --, 
   {{0x25bc417f,0xb8640efc,0xd7940395,0x6d2000d4}},	//   dyul_, زاتو, зикъ, _одяз, 
   {{0xc0580023,0x7a8401e2,0x00000000,0x00000000}},	//   _ንዝተፈ, _وشرم, --, --, 
   {{0xab2402d5,0xf1bc0429,0x6a8001b9,0x00000000}},	//   _фота_, yyá_, _олса, --, 
   {{0x2db400c8,0x999801d3,0x3b04022e,0x00000000}},	//   ַלטן_, _دھار_, mloq_, --, 
   {{0x3b04cbc2,0xc98401f7,0x859400f1,0xe4500124}},	//   lloq_, _عشقي, سټپا, мкьы, 
   {{0xf2dd5a01,0xb4d8060c,0x9294533f,0x25bc002e}},	//   tiâ_, _ठगी_, панц, ayul_, 
   {{0xc7641884,0x35a40137,0xf1a40138,0xdb240139}},	//   _رامى, _маег, оргн, _üräz, 
   {{0x66c40054,0xf2dc0393,0x6ef0031c,0x00000000}},	//   _uñka, riâ_, nħbe, --, 
   {{0xf2dc7fa8,0x83540014,0x3b04031c,0xd4440092}},	//   siâ_, _کپٹا, hloq_, _የበኩሏ, 
   {{0xe3ac15fa,0xee3c00a2,0x5f945a52,0xf1bc0784}},	//   _لري_, _anýa_, мирт, syá_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf1bc0309,0x00000000,0x00000000,0x00000000}},	// [23250] qyá_, --, --, --, 
   {{0xf1bc0407,0x00000000,0x00000000,0x00000000}},	//   scás_, --, --, --, 
   {{0x6ef0031c,0x00000000,0x00000000,0x00000000}},	//   eħbe, --, --, --, 
   {{0x25bd5a02,0x2d8c01bf,0x00000000,0x00000000}},	//   yyul_, æges_, --, --, 
   {{0x6ef0031c,0xba5000cf,0x00000000,0x00000000}},	//   għbe, رنوع, --, --, 
   {{0x88bc002b,0x00000000,0x00000000,0x00000000}},	//   _kuśi, --, --, --, 
   {{0x387c0175,0xad9801ed,0x26dc0381,0x3b0406be}},	//   _dbtr_, _ezút, tiuo_, bloq_, 
   {{0xbd540244,0x00000000,0x00000000,0x00000000}},	//   _برێژ, --, --, --, 
   {{0x26dc0006,0x00000000,0x00000000,0x00000000}},	//   riuo_, --, --, --, 
   {{0xe7300597,0x00000000,0x00000000,0x00000000}},	//   _قصص_, --, --, --, 
   {{0x03a55a03,0x88bc00b8,0x00000000,0x00000000}},	//   чино, _nuśi, --, --, 
   {{0x29055a04,0xc5d401ca,0x00000000,0x00000000}},	//   llna_, _ніль, --, --, 
   {{0x2a7c002e,0x88bc0055,0xe814012d,0x00000000}},	//   _mbub_, _auśi, धेरा_, --, 
   {{0xb6180150,0x00000000,0x00000000,0x00000000}},	//   _ﹼﺽ_, --, --, --, 
   {{0xe298039b,0x3f9c2507,0x29040098,0x932401b9}},	//   _ҳақ_, ítu_, ilna_, ثرین, 
   {{0x3ea4005a,0xa1c402dd,0x6fb01699,0x00000000}},	//   ñot_, _жұмд, رمقا, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [23260] --, --, --, --, 
   {{0x3dd0033f,0x1fd80154,0xdbc400c7,0xb19800df}},	//   rzyw_, _দুঃস, мазҩ, _פייכ, 
   {{0x2d8c037e,0x3b0401d5,0x00000000,0x00000000}},	//   æger_, tloq_, --, --, 
   {{0xfe404ccb,0x29055a05,0xe8900022,0x00000000}},	//   _سکری, elna_, ҵашь, --, 
   {{0x38440092,0x3b055a06,0x290402d2,0x00000000}},	//   _ያቀረብ, rloq_, flna_, --, 
   {{0xddc4033f,0x3178010f,0x290401a8,0x00000000}},	//   raiń, מאנד, glna_, --, 
   {{0xf090011a,0x3cf800cd,0x00000000,0x00000000}},	//   גנו_, ्तीं_, --, --, 
   {{0x98780fb7,0x9538023a,0x35686fe4,0x25f400c5}},	//   _išči_, озит_, брон_, _उँखी_, 
   {{0x7ae15a07,0xad9801d3,0x6a815a08,0x8570431a}},	//   miot, _nyúl, _ялта, نگوئ, 
   {{0x7ae15a09,0x660c00fd,0x2954011a,0xbb2801ec}},	//   liot, _şikä, _מסמך_, _ﺤﻘﻕ_, 
   {{0xb80800c6,0xc8f800db,0xe70407d6,0xe8500214}},	//   _ايام_, _بولچ_, _کسلی, _سنند, 
   {{0x7ae02045,0xddc400da,0x3cf80882,0xf6d4bfb2}},	//   niot, maiņ, ्तुं_, _عزاد, 
   {{0x78b802fb,0x46a8012c,0xe5a00353,0x88bc002b}},	//   _kotv, कारह, _пици, _suśi, 
   {{0x7ae00053,0xf8bc1d8a,0x78b95a0a,0x96a4012d}},	//   hiot, ्सिय, _jotv, काकॉ, 
   {{0x78b80efa,0xe478011a,0x00000000,0x00000000}},	//   _motv, _הרוכ, --, --, 
   {{0x78b8014f,0x7ae0005a,0x660c0112,0x00000000}},	//   _lotv, jiot, ückg, --, 
   {{0xad980419,0x50f401af,0xf8bc07b7,0x00000000}},	// [23270] _azúr, _озит, ्साय, --, 
   {{0x78b800de,0xddc400e2,0x5b240022,0x00000000}},	//   _notv, kaiņ, ҕьха, --, 
   {{0x29040122,0x7ae15a0b,0x00000000,0x00000000}},	//   vlna_, fiot, --, --, 
   {{0xd838033b,0xddc400e2,0xb21803b2,0x5a340006}},	//   _afč_, daiņ, rfæf, енцт, 
   {{0x29040083,0xdce4010f,0x9f2400d1,0xe7fc000d}},	//   tlna_, ltiĝ, _سۈكۈ, _ऊँहा_, 
   {{0x7cf40086,0x2904003e,0x57c40116,0x00000000}},	//   rürû, ulna_, ﯨﻠﯩﺮ, --, 
   {{0xdce404ac,0x78b802fb,0xddc400ef,0x00000000}},	//   ntiĝ, _dotv, gaiņ, --, 
   {{0x7ae15a0c,0x38300598,0xd8380100,0x4534009d}},	//   ciot, ннәр, _efč_, мхот, 
   {{0x2d9c0306,0x78b801e3,0xe8483f32,0x29045f0b}},	//   _šuej_, _fotv, _هجان_, plna_, 
   {{0x78b8200c,0xdce4008f,0x6ab95a0d,0xddc40153}},	//   _gotv, ktiĝ, _houf, ngiš, 
   {{0xd874107b,0x6ab870d8,0x00000000,0x00000000}},	//   _سالب, _kouf, --, --, 
   {{0x6ab80129,0xddc400a2,0xf770011a,0x00000000}},	//   _jouf, bbiň, _יקב_, --, 
   {{0x6ab95a0e,0xdce40115,0x78b8022e,0x00000000}},	//   _mouf, etiĝ, _yotv, --, 
   {{0x6ab85e51,0xdce401e4,0xf9900375,0x8424129d}},	//   _louf, ftiĝ, דרך_, _قىشن, 
   {{0x68e0009a,0x9ba001ec,0xf4b4193a,0x7ae00477}},	//   iind, _ءﻭﺗﺘ, _تشنگ, yiot, 
   {{0x6ab80099,0x7ae00077,0xdce401e4,0xe56c013d}},	//   _nouf, xiot, mriĉ, lğış, 
   {{0xdce4008f,0x7ae15a0f,0xad9801d3,0xdb080332}},	// [23280] lriĉ, viot, _szúr, ílís, 
   {{0x68e15a10,0x3cf8068f,0xd1c80020,0xc10400c6}},	//   jind, ्तें_, ጠኞች_, _زوجي, 
   {{0x7ae15a11,0x6ab95a12,0xb4f800c8,0xdce44250}},	//   tiot, _bouf, קלער, nriĉ, 
   {{0x78b8f61c,0x6ab82d16,0x68e01924,0xc0f40023}},	//   _sotv, _couf, eind, ሉዎም_, 
   {{0x68e15a13,0x7ae15a14,0x78b8506e,0x6ab8012c}},	//   find, riot, _potv, _douf, 
   {{0x7ae15a15,0x68e15a16,0x20040213,0xdce401e4}},	//   siot, gind, əmir_, kriĉ, 
   {{0x6ab95a17,0x7ae0936b,0xad9800dd,0x88bc0055}},	//   _fouf, piot, _nyúj, _nuśu, 
   {{0x6ab804c4,0x68e004cc,0x00000000,0x00000000}},	//   _gouf, aind, --, --, 
   {{0x78b800d8,0x00000000,0x00000000,0x00000000}},	//   _totv, --, --, --, 
   {{0x68e15a18,0x6ab95a19,0x00000000,0x00000000}},	//   cind, _zouf, --, --, 
   {{0x6ab81ed5,0xca7401a9,0x073800ec,0x6d4800e5}},	//   _youf, _kuzа, _فيلڊ_, ágaz, 
   {{0x66e00124,0x65840267,0x47b00154,0x00000000}},	//   _иоха, örhå, জনশী, --, 
   {{0x98a40356,0x45a019c5,0x00000000,0x00000000}},	//   _gumă_, _مەيك, --, --, 
   {{0x660c2155,0x3cf80034,0x20d40036,0x69ac0073}},	//   ücke, ्तों_, _läif_, ंमती, 
   {{0xdc880020,0xc5ec004b,0xad9801d3,0x4384030d}},	//   _አማራጭ_, _نړی_, _gyúj, _пăрт, 
   {{0x68e15a1a,0xdce4008f,0x88bc012d,0x200c0254}},	//   zind, rtiĝ, _huśt, üdia_, 
   {{0x68e15a1b,0xdce55a1c,0x6ef00327,0xcdc40137}},	// [23290] yind, stiĝ, għba, رۇسۇ_, 
   {{0x6ab95a1d,0x68e15a1e,0xee3c0030,0xddc40006}},	//   _souf, xind, _iným_, ugiš, 
   {{0x6ab95a1f,0xddc40024,0x00000000,0x00000000}},	//   _pouf, rgiš, --, --, 
   {{0x79c408b0,0xdd900014,0x00000000,0x00000000}},	//   ﯩﻠﯩﻤ, دوے_, --, --, 
   {{0x69ac0073,0x19580006,0x48c40150,0x00000000}},	//   ंमधी, дачы_, нәжа, --, 
   {{0x6ab804e6,0x00000000,0x00000000,0x00000000}},	//   _wouf, --, --, --, 
   {{0x6ab945cc,0x98a40311,0x5c04a229,0xfbcc00ec}},	//   _touf, _sumă_, _аята, _ٿڪل_, 
   {{0x68e12af5,0x00000000,0x00000000,0x00000000}},	//   sind, --, --, --, 
   {{0x68e15a20,0x9994007b,0x88bc002b,0x05d83be5}},	//   pind, _لؤلؤ, _suśu, _बेखब, 
   {{0x68e15a21,0x7bc808fb,0xdce401e4,0x82344605}},	//   qind, øfug, triĉ, کردا, 
   {{0xd77410de,0xdce402b1,0x660c0112,0xca7401a9}},	//   _لانع, nuiā, ückb, _yuzа, 
   {{0xd05403be,0xdce55a22,0xe9dc0008,0x45d40108}},	//   mizə, ktiğ, _þús_, _поес, 
   {{0x20d401b8,0xd175476e,0x26cc56ce,0xd05406be}},	//   _jäig_, кыры, _ilgo_, lizə, 
   {{0x657801c8,0xdce401e4,0x00000000,0x00000000}},	//   mtuh, priĉ, --, --, 
   {{0x65782a17,0x3f1406ed,0x09bc00dc,0xd05406be}},	//   ltuh, еќат, ्नुय, nizə, 
   {{0x670c012c,0xefb001d5,0x00000000,0x00000000}},	//   ातिक_, چییگ, --, --, 
   {{0x62840472,0x20d55a23,0xca74022e,0xd05403e3}},	// [232a0] _ibio, _räif_, _ruzа, hizə, 
   {{0xee340323,0x6578009f,0x26cc0142,0x20d40139}},	//   _үнэ_, ituh, _llgo_, _säif_, 
   {{0x20d401c7,0x65780254,0x00000000,0x00000000}},	//   _päif_, htuh, --, --, 
   {{0x65795a24,0x00000000,0x00000000,0x00000000}},	//   ktuh, --, --, --, 
   {{0x199470c9,0x62855a25,0xd838007f,0xe9dc00d7}},	//   таля, _mbio, _ončt_, _žúr_, 
   {{0x26cc5599,0x6578089c,0xd05400ac,0x00000000}},	//   _algo_, dtuh, fizə, --, 
   {{0x569413f3,0x628400db,0x7c2c02d0,0xca74022e}},	//   вайт, _obio, _igbr, _tuzа, 
   {{0x20d400c5,0xee3c010b,0x6578aaad,0x35441069}},	//   _häid_, _boýy_, ftuh, нхов, 
   {{0x65780589,0xa964e4e0,0x20d40037,0x00000000}},	//   gtuh, _пита_, _käid_, --, 
   {{0x62855a26,0x20d400af,0xa6100022,0xb8640066}},	//   _abio, _jäid_, ымыч, _ساطو, 
   {{0x628401ab,0x733000db,0x00000000,0x00000000}},	//   _bbio, دۉبا, --, --, 
   {{0x660c0112,0x7d1c0175,0x98a40210,0x360400ae}},	//   ückc, hmps, _dumą_, _كواف, 
   {{0x63a15a27,0x6a680793,0xa1842cc8,0xee3c0432}},	//   _ernn, löfü, лырл, _goýy_, 
   {{0x6284013f,0xe81405d7,0x7c2c003e,0x20d40036}},	//   _ebio, धेका_, _ngbr, _näid_, 
   {{0x88bc0055,0x98a43f05,0x61140305,0xad9800e5}},	//   _kuśr, _gumą_, удру, _tyúk, 
   {{0x6284006a,0xdce40365,0x752866b9,0x7c2c02d0}},	//   _gbio, ttiğ, _hifz, _agbr, 
   {{0xdef95a28,0xd9e00037,0x3f9c0158,0x9f0401d5}},	// [232b0] хыр_, _खेलत_, åtur_, اوقو, 
   {{0x62840034,0x66e40066,0xc0c000d1,0xdce55a29}},	//   _zbio, _kèkè, _кәси, tuiā, 
   {{0xdce405d1,0xe1f0208f,0x9d440131,0xca7400ee}},	//   stiğ, _نسی_, نئەن, вулы, 
   {{0x7c2c0ea0,0xdce403e0,0x9b443dbb,0x00000000}},	//   _egbr, ptiğ, اننو, --, 
   {{0xdb0801ed,0xade400ee,0xea54013d,0x09bc090a}},	//   ílás, _чцнк, _үзгә_, ्नेय, 
   {{0x77880213,0x74cc01ec,0xd9e00073,0x2d4c0210}},	//   _məxf, _ﯗﺭﻻﻳ, _खेळत_, mże_, 
   {{0x973c01a6,0x9d195a2a,0xc79401e0,0x2d4c012d}},	//   _prća, _чорт_, трлы, lże_, 
   {{0xd05400ac,0xfa680131,0x65795a2b,0x46a40108}},	//   rizə, _очуқ_, ttuh, таив, 
   {{0x98a40024,0x2d4c033f,0xae0407af,0xddc4002b}},	//   _sumą_, nże_, _वुमन_, daiś, 
   {{0x65795a2c,0x66e4007f,0x62840ffb,0x9998b610}},	//   rtuh, _bèkè, _sbio, _якут_, 
   {{0x65795a2d,0xa93402d3,0x46800150,0x00000000}},	//   stuh, _እተባህ, _ұққа, --, 
   {{0x2d4c006d,0x49080316,0x18b4035b,0x940c0213}},	//   kże_, ितको_, _аҳәы_, nddə_, 
   {{0x6284003a,0x2d4c012d,0x7d1d5a2e,0x05d80118}},	//   _vbio, jże_, ymps, _बेचब, 
   {{0x67280023,0xdce4031c,0x940c03b9,0x00840395}},	//   _higj, rriċ, hddə_, ълго, 
   {{0x442001fb,0x6d4c058a,0x628401ab,0x2d4c033f}},	//   _àh_, _awca, _tbio, eże_, 
   {{0x672801d9,0x8e744ecc,0x20d40139,0xdce4031c}},	//   _jigj, лууч, _säid_, priċ, 
   {{0xed540a16,0xf65000c8,0x67295a2f,0x1ea8004b}},	// [232c0] кот_, יצן_, _migj, واړي_, 
   {{0x6728069c,0x315400c8,0xbfc40124,0xd8380427}},	//   _ligj, _שיין_, _абок, _kače_, 
   {{0xd8381b24,0x78ac4b84,0x6d4c62af,0x00000000}},	//   _jače_, _òbvi, _ewca, --, 
   {{0x0ba95a30,0xe6040050,0x0ea82e05,0x8b940724}},	//   عالى_, _نش_, _चोपड, ыруч, 
   {{0xd910424b,0x6d4c009a,0x20d40254,0x00000000}},	//   میر_, _gwca, _täid_, --, 
   {{0x7c2c05c7,0x37a800d1,0x88bc002b,0xd7f4009d}},	//   _ugbr, дтин_, _suśr, лзлы, 
   {{0x20d400af,0xb2181455,0x00000000,0x00000000}},	//   _käib_, neær, --, --, 
   {{0x6bd40050,0x00000000,0x00000000,0x00000000}},	//   _شوقس_, --, --, --, 
   {{0x672802d3,0x66e402e2,0x779002f2,0x79b400e5}},	//   _digj, _sèkè, _چیتا, _جھاڑ_, 
   {{0x6a6801b8,0xdce423cc,0x660c002f,0x00000000}},	//   pöfü, krič, ücka, --, 
   {{0x39455a31,0xf47c0023,0xe8d4011a,0xc7640617}},	//   lpos_, _ንኻልእ_, _שובר_, _مانى, 
   {{0xdb1c0724,0xdce424c6,0x20d400c5,0x39440153}},	//   _üzäk, drič, _näib_, opos_, 
   {{0x39455a32,0xb4b004b4,0xb218005c,0x00000000}},	//   npos_, _вилә, veæs, --, 
   {{0x39441280,0x00000000,0x00000000,0x00000000}},	//   ipos_, --, --, --, 
   {{0x33b00131,0xd83801a6,0x6e2c0332,0x602801d3}},	//   _ئەجر, _gače_, _pgcb, _rémü, 
   {{0x31c40124,0xca3800df,0xdef43004,0x00000000}},	//   _асов, _kaŝe_, апсы, --, 
   {{0x1be802ab,0x9e2400d1,0x1e340006,0x00000000}},	// [232d0] _टेबल_, لىفو, рнуў, --, 
   {{0xdce41aff,0xe7e0007d,0x6d4c0175,0xb884003a}},	//   brič, _कइला_, _vwca, ntĭē, 
   {{0x09bc16d1,0xac2401fc,0x3944003a,0xeae000c7}},	//   ्न्य, тфак, epos_, аӡаҩ, 
   {{0x973c0023,0xdd7400e5,0x00000000,0x00000000}},	//   _ኢሰያስ, _چھلک, --, --, 
   {{0x3944b4bf,0xda784d15,0xe9a80131,0x67280240}},	//   gpos_, тях_, بدان_, _rigj, 
   {{0x6728033b,0xd91402d5,0x660801bf,0x20d40037}},	//   _sigj, адчы, _rygk, _täie_, 
   {{0x66080ac5,0x39440165,0xeaf8007b,0x00000000}},	//   _sygk, apos_, _قررت_, --, 
   {{0x39440218,0xd8389b4a,0x00000000,0x00000000}},	//   bpos_, _rače_, --, --, 
   {{0x67295a33,0x452801c6,0xe7e00118,0x00000000}},	//   _vigj, нжин_, _केरा_, --, 
   {{0x6728020c,0x2d8802e2,0xd8380841,0xd640030d}},	//   _wigj, _mpce_, _pače_, _чiож, 
   {{0x03240372,0x42e87e32,0xc3246bce,0xd7940395}},	//   лдон, емно_, лмок, _вихъ, 
   {{0xd7f805f5,0x2d895a34,0xdce40219,0xf484030f}},	//   _руу_, _opce_, vrič, پایی, 
   {{0x51553684,0x07a40022,0x09b4010f,0x7b08010e}},	//   итру, _шаҧн, נפֿט_, mýut, 
   {{0xdce41151,0xdb0c02d2,0x7b0800ee,0x00000000}},	//   trič, _íhön, lýut, --, 
   {{0xf45425f9,0x82a55a35,0x64a00184,0x2d895a36}},	//   _עיקר_, _байж, _баҙа, _apce_, 
   {{0xff240117,0x00000000,0x00000000,0x00000000}},	//   умбо, --, --, --, 
   {{0x2240009a,0xd1e80023,0x39440175,0x5194074d}},	// [232e0] _ifik_, _ዘላቶ_, xpos_, _кăта, 
   {{0xdce4341a,0x5f0400d1,0xec74fcdd,0x270c1a47}},	//   prič, узға, лпу_, ातुर_, 
   {{0xe7e005ba,0xfaa401b9,0x39440f85,0xf454010f}},	//   _केला_, лажо, wpos_, ריער_, 
   {{0x39455a37,0xf8bc0f4a,0x00000000,0x00000000}},	//   tpos_, ्स्प, --, --, 
   {{0x6f015a38,0x39455a39,0xaa5412e3,0x7d5400db}},	//   _ínca, upos_, الها_, _حئجئ, 
   {{0xe944315b,0xfce55a3a,0xb21801bf,0x23d007b7}},	//   ارنی, _сого, kfæn, दनाद, 
   {{0x39455a3b,0xf72800a8,0x2240014a,0x660c002f}},	//   spos_, нций_, _ofik_, ückn, 
   {{0x394416fe,0x96341f91,0xab255a3c,0x97141d39}},	//   ppos_, шниц, _боса_, јмиц, 
   {{0x3b04013c,0x88800014,0xf5b400be,0x00000000}},	//   mooq_, _ژیٖن, اصعد, --, 
   {{0x224001e2,0x3b040194,0xd4540063,0x00000000}},	//   _afik_, looq_, шкоћ, --, 
   {{0xa92004bf,0xd25069f2,0x8cd80034,0xb19119ba}},	//   ížen, يند_, फोटो, әлгә, 
   {{0x81e400bd,0x3b040194,0xf7700133,0xb3541291}},	//   _বুধ_, nooq_, _ناڤ_, پیکا_, 
   {{0x3b040194,0xf1a8007b,0xbb440150,0x98a40210}},	//   iooq_, راحه_, _ﺅﺩﻱ_, _sumę_, 
   {{0x22415a3d,0x7e740810,0xaee0002b,0x00000000}},	//   _efik_, egyp, _koṇe, --, 
   {{0xdfd800a7,0x7c3c0334,0x4ee401e0,0xeea833cc}},	//   гът_, dcpr, асаҡ, нтак_, 
   {{0x3b04013c,0xd13400f3,0x00000000,0x00000000}},	//   jooq_, _кнић, --, --, 
   {{0xec6878da,0x00000000,0x00000000,0x00000000}},	// [232f0] ерек_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x604400c7,0xde1800d1,0x7e6c0205,0x00000000}},	//   _ухыз, پقەت_, _şipş, --, 
   {{0x3b040eda,0xab082097,0xadf000fd,0xddd400a2}},	//   gooq_, رتاق_, _гомә, _ýaşn, 
   {{0x2d8801ef,0x00000000,0x00000000,0x00000000}},	//   _upce_, --, --, --, 
   {{0x20d400af,0x48c4013d,0x00000000,0x00000000}},	//   _käia_, шәба, --, --, 
   {{0x985402bf,0x6d5c03ac,0x00000000,0x00000000}},	//   стіш, lsqa, --, --, 
   {{0x05645cf0,0xba500137,0xc56407a5,0x270c0118}},	//   авин, _ۇچۇع, акик, ातेर_, 
   {{0x6d5c0857,0x00000000,0x00000000,0x00000000}},	//   nsqa, --, --, --, 
   {{0xd8740f00,0x69c8e53b,0x00000000,0x00000000}},	//   _هامب, myge, --, --, 
   {{0x29055a3e,0x69c87e1a,0x86c4b58a,0xd788004b}},	//   mona_, lyge, _پيشن, _منلو_, 
   {{0x29055a3f,0x42540120,0xc764075e,0xb218005c}},	//   lona_, штот, _ماچى, rfæn, 
   {{0xd1e8001f,0xb21800b5,0xee3c00a2,0x00000000}},	//   _ዘላቂ_, sfæn, _kaýf_, --, 
   {{0x03a4090b,0x29055a40,0x04455a41,0xd8380427}},	//   _вико, nona_, _текн, _kača_, 
   {{0xb218019b,0xd8380989,0x29055a42,0x6d5cad2b}},	//   lfæl, _jača_, iona_, esqa, 
   {{0x2240009a,0xe500098a,0xd8380171,0x00000000}},	//   _ufik_, रकवि_, _mača_, --, 
   {{0xee3409f7,0xada0117e,0xe29801ec,0x404801af}},	// [23300] рну_, оатл, _аақ_, _иппо_, 
   {{0xfbd0198a,0xbc6800be,0x69c800a2,0xd6040354}},	//   يتا_, ئمان_, dyge, _тiев, 
   {{0xad98056a,0x2720000f,0x6d5c0784,0x3b040869}},	//   _axúd, _jűns_, asqa, tooq_, 
   {{0xb9c401b9,0xdbd002f0,0x3ea40166,0xdcec00d7}},	//   иёли, nžér, _тимг, _úhľa, 
   {{0xf9915a43,0x3b040af5,0x660c0730,0x00000000}},	//   تبا_, rooq_, ückl, --, 
   {{0x29055a44,0xb7644ee3,0x3b0420ac,0xd83802f0}},	//   gona_, атий, sooq_, _bača_, 
   {{0x030402ab,0xf77001d5,0x00000000,0x00000000}},	//   रवाह_, زاغ_, --, --, 
   {{0x29040421,0x69c9487d,0xd838009b,0xfce40117}},	//   aona_, byge, _dača_, _соҳо, 
   {{0x4af80276,0xb21801bf,0x7b0803b2,0xa92400de}},	//   _сэря_, gfæl, býur, _bažī, 
   {{0x37e40228,0x2720045f,0xe7fc228d,0x00000000}},	//   _козг, _sűnt_, _ऊँचा_, --, 
   {{0xb4d411a6,0xded4001f,0x79815a45,0xdbd00306}},	//   _सती_, ረሱን_, ltow, _ožív, 
   {{0xf5e811ed,0xca3800df,0x2810036b,0xb5f002dd}},	//   _имел_, _kaŝa_, _بومس, _мүйі, 
   {{0x7980006d,0x76400241,0xd25014d1,0x91c400fb}},	//   ntow, _ifoy, ينگ_, сәйл, 
   {{0x7980949e,0xa1140a81,0x00000000,0x00000000}},	//   itow, ٲوِت, --, --, 
   {{0x251805e1,0xd4982b8d,0x69c80a05,0x272001d3}},	//   _שווא, _арқ_, zyge, _tűnt_, 
   {{0x7980068f,0x29055a46,0xea9c00b8,0x6d5c02d0}},	//   ktow, zona_, _meṣa_, tsqa, 
   {{0x69c883fb,0x79801430,0x00000000,0x00000000}},	// [23310] xyge, jtow, --, --, 
   {{0x29055a47,0x2ba40640,0xd25001d3,0x6d5c0857}},	//   xona_, ијев, _بنک_, rsqa, 
   {{0x29055a48,0x6f004a1f,0x20d400c5,0x79801961}},	//   vona_, _ínco, _käin_, etow, 
   {{0x290415d3,0x69c95a49,0x20d425e4,0xd838244f}},	//   wona_, tyge, _jäin_, _rača_, 
   {{0x20d40a40,0xad9802fb,0xda1800d1,0x99d402da}},	//   _mäin_, _vyús, ۇزۇش_, يتها, 
   {{0x270c0da5,0x76415a4a,0x69c8463d,0x2904696c}},	//   ात्र_, _afoy, ryge, uona_, 
   {{0x67915a4b,0x69c85b47,0xe9455a4c,0x76400076}},	//   تیاط, syge, ارچی, _bfoy, 
   {{0x20d40664,0x00000000,0x00000000,0x00000000}},	//   _näin_, --, --, --, 
   {{0x29055a4d,0x798002d0,0x6ef00003,0xcfcc0154}},	//   pona_, ctow, għbi, রছিন, 
   {{0x290423e0,0xb218005c,0x00000000,0x00000000}},	//   qona_, rfæl, --, --, 
   {{0xb21800b5,0xd90c01d3,0xd4c4007b,0x69c400e4}},	//   sfæl, _جیو_, تغيي, _ęjey, 
   {{0x438402dd,0x48f00fe6,0x57cc00df,0x00000000}},	//   _ۇلتق, ेवको_, _שמאַ, --, 
   {{0x45441de5,0x20d40a40,0xf49400ec,0xea9c00b8}},	//   _انتق, _däin_, _گانڌ, _zeṣa_, 
   {{0xea9c00b8,0x63b00150,0x00000000,0x00000000}},	//   _yeṣa_, _дәмх, --, --, 
   {{0x6440022f,0x20d401c7,0x81e400eb,0x00000000}},	//   _ifni, _fäin_, _বুশ_, --, 
   {{0x6f000048,0x79815a4e,0xef1c05d5,0x00000000}},	//   _íncl, ytow, _chü_, --, 
   {{0x61200793,0x30240075,0xfe6c0451,0x778806be}},	// [23320] völf, _қоюп_, وگڏ_, _məxa, 
   {{0x7bdc0112,0xee3c0162,0x79800175,0xefd00092}},	//   tzpu, _snýt_, vtow, _የልዩ_, 
   {{0x79815a4f,0x3b841b15,0xca3801e4,0x5ec400d1}},	//   wtow, слег, _saŝa_, _динғ, 
   {{0xdbd00e96,0x79807e54,0x7bdc002f,0x05b803ce}},	//   _užív, ttow, rzpu, ेहाब, 
   {{0xe3a4c45b,0x798003f9,0x64415a50,0x00000000}},	//   _کر_, utow, _ofni, --, 
   {{0x7980006d,0x3ea028dc,0xe8dc0051,0x3f9c0327}},	//   rtow, _hakt_, ườg_, ħtuf_, 
   {{0xf0900302,0x79815a51,0xfaa4ab39,0xf6e40408}},	//   פנה_, stow, _лаво, йцин, 
   {{0x3ea077d4,0xd7f804a9,0xe9d55a52,0x79815a53}},	//   _jakt_, луқ_, ркә_, ptow, 
   {{0xf7700d83,0x3ea07944,0xee3c02d2,0xded41954}},	//   زاں_, _makt_, _knýr_, ረሱና_, 
   {{0x20d40a40,0xea9c002b,0x00000000,0x00000000}},	//   _säin_, _teṣa_, --, --, 
   {{0x387c16cb,0x20d402f6,0x92940276,0x778806be}},	//   _ictr_, _päin_, оанц, _fəxa, 
   {{0x6440008c,0x387c0115,0xd8380010,0x00000000}},	//   _efni, _hctr_, _kačo_, --, 
   {{0x6120691c,0x98ac033b,0x644001a9,0xf2043129}},	//   köld, _lidč_, _ffni, сяно, 
   {{0x64a107e2,0x157c0131,0x61200008,0x656c0077}},	//   _нача, _ﻣﻪﺳﯩ, jöld, áche, 
   {{0xdfd40046,0x3ea003cd,0x00000000,0x00000000}},	//   поры, _bakt_, --, --, 
   {{0xdec80137,0x0f140212,0x37a800cc,0x00000000}},	//   буул_, імаю, _কথাৰ, --, 
   {{0x3ea001f7,0xd8380030,0x6120655d,0xee3c0162}},	// [23330] _dakt_, _načo_, föld, _snýs_, 
   {{0xc4b0012d,0x6120950c,0x00000000,0x00000000}},	//   जाएओ, völg, --, --, 
   {{0x3ea0a162,0x2b4404cc,0x5ac801ec,0x00000000}},	//   _fakt_, ënc_, әлім_, --, 
   {{0xd8380010,0x660c002f,0x8eb40345,0x00000000}},	//   _bačo_, ückk, _بڕست, --, 
   {{0x387c01ee,0x1a682172,0xe29c010f,0x00000000}},	//   _bctr_, صیلی_, טשאר, --, 
   {{0x3ea15a54,0xd8380419,0x778803e3,0x224403e0}},	//   _zakt_, _dačo_, _səxa, ımki_, 
   {{0x59d40058,0xfbf4014b,0x00000000,0x00000000}},	//   يغۇر, _дорӯ, --, --, 
   {{0x2ca00b4b,0x896401d9,0x06c801c6,0xee3c00a2}},	//   _hajd_, _وُزن, ргий_, _haýb_, 
   {{0x2a7c004e,0x2bc401ad,0x7c3001e4,0xd8380171}},	//   _icub_, लहवा, ĝerŝ, _gačo_, 
   {{0x83895a55,0xe798007b,0x00000000,0x00000000}},	//   абов_, _مخصص_, --, --, 
   {{0x2ca0066d,0x61200086,0x27b0013d,0xd83800d7}},	//   _majd_, nöle, _хәлс, _začo_, 
   {{0xc5d41c26,0xca380115,0x96b8014b,0x00000000}},	//   _міль, _maŝo_, _гушу_, --, 
   {{0x3ea15a56,0x9fa004e6,0x021800d4,0x00000000}},	//   _rakt_, méét_, рінь_, --, 
   {{0x20d404e6,0x32d800e8,0x3ea15a57,0x00000000}},	//   _gäil_, _rëye_, _sakt_, --, 
   {{0x93255a58,0x61215a59,0x3ea15a5a,0x973c16a3}},	//   ترین, völd, _pakt_, _prći, 
   {{0xee3c08a7,0x00000000,0x00000000,0x00000000}},	//   _snýr_, --, --, --, 
   {{0x2ca00135,0x61200267,0x660c002f,0x00000000}},	// [23340] _bajd_, töld, ückh, --, 
   {{0x3ea00bc9,0x00000000,0x00000000,0x00000000}},	//   _wakt_, --, --, --, 
   {{0x433c001f,0x9fa00036,0x00000000,0x00000000}},	//   _አደባባ, kéét_, --, --, 
   {{0xb4d47e2a,0x32d80de2,0x00000000,0x00000000}},	//   _सत्_, _tëye_, --, --, 
   {{0xddc40327,0x0d740108,0xb9040108,0x00000000}},	//   ngiż, _ныря, оздк, --, 
   {{0xe8f401c0,0xed54009b,0x612000a2,0x00000000}},	//   олч_, _фор_, böle, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xed4c210e,0xe8dc0051,0x00000000,0x00000000}},	//   _سپہ_, ưởg_, --, --, 
   {{0x6a800354,0x00000000,0x00000000,0x00000000}},	//   _юлта, --, --, --, 
   {{0x20d401c7,0x00000000,0x00000000,0x00000000}},	//   _bäim_, --, --, --, 
   {{0x80bc0b67,0x00000000,0x00000000,0x00000000}},	//   शाने, --, --, --, 
   {{0x27303955,0xddc472f2,0xe7e000bc,0x33740092}},	//   _قىلس, mbiņ, _केटा_, _በደረሰ_, 
   {{0xf484405c,0xe29802d5,0xd1e80023,0xddc40064}},	//   _дуйн, цаў_, _ዘላቒ_, igių, 
   {{0xb6040153,0x00000000,0x00000000,0x00000000}},	//   rašę, --, --, --, 
   {{0x2ca0012d,0x925848a6,0x00000000,0x00000000}},	//   _rajd_, _лайт_, --, --, 
   {{0x2ca0003d,0x60200ca8,0xd04803b9,0x00000000}},	//   _sajd_, _sámí, _ələy, --, 
   {{0x630421ef,0x3f9c066a,0xdef80022,0x712401e2}},	// [23350] _تويل, ætur_, цыр_, _ورخل, 
   {{0xca38010f,0x660cb1e1,0x612001f4,0xdcb8004e}},	//   _paŝo_, ücki, töle, огуч_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3cf8004e,0x00000000,0x00000000,0x00000000}},	//   anpv_, --, --, --, 
   {{0x2ca00327,0xdce400df,0x602002d2,0x0ef812eb}},	//   _tajd_, luiĝ, _támí, ्कीस_, 
   {{0x9d180801,0x47580801,0x2bc800db,0xc7a41887}},	//   _моят_, брия_, _кубо_, зикк, 
   {{0xd37807f5,0xdce400df,0x00000000,0x00000000}},	//   juć_, nuiĝ, --, --, 
   {{0x20d4000d,0x00000000,0x00000000,0x00000000}},	//   _räim_, --, --, --, 
   {{0x38300724,0xeaf40c22,0x00000000,0x00000000}},	//   мнәр, ंचीत_, --, --, 
   {{0x8d900125,0xda20000d,0xdce40064,0x00000000}},	//   _ምክትል_, _बरतत_, prią, --, 
   {{0xd37805ce,0x00000000,0x00000000,0x00000000}},	//   guć_, --, --, --, 
   {{0x88bc02a6,0x6f0000d2,0xf5540214,0x612001d3}},	//   _অতিক, _ínch, _کلوب_, kölc, 
   {{0xb344008e,0x7638008f,0xdc18098a,0x00000000}},	//   _azçı, _הענג, _थर्ड_, --, 
   {{0x41285378,0x25ac0010,0x61200e78,0x25bc031c}},	//   сого_, _irgl_, wölb, mxul_, 
   {{0x246401ed,0x0ef80118,0x00000000,0x00000000}},	//   _című_, ्कूस_, --, --, 
   {{0x823426c0,0x660c03fa,0x20d40037,0xf2dc0022}},	//   _عربا, ückw, _käik_, châ_, 
   {{0x20d4000d,0x25bc0356,0x00000000,0x00000000}},	// [23360] _jäik_, nxul_, --, --, 
   {{0xb88401f1,0xc310015b,0x200d5a5b,0xdce401e4}},	//   _kríž, _সূচি_, üdis_, buiĝ, 
   {{0xfb895a5c,0xeb955a5d,0x9aa400d1,0x00000000}},	//   сбек_, зих_, дулһ, --, 
   {{0xdce40989,0x9f515a5e,0x778803e3,0xd91053b6}},	//   krić, _ñaña_, _dəxl, چیر_, 
   {{0xd91089ba,0xdc8535dc,0xdce401fa,0x32d800e8}},	//   نیر_, _оңай, jrić, _jëya_, 
   {{0xdce408ad,0xb8644cec,0xeabc0241,0x00000000}},	//   drić, ساتو, _òùn_, --, 
   {{0x25ac0165,0xee3c010e,0x28f40108,0x48ec000d}},	//   _argl_, _haýa_, яешь_, _अगरो_, 
   {{0xd378107d,0xee3c00a2,0x25bc0327,0x35e40d1d}},	//   vuć_, _kaýa_, fxul_, зцов, 
   {{0xee3c0432,0xab2400d8,0x00000000,0x00000000}},	//   _jaýa_, _хота_, --, --, 
   {{0x656c52bd,0xb4d4068f,0xee3c0209,0xd8380219}},	//   ácha, ससे_, _maýa_, _mačk_, 
   {{0x93c801ed,0xee3c00a2,0xdb0c0248,0x00000000}},	//   زادہ_, _laýa_, _ìhón, --, 
   {{0x66e10c3b,0x26dc01c8,0xda200cb4,0xdce416a3}},	//   _поха, chuo_, _बरात_, brić, 
   {{0x778803b9,0xf2dc0042,0xf1a400bc,0x00000000}},	//   _məxm, rhâ_, खिइन, --, 
   {{0xdce40115,0x00000000,0x00000000,0x00000000}},	//   tuiĝ, --, --, --, 
   {{0xe3ac14a0,0x00000000,0x00000000,0x00000000}},	//   _مري_, --, --, --, 
   {{0xd904168d,0xee3c010e,0x420c01f2,0xdce400df}},	//   _ڕی_, _baýa_, ọsọ_, ruiĝ, 
   {{0xdd955a5f,0x2ca4006a,0xd1f80023,0xf7880139}},	// [23370] наты, ôndo_, ፈርቲ_, laçı_, 
   {{0x81e411ba,0x712000cf,0x9d14329b,0xd82400f1}},	//   _বুক_, _سۉزم, едуч, _مۍ_, 
   {{0xcb9804da,0x3cdc0037,0xf78803b9,0x9cc80166}},	//   تناش_, _गतरे_, naçı_, чыта_, 
   {{0x61200793,0x89d80451,0xdbdc00e4,0x25bc022e}},	//   möla, يوار_, gáña, yxul_, 
   {{0x1d940020,0x9f980162,0xee3c0432,0x7d000129}},	//   _ምርቶች_, _háða_, _gaýa_, éosc, 
   {{0x008800c8,0xdce40960,0x778803e3,0xf7885043}},	//   ַרפֿ, vrić, _təxl, kaçı_, 
   {{0x26dc5bae,0x61201900,0x9be40212,0xee3c010e}},	//   thuo_, nöla, _зітк, _zaýa_, 
   {{0xdce439ae,0x25bc0009,0x85480452,0x98ac24cb}},	//   trić, txul_, озив_, _vidā_, 
   {{0x49055a60,0x00000000,0x00000000,0x00000000}},	//   _قورق, --, --, --, 
   {{0x26dc0198,0x201c01bf,0x25bc0009,0x00000000}},	//   shuo_, _øvig_, rxul_, --, 
   {{0x47d48326,0x6f0000d2,0x9f980413,0xf788013d}},	//   _تيار, _íncw, _náða_, gaçı_, 
   {{0xa2855a61,0x97a49a47,0xd9e400fe,0x04fc0154}},	//   ریخو, _ярул, _ফুটম, ঁতের_, 
   {{0x82343ee6,0x00000000,0x00000000,0x00000000}},	//   بردا, --, --, --, 
   {{0x61200793,0xda201b57,0x9f9801a8,0x660c0112}},	//   föla, _बरसत_, _báða_, ücku, 
   {{0x0c6c07db,0x65795a62,0xee3c00a2,0x00000000}},	//   _ኣምላኽ_, luuh, _saýa_, --, 
   {{0xf4100375,0x9f98032e,0xee3c00a2,0x00000000}},	//   _שפה_, _dáða_, _paýa_, --, 
   {{0x62855a63,0x00000000,0x00000000,0x00000000}},	// [23380] _icio, --, --, --, 
   {{0x6284007f,0x9fa0002e,0x3ea4005f,0x9f9803b2}},	//   _hcio, _léép_, žot_, _fáða_, 
   {{0x657824a1,0x00000000,0x00000000,0x00000000}},	//   huuh, --, --, --, 
   {{0x6578023a,0xd8380219,0x6b800694,0xee3c00a2}},	//   kuuh, _tačk_, ànga, _taýa_, 
   {{0x6578003e,0xa9653ed4,0xdce4031c,0x1958008e}},	//   juuh, дича_, nsiċ, чалы_, 
   {{0xd83800f3,0x88800131,0x657806fd,0x4f6402f2}},	//   _kači_, лғул, duuh, _تایف, 
   {{0xd83856af,0x62855a64,0xb9042311,0x778800ac}},	//   _jači_, _ocio, _पत_, _təxm, 
   {{0x35695a65,0x65781418,0xf5680798,0x0ae800ec}},	//   орон_, fuuh, ошок_, _فرقي_, 
   {{0x7ae00810,0xa408000d,0x00000000,0x00000000}},	//   mhot, _सँउप_, --, --, 
   {{0x62855a66,0x7ae15a67,0xa920299e,0xa5040e92}},	//   _acio, lhot, _адул, мења_, 
   {{0x76840220,0xb4cc0490,0x00000000,0x00000000}},	//   _жылж, _रवी_, --, --, 
   {{0x65781c06,0x9f9809f3,0xd8380841,0xf7886656}},	//   buuh, _ráða_, _nači_, raçı_, 
   {{0x35f86a15,0x660c03fa,0xa18450c0,0x7ae001f4}},	//   _براد_, ückt, кырл, ihot, 
   {{0x7ae15a68,0x6284035a,0x6120005b,0x0ef802a0}},	//   hhot, _ecio, töla, ्क्स_, 
   {{0x7ae15a69,0xe4c479f8,0xce940395,0x00000000}},	//   khot, _تصنی, навъ, --, 
   {{0x7ae001ee,0x628400c6,0x71240451,0x9f980174}},	//   jhot, _gcio, _ڪربل, _váða_, 
   {{0x78b8400c,0x7ae15a6a,0xd83800f3,0xe1f0352e}},	// [23390] _ontv, dhot, _dači_, _پسي_, 
   {{0x7ae0009a,0xb910063f,0x2b4400c7,0x5c7400d8}},	//   ehot, rinụ_, ínco_, клут, 
   {{0x7ae00175,0x6304485f,0xdc340419,0x4ab8003b}},	//   fhot, _سویل, bĺčk, зуля_, 
   {{0x81e402a6,0x78b8010f,0xca38008f,0xdbdc08a7}},	//   _বুট_, _antv, _kaŝi_, ráða, 
   {{0x1a6800f2,0x00000000,0x00000000,0x00000000}},	//   بیقی_, --, --, --, 
   {{0x9fa0003e,0x47582f23,0x6d4c02d0,0x7ae00254}},	//   _séép_, прия_, _itca, ahot, 
   {{0x7ae02939,0x0a580107,0x6ed00037,0x00000000}},	//   bhot, _навъ_, _सवाँ, --, 
   {{0x7ae15a6b,0x78b8035a,0x65795a6c,0x98c01a14}},	//   chot, _entv, tuuh, āsām_, 
   {{0x6ab95a6d,0x3a8401d9,0x7ae801c7,0xf77c0135}},	//   _inuf, _سُلہ, ëfte, ħħan_, 
   {{0x76202777,0x62855a6e,0x6578005b,0x00000000}},	//   ымыз, _scio, ruuh, --, 
   {{0x6ab941af,0x68e00369,0x2af000af,0x6578037e}},	//   _knuf, mhnd, _आगाँ_, suuh, 
   {{0x65795a6f,0x660c0730,0x6d4c02d0,0x00000000}},	//   puuh, ücks, _otca, --, 
   {{0xb14007d8,0xb21800b5,0xd8380419,0x335c0023}},	//   лнял, dfæs, _rači_, _ሰደግኤ_, 
   {{0x68e00369,0x7ae095d8,0x3f8805ac,0xaec01171}},	//   nhnd, zhot, ttbu_, қбул, 
   {{0x7ae00204,0x6d4c0857,0x7a3405d1,0x6ab8036e}},	//   yhot, _atca, _kütü, _onuf, 
   {{0x7ae15a70,0x62840561,0x20d40254,0x8e7400db}},	//   xhot, _ucio, _näiv_, кууч, 
   {{0x7ae09cde,0x7c64007b,0xb3400327,0xc1d001ee}},	// [233a0] vhot, فاضل, ħħej, _сөнә, 
   {{0x6ab84686,0x3154008f,0xac815a71,0x7ae00175}},	//   _anuf, _ריין_, лгул, whot, 
   {{0xd8383341,0x6d4c0334,0x3058011a,0x940c03b9}},	//   _tači_, _etca, _מדיד, fedə_, 
   {{0xb21801a8,0x0ae8088c,0x7ae00118,0x00000000}},	//   mfær, ورني_, uhot, --, 
   {{0x7ae15a72,0xb218f4d8,0xe9d46bd5,0x00000000}},	//   rhot, lfær, нкц_, --, 
   {{0x7ae15a73,0x81e000eb,0x612000e5,0x00000000}},	//   shot, _দশা_, zöln, --, 
   {{0x7a34f7df,0x65680455,0xeb95251c,0xfd640208}},	//   _bütü, _avgh, _пир_, _nhuầ, 
   {{0x612001b8,0x7ae0004b,0x7a3403b9,0x00000000}},	//   kölo, qhot, _cütü, --, 
   {{0xf4855a74,0x28a82c30,0x6ef8013d,0x00000000}},	//   нунн, _टोकि, läbä, --, 
   {{0xdce40989,0xe8f4bb62,0x00000000,0x00000000}},	//   ksič, _злу_, --, --, 
   {{0x7a340793,0x6ee000af,0x65680356,0xaca000e4}},	//   _fütü, _hõbe, _evgh, gaỹg, 
   {{0xb218005c,0x00000000,0x00000000,0x00000000}},	//   dfær, --, --, --, 
   {{0xca380115,0x77907b15,0xc4cc0a81,0x91c43ad0}},	//   _paŝi_, _شیکا, _ژےٚ_, тәйл, 
   {{0xd708008e,0xb2195a75,0x00000000,0x00000000}},	//   _энҗе_, ffær, --, --, 
   {{0x61215a76,0xb2187246,0xee3c010b,0x2f2406ed}},	//   möll, gfær, _faýl_, еќав, 
   {{0xb2849480,0x612002f6,0xb8d0025c,0x00000000}},	//   _чыкк, löll, _ཟལ_, --, 
   {{0x63041e5a,0x00000000,0x00000000,0x00000000}},	// [233b0] _حويل, --, --, --, 
   {{0x6ab95a77,0x612002f6,0x6b80004e,0x9df835a2}},	//   _snuf, nöll, àngo, хнут_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x61209632,0xd83807f5,0xff540115,0x09f800ae}},	//   höll, _jaču_, _שברך_, وفاة_, 
   {{0x61215a78,0x6d4d5a79,0xd8380171,0x9b4400db}},	//   köll, _utca, _maču_, _ەنفو, 
   {{0x7a34a697,0x1cc00135,0x00000000,0x00000000}},	//   _sütü, _ཀོར_, --, --, 
   {{0xee3c010e,0x612001d3,0x7a340205,0x00000000}},	//   _kgý_, döll, _pütü, --, 
   {{0x6ab95a7a,0x98ac0064,0xee3c01ef,0x070800ae}},	//   _unuf, _ridą_, _anýz_, بيبي_, 
   {{0x060829e4,0xa8501321,0xd3780034,0x452801c0}},	//   ьник_, _безә, erć_, мжин_, 
   {{0x04b44155,0xefd0001f,0x2b400175,0x20d401f4}},	//   тсия, _የግድ_, _kujc_, _jäit_, 
   {{0xd83800f3,0x7a341ae4,0x1cc0031c,0xc324519b}},	//   _baču_, _tütü, _ཀོལ_, кмок, 
   {{0x20d40a40,0x7c3808a7,0x052000bd,0xded400b7}},	//   _läit_, _útre, নদের_, የቱን_, 
   {{0x937c0092,0x612002d2,0x00000000,0x00000000}},	//   _ተደርጐ_, böll, --, --, 
   {{0xb2194607,0xfd64001e,0x20d43110,0x26cc058a}},	//   tfær, _thuầ, _näit_, _hogo_, 
   {{0x26cd5a7b,0x6f6006ed,0xdce400df,0x00000000}},	//   _kogo_, иврз, griĝ, --, 
   {{0xf77004ac,0x26cc0cfc,0xb2187246,0xdce40427}},	//   יקל_, _jogo_, rfær, rsič, 
   {{0xb2187a1e,0xca380115,0x93240150,0xed40004e}},	// [233c0] lgæn, _kaŝu_, _حرون, интп, 
   {{0x26cc0334,0xb218008c,0x3178008d,0x8114c842}},	//   _logo_, pfær, _קרימ, _جذبا, 
   {{0x6ee000af,0x3b841cd1,0x778800ac,0x26cc0067}},	//   _sõbe, тлег, _təxi, _oogo_, 
   {{0x26cc09a8,0x3f98014f,0x1754013e,0x00000000}},	//   _nogo_, _ippu_, қвия, --, 
   {{0x6ef80724,0xcee80014,0x6120005b,0xee34074d}},	//   säbä, _سرَن_, yöll, рнă_, 
   {{0x26cc0270,0x3f98020b,0x39455a7c,0x692073b3}},	//   _aogo_, _kppu_, rqos_, амча, 
   {{0x26cd5a7d,0xa3c0031d,0x61200008,0xa3e0033f}},	//   _bogo_, yšší_, völl, पैम_, 
   {{0x20d55a7e,0x26cc16b8,0x2240003e,0xe3c400cc}},	//   _zäit_, _cogo_, _ngik_, শনাব, 
   {{0x26cd5a7f,0x6120023a,0xf8640c60,0x20d401f4}},	//   _dogo_, töll, _авзо, _jäis_, 
   {{0x224001b8,0x1cc0025c,0x20d401c7,0x00000000}},	//   _agik_, _ཀོས_, _mäis_, --, 
   {{0x26cd5a80,0x20d40036,0x61204268,0x53340117}},	//   _fogo_, _läis_, röll, леот, 
   {{0x6120023a,0xdce40115,0x7d1c02d0,0x00000000}},	//   söll, vriĝ, hlps, --, 
   {{0x96640139,0x20d40037,0x7228030d,0xe73400d8}},	//   _акҗе, _näis_, ьцов_, _рец_, 
   {{0x26cc01f7,0x2240b27b,0xdce400df,0x612001d3}},	//   _zogo_, _egik_, triĝ, lölj, 
   {{0xd8380029,0x60183580,0xf2e40139,0x3250010a}},	//   _taču_, воря_, _аюпо, _кейӳ, 
   {{0x20d404d1,0x26cc172e,0x22840354,0x61200108}},	//   _säit_, _xogo_, _куьг, nölj, 
   {{0x1df8d9ee,0x9f34005e,0x3f9801f4,0xdbdc02d2}},	// [233d0] веты_, реті, _eppu_, _sáðm, 
   {{0xdd9430cb,0x6120007c,0x00000000,0x00000000}},	//   рафы, hölj, --, --, 
   {{0x644c033f,0xca740209,0x6120007c,0xd83800de}},	//   ścig, гулы, kölj, _mačs_, 
   {{0x20d40a40,0x7d1c04cc,0xee3c00a2,0x00000000}},	//   _wäit_, alps, _maýk_, --, 
   {{0x26cd5a81,0xb74402dd,0x20d426bb,0x1d480064}},	//   _rogo_, қпыз_, _täit_, _аясп_, 
   {{0x26cd5a82,0x67d0013a,0x6ed800bc,0xa3e0012d}},	//   _sogo_, _nějá, नसकु, पैड_, 
   {{0x26cd5a83,0x612001e6,0xc7940209,0x58840a89}},	//   _pogo_, följ, урлы, рыча, 
   {{0x05a802bf,0x1cc00327,0x80d8000d,0x00000000}},	//   евий_, _ཀོོ_, _नकभे, --, 
   {{0xeb1c0490,0x0444aa52,0xaf740023,0x00000000}},	//   बतीत_, лепн, _ክልቴና_, --, 
   {{0x2c6c0139,0x00000000,0x00000000,0x00000000}},	//   _uñdı_, --, --, --, 
   {{0xdce4005f,0xc8640139,0x6120007c,0x80d8000d}},	//   nsiā, _атҗи, bölj, _नकबे, 
   {{0x73e15a84,0xb21800b5,0x02dc08df,0x00000000}},	//   союз, rgæn, मसेन, --, 
   {{0x57240058,0x77003df7,0xb21801bf,0x9644009d}},	//   _ئىنك, _دژون, sgæn, _тэхд, 
   {{0x657800ec,0x20d400fd,0xf1c801a8,0x00000000}},	//   mruh, _räis_, _spáð_, --, 
   {{0x44215a85,0xafe072a0,0x00000000,0x00000000}},	//   _áh_, борл, --, --, 
   {{0x93240075,0xfca81fb8,0x20d40254,0x65781210}},	//   _پرىن, کارو_, _päis_, oruh, 
   {{0xb21804ce,0x51840261,0x6d58013d,0x65781f96}},	// [233e0] ngæl, _куќа, _çual, nruh, 
   {{0x3f98020b,0x6578009f,0xe6055a86,0x451003d4}},	//   _tppu_, iruh, _ۇش_, _হওঁক_, 
   {{0x78ac06ed,0x28c48004,0x20d40036,0x65791eff}},	//   _óbvi, लानि, _wäis_, hruh, 
   {{0x65795a87,0x20d400af,0xb414008f,0xdce40205}},	//   kruh, _täis_, אקעס_, briğ, 
   {{0x612001e3,0x1c14000d,0x403401af,0x00000000}},	//   jölk, _तुरल_, _шеүс, --, 
   {{0x37a86f0c,0x7e64017a,0x65795a88,0x7b640014}},	//   етин_, _hekp, druh, _مارٕ, 
   {{0x61200267,0xda2001ad,0x657800e4,0xd8380171}},	//   tölj, _बरकत_, eruh, _račs_, 
   {{0x5574466a,0x65780112,0x00000000,0x00000000}},	//   агит, fruh, --, --, 
   {{0x65780004,0x612000e5,0x00000000,0x00000000}},	//   gruh, rölj, --, --, 
   {{0x7e655a89,0x778800ac,0xa85000c7,0xc7640050}},	//   _lekp, _bəxt, _лҵшә, _چانى, 
   {{0x7e640175,0x65795a8a,0xc764113e,0x00000000}},	//   _oekp, aruh, _نانى, --, 
   {{0x65780219,0x7e64257c,0xf2c40107,0x612001d3}},	//   bruh, _nekp, усон, lölh, 
   {{0x76400223,0xb4b00116,0xa2f40006,0x00000000}},	//   _igoy, _гилә, спяч, --, 
   {{0x28c4045b,0x67280200,0xdce40205,0x00000000}},	//   लायि, _zhgj, vriğ, --, 
   {{0xa3b4c578,0x7e642a89,0x2518010f,0x3cf82314}},	//   _ماير_, _bekp, _רווא, ोचने_, 
   {{0xdce40cf4,0x91b801af,0x79800210,0x00000000}},	//   driđ, _агит_, kuow, --, 
   {{0x644c068f,0x60d00086,0x5c7401c6,0x8cf456f3}},	// [233f0] ście, ñimò, өлтт, азац, 
   {{0x7e6403ac,0xbb4401ec,0xdef800fb,0xdce4031c}},	//   _eekp, _ﺄﺘﻲ_, _ҡыя_, ttiġ, 
   {{0xdd940046,0x778800ac,0xe2c8004b,0x76400009}},	//   _қары, _məxs, _شویو_, _ogoy, 
   {{0xc9541ee1,0xeff40023,0xdce4031c,0x28c40303}},	//   аткы, _ቈልዓ_, rtiġ, लाभि, 
   {{0xaca0063f,0x6578022e,0xdce40135,0x00000000}},	//   _agục, xruh, stiġ, --, 
   {{0x02e0023e,0x76401556,0x61215a8b,0xfcc15a8c}},	//   _पत्न, _agoy, völk, _мәхм, 
   {{0x612017da,0x65780214,0x7e640205,0x00000000}},	//   wölk, wruh, _yekp, --, 
   {{0xe4e44709,0x61200108,0x00000000,0x00000000}},	//   _ओतहि_, tölk, --, --, 
   {{0x89395a8d,0x00000000,0x00000000,0x00000000}},	//   _апас_, --, --, --, 
   {{0x764002e2,0xe9fc01fb,0xb218005c,0x612000e5}},	//   _egoy, _ngẩn_, rgæl, rölk, 
   {{0x02c44705,0x65789e02,0x46c40b4c,0x98c401a9}},	//   айно, sruh, वादह, _устл, 
   {{0xd7f80372,0x6578f4d5,0xc5940063,0x00000000}},	//   _суу_, pruh, _видј, --, 
   {{0xd1755a8e,0x6d4800df,0xfd640055,0x00000000}},	//   йыры, ŭgaj, bhuṣ, --, 
   {{0x41285aa6,0x778806be,0x63500051,0xfd640055}},	//   того_, _təxt, _năng, chuṣ, 
   {{0x64415a8f,0x7e655a90,0x200d17cf,0x26dc0134}},	//   _igni, _pekp, çdi_, okuo_, 
   {{0x28c40f44,0x200c025c,0x9ce800e5,0x00000000}},	//   लाडि, ħdi_, گوئے_, --, 
  
   {{0x3c655a91,0x7330075e,0xfd9401e0,0xcdc40150}},	// [23400] икаг, _بىيا, шөнә_, батқ, 
   {{0xb2f0031c,0x778803e3,0x612001f4,0xece401a9}},	//   _བཏོང_, _məxr, köli, адул_, 
   {{0x7e655a92,0x30780302,0xfb880e8e,0x90e401e2}},	//   _tekp, _באינ, тбек_, _دسين, 
   {{0xe56431ed,0x61200793,0xeab4b42d,0x79800210}},	//   _وط_, döli, ийх_, tuow, 
   {{0x64415a93,0x999802f2,0x3eb000c0,0x00000000}},	//   _ogni, اپتر_, mdyt_, --, 
   {{0xfce55a94,0x3eb000c0,0x00000000,0x00000000}},	//   _того, ldyt_, --, --, 
   {{0xe3a54e44,0xf6e423d3,0x96f87863,0x612055e1}},	//   _بر_, ицин, лект_, göli, 
   {{0x64415a95,0xe72d5a96,0x3eb00153,0x39e001ee}},	//   _agni, وصي_, ndyt_, _мәлғ, 
   {{0x87340150,0x394800f3,0x00000000,0x00000000}},	//   _ﺷﯟﻻﭖ_, _рззо_, --, --, 
   {{0x612001b8,0x3eb0023a,0x91ac0208,0x00000000}},	//   böli, hdyt_, _đòi_, --, 
   {{0x6828069d,0x00000000,0x00000000,0x00000000}},	//   _ዲፓርት, --, --, --, 
   {{0x32655a97,0x3b040194,0x778800ac,0x64415a98}},	//   штов, nnoq_, _fəxr, _egni, 
   {{0xf8d805f9,0x00000000,0x00000000,0x00000000}},	//   _बकाय, --, --, --, 
   {{0x57240075,0x64a15a99,0xa158014b,0x00000000}},	//   _ئىچك, _мача, рару_, --, 
   {{0x53355a9a,0x644c068f,0xb36400a7,0x94a802dd}},	//   _лект, ścic, _тълк, _атқа_, 
   {{0x6438011a,0x7ae804e6,0x64415a9b,0x3eb00064}},	//   _בעונ, ëftl, _zgni, gdyt_, 
   {{0xd1cc02d3,0x6c680063,0xec680798,0x00000000}},	// [23410] _ኣልቦ_, вшег_, врек_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa1340fb4,0xddc4033f,0xab841d0b,0x3eb00064}},	//   _بريش, eciń, рузк, bdyt_, 
   {{0xaee001ec,0x10a40139,0xab7c0092,0x00000000}},	//   _بۋرى, _тиүн, _ያግዛል_, --, 
   {{0x7ae8004b,0x46c46236,0x00000000,0x00000000}},	//   دونې_, वासह, --, --, 
   {{0x61205f95,0x1cc0025c,0x63500356,0x28c4687b}},	//   töli, _ཀོག_, _hăne, लाधि, 
   {{0x9be400d4,0x00000000,0x00000000,0x00000000}},	//   _дітк, --, --, --, 
   {{0xfc4800c6,0xf1a407f7,0xdce40327,0x5a4400c0}},	//   _tríú_, गबान, ttiħ, _дэфа, 
   {{0xfaa4313e,0x28c4146b,0x6350054e,0x497400fb}},	//   _دۇني_, लादि, _măne, _ылас, 
   {{0xb2f00003,0xdb24031c,0x59c40150,0x74e401c6}},	//   _བཏུང_, _འཚོཌ_, _بيكك, йдыг_, 
   {{0xc2c400c6,0x7d000098,0xc7640228,0x03a40815}},	//   ميدي, éosi, _چاچى, щино, 
   {{0x47350714,0x03a41621,0x77880213,0xd7c80133}},	//   _унес, _ҳико, _təxr, _خومه_, 
   {{0x29055a9c,0x644004cc,0x69c8009a,0x6350054e}},	//   onna_, _tgni, nxge, _sănd, 
   {{0x64400006,0x6680036b,0x03a400d8,0x46c400cd}},	//   _ugni, _ایکل, _гико, वावह, 
   {{0x29055a9d,0x63500311,0x93a8007b,0x3b0401b9}},	//   inna_, _băne, _نايف_, ynoq_, 
   {{0x1cc0081f,0xe9fc0016,0x2904003e,0x656c0113}},	//   _ཀོང_, _ngắn_, hnna_, šchu, 
   {{0x81e002a6,0xe2980220,0xed555a9e,0xef14014b}},	// [23420] _দশক_, _бақ_, йот_, ёму_, 
   {{0xbc695a9f,0xee355aa0,0xad980077,0x0084004e}},	//   امان_, сну_, _axús, _улоо, 
   {{0x8b655aa1,0x29040009,0x00000000,0x00000000}},	//   قانم, dnna_, --, --, 
   {{0x29055aa2,0xb9e80209,0x00000000,0x00000000}},	//   enna_, лмез_, --, --, 
   {{0x2904022f,0xdce40034,0x58d417cd,0x3b0401a9}},	//   fnna_, esią, жолт, rnoq_, 
   {{0x7c392718,0x4c8000d1,0xa3c400bc,0xfb68007b}},	//   _útro, _оғуз, ईमा_, _مصرى_, 
   {{0xace55aa3,0x69cc00d8,0xd8380010,0xddd0012d}},	//   _умра_, _àcen, _obče_, żeńs, 
   {{0x290406d5,0x973c1f7f,0xda7001f7,0x00000000}},	//   anna_, _opće, _آڏا_, --, 
   {{0x1dc800dc,0x7bdd5aa4,0xb21801bf,0xb894011c}},	//   रमित, lypu, rgæk, _греъ, 
   {{0xe9d40598,0x92c400bd,0x7ae15aa5,0x6d480332}},	//   _уку_, _এতে_, lkot, ígai, 
   {{0x53350f98,0x7ae001f7,0xee3c010e,0x7bdc03cd}},	//   жент, okot, _haýt_, nypu, 
   {{0x1dc839c5,0xa8b801e1,0x00000000,0x00000000}},	//   रमात, _òrò̟_, --, --, 
   {{0x656c0597,0x644c068f,0xddc400e2,0x3990003a}},	//   ácht, ścia, lciņ, nâs_, 
   {{0x1cc00dd4,0xb4b0053f,0x1c0800af,0x7bdd5aa6}},	//   _ཀོཊ_, _хикә, वपाल_, kypu, 
   {{0x7ae15aa7,0x92580139,0x7bdc0108,0x92940153}},	//   kkot, _кайт_, jypu, _дайц, 
   {{0xb2f00135,0x612002d2,0x00000000,0x00000000}},	//   _བཏིང_, dölu, --, --, 
   {{0x29055aa8,0x7ae00165,0xb1900139,0x00000000}},	// [23430] ynna_, dkot, _элпә, --, 
   {{0x7ae15aa9,0xfcc00166,0x00000000,0x00000000}},	//   ekot, мәсм, --, --, 
   {{0x28c41a22,0x61200008,0x7ae00158,0x32d8002e}},	//   लासि, tölv, fkot, _wëyu_, 
   {{0xee3c00a2,0x7ae00e02,0xeea82678,0x37ac0154}},	//   _baýt_, gkot, _сток_, কমার, 
   {{0x290401af,0xef1c0022,0xddc40171,0x00000000}},	//   tnna_, _ikü_, eciņ, --, 
   {{0x29043386,0x92c4015b,0x7ae15aaa,0x00000000}},	//   unna_, _এতো_, akot, --, 
   {{0x60dc008d,0xddc40006,0x7bdc0076,0x38c80133}},	//   רקונ, maiš, cypu, شاوی_, 
   {{0x612001ed,0x7ae0007c,0xddc42672,0x6b800de2}},	//   lölt, ckot, laiš, àngu, 
   {{0xee3c010e,0xa87826c6,0x00000000,0x00000000}},	//   _gaýt_, _محضر_, --, --, 
   {{0xe784201d,0x0395274c,0x7bc80b1a,0x2a6c0076}},	//   _гудо, ормя, åfug, lagb_, 
   {{0xef1c006a,0xd5e81291,0x00000000,0x00000000}},	//   _okü_, لعین_, --, --, 
   {{0xdb1c0231,0x28c407b7,0x00000000,0x00000000}},	//   _arrê, लावि, --, --, 
   {{0x66240228,0x63500276,0x612001ed,0xc0d00092}},	//   _اراك, _bănc, költ, _ከምር_, 
   {{0x7ae0d71a,0x2a6c507c,0xef1c0790,0xe9fc0051}},	//   zkot, hagb_, _akü_, _ngận_, 
   {{0x48e04c21,0x8ccc0034,0x63500356,0x3f686c00}},	//   _कवनो_, सानो, _dănc, рибо_, 
   {{0x7ae0005a,0xa3e000cd,0x42547b8f,0x00000000}},	//   xkot, पैः_, _بنظر, --, 
   {{0x23640097,0xef140d30,0x02a407f7,0xcdc401ec}},	// [23440] _hwnj_, іму_, गजीन, патқ, 
   {{0x6120632c,0x7bdd5aab,0xddc40024,0xacc400db}},	//   tölu, typu, gaiš, огуз_, 
   {{0xb098011a,0xee3c010b,0x00000000,0x00000000}},	//   _דייר, _saýt_, --, --, 
   {{0xba255aac,0x23640369,0xdce40552,0x7bdc00b5}},	//   одек, _mwnj_, ksić, rypu, 
   {{0x69cc06af,0x612001a8,0x7bdc0937,0x0c7400db}},	//   _àcel, sölu, sypu, زدەد, 
   {{0xad640fc0,0x3cfc03e0,0xfb8800ec,0x39900356}},	//   _фарз_, _ötv_, _پئسو_, râs_, 
   {{0x386c0109,0xec740108,0x00000000,0x00000000}},	//   rafr_, _фпс_, --, --, 
   {{0x7c2d5aad,0x1cc00489,0xe9d55aae,0xddc400e2}},	//   _izbr, _ཀོཌ_, скә_, rciņ, 
   {{0xf77016d5,0x6d4801e4,0x00000000,0x00000000}},	//   ساں_, ŭgav, --, --, 
   {{0x644c7e2a,0x79809774,0x49e00150,0x62800162}},	//   ścin, mrow, _سۋىق, ómon, 
   {{0x28c40b7d,0x18280214,0xa5d400e5,0x00000000}},	//   लारि, _اقای_, مبیر_, --, 
   {{0x79815aaf,0x7c2c020b,0xfc44012c,0x612001ed}},	//   orow, _mzbr, šího_, zölt, 
   {{0xc6495ab0,0x79802b4b,0x93c80014,0xdb1c036e}},	//   _اجمل_, nrow, _گاشہ_, _arrë, 
   {{0x3dc003d4,0x7c2c02fb,0x691c0af9,0x99d800cc}},	//   োনাল, _ozbr, lêer, _দেৱক, 
   {{0xddc40153,0x63500356,0x798015c0,0xbf1401f9}},	//   vaiš, _vănc, hrow, ढवून_, 
   {{0x79815ab1,0x1cc00327,0x14e00073,0xf1a401f4}},	//   krow, _ཀོཔ_, _पकडण, _дрон, 
   {{0x61215ab2,0xdd955ab3,0x23640198,0xdb1cb608}},	// [23450] tölt, маты, _zwnj_, _errë, 
   {{0x79815ab4,0x6d980023,0x00000000,0x00000000}},	//   drow, _ህይወታ_, --, --, 
   {{0xddc40006,0x79815ab5,0xe27400f7,0xcb080451}},	//   raiš, erow, _экөө, ٽيشن_, 
   {{0x79800034,0xaca40050,0x61215ab6,0x00000000}},	//   frow, _ژھاے_, sölt, --, 
   {{0x7c2c0165,0xf1c828b8,0x79815ab7,0x2a6c01ab}},	//   _ezbr, ामिन, grow, ragb_, 
   {{0x9f5c00e4,0xdce4012d,0x00000000,0x00000000}},	//   _ãvã_, księ, --, --, 
   {{0x87b95ab8,0x79815ab9,0x9938030d,0xb784013d}},	//   султ_, arow, _зiок_, зәче_, 
   {{0xf1c807b6,0xdce4068f,0x79801605,0x6d5c02d0}},	//   ामान, dsię, brow, opqa, 
   {{0xe818bddc,0x23640369,0x64440010,0xdce4033f}},	//   _पुरा_, _swnj_, žjim, esię, 
   {{0x1cc00003,0xdb1c068c,0x00980150,0x00000000}},	//   _ཀོབ_, _arrè, _ﺘﻤﺎﻤ_, --, 
   {{0x644c068f,0x823400f1,0x00000000,0x00000000}},	//   ścio, ګردا, --, --, 
   {{0x47355aba,0xe0a800cc,0x00000000,0x00000000}},	//   _энес, _ওচেন, --, --, 
   {{0x25a8004b,0x339003c7,0x00000000,0x00000000}},	//   _خداي_, ولیز, --, --, 
   {{0xb4b4008e,0x43080ce8,0x00000000,0x00000000}},	//   _ничә, рхүм_, --, --, 
   {{0x8268011c,0x00000000,0x00000000,0x00000000}},	//   _лайв_, --, --, --, 
   {{0x3e5c00b0,0x09e000fe,0x00000000,0x00000000}},	//   kātō_, _মইনা, --, --, 
   {{0xada15abb,0x1cc0031c,0x7d000241,0x00000000}},	// [23460] натл, _ཀོད_, _nírè, --, 
   {{0x6d20026a,0xdb1d5abc,0xdee401d5,0x00000000}},	//   едуз, _irré, чоғи, --, 
   {{0x7ac40801,0x79815abd,0x00000000,0x00000000}},	//   зсле, wrow, --, --, 
   {{0x3f882819,0x79800034,0xb21800b5,0xec102651}},	//   mubu_, trow, rgæv, روند, 
   {{0x3f895abe,0x79800210,0x00000000,0x00000000}},	//   lubu_, urow, --, --, 
   {{0x79815abf,0xd88801d9,0xb76430c7,0xb3400003}},	//   rrow, تھرن_, птий, ħħij, 
   {{0x7c2d5ac0,0x6cc00209,0xee3c0432,0xd1cc0240}},	//   _uzbr, _яйра, _haýp_, _ኣውት_, 
   {{0x7980068f,0x7d1d5ac1,0x6b80003a,0x644c0950}},	//   prow, lops, ánge, ścil, 
   {{0x3f880810,0xe9d40006,0x00000000,0x00000000}},	//   hubu_, _ект_, --, --, 
   {{0x3f895ac2,0x93795ac3,0x63500356,0xa7440150}},	//   kubu_, обот_, _săna, _ﻗﯟﺍﯓ_, 
   {{0xdb1d5ac4,0x1cc0025c,0x3f880086,0x20d40139}},	//   _arré, _ཀོན_, jubu_, _fäiz_, 
   {{0x7d1c03ac,0x3f881418,0xdce400c0,0x00000000}},	//   hops, dubu_, priė, --, 
   {{0x37ac00bd,0xe29802d5,0xe3ac0133,0x00000000}},	//   _কপির, чаў_, نرێ_, --, 
   {{0xa6380302,0x234404fb,0x7cf00b1a,0x7d1c01fa}},	//   _הגדר, _کليپ_, _hærf, jops, 
   {{0x7d1d5ac5,0x3f880161,0xdb1c01c7,0x37dc015b}},	//   dops, gubu_, _erré, _ভেতর, 
   {{0x1dc80073,0xdfd0009f,0x00000000,0x00000000}},	//   रमंत, ديِ_, --, --, 
   {{0x7d1c017a,0x6ca43da1,0x3f9c0790,0x9e1401ec}},	// [23470] fops, зреж, çtur_, едті, 
   {{0x3f895ac6,0x61f40598,0x7d1c0d47,0xe9fc004d}},	//   bubu_, şelä, gops, _ngạn_, 
   {{0x3f8801f0,0x9be40006,0x00000000,0x00000000}},	//   cubu_, ніцк, --, --, 
   {{0x7cf0032e,0x61200112,0x27140051,0x00000000}},	//   _nærf, lölp, măng_, --, 
   {{0x6f1c036b,0x7d1c005c,0x27140051,0x00000000}},	//   moqc, bops, lăng_, --, 
   {{0x6d7c0201,0x6d4c0077,0x5f740ec9,0xdd5873c3}},	//   _እርዳታ_, _iuca, _تایر, _харч_, 
   {{0x6d455ac7,0x7cf00158,0x6d4c003e,0x27140208}},	//   _iija, _bærf, _huca, năng_, 
   {{0x6d4c3917,0x857806ed,0x98ac00ef,0x27300022}},	//   _kuca, осот_, _bidē_, kãne_, 
   {{0x6d4c00a8,0x6d455ac8,0x644c00dc,0x3f881556}},	//   _juca, _kija, ścim, zubu_, 
   {{0x6d4d5ac9,0x6d440978,0x3f8800ca,0xda08009f}},	//   _muca, _jija, yubu_, _عيله_, 
   {{0x6d4d5aca,0x6d455acb,0xd90d5acc,0xb6000162}},	//   _luca, _mija, _دیو_, áári, 
   {{0x6d455acd,0xc0c802d3,0x3f895ace,0x00000000}},	//   _lija, _ሽበራ_, vubu_, --, 
   {{0x6d44090c,0x6f1c022e,0x67380254,0x7d1d3ba0}},	//   _oija, doqc, mmuj, yops, 
   {{0x3f895acf,0x6d455ad0,0x6568014f,0x4e2000c5}},	//   tubu_, _nija, _iwgh, _मड़ई_, 
   {{0x6d4d5ad1,0x7cf000b5,0x6f1c01b9,0x7d1c054e}},	//   _auca, _hærg, foqc, vops, 
   {{0x6d4d5ad2,0x6d455ad3,0x7d1c0bd7,0x7c380b21}},	//   _buca, _aija, wops, _útri, 
   {{0x6d455ad4,0x3f895ad5,0x7c940828,0x6aa95ad6}},	// [23480] _bija, subu_, дрец, degf, 
   {{0x6e280639,0x6d455ad7,0x80a400f1,0xac80010b}},	//   ügba, _cija, _ځمکن, кгул, 
   {{0x7d1c801c,0xeb9433b6,0x3f895ad8,0x6f1c0455}},	//   rops, дих_, qubu_, boqc, 
   {{0x6738068f,0x7d1d5ad9,0x6d4d5ada,0x6fd8012c}},	//   jmuj, sops, _fuca, नहरू, 
   {{0x6d455adb,0x6d4c01b2,0xd91003e6,0xb2182b96}},	//   _fija, _guca, هیر_, lgær, 
   {{0x644c2144,0x7cf0143a,0x6d4451bc,0xc8700ca8}},	//   ścij, _særf, _gija, _wo̟n_, 
   {{0xb8d49a28,0x628802d5,0x6d4d5adc,0xb218005c}},	//   _जस_, ėdoj, _zuca, ngær, 
   {{0x6d455add,0xd6d00491,0x6d4d5ade,0xe8dc001e}},	//   _zija, اقة_, _yuca, _muộn_, 
   {{0x6d4c0598,0x7cf008cb,0x6d440978,0xf484005b}},	//   _xuca, _værf, _yija, мунн, 
   {{0x6d455adf,0xaee00241,0x98ac00e2,0x6738058a}},	//   _xija, _koṣe, _vidē_, amuj, 
   {{0x92955ae0,0x6f1c544b,0xf7440120,0x00000000}},	//   нанц, yoqc, _жежо, --, 
   {{0x7cf000b5,0xb21801bf,0x6ee0000d,0xf2c407a5}},	//   _færg, dgær, _tõbi, фсон, 
   {{0x7cf00162,0x71340116,0x6f1c014f,0x77780051}},	//   _kærd, мҗит_, voqc, _hvtx, 
   {{0x7cf00158,0x09e0009e,0xe3ac00ec,0x27140051}},	//   _jærd, _মেডা, _چري_, tăng_, 
   {{0x6d4d5ae1,0xe8dc01fb,0x5f940137,0xe3ad5ae2}},	//   _suca, _cuộn_, кирт, _نري_, 
   {{0x6d455ae3,0x6d4c0bb8,0x7cf0778a,0x9f3400fa}},	//   _sija, _puca, _lærd, весі, 
   {{0x6d4c0213,0x6aa80158,0xdbdc0332,0x6f1c01d5}},	// [23490] _quca, vegf, _dáím, roqc, 
   {{0x6d4c2b1d,0xaee00248,0x973c3c52,0xb14403e6}},	//   _vuca, _boṣe, _općo, _زیزم_, 
   {{0x6d455ae4,0x67380034,0x6d4c0066,0x7778010a}},	//   _vija, ymuj, _wuca, _nvtx, 
   {{0x6d4c23e0,0x6d455ae5,0x5ba407d6,0xf1bc02fb}},	//   _tuca, _wija, ъруз, ová_, 
   {{0x6d455ae6,0xe9a846c6,0x6d4c003e,0x7cf003cd}},	//   _tija, تدان_, _uuca, _bærd, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdce400df,0x07a4009d,0x00000000,0x00000000}},	//   nsiĝ, хайн, --, --, 
   {{0xe9fc01fb,0x69a800ec,0x00000000,0x00000000}},	//   _ngần_, _واءُ_, --, --, 
   {{0x7cf0019b,0x2d980998,0x67382a5c,0x0608bafa}},	//   _færd, ntqe_, rmuj, яник_, 
   {{0x67b8489b,0x7c200311,0xdce4010f,0x7cf15ae7}},	//   _واضح_, şore, ksiĝ, _værg, 
   {{0x5ec0015b,0xf8ac0532,0xca7c0092,0x74e4009d}},	//   _একসে, _دکن_, _ከምንም_, хдэг_, 
   {{0x2a7c031c,0x15b000db,0x00000000,0x00000000}},	//   _jdub_, _چەيس, --, --, 
   {{0x7cf01347,0x09b4010f,0x00000000,0x00000000}},	//   _hære, עפֿט_, --, --, 
   {{0x7cf004ce,0x25bc009a,0xc8700241,0x00000000}},	//   _kære, mvul_, _je̟_, --, 
   {{0x6ee000af,0x7cf0168c,0xbea43d2a,0x34900798}},	//   _lõbu, _jære, навк, _сајр, 
   {{0xfe4400c7,0xb21800b5,0x8c240154,0xaee000b8}},	//   енбо, rgær, বধান_, _roṣe, 
   {{0x7cf02759,0x25bc0af9,0x6f0c013a,0x20040210}},	// [234a0] _lære, nvul_, _šicí, ńmi_, 
   {{0x7d24350a,0xb198008f,0xd378013d,0xed54011c}},	//   رفان, _צייכ, _эчә_, хоф_, 
   {{0x7cf008cb,0xa2a000bc,0x00000000,0x00000000}},	//   _nære, ग्थ्, --, --, 
   {{0x0cbc02a6,0x7cf008cb,0x6b815ae8,0x3f980477}},	//   _আকৃত, _særd, ánga, _iqpu_, 
   {{0x7e740986,0xed540818,0xf1c01414,0x00000000}},	//   mayp, _поя_, शियन, --, 
   {{0x7e748408,0x7cf00627,0xdb1c0022,0xbd340150}},	//   layp, _bære, _irrí, _سىزع, 
   {{0x7cf15ae9,0xf0900375,0x7ae804e6,0x2a7c01ef}},	//   _værd, אנו_, ëfts, _fdub_, 
   {{0x7e7403f0,0xfd4c00dc,0x75880108,0x00000000}},	//   nayp, _suhṛ, псов_, --, 
   {{0xd25004fb,0x3b040140,0x8aa4022e,0x953801f4}},	//   یند_, mioq_, _шрёд, мзит_, 
   {{0xd6d08bee,0x7cf00008,0x7e7402d1,0x387c01bf}},	//   اقک_, _fære, hayp, _udtr_, 
   {{0x78b80a73,0x7e7402d1,0x7cf0072b,0xa5900131}},	//   _iatv, kayp, _gære, نگۈچ, 
   {{0x78b95aea,0xf1bc0313,0x7cf02d8b,0x7e740784}},	//   _hatv, tvá_, _jærb, jayp, 
   {{0x250801ed,0xdbdc0241,0xf1bc0118,0xc8700241}},	//   _کرنی_, _láàm, uvá_, _ye̟_, 
   {{0x78b8014f,0xf1bc00d8,0xc0c80092,0x5e580014}},	//   _jatv, rvá_, ጠቀሱ_, ہلِس_, 
   {{0x78b81d1d,0xdb1c067c,0x00000000,0x00000000}},	//   _matv, _arrí, --, --, 
   {{0x78b926e8,0x7cf0383d,0x7e740309,0xdce400df}},	//   _latv, _nærb, gayp, rsiĝ, 
   {{0x779402d3,0xe29800d8,0x00000000,0x00000000}},	// [234b0] _ዘይብላ_, _чањ_, --, --, 
   {{0x78b95aeb,0xfd4c063f,0xdef800fd,0xdcb800cf}},	//   _natv, lekọ, _җыю_, нгуч_, 
   {{0x7cf04e9b,0x4ab80408,0x27300165,0x00000000}},	//   _bærb, дуля_, hãna_, --, 
   {{0xdb1c002d,0x99815aec,0x3f780375,0x3a700131}},	//   _arrâ, çiş_, _קארס, қләр, 
   {{0x7cf02d75,0x00000000,0x00000000,0x00000000}},	//   _sære, --, --, --, 
   {{0x78b80882,0x7cf02188,0xe9fc0208,0x25bc022e}},	//   _catv, _pære, _ngấn_, vvul_, 
   {{0x78b95aed,0xd8b8007b,0x00000000,0x00000000}},	//   _datv, عدها_, --, --, 
   {{0x7cf15aee,0x2a7c0050,0xdb1c003a,0x668001b9}},	//   _være, _udub_, _errâ, ایشل, 
   {{0x78b81cf2,0x46580b82,0x59f80395,0x00000000}},	//   _fatv, _ጂኦግራ, _зетя_, --, 
   {{0x6ab95aef,0x78b928b5,0x25bc05e4,0x7cf021e3}},	//   _hauf, _gatv, rvul_, _tære, 
   {{0x6ab95af0,0x7cf0005c,0x7e7403f0,0x47d401c8}},	//   _kauf, _hærc, yayp, _جيار, 
   {{0x29055af1,0x6ab80ba1,0x63c00032,0x98ac00c0}},	//   lina_, _jauf, _ҡалҡ, _bidė_, 
   {{0x290404c9,0x27e41368,0x6ab95af2,0x7e7400e4}},	//   oina_, lynn_, _mauf, vayp, 
   {{0x29055af3,0x6ab95af4,0x23c00014,0x65795af5}},	//   nina_, _lauf, _مٕتہ, msuh, 
   {{0x29041140,0x65795af6,0x9b940150,0x3b040113}},	//   iina_, lsuh, _ءﻭﺗﻜ, yioq_, 
   {{0xfb8004fb,0xfbd14db6,0x00000000,0x00000000}},	//   یگزی, یتا_, --, --, 
   {{0x29055af7,0x65795af8,0xe2980220,0x3b040194}},	// [234c0] kina_, nsuh, _жақ_, vioq_, 
   {{0x7e75428c,0xee3409f7,0xada15af9,0x7cf012ed}},	//   sayp, тну_, рафл, _særb, 
   {{0x644c068f,0x6ab80ade,0x7e755afa,0x657800d8}},	//   ściw, _bauf, payp, hsuh, 
   {{0x78b8198e,0x29055afb,0x6ab95afc,0x65795afd}},	//   _satv, eina_, _cauf, ksuh, 
   {{0x78b95afe,0x6ab95aff,0x7cf00fac,0x569402dd}},	//   _patv, _dauf, _værb, қапт, 
   {{0x3b040194,0xdbdc0241,0xfca800f1,0xae34014b}},	//   sioq_, _táàm, _کاڼو_, _рӯст_, 
   {{0x6ab9266c,0x28c41a22,0x27e41445,0x78b801f4}},	//   _fauf, लाजि, gynn_, _vatv, 
   {{0x6ab85bae,0x29055b00,0xdb080724,0xfaa4013e}},	//   _gauf, aina_, ülär, _шабо, 
   {{0x39455b01,0x29055b02,0x78b95b03,0xaa4006d2}},	//   _анаг, bina_, _tatv, _ветл, 
   {{0xe60c0220,0xfd4c0521,0x6ab95b04,0xa964011c}},	//   تشى_, wekọ, _zauf, _рифа_, 
   {{0xd250169d,0x65780022,0xa53000ee,0x77900244}},	//   ینگ_, asuh, рнэч, _ئیبا, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x273004a9,0x69cc004a,0xba880150,0x00000000}},	//   _ئىنس, _àcet, _ﻗﺩﻤﻙ_, --, 
   {{0x0cbc0154,0x27140356,0xe8040073,0xe3ac1a4b}},	//   _আক্ত, măna_, _वेडा_, حری_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x200c01f1,0xceb80022,0xb284010a,0x00000000}},	//   údia_, хәо_, _рыкк, --, 
   {{0x29055b05,0x6ab8f985,0x00000000,0x00000000}},	// [234d0] yina_, _rauf, --, --, 
   {{0x290436ed,0x6ab95b06,0xdb1c067c,0x2fc400e4}},	//   xina_, _sauf, _arrà, _ángo_, 
   {{0x99d404fb,0x65780369,0x8c88013d,0x00000000}},	//   یتها, zsuh, _җәза_, --, 
   {{0x29055b07,0x6578005b,0x0a3800ee,0xeda401f0}},	//   wina_, ysuh, нчлы_, _ишго, 
   {{0xf0840023,0xe8184970,0x7bd80cad,0x00000000}},	//   _ንምድሪ_, _पुजा_, _àtun, --, 
   {{0x98c40075,0xdb1c004e,0x290404c9,0x6ab8009f}},	//   لغىن, _errà, uina_, _wauf, 
   {{0x29055b08,0x6ab95b09,0x1bd48b11,0x09e000eb}},	//   rina_, _tauf, _коря, _মেশা, 
   {{0x657804ce,0x03a4013e,0x00000000,0x00000000}},	//   tsuh, қимо, --, --, 
   {{0x7cf005ac,0x09e0015b,0x00000000,0x00000000}},	//   _hæra, _মেরা, --, --, 
   {{0x29055b0a,0x04b40228,0x7cf009f3,0xdb1c00e4}},	//   qina_, усия, _kæra, _irrá, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6578000d,0x00000000,0x00000000,0x00000000}},	//   psuh, --, --, --, 
   {{0x26cd5b0b,0x7cf15b0c,0x69cc0077,0x24dc00cc}},	//   _ingo_, _læra, _áced, যোগহ, 
   {{0xf8a0012c,0x26cc006a,0xd5ac01ed,0x00000000}},	//   _роdо_, _hngo_, _کہی_, --, 
   {{0x7cf00183,0x03a40117,0x00000000,0x00000000}},	//   _næra, _сийо, --, --, 
   {{0x6ee0033d,0x3f880135,0xdb1c00e5,0x00000000}},	//   _sõbr, rrbu_, _orrá, --, 
   {{0xc624015b,0x27300022,0x644c012d,0x00000000}},	// [234e0] মেরা_, hãno_, ściu, --, 
   {{0x7cf00158,0x61200112,0xee3c010b,0x5c240014}},	//   _bæra, hölz, _jaýy_, ٔکرٲ, 
   {{0xa2d867b1,0xb09805e1,0x26cc08f5,0xac940075}},	//   याप्, _אייר, _ongo_, انما_, 
   {{0x8cc8012d,0x00000000,0x00000000,0x00000000}},	//   _होठो, --, --, --, 
   {{0x18745928,0xddc42672,0x63500356,0x6ee00254}},	//   агля, laiž, _dăni, _tõbr, 
   {{0x26cd5b0d,0x3eb00280,0x7cf001a8,0x00000000}},	//   _ango_, leyt_, _færa, --, 
   {{0x06cc00bd,0xdb1c04d4,0x7cf0032e,0x00000000}},	//   িউনি, _errá, _gæra, --, 
   {{0xe9d4723c,0x62855b0e,0x3eb15b0f,0x00000000}},	//   ткә_, _ndio, neyt_, --, 
   {{0xa2d818cc,0xee3c00a2,0xa80001e0,0x00000000}},	//   यान्, _baýy_, изәл, --, 
   {{0x62855b10,0x26cd5b11,0x225801e0,0x00000000}},	//   _adio, _engo_, ғиры_, --, 
   {{0x3eb00280,0xc624015b,0xee3c0432,0x69cc0129}},	//   keyt_, মেলা_, _daýy_, _àcer, 
   {{0x973c1727,0x62840165,0x6fb41086,0x59b84ca3}},	//   _opći, _cdio, ҳҳор_, _इनार, 
   {{0x7c2d5b12,0x628400a9,0x3eb01529,0xa184672f}},	//   _lybr, _ddio, deyt_, йырл, 
   {{0x6284016b,0xee3c00a2,0xdef802dd,0xe1040006}},	//   _edio, _gaýy_, қыс_, бясп, 
   {{0xe44d5b13,0x7c2d4ad4,0xc3c00166,0x601812e7}},	//   _عضو_, _nybr, _дөял, горя_, 
   {{0xaf342352,0x644c0882,0xc21001d9,0xe8040037}},	//   ارست, ścit, _ژٔٹ_, _वइसा_, 
   {{0x63500276,0x9f340220,0x6460032e,0xa2b4012d}},	// [234f0] _răni, сеті, _ávið, ेयर्, 
   {{0x2d845a39,0xd7b40490,0xf0800344,0x2ca401a8}},	//   čne_, ंबाच, _دیسپ, ýnd_, 
   {{0xca74005e,0x4fc01e4a,0x8f344f5c,0x6284003a}},	//   аулы, _بەزە, _венц, _ydio, 
   {{0xab28f629,0xaea00131,0x7c2c0042,0x7cf003cd}},	//   رسال_, _دەري, _dybr, _væra, 
   {{0xe9840640,0x00000000,0x00000000,0x00000000}},	//   ућен, --, --, --, 
   {{0x8cb80014,0xe9a40451,0x7cf002d2,0x00000000}},	//   _جگرس_, ندڙن_, _tæra, --, 
   {{0x46f55b14,0x9d181a21,0xa2d81d27,0x26cc0270}},	//   ичит, _сорт_, याम्, _pngo_, 
   {{0x45854118,0x06c805f5,0x8cc80073,0xee3c00a2}},	//   агив, тгий_, _होतो, _saýy_, 
   {{0x628401ab,0xee3c0432,0x286800f3,0x00000000}},	//   _rdio, _paýy_, _зрео_, --, 
   {{0x74e401c6,0xa2d800dc,0xb8d0010a,0x1958586a}},	//   идыг_, याभ्, _мухι, _сафы_, 
   {{0x03a55b15,0xfd5c01f2,0x26cc0789,0x00000000}},	//   шино, _bayọ, _tngo_, --, 
   {{0x26cd5b16,0x7cf005ac,0x96b8014b,0xf8e40327}},	//   _ungo_, _nærn, _бушу_, ġġżu_, 
   {{0xee3c010b,0xc1041b80,0xa2d808dd,0x00000000}},	//   _taýy_, لوحي, याब्, --, 
   {{0x200c0030,0x04444d87,0xe7d400cc,0x3eb0058a}},	//   údio_, _келн, তনীয, weyt_, 
   {{0xafe000f7,0x43755b17,0xdce40003,0x3eb001f4}},	//   оорл, _тулт, spiċ, teyt_, 
   {{0xe8dc07ae,0xddc40024,0x94640014,0x62855b18}},	//   _muốn_, raiž, _پھیۆ, _udio, 
   {{0xed540a16,0x7c2d5b19,0x80c407f7,0x3eb006ea}},	// [23500] иот_, _sybr, ायदे, reyt_, 
   {{0xfd5c063f,0x7178011a,0x00000000,0x00000000}},	//   _zayọ, _שניס, --, --, 
   {{0xbea406ae,0x0244036b,0x7cf001a8,0x4ee400cc}},	//   _канк, _حَکَ, _færn, _নগৰল, 
   {{0xfaa55b1a,0x7c2c0300,0xdce402fb,0x7cf0003b}},	//   радо, _vybr, mpič, _gærn, 
   {{0x7c2c068f,0x39445e76,0x00000000,0x00000000}},	//   _wybr, андг, --, --, 
   {{0xa3c4012c,0x7b6401d9,0x7c2d5b1b,0x37a800d8}},	//   ैमा_, _نارٕ, _tybr, втин_, 
   {{0xe8dc0016,0x59b800e1,0x00000000,0x00000000}},	//   _cuốn_, _इनवर, --, --, 
   {{0x6b80084c,0x00000000,0x00000000,0x00000000}},	//   ânge, --, --, --, 
   {{0x6350054e,0xe574004e,0x00000000,0x00000000}},	//   _mănu, айыч_, --, --, 
   {{0x61206c3f,0xddc4031c,0x09c805af,0x00000000}},	//   pöly, daiż, _حذفي_, --, 
   {{0xd9100451,0xc4440014,0x200c00d7,0x00000000}},	//   _وڌڻ_, میٖن_, údil_, --, 
   {{0x36691379,0xdce43a50,0x00000000,0x00000000}},	//   _радо_, ptiķ, --, --, 
   {{0x7cf02d75,0xdb1c010e,0xd9f80fe3,0x00000000}},	//   _næro, _irrä, ्छित_, --, 
   {{0xa50407d6,0x7cf0383d,0xf1240108,0x00000000}},	//   _кеча_, _særn, рьмо, --, 
   {{0x63500311,0xb28400db,0xaf048ca3,0x00000000}},	//   _bănu, _кыпк, ачак, --, 
   {{0xa2d8047f,0x0ed004af,0x00000000,0x00000000}},	//   याण्, हाइड, --, --, 
   {{0x7cf011c0,0x6350054e,0x8f5400f2,0x00000000}},	// [23510] _værn, _dănu, _گنجش, --, 
   {{0xeb1c0cb2,0xebc40640,0x7cf00fac,0x00000000}},	//   यक्त_, иљен, _wærn, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9a883306,0x7cf15b1c,0x00000000,0x00000000}},	//   لَمْ_, _færo, --, --, 
   {{0xa2d81684,0x7cf15b1d,0x7f380302,0x6b80006a}},	//   यात्, _kærl, _תערו, ângb, 
   {{0x2bc800c7,0x00000000,0x00000000,0x00000000}},	//   _иубо_, --, --, --, 
   {{0x6fd403f3,0xb67004b2,0x00000000,0x00000000}},	//   डमिं, _ኦሮምኛ_, --, --, 
   {{0x7cf052fd,0x1ac80137,0x88580022,0x2b5c00d7}},	//   _lærl, _кууп_, _ӡиас_, _čuch_, 
   {{0x452801c6,0x6f1800d7,0x00000000,0x00000000}},	//   лжин_, čuch, --, --, 
   {{0x7cf00623,0x00000000,0x00000000,0x00000000}},	//   _nærl, --, --, --, 
   {{0x032416c3,0xd7f8030d,0x6b800332,0xc324498b}},	//   йдон, _куц_, ángh, ймок, 
   {{0xd7f8dbdd,0xa2d829d9,0xdce40219,0xd65c01ec}},	//   _туу_, याध्, vpič, _тiрк, 
   {{0x842400d1,0xc56401f7,0x00000000,0x00000000}},	//   شىڭن, _اُتي, --, --, 
   {{0xb9f002d3,0x5724063f,0x00000000,0x00000000}},	//   _ሐደ_, ịntị_, --, --, 
   {{0xa2d808f8,0xc2e8326c,0x43843adf,0xddc40219}},	//   याद्, _معظم_, _البق, dbiš, 
   {{0x09bc0d42,0x00000000,0x00000000,0x00000000}},	//   _আপনা, --, --, --, 
   {{0x127801c6,0xf294011a,0x00000000,0x00000000}},	// [23520] _өшөө_, _הכפר_, --, --, 
   {{0xc0c80020,0xdce4025c,0x00000000,0x00000000}},	//   ጠቀም_, friġ, --, --, 
   {{0xf534008f,0xe8dc004d,0xfb880026,0xe804197e}},	//   צטער_, _luồn_, убек_, _वेला_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xba195b1e,0xfe44084c,0x590800c7,0x00000000}},	//   ديشا_, _ынмо, аҵам_, --, 
   {{0xf2dc026c,0x77680175,0x0dd40092,0x7cd4007b}},	//   zjâ_, tpfx, _ከክፉ_, _اتحذ, 
   {{0x370462b8,0x7cf000cc,0xf7295b1f,0x00000000}},	//   йчив, _jærm, лций_, --, 
   {{0xe8dc0016,0xe8040574,0xfb142c26,0x3cec0490}},	//   _buồn_, _वेळा_, _اورج, _आकडे_, 
   {{0x25ac00ca,0xe8dc0208,0x00000000,0x00000000}},	//   _cpgl_, _cuồn_, --, --, 
   {{0x06a800fe,0x09e00011,0xe7d000db,0xb92400ec}},	//   _খোদি, _মেকা, تۅۅگ, _افئي, 
   {{0x7cf0708a,0x478802bf,0x79800210,0x00000000}},	//   _nærm, _всім_, lsow, --, 
   {{0x7cf02759,0xe7355b20,0x66e0059f,0x00000000}},	//   _særl, _лех_, _ноха, --, 
   {{0x798086d2,0xd5b0263d,0x363410e0,0xb63401ec}},	//   nsow, _آفت_, _اراس, _اعات, 
   {{0xdef8052f,0x4ec40183,0x7cf00158,0xa15821fe}},	//   ҡыт_, _একেল, _bærm, сару_, 
   {{0x7cf15b21,0xeea8f7c2,0xddc40010,0xdfd802e8}},	//   _værl, лтак_, vbiš, бът_, 
   {{0x79800034,0xaee000b8,0x00000000,0x00000000}},	//   ksow, _maṇe, --, --, 
   {{0xed584d66,0x75b40490,0x00000000,0x00000000}},	// [23530] اشرت_, _अनोळ, --, --, 
   {{0x7980017a,0x7cf02b96,0x89d8179e,0x00000000}},	//   dsow, _uærl, یوار_, --, 
   {{0x2fc55b22,0x7cf008a5,0xf1a80133,0x79800210}},	//   _éng_, _gærm, _شاکه_, esow, 
   {{0x09e00eac,0xdce4025c,0x639800df,0x00000000}},	//   _মেগা, rriġ, רסאנ, --, 
   {{0xfa5401d5,0x00000000,0x00000000,0x00000000}},	//   زرنگ, --, --, --, 
   {{0xc0c8001f,0x00000000,0x00000000,0x00000000}},	//   ጠቀሙ_, --, --, --, 
   {{0xe7d4045e,0x79800083,0xf77001d3,0x3fbc00d1}},	//   তন্য, asow, واٹ_, ﻧﻐﺎﻧ, 
   {{0x46e843e8,0x81c00c58,0x6d5c0869,0xdce400e2}},	//   рдин_, ূহত_, oqqa, mpiā, 
   {{0xa2d8085c,0xaca00051,0x98c40150,0x6d5c03b9}},	//   यास्, _ngịc, ісәл, nqqa, 
   {{0x6d5c022f,0x17680116,0x00000000,0x00000000}},	//   iqqa, шрәп_, --, --, 
   {{0xaee000cd,0x00000000,0x00000000,0x00000000}},	//   _gaṇe, --, --, --, 
   {{0x26c000e2,0x05080154,0xe8dc0208,0x00000000}},	//   ējos_, রকের_, _tuồn_, --, 
   {{0x37c40489,0x9f4c012c,0x7cf000cc,0x7ae8045f}},	//   _གནོད, ádí_, _særm, êfti, 
   {{0xf038001f,0x7ae801c7,0x00000000,0x00000000}},	//   _በስምም, ëftz, --, --, 
   {{0x6d5c20ac,0xc56400ec,0x00000000,0x00000000}},	//   eqqa, _اُڪي, --, --, 
   {{0x7cf0143a,0xbe6801c0,0x984c00de,0x79815b23}},	//   _værm, рааж_, lēģi_, ysow, 
   {{0x82f91488,0x6da15b24,0xada15b25,0x7d08fbd3}},	// [23540] _مرکز_, мита, матл, анаг_, 
   {{0xa2d8041c,0x00000000,0x00000000,0x00000000}},	//   याव्, --, --, --, 
   {{0x6d5c0eda,0x23a00165,0x5e6400cf,0xe9fc0051}},	//   aqqa, nñj_, _ىندە, _thẻo_, 
   {{0x79815b26,0x7cf15b27,0x6b80054e,0xaee000b8}},	//   tsow, _kærk, ânga, _raṇe, 
   {{0x3f481682,0x7cf00158,0xed4c00db,0xcaa400cf}},	//   _ṱuwa_, _jærk, رپۅ_, سلوۋ, 
   {{0xf770b8c6,0x7cf0019b,0xc0c00020,0x28f4023a}},	//   واع_, _mærk, ስትሩ_, жешь_, 
   {{0x79800548,0x63a0003e,0x7cf01cf3,0x9c400220}},	//   ssow, _nqnn, _lærk, _ﺩﺍﻣﯟ_, 
   {{0x7bcd5b28,0x074800f1,0xdb1c0332,0x7980012d}},	//   _irbu, مړنی_, _osré, psow, 
   {{0x7cf00174,0xca74010b,0xa9655b29,0x7ae00327}},	//   _nærk, _хусы, _мита_, mjot, 
   {{0x17c40022,0x00000000,0x00000000,0x00000000}},	//   _назҭ, --, --, --, 
   {{0xdb1c0066,0xb6a400a8,0xdef80b82,0x00000000}},	//   _asré, _мижл, ለሱን_, --, 
   {{0x09e02158,0x281000db,0x46d00034,0xea9c0882}},	//   _মেটা, _تومس, _दोपह, raṇe_, 
   {{0x332800d4,0x00000000,0x00000000,0x00000000}},	//   rocx_, --, --, --, 
   {{0xc4cc7fc5,0x7ae001f4,0x00000000,0x00000000}},	//   _مےٚ_, hjot, --, --, 
   {{0xa2d80b7c,0x00000000,0x00000000,0x00000000}},	//   याश्, --, --, --, 
   {{0xe2f40489,0xc674001f,0x630400f1,0xa2ac0118}},	//   _བཞགཔ_, _ኦሮሚያ_, _يوول, जभण्, 
   {{0xa2d81276,0x7bcd5b2a,0x7cf00008,0x7ae0020c}},	// [23550] यार्, _arbu, _gærk, djot, 
   {{0xc0c15b2b,0x7e640270,0x7cf00158,0xec6800fd}},	//   ስትር_, _efkp, _jærh, ррак_, 
   {{0x06e002f5,0x00b80375,0x0f340efc,0xa3800055}},	//   বসতি, _המתמ, _فکرد, _guõā, 
   {{0x7bcd5b2c,0xd7b40490,0x1a680101,0x00000000}},	//   _drbu, ंबईच, قیفی_, --, 
   {{0x38c80133,0xf48c0023,0x09e00011,0x05a80037}},	//   ڵاوی_, ሓሳስብ_, _মেজা, _कहइब, 
   {{0x7cf014f5,0x61e001e6,0xc8c800ec,0xefe81ef7}},	//   _nærh, ämli, صوبن_, _ጅሃድ_, 
   {{0x8bd800d4,0x00000000,0x00000000,0x00000000}},	//   _умвс_, --, --, --, 
   {{0x6b802b76,0x1ab402bf,0xda791697,0x200c0419}},	//   ángu, _обся, _мяу_, údii_, 
   {{0x3af8010f,0x00000000,0x00000000,0x00000000}},	//   _פּלע, --, --, --, 
   {{0xc8c800f1,0xdce40327,0x00000000,0x00000000}},	//   _دوطن_, rriħ, --, --, 
   {{0xdb1c026c,0x7cf012ed,0xd5e801d3,0xa2d81223}},	//   _arrù, _særk, معین_, याल्, 
   {{0x4a28031c,0x940c03e3,0x00000000,0x00000000}},	//   _སྙོལ_, ngdə_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7cf0019b,0x1638007b,0x7ae0012d,0x7c200356}},	//   _værk, _بسمة_, zjot, şori, 
   {{0xd9b8084a,0x3f68005b,0x00000000,0x00000000}},	//   _इन्ट, сибо_, --, --, 
   {{0xdb082ca8,0x769403b9,0x00000000,0x00000000}},	//   ülür, müyü, --, --, 
   {{0x09e0045e,0x6b84022e,0x76940213,0xe9fc0051}},	// [23560] _মেঘা, _avjg, lüyü, _thẹo_, 
   {{0xdb1c007b,0x7cf01d1d,0x823400f1,0x00000000}},	//   _urrú, _kæri, _ورکا, --, 
   {{0x46bc53c3,0x00000000,0x00000000,0x00000000}},	//   ्याह, --, --, --, 
   {{0x7bcc009b,0x7ae00024,0x7cf002d2,0xafe000db}},	//   _vrbu, ujot, _mæri, _чоюл, 
   {{0x7ae0049b,0x69cc0077,0x65680327,0xe3a400f1}},	//   rjot, _ácel, _ntgh, _ګر_, 
   {{0x7bcc071b,0x23d800cd,0x00000000,0x00000000}},	//   _trbu, यमाद, --, --, 
   {{0x7cf0525d,0x7f5c0477,0x7d0c3cf7,0x69c80162}},	//   _næri, _jupq, _imbs, avge, 
   {{0x2240022e,0xe3b00154,0x7cf012e8,0x769403e3}},	//   _ozik_, য়মাব, _særh, düyü, 
   {{0x88b000cc,0x00000000,0x00000000,0x00000000}},	//   চয়ক, --, --, --, 
   {{0x7cf0032e,0xe8f402dd,0x00000000,0x00000000}},	//   _bæri, _елу_, --, --, 
   {{0x7f5c0477,0x224020a9,0x92955b2d,0x7cf003cd}},	//   _nupq, _azik_, манц, _værh, 
   {{0xfd4c0432,0x81e400eb,0x00000000,0x00000000}},	//   _proỳ, পনন_, --, --, 
   {{0x7d0c035a,0x00000000,0x00000000,0x00000000}},	//   _ombs, --, --, --, 
   {{0x7cf001a8,0x8534075e,0x31680107,0x76940205}},	//   _færi, _قونچ, ишҳо_, büyü, 
   {{0x224001c0,0x2934008f,0xdfd800a7,0x7cf0005c}},	//   _ezik_, פאלן_, път_, _gæri, 
   {{0xb8dc08ea,0x7f5c014f,0x7d0c02d0,0x7c3803b2}},	//   _ཇི_, _dupq, _ambs, _útry, 
   {{0x340000e8,0xc2100014,0x9f4c00bc,0x8c8800c7}},	// [23570] _féxé_, _لٔٹ_, ádá_, жәба_, 
   {{0xf1bc011f,0x387c0036,0x9df8005b,0x00000000}},	//   mwá_, _netr_, чнут_, --, 
   {{0x3dc00113,0xf1bd5b2e,0x96100154,0x00000000}},	//   _eskw_, lwá_, _হুমম_, --, 
   {{0x68e00369,0xceb801ef,0x00000000,0x00000000}},	//   wjnd, _úř_, --, --, 
   {{0xf1bd5b2f,0x6f0c02d0,0xdea417a6,0x6b400254}},	//   nwá_, _imcc, _سیلی, jõge, 
   {{0x1cdc025c,0x68e00399,0x76943535,0x7f5c571b}},	//   _འོར_, ujnd, yüyü, _yupq, 
   {{0xc1a81bd6,0x00000000,0x00000000,0x00000000}},	//   _चङ्ग, --, --, --, 
   {{0x68000de2,0x070800e3,0x00000000,0x00000000}},	//   _rёdd, تيبي_, --, --, 
   {{0x387c3ec2,0x7cf002d2,0x00000000,0x00000000}},	//   _fetr_, _særi, --, --, 
   {{0x7cf0013c,0x83884294,0x17bc03d4,0x00000000}},	//   _pæri, обов_, _অপৰি, --, 
   {{0x1cdc0135,0x2d98acd3,0x00000000,0x00000000}},	//   _འོལ_, huqe_, --, --, 
   {{0x76942fbe,0x7f5c014f,0xe3d00137,0x2d980240}},	//   rüyü, _rupq, _үйдө, kuqe_, 
   {{0xf1bc011f,0x340000e8,0x7f5c0477,0xdb2406af}},	//   gwá_, _péxé_, _supq, ésél, 
   {{0x7cf011c0,0x46bc0b7c,0x7f5c014f,0x00000000}},	//   _hærv, ्यवह, _pupq, --, 
   {{0x2d8c0407,0x7f5c014f,0x7cf001bf,0x2584013a}},	//   ágen_, _qupq, _kærv, bílý_, 
   {{0x2ee807c5,0x7f5c0477,0x25bc0de2,0xb218005c}},	//   _cocf_, _vupq, owul_, maæn, 
   {{0xf1c15b30,0x2d980117,0xc245051f,0x7cd801c8}},	// [23580] _айып, guqe_, _юник, يورز_, 
   {{0x27140356,0x7f5c0139,0x96dc0356,0x00000000}},	//   mănu_, _tupq, ăşiţ, --, 
   {{0x25bc2ad7,0x3b8401ee,0x00000000,0x00000000}},	//   hwul_, флег, --, --, 
   {{0xa2d4256a,0x200c0030,0xdce40210,0x61480241}},	//   _बोम्, údiu_, dpią, bélù, 
   {{0x7bd8b8dd,0x387d5b31,0x98a4013d,0x7e7400c7}},	//   _štud, _petr_, _sumı_, mbyp, 
   {{0x7d0d5b32,0x00000000,0x00000000,0x00000000}},	//   _umbs, --, --, --, 
   {{0x6b61444d,0xb9040c2e,0xf1bc0085,0x387c0165}},	//   _акса, _बच_, zwá_, _vetr_, 
   {{0x7588f0c0,0x260c74f6,0xab4c0150,0xe8f40139}},	//   осов_, _तेही_, _ﺑﺎﺳﯟ_, злә_, 
   {{0x0ae8a9e7,0xada00118,0x387c0139,0xf210000d}},	//   _عرفي_, ceúč, _tetr_, _ढेढ़_, 
   {{0x7c20054e,0x4a280327,0x00000000,0x00000000}},	//   şoru, _སྙིལ_, --, --, 
   {{0xf1bc0548,0xc8b40166,0x00000000,0x00000000}},	//   wwá_, _ясты, --, --, 
   {{0x26c879f8,0xd25001d9,0x6b40000d,0x00000000}},	//   _وطنی_, ُند_, põge, --, 
   {{0xe7055b33,0x00000000,0x00000000,0x00000000}},	//   _تسلی, --, --, --, 
   {{0x76400921,0x7cf01f60,0xf1bc0548,0xe9fc0208}},	//   _izoy, _kæru, rwá_, _nhẽo_, 
   {{0xd5c8001e,0xdb1c013d,0x250800e5,0x00000000}},	//   _hề_, _asrí, _برنی_, --, 
   {{0xd5c801fb,0x7e740af9,0x2d980240,0x7cf002d2}},	//   _kề_, gbyp, tuqe_, _mæru, 
   {{0x7cf00579,0x9f347707,0x2a7c00a3,0x6ca455e4}},	// [23590] _læru, теті, _reub_, дреж, 
   {{0xd0109fa2,0xd5c80208,0x03d003d4,0x00000000}},	//   _ملخ_, _mề_, াহৰণ, --, 
   {{0x7e7405ac,0x7cf0022c,0xd5c801fb,0x753801c4}},	//   bbyp, _næru, _lề_, iltz, 
   {{0x764001f0,0x6f0c014b,0x9c440304,0x1ae400d4}},	//   _ozoy, _umcc, тхул, коєм, 
   {{0xd838007f,0xd5c801fb,0xd6f003d4,0x4a0800c7}},	//   _ayč_, _nề_, জোৱা_, џьеҭ_, 
   {{0x7cf0525d,0xabb00124,0xab6002dd,0xa02003d4}},	//   _bæru, _иагә, _ٴۇشى, _ধৰিব_, 
   {{0x76415b34,0x6d455b35,0xb898002b,0x2a7c0129}},	//   _azoy, _ihja, _guḍā, _teub_, 
   {{0x7c2003be,0xd5c8001e,0x56f001e0,0xdce4012d}},	//   ğort, _bề_, ғүәс, rpią, 
   {{0x7cf00212,0x5a34f3d3,0xaee00055,0x00000000}},	//   _værv, _антт, _spṛd, --, 
   {{0x5a440276,0xd5c80208,0x7cf008a5,0x00000000}},	//   _рэса, _dề_, _færu, --, 
   {{0x76415b36,0x260c31a0,0x7cf0032e,0x14000022}},	//   _ezoy, _तेरी_, _gæru, иҧшн, 
   {{0x7cf005ac,0x8c000154,0xd77400db,0xe9fc0208}},	//   _hært, _এখান_, _شامع, _giảo_, 
   {{0x6d44049b,0x960403e6,0x3af8008f,0x7cf0005c}},	//   _ohja, _لبوم, פּטע, _kært, 
   {{0xdce401a6,0x29180066,0x00000000,0x00000000}},	//   mpić, éqah_, --, --, 
   {{0x6d480024,0xb4f8011a,0xd5c80051,0x00000000}},	//   įgal, _מפסי, _zề_, --, 
   {{0x64415b37,0x7cf03c12,0x6d449d3f,0xe9e40419}},	//   _izni, _lært, _ahja, _klúč_, 
   {{0x6738023a,0xd5c80051,0x00000000,0x00000000}},	// [235a0] iluj, _xề_, --, --, 
   {{0x6d440ba3,0xa2d8047f,0xbfc41cb8,0x3e7c004d}},	//   _chja, याक्, _збок, ắt_, 
   {{0xeb9407d8,0x6d440023,0x673802f0,0x7bd800d7}},	//   еих_, _dhja, kluj, _štub, 
   {{0xba242daf,0x79a4e362,0x3a2400ee,0xf984119e}},	//   ндек, ерке, нмег, егдо, 
   {{0x260c8bb7,0x7cf0383d,0x3f8803cd,0xdfc80055}},	//   _तेली_, _bært, lsbu_, _kṣāṇ, 
   {{0x6d440c95,0xb8655b38,0xd8380100,0x6440022e}},	//   _ghja, راتو, _pyč_, _ozni, 
   {{0x81e404c5,0x67380407,0x00000000,0x00000000}},	//   পনি_, fluj, --, --, 
   {{0x7cf001a8,0x67395b39,0x870801ed,0x00000000}},	//   _væru, gluj, وڑنے_, --, 
   {{0x64400ac5,0xe56c0214,0x7cf001bf,0xb90405ac}},	//   _azni, یطی_, _fært, _পত_, 
   {{0xd5c8431d,0x753801c0,0xd83802fb,0x3f880003}},	//   _về_, ultz, _tyč_, ksbu_, 
   {{0x7cf005ac,0x00000000,0x00000000,0x00000000}},	//   _hærs, --, --, --, 
   {{0xa2d837e3,0xf2c4013e,0x656c01f2,0xd5c8004d}},	//   याग्, хсон, ̣chi, _tề_, 
   {{0xb4b049c6,0x7640d9f2,0x7cf02d8b,0x25900014}},	//   _билә, _uzoy, _jærs, _مٔنز, 
   {{0xf3f81b35,0x7cf15b3a,0xe3ace43b,0x656d5b3b}},	//   ྒྱུད_, _mærs, جری_, íche, 
   {{0xa2d841ac,0x64a00063,0xe3ac35f9,0x63b002f0}},	//   याख्, _саја, _هري_, čená, 
   {{0x64380302,0x9f60fda8,0x533409a5,0x9f3402dd}},	//   _מעונ, árás_, _шейт, гесі, 
   {{0xdd955b3c,0x7cf06672,0x4fc000d1,0x25080345}},	// [235b0] латы, _nærs, _ھەرە, _برۆی_, 
   {{0x4fc015bf,0x00000000,0x00000000,0x00000000}},	//   _پەرە, --, --, --, 
   {{0xdd9400fb,0x2c24035b,0x00000000,0x00000000}},	//   _ҙары, хьаг, --, --, 
   {{0x7cf15b3d,0xfa5401d5,0x00000000,0x00000000}},	//   _sært, چرهگ, --, --, 
   {{0xdb1c00dd,0x2d8800f3,0x80c40073,0x00000000}},	//   _arró, _uvce_, ायचे, --, 
   {{0x7cb40116,0xeff400b7,0x00000000,0x00000000}},	//   _иқут_, _ወልድ_, --, --, 
   {{0x7cf0037e,0xdce4033f,0x0ac400c7,0x673802f0}},	//   _vært, jpię, _ишаҭ, tluj, 
   {{0x7cf000fc,0xabb000c7,0x6738005b,0xdce40210}},	//   _færs, _иаҳә, uluj, dpię, 
   {{0xe7f0330a,0xdb1c00bd,0x7cf0005c,0xb6c0009d}},	//   _अथवा_, _erró, _tært, рөхд, 
   {{0x673815ad,0x7cf00008,0x552401ec,0x49900066}},	//   sluj, _hærr, лпыұ, _میچر, 
   {{0xdce42375,0x1af40183,0x3f6800e4,0x7cf002d2}},	//   spić, _আগতে_, _oĝua_, _kærr, 
   {{0x644003c6,0x00000000,0x00000000,0x00000000}},	//   _vzni, --, --, --, 
   {{0x6440012d,0xf1c001d5,0x00000000,0x00000000}},	//   _wzni, айяп, --, --, 
   {{0x7cf000b5,0x86c400ec,0x00000000,0x00000000}},	//   _lærr, _سيڪن, --, --, 
   {{0x74100451,0x00000000,0x00000000,0x00000000}},	//   _پويا, --, --, --, 
   {{0x7cf008a7,0x309c001f,0x32300521,0x3f880158}},	//   _nærr, _ውዝግብ_, ụnụ_, rsbu_, 
   {{0x3ea4005f,0x6fc0031c,0x3f893e11,0x00000000}},	// [235c0] ļot_, _ཝརྨའ, ssbu_, --, 
   {{0x62840165,0x06cc0eac,0x00000000,0x00000000}},	//   _heio, িউটি, --, --, 
   {{0x7cf00a64,0xff240022,0x62855b3e,0x6b60074d}},	//   _særs, _амно, _keio, акха, 
   {{0xdb1c8d22,0x2fc400c7,0xa2d800bc,0xdee80240}},	//   _arrò, _ânga_, याट्, መዓካ_, 
   {{0x6284315a,0x5f0400c7,0xa9649fad,0xeff400b7}},	//   _meio, _азҟа, вича_, _ወልደ_, 
   {{0x7cf15b3f,0x628554cc,0xe89007dd,0x88801b1c}},	//   _værs, _leio, аашь, йғул, 
   {{0xa2d800dc,0xdbe001e1,0xf0900375,0x00000000}},	//   याञ्, _kìír, בנו_, --, 
   {{0xdb1c00cf,0x3e840006,0x3eb005e4,0x7cf0005c}},	//   _errò, būtų_, nfyt_, _tærs, 
   {{0x6f000262,0xf8e000dc,0xdbe0110e,0x00000000}},	//   _înce, पादय, _mìír, --, 
   {{0x62840072,0xeff4010c,0x3b04014f,0x00000000}},	//   _aeio, _ወልዱ_, lhoq_, --, 
   {{0x7df80055,0xa6c4315b,0xa7a40354,0x0c700023}},	//   _hāsā, رویل_, _акха_, _ብታሪኽ_, 
   {{0x62840393,0x7df800b8,0xdbe001e1,0xd83801ef}},	//   _ceio, _kāsā, _nìír, _občz_, 
   {{0x62845931,0xa34405f5,0xa2d801bc,0x05b401b9}},	//   _deio, рээл, याज्, _یگیت_, 
   {{0x6590e584,0x7df83db2,0x00000000,0x00000000}},	//   _ташу, _māsā, --, --, 
   {{0x62855b40,0xdb1c003a,0xb4bc0cf1,0xbb3000d1}},	//   _feio, _isræ, ँजी_, _ﮬﻪﻡ_, 
   {{0x3b040007,0xdd1c01e1,0xe7d007b6,0x00000000}},	//   jhoq_, _láńl, थितप, --, 
   {{0xb1e00075,0x7df800cd,0x944400e5,0x00000000}},	// [235d0] _тәнқ, _nāsā, _جھکن, --, 
   {{0x7cf00ac8,0x2ca4061f,0x614400f3,0x00000000}},	//   _særr, ünd_, _кења, --, 
   {{0xa2d82413,0xab8428f6,0x00000000,0x00000000}},	//   याच्, тузк, --, --, 
   {{0xd25800e2,0x3b04014f,0x00000000,0x00000000}},	//   žņu_, ghoq_, --, --, 
   {{0x7cf14094,0xdd840024,0x7df8002b,0x858c02dd}},	//   _værr, _высп, _cāsā, _ﻓﺈﺫﺍ_, 
   {{0x7df8002b,0x00000000,0x00000000,0x00000000}},	//   _dāsā, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3b04358d,0xdb1c007b,0x85780120,0x06a805ac}},	//   choq_, _tsrá, нсот_, _খোজি, 
   {{0xa8a40124,0xa2d80b7c,0xb51c0073,0x00000000}},	//   _арек, याघ्, यचंय_, --, 
   {{0xd1d40020,0x62855b41,0xaef801c3,0x9f4c00c6}},	//   ርኔት_, _seio, _fiùg, ádú_, 
   {{0xaee00943,0x290407f0,0xd7c825da,0x62840381}},	//   _laṱe, mhna_, _لوله_, _peio, 
   {{0x161409bb,0x7df8002b,0x00000000,0x00000000}},	//   _तेवर_, _yāsā, --, --, 
   {{0x62855b42,0xe4b001e0,0x00000000,0x00000000}},	//   _veio, _көнъ, --, --, 
   {{0x361804ac,0xa2d400ce,0x03a55b43,0xf590d55f}},	//   _אונד, _बोर्, _бико, _الوج, 
   {{0xd3c40150,0x00000000,0x00000000,0x00000000}},	//   _ەتۋى, --, --, --, 
   {{0x1cdc07e4,0x2904031c,0xdb200205,0x00000000}},	//   _འོང_, hhna_, ütüc, --, 
   {{0xd7f80016,0x7cf0143a,0xeb9401b9,0x3eac000f}},	// [235e0] _ngăn_, _bærp, ғич_, ęft_, 
   {{0xa11404a9,0xee340372,0x290409a8,0xac815b44}},	//   _ئۈست, уну_, jhna_, йгул, 
   {{0x9f58044e,0x8b64b76e,0x29040192,0xb4f8010f}},	//   nyrë_, لانم, dhna_, עלער, 
   {{0x7e740137,0x7df80055,0xab74007b,0x0ba800d1}},	//   _حادئ, _pāsā, امنا_, ئالى_, 
   {{0xaef801ab,0x9f580240,0x3b040240,0xe9d4010b}},	//   _siùg, hyrë_, rhoq_, лкц_, 
   {{0xa3e0038e,0x29055b45,0x3b055b46,0x58d400cf}},	//   नमा_, ghna_, shoq_, рокт, 
   {{0xc5f00d42,0x9f580023,0xaef801ab,0x3154008f}},	//   _জেলা_, jyrë_, _fiùd, ניצן_, 
   {{0xa2d44ff1,0x3b040369,0xd97800c7,0x29055b47}},	//   _बोल्, qhoq_, _аржә_, ahna_, 
   {{0x98fc0115,0xf4840166,0x3a2401ca,0x290400ae}},	//   _riĉf, лунн, _смаг, bhna_, 
   {{0x29055b48,0x656d5b49,0x66e001d5,0xdd1400d7}},	//   chna_, ícha, _қоча, _lúžn, 
   {{0xc5c40327,0x00000000,0x00000000,0x00000000}},	//   _ཀརྨི, --, --, --, 
   {{0xc76404a9,0x395c2734,0xf7540092,0x00000000}},	//   _ئالى, _hits_, _ሊቃዉን, --, 
   {{0x395c7d6a,0x2f040037,0x00000000,0x00000000}},	//   _kits_, _jõge_, --, --, 
   {{0x2f1c013d,0x00000000,0x00000000,0x00000000}},	//   kägä_, --, --, --, 
   {{0x395d5b4a,0x53a8447d,0x00000000,0x00000000}},	//   _mits_, _कमिश, --, --, 
   {{0x395d5b4b,0x7cf02d75,0xb2c00137,0xd1300014}},	//   _lits_, _særp, _اڭدۇ, _ڈمب_, 
   {{0x2d8c00dd,0x395c01d5,0x63040b24,0x8d9400d1}},	// [235f0] ége_, _oits_, _دويل, شلاش, 
   {{0x395d5b4c,0x4c94005b,0x30a40395,0x2f1c0166}},	//   _nits_, рижс, _срив, fägä_, 
   {{0x1cb920bb,0x7cf00fac,0x88cc0154,0x2f1c0139}},	//   طالب_, _værp, লামক, gägä_, 
   {{0xdce4010f,0x00000000,0x00000000,0x00000000}},	//   mpiĝ, --, --, --, 
   {{0x9b940075,0x09e55b4d,0xddc40276,0x290406f2}},	//   للەت, ролн, rciţ, thna_, 
   {{0x395c005f,0x6ce42626,0x29040098,0x195800db}},	//   _cits_, _сіме, uhna_, гачы_, 
   {{0x395d5b4e,0xee3c00a2,0x2f1c008e,0x00000000}},	//   _dits_, _hyý_, cägä_, --, 
   {{0x29055b4f,0x395c008b,0x6b8045c1,0x9b583d76}},	//   shna_, _eits_, ângu, _бист_, 
   {{0x290406a3,0xdb1c000f,0x395d5b50,0x00000000}},	//   phna_, _oprê, _fits_, --, 
   {{0xe7841fe2,0x9f5802d3,0x395d5b51,0xddc40024}},	//   _будо, tyrë_, _gits_, nciš, 
   {{0xd8741518,0x0444c08e,0x03255b52,0xd9d403e6}},	//   _طالب, ренн, идон, _پڕۆگ, 
   {{0x395d5b53,0x69cc0077,0x00000000,0x00000000}},	//   _zits_, _áces, --, --, 
   {{0x26cd5b54,0x3f840030,0x84e40408,0xc2c40ccb}},	//   _iago_, _ňou_, _волж, هيگي, 
   {{0x26cd5b55,0xd618034c,0x00000000,0x00000000}},	//   _hago_, _حتما_, --, --, 
   {{0x26cd5b56,0x3f140261,0xe9100208,0x93240ca5}},	//   _kago_, аќат, _đứa_, _گرون, 
   {{0x26cc5bf4,0x823404fb,0xd2540014,0x3f8c02d2}},	//   _jago_, _پربا, _گیُش_, _æfum_, 
   {{0x9324182f,0x23651e81,0xaab800bc,0xddc4025c}},	// [23600] _درون, _hunj_, ोजनक, qbiż, 
   {{0x26cd5b57,0xec755b58,0xaef801ab,0x40940aa8}},	//   _lago_, ипу_, _ciùb, _трит, 
   {{0x24855b59,0x6cd09124,0x395d5b5a,0x23641bce}},	//   _menm_, تقلا, _rits_, _junj_, 
   {{0x26cd5b5b,0x395d5b5c,0xeb955b5d,0x2b5c0311}},	//   _nago_, _sits_, риц_, _ciuc_, 
   {{0x395d5b5e,0x6f00084c,0x2b5c01c3,0x00000000}},	//   _pits_, _înca, _diuc_, --, 
   {{0x26cc0ca8,0x00000000,0x00000000,0x00000000}},	//   _aago_, --, --, --, 
   {{0xb8cc3323,0x26cd5b5f,0xf72811ed,0x395d5b60}},	//   _का_, _bago_, кций_, _vits_, 
   {{0x395d5b61,0x26cd5b62,0xb88000bc,0xc0c0001f}},	//   _wits_, _cago_, _řídi, ድድሩ_, 
   {{0x26cd5b63,0x395d5b64,0xf5255b65,0x248403e0}},	//   _dago_, _tits_, ифон, _benm_, 
   {{0x26cc0295,0x79513df8,0x00000000,0x00000000}},	//   _eago_, _بێتا, --, --, 
   {{0x26cd5b66,0x22400066,0x23640010,0xb60402d2}},	//   _fago_, _ayik_, _cunj_, _bláó, 
   {{0x26cd5b67,0x66e05842,0xdb1c0086,0x236401a6}},	//   _gago_, _моха, _errö, _dunj_, 
   {{0x7bd8110c,0x24852e1f,0x2138030a,0xe7344316}},	//   _štul, _fenm_, forh_, _тец_, 
   {{0x26cd0bf1,0x7c2d5b68,0x24840100,0x6fb4039b}},	//   _zago_, _oxbr, _genm_, аҳор_, 
   {{0x26cd5b69,0x5f94dcd7,0x98fc01e4,0xaef800a3}},	//   _yago_, жист, _giĉe, _niùc, 
   {{0xaef808c2,0xd7f8004d,0xdce400df,0x9e742374}},	//   _siùb, _ngăm_, rpiĝ, يۇپت, 
   {{0x224000e5,0x8afc013a,0x00000000,0x00000000}},	// [23610] _gyik_, _jiře, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4a755b6a,0x2fc401c7,0x720000f1,0xddc40064}},	//   былт, _èng_, _دوښم, rciš, 
   {{0xaef800a3,0xc0c000b7,0x00000000,0x00000000}},	//   _diùc, ድድር_, --, --, 
   {{0x26cc94af,0xa9c4084c,0xaef801ab,0xdce40135}},	//   _rago_, рсек, _tiùb, ssiġ, 
   {{0x26cd5b6b,0xf97801d3,0x7c400022,0x00000000}},	//   _sago_, اؤنڈ_, ñyrõ, --, 
   {{0x26cd5b6c,0x260c09d9,0x87b801c0,0x9d194390}},	//   _pago_, _तेजी_, уулт_, _торт_, 
   {{0x2484083a,0x656d5b6d,0xaacc1d8a,0x06c802bf}},	//   _senm_, ícho, _सोचक, угий_, 
   {{0x6ab801f2,0x00000000,0x00000000,0x00000000}},	//   _ibuf, --, --, --, 
   {{0xdb1d5b6e,0x9a880050,0x1cdc0327,0x98f400ae}},	//   _aprè, _منہٕ_, _འོབ_, _وثلا, 
   {{0x26cd5b6f,0x47d405e6,0x845800c7,0x00000000}},	//   _tago_, _ديار, ырит_, --, 
   {{0x69d95b70,0x23640007,0x26cc003a,0x85040133}},	//   _krue, _vunj_, _uago_, _گوتن, 
   {{0x24855b71,0x6ab801f2,0xdb1c04e6,0xab60012d}},	//   _tenm_, _mbuf, _sprë, ężyc, 
   {{0x65795b72,0xdb1c02e2,0x7bd87edf,0x8504004b}},	//   mpuh, _eprè, _štum, _دوتن, 
   {{0x6ab857d2,0x8ff86a8b,0x00000000,0x00000000}},	//   _obuf, ахту_, --, --, 
   {{0x69d8005a,0x00000000,0x00000000,0x00000000}},	//   _orue, --, --, --, 
   {{0x1cdc08ea,0xaef801c3,0x65795b73,0x41a8013e}},	// [23620] _འོད_, _siùc, npuh, _ёвон_, 
   {{0x6ab80134,0xc21001d9,0xe60401d9,0xd3fc03d4}},	//   _abuf, _ؤں_, _ہش_, ুপৰি_, 
   {{0x69d95b74,0x65780455,0x00000000,0x00000000}},	//   _arue, hpuh, --, --, 
   {{0x69d95b75,0xfaa4d1a6,0x00000000,0x00000000}},	//   _brue, садо, --, --, 
   {{0x315451a4,0x656c0332,0x00000000,0x00000000}},	//   _خلیج_, íchl, --, --, 
   {{0x6ab95b76,0x69d95b77,0x32dc01f4,0x19583947}},	//   _ebuf, _drue, _käyä_, шалы_, 
   {{0x69d95b78,0x7d1d5b79,0x7c2c045a,0x00000000}},	//   _erue, mips, _uxbr, --, 
   {{0x69d95b7a,0x7bcd5b7b,0x6c315b7c,0x7d1d5b7d}},	//   _frue, _isbu, _رفقا, lips, 
   {{0x6578065d,0x00000000,0x00000000,0x00000000}},	//   gpuh, --, --, --, 
   {{0x7d1d5b7e,0xdb1c00d8,0x28bc0807,0x78b80208}},	//   nips, _errô, _शॉपि, _ubtv, 
   {{0x1cdc003d,0xdb1d5b7f,0x7bd80841,0x00000000}},	//   _འོན_, _apré, _štuj, --, 
   {{0x92595b80,0x7d1c2c58,0x36681086,0xdb1c01e7}},	//   иант_, hips, _садо_, _bpré, 
   {{0x7d1d5b81,0x02a80073,0x00000000,0x00000000}},	//   kips, _कारभ, --, --, 
   {{0x764005b8,0xf1255b82,0x7d1c009a,0x32dc008e}},	//   _iyoy, сьмо, jips, _bäyä_, 
   {{0x24b40375,0x7640b1d9,0x7d1d5b83,0xa2d40b40}},	//   _ההון_, _hyoy, dips, _बोक्, 
   {{0xdb44168d,0x76400337,0xdef80032,0x753801c6}},	//   _سێ_, _kyoy, быу_, lotz, 
   {{0xd0d406bb,0x7bcd5b84,0x644c0034,0x00000000}},	// [23630] _допъ, _asbu, ęcie, --, 
   {{0x753804c4,0x6ab8c7cc,0x76401418,0x7bcc00a2}},	//   notz, _sbuf, _myoy, _bsbu, 
   {{0x6f000276,0xaca001f2,0x7bcc0175,0x7538005a}},	//   _înco, _nyục, _csbu, iotz, 
   {{0x69d811ea,0x753801c0,0x65795b85,0xa2bc6766}},	//   _prue, hotz, ypuh, ष्प्, 
   {{0x76415b86,0x753801c0,0x7bcc3756,0x00000000}},	//   _nyoy, kotz, _esbu, --, 
   {{0x7bcc01ab,0x7d1c0393,0x7538005a,0x6f1c01b9}},	//   _fsbu, cips, jotz, liqc, 
   {{0x764023db,0x77615b87,0x37840801,0x7538005a}},	//   _ayoy, _biox, общо_, dotz, 
   {{0x6ab95b88,0x69d95b89,0x97c41823,0x76401418}},	//   _ubuf, _true, ستىم, _byoy, 
   {{0x764000ca,0x6aa80175,0x7538002f,0x96900345}},	//   _cyoy, mggf, fotz, ریوش, 
   {{0x753801c0,0x6f1cfa7e,0x65782641,0x355000f1}},	//   gotz, hiqc, rpuh, ونيز, 
   {{0x02c4a4c8,0x76415b8a,0x1cc8025c,0x65781057}},	//   ойно, _eyoy, _ཉིལ_, spuh, 
   {{0x7bd95b8b,0x7d1c0209,0x65784ce6,0x52747753}},	//   _štuk, zips, ppuh, зуру, 
   {{0x75394ac9,0x76400337,0x6aa80175,0xbb38010f}},	//   botz, _gyoy, iggf, שערי, 
   {{0x66802be7,0x00000000,0x00000000,0x00000000}},	//   _بیکل, --, --, --, 
   {{0x65695b8c,0x656001f0,0xd538117d,0x00000000}},	//   _hugh, _iinh, _اثنا_, --, 
   {{0x65615b8d,0x65684180,0x64406eb0,0x6f000311}},	//   _hinh, _kugh, _iyni, _încl, 
   {{0x65615b8e,0x7d1d5b8f,0x73301e87,0x656801e4}},	// [23640] _kinh, tips, _تىيا, _jugh, 
   {{0x65695b90,0x65615b91,0x6aa80175,0x6d540175}},	//   _mugh, _jinh, eggf, gmxa, 
   {{0x65695b92,0x65615b93,0x9f4d127d,0xf534008f}},	//   _lugh, _minh, ádó_, קטער_, 
   {{0x6560ab04,0x7d1d5b94,0x1cdc031c,0x6440036e}},	//   _linh, sips, _འོམ_, _myni, 
   {{0x644003a2,0xe3a400b2,0x77600005,0x6560005a}},	//   _lyni, _ڪر_, _riox, _oinh, 
   {{0x65615b95,0xf8053c4b,0x3f6800e4,0x64415b96}},	//   _ninh, жчин, _aĝui_, _oyni, 
   {{0xe3a49daa,0x7ac816cb,0xeb945d88,0x56955b97}},	//   _تر_, _پوءِ_, _мир_, пайт, 
   {{0x65695b98,0x656001c6,0x9b4400ec,0xa2bc00cd}},	//   _bugh, _ainh, _ڀنڀو, ष्म्, 
   {{0x65615b99,0x64414f78,0x65695b9a,0x7538005a}},	//   _binh, _ayni, _cugh, totz, 
   {{0x1cc8003d,0x65600399,0x7640019f,0x32d4001e}},	//   _ཉིས_, _cinh, _vyoy, _ủy_, 
   {{0x65615b9b,0x644000a9,0x753801c0,0x656800a3}},	//   _dinh, _cyni, rotz, _eugh, 
   {{0x65615b9c,0x6440018b,0x753805f5,0x656808e5}},	//   _einh, _dyni, sotz, _fugh, 
   {{0x76406f4f,0x656805d5,0x65601f53,0xe60c01b9}},	//   _uyoy, _gugh, _finh, _لشو_, 
   {{0xc0e4069c,0x65615b9d,0x64400194,0x00000000}},	//   _ምበር_, _ginh, _fyni, --, 
   {{0x6440e57d,0x6f1c01b9,0xdfd4084c,0x00000000}},	//   _gyni, tiqc, моры, --, 
   {{0x65615b9e,0x65685867,0x23240166,0x00000000}},	//   _zinh, _yugh, _офыг, --, 
   {{0x65615b9f,0x6f1d5ba0,0x64401f0c,0xec683594}},	// [23650] _yinh, riqc, _zyni, арек_, 
   {{0x65615ba1,0x61e00008,0x777802d0,0xa2bc215d}},	//   _xinh, æmle, _ottx, ष्ठ्, 
   {{0x690c9069,0x48c400c7,0x00000000,0x00000000}},	//   _høeg, ҟәаа, --, --, 
   {{0x98fc008f,0xfbdc00d8,0x8cb801d9,0x437800d1}},	//   _riĉa, _drª_, _گگرس_, ﻠﺪﯨﻦ_, 
   {{0xed5831f3,0x48e4084c,0xda780845,0x69c801a4}},	//   _نشست_, золв, цях_, uwge, 
   {{0x65695ba2,0x69c80036,0x67380100,0xe6c000cd}},	//   _rugh, rwge, wouj, वज्ज, 
   {{0xa2ac05ba,0x65695ba3,0x65615ba4,0x07a42a30}},	//   _झाल्, _sugh, _rinh, чайн, 
   {{0x65615ba5,0x65695ba6,0x98fc01e4,0x06e8694c}},	//   _sinh, _pugh, _viĉa, смик_, 
   {{0x64415ba7,0x65615ba8,0x6568047e,0x6f7c0150}},	//   _syni, _pinh, _qugh, _ﺩﻨﻴﺎ_, 
   {{0x64400652,0xd874005e,0x65695ba9,0x67b81867}},	//   _pyni, _قامب, _vugh, _ناصح_, 
   {{0x65615baa,0x656801f2,0xdb500014,0x74e401c6}},	//   _vinh, _wugh, _سَے_, чдэг_, 
   {{0x6440be62,0x65695bab,0x48f400bc,0x7c1400df}},	//   _vyni, _tugh, ्सको_, פֿיע_, 
   {{0x65615bac,0x6440006d,0xd1741075,0x224c0210}},	//   _tinh, _wyni, дысы, ędko_, 
   {{0xdb1c0ffb,0x64415bad,0x97c40150,0x9f5800e4}},	//   _aprì, _tyni, _ءتەم, kyrã_, 
   {{0xafe1459b,0x64415bae,0x00000000,0x00000000}},	//   норл, _uyni, --, --, 
   {{0xf2dc0b21,0x00000000,0x00000000,0x00000000}},	//   llân_, --, --, --, 
   {{0x2fdc0421,0x57b801ad,0xb21801bf,0x9f5800e4}},	// [23660] āuga_, _आह्ह, lbæn, tyrâ_, 
   {{0xe09413f9,0xf2dc0b21,0xe164141d,0x00000000}},	//   _زیرخ, nlân_, _تضعی, --, 
   {{0x5fe0515b,0x7f44023a,0xf2dc045f,0x00000000}},	//   _पछिल, _неож, ilân_, --, 
   {{0xf2dc0142,0x00000000,0x00000000,0x00000000}},	//   hlân_, --, --, --, 
   {{0x58d401c0,0xf2dc000f,0x9f580124,0x00000000}},	//   долт, klân_, pyrâ_, --, 
   {{0xed555baf,0xf2dc045f,0x9f5800e4,0x00000000}},	//   _ноя_, jlân_, byrã_, --, 
   {{0xf2dc000f,0x2ca404d4,0xd0440213,0x00000000}},	//   dlân_, ónde_, _bahə, --, 
   {{0x7e740857,0x1de001bc,0xeb5000cf,0x00000000}},	//   ncyp, निपत, _كۉلگ, --, 
   {{0x963429c3,0xb1780158,0xca74009d,0x0ae8009f}},	//   ьниц, mvåg, _цусы, _ظرفي_, 
   {{0xb1780158,0x690c0fac,0xd2500133,0x00000000}},	//   lvåg, _røeg, ێند_, --, 
   {{0x53344c49,0x3634b5e0,0xb21801bf,0xdc0000eb}},	//   дент, _کراس, gbæn, _এইডস_, 
   {{0x91b80395,0x00000000,0x00000000,0x00000000}},	//   огмт_, --, --, --, 
   {{0xaef808c2,0x644c012d,0x00000000,0x00000000}},	//   _diùl, ęcia, --, --, 
   {{0xa5f4013e,0xa1640114,0x9f5800e4,0xdef800c7}},	//   _хешу_, ењск, yyrã_, ҿыу_, 
   {{0xdb1d5bb0,0x3b04013c,0x6b600241,0xaf055bb1}},	//   _aprí, kkoq_, _jìgì, пчак, 
   {{0xdb1c00c6,0xaef80e89,0x9f5800e4,0x00000000}},	//   _bprí, _giùl, vyrã_, --, 
   {{0x98fc0115,0xd250007b,0xb178248f,0xe29c00d9}},	// [23670] _niĉo, _جنة_, dvåg, _השחר, 
   {{0xc0e80092,0xec68010b,0x9f5800c7,0x656c01e7}},	//   መታል_, срак_, tyrã_, íchi, 
   {{0xeff402d3,0x5eb40154,0x00b8011a,0x00000000}},	//   _ወግዒ_, ুয়ে, _ומתמ, --, 
   {{0xa3d107c7,0xb1780158,0x9f580022,0xeea80108}},	//   _सैफ_, gvåg, ryrã_, _уток_, 
   {{0xf2dc0b21,0xd04406be,0xa3d00456,0x29640798}},	//   ylân_, _rahə, _सैन_, чњев, 
   {{0xd0440cc1,0x9f5807dd,0x92e80154,0x00000000}},	//   _sahə, pyrã_, _যতো_, --, 
   {{0xf8ac3345,0x5d540798,0x00000000,0x00000000}},	//   شکل_, _чкрт, --, --, 
   {{0xfbd00302,0x88cc0154,0x7b2c00df,0xcb0800e3}},	//   _בתל_, লাইক, nĝul, _بيرن_, 
   {{0xf2dc0b21,0x00000000,0x00000000,0x00000000}},	//   tlân_, --, --, --, 
   {{0x15f4033f,0x6b400124,0x00000000,0x00000000}},	//   ेनजर_, rõgu, --, --, 
   {{0xf2dc0225,0x5804030c,0xef1c0205,0x7e740210}},	//   rlân_, _كوكك, _omü_, ycyp, 
   {{0x6f0000a8,0xf2dc0b21,0xdb1c010e,0xd36c00db}},	//   _înch, slân_, _osrý, حۇي_, 
   {{0xf2dc002d,0x7af401f4,0x00000000,0x00000000}},	//   plân_, öyti, --, --, 
   {{0x3f680f06,0x29052542,0x03a400d8,0x00000000}},	//   живо_, nkna_, _жико, --, 
   {{0xdb1c01f1,0x2904a5b4,0x00000000,0x00000000}},	//   _sprí, ikna_, --, --, 
   {{0x2904000d,0xfca800ec,0x00000000,0x00000000}},	//   hkna_, ڪارو_, --, --, 
   {{0x88c400bc,0x29055bb2,0xcdc55bb3,0xef140212}},	// [23680] _změř, kkna_, натқ, єму_, 
   {{0xed5400c7,0x98fc0115,0xef1c00c5,0x7b2c00df}},	//   доу_, _riĉo, _emü_, aĝul, 
   {{0xb1780158,0x88d4002b,0xbe6801c6,0xb538010f}},	//   tvåg, _mṛdv, _манж_, קגעש, 
   {{0x9d9802d3,0xdb1c054e,0x606407d2,0xfe70007b}},	//   ጎነጻዊ_, _sprâ, _يۇڭل, _جدد_, 
   {{0xfe40066d,0xb178019b,0x8b642928,0x850c07f7}},	//   _شکری, rvåg, رامم, ाघाट_, 
   {{0xb17805ac,0x715c0882,0x2d4c00fd,0x00000000}},	//   svåg, _kīdṛ, lüen_, --, 
   {{0x3f6800df,0x3b080276,0x00000000,0x00000000}},	//   _iĝus_, _дево_, --, --, 
   {{0x29040254,0x7d0c00d7,0x00000000,0x00000000}},	//   akna_, _hlbs, --, --, 
   {{0xf7700d62,0x88c400bc,0x00000000,0x00000000}},	//   راں_, _směř, --, --, 
   {{0x290401e6,0x8cc046fb,0x79815b23,0x37e400cf}},	//   ckna_, र्पो, mpow, _оозг, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe3ac4c12,0x7bdc0254,0x00000000,0x00000000}},	//   گری_, ivpu, --, --, 
   {{0x79815bb4,0x6f000311,0x00000000,0x00000000}},	//   npow, _înci, --, --, 
   {{0xe3ac6813,0x3370014b,0x00000000,0x00000000}},	//   دری_, _иҳор, --, --, 
   {{0xe450010a,0x00000000,0x00000000,0x00000000}},	//   _икшы, --, --, --, 
   {{0xa3d84196,0x7d0c7b58,0x63b40419,0x8cc00055}},	//   ठिर_, _albs, žaní, र्नो, 
   {{0xdd955bb5,0x7b2c0115,0x79800210,0x00000000}},	// [23690] каты, rĝul, jpow, --, 
   {{0x09bc04c5,0x2fd0056a,0xcf900a81,0x7980033f}},	//   _ইছলা, _tsxg_, _مژر_, dpow, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7d0c002f,0xb178005c,0x00000000,0x00000000}},	//   _elbs, mvåb, --, --, 
   {{0x7bd8009b,0x00000000,0x00000000,0x00000000}},	//   _štut, --, --, --, 
   {{0x1cc8025c,0x290400d5,0x98c400d1,0x00000000}},	//   _ཉིག_, ukna_, نغىن, --, 
   {{0xdee802d3,0xfd64002b,0x29041427,0xc48400c7}},	//   መዓኒ_, _nisṛ, rkna_, ҭлик, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x98fc01e4,0x056400a8,0xfaec01e2,0x00000000}},	//   _miĉj, нвин, _دګل_, --, 
   {{0x04b40364,0xe7848c96,0xa3d00412,0xb2188ecc}},	//   хсия, _жудо, _सईद_, rbæl, 
   {{0x8cc01fe5,0xdb1c067c,0x644c033f,0x7bd801d3}},	//   र्यो, _isrò, ęcio, _átut, 
   {{0x3f9c7663,0xdee80023,0x00000000,0x00000000}},	//   átum_, መዓና_, --, --, 
   {{0xafe001d5,0x00000000,0x00000000,0x00000000}},	//   қотл, --, --, --, 
   {{0x656c52bd,0x8cc0cc41,0x6f0c02d0,0x715c0055}},	//   íchu, र्मो, _alcc, _pīdṛ, 
   {{0x79800034,0xb17801bf,0x00000000,0x00000000}},	//   zpow, gvåb, --, --, 
   {{0xdb1c0232,0x1cc80003,0x79815bb6,0x7d0c030a}},	//   _oprá, _ཉིང_, ypow, _slbs, 
   {{0x6da15bb7,0xada15bb8,0x2d4d5bb9,0xb8d0031c}},	// [236a0] лита, латл, rüen_, _ཐྰ_, 
   {{0xdb1c07c5,0xbd440150,0x61e514e3,0x0084004e}},	//   _sprà, رناي, _iril, _ялоо, 
   {{0x1ee800dd,0x62240150,0xb0b4008f,0x61e402d2}},	//   _ہوگی_, _سوگە, _אפיס_, _hril, 
   {{0x8cc007d0,0x60dc3421,0x2d4c004e,0xdb1c01e7}},	//   र्बो, ldrm, qüen_, _bprá, 
   {{0x7b2c0115,0x6a800354,0xc1c801ec,0x00000000}},	//   lĝuk, улча, _ﺑﻴﺪﺍ, --, 
   {{0x3eb00209,0x7d0c54fb,0x39e001e0,0x00000000}},	//   lgyt_, _ulbs, _ҡәлғ, --, 
   {{0x7980f9ac,0xfaa40953,0xb7655bba,0x96f95bbb}},	//   spow, _паво, нтий, дейт_, 
   {{0x61e4110e,0x3eb0005b,0x644c0210,0x00000000}},	//   _oril, ngyt_, ęcil, --, 
   {{0x596402dd,0xfd64002b,0x00000000,0x00000000}},	//   _анағ, _sisṛ, --, --, 
   {{0xe9d400d6,0xe9a405d9,0xdb1c0332,0x280016d9}},	//   _яку_, _سگهن_, _tsró, írná_, 
   {{0xdb1c038e,0xe60c2be7,0x247c0270,0xc7940166}},	//   _zprá, لشی_, _sāmé_, _арчы, 
   {{0x61e55bbc,0x201805b1,0xfd6400dc,0x00000000}},	//   _bril, dzri_, _visṛ, --, 
   {{0x61e401e3,0x8cc03885,0x00000000,0x00000000}},	//   _cril, र्डो, --, --, 
   {{0x2ee95bbd,0x5f24013e,0x61e45c66,0xb2180388}},	//   _sncf_, ҳфуз, _dril, lbæk, 
   {{0x61e4102e,0xe9fc0016,0x35a40c2e,0xb4bc0d01}},	//   _eril, _khảo_, _खिड़, ुजी_, 
   {{0x61e42d62,0xb17801bf,0xa3bc5219,0x5ff401ec}},	//   _fril, rvåb, ुबर_, ызсу, 
   {{0x6ca49e78,0x2d4c04cc,0x2f0400c5,0x5f444363}},	// [236b0] ереж, büel_, _jõgi_, انقل, 
   {{0xd01000db,0xdca40114,0x00000000,0x00000000}},	//   _ەلگ_, лађи, --, --, 
   {{0xdb1c0745,0xab683669,0xbff00b8d,0x8f340124}},	//   _sprá, سحاق_, _күрш, _аенц, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb21801bf,0x2d4c0139,0x00000000,0x00000000}},	//   dbæk, lüem_, --, --, 
   {{0x200c0a64,0xefe8001f,0x25840ca8,0x20f4010e}},	//   ødig_, መጣው_, _lílò_, _işiñ_, 
   {{0x589400c6,0xcc080014,0x8cc00b02,0x3d2401e1}},	//   اجهز, _غٲرن_, र्णो, _wíwè_, 
   {{0xbb34005e,0xe9fc01fb,0xb21808a5,0x25840248}},	//   ﺗﯩﻦ_, _chảo_, rbæj, _nílò_, 
   {{0x6f000276,0xaef80192,0x6d440327,0xdbcc0162}},	//   _încu, _ciùi, _kkja, _hóða, 
   {{0xaef800a3,0x61e4031c,0xdbcc032e,0x437400db}},	//   _diùi, _rril, _kóða, кумт, 
   {{0x61e55bbe,0x67a4007b,0x03a401f0,0x78f800df}},	//   _sril, _سحاق, ъино, _קלעפ, 
   {{0xdbcc0413,0x8cc01a47,0x3f9c00d7,0x00000000}},	//   _móða, र्तो, štuk_, --, 
   {{0x6d455bbf,0xc0dc0023,0x2d4c0790,0xdb0801d3}},	//   _okja, _ሕሱር_, tüel_, élés, 
   {{0xb140656c,0x61e53938,0x00000000,0x00000000}},	//   инял, _vril, --, --, 
   {{0x63c001e0,0x200c772a,0x8fc40124,0x00000000}},	//   _сайҡ, ádi_, ларҵ, --, 
   {{0x61e55bc0,0x6d440054,0x05c401ad,0x00000000}},	//   _tril, _akja, _वहाब, --, 
   {{0x61e55bc1,0x00000000,0x00000000,0x00000000}},	// [236c0] _uril, --, --, --, 
   {{0xc0041eed,0xac8001fe,0x71f800e5,0xcdf4008e}},	//   _апок, игул, _آرٹس_, ычсы, 
   {{0xeb955bc2,0xdbcc0005,0x2464016b,0xb3740092}},	//   вих_, _póña, nɑm_, _የቡድን_, 
   {{0xfaa55a03,0x00000000,0x00000000,0x00000000}},	//   тадо, --, --, --, 
   {{0x8ac40220,0xada00354,0xe9704fde,0x00000000}},	//   ықта_, _каял, لهند, --, 
   {{0x8cc02c2e,0x2f2401e1,0xddc800e5,0x00000000}},	//   र्दो, _tìgè_, _élőh, --, 
   {{0xdbcc05a4,0xaef801c3,0x9f5820e5,0x1de000cd}},	//   _góða, _siùi, pyrä_, निवत, 
   {{0xdb1d42f4,0x98fc00df,0x9f583402,0x80a000cd}},	//   _spræ, _miĉi, byrå_, कृते, 
   {{0xaa44516c,0xab247a9c,0x6d44010b,0x00000000}},	//   _апта_, _рота_, _ykja, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x58fc003d,0xe9fc07ae,0x92955bc3,0x823c001f}},	//   _དྭགས_, _thảo_, ланц, _ያስረዳ, 
   {{0x387c0109,0x76255bc4,0xaee00055,0x00000000}},	//   _hftr_, _имез, _paṭe, --, 
   {{0x46b002dd,0xe9fc0051,0x00000000,0x00000000}},	//   _اڭىس, _khạo_, --, --, 
   {{0xe3ac05d9,0xdb1c005c,0xa3d000cd,0x00000000}},	//   _ڀري_, _upræ, _सैव_, --, 
   {{0x64c000db,0x3e480064,0xb9fc00b8,0x64a00114}},	//   _ئيىل, _lėtą_, _vāṅ_, _таја, 
   {{0x6d455bc5,0x9258036b,0x7a2401a9,0xdbcc03b2}},	//   _skja, _пайт_, _mаtb, _róða, 
   {{0x2d8d5bc6,0x1de000dc,0xdbcc08ce,0x7bd800d7}},	// [236d0] ège_, निषत, _sóða, _štup, 
   {{0x48bc015b,0x9d14084c,0xe9fc0208,0x7a0800de}},	//   _আফ্র, адуч, _nhạo_, _mētā, 
   {{0xf1bc0548,0x7a08005f,0x00000000,0x00000000}},	//   ltá_, _lētā, --, --, 
   {{0xf2dc2776,0x00000000,0x00000000,0x00000000}},	//   ndâ_, --, --, --, 
   {{0xf1bd5bc7,0x690c08cb,0x8afc0118,0x00000000}},	//   ntá_, _døen, _jiři, --, 
   {{0x6d442e95,0xf1bd5bc8,0x2464013f,0xe9fc0051}},	//   _ukja, itá_, yɑm_, _chạo_, 
   {{0x1864001f,0x6d400010,0xf1bc0332,0x06742081}},	//   _ሲናገር_, čnad, htá_, лупя, 
   {{0xdb5800db,0x00000000,0x00000000,0x00000000}},	//   _аюу_, --, --, --, 
   {{0x7c2001e4,0x00000000,0x00000000,0x00000000}},	//   ĝore, --, --, --, 
   {{0x6380039b,0x4991104b,0x00000000,0x00000000}},	//   аҳка, _نیچر, --, --, 
   {{0xf1bd5bc9,0x06c403d4,0xd7c8004b,0x855400e5}},	//   etá_, _শোণি, _ټونه_, نیچر_, 
   {{0xd838084c,0x98fc010f,0x82f406ed,0xc59400d8}},	//   _рэу_, _riĉi, учоц, _бидј, 
   {{0xa3d013b4,0x81bc03d4,0xb178007c,0x00000000}},	//   _सैर_, ীয়ন_, tvåa, --, 
   {{0x3ea00a2e,0x66180921,0x25bc0311,0x41281468}},	//   _sdkt_, mzuk, mtul_, хого_, 
   {{0x3f9d5bca,0x3ea025a9,0x25bd5bcb,0x7f580120}},	//   étu_, _pdkt_, ltul_, ејат_, 
   {{0x26dd0eab,0x25bd4fd6,0x661801f7,0x8cc007f7}},	//   nduo_, otul_, ozuk, र्सो, 
   {{0x66195bcc,0x25bc0262,0x1cc81f21,0xf1bd5bcd}},	// [236e0] nzuk, ntul_, _ཉིད_, ctá_, 
   {{0x25bd5bce,0xa3c4772c,0x98fc01e4,0x661801c4}},	//   itul_, _उहा_, _tiĉi, izuk, 
   {{0x25bd5bcf,0xb1780267,0x26dc0115,0x6618002f}},	//   htul_, nvån, kduo_, hzuk, 
   {{0x3ea0013e,0x20c001ad,0x2fc4035b,0xdb1c005c}},	//   _udkt_, श्रध, _ãnga_, _oprå, 
   {{0x25bc2a6d,0xeb301411,0x00000000,0x00000000}},	//   jtul_, حىند, --, --, 
   {{0x6f00084c,0xe89007dd,0xdb1c01e6,0x66180bd7}},	//   _încr, башь, _sprä, dzuk, 
   {{0x25bc0311,0x7a0800ef,0x00000000,0x00000000}},	//   etul_, _sētā, --, --, 
   {{0xf1bd5bd0,0x75883580,0x25bc0311,0x0b5802dd}},	//   ytá_, нсов_, ftul_, _аруы_, 
   {{0x1514ad0e,0x8cc12a39,0x163458d5,0xe9fc01fb}},	//   идия, र्वो, репя, _thạo_, 
   {{0x7a24022e,0x05a4000d,0x1dac000d,0x00000000}},	//   _tаtb, _गटरब, _चिनत, --, 
   {{0x1cc81efe,0x25bd4fd6,0xb6a405f5,0x77855bd1}},	//   _ཉིན_, atul_, _биел, _слез, 
   {{0xf1bc28be,0x6ee8013d,0x25bc0356,0x00000000}},	//   ttá_, _möbä, btul_, --, 
   {{0x25bc00a8,0xd4c40daf,0x66180210,0x00000000}},	//   ctul_, _көнк, czuk, --, 
   {{0xf1bc45a7,0x9f58035b,0x00000000,0x00000000}},	//   rtá_, pyrû_, --, --, 
   {{0xf1bc2195,0xe4780302,0xa1593a70,0x00000000}},	//   stá_, _ארוכ, уару_, --, 
   {{0xaef800a3,0xf1bc749a,0x00000000,0x00000000}},	//   _niùt, ptá_, --, --, 
   {{0x690c0158,0xf1bc011f,0xd25000e5,0x00000000}},	// [236f0] _bøel, qtá_, _گچھ_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa2bc1db2,0x66195bd2,0x8c18007b,0xb068009d}},	//   ष्क्, zzuk, خيار_, _яриж_, 
   {{0x78b80393,0x26dc0076,0x25bc0de2,0xb3b403d4}},	//   _actv, xduo_, ytul_, _জনাজ, 
   {{0x3a700348,0x25bc0276,0xaef801ab,0x09cc00eb}},	//   әләр, xtul_, _diùt, লিভা, 
   {{0x78b802d0,0x48e425ea,0x00000000,0x00000000}},	//   _cctv, рокв, --, --, 
   {{0xdb1cb2e3,0x6ee80166,0x26dc0fac,0xdc68014b}},	//   _språ, _göbä, tduo_, _баёд_, 
   {{0x25bd5bd3,0x661801c0,0x46e92ddb,0xaef800a3}},	//   ttul_, tzuk, тдин_, _dhùg, 
   {{0xa8a55bd4,0x25bc054e,0x6ee8013d,0x00000000}},	//   _брек, utul_, _zöbä, --, 
   {{0x25bc00a8,0x66190f44,0xdb1c000f,0x699400c7}},	//   rtul_, rzuk, _oprû, _арҧх, 
   {{0x25bd5bd5,0x6618006d,0x47d400c6,0x00000000}},	//   stul_, szuk, _خيار, --, 
   {{0x25bc0262,0xb178049f,0x15c00131,0x00000000}},	//   ptul_, rvån, _ﻣﻪﺩﻩ, --, 
   {{0x16840032,0xaef800a3,0x25bc025c,0xb178007c}},	//   _уҡый_, _liùs, qtul_, svån, 
   {{0x36180a1e,0x98a0110c,0x69d80200,0x00000000}},	//   _בונד, đić_, _msue, --, 
   {{0x657924c3,0xdc340419,0xbf64007b,0xc39401af}},	//   lquh, _súľo, لدرو, _тјлњ, 
   {{0x257805c7,0x69d8aec3,0xd3b800d4,0x00000000}},	//   _kêl_, _osue, _суші_, --, 
   {{0xbe6801c6,0x00000000,0x00000000,0x00000000}},	// [23700] тааж_, --, --, --, 
   {{0x8cc007b7,0x2fdc033f,0x257836db,0x3198011a}},	//   र्लो, ługa_, _mêl_, _שבינ, 
   {{0x69d95bd6,0xcdc40220,0x212800f1,0x00000000}},	//   _asue, _қарқ, _ليکی_, --, 
   {{0x1cc80dd4,0x8b655bd7,0x0ba80137,0x2fc400c7}},	//   _ཉིམ_, مانم, االى_, _änga_, 
   {{0xaef800a3,0xe9dc00d7,0x78b80171,0xae34014b}},	//   _shùg, _šúr_, _pctv, _кӯфт_, 
   {{0x6ee80598,0x82f4031c,0xb2180252,0x4d140108}},	//   _töbä, _བོའུ_, mbæt, _льст, 
   {{0xf090025f,0xeb949b70,0x3208033f,0x69d80356}},	//   חנו_, _вис_, zycy_, _esue, 
   {{0xaef801ab,0x98fc010f,0x257803cb,0x7bcc02d0}},	//   _hiùr, _riĉu, _bêl_, _ipbu, 
   {{0x7ae15bd8,0x00000000,0x00000000,0x00000000}},	//   mdot, --, --, --, 
   {{0x7ae0420d,0x25780142,0xf4e801b9,0xdb500244}},	//   ldot, _dêl_, тфий_, _بێڵ_, 
   {{0x7ae00393,0x00000000,0x00000000,0x00000000}},	//   odot, --, --, --, 
   {{0xaef800a3,0x25780042,0x3208033f,0xefe80023}},	//   _liùr, _fêl_, tycy_, ዘባዊ_, 
   {{0xc76400f7,0x7ae01ebf,0x7b2c010f,0xf48401a9}},	//   _االى, idot, lĝus, _куйн, 
   {{0x7ae15bd9,0x7bcc002d,0xadc00051,0x32080210}},	//   hdot, _opbu, _nhạc, rycy_, 
   {{0x7ae15bda,0x3328000f,0xf9fc0154,0x06d80154}},	//   kdot, picx_, ্ছিল_, থারি, 
   {{0x09cc0729,0xbd64001f,0x23f80a7c,0xb28418bc}},	//   লিতা, ታወቅም_, _יהוא, _тыкк, 
   {{0x7ae15bdb,0xaef801c3,0x7bcc00de,0x00000000}},	// [23710] ddot, _biùr, _apbu, --, 
   {{0x30a55bdc,0x6ab95bdd,0xaef801c3,0xc0c02751}},	//   _трив, _scuf, _ciùr, _нәси, 
   {{0xec6844c1,0xaef808c2,0x7ae001c7,0xd1d00023}},	//   трак_, _diùr, fdot, _ብኣቦ_, 
   {{0x69d80036,0x3e6c0588,0x00000000,0x00000000}},	//   _psue, _ẽte_, --, --, 
   {{0xa2bc10fa,0xaef800a3,0x09e43cd7,0x7c200115}},	//   ष्ट्, _fiùr, солн, ĝora, 
   {{0x5f7405bd,0x7ae140f7,0xdd9405a2,0x00000000}},	//   _دایر, adot, _фары, --, 
   {{0x98fc0115,0x7ae0014f,0x257803cb,0x00000000}},	//   _riĉt, bdot, _sêl_, --, 
   {{0x49745c9e,0x65780cfe,0x25780368,0xfc440030}},	//   _глас, tquh, _pêl_, číta_, 
   {{0x69d8a50c,0x3ea400e8,0xda0801e2,0x00000000}},	//   _usue, óoti_, _پيله_, --, 
   {{0x6578039a,0x7c340174,0xb17801e3,0x940c03b9}},	//   rquh, _ágrý, rvål, ladə_, 
   {{0x81bc0183,0x2b5d5bde,0x25780042,0xb934010f}},	//   ীয়া_, _khuc_, _wêl_, _פרעג_, 
   {{0xdb1d5bdf,0x7a24022e,0x00000000,0x00000000}},	//   _sprú, _mаtn, --, --, 
   {{0x2b5c0afe,0xbb38010f,0xc7a4010a,0x00000000}},	//   _mhuc_, רערי, _виçк, --, 
   {{0x68e0044e,0xa068054a,0x00000000,0x00000000}},	//   ndnd, ғаға_, --, --, 
   {{0x7ae00036,0x00000000,0x00000000,0x00000000}},	//   ydot, --, --, --, 
   {{0xaef800a3,0xc0e4001f,0x2b5c0208,0x98bc0064}},	//   _siùr, ምቤላ_, _nhuc_, movą_, 
   {{0x63a00083,0xaef801ab,0xadc00051,0x7ae0022e}},	// [23720] _hvnn, _piùr, _phạc, vdot, 
   {{0xaef801c3,0x63a00139,0x3f9c01d3,0x312000db}},	//   _chùb, _kvnn, átus_, _ндыг, 
   {{0x940c0cc1,0x23600218,0xaef801c3,0xe9fc0cad}},	//   fadə_, _khij_, _dhùb, _iyẹn_, 
   {{0x7ed4911b,0xb21809cc,0x6b80c476,0x2b5d5be0}},	//   _ازدا, mbær, ínga, _chuc_, 
   {{0x7ae15be1,0xd9106676,0x59f8722e,0xadc0001e}},	//   rdot, ویر_, реля_, _thạc, 
   {{0x7ae15be2,0x628401ab,0x81a8009e,0x98bc0153}},	//   sdot, _lfio, _গঙা_, kovą_, 
   {{0x62855be3,0xdb1c037e,0xb21888d9,0x7bcc0051}},	//   _ofio, _oprø, nbær, _upbu, 
   {{0x98bc0024,0xa3c80073,0x569400c7,0x00000000}},	//   dovą_, रझन_, әаҿт, --, 
   {{0x35455be4,0x63a0022e,0x00000000,0x00000000}},	//   йхов, _avnn, --, --, 
   {{0x6284096b,0x00000000,0x00000000,0x00000000}},	//   _afio, --, --, --, 
   {{0xdb1c00a3,0x2ca41d0e,0x00000000,0x00000000}},	//   _sprù, óndi_, --, --, 
   {{0x2360dfd2,0x2284016c,0xaef801c3,0xb21812e8}},	//   _chij_, зург, _mhùc, dbær, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x77795be5,0x3e6000b0,0xd7dc0490,0x940c00ac}},	//   _kutx, _mōtī_, _मनाच, zadə_, 
   {{0x5f940262,0xb38423bb,0xd044013f,0x62840368}},	//   зист, _اجته, _nahɔ, _ffio, 
   {{0x7778db09,0x2360014f,0x62840076,0x00000000}},	//   _mutx, _ghij_, _gfio, --, 
   {{0x3f9c08a7,0x7778009d,0xaef801ab,0xcc980114}},	// [23730] átur_, _lutx, _phùb, ивац_, 
   {{0x4f840014,0x00000000,0x00000000,0x00000000}},	//   _واجہ, --, --, --, 
   {{0x2b5c001e,0xceb800d1,0x7a2401a9,0x8bd81797}},	//   _phuc_, _вәз_, _qаtn, рмес_, 
   {{0x8afc00bc,0x4a5400f3,0x00000000,0x00000000}},	//   _ohře, окес, --, --, 
   {{0xdea55be6,0xaef800a3,0xa9c55be7,0x5b2400c7}},	//   _ریلی, _thùb, ссек, џьха, 
   {{0x77789aa1,0xede401d5,0x200c002f,0x7bc80327}},	//   _butx, _кўҳн, ädig_, ħfur, 
   {{0x2b5c001e,0x87f801c0,0xfd4401d3,0x00000000}},	//   _thuc_, рэлт_, _بیلٹ_, --, 
   {{0x05a95be8,0x77782be5,0x613001e1,0x00000000}},	//   авий_, _dutx, _kólè, --, 
   {{0xbd54168d,0x19955be9,0x8afc013a,0x8bc8000d}},	//   _درێژ, _натя, _chře, _रहुअ, 
   {{0x62855bea,0xdb1c1088,0x9a8801d9,0x452867ba}},	//   _sfio, _sprø, _ننہٕ_, ржон_, 
   {{0x77780323,0x23600218,0xbb4c02d3,0x62840129}},	//   _gutx, _phij_, _ንኣባላ, _pfio, 
   {{0x98bc0064,0x00000000,0x00000000,0x00000000}},	//   rovą_, --, --, --, 
   {{0x69cc014a,0x00000000,0x00000000,0x00000000}},	//   _äced, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x23600218,0x3e6002b5,0xafe001b9,0x7cd8179e}},	//   _thij_, _mōtū_, морл, یورز_, 
   {{0x6284014b,0xb2185cf2,0x7a24022e,0x2240005a}},	//   _ufio, rbær, _bаtl, _txik_, 
   {{0x6d400306,0x00000000,0x00000000,0x00000000}},	// [23740] čnan, --, --, --, 
   {{0x0d080116,0xc0cc0023,0x59b8012d,0x00000000}},	//   бдуқ_, _ብቓሉ_, उंसर, --, 
   {{0x67295beb,0xd1d00023,0x00000000,0x00000000}},	//   _omgj, _ብኣቶ_, --, --, 
   {{0x39e95bec,0xe60473c9,0x7a24022e,0x00000000}},	//   идео_, _قش_, _qаto, --, 
   {{0x2d4c8d22,0xa3b80034,0xbb50037e,0xd839107e}},	//   gües_, इंड_, _proケ_, _meče_, 
   {{0xd838596b,0xf1bc00dd,0x77787c3f,0x37a95bed}},	//   _leče_, szág_, _putx, атин_, 
   {{0xe78000f1,0x00000000,0x00000000,0x00000000}},	//   ولوپ, --, --, --, 
   {{0xfb155bee,0xd8380301,0xb5a47c3f,0x00000000}},	//   _بورج, _neče_, орой, --, 
   {{0xb17802bf,0x8cc01a4e,0x96342f59,0x00000000}},	//   rvåk, र्को, яниц, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa4203419,0x2474001f,0xb178003b,0x7b2c01e4}},	//   дьял, _በዓመት_, pvåk, nŝuo, 
   {{0x06640502,0x00000000,0x00000000,0x00000000}},	//   _کامپ, --, --, --, 
   {{0xceb80184,0x7760014b,0x3634f85d,0xa194008e}},	//   ҙән_, _ihox, _براس, маяч, 
   {{0x7528014b,0xc0cc0023,0x7b2c01e4,0x81780107}},	//   _umfz, _ብቓል_, kŝuo, сарӣ_, 
   {{0xe828044e,0xaf0400a7,0xf2e4011c,0x00000000}},	//   _እንተነ, очак, _дюпо, --, 
   {{0xd6ac00bd,0xdfd0004b,0x3e6c0124,0x23280063}},	//   ক্রয, کيې_, _ẽta_, _моји_, 
   {{0x2d4c0c86,0x753801c6,0x7a2401a9,0x00000000}},	// [23750] düer_, ontz, _qаtl, --, 
   {{0xa128007b,0x00000000,0x00000000,0x00000000}},	//   _وكيل_, --, --, --, 
   {{0x753801c0,0x8cc0687b,0x00000000,0x00000000}},	//   intz, र्गो, --, --, 
   {{0x7760004d,0x00000000,0x00000000,0x00000000}},	//   _nhox, --, --, --, 
   {{0x9e840345,0x00000000,0x00000000,0x00000000}},	//   _تاپۆ, --, --, --, 
   {{0xb5c002a6,0x77615bef,0x00000000,0x00000000}},	//   ্টাচ, _ahox, --, --, 
   {{0x480853d9,0x46a40107,0x98bc0064,0x00000000}},	//   сейн_, пайв, novę_, --, 
   {{0x753805f5,0x7b2c01e4,0x77615bf0,0x46a40108}},	//   entz, nŝul, _chox, чаив, 
   {{0xd8383116,0x00000000,0x00000000,0x00000000}},	//   _reče_, --, --, --, 
   {{0x77600117,0xd838009b,0x00000000,0x00000000}},	//   _ehox, _seče_, --, --, 
   {{0xd8384b16,0x98bc00c0,0x00000000,0x00000000}},	//   _peče_, jovę_, --, --, 
   {{0x96b95bf1,0x753801c6,0x7760031c,0x2d8800bc}},	//   _душу_, antz, _ghox, _otce_, 
   {{0xd838597f,0x52755bf2,0xa3b41414,0x75380175}},	//   _veče_, дуру, _चमक_, bntz, 
   {{0x212c01ab,0x673844ef,0x00000000,0x00000000}},	//   òdh_, lnuj, --, --, 
   {{0x2fd00005,0x44201654,0xd258005f,0x660c0267}},	//   _cpxg_, _åh_, ļņa_, äckf, 
   {{0x67395bf3,0x06d803d4,0x77600200,0x00000000}},	//   nnuj, থাকি, _xhox, --, 
   {{0xb2b80302,0xcdc400d1,0x2d880356,0x7f540857}},	// [23760] _המפר, матқ, _ctce_, rlyq, 
   {{0xd3a4010b,0x9cb40137,0x00000000,0x00000000}},	//   _эрәп, بۅست, --, --, 
   {{0x2d88003a,0x30780375,0x5fb0007a,0x656c0306}},	//   _etce_, _לאינ, _जटिल, íchy, 
   {{0x0ba8c947,0x4dd402dd,0x67393fb4,0xd044009f}},	//   زامى_, _ﺟﻴﯩﻨ, jnuj, _آپٽي, 
   {{0x67380e3c,0xaef8004d,0x2d4c05d5,0x00000000}},	//   dnuj, _khùn, rüer_, --, 
   {{0x7760036b,0xf80402bf,0x00000000,0x00000000}},	//   _shox, зчин, --, --, 
   {{0x7760022f,0x1cdc031c,0x764003b9,0x00000000}},	//   _phox, _རྒར_, _sxoy, --, 
   {{0x383002d3,0x6738239b,0x35680d31,0x00000000}},	//   _ክንርእ, gnuj, әрин_, --, 
   {{0x24800092,0x24a40092,0xaa9401af,0x00000000}},	//   _ከአራት_, _ለአራት_, _хѳсә, --, 
   {{0xeaac0014,0x753801c4,0xaef80051,0x29d001f7}},	//   _لٹہ_, untz, _nhùn, _سيمس, 
   {{0x52d806a6,0x28100220,0x8cc0012d,0x00000000}},	//   омню_, _كوكس, र्टो, --, 
   {{0x1dac4da4,0x7760014b,0x1cdc025c,0x684001c0}},	//   _चिंत, _uhox, _རྒལ_, _янха, 
   {{0x6f0000d2,0x79800113,0x872451ad,0xf07400d1}},	//   _líbû, nqow, _تعلم, зигә_, 
   {{0xe3ad5167,0xaef8da31,0x00000000,0x00000000}},	//   خری_, _chùn, --, --, 
   {{0xaef80e89,0xeea8008e,0x00000000,0x00000000}},	//   _dhùn, йтак_, --, --, 
   {{0xc0cc02d3,0x6d4009a8,0x64380375,0x394c0112}},	//   _ብዓል_, čnam, _לעונ, hofs_, 
   {{0x7b2c01e4,0xd130007b,0x00000000,0x00000000}},	// [23770] rŝul, _لمة_, --, --, 
   {{0x22582a1a,0x67380dfe,0xdb1c0034,0x5d5400a8}},	//   _عجيب_, znuj, _opró, екут, 
   {{0x6d540227,0x2fc40036,0x6738012d,0x00000000}},	//   rlxa, _ëng_, ynuj, --, 
   {{0xae000116,0x00000000,0x00000000,0x00000000}},	//   _كۈزى, --, --, --, 
   {{0xdb1c00dd,0xad240214,0x673802f0,0x00000000}},	//   _apró, _فرآو, vnuj, --, 
   {{0xdb1c00c6,0x98bc0118,0x6738012d,0xf8ac0ed8}},	//   _bpró, mově_, wnuj, لکم_, 
   {{0x1bd53eb2,0x98bc0118,0x673800d7,0x00000000}},	//   _поря, lově_, tnuj, --, 
   {{0xa3b8033f,0x79800139,0x673801f4,0x74c800cd}},	//   इंस_, bqow, unuj, त्सृ, 
   {{0x98bc00bc,0x66e0023b,0x673833c8,0x56340023}},	//   nově_, доқа, rnuj, _ክትክእ, 
   {{0x65600354,0x00000000,0x00000000,0x00000000}},	//   _qhnh, --, --, --, 
   {{0x67380455,0x98bc0118,0x00000000,0x00000000}},	//   pnuj, hově_, --, --, 
   {{0x26cc0223,0x98bc00bc,0xb9c80092,0x00000000}},	//   _ubgo_, kově_, _ሳቅ_, --, 
   {{0xaef801fb,0xa5e40150,0x98bc0118,0x56940137}},	//   _phùn, _ءوتە_, jově_, _чачт, 
   {{0xdb1c03fa,0x98bc00bc,0x42bc015b,0x26840244}},	//   _sprü, dově_, ইজেশ, _بڕژێ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe2780b8d,0xad4400d1,0x8cc000cd,0x98bc01ef}},	//   _эшкә_, ۈرلۈ, र्घो, fově_, 
   {{0xd8384beb,0xada043ee,0xaef8001e,0x6f0000d2}},	// [23780] _meča_, катл, _thùn, _síbû, 
   {{0x61e55bf4,0xd8380427,0x00000000,0x00000000}},	//   _isil, _leča_, --, --, 
   {{0x394c01b8,0x4424002f,0xf7f0012d,0x00000000}},	//   vofs_, nzl_, ążką_, --, 
   {{0x60dd5bf5,0xdb1c180f,0x98bc01ef,0x00000000}},	//   lerm, _aprò, bově_, --, 
   {{0xdb1c0034,0x69c01b61,0x98bc013a,0x00000000}},	//   _spró, _रमणी, cově_, --, 
   {{0x60dc32ff,0x61e4f7f4,0x28f4023a,0x79800784}},	//   nerm, _msil, дешь_, rqow, 
   {{0xd83805a1,0xe3a407c0,0x61e40083,0x60dcd866}},	//   _beča_, _جر_, _lsil, ierm, 
   {{0x60dd5bf6,0x61e55bf7,0x394d5bf8,0x00000000}},	//   herm, _osil, sofs_, --, 
   {{0x61e40083,0x1cdc031c,0x00000000,0x00000000}},	//   _nsil, _རྒོ_, --, --, 
   {{0x2fdc006d,0x7a2401a9,0x7b2c01e4,0x4a740006}},	//   ługi_, _nаti, kŝuk, _чыст, 
   {{0x61e55bf9,0x60dd5bfa,0x65900330,0xa59000d1}},	//   _asil, derm, _یجور, ىگۈچ, 
   {{0xaef801c3,0xf77000cf,0x2fc40254,0x00000000}},	//   _chùl, _شاا_, _ängi_, --, 
   {{0xa34405f5,0x61e400dd,0xf5055bfb,0xc0dc02d3}},	//   тээл, _csil, _оздо, _ሕሱም_, 
   {{0x660d5bfc,0x61e400b5,0x00000000,0x00000000}},	//   äcke, _dsil, --, --, 
   {{0xb4240014,0x57dc53a5,0x690c005c,0x1cdc0327}},	//   _تعشو, _मनोह, _køer, _རྒེ_, 
   {{0x61e40175,0x98bc00bc,0x88d4002b,0x00000000}},	//   _fsil, tově_, _hṛtv, --, 
   {{0x60dd5bfd,0x88d40a28,0x8d7800c6,0x8cf4311b}},	// [23790] berm, _kṛtv, سماء_, нзац, 
   {{0x60dd5bfe,0x98bc00bc,0x00000000,0x00000000}},	//   cerm, rově_, --, --, 
   {{0x98bc00bc,0x88d400b8,0x00000000,0x00000000}},	//   sově_, _mṛtv, --, --, 
   {{0x09d8025c,0xcd940063,0x61e40108,0x00000000}},	//   _འགྱ_, _памћ, _ysil, --, 
   {{0x61e405b1,0xee3c00a2,0xc8340023,0xc954004e}},	//   _xsil, _seýf_, _እንኮላ, нткы, 
   {{0x41b0068f,0xd83814a6,0x8c880022,0x00000000}},	//   _जिसस, _seča_, _хәаа_, --, 
   {{0xa924005f,0x38c84715,0xdc740064,0x1bb800ae}},	//   _režī, ساوی_, _агры, _يافع_, 
   {{0x060825ff,0x00000000,0x00000000,0x00000000}},	//   зник_, --, --, --, 
   {{0x60dd5bff,0x09d8025c,0xd8385160,0x9984007b}},	//   yerm, _འགྲ_, _veča_, _للقو, 
   {{0x44240112,0x846c02d3,0xaef801ab,0x69c80e78}},	//   tzl_, _ባሕርን_, _shùl, mtge, 
   {{0x60dd5c00,0x69c91fc2,0x61e4fa82,0x97a401c6}},	//   verm, ltge, _ssil, _арчл, 
   {{0x60dd5c01,0x44255c02,0x69c85b5e,0xa92400de}},	//   werm, rzl_, otge, _dežū, 
   {{0xaca0063f,0xaef808c2,0x61e4022e,0x7c2001e4}},	//   _ayọc, _chùm, _qsil, ĝori, 
   {{0xef1c145e,0x61e40219,0x69c92128,0x60dc0112}},	//   _alü_, _vsil, itge, uerm, 
   {{0x60dd5c03,0x69c95c04,0x741003e6,0x2ec8102f}},	//   rerm, htge, _مووا, ाभूत, 
   {{0x60dd5c05,0x61e55c06,0x69c80112,0xed540124}},	//   serm, _tsil, ktge, ҵоу_, 
   {{0x61e55c07,0x1cdc003d,0xb900025c,0xf770008f}},	// [237a0] _usil, _རྒུ_, _ཧྲ_, רקן_, 
   {{0xe390001f,0x69c80e78,0xece400a8,0xee3400f3}},	//   _የተሰጠ_, dtge, ндул_, хну_, 
   {{0x3ea55c08,0x69c826be,0x30980375,0x8b640116}},	//   _пинг, etge, _משימ, چانم, 
   {{0x69c95c09,0xf1bc0077,0x8b64030f,0xafe000cf}},	//   ftge, izán_, نانم, _союл, 
   {{0x69c83c38,0x6cc000d1,0x00000000,0x00000000}},	//   gtge, _әйса, --, --, 
   {{0x58d47a71,0x690c005c,0x3fc000d1,0x00000000}},	//   токт, _søer, ﺭﺧﺎﻧ, --, 
   {{0x69c95c0a,0xf0900302,0x69cc01b8,0xb1780267}},	//   atge, ננה_, _äcen, nvår, 
   {{0xf7700a81,0x3ea005ac,0x7b640014,0x29040311}},	//   ھاں_, _jekt_, _سازٕ, ajna_, 
   {{0xf7702832,0x69c80196,0xaa415c0b,0x3ce8017a}},	//   پاں_, ctge, _бетл, _kabv_, 
   {{0xb178049f,0x09cc009e,0x9f580022,0x00000000}},	//   kvår, লিখা, myrõ_, --, 
   {{0x7d0d5c0c,0x92955c0d,0x88d40055,0x00000000}},	//   _mobs, канц, _vṛtv, --, 
   {{0xb1780267,0xa6300220,0x7d0c2d61,0x3ea15c0e}},	//   dvår, _әнші, _lobs, _nekt_, 
   {{0x7d0d5c0f,0x6e386d4e,0x200c005b,0x41e80022}},	//   _oobs, _ľubo, ädin_, мырҟ_, 
   {{0xee3c00e4,0x7d0c0327,0xa5040120,0x00000000}},	//   _jeýe_, _nobs, _печа_, --, 
   {{0xef1c060a,0xdfd806bb,0x387c003a,0x69c807de}},	//   _plü_, нът_, _mgtr_, ztge, 
   {{0xb900003d,0x61187236,0xd8380010,0xe3ac16cc}},	//   _ཧི_, _ağlı, _lečo_, _ارو_, 
   {{0x3ea15c10,0x29040034,0x7d0d5c11,0xc2100014}},	// [237b0] _dekt_, yjna_, _bobs, _نٔٹ_, 
   {{0x7d0c48fc,0xf2dc014b,0x27200166,0xee3c00a2}},	//   _cobs, leâ_, _iñne_, _reýd_, 
   {{0xf1bc0407,0xef1c0037,0xdd8400fb,0x00000000}},	//   luá_, _tlü_, _ҡырп, --, 
   {{0x7d0c009a,0x69c95c12,0xf2dc94e8,0xe3b0010f}},	//   _eobs, ttge, neâ_, רױף_, 
   {{0xf1bc03a0,0x09e468ba,0x9f5800e4,0x2bdc0118}},	//   nuá_, толн, gyrõ_, नबहा, 
   {{0x69c95c13,0xf1bc0093,0x6f0d5c14,0x3ea001c7}},	//   rtge, iuá_, _hocc, _zekt_, 
   {{0x6f0c4e82,0xf2dc014b,0x8b840150,0x3ea0022e}},	//   _kocc, keâ_, _شەشە_, _yekt_, 
   {{0x69c95c15,0x29055c16,0x9b580107,0xe7840107}},	//   ptge, sjna_, _зист_, _ҷудо, 
   {{0x99d55c17,0x49743d66,0x6f0d5c18,0xe9b401d9}},	//   _متلا, _алас, _mocc, _سناں_, 
   {{0x2ca00327,0x83881572,0x601c0108,0x682460a7}},	//   _jejd_, мбов_, nämö, _пьез, 
   {{0x04455c19,0x057401d5,0x039402e8,0x00000000}},	//   тенн, _یاتد, ърпя, --, 
   {{0x6f0d5c1a,0xf1bc04d4,0xee3c00a2,0x00000000}},	//   _nocc, rzán_, _zeýe_, --, 
   {{0xf1bd5c1b,0xb17801e3,0x00000000,0x00000000}},	//   guá_, vvår, --, --, 
   {{0x6f0c00b5,0x2ca00327,0x25bc815e,0x26dd5c1c}},	//   _aocc, _nejd_, muul_, leuo_, 
   {{0x6f0d5c1d,0xbea55c1e,0xb1780267,0x3ea0003b}},	//   _bocc, кавк, tvår, _pekt_, 
   {{0x7a2401a9,0x7d0c0139,0x26dc0042,0xa304190b}},	//   _kаtt, _sobs, neuo_, _сүме, 
   {{0x6f0d5c1f,0x3ea003a1,0xb17801e6,0x5348010a}},	// [237c0] _docc, _vekt_, rvår, _чăтă, 
   {{0x2a7c01ab,0xb17801e6,0x3ea0282c,0x6f0c9cef}},	//   _agub_, svår, _wekt_, _eocc, 
   {{0x6f0c002e,0x92e40c58,0x3ea00158,0x2ee80175}},	//   _focc, নাৰ_, _tekt_, _facf_, 
   {{0x6f0d5c20,0x7d0c0204,0x25bd5c21,0x20195c22}},	//   _gocc, _wobs, kuul_, myri_, 
   {{0x99d41b06,0x7d0d5c23,0x390801c6,0x26dc0042}},	//   اقتت, _tobs, дэйн_, deuo_, 
   {{0x6f0c6933,0xb2240008,0x25bd5c24,0x795003e6}},	//   _zocc, _hræð, duul_, گێڕا, 
   {{0xec7428e8,0xb8d823fd,0x6f0c00b5,0x596401ec}},	//   _апр_, _आए_, _yocc, _ұнағ, 
   {{0xe8f424ce,0x2ca15c25,0x6f0c002e,0x09cc00cc}},	//   елә_, _zejd_, _xocc, লিজা, 
   {{0x25bc058a,0xe66002e8,0x5a4401ec,0x2018036e}},	//   guul_, итьо, _смағ, hyri_, 
   {{0x660c049f,0x20180200,0x62800419,0x00000000}},	//   äcka, kyri_, žmol, --, 
   {{0xe60c158f,0x00000000,0x00000000,0x00000000}},	//   مشی_, --, --, --, 
   {{0xf1bd5c26,0x25bc0009,0x1fc80011,0x201802d2}},	//   tuá_, buul_, শবাস, dyri_, 
   {{0x6f0c4d72,0xd05c0213,0xf2dc003a,0x25bc1aed}},	//   _rocc, əyən, reâ_, cuul_, 
   {{0x6f0d5c27,0x09cc00cc,0xf1bcb555,0x20195c28}},	//   _socc, লিচা, ruá_, fyri_, 
   {{0xb4bc16f0,0x6f0d5c29,0xb2240252,0x2ee80327}},	//   इली_, _pocc, _bræð, _pacf_, 
   {{0x5eb40cca,0x6f0c208d,0xf1bd5c2a,0x1be0000d}},	//   ийст, _qocc, lzám_, _गैइल_, 
   {{0x6ca41de1,0x2ca00010,0x601c005b,0xad6400ae}},	// [237d0] вреж, _pejd_, tämö, نائه, 
   {{0xaef800a3,0x6b600241,0xfcc001e0,0x00000000}},	//   _mhùi, _ọgó, йәсм, --, 
   {{0x6f0d5c2b,0xb224008c,0x9f580022,0xdb800023}},	//   _tocc, _fræð, tyrô_, _ክቐውም_, 
   {{0xb22401a8,0x601c005b,0x00000000,0x00000000}},	//   _græð, sämö, --, --, 
   {{0x2ca00327,0x271c05b3,0x998401d5,0xa9c400d8}},	//   _tejd_, _बतौर_, للنو, тсек, 
   {{0x2fc40295,0x5c88059f,0x07a40139,0x00000000}},	//   _ängs_, _айём_, гакн, --, 
   {{0x6d455c2c,0x26dc00ca,0x00000000,0x00000000}},	//   _ijja, teuo_, --, --, 
   {{0xaef80e89,0x6b8036e4,0xdb1c40fc,0x2a7c0067}},	//   _bhùi, íngu, _sprö, _ugub_, 
   {{0x7bd8006a,0xaef80192,0x2018005a,0xb17803cd}},	//   _âtur, _chùi, zyri_, yvåp, 
   {{0xaef80e89,0x69d95c2d,0xe58001c0,0xf1bc02f0}},	//   _dhùi, _ipue, лтүү, rzál_, 
   {{0x25bc01d9,0x82a400ee,0x97c42984,0x656c00bc}},	//   suul_, ланж, _نقلو, ůcho, 
   {{0x644c0356,0x25bccdc8,0x201801f4,0x00000000}},	//   şcio, puul_, vyri_, --, 
   {{0x82355c2e,0x6d441418,0xddd400d0,0xb178003b}},	//   ارجا, _ojja, _ťažn, tvåp, 
   {{0x613400ac,0xd6d80022,0x6b000327,0x20195c2f}},	//   _külə, _зтә_, _ཚོའོ_, tyri_, 
   {{0x7a2801d3,0xb1780fac,0x00000000,0x00000000}},	//   _köté, rvåp, --, --, 
   {{0x6d455c30,0x69d898fa,0x339086bf,0xb178143a}},	//   _ajja, _opue, _اليز, svåp, 
   {{0x2018020c,0x74c800dc,0x613406be,0x7c94003b}},	// [237e0] syri_, त्कृ, _lülə, грец, 
   {{0x319805e1,0xb1980bd9,0xbca4247f,0x2018003a}},	//   _רבינ, _רייכ, اماي, pyri_, 
   {{0x69d95c31,0xf53404ac,0xdb1c000f,0xeb941f99}},	//   _apue, נטער_, _oprô, гих_, 
   {{0x3a24eaae,0x6d440795,0xba24fdf0,0xf1bc01d3}},	//   лмег, _ejja, лдек, zzám_, 
   {{0x2b44003e,0x00000000,0x00000000,0x00000000}},	//   énca_, --, --, --, 
   {{0xe97012e3,0x7ba42d4b,0x613403b9,0x00000000}},	//   مهند, _مصرم, _bülə, --, 
   {{0x69d8ddf0,0x6d401b5c,0x660c0267,0xaef80e89}},	//   _epue, čnat, äckn, _shùi, 
   {{0x2fc40267,0xaef800a3,0x613406be,0x25dc0037}},	//   _ånge_, _phùi, _dülə, _कनखी_, 
   {{0x69d801e4,0x7ae13dbb,0xa2a800cd,0x6e380419}},	//   _gpue, meot, चरन्, _ľubk, 
   {{0x80d41092,0xa5d40c8b,0xb4bc3105,0x25680174}},	//   म्मे, ابير_, इले_, jøld_, 
   {{0xa3b806ab,0x613400ac,0x7f540784,0x681001ef}},	//   इंग_, _gülə, koyq, _vědá, 
   {{0x78a8074d,0xf5404ecc,0xf1bc01ed,0xaef800a3}},	//   lafv, рдүү, szám_, _thùi, 
   {{0x25b4007b,0x7f5401a9,0xe8f4030d,0x00000000}},	//   _مهند_, doyq, _ллă_, --, 
   {{0xdb24006a,0x53c40034,0x7ae15c32,0x78a801f5}},	//   êsêl, लंदश, heot, nafv, 
   {{0x75387bb3,0xe3ac06f6,0x7ae15c33,0x64c00372}},	//   mitz, _فري_, keot, _ايىل, 
   {{0x75380e26,0x6a7829ef,0xdb4404d3,0x9f349e08}},	//   litz, _jäfü, _رێ_, бесі, 
   {{0x7ae15c34,0x7bcc0139,0x02a401c6,0x9f4c0118}},	// [237f0] deot, _aqbu, _өрөм, ídá_, 
   {{0x75380372,0xd7f8084c,0xc0c00058,0x20280174}},	//   nitz, _oră_, _мәси, ívið_, 
   {{0x69d804c4,0x2c58037e,0x46a40118,0x00000000}},	//   _spue, ｎdy_, _गजलह, --, 
   {{0x753805f5,0xd9f004fa,0x5e840a93,0x00000000}},	//   hitz, चिंत_, _гурз, --, 
   {{0x753805f5,0x497401c6,0x00000000,0x00000000}},	//   kitz, алдс, --, --, 
   {{0x7a2801ed,0x7538009d,0x6d455c35,0x00000000}},	//   _söté, jitz, _ujja, --, 
   {{0x48085afd,0x753805f5,0x6d555c36,0x00000000}},	//   тейн_, ditz, moxa, --, 
   {{0x6d555c37,0x475800a7,0x0684444e,0x660c01e3}},	//   loxa, ърля_, шгин, äcko, 
   {{0x753801a6,0xd7f80356,0x7b2c00df,0xf1bc01d3}},	//   fitz, _eră_, rŝut, száj_, 
   {{0x753801c0,0x6288012c,0x200c0793,0x6d54004b}},	//   gitz, ědom, ädik_, noxa, 
   {{0x2568022c,0x78f8008f,0x8d980150,0x00000000}},	//   vøld_, _שלעפ, _ﺘﻨﺴﻕ_, --, 
   {{0x6d54014b,0xdcfc0115,0x06755c38,0x7538005a}},	//   hoxa, _virĉ, _куля, aitz, 
   {{0xc0e4069c,0x68e000ec,0x75395c39,0xaad400dc}},	//   _ዝበለ_, oend, bitz, ण्यक, 
   {{0x66180a49,0x7ae0005a,0x67395c3a,0x6aa808a5}},	//   myuk, zeot, liuj, hagf, 
   {{0x68e15c3b,0x66195c3c,0x256803b2,0x2d8d5c3d}},	//   iend, lyuk, røld_, ígen_, 
   {{0x68e15c3e,0x67395c3f,0xfe450879,0x256803b2}},	//   hend, niuj, анбо, søld_, 
  
   {{0x68e15c40,0x63a000a9,0x12c400cf,0xd8380427}},	// [23800] kend, _hwnn, _اتىپ, _pečk_, 
   {{0x68e15c41,0x6b840007,0xc0e4044e,0xf1bc01ed}},	//   jend, _bujg, _ዝበሉ_, zzák_, 
   {{0x68e15b89,0x66188461,0xa3b803f3,0x6b840369}},	//   dend, hyuk, इंट_, _cujg, 
   {{0x75380323,0x66195c42,0xeb3057d7,0x2bd407c1}},	//   zitz, kyuk, يىلد, _ठहरा, 
   {{0xdcfc0003,0xcdc40116,0x66181f94,0x78a801f5}},	//   _jirċ, _лаяқ, jyuk, tafv, 
   {{0x7c64c284,0x68e06dc8,0x7ae15c43,0x6da0c891}},	//   _نازل, gend, seot, _фира, 
   {{0x75395c44,0x7ae001ee,0x6a7801b8,0x78a95c45}},	//   vitz, peot, _päfü, rafv, 
   {{0x75395c46,0x661807a8,0xd83801fa,0x67380194}},	//   witz, fyuk, _ječi_, giuj, 
   {{0x75387bb3,0x66189b41,0x354432cf,0x35680a93}},	//   titz, gyuk, ихов, крон_, 
   {{0x9b6404a9,0x63a00369,0xd8380063,0xe8f4119e}},	//   _ئۆچۈ, _bwnn, _leči_, _клу_, 
   {{0x75395c47,0xc0e4044e,0x66180083,0xd7f8054e}},	//   ritz, _ዝበሎ_, ayuk, _ură_, 
   {{0x75395c48,0x66195c49,0x6d54014b,0x63a00142}},	//   sitz, byuk, zoxa, _dwnn, 
   {{0x75380e78,0xb4b000fd,0xaef80192,0xecc403e5}},	//   pitz, _дилә, _mhùt, _लालफ, 
   {{0x62840c8c,0x6d54289d,0x00000000,0x00000000}},	//   _egio, xoxa, --, --, 
   {{0xaad4227c,0x628401ab,0x6d540117,0x00000000}},	//   ण्डक, _fgio, voxa, --, 
   {{0x68e15c4a,0x61ec0822,0x6e38001f,0x717400dc}},	//   zend, ällä, _በመግባ, _dīkṣ, 
   {{0x68e15c4b,0x5f180073,0x8afc01ef,0x9f54003b}},	// [23810] yend, _नवर्_, _uhři, івуч, 
   {{0xefc40020,0x69cc01b8,0x68e15c4c,0x1cdc025c}},	//   ችለው_, _äcei, xend, _རྒད_, 
   {{0x68e15c4d,0x6d555c4e,0x6aa94572,0xee855c4f}},	//   vend, roxa, tagf, _выго, 
   {{0x68e15c50,0x661802a8,0xddd409a8,0x00000000}},	//   wend, yyuk, žašk, --, 
   {{0xaef80e89,0x67380194,0x6aa80009,0x21ac00d1}},	//   _dhùt, viuj, ragf, ﻳﻴﺎﺭ, 
   {{0xf1bc2d86,0x6618019f,0x00000000,0x00000000}},	//   irá_, vyuk, --, --, 
   {{0xf1bcb231,0x99640116,0x60d803e0,0x4cac00eb}},	//   hrá_, өтәл, _övme, _চাপু, 
   {{0xf1bc1873,0x46e8085f,0x66195c51,0xb6040301}},	//   krá_, удин_, tyuk, kršć, 
   {{0x66195c52,0x67380024,0xfbcc0154,0x5f0800cd}},	//   uyuk, riuj, রবণত, हात्_, 
   {{0x68e15c53,0x62840192,0x66195c54,0x00000000}},	//   qend, _sgio, ryuk, --, 
   {{0x661938b7,0xf1bc09c2,0xdb500014,0x67380210}},	//   syuk, erá_, _رَے_, piuj, 
   {{0x1cdc038f,0xf1bc041e,0xad980cad,0x66195c55}},	//   _རྒན_, frá_, _irúf, pyuk, 
   {{0xd8395c56,0xf1bc011f,0xd75400f7,0x00000000}},	//   _reči_, grá_, _بئلب, --, 
   {{0xd8380010,0x63a00042,0xe18801e0,0x25bc2093}},	//   _seči_, _twnn, лөүе_, mrul_, 
   {{0xf1bd5c57,0xd838151c,0xbf640b24,0xaaa4095f}},	//   ará_, _peči_, مدرو, खराक, 
   {{0xf1bd5c58,0x25bc0311,0xdcfc0003,0xd3b800d4}},	//   brá_, orul_, _tirċ, _туші_, 
   {{0x2fdc0276,0xd838260c,0x00000000,0x00000000}},	// [23820] ăuga_, _veči_, --, --, 
   {{0x23d812eb,0x25bd5c59,0x7fd489bf,0x717400dc}},	//   _बहाद, irul_, _лімі, _tīkṣ, 
   {{0x25bc5e03,0xb53800c8,0xd83809a8,0x201c0252}},	//   hrul_, נגעש, _teči_, _ævi_, 
   {{0xdd900075,0xaef801c3,0x25bc0af9,0x2fc401e3}},	//   _يۈز_, _dhùs, krul_, _ånga_, 
   {{0xad980241,0x25bc0198,0xeb94039b,0xa3b8443a}},	//   _arúf, jrul_, _ҳис_, ेंड_, 
   {{0x25bd5c5a,0x3f815c5b,0xdc3c00d0,0xdcfc0153}},	//   drul_, _hiku_, láča, _kirč, 
   {{0x93bc084c,0x25bc0276,0x6ab400bd,0x3f815c5c}},	//   nzăt, erul_, _ইউরো, _kiku_, 
   {{0xa3a844ab,0x3f8003f9,0x25bc05b1,0xdcfc00c0}},	//   गठन_, _jiku_, frul_, _mirč, 
   {{0xe9a02850,0x3f815c5d,0x25bd5c5e,0xb8cc0011}},	//   _натп, _miku_, grul_, _কা_, 
   {{0xb60405ce,0xb4b00073,0xe8140014,0xf4e801a9}},	//   vršć, टणे_, _گٲمت_, уфий_, 
   {{0x25bd5c5f,0x4cac00fe,0xaef800a3,0xad9802d2}},	//   arul_, _চামু, _mhùr, _grúf, 
   {{0x3f815c60,0x25bd5c5f,0xf1bd5c61,0x00000000}},	//   _niku_, brul_, trá_, --, 
   {{0x25bc0276,0xad980241,0xe3ac03e6,0xcad403d4}},	//   crul_, _irúg, ورێ_, _সোঁফ, 
   {{0xf1bc102c,0xecc4068f,0x3f800241,0xdcfc8bbb}},	//   rrá_, _लाइफ, _aiku_, _birč, 
   {{0x65380302,0xd6e4010a,0x00000000,0x00000000}},	//   _תעוד, _хiув, --, --, 
   {{0x3f800286,0xdcfc0100,0x9f3402dd,0x32080117}},	//   _ciku_, _dirč, песі, _бхон_, 
   {{0xd2508bf7,0x16fc0156,0x3f8002d3,0xaef800a3}},	// [23830] _زند_, _ཐོནམ_, _diku_, _bhùr, 
   {{0xd1305263,0xaef80e89,0xdcfc00f3,0x3f800108}},	//   _آمد_, _chùr, _firč, _eiku_, 
   {{0x3f80166a,0xaef808c2,0x25bc0ac5,0xec695c62}},	//   _fiku_, _dhùr, zrul_, урак_, 
   {{0x9508031c,0xef1c0139,0x395c00de,0x25bc0009}},	//   _ཇོའི_, _biüe_, _akts_, yrul_, 
   {{0xd838e108,0xdaa802bf,0x98bc00c0,0x00000000}},	//   _meču_, свід_, novė_, --, 
   {{0x92e403f4,0xad980248,0x3f80860c,0xdd955c63}},	//   নায়_, _arúg, _ziku_, _хары, 
   {{0x2d8802a8,0xaef80428,0x3f80b3a7,0xad9806ea}},	//   _huce_, _ikùb, _yiku_, _brúg, 
   {{0x25bd5c64,0x3f8002b9,0x2d800023,0xd83801a6}},	//   trul_, _xiku_, _hije_, _neču_, 
   {{0x2d815c65,0x2d880384,0xad9806ea,0x98bc0153}},	//   _kije_, _juce_, _drúg, jovė_, 
   {{0x59c494d2,0x2d895c66,0x451806bf,0x2d80cc44}},	//   _ريمك, _muce_, рция_, _jije_, 
   {{0x2d895c67,0x25bc0a2e,0xd8381591,0x2d800023}},	//   _luce_, srul_, _beču_, _mije_, 
   {{0x2d80000f,0xad980162,0x25bd2355,0x00000000}},	//   _lije_, _grúg, prul_, --, 
   {{0x3f815c68,0x2d800083,0x2d88c92c,0xdcfc007f}},	//   _riku_, _oije_, _nuce_, _sirč, 
   {{0x2d801326,0x3f815c69,0xf99006a9,0x03a55c6a}},	//   _nije_, _siku_, ורך_, _дико, 
   {{0x2d895c6b,0x3f8001fa,0xdc3c00d0,0xe208012d}},	//   _auce_, _piku_, táča, wróć_, 
   {{0x2d881446,0x6d495c6c,0x3f80011f,0xfd4c02e3}},	//   _buce_, égan, _qiku_, bakọ, 
   {{0x3f8026b8,0x2d8802a8,0x23600295,0x417400f1}},	// [23840] _viku_, _cuce_, _ikij_, _واخس, 
   {{0x2d895c6d,0x2fd0006a,0x3f800687,0x3fe51add}},	//   _duce_, öngö_, _wiku_, _джов, 
   {{0x98780038,0x3f6810ea,0x2d815c6e,0x3f815c6f}},	//   _páči_, _вино_, _dije_, _tiku_, 
   {{0xad98022c,0x00000000,0x00000000,0x00000000}},	//   _brúd, --, --, --, 
   {{0x2d880333,0x59f8084c,0x93bc0276,0x2d815c70}},	//   _guce_, селя_, nzăr, _fije_, 
   {{0x2d8000ee,0x00000000,0x00000000,0x00000000}},	//   _gije_, --, --, --, 
   {{0xb8f0725a,0xf7295c71,0x48a801ec,0x00000000}},	//   _वा_, иций_, стім_, --, 
   {{0x2d815c72,0x2d880109,0xf644036b,0xad9802d2}},	//   _zije_, _yuce_, жхон, _frúd, 
   {{0x98fc0115,0xaee00055,0x2d800455,0xad9801e7}},	//   _akĉe, _avṛd, _yije_, _grúd, 
   {{0x6130363f,0x37e4bd9b,0xd83800f3,0x00000000}},	//   _hälf, _мозг, _seču_, --, 
   {{0xad980579,0xba00044e,0x2cf8008f,0xfd4c0521}},	//   _trúg, _ፍረ_, בליא, wakọ, 
   {{0x78b8ecac,0x98bc0153,0xd25002c9,0xf20401f0}},	//   _hdtv, tovė_, فنج_, ояго, 
   {{0x98fc01e4,0x159800f1,0x25680174,0x228400db}},	//   _ekĉe, _انتخ_, søla_, дург, 
   {{0x2d88012c,0x98bc0006,0x741402f2,0x634400e5}},	//   _ruce_, rovė_, _ووشا, vőne, 
   {{0x33b00075,0x2d801ce5,0x2d895c73,0x656c07ea}},	//   _تەجر, _rije_, _suce_, îche, 
   {{0x2d815c74,0x2d895c75,0xfd4c01f2,0x634401d3}},	//   _sije_, _puce_, pakọ, tőne, 
   {{0x35c001ad,0x00000000,0x00000000,0x00000000}},	// [23850] _शिफ़, --, --, --, 
   {{0x660c01e3,0xc8c83d1d,0xe6c408df,0x00000000}},	//   äcki, _राइट, _रञ्ज, --, 
   {{0x2d815c76,0x2d883142,0xd2515c77,0x2bc8014b}},	//   _vije_, _wuce_, _زنگ_, рузо_, 
   {{0xad980030,0x2d80df70,0x2d880960,0x1dc800dc}},	//   _prúd, _wije_, _tuce_, िंशत, 
   {{0xbab00f87,0x2d815c78,0x00000000,0x00000000}},	//   رموب, _tije_, --, --, 
   {{0x200c2ab7,0xda1c000d,0xf1bc00e5,0x9cc801f4}},	//   ådig_, _भअरत_, lzás_, _мыса_, 
   {{0x87f805f5,0xb8840008,0xc48400ee,0x00000000}},	//   сэлт_, _svíþ, үлик, --, 
   {{0xa3b84966,0x44280421,0xdd90004b,0xd8380219}},	//   ेंस_, _āa_, _سوې_, _rečt_, 
   {{0x6ab95c79,0xad980030,0xe9700014,0x06080108}},	//   _iduf, _hrúb, _ہۆچھ, ёнок_, 
   {{0xd8380010,0xe78400f3,0xdcfc002b,0xe70800ec}},	//   _pečt_, _дудо, _kirā, _ھتان_, 
   {{0x59f800a8,0x6130007c,0xd8240798,0x00000000}},	//   _леӂя_, _hälg, _одѕи, --, 
   {{0xa13c001f,0x61300139,0xdcfc00ef,0xb884032e}},	//   _ባለመሆ, _xälf, _mirā, _tvíþ, 
   {{0x6130007d,0xf8d0b7b0,0xa6440244,0x00000000}},	//   _jälg, _सामय, _بخان, --, 
   {{0x6d48004a,0xd8380427,0x61300139,0xad9801e1}},	//   égal, _tečt_, _mälg, _orúb, 
   {{0xdcfc0882,0x00000000,0x00000000,0x00000000}},	//   _nirā, --, --, --, 
   {{0x6ab8d78f,0x00000000,0x00000000,0x00000000}},	//   _nduf, --, --, --, 
   {{0xdcfc002b,0x61300037,0x00000000,0x00000000}},	// [23860] _airā, _nälg, --, --, 
   {{0x61e55c7a,0x6ab95c7b,0x200cfdc0,0x644c0356}},	//   _ipil, _aduf, ädis_, şciu, 
   {{0x711804ac,0x0ba81e4a,0xdcfc00cd,0xad9801e7}},	//   _הויפ, قانى_, _cirā, _crúb, 
   {{0x61e405b1,0x6130007c,0x5e640150,0xc8c828fe}},	//   _kpil, _bälg, _يندە, _राउट, 
   {{0x613001e6,0xbdf800db,0x78b802d0,0xee34074d}},	//   _välf, _ارجا_, _pdtv, хнă_, 
   {{0x61e55c7c,0x67280008,0x6ab8002d,0x3eb0079b}},	//   _mpil, _algj, _eduf, layt_, 
   {{0xfaa55c7d,0x7c65003d,0xdcfc002b,0xad9802d2}},	//   _наво, _راسل, _girā, _grúb, 
   {{0x613001e3,0x758c0023,0x00000000,0x00000000}},	//   _fälg, _መሲልዎ_, --, --, 
   {{0xe60c03e6,0xba240108,0x00000000,0x00000000}},	//   ۆشی_, _эдак, --, --, 
   {{0x6728143a,0x00000000,0x00000000,0x00000000}},	//   _elgj, --, --, --, 
   {{0xd1bc001f,0x61300166,0x256806ea,0xe60c1bf4}},	//   ሳየት_, _mäld, møll_, نشی_, 
   {{0xc76407a7,0x61e401e7,0x81e40011,0x00000000}},	//   _قانى, _bpil, ফিন_, --, 
   {{0xf67804fb,0xdea40115,0x326482e2,0x6130008e}},	//   _امشب_, gniƭ, ятов, _xälg, 
   {{0xe4b401ec,0xf20401f0,0x28dc1db2,0x00000000}},	//   _елші_, ояҳо, प्पि, --, 
   {{0xbe9805db,0x80cc77ca,0x79640092,0x6d480129}},	//   _ọhụr, _तारे, ግሥታት, égam, 
   {{0xd8ec0327,0x25680174,0x37bc00eb,0x7e7001e1}},	//   _རིའི, høll_, _আহার, _ọtọ̀, 
   {{0x6130420d,0x925800a8,0x21b80014,0xdcfc00b8}},	// [23870] _bäld, _фапт_, _ٹھُک_, _sirā, 
   {{0xfc440313,0x4cb8177b,0x7e640728,0x25680162}},	//   čína_, ілею_, _dykp, jøll_, 
   {{0x61300209,0x63840066,0xad9801e7,0x4fc000db}},	//   _däld, mènè, _brúc, _جەزە, 
   {{0xad9882e3,0xdcfc00dc,0x00000000,0x00000000}},	//   _crúc, _virā, --, --, 
   {{0xa2c01fad,0xad9801e7,0x256803b2,0x00000000}},	//   _वयस्, _drúc, føll_, --, 
   {{0x61302bea,0xad995c7e,0xdcfc0171,0x00000000}},	//   _välg, _trúb, _tirā, --, 
   {{0x2740007f,0x00000000,0x00000000,0x00000000}},	//   _nènè_, --, --, --, 
   {{0x6ab80230,0x97c441fa,0x61300166,0xfbd0123b}},	//   _uduf, رتىم, _iäle, _שתן_, 
   {{0xd50c043b,0x060802bf,0x80cc0d2c,0x61315c7f}},	//   _sɔ́k, інок_, _ताले, _häle, 
   {{0x69c95c80,0xe3e40135,0xad9800d0,0x776001e3}},	//   muge, _འགྱང, _zrúc, _ekox, 
   {{0x61e55c81,0x69c95c82,0x61301b99,0xc2c416ac}},	//   _spil, luge, _jäle, ويدي, 
   {{0x6130007d,0x27400066,0x61e55c83,0x63680165}},	//   _mäle, _dènè_, _ppil, oñni, 
   {{0x69c95c59,0x61300432,0x93bc054e,0x3eb15c84}},	//   nuge, _läle, szăp, vayt_, 
   {{0x212c007b,0x69c8003a,0xdcfc0356,0x3eb00009}},	//   ódh_, iuge, _miră, wayt_, 
   {{0x69c8d489,0xe3e4025c,0x6680036b,0x61300432}},	//   huge, _འགྲང, _تیکل, _näle, 
   {{0xf4100302,0xf1bc37b5,0x00000000,0x00000000}},	//   _יפו_, rzár_, --, --, 
   {{0x69c8324c,0xf1bc00e5,0x00000000,0x00000000}},	// [23880] juge, szár_, --, --, 
   {{0x69c84d11,0x4174034c,0x6130013d,0xf8d000dc}},	//   duge, _تابس, _bäle, _साधय, 
   {{0x6131551b,0x69c80114,0x7e64002d,0x25680174}},	//   _väld, euge, _wykp, vøll_, 
   {{0x6130791a,0x3de40183,0xc0e8211f,0xfaa40107}},	//   _wäld, নিবল, _افگن_, фадо, 
   {{0x4cac015b,0x69c8bc12,0xad9800d7,0x00000000}},	//   _চারু, guge, _vrúc, --, 
   {{0xf8047111,0xfbc42d39,0x61315c85,0x00000000}},	//   дчин, _обго, _fäle, --, 
   {{0x5694520d,0x6368030a,0x180800dc,0x61300112}},	//   найт, añni, वमेव_, _kälb, 
   {{0x69c83917,0x00000000,0x00000000,0x00000000}},	//   buge, --, --, --, 
   {{0x61300254,0xaef80ca8,0x00000000,0x00000000}},	//   _mälb, _okùn, --, --, 
   {{0xeaac2832,0xe8c400ee,0xe9840220,0x00000000}},	//   _مٹہ_, _огул_, _قالۋ, --, 
   {{0x613000fd,0x656c0124,0x00000000,0x00000000}},	//   _xäle, îcha, --, --, 
   {{0xaef80248,0x762401f0,0x00000000,0x00000000}},	//   _akùn, _омез, --, --, 
   {{0x660c049f,0xa2640801,0xe60c45cf,0x638804fb}},	//   äckt, върл, _نشو_, wènè, 
   {{0x63880d29,0x74bc1870,0x00000000,0x00000000}},	//   tènè, ﻠﻤﻪﻳ, --, --, 
   {{0x69c80730,0xdfd80801,0x4cac00eb,0x641000ae}},	//   zuge, мът_, _চালু, _لذيذ, 
   {{0xe3080dd4,0xad24186e,0x611800fd,0xb40001c0}},	//   _ཆོགཔ_, ژراو, _aşlı, _зүүд, 
   {{0x2d8c0b21,0x613008c5,0xad9808a5,0x80d80c70}},	// [23890] êge_, _säle, _brúa, _पॉके, 
   {{0xad980077,0x613001b8,0x2d852704,0x69c95c86}},	//   _crúa, _päle, öne_, vuge, 
   {{0x69c82dab,0x2bb8007b,0x7ae800f1,0x00000000}},	//   wuge, تاذة_, ګونې_, --, 
   {{0x6130023a,0x61180166,0x25f00f90,0xca740006}},	//   _väle, _eşlı, ्टमी_, нулы, 
   {{0xad980a87,0x00000000,0x00000000,0x00000000}},	//   _frúa, --, --, --, 
   {{0x69c95c87,0x95280156,0xad983eba,0x61315c88}},	//   ruge, རིསི_, _grúa, _täle, 
   {{0x69c95c89,0x00000000,0x00000000,0x00000000}},	//   suge, --, --, --, 
   {{0x61300139,0xe9d001e2,0x00000000,0x00000000}},	//   _xälb, _ټغر_, --, --, 
   {{0x458401a9,0x00000000,0x00000000,0x00000000}},	//   нгив, --, --, --, 
   {{0x195802dd,0x291800d1,0x00000000,0x00000000}},	//   _жауы_, ﺷﯜﭖ_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x66000588,0x660c0267,0x30a0190b,0xdcf000d7}},	//   _аҿиа, äcks, ңғығ, _čeči, 
   {{0xc7641823,0x26dc013f,0x74100326,0x2b4c0332}},	//   _قاچى, mfuo_, نویا, ingc_, 
   {{0x412800d6,0xb1e005d9,0x5660001f,0x80a80c4c}},	//   чого_, اڻيو, ገንዝበ, करें, 
   {{0xafe085a8,0x3f9c00e8,0x5f2802f2,0x28d40118}},	//   лорл, ëtu_, وترێ_, _ठानि, 
   {{0x44255c8a,0x28dc1a3e,0x3f9c00da,0x26dc013f}},	//   myl_, प्ति, ītu_, nfuo_, 
   {{0xdcf40989,0x4424d326,0x613001e6,0xaef801e1}},	// [238a0] šačk, lyl_, _välb, _ikùl, 
   {{0xd1640022,0x44241368,0x00000000,0x00000000}},	//   _инық, oyl_, --, --, 
   {{0x6cd00228,0xfb880351,0x00000000,0x00000000}},	//   اقما, чбек_, --, --, 
   {{0xad980241,0x44241368,0x00000000,0x00000000}},	//   _irún, iyl_, --, --, 
   {{0x44255c8b,0x58d408bf,0xad9809f3,0xeb302ba5}},	//   hyl_, волт, _trúa, دىند, 
   {{0x44255c8c,0x37a8104b,0xad981d0e,0xfb1400f1}},	//   kyl_, птин_, _krún, _ګورج, 
   {{0xfc18021a,0x442400a2,0x00000000,0x00000000}},	//   _عقرب_, jyl_, --, --, 
   {{0x44255c8d,0x3d0c1b57,0x2ca40790,0xfbc401f0}},	//   dyl_, ठावे_, ınde_, _обҳо, 
   {{0x44240363,0x00000000,0x00000000,0x00000000}},	//   eyl_, --, --, --, 
   {{0x44240385,0xca7531c3,0xf57001e0,0xad9801e1}},	//   fyl_, _русы, ыҫлы, _orún, 
   {{0x44255c8e,0xdec01954,0xb17801e3,0x660c007c}},	//   gyl_, ትሉን_, ltåg, äckr, 
   {{0xee3c00a2,0x00000000,0x00000000,0x00000000}},	//   _keýt_, --, --, --, 
   {{0xe5a00323,0x6d480086,0x44240363,0xa1940139}},	//   _бичи, ũgai, ayl_, лаяч, 
   {{0x44255c8f,0xad995c90,0xc6480c4f,0xd7d400c5}},	//   byl_, _brún, _تجمل_, _धमाच, 
   {{0x44255c91,0xb4bc52f2,0xb40805f5,0xaf043a23}},	//   cyl_, ेली_, _хэлж_, нчак, 
   {{0xdef80032,0x00000000,0x00000000,0x00000000}},	//   ныу_, --, --, --, 
   {{0x2490036e,0x71701c3e,0x00000000,0x00000000}},	// [238b0] _çamë_, _مۇحا, --, --, 
   {{0xad981427,0x00000000,0x00000000,0x00000000}},	//   _frún, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb4bc0fc8,0xee3c010e,0x9c6400f2,0xce940818}},	//   ेलु_, _beýt_, دهمو, _шамъ, 
   {{0xca400020,0x442400ee,0x61300724,0xcce405d9}},	//   _ፓርቲዎ, zyl_, _häla, _لڳاي, 
   {{0x48e40138,0x6d480100,0xbb2800d1,0x00000000}},	//   токв, ègad, ﻤﻜﻰ_, --, 
   {{0x44255c92,0xf89000d8,0x00000000,0x00000000}},	//   xyl_, шајќ, --, --, 
   {{0x06083e1e,0x613001e6,0x4424062c,0x7c2803cd}},	//   дник_, _mäla, vyl_, øfre, 
   {{0xb4bc1533,0x442400a9,0xca495c93,0x63880241}},	//   ेलू_, wyl_, _غلطه_, _lènì, 
   {{0x69d8074d,0x44255c94,0x84280395,0xb1400092}},	//   _ique, tyl_, джов_, _ከቅዱሳ, 
   {{0xe5800137,0xee3c00a2,0x4424062c,0x6130010e}},	//   ктүү, _keýs_, uyl_, _näla, 
   {{0x26c00006,0xe72c0133,0xe1f80107,0xb380013d}},	//   ėjos_, _دڵت_, еҳи_, илэл, 
   {{0x44255c95,0x95c40451,0x25680174,0x7ab8011a}},	//   syl_, _مينه, høli_, וצרו, 
   {{0x44255c96,0x69d8004e,0x545401c0,0x6130013d}},	//   pyl_, _mque, _өвчт, _bäla, 
   {{0xd0584e19,0x6130013d,0xfc440f91,0x3f680452}},	//   ерті_, _cäla, číka_, диво_, 
   {{0x02040588,0x69d80428,0x638801e1,0x79800150}},	//   _азин, _oque, _dènì, _ﺨﺎﻁﺌ_, 
   {{0xcdc41884,0xf1bc01ed,0xa3b800e1,0xc7a400e5}},	// [238c0] латқ, lyán_, ेंक_, _گڑ_, 
   {{0xad995c97,0xed540640,0xef1c0254,0x00000000}},	//   _trún, воу_, _eoü_, --, 
   {{0x69d95c98,0xf1bc22ec,0x98bc0276,0x2b94008e}},	//   _aque, nyán_, hivă_, _cçc_, 
   {{0xf1aca583,0xf1bc0789,0xcbc406f6,0xad980162}},	//   जीवन, iyán_, ازلي, _krúl, 
   {{0x7fe00abd,0x8e740aae,0xee34b464,0xfca80b24}},	//   _पहुँ, _бурч, _аня_, _ياسو_, 
   {{0x256803b2,0xb178007c,0x00000000,0x00000000}},	//   bøli_, rtåg, --, --, 
   {{0x69d95c99,0x61300166,0x613c0023,0xb178007c}},	//   _eque, _xäla, _ካብዚኣ, ståg, 
   {{0x29d8025a,0x69d80334,0x7bdc002f,0x00000000}},	//   bêa_, _fque, mtpu, --, 
   {{0x7ae15c9a,0xe9d4277c,0x660c0267,0x6a8000c0}},	//   mfot, _икт_, äckp, _влта, 
   {{0xb4bc482a,0x7ae15c9b,0x941806ed,0x28e40022}},	//   ेले_, lfot, ежот_, _идуп_, 
   {{0x3cf8068f,0x7ae000fb,0x00000000,0x00000000}},	//   _उसने_, ofot, --, --, 
   {{0x7ae15c9c,0x7d0c02d0,0xb6a4011c,0x00000000}},	//   nfot, _lnbs, _ридл, --, 
   {{0x61300724,0x7ae00472,0x7bdc00c5,0x25ac0142}},	//   _säla, ifot, htpu, _gwgl_, 
   {{0x61300793,0x7bdc3b84,0x5ee000cc,0x64a000f3}},	//   _päla, ktpu, _পোলে, _каља, 
   {{0x5ea400bd,0x7ae017b5,0xc578008f,0x7bdc0175}},	//   _ওয়ে, kfot, _אָקט, jtpu, 
   {{0x7bdc0ac8,0x61301900,0x4ad02072,0x6e3800a2}},	//   dtpu, _väla, _हाइव, _ýubk, 
   {{0x7ae0050a,0x7bdc0072,0x2e4802e8,0xf1ac07f7}},	// [238d0] dfot, etpu, фяво_, जीशन, 
   {{0x7ae15c9d,0x29d800d8,0x5fd0043e,0x61300139}},	//   efot, vêa_, तूहल, _täla, 
   {{0x69d95c9e,0xc314015b,0x7ae00548,0xad9801e1}},	//   _sque, াসরি_, ffot, _irúm, 
   {{0x7ae15c9f,0x201c0137,0xb1780267,0xdcfc00c0}},	//   gfot, _àvia_, ståd, _mirę, 
   {{0x69d8a547,0x61300139,0x00000000,0x00000000}},	//   _qque, _mäln, --, --, 
   {{0x4cac015b,0xaef801e1,0x00000000,0x00000000}},	//   _চাকু, _okùk, --, --, 
   {{0xdcfc4ca5,0x7bdc01f5,0x497402dd,0x6d480129}},	//   _sirć, ctpu, _ұлас, égau, 
   {{0x98bc084c,0x78d00022,0x00000000,0x00000000}},	//   tivă_, ажәх, --, --, 
   {{0x69d8014b,0x4a540845,0x497400c0,0x0684094e}},	//   _uque, _скас, _блас, ыгин, 
   {{0xdb1c007f,0x98bc054e,0x9990054e,0x00000000}},	//   _avrè, rivă_, şaţi_, --, 
   {{0x98bc0311,0x04440958,0x1d940092,0x580415bf}},	//   sivă_, уенн, ማኖቶች_, _پونك, 
   {{0x28dc07b7,0xad980022,0xd4400092,0xdef801f3}},	//   प्रि, _arúm, ኖሚያዊ, ገቱን_, 
   {{0x84e55ca0,0x4ad0033f,0x00000000,0x00000000}},	//   _болж, _हाईव, --, --, 
   {{0xb6000316,0x69c95ca1,0x51546191,0x528401e0}},	//   čátk, irge, атсу, шҡын_, 
   {{0x69c803fa,0x7ae062a5,0x67141f13,0x23b402e5}},	//   hrge, yfot, थापक_, _आबिद, 
   {{0xad980321,0x7ae00036,0xa3040150,0x00000000}},	//   _trúl, xfot, _түме, --, 
   {{0x73302928,0x7ae021e3,0xa2e401a9,0x00000000}},	// [238e0] _دىيا, vfot, _боқд, --, 
   {{0x23b4951e,0x7bdc007c,0xad980332,0xf8d0000d}},	//   _आबाद, ttpu, _grúm, _साइय, 
   {{0x7ae15ca2,0xa3b831a0,0x69c95c9c,0x80a828e1}},	//   tfot, ेंट_, erge, _ज्ये, 
   {{0x2ca44944,0xdb2401b8,0xa3c8012c,0x15f802ab}},	//   ında_, _äsüi, _लिन_, ्टमर_, 
   {{0xb1795ca3,0xe3a539ea,0x8b640150,0x19440124}},	//   ståe, _گر_, جالم, аҭан, 
   {{0x7ae15ca4,0x6d48387a,0x7bdc0036,0x81d400fe}},	//   sfot, égat, ptpu, _সনা_, 
   {{0xe3a40f66,0x69c95ca5,0xb76465f9,0x7ae00a40}},	//   _در_, arge, лтий, pfot, 
   {{0xee3c0432,0x940c06be,0x00000000,0x00000000}},	//   _keýp_, ccdə_, --, --, 
   {{0x63a00083,0x290c00c6,0x00000000,0x00000000}},	//   _atnn, álaí_, --, --, 
   {{0xad980407,0xaee000b8,0x00000000,0x00000000}},	//   _brúj, _kiṃb, --, --, 
   {{0xd6c45530,0x00000000,0x00000000,0x00000000}},	//   _نمای, --, --, --, 
   {{0xa3b8353b,0xe29800c7,0x00000000,0x00000000}},	//   ेंज_, лаџ_, --, --, 
   {{0x61300793,0xf1ac0073,0x00000000,0x00000000}},	//   _cälo, जींन, --, --, 
   {{0x613001b8,0xe3ac9105,0x786402d3,0xb4255ca6}},	//   _dälo, _کرو_, _ምሕንጻ, _معبو, 
   {{0x09d00a28,0xdb1c00e4,0x533474be,0xb3540344}},	//   _सम्य, _evré, _вейт, _میدا_, 
   {{0x613150bb,0x00000000,0x00000000,0x00000000}},	//   _häll, --, --, --, 
   {{0x613004f3,0xad98347d,0x201c0129,0xc0dc0092}},	// [238f0] _käll, _irúk, _àvin_, ንድሮ_, 
   {{0x613018db,0x627c025f,0x2568383d,0xaee000b8}},	//   _jäll, _אנחנ, sølv_, _biṃb, 
   {{0xf1bc01a8,0x613154e4,0x768401a9,0x9e60022e}},	//   lsá_, _mäll, lаyd, ndiª_, 
   {{0x61301b99,0xeea80212,0xe7a400d1,0x00000000}},	//   _läll, _яток_, ۇپتۇ_, --, 
   {{0x69c85e52,0x6d495ca7,0xf1bc056a,0x8cdc4438}},	//   urge, égas, nsá_, _पापो, 
   {{0xa4f00574,0x69c869a9,0x200c005c,0x634400e5}},	//   _असेच_, rrge, ædig_, tőnk, 
   {{0xad98110e,0x6d455ca8,0x07a45b0f,0xd8b80f84}},	//   _orúk, _imja, шайн, ادها_, 
   {{0xf1bc03b2,0xc724009d,0x98080137,0x00000000}},	//   ksá_, рдий, اتوف_, --, 
   {{0x61303411,0x85780261,0x7d1001ed,0x787409a5}},	//   _bäll, ксот_, _újsá, лйәр_, 
   {{0x61300166,0x256803cd,0x57a40124,0x452801a9}},	//   _cäll, jølt_, шшәа, тжон_, 
   {{0xad981125,0x99840597,0x61315ca9,0x74e4009d}},	//   _brúk, _اللو, _däll, шдэг_, 
   {{0x61300793,0x27380248,0xb600012c,0x48fc012c}},	//   _pälo, _dànù_, čárk, लयको_, 
   {{0x61315caa,0x998001a2,0x250479f8,0x7ae403e0}},	//   _fäll, šiť_, _مرغی_, _ökte, 
   {{0x61315cab,0x25bc3223,0xad9801e1,0xdef82440}},	//   _gäll, msul_, _erúk, ገዱን_, 
   {{0x25bc042f,0x3ea40077,0x82a4004e,0x82340066}},	//   lsul_, ñoto_, _кайж, _چرخا, 
   {{0x3ea55cac,0x6d455cad,0x436807d5,0x25bc054e}},	//   риаг, _amja, _шайн_, osul_, 
   {{0x25bd5cae,0x7dc532d7,0x256806ea,0x7c946ca7}},	// [23900] nsul_, شقان, sølu_, арец, 
   {{0x61300724,0x6d4400b5,0x02b40490,0x25bc0067}},	//   _xäll, _cmja, _अजुन, isul_, 
   {{0xf53404ac,0x25bd0609,0xed540107,0x00000000}},	//   סטער_, hsul_, шоф_, --, 
   {{0x25bc007d,0x6d440117,0x305802e4,0x2ee4016b}},	//   ksul_, _emja, _ידיד, ɑnfo_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x91f4025c,0x00000000,0x00000000,0x00000000}},	//   _བརྣག_, --, --, --, 
   {{0x02b40490,0x25bc6bab,0xce3403e6,0x61300108}},	//   _अजून, esul_, _نوێک, _räll, 
   {{0x6130049f,0xab240a83,0x96f807dd,0x971444e4}},	//   _säll, _коса_, уеит_, смиц, 
   {{0x25bc2819,0xab240cef,0x61315caf,0x7c3c002f}},	//   gsul_, _тота_, _päll, lzpr, 
   {{0xf52448a6,0x25e40037,0x00000000,0x00000000}},	//   рфин, _झहरी_, --, --, 
   {{0x61315cb0,0x7c3c17da,0x25bc0356,0xb4b4012d}},	//   _väll, nzpr, asul_, _ज़ी_, 
   {{0x61315cb1,0xb5940133,0x7684004e,0x4ab8000d}},	//   _wäll, _پێدا_, _кылж, _उड़ाव, 
   {{0x61300664,0x823c0023,0x00000000,0x00000000}},	//   _täll, _ኣድማሳ, --, --, 
   {{0xf1bc3adf,0x6130007c,0x00000000,0x00000000}},	//   rsá_, _hälj, --, --, 
   {{0xad98000f,0xf1bd57a0,0x00000000,0x00000000}},	//   _trúk, ssá_, --, --, 
   {{0x613016b5,0xb18401e3,0x6d44032e,0x7c3c0171}},	//   _jälj, _blåö, _smja, dzpr, 
   {{0xee84023a,0xb35401d3,0xd05406be,0x00000000}},	// [23910] рыво, _میگا_, _əbəl, --, 
   {{0xe1f021ec,0xb910063f,0xeca410fc,0x9d1400a8}},	//   _آسي_, renụ_, рјан, одуч, 
   {{0x656c004a,0x31b41cba,0x8cdc0a8a,0x00000000}},	//   îchi, _अबुध, _पाठो, --, 
   {{0x25bd5cb2,0x15f8072a,0x61300037,0x03b8010f}},	//   ysul_, ्टार_, _nälj, רצײל, 
   {{0x6b9800de,0x00000000,0x00000000,0x00000000}},	//   _čugu, --, --, --, 
   {{0xad980022,0x6d455cb3,0x00000000,0x00000000}},	//   _asúg, _umja, --, --, 
   {{0x25bc054e,0x00000000,0x00000000,0x00000000}},	//   wsul_, --, --, --, 
   {{0xd1ec001f,0x8afc01ef,0x25bc0254,0xed10009d}},	//   _ቅጣት_, _okři, tsul_, ргvй_, 
   {{0x80dc045e,0x6d540354,0xb8800008,0xad995cb4}},	//   য়ত্, onxa, _þínu, _brúi, 
   {{0x25bc00a8,0x753802fa,0x04c80d2f,0xad9800ae}},	//   rsul_, ghtz, دودي_, _crúi, 
   {{0x3cf8068f,0xad9801e7,0x8388009d,0x00000000}},	//   _उससे_, _drúi, лбов_, --, 
   {{0x25bcb6ee,0x61300267,0xd83800a8,0x3f9c148b}},	//   psul_, _välm, _тэу_, ítum_, 
   {{0x67389ca2,0xad98032e,0x15b000d1,0xf554cfad}},	//   mhuj, _frúi, _قەيس, _گلوب_, 
   {{0x75384665,0x2ee80334,0x04c805d9,0x673835e5}},	//   chtz, _abcf_, _صوبي_, lhuj, 
   {{0x61300432,0x00000000,0x00000000,0x00000000}},	//   _hälk, --, --, --, 
   {{0x6d54009a,0x6130007c,0x3ce8185d,0x00000000}},	//   enxa, _kälk, घ्ने_, --, 
   {{0x61300664,0x0eb802d5,0x26e8031c,0xb17800fe}},	// [23920] _jälk, русы_, _ཡིནཔ, ståa, 
   {{0x7c3c5ddb,0x6130013d,0x7c2803cd,0x8e5401ec}},	//   tzpr, _mälk, øfro, ітті, 
   {{0x4175272b,0x2ee8022f,0xf1bc011f,0x06f800cd}},	//   _پاکس, _fbcf_, yyák_, ्याव_, 
   {{0x3f980618,0x673809a8,0x7c3c1196,0xdb240205}},	//   _iupu_, jhuj, rzpr, _örüy, 
   {{0x6130023a,0x7c3c01ed,0x81e40eac,0x18b8010b}},	//   _nälk, szpr, ফিক_, аглы_, 
   {{0x3f995cb5,0x61300628,0xada15cb6,0x6da15cb7}},	//   _kupu_, _sälj, _харл, _хира, 
   {{0xf1bc01d3,0xfaa46584,0x57f400d4,0xb8e000cd}},	//   tyák_, _габо, іпит, _्य_, 
   {{0xde4c0020,0x96350261,0x3f98003e,0x613000fd}},	//   _በመንግ, жниц, _mupu_, _bälk, 
   {{0x61315cb8,0x3f995cb9,0x95380124,0xf60807d6}},	//   _välj, _lupu_, изит_, اتبه_, 
   {{0x3f980607,0x00000000,0x00000000,0x00000000}},	//   _oupu_, --, --, --, 
   {{0x67395cba,0x78b800da,0x3f980037,0xad9801e7}},	//   bhuj, _ietv, _nupu_, _tsúg, 
   {{0x78b95aea,0xa3d405f9,0xaef80248,0x394c1e54}},	//   _hetv, ाढ़_, _ijùg, lifs_, 
   {{0xc7643955,0x78b802d5,0x3f980618,0xad9801a8}},	//   _بالى, _ketv, _aupu_, _trúi, 
   {{0x70d00574,0x394d5cbb,0x00000000,0x00000000}},	//   तलेल, nifs_, --, --, 
   {{0x3f995cbc,0x28980677,0x00000000,0x00000000}},	//   _cupu_, רילא, --, --, 
   {{0x78b95cbd,0xceb80124,0xb400009d,0x00000000}},	//   _letv, шәо_, _дүүд, --, 
   {{0x4af82ea3,0x5f74027d,0x80a828d4,0x8afc013a}},	// [23930] یکرد_, سافر, _ज्वे, _ukři, 
   {{0x78b95cbe,0x2f0c0139,0x00000000,0x00000000}},	//   _netv, _bögä_, --, --, 
   {{0x22595cbf,0x394c06af,0xce94013e,0xe588010f}},	//   _نجیب_, difs_, _манъ, אָאָ, 
   {{0x2ee845a7,0xdc88024c,0x00000000,0x00000000}},	//   _ubcf_, ссул_, --, --, 
   {{0xad9800e4,0x613000a2,0x78b854d0,0x66180327}},	//   _arúv, _bälh, _betv, xxuk, 
   {{0x29100227,0x394c00d8,0xec140139,0x9f5801bf}},	//   ñxa_, gifs_, _легә_, rvrå_, 
   {{0x0c040014,0x78b875a4,0x98bc0118,0x60c8033f}},	//   _بوزُ, _detv, livě_, ódmi, 
   {{0x661801c0,0x78b80af9,0xad988011,0x61300108}},	//   txuk, _eetv, _drúv, _pälk, 
   {{0x78b95cc0,0x67395cc1,0xf1bc011f,0xa3c80ce0}},	//   _fetv, rhuj, qyáh_, _लिह_, 
   {{0x613004f3,0x394c014a,0x673876ed,0x3a302dba}},	//   _välk, cifs_, shuj, øype_, 
   {{0x6ab9105a,0x6738009a,0xad9803b2,0xd77401ed}},	//   _keuf, phuj, _grúv, _کالع, 
   {{0xd1dc0020,0x3f9805ce,0x6ab80de2,0x78b800f3}},	//   ንጅት_, _rupu_, _jeuf, _zetv, 
   {{0x80dc045e,0x3f995cc2,0x3cf80316,0x78b804ba}},	//   য়স্, _supu_, _उसले_, _yetv, 
   {{0x3f995cc3,0xb17804f3,0x6ab80618,0x61315cc4}},	//   _pupu_, stån, _leuf, _käli, 
   {{0x6ab807ea,0x4f9401c0,0x613000c5,0x2b4c0175}},	//   _oeuf, зруу, _jäli, kigc_, 
   {{0x6ab95cc5,0x61315cc6,0x394c01b8,0xdcfc0139}},	//   _neuf, _mäli, zifs_, _birğ, 
   {{0x3f980bd7,0xdcfc0139,0xfd480640,0x61300432}},	// [23940] _wupu_, _cirğ, азак_, _läli, 
   {{0x61e4014b,0xd2040150,0xb178007c,0x00000000}},	//   _iqil, _ءبيى, ntål, --, 
   {{0x78b95cc7,0xed4c004b,0xb538008f,0xfaa80214}},	//   _retv, خپل_, סגעש, لهاي_, 
   {{0x78b95cc8,0x6ab80142,0xdcfc0166,0x60dc0175}},	//   _setv, _ceuf, _firğ, lgrm, 
   {{0x394c3a6d,0x61e40227,0x78b95cc9,0x6ab8a4fd}},	//   tifs_, _jqil, _petv, _deuf, 
   {{0x61300780,0x6ab80af9,0xef1c0139,0x3eb0017a}},	//   _bäli, _eeuf, _ehüd_, lbyt_, 
   {{0x394c20ef,0x6ab8009a,0x78b95cca,0xfaa40364}},	//   rifs_, _feuf, _vetv, _маво, 
   {{0x61e55ccb,0x394c07ea,0x61302347,0xdaa400c7}},	//   _oqil, sifs_, _däli, _хгаҩ, 
   {{0xad9803b2,0x00000000,0x00000000,0x00000000}},	//   _frúu, --, --, --, 
   {{0x61315ccc,0xad980252,0x6ab805c7,0x3b0401a9}},	//   _fäli, _grúu, _zeuf, ldoq_, 
   {{0x61e40cfe,0x60dc0b4b,0xe56c06f6,0xb6a40d31}},	//   _aqil, dgrm, خطي_, _диел, 
   {{0xad983b1a,0x3b04fa80,0x42a41321,0xb668013d}},	//   _krút, ndoq_, зурғ, _киез_, 
   {{0x5ec0045e,0x73f8009e,0xc76400db,0x61300166}},	//   ইলাই, ইমেট_, _عامى, _zäli, 
   {{0x3cf40034,0x2d4c031c,0xd76402f2,0x00000000}},	//   ीयों_, eżen_, _بنڤی, --, 
   {{0x61e40194,0x53340b59,0xb4b402db,0x613000fd}},	//   _eqil, _нект, जरी_, _xäli, 
   {{0x81e4015b,0x3dd003cb,0xd1dc0092,0x98bc0118}},	//   ফিজ_, fryw_, ንጅቱ_, tivě_, 
   {{0xd2515ccd,0x61e4009a,0x3dd00368,0x6ab95cce}},	// [23950] _سند_, _gqil, gryw_, _reuf, 
   {{0x6ab95ccf,0xe6b41b37,0x00000000,0x00000000}},	//   _seuf, _इज्ज, --, --, 
   {{0x92dc0f22,0xdc9802bf,0xa6cd5cd0,0x00000000}},	//   ড়ী_, івці_, íčků, --, 
   {{0x50d401d9,0xad982a31,0xab840a89,0x98bc0118}},	//   _بٲگر, _csúc, цузк, pivě_, 
   {{0x6ab80129,0x6130008e,0x80dc0154,0x00000000}},	//   _veuf, _säli, য়র্, --, 
   {{0x91f4003d,0xad980332,0x61300432,0x7c380162}},	//   _བརླག_, _drút, _päli, óbró, 
   {{0x6ab95cd1,0x61300139,0x27f401d3,0x00000000}},	//   _teuf, _qäli, تہاد_, --, 
   {{0x61315cd2,0x7ec400e5,0x28a800cd,0x00000000}},	//   _väli, _tépő, _घ्रि, --, 
   {{0xad98032e,0xfe0c28d4,0xa8a4033a,0x613000fd}},	//   _grút, सियस_, _дрек, _wäli, 
   {{0x3eb0033f,0x61315cd3,0xb3b000f1,0x00000000}},	//   zbyt_, _hälv, ډیوګ, --, 
   {{0xad995cd4,0x29fc0034,0x613001f4,0x74c000f1}},	//   _krús, słać_, _kälv, رښون, 
   {{0xd7755cd5,0x29055cd6,0x29fc012d,0x00000000}},	//   _قانع, ldna_, płać_, --, 
   {{0x29040014,0x2d8002f6,0x61e401d5,0x61300166}},	//   odna_, _ohje_, _qqil, _xälw, 
   {{0x29055cd7,0x3b040007,0x3f800023,0x00000000}},	//   ndna_, zdoq_, _shku_, --, 
   {{0x2904039a,0x3eb005e4,0xd00401d5,0x3b04022e}},	//   idna_, tbyt_, морқ, ydoq_, 
   {{0x61e40135,0x290401ab,0x613001f4,0x3dd00042}},	//   _tqil, hdna_, _nälv, tryw_, 
   {{0x23600428,0xe2983769,0x3eb00267,0xe42001d3}},	// [23960] _ijij_, _лақ_, rbyt_, _رکھي, 
   {{0xee34e20b,0x3eb00ea0,0x6da0023b,0xdc547aaf}},	//   чну_, sbyt_, хифа, وراک, 
   {{0xad995cd8,0x3ea46141,0xdb1c0174,0x30980375}},	//   _brús, _нинг, _avrá, _לשימ, 
   {{0x29055cd9,0x20dc0fc8,0xad995cda,0x3ce400bc}},	//   edna_, _बाँध, _prút, řov_, 
   {{0x387c00f3,0x8e741f52,0xf2dc0042,0xada00cc9}},	//   _sztr_, _журч, ciâu_, _паял, 
   {{0x2d8008e5,0x2904107d,0xad9800d0,0x2d4c025c}},	//   _ghje_, gdna_, _vrút, nżel_, 
   {{0xad981d5d,0x3b080b3e,0xf1bc01d3,0xdec00092}},	//   _frús, _лево_, lyát_, _ስንኳ_, 
   {{0x56955cdb,0x29055cdc,0xf6440fc0,0xf09002e4}},	//   майт, adna_, зхон, ענה_, 
   {{0x20dc7e29,0x35685ec5,0xf1bc01d3,0x95f803ba}},	//   _बांध, йрон_, nyát_, ्टेट_, 
   {{0xaa380375,0x290532d0,0x7684022e,0xb4b43af7}},	//   _התמח, cdna_, bаyn, जरे_, 
   {{0xdb1c0306,0x00000000,0x00000000,0x00000000}},	//   _zvrá, --, --, --, 
   {{0x66e02d8f,0x613000af,0x2d4c031c,0x1dcc01f9}},	//   _गायक_, _mälu, eżel_, ाळात, 
   {{0x79880211,0xa3c800c5,0x6e3800ef,0x00000000}},	//   omfw, _लिअ_, _ļubo, --, 
   {{0x92dc00bd,0xa50407d6,0xa3b40214,0x768401a9}},	//   ড়ে_, _неча_, _کاور_, lаyo, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x290509eb,0x9258014b,0x00000000,0x00000000}},	//   zdna_, _майт_, --, --, 
   {{0x29055cdd,0xe1f003e6,0xb17803cd,0xdcfc0171}},	// [23970] ydna_, _یسی_, ntåk, _nirē, 
   {{0x2ca405d5,0x858400d1,0x00000000,0x00000000}},	//   ùnd_, ﺮﯨﺪﺍ_, --, --, 
   {{0xd251510a,0xad995cde,0x613000c5,0x200c0194}},	//   _سنگ_, _prús, _pälv, ådit_, 
   {{0xf2dc24ba,0x752801f5,0x94fc0327,0x00000000}},	//   ngâ_, _lofz, _ཐིའི_, --, 
   {{0x752804e6,0x3cf804ce,0x61300267,0x290400b5}},	//   _oofz, bepv_, _välv, tdna_, 
   {{0x98c40075,0x2904e614,0x3a302dba,0xf1bc01d3}},	//   ىغىن, udna_, øypa_, lyás_, 
   {{0x29055cdf,0xad9803f2,0x98c400f1,0x61300108}},	//   rdna_, _trús, رغون, _iält, 
   {{0x05a810f5,0xeab000c6,0xdb1c0174,0x61307a45}},	//   овий_, _سعر_, _avræ, _hält, 
   {{0x05b8034c,0xa3dc0574,0x613003fa,0x2a7c022e}},	//   زگشت_, धून_, _kält, _uzub_, 
   {{0xad9800e4,0xa3c80037,0x92dc0154,0x75800244}},	//   _yrúr, _लिआ_, ড়ো_, نینم, 
   {{0xd7f8010a,0x04440139,0x00000000,0x00000000}},	//   _нуц_, фенн, --, --, 
   {{0x7c28143a,0xdbd808a5,0x00000000,0x00000000}},	//   øfri, _mæðg, --, --, 
   {{0x752801c7,0xe6080014,0x84e41367,0x680401e1}},	//   _fofz, _دزاو_, _жолж, béjá, 
   {{0x67280200,0x63680166,0x00000000,0x00000000}},	//   _hogj, kıng, --, --, 
   {{0xafe007d6,0x7d180428,0x67280200,0x00000000}},	//   корл, _òtsi, _kogj, --, 
   {{0x67282ebe,0x26dd5ce0,0xf1bc01d3,0x636800fd}},	//   _jogj, nguo_, gyás_, dıng, 
   {{0xb60408a7,0x61300267,0x3cf800d7,0x00000000}},	// [23980] mráð, _bält, tepv_, --, 
   {{0xdcfc0882,0x672802d3,0xe6055ce1,0x6e2801e3}},	//   _bhrā, _logj, _یش_, ägba, 
   {{0x711800c8,0x0ba81066,0x67280d27,0x3b040024}},	//   _וויפ, كانى_, _oogj, _lūpų_, 
   {{0x3cf8006d,0x15800952,0x973c0960,0x61300267}},	//   _उसके_, ﺮﯨﺴﯩ, _kuće, _välu, 
   {{0x63684952,0x61315ce2,0xf9f8007b,0xa9a02716}},	//   mınd, _fält, تراث_, вичд, 
   {{0x636871e1,0x82fc0327,0x4a0000c7,0x00000000}},	//   lınd, _ཟིའུ_, ыҟуа, --, 
   {{0x613004f3,0x315400c8,0x75280036,0xdcfc00dc}},	//   _häls, ויסן_, _rofz, _ghrā, 
   {{0x636812ca,0xfb140150,0xe9d43531,0xac0401d5}},	//   nınd, _تورج, чкә_, _ўнта_, 
   {{0xd37808a4,0x67280023,0x779001b9,0x6b80054e}},	//   nuće_, _dogj, _ییتا, înge, 
   {{0x63683bc1,0x356801a9,0x2d4c0210,0x00000000}},	//   hınd, ўрин_, eżej_, --, 
   {{0x63682706,0x998002d5,0xad9800d2,0x672801ed}},	//   kınd, šių_, _nsún, _fogj, 
   {{0xd37805ce,0x6368495b,0x9f5c02e2,0xc76419c5}},	//   kuće_, jınd, _èvè_, _كانى, 
   {{0xd3781326,0x63684952,0xad9801e1,0xa5d44e76}},	//   juće_, dınd, _asún, _قبور_, 
   {{0xd3780989,0xe44c5530,0x67280240,0xa5040063}},	//   duće_, اضی_, _zogj, _жеља_, 
   {{0xa3c81b13,0x6368708d,0xa1952d27,0xad995ce3}},	//   _लिए_, fınd, тарч, _arúp, 
   {{0x63680724,0x6130007c,0xa2b00073,0x00000000}},	//   gınd, _sält, ंडण्, --, 
   {{0xd37804b9,0xf1a80272,0xf1a407d6,0xf2dc0142}},	// [23990] guće_, _بابه_, _ўрин, rhâd_, 
   {{0x61300432,0x5d8401b9,0x00000000,0x00000000}},	//   _däls, پلمل, --, --, 
   {{0x63680bfc,0x61315ce4,0x628002f0,0x5ce43b8f}},	//   bınd, _vält, ýmov, ъюта, 
   {{0x61315ce5,0x776000e8,0x63681b0d,0x7e68003e}},	//   _fäls, _njox, cınd, émpé, 
   {{0xad980597,0x61315ce6,0x672801fa,0xbed40375}},	//   _grúp, _tält, _rogj, _אורז_, 
   {{0x6b8005bb,0xdb1c0267,0x97c400d1,0x00000000}},	//   îngb, _avrä, ھتىم, --, 
   {{0x97c55ce7,0x2d4c033f,0x46a4022e,0x00000000}},	//   پتىم, yżej_, найв, --, 
   {{0xad9800c7,0xc60403f5,0x00000000,0x00000000}},	//   _yrúp, езий, --, --, 
   {{0x310c0882,0x6130013d,0x00000000,0x00000000}},	//   ायाः_, _xäls, --, --, 
   {{0x63680ba5,0xf8cc00dc,0x00000000,0x00000000}},	//   zınd, हृदय, --, --, 
   {{0x63684947,0x973c01fa,0x67280200,0x2d4c0210}},	//   yınd, _suće, _togj, eżek_, 
   {{0x63695ce8,0x00000000,0x00000000,0x00000000}},	//   xınd, --, --, --, 
   {{0xb6042242,0x6368456f,0xa3c806b1,0x06c00150}},	//   rráð, vınd, _लिक_, _ﺭﻩﺳﻪ, 
   {{0xb6042242,0xd6d80032,0x61300621,0xd3780841}},	//   sráð, _етә_, _räls, vuće_, 
   {{0x63689d58,0x44215ce9,0x6130007c,0x6fa40220}},	//   tınd, _çh_, _säls, _ﻋﺎﻧﺎ_, 
   {{0x613001e6,0x2ba000ab,0x00000000,0x00000000}},	//   _päls, _ओढ़ा, --, --, 
   {{0x63680abc,0x6e400139,0x00000000,0x00000000}},	// [239a0] rınd, гетз, --, --, 
   {{0x63690b83,0x61100085,0x53641ee0,0x613001e6}},	//   sınd, kɔlɔ, _ሲኖዶስ_, _väls, 
   {{0xf53404ac,0xd3783879,0x63684a98,0x40940075}},	//   עטער_, suće_, pınd, _ярит, 
   {{0x63691517,0xd37816a3,0xad9800ae,0x8eb000db}},	//   qınd, puće_, _trúp, _نەفت, 
   {{0x7f540455,0xf2d0010f,0x00000000,0x00000000}},	//   miyq, רעד_, --, --, 
   {{0xf8055cea,0xfd9400d1,0x201c0129,0x31ac00d1}},	//   ечин, _чөбә_, _àvis_, ﻳﺪﯨﻜ, 
   {{0xdb1c0267,0x00000000,0x00000000,0x00000000}},	//   _avrå, --, --, --, 
   {{0x6284468a,0x7f540113,0x588400c7,0x2d4c0210}},	//   _ozio, niyq, нықа, yżek_, 
   {{0xa6f00166,0x00000000,0x00000000,0x00000000}},	//   узыш, --, --, --, 
   {{0xa3c80bb2,0x7f540784,0xfdfc000d,0x00000000}},	//   _लिख_, hiyq, _उनईस_, --, 
   {{0x62855ceb,0x7bdd5cec,0x7999284d,0x931405af}},	//   _azio, nupu, _iitw, نودش, 
   {{0x799801b2,0x35a55ced,0x63680790,0xa3c80210}},	//   _hitw, _задг, yıne, _लिऐ_, 
   {{0x7bdc001f,0x7998cd30,0x37e00154,0x317001d5}},	//   hupu, _kitw, _মনির, лғит, 
   {{0x79980003,0x62855cee,0x6fb4024c,0x00000000}},	//   _jitw, _dzio, нҳор_, --, 
   {{0x79995cef,0x62855cf0,0x7ae09d8d,0x200c013c}},	//   _mitw, _ezio, kgot, ådip_, 
   {{0x79995cf1,0x5214eea5,0x7bdc8507,0xe478011a}},	//   _litw, _адит, dupu, _מרוכ, 
   {{0xdef41411,0x3f9c0ad9,0xa92000d0,0x9f0487ac}},	// [239b0] ыпты, ítur_, úžko, دوقو, 
   {{0x7bdd5cf2,0x79995cf3,0x92b80eac,0x75380112}},	//   fupu, _nitw, _চায়_, nktz, 
   {{0x7bdc000d,0x00000000,0x00000000,0x00000000}},	//   gupu, --, --, --, 
   {{0x5b249702,0x79995cf4,0x636803b9,0x00000000}},	//   льча, _aitw, mınc, --, 
   {{0x79995cf5,0xd7f8084c,0x636806b9,0x48e40a31}},	//   _bitw, _apă_, lınc, волв, 
   {{0x79995cf6,0x7bdd0d1e,0x7ae001c0,0x80a80882}},	//   _citw, bupu, agot, _ज्ञे, 
   {{0x7998073c,0x7bdd5cf7,0x63687225,0xdcfc0064}},	//   _ditw, cupu, nınc, _airė, 
   {{0x6d5497af,0x00000000,0x00000000,0x00000000}},	//   lixa, --, --, --, 
   {{0x7998009f,0xb5c094d4,0x572400db,0x0564009b}},	//   _fitw, айыл, ارىق, квин, 
   {{0x6d555cf8,0xa5040075,0x79995cf9,0x636803ee}},	//   nixa, رىجە_, _gitw, kınc, 
   {{0x6b99315e,0xe854030d,0x00000000,0x00000000}},	//   _kiug, _чĕнн, --, --, 
   {{0x79983dd4,0x63683535,0x6d54009d,0x491892c1}},	//   _zitw, dınc, hixa, पाको_, 
   {{0x79995cfa,0x6d555cfb,0xad987bd7,0x6b9800a3}},	//   _yitw, kixa, _asúm, _miug, 
   {{0x69c95cfc,0x7ae15cfd,0x68e15cfe,0x6b995cff}},	//   isge, zgot, ngnd, _liug, 
   {{0x673801f7,0x6d54005a,0x7f540113,0x69c8002f}},	//   okuj, dixa, tiyq, hsge, 
   {{0x6b981028,0x973c22c1,0x63a15d00,0x69c80af9}},	//   _niug, _kuća, _iunn, ksge, 
   {{0x63a03d25,0x73300075,0x62840ffb,0x69c801a4}},	// [239c0] _hunn, _خىيا, _uzio, jsge, 
   {{0x7bdd5d01,0x6b981140,0x69c870c7,0x6d5490ad}},	//   tupu, _aiug, dsge, gixa, 
   {{0x7c946c88,0x63a15d02,0x82342c6c,0x6b995d03}},	//   трац, _junn, _سرکا, _biug, 
   {{0x79995d04,0x63a15d05,0x67395d06,0x69c87585}},	//   _sitw, _munn, jkuj, fsge, 
   {{0x7bdd5d07,0x69c8fc8e,0x63a15d08,0xf9881129}},	//   supu, gsge, _lunn, وخته_, 
   {{0x7bdd5d09,0x7ae15d0a,0x6738033f,0x63a15d0b}},	//   pupu, sgot, ekuj, _ounn, 
   {{0xe3a45f8e,0x6b995d0c,0x69c80660,0x63a15d0d}},	//   _خر_, _fiug, asge, _nunn, 
   {{0x6b995d0e,0x79995d0f,0xdb080598,0xe3ac09bd}},	//   _giug, _witw, älär, _কিংব, 
   {{0xd378098d,0x79995d10,0xb9040022,0x55742996}},	//   juća_, _titw, _изак, лгит, 
   {{0x79980e29,0x973c34df,0xd3782220,0x63682fbe}},	//   _uitw, _duća, duća_, yınc, 
   {{0x63a15d11,0xe3ac143e,0x7538002f,0x1418007b}},	//   _cunn, يرَ_, rktz, ريحة_, 
   {{0x63a15d12,0xef1c04cc,0x6d555d13,0xcfb00154}},	//   _dunn, _chül_, zixa, _ছিলন, 
   {{0xd378098d,0x63a0020b,0x8fd00184,0xd5b0028e}},	//   guća_, _eunn, әҙмә, _افت_, 
   {{0x63a15d14,0x63681b0d,0xa1641d39,0x00000000}},	//   _funn, tınc, ањск, --, 
   {{0x550400d1,0x613001e3,0x00000000,0x00000000}},	//   _ачқа, _välp, --, --, 
   {{0xf1a55d15,0xe3ad5d16,0x63682fbe,0x69c93cd6}},	//   _ирон, _برو_, rınc, ysge, 
   {{0x6d555d17,0xe0d804c5,0x5f955d18,0x6368029f}},	// [239d0] tixa, দ্ধভ, ритт, sınc, 
   {{0x63a15d19,0xb0b481e9,0x6b995d1a,0x63680790}},	//   _yunn, _अभिग, _siug, pınc, 
   {{0x6b991208,0x6d555d1b,0x63681d89,0xd1303321}},	//   _piug, rixa, lına, _نمک_, 
   {{0x69c95d1c,0xcb1c0034,0x6d540117,0xdbf800b8}},	//   tsge, फाइड_, sixa, _cāñj, 
   {{0x6d555d1d,0x69c87884,0x63683535,0x6b980076}},	//   pixa, usge, nına, _viug, 
   {{0x69c95d1e,0x996401e0,0xc8c81291,0x00000000}},	//   rsge, ҫтәл, روبن_, --, 
   {{0x69c95d1f,0x38c8168d,0xd37801fa,0x6ed405d7}},	//   ssge, راوی_, zuća_, यणपु, 
   {{0x69c80d47,0x63a0eeb0,0x636871d5,0x67380194}},	//   psge, _runn, kına, ukuj, 
   {{0x63a15d20,0xad981aac,0x7ae800aa,0x6738bbaa}},	//   _sunn, _nsúk, _سولې_, rkuj, 
   {{0x63a15d21,0x63682791,0x57a4035b,0x8428011c}},	//   _punn, dına, ышәа, ежов_, 
   {{0x63a15d22,0xdb500014,0xa2b00a8a,0xf8b0011a}},	//   _qunn, _طَے_, ंडल्, _השב_, 
   {{0x63a09f65,0x442401e0,0x63680e2d,0x0708007b}},	//   _vunn, rxl_, fına, _سيتي_, 
   {{0x973c0bb8,0x63a15d23,0xbb38008f,0x95c400ec}},	//   _kućn, _wunn, גערי, _نينه, 
   {{0x75d005d9,0x63a017ce,0xd3782630,0x71a000c7}},	//   _ايوا, _tunn, ruća_, сарз, 
   {{0xd3795d24,0x63a122e3,0x63e00137,0x8d8c0150}},	//   suća_, _uunn, _ئيبە, _ﺒﺎﺘﺕ_, 
   {{0x33280354,0xd2541547,0x62240eff,0x63680139}},	//   cjcx_, اییش_, _نوبە, bına, 
   {{0xcb1c4142,0xb178007c,0x6e340023,0x00000000}},	// [239e0] फाईड_, ttåt, _የዘኻኽ, --, 
   {{0xed540124,0x5f0401ec,0xdbf8002b,0xf2dc0051}},	//   гоу_, ызға, _sāñj, nhân_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbda50596,0xef1c1570,0xb178df7a,0xf1bc0005}},	//   _محسو, _gnü_, ståt, ixán_, 
   {{0x5d0800c7,0x7e9800e5,0x00000000,0x00000000}},	//   _иҭан_, _سنسر_, --, --, 
   {{0xb1782b96,0x1c04141f,0x7af400dc,0x00000000}},	//   ltår, रबदल_, _śatā, --, 
   {{0x674c044e,0x7d0c009a,0x0c781919,0xb86400f1}},	//   _ንህዝብ, _iabs, _асты_, داشو, 
   {{0xa8153d7c,0xec755d25,0xb1780158,0x3f90037e}},	//   اتور_, _спс_, ntår, nmyu_, 
   {{0x7d0c1210,0xdcfc00dc,0xb3d00131,0x88c40137}},	//   _kabs, _nirī, әймә, اتۇل, 
   {{0xdb1c00cc,0x7d0c0067,0xf4e801b9,0x93f4f40f}},	//   _avrø, _jabs, хфий_, апоц, 
   {{0x7d0c0009,0xb17803cd,0x00000000,0x00000000}},	//   _mabs, ktår, --, --, 
   {{0x7d0d5d26,0x9295471c,0x63683bc1,0x69d807b7}},	//   _labs, ианц, tına, _निमी, 
   {{0x36343779,0xb178007c,0x00000000,0x00000000}},	//   _حراس, dtår, --, --, 
   {{0x7d0c4091,0x973c07f5,0x63695d27,0x00000000}},	//   _nabs, _kućo, rına, --, 
   {{0xdfd80801,0xe81400e1,0xe538011a,0x6554011a}},	//   лът_, थिया_, _אתגר, _תבוא_, 
   {{0x7d0cc562,0x1fb55d28,0x6368083c,0xaef801e1}},	//   _aabs, ссёр, pına, _ijùk, 
   {{0x7d0d5d29,0xdcfc002b,0x1dc007af,0xd0d402e8}},	// [239f0] _babs, _girī, शीलत, _копъ, 
   {{0x7d0d5d2a,0x17040327,0x7cf801bf,0x634400e5}},	//   _cabs, _ཙིའམ_, _røræ, dőny, 
   {{0x7d0d5d2b,0x3ea53760,0x2d4c033f,0x6b8000e4}},	//   _dabs, žota_, dżet_, îngo, 
   {{0xb178049f,0xaac404d3,0x00000000,0x00000000}},	//   fråg, اتان, --, --, 
   {{0x36dc05f9,0x6f0d5d2c,0x6368008e,0x00000000}},	//   _गाड़ी_, _iacc, kınn, --, 
   {{0x6f0d5d2d,0x13ac0c58,0x7d0c0548,0x1864001f}},	//   _hacc, কীয়, _gabs, _ድንጋይ_, 
   {{0x63680724,0x6f0d5d2e,0xc84400ee,0x02e4000d}},	//   dınn, _kacc, рейй, _कालह_, 
   {{0xb1785f03,0x6f0d5d2f,0x00000000,0x00000000}},	//   lråd, _jacc, --, --, 
   {{0x6f0d5d30,0x63680598,0x80b80882,0x2d4c031c}},	//   _macc, fınn, ्रमे, bżet_, 
   {{0x6f0d5d31,0x7d0c0050,0x5a355d32,0xb17805ac}},	//   _lacc, _xabs, _унут, nråd, 
   {{0xf2dc000f,0x6f0c0267,0x98bc00c0,0x00000000}},	//   rhân_, _oacc, eivė_, --, 
   {{0xad980077,0xa3a82017,0x6f0c1ef9,0xdcfc02b5}},	//   _crúz, _कंठ_, _nacc, _pirī, 
   {{0xb1795d33,0xf2dc0051,0x6368008e,0x00000000}},	//   kråd, phân_, bınn, --, 
   {{0xd378098d,0x6b5400b4,0x16640212,0x63680139}},	//   vrće_, ụgha, _увім, cınn, 
   {{0x0fd82bce,0x7d0d5d34,0x434400d1,0xb1782c95}},	//   льты_, _rabs, _вейв, ttår, 
   {{0x6f0d5d35,0x7d0c89fa,0x24a40153,0x00000000}},	//   _cacc, _sabs, šumą_, --, 
   {{0x6f0d5d36,0x2a7c0218,0x7d0c00df,0xb1781347}},	// [23a00] _dacc, _nyub_, _pabs, rtår, 
   {{0x7d0c1f9f,0xb1780423,0x00000000,0x00000000}},	//   _qabs, gråd, --, --, 
   {{0x6f0c9acb,0x2a7c7dec,0x7ac55d37,0xd378009b}},	//   _facc, _ayub_, асле, srće_, 
   {{0x6f0d5d38,0x3dc00120,0x7d0c1c1d,0xdcfc0022}},	//   _gacc, _twkw_, _wabs, _mirĩ, 
   {{0x7d0d5d39,0xead4009e,0x00000000,0x00000000}},	//   _tabs, সভূম, --, --, 
   {{0x864004b2,0x00000000,0x00000000,0x00000000}},	//   ባይነት, --, --, --, 
   {{0xed5445e7,0x2a7c0066,0x96f80395,0x109000d1}},	//   _тор_, _eyub_, гейт_, ﻘﯩﺪﯨ, 
   {{0x6f0c002e,0x63682791,0x00000000,0x00000000}},	//   _xacc, dıno, --, --, 
   {{0x63680724,0x7588399b,0xb8d41291,0x00000000}},	//   tınn, ксов_, _نتاش, --, 
   {{0x7bdc0869,0x69d89f56,0x00000000,0x00000000}},	//   orpu, _निती, --, --, 
   {{0xded40020,0x63680724,0xd6c43e58,0xc8b40220}},	//   ርመን_, rınn, _همای, _ысты, 
   {{0x63680724,0x704c0092,0xa7180408,0x66e00037}},	//   sınn, _ማመቻቸ, _ашшĕ_, _गाएक_, 
   {{0x6f0d5d3a,0x2038001f,0xb2840c98,0x872400f1}},	//   _racc, _ያመለክ, рынк, _دعلم, 
   {{0x63686d5b,0xad9800ae,0x93440133,0x00000000}},	//   lınl, _tsúi, _گرتۆ, --, 
   {{0x6f0cc5bf,0xb1780623,0x64c00c75,0xb4e00073}},	//   _pacc, vråd, _بيىل, धली_, 
   {{0xddc4068f,0x6f0c208d,0xe81400dc,0x10a40116}},	//   dził, _qacc, थिता_, риңн, 
   {{0x7bdd5d3b,0xb178795b,0x6ca4665a,0x2d4c012d}},	// [23a10] erpu, tråd, ареж, dżer_, 
   {{0x6f0d5d3c,0x2ee8037e,0x2d4c025c,0xed041d39}},	//   _wacc, _wccf_, eżer_, јџан, 
   {{0x6f0d5d3d,0x63681918,0x2c2400c7,0x00000000}},	//   _tacc, kınl, шьаг, --, 
   {{0xb1780ac8,0x6f0c908b,0x7ea4010b,0xa3f4010f}},	//   sråd, _uacc, _гурҗ, שמאק_, 
   {{0x63680baf,0x7bdc0eda,0xde6400a7,0xb17812e8}},	//   dınl, arpu, _дърп, pråd, 
   {{0x07a4520c,0x00000000,0x00000000,0x00000000}},	//   бакн, --, --, --, 
   {{0x06901c5c,0x98f447e7,0x6d455d3e,0x00000000}},	//   ﻟﯩﻨﯩ, تثنا, _ilja, --, 
   {{0x63680e2d,0x37a800f2,0xc724702f,0xe94400f2}},	//   gınl, دئوی_, сдий, درچی, 
   {{0x6d4439ae,0x8c4402dd,0x6ac000dc,0x2a7c06be}},	//   _klja, _теңе, शरीर, _uyub_, 
   {{0xdcfc00e4,0x63680790,0x00000000,0x00000000}},	//   _pirĩ, tıno, --, --, 
   {{0x6d440e04,0x10900131,0x63680205,0x47a40154}},	//   _mlja, ﻘﯩﺮﯨ, bınl, _গৌরী, 
   {{0xe7846be1,0x00000000,0x00000000,0x00000000}},	//   _тузо, --, --, --, 
   {{0xd7755d3f,0x6d455d40,0xb178332e,0x00000000}},	//   _بالع, _olja, ttåp, --, 
   {{0xb1795d41,0x98ac00ef,0x7bdc01e3,0x00000000}},	//   yråe, _kodā_, yrpu, --, 
   {{0x6368e16d,0xb1780fac,0x7dc40133,0xded40092}},	//   lınm, rtåp, ڵقان, ርመኑ_, 
   {{0x9f64010b,0xe51800cd,0xc1d001af,0x00000000}},	//   _öwüt_, _भोति_, _нөгә, --, 
   {{0x636807b3,0x2004fd87,0x80b816ae,0xada02de5}},	// [23a20] nınm, ňmi_, ्रदे, заул, 
   {{0xc1041c4e,0x7c944316,0xaef801e1,0x2d4c025c}},	//   _اودي, брец, _ojùw, wżer_, 
   {{0x63680ab7,0x0ba83f7b,0x0d980387,0xb7e000eb}},	//   yınl, لانى_, ртты_, _মন্ট, 
   {{0xf0900302,0x63695d42,0x6d455d43,0xba240276}},	//   _מנת_, xınl, _elja, йдек, 
   {{0xb34403b7,0x6d4402c4,0x00000000,0x00000000}},	//   luçõ, _flja, --, --, 
   {{0xcdc4039b,0x63682ca8,0x00000000,0x00000000}},	//   _фарқ, dınm, --, --, 
   {{0x63680baa,0x00000000,0x00000000,0x00000000}},	//   tınl, --, --, --, 
   {{0x35e40474,0x7c3c959f,0x3eb00077,0x6b600276}},	//   бцов, mypr, ncyt_, _екса, 
   {{0x7c3c127b,0xfa695d44,0x63680ac1,0x2b74006c}},	//   lypr, _саак_, rınl, _اینگ_, 
   {{0x63681ae4,0xb4e05d9c,0x478801e0,0x00000000}},	//   sınl, धले_, лсөм_, --, 
   {{0xa3a80c2e,0x7c3cbde6,0x46080327,0x98ac0171}},	//   _कूद_, nypr, _ཀརྨས_, _godā_, 
   {{0xb34406ed,0x973c1674,0x9ad401f2,0x63680139}},	//   duçõ, _mućk, zịny, bınm, 
   {{0x98ac1f14,0x6130023a,0x9ad402e3,0x66e155aa}},	//   _चलाए, _häly, yịny, _хоча, 
   {{0xe3ac53e2,0xdb000023,0x613001f4,0x59e00037}},	//   بری_, _bimë, _käly, _निनर, 
   {{0x53340dd8,0x656d5d45,0xb3d000ee,0x06901870}},	//   _мект, éche, _эййә, ﻟﯩﻠﯩ, 
   {{0xb8e849a6,0x6d4405a1,0xdb000023,0x91c4013d}},	//   _ིབ_, _slja, _dimë, _мәгл, 
   {{0x6d440bb8,0xb354158b,0x6ca4007b,0x200c0162}},	// [23a30] _plja, _نیگا_, مصال, ædir_, 
   {{0x973c00f3,0x7c3c00e4,0xddc4012d,0x00000000}},	//   _bućk, fypr, dziń, --, 
   {{0xb3440120,0x7c3c03ac,0x8f34030d,0xa06800d8}},	//   cuçõ, gypr, _денц, _гаќа_, 
   {{0x31ac0724,0xdb00007f,0xa3a8107c,0xb17801e3}},	//   _küz_, _jimè, _कंस_, bråc, 
   {{0x6d440010,0x497401c6,0xc8c804f2,0xaec00150}},	//   _tlja, олдс, لوشن_, _мұңл, 
   {{0xdb00007f,0x973c107d,0x7d08002d,0x98ac0171}},	//   _limè, _fućk, ôfst, _podā_, 
   {{0x7c3d5d46,0xcb28004b,0xdb0000c7,0x00000000}},	//   cypr, _پړاو_, _oimè, --, 
   {{0xed1001c6,0x00000000,0x00000000,0x00000000}},	//   сгvй_, --, --, --, 
   {{0xdb1c008c,0x31ad5d47,0x5a355d48,0x59e002e5}},	//   _evró, _nüz_, _ентт, _नियर, 
   {{0xd3780989,0xad981aac,0xdb00067c,0x58d55d49}},	//   vrća_, _isús, _aimè, _ноут, 
   {{0x499001d3,0x9928447e,0xb0bc28f0,0x80b807d0}},	//   _فیچر, _уюта_, ्रनग, ्रसे, 
   {{0x27e4ba6b,0x59e01b57,0x31ac0139,0xdb000240}},	//   munn_, _निमर, _büz_, _rimë, 
   {{0xdb001497,0x6d48005f,0x7c3c033f,0x27e55d4a}},	//   _dimè, īgaj, zypr, lunn_, 
   {{0x29055d4b,0x31ac51b7,0x94740214,0x044465d5}},	//   nena_, _düz_, _کدها, _мелн, 
   {{0x27e40d04,0x7c3c20a2,0xdb00007f,0x290401c4}},	//   nunn_, xypr, _fimè, iena_, 
   {{0x29055d4c,0xb34406ed,0xfe452fcf,0x7c3c0306}},	//   hena_, ruçõ, онбо, vypr, 
   {{0x92e82309,0x27e55d4d,0x31ac0790,0x0eb800ee}},	// [23a40] _ارىق_, hunn_, _güz_, сусы_, 
   {{0x63a4007d,0x7c3c127b,0x98ac0311,0x27e55d4e}},	//   _hiin, typr, _modă_, kunn_, 
   {{0x63a55d4f,0x3ea55d50,0xbea55d51,0xbc691cb7}},	//   _kiin, _минг, _манк, جمان_, 
   {{0x63a55d52,0x31ac046c,0x7c3c127b,0x80b8043e}},	//   _jiin, _yüz_, rypr, ्रवे, 
   {{0xdb015d53,0x8fb4004b,0xad9801ed,0x613001f4}},	//   _jimé, _ولیږ, _csús, _säly, 
   {{0x63a55d54,0xbbe81272,0x27e55d55,0xdb000129}},	//   _liin, _پرسم_, funn_, _mimé, 
   {{0x27e46672,0xdb000022,0xbb44005b,0xe89000c7}},	//   gunn_, _limé, _девк, машь, 
   {{0x63a55d56,0x96340d84,0x973c098d,0xdb00035b}},	//   _niin, зниц, _kući, _oimé, 
   {{0x3568020a,0xdb00df8a,0x6284062c,0xd5c401ad}},	//   ирон_, _nimé, _nyio, लींज, 
   {{0x63a40618,0x27e55d57,0x85e00952,0xdb015d58}},	//   _aiin, bunn_, رۋىن, _simè, 
   {{0xad1800c8,0x31ac0724,0xb8086762,0xdb0087aa}},	//   בויר, _süz_, _خيام_, _aimé, 
   {{0x74b819e5,0x63a5317e,0x35a40022,0x998c00ee}},	//   _श्रृ, _ciin, _дадг, _şoňa_, 
   {{0xd37816a3,0xddc4005f,0xdb0001e7,0x1b1c00cc}},	//   nući_, lziņ, _cimé, _থকাই_, 
   {{0x63a40421,0xdb005a4e,0xa5043591,0xe3ac00f1}},	//   _eiin, _dimé, _меча_, عرۍ_, 
   {{0x63a40262,0xb3c801c6,0x00000000,0x00000000}},	//   _fiin, _тулж_, --, --, 
   {{0xa3b4f6c4,0x29055d59,0x63a47bc3,0xd37805ce}},	//   _باور_, zena_, _giin, kući_, 
   {{0xd3781326,0x29055d5a,0xdb015d5b,0x27e4f00d}},	// [23a50] jući_, yena_, _gimé, zunn_, 
   {{0xd37804b9,0x63a55d5c,0x2904eb82,0xf1bd5d5d}},	//   dući_, _ziin, xena_, mpá_, 
   {{0x29055d5e,0x63a4054c,0x92ac015b,0x4ab9181e}},	//   vena_, _yiin, গরী_, буля_, 
   {{0x29055d5f,0xddc4005f,0x63a51249,0x27e404e6}},	//   wena_, dziņ, _xiin, vunn_, 
   {{0x29055d60,0xd3780b91,0xdb0004d4,0x27e4020c}},	//   tena_, gući_, _ximé, wunn_, 
   {{0xe8146bf6,0x27e55d61,0x1dc4012d,0x636803e0}},	//   थिला_, tunn_, _लौटत, tınk, 
   {{0x29055d62,0x47595d63,0x27e4003e,0x4c94009d}},	//   rena_, йрия_, uunn_, _хивс, 
   {{0x29055d64,0x27e4037f,0x63689f9f,0x00000000}},	//   sena_, runn_, rınk, --, 
   {{0x29055d65,0x63a55d66,0x27e55d67,0x00000000}},	//   pena_, _riin, sunn_, --, 
   {{0x63a55d68,0x2904dc40,0x98ac0311,0x6824084c}},	//   _siin, qena_, _vodă_, _мьез, 
   {{0xdb00b248,0x628405b1,0x00000000,0x00000000}},	//   _simé, _syio, --, --, 
   {{0x6ffc0327,0xd8742f56,0x00000000,0x00000000}},	//   _ཝརྟུ_, _غالب, --, --, 
   {{0x63a55d69,0xd7540137,0x8ed0009e,0x80b81a47}},	//   _viin, _تئلب, িলাগ, ्रले, 
   {{0x25bd5d6a,0x66195d6b,0xb3440139,0x63a55d6c}},	//   mpul_, mvuk, _arçı, _wiin, 
   {{0x63a55d6d,0x25bd5d6e,0xd37801fa,0x66195d6f}},	//   _tiin, lpul_, zući_, lvuk, 
   {{0x4f9405f5,0x6618009f,0x636806be,0xe7e00210}},	//   друу, ovuk, kıni, _गिना_, 
   {{0xfce55d70,0x25bc009b,0x66180083,0x93244fca}},	// [23a60] зозо, npul_, nvuk, _زرين, 
   {{0xd378098d,0x98ac0006,0x7c9400f0,0xb178007c}},	//   vući_, _kodą_, прец, lrån, 
   {{0x315430fb,0xfaa80214,0x6d880254,0x00000000}},	//   _זיין_, مهاي_, müal, --, 
   {{0xeb9473ea,0x59e01a2a,0xd3781710,0xdcfc00ef}},	//   пих_, _निदर, tući_, _birģ, 
   {{0x3f800194,0xcdf400fd,0x201c01ef,0x98bc013a}},	//   _ikku_, _очры, _švih_, chvě_, 
   {{0xd37805a1,0xcfa859c7,0x66195d71,0xe51800bc}},	//   rući_, _دایم_, dvuk, _भोलि_, 
   {{0xaef80086,0xa3a804aa,0xb178007c,0xc4b000eb}},	//   _ijùr, _कूल_, krån, ছরাঙ, 
   {{0xddc4005f,0xf1bc00e4,0x00000000,0x00000000}},	//   rziņ, ypá_, --, --, 
   {{0xeb94d562,0xd9102c04,0xb9c400cf,0x00000000}},	//   _хит_, _لیش_, _رقاي, --, 
   {{0xb4d40a94,0xddc400e2,0x00000000,0x00000000}},	//   िणे_, pziņ, --, --, 
   {{0x3f802c98,0x395c003e,0x656c004a,0x25bc00b5}},	//   _okku_, _imts_, écha, apul_, 
   {{0x6d48005f,0x6618004c,0xd6d002f2,0x16280150}},	//   īgai, bvuk, _شقت_, _وياۋ_, 
   {{0x42a40e46,0xf1bc0118,0x98d012eb,0x00000000}},	//   дурғ, upá_, _सजाए, --, 
   {{0x3f815d72,0xad9809c2,0x92ac015b,0x61e001ed}},	//   _akku_, _apún, গরে_, ámla, 
   {{0xa158426c,0xf36401af,0x00000000,0x00000000}},	//   чару_, _нтин, --, --, 
   {{0x9f341d31,0x37dc00fe,0x00000000,0x00000000}},	//   несі, _মহাৰ, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [23a70] --, --, --, --, 
   {{0x9d14a710,0xef1c07c5,0xd2f801d9,0x7d08002d}},	//   ндуч, _chür_, _اکھا_, ôfsp, 
   {{0x3f8003a0,0x6618cc1a,0xa15808a8,0xcb340395}},	//   _fkku_, zvuk, _מבזה_, межъ, 
   {{0x395d5d73,0x7fd406a9,0x952c031c,0xdc980212}},	//   _amts_, _קורס_, _ཧོའི_, ївці_, 
   {{0x6d880254,0x00000000,0x00000000,0x00000000}},	//   lüam, --, --, --, 
   {{0x2cb4031c,0x6d400267,0x87b80124,0xb4d400cd}},	//   _བཅིབ, önad, оуит_, िणो_, 
   {{0x2d800023,0x66e00248,0xa8c800f7,0xdd9400db}},	//   _ikje_, _nìkà, _ۇباق_, _чары, 
   {{0x65c001e1,0x66180254,0x00000000,0x00000000}},	//   _níhò, tvuk, --, --, 
   {{0xa8a4005e,0xd3782220,0x2bc80d79,0x98ac0153}},	//   _ерек, nuću_, ाठवा, _sodą_, 
   {{0x25bcb55c,0x66180cf8,0x00000000,0x00000000}},	//   rpul_, rvuk, --, --, 
   {{0x25bc0b21,0x661826bb,0xb1780267,0xb8800419}},	//   spul_, svuk, trån, šírk, 
   {{0x66e00248,0xd37807f5,0x25bc00e8,0x3ea400de}},	//   _dìkà, kuću_, ppul_, žoti_, 
   {{0xd37805ce,0x6368002d,0x98ac033f,0xdcfc0dfe}},	//   juću_, jűne, _wodą_, _skrč, 
   {{0x59e00574,0x26cc01c0,0x66e001e1,0xd37808a4}},	//   _निसर, _hego_, _fìkà, duću_, 
   {{0x71a15d74,0x92ac00fe,0xb17801e3,0x00000000}},	//   тарз, গৰে_, prån, --, 
   {{0x26cc006d,0x8f1400f0,0x00000000,0x00000000}},	//   _jego_, нфуч, --, --, 
   {{0xd37807f5,0x6368000f,0xbe6801c6,0xaee000b8}},	// [23a80] guću_, rűnd, цааж_, _suṃd, 
   {{0x26cc7483,0x626407d6,0x6368045f,0xaee00055}},	//   _lego_, _овқа, sűnd, _puṃd, 
   {{0x409407d6,0x201c01ed,0xfb8046ec,0x25a40100}},	//   _юрит, _évi_, نگری, _minl_, 
   {{0x26cc1326,0x3f800b45,0x2d800158,0x395c0472}},	//   _nego_, _ukku_, _ekje_, _smts_, 
   {{0xbda000c7,0xef1c002f,0x6288012d,0x00000000}},	//   _ақаҩ, _thür_, ędow, --, 
   {{0xf84800d4,0x00000000,0x00000000,0x00000000}},	//   жчий_, --, --, --, 
   {{0x26cc0f8b,0x59e000dc,0xb904121d,0x25ac02d2}},	//   _bego_, _निवर, _भय_, _augl_, 
   {{0x26cc617f,0x628800ac,0xf64402a9,0x25ac032e}},	//   _cego_, ədov, дхон, _bugl_, 
   {{0x6a815d75,0xe9d4a2fb,0x25ac0c86,0x26cc0014}},	//   _алта, _окт_, _cugl_, _dego_, 
   {{0x395d5d76,0x26cc01d9,0xdb0000c7,0x25ac02d2}},	//   _umts_, _eego_, _mimí, _dugl_, 
   {{0xdb015d77,0x973c63e0,0xb4ac0c70,0x00000000}},	//   _limí, _suću, _कली_, --, 
   {{0x26cc01a6,0x79880042,0x63680139,0x00000000}},	//   _gego_, llfw, kınu, --, 
   {{0x590c0c99,0x25ac0114,0xdb000ffb,0x63680790}},	//   _གྲོས_, _gugl_, _rimì, yınv, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x26cc0230,0xdb0001e7,0x66d80166,0xaee000b8}},	//   _yego_, _aimí, _fäkı, _ghṛb, 
   {{0x9f580d29,0x2d8003a1,0x26cc014b,0x00000000}},	//   ntrè_, _skje_, _xego_, --, 
   {{0x1df8b0b9,0x11d800c6,0xdb000332,0x5f580092}},	// [23a90] меты_, _عودة_, _cimí, _ሀገራቸ, 
   {{0xdb00003a,0xf2dc0142,0x636800e5,0x00000000}},	//   _dimí, rhâu_, rűne, --, 
   {{0xd3783879,0xdb00026c,0xf081104b,0xeab00a11}},	//   suću_, _timì, _شیرپ, نعش_, 
   {{0xad9800e4,0xc078004d,0xd378107d,0xdb000332}},	//   _ipúm, _lượm_, puću_, _fimí, 
   {{0x26cd5d78,0x09e49808,0x7c2000b0,0x2bac000d}},	//   _rego_, холн, āora, _जूरा, 
   {{0x26cd5d79,0xdd980220,0x681000ac,0x59e00825}},	//   _sego_, _жшс_, _hədə, _निरर, 
   {{0x26cd5d7a,0xdb00025a,0x25ac04cc,0x68100213}},	//   _pego_, _dimâ, _sugl_, _kədə, 
   {{0x98ac0210,0x00000000,0x00000000,0x00000000}},	//   _modę_, --, --, --, 
   {{0x68100cc1,0x25a40286,0x6ab801f2,0x06840137}},	//   _mədə, _pinl_, _ifuf, эгин, 
   {{0x26cc0ac5,0x6acc012c,0x00000000,0x00000000}},	//   _wego_, _हजुर, --, --, 
   {{0x26cc14cf,0x636803ee,0x842400f7,0x044400d8}},	//   _tego_, kınt, رىحن, хенн, 
   {{0x681000ac,0x0674efcc,0x25a40175,0x18b001ee}},	//   _nədə, _пуля, _winl_, _йҙәр, 
   {{0x67295d7b,0x25a40109,0x6ab801f7,0x684001d9}},	//   _ingj, _tinl_, _mfuf, _سێکل, 
   {{0xdcfc0055,0x0084004e,0x00000000,0x00000000}},	//   _okrā, елго, --, --, 
   {{0x6ab95d7c,0x681000ac,0xf8b0008f,0x9f5806af}},	//   _ofuf, _bədə, רשל_, ltré_, 
   {{0x6ab804ba,0x42c81586,0xd5ac01d3,0x6368008e}},	//   _nfuf, _эгин_, _دہی_, gınt, 
   {{0x9f595d7d,0xdb0006ed,0x681003e3,0x00000000}},	// [23aa0] ntré_, _limã, _dədə, --, 
   {{0x6ab95d7e,0xa3e005f9,0x88e403d4,0x00000000}},	//   _afuf, _फटा_, প্তক, --, 
   {{0xd910034c,0x672802d0,0x681006be,0xbb440108}},	//   ییر_, _ongj, _fədə, нежк, 
   {{0x3ce55d7f,0x4ccc03d4,0x68100213,0x00000000}},	//   şov_, ালগু, _gədə, --, 
   {{0x590c0135,0xdcfc005f,0x59f80229,0x00000000}},	//   _གྲུས_, _ekrā, феля_, --, 
   {{0x6ab95d80,0x6728036e,0x68100213,0x6a100107}},	//   _efuf, _angj, _zədə, умшу, 
   {{0x6ab80083,0x69d802d0,0x63682791,0xdee01ef7}},	//   _ffuf, _evue, nıns, _ዓሳን_, 
   {{0xa8440597,0x9f580008,0x3ea4005f,0x8b940139}},	//   عليم_, ftré_, žotu_, _аруч, 
   {{0xdb0001ab,0x3a2401c6,0x00000000,0x00000000}},	//   _iimà, _ямаг, --, --, 
   {{0xdb000137,0x67295d81,0xdb1d5d82,0xa9640262}},	//   _himà, _engj, _strè, _зиуа_, 
   {{0xd49810f5,0xdb1c04d4,0x36c41a5c,0xb7d80066}},	//   ької_, _atré, _збег, _روشا_, 
   {{0xd2515d83,0x78c400e2,0x63680342,0xe7b4011a}},	//   لنج_, ūrvē, dıns, _נהדר_, 
   {{0x8afc0118,0xadec000d,0x151400c0,0x00000000}},	//   _umře, _चमइन_, _адля, --, 
   {{0xdb1c00ae,0x6b5000a2,0x68100213,0x00000000}},	//   _dtré, _içge, _sədə, --, 
   {{0xdb1c0165,0x63680342,0x672802d2,0x00000000}},	//   _etré, tınt, _yngj, --, 
   {{0x68100cc1,0x6acc0073,0x00000000,0x00000000}},	//   _qədə, _हजेर, --, --, 
   {{0xf1a4dc9e,0x636803ee,0x98ac033f,0x622400cf}},	// [23ab0] _прон, rınt, _wodę_, _مىيل, 
   {{0x63680205,0x00000000,0x00000000,0x00000000}},	//   sınt, --, --, --, 
   {{0x6ab81682,0xdb0001ab,0x70bc7aec,0x3f4c010b}},	//   _pfuf, _bimà, ्रील, _iýun_, 
   {{0x6b840efb,0x9f5800bc,0xb178713c,0x00000000}},	//   رشال, ytré_, kråk, --, 
   {{0x9b755d84,0xdb015d85,0x7d0c0158,0x09e000cc}},	//   دالص, _dimà, ønså, _মঙহা, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe7a40131,0x5ca40c60,0x59e00037,0xd6e80154}},	//   ىپتۇ_, _биёб, _निअर, _খসড়া_, 
   {{0x6ab95d86,0x7c3929ce,0x9f587f70,0x6d8804cc}},	//   _ufuf, _àtra, ttré_, düai, 
   {{0x572400c6,0x3f4c00ee,0x6368294f,0x00000000}},	//   طريق, _oýun_, zıns, --, 
   {{0xda08021a,0xdb000120,0x9a847fb5,0x58d401f0}},	//   _سيمه_, _timã, _сусл, _бофт, 
   {{0x9f595d87,0xdb1d08c0,0x590c025c,0x98ac00bc}},	//   stré_, _stré, _གྲིས_, _lodě_, 
   {{0x06980597,0x6728f1c0,0xb178007c,0x90c40150}},	//   _قناة_, _ungj, bråk, ңғыз_, 
   {{0x84240952,0x16c001e0,0xd298cea4,0xbad8011a}},	//   رىڭن, _уҡын, етрі_, וקרת, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x039401a9,0x00000000,0x00000000,0x00000000}},	//   _ирия, --, --, --, 
   {{0x422400c7,0xfc301079,0x6fa400d1,0x98ac0118}},	//   _адив, یحا_, _ﺋﺎﻧﺎ_, _bodě_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [23ac0] --, --, --, --, 
   {{0xf2940375,0x69d80d0d,0x9eb40166,0x00000000}},	//   _בכפר_, _निजी, _әшнә, --, 
   {{0x656001e4,0x00000000,0x00000000,0x00000000}},	//   _mmnh, --, --, --, 
   {{0xb4ac00e1,0x7bcc0fac,0xb178713c,0x6d48002e}},	//   _कल्_, _vwbu, yråk, ëgar, 
   {{0x6a115d88,0x0ba8c19b,0x6a80c8a6,0xf1bc06ea}},	//   لبور, رامى_, алца, rvág_, 
   {{0xf8055d89,0x3ea400e2,0xf1bc03b2,0x16bc00cd}},	//   вчин, žots_, svág_, ैर्ब, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe7e03994,0x56955d8a,0xb1783402,0x97155d8b}},	//   _गिरा_, лайт, tråk, умиц, 
   {{0xd8f40ed8,0x00000000,0x00000000,0x00000000}},	//   _مزاک, --, --, --, 
   {{0x8d680092,0x7d1c343a,0xf5240395,0x00000000}},	//   _ተከተል_, ndps, тфин, --, 
   {{0x590c08ea,0x799802d0,0x26144142,0xb178007c}},	//   _གྲགས_, _ihtw, _बैठी_, lsåg, 
   {{0xb178b2e3,0x66e00a89,0xb604235c,0x00000000}},	//   pråk, _воца, _аякк, --, 
   {{0xb17800fe,0xb19000ee,0x258400cf,0x00000000}},	//   lråi, илмә, رچۇپ_, --, 
   {{0x70bc1ab2,0x25d4010f,0x00000000,0x00000000}},	//   ्रेल, _יודן_, --, --, 
   {{0xdfd806bb,0xb4ac1098,0x6280031c,0xa50400f3}},	//   кът_, कशी_, żmop, _реја_, 
   {{0x64480306,0xdb1c054e,0x5f7418fd,0x52140d1d}},	//   íliš, _strî, لاقر, _бдит, 
   {{0x3f4c010b,0xdb2000d0,0xa3ac3042,0x656002d0}},	// [23ad0] _iýul_, ätýc, _कूट_, _ymnh, 
   {{0x2d855d8c,0xe7e002ab,0x7d1c01f5,0x00000000}},	//   ône_, _गिला_, gdps, --, 
   {{0x6ca40b7f,0x2ca53b7a,0x98ac00bc,0xdb0001ed}},	//   траж, änd_, _vodě_, _simá, 
   {{0x4a54686c,0xca755d8d,0xfaa00022,0x00000000}},	//   лкес, лулы, әашо, --, 
   {{0x590c0c99,0x3dc00175,0x656c01c7,0xb178007c}},	//   _གྲངས_, _gtkw_, échk, gsåg, 
   {{0x1d6c0092,0x00000000,0x00000000,0x00000000}},	//   _ተረቶች_, --, --, --, 
   {{0xf1c40150,0x00000000,0x00000000,0x00000000}},	//   _ﺒﻨﻴﺘ, --, --, --, 
   {{0xc794799d,0x442854ae,0x799803ac,0x645c0213}},	//   ырлы, _ča_, _ehtw, _əqid, 
   {{0x6b995d8e,0xdb4d5d8f,0xa904d204,0x00000000}},	//   _ihug, _زێو_, _لبان, --, 
   {{0xe32c0156,0x6d540208,0x70bccc41,0x00000000}},	//   _སོངཔ_, nhxa, ्रोल, --, 
   {{0x3d040037,0x00000000,0x00000000,0x00000000}},	//   _सउसे_, --, --, --, 
   {{0x18a402bf,0x45d401c0,0x9f603361,0xf1bc0419}},	//   _таєм, _бодс, ürür_, dváb_, 
   {{0x3e40043b,0x00000000,0x00000000,0x00000000}},	//   kɔta_, --, --, --, 
   {{0x660805b1,0xf8c40acd,0x6b981713,0x88e40f22}},	//   _ipgk, रुपय, _lhug, প্রক, 
   {{0xa304c7f2,0x44215d90,0x6b995d91,0x6d54058a}},	//   _күне, _éh_, _ohug, dhxa, 
   {{0x6d4002f6,0x7d0000f3,0x3d0435e0,0xdb1c0051}},	//   önan, đosm, स्ने_, _ctrì, 
   {{0x6e900597,0x2cbc0205,0x00000000,0x00000000}},	// [23ae0] ملفا, _şuda_, --, --, 
   {{0x6b995d92,0xae8400f7,0xdcfc033f,0xdb00008e}},	//   _ahug, убуз_, _okrą, _kimç, 
   {{0x7c94c8cb,0x6b9800b8,0xfbd00b24,0x00000000}},	//   урац, _bhug, صتا_, --, 
   {{0x6b995d93,0xe8840023,0x00000000,0x00000000}},	//   _chug, _ምሕጋዝ_, --, --, 
   {{0x67382aef,0x6b980a4d,0xda3442fd,0x9f595d94}},	//   djuj, _dhug, релы, ntrí_, 
   {{0x6b980022,0x7c3806af,0xb178369d,0x67380153}},	//   _ehug, _àtro, rsåg, ejuj, 
   {{0xb804484d,0x39900022,0x636803e0,0x00000000}},	//   ابته, sâso_, yınp, --, 
   {{0x6b981713,0x7bdc0728,0xfaa5203a,0x67380240}},	//   _ghug, mspu, _бабо, gjuj, 
   {{0x799802d0,0xad9801e7,0x3f4c032e,0x00000000}},	//   _thtw, _spúi, _nýum_, --, 
   {{0x7bdc05b1,0xca7444a5,0x4a740150,0xaa5400f3}},	//   ospu, _тусы, _тыст, _сиђу_, 
   {{0x7bdc0e38,0xe81800af,0xad3400df,0x3d055d95}},	//   nspu, _भईया_, אניס_, स्ये_, 
   {{0x7bdd1d50,0x3f4c0174,0xdc3c0010,0x67380210}},	//   ispu, _býum_, jšča, cjuj, 
   {{0xad9800c7,0xb030a705,0x7790f05c,0x7bdc002f}},	//   _ipúv, әмбә, _پیکا, hspu, 
   {{0xd37807f5,0xe6900597,0xdef80032,0xef1c0254}},	//   vrću_, _الهد, һыу_, _ekül_, 
   {{0xc0cc0020,0xaf040f15,0x7bdc5613,0xdb00008e}},	//   _እናም_, лчак, jspu, _kimä, 
   {{0x7bdc39c2,0xdef8052f,0x9f6801f4,0x98bc0064}},	//   dspu, лыу_, груз_, rkvę_, 
   {{0x59e01f14,0x7bdc005c,0x6b995d96,0x5f940354}},	// [23af0] _निगर, espu, _rhug, ситт, 
   {{0x6b995d97,0xdb1c01e7,0x00000000,0x00000000}},	//   _shug, _dtrí, --, --, 
   {{0x656c07ea,0x7bdc178a,0x8c59017f,0x6b98003a}},	//   échi, gspu, خلاء_, _phug, 
   {{0x6d545310,0xcdc40137,0x00000000,0x00000000}},	//   shxa, _نۇرۇ_, --, --, 
   {{0x6b981682,0x245801e1,0x7bdc000d,0x00000000}},	//   _vhug, _kámé_, aspu, --, 
   {{0xef1c00b8,0xda780006,0x61e00162,0x99d40066}},	//   _haü_, ыях_, ámli, صتها, 
   {{0x6b983c5d,0x6738023a,0x883465eb,0xef1c0055}},	//   _thug, tjuj, рэлц, _kaü_, 
   {{0x6b98abdc,0xb17801bf,0x67381337,0x00000000}},	//   _uhug, nsåb, ujuj, --, 
   {{0x244c0793,0x47d405d9,0x67395d98,0xdb0000fd}},	//   kömö_, _چيئر, rjuj, _dimä, 
   {{0x05649133,0xc5655d99,0xe7e0009e,0xc79401e0}},	//   рвон, ркок, _মহীয, ырһы, 
   {{0xdb0001b8,0x6d880205,0xe58041b9,0x00000000}},	//   _fimä, lüas, итүү, --, 
   {{0xe8181533,0xd1740184,0x00000000,0x00000000}},	//   _भैया_, ҡыры, --, --, 
   {{0xb4ac02ab,0xbb38008f,0x6cf4033f,0x00000000}},	//   कशॉ_, דערי, ुभाग_, --, 
   {{0x7bdc005b,0x00000000,0x00000000,0x00000000}},	//   yspu, --, --, --, 
   {{0xdb1c09cc,0x9f5882e3,0x63e00137,0x200c0129}},	//   _strí, strí_, _ايبە, ïdi_, 
   {{0x442404e6,0xc1d000b1,0xb17801bf,0xdb00013d}},	//   mvl_, _мөгә, gsåb, _ximä, 
   {{0xef1c0793,0x2bac2017,0xdc3c09a8,0x4424037e}},	// [23b00] _daü_, _जंजा, ršča, lvl_, 
   {{0x3fc55d9a,0xfce4117e,0x00000000,0x00000000}},	//   _نگری_, рожо, --, --, 
   {{0x60dc0af5,0x161c0c2e,0x92d80183,0x7bdc33a1}},	//   marm, _बैनर_, ালৰ_, uspu, 
   {{0x7bdd5d9b,0xdb1d5d9c,0x3b8405a2,0xfaa80214}},	//   rspu, _strâ, шлег, نهاي_, 
   {{0xdcfc0055,0x6d880205,0x00000000,0x00000000}},	//   _jhrī, tüat, --, --, 
   {{0x3f904cdf,0x9f584f1b,0xdb000139,0xd9140124}},	//   llyu_, ltrà_, _simä, сдкы, 
   {{0x06900952,0xa8a00801,0xb8dc000d,0xb178007c}},	//   ﻟﯩﻘﯩ, орък, _इल_, mråt, 
   {{0x60dd5d9d,0x5718023a,0x9f586c0e,0x998c00a2}},	//   harm, ужия_, ntrà_, _şońa_, 
   {{0x60dd5d9e,0x6b5000a2,0x3d04043e,0x00000000}},	//   karm, _uçga, स्थे_, --, 
   {{0x60dd5d9f,0x354447ba,0x953806ed,0x37e4014b}},	//   jarm, рхив, узот_, _вожг, 
   {{0x60dd5da0,0xdb00014a,0x3cfc7039,0xdcfc0055}},	//   darm, _timä, _लाने_, _ahrī, 
   {{0xf3655da1,0x3d0488f2,0x20182165,0x60dc01ab}},	//   ртон, स्ते_, dwri_, earm, 
   {{0xe3b000aa,0xdcfc00b8,0x4424072b,0x244801e1}},	//   ګری_, _chrī, avl_, _pòmú_, 
   {{0x60dd5da2,0xef1c0205,0x25f00073,0xe5a0bf77}},	//   garm, _saü_, ंढरी_, _дичи, 
   {{0x656c39d3,0xe3b04bf3,0x590c0135,0xb1780158}},	//   èche, ثری_, _གྲབས_, dråt, 
   {{0x6444023a,0x23840014,0xa8540375,0x00000000}},	//   äjie, _ؤوِ, בילה_, --, 
   {{0x60dd5da3,0xd2504c9e,0x5f3c001f,0xcf900014}},	// [23b10] barm, _رند_, _አገራቸ, _ہژر_, 
   {{0x60dd5da4,0x61440f14,0xad980241,0x8c880124}},	//   carm, _мења, _npút, гәба_, 
   {{0x98bc00bc,0xef1c002b,0xc0c40150,0x00000000}},	//   skvě_, _taü_, _ушық, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4890001f,0xb178143a,0x600c01d3,0x3c0401b9}},	//   _ምንጮች_, bråt, _tömö, _қўрғ, 
   {{0xdcfc033f,0xe9840640,0x3cfc012d,0xdd840153}},	//   _okrę, шћен, _लाये_, _дысп, 
   {{0x9f580789,0x2bc81fbe,0x00000000,0x00000000}},	//   ltrá_, _југо_, --, --, 
   {{0x44240a73,0x00000000,0x00000000,0x00000000}},	//   vvl_, --, --, --, 
   {{0x60dd5da5,0x387c003a,0x9f595da6,0x4a5401b9}},	//   yarm, _extr_, ntrá_, _укас, 
   {{0x4534a577,0x60dc00ac,0x69c80b4f,0x451802e8}},	//   схит, xarm, mpge, уция_, 
   {{0x60dd5da7,0x261402e5,0x69c8017a,0x290446aa}},	//   varm, _बैरी_, lpge, mfna_, 
   {{0x60dd5da8,0x442401e0,0x69c80373,0x833806ed}},	//   warm, rvl_, opge, учот_, 
   {{0xdb1c0034,0x2904208d,0x00000000,0x00000000}},	//   _zwró, ofna_, --, --, 
   {{0x515400db,0x00000000,0x00000000,0x00000000}},	//   отсу, --, --, --, 
   {{0x03a41b88,0x2904208d,0xb1780158,0xf574007b}},	//   _лико, ifna_, vråt, _دموع_, 
   {{0xdb1c02fb,0xb17805ac,0x53480354,0x00000000}},	//   _otrá, frås, _кăсă, --, 
   {{0x60dd5da9,0xf1bd5daa,0xb1780158,0x9f5801e7}},	// [23b20] parm, lván_, tråt, gtrá_, 
   {{0x60dd5dab,0x61e470a9,0x9f594849,0xdb1c08c2}},	//   qarm, _ivil, strà_, _strà, 
   {{0xdb1cc31a,0x61e4501b,0x3f681b74,0xbc695dac}},	//   _atrá, _hvil, _бино_, دمان_, 
   {{0x3990025a,0x61e55dad,0xad995dae,0x290408a5}},	//   mâsi_, _kvil, _bpús, efna_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x61e4014b,0xdb1c007b,0xfaa401b9,0xb88c0023}},	//   _mvil, _dtrá, _ғазо, _ምንጻል_, 
   {{0xb764352d,0x69c8257c,0x109000d1,0x7f44036e}},	//   йтий, apge, ﺘﯩﺪﯨ, _kokq, 
   {{0x61e55daf,0x2904058a,0xe8f400d1,0x00000000}},	//   _ovil, afna_, алә_, --, 
   {{0xb17805ac,0xdcfc033f,0x00000000,0x00000000}},	//   irår, _skrę, --, --, 
   {{0xb9940491,0x28cc0bc0,0x91a8004d,0xad9800d0}},	//   _الطب, _स्पि, _trả_, _upút, 
   {{0xdb1c012c,0x937812d7,0x9f5801bf,0x00000000}},	//   _ztrá, ибот_, mtræ_, --, 
   {{0x7f44009a,0x79880076,0x9f591b83,0xe2f801ec}},	//   _nokq, lofw, ltræ_, беюі_, 
   {{0x61e55db0,0xdcfc033f,0x81b401ec,0xb2840958}},	//   _cvil, _wkrę, оңыр_, сынк, 
   {{0x656d5db1,0x61e47acb,0x9f5812e8,0x00000000}},	//   écht, _dvil, ntræ_, --, 
   {{0x61e43cf7,0x81d400cc,0xe3b000f1,0x00000000}},	//   _evil, াংগ_, _ګرو_, --, 
   {{0x3d0434ef,0x28cc17c6,0xe818000d,0x00000000}},	//   स्से_, _स्नि, _भईसा_, --, 
   {{0x61e40beb,0x7f440548,0x93bc0276,0xf2dc014b}},	// [23b30] _gvil, _dokq, zvăl, maâ_, 
   {{0xf2dc8967,0x6ca40484,0x7114010a,0x00000000}},	//   laâ_, бреж, _уçма, --, 
   {{0xdb1c2d2a,0x61e55db2,0x9f580306,0xad9800d7}},	//   _strá, _zvil, strá_, _spús, 
   {{0xf2dd5db3,0x200c025c,0x00000000,0x00000000}},	//   naâ_, ħdit_, --, --, 
   {{0x22a4020c,0xcd801d00,0x00000000,0x00000000}},	//   mèké_, _قۇرۋ, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf2dc0161,0xf78406ba,0x65e000d1,0x10c80150}},	//   kaâ_, ﺭﻟﯩﻚ_, _ﺋﻪﭘﻪ, _ﺒﺸﺄﻨ, 
   {{0x6d455db4,0x9b586baf,0x589400c6,0xf1bc0548}},	//   _hoja, _лист_, أجهز, kqá_, 
   {{0x85780261,0x6b880083,0x78740209,0xdb1c0216}},	//   исот_, mogg, ййәр_, _utrá, 
   {{0xf1bd5db5,0x6d455db6,0x79880472,0x6b800036}},	//   tván_, _joja, cofw, éngf, 
   {{0x61e51943,0x99842a4b,0xe7840697,0x03a40b96}},	//   _svil, _علمو, _лудо, жино, 
   {{0x6d455db7,0x6b880660,0xf1bc00e5,0x00000000}},	//   _loja, nogg, rván_, --, 
   {{0x84e55db8,0xf1bc0789,0x6d440254,0x656c0036}},	//   _долж, sván_, _ooja, échs, 
   {{0x41295db9,0x28cc08a3,0x26dd5dba,0x661800ca}},	//   шого_, _स्मि, lauo_, mwuk, 
   {{0xf1bc011f,0x6b881418,0x00000000,0x00000000}},	//   aqá_, kogg, --, --, 
   {{0x61e42ab7,0x7c380129,0x00000000,0x00000000}},	//   _tvil, _àtri, --, --, 
   {{0x6b895dbb,0x92e87146,0x25bd5dbc,0x00000000}},	// [23b40] dogg, _طريق_, nqul_, --, 
   {{0x6d455dbd,0xb17801e6,0x7c941d0d,0xada0a5de}},	//   _coja, lsån, орец, даул, 
   {{0x66180564,0x6d455dbe,0x6b880076,0xf1bc02f0}},	//   hwuk, _doja, fogg, hvál_, 
   {{0x0ba831f0,0xeb9434d8,0x6b895dbf,0x6618063f}},	//   مانى_, оих_, gogg, kwuk, 
   {{0xf9840323,0x6d455dc0,0x18800023,0xaa400166}},	//   огдо, _foja, _ይሕጸር_, мецл, 
   {{0x6d455dc1,0x6b88011c,0xd91019bc,0xe9fc0051}},	//   _goja, aogg, عیض_, hoặc_, 
   {{0x6b895dc2,0xd7f00597,0xaef808c2,0x7d0c02d0}},	//   bogg, ركة_, _smùi, _ibbs, 
   {{0xdb1d390f,0xfb54034c,0x6d440161,0x26dc0b23}},	//   _stræ, _بپرد, _zoja, gauo_, 
   {{0x6d455dc3,0x9f58007c,0xf2dc0022,0x68ec01ef}},	//   _yoja, mträ_, vaâ_, _řidš, 
   {{0xf2dc02ce,0x6d4401d5,0xaaf403b9,0x79500133}},	//   waâ_, _xoja, _çörç, _زێبا, 
   {{0xf2dd5dc4,0x661804ba,0xb1781f53,0x22a4020c}},	//   taâ_, awuk, dråp, yèké_, 
   {{0xe7340108,0x97340ed8,0xf62800d4,0x00000000}},	//   _мех_, _رکعا, _віки_, --, 
   {{0xf2dc0161,0xa2bc7039,0xf1bc011f,0xf6741e2f}},	//   raâ_, _एलर्, uqá_, _بااخ, 
   {{0xf2dc014b,0x7c2c0115,0x3ce8017a,0x22a40214}},	//   saâ_, _orbr, _ndbv_, wèké_, 
   {{0x6d455dc5,0xf1bc0784,0x22a4020c,0x636800e5}},	//   _roja, sqá_, tèké_, zűni, 
   {{0x6d455dc6,0x1fa55dc7,0x9f340220,0xc0c00116}},	//   _soja, друг, месі, _җәри, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [23b50] --, --, --, --, 
   {{0x7c2c0076,0x22a4020c,0x6b880337,0x50f4005b}},	//   _brbr, sèké_, wogg, _эзот, 
   {{0x6d455dc8,0x6b895dc9,0xdb1c01e3,0x602800d4}},	//   _voja, togg, _oträ, _діяв_, 
   {{0xcb0800ec,0x9f58007c,0x25bc022e,0x6d440210}},	//   صيتن_, gträ_, yqul_, _woja, 
   {{0x6d455dca,0x6b895dcb,0x7c2c03fa,0x7f3802e4}},	//   _toja, rogg, _erbr, _הערו, 
   {{0x6b895dcc,0x00000000,0x00000000,0x00000000}},	//   sogg, --, --, --, 
   {{0x6b8800a7,0x7c3c000f,0x26dc003a,0xfbf401f0}},	//   pogg, cxpr, tauo_, _норӯ, 
   {{0x773400d1,0x25bc022e,0x00000000,0x00000000}},	//   ككىز_, tqul_, --, --, 
   {{0x28cc39a7,0xb17801e3,0xdb080241,0x00000000}},	//   _स्थि, vsån, _ìláw, --, 
   {{0x25bd5dcd,0x00000000,0x00000000,0x00000000}},	//   rqul_, --, --, --, 
   {{0xb97800c8,0x25bc058a,0xb17801e3,0x00000000}},	//   _פרעז, squl_, tsån, --, 
   {{0xb9c81b49,0x28cc19e9,0xaac800bc,0x00000000}},	//   _ቲቪ_, _स्ति, ाडिक, --, 
   {{0xb6b80a1e,0xb17801e3,0x00000000,0x00000000}},	//   _הצני, rsån, --, --, 
   {{0x6f0c0142,0xb178007c,0x00000000,0x00000000}},	//   _abcc, ssån, --, --, 
   {{0xb1780fac,0x6e2c00e5,0x00000000,0x00000000}},	//   msål, _arcb, --, --, 
   {{0x9f580023,0x6f0c0175,0x6e2c0205,0xcf24007b}},	//   murë_, _cbcc, _brcb, ورقي, 
   {{0x63a529cd,0x6f0c0175,0xaef80248,0x95c800df}},	// [23b60] _ihin, _dbcc, _olùf, ַלאַ_, 
   {{0x6f0c0408,0xc0055dce,0x62855dcf,0x63a401ab}},	//   _ebcc, _епок, _ixio, _hhin, 
   {{0x63a55dd0,0x79a40ed0,0xe818000d,0x00000000}},	//   _khin, үрле, _भैला_, --, 
   {{0xaef801e1,0xdb000784,0x3cfc00af,0x8b640133}},	//   _alùf, _khmé, _लावे_, وانم, 
   {{0x63a55dd1,0xfaa40aac,0xb178007c,0x9f595dd2}},	//   _mhin, чадо, ksål, hurë_, 
   {{0xccf4005e,0xdb1d5dd3,0x63a40363,0x9f58a4bf}},	//   _оқу_, _strä, _lhin, kurë_, 
   {{0x55f82f8b,0x2b741194,0x6da08595,0x63a55dd4}},	//   _অনেক_, _کینگ_, _чира, _ohin, 
   {{0x63a55dd5,0x96343169,0xa81421ef,0x9f580240}},	//   _nhin, дниц, ستىر_, durë_, 
   {{0x6b800a40,0x7ae15dd6,0xdb1ca87b,0x7588005b}},	//   énge, maot, _lurë, йсов_, 
   {{0x63a55dd7,0xe60c082e,0x7ae08ad8,0x00000000}},	//   _ahin, اشي_, laot, --, 
   {{0x62855dd8,0x63a55dd9,0x7ea400b0,0x9f580023}},	//   _axio, _bhin, _hōpī, gurë_, 
   {{0x63a55dda,0x7ae00451,0x7ea402b5,0xdb1c0267}},	//   _chin, naot, _kōpī, _uträ, 
   {{0x63a40a81,0x628400e8,0xc7640c50,0x7614074d}},	//   _dhin, _cxio, _تالى, _хьех, 
   {{0x7ae15ddb,0xdb4404d3,0x63a55ddc,0x6d0801ad}},	//   haot, _ڵێ_, _ehin, _सॉंग_, 
   {{0x7ae15ddd,0x63a55dde,0x8c100150,0x62840129}},	//   kaot, _fhin, _ءﺍﻧﺸ, _exio, 
   {{0x63a55ddf,0x7ae00641,0x5f255de0,0x5214005b}},	//   _ghin, jaot, нфуз, _ждит, 
   {{0x7ae02819,0x78b802d0,0x00000000,0x00000000}},	// [23b70] daot, _ogtv, --, --, 
   {{0x6ca40801,0x63a40433,0x6b50010b,0xaef80ca8}},	//   преж, _zhin, _içgi, _olùg, 
   {{0x8c18bd0e,0xdb1d5de1,0x63a55de2,0x7ae00109}},	//   تيار_, _kurè, _yhin, faot, 
   {{0x63a40023,0x7ae15de3,0x00000000,0x00000000}},	//   _xhin, gaot, --, --, 
   {{0xdb1c180f,0x19c402dd,0x78b80051,0x50b400bc}},	//   _murè, ебім, _bgtv, ःखकष, 
   {{0x1cbc0135,0x92d8015b,0x6b800036,0x64d80073}},	//   _ངུར_, ালয়_, éngb, _मजेश, 
   {{0xca4401ec,0x6d4001f4,0x00000000,0x00000000}},	//   _ﺘﺠﺩ_, önau, --, --, 
   {{0x78b8005c,0xf4080327,0x7ae00051,0x00000000}},	//   _egtv, _ཀྱེད_, caot, --, 
   {{0x63a55de4,0x6ab894a7,0xb1789596,0x068401f4}},	//   _rhin, _iguf, tsål, ьгин, 
   {{0xdb1c35f5,0x63a55de5,0x9f580023,0x6d5400aa}},	//   _aurè, _shin, turë_, nkxa, 
   {{0x63a55de6,0xfa080003,0xdb1c180f,0x7ae800d2}},	//   _phin, _གདོན_, _burè, _úmtî, 
   {{0x7ea400b0,0x63a51d62,0x46140472,0x420800cf}},	//   _hōpū, _qhin, _يوار, онмо_, 
   {{0x63a55de7,0xdb1cff24,0x7ea402b1,0x68e001c8}},	//   _vhin, _durè, _kōpū, oand, 
   {{0x63a55de8,0x9f58020c,0xf6500375,0x98ac054e}},	//   _whin, muré_, _בצד_, _undă_, 
   {{0x63a420c6,0x68e15de9,0x6ab80337,0x9f580214}},	//   _thin, iand, _oguf, luré_, 
   {{0x63a408f5,0x6ab8015c,0x9f580137,0x628401c4}},	//   _uhin, _nguf, ltrú_, _txio, 
   {{0x68e15dea,0x3f4c1125,0x32d40014,0x8fd400d1}},	// [23b80] kand, _býur_, _تۯُک_, _җәсә, 
   {{0x68e0bf1a,0x6ab95deb,0x7ae002b5,0x00000000}},	//   jand, _aguf, waot, --, 
   {{0x68e15dec,0x7ae11894,0x9f5800f2,0x7c94041b}},	//   dand, taot, huré_, фрац, 
   {{0xaef801ab,0xdb1c0694,0x68e0062c,0x00000000}},	//   _clùd, _kuré, eand, --, 
   {{0x68e15ded,0x7ae15dee,0xdb1c73a0,0xfa34c320}},	//   fand, raot, _juré, براد, 
   {{0x68e15def,0x7ae01311,0xdb1c026c,0x7644023a}},	//   gand, saot, _muré, äkym, 
   {{0x69d939fd,0x6b80e751,0x7ae15df0,0xd79400a7}},	//   _ewue, éngc, paot, никъ, 
   {{0x7ea400b0,0xf7713487,0xd6d0007b,0x68e00022}},	//   _tōpī, ضاع_, دقة_, aand, 
   {{0x28cc1b76,0xd9115df1,0x9f595df2,0xb9055df3}},	//   _स्वि, _میش_, guré_, _озак, 
   {{0x68e15df4,0x1cbc0135,0xe8f4074d,0x5f840092}},	//   cand, _ངུས_, _олу_, _የጥበቃ_, 
   {{0xdb1d5df5,0xc7780050,0xd4980212,0x98ac0153}},	//   _auré, _کٔنڈ_, якої_, _rodė_, 
   {{0xdb1c004e,0x478802dd,0x9f584db4,0x69e40108}},	//   _buré, _есім_, buré_, _äreä, 
   {{0x273007a7,0xdb1d1b75,0x71240214,0x9f580129}},	//   _جىنس, _strû, ورآل, curé_, 
   {{0xdb1c0231,0xe53000c7,0x3f800200,0xf1a815eb}},	//   _duré, _аешь, _ajku_, تاجه_, 
   {{0xa420010b,0xa6bc00eb,0x636800e5,0x00000000}},	//   _аьыл, _এড়িয়, tűnt, --, 
   {{0xaef801e1,0x24e000eb,0x00000000,0x00000000}},	//   _amùr, _মাযহ, --, --, 
   {{0xdb015df6,0xf1a405f5,0x7bcd5df7,0x91a80208}},	// [23b90] _limó, _орон, _atbu, _trà_, 
   {{0x8d94049e,0x4fc015bf,0x00000000,0x00000000}},	//   رلاش, _مەسە, --, --, 
   {{0x6d540227,0xd054013f,0x7ea402b5,0xdb00002e}},	//   rkxa, _ɔbɛm, _rōpū, _nimó, 
   {{0x68e15df8,0x395d5df9,0xb17801e3,0xa2740023}},	//   wand, _alts_, ksåk, _ከንኣን_, 
   {{0x395c0100,0x7bcc01e4,0xdb1c0005,0x6d400267}},	//   _blts_, _etbu, _xuré, önas, 
   {{0x7c380331,0xcb681077,0x68e098df,0x00000000}},	//   _štre, _کمره_, uand, --, 
   {{0x68e15dfa,0xdb000077,0x9f5804fb,0xa3e0000d}},	//   rand, _cimó, wuré_, _पौढ_, 
   {{0x9f595dfb,0x395c0a85,0x6ab88aa7,0x0ad413f9}},	//   turé_, _elts_, _uguf, _سحرگ, 
   {{0x3ab00831,0x7ea402b1,0x69d80036,0x89d80133}},	//   _йәшт, _tōpū, _uwue, _روار_, 
   {{0x68e0a233,0x00000000,0x00000000,0x00000000}},	//   qand, --, --, --, 
   {{0xdb1cc917,0x74e405f5,0xdb00011f,0x9f5807ea}},	//   _suré, эдэг_, _gimó, suré_, 
   {{0xdb1d5dfc,0xe7a401ec,0x58840124,0x9f595dfd}},	//   _puré, _تۇبى_, _рыуа, puré_, 
   {{0x2d801418,0xaef80241,0xd05406be,0x00000000}},	//   _ojje_, _olùb, mazə, --, 
   {{0x2b5c00cf,0xade000af,0xdb000790,0x052801ee}},	//   _lluc_, गठनन_, _simü, _хокк_, 
   {{0x03955dfe,0x4524009e,0x00000000,0x00000000}},	//   _прия, বাদক_, --, --, 
   {{0x2d815dff,0xdb00068c,0xdb1c002e,0x7bcc01a9}},	//   _ajje_, _limò, _turé, _rtbu, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [23ba0] --, --, --, --, 
   {{0xdb000086,0x81d400fe,0x3f4c010e,0xdb1c0356}},	//   _nimò, _হিপ_, _eýup_, _curî, 
   {{0xdb00014a,0xe0588341,0x7c38181f,0xfce40107}},	//   _timü, _غیرت_, _štrb, доҷо, 
   {{0x2d800083,0x6d4011ab,0x3f800240,0xd83800d0}},	//   _ejje_, önar, _ujku_, _szčo_, 
   {{0xdb015e00,0x395c020b,0xb1780158,0x6b81461a}},	//   _simó, _plts_, fsåh, énga, 
   {{0x3f9123d5,0xa9655e01,0x3d04033f,0x00000000}},	//   loyu_, нича_, स्खे_, --, 
   {{0xdb50168d,0x7bcc049f,0x18b40588,0xdb1c0158}},	//   _پێش_, _utbu, тәар, _otrø, 
   {{0x3dc01dc9,0x3f915e02,0x5694d20e,0xeb94084c}},	//   _kukw_, noyu_, кайт, _зис_, 
   {{0xdb00067c,0x00000000,0x00000000,0x00000000}},	//   _fimò, --, --, --, 
   {{0xdb0024c8,0x23600381,0x25a4010a,0x7d1d5e03}},	//   _timó, _alij_, _chnl_, neps, 
   {{0x23615e04,0x98a400af,0xf1a40cf1,0x228401f0}},	//   _blij_, _ओरिए, _गठबन, ҳург, 
   {{0x5fb4032c,0x60c00134,0x7d1c5d49,0xe3b00133}},	//   ंगफल, ɛmmi, heps, یرێ_, 
   {{0x98fc010f,0x7d1c017a,0x45600014,0x22846d64}},	//   _elĉe, keps, _چھپہ, гург, 
   {{0x7d1c08ad,0x06655e05,0x5f94013e,0x387803b9}},	//   jeps, _جامپ, ҳист, _üzrә_, 
   {{0x7d1d5e06,0xa0c400c6,0x00000000,0x00000000}},	//   deps, ايفو, --, --, 
   {{0x5f955e07,0xb8e00c99,0x2d84151c,0x75295e08}},	//   гист, _གུ_, čnem_, _hafz, 
   {{0x2d84003a,0x00000000,0x00000000,0x00000000}},	// [23bb0] ōnem_, --, --, --, 
   {{0x9f580ffb,0x00000000,0x00000000,0x00000000}},	//   lurì_, --, --, --, 
   {{0x5f0c06ab,0x61440261,0xdb1c0158,0x906000d1}},	//   _डॉक्_, _сеќа, _ytrø, _ئۆزۇ, 
   {{0xe0d0af1c,0x7c3801a6,0x752801a9,0x35b007f7}},	//   _پزی_, _štrc, _lafz, ँगड़, 
   {{0x7d1d5e09,0xc92800d8,0x00000000,0x00000000}},	//   beps, долж_, --, --, 
   {{0x99d55bd7,0x644401f4,0xc4e001ec,0x00000000}},	//   اتنا, äjik, _ﻋﻘﺎﺌ, --, 
   {{0x18800023,0x6680036b,0x00000000,0x00000000}},	//   _ይንገር_, گیشل, --, --, 
   {{0x3dc000ca,0xe7a40131,0x00000000,0x00000000}},	//   _yukw_, رۇشى_, --, --, 
   {{0xdb000ba1,0x59f81c50,0x00000000,0x00000000}},	//   _timò, _петя_, --, --, 
   {{0xdb1c0ac7,0x236001fa,0xbaa4035b,0x9f580fac}},	//   _strø, _slij_, _русқ, strø_, 
   {{0x58d422f7,0x23600489,0x3f900205,0x00000000}},	//   _сохт, _plij_, yoyu_, --, 
   {{0x2d915e0a,0x6f1c0477,0x7d1c013a,0x00000000}},	//   hoxe_, jeqc, zeps, --, 
   {{0x2d8401a2,0x2d9001c4,0x6b500432,0xb380011c}},	//   čnej_, koxe_, _uçgu, рлял, 
   {{0xadc00051,0xf67800df,0x00000000,0x00000000}},	//   _hoặc, _קאסמ, --, --, 
   {{0x49080316,0x2d915e0b,0xc784001f,0x442000f2}},	//   _सानो_, doxe_, _ዝቅተኛ_, _èh_, 
   {{0x672800d5,0xdb1c0217,0xbe6402d3,0xbea400d1}},	//   _jagj, _utrø, _ግርጭታ, вабк, 
   {{0x6728044e,0xaec15e0c,0x2d9000d7,0x3f902c13}},	// [23bc0] _magj, рбул, foxe_, royu_, 
   {{0x672802d3,0x6b800c6a,0x00000000,0x00000000}},	//   _lagj, éngn, --, --, 
   {{0xdcfc005f,0x93bc054e,0x3f6806b4,0x3f9003e0}},	//   _skrē, lvăr, _жино_, poyu_, 
   {{0xb9e41b92,0x3cfc000d,0x00000000,0x00000000}},	//   نستى, _लाके_, --, --, 
   {{0x7b640014,0x2d9000d7,0x00000000,0x00000000}},	//   _یارٕ, boxe_, --, --, 
   {{0x672801f5,0x7d1c0200,0x00000000,0x00000000}},	//   _aagj, qeps, --, --, 
   {{0xebe00e84,0x67283386,0x31780302,0x9f5800e4}},	//   _восп, _bagj, ורסמ, murâ_, 
   {{0x9f5800e4,0x8b9400c0,0xddd001ef,0x00000000}},	//   kurí_, _бруч, _řeři, --, 
   {{0xdb1d5e0d,0x67280196,0xb5a40c9e,0x9f580ffb}},	//   _jurí, _dagj, крой, vurì_, 
   {{0x6728002d,0x49080073,0xdb1c00d7,0x00000000}},	//   _eagj, _सायो_, _murí, --, 
   {{0x67280158,0xf4880108,0x00000000,0x00000000}},	//   _fagj, ьщик_, --, --, 
   {{0x4a00035b,0x9f58fba5,0xd6c40454,0x6608b35a}},	//   _тҟәа, hurâ_, _сидқ, ömkö, 
   {{0xc764005e,0xb2844990,0xb4f000fd,0xded00023}},	//   _حالى, тынк, _күпч, ብካን_, 
   {{0xb4b00348,0x3cfc1b0c,0x2d906f4f,0x00000000}},	//   _килә, _लागे_, xoxe_, --, 
   {{0xdb1d5e0e,0xa1853b20,0x6fac1d8a,0x5334021f}},	//   _murâ, рыял, ंगलू, _бейт, 
   {{0xf4d802f5,0x67280014,0xf1a805d9,0xdb1c00d7}},	//   _দায়ব, _xagj, _ڪابه_, _burí, 
   {{0x4524015b,0x10a40116,0x00000000,0x00000000}},	// [23bd0] বারক_, тиңн, --, --, 
   {{0x7c381050,0xdb1c2815,0xf1a95e0f,0x2fc400c7}},	//   _štra, _durí, _تابه_, _éngo_, 
   {{0xdb1d5e10,0x6b80020c,0x8af95e11,0x00000000}},	//   _turì, éngo, енес_, --, 
   {{0x2d900109,0x6f1c0455,0x64440108,0x00000000}},	//   soxe_, qeqc, äjii, --, 
   {{0x9a240372,0xad980077,0x00000000,0x00000000}},	//   لعون, _opúx, --, --, 
   {{0x7760172e,0xdb1c0276,0x67280432,0xf1bc00e5}},	//   _alox, _curâ, _sagj, lvás_, 
   {{0x87b80276,0x67280240,0x00000000,0x00000000}},	//   нуит_, _pagj, --, --, 
   {{0x07095e12,0xc7255e13,0x9f5800e4,0x46a401d5}},	//   ريخي_, удий, murã_, лайв, 
   {{0xdb1c172e,0x67280200,0x28200023,0xd5e401ec}},	//   _xurí, _vagj, _ተክኒካ, айық, 
   {{0x9a845ded,0x77615e14,0x48c4008e,0x044801f4}},	//   _тусл, _elox, _сәда, епок_, 
   {{0x672801ed,0x00000000,0x00000000,0x00000000}},	//   _tagj, --, --, --, 
   {{0x28cc02c3,0xdb1c0432,0xd7f80b83,0xb4602bb6}},	//   सुरि, _otrý, _шуу_, скюл, 
   {{0x06b000bd,0x9f5800e4,0x527400f3,0xfec800d1}},	//   _ট্রি, hurã_, ауру, _ﺑﯩﯟﺍ, 
   {{0xded00b82,0x2bbc0327,0x09b4010f,0x00000000}},	//   ብያን_, _གང༵_, רפֿט_, --, 
   {{0x9f84016c,0xd83802fb,0x93bc054e,0xb4f8011a}},	//   иҳод, _tyče_, rvăr, _טפסי, 
   {{0x9f540428,0xdb1c004e,0x6e38110c,0x6b80bcd7}},	//   ñeàt_, _purí, _šuba, éngl, 
   {{0x9f580393,0x3da80063,0xcdc44640,0x00000000}},	// [23be0] turâ_, екао_, иатқ, --, 
   {{0x44240204,0xf1bc01d3,0x1fe800f1,0x00000000}},	//   owl_, rvát_, _ټکسي_, --, 
   {{0x442400a9,0x9f580022,0x00000000,0x00000000}},	//   nwl_, rurâ_, --, --, 
   {{0x0ba95e15,0xe5103be5,0xdb1d5e16,0x4ed40064}},	//   نانى_, त्ति_, _turí, _вюрт, 
   {{0xd9b41ee2,0x6f180113,0xb1784606,0xf1bc3add}},	//   لەرد, _ñuca, rsåv, lvár_, 
   {{0x9f58026c,0x28cc12eb,0xf804009d,0x00000000}},	//   lurà_, सुलि, гчин, --, 
   {{0xe444007b,0x00000000,0x00000000,0x00000000}},	//   _اض_, --, --, --, 
   {{0x5884005e,0x17540801,0x9f595e17,0xdb1c00d8}},	//   лықа, рвия, nurà_, _durã, 
   {{0x28cc03f3,0xd8f55e18,0xf50834b1,0x9f580789}},	//   _स्कि, _نزاک, ىزدى_, ltró_, 
   {{0xf1bc0e33,0x7c20033f,0x44240142,0x5574011c}},	//   kvár_, łoru, fwl_, ргот, 
   {{0x9f5804cf,0xdb000139,0xc7640131,0x44240042}},	//   ntró_, _dimö, _ھامى, gwl_, 
   {{0xdb1c00db,0x9f58026c,0x3b04013c,0xc7640b38}},	//   _jurà, jurà_, ngoq_, _پامى, 
   {{0xa77800c8,0x9f5800db,0x4424015d,0x00000000}},	//   _אראפ, durà_, awl_, --, 
   {{0x047401ed,0x799802d0,0x9584010b,0x442403cb}},	//   ائیگ, _jktw, _өлҗе, bwl_, 
   {{0xe3b02b3c,0x9f580306,0x7c3800d0,0x3cfc0037}},	//   تری_, strý_, _štrn, _लाजे_, 
   {{0x9f580268,0xaf34a4ca,0x00000000,0x00000000}},	//   gurà_, درست, --, --, 
   {{0x1df95e19,0x2c0400c5,0x00000000,0x00000000}},	// [23bf0] леты_, _हमहू_, --, --, 
   {{0xdb1d5e1a,0x9f595e1b,0x49087e7c,0xd8380100}},	//   _aurà, turã_, _साधो_, _orč_, 
   {{0x2ca4ef77,0xdb0000d8,0x1b000011,0x6ca40395}},	//   ånd_, _limõ, োজনে_, ураж, 
   {{0xdd94005e,0x7998ca60,0xdb1c04cc,0x9f595e1c}},	//   _ғасы, _aktw, _curà, curà_, 
   {{0xd838007f,0xdb1c0c86,0x257801e1,0x9f580022}},	//   _arč_, _durà, _jálè_, surã_, 
   {{0xdb1d5e1d,0x9f603653,0xb17803cd,0x00000000}},	//   _eurà, ösön_, msås, --, 
   {{0x9f58004e,0x25780241,0xb178143a,0xaa4000d1}},	//   ctró_, _lálè_, lsås, _گۆشى, 
   {{0x5c7401c0,0x00000000,0x00000000,0x00000000}},	//   _улст, --, --, --, 
   {{0x9f4d5e1e,0xa3e403f3,0x6b995e1f,0x056400a8}},	//   édé_, मीन_, _ikug, ивин, 
   {{0x05555e20,0x9f58b2cc,0xd83802e2,0xe1f8013e}},	//   ртия, ntrò_, _frč_, қҳо_, 
   {{0x257801e1,0x6b980083,0xd83804a7,0xdb1c02f0}},	//   _aálè_, _kkug, _grč_, _hurá, 
   {{0x25780241,0x442401e0,0x29055e21,0xdb1c03da}},	//   _bálè_, rwl_, lgna_, _kurá, 
   {{0xaef805d5,0x290407c5,0x9f580c86,0xdb1d537b}},	//   _plùn, ogna_, vurà_, _jurá, 
   {{0x2904ebf1,0x25780248,0xdb1d5e22,0xd17402dd}},	//   ngna_, _dálè_, _murá, бысы, 
   {{0x6b980c8a,0x29c800cc,0x9f580ffb,0x29055e23}},	//   _okug, _løa_, turà_, igna_, 
   {{0x3390009a,0x00000000,0x00000000,0x00000000}},	//   _ولوز, --, --, --, 
  
   {{0x71780020,0xf1bc01d3,0x9f5800d8,0x2c340092}},	// [23c00] _ባለፉት_, rvár_, gurá_, _የሚገኝ, 
   {{0x61e55e24,0x6b98239f,0xee355e25,0x9f580268}},	//   _iwil, _akug, шну_, surà_, 
   {{0x61e405c7,0x19586518,0xfbd03c5a,0x80a8005b}},	//   _hwil, ғайы_, زتا_, _швов_, 
   {{0x61e400aa,0xdb1d5e26,0x9f580137,0x290407c5}},	//   _kwil, _atrò, rtró_, egna_, 
   {{0x9f595e27,0xb1784bc1,0xda34023a,0xdb1c2389}},	//   stró_, msår, селы, _stró, 
   {{0x6b98136f,0x61e405d9,0xdb1c0d19,0xb17848a1}},	//   _ekug, _mwil, _durá, lsår, 
   {{0x61e4007f,0xdb000798,0xdb1c1de4,0xb764009d}},	//   _lwil, _simõ, _eurá, итий, 
   {{0x2ca55e28,0x61e4166a,0xb1780158,0xd839357e}},	//   ünde_, _owil, nsår, _vrč_, 
   {{0x61e402b9,0xb90c004d,0x8ccc03ce,0xdb1c00d7}},	//   _nwil, _xalộ_, दुको, _gurá, 
   {{0x4a747283,0xd83802e2,0x00000000,0x00000000}},	//   _уыст, _trč_, --, --, 
   {{0x61e403f9,0xe56c1b45,0x28cc1f13,0xb1781347}},	//   _awil, بطي_, _स्टि, ksår, 
   {{0x61e41743,0x764401f4,0x00000000,0x00000000}},	//   _bwil, äkys, --, --, 
   {{0xdb1c0077,0xb1782b96,0x61e41397,0x7c3846aa}},	//   _xurá, dsår, _cwil, _štrl, 
   {{0x61e400f2,0x925801e0,0x3e5c00dc,0xb17801e3}},	//   _dwil, _ҡайт_, _mātā_, vsås, 
   {{0x61e402d0,0x26c000bc,0x6b8000d5,0x613c01e3}},	//   _ewil, ějov_, éngk, _sålä, 
   {{0xb1784bc1,0x613c0267,0xb4007c3f,0xdfd80395}},	//   gsår, _pålä, _лүүд, рър_, 
   {{0x61e55e29,0x7a1800da,0xf2dc025a,0xe3b09165}},	// [23c10] _gwil, nātā, mbâ_, _ترو_, 
   {{0x6b98f971,0x29c8003b,0xb178a075,0x6eb800dc}},	//   _skug, _røa_, rsås, _शृणु, 
   {{0x61e406d6,0x6b980083,0x8b84005e,0xb17802ed}},	//   _zwil, _pkug, مەسە_, ssås, 
   {{0x9f595e2a,0x6f6015c3,0xc9f400c6,0xdb1c01ab}},	//   strò_, _بۇرم, مستع, _strò, 
   {{0x29041570,0x61e402c4,0xeea817a0,0xc954004e}},	//   tgna_, _xwil, _шток_, йткы, 
   {{0x98ac0bcc,0x7a180f40,0xdb000139,0x9f580393}},	//   _aldı_, dātā, _ahmä, guræ_, 
   {{0x29055e2b,0x98c41b15,0x286800a7,0x93bc1418}},	//   rgna_, әсәл, ърдо_, twăl, 
   {{0x6b980944,0x9b94bf77,0x9b58013e,0x290401ab}},	//   _ukug, _дисц, _кист_, sgna_, 
   {{0x7a1800e2,0xdb1c005c,0x09d40154,0xddc40064}},	//   gātā, _buræ, _হয়রা, oziš, 
   {{0x61e4009f,0xa50406ba,0x8548023a,0x6e380327}},	//   _rwil, جىدە_, узов_, _ġubl, 
   {{0x61e40c11,0xaef801e1,0xc7d8d6c8,0x9984088c}},	//   _swil, _alùm, _смех_, _ظلمو, 
   {{0xf2dc2776,0xe1f802a9,0xa800013d,0x3e5c002b}},	//   gbâ_, аҳи_, _çıqs, _yātā_, 
   {{0xcfd008b0,0x26dc0115,0x7c380092,0x95c800f3}},	//   _ﻛﺎﺭﺗ, mbuo_, _የሚሄዱ, _куја_, 
   {{0x23ccb658,0xd5c80208,0x6444005b,0x00000000}},	//   _संपद, _kền_, äjis, --, 
   {{0x7194001f,0xddc4feb5,0x437401fe,0xb17801e3}},	//   _ማጥፋት_, dziš, _гупт, tsår, 
   {{0xe5101a22,0xa3e405d7,0xd5c8004d,0x61e55e2c}},	//   त्रि_, मीण_, _mền_, _twil, 
   {{0x61e55e2d,0xb178007c,0x00000000,0x00000000}},	// [23c20] _uwil, rsår, --, --, 
   {{0xed5400c7,0x3e5c0374,0x1cc8025c,0xdb1c008e}},	//   боу_, _rātā_, _ྋཔཎ_, _kurç, 
   {{0xd5c80016,0x8fd400ee,0xb17899c0,0x6e28005c}},	//   _nền_, _мәтә, psår, ægbr, 
   {{0x38780cc1,0x8fc45007,0xfb881d37,0xff24992f}},	//   _üzrə_, _گزین, ыбек_, _уммо, 
   {{0x9f580381,0xa3e40fe3,0x00000000,0x00000000}},	//   turæ_, मीत_, --, --, 
   {{0xd5c8001e,0x7a181a14,0xb178003b,0x8fc402f2}},	//   _bền_, vātā, nsåp, _دزین, 
   {{0xb88c02d3,0xdb1c5043,0x00000000,0x00000000}},	//   _ዝቕጽል_, _nurç, --, --, 
   {{0xe9d4891e,0x26dd5e2e,0x7c2cdac1,0xa5000135}},	//   шкә_, gbuo_, _isbr, _མཐུག_, 
   {{0xec6c0241,0x4b500244,0x00000000,0x00000000}},	//   _òòró_, _تێنر, --, --, 
   {{0xdb1ca697,0x3ea01445,0x1c0c012c,0x6efc01e1}},	//   _burç, _mykt_, _हमाल_, _kàbà, 
   {{0xe60d5e2f,0xdcfc0055,0x6efc0248,0x3ea04699}},	//   وشی_, _akrī, _jàbà, _lykt_, 
   {{0xf364ce9e,0xf48401a9,0x00000000,0x00000000}},	//   стон, _қулн, --, --, 
   {{0xa34405f5,0x36340597,0x6b8000f2,0x2ea40073}},	//   чээл, _دراس, éngi, _खरेत, 
   {{0xb17800d4,0x7c2cf612,0x23480150,0x9f5800e4}},	//   gsåp, _osbr, _ۇلىپ_, hurä_, 
   {{0xdb1d1be6,0x00000000,0x00000000,0x00000000}},	//   _kurä, --, --, --, 
   {{0x2e4800a7,0x00000000,0x00000000,0x00000000}},	//   лязо_, --, --, --, 
   {{0xa2a011d7,0x7c2d30ab,0x490800e1,0xf1247927}},	// [23c30] _गुप्, _asbr, _सालो_, _льно, 
   {{0xdb1c0bc9,0x6efc01e1,0x3ea00267,0xd6c400fe}},	//   _lurä, _bàbà, _dykt_, _এজোপ, 
   {{0x3ea002d2,0x09d00073,0x4b540395,0x6d8800ef}},	//   _eykt_, हऱ्य, жълт, bļan, 
   {{0xd5c80051,0x20680150,0x9f580139,0x00000000}},	//   _rền_, _ышып_, gurä_, --, 
   {{0x7c2d5e30,0xd5c80051,0x00000000,0x00000000}},	//   _esbr, _sền_, --, --, 
   {{0x48241b92,0x6efc0248,0xaef80cad,0x940801f9}},	//   قىتق, _fàbà, _olùk, वढाच_, 
   {{0xa2a01af8,0xdc7400c7,0x9be40024,0x00000000}},	//   _गुन्, _егры, _нітк, --, 
   {{0x8f04151c,0x23cc2e1e,0x00000000,0x00000000}},	//   _єlє_, _संबद, --, --, 
   {{0x9f615e31,0x388003e3,0x764401f4,0x5a440064}},	//   érés_, _əsrə_, äkyp, _нэфа, 
   {{0xe9395e32,0x7c2c00a9,0xc484084c,0x00000000}},	//   _حسرت_, _ysbr, жлок, --, 
   {{0x838863ee,0xdb1c013d,0x39740133,0xdcfc00de}},	//   ибов_, _qurç, _بڵند_, _skrī, 
   {{0xd054016b,0x7c3800d0,0xa50415bf,0x00000000}},	//   _ɔbɔm, _štrk, جىگە_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfd50063f,0x98fc01e4,0x200c0137,0xd1746f32}},	//   _dajụ, _alĉj, àdio_, пысы, 
   {{0x3ea15e33,0x4368074d,0xb1780fac,0x71a00b01}},	//   _sykt_, _вайн_, rsåp, фарз, 
   {{0x34b000f1,0x38780413,0x00000000,0x00000000}},	//   _غميز, úpri_, --, --, 
   {{0xc5f8010f,0x3ce400bc,0x00000000,0x00000000}},	// [23c40] יפּט, टरले_, --, --, 
   {{0xc1041c36,0x00000000,0x00000000,0x00000000}},	//   _بودي, --, --, --, 
   {{0x7ac55e34,0xfc2800ee,0x3ea0002d,0xdb1c03cd}},	//   осле, ржек_, _wykt_, _lurå, 
   {{0x8fd423c9,0xd9789e04,0x3ea00450,0x2b4001c4}},	//   _хәрә, әрдә_, _tykt_, дэшг, 
   {{0xee35234c,0x7f44021a,0xdb1c0309,0xa2a0190c}},	//   _дня_, _inkq, _rurä, _गुम्, 
   {{0x58d43740,0xdb1c008e,0xe97005af,0xfca84dc1}},	//   чокт, _surä, وهند, _نازو_, 
   {{0xcd280050,0xb22408a7,0x96f800f7,0xf66801a8}},	//   _اسُن_, _kvæð, бейт_, kvæð_, 
   {{0x7bdc02f6,0xeb955e35,0xba2800f2,0x00000000}},	//   mppu, _дис_, _پسرم_, --, 
   {{0x7ae15e36,0x7bdc023a,0x7588adae,0xeb5000db}},	//   mbot, lppu, исов_, _تۉنگ, 
   {{0x7ae15e37,0x7bdc8e0d,0xf2e001ad,0x7afc0153}},	//   lbot, oppu, पर्घ, ėptu, 
   {{0xa2a003ce,0x5334011c,0x4b500345,0x00000000}},	//   _गुब्, пент, _تێۆر, --, 
   {{0x7ae15e38,0x7bdca9b5,0x7f44009a,0x00000000}},	//   nbot, ippu, _nnkq, --, 
   {{0x67600014,0xd5c80208,0x00000000,0x00000000}},	//   _زُول, _kềm_, --, --, 
   {{0x79895e39,0x7ae0014f,0x2fd400ae,0x75880240}},	//   nnfw, hbot, قترح, _ዝብሉዎ_, 
   {{0xd5c807ae,0xd5b80318,0x6114009d,0xdfd401f4}},	//   _mềm_, mmā_, ьдру, досы, 
   {{0x6e2d5e3a,0xd5b8005f,0xa85402e4,0x929400d3}},	//   _pscb, lmā_, חילה_, _найц, 
   {{0x7ae00158,0xd83802e2,0x00000000,0x00000000}},	// [23c50] dbot, _syčl_, --, --, 
   {{0x7f4401e2,0x7ae15e3b,0x6ca55e3c,0xeca40063}},	//   _enkq, ebot, ореж, ојен, 
   {{0x9ad8063f,0xd5b800e2,0xb1780fac,0xdd9828f6}},	//   _ịrụg, imā_, gpåe, ішу_, 
   {{0x7ae15e3d,0xa2a01524,0xb1784cab,0x00000000}},	//   gbot, _गुड्, spåd, --, 
   {{0x7bdc0af5,0x00000000,0x00000000,0x00000000}},	//   appu, --, --, --, 
   {{0x7ae00ba7,0x00000000,0x00000000,0x00000000}},	//   abot, --, --, --, 
   {{0x6d455e3e,0x7ae15e3f,0x6e3801fa,0x5bc400db}},	//   _inja, bbot, _šubh, سقۇل, 
   {{0x37242b65,0xdb1d5e40,0x6d44032e,0xd5b800de}},	//   _རྒྱལ_, _strö, _hnja, emā_, 
   {{0x6d44009b,0x497439c8,0xe9d0036b,0x6b815e41}},	//   _knja, _елас, _آغر_, éngu, 
   {{0x69d80428,0x758802d3,0xdb1c002d,0xaef801c3}},	//   _itue, _ዝብልዎ_, _ourû, _dlùi, 
   {{0x04441830,0x03a55e42,0x6d4518e3,0x6b895e43}},	//   ченн, зино, _mnja, ongg, 
   {{0x69d80158,0x06742401,0xa9c801ec,0x00000000}},	//   _ktue, _нуля, _ﻗﻮﯕﺴ, --, 
   {{0x6d455e44,0x6b88079b,0xaef801c3,0xd77411dc}},	//   _onja, ingg, _glùi, _تالع, 
   {{0xb224008c,0x7638008f,0xf1bc0548,0xa2a066c0}},	//   _svæð, _לענג, nwáh_, _गुण्, 
   {{0xee3c0109,0x98ac00dc,0xbfa80014,0x00000000}},	//   _arý_, _kadā_, مارٕ_, --, 
   {{0x6d455e45,0x7c380aa6,0x7ae00175,0xf410011a}},	//   _anja, _átri, xbot, _נפח_, 
   {{0x7dc55e46,0xa3e42c33,0x98ac00b8,0x7ae1139c}},	// [23c60] سقان, मीर_, _madā_, vbot, 
   {{0x6b880399,0x6b50010e,0xaef80ca8,0x6da00022}},	//   engg, _içgy, _olùw, еиуа, 
   {{0x7bdc0eda,0x69d911bf,0x7ae0010a,0xee3c05da}},	//   uppu, _atue, tbot, _erý_, 
   {{0x7f488fcb,0x6d455e47,0x7bdc023a,0x6b88020c}},	//   _الحق_, _enja, rppu, gngg, 
   {{0x20195e48,0xb6c405f5,0x19586518,0xef1401c6}},	//   ltri_, үсий, жалы_, _эмя_, 
   {{0x7ae15e49,0x6d4404a7,0x2240020c,0xdb1c00c7}},	//   sbot, _gnja, _mrik_, _jurú, 
   {{0x20195e4a,0x69d8003a,0xd838007f,0xdb1c0332}},	//   ntri_, _etue, _tyčm_, _murú, 
   {{0x95d81c22,0x2240014a,0x2018004d,0x6e381dd5}},	//   одит_, _orik_, itri_, _šubi, 
   {{0x7bcc2f2b,0xd5b80882,0x79c803c7,0x20192009}},	//   _hubu, tmā_, _طواف_, htri_, 
   {{0x20195e4b,0xf9880691,0xe9900ed1,0x24e000d4}},	//   ktri_, _اخره_, _كۇنگ, нцюг, 
   {{0xd5b934c7,0x224000ca,0x7bcd5e4c,0xa3e427f2}},	//   rmā_, _arik_, _jubu, मील_, 
   {{0x98ac0029,0x22415e4d,0x7bcd5e4e,0x20180048}},	//   _gadā_, _brik_, _mubu, dtri_, 
   {{0x98fc01e4,0xdb1c0ca8,0x20195e4f,0x163412b4}},	//   _alĉi, _burú, etri_, _целя, 
   {{0x22415e50,0x66b8011a,0x20195e51,0x00000000}},	//   _drik_, _המדה, ftri_, --, 
   {{0x7bcd5e52,0x98ac0882,0xa194074d,0xd8380100}},	//   _nubu, _yadā_, харч, _syčj_, 
   {{0xee3c012c,0x6d4401a8,0x2240bd1d,0x1fa402dd}},	//   _prý_, _snja, _frik_, еруг, 
   {{0x7bcc014a,0x22401509,0x6d440a2e,0x98fc010f}},	// [23c70] _aubu, _grik_, _pnja, _elĉi, 
   {{0xdb1d5e53,0x6b880007,0x9df80108,0x00000000}},	//   _turû, wngg, янут_, --, 
   {{0x69d95e54,0x7bcd5e55,0x320800b5,0xf1a8a675}},	//   _stue, _cubu, lucy_, _پاکه_, 
   {{0x7bcd5e56,0x23cc000b,0xee3c022c,0xf1bc0548}},	//   _dubu, _संसद, _trý_, wwáh_, 
   {{0x7bcc0393,0x7f38011a,0x6ce4003b,0x00000000}},	//   _eubu, _ותרג, _ніве, --, 
   {{0x98ac0882,0x7bcd4756,0x23c401e1,0xa3b40d2e}},	//   _sadā_, _fubu, _kèjì_, _जीन_, 
   {{0x7bcd5e57,0x5c0442cd,0xf1bc011f,0x23c401e1}},	//   _gubu, _пята, rwáh_, _jèjì_, 
   {{0xeaf8a4ca,0x998c05a1,0x23c401e1,0xee3c00a2}},	//   _درست_, đoše_, _mèjì_, _zyýa_, 
   {{0xdd9015fa,0x7bd000da,0x7bcc0223,0x69d8009f}},	//   _شوې_, ējuš, _zubu, _utue, 
   {{0x7bcc01b2,0x20180162,0x00000000,0x00000000}},	//   _yubu, ytri_, --, --, 
   {{0x98ac0a28,0xa3e407d0,0x20195e58,0x57a400c7}},	//   _tadā_, मीं_, xtri_, ьшәа, 
   {{0x22415e59,0xc624009e,0x00000000,0x00000000}},	//   _prik_, বিবা_, --, --, 
   {{0xdb1c0124,0xb3380076,0xfaf4011a,0x9f580022}},	//   _purú, ilçh, וצרי_, purú_, 
   {{0x20195e5a,0x65ac03b2,0x00000000,0x00000000}},	//   ttri_, bøha, --, --, 
   {{0x7f5803b7,0xe4a468b2,0x2c280023,0xbf65160f}},	//   ојат_, _эрдо, _ደጋጊም, ودرو, 
   {{0x22415e5b,0x7bcd5e5c,0x20180fc7,0x23c40241}},	//   _trik_, _rubu, rtri_, _dèjì_, 
   {{0x22415e5d,0x3dd00399,0x6fb15e5e,0x00000000}},	// [23c80] _urik_, uqyw_, ئمقا, --, 
   {{0x7bcd5e5f,0xe28401b9,0x2018003a,0xf18401ec}},	//   _pubu, _олқи, ptri_, _ойыл_, 
   {{0x7bcc03d9,0x63a55e60,0x81d40eac,0xec74b3bc}},	//   _qubu, _kkin, _হিট_, мпф_, 
   {{0xf454008f,0xd12c0014,0x98ac0356,0x6b60074d}},	//   ויער_, _پۅہ_, _ladă_, ккха, 
   {{0x7bcd5e61,0x63a55e62,0x6b800066,0x6a10009a}},	//   _wubu, _mkin, ènga, نبور, 
   {{0x63a4089c,0x7c395e63,0xdb1c03cd,0xa9640139}},	//   _lkin, _štru, _lurø, мича_, 
   {{0x6cc05409,0x7bcc1c06,0xa2a031a0,0x6d34008f}},	//   _айра, _uubu, _गुस्, _קטלא_, 
   {{0x96340577,0x63a55e64,0x3688444e,0x7c3c00d7}},	//   ениц, _nkin, жсон_, mvpr, 
   {{0x7c3c072b,0x00000000,0x00000000,0x00000000}},	//   lvpr, --, --, --, 
   {{0x63a55e65,0xa3cc3bca,0x98ac054e,0x54540021}},	//   _akin, _वंश_, _cadă_, евот, 
   {{0x7bd80231,0xb4dc068f,0xdb1c003b,0x93bc04ba}},	//   _étud, _तभी_, _burø, kwăt, 
   {{0x648401c0,0xa2a000dc,0x80a0000d,0xf54001c6}},	//   ьсыг_, _गुह्, _गड़े, хдүү, 
   {{0x63a4089c,0x667000ae,0x00000000,0x00000000}},	//   _dkin, _لدور, --, --, 
   {{0x63a55e66,0x76400cad,0x238801d3,0x02e40022}},	//   _ekin, _iroy, vője_, _ҧсыҭ, 
   {{0x63a40418,0xb91001f2,0xb1780158,0x6590a97e}},	//   _fkin, wanụ_, gpåa, _шашу, 
   {{0x238801ed,0x76415e67,0x7c3c0010,0x7f54036e}},	//   tője_, _kroy, dvpr, gjyq, 
   {{0xd0d40801,0xc444036b,0xa3b806c2,0x00000000}},	// [23c90] _попъ, _قیین_, _تاور_, --, 
   {{0xb91001f2,0x753803cd,0x238800e5,0x3f8c0248}},	//   ranụ_, ndtz, rője_, _ìfun_, 
   {{0x2ca404ce,0x3cdc0307,0x6ca40395,0x00000000}},	//   ænd_, गड़े_, фраж, --, 
   {{0xecdc02ab,0x9950002e,0x00000000,0x00000000}},	//   _प्रफ, _fàŋ_, --, --, 
   {{0xaef80192,0x7e74033f,0x656c01c7,0x00000000}},	//   _dlùt, czyp, ëchk, --, 
   {{0x9b68035b,0x00000000,0x00000000,0x00000000}},	//   зшәа_, --, --, --, 
   {{0x07a55e68,0x76415e69,0xc7a46995,0x26c800d7}},	//   накн, _aroy, никк, žcom_, 
   {{0x76401125,0x68380020,0x00000000,0x00000000}},	//   _broy, _በክርስ, --, --, 
   {{0x76415e6a,0x00000000,0x00000000,0x00000000}},	//   _croy, --, --, --, 
   {{0xe848036b,0x764006ea,0xc4c82c35,0xf65001d3}},	//   _وجان_, _droy, रशेख, ائٹ_, 
   {{0x98ac0276,0x76412623,0x00000000,0x00000000}},	//   _vadă_, _eroy, --, --, 
   {{0xd7c95e6b,0xf8ac0330,0x5eb803d4,0x867400d4}},	//   _قوله_, _اکه_, েঁতে, _плеє, 
   {{0x63a44a5d,0xee3c00a2,0x23cc03ce,0x00000000}},	//   _vkin, _syýn_, _सूरद, --, 
   {{0x66181574,0x63a40472,0x6738000d,0xaef80248}},	//   mtuk, _wkin, lduj, _olùs, 
   {{0x66195e6c,0xa2a072c0,0xdb1c05ac,0x0444299f}},	//   ltuk, _गुर्, _turø, _чейн, 
   {{0x67395e6d,0x66187851,0x4f94009d,0x00000000}},	//   nduj, otuk, вруу, --, 
   {{0x644000d0,0xf770010f,0xfce4010a,0x8234007b}},	// [23ca0] _hrni, אקן_, еозо, _أربا, 
   {{0xa3b409d9,0x66195e6e,0xb3380120,0x64405160}},	//   _जीत_, ituk, moça, _krni, 
   {{0xaac82a05,0x66195e6f,0x673801e4,0xd8380306}},	//   िशंक, htuk, kduj, _tyči_, 
   {{0xeb955e70,0x66195e71,0x592807e4,0x6738068f}},	//   них_, ktuk, _རིངས_, jduj, 
   {{0x3f800a73,0x644001e4,0x66180309,0xf984023b}},	//   _imku_, _lrni, jtuk, нгдо, 
   {{0x64415e72,0x75380175,0x2a04568c,0x00000000}},	//   _orni, xdtz, رقىپ_, --, 
   {{0xb864004b,0x66180254,0xfca80b24,0x05d4000d}},	//   عاتو, etuk, _راسو_, _डूबब, 
   {{0x76415e73,0x35e4531d,0xdb080598,0x2a6c0085}},	//   _proy, нцов, çlär, ómbó_, 
   {{0xf65019dd,0x66195e74,0xeb955e75,0xadc00016}},	//   ائع_, gtuk, _чит_, _hoạc, 
   {{0x64409638,0xdcfc01a6,0x00000000,0x00000000}},	//   _brni, _omrč, --, --, 
   {{0x64400b91,0x66195e76,0x395c00db,0x1fe0009e}},	//   _crni, atuk, _iots_, _বয়সস, 
   {{0x76415e77,0x395c01c0,0x6440623e,0x45180327}},	//   _troy, _hots_, _drni, ྱུུར_, 
   {{0x64415e78,0xb3d081fc,0x76415e79,0x395c0549}},	//   _erni, _өйлә, _uroy, _kots_, 
   {{0x395c0204,0x64400010,0x8474001f,0xddc800a2}},	//   _jots_, _frni, ርሜሽን_, _ülňi, 
   {{0x395cc735,0x2d8c00e5,0xb63802dd,0xc8301ef7}},	//   _mots_, égem_, _ﺘﻤ_, _በርሚን, 
   {{0x9f340046,0x395d5e7a,0xb33800d8,0x00000000}},	//   лесі, _lots_, boça, --, 
   {{0x395c0204,0x31c40640,0x644002f0,0x8d9400d1}},	// [23cb0] _oots_, _псов, _zrni, پلاش, 
   {{0x91800075,0x67380cf4,0x395d5e7b,0xa3e40bae}},	//   _ئۇسۇ, zduj, _nots_, मीक_, 
   {{0x661805f5,0xc0c000d1,0xb0c4468d,0xa8000213}},	//   ztuk, _вәти, _ящик, _çıxs, 
   {{0x66195e7c,0xab6000d1,0xd5c80051,0x00000000}},	//   ytuk, دۇرى, _iều_, --, 
   {{0xaef801c3,0x6618037e,0x1dd808ec,0xee840006}},	//   _flùr, xtuk, _भूपत, _чыно, 
   {{0x395d5e7d,0x2f3c063f,0x3338031c,0xaef800a3}},	//   _cots_, _ọghi_, _laqx_, _tlùs, 
   {{0xdd955e7e,0x395c0f85,0x2bc803f6,0x00000000}},	//   _сары, _dots_, _хуго_, --, 
   {{0x66195e7f,0xdb1c0118,0xd5c80051,0x00000000}},	//   ttuk, _kurý, _mều_, --, 
   {{0x237c044e,0x395d5e80,0xe12c031c,0x5da40014}},	//   _ኣህዛብ_, _fots_, _སྲྀད_, _شمہٕ, 
   {{0x66195e81,0x395c00cf,0x2b5c030a,0x00000000}},	//   rtuk, _gots_, _houc_, --, 
   {{0x66195e82,0x2b5c0165,0x6738047e,0x98ac0064}},	//   stuk, _kouc_, pduj, _padą_, 
   {{0x6440151c,0xe7080046,0x58840032,0x395c007f}},	//   _vrni, _ءتان_, _сыуа, _zots_, 
   {{0x66180cfe,0xdcfc14b2,0xdb1c00a2,0x98ac00c0}},	//   qtuk, _smrč, _nurý, _vadą_, 
   {{0x2b5c030a,0x55580276,0x98ac0210,0xb63802dd}},	//   _louc_, _пачя_, _wadą_, _ﺘﺤ_, 
   {{0x64415e83,0x98ac0064,0xb178007c,0xb4f800d9}},	//   _urni, _tadą_, mpål, _חפצי, 
   {{0x20055e84,0xc244023b,0x0324084c,0xd5c80051}},	//   čmi_, _аник, _рдин, _dều_, 
   {{0x656c0036,0x9f5800ae,0x6e3801ef,0x00000000}},	// [23cc0] ëchw, orrú_, _šubr, --, 
   {{0x6d8800da,0xdb1c0209,0x98fc0115,0xfce401ec}},	//   kļau, _durý, _koĉe, тожо, 
   {{0x2b5c59e5,0x395d5e85,0x6cc002e8,0xa2c4013d}},	//   _bouc_, _rots_, айфа, _шәүк, 
   {{0x236008cd,0x395d5e86,0x26cc04fb,0x00000000}},	//   _joij_, _sots_, _nggo_, --, 
   {{0x395d5e87,0x2b5c0165,0xdb1c010b,0x00000000}},	//   _pots_, _douc_, _gurý, --, 
   {{0x26cc013c,0xd91010e8,0x69200fac,0x00000000}},	//   _aggo_, صیص_, имча, --, 
   {{0x395c00f7,0xa3c40cf1,0xb17801bf,0xf50800d1}},	//   _vots_, ौदा_, dpål, ۈزدى_, 
   {{0xf0910b71,0x2b5c0165,0x3f90a86f,0x00000000}},	//   ינו_, _gouc_, nnyu_, --, 
   {{0x395d5e88,0xe9d80014,0x7aa400c7,0xd9dc00eb}},	//   _tots_, _قدٕچ_, _риаз, _ডটকম, 
   {{0x26cc0ea0,0xf1c40306,0x13bc00dc,0xdb500133}},	//   _eggo_, čáku_, ोद्भ, _خێڵ_, 
   {{0x98fc00c8,0x2b5c05c7,0x01e0009e,0xaef80248}},	//   _voĉd, _youc_, _বিষদ, _olùp, 
   {{0xf3640354,0xa878010f,0x2ca4000d,0x00000000}},	//   ттон, _קאאר, ündi_, --, 
   {{0x2d8c00dd,0x25a40109,0x6d880034,0xdb1c00d7}},	//   égek_, _fknl_, nżac, _huró, 
   {{0xaef801e1,0x3f900a55,0x2fc801a6,0xd8380306}},	//   _alùp, enyu_, _sicg_, _ksč_, 
   {{0x656c5eb5,0xa3b402db,0xb4dc0316,0xdb1c1574}},	//   êche, _जीव_, तडी_, _juró, 
   {{0x8afc012c,0x5f94384f,0x32641086,0x2d8001a6}},	//   _koře, аист, _атов, _smje_, 
   {{0x7c380cf4,0x5ed401c6,0x9f34753d,0x00000000}},	// [23cd0] _štrp, ржуу, шеті, --, 
   {{0x8afc0118,0xd13006c2,0x00000000,0x00000000}},	//   _moře, _امد_, --, --, 
   {{0x9f5804cf,0x6ac81b61,0xdb1c002e,0xf3e400cc}},	//   guró_, िश्र, _nuró, _কিডৰ_, 
   {{0x3208012d,0xdb1c0432,0x00000000,0x00000000}},	//   orcy_, _turý, --, --, 
   {{0xd8380100,0x2b5c030a,0x00000000,0x00000000}},	//   _asč_, _vouc_, --, --, 
   {{0xdb1d5e89,0x6d8800e2,0x2b0c05dc,0x00000000}},	//   _zurü, tļau, _डाकु_, --, 
   {{0xdb1c004e,0x9f580ffb,0xb17808fb,0x00000000}},	//   _curó, murò_, vpål, --, 
   {{0x4bc4ba84,0x3a709e04,0x98fc01e4,0x98ac012d}},	//   _сөзг, рләр, _roĉe, _jadę_, 
   {{0xdb1ca568,0x09dc00bd,0xb1780fac,0xda3401af}},	//   _euró, _ঠিকা, tpål, _кеты, 
   {{0x28680798,0x8afc013a,0x453400f3,0x8504009a}},	//   _орео_, _doře, ухит, دودن, 
   {{0xb6a15e8a,0x32400184,0x58d404a9,0x00000000}},	//   _қишл, ҙерг, _тохт, --, 
   {{0x98fc0115,0xb0a400e1,0x00000000,0x00000000}},	//   _voĉe, _गड़ग, --, --, 
   {{0xb6d8010f,0xb380ce59,0x7c280327,0x00000000}},	//   _אַוט, слял, ħfri, --, 
   {{0xe4e402bf,0xdb1c00e8,0xb3380120,0x00000000}},	//   _рідн, _jurò, boço, --, 
   {{0x60dc003e,0x83644278,0x3f940120,0x00000000}},	//   rcrm, _مدظل, граѓ, --, 
   {{0xf41000d9,0x03b000fe,0x00000000,0x00000000}},	//   _הפה_, _ঘূৰণ, --, --, 
   {{0x932400cf,0x00000000,0x00000000,0x00000000}},	// [23ce0] _ئرىن, --, --, --, 
   {{0x61e55e8b,0xee355e8c,0xeb9401d5,0xaec0030d}},	//   _itil, ыну_, қич_, сбул, 
   {{0x71181a4c,0xbb45337d,0x3f6821f3,0x9ba80014}},	//   _אויפ, лежк, _зино_, نگرِ_, 
   {{0xdb1c0ba1,0x3ce401e4,0x200c0135,0x00000000}},	//   _aurò, ŝov_, ġdid_, --, 
   {{0xad9800d2,0xdb1c012d,0x9f5801e1,0x00000000}},	//   _dvúb, _suró, burò_, --, 
   {{0xd8380122,0x9f58c7cc,0x61e4009f,0xaa440063}},	//   _psč_, curò_, _mtil, упља_, 
   {{0xebe15e8d,0x00000000,0x00000000,0x00000000}},	//   _госп, --, --, --, 
   {{0x61e55e8e,0xdb1c2508,0x57b416a4,0x8afc013a}},	//   _otil, _eurò, јбит, _poře, 
   {{0x5694841d,0x7bc15e8f,0x61e55e90,0x80b804c5}},	//   рапт, mmou, _ntil, _আলফ্, 
   {{0x7bc15e91,0x00000000,0x00000000,0x00000000}},	//   lmou, --, --, --, 
   {{0x61e55e92,0x7bc00270,0x07f800c7,0x66700517}},	//   _atil, omou, _ахчы_, لدیر, 
   {{0x7bc15e93,0x61e40083,0x7790183b,0xb3380798}},	//   nmou, _btil, _دیبا, roço, 
   {{0x388c11a9,0xb1780158,0x98acd061,0x61e401ef}},	//   _hər_, spåm, _radę_, _ctil, 
   {{0x656c04e6,0x00000000,0x00000000,0x00000000}},	//   ëcht, --, --, --, 
   {{0x61e55e94,0x77600a81,0x6b800066,0x7bc00175}},	//   _etil, _koox, èngk, kmou, 
   {{0x61e48db1,0x77600de2,0x7bc000bc,0x63780022}},	//   _ftil, _joox, jmou, _rãng, 
   {{0x7bc08c66,0xfc68001f,0x388c00ac,0x26c800d0}},	// [23cf0] dmou, _በሚገኙ_, _lər_, žcov_, 
   {{0x66c809a5,0x7bc002fa,0x98ac0034,0x77615e95}},	//   _hökü, emou, _wadę_, _loox, 
   {{0x66c9140d,0xdd980107,0x388c06be,0x63040116}},	//   _kökü, ушт_, _nər_, _ئوۋل, 
   {{0x7bc000c7,0xac740092,0x00000000,0x00000000}},	//   gmou, _በኩልም_, --, --, 
   {{0xe9fc0016,0x7bd800f2,0x61e40327,0xb7c400ef}},	//   _trận_, _étun, _xtil, _maģī, 
   {{0x388c03b9,0x7bc0d57c,0x19594783,0x1ca80133}},	//   _bər_, amou, лачы_, _ڵێنی_, 
   {{0x77600548,0x7bc0003a,0xf8ac0133,0xd1340023}},	//   _boox, bmou, وکم_, _ብዝቐል, 
   {{0x77600548,0x7bc00036,0xc6040354,0x388c03b9}},	//   _coox, cmou, азий, _dər_, 
   {{0x7760292a,0x6b8804ba,0x00000000,0x00000000}},	//   _doox, migg, --, --, 
   {{0x45855e96,0x6b895e97,0x1658040b,0xe63c00b5}},	//   ргов, ligg, اسٹک_, _kg級_, 
   {{0x61e47670,0x473479e5,0x69c00194,0x77600548}},	//   _stil, _внес, mmne, _foox, 
   {{0x03a55e98,0x61e55e99,0x02c55e9a,0xb1780158}},	//   римо, _ptil, ийно, lpåh, 
   {{0x66c8482b,0x52755e9b,0x69c15e9c,0x388c03b9}},	//   _dökü, буру, omne, _zər_, 
   {{0x69c000c6,0x6b880014,0xf990008f,0x61e40381}},	//   nmne, higg, ַרן_, _vtil, 
   {{0x7bc15e9d,0x69c045c0,0x77608e3d,0x6b895e9e}},	//   ymou, imne, _yoox, kigg, 
   {{0x6560013b,0x26dc03f9,0x6b881418,0x9f580321}},	//   _honh, ncuo_, jigg, gurð_, 
   {{0x70880092,0x00000000,0x00000000,0x00000000}},	// [23d00] _አድርጉ_, --, --, --, 
   {{0x65615e9f,0x5fb80490,0xece400a8,0x00000000}},	//   _jonh, _आठवल, идул_, --, 
   {{0x65615ea0,0x6b880395,0x7bc15ea1,0xdb1c05f7}},	//   _monh, figg, tmou, _burð, 
   {{0x6b895ea2,0x66c80598,0x656046b7,0x69c15ea3}},	//   gigg, _xökü, _lonh, emne, 
   {{0x69c00263,0xdb1c03b2,0x77600009,0x7bc087ba}},	//   fmne, _durð, _roox, rmou, 
   {{0x65615ea4,0xf8047055,0x77615ea5,0x6d880210}},	//   _nonh, ачин, _soox, lżan, 
   {{0xa9648fad,0xdb1c0008,0x3154008f,0x8fc55ea6}},	//   рија_, _furð, ייסן_, _خزین, 
   {{0x7c2d5ea7,0x69c00194,0x7988014b,0x77600009}},	//   _ipbr, amne, sifw, _qoox, 
   {{0x65615ea8,0xe9d400d8,0xa77000d4,0xa5d0004e}},	//   _bonh, _вку_, ільч, ожыш, 
   {{0x65600cfc,0x66c92af5,0x5bc402e3,0x5694a5db}},	//   _conh, _sökü, _ịchị_, _қалт, 
   {{0x65615ea9,0x7760058a,0xf3e400fe,0x69a001f9}},	//   _donh, _toox, _কিহৰ_, गवरी, 
   {{0xb6a402dd,0x69cc021c,0xee3c00a2,0x6d880327}},	//   _киел, _écer, _gyýw_, jżan, 
   {{0x36342cbf,0x65600142,0x6b8000f2,0xb33825a8}},	//   _خراس, _fonh, èngi, loçk, 
   {{0x7c2c23f3,0x6560004c,0x066404fb,0x6b880337}},	//   _opbr, _gonh, _دامپ, zigg, 
   {{0xb4d00574,0x66c80213,0x6b880a49,0x6f8400c7}},	//   वशी_, _tökü, yigg, ауаж, 
   {{0xa520031c,0x656001a4,0x2fcc553f,0x28980677}},	//   _འཁོག_, _zonh, ögg_, דילא, 
   {{0xdef95eaa,0x69c15eab,0x7c2c00e2,0xf1a80133}},	// [23d10] рыс_, ymne, _apbr, _لاده_, 
   {{0x2d846f90,0x6b880af9,0x5d545dce,0xf1a90716}},	//   òne_, wigg, окут, _جابه_, 
   {{0xc198011a,0xfcc0013d,0x40e401af,0x00000000}},	//   _תשתי, зәтм, _усығ, --, 
   {{0xe45404ac,0x4a54237e,0x4a7400f7,0xb3440139}},	//   ייבט_, йкес, йылт, _uqçı, 
   {{0x6b895eac,0x245001f2,0x3f9c0129,0x69c00010}},	//   rigg, _ịme_, étue_, tmne, 
   {{0x6b895ead,0x69c00010,0x00000000,0x00000000}},	//   sigg, umne, --, --, 
   {{0x6b8803cd,0x65615eae,0x9be40212,0xb1780fac}},	//   pigg, _ronh, _мітк, rpåh, 
   {{0x65615eaf,0xfbb80882,0x98fc00df,0x310400cd}},	//   _sonh, ेषणम, _voĉa, वृतः_, 
   {{0x6b980428,0x65615eb0,0xea6000f2,0xb74401ec}},	//   _ijug, _ponh, _بپذی, спыз_, 
   {{0x05554fc4,0x66e400e1,0x247400ac,0x65611eb2}},	//   стия, _ट्रक_, ləmə_, _qonh, 
   {{0x9f580589,0xa3b4b340,0xd8740133,0x4368ca0f}},	//   nsrã_, _जीउ_, _وامب, ганн_, 
   {{0x6560016b,0xb3800395,0x247403b9,0xa5040116}},	//   _wonh, злюл, nəmə_, دىگە_, 
   {{0xaef801e1,0x76d000ec,0x850450d8,0x00000000}},	//   _poùn, _عيوض, _هوشن, --, 
   {{0xdedc044e,0x6b9801e6,0xf65004ae,0x00000000}},	//   _ንዕኡ_, _ljug, _מצד_, --, 
   {{0x6e2c007f,0x44200036,0x6b980241,0xb3380205}},	//   _apcb, _ëh_, _ojug, koçh, 
   {{0x6b9801f7,0xef155eb1,0x6d400129,0x93bc0356}},	//   _njug, ймс_, ônan, rtăc, 
   {{0x6ab80099,0xa3b4ad78,0x41740330,0xc6240011}},	// [23d20] _nzuf, _जीए_, _هادس, বিকা_, 
   {{0x6b9820ac,0xabcc02dd,0xe60400cf,0x00000000}},	//   _ajug, _ﺑﺎﺭﻋ, _ۉش_, --, 
   {{0xfbd15eb2,0x6ab83eba,0xbca400c6,0x9f5807c5}},	//   ستا_, _azuf, حماي, orrü_, 
   {{0x8afc0316,0xe6040b38,0x2c081d10,0x8b648944}},	//   _pořa, _ىش_, اعلی_, يانم, 
   {{0x6b980077,0x79980334,0x7c2c00e4,0x58d401c6}},	//   _djug, _pjtw, _wpbr, оолт, 
   {{0x2d8c00dd,0x6b98063f,0x00000000,0x00000000}},	//   éget_, _ejug, --, --, 
   {{0xbb4408da,0xdc2800e2,0x6b98007c,0x7c2c83fb}},	//   _левк, rķēt, _fjug, _upbr, 
   {{0xf77005d9,0x67280175,0x247406be,0x00000000}},	//   ڪاڻ_, _cbgj, cəmə_, --, 
   {{0xba5400a7,0x6b80168a,0xf1bc00d7,0x00000000}},	//   _утвъ, ënge, ntác_, --, 
   {{0x6b980254,0xf77000ec,0xb1785794,0xea74011a}},	//   _zjug, تاڻ_, lpåv, _הגמר_, 
   {{0x78b8005f,0x7ae0009a,0x53340022,0xb33806be}},	//   _uztv, ocot, оент, loçi, 
   {{0xf7b800f2,0x2bc800cd,0x7af401a9,0x00000000}},	//   _صداش_, िषया, аyti, --, 
   {{0x55589b70,0x00bc0131,0xdb0000fd,0x386c015d}},	//   _валя_, ﻠﯩﺸﻘ, _ikmä, lyfr_, 
   {{0xd54800ec,0x00000000,0x00000000,0x00000000}},	//   _ضلعو_, --, --, --, 
   {{0xfbb800dc,0x98ac0166,0xaf04013d,0xa4f800d9}},	//   ेषाम, _kodı_, йчак, _גלוט, 
   {{0xdef80184,0x24940014,0x200c0306,0xdfd802e8}},	//   йыу_, _دن٘د_, ádia_, сър_, 
   {{0x320c066d,0xceb852c6,0x98fc01e4,0xae0002ab}},	// [23d30] _így_, рән_, _noĉo, _लिओन_, 
   {{0x7ae0ea92,0x00000000,0x00000000,0x00000000}},	//   ecot, --, --, --, 
   {{0x6ab877e1,0x0f340133,0xaf500166,0x00000000}},	//   _szuf, _وکرد, _еннә, --, 
   {{0x7ae03389,0xb17801e3,0x00000000,0x00000000}},	//   gcot, gpåv, --, --, 
   {{0x2d8c00dd,0xea895eb3,0x98fc01e4,0x6e2c01ef}},	//   éges_, دخان_, _voĉn, _upcb, 
   {{0xdb00010e,0x99d49eb5,0x00000000,0x00000000}},	//   _akmä, ستها, --, --, 
   {{0x6b983953,0x6d880003,0x00000000,0x00000000}},	//   _tjug, nżam, --, --, 
   {{0x7ae15eb4,0x6b980223,0x06089088,0x2578004a}},	//   ccot, _ujug, аник_, _mêle_, 
   {{0x6ab8054e,0x47345035,0x8afc013a,0x2ab401ee}},	//   _uzuf, مرکز, _hořo, _уңды_, 
   {{0x69d81730,0xdb00010e,0x84041214,0x00000000}},	//   _iuue, _ekmä, опож, --, 
   {{0xf9900375,0xcafc0bae,0x00000000,0x00000000}},	//   _קרב_, _उजाड_, --, --, 
   {{0x69d95eb5,0x45d4016c,0x067504b9,0xdb1c00d8}},	//   _kuue, _додс, _муля, _furõ, 
   {{0xbb38008f,0x69d8000d,0x527405a9,0x7c600092}},	//   בערי, _juue, пуру, ደርሰው_, 
   {{0x16c00184,0x6d4005da,0x63780055,0x00000000}},	//   _яҡын, ônal, _dãna, --, 
   {{0xafe03db7,0x9f9801e1,0x741001d5,0x69d80037}},	//   досл, _fáìn_, _قووا, _luue, 
   {{0xbf14869d,0xd4083f6c,0x00000000,0x00000000}},	//   تورب, _اتوم_, --, --, 
   {{0x69d80421,0x442401c7,0x41b496b4,0xd178009d}},	// [23d40] _nuue, ltl_, _ومعر, рөөх_, 
   {{0x22415eb6,0x4424039a,0x81bc015b,0x7ae00129}},	//   _isik_, otl_, ইদহ_, wcot, 
   {{0x44255eb7,0x21380165,0xf98800f2,0xb17801e3}},	//   ntl_, merh_, یخته_, tpåv, 
   {{0x2d8c180f,0x2240022e,0xb3380240,0x81141d10}},	//   éger_, _ksik_, toçi, _اذکا, 
   {{0x20195eb8,0xf2dc025a,0xfa34d627,0x80dc0456}},	//   luri_, ndâa_, تراد, _मलाइ, 
   {{0x98fc008f,0xb1780158,0x9f580022,0x8afc013a}},	//   _voĉo, spåv, rurõ_, _hořl, 
   {{0x20195eb9,0x44240334,0x9f5800e4,0xa8a00395}},	//   nuri_, jtl_, surõ_, мрък, 
   {{0x7ae00a73,0x20180276,0x22400066,0x93bc0083}},	//   qcot, iuri_, _osik_, bwăy, 
   {{0x20195eba,0x69d8020c,0x4424033f,0xeb3000db}},	//   huri_, _guue, etl_, _زىلد, 
   {{0x20195ebb,0x3a240334,0x35684131,0x4424002f}},	//   kuri_, mtop_, ррин_, ftl_, 
   {{0x22403e39,0x3a240334,0x44240112,0xf30001c6}},	//   _asik_, ltop_, gtl_, үжүү, 
   {{0x20195ebc,0xc5f803f4,0xe7dc0490,0xe3b00592}},	//   duri_, _আমরা_, _पंतप, َرَ_, 
   {{0x44240561,0xa3b400ab,0x20180356,0xe2980006}},	//   atl_, _जीओ_, euri_, жаў_, 
   {{0x20195ebd,0x257806af,0x00000000,0x00000000}},	//   furi_, _pêle_, --, --, 
   {{0xe9fc0016,0x224084ce,0x3a240334,0x00000000}},	//   _trần_, _esik_, htop_, --, 
   {{0x3a240798,0x00000000,0x00000000,0x00000000}},	//   ktop_, --, --, --, 
   {{0x0ec413b4,0x8e140d30,0x3f9c00d8,0x8f540014}},	// [23d50] लेंड, ядац, étua_, _ہندش, 
   {{0x3a240334,0x00000000,0x00000000,0x00000000}},	//   dtop_, --, --, --, 
   {{0x20180262,0x98fc0115,0x3a24032e,0x00000000}},	//   curi_, _voĉl, etop_, --, 
   {{0xddc402ce,0x69d80037,0xade002a0,0x00000000}},	//   dziŵ, _puue, _कंपन_, --, 
   {{0x68e00083,0x3a240175,0x92cc03d4,0x00000000}},	//   tcnd, gtop_, শুৰ_, --, 
   {{0x44240118,0xa92801ec,0x00000000,0x00000000}},	//   ytl_, ріде_, --, --, 
   {{0xdcfc08ad,0xb178007c,0x5c04c7b0,0x00000000}},	//   _smrć, lpås, _оята, --, 
   {{0x69d95ebe,0x98fc0115,0x00000000,0x00000000}},	//   _tuue, _joĉj, --, --, 
   {{0x20195ebf,0xb1785794,0xb33806be,0xf1a80825}},	//   zuri_, npås, noçu, चकान, 
   {{0x44255ec0,0x2018019b,0x99d4143e,0x00000000}},	//   ttl_, yuri_, _قتلا, --, 
   {{0x2018c6a5,0x4424037e,0xf3f00014,0x00000000}},	//   xuri_, utl_, ى۪وک, --, 
   {{0x4425585e,0x20195ec1,0x22400419,0xb178007c}},	//   rtl_, vuri_, _psik_, kpås, 
   {{0x201806e4,0x44255ec2,0x93bc0356,0xbb380677}},	//   wuri_, stl_, ptăn, זערי, 
   {{0x20195ec3,0x200c02f0,0xab5c0150,0xb33803e3}},	//   turi_, ádio_, _ﺍﻗﺴﯟ_, doçu, 
   {{0x50b44d56,0x00000000,0x00000000,0x00000000}},	//   дсту, --, --, --, 
   {{0x20195ec4,0x02041b2e,0x7bd806af,0x22400165}},	//   ruri_, _езин, _étui, _tsik_, 
   {{0x20195ec5,0x22415ec6,0x3a255ec7,0xb1781f53}},	// [23d60] suri_, _usik_, xtop_, tpåt, 
   {{0x20195ec8,0xf1bc73ab,0x3a240334,0x00000000}},	//   puri_, ltán_, vtop_, --, 
   {{0x98fc01e4,0xf1bc007b,0x3a240175,0x7be400d4}},	//   _foĉj, otán_, wtop_, їждж, 
   {{0x3a255ec9,0xdcfceb46,0xf1bd5eca,0x00000000}},	//   ttop_, ızın, ntán_, --, 
   {{0x8b6410fe,0x3f90b445,0x6b815ecb,0x3a240334}},	//   بالم, miyu_, ënga, utop_, 
   {{0x3f907f13,0x98a00118,0xf1bc0332,0x00000000}},	//   liyu_, řič_, htán_, --, 
   {{0x3a255ecc,0xb4a8353b,0x00000000,0x00000000}},	//   stop_, _खडे_, --, --, 
   {{0x3f915ecd,0xab251ee7,0x3a255ece,0x99fc010a}},	//   niyu_, _носа_, ptop_, _гiаж_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7f44102c,0x3f9001a9,0x0968007b,0xd49800d4}},	//   _lakq, hiyu_, _وإلى_, жкої_, 
   {{0x8880024e,0x3f90037e,0x00000000,0x00000000}},	//   _لیون, kiyu_, --, --, 
   {{0x66140227,0x9e6c0023,0xe3b00133,0x00000000}},	//   ñakï, _በጺሕና_, ێرێ_, --, 
   {{0xe9fc001e,0x3f915ecf,0x00000000,0x00000000}},	//   _trấn_, diyu_, --, --, 
   {{0x764004ce,0x46c8012c,0x00000000,0x00000000}},	//   _isoy, ाइरह, --, --, 
   {{0x7f440548,0x7538f2f1,0x3f9000e8,0x00000000}},	//   _bakq, metz, fiyu_, --, 
   {{0xa8540302,0x75395c48,0x3f90022e,0xa4b40a7c}},	//   הילה_, letz, giyu_, _מלוה_, 
   {{0x61f002fb,0x7c3c035a,0x9e340108,0x00000000}},	// [23d70] čilý, ewpr, нетч, --, 
   {{0x75383203,0x66e00cad,0xb178007c,0xddb800d4}},	//   netz, _kíkó, rpås, пуєш_, 
   {{0x3f915ed0,0xb17801e3,0x3004009f,0xcc24035b}},	//   biyu_, spås, _عبدُ, ьчаҩ, 
   {{0x75380086,0x764001b9,0x705000ec,0xb178007c}},	//   hetz, _osoy, _قنڌا, ppås, 
   {{0x7640013f,0xd5b81a14,0x753801c4,0x8afc0118}},	//   _nsoy, klā_, ketz, _hořk, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x753805f5,0x764001e1,0x07a55ed1,0x6d4402d0}},	//   detz, _asoy, макн, _iaja, 
   {{0x6f1c0399,0xf1bc011f,0x2d915ed2,0x85e80212}},	//   ngqc, rwáy_, lixe_, одив_, 
   {{0x6d455ed3,0x753802c1,0xdbdc0248,0x00000000}},	//   _kaja, fetz, _láìj, --, 
   {{0x6d455ed4,0x39a4025a,0x3f9002ce,0x75382ec5}},	//   _jaja, rêsû_, ziyu_, getz, 
   {{0x6fbc05ba,0x03a55ed5,0x764001e2,0xf1bc7c7b}},	//   ्षां, дино, _esoy, ttán_, 
   {{0x6d440d29,0x66e00241,0x2d90009a,0x78bc0254}},	//   _laja, _díkó, hixe_, üpve, 
   {{0x753805f5,0xf1bc9cba,0x6d440083,0x2d90005a}},	//   betz, rtán_, _oaja, kixe_, 
   {{0x66195ed6,0x6738c52c,0xf1bd5ed7,0xc7b801d3}},	//   muuk, leuj, stán_, llő_, 
   {{0x3f915ed8,0x3f9c0798,0x66195ed9,0x00000000}},	//   tiyu_, étuo_, luuk, --, 
   {{0x64415eda,0x6d44013c,0x67395edb,0xf1bc01d3}},	//   _isni, _aaja, neuj, ltál_, 
   {{0x2d915edc,0x3f906ca0,0x66195edd,0x160003ce}},	// [23d80] fixe_, riyu_, nuuk, लीपर_, 
   {{0x2d90011f,0x98fc01e4,0x67380098,0xf1bcd203}},	//   gixe_, _voĉk, heuj, ntál_, 
   {{0x6d455ede,0x7c3c0d27,0x7f44011f,0x3f900309}},	//   _daja, uwpr, _takq, piyu_, 
   {{0x66195edf,0xeb955ee0,0x644001a6,0x67380c6a}},	//   kuuk, мих_, _msni, jeuj, 
   {{0x6d446ed5,0x19595ee1,0x59f8084c,0x69bc00c5}},	//   _faja, залы_, челя_, _लीही, 
   {{0x64401326,0xad9801e1,0x66180a49,0x7538005a}},	//   _osni, _awúf, duuk, xetz, 
   {{0xe94401b9,0xf1bc00e5,0x16200037,0x1600134e}},	//   برنی, dtál_, _ममहर_, लीनर_, 
   {{0x6d443ba3,0x8b940845,0xf608269c,0x66182252}},	//   _zaja, _зруч, охой_, fuuk, 
   {{0x644092ba,0x753805f5,0x6d455ee2,0x66195ee3}},	//   _asni, tetz, _yaja, guuk, 
   {{0x6d442db1,0xdbdc01e1,0x00000000,0x00000000}},	//   _xaja, _láíj, --, --, 
   {{0x753805f5,0x00000000,0x00000000,0x00000000}},	//   retz, --, --, --, 
   {{0x75388505,0x93bc00a8,0x66182e06,0x2d90005a}},	//   setz, ptăm, buuk, zixe_, 
   {{0xf8e01a04,0x16355ee4,0x76400472,0x75395ee5}},	//   _पलाय, _челя, _usoy, petz, 
   {{0x2d9000d8,0xc5ec00f1,0x85cc00b8,0x00000000}},	//   xixe_, _اړي_, _tārṇ, --, 
   {{0x53355ee6,0x6f6800d8,0x00000000,0x00000000}},	//   _зейт, ојав_, --, --, 
   {{0x6d448851,0x9f340046,0x64c001ec,0xf3c80345}},	//   _saja, кесі, _جيىل, _ببته_, 
   {{0x6d455ee7,0x31c4399f,0x2d90005a,0x00000000}},	// [23d90] _paja, _осов, tixe_, --, 
   {{0x6d455ee8,0xe81c012d,0x00000000,0x00000000}},	//   _qaja, _यमला_, --, --, 
   {{0x6d455ee9,0x2d915eea,0x6b800240,0x66182252}},	//   _vaja, rixe_, ëngo, zuuk, 
   {{0x6d455eeb,0x6b800374,0x661804ce,0x8afc013a}},	//   _waja, īngo, yuuk, _koři, 
   {{0x6d440a4d,0x9a240a2c,0x00000000,0x00000000}},	//   _taja, نعون, --, --, 
   {{0xda78023a,0xa8005775,0x661816ca,0x8afc013a}},	//   ьях_, _çıks, vuuk, _moři, 
   {{0xad980241,0x66180337,0x00000000,0x00000000}},	//   _awúg, wuuk, --, --, 
   {{0x66180c8a,0x261000bc,0xc72401c6,0x00000000}},	//   tuuk, _दिदी_, хдий, --, 
   {{0x4a555eec,0x6f0d5eed,0xcba40131,0x0a149dc7}},	//   _якас, _mdcc, _жаңй, _سواح, 
   {{0x66195eee,0x4464cfae,0x448808ca,0x00000000}},	//   ruuk, евов, збон_, --, 
   {{0xf1bd5eef,0x66195ef0,0xc7b801ed,0xe7440220}},	//   rtál_, suuk, plő_, _жүйе_, 
   {{0xf1bc03da,0x661816ca,0x8afc0118,0x00000000}},	//   stál_, puuk, _boři, --, 
   {{0xd7743b5f,0x59c402ab,0x25f801f9,0x00000000}},	//   _جالع, _लीडर, लीशी_, --, 
   {{0xf1bc011f,0x00000000,0x00000000,0x00000000}},	//   qtál_, --, --, --, 
   {{0xecac000d,0x00000000,0x00000000,0x00000000}},	//   _जुलफ, --, --, --, 
   {{0x98fc01e4,0x42255ef1,0xfde80137,0x43680166}},	//   _voĉi, _здив, здак_, _хаин_, 
   {{0x63a55ef2,0x6fb07d81,0xc0e55ef3,0x2ee80175}},	// [23da0] _ijin, امقا, _попк, _dfcf_, 
   {{0xbd440597,0x9f9400c7,0x00000000,0x00000000}},	//   عناي, хыҳә, --, --, 
   {{0x6f0c01af,0x63a4017a,0x2ee80175,0x00000000}},	//   _fdcc, _kjin, _ffcf_, --, 
   {{0x2ca4006a,0x63a40337,0x7ac4460c,0x38c401e1}},	//   ûnda_, _jjin, нсле, _lírí_, 
   {{0xdedc069c,0x63a400b2,0xbab8007b,0x0eb80024}},	//   _ንሕና_, _mjin, أداء_, _журы_, 
   {{0x63a401a6,0x2018208d,0xf1bc02f0,0xbb3801ec}},	//   _ljin, orri_, ytám_, _ﻓﻴﻬ_, 
   {{0x6da13b03,0x63a4009a,0xada15ef4,0x19580032}},	//   _сира, _ojin, _сарл, заһы_, 
   {{0x96355ef5,0x17550ca2,0x63a55ef6,0x20195ef7}},	//   вниц, твия, _njin, irri_, 
   {{0xe72c2004,0x2018036e,0x00000000,0x00000000}},	//   صصي_, hrri_, --, --, 
   {{0x63a55ef8,0xbb60037e,0x557400c0,0x20180200}},	//   _ajin, _forヨ_, тгот, krri_, 
   {{0x63a48d82,0x38c401e7,0x93bc0356,0x7e7401f4}},	//   _bjin, _dírí_, ltăi, hyyp, 
   {{0xb9d8069c,0x8afc00bc,0xf1bc0cde,0x20180200}},	//   _ኢለ_, _poři, rtám_, drri_, 
   {{0x20195ef9,0xf1a40815,0xf1bc0518,0xdbdc0241}},	//   erri_, ервн, stám_, _láàj, 
   {{0x63a4bc12,0xc26c00b5,0xf1bc4e82,0x38c401e1}},	//   _ejin, _dｔ_, mták_, _gírí_, 
   {{0xf1bd5efa,0x67e40139,0x00000000,0x00000000}},	//   lták_, _lıjn, --, --, 
   {{0x63a4044e,0xf1bc011f,0x533400c7,0x5f2401a9}},	//   _gjin, oták_, _реит, лфуз, 
   {{0x2018198f,0xdcfc013d,0xf1bce183,0x9f5000a2}},	// [23db0] arri_, _akrı, nták_, _ýaýa_, 
   {{0xe1f00740,0xe29c011a,0x00000000,0x00000000}},	//   _اسي_, _משחר, --, --, 
   {{0xf1900014,0x3208033f,0x78b8007c,0x8c589edc}},	//   _لُکھ, lscy_, _nytv, بلاء_, 
   {{0xf1bc01d3,0xf4ec01e1,0x290800b8,0x00000000}},	//   kták_, _sẹlè_, _śca_, --, 
   {{0x78b8022e,0x9f541cb8,0xf1bc01d3,0x00000000}},	//   _aytv, _свяч, jták_, --, 
   {{0x1ce00135,0xf1bc01ed,0x00000000,0x00000000}},	//   _ཤུར_, dták_, --, --, 
   {{0x10800131,0x38c401e1,0xab94010a,0x261000c5}},	//   _ﮬﺎﺯﯨ, _rírí_, _пăкк, _दिही_, 
   {{0x25780798,0x9bc802dd,0xed1001c6,0xd1e4069d}},	//   _pêlo_, _كۇلە_, хгvй_, ማማት_, 
   {{0xf1bc01d3,0x3208012d,0x00000000,0x00000000}},	//   gták_, jscy_, --, --, 
   {{0xef1c04cc,0x63a49eaa,0x00000000,0x00000000}},	//   _flüg_, _sjin, --, --, 
   {{0x1ce05078,0xef1c0793,0x98140214,0x628800df}},	//   _ཤུལ_, _glüg_, _مبنا, ĝdom, 
   {{0xf1bc00e5,0x00000000,0x00000000,0x00000000}},	//   bták_, --, --, --, 
   {{0x29055efb,0xf1bc011f,0x1618000d,0x00000000}},	//   oana_, otáh_, _दियर_, --, 
   {{0x290427f8,0x6ab804ba,0x6b800023,0xf1bcbdb8}},	//   nana_, _myuf, ëngj, ntáh_, 
   {{0x29055efc,0x20195efd,0x04455efe,0x27e4003e}},	//   iana_, urri_, _рейн, nqnn_, 
   {{0x29055eff,0x63a400ec,0x7e7402f6,0x6f600131}},	//   hana_, _ujin, tyyp, لۇپم, 
   {{0x6ab95f00,0xfce4fcc3,0xdcfc0139,0xe0c485cf}},	// [23dc0] _nyuf, возо, _skrı, ্ডেন, 
   {{0xee340107,0x7e7401f4,0x9d5402f2,0x00000000}},	//   ъну_, ryyp, دۆست, --, 
   {{0x29055f01,0x61e55f02,0xf1bc01ed,0x5bdc081e}},	//   dana_, _huil, zták_, यदेव, 
   {{0xf1bc011f,0x6d880135,0x00000000,0x00000000}},	//   yták_, wżat, --, --, 
   {{0x61e42047,0x2904c569,0x3f800009,0x451800fe}},	//   _juil, fana_, _ilku_, ত্যক_, 
   {{0x644c11f9,0x61e55f03,0x6b540ce8,0xfaa4035b}},	//   ācij, _muil, ешәр_, наҵо, 
   {{0x88d4045e,0x61e4f163,0x93bc0356,0x909c0023}},	//   _স্বক, _luil, stăi, _ወድዓዊ_, 
   {{0x78b80745,0xf1bc00dd,0x29040b23,0x3b040194}},	//   _vytv, tták_, aana_, qaoq_, 
   {{0xeab41411,0x95d95f04,0x61e4b0b3,0x91e005f9}},	//   _айт_, ндит_, _nuil, _गूंज_, 
   {{0x1ce0025c,0xf1bc01ed,0xd4c400db,0x00000000}},	//   _ཤུས_, rták_, лөйк, --, 
   {{0x61e41140,0xf4841bf6,0xf1bd5f05,0xb3381e54}},	//   _auil, тупн, sták_, ença, 
   {{0x61e55f06,0xf1bc0e33,0xdbdc01e1,0x00000000}},	//   _buil, pták_, _yááj, --, 
   {{0x61e55f07,0x81bc2f8b,0xe0c400fe,0xf1bc0332}},	//   _cuil, েদন_, ্ডোন, ltái_, 
   {{0x3f815f08,0x61e55f09,0xddc400e2,0x32080210}},	//   _alku_, _duil, lviņ, rscy_, 
   {{0xb33803b7,0x59280327,0x212c01ab,0xc5ec00f1}},	//   ança, _ལྡབས_, òdha_, _وړی_, 
   {{0x29055f0a,0x61e55f0b,0x3dc80083,0xa3e400e1}},	//   zana_, _fuil, _ahbw_, _बढत_, 
   {{0xdfd806bb,0x61e55f0c,0xf1bc011f,0xdd2c0153}},	// [23dd0] тър_, _guil, ytáh_, _dėži, 
   {{0x29055f0d,0x15140183,0x3f8000ef,0x6d880210}},	//   xana_, ত্ৰী_, _elku_, eżar, 
   {{0x29055f0e,0xabb00588,0x61e40d27,0x6ab8037e}},	//   vana_, аажә, _zuil, _syuf, 
   {{0x26100574,0xf1bc011f,0x6ee4036b,0x94180213}},	//   _दिली_, wtáh_, _جسدل, çrə_, 
   {{0xee855f0f,0xf1bc011f,0xde6400a7,0xaa6000fb}},	//   _рыно, ttáh_, _кърп, релһ, 
   {{0x29055f10,0xef1c05d5,0x9aa400c6,0x7bd80066}},	//   uana_, _gmür_, جمهو, _ètun, 
   {{0xdd955f11,0x2ec000dc,0x00000000,0x00000000}},	//   _тары, _शरुत, --, --, 
   {{0xcb68925c,0xef1c04cc,0x46488d87,0x00000000}},	//   _ثمره_, _flüe_, езин_, --, 
   {{0x1bb82a93,0x00000000,0x00000000,0x00000000}},	//   _شافع_, --, --, --, 
   {{0x29055f12,0xf8ac0133,0x0564f239,0xd87400d1}},	//   qana_, _ککه_, увон, _ھالب, 
   {{0x9f600023,0x61e55f13,0xd87400cf,0x00000000}},	//   ërës_, _suil, _پالب, --, 
   {{0x61e55f14,0x588401e0,0x00000000,0x00000000}},	//   _puil, _тыуа, --, --, 
   {{0x2d815f15,0xdd2c0153,0x660001ee,0x00000000}},	//   _olje_, _rėži, _толҡ, --, 
   {{0x61e55f16,0xd6680f1c,0x66195f17,0x95840006}},	//   _vuil, _جمهو_, mruk, _кліе, 
   {{0xa3e41b90,0x2fc40374,0x61e40076,0x437401a9}},	//   _बढि_, _ūnga_, _wuil, _бупт, 
   {{0x61e55f18,0x2d800165,0x8afc00bc,0x1600466d}},	//   _tuil, _alje_, _mořs, लीवर_, 
   {{0x733800c8,0xbc680e60,0xdd2c0006,0x6618d4b6}},	// [23de0] _טעקס, کمان_, _vėži, nruk, 
   {{0x5bdc194b,0xfaa401ec,0xa3e4023e,0x00000000}},	//   यद्व, ңажо, _बढा_, --, 
   {{0x66195f19,0x2d8009a8,0x82341968,0x00000000}},	//   hruk, _dlje_, _شرکا, --, 
   {{0xd9cc1431,0x3f8001f5,0x200c13d5,0x7dc000d0}},	//   ाष्ट, _ulku_, ádiu_, pôso, 
   {{0x6618125c,0x2fc40022,0x9f50010e,0xe9fc0051}},	//   jruk, _ënga_, _ýaña_, _trẽn_, 
   {{0xa9655f1a,0xf848084c,0x93bc0311,0xd7f40022}},	//   лича_, ечий_, ltăt, азкы, 
   {{0x66195f1b,0x2d8c00e8,0x00000000,0x00000000}},	//   eruk, ëgee_, --, --, 
   {{0xa3e409d9,0x66181f53,0x93bc054e,0x00000000}},	//   _बढ़_, fruk, ntăt, --, 
   {{0x6b615f1c,0x661806fd,0xc5ec004b,0xf1bc00e5}},	//   _укта, gruk, وړو_, stái_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc4446ee9,0x6618dfe5,0x64540077,0xa9200153}},	//   لیون_, aruk, _áxil, ąžta, 
   {{0x661878d0,0x69cc0395,0xf364e017,0x00000000}},	//   bruk, _ècer, утон, --, 
   {{0x6618020c,0x6b800240,0x246400cf,0x00000000}},	//   cruk, ëngi, _ەمىپ_, --, 
   {{0x23600086,0xe5a01768,0x94d400a8,0x7c2c025c}},	//   _enij_, _личи, _колц, _oqbr, 
   {{0x6b8002b1,0x00000000,0x00000000,0x00000000}},	//   ūngi, --, --, --, 
   {{0x5f955f1d,0x92580022,0xb4c150c4,0xb7f400cc}},	//   бист, _ааит_, ्धी_, _ঘটাত_, 
   {{0x2d8001c7,0xe31416a2,0xaca00051,0x7e6001f4}},	// [23df0] _plje_, _طبيب, _trịc, äopp, 
   {{0x38441e38,0x2b5c0165,0x61f400ec,0x00000000}},	//   ረተሰብ, _snuc_, _اسيء, --, 
   {{0x67e40139,0x661801a9,0xe1f0d204,0x00000000}},	//   _pıjm, zruk, _وسی_, --, 
   {{0x6618a8cc,0x6d880327,0x00000000,0x00000000}},	//   yruk, rżaq, --, --, 
   {{0x9f980248,0xb4c0023e,0xca48007b,0x80d800eb}},	//   _náùn_, ्धु_, ئلته_, বুদ্, 
   {{0x2d80041a,0xd9440075,0xea9c0055,0xabb00022}},	//   _ulje_, مئىي, _arṣa_, шаҵә, 
   {{0x2e2c01b8,0x661802d1,0x00000000,0x00000000}},	//   lüf_, wruk, --, --, 
   {{0x29195f1e,0x3a700724,0x00000000,0x00000000}},	//   şqa_, сләр, --, --, 
   {{0xa9242781,0xea60237e,0x45840c69,0x490001e0}},	//   _معاه, _دۇشپ, игив, _һүҙг, 
   {{0x66195f1f,0x236024d1,0xf2dc015d,0x00000000}},	//   rruk, _snij_, ndâu_, --, 
   {{0xa8a4d7b1,0x6618003e,0x178409a0,0xdd1400d7}},	//   _срак, sruk, ргөм, núšk, 
   {{0x66180438,0x00000000,0x00000000,0x00000000}},	//   pruk, --, --, --, 
   {{0xb3381497,0x66180784,0xf8140133,0xb778011a}},	//   anço, qruk, _مسۆگ, _שאנש, 
   {{0x2e2c3535,0x36180375,0xe4e4187f,0x00000000}},	//   düf_, _יונד, _сідн, --, 
   {{0xd6d80348,0x84240131,0x00000000,0x00000000}},	//   _итә_, _ئىبن, --, --, 
   {{0xef140022,0x00000000,0x00000000,0x00000000}},	//   имс_, --, --, --, 
   {{0x93bc0311,0x932410de,0xaef801ab,0x00000000}},	// [23e00] rtăt, _ارىن, _snùc, --, 
   {{0x93bc054e,0x00000000,0x00000000,0x00000000}},	//   stăt, --, --, --, 
   {{0x93bc0311,0xfc28010b,0xe60400e5,0x00000000}},	//   ptăt, тжек_, _ڈش_, --, 
   {{0xe6055f20,0x93bc0276,0xeb301ca1,0x85a00116}},	//   _وش_, ltăr, قىمد, ﺌﺎﺭﺍ_, 
   {{0x0ba80ed1,0xeb3034b1,0xfce40212,0x8e74030d}},	//   دالى_, تىند, _вого, _лурч, 
   {{0x93bc084c,0xf1bc0030,0x30f800dc,0x00000000}},	//   ntăr, stáv_, ्रयः_, --, 
   {{0x37a94d9b,0xdd1400d0,0x3154010f,0x00000000}},	//   ктин_, cúšk, שיצן_, --, 
   {{0x81bc00fe,0xbb2c00d1,0x00000000,0x00000000}},	//   েদি_, ﯩﻤﻪ_, --, --, 
   {{0x7bc000bc,0x30f800dc,0x1ad403d4,0x56955f21}},	//   mlou, ्रमः_, _হ্ৰা, сапт, 
   {{0x7bc007e4,0xf1bc28bb,0xf77000e5,0x00000000}},	//   llou, ntát_, _ڈاؤ_, --, 
   {{0x2ec073c6,0xb4c00a94,0x779004fb,0x00000000}},	//   _शर्त, ्धे_, _ویتا, --, 
   {{0x93bc0356,0x287800d9,0x00000000,0x00000000}},	//   etăr, _שנאמ, --, --, 
   {{0xc7640617,0xf1bc0cde,0xe8f4030d,0x35a400f3}},	//   _دالى, ktát_, _млă_, _кадг, 
   {{0x7bc0013a,0xa638011a,0x16840133,0xf1bc00e5}},	//   hlou, _סגור, _پاڵێ, jtát_, 
   {{0x77600793,0x67e40139,0x7bc15f22,0x2fd4007b}},	//   _knox, _rıjk, klou, لترح, 
   {{0x93bc0311,0xd5b80421,0xd1300214,0xd90400f1}},	//   drăg, loā_, _کمد_, _ښی_, 
   {{0x9f054855,0x7bc15f23,0xadc000e4,0x00000000}},	// [23e10] زولو, dlou, ahẽg, --, 
   {{0x93bc0311,0xd5b802b5,0x7bc15f24,0xf1bc01d3}},	//   ctăr, noā_, elou, gtát_, 
   {{0x77615f25,0x2e2c00ac,0x00000000,0x00000000}},	//   _onox, süf_, --, --, 
   {{0x7bc0557b,0xdef8030d,0x00000000,0x00000000}},	//   glou, _выр_, --, --, 
   {{0x2d8c7ea5,0x7f3800c8,0xd5b800b0,0x00000000}},	//   èges_, _גערו, koā_, --, 
   {{0x776088f8,0x7bc0d0ab,0x6b80006a,0xb3380205}},	//   _anox, alou, êngb, liçd, 
   {{0x1ce00135,0x7bc15f26,0xb4c000dc,0xf1bc01d3}},	//   _ཤུག_, blou, ्धो_, ltás_, 
   {{0x7bc15f27,0xa9e000eb,0x00000000,0x00000000}},	//   clou, নীগঞ, --, --, 
   {{0xf1bc01ed,0x6b80a4bf,0xa2e407f7,0xe9fc0208}},	//   ntás_, ëngu, _गलौज_, _trằn_, 
   {{0x271407ae,0x776001e2,0x00000000,0x00000000}},	//   ển_, _enox, --, --, 
   {{0x04447724,0x6b8000b0,0x69c04e73,0x6fc401f9}},	//   щенн, ūngu, mlne, लतां, 
   {{0x03a55f28,0xc98407d6,0x69c02b9d,0xee3c00e4}},	//   симо, _туғи, llne, _opý_, 
   {{0xf1bc01d3,0x69c0017a,0xd29800d4,0x16340064}},	//   jtás_, olne, атрі_, _меця, 
   {{0x9f5800eb,0xb22401a8,0x7bc000bc,0xa06801ec}},	//   mpré_, _stæð, zlou, қаға_, 
   {{0x65601a84,0x93bc0311,0x69c00711,0xa08401ec}},	//   _innh, rtăr, ilne, іңме, 
   {{0x93bc0311,0x7bc00369,0x0084013e,0x7fd401ec}},	//   stăr, xlou, алҳо, сігі, 
   {{0x44255f29,0x93bc0311,0x7bc004cc,0x25f80073}},	// [23e20] lul_, ptăr, vlou, लीची_, 
   {{0xbea43461,0x44240489,0x8144015e,0x69c1354c}},	//   _ҳамк, oul_, _اندن, jlne, 
   {{0x44255f2a,0x69c00030,0x8c940212,0x7bc0013a}},	//   nul_, dlne, орці, tlou, 
   {{0xf1bd5f2b,0x7bc15f2c,0x4424084c,0x69c15f2d}},	//   stát_, ulou, iul_, elne, 
   {{0x44255f2e,0x09d002a6,0xaf3401ec,0x7ed400f2}},	//   hul_, াদনা, _ارپت, _دزدا, 
   {{0x44255f2f,0x7bc0012c,0xf1bc43ed,0x8a780107}},	//   kul_, slou, ltár_, ришӣ_, 
   {{0x44255f30,0xa9641b6b,0xb338456f,0x7bc15f31}},	//   jul_, сија_, liçe, plou, 
   {{0xf1bc01a2,0x22415f32,0x656003cb,0x69c11131}},	//   ntár_, _opik_, _annh, alne, 
   {{0x98fc01e4,0xd5b80618,0x44240098,0xb3395f33}},	//   _enĉa, toā_, eul_, niçe, 
   {{0x44255f34,0x79500133,0x9f580100,0x00000000}},	//   ful_, _رێبا, sprè_, --, 
   {{0x22415f35,0xd5b800b0,0xb6e402e8,0xf1bc01d3}},	//   _apik_, roā_, _люлк, ktár_, 
   {{0x776001e2,0xd5b80421,0xb4c000cd,0xb3380139}},	//   _unox, soā_, ्धौ_, kiçe, 
   {{0x44244312,0xe69000cf,0x22844eca,0x00000000}},	//   aul_, _ىلمد, пург, --, 
   {{0x3d200034,0x0f2002a0,0xf07400d1,0xd5b01888}},	//   मलों_, यल्स_, бигә_, _تفت_, 
   {{0x44255f36,0x53355f37,0x1ce0031c,0x61d81e76}},	//   cul_, _дейт, _ཤུཊ_, ёмся_, 
   {{0x2240020c,0x5f948e3c,0xb3380200,0xf1bc00e5}},	//   _fpik_, пист, fiçe, ttás_, 
   {{0xf1a8e109,0xd13000c6,0x3f9c00cf,0x69c000d7}},	// [23e30] _ماده_, _قمة_, ètua_, ylne, 
   {{0xf1bc01d3,0x2d855f38,0x3f9c003a,0x6cc40150}},	//   rtás_, óne_, étur_, _ﺒﻭﺍﺴ, 
   {{0x69c00030,0xf1bc00e5,0x00000000,0x00000000}},	//   vlne, stás_, --, --, 
   {{0x53c940c6,0x00000000,0x00000000,0x00000000}},	//   रतिश, --, --, --, 
   {{0x44255f39,0xc0b80092,0xdea401d3,0xeab000ae}},	//   zul_, ዲውል_, _ٹیلی, أعض_, 
   {{0x442429ef,0x799802d0,0x00000000,0x00000000}},	//   yul_, _cmtw, --, --, 
   {{0x44255f3a,0x799802d0,0x6b800036,0xa9040137}},	//   xul_, _dmtw, ëngs, _ۇبان, 
   {{0x3e3c0201,0x44255f3b,0x79986fb2,0x7c38014a}},	//   _አካባቢ, vul_, _emtw, _ätra, 
   {{0x44241574,0x6b98d499,0x69c001f1,0x1bd402f6}},	//   wul_, _imug, plne, _хотя, 
   {{0x44255f3c,0x85780116,0x9aa40691,0x7998035a}},	//   tul_, рсит_, _عملو, _gmtw, 
   {{0x22415f3d,0x92e400bd,0xe5e00a81,0x00000000}},	//   _spik_, _পড়ে_, _کٲتی, --, 
   {{0x44255f3e,0x224001e4,0x644c012d,0x039400d4}},	//   rul_, _ppik_, łcio, ірня, 
   {{0x6b980337,0xe6c40228,0xf1bc01d3,0xa34800c7}},	//   _mmug, _اتاي, vtár_, азҟа_, 
   {{0x44255f3f,0x22400793,0x2b9801f2,0x00000000}},	//   pul_, _vpik_, ụcha_, --, 
   {{0x44255f40,0x6b982f99,0xf1bd5f41,0x00000000}},	//   qul_, _omug, ttár_, --, 
   {{0x82a400d6,0x98bc054e,0x2d8c01c7,0xf2dc015d}},	//   _майж, levă_, ëgen_, rdâr_, 
   {{0x2240020b,0xf1bc00e5,0x8e540092,0x00000000}},	// [23e40] _upik_, rtár_, _መያዛቸ, --, 
   {{0x6b98017c,0x7ff40014,0x0d080116,0xf1bc00e5}},	//   _amug, _وسجا, йдуқ_, stár_, 
   {{0xf1bd5f42,0xfc4400cf,0xfb80072d,0x00000000}},	//   ptár_, تپاپ, وگری, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x60a0044e,0xade01fe5,0x6b98025c,0xd7f80276}},	//   _ፍልጠት_, _कंचन_, _dmug, _stă_, 
   {{0x6b995f43,0x3a2401af,0x6b803d7e,0x00000000}},	//   _emug, ruop_, ëngr, --, 
   {{0xb9000882,0x00000000,0x00000000,0x00000000}},	//   _नः_, --, --, --, 
   {{0x2ca40113,0x24c00150,0x00000000,0x00000000}},	//   únde_, _ﺭﺍﺘﻬ, --, --, 
   {{0x3cdc0882,0x1ce0031c,0x00000000,0x00000000}},	//   _कृते_, _ཤུཌ_, --, --, 
   {{0x98fc01e4,0x00000000,0x00000000,0x00000000}},	//   _inĉo, --, --, --, 
   {{0x6b9800ca,0x13f40c98,0xf1bc00c7,0xd6b41291}},	//   _ymug, язня, fuán_, _کشاک, 
   {{0xf7455f44,0x27f00306,0x00000000,0x00000000}},	//   _федо, žané_, --, --, 
   {{0x55591ee7,0x00000000,0x00000000,0x00000000}},	//   _галя_, --, --, --, 
   {{0xad9801e1,0x76400241,0x00000000,0x00000000}},	//   _ewúj, _ipoy, --, --, 
   {{0x75380175,0xb408009d,0x00000000,0x00000000}},	//   mftz, _тэлж_, --, --, 
   {{0x52155f45,0x9f688087,0xddc4010f,0x30f800dc}},	//   _едит, оруз_, rviŝ, ्रहः_, 
   {{0xceb87569,0x30e402dd,0xdd1400d7,0x9e3401f4}},	// [23e50] сән_, _мінб, _dĺžo, метч, 
   {{0x7640043b,0x93bc0276,0xd3700066,0x00000000}},	//   _mpoy, brăc, _آهک_, --, 
   {{0x98fc01e4,0xec68010b,0x1e540092,0xf0800633}},	//   _anĉo, шрак_, ፈልገና, _غیرپ, 
   {{0x6f6007a7,0x7640020c,0x6d880135,0x00b8123b}},	//   _تۇرم, _opoy, nżaz, _למתמ, 
   {{0x5f940395,0x00000000,0x00000000,0x00000000}},	//   _цият, --, --, --, 
   {{0xaca0063f,0x98ac71d6,0x00000000,0x00000000}},	//   _apục, _andı_, --, --, 
   {{0x76401714,0x9d181142,0x00000000,0x00000000}},	//   _apoy, _фост_, --, --, 
   {{0x6b98633d,0xc7941982,0x060856cd,0xc994004b}},	//   _umug, ярлы, бник_, _کارګ, 
   {{0xebbc00b8,0xd6c40014,0x00000000,0x00000000}},	//   _jaḍa_, وۅمی, --, --, 
   {{0x9fa073a0,0x6d540de2,0xa3e401f9,0x00000000}},	//   réés_, ndxa, बदल_, --, 
   {{0xad9801e1,0x1ce0031c,0xf1bc04d4,0x00000000}},	//   _awúk, _ཤུབ_, tuán_, --, 
   {{0xe1f80364,0x61b407d0,0x48c001ee,0x00000000}},	//   оҳи_, ंक्ष, _оҙҙа, --, 
   {{0x673800f3,0x1618012c,0x00000000,0x00000000}},	//   mfuj, _दिएर_, --, --, 
   {{0xf674010f,0x6d400254,0x00000000,0x00000000}},	//   _מײנט_, õnal, --, --, 
   {{0xd0580212,0x3f68009b,0x442002d2,0x00000000}},	//   орті_, биво_, _íh_, --, 
   {{0xef1c05d5,0x6440014f,0x6738037e,0x00000000}},	//   _flüm_, _ipni, nfuj, --, 
   {{0xef1c07c5,0x7dc12722,0x3cdc0073,0x00000000}},	// [23e60] _glüm_, kôst, केने_, --, 
   {{0xdee407d6,0xf1bc02fb,0x1ce0025c,0xb220008e}},	//   зоғи, nuál_, _ཤུད_, _ямьл, 
   {{0x644005b1,0x80d8015b,0xb3395f46,0x7178011a}},	//   _jpni, _ব্র্, liça, _הניס, 
   {{0x7c6c0092,0xa8040205,0x3d08190c,0x00000000}},	//   _በዋለው_, zlıç, िरहे_, --, 
   {{0xb3395f47,0x6d6400ae,0x00000000,0x00000000}},	//   niça, áraí, --, --, 
   {{0x64415f48,0xf80422c3,0xa9500150,0x00000000}},	//   _opni, пчин, екші, --, 
   {{0xf7705b9b,0xcd280014,0x7d0c0135,0x76400363}},	//   فاظ_, _بسُن_, _iebs, _spoy, 
   {{0x7d0d43c8,0x98bc00c0,0x00000000,0x00000000}},	//   _hebs, jevą_, --, --, 
   {{0x64415f49,0xeb3000db,0x00000000,0x00000000}},	//   _apni, _سىلد, --, --, 
   {{0xb3380120,0xa9a00022,0x7d0c0009,0xe9a000f3}},	//   diça, _зиуд, _jebs, _зауп, 
   {{0x74695f4a,0x00000000,0x00000000,0x00000000}},	//   ёров_, --, --, --, 
   {{0x7d0d5f4b,0x1ce00135,0x00000000,0x00000000}},	//   _lebs, _ཤུན_, --, --, 
   {{0xe29802d5,0x80d80154,0x6d88025c,0x00000000}},	//   заў_, _ব্ল্, rżaz, --, 
   {{0x7d0d5f4c,0x753401c0,0xf0740131,0x00000000}},	//   _nebs, _хэдх, пигә_, --, 
   {{0xa6200023,0x00000000,0x00000000,0x00000000}},	//   _ተቐዳደ, --, --, --, 
   {{0xb3380798,0x00000000,0x00000000,0x00000000}},	//   biça, --, --, --, 
   {{0x5f94425c,0xb33800d8,0x7d0c01bf,0x31c4003b}},	// [23e70] хитт, ciça, _bebs, _нсов, 
   {{0xf1a84046,0xec681411,0x00000000,0x00000000}},	//   _دابه_, йрек_, --, --, 
   {{0x7d0d5f4d,0x4b5402e8,0x00000000,0x00000000}},	//   _debs, дълт, --, --, 
   {{0x7d0c02d0,0xf1bc02f0,0x00000000,0x00000000}},	//   _eebs, zuál_, --, --, 
   {{0x6da000cf,0x00000000,0x00000000,0x00000000}},	//   _كۅرم, --, --, --, 
   {{0xbb2c1c5c,0xc95400dc,0xf1bc0306,0xad9802d2}},	//   ﯩﻤﻰ_, _bhūṣ, xuál_, _stúf, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb7840139,0x00000000,0x00000000,0x00000000}},	//   мәче_, --, --, --, 
   {{0x6f0d5f4e,0x6738655f,0xf1bc0306,0x668001b9}},	//   _mecc, rfuj, tuál_, عیتل, 
   {{0x6f0d5f4f,0x22940248,0xc48400f5,0x290002d2}},	//   _lecc, _lúké_, длок, _ýja_, 
   {{0xd6a801b9,0x98480276,0x04c8009a,0x04b40150}},	//   قدیم_, _няца_, تودي_, ьсия, 
   {{0x6f0d5f50,0x7bd80395,0x82a55f51,0xb33800d8}},	//   _necc, _ètut, дамж, tiça, 
   {{0xf770011a,0x00000000,0x00000000,0x00000000}},	//   _שקד_, --, --, --, 
   {{0xb3380261,0x98fc0115,0x6f0c0381,0x00000000}},	//   riça, _anĉj, _aecc, --, 
   {{0x50b48d61,0x6f0d5f52,0x3ce845a7,0x644101bd}},	//   есту, _becc, _rgbv_, _upni, 
   {{0x6f0d4775,0x7d0cc226,0x20041d55,0x44240010}},	//   _cecc, _sebs, ďmi_, mrl_, 
   {{0x6f0d5f53,0x00000000,0x00000000,0x00000000}},	// [23e80] _decc, --, --, --, 
   {{0x6f0c014b,0x41c40014,0x00000000,0x00000000}},	//   _eecc, _زٲجِ, --, --, 
   {{0x92655f54,0x7d0c33cc,0x6f0d5f55,0x21f40108}},	//   _قدیم, _vebs, _fecc, _häh_, 
   {{0x7d0c1006,0x442401c3,0x6f0d5f56,0x2ca45e4f}},	//   _webs, irl_, _gecc, únda_, 
   {{0x9f594849,0x1ce00327,0x21f4002f,0x4424002f}},	//   mprà_, _ཤུམ_, _jäh_, hrl_, 
   {{0x6f0c0c2b,0x7d0c0c52,0x81bc0154,0x6a800395}},	//   _zecc, _uebs, েদক_, ълча, 
   {{0xad980162,0x18b4035b,0xb3380166,0x00000000}},	//   _stúg, хәар, diçn, --, 
   {{0x3f90020c,0x6b600166,0xba1800ec,0x44240427}},	//   nhyu_, _икса, _ويزا_, drl_, 
   {{0x44240065,0x2b74036b,0x21f40254,0x3b0431c5}},	//   erl_, _تینگ_, _näh_, mboq_, 
   {{0x3a24014f,0xb8d400db,0xca74008e,0x692000c0}},	//   mrop_, _قتاش, _яусы, _амфа, 
   {{0x53355f57,0x88815f58,0x3a2403cd,0x37e400db}},	//   нент, _میون, lrop_, _жожг, 
   {{0xf36428e5,0xd1e4010c,0x21f55f59,0x00000000}},	//   фтон, ዛዛት_, _bäh_, --, 
   {{0x6f0d5f5a,0xf20445b5,0x3a2406a3,0x3f900810}},	//   _recc, ьяно, nrop_, dhyu_, 
   {{0x2018009f,0x21f400a2,0x00000000,0x00000000}},	//   fsri_, _däh_, --, --, 
   {{0x6f0d5f5b,0xf3b00588,0x4424067c,0xe3b0004b}},	//   _pecc, _аҩны, crl_, ارۍ_, 
   {{0x3a255f5c,0xdfd412b9,0x3f900076,0xee84010b}},	//   krop_, восы, ghyu_, мызо, 
   {{0x6f0c43df,0xb33800cf,0x00000000,0x00000000}},	// [23e90] _vecc, liço, --, --, 
   {{0x3a255f5d,0x6f0c0694,0xeca41f5a,0x6ca40cb6}},	//   drop_, _wecc, мјен, мреж, 
   {{0x6f0d5f5e,0x98fc01e4,0x21f40112,0x00000000}},	//   _tecc, _tnĉj, _zäh_, --, 
   {{0xad995f5f,0x09b80882,0x3f90003e,0x00000000}},	//   _stúd, ेत्य, chyu_, --, 
   {{0xdbdc0579,0x3a240158,0x6a64007b,0x00000000}},	//   ráðn, grop_, بطال, --, 
   {{0x9f58e0e2,0x00000000,0x00000000,0x00000000}},	//   mprá_, --, --, --, 
   {{0x5cc40064,0x5bc400cf,0x857800c7,0x00000000}},	//   _астз, رقۇل, ҧсот_, --, 
   {{0x3a709e04,0xd7f801fb,0x1938037e,0x060822c3}},	//   тләр, _trăn_, _ｗａｂ_, пник_, 
   {{0x3a240076,0xaad0515b,0x76200022,0x00000000}},	//   crop_, _तरिक, гмыз, --, 
   {{0x44255f60,0x00000000,0x00000000,0x00000000}},	//   trl_, --, --, --, 
   {{0x4424030d,0x29055f61,0x03a434da,0xbb1424ae}},	//   url_, mbna_, еино, _ﺳﻪﻥ_, 
   {{0x442401e0,0xef1c006a,0x29040135,0x00000000}},	//   rrl_, _ndü_, lbna_, --, 
   {{0x44240395,0xaef801c3,0xb3801b04,0x2bb4012d}},	//   srl_, _gnùi, улял, _अदना, 
   {{0xef1c2776,0x290406a3,0x442409a8,0x21f40e03}},	//   _adü_, nbna_, prl_, _väh_, 
   {{0x3f9002b9,0x75d04c1c,0x03a47b98,0xb33800d8}},	//   thyu_, _حيوا, _пико, ciço, 
   {{0xdb000129,0x21f40108,0x00000000,0x00000000}},	//   _emmê, _täh_, --, --, 
   {{0x606400d1,0x20195f62,0x2bb008a3,0x00000000}},	// [23ea0] رۇڭل, ssri_, ंचना, --, 
   {{0x7dc55f63,0xed542786,0x3f900526,0x4104311c}},	//   رقان, ноу_, shyu_, _язов, 
   {{0xb3382093,0x00000000,0x00000000,0x00000000}},	//   kiçl, --, --, --, 
   {{0x2904031c,0xada000fb,0x00000000,0x00000000}},	//   ebna_, _ҡаял, --, --, 
   {{0x6f60169c,0xb9e44d2d,0x19595f64,0xf1bc2b76}},	//   _связ, ىستى, далы_, irán_, 
   {{0xf1bc0597,0x3a240113,0x8b6401b9,0x28b8000d}},	//   hrán_, rrop_, _یاقم, _ऊँखि, 
   {{0xcc34053f,0xfdbc0034,0x3a240165,0xb8800419}},	//   _ихты, ्तीफ, srop_, _čísi, 
   {{0x9fb80122,0xebe000db,0x398002d2,0xeb5000cf}},	//   _očí_, _босп, _aðst_, _مۉمگ, 
   {{0xf1bc204e,0x5694107e,0x7bc00280,0xe8e46023}},	//   drán_, тапт, moou, ммәд_, 
   {{0xf1bc04d4,0x7bc00165,0xb3380798,0x2e34010f}},	//   erán_, loou, tiço, עריש_, 
   {{0xf1bc09c2,0x3e5002bd,0x667001b9,0x85702e0b}},	//   frán_, _lņt_, ندیر, شگوئ, 
   {{0xf1bd5f65,0xb338036e,0x394d5f66,0x7bc0030a}},	//   grán_, riço, lefs_, noou, 
   {{0x3e500100,0xb3380077,0x163520d9,0x00000000}},	//   _nņt_, siço, _реля, --, 
   {{0xf1bd5f67,0x394c29ef,0x66e15f68,0xef1c0205}},	//   arán_, nefs_, _соча, _sdü_, 
   {{0xf1bd5f69,0xe3b15f6a,0x7bc000b0,0xb338004e}},	//   brán_, _گرو_, koou, liçm, 
   {{0x394d027e,0x88c401ef,0x00000000,0x00000000}},	//   hefs_, _uděř, --, --, 
   {{0xe3b15f6b,0x98fc01e4,0x28a4256a,0x2904058a}},	// [23eb0] _درو_, _enĉi, _केनि, ybna_, 
   {{0xf1bc07dd,0xa1940354,0x00000000,0x00000000}},	//   kuái_, _баьч, --, --, 
   {{0x29041a33,0xa07400c0,0x00000000,0x00000000}},	//   vbna_, _быўш, --, --, 
   {{0x4fc00075,0x6f040129,0xaee010e0,0x7bb00022}},	//   _ئەرە, _débâ, _مۋزى, аҩсу, 
   {{0x1a6801d3,0x5b34027d,0xff14011a,0x00000000}},	//   ٹیلی_, اعمر, _בקרת_, --, 
   {{0x2904003e,0x1a6810e8,0xb33803e3,0x00000000}},	//   ubna_, عیلی_, diçm, --, 
   {{0xf1bc07dd,0x48fc00dc,0xf8ac3bd7,0x29040010}},	//   guái_, रुषो_, يکم_, rbna_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdcfc008f,0x93bc0356,0x00000000,0x00000000}},	//   _sorĉ, grăm, --, --, 
   {{0xdcfc0115,0x458402e8,0x00000000,0x00000000}},	//   _porĉ, тгов, --, --, 
   {{0xe784e017,0xf1bc00e4,0x00000000,0x00000000}},	//   _пудо, cuái_, --, --, 
   {{0x03a41d18,0xf8ac0272,0xca2c0131,0x153000c7}},	//   тимо, _بکه_, ﯩﺴﺎ_, аҕәр, 
   {{0x9f4c020c,0x69c15f6c,0xf1bc0736,0xd77800ec}},	//   _élék_, oone, rrán_, _سلوڪ_, 
   {{0x69c15f6d,0x412810f5,0x66195f6e,0xdb00004a}},	//   none, ього_, msuk, _emmè, 
   {{0x66195f6f,0x69c15f70,0x7d180086,0x3e50007f}},	//   lsuk, ione, _ôtsi, _sņt_, 
   {{0x69c15f71,0x7fd40220,0x3e500100,0xf2dc0142}},	//   hone, тігі, _pņt_, ffâd_, 
   {{0x63a55f72,0x66195f73,0x69c15f74,0xafe0036b}},	// [23ec0] _imin, nsuk, kone, ротл, 
   {{0x69c01a84,0xdb007587,0x66195f75,0x3e50007f}},	//   jone, _immé, isuk, _vņt_, 
   {{0x69c15f76,0xad9801e1,0x7bc00607,0xbc680330}},	//   done, _awús, toou, بمان_, 
   {{0x66195f77,0x63a402e2,0xf1bc012c,0xfaa80214}},	//   ksuk, _jmin, hrál_, وهاي_, 
   {{0x63a55f78,0x3e500bc9,0xaef801ab,0x6618020c}},	//   _mmin, _uņt_, _cnùu, jsuk, 
   {{0x66195f79,0xa964030d,0xf1bc00e4,0x80d4000d}},	//   dsuk, кича_, tuái_, _धराइ, 
   {{0x63a55f7a,0x6da15f7b,0xd7f80016,0xace400c7}},	//   _omin, _тира, _trăm_, _амра_, 
   {{0x63a40280,0x368805f5,0x7c3c03fa,0x3d080574}},	//   _nmin, дсон_, mtpr, िरके_, 
   {{0x6618417f,0xaef8026c,0xad980241,0xa61000c7}},	//   gsuk, _inùt, _iwúr, амыч, 
   {{0x63a55f7c,0x69c15f7d,0x5574721f,0x7c3c017a}},	//   _amin, cone, угот, otpr, 
   {{0x7c3cca9a,0x63a405b1,0xf8b403e5,0x66195f7e}},	//   ntpr, _bmin, _अखिय, asuk, 
   {{0xc5ec15fa,0x6618020c,0x7e640857,0xf624005b}},	//   _کړي_, bsuk, _orkp, _аддо, 
   {{0x2bb00cb4,0xa34401c0,0x661801d3,0x7c3c0254}},	//   ंचता, шээл, csuk, htpr, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x25a820ef,0x7e64127b,0xdb0006af,0x14e000cc}},	//   ècle_, _arkp, _emmé, _খ্ৰী_, 
   {{0x63a55f7f,0x69c15f80,0x7e64020c,0x7c3c005c}},	//   _gmin, zone, _brkp, dtpr, 
   {{0x69c15f81,0xdef80046,0x7c3c01f5,0x00000000}},	// [23ed0] yone, тыс_, etpr, --, 
   {{0x69c15f82,0x63a55f83,0xad980241,0x7c3c143a}},	//   xone, _zmin, _awúr, ftpr, 
   {{0x69c15f84,0x7c3c00b5,0x3cdc17e6,0x63a49da5}},	//   vone, gtpr, केले_, _ymin, 
   {{0x69c15f85,0x66180548,0x1c14000d,0x9b680124}},	//   wone, ysuk, _ढबरल_, ҵшәа_, 
   {{0x69c15f86,0xf1bc0419,0x00000000,0x00000000}},	//   tone, hrám_, --, --, 
   {{0xad980ca8,0x69c0009f,0x3e4c0023,0x00000000}},	//   _ewúr, uone, _ምርኣይ, --, 
   {{0xc7a49fb6,0x7c3c0c8c,0xef1c03e0,0x07a55f87}},	//   ликк, ctpr, _flüt_, лакн, 
   {{0x66195f88,0x69c15f89,0xef1c0139,0x60c80037}},	//   tsuk, sone, _ilüs_, üdmi, 
   {{0x66183217,0x85e801c0,0xf1bc01d3,0x00000000}},	//   usuk, ндив_, trál_, --, 
   {{0xa8a4b392,0x66195f8a,0x69c00014,0x28a41945}},	//   _ирек, rsuk, qone, _ишег, 
   {{0x63a4037e,0xf1bc011f,0x490001e0,0xdcfc0327}},	//   _pmin, rrál_, _күҙг, _sorċ, 
   {{0x661826bb,0xdcfc031c,0x386800e5,0x00000000}},	//   psuk, _porċ, _ábra_, --, 
   {{0x6d455e63,0xbd98001f,0x02dc0034,0x7c3c0112}},	//   _obja, _ሁለቱም_, नेंभ, ztpr, 
   {{0xf6500375,0xd5b800fd,0xda1c01f9,0x00000000}},	//   _לצד_, _үсә_, _निघत_, --, 
   {{0x7c3c30c6,0x63a55f8b,0x04440395,0x00000000}},	//   xtpr, _tmin, _сейн, --, 
   {{0x6d455f8c,0x4f9495de,0x63a55f8d,0xdcfc025c}},	//   _abja, аруу, _umin, _torċ, 
   {{0x6ea400bc,0x00000000,0x00000000,0x00000000}},	// [23ee0] _घेदु, --, --, --, 
   {{0x7c3c1f53,0x8b6428c4,0x00000000,0x00000000}},	//   ttpr, یانم, --, --, 
   {{0x315404ac,0xef1c04cc,0x5dd40150,0xbca4009a}},	//   _גיין_, _clüs_, _ﯙﻩﻧﻴ, دماي, 
   {{0xeb955f8e,0x6d4401e4,0x93bc0311,0x7e640334}},	//   лих_, _ebja, luăr, _trkp, 
   {{0x8e755f8f,0xdcfc0f91,0x3a640022,0x00000000}},	//   _курч, _horč, ыҧаҿ_, --, 
   {{0x3f815f90,0x1db861b8,0x7c3d5f91,0xdcfd5f92}},	//   _hoku_, _आदित, ptpr, _korč, 
   {{0x3f815f93,0xef1c0139,0x00000000,0x00000000}},	//   _koku_, _glüs_, --, --, 
   {{0x3f800664,0xf0900375,0xdcfc02fb,0x00000000}},	//   _joku_, מנו_, _morč, --, 
   {{0x3f800c34,0xeb940184,0x35e40cb6,0x00000000}},	//   _moku_, _сит_, лцов, --, 
   {{0x3f815f94,0xaa900597,0xf1bc02f0,0xb3384890}},	//   _loku_, _الكث, trám_, miçi, 
   {{0x94d55f95,0x3f815f96,0xdcfc0219,0xb3382330}},	//   ронц, _ooku_, _norč, liçi, 
   {{0x3f815f97,0x395c665e,0xad9801e1,0x00000000}},	//   _noku_, _hats_, _ntún, --, 
   {{0xc7640075,0xb33800fd,0x395c0254,0x00000000}},	//   _خالى, niçi, _kats_, --, 
   {{0xad980241,0xdcfc1aff,0x395c014f,0x00000000}},	//   _atún, _borč, _jats_, --, 
   {{0x212c0332,0x602800d4,0x00000000,0x00000000}},	//   ódha_, літв_, --, --, 
   {{0x395d5f98,0xe1f0468e,0x9f340046,0xf1a45aba}},	//   _lats_, _کسي_, йесі, _әрин, 
   {{0xceb823c9,0x3f815f99,0x395c0f85,0x51d81fbe}},	// [23ef0] тән_, _doku_, _oats_, _имиџ_, 
   {{0x3f800086,0xef1c07de,0x93bc0356,0x395c045a}},	//   _eoku_, _plüs_, cuăr, _nats_, 
   {{0xdcfc1a48,0x3f80005a,0xab84782a,0xcb1404b4}},	//   _gorč, _foku_, лудк, афлы, 
   {{0xd7f80356,0xb338036e,0x00000000,0x00000000}},	//   _grăi_, fiçi, --, --, 
   {{0xee855f9a,0xef1c0166,0x93bc0356,0x6d400254}},	//   _сыно, _flür_, grăi, õnas, 
   {{0x6d440117,0x3f8001b3,0x395cdcfb,0x6d4000a3}},	//   _ubja, _zoku_, _cats_, ònad, 
   {{0x395d5f9b,0x3f815f9c,0x33f80de2,0x2fc801ef}},	//   _dats_, _yoku_, _nëx_, _kkcg_, 
   {{0x2d800cfc,0x6ab8005a,0x395cc38d,0x00000000}},	//   _hoje_, _txuf, _eats_, --, 
   {{0x2d801326,0x395c3af1,0x96040214,0x00000000}},	//   _koje_, _fats_, یبیم, --, 
   {{0x2b5c0218,0x395c4f1e,0x2d800006,0x68e401ed}},	//   _hauc_, _gats_, _joje_, _újdo, 
   {{0x04444963,0x00000000,0x00000000,0x00000000}},	//   шенн, --, --, --, 
   {{0x2d81193a,0xf1bc0cde,0x2b5c0171,0x00000000}},	//   _loje_, brák_, _jauc_, --, 
   {{0x3f80489c,0xdcfc0010,0x42d4cea4,0x2b5c00ef}},	//   _roku_, _sorč, ріну, _mauc_, 
   {{0xdcfc01fa,0x395c00db,0x2d815f9d,0x84e400db}},	//   _porč, _xats_, _noje_, _колж, 
   {{0xc0e55f9e,0x4e90001f,0x3f815f9f,0x26cc036e}},	//   ровк, _የመረጃ_, _poku_, _hygo_, 
   {{0x2b5c0ba1,0x25a401a6,0xdcfc0064,0x00000000}},	//   _nauc_, _hmnl_, _vorč, --, 
   {{0x2d8004b9,0xf1bc0998,0xef1c07c5,0x25a401a6}},	// [23f00] _boje_, tuát_, _plür_, _kmnl_, 
   {{0x23600399,0x27ec61c5,0x3f815fa0,0xb3395fa1}},	//   _haij_, _lign_, _woku_, viçi, 
   {{0x3f815fa2,0x26cc010a,0xd7f80311,0x2d800023}},	//   _toku_, _lygo_, _trăi_, _doje_, 
   {{0xbb44656c,0x27ec07de,0x98fc01e4,0x2d8c0036}},	//   редк, _nign_, _maĉe, ëger_, 
   {{0x395d5fa3,0x2d8000c8,0x23614043,0xd94800ee}},	//   _pats_, _foje_, _maij_, лҗак_, 
   {{0x236001d4,0x2d815fa4,0xb3395fa5,0xf8480212}},	//   _laij_, _goje_, riçi, вчий_, 
   {{0x27ec030a,0x395d5fa6,0xec7401a9,0xef1c0205}},	//   _bign_, _vats_, _кпр_, _klüp_, 
   {{0xf1bc56b1,0x23600218,0x395d01d3,0xddc4033f}},	//   nuár_, _naij_, _wats_, ywiś, 
   {{0x27ed5fa7,0x395c0793,0xb33803e3,0x00000000}},	//   _dign_, _tats_, qiçi, --, 
   {{0xf1bc28be,0x35695fa8,0x27ec01a8,0x28a447b8}},	//   rrák_, трин_, _eign_, _केवि, 
   {{0x23600007,0x27ec0109,0xf1bc01ed,0xc4440214}},	//   _baij_, _fign_, lság_, میون_, 
   {{0x23600190,0x48700150,0xf1bc0162,0x27ec00ef}},	//   _caij_, _رگىس, juár_, _gign_, 
   {{0x48fc038e,0xf1bc01ed,0x00000000,0x00000000}},	//   रुको_, nság_, --, --, 
   {{0xf65005d9,0x33f80de2,0xc1a402dd,0xe9fc0208}},	//   _هئڻ_, _tëx_, бысқ, nhạc_, 
   {{0x2d815fa9,0x27ec002e,0x2f7400c7,0x6ad15faa}},	//   _roje_, _yign_, аҩны_, _तर्र, 
   {{0x23600097,0xf1bc01ed,0x5f94acf9,0x95680023}},	//   _gaij_, kság_, оист, _ጸበባን_, 
   {{0x2b5c04cc,0x2d800219,0xf1bc011f,0xd7f80356}},	// [23f10] _rauc_, _poje_, yráh_, _luă_, 
   {{0xd7f80311,0x2b5c005f,0xf1bc01ed,0xace95fab}},	//   _ouă_, _sauc_, dság_, نرال_, 
   {{0x2b5d5fac,0x2d8001e4,0x00000000,0x00000000}},	//   _pauc_, _voje_, --, --, 
   {{0x236001d4,0xad9801e1,0x2d800100,0xdcfc02f0}},	//   _xaij_, _itúm, _woje_, _forď, 
   {{0x2d815fad,0xf1bca5ae,0x7f7402e4,0xca4815eb}},	//   _toje_, gság_, _הערב_, الته_, 
   {{0x27ec025f,0xe94401c6,0x00000000,0x00000000}},	//   _sign_, рхдо, --, --, 
   {{0x0ce43fae,0x27ec0c86,0xf1bd5fae,0x5c040395}},	//   _প্ৰত, _pign_, rráh_, _мята, 
   {{0x5ba55faf,0xfe6c0014,0x00000000,0x00000000}},	//   _друз, _تگہ_, --, --, 
   {{0x23600649,0x27ec1570,0xdcfc00b8,0x28a40d2e}},	//   _raij_, _vign_, _horā, _केरि, 
   {{0xda700050,0xf1bc00e4,0x9f40002e,0xdcfc0171}},	//   _کُے_, brái_, rmié_, _korā, 
   {{0x74c821b8,0x27ed5fb0,0x9f5800ae,0x00000000}},	//   _सुदृ, _tign_, rprú_, --, 
   {{0x236001d4,0xad98008c,0x7c382c95,0xdcfc005f}},	//   _qaij_, _stúl, _åtre, _morā, 
   {{0xad980cad,0x23600007,0xf1bc06ea,0x6ea40037}},	//   _atúm, _vaij_, vuár_, _घेलु, 
   {{0x23600086,0x784803e3,0x00000000,0x00000000}},	//   _waij_, _həva, --, --, 
   {{0xdcfc0029,0x43680364,0x236001d4,0xf1bc01d3}},	//   _norā, _байн_, _taij_, zság_, 
   {{0x2d855fb1,0x2d8c045f,0xbea4022e,0x00000000}},	//   önen_, êgen_, бабк, --, 
   {{0x784803e3,0xfd480798,0x00000000,0x00000000}},	// [23f20] _məva, лзак_, --, --, 
   {{0x6e285f48,0x0d0800d1,0xddd400d0,0x784803e3}},	//   ágba, идуқ_, ťažk, _ləva, 
   {{0xdcfc00b8,0x769c0248,0x28a4b1e3,0xfc280108}},	//   _corā, _kàyé, _केलि, ужек_, 
   {{0xeb312374,0xed540220,0xf1bc01d3,0x784803e3}},	//   كىمد, _қос_, tság_, _nəva, 
   {{0x8b6406b3,0x6d400e89,0x7af40153,0x93bc0356}},	//   تالم, ònac, žyto, prăv, 
   {{0xeb940184,0x7d9400c6,0xf1bc01d3,0x3da800f3}},	//   _һис_, _السؤ, rság_, _скго_, 
   {{0xf1bc00dd,0xe8100073,0x7d1d5fb2,0x18b4035b}},	//   sság_, णीला_, maps, цәар, 
   {{0x3f915fb3,0xba18489b,0xf1bc6293,0x784803e3}},	//   nkyu_, _ميرا_, pság_, _cəva, 
   {{0xf668034c,0xd6d00597,0x5edc009e,0xd7f8054e}},	//   احبه_, بقة_, _ভলডে, _arăt_, 
   {{0x8afc012c,0x7d1d5fb4,0xb408009d,0xded40092}},	//   _vaře, naps, лэмж_, ራልና_, 
   {{0x769c01e1,0x5fc86b9b,0x3f90037e,0xb3380166}},	//   _bàyé, लवाल, kkyu_, kiçt, 
   {{0x7d1d5fb5,0x487004fb,0x00000000,0x00000000}},	//   haps, _آگوس, --, --, 
   {{0x7d1c78d0,0xf6d4021a,0xb3840023,0x00000000}},	//   kaps, _ازاد, _ዝከውን_, --, 
   {{0xf204013e,0x93bc0356,0x784806be,0x00000000}},	//   ияҳо, erăt, _zəva, --, 
   {{0x25180a1e,0x25d4011a,0xed8801a9,0x00000000}},	//   _גווא, _הוגן_, қсак_, --, 
   {{0xd5b8005f,0x7fb80107,0x93bc0356,0x784803b9}},	//   lnā_, авсӣ_, trău, _xəva, 
   {{0x9f040633,0xa3b8103f,0x00000000,0x00000000}},	// [23f30] سولو, _داور_, --, --, 
   {{0xf4242b88,0xd5b80a54,0x776001ab,0xb3380240}},	//   _རྗོད_, nnā_, _laox, riçu, 
   {{0x82c46d7e,0x8af812c1,0xec68dfe6,0x00000000}},	//   _གཙོའ, анес_, ырак_, --, 
   {{0x93bc084c,0x00000000,0x00000000,0x00000000}},	//   crăt, --, --, --, 
   {{0x7f3804ac,0x784800ac,0x6f1ce942,0x8afc013a}},	//   _דערו, _rəva, maqc, _pařb, 
   {{0x7d1c5f00,0x784806be,0x6f1c06be,0x00000000}},	//   caps, _səva, laqc, --, 
   {{0xdd740014,0x77600208,0x6d540946,0xc7a40395}},	//   _ژھۅک, _baox, mexa, жийк, 
   {{0x7760020c,0xc6045ac1,0x91f806ab,0xd5b8005f}},	//   _caox, озий, ंदाज_, enā_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d555fb6,0x05a81301,0x6f1c0113,0x74c800dc}},	//   nexa, рвой_, haqc, _सुहृ, 
   {{0x6f1c0309,0x784803e3,0x00000000,0x00000000}},	//   kaqc, _təva, --, --, 
   {{0x6d5401d9,0x42e95fb7,0x77600327,0xd5b802b5}},	//   hexa, имно_, _gaox, anā_, 
   {{0x7d1c01b9,0xd7c8004b,0x6f1c0477,0xddc400a2}},	//   yaps, _اونه_, daqc, btiň, 
   {{0x98fc01e4,0x6d5401f5,0x6738b1ec,0x00000000}},	//   _kaĉa, jexa, lguj, --, 
   {{0x434400a7,0x54e400cf,0x00000000,0x00000000}},	//   _дейв, _ىسىق, --, --, 
   {{0x65615fb8,0x6440c6a3,0x98fc0115,0x3f90037e}},	//   _hanh, _iqni, _maĉa, ukyu_, 
   {{0x7d1d5fb9,0x65615fba,0x3f90020b,0x98fc01e4}},	// [23f40] taps, _kanh, rkyu_, _laĉa, 
   {{0x656002a8,0x6d540548,0x7f54014f,0xbbd000cd}},	//   _janh, gexa, seyq, तत्क, 
   {{0x7d1d5fbb,0x6560adfe,0x6f1c0213,0x93900023}},	//   raps, _manh, baqc, _ዝከኣሎ_, 
   {{0x65615fbc,0x7d1d5fbd,0x7f540113,0x3f68014b}},	//   _lanh, saps, qeyq, _тимо_, 
   {{0x65600a85,0x7d1c0093,0xdcfc0356,0x79c402d5}},	//   _oanh, paps, _coră, ойдз, 
   {{0xf804049d,0x65615fbe,0x6440022e,0x8db40150}},	//   очин, _nanh, _oqni, _ессі, 
   {{0xe944006c,0xc0f801f3,0xb3380432,0x00000000}},	//   ترنی, _ፋክስ_, ançy, --, 
   {{0x6560225e,0xebe0005e,0x673804ba,0xc7b801d3}},	//   _aanh, _жосп, gguj, gnő_, 
   {{0x65615fbf,0x644002d1,0x3b080208,0x4a7401af}},	//   _banh, _aqni, _đbqh_, _ныфт, 
   {{0x65615fc0,0x67380194,0xdb0806ea,0x644c054e}},	//   _canh, aguj, álær, ăcin, 
   {{0x2cf8159d,0x65615fc1,0x93bc0311,0x799802d0}},	//   יליא, _danh, drăr, _iltw, 
   {{0xf1bc0316,0x6d54208d,0x00000000,0x00000000}},	//   hrát_, zexa, --, --, 
   {{0xf1bc031d,0x65600109,0x6d540472,0x3e4c00e2}},	//   krát_, _fanh, yexa, nētā_, 
   {{0x65615fc2,0xe6040014,0x93bc054e,0x6f1c02d1}},	//   _ganh, _بٲوو_, grăr, waqc, 
   {{0x5ea8009e,0x6d55153e,0x6f1c6b88,0xf8c8012d}},	//   _কুলে, vexa, taqc, िथिय, 
   {{0x6d54f0b2,0x65600810,0xc5ec004b,0x23280640}},	//   wexa, _zanh, _لړۍ_, _доћи_, 
   {{0x6d555fc3,0x65615fc4,0x93bc0311,0xf1a803e6}},	// [23f50] texa, _yanh, brăr, _ناده_, 
   {{0x93bc084c,0xf1bc011f,0x6f1c0309,0xad0801c6}},	//   crăr, grát_, saqc, рхаж_, 
   {{0x6d555fc5,0x6f1c03f0,0x2ca407de,0x6738012d}},	//   rexa, paqc, ànd_, yguj, 
   {{0x6d555fc6,0x79995fc7,0xae000131,0xcc100254}},	//   sexa, _altw, _يۈزى, डीगढ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x65615fc8,0xd1f00092,0x00000000,0x00000000}},	//   _ranh, _ሁከት_, --, --, 
   {{0x65615fc9,0xc72405f5,0x06855fca,0x752803ac}},	//   _sanh, чдий, згин, _adfz, 
   {{0x65615fcb,0x6b98c675,0x3e4c005f,0x67395fcc}},	//   _panh, _ilug, cētā_, rguj, 
   {{0x6560014f,0xc7b801d3,0xa994007b,0x8578014b}},	//   _qanh, snő_, _بشرت, ссит_, 
   {{0x65615fcd,0x8afc012c,0x6b980112,0x93bc0311}},	//   _vanh, _zařa, _klug, vrăr, 
   {{0x65615fce,0x6b98020c,0x8c48494d,0xad9801e7}},	//   _wanh, _jlug, maşı, _dtúi, 
   {{0x65600502,0x8c480ba5,0x93bc0311,0x00000000}},	//   _tanh, laşı, trăr, --, 
   {{0xf1bd5fcf,0xd1755fd0,0x6b980142,0x9f400306}},	//   drás_, мысы, _llug, rmií_, 
   {{0x6b995fd1,0x6608003e,0x8c48b8f1,0x3e4c00e2}},	//   _olug, _htgk, naşı, zētā_, 
   {{0x6b980083,0xf06048bd,0x4f641d93,0x63e40150}},	//   _nlug, эксп, واقف, _تيبە, 
   {{0xf1bd5fd2,0x82c40327,0x40b401d9,0xded40240}},	// [23f60] trát_, _གཙིའ, تھکھ_, ራፍን_, 
   {{0x6b995fd3,0x22b8063f,0x8c480205,0x00000000}},	//   _alug, ọks_, kaşı, --, 
   {{0x6b995fd4,0x3e4c00b0,0xbdf8211f,0xb3380200}},	//   _blug, wētā_, _گرجا_, shçe, 
   {{0x8c480ab7,0xf1bcd215,0x6b995fd5,0xb33806be}},	//   daşı, brás_, _clug, niçp, 
   {{0xaef8026c,0xbdf80832,0x6b98033f,0xf1bc0162}},	//   _maùl, _درجا_, _dlug, prát_, 
   {{0x6728037e,0x6b995fd6,0x3e4c00e2,0x8d54005b}},	//   _adgj, _elug, rētā_, _отсч, 
   {{0x6b995fd7,0xfce401c0,0x00000000,0x00000000}},	//   _flug, _хово, --, --, 
   {{0x6b98008c,0x9f5800eb,0x2ca401ee,0x644c0356}},	//   _glug, mpró_, _эксп_, ăcil, 
   {{0x20dc1aa1,0x442401f5,0xb9a400e5,0x00000000}},	//   _ḽi_, esl_, _ٹماٹ, --, 
   {{0x8c48719a,0x6a98011a,0x6b980064,0x00000000}},	//   başı, _השמנ, _zlug, --, 
   {{0xdcfc0034,0x386800d8,0x3a242694,0xa420104e}},	//   _gorą, _ébr_, lsop_, ньял, 
   {{0x98fc0115,0xb7e45378,0x3b040066,0xf744119e}},	//   _kaĉo, _эжек, ncoq_, _хедо, 
   {{0xe7341b74,0x27040016,0xad98035b,0xe704004b}},	//   _хеч_, _ống_, _itúv, _رسنی, 
   {{0xdb002242,0x59dc0a94,0xa1840184,0x98fc01e4}},	//   _ummæ, यतिर, нысл, _maĉo, 
   {{0x98fc01e4,0xd7b00073,0x842401d9,0x98ac03e0}},	//   _laĉo, _जगाच, _ہى۪ن, _kadı_, 
   {{0x20dc1aa1,0xf1bd5fd8,0x2cbc16a3,0x289808c3}},	//   _ḓi_, trás_, _ćud_, זילא, 
   {{0xddd0012c,0x9df800f5,0x59dc1408,0x8c480205}},	// [23f70] _řeši, знут_, यतार, zaşı, 
   {{0x6b995fd9,0xf1bd5fda,0xa2b8011a,0xe29c011a}},	//   _slug, rrás_, _מפחד_, _לשחר, 
   {{0x3a247ae3,0xf1a803e6,0xd7cc08a3,0xf1bc03b2}},	//   esop_, _ناگه_, ावाच, srás_, 
   {{0x8c48029f,0x6b98025c,0xdfe8010a,0xce955fdb}},	//   vaşı, _qlug, _ньял_, _жамъ, 
   {{0x6b985815,0x957c0006,0x5f9400a7,0x201c0174}},	//   _vlug, rmąj, _чият, _ævir_, 
   {{0x45080003,0x4424012c,0x00000000,0x00000000}},	//   _གཅེར_, ysl_, --, --, 
   {{0x9d195fdc,0x99d40214,0x6b980135,0xdc8800f3}},	//   _хост_, رتها, _tlug, _естл_, 
   {{0x6b9804c9,0x8c480bfc,0x98ac0790,0x00000000}},	//   _ulug, raşı, _cadı_, --, 
   {{0x98ac4dd9,0xda340153,0x00000000,0x00000000}},	//   _dadı_, _петы, --, --, 
   {{0x442401af,0x05555fdd,0xdb0001f4,0x00000000}},	//   tsl_, фтия, _emmä, --, 
   {{0x8c4803b9,0x00000000,0x00000000,0x00000000}},	//   qaşı, --, --, --, 
   {{0x44255fde,0x67281c42,0xddc40083,0x00000000}},	//   rsl_, _udgj, ttiŋ, --, 
   {{0x21e441ba,0x44255fdf,0x741000f1,0x96b8014b}},	//   höhe_, ssl_, _یووا, _нушу_, 
   {{0x44255fe0,0x29047edf,0xc8e0000d,0x98ac06be}},	//   psl_, ncna_, _फराट, _zadı_, 
   {{0xdb00049b,0x4384007b,0x00000000,0x00000000}},	//   _ymmä, _يلتق, --, --, 
   {{0xafe15fe1,0x200c005f,0x62240220,0x00000000}},	//   восл, īdi_, _كوبە, --, 
   {{0x9f40521d,0x200c2672,0x2bb000dc,0x23800240}},	// [23f80] rmià_, ūdi_, ूचना, _ንረዳእ_, 
   {{0xee3400d6,0xe2982bcb,0xf54c0051,0xa11400d1}},	//   ьну_, _мақ_, _lụng_, _سۈرت, 
   {{0xf1bc01e7,0x7178011a,0x00000000,0x00000000}},	//   osán_, _וניס, --, --, 
   {{0xf1bd5fe2,0xdb00007c,0xe9cc036b,0x00000000}},	//   nsán_, _ommå, یغو_, --, 
   {{0xf7840139,0x00000000,0x00000000,0x00000000}},	//   _äçit_, --, --, --, 
   {{0xad9803b2,0x3a240af9,0x957c0153,0x00000000}},	//   _stúv, rsop_, rmąk, --, 
   {{0x3a255fe3,0xf54c0016,0x00000000,0x00000000}},	//   ssop_, _bụng_, --, --, 
   {{0x3a2435b7,0xdb24f968,0xf54c0208,0x98ac03b9}},	//   psop_, _سوئی, _cụng_, _qadı_, 
   {{0xf54c01dc,0x39455fe4,0xa3c4024a,0x00000000}},	//   _dụng_, _онаг, ्वन_, --, 
   {{0xdcfc0114,0x00000000,0x00000000,0x00000000}},	//   _dorć, --, --, --, 
   {{0x6840fe8d,0xe9443faa,0x98ac05d1,0xf1bc148b}},	//   _анха, _ترقی, _tadı_, dráp_, 
   {{0x9f4c00f2,0x07e801d3,0x46800022,0x00000000}},	//   _èlèk_, _فرنٹ_, тқәа, --, 
   {{0xe2980953,0x25f40490,0xe9d40354,0x00000000}},	//   даў_, _उंची_, _акă_, --, 
   {{0xff1c037e,0xf1bc0332,0x00000000,0x00000000}},	//   _rayが, asán_, --, --, 
   {{0x6d982776,0xe53808c3,0x00000000,0x00000000}},	//   _bîan, _ותור, --, --, 
   {{0x9f4401e1,0x00000000,0x00000000,0x00000000}},	//   _òmì_, --, --, --, 
   {{0x93bc0311,0xdfd80395,0x00000000,0x00000000}},	// [23f90] nsăm, фър_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc0c02f89,0xe08801d9,0x00000000,0x00000000}},	//   _бәти, _ہَیو_, --, --, 
   {{0x2e400421,0x6f600220,0xfd640055,0xa3c404e4}},	//   tūfā_, _جۇرم, _masṛ, ्वय_, 
   {{0xf54c01fb,0xd3c40139,0x00000000,0x00000000}},	//   _rụng_, _ölеş, --, --, 
   {{0x6ce4005e,0xddc40356,0x05dc012d,0xf1bc00e5}},	//   _жібе, rviţ, _नींब, zsán_, 
   {{0xa3c400cd,0x39580037,0x00000000,0x00000000}},	//   ्वम_, õpsa_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb8d40574,0x98fc01e4,0xf54c01fb,0xf7d400d1}},	//   _चे_, _maĉj, _vụng_, _ﯞﻩﻗﻪ, 
   {{0xc4851e06,0x66e02bcb,0x00000000,0x00000000}},	//   елок, ноқа, --, --, 
   {{0xf54c01fb,0x28a400dc,0xe8240150,0x00000000}},	//   _tụng_, _केचि, _цфзо, --, 
   {{0xf1bc0077,0xdcfc012d,0x00000000,0x00000000}},	//   usán_, _dorę, --, --, 
   {{0xd7cc0490,0xbb38008f,0xd2f801c0,0x64cc0073}},	//   ावरच, הערי, дэрч_, _सुरळ, 
   {{0x6afc025c,0x74c800dc,0xddc40064,0xd6181063}},	//   _ཞུའོ_, _सुकृ, kviš, _آتنا_, 
   {{0xddc40552,0x50b5015b,0xe8100073,0xf1bc0118}},	//   jviš, всту, णीचा_, psán_, 
   {{0xc24402bf,0xc32800db,0x00000000,0x00000000}},	//   _зник, _ةكةن_, --, --, 
   {{0x9f440241,0x00000000,0x00000000,0x00000000}},	// [23fa0] _òmí_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6ce40372,0x00000000,0x00000000,0x00000000}},	//   ىزمە, --, --, --, 
   {{0x394c0204,0x9e900023,0xad980aab,0x0ba8007b}},	//   wffs_, _ቀጺልና_, _stút, وانى_, 
   {{0xfeb95fe5,0x7f4402d0,0x00000000,0x00000000}},	//   _راحت_, _ickq, --, --, 
   {{0x7db400c6,0x98fc010f,0xad980332,0xdd10013a}},	//   _أصحا, _taĉm, _dtús, _hýžd, 
   {{0xa3e016ae,0xf1bd5fe6,0x28f4005b,0x00000000}},	//   थता_, guáy_, нешь_, --, 
   {{0x7c3c006f,0x394c007c,0x96f80395,0x6b6c0055}},	//   mupr, sffs_, мейт_, _ṛgvi, 
   {{0xe60d2b47,0x7c3c03c6,0xe9d400fd,0xaa480220}},	//   یشی_, lupr, ькә_, _ىسكە_, 
   {{0xaa549528,0x9f4002f6,0xdcfc033f,0x888000e5}},	//   _سلما_, lmiä_, _porę, _چیون, 
   {{0x7c3d5fe7,0x7f4402d0,0xc4440214,0xe94400f1}},	//   nupr, _ockq, نیون_, _سرلی, 
   {{0xb6a40fbe,0xf364384f,0xded40023,0x142400cf}},	//   _пиел, хтон, ያልን_, ндүм, 
   {{0xddc40841,0x00000000,0x00000000,0x00000000}},	//   zviš, --, --, --, 
   {{0x7c3d5fe8,0x660c0030,0x9f40023a,0xc6b4010f}},	//   kupr, ícke, hmiä_, _בלױז_, 
   {{0x7c3c06ea,0x98fc00df,0xf1500133,0xb408009d}},	//   jupr, _paĉj, نێکد, _ээлж_, 
   {{0x200ca275,0x00000000,0x00000000,0x00000000}},	//   ídia_, --, --, --, 
   {{0xc0f80020,0x9e355fe9,0xde580212,0x00000000}},	// [23fb0] _ፋይል_, летч, наті_, --, 
   {{0xad980248,0x11d8007b,0xddc40153,0x9f400108}},	//   _atúr, _زوجة_, tviš, emiä_, 
   {{0x7c3d5fea,0xad98032e,0x00000000,0x00000000}},	//   gupr, _stús, --, --, 
   {{0xddc42625,0x00000000,0x00000000,0x00000000}},	//   rviš, --, --, --, 
   {{0xa3c412eb,0xdcf0008f,0xf1bc011f,0xceb400df}},	//   ्वत_, _ĉeĥi, ysál_, _ספֿק_, 
   {{0x7c3c01f0,0x00000000,0x00000000,0x00000000}},	//   bupr, --, --, --, 
   {{0xaca001f2,0x07a422d8,0x00000000,0x00000000}},	//   _kpọc, какн, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x76215feb,0x9694084c,0x6e3c014f,0x00000000}},	//   амыз, грэш, nuqb, --, 
   {{0xa8a40e92,0x481401c6,0x21e40254,0x00000000}},	//   _прек, _амжс, köha_, --, 
   {{0x03a55fec,0x6e3c014f,0x8afc01ef,0x00000000}},	//   вино, huqb, _nařk, --, 
   {{0x03948701,0x00000000,0x00000000,0x00000000}},	//   троя, --, --, --, 
   {{0x6d440175,0x7c3c002f,0x00000000,0x00000000}},	//   _ocja, zupr, --, --, 
   {{0x784803be,0x47240014,0xb3440139,0x6e3c014f}},	//   _səvi, _سرچٲ, _awçı, duqb, 
   {{0x9f40005b,0x43695fed,0x00000000,0x00000000}},	//   ymiä_, _жайн_, --, --, 
   {{0x6d446873,0x7dc40131,0x00000000,0x00000000}},	//   _acja, ھقان, --, --, 
   {{0x7dc41a02,0xfd1003cc,0xdc300118,0x00000000}},	// [23fc0] پقان, لجا_, _výče, --, 
   {{0x7c3d5fee,0x6d440327,0xad9806ea,0x00000000}},	//   tupr, _ccja, _stúr, --, 
   {{0xdd100038,0x313402e4,0x784803b9,0xc0e40137}},	//   _týžd, _בנים_, _həvv, _шоок, 
   {{0xeb303cd9,0x7c3d5fef,0xa3c400cd,0x00000000}},	//   لىمد, rupr, ्वि_, --, 
   {{0x7c3d5ff0,0x9f400108,0x00000000,0x00000000}},	//   supr, rmiä_, --, --, 
   {{0xaa90515c,0x2d8401d3,0x95800023,0xa96400f0}},	//   ришч, önet_, _ክፈትሕ_, виља_, 
   {{0xa3c41161,0xdb000fac,0xc5b8009e,0xcdc4681b}},	//   ्वा_, _ommø, ুতাপ, _сарқ, 
   {{0x98fc01e4,0xf0900375,0xf6080354,0x00000000}},	//   _maĉi, שנה_, мхой_, --, 
   {{0x76840228,0x56940220,0x98fc01e4,0x784806be}},	//   тыйж, уапт, _laĉi, _nəvv, 
   {{0x7bc001ab,0xc7e801d9,0xb8b4009b,0x00000000}},	//   lnou, وى۪ن_, _исећ, --, 
   {{0x7e9800b0,0x7bc15ff1,0x6d4008c2,0x6d3805d0}},	//   _hāpā, onou, ònai, ותינ, 
   {{0x7bc15ff2,0x040c0016,0x45400124,0x7e981619}},	//   nnou, _hưởn, аҕәа, _kāpā, 
   {{0x36980532,0x16355ff3,0x35a40124,0x7e9800e2}},	//   _تضاد_, _селя, _иадг, _jāpā, 
   {{0x7bc0012c,0x66e01d1c,0x6e3c014f,0x6590688a}},	//   hnou, _точа, vuqb, _вашу, 
   {{0x7bc15ff4,0x6e3c0477,0x7e9800ef,0x8f3400f3}},	//   knou, wuqb, _lāpā, левц, 
   {{0xe3b016cb,0xad980241,0xd90404d3,0x9f3402dd}},	//   _وري_, _atúp, _ژی_, иесі, 
   {{0x7c2ccf77,0x7bc0012c,0xc0c004a9,0x69b418cc}},	// [23fd0] _avbr, dnou, _ғәри, ्चमी, 
   {{0xd5b80093,0x91c003d4,0xc278011a,0x00000000}},	//   niā_, _শীৰ্, _נרתי, --, 
   {{0x93bc0311,0x78480213,0xe1f0009f,0x95340092}},	//   drăz, _zəvv, _بسي_, _በአንደ, 
   {{0x7bc15ff5,0x7c2cbd6e,0x957c012d,0xcb0801c8}},	//   gnou, _dvbr, bląg, ريتن_, 
   {{0x7e98002b,0x2d840112,0x6e3c01b9,0x5e8400f3}},	//   _cāpā, önes_, quqb, _курз, 
   {{0x7bc15ff6,0x00000000,0x00000000,0x00000000}},	//   anou, --, --, --, 
   {{0x7bc00ebb,0xa0680023,0x85b80014,0x00000000}},	//   bnou, _ጎደናታ, ہادس_, --, 
   {{0xb784008e,0x00000000,0x00000000,0x00000000}},	//   ләче_, --, --, --, 
   {{0xaab42052,0xa3c4a88c,0x99180055,0x00000000}},	//   _अधिक, ्वस_, _ũāũv, --, 
   {{0x4584470d,0x8afc013a,0x00000000,0x00000000}},	//   угов, _naři, --, --, 
   {{0x48147413,0xe8700133,0x74100753,0x00000000}},	//   _смес, _ڕۆژگ, یویا, --, 
   {{0x6d98025a,0xf1bc011f,0x69c00165,0x00000000}},	//   _bîak, lsáh_, lnne, --, 
   {{0x69c15ff7,0x7b0400bc,0x668003e6,0x8afc01ef}},	//   onne, _ústř, _ڕیکل, _baři, 
   {{0x957c006d,0x7bc15ff8,0x040c001e,0x200c0120}},	//   gląd, znou, _xưởn, ídio_, 
   {{0x69c03e80,0xd0955ff9,0x7bc15ffa,0xdcfc0115}},	//   inne, ашты, ynou, _borĝ, 
   {{0xad980030,0x7c3803cd,0x741000f1,0x69c0002f}},	//   _stúp, _åtri, _اويا, hnne, 
   {{0x63a432ff,0x8be82158,0x644c0276,0x69c00194}},	// [23fe0] _ilin, গদান_, ăciu, knne, 
   {{0x7bc15ffb,0x63a40232,0x7d240244,0x01640f06}},	//   wnou, _hlin, افان, _скоо, 
   {{0xec100137,0xa6cc04c5,0xdcfc010f,0x6f0ccba5}},	//   مولد, াইটট, _forĝ, _ffcc, 
   {{0x69c15ffc,0x20182b1d,0x7e989db5,0xdcfc010f}},	//   enne, mpri_, _pāpā, _gorĝ, 
   {{0x7bc15ffd,0x00000000,0x00000000,0x00000000}},	//   rnou, --, --, --, 
   {{0x63a55ffe,0x69c018d5,0x7bc15fff,0x1958010b}},	//   _llin, gnne, snou, такы_, 
   {{0x63a56000,0x201821a3,0x52e03806,0x7bc0012c}},	//   _olin, npri_, _नर्स, pnou, 
   {{0x96342082,0x69c16001,0x63a40354,0x7e991be1}},	//   аниц, anne, _nlin, _tāpā, 
   {{0x040c07ae,0x69c00165,0x8c6400db,0x8a4400db}},	//   _tưởn, bnne, _مەەل_, _نئلم, 
   {{0x63a56002,0x54550c72,0x00000000,0x00000000}},	//   _alin, авот, --, --, 
   {{0x63a441fb,0xd5b920cd,0xf1bc01d3,0x3744010a}},	//   _blin, riā_, ssák_, _йĕнт, 
   {{0x63a56003,0xd5b80421,0xe7800117,0x20180139}},	//   _clin, siā_, _гушо, dpri_, 
   {{0x63a56004,0x66f800b8,0x8afc013a,0x72f40022}},	//   _dlin, _cākī, _paři, ыҕит_, 
   {{0xc8300020,0x9f40007b,0x301800c6,0x957c0024}},	//   _አይሆን, cmiú_, فترة_, rmąs, 
   {{0xdb0001ed,0xf1bc0789,0x8afc00bc,0x63a56005}},	//   _elmé, nsái_, _vaři, _flin, 
   {{0x63a40491,0x00000000,0x00000000,0x00000000}},	//   _glin, --, --, --, 
   {{0xa3c4fec4,0x69c16006,0x7c740201,0xef9001b9}},	// [23ff0] ्वर_, ynne, _የሚለው_, لیگد, 
   {{0xdef80220,0x9180129d,0x63a417ee,0xdd9401ec}},	//   уыс_, _بۇسۇ, _zlin, бауы, 
   {{0x63a56007,0xded4001f,0x69c00051,0x00000000}},	//   _ylin, ያውኑ_, vnne, --, 
   {{0x16043eaf,0x63a56008,0x69c00072,0x00000000}},	//   रदार_, _xlin, wnne, --, 
   {{0x615c0092,0x00000000,0x00000000,0x00000000}},	//   _ህዝቦች, --, --, --, 
   {{0x69c00af5,0xdde40139,0xeac001ec,0xcb0800ec}},	//   unne, _ләхү, _құлп, ريڪن_, 
   {{0x69c09a36,0x66f802b1,0x9cc807d8,0x00000000}},	//   rnne, _mākū, _быта_, --, 
   {{0x69c04f3b,0x00e00131,0xcb681bf4,0x78bc0162}},	//   snne, _ﺋﯜﺳﺘ, _جمره_, úpva, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x63a56009,0x397800c8,0xe94400c7,0xa3c41b87}},	//   _plin, _שטענ, _ахҵо, ्वल_, 
   {{0x66f80069,0x63a40334,0x00000000,0x00000000}},	//   _pākī, _qlin, --, --, 
   {{0x63a5600a,0xbf640271,0x059402f2,0x00000000}},	//   _vlin, یدرو, _پاشگ, --, 
   {{0x63a4020c,0xc0a8fae3,0xa50400c0,0x00000000}},	//   _wlin, نازل_, _сядл, --, 
   {{0x63a5600b,0x20180100,0x00000000,0x00000000}},	//   _tlin, upri_, --, --, 
   {{0x63a47ab0,0x2019600c,0x66f800b0,0xade8012c}},	//   _ulin, rpri_, _tākī, _जीबन_, 
  
   {{0x2018d7f5,0xdcfc0139,0xdcf40e04,0x9f40017a}},	// [24000] spri_, _borğ, _čađa, llië_, 
   {{0xb3380274,0x98bc054e,0xbc1800d4,0x00000000}},	//   rkçe, ngvă_, віді_, --, 
   {{0x315404ac,0xf53400c8,0xac040022,0x3c64a5de}},	//   _דיין_, שטער_, анха_, ркег, 
   {{0x3d15600d,0x3ce4033d,0xf454008f,0xba280214}},	//   _प्रे_, _करीं_, ייער_, نستم_, 
   {{0x3f81600e,0xdb01600f,0x00000000,0x00000000}},	//   _inku_, _immü, --, --, 
   {{0xb338044e,0xb864004b,0xf3f8031c,0x6d4800e5}},	//   thçk, لابو, _དངཐད_, őgar, 
   {{0xb88400ee,0x95d80075,0xa8000166,0x00000000}},	//   рулй, һдит_, _şırp, --, 
   {{0xeb943c1a,0xdb100793,0x93bc0356,0x00000000}},	//   _кис_, öfäd, nsăt, --, 
   {{0x3ce401ad,0xd9102651,0xdcfc0213,0xd6d0007b}},	//   _करुं_, _فیش_, _yorğ, ثقة_, 
   {{0x7c3c003e,0xc0601954,0x00000000,0x00000000}},	//   orpr, _ስልጡን_, --, --, 
   {{0xa3c40a28,0x31600114,0x4d78010f,0x94d5376b}},	//   ्वं_, vejz_, אָרא, сонц, 
   {{0xe8d4011a,0xe7340cb6,0xb8640133,0x00000000}},	//   _דובר_, _вец_, _ماڵو, --, 
   {{0xb16c044e,0x66f802b5,0x7c3c0112,0xf2e401ee}},	//   _ብዝኾነ_, _pākū, hrpr, рюно, 
   {{0x3f816010,0x9f400ffb,0xddc4005f,0x3ce402a0}},	//   _anku_, lliè_, ltiņ, _करूं_, 
   {{0x81e4045e,0x9f400ffb,0x2bb4012c,0x5e580014}},	//   _বংশ_, oliè_, _आगला, یلِس_, 
   {{0xdcfc03be,0xa3c40882,0xddc4005f,0x7f540175}},	//   _sorğ, ्वः_, ntiņ, gfyq, 
   {{0x7c3d6011,0xa3b840ec,0xceb80131,0x00000000}},	// [24010] erpr, _خاور_, уән_, --, 
   {{0x3f800337,0xdcfc013d,0x00000000,0x00000000}},	//   _enku_, _qorğ, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc060206f,0xdb200248,0x00000000,0x00000000}},	//   _ስልጣን_, _àtìg, --, --, 
   {{0xaa656012,0xdcfc0598,0x7c3cee0a,0xee84010a}},	//   ртек, _torğ, arpr, _тыно, 
   {{0x6ab429da,0xddc40171,0x00000000,0x00000000}},	//   _अधीर, etiņ, --, --, 
   {{0x2d804cec,0x2b440166,0xab84013d,0x00000000}},	//   _inje_, _вэзг, _куак, --, 
   {{0x1bd400d6,0x9f4004cc,0xf1bc0548,0x660c00d0}},	//   _дося, gliè_, rráy_, ícko, 
   {{0xdb4c0133,0x00000000,0x00000000,0x00000000}},	//   _شێو_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa7845220,0x6ab40db3,0x00000000,0x00000000}},	//   _پشاو, _अधुर, --, --, 
   {{0xdb00642b,0xbaac0154,0x00000000,0x00000000}},	//   _immò, _ছুটছ, --, --, 
   {{0xcfcc015b,0x42d402dd,0x2d800248,0xd7f80818}},	//   লতান, сіну, _onje_, _туф_, 
   {{0x11396013,0x2d80009f,0x07a4030d,0x00000000}},	//   иясы_, _nnje_, _каçн, --, 
   {{0x3ce414cf,0xc0e4e55b,0x66196014,0xb0d801ad}},	//   _करें_, совк, lpuk, _मुदग, 
   {{0xa3ac37d0,0x6ab4033f,0x032403f6,0x00000000}},	//   _गति_, _अधूर, _удин, --, 
   {{0x82356015,0x93bc054e,0x2474004d,0x66181f94}},	// [24020] _اربا, rsăt, _hăm_, npuk, 
   {{0x6618166a,0x7c3d6016,0xaad800af,0x00000000}},	//   ipuk, trpr, _बड़क, --, 
   {{0x7c3c1a7c,0x7e74017a,0xed54e174,0xa3ac00cd}},	//   urpr, svyp, сох_, _गता_, 
   {{0x2d816017,0x66181c06,0x7f8400c6,0x3f800309}},	//   _enje_, kpuk, _الحن, _unku_, 
   {{0xdb00026c,0x19940801,0x2474004d,0xba5421f3}},	//   _ammò, жаля, _lăm_, стеъ, 
   {{0xa964006c,0x93bc054e,0x661801e4,0x24740208}},	//   йича_, nsăr, dpuk, _oăm_, 
   {{0x247401dc,0x27ec0ac5,0x499007d6,0x661801f7}},	//   _năm_, _bhgn_, بیلر, epuk, 
   {{0xf64416c3,0xe7800131,0xfb5400f1,0x48a80150}},	//   бхон, كلىپ, _دپرد, штім_, 
   {{0x6618d0c8,0xddc4005f,0x2d80000f,0x9f4004cc}},	//   gpuk, rtiņ, _ynje_, glié_, 
   {{0xddc400da,0x2474004d,0x35696018,0x8afc013a}},	//   stiņ, _băm_, урин_, _vařt, 
   {{0xddc4005f,0x247401fb,0x6eec0241,0xf4e400fe}},	//   ptiņ, _căm_, _kòbí, নশ্ব, 
   {{0x9f402047,0xd25000c6,0x24756019,0x00000000}},	//   blié_, ونج_, _dăm_, --, 
   {{0xaef9601a,0xe7047254,0xd40800ec,0x00000000}},	//   _ibùg, _اسمی, _ھڪدم_, --, 
   {{0x6114d718,0xaf34001f,0xb4b0008e,0xf1bc0142}},	//   здру, _እችላለ, _нилә, ysáu_, 
   {{0x24740208,0x00000000,0x00000000,0x00000000}},	//   _găm_, --, --, --, 
   {{0xdb01601b,0x1aa800cd,0xc4c406c2,0x00000000}},	//   _almí, कनाथ, _بتهو, --, 
   {{0x5f9400f7,0x349001f0,0x00000000,0x00000000}},	// [24030] читт, _фақр, --, --, 
   {{0xdcfc005f,0xdd940417,0x35780092,0xdcb400b8}},	//   _norē, пауы, _ጠበብት_, _śāṃb, 
   {{0x2474001e,0x30f401ed,0x00000000,0x00000000}},	//   _xăm_, _دودھ_, --, --, 
   {{0x661800c7,0xab2801b9,0x7e6c023a,0x6d4001a8}},	//   ypuk, اسال_, änpä, ónab, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9b180075,0xa2c00807,0x2d81601c,0xf1bc00e5}},	//   لتۇز_, _लेफ्, _unje_, csát_, 
   {{0xa2c07220,0x00000000,0x00000000,0x00000000}},	//   _लेन्, --, --, --, 
   {{0x66183421,0x2475601d,0x5ba40153,0x00000000}},	//   tpuk, _răm_, _еруз, --, 
   {{0x06e004c5,0x05a9601e,0xf1bd379b,0x2aa8009b}},	//   মেনি, ивий_, nsás_, _ство_, 
   {{0xaef80ca8,0x6619601f,0x00000000,0x00000000}},	//   _ibùd, rpuk, --, --, 
   {{0x66196020,0xd6a8036b,0x28a4004e,0x00000000}},	//   spuk, لدیم_, _ушаг, --, 
   {{0x661802f6,0x9f4006af,0x00000000,0x00000000}},	//   ppuk, plié_, --, --, 
   {{0xa28400f1,0x6ab401f9,0x00000000,0x00000000}},	//   سیدو, _अधोर, --, --, 
   {{0x00853acc,0x7ae408fb,0xc21c013f,0x247401fb}},	//   олго, _økte, nkɔɔ_, _tăm_, 
   {{0x660015fa,0x93bc0311,0x660802d2,0x00000000}},	//   _iink, rsăr, _hugk, --, 
   {{0x660013a1,0x67280098,0xc244e91f,0x00000000}},	//   _hink, _jegj, _дник, --, 
   {{0x67296021,0x66016022,0x21e404cc,0x00000000}},	// [24040] _megj, _kink, höhi_, --, 
   {{0x66016023,0x67296024,0x66080a2e,0xa3c4185b}},	//   _jink, _legj, _mugk, ्वक_, 
   {{0x66016025,0x66080af9,0xf1bc00e5,0x00000000}},	//   _mink, _lugk, rsát_, --, 
   {{0x66016026,0xab80524d,0x6728007f,0x327401d3}},	//   _link, душк, _negj, _امیج_, 
   {{0xade837f3,0x602001e1,0x66016027,0x6d40007b}},	//   _जीवन_, _fàmò, _oink, ónac, 
   {{0x66016028,0xfa580b82,0x00000000,0x00000000}},	//   _nink, _ሃይለማ, --, --, 
   {{0x6728193f,0x37a800e4,0x8c940220,0x66080171}},	//   _begj, итин_, _ерті, _augk, 
   {{0x66016029,0x6b61602a,0x569400fb,0x00000000}},	//   _aink, _окса, заит, --, 
   {{0x6728044e,0x5c3c02d3,0x67d00356,0x5edc0154}},	//   _degj, _ኣልጀር, dăjd, _মৃতে, 
   {{0x20bc146b,0x00000000,0x00000000,0x00000000}},	//   ोपाध, --, --, --, 
   {{0x6601602b,0x245c01f4,0x3958000d,0xa42012b9}},	//   _dink, _rämö_, õpsu_, мьял, 
   {{0x6601602c,0xfd4c0084,0xb4e876f8,0x00000000}},	//   _eink, _vhoṱ, _मरी_, --, 
   {{0x6601602d,0x2bd89f23,0xc76402dd,0x00000000}},	//   _fink, यकता, _ءامى, --, 
   {{0x6601602e,0xa1845067,0x672801f5,0x28dc0490}},	//   _gink, мысл, _zegj, _पुडि, 
   {{0x543801d9,0x9420013f,0x66080112,0x25180115}},	//   _آبس_, _ɔpɛe_, _zugk, _דווא, 
   {{0x6601602f,0xb4b001ee,0x00000000,0x00000000}},	//   _zink, _ниһә, --, --, 
   {{0x6600124c,0xb0d8a4ea,0x622400f7,0x63a02641}},	// [24050] _yink, _मुरग, _قىيل, ömne, 
   {{0xd9056030,0x660007a9,0x80d40456,0x905403f6}},	//   _لی_, _xink, _मुके, _евоц, 
   {{0xdb00004e,0x67d0054e,0xfe9c0241,0x00000000}},	//   _almà, lăje, _ọ̀nà_, --, 
   {{0x4a7429a3,0xdd3800b8,0x00000000,0x00000000}},	//   зыкт, _kāśm, --, --, 
   {{0x67296031,0x3eb0033f,0xb1600023,0xfcc800d1}},	//   _regj, czyt_, _ልምድታ, _ﯪﻟﻼﻫ, 
   {{0x672800fc,0x6608b312,0x06e002f5,0x00000000}},	//   _segj, _rugk, মেডি, --, 
   {{0x66016032,0x6608007c,0x67280200,0x00000000}},	//   _rink, _sugk, _pegj, --, 
   {{0xfe6c066d,0x3a7000fd,0xc7641411,0x00000000}},	//   _جگہ_, фләр, ساعى, --, 
   {{0x66016033,0x672802d3,0x31ac00e5,0x00000000}},	//   _pink, _vegj, _küzd_, --, 
   {{0x67280b4f,0x05a8022e,0x00000000,0x00000000}},	//   _wegj, свой_, --, --, 
   {{0xb0d80574,0x67280200,0x00000000,0x00000000}},	//   _मुलग, _tegj, --, --, 
   {{0x66008e0d,0xd7f81f71,0x66082819,0xd87536c6}},	//   _wink, _дуч_, _tugk, _زامب, 
   {{0x66016034,0x96b80075,0x28dc0cf1,0xdd380055}},	//   _tink, _мушу_, _पुति, _cāśm, 
   {{0xd24c03e6,0xa2c00073,0x6d183885,0x212c0332}},	//   گۆی_, _लेण्, _प्लग_, údh_, 
   {{0x2b5c0841,0x80d4085c,0x00000000,0x00000000}},	//   _obuc_, _मुखे, --, --, 
   {{0x3f856035,0x03256036,0xf4380302,0x94640014}},	//   ñou_, _эдин, _התקש, _کھیۆ, 
   {{0x244401f7,0x00000000,0x00000000,0x00000000}},	// [24060] _اجڙي_, --, --, --, 
   {{0xf27805e1,0xee356037,0xed54399f,0xb2b805d0}},	//   _פריש, яну_, зоф_, _למפר, 
   {{0xc0e56038,0x31980375,0x3ea400e2,0x3f6806ed}},	//   _хонк, _הבינ, šot_, _лино_, 
   {{0x9f400789,0xdb00bed3,0x00000000,0x00000000}},	//   rmió_, _almá, --, --, 
   {{0x2a7d6039,0x93bc0276,0x6a10003b,0x00000000}},	//   _crub_, spăg, еміу, --, 
   {{0x9f41603a,0x00000000,0x00000000,0x00000000}},	//   mmiñ_, --, --, --, 
   {{0xb4e81dd1,0x9f400165,0x28dc2052,0xc7ec00b8}},	//   _मरे_, lmiñ_, _पुदि, _ṣaḍr, 
   {{0xdb0003b2,0xf6440818,0x00000000,0x00000000}},	//   _elmá, пхон, --, --, 
   {{0x2a7c1590,0x6b600724,0xaa402218,0x7bc1603b}},	//   _grub_, _якта, _петл, miou, 
   {{0x7bc1603c,0xb218008c,0x7589603d,0x31ac372c}},	//   liou, lvæg, ссив_, _küze_, 
   {{0x92e803f4,0xb0d83d4d,0xd91005d9,0xe8f400d8}},	//   _বলে_, _मुंग, _ٻڌڻ_, _елф_, 
   {{0x7998201e,0x7bc1603e,0xa3ac00dc,0xb21800b5}},	//   _hotw, niou, _गतः_, nvæg, 
   {{0x7999603f,0x2cb00354,0xf124d3a6,0xa3c40456}},	//   _kotw, zzxd_, зьбо, ्वज_, 
   {{0x79980455,0x7bc0007f,0x67d00356,0x00000000}},	//   _jotw, hiou, răje, --, 
   {{0x7998013f,0xd3b80014,0x7bc16040,0x00000000}},	//   _motw, _وُتش_, kiou, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7999151f,0xad2402e9,0xdcfc0024,0x59dc1d03}},	// [24070] _ootw, كراو, _korė, मकार, 
   {{0x2d840724,0x799802c2,0x22440419,0x00000000}},	//   ñne_, _notw, ámke_, --, 
   {{0xa3c40490,0x200c0118,0x2a7c0118,0x2d840e2d}},	//   ्वच_, ídit_, _srub_, ıne_, 
   {{0x2d84002d,0xb21801bf,0x31ac2093,0xc0d40023}},	//   űne_, gvæg, _düze_, ሪኾም_, 
   {{0x79996041,0xd838033b,0xf8ad6042,0x4af802f2}},	//   _botw, _avč_, یکم_, زکرد_, 
   {{0xdcfc02d5,0x79980042,0x2a7c02f0,0x31ac0790}},	//   _norė, _cotw, _vrub_, _füze_, 
   {{0x7bc0232c,0x22c002b5,0x92e80154,0xd8380419}},	//   biou, mākū_, _বলো_, _cvč_, 
   {{0xbc540122,0x92e80183,0x9b580262,0x2a7c01ef}},	//   žšíc, _বলৈ_, _нист_, _trub_, 
   {{0x6b9801ab,0x7998015d,0xdb006a39,0x2a7c022e}},	//   _ioug, _fotw, _almæ, _urub_, 
   {{0x6b996043,0x79996044,0x85b80050,0x31ac2ba3}},	//   _houg, _gotw, تابس_, _yüze_, 
   {{0x69c16045,0x6b9804ce,0xd7c80753,0xddc4025c}},	//   mine, _koug, _کونه_, vviż, 
   {{0x21e403fa,0x7998014b,0x6b981368,0x03a56046}},	//   höht_, _zotw, _joug, фимо, 
   {{0x69c0c699,0x6b996047,0x85b800c6,0x7998014f}},	//   oine, _moug, _واتس_, _yotw, 
   {{0x6b9841f2,0x850447b3,0x7bc16048,0x00000000}},	//   _loug, _قوشن, ziou, --, 
   {{0xbf980114,0xdb0002d2,0xddc40135,0x95d00354}},	//   ођач_, _ummö, rviż, _сăра_, 
   {{0x6d4000bd,0x23600e3c,0x7bc16049,0x883c0240}},	//   ónan, _ubij_, xiou, _ከይተደ, 
   {{0x7bc1604a,0xb21801bf,0x31ac008e,0x4175604b}},	// [24080] viou, gvæd, _süze_, _قادس, 
   {{0x69c1604c,0xfbd000dd,0x9f400156,0x0ba800d1}},	//   jine, ھتا_, rmiñ_, ۋانى_, 
   {{0xbc69604d,0xfbd01e0e,0x6b99604e,0x69c00d63}},	//   تمان_, پتا_, _boug, dine, 
   {{0x6b99604f,0x69c16050,0x79980332,0x200c010f}},	//   _coug, eine, _sotw, ŭdis_, 
   {{0x6b996051,0x7bc16052,0x7998068f,0xb218037e}},	//   _doug, riou, _potw, rvæg, 
   {{0x7bc16053,0x69c16054,0x6b980295,0x9f404f1b}},	//   siou, gine, _eoug, llià_, 
   {{0x7bc0232c,0xa96414b7,0x6b9875c6,0xa2c02356}},	//   piou, фија_, _foug, _लेस्, 
   {{0x69c069f7,0x7998016b,0x2ca4005c,0x00000000}},	//   aine, _wotw, ønde_, --, 
   {{0x79980083,0xdcfc0064,0xa770008e,0x2bd808a3}},	//   _totw, _porė, тлыч, यकरा, 
   {{0x6b98a59c,0x9f4007c5,0x79983012,0xc76400db}},	//   _zoug, hlià_, _uotw, _ۋانى, 
   {{0x6b996055,0x9f40148b,0x00000000,0x00000000}},	//   _youg, ymið_, --, --, 
   {{0xe7147153,0x6b9801a9,0x00000000,0x00000000}},	//   _قيمت_, _xoug, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb0001f4,0xfa3c0023,0x28c0166d,0x94d404c2}},	//   _ilmä, _ኣይሰማ, _वेडि, _полц, 
   {{0xb4b0008e,0xfe9c01e1,0x00000000,0x00000000}},	//   _шикә, _ọ̀jà_, --, --, 
   {{0x9f40db60,0x200c026c,0xb4c801ad,0xa2c001f9}},	//   glià_, ìdia_, लपी_, _लेव्, 
   {{0x69c16056,0xf484021a,0x7760009a,0x6b995100}},	// [24090] yine, _راډی, _mbox, _roug, 
   {{0x69c16057,0xce94016c,0x601800b4,0x6b98e4f5}},	//   xine, _ҷамъ, ụmat, _soug, 
   {{0x6b9801a6,0xb21801bf,0x00000000,0x00000000}},	//   _poug, svæd, --, --, 
   {{0x69c16058,0xce940801,0xddc40784,0x00000000}},	//   wine, _замъ, rwiš, --, 
   {{0x6b98030a,0x5f944f33,0x6cd00137,0x00000000}},	//   _voug, _рият, رقچا, --, 
   {{0x69c020ac,0x6b996059,0xc0d40023,0x00000000}},	//   uine, _woug, ሪጾም_, --, 
   {{0x3d182413,0x69c00d90,0xdb00010e,0x6b99605a}},	//   मुळे_, rine, _almä, _toug, 
   {{0x69c1605b,0x273c001f,0x997c0055,0x00000000}},	//   sine, _ተቀምጠ, _kāśi_, --, 
   {{0xb9043852,0xc60401c6,0x28dc0b98,0xdb340063}},	//   _यु_, нзий, _पुरि, _шетњ, 
   {{0x69c1605c,0x201c01ed,0x05543edd,0x6b700131}},	//   qine, _évig_, хтия, _ялғу, 
   {{0xdb01489e,0x28a807f7,0x26c00100,0xa9240064}},	//   _elmä, टैशि, ńjo_, rožė, 
   {{0xe3040489,0x9f400108,0x57a44eca,0x00000000}},	//   _ཚུདཔ_, lmiö_, _ишча, --, 
   {{0x3ce40490,0x00000000,0x00000000,0x00000000}},	//   _जुने_, --, --, --, 
   {{0x6d4136b6,0xb34403b9,0x00000000,0x00000000}},	//   ónal, _atçı, --, --, 
   {{0xf5744d49,0x00000000,0x00000000,0x00000000}},	//   _سميع_, --, --, --, 
   {{0xafe0ccfb,0xdb1001b8,0x383c0092,0xddc42791}},	//   госл, öfüd, _አይቀበ, ftiş, 
   {{0xbd840818,0x3d00098b,0x00000000,0x00000000}},	// [240a0] нгак, वेने_, --, --, 
   {{0x6285605d,0x00000000,0x00000000,0x00000000}},	//   _irio, --, --, --, 
   {{0x28dc534e,0x315404ac,0x7b6409a5,0x62840165}},	//   _पुलि, _איין_, етле, _hrio, 
   {{0x6285605e,0xf66806ea,0x00000000,0x00000000}},	//   _krio, nsæð_, --, --, 
   {{0xef80495c,0xe3900092,0x00000000,0x00000000}},	//   _сляп, _እየሰጠ_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe44401d9,0xf8040cff,0x28c00882,0x00000000}},	//   _حض_, нчин, _वेदि, --, 
   {{0x6285605f,0xdb000217,0xf0900375,0xdcfc00ef}},	//   _orio, _almå, רנה_, _lorī, 
   {{0x1dd400dc,0x7d0d549f,0x6aa401ec,0xba4400e5}},	//   _ददात, _kgbs, _كشكە, _سناٹ, 
   {{0xaa38011a,0xe60c027d,0xdcfc00de,0xb8b400f3}},	//   _מתמח, حشي_, _norī, _псећ, 
   {{0x62856060,0x684001c0,0x77903267,0x00000000}},	//   _ario, _бнха, _میثا, --, 
   {{0xd7c868ff,0x62856061,0xdb00005c,0xe86400cf}},	//   _کوچه_, _brio, _elmå, _سئمۋ, 
   {{0x62841554,0x35a40024,0xb33806be,0x00000000}},	//   _crio, _падг, nkçi, --, 
   {{0x22440232,0x628498a1,0x7c2c02d0,0xf07400d1}},	//   ámka_, _drio, _owbr, нигә_, 
   {{0x62856062,0x7b9c0150,0x52e0000d,0x00000000}},	//   _erio, _ﺃﺠﺎﺏ_, _गुरउ_, --, 
   {{0x62856063,0xddc43361,0x234800db,0xedb800cd}},	//   _frio, ttiş, _كلىپ_, ोच्छ, 
   {{0x62856064,0x8afc00bc,0xb284004e,0x64440327}},	// [240b0] _grio, _obřa, _чыйк, ġjie, 
   {{0x5d556065,0x98b0033f,0xddc403e0,0x00000000}},	//   лкут, जनाए, rtiş, --, 
   {{0xaef801e1,0x27440241,0x00000000,0x00000000}},	//   _gbùn, _jìnà_, --, --, 
   {{0x53e000a5,0x9f4000d8,0xddc40356,0x09a800cd}},	//   नविश, pliá_, ptiş, कस्य, 
   {{0xbf34025f,0x7c2c03ac,0x00000000,0x00000000}},	//   _בארץ_, _ewbr, --, --, 
   {{0x6e2c0472,0xfaa00be8,0x60d40432,0x6ce40153}},	//   _iwcb, рашо, _çemç, _зібе, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x67f400e4,0x00000000,0x00000000,0x00000000}},	//   kãje, --, --, --, 
   {{0x68480023,0x4974cd61,0x00000000,0x00000000}},	//   _ዘይምድ, _илас, --, --, 
   {{0x3ce4033f,0x00000000,0x00000000,0x00000000}},	//   _जुडे_, --, --, --, 
   {{0x986400ec,0x00000000,0x00000000,0x00000000}},	//   _مُله, --, --, --, 
   {{0x62856066,0x00000000,0x00000000,0x00000000}},	//   _prio, --, --, --, 
   {{0x27fd6067,0xbb38008d,0xf6680174,0x53800150}},	//   mmun_, וערי, rsæð_, сқыз, 
   {{0xd1747cbb,0x62856068,0x6f0c0077,0x27fd6069}},	//   лысы, _vrio, _agcc, lmun_, 
   {{0xca2c0075,0xc0e44d75,0x93bc0311,0xdbdc0241}},	//   ﯩﺪﺍ_, товк, mpăn, _làáy, 
   {{0x4425606a,0xf454011a,0xb60002d2,0x00000000}},	//   mpl_, _סיפר_, _íárs, --, 
   {{0x27fd606b,0x6f0c0129,0x6284e257,0x940001f9}},	// [240c0] imun_, _dgcc, _urio, ोदरच_, 
   {{0x31ac03b9,0x4175606c,0x00000000,0x00000000}},	//   _hüzn_, _شاخس, --, --, 
   {{0x27fc0a2e,0x4424007f,0xed55606d,0x8108004b}},	//   kmun_, npl_, тох_, _کرښې_, 
   {{0xe624004d,0x00000000,0x00000000,0x00000000}},	//   _phố_, --, --, --, 
   {{0x20000a55,0x00000000,0x00000000,0x00000000}},	//   mmii_, --, --, --, 
   {{0x4424f4b3,0xf3fc0589,0x58d401c0,0x2001606e}},	//   kpl_, zmã_, лолт, lmii_, 
   {{0x2000022f,0x2018353d,0xed54004e,0x00000000}},	//   omii_, nqri_, _шор_, --, 
   {{0xdbdc01e1,0x567802e8,0xe78000d1,0x00000000}},	//   _fàáy, ебия_, للىپ, --, 
   {{0xa3c82e04,0x39540798,0x00000000,0x00000000}},	//   ोचन_, _ањет, --, --, 
   {{0x213877a5,0x9f40023a,0x3a24b594,0x35680117}},	//   jarh_, lliä_, mpop_, фрин_, 
   {{0xaef801e1,0x3a240196,0x88800214,0x4425606f}},	//   _abùl, lpop_, _هیون, gpl_, 
   {{0xd5b00502,0xded40b82,0x00000000,0x00000000}},	//   _گفت_, ካልን_, --, --, 
   {{0xf3fc0589,0xdb0008ce,0x3a240f85,0xb3540133}},	//   rmã_, _almú, npop_, _ییدا_, 
   {{0x20000393,0x3a24017a,0xf3fc0798,0x2138045a}},	//   emii_, ipop_, smã_, garh_, 
   {{0xa1955ef4,0x64a01f5a,0xa0a401d5,0x00000000}},	//   шарч, _ваја, аштл, --, 
   {{0x7c38143a,0x5f24041b,0x53540120,0xdd9001d9}},	//   _åtry, ифуз, _свиѓ, ۪وٕ_, 
   {{0xdb0000dd,0x9f040a2c,0x9e1401ec,0xe7e001f9}},	// [240d0] _elmú, لوفو, идті, खवता_, 
   {{0x27fd6070,0x20000ba7,0x9f4001f4,0x30c40117}},	//   zmun_, amii_, eliä_, _аёмб, 
   {{0x80c805d7,0x27fd6071,0xb1600023,0x2000045a}},	//   _हेपे, ymun_, _ልምዓታ, bmii_, 
   {{0x200001ab,0x9f400166,0x00000000,0x00000000}},	//   cmii_, gliä_, --, --, 
   {{0x6e2c0472,0xdea44689,0x44240010,0x7d1403b2}},	//   _uwcb, _پیلی, zpl_, ígsú, 
   {{0x48793ad0,0x9878001f,0x00000000,0x00000000}},	//   есия_, _ኮሚሽኑ_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x86980cfc,0xe7900133,0x00000000,0x00000000}},	//   етот_, شابک, --, --, 
   {{0x06084963,0x27fd6072,0x28c0134e,0x69f001f0}},	//   нник_, rmun_, _वेरि, _кӯкт, 
   {{0xcb3c00b5,0x27fd6073,0x00000000,0x00000000}},	//   _km圏_, smun_, --, --, 
   {{0x58d56074,0x03a56075,0x00000000,0x00000000}},	//   _кофт, гино, --, --, 
   {{0x44256076,0x00000000,0x00000000,0x00000000}},	//   rpl_, --, --, --, 
   {{0xdcf40063,0x07a400c7,0x442400c0,0x00000000}},	//   _čača, _иаҧн, spl_, --, 
   {{0x64a00184,0x00000000,0x00000000,0x00000000}},	//   _ҡаҙа, --, --, --, 
   {{0x75d00979,0x94780032,0x9f40023a,0x2138054e}},	//   _ديوا, _асыу_, yliä_, rarh_, 
   {{0xaef801e1,0x00000000,0x00000000,0x00000000}},	//   _ibùj, --, --, --, 
   {{0x20016077,0xf2640220,0x3a240324,0x0f340276}},	// [240e0] rmii_, _биыл_, xpop_, рэся, 
   {{0xed540588,0xaf00084c,0x20016078,0x3a240455}},	//   лоу_, спул, smii_, vpop_, 
   {{0xf53400c8,0x28c002ab,0x3a2401f5,0xa3d8000d}},	//   רטער_, _वेलि, wpop_, _ादा_, 
   {{0xdb500133,0xf1bc00e4,0x00000000,0x00000000}},	//   تێر_, npán_, --, --, 
   {{0x19596079,0xdcfd607a,0x31480023,0x1aec00cc}},	//   валы_, _marĉ, _ንምብር, জেনে_, 
   {{0xfce4516a,0x42a00020,0xcaa400d1,0x6b500022}},	//   _бого, _ልዩነት_, شلىۋ, атәх, 
   {{0xcdc41b6d,0xb8640137,0x3a25607b,0xdb000c52}},	//   _тарқ, ااتو, spop_, _komë, 
   {{0x7c3d607c,0x68382e1f,0xee3c00e4,0x3a2462f1}},	//   mspr, _አይመስ, _yvý_, ppop_, 
   {{0x24840005,0xaba4086f,0xda700451,0xa8c000d1}},	//   _arnm_, _ёвуз_, _ڇڏڻ_, ийәд, 
   {{0x7c3c017a,0xab60012d,0x2db4010f,0xb21802d2}},	//   ospr, ążec, ָלטן_, fvæn, 
   {{0x81d80c58,0x6d4000c6,0x6ec800c5,0xc02c0051}},	//   ়তা_, ónai, _सेनु, điều_, 
   {{0x7c3c26cf,0xdb01607d,0x00000000,0x00000000}},	//   ispr, _nomë, --, --, 
   {{0x7c3c2ad7,0x2240cc1a,0x16340229,0x00000000}},	//   hspr, _cvik_, _теля, --, 
   {{0x7c3c0623,0x65904b00,0xdcfc0064,0x66e00114}},	//   kspr, _гашу, _norį, _уоча, 
   {{0x753805f5,0xdcfc0115,0x2518008d,0xdef80220}},	//   matz, _farĉ, _אווא, ғыт_, 
   {{0x75380323,0x79840605,0xa2c00f4a,0x00000000}},	//   latz, _ɔkwa, _लेक्, --, 
   {{0x7c3c0c8c,0xe8182017,0xdcfc00a2,0x3d000073}},	// [240f0] espr, _पूना_, _borį, वेसे_, 
   {{0x753805f5,0x7c3cb76c,0x60e000e5,0x00000000}},	//   natz, fspr, ézmé, --, 
   {{0x753801c6,0xdb002ffe,0xef1c0166,0x00000000}},	//   iatz, _homè, _tfü_, --, 
   {{0xd1d00020,0xdb01607e,0x7539607f,0x09dc3f55}},	//   _ጥበቃ_, _komè, hatz, यव्य, 
   {{0x75380323,0x7f38011a,0xda64007b,0x00000000}},	//   katz, _בערו, ماوي, --, 
   {{0x7c3c3586,0xdb0000f2,0x7538009d,0x80c801ad}},	//   bspr, _momè, jatz, _हेडे, 
   {{0x753805f5,0xd5b80882,0x42841b49,0x2b5404fb}},	//   datz, dhā_, ክርነት_, _میاد_, 
   {{0xc1d00d41,0x5efc012d,0x00000000,0x00000000}},	//   _सद्ग, लेक्_, --, --, 
   {{0xdb00642b,0x6a2001ed,0x9de80014,0x7538009d}},	//   _nomè, _اہتم, _شفہٕ_, fatz, 
   {{0x6d546ae5,0x273007ae,0x44641bf6,0x75384ecc}},	//   ngxa, ản_, авов, gatz, 
   {{0x6aa80368,0x22400413,0x7e74012d,0x00000000}},	//   lygf, _svik_, zwyp, --, 
   {{0xf8ac0da4,0xb218ab69,0x7af4033f,0x2da00150}},	//   _تکه_, rvæn, żyte, _ﺃﻀﻔﻰ_, 
   {{0xdb016080,0x753801c0,0xa2c00316,0xd5b80882}},	//   _comè, batz, _लेख्, bhā_, 
   {{0xdb005849,0x67380006,0x66180472,0x75380334}},	//   _domè, lauj, mquk, catz, 
   {{0x7c3c0d27,0x84e802ab,0xded4010c,0x661802d1}},	//   xspr, _ऑडिट_, ካውን_, lquk, 
   {{0x673802d5,0xfe44a283,0x7d1c009a,0x9f40007b}},	//   nauj, инбо, wcps, lliú_, 
   {{0xef14db18,0x22416081,0xdb00020c,0x7c3c0072}},	// [24100] рму_, _uvik_, _gomè, wspr, 
   {{0x63a418a6,0x7ae40174,0x9f400332,0x00000000}},	//   _hoin, _økti, nliú_, --, 
   {{0x63a56082,0x7c3c39ed,0x9f4000c6,0x673800c0}},	//   _koin, uspr, iliú_, kauj, 
   {{0x75380323,0x63a56083,0xdb002056,0xa3c80ce0}},	//   zatz, _join, _homé, ोचि_, 
   {{0x63a56084,0x7c3d6085,0xdb016086,0x67380006}},	//   _moin, sspr, _komé, dauj, 
   {{0x63a56087,0x7c3c1876,0x7538009d,0x83140327}},	//   _loin, pspr, xatz, _ཊུའུ_, 
   {{0x7b9410f5,0xdb016088,0xccfc013f,0xdcfc025c}},	//   _краї, _momé, yeɛɛ_, _marċ, 
   {{0x2ca56089,0xd5b80053,0x96354a2a,0x63a5608a}},	//   ände_, whā_, бниц, _noin, 
   {{0xd5b818e5,0x7539608b,0xe8f42de8,0x66180472}},	//   thā_, tatz, ллә_, gquk, 
   {{0xdb01608c,0x63a5608d,0x00000000,0x00000000}},	//   _nomé, _aoin, --, --, 
   {{0x63a5608e,0x7538152d,0xdb00033b,0x67380254}},	//   _boin, ratz, _somè, bauj, 
   {{0x63a5608f,0x75396090,0x4f980092,0x00000000}},	//   _coin, satz, _መሪዎቹ_, --, 
   {{0x753805f5,0xdcfc025c,0x63a56091,0x53340131}},	//   patz, _barċ, _doin, _һейт, 
   {{0xb9dc0201,0xdb016092,0x63a400ad,0xb4b01945}},	//   _እኛ_, _comé, _eoin, _милә, 
   {{0xdb016093,0x63a40597,0x3ce400e1,0xa18402d5}},	//   _domé, _foin, _जुले_, цыял, 
   {{0x63a40302,0x957c001f,0x00000000,0x00000000}},	//   _goin, ኔዎችን_, --, --, 
   {{0xad247ec6,0xdb000077,0x7c98001f,0x7c740092}},	// [24110] لراو, _fomé, _ለሚለው_, _ከሚለው_, 
   {{0x63a400e3,0x67381d55,0x00000000,0x00000000}},	//   _zoin, zauj, --, --, 
   {{0x2ca400a8,0x67380d04,0x63a56094,0x3d016095}},	//   ând_, yauj, _yoin, वेले_, 
   {{0x66180309,0x63a401a9,0x4094009f,0x00000000}},	//   yquk, _xoin, _الٽر, --, 
   {{0x673802d5,0xb2180008,0xa13402dd,0xf1b802c3}},	//   vauj, kvæm, _ارۋش, _उतान, 
   {{0x1a6804fb,0x9da800a7,0x6738009f,0xf8b401c6}},	//   شیمی_, _къса_, wauj, өөх_, 
   {{0x76401529,0x67396096,0x98ac0356,0xa86001e0}},	//   _avoy, tauj, _redă_, цейҙ, 
   {{0xb2180008,0x00000000,0x00000000,0x00000000}},	//   tvæl, --, --, --, 
   {{0x63a4387b,0x6738b700,0x9f404d76,0xaa8403e6}},	//   _roin, rauj, gliù_, _خۆشم_, 
   {{0x63a56097,0x764000d2,0xb2183774,0x661802d1}},	//   _soin, _dvoy, rvæl, rquk, 
   {{0x63a56098,0xb50805d7,0x95980032,0xdb0006af}},	//   _poin, _हृदय_, ртыу_, _romé, 
   {{0xdb016099,0x57a40022,0x9f4000ae,0xb63000e5}},	//   _somé, _ҳшәа, sliú_, _کٹوت, 
   {{0x6d440427,0x66194764,0x63a5609a,0xe8d001d9}},	//   _odja, qquk, _voin, _دۅژھ, 
   {{0x6d440198,0x00000000,0x00000000,0x00000000}},	//   _ndja, --, --, --, 
   {{0xb9dc693c,0x63a4049b,0x00000000,0x00000000}},	//   _እዛ_, _toin, --, --, 
   {{0x6d45609b,0x24402d1c,0x28dc0dba,0x4f9401c6}},	//   _adja, mım_, _पुछि, оруу, 
   {{0x24400d9c,0xef1c0205,0x76400139,0x00000000}},	// [24120] lım_, _anüs_, _xvoy, --, 
   {{0xfce438ac,0x00000000,0x00000000,0x00000000}},	//   бозо, --, --, --, 
   {{0x24400ba5,0xb538008f,0xc10400f1,0x00000000}},	//   nım_, רגעש, _دودي, --, 
   {{0x6d4400ad,0x20040ba1,0xb600031c,0x00000000}},	//   _edja, _òmi_, ġġil, --, 
   {{0x244006b9,0x67d00356,0xd91401c4,0x00000000}},	//   hım_, căji, одлы, --, 
   {{0x3f81609c,0x24400365,0x64403d5a,0x98ac0064}},	//   _haku_, kım_, _ovni, _ledą_, 
   {{0x3f81609d,0x3dc80526,0xa96400c6,0x2b7401d3}},	//   _kaku_, _imbw_, صميم_, _گینگ_, 
   {{0x244071e1,0x3f81609e,0xf0900302,0xdcfd609f}},	//   dım_, _jaku_, לנו_, _jarč, 
   {{0x3f8160a0,0xdcfcc72a,0x6440b89a,0x35e4005b}},	//   _maku_, _marč, _avni, йцов, 
   {{0xd910036b,0x24400790,0xa72001e1,0x00000000}},	//   _قیش_, fım_, _yọkú, --, 
   {{0x539800d6,0x395c6fa3,0x2440247e,0x45640014}},	//   авня_, _icts_, gım_, تھنہ, 
   {{0x3f8160a1,0x387d60a2,0x00000000,0x00000000}},	//   _naku_, _istr_, --, --, 
   {{0x64400579,0x00000000,0x00000000,0x00000000}},	//   _evni, --, --, --, 
   {{0x3f8160a3,0x94c800aa,0xb21800b5,0x244067ab}},	//   _aaku_, _پاتې_, lvæk, bım_, 
   {{0x244006b9,0xdc3c0006,0xdb140432,0x00000000}},	//   cım_, _išėj, _şaýl, --, 
   {{0x1fa41d83,0x3f80e20a,0xdb000356,0xb21801bf}},	//   пруг, _caku_, _romî, nvæk, 
   {{0x3f8160a4,0xdcfc01a2,0x395c0327,0xc0c80092}},	// [24130] _daku_, _darč, _octs_, _በውል_, 
   {{0xd13052c8,0x3f800086,0xb14401b9,0x387c0332}},	//   _تمد_, _eaku_, _دیسم_, _ostr_, 
   {{0x3f800421,0x9f40004e,0x4fc000d1,0x00000000}},	//   _faku_, boià_, _قەسە, --, 
   {{0x3f80676d,0x6d44020c,0x9f4000db,0x9be400d4}},	//   _gaku_, _wdja, coià_, пічк, 
   {{0x244160a5,0x387c030a,0x6d4160a6,0x76440153}},	//   zım_, _astr_, ónas, škyj, 
   {{0x2440494d,0x3f8023db,0xda0805e6,0xe0d001b9}},	//   yım_, _zaku_, مينه_, _آزی_, 
   {{0x3f8160a7,0x321002f0,0x31ac453a,0x87b800c7}},	//   _yaku_, _mixy_, _cüzi_, иуит_, 
   {{0x2d8142ab,0x3f8002b9,0x46485e5b,0xab60005e}},	//   _haje_, _xaku_, азин_, _ءۇشى, 
   {{0x2d8160a8,0x64400076,0x798c04e6,0xe5200139}},	//   _kaje_, _svni, äiwë, _söñğ, 
   {{0x244071e1,0x2d8007f5,0x64440427,0xc1e00150}},	//   tım_, _jaje_, šjim, _ﺍﻳﺮﺍ, 
   {{0x2d8160a9,0x16640014,0xdbcc01e1,0x04940006}},	//   _maje_, _ہاوَ, _róún, іроў, 
   {{0x24400d9c,0x2d8160aa,0x00000000,0x00000000}},	//   rım_, _laje_, --, --, 
   {{0x2440a493,0x885c0023,0x00000000,0x00000000}},	//   sım_, _ዉልቀሰ, --, --, 
   {{0x3f8160ab,0x2d8160ac,0x244005d1,0x64402681}},	//   _saku_, _naje_, pım_, _tvni, 
   {{0xdcfd60ad,0x03a463e8,0x2b5c004e,0x6440012c}},	//   _parč, _мико, _ocuc_, _uvni, 
   {{0x3f80011f,0xd24c0133,0x753406be,0x00000000}},	//   _qaku_, خۆی_, _ğazə, --, 
   {{0x2d8160ae,0x3f8160af,0x64a00fab,0xf77005e1}},	// [24140] _baje_, _vaku_, _фақа, וקן_, 
   {{0x25a40a73,0x2d8104ab,0x3f8160b0,0xc0c8001f}},	//   _jonl_, _caje_, _waku_, _በግል_, 
   {{0x3f6960b1,0x3f801f4c,0x2a7c00af,0xdcfc1fe6}},	//   _кино_, _taku_, _asub_, _tarč, 
   {{0x6fe849a6,0x2fc80048,0x2ca4049f,0x6d402833}},	//   _རྩྭའ, _gmcg_, ända_, ónar, 
   {{0x2d80e64a,0x387c0204,0x395c010a,0x19949c36}},	//   _faje_, _sstr_, _pcts_, заля, 
   {{0x2d8160b2,0x387c010a,0xbf6400e5,0x00000000}},	//   _gaje_, _pstr_, _ادھو, --, 
   {{0xdcfc0327,0x93bc054e,0xb21801bf,0x00000000}},	//   _forġ, spăi, tvæk, --, 
   {{0x2d80f734,0xdb001b08,0xf644220f,0x96343e4f}},	//   _zaje_, _homí, охон, пниц, 
   {{0x2d80015c,0xdb0160b3,0xb218005c,0xddc40003}},	//   _yaje_, _komí, rvæk, kwiż, 
   {{0x395c0109,0x744c001f,0xb21800b5,0x236000ef}},	//   _ucts_, _በተፈጠ, svæk, _acij_, 
   {{0x68240205,0x80c807af,0x00000000,0x00000000}},	//   _cıdd, _हेले, --, --, 
   {{0x28c02017,0xdef8010c,0x92240327,0x28100150}},	//   _वेटि, ላልን_, _འཕྱག_, _قولس, 
   {{0x569531ff,0x08081913,0x00000000,0x00000000}},	//   _халт, _ازلي_, --, --, 
   {{0xd838033b,0xddc40327,0x00000000,0x00000000}},	//   _kwč_, gwiż, --, --, 
   {{0x2d8160b4,0x290001d3,0x00000000,0x00000000}},	//   _raje_, _újat_, --, --, 
   {{0x2d8160b5,0xb4b400af,0xb4e401ad,0xddc4010e}},	//   _saje_, छनी_, पथी_, lsiň, 
   {{0x2d8160b6,0xb40001c0,0x68240205,0x00000000}},	// [24150] _paje_, _нүүд, _zıdd, --, 
   {{0xdb005b84,0xdcfc0327,0x2d80036e,0x00000000}},	//   _comí, _sorġ, _qaje_, --, 
   {{0xdb0160b7,0x2d80151c,0xd8380100,0x682405d1}},	//   _domí, _vaje_, _nwč_, _kıde, 
   {{0x2d8160b8,0x2fc801a4,0x00000000,0x00000000}},	//   _waje_, _umcg_, --, --, 
   {{0xbf9806a9,0x2d8160b9,0x28c001ad,0x7af4033f}},	//   _הירש, _taje_, _वेजि, żytn, 
   {{0xd83802e2,0x00000000,0x00000000,0x00000000}},	//   _bwč_, --, --, --, 
   {{0xcb340801,0x00000000,0x00000000,0x00000000}},	//   _невъ, --, --, --, 
   {{0x2a7c0218,0x00000000,0x00000000,0x00000000}},	//   _tsub_, --, --, --, 
   {{0xe8184103,0x25a40048,0xaef80248,0x2a7c00c5}},	//   _पूरा_, _ponl_, _ibùs, _usub_, 
   {{0xdcfc002b,0xe7740050,0x00000000,0x00000000}},	//   _harā, _ژلاں_, --, --, 
   {{0xe7841b74,0xdcfd60ba,0x2fd80051,0x00000000}},	//   _мудо, _karā, knqg_, --, 
   {{0x78f80375,0xd87400db,0xdcfc00dc,0xd66800f1}},	//   _הפעו, _تاكب, _jarā, _ژمنو_, 
   {{0xd7c803e6,0x53800220,0x6ec805d7,0xdcfc00b8}},	//   _بونه_, тқыз, _सेलु, _marā, 
   {{0x91b00208,0x67d00356,0x95c800f3,0x00000000}},	//   _đạt_, răju, _муја_, --, 
   {{0x69b001ad,0xf990008f,0x92a8033f,0x82341bf4}},	//   _अवनी, ערל_, _połó, _کربا, 
   {{0xdcfc0882,0xc244d6aa,0x682403e0,0x9f5803b9}},	//   _narā, _еник, _gıde, _özül_, 
   {{0xdb00013a,0xfd4800db,0x00000000,0x00000000}},	// [24160] _pomí, йзак_, --, --, 
   {{0x6d4160bb,0x224402fb,0xdcfc0327,0x92a80210}},	//   ónap, ámku_, _jorħ, _wołó, 
   {{0x711800c8,0x660c0030,0x224c033f,0x00000000}},	//   _לויפ, ícky, ądku_, --, 
   {{0xdb000262,0x0ba807a7,0xdcfc00cd,0x2c081208}},	//   _româ, يانى_, _carā, معنی_, 
   {{0xa068035b,0xdcfc00e2,0x93bc0356,0xdb00013a}},	//   _уаҟа_, _darā, mpăt, _tomí, 
   {{0x357c0023,0x00000000,0x00000000,0x00000000}},	//   እዮታት_, --, --, --, 
   {{0x3154010f,0x00000000,0x00000000,0x00000000}},	//   ליסן_, --, --, --, 
   {{0xaef808e7,0xdcfc005f,0x660002d0,0x3dbc0011}},	//   _ibùr, _garā, _ahnk, _আদিল, 
   {{0x9f4000dd,0xa3c03d1d,0xeb94010b,0xb21801bf}},	//   llió_, ंघन_, _эит_, lvæv, 
   {{0xe60c03e6,0xd9d00137,0xb9c412ea,0xdef80092}},	//   ێشی_, _جەتگ, _عقاي, ላልና_, 
   {{0x3dbc09bd,0xb4b40c2e,0xdb000109,0xddc40209}},	//   _আদাল, छने_, _homà, rsiň, 
   {{0xc7940139,0x289800df,0xb6a401af,0x00000000}},	//   _орчы, _ליבא, _ниел, --, 
   {{0xb1480023,0x682403e0,0x59b06c5a,0x00000000}},	//   _ንምውሳ, _vıde, _जकार, --, 
   {{0xe5a0225f,0x6b440092,0x00000000,0x00000000}},	//   _пичи, _የኮሚቴ, --, --, 
   {{0xdecc02d3,0xd108036b,0xd41c010a,0x00000000}},	//   _በይኑ_, زقره_, _тιеι, --, 
   {{0xa3e800dc,0x3264022e,0x32280139,0x3384011c}},	//   भवः_, _етов, _ƅuyı_, _хукв, 
   {{0xaef801e1,0x2d8400d8,0x200c0ba1,0x622400cf}},	// [24170] _abùr, ôneo_, ïdia_, _كىيل, 
   {{0xd904d87e,0x9f0560bc,0xdcfc00cd,0x2ca4007c}},	//   _می_, رولو, _sarā, ändo_, 
   {{0xdcfd60bd,0x98bc007f,0xd2f801d3,0xabb000c7}},	//   _parā, favč_, _دکھا_, нажә, 
   {{0x4a740372,0x8af806ed,0x00000000,0x00000000}},	//   дыкт, онес_, --, --, 
   {{0xd1d01b49,0xdb0000d8,0x10600023,0xdcfc00dc}},	//   _ኦሪት_, _romã, _ውልቀመ, _varā, 
   {{0x801800f1,0xabd80150,0xc8c801f7,0x5ba40166}},	//   _دریځ_, _ﺃﻓﻌﺎ, يوشن_, дрәз, 
   {{0xdcfc1d86,0xaef80248,0x07a560be,0xd9440a11}},	//   _tarā, _gbùr, дайн, رئوي, 
   {{0x3ce407c1,0x00000000,0x00000000,0x00000000}},	//   _जुटे_, --, --, --, 
   {{0x65bc017a,0x27b00139,0xd1600092,0xdecc1954}},	//   _lêhe, _җәйс, _ድምፁን_, _በይና_, 
   {{0x776000db,0x04485aa2,0x2bd00073,0x8cc00709}},	//   _ecox, опок_, _दगडा, लनपो, 
   {{0x79e801d9,0x74e405f5,0xdcfc0311,0xdb00007b}},	//   _بولہ_, ддэг_, _iară, _iomá, 
   {{0xd8740592,0x5804007b,0x98ac0118,0xdb0000e5}},	//   _سامب, _كولك, _ledě_, _homá, 
   {{0xdb0136d2,0x4128720b,0x00000000,0x00000000}},	//   _komá, жого_, --, --, 
   {{0xb344013d,0x2cb0004e,0x81b403d4,0x3e6400e4}},	//   _auçı, kyxd_, চোন_, vôt_, 
   {{0xdef81540,0xdb000077,0x43683edb,0x00000000}},	//   ላውን_, _momá, _дайн_, --, 
   {{0x3e640231,0xdb0000ae,0xf4380375,0xe7e001f9}},	//   tôt_, _lomá, _ותקש, खवटा_, 
   {{0x3f840030,0xbd8400fd,0xbef800cd,0x00000000}},	// [24180] ľou_, мгак, ्धेन_, --, 
   {{0xfd104111,0x628400b4,0xdb011bd9,0x9f4008e5}},	//   نجا_, _isio, _romà, gliò_, 
   {{0x93bc00a8,0xdb0000db,0xeb3005a9,0xbb480a11}},	//   mpăr, _somà, چىمد, قلان_, 
   {{0x3e6420ef,0x62841529,0xeb300447,0x00000000}},	//   pôt_, _ksio, نىمد, --, 
   {{0x8e740d6f,0x98bc02e2,0xb21801bf,0xe4ec0037}},	//   _пурч, ravč_, svæv, _घुसि_, 
   {{0xfce40372,0x628401c8,0x9f400407,0xdb0000ae}},	//   _жого, _msio, plió_, _comá, 
   {{0xdb000e96,0xf80560bf,0x9f400156,0xb21803b2}},	//   _domá, мчин, lliñ_, lvæt, 
   {{0xdb01033e,0x628560c0,0xa9200cef,0xdd0c0210}},	//   _tomà, _osio, ндәл, półm, 
   {{0xb4b4038e,0x7bc09d08,0x12d80154,0x00000000}},	//   छन्_, mhou, _সর্দ, --, 
   {{0x7bc160c1,0xb8b40640,0xabd802dd,0xe98400d1}},	//   lhou, _осећ, _ﺃﻓﻐﺎ, _يالۋ, 
   {{0x79982001,0x628560c2,0x69b007b6,0x00000000}},	//   _intw, _asio, _अवती, --, 
   {{0x7bc160c3,0xb21801a8,0x28d80303,0xdb0000e5}},	//   nhou, kvæt, यपरि, _zomá, 
   {{0xb3440139,0xf1240108,0x00000000,0x00000000}},	//   _ruçı, дьбо, --, --, 
   {{0x388c05c7,0xc1a402dd,0xf0740075,0x00000000}},	//   _kęr_, нысқ, мигә_, --, 
   {{0x7bc160c4,0xdb44168d,0x79984242,0x628560c5}},	//   khou, _پێ_, _mntw, _esio, 
   {{0xc5ec15fa,0x7bc00196,0xd5b8005f,0x98ac01ef}},	//   _نړۍ_, jhou, lkā_, _sedě_, 
   {{0x7998bbd7,0x7c2c00da,0x7bc04ebd,0x00000000}},	// [24190] _ontw, _atbr, dhou, --, 
   {{0x7bc034b6,0xd13160c6,0xdb0001bf,0xd5b800e2}},	//   ehou, _حمد_, _komæ, nkā_, 
   {{0x2d8401f1,0x798800a9,0x7bc029d0,0xdcfc0356}},	//   ľne_, ddfw, fhou, _rară, 
   {{0x2d8560c7,0x7bc149d9,0x9f4005c7,0x6284035a}},	//   žne_, ghou, bliñ_, _ysio, 
   {{0xdb0004bf,0x7c2c01c4,0xdef80220,0xb21801bf}},	//   _pomá, _etbr, _жыр_, mvæs, 
   {{0x9f402242,0xf1bd60c8,0x799802d0,0x8470001f}},	//   llið_, mpás_, _cntw, _እራሱን_, 
   {{0x799802d0,0xfd4401ed,0xabb000c7,0x6cf004af}},	//   _dntw, _سینٹ_, _ҧаҳә, _अडिग_, 
   {{0x799960c9,0x388c0a85,0x068560ca,0xdb584f41}},	//   _entw, _dęr_, егин, _оюу_, 
   {{0xdb011a6d,0x3f9c016b,0x81d402f5,0xe98001a9}},	//   _tomá, _ɑtu_, িকত_, _ақлн, 
   {{0x62840194,0x9f40032e,0x00000000,0x00000000}},	//   _rsio, hlið_, --, --, 
   {{0x69c160cb,0x388c030a,0x473400d3,0x9f400d12}},	//   mhne, _gęr_, _знес, klið_, 
   {{0x03a4506f,0xdb00037e,0x75280175,0x682405d1}},	//   химо, _domæ, _effz, _gıda, 
   {{0xe4ec00af,0x9f4003b2,0xdef80b82,0xd5b800ef}},	//   _घुरि_, dlið_, ላውና_, bkā_, 
   {{0x69c160cc,0x7bc0b1d6,0x1aec00bd,0x65600113}},	//   nhne, zhou, জেকে_, _ucnh, 
   {{0x7bc02238,0xb21803b2,0x95d00408,0x9f4008a5}},	//   yhou, fvæs, _тăра_, flið_, 
   {{0x628560cd,0x93bc0276,0x6b980083,0xb2180158}},	//   _tsio, spăr, _nnug, gvæs, 
   {{0x628560ce,0x98bc0421,0x3cfc0030,0x7c2c01ab}},	// [241a0] _usio, iavā_, _štv_, _stbr, 
   {{0x6b9960cf,0x69c009a8,0x9f400162,0x7af4012d}},	//   _anug, jhne, alið_, żytk, 
   {{0x7bc1185e,0x69c00192,0x7f44010b,0xf1bc5923}},	//   thou, dhne, _пенж, rpát_, 
   {{0xbea46afe,0xb21828b3,0x7bc0030a,0x6ec81b51}},	//   _замк, mvær, uhou, _सेकु, 
   {{0x7bc160d0,0xb218eda6,0xc14c0023,0xf4100a7c}},	//   rhou, lvær, _ንምዕቃ, אפא_, 
   {{0x69c160d1,0x7bc160d2,0x6b9960d3,0x58d4323d}},	//   ghne, shou, _enug, колт, 
   {{0x7bc160d4,0x7c2c77d4,0xa9641677,0xb2180627}},	//   phou, _utbr, хија_, nvær, 
   {{0x6b980267,0x68240139,0x69c00419,0xb21801bf}},	//   _gnug, _qıda, ahne, ivær, 
   {{0x69c0379c,0x388c045f,0xdbcc0241,0x76700116}},	//   bhne, _węr_, _fóòn, уңлу, 
   {{0x69c01c1b,0xac941973,0xe964084c,0xb218037e}},	//   chne, _تنہا_, _паул_, kvær, 
   {{0x61fc08a5,0xd5b8005f,0xf1bc01ed,0x533439b8}},	//   dlrl, rkā_, kpár_, кент, 
   {{0xd5b80029,0xb218318c,0xc81800db,0xe7801bc3}},	//   skā_, dvær, _قىلچ_, _бушо, 
   {{0x91c400d1,0x4ce000cc,0x00000000,0x00000000}},	//   вәнл, _ভৰাঁ, --, --, 
   {{0xda100d0d,0x2efc025c,0x00000000,0x00000000}},	//   ाषित_, _ġuf_, --, --, 
   {{0xb2183b9d,0x00000000,0x00000000,0x00000000}},	//   gvær, --, --, --, 
   {{0x9294035b,0x69c0fc2d,0x611401c6,0x00000000}},	//   _ааиц, zhne, удсу, --, 
   {{0x9f4005f7,0xb218332e,0x00000000,0x00000000}},	// [241b0] rlið_, rvæs, --, --, 
   {{0x6b98232c,0x9f400ad9,0x9ed800d1,0x9df80114}},	//   _snug, slið_, хмут_, енут_, 
   {{0xdb000793,0x3b2c01f2,0xb21801bf,0x9f400413}},	//   _lomä, _ịyị_, svæs, plið_, 
   {{0xd01000f2,0x7f1400db,0x00000000,0x00000000}},	//   _خلج_, ركەچ, --, --, 
   {{0x69c014d0,0xdb0001b8,0x98bc0421,0xef1c0166}},	//   thne, _nomä, vavā_, _igü_, 
   {{0x98ac03b9,0xdb0801e7,0x0e04014b,0x00000000}},	//   _acdı_, ílár, _рӯбо, --, 
   {{0x69c001fa,0xe7cc00dc,0xdb2002f0,0x00000000}},	//   rhne, तोऽप, štác, --, 
   {{0x69c160d5,0x6b980014,0x4b2000d1,0x4ab001e0}},	//   shne, _unug, _ئېشە, _ҡөҙр, 
   {{0x69c139bd,0x060863e6,0xef1c00cf,0x8cd40073}},	//   phne, мник_, _raül_, _येतो, 
   {{0xdb000624,0xef1d60d6,0xdb500050,0x68240006}},	//   _domä, _saül_, _پَے_, _зьдз, 
   {{0xf50000a7,0x58d4014b,0x00000000,0x00000000}},	//   изьо, _йофт, --, --, 
   {{0x7d1960d7,0xdb000793,0x442401e0,0x00000000}},	//   _útse, _fomä, rql_, --, 
   {{0x442560d8,0xd29802bf,0xddc4054e,0xdb00013d}},	//   sql_, нтрі_, ntiţ, _gomä, 
   {{0x57a407dd,0x65c401e1,0xe3c401c6,0xa50400db}},	//   _ашәа, _déhù, трүү, _كىشە_, 
   {{0xb218019b,0x6ab4015b,0x00000000,0x00000000}},	//   tvær, _আইফো, --, --, 
   {{0x61fc074d,0xc2c4e540,0x1aec00eb,0x00000000}},	//   slrl, _ليبي, জেটে_, --, 
   {{0xb218ad6a,0x02040588,0xfb8000e5,0x1ee800f2}},	// [241c0] rvær, _изин, یگری, روئی_, 
   {{0xb21960d9,0x98bc0356,0xf1bc2bb4,0x00000000}},	//   svær, navă_, spár_, --, 
   {{0x3154008d,0x9f400d27,0xb600032e,0x00000000}},	//   _ביין_, nnië_, _þáer, --, 
   {{0x224160da,0x6fd80598,0x248560db,0xd32c0069}},	//   _kwik_, räcä, _msnm_, _olaʝ, 
   {{0x0ba802dd,0x6b6160dc,0x00000000,0x00000000}},	//   عامى_, ркча, --, --, 
   {{0xb8644a91,0x9f4007de,0x00000000,0x00000000}},	//   نابو, gliö_, --, --, 
   {{0x957c0210,0x00000000,0x00000000,0x00000000}},	//   hnąc, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa5901e4a,0x1fe800cc,0x00000000,0x00000000}},	//   لگىچ, পতিস, --, --, 
   {{0xd76401d3,0xdb0803b2,0x00000000,0x00000000}},	//   _منای, ílær, --, --, 
   {{0x2ca560dd,0xe73400a7,0xf420009d,0x00000000}},	//   ändi_, _аец_, лзүү, --, 
   {{0xe2980953,0x9f400549,0xf2e43d6b,0x957c012d}},	//   ваў_, anië_, тюно, gnąc, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x60180248,0xa6e003d4,0xb60002d2,0x661c013a}},	//   _rúmì, _পৰিয়, _þábr, _úzké, 
   {{0x5eb40131,0x2ce800af,0xdf440006,0xdeb401ec}},	// [241d0] айтт, _जुड़ल_, рэсп, абты, 
   {{0xf3fc0004,0x1d340276,0xf4a00023,0x7278009d}},	//   llã_, инуя, ዝፍለጥ_, _есүс_, 
   {{0x2240000f,0x00000000,0x00000000,0x00000000}},	//   _zwik_, --, --, --, 
   {{0x5c0400fd,0x98bc0356,0x00000000,0x00000000}},	//   аяча, zavă_, --, --, 
   {{0xc9540055,0x81d4015b,0xda0800f1,0x0d640214}},	//   _amūṣ, িকর_, چينه_, _مگاپ, 
   {{0xe8181d8a,0x1a680405,0x2b0c0882,0xea9c00b8}},	//   _पूजा_, ئیلی_, तेषु_, _akṣo_, 
   {{0xddc4084c,0x59640801,0x0c900014,0x00000000}},	//   stiţ, ръча, _دۯاگ, --, 
   {{0x957c012d,0x93280092,0xddc40064,0x00000000}},	//   ynąc, ዲንቀሳ, mtiš, --, 
   {{0xaa400131,0x2484058a,0xddc40153,0x1a68150e}},	//   _ئۆتى, _ssnm_, ltiš, _لینی_, 
   {{0x1b08ede6,0xddc40153,0x00000000,0x00000000}},	//   _рэсп_, otiš, --, --, 
   {{0xddc560de,0xa3c005f9,0x59b803ba,0x2240017a}},	//   ntiš, ंघल_, _अवतर, _swik_, 
   {{0x9f400926,0xc694489b,0x957c012d,0xddc400c0}},	//   rnië_, _مشتع, tnąc, itiš, 
   {{0xdb000fac,0x2484010a,0x9f400d47,0xdcfc0064}},	//   _tomå, _wsnm_, snië_, _darę, 
   {{0xddc560df,0x36640c56,0x09e400cc,0x9e800092}},	//   ktiš, _сашо_, _পীতা, _ዓላማና_, 
   {{0x957c033f,0xb2180158,0xddc40e04,0x00000000}},	//   snąc, rvæp, jtiš, --, 
   {{0x27fd60e0,0xddc40356,0xbfa801d9,0xb4f8010f}},	//   nlun_, friş, رازٕ_, _אפצי, 
   {{0x27fc02f6,0xe8181d15,0xdb00003a,0x41280276}},	// [241e0] ilun_, _पूछा_, _domû, _попо_, 
   {{0xbd8960e1,0xad6560e2,0xdcfc012d,0x27fce3db}},	//   عنان_, лауз_, _zarę, hlun_, 
   {{0x7074036b,0x27fc031c,0x7c94fda4,0x00000000}},	//   _یمیز_, klun_, ырац, --, 
   {{0x27fc0007,0xddc40356,0x98bc00c0,0x00000000}},	//   jlun_, briş, navą_, --, 
   {{0x8fd410db,0x6738151c,0x68fc00ac,0x27fd60e3}},	//   _тәрә, dbuj, əqdi, dlun_, 
   {{0x65bc006a,0x200160e4,0xddc40427,0x00000000}},	//   _sêhn, llii_, btiš, --, 
   {{0x499001d5,0xdcfc0419,0x98bc0064,0x27fd60e5}},	//   تیلر, _horľ, kavą_, flun_, 
   {{0x57b4bdd4,0x8b94ed81,0x76a829cc,0x2000003a}},	//   рбит, _круч, етов_, nlii_, 
   {{0x7f4401ee,0x386d60e6,0x200160e7,0xb9e8035b}},	//   _mekq, stfr_, ilii_, _змаз_, 
   {{0x2000123c,0x80b800bd,0x59b83599,0xa9a0fbd3}},	//   hlii_, _উইন্, _अविर, _лиуд, 
   {{0x27fc07de,0x6738002e,0xd488009d,0x00000000}},	//   blun_, bbuj, төлж_, --, 
   {{0x1bf41d15,0xaee000b8,0x65e00124,0x27fc015d}},	//   इकिल_, _jaṃb, _қәыҧ, clun_, 
   {{0x59b8375c,0xf3fc0004,0x00000000,0x00000000}},	//   _अवार, rlã_, --, --, 
   {{0x764160e8,0x200160e9,0xe530a19b,0xddc40153}},	//   _iwoy, elii_, _лешь, ytiš, 
   {{0xdb0028f2,0x04880046,0xaca001f2,0xe44c007b}},	//   _comú, _ашық_, _kwục, _فضي_, 
   {{0x764004ba,0x200160ea,0xddc4054e,0x3fc402dd}},	//   _kwoy, glii_, triş, аруғ, 
   {{0xde580212,0x00000000,0x00000000,0x00000000}},	// [241f0] латі_, --, --, --, 
   {{0x200160eb,0x764160ec,0x27fc0369,0xf78800fd}},	//   alii_, _mwoy, zlun_, luçı_, 
   {{0x764004ba,0x67385188,0x200160ed,0x74100055}},	//   _lwoy, ybuj, blii_, _ṣṭap, 
   {{0xa1344eaf,0x4fc00a52,0x20004ff3,0xddc40024}},	//   _پریش, _بەرە, clii_, rtiš, 
   {{0xddc48abe,0x2f0801e1,0xaee000b8,0x27fc0205}},	//   stiš, _dògí_, _daṃb, vlun_, 
   {{0x4878039b,0xddc439d5,0x00000000,0x00000000}},	//   всия_, ptiš, --, --, 
   {{0x764160ee,0x27fc0008,0xdd740050,0x69a4012c}},	//   _awoy, tlun_, _چھۅک, चाबी, 
   {{0x6d4560ef,0x764160f0,0x27fc023a,0xaee000b8}},	//   _heja, _bwoy, ulun_, _gaṃb, 
   {{0x6d447cba,0x67383a81,0x27fc0368,0x00000000}},	//   _keja, rbuj, rlun_, --, 
   {{0x6d4560f1,0x9f40026c,0x98c41b15,0xf1bc011f}},	//   _jeja, rnié_, рсәл, uqál_, 
   {{0x6d442508,0x76410516,0x29010c89,0xd6a960f2}},	//   _meja, _ewoy, _ája_, ندیم_, 
   {{0x6d449cbc,0xaca001f2,0xf788013d,0x84700092}},	//   _leja, _gwục, guçı_, _እያለን_, 
   {{0x9814036d,0x95c416cb,0x02055692,0x764004ba}},	//   _ابلا, _ڏينه, измн, _gwoy, 
   {{0x6d4560f3,0xdb007ae7,0x86c40451,0x00000000}},	//   _neja, _comù, _ٽيڪن, --, 
   {{0x59b839d7,0x46d800e1,0x200001ab,0xb61c01ec}},	//   _अवसर, _बेतह, tlii_, _ﺤﺭ_, 
   {{0x64400142,0xd25800e2,0x48ec05dc,0x00000000}},	//   _iwni, šņa_, _अखनो_, --, 
   {{0x6d4560f4,0x741160f5,0x00000000,0x00000000}},	// [24200] _beja, _بويا, --, --, 
   {{0xaee00a28,0x6d4560f6,0x7c9406ed,0xdb01009c}},	//   _saṃb, _ceja, ирец, _tomú, 
   {{0x6d4560f7,0xdb240133,0xdb00072b,0xc10401c8}},	//   _deja, موای, _homø, _خودي, 
   {{0x6d44208d,0x00000000,0x00000000,0x00000000}},	//   _eeja, --, --, --, 
   {{0x19580830,0x79a400db,0xf98401c4,0x00000000}},	//   галы_, ирке, игдо, --, 
   {{0x644160f8,0x6a1052c8,0x764000ca,0xe9f402d5}},	//   _owni, يبور, _rwoy, аніі_, 
   {{0x80b409bd,0xc4d400cc,0xbb4400f5,0x00000000}},	//   ৃপক্, _সুসঙ, _вебк, --, 
   {{0x270c03d4,0x00000000,0x00000000,0x00000000}},	//   াখনো_, --, --, --, 
   {{0x64401bde,0x6d455941,0x35e4011c,0x00000000}},	//   _awni, _yeja, ицов, --, 
   {{0x7b101d55,0xdef80092,0x06b400cc,0x00000000}},	//   _výuč, ዋልና_, _জেহি, --, 
   {{0x7784db74,0xdb000036,0x6440015d,0x65a401c6}},	//   _влез, _onmë, _cwni, ртыг_, 
   {{0x76400223,0x64400042,0xc6c40116,0xded401f3}},	//   _twoy, _dwni, рқәд_, ረሰን_, 
   {{0x764160f9,0xf7880724,0x64400363,0x84700092}},	//   _uwoy, ruçı_, _ewni, _እያልን_, 
   {{0x637c01bf,0x00000000,0x00000000,0x00000000}},	//   _pånæ, --, --, --, 
   {{0x6d4560fa,0x0ce000bd,0x64400042,0x00000000}},	//   _reja, _ভর্ত, _gwni, --, 
   {{0x6d4475a3,0xe3b031ed,0xee1c05d7,0x25180375}},	//   _seja, _يري_, बद्ध_, _בווא, 
   {{0xd2500491,0xa92002fb,0x80b80349,0xf2040024}},	// [24210] _عند_, ážko, _উইণ্, _вяно, 
   {{0x70240014,0x2b900208,0x00000000,0x00000000}},	//   _پردٕ, _ợc_, --, --, 
   {{0x6d442508,0x00000000,0x00000000,0x00000000}},	//   _veja, --, --, --, 
   {{0x6d455cbc,0xab600ae5,0x1b1000eb,0x00000000}},	//   _weja, تۇرى, িশনে_, --, 
   {{0x6d4560fb,0x2d84004a,0x7d18002d,0x53a00023}},	//   _teja, ônes_, _útsn, _ውጹዓት_, 
   {{0xb6000122,0xf1bc0548,0x2ca4007c,0x98bc00c0}},	//   _žánr, dqák_, änds_, lavę_, 
   {{0x0088010f,0x765c00b8,0x2b5400f2,0x00000000}},	//   ָרפֿ, _āpya, _نیاد_, --, 
   {{0xd6d000fe,0x86f40150,0x07a439b8,0xe9e40022}},	//   াপনয, _ﺁل_, саин, ыцҵо, 
   {{0x24280020,0xdcfc00df,0x644003cb,0x00000000}},	//   _ተቃዋሚ, _marĝ, _swni, --, 
   {{0xdcfc008f,0xdb0003cd,0x64400142,0x7bd80248}},	//   _larĝ, _romø, _pwni, _ìtur, 
   {{0xdb0002e2,0x85100034,0x2ad8000d,0xe57c0241}},	//   _anmè, डेंट_, _खेतु_, _àpíì, 
   {{0x481560fc,0x67189401,0x4b78010f,0x98bc0064}},	//   _умес, _पृथक_, נאָו, javę_, 
   {{0xa6a800db,0x98bc0153,0x00000000,0x00000000}},	//   _جااق_, davę_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdcfc0115,0xdb000100,0x00000000,0x00000000}},	//   _barĝ, _enmè, --, --, 
   {{0x7f180220,0xd6e80183,0x38680fac,0xa3bc00c5}},	//   гізу_, _পৰিয, _åbre_, _आकि_, 
   {{0x2a7c0218,0xdcfc01e4,0x3f900113,0xee340395}},	// [24220] _npub_, _darĝ, rdyu_, йнт_, 
   {{0x63a5422a,0xd838110c,0xef1560fd,0xef0c00f1}},	//   _hnin, _hrče_, сму_, رټل_, 
   {{0x63a4107d,0xf1bc0548,0x46d813f5,0x2a7c00d8}},	//   _knin, dqáh_, _बेसह, _apub_, 
   {{0x2d840129,0xf454010f,0x387c045a,0xb4f8010f}},	//   ôner_, מיער_, _rptr_, אפעי, 
   {{0x63a560fe,0xdb08014a,0x00000000,0x00000000}},	//   _mnin, _älüv, --, --, 
   {{0xcaa40597,0x22440122,0xfaa41086,0x7d18045f}},	//   تصمي, ámky_, _қазо, _útso, 
   {{0x63a560ff,0xc0f00016,0x9f400156,0x2a7c3046}},	//   _onin, _rượu_, loiñ_, _epub_, 
   {{0x96356100,0x63a40a49,0x00000000,0x00000000}},	//   ониц, _nnin, --, --, 
   {{0xdb0004e6,0x7bc0030a,0x4b540395,0xaa407b0e}},	//   _onmé, mkou, _фъст, _нетл, 
   {{0x63a56101,0x54549cff,0x758800a8,0x7bc0037e}},	//   _anin, овот, усив_, lkou, 
   {{0x29341a4c,0x63a4089c,0x394c01b8,0xdcfc00fd}},	//   _האבן_, _bnin, mafs_, _korı, 
   {{0x7bc16102,0xf3c96103,0xad18010f,0x46d80037}},	//   nkou, ابده_, טויר, _बेवह, 
   {{0x7bc00129,0x00000000,0x00000000,0x00000000}},	//   ikou, --, --, --, 
   {{0x63a56104,0x271c0055,0xe714011a,0x55c40304}},	//   _enin, _dānī_, _החדר_, _фәиз, 
   {{0xef1c0ba1,0x7bc16105,0x00000000,0x00000000}},	//   _laüt_, kkou, --, --, 
   {{0x63a56106,0xdfd56107,0xd83801a6,0x394c02d2}},	//   _gnin, посы, _mtč_, hafs_, 
   {{0xad2401d9,0xc5ec00aa,0x394c0793,0x98bc0024}},	// [24230] مراو, _سړی_, kafs_, ravę_, 
   {{0xd83802e2,0x7bc00b4f,0xd2500014,0x63a401d5}},	//   _otč_, ekou, _ٹنگ_, _znin, 
   {{0xdcfc0724,0x394c0793,0x7d196108,0x63a56109}},	//   _borı, dafs_, _útsl, _ynin, 
   {{0x7bc0007f,0x63a4022e,0x00000000,0x00000000}},	//   gkou, _xnin, --, --, 
   {{0x957c068f,0xd83802e2,0xf8ac0133,0x00000000}},	//   ciąg, _atč_, ێکم_, --, 
   {{0x957c0034,0x7bc1610a,0x6824002d,0x394c01b8}},	//   niąd, akou, _lűde, gafs_, 
   {{0x98bc0118,0x91a80051,0x00000000,0x00000000}},	//   mavě_, _cuả_, --, --, 
   {{0x7bc096a0,0x00000000,0x00000000,0x00000000}},	//   ckou, --, --, --, 
   {{0x63a5610b,0x96940276,0xdb00010e,0x2a7c0254}},	//   _rnin, прэш, _komý, _upub_, 
   {{0x63a5610c,0x00000000,0x00000000,0x00000000}},	//   _snin, --, --, --, 
   {{0x63a4022e,0x47340395,0xdcfc0139,0x46d8012d}},	//   _pnin, _днес, _marğ, _बेरह, 
   {{0x63a46eb0,0xdcfc0166,0x98bc013a,0xf8ac0244}},	//   _qnin, _larğ, havě_, _جکه_, 
   {{0x63a40051,0x98bc01ef,0x00000000,0x00000000}},	//   _vnin, kavě_, --, --, 
   {{0x7bc00316,0xdb0000e4,0xbbb43874,0x69c1610d}},	//   zkou, _nomý, _अक्क, nkne, 
   {{0x7bc1610e,0x7fd9610f,0xd838041a,0x69c16110}},	//   ykou, афат_, _trče_, ikne, 
   {{0x63a56111,0x69c06de4,0x00000000,0x00000000}},	//   _unin, hkne, --, --, 
   {{0x82349717,0x69c16112,0xdcfc00fd,0xee34b834}},	// [24240] _بربا, kkne, _barğ, жну_, 
   {{0x9f400165,0xdcfc00fd,0x00000000,0x00000000}},	//   roiñ_, _sorı, --, --, 
   {{0x61fd5a06,0xd9b40131,0x317808a8,0xdb0002f0}},	//   morl, ۋەرد, _דרימ, _domý, 
   {{0x61fd6113,0xdcfc0724,0x7d18002d,0xa3c000e1}},	//   lorl, _qorı, _útsm, ंघट_, 
   {{0x7bc0234d,0x98bc0118,0x394c0327,0xae34014b}},	//   rkou, bavě_, tafs_, _дӯхт_, 
   {{0x7bc16114,0x61fd6115,0x69c006a3,0x7e740334}},	//   skou, norl, gkne, mtyp, 
   {{0xa9644a8f,0x7e7499b9,0xdcfc0724,0x61fc0194}},	//   ција_, ltyp, _torı, iorl, 
   {{0x61fd6116,0x69c00072,0x9f400268,0xef1c004e}},	//   horl, akne, nnià_, _taüt_, 
   {{0x7e756117,0x61fd6118,0x7c3c257c,0xdcfc2b24}},	//   ntyp, korl, lppr, _yarğ, 
   {{0x7c3c0373,0x61fd6119,0x68240790,0x7e740124}},	//   oppr, jorl, _rıdv, ityp, 
   {{0x61fc07d6,0x69a40316,0x7e75611a,0xf7a802e8}},	//   dorl, चारी, htyp, _вълк_, 
   {{0x273000db,0x00000000,0x00000000,0x00000000}},	//   _قىمس, --, --, --, 
   {{0x61fc12ed,0xa3bc0034,0x1634010b,0x00000000}},	//   forl, _आकर_, _эеля, --, 
   {{0xdb01611b,0x61fc0eda,0xefcc0020,0x00000000}},	//   _homó, gorl, _ጣቢያ_, --, 
   {{0x7e7402fa,0xdb000034,0x98ac0153,0x26040210}},	//   etyp, _komó, _vedė_, हतरी_, 
   {{0x7e740175,0xceb800d1,0x0e344d56,0xdcfc8af3}},	//   ftyp, бәг_, знаю, _sarğ, 
   {{0x61fd611c,0x7c3c01f5,0x69c1611d,0xdcfd611e}},	// [24250] borl, eppr, ykne, _korķ, 
   {{0x7c3c010a,0xdcfc6656,0x907400d4,0x00000000}},	//   fppr, _qarğ, _егої, --, 
   {{0x7c3c0280,0xc1700375,0x98bc012c,0x7e740022}},	//   gppr, _אחי_, ravě_, atyp, 
   {{0xdb000793,0x7e74a270,0x997c00de,0x00000000}},	//   _fomü, btyp, _jāņi_, --, 
   {{0x7e740408,0xbf340bd9,0xe1f0be04,0x7c3c257c}},	//   ctyp, _מארץ_, _سسی_, appr, 
   {{0x7a100051,0x00000000,0x00000000,0x00000000}},	//   _ởtro, --, --, --, 
   {{0x69c1611f,0xdc7400ee,0xdd580276,0x6fbc36c3}},	//   rkne, _огры, _фасч_, _एकां, 
   {{0x69c16120,0xdb0000c6,0x61fc036b,0x2bc800f5}},	//   skne, _comó, zorl, _туго_, 
   {{0x61fd6121,0xdb000034,0x00000000,0x00000000}},	//   yorl, _domó, --, --, 
   {{0x6e38029f,0xdcfc009b,0x889400a7,0x3868007b}},	//   _çubu, _zarđ, _низх, óiré_, 
   {{0xa5040075,0x3a8401d9,0x00000000,0x00000000}},	//   تىدە_, _وُہہ, --, --, 
   {{0x7e756122,0x48140228,0x97a401c6,0x00000000}},	//   ytyp, _эмес, _орчл, --, 
   {{0xdb0000cf,0x4abcd0f6,0x46a40395,0x997c00ef}},	//   _homò, ्निव, _халв, _dāņi_, 
   {{0x7e7412e8,0x3f9c0139,0x00000000,0x00000000}},	//   vtyp, _ştu_, --, --, 
   {{0x61fd6123,0x25a403b2,0x3dc80175,0x7e740175}},	//   rorl, _innl_, _rlbw_, wtyp, 
   {{0x4abc2311,0x61fc20ac,0xdb00067c,0x00000000}},	//   ्नाव, sorl, _momò, --, 
   {{0x61fd6124,0x64a000d1,0x7e7401f5,0x00000000}},	// [24260] porl, _хақа, utyp, --, 
   {{0x7e756125,0x7d187996,0x62840165,0x61fc0869}},	//   rtyp, _útsk, _ipio, qorl, 
   {{0x3b856126,0x71b8011a,0x31b8011a,0x00000000}},	//   злег, _הציג, _הזינ, --, 
   {{0x2ca40158,0x7e740334,0x23cc00cd,0xe9340116}},	//   ånda_, ptyp, ासिद, ۋسىت_, 
   {{0x19954123,0x957c033f,0x7e740334,0x2c080066}},	//   даля, niąc, qtyp, حعلی_, 
   {{0x62856127,0x00000000,0x00000000,0x00000000}},	//   _mpio, --, --, --, 
   {{0xdb016128,0x3eb00311,0xbb440fbe,0x23cc00dc}},	//   _comò, ţată_, _невк, ासाद, 
   {{0x6284166a,0xf09006a9,0xdb0000db,0x6f0c037e}},	//   _opio, תנה_, _domò, _yzcc, 
   {{0xa8204667,0x7c2c35ee,0xf7480137,0x00000000}},	//   رکمن, _hubr, _ۇلاي_, --, 
   {{0xe9440344,0x4964010b,0xcaa45230,0x00000000}},	//   _فرمی, _онуң, _تصفي, --, 
   {{0x7c2c90e9,0x62856129,0xe60c0d2f,0x98ac0171}},	//   _jubr, _apio, دشي_, _medī_, 
   {{0x7c2d612a,0x628436f4,0x366808ca,0xdcfc00ef}},	//   _mubr, _bpio, _гадо_, _harē, 
   {{0x35a44533,0xc7640014,0xdcfc0171,0x5558026b}},	//   _надг, _زانى, _karē, _даля_, 
   {{0x7c2d612b,0xc1a40220,0x7988015d,0x00000000}},	//   _oubr, мысқ, nefw, --, 
   {{0xdcfd612c,0x6284005a,0x7c2d612d,0x68240205}},	//   _marē, _epio, _nubr, _hıdr, 
   {{0x628401ab,0x957c012d,0x00000000,0x00000000}},	//   _fpio, biąc, --, --, 
   {{0x7c2d612e,0xf3fc00e4,0xdfd802e8,0xdef45fd0}},	// [24270] _aubr, moã_, чър_, епты, 
   {{0xdd94054a,0x00000000,0x00000000,0x00000000}},	//   науы, --, --, --, 
   {{0x7c2c1280,0xe1f0131e,0x7988015d,0xe80c00bc}},	//   _cubr, _حسي_, defw, ातमा_, 
   {{0x7c2d612f,0x09c400dc,0x630400d1,0x8b8400cf}},	//   _dubr, वस्य, _توۋل, بەرە_, 
   {{0x6d4005d1,0xfe6d08c4,0x5e8401f0,0xc928009d}},	//   ınab, _نگل_, _пурз, оолж_, 
   {{0xfaa00107,0x00000000,0x00000000,0x00000000}},	//   ташо, --, --, --, 
   {{0x7c2c5513,0xf8b401c0,0x00000000,0x00000000}},	//   _gubr, мөц_, --, --, 
   {{0x6e240477,0x9b947180,0x668015b4,0x06c8009d}},	//   _hijb, _писц, فیصل, жгий_, 
   {{0x6b896130,0x0cdc13e0,0x49740982,0xba440118}},	//   megg, _मधुम, _олас, _průř, 
   {{0x6e240477,0x28680798,0x00000000,0x00000000}},	//   _jijb, _грдо_, --, --, 
   {{0x62856131,0xdcfc010f,0x6e2c01ab,0x957c033f}},	//   _spio, _forĵ, _lucb, wiąc, 
   {{0x6b896132,0x6e240369,0x86a00184,0x00000000}},	//   negg, _lijb, _ағиҙ, --, 
   {{0x27fc5f79,0xa5040075,0xe70805d9,0xa28400f1}},	//   moun_, تىگە_, _اتان_, ریدو, 
   {{0x6b880801,0x27fd6133,0x6e256134,0x8fc40124}},	//   hegg, loun_, _nijb, ҭарҵ, 
   {{0x957c068f,0x00000000,0x00000000,0x00000000}},	//   siąc, --, --, --, 
   {{0x27fd6135,0x6b88eab6,0x7d190896,0xf1a4012c}},	//   noun_, jegg, _útsi, खाउन, 
   {{0x7c2d6136,0x6e240cf9,0x27fc0086,0x95b401c6}},	// [24280] _subr, _bijb, ioun_, _цөөх, 
   {{0x27fc06f2,0xc0bc001f,0x6b880036,0x00000000}},	//   houn_, ተባለ_, eegg, --, 
   {{0x6e2401f5,0x27fc5dad,0x7c2d6137,0x98ac00b8}},	//   _dijb, koun_, _qubr, _vedī_, 
   {{0xab8005cc,0x6b88a723,0x61440c71,0x672803b2}},	//   вушк, gegg, _تىگە, _nggj, 
   {{0xdcfc0171,0x00000000,0x00000000,0x00000000}},	//   _parē, --, --, --, 
   {{0x7c2d6138,0x6d400259,0xddc402f0,0xa6b000cc}},	//   _tubr, ınac, ltiž, টনাট, 
   {{0xdcfc0029,0x7c2c1c06,0x6e3883c5,0x6b880083}},	//   _varē, _uubr, _çubr, begg, 
   {{0x79880b6f,0x20016139,0x27fd44c3,0x6e2401a4}},	//   sefw, noii_, goun_, _zijb, 
   {{0x7ac80451,0xeb302a8b,0x395400f3,0x00000000}},	//   _بوءِ_, _شىلد, _жњет, --, 
   {{0xaa4000a8,0x672805f7,0x38680158,0xddc40064}},	//   _рефл, _eggj, _åbro_, driū, 
   {{0x9cec0d42,0x27fd613a,0xfa88001f,0xae9000e4}},	//   _করুন_, boun_, _መልአክ_, rỹim, 
   {{0x9f400108,0x00000000,0x00000000,0x00000000}},	//   nniä_, --, --, --, 
   {{0xae9000c7,0x9f400108,0xddc400c0,0x00000000}},	//   pỹim, iniä_, griū, --, 
   {{0x3f8002a8,0x6b880196,0x00000000,0x00000000}},	//   _abku_, zegg, --, --, 
   {{0x6e240196,0x6b880337,0x84c00166,0xd4c4004e}},	//   _rijb, yegg, _бәяд, _чөпк, 
   {{0xd5b80a28,0x6e240582,0xd9040133,0xddc40064}},	//   smād_, _sijb, _ۆی_, briū, 
   {{0xd904992b,0x9f05613b,0x6b882147,0x92dc00cc}},	// [24290] _چی_, پولو, vegg, _তুৰ_, 
   {{0xd905613c,0x6b880337,0x6e24047e,0x2bc4449f}},	//   _نی_, wegg, _qijb, लस्थ, 
   {{0x6b89613d,0x00000000,0x00000000,0x00000000}},	//   tegg, --, --, --, 
   {{0xf78400ee,0x0c74001f,0x6e25613e,0x59a40b26}},	//   ýçli_, _አጋማሽ_, _wijb, _गोबर, 
   {{0x6b89613f,0x8b04012d,0x7f38011a,0x34c800cd}},	//   regg, knęł, _מתרג, ानुद, 
   {{0x6b88017a,0xdcfc0841,0x5a44084c,0x27fc0100}},	//   segg, _zbrč, тэца, woun_, 
   {{0x6b880395,0x452801c0,0x27fd6140,0x00000000}},	//   pegg, үжин_, toun_, --, 
   {{0x3f9c013f,0x3ea00162,0x00000000,0x00000000}},	//   _ɔtuo_, _yrkt_, --, --, 
   {{0x46e80116,0x46a402e8,0xc7a4008e,0x00000000}},	//   ядин_, хапв, _җилк, --, 
   {{0x27fc01c7,0x88a00133,0xc4f80050,0x8b040210}},	//   soun_, _میتۆ, ۪ٹھا_, gnęł, 
   {{0x27fc01c7,0x0cdc01f9,0x00000000,0x00000000}},	//   poun_, _मधोम, --, --, 
   {{0x603c007f,0x7c396141,0xe28401d5,0x1888030d}},	//   _jčme, _étre, вғин, _юсуп_, 
   {{0x2d801f7f,0x34b00132,0xddc4054e,0x20000356}},	//   _obje_, _ەمىز, nuiţ, voii_, 
   {{0x2d840254,0x00000000,0x00000000,0x00000000}},	//   õnel_, --, --, --, 
   {{0xee3c06d9,0x20002499,0x34900e92,0x00000000}},	//   _atý_, toii_, _бајр, --, 
   {{0x25d800dc,0x00000000,0x00000000,0x00000000}},	//   गोरी_, --, --, --, 
   {{0x9cec03f4,0x7dd0019b,0xdb001dfe,0xf2dc000f}},	// [242a0] _করেন_, _læse, _homö, lbân_, 
   {{0x22416142,0x2b5c084c,0x7dd00194,0xdb001cc4}},	//   _itik_, _aduc_, _oæse, _komö, 
   {{0xee3c05da,0x7dd0037e,0xfb88b32f,0xc0e56143}},	//   _etý_, _næse, збек_, _чонк, 
   {{0xdb2444e7,0x395c009a,0xf438008f,0x06b400cc}},	//   نوای, _sdts_, לגעמ, _জেছি, 
   {{0x2240025c,0x7f5402d1,0x8b040210,0x00000000}},	//   _jtik_, mayq, ynęł, --, 
   {{0x7f54ba3d,0xbe1400db,0xddc40327,0x00000000}},	//   layq, _سوزع, ntiż, --, 
   {{0xdb00014a,0x603c02e2,0x201c02e2,0x699c0073}},	//   _nomö, _fčme, _èvis_, _गोळी, 
   {{0x23600399,0xdb00056a,0x224001b8,0x7f54bff1}},	//   _ndij_, _enmá, _otik_, nayq, 
   {{0xddc40356,0x96f8035b,0x00000000,0x00000000}},	//   cuiţ, ьеит_, --, --, 
   {{0x7f5402d1,0x7dd0005c,0x57d801ec,0xd838013a}},	//   hayq, _hæsb, _ﺀﺑﯩﺮ, _určo_, 
   {{0x22400d29,0x7f540784,0x8b040210,0x00000000}},	//   _atik_, kayq, rnęł, --, 
   {{0x79996144,0x7d18002d,0x8b04012d,0xe8f40354}},	//   _hatw, _útsu, snęł, _ялх_, 
   {{0x79996145,0x7f540784,0x228521d2,0x18680139}},	//   _katw, dayq, лург, _хаҗи_, 
   {{0xdb0001b8,0x7998014f,0x65902716,0x7dd001bf}},	//   _fomö, _jatw, _башу, _læsb, 
   {{0x22416146,0x79996147,0x1cdc0327,0xddc400d0}},	//   _etik_, _matw, ྣགས_, mpiň, 
   {{0x79996148,0x7dd0005c,0x7af4012d,0x00000000}},	//   _latw, _næsb, żyty, --, 
   {{0xf41d6149,0x799802d0,0x521557bd,0x00000000}},	// [242b0] mmä_, _oatw, _идит, --, 
   {{0xf41d614a,0x79981389,0xb21804ce,0x00000000}},	//   lmä_, _natw, dtæg, --, 
   {{0x32000109,0x0c040014,0x00000000,0x00000000}},	//   mojy_, پوشُ, --, --, 
   {{0xea5400fd,0x1aec015b,0x7dd001bf,0xd25800de}},	//   ездә_, ড়েছে_, _ræse, šņu_, 
   {{0x7999614b,0x8afc0118,0x00000000,0x00000000}},	//   _batw, _odře, --, --, 
   {{0xf41c02f6,0xdcfc0006,0x59a402ab,0xddc4054e}},	//   hmä_, _narė, _गोदर, ruiţ, 
   {{0x6d55614c,0x79980042,0x0cf42ce6,0xf41c0166}},	//   maxa, _datw, _आशिष_, kmä_, 
   {{0x7dd004ce,0xf41c01a2,0x79980857,0x78bc01e3}},	//   _væse, jmä_, _eatw, äpva, 
   {{0xdb01614d,0x6b9805ac,0x391001e0,0x668007d6}},	//   _somö, _iaug, лмәр, ایتل, 
   {{0x6d55614e,0x6b981700,0x224007ab,0xf41c0166}},	//   naxa, _haug, _rtik_, emä_, 
   {{0x6b99614f,0x22416150,0x7d196151,0x28a4036b}},	//   _kaug, _stik_, _útst, _яшаг, 
   {{0xf2dc0b21,0xa3dc068f,0x6d5401d9,0x957c0034}},	//   rbân_, णों_, haxa, wnąt, 
   {{0x6b996152,0x6d556153,0x79996154,0xdb000e78}},	//   _maug, kaxa, _yatw, _womö, 
   {{0x32400b65,0x6d556155,0x6b996156,0xddc40cf4}},	//   рерг, jaxa, _laug, kuiš, 
   {{0x6d556157,0xdb000798,0x91a801fb,0xded4001f}},	//   daxa, _homô, _quá_, ጫውን_, 
   {{0xdb005e32,0x67396158,0xddc4033f,0x412801f0}},	//   _komô, ncuj, stiż, зоҳо_, 
   {{0x35a40dad,0x22400194,0x6d556159,0x07440131}},	// [242c0] _कोड़, _utik_, faxa, ﭘﺘﯘ_, 
   {{0xef15615a,0x67380007,0xdcfc07d7,0x9f40007b}},	//   тму_, hcuj, _abrā, nniú_, 
   {{0x6b99615b,0x799801ee,0x9f4000c6,0x7f54e942}},	//   _baug, _ratw, iniú_, payq, 
   {{0x9f400597,0x79989c2d,0x6b99615c,0x7f540784}},	//   hniú_, _satw, _caug, qayq, 
   {{0x7999615d,0x6b99615e,0x6d55615f,0xeaac05d9}},	//   _patw, _daug, baxa, قعو_, 
   {{0xcee801d9,0x6b986b53,0x7998014f,0x35a400c5}},	//   _سرُن_, _eaug, _qatw, _कोढ़, 
   {{0x6b996160,0x79996161,0xf41ce9b1,0xfce55de0}},	//   _faug, _vatw, ymä_, _рово, 
   {{0x2ca4037e,0x79996162,0xfaa400c7,0x6b980afa}},	//   ænde_, _watw, _иабо, _gaug, 
   {{0x79996163,0x34c81a55,0xdcfc0153,0x00000000}},	//   _tatw, ान्द, _parė, --, 
   {{0x6b9804cc,0x9f40007b,0xb5a448d4,0x00000000}},	//   _zaug, gniú_, трий, --, 
   {{0xdcfc0024,0x6b996164,0x58e000cc,0x00000000}},	//   _varė, _yaug, _পুৰী, --, 
   {{0xf7442e58,0x3d18033f,0x00000000,0x00000000}},	//   _редо, _भरने_, --, --, 
   {{0xe7348f91,0xf41c2347,0x91c40075,0x6d547c86}},	//   _реч_, rmä_, гәнл, yaxa, 
   {{0x76400921,0x6d556165,0xf41d6166,0xdb00010e}},	//   _itoy, xaxa, smä_, _inmä, 
   {{0xa5f40220,0xb62c01ec,0x00000000,0x00000000}},	//   _шешу_, _ﻓﻜ_, --, --, 
   {{0x6d5436ba,0xa4240022,0x60c803cd,0x20544a1a}},	//   waxa, _кьыл, ødma, ртёр, 
   {{0x6d556167,0xdce80421,0x6b996168,0x9f3402dd}},	// [242d0] taxa, _ālāv, _raug, реуі, 
   {{0x6b980953,0xace8005e,0xad24168d,0x67380369}},	//   _saug, ورال_, نراو, zcuj, 
   {{0x6b996169,0x6d55616a,0xdd94c8a6,0x67380118}},	//   _paug, raxa, рахы, ycuj, 
   {{0x6b980194,0x6d54292a,0x77601bce,0x8af8dff5}},	//   _qaug, saxa, _ndox, ннес_, 
   {{0x6b99616b,0x76400230,0x59a4000d,0x00000000}},	//   _vaug, _ntoy, _गोहर, --, 
   {{0x6b99616c,0x2bf02b1b,0x00000000,0x00000000}},	//   _waug, জতেই_, --, --, 
   {{0xdb000628,0xe80c0490,0x9855616d,0xac240124}},	//   _anmä, ातला_, атыш, _афак, 
   {{0x9d18fc32,0x7c3908e8,0xdb0001a2,0x5ba40a89}},	//   _рост_, _étra, _pomô, _круз, 
   {{0x9be4005e,0x5a347724,0x59a41d97,0x6738655f}},	//   _тірк, _внут, _गोवर, rcuj, 
   {{0x776002d0,0x957c0153,0x2bdc0dba,0x85780022}},	//   _edox, liąj, पोरा, хсит_, 
   {{0x85b80220,0x00000000,0x00000000,0x00000000}},	//   _үлес_, --, --, --, 
   {{0xdc2c0055,0x9f400332,0x957c00c0,0x00000000}},	//   _kųān, sniú_, niąj, --, 
   {{0x7dd00413,0xc79401af,0x1664003b,0x00000000}},	//   _læsa, _арһы, _ввім, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x394000ac,0x6d400ac4,0x7dd003b2,0x00000000}},	//   _əks_, ınal, _næsa, --, 
   {{0xafe0c3ff,0x6441616e,0x00000000,0x00000000}},	//   босл, _itni, --, --, 
   {{0xbd8504b9,0xfe44013e,0xdcfc0356,0x3ea40332}},	// [242e0] лгак, унзо, _obră, íot_, 
   {{0x44200175,0xfe0800cf,0x00000000,0x00000000}},	//   lmk_, رقاي_, --, --, 
   {{0x7dd1616f,0x603c007f,0x3178008f,0x6cb0004e}},	//   _cæsa, _fčma, _ארימ, бөтт, 
   {{0xdcfc002b,0x7514010f,0x00000000,0x00000000}},	//   _harī, אַדע_, --, --, 
   {{0x8ac404a9,0x3f90009a,0x1ab4005b,0xdcfc1a14}},	//   ақта_, meyu_, рбля, _karī, 
   {{0x64416170,0x3f916171,0x8eb019c5,0xee3c00a2}},	//   _otni, leyu_, _بەكت, _urýa_, 
   {{0x76416172,0x18b40588,0xf8056173,0x58d56174}},	//   _stoy, шәар, лчин, ройт, 
   {{0x3f900bd7,0x6560035a,0x3b08013e,0x4420037e}},	//   neyu_, _adnh, _зебо_, jmk_, 
   {{0x7c216175,0x644001d5,0x571800a7,0x00000000}},	//   mmor, _atni, ъжия_, --, 
   {{0xdcfc0055,0x5bd40037,0x78741291,0x00000000}},	//   _narī, _दतुव, _مُطا, --, 
   {{0x3f900161,0x2db40a1e,0xe004107c,0x3868032e}},	//   keyu_, אלין_, लवाद_, _íbr_, 
   {{0x7c216176,0x00000000,0x00000000,0x00000000}},	//   nmor, --, --, --, 
   {{0x76416177,0xdcfc005f,0xe2980006,0x00000000}},	//   _utoy, _barī, гаў_, --, 
   {{0x26d80375,0x7c20002f,0x603c0100,0xee3c032e}},	//   _אקדמ, hmor, _sčma, _brýn_, 
   {{0xdcfc00da,0x603c02e2,0x7c201f65,0x2934010f}},	//   _darī, _pčma, kmor, ראלן_, 
   {{0x6d400790,0x3f9000e8,0x7c200455,0x00000000}},	//   ınam, geyu_, jmor, --, 
   {{0xaef80241,0x7d0c01d5,0xb63400b5,0xb2840137}},	// [242f0] _edùn, _aybs, _ｚｚ_, _сыйк, 
   {{0xdcfc0318,0x22440030,0x2d856178,0xf19001d3}},	//   _garī, ímke_, ýne_, _اُدھ, 
   {{0x7c2096c9,0x4c940fbe,0xb7f4012c,0x3d1807b6}},	//   fmor, риес, ुकाम_, _भरणे_, 
   {{0x7c216179,0xdd940046,0x3f900ffb,0x603c009b}},	//   gmor, _қасы, ceyu_, _učma, 
   {{0xe50800af,0xaa641367,0x957c00c0,0x00000000}},	//   _सुनि_, утек, riąj, --, 
   {{0x1a68be60,0x00000000,0x00000000,0x00000000}},	//   ایلی_, --, --, --, 
   {{0x7d19617a,0x1df81e76,0x8c2400c6,0x9d1800f5}},	//   _útsp, _серы_, _نفسه, _борт_, 
   {{0x2d91617b,0x3a800014,0x7c20002f,0x3d19617c}},	//   lexe_, _ژینِ, cmor, _भरते_, 
   {{0x1a69617d,0x644c0e3c,0x6440022e,0x00000000}},	//   _مینی_, ćcim, _stni, --, 
   {{0x2d91617e,0x7dd0037e,0xc484022e,0x568800ec}},	//   nexe_, _læsn, алок, ائيٽ_, 
   {{0xe7740014,0x98bc0024,0x442000b5,0x04380023}},	//   _ملاں_, davė_, tmk_, _ከተጽን, 
   {{0xdcfc1c52,0x2d91617f,0x82a4009d,0x00000000}},	//   _sarī, hexe_, аамж, --, 
   {{0xdcfc0aed,0x00000000,0x00000000,0x00000000}},	//   _parī, --, --, --, 
   {{0x3f9002ce,0xd6c00014,0x3a3402e4,0x7c216180}},	//   weyu_, _رۅپی, ירשם_, zmor, 
   {{0x7c216181,0x3f906e08,0x2d9009e2,0xdcfc24cb}},	//   ymor, teyu_, dexe_, _varī, 
   {{0xe3b80150,0x425401f4,0x00000000,0x00000000}},	//   _сұм_, _ктот, --, --, 
   {{0xee356182,0x7c200250,0x30000220,0xd8380010}},	// [24300] инт_, vmor, ізуг, _vrči_, 
   {{0x0eb8052f,0x998c005f,0x7c213f5b,0x00000000}},	//   ыусы_, _vidū_, wmor, --, 
   {{0x7c216183,0xd83805ce,0xdcfc012d,0x3f9000e4}},	//   tmor, _trči_, _obrą, peyu_, 
   {{0x7ac43d63,0x7dd003b2,0x00000000,0x00000000}},	//   исле, _gæsn, --, --, 
   {{0xeb500137,0x00000000,0x00000000,0x00000000}},	//   زۉلگ, --, --, --, 
   {{0x7c385725,0x80b8000d,0x00000000,0x00000000}},	//   _étro, _उपाइ, --, --, 
   {{0x7c20007c,0x957c0210,0x84840092,0x00000000}},	//   pmor, siąk, _ሞርሞን_, --, 
   {{0xddc4054e,0x57b40131,0xd7f80051,0xb8cc0037}},	//   briţ, сбит, _evăn_, _ओछ_, 
   {{0xab256184,0xaa400cb6,0x1ae40183,0x2d8401e4}},	//   _вота_, _метл, _ফুৰা, ĵnev_, 
   {{0xd00002f5,0xca740032,0x74a4041b,0xd49800d4}},	//   ্ষয়_, _ыусы, ајме, гкої_, 
   {{0x388c00ac,0x2ba80fe6,0x00000000,0x00000000}},	//   _sərf_, _घोडा, --, --, 
   {{0x2d900564,0xd5b800e2,0x00000000,0x00000000}},	//   zexe_, mmām_, --, --, 
   {{0x2d9002c4,0x00000000,0x00000000,0x00000000}},	//   yexe_, --, --, --, 
   {{0xf20402bf,0x2d90003e,0x00000000,0x00000000}},	//   рямо, xexe_, --, --, 
   {{0xa1586d5a,0x00000000,0x00000000,0x00000000}},	//   расу_, --, --, --, 
   {{0x9f34753d,0x00000000,0x00000000,0x00000000}},	//   жеті, --, --, --, 
   {{0xd8396185,0x2d916186,0x60d40010,0x7dd0005c}},	// [24310] _luč_, texe_, _čemš, _væsn, 
   {{0xeca4026a,0x1544001f,0x7124e824,0xad440454}},	//   ијен, _የጠቆሙ, _پرخل, рхак, 
   {{0x2d916187,0x9f4000a2,0x00000000,0x00000000}},	//   rexe_, lniý_, --, --, 
   {{0x2d916188,0xddc40276,0x7dd001bf,0x388c03b9}},	//   sexe_, triţ, _hæsl, _mərd_, 
   {{0x06c80131,0x15f8202e,0x9f4000a2,0x00000000}},	//   ﻪﻣﺒﻪ, ुवार_, nniý_, --, 
   {{0x9a2400f7,0xd8380427,0x00000000,0x00000000}},	//   يعون, _buč_, --, --, 
   {{0x7dd001bf,0x388c03b9,0xf8ac00e5,0x00000000}},	//   _mæsl, _nərd_, ٹکل_, --, 
   {{0x03c002a6,0xefd40023,0x6680036b,0x00000000}},	//   _উষ্ণ, _ኮማዊ_, قیصل, --, 
   {{0x06081b10,0xc0ec001f,0xc7940124,0x696400db}},	//   лник_, _ቀውስ_, арҿы, _نداق, 
   {{0xd83819d6,0xa5e401e0,0xb38001c6,0x7ae402d2}},	//   _fuč_, рлоҡ_, үлэл, _ýkta, 
   {{0x03a44e69,0xe8940014,0x0b7c001f,0xe5880150}},	//   бино, _خماں_, _የምድር_, _ﺒﺤﺼﺭ_, 
   {{0xd8380100,0x388c0213,0x00000000,0x00000000}},	//   _prčv_, _dərd_, --, --, 
   {{0xddc400f3,0x9f40010e,0x00000000,0x00000000}},	//   hriš, gniý_, --, --, 
   {{0x7dd000b5,0xddc400e2,0x388c03b9,0xd24c0133}},	//   _ræso, kriš, _fərd_, کۆی_, 
   {{0x7dd0019b,0x3f6853d1,0xdb0000d8,0x4374084c}},	//   _sæso, ливо_, _camê, _лупт, 
   {{0x6ab40d38,0xafe0bde1,0xd83816a3,0xddc45160}},	//   _आपूर, посл, _grču_, driš, 
   {{0x754400dd,0x4430003e,0xb21800b5,0xe5082d8f}},	// [24320] _érzé, _iiy_, mtæn, _सुति_, 
   {{0x443152c0,0x7dd001a8,0xed5401e0,0xdd3c0153}},	//   _hiy_, _gæsl, йоу_, sąži, 
   {{0x31980302,0x44300694,0x73300131,0xddc40cf4}},	//   _גבינ, _kiy_, _بىۋا, griš, 
   {{0xca3800df,0x44301bce,0xb2184e95,0x00000000}},	//   _buŝ_, _jiy_, ntæn, --, 
   {{0xdcfc110c,0x44316189,0x0eb81e76,0xd9b40131}},	//   _obrć, _miy_, _куры_, يەرد, 
   {{0x4431618a,0xddc40f03,0xd838009b,0x7db5618b}},	//   _liy_, briš, _puč_, _اصحا, 
   {{0x44300295,0xdb00036e,0x00000000,0x00000000}},	//   _oiy_, _kamë, --, --, 
   {{0x4431618c,0xe5080cb4,0xd5b800e2,0x00000000}},	//   _niy_, _सुधि_, rmām_, --, 
   {{0xf1bc0548,0xb97855cf,0x95d807d8,0xb21801bf}},	//   aqáy_, _محاذ_, идит_, dtæn, 
   {{0x44300086,0xb6840150,0xdb000200,0x140001f9}},	//   _aiy_, _ۇشتى, _lamë, ईव्ह_, 
   {{0x44300694,0x7e740784,0x778402e8,0x00000000}},	//   _biy_, huyp, _глез, --, 
   {{0x44301574,0x7e740bf1,0xb21803b2,0x00000000}},	//   _ciy_, kuyp, gtæn, --, 
   {{0x4431618d,0x7e740113,0xa9200118,0x00000000}},	//   _diy_, juyp, ěžen, --, 
   {{0x443008e7,0xe5a1618e,0xd838007f,0x22440419}},	//   _eiy_, _ничи, _frčt_, ímka_, 
   {{0x4431618f,0x388c00ac,0x74f00220,0xc0d00092}},	//   _fiy_, _hərb_, _رۋحا, _የዜማ_, 
   {{0x44301bce,0xdb000200,0xe8dc0051,0x00000000}},	//   _giy_, _camë, _chộm_, --, 
   {{0x7e7400c7,0xe0d001d3,0xe3b0007b,0x00000000}},	// [24330] guyp, وزہ_, _أرى_, --, 
   {{0xddc48aac,0x44306e25,0xc0a800ec,0x00000000}},	//   triš, _ziy_, _ڦاٿل_, --, 
   {{0x0b596190,0x8f34084c,0xdb000023,0x44301574}},	//   арлы_, _менц, _famë, _yiy_, 
   {{0xdb011b79,0xf78803e0,0x982c0150,0x00000000}},	//   _kamè, nsçı_, _ﺷﺎﻻﯓ_, --, 
   {{0x1fa405f5,0xdb00068c,0x7dd00158,0x272c0205}},	//   _эрэг, _jamè, _mæsj, _mönü_, 
   {{0xdb001df3,0xbd7064b6,0xddc439e2,0x2ca47fff}},	//   _mamè, _оңуш, priš, ånds_, 
   {{0xdb001f5d,0x7d080e78,0xdcfc033f,0xa17c0a7c}},	//   _lamè, üfst, _obrę, אטוט, 
   {{0x3a703531,0xb21803b2,0x00000000,0x00000000}},	//   чләр, xtæn, --, --, 
   {{0x44316191,0x9f9c0cad,0xc2ec009e,0x59a4278e}},	//   _riy_, _díè_, _টুনি_, _गोकर, 
   {{0x44316192,0x44896193,0xd83802e2,0xadf80bc0}},	//   _siy_, абон_, _prčt_, ्विन_, 
   {{0x4430047e,0x7dd0003b,0xb2183bb4,0x00000000}},	//   _piy_, _bæsj, ttæn, --, 
   {{0xd874168d,0x443001d5,0x7e740309,0xd7f84109}},	//   _رامب, _qiy_, yuyp, _луч_, 
   {{0xdb016194,0xb21886ee,0x44316195,0x27e8033f}},	//   _ramë, rtæn, _viy_, ękną_, 
   {{0xb2186964,0xdb000066,0x44316196,0x3d180073}},	//   stæn, _damè, _wiy_, _भरले_, 
   {{0x4128048a,0x7f58147e,0x44300113,0xdb000240}},	//   рово_, ијат_, _tiy_, _pamë, 
   {{0x272c0793,0x330801f2,0x7e740784,0x388c03b9}},	//   _gönü_, ụbọ_, tuyp, _hərc_, 
   {{0x63a40851,0xdb00020c,0xfe70007b,0xf8b47fd5}},	// [24340] _iain, _gamè, بدأ_, _अप्प, 
   {{0x63a56197,0x7e740784,0x1b1000cc,0x638402d2}},	//   _hain, ruyp, ়েডে_, bínó, 
   {{0x272c0342,0x957c033f,0x7c6401b9,0x388c03b9}},	//   _yönü_, miąt, تاذل, _mərc_, 
   {{0x63a56198,0x7e753b6d,0x3078008f,0xdbd402d2}},	//   _jain, puyp, _דאטנ, _búál, 
   {{0x63a46351,0xdb016199,0x228401ed,0x7e740309}},	//   _main, _kamé, nök_, quyp, 
   {{0x63a5619a,0x7c64030f,0x7dd001bf,0x00000000}},	//   _lain, _وازل, _mæsk, --, 
   {{0x7c3c010a,0xdb00004e,0x63a45798,0x7dd0005c}},	//   qqpr, _mamé, _oain, _læsk, 
   {{0x3688013e,0x2285619b,0x9f40030a,0x81c000cc}},	//   асон_, kök_, oniñ_, ্ফি_, 
   {{0x9f400dd4,0x388c00ac,0xd83802e2,0x7bc1619c}},	//   nniñ_, _qərb_, _prčs_, mjou, 
   {{0x63a5619d,0xdb0059cc,0xf48403c5,0xd1bc0023}},	//   _aain, _ramè, оумн, ሰታት_, 
   {{0x63a5619e,0x776406bb,0x388c00ac,0x7ae001d3}},	//   _bain, _дълж, _dərc_, lzot, 
   {{0x7bc0c76a,0xdb0000f2,0x7988015d,0xe8500c4f}},	//   njou, _pamè, lffw, _آنند, 
   {{0x7ae1619f,0x63a561a0,0xdb0002ea,0x9f9c0248}},	//   nzot, _dain, _bamé, _gíé_, 
   {{0x63a40618,0xdb0020ef,0x7ae0006f,0xa1586dac}},	//   _eain, _camé, izot, жару_, 
   {{0xdb00020c,0x29c80158,0xe5e404fb,0x63a4d153}},	//   _damé, _køar_, _بزنی, _fain, 
   {{0xdb0000f2,0x63a42e78,0xc4e4031c,0x7bc161a1}},	//   _tamè, _gain, _སྟྲཱ, jjou, 
   {{0x7bc161a2,0xdb000036,0x7dd0032e,0x93c800e5}},	// [24350] djou, _famé, _gæsk, _ناکہ_, 
   {{0x63a561a3,0xdd946f78,0xdb000098,0xe8dc0208}},	//   _zain, мауы, _gamé, _chớm_, 
   {{0xac0804a9,0x63a561a4,0x7bc0002d,0x957c0153}},	//   ۇرچە_, _yain, fjou, liąs, 
   {{0x0f34168d,0x7ae00200,0x63a403b9,0xa4f800df}},	//   _رکرد, fzot, _xain, סלאט, 
   {{0xdef8fba5,0x89d400d4,0x957c0064,0x00000000}},	//   _дыр_, зійш, niąs, --, 
   {{0x1a6807d6,0xdb0000e8,0xef1c0166,0x2ba804e4}},	//   زیمی_, _xamé, _izü_, _घोरा, 
   {{0x29c80158,0x7ae00109,0x228401d3,0x6e38002b}},	//   _bøar_, azot, zök_, _ũubh, 
   {{0x61c86ace,0x9f4009cc,0x228400e5,0x00000000}},	//   _रक्ष, nnið_, yök_, --, 
   {{0x63a46351,0x7ae0033f,0x29840166,0x00000000}},	//   _rain, czot, _мыжг, --, 
   {{0x63a427f8,0x7dd002d2,0x228400e5,0x195801af}},	//   _sain, _ræsk, vök_, _мауы_, 
   {{0xb218019b,0x63a561a5,0xdb007dec,0xda0800f1}},	//   rtæl, _pain, _ramé, _بيله_, 
   {{0x2284628e,0x69c009a8,0xdb01074c,0x03a4b27b}},	//   tök_, ljne, _samé, чимо, 
   {{0x63a561a6,0xdb008851,0xb21801bf,0x388c03b9}},	//   _vain, _pamé, ptæl, _tərc_, 
   {{0x63a561a7,0x7dd05b47,0x7bc0030d,0x228401ed}},	//   _wain, _væsk, zjou, rök_, 
   {{0x228561a8,0x7ae06933,0x9f40008c,0x68e00399}},	//   sök_, zzot, fnið_, nznd, 
   {{0x63a561a9,0x6d4401d9,0x228455e1,0x7c38004a}},	//   _uain, _afja, pök_, _étri, 
   {{0xdb006bf8,0xafe161aa,0x09e004c5,0xee34b09c}},	// [24360] _tamé, хотл, _বদনা, зну_, 
   {{0x06c400bd,0xada161ab,0x00000000,0x00000000}},	//   এনপি, наул, --, --, 
   {{0x315404ac,0x7bc161ac,0x00000000,0x00000000}},	//   _מיין_, tjou, --, --, 
   {{0x7ae08e47,0x7bc00129,0x00000000,0x00000000}},	//   tzot, ujou, --, --, 
   {{0x0ba80447,0x7bc0049b,0x798800d2,0x1cb00327}},	//   تالى_, rjou, tffw, ནའང_, 
   {{0x7bc161ad,0xd91401c0,0x00000000,0x00000000}},	//   sjou, мдлы, --, --, 
   {{0xed5561ae,0xa96407b5,0x5fe005d7,0xec740640}},	//   _хос_, чија_, _नताल, _нпр_, 
   {{0xf0900375,0x6cf80375,0xacf8011a,0xac941291}},	//   גנה_, _הפלס, _ההלכ, _عنقا_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x95800092,0x94d41318,0x59a400cd,0xe9d40395}},	//   ናቀቁን_, дооц, _गोचर, _еку_, 
   {{0x395cbbd7,0x539800c9,0x61fc0175,0x00000000}},	//   _iets_, овня_, dnrl, --, 
   {{0x395d61af,0x00000000,0x00000000,0x00000000}},	//   _hets_, --, --, --, 
   {{0x9f400579,0x395c020b,0xdb0009c2,0xf6280212}},	//   vnið_, _kets_, _inmó, _ліки_, 
   {{0x395d5593,0xa4100316,0x00000000,0x00000000}},	//   _jets_, ětší_, --, --, 
   {{0x395d61b0,0x09e002f5,0x6d440472,0x9f400ad9}},	//   _mets_, _বদমা, _rfja, tnið_, 
   {{0x7d18f2bc,0x395d61b1,0x69c00158,0x6d4402d2}},	//   _útsy, _lets_, zjne, _sfja, 
   {{0x9f4026b8,0x69c00034,0x63b80419,0x00000000}},	// [24370] rnið_, yjne, šaní, --, 
   {{0x395c1590,0x918000cf,0x6e9050e5,0x9f401427}},	//   _nets_, _جۇسۇ, миғу, snið_, 
   {{0xdb00025a,0x9f9c01e1,0x9f401427,0x98bc00c0}},	//   _bamï, _kíì_, pnið_, davį_, 
   {{0x395c0493,0x00000000,0x00000000,0x00000000}},	//   _aets_, --, --, --, 
   {{0x395cb47d,0x5f840046,0x9f9c0241,0x160c1b51}},	//   _bets_, _سۇلە, _míì_, सकार_, 
   {{0x6d40afe3,0x490401d5,0x88d80124,0x00000000}},	//   ınas, ووشق, жьит_, --, 
   {{0x395d61b2,0xf89003b7,0x603c02e2,0x8c880166}},	//   _dets_, вајќ, _pčmi, _фәза_, 
   {{0xb21801a8,0x4648014b,0x9f9c01e1,0x7dd008ce}},	//   ftæk, озин_, _níì_, _ræsi, 
   {{0x395c00f7,0x54cc0131,0x057401e2,0x3ea00051}},	//   _fets_, ﺗﻜﯜﺯ, وادد, _xskt_, 
   {{0xdcfc0327,0x395c0c30,0xdb100798,0x04447160}},	//   _harġ, _gets_, _éfác, меон, 
   {{0x316056c0,0x603d61b3,0x9f9c0241,0x58d4084c}},	//   dajz_, _kōme, _bíì_, _пофт, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdcfc0135,0x00000000,0x00000000,0x00000000}},	//   _marġ, --, --, --, 
   {{0x603c0270,0x2b5c0165,0x36a00131,0x00000000}},	//   _lōme, _leuc_, _شەپق, --, 
   {{0x2fc800db,0x81c0009e,0x00000000,0x00000000}},	//   _bocg_, ্ফল_, --, --, 
   {{0x603c003a,0xee3c00a2,0xea9c00cd,0x9f4001f4}},	//   _nōme, _buý_, _guṇa_, hniö_, 
   {{0x2fc8011c,0xdef0044e,0x03240139,0x00000000}},	// [24380] _docg_, _ቀርኒ_, _юдин, --, 
   {{0x25a40100,0xee3c00a2,0x00000000,0x00000000}},	//   _janl_, _duý_, --, --, 
   {{0x395d61b4,0x2fd0145e,0xd20000d1,0x22400037}},	//   _rets_, üngö_, _сүрк, _huik_, 
   {{0x6d400598,0x395c9bdc,0x224001f5,0xaef80165}},	//   ñnar, _sets_, _kuik_, _seùe, 
   {{0x3ea00227,0xdb010ce1,0x23604fa5,0x2b5c0165}},	//   _uskt_, _anmò, _meij_, _deuc_, 
   {{0x2360002d,0xf84961b5,0xee3402e8,0x00000000}},	//   _leij_, очий_, _оня_, --, 
   {{0x224161b6,0x19c40032,0x636c0139,0xfcd40451}},	//   _luik_, _үҙег, _könı, _غيرج, 
   {{0x98fc0115,0x7b6401d9,0x395c017a,0xb21801a8}},	//   _neĉe, _زارٕ, _wets_, ttæk, 
   {{0x963561b7,0x224029ef,0x7e74002d,0x670401c0}},	//   нниц, _nuik_, nryp, дээг_, 
   {{0xb21800fc,0x25a401ab,0x9f9c0241,0x93440133}},	//   rtæk, _canl_, _síì_, کردۆ, 
   {{0xdb005e94,0x23600097,0x25a40100,0xb21801a8}},	//   _mamí, _beij_, _danl_, stæk, 
   {{0x23600007,0x2240d2aa,0x98fc0115,0x9f9c01e1}},	//   _ceij_, _buik_, _ceĉe, _bíí_, 
   {{0xdb00025a,0xc76561b8,0x98fc01e4,0x228561b9}},	//   _hamâ, _سانى, _deĉe, кург, 
   {{0xdb0161ba,0x22401af3,0xe5b002dd,0x7e745522}},	//   _kamâ, _duik_, _айшы, dryp, 
   {{0xa5d41365,0x9f405d43,0xe8dc01fb,0x7e7408c8}},	//   _زبور_, chië_, _kiềm_, eryp, 
   {{0x5f9473e3,0x23600097,0x31e401ec,0x00000000}},	//   кист, _geij_, _ﺍﺑﯩﻜ, --, 
   {{0xee3c07ae,0x7e7561bb,0xceb85183,0x7dd002d2}},	// [24390] _quý_, gryp, чән_, _læsu, 
   {{0xf3fc0004,0xd5b800e2,0xe8dc0208,0x00000000}},	//   lnã_, mmās_, _liềm_, --, 
   {{0x224001b8,0x2b5c030a,0xc154011a,0x7e7402d0}},	//   _zuik_, _peuc_, _אשתו_, aryp, 
   {{0xe8dc0016,0xf3fc0004,0xee3d07d1,0x9f9c01e1}},	//   _niềm_, nnã_, _tuý_, _yíí_, 
   {{0xdb0161bc,0xaa6561bd,0x5e580014,0x00000000}},	//   _famí, фтек, _ٲلِس_, --, 
   {{0x92a8068f,0x8afc00bc,0xe8dc0051,0x00000000}},	//   _załó, _neře, _chởm_, --, 
   {{0x2b5c0165,0xdcfc031c,0x9f4001f4,0x00000000}},	//   _teuc_, _tarġ, rniö_, --, 
   {{0xf3fc0004,0x25a4007f,0xdb0000bc,0x998c0010}},	//   jnã_, _sanl_, _zamí, _vidš_, 
   {{0xf3fc0004,0x5b1401c0,0x3ae00374,0x98c400e2}},	//   dnã_, _амтт, tōpū_, ētām_, 
   {{0x22400926,0xc0c002d3,0x00000000,0x00000000}},	//   _ruik_, _ትደሊ_, --, --, 
   {{0xd7c800b2,0x23600086,0xa8a401b9,0x3ae00374}},	//   _ڪونه_, _peij_, _юрак, rōpū_, 
   {{0xf3fc0589,0x7dd00008,0x224005e4,0x7e7561be}},	//   gnã_, _hæst, _puik_, yryp, 
   {{0x45d415a3,0x2bc4b5f0,0x27fc5a7f,0x25a4007f}},	//   _подс, _रचना, mnun_, _tanl_, 
   {{0xf3fc0004,0x35a00510,0x25a40789,0x9f9cdd18}},	//   anã_, _башг, _uanl_, _víí_, 
   {{0xdb0161bf,0xef1c0205,0x27fc03b9,0x00000000}},	//   _ramí, _obüs_, onun_, --, 
   {{0x7dd0019b,0x27fd61c0,0xd5b80a28,0x7e7561c1}},	//   _læst, nnun_, smāt_, tryp, 
   {{0xdb0006ed,0x00000000,0x00000000,0x00000000}},	// [243a0] _mamã, --, --, --, 
   {{0x7dd161c2,0xef1c05d5,0xfce41b0a,0xe9fc0208}},	//   _næst, _abüs_, нозо, _duẫn_, 
   {{0x27fd61c3,0x5ec8015b,0xa2a436c7,0x5fa801d5}},	//   knun_, _রেখে, _चैत्, _قندۀ_, 
   {{0xab8161c4,0xe724007b,0x7dd003b2,0xdb00054e}},	//   гушк, _مص_, _ræsu, _ramâ, 
   {{0x200161c5,0xfaf0143e,0x7dd0072b,0x27fc03b2}},	//   mnii_, دثا_, _bæst, dnun_, 
   {{0x603c007f,0xb3380798,0xdb00054e,0x20000de2}},	//   _fčmt, meçe, _pamâ, lnii_, 
   {{0xa81561c6,0x27fc008c,0x200161c5,0xf3fc0589}},	//   کتور_, fnun_, onii_, ynã_, 
   {{0x200161c7,0x27fd61c8,0xaef808e7,0xfaa47ecf}},	//   nnii_, gnun_, _idùr, _пабо, 
   {{0x200161c9,0xf0a80086,0xf3fc0589,0xd5b000c6}},	//   inii_, _kiàô_, vnã_, لفة_, 
   {{0x7dd0019b,0x27fc0589,0xe70405d9,0x79280257}},	//   _gæst, anun_, رڪنن_, _ትዕቢት, 
   {{0x8afc0316,0xe8dc001e,0xf3fc0656,0x38586eb7}},	//   _veře, _tiềm_, tnã_, _رشاد_, 
   {{0x27fc029f,0x9f9c0248,0xdef80023,0xb338008e}},	//   cnun_, _níà_, ፋልን_, keçe, 
   {{0xf3fc0c67,0x00000000,0x00000000,0x00000000}},	//   rnã_, --, --, --, 
   {{0x200161ca,0xf3fc0589,0xd5b80f40,0xdb000561}},	//   enii_, snã_, rmās_, _mamà, 
   {{0x9f9c0248,0x20000e14,0x7dd000b5,0x64a016a4}},	//   _bíà_, fnii_, _læss, _баја, 
   {{0xe8dc0016,0x2000026c,0xee3c00a2,0xace800d1}},	//   _hiểm_, gnii_, _asýa_, ۋرال_, 
   {{0xe8dc07ae,0xd838007f,0xdb0005da,0xdef80184}},	// [243b0] _kiểm_, _asčk_, _namà, ныф_, 
   {{0xd9047fce,0x20000a4d,0xee3c0d12,0xb3381ea0}},	//   _هی_, anii_, _brýr_, geçe, 
   {{0x764161cb,0x2000022f,0x9f9c01e1,0xdef800fd}},	//   _luoy, bnii_, _fíà_, _җыя_, 
   {{0x2000058a,0x7dd008a5,0x4a74008e,0x00000000}},	//   cnii_, _sæst, выкт, --, 
   {{0xdb00067c,0xdb540209,0x00000000,0x00000000}},	//   _camà, увчы, --, --, 
   {{0x603c0374,0xdb00f153,0x66e401e1,0x00000000}},	//   _hōma, _damà, _lèké, --, 
   {{0x07a561cc,0x603d61cd,0x27fd61ce,0x00000000}},	//   вайн, _kōma, tnun_, --, 
   {{0x7640136c,0x9f9c0248,0x9f4000e8,0x27fd61cf}},	//   _buoy, _kíá_, thié_, unun_, 
   {{0x7760e5b5,0x97c40efb,0x7c381a44,0x27fd61d0}},	//   _deox, اتىم, _ètra, rnun_, 
   {{0x7640022e,0x56440023,0x98c40352,0x0448004e}},	//   _duoy, _ከነኽብ, тсәл, мпок_, 
   {{0xd87424e0,0xe7080b28,0x200161d1,0xdb0001e7}},	//   _مانب, _کتان_, ynii_, _iamá, 
   {{0x603c0100,0x9f4006af,0x260c0073,0xd5b800ef}},	//   _nōma, phié_, डवही_, glāb_, 
   {{0x76400198,0xaca0063f,0x9f9c0241,0x00000000}},	//   _guoy, faịd, _ríà_, --, 
   {{0xdb0095fc,0x412961d2,0x04b40075,0x20000221}},	//   _jamá, дого_, _асия, wnii_, 
   {{0xdb0161d3,0x65600b21,0x200161d4,0x65c000fb}},	//   _mamá, _ienh, tnii_, _абҙа, 
   {{0x644161d5,0x200161d6,0x656161d7,0xdb000af2}},	//   _iuni, unii_, _henh, _lamá, 
   {{0x644161d8,0x20009dfd,0x656161d9,0xaef80165}},	// [243c0] _huni, rnii_, _kenh, _peùa, 
   {{0x9f9c0241,0xdb0002fb,0x20000ba7,0x6e9001b9}},	//   _díá_, _namá, snii_, شلما, 
   {{0x656161da,0x644161db,0xada01d5a,0x603c02e2}},	//   _menh, _juni, рахл, _fōma, 
   {{0x656161dc,0x64401be9,0x61442544,0x20000e14}},	//   _lenh, _muni, _جىگە, qnii_, 
   {{0x644161dd,0x6a8001c0,0xab7002dd,0xba280d23}},	//   _luni, илца, ргіш, وستم_, 
   {{0x656161de,0xee3c06ea,0xb21800b5,0x644161df}},	//   _nenh, _trýr_, stæv, _ouni, 
   {{0x2ca4037e,0xdb0000c6,0xd8b40722,0xf804094f}},	//   ændt_, _damá, امبخ, кчин, 
   {{0x65600036,0xdb0005da,0x00000000,0x00000000}},	//   _aenh, _tamà, --, --, 
   {{0xa920052f,0x644161e0,0x2ba84da4,0x76400165}},	//   лдәл, _auni, _घोटा, _quoy, 
   {{0x644161e1,0x65600368,0xdb0c00c5,0xe8dc0208}},	//   _buni, _cenh, öhõi, _chồm_, 
   {{0x644161e2,0x656161e3,0xddc46b48,0x778400f3}},	//   _cuni, _denh, križ, _алез, 
   {{0x644161e4,0x656161e5,0x48700ec9,0x59740220}},	//   _duni, _eenh, _اگوس, _шығу, 
   {{0x6440013b,0x656161e6,0x43b00032,0xddc40171}},	//   _euni, _fenh, сҡыр, driž, 
   {{0x656161e7,0xe60d61e8,0xdb000077,0x603c02b5}},	//   _genh, _وشو_, _xamá, _rōma, 
   {{0x644161e9,0x64c000aa,0xd1b0036b,0xe9fc004d}},	//   _guni, _نيول, لیکک, _quẩn_, 
   {{0x65600107,0x603c1e2b,0xddc401a6,0xef300124}},	//   _zenh, _pōma, griž, иҭны, 
   {{0x644161ea,0x656161eb,0xe2c8004b,0x388c0213}},	// [243d0] _zuni, _yenh, _لويو_, _bərk_, 
   {{0xf41c99ac,0x2d8561ec,0xdb0001bf,0x5d540212}},	//   llä_, üne_, _kamæ, икут, 
   {{0x64400005,0x32000109,0x388c00ac,0xddc404a7}},	//   _xuni, mnjy_, _dərk_, briž, 
   {{0x2d84068f,0xdf38049e,0x603d19e9,0xdb0161ed}},	//   żne_, ركەت_, _tōma, _samá, 
   {{0xdb00012c,0x4af83c5b,0x00000000,0x00000000}},	//   _pamá, رکرد_, --, --, 
   {{0x3ea40120,0xe8dc0051,0x09c400c7,0x00000000}},	//   çote_, _liễm_, ыӡбо, --, 
   {{0x6560914f,0xf41c0309,0x48e000eb,0x00000000}},	//   _renh, klä_, যপ্র, --, 
   {{0x656161ee,0x644161ef,0x1bd400f5,0x068561f0}},	//   _senh, _runi, _кося, ггин, 
   {{0x656161f1,0xdb0001ed,0xba940451,0xc79402dd}},	//   _penh, _tamá, _مالڪ, _ұрлы, 
   {{0x644161f2,0x65600477,0x00000000,0x00000000}},	//   _puni, _qenh, --, --, 
   {{0x65613f23,0x64400986,0x7dd002d2,0x588400c0}},	//   _venh, _quni, _mæsp, _выча, 
   {{0x644023e0,0x656161f3,0x064c001f,0x46b42e0b}},	//   _vuni, _wenh, _ቀጣይነ, _محتس, 
   {{0x656161f4,0x6440016b,0xe8dc01fb,0x00000000}},	//   _tenh, _wuni, _diễm_, --, 
   {{0x644161f5,0x32400032,0x3170007c,0x1b1000cc}},	//   _tuni, серг, _cdxz_, ়েকে_, 
   {{0xdb0041ba,0xb21804ce,0xf41c0004,0x644161f6}},	//   _unmö, kræf, blä_, _uuni, 
   {{0xbea4036b,0x3ea401d5,0x80243c5a,0x00000000}},	//   лабк, либг, ارسم, --, 
   {{0xb33803e0,0x00000000,0x00000000,0x00000000}},	// [243e0] reçc, --, --, --, 
   {{0xe058034c,0xef1561f7,0xcf2400c6,0x2244219b}},	//   _لیست_, уму_, شرقي, ímku_, 
   {{0xb33803b7,0xb1400276,0xadf801ad,0xdb00294f}},	//   meça, _ынэл, ्वजन_, _kamç, 
   {{0x8afc012c,0xb3380798,0xafe0010b,0xb219390f}},	//   _seřa, leça, _гоюл, stæt, 
   {{0x388c00ac,0xd838007f,0x8b64036b,0xdac400fb}},	//   _tərk_, _trčz_, شانم, шҡай, 
   {{0x603c02b5,0xb33800d8,0x388c06be,0x00000000}},	//   _kōmo, neça, _həri_, --, 
   {{0x7c380395,0xf41c5d8a,0xfce41553,0x9f400165}},	//   _ètro, ylä_, _сово, liiñ_, 
   {{0xb2180ac8,0x603c04fe,0xd83801a6,0xdd9001d3}},	//   ntær, _mōmo, _opče_, _دوڑ_, 
   {{0xeef4008f,0x00000000,0x00000000,0x00000000}},	//   ָמיר_, --, --, --, 
   {{0xb5a561f8,0xb338b7c6,0x388c0213,0x0ae8d593}},	//   урий, jeça, _ləri_, _شرقي_, 
   {{0x1ccc031c,0xf1c008df,0x00000000,0x00000000}},	//   ླའི_, शासन, --, --, 
   {{0x53343804,0xf744570a,0x00000000,0x00000000}},	//   иент, _седо, --, --, 
   {{0xddc4025c,0x388c06be,0x6d40022e,0x2810009a}},	//   friż, _sərh_, оnal, _اونس, 
   {{0xb2180158,0xe7344f5c,0x46b000bc,0x068c0150}},	//   etær, _сеч_, जिरह, _ﻛﻪﻣﯩ, 
   {{0xe6000014,0x98fc01e4,0x388c0213,0x386c03b2}},	//   _دِوَ, _meĉo, _bəri_, nsfr_, 
   {{0x601811ed,0xdb0161f9,0x2054e846,0x00000000}},	//   гося_, _kamä, стёр, --, 
   {{0xb33806ed,0x388c00ac,0x00000000,0x00000000}},	// [243f0] beça, _dəri_, --, --, 
   {{0x9df80414,0xefd00092,0xad240b24,0xb218032e}},	//   гнут_, የቂያ_, هراو, dræg, 
   {{0xdd9439f6,0xdb00aba8,0x2d8c045f,0xb21801bf}},	//   сахы, _lamä, ęge_, træf, 
   {{0x6e400133,0xb21808a5,0x00000000,0x00000000}},	//   _هۆرم, fræg, --, --, 
   {{0xe8dc0016,0xdb0161fa,0x8ba401f9,0x00000000}},	//   _kiệm_, _namä, _ऐसीअ, --, 
   {{0x9f400174,0x388c03e3,0x00000000,0x00000000}},	//   liið_, _zəri_, --, --, 
   {{0x48e402e8,0x48c40124,0x00000000,0x00000000}},	//   ройв, шәаа, --, --, 
   {{0x9d1818d9,0xddc4054e,0xe8dc0051,0x0ce00bae}},	//   _сост_, psiţ, _liệm_, पनीम, 
   {{0xda7806bb,0x77c401c0,0x06081422,0x98ac0790}},	//   _бях_, рлыг_, кник_, _dedı_, 
   {{0x45d4295e,0xe8dc0016,0x5a349a41,0x068c0ef6}},	//   рцит, _niệm_, _гнут, _ﻛﻪﻧﯩ, 
   {{0x99d5212c,0x67e405c7,0xddc40153,0x8afc01ef}},	//   _اتقا, _añje, nsiš, _keřo, 
   {{0xdb005043,0xb21808a5,0x00000000,0x00000000}},	//   _qamç, hræd, --, --, 
   {{0xe9fc07ae,0xdb000724,0xb33800d8,0xd1f00092}},	//   _luận_, _gamä, teça, _ቃሎች_, 
   {{0x70b0007a,0xf484158b,0x388c06be,0xf5e400db}},	//   ुमूल, دایی, _səri_, _ۅتۉۋ, 
   {{0xb33961fb,0x2f5005db,0x437561fc,0xe8dc004d}},	//   reça, _ụmụ_, _купт, _diệm_, 
   {{0x2e2c05d5,0x660c01c7,0xafe01d39,0xf4840133}},	//   nüff_, éckf, оосл, _ئاوی, 
  
   {{0xddc4003d,0xb3380120,0xb21812ed,0x05a823e9}},	// [24400] priż, peça, rtær, _कसाब, 
   {{0x957c068f,0xf3f00135,0x603ccf1c,0xb2187246}},	//   wiąz, _བཏོད_, _tōmo, stær, 
   {{0x7b64a2ed,0x61fca226,0x0d982ff2,0x7178011a}},	//   атле, mirl, ытты_, _בניס, 
   {{0x61fc708d,0x60dc7ba4,0x00000000,0x00000000}},	//   lirl, myrm, --, --, 
   {{0x61fc0597,0xb218005c,0x00000000,0x00000000}},	//   oirl, bræd, --, --, 
   {{0xed54b3ba,0x61fd61fd,0x388c06be,0xb338013d}},	//   _вор_, nirl, _mərv_, keçn, 
   {{0xdb00007c,0x00000000,0x00000000,0x00000000}},	//   _samä, --, --, --, 
   {{0x61fc54ee,0xdb0001a2,0xb21800b5,0xddc40064}},	//   hirl, _pamä, præg, prių, 
   {{0x61fc54de,0x7c20020c,0x60dc722a,0xf6c80139}},	//   kirl, mlor, hyrm, тыйк_, 
   {{0x7c2161fe,0x60dc0649,0x61fd61ff,0x4420000f}},	//   llor, kyrm, jirl, elk_, 
   {{0xb21801bf,0xb4c0043e,0xb3380139,0xc95401af}},	//   dtæp, ृहे_, geçn, _ытты, 
   {{0x7c20bb91,0xf364797f,0x60dc010b,0x00000000}},	//   nlor, штон, dyrm, --, 
   {{0x61fd6200,0xc7e40137,0xd58801af,0x00000000}},	//   firl, _دۉين_, _йәнл_, --, 
   {{0x7c216201,0x61fd6202,0xd9f82b3d,0x78b800b8}},	//   hlor, girl, ्चित_, _krtv, 
   {{0x7c216203,0x44200175,0x44040107,0x60dc010b}},	//   klor, blk_, рчӯб, gyrm, 
   {{0x4420010a,0xc0c8001f,0x61fd6204,0x7c2000df}},	//   clk_, _አፍሮ_, airl, jlor, 
   {{0x61fc1934,0xb3380261,0xb2196205,0xd9f839de}},	// [24410] birl, meço, træd, ्चात_, 
   {{0x7c216206,0x61fd6207,0xf1a83c5b,0xb338a547}},	//   elor, cirl, _شاخه_, leço, 
   {{0xe9fc0016,0xb21812ed,0x2bc800f3,0x60dc00a2}},	//   _quận_, rræd, кудо_, cyrm, 
   {{0x1b1003f4,0x7c208527,0x799802d0,0xb33800db}},	//   ়েছে_, glor, _abtw, neço, 
   {{0xe1f01e7c,0x9f40026c,0x78b96208,0xb218005c}},	//   _رسی_, chià_, _artv, præd, 
   {{0xa258025f,0x78b863e0,0x7c200393,0xbf3404ae}},	//   סבוק_, _brtv, alor, _לארץ_, 
   {{0x78b8172e,0x4420002d,0xab840024,0x00000000}},	//   _crtv, ylk_, _вузк, --, 
   {{0x61fd6209,0x1a68397d,0x98fc00df,0x8afc0118}},	//   zirl, _چینی_, _keĉj, _heřm, 
   {{0x61fc07b3,0x78b80158,0xdcfc0194,0x1a68e55d}},	//   yirl, _ertv, _sarĸ, _نینی_, 
   {{0xf3f00d46,0xc48455a2,0xf5e47a71,0x6ab80248}},	//   _བཏུད_, блок, ймыл_, _iruf, 
   {{0x61fd620a,0x27b00075,0x388c06be,0x036801f4}},	//   virl, _дәпс, _sərv_, линк_, 
   {{0xd7f87390,0x986401ed,0xd7c8004b,0x6ab808a5}},	//   _куч_, _بیٹے_, _پوهه_, _kruf, 
   {{0x61fd620b,0x6b99620c,0x78b808ad,0x44200194}},	//   tirl, _mbug, _zrtv, rlk_, 
   {{0xe1f80364,0x6ab8009f,0x61fc00ae,0xb3380205}},	//   рҳо_, _mruf, uirl, meçl, 
   {{0x7c21620d,0x61fd620e,0xea9c0084,0x6b99620f}},	//   ylor, rirl, _muṱa_, _obug, 
   {{0x037905ca,0x61fd6210,0x98fc01e4,0x6ab87b8a}},	//   _صحبت_, sirl, _beĉj, _oruf, 
   {{0x6280066d,0xf4100302,0x8284007b,0x68ec03e3}},	// [24420] ámod, _מפה_, _اجعل, _əcda, 
   {{0x6b996211,0xb218037e,0x01a83e4f,0x61fd6212}},	//   _abug, træe, _скок_, qirl, 
   {{0x6b980a49,0x6ab96213,0xb5f8008f,0x00000000}},	//   _bbug, _aruf, נלעכ, --, 
   {{0xb0980375,0x388c06be,0x9f9c08a5,0x7f18003b}},	//   _גיטר, _mərt_, _líú_, _бігу_, 
   {{0x6ab804cc,0x7050030f,0x2c093c28,0x8e74a68e}},	//   _cruf, _ونیا, دعلی_, _мурч, 
   {{0x6b996214,0x6ab802c1,0x7c200718,0xce340014}},	//   _ebug, _druf, slor, _ووَک, 
   {{0x7c201be8,0x6728036e,0x00000000,0x00000000}},	//   plor, _azgj, --, --, 
   {{0x6b98025a,0x5678011c,0x6cf4010a,0x96f80395}},	//   _gbug, абия_, _уесĕ, иейт_, 
   {{0xe9fc07ae,0xe8f44701,0x6ab8a4fd,0xdb0001e1}},	//   _quản_, илә_, _gruf, _lamú, 
   {{0x54980006,0xd6a40150,0x00000000,0x00000000}},	//   авоў_, _ﻋﺴﻜﺭ_, --, --, 
   {{0x98ac0051,0x2db40677,0x00000000,0x00000000}},	//   _tgdđ_, זלין_, --, --, 
   {{0xf77001d3,0xfd4c0055,0xb44c0092,0x00000000}},	//   _راؤ_, _vahṝ, _አደረጉ, --, 
   {{0xb3380261,0x998c01fa,0x46601075,0x00000000}},	//   reço, _midž_, _قۇيق, --, 
   {{0xe6740302,0x79880369,0xdd0c0055,0x55580107}},	//   _פתוח_, ngfw, _iųņa, _такя_, 
   {{0x660ca62c,0x2d9c0115,0xb21800b5,0xb33800d8}},	//   écke, _ĝue_, træb, peço, 
   {{0x98fc01e4,0x2cbc0165,0x317c03e0,0x00000000}},	//   _peĉj, _čud_, şuz_, --, 
   {{0xb8c96215,0xe3b02966,0x200d6216,0x9f340046}},	// [24430] _བར_, _سري_, édia_, зеті, 
   {{0x6ab96217,0xf3fc0589,0x6b996218,0x271401fb}},	//   _rruf, liã_, _sbug, ểng_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4fc00c50,0x6ab96219,0xf3fc0589,0x1d340212}},	//   _تەرە, _pruf, niã_, їнця, 
   {{0x5e847c6c,0xb33806be,0xd5b800de,0x00000000}},	//   _нурз, keçm, elām_, --, 
   {{0x6ce43334,0x4878034b,0x3c2c00e4,0xf3fc0051}},	//   _лібе, асия_, výve_, hiã_, 
   {{0x67e5621a,0xdd0c0055,0x6d44035a,0xd5b80171}},	//   _añja, _aųņa, _igja, glām_, 
   {{0x6ab9621b,0x6b982dab,0x86980261,0x87b801ee}},	//   _truf, _ubug, атот_, рукт_, 
   {{0x6ab801aa,0x388c00ac,0xb7d40472,0x2ab401ee}},	//   _uruf, _sərt_, تويا_, _ыңды_, 
   {{0xb33805d2,0xdbd408ce,0x28681d39,0x388c03b9}},	//   reçl, _húðl, _брдо_, _pərt_, 
   {{0x668000dd,0xe2790a6d,0x388c00ac,0x744402d3}},	//   _کیخل, әшмә_, _dərs_, _ከተግብ, 
   {{0xf3fc0004,0x68e81432,0x660c01c7,0x3c2c00e4}},	//   giã_, ımdı, éckb, pýve_, 
   {{0x27fd621c,0xdb0001a8,0x00000000,0x00000000}},	//   miun_, _samú, --, --, 
   {{0x6d44069c,0x27fd621d,0x8234007b,0x388c03b9}},	//   _ngja, liun_, ترجا, _tərt_, 
   {{0x603c02b5,0xd61800dd,0xd5b8005f,0xc0e4082d}},	//   _hōmi, _اتنا_, klāj_, цовк, 
   {{0x603d4aac,0x27fd621e,0xf3fd2c7b,0x6d4402d0}},	//   _kōmi, niun_, ciã_, _agja, 
   {{0x6d44009a,0x7411621f,0x62800219,0x823400e3}},	// [24440] _bgja, _تويا, šmob, _ورخا, 
   {{0x27fc0c86,0xada00166,0xbbe007b6,0xa2e401d5}},	//   hiun_, маул, पस्क, _моқд, 
   {{0x603c0421,0xed5405f5,0xbca400d1,0xbca96220}},	//   _lōmi, цох_, تماي, рвеж_, 
   {{0x79880369,0x4430017a,0x27fc003e,0x00000000}},	//   wgfw, _jhy_, jiun_, --, 
   {{0x1958b064,0x27fd6221,0x44316222,0xa920219b}},	//   балы_, diun_, _mhy_, ížno, 
   {{0x6d440162,0x00000000,0x00000000,0x00000000}},	//   _ggja, --, --, --, 
   {{0xc0c0001f,0x9cd40451,0x00000000,0x00000000}},	//   ስቴሩ_, _عمرڪ, --, --, 
   {{0x27fc060a,0x6d4402d3,0x3ea005b1,0xf2dc0548}},	//   giun_, _zgja, _kpkt_, yyâ_, 
   {{0x8b180108,0xdb24007c,0x00000000,0x00000000}},	//   _люфт_, ösäk, --, --, 
   {{0x44301311,0xd8380010,0x00000000,0x00000000}},	//   _ahy_, _esčp_, --, --, 
   {{0xf3fd6223,0xb7d80014,0x00000000,0x00000000}},	//   tiã_, _پوشا_, --, --, 
   {{0x44316224,0x27fd6225,0x00000000,0x00000000}},	//   _chy_, ciun_, --, --, 
   {{0x67e42e95,0xf3fc0004,0x443000b8,0xd7f80356}},	//   _uñja, riã_, _dhy_, _ovăz_, 
   {{0xf2dc0109,0x443000b8,0x1ad803d4,0x06640214}},	//   ryâ_, _ehy_, _দেৱা, _راهپ, 
   {{0xf3fcb3a4,0x6ad002f5,0x33b000d1,0xa194074d}},	//   piã_, থনযো, _قەدر, ьарч, 
   {{0xf2dc025a,0x44300055,0xdb0001bf,0x00000000}},	//   pyâ_, _ghy_, _famø, --, 
   {{0x98fc00df,0xd04806be,0x00000000,0x00000000}},	// [24450] _deĉi, _ələx, --, --, 
   {{0x27fd3c16,0x00000000,0x00000000,0x00000000}},	//   ziun_, --, --, --, 
   {{0xc0c00201,0x9f40005b,0x0b5804b4,0x2fcc007c}},	//   ስቴር_, ehiä_, брлы_, öggs_, 
   {{0x27fc07c5,0xaca00051,0x00000000,0x00000000}},	//   xiun_, _quốc, --, --, 
   {{0xeab000c6,0xd5b800e2,0x27fc04cc,0x00000000}},	//   بعض_, glāk_, viun_, --, 
   {{0x4f840014,0x7f380375,0x26dc009f,0x6d4402d0}},	//   _باگہ, _לערו, vyuo_, _ugja, 
   {{0x27fc0004,0x6ad003d4,0x388c06be,0x00000000}},	//   tiun_, _দেখো, _bərq_, --, 
   {{0x27fc01ab,0xb3380139,0x00000000,0x00000000}},	//   uiun_, geçk, --, --, 
   {{0x27fc02d3,0x44300368,0x86c4009a,0x00000000}},	//   riun_, _rhy_, سيدن, --, 
   {{0x44316226,0x27fd6227,0x3a8401d9,0x8afc01ef}},	//   _shy_, siun_, _رُمہ, _neři, 
   {{0x44316228,0x4dbc02f5,0x388c0213,0x3c2c00d0}},	//   _phy_, _আকাং, _fərq_, lýva_, 
   {{0x603c02b5,0xe8dc0051,0x00000000,0x00000000}},	//   _tōmi, quốc_, --, --, 
   {{0x998c0064,0x00000000,0x00000000,0x00000000}},	//   _gidų_, --, --, --, 
   {{0x44300302,0x00000000,0x00000000,0x00000000}},	//   _why_, --, --, --, 
   {{0x44316229,0x412805c5,0x200c06ed,0x66e00032}},	//   _thy_, сово_, édio_, _хоҙа, 
   {{0x9f40005b,0x3c2c00c7,0x442401e1,0x00000000}},	//   yhiä_, kýva_, _óo_, --, 
   {{0x6810054e,0x3c2c0022,0x00000000,0x00000000}},	// [24460] căde, jýva_, --, --, 
   {{0x6d8c06d6,0xd8380100,0x00000000,0x00000000}},	//   ṱanz, _apčl_, --, --, 
   {{0xc105622a,0xbb487b63,0x00000000,0x00000000}},	//   _روحي, ملان_, --, --, 
   {{0x82b80003,0x00000000,0x00000000,0x00000000}},	//   _བློའ, --, --, --, 
   {{0x7a400241,0x7ccc00e5,0xe7bc00b8,0x00000000}},	//   _nítì, _bőrá, _शोधप, --, 
   {{0xea9c1682,0x00000000,0x00000000,0x00000000}},	//   guṱe_, --, --, --, 
   {{0xb2183b9d,0xa8a002d5,0x195801e0,0x00000000}},	//   kræn, ерык, баһы_, --, 
   {{0xeb94cde5,0x368803f6,0x3c2c6711,0x388c03e3}},	//   _нис_, бсон_, býva_, _qərq_, 
   {{0x9634ceb8,0x00000000,0x00000000,0x00000000}},	//   мниц, --, --, --, 
   {{0x998c0153,0xdcfce2ff,0x6d4000d0,0xba0800ae}},	//   _vidų_, _harı, ľnav, _اترك_, 
   {{0xdcfca493,0xb2180008,0x7ae1622b,0xe97000ec}},	//   _karı, fræn, lyot, _سهند, 
   {{0xb218019b,0x603c02b1,0x7ae00083,0x8afc0118}},	//   græn, _kōmu, oyot, _seři, 
   {{0x7ae1622c,0xe9fc07ae,0x01b400fe,0xdcfc06be}},	//   nyot, _quần_, ঞানদ, _marı, 
   {{0xdcfc0aba,0xa15811eb,0x6810054e,0xb3384560}},	//   _ları, зару_, răde, neçi, 
   {{0xb218037e,0x3c2c0030,0x7ae0a5e9,0xe1f0009f}},	//   bræn, zýva_, hyot, اسُ_, 
   {{0xe9fc07ae,0x2ca0003e,0x649402e3,0x7ae004ba}},	//   _tuần_, _rpjd_, ụich, kyot, 
   {{0xe9fc001e,0x52146134,0xb33800ee,0xb8ec0327}},	// [24470] _huấn_, _одит, keçi, _ུཌ_, 
   {{0xd5b80318,0x7ae000dc,0x3c2c0124,0x00000000}},	//   ndā_, dyot, výva_, --, 
   {{0xdcfc0c02,0x98fc0115,0xd9c4009e,0xd5b800e2}},	//   _barı, _keĉu, ্সাম, idā_, 
   {{0x3eb0023a,0xdcfc0205,0x941c012d,0x3c2c035b}},	//   äntä_, _carı, नविच_, týva_, 
   {{0xdcfc3535,0x7ae080d8,0x160c190e,0x89d402bf}},	//   _darı, gyot, िचार_, дійш, 
   {{0x3c2d622d,0xdea5622e,0x1a681fcb,0xc7b801d3}},	//   rýva_, _سیمی, سیمی_, plők_, 
   {{0x9e35622f,0xdcfc1f02,0x3c2c00c7,0x00000000}},	//   _черч, _farı, sýva_, --, 
   {{0xf5740248,0x7ae002e2,0x6d54002e,0xdcfc0205}},	//   _kẹwà_, byot, lcxa, _garı, 
   {{0xdb0001ef,0xb33803b9,0x7ae00055,0x00000000}},	//   _kamý, beçi, cyot, --, 
   {{0x6d540998,0xdcfceaab,0x32000109,0xb38c0118}},	//   ncxa, _zarı, jijy_, ážní, 
   {{0xdcfc1b09,0xb218f4d8,0x7e7433c8,0x5a38030d}},	//   _yarı, træn, zsyp, _хытă, 
   {{0x68e16230,0xdcfc06be,0x7bc40241,0x00000000}},	//   mynd, _xarı, _òkut, --, 
   {{0x68e16231,0xb2196232,0xd77400cf,0xd5b800cd}},	//   lynd, rræn, _سانع, bdā_, 
   {{0xc7b801d3,0x3250005b,0xdb0000d7,0x00000000}},	//   ldő_, твёр, _namý, --, 
   {{0x68e009a5,0x80b80034,0xb21836e0,0xf1c0098a}},	//   nynd, ॉमें, præn, शाजन, 
   {{0xc7b800dd,0x7ae0198f,0xb218003a,0x9f4000ae}},	//   ndő_, yyot, bræo, mhiú_, 
   {{0xdb00008c,0x68e12d73,0x245001fb,0xc7b800e5}},	// [24480] _samþ, hynd, _hãm_, idő_, 
   {{0x68e16233,0xdcfc0ba5,0x7ae005d9,0xee340957}},	//   kynd, _sarı, vyot, дну_, 
   {{0xdb0000a2,0xdcfc93ba,0x68e00432,0x7410072d}},	//   _damý, _parı, jynd, _سویا, 
   {{0xc61002a6,0xdcfc654f,0x68e000ee,0x00000000}},	//   _সীমা_, _qarı, dynd, --, 
   {{0x19596234,0xeaac00f7,0x2450001e,0x0b7802d3}},	//   палы_, لعو_, _lãm_, _ኣጽዋር_, 
   {{0x7ae16235,0x68e0722a,0x00000000,0x00000000}},	//   ryot, fynd, --, --, 
   {{0x68e16236,0xdcfc0bc7,0x29180724,0x00000000}},	//   gynd, _tarı, şqan_, --, 
   {{0x603c04fe,0xb8d40fc8,0xdb0002fb,0xb904121d}},	//   _tōmu, _छन_, _zamý, _पथ_, 
   {{0x6d408841,0x6c0000c7,0xb2180174,0x00000000}},	//   žnat, _рзтз, fræl, --, 
   {{0xd74c02d3,0x68e16237,0x49900133,0x8b44007b}},	//   _ቀዳምነ, bynd, _میهر, _أضفن, 
   {{0x62816238,0xe9fc01fb,0xd5b8005f,0x24500208}},	//   ámon, _quấn_, rdā_, _cãm_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3dc8007f,0x3c2c0022,0x00000000,0x00000000}},	//   _onbw_, hývo_, --, --, 
   {{0xe9fc0016,0x9f4001e7,0xe704179e,0x3c2c00e4}},	//   _tuấn_, bhiú_, _تسمی, kývo_, 
   {{0xf41c0004,0x3c2c00e4,0x9f4000ae,0x00000000}},	//   poä_, jývo_, chiú_, --, 
   {{0xdb00da60,0xb218008c,0x92940124,0x53340108}},	//   _jamó, mræm, _заиц, _пейт, 
   {{0xdb000124,0x237402dd,0x0e34074d,0x00000000}},	// [24490] _mamó, _شايح, енаю, --, 
   {{0x9f340220,0xc7b801ed,0x9f9c01a8,0xa9200118}},	//   теуі, zdő_, _bíó_, ížko, 
   {{0xdef8001f,0x6114084c,0xdcfc005f,0xdd9401c6}},	//   ለተኛ_, _адэу, _marķ, тахы, 
   {{0xdb016239,0xaa04185b,0x3dc8002f,0x4a940798}},	//   _famü, वच्छ_, _enbw_, ејку, 
   {{0xaac40244,0x00000000,0x00000000,0x00000000}},	//   بتان, --, --, --, 
   {{0x68e009a5,0x1c006527,0x48b400a7,0xb21801bf}},	//   tynd, लोबल_, ещит, kræm, 
   {{0xf8900120,0xf8ac0014,0x00000000,0x00000000}},	//   гајќ, ٝکن_, --, --, 
   {{0x68e00510,0x66702a60,0xdb013fe3,0x00000000}},	//   rynd, نگتر, _camó, --, 
   {{0x68e00510,0xc72401c0,0xc7b801ed,0x660c00d0}},	//   synd, эдий, rdő_, écko, 
   {{0x68e1623a,0xaca002e3,0x9f4000c6,0xb33856ed}},	//   pynd, _nhịa, thiú_, neçu, 
   {{0xdb00642b,0x794802d3,0x07080ee8,0x452801d5}},	//   _famó, _ሓሳባት, تيکي_, яжон_, 
   {{0x74c0004b,0xfcf8010f,0x588401ee,0x00000000}},	//   اښون, פּיל, _шыуа, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb00068f,0xe3c4009d,0x00000000,0x00000000}},	//   _zamó, хрүү, --, --, 
   {{0x03a40117,0x00000000,0x00000000,0x00000000}},	//   _зийо, --, --, --, 
   {{0xdb01623b,0x9f9c02d2,0x3c2c00c7,0x00000000}},	//   _xamó, _ríó_, vývo_, --, 
   {{0x63a5623c,0x4421623d,0x2fc8026c,0xdb0002e2}},	// [244a0] _ibin, mok_, _dncg_, _lamò, 
   {{0xc61004c5,0x2fc80129,0x2388012d,0xe8dc0051}},	//   _সীতা_, _encg_, łują_, _nhỏm_, 
   {{0xd201623e,0x3b84b494,0x9f9c0241,0x2d8409c2}},	//   _түрк, елег, _díò_, ónea_, 
   {{0x4421623f,0x9f40030a,0x3c2c00c7,0x00000000}},	//   nok_, zhiù_, rývo_, --, 
   {{0x63a56240,0xdb016241,0x442001c4,0xb33800d8}},	//   _mbin, _ramó, iok_, beçu, 
   {{0x44216242,0x660c0a40,0xdb00007f,0xbe3413ef}},	//   hok_, éckl, _bamò, _سىزب, 
   {{0x63a56243,0x22440122,0x6d400219,0x3eb0002d}},	//   _obin, ímky_, žnar, lwyt_, 
   {{0x27ec070d,0xdb00067c,0x63a40521,0x44216244}},	//   _clgn_, _damò, _nbin, jok_, 
   {{0x7c216245,0x628000dd,0xd5b800e2,0xf9900472}},	//   moor, ámol, klāt_, _مبا_, 
   {{0x63a56246,0x7c216247,0xdb000561,0xb2180194}},	//   _abin, loor, _famò, træm, 
   {{0x63a41c94,0x3eb0033f,0xca4c0150,0x44216248}},	//   _bbin, hwyt_, _ﺃﺘﺕ_, fok_, 
   {{0x44216249,0x3eb0017a,0xb218003a,0x6810054e}},	//   gok_, kwyt_, rræm, păda, 
   {{0xb21803b2,0xe60c9f6d,0xe734009b,0x00000000}},	//   kuæt, ششی_, _зец_, --, 
   {{0x7c21624a,0x63a5624b,0xb219624c,0x98bc1f02}},	//   hoor, _ebin, juæt, lavı_, 
   {{0x7c21624d,0xd250132f,0x00000000,0x00000000}},	//   koor, _ھند_, --, --, 
   {{0x4420ae08,0x98bc510c,0x63a40241,0x9f40004e}},	//   cok_, navı_, _gbin, fkià_, 
   {{0x7c21624e,0x7648009f,0xa3b804fb,0xb21801a8}},	// [244b0] door, _kify, _ساير_, nræk, 
   {{0xdd941669,0x63a44317,0x7c200942,0xdf44084c}},	//   лауы, _zbin, eoor, уэсп, 
   {{0x680400f2,0x4c94013d,0x2ca401f5,0x63a801d3}},	//   _jèjè, тиес, ïnd_, ődne, 
   {{0x7c21624f,0x76481529,0xb218c8c6,0xdb0002e2}},	//   goor, _lify, kræk, _ramò, 
   {{0xe8dc001e,0xe47802d3,0x7f740375,0x9f9c0241}},	//   _phỏm_, _ኮይንካ_, _בערב_, _tíò_, 
   {{0x44216250,0x66e401e1,0x67e40055,0x00000000}},	//   zok_, _lékú, _iñji, --, 
   {{0x44216251,0x1cb0003d,0x67e40bc9,0x9d1800d8}},	//   yok_, _དགར_, _uñjk, _зорт_, 
   {{0x7c216252,0x44216253,0x46a4034b,0xd5b800e2}},	//   coor, xok_, ваив, klās_, 
   {{0x44216254,0xe8dc0208,0x9a84014b,0xda0800f1}},	//   vok_, _thỏm_, _бухл, _ګيله_, 
   {{0x44216255,0x63a43657,0x628001ed,0x2d900472}},	//   wok_, _sbin, ámom, ngxe_, 
   {{0x44216256,0x76496257,0xdecc001f,0xb89400e5}},	//   tok_, _dify, _አይን_, _لانڈ, 
   {{0x1ad800bd,0x1cc0031c,0x7a34098c,0x21f4000d}},	//   _দেয়া, _ཀླས_, râte, _mähe_, 
   {{0x21f400af,0x940c0213,0xb9e4069d,0x78480118}},	//   _lähe_, ntdə_, _ጫት_, _uřva, 
   {{0x44216258,0x6d5805d1,0x7c2001f7,0xa2c4033f}},	//   sok_, _şuan, zoor, िटब्, 
   {{0x44216259,0x21f40730,0x67e40055,0x34a00432}},	//   pok_, _nähe_, _añji, _diỳỳ, 
   {{0x63a5625a,0x44206cd2,0x4f9401c6,0x940c03e3}},	//   _ubin, qok_, лруу, ktdə_, 
   {{0x7c207890,0xf77004ac,0x00000000,0x00000000}},	// [244c0] voor, יקן_, --, --, 
   {{0x7c20292b,0xd24c105d,0xb33805d1,0x3eb06e1c}},	//   woor, _رۆف_, reçt, rwyt_, 
   {{0x7c21625b,0xc7b801d3,0xddc40064,0x00000000}},	//   toor, nlős_, psiž, --, 
   {{0xe7254559,0x9e740ef6,0xfb6000c7,0x940c06be}},	//   _نص_, _مۇرت, рҭаҿ, ftdə_, 
   {{0x7c21625c,0x6728050a,0x3f800009,0x7f180212}},	//   roor, _nygj, _idku_, _ціну_, 
   {{0x7c21625d,0x00000000,0x00000000,0x00000000}},	//   soor, --, --, --, 
   {{0x7c21625e,0x7648015d,0x00000000,0x00000000}},	//   poor, _rify, --, --, 
   {{0xb21804ce,0x57b43129,0x7c21625f,0x672800a2}},	//   træk, убит, qoor, _bygj, 
   {{0x19c56260,0x68040066,0xdb0c005b,0x21f4002f}},	//   _бәйг, _sèjè, öhäi, _zähe_, 
   {{0x1cc0025c,0xb218782c,0x9bc400cf,0x6728036e}},	//   _ཀློ_, rræk, _جەچۉ, _dygj, 
   {{0x1cb031d9,0xb4bc045b,0xe8dc004d,0xb218d379}},	//   _དགས_, ीमे_, _thềm_, sræk, 
   {{0xb21801bf,0x00000000,0x00000000,0x00000000}},	//   præk, --, --, --, 
   {{0x387c05da,0x9f9c03b2,0x00000000,0x00000000}},	//   _hvtr_, _ríð_, --, --, 
   {{0xdcfc0100,0x9f9c09e8,0x00000000,0x00000000}},	//   _adrč, _síð_, --, --, 
   {{0xa159533f,0x00000000,0x00000000,0x00000000}},	//   тасу_, --, --, --, 
   {{0xb4dc0073,0xb4bc10fa,0x00000000,0x00000000}},	//   णही_, ँटी_, --, --, 
   {{0x2d8409c2,0xe3b00451,0x316802a9,0x9f04004b}},	// [244d0] óneo_, _ذري_, _ошно_, ټولو, 
   {{0x21f400c5,0x6e900131,0xd25010e8,0x9f40002b}},	//   _pähe_, лиғу, _پنگ_, bhiþ_, 
   {{0x1dc43306,0x9f9c09cc,0xaca00208,0x00000000}},	//   ؤْمِ, _tíð_, _thọa, --, 
   {{0x21f400af,0x5cc40137,0x388c03e3,0x00000000}},	//   _vähe_, шсуз, _fərz_, --, 
   {{0x53a47f1a,0x67e40bc9,0xc9a83cc5,0x660c04e6}},	//   ग्यश, _uñji, евле_, éckk, 
   {{0x67280158,0x21f40037,0x5a34004e,0x00000000}},	//   _rygj, _tähe_, анчт, --, 
   {{0x395c01e4,0xa3e402ab,0xdde400d1,0x67280240}},	//   _dfts_, पॉड_, _тәтү, _sygj, 
   {{0x395c009a,0x908002d3,0x628001d3,0xb4bc012c}},	//   _efts_, _ንግዳዊ_, ámok, ीमै_, 
   {{0x1cb00ad3,0xcfc40eac,0x69b81d8a,0xaca0004d}},	//   _དགོ_, _একান, _एसपी, _khỏa, 
   {{0x7d000115,0xa5e400fb,0x00000000,0x00000000}},	//   ŝose, тлоҡ_, --, --, 
   {{0x74e4009d,0x1b1800cc,0x00000000,0x00000000}},	//   гдэг_, _তৰপে_, --, --, 
   {{0xd7c8208f,0xb3380213,0xe28401a9,0x00000000}},	//   _لومه_, veçr, ағин, --, 
   {{0x2d800e3c,0x387c06d9,0xd7c8036b,0x00000000}},	//   _odje_, _zvtr_, _جونه_, --, 
   {{0x6600209c,0xb218005c,0x2d80036e,0x3f800419}},	//   _umnk, jsæd, _ndje_, _sdku_, 
   {{0x1cb01e81,0xb218005c,0x661004f2,0x00000000}},	//   _དགེ_, dsæd, _مژگا, --, 
   {{0x2d80ef96,0xb3e80327,0x437464c2,0x008401f0}},	//   _adje_, རྒྱུ, _сукт, клҳо, 
   {{0x25f41f14,0x8f74fb4f,0xbdc801c0,0x00000000}},	// [244e0] एसपी_, русі, нгаж_, --, 
   {{0x1cc0081f,0xb21800b5,0x7b0400ac,0x660c0036}},	//   _ཀླུ_, gsæd, _üstə, éckh, 
   {{0xfb896261,0x6da16262,0x263000b5,0xc0e40209}},	//   ебек_, сиха, _ｚone_, _сонк, 
   {{0x388c06be,0x00000000,0x00000000,0x00000000}},	//   _tərz_, --, --, --, 
   {{0xab741c43,0x6c8000d1,0x995801ef,0x00000000}},	//   امها_, للەم, _záři_, --, 
   {{0x2d80036f,0xddc40153,0xde480133,0xb2180174}},	//   _gdje_, rsių, _شیاو_, træi, 
   {{0xf8480276,0x9a9c0092,0x395c2641,0x3154010f}},	//   нчий_, ለቲካው_, _vfts_, ניקן_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb4bc0882,0xb99513f3,0xf64412d7,0x6b600137}},	//   ीम्_, _مشاغ, лхон, _ыкта, 
   {{0x23600129,0x00000000,0x00000000,0x00000000}},	//   _afij_, --, --, --, 
   {{0x25a40d27,0x7998035a,0x9f40005b,0xf8640063}},	//   _dbnl_, _ictw, lkiä_, _свео, 
   {{0x78b800dd,0xdef8001f,0xdb0002d2,0x6fc8013d}},	//   _istv, ወሰን_, _damö, _möcä, 
   {{0xc7640075,0x9f40023a,0xa7780a1e,0xf4200137}},	//   _ئامى, nkiä_, _טראפ, изүү, 
   {{0x916406c2,0x00000000,0x00000000,0x00000000}},	//   شهره, --, --, --, 
   {{0xb21804ce,0x2d856263,0x9f4001f4,0x00000000}},	//   kræv, ónem_, hkiä_, --, 
   {{0x9f4002f6,0x5f940e4e,0xaac40118,0x00000000}},	//   kkiä_, йист, लिमक, --, 
   {{0x1cb01b4b,0xed882e59,0x79980857,0xce9412e7}},	// [244f0] _དགུ_, есек_, _octw, разъ, 
   {{0x78b81326,0x91c429db,0x6fc80166,0x00000000}},	//   _ostv, _тәмл, _böcä, --, 
   {{0xd7c40574,0xb2193116,0x69b825c9,0x78b801ef}},	//   वयाच, rsæd, _एसबी, _nstv, 
   {{0x200d6264,0xce940801,0x79980c8c,0xb21801bf}},	//   édit_, _камъ, _actw, ssæd, 
   {{0x78b95fb2,0xaca00051,0x00000000,0x00000000}},	//   _astv, _thỏa, --, --, 
   {{0xac756265,0x88c40597,0x2d800384,0x7bc40252}},	//   _مارش, لتعل, _udje_, _ókun, 
   {{0x9a841638,0x14b039de,0xb218022c,0x7998035a}},	//   _қутл, _जनगण, bræv, _dctw, 
   {{0x06856266,0x799802d0,0x1cc0031c,0x2e2c0213}},	//   агин, _ectw, _ཀླི_, düfi_, 
   {{0x6b9801ab,0x78b803ac,0x9f4001f4,0xab28007b}},	//   _icug, _estv, ckiä_, _أسأل_, 
   {{0xdb00021c,0xafd82b96,0x6ab96267,0x00000000}},	//   _camõ, _uhøf, _isuf, --, 
   {{0x21f4007d,0xa8a400a7,0x25f41cd2,0x00000000}},	//   _näha_, _щрак, एसबी_, --, 
   {{0x02c446e0,0x69b8033f,0xe8dc0051,0x00000000}},	//   аймо, _एसडी, _chễm_, --, 
   {{0x666474ac,0x46a800c5,0x00000000,0x00000000}},	//   _съез, _कहिह, --, --, 
   {{0x21f40166,0xdd1400d7,0x00000000,0x00000000}},	//   _bäha_, _rúžo, --, --, 
   {{0x41282082,0xdb000109,0x634c00de,0x349000f3}},	//   тово_, _hamô, _sēnī, _дајр, 
   {{0xdef82e1f,0x6ab800c7,0xdcfc0055,0x00000000}},	//   ወሰኑ_, _osuf, _ndrā, --, 
   {{0x44c56268,0x660c0221,0xf8d0141f,0x00000000}},	// [24500] _hē_, éckw, _थप्प, --, 
   {{0x44c41f4c,0xdb000109,0xdcfc00cd,0x75f400a2}},	//   _kē_, _mamô, _adrā, _tâze, 
   {{0xd7f80311,0x27140208,0x44c400ef,0x00000000}},	//   _stăm_, ểnh_, _jē_, --, 
   {{0x44c56269,0x9f4002f6,0xdd140419,0x25f40210}},	//   _mē_, tkiä_, _túžo, एसडी_, 
   {{0xaab43ccf,0x44c4096b,0xdb000109,0x6b9801ab}},	//   لدور_, _lē_, _namô, _dcug, 
   {{0x9f408b82,0x958802d3,0x7c640150,0xaa544258}},	//   rkiä_, ማታትን_, _نارل, шишу_, 
   {{0x44c5626a,0xfce5626b,0x9f40023a,0xec740816}},	//   _nē_, _тово, skiä_, _впс_, 
   {{0xb6040241,0xb218041e,0x77900345,0x00000000}},	//   _oláò, lræt, زیتا, --, 
   {{0x44c40418,0x0ec807f7,0x00000000,0x00000000}},	//   _aē_, रियड, --, --, 
   {{0x7bc1626c,0xb2180bcd,0x95d9626d,0xafd801bf}},	//   ldou, nræt, удот_, _thøg, 
   {{0x78b82340,0xafd805ac,0x7bc00165,0xd87400cf}},	//   _ustv, _uhøg, odou, _چاچب, 
   {{0x44c4003a,0xb6a406ed,0x00000000,0x00000000}},	//   _dē_, _видл, --, --, 
   {{0x05cc033f,0x91c4104e,0x00000000,0x00000000}},	//   ़ाखब, бәнл, --, --, 
   {{0x44c40418,0xe73402e8,0x873401c8,0x00000000}},	//   _fē_, _теч_, _اِهڙ, --, 
   {{0xb2194607,0x61e80267,0xe638011a,0xf0740116}},	//   dræt, ödla, _שתוכ, рибә_, 
   {{0x82b80489,0x67e40054,0x7bc00369,0x00000000}},	//   _བླམའ, _uñjt, jdou, --, 
   {{0x200c00cf,0xea9c00b8,0x00000000,0x00000000}},	// [24510] èdia_, _puṭa_, --, --, 
   {{0x9df8034b,0x6b995b9a,0xa2c401ad,0xb2181427}},	//   анут_, _scug, िटर्, græt, 
   {{0x62800306,0xc1700677,0xcb540efe,0x00000000}},	//   ámov, _מחי_, مناظ, --, 
   {{0x8af9626e,0xab842218,0x00000000,0x00000000}},	//   лнес_, ружк, --, --, 
   {{0x21f40036,0xb218005c,0x00000000,0x00000000}},	//   _mähn_, bræt, --, --, 
   {{0x3a3c00d8,0x7bc12a89,0x9f400165,0x6ce400d4}},	//   _chtp_, adou, chiñ_, _кібе, 
   {{0xc8c80244,0x00000000,0x00000000,0x00000000}},	//   اوبن_, --, --, --, 
   {{0x6ab80b45,0x44c400b0,0x9d187401,0x7bc001ab}},	//   _tsuf, _rē_, _тост_, cdou, 
   {{0x6ab9626f,0x44c40607,0xee3c00e4,0x66d005d1}},	//   _usuf, _sē_, _apýi_, dıkö, 
   {{0x44c408f5,0x45d40353,0x00000000,0x00000000}},	//   _pē_, сцит, --, --, 
   {{0xb5a800e5,0x00000000,0x00000000,0x00000000}},	//   ھئیے_, --, --, --, 
   {{0x9f4005c7,0x44c400ef,0x00000000,0x00000000}},	//   zhiñ_, _vē_, --, --, 
   {{0x44c402b1,0x69c10027,0xcd600023,0xe1f80b01}},	//   _wē_, odne, ድሕድና_, иҳи_, 
   {{0x04c84f5f,0x44c404fe,0x69c00e21,0x7bc00165}},	//   _موتي_, _tē_, ndne, zdou, 
   {{0x44c40069,0x7bc00129,0xb2180162,0x04440354}},	//   _uē_, ydou, vræt, _лекн, 
   {{0xf66002e3,0x21f4002f,0xb218005c,0xaae401ec}},	//   _họọr, _gähn_, fræs, _әдiс, 
   {{0xf660063f,0xb21856a9,0x1cb0031c,0x3da813d6}},	// [24520] _kọọr, træt, _དགང_, лкао_, 
   {{0x69c001ed,0x21f40036,0x00000000,0x00000000}},	//   jdne, _zähn_, --, --, 
   {{0x82356270,0x315406a9,0xb218022c,0x7f9001a9}},	//   _پرکا, _ליין_, rræt, _fаqа, 
   {{0x7bc0030a,0x7a8400e5,0xb21806ea,0x00000000}},	//   udou, مشتم, sræt, --, 
   {{0x614404a9,0x7bc0030a,0xafd803cd,0xb218148b}},	//   _دىگە, rdou, _tiør, præt, 
   {{0xed5451bc,0x8eb01473,0x7bc103e2,0x7a340356}},	//   _гор_, _تەكت, sdou, râto, 
   {{0xf1b00302,0xa3c8000d,0xf8055b1f,0x7bc00247}},	//   פסה_, ईया_, йчин, pdou, 
   {{0x69c16271,0x7bc00369,0x2bcc07b7,0x62840022}},	//   adne, qdou, _सोपा, _ovio, 
   {{0xa3dc012c,0x21f40254,0x69c00118,0x00000000}},	//   ठान_, _rähn_, bdne, --, 
   {{0x1dc800dc,0xe9d40354,0xb218032e,0x00000000}},	//   रयित, _лку_, hrær, --, 
   {{0x281000dd,0x21f40254,0xb1900131,0x00000000}},	//   _کونس, _pähn_, үлмә, --, 
   {{0x656002d2,0x00000000,0x00000000,0x00000000}},	//   _efnh, --, --, --, 
   {{0xef1c04cc,0xf66001e1,0x925801c0,0x7f9001a9}},	//   _adün_, _fọọr, рагт_, _rаqа, 
   {{0x2bcc02ab,0xf0740131,0x660c01c7,0x6240007c}},	//   _सोना, йигә_, éckt, jöod, 
   {{0x62840c8c,0x8178013e,0x00000000,0x00000000}},	//   _evio, расӣ_, --, --, 
   {{0xb2183c38,0x69c023cc,0xe4c401e2,0x00000000}},	//   træs, zdne, _دصهی, --, 
   {{0x69c08a29,0xe4d00137,0x628000e5,0x00000000}},	// [24530] ydne, _وقۇد, ámot, --, 
   {{0x2d856272,0xaac487ee,0x62880210,0x00000000}},	//   ûne_, लिसक, ądot, --, 
   {{0x6284006f,0x69c00219,0x5fc4ac66,0x00000000}},	//   _zvio, vdne, _लोकल, --, 
   {{0xb21804ce,0xc11802dd,0x69c00076,0x6810054e}},	//   præs, _түсi, wdne, pădi, 
   {{0x63780521,0x69c00427,0x00000000,0x00000000}},	//   ụngw, tdne, --, --, 
   {{0xda785a19,0xdd5805f5,0xadb40131,0x00000000}},	//   сяц_, _гарч_, _دۇئا_, --, 
   {{0x69c115a6,0x482441fa,0x25f425c9,0xe9fc0208}},	//   rdne, يىتق, एससी_, _quằn_, 
   {{0x69c023ac,0x00000000,0x00000000,0x00000000}},	//   sdne, --, --, --, 
   {{0x2bcc3be6,0x26c80048,0x7ae8004b,0x49a401ee}},	//   _सोया, íco_, _پولې_, _мыжғ, 
   {{0xc4856273,0x06080107,0xddc40356,0x26c0008f}},	//   олок, рнок_, mpiţ, ĉjo_, 
   {{0x04442164,0x26c80115,0x00000000,0x00000000}},	//   женн, ŭco_, --, --, 
   {{0x2bcc09ae,0xdcfc003a,0x070800ec,0xf6600248}},	//   _सोमा, _scrī, _پيتي_, _wọọr, 
   {{0x660c04e6,0xaab821f6,0x00000000,0x00000000}},	//   écks, ोटिक, --, --, 
   {{0xe1f8013e,0x00000000,0x00000000,0x00000000}},	//   сҳо_, --, --, --, 
   {{0x03a400ee,0xb2180fac,0x2bcc0037,0x00000000}},	//   _дийо, trær, _सोभा, --, 
   {{0x62816274,0x61fc036b,0x34b011e6,0xaab800bc}},	//   ámos, shrl, _آميز, ोटाक, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [24540] --, --, --, --, 
   {{0xfd116275,0x12c40150,0x6810054e,0x6e040131}},	//   وجا_, _ءتيپ, mădu, يسلە, 
   {{0x33900edf,0xbb8400d1,0x614001a8,0x7d0001e4}},	//   _علیز, قلاي, _dálí, ĝoso, 
   {{0xb0980677,0x00000000,0x00000000,0x00000000}},	//   _דיטר, --, --, --, 
   {{0xefb001b9,0xfe44014b,0x00000000,0x00000000}},	//   _زیلگ, _мнмо, --, --, 
   {{0xc8c406ab,0x79a40046,0x2010012d,0xfb840022}},	//   विंट, ірле, śnić_, сыҧн, 
   {{0x2e2c03fa,0xf1c800dc,0x53dc0b67,0x87d000e5}},	//   rüft_, ायतन, यामश, کےنت, 
   {{0x76a96276,0xeb956277,0xf6c4031c,0x68400798}},	//   атов_, _мис_, _ཀླུང, мнја, 
   {{0xfaa4561e,0x6a8028a8,0xb218005c,0x00000000}},	//   _фазо, _олта, dsæn, --, 
   {{0xb8d401ec,0x06300092,0x74a40798,0x00000000}},	//   _وتاش, _አባይነ, ојме, --, 
   {{0x41dc1d27,0x957c033f,0x2bcc0490,0xb21802d2}},	//   मानस, ejąc, _सोडा, dræp, 
   {{0xd8300451,0x660c01c7,0x00000000,0x00000000}},	//   _ڪڍڻ_, éckr, --, --, 
   {{0x68100311,0x55580276,0xe7340063,0x00000000}},	//   gădu, _лаля_, _дец_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6234084c,0x957c0034,0xb3545da7,0x00000000}},	//   феру, ając, _ویدا_, --, 
   {{0x937813f3,0xdfd40139,0x00000000,0x00000000}},	//   _убит_, мосы, --, --, 
   {{0x614008a5,0x9f34155b,0x00000000,0x00000000}},	// [24550] _pálí, деті, --, --, 
   {{0xf3fc4b91,0x6cc80114,0x00000000,0x00000000}},	//   lhã_, ићев_, --, --, 
   {{0x1cc0038f,0x00000000,0x00000000,0x00000000}},	//   _ཀླད_, --, --, --, 
   {{0xf3fd6278,0xd5b80421,0x96bc00bc,0x00000000}},	//   nhã_, heā_, ्टाउ, --, 
   {{0xd5b802b5,0xa3dc0073,0xabb00022,0x3fd8011a}},	//   keā_, ठात_, заҵә, _הקרב, 
   {{0x09d802f5,0xf1c800dc,0x0c040014,0x0fc801f9}},	//   থস্থ, ायिन, _کورُ, ाएवढ, 
   {{0xf6b4031c,0x9d1800ee,0xecf002dd,0x00000000}},	//   _དགུང, _дорт_, _تۋاد, --, 
   {{0xddc40784,0x9bc400cf,0x957c0210,0x00000000}},	//   mpiš, _يەلۉ, yjąc, --, 
   {{0x06081b8c,0xf1c80a94,0xb21801bf,0xddc40064}},	//   йник_, ायान, vsæn, lpiš, 
   {{0x6810054e,0x00000000,0x00000000,0x00000000}},	//   vădu, --, --, --, 
   {{0x1cb00327,0xb218005c,0x98ac01ef,0x00000000}},	//   _དགབ_, tsæn, _mzdě_, --, 
   {{0x281001b9,0xb6f400d1,0x00000000,0x00000000}},	//   _کوچس, تىۋا_, --, --, 
   {{0x1cc00135,0xc5f40801,0x27fc05da,0xe9fc0208}},	//   _ཀླན_, _някъ, mhun_, _quặn_, 
   {{0x27fc0b45,0x68100311,0x72a00131,0x250401e2}},	//   lhun_, rădu, رەپن, _ورغی_, 
   {{0x7d0001e7,0xf3fc0055,0x00000000,0x00000000}},	//   _míré, bhã_, --, --, 
   {{0xafe145ed,0xf3fc0c67,0x27fc0652,0x26cc0cf4}},	//   носл, chã_, nhun_, _krgo_, 
   {{0x6444170b,0x27fc03f9,0x44316279,0xfbc40b6d}},	// [24560] _ihii, ihun_, _iky_, _रोगम, 
   {{0xb218008c,0x6444020c,0x27fc0036,0x1cb00327}},	//   nsæl, _hhii, hhun_, _དགད_, 
   {{0x27fc06a3,0x27142aa1,0x3b640801,0x6444058a}},	//   khun_, दपुर_, пълв, _khii, 
   {{0xfaa5627a,0x26cc0077,0x417440ec,0xee3c03b2}},	//   задо, _orgo_, _باکس, _spýt_, 
   {{0x27fd627b,0x87b80156,0x44300004,0x6d640022}},	//   dhun_, _དྲེཡ, _mky_, éraí, 
   {{0xdce8723e,0xf3fc0004,0x27fc009d,0x7d0001e7}},	//   şlıq, zhã_, ehun_, _círé, 
   {{0x26cd627c,0x6444166a,0x4431627d,0x7af0012c}},	//   _argo_, _ohii, _oky_, _řetě, 
   {{0xfaa5627e,0x4430016b,0xd5b800b0,0x8b650030}},	//   _набо, _nky_, weā_, _ياقم, 
   {{0xd5b80270,0x1de03381,0x746805a2,0x7d0001e7}},	//   teā_, नापत, әров_, _fíré, 
   {{0x64440cfe,0x4431627f,0x1a68034d,0x20000093}},	//   _ahii, _aky_, _هیچی_, hhii_, 
   {{0x26cd4d79,0x644401ab,0x44300175,0x2000058a}},	//   _ergo_, _bhii, _bky_, khii_, 
   {{0x27fd6280,0x64456281,0x248402b9,0xd5b80607}},	//   chun_, _chii, _dvnm_, seā_, 
   {{0x64456282,0x20007361,0x26cc01a6,0xddc40427}},	//   _dhii, dhii_, _grgo_, zpiš, 
   {{0x44300c8a,0x26c0005f,0x463000c7,0x6f0001e1}},	//   _eky_, ājot_, _иҭыр, _lìbé, 
   {{0x644400a3,0x64a010f3,0x00000000,0x00000000}},	//   _fhii, _заја, --, --, 
   {{0x4430070d,0x2000084c,0x644400a3,0x20540276}},	//   _gky_, ghii_, _ghii, екся, 
   {{0xdb0820ef,0xdfd001d3,0x234800db,0x00000000}},	// [24570] _élèv, ھيے_, _ىلىپ_, --, 
   {{0xddc40552,0x27fc0dd4,0x20016283,0x09b002f5}},	//   tpiš, zhun_, ahii_, _টোনা, 
   {{0x64541280,0xf15013f9,0xbb6801f2,0x2001625c}},	//   _éxit, _سکسک, _ịmịc, bhii_, 
   {{0x20016284,0x4fc00ef6,0xceb80572,0x4de402dd}},	//   chii_, _جەرە, _мәз_, _ﺍﺷﯩﻨ, 
   {{0x2d85509f,0xddc41050,0x00000000,0x00000000}},	//   ónes_, spiš, --, --, 
   {{0x27fc7330,0x98ac013a,0x00000000,0x00000000}},	//   whun_, _uzdě_, --, --, 
   {{0x27fd6285,0xf5740241,0xdcfc033f,0xb21803b2}},	//   thun_, _kẹfà_, _odrę, vsæl, 
   {{0x0c8401ec,0xf8ac02f2,0x27fc0108,0x5ba4009b}},	//   _нығм, شکم_, uhun_, _пруз, 
   {{0x27fc0108,0x64440037,0xa3dc03ba,0x00000000}},	//   rhun_, _rhii, ठास_, --, 
   {{0xdcfc04ac,0x64456286,0x27fd6287,0x7af4168c}},	//   _serĉ, _shii, shun_, øyte, 
   {{0x644401ab,0x27fd040b,0xb2196288,0x290003cd}},	//   _phii, phun_, rsæl, _åja_, 
   {{0xb2188ecc,0xe78401af,0x00000000,0x00000000}},	//   ssæl, _хужо, --, --, 
   {{0x21f402b5,0x20000810,0xd61801ed,0x26cca721}},	//   _hähi_, vhii_, _کتنا_, _urgo_, 
   {{0x644400b0,0x2bcc46fb,0x21f400a2,0x00000000}},	//   _whii, _सोसा, _kähi_, --, 
   {{0x6445491d,0xcfc4015b,0x443002f0,0x2000003a}},	//   _thii, _একজন, _tky_, thii_, 
   {{0x6444166a,0x20000093,0x44300432,0x00000000}},	//   _uhii, uhii_, _uky_, --, 
   {{0x72c00124,0xc0f8001f,0x20016289,0x21f416ca}},	// [24580] _абыз, _ላይም_, rhii_, _lähi_, 
   {{0x2001628a,0xfbc405f9,0xdb08004a,0xee3c03b2}},	//   shii_, _रोजम, _élév, _spýr_, 
   {{0x6da0abba,0x20000a55,0x2bcc00c5,0x63a4031c}},	//   тиха, phii_, _सोहा, _kcin, 
   {{0x1ee800dd,0x20000ba7,0x2d840ba1,0x00000000}},	//   _فوجی_, qhii_, óner_, --, 
   {{0xdcfc031c,0xbab80e55,0x00000000,0x00000000}},	//   _kerċ, تداء_, --, --, 
   {{0xcf780020,0xb8640fc6,0x3958003b,0x7c640116}},	//   _ኢኮኖሚ_, وابو, øps_, _يازل, 
   {{0x63a5628b,0xada13ca1,0xdcfc031c,0x00000000}},	//   _ocin, _шарл, _merċ, --, 
   {{0x3688a848,0x63a418f7,0xafd80162,0x8cac01f9}},	//   осон_, _ncin, _nhøl, ीबरो, 
   {{0x21f40254,0x00000000,0x00000000,0x00000000}},	//   _tähh_, --, --, --, 
   {{0x63a5628c,0x00000000,0x00000000,0x00000000}},	//   _acin, --, --, --, 
   {{0x77840b96,0xe4e00816,0x00000000,0x00000000}},	//   _жлез, віян, --, --, 
   {{0x63a401ab,0x92940a89,0xd9e000cc,0x00000000}},	//   _ccin, намц, _ভতিম, --, 
   {{0xaac4038e,0x63a40139,0x7ae001a9,0x00000000}},	//   लिएक, _dcin, nxot, --, 
   {{0x63a44ec2,0xb21801a8,0x7ae0004e,0xd1b001d5}},	//   _ecin, msæk, ixot, چیکک, 
   {{0xa159628d,0x63a40200,0x00000000,0x00000000}},	//   дару_, _fcin, --, --, 
   {{0x64a000f3,0x00000000,0x00000000,0x00000000}},	//   _раћа, --, --, --, 
   {{0xe3b00137,0xbd080327,0x78a80334,0x00000000}},	// [24590] _ئرى_, _གཟུཊ_, htfv, --, 
   {{0x63a40810,0xf41c0166,0x00000000,0x00000000}},	//   _zcin, lnä_, --, --, 
   {{0x2ca40311,0x09bc00cc,0x63a403ac,0x16bc6a60}},	//   înd_, _ইচলা, _ycin, ्टुब, 
   {{0xf41c049b,0x00000000,0x00000000,0x00000000}},	//   nnä_, --, --, --, 
   {{0x7ae01cdf,0xa3e40c4c,0xf41c005b,0x00000000}},	//   gxot, पॉट_, inä_, --, 
   {{0xe29c0302,0x6d8400dd,0x21f402b5,0xa2d00882}},	//   קשור, _زمرہ_, _pähi_, दित्, 
   {{0x200c015d,0x61e801e3,0x00000000,0x00000000}},	//   ëdig_, ödli, --, --, 
   {{0x46e809b3,0x16bc068f,0x869806ed,0x21f40037}},	//   здин_, ्टूब, птот_, _vähi_, 
   {{0x21f40374,0xb2181b25,0xafd803b2,0x63a40055}},	//   _wähi_, gsæk, _rhøl, _rcin, 
   {{0x63a5628e,0xf41c023a,0x00000000,0x00000000}},	//   _scin, enä_, --, --, 
   {{0x45187496,0xb03c001f,0xa3dc000d,0x3480009d}},	//   яция_, _በጥንቃ, ठाल_, лгэг, 
   {{0xf41c013d,0x00000000,0x00000000,0x00000000}},	//   gnä_, --, --, --, 
   {{0xdcfc0135,0x29040010,0x7d000115,0x00000000}},	//   _perċ, lzna_, ĝosi, --, 
   {{0xa3e402ab,0x5bbc05d7,0x7c2000d0,0xb6a0009b}},	//   पॉज_, _ईस्व, čori, _сишл, 
   {{0x68e00369,0xb7f003d4,0x29040327,0x3b0401a9}},	//   nxnd, _জগতত_, nzna_, zzoq_, 
   {{0x63a4842f,0x2bcc0574,0x03a4033a,0xf41c0139}},	//   _ucin, _सोला, _џипо, cnä_, 
   {{0xab1c0295,0x7ae00327,0x00000000,0x00000000}},	// [245a0] kòñò_, xxot, --, --, 
   {{0xee3522b4,0x6e9004da,0xada020b0,0x00000000}},	//   ену_, اللا, лаул, --, 
   {{0x92e853b2,0x00000000,0x00000000,0x00000000}},	//   _فریق_, --, --, --, 
   {{0x2904090c,0x9eb400ee,0x7ae0009d,0x81b000cc}},	//   dzna_, _ишгә, txot, _টফি_, 
   {{0xeaacb94d,0x2bcc01f9,0x00000000,0x00000000}},	//   معو_, _सोळा, --, --, 
   {{0xaef80241,0x3f8003a0,0xf988027d,0xead402d5}},	//   _afùw, _heku_, سخته_, эміі_, 
   {{0x3f8006c8,0xf41c1b5d,0x29040e3c,0xdcfc0427}},	//   _keku_, ynä_, gzna_, _kerč, 
   {{0xdcfc007f,0xf0900375,0x00000000,0x00000000}},	//   _jerč, אנה_, --, --, 
   {{0x3a24242f,0xdcfc16a3,0x16bc134e,0x75f400a2}},	//   _змаг, _merč, ्टेब, _hâzi, 
   {{0x3f81628f,0xa9641b15,0xb5a4b5f5,0x25b402fb}},	//   _leku_, _зифа_, хрий, _čelí_, 
   {{0x2904006d,0xb21801bf,0x00000000,0x00000000}},	//   czna_, ssæk, --, --, 
   {{0x3f801326,0x7a340311,0xad1800df,0x00000000}},	//   _neku_, râtu, לויר, --, 
   {{0xe69005d9,0x57b001ec,0x00000000,0x00000000}},	//   _ملند, _бұқт, --, --, 
   {{0xf41c005b,0x26d8123b,0x00000000,0x00000000}},	//   snä_, _מקדמ, --, --, 
   {{0xadc001fb,0xb36400a7,0xe7a40037,0x00000000}},	//   _ngạc, _пъпк, _गामप, --, 
   {{0x65380302,0x033001f2,0xb4bc146c,0x3f80036e}},	//   _מעוד, ọrọn, ुटी_, _ceku_, 
   {{0x3f816290,0xb8d0031c,0x290404cc,0x2328009b}},	// [245b0] _deku_, _ཞད_, zzna_, _поћи_, 
   {{0x3f816291,0xc1700214,0x918000d1,0x2904012d}},	//   _eeku_, _نگفت, _خۇسۇ, yzna_, 
   {{0x3f8000f3,0x39201772,0xc0c000ee,0xe9dc004d}},	//   _feku_, ትራዊያ, _кәти, _đú_, 
   {{0xc61c610a,0x3f816292,0xdcfcc72a,0x9be40024}},	//   _पद्य_, _geku_, _gerč, лічк, 
   {{0x16bc5e58,0x0f34eb7e,0x00000000,0x00000000}},	//   ्टोब, _شکرد, --, --, 
   {{0x3f80110c,0x211807d6,0x7af40217,0xd7f80208}},	//   _zeku_, _آتیب_, øyta, _quăn_, 
   {{0x9f401f60,0x3f816293,0x6d4005d5,0x00000000}},	//   lkið_, _yeku_, ünad, --, 
   {{0x29056294,0xf1e0033f,0x00000000,0x00000000}},	//   rzna_, खाड़_, --, --, 
   {{0x2d816295,0x2fc96296,0x4a543929,0x395c0120}},	//   _keje_, _macg_, _акас, _fgts_, 
   {{0x2d816297,0x5b144855,0xa2d001bc,0x21f400a2}},	//   _jeje_, _смут, दिस्, _jäht_, 
   {{0x2d816298,0x53dc543b,0xd6a800f2,0x00000000}},	//   _meje_, यांश, ودیم_, --, 
   {{0x2d816299,0x7a340af2,0x9f4009f3,0xe0c02b1b}},	//   _leje_, bâts, kkið_, _উপলভ, 
   {{0x3f81629a,0x7c3807ea,0x72c00953,0xa28403e6}},	//   _reku_, _être, абяз, دیخو, 
   {{0x392002d3,0xdcfc007f,0x72c006ed,0x7a340129}},	//   ትራዉያ, _serč, јбрз, lâtr, 
   {{0x3f81629b,0xdcfd22a1,0x00000000,0x00000000}},	//   _peku_, _perč, --, --, 
   {{0x3f80011f,0x2b5c01fb,0x7a3406af,0xa2b40073}},	//   _qeku_, _nguc_, nâtr, ेबद्, 
   {{0x2d81629c,0x3f81629d,0x64a0136b,0x27ed629e}},	// [245c0] _beje_, _veku_, _рақа, _mogn_, 
   {{0x25f406ab,0x44201d6f,0x3f81629f,0xc1d01b15}},	//   एसटी_, lnk_, _weku_, _төмә, 
   {{0x3f8162a0,0x2d8162a1,0xdcfc02fb,0x3b8406ed}},	//   _teku_, _deje_, _terč, влег, 
   {{0x9f400dd4,0x7a3400d2,0x2ca407de,0x442162a2}},	//   skiñ_, yâts, ànda_, nnk_, 
   {{0x442162a3,0x5f480116,0x2d8162a4,0x13b40154}},	//   ink_, _чүан_, _feje_, _জোড়, 
   {{0x61fc0789,0xdbd000a2,0x56941df2,0x2d80134e}},	//   nkrl, _hýüb, ңайт, _geje_, 
   {{0x27ec0c86,0x7e7477b9,0xbd340c75,0xee340408}},	//   _bogn_, lpyp, _شىرع, _рнр_, 
   {{0x1de0cead,0xe9d4010b,0x2d8162a5,0x00000000}},	//   नावत, екә_, _zeje_, --, 
   {{0x96343117,0xa3dc00ab,0x7c215eed,0xb4d80882}},	//   лниц, ठाई_, mnor, ठम्_, 
   {{0x3920067d,0x25a562a6,0x7c2162a7,0x4420017a}},	//   ትራውያ, _ccnl_, lnor, enk_, 
   {{0x27ec8d2d,0x9f40026c,0x151413f3,0x8cd4033f}},	//   _fogn_, hjià_, удня, णियो, 
   {{0x7c2162a8,0x00000000,0x00000000,0x00000000}},	//   nnor, --, --, --, 
   {{0x569562a9,0xa2d162aa,0x41dc53c7,0x7c20eb20}},	//   _салт, दिष्, मांस, inor, 
   {{0x7c200639,0xe704072d,0xaa380092,0x00000000}},	//   hnor, _جسمی, ስፈልጋ, --, 
   {{0x22580b32,0x7c2162ab,0xd7f80311,0x2d801e0b}},	//   тиры_, knor, _luăm_, _reje_, 
   {{0x28d11269,0x2d8162ac,0x5f94872a,0x7c2162ad}},	//   थिति, _seje_, иист, jnor, 
   {{0x2d814861,0x7c200609,0xdef4e3cd,0xdd1c00d7}},	// [245d0] _peje_, dnor, апты, láňa, 
   {{0x9f4009cc,0x7c2000a9,0xdcfc06be,0xa184013d}},	//   rkið_, enor, _abrı, _кыюл, 
   {{0x2d8162ae,0x4a5402dd,0x7e7400e4,0x7af4143a}},	//   _veje_, ңкес, apyp, øytn, 
   {{0x7c2162af,0x200c8d22,0xcb693bf2,0x660c04e6}},	//   gnor, èdit_, رمته_, éckz, 
   {{0x2d8002d3,0x27ec6a0d,0xdd1c0030,0x78b81ebf}},	//   _teje_, _rogn_, háňa, _aptv, 
   {{0x27ecacbc,0x7c2162b0,0x75280208,0xe0d00bce}},	//   _sogn_, anor, _oxfz, _ازی_, 
   {{0x7c2162b1,0x2b90030f,0x628001d3,0x45840116}},	//   bnor, _نیاس, ámoz, ңгив, 
   {{0x06c80276,0x3a7024a5,0xc308015b,0x44200789}},	//   егий_, шләр, রপতি_, xnk_, 
   {{0x27ec1512,0x7a340129,0x7d0001e4,0xdcfc00de}},	//   _vogn_, râtr, ŝost, _ierā, 
   {{0x6ab80421,0x7a340129,0x62400108,0x68400150}},	//   _ipuf, sâtr, töom, ынқа, 
   {{0x44200109,0x6ab80334,0x27ec0165,0x7a340129}},	//   tnk_, _hpuf, _togn_, pâtr, 
   {{0x057404d3,0x62e801d9,0xa2d05b29,0x7e7400e4}},	//   _ڵاتد, نِجہ_, दिल्, ypyp, 
   {{0x25a40113,0xe77400c7,0x442162b2,0x9f400108}},	//   _tcnl_, _заҵә_, rnk_, lkiö_, 
   {{0xfb1404ac,0xe1f8016c,0x442162b3,0x00000000}},	//   אַלט_, тҳо_, snk_, --, 
   {{0x442005b1,0x7c200042,0x09cc0154,0xf2e40244}},	//   pnk_, ynor, লাপা, نکیه_, 
   {{0xd9c02f0a,0x58fc031c,0xdcfc00e2,0x00000000}},	//   _एस्ट, ྐྱིས_, _nerā, --, 
   {{0x6d44012d,0xfd98007b,0x7c2162b4,0xb21803b2}},	// [245e0] _azja, فئات_, vnor, vsæv, 
   {{0xef1c04cc,0xfce562b5,0x7e740af9,0xdcfc00ef}},	//   _adüs_, лозо, rpyp, _aerā, 
   {{0x21f401c7,0x7e740af9,0xb5f8010f,0x8e5402dd}},	//   _fähr_, spyp, עלעכ, ртті, 
   {{0xab8162b6,0x7c200099,0x9e753b7b,0xf534010f}},	//   бушк, unor, _نۇرت, אטער_, 
   {{0x6d44009d,0x00000000,0x00000000,0x00000000}},	//   _ezja, --, --, --, 
   {{0x2010012d,0xec740139,0x00000000,0x00000000}},	//   żnią_, _әпт_, --, --, 
   {{0x7e6402d1,0xb21962b7,0x6e2801ed,0x2bcc0073}},	//   _hukp, msæt, égbe, _सोका, 
   {{0xb21804ce,0x7648036e,0x7c200200,0x00000000}},	//   lsæt, _shfy, qnor, --, 
   {{0x7e640309,0x66000175,0xeb9462d9,0x7bc162b8}},	//   _jukp, _blnk, _щит_, meou, 
   {{0xb21869e8,0x00000000,0x00000000,0x00000000}},	//   nsæt, --, --, --, 
   {{0x7988014b,0x00000000,0x00000000,0x00000000}},	//   mafw, --, --, --, 
   {{0x7bc162b9,0x798962ba,0x366800d8,0xdd1c00d7}},	//   neou, lafw, _задо_, ráňa, 
   {{0xb21804ce,0xa8340a1e,0x6fa000e1,0x0b340240}},	//   ksæt, _גראד_, गलसू, _እናተማ, 
   {{0x7bc00270,0x798801f5,0x00000000,0x00000000}},	//   heou, nafw, --, --, 
   {{0xb21804ce,0xe4503ee6,0xdef002d3,0xd4c405a2}},	//   dsæt, تضی_, _ዀይኑ_, _төпк, 
   {{0xd9040c55,0x7e6401e3,0x79880142,0x338400c0}},	//   _ہی_, _bukp, hafw, _сукв, 
   {{0x8e1562bb,0x1de002ab,0x7bc162bc,0x798802ce}},	// [245f0] адац, नांत, deou, kafw, 
   {{0x273001dc,0xd9046f51,0x6b580793,0x6ab80ffb}},	//   ợng_, _فی_, _lägü, _rpuf, 
   {{0x798801f5,0x7760022e,0x09cc0011,0x644c012d}},	//   dafw, _ogox, লামা, łnił, 
   {{0x7bc0a0b0,0xf3fc0589,0x7760004b,0x6b841d37}},	//   geou, nkã_, _ngox, اشال, 
   {{0xd5b800e2,0x00000000,0x00000000,0x00000000}},	//   enām_, --, --, --, 
   {{0x7988017a,0xede401b9,0x09cc0154,0x00000000}},	//   gafw, _сўмн, লাভা, --, 
   {{0x6b580432,0x6d440171,0x00000000,0x00000000}},	//   _bägü, _uzja, --, --, 
   {{0x7bc162bd,0x660001f1,0xf8b401e0,0xd720012d}},	//   ceou, _slnk, рөф_, मपंथ_, 
   {{0x6b8962be,0x44c40421,0x6ab80607,0xc60562bf}},	//   magg, _sœ_, _upuf, изий, 
   {{0x58fc003d,0x7af4023a,0x00000000,0x00000000}},	//   ྐྱངས_, äyte, --, --, 
   {{0x69c162c0,0x66000306,0xd8740345,0x00000000}},	//   mene, _vlnk, _هانب, --, 
   {{0x69c0bd81,0x6b8962c1,0x03a4130f,0xdcfc0356}},	//   lene, nagg, шимо, _heră, 
   {{0x69c05095,0xb2184c5d,0x27fd62c2,0x00000000}},	//   oene, jsæs, mkun_, --, 
   {{0x41281830,0x69c162c3,0x27fd62c4,0x6b8962c5}},	//   вого_, nene, lkun_, hagg, 
   {{0x69c162c6,0x6b881418,0x801400a8,0x6b580139}},	//   iene, kagg, афац, _yägü, 
   {{0x69c162c7,0x7e6562c8,0x27fd62c9,0xf3fc0004}},	//   hene, _pukp, nkun_, ckã_, 
   {{0x6b8962ca,0x2bb8726a,0x27fd62cb,0xbea4a406}},	// [24600] dagg, ोजना, ikun_, разк, 
   {{0x628400b0,0xdcfc0311,0xe3e800cc,0x5f0402dd}},	//   _iwio, _neră, _পতিব, азға, 
   {{0xb21962cc,0x7bc0bed5,0x27fd62cd,0x6b88a723}},	//   rsæt, teou, kkun_, fagg, 
   {{0x6b8962ce,0x27fc0063,0x628400f1,0x8d540a93}},	//   gagg, jkun_, _kwio, стуч, 
   {{0x69c162cf,0x7bc023d2,0x200001d9,0x6240023a}},	//   fene, reou, mkii_, töoh, 
   {{0x20000a81,0x7bc0074d,0xf8a81d0a,0x27fc012d}},	//   lkii_, seou, ندبه_, ekun_, 
   {{0x6b8962d0,0xa3c835e8,0xf3fc0589,0xa9640e92}},	//   bagg, ैया_, ykã_, шија_, 
   {{0x200162d1,0x33f8002e,0xb2181427,0x00000000}},	//   nkii_, _tëxi_, nsær, --, 
   {{0xa9200724,0x20000ba7,0xdcfc0356,0x6d60054e}},	//   йдәл, ikii_, _feră, ştaş, 
   {{0x2001415b,0x3eb00153,0x5ed41870,0xaa5400f3}},	//   hkii_, ityt_, ﺟﺒﯘﺭ, _виђу_, 
   {{0x20009341,0xf3fc0589,0xaef8004d,0xa9651a8f}},	//   kkii_, tkã_, _ngùn, _тиха_, 
   {{0xb4c4038e,0x62840428,0x20000014,0x28d00037}},	//   _उनी_, _bwio, jkii_, थिरि, 
   {{0x20000a81,0x660c0036,0xa3c80037,0x483400f1}},	//   dkii_, ëckc, _उसर_, _اونړ, 
   {{0xf3fc0004,0x200162d2,0xc1a401ec,0xceb800d1}},	//   skã_, ekii_, йысқ, қәм_, 
   {{0x6b8962d3,0x20000050,0x463800c8,0xf1a962d4}},	//   yagg, fkii_, _געװע, _یاده_, 
   {{0x69c162d5,0x6b88011c,0xb21801bf,0xf9fc00cc}},	//   zene, xagg, tsæs, ্চিল_, 
   {{0x69c01813,0x6b8962d6,0xe2c8004b,0x62842f50}},	// [24610] yene, vagg, _نويو_, _gwio, 
   {{0x69c162d7,0x2d841dec,0x6b8962d8,0x2000c17b}},	//   xene, úne_, wagg, akii_, 
   {{0x6b8962d9,0x41b41129,0x20000050,0x27fc03f0}},	//   tagg, _امپر, bkii_, ykun_, 
   {{0x6d580115,0x2d84033f,0xc7b801d3,0xf8d800cd}},	//   _ĝuad, źne_, tnőm_, भिनय, 
   {{0x6b8962da,0xa96422f7,0xac7489c9,0x01ac0154}},	//   ragg, қиқа_, _چارش, _ছোটদ, 
   {{0x6b8962db,0x3138001f,0x88c562dc,0x6240005b}},	//   sagg, _የቤተክ, متعل, töoi, 
   {{0x69c162dd,0x27fc008c,0x6b881c06,0x99640bd6}},	//   rene, tkun_, pagg, әтәл, 
   {{0x6eb8038e,0x27fcc2d0,0x068401d5,0x2bcc00bc}},	//   _उहाँ, ukun_, бгин, _सोचा, 
   {{0xa9c40c04,0x27fd62de,0xd7f8026a,0x00000000}},	//   _всек, rkun_, руј_, --, 
   {{0x85e962df,0xc4c801c0,0x69c00240,0x3ed8008f}},	//   удов_, глож_, qene, אַטא, 
   {{0x628402b9,0x27fc1b25,0x58d40166,0x737c00d1}},	//   _swio, pkun_, _мофт, ﯩﻨﯩﺶ_, 
   {{0xa3c801f9,0x3eb00108,0x00000000,0x00000000}},	//   _उसळ_, ytyt_, --, --, 
   {{0x7c3801a8,0x200003e0,0x00000000,0x00000000}},	//   _ítre, vkii_, --, --, 
   {{0x67b803e6,0x008401c6,0xf674010f,0x2000058a}},	//   _ساڵح_, йлго, _הײסט_, wkii_, 
   {{0x200162e0,0x00000000,0x00000000,0x00000000}},	//   tkii_, --, --, --, 
   {{0xb4f80302,0x2000198f,0xcaf801ad,0x442562e1}},	//   _תפקי, ukii_, ्नाड_, _ño_, 
   {{0x20000d62,0x6d40002f,0x00000000,0x00000000}},	// [24620] rkii_, ünan, --, --, 
   {{0xbd889010,0xe058034c,0x200001d9,0xb21952dc}},	//   انان_, _چیست_, skii_, ssær, 
   {{0xe0580502,0x3eb01507,0xc0e80451,0xa2d000cd}},	//   _نیست_, styt_, _صفحن_, दिक्, 
   {{0xab8000a8,0xbb480472,0x00000000,0x00000000}},	//   пушк, هلان_, --, --, 
   {{0xaab40f1b,0x955c0b82,0xafd801bf,0x8b64c1ac}},	//   مدور_, _ሰዓትን_, _skøg, زانم, 
   {{0xdca40220,0xad64009d,0x00000000,0x00000000}},	//   _қағи, _гарз_, --, --, 
   {{0xef1c01b8,0x81e803d4,0xec74009b,0xb8640472}},	//   _leül_, _মতা_, _гпс_, حاتو, 
   {{0x77901d0a,0x00000000,0x00000000,0x00000000}},	//   سیتا, --, --, --, 
   {{0xa3ac0da3,0xa3cc033f,0xca7401c6,0x6ed81fe7}},	//   खलन_, रजन_, _духы, नियु, 
   {{0x9bc400cf,0xb6a401d5,0x00000000,0x00000000}},	//   _دەچۉ, _ҳидл, --, --, 
   {{0xaa542ba5,0xe97000b2,0x09b0045e,0x00000000}},	//   _اللا_, _رهند, _টোকা, --, 
   {{0xdcfc0153,0x00000000,0x00000000,0x00000000}},	//   _gerą, --, --, --, 
   {{0xa2d01fe5,0x8474001f,0x00000000,0x00000000}},	//   दिग्, _የሰሜን_, --, --, 
   {{0x55580953,0xb33800a2,0x00000000,0x00000000}},	//   _каля_, ngçi, --, --, 
   {{0x63b4dbcd,0x3d00012d,0x76a001e1,0x00000000}},	//   _ženš, लनों_, bíyì, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf41d62e2,0xa5200166,0xceb800d1,0x00000000}},	// [24630] miä_, _ммәд, шән_, --, 
   {{0xf41c0877,0xafd962e3,0xeff40020,0x9df80108}},	//   liä_, _skød, ወቂያ_, бнут_, 
   {{0xb0c0010a,0x00000000,0x00000000,0x00000000}},	//   _хăех_, --, --, --, 
   {{0xf41d614a,0x58fc0003,0xb4c40118,0x00000000}},	//   niä_, ྐྱབས_, _उनै_, --, 
   {{0x6e4003e6,0xdef800fb,0x00000000,0x00000000}},	//   _فۆرم, _лыр_, --, --, 
   {{0xf41c02f6,0xdea45022,0x5ce400cf,0x00000000}},	//   hiä_, _ریمی, تكۅل, --, 
   {{0xf41c049b,0x00000000,0x00000000,0x00000000}},	//   kiä_, --, --, --, 
   {{0xf41c02f6,0xb2181cf3,0x00000000,0x00000000}},	//   jiä_, lpæd, --, --, 
   {{0xf41c2776,0x060962e4,0xe9a80244,0x955c01f3}},	//   diä_, иник_, _مدان_, _ሰዓቱን_, 
   {{0x04b40395,0x09cc0154,0x00000000,0x00000000}},	//   осмя, লাহা, --, --, 
   {{0xd7c8034c,0xf41c0716,0xef1c004e,0x4ab8000d}},	//   _گونه_, fiä_, _seül_, _इहँव, 
   {{0xd9c400cc,0xf41c00fd,0xb33800a2,0x00000000}},	//   _এচএম, giä_, lfçy, --, 
   {{0xd7c91147,0x42b802d5,0xe7dc166d,0xc7b800e5}},	//   _دونه_, шыню_, _खोया_, mfő_, 
   {{0xc8ac0cbf,0x7af408fb,0x242801c0,0x200c00e2}},	//   _टमाट, øyti, рхүү_, īdim_, 
   {{0xdb2001d3,0xabe401ec,0xf41c013d,0x6d400037}},	//   _ötöd, _ﺍﺗﺎﻋ, biä_, ünal, 
   {{0x1dac006d,0xf41cd7e6,0x7410004b,0x4ab80037}},	//   _चाहत, ciä_, _يووا, _इहंव, 
   {{0xa0681669,0x00000000,0x00000000,0x00000000}},	// [24640] раға_, --, --, --, 
   {{0x3fc401ed,0x6da001d5,0x00000000,0x00000000}},	//   _ڈگری_, дифа, --, --, 
   {{0x741012e1,0x6cb00228,0x80c40073,0xad8400cf}},	//   _رویا, мөтт, ाबळे, زالۇ, 
   {{0xafe00137,0x26cc0042,0x00000000,0x00000000}},	//   _жоюл, _osgo_, --, --, 
   {{0xeaac00f7,0xb4c4033f,0xf4100375,0xf8c0578b}},	//   نعو_, _उन्_, ופא_, _वैजय, 
   {{0xafd80450,0xfca80451,0x58d400cf,0x6e90009a}},	//   _uhør, _پاسو_, зокт, _زلفا, 
   {{0x41b076f8,0x00000000,0x00000000,0x00000000}},	//   _जानस, --, --, --, 
   {{0x3b84f423,0xfaa402a9,0x28d80037,0x00000000}},	//   _флаг, _мабо, _मछरि, --, 
   {{0xf41d62e5,0x41c8f5d8,0x00000000,0x00000000}},	//   viä_, ाजास, --, --, 
   {{0x88c400db,0xb5a4009d,0xa964011c,0x00000000}},	//   تتۇل, црий, _дифа_, --, 
   {{0xf41c0877,0x387007d6,0x00000000,0x00000000}},	//   tiä_, _ўқит, --, --, 
   {{0xdb1c00ae,0x77901bf4,0x00000000,0x00000000}},	//   _ózói, _کیکا, --, --, 
   {{0xf41c071f,0x57b002dd,0x00000000,0x00000000}},	//   riä_, _жұқт, --, --, 
   {{0xf41c8b51,0x74683169,0xff28010c,0x925801c6}},	//   siä_, _крив_, _ተመራመ, сагт_, 
   {{0xf41c02f6,0x257001ec,0x00000000,0x00000000}},	//   piä_, _تۇپس, --, --, 
   {{0x533562e6,0x799803ac,0x289800df,0x00000000}},	//   _нейт, _ldtw, יילא, --, 
   {{0x79980034,0x234800db,0x7044004e,0x00000000}},	// [24650] _odtw, _ولىپ_, йүүм_, --, 
   {{0x41b01fe5,0x799802d0,0x28d8012d,0x918015bf}},	//   _जायस, _ndtw, _मछलि, _سۇرۇ, 
   {{0xd7bc0073,0x2bc800c7,0xc7b800e5,0x333400e5}},	//   ्जाच, иудо_, yfő_, _ديکھ_, 
   {{0x64580137,0xa92000bc,0xdcf8036b,0xb21801bf}},	//   _èxit, ůžko, غرلش_, spæd, 
   {{0x7f7405e1,0x9b44da98,0xe21410e8,0x00000000}},	//   _מערב_, ونمو, _ربیع, --, 
   {{0xdea413f9,0x00000000,0x00000000,0x00000000}},	//   _آیلی, --, --, --, 
   {{0xc7b800dd,0x09cc0154,0x99d43cc6,0x00000000}},	//   tfő_, লালা, بتنا, --, 
   {{0x0684036b,0xa2ac0073,0x7d1800a2,0x00000000}},	//   пгин, _जमल्, _ýtsa, --, 
   {{0x6b982819,0xea9c00cd,0xe74401e0,0x79e801d3}},	//   _idug, _doṣo_, әүһе_, _گولہ_, 
   {{0x6b980165,0x0608005b,0x00000000,0x00000000}},	//   _hdug, снок_, --, --, 
   {{0x044562e7,0xf5e4009d,0x7c4802d2,0x3a3000e4}},	//   зенн, чмэл_, _ápró, éype_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x1dac0574,0x00000000,0x00000000,0x00000000}},	//   _चालत, --, --, --, 
   {{0xbb3800c8,0xe7dc00e1,0xf484085b,0x97a460c6}},	//   מערי, _खोता_, _کاوی, _ерәл, 
   {{0xae680145,0xa2d000bc,0x00000000,0x00000000}},	//   ەشمە_, दिङ्, --, --, 
   {{0x6b9962e8,0x7498011a,0xf06162e9,0x838962ea}},	//   _ndug, _היקפ, експ, _убив_, 
   {{0x442162eb,0x00000000,0x00000000,0x00000000}},	// [24660] mik_, --, --, --, 
   {{0xa3b81a22,0x6b9962ec,0x7bdc005f,0x00000000}},	//   घ्र_, _adug, ēpum, --, 
   {{0xbb8400be,0xfbd000e5,0x00000000,0x00000000}},	//   كلاي, ٹتا_, --, --, 
   {{0x442162ed,0x5bb802bf,0x46bc085c,0x41b001f9}},	//   nik_, ілля_, ्बाह, _जाडस, 
   {{0x3f9162ee,0x6b980142,0x4420003e,0x79980857}},	//   mayu_, _ddug, iik_, _pdtw, 
   {{0x44201bb7,0x3f900201,0x6b9962ef,0x0ae87da6}},	//   hik_, layu_, _edug, ترمي_, 
   {{0x442162f0,0xa3ad1afa,0xa3cc19e9,0xea9c0055}},	//   kik_, खला_, रजा_, _poṣo_, 
   {{0x442162f1,0x3f90ded4,0xe7dc00ab,0x567810e4}},	//   jik_, nayu_, _खोदा_, обия_, 
   {{0x442162f2,0x7c2162f3,0xfaa400c2,0x2cbc16a3}},	//   dik_, mior, _хазо, _ćudi_, 
   {{0x7c2162f4,0x3f90065c,0x6d900124,0xd49800d4}},	//   lior, hayu_, _iñañ, окої_, 
   {{0x442162f5,0x3f9162f6,0xa59001b9,0x00000000}},	//   fik_, kayu_, رگوچ, --, 
   {{0x442162f7,0x7c201e3d,0x88c4007b,0x00000000}},	//   gik_, nior, _تتكل, --, 
   {{0x3f9162f8,0x66e00108,0xb604010a,0x00000000}},	//   dayu_, _поца, _някк, --, 
   {{0x7c2162f9,0x44200af9,0x00000000,0x00000000}},	//   hior, aik_, --, --, 
   {{0x442162fa,0x7c2162fb,0x38640076,0x25d4011a}},	//   bik_, kior, _kior_, _מוגן_, 
   {{0x442162fc,0x7c2162fd,0x3f9162fe,0x00000000}},	//   cik_, jior, gayu_, --, 
   {{0x7c2162ff,0x38640ac5,0xb8dc025c,0x6b9801ab}},	// [24670] dior, _mior_, _ཇཱ_, _rdug, 
   {{0x38640072,0x00000000,0x00000000,0x00000000}},	//   _lior_, --, --, --, 
   {{0x7c216300,0x6d916301,0x624112c5,0xd5b800e2}},	//   fior, _añañ, möop, lnās_, 
   {{0x7c200c04,0xa0a40598,0xd0540134,0x3f90011f}},	//   gior, _яшьл, _ɛbɛm, cayu_, 
   {{0xaa640139,0x00000000,0x00000000,0x00000000}},	//   чтек, --, --, --, 
   {{0x44216302,0x246401e1,0x4878236b,0x00000000}},	//   zik_, _kèmì_, осия_, --, 
   {{0x44216303,0x7c216304,0x38656305,0x6d9000e4}},	//   yik_, bior, _bior_, _eñañ, 
   {{0x7c216306,0x44216307,0x2d916308,0x6b98b3ae}},	//   cior, xik_, laxe_, _udug, 
   {{0x44216309,0x6d4400a2,0x7af42dba,0xa3ac0037}},	//   vik_, _hyja, øytt, खलस_, 
   {{0x2d91630a,0x3f9002ce,0x9f64020c,0x6d4400d7}},	//   naxe_, zayu_, éwéi_, _kyja, 
   {{0x3865630b,0xd5b8005f,0x00000000,0x00000000}},	//   _fior_, enās_, --, --, 
   {{0x3864011c,0x6d440030,0x19f000c7,0x27b064b6}},	//   _gior_, _myja, _аҟәр, _чәкс, 
   {{0x6d4400c0,0x3f90022e,0x00000000,0x00000000}},	//   _lyja, vayu_, --, --, 
   {{0x4421630c,0x7c21630d,0xd9f034ef,0x6d5800df}},	//   sik_, zior, चायत_, _ĝuan, 
   {{0x4421630e,0x3f91630f,0x2d90056a,0x6d456310}},	//   pik_, tayu_, daxe_, _nyja, 
   {{0x7c216311,0x38680ba1,0x44216312,0x00000000}},	//   xior, _èbre_, qik_, --, 
   {{0x7c216313,0x44316314,0x64456315,0x6d44cbfc}},	// [24680] vior, _ijy_, _ikii, _ayja, 
   {{0x69bc4309,0x3f916316,0x7c216317,0x2d916318}},	//   ल्मी, sayu_, wior, gaxe_, 
   {{0x7c216319,0xdcfc0165,0x3f90003e,0x3f681069}},	//   tior, _idrī, payu_, _мино_, 
   {{0xfaa456b2,0x6d440240,0x7c200381,0x515400fb}},	//   дадо, _dyja, uior, _ятыу, 
   {{0x6444d784,0x6d440008,0x2d90011f,0x44300175}},	//   _mkii, _eyja, baxe_, _mjy_, 
   {{0x7c200af5,0xe6048fdc,0x38640afe,0x6ed800cd}},	//   sior, _شش_, _sior_, निरु, 
   {{0x38640261,0x64440069,0x7c21631a,0x443000c7}},	//   _pior_, _okii, pior, _ojy_, 
   {{0x443009a5,0x64441418,0xaef800a3,0xd7f0007b}},	//   _njy_, _nkii, _sgùi, اكة_, 
   {{0x6d900054,0x00000000,0x00000000,0x00000000}},	//   _uñañ, --, --, --, 
   {{0x6445631b,0x4430010b,0x6d44037e,0xd5b80171}},	//   _akii, _ajy_, _yyja, ciāl_, 
   {{0x76580175,0x3864007c,0x00000000,0x00000000}},	//   rmty, _tior_, --, --, 
   {{0x2d90172e,0x36680798,0x00000000,0x00000000}},	//   zaxe_, _дадо_, --, --, 
   {{0xa3440323,0x27f40232,0x63b402fb,0x44300ea0}},	//   вэрл, žená_, _žená, _djy_, 
   {{0x64441418,0xc0dc02d3,0x46bc00bc,0xe5c001f0}},	//   _ekii, _ሕሰም_, ्बरह, _асъо, 
   {{0x64440270,0x00000000,0x00000000,0x00000000}},	//   _fkii, --, --, --, 
   {{0x1fa42bbd,0xe3f8007b,0xe7a400c5,0x6d440064}},	//   круг, _يعيش_, _गाछप, _ryja, 
   {{0x2d91631c,0xad2401d9,0x69bc01f9,0x00000000}},	// [24690] taxe_, ڈراو, ल्डी, --, 
   {{0xad25631d,0x00000000,0x00000000,0x00000000}},	//   وراو, --, --, --, 
   {{0x2d91631e,0x20e8041e,0xc0c001ee,0x00000000}},	//   raxe_, ríið_, _йәти, --, 
   {{0x2d90172e,0x6d440313,0xb0000055,0x00000000}},	//   saxe_, _vyja, _kaḍe, --, 
   {{0x6d44068f,0x387c030d,0x2d900005,0x3f780a7c}},	//   _wyja, _attr_, paxe_, _מארס, 
   {{0x08d4d394,0x80a4012c,0x2ca407c5,0x6aa8017a}},	//   еция, _छिमे, ànds_, rugf, 
   {{0x480801c6,0x7af403cd,0x00000000,0x00000000}},	//   зейн_, øytr, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x86c40472,0x00000000,0x00000000,0x00000000}},	//   ريدن, --, --, --, 
   {{0x78ac007b,0x64446853,0x998400ae,0x00000000}},	//   óivé, _skii, _للكو, --, 
   {{0x854809a5,0x387c2b52,0x80bc000d,0x6fac01f9}},	//   язов_, _gttr_, _ऊहें, टलां, 
   {{0xafd8019b,0x58842b61,0x82a401c6,0x6fdc01f9}},	//   _skøn, _рыфа, намж, _पोलं, 
   {{0xa6100075,0xaadc043e,0x00000000,0x00000000}},	//   _издә, फटिक, --, --, 
   {{0x85b80050,0x00000000,0x00000000,0x00000000}},	//   _راتس_, --, --, --, 
   {{0xa44403e6,0x84e401c6,0x00000000,0x00000000}},	//   _لێدو, _чойж, --, --, 
   {{0x6445631f,0x44300432,0x28a427a6,0x00000000}},	//   _ukii, _ujy_, _गिनि, --, 
   {{0x2a7c0211,0xdcf407f5,0x8f7401ca,0x26dc0108}},	// [246a0] _ntub_, đačk, тусі, nvuo_, 
   {{0x8d84e750,0x8e800107,0x00000000,0x00000000}},	//   نشمن, рҳре, --, --, 
   {{0x2a7c089c,0xb0ac2871,0x62800115,0xa3e444e3}},	//   _atub_, जूदग, ŭmod, _नफा_, 
   {{0xe7dc06bc,0xa0240023,0x00000000,0x00000000}},	//   _खोला_, _ተገዲዶ, --, --, 
   {{0xed540139,0x00000000,0x00000000,0x00000000}},	//   _җот_, --, --, --, 
   {{0xdc8401ec,0x00000000,0x00000000,0x00000000}},	//   _ақжо, --, --, --, 
   {{0xa8a00139,0x00000000,0x00000000,0x00000000}},	//   грык, --, --, --, 
   {{0xd6d00597,0x2ca400d2,0x3e740165,0x7d10247e}},	//   لقب_, ánde_, _kæt_, ıksı, 
   {{0x6d4007de,0x39e000fb,0xc73c0092,0xa3e4578b}},	//   ünav, _бәйғ, _አታውቅ, नयन_, 
   {{0x3e743c38,0x4b5402e8,0xc1c805c0,0x00000000}},	//   _mæt_, _ръст, ाजोग, --, 
   {{0x54543576,0x3e7405f7,0xe4e00006,0x6e2800e5}},	//   квот, _læt_, гіян, égbi, 
   {{0x38b8044e,0xf31404b4,0x00000000,0x00000000}},	//   mër_, енмә_, --, --, 
   {{0x38b81bce,0xf6280150,0x25a80118,0xf3640246}},	//   lër_, _ىستى_, áhlé_, этон, 
   {{0xdcfc00df,0xf2dc003a,0xb4b02a9d,0x00000000}},	//   _serĝ, rvâ_, _бикә, --, 
   {{0x38b883cc,0x066421e7,0xe0d000e5,0xdef80022}},	//   nër_, _شاهپ, یزہ_, ҭыу_, 
   {{0xdfd56320,0x80c005d7,0x3e7402d2,0x00000000}},	//   лосы, _लहरे, _bæt_, --, 
   {{0xe3b09f5f,0xb8d00327,0x38b80240,0xef200092}},	// [246b0] _ارى_, _ཟའ_, hër_, _ተዘዋው, 
   {{0x38b96321,0x98e0012d,0xcd8000d1,0x00000000}},	//   kër_, पटाए, شۇرۋ, --, 
   {{0x2a7d6322,0xaef80241,0xddd00276,0x8c180451}},	//   _stub_, _agùt, şeşt, ويئر_, 
   {{0x38b802d3,0xaa840133,0x0cd0000d,0x00000000}},	//   dër_, فۆرم_, _सनीम, --, 
   {{0x38b80660,0x3e74037e,0xc5ec00fe,0x00000000}},	//   eër_, _gæt_, য়োটা_, --, 
   {{0x38b8ce7b,0x31540092,0x00000000,0x00000000}},	//   fër_, _ለቤተክ, --, --, 
   {{0x3b040784,0x38b80694,0xe2380092,0x1a693c28}},	//   ayoq_, gër_, ረሊባኖ, ریمی_, 
   {{0x46e81b74,0xc30803d4,0x00000000,0x00000000}},	//   ддин_, ৰপতি_, --, --, 
   {{0x41b03c71,0x00000000,0x00000000,0x00000000}},	//   _जालस, --, --, --, 
   {{0x99d4c651,0x38b802d3,0xafd803b2,0x49d80212}},	//   _متما, bër_, _skøl, _ідею_, 
   {{0xe9b00022,0x38b80023,0x26dc023a,0x58840137}},	//   _абҕь, cër_, svuo_, _быча, 
   {{0x36241973,0x29040209,0xf48523dd,0xd1743419}},	//   _یونہ, myna_, کایی, ғыры, 
   {{0x29056323,0x00000000,0x00000000,0x00000000}},	//   lyna_, --, --, --, 
   {{0xb218037e,0xb6a0036b,0xdddc00de,0x63c400b8}},	//   spæn, _тишл, _zirņ, _śunā, 
   {{0x3e74f4d8,0x29040209,0x41280a0e,0x00000000}},	//   _sæt_, nyna_, фово_, --, 
   {{0x04456324,0x3e7403b2,0x81e800b8,0x00000000}},	//   _шейн, _pæt_, _ṛtāy, --, 
   {{0x38b80023,0xdcfc0139,0x660c01c7,0x2904010b}},	// [246c0] zër_, _berğ, ëckw, hyna_, 
   {{0xee34504f,0x41040d44,0x3e7405ac,0xfce42cdd}},	//   вну_, _азов, _væt_, козо, 
   {{0x2904010e,0xce3400e5,0x00000000,0x00000000}},	//   jyna_, دولک, --, --, 
   {{0x29046b7e,0x3e74019b,0xff256325,0x200c00e2}},	//   dyna_, _tæt_, _аммо, īdis_, 
   {{0xaab56326,0xeb94ff3c,0x2904058a,0x38b80de2}},	//   ندور_, тич_, eyna_, wër_, 
   {{0x38b96327,0x19590e19,0x1dac02ab,0x958802d3}},	//   tër_, налы_, _चाटत, ኛታትን_, 
   {{0x290409a5,0x6d4004cc,0xec740064,0x00000000}},	//   gyna_, ünat, _апс_, --, 
   {{0xed556328,0xf0900302,0x38b82568,0xa9640063}},	//   _рос_, בנה_, rër_, њића_, 
   {{0x38b8b45c,0x7bc00204,0x3b040309,0x29040009}},	//   sër_, mfou, qyoq_, ayna_, 
   {{0x38b8069c,0x29040209,0x7ae0209c,0xef1c0165}},	//   për_, byna_, mvot, _zeüs_, 
   {{0x7ae16329,0x29040034,0x38b80200,0x00000000}},	//   lvot, cyna_, qër_, --, 
   {{0x932400c6,0xd9f0069f,0xfd4c01f2,0xdef8010c}},	//   _ỷα_, चावत_, wukọ, ፈተነ_, 
   {{0xb89c0092,0x00000000,0x00000000,0x00000000}},	//   _ሊሰጠው_, --, --, --, 
   {{0x7bc00327,0x7bc4032e,0x00000000,0x00000000}},	//   hfou, _ökuf, --, --, 
   {{0xa195632a,0xc7e801d9,0xb4b00131,0x7bc0257c}},	//   расч, _زى۪ن_, _тийә, kfou, 
   {{0xdcfd632b,0x2934010f,0x00000000,0x00000000}},	//   _nerđ, דאלן_, --, --, 
   {{0x29046b7e,0xef1c030a,0x7ae007f5,0xdef80139}},	// [246d0] zyna_, _reüs_, jvot, кыф_, 
   {{0x8d940b38,0x7bc001f5,0x4fc000f7,0x00000000}},	//   الاش, efou, _گەرە, --, 
   {{0x7ae00472,0x0f340133,0x2904058a,0x6ab8036e}},	//   evot, _ڵکرد, xyna_, _squf, 
   {{0x4fc02e51,0x0f7800df,0x00000000,0x00000000}},	//   _دەرە, _ראָב, --, --, 
   {{0x09cc03d4,0x81e400fe,0x4ac4215c,0x00000000}},	//   লাঘা, _ভকত_, ايتق, --, 
   {{0x2905632c,0x7bc00618,0x6d400213,0x39400075}},	//   tyna_, afou, ünas, әнъг, 
   {{0x58940184,0x9f400321,0x2904003e,0x00000000}},	//   ашыу, ljið_, uyna_, --, 
   {{0x2905632d,0xafd800b5,0x393400c7,0x00000000}},	//   ryna_, _skøj, ыҧхь_, --, 
   {{0x290409a5,0x77c401c6,0x9f4003b2,0x00000000}},	//   syna_, улыг_, njið_, --, 
   {{0x45d44961,0x5b1401af,0x00000000,0x00000000}},	//   уцит, _тмут, --, --, 
   {{0xdb0035fe,0x69c00010,0xd9f00073,0xda08009a}},	//   _admè, mfne, चारत_, _جيله_, 
   {{0xb218022c,0xd8740131,0x00000000,0x00000000}},	//   spæl, _ئالب, --, --, 
   {{0xe709632e,0x46a5632f,0x69c00ba7,0xafd833b8}},	//   _تتان_, _салв, ofne, _uhøy, 
   {{0x8234b94d,0x7bc00007,0x6aa836f4,0xddd40419}},	//   ارحا, zfou, irgf, _ťažo, 
   {{0xf650025f,0x69c00ba7,0x7bc00072,0xc05800f3}},	//   _הצג_, ifne, yfou, ерац_, 
   {{0x27ec020b,0x7ae00124,0x940c03b9,0x00000000}},	//   _jngn_, yvot, ksdə_, --, 
   {{0x82356330,0x63a56331,0x93256332,0xaef808c2}},	// [246e0] _مردا, _idin, _پرين, _sgùr, 
   {{0x62856333,0x7bc16334,0xdcfc00f3,0x7ae00135}},	//   _itio, wfou, _serđ, vvot, 
   {{0x412801c0,0xdd2800ef,0x00000000,0x00000000}},	//   _чоно_, _bēša, --, --, 
   {{0x69c16335,0x92c803d4,0x601802d2,0xdb8400c7}},	//   efne, োমৰ_, _símf, рҳаи, 
   {{0x7bc16336,0x63a56337,0x7ae0023a,0x60c8025c}},	//   rfou, _mdin, uvot, ħdmu, 
   {{0x69bc4195,0x7bc16338,0x7ae16339,0x63a401d5}},	//   ल्ली, sfou, rvot, _ldin, 
   {{0xed55633a,0x7ae1633b,0xa3e4739b,0x7bc1633c}},	//   _бор_, svot, नया_, pfou, 
   {{0x63a5633d,0x6285633e,0x19580032,0x7bc00007}},	//   _ndin, _otio, наһы_, qfou, 
   {{0x6284013f,0x27ec06df,0x6e2800d2,0x670405f5}},	//   _ntio, _dngn_, _ímbû, гээг_, 
   {{0x63a5633f,0xf4856340,0xa62801e1,0x00000000}},	//   _adin, лумн, _ṣòro_, --, 
   {{0x62840c8c,0x63a40166,0xdcfc00e2,0x68e00393}},	//   _atio, _bdin, _ierē, cvnd, 
   {{0xdb000ba1,0xe8d40302,0xdd100064,0xa93800df}},	//   _admé, _תואר_, ežūr, _אײבי, 
   {{0xe60c0502,0xdcfc04fe,0x63a56341,0x6284003a}},	//   زشی_, _kerē, _ddin, _ctio, 
   {{0x628400c6,0x925801c0,0xb504592e,0x63a56342}},	//   _dtio, тагт_, _مظبو, _edin, 
   {{0x6ea402e5,0xe5041913,0x00000000,0x00000000}},	//   _चिहु, _ميوو_, --, --, 
   {{0xdb0001c7,0x9f4001a8,0x24800419,0x80a400bc}},	//   _edmé, tjið_, íjme_, _छिरे, 
   {{0x34901086,0x69c0015d,0xdd2800ef,0x00000000}},	// [246f0] _тақр, yfne, _rēša, --, 
   {{0x63a401a6,0x9f50010e,0xdcfc0171,0xdd94007b}},	//   _zdin, _çaýa_, _nerē, مجمع, 
   {{0x63a56343,0x00000000,0x00000000,0x00000000}},	//   _ydin, --, --, --, 
   {{0x24b4010f,0x00000000,0x00000000,0x00000000}},	//   רהאן_, --, --, --, 
   {{0x66e80051,0x28a40037,0xd5c405c0,0x00000000}},	//   _mêkô, _गिहि, वभाज, --, 
   {{0x627c00c8,0x69c00e14,0xdcfc00e2,0xcc8801d5}},	//   ענונ, ufne, _cerē, _لنسه_, 
   {{0x27ec020b,0x5ce402d5,0x1e1400a7,0xab856344}},	//   _pngn_, _люта, _умря, _бузк, 
   {{0x06c80212,0x106c0150,0x00000000,0x00000000}},	//   вгий_, _ﺳﺎﺯﯨ, --, --, 
   {{0x63a56345,0x7af402f6,0x7ae800aa,0x69c0002f}},	//   _rdin, äytt, _ټولې_, pfne, 
   {{0x63a40200,0x26c0025c,0xd10405c0,0xb89400e5}},	//   _sdin, ċjo_, रहाण_, _چانڈ, 
   {{0x62856346,0x6e240334,0x601800e5,0x00000000}},	//   _stio, _mmjb, _híme, --, 
   {{0x04456347,0x62840072,0xe7740139,0x518c0150}},	//   ремн, _ptio, _садә_, _ﺒﺸﺭﻁ_, 
   {{0xc4f80014,0x660c0036,0x601801ef,0x00000000}},	//   ؑٹھا_, ëcks, _jíme, --, 
   {{0x0084cdc1,0xbbd000bc,0xe5c801e1,0x106c1d00}},	//   илго, _सस्क, _àpàà, _ﺳﺎﺭﯨ, 
   {{0x0164177b,0x74f402e9,0x63a4022e,0xa6b40154}},	//   ркво, _نفوز_, _tdin, _অনিয়, 
   {{0x63a419f8,0x66016348,0x4f9405f5,0x62840332}},	//   _udin, _honk, йруу, _ttio, 
   {{0x7e6c00e4,0x62856349,0x9f4001f4,0x00000000}},	// [24700] _pibp, _utio, hjiö_, --, 
   {{0x6601634a,0xfd11634b,0x8fd40116,0x2d84002d}},	//   _jonk, يجا_, _қәсә, űnen_, 
   {{0xbb840075,0x6601634c,0x8e5401ec,0xa2e800cc}},	//   للاي, _monk, стті, _পথিও, 
   {{0x9f400373,0xdcfc00ef,0xfbc4024c,0xf53400df}},	//   ndië_, _serē, рбдо, בטער_, 
   {{0x601800dd,0x6601634d,0xeab40108,0xdcfce321}},	//   _címe, _oonk, ийц_, _perē, 
   {{0x6601634e,0xd91405f5,0x601804d4,0xfce5634f}},	//   _nonk, йдлы, _díme, _кого, 
   {{0x8ccc2db8,0xada000c2,0x60181d0e,0xdb500133}},	//   _सहयो, _фасл, _tímd, _کێش_, 
   {{0x57f4e34b,0x28a49d35,0x00000000,0x00000000}},	//   спит, _गिरि, --, --, 
   {{0x6600124c,0xf1a4007d,0xdcfc00de,0x00000000}},	//   _bonk, _कएलन, _terē, --, 
   {{0x66016350,0x0ae80592,0x00000000,0x00000000}},	//   _conk, _حرفي_, --, --, 
   {{0x66016351,0x62800005,0x48143a49,0xb21801bf}},	//   _donk, ímon, рмөс, spæk, 
   {{0xe3b00592,0x6018032e,0x3dc801ef,0x00000000}},	//   ورُ_, _límb, _lbbw_, --, 
   {{0x660060d7,0x60180077,0x628000df,0x7c3802d2}},	//   _fonk, _oímb, ŭmon, _ítru, 
   {{0x3f816352,0x66016353,0x00000000,0x00000000}},	//   _afku_, _gonk, --, --, 
   {{0x92c8009e,0x62340276,0xe5c80241,0x16840345}},	//   োমে_, церу, _àpáà, _ئاڵێ, 
   {{0x66008cdb,0xe4e017ee,0x00000000,0x00000000}},	//   _zonk, गिरि_, --, --, 
   {{0x6600124c,0x60180241,0xd5b80618,0x6fc803d4}},	// [24710] _yonk, _bímb, ogā_, ৱালৈ, 
   {{0x273001dc,0xd5b96354,0x2ca56355,0xf1a4119e}},	//   ảng_, ngā_, ándo_, _трин, 
   {{0xd5b800e2,0x601809e8,0x00000000,0x00000000}},	//   igā_, _síme, --, --, 
   {{0x4a74064e,0xd5b8002b,0x00000000,0x00000000}},	//   быкт, bhāg_, --, --, 
   {{0x37bc1c82,0xdef850c0,0xcdc4013d,0xb0c40037}},	//   ্যাৰ, _кыр_, _гәеп, _लहँग, 
   {{0x2ba407ae,0x6018004e,0xe7dc0456,0xc89400ea}},	//   ốc_, _víme, _खोजा_, брињ, 
   {{0xbaa45026,0x660030f2,0x07a54146,0xec68322b}},	//   _қутқ, _ronk, байн, _арак_, 
   {{0x660053ff,0x2138011a,0x601800e5,0xd5b80171}},	//   _sonk, יטול_, _tíme, egā_, 
   {{0x66016356,0x00000000,0x00000000,0x00000000}},	//   _ponk, --, --, --, 
   {{0x66000113,0xb0c405b3,0x8c380117,0x00000000}},	//   _qonk, _लहंग, _роғӣ_, --, 
   {{0x660001f1,0x4de0009e,0x3ce8012d,0x00000000}},	//   _vonk, নাপূ, छिये_, --, 
   {{0x6600124c,0xd7c80691,0xe28401b9,0xe8dc0208}},	//   _wonk, _نومه_, оғин, _chụm_, 
   {{0x66016357,0xed84069c,0xd7c83418,0x392002d3}},	//   _tonk, ምንታይ_, _خونه_, ስያውያ, 
   {{0x27fc003d,0x41296358,0xc7b800e5,0x00000000}},	//   ljun_, гого_, lgő_, --, 
   {{0x3ea004cc,0x28bc09ab,0x00000000,0x00000000}},	//   _svkt_, _एमफि, --, --, 
   {{0x27fc4598,0x0084013e,0x3550007b,0xc7b801d3}},	//   njun_, илҳо, _عنيز, ngő_, 
   {{0xbdc805f5,0xd5b8002b,0x00000000,0x00000000}},	// [24720] лгаж_, bhād_, --, --, 
   {{0x82356359,0x6e91635a,0x9f41635b,0x3ea00064}},	//   _دربا, سلما, ndié_, _vvkt_, 
   {{0xed54466a,0xb3380205,0x00000000,0x00000000}},	//   боф_, taçg, --, --, 
   {{0xafd80162,0xd5b800e2,0x27fc031c,0x3f8003e0}},	//   _skøv, zgā_, jjun_, _ufku_, 
   {{0x0ef80064,0x00000000,0x00000000,0x00000000}},	//   _кэры_, --, --, --, 
   {{0x368801d5,0x90e40244,0x00000000,0x00000000}},	//   қсин_, _اسین, --, --, 
   {{0x20000ba7,0xafd8005c,0xf849635c,0x27fc08a5}},	//   ojii_, _djøf, лчий_, fjun_, 
   {{0x20000a55,0xc7b801d3,0x27fc0327,0x00000000}},	//   njii_, ggő_, gjun_, --, 
   {{0x6280172e,0xf64400c2,0x3af4030d,0x00000000}},	//   ímol, йхон, _уявс, --, 
   {{0x27fc0cfe,0x1dd80c2e,0x2000026c,0xbd240327}},	//   ajun_, ड़ित, hjii_, _རྟོཊ_, 
   {{0x79981af3,0xd5b80f40,0x48a80212,0x27fc031c}},	//   _ietw, rgā_, _втім_, bjun_, 
   {{0x25a40077,0x20000a55,0x799913ee,0xdd1c0419}},	//   _ednl_, jjii_, _hetw, káža, 
   {{0xdb00012c,0x1dd800e1,0xb3380139,0xf8b401ee}},	//   _odmí, ड़ात, kaçe, _төҙ_, 
   {{0x7790267a,0x98dc1d8a,0x799802e2,0x2000022f}},	//   _بیکا, _मनाए, _jetw, ejii_, 
   {{0x7999635d,0xf484009d,0x95c8022e,0x00000000}},	//   _metw, _уулн, _буқа_, --, 
   {{0xdb000077,0x7999635e,0xdddc010f,0x905402d5}},	//   _admí, _letw, _virŝ, івац, 
   {{0xdcfc00c0,0x00000000,0x00000000,0x00000000}},	// [24730] _kerė, --, --, --, 
   {{0x2000022f,0xb338415b,0x00000000,0x00000000}},	//   ajii_, gaçe, --, --, 
   {{0x22640316,0xfcc00116,0xdcfc0064,0x00000000}},	//   řské_, мәтм, _merė, --, 
   {{0xafd8168c,0xd15000b8,0xd7183507,0x0cc8012d}},	//   _sjøf, _aṅgo_, धनाथ_, _रहीम, 
   {{0x799950f7,0x6d480e78,0xab2800f2,0xb338013d}},	//   _betw, ßgab, دسال_, baçe, 
   {{0xe29c008f,0x9f400e78,0x31380092,0xdcfc00c0}},	//   נשור, leiß_, _ከቤተክ, _nerė, 
   {{0x7999635f,0x27fc02f6,0x98ac0006,0xdd9400ee}},	//   _detw, tjun_, _dydį_, _хасы, 
   {{0x0684be02,0x79986548,0xdddd2b94,0x48080484}},	//   огин, _eetw, _kirş, реин_, 
   {{0x27fc2507,0x79996360,0xd1e0001f,0x510400af}},	//   rjun_, _fetw, ነሳት_, रहुआ_, 
   {{0x6b98d0ab,0x79981a7c,0x9f400e78,0xdddc06be}},	//   _heug, _getw, heiß_, _mirş, 
   {{0xafd96361,0x6b980ac5,0xdcfc0024,0x601803b2}},	//   _gjøg, _keug, _derė, _líma, 
   {{0x74106aee,0xd7e4063b,0x6b9827c0,0x79996362}},	//   ِوَا, _нічо, _jeug, _zetw, 
   {{0x79996363,0x6b980098,0xafd8fcf4,0xc5e000eb}},	//   _yetw, _meug, _mjød, বাবপ, 
   {{0x6b996364,0xdd1c0030,0x40956365,0xdcfc0153}},	//   _leug, váža, жрат, _gerė, 
   {{0x10f4010a,0x00000000,0x00000000,0x00000000}},	//   пятя, --, --, --, 
   {{0x6b996366,0x35b0052f,0xdddc03ee,0xf4843c5a}},	//   _neug, _ебәр, _birş, _باوی, 
   {{0x2000198f,0xf4640092,0x00000000,0x00000000}},	// [24740] rjii_, _ታህሣሥ_, --, --, 
   {{0x6b980007,0x7e54063b,0xdd1c0030,0xafd803b2}},	//   _aeug, ітац, ráža, _skøt, 
   {{0x79996367,0x6b996368,0xafd805ac,0xba2828c4}},	//   _retw, _beug, _bjød, یستم_, 
   {{0x79996369,0x27400024,0xb3382330,0xb88408a5}},	//   _setw, _kūną_, saçe, hlíð, 
   {{0x7999636a,0xafd8143a,0x00000000,0x00000000}},	//   _petw, _sjøg, --, --, 
   {{0x79980455,0x995800d0,0x8b65636b,0x1f64010a}},	//   _qetw, _váži_, سانم, ĕкĕм, 
   {{0x6b980483,0x6cc1636c,0x799801f5,0x00000000}},	//   _feug, _ойра, _vetw, --, 
   {{0x6b99636d,0xafd8168c,0x79980083,0x3eb00076}},	//   _geug, _gjød, _wetw, oryt_, 
   {{0xdcfc0006,0x79980a49,0xabd00014,0x41c83996}},	//   _perė, _tetw, _زٲلت, िभास, 
   {{0xd1e0044e,0x6b9803fa,0xf60801c0,0x00000000}},	//   ነታት_, _zeug, рхий_, --, 
   {{0x6b9800e8,0x483400f1,0x00000000,0x00000000}},	//   _yeug, _کونړ, --, --, 
   {{0x3eb00af9,0xdddc01d3,0x00000000,0x00000000}},	//   kryt_, _mirő, --, --, 
   {{0x84740092,0xb8840413,0xb6040024,0x00000000}},	//   _ከሰሜን_, blíð, _мякк, --, 
   {{0x9f400e78,0x60180a87,0x3eb0012d,0x88bc00cc}},	//   weiß_, _ríma, dryt_, _আনতক, 
   {{0x6018008c,0xafd80158,0xc0cc001f,0xb5440214}},	//   _síma, _ljøe, _ቢባል_, _بخشه, 
   {{0x17ac03d4,0xdddc06be,0x2518010f,0xd5b800b8}},	//   ক্ৰি, _pirş, _כווא, bhāc_, 
   {{0xd83802bd,0xf3fc0120,0x5335636e,0x6b980c6a}},	// [24750] _avčk_, lmão_, _хепт, _reug, 
   {{0x6b99636f,0xed8874a1,0xafd8143a,0x601802d2}},	//   _seug, рсак_, _sjød, _víma, 
   {{0x4350001f,0x00000000,0x00000000,0x00000000}},	//   _ማስተባ, --, --, --, 
   {{0x60181c38,0x3eb0cf77,0xf1c0012d,0x00000000}},	//   _tíma, bryt_, षभकन, --, 
   {{0x3ff80375,0x9cb415bf,0x6018032e,0x48dc00c5}},	//   _הפרע, كمەت, _kímn, _कईहो_, 
   {{0xaca001f2,0x7bc402d2,0x00000000,0x00000000}},	//   _ahụa, _ökun, --, --, 
   {{0x6b996370,0xafd80158,0x4c9401d5,0x91cc00cd}},	//   _teug, _tjød, _хибс, द्यै, 
   {{0xf8ac004b,0x9854004e,0x00000000,0x00000000}},	//   اکل_, мтыш, --, --, 
   {{0xe9a804d3,0xafd80b1a,0xc79800db,0x298400c0}},	//   _ندان_, _kjøb, _ۇپاا_, _дыег, 
   {{0xaa4000d1,0x00000000,0x00000000,0x00000000}},	//   _تۆتى, --, --, --, 
   {{0xc9580eff,0x00000000,0x00000000,0x00000000}},	//   _الاش_, --, --, --, 
   {{0x43440395,0x00000000,0x00000000,0x00000000}},	//   земв, --, --, --, 
   {{0x395002d3,0xb7780375,0xc68801c6,0xf2a0010a}},	//   _ምሕደራ, _האנש, _уйлж_, нияп, 
   {{0x04c81913,0x00000000,0x00000000,0x00000000}},	//   _هوتي_, --, --, --, 
   {{0xc5e00eac,0x0f300092,0xf650011a,0x00000000}},	//   বাদপ, _በመለየ, _רצו_, --, 
   {{0xafd869e8,0x6ea40037,0x00000000,0x00000000}},	//   _skør, _चिखु, --, --, 
   {{0x3f903b72,0x3ea4003e,0xed5400c7,0x00000000}},	// [24760] rbyu_, éot_, ҧоу_, --, 
   {{0x4528025c,0xa0696371,0x60180166,0x3eb00108}},	//   _སྟོར_, саға_, _gímn, rryt_, 
   {{0xb3396372,0xdcfc00da,0xafd803a1,0xf4640092}},	//   maça, _ierī, _sjøe, _ታኅሣሥ_, 
   {{0xb3396373,0x3ce40115,0xb21801bf,0x00000000}},	//   laça, ĉov_, spæt, --, 
   {{0x2fc40213,0x5e640150,0x53c000cd,0x05bc28fe}},	//   əng_, _ينجە, ष्टश, ्भाब, 
   {{0xb3396374,0x58d4496c,0x796001e1,0x00000000}},	//   naça, докт, _níwí, --, 
   {{0xf41c005b,0x59940248,0x00000000,0x00000000}},	//   yhä_, _ọmọẹ, --, --, 
   {{0x4528003d,0xebe02a30,0x69c401b8,0x60180241}},	//   _སྟེར_, _посп, _öjen, _mímo, 
   {{0x601802d2,0x3a2401a9,0x00000000,0x00000000}},	//   _límo, _емаг, --, --, 
   {{0x601804d4,0xf41c02b5,0xdcfc0171,0x00000000}},	//   _oímo, whä_, _nerī, --, 
   {{0x9f40014b,0xb33828ed,0xf60801b9,0x6018032e}},	//   ndiâ_, daça, لتگه_, _rímn, 
   {{0xf3fc0798,0x9a640092,0x5334ec41,0x6018032e}},	//   rmão_, ትገኘው_, демт, _símn, 
   {{0xef1c006a,0x387c0477,0xb3381e54,0xf3fc00d8}},	//   _afün_, _hutr_, faça, smão_, 
   {{0xb3396375,0xdcfc005f,0x00000000,0x00000000}},	//   gaça, _cerī, --, --, 
   {{0xdcfc005f,0x387c0427,0x07d80133,0x601800e5}},	//   _derī, _jutr_, _دهۆک_, _címo, 
   {{0xafd82dba,0x6554011a,0x00000000,0x00000000}},	//   _sjøb, _מבוא_, --, --, 
   {{0xb338fbc0,0x23280640,0x00000000,0x00000000}},	// [24770] baça, _ноћи_, --, --, 
   {{0xb3396376,0x33b00131,0x88bc00fe,0x24440205}},	//   caça, _تەڭر, _আনসক, rıme_, 
   {{0x387c0f85,0x2ca40de2,0xfda40022,0x00000000}},	//   _nutr_, énd_, ьытҟ, --, 
   {{0x7bc4032e,0x00000000,0x00000000,0x00000000}},	//   _ökul, --, --, --, 
   {{0x387c04cc,0x09e41d0f,0x1f740395,0x00000000}},	//   _autr_, долн, _плюя, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x32880150,0x00000000,0x00000000,0x00000000}},	//   _ﺒﻨﻔﺱ_, --, --, --, 
   {{0xb3396377,0xd1e40023,0x00000000,0x00000000}},	//   zaça, _ምዱብ_, --, --, 
   {{0xb3380724,0x1a6800f1,0x56580023,0x00000000}},	//   yaça, _ځینی_, _ምእካብ, --, 
   {{0x275402d3,0x5a3400c0,0x00000000,0x00000000}},	//   _ምድረበ, _знут, --, --, 
   {{0x04442164,0x2a7c67c3,0xb33800d8,0xe77401d3}},	//   денн, _huub_, vaça, _فلاں_, 
   {{0x601801ed,0x6b6001e1,0x2a7c82b8,0xada00306}},	//   _címl, _gìgí, _kuub_, luúč, 
   {{0xb3396378,0x601808a5,0x00000000,0x00000000}},	//   taça, _símo, --, --, 
   {{0x2bfc0490,0xc5e000fe,0x6ea4000d,0x00000000}},	//   ळाडू_, বাহপ, _चिजु, --, 
   {{0xb3396379,0x792c044e,0xc48401b9,0x91cc00dc}},	//   raça, _እንተድ, _ўлик, द्धै, 
   {{0x60180077,0x00000000,0x00000000,0x00000000}},	//   _vímo, --, --, --, 
   {{0xb338b318,0xc2444965,0x00000000,0x00000000}},	// [24780] paça, _оник, --, --, 
   {{0xb2181fcd,0x601852dd,0x4420037e,0x00000000}},	//   spær, _tímo, lhk_, --, 
   {{0xa2a400af,0x0d983740,0x00000000,0x00000000}},	//   _कबड्, ятты_, --, --, 
   {{0x2a7c002e,0x2ca4025a,0x44211b1a,0x26dc0521}},	//   _buub_, ânda_, nhk_, kwuo_, 
   {{0x7bc5637a,0x34d80d2b,0x2a7c0de2,0x387c020c}},	//   _ökum, _बन्द, _cuub_, _sutr_, 
   {{0x2a7c0067,0x00000000,0x00000000,0x00000000}},	//   _duub_, --, --, --, 
   {{0x4420003e,0xed5401c6,0x601808a5,0x58d4009d}},	//   khk_, _жор_, _límm, хойт, 
   {{0xb8d5637b,0x76a8023a,0x59bc00bc,0x2a7c03e0}},	//   _जि_, отов_, ईलहर, _fuub_, 
   {{0x392c2295,0x061c044e,0x7c21637c,0x2a7c0548}},	//   _እንዲያ, _ስለዝነ, mhor, _guub_, 
   {{0x7c20a1d4,0x6018032e,0x00000000,0x00000000}},	//   lhor, _síml, --, --, 
   {{0x2db4011a,0xe9a00e4e,0xd5b800cd,0x00000000}},	//   ולין_, _рахп, bhān_, --, 
   {{0x7c21637d,0x4a000588,0x5aec031c,0x44200327}},	//   nhor, _аҟәа, _རློམ, ghk_, 
   {{0x2a7c0067,0x601801d3,0x73480395,0xe82400e5}},	//   _xuub_, _címm, ючов_, _تذلی, 
   {{0x392c0020,0xb59404d3,0x776001d5,0x7c2001d5}},	//   _እንዳያ, _تێدا_, _izox, hhor, 
   {{0x3864003c,0xdb00037e,0x261800bc,0x00000000}},	//   _khor_, _udmæ, यसरी_, --, 
   {{0x44200784,0xe3d00016,0x7659637e,0x7c2002fd}},	//   chk_, _hằng_, llty, jhor, 
   {{0xd6bc000e,0x7c21637f,0x38640e89,0xb338067c}},	// [24790] _অনুপ, dhor, _mhor_, maço, 
   {{0x2a7c01f5,0xb3396380,0x7c200072,0x24440205}},	//   _ruub_, laço, ehor, mıma_, 
   {{0x7c216381,0x24446d5b,0x76581368,0xe81c00e1}},	//   fhor, lıma_, ilty, _बतला_, 
   {{0x7c216382,0xb3380077,0xb11001f2,0x76580076}},	//   ghor, naço, tụfo, hlty, 
   {{0x2444050e,0x5e84035b,0x00000000,0x00000000}},	//   nıma_, _аусз, --, --, 
   {{0x7c216383,0x602401e1,0xe3d00208,0x00000000}},	//   ahor, _tìmù, _nằng_, --, 
   {{0x7760014b,0x386400a3,0x7c216384,0x24444dd9}},	//   _azox, _bhor_, bhor, hıma_, 
   {{0x38656385,0x7c216386,0x244405d1,0x2a7d6387}},	//   _chor_, chor, kıma_, _tuub_, 
   {{0xe3d001dc,0xb3396388,0x38640009,0x8c4402dd}},	//   _bằng_, daço, _dhor_, _жеңе, 
   {{0x9f416389,0x2444915d,0x00000000,0x00000000}},	//   ndiá_, dıma_, --, --, 
   {{0x7760014b,0x386401ab,0xb338004a,0xdb0000a2}},	//   _ezox, _fhor_, faço, _edmä, 
   {{0x3864047e,0x7658e6d5,0xb338021c,0x24440790}},	//   _ghor_, alty, gaço, fıma_, 
   {{0x2444294f,0x00000000,0x00000000,0x00000000}},	//   gıma_, --, --, --, 
   {{0x4421638a,0x7c21327b,0xe1f80107,0xf48428c4}},	//   shk_, zhor, фҳо_, بایی, 
   {{0xea9c0943,0x39c00093,0xafd82d8b,0x212c0e89}},	//   _maṱo_, _hōsí_, _sjøa, àdh_, 
   {{0x7950069c,0xd40836e9,0xafe11048,0x7c200023}},	//   _ምንቅስ, _يتيم_, лосл, xhor, 
   {{0x7050fd47,0x671c39de,0x6d480209,0x6445638b}},	// [247a0] انقا, यनिक_, şgal, _ijii, 
   {{0xa3c006e3,0x7c200455,0x3e64025a,0x9f4000db}},	//   ुभव_, whor, kôte_, rdià_, 
   {{0x44e00953,0x7c21638c,0x319802e4,0x6018022a}},	//   _jų_, thor, _מבינ, _jímk, 
   {{0x64440083,0xafd80158,0x7ac40220,0x44300076}},	//   _jjii, _hjøn, еске, _jmy_, 
   {{0xa3b8089a,0xafd81700,0x4174c636,0xb11401ec}},	//   _चयन_, _kjøn, _تاکس, _يقۋا_, 
   {{0x19589298,0x3865638d,0xb3380d2a,0xbb74013e}},	//   малы_, _shor_, zaço, _ҷузъ, 
   {{0x7c21638e,0xe3d007ae,0xcdc4136b,0x44300c6a}},	//   phor, _rằng_, _шарқ, _omy_, 
   {{0x96f800c7,0x64441574,0xee900014,0xe3d00051}},	//   деит_, _njii, _شۯۅک, _sằng_, 
   {{0x1b0401c0,0x7bc00165,0xec34011a,0xe3d00051}},	//   _шүдн, mgou, _נאמר_, _pằng_, 
   {{0xdecc02d3,0x7ae05745,0x4430123b,0x44e00064}},	//   _ኣነን_, mwot, _amy_, _bų_, 
   {{0x601800dd,0x7ae01028,0x3e65638f,0xb338021c}},	//   _címk, lwot, côte_, taço, 
   {{0x7bc16390,0x44316391,0xa1843419,0x244429af}},	//   ngou, _cmy_, ғырл, tıma_, 
   {{0xb33934f6,0xee3c0316,0x7760014b,0xe2980953}},	//   raço, _svým_, _uzox, наў_, 
   {{0x644404ba,0x7af402f6,0x244471e1,0x7bc00369}},	//   _ejii, äyty, rıma_, hgou, 
   {{0xb3382cd5,0x9f340220,0x9f40003a,0xa5e400db}},	//   paço, ңесі, ndiæ_, _سىيل_, 
   {{0x7bc00369,0x7ae12680,0x24440205,0x7bc402d2}},	//   jgou, kwot, pıma_, _ökuh, 
   {{0xb110063f,0x7bc16392,0x601801e7,0x00000000}},	// [247b0] wụdo, dgou, _mímh, --, 
   {{0x6ca4160b,0xdb00067c,0xafd803cd,0x7bc0715e}},	//   ердж, _iemè, _gjøn, egou, 
   {{0xdb0002d3,0x4430a443,0x00000000,0x00000000}},	//   _femë, _ymy_, --, --, 
   {{0xa3d41533,0x78a84a1f,0xb33803ee,0xdb0004e6}},	//   स्प_, dsfv, yaçl, _gemë, 
   {{0xdb00020c,0x0c040014,0x00000000,0x00000000}},	//   _jemè, _یوسُ, --, --, 
   {{0xdb016393,0xcda8bf4e,0x1a685598,0x68500023}},	//   _zemë, _زهره_, فیقی_, _ምቅላስ, 
   {{0x7bc00369,0x7ae00ba7,0xdb000100,0x2cb80327}},	//   bgou, awot, _lemè, _པའིབ, 
   {{0xc61800dc,0x7ae00a1d,0x44e000c0,0x00000000}},	//   धस्य_, bwot, _rų_, --, 
   {{0xd1e40020,0x601813db,0x8644020f,0x44e00153}},	//   ምስት_, _dímh, книж, _sų_, 
   {{0xa3d411b1,0x644401f5,0x458400a7,0x3e64007f}},	//   स्न_, _sjii, ъгов, pôte_, 
   {{0x69c004cc,0x47d44fca,0x7c8c0023,0x291001e3}},	//   mgne, _ليار, _ዝነቐለ_, äxad_, 
   {{0xe784e444,0x69c000c5,0xafd803cd,0x00000000}},	//   _чужо, lgne, _sjøn, --, 
   {{0xe3b89d58,0x00000000,0x00000000,0x00000000}},	//   ğı_, --, --, --, 
   {{0xe3b80c07,0x44e00006,0xdb016394,0x3cfc0077}},	//   şı_, _tų_, _demè, _átvg_, 
   {{0x69c16395,0xdb000023,0x44300306,0x68e00042}},	//   igne, _pemë, _tmy_, nwnd, 
   {{0xdb0035b2,0x44312506,0x64440009,0xc0e401d5}},	//   _femè, _umy_, _ujii, ноҳк, 
   {{0x63a400e2,0xafd8143a,0x932400ec,0x3ea401a9}},	// [247c0] _iein, _tjøn, _ٽرين, тизг, 
   {{0xafd8a934,0x6018032e,0x95940092,0x00000000}},	//   _hjøl, _mími, _የአደጋ_, --, 
   {{0x63a448aa,0xafd94387,0x6284e068,0xdb0002d3}},	//   _kein, _kjøl, _huio, _temë, 
   {{0x7ae008cd,0x62849ea8,0x63a56396,0x69c16397}},	//   twot, _kuio, _jein, egne, 
   {{0x63a56398,0xa3d4810c,0x7bc16399,0xafd900b0}},	//   _mein, स्य_, rgou, _mjøl, 
   {{0x63a5639a,0x62840dd4,0x69c16112,0xaa501ae2}},	//   _lein, _muio, ggne, авіш, 
   {{0xdb0000e4,0x6285639b,0xadd40375,0x63a4035a}},	//   _memé, _luio, _שולח_, _oein, 
   {{0x63a5639c,0xb92c0201,0xa3d41684,0x19580184}},	//   _nein, _እንግዲ, स्म_, маһы_, 
   {{0x62840ffb,0x68e0015d,0xf424010e,0x00000000}},	//   _nuio, awnd, nmäň_, --, 
   {{0x4b540c04,0xdb01639d,0xa770081d,0xf484011c}},	//   _съст, _remè, шлыч, кумн, 
   {{0x63a5639e,0xdb0002bd,0xafd8dd74,0x39040014}},	//   _bein, _semè, _bjøl, _جواٲ, 
   {{0x63a5639f,0xe780013e,0xdb000100,0xb3380023}},	//   _cein, _кушо, _pemè, saçm, 
   {{0x63a563a0,0x9f40145e,0xdb015629,0xf11821f6}},	//   _dein, ndiä_, _bemé, नन्द_, 
   {{0x63a40857,0xe7140375,0x6284054e,0xb5fc0051}},	//   _eein, _בחדר_, _duio, _khơm, 
   {{0x63a563a1,0xafd80579,0xdb0000db,0x41d00882}},	//   _fein, _fjøl, _demé, द्धस, 
   {{0x63a563a2,0x62840618,0xafd8022c,0x69c000f3}},	//   _gein, _fuio, _gjøl, zgne, 
   {{0x628421fc,0x69c163a3,0xf42400a2,0x999c00c0}},	// [247d0] _guio, ygne, gmäň_, novų_, 
   {{0x63a401c0,0xf1a804d3,0xdb000221,0x00000000}},	//   _zein, _کاکه_, _gemé, --, 
   {{0x6b88074d,0x63a4bc61,0x62840165,0x69c004cc}},	//   tcgg, _yein, _zuio, vgne, 
   {{0xafd805ac,0x6e340066,0x5f782d40,0x48dc0037}},	//   _kjøm, sixb, رمەس_, _कैगो_, 
   {{0x69c005d5,0x81e40154,0x6e340175,0x00000000}},	//   tgne, ফার_, pixb, --, 
   {{0xafd805ac,0x601806ea,0x999c0024,0xdd9402d5}},	//   _mjøm, _rími, dovų_, _вары, 
   {{0x48785c9c,0x69c163a4,0x601809e8,0x5e580276}},	//   нсия_, rgne, _sími, _риря_, 
   {{0xe7c00183,0x46e866be,0x869803b7,0x68e00223}},	//   ্য্য, един_, нтот_, rwnd, 
   {{0xa9c40224,0xee3c00e4,0x1cc0025c,0x67000137}},	//   _асек, _avýi_, _ཁའོ_, рүлб, 
   {{0x63a563a5,0xafd81c82,0x62840165,0x00000000}},	//   _sein, _sjøl, _ruio, --, 
   {{0x63a563a6,0xdb0163a7,0x628401e7,0xb338010e}},	//   _pein, _remé, _suio, baçk, 
   {{0x601963a8,0x62840869,0xdb00003e,0x06f41622}},	//   _tími, _puio, _semé, _مستج, 
   {{0x6284311a,0x63a563a9,0xc618011c,0x00000000}},	//   _quio, _vein, _подх_, --, 
   {{0x203c001f,0x62840156,0x00000000,0x00000000}},	//   _አብራር, _vuio, --, --, 
   {{0x63a563aa,0x41284c7f,0x81e404c5,0x1cc0025c}},	//   _tein, хово_, ফাল_, _ཁའེ_, 
   {{0x628563ab,0x24800122,0x63a400cc,0x4f9421cb}},	//   _tuio, íjmu_, _uein, ируу, 
   {{0x1da40588,0xafd80158,0xbe84fc68,0x244403e0}},	// [247e0] илаҭ, _gjøm, اجرو, nımm_, 
   {{0x4ee4045e,0xee340063,0x20cc00e4,0x00000000}},	//   নমূল, гну_, pÿi_, --, 
   {{0xef1c0c86,0x2730001e,0x8e7400d8,0xada000d7}},	//   _agüd_, ảnh_, рутч, drúč, 
   {{0xd12c0014,0xbb4800d1,0x00000000,0x00000000}},	//   _کۅہ_, ىلان_, --, --, 
   {{0xa3cc5d4f,0xdcfc0171,0xeb94011c,0x00000000}},	//   _लान_, _berģ, уич_, --, 
   {{0xa3d41431,0xf2d0011a,0xfce40229,0x24440205}},	//   स्त_, צעו_, _його, dımm_, 
   {{0x0d74034b,0xad64030d,0x00000000,0x00000000}},	//   _вытя, _барз_, --, --, 
   {{0xb86563ac,0xed5414a4,0x6cc000f7,0xec746179}},	//   داتو, _сос_, _ыйса, _бпс_, 
   {{0x290401ab,0xd91001d9,0x4c344b00,0xdddc00dc}},	//   axna_, _ڈیش_, _тэрт, _nirū, 
   {{0xd91004d3,0xdb10010e,0xbb880150,0x00000000}},	//   _ویش_, _ýeñs, _ﺗﯩﻜﻪ_, --, 
   {{0xafd8168c,0xb338036e,0x00000000,0x00000000}},	//   _sjøm, maçi, --, --, 
   {{0x98ac0598,0xb19001e0,0xc2fc00fe,0xb42468e1}},	//   _uzdı_, өлмә, ঁহনি_, اعدو, 
   {{0xe69005d9,0x00000000,0x00000000,0x00000000}},	//   _هلند, --, --, --, 
   {{0x65901180,0xd4c404b3,0x00000000,0x00000000}},	//   _лашу, _көмк, --, --, 
   {{0xdef80046,0x7f9001e1,0x00000000,0x00000000}},	//   қыт_, _ọmọg, --, --, 
   {{0x1fa563ad,0xafd8143a,0x00000000,0x00000000}},	//   йруг, _tjøm, --, --, 
   {{0x395c0a85,0x1cc0031c,0xa8040205,0xb3a800eb}},	// [247f0] _lyts_, _ཁའུ_, lgıç, _কাপড়, 
   {{0xafd803a1,0xf41d4bd1,0xded002d3,0x6824013d}},	//   _kjøk, lkä_, ብረካ_, _iñde, 
   {{0xa8040e51,0x395c0042,0x7dd801bf,0x0c7400f2}},	//   ngıç, _nyts_, _søsæ, لگرد, 
   {{0xf41d63ae,0x0fc4004e,0xdcfc00ef,0x9b8800f1}},	//   nkä_, _өйүн, _serģ, هنمل_, 
   {{0xdef963af,0xf41c0108,0x00000000,0x00000000}},	//   _йыр_, ikä_, --, --, 
   {{0xa3cc09fd,0x48b4fc21,0xdcfc0e3c,0x601806ea}},	//   _लाभ_, ащит, _zgrč, _dímu, 
   {{0xf41d63b0,0xafd8168c,0x6d40007b,0x00000000}},	//   kkä_, _skøy, únad, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x89340092,0x00000000,0x00000000,0x00000000}},	//   _እንዲሻ, --, --, --, 
   {{0x85380198,0x29040227,0x395c0b21,0x5b14548b}},	//   _haɗɗ, pxna_, _fyts_, _умут, 
   {{0x998474bb,0xf504004e,0xf41c013d,0x00000000}},	//   _المو, анэл_, fkä_, --, 
   {{0xdcfc0003,0x7bc401a8,0x00000000,0x00000000}},	//   _jerġ, _ökut, --, --, 
   {{0x2bd42d6c,0x321093ee,0x72c08c72,0x46a407a5}},	//   ण्या, _boxy_, обяз, _талв, 
   {{0x27ec0165,0xf41c00e4,0x601802d2,0x2428009d}},	//   _hagn_, akä_, _límt, тхүү_, 
   {{0x32100076,0x27ec00e8,0xc0e40276,0xafd80fac}},	//   _doxy_, _kagn_, шовк, _gjøk, 
   {{0x3ea0003e,0xd8380100,0xdcfc0135,0x2d800200}},	//   _pwkt_, _nwčl_, _nerġ, _agje_, 
  
   {{0x64a163b1,0x27ec0321,0xe5a001fb,0x53c400f7}},	// [24800] _тақа, _magn_, _điệ, _ازىق, 
   {{0x27ec07c5,0xa06868b9,0x6018148b,0xfd940eed}},	//   _lagn_, таға_, _rímu, ршаю, 
   {{0xdcfc031c,0x60180436,0x2480003e,0x25a40100}},	//   _berġ, _símu, _kiim_, _menl_, 
   {{0x41d0446c,0x27ec003e,0x24800009,0x73300131}},	//   द्रस, _nagn_, _jiim_, _دىۋا, 
   {{0x85380198,0x395d63b2,0x4ec400d1,0xd1e40023}},	//   _daɗɗ, _syts_, _лияң, ምድቲ_, 
   {{0x248163b3,0x7c9400a7,0x225801c6,0x601801a8}},	//   _liim_, _врац, nork_, _vímu, 
   {{0x1cc00c99,0x27ec0c86,0x2c6400c5,0xb33963b4}},	//   _ཁའི_, _bagn_, sõda_, raçi, 
   {{0x60180ad9,0xf0900375,0x3dc403f9,0x2258a604}},	//   _tímu, חנה_, ɗowa_, hork_, 
   {{0x236001d4,0x25a4030d,0x27ec04cc,0xafd808fb}},	//   _nyij_, _benl_, _dagn_, _sjøk, 
   {{0x225963b5,0x248001ab,0xa3d406ff,0xd8380100}},	//   jork_, _aiim_, स्स_, _zwčl_, 
   {{0xf41d614a,0x248001ab,0x27ec05d5,0x3210045a}},	//   tkä_, _biim_, _fagn_, _roxy_, 
   {{0x628800c8,0x27ec23ee,0xdb0000d2,0x2480003a}},	//   ĉdon, _gagn_, _lemí, _ciim_, 
   {{0xf41d63b6,0xe60c0066,0x00000000,0x00000000}},	//   rkä_, سشی_, --, --, 
   {{0x25a405e4,0xf41cf4b5,0xdb000118,0x00000000}},	//   _genl_, skä_, _nemí, --, 
   {{0x27ec0a2e,0x321002b9,0x2bd416d1,0x6114003b}},	//   _yagn_, _voxy_, ण्डा, одру, 
   {{0x24800de2,0x929403f6,0x00000000,0x00000000}},	//   _giim_, _лаиц, --, --, 
   {{0x22585675,0xa3cc76f8,0x2d800407,0x601803b2}},	// [24810] bork_, _लात_, _pgje_, _rímt, 
   {{0x6018142f,0x00000000,0x00000000,0x00000000}},	//   _símt, --, --, --, 
   {{0xa3d44433,0xdb000048,0xdef80092,0xb5fc0051}},	//   स्व_, _demí, ገተኛ_, _chơi, 
   {{0xc578010f,0x00000000,0x00000000,0x00000000}},	//   אָנט, --, --, --, 
   {{0xe2143047,0x27ed63b7,0xdcfc0135,0xdb0001a8}},	//   _طبیع, _ragn_, _verġ, _femí, 
   {{0x85380198,0xdb000789,0x27ec0b1a,0xafd82dba}},	//   _waɗɗ, _gemí, _sagn_, _sjøh, 
   {{0x6018012c,0xdcfc0003,0x00000000,0x00000000}},	//   _tímt, _terġ, --, --, 
   {{0x480563b8,0xdb0000bc,0x46a4020f,0x77800395}},	//   спив, _zemí, баив, плъз, 
   {{0x27ed63b9,0x6e2401fa,0x88a003e6,0x24800254}},	//   _vagn_, _kljb, _کیبۆ, _riim_, 
   {{0x248163ba,0xe58000f7,0x06082d29,0x9a8432eb}},	//   _siim_, өтүү, унок_, _футл, 
   {{0x85780124,0x27ec07c5,0x248000c5,0xa3cc00e1}},	//   ысит_, _tagn_, _piim_, _लाद_, 
   {{0x044563bb,0xd838084c,0x00000000,0x00000000}},	//   семн, _кэч_, --, --, 
   {{0xe7080451,0x2258a8ce,0x25a40139,0x24800108}},	//   _جتان_, tork_, _tenl_, _viim_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x01644e0c,0xdb0163bc,0x2480291e,0x66002e49}},	//   скво, _remí, _tiim_, _innk, 
   {{0x60180030,0xdb0163bd,0x00000000,0x00000000}},	//   _ríms, _semí, --, --, 
   {{0x66000076,0x1cc00327,0x601808a5,0x00000000}},	// [24820] _knnk, _ཁའང_, _síms, --, 
   {{0xdcfd63be,0xa3d46594,0x601801d3,0x7ca00240}},	//   _agrā, स्र_, _címr, _ጎብለል_, 
   {{0x80d0015b,0xdcfc0003,0xbb8563bf,0xdcb00228}},	//   হিঙ্, _merħ, ملاي, بۉز_, 
   {{0x442163c0,0x20f801a6,0x3024010b,0xfbc401a9}},	//   nkk_, _iči_, _гоюп_, сбдо, 
   {{0xdb000a90,0x20f809a8,0xefb001b9,0x0ba89805}},	//   _temí, _hči_, _ریلگ, شانى_, 
   {{0x6d400491,0xfca880de,0xdcfc0327,0xb33963c1}},	//   únac, _مارو_, _nerħ, caçu, 
   {{0x6da163c2,0xafd80158,0xada163c3,0xd7f800d1}},	//   _хиса, _sjøi, _хасл, ғуқ_, 
   {{0x660163c4,0xbc242309,0x06e00154,0x00000000}},	//   _annk, _ارسى, বিনি, --, 
   {{0x7c20006c,0xdb000798,0xa62402d3,0xd9380092}},	//   mkor, _demã, _ስለዝሰ, _እንዲቋ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8afc012c,0x7c200083,0x00000000,0x00000000}},	//   _vyře, okor, --, --, 
   {{0x66000083,0x3eb0023a,0x00000000,0x00000000}},	//   _ennk, ksyt_, --, --, 
   {{0x7c2004fe,0xdcfc0135,0x1da8024a,0xd7f800fb}},	//   ikor, _ferħ, गरात, _буҙ_, 
   {{0x77607bff,0x7c2163c5,0x44207dfa,0x7d1d1e05}},	//   _iyox, hkor, akk_, kyps, 
   {{0x7c2163c6,0x765963c7,0x24440213,0x00000000}},	//   kkor, moty, zımi_, --, 
   {{0x765963c8,0x7c2163c9,0x601802d2,0xbef4012d}},	//   loty, jkor, _símr, ीमून_, 
   {{0x7c2163ca,0x81dc0729,0x765800ad,0x8e146179}},	// [24830] dkor, ণয়_, ooty, одац, 
   {{0x765963cb,0xf1a563cc,0x7c20000d,0x41a80303}},	//   noty, _урин, ekor, करणस, 
   {{0xdb00012d,0x7d1c035a,0x7c2002d2,0x00000000}},	//   _odmó, gyps, fkor, --, 
   {{0x7658004b,0x7760014b,0x8af80b7e,0xc5e400dc}},	//   hoty, _oyox, инес_, _कस्य_, 
   {{0x76586ef1,0x5ba80953,0xc9a80b3b,0xa3cc2356}},	//   koty, скім_, авле_, _लास_, 
   {{0xdb000077,0x7c2163cd,0x6f1c0076,0x2de40137}},	//   _admó, akor, myqc, _уюмг, 
   {{0xec680abe,0x44201a82,0x7c2051ca,0x00000000}},	//   _брак_, ykk_, bkor, --, 
   {{0x776002b9,0x7c20049f,0x1bd563ce,0x2ca40276}},	//   _byox, ckor, _нося, ându_, 
   {{0x7658045f,0x00000000,0x00000000,0x00000000}},	//   foty, --, --, --, 
   {{0x765963cf,0x4420020b,0xafd808fb,0x60183822}},	//   goty, wkk_, _gjøv, _límp, 
   {{0x7760014b,0x44200158,0x00000000,0x00000000}},	//   _eyox, tkk_, --, --, 
   {{0xdb000798,0x44213aef,0xb33803e0,0x00000000}},	//   _hemá, ukk_, yaçt, --, 
   {{0x7658fd89,0xdcfc031c,0x00000000,0x00000000}},	//   boty, _terħ, --, --, 
   {{0x7c2163d0,0x765963d1,0xb33803e0,0x4ad00037}},	//   zkor, coty, vaçt, _समनव, 
   {{0x442005b1,0x7c2163d2,0xd174b720,0x00000000}},	//   pkk_, ykor, зыты, --, 
   {{0xf1d80b33,0x7c2001c4,0x3eb0005b,0x682400a2}},	//   म्बन, xkor, tsyt_, _yñda, 
   {{0xdcfc0356,0xc7b800e5,0x3da80114,0x00000000}},	// [24840] _ogră, lhős_, икао_, --, 
   {{0xdb0003c6,0x656006a3,0x7d1c0240,0xed4c01d9}},	//   _nemá, _kynh, typs, چھِ_, 
   {{0x7c2163d3,0x20f805a1,0xdb0000cf,0xfb894da1}},	//   tkor, _uči_, _semà, абек_, 
   {{0x65609a8d,0xc0c8044e,0xafd808fb,0x765963d4}},	//   _mynh, ኽእል_, _sjøv, zoty, 
   {{0x3ce401f1,0x7f7406bd,0x656000b5,0x19940410}},	//   ňov_, _фунц, _lynh, паля, 
   {{0x7c2163d5,0x76580472,0x7d1c02d0,0x00000000}},	//   skor, xoty, pyps, --, 
   {{0xdb010cc9,0x7c2163d6,0x765801f4,0xb88001e1}},	//   _demá, pkor, voty, _ííku, 
   {{0xdb0000f7,0x765963d7,0xdd9000f1,0xdb2400e5}},	//   _temà, woty, _زوړ_, _ٹوئی, 
   {{0x765963d8,0xeb94084c,0xe818000d,0xab2401f4}},	//   toty, _фиу_, _फकरा_, _дота_, 
   {{0xef1c03e0,0x00000000,0x00000000,0x00000000}},	//   _ogün_, --, --, --, 
   {{0x765963d9,0x65600cfd,0xa3cc0c2e,0xafd82cb2}},	//   roty, _cynh, _लाश_, _kjøt, 
   {{0x65605e59,0x765963da,0xdb0002f0,0xf54000cf}},	//   _dynh, soty, _zemá, здүү, 
   {{0x765963db,0x47c40156,0x7760014b,0x2810bf4e}},	//   poty, _ཁྐྲམ, _uyox, _تونس, 
   {{0x60180137,0x76580472,0x656001bf,0x18680166}},	//   _símp, qoty, _fynh, _таҗи_, 
   {{0x656000a9,0x34340014,0x870400cf,0xdb440133}},	//   _gynh, _وٲتھ_, _وبۇل, _ڤێ_, 
   {{0xafd80158,0xd3e800ec,0x00000000,0x00000000}},	//   _njøt, _اڙدو_, --, --, 
   {{0x2d84151c,0xe3b07427,0x23280640,0xf1d00b98}},	// [24850] žnem_, _شري_, _моћи_, _तापन, 
   {{0x2d8403d4,0xc3300375,0xd25163dc,0xad24027d}},	//   øne_, _נוי_, _سنج_, يراو, 
   {{0xdb000077,0x60180005,0xafd8143a,0x00000000}},	//   _remá, _tímp, _sjøu, --, 
   {{0xdb000615,0xc0f800df,0x00000000,0x00000000}},	//   _semá, _פּיט, --, --, 
   {{0xdb000077,0xe3b000fe,0x00000000,0x00000000}},	//   _pemá, _কামব, --, --, 
   {{0x1a682ab4,0x00000000,0x00000000,0x00000000}},	//   قیقی_, --, --, --, 
   {{0xa3cc3eaf,0x7afc0882,0xafd803b2,0x00000000}},	//   _लाल_, āpta, _fjøt, --, 
   {{0x1bb8193a,0x48080965,0xdb000af2,0x6560017a}},	//   _واقع_, сеин_, _wemá, _rynh, 
   {{0xdb002cd7,0xafd8037e,0xdcfc01e4,0x1ab462d9}},	//   _temá, _imød, _verĥ, _обтя, 
   {{0xdb0004ce,0x656006a3,0xafd82d8b,0x00000000}},	//   _bemæ, _pynh, _kjøs, --, 
   {{0xd90cb675,0x6fc80490,0x00000000,0x00000000}},	//   _نیو_, िलां, --, --, 
   {{0xafd808fb,0x10d401ec,0x00000000,0x00000000}},	//   _mjøs, _ﺘﺴﺘﻨ, --, --, 
   {{0xafd805ac,0x656008c8,0x2d840030,0xc1d000fb}},	//   _ljøs, _wynh, ľnej_, нөнә, 
   {{0x2d8401f1,0x4094136b,0x06e002f5,0x319400bc}},	//   žnej_, зрат, বিদি, vězí_, 
   {{0xafd805ac,0x00000000,0x00000000,0x00000000}},	//   _njøs, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x1b20015b,0x72c00022,0x64d800cd,0x6d4119ee}},	// [24860] _মেনে_, _збыз, _बहुश, únan, 
   {{0xafd82147,0xdb0003b9,0x00000000,0x00000000}},	//   _sjøt, _hemç, --, --, 
   {{0xdb0000ee,0x6cc001c6,0xf650011a,0x00000000}},	//   _kemç, ейха, עצב_, --, 
   {{0xdb000139,0x8afc01ef,0x90e40101,0x00000000}},	//   _jemç, _syřa, _کسین, --, 
   {{0xab8163dd,0xafd800b5,0x0eb800c0,0x00000000}},	//   нушк, _smøg, _муры_, --, 
   {{0xafd808fb,0xe8880023,0x6ac01870,0x00000000}},	//   _fjøs, _ሓዲጎም_, رقىم, --, 
   {{0xafd963de,0x2004068c,0x8afc00bc,0x00000000}},	//   _gjøs, _òmis_, _vyřa, --, 
   {{0x77904fdc,0xd83802f0,0x5f0001ad,0x00000000}},	//   ریتا, _otče_, रिप्_, --, 
   {{0x96f89f59,0xafd82a1e,0xd5b8005f,0x00000000}},	//   цепт_, _kjør, skām_, --, 
   {{0x2e38001f,0x9f40067c,0x06d002dd,0x00000000}},	//   _በየዓመ, ldió_, _ﻛﻪﺷﻪ, --, 
   {{0xafd80174,0x35440108,0x00000000,0x00000000}},	//   _mjør, яхив, --, --, 
   {{0x9f4163df,0xafd803cd,0x3adc1d77,0xb9c80023}},	//   ndió_, _ljør, pāpā_, _ሳሆ_, 
   {{0x91c40075,0xf364551b,0x1dcc07b7,0x00000000}},	//   мәнл, ятон, ालात, --, 
   {{0xc744212d,0xc0cc0023,0x5f00190c,0x00000000}},	//   _تضمي, ብገስ_, रिन्_, --, 
   {{0x92cc00bd,0x63c800bc,0xd554074d,0xa0880137}},	//   রবে_, ásné, _юккъ, зсуз_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xafd84098,0x74ac00bd,0xd37000c6,0x533400d8}},	// [24870] _bjør, _কমিউ, _جهة_, _цепт, 
   {{0xdb000793,0xf1a563e0,0xb1a563e1,0xafd803b2}},	//   _memä, _эрин, _эшик, _pjøs, 
   {{0xa3d4547d,0xdb0001b8,0xa29801ed,0x8bd4084c}},	//   स्क_, _lemä, _وئیر_, джец, 
   {{0xb3bc3381,0x00000000,0x00000000,0x00000000}},	//   ्लिख, --, --, --, 
   {{0xafd963e2,0x6e400075,0x00000000,0x00000000}},	//   _fjør, _كۆرم, --, --, 
   {{0xafd963e3,0x98ac06be,0x9b0402d5,0xc0cc0023}},	//   _gjør, _aydı_, эзід, ብለሉ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x0c040014,0xdb00fc23,0xa3cc012c,0x06e00154}},	//   _تورُ, _bemä, _लाइ_, বিসি, 
   {{0x200c016b,0xab28007b,0x00000000,0x00000000}},	//   _ɑdi_, _اسأل_, --, --, 
   {{0xdb000643,0xdddc4e96,0x08e001ee,0x00000000}},	//   _demä, _kirš, _аҡкү, --, 
   {{0x92cc0154,0x61ec03b9,0xbdd00150,0x00000000}},	//   রবো_, _önlə, _ﻓﺨﻴل_, --, 
   {{0xdd1c01f1,0x4ad04195,0xdddc2ba4,0x00000000}},	//   náša, _समाव, _mirš, --, 
   {{0xdb004dde,0xc8dc000d,0x00000000,0x00000000}},	//   _gemä, _महँट, --, --, 
   {{0xea9c0055,0xb77800d9,0x05280798,0x00000000}},	//   _naṭo_, _ואנש, _молк_, --, 
   {{0xa3cc069f,0x51540137,0x41280108,0xdddc0171}},	//   _लाऊ_, етту, цово_, _nirš, 
   {{0xafd831a2,0xafe02bbd,0xdb0001e3,0xe80000bc}},	//   _sjør, косл, _hemå, _शोमा_, 
   {{0x850401ed,0x3db00183,0xea9c0055,0xdb000139}},	// [24880] _روکن, _চাবল, _baṭo_, _xemä, 
   {{0xdee401b9,0xdddc0024,0x8284007b,0xada0022e}},	//   моғи, _birš, _تجعل, вафл, 
   {{0x2fd024ba,0xe8000b27,0x2294010e,0xdddc00e2}},	//   ängö_, _शोभा_, _häk_, _cirš, 
   {{0x0ea80d01,0xd8380100,0x3a3c1a9f,0x229401e3}},	//   _चौकड, _jwčt_, _smtp_, _käk_, 
   {{0xa3cc8a57,0x9f40667d,0xafd94914,0x1cc0031c}},	//   _लाई_, rdió_, _tjør, _ཁའམ_, 
   {{0xef80a3f8,0x2294013d,0x4df400c0,0x00000000}},	//   _шляп, _mäk_, _пяст, --, 
   {{0xafd81a84,0x2295489f,0xe91400d4,0x6e20a6e1}},	//   _kjøp, _läk_, дощі_, önbe, 
   {{0xdb0001b8,0x9f4000a2,0x00000000,0x00000000}},	//   _pemä, ldiñ_, --, --, 
   {{0x6b6163e4,0x229400fd,0xe7bc5d4f,0x00000000}},	//   _акта, _näk_, _एयरप, --, 
   {{0x9f4000a2,0x00000000,0x00000000,0x00000000}},	//   ndiñ_, --, --, --, 
   {{0x799802d0,0x00000000,0x00000000,0x00000000}},	//   _iftw, --, --, --, 
   {{0x684163e5,0x2294d398,0xf3fc00d8,0xdb000139}},	//   _инха, _bäk_, rlão_, _temä, 
   {{0xd8380100,0xe29802d5,0x1b200154,0x00000000}},	//   _dwčt_, маў_, _মেতে_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x244400c7,0x6d40007b,0x9f400165,0xa3cc2e05}},	//   _ахьг, únam, ediñ_, _लाए_, 
   {{0x79980c8c,0xea9c00b8,0x00000000,0x00000000}},	// [24890] _oftw, _paṭo_, --, --, 
   {{0x7c380006,0xdddc0006,0x00000000,0x00000000}},	//   _įtra, _pirš, --, --, 
   {{0xfcc00131,0x0c780240,0x00000000,0x00000000}},	//   ләтм, _ይባረኽ_, --, --, 
   {{0xdddc0953,0x6458315a,0x799802d0,0x9f40030a}},	//   _virš, _êxit, _aftw, adiñ_, 
   {{0xa3d410eb,0xd8380100,0xdaa81cd0,0x93e001f9}},	//   स्ट_, _lwčs_, двід_, ग्यच_, 
   {{0xdd380882,0xdea563e6,0xdddc33fc,0x00000000}},	//   nāśa, _شیمی, _tirš, --, 
   {{0x9f401bb0,0x00000000,0x00000000,0x00000000}},	//   ldið_, --, --, --, 
   {{0x998c01ef,0x00000000,0x00000000,0x00000000}},	//   _modř_, --, --, --, 
   {{0x9f4011c3,0xdd380882,0x068563e7,0x4a540022}},	//   ndið_, kāśa, нгин, _зкас, 
   {{0x2294013d,0x38b80139,0x00000000,0x00000000}},	//   _räk_, bīr_, --, --, 
   {{0x1ce40327,0x22940139,0x5a440064,0x38b80055}},	//   _ཨརབ_, _säk_, _рэта, cīr_, 
   {{0x2294010b,0x6824030d,0x00000000,0x00000000}},	//   _päk_, _юьзз, --, --, 
   {{0x58040150,0x6b9801f7,0xb38163e8,0x00000000}},	//   _جونك, _mfug, ллюл, --, 
   {{0xafd803cd,0xbb38008f,0x9f4008ce,0x00000000}},	//   _sjøp, לערי, ddið_, --, 
   {{0x50b53a15,0x6b981418,0xc0740640,0x044400c0}},	//   ксту, _ofug, ећањ, _пекн, 
   {{0x6b980337,0x229400ee,0x601801d3,0xb1140e56}},	//   _nfug, _täk_, _hímz, رققا_, 
   {{0x9f4006ea,0x505800d4,0x00000000,0x00000000}},	// [248a0] gdið_, єшся_, --, --, 
   {{0x6b982252,0x9f40030a,0xb9000327,0x82340066}},	//   _afug, udiñ_, _ཧྱ_, _سرخا, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfe0c1524,0xbea40153,0x00000000,0x00000000}},	//   साहस_, _памк, --, --, 
   {{0x59f931bb,0xe8000574,0x24840122,0xbb4c037e}},	//   деля_, _शोधा_, íjmy_, _simカ_, 
   {{0x61fd63e9,0x6b9963ea,0x00000000,0x00000000}},	//   ndrl, _efug, --, --, 
   {{0xed541183,0x60dc01e0,0x7e7c0280,0x6b980368}},	//   _зор_, ntrm, mmpp, _ffug, 
   {{0xa3cc007d,0x9f400158,0xfb1402dd,0xef280023}},	//   _लाग_, reiæ_, _كوزج, ተውዒል, 
   {{0x5678bcaa,0xf7701e24,0x1b640124,0x799802d0}},	//   мбия_, داغ_, _рнаҭ, _tftw, 
   {{0xd838007f,0x601801d3,0x60dc022e,0xe9d4292c}},	//   _pwčs_, _címz, ktrm, _пку_, 
   {{0xa3cc0d0d,0xe9840150,0x64a00798,0x00000000}},	//   _लाख_, _كامۋ, лаќа, --, 
   {{0xe60c00db,0x00000000,0x00000000,0x00000000}},	//   _ۇشى_, --, --, --, 
   {{0x386405da,0xc8182002,0xc2b000c7,0xef280023}},	//   _ikor_, _تىنچ_, аҩыш, ተውዓል, 
   {{0xe61402e8,0x9f4006ea,0x00000000,0x00000000}},	//   _пдч_, vdið_, --, --, 
   {{0x5f2400d1,0xe3b000eb,0x00000000,0x00000000}},	//   ңфуз, _কারব, --, --, 
   {{0x601963eb,0xf1d000cd,0x40840166,0x00000000}},	//   _kímy, _तावन, кәям_, --, 
   {{0x31a401a9,0x9f3401ec,0xa344009d,0x00000000}},	// [248b0] _tеz_, геті, _бээл, --, 
   {{0x6b995661,0xd13000db,0x00000000,0x00000000}},	//   _sfug, _ەمگ_, --, --, 
   {{0x2374687d,0x38640086,0x6b980099,0xdb00002d}},	//   _لایح, _okor_, _pfug, _temû, 
   {{0x09c8205d,0xf354001f,0x5fa80037,0xf1a81176}},	//   रल्य, _ዋስትና, _छ्पल, _باکه_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x386563ec,0x1ce40156,0x09e43417,0x00000000}},	//   _akor_, _ཨརཝ_, токн, --, 
   {{0x48780139,0x00000000,0x00000000,0x00000000}},	//   мсия_, --, --, --, 
   {{0x6b9800ec,0xac7413ea,0x9854004e,0x00000000}},	//   _ufug, _سازش, лтыш, --, 
   {{0x6844020c,0xcb28004b,0x28cc6d58,0x8ccc033f}},	//   _aèdè, _تړاو_, संहि, दूरो, 
   {{0x386433cb,0x26c00fb7,0x6b700075,0xc0dc02d3}},	//   _ekor_, čjo_, _алғу, _ንደሊ_, 
   {{0x03a4016c,0x00000000,0x00000000,0x00000000}},	//   кино, --, --, --, 
   {{0x044563ed,0xa3cc033f,0xfc3c0248,0x27b001af}},	//   темн, _लाओ_, _ààtò_, _сәкс, 
   {{0x7e7c005b,0x00000000,0x00000000,0x00000000}},	//   ympp, --, --, --, 
   {{0x7ae401e6,0x5f00098a,0xdbf80055,0x12180166}},	//   _äkte, रिस्_, _sāük, нюсы_, 
   {{0x3618b809,0x212c00ae,0x00000000,0x00000000}},	//   _ترنگ_, ádh_, --, --, 
   {{0xfd1001ed,0xdd1c00d0,0x06e4000d,0xa3cc06e3}},	//   یجا_, _nášm, _कहाव_, _लाट_, 
   {{0x60dd63ee,0x644563ef,0x6844020c,0x443163f0}},	// [248c0] strm, _imii, _zèdè, _ily_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8e5400d4,0x00000000,0x00000000,0x00000000}},	//   утті, --, --, --, 
   {{0x351800c8,0x443005da,0xbb8563f1,0x00000000}},	//   ווענ, _jly_, نلاي, --, 
   {{0x80e0534e,0x44300687,0x8f74003b,0x00000000}},	//   _पहुं, _mly_, _бурі, --, 
   {{0x6da002bf,0xada00153,0x44300142,0x0ba80ef6}},	//   _вира, _варл, _lly_, _ۋاقى_, 
   {{0x443163f2,0x644563f3,0x6e4163f4,0x6a1000f2}},	//   _oly_, _omii, _терз, شبور, 
   {{0xbbe8505a,0x3e6420ef,0x3ea00051,0x00000000}},	//   _ترسم_, pôts_, _ktkt_, --, 
   {{0xa3cc89b2,0xf7700050,0xf0ecc853,0x1b20015b}},	//   _लाज_, گاں_, _चन्द_, _মেরে_, 
   {{0x443000ee,0xded002d3,0xba0800ae,0x06d002dd}},	//   _aly_, ብረና_, _تترك_, _ﻛﻪﺗﻪ, 
   {{0x44300591,0xf7700d83,0x1a6800f2,0x2db40677}},	//   _bly_, داں_, _قیچی_, כלין_, 
   {{0x6444a3a0,0x6d400597,0xe3b00592,0xb6e4010a}},	//   _cmii, únai, يرُ_, _аюкк, 
   {{0xf9f80327,0x00000000,0x00000000,0x00000000}},	//   _ྒྲོན_, --, --, --, 
   {{0x64440140,0x659163f5,0xe64000cf,0xd0d40395}},	//   _emii, _кашу, _кечп, логъ, 
   {{0x4431184e,0xa3cc01f9,0xe53001f4,0x06740153}},	//   _fly_, _लाच_, _вещь, _суця, 
   {{0xdb0012e8,0x44312ca0,0x00000000,0x00000000}},	//   _femø, _gly_, --, --, 
   {{0x5f946a24,0x00000000,0x00000000,0x00000000}},	// [248d0] риут, --, --, --, 
   {{0x44307881,0xf2400345,0x00000000,0x00000000}},	//   _zly_, _ئێسپ, --, --, 
   {{0x2d854558,0xd5b8db02,0xf2dc003a,0x443163f6}},	//   äne_, iaā_, ltâ_, _yly_, 
   {{0xf3fc0c67,0xf2dc011f,0xd01000c6,0xb7e00412}},	//   ndã_, otâ_, _الح_, _कॉलम_, 
   {{0xf2dd5900,0xdd1c00d0,0x5ba8b4c7,0x00000000}},	//   ntâ_, _vášm, ткім_, --, 
   {{0xcda80b73,0xaba402dd,0x00000000,0x00000000}},	//   _سهره_, _ﺷﯩﻨﺎ, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf8ac02f2,0x00000000,0x00000000,0x00000000}},	//   سکم_, --, --, --, 
   {{0xd5b80618,0x0088010f,0x00000000,0x00000000}},	//   faā_, ערפֿ, --, --, 
   {{0x4430045a,0xd4080014,0xfc3c0241,0x00000000}},	//   _sly_, ۆتُم_, _ààrò_, --, 
   {{0x443163f7,0x47d4d675,0xc484005b,0x6fc00073}},	//   _ply_, _ميار, ллок, षणां, 
   {{0xe7b44540,0x82a405f5,0xa4040154,0x3898010f}},	//   _इजिप, ламж, ৎস্য_, _װיסנ, 
   {{0x2ee801f5,0x4430007f,0xa5041896,0xe7840024}},	//   _npcf_, _vly_, رىڭە_, _ружо, 
   {{0x27fc05f5,0x443163f8,0xbb38010f,0xb3380432}},	//   ldun_, _wly_, געשי, naçy, 
   {{0x7afc0882,0xd838007f,0x673802f0,0x69d8007a}},	//   āpti, _otčl_, lzuj, _नानी, 
   {{0x44300510,0x64448b14,0x9690036b,0xb33800a2}},	//   _uly_, _umii, _دییش, haçy, 
   {{0x27fd63f9,0x26dd63fa,0x673802f0,0xf2dc0393}},	// [248e0] idun_, ntuo_, nzuj, ctâ_, 
   {{0x9f40004a,0x27fc005b,0x95b80092,0x00000000}},	//   nfié_, hdun_, _ለአደጋ_, --, 
   {{0x798c0086,0x32040419,0xb3380432,0x00000000}},	//   _ûbwi, _ónya_, daçy, --, 
   {{0x26dc01e4,0x00000000,0x00000000,0x00000000}},	//   ktuo_, --, --, --, 
   {{0x27fd63fb,0x9e8403e6,0x2000058a,0x41740345}},	//   ddun_, _ناسۆ, mdii_, _جاکس, 
   {{0x200163fc,0x673801f1,0x27fc01f4,0xf42400a2}},	//   ldii_, dzuj, edun_, mläň_, 
   {{0x20000050,0xb33800ac,0xa8a002d5,0xf8e400f1}},	//   odii_, rbçi, брык, استپ, 
   {{0x200163fd,0x76a8dd6f,0x27fc0004,0xf2dd63fe}},	//   ndii_, нтов_, gdun_, ytâ_, 
   {{0x26dcd9a6,0xd5b80270,0x6d411a56,0x200163ff}},	//   gtuo_, taā_, únav, idii_, 
   {{0x20000067,0x27fc0108,0x4b5002f2,0x00000000}},	//   hdii_, adun_, _بێهر, --, 
   {{0x35681586,0x545407c6,0x20000009,0x9f40007f}},	//   эрин_, ивот, kdii_, sfiè_, 
   {{0xf2dc0429,0x2000054e,0xf41c000d,0x00000000}},	//   ttâ_, jdii_, kmäe_, --, 
   {{0x20000d62,0xf3fd6400,0x26dc1ada,0xdcfc0166}},	//   ddii_, rdã_, ctuo_, _merı, 
   {{0x200001d9,0xf2dc003a,0x2c080073,0xf41c000d}},	//   edii_, rtâ_, _सोनं_, dmäe_, 
   {{0xd5b80029,0xa1585fb0,0x8afc00bc,0xf2dc003a}},	//   skās_, гару_, _vyři, stâ_, 
   {{0xf2dc003a,0x8c44010e,0xddd000d0,0xb5940133}},	//   ptâ_, _kişň, _češi, _جێگا_, 
   {{0xe3d400db,0x2ca000d8,0x2dc80640,0x8e8401d5}},	// [248f0] _اتىع, _stjd_, ећен_, للره, 
   {{0xdcfc0724,0x27fc0007,0xb644019b,0x20005f39}},	//   _aerı, zdun_, _ｋｍ_, adii_, 
   {{0xe814038e,0x2000300b,0xc2100677,0x00000000}},	//   थामा_, bdii_, _והי_, --, 
   {{0x20000014,0xef6402e8,0x00000000,0x00000000}},	//   cdii_, _бъго, --, --, 
   {{0xdcfc0205,0x836801f3,0x00000000,0x00000000}},	//   _derı, _ሰንደቅ_, --, --, 
   {{0xdd956401,0x00000000,0x00000000,0x00000000}},	//   _гары, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x26dc0395,0x27fd6402,0x480800d8,0xa96401e0}},	//   ttuo_, udun_, теин_, киҙа_, 
   {{0xa3b407f7,0x9b5801ee,0x3cfc032e,0x42680092}},	//   टरस_, _битт_, _átvr_, ተፊኬት_, 
   {{0x26dc16b8,0x673800bc,0x27fd6403,0x00000000}},	//   rtuo_, rzuj, sdun_, --, 
   {{0x200001d9,0x29000066,0xa8c808de,0x26dc003a}},	//   ydii_, _éja_, _سباق_, stuo_, 
   {{0x97d82a1a,0x20000050,0xd7dc0490,0x69d8085c}},	//   _مظهر_, xdii_, _यायच, _नाडी, 
   {{0x43746391,0x98640451,0x00000000,0x00000000}},	//   рунт, _اُنه, --, --, 
   {{0xdb000306,0x09b4010f,0x2000058a,0x6e20007c}},	//   _nemý, יפֿט_, wdii_, önbl, 
   {{0xf28400ec,0xf3e800fe,0x00000000,0x00000000}},	//   جھيو_, টয়ৰ_, --, --, 
   {{0x3db000bd,0xafd800cc,0xf5580375,0x20016404}},	//   _চাইল, _kjøy, _בדצמ, udii_, 
   {{0x6fb03009,0x2000198f,0xb7780882,0x2a64007f}},	// [24900] زملا, rdii_, riṇā, konb_, 
   {{0xee356405,0xb2b804ae,0xdcfc0205,0x906400f7}},	//   ану_, _שמיר, _serı, _ۇچقۇ, 
   {{0xf41c00c5,0x05dc28fe,0x00000000,0x00000000}},	//   smäe_, _मानब, --, --, 
   {{0x200131eb,0x15dc0150,0x00000000,0x00000000}},	//   qdii_, _ﺃﻫﻤﻬ, --, --, 
   {{0xdcfc0790,0xfb8007d6,0x00000000,0x00000000}},	//   _verı, زگری, --, --, 
   {{0x19593eb5,0x20f802b5,0x38c400f5,0x00000000}},	//   лалы_, _kōi_, ащив, --, 
   {{0x6d400113,0x6b500075,0x00000000,0x00000000}},	//   únat, йтәх, --, --, 
   {{0xb8cc367a,0xed543abb,0xb8fc00dc,0x9f40004e}},	//   _कऽ_, _тос_, _तम_, nfiï_, 
   {{0xb7e0243c,0x00000000,0x00000000,0x00000000}},	//   क्षम_, --, --, --, 
   {{0xdb0001b8,0x7ae16406,0xaa4001fc,0x56140154}},	//   _memü, mtot, _деул, িস্ক_, 
   {{0x7ae16407,0x00000000,0x00000000,0x00000000}},	//   ltot, --, --, --, 
   {{0x7ae00770,0x629805ce,0x2378001f,0xdddc002b}},	//   otot, _čvor, _በሕዝብ_, _bhrū, 
   {{0x75d400e3,0xafd80158,0xdddc00b8,0xf1d8012c}},	//   _نيشا, _gjøy, _chrū, म्झन, 
   {{0x05dc05ba,0xb7e00cb2,0x3b0420ac,0xdddc0055}},	//   _मायब, क्रम_, ivoq_, _dhrū, 
   {{0x7ae025e4,0xdb0000e4,0x68240139,0x00000000}},	//   htot, _remý, _iñdr, --, 
   {{0xdb012997,0x7ae16408,0x93b40063,0x25180677}},	//   _bemü, ktot, _убиц, _יווא, 
   {{0xdb011041,0x7ae001ed,0xa500031c,0x9f40002f}},	// [24910] _memó, jtot, _མནོག_, rgiß_, 
   {{0xdb000086,0xf41c02f6,0x3db000fe,0xf9e40154}},	//   _demü, ljä_, _চাউল, _গোসল_, 
   {{0xed896409,0x7ae0005f,0xdd981ae2,0xdcfc00de}},	//   тсак_, etot, ршу_, _merķ, 
   {{0x7ae0208d,0x630407d6,0xfba81870,0xf41c0432}},	//   ftot, _اویل, _ﺷﯩﺮﻛ, njä_, 
   {{0xdb008e11,0xee85640a,0x7ae1640b,0x9cb40075}},	//   _gemü, _выво, gtot, ممەت, 
   {{0x6ca5640c,0xf41c023a,0xb344010e,0x1a780f15}},	//   _враж, hjä_, _gaçŷ, абчы_, 
   {{0x3b040af5,0x9d18c3c7,0x7ae00ba7,0x5e6400d1}},	//   avoq_, _корт_, atot, _بۆلە, 
   {{0x7ae1640d,0x00000000,0x00000000,0x00000000}},	//   btot, --, --, --, 
   {{0xdb01379b,0xfbd002e4,0xdcfc0171,0x864400d4}},	//   _demó, _מתן_, _berķ, йниж, 
   {{0x7c3800c0,0x00000000,0x00000000,0x00000000}},	//   _įtri, --, --, --, 
   {{0x5ea80154,0x4488009d,0xd624007b,0x00000000}},	//   _ওয়াই, лбон_, تعيي, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x06d4015b,0x940c0213,0x00000000,0x00000000}},	//   _তৈরি, nqdə_, --, --, 
   {{0xdb00007f,0xf3fc0798,0xd7746d69,0x71a018cd}},	//   _kemò, boão_, _بامع, зарз, 
   {{0x3241640e,0x4ad000c5,0x7ae1640f,0x65840006}},	//   черг, _समझव, ztot, _тыдз, 
   {{0xdb016410,0x7ae01e54,0x290405d5,0x7f18187f}},	//   _memò, ytot, ivna_, лізу_, 
   {{0x63a56411,0xdb000ba1,0xef1c07c5,0x823401b9}},	// [24920] _ifin, _lemò, _sgür_, _هردا, 
   {{0xa068329e,0x7ae01eca,0x00000000,0x00000000}},	//   уаға_, vtot, --, --, 
   {{0x24800649,0x7ae16412,0x0d9801ec,0xc104009a}},	//   _khim_, wtot, ртуы_, _اوجي, 
   {{0x7ae16413,0x7ff56414,0x3b840395,0x00000000}},	//   ttot, _اسدا, блег, --, 
   {{0x3b040af5,0x63a40134,0x68e00007,0xdb00056a}},	//   uvoq_, _mfin, etnd, _remó, 
   {{0x7ae16415,0x3e347c12,0xdb00067c,0x7c941a5c}},	//   rtot, _افسر, _bemò, _грац, 
   {{0x63a407b4,0xf41c049b,0x2480013f,0x3b040194}},	//   _ofin, yjä_, _ohim_, svoq_, 
   {{0x19585dc9,0x6d5400c8,0xdb016416,0x63a40789}},	//   лаһы_, _הילף_, _demò, _nfin, 
   {{0x36880323,0x787c0200,0xd5b0007b,0x00000000}},	//   лсон_, jëve, وفة_, --, 
   {{0x24812beb,0x0b580166,0x15b40150,0x00000000}},	//   _ahim_, _трсы_, _ﺼﺩﻗﻬ, --, 
   {{0xe85029a4,0xdb000005,0x63a40175,0xb89400c6}},	//   _کنند, _temó, _bfin, _الصع, 
   {{0x24816417,0xb9e40020,0x63a40332,0x857401c6}},	//   _chim_, _ራስ_, _cfin, өлөх, 
   {{0x63a4089c,0xf41c01f4,0x00000000,0x00000000}},	//   _dfin, rjä_, --, --, 
   {{0x63a40c8c,0x260c00ab,0xa6c40736,0xabdc0150}},	//   _efin, _थोपी_, _اوول_, _ﺇﻋﻤﺎ, 
   {{0x89480020,0xdddd6418,0x76481459,0x63a43995}},	//   _እንደጻ, _birž, _imfy, _ffin, 
   {{0x24816419,0x65540375,0x00000000,0x00000000}},	//   _ghim_, _לבוא_, --, --, 
   {{0xb8d86d7e,0xdddc0006,0x59c808e6,0x52dc0f22}},	// [24930] _མས_, _dirž, रणार, যবহৃ, 
   {{0x50f439af,0x30e401ca,0x00000000,0x00000000}},	//   _дзот, _лімб, --, --, 
   {{0x2ca5641a,0x2d0017cb,0x68e00175,0xa1a8008e}},	//   ënd_, रटेल_, xtnd, _утыз_, 
   {{0x69d88fa7,0xdb001f3f,0xdddc00c0,0x24800200}},	//   _नाही, _remò, _girž, _xhim_, 
   {{0x683c0241,0x764802d0,0xcb680063,0x00000000}},	//   _làdù, _omfy, јале_, --, 
   {{0x30c01c5c,0xfee80116,0x940c0213,0x00000000}},	//   ﺭﮔﻪﻧ, _туюқ_, rqdə_, --, 
   {{0x9e34010b,0x787c036e,0x9a740092,0xf41c00cc}},	//   _эерч, zëve, ብሪካው_, _পতনৰ_, 
   {{0x2905641b,0x6e240455,0x7d0000e4,0x06c801c4}},	//   rvna_, _hojb, sãrá, агий_, 
   {{0x4e0c08e9,0x63a4031c,0xd6a8109c,0x00000000}},	//   _सफाई_, _rfin, یدیم_, --, 
   {{0x2480138f,0x63a5641c,0x6e240455,0x59e00406}},	//   _shim_, _sfin, _jojb, _नायर, 
   {{0x2481641d,0x63a5641e,0x6e25641f,0x437400d1}},	//   _phim_, _pfin, _mojb, ﺸﺘﯩﻦ_, 
   {{0x787c0023,0x6e24047e,0x00000000,0x00000000}},	//   tëve, _lojb, --, --, 
   {{0x59e00bca,0xefe40092,0xd3340006,0xe6a80108}},	//   _नामर, _ማሳያ_, пэры, _съел_, 
   {{0x787c0240,0x24811107,0xdddc00ef,0x00000000}},	//   rëve, _whim_, _sirž, --, 
   {{0xf41c0664,0x24816420,0x66016421,0x6fc806b1}},	//   mmän_, _thim_, _iank, तृभू, 
   {{0x66016422,0xf41d6423,0x63a56424,0x23600457}},	//   _hank, lmän_, _ufin, _txij_, 
   {{0x7e2425f2,0x66016425,0xc2c401f7,0xdddc0064}},	// [24940] одаж, _kank, _بيخي, _virž, 
   {{0x66016426,0x44210036,0xf41c010b,0x00000000}},	//   _jank, ljk_, nmän_, --, 
   {{0x6e240477,0x66016427,0x823400f2,0x00000000}},	//   _dojb, _mank, _هرگا, --, 
   {{0x7178025f,0xf41c02f6,0xd838110c,0x3db0009e}},	//   _כניס, hmän_, _kuče_, _চাওল, 
   {{0xd8381696,0xfca8021a,0x66000a85,0xab816428}},	//   _juče_, _چارو_, _oank, мушк, 
   {{0x66016429,0xfca9642a,0xd83805ce,0xdb0803b2}},	//   _nank, _نارو_, _muče_, _ílív, 
   {{0xed544f85,0x69d818cc,0xf41c007c,0x4c1400f7}},	//   _дор_, _नारी, dmän_, تبەس, 
   {{0x6601642b,0x59c800bc,0xad18011a,0x00000000}},	//   _aank, रणहर, _דולר, --, 
   {{0x7c200efa,0x00000000,0x00000000,0x00000000}},	//   mjor, --, --, --, 
   {{0x660043d6,0x7c21642c,0x8b642309,0xf41c010e}},	//   _cank, ljor, _راقم, gmän_, 
   {{0x6601642d,0x37e4013d,0x00000000,0x00000000}},	//   _dank, _можг, --, --, 
   {{0x7c21642e,0xd8381a48,0x00000000,0x00000000}},	//   njor, _buče_, --, --, 
   {{0x6601642f,0xdddc003d,0x7c200086,0x00000000}},	//   _fank, _birż, ijor, --, 
   {{0x7760379d,0x6600005c,0x7c2019f5,0x7d0d0b07}},	//   _ixox, _gank, hjor, _orbs, 
   {{0x1cb4025c,0x6e240477,0xa1956430,0x646800f2}},	//   ཞེས_, _rojb, дарч, èsiè, 
   {{0xd90519f1,0x66016431,0xd5a56432,0x9f400268}},	//   _یی_, _zank, _بلژی, ffià_, 
   {{0x260c0574,0x7c216433,0xd838009b,0x6e256434}},	// [24950] _थोडी_, djor, _guče_, _pojb, 
   {{0x6e24014f,0x66000213,0x76580076,0x9f9c0c5e}},	//   _qojb, _xank, nnty, rťák_, 
   {{0x7c20c80a,0x76590dd8,0x6e240115,0x7d00033f}},	//   fjor, inty, _vojb, łosn, 
   {{0x77611757,0x00000000,0x00000000,0x00000000}},	//   _oxox, --, --, --, 
   {{0xe47c008f,0x7d0d6435,0x6e24047e,0xf41cadae}},	//   בראכ, _erbs, _tojb, ymän_, 
   {{0x3e6405da,0x6f0cffe7,0x7c21274e,0xae4001d3}},	//   kôty_, _ircc, ajor, _کپڑو, 
   {{0x77600921,0x66016436,0x7c2002d2,0x38c8129e}},	//   _axox, _rank, bjor, مايی_, 
   {{0x66004d42,0x9f400120,0x76596437,0x07f80022}},	//   _sank, ceió_, enty, схкы_, 
   {{0x66016438,0x3a700598,0x8c4400ee,0x9b240108}},	//   _pank, ьләр, _деңе, _оффл, 
   {{0xca380115,0x660002d1,0xcfd000cc,0xe7a83885}},	//   _buŝe_, _qank, াভিন, _ट्रप, 
   {{0x7760379d,0x66016439,0xf41c0d31,0xd8380010}},	//   _exox, _vank, rmän_, _suče_, 
   {{0x6601643a,0x7659643b,0xaacc05f9,0xf41d493a}},	//   _wank, anty, _हटाक, smän_, 
   {{0x6601643c,0xafd800ed,0xf55401d5,0x64940171}},	//   _tank, _kløf, قلیب_, _aģit, 
   {{0xd83805ce,0x4129643d,0xca380115,0x00000000}},	//   _vuče_, бого_, _fuŝe_, --, 
   {{0x28cc00dc,0xf484797d,0x7c2001f4,0x6f0c179e}},	//   सूचि, تایی, yjor, _arcc, 
   {{0xd8381591,0x94a801d9,0x1fd400fe,0xf41c007c}},	//   _tuče_, _باوِ_, হ্নস, nmäl_, 
   {{0xe7e03bca,0x7d0c2a92,0xf438011a,0x7c20010f}},	// [24960] _गाना_, _srbs, _לתקש, vjor, 
   {{0xb380010b,0x00000000,0x00000000,0x00000000}},	//   _ялыл, --, --, --, 
   {{0x6e909ce2,0x7c21643e,0x93246f51,0xb198008f}},	//   رلما, tjor, _فرین, _לייכ, 
   {{0xdb0001b8,0x2ca40077,0x7d0c0010,0x3b8405a2}},	//   _memö, índa_, _vrbs, плег, 
   {{0x7c21643f,0x76596440,0xdb0001b8,0xafd81445}},	//   rjor, ynty, _lemö, _bløf, 
   {{0x7760025c,0xcdf4013d,0x00000000,0x00000000}},	//   _rxox, _очсы, --, --, 
   {{0xdb00014a,0x60c8007b,0xf848084c,0x7d0c02d0}},	//   _nemö, ádmh, йчий_, _urbs, 
   {{0x97140c04,0x9f400489,0xa9640114,0x00000000}},	//   дмиц, leiñ_, џића_, --, 
   {{0xafd808fb,0x7bc0030a,0xdd9001e2,0x00000000}},	//   _imøt, maou, _سوړ_, --, 
   {{0x7bc00dd4,0xdb0001e6,0x95280327,0xf3fc0022}},	//   laou, _bemö, རྱའི_, moãi_, 
   {{0x05dc02c3,0x00000000,0x00000000,0x00000000}},	//   _मारब, --, --, --, 
   {{0x7bc16441,0x080821ec,0xdb0002d2,0xe7e009bb}},	//   naou, _وزني_, _demö, _गाया_, 
   {{0x28882444,0x77602798,0x366800d8,0xa3ac012d}},	//   _اصلی_, _uxox, _ладо_, गड़_, 
   {{0x3e640109,0x1fd4009e,0xafd81924,0x7bc0a573}},	//   pôty_, হ্মস, _kløg, haou, 
   {{0xb3540b8a,0x61156442,0x7bc16443,0x779008dc}},	//   تیکا_, ндру, kaou, _تیکا, 
   {{0x656c0e78,0x6f0c0055,0xb61402dd,0x00000000}},	//   ßche, _prcc, _ﺸﻥ_, --, 
   {{0x7bc07d9b,0x7ae4007c,0x00000000,0x00000000}},	// [24970] daou, _äkth, --, --, 
   {{0x7998035a,0x644800e2,0x00000000,0x00000000}},	//   _ngtw, ījie, --, --, 
   {{0xd7dc2413,0xcb080451,0x00000000,0x00000000}},	//   _यांच, ڪيشن_, --, --, 
   {{0x7bc00165,0x98c400bc,0xcb5400e5,0x00000000}},	//   gaou, štěn_, وناظ, --, 
   {{0xbf7001ec,0xf41c00cc,0x00000000,0x00000000}},	//   _ақты, _পতাৰ_, --, --, 
   {{0x787c00e4,0x00000000,0x00000000,0x00000000}},	//   vëva, --, --, --, 
   {{0x9f402880,0x7bc00156,0x4ac80412,0x00000000}},	//   leið_, baou, _रिकव, --, 
   {{0xdd94045c,0x787c036e,0x00000000,0x00000000}},	//   _часы, tëva, --, --, 
   {{0x6b996444,0x06840b01,0x00000000,0x00000000}},	//   _igug, мгин, --, --, 
   {{0xafd8cc33,0x6ab8014b,0x787c0240,0x00000000}},	//   _fløg, _iwuf, rëva, --, 
   {{0x69c149c0,0x228401ed,0xafd82a5b,0xd90c129e}},	//   mane, nöke_, _klød, _هیو_, 
   {{0x9f4005a4,0x47353989,0x00000000,0x00000000}},	//   keið_, _онес, --, --, 
   {{0x69c16445,0x051c0154,0x00000000,0x00000000}},	//   oane, দনের_, --, --, 
   {{0x69c16446,0xd29402bf,0x7bc00156,0x00000000}},	//   nane, ерсь, zaou, --, 
   {{0x4095313b,0x69c004fe,0x6b996447,0x9f4005c7}},	//   драт, iane, _ogug, veiñ_, 
   {{0x6ab80921,0x6b996448,0xd8380841,0xb3200327}},	//   _owuf, _ngug, _kuča_, ོདཁང_, 
   {{0xf4100302,0x9f400156,0xf484a541,0x7bc00165}},	// [24980] _יפה_, teiñ_, _تاوی, vaou, 
   {{0x6b986ca2,0x00000000,0x00000000,0x00000000}},	//   _agug, --, --, --, 
   {{0x69c02045,0x61fd6449,0xafd944cf,0x9f4003bd}},	//   dane, merl, _blød, reiñ_, 
   {{0x61fd644a,0x69c00731,0x9f400174,0xfbd000ec}},	//   lerl, eane, beið_, ئتا_, 
   {{0x69c02747,0xdb0001a2,0x7bc00489,0x78b80618}},	//   fane, _nemô, raou, _swtv, 
   {{0x61fd644b,0x69c1644c,0x6b98209c,0x8b641547}},	//   nerl, gane, _egug, رانم, 
   {{0x6ab8401f,0xafd8037e,0x61fc1542,0x60dd644d}},	//   _ewuf, _flød, ierl, nurm, 
   {{0x61fd644e,0x69c1644f,0xafd96450,0xd8380010}},	//   herl, aane, _glød, _buča_, 
   {{0x61fd6451,0x60dd6452,0x56956453,0x00000000}},	//   kerl, hurm, наит, --, 
   {{0x61fc04a7,0xdb007e9a,0xe9d56454,0x60dd6455}},	//   jerl, _demô, _оку_, kurm, 
   {{0x60dc0200,0xadd4011a,0xbb740150,0x9f40013d}},	//   jurm, וויח_, _ﺸﻜﻠﻪ_, lfiä_, 
   {{0xafd80450,0x61fc01f5,0xdc3c0024,0x00000000}},	//   _kløe, eerl, ršėn, --, 
   {{0xe7e002ab,0xd838009b,0xd8756456,0xf41c013d}},	//   _गाता_, _guča_, _قاچب, lmäk_, 
   {{0x61fc32ff,0x60dd6457,0x93840139,0x00000000}},	//   gerl, furm, _ığıs, --, 
   {{0xe5f40302,0x60dd6458,0xa29402bf,0x229401a9}},	//   _חזור_, gurm, тарі, тиря, 
   {{0x5185141c,0x601802bf,0x5ea8015b,0xa088010b}},	//   дуға, мося_, গঠনে, дсуз_, 
   {{0x61fd6459,0x69c1645a,0xd1d40023,0x533400cf}},	// [24990] berl, yane, _ይዓቢ_, _чепт, 
   {{0x61fd645b,0x2ca4172e,0x60dd20fe,0x6ab800ca}},	//   cerl, índo_, burm, _rwuf, 
   {{0x60dc070d,0xd25001ed,0x7e600129,0xc1e400f1}},	//   curm, _لنک_, éopa, _ښکېل_, 
   {{0x2ca400df,0x26c800e5,0x00000000,0x00000000}},	//   ŭndo_, ácok_, --, --, 
   {{0x69c1645c,0x4a7510b2,0x6e2000e5,0x00000000}},	//   tane, ныкт, önbs, --, 
   {{0xca380115,0x98ac06be,0x69c068a9,0x5f940395}},	//   _buŝa_, _axdı_, uane, _шият, 
   {{0xdd95645d,0xc7a5645e,0x8be800db,0x00000000}},	//   _аары, нийк, _ىىسق_, --, 
   {{0x61fd645f,0x6b9859fc,0x64980356,0xaad401f9}},	//   zerl, _ugug, _aţin, _ठिपक, 
   {{0x6ab80921,0x69c16460,0x1cdc025c,0x61fd6461}},	//   _uwuf, pane, _ཡའོ_, yerl, 
   {{0x69c16462,0xca380115,0x60dcc026,0xd83816a3}},	//   qane, _fuŝa_, yurm, _vuča_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x61fd6463,0xd8382220,0x60dc2ca8,0x3eb001f4}},	//   werl, _tuča_, vurm, ypyt_, 
   {{0x61fc2b8a,0x00000000,0x00000000,0x00000000}},	//   terl, --, --, --, 
   {{0x60dd6464,0x61fc03fa,0xe814012c,0x04c801c8}},	//   turm, uerl, थाका_, _فوتي_, 
   {{0x61fd6465,0xae006a04,0x1cdc0327,0xe73401ee}},	//   rerl, रजनन_, _ཡའེ_, _хеҙ_, 
   {{0x61fd6466,0xafd86ab9,0x6da016c3,0x3c3c0124}},	//   serl, _smør, ҳифа, _oïva_, 
   {{0x61fd1837,0x60dd6467,0xba400153,0x00000000}},	// [249a0] perl, surm, _šįme, --, 
   {{0x9f416468,0x88c4015b,0x60dc04cc,0xfe0800c5}},	//   lgië_, _এমনক, purm, _होखस_, 
   {{0x71b80375,0xb634008f,0xed54014b,0x3eb0007c}},	//   _מציג, ערעס_, ноф_, spyt_, 
   {{0x3a3c008b,0xdb00032e,0xd9c8098a,0x7c6407d6}},	//   _sltp_, _afmá, रण्ट, راضل, 
   {{0x94200490,0x00000000,0x00000000,0x00000000}},	//   यातच_, --, --, --, 
   {{0x787c036e,0x6b7400d1,0x00000000,0x00000000}},	//   tëvo, хәсс_, --, --, 
   {{0xf1b004ae,0x00000000,0x00000000,0x00000000}},	//   נסה_, --, --, --, 
   {{0x3ea004e6,0x57183da1,0x39440022,0x00000000}},	//   _kukt_, джия_, _ҧнаг, --, 
   {{0x69ac00cd,0x00000000,0x00000000,0x00000000}},	//   ुरशी, --, --, --, 
   {{0x3ea00227,0x3a0400dd,0x00000000,0x00000000}},	//   _mukt_, _سکتی_, --, --, 
   {{0x3ea0ed6b,0x98c40022,0xd1d40023,0x81d40154}},	//   _lukt_, _риеҵ, ራኸብ_, সভা_, 
   {{0x9f40017a,0xdcfc00de,0xb6a4022e,0x00000000}},	//   ggië_, _agrī, _зидл, --, 
   {{0x3ea00054,0x00000000,0x00000000,0x00000000}},	//   _nukt_, --, --, --, 
   {{0xb9fc2295,0xe4d001d5,0x00000000,0x00000000}},	//   _ቀን_, ختیب, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3ea078d0,0x20980108,0x00000000,0x00000000}},	//   _bukt_, ексы_, --, --, 
   {{0x1cdc0327,0x047400f2,0xec680150,0x00000000}},	// [249b0] _ཡའུ_, _جئوگ, үрек_, --, 
   {{0x54e400af,0x9294a30d,0x202c0023,0x00000000}},	//   _कमाए_, _шапц, _ተጻረር, --, 
   {{0xf2dc014b,0x0c740214,0x787c036e,0x0ce80022}},	//   luâ_, نگرد, tëvl, ьуаҩ_, 
   {{0x3ea0a2ec,0x6ca000cf,0x00000000,0x00000000}},	//   _fukt_, _ۅلسۅ, --, --, 
   {{0x09e56469,0xf1e002f5,0xdef9646a,0x48dc00cc}},	//   волн, য়ীভ, _пыр_, _মনেৰ, 
   {{0xd8382230,0x00000000,0x00000000,0x00000000}},	//   _bučo_, --, --, --, 
   {{0x787c0240,0x00000000,0x00000000,0x00000000}},	//   mëvj, --, --, --, 
   {{0x64880156,0xf2dc0124,0x668001d5,0x00000000}},	//   oñie, kuâ_, گیتل, --, 
   {{0xdb00008c,0xdcfc00da,0x64880649,0x26c806af}},	//   _afmæ, _izrā, nñie, éco_, 
   {{0x613c0793,0x00000000,0x00000000,0x00000000}},	//   nälö, --, --, --, 
   {{0x04441c31,0xa24405a9,0x58d4013e,0xc4841422}},	//   венн, ۇرسۇ, _бохт, клок, 
   {{0x387804fb,0x58041870,0x7d0801bf,0x00000000}},	//   _قشنگ_, _مومك, æfsi, --, 
   {{0xf2dc07dd,0xb9e81772,0x27fc00d5,0x9f402543}},	//   guâ_, _ኮታ_, meun_, rgië_, 
   {{0x27fc3386,0x7d000034,0xca380115,0x3ea001a4}},	//   leun_, łosi, _muŝo_, _rukt_, 
   {{0x613c014a,0x3ea00064,0x00000000,0x00000000}},	//   dälö, _sukt_, --, --, 
   {{0x27fc3386,0x00000000,0x00000000,0x00000000}},	//   neun_, --, --, --, 
   {{0xdb240217,0x27fc0098,0x48dc03d4,0x00000000}},	// [249c0] _årøy, ieun_, _মনোৰ, --, 
   {{0x27fc3386,0x613c01b8,0x4f95646b,0xa06801e0}},	//   heun_, gälö, урсу, фаға_, 
   {{0x27fd29df,0x188c02dd,0x00000000,0x00000000}},	//   keun_, _ﺗﺎﯞﻯ_, --, --, 
   {{0x27fc1dd4,0x3ea00054,0x69d41709,0xca38010f}},	//   jeun_, _tukt_, óxen, _buŝo_, 
   {{0x20000276,0x27fc0c6a,0xeb9426b1,0xee34074d}},	//   meii_, deun_, виц_, анă_, 
   {{0xca380115,0x613c0793,0x200003a0,0x27fc003e}},	//   _duŝo_, cälö, leii_, eeun_, 
   {{0x1cdc003d,0x7c94889a,0x27fc036e,0x00000000}},	//   _ཡའི_, _арац, feun_, --, 
   {{0x27fc7f01,0xafd80158,0x2258037e,0x20000356}},	//   geun_, _kløa, hirk_, neii_, 
   {{0xe7e0069f,0xca3801e4,0xe3d80eac,0x6d64054e}},	//   _गारा_, _guŝo_, তভাব, ăraţ, 
   {{0x2258002d,0xea85646c,0xfc3c0ca8,0x00000000}},	//   jirk_, _абул_, _ààbò_, --, 
   {{0xd5b8005f,0x20000270,0x27fd646d,0xa9f401e1}},	//   rbā_, keii_, beun_, _àbáà_, 
   {{0x27fc0438,0xf2dc0607,0x00000000,0x00000000}},	//   ceun_, tuâ_, --, --, 
   {{0x38640428,0x97c40209,0x2000054e,0x91c400d1}},	//   _ijor_, _айҗе, deii_, ләнл, 
   {{0x2d85646e,0xfbb800eb,0x04f000eb,0x00000000}},	//   ýnek_, ুলিত, জয়ের_, --, 
   {{0x20000421,0x0efc0490,0x613c29ef,0x6adc276a}},	//   feii_, ॉट्स_, välö, _नम्र, 
   {{0x0f440020,0xe1f00014,0x2284007c,0x00000000}},	//   _መመልከ, ٝسہ_, röka_, --, 
   {{0x228401e6,0x59b43ee1,0x787c0240,0xf2dc003a}},	// [249d0] söka_, ुरार, tëvj, quâ_, 
   {{0x27fd646f,0x6488002e,0x00000000,0x00000000}},	//   zeun_, rñie, --, --, 
   {{0x20004ff3,0x27fc00d5,0x21640138,0x8bd8d227}},	//   beii_, yeun_, _втяг, емес_, 
   {{0x20016470,0xafd80158,0xca380115,0x787c036e}},	//   ceii_, _fløa, _puŝo_, sëvj, 
   {{0x613c01b8,0x00000000,0x00000000,0x00000000}},	//   pälö, --, --, --, 
   {{0x3864013c,0xdea402f2,0x00000000,0x00000000}},	//   _ajor_, _ئیلی, --, --, 
   {{0x27fd6471,0x7c341347,0x00000000,0x00000000}},	//   teun_, ågrø, --, --, 
   {{0x225803fa,0x48040251,0xdcfc005f,0xca380115}},	//   zirk_, упив, _uzrā, _tuŝo_, 
   {{0x27fc1dd4,0x97c40131,0x64880113,0xdb80001f}},	//   reun_, جتىم, hñic, ራቸውም_, 
   {{0x27fd29de,0x20000311,0x26f000af,0x26dc00b5}},	//   seun_, zeii_, _अहीर_, ruuo_, 
   {{0x27fc3386,0x386403a1,0x34b0036b,0x7afc0356}},	//   peun_, _fjor_, یمیز, ăpte, 
   {{0x3864143a,0x9f405207,0x00000000,0x00000000}},	//   _gjor_, rfiú_, --, --, 
   {{0x225895ac,0x5a440276,0x9f4000e5,0x00000000}},	//   tirk_, _сэӂа, sfiú_, --, 
   {{0x26c80030,0x00000000,0x00000000,0x00000000}},	//   ácou_, --, --, --, 
   {{0x20016472,0xd61801ed,0x38640200,0x69c8000d}},	//   teii_, _جتنا_, _yjor_, _सजनी, 
   {{0x34b031b1,0xf8b000d9,0x8eac00eb,0x00000000}},	//   _اميز, משל_, গঠনগ, --, 
   {{0x64456473,0x20000311,0x44300009,0x22580153}},	// [249e0] _ilii, reii_, _ioy_, pirk_, 
   {{0x44316474,0x7dc56475,0xdee401b9,0x20000356}},	//   _hoy_, اقان, лоғи, seii_, 
   {{0x44303d27,0x6444d62e,0x20000421,0x3f840030}},	//   _koy_, _klii, peii_, ťou_, 
   {{0xfaa56476,0x44300c18,0x3b8c0023,0x00000000}},	//   гадо, _joy_, _ዝሓይሽ_, --, 
   {{0x44301574,0xf41c5d8a,0x64456477,0xafd95b1c}},	//   _moy_, mmät_, _mlii, _kløn, 
   {{0x19580209,0x44316478,0xf41c02f6,0xada09731}},	//   калы_, _loy_, lmät_, _гарл, 
   {{0x64456479,0x44300014,0x787c0240,0x48c40961}},	//   _olii, _ooy_, lëvi, ашығ, 
   {{0x4431647a,0xdb0001bf,0x64440254,0x59e00a59}},	//   _noy_, _afmå, _nlii, _नाकर, 
   {{0xbf98008f,0x00000000,0x00000000,0x00000000}},	//   עיִש, --, --, --, 
   {{0x6445647b,0x26f499db,0x7ae1647c,0xf41c023a}},	//   _alii, اريخ_, muot, hmät_, 
   {{0x64440b21,0x7ae01e76,0x4431647d,0x98c401c6}},	//   _blii, luot, _boy_, _төлж, 
   {{0x38a80295,0x6445647e,0x3864036e,0x998c01ef}},	//   _iùr_, _clii, _ujor_, _hodů_, 
   {{0x4431647f,0x7ae002d5,0x644401c3,0xd8380010}},	//   _doy_, nuot, _dlii, _lučk_, 
   {{0x64456480,0xe2980953,0x44300254,0x333c0135}},	//   _elii, лаў_, _eoy_, ġux_, 
   {{0x76596481,0x44316482,0x64456483,0x7ae004cc}},	//   mity, _foy_, _flii, huot, 
   {{0x76596484,0x7ae002d5,0xe4d012e1,0x44316485}},	//   lity, kuot, _اتوب, _goy_, 
   {{0x7ae002d5,0xafd801bf,0x00000000,0x00000000}},	// [249f0] juot, _fløn, --, --, 
   {{0x59e0000b,0x76596486,0x7ae002d5,0xd8380427}},	//   _नागर, nity, duot, _bučk_, 
   {{0x2d84049f,0x44316487,0xd37000f2,0x20d40064}},	//   åne_, _yoy_, _دهک_, _ліўс, 
   {{0x76596488,0x64456489,0xc0c01cd1,0x320006d9}},	//   hity, _xlii, _фәри, lejy_, 
   {{0x7659648a,0x64880649,0x7ae0e575,0x998c012c}},	//   kity, nñia, guot, _bodů_, 
   {{0xc95400b8,0x00000000,0x00000000,0x00000000}},	//   _adūṣ, --, --, --, 
   {{0x7659648b,0x9d1818ce,0x1a6800dd,0x38c812ea}},	//   dity, _йорт_, دیلی_, نايی_, 
   {{0x38a801ab,0x7ae02281,0x2bb8007b,0x7659648c}},	//   _dùr_, buot, _سارة_, eity, 
   {{0x443053ea,0x7d00012d,0x5f300023,0x249c0150}},	//   _roy_, łost, _ተራኺቦ, _ﺍﻟﺘﺸ_, 
   {{0x4431648d,0xf41c008e,0xf09d648e,0x6445648f}},	//   _soy_, zmät_, _lià_, _slii, 
   {{0x64456490,0x443034fe,0x44641318,0x65c002dd}},	//   _plii, _poy_, ивов, _құна, 
   {{0x2aa8105c,0x44316491,0x98c40cef,0xf41c0724}},	//   _køb_, _qoy_, _ысул, xmät_, 
   {{0x68e16492,0x44316493,0x76596494,0x0514015b}},	//   lund, _voy_, bity, াহের_, 
   {{0x76596495,0x45180276,0x68e0009f,0x44316496}},	//   city, _ация_, ound, _woy_, 
   {{0x68e16497,0x2aa804ce,0x7ae002d5,0x44316498}},	//   nund, _løb_, zuot, _toy_, 
   {{0x644401f7,0x7f180046,0x68e0002f,0xdb1c0205}},	//   _ulii, кізу_, iund, _özçi, 
   {{0x68e16499,0x63a5649a,0x290401ee,0x6738bf65}},	// [24a00] hund, _igin, hwna_, nyuj, 
   {{0x7ae1649b,0xef143272,0xafd82ab7,0xee3c0162}},	//   vuot, шму_, _uløn, _stýr_, 
   {{0x63a400fb,0x68e0007d,0xcfd00154,0x998c013a}},	//   _kgin, jund, াভজন, _rodů_, 
   {{0xf09d649c,0x7ae1649d,0x7659649e,0x68e1649f}},	//   _già_, tuot, zity, dund, 
   {{0xeaac0372,0x63a564a0,0xd1f0001f,0x76582d2f}},	//   وعو_, _mgin, _ሂሳብ_, yity, 
   {{0x68e04b26,0x7ae00953,0xaa5002d5,0x63a4022e}},	//   fund, ruot, овіш, _lgin, 
   {{0x765964a1,0x63a469e0,0x7ae164a2,0x8c3c399d}},	//   vity, _ogin, suot, _bişd, 
   {{0x1958052f,0xd8380e04,0x7ae00153,0x7658012d}},	//   каһы_, _kuči_, puot, wity, 
   {{0x68e0545f,0x8c3c06be,0xeb94011c,0x00000000}},	//   aund, _dişd, _вит_, --, 
   {{0x63a564a3,0x7e605eb5,0xd83807f5,0x38a808c2}},	//   _agin, éoph, _muči_, _tùr_, 
   {{0x765964a4,0x68e164a5,0xd838151c,0x63a430c1}},	//   rity, cund, _luči_, _bgin, 
   {{0x765964a6,0x673800ca,0x00000000,0x00000000}},	//   sity, byuj, --, --, 
   {{0x765800c7,0xe3b0004b,0xb354158b,0x87b80117}},	//   pity, ګرۍ_, شیدا_, _сухт_, 
   {{0x63a564a7,0xf09d64a8,0x765800f1,0x6670007b}},	//   _egin, _sià_, qity, _ودور, 
   {{0xf09cef52,0xd8380171,0x00000000,0x00000000}},	//   _pià_, _auči_, --, --, 
   {{0xd8380010,0xad2486f4,0x8c3c008e,0x3fc401b9}},	//   _buči_, یراو, _kişe, йруғ, 
   {{0x320006d9,0xc5ec004b,0x68e164a9,0x5f38084c}},	// [24a10] pejy_, _غړی_, zund, аптя_, 
   {{0xd25127f4,0x68e164aa,0x63a564ab,0x64880784}},	//   _رنج_, yund, _zgin, nñin, 
   {{0xc0c164ac,0x68e164ad,0xf09c004e,0x63a40175}},	//   _нәти, xund, _tià_, _ygin, 
   {{0x6738002e,0xf2dc00e4,0x00000000,0x00000000}},	//   yyuj, orâ_, --, --, 
   {{0xd8380063,0xf1d81d8a,0x00000000,0x00000000}},	//   _guči_, _बयान, --, --, 
   {{0xca3800df,0x68e06dc8,0xdef859fb,0x1a6801ed}},	//   _kuŝi_, tund, _тыю_, لیقی_, 
   {{0x0f40001f,0xdcf4031c,0x7afc054e,0x68e00162}},	//   _የመሠረ, _ċaħa, ăpta, uund, 
   {{0x68e164ae,0x8c3d64af,0x4bf801d5,0x787c0200}},	//   rund, _bişe, _حبسگ_, këvu, 
   {{0x63a4022e,0x64b0054e,0x869887e6,0xa78000fb}},	//   _rgin, _măie, лтот_, әҫһе, 
   {{0x68e164b0,0x63a42b52,0x8c3c03e0,0x25a001bf}},	//   pund, _sgin, _dişe, øjl_, 
   {{0x63a4036b,0xf2dc00c7,0x5a38074d,0x00000000}},	//   _pgin, erâ_, _тытă, --, 
   {{0xafd800cc,0x7c880023,0x8c3d64b1,0x9814007b}},	//   _bløm, _ዝኣተወ_, _fişe, _وبنا, 
   {{0xd874cbc6,0x34380014,0xc87925bb,0x8c3c03e0}},	//   _بالب, اسپد_, moş_, _gişe, 
   {{0xc87925bb,0x70440725,0x00000000,0x00000000}},	//   loş_, ەركە, --, --, 
   {{0x64b00276,0x9f400122,0xf2dd64b2,0x63a407c5}},	//   _băie, rgií_, arâ_, _tgin, 
   {{0xf2dc003a,0x00000000,0x00000000,0x00000000}},	//   brâ_, --, --, --, 
   {{0x44f059ed,0xafd80217,0x6fb018fd,0xbe68009d}},	// [24a20] lá_, _gløm, سملا, гааж_, 
   {{0xca380115,0xed540588,0xee347b17,0xaaa8012d}},	//   _fuŝi_, ӡоу_, бну_, _चढ़क, 
   {{0x44f164b3,0x6da08a89,0x518400ea,0xc8781f02}},	//   ná_, чиха, _муџа, koş_, 
   {{0xa3d80a28,0xb7d40a28,0xd8382625,0x44f164b4}},	//   ाणि_, kṣay, _tuči_, iá_, 
   {{0x44f150d2,0xda340c9e,0x8c3c0166,0xb478008f}},	//   há_, желы, _bişb, אָגי, 
   {{0x44f164b5,0x3f800113,0x9f4007c5,0xe9cc0131}},	//   ká_, _iyku_, mgià_, ىغى_, 
   {{0xa3d8a3d5,0x3f8000e4,0x8c3c0209,0x44f164b6}},	//   ाणा_, _hyku_, _sişe, já_, 
   {{0x44f164b7,0x583964b8,0xc8780311,0x8c3c9c11}},	//   dá_, рзия_, goş_, _pişe, 
   {{0x9f401570,0x44f00270,0x00000000,0x00000000}},	//   ngià_, eá_, --, --, 
   {{0x44f164b9,0x7d0c0421,0x8c3d64ba,0x59ac00bc}},	//   fá_, _ksbs, _vişe, _चलिर, 
   {{0x44f0306a,0xdddc00b8,0xc8784e7e,0xe9cc00ec}},	//   gá_, _akrū, boş_, _سٺن_, 
   {{0x9f400407,0xcaa402dd,0x26dc01e4,0xc878054e}},	//   nfió_, _الەۋ, bruo_, coş_, 
   {{0xafd8037e,0x44f164bb,0x00000000,0x00000000}},	//   _fløj, aá_, --, --, 
   {{0x44f00429,0x78a00170,0x06681c5c,0x3dc804ba}},	//   bá_, _hiov, ﻴﺎﻟﯩ, _nebw_, 
   {{0x44f164bc,0x78a098df,0x3f8042b2,0x00000000}},	//   cá_, _kiov, _ayku_, --, 
   {{0x78a023e0,0x8c3c084c,0xf3fc00d8,0x445401e2}},	//   _jiov, _mişc, mnão_, _وريځ, 
   {{0x78a164bd,0x5f9564be,0x9f400ffb,0x7d0c02d0}},	// [24a30] _miov, зитт, ggià_, _asbs, 
   {{0xd2510fec,0xca3800df,0xb63804ce,0xafd8fcf4}},	//   _آند_, _tuŝi_, _ｆｃ_, _kløk, 
   {{0x64b00311,0x9a800092,0x00000000,0x00000000}},	//   _tăie, ርገናል_, --, --, 
   {{0x78a00170,0x09d00073,0x656c002f,0x00000000}},	//   _niov, सण्य, ßchi, --, 
   {{0x44f164bf,0x61f00fac,0x1bb8007b,0xd1cc0092}},	//   zá_, _åhlé, صانع_, _ኢሳት_, 
   {{0x656c054e,0x48b53005,0xab600327,0x00000000}},	//   şchi, ощит, żżon, --, 
   {{0x78a0180f,0x44f164c0,0x64b0054e,0x69cc031c}},	//   _biov, xá_, _măic, _ġieħ, 
   {{0x44f00745,0x26dd64c1,0xafd800b5,0x07083997}},	//   vá_, truo_, _sløj, ليبي_, 
   {{0x78a006d9,0x3a700724,0x464800ee,0x44f164c2}},	//   _diov, яләр, изин_, wá_, 
   {{0x7d0c025a,0xd0540213,0x4638084c,0x2d8001ef}},	//   _ysbs, ruzə, рчия_, _kyje_, 
   {{0x78a00170,0x44f00093,0xdddc00e2,0x386800ae}},	//   _fiov, uá_, _skrū, úiré_, 
   {{0x78a164c3,0x26dc05d5,0xd83800ef,0x9944009f}},	//   _giov, pruo_, _buču_, _عَنه, 
   {{0x44f092f7,0x32100009,0x64b00356,0x75a00023}},	//   sá_, _baxy_, _băic, _መዓርፎ_, 
   {{0x44f164c4,0xafd80174,0x9f4005d5,0x00000000}},	//   pá_, _fløk, vgià_, --, 
   {{0x6f0c02d0,0x44f0011f,0xc0580640,0xd678007b}},	//   _ascc, qá_, арац_, _احنا_, 
   {{0x44d564c5,0x3f8000c7,0x98a00960,0xdcf400e4}},	//   mā_, _pyku_, ćić_, _ñaĩm, 
   {{0x44d50eb3,0x248164c6,0xd83800f3,0x32100306}},	// [24a40] lā_, _ikim_, _guču_, _faxy_, 
   {{0x2480003e,0xca3800df,0x9f40b618,0x00c8011c}},	//   _hkim_, _kuŝu_, rgià_, _клок_, 
   {{0x44d52e4b,0x9f4008e5,0x00000000,0x00000000}},	//   nā_, sgià_, --, --, 
   {{0x984c0316,0x44d466ff,0x321000d8,0xb4f8010f}},	//   věď_, iā_, _zaxy_, ילער, 
   {{0x3f8005d1,0x78a000d8,0x6e30005c,0xe7e004af}},	//   _uyku_, _riov, ædbø, _गाजा_, 
   {{0x44d534c7,0x78a06d4d,0x24800ac5,0x8c3c0356}},	//   kā_, _siov, _lkim_, _pişc, 
   {{0x44d411f9,0x78a164c7,0xf84828cf,0x7c040597}},	//   jā_, _piov, ичий_, _وبرك, 
   {{0x44d50eb3,0x24800211,0xec74e7ee,0xdb20054e}},	//   dā_, _nkim_, _дпс_, ătân, 
   {{0xf09164c8,0xafd89b7b,0x78a001f7,0xb6042218}},	//   ונה_, _sløk, _viov, оянк, 
   {{0x248164c9,0xafd801bf,0xf991265f,0x8a4400db}},	//   _akim_, _pløk, _قبا_, _ىئلم, 
   {{0x44d564ca,0x248008cd,0x7ae09f0f,0x6a7c045f}},	//   gā_, _bkim_, lrot, rêft, 
   {{0x7bc164cb,0x7ae164cc,0xf3fc021c,0xb864009a}},	//   nbou, orot, rnão_, _باطو, 
   {{0xe60cebe8,0x066400b2,0x44d40421,0xc32c0133}},	//   رشی_, _کانپ, aā_, ۆڕی_, 
   {{0x248164cd,0x44d4005f,0x7ae00ba7,0xd8380331}},	//   _ekim_, bā_, irot, _vuču_, 
   {{0x7ae164ce,0x3cf4033f,0x7bc0007f,0x8c3c00a2}},	//   hrot, ीबों_, kbou, _lişa, 
   {{0x6f0c070d,0x7ae164cf,0x7bc164d0,0x3210058a}},	//   _pscc, krot, jbou, _waxy_, 
   {{0x8fd0052f,0x8c3c046c,0x7bc001a4,0xc0c00131}},	// [24a50] _үҙгә, _nişa, dbou, _җәси, 
   {{0x2c2404c5,0x8164001f,0x6304036b,0x2d800240}},	//   _মতেই_, ደሚችሉ_, _کویل, _pyje_, 
   {{0x7ae164d1,0x61f800ac,0x24800309,0x30f401ed}},	//   erot, _övla, _ykim_, _بوجھ_, 
   {{0x7bc164d2,0x1b0402f5,0x64880113,0xd2507f51}},	//   gbou, লিনে_, yñim, _آنگ_, 
   {{0x78b964d3,0x6f0c0784,0x44d400e2,0x00000000}},	//   _attv, _uscc, zā_, --, 
   {{0x44d41161,0xef1c00c7,0x7bc002d0,0x8c3c0205}},	//   yā_, _irü_, abou, _dişa, 
   {{0x7ae164d4,0x27ec0165,0x7bc00129,0x6f1800d7}},	//   arot, _pcgn_, bbou, _šuch, 
   {{0x7ae0a5b8,0x44d40061,0x7bc00129,0x00000000}},	//   brot, vā_, cbou, --, 
   {{0x7ae164d5,0x787c02d3,0x44d402b1,0xb6f400d1}},	//   crot, tëvr, wā_, كىيا_, 
   {{0x44d564d6,0x248164d7,0x6ab85489,0x2bcc012d}},	//   tā_, _skim_, _ituf, _हड़ता, 
   {{0x69c0151c,0x64b00276,0xecc4005e,0x44d43495}},	//   mbne, _băia, _ﻩﻟﻪﻛ, uā_, 
   {{0x44d564d8,0xafd803cd,0x78f80375,0x7648015d}},	//   rā_, _fløi, _לפעו, _elfy, 
   {{0x44d40061,0xae180764,0xba080092,0x00000000}},	//   sā_, नयान_, _ቋት_, --, 
   {{0x44d564d9,0x34140882,0x7bc164da,0xca3800df}},	//   pā_, āraḥ_, zbou, _tuŝu_, 
   {{0x044564db,0xdb0c08a5,0x7fd8008e,0xf41c010e}},	//   _некн, _áhöl, йфат_, mlän_, 
   {{0x248164dc,0x6ab8b137,0x7bc00007,0x9f4164dd}},	//   _ukim_, _otuf, xbou, ngiç_, 
   {{0x2d8403fa,0x6ab801f2,0x2bcc0034,0x68e0009a}},	// [24a60] ünen_, _ntuf, _हज़ा, hrnd, 
   {{0xef1c00a2,0xee3448a9,0x7bc001a4,0x8c3ca75a}},	//   _drü_, пну_, wbou, _rişa, 
   {{0x6ab964de,0x7bc164df,0x7ae00034,0xef1c0254}},	//   _atuf, tbou, wrot, _erü_, 
   {{0x7bc06fca,0xb7e8023e,0x68e00109,0x7ae01e56}},	//   ubou, _टाइम_, drnd, trot, 
   {{0xaca0010e,0x68e00e78,0x2cbc04a7,0x7bc08bab}},	//   _alỳa, ernd, _čude_, rbou, 
   {{0x7bc164e0,0x8c3c0356,0xfca85089,0x00000000}},	//   sbou, _vişa, _هارو_, --, 
   {{0x6ab801f2,0x7ae164e1,0x7bc009b6,0x0f40001f}},	//   _etuf, srot, pbou, _የመሰረ, 
   {{0x7e7d64e2,0x69c00810,0x7bc00369,0xada00063}},	//   lopp, abne, qbou, _часл, 
   {{0x68e00582,0x569400d1,0x8c3c2ca8,0x7ae0022e}},	//   arnd, маит, _kişn, qrot, 
   {{0x7e7d64e3,0xf9840e92,0xd83800ef,0x00000000}},	//   nopp, _егзо, _pučs_, --, 
   {{0xa3d80b7c,0x29d0038b,0x64b00356,0x9f400166}},	//   ाणं_, _سينس, _păia, lgiä_, 
   {{0x8c3c0139,0x00000000,0x00000000,0x00000000}},	//   _lişn, --, --, --, 
   {{0xafd821e3,0x26f41ec7,0xe78001f0,0x9f400108}},	//   _kløv, _فروخ_, _пушо, ngiä_, 
   {{0xc0f41ee0,0xc7642dfc,0x7e7c0ffb,0xf1bc1100}},	//   _ፎረም_, _تامى, jopp, ्रधन, 
   {{0x7e7c4675,0x64b0054e,0xef1c0254,0x00000000}},	//   dopp, _tăia, _srü_, --, 
   {{0xb4f00011,0xa3d800dc,0x00000000,0x00000000}},	//   _জনপথ_, ाणः_, --, --, 
   {{0xa34405f5,0x8c3c0139,0xb1e000d1,0xb7e8ac66}},	// [24a70] _зээл, _bişn, _пәвқ, _टाईम_, 
   {{0x9f40008c,0x7e7c2dba,0xb81c02ab,0x64880309}},	//   rfið_, gopp, _मोसम_, yñik, 
   {{0x6ab964e4,0x69c00219,0x41b401d3,0x25b806be}},	//   _stuf, vbne, _تمپر, _əql_, 
   {{0xef1c2d1e,0x00000000,0x00000000,0x00000000}},	//   _trü_, --, --, --, 
   {{0x94fc0489,0xc9a8d550,0xf41c0723,0x69c0005a}},	//   _ཐཱའི_, овле_, ylän_, tbne, 
   {{0x7e7c00a7,0xaca000a2,0xf1bc2894,0x228402d2}},	//   copp, _plỳa, ्रिन, böku_, 
   {{0x69c08a8a,0xf8ad5b33,0x37bc00eb,0x00000000}},	//   rbne, لکن_, _ইয়র, --, 
   {{0xc7240075,0x07a43425,0xc7a4003b,0x00000000}},	//   ддий, майн, мийк, --, 
   {{0xf1bc2e35,0x6ab8cb5e,0xafd80162,0x64b00356}},	//   ्रान, _utuf, _fløv, _căin, 
   {{0x64b00356,0x8c3c0205,0x00000000,0x00000000}},	//   _dăin, _kişo, --, --, 
   {{0x74e401c0,0x00000000,0x00000000,0x00000000}},	//   мдэг_, --, --, --, 
   {{0xc1c404e4,0x64b00311,0xda3000c7,0xf41c4c51}},	//   वर्ग, _făin, _аҵәы, slän_, 
   {{0x27400248,0x64b00311,0x7e7c102c,0x7c3401f4}},	//   _dénú_, _găin, yopp, öyri, 
   {{0x41280228,0xd6d80798,0x25044e10,0x64a40124}},	//   оого_, _хтц_, _فرعی_, ьаҟа, 
   {{0xf69564e5,0x7e7c0217,0x00000000,0x00000000}},	//   _تنوع_, vopp, --, --, 
   {{0x1b04015b,0x436832ea,0x00000000,0x00000000}},	//   লিতে_, _майн_, --, --, 
   {{0x09e4015b,0x3ea403f5,0x61fc0175,0x7330075e}},	// [24a80] প্যা, диаг, pfrl, _لىيا, 
   {{0x22840008,0x6e903e66,0x8c3c00a2,0x2d8c002d}},	//   töku_, پلما, _bişo, ęgen_, 
   {{0x9324036b,0x8c3c2ca8,0xed5400d1,0x55ac010f}},	//   _قرین, _vişn, моф_, ציאַ, 
   {{0x7e7d0eed,0xafd85522,0xef1c013d,0xf534010f}},	//   sopp, _sløv, _iyün_, וטער_, 
   {{0xefb0315b,0x629c017a,0xaab40633,0xeaac00e5}},	//   _شیلگ, omro, ودور_, لٹن_, 
   {{0x4dfc0316,0x19947aa6,0x7e7c0477,0xfce441b9}},	//   र्दै_, наля, qopp, _оого, 
   {{0xada000c7,0x8c3c1ea0,0xc2f80154,0x3bf400d8}},	//   _аарл, _kişl, ইটটি_, _оџат, 
   {{0xe9d4723c,0x97140c17,0x998c012d,0x00000000}},	//   пкә_, емиц, _padł_, --, 
   {{0x629c01b9,0xac0401ca,0x00000000,0x00000000}},	//   kmro, _інфа_, --, --, 
   {{0x629c036e,0xfa48007b,0xca7400d1,0xceb8013a}},	//   jmro, _بشرى_, _كەنت_, _éře_, 
   {{0x91d4000d,0x00000000,0x00000000,0x00000000}},	//   _बजबै, --, --, --, 
   {{0x64b0054e,0x8c3c008e,0xb2c40150,0xe8200117}},	//   _tăin, _nişl, _ﺒﻨﻭﺍ, _афшо, 
   {{0xe23c0023,0x00000000,0x00000000,0x00000000}},	//   _ዓለምና, --, --, --, 
   {{0x274001e1,0x569401c4,0x00000000,0x00000000}},	//   _wénú_, _яалт, --, --, 
   {{0x8c3c013d,0xf41c0a43,0x00000000,0x00000000}},	//   _bişl, lläm_, --, --, 
   {{0x8c3c0139,0x3cf0012d,0x00000000,0x00000000}},	//   _rişo, ँढने_, --, --, 
   {{0xdef83abd,0xf1a86049,0x8c3c574b,0xa2b00073}},	// [24a90] дых_, _واده_, _dişl, ंदण्, 
   {{0xed8807b5,0x00000000,0x00000000,0x00000000}},	//   осек_, --, --, --, 
   {{0x2d8404ce,0xafd84606,0x8c3c0790,0xbf7001ec}},	//   æne_, _bløt, _fişl, _ұқты, 
   {{0x228401e6,0xc198011a,0x00000000,0x00000000}},	//   sökt_, _משתי, --, --, 
   {{0x8a0426f8,0xd1cc0023,0x5ea400db,0x00000000}},	//   езле, _ኢሳቕ_, رمۅل, --, 
   {{0x64b0054e,0x957c0064,0x07a40022,0x00000000}},	//   _băil, ngąs, ҭакн, --, 
   {{0xac740c50,0xafd9449a,0x64b00311,0x00000000}},	//   _قارش, _fløt, _căil, --, 
   {{0xafd8143a,0xdd9402dd,0x8c3c45d8,0xb5c029dc}},	//   _gløt, _расы, _kişm, ңйыл, 
   {{0x629c0142,0x00000000,0x00000000,0x00000000}},	//   ymro, --, --, --, 
   {{0xc1ec00af,0x00000000,0x00000000,0x00000000}},	//   _जाइब_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdd0c033f,0x00000000,0x00000000,0x00000000}},	//   _róża, --, --, --, 
   {{0x392000b7,0x64b00356,0x8c3c0205,0xe4e8000d}},	//   ጵያውያ, _tăio, _rişl, _झमकि_, 
   {{0x79a4010e,0x04ec00cc,0xb9dc0241,0xd5b800b8}},	//   _ýuwý, _জনীৰ_, _ṣẹ_, ccā_, 
   {{0x7d00006d,0x2d84033f,0x00000000,0x00000000}},	//   łosz, żnej_, --, --, 
   {{0x8c3d64e6,0x00a000d1,0x00000000,0x00000000}},	//   _bişm, _ﺋﺎﺷﯘ, --, --, 
   {{0x2cbc1b24,0x7e253a2a,0x8c3c054e,0x768403b2}},	// [24aa0] _čuda_, ндаж, _cişm, rðyv, 
   {{0x9d5404d3,0xef1c013d,0xafd80162,0xae8400cf}},	//   پۆرت, _iyül_, _sløt, ебуз_, 
   {{0x614400cf,0x9f4001e7,0x228401e3,0x00000000}},	//   _شىحە, ngiú_, söks_, --, 
   {{0xfbd164e7,0x27fd64e8,0x823401ed,0x03e00154}},	//   اتا_, jfun_, _آرکا, গ্রী_, 
   {{0xab8164e9,0x27fc025c,0x20000356,0x00000000}},	//   лушк, dfun_, mfii_, --, 
   {{0xbb8c02d3,0xb86424c5,0x2000c7e9,0xafd806ea}},	//   _ዝዓለመ_, کاتو, lfii_, _fløs, 
   {{0x27fc1381,0x2000208d,0xafd82a5b,0x64b0054e}},	//   ffun_, ofii_, _gløs, _băim, 
   {{0x66000280,0x81d564ea,0x2000013f,0x27fc0076}},	//   _abnk, হলি_, nfii_, gfun_, 
   {{0x20010e5e,0xafd803cd,0x1b0403d4,0xa83000cf}},	//   ifii_, _klør, লিহে_, اعىش, 
   {{0xa2d4069f,0xaee000b8,0x644164eb,0x0ba80150}},	//   _बौध्, _akṛc, ömin, _زاقى_, 
   {{0xee3c00a2,0x5558010b,0x2600008e,0x00000000}},	//   _guýu_, фаня_, учыг, --, 
   {{0xee3c0208,0x00000000,0x00000000,0x00000000}},	//   _huýt_, --, --, --, 
   {{0x91c564ec,0xf2040006,0x00000000,0x00000000}},	//   кәнл, няво, --, --, 
   {{0xb36002d3,0x20000ba7,0x5bcc1a04,0xf1a40108}},	//   _ትኸውን_, efii_, ारुव, ербн, 
   {{0x200164ed,0xca280150,0x3d18012d,0x00000000}},	//   ffii_, _ﲤﻮﺯ_, नटों_, --, 
   {{0xe1356190,0x8c3c05d1,0xa088004e,0x00000000}},	//   ынсы, _pişm, есуз_, --, 
   {{0x533564ee,0xafd964ef,0xd1d40023,0x3ea8045a}},	// [24ab0] _репт, _sløs, _ክዓቢ_, _bibt_, 
   {{0x2000198f,0xc1ec00c5,0x709001a9,0x00000000}},	//   afii_, _जाएब_, тағф, --, 
   {{0xd2500014,0x27fc03e0,0xf1a4b86f,0x00000000}},	//   _منک_, yfun_, _ярин, --, 
   {{0xf1a80330,0x27fc002f,0x00000000,0x00000000}},	//   _واگه_, xfun_, --, --, 
   {{0xafd82c95,0xee3c01fb,0x00000000,0x00000000}},	//   _flør, _buýt_, --, --, 
   {{0x3ea809f0,0xafd80158,0x8c3c0166,0x00000000}},	//   _gibt_, _glør, _kişk, --, 
   {{0x6d4001e6,0x99d40a8e,0xafd80450,0x7d2001d3}},	//   änad, اتها, _uløs, _پہنن, 
   {{0x8c3c27ac,0x7bb002dd,0x00000000,0x00000000}},	//   _mişk, _көшу, --, --, 
   {{0x27fc01c7,0x00000000,0x00000000,0x00000000}},	//   rfun_, --, --, --, 
   {{0x9f400395,0x27fc0ffb,0x778010a7,0x3ea800e8}},	//   ggiù_, sfun_, рльз, _xibt_, 
   {{0xdb00010e,0xf41803d4,0x00000000,0x00000000}},	//   _egmä, ধানৰ_, --, --, 
   {{0x996440da,0xb934010f,0x9f400332,0x00000000}},	//   _стул, _ברעג_, rgiú_, --, 
   {{0xe2840075,0xfe001cd2,0x00000000,0x00000000}},	//   лғин, र्डस_, --, --, 
   {{0xdddc1674,0x8c3d64f0,0x2cbc0010,0xee3c0208}},	//   _okrš, _bişk, _čudn_, _xuýt_, 
   {{0xd1789e08,0x389c02e3,0x57a400c7,0x2a6401ab}},	//   есті_, _ọria_, _ишәа, iinb_, 
   {{0x3ea8003d,0xafd80450,0x20000ba7,0xc3240117}},	//   _sibt_, _slør, ufii_, _амик, 
   {{0xf48450b5,0x200164f1,0xafd801bf,0xf2dc00a2}},	// [24ac0] _جاوی, rfii_, _plør, lyân_, 
   {{0x3ea800e8,0x00000000,0x00000000,0x00000000}},	//   _qibt_, --, --, --, 
   {{0x6cd018fd,0x64880113,0xedd01913,0x00000000}},	//   لقلا, sñiu, شيند, --, 
   {{0xee3c01fb,0x7b64010b,0x36e0000d,0x00000000}},	//   _suýt_, ктле, _खिलअ_, --, 
   {{0x3ea8020c,0xafd833b8,0x00000000,0x00000000}},	//   _tibt_, _iløp, --, --, 
   {{0xee3c01fb,0x1b0403d4,0x58d4004e,0xa8200066}},	//   _quýt_, লিলে_, гокт, یکنن, 
   {{0xafd803cd,0x64880113,0x00000000,0x00000000}},	//   _kløp, nñis, --, --, 
   {{0xa92402bf,0x57180395,0x64400108,0x00000000}},	//   тіше_, ежия_, ömil, --, 
   {{0x3a3c0175,0xdb0008a5,0x3b8400c7,0xd1d40023}},	//   _totp_, _afmö, _рлаг, _ክሓቱ_, 
   {{0x953806ed,0x00000000,0x00000000,0x00000000}},	//   езот_, --, --, --, 
   {{0x648802d1,0xfb840139,0xdcfc00de,0x00000000}},	//   yñit, _чыңн, _izrē, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8c3c0205,0x00000000,0x00000000,0x00000000}},	//   _dişh, --, --, --, 
   {{0xf524035b,0xe2984077,0x310c00dc,0x7ae4007c}},	//   _афин, каў_, ाबलः_, _åktu, 
   {{0x2cbc098d,0x00000000,0x00000000,0x00000000}},	//   _čudo_, --, --, --, 
   {{0x93f564f2,0xf3fc0798,0xd9d8015b,0xa9200030}},	//   _спиц, mião_, সলিম, úžil, 
   {{0xdddc0e3c,0x60dc0194,0xf3fc0120,0xf41c00fd}},	// [24ad0] _skrš, asrm, lião_, mdä_, 
   {{0xa2b08f35,0xf41c0598,0x8c3c013d,0x00000000}},	//   ंदर्, ldä_, _tişk, --, 
   {{0xf3fc0cfc,0xfcc000d1,0xd9d80154,0x61e8000d}},	//   nião_, йәтм, সলাম, _जयतौ_, 
   {{0xf41ceabc,0x8c3cfccc,0x3cf0000d,0xdd3800ef}},	//   ndä_, _kişi, ँढ़े_, bāža, 
   {{0x6d40025a,0x09e4f9e2,0xe6680023,0x00000000}},	//   änab, голн, _ትገብሮ_, --, 
   {{0xf41c0664,0x8c3c0139,0xaa640395,0x00000000}},	//   hdä_, _mişi, ътек, --, 
   {{0xdddc2625,0x6ca4c851,0xeca400d8,0xf41c010e}},	//   _ukrš, _араж, _ајан, kdä_, 
   {{0x6250000d,0xab6000d1,0x3b50bc08,0x00000000}},	//   _näon, _پۇتى, ркәр, --, 
   {{0x07085789,0x068564f3,0xf41c0166,0x644001f4}},	//   ريدي_, лгин, ddä_, ömim, 
   {{0x6f0400e2,0x31bc00dc,0x26cc0112,0x296400d8}},	//   mībā, ्रोध, _vwgo_, _ињев, 
   {{0x044564f4,0xf3fc03b7,0x6fd00a59,0x61f803b9}},	//   генн, gião_, तरां, _övli, 
   {{0x8c3c5556,0xf41c008e,0x00000000,0x00000000}},	//   _bişi, gdä_, --, --, 
   {{0xf56c044e,0x6f04005f,0x3550004b,0x387800e5}},	//   _ብዘይካ_, nībā, لنیز, épre_, 
   {{0x09e4015b,0x8c3cd95c,0xf41c013d,0x00000000}},	//   প্রা, _dişi, adä_, --, 
   {{0x50b40713,0xf3fc00d8,0xf41c0139,0x00000000}},	//   исту, cião_, bdä_, --, 
   {{0x8c3c084c,0xf41c0166,0x0f400092,0x00000000}},	//   _fişi, cdä_, _የመምረ, --, 
   {{0x0324004e,0x6fb000ae,0x00000000,0x00000000}},	// [24ae0] _сдпн, إمكا, --, --, 
   {{0xb7c0005f,0xef142e70,0x6f0400e2,0x5bcc17c6}},	//   ēģij, ыму_, dībā, ार्व, 
   {{0xfd948c72,0xdd38005f,0x64880113,0x615400d1}},	//   ушаю, sāža, qñis, _ئۆزئ, 
   {{0x3ce401a2,0x00000000,0x00000000,0x00000000}},	//   čov_, --, --, --, 
   {{0x39e001e0,0xd9d80154,0x59f8117e,0xa5c00210}},	//   йҙағ, _সাবম, веля_, _ziół, 
   {{0x6a1004a2,0xf41c0598,0xcdc51bf5,0x00000000}},	//   مبىر, zdä_, _варқ, --, 
   {{0xf41d64f5,0x7c9463bb,0x8e6400ee,0x00000000}},	//   ydä_, _брац, _терҗ, --, 
   {{0x3ad564f6,0xa9040691,0xf3fc0798,0x57b40139}},	//   _ميرز, اييل_, vião_, шбит, 
   {{0xd5b00491,0x6f04005f,0x8c3c010e,0xa3d800bc}},	//   يفة_, cībā, _aişw, िरन_, 
   {{0xfaa400c2,0xf41c0724,0xdcfc00ef,0x00000000}},	//   _сазо, wdä_, _uzrē, --, 
   {{0x5fb410f7,0x37e40474,0x6f000356,0xf1c81d00}},	//   ंखाल, _боег, ănci, _ﺑﯘﻟﺘ, 
   {{0x8c3c3630,0xf3fc0798,0x888005af,0x98bc0064}},	//   _pişi, rião_, _ویون, gyvą_, 
   {{0xf41c0598,0xf3fc06ed,0x386564f7,0x281000f2}},	//   rdä_, sião_, _imor_, _دونس, 
   {{0xf3fc0120,0x8c3c054e,0x00000000,0x00000000}},	//   pião_, _vişi, --, --, 
   {{0x625000b0,0x00000000,0x00000000,0x00000000}},	//   _täon, --, --, --, 
   {{0x60183bb3,0x00000000,0x00000000,0x00000000}},	//   лося_, --, --, --, 
   {{0x931404a9,0x8c3c06be,0x9f3401ec,0x638001ef}},	// [24af0] _ئوخش, _kişv, беті, _pánů, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x38640276,0xf2dc011f,0xee3c00a2,0xb7f800fe}},	//   _omor_, lsâ_, _duýp_, _আসনত_, 
   {{0xe2c80014,0x6f0400e2,0x00000000,0x00000000}},	//   _جویو_, tībā, --, --, 
   {{0x16141533,0xf1a804d3,0x3fd8011a,0x26f00210}},	//   तजार_, _تاکه_, _בקרב, _आमेर_, 
   {{0x62500037,0x6f040aea,0x9aa4007b,0xda00012d}},	//   _näol, rībā, ممنو, ल्लत_, 
   {{0x487964f8,0xdea54a43,0x6f04005f,0x64400108}},	//   ксия_, _ایلی, sībā, ömik, 
   {{0xaae44e02,0x8d8401b9,0x98543abf,0x8c3c008e}},	//   _مسئو, _буғд, йтыш, _rişw, 
   {{0x869803b7,0x65c002dd,0x00000000,0x00000000}},	//   ктот_, бұла, --, --, 
   {{0x38644c48,0x00000000,0x00000000,0x00000000}},	//   _emor_, --, --, --, 
   {{0x48141342,0x98bc0024,0xbd780023,0x00000000}},	//   _вмес, tyvą_, ባራቶም_, --, 
   {{0x95980032,0x00000000,0x00000000,0x00000000}},	//   ытыу_, --, --, --, 
   {{0x572411e6,0xb4600214,0x00000000,0x00000000}},	//   _هروق, تگوه, --, --, 
   {{0xf774010f,0x00000000,0x00000000,0x00000000}},	//   _דעני_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x625000a2,0x54e400e5,0x8ff8009d,0x00000000}},	//   _iäom, _اسوق, лхуу_, --, 
   {{0x44301311,0xea9c00b8,0x7db41d0f,0x4420417b}},	// [24b00] _iny_, _gaṇo_, асец, mdk_, 
   {{0x644403a0,0x44300263,0x8c3c0356,0x00000000}},	//   _hoii, _hny_, _mişu, --, 
   {{0x64440069,0x443000c0,0x00000000,0x00000000}},	//   _koii, _kny_, --, --, 
   {{0x44300076,0x7ac40220,0x4420417b,0x6d400108}},	//   _jny_, аске, ndk_, änaa, 
   {{0xfaa439f6,0xee3c004d,0x64440129,0xded00023}},	//   аадо, _tuýp_, _moii, እየካ_, 
   {{0x64440418,0xf41c0724,0x38640cf4,0x442164f9}},	//   _loii, llät_, _smor_, hdk_, 
   {{0x443164fa,0xdbd40321,0x64880113,0x62500037}},	//   _ony_, búði, yñip, _näom, 
   {{0x443005da,0x96f80588,0x7d0d64fb,0x644564fc}},	//   _nny_, геит_, _ipbs, _noii, 
   {{0x25a800ac,0x7c2001b9,0xfb7001d3,0xa82001d5}},	//   əklə_, mdor, _بھاگ, تکلن, 
   {{0x4430025f,0x644401ab,0x13ac02f5,0xf64472a0}},	//   _any_, _aoii, কুড়, рхин, 
   {{0x7c2164fd,0x6444003a,0xe9447ba2,0x998c01ef}},	//   odor, _boii, _پرلی, _indů_, 
   {{0x443164fe,0x64440393,0x9f400789,0xea9c0055}},	//   _cny_, _coii, ngió_, _paṇo_, 
   {{0x44300316,0xf7700228,0x00000000,0x00000000}},	//   _dny_, _باا_, --, --, 
   {{0x44301311,0x7c2164ff,0x442001ab,0xf2dc003a}},	//   _eny_, hdor, adk_, rsâ_, 
   {{0x443005da,0x644401ab,0x8c3c013d,0xf2dc003a}},	//   _fny_, _foii, _kişt, ssâ_, 
   {{0x64880309,0x7c203a65,0x64b00356,0xa6e000c7}},	//   qñip, jdor, _căiu, _ужәл, 
   {{0x7c216500,0x81d4015b,0x6dc400cf,0x8c3c9736}},	// [24b10] ddor, _হার_, لزال, _mişt, 
   {{0xada80058,0x7c200549,0xe3b000c6,0x76b0012d}},	//   نداق_, edor, _ترى_, _złyc, 
   {{0x7c20036b,0x6ca4a8db,0x443113d7,0x765801f4}},	//   fdor, ардж, _yny_, ihty, 
   {{0x8c3c0276,0x4c9400c9,0x7d0c02d0,0x62500254}},	//   _nişt, щиес, _dpbs, _näoj, 
   {{0xcb080451,0xe1f003e6,0x64b00356,0x6280020c}},	//   ايتن_, _عسی_, _hăit, émog, 
   {{0x7c212ff8,0x5b34027d,0x442001fa,0x2d840e78}},	//   ador, تعمر, zdk_, ünes_, 
   {{0x7c2001b9,0x8c3c013d,0xf09c004d,0x44200175}},	//   bdor, _bişt, _khà_, ydk_, 
   {{0x26dc019b,0x0c0401d9,0xa178011a,0x2178011a}},	//   tsuo_, _دورُ, יעוד_, יתור_, 
   {{0x8c3c0205,0xf8ac029c,0x857400d1,0x9be4187f}},	//   _dişt, رکم_, ﻼﺭﺩﺍ_, _фіск, 
   {{0x765802a4,0x44316501,0x6f0d638d,0x6b996502}},	//   ghty, _sny_, _mpcc, _izug, 
   {{0x44300263,0x26dc0120,0x9f416503,0x4420005c}},	//   _pny_, ssuo_, ngiò_, tdk_, 
   {{0xf09c431d,0x00000000,0x00000000,0x00000000}},	//   _nhà_, --, --, --, 
   {{0x47a4015b,0x4b78008f,0x799802d0,0x4420005c}},	//   _গ্রী, ראָו, _zztw, rdk_, 
   {{0xf41c0598,0x64440066,0x4420005c,0xf7400107}},	//   wlät_, _woii, sdk_, _хешо, 
   {{0x44316504,0x04445848,0xf09c01c3,0x7c20aaa9}},	//   _tny_, _гейн, _bhà_, ydor, 
   {{0x44316505,0x6b980521,0xf09d6506,0x8fd40032}},	//   _uny_, _ozug, _chà_, жәрә, 
   {{0x6d416507,0xf09c0192,0xc1d004a9,0x6b98770e}},	// [24b20] änan, _dhà_, _нөвә, _nzug, 
   {{0x7db56508,0x00000000,0x00000000,0x00000000}},	//   ссац, --, --, --, 
   {{0x9f40b2cc,0x7c216509,0xf09c00a3,0xa3ac146b}},	//   ggiò_, tdor, _fhà_, _कृत_, 
   {{0xf41c0724,0xa3d813f5,0xf09c01ab,0x67280240}},	//   llär_, िरि_, _ghà_, _orgj, 
   {{0x7c20069c,0x9f4009d7,0x7658023a,0x2d8512c5}},	//   rdor, rgió_, yhty, üner_, 
   {{0x4df5650a,0x81d40154,0xe6043226,0x00000000}},	//   _мяст, _হাঁ_, _عش_, --, 
   {{0x6729650b,0xa3d838b0,0x6b9802e3,0x1959650c}},	//   _argj, िरा_, _ezug, райы_, 
   {{0x7c2007d6,0x998c0153,0x8c3c06be,0x00000000}},	//   qdor, _sodų_, _dişs, --, 
   {{0xf41c0598,0x7bc00175,0x76a828e8,0x76580051}},	//   klär_, mcou, лтов_, thty, 
   {{0xb8fc11ba,0x00000000,0x00000000,0x00000000}},	//   _তম_, --, --, --, 
   {{0xf314767b,0x7ae1650d,0x67293ec5,0xb924027d}},	//   әнгә_, lsot, _ergj, _دفاي, 
   {{0x7bc1650e,0x76580731,0x7ae00072,0xf41c04ab}},	//   ncou, shty, osot, vläs_, 
   {{0x7ae1650f,0x78b96510,0x27f00f91,0xf41c00fd}},	//   nsot, _hutv, šané_, flär_, 
   {{0x7ae16511,0x7bc00007,0x78b8022e,0xe714011a}},	//   isot, hcou, _kutv, _לחדר_, 
   {{0xa1596512,0xd5b8005f,0xf09c004d,0x00000000}},	//   бару_, ndām_, _phà_, --, 
   {{0x7ae16513,0x7bc00369,0x78b95bd8,0xf41c1f65}},	//   ksot, jcou, _mutv, rläs_, 
   {{0x255403be,0x78b80978,0xe3b000ec,0x9f345074}},	// [24b30] vələ_, _lutv, _ٻري_, петі, 
   {{0x7bc0005a,0x62500037,0xdcfc03e0,0x78b8007c}},	//   ecou, _näoh, _agrı, _outv, 
   {{0xf09d6514,0x7ae00109,0xb030008e,0x78b88938}},	//   _thà_, esot, _емнә, _nutv, 
   {{0x6304006c,0xdda800a8,0x7bc00158,0xa06800d8}},	//   _بویل, стул_, gcou, _гаџа_, 
   {{0x9f40026c,0xa3ac01ad,0xdec807a5,0x00000000}},	//   sgiò_, केप_, _гусл_, --, 
   {{0x255400ac,0xb368001f,0x78b800c0,0x00000000}},	//   sələ_, _አንድን_, _butv, --, 
   {{0x7ae00194,0x52b42232,0xd1cc0023,0x00000000}},	//   asot, ंदुस, ባላታ_, --, 
   {{0x46e80d09,0xf41d6515,0x06e83f1d,0x0ba40124}},	//   адин_, zlär_, амик_, _дызҭ, 
   {{0x9f4019cf,0x80c0009e,0x6b996516,0xc6780023}},	//   ngið_, ষীপ্, _uzug, _ይብለካ_, 
   {{0x4504003d,0x5a44010b,0x00000000,0x00000000}},	//   _མྱུར_, _нэха, --, --, 
   {{0x6ab81132,0xa3aca5b3,0xae0800af,0x45841cb8}},	//   _huuf, केन_, स्यन_, югов, 
   {{0x6ab96517,0x81d40eac,0x4734010a,0x00000000}},	//   _kuuf, _হাই_, _мнес, --, 
   {{0xf41c0724,0x67280023,0x0eb40210,0x00000000}},	//   tlär_, _urgj, _अंगड, --, 
   {{0x97a405f5,0xa3d805f9,0x7bc00369,0x6ab8058a}},	//   _эрхл, िरह_, zcou, _muuf, 
   {{0xf41c0598,0x7bc018b0,0x6ab80083,0x69c09a14}},	//   rlär_, ycou, _luuf, icne, 
   {{0xa9240006,0xafd82d8b,0x7ae0011f,0x7bc00072}},	//   mažė, _kløy, ysot, xcou, 
   {{0x9f402833,0x6ab96518,0x68e000d2,0xf41c2b95}},	// [24b40] ggið_, _nuuf, hsnd, plär_, 
   {{0xee356519,0x7bc0a000,0xf41c6590,0x1ec801b9}},	//   ону_, wcou, lläp_, илғи_, 
   {{0x7bc00334,0xd9d8015b,0x1b0403d4,0x9f40030a}},	//   tcou, _সালম, লিছে_, rgiñ_, 
   {{0x7ae1651a,0x7bc1651b,0x6ab9651c,0x68e0003a}},	//   tsot, ucou, _buuf, dsnd, 
   {{0x7bc1651d,0xbea41f52,0x6ab819f5,0x78b9651e}},	//   rcou, _мамк, _cuuf, _sutv, 
   {{0x7bc0c2e4,0x7ae1651f,0x6ab80014,0xb8e8084c}},	//   scou, rsot, _duuf, афие_, 
   {{0x7ae16520,0xfce418c8,0x7bc00334,0x78b80455}},	//   ssot, _фобо, pcou, _qutv, 
   {{0xafd805ac,0x6ab96521,0x7bc00369,0xf8a80b24}},	//   _bløy, _fuuf, qcou, جدته_, 
   {{0x7ae0022f,0x6ab80009,0xf6c800fd,0x69c02860}},	//   qsot, _guuf, шыйк_, bcne, 
   {{0x78b8033d,0xb368001f,0x39340276,0x00000000}},	//   _tutv, _አንዱን_, _мэес, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xafd8168c,0x746801b9,0x59d80412,0xc0ac01ec}},	//   _fløy, рров_, डरवर, _ﺳﺎﻻﺗ, 
   {{0xafd803d4,0x78a16522,0x3b04022e,0x787c00dc}},	//   _gløy, _ihov, ntoq_, cīva, 
   {{0xe6902115,0x78a03d1a,0x3b040194,0xa6c402f2}},	//   _قلند, _hhov, itoq_, _بوول_, 
   {{0x78a00943,0xb0696523,0x306810fc,0xc1a401ec}},	//   _khov, араж_, ајан_, зытқ, 
   {{0x6d416524,0x6440d811,0x00000000,0x00000000}},	//   änam, ömit, --, --, 
   {{0x5f956525,0x62800030,0x69c00f85,0x00000000}},	// [24b50] дитт, émoc, ycne, --, 
   {{0x9f4008a7,0xd25016ac,0xbdb80014,0xf1a800f1}},	//   rgið_, _أند_, ٕنٕچ_, _پاخه_, 
   {{0x78a16526,0x6ab8ad04,0x00000000,0x00000000}},	//   _ohov, _suuf, --, --, 
   {{0x78a072ed,0x00000000,0x00000000,0x00000000}},	//   _nhov, --, --, --, 
   {{0x2cbc041a,0x6ab8208d,0x00000000,0x00000000}},	//   _čudu_, _quuf, --, --, 
   {{0xba201677,0x76b0033f,0x78a16527,0x08d40f7e}},	//   едшк, _słyn, _ahov, пция, 
   {{0xdd943cd9,0x76b00034,0xafd808fb,0x5e640131}},	//   _жары, _płyn, _sløy, _تۆلە, 
   {{0x78a16528,0x787c00da,0x6ab804c9,0xafd8143a}},	//   _chov, tīva, _tuuf, _pløy, 
   {{0xfe0002ab,0x78a00055,0x00000000,0x00000000}},	//   र्कस_, _dhov, --, --, 
   {{0x05640a8f,0x78a02cd9,0xc8f8015b,0xa3ac687b}},	//   звон, _ehov, _আনীত_, _कृष_, 
   {{0xfc4802fb,0x7a78008f,0xc7b801d3,0xa3d83507}},	//   žíš_, _פרעס, ndők_, िरल_, 
   {{0x78a0016d,0xae080037,0x29040327,0x8bd80037}},	//   _ghov, स्तन_, mtna_, _ढ़ोअ, 
   {{0x29054068,0x361804d3,0xafd805ac,0x38980375}},	//   ltna_, _گرنگ_, _uløy, _פיננ, 
   {{0xd7740228,0x78a00419,0x4adc095f,0x00000000}},	//   _تامع, _zhov, नीयव, --, 
   {{0xf41d6515,0x644033eb,0x78a000e4,0xe3b801ec}},	//   pläp_, ömis, _yhov, _мұн_, 
   {{0x04440276,0x62500254,0x78a0036e,0x00000000}},	//   _хеин, _näov, _xhov, --, 
   {{0x2480022e,0xfde96529,0x823441ff,0x7c240162}},	// [24b60] _ijim_, йдак_, _فردا, _ókri, 
   {{0x13e0045e,0x81d4009e,0xdcfc0171,0x00000000}},	//   _ভায়, _হাক_, _uzrī, --, 
   {{0xd2000116,0x2904025c,0xbd8807fc,0x00000000}},	//   _шүрк, jtna_, حنان_, --, 
   {{0x3b040af5,0xa0340137,0xe05803e6,0x2904031c}},	//   ttoq_, _تۉرت, _بیرت_, dtna_, 
   {{0x78a002c4,0x6d40022c,0x2904e35f,0x0ba400c7}},	//   _rhov, ønar, etna_, мышҭ, 
   {{0x78a1652a,0x3b0432ff,0xfce405f5,0x1994784b}},	//   _shov, rtoq_, _ного, маля, 
   {{0xa3ac2d8f,0x3b0526ba,0x692006ed,0x78a00051}},	//   केत_, stoq_, емја, _phov, 
   {{0x78a001d4,0x01e000cc,0xec740114,0x00000000}},	//   _qhov, বলিদ, _епс_, --, 
   {{0x3689652b,0x290400d5,0x78a00455,0xc62400eb}},	//   йсон_, atna_, _vhov, বানা_, 
   {{0xab74212d,0x78a0010a,0x29040010,0x1ae401ee}},	//   _عملا_, _whov, btna_, _ноғм, 
   {{0x78a00943,0xa3d800cd,0x00000000,0x00000000}},	//   _thov, िरं_, --, --, 
   {{0xf8a8026a,0x7e6c00b5,0x81d400fe,0x00000000}},	//   _увек_, _lmbp, _হাগ_, --, 
   {{0x75e00724,0x322802d3,0xc7b800e5,0x00000000}},	//   _пәнҗ, _ብምርኣ, zdők_, --, 
   {{0xb19024ce,0x2480020c,0x7c2c013f,0x6d400254}},	//   елгә, _ejim_, _ɔbra, änak, 
   {{0x06b000bc,0xee3c0432,0x65900024,0xa15800c0}},	//   řící_, _guýy_, _пашу, пару_, 
   {{0x787c00e2,0x5dd401ec,0xa3d80303,0x00000000}},	//   zīvn, _ﺘﺸﻭﻴ, िरः_, --, 
   {{0xead42f8b,0x76480607,0xb9440092,0x00000000}},	// [24b70] _সম্ম, _kofy, ማግሌዎ, --, 
   {{0xf41000e5,0x00000000,0x00000000,0x00000000}},	//   _آؤں_, --, --, --, 
   {{0x8c3c03ee,0x92e40c58,0xef1c0790,0x76480142}},	//   _ahşa, _নহয়_, _eyüp_, _mofy, 
   {{0xf3fc0589,0xd25800e2,0x13e00011,0x3d0c228d}},	//   ngã_, īņu_, _ভাড়, _ठहरे_, 
   {{0x764803ac,0x00000000,0x00000000,0x00000000}},	//   _oofy, --, --, --, 
   {{0x2904c9df,0x7f38011a,0x00000000,0x00000000}},	//   ttna_, _ועשו, --, --, 
   {{0x29040438,0x00000000,0x00000000,0x00000000}},	//   utna_, --, --, --, 
   {{0x6e244a5e,0x2905652c,0x06c82cb9,0x7ea00109}},	//   _hajb, rtna_, огий_, rôpe, 
   {{0x2905652d,0xf3fc0589,0x764800ec,0x6e2401e4}},	//   stna_, dgã_, _bofy, _kajb, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6e2407d6,0xa784034c,0xe3b8031c,0x76480142}},	//   _majb, _کشاو, _དཔྱང, _dofy, 
   {{0x6e24c9b1,0x00000000,0x00000000,0x00000000}},	//   _lajb, --, --, --, 
   {{0xdd1c02fb,0xba082440,0x00000000,0x00000000}},	//   mšťa, _ላት_, --, --, 
   {{0x76480cfd,0x76b80375,0x27fd652e,0x6250000d}},	//   _gofy, _ומספ, lgun_, _näot, 
   {{0x27fd652f,0x20040793,0x6ed8012c,0xc0e400d4}},	//   ogun_, _ömik_, मीसँ, ьовк, 
   {{0x27fd6530,0x24800b6f,0x81d400cc,0x648802d1}},	//   ngun_, _ujim_, _হাও_, yñiy, 
   {{0x6e240399,0x91dc0c58,0x27fc01c6,0x787c00e2}},	// [24b80] _bajb, _বাৰ্, igun_, zīvo, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6e24047e,0xaca000a2,0x04640055,0x00000000}},	//   _dajb, _noỳa, _śeṣv, --, 
   {{0xed5402bf,0x69b01f13,0x81d40f22,0x3d0c00ab}},	//   ьох_, ेखनी, _হাট_, _सहीं_, 
   {{0xab8057c6,0x00000000,0x00000000,0x00000000}},	//   кушк, --, --, --, 
   {{0x6a1004a9,0x0ba96531,0xbe14034c,0x27fd6532}},	//   نبىر, سانى_, _توسع, egun_, 
   {{0x2001638b,0x64880113,0x764801e3,0x6cc0686b}},	//   ogii_, sñiy, _rofy, _айса, 
   {{0x20016533,0x76496534,0xada16535,0x6da16536}},	//   ngii_, _sofy, _расл, _риса, 
   {{0xf0900302,0xf7702832,0x6e24016d,0x8d900023}},	//   כנה_, کاں_, _yajb, _ክሳተፍ_, 
   {{0x76480009,0x27fc0248,0x00000000,0x00000000}},	//   _qofy, agun_, --, --, 
   {{0x984c0034,0xa8f800ab,0xaca0010e,0xaa402a9d}},	//   jść_, _एमएफ_, _goỳa, _шефл, 
   {{0x62805efc,0x6d4001f4,0x00000000,0x00000000}},	//   émon, änai, --, --, 
   {{0x20000393,0x984c033f,0x6250000d,0x00000000}},	//   dgii_, eść_, _näos, --, 
   {{0xe56cc0e3,0xf3fc00d8,0x20000067,0x667000cf}},	//   اطی_, tiãs_, egii_, _لدىر, 
   {{0xa1940f64,0x66e00241,0xfbdc4f3c,0x4f5c0092}},	//   варч, _tìká, मराम, _ለመዘር, 
   {{0x200001d9,0x6e240cf4,0x80a00037,0x00000000}},	//   ggii_, _sajb, _कीदे, --, 
   {{0x6e256537,0x00000000,0x00000000,0x00000000}},	// [24b90] _pajb, --, --, --, 
   {{0x5ec803f4,0x9f045f2e,0x20000014,0x63a057d9}},	//   _লিখে, ئولو, agii_, ümne, 
   {{0x27fc0790,0x63b80118,0xf1a401a9,0x41bc013a}},	//   ygun_, čanů, _юрин, ्डरस, 
   {{0x590c0003,0x6ad000cc,0x3e780092,0x00000000}},	//   _གྱེས_, _সিবো, _በጨረታ_, --, 
   {{0x6e24038f,0x00000000,0x00000000,0x00000000}},	//   _tajb, --, --, --, 
   {{0x625000b0,0x2fc40085,0xf8ac01d9,0x00000000}},	//   _häor, ɛnga_, ۅکن_, --, 
   {{0x625002b1,0xbe6000db,0xefe00023,0x00000000}},	//   _käor, _حۇلي, _ምዕዶ_, --, 
   {{0xc7256538,0xf8ac6646,0xf89000d8,0x00000000}},	//   едий, مکن_, лајќ, --, 
   {{0x625002b1,0x97c40131,0x27fd6539,0x00000000}},	//   _mäor, ختىم, rgun_, --, 
   {{0xe8dc01f2,0x984c033f,0x53800023,0x00000000}},	//   _alụm_, yść_, _የሕዋት_, --, 
   {{0xa90405c6,0x200001d9,0xf5e401c0,0x00000000}},	//   _زبان, ygii_, эмэл_, --, 
   {{0x98140066,0x00000000,0x00000000,0x00000000}},	//   _لبها, --, --, --, 
   {{0x822c0023,0x00000000,0x00000000,0x00000000}},	//   _ብምርዳ, --, --, --, 
   {{0x200001d9,0xe3c401c0,0x8ecc00fe,0x59ac01f9}},	//   wgii_, эрүү, _লিংগ, टेवर, 
   {{0xf99004ac,0x2bac9201,0xd174013d,0x00000000}},	//   ָרן_, जेता, выты, --, 
   {{0x984c012d,0x00000000,0x00000000,0x00000000}},	//   rść_, --, --, --, 
   {{0x3f840261,0x2001653a,0xa3ac3885,0xf8b027af}},	// [24ba0] çou_, rgii_, केश_, רשן_, 
   {{0x63a40173,0x20000268,0x00000000,0x00000000}},	//   _izin, sgii_, --, --, 
   {{0xa3ac012c,0xc1bc39bc,0x39a4013a,0x00000000}},	//   केर_, ्डीग, _mísí_, --, 
   {{0xbb840952,0x3b840724,0xac940131,0x7c940137}},	//   ىلاي, нлег, ىنلا_, رشاا, 
   {{0x45240f22,0x629c0af9,0xe3c40154,0x81942829}},	//   যমিক_, olro, _্যাব, _መስቀሉ_, 
   {{0x63a4055a,0xaa4000d8,0xdb2001e1,0x00000000}},	//   _mzin, лечл, _ńtób, --, 
   {{0xada12027,0x6da1653b,0x63a40153,0x54e002dd}},	//   _барл, _бира, _lzin, _ﻋﻨﺎﺼ, 
   {{0x3b083967,0x4bc0010b,0x629d653c,0xfca800ec}},	//   _небо_, _көшг, hlro, _ڀاڱو_, 
   {{0x63a40296,0x39a40241,0x670401c6,0x6d4026bb}},	//   _nzin, _bísí_, нээг_, änav, 
   {{0x6280172e,0xb600038e,0xdeec02d3,0x26c80005}},	//   émol, _část, ህረና_, ícoa_, 
   {{0xeaac00e5,0xbb1c0205,0x00000000,0x00000000}},	//   _اٹل_, şçıy, --, --, 
   {{0x483415fa,0x63a5653d,0x629c01a4,0xf74800db}},	//   _لومړ, _bzin, elro, _ىلاي_, 
   {{0xa3ac0fe3,0xd5b800e2,0x675001e2,0xe73400d8}},	//   केल_, edāt_, _مخور, _пец_, 
   {{0x63a5653e,0xc76431f0,0x39a401e1,0x6fa4000d}},	//   _dzin, _جامى, _gísí_, _खरबं, 
   {{0x63a5653f,0x30a4c663,0x3a380108,0xdef800c7}},	//   _ezin, ерав, öppy_, ҵых_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf41c02f6,0xdef4004e,0x00000000,0x00000000}},	// [24bb0] meä_, лпты, --, --, 
   {{0x76596540,0xf41c005b,0xd5b8002b,0x00000000}},	//   nkty, leä_, bdāt_, --, 
   {{0x2fc801f7,0x63a41418,0x63a8012d,0x00000000}},	//   _tfcg_, _zzin, ędne, --, 
   {{0xafd8143a,0x271400cc,0x3d1400bc,0xf41c01f4}},	//   _snøf, তিতো_, नबजे_, neä_, 
   {{0x27ec00ca,0x62500254,0x765803cd,0x5ac801ec}},	//   _rdgn_, _käop, kkty, елім_, 
   {{0xd5b8005f,0xf3e403d4,0xf41c0108,0x00000000}},	//   ndās_, কলিৰ_, heä_, --, 
   {{0x9d19062b,0xf41c02f6,0x26cc0789,0xec68086a}},	//   _порт_, keä_, _stgo_, _ерак_, 
   {{0xdd941c3e,0xa3ac033d,0x76580034,0x6d416541}},	//   _сасы, केँ_, ekty, änau, 
   {{0xc624015b,0xafd801bf,0xd90c0050,0xdcfc0064}},	//   বাসা_, _enøg, _ہیو_, _byrė, 
   {{0x6b996542,0xd12002ab,0x6250000d,0x00000000}},	//   _iyug, मबाण_, _näop, --, 
   {{0xc958521e,0x63a4066d,0x6b9804ce,0x6280020c}},	//   _تلاش_, _szin, _hyug, émom, 
   {{0xaee000cd,0x7658e1eb,0x63a40064,0x12b80150}},	//   _guṇe, akty, _pzin, _ﺤﺎﻭﺭ, 
   {{0x6b9804ce,0xd7f80408,0x2c1000dc,0xa3ac072a}},	//   _jyug, _чух_, ण्यं_, कें_, 
   {{0x6b981419,0x7658a46e,0x52840184,0xdcfc0064}},	//   _myug, ckty, лҡын_, _gyrė, 
   {{0x409405c5,0x32400cef,0xded00023,0x00000000}},	//   врат, шерг, እየን_, --, 
   {{0x9ce800e5,0x00ac313e,0x00000000,0x00000000}},	//   ہوئے_, _ﺳﺎﺗﺘ, --, --, 
   {{0x6b996543,0x2d840b21,0x6fb0007b,0xd5b800b8}},	// [24bc0] _nyug, ûnen_, لمفا, bdās_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6b980055,0x6cc0d303,0x321001d3,0x008400f3}},	//   _ayug, айха, ényű_, _ално, 
   {{0xf53400c8,0x6b996544,0xafe00228,0x00000000}},	//   כטער_, _byug, _коюл, --, 
   {{0x6b980223,0xafd96545,0xb39402d3,0xf3e40183}},	//   _cyug, _snøg, _መንደቕ_, _কামৰ_, 
   {{0xeaad6546,0x6d54007c,0x00000000,0x00000000}},	//   يعو_, byxa, --, --, 
   {{0x6b98209c,0x787c0265,0xfbc4039b,0xa9040691}},	//   _eyug, līvi, _аббо, نيول_, 
   {{0xd7f000c6,0x26c000df,0x26140412,0x00000000}},	//   حكة_, ĉjon_, _बॉबी_, --, 
   {{0x19c40184,0xeb940131,0x79980034,0xf41c023a}},	//   _йәйг, _аит_, _wytw, veä_, 
   {{0xe9dc0051,0x00000000,0x00000000,0x00000000}},	//   _đúg_, --, --, --, 
   {{0x765804f3,0x4e3404ac,0x3a3d44f7,0xf41c005b}},	//   rkty, אָרן_, _intp_, teä_, 
   {{0x8978008f,0x3ea96547,0x8c3c0139,0x2bac0ce0}},	//   _אָנה, _lhbt_, _bişy, जेवा, 
   {{0xae002017,0xf41c2ecb,0xdcfc0024,0xb5f001ec}},	//   _लालन_, reä_, _tyrė, _күпі, 
   {{0x94200213,0xf41c005b,0xd53400f2,0x63a00037}},	//   _əsər_, seä_, _مفتخ, ümna, 
   {{0xf41c023a,0x20c401b9,0xf3e403d4,0x2c1000cd}},	//   peä_, истг, _কাঠৰ_, ण्डं_, 
   {{0xc3c029db,0x76b0033f,0xa088010b,0xf2c529be}},	//   _гөрл, _pływ, всуз_, _исон, 
   {{0x53341e80,0xc62400bd,0x3ea801ab,0x2614c725}},	// [24bd0] _септ, বারা_, _bhbt_, _बॉडी_, 
   {{0x6b9804ce,0x058000b7,0xafd808fb,0x9df813dc}},	//   _ryug, _ያዕቆብ_, _snød, кнут_, 
   {{0xc7b801d3,0xd25000f1,0x00000000,0x00000000}},	//   ndőr_, _ننک_, --, --, 
   {{0xd1340023,0xfcc00139,0x00000000,0x00000000}},	//   _ኣሉታው, сәрм, --, --, 
   {{0x4a748dc7,0xdea407d6,0x6cd0129d,0xca74004e}},	//   лыкт, _چیقی, اقچا, лукы, 
   {{0x590c0dd4,0x6b981446,0xb058013d,0x99640118}},	//   _གྱངས_, _vyug, _qiäf, _hůře_, 
   {{0x3a3c0066,0x6d4007b9,0xdd982d7f,0x996401ef}},	//   _dntp_, ånad, _ашт_, _kůře_, 
   {{0x7af402d5,0xafd80e38,0x3a3c0254,0xc7a402e8}},	//   šyta, _unød, _entp_, лийк, 
   {{0xc7955972,0xfbcc00b2,0x6b98014b,0x62800066}},	//   ыркы, _رڪن_, _uyug, émok, 
   {{0x85496548,0x5a340b3b,0xe9d0007b,0x00000000}},	//   езов_, _кнут, _ضغط_, --, 
   {{0x74e40323,0x1fb08cb2,0xc6240011,0x09b000eb}},	//   лдэг_, _झण्ड, বালা_, _ঘ্রা, 
   {{0x1958010b,0x00000000,0x00000000,0x00000000}},	//   _шахы_, --, --, --, 
   {{0xc8784ba9,0xded002d3,0x00000000,0x00000000}},	//   miş_, እየና_, --, --, 
   {{0x4128824c,0xc878e35c,0xa2c400fb,0x437400fb}},	//   ного_, liş_, ләүк, _ҡупт, 
   {{0x51540b38,0xd17800d4,0x95c800f3,0x00000000}},	//   атту, всті_, _руча_, --, 
   {{0xc87851b7,0x40956549,0x787c005f,0x3ea805b1}},	//   niş_, ургт, tīvi, _shbt_, 
   {{0x4421654a,0x42543fe6,0x9f400589,0xc1d0008e}},	// [24be0] mek_, _منظر, daiã_, _гөбә, 
   {{0xc87800ac,0x00000000,0x00000000,0x00000000}},	//   hiş_, --, --, --, 
   {{0xc8780365,0xafd8168c,0xed54020a,0x44205456}},	//   kiş_, _snøe, лоф_, oek_, 
   {{0x4421654b,0xfb88af85,0x00000000,0x00000000}},	//   nek_, нбек_, --, --, 
   {{0x6d40049f,0xc8787b4e,0x4420f019,0xafd80158}},	//   änar, diş_, iek_, _toør, 
   {{0x4421654c,0x90e42263,0xab74007b,0xe8900022}},	//   hek_, _حسین, دمها_, ҩашь, 
   {{0x4421654d,0x0d98dacb,0x00000000,0x00000000}},	//   kek_, _атты_, --, --, 
   {{0x4421654e,0x4c340262,0xb0580139,0x3ff4000d}},	//   jek_, _кэут, _giäd, ेलिआ_, 
   {{0x7c200086,0x3b84b576,0x98ac0356,0x8c3c03b9}},	//   meor, _слаг, _ardă_, _rişx, 
   {{0x7c21654f,0x09b8015b,0xd90c01d3,0xca040046}},	//   leor, ঁড়া, _ہیڈ_, _ەكەۋ, 
   {{0x44216550,0xc8784112,0x29142e0b,0x00000000}},	//   fek_, biş_, _مقلد_, --, 
   {{0x44216551,0xd90c01d3,0xc87803e0,0x54c4004e}},	//   gek_, _فیڈ_, ciş_, лбүб, 
   {{0x66d005d9,0x00000000,0x00000000,0x00000000}},	//   _هينئ, --, --, --, 
   {{0x7c216552,0xae00228d,0x44216553,0x00000000}},	//   heor, _लाइन_, aek_, --, 
   {{0x7c216554,0x70c4004b,0x00000000,0x00000000}},	//   keor, اهرې_, --, --, 
   {{0x4420079d,0x4fd56555,0x787c005f,0xafd808fb}},	//   cek_, ржат, būve, _snøb, 
   {{0x7c216556,0xf3fc0261,0xb0580139,0x00000000}},	// [24bf0] deor, lhão_, _riäd, --, 
   {{0xc8796557,0xed896558,0xfbb83ec5,0x9f040736}},	//   ziş_, нсек_, ेशनम, صومو, 
   {{0xf3fc0261,0xc87807b3,0x4adc09bb,0x686801e1}},	//   nhão_, yiş_, _नौजव, _lámọ, 
   {{0x7c216559,0x4c9411ed,0xdd9800f7,0xdcf801b9}},	//   geor, шиес, ушу_, ارلش_, 
   {{0x98bc0024,0xc878236c,0xae0001f9,0x00000000}},	//   lyvė_, viş_, _लाऊन_, --, 
   {{0x4421655a,0x00000000,0x00000000,0x00000000}},	//   zek_, --, --, --, 
   {{0x4421655b,0xb0580793,0x20240295,0xc87806b9}},	//   yek_, _tiäd, _ùriò_, tiş_, 
   {{0x5d840597,0x3b50053f,0x442001c6,0x9f400270}},	//   _الفل, скәр, xek_, laiá_, 
   {{0xc878e03b,0xaa05655c,0x2cbc009a,0xdb340640}},	//   riş_, _مظاه, _iiud_, _летњ, 
   {{0x4421655d,0x99641945,0x7b940244,0x00000000}},	//   wek_, ртәл, _ئافڕ, --, 
   {{0x4421655e,0x04443162,0x2cbc000d,0x00000000}},	//   tek_, аенн, _kiud_, --, 
   {{0x76b00034,0x01e003d4,0x84591f22,0x4421655f}},	//   _błys, _বাইদ, трот_, uek_, 
   {{0x44216560,0x76b0068f,0x9f400270,0xe8b0dc75}},	//   rek_, _płyt, kaiá_, ुदीच, 
   {{0x44216561,0x473405d9,0x00000000,0x00000000}},	//   sek_, _مرڪز, --, --, 
   {{0xc0e56562,0xf3fc0120,0xc0740640,0x9f40004e}},	//   робк, chão_, аћањ, waià_, 
   {{0x44202702,0x7c20005a,0xae000bae,0x74c8a71d}},	//   qek_, xeor, _लाउन_, _संतृ, 
  
   {{0xcd400092,0x00000000,0x00000000,0x00000000}},	// [24c00] _የሚከለ, --, --, --, 
   {{0x9f400ffb,0x2cbc0311,0x7c200083,0x00000000}},	//   raià_, _aiud_, weor, --, 
   {{0x6d400793,0x44f0031c,0x93a8085b,0x00000000}},	//   änap, nġ_, _لایف_, --, 
   {{0x8e840022,0xcdc401a9,0x00000000,0x00000000}},	//   агӡе, _ҳарқ, --, --, 
   {{0x7c216563,0x59f84ea5,0xec116564,0xcc080451}},	//   reor, геля_, توند, ازمن_, 
   {{0x7c2015a5,0x0eb8081d,0x6a809d7d,0x7af40006}},	//   seor, _бусы_, олча, šyto, 
   {{0x7c216565,0x6728044e,0x23ac0024,0x00000000}},	//   peor, _asgj, lųjį_, --, 
   {{0x2cbc07de,0x59ac11d7,0x00000000,0x00000000}},	//   _giud_, टेगर, --, --, 
   {{0x44f0038f,0x76a877c6,0xab241f99,0x23ac0153}},	//   eġ_, ктов_, _кота_, nųjį_, 
   {{0xfaa47f95,0x7aa401b9,0x247c0023,0x00000000}},	//   _тазо, _тизз, _ብየሱስ_, --, 
   {{0x76b00034,0xae082f0a,0x00000000,0x00000000}},	//   _słys, स्टन_, --, --, 
   {{0x2614033f,0x787c00e2,0x00000000,0x00000000}},	//   ब्बी_, tīvu, --, --, 
   {{0x94ec013b,0x322802d3,0x3864054e,0x91c41719}},	//   _yɛɛ_, _ብምልኣ, _ilor_, йәнл, 
   {{0x48fc038e,0x00000000,0x00000000,0x00000000}},	//   रूको_, --, --, --, 
   {{0x7790030f,0x00000000,0x00000000,0x00000000}},	//   _دیکا, --, --, --, 
   {{0x4e1856e9,0x7ea000d2,0x10681d37,0x25b8011a}},	//   न्नई_, lôph, اڭدى_, _בצומ, 
   {{0xa520081f,0x38640165,0x8d940131,0x931407d6}},	// [24c10] _འགོག_, _mlor_, ڭلاش, _اوخش, 
   {{0x3864004e,0x2cbc0e89,0x00000000,0x00000000}},	//   _llor_, _siud_, --, --, 
   {{0x38656566,0x9f4000d8,0x8c8800c7,0x8d78007b}},	//   _olor_, raiá_, гәаа_, دماء_, 
   {{0x62800232,0x94ec0134,0x9f400093,0xec1400fd}},	//   émov, _sɛɛ_, saiá_, редә_, 
   {{0x94ec016b,0xb7fc009e,0x00000000,0x00000000}},	//   _pɛɛ_, ্জাত_, --, --, 
   {{0xa3ac1d72,0x38656567,0x00000000,0x00000000}},	//   केट_, _alor_, --, --, 
   {{0x9a2400cf,0x00000000,0x00000000,0x00000000}},	//   زعون, --, --, --, 
   {{0x38656568,0x9d540014,0x94ec013f,0x38c802f2}},	//   _clor_, _بنِت, _wɛɛ_, داوی_, 
   {{0xb6f40b38,0xdd3800e2,0xdba40092,0x44f00327}},	//   مىيا_, māša, ላቸውም_, wġ_, 
   {{0x38643627,0x7d180036,0xf3e403d4,0x5a440153}},	//   _elor_, _ätsc, _কাষৰ_, _мэха, 
   {{0x58d40131,0x8834009d,0x00000000,0x00000000}},	//   _дохт, _гэлц, --, --, 
   {{0xdd380029,0x386401e4,0x00000000,0x00000000}},	//   nāša, _glor_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2fc40085,0x9f40067c,0xae0005dc,0xaaa4041c}},	//   ɛngi_, laiç_, _लागन_, गतिक, 
   {{0xa3ac07af,0x48fc0210,0x00000000,0x00000000}},	//   केज_, रंटो_, --, --, 
   {{0x38656569,0x00000000,0x00000000,0x00000000}},	//   _xlor_, --, --, --, 
   {{0x6445656a,0x4431656b,0xf4856432,0xaec134a1}},	// [24c20] _inii, _iay_, _داوی, збул, 
   {{0x4431656c,0xf41c1248,0xaac800bc,0x0204004e}},	//   _hay_, nnän_, ादनक, _узон, 
   {{0x4431656d,0x0eb9656e,0x0d9806a6,0x62800129}},	//   _kay_, руты_, атцы_, émou, 
   {{0x44300978,0x74c800cd,0xf41c01f4,0xe9dc0051}},	//   _jay_, _संसृ, hnän_, _đúa_, 
   {{0x44300d65,0x79a4e695,0xde4804d3,0xa3ac0490}},	//   _may_, әрле, _پیاو_, केच_, 
   {{0x4431656f,0x19596570,0x386402d2,0x00000000}},	//   _lay_, иалы_, _slor_, --, 
   {{0xed541142,0x3864c4ee,0x64440270,0x443003d1}},	//   _лор_, _plor_, _onii, _oay_, 
   {{0x7e7d6571,0x4430273c,0x6444b1ee,0x00000000}},	//   lipp, _nay_, _nnii, --, 
   {{0xa5200135,0x60dc0c6a,0x7b3c0356,0xf3e403d4}},	//   _འགུག_, hprm, _băuţ, _কালৰ_, 
   {{0x644422a9,0x44316572,0xb4e400e8,0x00000000}},	//   _anii, _aay_, _ngàñ, --, 
   {{0x44316573,0xb994007b,0x00000000,0x00000000}},	//   _bay_, _الضب, --, --, 
   {{0x7e7d6574,0xfaa40364,0x44316575,0x52dc0154}},	//   hipp, _таҷо, _cay_, _বিবৃ, 
   {{0x44316576,0x7e7d6577,0xd5440248,0x55c40131}},	//   _day_, kipp, _bẹ̀r, _мәнз, 
   {{0x64440083,0x44300072,0x7e7c045f,0xf41c0139}},	//   _enii, _eay_, jipp, cnän_, 
   {{0x44316578,0x7e7c4593,0x998c0024,0xa614011a}},	//   _fay_, dipp, _indų_, _הקוד_, 
   {{0x44316579,0x6445657a,0xd7ac0b8f,0x3dac0154}},	//   _gay_, _gnii, _चराच, কখাল, 
   {{0xb8f8025c,0x7e7c0140,0xd54401e1,0x6dc40116}},	// [24c30] _འཕ_, fipp, _fẹ̀r, مزال, 
   {{0x4431657b,0x7e7c0eda,0x6dc4192d,0xf1c400bc}},	//   _zay_, gipp, ссаж, část_, 
   {{0x4431657c,0x00000000,0x00000000,0x00000000}},	//   _yay_, --, --, --, 
   {{0x4431657d,0xef1c0254,0x32cc03e3,0x0b580139}},	//   _xay_, _tpü_, _küy_, ирлы_, 
   {{0xdea45457,0xd54401e1,0x2bc8012d,0xf41c01f4}},	//   _کیلی, _yẹ̀r, िशबा, ynän_, 
   {{0xdcf42573,0xdd3800e2,0x88c43260,0x00000000}},	//   _çağl, sāša, يتعل, --, 
   {{0xa86001e0,0xf8ac01d5,0xdd58010a,0x5ce4014b}},	//   зейҙ, چکن_, _ларч_, _нюта, 
   {{0xe7e40eac,0xf8acaf1c,0x998c0064,0x00000000}},	//   ফল্য, نکن_, _andų_, --, 
   {{0x44306c81,0x213802fb,0x2b48013d,0xdb54190b}},	//   _ray_, zvrh_, _çcc_, _евты, 
   {{0x4430cc9d,0x458400d8,0x00000000,0x00000000}},	//   _say_, жгов, --, --, 
   {{0x44300302,0x44880fc0,0xf41c01f4,0xb8fc00cc}},	//   _pay_, ибон_, rnän_, _থয়_, 
   {{0x2905657e,0x4431657f,0x87b96580,0xafd80158}},	//   muna_, _qay_, _култ_, _snøn, 
   {{0x44316581,0x29056582,0x00000000,0x00000000}},	//   _vay_, luna_, --, --, 
   {{0x4430025f,0x7e7d6583,0x5274004e,0x00000000}},	//   _way_, xipp, пусу, --, 
   {{0x29056584,0x44316585,0x0594034c,0x7e7c1f33}},	//   nuna_, _tay_, _باشگ, vipp, 
   {{0x64456586,0x7e7cb915,0x00000000,0x00000000}},	//   _unii, wipp, --, --, 
   {{0x29056587,0x7e7d6588,0xfe4027a1,0x6d4010d1}},	// [24c40] huna_, tipp, وکسی, ånan, 
   {{0x29056589,0x63a5658a,0xbb48328a,0x7e7c0194}},	//   kuna_, _iyin, یلان_, uipp, 
   {{0x2905658b,0xb5f8008f,0x629d658c,0xafd803cd}},	//   juna_, שלעכ, moro, _knøl, 
   {{0x2905658d,0x7e7d658e,0x302400ee,0x7f940022}},	//   duna_, sipp, _доюп_, _ҳаҭх, 
   {{0x7e7d658f,0x2bc40b8d,0x29056590,0x6a6c005c}},	//   pipp, әләп_, euna_, _møff, 
   {{0x29056591,0x629d6592,0x63a4015c,0xeaac1973}},	//   funa_, noro, _myin, نٹن_, 
   {{0x29056593,0x20e96594,0x629c0295,0x6da019c3}},	//   guna_, nşi_, ioro, _жира, 
   {{0x629d6595,0x63a56596,0x499001b9,0x28a012b9}},	//   horo, _oyin, رینر, мшыг, 
   {{0x63a56597,0x2904084c,0xf7700ef8,0x36896598}},	//   _nyin, auna_, باغ_, исон_, 
   {{0x29056599,0x629d659a,0x76a80261,0xff6c001f}},	//   buna_, joro, јтив_, _በጉዳዩ_, 
   {{0x63a5659b,0x6a6c1600,0xe97000ec,0x3544003b}},	//   _ayin, _bøff, _ٺهند, іхов, 
   {{0x63a44c99,0xd8300050,0x8b6401ed,0x03900cad}},	//   _byin, _سٍت_, _باہم, _ìjọb, 
   {{0x629d659c,0x63a40230,0x77903737,0xe3b000e3}},	//   foro, _cyin, _زیدا, َرُ_, 
   {{0x629c253c,0x8c3c0139,0x63a40f85,0xc7640132}},	//   goro, _ikşe, _dyin, _عانى, 
   {{0xc7ac00dd,0xd1a405d9,0x00000000,0x00000000}},	//   _لڑی_, سٽري, --, --, 
   {{0x62807f70,0x32cc0790,0x00000000,0x00000000}},	//   émor, _tüy_, --, --, 
   {{0x629d659d,0x2905659e,0x63a4013b,0x998000ee}},	// [24c50] boro, zuna_, _gyin, şiň_, 
   {{0x629d659f,0x24f000fd,0xe3b000ae,0x00000000}},	//   coro, _эчәр, _جرى_, --, 
   {{0x290565a0,0x20e80311,0xf2dc003a,0x22b84706}},	//   xuna_, cşi_, lpâ_, _بديع_, 
   {{0x290565a1,0xc198011a,0x20c400d4,0x00000000}},	//   vuna_, _לשתי, _осяг, --, 
   {{0x290565a2,0xae000131,0xdef91196,0x7fd40115}},	//   wuna_, _يۈرى, _мыр_, _מורס_, 
   {{0x290565a3,0x5ba80006,0xb0580166,0x9f240116}},	//   tuna_, цкім_, _xiän, _تۈكۈ, 
   {{0x8c3c03e0,0x00000000,0x00000000,0x00000000}},	//   _akşe, --, --, --, 
   {{0x629d65a4,0xf2dc025a,0xd99800d1,0x992800d4}},	//   zoro, kpâ_, ڭخۇا_, ююча_, 
   {{0x290565a5,0x629d65a6,0xd32c01e4,0x6a6c383d}},	//   suna_, yoro, _uzaʈ, _røff, 
   {{0x290565a7,0x63a401b2,0x629c036b,0xf8ac03e6}},	//   puna_, _ryin, xoro, نکۆ_, 
   {{0x290565a8,0x63a565a9,0x00000000,0x00000000}},	//   quna_, _syin, --, --, 
   {{0xdb00529d,0x161c0acd,0x00000000,0x00000000}},	//   _symé, ब्बर_, --, --, 
   {{0xaac800dc,0xd8740137,0xe5e001d5,0x66c80139}},	//   ादिक, _تالب, _قزغی, _туег_, 
   {{0x63a41459,0x00000000,0x00000000,0x00000000}},	//   _vyin, --, --, --, 
   {{0x629d65aa,0x6a6c168c,0x9f400407,0x67380306}},	//   roro, _tøff, mbié_, lvuj, 
   {{0x629d65ab,0x20e92b94,0x63a565ac,0x7af40153}},	//   soro, rşi_, _tyin, šyti, 
   {{0x63a40028,0x00000000,0x00000000,0x00000000}},	// [24c60] _uyin, --, --, --, 
   {{0x629d65ad,0x6fb165ae,0xef800395,0x00000000}},	//   qoro, رملا, хлуп, --, 
   {{0x26100037,0x271400fe,0x725800d9,0x00000000}},	//   _दानी_, তিটো_, _הכיפ, --, 
   {{0x6ad004c5,0x3fc403e6,0x26dc063f,0x00000000}},	//   _সিজো, _رگری_, kpuo_, --, 
   {{0x0ef965af,0xfaa4816c,0xda34defb,0xfb803b93}},	//   _мэры_, падо, делы, رگری, 
   {{0x2d44001f,0x00000000,0x00000000,0x00000000}},	//   _የዩኒቨ, --, --, --, 
   {{0xfce40117,0x9cd4009f,0x00000000,0x00000000}},	//   _хобо, _آمرڪ, --, --, 
   {{0xfce401f0,0xe990075e,0x00000000,0x00000000}},	//   _моҳо, رۇنگ, --, --, 
   {{0xec1165b0,0xf8ac0014,0x00000000,0x00000000}},	//   _سولد, نکچ_, --, --, 
   {{0x94d41318,0x261400bc,0xbbb800bc,0x00000000}},	//   мооц, ब्ली_, ेशीक, --, 
   {{0xf770040b,0xafd8143a,0x757c0240,0x00000000}},	//   باں_, _snøm, _ካንሸሎ_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x78a165b1,0xa344010b,0xb6841411,0xdd100118}},	//   _ikov, нэрл, _ىشتى, _výře, 
   {{0xa2c40640,0xe4d001d5,0xfbd00154,0x00000000}},	//   ељск, بتیب, ারিত, --, 
   {{0x78a00083,0xade803ce,0xa294003b,0x00000000}},	//   _kkov, टरसन_, харі, --, 
   {{0x64a406ed,0xe9dc0051,0x00000000,0x00000000}},	//   _паја, _đúm_, --, --, 
   {{0x6a6c01bf,0x00000000,0x00000000,0x00000000}},	// [24c70] _høfe, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe3b05c81,0x4c3405f5,0x00000000,0x00000000}},	//   _لری_, дэлт, --, --, 
   {{0x78a165b2,0x673800e4,0x00000000,0x00000000}},	//   _nkov, yvuj, --, --, 
   {{0x22b000a2,0xfcc00bd6,0xccf800cd,0x00000000}},	//   _ańky_, тәрм, _āśu_, --, 
   {{0x78a00093,0xbb411317,0x161c01ad,0xeab00116}},	//   _akov, тешк, _बॉलर_, رعش_, 
   {{0xdd94a6e6,0x2610012c,0x63a8033f,0x092800d4}},	//   _зары, _दाबी_, ędni, іжий_, 
   {{0x6738110c,0x1c1425c9,0xf89006ed,0x00000000}},	//   tvuj, _डायल_, кајќ, --, 
   {{0xa9c40150,0x00000000,0x00000000,0x00000000}},	//   _есек, --, --, --, 
   {{0x673965b3,0x2378001f,0x78a025ad,0xfd6401e1}},	//   rvuj, _አሕዛብ_, _ekov, _nipọ, 
   {{0x78a00270,0x66e001e1,0xf504009d,0xa8c8009a}},	//   _fkov, _bíkò, мнэл_, _طباق_, 
   {{0x26c80048,0x98c00356,0x00000000,0x00000000}},	//   ícos_, ăpăd_, --, --, 
   {{0xafd80fac,0xfda85d4f,0xed74069d,0x386001d3}},	//   _enøk, _कर्फ, በርበር_, ökre_, 
   {{0xdebc0201,0x52dc045e,0x27ec3774,0x68000248}},	//   ታችን_, _বিশৃ, _hegn_, _fìjà, 
   {{0x71a0016c,0xa0844494,0x26cd33a1,0xc0580063}},	//   варз, еңне, _hugo_, орац_, 
   {{0x26c565b4,0x80a800d4,0x00000000,0x00000000}},	//   _hino_, івав_, --, --, 
   {{0x26c565b5,0x24800295,0x823401d5,0x27ec02d2}},	// [24c80] _kino_, _imim_, _قردا, _megn_, 
   {{0x26cd65b6,0x26c48f5a,0x27ec05d5,0x00000000}},	//   _mugo_, _jino_, _legn_, --, 
   {{0x26cc0f71,0x26c565b7,0x6cd0849a,0x00000000}},	//   _lugo_, _mino_, نقلا, --, 
   {{0x26c565b8,0x3b840cef,0xbb8412fc,0xe9fc004d}},	//   _lino_, млег, ولاي, _trẻo_, 
   {{0x3b9c001f,0x78a0022e,0x2d840129,0x261001f9}},	//   ቃሚዎች_, _rkov, ûner_, _दाढी_, 
   {{0x26c565b9,0x78a0019b,0xf96867ba,0xaa40008e}},	//   _nino_, _skov, жрий_, кечл, 
   {{0x26cd65ba,0x248001e4,0x5bc801ee,0x00000000}},	//   _augo_, _omim_, _еҫен_, --, 
   {{0x26c565bb,0x26cc0b45,0x00000000,0x00000000}},	//   _aino_, _bugo_, --, --, 
   {{0x26c565bc,0x27ed65bd,0xafd831a2,0xb604064d}},	//   _bino_, _degn_, _snøk, мянк, 
   {{0x7ae165be,0x26c40066,0x24800170,0x628000db}},	//   mpot, _cino_, _amim_, èmol, 
   {{0x7ae165bf,0xb058014a,0x27ed3f56,0x3b04036b}},	//   lpot, _siäm, _fegn_, lroq_, 
   {{0x27ec008c,0xf74802dd,0x7ae11cff,0x7af40024}},	//   _gegn_, _ولاي_, opot, šytu, 
   {{0x26c565c0,0x7ae165c1,0x3b04036b,0xb0580166}},	//   _fino_, npot, nroq_, _qiäm, 
   {{0x26c565c2,0x7ae000c7,0xed740092,0x68000241}},	//   _gino_, ipot, በርብር_, _tìjà, 
   {{0x26cc01e4,0x3b04022e,0x66e00ca8,0xa184013d}},	//   _zugo_, hroq_, _tíkò, вытл, 
   {{0x26c565c3,0x2480020b,0x7ae165c4,0x7e6c0240}},	//   _zino_, _gmim_, kpot, _albp, 
   {{0x26c40161,0x26cc0005,0xdddc00d7,0x00000000}},	// [24c90] _yino_, _xugo_, _korň, --, 
   {{0x26c400db,0x3b0401a9,0x7c24010e,0x612c0023}},	//   _xino_, droq_, _ıkra, _ብግዝኣ, 
   {{0x8c3c0365,0xdb000005,0x7ae165c5,0x9d180107}},	//   _akşa, _gzmú, epot, дохт_, 
   {{0x040402a6,0x2fc80048,0x4fc001ec,0x7e6c002f}},	//   ষ্ঠী_, _ugcg_, _مەزە, _elbp, 
   {{0x7ae1460c,0xab280214,0xee840024,0x53a40210}},	//   gpot, تسال_, _жыво, _गुमश, 
   {{0x26cc0516,0x27ed65c6,0xafd8143a,0x00000000}},	//   _rugo_, _segn_, _snøh, --, 
   {{0x26cd65c7,0x26c565c8,0x27ec07de,0xf3fc0798}},	//   _sugo_, _rino_, _pegn_, nhãs_, 
   {{0x26c565c9,0x26ccb568,0x76480142,0x3b500bd6}},	//   _sino_, _pugo_, _anfy, ткәр, 
   {{0x27ed65ca,0x26102871,0xb90400c5,0x00000000}},	//   _vegn_, _दादी_, _बढ़_, --, 
   {{0x5b344191,0x2f2000e2,0x00000000,0x00000000}},	//   _جعفر, mīgā_, --, --, 
   {{0x27ed65cb,0x2f2000e2,0xf3e400fe,0xf41c0139}},	//   _tegn_, līgā_, _কাজৰ_, ffä_, 
   {{0x764803cb,0x26c565cc,0x24800200,0xaaa401f9}},	//   _enfy, _wino_, _qmim_, गतकक, 
   {{0x26c565cd,0x2f20005f,0x93d400b8,0x68e0007f}},	//   _tino_, nīgā_, _aṃsa, lpnd, 
   {{0xd774f082,0x26c40393,0x00000000,0x00000000}},	//   _جامع, _uino_, --, --, 
   {{0x6ac81a4e,0x3b0401b9,0x7ae00427,0xd310030d}},	//   ादुर, zroq_, zpot, _хlот, 
   {{0x7ae149b8,0x63842c1d,0xdb0000e4,0x3b0401b9}},	//   ypot, _аҳма, _symí, yroq_, 
   {{0x0d400020,0x2d842b76,0x7648015d,0x3e8401e1}},	// [24ca0] _የሚፈል, únen_, _ynfy, _nítè_, 
   {{0xee3565ce,0xa3e400e1,0x337402e4,0xef140006}},	//   нну_, _प्त_, _נעים_, эму_, 
   {{0xfc28010b,0x2904eef1,0x6b640171,0xdb00013a}},	//   зжек_, jrna_, _līgā, _vymí, 
   {{0xe8dc00b4,0xafe00116,0x6ac82c82,0x3b0401d5}},	//   ahịa_, _йоюл, ादूर, troq_, 
   {{0x7ae02d2b,0x80d402ab,0xfca80014,0x9ec401af}},	//   upot, _मंडे, _ہارو_, _аҡае, 
   {{0x3b0401b9,0x00000000,0x00000000,0x00000000}},	//   rroq_, --, --, --, 
   {{0x7ae165cf,0xd9102807,0x7c940f5c,0x35a40023}},	//   spot, شیش_, _зрац, ገድታት_, 
   {{0x7ae165d0,0x3b04036b,0x6da00556,0xada01742}},	//   ppot, proq_, _сиса, _сасл, 
   {{0x29040fa3,0x3b0401b9,0x2f2000e2,0x57b402e8}},	//   arna_, qroq_, cīgā_, ъбит, 
   {{0xa77165d1,0xdca400d1,0x00000000,0x00000000}},	//   ульч, _чағи, --, --, 
   {{0xb5a405f5,0x1ad80154,0x00000000,0x00000000}},	//   эрий, _সিয়া, --, --, 
   {{0xc6200154,0x9f400055,0x00000000,0x00000000}},	//   _ভোদা_, daiþ_, --, --, 
   {{0xe22002d3,0xa19401b9,0xf41c007c,0x787c0153}},	//   _ስምምዓ, ҳарч, rfä_, jūvi, 
   {{0x659000e5,0x00000000,0x00000000,0x00000000}},	//   ئجیر, --, --, --, 
   {{0xd5e806d6,0x64400120,0xa194ec77,0xc64400db}},	//   nnḓ, ômic, гарч, _جئنى, 
   {{0x8c3c0166,0x00000000,0x00000000,0x00000000}},	//   _akşn, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [24cb0] --, --, --, --, 
   {{0x2904032e,0x7c740092,0xefd40023,0x9f042dd0}},	//   yrna_, _ጨምረው_, ርካዮ_, اولو, 
   {{0xd71c0183,0x00000000,0x00000000,0x00000000}},	//   তিয়া_, --, --, --, 
   {{0xf21400e1,0x1c38084c,0x787c0153,0x2f2000de}},	//   _ताड़_, еяшь_, būvi, tīgā_, 
   {{0x201c03be,0xdd9001ed,0xca7400fd,0xab98007b}},	//   əvi_, لوے_, кукы, أخضر_, 
   {{0x2f20005f,0x29040219,0x00000000,0x00000000}},	//   rīgā_, trna_, --, --, 
   {{0x29053a1e,0x1b800023,0x00000000,0x00000000}},	//   urna_, ሓላለኸ_, --, --, 
   {{0x07a565d2,0xc724702f,0x3e840ca8,0xc7a48a2e}},	//   кайн, вдий, _títè_, кийк, 
   {{0x2ca4054e,0x9b94009b,0x00000000,0x00000000}},	//   îndu_, _битц, --, --, 
   {{0x7bd0005f,0x68e000e8,0x29040010,0x00000000}},	//   ājuš, ppnd, prna_, --, 
   {{0x6aa0026c,0x4814084c,0xa9040fb4,0x00000000}},	//   monf, _амес, _سبان, --, 
   {{0xafd803b2,0x261000bc,0x00000000,0x00000000}},	//   _knøu, _दावी_, --, --, 
   {{0x94ec013f,0x867401af,0xe530013d,0x00000000}},	//   _sɛɔ_, _илдє, läüş, --, 
   {{0x41287724,0x161811b1,0x05747092,0xb058008e}},	//   мого_, _दायर_, _لابد, _kiäw, 
   {{0x7fd4063b,0x66807e89,0xd1742eca,0x6fa4000d}},	//   візі, _لیکل, гыты, _कुबं, 
   {{0x6aa0d58b,0x00000000,0x00000000,0x00000000}},	//   honf, --, --, --, 
   {{0x73302002,0x403401e0,0xd3980139,0x3ea4009d}},	// [24cc0] _نىيا, неңс, _зәрә_, виаг, 
   {{0x01640124,0x6aa0031c,0xf41c01f4,0xe8dc010e}},	//   _акоо, jonf, niän_, niỳa_, 
   {{0xc0e401e0,0xed5407a5,0x00000000,0x00000000}},	//   _шонк, коф_, --, --, 
   {{0xafd81347,0xfb88c081,0x6da001c6,0xfb840139}},	//   _snøv, мбек_, шиха, кылн, 
   {{0x427c044e,0x6aa001e3,0x6a6c3778,0xf41c01f4}},	//   _ኣብነት_, fonf, _søfa, kiän_, 
   {{0x9f4008e5,0xf41c007c,0x8ad40006,0x00000000}},	//   mbià_, lnät_, уюцц, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf41ce9b1,0xe9d42123,0x00000000,0x00000000}},	//   nnät_, нкә_, --, --, 
   {{0x44200036,0xa6f00124,0x6aa0007c,0xdb200248}},	//   dfk_, азыш, bonf, _ìtàg, 
   {{0xeb9565d3,0xd5b001ed,0x6b78011a,0xaa4001ec}},	//   _риу_, یفک_, _חרמנ, _кеул, 
   {{0xafd965d4,0x7c2001e4,0xca740006,0x26100fe3}},	//   _knøt, ofor, _суты, _दारी_, 
   {{0x7c202d61,0xf54001c0,0xe7dc00bc,0x00000000}},	//   nfor, гдүү, _नभएप, --, 
   {{0x7c20030a,0x67500214,0xe3b801f4,0x00000000}},	//   ifor, _نخور, ключ_, --, 
   {{0x7c2165d5,0xc0cc0240,0x877001af,0x00000000}},	//   hfor, _ኤህም_, _ығыш, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2d840120,0x2fcc0feb,0x65540375,0x6aa08503}},	//   únem_, øgg_, _יבוא_, zonf, 
   {{0xdef845b3,0xdfd401e0,0x6aa00100,0x00000000}},	// [24cd0] вых_, роуы, yonf, --, 
   {{0xed883f6e,0x6aa00077,0xf1a8004b,0x6ce40212}},	//   мсек_, xonf, _ياده_, віде, 
   {{0x7c2165d6,0xafd805ac,0x00000000,0x00000000}},	//   ffor, _snøu, --, --, 
   {{0x9f40026c,0x6ac8412f,0xe0d02d20,0x6aa00784}},	//   bbià_, ाद्र, _گزی_, wonf, 
   {{0x261000af,0x6aa000e5,0xaafc0432,0xf41c01e3}},	//   _दाली_, tonf, _özüñ_, lnäs_, 
   {{0xe0d00133,0x6aa00175,0x1ca80014,0xe94001d5}},	//   _دزی_, uonf, _یێلی_, لرعی, 
   {{0x7c2165d7,0xdb0002fb,0x6aa165d8,0xf41c0621}},	//   bfor, _vymá, ronf, nnäs_, 
   {{0x6d447e9e,0xdd940ed0,0x6aa0005c,0x9f400ffb}},	//   _irja, _тасы, sonf, maiò_, 
   {{0x9f40011c,0xab8484da,0x66040210,0x00000000}},	//   laiò_, _рувк, ójko, --, 
   {{0xdb0001bf,0xf41c007c,0x00000000,0x00000000}},	//   _bymæ, knäs_, --, --, 
   {{0x199400a7,0x9f400561,0x63540213,0xe59c0150}},	//   _кафя, ibiá_, _mənş, _ﺍﻜﺒﺭ_, 
   {{0x5884004e,0xf41c0108,0x00000000,0x00000000}},	//   _кыча, siän_, --, --, 
   {{0xd7f965d9,0x40940fc0,0xdb900023,0x00000000}},	//   _рух_, ҳрат, ማሚዖም_, --, 
   {{0xa3e42d8f,0x45442e2e,0xd29400d6,0xe2842c1d}},	//   _प्र_, _منتق, арсь, рғон, 
   {{0x7c2165da,0x409565db,0x044565dc,0x66000009}},	//   yfor, грат, _бейн, _idnk, 
   {{0x60c002dd,0x00000000,0x00000000,0x00000000}},	//   _ﺣﺎﺗﺸ, --, --, --, 
   {{0x7c203c12,0x3e7405ac,0x6d4165dd,0x44f00010}},	// [24ce0] vfor, _læte_, ænan, lš_, 
   {{0xbea965de,0x7c2165df,0xafd803cd,0x7d1c0fac}},	//   رهان_, wfor, _snøt, ttps, 
   {{0xf41c0724,0x38b8002e,0xf264009d,0x00000000}},	//   mnär_, lëre_, _сиэл_, --, 
   {{0x02880020,0x672800b5,0x00000000,0x00000000}},	//   _አቅጣጫ_, _opgj, --, --, 
   {{0x7c2165e0,0xf41d65e1,0x6d444167,0x7d1c03ac}},	//   rfor, onär_, _erja, stps, 
   {{0xf41c0598,0xdddc02b1,0xc7b801ed,0xed4c00cf}},	//   nnär_, _korō, tfőn_, تپۅ_, 
   {{0x7c200b34,0xe9dc004d,0x6d4400ef,0x00000000}},	//   pfor, _đút_, _grja, --, 
   {{0x660002e8,0x9f4003a2,0x6a6c1477,0xc6200154}},	//   _adnk, laiñ_, _høfl, _ভোলা_, 
   {{0xeb94bcf5,0x44f00953,0xafd806ea,0xab240352}},	//   _бит_, eš_, _knør, _йота_, 
   {{0xa7b40184,0xf41c01e6,0x6600005a,0xe7b400fd}},	//   ылыу_, ynäs_, _cdnk, ыгыш_, 
   {{0x3a3d65e2,0x38b80ea0,0x47a400fe,0xf41c007c}},	//   _iatp_, eëre_, খেলী, xnäs_, 
   {{0xf41c007c,0x00000000,0x00000000,0x00000000}},	//   vnäs_, --, --, --, 
   {{0xf2040153,0x44f000d0,0x38b800e8,0xe59c0150}},	//   ляво, aš_, gëre_, _ﺍﻜﺜﺭ_, 
   {{0x44f00010,0x228401d5,0x00000000,0x00000000}},	//   bš_, бусг, --, --, 
   {{0x3a3c02c4,0xdb4404d3,0xdef80032,0x6e6402dd}},	//   _matp_, _کێ_, ҫыу_, қтаж, 
   {{0xb05800fd,0x16840133,0xf41c01e3,0xa5040114}},	//   _niät, _حاڵێ, rnäs_, _сећа_, 
   {{0x20984734,0xafd8168c,0xda04dc75,0x53340354}},	// [24cf0] укты_, _snøs, रणात_, _тепт, 
   {{0xdddc007f,0x6d440427,0x11d8007b,0x00000000}},	//   _forō, _prja, _جودة_, --, 
   {{0x6a6c005c,0x00000000,0x00000000,0x00000000}},	//   _søfo, --, --, --, 
   {{0x7a1c0100,0x6d440427,0xdda800a8,0x4ea404a9}},	//   _lņtč, _vrja, утул_, урға, 
   {{0xb0580e78,0x6a6c00d4,0x628000b0,0xef6402e8}},	//   _diät, _føfl, ūmoe, _съно, 
   {{0x6d44020b,0xee901680,0x257801e1,0x7dd001d3}},	//   _trja, _اگرک, _jálé_, rűsí, 
   {{0x3a3c0077,0xc9547626,0xdb000139,0xcda824cf}},	//   _datp_, ртлы, _aymä, _شهره_, 
   {{0x3e740158,0x25780248,0x80b800dc,0x612c0108}},	//   _væte_, _lálé_, ्षये, _hölö, 
   {{0x53a403ce,0x00000000,0x00000000,0x00000000}},	//   _गुलश, --, --, --, 
   {{0x0684fb0f,0x27b000d1,0xb0580139,0xa3e81c5d}},	//   ргон, _қәйс, _kiäs, मुन_, 
   {{0x6fa41524,0x7d180267,0x228c0ca8,0x38b8002e}},	//   _कुसं, _ätst, _lókè_, wëre_, 
   {{0x612c29ef,0x44f13760,0x996565e3,0xaca00432}},	//   _lölö, rš_, _утул, miỳe, 
   {{0x25780248,0xf41c0267,0xaca000a2,0x00000000}},	//   _bálé_, tnär_, liỳe, --, 
   {{0x84140022,0x00000000,0x00000000,0x00000000}},	//   ымҭх, --, --, --, 
   {{0x25780241,0x34a001d9,0xaca00432,0x00000000}},	//   _dálé_, _ژۅپٲ, niỳe, --, 
   {{0xafd828b3,0x3fe565e4,0xf8c401a8,0x00000000}},	//   _snør, ржав, _þétt_, --, 
   {{0x25780241,0xf484732b,0x00000000,0x00000000}},	// [24d00] _fálé_, _خاوی, --, --, 
   {{0x228c01e1,0xdddc00b0,0x9f400165,0x00000000}},	//   _dókè_, _torō, uaiñ_, --, 
   {{0x3a3d65e5,0x7a841046,0x7fd400c0,0x00000000}},	//   _ratp_, یشتم, _вігі, --, 
   {{0x7b640209,0x995400a2,0xb0580139,0x00000000}},	//   итле, _aýşa_, _diäs, --, 
   {{0x60c565e6,0x612c01ed,0x6a6c383d,0x6d4001e3}},	//   mmim, _fölö, _tøfl, ånar, 
   {{0x61fd65e7,0x60c565e8,0x0ba81b06,0x20dc0248}},	//   narl, lmim, دامى_, _kíi_, 
   {{0xed540aa5,0x61fc013c,0x20dc01e1,0xafd80162}},	//   _кор_, iarl, _jíi_, _knøp, 
   {{0x61fd65e9,0x917801fb,0xa8440131,0x60c4022e}},	//   harl, _hợp_, للىم_, nmim, 
   {{0xdb0005ac,0xb0580139,0xdddc0419,0x00000000}},	//   _bymå, _kiär, _zmrš, --, 
   {{0x61fd65ea,0x60c41b99,0x48a800db,0x00000000}},	//   jarl, hmim, ктөм_, --, 
   {{0x20dc0248,0xe9d400fb,0x00000000,0x00000000}},	//   _níi_, _ткх_, --, --, 
   {{0x746864d6,0x61fc0076,0xb9d40092,0x478801ec}},	//   тров_, earl, _ችላ_, _өсім_, 
   {{0xe78015d1,0x60c40010,0xa87800df,0x00000000}},	//   _мушо, dmim, _באאר, --, 
   {{0x20dc0cad,0x23640267,0xc764247f,0x60c565eb}},	//   _bíi_, ämja_, _دامى, emim, 
   {{0x6a6c00cc,0x60c405b1,0xa2940212,0x228c0ca8}},	//   _bøfj, fmim, царі, _sókè_, 
   {{0x60c565ec,0x61fc5830,0x2098004e,0xb0580139}},	//   gmim, aarl, аксы_, _riäs, 
   {{0x61fd65ed,0xdddc39ae,0x612c0d36,0xd0080150}},	// [24d10] barl, _smrš, _pölö, кеңе_, 
   {{0x61fc33f2,0x20dc0241,0xea9c0055,0x60c565ee}},	//   carl, _fíi_, _meṣo_, amim, 
   {{0xb05800fd,0xdd9001d9,0x00000000,0x00000000}},	//   _diär, ٘وٕ_, --, --, 
   {{0x60c40240,0x80b800cd,0x00000000,0x00000000}},	//   cmim, ्षणे, --, --, 
   {{0x09e439c1,0xdef80a89,0x0054011a,0x00000000}},	//   болн, _выс_, _השרת_, --, 
   {{0x7f38008f,0x20dc0248,0x1bb80efe,0x00000000}},	//   _געשו, _yíi_, جامع_, --, 
   {{0xdd94c01a,0xdea44bf3,0xdd5800db,0x5edc0154}},	//   _дары, _بیلی, _карч_, মীদে, 
   {{0x61fc0c44,0x2398ba77,0xab840166,0xb0580139}},	//   zarl, ọji_, _кузк, _ziär, 
   {{0x8c44005e,0x61fd65ef,0x068401b9,0x00000000}},	//   _кеңе, yarl, йгин, --, 
   {{0x9964008e,0x6a141d10,0xe7e407f7,0x4638005b}},	//   стәл, _خبرر, _ट्रा_, учия_, 
   {{0x044408e2,0x2cbc0009,0x8c3c0205,0x60c565f0}},	//   бенн, _khud_, _akşi, ymim, 
   {{0x3e740008,0x61fd65f1,0x7d1805ac,0x2a080165}},	//   _mæta_, warl, _åtse, ṅkār_, 
   {{0x61fc694c,0xb7d8008f,0x3e740162,0xf2e40133}},	//   tarl, _עקסי, _læta_, یکیه_, 
   {{0x61fc013c,0x2cbc0135,0xafd803cd,0xe1f8013e}},	//   uarl, _lhud_, _snøp, шҳо_, 
   {{0x17240135,0x95c80640,0x850565f2,0x8c3c0790}},	//   _འདོམ_, _кућа_, _اوبن, _ekşi, 
   {{0x61fd65f3,0x3490147e,0x60c40140,0x66f80037}},	//   sarl, _најр, umim, _एबाक_, 
   {{0x61fd65f4,0x60c565f5,0xb59001af,0x00000000}},	// [24d20] parl, rmim, _миәш, --, 
   {{0x61fc32ff,0x3e74008c,0x2cbc003e,0x20dc0241}},	//   qarl, _bæta_, _ahud_, _tíi_, 
   {{0x814565f6,0x80b839d7,0xe9dc004d,0xbd881291}},	//   _انجن, ्षदे, _đúp_, دنان_, 
   {{0x8c940212,0x3154008f,0x00000000,0x00000000}},	//   орчі, _היטן_, --, --, 
   {{0x38b802d3,0x17240135,0xa06800c7,0x9b5801c0}},	//   jëra_, _འདེམ_, _баҟа_, рилт_, 
   {{0x2cbd65f7,0x261005f9,0x00000000,0x00000000}},	//   _ehud_, _दागी_, --, --, 
   {{0x3e7401a8,0x6e74074d,0x999c00e5,0x00000000}},	//   _gæta_, _уйрă, tevő_, --, 
   {{0x7c94007b,0x00000000,0x00000000,0x00000000}},	//   _الرص, --, --, --, 
   {{0x1ddc05d7,0x6b600006,0x00000000,0x00000000}},	//   _बलात, _екта, --, --, 
   {{0x2cbc0309,0xbdf4015b,0x00000000,0x00000000}},	//   _zhud_, _চাঁদ_, --, --, 
   {{0x998cb0e8,0xb4b0008e,0x00000000,0x00000000}},	//   _hadž_, зинә, --, --, 
   {{0x2cbc0135,0x23e40212,0x957c012d,0x00000000}},	//   _xhud_, зірв, ecąc, --, 
   {{0x75e00116,0x1684105d,0x6a6c01bf,0xb0d833ee}},	//   _нәнҗ, _واتێ, _bøfh, _मंहग, 
   {{0x38647890,0x6efc01e1,0xded40b82,0xe60c0137}},	//   _hoor_, _làbá, ርኛን_, _كشى_, 
   {{0xd4c424ce,0x386565f8,0x65900364,0x00000000}},	//   _мөмк, _koor_, _нашу, --, 
   {{0x76000316,0x38640de2,0x6efc0241,0x00000000}},	//   bízí, _joor_, _nàbá, --, 
   {{0x386565f9,0x3e740008,0x28dc0210,0x00000000}},	// [24d30] _moor_, _sæta_, _पूनि, --, 
   {{0x2cbd65fa,0x386565fb,0xb638037e,0xf3fc00d8}},	//   _shud_, _loor_, _ｅｐ_, laã_, 
   {{0x6efc0248,0x00000000,0x00000000,0x00000000}},	//   _bàbá, --, --, --, 
   {{0x386565fc,0xf3fc0004,0x3e7565fd,0xec140166}},	//   _noor_, naã_, _væta_, седә_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2cbc025c,0xdea401d3,0x3e7402d2,0x5ce400db}},	//   _whud_, _ٹیمی, _tæta_, زكۇل, 
   {{0x386565fe,0x48786575,0x17240135,0x2cbc0204}},	//   _boor_, исия_, _འདུམ_, _thud_, 
   {{0x3a70468c,0x386544f9,0x38b80023,0x00000000}},	//   зләр, _coor_, tëra_, --, 
   {{0x386565ff,0xa3e01f14,0x869806ed,0xc62000fe}},	//   _door_, _तलब_, итот_, _ভোগা_, 
   {{0xf2dc0548,0x452801b9,0x38b8036e,0x00000000}},	//   dqâ_, ажон_, rëra_, --, 
   {{0xe9b401d9,0x38640e14,0x00000000,0x00000000}},	//   _اناں_, _foor_, --, --, 
   {{0x3864fb6b,0xc35402e8,0x38b8036e,0x00000000}},	//   _goor_, оъгъ, përa_, --, 
   {{0x28dc0c66,0x27fc1570,0x4e1800bc,0x00000000}},	//   _पंडि, maun_, दलाई_, --, 
   {{0x27fd6600,0x89f8010f,0x86c4007b,0x00000000}},	//   laun_, יפֿה, _بيتن, --, 
   {{0xf2dc0548,0x38640de2,0x765c00e4,0x6e340009}},	//   aqâ_, _yoor_, _òpya, dexb, 
   {{0xf3fc00d8,0x9fa0003e,0x3864058a,0xfe7121eb}},	//   caã_, léér_, _xoor_, ژدا_, 
   {{0x26dd2294,0x67380066,0x0d5c0092,0x00000000}},	// [24d40] nquo_, nwuj, _ለሚፈል, --, 
   {{0x27fd6601,0x6444166a,0xaec000d6,0x9f41407e}},	//   haun_, _haii, дбул, ncié_, 
   {{0x644520c4,0xdd900131,0x27fc0200,0x00000000}},	//   _kaii, رۈر_, kaun_, --, 
   {{0x64440113,0x27fd6602,0x4f840092,0x1ddc3409}},	//   _jaii, jaun_, ሪያዎቹ_, _बलवत, 
   {{0x64456603,0x27fd6604,0x200003a0,0x38640009}},	//   _maii, daun_, maii_, _roor_, 
   {{0x64440421,0x38656605,0x27fc0076,0xf3fc00d8}},	//   _laii, _soor_, eaun_, zaã_, 
   {{0x64440093,0x38656606,0x8c3c0432,0x7c940064}},	//   _oaii, _poor_, _akşu, _драц, 
   {{0x64448b14,0x27fd6607,0xcf10015b,0x3864058a}},	//   _naii, gaun_, _সৈয়দ_, _qoor_, 
   {{0x38656608,0x00000000,0x00000000,0x00000000}},	//   _voor_, --, --, --, 
   {{0x64456609,0x38640694,0x200001ab,0x00000000}},	//   _aaii, _woor_, haii_, --, 
   {{0x2fc40016,0x3864cf51,0xf3fc4b91,0x200003c1}},	//   ̀ng_, _toor_, taã_, kaii_, 
   {{0x6444003a,0xaee00055,0x6280036e,0x38b80200}},	//   _caii, _juṣe, ëmon, mëro_, 
   {{0xfbc873d4,0xf3fc0c67,0x644400b5,0x2000058a}},	//   िधिम, raã_, _daii, daii_, 
   {{0x644400b5,0x00000000,0x00000000,0x00000000}},	//   _eaii, --, --, --, 
   {{0xefd4044e,0x64444894,0xf3fc0589,0x200003a0}},	//   ርያዊ_, _faii, paã_, faii_, 
   {{0x20000270,0x644401c7,0xf8c8033f,0x93f43b8f}},	//   gaii_, _gaii, ागिय, _эпиц, 
   {{0x2fcc04f3,0xa3e004fa,0xc7b800e5,0x00000000}},	// [24d50] ägg_, _तलत_, tfői_, --, 
   {{0x27fc3203,0x00000000,0x00000000,0x00000000}},	//   zaun_, --, --, --, 
   {{0x27fc0589,0x6444006f,0x2d84026c,0x998c00c0}},	//   yaun_, _yaii, àne_, _madų_, 
   {{0xa1340efc,0x6e340076,0x00000000,0x00000000}},	//   _کریش, sexb, --, --, 
   {{0x09e5660a,0xdddc0030,0x27fc07c5,0x00000000}},	//   полн, _smrť, vaun_, --, 
   {{0x8c3c0166,0x27fd660b,0x00000000,0x00000000}},	//   _akşt, waun_, --, --, 
   {{0x27fd660c,0x0404009e,0x4808299f,0x00000000}},	//   taun_, ষ্টী_, бейн_, --, 
   {{0xf8ac01b9,0xe7c05f32,0x00000000,0x00000000}},	//   هکن_, _ﺯﻭﺭﻟ, --, --, 
   {{0x27fc0bed,0xbc5402fb,0x6445660d,0x00000000}},	//   raun_, ššíc, _raii, --, 
   {{0x45842082,0x27fd660e,0x64442499,0x673803f3}},	//   згов, saun_, _saii, rwuj, 
   {{0x6445660f,0x04450ba0,0x27fc020b,0x9f40004a}},	//   _paii, пенн, paun_, rcié_, 
   {{0x03a40868,0x04442235,0x32cc033f,0xf09c0241}},	//   зимо, чемн, _użyj_, _njà_, 
   {{0xb7d80302,0x64456610,0x20001140,0x986400ec}},	//   _הקני, _vaii, vaii_, _تُنه, 
   {{0x64456611,0x20016612,0x3024035b,0x00000000}},	//   _waii, waii_, ҟоуп_, --, 
   {{0x2000881c,0x64456611,0x09b4008f,0x00000000}},	//   taii_, _taii, לפֿט_, --, 
   {{0x44e0004e,0x644401ab,0x00000000,0x00000000}},	//   _ió_, _uaii, --, --, 
   {{0x44e16613,0x2000e775,0xd39800b1,0x8fd400b1}},	// [24d60] _hó_, raii_, _дәрә_, дәрә, 
   {{0x44e00570,0xf09c01e1,0x63a56614,0xaee0002b}},	//   _kó_, _ejà_, _ixin, _suṣe, 
   {{0x44e16615,0xc0541b49,0xa3e077ca,0x00000000}},	//   _jó_, _ከገልግ, _तला_, --, 
   {{0x44e16616,0xfe1c00af,0xa6b000cc,0x00000000}},	//   _mó_, _पावस_, ীদিয়, --, 
   {{0x44e04e53,0xee34074d,0x629c0332,0x00000000}},	//   _ló_, ннă_, onro, --, 
   {{0x629d6617,0xb0580036,0x64a401a6,0xab6001c0}},	//   nnro, _jhän, nđib, эвчл, 
   {{0x44e16618,0xada16619,0x6da1661a,0xa96407fa}},	//   _nó_, _зарл, _зира, зија_, 
   {{0xf41c0724,0x9f4000db,0x63a54fe6,0x81e00154}},	//   niät_, nciï_, _oxin, দরি_, 
   {{0x76a8ac51,0x44e1661b,0x2bc800e1,0x63a4036e}},	//   йтов_, _aó_, ़ेदा, _nxin, 
   {{0x44e03589,0xd5e806d6,0xe72c2824,0x629c01a4}},	//   _bó_, piḓ, اصي_, jnro, 
   {{0x44e04cc5,0xb0d82871,0x63a5661c,0x629c0109}},	//   _có_, _मूंग, _axin, dnro, 
   {{0x44e1661d,0x00000000,0x00000000,0x00000000}},	//   _dó_, --, --, --, 
   {{0x7ae1661e,0x44e00332,0xf41c002f,0xb3541e4b}},	//   nqot, _eó_, diät_, سیدا_, 
   {{0x44e00cad,0x3b040eda,0xb0580309,0xe73c00d8}},	//   _fó_, isoq_, _chän, çõe_, 
   {{0x63a5661f,0x44e16620,0xa5d42cb0,0xb0580036}},	//   _exin, _gó_, _عبور_, _dhän, 
   {{0x690800a2,0x00000000,0x00000000,0x00000000}},	//   _ỳeke, --, --, --, 
   {{0x9f340220,0xf41c0724,0x3b040007,0x00000000}},	// [24d70] неті, mgä_, jsoq_, --, 
   {{0xdcfc0baf,0xf41c0598,0xcf2c02d3,0x44e16621}},	//   _ayrı, lgä_, _ስክፍታ, _yó_, 
   {{0xfe1c0cf1,0x44e00208,0xdd94a3f7,0xc0b80023}},	//   _पारस_, _xó_, нафы, ቲሎም_, 
   {{0x6a6c5b47,0xf41d6622,0xccfc013f,0x630401b9}},	//   _løft, ngä_, nyɛɛ_, _تویل, 
   {{0x7ae00472,0x2e4800a7,0xf41c0108,0x19c40150}},	//   gqot, _ляво_, liäs_, _ﺨﺭﻭﺠ, 
   {{0xccfc0134,0x9bc400db,0x00000000,0x00000000}},	//   hyɛɛ_, رەلۉ, --, --, 
   {{0xa3b4038e,0x3b040af5,0x5ee80154,0x9d1801ee}},	//   _जुन_, asoq_, _পিএই, _норт_, 
   {{0x44e16623,0xefd40020,0x46e96624,0x06e96625}},	//   _ró_, ርጫው_, один_, омик_, 
   {{0x44e16626,0x32000851,0x629c0649,0x2b4801e7}},	//   _só_, kajy_, ynro, _écc_, 
   {{0x44e16627,0x2cad6628,0x9a844d56,0x57241870}},	//   _pó_, logd_, _пухл, رىپك, 
   {{0xa3d00882,0x58b850b5,0x3a8401d9,0x63a40139}},	//   वेन_, _کالج_, _تُلہ, _sxin, 
   {{0x44e16629,0xc794760c,0x4ae00037,0x00000000}},	//   _vó_, _орлы, _पढाव, --, 
   {{0x44e04e53,0xb0583262,0x85083c20,0x629d662a}},	//   _wó_, _phän, _विकट_, tnro, 
   {{0x44e07883,0x2cac0158,0x29040098,0xf41c0139}},	//   _tó_, hogd_, osna_, agä_, 
   {{0x29040054,0x44e00421,0x629d662b,0xf6b00133}},	//   nsna_, _uó_, rnro, _جموج, 
   {{0x63a405f5,0x29042878,0xb0580374,0xf41c0139}},	//   _txin, isna_, _whän, cgä_, 
   {{0x443001aa,0x63a400f1,0x1f340092,0x00000000}},	// [24d80] _iby_, _uxin, _አያያዝ, --, 
   {{0x80bc06bc,0xee35662c,0xa1f40150,0x4ae00037}},	//   _वीरे, мну_, _سۋرت, _पढ़व, 
   {{0xf41c049f,0x29040e3c,0x4430017a,0xdb000432}},	//   miär_, jsna_, _kby_, _dymý, 
   {{0x3b040af5,0x2905662d,0xf41c002f,0xccdc02dd}},	//   tsoq_, dsna_, liär_, _ﻁﺎﺌﻔ, 
   {{0x3b0420ac,0x4431662e,0x0f340276,0x6e281bce}},	//   usoq_, _mby_, _пэря, àlbé, 
   {{0x3b040af5,0xf41c0598,0x4430020c,0x9f400216}},	//   rsoq_, zgä_, _lby_, ncií_, 
   {{0xb05801e6,0x3b0420ac,0x29040267,0x7ae00784}},	//   _ohäl, ssoq_, gsna_, sqot, 
   {{0xb9040882,0x443005ac,0x6a6c0b1a,0x38b80240}},	//   _यं_, _nby_, _søft, përm_, 
   {{0x290401d9,0x9f4001f1,0x3b040007,0x2da00311}},	//   asna_, kcií_, qsoq_, ăreţ_, 
   {{0x4430e92c,0x19c400fd,0xf4e40150,0x4e00012d}},	//   _aby_, _пәйг, _ﺍﻟﺭﻜ, _लड़ाई_, 
   {{0x6921662f,0xafd80fac,0xdddc00e2,0x00000000}},	//   _амха, _enøy, _torņ, --, 
   {{0x3aa8009f,0x00000000,0x00000000,0x00000000}},	//   _اُڦٽ_, --, --, --, 
   {{0xf41c1248,0x4430010a,0x00000000,0x00000000}},	//   rgä_, _dby_, --, --, 
   {{0x44300c8a,0x00000000,0x00000000,0x00000000}},	//   _eby_, --, --, --, 
   {{0x4430020b,0x779004fb,0x32016630,0x30680b3e}},	//   _fby_, _سیگا, rajy_, ојан_, 
   {{0x64a4107d,0x3ce000ab,0x00000000,0x00000000}},	//   rđic, _ओढ़े_, --, --, 
   {{0xf2c56631,0xc3c078da,0x79440092,0x5f940121}},	// [24d90] _осон, _бөрл, ረሰበት, витт, 
   {{0x29056632,0x8eb56633,0x78a0009b,0x00000000}},	//   ysna_, رماش, _ljov, --, 
   {{0x29040227,0xe3b000f6,0xdb0002fb,0x78a000c7}},	//   xsna_, _مری_, _vymý, _ojov, 
   {{0x78a16634,0x00000000,0x00000000,0x00000000}},	//   _njov, --, --, --, 
   {{0x29040009,0xefc800f3,0x11cc01e1,0x00000000}},	//   wsna_, _функ_, _ṣèlé, --, 
   {{0x29056635,0x6d40022c,0x78a16636,0x7d0c0162}},	//   tsna_, ænas, _ajov, ónsú, 
   {{0x08d56637,0x68e00369,0x1a681a4b,0x29056638}},	//   нция, uqnd, بیلی_, usna_, 
   {{0x29056639,0x3d180073,0xb058007c,0x6b6400b8}},	//   rsna_, मूळे_, _ohäm, _pūgā, 
   {{0x2905663a,0xb904023e,0x78a00175,0x6f180213}},	//   ssna_, _यू_, _djov, əccü, 
   {{0x4430a324,0x2905663b,0xa3d09543,0x5a340276}},	//   _sby_, psna_, _वृष_, _инут, 
   {{0x29040054,0x44300334,0xe944010a,0x00000000}},	//   qsna_, _pby_, _юхао, --, 
   {{0x9f400589,0x7b940014,0x78a0036e,0x00000000}},	//   nciã_, _تھۅس_, _gjov, --, 
   {{0xb0580113,0xf1b81c5c,0xd875663c,0x93d40055}},	//   _chäm, ﻠﯩﻘﺘ, _جالب, _aṃba, 
   {{0xdebc001f,0xfe1c07f7,0x03940139,0x00000000}},	//   ሳችን_, _पाइस_, _үрия, --, 
   {{0xc0d4007b,0xb058002f,0x9f400419,0x4e18000d}},	//   فيسب, _thäl, rcií_, _पाड़े_, 
   {{0x44300419,0x5dc802dd,0x00000000,0x00000000}},	//   _uby_, _ﺩﺍﻨﻴ, --, --, 
   {{0x2481663d,0x9f4000d7,0x00000000,0x00000000}},	// [24da0] _ilim_, pcií_, --, --, 
   {{0x3e740413,0x6cd00131,0xa3d000cd,0x79440092}},	//   _kæti_, ۇقلا, वेण_, ረተበት, 
   {{0x24805815,0x61b41e4a,0xa3b40037,0x00000000}},	//   _klim_, _شەرا, _जुत_, --, 
   {{0x3e7409e8,0xf41c0112,0x00000000,0x00000000}},	//   _mæti_, phäe_, --, --, 
   {{0xfe1c0574,0x26c5663e,0xb0bc02ab,0x3e7409e8}},	//   _पाऊस_, _ohno_, ्षरग, _læti_, 
   {{0x78a0019b,0x38b802d3,0xcee80014,0x19941d5a}},	//   _sjov, mëri_, _ترَن_, каля, 
   {{0xa3d133ab,0x2481663f,0x78a00024,0x442000b5}},	//   वेत_, _olim_, _pjov, kgk_, 
   {{0x7d1c0161,0x248006d9,0x26c400cd,0xab60104e}},	//   mups, _nlim_, _ahno_, твәл, 
   {{0x9f416640,0x7d1c12ed,0x39e001e0,0x7c20a443}},	//   ncià_, lups, _йәйғ, mgor, 
   {{0x24816641,0x7e6c0a06,0x3e7408a5,0xdb00012d}},	//   _alim_, _jobp, _bæti_, _wymó, 
   {{0x44200036,0x7d1c02d0,0x38b80200,0x7c20007c}},	//   fgk_, nups, hëri_, ogor, 
   {{0x24816642,0x38b80240,0x77840166,0x7e6c002f}},	//   _clim_, këri_, _плез, _lobp, 
   {{0x7c216643,0xf77005d9,0x38b80240,0x7d1c02d0}},	//   igor, _ڄاڻ_, jëri_, hups, 
   {{0xd1e036bc,0x7d1d6644,0x56956645,0x248056f8}},	//   _ፓርቲ_, kups, _шалт, _elim_, 
   {{0x7c216646,0x3e74008c,0xa158e09a,0x44200175}},	//   kgor, _gæti_, нару_, bgk_, 
   {{0xb13402d3,0xfe1c0490,0x7648010e,0x7d1c03ac}},	//   _ኣካይዳ, _पाउस_, _hafy, dups, 
   {{0xb9000ed9,0x7c216647,0xa3d11139,0x76480083}},	// [24db0] _ཨང_, dgor, वेद_, _kafy, 
   {{0x24800e3c,0x7648007f,0x2c747cd9,0xe29800f3}},	//   _zlim_, _jafy, _içdi_, _пањ_, 
   {{0x76496648,0x91800075,0xa3e83d1d,0x2a640175}},	//   _mafy, _ئۇزۇ, मुक_, vjnb_, 
   {{0x76496649,0x7c21664a,0x4fc00075,0x0fc40228}},	//   _lafy, ggor, _نەزە, _үйүн, 
   {{0x9f402b1d,0x00000000,0x00000000,0x00000000}},	//   ccià_, --, --, --, 
   {{0x7c2001c6,0x7d1c014b,0xff140375,0x00000000}},	//   agor, bups, _בקשת_, --, 
   {{0x9f400589,0xecb9664b,0x7d1c0423,0x7c20e0aa}},	//   pciã_, _فطرت_, cups, bgor, 
   {{0x26c40048,0x9f409192,0x6d449f58,0x44200175}},	//   _shno_, mbiò_, _isja, xgk_, 
   {{0x3e745787,0x200c013f,0x46a4005b,0x6f1c0455}},	//   _sæti_, _ɛdi_, каив, nuqc, 
   {{0x24800e21,0x00000000,0x00000000,0x00000000}},	//   _slim_, --, --, --, 
   {{0x38b8006a,0x76480368,0xda083296,0x2480b673}},	//   zëri_, _dafy, _سينه_, _plim_, 
   {{0x764802d0,0x00000000,0x00000000,0x00000000}},	//   _eafy, --, --, --, 
   {{0xd174005e,0x44200175,0x00000000,0x00000000}},	//   қыры, rgk_, --, --, 
   {{0x3ce0069f,0x09d400bd,0x6f1c00ac,0x7648010e}},	//   _ओढले_, _স্যা, duqc, _gafy, 
   {{0x27294a24,0x6600045f,0x1139664c,0xf5900451}},	//   løn_, _ienk, няты_, _پليج, 
   {{0x66000664,0xa3e80b6d,0xed88001f,0x38b8ce7b}},	//   _henk, मुख_, ፒዩተር_, tëri_, 
   {{0x6601664d,0x6d44033d,0x7c2000fd,0x7e24010b}},	// [24dc0] _kenk, _asja, vgor, кдаж, 
   {{0x6601664e,0x9f40521d,0x7d187813,0xefc4084c}},	//   _jenk, rcià_, _åtsk, тлул_, 
   {{0x6601664f,0x9f402b1d,0x38b8a87b,0x7c200042}},	//   _menk, scià_, sëri_, tgor, 
   {{0x38b8044e,0x7d1cc55a,0x7c200165,0x2728005c}},	//   përi_, rups, ugor, køn_, 
   {{0xe60401d9,0x38b802d3,0x7d1d6650,0x272805ac}},	//   _پش_, qëri_, sups, jøn_, 
   {{0x6600124c,0x0ba91b48,0x4ed41836,0x6a115889}},	//   _nenk, رانى_, _бюст, амшу, 
   {{0xcdc41b74,0xd95404fb,0x7c20015d,0x00000000}},	//   _барқ, انبخ, pgor, --, 
   {{0xe8dc063f,0xada16651,0xc0b80023,0x76480064}},	//   _gbọm_, _тасл, ቲፎም_, _safy, 
   {{0xf0910b71,0x3ce4033f,0x7648036e,0xf4e402dd}},	//   ינה_, _जूते_, _pafy, _ﺍﻟﺸﻜ, 
   {{0x66016652,0x5ca400d1,0x6b7400d1,0x6d4402d0}},	//   _cenk, _риғб, _шәхс_, _ysja, 
   {{0x66016653,0xae180a7c,0x00000000,0x00000000}},	//   _denk, וויכ, --, --, 
   {{0x66016654,0x7648009f,0xf3fc00d8,0x6f1c02d1}},	//   _eenk, _wafy, rjão_, yuqc, 
   {{0x66016655,0xb05800b0,0x163558eb,0x764802e2}},	//   _fenk, _whäk, _беля, _tafy, 
   {{0x66016656,0x66701075,0x6f1c014f,0x00000000}},	//   _genk, _ندىر, vuqc, --, 
   {{0x79880369,0x9f40003a,0x50300023,0x6f1c0455}},	//   nzfw, nciæ_, _ኣማልኽ, wuqc, 
   {{0x70bc10f7,0x66012ccc,0x6f1c91c6,0xb42401d3}},	//   ्षेल, _zenk, tuqc, _شعبو, 
   {{0xdb440272,0x6600136f,0xd904066d,0xb4ac01f9}},	// [24dd0] _بێ_, _yenk, _ڈی_, कवी_, 
   {{0xb0c00b40,0x34a0010e,0x00000000,0x00000000}},	//   _वीरग, _taỳỳ, --, --, 
   {{0xf1a96657,0xe7f4012c,0x6f1c27b3,0xdbdc03b2}},	//   _زاده_, ीरमा_, suqc, _sáðk, 
   {{0x63056658,0xc0d4001f,0xaca000a2,0xa3d000cd}},	//   _حویل, ይቻል_, _raỳa, वेव_, 
   {{0x7d0c00f2,0xf4e401ec,0xaaac00bc,0x00000000}},	//   _evbs, _ﺍﻟﺴﻜ, टवलक, --, 
   {{0x6d456659,0xb05800a2,0x9f40148b,0x00000000}},	//   _tsja, _shäh, mbið_, --, 
   {{0x6601665a,0xdddc0115,0x3dc40198,0x6d4403ac}},	//   _renk, _korŝ, ƙowa_, _usja, 
   {{0x6601665b,0xc72401c0,0x597419b0,0x00000000}},	//   _senk, гдий, рышу, --, 
   {{0x6601665c,0x1bd413cf,0x00000000,0x00000000}},	//   _penk, _вотя, --, --, 
   {{0x660002d3,0x2728353e,0xaca0010e,0x00000000}},	//   _qenk, røn_, _taỳa, --, 
   {{0x6601665d,0x3e740008,0x8834084c,0x286800f7}},	//   _venk, _gætu_, _бэлц, _ордо_, 
   {{0x09d4febc,0x3e740008,0x6f0c0165,0x70bc07f7}},	//   _স্থা, _hætt_, _ovcc, ्षोल, 
   {{0x6601665e,0xaca00521,0xe2842097,0x6aa001ab}},	//   _tenk, _abịa, иғин, onnf, 
   {{0xc575665f,0x660002d0,0xa3d1617c,0x56941ee1}},	//   _مطبع, _uenk, वेष_, _качт, 
   {{0x35502be7,0x3e7401a8,0x6aa001ab,0x00000000}},	//   _هنوز, _mætt_, innf, --, 
   {{0x7fd4005e,0x3e74022c,0x3fe00eac,0xf41c01f4}},	//   гізі, _lætt_, বর্ষ, lhän_, 
   {{0xa3d021bd,0x38b80240,0x4cc800cc,0xbfc54837}},	// [24de0] वेश_, mërt_, ষদাঁ, убак, 
   {{0xf41c023a,0x9f400489,0xabc00150,0x00000000}},	//   nhän_, ubiñ_, _ﺩﻭﻋﺎ, --, 
   {{0xdddc00df,0xa3d07ef5,0x8db40006,0x0eb860a7}},	//   _forŝ, वेर_, асці, туты_, 
   {{0x3b856660,0xb1980a1e,0xa3e8e1ff,0x1acc00b8}},	//   ллег, _טייכ, मुच_, ाष्ठ, 
   {{0x3e7401a8,0xde1414a5,0x7f740640,0x2ca46479}},	//   _bætt_, _نژاد, _сунц, énda_, 
   {{0xb05801c7,0x67d800e2,0x4af8084c,0x7b0400e2}},	//   _rhäi, _mājī, тэця_, _ērtī, 
   {{0xed5422f9,0xe56456e6,0xd944035b,0x00000000}},	//   _йор_, _اط_, рҵеи, --, 
   {{0x6d480a28,0x18756661,0x98755de0,0x3e741427}},	//   āgat, ргия, рлиц, _vætu_, 
   {{0xb6056662,0xa3b47dad,0xa8500fca,0x3e7408a5}},	//   лянк, _जुल_, скыч, _fætt_, 
   {{0x39580f7c,0x3e7401a8,0x56940798,0x00000000}},	//   ጌላውያ, _gætt_, раот, --, 
   {{0xb05802b5,0xca7400fd,0x38b883cc,0x4a7400db}},	//   _whäi, _туты, fërt_, _тытт, 
   {{0xb4ac04fa,0xe970004b,0x38b81bce,0x00000000}},	//   कवे_, _دهمد, tëru_, --, 
   {{0xa3d00f4a,0x4834004b,0x30a40818,0x7c2402d2}},	//   वेल_, _خونړ, ҳрав, _ökru, 
   {{0xe6f000ec,0x2b14000d,0x94240022,0x00000000}},	//   _اڪيڊ, _निसु_, ымҭе, --, 
   {{0x30a49dde,0x00000000,0x00000000,0x00000000}},	//   грав, --, --, --, 
   {{0x667000cf,0x00000000,0x00000000,0x00000000}},	//   _ندۉر, --, --, --, 
   {{0xe7f4681e,0x3fe003d4,0xdd9400fb,0x00000000}},	// [24df0] ीरता_, বৰ্ষ, ҡауы, --, 
   {{0x6ce402dd,0xa3d00073,0x999c0118,0x00000000}},	//   гіде, वेळ_, jevů_, --, 
   {{0x3e7409cc,0x8cb96663,0x00000000,0x00000000}},	//   _rætt_, نگرس_, --, --, 
   {{0xfdc800d1,0x3e740252,0x00000000,0x00000000}},	//   ттуқ_, _sætt_, --, --, 
   {{0x6f0c00ec,0xf41c005b,0x16140073,0x7a0c0055}},	//   _uvcc, yhän_, ढणार_, _ṛtad, 
   {{0x67d80171,0xe37c010f,0x00000000,0x00000000}},	//   _jājū, ערגר, --, --, 
   {{0x5e6404a9,0xc6d407d6,0x0ba800cf,0x00000000}},	//   _دۆلە, یتخت, راچى_, --, 
   {{0x1cc40327,0xdd940022,0xed10009d,0x00000000}},	//   _ཌེར_, _уасы, ггvй_, --, 
   {{0x06842de0,0xc7a50dff,0x3e7406ea,0xf41c023a}},	//   игин, рипк, _tætt_, thän_, 
   {{0x67d8002b,0x00000000,0x00000000,0x00000000}},	//   _rājī, --, --, --, 
   {{0x38b80023,0x00000000,0x00000000,0x00000000}},	//   tërt_, --, --, --, 
   {{0xdb5001d9,0xf79401d5,0xf41c0108,0x3de400eb}},	//   _بَے_, انیب_, shän_, _পড়াল, 
   {{0xa3d04614,0xd7f96664,0x2c7403b9,0x00000000}},	//   वें_, _сух_, _uçdu_, --, 
   {{0x42b44965,0xd7740472,0x67d80171,0x00000000}},	//   рёму, _دامع, _vājī, --, 
   {{0x40956665,0x38b80023,0x00000000,0x00000000}},	//   арат, përt_, --, --, 
   {{0x200c00ef,0x00000000,0x00000000,0x00000000}},	//   _ēdis_, --, --, --, 
   {{0xe3b803be,0xde50001f,0xdddc054e,0xfe7000f1}},	// [24e00] şıb_, _የማይፈ, _borş, يدئ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x98d0313e,0x00000000,0x00000000,0x00000000}},	//   _ﺗﺎﯞﻻ, --, --, --, 
   {{0x629d6666,0xf53404ac,0xe058424b,0xaa5400e5}},	//   liro, יטער_, _حیرت_, یلنا_, 
   {{0xf41400c8,0xab240640,0x38b8036e,0x629c0076}},	//   בֿות_, иоца_, kërr_, oiro, 
   {{0x629d6667,0xdddc0139,0xeb94011c,0x00000000}},	//   niro, _gorş, шич_, --, 
   {{0xad646763,0x38b80023,0x64a400f3,0x6da16668}},	//   _карз_, dërr_, rđij, _дира, 
   {{0x629d6669,0xa9640063,0xb8642a77,0xcb8400d1}},	//   hiro, рића_, شابو, рвәқ, 
   {{0xcd54001f,0xf77033d2,0x00000000,0x00000000}},	//   _የሚነገ, تاغ_, --, --, 
   {{0x629c04ce,0x06ac00d1,0xb4dc00cd,0x00000000}},	//   jiro, ﻴﺎﺳﻪ, तद्_, --, 
   {{0xed8c0248,0x00000000,0x00000000,0x00000000}},	//   _òótó_, --, --, --, 
   {{0x629d1c67,0xe9fc0208,0xd7c800f1,0x00000000}},	//   eiro, _trảo_, _یوڅه_, --, 
   {{0xc8b4072d,0xa3b4012d,0xb6a401a9,0x00000000}},	//   _النک, _जुआ_, _кидл, --, 
   {{0x629d666a,0xf1a412fa,0x38b80200,0x389c0327}},	//   giro, арбн, cërr_, rċru_, 
   {{0xc6440137,0xc32c0133,0x65900ce1,0xa17400d4}},	//   _دئنى, وڕی_, _машу, огрі, 
   {{0x629c017a,0x00000000,0x00000000,0x00000000}},	//   airo, --, --, --, 
   {{0x629d666b,0xf3fc4b91,0xdddc00a2,0x50400023}},	// [24e10] biro, mbã_, _porş, _ርኽክባ, 
   {{0x629d666c,0xf3fc0589,0x9df88eb4,0xb144015e}},	//   ciro, lbã_, инут_, _پیرم_, 
   {{0x2ca426b6,0x00000000,0x00000000,0x00000000}},	//   éndo_, --, --, --, 
   {{0xf3fc0589,0xb05804cc,0xe534008f,0xf080036b}},	//   nbã_, _chät, שטאט_, _بیرپ, 
   {{0x4a743740,0x4974009d,0x00000000,0x00000000}},	//   йыкт, өлдс, --, --, 
   {{0x1df8652e,0x8e8400c6,0x28dc00cd,0x92d803d4}},	//   _веры_, _السه, _पूजि, াৱৰ_, 
   {{0xdb00013d,0xf41c03d4,0xc954013d,0x00000000}},	//   _axmä, য্যৰ_, стлы, --, 
   {{0xcd540020,0xcb080451,0xe9a80133,0x00000000}},	//   _የሚናገ, _ميرن_, _یدان_, --, 
   {{0x629d666d,0x4ab800cd,0x00000000,0x00000000}},	//   yiro, ेतदव, --, --, 
   {{0x629d666e,0x068401c6,0xdb0000d7,0x00000000}},	//   xiro, сгон, _vymô, --, 
   {{0x74e405f5,0x7d18007c,0x00000000,0x00000000}},	//   йдэг_, _åtst, --, --, 
   {{0x629c925b,0xf41c00a2,0x00000000,0x00000000}},	//   wiro, bhäm_, --, --, 
   {{0x27fce11d,0x9c1401f2,0x0674010b,0x00000000}},	//   mbun_, kọny, _гуйя, --, 
   {{0x4128196c,0x27fc04cc,0x629c003a,0xfbd0011a}},	//   лого_, lbun_, uiro, פתם_, 
   {{0xd17802bf,0x5154f647,0x00000000,0x00000000}},	//   асті_, отту, --, --, 
   {{0x629d666f,0x27fd6670,0x95c80556,0xa4440345}},	//   siro, nbun_, _туча_, _بێحو, 
   {{0xe76008e7,0xb05804cc,0x28dc09bb,0x0fe80131}},	// [24e20] _kòñò, _rhät, _पूछि, рлуқ_, 
   {{0x422462bd,0xcf240597,0xc61800bd,0x629c2dbe}},	//   _удов, ترفي, ত্রা_, qiro, 
   {{0xb05804cc,0xd9f800ab,0x02b4043e,0x00000000}},	//   _chäs, ुरसत_, ृतीन, --, 
   {{0x7fd400d3,0xfb896671,0xedd01913,0x00000000}},	//   _гігі, лбек_, سيند, --, 
   {{0x20016672,0x7d1c08ad,0x60c56673,0xb0580267}},	//   mbii_, srps, mlim, _skäg, 
   {{0x60c56674,0xdd200316,0x2000198f,0x421400dc}},	//   llim, může, lbii_, _तयोः_, 
   {{0x2000022f,0x8cb80131,0xb05801e3,0xd94800ee}},	//   obii_, ددەس_, _ihär, рҗек_, 
   {{0x60c56675,0x27fc0004,0x00000000,0x00000000}},	//   nlim, gbun_, --, --, 
   {{0xe7600086,0x3b856676,0xec1000f7,0xf42400a2}},	//   _bòñò, _улаг, _رولد, njäň_, 
   {{0x60c56677,0x29dc025c,0x27fd6678,0xa3bc00e1}},	//   hlim, _bħaċ_, abun_, _अड़_, 
   {{0xe72c19d2,0xf7700050,0x27fd6679,0xb9c40137}},	//   وصی_, تاں_, bbun_, _اقاي, 
   {{0xf3fc0c67,0x9964012c,0x60c5667a,0x3eb801a4}},	//   ubã_, _kůže_, jlim, hopt_, 
   {{0x60c40548,0xf3fc0589,0x3eb9667b,0xafd801bf}},	//   dlim, rbã_, kopt_, _ibøg, 
   {{0x9964038e,0x60c5667c,0x229806be,0x00000000}},	//   _může_, elim, _yükə_, --, 
   {{0x60c4003a,0x29dc0003,0xefd40023,0x559401af}},	//   flim, _għaċ_, ይካዚ_, _файѓ, 
   {{0x60c5667d,0x64a46997,0xe1340c75,0x60980014}},	//   glim, _наја, янсы, ٕنِس_, 
   {{0xb8e8025c,0x929406ed,0x00000000,0x00000000}},	// [24e30] _ཊེ_, _маиц, --, --, 
   {{0xceb823c9,0x2000208d,0xf41c01b8,0xed8810de}},	//   рәм_, abii_, skäd_, лсек_, 
   {{0x200022a9,0x60c4ffe4,0x918000d1,0x00000000}},	//   bbii_, blim, _غۇرۇ, --, 
   {{0xa3d01cd2,0xdc740124,0x32e00ca8,0x00000000}},	//   वेक_, зышь, béyè_, --, 
   {{0xcb69667e,0x66cc03cd,0x0ca80037,0x69c40118}},	//   рале_, løke, _कदीम, _újez, 
   {{0xbb40026b,0x00000000,0x00000000,0x00000000}},	//   фешк, --, --, --, 
   {{0xaef801ab,0xb920063f,0x2910002e,0x00000000}},	//   _brùg, mkpọ_, éxa_, --, 
   {{0x48b8015b,0x47380006,0x00000000,0x00000000}},	//   ুদ্র, ачоў_, --, --, 
   {{0xaef801ab,0xa964267c,0x27fd667f,0x5c04009d}},	//   _drùg, риқа_, rbun_, _хяса, 
   {{0x2ce40003,0x27fd6680,0x2cbc107d,0xafd801bf}},	//   _སྤོབ, sbun_, _hkud_, _ebøg, 
   {{0x60c56681,0x044400c9,0x66cc0158,0xf2dc000f}},	//   ylim, оенн, jøke, rwâl_, 
   {{0xf9900302,0x2ee00196,0xf2dc002d,0x7d1801bf}},	//   _קרא_, _lijf_, swâl_, _ætse, 
   {{0xd6a8035c,0x9f40007b,0x06200092,0x00000000}},	//   شدیم_, sciú_, ሳሳይነ, --, 
   {{0x9f4086ed,0x60c4009a,0x09b4008f,0x01656682}},	//   cciù_, wlim, ַפּט_, окго, 
   {{0x60c4002e,0x00000000,0x00000000,0x00000000}},	//   tlim, --, --, --, 
   {{0x60c56683,0x2000208d,0xc4841def,0x00000000}},	//   ulim, ubii_, _флик, --, 
   {{0x20016684,0x60c56685,0x3eb82d2d,0x92d80183}},	// [24e40] rbii_, rlim, topt_, াৱে_, 
   {{0x66cc03a1,0x2cbd6686,0x996400bc,0x00000000}},	//   bøke, _akud_, _růže_, --, 
   {{0x60c56687,0x93d400b8,0x3eb8df4f,0xe4ec00c5}},	//   plim, _aṃha, ropt_, _घूमि_, 
   {{0xbb840075,0xb920063f,0xb05802b5,0x62240150}},	//   يلاي, akpọ_, _whär, _بوگە, 
   {{0xfa240003,0xaef801ab,0x59f81d0b,0x7fd400d3}},	//   _རྐུན_, _crùd, беля_, _фіні, 
   {{0xaef800a3,0x9f9400c7,0x00000000,0x00000000}},	//   _drùd, _дыҳә, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7c656688,0xd5b800e2,0xc9540cdd,0x00000000}},	//   _باسل, igāt_, ятчы, --, 
   {{0xaef801c3,0x76a89c05,0x00000000,0x00000000}},	//   _grùd, итов_, --, --, 
   {{0xd6d08bf0,0x7a8400f1,0x00000000,0x00000000}},	//   عقد_, _بشرم, --, --, 
   {{0xaef80086,0xb4b03ad0,0x00000000,0x00000000}},	//   _irùe, динә, --, --, 
   {{0xe3b80bfc,0xda780306,0xe85400d4,0x00000000}},	//   ğın_, _hoď_, _маєш_, --, 
   {{0xe3b81ae6,0x386401c0,0x667001d5,0x23e40212}},	//   şın_, _inor_, سدیر, дірв, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3864dd59,0xe5b002dd,0x3ce407f7,0x00000000}},	//   _knor_, _ойшы, _जंगे_, --, 
   {{0xda780122,0x66cc08fb,0x20680137,0x00000000}},	//   _loď_, røke, ошуп_, --, 
   {{0x66cc1700,0x630405a9,0x9f356689,0x00000000}},	// [24e50] søke, _قويل, меті, --, 
   {{0x2ce40156,0x2cbc0420,0x395d668a,0xa3b41715}},	//   _སྤུབ, _skud_, _orts_, _जुट_, 
   {{0x3865668b,0x2ee00cf9,0x9bf801f2,0x64a405a1}},	//   _onor_, _vijf_, _ịsụg, rđiv, 
   {{0x6ac01fe7,0xa3c42208,0x2ee00d27,0xfcd801d3}},	//   षत्र, _्रम_, _wijf_, مانڈ_, 
   {{0x395d668c,0x00000000,0x00000000,0x00000000}},	//   _arts_, --, --, --, 
   {{0x3865668d,0xa3d007af,0x00000000,0x00000000}},	//   _anor_, वेट_, --, --, 
   {{0x6ca5668e,0xec6905ec,0xcc240022,0x00000000}},	//   _драж, _крак_, _нчаҩ, --, 
   {{0x3a3c0327,0x3a700166,0x00000000,0x00000000}},	//   _ebtp_, дләр, --, --, 
   {{0x95180135,0x395c017a,0xf41c0036,0xd5b800e2}},	//   ྱེའི_, _erts_, chäi_, zgāt_, 
   {{0x3865668f,0x696401ec,0x052920fe,0x00000000}},	//   _enor_, _وداق, боок_, --, 
   {{0x395c01f5,0xda34ad0e,0x00000000,0x00000000}},	//   _grts_, _цехы, --, --, 
   {{0x764c0134,0x2b5c0115,0x98480108,0xdde400dc}},	//   _ɔhyɛ, _kruc_, _мяча_, _śrūy, 
   {{0x69c404ce,0xb3801a21,0x787031f6,0xd8b84197}},	//   _øjeb, елял, _سُوا, _بدلا_, 
   {{0xaef801e1,0xdbe80027,0x00000000,0x00000000}},	//   _orùb, _ओल्ड_, --, --, 
   {{0xa3d025c9,0xa24800e5,0x00000000,0x00000000}},	//   वेज_, میکل_, --, --, 
   {{0x2b5c00ac,0xd5b81a14,0x016401b9,0x00000000}},	//   _oruc_, rgāt_, окҳо, --, 
   {{0x44316690,0xaef801e1,0x03a4e4e0,0xb058007c}},	// [24e60] _icy_, _arùb, _хипо, _skäc, 
   {{0xef143334,0xaec000d8,0x00000000,0x00000000}},	//   яму_, ебул, --, --, 
   {{0x3f840313,0xaef801c3,0xf2780375,0x81d80154}},	//   šou_, _crùb, _הריש, _ড্র_, 
   {{0x2b5d6691,0x2360045f,0x55ac010f,0x00000000}},	//   _bruc_, _krij_, סיאַ, --, 
   {{0x6f6002d5,0x0024004b,0x6cb001c0,0xda780419}},	//   _звяз, _وګړو_, хөрт, _poď_, 
   {{0x38650e7b,0x3870015d,0x00000000,0x00000000}},	//   _snor_, _ŵyr_, --, --, 
   {{0x6a100372,0xf41c0054,0x39a42776,0xcdc40220}},	//   ربور, chäw_, dësô_, _жарқ, 
   {{0x6f840014,0x00000000,0x00000000,0x00000000}},	//   _بچہِ_, --, --, --, 
   {{0xfb880137,0xf4e40220,0x00000000,0x00000000}},	//   _убак_, _ﺍﻟﺘﻜ, --, --, 
   {{0x44300354,0x39a4006a,0xd9f00c6f,0x95200327}},	//   _acy_, gësô_, _चलित_, _འའདྲ_, 
   {{0x2fc40016,0x2360003a,0x3a2c010a,0xb8800789}},	//   ́ng_, _arij_, mgfp_, ñísi, 
   {{0x386400a8,0x23616692,0x44300175,0x773000c7}},	//   _unor_, _brij_, _ccy_, _зҭиу, 
   {{0x16340801,0x2ca400e4,0x00000000,0x00000000}},	//   _желя, éndi_, --, --, 
   {{0x356817a0,0xe1f80276,0xa6c4030d,0x00000000}},	//   _грин_, зерч_, _елча_, --, 
   {{0xe2c801d9,0xe6380302,0xd2500952,0xa6380375}},	//   سوفو_, _התוכ, ىنڭ_, _הגור, 
   {{0x23600a85,0x20c402dd,0x94a80014,0x00000000}},	//   _frij_, есуг, _گاڈِ_, --, 
   {{0xe8d40302,0x66cc0158,0xaef800a3,0x3384009d}},	// [24e70] לולר_, løka, _srùb, _хуйв, 
   {{0xb8dc0135,0xeff002d3,0x213801ef,0x00000000}},	//   _གཉ_, ልካዮ_, btrh_, --, 
   {{0x2d8484d1,0xaef800a3,0xdea44e5c,0xe8d40150}},	//   áne_, _brùc, ریفی, _ﺟﺎﯞﻋ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe7d439db,0x2d848c17,0x61ec00dd,0xaef801ab}},	//   _সভ্য, šne_, _állá, _drùc, 
   {{0x2b5c0e3c,0x00000000,0x00000000,0x00000000}},	//   _vruc_, --, --, --, 
   {{0xa2a005ba,0x1a684c8b,0x00000000,0x00000000}},	//   _ऑगस्, ثیلی_, --, --, 
   {{0x2b5d6693,0x87e00327,0x00000000,0x00000000}},	//   _truc_, _ཤུདྡ, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x66d40428,0x45840f5c,0x23600200,0xaa400108}},	//   dûkù, дгов, _rrij_, äpää_, 
   {{0xe3b807c4,0xdbdc01e1,0x00000000,0x00000000}},	//   ğım_, _láìk, --, --, 
   {{0x03a4330e,0xe3b88eb9,0x47d40150,0x00000000}},	//   димо, şım_, _قيار, --, 
   {{0xc7b801d3,0x6aa16694,0x00000000,0x00000000}},	//   rgős_, oinf, --, --, 
   {{0x23600936,0xf09ce8c4,0x527400db,0xdef80327}},	//   _vrij_, _amà_, нусу, _ċċ_, 
   {{0x05d0012c,0x6aa0000d,0xf59000ae,0x00000000}},	//   _हरिब, iinf, _للوج, --, 
   {{0xf41c1611,0xb9e40092,0x00000000,0x00000000}},	//   lkän_, _ይዩ_, --, --, 
   {{0xd5ac01d3,0x00000000,0x00000000,0x00000000}},	// [24e80] _نہی_, --, --, --, 
   {{0x6aa0000f,0xf41c0108,0x00000000,0x00000000}},	//   jinf, nkän_, --, --, 
   {{0xb0588b82,0x6aa16695,0x312001c4,0x00000000}},	//   _ikän, dinf, _идэг, --, 
   {{0x6aa00254,0x3f6828e8,0x200402d2,0x00000000}},	//   einf, _димо_, _ými_, --, 
   {{0xcce400c6,0x6aa00175,0x59f800c0,0xf41c008e}},	//   رسمي, finf, пеля_, kkän_, 
   {{0x6aa00cfe,0xf41c0227,0xbe1400cf,0x2fcc002f}},	//   ginf, jkän_, _زورع, ügge_, 
   {{0xa9641b6b,0x00000000,0x00000000,0x00000000}},	//   дија_, --, --, --, 
   {{0x66cc03b2,0xa8a05b0f,0x17540395,0x28a000db}},	//   vøka, крык, евия, кшыг, 
   {{0xb058049f,0x6aa132a2,0xa85019b0,0x00000000}},	//   _okän, binf, ткыч, --, 
   {{0x66cc022c,0x00000000,0x00000000,0x00000000}},	//   tøka, --, --, --, 
   {{0xb86400be,0x00000000,0x00000000,0x00000000}},	//   _ياصو, --, --, --, 
   {{0x9f416696,0x0928a521,0x77902421,0x66cc05ac}},	//   nció_, _رسمي_, _لیبا, røka, 
   {{0x9f40004e,0x66cc00fe,0xf77000cf,0xd25001d9}},	//   ició_, søka, _جاا_, ۆچھ_, 
   {{0x09d400bd,0x82280135,0x00000000,0x00000000}},	//   _স্টা, _སྐྱི_, --, --, 
   {{0xd2502832,0x9f4001ed,0xa15800c0,0x00000000}},	//   نچھ_, kció_, мару_, --, 
   {{0xb058007c,0x64a400e5,0x00000000,0x00000000}},	//   _ekän, lőin, --, --, 
   {{0x6aa1418b,0x7760031c,0x2484005b,0xb3d000af}},	// [24e90] yinf, _jrox, ömme_, _सरिख, 
   {{0x2348e8e1,0x76596697,0xdcfca75a,0xd05c06be}},	//   _کلیپ_, ndty, _axrı, _əyəc, 
   {{0x82280327,0xc0b80023,0xf1a412fa,0x00000000}},	//   _སྐྲི_, ሲሎም_, _ірон, --, 
   {{0x6aa044b6,0x77600005,0x4c94084c,0x6cb801ec}},	//   winf, _orox, эиес, _ﺸﻌﺒﻴ, 
   {{0x6aa16698,0xf41c005b,0x00000000,0x00000000}},	//   tinf, ykän_, --, --, 
   {{0x9f400228,0x41d4000d,0x6aa0002f,0x00000000}},	//   ació_, _धरमस, uinf, --, 
   {{0x6aa16699,0x1a6813de,0xf9f400ae,0x00000000}},	//   rinf, ظیمی_, رفيع_, --, 
   {{0x9f400e26,0x7761669a,0x7d0000f3,0x23bc01ef}},	//   cció_, _brox, ćost, _hájů_, 
   {{0xf41c578c,0x6aa1669b,0x00000000,0x00000000}},	//   tkän_, pinf, --, --, 
   {{0xe3b80365,0xae0c000d,0x26c00129,0x6aa00200}},	//   şık_, िरिन_, ôjo_, qinf, 
   {{0x9f406933,0xf41c4260,0x7761669c,0x00000000}},	//   nciò_, rkän_, _erox, --, 
   {{0xf41d669d,0x77600005,0xb0595403,0x47c000cc}},	//   skän_, _frox, _skän, শেষী, 
   {{0x7dec01ed,0xd8388e21,0xe8c80073,0x00000000}},	//   nősí, _цэх_, ातीच, --, 
   {{0x6d444011,0x2c1c00cd,0x00000000,0x00000000}},	//   _opja, मृतं_, --, --, 
   {{0x0445669e,0x66cc28b3,0x673826b1,0x7164074d}},	//   _зейн, løko, ltuj, нарг_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6738012d,0x644401e1,0xb058005b,0x6d45669f}},	// [24ea0] ntuj, _ibii, _ikäl, _apja, 
   {{0xe2d80014,0x6738005b,0x00000000,0x00000000}},	//   _تابچ_, ituj, --, --, 
   {{0x6738003e,0xf41c013d,0x00000000,0x00000000}},	//   htuj, kkäl_, --, --, 
   {{0x6738a3f5,0xaef801e1,0x3950012d,0x00000000}},	//   ktuj, _irùn, łysk_, --, 
   {{0xfaa52205,0x9f4000f7,0x6444f0e3,0x7ac566a0}},	//   надо, rció_, _mbii, нске, 
   {{0x8fd40831,0x98fc01e4,0x656003ac,0xf41c01e3}},	//   _рәсә, _arĉa, _ornh, nhär_, 
   {{0x9f4166a1,0x644416b8,0x2d8404cc,0x9f0400f1}},	//   pció_, _obii, ùnet_, _سوځو, 
   {{0x66cc2f48,0xdd10013a,0x37040902,0xfce45dce}},	//   føko, _kýže, нчов, _чобо, 
   {{0x656166a2,0x69c4037e,0xf0900375,0x66cd66a3}},	//   _arnh, _øjen, טנה_, røkn, 
   {{0x644566a4,0x66ccb02f,0xdddc00de,0x00000000}},	//   _abii, søkn, _norū, --, 
   {{0x2c74010b,0x673966a5,0x94d40395,0x00000000}},	//   _açdy_, atuj, кооц, --, 
   {{0x644400a3,0xdbdc0ca8,0x9584008e,0xe9441291}},	//   _cbii, _káàk, елүе, _سرمی, 
   {{0xb9d8067d,0x1cc431d9,0x36680775,0xa88566a6}},	//   _ኢሉ_, _ཌེན_, _надо_, _яйца_, 
   {{0x5388044e,0x64441418,0xaef801ab,0x66cc0fac}},	//   _ዝኸይድ_, _ebii, _brùn, nøkl, 
   {{0xe5f4025f,0xaef800a3,0xf41c00a2,0x00000000}},	//   _אזור_, _crùn, lkäm_, --, 
   {{0x6444006a,0x00000000,0x00000000,0x00000000}},	//   _gbii, --, --, --, 
   {{0x6d441873,0x5f940228,0xaef801e1,0xe3b000ec}},	// [24eb0] _spja, гитт, _erùn, _ٿري_, 
   {{0xaef804cc,0x50f40354,0x6d440135,0xe3b00633}},	//   _frùn, _изот, _ppja, _چری_, 
   {{0xaef800a3,0xe3b00ee8,0xa18401e0,0xdfd000f1}},	//   _grùn, _نری_, _быял, ليې_, 
   {{0x67384e86,0x9f415661,0x20f800d0,0x00000000}},	//   ytuj, rciò_, _učia_, --, 
   {{0x9f40f518,0xc014011a,0x6fdc03d4,0x00000000}},	//   sciò_, _בקרו_, _ফ্ৰে, --, 
   {{0x78a166a7,0x7dec01ed,0x5a6401ec,0x3a20009d}},	//   _amov, rősí, лкіб, амшг, 
   {{0xfd640521,0x2bd01fd2,0x3ce400d7,0x00000000}},	//   _mkpọ, _तरवा, ňova_, --, 
   {{0x6738049b,0x66cc1fcd,0x321000a3,0x00000000}},	//   ttuj, tøko, _lexy_, --, 
   {{0x78a00334,0x67380108,0x00000000,0x00000000}},	//   _dmov, utuj, --, --, 
   {{0xfd6401f2,0x78a00c8c,0xb05801e6,0x068401c0}},	//   _nkpọ, _emov, _skäl, тгон, 
   {{0x673966a8,0xb05800e4,0x66cc1477,0x78a00175}},	//   stuj, _akäm, søko, _fmov, 
   {{0xfd6400b4,0x673919a8,0xf41c0139,0x00000000}},	//   _akpọ, ptuj, bkäm_, --, 
   {{0xdbdc01e1,0x5724129d,0x957801c6,0xdddc0064}},	//   _káák, _مىنك, дөөс_, _porū, 
   {{0x68e86129,0xaef804cc,0x46a4022e,0x00000000}},	//   _higd, _prùn, _шалв, --, 
   {{0x68e8030a,0x78a00175,0xb05801f4,0x00000000}},	//   _kigd, _ymov, _ikäj, --, 
   {{0x044566a9,0x68e8031c,0x6444003a,0x00000000}},	//   _реин, _jigd, _ubii, --, 
   {{0x68e966aa,0x26c404ba,0xf41c0036,0x7d0c0042}},	// [24ec0] _migd, _kkno_, phär_, _swbs, 
   {{0x68e966ab,0xaef80016,0x7d0c03ac,0x64a401ec}},	//   _ligd, _trùn, _pwbs, _шақа, 
   {{0x7f400135,0x00000000,0x00000000,0x00000000}},	//   ħoqq, --, --, --, 
   {{0x68e88c79,0x8d540598,0x3b8429db,0x32100076}},	//   _nigd, ытуч, клег, _zexy_, 
   {{0x60c566ac,0x24800034,0x2da4016b,0x00000000}},	//   moim, _moim_, _ɛteɛ_, --, 
   {{0x60c566ad,0x7bc40158,0x5a3566ae,0xf9691486}},	//   loim, _økum, ункт, дрий_, 
   {{0xdbdc01e1,0xb05805d5,0x66cc0162,0x5de000fe}},	//   _dáák, _rhäz, røkl, _প্ৰু, 
   {{0x26c40115,0x60c566af,0x68e966b0,0xf1b0011a}},	//   _akno_, noim, _cigd, יסו_, 
   {{0x68e966b1,0xb05802d1,0xf6280212,0xfd4c0208}},	//   _digd, _chäy, міни_, _ngoằ, 
   {{0x60c566b2,0x68e800fe,0xab240798,0x00000000}},	//   hoim, _eigd, _шоуа_, --, 
   {{0xb058049f,0x60c402f6,0x24800098,0xd5b000c6}},	//   _skäm, koim, _boim_, صفح_, 
   {{0x52bc0846,0x78a005a1,0x248001e7,0x746802e8}},	//   ोत्स, _umov, _coim_, фров_, 
   {{0x2480036b,0x248401e6,0x60c461db,0x00000000}},	//   _doim_, ömma_, doim, --, 
   {{0xe0c40154,0x00000000,0x00000000,0x00000000}},	//   ্দোন, --, --, --, 
   {{0x6114764a,0xefd402d3,0xa6c400cf,0xf41c00a2}},	//   идру, ክያድ_, _جوول_, nkäk_, 
   {{0x60c426b1,0xb0580108,0x00000000,0x00000000}},	//   goim, _ikäk, --, --, 
   {{0x4fd40d44,0xa34400db,0x321001ef,0xdb0c01e1}},	// [24ed0] ужат, _кээл, _texy_, _òkèg, 
   {{0xd25166b3,0xb394001f,0x248001a6,0xa2c40490}},	//   _اند_, ገኘውን_, _zoim_, ळवण्, 
   {{0xd13c01ed,0xf1dc52f2,0x00000000,0x00000000}},	//   _ѕυк_, फेशन, --, --, 
   {{0x60c4089c,0x98fc0115,0x6ad89295,0x2fc80175}},	//   coim, _arĉo, यग्र, _tycg_, 
   {{0x9f98084c,0x68e966b4,0x7e6c035a,0x0df00240}},	//   _авяу_, _rigd, _fnbp, ልላፍ_, 
   {{0x5b2405f5,0x68e803cd,0xee84035b,0x2c1000eb}},	//   рьца, _sigd, _рымо, হলেই_, 
   {{0x3b04013c,0x98ac1ae4,0x38c80aad,0xaa400032}},	//   apoq_, _ardı_, کاوی_, геҙл, 
   {{0x88c40316,0x69c4037e,0x68e8011f,0x00000000}},	//   _ověř, _øjem, _qigd, --, 
   {{0x46e966b5,0x68e966b6,0xdbdc0241,0x659003b9}},	//   ндин_, _vigd, _táák, məhə, 
   {{0x24800bed,0x278400f7,0x60c566b7,0x6e200332}},	//   _soim_, ерүү_, zoim, ónbh, 
   {{0x68e81aef,0x66ccb3f8,0x60c401f7,0x9a840354}},	//   _tigd, løkk, yoim, _тутл, 
   {{0x320c013f,0x29040393,0x2480022e,0x87d401d5}},	//   _ɑgye_, mpna_, _qoim_, _йўлч, 
   {{0x60c566b8,0x66cc4606,0xb0580108,0x53140815}},	//   voim, nøkk, _ikäh, ифру, 
   {{0xb1400131,0x88c401ef,0x00000000,0x00000000}},	//   әнтл, _dvěř, --, --, 
   {{0x60c566b9,0x24803110,0x94180213,0xd05c06be}},	//   toim, _toim_, hisə_, _hisə, 
   {{0x020404a9,0x66cc00b5,0xd05c03e3,0xd094013d}},	//   _өзин, køkk, _kisə, ашуы, 
   {{0x60c566ba,0x20f801a6,0x66cc143a,0x2d8405ac}},	// [24ee0] roim, _ičim_, jøkk, ønen_, 
   {{0x20f808ad,0x941803be,0xee340640,0x60c4005b}},	//   _učio_, disə_, лну_, soim, 
   {{0x60c40261,0xfc280209,0x5bdc00dc,0x88c40118}},	//   poim, ежек_, यध्व, _zvěř, 
   {{0x317800c8,0x0ba80116,0xf53400df,0x00000000}},	//   _נאכד, ھانى_, טטער_, --, 
   {{0xd1f002d3,0x5fe02208,0x0ba80046,0xac047390}},	//   _ቁሩብ_, पेशल, پانى_, унча_, 
   {{0x3b040680,0x66cd4e5f,0x98a009a8,0xfe4000f1}},	//   rpoq_, søkj, čič_, _دکری, 
   {{0xd910675b,0x00000000,0x00000000,0x00000000}},	//   زیش_, --, --, --, 
   {{0x3b040af5,0xfb1415f2,0xa8e000f1,0x57f400d8}},	//   ppoq_, _مورج, مړني, шпит, 
   {{0x2904003e,0x7a342586,0xf6e48602,0x00000000}},	//   apna_, _معائ, лцон, --, 
   {{0x2d840036,0xdca4d08a,0x00000000,0x00000000}},	//   äneg_, _сағи, --, --, 
   {{0x6e2006ea,0x88c400bc,0x7d1c2b96,0x00000000}},	//   ónbi, _svěř, nsps, --, 
   {{0xc9840063,0x65900150,0x00000000,0x00000000}},	//   _туђи, саюу, --, --, 
   {{0xdedc0b82,0x073800ec,0x00000000,0x00000000}},	//   ፕሊን_, _لينڊ_, --, --, 
   {{0xb05802f6,0x39ac00ac,0x81dc00fe,0x00000000}},	//   _ikäi, _kəs_, তখন_, --, 
   {{0xa194fd59,0x20f82a92,0x644000db,0x00000000}},	//   барч, _učil_, òmic, --, 
   {{0x94180213,0x649800e4,0xb19000c7,0x39ac03e3}},	//   yisə_, _rãig, алҳә, _məs_, 
   {{0xb4c006ab,0x8e1439c9,0xdddc0118,0x88c40118}},	// [24ef0] ्ती_, идац, _borů, _uvěř, 
   {{0xe3b803ee,0xb8d4031c,0xb644037e,0x67e80139}},	//   ğıt_, _ཚམ_, _ｈｇ_, _höjü, 
   {{0xf1a8bc05,0xe3b80790,0xdef801e0,0x2ca40100}},	//   _ساده_, şıt_, _ҡыр_, èndo_, 
   {{0xf3fc014b,0xd25166bb,0xa158004e,0x00000000}},	//   ncã_, _انگ_, _саюу_, --, 
   {{0x09dc93cb,0x6ee4036b,0x6f8401c4,0x00000000}},	//   मध्य, _مسآل, _сунж, --, 
   {{0xb4c008df,0x39ac00ac,0x22940267,0x69c4005c}},	//   ्तु_, _bəs_, _käka_, _øjek, 
   {{0xb05800e4,0x79880368,0x0ce80124,0x94180213}},	//   _akäi, gyfw, _ауаҩ_, sisə_, 
   {{0xc72566bc,0x1d3400a8,0x29040010,0x9cc800fb}},	//   адий, _ынся, rpna_, _быуа_, 
   {{0x22940267,0x5c74c502,0x66cc0162,0x00000000}},	//   _läka_, _ултт, løki, --, 
   {{0x6e340369,0x290436d5,0x160007f7,0x00000000}},	//   ngxb, ppna_, लुलर_, --, 
   {{0xb4c00490,0xfe340375,0x24700023,0x66cc0174}},	//   ्तू_, ברתי_, _ድኹማት_, nøki, 
   {{0xb0580139,0x19a800f3,0x6b880174,0x9984cdcc}},	//   _ikäw, _ступ_, oygg, _دلمو, 
   {{0xd87566bd,0x4b78010f,0x6b8801e3,0x27fc06be}},	//   _دالب, דאָו, nygg, mcun_, 
   {{0x412966be,0x27fd4f99,0xee0c375c,0xafd8003b}},	//   кого_, lcun_, िरोध_, _ebøk, 
   {{0x6b8862b4,0x35a009a5,0xd174e44f,0x66809fa2}},	//   hygg, _машг, быты, _نیکل, 
   {{0x27fd66bf,0x6b888605,0xd5ac0014,0xff24146a}},	//   ncun_, kygg, _سہُ_, имбо, 
   {{0x98b00cf4,0x403402dd,0x00000000,0x00000000}},	// [24f00] šaću_, леңс, --, --, 
   {{0x6b880162,0x27440356,0x7d1c01bf,0x00000000}},	//   dygg, mînă_, tsps, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc0f0044e,0x798c0428,0x6fa40073,0x999c0427}},	//   ልኻል_, _übwi, _घेवू, tevž_, 
   {{0x39ac03be,0x8c3c0139,0x79880142,0x7f7400f5}},	//   _səs_, _tmşn, wyfw, _тунц, 
   {{0x9418013f,0x2000054e,0x2900031c,0xb9243ffb}},	//   fisɛ_, lcii_, _ħjar_, афий, 
   {{0x6d300107,0x39ac03b9,0x6e4400e5,0xfce400f5}},	//   _меёф, _qəs_, ésbő, _вово, 
   {{0x200166c0,0x798805e4,0x98742083,0x39ac06be}},	//   ncii_, ryfw, слиц, _vəs_, 
   {{0xa8000227,0xe9d4c5df,0x18480150,0x00000000}},	//   äñax, лкә_, _ەستۋ_, --, 
   {{0x247c02d3,0x9a6800f1,0x567802e8,0x39ac06be}},	//   _ብማለት_, _حجرې_, убоя_, _təs_, 
   {{0x200001a2,0xb05802f6,0xd5b800b0,0xe98424ae}},	//   kcii_, _ikäv, kaāe_, _پالۋ, 
   {{0xb4c0bc82,0xf74566c1,0x27fc04cc,0x2294007c}},	//   ्ते_, _ведо, ccun_, _räka_, 
   {{0xf3fc0004,0xe72c0451,0xe73402e8,0x00000000}},	//   rcã_, _قصو_, _веч_, --, 
   {{0x649800d8,0x66e13292,0xa5f432e1,0x00000000}},	//   _cãib, _доча, _кешу_, --, 
   {{0x30a566c2,0xb59403e6,0xeff00240,0x00000000}},	//   арав, _ڕێگا_, ልያዊ_, --, 
   {{0xe3b966c3,0x64a41fbe,0xb6280150,0x66cc03b2}},	//   ğır_, _маја, _ﯗﻕ_, vøki, 
   {{0xe3b845a5,0xa854011a,0x00000000,0x00000000}},	// [24f10] şır_, סימה_, --, --, 
   {{0x20000009,0x0c440023,0x66cc0162,0xed8841e5}},	//   acii_, _መምዘኒ, tøki, ксек_, 
   {{0xad240050,0x2d8566c4,0xc2100375,0xb4c000dc}},	//   شراو, âne_, _מהי_, ्तॊ_, 
   {{0x66cc022c,0x200166c5,0xdf3800f7,0x00000000}},	//   røki, ccii_, اكەت_, --, 
   {{0x66cc0579,0xf41c0724,0x00000000,0x00000000}},	//   søki, skäw_, --, --, 
   {{0x6b882507,0xda0800ec,0xfb5000d1,0x00000000}},	//   rygg, ليهه_, سپىد, --, 
   {{0x8d940597,0x2bd03105,0xade0c8aa,0x38b800b0}},	//   _الأش, _तरका, केशन_, wīra_, 
   {{0xb4c07509,0x9418013f,0xdd90004b,0x4ddc009e}},	//   ्तो_, risɛ_, _کوې_, _বলপূ, 
   {{0xb8fc4425,0xb4c0038e,0x27fd66c6,0xaef801c3}},	//   _दी_, ्तै_, rcun_, _brùi, 
   {{0x27fc34fe,0xaef801c3,0xc0f00092,0x00000000}},	//   scun_, _crùi, ልጻሉ_, --, 
   {{0xaef808c2,0xfe34011a,0x00000000,0x00000000}},	//   _drùi, זרתי_, --, --, 
   {{0x38b8005f,0x9af40150,0x2000003a,0x00000000}},	//   pīra_, _اكەت, xcii_, --, 
   {{0xd7f8074d,0x409401ec,0x91cc0118,0x00000000}},	//   _тух_, ұрат, _दुबै, --, 
   {{0xd29402bf,0xaef801ab,0x9f440241,0x00000000}},	//   орсь, _grùi, _àmé_, --, 
   {{0xba000201,0x40940d4b,0xdddc0276,0xe3b800ac}},	//   _ልዩ_, брат, _morţ, ğıq_, 
   {{0xd5b80032,0xe3b800ac,0x6d480083,0x2000058a}},	//   _әсә_, şıq_, ăgal, ucii_, 
   {{0x200166c7,0x7e24010b,0xafe0022e,0x3ed4a0bc}},	// [24f20] rcii_, йдаж, зотл, مقرر, 
   {{0x200166c8,0xdc1000e1,0x00000000,0x00000000}},	//   scii_, ार्ड_, --, --, 
   {{0x629d66c9,0x2000c7e4,0x8c3c0139,0x0164009f}},	//   mhro, pcii_, _tmşl, _اُجَ, 
   {{0xe0940345,0x00000000,0x00000000,0x00000000}},	//   _بیرخ, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf41c9226,0x6b6166ca,0x2010033f,0x8b6566cb}},	//   lkät_, якча, łnić_, غانم, 
   {{0xd7f87b08,0x5fac05ba,0xc0f001f3,0x00000000}},	//   қуқ_, _घेतल, ልጻል_, --, 
   {{0xaef801c3,0xf41c3167,0xa9640114,0xb86400ae}},	//   _srùi, nkät_, сића_, صابو, 
   {{0xdddc084c,0x629d66cc,0xb86448ca,0xf2dc0356}},	//   _forţ, khro, لاکو, ntâc_, 
   {{0x3ce51878,0x644000db,0xeb300e56,0x393401c6}},	//   lmov_, òmin, _رىمد, _гэдс, 
   {{0x98c46648,0x3a3c2a90,0x39440276,0x66cc0162}},	//   ştım_, _ictp_, _ынжг, jøku, 
   {{0x3ea805b1,0x628829ef,0x395c0e78,0xc8643592}},	//   _lmbt_, ödon, _ists_, _وطني, 
   {{0xb4c00882,0x7790030f,0x3ce4022e,0x00000000}},	//   ्तौ_, _ریدا, imov_, --, 
   {{0x98fc01e4,0xe3b800fd,0x629d66cd,0x6584036e}},	//   _arĉi, ğıp_, ghro, ëshë, 
   {{0xe3b87bfb,0xf41c0139,0x00000000,0x00000000}},	//   şıp_, fkät_, --, --, 
   {{0x80780a28,0x3ea801a4,0x3ce454b0,0x212c0332}},	//   ṣṭhā, _ambt_, jmov_, ádha_, 
   {{0x7c6c001f,0x629c00a3,0x6ee402cb,0x00000000}},	// [24f30] _በሌላው_, bhro, مسئل, --, 
   {{0x629d66ce,0x395d66cf,0x66cc022c,0xf41c00a2}},	//   chro, _osts_, bøku, laä_, 
   {{0xf7cc08b0,0xdde400fd,0xa3b80133,0x00000000}},	//   ﺗﯩﻤﻪ, зәтү, _نایر_, --, 
   {{0x707402d3,0xdddc054e,0x9cc8005b,0xbb380150}},	//   _ተጻሒፉ_, _sorţ, быча_, _ﺒﺤﻲ_, 
   {{0xdddc0276,0x00000000,0x00000000,0x00000000}},	//   _porţ, --, --, --, 
   {{0x8cd80034,0x66cc003b,0xb7b005ac,0x00000000}},	//   _फीरो, nøkt, _চৰ্ট, --, 
   {{0x3ce402fa,0xf41c005b,0x6d4001ab,0x00000000}},	//   bmov_, nkäs_, ànad, --, 
   {{0x0888044c,0x3ea80b4b,0xb058005b,0x629c5a54}},	//   рбий_, _zmbt_, _ikäs, zhro, 
   {{0x395d66d0,0xdddc0311,0x00000000,0x00000000}},	//   _ests_, _torţ, --, --, 
   {{0x85487888,0x3a3c01b8,0x2cac0196,0xdddc0308}},	//   азов_, _gctp_, ligd_, _horš, 
   {{0xda7966d1,0xf41c005b,0xdddc00c0,0xf3f000cc}},	//   _уят_, ykät_, _korš, _অজগৰ_, 
   {{0x2cac0196,0xa81405d9,0x02b0012c,0x66cc03b2}},	//   nigd_, _اڪثر_, ँच्न, vøku, 
   {{0x629d1fb8,0x00000000,0x00000000,0x00000000}},	//   thro, --, --, --, 
   {{0x66cc0579,0x3ce4cd97,0xb5a801d3,0x00000000}},	//   tøku, zmov_, ائیے_, --, 
   {{0x044406bb,0xf41c023a,0xd174034b,0xe73401af}},	//   _дейн, tkät_, пыты, _теҙ_, 
   {{0x629c32be,0x838800d4,0x66cc03b2,0xdddc01ef}},	//   shro, _вбив_, røku, _norš, 
   {{0x629c52df,0x2cac0cf9,0xf41c0716,0x66cc06ea}},	// [24f40] phro, digd_, rkät_, søku, 
   {{0xef151871,0xa06814d4,0x0fe80131,0xf41c01f4}},	//   юму_, шаға_, слуқ_, skät_, 
   {{0x225966d2,0x3ce47edf,0x5edc00eb,0x00000000}},	//   merk_, tmov_, বদলে, --, 
   {{0x823566d3,0x98bc0882,0x22580af9,0x59c44196}},	//   _ارکا, ktvā_, lerk_, _लुगर, 
   {{0x6ee0063f,0x42800092,0x3ce43493,0x00000000}},	//   ọbar, _ያገኙት_, rmov_, --, 
   {{0x22580d04,0xbb4c00b5,0x90e402f2,0xf41c00a2}},	//   nerk_, _comに_, _وسێن, nkär_, 
   {{0xb058ee1f,0xdddd66d4,0x27340419,0x00000000}},	//   _fjäd, _forš, yžná_, --, 
   {{0xdddd66d5,0x225801a9,0xfca80345,0x00000000}},	//   _gorš, herk_, _ئاسو_, --, 
   {{0x225966d6,0x7b640014,0xf41c0166,0x00000000}},	//   kerk_, _بازٕ, kkär_, --, 
   {{0x2258045f,0x368966d7,0x395c009a,0xf41c005b}},	//   jerk_, рсин_, _tsts_, ykäs_, 
   {{0xc1d01df2,0xf42000f7,0xf41d66d8,0xc76c00e5}},	//   ﺘﯩﺮﺍ, үзүү, dkär_, őépí, 
   {{0xe0cc009e,0x213803b2,0x00000000,0x00000000}},	//   লগুন, durh_, --, --, 
   {{0x66cc0158,0x2ca4067c,0x00000000,0x00000000}},	//   tøkt, èndi_, --, --, 
   {{0x290006af,0x2cac01f5,0xf41c01f4,0x2258c72a}},	//   _éjac_, zigd_, tkäs_, gerk_, 
   {{0x66cc022c,0x77900b28,0x69c401bf,0x00000000}},	//   røkt, _ریگا, _øjet, --, 
   {{0xb0580022,0x66cc168c,0x00000000,0x00000000}},	//   _akär, søkt, --, --, 
   {{0x225966d9,0x9f440cad,0x2cad66da,0x00000000}},	// [24f50] berk_, _àmì_, vigd_, --, 
   {{0xa2b41c22,0x2cac01a4,0xdddc0427,0x20f800c0}},	//   _обыч, wigd_, _sorš, _ačiu_, 
   {{0x062c0020,0x712422e0,0x2cac0d27,0xdddc009b}},	//   _ተጠቃሚ, _برخل, tigd_, _porš, 
   {{0xaef808c2,0x2b5c00db,0xdd940022,0x00000000}},	//   _brùt, _psuc_, ьахы, --, 
   {{0x0f781a4c,0xcb68c7fe,0x00000000,0x00000000}},	//   _האָב, сале_, --, --, 
   {{0xdaa8cea6,0x00000000,0x00000000,0x00000000}},	//   овід_, --, --, --, 
   {{0xbb4c04ce,0xdea4006c,0xad400137,0xb05801e3}},	//   _comカ_, _تیلی, _تىزۉ, _tjäd, 
   {{0x98bc0882,0xac7402dd,0x2258005a,0xed6000c0}},	//   ttvā_, _باسش, zerk_, _vežė_, 
   {{0xa96401b9,0x1ca802f2,0x00000000,0x00000000}},	//   сиқа_, _بێنی_, --, --, 
   {{0x1a681056,0x66cc06ea,0x00000000,0x00000000}},	//   _وینی_, vøks, --, --, 
   {{0x225966db,0xe9b401d9,0xe7740014,0x628801e3}},	//   verk_, _بناں_, _ڈلاں_, ödom, 
   {{0x22582e94,0xe77401d9,0x00000000,0x00000000}},	//   werk_, _ولاں_, --, --, 
   {{0x225966dc,0x00000000,0x00000000,0x00000000}},	//   terk_, --, --, --, 
   {{0x2cbc049f,0x98a00006,0x20f80841,0x66cc05ac}},	//   _ljud_, čią_, _očit_, røks, 
   {{0x5bb8206b,0x4094db74,0x66cc168c,0x22940254}},	//   _अश्व, прат, søks, _häkk_, 
   {{0x03241f5c,0xb05804f3,0x23600211,0xf41d3c88}},	//   _един, _skär, _tsij_, skär_, 
   {{0x2d8566dd,0x22585b5e,0xb058007c,0x00000000}},	// [24f60] änen_, perk_, _bjäb, --, 
   {{0x442166de,0x300005f5,0xc1d01b15,0x2cbc000d}},	//   lak_, _үзэг, _зөбә, _ajud_, 
   {{0x442005f5,0x2cbc0267,0xaef801ab,0x0164004e}},	//   oak_, _bjud_, _srùt, _экно, 
   {{0x442166df,0x6cd00075,0x00000000,0x00000000}},	//   nak_, ىقلا, --, --, 
   {{0x442005f5,0x22940254,0xb05801f4,0x00000000}},	//   iak_, _näkk_, _ikäp, --, 
   {{0x44205101,0x6d4000a3,0xa3c40037,0x3e8800cf}},	//   hak_, ànac, _एखन_, _уйго_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3a300209,0x4de0000d,0xa8a00108,0x00000000}},	//   şyp_, _करतै_, ерьк, --, 
   {{0x442166e0,0x7c20b0dc,0x2ca566e1,0x6c78010f}},	//   dak_, maor, ënde_, _פאמפ, 
   {{0x7c2166e2,0x442166e3,0x39e0a705,0x247c00b7}},	//   laor, eak_, _пәйғ, _እየሱስ_, 
   {{0x442166e4,0x00480023,0x00000000,0x00000000}},	//   fak_, _ምጽንና, --, --, 
   {{0x442166e5,0x49e002dd,0xdddc0210,0xda7000ec}},	//   gak_, _جۋىق, _karł, _سڏڻ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x442166e6,0x1adc2ecf,0x7c2166e7,0x776002d0}},	//   aak_, यतिथ, haor, _isox, 
   {{0x442166e8,0x765966e9,0x7c2166ea,0xe8dc01f2}},	//   bak_, mety, kaor, shụa_, 
   {{0x442166eb,0x753966ec,0x765966ed,0x61e80118}},	//   cak_, mutz, lety, ýdla, 
   {{0x63041c62,0x7c2166ee,0xf3fc0798,0x386553a2}},	// [24f70] _كويل, daor, ldão_, _maor_, 
   {{0x765966ef,0xaef801c3,0x37dc0154,0x2cbc007c}},	//   nety, _brùr, _ডলার, _sjud_, 
   {{0x753809f0,0xf3fc0120,0xaef8026c,0x3f90022f}},	//   nutz, ndão_, _prùs, ayyu_, 
   {{0x765966f0,0x7c2060bd,0xcb9800d1,0x6c0000f7}},	//   hety, gaor, يناش_, ركتۅ, 
   {{0x753966f1,0x680000d2,0x765966f2,0x04b4010f}},	//   hutz, _líjó, kety, וּסט_, 
   {{0x44209d23,0x20f80053,0x753801c6,0x9a243b5f}},	//   zak_, _hōia_, kutz, ىعىن, 
   {{0x44202d9e,0x20f966f3,0x9a24868d,0x7c2001c4}},	//   yak_, _kōia_, رعون, baor, 
   {{0x3a7024ce,0x44212316,0x386566f4,0x2cbd66f5}},	//   еләр, xak_, _caor_, _ujud_, 
   {{0x765966f6,0x4420a148,0x386437a8,0x78600026}},	//   fety, vak_, _daor_, ткыз, 
   {{0x442166f7,0x765966f8,0x20f80618,0x00000000}},	//   wak_, gety, _lōia_, --, 
   {{0x442166f9,0x753805f5,0x386400a3,0xbb380150}},	//   tak_, gutz, _faor_, _ﺒﺤﻕ_, 
   {{0x442001c0,0x58843e1f,0xe1f8013e,0xd7c80451}},	//   uak_, _пыча, ӯҳи_, _کوهه_, 
   {{0x442166fa,0xb38012a2,0x765966fb,0x229400a2}},	//   rak_, влял, bety, _häki_, 
   {{0x7658004b,0xf2dc0a85,0x6d440784,0x7c2006d9}},	//   cety, stân_, _oqja, zaor, 
   {{0x7c2166fc,0xaca0001e,0x649800e4,0x2d4400c5}},	//   yaor, _chừn, _hãim, jõe_, 
   {{0x98a056c0,0x44200429,0x22940108,0x42e801f0}},	//   čić_, qak_, _mäki_, смҳо_, 
   {{0x6d440227,0x7c2166fd,0x248401a8,0x673966fe}},	// [24f80] _aqja, vaor, ömmu_, nuuj, 
   {{0x7c20063f,0xafe001d5,0x00000000,0x00000000}},	//   waor, тоул, --, --, 
   {{0x7c2166ff,0x2294005b,0x00e4013e,0xc0bc0023}},	//   taor, _näki_, _ожон, ተበለ_, 
   {{0x6738013c,0x765806d9,0x6d40002e,0xfd3001e1}},	//   kuuj, zety, ànaa, _òsíẹ, 
   {{0x7c216700,0xfaa56701,0x26c039ae,0x67396702}},	//   raor, мадо, čjoj_, juuj, 
   {{0x38647e9f,0x7c216703,0x75380356,0xd14800f2}},	//   _saor_, saor, yutz, _بشین_, 
   {{0x7c216704,0x81bc045e,0x76596705,0x58d56706}},	//   paor, েধক_, vety, нокт, 
   {{0x7658bdcf,0x22940432,0x7d0c02d0,0xf728009d}},	//   wety, _däki_, _itbs, оцой_, 
   {{0x76596707,0x67380194,0x6560035a,0x2900020c}},	//   tety, guuj, _asnh, _éjan_, 
   {{0x75391701,0xd050013f,0x7658017a,0x64456708}},	//   tutz, _ɛfɑt, uety, _acii, 
   {{0x598c0092,0x00000000,0x00000000,0x00000000}},	//   ንጫፎች_, --, --, --, 
   {{0x765815fa,0x753805f5,0xf3fc06ed,0x6444003a}},	//   sety, rutz, rdão_, _ccii, 
   {{0x76596709,0x7538009d,0x2294008e,0x16340153}},	//   pety, sutz, _zäki_, _зеля, 
   {{0x20f804fe,0x22940724,0x7539670a,0xaca00051}},	//   _rōia_, _yäki_, putz, _phừn, 
   {{0x95b48dcb,0x7d0c02d0,0xe6380375,0xddd400ee}},	//   _ярдә, _ntbs, _ותוכ, _ýaňl, 
   {{0x248401c7,0x9f4c0248,0x00000000,0x00000000}},	//   ömmt_, _ńdá_, --, --, 
   {{0xe3b0511e,0x00000000,0x00000000,0x00000000}},	// [24f90] _پري_, --, --, --, 
   {{0xaca0004d,0x00000000,0x00000000,0x00000000}},	//   _thừn, --, --, --, 
   {{0xaef801e1,0xb144035c,0x8c1800d1,0x6cd40150}},	//   _erùp, _تیزم_, كيار_, _ﺘﻌﺭﻴ, 
   {{0xd064013f,0x20f80374,0x64449658,0x00000000}},	//   _ɔpɛn, _tōia_, _xcii, --, 
   {{0xaef800a3,0xf09c01e1,0xc0c00352,0x00000000}},	//   _grùp, _ilà_, _сәри, --, 
   {{0x2d4406ed,0x649800e4,0x2d8403cd,0x2294010e}},	//   põe_, _rãim, ønes_, _päki_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe3b80bcc,0x59740228,0x6739670b,0x2294005b}},	//   ğız_, тышу, tuuj, _väki_, 
   {{0x644401ab,0xaca00051,0xe3b803e0,0x00000000}},	//   _rcii, _nhứn, şız_, --, 
   {{0x45842e58,0x644400c8,0xd9b00131,0x67380009}},	//   егов, _scii, _ھەيد, ruuj, 
   {{0x04455b82,0xd9b00075,0x67380869,0x481402d5}},	//   ненн, _پەيد, suuj, _змес, 
   {{0xf2dc002d,0x03a4014b,0x00000000,0x00000000}},	//   stâl_, еимо, --, --, 
   {{0xaca007ae,0xccf8012d,0x85b800f2,0x00000000}},	//   _chứn, _miś_, تاکس_, --, 
   {{0xf09c0ba1,0x3f9c0421,0xf74000a7,0x38b800e2}},	//   _alà_, _ātu_, _сешо, vīri_, 
   {{0xf09ce775,0x6f0c02d0,0x5bdc0073,0x00000000}},	//   _blà_, _atcc, _बर्व, --, 
   {{0xf09c07c5,0xf41c023a,0x20e80e78,0xccf800b8}},	//   _clà_, ljän_, ißig_, _niś_, 
   {{0x6d400e89,0x09bc03d4,0x6d1c002b,0x4374011c}},	// [24fa0] ànan, েইটা, _āliṅ, _чуйт, 
   {{0xf09d670c,0x00000000,0x00000000,0x00000000}},	//   _elà_, --, --, --, 
   {{0xf09c05d5,0x8e24030d,0x39500210,0xfd1000ae}},	//   _flà_, _гlо_, łysz_, اجئ_, 
   {{0xac05670d,0x0ca80597,0xaef800a3,0xf41c005b}},	//   енца_, وطني_, _trùp, hjän_, 
   {{0xeb941de1,0x98fc01e4,0x2d8408cb,0x7cf800bc}},	//   ниц_, _arĉp, øner_, _důra, 
   {{0x195809a5,0xbe140150,0xd910072d,0x00000000}},	//   дакы_, _سورع, لیط_, --, 
   {{0x6729670e,0xed5400c9,0xdc3400d0,0x00000000}},	//   _avgj, _пор_, lúči, --, 
   {{0x1754013e,0x00000000,0x00000000,0x00000000}},	//   ввия, --, --, --, 
   {{0x8b640a11,0x3de000eb,0x00000000,0x00000000}},	//   _لالم, _বলিল, --, --, 
   {{0x675000c6,0x3b040455,0x55740212,0x75e0010b}},	//   اخير, mqoq_, вгот, ләйҗ, 
   {{0x7af93861,0x3b04047e,0x6728036e,0xb7d80066}},	//   _iitt, lqoq_, _evgj, _کوشا_, 
   {{0x7af94abb,0x7790034c,0x229400b0,0x6904008e}},	//   _hitt, _میبا, _mäku_, _kıen, 
   {{0x7af9670f,0xb354208f,0xdc340306,0x69040139}},	//   _kitt, ریدا_, júči, _jıen, 
   {{0x7af8ce13,0xd04c1c5c,0xf09c01ab,0x7d300023}},	//   _jitt, ﺭﺗﯩﭗ_, _slà_, _ኣውጺኦ, 
   {{0x7af96710,0xf09c00db,0x3b04047e,0x00000000}},	//   _mitt, _plà_, hqoq_, --, 
   {{0x7af96711,0x7bdc068f,0x2d9c02b1,0xb0580432}},	//   _litt, ępuj, _āue_, _ejän, 
   {{0x9f34005e,0x68380793,0x3b040455,0x7af801f4}},	// [24fb0] леті, lädü, jqoq_, _oitt, 
   {{0x7af96712,0xaee0005e,0x3b04014f,0x8f5401d5}},	//   _nitt, اۋسى, dqoq_, _ینجش, 
   {{0x683801b8,0xc0dc0023,0x00000000,0x00000000}},	//   nädü, ቒሎም_, --, --, 
   {{0x7af96713,0xa3e800af,0xdc340419,0x00000000}},	//   _aitt, _भरम_, búči, --, 
   {{0x7af96714,0x69040724,0x5fe56715,0xf41c023a}},	//   _bitt, _cıen, _бірж, yjän_, 
   {{0x7af96716,0x00000000,0x00000000,0x00000000}},	//   _citt, --, --, --, 
   {{0x7af87897,0x98ac03e3,0xfaa021d7,0x00000000}},	//   _ditt, _asdı_, ращо, --, 
   {{0x7af800fc,0x3b04014f,0x00000000,0x00000000}},	//   _eitt, bqoq_, --, --, 
   {{0x07a4d17b,0x46e8425b,0x7af847a3,0x2b480de2}},	//   тапн, мдин_, _fitt, _ëcc_, 
   {{0x7af96717,0x68380793,0x44240064,0xa3e8000d}},	//   _gitt, fädü, _žo_, _भरब_, 
   {{0x9aa400dd,0x49040150,0xf41c01f4,0x00000000}},	//   _حملو, _شوشق, rjän_, --, 
   {{0x7af96718,0x229401e3,0x473400d8,0x04940006}},	//   _zitt, _läkt_, _андс, троў, 
   {{0x7af8fa88,0x29040327,0x00000000,0x00000000}},	//   _yitt, lqna_, --, --, 
   {{0x9f4c00d5,0x7af80067,0xa5e402dd,0xa504215c}},	//   _éléh_, _xitt, _كوشە_, _كىتە_, 
   {{0xaca0431d,0xef1c025a,0x29040327,0x00000000}},	//   _nhữn, _awü_, nqna_, --, 
   {{0x01640107,0x3b04014f,0x442402d2,0xdc3400d7}},	//   нкҳо, yqoq_, _þo_, túči, 
   {{0xb0580628,0x44300198,0x42c800d8,0x00000000}},	// [24fc0] _tjän, _idy_, _огин_, --, 
   {{0xb0580628,0xee34f3a6,0xdc3400d0,0x3b040455}},	//   _hjäl, кну_, rúči, vqoq_, 
   {{0x44300316,0xaca0004d,0x6904013d,0x3b040455}},	//   _kdy_, _chữn, _sıen, wqoq_, 
   {{0x3b0431c5,0xff244c87,0x00000000,0x00000000}},	//   tqoq_, _иммо, --, --, 
   {{0xef156719,0xb05801e6,0x7af9671a,0x29040327}},	//   _имя_, _mjäl, _pitt, eqna_, 
   {{0x629d671b,0x7af9671c,0x8fd40032,0x2ebc00dc}},	//   nkro, _qitt, _сәсә, ्वृत, 
   {{0x4430dda0,0x3b040113,0x629c0254,0x5db000fe}},	//   _ody_, sqoq_, ikro, _জুৰু, 
   {{0xfce4090b,0x4431671d,0x6cb1671e,0x629d3e07}},	//   _робо, _ndy_, _көчт, hkro, 
   {{0x7af9671f,0x29042878,0x8b0403f9,0x629c33b8}},	//   _titt, aqna_, ƙƙar, kkro, 
   {{0x44316720,0x7af96721,0xed4c0014,0x38b800e2}},	//   _ady_, _uitt, _دپہ_, vīru_, 
   {{0x2294007d,0x629c0ebd,0xe9440517,0x69040139}},	//   _läks_, dkro, _لرنی, _jıel, 
   {{0xb9fc02d3,0x629c017a,0x7cf801ef,0x00000000}},	//   _ዂሉ_, ekro, _můro, --, 
   {{0x78a16722,0xa3e8098a,0x44300042,0xd9e801f9}},	//   _ilov, _भरण_, _ddy_, _ओरडत_, 
   {{0x44316723,0x78a16724,0xb37c02d3,0x629c4cab}},	//   _edy_, _hlov, _ንኸውን_, gkro, 
   {{0xe2f8eeec,0xb05801e6,0xd9f44728,0xf2dc054e}},	//   тері_, _fjäl, ेखित_, ntâi_, 
   {{0x44316725,0x629d6726,0x78a000b5,0xa0a419d8}},	//   _gdy_, akro, _jlov, ашул, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [24fd0] --, --, --, --, 
   {{0xa3e810f7,0x78a16727,0x69040724,0x1cb0025c}},	//   _भरत_, _llov, _bıel, ྒྲལ_, 
   {{0x78a16728,0xe3b06b5d,0x69040724,0x443000a9}},	//   _olov, _هری_, _cıel, _ydy_, 
   {{0x6ac800dc,0xc32c0133,0x00000000,0x00000000}},	//   िव्र, _بڕێ_, --, --, 
   {{0x7538002f,0x00000000,0x00000000,0x00000000}},	//   hrtz, --, --, --, 
   {{0x81e40183,0x78a16729,0x38b800e2,0x31340023}},	//   _ফলত_, _alov, kīrs_, _ኤርትር, 
   {{0x78a0010f,0xaf840032,0x00000000,0x00000000}},	//   _blov, _яҡҡа_, --, --, 
   {{0x78a1672a,0xb05801e6,0x629c0306,0x056408ca}},	//   _clov, _ojäm, zkro, ҳвон, 
   {{0x78a000d2,0x629d672b,0x91e8009e,0x443000a2}},	//   _dlov, ykro, পশিখ, _rdy_, 
   {{0xb0580628,0x78a11fe6,0x629c007c,0x38b80171}},	//   _själ, _elov, xkro, fīrs_, 
   {{0x78a1672c,0xe7340014,0x29040327,0xf41c013d}},	//   _flov, رتکچ_, qqna_, lkäy_, 
   {{0x629c0649,0x4430003a,0x78a0c606,0x79b402e4}},	//   wkro, _qdy_, _glov, _גלעד_, 
   {{0x629c07f5,0x753855f2,0xaca00208,0x00000000}},	//   tkro, artz, _nhửn, --, 
   {{0x2d702375,0x78a09041,0x2ebc1df0,0x67380115}},	//   _oće_, _zlov, ्वोत, mruj, 
   {{0x4431672d,0x2ebc043e,0x78a001a9,0xb05801e3}},	//   _tdy_, ्वैत, _ylov, _tjäl, 
   {{0x629d672e,0x673820ac,0x41d0194b,0x00000000}},	//   skro, oruj, _दुःस, --, 
   {{0x2481672f,0xbd8804fb,0x3fe4b576,0x25a405d9}},	// [24fe0] _inim_, کنان_, ужав, _سگھي_, 
   {{0x673805b1,0x7410028e,0x0fe800d1,0xe81021f2}},	//   iruj, _پویا, тлуқ_, णुता_, 
   {{0x38b801e1,0x3fc403e6,0x00000000,0x00000000}},	//   _jàrè_, _ڵگری_, --, --, 
   {{0xa3e831a0,0xb5a8002e,0x6738cc18,0x69040166}},	//   _भरा_, _k斡ra, kruj, _cıem, 
   {{0x60c56730,0xfbd00137,0x67380115,0x81e400cc}},	//   mnim, حتا_, jruj, _ফলি_, 
   {{0x78a16731,0xf9680262,0x60c56732,0x673810b3}},	//   _slov, ерий_, lnim, druj, 
   {{0x2480d601,0xaa8412b7,0x6738f4b3,0xd948010b}},	//   _onim_, انىم_, eruj, тҗек_, 
   {{0x8d7c0020,0x24800134,0xcdc40220,0xa8a064c2}},	//   _የሚባል_, _nnim_, _тасқ, йрык, 
   {{0xe9d5213e,0x60c56733,0xec1000dd,0x38b96734}},	//   ккә_, inim, _چوہد, _aàrè_, 
   {{0x24816735,0x7e6c0175,0x8c3c008e,0x00000000}},	//   _anim_, _jabp, _ilşa, --, 
   {{0x7e6c01ee,0x673820ac,0x60c56736,0x67d004a9}},	//   _mabp, aruj, knim, _қошу, 
   {{0x24800393,0x60c56737,0x81e802f5,0x13f402bf}},	//   _cnim_, jnim, যশা_, изня, 
   {{0x60c56738,0x3eb86ead,0xf77000db,0x6ee884bf}},	//   dnim, kipt_, _داا_, lübe, 
   {{0x24816739,0x60c4102c,0x3eb802d3,0x81b402f5}},	//   _enim_, enim, jipt_, _জড়_, 
   {{0x6ee9673a,0x30e80861,0x60c5673b,0x38b80241}},	//   nübe, ефан_, fnim, _gàrè_, 
   {{0x60c5673c,0xdef80184,0x248000b8,0xfdbc00fe}},	//   gnim, ғыу_, _gnim_, _অৰ্ড, 
   {{0xe4505368,0xc3c0104e,0x3eb8054e,0x6ee8002f}},	// [24ff0] _رضي_, _дөрл, fipt_, hübe, 
   {{0x60c5673d,0xceb80cef,0x3eb9673e,0x64480006}},	//   anim, тәм_, gipt_, ėdie, 
   {{0x60c5673f,0x8c3cd394,0x2480022e,0x00000000}},	//   bnim, _alşa, _ynim_, --, 
   {{0x60c56740,0x6ee8002f,0x67396741,0xe7f40118}},	//   cnim, dübe, yruj, ँधमा_, 
   {{0xcb68a710,0xdd940032,0xdddc002b,0xe6840023}},	//   тале_, _һары, _karś, _ንገብሮ_, 
   {{0xadf00124,0x9c440124,0xdb140432,0xfaa0004e}},	//   _гогә, ахәл, _ýaýk, жашо, 
   {{0xdd956742,0x8c3c0213,0x6ee8002f,0x00000000}},	//   _лары, _elşa, gübe, --, 
   {{0x38b85c07,0x67396743,0x6e256744,0xf8ac0244}},	//   tūra_, truj, _hejb, وکن_, 
   {{0x9cc96745,0x6e240135,0x69040139,0x8af833be}},	//   _сыра_, _kejb, _kıek, _анас_, 
   {{0xe8dc063f,0x60c409a8,0x6e24014f,0x67396746}},	//   _idọm_, znim, _jejb, rruj, 
   {{0x612c067d,0x60c56747,0x6e24d02d,0x69040139}},	//   _እግዚኣ, ynim, _mejb, _mıek, 
   {{0x60c401d9,0x04446215,0xb058007c,0xe7fc11d7}},	//   xnim, шемн, _djäk, _उलटा_, 
   {{0x60c56748,0xd17401e0,0x6440004e,0xc0d80023}},	//   vnim, ҙыры, òmiq, _ኮረሻ_, 
   {{0xd05c01e4,0x6e256749,0x60c40463,0x00000000}},	//   _hisɨ, _nejb, wnim, --, 
   {{0xdddc0a28,0x60c41fe6,0x76b80375,0x9f4401e1}},	//   _darś, tnim, _במספ, _àmú_, 
   {{0x60c5674a,0x80641b88,0xb5a8002e,0x2481674b}},	//   unim, јваж, _t斡ra, _unim_, 
  
   {{0x6e25674c,0x7e6c014f,0x3eb801a4,0xd9480240}},	// [25000] _bejb, _pabp, tipt_, _ዘይትን, 
   {{0x8d7c0020,0xdddc012d,0xb9cc1ef7,0x00000000}},	//   _የሚችል_, _garś, _ሴፍ_, --, 
   {{0x3eb9674d,0x6e240455,0x60c40427,0xc0e402d5}},	//   ript_, _dejb, pnim, _вонк, 
   {{0x30240228,0x60c5674e,0x3178010f,0xb6080220}},	//   _коюп_, qnim, _סאכד, _ﺳﯟ_, 
   {{0xfca80050,0x7e6c030d,0x80e00073,0x6e2401d3}},	//   _یارو_, _tabp, पतीं, _fejb, 
   {{0x6ee80112,0xe520010e,0xbbc415e0,0x7cf801ef}},	//   tübe, _söýş, _वशीक, _kůrk, 
   {{0xd9101550,0x2d840821,0x00000000,0x00000000}},	//   سیش_, änet_, --, --, 
   {{0x6ee83b45,0xfb14a012,0x00000000,0x00000000}},	//   rübe, _نورج, --, --, 
   {{0x6ee803fa,0x3b0800c7,0x05a00240,0x00000000}},	//   sübe, _резо_, _ዝመረጾ_, --, 
   {{0xdca4023b,0x00000000,0x00000000,0x00000000}},	//   _тағи, --, --, --, 
   {{0xaa0800e5,0xaadc012d,0x00000000,0x00000000}},	//   _شعلے_, _पीटक, --, --, 
   {{0x395c2a1f,0x6d400e89,0x86440022,0x00000000}},	//   _ipts_, ànai, аҟәа_, --, 
   {{0xdddc0055,0xdb20013d,0x32b8007b,0x00000000}},	//   _parś, _ütäd, ندسة_, --, 
   {{0xdddc0135,0x656c0ced,0x9f4401e1,0x00000000}},	//   _borż, łcha, _àmù_, --, 
   {{0x644030cf,0xa504009b,0x00000000,0x00000000}},	//   ómic, _кеја_, --, --, 
   {{0xd2500502,0x6e240135,0x16840133,0x8d7c0092}},	//   _کند_, _sejb, _خاڵێ, _የሚቻል_, 
   {{0xdb4403e6,0x6e240455,0x00000000,0x00000000}},	// [25010] _تێ_, _pejb, --, --, 
   {{0xd90400aa,0xdddc031c,0x395c3c36,0x00000000}},	//   _يی_, _forż, _opts_, --, 
   {{0xdef9674f,0x6e240726,0x00000000,0x00000000}},	//   рыт_, _vejb, --, --, 
   {{0x6e24014f,0xf0743c1a,0xce54ba15,0xa158004e}},	//   _wejb, _тимә_, _گھرب, _таюу_, 
   {{0x395c0076,0xeaf400d1,0x6f84004e,0x6e2483e4}},	//   _apts_, аддә_, _тунж, _tejb, 
   {{0xd05c01e4,0xd1bc0092,0x30740166,0x2d840037}},	//   _sisɨ, _ታይቶ_, _суүс, änes_, 
   {{0xf2dc003a,0xe5080950,0x2d8401bf,0xda64007b}},	//   ltâs_, _संधि_, åned_, زاوي, 
   {{0xdddc0115,0xa3e8007d,0x8de801af,0xea6000e5}},	//   _jarŝ, _भरल_, _афға_, _ڈپری, 
   {{0xdddc008f,0x3a8401d9,0xaa6400d4,0x00000000}},	//   _marŝ, _گُلہ, _втек, --, 
   {{0x9a842c1d,0x3f78008f,0x8a840014,0x97c41884}},	//   _мухл, אָטע, _چھژِ_, تتىم, 
   {{0x427002d3,0xd99801e2,0x5a0c00df,0x00000000}},	//   _ብምኻድ_, _پخلا_, _סלאַ, --, 
   {{0x443c0639,0xf41c006a,0xd87424e0,0x00000000}},	//   ßt_, gbä_, _وانب, --, 
   {{0x78700014,0x00000000,0x00000000,0x00000000}},	//   _رُوا, --, --, --, 
   {{0x461407d6,0x88a800eb,0x00000000,0x00000000}},	//   _اوغر, _ওদিক, --, --, 
   {{0x66800ec9,0x7ce800e4,0x41d005dc,0x71a0004e}},	//   _هیکل, hýra, _दुखस, парз, 
   {{0xb9dc07db,0xc0052d06,0x0368013d,0x7fd401ec}},	//   _እዚ_, спак, _биик_, бізі, 
   {{0x7f4800c6,0x7ce80022,0xe50800c5,0x42d400c0}},	// [25020] طلاق_, jýra, _सूति_, _гіну, 
   {{0x7ce801a8,0x00000000,0x00000000,0x00000000}},	//   dýra, --, --, --, 
   {{0x2b5c0311,0xf278010f,0x00000000,0x00000000}},	//   _apuc_, _ערטש, --, --, 
   {{0x395c0077,0x3b84021f,0xf2dc0165,0x6ee8002f}},	//   _rpts_, йлег, stât_, tübc, 
   {{0x395c0ac5,0x0f34084c,0xeb8c01f7,0x00000000}},	//   _spts_, _мэря, فظو_, --, 
   {{0xdce86f38,0x4278008f,0x00000000,0x00000000}},	//   ılır, ראַג, --, --, 
   {{0xfce53774,0x00000000,0x00000000,0x00000000}},	//   _гово, --, --, --, 
   {{0xbea4013e,0x9714549f,0x98b80171,0x6cc0022e}},	//   _таҳк, омиц, _īrē_, _ейса, 
   {{0xb4f001c0,0xf6280212,0x57b42077,0x4c340006}},	//   үүлч, ліни_, юбит, _фэст, 
   {{0xed4c00f8,0x6b780375,0x38a800a3,0xdb14010e}},	//   _تھے_, _גרמנ, _sùrd_, _ýañk, 
   {{0xe7340fab,0x2fc4001e,0xca2401ec,0x83e402dd}},	//   _ҳеч_, ̃ng_, _بۋىن_, _ﺍﺭﺍﻳ, 
   {{0xb4d0000d,0xf744011c,0x00000000,0x00000000}},	//   ववे_, _гедо, --, --, 
   {{0x163507e2,0x1cb0025c,0xe734030d,0x6750007b}},	//   _деля, ྒྲག_, _геч_, _فخور, 
   {{0xa63002dd,0x6ee8000d,0x00000000,0x00000000}},	//   _енші, küba, --, --, 
   {{0x30a56750,0xa6c400db,0xee840124,0x00000000}},	//   брав, _دوول_, ҩызо, --, 
   {{0x90540006,0x00000000,0x00000000,0x00000000}},	//   ўвац, --, --, --, 
   {{0xdddc0115,0x649800e4,0x00000000,0x00000000}},	// [25030] _varŝ, _tãir, --, --, 
   {{0x2aa8019b,0xdef82ecc,0xd250e1de,0x2fc40016}},	//   _købe_, бых_, _کنگ_, ăng_, 
   {{0x8c196751,0xdddc01e4,0xaca0063f,0x6ce40150}},	//   ليار_, _tarŝ, swọd, біде, 
   {{0x7ce96752,0x00000000,0x00000000,0x00000000}},	//   týra, --, --, --, 
   {{0x2aa804ce,0x00000000,0x00000000,0x00000000}},	//   _løbe_, --, --, --, 
   {{0x8afc0118,0x7ce80022,0x74cc00eb,0x00000000}},	//   _opře, rýra, রতিউ, --, 
   {{0x9d188ed9,0x59a40034,0xb0580267,0x60e802d2}},	//   _гост_, गैलर, _djäv, _ármó, 
   {{0x98bc00e2,0x7ce800e4,0x00000000,0x00000000}},	//   tuvā_, pýra, --, --, 
   {{0xdddc0e42,0xfbb407f7,0x00000000,0x00000000}},	//   _karş, _आइएम, --, --, 
   {{0x8698170a,0xb91001e1,0xe818000d,0x00000000}},	//   ртит_, _jabọ_, _नभवा_, --, 
   {{0xaca0001e,0xc4c801a9,0x00000000,0x00000000}},	//   _chủn, илож_, --, --, 
   {{0xdb500a81,0x2aa801bf,0x00000000,0x00000000}},	//   _تَے_, _døbe_, --, --, 
   {{0x981406c2,0x248403e0,0x00000000,0x00000000}},	//   _ربنا, ımm_, --, --, 
   {{0xd7f801c0,0x00000000,0x00000000,0x00000000}},	//   _уух_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00e41cd0,0x00000000,0x00000000,0x00000000}},	//   іжан, --, --, --, 
   {{0xdddc0209,0xafe0013d,0x8afc013a,0x63c401af}},	// [25040] _barş, дотл, _zpře, _хапҡ, 
   {{0xae840137,0x453c0092,0x442000c0,0x00000000}},	//   обуз_, _በሰንበ, lbk_, --, 
   {{0x2d8400fd,0xd3c40150,0x00000000,0x00000000}},	//   änep_, _وتۋى, --, --, 
   {{0x6ee80086,0xb058007c,0x7be400d4,0x44216753}},	//   rüba, _sjäv, ожеж, nbk_, 
   {{0x1cb0031c,0xdddc0139,0xcee80014,0x00000000}},	//   ྒྲཊ_, _farş, _گرَن_, --, 
   {{0xdddc09a5,0xf41c0108,0x00000000,0x00000000}},	//   _garş, ljät_, --, --, 
   {{0x6d4001ab,0xf608036b,0xee340108,0x00000000}},	//   ànat, یتده_, _фнс_, --, 
   {{0x7d1c003e,0x44200175,0x2aa801bf,0x98bc0356}},	//   mpps, jbk_, _røbe_, duvă_, 
   {{0x7c216754,0xdb24424b,0xb86401ed,0x1b14009e}},	//   mbor, _روای, ماکو, _ঠিকে_, 
   {{0x3ce4008e,0x6440041e,0x7d1c08fb,0xab60010b}},	//   llov_, ómin, opps, _ювул, 
   {{0xddd400a2,0xb9c493fc,0xa3e8000d,0x00000000}},	//   _ýańl, _بقاي, _भरउ_, --, 
   {{0x7c216755,0x3ce4036b,0x8afc00bc,0x281000cf}},	//   nbor, nlov_, _vpře, _قومس, 
   {{0x3ce56756,0x00000000,0x00000000,0x00000000}},	//   ilov_, --, --, --, 
   {{0xaca16757,0x3ce401b9,0x00000000,0x00000000}},	//   _ihụn, hlov_, --, --, 
   {{0x3ce56758,0x7c20dfad,0x8afc00bc,0x3c20022e}},	//   klov_, kbor, _upře, _oаv_, 
   {{0x77600076,0x3ce49ae3,0x61e80037,0x76580af9}},	//   _kpox, jlov_, üdla, lfty, 
   {{0x7c216759,0x3ce5675a,0xb4e403e5,0x8c4400ee}},	// [25050] dbor, dlov_, भती_, җеле, 
   {{0xdddd675b,0xf3fc0120,0x3ce40419,0x00000000}},	//   _qarş, leão_, elov_, --, 
   {{0xdddd675c,0x7c21675d,0x88d000cc,0x7ce84158}},	//   _varş, fbor, াততক, rýrn, 
   {{0x7c21675e,0x408401d9,0x776002d0,0x8c3c03e0}},	//   gbor, _ٹھِپ_, _opox, _ilşk, 
   {{0x92bc00fe,0xf41c005b,0x00000000,0x00000000}},	//   ইকী_, ljäs_, --, --, 
   {{0x7c200810,0x3ce40427,0x00000000,0x00000000}},	//   abor, alov_, --, --, 
   {{0x7c207e54,0x77600005,0x3ce5675f,0x6d416760}},	//   bbor, _apox, blov_, ánad, 
   {{0x6d540218,0x76580af9,0x2a64003a,0x088801b9}},	//   mtxa, efty, senb_, сбий_, 
   {{0x9b450f5e,0x6d5401c4,0xf3fc00d8,0xb058007c}},	//   _ينفو, ltxa, deão_, _hjäs, 
   {{0x29840166,0x02b80037,0x00000000,0x00000000}},	//   _мыег, _उगेन, --, --, 
   {{0xf6b40135,0x6d5401c0,0x442001c4,0xf41c005b}},	//   ྒྲེང, ntxa, tbk_, yjät_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3550004b,0x44200153,0x00000000,0x00000000}},	//   ونیز, rbk_, --, --, 
   {{0x426c02d3,0xb7780375,0x412806d4,0xd7c80244}},	//   _ትምኒት_, _לאנש, його_, _بوهه_, 
   {{0xd178090b,0x3ce407d6,0x1cb00135,0x6d540218}},	//   ості_, ylov_, ྒྲཌ_, jtxa, 
   {{0x7c20ca01,0x7ce802fb,0x7760035a,0x04c801e2}},	//   xbor, výro, _ypox, _دوبي_, 
   {{0x9f594967,0x3ce56761,0x7c216762,0x03a8004b}},	// [25060] _özüm_, vlov_, vbor, _ددغو_, 
   {{0xb05801e3,0x42e8084c,0x7c201bb3,0x80b803d4}},	//   _sjät, _ымпо_, wbor, _আৱশ্, 
   {{0x81e42baf,0x6e901532,0x72980375,0xc0e400f7}},	//   _ফলক_, علما, _הסיס, _ноок, 
   {{0xedd005d9,0x6ee80793,0x7f5406af,0xf41c01e3}},	//   ريند, lübl, ptyq, ljär_, 
   {{0x3ce56763,0x2ba024cb,0x6d540051,0xef8000c0}},	//   rlov_, _nīcā_, atxa, _зляп, 
   {{0x3ce466dc,0x6d540218,0x65600036,0xf41c01e3}},	//   slov_, btxa, _opnh, njär_, 
   {{0x3ce408ad,0x58d56764,0x3e800166,0x1cbc031c}},	//   plov_, мокт, _eçtä_, ཅོད_, 
   {{0xb05804f3,0xaca001fb,0x6d540a7c,0x9f440ca8}},	//   _hjär, _phụn, _מילף_, _àmó_, 
   {{0x7d0d6765,0xc61c015b,0xeb940022,0xf60801d5}},	//   _hubs, _দয়া_, _еит_, یتگه_, 
   {{0x38a808e7,0xc7b801d3,0x95383cb4,0x36880354}},	//   _dùra_, mből_, озот_, ссин_, 
   {{0x94d42850,0x7d0c00e8,0xaa406eec,0xb058007c}},	//   донц, _jubs, _чехл, _mjär, 
   {{0xb4e40b7c,0x998c00ef,0xaca00208,0x00000000}},	//   भते_, _ledū_, _thụn, --, 
   {{0x7d0c91a7,0x66100790,0xc7b800e5,0x877000fb}},	//   _lubs, çekç, nből_, _ағыш, 
   {{0x91c40d52,0xc7b800e5,0x00000000,0x00000000}},	//   дәмл, iből_, --, --, 
   {{0x7d0cca7e,0x8d9c001f,0xe8107220,0x00000000}},	//   _nubs, ለክተው_, णुका_, --, 
   {{0xc7b801ed,0x6d540218,0x921c0034,0x92bc0eac}},	//   kből_, vtxa, _ब्रज_, ইকে_, 
   {{0xb0580267,0x91780051,0x00000000,0x00000000}},	// [25070] _bjär, _bậc_, --, --, 
   {{0x7d0c01a6,0x6ee80213,0xb0596766,0xed8800ee}},	//   _bubs, cübl, _pjäs, йсек_, 
   {{0x9f05041c,0xa1841cd1,0x2294005b,0xb05801e3}},	//   رومو, _зыял, _näky_, _djär, 
   {{0x6d5405f5,0x6ee8014a,0x00000000,0x00000000}},	//   rtxa, pübo, --, --, 
   {{0xb058049f,0xcaf403e6,0xc7b801d3,0x6d5401a9}},	//   _fjär, وستب, gből_, stxa, 
   {{0xa1340133,0xef1c002f,0x09e4a2b6,0x00000000}},	//   _تریش, _prüf_, молн, --, 
   {{0x7d0c020b,0x6f0c198f,0x9f440248,0xfd54014b}},	//   _gubs, _hucc, _àmò_, _онрӯ, 
   {{0x6f0caf62,0x00000000,0x00000000,0x00000000}},	//   _kucc, --, --, --, 
   {{0x7d0c009f,0x69040139,0x4a54010b,0x6f040055}},	//   _zubs, _cıer, _окас, _kijc, 
   {{0x6f0d6767,0x6f04014f,0xef1c0205,0x969401f4}},	//   _mucc, _jijc, _trüf_, ерюш, 
   {{0x044500fc,0x6f0d6768,0x8c3c0139,0x00000000}},	//   менн, _lucc, _alşi, --, 
   {{0x6f0489fd,0x98bc02d5,0x79e80014,0x00000000}},	//   _lijc, tuvą_, _بومہ_, --, 
   {{0xfd4c0084,0x6f0d6769,0x58040150,0xd6a801b9}},	//   _dzoṱ, _nucc, _كومك, زدیم_, 
   {{0x68f9676a,0x56940139,0x00000000,0x00000000}},	//   lmud, _пачт, --, --, 
   {{0x81e403f4,0x6f0cf998,0xc7b801d3,0xc0e400f5}},	//   বেন_, _aucc, zből_, довк, 
   {{0x6f0d676b,0x68f80c67,0x7d0c01e4,0xc7b801d3}},	//   _bucc, nmud, _rubs, yből_, 
   {{0x6f0d676c,0x6f040477,0x63a001e6,0x68f82ec1}},	// [25080] _cucc, _bijc, ämnd, imud, 
   {{0x6f0d676d,0x68f9676e,0x38b802b1,0xc7b800e5}},	//   _ducc, hmud, rūri_, vből_, 
   {{0xed540323,0x6f040399,0x7d0c0ba7,0xb0580139}},	//   дох_, _dijc, _qubs, _smäe, 
   {{0x7fd40046,0x6f04003a,0x6f0d676f,0xc7b801ed}},	//   _жігі, _eijc, _fucc, tből_, 
   {{0x6f0d6770,0x60c49c81,0x38a801c3,0xb05833da}},	//   _gucc, miim, _bùrn_, _tjär, 
   {{0x60c56771,0x6d400597,0x7d0cdbb7,0x2cbc003e}},	//   liim, ánac, _tubs, _emud_, 
   {{0x6f0d6772,0xed5430af,0xc7b801d3,0x6d48012d}},	//   _zucc, _оор_, sből_, ągac, 
   {{0x60c56773,0x6f0c04ce,0x3f80abea,0x690400fd}},	//   niim, _yucc, _krku_, _sıer, 
   {{0xec100150,0x6f0c0548,0x9f580139,0xdb2401e1}},	//   _شولد, _xucc, _äzäl_, _àsàw, 
   {{0x60c56774,0x68f82f0f,0x69a80e49,0x3f80013a}},	//   hiim, amud, जनशी, _mrku_, 
   {{0x60c56775,0x3a3c00d8,0x75880150,0x00000000}},	//   kiim, _idtp_, ісов_, --, 
   {{0x3f801f60,0x60c56776,0x7ce803f2,0xbb281870}},	//   _orku_, jiim, dýrk, ﻣﮕﻪ_, 
   {{0x60c56777,0x4a0000c7,0x00000000,0x00000000}},	//   diim, _иҟәа, --, --, 
   {{0x6f0d0416,0x00000000,0x00000000,0x00000000}},	//   _rucc, --, --, --, 
   {{0xf09c0109,0x6f0403f0,0x3f816778,0x60c40083}},	//   _diàn_, _rijc, _arku_, fiim, 
   {{0x6f0d6779,0x60c420ac,0x6f040369,0x206800c7}},	//   _pucc, giim, _sijc, мшуп_, 
   {{0xa5080135,0x6f040113,0xfbdd4590,0x9f341ac3}},	// [25090] _གཤོག_, _pijc, _फुलम, кеті, 
   {{0x6dc40046,0x63a13c88,0xf09c01fb,0x6f04047e}},	//   وزال, ämne, _giàn_, _qijc, 
   {{0x6f0c0198,0x60c4011f,0x38a801ab,0x3f8000a2}},	//   _wucc, biim, _rùrn_, _erku_, 
   {{0x6f0d677a,0x6f05677b,0x3f800fcf,0x60c4415a}},	//   _tucc, _wijc, _frku_, ciim, 
   {{0x8e2403ee,0x26c80098,0x00000000,0x00000000}},	//   _аlа_, écok_, --, --, 
   {{0xef1d677c,0x00000000,0x00000000,0x00000000}},	//   _itü_, --, --, --, 
   {{0xa5080327,0xa87401c6,0xc9a80108,0xdea4072d}},	//   _གཤེག_, дөлт_, явке_, _جیلی, 
   {{0x48dc0183,0x7ae80af9,0xef1c1ea0,0x2cbc03b9}},	//   মগ্ৰ, alft, _erüe_, _umud_, 
   {{0x68f9677d,0xb5a8002e,0x7ae8004b,0xafd812ed}},	//   rmud, _j斡fa, _کولې_, _udød, 
   {{0xef1c00c5,0x60c5677e,0x38b800e2,0xdb240248}},	//   _mtü_, ziim, dūru_, _àsáw, 
   {{0x60c4384e,0x85e8005b,0x9aa415b4,0x64a40022}},	//   yiim, ядов_, _جملو, ҵаҟа, 
   {{0x7d1800d2,0x60c4058a,0xe79001fd,0x3978011a}},	//   _étse, xiim, _لاتک, _מטענ, 
   {{0x60c4d62e,0x5ef400dc,0x97d80408,0x00000000}},	//   viim, ्गम्_, _оьшу_, --, 
   {{0x60c4009a,0x00000000,0x00000000,0x00000000}},	//   wiim, --, --, --, 
   {{0x60c5677f,0xae680023,0xb3380432,0x00000000}},	//   tiim, _ጽሑፋዊ_, lyçl, --, 
   {{0xc0e40107,0x44240432,0x00000000,0x00000000}},	//   хобк, _ýo_, --, --, 
   {{0x60c56780,0x44302ab1,0x03a4337e,0xf8b0010f}},	// [250a0] riim, _iey_, _чипо, אשן_, 
   {{0x60c56781,0x4430665e,0x2d800010,0x7ee402ef}},	//   siim, _hey_, _brje_, ركان, 
   {{0x6da016c3,0x44316782,0xaaf40086,0x60c56783}},	//   лифа, _key_, _ûrùò_, piim, 
   {{0x6e200598,0x44316784,0x3f803421,0x60c40009}},	//   ınba, _jey_, _trku_, qiim, 
   {{0x44316785,0xaca00016,0x3f800113,0xb0980375}},	//   _mey_, _giọn, _urku_, _זיכר, 
   {{0x44316786,0xdd000790,0x00000000,0x00000000}},	//   _ley_, ıtıc, --, --, 
   {{0x44300204,0xe9140212,0xad6400cf,0x00000000}},	//   _oey_, нощі_, _парз_, --, 
   {{0xa3c0098a,0xef1c0205,0xc0bc0023,0xec7401f4}},	//   ंछा_, _ytü_, ደበሩ_, _ппс_, 
   {{0x3b8467b0,0x57f402e8,0x56940166,0xb33800a2}},	//   _ялаг, ъпит, вапт, gyçl, 
   {{0x44316787,0x1a644d4e,0xc8780205,0x7ce809e8}},	//   _aey_, _شیعی_, roşa_, dýri, 
   {{0x2a3400ae,0x00000000,0x00000000,0x00000000}},	//   _سكند_, --, --, --, 
   {{0x44300de2,0x38b8005f,0xb4c80490,0x7ce80162}},	//   _cey_, tūru_, ळचे_, fýri, 
   {{0x44300694,0x7cf40432,0x00000000,0x00000000}},	//   _dey_, _zürý, --, --, 
   {{0xda1010f7,0x443001d9,0x998c01ef,0x271800df}},	//   ाशित_, _eey_, _jedů_, _צווײ, 
   {{0x44316788,0xf2dc000f,0x00000000,0x00000000}},	//   _fey_, brân_, --, --, 
   {{0x44316789,0xb338010e,0x00000000,0x00000000}},	//   _gey_, lyçm, --, --, 
   {{0xa92002d5,0x8c3cf3aa,0xda100073,0x00000000}},	// [250b0] ąžin, _hoşg, ाशात_, --, 
   {{0x443006d9,0x59b01971,0x2ed800cd,0x61e00205}},	//   _zey_, जनार, भवेत, şmla, 
   {{0x4431678a,0x2ca4025a,0x7538ef24,0xf1a803e6}},	//   _yey_, êndo_, nstz, _راده_, 
   {{0xef1c00c5,0x01c40022,0x753802d0,0x443006be}},	//   _ttü_, _шрыҭ, istz, _xey_, 
   {{0xc0c004a9,0x611c02f0,0x7cf400ee,0x09c800cd}},	//   _тәри, _včle, _sürý, िप्य, 
   {{0xf09c001e,0xef1c002f,0x5bc400ae,0x00000000}},	//   _hoà_, _trüb_, دقهل, --, 
   {{0xaf840032,0xccfc0134,0x06fc0118,0x00000000}},	//   _юҡҡа_, hwɛɛ_, říká_, --, 
   {{0xfcc000d1,0x48084316,0xb8800118,0x3af00124}},	//   _кәчм, мейн_, řínk, râpa_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4431678b,0xf09c0051,0x458400d4,0x00000000}},	//   _sey_, _loà_, вгов, --, 
   {{0x4431678c,0xf2dc0311,0x7538002f,0xe5080037}},	//   _pey_, trân_, gstz, _सूखि_, 
   {{0x7ce81125,0x4431678d,0xc3240154,0x03a400d4}},	//   týri, _qey_, _বিবি_, вимо, 
   {{0x44302166,0xa85000c7,0xca241870,0x07a4033a}},	//   _vey_, _аеҵә, ﻠﺴﺎ_, _јалн, 
   {{0x4431678e,0x52740228,0x673801f7,0xc7b801ed}},	//   _wey_, лусу, msuj, mző_, 
   {{0x4431678f,0x11d96790,0xc7b800dd,0x8c3c0209}},	//   _tey_, ефть_, lző_, _goşg, 
   {{0x4430003e,0x8c3c010e,0x008402e8,0x00000000}},	//   _uey_, _joşd, ълбо, --, 
   {{0x8fd401d2,0x6d416791,0x6739484a,0x5348030d}},	// [250c0] гәрә, ánan, nsuj, _пăтă, 
   {{0x6e340014,0x6738023a,0x6d48033f,0x00000000}},	//   gaxb, isuj, ągan, --, 
   {{0xbd896792,0xdb080008,0xb058013d,0x8c3c03b9}},	//   بنان_, _ólét, _imän, _xoşg, 
   {{0x06d402a6,0x67396793,0x00000000,0x00000000}},	//   _সীমি, ksuj, --, --, 
   {{0xc324015b,0xdbcc0077,0xfbd01291,0xae4402dd}},	//   _বিডি_, _póño, جتا_, _ﻗﯘﺭﯞ_, 
   {{0x59f80276,0x91c8036b,0xaa500212,0x8db401ec}},	//   неля_, _آذیق_, ивіш, _өссі, 
   {{0xa9642850,0x8c3c4560,0x00000000,0x00000000}},	//   вија_, _boşd, --, --, 
   {{0x98747083,0x187400a7,0x394c0112,0x8c3c03e3}},	//   улиц, угия, rufs_, _coşd, 
   {{0x8b64a9de,0x65a8005b,0xb05801e3,0xc7b801d3}},	//   _مالم, yöhö, _omän, gző_, 
   {{0x38b800e2,0x99e800a2,0x00000000,0x00000000}},	//   tūrs_, gyňç, --, --, 
   {{0x9a54035b,0x673800e4,0x00000000,0x00000000}},	//   _ахҵә, asuj, --, --, 
   {{0xd5b8005f,0xb354f237,0x8c3c010b,0x753801f5}},	//   rzā_, پیدا_, _goşd, rstz, 
   {{0x3864003a,0x00000000,0x00000000,0x00000000}},	//   _ibor_, --, --, --, 
   {{0x3864107d,0x63a00267,0x245c01f2,0xb8640133}},	//   _hbor_, ämna, ụmpi_, _ساڵو, 
   {{0x62346be2,0xa15811eb,0x00000000,0x00000000}},	//   ресу, кару_, --, --, 
   {{0x54556794,0xb0585dcf,0x8c3d6795,0x6e340009}},	//   _свит, _emän, _koşe, waxb, 
   {{0x3864020c,0xbbc000b5,0xaca0004d,0x49540023}},	// [250d0] _mbor_, _ｍの_, _niền, _ዘይትብ, 
   {{0x6d400efe,0x8c3c0166,0x999c00c0,0x00000000}},	//   ánao, _moşe, ngvų_, --, 
   {{0x38656796,0xf09c01fb,0x6e340169,0x00000000}},	//   _obor_, _toà_, raxb, --, 
   {{0x7af80175,0x673802f0,0x00000000,0x00000000}},	//   _ahtt, ysuj, --, --, 
   {{0xe5040918,0xf1a804d3,0x7af80175,0x00000000}},	//   रगति_, _راگه_, _bhtt, --, 
   {{0x38645138,0x63a0318c,0x7ce81d1d,0x00000000}},	//   _abor_, ømni, dýru, --, 
   {{0x7af80354,0xdd956797,0x00000000,0x00000000}},	//   _dhtt, _кары, --, --, 
   {{0x6738019b,0x48d000bd,0x38656798,0x61e8260b}},	//   tsuj, াত্র, _cbor_, üdli, 
   {{0x7af80334,0xaca0004d,0x67380108,0x00000000}},	//   _fhtt, _giền, usuj, --, 
   {{0xc7b800dd,0xaab41b6e,0xa9c56799,0x452801d5}},	//   rző_, _अतिक, _исек, нжон_, 
   {{0xc3240f22,0x6738023a,0x0608010b,0x7c4802d2}},	//   _বিধি_, ssuj, энок_, _ípró, 
   {{0xa9046646,0x8c3c0f7d,0x04440006,0xf990011a}},	//   _شبان, _hoşb, ыемн, _לרב_, 
   {{0x8c3c0166,0xb3380076,0xaca00208,0x00000000}},	//   _goşe, nyçh, _xiền, --, 
   {{0xd6d85dc9,0x3865679a,0x00000000,0x00000000}},	//   _үтә_, _zbor_, --, --, 
   {{0x611c02e2,0x71640354,0x6ee855ac,0xb36c0023}},	//   _bčla, ларг_, nübu, _እዚውን_, 
   {{0x039400a7,0xe50c0ebb,0x6d48012d,0x6f180055}},	//   _броя, _सूचि_, ągal, _ũuca, 
   {{0x64440050,0xb4f80a7c,0x42e800d8,0x00000000}},	// [250e0] _idii, _אפקי, _пмио_, --, 
   {{0x42540276,0xaca00208,0x00000000,0x00000000}},	//   _стит, _riền, --, --, 
   {{0x61b404a9,0x629c0369,0x7dc43346,0xc2c400ec}},	//   _ئەزا, mjro, دقان, _ليکي, 
   {{0x6ff400a2,0xb55400df,0x00000000,0x00000000}},	//   _ỳeńi, טשעס_, --, --, 
   {{0x81e402a6,0x9b940323,0x7aa46550,0xdddd679b}},	//   বেশ_, рилц, лидз, _karū, 
   {{0x629d342c,0x8c3d679c,0x38640118,0x00000000}},	//   njro, _coşb, _sbor_, --, 
   {{0x81e403f4,0x6445679d,0xdddc0055,0xfa68013d}},	//   বের_, _odii, _marū, _җаек_, 
   {{0xfce44294,0xa9640597,0x6445679e,0x8c3d679f}},	//   _собо, اميم_, _ndii, _poşe, 
   {{0x7d0167a0,0x629c00f2,0xaef801c3,0x370402e8}},	//   mmos, kjro, _spùi, лчов, 
   {{0x644567a1,0x3ce40218,0xba1800c6,0x7d0167a2}},	//   _adii, loov_, _أيضا_, lmos, 
   {{0xb864021a,0x629c020c,0xb68401ec,0x00000000}},	//   _ماشو, djro, _ەشبى, --, 
   {{0x7d0167a3,0x386401d5,0x7ce800e4,0x00000000}},	//   nmos, _ubor_, pýru, --, 
   {{0x64440a49,0xf9f4009e,0x569403f6,0xa34400ee}},	//   _ddii, _চলিল_, _валт, йэрл, 
   {{0x78a167a4,0x7d0167a5,0x644404ba,0xef1c05d5}},	//   _hoov, hmos, _edii, _brün_, 
   {{0x78a167a6,0x7ce800bc,0x0664132f,0x224c0210}},	//   _koov, nýrs, _خانپ, ódka_, 
   {{0x7d003656,0x78a00037,0x2934010f,0x3d0c012d}},	//   jmos, _joov, טאלן_, िदों_, 
   {{0x5f940184,0x611c151c,0x81e40f22,0x0e340138}},	// [250f0] битт, _včla, বেল_, инаю, 
   {{0xd2507ff6,0x78a167a7,0x7ce801a8,0x7d0016b8}},	//   _بند_, _loov, kýrs, emos, 
   {{0x2d8567a8,0x91803baf,0xef1c0730,0xd0110dbc}},	//   íne_, _بۇزۇ, _grün_, _ولد_, 
   {{0x611c026a,0x78a167a9,0x7644013f,0x7d0000e5}},	//   _učla, _noov, ɔkye, gmos, 
   {{0x9d1801e0,0xa29801d3,0x00000000,0x00000000}},	//   _ҡорт_, _شئیر_, --, --, 
   {{0x7d0167aa,0xddd40209,0x8c3c0356,0x7eb0032e}},	//   amos, _ýaşl, _boşc, _hæpn, 
   {{0x78a0009a,0x9ed81b88,0x48b42d29,0x7d0167ab}},	//   _boov, _смрт_, ищит, bmos, 
   {{0x6ee8002f,0x00000000,0x00000000,0x00000000}},	//   rübu, --, --, --, 
   {{0x6ee817da,0x1bec0037,0x78a401e3,0x00000000}},	//   sübu, _छुपल_, ökva, --, 
   {{0x056527dd,0xb058049f,0x46f4147e,0x00000000}},	//   авон, _smäl, јчит, --, 
   {{0xbaa404a9,0x7bd8054e,0xe854010a,0x00000000}},	//   _тутқ, ăcuţ, _йĕнн, --, 
   {{0x84e405f5,0xdddc1a14,0xaca00208,0xed5c0419}},	//   ромж, _sarū, _khựn, _úľuv_, 
   {{0x290c01d9,0xdddd67ac,0x957801c6,0x00000000}},	//   _iiga_, _parū, вөөс_, --, 
   {{0x290d67ad,0x629c0399,0x6d48033f,0x7d00283f}},	//   _higa_, ujro, ągaj, zmos, 
   {{0x290d67ae,0x64400085,0x26c400e4,0xa28412ea}},	//   _kiga_, ómis, _imno_, لیکو, 
   {{0x290c3386,0x64440014,0x3ce40211,0xf41c0166}},	//   _jiga_, _udii, xoov_, ccä_, 
   {{0x248008cd,0x290d67af,0xb0300131,0xf9ec00cc}},	// [25100] _iaim_, _miga_, زىلغ, টেপল_, 
   {{0x93240220,0x0fe80131,0x41a80798,0xf78400a2}},	//   _ارين, улуқ_, _авон_, _öçer_, 
   {{0x7d0167b0,0x248167b1,0x290c0407,0x27ec0174}},	//   tmos, _kaim_, _oiga_, _lygn_, 
   {{0x8c3c0311,0x290d246f,0x9b3c0092,0xb5f800df}},	//   _roşc, _niga_, _ሲነጻጸ, דלעכ, 
   {{0xeb301a59,0x248167b2,0x26c40048,0x7d000f85}},	//   قىند, _maim_, _omno_, rmos, 
   {{0x78a0033d,0x290d67b3,0x3ce40457,0x24800211}},	//   _soov, _aiga_, soov_, _laim_, 
   {{0x290c01b2,0x7d00b89a,0x7c94033a,0x2954007b}},	//   _biga_, pmos, _крац, لشيخ_, 
   {{0x290c0098,0x248167b4,0x25fc06e3,0x9cd401f7}},	//   _ciga_, _naim_, _रणजी_, _امرڪ, 
   {{0x290d67b5,0x26c4022f,0xa8940124,0x00000000}},	//   _diga_, _bmno_, ркыу_, --, 
   {{0x290cb25d,0x27ec01e6,0x78a0009a,0x36883be4}},	//   _eiga_, _dygn_, _woov, тсин_, 
   {{0x248167b6,0x290d67b7,0x78a167b8,0x59242fc0}},	//   _baim_, _figa_, _toov, _اکتف, 
   {{0x290d67b9,0x8c3c05d1,0x248000d8,0x37e40139}},	//   _giga_, _koşa, _caim_, _коег, 
   {{0x24800190,0xe8d40302,0xdddc002b,0x8c3c010e}},	//   _daim_, _דואר_, _darũ, _joşa, 
   {{0x290d67ba,0xf77005d9,0x57b002dd,0x00000000}},	//   _ziga_, _هاڻ_, _мұқт, --, 
   {{0x248007ea,0x91c40139,0x00000000,0x00000000}},	//   _faim_, сәпл, --, --, 
   {{0x290d5adf,0x6d400427,0xaca00051,0x00000000}},	//   _xiga_, šnak, _kiễn, --, 
   {{0x7eb008fb,0x00000000,0x00000000,0x00000000}},	// [25110] _væpn, --, --, --, 
   {{0x248167bb,0x3eb80175,0xc374009f,0x00000000}},	//   _zaim_, ghpt_, _اُٿب, --, 
   {{0xafd82142,0x248001d5,0xa1840006,0x00000000}},	//   _idøm, _yaim_, _дыял, --, 
   {{0x8c3c9e1c,0x248001d4,0x27200030,0x7d2801e2}},	//   _boşa, _xaim_, nčný_, اينې_, 
   {{0x290d67bc,0xcb6967bd,0x8c3c2ca8,0x00000000}},	//   _riga_, امته_, _coşa, --, 
   {{0x290d67be,0xc8780311,0xbb4024fc,0x508400d1}},	//   _siga_, moşi_, чешк, _ئاگې, 
   {{0x290d67bf,0x272001f1,0xc878054e,0x27ec0210}},	//   _piga_, kčný_, loşi_, _sygn_, 
   {{0x290c022e,0xcce400ec,0x00000000,0x00000000}},	//   _qiga_, _اڳئي, --, --, 
   {{0xb0580054,0x46e83955,0x290d67c0,0x248167c1}},	//   _amäk, лдин_, _viga_, _raim_, 
   {{0x290c0230,0x248167c2,0xaca00051,0xeab000d1}},	//   _wiga_, _saim_, _diễn, _بعر_, 
   {{0x290d67c3,0x24800218,0x7ccc01e4,0xf9ec0154}},	//   _tiga_, _paim_, lŝra, টেবল_, 
   {{0x290c2f06,0x24800218,0x67d00116,0x3d0800cd}},	//   _uiga_, _qaim_, _һоҗу, िषये_, 
   {{0x248167c4,0x7ccc0115,0xf8142586,0xc8780356}},	//   _vaim_, nŝra, _اسمگ, joşi_, 
   {{0x26c40020,0xcce8013f,0x27200030,0x00000000}},	//   _umno_, hoכ_, ačný_, --, 
   {{0x2480398e,0x55c41b74,0x9f4401e1,0x7c3403b2}},	//   _taim_, _машғ, _ámú_, ðyrk, 
   {{0x24809a14,0x00000000,0x00000000,0x00000000}},	//   _uaim_, --, --, --, 
   {{0xbc2404a9,0x442000d8,0x2d8400b5,0xc878054e}},	// [25120] ەرتى, mck_, ænen_, goşi_, 
   {{0x442167c5,0xee34d47b,0xef1c04cc,0x09ac00fe}},	//   lck_, йну_, _grüm_, _কইনা, 
   {{0xcce80134,0x74100131,0x00000000,0x00000000}},	//   foכ_, _بوۋا, --, --, 
   {{0xaef801ab,0x1f2401d9,0x30f800dc,0x8c3c415b}},	//   _spùt, _وِجہ, ्षणः_, _poşa, 
   {{0x442167c6,0xa3d80a28,0xc8780311,0x92bc03d4}},	//   ick_, ऽपि_, coşi_, েকৰ_, 
   {{0x1ab40108,0x00000000,0x00000000,0x00000000}},	//   юбля, --, --, --, 
   {{0xae042356,0x2d845629,0xb05801e3,0xb33800a2}},	//   वेदन_, ånet_, _pjäx, lyçt, 
   {{0xa3b82052,0x442001a4,0x8c3d069b,0x315408a8}},	//   चना_, jck_, _hoşn, ציפן_, 
   {{0x7c200483,0xf09c0016,0x8c3c0139,0xd7f0007b}},	//   mcor, _giàu_, _koşn, بكة_, 
   {{0xaa400d1d,0x4bd8117e,0x00000000,0x00000000}},	//   _неул, _ться_, --, --, 
   {{0x7c20011c,0x7ae967c7,0xb8848fdf,0x8c3c054e}},	//   ocor, moft, _гулй, _moşn, 
   {{0x7ae967c8,0x6d400597,0x7f5403f0,0x00000000}},	//   loft, ánai, kuyq, --, 
   {{0xef1c0c86,0x611c007f,0xf7f40150,0x7c200393}},	//   _prüm_, _dčlm, _اساد, icor, 
   {{0x442167c9,0x7ae80200,0xdddc0118,0x00000000}},	//   ack_, noft, _narů, --, 
   {{0x7c2002d0,0x27200419,0x30680798,0x00000000}},	//   kcor, pčný_, лјан_, --, 
   {{0xc878054e,0x7ae801a4,0x50f40a4a,0x00000000}},	//   toşi_, hoft, ізат, --, 
   {{0x2aa8019b,0x7c20a2e5,0x7eb00008,0xddd416a3}},	// [25130] _købt_, dcor, _tæpl, _čaša, 
   {{0x765967ca,0x7ae8a602,0x7c2016b8,0xc8780311}},	//   ngty, joft, ecor, roşi_, 
   {{0x09ac00bd,0x7c2001f5,0xdef8010b,0x7ae8007c}},	//   _কেনা, fcor, сыт_, doft, 
   {{0xaca00016,0x7c20004e,0x00000000,0x00000000}},	//   _miện, gcor, --, --, 
   {{0xe47c00c8,0xe9d804fb,0xcce8016b,0x8c3c0356}},	//   טראכ, گذشت_, roכ_, _foşn, 
   {{0x7c2167cb,0x2d854ad4,0x3a700075,0x00000000}},	//   acor, ånes_, мһур, --, 
   {{0x442004f3,0xf1cc194b,0x3ead67cc,0xda6400ae}},	//   yck_, _हेमन, öfte_, ساوي, 
   {{0x81e400bd,0x6d54f221,0x76580ea0,0x7ccc01e4}},	//   বেক_, muxa, egty, pŝra, 
   {{0x6d5567cd,0x0a58013e,0x8c3c010e,0x87b80137}},	//   luxa, _вазъ_, _hoşo, руйт_, 
   {{0xf09c0e89,0x7d0002fb,0x611c033b,0x06c84dbb}},	//   _fhàg_, ňost, _sčlm, ргой_, 
   {{0x38a801c3,0x2f1c0327,0x2aa800b5,0x442167ce}},	//   _cùrs_, _lîg_, _døbt_, tck_, 
   {{0x442167cf,0x19a80137,0x7f540113,0x53880022}},	//   uck_, _утуп_, yuyq, әарҭ_, 
   {{0x442167d0,0x43f83334,0xf8c40345,0x00000000}},	//   rck_, рхня_, _بمنێ, --, 
   {{0x6d541cdf,0x4420ecf1,0x00000000,0x00000000}},	//   kuxa, sck_, --, --, 
   {{0x611c02e2,0x04c40014,0x0084022e,0x00000000}},	//   _tčlm, _وقتُ, олво, --, 
   {{0x7c201709,0x04c80832,0x7f540784,0x2aa8005c}},	//   xcor, _خوبي_, tuyq, _købs_, 
   {{0x73300aaf,0x65bc01e1,0x611c02e2,0x7f48710e}},	// [25140] _قىيا, _fáhé, _kčlk, شلاق_, 
   {{0x7c2044b6,0x7f5402d1,0x8c3c0139,0x2c0800fe}},	//   wcor, ruyq, _qoşn, হুৱে_, 
   {{0xb8840077,0x6d54005a,0xc0e400db,0x932403c7}},	//   ntíñ, guxa, _моок, _ورین, 
   {{0xe924031c,0x7f540309,0x7c2039da,0x00000000}},	//   _ལྕེབ_, puyq, ucor, --, 
   {{0x7c2167d1,0xf41c025a,0x2d84cc6e,0x7f540113}},	//   rcor, ndäa_, åner_, quyq, 
   {{0x7c2150c6,0x6d5567d2,0x8c3c3712,0x4cb80154}},	//   scor, buxa, _hoşl, েকগু, 
   {{0x7ae967d3,0x8c3c008e,0x09ac03d4,0x00000000}},	//   roft, _koşl, _কেবা, --, 
   {{0x7ae967d4,0x8c3c00a2,0x00000000,0x00000000}},	//   soft, _joşl, --, --, 
   {{0xe8f4052f,0xab2400f3,0xe9d40166,0x00000000}},	//   өлә_, _мота_, йкә_, --, 
   {{0x7ae802d3,0xaa9400fb,0x00000000,0x00000000}},	//   qoft, _мѳхә, --, --, 
   {{0x611c007f,0x7bc013eb,0x00000000,0x00000000}},	//   _dčlk, lzou, --, --, 
   {{0x1cd803bd,0xef1c03fa,0x7bc00165,0x65bc01e1}},	//   _ོམས_, _früh_, ozou, _sáhé, 
   {{0x7bc037b6,0x6d5418f7,0xf48002d3,0x611c0010}},	//   nzou, zuxa, _ይዛረብ_, _učlj, 
   {{0x7bc167d5,0x00000000,0x00000000,0x00000000}},	//   izou, --, --, --, 
   {{0x30a47fe3,0x8c3c3630,0xf48439c1,0xe1f00472}},	//   орав, _boşl, _дупн, نسف_, 
   {{0x6ab47922,0x92bc09bd,0xdb0802d2,0x00000000}},	//   _अत्र, েকে_, _ólæt, --, 
   {{0xdb4404d3,0xb4e400e1,0x6d54009a,0x7eb001bf}},	// [25150] _جێ_, बकी_, wuxa, _kæph, 
   {{0x7bc00810,0x6d540009,0xed88004e,0x00000000}},	//   dzou, tuxa, исек_, --, 
   {{0xf09c030a,0xad24b4d5,0x3f8c0607,0x7bc00165}},	//   _diàr_, زراو, āfua_, ezou, 
   {{0x8c3c0432,0xeff00092,0x00000000,0x00000000}},	//   _goşl, ፍራው_, --, --, 
   {{0x7988074d,0x00000000,0x00000000,0x00000000}},	//   evfw, --, --, --, 
   {{0x81e402a6,0x63a0049f,0xfb500131,0x3ce567d6}},	//   বেও_, ämni, رپىد, čova_, 
   {{0x8c3c062d,0x7bc167d7,0x06b000cc,0x60980023}},	//   _hoşm, azou, টোডি, _ቅሬጥስ_, 
   {{0x07a567d8,0x76480368,0x6d44025c,0xf09c030a}},	//   заин, _adfy, _ivja, _ziàr_, 
   {{0x8c3c010e,0x00000000,0x00000000,0x00000000}},	//   _joşm, --, --, --, 
   {{0xfbcc05d9,0x00000000,0x00000000,0x00000000}},	//   _حڪم_, --, --, --, 
   {{0x48140220,0x45d40395,0x06cc00eb,0x20f0010e}},	//   _емес, яцит, রকলি, lşiň_, 
   {{0xd8a800f1,0xa50800d1,0x00000000,0x00000000}},	//   _وهلو_, تىجە_, --, --, 
   {{0xc87967d9,0x611c007f,0x69c0002f,0xb058002f}},	//   meş_, _tčlk, lzne, _kläf, 
   {{0xc87967da,0x6d44031c,0x69c0030a,0x00000000}},	//   leş_, _ovja, ozne, --, 
   {{0x69c00399,0xdddc084c,0x7bc00198,0x8c3c0166}},	//   nzne, _marţ, zzou, _poşl, 
   {{0xc878ca2c,0xf41c00fd,0x69c0107d,0x8c3c013d}},	//   neş_, ldän_, izne, _qoşl, 
   {{0xef153aa1,0x6d44bd70,0x8c3c75c0,0x7eb0032e}},	// [25160] зму_, _avja, _coşm, _hæpi, 
   {{0xf41c29ef,0x8c3c00fd,0x7bc00165,0xc2c4007b}},	//   ndän_, _doşm, vzou, _ريجي, 
   {{0xe05804d3,0xae0400af,0x81e40011,0x69c000d7}},	//   _ویست_, वेलन_, বেজ_, jzne, 
   {{0x823567db,0x7bc00036,0xeab401c6,0xf41c01f4}},	//   _برکا, tzou, үйц_, hdän_, 
   {{0x426c0020,0x8c3c0209,0xc8783536,0xd0f8547d}},	//   _ስምንት_, _goşm, deş_, ंतरण_, 
   {{0x3f800d62,0x7bc0e0c4,0x00000000,0x00000000}},	//   _isku_, rzou, --, --, 
   {{0x8eb01075,0x7bc0382c,0x6d4167dc,0x69c000ef}},	//   _جەلت, szou, ánat, gzne, 
   {{0xc878a5c1,0x6d400327,0x6f1800b8,0x00000000}},	//   geş_, ġnat, _ũuci, --, 
   {{0x6d400010,0x8c3c03e3,0x998c0210,0x00000000}},	//   šnat, _xoşm, _jedź_, --, 
   {{0x02cc0034,0xdddc00a2,0xb058007c,0x95d80120}},	//   होमभ, _garţ, _gläf, ждот_, 
   {{0x69c0006d,0xc87967dd,0x8c3c010b,0x00000000}},	//   czne, beş_, _alşy, --, 
   {{0xdcfc0427,0xb059489f,0xa3b800dc,0x3ea80112}},	//   _osrč, _iläg, चनं_, _lobt_, 
   {{0x28100132,0x25b803e3,0x00000000,0x00000000}},	//   _كومس, _əqli_, --, --, 
   {{0x764804ce,0xb05803fa,0x81e400fe,0xe3b000ec}},	//   _udfy, _kläg, বেছ_, ارَ_, 
   {{0xa19567de,0xb058007c,0x00000000,0x00000000}},	//   нарч, _omät, --, --, 
   {{0x359002d3,0x96b4012d,0xf4840395,0xe5f4011a}},	//   _ሜላታት_, इसकॉ, _хукн, _מזור_, 
   {{0xe1f00050,0x69c06257,0x09a800dc,0x8c3c0213}},	// [25170] نسہ_, zzne, _कथ्य, _qoşm, 
   {{0x8c3c010e,0xb05801e3,0x8e98007b,0x00000000}},	//   _goşj, _oläg, غناء_, --, 
   {{0x3f8005f5,0xfba80154,0xc0dc0023,0x8d9402ef}},	//   _esku_, _খেলত, ዒሎም_, بلاش, 
   {{0xf41c0724,0x3f800175,0x6d44031c,0xaca00208}},	//   zdän_, _fsku_, _vvja, _khỉn, 
   {{0xdddc0276,0xf41ce9b1,0x5f949d86,0x69c00175}},	//   _parţ, ydän_, _зият, wzne, 
   {{0xb05967df,0x69c00112,0xfe6c0ab4,0x8c3c0166}},	//   _bläg, tzne, _نگم_, _koşk, 
   {{0xaca001f2,0xc8780724,0x69c00165,0x224c0210}},	//   _akụn, teş_, uzne, ódki_, 
   {{0x69c167e0,0xb4e400bc,0x00000000,0x00000000}},	//   rzne, बको_, --, --, 
   {{0x3ea967e1,0xc87967e2,0x69c05642,0x7eb0003a}},	//   _yobt_, reş_, szne, _sæpi, 
   {{0x2bc80364,0x85480108,0xb05800d0,0xecd001f9}},	//   _куҷо_, озов_, _zmät, _दगडफ, 
   {{0xb05804f3,0x611c166a,0xdddd313f,0xf41c0724}},	//   _kläd, _kōle, _karš, rdän_, 
   {{0x87b800a8,0xdddc0427,0xb0580139,0x43740166}},	//   _мулт_, _jarš, _xmät, мугт, 
   {{0xdddd67e3,0xaca00016,0x672803a1,0x00000000}},	//   _marš, _chỉn, _utgj, --, 
   {{0x8c3c0205,0x070800ae,0x7eb0032e,0x00000000}},	//   _boşk, _بيتي_, _tæpi, --, 
   {{0x8c3c05d1,0xf554e591,0xe1f8013e,0xd1740993}},	//   _coşk, _قلوب_, яҳо_, ныты, 
   {{0xdddc02d5,0x5434030d,0x8504009f,0x00000000}},	//   _narš, _пхьу, _توبن, --, 
   {{0xd4682834,0x2d8001f5,0x611c0100,0x82a400cf}},	// [25180] _رحيم_, _asje_, _sōld, _жапж, 
   {{0xedd000ec,0x00000000,0x00000000,0x00000000}},	//   ھيند, --, --, --, 
   {{0x32980302,0x7c840408,0xb05801e6,0xd2008147}},	//   _וביד, дуле, _bläd, _бүрк, 
   {{0x3ce41155,0xdcb000cf,0x00000000,0x00000000}},	//   čovo_, دۉر_, --, --, 
   {{0x3f80000d,0x3ea80112,0xb0583167,0x00000000}},	//   _usku_, _tobt_, _släg, --, 
   {{0x8c3c013d,0x6d480210,0x00000000,0x00000000}},	//   _yoşk, ągar, --, --, 
   {{0xb05801e3,0xdddc0153,0xdd1c0419,0x00000000}},	//   _fläd, _farš, bášn, --, 
   {{0xb058049f,0xdddc00da,0xeab40116,0xec74020f}},	//   _gläd, _garš, зйә_, _опс_, 
   {{0x6b6000fb,0x00000000,0x00000000,0x00000000}},	//   _икта, --, --, --, 
   {{0xeb3000db,0x00000000,0x00000000,0x00000000}},	//   _شىمد, --, --, --, 
   {{0xafd8037e,0x00000000,0x00000000,0x00000000}},	//   _udøv, --, --, --, 
   {{0xb0580036,0x7f540240,0xf540133a,0xf4cc03d4}},	//   _kläe, kryq, ндүү, ৰত্ব, 
   {{0xb058007c,0x779010e8,0x00000000,0x00000000}},	//   _omär, _شیدا, --, --, 
   {{0x168403e6,0x98bc0024,0x00000000,0x00000000}},	//   _ساتێ, tuvė_, --, --, 
   {{0x8c3c0166,0xd7880051,0x33740150,0x00000000}},	//   _qoşk, _hể_, _ﺸﻔﻬﻲ_, --, 
   {{0xd7880016,0xaca001fb,0x6ad83b90,0x8c3c010e}},	//   _kể_, _thỉn, _बद्र, _goşh, 
   {{0x22b8007f,0xb4c8000d,0x00000000,0x00000000}},	// [25190] _fٍk_, लफी_, --, --, 
   {{0x611c0418,0xfbb40154,0x656c030a,0xb058007c}},	//   _sōle, ড়পাত, ńche, _släd, 
   {{0x3db004c5,0xb05967e4,0x8c3c0139,0xd7880208}},	//   _টেবল, _pläd, _hoşi, _lể_, 
   {{0x9e042063,0xef1d67e5,0x8c3c06be,0x09ac00eb}},	//   тчул, _brüt_, _xoşh, _কইলা, 
   {{0x225967e6,0xdddd67e7,0x248c02d3,0xd78801fb}},	//   _عجیب_, _varš, _ንጹሃት_, _nể_, 
   {{0x2d80002d,0x8a040276,0x8c3c054e,0x7f3808a8}},	//   _tsje_, нзле, _moşi, _מעשו, 
   {{0xdddc0024,0xb0580108,0x9e14003b,0x00000000}},	//   _tarš, _eläe, _адрі, --, 
   {{0xd788001e,0xef1c05d5,0x00000000,0x00000000}},	//   _bể_, _früt_, --, --, 
   {{0xd76401d3,0xb05801f4,0x1ca80345,0x00000000}},	//   نچوی, _ymär, _تێنی_, --, 
   {{0x2cbc0165,0x7d1804cc,0xd788004d,0xa9a00014}},	//   _hlud_, _ètsc, _dể_, _لۅتى, 
   {{0x2cbc5b25,0x0dec001f,0x09ac0154,0x8bf00154}},	//   _klud_, _ፀሐፊ_, _কেরা, জেশন_, 
   {{0x1ccc025c,0x79b405d0,0x00000000,0x00000000}},	//   ྲིར_, _אלעד_, --, --, 
   {{0x68f967e8,0xf2dc000f,0xd6a801b9,0xb600031c}},	//   mlud, rsân_, سدیم_, ġġam, 
   {{0x68f967e9,0x527567ea,0xdee0001f,0x28a801ad}},	//   llud, кусу, ናችን_, टॉरि, 
   {{0xf65025f9,0x11d400d6,0x2cbc1405,0x68f967eb}},	//   _עצה_, вітр, _olud_, olud, 
   {{0x68f967ec,0xb058049f,0xe3b801ec,0x6a7003e0}},	//   nlud, _smär, _жұм_, lıfı, 
   {{0x8c3c00a2,0x6d5402d0,0x7e540902,0x00000000}},	// [251a0] _hoşw, erxa, етец, --, 
   {{0x611c007f,0x2cbc0789,0x6a7005d1,0x7f5402d0}},	//   _bčlt, _alud_, nıfı, rryq, 
   {{0x68f967ed,0x2cbc01fa,0xdcfc0055,0x6e1400c6}},	//   klud, _blud_, _asrā, فيكس_, 
   {{0x7b64005e,0x68f80cf4,0x2cbc6729,0x6d400327}},	//   етке, jlud, _clud_, ġnap, 
   {{0xfbd167ee,0x60c567ef,0x68f95b39,0xf09c0208}},	//   دتا_, mhim, dlud, _khàn_, 
   {{0x60c4eaef,0xd78801fb,0x629801ed,0x59f82401}},	//   lhim, _rể_, _óvod, меля_, 
   {{0x60c567f0,0x7e7c87ef,0x4df4672f,0x68f80115}},	//   ohim, mepp, _аятт, flud, 
   {{0x60c567f1,0x7e7d67f2,0xa84413ef,0x68f967f3}},	//   nhim, lepp, ىلىم_, glud, 
   {{0x60c567f4,0xc5880165,0x970800aa,0x00000000}},	//   ihim, _aẓ_, وښتل_, --, 
   {{0xf41c0598,0x8c3c084c,0xf09c01fb,0x60c400d8}},	//   rdäm_, _roşi, _nhàn_, hhim, 
   {{0x60c40357,0x998c0cf4,0x00000000,0x00000000}},	//   khim, _hedž_, --, --, 
   {{0x68f8d0d5,0x7e7d67f5,0x94d434cd,0x66000175}},	//   clud, hepp, томц, _dznk, 
   {{0x60c567f6,0x6600009a,0x7e7d67f7,0xf09c08c2}},	//   dhim, _eznk, kepp, _bhàn_, 
   {{0x60c400b0,0x7e7c2167,0xe73452d1,0x998c0064}},	//   ehim, jepp, _џеј_, _medž_, 
   {{0xf09c01c3,0x7e7c0036,0x60c4025c,0xd0d40395}},	//   _dhàn_, depp, fhim, вовъ, 
   {{0x60c567f8,0xa08806d3,0x00000000,0x00000000}},	//   ghim, нсуз_, --, --, 
   {{0x7e7c00e8,0x00000000,0x00000000,0x00000000}},	// [251b0] fepp, --, --, --, 
   {{0xb05967f9,0x2cbc0793,0xaca0001e,0x5ed4009d}},	//   _bläc, _slud_, _thịn, гжуу, 
   {{0x60c40882,0x00000000,0x00000000,0x00000000}},	//   bhim, --, --, --, 
   {{0x9cc8004e,0x6f0402d0,0xfbd000cd,0x00000000}},	//   ныча_, _whjc, _देहम, --, 
   {{0x68f967fa,0x7e7c04ce,0x20680139,0x6f040051}},	//   vlud, bepp, _яшэп_, _thjc, 
   {{0x386402ea,0x611c7d7d,0xb05967fb,0x7e7c5bd9}},	//   _acor_, _hōla, _fläc, cepp, 
   {{0x386401ee,0xc0f002d3,0x68f967fc,0x00000000}},	//   _bcor_, ፍጻም_, tlud, --, 
   {{0x692007f5,0xfbd017c6,0xd7dc0073,0x00000000}},	//   _uđem, _देवम, मपंच, --, 
   {{0x8c3c03ee,0x9b5803f5,0xa9640818,0x00000000}},	//   _boşv, _питт_, фиқа_, --, 
   {{0x68f967fd,0x60c432dd,0x452801b9,0xf1bc0327}},	//   slud, zhim, мжон_, ġġji_, 
   {{0xf09c01fb,0x87100055,0x68f82ba4,0x60c567fe}},	//   _nhào_, _cāsṛ, plud, yhim, 
   {{0x60c40023,0x7e7d67ff,0x0444023a,0x386401e7}},	//   xhim, zepp, ъемн, _gcor_, 
   {{0xb3800024,0x60c4006f,0xf09c004d,0x5f0400cd}},	//   алял, vhim, _phàn_, वतम्_, 
   {{0x60c402b5,0x1ccc0327,0x660000fb,0x00000000}},	//   whim, ྲིོ_, _йолҡ, --, 
   {{0x60c56800,0xf09c0016,0x8c3c05d1,0x515400f7}},	//   thim, _chào_, _hoşu, лтту, 
   {{0x8c3c0365,0x60c43209,0x00000000,0x00000000}},	//   _koşu, uhim, --, --, 
   {{0x60c56801,0xb05801e6,0xf09cf01e,0x8c3c0432}},	// [251c0] rhim, _släc, _thàn_, _joşu, 
   {{0x64447d7d,0x8c3c054e,0xaec01a6d,0x7e7c01c7}},	//   _heii, _moşu, абул, uepp, 
   {{0x60c56802,0x64456803,0x7e7d6804,0x5bbc00cd}},	//   phim, _keii, repp, ्छ्व, 
   {{0x7e7c0f0f,0x60c46018,0x00000000,0x00000000}},	//   sepp, qhim, --, --, 
   {{0x7e7d6805,0xfbd00954,0x6444045f,0xfaa42ac7}},	//   pepp, _देशम, _meii, кадо, 
   {{0x38656806,0x644403d4,0x00000000,0x00000000}},	//   _scor_, _leii, --, --, 
   {{0x6da10e64,0x2d84037e,0x58d42ff2,0x00000000}},	//   _кира, ænet_, локт, --, 
   {{0x3154008f,0x8c3c029f,0xf41c0113,0xc0e00023}},	//   דיקן_, _boşu, rdäk_, ቐበሉ_, 
   {{0xaca007ae,0x8c3c0276,0xba740a2c,0x87100055}},	//   _giốn, _coşu, _لاات, _sāsṛ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6444e775,0x00000000,0x00000000,0x00000000}},	//   _beii, --, --, --, 
   {{0xb8082781,0x644401ab,0x69b4010f,0xa2d007af}},	//   _قيام_, _ceii, _שלאף_, डोस्, 
   {{0x8c3c09a5,0x64453fa8,0xc1c000d1,0x6378792b}},	//   _goşu, _deii, _ﮬﺎﺭﺍ, ксёр_, 
   {{0xf09c004d,0x656c030a,0x8c3c0bbc,0x00000000}},	//   _phào_, ńcha, _hoşt, --, 
   {{0x611c0270,0x644400cc,0x8c3c510c,0x05940150}},	//   _sōla, _feii, _koşt, _مايگ, 
   {{0x611c0270,0x06a400c7,0x644401c7,0xaf5001e0}},	//   _pōla, _агәҽ, _geii, инбә, 
   {{0x8c3d6807,0xca60022e,0x2fcc002e,0xdee00023}},	// [251d0] _moşt, _oilа, àgg_, ናጽን_, 
   {{0xf09c0208,0xabd801ec,0x00000000,0x00000000}},	//   _thào_, _ﺃﺒﻨﺎ, --, --, 
   {{0xd5b80882,0x6444173b,0xceb800c7,0x998c0153}},	//   nyā_, _yeii, _ҟәа_, _medų_, 
   {{0xeff00020,0x611c0421,0x8c3c0276,0xaf3404fb}},	//   ግራይ_, _tōla, _noşt, _لرست, 
   {{0xd5b80882,0xca6001b9,0xf09c01e1,0x4a74008e}},	//   hyā_, _bilа, _inà_, гыйт, 
   {{0xf09c01ab,0x2d8400b5,0x58f80327,0x9f2400d1}},	//   _mhàm_, ænes_, _ཕེཔས_, _ئۈلۈ, 
   {{0x80b800a5,0xdddc19b3,0x8c3c0790,0x7eb002d2}},	//   _एकमे, _parť, _boşt, _tæpr, 
   {{0xd5b80882,0xb300031c,0xb058005b,0x8c3c0790}},	//   dyā_, _ཚེའང_, _yläa, _coşt, 
   {{0x8c3c03be,0xaa6400c7,0x64456808,0xf09ce021}},	//   _qoşu, _атек, _reii, _nhàm_, 
   {{0x64456809,0x05a800c9,0x03a400c2,0xf09c00a3}},	//   _seii, евой_, ҳимо, _shàl_, 
   {{0x8c3c0311,0xae041d68,0x00000000,0x00000000}},	//   _foşt, वेचन_, --, --, 
   {{0xc795017f,0x03a5680a,0xda0816ac,0xb338010b}},	//   _مشتب, гимо, _شينه_, lyçy, 
   {{0x6445680b,0x80b82983,0xf09c004d,0x8c3c0205}},	//   _veii, _एकबे, _chàm_, _hoşs, 
   {{0x242805f5,0xf09d680c,0x7eb0037e,0x64446ef0}},	//   эхүү_, _anà_, _næpp, _weii, 
   {{0x64440085,0xd5b800cd,0x00000000,0x00000000}},	//   _teii, cyā_, --, --, 
   {{0x58f81b4b,0xb0580793,0x446402e8,0x7bcc03b9}},	//   _ཕེབས_, _pläa, _свив, _əbub, 
   {{0xed54036b,0xc0041bc4,0xc7b801d3,0xf8b0010f}},	// [251e0] ғоч_, упак, nyő_, זשן_, 
   {{0x3f91680d,0xc15401af,0x00000000,0x00000000}},	//   rvyu_, _йњмњ, --, --, 
   {{0xfd94005b,0xaca00051,0x00000000,0x00000000}},	//   ышаю, _chỏn, --, --, 
   {{0x68180055,0x00000000,0x00000000,0x00000000}},	//   _kādī, --, --, --, 
   {{0xb059680e,0x2d8404ce,0x611cfa1b,0xb7780882}},	//   _klän, æner_, _hōlo, maṇā, 
   {{0x611c0093,0xca6001d5,0x1958010b,0x408401d3}},	//   _kōlo, _qilа, вакы_, _جھڑپ_, 
   {{0x29080801,0xa9641b6b,0x8c3c0276,0x68180171}},	//   зca_, гија_, _poşt, _lādī, 
   {{0xd5b80882,0x1755680f,0x8c78023a,0x37a848d4}},	//   vyā_, авия, _ищут_, етон_, 
   {{0x611c0418,0x8880fc2b,0x8c3c054e,0x1b0401f0}},	//   _lōlo, زیون, _voşt, _кӯкн, 
   {{0x5574449b,0xd5b80882,0xab24034f,0x00000000}},	//   агот, tyā_, _софа_, --, 
   {{0x8c3c010e,0xaca00051,0x998c0064,0x00000000}},	//   _goşs, _giồn, _vedų_, --, 
   {{0xf7450085,0xf09c01fb,0x8c3c010e,0x00000000}},	//   _бедо, _phàm_, _hoşr, --, 
   {{0xf09c0016,0xd5b80882,0xb0580267,0xe7340114}},	//   _giày_, syā_, _blän, _беч_, 
   {{0x59a8256a,0xa2d007f7,0x00000000,0x00000000}},	//   _कपार, डोल्, --, --, 
   {{0x623402bf,0xe60c0c75,0x710801f4,0x00000000}},	//   сесу, _ىشى_, ехав_, --, 
   {{0xb05808ae,0x2068010b,0xdef00023,0x00000000}},	//   _elän, лшуп_, ግዛእ_, --, 
   {{0xf09c07c5,0xb05801e3,0x9f3401ec,0x681800de}},	// [251f0] _vnà_, _flän, йеті, _gādī, 
   {{0xaca0001e,0xb0596810,0x3b1c03e3,0x00000000}},	//   _phỏn, _glän, _nitq_, --, 
   {{0x9f040aa0,0xf19001f7,0x00000000,0x00000000}},	//   حولو, _اُجھ, --, --, 
   {{0xf09c003a,0x8c196811,0x13d800eb,0x00000000}},	//   _unà_, نيار_, _ধুয়, --, 
   {{0x7eb0037e,0xfb8401d5,0xb0580108,0xe68c00a2}},	//   _tæpp, لدوی, _ylän, _üpçü, 
   {{0x20e806be,0x00000000,0x00000000,0x00000000}},	//   nğin_, --, --, --, 
   {{0xdea42cef,0x1a680344,0x00000000,0x00000000}},	//   _دیلی, ایمی_, --, --, 
   {{0x52d08e37,0x0c040050,0x00000000,0x00000000}},	//   सफुस, _نوزُ, --, --, 
   {{0x6a64dffc,0x29000029,0xaca00208,0x7b9401d3}},	//   _مطال, ēja_, _ghền, _پھنس_, 
   {{0x49041533,0x681800da,0xb0b00118,0x00000000}},	//   _हीरो_, _rādī, ीसँग, --, 
   {{0x7bc400e4,0x68180055,0xdb240cad,0x00000000}},	//   _ýkur, _sādī, _ìròy, --, 
   {{0x1ccc1e81,0xb058049f,0x48240075,0x656c0165}},	//   ྲིག_, _slän, _ئىشق, ńcho, 
   {{0xb0596812,0x611c0421,0x4374036b,0x2aa8e0de}},	//   _plän, _sōlo, шунт, _søby_, 
   {{0x668001d5,0x3240121c,0xfc14011a,0x40c800ec}},	//   _ایدل, жерг, יקרי_, ھوءَ_, 
   {{0xc2100014,0xc0cc01f3,0x80b80303,0x00000000}},	//   زٔر_, _ኦማር_, _एकदे, --, 
   {{0xc434013d,0x00000000,0x00000000,0x00000000}},	//   _тэкъ, --, --, --, 
   {{0xb7780a28,0x44300263,0x30240588,0xb0580166}},	// [25200] raṇā, _ify_, роуп_, _tlän, 
   {{0xee356813,0xb3b808a8,0xca600166,0xef1c0205}},	//   ину_, _סמיכ, _kilе, _usül_, 
   {{0x92e8007b,0xbd843947,0x00000000,0x00000000}},	//   _حريق_, ргек, --, --, 
   {{0x339015f6,0x8c3c03b9,0x00000000,0x00000000}},	//   _الیز, _boşq, --, --, 
   {{0x44300784,0x9abc003d,0x200400e4,0x8c3c03b9}},	//   _mfy_, _liċe, _ámi_, _coşq, 
   {{0x1ccc0ed9,0xd9540aaa,0xb058005b,0x00000000}},	//   ྲིང_, منتخ, _yläo, --, 
   {{0x9abc025c,0x6d40054e,0x00000000,0x00000000}},	//   _niċe, ânat, --, --, 
   {{0xfce56814,0x988801d3,0x00000000,0x00000000}},	//   _тобо, احثہ_, --, --, 
   {{0x96f80588,0x7d016815,0x3ce56816,0x00000000}},	//   леит_, mlos, mnov_, --, 
   {{0xdeb403f9,0xd6d41e76,0x5c48001f,0x58f80327}},	//   _ƙaƙa, ёжны, _ኘሮጀክ, _ཕེམས_, 
   {{0xb8641f07,0x7d016817,0xf41c01f4,0xc87800a2}},	//   _ناشو, olos, hdät_, hoşy_, 
   {{0x7d000639,0x9abc003d,0xf8d80307,0xa5900131}},	//   nlos, _diċe, _बगिय, زگىچ, 
   {{0x5694035b,0x7d000421,0x44300334,0x3ce40010}},	//   _галт, ilos, _dfy_, inov_, 
   {{0x7d016818,0xa5d4c8b6,0xb0580139,0xaca00208}},	//   hlos, ابیر_, _eläl, _khển, 
   {{0x7d016819,0xb4b01cd1,0x3ce401ef,0x00000000}},	//   klos, _микә, knov_, --, 
   {{0x33280022,0x7998035a,0x533400c7,0x7d000477}},	//   _ицон_, _mrtw, _леит, jlos, 
   {{0x7bc40227,0xca244da8,0x3ce409a8,0xe3b001d3}},	// [25210] _żkun, ﻠﻪﺭ_, dnov_, _ہری_, 
   {{0x7d000ffb,0xc87800ee,0xe3b0009e,0x3ce43493}},	//   elos, mişe_, _চেকব, enov_, 
   {{0x7d000d16,0xe3b1681a,0x78a053f9,0xb058005b}},	//   flos, _فری_, _onov, _yläl, 
   {{0xb05801e6,0x78a00789,0xf3fc0120,0x1d2402dd}},	//   _kläm, _nnov, ngão_, імім, 
   {{0x7999681b,0xf09c0208,0x8c3c5043,0xc87803e0}},	//   _artw, _nhài_, _qoşq, nişe_, 
   {{0x78a005b8,0x799803ac,0xcf2405d9,0x7d000254}},	//   _anov, _brtw, _پرڏي, alos, 
   {{0x7d01681c,0x6ca4ab01,0x799803ac,0xc8780790}},	//   blos, _краж, _crtw, hişe_, 
   {{0x9abc038f,0xb05801e6,0x49a40220,0x7d01681d}},	//   _riċe, _oläm, _қызғ, clos, 
   {{0xf09c004d,0xd04c01e4,0x78a002f0,0x00000000}},	//   _chài_, klaɾ, _dnov, --, 
   {{0x78a1681e,0x6b99681f,0xc8780790,0x9ad4010a}},	//   _enov, _irug, dişe_, _джуч, 
   {{0x6b980165,0x47d405d9,0x00000000,0x00000000}},	//   _hrug, _ڏيار, --, --, 
   {{0xf41c02f6,0x9abc0327,0x4dc800fe,0x00000000}},	//   ydät_, _viċe, _শশাং, --, 
   {{0xf09c00a3,0x9578009d,0x98f4007b,0xf41c0139}},	//   _ghài_, гөөс_, _بثلا, ddäs_, 
   {{0x78a04ea1,0x6b982314,0x67396820,0x7d000866}},	//   _znov, _mrug, mpuj, zlos, 
   {{0xb0580664,0x7d016821,0x3ce56822,0x78a0022e}},	//   _eläm, ylos, ynov_, _ynov, 
   {{0x6b996823,0x6b04025c,0x6680036b,0xb8840005}},	//   _orug, _ཆེའོ_, _ایگل, muíñ, 
   {{0x6b98063f,0xb03000d1,0x00000000,0x00000000}},	// [25220] _nrug, سىلغ, --, --, 
   {{0x2eb48153,0xe2d80014,0x2bd8146b,0x7d016824}},	//   _आकृत, _خابچ_, _मेधा, wlos, 
   {{0x6b996825,0xfce401b9,0x3ce56826,0x00000000}},	//   _arug, божо, tnov_, --, 
   {{0x6b9807ad,0xb058005b,0xf96801a9,0x00000000}},	//   _brug, _yläm, ҳрий_, --, 
   {{0x7d016827,0x3ce48e94,0x6d400311,0xeb300e8e}},	//   rlos, rnov_, ânar, كىند, 
   {{0x6b98a2ac,0x7d00a352,0x3ce564ba,0xbc740451}},	//   _drug, slos, snov_, _گهرب, 
   {{0x6b9802e3,0xf41d6828,0x611c002d,0x1cb00327}},	//   _erug, ndär_, _rōlj, ནྡུ_, 
   {{0x6b996829,0x26c401e4,0x9abc0327,0x2bc5682a}},	//   _frug, _alno_, _biċc, рләп_, 
   {{0x78a009a8,0xeb943129,0xe9d4151e,0xf090011a}},	//   _vnov, _лит_, икә_, לנה_, 
   {{0x8c3c029f,0xdd1c0306,0x20e80205,0x00000000}},	//   _inşa, nážn, dğim_, --, 
   {{0x6b980165,0x692002dd,0x79980327,0xb0580254}},	//   _zrug, _емха, _urtw, _släm, 
   {{0x78a1682b,0x6b98035b,0xb0581b99,0x7bcc03b9}},	//   _unov, _yrug, _pläm, _əbun, 
   {{0x94040296,0x2f0c03fa,0xf3fc0798,0xf77000ec}},	//   ɛlɛ_, lüge_, rgão_, _ڀاڻ_, 
   {{0xc87841b5,0x673001d3,0xb5a55b1f,0x623400d4}},	//   rişe_, ődjö, _грий, зеру, 
   {{0xc0c802d3,0x6920110c,0x2f0c0112,0x80b800cd}},	//   _በሎም_, _uđet, nüge_, _एकशे, 
   {{0x76480f7b,0xdddc36dd,0xb0580139,0x2934010f}},	//   _hefy, _barž, _iläk, מאלן_, 
   {{0x28980a1e,0x80d8012c,0x76480153,0xb05801f4}},	// [25230] נימא, _नगरे, _kefy, _yläj, 
   {{0x6b98069c,0xdddc02d5,0x59a861ef,0x00000000}},	//   _rrug, _darž, कमार, --, 
   {{0x7648007f,0x00000000,0x00000000,0x00000000}},	//   _mefy, --, --, --, 
   {{0x6b988265,0x764803cb,0x67380210,0x00000000}},	//   _prug, _lefy, ypuj, --, 
   {{0x66dc01e1,0x7e6c03ac,0xb05801f4,0x00000000}},	//   _jákè, _fcbp, _lläk, --, 
   {{0x6b980151,0xfaa0013e,0x290c022e,0x764803cb}},	//   _vrug, дашо, _shga_, _nefy, 
   {{0x8c3c010b,0x00000000,0x00000000,0x00000000}},	//   _enşa, --, --, --, 
   {{0x6b99682c,0xddd400a2,0x00000000,0x00000000}},	//   _trug, _ýašl, --, --, 
   {{0x6b99682d,0x75288e11,0x7648002d,0x26c402fb}},	//   _urug, _aufz, _befy, _plno_, 
   {{0x6739682e,0xb8840077,0x76480142,0x96d403ce}},	//   rpuj, tuíñ, _cefy, योलॉ, 
   {{0xa879370e,0x7649682f,0x673800db,0xa9c40139}},	//   _محشر_, _defy, spuj, _усак, 
   {{0x673802f6,0x764802d0,0xe8ec0451,0x00000000}},	//   ppuj, _eefy, _ڪڻڪ_, --, 
   {{0x98f40f11,0xb0596830,0x0674010b,0x00000000}},	//   _عثما, _eläk, _дуйя, --, 
   {{0x68f96831,0xb05801e6,0x26c40115,0x7648777e}},	//   loud, _fläk, _ulno_, _gefy, 
   {{0x67216832,0xdd1c02fd,0xb0580254,0x461454f0}},	//   _iinj, vážn, _kläh, _بوغر, 
   {{0x68f96833,0x1ccc0003,0x67216834,0x41040006}},	//   noud, ྲིབ_, _hinj, ізав, 
   {{0x67216835,0x67280c6a,0x2f0d6836,0x6d4403ac}},	// [25240] _kinj, _jugj, züge_, _awja, 
   {{0x68f96837,0xdddc02d5,0x67216838,0x611c4894}},	//   houd, _varž, _jinj, _mōli, 
   {{0x68f80dd4,0x611c0270,0xdd1c0122,0xf2780375}},	//   koud, _lōli, rážn, _דריש, 
   {{0x67216839,0xdb24006a,0x660003a2,0xdd1c0122}},	//   _linj, _âsëw, _mynk, sážn, 
   {{0x68f9683a,0x60c401f7,0x6d4403ac,0x6720127b}},	//   doud, mkim, _ewja, _oinj, 
   {{0x60c5683b,0xaca0010e,0x68f8017a,0xc0d40023}},	//   lkim, _beỳa, eoud, ካዮም_, 
   {{0x1ccc0003,0x660067c3,0xed549080,0x8db40046}},	//   ྲིད_, _nynk, _мор_, _есті, 
   {{0x76480cfd,0x60c5683c,0xd911683d,0x68f9683e}},	//   _sefy, nkim, ریش_, goud, 
   {{0x6721683f,0xb058049f,0x60c56840,0x00000000}},	//   _binj, _släk, ikim, --, 
   {{0x67216841,0x60c56842,0xb0581b99,0x7bcc06be}},	//   _cinj, hkim, _pläk, _əbul, 
   {{0x6720038f,0x60c56843,0x68f96844,0x67280200}},	//   _dinj, kkim, boud, _eugj, 
   {{0x611c0618,0x3f800093,0xdddc00b8,0x68f96845}},	//   _fōli, _opku_, _abrū, coud, 
   {{0x672001e1,0x60c56846,0xdef00092,0x00000000}},	//   _finj, dkim, ግማን_, --, 
   {{0x2544066d,0x67216847,0x66000af9,0x569400fd}},	//   ből_, _ginj, _fynk, _хакт, 
   {{0x066801ec,0x44440014,0xa1956848,0x66000114}},	//   _الىۋ_, _کر٘ہ, марч, _опља, 
   {{0x67200513,0x22b405d1,0x61400241,0x33840117}},	//   _zinj, _aşkı_, _sàlò, _дуов, 
   {{0x6720015c,0x00000000,0x00000000,0x00000000}},	// [25250] _yinj, --, --, --, 
   {{0x60c56849,0x68f884b6,0x6dc5684a,0x14e0000d}},	//   akim, zoud, يزال, _पगडण, 
   {{0xf09c00a3,0xdddc025c,0x3f8001a6,0xe4480150}},	//   _bhàt_, _garż, _epku_, _الۋى_, 
   {{0x61e8022c,0x7ae8002f,0x00000000,0x00000000}},	//   údle, enft, --, --, 
   {{0x68f9684b,0x6b841216,0x69d00037,0x00000000}},	//   voud, تشال, _भेजी, --, 
   {{0x68f9684c,0x00000000,0x00000000,0x00000000}},	//   woud, --, --, --, 
   {{0x68f9684d,0x6721684e,0x672802d3,0x2bd80456}},	//   toud, _rinj, _sugj, _मेरा, 
   {{0x6721684f,0x66016850,0xb05804e6,0x611d6851}},	//   _sinj, _rynk, _bläi, _pōli, 
   {{0x67216852,0x68f96853,0x8c440352,0xdb540961}},	//   _pinj, roud, _меңе, _овты, 
   {{0x254400dd,0x6600138f,0x60c56854,0x00000000}},	//   től_, _pynk, zkim, --, 
   {{0x60c56855,0x67216856,0xb058049b,0x68f96857}},	//   ykim, _vinj, _eläi, poud, 
   {{0x2544066d,0x67201389,0xb0580a40,0x67280022}},	//   ről_, _winj, _fläi, _tugj, 
   {{0x67200020,0xb0580a40,0x07a43a47,0x66000ea0}},	//   _tinj, _gläi, _халн, _wynk, 
   {{0x672001c8,0xafd80158,0x66016858,0xc8a807f7}},	//   _uinj, _udøy, _tynk, कावट, 
   {{0x60c4049b,0x01080c8b,0xd1740150,0xb64401ec}},	//   tkim, مترو_, мыты, _ﻋﺎ_, 
   {{0xf9901a4c,0x60c40006,0xb0580108,0x00000000}},	//   ערן_, ukim, _yläi, --, 
   {{0x2bd8146c,0x82340228,0x00000000,0x00000000}},	// [25260] _मेला, _ىردا, --, --, 
   {{0x60c56859,0xf09c08c2,0x0288009f,0x00000000}},	//   skim, _bhàs_, _اَدي_, --, 
   {{0xf09c01c3,0x60c468af,0xb2b8011a,0x00000000}},	//   _chàs_, pkim, _המיר, --, 
   {{0x2fd02776,0xf53400c8,0xdddc00b8,0x6e38013d}},	//   ïngö_, לטער_, _sarų, _ğube, 
   {{0x6e3803ee,0xb0980375,0x7f54001f,0x8c3c0205}},	//   _şube, _היכר, ምጃዎች, _inşl, 
   {{0x0ba807d2,0xf09c0e89,0x2bd80073,0x195801e0}},	//   تامى_, _fhàs_, _मेळा, ҡаһы_, 
   {{0x24801050,0xac080150,0xdddc002b,0xbef80210}},	//   _obim_, _ۇركە_, _varų, ्तीन_, 
   {{0xec7401f4,0xb76400db,0x00000000,0x00000000}},	//   _нпс_, птой, --, --, 
   {{0xaca00208,0x20e803b9,0x00000000,0x00000000}},	//   _nhộn, mşid_, --, --, 
   {{0xb05804c4,0x76a85265,0x2481685a,0x2b5400bc}},	//   _vläi, стив_, _abim_, řecí_, 
   {{0xf09c01ab,0x7bc00165,0x6930013a,0xf7f41291}},	//   _mhàr_, lyou, _přeř, _کساد, 
   {{0xc98400c6,0xca2402dd,0xf54000f7,0x00000000}},	//   _تشكي, _تۋىن_, мдүү, --, 
   {{0x7bc0763f,0xf480044e,0xc8640050,0x00000000}},	//   nyou, _ክዛረብ_, _زان٘, --, 
   {{0x7bc00369,0x8c3d685b,0xb0bc000d,0x00000000}},	//   iyou, _anşl, _एकहग, --, 
   {{0x7bc00399,0x00000000,0x00000000,0x00000000}},	//   hyou, --, --, --, 
   {{0x7bc00007,0x1bec03ce,0x00000000,0x00000000}},	//   kyou, जपाल_, --, --, 
   {{0xf09c00a3,0x7bc00399,0x00000000,0x00000000}},	// [25270] _bhàr_, jyou, --, --, 
   {{0xf09c01c3,0x953c0092,0x00000000,0x00000000}},	//   _chàr_, _የሰንደ, --, --, 
   {{0xad2404d3,0x00000000,0x00000000,0x00000000}},	//   سراو, --, --, --, 
   {{0x3e200092,0x00000000,0x00000000,0x00000000}},	//   _ስታዲየ, --, --, --, 
   {{0xdb2000d0,0x7bc1685c,0xaee001ec,0xdfd80395}},	//   _štád, gyou, _كۋرى, _еър_, 
   {{0xf09c01ab,0xef1c01d3,0x00000000,0x00000000}},	//   _ghàr_, _csüt_, --, --, 
   {{0x2d8001f5,0x00000000,0x00000000,0x00000000}},	//   _upje_, --, --, --, 
   {{0x26f4a5b3,0x8cc819b6,0x7bc00007,0xb05802f6}},	//   ुत्र_, _بورق_, byou, _eläv, 
   {{0x6d54002e,0x4be800f2,0x00000000,0x00000000}},	//   lsxa, _بکاپ_, --, --, 
   {{0x05740597,0x79940034,0x00000000,0x00000000}},	//   واجد, ływa, --, --, 
   {{0xfe3408c3,0x00000000,0x00000000,0x00000000}},	//   ורתי_, --, --, --, 
   {{0x69c06b97,0xb98401b9,0xf9f80375,0xaca0004d}},	//   myne, _ютуқ, _והעמ, _phộn, 
   {{0x7e081d94,0x69c1685d,0xb058005b,0x00000000}},	//   _वर्ग_, lyne, _yläv, --, 
   {{0xdb0000d8,0x41280395,0x00000000,0x00000000}},	//   _armê, жово_, --, --, 
   {{0x69c1685e,0x75d1685f,0x7bc00007,0x40940131}},	//   nyne, _ليوا, zyou, мрат, 
   {{0xf09c01c3,0x00000000,0x00000000,0x00000000}},	//   _shàr_, --, --, --, 
   {{0x7bc00369,0x973002d3,0x69c000ad,0xa92400d0}},	// [25280] xyou, _ተባዕት, hyne, _zaľú, 
   {{0x7bc076ed,0xbef800dc,0x69c16860,0xef1404f5}},	//   vyou, ्तेन_, kyne, дму_, 
   {{0xbd896861,0xdcfc00dc,0x1cac031c,0x8c3c0139}},	//   تنان_, _aprā, _ྗོད_, _hoşy, 
   {{0x7bc15112,0x69c16862,0xb0582305,0x999c0010}},	//   tyou, dyne, _bläu, tavž_, 
   {{0x6d6402d5,0xfbd03500,0xf09c00a3,0x69c00363}},	//   _įraš, ختا_, _thàr_, eyne, 
   {{0x7bc004ce,0x6d5400ac,0x79a401fc,0x69c00042}},	//   ryou, bsxa, дрие, fyne, 
   {{0x7bc0019b,0xbdc401d9,0xf1c000ef,0xe5dc00ee}},	//   syou, _تۯاے_, _gošē_, _çuňň, 
   {{0x7bc0007f,0x00000000,0x00000000,0x00000000}},	//   pyou, --, --, --, 
   {{0xb058cc35,0x69c01368,0x2f00032e,0x00000000}},	//   _gläu, ayne, _örfá_, --, 
   {{0x69c00363,0xd6d0007b,0x00000000,0x00000000}},	//   byne, اقد_, --, --, 
   {{0xb05801e6,0x00000000,0x00000000,0x00000000}},	//   _klät, --, --, --, 
   {{0x6ba40166,0x00000000,0x00000000,0x00000000}},	//   _ürgä, --, --, --, 
   {{0x6e340175,0x00000000,0x00000000,0x00000000}},	//   ycxb, --, --, --, 
   {{0x27e80419,0x00000000,0x00000000,0x00000000}},	//   úcne_, --, --, --, 
   {{0xdb0002d3,0xa5f4013d,0x623401ec,0x2d84025c}},	//   _armë, _оешу_, тесу, ħnek_, 
   {{0x65e00022,0x61e80332,0x00000000,0x00000000}},	//   _шәыҧ, údla, --, --, 
   {{0x3cf005f9,0x8c3c010e,0xd25002f2,0x69c0012d}},	// [25290] ंचने_, _goşy, _ینک_, zyne, 
   {{0x129400d8,0x999c00c0,0x00000000,0x00000000}},	//   _џинџ, navų_, --, --, 
   {{0xb05803fa,0xdb0001c7,0xdcfc00e2,0xa3b812e9}},	//   _blät, _ermë, _sprā, _فایر_, 
   {{0x69c11d01,0xaf5001e0,0xefec0092,0xe04400d8}},	//   vyne, _инмә, ቀሰው_, _инџи, 
   {{0x69c00368,0x1c44187f,0x7c5400cf,0x00000000}},	//   wyne, тнім, رلور_, --, 
   {{0x69c16863,0x4994ed5a,0xb058023a,0x70bc01f9}},	//   tyne, ешит, _elät, _एकुल, 
   {{0xdd9400c7,0xb05842a7,0x9f04007b,0xbab000db}},	//   _иары, _flät, _شوفو, امىب, 
   {{0x69c16864,0xb0596865,0xaf840092,0xef1c000d}},	//   ryne, _glät, _ምርትና_, _tsüs_, 
   {{0xc7240323,0x2ab401ec,0x07a4011c,0x80d0000d}},	//   ндий, _оңды_, хапн, _सतसइ, 
   {{0xe9a96866,0x87c401d9,0xa9c400f0,0x69c00a89}},	//   _ودان_, ِتھٕ, _осек, pyne, 
   {{0x20e80356,0x06080815,0xb0580108,0xab600135}},	//   nşic_, янок_, _ylät, ħżun, 
   {{0xdb00642b,0x9964033a,0xd7c800ec,0x00000000}},	//   _armè, _штул, _ڪوهه_, --, 
   {{0x17980108,0x00000000,0x00000000,0x00000000}},	//   _овцы_, --, --, --, 
   {{0x981420ad,0xb0580267,0xfbd0011a,0x00000000}},	//   _شبنا, _oläs, נתם_, --, 
   {{0x016433ea,0xb38001ec,0xe5c80241,0x5154004e}},	//   экво, _ұлыл, _ípàà, ктту, 
   {{0xdb00067c,0x044804b4,0x3ea801ab,0x6e380139}},	//   _ermè, _эпик_, _snbt_, _ğuba, 
   {{0x6e380365,0xb0580139,0x00000000,0x00000000}},	// [252a0] _şuba, _aläs, --, --, 
   {{0xed4c0272,0xb05840fc,0x00000000,0x00000000}},	//   ڵپه_, _slät, --, --, 
   {{0x63a4008c,0xb0593515,0x629c8eaf,0x863c001f}},	//   _hrin, _plät, mdro, _የአንድ, 
   {{0x63a43d28,0x20c40022,0x629c2f7f,0x80b80073}},	//   _krin, _римҭ, ldro, _एकटे, 
   {{0x629c0549,0x8c640212,0x3b0800d8,0x00000000}},	//   odro, ттєд, педо_, --, 
   {{0x629d6867,0xb0596868,0x63a56869,0xbf15686a}},	//   ndro, _fläs, _mrin, _سوزب, 
   {{0x629d686b,0xb05803fa,0x6da00075,0x58d4004e}},	//   idro, _gläs, _йира, кокт, 
   {{0x63a5686c,0xf1b00302,0x774802d3,0xeb940032}},	//   _orin, רסה_, _ዓሰርተ, фиә_, 
   {{0x7d01686d,0xb0595a8b,0xbb480014,0x9abc0327}},	//   moos, _klär, _رلان_, _jiċk, 
   {{0x629d686e,0x468001d5,0xb0580108,0xa8100124}},	//   jdro, иқча, _yläs, ыдыш, 
   {{0xaa540214,0x629c3d32,0xc95400db,0x499800d4}},	//   _سلنا_, ddro, _атчы, _отця_, 
   {{0x7d000548,0x629c0af9,0xed680023,0x64a400d8}},	//   noos, edro, _ትነብር_, гаџа, 
   {{0x63a5686f,0xdb0083d2,0x629d6870,0x66e400e2}},	//   _crin, _armé, fdro, _sūkņ, 
   {{0x7d016871,0x63a4ee0c,0x7aa40490,0x00000000}},	//   hoos, _drin, _टोमॅ, --, 
   {{0x63a56872,0x30a4049b,0x7d016873,0x00000000}},	//   _erin, нрав, koos, --, 
   {{0x63a56874,0x629d6875,0x0c80001f,0x7d000036}},	//   _frin, adro, _የሌሎች_, joos, 
   {{0x7d016876,0xb05801c7,0xdb0004e6,0xdb4404d3}},	// [252b0] doos, _blär, _ermé, _دێ_, 
   {{0xdef84734,0xb0580793,0x2bd81f13,0x2540001f}},	//   ных_, _pläs, _मेगा, _የተቀሩ, 
   {{0x2d856877,0x63a56878,0x7d000083,0x32cd6879}},	//   ïne_, _zrin, foos, _güya_, 
   {{0x9e04972b,0x7d01687a,0xb0580139,0x63a54675}},	//   учул, goos, _elär, _yrin, 
   {{0xb05801e3,0x98bc0064,0x00000000,0x00000000}},	//   _flär, lsvė_, --, --, 
   {{0x09e5687b,0x629802d2,0x00000000,0x00000000}},	//   колн, _óvot, --, --, 
   {{0x7d01687c,0xdef40006,0x00000000,0x00000000}},	//   boos, _спры, --, --, 
   {{0x629c8864,0xdb4c4732,0x3ce4054e,0x2f0c0112}},	//   zdro, _کێو_, ciov_, zügl_, 
   {{0x629d687d,0x23e00254,0xb058005b,0x00000000}},	//   ydro, _पेंद, _ylär, --, 
   {{0x2cbc0cf9,0x63a5687e,0x629c00b5,0x9b5802e8}},	//   _houd_, _rrin, xdro, _чифт_, 
   {{0x63a5687f,0x2cbd6880,0x601800d2,0x04456881}},	//   _srin, _koud_, _kúmí, кенн, 
   {{0x629c2ab0,0x32cc03ee,0x16700022,0xf41c0139}},	//   wdro, _rüya_, ақәр, ldäy_, 
   {{0x629d6882,0x2cbd6883,0x291d6884,0x601802d2}},	//   tdro, _moud_, mmua_, _múmí, 
   {{0x63a4928f,0x629c39b4,0xa24801ed,0x2cbc011a}},	//   _vrin, udro, ڈیکل_, _loud_, 
   {{0xa28457e6,0x42740214,0x7d0024be,0xb0580166}},	//   نیکو, _یادآ, yoos, _rlär, 
   {{0x629d6885,0x2cbc01f5,0x291c0051,0x00000000}},	//   sdro, _noud_, nmua_, --, 
   {{0x6e382220,0x291c7343,0xca241df2,0x63a56886}},	// [252c0] _đubr, imua_, ﻠﺪﺍ_, _urin, 
   {{0x7d016887,0x291c0200,0x0fe807a5,0x00000000}},	//   woos, hmua_, хлуқ_, --, 
   {{0x2cbd6888,0xf09c0241,0xed556889,0xc10401e2}},	//   _boud_, _ikàn_, вох_, _لودي, 
   {{0xb0241c5c,0x2cbc0c3a,0xbb440024,0x9abc031c}},	//   ركەم_, _coud_, ведк, _tiċk, 
   {{0x7d01688a,0xeb301e0e,0x2bb40574,0x2cbc0221}},	//   roos, لىند, _आपणा, _doud_, 
   {{0x6e40c23f,0x21200219,0x291d688b,0x7d01688c}},	//   _верз, lmih_, emua_, soos, 
   {{0x7d01688d,0x610c0730,0x7c947b68,0xb0589e50}},	//   poos, eßli, _ирац, _kläp, 
   {{0x2cbd688e,0x21200652,0x7d00011f,0x291c01fb}},	//   _goud_, nmih_, qoos, gmua_, 
   {{0x6c7800c8,0x21200548,0x2258030a,0xf09c0241}},	//   _קאמפ, imih_, kark_, _okàn_, 
   {{0x291d688f,0x70bc0316,0x2bd80b4c,0x6d4000e4}},	//   amua_, _एक्ल, _मेटा, ínag, 
   {{0xaa34008f,0x00000000,0x00000000,0x00000000}},	//   _סטאק_, --, --, --, 
   {{0xf09c0241,0x21200427,0xe944187c,0x291c03e0}},	//   _akàn_, jmih_, _شرمی, cmua_, 
   {{0x21200219,0x32cc010e,0x00000000,0x00000000}},	//   dmih_, _düyn_, --, --, 
   {{0xd6d02ad9,0x66e16890,0x1b10045e,0xb0580309}},	//   _دقت_, _коча, াদকে_, _aläp, 
   {{0xe7140302,0x00000000,0x00000000,0x00000000}},	//   _שחור_, --, --, --, 
   {{0x22580036,0x1ccc0327,0x2998011a,0x00000000}},	//   aark_, ིིས_, וסלמ, --, 
   {{0x22596891,0x2cbd6892,0x9f340220,0x00000000}},	// [252d0] bark_, _roud_, иеті, --, 
   {{0x2cbd6893,0x2120102c,0x54b40166,0x5ed401c6}},	//   _soud_, amih_, _рәүф, ажуу, 
   {{0x712419b6,0x9f040a2c,0x2cbd6894,0xb05801f4}},	//   _لرحل, جولو, _poud_, _fläp, 
   {{0x0ce0febc,0x3590069c,0x2bb41be1,0x00000000}},	//   যক্ত, _ዜጋታት_, _आपदा, --, 
   {{0x2cbc030a,0x00000000,0x00000000,0x00000000}},	//   _voud_, --, --, --, 
   {{0x49993c1b,0x2cbc0926,0x291c0218,0xc8796895}},	//   етия_, _woud_, wmua_, mişi_, 
   {{0xc8785556,0xb058023a,0x2cbc0156,0x48e556f3}},	//   lişi_, _yläp, _toud_, локв, 
   {{0x291d6896,0xdb000356,0x3a70013d,0x00000000}},	//   umua_, _urmî, аләр, --, 
   {{0x291d6897,0xc8782ba3,0xafd821e3,0x473400f2}},	//   rmua_, nişi_, _ufød, دربز, 
   {{0x291c005a,0xdb500014,0x21200010,0xaab40037}},	//   smua_, _گَے_, zmih_, _इचिक, 
   {{0x2258a77e,0xc8794092,0xe7900133,0x291c0051}},	//   vark_, hişi_, _چاتک, pmua_, 
   {{0xdb500014,0xaca001fb,0xc8787225,0x9abc0135}},	//   _دَے_, _khốn, kişi_, _riċi, 
   {{0xb3804f88,0xe81c0037,0x764c00e5,0x00000000}},	//   блял, मेशा_, ényü, --, 
   {{0xb05804f3,0xdb2001a2,0xc8796898,0x420800db}},	//   _släp, _štúd, dişi_, енго_, 
   {{0xaca0ba77,0xb05801b8,0xe81c330a,0x2bd872c0}},	//   _akọn, _pläp, मेरा_, _मेघा, 
   {{0x9abc0003,0x2b5c03b9,0x00000000,0x00000000}},	//   _viċi, _ovuc_, --, --, 
   {{0x443001ed,0x03a4013e,0x21207cb8,0x00000000}},	// [252e0] _igy_, _сипо, rmih_, --, 
   {{0xa114004b,0x21200427,0x98ac00cd,0x225803b9}},	//   اوړت, smih_, _mudā_, qark_, 
   {{0xc0e4016c,0xbc680424,0xfc6400a7,0x5194010a}},	//   _бонк, فمان_, гълн, _вăха, 
   {{0x3a3c02fa,0x28a000bc,0x00000000,0x00000000}},	//   _sftp_, _खोलि, --, --, 
   {{0xaca007ae,0xafe0086f,0xc10401ec,0xc8780356}},	//   _chốn, _гоял, _لوگي, cişi_, 
   {{0xf41c01f4,0x00000000,0x00000000,0x00000000}},	//   meät_, --, --, --, 
   {{0xca756899,0xf41c01f4,0x4a740166,0x00000000}},	//   ручы, leät_, рычт, --, 
   {{0xee04010b,0x2d840327,0x00000000,0x00000000}},	//   _сесл_, ħnet_, --, --, 
   {{0x8c3c0139,0xf7e8007b,0xe81c6620,0x00000000}},	//   _başf, عربى_, मेला_, --, 
   {{0xdb0002fb,0x4aa80214,0x4431689a,0x00000000}},	//   _krmí, _لامپ_, _agy_, --, 
   {{0x39443c85,0x44300280,0xa96400a7,0x03e0009e}},	//   _снег, _bgy_, _биха_, _গুলী_, 
   {{0x799811c1,0x7ae9689b,0xc8794c76,0xaee0002b}},	//   _istw, lift, yişi_, _kaṃc, 
   {{0x98ac0055,0x533400d4,0x00000000,0x00000000}},	//   _gudā_, регт, --, --, 
   {{0x443055b4,0x7ae8c286,0xd8a800ec,0x00000000}},	//   _egy_, nift, _سهڻو_, --, 
   {{0x7659689c,0x799803ac,0x94d40816,0xb880013d}},	//   maty, _jstw, _войц, _çíst, 
   {{0x765875d4,0x44300083,0x75380175,0x32cc0205}},	//   laty, _ggy_, mqtz, _tüyo_, 
   {{0x7ae9689d,0xdb000166,0x799802d0,0x60f80276}},	// [252f0] kift, _armí, _lstw, унтя_, 
   {{0xc87917cb,0x799925bf,0x68280209,0x7c74001f}},	//   rişi_, _ostw, _hödü, _የምለው_, 
   {{0xdef83e25,0xe7e8772c,0x443000a2,0x00000000}},	//   уыт_, _जेना_, _ygy_, --, 
   {{0xaf3415fa,0xdd986c31,0x7659689e,0x8c3c0209}},	//   _مرست, ышу_, haty, _maşg, 
   {{0x7659689f,0x799968a0,0x7ae968a1,0x00000000}},	//   katy, _astw, fift, --, 
   {{0x7ae817c0,0x765968a2,0x9e34011c,0x00000000}},	//   gift, jaty, _герч, --, 
   {{0x799802d0,0x765968a3,0x1a6857be,0x2f0c010e}},	//   _cstw, daty, طینی_, jügi_, 
   {{0x08c40364,0xaca007ae,0x4bb0004b,0x480800d1}},	//   рбин, _thốn, _ویاړ, кейн_, 
   {{0x7ae8208d,0x799968a4,0x765968a5,0x8c180451}},	//   bift, _estw, faty, _شيئر_, 
   {{0x765968a6,0x6b980a81,0x8c3c09a5,0x458510b0}},	//   gaty, _isug, _başg, агов, 
   {{0x1cd40489,0x799803ac,0x9f9002d2,0x00000000}},	//   ེལཝ_, _gstw, _lúða_, --, 
   {{0x03a480df,0x99d40a2c,0x8c3c0432,0x76580124}},	//   аимо, _اتكا, _daşg, aaty, 
   {{0x765968a7,0x00000000,0x00000000,0x00000000}},	//   baty, --, --, --, 
   {{0xdb000261,0x6b9801f7,0xb7d80375,0x7998015d}},	//   _irmã, _msug, _בקני, _ystw, 
   {{0xf09c0248,0x45180276,0x2738004d,0x00000000}},	//   _baà_, _иция_, _hên_, --, 
   {{0x6b98037e,0x443001d3,0x9f9002d2,0x27380051}},	//   _osug, _ugy_, _búða_, _kên_, 
   {{0x442568a8,0x8fd42cc8,0x43742519,0x7ae80205}},	// [25300] _ào_, бәрә, _туйт, yift, 
   {{0xf8d00882,0x273968a9,0x7994012d,0x8c3c0139}},	//   _तत्प, _mên_, ływi, _yaşg, 
   {{0x273801dc,0x6b9800e4,0xf09d68aa,0x3cf00254}},	//   _lên_, _asug, _faà_, ंचले_, 
   {{0x7ae807de,0x0d9812b9,0xaee000cd,0x76580210}},	//   wift, ытуы_, _paṃc, zaty, 
   {{0x273801dc,0xac0568ab,0x7ae968ac,0x6dc400d0}},	//   _nên_, анца_, tift, včať, 
   {{0x41b81408,0x4ed40b2c,0x6d4002fb,0x2bb40cf1}},	//   _उपास, _люст, ínac, _आपरा, 
   {{0xaca007ae,0x765968ad,0x8c3cec3e,0x6b980036}},	//   _chồn, vaty, _başd, _esug, 
   {{0x765968ae,0x273807ae,0x7d0805d9,0x7ae80ba7}},	//   waty, _bên_, _شيءِ_, sift, 
   {{0x765968af,0xeb95020f,0x888168b0,0x98ac054e}},	//   taty, _кит_, سیون, _audă_, 
   {{0xb6c48c75,0x6ae08740,0x27380208,0x7ae80009}},	//   рсий, _джуз, _dên_, qift, 
   {{0x765968b1,0xdcfd2a2e,0x67380194,0x799802d0}},	//   raty, _sprę, aquj, _ustw, 
   {{0x1ad4006c,0x765968b2,0xdb000276,0x95b400c7}},	//   _тўғр, saty, _urmâ, арҭә, 
   {{0x765968b3,0x3864005a,0x27380142,0x00000000}},	//   paty, _idor_, _gên_, --, 
   {{0x765800f1,0x8c3c0205,0x00000000,0x00000000}},	//   qaty, _taşg, --, --, 
   {{0x2258081d,0x386409a8,0x8c3d68b4,0x9f900162}},	//   рисы_, _kdor_, _yaşd, _súða_, 
   {{0x27380016,0xb4440139,0x8c3c03e0,0x9f90032e}},	//   _yên_, _тэкк, _kaşe, _púða_, 
   {{0x1cc40327,0x00000000,0x00000000,0x00000000}},	// [25310] _ཏྭེ_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x38653d74,0xf1a80345,0x00000000,0x00000000}},	//   _odor_, _شاده_, --, --, 
   {{0x8c1805d4,0xa13421de,0x75c80213,0x8bd801ec}},	//   هيار_, _گریش, məzd, лмес_, 
   {{0x57b0098a,0x8c3c0166,0x00000000,0x00000000}},	//   जमोह, _naşe, --, --, 
   {{0x386568b5,0xfbc41c82,0xaca001fb,0x273801fb}},	//   _ador_, _শেহত, _phồn, _rên_, 
   {{0x2738004d,0x00000000,0x00000000,0x00000000}},	//   _sên_, --, --, --, 
   {{0x6d4400fb,0x6b9968b6,0x98ac0356,0x8c3c0bbc}},	//   _itja, _tsug, _rudă_, _başe, 
   {{0x6b981140,0x386400f3,0x1bd40229,0xa9a001d5}},	//   _usug, _ddor_, _дотя, сиқд, 
   {{0x4ec4015b,0x6738022f,0x613801f2,0x86980108}},	//   _এগুল, rquj, ụlit, утит_, 
   {{0x99d568b7,0x09e400bd,0x273968b8,0x776002d0}},	//   _وتما, _পুরা, _wên_, _evox, 
   {{0x273801dc,0xdb00172e,0xf09c004d,0x4814010b}},	//   _tên_, _irmá, _thày_, _лмес, 
   {{0xb05804f3,0xb3806c20,0x6738013c,0x8c3c0139}},	//   _poän, плял, qquj, _kaşb, 
   {{0x32400724,0x6d4402d0,0x32500108,0x56940d1d}},	//   зерг, _otja, звёр, _мачт, 
   {{0x6d4401ee,0x113968b9,0x062400e5,0x00000000}},	//   _ntja, ияты_, _دےدی_, --, 
   {{0x8c3c0598,0xaca0001e,0x50b401c0,0x00000000}},	//   _yaşe, _khổn, осуу, --, 
   {{0x6d4400da,0x644568ba,0x20e8010e,0xbf14009a}},	// [25320] _atja, _ifii, lşik_, مورب, 
   {{0x30240022,0x00000000,0x00000000,0x00000000}},	//   соуп_, --, --, --, 
   {{0x20e800ac,0xce34004b,0x05080154,0x72980115}},	//   nşik_, زونک, রগীর_, _גסיס, 
   {{0x2700069f,0x7fb40153,0x00000000,0x00000000}},	//   रकुर_, _лёгі, --, --, 
   {{0x8c3c0365,0xdb0168bb,0x6d44035a,0x2cb40216}},	//   _başb, _armá, _etja, _šedé_, 
   {{0x25600790,0x7c6401c8,0x00000000,0x00000000}},	//   kıl_, _گاسل, --, --, 
   {{0x644568bc,0xf98804fb,0x691400e4,0x00000000}},	//   _ofii, اخته_, rãen, --, 
   {{0xeb9400c6,0x7c6400aa,0x64440083,0x25602791}},	//   _яиσ_, _داسل, _nfii, dıl_, 
   {{0x656002d0,0x38640427,0xaca00208,0x00000000}},	//   _avnh, _vdor_, _chổn, --, 
   {{0x64443cd4,0xeab400d1,0x7c6c0023,0x2bc4004e}},	//   _afii, _лйу_, _ትበሃል_, _улуп_, 
   {{0xa9a40124,0x25602737,0xb864104c,0x00000000}},	//   _гәыҧ_, gıl_, _هاشو, --, 
   {{0xb808045e,0xf7986356,0x8c3c0790,0x2f0c002f}},	//   শেষত_, _منصب_, _taşe, lügt_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x64442e87,0x2f0c0e78,0x25608411,0x00000000}},	//   _efii, nügt_, bıl_, --, 
   {{0x64440083,0x78a00037,0x25600213,0x00000000}},	//   _ffii, _kaov, cıl_, --, 
   {{0x957c006d,0x78a0001e,0xe81c11a0,0x00000000}},	//   rząd, _jaov, मेका_, --, 
   {{0xa3440323,0x6d4409e8,0x78a000ec,0x91e004c5}},	// [25330] _нээл, _stja, _maov, _মুখখ, 
   {{0xb8c80867,0xd250cae0,0x78a168bd,0xa80400a2}},	//   _བལ_, _تند_, _laov, leıä, 
   {{0xe3b001d5,0x8d94e098,0x64440175,0xb05800a2}},	//   _قری_, تلاش, _yfii, _hoäm, 
   {{0x78a016a3,0x33300051,0x00000000,0x00000000}},	//   _naov, _hixx_, --, --, 
   {{0xb3242b65,0x25607230,0x2f0c03fa,0x70240014}},	//   _རྫོང_, zıl_, fügt_, _دردٕ, 
   {{0x2560a090,0x29d0063f,0x8c3c06be,0xe1f000e5}},	//   yıl_, ṭa_, _başc, _آسی_, 
   {{0x78a00851,0x6d442e95,0x256000ac,0x8c3c054e}},	//   _baov, _utja, xıl_, _caşc, 
   {{0x78a11b1a,0x25600baa,0x3330025c,0x88c813d6}},	//   _caov, vıl_, _lixx_, рлив_, 
   {{0xc7a40026,0x8c3c0166,0x78a00051,0x00000000}},	//   ципк, _taşb, _daov, --, 
   {{0x46e968be,0x6444b900,0x33300036,0x25600db1}},	//   рдон_, _sfii, _nixx_, tıl_, 
   {{0x04c8027d,0xc8c80050,0x9abc031c,0x8c3c0356}},	//   لودي_, _پوشن_, _tiċr, _gaşc, 
   {{0x78a00165,0xca340873,0x071801ad,0x25602d1c}},	//   _gaov, ﯖﯩﺰ_, _नीरव_, rıl_, 
   {{0x25600ab7,0x68e8010a,0xe6102ab4,0x00000000}},	//   sıl_, _imgd, _کشش_, --, 
   {{0xf41c0295,0x78a00cf4,0xb0580139,0x17c40022}},	//   pfän_, _zaov, _iläy, _хашҭ, 
   {{0x26c40093,0x3330025c,0x78a0009f,0x6444045a}},	//   _iono_, _dixx_, _yaov, _tfii, 
   {{0x26c568bf,0x644568c0,0x20e80311,0xdc1800ef}},	//   _hono_, _ufii, oşii_, cāķo, 
   {{0x823568c1,0x26c568c2,0x80c810eb,0x20e8054e}},	// [25340] _وردا, _kono_, _रवीं, nşii_, 
   {{0x26c568c3,0xafd85b47,0x3390004b,0x2fcc0174}},	//   _jono_, _iføl, _کلیز, øgga_, 
   {{0x8658001f,0xe8dc0051,0x00000000,0x00000000}},	//   _ለአንድ, _ngỏm_, --, --, 
   {{0x26c568c4,0x290c01af,0xadb400ae,0x00000000}},	//   _lono_, _nkga_, تهما_, --, 
   {{0x7ed400d6,0x26c40618,0x78a0001e,0x60c8045f}},	//   _дівч, _oono_, _raov, êdmu, 
   {{0x4400006d,0x290cbe31,0xf96968c5,0x61380115}},	//   _लखनऊ_, _akga_, арий_, _eŭle, 
   {{0x78a0dc85,0x2480003e,0x68e80432,0xe604af1c}},	//   _paov, _ocim_, _bmgd, _آش_, 
   {{0x26c48cae,0x2bc47f6d,0xec7400a7,0xb764133a}},	//   _aono_, сләп_, _мпс_, отой, 
   {{0x78a01311,0xd6d000c6,0x592400e5,0x00000000}},	//   _vaov, فقة_, _ہوئے, --, 
   {{0xf99010fe,0x24800438,0x78a000ec,0x8c3c0205}},	//   _يبا_, _acim_, _waov, _taşc, 
   {{0x26c568c6,0x957c068f,0x78a104d5,0x33300327}},	//   _dono_, dząc, _taov, _rixx_, 
   {{0x26c418a6,0x33300a06,0x8c3d15df,0x394c5161}},	//   _eono_, _sixx_, _kaşa, mpfs_, 
   {{0x26c4096b,0xa34405f5,0x33300036,0x181804fb}},	//   _fono_, дэсл, _pixx_, _اراک_, 
   {{0x26c40099,0xc76402dd,0x8c3cd95c,0x24800240}},	//   _gono_, _ءانى, _maşa, _ecim_, 
   {{0xa2cc0882,0x248000db,0x925802dd,0xc7e80014}},	//   _सकर्, _fcim_, _қант_, _پى۪ن_, 
   {{0x26c4008f,0x00000000,0x00000000,0x00000000}},	//   _zono_, --, --, --, 
   {{0x26c44d11,0xdddc0419,0x00000000,0x00000000}},	// [25350] _yono_, _herň, --, --, 
   {{0x957c006d,0xdbd801a8,0xd25000ec,0x00000000}},	//   cząc, væða, _ڪنگ_, --, 
   {{0x4298011a,0x00000000,0x00000000,0x00000000}},	//   _הסתב, --, --, --, 
   {{0x8c3c3b13,0x8f351910,0xdbd80008,0x7644016b}},	//   _başa, _немц, tæða, ɛkye, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7f38025f,0x8c3c09a5,0xdbd80008,0x28a003f8}},	//   _לעשו, _daşa, ræða, _खोजि, 
   {{0x26c568c7,0x2bb4012d,0x00000000,0x00000000}},	//   _rono_, _आपका, --, --, 
   {{0x26c4156b,0xb0580793,0x00000000,0x00000000}},	//   _sono_, _pläy, --, --, 
   {{0x26c568c8,0x46e81823,0x8c3c010e,0xe7a400d1}},	//   _pono_, йдин_, _gaşa, تۇشى_, 
   {{0xe8940014,0xdddc01ef,0x15ec000d,0x00000000}},	//   _ژماں_, _berň, _छेहर_, --, 
   {{0x26c568c9,0x00000000,0x00000000,0x00000000}},	//   _vono_, --, --, --, 
   {{0x8c3c82aa,0x26c408e7,0xdb000e78,0xdddc00ee}},	//   _yaşa, _wono_, _ermä, _derň, 
   {{0x26c40325,0x22ac0085,0x7de001ed,0xd04c01e4}},	//   _tono_, lɔkɔ_, _kísé, ciaɩ, 
   {{0x68f80037,0xd9b000d1,0x46a40395,0x00000000}},	//   lnud, _سەۋد, _хакв, --, 
   {{0x22ac043b,0x052968ca,0x76b80375,0x957c033f}},	//   nɔkɔ_, _локк_, _למספ, rząc, 
   {{0x68f805a4,0x2480110c,0xccfc013f,0x957c0034}},	//   nnud, _ucim_, brɛɛ_, sząc, 
   {{0x67200076,0xfe7002e9,0x68f80254,0xf1bc0135}},	// [25360] _khnj, فدا_, inud, ġġaw_, 
   {{0x68f80a40,0x6fb000c6,0x22ac013f,0x8c3c013d}},	//   hnud, عملا, kɔkɔ_, _raşa, 
   {{0xb3240135,0x68f8005c,0x8c3c8021,0x00000000}},	//   _རྫིང_, knud, _saşa, --, 
   {{0x8c3d68cb,0xfd1168cc,0x741000f7,0x8234113e}},	//   _paşa, رجا_, _توۋا, _ورگا, 
   {{0x9e7404a9,0x6720127b,0x61ec0153,0x8c3c013d}},	//   _يۇرت, _ohnj, žolė, _qaşa, 
   {{0x60c404b9,0x6448013f,0xaa545716,0x68f8000d}},	//   ljim, ɛdie, пишу_, enud, 
   {{0xd9101c40,0x7de00332,0x60c40153,0x00000000}},	//   پیش_, _dísé, ojim, --, 
   {{0x60c41326,0x68f80ffb,0xa3cc007d,0x8c3c5775}},	//   njim, gnud, लहा_, _taşa, 
   {{0xfb1401b9,0x919c00d1,0xfa34cdcc,0xebe00117}},	//   _فورج, ﻟﻐﯘﭼ, _فراد, _зотп, 
   {{0x60c41cb9,0x22ac33b3,0x7e7c089c,0x68f8000d}},	//   hjim, bɔkɔ_, ngpp, anud, 
   {{0x68f8208d,0x60c400b5,0x98c4004e,0x00000000}},	//   bnud, kjim, _жөпж, --, 
   {{0x60c568cd,0x1c2000bc,0xa964030d,0x00000000}},	//   jjim, _बराल_, _хица_, --, 
   {{0x60c40552,0x00000000,0x00000000,0x00000000}},	//   djim, --, --, --, 
   {{0x27f40122,0x60c40064,0x00000000,0x00000000}},	//   šená_, ejim, --, --, 
   {{0xef1c04cc,0x60c4009a,0x00000000,0x00000000}},	//   _opür_, fjim, --, --, 
   {{0x60c402d3,0x3d040034,0x3de8031c,0x6d4002f0}},	//   gjim, षकों_, _རྟེན, ínam, 
   {{0x8c3c372c,0x1ccc031c,0x5f94a74b,0x00000000}},	// [25370] _başn, ིིན_, нитт, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8c3c03e3,0x644c032e,0xe1f0009f,0x00000000}},	//   _daşn, _ámið, _مسَ_, --, 
   {{0x60c401fa,0xb7c400de,0x00000000,0x00000000}},	//   cjim, _kuģī, --, --, 
   {{0xcb680354,0x68f80162,0x00000000,0x00000000}},	//   цале_, vnud, --, --, 
   {{0x66dc006a,0xf8ad104b,0xedd400fb,0xc60400cc}},	//   _kêke, یکن_, _елгә_, ৈধতা_, 
   {{0xdd95149e,0x63a800e2,0xda64007b,0xdeb4004e}},	//   _пары, ādni, راوي, _ябры, 
   {{0xfa240327,0x67200200,0x7bcc06be,0x00000000}},	//   རྟེན_, _shnj, _əbuz, --, 
   {{0x68f968ce,0xc724010b,0x8c3c0166,0x067408da}},	//   rnud, мдий, _yaşn, муня, 
   {{0x68f968cf,0x60c4002d,0x00000000,0x00000000}},	//   snud, zjim, --, --, 
   {{0x97a401c6,0x00000000,0x00000000,0x00000000}},	//   _үрчл, --, --, --, 
   {{0x20e803e0,0x00000000,0x00000000,0x00000000}},	//   nşit_, --, --, --, 
   {{0x60c40010,0x6d4002f0,0x5f1000cd,0x00000000}},	//   vjim, ínaj, तकम्_, --, 
   {{0x1c20000d,0x00000000,0x00000000,0x00000000}},	//   _बरसल_, --, --, --, 
   {{0x60c40010,0x00000000,0x00000000,0x00000000}},	//   tjim, --, --, --, 
   {{0x98fc010f,0x60c40030,0x42cc0154,0x00000000}},	//   _avĉj, ujim, রফেশ, --, 
   {{0x60c568d0,0x8c3c054e,0x00000000,0x00000000}},	// [25380] rjim, _paşn, --, --, 
   {{0xef1c0065,0x60c40af9,0x6e380356,0x20e80356}},	//   _spür_, sjim, _şubr, eşit_, 
   {{0x63a40561,0xbc6968d1,0x60c40240,0xc0e40006}},	//   _hsin, قمان_, pjim, _жонк, 
   {{0x629c04ac,0xdb0000dd,0x8c3c0209,0xeaac00dd}},	//   lero, _ismé, _daşo, یٹن_, 
   {{0x63a40175,0x629c023a,0x8c3c013d,0x9b58009d}},	//   _jsin, oero, _taşn, чилт_, 
   {{0x63a568d2,0xeaac021f,0x8c3cbd8f,0x3a380162}},	//   _msin, لعى_, _haşl, øpp_, 
   {{0x63a40efc,0x6da00022,0x629c01c7,0x3958067c}},	//   _lsin, _иира, iero, èps_, 
   {{0x63a51760,0x7c6568d3,0x00000000,0x00000000}},	//   _osin, _زارل, --, --, 
   {{0x63a568d4,0xb8f4ccc0,0x7b442b9f,0x00000000}},	//   _nsin, _हव_, _آئرل, --, 
   {{0xdb00013a,0xab741291,0x00000000,0x00000000}},	//   _osmé, _آملا_, --, --, 
   {{0xe964022e,0x00000000,0x00000000,0x00000000}},	//   _жахл_, --, --, --, 
   {{0x63a40327,0x7988192e,0x2108a4cd,0x00000000}},	//   _bsin, mtfw, वकोश_, --, 
   {{0x63a4066d,0xe82001f0,0x00000000,0x00000000}},	//   _csin, _ифшо, --, --, 
   {{0xd5b02ad5,0x63a40263,0xdb0000ae,0x39ac0064}},	//   _مفت_, _dsin, _armú, _kęs_, 
   {{0x63a568d5,0x798813c4,0x30a4013e,0x39ac0064}},	//   _esin, ntfw, мрав, _jęs_, 
   {{0x6fa400aa,0x629c00b0,0x98ac01ef,0x75c806be}},	//   ونزې_, aero, _rudě_, ləzo, 
   {{0x8c3cffea,0x39ac000f,0x63a40036,0x00000000}},	// [25390] _daşl, _lęs_, _gsin, --, 
   {{0xdef843a7,0x00000000,0x00000000,0x00000000}},	//   мых_, --, --, --, 
   {{0x2d8568d6,0x8c940046,0x63a401d3,0x56700092}},	//   îne_, ерлі, _zsin, _በአንዱ_, 
   {{0x8c3c0432,0x7e6c005c,0x63a42a9e,0x32cc010e}},	//   _gaşl, _edbp, _ysin, _tüys_, 
   {{0xdcfc005f,0x00740375,0x20e819b2,0x63a4017a}},	//   _aprē, _אתרי_, rşit_, _xsin, 
   {{0x8c3c03e0,0xfcd40ca8,0x00000000,0x00000000}},	//   _taşo, _àánú_, --, --, 
   {{0x8c3d2524,0xec6828a8,0x20e815b7,0xac7400be}},	//   _yaşl, _мрак_, mşir_, _يارش, 
   {{0x764968d7,0x8c3d0647,0xab70014b,0xdd94190b}},	//   _affy, _kaşm, _аҳдш, _шасы, 
   {{0x8bd8006c,0x629d68d8,0x05780020,0x683802d3}},	//   _эмас_, yero, _በደቡብ_, _ብኤርት, 
   {{0x629d2568,0x85e8030d,0x63a568d9,0x37000137}},	//   xero, здов_, _rsin, лпыг, 
   {{0x63a568da,0x85b800c6,0x8c3c0166,0x2ba00118}},	//   _ssin, سادس_, _laşm, _खैता, 
   {{0x629d68db,0x63a405be,0xd90c2099,0x764802d0}},	//   wero, _psin, _ویو_, _effy, 
   {{0xd800010a,0x20e800a2,0x00000000,0x00000000}},	//   _вăя_, kşir_, --, --, 
   {{0xb6a0eb12,0x00000000,0x00000000,0x00000000}},	//   _бишл, --, --, --, 
   {{0x629d68dc,0x41281d11,0xafe0036b,0x00000000}},	//   rero, зово_, ҳотл, --, 
   {{0x629d68dd,0x63a568de,0x8c3ca565,0x00000000}},	//   sero, _tsin, _başm, --, 
   {{0x63a568df,0x00000000,0x00000000,0x00000000}},	// [253a0] _usin, --, --, --, 
   {{0xef14db20,0x629d68e0,0x8c3c2d9a,0xac9400e5}},	//   ему_, qero, _daşm, ہنما_, 
   {{0x8c3c9155,0x221400f1,0x09e000fe,0xed4c431a}},	//   _taşl, _شېرز, যপুথ, مپل_, 
   {{0xd2000046,0x71a002d5,0xb63400df,0x00000000}},	//   _түск, _саюз, גרעס_, --, 
   {{0x823412ea,0x79880369,0xdcfc00ef,0xecb00022}},	//   _ترکا, wtfw, _sprē, ыӡры, 
   {{0x79a568e1,0x9f4001a2,0x798800d2,0x39a445ce}},	//   ерие, nzií_, ttfw, ешив, 
   {{0x7c9568e2,0xfce401c0,0x8a100131,0x6ac0075e}},	//   _прац, _зово, لېكت, اقىم, 
   {{0x3ea80730,0xb86568e3,0xada002bf,0x8c3c2791}},	//   _habt_, رابو, _щасл, _yaşm, 
   {{0x77900bce,0x5b600092,0x00000000,0x00000000}},	//   ایتا, ገነዘቡ, --, --, 
   {{0xeb300131,0x8c00070e,0x39ac00c0,0x768400c7}},	//   _مىقد, _әҗәл, _tęs_, хыиж, 
   {{0xe9d40104,0xb958007b,0x290c03b2,0xb4f000cf}},	//   _пкф_, _رجاء_, ómað_, лүкч, 
   {{0xf7451b47,0x98fc01e4,0x26c001e6,0x628802e2}},	//   _зедо, _ovĉi, öjor_, òdon, 
   {{0xb0000055,0x75c806be,0x00000000,0x00000000}},	//   _paḍb, məzm, --, --, 
   {{0x764803ac,0x356800d8,0x00000000,0x00000000}},	//   _uffy, _ерин_, --, --, 
   {{0xa1940c4d,0x8c3c00a2,0x32cc00a2,0xbbbc00c5}},	//   ларч, _daşj, _düyp_, ्हुक, 
   {{0x8c3c010e,0xf4840484,0x00000000,0x00000000}},	//   _paşm, _чукн, --, --, 
   {{0xd2512dda,0xc3c004b4,0x00000000,0x00000000}},	// [253b0] _پنج_, _көрл, --, --, 
   {{0x533568e4,0x00000000,0x00000000,0x00000000}},	//   _шепт, --, --, --, 
   {{0x9f056811,0xeabc0051,0x00000000,0x00000000}},	//   دولو, _đù_, --, --, 
   {{0x8c3c03e0,0x00000000,0x00000000,0x00000000}},	//   _taşm, --, --, --, 
   {{0x9d540075,0x5c140948,0xfb8568e5,0xb9300092}},	//   ننەت, льшу, ندوی, ጠቃሚዎ, 
   {{0xbb5000c6,0x3a3c021c,0x499424fc,0x8c3c371e}},	//   جنوب, _cgtp_, вшит, _kaşk, 
   {{0x48e515b5,0x66e401e1,0x26fc0154,0x00000000}},	//   кокв, _lékù, _উঠলো_, --, 
   {{0x8c3c0432,0x3ea83149,0x00000000,0x00000000}},	//   _maşk, _zabt_, --, --, 
   {{0x3a3c010a,0xb058007c,0x00000000,0x00000000}},	//   _fgtp_, _enäg, --, --, 
   {{0xf1b04a18,0x00000000,0x00000000,0x00000000}},	//   ुमान, --, --, --, 
   {{0x97c568e6,0xb058007c,0x9694010b,0x81d405ac}},	//   نتیم, _gnäg, урыш, _াইভ_, 
   {{0x43444170,0xc79568e7,0x00000000,0x00000000}},	//   кемв, _аркы, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8c3d53ba,0x66e40241,0x00000000,0x00000000}},	//   _başk, _dékù, --, --, 
   {{0xd174f9cb,0x9f4000d0,0x00000000,0x00000000}},	//   лыты, rzií_, --, --, 
   {{0x8c3cffea,0xdd1c0024,0xe9fc0208,0x20e8010e}},	//   _daşk, ršūn, _quẹo_, gşip_, 
   {{0x03240124,0xdb0803e0,0x00000000,0x00000000}},	// [253c0] _идин, _ölçt, --, --, 
   {{0x23600bc9,0x2fcc01e6,0x8c3c03e0,0xc1d001ee}},	//   _iwij_, ägga_, _haşh, _көбә, 
   {{0xd1e8044e,0x11d40153,0x781c0210,0x00000000}},	//   _መግቢ_, _біяр, _पर्क_, --, 
   {{0xed4ccddb,0x00000000,0x00000000,0x00000000}},	//   زپه_, --, --, --, 
   {{0x3ea8037e,0x9b9400db,0x00000000,0x00000000}},	//   _tabt_, التت, --, --, 
   {{0x8c3c008e,0x00000000,0x00000000,0x00000000}},	//   _yaşk, --, --, --, 
   {{0xa9c000a7,0x79a568e8,0xbe1400cf,0x9a8401d5}},	//   исък, трле, _شورع, вуқл, 
   {{0xb0580b70,0xfca800f1,0xa92001ef,0x6e203f17}},	//   _gnäd, _غازو_, _úžla, ünbe, 
   {{0xbb4400c9,0x9f4042bc,0xb8f8d2c7,0x4b5003e6}},	//   _резк, nzià_, _ठक_, _هێنر, 
   {{0x7d003466,0x644001fa,0xb99400c6,0x3ce4d7fe}},	//   lnos, žmil, _للطب, lhov_, 
   {{0xaaa809bb,0x8c3c0bbc,0x7d000108,0x00000000}},	//   _टोटक, _başh, onos, --, 
   {{0x8ac40022,0xb05801e3,0x46800124,0xd90c00e5}},	//   _ақәа_, _knäe, ақәа, _ڈیڈ_, 
   {{0x7d003c6d,0x8c3c6cba,0x7998035a,0xd9440166}},	//   inos, _daşh, _hptw, _реҗи, 
   {{0x7d0168e9,0xa8000131,0x8c3c0139,0x3ce40254}},	//   hnos, _әзәл, _paşk, hhov_, 
   {{0x7d0168ea,0x8618016c,0x00000000,0x00000000}},	//   knos, _пешӣ_, --, --, 
   {{0x0c800020,0x0ca4001f,0x62240116,0x00000000}},	//   _ከሌሎች_, _ለሌሎች_, شىقل, --, 
   {{0xb4dc1fb0,0xb058014a,0x3490022e,0x00000000}},	// [253d0] णसी_, _soäs, _бақр, --, 
   {{0x5f9568eb,0x8c3d68ec,0x7d005727,0x799803ac}},	//   рифт, _taşk, enos, _optw, 
   {{0x8c3d2d8c,0x00000000,0x00000000,0x00000000}},	//   _haşi, --, --, --, 
   {{0x7d0168ed,0xd10002dd,0x2a640784,0x3ce4016d}},	//   gnos, _اۋرۋ, wanb_, ghov_, 
   {{0x613801e1,0x00000000,0x00000000,0x00000000}},	//   _wúlì, --, --, --, 
   {{0x8c3ce732,0xa92401a2,0x6d40063f,0x7d00691f}},	//   _maşi, _obľú, ̣nay, anos, 
   {{0x7d0168ee,0x2a640ffb,0x799802d0,0x5f100490}},	//   bnos, ranb_, _cptw, तकर्_, 
   {{0x7d000e8b,0x2a6402e2,0x3b500116,0x00000000}},	//   cnos, sanb_, шкәр, --, 
   {{0xb0580267,0x2cbc0254,0xdcfc0153,0x00000000}},	//   _knäb, _inud_, _aprė, --, 
   {{0x8c3c2791,0x00000000,0x00000000,0x00000000}},	//   _naşi, --, --, --, 
   {{0x2cbd68ef,0x2360002d,0x9f4004cc,0x8c140154}},	//   _knud_, _swij_, zzià_, ়েশন_, 
   {{0xf8c400d0,0x00000000,0x00000000,0x00000000}},	//   žéri_, --, --, --, 
   {{0xd6a858ae,0x25ac0153,0xb890114f,0x00000000}},	//   ردیم_, _žolė_, _طلوع, --, 
   {{0x7d004d3c,0x6b98046a,0x291d68f0,0x00000000}},	//   znos, _mpug, llua_, --, 
   {{0x7d0168f1,0x6abc015b,0xdc20257b,0x2cbc0254}},	//   ynos, ্সপো, _बर्ड_, _onud_, 
   {{0xc4848fad,0x3ce40070,0x5154010a,0x7d0002f0}},	//   _слик, xhov_, ртру, xnos, 
   {{0x7d00b384,0x291c9f70,0xbb6000b5,0xb11416a0}},	// [253e0] vnos, ilua_, _masボ_, اققا_, 
   {{0x7d0168f2,0x41a80c98,0x8c3c0139,0x291c0332}},	//   wnos, _звон_, _gaşi, hlua_, 
   {{0x6b98063f,0xc10400c6,0xed54a848,0x3ce40218}},	//   _apug, _مودي, гох_, thov_, 
   {{0x7d00004c,0xee2c00ec,0x00000000,0x00000000}},	//   unos, سٽن_, --, --, 
   {{0x6d540227,0x6b980327,0x8c3d1cb4,0x7fd402dc}},	//   apxa, _cpug, _yaşi, _сіні, 
   {{0xeb30278f,0x291c0421,0x2120102c,0x4ed400a7}},	//   مىند, elua_, llih_, _кюст, 
   {{0x7d004ea1,0x291d68f3,0x3ce40267,0xdb000118}},	//   pnos, flua_, phov_, _usmí, 
   {{0x66dc006a,0x3ce401d4,0x2bc419b8,0xafd80627}},	//   _bêko, qhov_, тләп_, _ifør, 
   {{0x21200548,0xdc7400c7,0x2b74006c,0x6cd01c3e}},	//   ilih_, _быҕь, _مینگ_, _اققا, 
   {{0x291cc1c2,0xb05801e6,0x0dc8001f,0x21200010}},	//   alua_, _knäc, _በነፃ_, hlih_, 
   {{0x8c3ccb7d,0x00000000,0x00000000,0x00000000}},	//   _raşi, --, --, --, 
   {{0x291c0120,0x2db400c8,0xb4dc0490,0x8c3c0356}},	//   clua_, אלטן_, णसे_, _saşi, 
   {{0xf3fc0798,0x8c3c0311,0x21200427,0x2bc4010a}},	//   raão_, _paşi, dlih_, _улăп_, 
   {{0xf41c01e6,0x660c003e,0x163401d5,0x00000000}},	//   ffär_, éhké, _келя, --, 
   {{0x7c6c001f,0x2120102c,0x8c3c0213,0xf41c0139}},	//   ጠቀሰው_, flih_, _vaşi, gfär_, 
   {{0x905568f4,0x40e402dd,0x8c3c2b95,0x00000000}},	//   рвац, асуғ, _waşi, --, 
   {{0x38640ac5,0x20980228,0xdfd800a7,0x8c3c0790}},	// [253f0] _meor_, ыкты_, лъф_, _taşi, 
   {{0x386568f5,0x2cbc01b8,0x212036df,0x00000000}},	//   _leor_, _snud_, alih_, --, 
   {{0x6b9968f6,0x2cbd68f7,0x712435e6,0x21200010}},	//   _spug, _pnud_, _مرحل, blih_, 
   {{0x4ea44d50,0x4c9403b7,0x386400a3,0xaac43c71}},	//   ырға, ридс, _neor_, लाभक, 
   {{0xafd805ac,0x00000000,0x00000000,0x00000000}},	//   _efør, --, --, --, 
   {{0x69c401e1,0x2fcc03b2,0x00000000,0x00000000}},	//   _àjek, øggu_, --, --, 
   {{0xdb0004d4,0x6d8401d3,0x00000000,0x00000000}},	//   _armó, _حمزہ_, --, --, 
   {{0x2cbc089c,0x6d4401e4,0x3a7000d1,0x6d4001e4}},	//   _unud_, _iuja, бләр, ŭnas, 
   {{0x38640bc2,0x6b980607,0x291c013c,0x27281600}},	//   _deor_, _upug, rlua_, høne_, 
   {{0x6d4568f8,0x8c3c0365,0x21200427,0x00000000}},	//   _kuja, _başv, zlih_, --, 
   {{0x6d4402d1,0x272805ac,0x3d180073,0x3ab8011a}},	//   _juja, jøne_, बतचे_, _שמענ, 
   {{0x6d4568f9,0x38640048,0x6aa168fa,0xd8a8004b}},	//   _muja, _geor_, lenf, _مهمو_, 
   {{0x6d44016d,0x6aa00f49,0x68f8005c,0xb3800138}},	//   _luja, oenf, miud, олял, 
   {{0x6aa168fb,0x6d440af9,0x68f800c0,0x00000000}},	//   nenf, _ouja, liud, --, 
   {{0x6d4568fc,0x2120e912,0x8c3c0311,0x272801bf}},	//   _nuja, tlih_, _iaşu, rønd_, 
   {{0x68f968fd,0x6aa03262,0x310401af,0x1ee8179e}},	//   niud, henf, ансп_, گوئی_, 
  
   {{0xf41d68fe,0x644568ff,0xfe7003e6,0x6d456900}},	// [25400] lgän_, _igii, قدا_, _auja, 
   {{0x7e555bc3,0x6d456901,0x68f96902,0xaec00815}},	//   ртац, _buja, hiud, обул, 
   {{0x6aa16903,0xf41c0724,0x6d440120,0x3d100037}},	//   denf, ngän_, _cuja, तवले_, 
   {{0x6d456904,0x65600007,0xdddc012d,0x5108010a}},	//   _duja, _mwnh, _perł, _йĕхĕ, 
   {{0x6f14030d,0x65600007,0xdb000789,0x6aa05fc7}},	//   boxc, _lwnh, _asmá, fenf, 
   {{0x6aa16905,0x386401ab,0x68f816b8,0x8c3c054e}},	//   genf, _seor_, eiud, _naşu, 
   {{0x6d456906,0x38641280,0x776002b9,0xafd8168c}},	//   _guja, _peor_, _swox, _ufør, 
   {{0x68f96907,0x64456908,0x7c6400d1,0x00000000}},	//   giud, _ngii, _خاسل, --, 
   {{0x6d4405a1,0x65600327,0x6aa067c4,0x8c3c56f8}},	//   _zuja, _awnh, benf, _başu, 
   {{0x64456909,0x6aa0003a,0x5bb40073,0xaa401d5b}},	//   _agii, cenf, ूमीव, _дефл, 
   {{0x3865690a,0x6d45690b,0x79500133,0x00000000}},	//   _teor_, _xuja, _بێبا, --, 
   {{0x68f90c3f,0x00000000,0x00000000,0x00000000}},	//   ciud, --, --, --, 
   {{0xdcfc00da,0xc5f40116,0x31dc00bc,0xad340a7c}},	//   _aprī, иғә_, नन्ध, ינטס_, 
   {{0x65600007,0x8c3c0139,0x64440254,0xb2844640}},	//   _fwnh, _gaşu, _egii, шымк, 
   {{0x04e401e1,0x00000000,0x00000000,0x00000000}},	//   _ìṣọ̣, --, --, --, 
   {{0x6d45690c,0xe63823e4,0x6dc52a84,0x6aa1690d}},	//   _ruja, _בתוכ, یزال, zenf, 
   {{0x6aa08576,0xc0e002d3,0xd371690e,0x8c3c0432}},	// [25410] yenf, ነበሮ_, _عهد_, _yaşu, 
   {{0x6d45690f,0x23280e92,0x8c3c03e3,0x316801af}},	//   _puja, _коњи_, _maşt, _ишмо_, 
   {{0x6d440eda,0x8c3c0139,0xfd4c00b8,0x6aa026c2}},	//   _quja, _laşt, _kaiṭ, venf, 
   {{0x6d456910,0xc0e0001f,0x6aa00083,0xb63c0092}},	//   _vuja, ነበር_, wenf, _አጠናቅ, 
   {{0x8c3c084c,0x68f8067c,0x00000000,0x00000000}},	//   _naşt, viud, --, --, 
   {{0x6d456911,0x6aa16912,0x8e24030d,0xa3b83cc3}},	//   _tuja, uenf, _дlа_, छित_, 
   {{0x1a68006c,0x68f80433,0x6d440194,0x00000000}},	//   شینی_, tiud, _uuja, --, 
   {{0x8c3d6913,0x635400bc,0xdddc0432,0xc9200073}},	//   _başt, něný, _derń, मतेम_, 
   {{0x68f96914,0x6aa12815,0x2d90005a,0x8c3c0356}},	//   riud, penf, ltxe_, _caşt, 
   {{0x06c843a7,0x37d4015b,0x64440142,0x44240003}},	//   угой_, _তেহর, _sgii, _ġo_, 
   {{0x44240029,0x2d9001c0,0x89d800c6,0x68f8003e}},	//   _šo_, ntxe_, _حوار_, piud, 
   {{0xf41c0598,0x03a56915,0x00000000,0x00000000}},	//   rgän_, бимо, --, --, 
   {{0x63540118,0x8c3c008e,0xdcfc00de,0x00000000}},	//   děný, _taşu, _sprī, --, 
   {{0x748c00d1,0x00000000,0x00000000,0x00000000}},	//   _ﻛﯚﭘﯩ, --, --, --, 
   {{0x8b040034,0xd1e00023,0xf5902bef,0xf654011a}},	//   częł, _ዓርቢ_, _فلوج, _פסקי_, 
   {{0x8c3c70f7,0x85040472,0x44640395,0x00000000}},	//   _yaşt, _دوبن, _увив, --, 
   {{0x442407ae,0x2d9030dd,0xbfa80014,0x9f6400a2}},	// [25420] _áo_, etxe_, دازٕ_, _öwür_, 
   {{0x3f4c00e4,0x00000000,0x00000000,0x00000000}},	//   _añuã_, --, --, --, 
   {{0x3f91289a,0xada00166,0x6d400022,0x6354013a}},	//   styu_, захл, ínap, běný, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb0580267,0x3b940063,0xab7001ec,0xab9552e5}},	//   _knän, сјет, згіш, مخور_, 
   {{0xd1e00092,0x19580137,0x8c3c008e,0x37a807a5}},	//   _ዓርብ_, аакы_, _raşt, ҳтон_, 
   {{0xa9640b7f,0x8c3c7b37,0xed5400f5,0xe9640798}},	//   бија_, _başs, _гос_, бајл_, 
   {{0x8c3c0311,0x175559f4,0x58d803c5,0x2ba00037}},	//   _paşt, овия, рдия_, _खैका, 
   {{0x7bc40427,0x5fc81fd2,0x00000000,0x00000000}},	//   _škuf, रमिल, --, --, 
   {{0xb6c56916,0x67500597,0x5574e8ef,0xbab400f1}},	//   ссий, أخير, огот, _دمطب, 
   {{0xdde400b8,0x00000000,0x00000000,0x00000000}},	//   _ārśy, --, --, --, 
   {{0x8c3c62c7,0xb0580139,0x30b000fe,0x5fc807b6}},	//   _taşt, _anän, _টক্স, रमाल, 
   {{0x635400bc,0x00000000,0x00000000,0x00000000}},	//   věný, --, --, --, 
   {{0x67d001c0,0x00000000,0x00000000,0x00000000}},	//   _хошу, --, --, --, 
   {{0xdb00008e,0x63540118,0xf4840798,0x22580166}},	//   _ismä, těný, _лупн, сисы_, 
   {{0xb058010b,0x8c3c010e,0x81940150,0x00000000}},	//   _enän, _maşr, _ﺘﺴﻌﺔ_, --, 
   {{0x7af80083,0x27280158,0xd5b800e2,0x225c00bc}},	// [25430] _omtt, løna_, lvā_, ízké_, 
   {{0x7c240306,0x00000000,0x00000000,0x00000000}},	//   _úkry, --, --, --, 
   {{0xd0d40831,0x957c068f,0xdfd000f1,0xae28009d}},	//   _донъ, cząt, ويې_, уцаж_, 
   {{0x2d9001c6,0xc7400092,0x0b5800cf,0x00000000}},	//   rtxe_, _ከነዚህ, аркы_, --, 
   {{0x7af801a9,0x272962ab,0xbf700150,0x00000000}},	//   _bmtt, høna_, _оқты, --, 
   {{0x95280135,0x8c3c05d1,0xcda80efc,0x00000000}},	//   _ལེའི_, _başr, _پهره_, --, 
   {{0xda78d47b,0x98ac0139,0x272800cc,0xfaa400f2}},	//   сяч_, _awdı_, jøna_, زجوی, 
   {{0xd04c03f9,0x3a703531,0x8c3c010e,0x00000000}},	//   rhaɗ, пләр, _daşr, --, 
   {{0x46e80058,0xd04c02a8,0x06e96917,0x00000000}},	//   идин_, shaɗ, имик_, --, 
   {{0x7bc401a6,0x00000000,0x00000000,0x00000000}},	//   _škug, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x5a3401c0,0x35ac0210,0x00000000,0x00000000}},	//   _энхт, टिज़, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8c3c0166,0x00000000,0x00000000,0x00000000}},	//   _yaşr, --, --, --, 
   {{0xc5d41c26,0x3241035c,0x80f80209,0xf41800fe}},	//   _філь, дерг, ахат_, নেলৰ_, 
   {{0x957c033f,0x00000000,0x00000000,0x00000000}},	//   rząt, --, --, --, 
   {{0xb05833fe,0x00000000,0x00000000,0x00000000}},	// [25440] _inäl, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x412802bf,0xb05801e3,0x28bc09fa,0x00000000}},	//   _воно_, _knäl, _शोभि, --, 
   {{0xc7b801ed,0x00000000,0x00000000,0x00000000}},	//   kvő_, --, --, --, 
   {{0x8c3c3f59,0xeb945bc6,0x00000000,0x00000000}},	//   _başq, жич_, --, --, 
   {{0xf21c0307,0x00000000,0x00000000,0x00000000}},	//   _मुड़_, --, --, --, 
   {{0xfce41cb6,0x8c3d6918,0x7bc41462,0xc8c407af}},	//   _дово, _daşq, _škud, वांट, 
   {{0x39402bea,0x00000000,0x00000000,0x00000000}},	//   öks_, --, --, --, 
   {{0x3b1c020c,0x5694021f,0x00000000,0x00000000}},	//   _tktq_, папт, --, --, 
   {{0xd5b81161,0xaef80241,0x8c3c0790,0x00000000}},	//   tvā_, _awùj, _taşr, --, 
   {{0x940403be,0x19c42cc8,0xa3b0012d,0xf990072d}},	//   ələ_, _хәлг, _टैब_, _زبا_, 
   {{0xd5b80882,0xf7447d11,0x81c0015b,0x7a0806be}},	//   rvā_, _дедо, ্না_, _tәtb, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb000730,0x27284606,0xb0580139,0xd5540354}},	//   _ermö, lønn_, _enäl, _еккъ, 
   {{0x3068147e,0x957c012d,0x00000000,0x00000000}},	//   ијан_, rząs, --, --, 
   {{0x6ab40490,0xb05801e6,0x00000000,0x00000000}},	//   _आफ्र, _gnäl, --, --, 
   {{0x5f956919,0x00000000,0x00000000,0x00000000}},	// [25450] митт, --, --, --, 
   {{0x9f3401ec,0x12a80116,0x00000000,0x00000000}},	//   деуі, ﺴﻠﻪﺭ, --, --, 
   {{0xdd9401c6,0xf1a80345,0x00000000,0x00000000}},	//   дахы, _ئاخه_, --, --, 
   {{0x272808fb,0x8c3c9c11,0x42880092,0xd6d000eb}},	//   jønn_, _başp, _ዕምነት_, িসিয, 
   {{0xef91691a,0xf09c0241,0x00000000,0x00000000}},	//   _زیاد, _ibà_, --, --, 
   {{0xefe802d3,0xed58007b,0x8c3c03b9,0x00000000}},	//   _መርዓ_, _نشرت_, _qaşq, --, 
   {{0x3ebc05f7,0x00000000,0x00000000,0x00000000}},	//   _ótta_, --, --, --, 
   {{0x9d18497a,0x88c86acd,0x00000000,0x00000000}},	//   _дост_, слив_, --, --, 
   {{0xf09d691b,0x9b580139,0x8c3c008e,0x47d000cc}},	//   _mbà_, _митт_, _taşq, _তেজী, 
   {{0xb058049f,0xa9c402e9,0x00000000,0x00000000}},	//   _snäl, _وزاو, --, --, 
   {{0x04c83c19,0xb058002f,0xf41c0432,0x00000000}},	//   مودي_, _anäm, lgäh_, --, 
   {{0xf09c01e1,0xa92801ec,0x00000000,0x00000000}},	//   _nbà_, _тізе_, --, --, 
   {{0x68e800ef,0x00000000,0x00000000,0x00000000}},	//   _ilgd, --, --, --, 
   {{0xf09d691c,0xfbd0025d,0x00000000,0x00000000}},	//   _abà_, עתם_, --, --, 
   {{0x26c5691d,0x52b80006,0xf6b000ec,0x00000000}},	//   _inno_, цыяў_, _سميج, --, 
   {{0xaac4228d,0xefe80092,0x00000000,0x00000000}},	//   लाँक, _መርዝ_, --, --, 
   {{0xcfa800ae,0x00000000,0x00000000,0x00000000}},	// [25460] ياكم_, --, --, --, 
   {{0x63a5691e,0xb0300131,0x8cc0547d,0x33f8011a}},	//   _ipin, رىلغ, _रोबो, _להפנ, 
   {{0x629c7cea,0x32d80375,0xfbd001d3,0x57a82ca5}},	//   mfro, _החינ, کتا_, _कन्ह, 
   {{0x315404ac,0xf09c110e,0xdc9802bf,0x8c3c0139}},	//   _מיטן_, _gbà_, івлі_, _paşp, 
   {{0xaac409d9,0x6b6001fc,0x26c40582,0x63a4031c}},	//   लांक, екча, _onno_, _jpin, 
   {{0x63a5691f,0xec3004a9,0x629d6920,0x68e80254}},	//   _mpin, رۈلگ, nfro, _algd, 
   {{0xa964147e,0x58d407d8,0x395804e6,0xe8780092}},	//   пија_, дойт, ëps_, _ተቀመጡ_, 
   {{0x26c56921,0xd910c0e3,0xa9640640,0x8c3c03e0}},	//   _anno_, خیص_, чића_, _taşp, 
   {{0x2d54031c,0x3ce56922,0x7d008cf1,0x63a4005c}},	//   _għeb_, mkov_, mios, _npin, 
   {{0x3ce40f72,0xdb0001c7,0x290c0010,0x1954037e}},	//   lkov_, _opmé, _ejga_, _ｈｕｇ_, 
   {{0x629d6923,0xa2d00303,0x7e6c016d,0xba1800c6}},	//   dfro, दान्, _mebp, _ايضا_, 
   {{0x7d016924,0x26c56925,0x3ce56926,0x629c017a}},	//   nios, _enno_, nkov_, efro, 
   {{0x629d6927,0xa8441f3c,0x5694113e,0x00000000}},	//   ffro, _علوم_, _жалт, --, 
   {{0xa778025f,0xaef80428,0x7d016928,0x394401c3}},	//   _פרופ, _itùg, hios, _hios_, 
   {{0x63a56929,0x39446368,0x7d01692a,0xa6980375}},	//   _epin, _kios_, kios, _השופ, 
   {{0x394408cd,0x7d01692b,0x3ce48908,0x9f40007f}},	//   _jios_, jios, jkov_, lyiè_, 
   {{0x7d01692c,0x3ce43896,0x3945692d,0x333001c7}},	// [25470] dios, dkov_, _mios_, _thxx_, 
   {{0x798802ce,0xd251692e,0x39443e7c,0x629c34b9}},	//   kufw, _جند_, _lios_, cfro, 
   {{0x7d01692f,0xb62c037e,0x3ce40010,0xae000116}},	//   fios, _ｐｈ_, fkov_, رۈرى, 
   {{0x39456930,0xdb2400e4,0x63a403ac,0x00000000}},	//   _nios_, _ôsêv, _ypin, --, 
   {{0xfc4400d0,0x8c3c00a2,0x00000000,0x00000000}},	//   _šíri_, _obşe, --, --, 
   {{0x66dc006a,0x99d404fb,0xaac405d7,0x39456931}},	//   _yêku, کتها, लाइक, _aios_, 
   {{0x3ce56932,0x79880230,0x39445f5c,0x00000000}},	//   bkov_, gufw, _bios_, --, 
   {{0x39456933,0xe8dc01f2,0x8c3c00ac,0x3ce56934}},	//   _cios_, maịa_, _abşe, ckov_, 
   {{0x39456935,0x629ce0bc,0x7988002f,0xc7a8210e}},	//   _dios_, yfro, aufw, تگال_, 
   {{0x6b896936,0x00000000,0x00000000,0x00000000}},	//   mugg, --, --, --, 
   {{0x39440876,0x6b896937,0x63a56938,0x3a8401d9}},	//   _fios_, lugg, _spin, _زُنہ, 
   {{0x39440004,0x629c0113,0x63a56939,0x00000000}},	//   _gios_, wfro, _ppin, --, 
   {{0x291c1132,0xd875693a,0x00000000,0x00000000}},	//   moua_, _سانب, --, --, 
   {{0x7d01693b,0x629c45a7,0x3ce5693c,0xd04c03f9}},	//   zios, ufro, zkov_, kkaɓ, 
   {{0x461456ff,0x6b884836,0xb058007c,0x63a40210}},	//   _توغر, hugg, _knäh, _wpin, 
   {{0x7d00172e,0x6b89693d,0x291d693e,0xe7cc00fe}},	//   xios, kugg, noua_, িনীয, 
   {{0x3ce4cd94,0x63a5693f,0x291c009f,0x0ec8443a}},	// [25480] vkov_, _upin, ioua_, रांड, 
   {{0x44300875,0x6b896940,0x291d6941,0x7d000c6a}},	//   _izy_, dugg, houa_, wios, 
   {{0x3ce44859,0x7d016942,0x291c08f5,0xfd940108}},	//   tkov_, tios, koua_, ьшаю, 
   {{0x6b880337,0x8fa40022,0x00000000,0x00000000}},	//   fugg, ьаӡе, --, --, 
   {{0x932484d2,0x291c002d,0x6b881418,0x7e6c0455}},	//   _زرین, doua_, gugg, _tebp, 
   {{0x7d016943,0x39456944,0x3ce56945,0xeb303b5f}},	//   sios, _sios_, skov_, نىند, 
   {{0x7d016946,0xfca800b2,0x39456947,0x291c0618}},	//   pios, _وارو_, _pios_, foua_, 
   {{0x57b47b98,0x6b896948,0x44316949,0x291d694a}},	//   ебит, bugg, _ozy_, goua_, 
   {{0x3945694b,0xb7bc09bd,0x79880161,0x6b88026c}},	//   _vios_, েন্ট, sufw, cugg, 
   {{0x21200369,0x3eb80ac5,0x394400d5,0x00000000}},	//   hoih_, ndpt_, _wios_, --, 
   {{0x44300875,0x291c025a,0x212001fa,0x1818030f}},	//   _azy_, boua_, koih_, _کراک_, 
   {{0xaef80086,0x67202230,0x3944003b,0x21200427}},	//   _itùe, _eknj, _uios_, joih_, 
   {{0x443014cf,0x78a00798,0x00000000,0x00000000}},	//   _czy_, _ibov, --, --, 
   {{0xb05800b0,0x5694748c,0x38a0036b,0xaac400bc}},	//   _inäi, _чакт, lаr_, लाएक, 
   {{0x44300421,0xa195694c,0xc1a402dd,0xa1580150}},	//   _ezy_, карч, нытқ, дасу_, 
   {{0xb0580036,0x395c0254,0x38a001a9,0xa504030d}},	//   _knäi, _mtts_, nаr_, _аяьл, 
   {{0x78a1694d,0xe6140bd6,0x00000000,0x00000000}},	// [25490] _mbov, _ндә_, --, --, 
   {{0x0ec81d8a,0x30cc0154,0xceb83052,0x6b8801bf}},	//   राइड, রসেস, чәм_, vugg, 
   {{0x44300295,0x1b1404c5,0x78a0007f,0x291c01f7}},	//   _zzy_, িতাই_, _obov, youa_, 
   {{0xd2501a57,0x78a00175,0x6b880337,0x61e80158}},	//   _جنگ_, _nbov, tugg, ødle, 
   {{0xcb68b9ad,0xe8dc01f2,0x38a0022e,0x6a60069d}},	//   чале_, saịa_, dаr_, _ግንዛቤ, 
   {{0x78a1694e,0x705005d9,0x6b889c1c,0x00000000}},	//   _abov, _سنڀا, rugg, --, 
   {{0xa2d00b9c,0x6b89694f,0x291c1442,0x38a001a9}},	//   दात्, sugg, toua_, fаr_, 
   {{0xf41c08d5,0x6d4026b7,0x00000000,0x00000000}},	//   lgäu_, ïnad, --, --, 
   {{0x291c0053,0xaef80086,0x778000c7,0x00000000}},	//   roua_, _itùb, глыз, --, 
   {{0x78a0014b,0x291c0421,0xc564022e,0x00000000}},	//   _ebov, soua_, нкок, --, 
   {{0xfa7002d3,0xe8f0004d,0x67200427,0x291d6950}},	//   _ጽንኩር_, _đươc_, _vknj, poua_, 
   {{0x09bd6951,0x00000000,0x00000000,0x00000000}},	//   ्मीय, --, --, --, 
   {{0x27b002d9,0x00000000,0x00000000,0x00000000}},	//   _рәйс, --, --, --, 
   {{0x67200552,0xdddc0115,0x2b5c05b1,0x00000000}},	//   _uknj, _aerŝ, _mtuc_, --, 
   {{0x28d01715,0xd1740724,0x71a16952,0x00000000}},	//   थापि, кыты, ларз, --, 
   {{0x02040131,0x00000000,0x00000000,0x00000000}},	//   _үзин, --, --, --, 
   {{0xe5a056ff,0x24807a36,0x23a4000d,0xa2d000cd}},	// [254a0] _чиқи, _idim_, _ओहिद, दाद्, 
   {{0x38a0022e,0x00000000,0x00000000,0x00000000}},	//   zаr_, --, --, --, 
   {{0x6e909bec,0xa3b87039,0x4e1c00e1,0x24800166}},	//   الما, छिक_, _बुआई_, _kdim_, 
   {{0x80c800bd,0x236002d3,0xdddc0115,0xdcb01df2}},	//   রসঙ্, _ktij_, _gerŝ, شىت_, 
   {{0x28d067b1,0xafe16953,0x00000000,0x00000000}},	//   थानि, _боял, --, --, 
   {{0x2480036b,0x00000000,0x00000000,0x00000000}},	//   _ldim_, --, --, --, 
   {{0x2b5c031c,0x2480022e,0xca748ca3,0x00000000}},	//   _etuc_, _odim_, тучы, --, 
   {{0x24816954,0x7c6435ea,0xf41803d4,0xdb8401a9}},	//   _ndim_, _سارل, নেটৰ_, _аҳди, 
   {{0xf41c1b5d,0xb86400f1,0x48e000af,0x2854007b}},	//   ngät_, واکو, _ओकरो_, رؤية_, 
   {{0x24816955,0x4c340024,0x00000000,0x00000000}},	//   _adim_, _рэст, --, --, 
   {{0x23616956,0x25a400db,0x4a7401ee,0x00000000}},	//   _atij_, _cpnl_, _шытт, --, 
   {{0x3998044e,0x2480003a,0x78a001f7,0x2ba402e5}},	//   mës_, _cdim_, _ubov, _गहमा, 
   {{0x24800f7b,0x3998044e,0x9f4001d3,0xb058007c}},	//   _ddim_, lës_, nzió_, _knäv, 
   {{0x24816957,0xd5b0034c,0xd8a800ec,0x660800e5}},	//   _edim_, _نفت_, _رهڻو_, álká, 
   {{0x3998069c,0xb3700046,0xda2002ab,0x2480005c}},	//   nës_, _әңгі, यथित_, _fdim_, 
   {{0x88bc006d,0x2480031c,0x28d00b8f,0xfbe40208}},	//   mośc, _gdim_, थायि, _đênh_, 
   {{0x3998044e,0xdddc00c8,0x7bc4009b,0x00000000}},	// [254b0] hës_, _verŝ, _škun, --, 
   {{0x3998069c,0xf09c01ab,0x00000000,0x00000000}},	//   kës_, _smàd_, --, --, 
   {{0x88bc006d,0x3998044e,0xe3156958,0xdcfc1f02}},	//   nośc, jës_, _حبيب, _asrı, 
   {{0x399802d3,0x9d18013e,0xad24527d,0x4bc4004e}},	//   dës_, нохт_, رراو, көзг, 
   {{0x2d540135,0x00000000,0x00000000,0x00000000}},	//   _għen_, --, --, --, 
   {{0x88bc068f,0x39980023,0x8afc0118,0x3f840010}},	//   kośc, fës_, _otře, šouc_, 
   {{0xb9b00a2c,0x3998044e,0x6ca40006,0x9e342fe5}},	//   لموع, gës_, _праж, _берч, 
   {{0xdddc0365,0x88bc033f,0x2d5405d1,0x0ec80073}},	//   _herş, dośc, _içe_, राकड, 
   {{0xe7cc045e,0x80dc045e,0x248001b9,0x12d802dd}},	//   িন্য, নোক্, _rdim_, _ﺀﺗﻮﺭ, 
   {{0x2cac0cf9,0x2a64013f,0x9b4425ef,0x3998df62}},	//   legd_, qbnb_, _منقو, bës_, 
   {{0x399802d3,0xc8b56959,0xa2d00ad7,0x88bc0034}},	//   cës_, _аслы, दास्, gośc, 
   {{0xda040801,0x9f4086ed,0x2d540139,0xb058002f}},	//   _счуп, nziò_, _mçe_, _knäu, 
   {{0xd41400c7,0x00000000,0x00000000,0x00000000}},	//   гьры, --, --, --, 
   {{0x88bc033f,0x514400d1,0x610c03e0,0xdb0001ef}},	//   bośc, ғдуғ, işle, _osmý, 
   {{0x2d540598,0xd04c0198,0x4128e4c1,0x6b98031c}},	//   _nçe_, nkaɗ, дово_, _lqug, 
   {{0xa08401ec,0x00000000,0x00000000,0x00000000}},	//   ыңме, --, --, --, 
   {{0x399802d3,0xe8dc063f,0x2d540139,0xdddc36e1}},	// [254c0] zës_, _nzọm_, _açe_, _berş, 
   {{0xdddc054e,0xa304008e,0xae8400db,0x00000000}},	//   _cerş, _сүге, кбуз_, --, 
   {{0xaef9695a,0x7f980023,0x00000000,0x00000000}},	//   _awùs, ሎቲካዊ_, --, --, 
   {{0x3998069c,0xc0e46f61,0x8c3c010e,0xcd840131}},	//   vës_, _ромк, _haşy, اجلى, 
   {{0x6d54022f,0xb4d8067c,0x2d54013d,0xdddc0139}},	//   aqxa, lmàc, _eçe_, _ferş, 
   {{0x3998069c,0x0ba80372,0x9f4001ed,0xdddc20a9}},	//   tës_, عانى_, rzió_, _gerş, 
   {{0x6b98013c,0x8c3c0209,0xeaac00db,0xed544d01}},	//   _equg, _maşy, زعو_, _аос_, 
   {{0x3998069c,0xfca8021a,0x9f400165,0x8c3c00a2}},	//   rës_, _تاسو_, mziñ_, _laşy, 
   {{0x88bc006d,0x8afc038e,0x3998044e,0xf771695b}},	//   wośc, _stře, sës_, جاع_, 
   {{0x399802d3,0x88bc0034,0x95d80261,0x7bc00165}},	//   pës_, tośc, едот_, mvou, 
   {{0x7bc1695c,0x39980023,0xb0584a41,0x00000000}},	//   lvou, qës_, _knät, --, 
   {{0x88bc033f,0xa8443fe6,0x610c03b9,0x00000000}},	//   rośc, علیم_, oğlu, --, 
   {{0x7bc01aa7,0x8c3c0209,0xdddc00bc,0xf53c376e}},	//   nvou, _başy, _odrů, rmå_, 
   {{0x2cac0cf9,0x9f4019f5,0x7bc0005b,0x2284bb65}},	//   zegd_, zziò_, ivou, иусг, 
   {{0x8c3c0209,0x225801e0,0xb9fc0055,0x7bc400d7}},	//   _daşy, тисы_, _pāṇ_, _škul, 
   {{0xf484023b,0xa089695d,0x25d4011a,0x2d540139}},	//   _рукн, ксуз_, _יוון_, _rçe_, 
   {{0xdddc03ee,0x9f400165,0xa2d0c488,0x00000000}},	// [254d0] _perş, eziñ_, दाश्, --, 
   {{0x8c3c0432,0x7bc00427,0xb338008e,0x00000000}},	//   _gaşy, dvou, ftçe, --, 
   {{0xa2d03f55,0x7bc0257c,0xa1840137,0xdddc0166}},	//   दार्, evou, _кыял, _verş, 
   {{0x8c1803cc,0x6f602374,0xdddc0432,0x9cc800db}},	//   ىيار_, _نۇرم, _werş, кыча_, 
   {{0x09bc0b9c,0x8c3c0432,0x00000000,0x00000000}},	//   ्म्य, _yaşy, --, --, 
   {{0xaef80241,0x4995695e,0x00000000,0x00000000}},	//   _ewùr, гшит, --, --, 
   {{0xeaf045bf,0x5e640131,0x997401ec,0xdd98030d}},	//   _अतीत_, _ئۆمە, ауыш, _ишт_, 
   {{0xb0580139,0x00000000,0x00000000,0x00000000}},	//   _inäs, --, --, --, 
   {{0x12e40150,0xc7241d4d,0x00000000,0x00000000}},	//   _ﺍﻀﻁﺭ, лдий, --, --, 
   {{0xdd90004b,0xb0580267,0x752c012d,0x00000000}},	//   _دوې_, _knäs, elcz, --, 
   {{0x776002d0,0xd8b800f2,0x00000000,0x00000000}},	//   _etox, رپیچ_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa6dc045e,0xc879695f,0x46a400f3,0x8c3c00a2}},	//   যোগট, maş_, _балв, _paşy, 
   {{0x201c05d1,0x69c02ab7,0x88a00345,0x00000000}},	//   şvik_, ovne, _ئیکۆ, --, 
   {{0x7bc16960,0xd178d5d9,0x3ebc1d1d,0x00000000}},	//   zvou, ксті_, _ótti_, --, 
   {{0xb4d800f7,0x7fd4331d,0x00000000,0x00000000}},	//   rmàc, лізі, --, --, 
   {{0xc54000dd,0xb4600724,0xb0580112,0x80242ed7}},	// [254e0] _پڑھی, _укыл, _anäs, ارزم, 
   {{0x527400cf,0x2bc421b8,0x79880142,0xe16401f7}},	//   _куюу, लिना, yrfw, _نگري, 
   {{0x7c840209,0x7bc00204,0x2fc40374,0x9f400489}},	//   гуле, wvou, ānga_, uziñ_, 
   {{0x2d8409ff,0xe0945194,0x7bc00373,0x9f400165}},	//   ánea_, _خیرخ, tvou, rziñ_, 
   {{0xc878a2d4,0x69c16961,0x1bd40006,0xb0580139}},	//   daş_, evne, роля, _enäs, 
   {{0xb560001f,0x3f916962,0x7bc0f8b1,0xebbc00b8}},	//   _ወደፊት, muyu_, rvou, _guḍa_, 
   {{0xee3404ad,0x3f916963,0xc8780342,0x79a400ee}},	//   _бнр_, luyu_, faş_, урле, 
   {{0x776000e4,0xc8796895,0x00000000,0x00000000}},	//   _ptox, gaş_, --, --, 
   {{0x3f9003ee,0xb058007c,0x5838024c,0xd6b40395}},	//   nuyu_, _knär, ъзия_, айпъ, 
   {{0x7f4c003d,0x00000000,0x00000000,0x00000000}},	//   _jibq, --, --, --, 
   {{0x3f916964,0xc878c023,0xd8843e58,0x16353c4a}},	//   huyu_, baş_, _نهای, реня, 
   {{0x3f90714b,0xc8780311,0x00000000,0x00000000}},	//   kuyu_, caş_, --, --, 
   {{0x2bc43d1d,0x776003ac,0x00000000,0x00000000}},	//   लिया, _utox, --, --, 
   {{0x88bc0034,0x7f4c0135,0xb0580139,0x3f9003e0}},	//   nośn, _nibq, _nnär, duyu_, 
   {{0xd108036b,0x37d800cc,0x00000000,0x00000000}},	//   نقسه_, _বেচৰ, --, --, 
   {{0x7124035c,0xdef8031c,0x2bc49a09,0x05940345}},	//   ارآل, _ċċa_, लिमा, _ئاوگ, 
   {{0x3f9004fb,0x69c00010,0xdfd4009d,0x00000000}},	// [254f0] guyu_, zvne, боты, --, 
   {{0xdef89f4d,0x9f040f1b,0x1fb825a2,0x69c000d0}},	//   лых_, موقو, ылуы_, yvne, 
   {{0x7f4c0009,0x272801bf,0x6ce4155b,0x88bc0210}},	//   _dibq, mønt_, ліде, dośn, 
   {{0x3f9001f7,0x27280174,0x00000000,0x00000000}},	//   buyu_, lønt_, --, --, 
   {{0xc878050e,0x0f78008f,0x3f9003e0,0x5f941188}},	//   vaş_, _באָב, cuyu_, _лият, 
   {{0x69c0020b,0x2bc41d72,0x5f8402dd,0x80a803d4}},	//   tvne, लिबा, _دۇكە, _চোপ্, 
   {{0xdb0004ce,0xc878d304,0xc85002d3,0xc8b40150}},	//   _opmæ, taş_, _መሳርሕ, аспы, 
   {{0xb9fc1161,0x88c8f631,0x69c16965,0x2d900077}},	//   nāṃ_, тлив_, rvne, muxe_, 
   {{0xc8796966,0xf8b401c0,0x610c0790,0x2728005c}},	//   raş_, рөх_, nşla, kønt_, 
   {{0x2cbd6967,0x272808fb,0xa3b08bb5,0x99642cc8}},	//   _haud_, jønt_, _टैग_, штәл, 
   {{0xb9fc0882,0x2d9000d7,0x3f900205,0x9b440066}},	//   kāṃ_, nuxe_, zuyu_, _انلو, 
   {{0x2cbc039a,0x3f916968,0xc87803b9,0x00000000}},	//   _jaud_, yuyu_, qaş_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2cbd6969,0x44f404fb,0x0708038b,0x3f9004ba}},	//   _laud_, اسگز, _جيتي_, vuyu_, 
   {{0x11d40a4a,0x72140ce1,0x00000000,0x00000000}},	//   бітр, ажёр_, --, --, 
   {{0x3f91696a,0x2cbc3d7c,0xb058007c,0x8065696b}},	//   tuyu_, _naud_, _snär, рваж, 
   {{0x7f840075,0xd4980114,0x7e5408da,0x610c00a2}},	// [25500] شلان, _срј_, атец, gşla, 
   {{0x6f0400b5,0x3f91696c,0x6d40068c,0x00000000}},	//   _cmjc, ruyu_, ïnan, --, 
   {{0x2cbd696d,0x3f900986,0xca2c1870,0x4cdc00fe}},	//   _baud_, suyu_, ﺩﯨﺮ_, _মগজু, 
   {{0x7b65696e,0x2cbc0ba1,0x3f90ac6b,0xb9fc002b}},	//   атке, _caud_, puyu_, cāṃ_, 
   {{0xc0d0001f,0x7f4c0003,0x7fd4155b,0x8afc013a}},	//   ረናል_, _tibq, _тіні, _střa, 
   {{0x2ba405b3,0x0b58005b,0x00000000,0x00000000}},	//   _गहरा, урцы_, --, --, 
   {{0xb059696f,0xb338004a,0x88bc033f,0x2728353e}},	//   _knäp, ntça, rośn, høns_, 
   {{0x58d40107,0x5694035b,0x00000000,0x00000000}},	//   соит, әант, --, --, 
   {{0x0ba852c8,0x2b74d719,0x00000000,0x00000000}},	//   _مالى_, _نینگ_, --, --, 
   {{0x2cbc0211,0xf6e44d87,0x56f40120,0x6d656970}},	//   _zaud_, рцин, споѓ, špań, 
   {{0xb9fc0a28,0x19e400cc,0x64416971,0x00000000}},	//   yāṃ_, _কেৰু_, ýmin, --, 
   {{0x3f8001a6,0x00000000,0x00000000,0x00000000}},	//   _ovku_, --, --, --, 
   {{0xda780038,0xa18800e8,0x2d900564,0x8af800ac}},	//   _keď_, _fàŋŋ_, zuxe_, bləğ, 
   {{0x2bc400dc,0x39ac03b9,0xda7801ef,0xb3380213}},	//   लिता, _vəsf_, _jeď_, ftça, 
   {{0xb9fc0a28,0x27282ab7,0xda780419,0xd0d40395}},	//   tāṃ_, rønt_, _meď_, бовъ, 
   {{0xe574013d,0x8af80213,0x00000000,0x00000000}},	//   _өзә_, mləş, --, --, 
   {{0x2cbd6972,0xb9fc0882,0x8af800ac,0x8cc0033f}},	// [25510] _raud_, rāṃ_, lləş, _रोगो, 
   {{0x2cbd6973,0x2d8439b3,0xe3b0038b,0xb9fc0882}},	//   _saud_, áneo_, _آري_, sāṃ_, 
   {{0x8af803be,0x2cbc4862,0x683c0064,0x00000000}},	//   nləş, _paud_, _išdū, --, 
   {{0x30a56974,0xd5b800b0,0xaef80241,0x61e805d5}},	//   _тров, iwā_, _itùm, ädle, 
   {{0x2cbc0c67,0xec14013d,0x00000000,0x00000000}},	//   _vaud_, шедә_, --, --, 
   {{0x2d900005,0xaca00241,0x07a401e0,0x81a800fe}},	//   puxe_, _imọn, ҡайн, _গছত_, 
   {{0x98ac0213,0x9f240116,0x00000000,0x00000000}},	//   _atdı_, _بۈلۈ, --, --, 
   {{0x2bc4b1e3,0xc914015b,0xdba002dd,0xe21808c3}},	//   लिदा, াত্ত_, _ﺍﻻﺩﻯ_, יקוח_, 
   {{0x6ed8045b,0x00000000,0x00000000,0x00000000}},	//   नापु, --, --, --, 
   {{0xcebc03b9,0x8af806be,0x00000000,0x00000000}},	//   _fləş_, fləş, --, --, 
   {{0xb4d96975,0x00000000,0x00000000,0x00000000}},	//   rmàn, --, --, --, 
   {{0x58d429db,0xda7800bc,0xf98400f1,0x00000000}},	//   _мохт, _zeď_, _اچوي_, --, 
   {{0x68f801f7,0x69ac47b8,0xf504447e,0x00000000}},	//   mhud, ंबकी, снял_, --, 
   {{0x68f8067c,0xb0580267,0x27fc05c7,0x37e001c6}},	//   lhud, _snäp, mzun_, _хошг, 
   {{0xaca001e1,0x70446923,0x6ed8193d,0x68f801f7}},	//   _amọn, ەرلە, नानु, ohud, 
   {{0x070816cb,0x6d4000cf,0x7a4001d3,0x6f140332}},	//   _جيڪي_, ïnal, líté, enxc, 
   {{0x27fd6976,0xf3fc0589,0x00000000,0x00000000}},	// [25520] nzun_, czã_, --, --, 
   {{0x7e551eaa,0x7a4001ed,0x68f96977,0x27fc01c4}},	//   стац, níté, hhud, izun_, 
   {{0x68f96978,0xb2b80375,0x27fc155d,0x443001f4}},	//   khud, _גמיר, hzun_, _hyy_, 
   {{0x8d840214,0x4430005b,0x40940117,0xa2d007b7}},	//   زشمن, _kyy_, _урот, दाक्, 
   {{0x60c56979,0x2d80332c,0x68f9697a,0x8af80213}},	//   mdim, _evje_, dhud, zləş, 
   {{0x443002f6,0x200001f7,0xdb00005c,0xaa540b73}},	//   _myy_, mzii_, _opmå, ملها_, 
   {{0x7e7c0af5,0x443000f2,0xda7801f1,0xbdc401d9}},	//   mapp, _lyy_, _veď_, _دۯاے_, 
   {{0x60c5697b,0x68f80dda,0x6e20000f,0x44300205}},	//   ndim, ghud, ûnbe, _oyy_, 
   {{0xda780316,0x2001697c,0x60c5697d,0x42800092}},	//   _teď_, nzii_, idim, ርዳኖስ_, 
   {{0x20000e14,0x7a4001ed,0xa4f4031c,0x8af80213}},	//   izii_, gíté, _བཞུག_, tləş, 
   {{0xaa55697e,0x4430062d,0x39ac0213,0x60c4008e}},	//   _الما_, _ayy_, _qəsd_, kdim, 
   {{0x68f9697f,0x8af80cc1,0x74683c1f,0xf3fc014b}},	//   chud, rləş, ыров_, tzã_, 
   {{0x7e7d6980,0x60c440f6,0x6ed8085c,0x8af80213}},	//   kapp, ddim, नामु, sləş, 
   {{0x7e7d6981,0xf3fc0004,0x2000006f,0x7c2403b2}},	//   japp, rzã_, dzii_, _økru, 
   {{0x7e7d6982,0xf3fc0c67,0x8af80213,0x2000054e}},	//   dapp, szã_, qləş, ezii_, 
   {{0x39ac0213,0x7e7d6983,0x2d840118,0x60c400a2}},	//   _kəsb_, eapp, ánem_, gdim, 
   {{0x2d8005be,0x9410016b,0x9f54e91f,0x6ef80393}},	// [25530] _svje_, _ɛbɛn_, звуч, _lîbe, 
   {{0x7e7c9f5c,0x2bc40490,0x2d840219,0x60c56984}},	//   gapp, लिसा, šnem_, adim, 
   {{0x20c40882,0x60c56985,0x2ce8117e,0x0c796986}},	//   _लोकध, bdim, льдо_, аслы_, 
   {{0x7e7c0140,0x7a4001ed,0x60c401e4,0x00000000}},	//   aapp, zíté, cdim, --, 
   {{0x44316987,0x68f81aa1,0xddb8036b,0xaf3402f2}},	//   _xyy_, vhud, _қуёш_, _هرست, 
   {{0x7e7d6988,0xa8a43535,0x5e5801f0,0xc8bc1cba}},	//   capp, şmüş_, _гиря_, ्यभट, 
   {{0xdd956989,0x68f8055a,0xc21c013f,0x7a4001d3}},	//   _нары, thud, ttɔɔ_, víté, 
   {{0x27fc05f5,0xcb68258c,0xefd00092,0x00000000}},	//   tzun_, _نمره_, ረጃው_, --, 
   {{0x7a4001ed,0x8c3c010e,0x06d80166,0x00000000}},	//   títé, _obşi, афны_, --, 
   {{0x68f9698a,0x05a9698b,0x3dc40034,0x27fd698c}},	//   shud, авой_, łowe_, rzun_, 
   {{0x68f806d6,0x443002f6,0x60c5698d,0x7a4001ed}},	//   phud, _syy_, ydim, ríté, 
   {{0x7e7c13fd,0x7a4000dd,0x03a434d8,0x68f801f0}},	//   zapp, síté, оимо, qhud, 
   {{0xdd0c068f,0x7a4001ed,0x48240137,0x00000000}},	//   _późn, píté, _بىشق, --, 
   {{0x7e7c0072,0xd7c80133,0x00000000,0x00000000}},	//   xapp, _دوهه_, --, --, 
   {{0x37b40156,0xd5ac066d,0x2d8401f1,0x60c40718}},	//   _དགོད, _یہی_, šnej_, tdim, 
   {{0x60c402d5,0x7e7c1543,0xa4f4031c,0x8c3c00a2}},	//   udim, wapp, _བཞིག_, _ebşi, 
   {{0x60c409a5,0x44300280,0x3ea401a9,0x00000000}},	// [25540] rdim, _uyy_, жизг, --, 
   {{0x63a5698e,0x2001698f,0xd3c40220,0xe6b40118}},	//   _iqin, rzii_, _ءتيى, _असोज, 
   {{0x6da0016c,0x629c0b4f,0x3d0c015b,0x60c41e68}},	//   диха, mgro, িকস্_, pdim, 
   {{0x629c3e2a,0x60c56990,0x7e7d6991,0x00000000}},	//   lgro, qdim, sapp, --, 
   {{0x7e7d6992,0xac056993,0x00000000,0x00000000}},	//   papp, онца_, --, --, 
   {{0x629d6994,0x63a40b6f,0xeaac10e0,0x9eb40b8d}},	//   ngro, _mqin, نعى_, _эшмә, 
   {{0xda78b071,0x63a401b9,0x629c0b4f,0xc4c8012d}},	//   аяқ_, _lqin, igro, ियाओ, 
   {{0x37a96995,0x63a56996,0x629c03cb,0xed5400d4}},	//   атон_, _oqin, hgro, _фот_, 
   {{0x629d6997,0x63a4009a,0xf8a40882,0x3f9000b5}},	//   kgro, _nqin, क्षय, nryu_, 
   {{0x6bd45f9f,0xa814129d,0x629c5b38,0xdb2401f4}},	//   _بوكس_, تتىر_, jgro, ösäh, 
   {{0x63a40912,0x7af8035a,0xe72c0a12,0x8ad4010b}},	//   _aqin, _iltt, خصي_, _эютц, 
   {{0x629d6998,0x00000000,0x00000000,0x00000000}},	//   egro, --, --, --, 
   {{0x5bb802ab,0x386403cb,0x629c0d47,0xe82085ca}},	//   _इनोव, _ifor_, fgro, _офшо, 
   {{0x2d84038e,0x629c017a,0xf8a4726b,0x3f90427b}},	//   ánek_, ggro, क्रय, dryu_, 
   {{0x63a41253,0x38656999,0x00000000,0x00000000}},	//   _eqin, _kfor_, --, --, 
   {{0x629c0998,0x63a402d3,0x6330001f,0x23a4007c}},	//   agro, _fqin, ደረገበ, böj_, 
   {{0x629c0f85,0x00000000,0x00000000,0x00000000}},	// [25550] bgro, --, --, --, 
   {{0x629d699a,0x2dc80114,0x00000000,0x00000000}},	//   cgro, ићен_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd7bc1ab2,0x7af9699b,0x8bd80150,0x62880419}},	//   ्टाच, _altt, ймес_, ódov, 
   {{0xa2d0041c,0x7af80051,0x9b680120,0x321c0205}},	//   दाच्, _bltt, ошја_, ğuyu_, 
   {{0x386401f2,0x9b6802d5,0x92e800cc,0x00000000}},	//   _afor_, ішча_, _মগু_, --, 
   {{0xe8dc004d,0x7bc400ef,0x00000000,0x00000000}},	//   _ngợm_, _škut, --, --, 
   {{0x7af80174,0x99d42f84,0x29081497,0x00000000}},	//   _eltt, بتها, òca_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x63a401d5,0x38642093,0x00000000,0x00000000}},	//   _rqin, _efor_, --, --, 
   {{0x2bbc060c,0x4528036b,0xa5080131,0x38640042}},	//   _शैता, йжон_, قىدە_, _ffor_, 
   {{0x629c7c26,0x26c009a8,0x00000000,0x00000000}},	//   wgro, žjo_, --, --, 
   {{0x629d699c,0x98e400c6,0x63a4022e,0x42d4003b}},	//   tgro, _تكنو, _qqin, піву, 
   {{0xb5a801ed,0x629d141f,0xb9f80092,0x00000000}},	//   جئیے_, ugro, _ቆቁ_, --, 
   {{0x629c10fd,0x5bb84466,0x00000000,0x00000000}},	//   rgro, _इन्व, --, --, 
   {{0x629d699d,0x7cf800e4,0x2aac0e2d,0xa2d008df}},	//   sgro, _oïra, lıbı_, दाङ्, 
   {{0x629d699e,0x63a40912,0x63300092,0x5f780050}},	// [25560] pgro, _uqin, ደረግበ, زمؔس_, 
   {{0xaec1699f,0xc05802dd,0x00000000,0x00000000}},	//   нбул, рің_, --, --, 
   {{0xfc640c04,0x93240a12,0xf2d0008f,0xdddc00ef}},	//   пълн, _ترين, _װער_, _ierū, 
   {{0x409569a0,0x2fc4043b,0x7a400cad,0x2aac0205}},	//   _эрот, ́ngi_, _lítí, hıbı_, 
   {{0x92e86112,0x82b8025c,0x38640076,0xf0900375}},	//   _طریق_, _བྲོའ, _rfor_, _אנר_, 
   {{0x3864c1b3,0x98a4005f,0x00000000,0x00000000}},	//   _sfor_, domā_, --, --, 
   {{0xca2c0952,0xdddc7acb,0x98c4009d,0xeb500137}},	//   ﺩﯨﺲ_, _merū, дөлж, رۉمگ, 
   {{0xe9cc0691,0xae180375,0x3eb80311,0xbc1800d4}},	//   اغو_, _הולכ, lept_, _лізі_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdddc1d64,0x7a4000bc,0x6c30007b,0x6ef00205}},	//   _nerū, _cítí, _أفكا, _gıbı, 
   {{0xf99000aa,0x2fc4001e,0xb05800a2,0x00000000}},	//   _سبا_, ̉ng_, _baäl, --, 
   {{0x3eb80d27,0x39440137,0x39480063,0x6ef00205}},	//   hept_, _энег, _узео_, _zıbı, 
   {{0x78a00a73,0x395c01c6,0xaef800e4,0x3eb969a1}},	//   _icov, _huts_, _itùv, kept_, 
   {{0x66e010f5,0x395c0254,0xf8d800cd,0x00000000}},	//   _поча, _kuts_, भावय, --, 
   {{0x61f4013a,0xc1a40150,0x00000000,0x00000000}},	//   _čelá, мытқ, --, --, 
   {{0x395d69a2,0x3200045f,0x69140356,0x00000000}},	//   _muts_, rzjy_, rţeg, --, 
   {{0x395d69a3,0xe3b004d3,0x6f0001e1,0x752c012d}},	// [25570] _luts_, _یری_, _níbù, mocz, 
   {{0xaf300214,0x395c8bab,0x628801d3,0xdea400e5}},	//   رواژ, _outs_, ódot, ٹیفی, 
   {{0x2d8569a4,0x395c2517,0x6ef00166,0xd1300b24}},	//   éne_, _nuts_, _rıbı, _لمد_, 
   {{0x7cf800b0,0x8c3c054e,0x6ef00166,0x2d8400e4}},	//   _pïra, _obşt, _sıbı, ĩne_, 
   {{0x395d69a5,0xef904c0e,0x7bc569a6,0x00000000}},	//   _auts_, _سیاد, _škur, --, 
   {{0x3eb969a7,0x78a0004e,0x395d69a8,0x3dc40034}},	//   cept_, _acov, _buts_, łowa_, 
   {{0x395c9fc4,0x3c4001d9,0x689000e5,0x752d69a9}},	//   _cuts_, _یێمِ, فیائ, kocz, 
   {{0x395c004e,0x98a4cf1c,0x7a4169aa,0x00000000}},	//   _duts_, tomā_, _sítí, --, 
   {{0x77c405f5,0x29000006,0x752c0034,0x6d482fb3}},	//   длыг_, ėja_, docz, mmga, 
   {{0x78a0127b,0xdebc0023,0x00000000,0x00000000}},	//   _ecov, _ደቀን_, --, --, 
   {{0x395d69ab,0x7bc400c7,0x6d492d6d,0x00000000}},	//   _guts_, _ákur, omga, --, 
   {{0xfd640ca8,0x3eb8097d,0xddd40165,0x64b804af}},	//   _aapọ, zept_, _ŋaŋa, इजेश, 
   {{0x290c01d5,0x6d4802d0,0x7a400248,0x46a40395}},	//   _imga_, imga, _títí, _жалв, 
   {{0x290c070d,0x68e80158,0xc8c401d9,0x76c80014}},	//   _hmga_, _hogd, _رٕڈی, _وُنہ_, 
   {{0x26c406a3,0x752c0034,0x395c004e,0x78a0003a}},	//   _iano_, bocz, _xuts_, _ycov, 
   {{0x26c569ac,0x2b5c0194,0x68e801d3,0x78a001f4}},	//   _hano_, _ouuc_, _jogd, _xcov, 
   {{0x26c569ad,0x3eb8084c,0x03240dbb,0xc324a688}},	// [25580] _kano_, tept_, _один, _омик, 
   {{0x248169ae,0x68e82575,0x290c0af9,0x26c569af}},	//   _heim_, _logd, _lmga_, _jano_, 
   {{0x80a411b1,0x24800363,0x82f8913f,0x68e80373}},	//   _छापे, _keim_, _هرگز_, _oogd, 
   {{0x290c0421,0x2d8406ed,0x395cd93f,0x3eb969b0}},	//   _nmga_, ânea_, _ruts_, sept_, 
   {{0x1ab4023a,0x395c2349,0x2480002f,0x00000000}},	//   ебля, _suts_, _meim_, --, 
   {{0xf968e95a,0x290c783f,0x78a169b1,0x248169b2}},	//   орий_, _amga_, _scov, _leim_, 
   {{0x68e969b3,0x79a406ed,0x2aec0037,0x00000000}},	//   _bogd, фрле, _अवरु_, --, 
   {{0x248008cd,0x26c569b4,0x68e80429,0x395c04cc}},	//   _neim_, _aano_, _cogd, _vuts_, 
   {{0x26c569b5,0x7d0169b6,0x68e969b7,0x200400ac}},	//   _bano_, mhos, _dogd, _ümid_, 
   {{0x395d69b8,0x7d0169b9,0x752c068f,0x7cdc0356}},	//   _tuts_, lhos, wocz, _fărâ, 
   {{0x24801eaa,0x151569ba,0x752c033f,0x68e969bb}},	//   _beim_, едня, tocz, _fogd, 
   {{0x290c089c,0x7d0169bc,0x98fc01e4,0x2eb86b9b}},	//   _gmga_, nhos, _buĉe, _उस्त, 
   {{0x26c569bd,0x248005ac,0x752c0034,0x8afc012c}},	//   _fano_, _deim_, rocz, _stři, 
   {{0xe60c608c,0x26c569be,0x7d00003c,0x6d48022e}},	//   اشی_, _gano_, hhos, zmga, 
   {{0x7d005b36,0x394569bf,0x752c068f,0xb9d402d3}},	//   khos, _khos_, pocz, _ኾነ_, 
   {{0x26c569c0,0x248169c1,0x00000000,0x00000000}},	//   _zano_, _geim_, --, --, 
   {{0x7d00eda4,0x26c451e2,0x394401ab,0x54542d29}},	// [25590] dhos, _yano_, _mhos_, _явит, 
   {{0x7d00009a,0xf3fc06ed,0x26c45133,0x8afc00bc}},	//   ehos, lcão_, _xano_, _kuře, 
   {{0x7d0169c2,0x1b1400cc,0xdef80240,0x00000000}},	//   fhos, াকাই_, _ፈታኒ_, --, 
   {{0x7d000978,0xdd986ee2,0x394403cd,0xf3fc0798}},	//   ghos, ьшу_, _nhos_, ncão_, 
   {{0x6d480171,0x00000000,0x00000000,0x00000000}},	//   rmga, --, --, --, 
   {{0x290c0a2e,0x3944089c,0xb3381ae4,0x68e969c3}},	//   _smga_, _ahos_, ftçi, _sogd, 
   {{0x26c569c4,0x7d0169c5,0x394569c6,0x4c94041b}},	//   _rano_, bhos, _bhos_, _пивс, 
   {{0x26c569c7,0x7d012442,0x394569c8,0x47c436f0}},	//   _sano_, chos, _chos_, ебив, 
   {{0x26c569c9,0x39440211,0x00000000,0x00000000}},	//   _pano_, _dhos_, --, --, 
   {{0x248169ca,0x7cdc0311,0x86c40592,0x00000000}},	//   _seim_, _tărâ, ريجن, --, 
   {{0x24801028,0x26c569cb,0x2bc404e4,0x68e801d9}},	//   _peim_, _vano_, लिका, _togd, 
   {{0x39440978,0x26c42f99,0x290c00a2,0x00000000}},	//   _ghos_, _wano_, _umga_, --, 
   {{0x26c569cc,0xdd0c006d,0x2480004e,0x588400c7}},	//   _tano_, _różn, _veim_, _рыха, 
   {{0xe1f8016c,0x26c4003a,0xca1c01ec,0x00000000}},	//   дҳо_, _uano_, _ﺴﻌﺕ_, --, 
   {{0x7d0169cd,0x2480022c,0x39ac06be,0x8afc01ef}},	//   yhos, _teim_, _nəsl_, _kuřb, 
   {{0x7d0169ce,0x250801d3,0x04443866,0x291ce1db}},	//   xhos, _زرعی_, _пейн, nnua_, 
   {{0x291d69cf,0x14dd69d0,0x2d84000f,0x3ce401e4}},	// [255a0] inua_, यारण, ânen_, vjov_, 
   {{0x644569d1,0x7cf800b0,0xdef80092,0x3c6c0150}},	//   _izii, _pïro, _ፈታኝ_, _ﺷﯩﺴﻰ_, 
   {{0x7d0169d2,0x3ce40194,0x81a800cc,0x98a400c0}},	//   thos, tjov_, _গছক_, lomą_, 
   {{0xfd6401fb,0xaef800a3,0x3dc4033f,0x3d3400cf}},	//   _khuấ, _stùt, łowo_, رعاس, 
   {{0x28c0000b,0x99bc09bd,0x7d0169d3,0x932569d4}},	//   वजनि, _অপেক, rhos, _سرین, 
   {{0x7d0169d5,0xf9c4011b,0x80a4012c,0x67200208}},	//   shos, ещин, _छाडे, _njnj, 
   {{0x7d0169d6,0x394569d7,0x21200cf4,0xb4d8004e}},	//   phos, _phos_, onih_, omàt, 
   {{0x2120102c,0x7d0169d8,0x64442ad1,0x6d4000db}},	//   nnih_, qhos, _ozii, ïnat, 
   {{0x1cc00489,0xf7700597,0xaef80428,0x2120011f}},	//   _ཀྲར_, داع_, _itùr, inih_, 
   {{0x212133cd,0x98a44632,0x760400e5,0x00000000}},	//   hnih_, domą_, _nézé, --, 
   {{0x644569d9,0x00000000,0x00000000,0x00000000}},	//   _azii, --, --, --, 
   {{0x28a40959,0x00000000,0x00000000,0x00000000}},	//   _गायि, --, --, --, 
   {{0x7bc0364b,0xf3fc0798,0x98a40064,0x00000000}},	//   nwou, rcão_, gomą_, --, 
   {{0x6444fa0e,0x080800aa,0x21200429,0xf3fc0798}},	//   _dzii, _غزني_, enih_, scão_, 
   {{0x644482d0,0xc5c40022,0x21202a53,0x69140356}},	//   _ezii, _арыҩ, fnih_, lţea, 
   {{0xa6e00588,0xa6380375,0xb4d800cf,0xe6380375}},	//   _ажәл, _מגור, gmàt, _מתוכ, 
   {{0xc0cc02d3,0x69140276,0xa9200122,0x5f9429c6}},	// [255b0] _ጥቕሲ_, nţea, ížil, литт, 
   {{0x2d8406ed,0x2120102c,0xddd44a97,0x00000000}},	//   âneo_, anih_, _šašl, --, 
   {{0x2120341a,0x6448003a,0x02dc00cd,0xa18401ee}},	//   bnih_, ędie, मारभ, _йыял, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7bc002e2,0x28a40118,0x00000000,0x00000000}},	//   gwou, _गाबि, --, --, 
   {{0xaef80086,0xe3b4008f,0x2d840174,0x00000000}},	//   _etùr, רױס_, ánes_, --, 
   {{0x6cb00c75,0x2d44000d,0x00000000,0x00000000}},	//   _бөлт, tõed_, --, --, 
   {{0x291d69da,0x1cc0031c,0xc95400b8,0x7bc0007f}},	//   unua_, _ཀིར_, _brūṣ, bwou, 
   {{0x5ef82cb6,0x291d69db,0xe8dc0208,0x77800022}},	//   _एवम्_, rnua_, _ngụm_, алыз, 
   {{0x7bc4006a,0x572402dd,0x6f1402d0,0xd1e80092}},	//   _âkua, лпығ, nixc, ኘሁት_, 
   {{0xe8dc01f2,0x2120011f,0x6d58d64c,0xbac801ec}},	//   _agụm_, ynih_, _kiua, _ﻓﺄﺠﺎ, 
   {{0x69c00142,0x98c4054e,0x200c03b9,0x00000000}},	//   mwne, ătăm_, _ədib_, --, 
   {{0xd1741ac1,0x6d580165,0xf2640276,0x07a43acc}},	//   ғысы, _miua, ӂисл_, _ралн, 
   {{0x6d59024c,0x69c09108,0x45d40022,0x28a44721}},	//   _liua, owne, _ацит, _गाडि, 
   {{0x7bc004e6,0x461474dd,0x6aa0127b,0x00000000}},	//   zwou, _جوغر, ignf, --, 
   {{0x6d5969dc,0x7fd40046,0xb4d800cf,0xfd640208}},	//   _niua, кізі, umàt, _thuấ, 
   {{0xfe700c50,0xb4d800f7,0x656169dd,0x69c00770}},	// [255c0] لدا_, rmàt, _hunh, hwne, 
   {{0xd1e0069c,0x21200219,0xd05c0296,0xc0cc02d3}},	//   _ናይቲ_, snih_, _kosɛ, _ጥንሲ_, 
   {{0x6560ab04,0x68f8007d,0x6d5804cc,0xf2940375}},	//   _junh, kkud, _biua, _בכיר_, 
   {{0x656169de,0xd05c043b,0x6d5800a3,0x7bc0033b}},	//   _munh, _mosɛ, _ciua, twou, 
   {{0x65600fac,0x6b8801ab,0x7bc00ea0,0x68f80009}},	//   _lunh, gsgg, uwou, dkud, 
   {{0x7bc023f5,0x68f80099,0x79880042,0x2bc400bc}},	//   rwou, ekud, tsfw, लिजा, 
   {{0x656036ed,0xe564a9da,0xd1e0044e,0x6ea41cb7}},	//   _nunh, _خط_, _ናይታ_, _चातु, 
   {{0x98fc00df,0x6d5807de,0x20040008,0x68f8003e}},	//   _buĉa, _giua, _ýmis_, gkud, 
   {{0x6560005a,0x58388f0c,0x690400c7,0x69c00076}},	//   _aunh, эзия_, _oñef, awne, 
   {{0x656169df,0x98fc0115,0x6d580276,0x68f8004c}},	//   _bunh, _duĉa, _ziua, akud, 
   {{0x656169e0,0x1cc031d9,0x69140356,0x00000000}},	//   _cunh, _ཀྲོ_, mţen, --, 
   {{0xdddc1326,0x656036ed,0x1cc0025c,0xb3d00131}},	//   _održ, _dunh, _ཀིས_, аймә, 
   {{0x656169e1,0x00000000,0x00000000,0x00000000}},	//   _eunh, --, --, --, 
   {{0xd5b0034c,0x69140276,0xb4d8004e,0x15140139}},	//   _هفت_, nţen, gmàr, _әдия, 
   {{0x30a524ea,0x656169e2,0x94d419a5,0x6f14035a}},	//   крав, _gunh, _бойц, vixc, 
   {{0xf3640116,0x00000000,0x00000000,0x00000000}},	//   _итон, --, --, --, 
   {{0x1cc00135,0x6d58fae4,0x141800c6,0xd2511b58}},	// [255d0] _ཀྲེ_, _riua, _سيدة_, _گند_, 
   {{0x656169e3,0x6d580eda,0xf53c01e6,0x69c0033f}},	//   _yunh, _siua, llå_, ywne, 
   {{0x6f1569e4,0x6d5969e5,0xcc980120,0xad2401d9}},	//   rixc, _piua, евец_, پراو, 
   {{0xdd940953,0x28a400af,0x69040139,0x00000000}},	//   рацы, _गाधि, _iñeg, --, 
   {{0x6d5969e6,0x5bc400c6,0x00000000,0x00000000}},	//   _viua, لتوف, --, --, 
   {{0xaa400032,0xc9a969e7,0x2ea40244,0x00000000}},	//   һеҙл, евке_, _جپسی_, --, 
   {{0x7bc4006a,0xdddc6041,0x6d580421,0x443c01fb}},	//   _âkun, _zdrž, _tiua, ́t_, 
   {{0x656169e8,0x08c569e9,0xdcb8023a,0x6d580381}},	//   _runh, убин, _ищу_, _uiua, 
   {{0x656004ce,0xf53c0158,0x668001b9,0xd7640133}},	//   _sunh, dlå_, لیشل, لۆنی, 
   {{0x656097e2,0x68f8f63e,0x85e969ea,0x6904035b}},	//   _punh, skud, едов_, _oñeg, 
   {{0x4974274b,0xf53c05ac,0x00000000,0x00000000}},	//   _слес, flå_, --, --, 
   {{0x656018f7,0x5a0c00c8,0xdddc0356,0x98f40024}},	//   _vunh, _קלאַ, _herţ, _вяшч, 
   {{0x6560016b,0xd8740131,0x00000000,0x00000000}},	//   _wunh, _ئامب, --, --, 
   {{0xc5f41c36,0x65600099,0x7728069d,0x6ed800ef}},	//   _مثبت, _tunh, _ስፖርተ, _jābē, 
   {{0x75d0021a,0xd05c0085,0xd90c04d3,0xc6100154}},	//   _هيوا, _tosɛ, _ریی_, _সুরা_, 
   {{0xa2a80882,0x3618011a,0x95c8009b,0x00000000}},	//   ञ्ज्, _רוקד, _руља_, --, 
   {{0x63c4052f,0xafe00f89,0xbf640b24,0x690400a2}},	// [255e0] _тапҡ, ботл, ادرو, _eñeg, 
   {{0xa3040348,0x6d40004a,0x823490b2,0xef148f18}},	//   _түге, înan, _مرجا, гму_, 
   {{0x1cc0025c,0x00000000,0x00000000,0x00000000}},	//   _ཀྲུ_, --, --, --, 
   {{0xdb8c02d3,0xa3c8000d,0xfc2800ee,0x79a407a5}},	//   _ናይዞም_, _ईना_, нжек_, ҳрие, 
   {{0xdddc04bf,0xb338fbaa,0x3b940063,0x2ce8a638}},	//   _udrž, luça, ујет, عظمی_, 
   {{0xac045680,0xed540150,0x00000000,0x00000000}},	//   ынча_, _ұос_, --, --, 
   {{0x69040124,0x39ac0213,0xbaa401d5,0x00000000}},	//   _oñed, _kəsi_, вуққ, --, 
   {{0xed5569eb,0xee340640,0xfe4401d5,0x00000000}},	//   _бос_, _снс_, _анҳо, --, 
   {{0x28b0007b,0x39ac06be,0xad18011a,0xbb440107}},	//   صحيح, _məsi_, _נומר, _беак, 
   {{0x6e2800d2,0x569407b5,0x5ac80133,0xcaa401ec}},	//   _ímbú, јант, _جارێ_, _ەلەۋ, 
   {{0x644169ec,0xe9e400d7,0x00000000,0x00000000}},	//   ümin, žúry_, --, --, 
   {{0x691400a8,0xb3380798,0x00000000,0x00000000}},	//   nţel, duça, --, --, 
   {{0xf7f4104c,0xfc4401ef,0x00000000,0x00000000}},	//   _حساد, _šíji_, --, --, 
   {{0x59b8412f,0x2d84011f,0x00000000,0x00000000}},	//   _आहार, ânek_, --, --, 
   {{0x39ac06be,0x80700248,0x00000000,0x00000000}},	//   _bəsi_, _ọlọg, --, --, 
   {{0x2efc004a,0xf4850ed7,0x65903229,0x216569ed}},	//   _œuf_, _сукн, _اجور, стрг, 
   {{0x5f74036b,0x929531c6,0x00000000,0x00000000}},	// [255f0] مالر, _капц, --, --, 
   {{0xb8e4003d,0x6914054e,0xce94011c,0x00000000}},	//   _ཎི_, eţel, ражъ, --, 
   {{0xe7080156,0xd2502ab4,0xf1a40818,0x00000000}},	//   གལྷན_, _گنگ_, _ёрон, --, 
   {{0xed10015b,0xd0d401c6,0x52c41408,0x00000000}},	//   িক্স_, _томъ, _लघुस, --, 
   {{0xdd940efb,0xd2503868,0xa9240306,0x00000000}},	//   _қаты, _دنگ_, _ležé, --, 
   {{0x2fc80048,0x98fc0115,0x4994055f,0x6b8400db}},	//   _iscg_, _buĉo, ашит, _ەشال, 
   {{0x3b040801,0x98ac0139,0x00000000,0x00000000}},	//   рещо_, _audı_, --, --, 
   {{0xdb000166,0x690400e4,0x65b801f4,0x9cc800fb}},	//   _aqmä, _oñee, _lähö, _йыуа_, 
   {{0x1cc02b88,0xdddc0276,0xdc740209,0x8b840131}},	//   _ཀྲི_, _terţ, _ыгты, _ئەتە_, 
   {{0x46f569ee,0x28a40316,0xb3380724,0x9bf4013d}},	//   рчит, _गावि, yuça, _узуч, 
   {{0x2fc81710,0xdddc0024,0x00000000,0x00000000}},	//   _lscg_, _kerš, --, --, 
   {{0xdddc0010,0xfe34011a,0x00000000,0x00000000}},	//   _jerš, ירתי_, --, --, 
   {{0xdddc0010,0x00000000,0x00000000,0x00000000}},	//   _merš, --, --, --, 
   {{0x39ac00ac,0xb6a0010b,0x0ed40037,0x3dc4012d}},	//   _səsi_, _дишл, _डोलड, łowi_, 
   {{0xd17569ef,0x00000000,0x00000000,0x00000000}},	//   йыты, --, --, --, 
   {{0x64480213,0xdddc00c0,0x04c84029,0x98ac0139}},	//   ədin, _nerš, _شوخي_, _yudı_, 
   {{0x2d80014f,0x00000000,0x00000000,0x00000000}},	// [25600] _awje_, --, --, --, 
   {{0xb4d8004e,0xd0580212,0x2fc80129,0xef8014fb}},	//   plàc, урсі_, _dscg_, юлуп, 
   {{0x72980375,0x6ea401bc,0x4aa81223,0x3c6400db}},	//   _בסיס, _चारु, च्छव, акег, 
   {{0xdddc01fa,0x61fc010e,0x00000000,0x00000000}},	//   _cerš, myrl, --, --, 
   {{0x69140276,0x98fc01e4,0x1bd40395,0x8f740816}},	//   rţel, _suĉo, соля, _гусі, 
   {{0x98fc0115,0x1b640022,0x00000000,0x00000000}},	//   _puĉo, _ҳнаҭ, --, --, 
   {{0x98ac008e,0xb9e400d4,0x00000000,0x00000000}},	//   _sudı_, ріли, --, --, 
   {{0x60c569f0,0xdddc00f3,0x00000000,0x00000000}},	//   neim, _gerš, --, --, 
   {{0xfaa40364,0x1cc00156,0x98ac0139,0xf8b401e0}},	//   _вазо, _ཀྲག_, _qudı_, гөҙ_, 
   {{0xbb4401b9,0x61fc0432,0x00000000,0x00000000}},	//   _тезк, kyrl, --, --, 
   {{0xeb3008c9,0x60c569f1,0x4ed8008f,0x163401ca}},	//   _بىلد, keim, אַרנ, сеня, 
   {{0x60c569f2,0x61fc00ee,0x98ac008e,0x2d840356}},	//   jeim, dyrl, _tudı_, ânei_, 
   {{0x60c569f3,0xc8641371,0x98a40166,0x6ea41fc4}},	//   deim, _اطمي, _виҗе, _चालु, 
   {{0x64580115,0x2fc80334,0x0ed4000d,0xae14000d}},	//   _ŝvic, _rscg_, _डोंड, _धइलन_, 
   {{0x61fc00ee,0xe5a000f3,0x00000000,0x00000000}},	//   gyrl, _дији, --, --, 
   {{0x7f4c00c6,0x2099569a,0x622400d1,0x60c41dca}},	//   _ahbq, иксы_, زىقل, geim, 
   {{0x6e64a3fa,0x3ce812eb,0xe8280092,0x6e880114}},	// [25610] атеж, छाने_, ብጋቢነ, вљев_, 
   {{0xa8540375,0x8c440032,0x61fd69f4,0xf1a400f3}},	//   שימה_, ҙеле, byrl, _крмн, 
   {{0xb3381e54,0x28a403f3,0x1cc00003,0xdddd69f5}},	//   luço, _गालि, _ཀྲང_, _perš, 
   {{0x60c40175,0xa04c0208,0x00000000,0x00000000}},	//   ceim, ừơng_, --, --, 
   {{0xee8434d8,0xdddce65e,0x9cc89c36,0xef9000e5}},	//   _выбо, _verš, рыха_, _ذیاد, 
   {{0x6904035b,0xccf800b8,0x3c800014,0x0054011a}},	//   _oñec, _diśa_, _ہیمٲ, _לשרת_, 
   {{0x6ef00316,0xdddc0024,0xdd953d32,0x89d40150}},	//   _výbě, _terš, _мары, сілш, 
   {{0xd1b80240,0x00000000,0x00000000,0x00000000}},	//   _ኲነት_, --, --, --, 
   {{0xee900873,0xf8b401c6,0x2ac400f3,0x00000000}},	//   ﻟﮕﻪﻥ_, сөх_, _вљев, --, 
   {{0xb3380077,0x60c4002f,0x06e800d4,0x00000000}},	//   duço, zeim, умок_, --, 
   {{0xe8940014,0x80a8166d,0x439800d1,0x00000000}},	//   _نماں_, टलमे, ﭘﺘﯩﻦ_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x60c569f6,0x61fc0142,0x00000000,0x00000000}},	//   veim, wyrl, --, --, 
   {{0x644800ac,0x6d000118,0x00000000,0x00000000}},	//   ədil, लसँग_, --, --, 
   {{0x40948d17,0xc0e4011c,0x00000000,0x00000000}},	//   йрат, бовк, --, --, 
   {{0x6f0400b5,0x2d540135,0xb338010e,0x00000000}},	//   _aljc, _għex_, luçl, --, 
   {{0x60c569f7,0x6f0400b5,0xe0581272,0x40480114}},	// [25620] reim, _bljc, شیست_, упао_, 
   {{0x60c569f8,0xb3380365,0x1cc0031c,0xb4d856ed}},	//   seim, nuçl, _ཀིང_, nlàn, 
   {{0xf09c0109,0x60c569f9,0x57c40073,0x6d0000bc}},	//   _ilàn_, peim, _वन्ह, लसंग_, 
   {{0xed5400a6,0xb4d804cc,0x39ac06be,0xee2c00ec}},	//   бох_, hlàn, _məst_, رٽن_, 
   {{0x6bd04c2d,0xbb443da1,0x7f484c84,0x00000000}},	//   كتور, бедк, _ملحق_, --, 
   {{0x6f0400b5,0x9b5801c6,0xccf800b8,0xa0c4009f}},	//   _gljc, шилт_, _viśa_, _ايڏو, 
   {{0xb4d804cc,0x6da0020f,0xada001c4,0x00000000}},	//   dlàn, _нира, _нарл, --, 
   {{0xa3c80406,0xdc3c0306,0x2d440254,0x00000000}},	//   ईबा_, láčo, nõel_, --, 
   {{0x7d0169fa,0xc0cc02d3,0x3f90037e,0xaf1800eb}},	//   mkos, _ጥቕሚ_, nsyu_, তকরণ_, 
   {{0xf6e495fa,0xfd4c0248,0xdc3c0419,0x3dc40210}},	//   сцин, _ranṣ, náčo, łowu_, 
   {{0x7d0169fb,0x588401e0,0xea74011a,0x00000000}},	//   okos, _һыҙа, _הגבר_, --, 
   {{0x7d0169fc,0xdc3c0f91,0x39ac03b9,0x2d440037}},	//   nkos, háčo, _dəst_, jõel_, 
   {{0xf09c01ab,0x7d0169fd,0x77901968,0x569569fe}},	//   _blàn_, ikos, _عیدا, _далт, 
   {{0x7d00f4d5,0xdce001e4,0xc25c007f,0xe56c01d5}},	//   hkos, _dimĉ, _enpٍ, بطی_, 
   {{0x7d0169ff,0xdc3c02f0,0x80d00154,0x9258009d}},	//   kkos, dáčo, হান্, равт_, 
   {{0xa08800cf,0x00000000,0x00000000,0x00000000}},	//   йсуз_, --, --, --, 
   {{0xfb040de2,0x00000000,0x00000000,0x00000000}},	// [25630] _ñëwu_, --, --, --, 
   {{0x7d000660,0x6e64442d,0x00000000,0x00000000}},	//   ekos, стаж, --, --, 
   {{0x7d006c2b,0x39ac06be,0x63a8012d,0xabb00150}},	//   fkos, _xəst_, ądne, _ﺼﻔﻘﺎ, 
   {{0x30a434d8,0x7d016a00,0x386506be,0x69040022}},	//   _уров, gkos, _ngor_, _oñea, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x38640cfd,0x7d000958,0x17f400dc,0x7eb00174}},	//   _agor_, akos, ेनैव_, rðpó, 
   {{0x69040022,0xcce80014,0xb338236c,0xee340354}},	//   _añea, _پڑاو_, vuçl, çнă_, 
   {{0x14d80574,0x7d016a01,0x64400254,0x00000000}},	//   _बोलण, ckos, ümik, --, 
   {{0xb4d835f5,0x7b0408a5,0x00000000,0x00000000}},	//   tlàn, _iðun, --, --, 
   {{0x80d05d2d,0x1bb96a02,0x38640156,0x9cd402f2}},	//   হায্, _دافع_, _egor_, _وڕۆژ, 
   {{0x690400e4,0xb4d96a03,0x452801d5,0x00000000}},	//   _eñea, rlàn, ижон_, --, 
   {{0xf09c0e89,0x3f900113,0x044400d8,0x00000000}},	//   _slàn_, ysyu_, жемн, --, 
   {{0x80d003f4,0xd87403e6,0xf09c07c5,0xb4d804cc}},	//   হাম্, _رانب, _plàn_, plàn, 
   {{0x27fc7dcc,0x291d6a04,0x4208004e,0x7d00b29b}},	//   myun_, liua_, анго_, zkos, 
   {{0x27fd6a05,0x39ac03be,0xdc3c0f91,0x00000000}},	//   lyun_, _həsr_, váčo, --, 
   {{0x291d6a06,0x39ac06be,0x7d00002f,0xf650011a}},	//   niua_, _kəsr_, xkos, _קצה_, 
   {{0x291c0093,0x216846ee,0x00000000,0x00000000}},	// [25640] iiua_, риғи_, --, --, 
   {{0xaec00228,0x3eac03fa,0x656402f6,0x27fc0198}},	//   мбул, üft_, _hiih, iyun_, 
   {{0x7dc4278f,0x27fcc85e,0x7d016a07,0x656402f6}},	//   تقان, hyun_, tkos, _kiih, 
   {{0x291c00ec,0x64441418,0xccf800cd,0x27fc037e}},	//   jiua_, _kyii, _diśo_, kyun_, 
   {{0x656402b1,0x82356a08,0x291c04cc,0x27fc037e}},	//   _miih, _درکا, diua_, jyun_, 
   {{0x291c0270,0x20000109,0x8b6400c6,0x38644436}},	//   eiua_, myii_, ساهم, _sgor_, 
   {{0x64440083,0xf668036b,0x6bd000d1,0x79a401ec}},	//   _lyii, یحده_, كتۈر, ірке, 
   {{0xd7c80502,0xdcfc0989,0x65656a09,0x57f4763d}},	//   موعه_, _tvrđ, _niih, зпит, 
   {{0x64442255,0x27fc6d1f,0x20016a0a,0x00000000}},	//   _nyii, gyun_, nyii_, --, 
   {{0x6564003e,0x21216a0b,0xf8d80d79,0x00000000}},	//   _aiih, hiih_, _मोरय, --, 
   {{0x27fc0357,0x443008cd,0x65640083,0x6444fa60}},	//   ayun_, _axy_, _biih, _ayii, 
   {{0x1cb808ea,0x644400ca,0xe9fc001e,0x37e4034b}},	//   _མཁས_, _byii, _hiếm_, _моег, 
   {{0xe9fc07ae,0x64456a0c,0x644800ac,0x65656a0d}},	//   _kiếm_, _cyii, ədik, _diih, 
   {{0x35680276,0x69040055,0x324c0092,0xb5a541f6}},	//   _крин_, _jñen, _በስልጣ, _дрий, 
   {{0x44300204,0x656404ba,0x66715d8f,0x64440241}},	//   _exy_, _fiih, _تۯپر, _eyii, 
   {{0x98fc00df,0xe9fc01fb,0x2120020c,0x656400d8}},	//   _buĉi, _liếm_, giih_, _giih, 
   {{0x6904035b,0xb4c41025,0xe13801ec,0x00000000}},	// [25650] _oñen, ईजी_, ізуі_, --, 
   {{0x65640472,0x291c005a,0x00000000,0x00000000}},	//   _ziih, ziua_, --, --, 
   {{0x2d856a0e,0x2000208d,0x65640009,0x81cc0154}},	//   ène_, ayii_, _yiih, _শপথ_, 
   {{0x27fd6a0f,0x69040022,0x2d448607,0x64440083}},	//   yyun_, _añen, põem_, _yyii, 
   {{0xe9fc004d,0x00000000,0x00000000,0x00000000}},	//   _biếm_, --, --, --, 
   {{0x27fc0998,0x2d840129,0x8afc0118,0x81cc00cc}},	//   vyun_, ânes_, _kuři, _শপত_, 
   {{0x1a6807d6,0x291d6a10,0x7b0408a5,0xe9fc0208}},	//   زینی_, tiua_, _iðul, _diếm_, 
   {{0xc0e80092,0x2ad80550,0x00000000,0x00000000}},	//   _ፅንሰ_, _गोरु_, --, --, 
   {{0x65656a11,0xf8ac8235,0x291d6a12,0x39ac06be}},	//   _riih, اکم_, riua_, _qəsr_, 
   {{0x1cb80ed9,0x6564049b,0x9e2801d9,0x291d6a13}},	//   _མཁོ_, _siih, _آہم_, siua_, 
   {{0x6564f43c,0xf09c0109,0xe1d00220,0x27fd6a14}},	//   _piih, _alàm_, _ءﺍﺩﯨ, syun_, 
   {{0x64440083,0x20000a55,0x3e14010f,0x00000000}},	//   _pyii, yyii_, פֿיל_, --, 
   {{0x6564049b,0x27fc0309,0xe61000ec,0x00000000}},	//   _viih, qyun_, _ڪشش_, --, 
   {{0x1cc049a6,0xdef0069d,0xb7d8011a,0x8afc01ef}},	//   _ཀྲན_, _ጃፓን_, _לקני, _buři, 
   {{0x65655617,0x98fc00df,0xc0e44627,0x00000000}},	//   _tiih, _suĉi, повк, --, 
   {{0x2020001f,0x98fc01e4,0x42080107,0xc484081b}},	//   _ተመልክ, _puĉi, анҳо_, _элик, 
   {{0x44240120,0xfc240154,0xd39801af,0x25a4009f}},	// [25660] _ão_, _বর্ষ_, _мәрә_, _ادڙي_, 
   {{0x2cbc5513,0x2120020b,0x690400c7,0x2000009f}},	//   _abud_, siih_, _oñeo, ryii_, 
   {{0xbc68158b,0x6da000c7,0x00000000,0x00000000}},	//   ممان_, еиха, --, --, 
   {{0xccf8068f,0x21200009,0x224c0118,0x3b640395}},	//   _coś_, qiih_, ýdku_, пъкв, 
   {{0xbb440220,0x2d840129,0x8afc0118,0xab700150}},	//   педк, âner_, _zuři, егіш, 
   {{0x9f940124,0x00000000,0x00000000,0x00000000}},	//   _ныҳә, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdc3c0308,0xb340031c,0x88800066,0x00000000}},	//   _háčk, ħħih, پیون, --, 
   {{0xd5e806d6,0xed5405f5,0xbb856a15,0x76a00248}},	//   raḓ, _хот_, _رلاي, _níyà, 
   {{0x8b656a16,0x88bc0882,0xdce0013a,0x00000000}},	//   _قالم, viśe, _mimč, --, 
   {{0xe94400dd,0xda7000ec,0x00000000,0x00000000}},	//   _کرلی, _ٻڏڻ_, --, --, 
   {{0x76a00241,0x7af80e21,0xb3390d98,0x00000000}},	//   _bíyà, _hott, muçi, --, 
   {{0x7af96a17,0x1cc0ce91,0xe8c4031c,0xb338405f}},	//   _kott, _ཀིན_, _ཁྲིག, luçi, 
   {{0xfa28038f,0x7af96a18,0xd05c0085,0x63a000e5}},	//   _སྨོན_, _jott, _mosɔ, ámna, 
   {{0x7af8df7a,0xb9d8001f,0x557401d5,0x00000000}},	//   _mott, _በኔ_, _ўгит, --, 
   {{0x7af81486,0x76a001e1,0xd5b800e2,0x61e800cc}},	//   _lott, _fíyà, mtā_, ådla, 
   {{0x7af96a19,0xf53c0004,0x9f055904,0xd5b8005f}},	// [25670] _oott, moå_, کولو, ltā_, 
   {{0x7af96a1a,0x2ec400dc,0x5ed401c6,0xfc2400fe}},	//   _nott, रजेत, нжуу, _বৰ্ষ_, 
   {{0xd5b84114,0x88bc0882,0xdcfc013d,0x9e98002e}},	//   ntā_, niśc, _aqrı, _ŋàññ_, 
   {{0x98fc01e4,0xd5b8005f,0x76a001e1,0xb3380166}},	//   _kuĉu, itā_, _yíyà, duçi, 
   {{0x7af96a1b,0xceb800fb,0x3200010b,0x00000000}},	//   _bott, _мәж_, lyjy_, --, 
   {{0xd5b84114,0x7af96a1c,0x00000000,0x00000000}},	//   ktā_, _cott, --, --, 
   {{0x7af96a1d,0x1cc00dd4,0xf53c0004,0x9e34084c}},	//   _dott, _ཀྲམ_, koå_, _зерч, 
   {{0x2cbc008b,0x7af80263,0x2908007b,0x98a400e2}},	//   _ubud_, _eott, óca_, domē_, 
   {{0x7af96a1e,0xaa6402dd,0xd5b800e2,0x2c1800cc}},	//   _fott, _етек, etā_, _ফুৰে_, 
   {{0x7af96a1f,0x6670034c,0x06c805f5,0x6904035b}},	//   _gott, رگتر, цгой_, _iñem, 
   {{0x5ac8025c,0xa50800d1,0x76a001e1,0x9a6800d8}},	//   _གྲིམ, كىدە_, _síyà, _хјуз_, 
   {{0x7af801a4,0x3200010b,0x00000000,0x00000000}},	//   _zott, dyjy_, --, --, 
   {{0x7af8037e,0x3fcc0150,0x00000000,0x00000000}},	//   _yott, _ﻗﻴﺎﻧ, --, --, 
   {{0x88bc0034,0x7af8f28f,0xdce00153,0xc7b800e5}},	//   biśc, _xott, _rimč, mtő_, 
   {{0xf53c0589,0xc7b801ed,0x443c033f,0x32416a20}},	//   boå_, ltő_, łt_, верг, 
   {{0x690403a5,0xdc3c0308,0x00000000,0x00000000}},	//   _oñem, _sáčk, --, --, 
   {{0xc7b800dd,0xdc3c02fb,0x6914054e,0x44240108}},	// [25680] ntő_, _páčk, lţes, _äo_, 
   {{0xb4d8002e,0x02c401a9,0xb338010e,0x00000000}},	//   ylàk, _ўйно, ktçy, --, 
   {{0x8234c25a,0x6904035b,0xc0580220,0x69140311}},	//   _زردا, _añem, сің_, nţes, 
   {{0x7af96a21,0xce34004b,0x6c816a22,0x00000000}},	//   _sott, رونک, پلوم, --, 
   {{0x28a40034,0xeb956a23,0x7af96a24,0xc7b801d3}},	//   _गाजि, дич_, _pott, jtő_, 
   {{0x1cc0031c,0x7af96a25,0x00000000,0x00000000}},	//   _ཀིམ_, _qott, --, --, 
   {{0x7af96a26,0x690400c7,0xb4d800db,0xb338010b}},	//   _vott, _eñem, noàc, gtçy, 
   {{0x7af81bce,0xf1b00375,0xfbc40117,0xc8380092}},	//   _wott, דסה_, _оббо, _ከሳምን, 
   {{0xb8d45345,0x7af96a27,0x88bc068f,0x5694e3cd}},	//   _जा_, _tott, wiśc, напт, 
   {{0xd5b80882,0x2bc40116,0xabf80375,0xb3380200}},	//   ttā_, _юлуп_, _והמר, puçi, 
   {{0xba18038b,0x98fc01e4,0x2ae827a6,0x00000000}},	//   _بيضا_, _suĉu, चारु_, --, 
   {{0xd5b80061,0x7bc4025a,0xe9445945,0x0c7802d3}},	//   rtā_, _âkus, _قرنی, _ብሓጺሩ_, 
   {{0xd5b89787,0xf53c0589,0x94040035,0xe7b001f7}},	//   stā_, roå_, روسه, _لمند, 
   {{0x1754230c,0x163400c0,0x00000000,0x00000000}},	//   _явля, _пеля, --, --, 
   {{0x2cac36d5,0x399800e2,0x002c0092,0xd5b0007b}},	//   yggd_, nīs_, _በመከና, _صفة_, 
   {{0x69040789,0x799802d0,0x00000000,0x00000000}},	//   _añej, _mvtw, --, --, 
   {{0x5f740f1c,0x32cc0166,0x8afc01ef,0x5f9405a9}},	// [25690] نالر, _cıyü_, _kuřt, китт, 
   {{0xb0dccd66,0x32006aad,0x00000000,0x00000000}},	//   _पोरग, pyjy_, --, --, 
   {{0xd130267a,0x9e252374,0x4ad800dc,0xdd945d9f}},	//   _ممد_, نىكو, _योगव, вахы, 
   {{0x3998005f,0x00000000,0x00000000,0x00000000}},	//   dīs_, --, --, --, 
   {{0xf09c0241,0x0f78010f,0xabc80066,0x00000000}},	//   _idà_, _מאָב, تذال_, --, 
   {{0x4e840014,0x5f8407d2,0x00000000,0x00000000}},	//   _سٔرٕ, _شۇمە, --, --, 
   {{0x80d00154,0x00000000,0x00000000,0x00000000}},	//   হার্, --, --, --, 
   {{0xc7b801ed,0x2bc8014b,0x14c000cd,0x00000000}},	//   ttő_, _музо_, ष्मण, --, 
   {{0x200405d1,0x60c15a23,0xccf800cd,0x8afc013a}},	//   _ümit_, _ömme, _niśi_, _buřt, 
   {{0x6b982da1,0x6d496a28,0xc7b801ed,0x3998003a}},	//   _ivug, llga, rtő_, bīs_, 
   {{0x7bc40022,0x6d480ea0,0xdce0002b,0x41cc07f7}},	//   _âkur, olga, _himā, _हैंस, 
   {{0xfa280867,0xdce000cd,0xf09c01e1,0x03a424c3}},	//   _སྨིན_, _kimā, _ndà_, нимо, 
   {{0x290d6a29,0xa5080131,0x68e96a2a,0xd8b800f2}},	//   _ilga_, كىگە_, _ingd, _آدما_, 
   {{0x6b980516,0x69040124,0xccf800dc,0x6d4867c4}},	//   _mvug, _oñek, _diśi_, hlga, 
   {{0x68e8020c,0x00000000,0x00000000,0x00000000}},	//   _kngd, --, --, --, 
   {{0x6b980083,0x644000c5,0x6d48005c,0x448800db}},	//   _ovug, ümis, jlga, _эбин_, 
   {{0x690400e4,0x6b98895d,0x44640212,0x00000000}},	// [256a0] _añek, _nvug, _явив, --, 
   {{0x70500ef6,0x6d480363,0x68e80175,0xa0696a2b}},	//   انكا, elga, _lngd, заға_, 
   {{0x6b980537,0x7d78021a,0xdcf40552,0x7bdc005f}},	//   _avug, سمشر_, šači, āpum, 
   {{0x6d4801bf,0x3f68014b,0x3ea40205,0x00000000}},	//   glga, _нимо_, şot_, --, 
   {{0x690400e4,0x1bd48740,0x00000000,0x00000000}},	//   _iñeh, толя, --, --, 
   {{0x290d6a2c,0x399800da,0x68e96a2d,0x6d496a2e}},	//   _alga_, tīs_, _angd, alga, 
   {{0x6b996a2f,0x13c8015b,0x0d9801ec,0x00000000}},	//   _evug, শিয়, _отты_, --, 
   {{0xa9656a30,0xb058145e,0x290c00a3,0xb4d8004e}},	//   нија_, _mbän, _clga_, llàv, 
   {{0x3998005f,0x1b640124,0x01d400eb,0x00000000}},	//   sīs_, _анаҭ, হমিদ, --, 
   {{0x3a14893f,0x290d6a31,0x68e80477,0xb33803ee}},	//   _пьес, _elga_, _engd, nuçt, 
   {{0x69040588,0x16340f06,0x00000000,0x00000000}},	//   _oñeh, теня, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd6d40323,0xb0580112,0x00000000,0x00000000}},	//   _ажлы, _abän, --, --, 
   {{0x690400e4,0x9258009d,0xf41c013d,0x66e0009b}},	//   _añeh, дагт_, bbän_, _боља, 
   {{0x62344827,0x752c0175,0x290c00a2,0x00000000}},	//   геру, pncz, _ylga_, --, 
   {{0xdddc0153,0xd2500014,0xd39401af,0x659001f0}},	//   _berž, ُچھ_, _иҙмә_, _саъу, 
   {{0x6d48074d,0xf8c000dc,0x76480042,0x73480798}},	// [256b0] vlga, व्यय, _hyfy, _нчов_, 
   {{0x6d480050,0xdddc01a6,0xdce00055,0x59e003ce}},	//   wlga, _derž, _rimā, पटार, 
   {{0x6b9805a1,0x77680327,0x5f5c001f,0x6d494d6f}},	//   _svug, _mifx, _ቁጥራቸ, tlga, 
   {{0x39456a32,0x764800a9,0xe7e000bc,0xc19800d9}},	//   _nkos_, _myfy, कटमा_, _קשרי, 
   {{0x7c700131,0x6d48022e,0x80d8098a,0x00000000}},	//   рғуч, rlga, _पोटे, --, 
   {{0x690400e4,0xfaa00107,0x6d4801ab,0xdce000dc}},	//   _iñei, аашо, slga, _vimā, 
   {{0x9f34204c,0x00000000,0x00000000,0x00000000}},	//   _сері, --, --, --, 
   {{0x6b98007c,0xdce000b8,0x48e4014b,0x00000000}},	//   _tvug, _timā, тоив, --, 
   {{0x6b98015c,0xf8b4009d,0xb3380205,0x00000000}},	//   _uvug, төх_, nuçs, --, 
   {{0x68e80399,0x39440798,0x88bc033f,0x290c015d}},	//   _wngd, _ekos_, ciśn, _wlga_, 
   {{0x290c22d0,0xa6d004c5,0x764800a9,0xbc640137}},	//   _tlga_, ়ালট, _cyfy, _كۅۅن_, 
   {{0x68e96a33,0x2d44315a,0x76480368,0x9abc031c}},	//   _ungd, mões_, _dyfy, _imċa, 
   {{0x2d4406ed,0x5ed82b1b,0x188001e0,0x00000000}},	//   lões_, ঠাতে, _уңын, --, 
   {{0x76480368,0x5fe0012c,0xaca0010e,0xe1f80107}},	//   _fyfy, निसल, _kyỳa, еҳо_, 
   {{0x76480368,0xef1c0254,0xdddc25ad,0x00000000}},	//   _gyfy, _mtüd_, _serž, --, 
   {{0xdddc02d5,0x67200175,0x1ee86a0e,0xcacc0154}},	//   _perž, _hmnj, کوئی_, লাটফ, 
   {{0x2d440120,0x7bdc02b5,0x00000000,0x00000000}},	// [256c0] hões_, āpuk, --, --, 
   {{0x0204035b,0xdddce676,0xefc401f0,0x00000000}},	//   _азон, _verž, ълул_, --, 
   {{0x81441617,0xdce0054e,0xb4d9532d,0x2d45440a}},	//   _لندن, _nimă, rlàv, jões_, 
   {{0x6da04303,0x2d440120,0xb4d800db,0x64480213}},	//   рица, dões_, slàv, ədir, 
   {{0x6bd16a34,0xdb5004d3,0xdd0c0034,0x00000000}},	//   لتور, مێر_, _półn, --, 
   {{0xf9c429c3,0x39440489,0x2d4400d8,0x3f80005b}},	//   вщин, _skos_, fões_, _itku_, 
   {{0x2d440120,0xe6040228,0xfca800ec,0x00000000}},	//   gões_, _ئش_, _يارو_, --, 
   {{0x764803d4,0xef1cfe4a,0xfa340050,0x98b801a9}},	//   _ryfy, _etüd_, _یراد, хлит_, 
   {{0x02b00073,0x7648036e,0x00000000,0x00000000}},	//   _जांभ, _syfy, --, --, 
   {{0xdca40184,0x69300356,0x00000000,0x00000000}},	//   _шағи, lăel, --, --, 
   {{0x2d440798,0x7648036e,0x00000000,0x00000000}},	//   cões_, _qyfy, --, --, 
   {{0xdcfc04a7,0xef1c008e,0x168403e6,0xb4b000d1}},	//   _otrč, _itüe_, _ڵاتێ, шимә, 
   {{0x78a16a35,0xa9640022,0x76480142,0xaca000a2}},	//   _idov, _рица_, _wyfy, _zyỳa, 
   {{0x56940372,0x7bdc0374,0xa424008e,0x00000000}},	//   _сакт, āpuh, рьюл, --, 
   {{0xa2940d30,0xb5f002dd,0x973401d3,0x78a00118}},	//   расі, _түні, _لکھا, _kdov, 
   {{0x2bf00490,0xb03000fd,0xa184151e,0x25ec0456}},	//   _आपलं_, амбә, рырл, इमरी_, 
   {{0x2d4406ed,0x10a40116,0xa07400cf,0x905400d4}},	// [256d0] zões_, киңн, ргуч, увац, 
   {{0xe7e05219,0x00000000,0x00000000,0x00000000}},	//   कटता_, --, --, --, 
   {{0x2d440261,0x78a001f1,0xdddc031c,0xb07401ee}},	//   xões_, _odov, _gerż, _аҡбу_, 
   {{0x78a16a36,0x4c3405f5,0x2d440798,0x507805d9}},	//   _ndov, лэлт, vões_, _ڪجھھ_, 
   {{0xcac80120,0xaca00432,0x60c001e3,0x00000000}},	//   егле_, _syỳa, _ömma, --, 
   {{0x2d440261,0xf1c40574,0x78a06d64,0x00000000}},	//   tões_, _लहान, _adov, --, 
   {{0xdd94151e,0x00000000,0x00000000,0x00000000}},	//   _васы, --, --, --, 
   {{0x2d440120,0x78a00334,0xd05c01e4,0x9e34010a}},	//   rões_, _cdov, _posɨ, _тесч, 
   {{0x6d580cfe,0x2d440261,0x690400e4,0x1bd4011b}},	//   _ihua, sões_, _oñev, _котя, 
   {{0x6d583dc2,0x2d440798,0x7bc40022,0xdddc0064}},	//   _hhua, pões_, _ãkua, _gerų, 
   {{0x88bc068f,0x6d596a37,0x78a00334,0x056421f3}},	//   liśm, _khua, _fdov, лвон, 
   {{0x42800020,0x2edc00cd,0x00000000,0x00000000}},	//   ንዳንድ_, नयुत, --, --, 
   {{0x68f95a68,0x957801c0,0xc7a56a38,0x7878008f}},	//   mjud, нөөс_, _силк, _אָוו, 
   {{0x68f82042,0x2d802d15,0x6d596a39,0x6720107d}},	//   ljud, _otje_, _lhua, _umnj, 
   {{0x78a00a73,0x84e56a3a,0xdcfc0306,0x6d596a3b}},	//   _ydov, _бойж, _strč, _ohua, 
   {{0xdd000029,0xdddc003d,0x68f96a3c,0x6d580208}},	//   ītīb, _verż, njud, _nhua, 
   {{0x2d80044e,0xa2ac02e5,0xdd00005f,0xe5a0267c}},	// [256e0] _atje_, _जयप्, ūtīb, _сиқи, 
   {{0x6d596a3d,0xf0616a3e,0x2d8001f5,0x68f96a3f}},	//   _ahua, скуп, _btje_, hjud, 
   {{0x6d580ea3,0x7e5400a8,0xf09c00a3,0x2fc80cf4}},	//   _bhua, утац, _clàs_, _epcg_, 
   {{0x6d58387b,0x2fd0145e,0x7c940a2c,0xdcb02002}},	//   _chua, ëngö_, اشاا, زىت_, 
   {{0x6d596a40,0xada025f8,0xac940f84,0x3f812c62}},	//   _dhua, _қатл, انها_, _utku_, 
   {{0x6d5800d8,0x68f8003a,0x1d840133,0x00000000}},	//   _ehua, ejud, _ندرێ, --, 
   {{0x6d580013,0x6bd00075,0xa2ad3394,0xaa54007b}},	//   _fhua, لتۈر, _जयन्, هلها_, 
   {{0x60c56a41,0x6d5814d0,0x3eb0054e,0xd7c80b73}},	//   nfim, _ghua, şată_, نوعه_, 
   {{0xd04803f9,0x78a02e31,0xb76406b0,0x97140276}},	//   ɓoɓi, _vdov, лтой, имиц, 
   {{0x6d596a42,0x59dc0316,0x24800120,0x2d80002d}},	//   _zhua, _मनपर, _afim_, _ytje_, 
   {{0x68f804f3,0x24800200,0xeef400df,0x00000000}},	//   bjud, _bfim_, אמיר_, --, 
   {{0x78a16a43,0xd1f80023,0x00000000,0x00000000}},	//   _udov, ለኣብ_, --, --, 
   {{0x1cb81efe,0x79500133,0x60c534a8,0x00000000}},	//   _མཁན_, _پێکا, dfim, --, 
   {{0x59b8073d,0x3dc40034,0x684001b9,0xe85000f2}},	//   _इमार, łowy_, _унча, _انهد, 
   {{0x60c40af5,0x645800df,0xf1ac0073,0xf7700345}},	//   ffim, _ŝvit, जूंन, _ئاڤ_, 
   {{0x70ac0490,0x60c402d2,0xb4d80248,0x00000000}},	//   टलेल, gfim, alàr, --, 
   {{0x6d580070,0xf09c0e89,0x64b40150,0x5f300023}},	// [256f0] _rhua, _blàr_, _احىر, _ተረኽቦ, 
   {{0x6d596a44,0xf09c0013,0x60c43877,0xb4d800db}},	//   _shua, _clàr_, afim, plàs, 
   {{0x6d580211,0x00000000,0x00000000,0x00000000}},	//   _phua, --, --, --, 
   {{0x6d580457,0x60c401e7,0xdd956a45,0x00000000}},	//   _qhua, cfim, сацы, --, 
   {{0x6d580943,0x68f8036b,0x2ba40640,0x5bc41532}},	//   _vhua, vjud, ујев, متوف, 
   {{0x8a056a46,0x6d596a47,0xadf00124,0x637c011a}},	//   изле, _whua, _логә, תנגד, 
   {{0x6d596a48,0x68f8fcfc,0x5f3800a7,0x6904260d}},	//   _thua, tjud, _спря_, _oñet, 
   {{0x09041925,0x00000000,0x00000000,0x00000000}},	//   рпин, --, --, --, 
   {{0x66812766,0x9d180150,0x00000000,0x00000000}},	//   میشل, _сотт_, --, --, 
   {{0x68f8070d,0x69040588,0xd76403e6,0x5f300023}},	//   sjud, _añet, مۆنی, _ተረኺቦ, 
   {{0xe9a800f2,0x3ce84f76,0x21c401ec,0x87d4210e}},	//   _سدان_, _घोडे_, _ﺨﻴﺎﺭ, _چغتا, 
   {{0xb91001f2,0x2b44009b,0x2eb00b6d,0xd8b80066}},	//   _mgbọ_, lonc_, ुभुत, _مدها_, 
   {{0xda3000c7,0x538001ec,0x00000000,0x00000000}},	//   _мҵәы, пқыз, --, --, 
   {{0x26c40211,0x4a8c0023,0x00000000,0x00000000}},	//   _ubno_, _ዓቀብቲ_, --, --, 
   {{0xd5e90565,0xb91001e1,0x41280353,0x00000000}},	//   _معين_, _ngbọ_, вово_, --, 
   {{0xb058025a,0xd1756a49,0x10880873,0x69040022}},	//   _gbäk, сыры, _ﺑﯩﺮﯨ, _iñes, 
   {{0xb910063f,0x60c40af5,0x2eb074c8,0x2b44b9be}},	// [25700] _agbọ_, rfim, ुभूत, konc_, 
   {{0xef156a4a,0xba04001f,0x3ea56a4b,0x60c40381}},	//   аму_, _ገፅ_, рижг, sfim, 
   {{0xdcfc3a71,0x2b44067c,0x60c56a4c,0x02b00764}},	//   _atrā, donc_, pfim, जलीन, 
   {{0x629d6a4d,0xbc6804d3,0xc0e4004e,0xdb1001e1}},	//   laro, نمان_, _томк, _òfún, 
   {{0xfbd01b56,0xfb8001b9,0x5ac801e0,0xab7400ae}},	//   تتا_, تگزی, лһам_, لمنا_, 
   {{0x79a41481,0x69040124,0x39a56a4e,0x00000000}},	//   арие, _oñes, ашив, --, 
   {{0x6da16a4f,0x629d6a50,0xb3a0000d,0x5fac01f9}},	//   _мира, iaro, _कट््, _चिडल, 
   {{0x629d6a51,0x688c044e,0x58d96a52,0x3b8475a2}},	//   haro, _ዓበይቲ_, удия_, _влаг, 
   {{0x69040022,0x9f4000db,0xa9640063,0x76700116}},	//   _añes, nviï_, шића_, оңлу, 
   {{0x629d6a53,0x7bc00010,0x37043da1,0x7b30033f}},	//   jaro, mtou, рчив, dług, 
   {{0xe9d40117,0x00000000,0x00000000,0x00000000}},	//   _вкх_, --, --, --, 
   {{0x7bc16a54,0x79880112,0xf41c03d4,0x00000000}},	//   otou, mpfw, _যুগৰ_, --, 
   {{0x185400db,0xa7f42e0b,0x3cfc012d,0x00000000}},	//   _اراڭ, _نعوذ_, _रचने_, --, 
   {{0x7bc0fb0e,0xbb4c019b,0xf41c01c7,0xb4d8002e}},	//   itou, _humオ_, nbäi_, rlàq, 
   {{0x7bc16a55,0x00000000,0x00000000,0x00000000}},	//   htou, --, --, --, 
   {{0x7bc0c795,0x00000000,0x00000000,0x00000000}},	//   ktou, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [25710] --, --, --, --, 
   {{0x629d6a56,0x7bc16a57,0x17b400fe,0xce94011c}},	//   caro, dtou, _জৈৱি, сажъ, 
   {{0xdcfc0029,0x80d00154,0x7bc001f4,0x00000000}},	//   _strā, হাজ্, etou, --, 
   {{0xc578008f,0xd25000f2,0x00000000,0x00000000}},	//   אָסט, _ونک_, --, --, 
   {{0xaca001f2,0x690400c7,0x00000000,0x00000000}},	//   _nnụn, _oñer, --, --, 
   {{0x5f940b3b,0xdf440064,0x00000000,0x00000000}},	//   _фирт, _дэсп, --, --, 
   {{0x1830001f,0xf8ac00f1,0x2b440200,0x00000000}},	//   _እስከዛ, ځکه_, ronc_, --, 
   {{0x224c000d,0x00000000,0x00000000,0x00000000}},	//   üdki_, --, --, --, 
   {{0x7bc16a58,0x629d6a59,0x2b440010,0xc72401c6}},	//   ctou, yaro, ponc_, йдий, 
   {{0x46f56a5a,0x629d6a5b,0x6914054e,0x00000000}},	//   счит, xaro, nţez, --, 
   {{0xa5080ae5,0x00000000,0x00000000,0x00000000}},	//   لىدە_, --, --, --, 
   {{0x69c0002d,0x5a0c010f,0x00000000,0x00000000}},	//   mtne, _שלאַ, --, --, 
   {{0xa2ac0d41,0x761401d5,0xd4c000c7,0x00000000}},	//   _जयद्, لقیز_, фҩык, --, 
   {{0x69c0003e,0x629d6a5c,0x00000000,0x00000000}},	//   otne, uaro, --, --, 
   {{0x629d6a5d,0x69c16a5e,0x7b30068f,0xd178d5d9}},	//   raro, ntne, sług, исті_, 
   {{0x7bc0002e,0x6360025a,0x69c16a5f,0xf47402dd}},	//   ytou, köng, itne, _гөрі_, 
   {{0x629d6a60,0x09bc02f5,0xdce00024,0x69c16a61}},	// [25720] paro, _আনফা, _gimę, htne, 
   {{0x629c006c,0x63a40c8c,0x69c16a62,0xdcfc054e}},	//   qaro, _ivin, ktne, _otră, 
   {{0xc058005e,0x63a4169f,0x7c844a1d,0x9f40067c}},	//   тің_, _hvin, буле, sviï_, 
   {{0x63a543ae,0x7bc16a63,0x69c00158,0x80d0015b}},	//   _kvin, ttou, dtne, হাঙ্, 
   {{0x69c16a64,0xd9e0b213,0x7bc00585,0x63616a65}},	//   etne, पट्ट, utou, göng, 
   {{0x7bc16a66,0x63a401c8,0xe9fc0208,0x00000000}},	//   rtou, _mvin, _giẫm_, --, 
   {{0xf41c1859,0xfaa40364,0x7bc00316,0xef14039b}},	//   rbäi_, _ҳазо, stou, _умр_, 
   {{0x63a56a67,0x636043e5,0xeab40131,0x00000000}},	//   _ovin, lönd, айә_, --, 
   {{0xfaa56a68,0x69c01590,0xf7e800f7,0x69c4014a}},	//   _газо, atne, اربى_, _äjen, 
   {{0x69c00010,0x3eb80051,0xdb2404f2,0xf7ac1d00}},	//   btne, ngpt_, _بوئی, _ﺳﻪﻧﻪ, 
   {{0x63a56a69,0x69c16a6a,0x29e41710,0x95396a6b}},	//   _avin, ctne, _gđa_, изот_, 
   {{0x2d700d0f,0x473400f7,0xe7340131,0x7b30012d}},	//   _kćer_, йнөс, _һеч_, słud, 
   {{0x07e800dd,0x69040124,0x98a4010b,0xf744537c}},	//   _پرنٹ_, _iñep, _гиҗе, _ледо, 
   {{0xf41c0004,0x66e16a6c,0xe9fc0051,0x67b800d9}},	//   rzä_, _ноча, _nhẻm_, _עמוק, 
   {{0x63a56a6d,0x30a53823,0x00000000,0x00000000}},	//   _evin, йрав, --, --, 
   {{0x11543981,0x62340276,0x9378aec3,0x00000000}},	//   ікаю, чесу, _кбит_, --, 
   {{0x752c068f,0x63a56a6e,0xa158f258,0x636002d2}},	// [25730] micz, _gvin, сату_, fönd, 
   {{0x752c068f,0x69c002fb,0xceb92282,0x876800cd}},	//   licz, ytne, шәм_, _kārṣ, 
   {{0x63a52ef9,0xf3c93f07,0x2d856a6f,0x69040588}},	//   _zvin, _شبکه_, ëne_, _oñep, 
   {{0x752c006d,0x2d84005f,0x25d40375,0x876800cd}},	//   nicz, īne_, מובן_, _mārṣ, 
   {{0xdcfc00a8,0x69c00175,0x7b30012d,0x63603720}},	//   _stră, wtne, dłub, bönd, 
   {{0x6360145e,0x69c16a70,0x690400c7,0x752c033f}},	//   röng, ttne, _añep, hicz, 
   {{0x63616a71,0x4fc400c7,0xa2ac4f71,0x00000000}},	//   söng, _усҟа, _जयस्, --, 
   {{0x69c0e4f5,0x9d18156c,0x4c941422,0x00000000}},	//   rtne, _лост_, _фиас, --, 
   {{0x6d496a72,0x69c16a73,0x61fc010a,0x752c07de}},	//   moga, stne, zxrl, dicz, 
   {{0x6d496a74,0x63a40d04,0x69040022,0x69c00072}},	//   loga, _rvin, _eñep, ptne, 
   {{0x6f056a75,0x89d848ca,0x752c068f,0x7ae8004b}},	//   _mojc, _خوار_, ficz, _خولې_, 
   {{0x752c068f,0x6d48f313,0x6f04014f,0x2ee015ad}},	//   gicz, noga, _lojc, _lajf_, 
   {{0x63600639,0x6d480421,0x63a56a76,0xa50804da}},	//   höne, ioga, _qvin, لىگە_, 
   {{0x6d496a77,0x6360023a,0x63a40327,0x00000000}},	//   hoga, köne, _vvin, --, 
   {{0x6d496a78,0x752c012d,0x00000000,0x00000000}},	//   koga, bicz, --, --, 
   {{0x63a56a79,0xe50400af,0x6d496a7a,0x752c1a54}},	//   _tvin, _लवटि_, joga, cicz, 
   {{0x6d496a7b,0x63a41606,0x6f0400f3,0x7f8402ef}},	// [25740] doga, _uvin, _bojc, زلان, 
   {{0x4420037e,0x7e540452,0x00000000,0x00000000}},	//   mzk_, отец, --, --, 
   {{0x6d496a7c,0x6f056a7d,0x98a40276,0x636043e5}},	//   foga, _dojc, nimă_, rönd, 
   {{0xf09c07ae,0x2cbc01ab,0xed5405f5,0x63616a7e}},	//   _hoàn_, _ccud_, оох_, sönd, 
   {{0xc0f41b49,0x44200175,0xec7400d1,0x00000000}},	//   ለዓለ_, nzk_, әпә_, --, 
   {{0x63616a7f,0x6d4804c9,0xfd500241,0x05a80073}},	//   lönb, aoga, _jijẹ, _किंब, 
   {{0x6d496a80,0x69c401b8,0x66dc0006,0x752c014b}},	//   boga, _äjel, iškė, yicz, 
   {{0x6d480066,0x442000f3,0x9f4000db,0xf09c0051}},	//   coga, kzk_, lvià_, _loàn_, 
   {{0x6f04014f,0x87680055,0x3ad400ae,0x00000000}},	//   _yojc, _sārṣ, _ويرز, --, 
   {{0x752c0034,0xab2400a8,0x63607a78,0x9f416a81}},	//   wicz, _доуа_, hönb, nvià_, 
   {{0x6d4020ef,0x7c216a82,0xd7f82310,0x672c0030}},	//   énag, lzor, руқ_, _žijú, 
   {{0xc5ec021a,0x7d016a83,0x3ce56a84,0x91c40116}},	//   اړو_, njos, ndov_, үәнл, 
   {{0x752c8351,0x3ce41a33,0x675401d3,0xa2ac0073}},	//   ricz, idov_, _ڈیٹس_, _जयश्, 
   {{0xe8c42b88,0x6d496a85,0x7c20006f,0x7d000108}},	//   _གཡོག, zoga, izor, hjos, 
   {{0x6d496a86,0x2a2802d3,0x6f0401a6,0x4420005a}},	//   yoga, _እንተኮ, _rojc, azk_, 
   {{0x6d48f3ff,0xd5b800b0,0x6f040477,0x2ee00003}},	//   xoga, muā_, _sojc, _sajf_, 
   {{0x6d496a87,0xd5b80421,0x7d000cf4,0x00000000}},	// [25750] voga, luā_, djos, --, 
   {{0x7c216a88,0x2cbc1caa,0x5ed405f5,0x6d496a89}},	//   dzor, _scud_, мжуу, woga, 
   {{0x9f051d63,0x7c200117,0x3ea80175,0xd5b800b0}},	//   بولو, ezor, _ddbt_, nuā_, 
   {{0x6f042634,0x7d000240,0xdd9800cf,0xf41c00fd}},	//   _wojc, gjos, юшу_, bbät_, 
   {{0x2bb8007b,0xf41c01c7,0x8c440120,0x00000000}},	//   شاشة_, pbäu_, џеле, --, 
   {{0x37c003f4,0x2004026c,0x6d496a8a,0xcb880023}},	//   ্টার, _àmia_, soga, _ዝደለየ_, 
   {{0x6d496a8b,0x98a40276,0x63616a8c,0x2fc40083}},	//   poga, ximă_, lönc, ăngu_, 
   {{0x2cbc0009,0x00000000,0x00000000,0x00000000}},	//   _ucud_, --, --, --, 
   {{0xb058025a,0x7c200034,0xec2000cf,0x3a700131}},	//   _gbät, czor, _تۉشپ, мләр, 
   {{0x88bc0882,0x98a40276,0x7cf0022e,0x00000000}},	//   viśu, timă_, lаrа, --, 
   {{0xe8dc01f2,0x644803be,0x7b300034,0xe98001d5}},	//   _azụm_, ədiy, słuc, _ўқин, 
   {{0x04456a8d,0x98a40356,0x23c40014,0x00000000}},	//   земн, rimă_, وٕجہ, --, 
   {{0x057403e6,0x00000000,0x00000000,0x00000000}},	//   _کاتد, --, --, --, 
   {{0x0af804c5,0x3ce53ec2,0x00000000,0x00000000}},	//   _অতুল_, zdov_, --, --, 
   {{0x7c20c044,0x66dc0024,0x27fc0067,0x44216a8e}},	//   zzor, rškė, lxun_, szk_, 
   {{0x04456a8f,0x35800092,0x7c216a90,0x00000000}},	//   _нейн, _ከሰባት_, yzor, --, 
   {{0xf09c01dc,0x65656a91,0x291c0374,0xdc7800b7}},	// [25760] _toàn_, _ihih, ihua_, ክትሪክ_, 
   {{0x65640270,0x8c3c03ee,0x98a40153,0x6ed0000d}},	//   _hhih, _keşf, mimą_, ड़गु, 
   {{0xf2940375,0x98a40024,0x9f4000db,0x7d016a92}},	//   _מכיר_, limą_, rvià_, tjos, 
   {{0x2d842137,0x7c2005f5,0x7d000024,0x3dc40100}},	//   ínea_, tzor, ujos, ńowo_, 
   {{0x98a402d5,0x5bf400aa,0x7d00023a,0x3ce43883}},	//   nimą_, بغاړ, rjos, rdov_, 
   {{0x7c216a93,0xe8c40135,0x2000022f,0x27fc0009}},	//   rzor, _གཡུག, mxii_, dxun_, 
   {{0xf41d3c88,0x65640270,0x7c2001ed,0x64440381}},	//   nbär_, _ohih, szor, _lxii, 
   {{0x65640280,0x98a402d5,0x7c2001f5,0x57f400f5}},	//   _nhih, kimą_, pzor, дпит, 
   {{0x98a402d5,0x5f002e1e,0xeb94033a,0x6d40030a}},	//   jimą_, राप्_, _нит_, énae, 
   {{0x291c0053,0x65656a94,0xd5b96a95,0x98a40006}},	//   ahua_, _ahih, tuā_, dimą_, 
   {{0x212006a3,0x0ae8a3a9,0x6564002b,0x6448e978}},	//   khih_, _برقي_, _bhih, şdil, 
   {{0x291c1bb7,0x65656a96,0x39980024,0xe978011a}},	//   chua_, _chih, mūs_, _הנאש, 
   {{0x656422a9,0x399802d5,0x6444c4e9,0xd5b80421}},	//   _dhih, lūs_, _cxii, suā_, 
   {{0x65640521,0x00000000,0x00000000,0x00000000}},	//   _ehih, --, --, --, 
   {{0x64440381,0x5f0000dc,0x39980024,0x059400db}},	//   _exii, रान्_, nūs_, _قايگ, 
   {{0xe6380302,0x6564047e,0xdb4404d3,0x25d4008f}},	//   _לתוכ, _ghih, _ڕێ_, _זוהן_, 
   {{0xb3b4025c,0x2098a654,0xffc00150,0x00000000}},	// [25770] _བཀྲུ, якты_, көрп, --, 
   {{0x656403f9,0x09bc015b,0x39980024,0x799802d0}},	//   _zhih, _আনসা, kūs_, _owtw, 
   {{0x7998013f,0x20000009,0x291c0113,0xa184013d}},	//   _nwtw, axii_, yhua_, _пыял, 
   {{0x291c0218,0x20000a55,0x65640023,0x9f40067c}},	//   xhua_, bxii_, _xhih, rviá_, 
   {{0x64456a97,0xc0c039c7,0x8c3c0afb,0x6360ccfa}},	//   _xxii, _шәри, _meşg, löna, 
   {{0xb3b4031c,0x8c3c0432,0x6d406fca,0x00000000}},	//   _བཀླུ, _leşg, énab, --, 
   {{0x09bc0183,0xdea56a98,0x39982ba4,0x291cf8e3}},	//   _আনহা, _سینی, gūs_, thua_, 
   {{0x1a68c5f2,0x27fc01c6,0x7d08000f,0xdcfc012d}},	//   سینی_, txun_, êfst, _otrę, 
   {{0x6f140175,0x63600112,0x291c3889,0x06e000eb}},	//   okxc, höna, rhua_, বাসি, 
   {{0x291d6a99,0x05a834d8,0x65656a9a,0x6b980b6f}},	//   shua_, овой_, _shih, _iwug, 
   {{0x6aa16a9b,0x65656a9c,0x291c0270,0xdcfc00df}},	//   manf, _phih, phua_, _surĉ, 
   {{0x6b996a9d,0xdcfc01e4,0x99d40133,0x98a40024}},	//   _kwug, _purĉ, _ستما, timą_, 
   {{0x48241c3e,0x20016a9e,0x5f0000cd,0x225c00d7}},	//   _تىشق, xxii_, राम्_, _švk_, 
   {{0x6aa16a9f,0x6b9801b2,0x98a402d5,0xf41c007c}},	//   nanf, _mwug, rimą_, tbär_, 
   {{0x2120ab1a,0x8c3c010e,0x656403b2,0xb6f4075e}},	//   thih_, _heşd, _thih, _زىيا_, 
   {{0x656400ca,0x6b98bc12,0x98a40024,0xfe7003e6}},	//   _uhih, _owug, pimą_, ۆدا_, 
   {{0x64440548,0x2d8401d3,0x3ea40116,0xf41c3b52}},	// [25780] _uxii, ínen_, дизг, sbär_, 
   {{0xfe716aa0,0x2000022f,0x6aa0107d,0x786401a9}},	//   ندا_, rxii_, janf, dаvl, 
   {{0x6aa0b25d,0xada0010b,0x6da001c6,0x00000000}},	//   danf, вахл, виха, --, 
   {{0x6b980223,0x2000208d,0x39980024,0x00000000}},	//   _bwug, pxii_, vūs_, --, 
   {{0x6aa098a1,0x3f68e278,0xde48036b,0x00000000}},	//   fanf, _мимо_, _کیاو_, --, 
   {{0x39980006,0xdcfc025c,0x6aa00112,0x6b980210}},	//   tūs_, _kurċ, ganf, _dwug, 
   {{0x6b98009a,0xdb1002d2,0xf2d0011a,0x879c0055}},	//   _ewug, _ófín, דעו_, _āspṛ, 
   {{0xa96414b7,0x39980006,0x37a96aa1,0x8c3c03b9}},	//   мија_, rūs_, отон_, _beşd, 
   {{0xb88401e4,0xed24004b,0x39980153,0x0b8801e2}},	//   _neŭŝ, _تړلي_, sūs_, _فضلي_, 
   {{0x6b610bea,0x8c3c06be,0xef1c0790,0x55940120}},	//   _акуа, _deşd, _rtük_, наоѓ, 
   {{0x7af838e1,0xca60022e,0x8c3c010b,0xa2ec00bc}},	//   _intt, _ullа, _peşg, _छोइङ_, 
   {{0x1cdc031c,0x9f40005b,0x356801d5,0x00000000}},	//   _འིས_, lviä_, ўрон_, --, 
   {{0xd7c800f1,0xfe9c0241,0x00000000,0x00000000}},	//   _روغه_, _ẹ̀wà_, --, --, 
   {{0xccf800b8,0x00000000,0x00000000,0x00000000}},	//   _diśy_, --, --, --, 
   {{0x8c3c0311,0xe7043345,0x9f400108,0xd0d40395}},	//   _ieşe, _تسنی, iviä_, новъ, 
   {{0x8c3c010e,0x40e40131,0xdce00139,0x9f4001f4}},	//   _heşe, нсуғ, _rimğ, hviä_, 
   {{0x8c3c0598,0x7af96aa2,0x63600008,0x06e00154}},	// [25790] _keşe, _ontt, mönn, বারি, 
   {{0x91801b16,0x2d842cd7,0x6b980223,0x69cc00e1}},	//   _مۇسۇ, íneo_, _rwug, _दहली, 
   {{0xc87800fd,0x92580139,0x8c3c0205,0x246401e1}},	//   leşe_, _хант_, _meşe, _tèmí_, 
   {{0x7af96aa3,0xf53c0158,0x8c3c415b,0xdd9402d5}},	//   _antt, nnå_, _leşe, тацы, 
   {{0x6aa16aa4,0xc87862c7,0x00000000,0x00000000}},	//   tanf, neşe_, --, --, 
   {{0x8c3c4252,0x636001a8,0xb4d8004e,0xc84c0023}},	//   _neşe, hönn, nnàb, _ምስማዕ, 
   {{0xaca0063f,0x63616aa5,0xfaa400f2,0x00000000}},	//   _azụa, könn, رجوی, --, 
   {{0x6aa16aa6,0x6b98ad0c,0x7af8a88a,0x636001d3}},	//   sanf, _twug, _entt, jönn, 
   {{0x6b9807a8,0x6e380882,0x7af80175,0x8c3c05d2}},	//   _uwug, _śubh, _fntt, _beşe, 
   {{0x12d004c5,0x442401e4,0xc7b800e5,0x00000000}},	//   াযুদ, _ĥo_, lzők_, --, 
   {{0x8c3c0276,0x5f0000dc,0x999000b0,0x4c98010f}},	//   _deşe, रात्_, _ɾaŋi_, ּבֿו, 
   {{0xa3e40307,0x63600112,0xab680092,0x00000000}},	//   _ननद_, gönn, ትፈዋል_, --, 
   {{0x97d8007b,0x3fcc0046,0x00000000,0x00000000}},	//   _يظهر_, _ﺗﻴﺎﻧ, --, --, 
   {{0xe9fc07ae,0xcfe4045e,0xdcfc0003,0x8c3c00ee}},	//   _giảm_, নমান, _purċ, _keşb, 
   {{0x32416aa7,0x91c4010b,0xc5d4003b,0x00000000}},	//   герг, карҗ, _чіль, --, 
   {{0x194400b5,0x38b803e0,0x00000000,0x00000000}},	//   _ｚｉｐ_, mürü_, --, --, 
   {{0xd1756aa8,0x9f40023a,0x25d801ad,0xd9ac085c}},	// [257a0] тыры, yviä_, गौरी_, _घट्ट, 
   {{0x6fb16aa9,0xaec0230d,0x00000000,0x00000000}},	//   املا, лбул, --, --, 
   {{0x82341f84,0xd2016aaa,0x636001f4,0x00000000}},	//   _سردا, _күрк, löno, --, 
   {{0x25e4813f,0x06300023,0x00000000,0x00000000}},	//   _जननी_, _ኣንድነ, --, --, 
   {{0xd04c03f9,0x4c800131,0x3078010f,0x5f0000cd}},	//   ddaɗ, рғуз, _מאכנ, राद्_, 
   {{0x8c3c06be,0xab240212,0x636000e5,0x00000000}},	//   _beşb, ноча_, zönn, --, 
   {{0x3f816aab,0x8c3d49ab,0x6360005b,0x9f400108}},	//   _huku_, _reşe, yönn, rviä_, 
   {{0x2c54006d,0xdcfd6aac,0x38b805d1,0x2df4011a}},	//   _będą_, _kurč, dürü_, _אצלך_, 
   {{0xdcfd6aad,0x69040882,0x3f816aae,0x8c3d2e16}},	//   _jurč, _jñey, _juku_, _peşe, 
   {{0x3f816aaf,0xf788180f,0xb6c40131,0xef1c000d}},	//   _muku_, _aiçò_, хсий, _ptüi_, 
   {{0x3f816ab0,0x8c3c0139,0x38b803e0,0x25d800bc}},	//   _luku_, _veşe, gürü_, गौली_, 
   {{0xb4a80073,0x8c3c00a2,0x3db000cc,0x00000000}},	//   खणे_, _weşe, _টঙাল, --, 
   {{0x3f816ab1,0x8c3c0ab7,0x78a004c9,0x09281e5a}},	//   _nuku_, _teşe, _ieov, _تسلي_, 
   {{0xc8640014,0xa3c002e5,0x336000d1,0x00000000}},	//   _شان٘, ँढ़_, انسې, --, 
   {{0xb0580793,0x3f800de9,0xf53cce29,0xf09c001e}},	//   _ecäl, _auku_, pnå_, _hoài_, 
   {{0x78a00bed,0x63616ab2,0x5fac0490,0x21782b8e}},	//   _jeov, lönl, _चिखल, ейсы_, 
   {{0x3f80793c,0x64a40063,0x00000000,0x00000000}},	// [257b0] _cuku_, _сања, --, --, 
   {{0x3f800433,0xf0740139,0x63600108,0x2f38007b}},	//   _duku_, _җигә_, nönl, أثرة_, 
   {{0xf09c001e,0xf1a90339,0xdd9401c6,0xd1300066}},	//   _loài_, _عاده_, гахы, _نمد_, 
   {{0x3f816ab3,0x63600065,0xdcfc00d7,0x00000000}},	//   _fuku_, hönl, _furč, --, 
   {{0x3f800421,0xc7b801d3,0x212c0200,0x6360008e}},	//   _guku_, rzők_, ëdhe_, könl, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x78a16ab4,0x3f8001c4,0x6ae000fe,0xc7b800e5}},	//   _beov, _zuku_, পালো, mzői_, 
   {{0x3f816ab5,0x20380020,0xd5b83a71,0xdd5801c6}},	//   _yuku_, _በመቅረ, drā_, _засч_, 
   {{0x2d800427,0xd5b800e2,0x07680075,0x00000000}},	//   _huje_, erā_, маий_, --, 
   {{0x38b80342,0x9a8401c6,0xaa0800db,0x8c3c0205}},	//   türü_, _буцл, _ىزال_, _teşb, 
   {{0x2d816ab6,0x7bc400c7,0xc564024c,0xe848030f}},	//   _juje_, _ãkur, ккок, _کجان_, 
   {{0x78a16ab7,0x33316ab8,0x2d816ab9,0x7e7803b2}},	//   _geov, _amxx_, _muje_, _útpe, 
   {{0x68e8089c,0x290d6aba,0x2d80014f,0xd5b802b5}},	//   _iagd, _ioga_, _luje_, arā_, 
   {{0x68e96abb,0x290d6abc,0xe7302f5e,0x9f400af9}},	//   _hagd, _hoga_, _حصص_, rwië_, 
   {{0x3f816abd,0xf2a08f99,0xdcfc0114,0x2d816abe}},	//   _suku_, рисп, _surč, _nuje_, 
   {{0x3f816abf,0x68e96ac0,0x78a00005,0x441400c7}},	//   _puku_, _jagd, _xeov, _афот, 
   {{0x68e8583c,0x70816ac1,0xf2e4d968,0xf09c01fb}},	// [257c0] _magd, ргуз, رکیه_, _xoài_, 
   {{0x3f8003b4,0x100812b7,0xa0696ac2,0x35a400e1}},	//   _vuku_, رتقى_, даға_, _कौड़, 
   {{0x2d80afc5,0x1b20015b,0x3f8082af,0x290d6ac3}},	//   _cuje_, _বদলে_, _wuku_, _ooga_, 
   {{0x3f816ac4,0x68e81089,0xe9fc0016,0x62880122}},	//   _tuku_, _nagd, _nhằm_, ždod, 
   {{0x3f80123c,0x78a00037,0x00000000,0x00000000}},	//   _uuku_, _reov, --, --, 
   {{0x290c096b,0x60c56ac5,0xf09c004d,0x2d800009}},	//   _aoga_, lgim, _roài_, _fuje_, 
   {{0x290cebf1,0x2d800c09,0x6da16ac6,0x8e640209}},	//   _boga_, _guje_, _виса, _берҗ, 
   {{0x60c56ac7,0x68e80369,0x24800652,0xe9fc004d}},	//   ngim, _cagd, _ngim_, _chằm_, 
   {{0x68e96ac8,0xec104bcf,0x290d6ac9,0x60c4a379}},	//   _dagd, _پولد, _doga_, igim, 
   {{0xd5b80a2b,0xeb941945,0x248002d3,0x2d800223}},	//   trā_, _риф_, _agim_, _yuje_, 
   {{0x290d6aca,0xc9d40517,0x55756acb,0x68e8143a}},	//   _foga_, _مملک, лгот, _fagd, 
   {{0x290d6acc,0x68e80369,0xed840023,0x7864022e}},	//   _goga_, _gagd, _ንነብር_, hаvi, 
   {{0xe72c0502,0xa7a48dc7,0x4ac8013a,0x60c4012d}},	//   صصی_, _акча_, _रामव, dgim, 
   {{0x2d847815,0xb1900075,0x290c022e,0x60c40153}},	//   ínek_, илгә, _zoga_, egim, 
   {{0x68e96acd,0x290d6ace,0x3944143a,0xa5d402dd}},	//   _yagd, _yoga_, _kjos_, _ٴبىر_, 
   {{0x60c40429,0x290c1709,0x2d800223,0x00000000}},	//   ggim, _xoga_, _ruje_, --, 
   {{0x2d8003f9,0xa15804b0,0x8c3c0139,0x7864022e}},	// [257d0] _suje_, тату_, _oeşa, fаvi, 
   {{0x394400cc,0x5f0001ad,0x8c3c00a2,0x60c40200}},	//   _ljos_, राष्_, _neşa, agim, 
   {{0x39456acf,0xc7b801ed,0x4ac80073,0x00000000}},	//   _ojos_, rzői_, _राबव, --, 
   {{0x386401d5,0x6440012d,0x00000000,0x00000000}},	//   _ozor_, źmie, --, --, 
   {{0x290d6ad0,0x2d800223,0x6280012c,0x8c3c03e0}},	//   _roga_, _wuje_, ěmov, _beşa, 
   {{0x2d816ad1,0xe1f0066d,0x68e96ad2,0x290d6ad3}},	//   _tuje_, _اسی_, _sagd, _soga_, 
   {{0x68e96ad4,0x3864007f,0x9f340046,0x39440798}},	//   _pagd, _azor_, _тері, _bjos_, 
   {{0x88e407d8,0x1cdc0327,0xef1c03e0,0x00000000}},	//   ужие, _འིག_, _etüt_, --, 
   {{0x290d6ad5,0x6ec4142d,0x248001a9,0x9b8800ae}},	//   _voga_, ालपु, _rgim_, _لنقل_, 
   {{0x06096ad6,0x386402fa,0x290c8b3b,0x60c5398f}},	//   енок_, _dzor_, _woga_, zgim, 
   {{0x68e96ad7,0x00000000,0x00000000,0x00000000}},	//   _tagd, --, --, --, 
   {{0xdcfc00da,0x290cf2ce,0x941803e3,0x00000000}},	//   _kurā, _uoga_, lasə_, --, 
   {{0x9f401c69,0x60c4cddc,0x8c3c06be,0xd7c80f2b}},	//   rviú_, vgim, _yeşa, _لونه_, 
   {{0xd05c01e4,0x6d90025c,0xd1f8001f,0xb3380213}},	//   _insɨ, _iħaf, ወጣት_, ksçu, 
   {{0x60c404cc,0x00000000,0x00000000,0x00000000}},	//   tgim, --, --, --, 
   {{0xdbe00248,0x00000000,0x00000000,0x00000000}},	//   _sìíp, --, --, --, 
   {{0x80651299,0xdb1402d1,0x6d90025c,0xd04c01e4}},	// [257e0] уваж, _ñaçh, _jħaf, ndaɨ, 
   {{0x60c4026c,0x1cdc031c,0x6d90031c,0x2cdc0327}},	//   sgim, _འིང_, _mħaf, ོབའབ, 
   {{0x814401d9,0x8c3c0bbc,0x7374011a,0x8f7400d4}},	//   _مندن, _reşa, _תגיד_, руті, 
   {{0xb4d807de,0x6da0a641,0xdcfc00de,0x7b300210}},	//   hnàn, сица, _burā, płuk, 
   {{0x6bd025aa,0x6d90031c,0x8c3c399d,0x614400db}},	//   متور, _nħaf, _peşa, _مىگە, 
   {{0xbda412dd,0x58fc0135,0x0ba80131,0xdcfc00dc}},	//   _محرو, _ཐོངས_, ئانى_, _durā, 
   {{0xe6056ad8,0xaa540063,0x63a80210,0x78a40162}},	//   _اش_, лишу_, ądny, ðkvo, 
   {{0x629c02c1,0x57b41d4a,0xd910315b,0xa3e4482a}},	//   hbro, абит, غیش_, नबा_, 
   {{0x629d6ad9,0xdcfc00b8,0x888000d1,0x00980150}},	//   kbro, _gurā, әғәл, _ﺘﺘﺤﻤ_, 
   {{0x38640122,0xb4d8354d,0xd05c06be,0x8c3c25a8}},	//   _vzor_, gnàn, _casə, _keşn, 
   {{0x69c40022,0x00000000,0x00000000,0x00000000}},	//   _ãjep, --, --, --, 
   {{0x629c0b4f,0xdc3400d7,0x6360032e,0x00000000}},	//   ebro, _lúčm, bönk, --, 
   {{0x7bc16ada,0x386404a7,0x6d90025c,0xb794026a}},	//   nuou, _uzor_, _għaf, _срећ, 
   {{0x56956adb,0x629d6adc,0xb9280208,0x00000000}},	//   _такт, gbro, _nhuế_, --, 
   {{0xc7640075,0x31680063,0xe704136e,0xca340023}},	//   _ئانى, ешао_, _حسنی, _እንተሎ, 
   {{0xa1843c43,0x636003fa,0x629cf1b6,0xa158009b}},	//   сырл, hönh, abro, гасу_, 
   {{0x629c78d6,0x5f940137,0xd05c03b9,0x6d40908e}},	// [257f0] bbro, йитт, _yasə, énam, 
   {{0x7bc125cd,0xdcfc0055,0x629c01ef,0x00000000}},	//   duou, _rurā, cbro, --, 
   {{0xdfd4005e,0xb64400b5,0xdcfc00dc,0x00000000}},	//   _қоры, _ｋｎ_, _surā, --, 
   {{0xdcfc0882,0x6b9c02d3,0x477400b8,0xa638010f}},	//   _purā, _ዝተረፈ_, _mātṛ_, עגאר, 
   {{0xab600131,0x300401d9,0x00000000,0x00000000}},	//   مۇرى, _صبحُ, --, --, 
   {{0x39880241,0xaf8401ee,0xfe9c0241,0xc9b400d8}},	//   _bùs_, _аҡҡа_, _ẹ̀pà_, асињ, 
   {{0xdd940598,0x398801ab,0xa038001f,0xdef8699d}},	//   _гасы, _cùs_, _በመነሳ, _сыя_, 
   {{0x7e78000f,0xef1c0254,0xdcfc1619,0x00000000}},	//   _útpa, _ttüs_, _turā, --, 
   {{0x7bc13d71,0x6d596add,0x60380166,0xca340092}},	//   cuou, _ikua, _işmö, _እንዲሄ, 
   {{0xb4d805d5,0x629c01e3,0x071401f0,0x00000000}},	//   unàn, xbro, рфия, --, 
   {{0xb4d96ade,0xd5b8005f,0x629c07b9,0x79e80a81}},	//   rnàn, dzās_, vbro, _لولہ_, 
   {{0x69c16adf,0x6d900135,0xd5b800de,0x45351697}},	//   mune, _iħad, ezās_, рхот, 
   {{0x63600267,0x291c009f,0xc7a422bf,0x86c43090}},	//   löni, mkua_, _тилк, _نيشن, 
   {{0x69c004c4,0x291c0992,0x6d900327,0x00000000}},	//   oune, lkua_, _għag, --, 
   {{0x69c16ae0,0x6d596ae1,0x6d900135,0x291c01f7}},	//   nune, _okua, _jħad, okua_, 
   {{0x6d580211,0x291d6ae2,0x6d90025c,0xe9fc004d}},	//   _nkua, nkua_, _mħad, _giấm_, 
  
   {{0x291c005a,0x932411e6,0xe5a001b9,0x48dc00af}},	// [25800] ikua_, _گرين, _тиқи, _कउनो_, 
   {{0x6d596ae3,0x63a56ae4,0x63600112,0x291cba5d}},	//   _akua, _iwin, köni, hkua_, 
   {{0x291d5158,0x69c16ae5,0x63a4006f,0x0490002b}},	//   kkua_, june, _hwin, _bāḍh, 
   {{0x63a56ae6,0x69c16ae7,0x7bc16ae8,0x8c3c3119}},	//   _kwin, dune, tuou, _veşn, 
   {{0xd05c043b,0xb9280016,0x63a4007f,0x69c0017a}},	//   _masɛ, _thuế_, _jwin, eune, 
   {{0x63a56ae9,0x69c082c6,0x6d580588,0x7bc16aea}},	//   _mwin, fune, _ekua, ruou, 
   {{0x69c16aeb,0x63a4009a,0xdcfc0276,0x6e400408}},	//   gune, _lwin, _cură, _дерз, 
   {{0x21200219,0x049000cd,0x63a45337,0x8c3c03b9}},	//   nkih_, _gāḍh, _owin, _keşl, 
   {{0x69c16aec,0x63a40564,0x28d4000d,0x00000000}},	//   aune, _nwin, _भउरि, --, 
   {{0x291c0069,0x21216aed,0x398808c2,0x8c3c0139}},	//   akua_, hkih_, _tùs_, _meşl, 
   {{0x69c16aee,0x6d90038f,0x63a56aef,0xd05c0085}},	//   cune, _għad, _awin, _basɛ, 
   {{0x63a41813,0xe98400d1,0xd5b000e5,0x00000000}},	//   _bwin, _ئالۋ, _ہفت_, --, 
   {{0xd7940597,0x63a406f2,0x212009a8,0x59b003ce}},	//   _التخ, _cwin, dkih_, ींकर, 
   {{0x63a56af0,0xe7353291,0x675000f1,0x00000000}},	//   _dwin, _кеч_, _وخور, --, 
   {{0x63a56af1,0x30a56af2,0x6360002f,0x00000000}},	//   _ewin, ирав, hönw, --, 
   {{0xa5080640,0x8c3c4e7e,0x644803e0,0x00000000}},	//   _већа_, _beşl, ğdir, --, 
   {{0x64496af3,0x63a56af4,0x69c005f5,0x533401ec}},	// [25810] şdir, _gwin, zune, _гепт, 
   {{0x6d58069d,0x44440014,0x8c3c00a2,0x291c01c4}},	//   _skua, _در٘ہ, _deşl, zkua_, 
   {{0x2d856af5,0x63a40dc9,0xf09c0086,0x237400db}},	//   êne_, _zwin, _anàe_, _بايح, 
   {{0x21200b91,0x69c16af6,0xd010011d,0xd9cc0154}},	//   ckih_, vune, _فلج_, লবাম, 
   {{0x4c9407d6,0x69c16af7,0xe3149c1d,0x00000000}},	//   _ҳибс, wune, _طبیب, --, 
   {{0xce5801c0,0x636005d5,0xfaa00117,0x00000000}},	//   _багц_, töni, пашо, --, 
   {{0x291d6af8,0x69c020ac,0x4c942b2e,0x00000000}},	//   tkua_, uune, _гибс, --, 
   {{0x6d583209,0x090423c3,0x291c0140,0x63600267}},	//   _ukua, спин, ukua_, röni, 
   {{0x69c16af9,0xb4d8521d,0x291d6afa,0x9b940212}},	//   sune, gnàm, rkua_, _митц, 
   {{0x69c16afb,0x291d6afc,0x63a56afd,0x6d900135}},	//   pune, skua_, _rwin, _iħab, 
   {{0x291c0357,0x273c0020,0x69c00869,0x63a55679}},	//   pkua_, _ይኖርበ, qune, _swin, 
   {{0x63a407ab,0x497400a7,0xda08027d,0xfe34011a}},	//   _pwin, _улес, _خيمه_, מרתי_, 
   {{0x8c3c0724,0x21200219,0x6d900135,0xd7880208}},	//   _oeşm, vkih_, _jħab, _hển_, 
   {{0x6d900135,0x49040133,0x42e80022,0xfc5800df}},	//   _mħab, _خوڵق, ымго_, רכשמ, 
   {{0x21200f72,0x412805c5,0xe81c0ebb,0x82a401ec}},	//   tkih_, гово_, यनका_, _қанж, 
   {{0x58fc025c,0xc7640131,0x8c3c294f,0x15b92c72}},	//   _ཐོབས_, _ئاچى, _peşl, _тышы_, 
   {{0x21200429,0x63a56afe,0x6d90031c,0x8c3c03b9}},	// [25820] rkih_, _uwin, _nħab, _beşm, 
   {{0xbea8034c,0xbda42824,0x82340123,0x00000000}},	//   اهان_, محصو, _هرجا, --, 
   {{0x212009a8,0x8c3c0139,0x00000000,0x00000000}},	//   pkih_, _deşm, --, --, 
   {{0xbc6804fb,0xfc280209,0x8c3c013d,0x3658010f}},	//   همان_, лжек_, _teşl, אכענ, 
   {{0x50b400aa,0xdcfc00e2,0x8c3c03e0,0x00000000}},	//   _بشپړ, _strē, _feşm, --, 
   {{0x79a56aff,0xeaac73c5,0x8c3c00a2,0xd7880051}},	//   брие, ىعى_, _geşm, _bển_, 
   {{0xeaac0228,0x3ea80077,0xb93402d3,0x00000000}},	//   رعو_, _iebt_, _ክህልዎ, --, 
   {{0x3ea80460,0x3b856b00,0xee3537d6,0x5f0000dc}},	//   _hebt_, _глаг, _унс_, राक्_, 
   {{0xbb840acb,0x6d90031c,0xad1808c3,0x00000000}},	//   _طلاي, _għab, _עומר, --, 
   {{0x95d803b7,0x00000000,0x00000000,0x00000000}},	//   адот_, --, --, --, 
   {{0x9f4004cf,0x2f580bd9,0xab742a9f,0x3f14031c}},	//   lvió_, רדינ, _املا_, ྷྰརྠ_, 
   {{0x3ea803fa,0x3ce401a6,0x77c80d4b,0x555802d5}},	//   _lebt_, neov_, _букв_, рамя_, 
   {{0x6d40004a,0xf9e82b1b,0x1cdc031c,0xa8780408}},	//   énai, _কপিল_, _འིན_, _йышĕ_, 
   {{0xb460001f,0x79800076,0xa29400d4,0x00000000}},	//   _ማድረጉ, _hiow, зарі, --, 
   {{0x79816b01,0x667010de,0xc6d40395,0x00000000}},	//   _kiow, _ىدىر, _фючъ, --, 
   {{0x63600793,0x90996b02,0xe004000d,0xf9e800eb}},	//   dönu, рват_, रमंद_, _কপাল_, 
   {{0x79800428,0x162001ad,0x8c3c0213,0x3ce40427}},	// [25830] _miow, मनकर_, _peşm, deov_, 
   {{0x91c40131,0xf41c0958,0x00000000,0x00000000}},	//   _мәбл, myä_, --, --, 
   {{0xf41c02f6,0x7e780b21,0x3ea82517,0x6360023a}},	//   lyä_, _útpl, _debt_, tönv, 
   {{0xb144036b,0x00000000,0x00000000,0x00000000}},	//   _ایرم_, --, --, --, 
   {{0x0c74521f,0xf41c0139,0x00000000,0x00000000}},	//   زگرد, ccät_, --, --, 
   {{0xa720045e,0x499408b7,0x2d8401ed,0x3ea80e78}},	//   _পদ্ম_, ошит, ínes_, _gebt_, 
   {{0x7bc4168c,0x8c3c05d1,0x9f40004e,0x00000000}},	//   _åkun, _keşk, avió_, --, 
   {{0xf41c023a,0x7c80001f,0x638001e1,0x6d900135}},	//   kyä_, ንድሮው_, _kánì, _tħab, 
   {{0x7980034c,0xf53c0589,0xf41c02f6,0x7b300210}},	//   _diow, diå_, jyä_, głus, 
   {{0x2caca249,0x5bc4036b,0x478800db,0x00000000}},	//   lagd_, _رقمل, лсүм_, --, 
   {{0x9a84152d,0x638001e1,0x8c3c008e,0xe6380023}},	//   _хуул, _lánì, _oeşk, _ኣንጸላ, 
   {{0xd87407d6,0x636007c5,0xfc480306,0xf990011a}},	//   _کامب, hönt, šíš_, _חרא_, 
   {{0x2b0007f7,0xf80800db,0xd4c00022,0x00000000}},	//   लाऊँ_, _ەرۉۉ_, хҩык, --, 
   {{0x2c1400cc,0x00000000,0x00000000,0x00000000}},	//   _দেৱে_, --, --, --, 
   {{0xf53c0589,0x79816b03,0xdddc0010,0x636001d3}},	//   biå_, _yiow, _ogrš, dönt, 
   {{0xf53c0589,0x0444010b,0x2cac0112,0x05747b7a}},	//   ciå_, _мейн, jagd_, _باتد, 
   {{0x78a40413,0x00000000,0x00000000,0x00000000}},	// [25840] ðkvi, --, --, --, 
   {{0xe6b41092,0xfe44188b,0x638001e1,0xf41001ed}},	//   _आयोज, онзо, _dánì, _آؤٹ_, 
   {{0xfde96b04,0xc0580150,0x00000000,0x00000000}},	//   рдек_, уің_, --, --, 
   {{0xbc640b3b,0xec1000f1,0x00000000,0x00000000}},	//   овек, ژوند, --, --, 
   {{0xed4c01ed,0x8f98011c,0x00000000,0x00000000}},	//   ڑھے_, _гъст_, --, --, 
   {{0x8c3c37be,0x9f402760,0x6360c9df,0x00200023}},	//   _meşh, rvió_, möns, ተኾይኖ, 
   {{0x9f400789,0x8eb0129d,0x6e900066,0xcdc40150}},	//   svió_, _سەنت, _آلفا, _нарқ, 
   {{0xed556b05,0x7b30012d,0x6e2001bf,0x00000000}},	//   _дос_, tłus, ønbe, --, 
   {{0xeb95116b,0x1b0401c0,0xbb441c7b,0x9f40030a}},	//   _мит_, _нүдн, _деак, lviñ_, 
   {{0xf41c023a,0x96342077,0x7bc00076,0x36886bce}},	//   vyä_, зноц, mrou, шсин_, 
   {{0xeb301ee2,0x63600730,0x988400ee,0x7b30012d}},	//   _تىلد, höns, _екеҗ, słus, 
   {{0xf41c02f6,0x799802d0,0x7bc0045a,0x63616b06}},	//   tyä_, _ittw, orou, köns, 
   {{0x7bc00489,0x63608573,0x998c00a2,0x00000000}},	//   nrou, yönt, _şoňo_, --, 
   {{0xa3dc0cf1,0xf1a441e5,0x2b002982,0xf41c01f4}},	//   _ठहर_, жран, लाएँ_, ryä_, 
   {{0xf41c02f6,0xb4d8026c,0x8c3c5656,0x41840150}},	//   syä_, riàb, _peşk, зтуғ, 
   {{0x7bc16b07,0x63600267,0xf41c005b,0x00000000}},	//   krou, föns, pyä_, --, 
   {{0x6360023a,0xb284084c,0x2584007f,0xe9fc0051}},	// [25850] tönt, _мынк, sèlè_, _phẫm_, 
   {{0x7bc05e52,0x6e650bf0,0x799802d0,0x9f440241}},	//   drou, отеж, _ottw, _èmì_, 
   {{0x8c3d6b08,0x2cac0d27,0x7bc08e64,0x6360007c}},	//   _ieşi, tagd_, erou, rönt, 
   {{0x7bc16b09,0x636002d2,0x00000000,0x00000000}},	//   frou, böns, --, --, 
   {{0x7bc16b0a,0x7998003d,0x8c3c1ae4,0xe9fc0208}},	//   grou, _attw, _keşi, _thẫm_, 
   {{0xbf14004b,0x2cac007c,0x00000000,0x00000000}},	//   _فوټب, sagd_, --, --, 
   {{0x9f4006ea,0x7bc00156,0xb4d801ab,0x0684010b}},	//   mvið_, arou, anài, үгин, 
   {{0x7bc16b0b,0x8c3c054e,0xc8780356,0x9f4006ea}},	//   brou, _leşi, leşi_, lvið_, 
   {{0xd90c0502,0x6d4851b0,0x79981418,0xf77001ed}},	//   شیو_, mnga, _ettw, کاٹ_, 
   {{0x6d496b0c,0x6b996b0d,0x8c3c0209,0xc8780274}},	//   lnga, _itug, _neşi, neşi_, 
   {{0x6d496b0e,0x636001ed,0x00000000,0x00000000}},	//   onga, zöns, --, --, 
   {{0x6d496b0f,0x497400f7,0xe9fc0208,0x00000000}},	//   nnga, _элес, _nhẩm_, --, 
   {{0x69c0070d,0x8c3c4953,0xa5080131,0xd7880208}},	//   lrne, _beşi, مىگە_, _yểm_, 
   {{0x69c00af5,0x6d496b10,0x8c3c0205,0x20dc002b}},	//   orne, hnga, _ceşi, _ṭi_, 
   {{0x6d496b11,0x8c3d23f5,0x7bc0030a,0x11d40006}},	//   knga, _deşi, zrou, мітр, 
   {{0x6d496b12,0x69c16b13,0x6b08025c,0x6b996b14}},	//   jnga, irne, _ཁོའོ_, _otug, 
   {{0x6d480c67,0x6b984f5b,0x69c16b15,0x48dd2877}},	// [25860] dnga, _ntug, hrne, क्यो_, 
   {{0x7bc16b16,0x44216b17,0x6d496b18,0xef140075}},	//   vrou, myk_, enga, пму_, 
   {{0x44216b19,0x6b996b1a,0x9f400165,0x9f440248}},	//   lyk_, _atug, uviñ_, _èmí_, 
   {{0x7bc16b1b,0x6d496b1c,0x69c400e4,0x9f4005c7}},	//   trou, gnga, _ãjey, rviñ_, 
   {{0x69c00eda,0x8c3c0365,0x7bc16b1d,0x44216b1e}},	//   erne, _yeşi, urou, nyk_, 
   {{0x6d496b1f,0x6b980597,0x79a52662,0xf7e82ba5}},	//   anga, _dtug, прие, ەردى_, 
   {{0x6d496b20,0x6b981418,0x229c01f2,0x999800d1}},	//   bnga, _etug, ụkwu_, زھار_, 
   {{0x7bc134cf,0x44216b21,0x6d4006af,0x81bc0154}},	//   prou, kyk_, énat, _ইহা_, 
   {{0x69c032ff,0x442000ee,0xdcfc0153,0x58380395}},	//   arne, jyk_, _strė, юзия_, 
   {{0x44216b22,0x69c16b23,0x1de000e1,0x7f5c0175}},	//   dyk_, brne, _नहात, nopq, 
   {{0x7c205062,0x8c3d6b24,0x7ae80bcd,0x69c000f3}},	//   lyor, _reşi, meft, crne, 
   {{0x6b98013f,0x7ae96b25,0x4420000f,0x7f5c014f}},	//   _ytug, left, fyk_, hopq, 
   {{0x7c201cbd,0x8c3c0365,0x674401d3,0x9f4006ea}},	//   nyor, _peşi, _کرنے, yvið_, 
   {{0x7ae96b26,0x6d480007,0x7f5c0200,0xa7700064}},	//   neft, znga, jopq, _зліч, 
   {{0xe9fc01dc,0x6d4800a9,0x26d80375,0xfe9c01e1}},	//   _phẩm_, ynga, _הקומ, _ẹ̀yà_, 
   {{0x7ae8fcf4,0x216402dd,0x7c200083,0x00000000}},	//   heft, етуг, kyor, --, 
   {{0x7ae80548,0x20540276,0xa05402dd,0x4420012d}},	// [25870] keft, ектя, евті, cyk_, 
   {{0x7ae96b27,0x6d496b28,0x69c16b29,0x8c3c06be}},	//   jeft, wnga, yrne, _ueşi, 
   {{0x6d496b2a,0x9f400579,0xe9fc0016,0x6b996b2b}},	//   tnga, rvið_, _thẩm_, _stug, 
   {{0x6d496b2c,0x9f400008,0x69c00b3d,0xb0580166}},	//   unga, svið_, vrne, _ndäg, 
   {{0x6d903aaf,0x6d496b2d,0x7ae8003a,0x6b980135}},	//   _għan, rnga, feft, _qtug, 
   {{0x69c045a7,0x7ae804ce,0xaca00ca8,0x09e41f5a}},	//   trne, geft, _inọn, докн, 
   {{0x442108a1,0x254801ed,0x69c16b2e,0x6d496b2f}},	//   zyk_, lőle_, urne, pnga, 
   {{0x7c216b30,0x69c12fde,0x7b30033f,0x6b980332}},	//   byor, rrne, słup, _ttug, 
   {{0x6b980796,0xf8ac036b,0x7c200223,0x1ae800eb}},	//   _utug, شکن_, cyor, পাড়া, 
   {{0x9bf40598,0x69c00010,0x442002f0,0xc76411dc}},	//   _язуч, prne, vyk_, باعى, 
   {{0x4420ed06,0x69c00194,0x690402d5,0x996400c7}},	//   wyk_, qrne, _нядз, ьтәл, 
   {{0x44216b31,0x04440395,0x98a4013d,0x00000000}},	//   tyk_, демн, bomı_, --, 
   {{0xe9fc0051,0x00000000,0x00000000,0x00000000}},	//   _khắm_, --, --, --, 
   {{0x44216b32,0x420800f7,0x9f4001f4,0x00000000}},	//   ryk_, онго_, lviö_, --, 
   {{0xaca0063f,0xb144001f,0x44216b33,0x6d900135}},	//   _anọn, _ፕሬዝዳ, syk_, _sħan, 
   {{0x7c20006c,0x44205443,0xb4d804cc,0x00000000}},	//   yyor, pyk_, liàn, --, 
   {{0x65656b34,0x74106cb9,0x00000000,0x00000000}},	// [25880] _ikih, _لويا, --, --, 
   {{0x7c204532,0xe9fc01fb,0x48dc0882,0xb4d80109}},	//   vyor, _nhắm_, क्तो_, niàn, 
   {{0x7c2068c8,0xb4d8004e,0xc10400e5,0x00000000}},	//   wyor, rnàv, _ہوگي, --, 
   {{0x7c216b35,0x6d900003,0x6da00640,0x7ae8000f}},	//   tyor, _iħal, тица, weft, 
   {{0x6bd1020c,0x8c3c008e,0x28d400af,0x00000000}},	//   نتور, _oeşu, _भउजि, --, 
   {{0x6d4007ea,0x7c200585,0x386402f0,0x7f5c0455}},	//   énar, ryor, _ryor_, qopq, 
   {{0x7ae96b36,0x7c216b37,0x656400b0,0x38642a1f}},	//   reft, syor, _okih, _syor_, 
   {{0xb1440020,0x65656b38,0x777801d4,0x7ae96b39}},	//   _ፕሬዚዳ, _nkih, wmtx, seft, 
   {{0x8c3c06be,0x7ae868f1,0x00000000,0x00000000}},	//   _beşu, peft, --, --, 
   {{0x65656b3a,0xb4d805d5,0xec74011c,0x00000000}},	//   _akih, giàn, _цпу_, --, 
   {{0x6d90025c,0x00000000,0x00000000,0x00000000}},	//   _nħal, --, --, --, 
   {{0xfe9c01e1,0x00000000,0x00000000,0x00000000}},	//   _ẹ̀fà_, --, --, --, 
   {{0xbb1806ba,0x5bdc0cf1,0xdee8069d,0x00000000}},	//   ﺴﻼﻡ_, _यहोव, መንና_, --, 
   {{0x6d901f21,0x65640337,0x8c3c05d1,0xe3b00133}},	//   _bħal, _ekih, _teşv, گرێ_, 
   {{0x66e01fbe,0xa29412fa,0x676001c8,0x00000000}},	//   _роја, тасі, _جُول, --, 
   {{0x6d90025c,0xe3b16b3b,0xb7f01cd2,0x00000000}},	//   _dħal, درێ_, _अनाम_, --, 
   {{0xa184abba,0x8c3c06be,0x00000000,0x00000000}},	// [25890] тырл, _yeşu, --, --, 
   {{0x8c3c0311,0x00000000,0x00000000,0x00000000}},	//   _meşt, --, --, --, 
   {{0x6d903aaf,0xf3fc0004,0x8c3c1ea0,0x00000000}},	//   _għal, lvã_, _leşt, --, 
   {{0x8fbc0597,0x8c3c0598,0xb4d8b497,0x3d1c0142}},	//   _ɦօʊɖ, _oeşt, mnàs, _sïwr_, 
   {{0x4098008d,0x6d900327,0x8c3c19b2,0x00000000}},	//   _מברס, _iħam, _neşt, --, 
   {{0xd5b800da,0x09f4011c,0x00000000,0x00000000}},	//   ksā_, ечия, --, --, 
   {{0xb4d8004e,0x09e43802,0x9f54010a,0x00000000}},	//   nnàs, хойн, _шĕшк, --, 
   {{0x3d040490,0x9614009e,0x6d90031c,0xca60022e}},	//   _सोपे_, ানাম_, _jħam, _dolа, 
   {{0x2cbc003e,0xe9fc01fb,0x8c3c0356,0x9f400108}},	//   _idud_, _thắm_, _ceşt, rviö_, 
   {{0x8c3c0311,0x00000000,0x00000000,0x00000000}},	//   _deşt, --, --, --, 
   {{0xb4d8354d,0xccf800dc,0x00000000,0x00000000}},	//   riàn, _kaś_, --, --, 
   {{0xa6a4015b,0xd9b00131,0x59d4012d,0xccf80210}},	//   _খাওয়, _ئەيد, _धमतर, _jaś_, 
   {{0xdcfc0a2b,0x68f96b3c,0x2ee00158,0xb4d8004e}},	//   _strī, mdud, _objf_, miàl, 
   {{0x3d041f5e,0x68f96b3d,0x00000000,0x00000000}},	//   _सोने_, ldud, --, --, 
   {{0xc0e46be6,0xc7b800dd,0xb6f4215c,0xbea40022}},	//   новк, lső_, _سىيا_, ҵазк, 
   {{0x65656b3e,0xdcfc010f,0xfe70167e,0x2cbc003e}},	//   _ukih, _burĝ, ۇدا_, _ndud_, 
   {{0xb0580139,0x8fd42cc8,0x66000118,0x3ea40022}},	// [258a0] _adäb, кәрә, _hrnk, еизг, 
   {{0x2cbc003e,0x68f800ac,0xe8dc01f2,0x6d90025c}},	//   _adud_, hdud, diọn_, _iħaj, 
   {{0x4ac8f5d8,0xf1bc0419,0x00000000,0x00000000}},	//   _राजव, ýšte_, --, --, 
   {{0x6d90038f,0xe9fc001e,0xee3405f5,0xed556b3f}},	//   _għam, _chậm_, энх_, нох_, 
   {{0x6d900327,0xb4d84b84,0x7b640137,0x68f8ea28}},	//   _jħaj, onàr, нтке, ddud, 
   {{0xd24c0014,0x45140eac,0x6d900327,0x660002d0}},	//   _اۆہ_, াসিক_, _mħaj, _ornk, 
   {{0xaab401d5,0x20016b40,0x19580588,0x00000000}},	//   ردور_, lvii_, макы_, --, 
   {{0x68f81ff6,0x3f896b41,0x8c3d6b42,0x64480213}},	//   gdud, _hibu_, _peşt, şdiy, 
   {{0x0ba804a9,0x2000011c,0x3f880548,0x3d0400e1}},	//   _ياكى_, nvii_, _kibu_, _सोये_, 
   {{0x3f8805d9,0x68f96b43,0xccf80034,0x8c3c3119}},	//   _jibu_, adud, _zaś_, _veşt, 
   {{0x3f896b44,0x66000d0f,0xb4b000d1,0x72800023}},	//   _mibu_, _crnk, линә, ናዕታዊ_, 
   {{0x7af8feaf,0x3f88ca60,0xd5b8005f,0x7e78002d}},	//   _hatt, _libu_, rsā_, _útpu, 
   {{0x66000a73,0x7468b93d,0x6d900327,0xc7b801d3}},	//   _ernk, яров_, _rħam, cső_, 
   {{0x7af96b45,0x66000334,0x60980014,0x00000000}},	//   _jatt, _frnk, ہنِس_, --, 
   {{0x4ac8bc82,0x659000ee,0x2000003a,0x3d0400af}},	//   _राघव, _йащу, evii_, _सोभे_, 
   {{0x3f896b46,0xe2141411,0x7af96b47,0x70c80490}},	//   _aibu_, ымсы, _latt, िलेल, 
   {{0x6d90038f,0x3f880241,0x66000306,0xe9fc004d}},	// [258b0] _għaj, _bibu_, _zrnk, _khảm_, 
   {{0x3f880268,0xf7cc2d40,0xa854011a,0x6e2001bf}},	//   _cibu_, _ﻛﻪﻟﺪ, תימה_, ønbo, 
   {{0x22640122,0x20013635,0x3f880014,0x68f8011f}},	//   čské_, avii_, _dibu_, ydud, 
   {{0x7af96b48,0x30a4bafa,0x00000000,0x00000000}},	//   _aatt, _яров, --, --, 
   {{0x7af96b49,0x2000003a,0xdd9401e0,0x00000000}},	//   _batt, cvii_, _ҡары, --, 
   {{0x2900005f,0x5f840131,0x7af96b4a,0x6d90031c}},	//   ējam_, _مۇقە, _catt, _jħak, 
   {{0x7af96b4b,0x58a8045e,0x62880063,0xe9fc001e}},	//   _datt, _গাড়ী, ždov, _thậm_, 
   {{0x29080882,0x2cbc551a,0x7af8127b,0x7d14023a}},	//   ñca_, _udud_, _eatt, öyst, 
   {{0x7af96b4c,0x3a7051a3,0x68f96b4d,0x290806b9}},	//   _fatt, лләр, rdud, ıca_, 
   {{0x7af96b4e,0x27fd6b4f,0x68f80327,0xb7440026}},	//   _gatt, rvun_, sdud, кпыз_, 
   {{0xa9c4872b,0xe9a803e6,0x27fc005b,0x8c3c0166}},	//   _سزاو, _ردان_, svun_, _teşs, 
   {{0x2b456b50,0xc7b801d3,0x83c81884,0x00000000}},	//   linc_, pső_, _ﺑﻪﺭﺳ, --, 
   {{0x7af96b51,0x200016b8,0x58b800cf,0xda700014}},	//   _yatt, xvii_, _سانج_, _نُے_, 
   {{0x2000011c,0x7af96b52,0x660012fe,0x48dc276a}},	//   vvii_, _xatt, _trnk, क्रो_, 
   {{0x3f896b53,0xb4d8004e,0xdcfc013d,0x660003ac}},	//   _ribu_, rnàr, _nurğ, _urnk, 
   {{0x3f88e88c,0x2b4416b8,0x6d90031c,0xf9900115}},	//   _sibu_, hinc_, _tħaj, שרן_, 
   {{0xf8b004ac,0x54a400c6,0xd1740220,0x00000000}},	// [258c0] ישן_, _صحيف, уыры, --, 
   {{0x6d90031c,0xafe0300e,0x20016b54,0x42240b01}},	//   _għak, рофл, rvii_, _адов, 
   {{0xb6053a9e,0x4254147e,0x2b440072,0x3f88000d}},	//   _ibáñ, _штит, dinc_, _vibu_, 
   {{0x7af96b55,0x629d6b56,0x24b003d4,0xdcfc03e3}},	//   _satt, lcro, _কাঁহ, _durğ, 
   {{0x7af96b57,0x3f896b58,0x8c3c06be,0x21ec01e1}},	//   _patt, _tibu_, _beşq, bòhò_, 
   {{0x7af96b59,0x2b456b5a,0xd7880208,0x00000000}},	//   _qatt, ginc_, _yểu_, --, 
   {{0x7af80628,0x629c0175,0x00000000,0x00000000}},	//   _vatt, icro, --, --, 
   {{0x7af96b5b,0xf804023a,0x2b440042,0x629d6b5c}},	//   _watt, вчон, ainc_, hcro, 
   {{0x56944478,0x3b84035b,0x7af96b5d,0x0d64005b}},	//   лапт, _алаг, _tatt, _съём, 
   {{0x7af80140,0x3d040412,0x8c3c03e0,0xdcfc0166}},	//   _uatt, _सोते_, _teşr, _yurğ, 
   {{0x29d023bb,0x00000000,0x00000000,0x00000000}},	//   _نيلس, --, --, --, 
   {{0x77905533,0xf5242678,0x8c3c0432,0x00000000}},	//   _پیدا, тфон, _keşp, --, 
   {{0xe9fc001e,0x9abc0327,0xc1a402dd,0xf6080133}},	//   _thảm_, _eoċe, ғысқ, ستگه_, 
   {{0x70c8038e,0x9abc0327,0x629d39fd,0x00000000}},	//   िल्ल, _foċe, gcro, --, 
   {{0xddd4010e,0x00000000,0x00000000,0x00000000}},	//   _çaňl, --, --, --, 
   {{0x2b441d46,0x629c02d0,0x00000000,0x00000000}},	//   zinc_, acro, --, --, 
   {{0x629c0421,0x6d900327,0xdcfc0166,0x3d0400bc}},	// [258d0] bcro, _tħak, _surğ, _सोधे_, 
   {{0x629c06af,0x561400cc,0x00000000,0x00000000}},	//   ccro, ানীক_, --, --, 
   {{0xd74402d3,0x2b456b5e,0xe8dc01fb,0xdcfc00ac}},	//   _ንእስነ, vinc_, hiền_, _qurğ, 
   {{0xdcfc03be,0x9e040137,0x2b440076,0x0c7836e1}},	//   _vurğ, шчул, winc_, нслы_, 
   {{0xf09c01e1,0x613808ce,0x2b44003a,0x00000000}},	//   _ifà_, _bílf, tinc_, --, 
   {{0xdcfc0139,0x00000000,0x00000000,0x00000000}},	//   _turğ, --, --, --, 
   {{0x2b44d11c,0x795c0142,0xdea40345,0x00000000}},	//   rinc_, lëwy, _ئیمی, --, 
   {{0xe9fc001e,0x00000000,0x00000000,0x00000000}},	//   _chạm_, --, --, --, 
   {{0x629c48bb,0x7e792673,0x00000000,0x00000000}},	//   ycro, _útpr, --, --, 
   {{0xa5080075,0x03a41cd1,0x00000000,0x00000000}},	//   چىدە_, һимо, --, --, 
   {{0xf09c0241,0xa50800d1,0x00000000,0x00000000}},	//   _ofà_, نىدە_, --, --, 
   {{0xaadc2c82,0x03a48e5a,0x629d6b5f,0x00000000}},	//   प्रक, лимо, wcro, --, 
   {{0x290d6b60,0x629d6b61,0x7bc403cd,0x6fe400de}},	//   _inga_, tcro, _åkut, nīcā, 
   {{0xf09c026c,0x3330003a,0x629c06af,0xb84c02f0}},	//   _afà_, _clxx_, ucro, šťák, 
   {{0x6d90031c,0xb6d000db,0xe2d80014,0x00000000}},	//   _iħaw, _اقىع, _یادچ_, --, 
   {{0x6d900327,0x26f16b62,0x00000000,0x00000000}},	//   _għai, _असुर_, --, --, 
   {{0xf554007b,0x4f94009d,0xf47401ec,0x00000000}},	// [258e0] _حليب_, арху, _бөрі_, --, 
   {{0x63a56b63,0x6d900327,0x5ec4035f,0x70800107}},	//   _itin, _jħaw, рижғ, сгуз, 
   {{0x290d6b64,0x6360006a,0xafe00220,0x3b841945}},	//   _onga_, könz, _қорл, ңлег, 
   {{0x5aec0489,0x290c409c,0xac94034c,0x72180375}},	//   _རིངམ, _nnga_, هنما_, _נוכח, 
   {{0x77f00d79,0x26f0069f,0x63a4031c,0xac056b65}},	//   _अनेक_, _असूर_, _jtin, лнца_, 
   {{0x290d6b66,0x63a40451,0xc18002e3,0x6d90031c}},	//   _anga_, _mtin, _ọghọ, _nħaw, 
   {{0xb9e42e51,0xe9fc07ae,0xf2d00375,0xfce42f59}},	//   استى, _phạm_, צעה_, _йово, 
   {{0xad841e87,0xa96414b7,0xfca80451,0x3eb801f5}},	//   _ماقۇ, лија_, _سارو_, lapt_, 
   {{0xfaa464cf,0x63a56b67,0xb7c800db,0xb81800fe}},	//   _базо, _ntin, ربةك_, _তেজত_, 
   {{0x3eb82e95,0x290d6b68,0xfb000055,0x6c30007b}},	//   napt_, _enga_, _bhūś_, _افكا, 
   {{0x290c0270,0xaa916b69,0x15140410,0x56940022}},	//   _fnga_, _المث, адня, лаҿт, 
   {{0x63a401ab,0xd6ac015b,0x3eb801c7,0x00000000}},	//   _btin, _খাওয, hapt_, --, 
   {{0x39456b6a,0x6138004e,0x3eb96547,0x88d400b8}},	//   _imos_, _míld, kapt_, _kṛnt, 
   {{0x39440211,0xf09c0ffb,0x34480510,0x6d90003d}},	//   _hmos_, _sfà_, _үчин_, _għaw, 
   {{0x63a56b6b,0x35681142,0x61380077,0x623499c6}},	//   _etin, _прин_, _xílg, беру, 
   {{0xc5ec15fa,0xc44404d3,0x926801e0,0x9ed800d1}},	//   _کړی_, ایین_, ерға_, һмут_, 
   {{0x3eb80311,0xe4d400db,0xdb1000ee,0x00000000}},	// [258f0] fapt_, _اتىب, _şeýt, --, 
   {{0x636001ed,0x9ed80276,0x290000e2,0x00000000}},	//   köny, лмут_, ējai_, --, 
   {{0x62880122,0xaca0063f,0x39456b6c,0x613808a5}},	//   ždor, siọb, _omos_, _bíld, 
   {{0x63a400cc,0x7d140205,0x00000000,0x00000000}},	//   _ytin, öysp, --, --, 
   {{0xe8dc0208,0xdcfc00ef,0x00000000,0x00000000}},	//   hiển_, _aurē, --, --, 
   {{0x290c089c,0x3eb8e9a7,0x2fcc00e8,0xda0800ec}},	//   _snga_, capt_, àggu_, ڏيهه_, 
   {{0x3168009b,0x290c01c4,0x689001ed,0x64b00241}},	//   _kkcz_, _pnga_, میائ, _lẹẹm, 
   {{0x1a6853b6,0x47c40117,0x00000000,0x00000000}},	//   دیمی_, абив, --, --, 
   {{0x6d496b6d,0x64c80024,0xb7d41bf4,0x00000000}},	//   miga, nčių, لويا_, --, 
   {{0x39443ecf,0x6d496b6e,0xe9fc001e,0x63a401b9}},	//   _emos_, liga, _nhầm_, _rtin, 
   {{0x290c06a3,0x63a4be69,0x229c01e1,0xa9280212}},	//   _tnga_, _stin, _làkó_, _піде_, 
   {{0x6d496b6f,0x290d6b70,0x6930034c,0x3998008d}},	//   niga, _unga_, _دکتر, _סינד, 
   {{0x3eb80054,0xa5080131,0x6d90025c,0xd7c833ae}},	//   yapt_, نىگە_, _tħaw, _مونه_, 
   {{0x46a42424,0x051400bd,0x613800c6,0x6b800194}},	//   _такв, াসের_, _míle, nmng, 
   {{0x1888008e,0x00000000,0x00000000,0x00000000}},	//   _исәп_, --, --, --, 
   {{0x63a56b71,0x67216b72,0x057800c6,0x28a80037}},	//   _ttin, _honj, _جمعة_, _ट्मि, 
   {{0x6d496b73,0x63a56b74,0x3eb801f5,0x61380241}},	// [25900] diga, _utin, tapt_, _níle, 
   {{0x6720a64d,0x6d496b75,0x387005ac,0x3f8c0008}},	//   _jonj, eiga, _øyre_, öfu_, 
   {{0xbca49067,0x6d4820ac,0x9d54168d,0x61383eba}},	//   لماي, figa, مۆست, _píld, 
   {{0xfce4f8da,0x67216b76,0x6d496b77,0x61396b78}},	//   родо, _lonj, giga, _bíle, 
   {{0x6138012c,0x20049429,0x9f400036,0xcdc401ec}},	//   _cíle, _émi_, ntië_, _қатқ, 
   {{0x67216b79,0x05c406ab,0x6d496b7a,0x0ba800cf}},	//   _nonj, _विंब, aiga, اانى_, 
   {{0x6d496b7b,0xab240063,0xbe3400d1,0x88d400b8}},	//   biga, роја_, _ئىزب, _vṛnt, 
   {{0x6d496b7c,0x67202ce9,0x57b42b17,0x4ba40116}},	//   ciga, _aonj, ббит, шләң, 
   {{0x67216b7d,0xfb880415,0x7d0163c5,0xf1bc0030}},	//   _bonj, _абак_, mdos, ľšie_, 
   {{0xf1bc01a2,0xdcfc005f,0xdb0c01e1,0x00000000}},	//   žšie_, _turē, _àhàm, --, 
   {{0x67200bb8,0x7d016b7e,0xd7f804a9,0x39440200}},	//   _donj, odos, туқ_, _tmos_, 
   {{0x3544559a,0x39440066,0x37e40006,0xa8440066}},	//   рхов, _umos_, _водг, الیم_, 
   {{0x672003d1,0xb794026a,0x7d009d07,0xe9fc004d}},	//   _fonj, _трећ, idos, _phầm_, 
   {{0x7d0002f6,0xa5d400f2,0xe73400f3,0x66e0009b}},	//   hdos, دبیر_, _вељ_, _доља, 
   {{0x6d496b7f,0x9f400d27,0x48dc0254,0xc7640137}},	//   yiga, atië_, क्को_, _اانى, 
   {{0x6d480429,0x67216b80,0x74f00150,0x6d90031c}},	//   xiga, _zonj, _بۋحا, _mħat, 
   {{0x6d496b81,0xe9fc001e,0x7d000429,0x67216b82}},	// [25910] viga, _thầm_, ddos, _yonj, 
   {{0x6d487dcc,0x9f400699,0x6720022e,0x61380332}},	//   wiga, ntiè_, _xonj, _ríle, 
   {{0x9f056b83,0x6d4817ce,0x23900165,0x6d90025c}},	//   تولو, tiga, _uńja_, _nħat, 
   {{0xe1f0eb14,0x6d496b84,0x613800d7,0x7d016b85}},	//   _کسی_, uiga, _píle, gdos, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x78a00170,0x6b800472,0xdb5409a5,0x7d016b86}},	//   _afov, umng, овчы, ados, 
   {{0x6d496b87,0xdef9408b,0x7d016b88,0x00000000}},	//   piga, _тыя_, bdos, --, 
   {{0x67216b89,0x6d480869,0xdd9400fd,0x7d0401ed}},	//   _sonj, qiga, _фаты, térő, 
   {{0x67216b8a,0x6d58c135,0xb05801b8,0xa464001f}},	//   _ponj, _ijua, _odäm, _ፍላጎት, 
   {{0x2a64030d,0x7d0400e5,0x00000000,0x00000000}},	//   _къег, rérő, --, --, 
   {{0x67216b8b,0x6d90025c,0x0564039b,0x7d0401ed}},	//   _vonj, _għat, йвон, sérő, 
   {{0xe9fc0016,0x67216b8c,0x4534d89f,0xb0580166}},	//   _chấm_, _wonj, схот, _adäm, 
   {{0x291c76ed,0x6d5801f7,0xf6f402f2,0xc4f80014}},	//   mjua_, _mjua, _گزنگ, نٹھا_, 
   {{0xd87415f6,0x6d90025c,0x957801c6,0x291c005b}},	//   _بامب, _jħas, лөөс_, ljua_, 
   {{0x6d58565c,0x291c009f,0x6d900135,0xb4d800e4}},	//   _ojua, ojua_, _mħas, viàv, 
   {{0x291c01f7,0x67400210,0x00000000,0x00000000}},	//   njua_, żują, --, --, 
   {{0x7d00036b,0x291c01c8,0x00000000,0x00000000}},	// [25920] vdos, ijua_, --, --, 
   {{0x6d586f76,0x6d90031c,0xd5b800b8,0x00000000}},	//   _ajua, _nħas, cyās_, --, 
   {{0x7d0001b9,0x6e9000c6,0x00000000,0x00000000}},	//   tdos, ألما, --, --, 
   {{0x7d016b8d,0x41740133,0x6138013a,0x00000000}},	//   udos, _داخس, _dílc, --, 
   {{0xe6045929,0x6d583132,0x00000000,0x00000000}},	//   _کش_, _djua, --, --, 
   {{0x7d0002d3,0x291c009f,0x37a80131,0x00000000}},	//   sdos, ejua_, қтин_, --, 
   {{0xcdc4681b,0x20100210,0x00000000,0x00000000}},	//   _марқ, łnię_, --, --, 
   {{0x21200f03,0x6d580023,0xb4d8004e,0x291c036e}},	//   njih_, _gjua, niàt, gjua_, 
   {{0xbc2400cf,0xb76402dd,0x00000000,0x00000000}},	//   _ارزى, йтой, --, --, 
   {{0x7bc16b8e,0x6d900003,0x0ae81541,0x00000000}},	//   msou, _għas, _نرمي_, --, 
   {{0x25a40005,0xb9940597,0x27ec005a,0xf3f4151e}},	//   _ctnl_, _الصب, _epgn_, әмгә_, 
   {{0x7bc00421,0x00000000,0x00000000,0x00000000}},	//   osou, --, --, --, 
   {{0xb4d80137,0x21200cf4,0x7998009f,0x6d900135}},	//   diàt, djih_, _hutw, _jħar, 
   {{0x79996b8f,0xfbd802f5,0x6d900135,0x7bc00036}},	//   _kutw, _ধনাত, _mħar, isou, 
   {{0xe9fc001e,0x62343f67,0xa6c41b80,0x3158007b}},	//   _thấm_, перу, _طويل_, هجرة_, 
   {{0x79989d20,0xdef80032,0x7bc00784,0x00000000}},	//   _mutw, ҙыу_, ksou, --, 
   {{0x7bc00369,0x7998047e,0x601800a7,0x6d900135}},	// [25930] jsou, _lutw, ботя_, _nħar, 
   {{0x7bc0aef5,0x6d584535,0x79985337,0xdcfc0064}},	//   dsou, _sjua, _outw, _kurė, 
   {{0x799800ca,0x6d900327,0x7bc0b594,0x21200219}},	//   _nutw, _aħar, esou, bjih_, 
   {{0xb4d8004e,0x2120892f,0x8c3c0205,0x00000000}},	//   ciàt, cjih_, _afşa, --, 
   {{0x2b90ff95,0x00000000,0x00000000,0x00000000}},	//   سیاس, --, --, --, 
   {{0x799893ea,0x9abc031c,0xc9a845ce,0x0f340133}},	//   _butw, _doċo, авке_, _بکرد, 
   {{0x79980072,0x6d5805ac,0x291c023a,0xb4d800e4}},	//   _cutw, _tjua, tjua_, chàg, 
   {{0x5d556b90,0x79980223,0x21f00036,0x6d588a07}},	//   _екст, _dutw, _höhö_, _ujua, 
   {{0xe8dc001e,0x7bc0009a,0xdddc010e,0x291d6b91}},	//   hiện_, csou, _kyrş, rjua_, 
   {{0x85e88488,0x6d900003,0x6b980280,0x7a2001f2}},	//   адов_, _għar, _iuug, ọtal, 
   {{0x7998015c,0x61387978,0x6b980254,0xfbbc0154}},	//   _gutw, _líla, _huug, _উৎপত, 
   {{0x29000029,0x6b996b92,0x69c16b93,0x9f40002e}},	//   ējas_, _kuug, msne, rtié_, 
   {{0x6b996b94,0x21200219,0x00000000,0x00000000}},	//   _juug, vjih_, --, --, 
   {{0x18800032,0x6b996b95,0x387000cc,0x69c00076}},	//   _яңын, _muug, _øyra_, osne, 
   {{0x212009a8,0x6d90031c,0x6b996b96,0x00000000}},	//   tjih_, _lħaq, _luug, --, 
   {{0x6138008c,0x69c16b97,0x80a8156e,0x00000000}},	//   _bíla, isne, рвав_, --, 
   {{0x2120151c,0x69c004cc,0x6b996b98,0xb4d800cf}},	// [25940] rjih_, hsne, _nuug, riàt, 
   {{0xef142164,0x69c16b99,0xb4d8004e,0x2d8401f5}},	//   ому_, ksne, siàt, ïnen_, 
   {{0x2738004a,0xb4d8067c,0x69c001f5,0x7bc0bdff}},	//   _gêne_, miàr, jsne, wsou, 
   {{0x7bc16b9a,0x79996b9b,0x6b980050,0xb4d81e7b}},	//   tsou, _rutw, _buug, liàr, 
   {{0x61380241,0x7998014f,0x69c16b9c,0x6fc4134e}},	//   _gíla, _sutw, esne, _लिएं, 
   {{0x79a56b9d,0x7bc004c4,0x6b986928,0x39a402f6}},	//   орие, rsou, _duug, ошив, 
   {{0x7bc07d6a,0x69c16b9e,0x7998014f,0x00000000}},	//   ssou, gsne, _qutw, --, 
   {{0x7bc16b9f,0x6d400268,0xbd340132,0x7998ae99}},	//   psou, ènat, _بىرع, _vutw, 
   {{0x6b987171,0x6d900003,0x61380139,0xdcfc0064}},	//   _guug, _għaq, _xíla, _surė, 
   {{0xf7281142,0x799866b0,0x6e4408a5,0x00000000}},	//   рций_, _tutw, _úrbæ, --, 
   {{0x28a81ab2,0x69c16ba0,0xb4d81f40,0xb058010e}},	//   _ट्वि, csne, diàr, _edäh, 
   {{0xaa4800db,0x6b98037e,0x00000000,0x00000000}},	//   _ئسكە_, _yuug, --, --, 
   {{0x79801f4c,0x2738000f,0xb4d8004e,0x8c3c0205}},	//   _ihow, _sêne_, fiàr, _beşy, 
   {{0xdcfc0953,0x5ed000eb,0x00000000,0x00000000}},	//   _turė, স্তে, --, --, 
   {{0x79800472,0x61396ba1,0x7ae80142,0x1b042cc5}},	//   _khow, _síla, ifft, লাপে_, 
   {{0x79806085,0x90980801,0xd4b91af5,0x61396ba2}},	//   _jhow, сват_, _улиц_, _píla, 
   {{0x4fd4170a,0xb4d800cf,0x79816ba3,0xa0c4027d}},	// [25950] яжат, siàs, _mhow, بيقو, 
   {{0x69c16ba4,0x6b9803d9,0xb4d81f40,0xeea8abb9}},	//   ysne, _ruug, ciàr, ртак_, 
   {{0x6b996ba5,0xd6e80183,0x6d900327,0x00000000}},	//   _suug, _কোৱা_, _sħaq, --, 
   {{0x79800810,0x69c095a6,0x6b996ba6,0x88d40055}},	//   _nhow, vsne, _puug, _vṛkt, 
   {{0x1b040729,0xfe6c01d9,0x69c003cb,0x6f600e76}},	//   লানে_, نگہ_, wsne, _قۇرم, 
   {{0x798000b0,0x6b98000d,0x9b440345,0x25640205}},	//   _ahow, _vuug, وننو, mıle_, 
   {{0x69c16ba7,0x6d40007f,0x613802d2,0x5e58011c}},	//   usne, ènas, _míln, _диря_, 
   {{0x79816ba8,0x6b996ba9,0x69c027bb,0x795c02b5}},	//   _chow, _tuug, rsne, tīwa, 
   {{0x69c16baa,0x798162d1,0x00000000,0x00000000}},	//   ssne, _dhow, --, --, 
   {{0x7980014b,0x28a88a4f,0x69c129b7,0x795c00b0}},	//   _ehow, _ट्रि, psne, rīwa, 
   {{0xb4d84b84,0xc0cc0023,0xd7440023,0x69040006}},	//   viàr, _ብዕሊ_, _ንእምነ, _мядз, 
   {{0x99d40722,0x79816bab,0x795c02b5,0x9a84009d}},	//   _آتلا, _ghow, pīwa, _цуул, 
   {{0x613801a8,0xd90c0133,0x00000000,0x00000000}},	//   _bíln, _ڵیی_, --, --, 
   {{0x443c033f,0x491800cd,0x00000000,0x00000000}},	//   ąt_, भावो_, --, --, 
   {{0x6138012c,0x7c3c01e4,0x8c3cea5e,0x00000000}},	//   _díln, ĝpri, _ofşo, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc0cc0092,0x25640166,0x00000000,0x00000000}},	// [25960] _ብንል_, gıle_, --, --, 
   {{0x4f656bac,0x2480022e,0xdddc00ef,0x00000000}},	//   والف, _izim_, _uzrū, --, 
   {{0x1b040011,0x00000000,0x00000000,0x00000000}},	//   লামে_, --, --, --, 
   {{0xa11400d1,0x00000000,0x00000000,0x00000000}},	//   _تۈرت, --, --, --, 
   {{0x79800368,0x6cc001d9,0xb5a001ec,0x00000000}},	//   _rhow, رٲوٕ, _ﺍﻟﻤﻘ_, --, 
   {{0x79816bad,0xdcfc00b0,0x8eb00c75,0xf9a00092}},	//   _show, _kurī, _لەكت, ፈፃፀም_, 
   {{0x7d78034c,0x7b1000e4,0xaa90013e,0x798075d3}},	//   _همسر_, _añuä, нишч, _phow, 
   {{0x248001a9,0x613801ef,0x00000000,0x00000000}},	//   _ozim_, _mílo, --, --, 
   {{0xdff002dd,0x7c3400cc,0x1b040154,0x00000000}},	//   ерiн_, øyrd, লাবে_, --, 
   {{0x7980009a,0x1634fdca,0x68b40014,0xdb2400f2}},	//   _whow, деоя, _ہُمس_, _توئی, 
   {{0x79816bae,0x24816baf,0x46dc01f9,0x00000000}},	//   _thow, _azim_, _मारह, --, 
   {{0x7980014b,0x387005ac,0x9f400381,0x00000000}},	//   _uhow, _øyro_, ntiâ_, --, 
   {{0xf53c01bf,0x00000000,0x00000000,0x00000000}},	//   rhå_, --, --, --, 
   {{0x9abc038f,0x613800bc,0x248000ef,0xf1a41572}},	//   _soċj, _bílo, _dzim_, зран, 
   {{0x24800083,0x61396bb0,0xd5880116,0x00000000}},	//   _ezim_, _víln, _мәмл_, --, 
   {{0x64680438,0x622400d1,0x265800df,0x00000000}},	//   ésié, رىقل, _לכוא, --, 
   {{0x24800200,0x3ce40150,0x189004b2,0x00000000}},	// [25970] _gzim_, _ﺍﺤﺘﻤ, _ማናጀር_, --, 
   {{0xd7d42ac3,0xb14404f2,0x27380092,0x00000000}},	//   _दिनच, _کیرم_, _ስለሚጠ, --, 
   {{0xb63c04ce,0x00000000,0x00000000,0x00000000}},	//   _ｂｌ_, --, --, --, 
   {{0xdddc0142,0x201c0419,0x00000000,0x00000000}},	//   _ngrŵ, ózií_, --, --, 
   {{0xc1716bb1,0xdd941291,0x00000000,0x00000000}},	//   _شگفت, رجمع, --, --, 
   {{0x8fa40022,0x00000000,0x00000000,0x00000000}},	//   _наҭе, --, --, --, 
   {{0x2bcc01ad,0x00000000,0x00000000,0x00000000}},	//   _हटवा, --, --, --, 
   {{0x6f0478e0,0xf8ac712d,0xded00023,0xe8a000db}},	//   _hajc, لکه_, _ብስነ_, رۅتپ, 
   {{0xfcc018ce,0xd04c02a8,0x1bd416ab,0x60c00037}},	//   _рәхм, rfaɗ, _потя, _õmme, 
   {{0xfbd0068f,0x6f0424dd,0x7c3400fe,0x2cbc01ab}},	//   _सितम, _jajc, øyre, _heud_, 
   {{0x613801a8,0x957c0153,0x82300023,0xdecc01ec}},	//   _bíll, mtąj, _ጽፍሕታ, _ﻗﯘﺳﺒ, 
   {{0x6f04dc95,0x17ac00fe,0x957c00c0,0x00000000}},	//   _lajc, _খিৰি, ltąj, --, 
   {{0xfa080867,0x2cbd6bb2,0xb4d8004e,0x61389247}},	//   _གནོན_, _meud_, riàp, _díll, 
   {{0x6f056bb3,0xaca001f2,0x68f96bb4,0x2cbc08c2}},	//   _najc, _baịn, leud, _leud_, 
   {{0xc0e4040e,0x57240014,0xf2a11228,0x613802d2}},	//   мовк, _سروق, тисп, _fíll, 
   {{0x66000113,0x2cbd6bb5,0x68f96bb6,0x9f400306}},	//   _isnk, _neud_, neud, rtií_, 
   {{0xa49490c7,0x1b04015b,0x248007a5,0xe058030f}},	// [25980] _سیست, লাতে_, _uzim_, سیست_, 
   {{0x2cbc0098,0x3dd80227,0x68f89f5c,0xddc800e8}},	//   _aeud_, tupw_, heud, _ñoŋa, 
   {{0x6f056bb7,0x68f96bb8,0x2cbcdf6d,0x412802a9}},	//   _dajc, keud, _beud_, _доно_, 
   {{0x2cbc0e89,0x66000009,0xed556bb9,0x00000000}},	//   _ceud_, _msnk, мох_, --, 
   {{0x06d402a6,0x68f96bba,0x2cbd6bbb,0x1af4005b}},	//   ত্যি, deud, _deud_, епля, 
   {{0x9f40003a,0x8f7402d5,0x00000000,0x00000000}},	//   stiâ_, _зусі, --, --, 
   {{0x629803c6,0x2cbcf7ee,0x68f96bbc,0xaa540127}},	//   _úvod, _feud_, feud, ولها_, 
   {{0x60c56bbd,0x3d047db3,0x6f040427,0x68f928a7}},	//   naim, _सोचे_, _zajc, geud, 
   {{0xfaa407d6,0x7aa4036b,0x1b640022,0x6cd001ec}},	//   _жазо, _жизз, _знаҭ, _جققا, 
   {{0x61380998,0x660000df,0x9f400ffb,0xb05801f4}},	//   _síll, _bsnk, ntià_, _idät, 
   {{0x61380005,0xeb300a52,0x68f80156,0x33940150}},	//   _píll, _جىلد, beud, _ﺜﺎﻨﻲ_, 
   {{0xf9901169,0x20016bbe,0x60c46c3f,0x68f801bf}},	//   _شبا_, kwii_, jaim, ceud, 
   {{0x60c56bbf,0x7c2000cf,0xe9440345,0x00000000}},	//   daim, nxor, _ترلی, --, 
   {{0x676000ec,0xa878011a,0x00000000,0x00000000}},	//   _لڏپل, _ואדר, --, --, 
   {{0x60c56bc0,0x6f056bc1,0xdb0000fd,0x26009a25}},	//   faim, _rajc, _itmä, _ачыг, 
   {{0x60c45088,0x61385cca,0x7778010a,0x3ea80334}},	//   gaim, _fílm, lltx, _afbt_, 
   {{0x2cbc0165,0xa1584258,0x6f056bc2,0xd37400f3}},	// [25990] _reud_, фату_, _pajc, _плић, 
   {{0x2cbc00a3,0x68f96bc3,0x00000000,0x00000000}},	//   _seud_, zeud, --, --, 
   {{0x60c56bc4,0x6f040030,0x88d400cd,0x68f94f80}},	//   baim, _vajc, _kṛtt, yeud, 
   {{0x6f0402d1,0x27fc00a9,0xd9f80490,0x60c401e7}},	//   _wajc, ywun_, ंबईत_, caim, 
   {{0x25640724,0xd054016b,0xfa08025c,0x2cbc0165}},	//   nıla_, _ɔbɛk, _གནུན_, _veud_, 
   {{0x7c7004a9,0x2cbc0042,0xef54136e,0x614401e1}},	//   уғуч, _weud_, _غیاث_, _tìlù, 
   {{0x9f400004,0xe8e8025c,0x2cbc00a3,0x68f8ddd6}},	//   stiã_, _རྡུག, _teud_, teud, 
   {{0xb058002f,0x88d4002b,0x256403e0,0x689000e5}},	//   _geäc, _nṛtt, kıla_, نیائ, 
   {{0x68f96bc5,0xb0585f95,0x3a70468c,0x0bd43a16}},	//   reud, _idäs, кләр, _سياح, 
   {{0x60c56bc6,0x68f802f6,0x6600005a,0x256403e3}},	//   zaim, seud, _psnk, dıla_, 
   {{0x68f802f6,0xe7900517,0x9f40067c,0x00000000}},	//   peud, _یاتک, ntiá_, --, 
   {{0xdb000209,0x7778005a,0x04440108,0x3a3400df}},	//   _etmä, altx, еемн, _ארעם_, 
   {{0x60c56bc7,0x2564008e,0x00000000,0x00000000}},	//   vaim, gıla_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x60c56bc8,0x20000a55,0x01642766,0x442001f4}},	//   taim, wwii_, екво, sxk_, 
   {{0x69d4012c,0x2000002e,0x3864007c,0x6d40022e}},	//   _यिनी, twii_, _yxor_, ënal, 
   {{0x60c56bc9,0x6564009f,0xf8b0008f,0x717000c6}},	// [259a0] raim, _ijih, טשן_, اهقا, 
   {{0x60c56bca,0x2ee0004e,0x00000000,0x00000000}},	//   saim, лжуг, --, --, 
   {{0x60c56bcb,0xb900031c,0x9f4000db,0xdddc0118}},	//   paim, _ཧྰ_, rtià_, _vzrů, 
   {{0x9f416bcc,0x7c2001c6,0x7c8417b4,0x568c010f}},	//   stià_, txor, нуле, קטאַ, 
   {{0xada001e0,0x1b040154,0x00000000,0x00000000}},	//   _ҡарл, লাসে_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7c200077,0x6f600120,0x00000000,0x00000000}},	//   sxor, _сврз, --, --, 
   {{0x25646b8e,0xb05800fd,0x6a10cdcc,0x00000000}},	//   yıla_, _idär, ابور, --, 
   {{0xb6e40395,0x00000000,0x00000000,0x00000000}},	//   нюнк, --, --, --, 
   {{0x65656bcd,0x38640393,0x613800bc,0xac040276}},	//   _ajih, _vxor_, _bílk, _януа_, 
   {{0x9b640075,0x0ae805d9,0xdb00036e,0xb4f0009d}},	//   _كۆچۈ, _ترقي_, _lumë, гүйч, 
   {{0x25640724,0x613800bc,0x00000000,0x00000000}},	//   tıla_, _dílk, --, --, 
   {{0x3864d1fe,0x295404ac,0xdb0002d3,0x88d40882}},	//   _uxor_, _אסאך_, _numë, _vṛtt, 
   {{0xdb00049f,0x25640598,0xd9f40574,0xb4d804cc}},	//   _utmä, rıla_, _आहात_, chàn, 
   {{0x66e00798,0x645800b8,0x00000000,0x00000000}},	//   _соја, _śvit, --, --, 
   {{0x6a40002e,0x9f4016b8,0x65640200,0x6678011a}},	//   _jёfa, ntiæ_, _gjih, _מטוק, 
   {{0xdb0000d2,0xdfd4023a,0xa1840220,0x88d400b8}},	// [259b0] _vumê, лоты, уырл, _kṛrt, 
   {{0xb1901b15,0xe3b04706,0x680c00e5,0x00000000}},	//   _әлмә, _اري_, lődö, --, 
   {{0x6e6400fb,0x00000000,0x00000000,0x00000000}},	//   хтаж, --, --, --, 
   {{0x2fc8009b,0x2c840248,0x00000000,0x00000000}},	//   _tvcg_, _nìdí_, --, --, 
   {{0xc0a801d9,0x9f416bce,0xdb000200,0xf09c0051}},	//   _تاپل_, stiá_, _gumë, _igà_, 
   {{0xdb00067c,0xfbd00034,0x7c3400fe,0x4a74004e}},	//   _jumè, _सिरम, øyra, кыйт, 
   {{0x6138032e,0x00000000,0x00000000,0x00000000}},	//   _bílh, --, --, --, 
   {{0xdd954fe1,0x1a680426,0x00000000,0x00000000}},	//   _басы, رینی_, --, --, 
   {{0xcb6801b9,0xb4d80051,0x00000000,0x00000000}},	//   _قمره_, thàn, --, --, 
   {{0xdb0056ed,0xb6e000b5,0x795c00b0,0x61380419}},	//   _numè, _expﾃ_, hīwh, _pílk, 
   {{0x99d50fca,0x2c840248,0x38a8035b,0x6138032e}},	//   _متنا, _fìdí_, _ỹre_, _fílh, 
   {{0x03a56bcf,0x2d8c0810,0xf09c2ba0,0x671c00bc}},	//   кимо, nmge_, _ngà_, बाहक_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb6a0023b,0x4918012c,0x61380118,0x00000000}},	//   _кишл, भाको_, _tílk, --, 
   {{0xdb016bd0,0x526401e0,0x11d4187f,0x00000000}},	//   _dumè, герғ, літр, --, 
   {{0xdb00067c,0x6564009f,0x515401c0,0xb0581196}},	//   _eumè, _ujih, гтуу, _adäq, 
   {{0xd5ac00dd,0xdb000023,0x00000000,0x00000000}},	// [259c0] _وہی_, _qumë, --, --, 
   {{0x6d90031c,0x613801e7,0xa9240064,0x00000000}},	//   _għaz, _míli, lužė, --, 
   {{0x63a56bd1,0x333806a9,0x01645b66,0x00000000}},	//   _huin, _חתימ, _акно, --, 
   {{0x63a56bd2,0x9f9400c7,0x00000000,0x00000000}},	//   _kuin, _ӡыгә, --, --, 
   {{0x8fd4053f,0x63a40129,0x613800ae,0x932428c4}},	//   _бәхә, _juin, _níli, _شرین, 
   {{0x63a56bd3,0xdb000098,0x38700158,0xdcfc00c0}},	//   _muin, _kumé, _øyri_, _turį, 
   {{0x1b04045e,0x63a56bd4,0xdb00020c,0xf2d000d9}},	//   লালে_, _luin, _jumé, בעו_, 
   {{0x61381f60,0xa9640e92,0x63a40129,0xb058007c}},	//   _bíli, кија_, _ouin, _meän, 
   {{0x63a40053,0xed54cef8,0x61380120,0xdb00003e}},	//   _nuin, _рот_, _cíli, _lumé, 
   {{0x7790034c,0x6138007b,0x9f400393,0xe7f00037}},	//   جیتا, _díli, stiæ_, _अहरा_, 
   {{0xdb002047,0x63a54cb0,0xe51403e5,0xded01954}},	//   _numé, _auin, _तोहि_, ብሩና_, 
   {{0xa92402d5,0x63a56bd5,0xdb001df3,0x61396bd6}},	//   gužė, _buin, _sumè, _fíli, 
   {{0x63a56bd7,0xb058145e,0xdb003512,0xe58000d1}},	//   _cuin, _ndäp, _aumé, _ﮬﯚﻛﯜ, 
   {{0x63a56bd8,0xdb000098,0xb0596bd9,0x9f40023a}},	//   _duin, _bumé, _beän, ntiä_, 
   {{0x671c1533,0x63a400b5,0x795c02b5,0xb4f0064e}},	//   बारक_, _euin, tīwh, _күнч, 
   {{0x63a56bda,0xe8040574,0xdb000c6a,0x9f40023a}},	//   _fuin, वटचा_, _dumé, htiä_, 
   {{0x63a47dcc,0xa1956bdb,0xdb01513b,0x048400ee}},	// [259d0] _guin, ратч, _eumé, _бәри_, 
   {{0xdb0007ea,0x942400c7,0xce9400a7,0x491801ad}},	//   _fumé, _амҩе, газъ, _मोनो_, 
   {{0xb0596bdc,0x63a40196,0xdb00003e,0x795c0374}},	//   _geän, _zuin, _gumé, pīwh, 
   {{0x63a56bdd,0x3b1c0051,0x00000000,0x00000000}},	//   _yuin, _antq_, --, --, 
   {{0xfff401d5,0xcebc03b9,0xaf080154,0xceb80139}},	//   _مکلت_, _abəş_, রাবণ_, _зәе_, 
   {{0x613c005c,0x06a001ec,0x1c4428f6,0x00000000}},	//   pålæ, _ﺍﺯﻋﯩ, шнім, --, 
   {{0x61396bde,0x49996bdf,0x714802d3,0xe8dc0521}},	//   _síli, нтия_, _ሓረስቶ, shọn_, 
   {{0x0904f5b4,0x613800d7,0x25640139,0x00000000}},	//   упин, _píli, gıll_, --, 
   {{0x88d4002b,0xac7410de,0x671c302b,0x475801f4}},	//   _dṛpt, _شارش, बालक_, ерня_, 
   {{0x07080979,0x26c0baac,0x2908238f,0xab840229}},	//   ريجي_, újo_, žca_, _рубк, 
   {{0x63a464da,0xda0800ae,0x00000000,0x00000000}},	//   _suin, _ليله_, --, --, 
   {{0x63a56be0,0x61382be1,0x00000000,0x00000000}},	//   _puin, _tíli, --, --, 
   {{0x42d53540,0x64a40022,0x00000000,0x00000000}},	//   ліву, лаҟа, --, --, 
   {{0x63a56be1,0x5ec80154,0xa7740166,0x00000000}},	//   _vuin, _লাভে, _шәйх_, --, 
   {{0xc5d400d6,0x85780276,0x63a4007f,0xdcfc00de}},	//   _сіль, _псит_, _wuin, _jurģ, 
   {{0x6d900003,0x9abc0003,0xd164035b,0xded00023}},	//   _għax, _inċe, ансқ, ብዩን_, 
   {{0x63a48c04,0xd9d017ee,0x44256be2,0x9f40005b}},	// [259e0] _uuin, _सट्ट, _ço_, ytiä_, 
   {{0x06d400bd,0xaec16be3,0xafe00440,0x00000000}},	//   ত্রি, йбул, софл, --, 
   {{0x016401d9,0xc0e56be4,0x64b80073,0xce3400f1}},	//   _مُدَ, _йонк, _आभाळ, ټونک, 
   {{0xd7d41533,0xbc6803cc,0x00000000,0x00000000}},	//   _दिलच, ىمان_, --, --, 
   {{0x6138808c,0x9f4002f6,0xafe15e96,0x09ac0154}},	//   _sílw, ttiä_, _лоял, _গিগা, 
   {{0xf9f8031c,0xeb956be5,0xdcfc0171,0x00000000}},	//   _ྒྱུན_, гич_, _burģ, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9f4c0598,0x9f40049b,0x2738004d,0x6e20007c}},	//   şlär_, stiä_, _hênh_, ånbe, 
   {{0x3b848233,0xbc6415ed,0x27380016,0x9abc0327}},	//   _благ, _свак, _kênh_, _anċe, 
   {{0x37056be6,0x7d0002cf,0x3ce56be7,0x00000000}},	//   учив, leos, lgov_, --, 
   {{0xab900491,0xeaac0014,0x2738004d,0x19c40304}},	//   _اللغ, _رٹن_, _mênh_, _тәлг, 
   {{0x3ce56be8,0x7d016be9,0x2738004d,0xb4bc000d}},	//   ngov_, neos, _lênh_, इरे_, 
   {{0x78a0014b,0xc1ac00d1,0x00000000,0x00000000}},	//   _igov, _ﻳﺎﺭﺍ, --, --, 
   {{0x569503ff,0x6138032e,0x7d00000d,0x281000f2}},	//   _калт, _mílu, heos, _دوهس, 
   {{0x6d400006,0x6d900327,0x9294041b,0x7d0001f4}},	//   ūnai, _tħax, равц, keos, 
   {{0xb35401ed,0x64a400f3,0x00000000,0x00000000}},	//   ئیگا_, _лаћа, --, --, 
   {{0x7d016bea,0x90980801,0xb0580036,0xd5b80318}},	// [259f0] deos, тват_, _geäl, lpā_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe3b01416,0x78a00e3c,0xf9cc00d4,0x00000000}},	//   _وری_, _ogov, _днiв_, --, 
   {{0x7d016beb,0x78a01cdf,0x61396bec,0x957c0064}},	//   geos, _ngov, _sílv, mtąs, 
   {{0x8ac401c6,0x00000000,0x00000000,0x00000000}},	//   айлж, --, --, --, 
   {{0x78a16bed,0xe1f11655,0x613801e7,0xe458010f}},	//   _agov, _بسی_, _dílu, ניגט_, 
   {{0xdea4104a,0x2d856bee,0xf53c0158,0x00000000}},	//   _ایمی, ïnes_, kkå_, --, 
   {{0xbb3c0952,0x6138022c,0x7d00021c,0x3ce4007f}},	//   ﻟﻜﻰ_, _fílu, ceos, cgov_, 
   {{0xaae47640,0x77c405f5,0xb5c40014,0x00000000}},	//   _مساو, алыг_, یوٝم_, --, 
   {{0x05100154,0x27380051,0x00000000,0x00000000}},	//   _হকের_, _xênh_, --, --, 
   {{0xa3e8acd2,0x05642766,0x87d820d4,0x00000000}},	//   मून_, ивон, ربکس_, --, 
   {{0x055401f0,0x00000000,0x00000000,0x00000000}},	//   ртоя, --, --, --, 
   {{0x5ed000bd,0x290c0b23,0x613800c6,0x03a56bef}},	//   স্টে, _iaga_, _mílt, риго, 
   {{0x290d6bf0,0x78a00219,0x3ce432fe,0x984802e8}},	//   _haga_, _zgov, zgov_, _щяха_, 
   {{0x290d6bf1,0x7d000076,0xc15400ea,0x00000000}},	//   _kaga_, yeos, ањањ, --, 
   {{0x26c56bf2,0x2d9d6bf3,0x613801e7,0x27380051}},	//   _heno_, _niue_, _nílt, _sênh_, 
   {{0x290d6bf4,0xf0a402a3,0xaca001f2,0x54e41075}},	// [25a00] _maga_, ркул_, ghọb, _اسىق, 
   {{0x290d6bf5,0x26c40793,0xa0696bf6,0x8628001f}},	//   _laga_, _jeno_, ваға_, _ትራንስ, 
   {{0x26c56bf7,0x32d806a9,0x7d0026bb,0x290c0421}},	//   _meno_, _בחינ, teos, _oaga_, 
   {{0x290d6bf8,0x2480013f,0x2d9d647e,0x6138021c}},	//   _naga_, _kyim_, _ciue_, _pílu, 
   {{0x3ce401d5,0x25a16bf9,0x69d40077,0x7ed401d9}},	//   rgov_, _miil_, áxen, _پٲزا, 
   {{0x26c56bfa,0xeb300e76,0x290d6bfb,0x7d00340f}},	//   _neno_, يىند, _aaga_, seos, 
   {{0x290d6bfc,0xe604a012,0x84e42ba2,0x9f04004b}},	//   _baga_, _بش_, _कांट_, _پوځو, 
   {{0x290d6bfd,0x26c4003a,0x25a16bfe,0x248001d5}},	//   _caga_, _aeno_, _niil_, _oyim_, 
   {{0x290c576b,0xb8fc1dd1,0x24816bff,0x26c56c00}},	//   _daga_, _तय_, _nyim_, _beno_, 
   {{0x25a00270,0x26c40fb7,0x290c0086,0x6d4002d3}},	//   _aiil_, _ceno_, _eaga_, ënav, 
   {{0x290d6c01,0x24800066,0x26c40793,0x25a0058a}},	//   _faga_, _ayim_, _deno_, _biil_, 
   {{0x290d6c02,0x78a004b9,0x26c404ba,0x25a107fb}},	//   _gaga_, _ugov, _eeno_, _ciil_, 
   {{0x26c40851,0x3944009a,0x43b00032,0xf4852247}},	//   _feno_, _ilos_, пҡыр, рунн, 
   {{0x39440218,0x290d6c03,0x26c4010f,0xf53c0158}},	//   _hlos_, _zaga_, _geno_, skå_, 
   {{0x39442b92,0x290c03b4,0x7af80083,0x25a16c04}},	//   _klos_, _yaga_, _mbtt, _fiil_, 
   {{0x26c56c05,0x290c6928,0x25a0208d,0x00000000}},	//   _zeno_, _xaga_, _giil_, --, 
   {{0x5f4802d3,0x8c3c0432,0xb4b0107c,0x26c40055}},	// [25a10] _መከላኸ, _ogşa, टडी_, _yeno_, 
   {{0x26c4ae67,0x2d9c1730,0x39440077,0x61396c06}},	//   _xeno_, _siue_, _llos_, _bíls, 
   {{0xdcfc025c,0x25a00067,0x741001f7,0x00000000}},	//   _surġ, _yiil_, _اوڌا, --, 
   {{0x8c3c00ee,0x6138007b,0x00000000,0x00000000}},	//   _agşa, _díls, --, --, 
   {{0x290c44ce,0xc0c000ee,0xb4d801c3,0x00000000}},	//   _raga_, _хәси, ghài, --, 
   {{0x39456c07,0xa3e96c08,0x613802d2,0x00000000}},	//   _alos_, मंत_, _fíls, --, 
   {{0x26c56c09,0x39440428,0x6ce400d4,0x60cc0432}},	//   _reno_, _blos_, _візе, _ölmä, 
   {{0x26c4014c,0x1b040183,0x39456c0a,0x2d9c003a}},	//   _seno_, লাগে_, _clos_, _uiue_, 
   {{0x290d6c0b,0x26c56c0c,0x25a0562c,0x39440142}},	//   _vaga_, _peno_, _riil_, _dlos_, 
   {{0x290c0034,0x25a05a7a,0x752c0210,0x00000000}},	//   _waga_, _siil_, ejcz, --, 
   {{0x394416b8,0x26c56c0d,0x00000000,0x00000000}},	//   _flos_, _veno_, --, --, 
   {{0x26c56c0e,0x39445cf8,0x290d6c0f,0xd7c803e6}},	//   _weno_, _glos_, _uaga_, _چونه_, 
   {{0x391000db,0xd7c80fb4,0xb600025c,0x25a00254}},	//   _رووز, _نونه_, _ġġen, _viil_, 
   {{0xe1f80364,0x25a00050,0x9f4000c6,0xd5e801d5}},	//   аҳо_, _wiil_, stiú_, دعین_, 
   {{0x25a0c7ea,0x03a4013e,0x9f416c10,0x64a400d1}},	//   _tiil_, риҳо, quié_, _һақа, 
   {{0x51b8084c,0xa3e8033f,0x3fa40b73,0x00000000}},	//   рыря_, मंद_, مصطف, --, 
   {{0x6d4856f2,0x64a56c11,0xefcc0023,0x613802d2}},	// [25a20] dhga, _лақа, _ኣባይ_, _bílr, 
   {{0x2ba81533,0x5ec800cc,0x957c0210,0x00000000}},	//   _चढ़ा, _লাহে, trąg, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xeabc001e,0x795c02b5,0x8d880092,0x55ac010f}},	//   _đùa_, kūwa, _ንዲቻል_, דיאַ, 
   {{0xdb000356,0xccb40150,0x00000000,0x00000000}},	//   _rumâ, _ﺴﺎﺌل_, --, --, 
   {{0x2cb800ac,0x394400a3,0x3ebc08a5,0x0ba40150}},	//   ıqda_, _slos_, _ýtt_, ішім, 
   {{0x7f5c0455,0x39449b1e,0x5a356c12,0x752c012d}},	//   mipq, _plos_, юнкт, yjcz, 
   {{0x57b56c13,0x115c044e,0x6d496c14,0x2618146b}},	//   обит, _ተወሳኺ_, chga, यिनी_, 
   {{0xb058002d,0x3944017a,0x5c7800fb,0x00000000}},	//   _reäk, _vlos_, _тәжр_, --, 
   {{0x175400d4,0x00000000,0x00000000,0x00000000}},	//   івня, --, --, --, 
   {{0xf9340209,0x16356c15,0x00000000,0x00000000}},	//   _гүйч_, ценя, --, --, 
   {{0x394402f6,0x35441fe2,0xd15c0023,0xf1bc00d7}},	//   _ulos_, схов, _ተለፎን_, ýšme_, 
   {{0xb8940491,0x7f5c0113,0x98a40356,0x00000000}},	//   _الشع, kipq, ajmă_, --, 
   {{0x62a801e1,0x00000000,0x00000000,0x00000000}},	//   _àsọ, --, --, --, 
   {{0xd1c00020,0x777801c4,0x00000000,0x00000000}},	//   _ሴቶች_, motx, --, --, 
   {{0x7778005a,0xa1596c16,0x00000000,0x00000000}},	//   lotx, басу_, --, --, 
   {{0xddd400d0,0xa3e80c70,0x00000000,0x00000000}},	// [25a30] _čašn, मूद_, --, --, 
   {{0x23b8314c,0xdb0000db,0x77787c3f,0xf2c56c17}},	//   _اديب_, _numà, notx, _усин, 
   {{0x6d4800a9,0xfbc41c15,0x5ec80154,0xed1401d9}},	//   thga, रीसम, _লাশে, ٝفاں_, 
   {{0x7778005a,0x2af8012c,0x6678010f,0x00000000}},	//   hotx, ल्नु_, נטאק, --, 
   {{0x77796c18,0x7f5c0139,0x98a4013d,0x00000000}},	//   kotx, bipq, jimı_, --, 
   {{0x6d48006c,0x95082fb5,0x5f943fa5,0x00000000}},	//   shga, _ཇིའི_, _ният, --, 
   {{0xdb002b76,0x777801c4,0x0f300092,0x6d40036e}},	//   _atmó, dotx, _በማሳየ, ënas, 
   {{0x795c02b5,0x00000000,0x00000000,0x00000000}},	//   tūwa, --, --, --, 
   {{0xdd956c19,0x6d580124,0x00000000,0x00000000}},	//   _хаты, _imua, --, --, 
   {{0x7778c383,0x795c02b5,0x1c380166,0x00000000}},	//   gotx, rūwa, _узуы_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x795c02b5,0x00000000,0x00000000,0x00000000}},	//   pūwa, --, --, --, 
   {{0xdb016c1a,0x82e40003,0x6d580134,0x7778005a}},	//   _humá, _སྐུའ, _mmua, botx, 
   {{0x957c068f,0x7778004e,0x7c3400fe,0x82f800cc}},	//   stąp, cotx, øyri, েঞ্চ_, 
   {{0x6d589bb6,0x613808a5,0x0574007b,0xc574007b}},	//   _omua, _bílp, _وابد, _وطبع, 
   {{0x2bcc8b95,0x00000000,0x00000000,0x00000000}},	//   _सौभा, --, --, --, 
   {{0xfeb80a2c,0xeabc0208,0x00000000,0x00000000}},	// [25a40] لاات_, _đùn_, --, --, 
   {{0x6d596c1b,0x6b4c00fe,0x0204010a,0x00000000}},	//   _amua, _høgf, _дзон, --, 
   {{0xdb000c86,0xb4d80109,0xdddc0118,0x00000000}},	//   _rumà, ikàn, _vyrů, --, 
   {{0xdcb01e87,0x7778005a,0x6d580240,0xb5f8010f}},	//   رىت_, zotx, _cmua, ילעכ, 
   {{0x6b4c01bf,0x6da000d8,0x00000000,0x00000000}},	//   _møgf, фица, --, --, 
   {{0xac056c1c,0x6d596c1d,0x6b4c022c,0x9f400036}},	//   юнча_, _emua, _løgf, irië_, 
   {{0x6d5800a3,0xbe1400db,0xdb000332,0x7c2401ef}},	//   _fmua, _بوزع, _cumá, _škrd, 
   {{0x6d5801ab,0xa9900691,0xdb2002d2,0xdb0000e5}},	//   _gmua, وشيت, _útþe, _dumá, 
   {{0xd7c40490,0x7778005a,0x00000000,0x00000000}},	//   लींच, totx, --, --, 
   {{0x9abc0327,0x7b4400cf,0xec3400d9,0x1d840244}},	//   _inċo, _بئرل, _ואמר_, _بگڕێ, 
   {{0xdb000306,0x777801c4,0x00000000,0x00000000}},	//   _gumá, rotx, --, --, 
   {{0xe9b4066d,0x777801c4,0x00000000,0x00000000}},	//   _بچوں_, sotx, --, --, 
   {{0xc76401d9,0x8ed40154,0x02c401f9,0x00000000}},	//   _کانى, স্টগ, वरून, --, 
   {{0xc0680020,0xfba000b5,0xb4d800db,0xd7c80133}},	//   _በመጫን_, _bit版, ckàn, _نوچه_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa3e80490,0x9f4001f5,0x00000000,0x00000000}},	//   मूह_, brië_, --, --, 
   {{0x2ea80063,0xb2a400ae,0x10540798,0x00000000}},	// [25a50] ањен_, _وحده, чкаџ, --, 
   {{0x6d580e89,0x6e2001e6,0x00000000,0x00000000}},	//   _smua, ånbo, --, --, 
   {{0x6b4d6c1e,0x00000000,0x00000000,0x00000000}},	//   _høgg, --, --, --, 
   {{0xb14403e6,0x71200137,0x6d580200,0x2564013d}},	//   _بیرم_, _تۉرم, _qmua, bılu_, 
   {{0xdb016c1f,0x00000000,0x00000000,0x00000000}},	//   _sumá, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2bd405ba,0xfaa0013e,0x6b4c06ea,0x7a3000e5}},	//   _ठिका, нашо, _løgg, فٹوئ, 
   {{0x6d580521,0xdd94005e,0x7c240f91,0xe7e000d1}},	//   _umua, _жасы, _škre, _ﺋﻪﺭﻟ, 
   {{0xd04c02a8,0xab856c20,0x6b4c00b5,0xdc0801f7}},	//   rgaɗ, _дужк, _røgf, _وقفو_, 
   {{0xdb200109,0x00000000,0x00000000,0x00000000}},	//   ôtôn, --, --, --, 
   {{0xd1f80b82,0x43c000d1,0x00000000,0x00000000}},	//   ገባብ_, ﯩﺸﯩﺪ, --, --, 
   {{0xea9c0055,0xf9f8011a,0x00000000,0x00000000}},	//   _arṇo_, _להעמ, --, --, 
   {{0x68f8401f,0x00000000,0x00000000,0x00000000}},	//   mfud, --, --, --, 
   {{0x6b4c03b2,0x77b80375,0x957c033f,0xc3300014}},	//   _døgg, _המסח, trąc, رٕز_, 
   {{0x68f80e14,0x41296c21,0xe73401af,0x84800023}},	//   ofud, бово_, _геҙ_, _ሓድሽን_, 
   {{0x6b4c03d4,0x68f96c22,0xa3b401ad,0x0578007b}},	//   _høgd, nfud, _जंप_, _دمعة_, 
   {{0x68f80810,0xa3b0000d,0x00000000,0x00000000}},	// [25a60] ifud, _ओढि_, --, --, 
   {{0xfe700058,0x68f8020b,0xe7f032ed,0x82340a0a}},	//   ىدا_, hfud, _आमना_, _فرجا, 
   {{0x9f400421,0xa3e8098a,0xfe400799,0x73380375}},	//   tuiâ_, मूर_, رکسی, _העיס, 
   {{0x68f801fa,0x6b4c022c,0x66000100,0xfc2800ee}},	//   jfud, _løgd, _mpnk, йжек_, 
   {{0x2bcc0764,0x716405f5,0x7c240010,0x68f80009}},	//   _सौदा, _хаяг_, _škrb, dfud, 
   {{0x60c40953,0x6b4d4e5f,0x6be01df2,0x68f804ba}},	//   lbim, _nøgd, ركىم, efud, 
   {{0x60c40083,0x195802dd,0x68f96c23,0x00000000}},	//   obim, жайы_, ffud, --, 
   {{0x23dc69af,0x6cf4010a,0xf1bc00d7,0x00000000}},	//   _बिंद, _несĕ, ýšie_, --, 
   {{0xebe00b7f,0xdb00037e,0x4d14074d,0x60c40037}},	//   _потп, _rumæ, _юьрт, ibim, 
   {{0x95d803b7,0x68f804ba,0xb0580ade,0x6b600022}},	//   одот_, afud, _geäu, _зкуа, 
   {{0x64416c24,0x95280327,0xc0c00023,0x00000000}},	//   ømin, ཥྐའི_, ትራስ_, --, 
   {{0xc8b41b12,0xaa480150,0x18680131,0x60c40477}},	//   _قلمک, _اسكە_, _һаҗи_, jbim, 
   {{0x9f4000eb,0x79816c25,0x628805d5,0xa3e8197c}},	//   ntió_, _ikow, üdon, मूल_, 
   {{0xd5b80882,0xa3a41677,0x6b4c06ea,0x60c56c26}},	//   tvād_, ејск, _vøgg, ebim, 
   {{0x7980f9c5,0x9f400561,0xa2a00243,0xe73400ea}},	//   _kkow, crié_, _गृद्, _хеј_, 
   {{0xeabc0208,0xde4c0092,0xa158187f,0x00000000}},	//   _đùm_, _በሚያገ, пасу_, --, 
   {{0x6b4c05ac,0xe81c07af,0xb4440139,0x5334004e}},	// [25a70] _høge, बिया_, _хэйк, _жепт, 
   {{0x2bcc13b4,0xeea802d5,0x60c404ba,0xf2c43be4}},	//   सीफा, стак_, abim, _эсин, 
   {{0x60c56c27,0x8cf402d5,0x79800ca8,0xc1b001af}},	//   bbim, дзец, _okow, _аҙсы, 
   {{0x798001f2,0x3f980ffb,0x6b4c1924,0x644001e3}},	//   _nkow, ampu_, _møge, ämig, 
   {{0xfc440016,0x6b4c005c,0xfbcc00ec,0xa2b400cd}},	//   _đích_, _løge, لڪل_, _आलम्, 
   {{0x79816c28,0x67180037,0xf41c00fe,0xdef86171}},	//   _akow, _भोंक_, _পথাৰ_, _ныс_, 
   {{0xa3b47e29,0x6b4c02ed,0x2fc8c807,0x5f94008e}},	//   _जून_, _nøge, _hwcg_, _чирт, 
   {{0x3a3801e6,0x6b4c022c,0xdb000037,0x68f804ce}},	//   äppa_, _søgd, _aumä, ufud, 
   {{0x3ea80334,0x7c340158,0x2c00013d,0x68f86330}},	//   _ygbt_, øyrt, _чүлм, rfud, 
   {{0x6b4c019b,0x79800428,0x8644119e,0x9f400129}},	//   _bøge, _ekow, днож, trié_, 
   {{0x6ad000bd,0x68f8004c,0x99980790,0xca780244}},	//   _সাপো, pfud, _çrş_, _بڕشت_, 
   {{0x9a8405f5,0x9f402b76,0x6b4c00cc,0x00000000}},	//   _чуул, rrié_, _døge, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9f4007ea,0x6b4c05ac,0x2bcc41ac,0x00000000}},	//   prié_, _høgb, सीया, --, 
   {{0x660001c4,0x999000d0,0x6b4c01bf,0x00000000}},	//   _upnk, ťaťu_, _gøge, --, 
   {{0x9f480241,0x00000000,0x00000000,0x00000000}},	//   _òhún_, --, --, --, 
   {{0x60c56c29,0x6b4c01bf,0xb12c0023,0xd174010b}},	// [25a80] rbim, _møgb, _ተጻዋታ, хыры, 
   {{0x3ccc00d1,0x60c520b0,0xddf80166,0x00000000}},	//   _ﻗﯩﺴﻤ, sbim, зьдә_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe8dc0016,0xedd000b2,0x2bcca88c,0x00000000}},	//   _trộm_, ئيند, _सौहा, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8eb01b56,0x9f416c2a,0x79814eb3,0x926401b9}},	//   _مەكت, rtió_, _skow, _آدیم, 
   {{0x9f400228,0xdb000047,0x2bcc012c,0x00000000}},	//   stió_, _rumä, सीबा, --, 
   {{0xdb000793,0x6b4c037e,0x7c3400cc,0x00000000}},	//   _sumä, _røge, øyrs, --, 
   {{0x6b4c105c,0x2af800af,0x9f400165,0x64400feb}},	//   _søge, ल्हु_, ltiñ_, ømil, 
   {{0xeee80016,0x7bc16c2b,0x96340124,0x00000000}},	//   _đừng_, mpou, еноц, --, 
   {{0x79800589,0x7bc16c2c,0x9f416c2d,0x8a400014}},	//   _tkow, lpou, ntiñ_, _مێون, 
   {{0xf5240139,0x00000000,0x00000000,0x00000000}},	//   ффон, --, --, --, 
   {{0x7bc16c2e,0xdb0c0327,0xa998011a,0xd88800e5}},	//   npou, _གྲོཌ_, _ובאר, _ڈھکن_, 
   {{0xa2a00882,0x9f40e761,0x2038069d,0x00000000}},	//   _गृह्, ktiñ_, _አመራር, --, 
   {{0xe60d41e7,0xf1a56c2f,0x8ecc009e,0x23d00073}},	//   _نشي_, дран, _লালগ, तीबद, 
   {{0x5ec800bd,0x24780521,0x7bc00165,0xb4d800e4}},	//   _লাগে, ọma_, kpou, chàp, 
   {{0x9f400165,0xe01c166d,0xb4e81d68,0x00000000}},	// [25a90] etiñ_, निषद_, मली_, --, 
   {{0xb0580036,0x9f400421,0x6440678b,0xa5300139}},	//   _beär, tuiá_, ämie, _kеşе_, 
   {{0xf41c023a,0x00000000,0x00000000,0x00000000}},	//   lvä_, --, --, --, 
   {{0x429800d9,0x81bc00cc,0x39ac0210,0x00000000}},	//   _מסתב, ুংখ_, _gęsi_, --, 
   {{0x03b4063f,0x765403e3,0x00000000,0x00000000}},	//   _ịṅụr, _əyya, --, --, 
   {{0xceb800c7,0x8a1400d8,0x00000000,0x00000000}},	//   _хәа_, еќич, --, --, 
   {{0x2bcc5b29,0x7bc000c7,0xb0580112,0x9f4003b2}},	//   _सौरा, apou, _geär, mtið_, 
   {{0x9f4005f7,0xf8ac1e4b,0x00000000,0x00000000}},	//   ltið_, مکه_, --, --, 
   {{0xb9000124,0xd90c56a7,0xdcf400e5,0xe81c0b26}},	//   узык, زیو_, _شہوت_, बिधा_, 
   {{0x9f40041e,0xab6001ec,0xdc7400c7,0xdba40092}},	//   ntið_, _جۇتى, _ргуы, ገባውም_, 
   {{0xb15002d3,0x795c02b5,0xa5c0012d,0x00000000}},	//   _መገድታ, kūwh, _ogół, --, 
   {{0x92c003f4,0x69c16c30,0x628801b8,0x00000000}},	//   ুলো_, mpne, üdom, --, 
   {{0xf99005e1,0x69c056ce,0x39580036,0x9f401d0e}},	//   _ערד_, lpne, ëpse_, ktið_, 
   {{0xe51c0037,0x00000000,0x00000000,0x00000000}},	//   _फफकि_, --, --, --, 
   {{0x7bc00118,0x41295099,0xb6a00354,0xa14800e5}},	//   zpou, пово_, _йишл, وسرے_, 
   {{0x69c0713c,0x23b400a2,0x00000000,0x00000000}},	//   ipne, _täj_, --, --, 
   {{0x9f402880,0x69c00354,0x490000dc,0xafe03eeb}},	// [25aa0] ftið_, hpne, व्यो_, лотл, 
   {{0x7f84c947,0xef140075,0xf4540375,0x9f40032e}},	//   رلان, нму_, _נייר_, gtið_, 
   {{0x9f400165,0x00000000,0x00000000,0x00000000}},	//   utiñ_, --, --, --, 
   {{0x9abc0003,0x9f416c31,0x00000000,0x00000000}},	//   _inċi, rtiñ_, --, --, 
   {{0x61fd6c32,0x69c00072,0x9f400489,0x6ed80116}},	//   ltrl, epne, stiñ_, زدەڭ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfce42add,0x7bc009b9,0x61fd6c33,0xee040139}},	//   _пово, spou, ntrl, _перл_, 
   {{0xeee80016,0xf41c02f6,0xada000c7,0xfaa40107}},	//   _đứng_, yvä_, _басл, _ҷазо, 
   {{0xb86400cf,0x69c16c34,0x5ba401e0,0xfaf002cb}},	//   عابو, apne, _алағ, _مثا_, 
   {{0x0ba825aa,0xfaa43d2a,0x61fc01a9,0xf5e401ec}},	//   _قالى_, _зазо, ktrl, німм, 
   {{0xaba40150,0x00000000,0x00000000,0x00000000}},	//   _ﺷﻮﻣﺎ, --, --, --, 
   {{0xb4e82068,0xeabc01fb,0xf99012fd,0x9f40003a}},	//   मले_, _đùi_, _صبا_, quiæ_, 
   {{0x6b4c0183,0x9f400008,0x9abc031c,0xf7454526}},	//   _høga, ytið_, _anċi, _педо, 
   {{0x61fc0175,0xe73400c0,0x2a0001e1,0x00000000}},	//   ftrl, _печ_, _òṣùp, --, 
   {{0x795c02b1,0x00000000,0x00000000,0x00000000}},	//   tūwh, --, --, --, 
   {{0xfc440016,0xf8b0033f,0x9f3402dd,0x8ecc00eb}},	//   _đính_, ीडिय, ңеті, _লাইগ, 
   {{0xb4bc1ab2,0x9abc0003,0x9f4009f3,0xdb08003a}},	// [25ab0] ेरी_, _enċi, ttið_, _vidê, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9f4008a7,0xb05801b8,0x795c02b5,0x4fc000db}},	//   rtið_, _ofäg, pūwh, _چەرە, 
   {{0x918004a9,0x9f4009f3,0xabb0013d,0x00000000}},	//   _ئۇرۇ, stið_, гадә, --, 
   {{0x81d402f5,0x9f400252,0x00000000,0x00000000}},	//   _সময_, ptið_, --, --, 
   {{0xb058b1e1,0x6b4c0feb,0xefbc0092,0x35980092}},	//   _pfäf, _bøga, ትኛው_, ቀሙበት_, 
   {{0x5c74005e,0x69c0002f,0xa2b4e459,0x00000000}},	//   _ұлтт, upne, _आलस्, --, 
   {{0xdb08033b,0xf2bc07d0,0x00000000,0x00000000}},	//   _lidè, ्रुघ, --, --, 
   {{0x7af001d3,0xf8ac00f2,0xb60000e4,0x00000000}},	//   újtá, زکن_, ñánt, --, 
   {{0x6d480077,0x00000000,0x00000000,0x00000000}},	//   lkga, --, --, --, 
   {{0x6b816c35,0x6d480770,0x09d404c5,0x7afc004e}},	//   mong, okga, সংহা, òpte, 
   {{0x6b809024,0x96956c36,0x04440166,0x00000000}},	//   long, ырыш, вемн, --, 
   {{0x83656c37,0x6b816c38,0xca9801ec,0x00000000}},	//   ندسل, oong, _ﺘﻭﺠﻪ_, --, 
   {{0xfbc42ecf,0x81d40154,0x99740213,0x37e001b9}},	//   रीटम, _সমব_, _kəşf_, _тошг, 
   {{0xdb096c39,0x6b816c3a,0x6d4803cd,0x00000000}},	//   _didè, iong, kkga, --, 
   {{0x6d4801f5,0x9f400108,0x00000000,0x00000000}},	//   jkga, ntiö_, --, --, 
   {{0x61fd6c3b,0x6b816c3c,0xdb096c3d,0x4ad0ad78}},	// [25ac0] strl, kong, _fidè, हराव, 
   {{0x6b801992,0x03a56c3e,0x6d480369,0x39ac000f}},	//   jong, _шипо, ekga, _kęst_, 
   {{0xf2d01203,0xf5742418,0x9f40003a,0x5ba400fb}},	//   _דעת_, _سمیع_, triâ_, ңлеғ, 
   {{0xbc696c3f,0xbca56c40,0xdb000e38,0x39ac002d}},	//   ومان_, نماي, _humø, _męst_, 
   {{0x6b8008f5,0x6b4d6c41,0x39ac045f,0xdb0801e7}},	//   fong, _søga, _lęst_, _hidé, 
   {{0xeaad6c42,0x6b816c43,0x4420013c,0xf4100375}},	//   يعى_, gong, ivk_, יפד_, 
   {{0xae416c44,0x6564022f,0x39ac002d,0xa3b4012d}},	//   _پھلو, _omih, _nęst_, _जूस_, 
   {{0x6d489c50,0x6b816c45,0xeab56c46,0x4420020c}},	//   ckga, aong, нйә_, kvk_, 
   {{0x6b816c47,0x00000000,0x00000000,0x00000000}},	//   bong, --, --, --, 
   {{0x65656c48,0x7c216c49,0x6b4c0579,0x39ac000f}},	//   _amih, mvor, _høgn, _bęst_, 
   {{0xdb080ba1,0x94d43542,0xd7f80107,0xe9a40372}},	//   _ridè, лонц, фуқ_, رگۅن_, 
   {{0xb4bc4614,0x7d016c4a,0xdb08033b,0x4420007f}},	//   ेरे_, nfos, _sidè, fvk_, 
   {{0x7c216c4b,0xdb08004a,0x753c0139,0x2934010f}},	//   nvor, _aidé, _voqz, _שאדן_, 
   {{0x65656c4c,0x6b4c7779,0x91c439c7,0x39ac000f}},	//   _emih, _løgn, ләмл, _fęst_, 
   {{0xdb08180f,0x7c216c4d,0x7c246b48,0x31700107}},	//   _vidè, hvor, _škrl, иғот, 
   {{0x6b816c4e,0x7c216c4f,0xdb088616,0xf8d00307}},	//   zong, kvor, _didé, सरिय, 
   {{0x6b803182,0x7d0003cd,0x7a0803b9,0x2484002f}},	// [25ad0] yong, dfos, _hətd, ümmt_, 
   {{0x7c2070b1,0xdb096c50,0xf3fc0004,0x6b816c51}},	//   dvor, _fidé, mtã_, xong, 
   {{0x6b816c52,0xdb08011f,0x7d016c53,0x7c216c54}},	//   vong, _gidé, ffos, evor, 
   {{0x7c216c55,0x9f4000d8,0xa3e801ad,0x15c80150}},	//   fvor, triã_, मंच_, _ﺒﺈﺤﺩ, 
   {{0x6b816c56,0xf3fd6c57,0x7c216c58,0x6d48017a}},	//   tong, ntã_, gvor, rkga, 
   {{0x9f400589,0xf09c01e1,0x8ec801d9,0x6b80009f}},	//   rriã_, _gbàa_, _سِرٕ_, uong, 
   {{0x2d8407ea,0x7c200869,0x6b816c59,0x9f40023a}},	//   înes_, avor, rong, ttiö_, 
   {{0xdd980873,0x6b816c5a,0x18b0052f,0x39ac000f}},	//   _ашу_, song, ҙҙәр, _ręst_, 
   {{0x7c200115,0x7e6001e4,0x8cc8024a,0xb4bc00bc}},	//   cvor, ĝope, _ह्यो, ेरै_, 
   {{0x6b806f7a,0xaa656c5b,0x9af4113e,0x7ac80073}},	//   qong, _итек, _ەكەت, _स्पॅ, 
   {{0xf3fc0589,0x6b4c0158,0xb0d000cd,0x00000000}},	//   etã_, _høgo, तराग, --, 
   {{0xdb08a573,0x45340828,0x49a40150,0x00000000}},	//   _ridé, ухот, _сызғ, --, 
   {{0x2d8c06d5,0x6f04070d,0xdb0806af,0x00000000}},	//   ilge_, _objc, _sidé, --, 
   {{0x291c01c0,0x27fc594a,0xb7d8011a,0x00000000}},	//   ldua_, mtun_, _טקני, --, 
   {{0x7c216c5c,0x27fc022f,0xc0e56c5d,0xf3fc00c7}},	//   zvor, ltun_, ловк, atã_, 
   {{0xdb096c5e,0x291d6c5f,0x2508694d,0x65656c60}},	//   _vidé, ndua_, _شرعی_, _umih, 
   {{0xdb0800e8,0xdf6400c7,0x7c20002f,0x00000000}},	// [25ae0] _widé, анаҩ, xvor, --, 
   {{0x6b4c019b,0x3ea46f63,0x42c80364,0x291c0098}},	//   _søgn, гизг, _ягон_, hdua_, 
   {{0x9f40eacd,0x7d001cea,0x39980240,0x291c0115}},	//   rrià_, tfos, lëse_, kdua_, 
   {{0xed5524ce,0x7c216c61,0x27fd6c62,0x2b480356}},	//   лох_, tvor, ktun_, _îccj_, 
   {{0x27fc0003,0x399802d3,0x9f412972,0x2bcc012c}},	//   jtun_, nëse_, ariá_, सीला, 
   {{0x20016c63,0x27fd6c64,0x7d000217,0x2d8407ea}},	//   mtii_, dtun_, sfos, îner_, 
   {{0x7c216c65,0x20016c66,0x7d0001e3,0x39996c67}},	//   svor, ltii_, pfos, hëse_, 
   {{0x2000198f,0x6b4cb5a3,0x39980240,0x0d98013d}},	//   otii_, _høgl, këse_, _атуы_, 
   {{0x20016c68,0xed540447,0x27fc2819,0x17540395}},	//   ntii_, _сот_, gtun_, ивия, 
   {{0x2000198f,0x291c0098,0xdc1c00e2,0xb4bc215d}},	//   itii_, adua_, _eņģe, ेर्_, 
   {{0x55744f13,0x6440049b,0x27fd6c69,0xeb301e87}},	//   игот, ämin, atun_, _دىلد, 
   {{0x2000198f,0x6b4c03b2,0xdcfc013d,0x7824009f}},	//   ktii_, _løgl, _kurı, _معتل, 
   {{0x76596c6a,0x7c240010,0x3998036e,0x2120031c}},	//   szty, _škrj, gëse_, ddih_, 
   {{0x6b4c04ce,0xf3fc0004,0xb35403e6,0x27e800d0}},	//   _nøgl, rtã_, ایدا_, ácne_, 
   {{0xf3fd6c6b,0x20016c6c,0x2d8c0b21,0x00000000}},	//   stã_, etii_, ylge_, --, 
   {{0x200036c6,0xf3643ad0,0xe3b0678e,0x00000000}},	//   ftii_, _әтин, _کري_, --, 
   {{0x200001d9,0xb9d4001f,0xa5100327,0xdcfc0166}},	// [25af0] gtii_, _ጽጌ_, _ཏྲིག_, _nurı, 
   {{0x7a080cc1,0x2bcc1715,0x9f40067c,0x00000000}},	//   _mətb, _सौगा, triá_, --, 
   {{0xc33030fb,0x20016c6d,0x27fc01c6,0x21200548}},	//   _ווי_, atii_, ztun_, bdih_, 
   {{0x200001d9,0xdcfc0724,0x7af803ac,0x27fc0429}},	//   btii_, _burı, _actt, ytun_, 
   {{0x2000084c,0x00000000,0x00000000,0x00000000}},	//   ctii_, --, --, --, 
   {{0x6b4c01bf,0x8ba4009d,0x00000000,0x00000000}},	//   _gøgl, шилж, --, --, 
   {{0x7af8022f,0x27fc0198,0x39980240,0x7afc067c}},	//   _dctt, wtun_, zëse_, òpta, 
   {{0x27fd6c6e,0xa87405f5,0x27b0151e,0x00000000}},	//   ttun_, лөлт_, бәкс, --, 
   {{0x3a700cef,0x6b4c4606,0x00000000,0x00000000}},	//   йләр, _høgm, --, --, 
   {{0xab856c6f,0xf3f8015b,0x6a1549d4,0xa9a001d5}},	//   _субк, ইবার_, _مبصر, шиқд, 
   {{0x27fd6c70,0xdb0805da,0x2120011f,0xda0800f1}},	//   stun_, _midì, ydih_, _ميله_, 
   {{0x27fd6c71,0x399802d3,0x290c02fb,0x65c00220}},	//   ptun_, tëse_, ínač_, _құма, 
   {{0x99840597,0x6b4c0579,0x27fc0357,0x212009a8}},	//   _النو, _løgm, qtun_, vdih_, 
   {{0xb9dd6c72,0x399802d3,0x46a40305,0x98c401af}},	//   _ኣብ_, rëse_, _калв, _ксәл, 
   {{0x3999561d,0x29d00262,0xc5d410f5,0x82a402bf}},	//   sëse_, nţa_, _тіль, равж, 
   {{0x200022a9,0xc4f8143e,0x764c05ac,0x3998036e}},	//   ttii_, _شعبا_, øbye, pëse_, 
   {{0xd409353b,0x39980023,0x2120011f,0x20011608}},	// [25b00] _یتیم_, qëse_, rdih_, utii_, 
   {{0x2000331b,0xc0cc044e,0x30240124,0xc1acb071}},	//   rtii_, _ኣዳም_, шоуп_, _ﺳﺎﺩﺍ, 
   {{0xf3f00ad3,0x20016c73,0xd00417de,0xf484030f}},	//   _བཀོད_, stii_, _қорқ, _مایی, 
   {{0x20009fda,0x21200548,0x9abc0135,0xe5c801ec}},	//   ptii_, qdih_, _maċe, _ﺒﺈﻤﻜ, 
   {{0xdb080109,0x2000011f,0xdcfc013d,0xad840137}},	//   _fidì, qtii_, _qurı, جالۇ, 
   {{0xbfe000c7,0xbe140214,0x3ebc03e3,0x833400df}},	//   _гәҧҩ, _پورع, _ütt_, שאַס_, 
   {{0x12e800c8,0x39900023,0x9f400393,0xee34064d}},	//   אַפּ, _ምህርቲ_, triæ_, _кнр_, 
   {{0xdcfc1248,0x8e7400d8,0x00000000,0x00000000}},	//   _turı, _ѓурч, --, --, 
   {{0x7af8074d,0x29d00276,0x31540115,0x00000000}},	//   _tctt, aţa_, ייקן_, --, 
   {{0x9abc031c,0x957c033f,0x6e44005c,0xab6012e7}},	//   _baċe, zsąd, _ørbæ, _двул, 
   {{0x59d401b9,0x00000000,0x00000000,0x00000000}},	//   _چغچر, --, --, --, 
   {{0x56956c74,0x7a0803be,0x00000000,0x00000000}},	//   _қайт, _tətb, --, --, 
   {{0xf60807d6,0xb4b41b51,0x00000000,0x00000000}},	//   رتگه_, _जली_, --, --, 
   {{0x28980677,0xc1ac08b0,0x00000000,0x00000000}},	//   _סיגא, _ﺳﺎﺭﺍ, --, --, 
   {{0xdb0801e1,0x9f4001f4,0x00000000,0x00000000}},	//   _ridì, iriä_, --, --, 
   {{0x21790781,0xe4d80014,0xc0c00116,0xd48801c6}},	//   айсы_, _پوٝت_, зәри, _бөгж_, 
   {{0x90996c75,0x229c0241,0xa0b8009d,0x00000000}},	// [25b10] уват_, _pákí_, ргуу_, --, 
   {{0xdb00060a,0xbf0005d7,0x00000000,0x00000000}},	//   _cumü, र्लभ_, --, --, 
   {{0xdb0819f5,0xf1a80133,0xdcfc00ef,0xeea80022}},	//   _vidì, _لاحه_, _jurķ, ттак_, 
   {{0xdd98747c,0x9f400108,0x00000000,0x00000000}},	//   ашч_, eriä_, --, --, 
   {{0x0738313e,0x7e6001e4,0x5fe401ec,0x00000000}},	//   _ﮔﺎﯞ_, ĝopa, _мірж, --, 
   {{0x3ec4023b,0xc60c009e,0xc8780356,0x5f956c76}},	//   _гиёҳ, ষিতা_, naşe_, _мият, 
   {{0x6b4c00cc,0x28b80037,0x00000000,0x00000000}},	//   _høgk, _उलदि, --, --, 
   {{0x29d00276,0x6200010b,0xbd340117,0x00000000}},	//   rţa_, _çylş, _гӯшу_, --, 
   {{0x9f4400d8,0x9abc0003,0xaae40244,0x00000000}},	//   _ímã_, _saċe, _نساو, --, 
   {{0xdb00002e,0x33300077,0x9abc0135,0x6b4c75f9}},	//   _dumó, _nnxx_, _paċe, _møgk, 
   {{0x07086b1e,0x442d44c3,0x2d9c0051,0x00000000}},	//   نيکي_, _ōf_, _khue_, --, 
   {{0x05542dc1,0x81d40183,0x00000000,0x00000000}},	//   стоя, _সমল_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc8780356,0x61e802f0,0x972408de,0x00000000}},	//   gaşe_, ádlo, _وفنو, --, 
   {{0xdcfc00e2,0x7a0803b9,0xe81c6c5a,0x39980200}},	//   _gurķ, _kəta, बिका_, lësa_, 
   {{0xf5e40137,0x46a4008e,0x38c40118,0x64400162}},	//   _اتوۋ, _каһв, pírů_, ømis, 
   {{0x44256c77,0x9f400716,0x7a0803e3,0x00000000}},	// [25b20] _éo_, yriä_, _məta, --, 
   {{0xf0a56c78,0x9f58d95c,0xc8780356,0xa068329e}},	//   скул_, _üzüm_, caşe_, гаға_, 
   {{0xfde801d5,0x7d240014,0x00000000,0x00000000}},	//   удек_, ٝفان, --, --, 
   {{0xdb080232,0x2d9c0354,0xb5f800c8,0x0d9843be}},	//   _vidí, _chue_, טלעכ, атчы_, 
   {{0x9f4002f6,0x25a001ab,0x1ab466c1,0x06f81fd2}},	//   triä_, _mhil_, обля, ्भाव_, 
   {{0xe730013f,0xe8fc0086,0x33300208,0x3ea4022e}},	//   _nnε_, òûn_, _xnxx_, _гигг, 
   {{0x6b4c01bf,0x00000000,0x00000000,0x00000000}},	//   _møgh, --, --, --, 
   {{0xa3d86c08,0x2bc4d73a,0xb4b44de3,0xfaf801e2}},	//   ाठा_, шләп_, _जले_, _څراغ_, 
   {{0x6da16c79,0xada16c7a,0xa3b4216a,0x2c08179e}},	//   _хита, _хатл, _जंग_, _معلی_, 
   {{0x25a00c54,0xb0580036,0x1a7401ec,0x27e80419}},	//   _ahil_, _ofän, _құқы_, ácna_, 
   {{0x7a0806be,0x15141f39,0x00000000,0x00000000}},	//   _fəta, одня, --, --, 
   {{0x25a11eb2,0x00000000,0x00000000,0x00000000}},	//   _chil_, --, --, --, 
   {{0x25a16c7b,0xdb000113,0xb05801c7,0x00000000}},	//   _dhil_, _humñ, _afän, --, 
   {{0x39440050,0xf53c2d8b,0x9f4000d8,0x25a003e0}},	//   _hoos_, sjå_, ssiê_, _ehil_, 
   {{0x39456c7c,0x9f40017a,0xc8780356,0xc0d40092}},	//   _koos_, asië_, raşe_, _ይሄም_, 
   {{0x4fd407d6,0x39456c7d,0x25a16c7e,0x7a0800ac}},	//   жжат, _joos_, _ghil_, _xəta, 
   {{0x3944d72f,0x2d9c0076,0x9f0401e2,0x00000000}},	// [25b30] _moos_, _rhue_, ړولو, --, 
   {{0xb8d8031c,0x9ed8005b,0x2898010f,0x00000000}},	//   _ཙུ_, ймут_, רימא, --, 
   {{0x1da40073,0x62880210,0x00000000,0x00000000}},	//   _ओळखत, żdor, --, --, 
   {{0x394400e8,0xca4801d5,0x2cb801a9,0x00000000}},	//   _noos_, یلشه_, оqda_, --, 
   {{0x2d9c0943,0x6b4c0174,0x00000000,0x00000000}},	//   _vhue_, _høgi, --, --, 
   {{0xdea4183b,0x00000000,0x00000000,0x00000000}},	//   _کیمی, --, --, --, 
   {{0x39456c7f,0xdb080137,0x2d9c001e,0xf8ac04d3}},	//   _boos_, _didà, _thue_, ۆکه_, 
   {{0x39456c80,0x47c43f67,0xf8ac03e6,0x389c0ca8}},	//   _coos_, обив, چکه_, _ọran_, 
   {{0xf8ac55bd,0x39456c81,0x6b4c022c,0x1ad80183}},	//   نکه_, _doos_, _løgi, _সাৰা, 
   {{0x06096c82,0xdb0805d5,0x25a16c83,0x3944003a}},	//   анок_, _gidà, _shil_, _eoos_, 
   {{0x39456c84,0x27840228,0x3a3801e6,0x25a0011a}},	//   _foos_, ирүү_, äppt_, _phil_, 
   {{0x39440014,0x957c0024,0xd7c800ec,0x25f801f9}},	//   _goos_, drąs, _ڇونه_, लंबी_, 
   {{0xd7c80272,0x68f96c85,0x9b9400cf,0x88a001e0}},	//   _هونه_, mgud, _بلەت, _юғиһ, 
   {{0x7a0803be,0xe1f8013e,0xb0580e78,0x9f400af9}},	//   _mətn, бҳо_, _pfän, rsië_, 
   {{0x672006d9,0x3944022f,0x6f140f85,0xdb08013a}},	//   _ianj, _yoos_, dexc, _jidá, 
   {{0x67216c86,0x24800457,0x3944002e,0x00c96c87}},	//   _hanj, _txim_, _xoos_, рлак_, 
   {{0x67200aa5,0x68f8067c,0x3940005b,0x42e80139}},	// [25b40] _kanj, igud, öksi_, _кмпо_, 
   {{0xfe705845,0x67207f0b,0x00000000,0x00000000}},	//   ودا_, _janj, --, --, 
   {{0xb0580a40,0x3eac17da,0x00000000,0x00000000}},	//   _ufän, äft_, --, --, 
   {{0x67216c88,0x2600056a,0x568c008f,0x7a0803e3}},	//   _lanj, iño_, נטאַ, _bətn, 
   {{0x39456c89,0x67200b21,0x68f86243,0x200400e4}},	//   _roos_, _oanj, dgud, _ëmi_, 
   {{0x39449546,0x60c41050,0xf9c40212,0xb4b4023e}},	//   _soos_, lcim, ощин, _जल्_, 
   {{0x39456c8a,0xaee00882,0x26000882,0xdcfc01e4}},	//   _poos_, saṃg, jño_, _surĵ, 
   {{0xdb089312,0x39440180,0x67216c8b,0x68f8fa69}},	//   _didá, _qoos_, _aanj, ggud, 
   {{0x67216c8c,0x39456c8d,0x60c4007b,0x26002cf4}},	//   _banj, _voos_, icim, eño_, 
   {{0x67216c8e,0x68f96c8f,0x3944039a,0x3a3801e6}},	//   _canj, agud, _woos_, äpps_, 
   {{0x67216c90,0x39448c8a,0xb05801c7,0x00000000}},	//   _danj, _toos_, _afäl, --, 
   {{0x60c405ce,0x67203f27,0xe7f00490,0x35680e4e}},	//   jcim, _eanj, _आमचा_, ррон_, 
   {{0x67216c91,0xa3d407d6,0x26016c92,0x60c40841}},	//   _fanj, мояч, año_, dcim, 
   {{0x60c406ed,0x29b400db,0x00000000,0x00000000}},	//   ecim, _اجەڭ, --, --, 
   {{0xc8796c93,0x9f4000c6,0x777801d4,0xe3b003e6}},	//   maşa_, briú_, mntx, کرێ_, 
   {{0xc0e40020,0x60c40356,0x7e6001e4,0xc878a75a}},	//   _ሜትር_, gcim, ĝopl, laşa_, 
   {{0x67200bd5,0x338402f4,0x6f144ed7,0xb0580036}},	// [25b50] _yanj, _муов, texc, _gfäl, 
   {{0x6b4c05ac,0x67207708,0x60c46473,0x00000000}},	//   _høgv, _xanj, acim, --, 
   {{0x777801c6,0xa3b407f7,0x9294009d,0x68f80bbc}},	//   intx, _जूट_, _ханц, ygud, 
   {{0x60c56c94,0x2d54013d,0x71080354,0xaee000cd}},	//   ccim, _eçen_, _тхов_, daṅg, 
   {{0x9f410983,0x7a0800ac,0x68f80158,0x6f140175}},	//   guió_, _qətn, vgud, pexc, 
   {{0xf09c0109,0x77780218,0xac8402d3,0xdef802dd}},	//   _izà_, jntx, _ንዓለም_, _мыс_, 
   {{0x7c24adbb,0x30bc015b,0xc8780342,0x68f96c95}},	//   _škrt, েণীস, daşa_, tgud, 
   {{0x627c05e1,0x777801c0,0xdb0801ed,0xad240214}},	//   ינונ, entx, _vidá, _برآو, 
   {{0x67216c96,0x6d596c97,0x68f96c98,0xa3b4033f}},	//   _panj, _ilua, rgud, _जूझ_, 
   {{0x6d580190,0x66ec0134,0xa5e40032,0x67216c99}},	//   _hlua, _kɔkɔ, олоҡ_, _qanj, 
   {{0x67216c9a,0x6d582ebc,0xf53c0267,0x9f40007b}},	//   _vanj, _klua, rmån_, triú_, 
   {{0x6720151f,0xf09c0109,0xb0580112,0x7a0803e3}},	//   _wanj, _ozà_, _pfäl, _mətl, 
   {{0x67216c9b,0x60c4098d,0x6d580218,0x777801d4}},	//   _tanj, vcim, _mlua, bntx, 
   {{0xd8744e74,0x6d580194,0x68e80036,0x672002d0}},	//   _تامب, _llua, _hdgd, _uanj, 
   {{0x60c404a7,0x6d580083,0x06a8015b,0x00000000}},	//   tcim, _olua, _খ্রি, --, 
   {{0x290c2630,0x84596c9c,0xf53d4ad4,0xc76400cf}},	//   _jbga_, _грот_, nmål_, _باچى, 
   {{0xfeb8b94d,0xb05801c7,0x6b4c06ea,0x00000000}},	// [25b60] ماات_, _ufäl, _høgu, --, 
   {{0x6d596c9d,0xc2e805d3,0xdb0001e6,0xb4d80109}},	//   _alua, _اعظم_, _humö, njàn, 
   {{0x60c4098d,0x6d596c9e,0xf53c0183,0xdcb00131}},	//   pcim, _blua, kmål_, ھىت_, 
   {{0x6b4c1125,0x6d587ea1,0xeee8001e,0x41740150}},	//   _møgu, _clua, _đụng_, _ءادس, 
   {{0x6d596c9f,0xf53d6ca0,0x6b4c86ee,0x6ad000cc}},	//   _dlua, dmål_, _løgu, _সাজো, 
   {{0x6d5800af,0x39980200,0x00000000,0x00000000}},	//   _elua, tëso_, --, --, 
   {{0x6d596ca1,0xc8781432,0x2d54013d,0xf96806dc}},	//   _flua, vaşa_, _kçel_, йрий_, 
   {{0x6d581549,0xdb0001b8,0x7b6401d9,0xf53c2611}},	//   _glua, _numö, _کارٕ, gmål_, 
   {{0xaee00882,0x6b4c01bf,0x00000000,0x00000000}},	//   saṅg, _røgv, --, --, 
   {{0x6b4c03b2,0x23a40267,0xec101c62,0x9f400156}},	//   _bøgu, nöjd_, _سومد, ouiñ_, 
   {{0x7a080213,0x80e00154,0xd9f01bbb,0x80a400eb}},	//   _xətl, _ফান্, _घटित_, গুচ্, 
   {{0x6b4c0579,0xdb0005d5,0x23a40267,0xaa38030d}},	//   _døgu, _cumö, höjd_, _ыйхă_, 
   {{0xe4a4577e,0xb9c81772,0x498800f7,0x9f400489}},	//   ерро, _ሳሙ_, _بئلپ_, huiñ_, 
   {{0xda200574,0x2fc805be,0x6b4c0162,0xa5240327}},	//   _मनात_, _rtcg_, _føgu, འཇུག_, 
   {{0x62356ca2,0xa7980a1e,0xed5c00d7,0x00000000}},	//   неру, _השגח, úžka_, --, 
   {{0x6b4c03d4,0x9f400489,0xdb080139,0x6678011a}},	//   _høgt, duiñ_, _hidä, _לטוק, 
   {{0x93c801d9,0xa1845290,0x00000000,0x00000000}},	// [25b70] _بابہ_, хырл, --, --, 
   {{0x6d584695,0x9f400165,0xb3840133,0x00000000}},	//   _slua, fuiñ_, _رێزم_, --, 
   {{0x6d596ca3,0x7a0803be,0xe0d000dd,0xf41c0139}},	//   _plua, _qətl, ئزہ_, lwä_, 
   {{0x6b4c1125,0xcc996ca4,0xe3b001e2,0x00000000}},	//   _løgt, овец_, _لرۍ_, --, 
   {{0x612805f5,0x66ec0134,0x6d58036e,0xa4b8011a}},	//   _эцэг_, _wɔkɔ, _vlua, פלגה_, 
   {{0xdb0864d4,0x0f3403e6,0x6b4c005c,0x2b9069f1}},	//   _nidä, _تکرد, _nøgt, ریاس, 
   {{0xc9a8bda8,0xf41000bd,0xf41c0295,0xf53c26cc}},	//   овке_, িটির_, hwä_, tmål_, 
   {{0x6d596ca5,0xdd94c583,0x25740ca8,0x61e80174}},	//   _ulua, _засы, _múlè_, ádli, 
   {{0x2d8d3adc,0xf53c39c2,0x6b4c0579,0xdb082045}},	//   moge_, rmål_, _søgu, _bidä, 
   {{0xf53c1a82,0x85e96ca6,0x8b8400cf,0xf4100154}},	//   smål_, одов_, _تەتە_, িটার_, 
   {{0xdb0800a2,0x23a40267,0x00000000,0x00000000}},	//   _didä, nöje_, --, --, 
   {{0x29c16ca7,0x2d8d6ca8,0x69c00369,0x00000000}},	//   _iña_, noge_, mqne, --, 
   {{0x26c431c3,0xdb080166,0x00000000,0x00000000}},	//   _tfno_, _fidä, --, --, 
   {{0x2d8d6ca9,0xd5b80a28,0xdb08010e,0xc6f4009f}},	//   hoge_, tvāt_, _gidä, _آتشڪ, 
   {{0x6b4d6caa,0xdb016cab,0x3d0ccace,0x2d8c08f0}},	//   _høgs, _tumö, ण्डे_, koge_, 
   {{0x2d8c020c,0x00000000,0x00000000,0x00000000}},	//   joge_, --, --, --, 
   {{0xd8bc0327,0xafe01eca,0x00000000,0x00000000}},	// [25b80] _པུལི, котл, --, --, 
   {{0xef156cac,0x44316cad,0x6b4c353e,0xf70c0208}},	//   мму_, _iry_, _møgs, _lủng_, 
   {{0x443003c6,0x6b4c3c38,0x2d540139,0x23a4007c}},	//   _hry_, _løgs, _eçem_, röjd_, 
   {{0x44300591,0x61fd6cae,0x6be00131,0x00000000}},	//   _kry_, murl, ھكىم, --, 
   {{0x29c16caf,0x9abc003d,0x61fc8dbf,0xac94431a}},	//   _aña_, _faċl, lurl, ونما_, 
   {{0x01080014,0xbf140137,0x9f40030a,0x387002d2}},	//   _اتھو_, _توسب, puiñ_, _þyri_, 
   {{0x61fc3209,0x2d8d6cb0,0x69c00007,0x6b4c01bf}},	//   nurl, boge_, gqne, _røgt, 
   {{0x2d8c04cf,0x443003d1,0x6b4c037e,0x38a001b9}},	//   coge_, _ory_, _søgt, lаri_, 
   {{0xdb0802f6,0xaacc00dc,0x61fc01b9,0xb904012d}},	//   _pidä, _स्वक, hurl, _बज_, 
   {{0x61fd6cb1,0x00000000,0x00000000,0x00000000}},	//   kurl, --, --, --, 
   {{0x44316cb2,0xc5ec00aa,0xf410015b,0x61fd6cb3}},	//   _ary_, مړي_, িয়ার_, jurl, 
   {{0x61fd6cb4,0x4430a2ec,0x00000000,0x00000000}},	//   durl, _bry_, --, --, 
   {{0xed5c01f1,0x798001e1,0x44300c18,0xb7d40014}},	//   úžia_, _ijow, _cry_, _کوڈا_, 
   {{0x2898025f,0x6b4d6cb5,0x78a04e2b,0x61fc01a8}},	//   _וידא, _høgr, _izov, furl, 
   {{0x44316cb6,0xa29400d6,0x61fd6cb7,0x00000000}},	//   _ery_, варі, gurl, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4430068f,0xe57001c8,0x38a0022e,0x257401e1}},	// [25b90] _gry_, _خطو_, fаri_, _wúlè_, 
   {{0x6b4c022c,0x61fc00a2,0xe45400c7,0x13a40133}},	//   _løgr, burl, _ркьы, _سۆزی_, 
   {{0x2d8c18c6,0xa2b00073,0x00000000,0x00000000}},	//   toge_, ंधण्, --, --, 
   {{0xe510001e,0x78a04e2b,0x798000f2,0xe6d96cb8}},	//   _lặng_, _ozov, _njow, _मज्ज, 
   {{0x2d8d6cb9,0x78a00223,0x0c7404fb,0x539400b7}},	//   roge_, _nzov, رگرد, _መቅደስ_, 
   {{0xe5100016,0x79808024,0xf70c01fb,0x39980023}},	//   _nặng_, _ajow, _sủng_, lësh_, 
   {{0x2d8c073c,0x78a16cba,0x6b4c02ed,0xb058002f}},	//   poge_, _azov, _bøgr, _sfäh, 
   {{0x39980240,0x310c00dc,0x78a002f0,0x2d8405c7}},	//   nësh_, ाभिः_, _bzov, éned_, 
   {{0x79800214,0x61fd6cbb,0x7ac80073,0x5c04030d}},	//   _djow, zurl, _स्कॅ, _аяха, 
   {{0x78a00564,0x61fd6cbc,0x44316cbd,0x399802d3}},	//   _dzov, yurl, _rry_, hësh_, 
   {{0x44316cbe,0x78a00117,0x29c16cbf,0x39980023}},	//   _sry_, _ezov, _uña_, kësh_, 
   {{0x61fc01d5,0x44316cc0,0x3998036e,0x39580036}},	//   vurl, _pry_, jësh_, ëpst_, 
   {{0x44300334,0x3998036e,0x00000000,0x00000000}},	//   _qry_, dësh_, --, --, 
   {{0x44300660,0xfbd000d9,0xe5100051,0x00000000}},	//   _vry_, רתם_, _gặng_, --, 
   {{0xc0f80020,0x39980200,0x9f440241,0x00000000}},	//   _ዋኢማ_, fësh_, _ìmé_, --, 
   {{0x6440db6d,0x61fd109f,0x44316cc1,0xb0580793}},	//   ämis, rurl, _try_, _ogäd, 
   {{0x61fd416b,0x4430ec0a,0x565402d3,0x57cc008f}},	// [25ba0] surl, _ury_, _ዝመደበ, ַמאַ, 
   {{0x7a0803e3,0x00000000,0x00000000,0x00000000}},	//   _fəth, --, --, --, 
   {{0x61fc9169,0xc0e400d1,0x1cb80327,0x39980200}},	//   qurl, _понк, _ཛུང_, bësh_, 
   {{0xedd16cc2,0xc0240150,0x3998036e,0x38a0022e}},	//   ايند, _كىجي, cësh_, sаri_, 
   {{0x6b4c12e8,0x50b47c3f,0x24c400cc,0x957c0153}},	//   _røgr, _асру, _্যাহ, fsąj, 
   {{0x8eb01e87,0x39980023,0x38a001a9,0x00000000}},	//   _چەكت, mësi_, qаri_, --, 
   {{0x39980023,0x78a001d3,0xe5100208,0xaa916cc3}},	//   lësi_, _szov, _rặng_, лишч, 
   {{0x44206368,0x00000000,0x00000000,0x00000000}},	//   kwk_, --, --, --, 
   {{0x7d00014b,0x39980023,0x2d84002e,0x7a0803e3}},	//   mgos, nësi_, énee_, _məti, 
   {{0x7c216cc4,0x7d000077,0x999c0024,0x7a080213}},	//   mwor, lgos, tyvų_, _ləti, 
   {{0x1600068f,0x7f4c014f,0x94d44a1d,0x8a4003e6}},	//   लंधर_, _mobq, конц, _نێون, 
   {{0x7d016cc5,0x7a080cc1,0x79800107,0x39980023}},	//   ngos, _nəti, _ujow, kësi_, 
   {{0xe51007ae,0x78a16cc6,0x9f400407,0x3998036e}},	//   _tặng_, _uzov, nrió_, vësh_, 
   {{0xb4b96cc7,0x7f4c014f,0x569400c7,0x91c400d1}},	//   _کاغذ_, _nobq, _иалт, кәмл, 
   {{0x7c216cc8,0xf1a56cc9,0x7d004d11,0x399802d3}},	//   hwor, еран, kgos, tësh_, 
   {{0x44200399,0x7a0806be,0xa19401c6,0xa698011a}},	//   bwk_, _cəti, гасч, _משופ, 
   {{0x39980240,0x44200007,0x7d016cca,0x2fcc0de2}},	// [25bb0] rësh_, cwk_, dgos, ëgg_, 
   {{0x7c204b5a,0x7f4c0218,0x39980023,0xf3fc00d8}},	//   dwor, _cobq, sësh_, lzão_, 
   {{0xf3fc0589,0x7c200af9,0x39980240,0x9f04027d}},	//   luã_, ewor, pësh_, اومو, 
   {{0x7a080cc1,0x9f402760,0xad240f1c,0x7d000429}},	//   _gəti, frió_, عراو, ggos, 
   {{0x7c216ccb,0xf3fc0004,0x7d2800f1,0x00000000}},	//   gwor, nuã_, بينې_, --, 
   {{0x1a6801b9,0xb99000f1,0x00000000,0x00000000}},	//   کیمی_, یلوب, --, --, 
   {{0xdbf80055,0x7d000332,0x2004008e,0x7a0806be}},	//   _bāóh, bgos, _ämir_, _yəti, 
   {{0x7c200354,0x9f416ccc,0xf3fc035b,0x7a0803b9}},	//   bwor, brió_, kuã_, _xəti, 
   {{0x7c207cea,0xfcc00131,0x7f4c0477,0xb7e0010b}},	//   cwor, _тәхм, _yobq, ажык, 
   {{0xbc980014,0x5c740114,0x00000000,0x00000000}},	//   _غمٕچ_, _слут, --, --, 
   {{0x6e24003e,0xf09c00e8,0xdb080241,0x7ac8466d}},	//   _jsjb, _mbàq_, _nidù, _स्टॅ, 
   {{0xe9080156,0xefbc02d3,0x00000000,0x00000000}},	//   _གཡིབ_, ስማዕ_, --, --, 
   {{0x616002d3,0x291c01f7,0x6e240267,0xf3fc0588}},	//   _ሰለማዊ_, meua_, _lsjb, guã_, 
   {{0x27fc22a9,0x291c54bb,0x03a43cc5,0x7a0803e3}},	//   muun_, leua_, тиго, _səti, 
   {{0x27fcc7f7,0xf7941077,0xc0e43129,0x9784030d}},	//   luun_, _جنوب_, ковк, _сăрă_, 
   {{0x7c216ccd,0x399802d3,0x80d80f22,0x7a0800ac}},	//   ywor, tësi_, বৃন্, _qəti, 
   {{0xf5740491,0x27fd6cce,0xe0582ea3,0xf3fc0589}},	// [25bc0] _جميع_, nuun_, ریست_, cuã_, 
   {{0x2cbc4ba8,0x399802d3,0x2ee005be,0x291c0093}},	//   _agud_, rësi_, _cejf_, heua_, 
   {{0x27fc0a55,0x7c2001f5,0x9f400ffb,0x39980240}},	//   huun_, wwor, rsià_, sësi_, 
   {{0x7c216ccf,0x27fd6cd0,0xed556cd1,0x9f40f2b8}},	//   twor, kuun_, кох_, ssià_, 
   {{0x7d016cd2,0x399802d3,0x3ce401fa,0x27fd6cd3}},	//   rgos, qësi_, raov_, juun_, 
   {{0x67100acd,0x9f40de88,0x27fd1000,0x7d016cd4}},	//   त्मक_, rrió_, duun_, sgos, 
   {{0x7c216cd5,0x8b656cd6,0x35c405f9,0x5ba402dd}},	//   swor, دانم, _रूढ़, _ұлағ, 
   {{0xbc7003cc,0x27fc198f,0x2cbc0009,0x9ce800e5}},	//   _پۇتب, fuun_, _ggud_, _سوئے_, 
   {{0x27fc198f,0x00000000,0x00000000,0x00000000}},	//   guun_, --, --, --, 
   {{0x21200369,0x95d806ed,0xfaa40124,0x02bc12eb}},	//   heih_, ндот_, _ҟаҵо, ्डोन, 
   {{0x20000418,0x6b7827af,0x36883129,0x39e001e0}},	//   huii_, _קרבנ, ьсин_, _тәлғ, 
   {{0x27fc0a55,0x8a78010f,0xa5d44d4e,0x38a80ca8}},	//   buun_, _אָנק, کبیر_, _ẹru_, 
   {{0x27fc9f02,0xf3fc00d8,0xf48509e7,0x999801d3}},	//   cuun_, rzão_, тунн, _érő_, 
   {{0xf3fc0589,0x80e0009e,0x33700107,0xca6c0092}},	//   ruã_, _ফাষ্, рҳор, ቻልኩም_, 
   {{0x9abc0135,0xd1d4001f,0x00000000,0x00000000}},	//   _baċi, ክፈት_, --, --, 
   {{0x2ee0202a,0xf3fd6400,0x21200399,0x23a401e3}},	//   _sejf_, puã_, geih_, röja_, 
   {{0xf3fc0589,0x6e24003e,0x3d14012c,0x321c0de2}},	// [25bd0] quã_, _ssjb, नभने_, ňuy_, 
   {{0x564002d3,0x2ee00023,0x9ef4004b,0x7e6c01ec}},	//   _ንመንእ, _qejf_, لسمش, _ﺴﺒﺒﺎ_, 
   {{0xe3b00347,0x9abc003d,0x80e000bd,0xb058008e}},	//   _بري_, _faċi, _ফার্, _afät, 
   {{0x27fc8ebb,0x2000054e,0xd26400cf,0xa2b023e9}},	//   yuun_, buii_, _акүй, ंधर्, 
   {{0x9f40180f,0x2000054e,0x7a0803b9,0x27fc5f39}},	//   ssiá_, cuii_, _mətu, xuun_, 
   {{0x9f400489,0x27fc005b,0xabc8313e,0x00000000}},	//   briñ_, vuun_, _ﻗﻮﻧﺎ, --, 
   {{0x291c00ec,0x27fc0ba7,0xc878054e,0xdb08036e}},	//   teua_, wuun_, maşi_, _zhdë, 
   {{0x27fd6cd7,0xc878084c,0xdda80276,0x4ea424bb}},	//   tuun_, laşi_, _атул_, _арға, 
   {{0x3a70c359,0x3ce00254,0x291c0042,0x957c0210}},	//   иләр, _õkva_, reua_, brąz, 
   {{0x27fc3e6f,0xf8ac01a9,0x1b00010b,0xc8780356}},	//   ruun_, سکن_, _дүшн, naşi_, 
   {{0x27fc22a9,0x200001f7,0x7afc0077,0x8698084c}},	//   suun_, zuii_, ópte, этит_, 
   {{0xaca002e3,0x27fc02f6,0x044507fa,0x6d480007}},	//   _nrịa, puun_, гемн, njga, 
   {{0x6d480369,0x21216cd8,0x27fc0a55,0x684003e6}},	//   ijga, veih_, quun_, _ڕێکل, 
   {{0x752c006d,0x21216cd9,0x8778010f,0xf8b0011a}},	//   adcz, weih_, _ראַי, _השד_, 
   {{0x6b8020ac,0x9abc0135,0x7a080213,0x9f400174}},	//   inng, _paċi, _fətu, drið_, 
   {{0x03a422f7,0xc878084c,0x200145dc,0x9f40030a}},	//   тиҳо, eaşi_, tuii_, vriñ_, 
   {{0x65656cda,0x43742685,0x7a0803be,0x21200363}},	// [25be0] _ilih, _бунт, _hətt, reih_, 
   {{0xcfcc1c82,0xc324c2f3,0x7ee41884,0x9f416cdb}},	//   _লিখন, _смок, اكان, triñ_, 
   {{0x13d8009e,0x9abc031c,0x21200076,0x9f40030a}},	//   _তিয়, _taċi, peih_, uriñ_, 
   {{0x20000093,0x3c647177,0x9f400489,0x7c841797}},	//   puii_, лкег, rriñ_, луле, 
   {{0x20000381,0xc8789736,0xf53c01e3,0xad8400db}},	//   quii_, başi_, mmåt_, دالۇ, 
   {{0x6be00597,0x6564009a,0x3ed84028,0x29085c99}},	//   حكوم, _llih, _سورج_, òcan_, 
   {{0x65656cdc,0xefb007d6,0x1d0800c7,0xde480244}},	//   _olih, _ایلگ, _аҵеи_, _جیاو_, 
   {{0x57f56cdd,0x6b8032ff,0x637403be,0x9a841638}},	//   апит, anng, _dünə, луқл, 
   {{0xb6e4242f,0x3154008f,0x00000000,0x00000000}},	//   люнк, טיקן_, --, --, 
   {{0x65656cde,0xa2d4146c,0xcab80154,0xa814007b}},	//   _alih, _ब्ल्, ঁড়ফ, اتير_, 
   {{0x637400ac,0x7ae96cdf,0x65640240,0xc0c00023}},	//   _günə, maft, _blih, ስራሕ_, 
   {{0x7ae811ad,0x35451ee7,0x80d80eac,0x9f40023a}},	//   laft, ухов, বৃত্, lsiä_, 
   {{0xe2980b01,0x9f4003f2,0x00000000,0x00000000}},	//   ҳаё_, yrið_, --, --, 
   {{0x65656ce0,0x7ae96ce1,0x9f4000fd,0x7a0803b9}},	//   _elih, naft, nsiä_, _fətt, 
   {{0x9f40023a,0x65640200,0xa2d400cd,0xc8780205}},	//   isiä_, _flih, बुध्, vaşi_, 
   {{0x7ae8928b,0x65640010,0x777801c4,0x399801c7}},	//   haft, _glih, litx, mëss_, 
   {{0x9f416ce2,0x765802f6,0x7ae802ed,0xb0580166}},	// [25bf0] ksiä_, lyty, kaft, _afär, 
   {{0xa2d40a28,0xa8540375,0x77796ce3,0x7ae80413}},	//   बुद्, אימה_, nitx, jaft, 
   {{0x5794069c,0x7ae96ce4,0x7a0800ac,0xc8780276}},	//   _ምእንቲ_, daft, _xətt, raşi_, 
   {{0x6d480369,0x777801c4,0x0c7805a2,0xefd40092}},	//   ujga, hitx, кслы_, ክረው_, 
   {{0x8c44d4b3,0x777801c6,0x399804e6,0x76580076}},	//   реле, kitx, hëss_, hyty, 
   {{0xf1bc0270,0x6b80c203,0x7ae8022f,0x921805f9}},	//   _hiá_, unng, gaft, _पहाड़_, 
   {{0x6b800194,0x777801c4,0xcd440583,0x76580108}},	//   rnng, ditx, _پھاٹ, jyty, 
   {{0x76596ce5,0x08c4013e,0xdd98009d,0x88bc0210}},	//   dyty, шбин, _бшу_, jeśc, 
   {{0xf1bc0ba1,0x7778005a,0x7ae801bf,0x7a0803e3}},	//   _miá_, fitx, baft, _sətt, 
   {{0x6b800194,0x7778009d,0x76596ce6,0x7ae80166}},	//   qnng, gitx, fyty, caft, 
   {{0x4584ac57,0x05a80b7e,0x46a400a7,0x39980036}},	//   игов, квой_, ранв, gëss_, 
   {{0x3a38005c,0xdb2401e1,0x00000000,0x00000000}},	//   æppe_, _ìsòw, --, --, 
   {{0x7778009d,0x7658062c,0x50bc0327,0x00000000}},	//   bitx, ayty, _མུཊྚ, --, 
   {{0xe5840228,0xc1e001e0,0x76580d2e,0x00000000}},	//   ртүү, ҙөүҙ, byty, --, 
   {{0xf53c005c,0x00000000,0x00000000,0x00000000}},	//   flåd_, --, --, --, 
   {{0x00856ce7,0x8e400092,0x00000000,0x00000000}},	//   албо, _የሚያሸ, --, --, 
  
   {{0xf1bc0ba1,0x7ae80198,0xcb0401ad,0x9f40005b}},	// [25c00] _diá_, yaft, _रांड_, ysiä_, 
   {{0xfeb80a2c,0x1ee803e6,0x2d8401c7,0x00000000}},	//   ناات_, اوای_, énen_, --, 
   {{0x7e2400ee,0x26e0012d,0x00000000,0x00000000}},	//   рдеж, _ग़ैर_, --, --, 
   {{0xf1bc431d,0x7ae803f9,0xdb0800a2,0xb0580139}},	//   _giá_, waft, _didý, _igän, 
   {{0x9f400724,0x7658068f,0xac056ce8,0x7ae91db8}},	//   tsiä_, zyty, инца_, taft, 
   {{0x7778f3e0,0x2d540166,0x76580108,0x88bc012d}},	//   xitx, _sçet_, yyty, ześc, 
   {{0xdb080209,0x7778004e,0x9f403f47,0x79e400e5}},	//   _gidý, vitx, rsiä_, جوعہ_, 
   {{0x9f400891,0xed54c1ef,0x671004af,0x7a70001f}},	//   ssiä_, _кос_, त्सक_, _እንግዳ_, 
   {{0xed556ce9,0x9f409226,0x7ae8022c,0x777801c6}},	//   _тот_, psiä_, paft, titx, 
   {{0xded00125,0x765917f6,0xb6c4010b,0x00000000}},	//   _እስኪ_, tyty, шсий, --, 
   {{0x56956cea,0x777819bb,0xaacc00af,0x4c140150}},	//   сант, ritx, _स्टक, _نبەس, 
   {{0x77781d4d,0x39980036,0x76596ceb,0x2d540139}},	//   sitx, rëss_, ryty, _uçet_, 
   {{0x7658023a,0x777801c4,0x8c3c0432,0x69bc000d}},	//   syty, pitx, _gyşd, _लूटी, 
   {{0x76580588,0x77780227,0xf1bc2508,0xb37002dd}},	//   pyty, qitx, _siá_, іңні, 
   {{0xf5e402dd,0xe3b0009f,0x00000000,0x00000000}},	//   _тілм, برَ_, --, --, 
   {{0xded15948,0xeee8001e,0xf53c01bf,0x00000000}},	//   _እስከ_, _đựng_, rmås_, --, 
   {{0xb4e00307,0xdb080432,0x7a0803e3,0x8af806be}},	// [25c10] धरी_, _bidü, _xətr, ldəş, 
   {{0x91c40124,0x9ed8005b,0xdec00023,0xd37001f7}},	//   _гәал, имут_, ስጋን_, _رهج_, 
   {{0xdb200086,0xf1bc0ba1,0xdec801c0,0x92580479}},	//   _òtùb, _tiá_, руул_, _сант_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xac256cec,0xdc9802bf,0x00000000,0x00000000}},	//   рфек, авці_, --, --, 
   {{0xf3fc0004,0xda188098,0x69c400e4,0xc0dc0023}},	//   irã_, _दहशत_, _éjek, ቕያር_, 
   {{0x8c440184,0x88bc0882,0x46e804a9,0x7afc0077}},	//   реһе, deśa, ңдин_, ópta, 
   {{0xdb0804d4,0xc4e00f22,0x8c3c2ac2,0x19e40220}},	//   _bidó, _মঞ্জ, _ayşe, _ﺍﻹﻗﻠ, 
   {{0x29c000a2,0x26c0107d,0x7a0803b9,0x00000000}},	//   _aıat_, žjom_, _qətr, --, 
   {{0xf3fc0004,0xabc808b0,0x00000000,0x00000000}},	//   drã_, _ﻗﻮﻳﺎ, --, --, 
   {{0x6c7400d1,0xf3fc00c7,0xda700014,0x4adc00cd}},	//   _суңх, erã_, _ہُے_, _न्यव, 
   {{0x7a7804ac,0xf3fc0589,0xdb080429,0x00000000}},	//   _גרעס, frã_, _fidó, --, 
   {{0xf3fc0589,0x764c0fac,0x00000000,0x00000000}},	//   grã_, øbyr, --, --, 
   {{0x04f8015b,0x27fc0135,0xef0000c5,0x00000000}},	//   েজের_, mrun_, _लागऽ_, --, 
   {{0xe734052f,0xc8780724,0xf53c7c52,0xcb0402ab}},	//   _беҙ_, raşu_, rmår_, _राईड_, 
   {{0xf3fc0004,0xdb080295,0xfe700046,0x04440022}},	//   brã_, _jidò, ۋدا_, _геин, 
   {{0x80a887ff,0x9f4000c6,0x7fd4d8f9,0x27fd6ced}},	// [25c20] ував_, msiú_, сібі, nrun_, 
   {{0x9f4000c6,0x27fd6a0f,0xb058013d,0x2bc8078a}},	//   lsiú_, irun_, _igäl, ादना, 
   {{0xb3b80302,0x03680022,0x7080001f,0x0dc818fd}},	//   _תמיכ, _аиҿк_, _በዘርፉ_, لبنى_, 
   {{0x741007d6,0x236400e2,0x27fd05e9,0x9f4000ae}},	//   _بویا, īmju_, krun_, nsiú_, 
   {{0x9f4000c6,0x20040022,0x00000000,0x00000000}},	//   isiú_, _êmi_, --, --, 
   {{0x27fd6cee,0xeb956cef,0x20000548,0x26c004a7}},	//   drun_, бич_, mrii_, žjoj_, 
   {{0xfe4402f4,0x88bc0882,0xdb08011f,0x6a1000c6}},	//   _унво, veśa, _sidó, كبير, 
   {{0xafd87214,0x20000356,0x27fcaa9a,0xf3fc035b}},	//   _drøf, orii_, frun_, yrã_, 
   {{0xdb0808c2,0x27fd6cf0,0x00000000,0x00000000}},	//   _didò, grun_, --, --, 
   {{0x3dc80eb4,0xf72813b1,0x20000311,0xec1001ec}},	//   _kubw_, уций_, irii_, _ءولد, 
   {{0x29d0a864,0xafd84675,0x2000022f,0xe94401b9}},	//   _فيلس, _grøf, hrii_, _گرلی, 
   {{0x3f996cf1,0xf3fc0c67,0x20016cf2,0x39440276}},	//   hopu_, trã_, krii_, _ынег, 
   {{0xf9f80183,0x88bc033f,0xe94405af,0x70a40118}},	//   _আহিল_, leśn, _درلی, _खरेल, 
   {{0x78a00117,0xf3fc0c67,0xdb0802bd,0x20000356}},	//   _iyov, rrã_, _zidò, drii_, 
   {{0xa7780302,0x20016cf3,0xd13001b9,0xb188009d}},	//   _תרופ, erii_, ومآ_, гсаж_, 
   {{0x78a00337,0x659401f4,0x00000000,0x00000000}},	//   _kyov, _нащу, --, --, 
   {{0x20016cf4,0x04840116,0x2d8400bc,0x533410de}},	// [25c30] grii_, _дәри_, énem_, _депт, 
   {{0x78a0009f,0x00000000,0x00000000,0x00000000}},	//   _myov, --, --, --, 
   {{0x20016cf5,0x5ed400c6,0x59c4000d,0xeea8f3f0}},	//   arii_, ستلز, _लंगर, утак_, 
   {{0x78a00117,0x3330003e,0x2000e9e5,0xa698008f}},	//   _oyov, _haxx_, brii_, נשאפ, 
   {{0x78a0014b,0x20001cd4,0x3f980124,0x8ac4009d}},	//   _nyov, crii_, bopu_, ойлж, 
   {{0xdb080109,0xbb4000f7,0x2d54013d,0x8c3c00a2}},	//   _sidò, дешк, _eçep_, _pyşb, 
   {{0x33316cf6,0x27fca24e,0x78a021f3,0xafd887c2}},	//   _maxx_, wrun_, _ayov, _brøg, 
   {{0x27fd6cf7,0x78a00083,0xafd80158,0x00000000}},	//   trun_, _byov, _crøg, --, 
   {{0x2d9c010f,0x77c405f5,0x27fc04cc,0x00000000}},	//   _ikue_, олыг_, urun_, --, 
   {{0x27fd6cf8,0xafd80ac8,0xdce000de,0xf40c00fe}},	//   rrun_, _trøf, _ilmā, িবাৰ_, 
   {{0x78a00117,0xaa6401e9,0x2fcc06ea,0xafd801bf}},	//   _eyov, _утак, íggj_, _frøg, 
   {{0x20000548,0xafd8143a,0x85780120,0xeff001f3}},	//   yrii_, _krød, рсот_, ውረድ_, 
   {{0x3330003d,0x27fc0784,0x9f4000ae,0x00000000}},	//   _baxx_, qrun_, rsiú_, --, 
   {{0x68e833b8,0xfbd000d9,0xf8b40677,0xb7d40244}},	//   _hegd, ותך_, _ופני_, _بووا_, 
   {{0x2d9c0022,0x26c4a385,0x96b8030d,0x00000000}},	//   _okue_, _igno_, _луъу_, --, 
   {{0x20016cf9,0x515400cf,0x00000000,0x00000000}},	//   trii_, птуу, --, --, 
   {{0x88bc068f,0x33300327,0x68e801ed,0x2fc0022e}},	// [25c40] ześn, _faxx_, _megd, _bijg_, 
   {{0x200022a9,0x2d9c035b,0xdef802d3,0x68e96cfa}},	//   rrii_, _akue_, _ወሳኒ_, _legd, 
   {{0x20000ba7,0xee340640,0x00000000,0x00000000}},	//   srii_, жнх_, --, --, 
   {{0xcbd403f4,0x68e81326,0xa084005e,0xafd814f5}},	//   _হয়েছ, _negd, _еңбе, _brød, 
   {{0x3f980270,0x00000000,0x00000000,0x00000000}},	//   popu_, --, --, --, 
   {{0x2d9c07dd,0x00000000,0x00000000,0x00000000}},	//   _ekue_, --, --, --, 
   {{0xe604004b,0xf96800a8,0x25a16cfb,0x68e80432}},	//   _تش_, ирий_, _okil_, _begd, 
   {{0x26c4003a,0xfaf82263,0xafd803b2,0x88bc0210}},	//   _agno_, _چراغ_, _frød, reśn, 
   {{0xbb48438b,0x68e96cfc,0xf74800d6,0xafd8bc85}},	//   _پلان_, _degd, аїни_, _grød, 
   {{0x78a16cfd,0x68e80ba7,0x7b6401d9,0x34e0012c}},	//   _vyov, _eegd, _بارٕ, पर्द, 
   {{0xafd803cd,0x393401c0,0x3330031c,0x2d9c00e4}},	//   _trøg, _мэдс, _raxx_, _ykue_, 
   {{0x78a00100,0x00000000,0x00000000,0x00000000}},	//   _tyov, --, --, --, 
   {{0x78a00107,0x9f40026c,0x637000fd,0x3944045a}},	//   _uyov, ssiù_, _mänf, _inos_, 
   {{0x39440789,0x68e96cfe,0x55c40166,0x00000000}},	//   _hnos_, _zegd, _нәмз, --, 
   {{0x2d8400dd,0x00000000,0x00000000,0x00000000}},	//   ének_, --, --, --, 
   {{0x9268c89a,0x93f42082,0x88800271,0x4fd4005b}},	//   арға_, _епиц, _آیین, зжат, 
   {{0xb4d4007d,0xdef80020,0x3a3c007f,0x6560007c}},	// [25c50] िडी_, _ወሳኝ_, _lrtp_, ömhe, 
   {{0x6440037e,0x8c3c00ee,0x2d9c072b,0x3204007c}},	//   æmie, _nyşa, _skue_, _ånyo_, 
   {{0x2d9c01e4,0x5f74007b,0x394400c0,0x3a3c00ef}},	//   _pkue_, ذاكر, _onos_, _nrtp_, 
   {{0x84700023,0x00000000,0x00000000,0x00000000}},	//   _ብሩህን_, --, --, --, 
   {{0x68e96cff,0x80c00154,0x237400f2,0x00000000}},	//   _regd, ষুব্, _رایح, --, 
   {{0x394410b4,0x3c1c00da,0x29c000a2,0x9abc0327}},	//   _anos_, dāvā_, _aıap_, _paċp, 
   {{0x1df8b690,0x7c3c0882,0x7af80175,0x00000000}},	//   _меры_, āpra, _ddtt, --, 
   {{0xb05802b1,0xafd805ac,0x2d9c009f,0xad4000f7}},	//   _ngäk, _trød, _ukue_, _تىرۉ, 
   {{0xafd800ed,0x68e808fb,0x00000000,0x00000000}},	//   _frøe, _vegd, --, --, 
   {{0x25a16d00,0x68e96d01,0x3e44001f,0x8c3c010b}},	//   _skil_, _wegd, _መላእክ, _gyşa, 
   {{0x63716d02,0x68e801d5,0xebbc00b8,0x7ae800e5}},	//   _häng, _tegd, _jaḍo_, öltő, 
   {{0x63716d03,0x00000000,0x00000000,0x00000000}},	//   _käng, --, --, --, 
   {{0xfb500014,0x3a3c0010,0x00000000,0x00000000}},	//   _تھۆد, _zrtp_, --, --, 
   {{0x63716d04,0xe1f80107,0x538001ec,0xb4d8000d}},	//   _mäng, оҳо_, кқыз, _ढ्ी_, 
   {{0x63716d05,0x88bc0034,0x80f821f3,0x25a865dc}},	//   _läng, ześl, йхат_, _وضعی_, 
   {{0xf53c2611,0xf1c0084c,0x00000000,0x00000000}},	//   llån_, ейсп, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [25c60] --, --, --, --, 
   {{0x44316d06,0xf53c713c,0x00000000,0x00000000}},	//   _isy_, nlån_, --, --, 
   {{0x82a401a9,0x443001f4,0x00000000,0x00000000}},	//   _ханж, _hsy_, --, --, 
   {{0x6370145e,0xafd84606,0x568c008f,0x4174a397}},	//   _bäng, _drøb, סטאַ, _راجس, 
   {{0x9b5805f5,0x85080490,0x4adc0b7c,0xdce0054e}},	//   жилт_, _वाईट_, नुभव, _almă, 
   {{0x88bc068f,0x44316d07,0x6c816d08,0x6fe4031c}},	//   reśl, _msy_, علوم, _སྦྲའ, 
   {{0x98b007f5,0xf53c353e,0xcdf40166,0x00000000}},	//   đaču_, dlån_, _очты, --, 
   {{0x63716d09,0x44309119,0xe9cc00f1,0xd910072d}},	//   _fäng, _osy_, دغو_, ئیش_, 
   {{0x63716d0a,0xefcc0020,0x3944151c,0xbc656d0b}},	//   _gäng, _እቅድ_, _vnos_, _эвак, 
   {{0xf53c4e9b,0xa77000e6,0x6370000d,0x7af80356}},	//   glån_, ельч, _jänd, _udtt, 
   {{0xaad8025f,0x4430035b,0x6370145e,0xd05c00ac}},	//   _החבר, _asy_, _mänd, _desə, 
   {{0x39456d0c,0x63709577,0x00000000,0x00000000}},	//   _unos_, _länd, --, --, 
   {{0x63700267,0xa8141291,0xf53c007c,0x00000000}},	//   _oänd, _فتور_, blån_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb0801b8,0x443005da,0x80a03cbe,0xb1900139}},	//   _fidö, _esy_, _कुबे, елвә, 
   {{0xdb0801b8,0x88bc0210,0x00000000,0x00000000}},	//   _gidö, ześm, --, --, 
   {{0x9378aec3,0xd05c06be,0x00000000,0x00000000}},	// [25c70] _мбит_, _yesə, --, --, 
   {{0x29000006,0x63716d0d,0x00000000,0x00000000}},	//   ėjai_, _räng, --, --, 
   {{0x63716d0e,0x80a00574,0xafd801bf,0x00000000}},	//   _säng, _कुठे, _brøc, --, 
   {{0x63716d0f,0xdd947db4,0xf1a804d3,0x44316d10}},	//   _päng, нахы, _داخه_, _ysy_, 
   {{0x63716d11,0xde180075,0xcac803f6,0x9f4000a2}},	//   _fänd, ققەت_, огле_, lsiý_, 
   {{0xafd84606,0x63716d12,0xf53c005c,0x00000000}},	//   _trøb, _gänd, xlån_, --, 
   {{0x01c80150,0x00000000,0x00000000,0x00000000}},	//   _ﻓﺎﻟﺨ, --, --, --, 
   {{0x63716d0f,0x3eac0e78,0x6d8001e4,0x9d185336}},	//   _täng, üfte_, aĵar, _ност_, 
   {{0x63700664,0xaac411fc,0x80d802f5,0xdd956d13}},	//   _häne, _فتان, বৃক্, _чаты, 
   {{0x6d596d14,0xdb580064,0x668001d3,0x00000000}},	//   _houa, _нюх_, ٹیبل, --, 
   {{0x6d596d15,0x6b816d16,0x637000c5,0x7bc4020c}},	//   _koua, ming, _jäne, _èkua, 
   {{0x6d596d17,0x7bc4565c,0x63707bbc,0x00000000}},	//   _joua, _ékur, _mäne, --, 
   {{0x44300054,0x6370049f,0x6b816d18,0x6d596d19}},	//   _qsy_, _läne, oing, _moua, 
   {{0x6d596d1a,0x44300175,0x00000000,0x00000000}},	//   _loua, _vsy_, --, --, 
   {{0x6b816d1b,0xdb0801b8,0x63716d1c,0xf09c004e}},	//   iing, _tidö, _ränd, _ocàs_, 
   {{0x44316d1d,0x6b816d1e,0x6370049f,0x6d596d1f}},	//   _tsy_, hing, _sänd, _noua, 
   {{0xbef96c37,0xb4f8011a,0x00000000,0x00000000}},	// [25c80] قراض_, _ולפר, --, --, 
   {{0xaf003ea2,0x764c050a,0x23b400f7,0xd1740139}},	//   кпул, åbyg, _سۅزس, _җыюы, 
   {{0x6b816d20,0x63716d21,0xdcf400d0,0xdef8069d}},	//   ding, _vänd, ňačk, _ሊንክ_, 
   {{0x63716d22,0xc10431ed,0x6d596d23,0xb05800b0}},	//   _däne, _توحي, _coua, _ngäw, 
   {{0x6b816d24,0x6d5803bd,0x6370049f,0x69d41709}},	//   fing, _doua, _tänd, íxen, 
   {{0x6370013d,0xba44009d,0x00000000,0x00000000}},	//   _fäne, дхий, --, --, 
   {{0x6d596d25,0xbe14fd47,0x6370010e,0x58d400db}},	//   _foua, _توزع, _känb, нойт, 
   {{0x6d580dd4,0x6b80006f,0x00000000,0x00000000}},	//   _goua, aing, --, --, 
   {{0x637029ef,0x3ce45340,0x00000000,0x00000000}},	//   _zäne, mbov_, --, --, 
   {{0x6b816d26,0x6d580156,0x8c3c0432,0x63700139}},	//   cing, _zoua, _myşl, _yäne, 
   {{0x6d596d27,0x9f4000cf,0x00000000,0x00000000}},	//   _youa, lsió_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9f400228,0x743c0092,0x00000000,0x00000000}},	//   nsió_, _ሲያጋጥ, --, --, 
   {{0xb4ad6d28,0xe60c0101,0xe73400f3,0x00000000}},	//   _करी_, دشی_, _жељ_, --, 
   {{0x3ce4013d,0x00000000,0x00000000,0x00000000}},	//   kbov_, --, --, --, 
   {{0x6b816d29,0x63700374,0xccf800b8,0x00000000}},	//   zing, _räne, _kośe_, --, 
   {{0x6d596d2a,0x6b806dc8,0x6aa87dad,0x80a05ca7}},	// [25c90] _roua, ying, _छर्र, _कुदे, 
   {{0x6b816d2b,0x6d59242d,0x2fc4b625,0x63700793}},	//   xing, _soua, öng_, _päne, 
   {{0x6d580053,0xc330008f,0xb4ac0574,0xe0d01893}},	//   _poua, _גוי_, _करु_, ازہ_, 
   {{0x6b816d2c,0x4c945cb9,0x637001e6,0xe3b001e2}},	//   wing, ниес, _väne, _مرۍ_, 
   {{0x6b816d2d,0xafd80162,0x6d58a573,0x8c3c0432}},	//   ting, _frøa, _voua, _gyşl, 
   {{0xe1f00f01,0x6d580129,0x6b816d2e,0x6370013d}},	//   _حسی_, _woua, uing, _täne, 
   {{0xfaa16d2f,0x9f40004e,0xfb500131,0x3f280327}},	//   лашо, asió_, اپىد, _ཤྲིའ_, 
   {{0x6b816d30,0xb4ac0574,0x6d580270,0x00000000}},	//   sing, _करू_, _uoua, --, 
   {{0x6b816d31,0xd05c013f,0x2d8d6d32,0x2d84002e}},	//   ping, _resɛ, mnge_, éneu_, 
   {{0x6b816d33,0xaa64ca40,0x00000000,0x00000000}},	//   qing, _отек, --, --, 
   {{0x2d8c009f,0x2908068c,0xdda80354,0x33cc0150}},	//   onge_, òcas_, _атăл_, _ﻛﺮﺍﺣ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2d8d6d34,0x291c0134,0x8ac401b9,0xd7f464c2}},	//   inge_, mfua_, _ўққа_, _азчы, 
   {{0xd874db35,0x29000006,0x22c001e1,0x4b78010f}},	//   _جامب, ėjau_, _ǹkò_, לאָו, 
   {{0x41b56d35,0x2d8c0810,0x3ce400d7,0x00000000}},	//   есат, knge_, ybov_, --, 
   {{0x9f400407,0x764c03cd,0x11380092,0xdb1800d7}},	//   mpié_, åbye, _የቻይና, rmvé, 
   {{0x291c72dc,0x6370013d,0xdb2001e1,0x00000000}},	// [25ca0] ifua_, _cänc, _ńwíp, --, 
   {{0x644404fe,0x2d8c039a,0xef80033a,0x23a4007c}},	//   _irii, enge_, глуп, röjs_, 
   {{0x69d40077,0x644402d2,0x3ce40455,0x00000000}},	//   íxel, _hrii, tbov_, --, 
   {{0x64453924,0x00000000,0x00000000,0x00000000}},	//   _krii, --, --, --, 
   {{0xb140023a,0x31300064,0x00000000,0x00000000}},	//   _снял, _сеўр, --, --, 
   {{0x9f400228,0x2d8c03c1,0xc0cc044e,0x81bc063f}},	//   rsió_, ange_, _እንሆ_, _ọchọ_, 
   {{0x9f400372,0xf9c56d36,0x19580209,0xcee80014}},	//   ssió_, нщин, дайы_, _ترُن_, 
   {{0x2d8401ed,0xdc740022,0x64456d37,0x00000000}},	//   énet_, _ҿыҕь, _orii, --, 
   {{0xb4ac09fd,0x63700139,0x00000000,0x00000000}},	//   _करे_, _xänc, --, --, 
   {{0x291c0618,0x61ac00cd,0xabf8011a,0x73e00022}},	//   afua_, चतुष, _מהמר, қәиҵ, 
   {{0x64449bb2,0xe81400f2,0x80a00037,0x6440041e}},	//   _arii, وزیت_, _कुसे, æmin, 
   {{0x69c40022,0x64456d38,0x00000000,0x00000000}},	//   _éjep, _brii, --, --, 
   {{0x79814fe6,0xb4f800af,0xbab003d4,0x00000000}},	//   _imow, ्लौप_, _চলিছ, --, 
   {{0xafd811c0,0x64456d39,0x6370008e,0x00000000}},	//   _brøn, _drii, _ränc, --, 
   {{0xb5a410f5,0x2d8c0493,0x64456d3a,0xa5d40597}},	//   _прий, ynge_, _erii, _كبير_, 
   {{0xafd8efd7,0xa1596d3b,0x6370008e,0x00000000}},	//   _drøn, насу_, _pänc, --, 
   {{0x64456d3c,0xb05802b5,0xaf056d3d,0x93b40fbe}},	// [25cb0] _grii, _ngät, ечек, _ибиц, 
   {{0x752d6d3e,0xafd800cc,0x59d000b8,0x00000000}},	//   lecz, _frøn, हदार, --, 
   {{0xafd800d4,0xf2c40131,0x644800e2,0xd15c0023}},	//   _grøn, _ясин, ādie, _ደገፍን_, 
   {{0x80a002f8,0x2d8d6d3f,0x3ea8037e,0x752c0034}},	//   _कुवे, unge_, _dybt_, necz, 
   {{0xb4ac17cb,0x742c0092,0x004401e2,0x00000000}},	//   _करो_, ሳተፉበ, _ټیلي_, --, 
   {{0x798002b5,0x996c012c,0xb4ac0307,0x9f400268}},	//   _amow, měř_, _करै_, ssiò_, 
   {{0x2d84015b,0xfe340364,0x5f94798a,0x4dc401e0}},	//   énes_, _имрӯ, _сирт, _араҡ, 
   {{0x6370025a,0x752cae75,0x00000000,0x00000000}},	//   _mäna, jecz, --, --, 
   {{0x63700793,0x8c18004b,0x291c022e,0x752c012d}},	//   _läna, _زيار_, rfua_, decz, 
   {{0x291c0421,0x7980cbfc,0x8b841c3e,0x88bc012d}},	//   sfua_, _emow, _جەتە_, ześw, 
   {{0x63700793,0x752c07c5,0x644401ab,0x84e4084c}},	//   _näna, fecz, _srii, конж, 
   {{0x64456d40,0x29000006,0x9a843bfd,0x00000000}},	//   _prii, ėjas_, _суул, --, 
   {{0x69c96d41,0x9f400174,0x00000000,0x00000000}},	//   _iige, ksið_, --, --, 
   {{0x69c96d42,0x7c24d398,0xd17402dd,0x25a80092}},	//   _hige, _äkre, қысы, ገብጋቢ_, 
   {{0xd298005e,0x63700139,0x26a40150,0x752c012d}},	//   етті_, _cäna, _سۇحپ_, becz, 
   {{0x644400af,0x69c80694,0x973c05a1,0x2120011f}},	//   _trii, _jige, moća, ufih_, 
   {{0x64456d43,0x41d01a4e,0x00000000,0x00000000}},	// [25cc0] _urii, _दूरस, --, --, 
   {{0x69c96d44,0xafd803a1,0xe9c4004b,0x98a40356}},	//   _lige, _trøn, _ږغ_, lemă_, 
   {{0x4f956d45,0x69c854fb,0x80a02e2a,0x6df0007b}},	//   урту, _oige, _कुरे, لكلا, 
   {{0x69c96d46,0x7c840b7b,0xafd81477,0x8c3c0432}},	//   _nige, куле, _krøl, _gyşk, 
   {{0x6370014a,0xefb007d6,0x1b4801f0,0x00000000}},	//   _zäna, _چیقگ, нҷаи_, --, 
   {{0x2d856d47,0x752c068f,0x69c80428,0x6370094a}},	//   éner_, zecz, _aige, _yäna, 
   {{0x69c851a9,0xfd5000ec,0x00000000,0x00000000}},	//   _bige, _پڙاڏ, --, --, 
   {{0xcdc56d48,0x69c96d49,0x58396d4a,0x79a400a7}},	//   _басқ, _cige, езия_, ърле, 
   {{0x64400008,0xb4e0098a,0x00000000,0x00000000}},	//   æmil, _क्षय_, --, --, 
   {{0x69c96d4b,0x752c012d,0xc87800a2,0x00000000}},	//   _eige, wecz, naşy_, --, 
   {{0x69c96d4c,0x752d6d4d,0x8e2001a9,0x06c400fe}},	//   _fige, tecz, nchа_, _শ্বি, 
   {{0x69c96d4e,0x7980068f,0xeee801fb,0xccf800b8}},	//   _gige, _umow, _đọng_, _kośa_, 
   {{0x752d6d4f,0x9f400ad9,0x63700139,0x80a01bd6}},	//   recz, ysið_, _säna, _कुले, 
   {{0x69c89390,0x63700793,0xdb0c00fd,0x752c396d}},	//   _zige, _päna, _ähäm, secz, 
   {{0x69c8f320,0xf1a56d50,0x752c012d,0x36d000fb}},	//   _yige, вран, pecz, _йоҙр, 
   {{0x69c80050,0xafd81347,0x00000000,0x00000000}},	//   _xige, _frøl, --, --, 
   {{0xa0c498f0,0x9098bd08,0x637002b5,0x00000000}},	// [25cd0] ليفو, хват_, _wäna, --, 
   {{0x63716d51,0xf41c00fd,0x00000000,0x00000000}},	//   _täna, mtä_, --, --, 
   {{0xf41c426d,0x637008b3,0x9f416d52,0xfccc02d3}},	//   ltä_, _känn, mpiì_, _ብሉጽ_, 
   {{0x637002f6,0x9f40148b,0x6ce40150,0x00000000}},	//   _jänn, ssið_, тіже, --, 
   {{0x69c8337a,0x63716d53,0xf41c0664,0xb0580166}},	//   _rige, _männ, ntä_, _egär, 
   {{0x69c96d54,0xf41c049b,0x637028ef,0xb4d8026c}},	//   _sige, itä_, _länn, ndàb, 
   {{0x69c96d55,0xfd4c1682,0x07a40ed1,0xf41c0108}},	//   _pige, _lwoṱ, ғанн, htä_, 
   {{0xf41c0598,0xd5e8063f,0x637016ca,0xf53c01e3}},	//   ktä_, ̣ọl, _nänn, jdå_, 
   {{0x4a540046,0x9c656d56,0xf53c01e3,0x07a4009b}},	//   _әкес, _پهلو, ddå_, лаин, 
   {{0x69c85975,0x42800020,0x85e8afe2,0xf41c0108}},	//   _wige, _የሆኑት_, ндов_, dtä_, 
   {{0xf53c0158,0x69c96d57,0x63716d58,0xf41c005b}},	//   fdå_, _tige, _bänn, etä_, 
   {{0x69c96d59,0xf53c0158,0x973c110c,0x6370008e}},	//   _uige, gdå_, roća, _cänn, 
   {{0x973c04b9,0x637001c7,0x00000000,0x00000000}},	//   moćn, _dänn, --, --, 
   {{0x9f600bbc,0xd6c81291,0x00000000,0x00000000}},	//   ürüp_, عظین_, --, --, 
   {{0xafd83570,0x412876ac,0x63716d5a,0x2c1c0154}},	//   _drøm, ново_, _fänn, পিয়ে_, 
   {{0x973c05ce,0xafd8022c,0x637004c1,0x00000000}},	//   noćn, _trøl, _gänn, --, 
   {{0xafd8005c,0x00000000,0x00000000,0x00000000}},	// [25ce0] _frøm, --, --, --, 
   {{0xafd80174,0x637001c7,0xef147f50,0x2d8402e2}},	//   _grøm, _zänn, лму_, ènen_, 
   {{0xfd4c0084,0xd05c013f,0x04c8d371,0xdb080051}},	//   _zwoṱ, _desɑ, _توکي_, _đoàn, 
   {{0x8e2001d5,0x98a40064,0x00000000,0x00000000}},	//   rchа_, lemą_, --, --, 
   {{0xfb840724,0xd12c0050,0x1af40826,0xdb8400c7}},	//   лыкн, _زۅل_, апля, аҳаи, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x39a400a7,0x5fd8090a,0x00000000,0x00000000}},	//   лшив, _भूतल, --, --, 
   {{0xf41c0664,0x6e916d5b,0x98a40153,0x00000000}},	//   ytä_, _الفا, hemą_, --, 
   {{0xd6d00491,0x63701284,0x7c0816ac,0x33200175}},	//   يقة_, _ränn, _سياف_, yfjx_, 
   {{0xdca407d6,0x6370000d,0xf5e401ec,0xa77000db}},	//   _бағи, _sänn, лімм, йлыч, 
   {{0xb8040254,0xab740451,0x6f00068c,0x637001f4}},	//   _शिवम_, _حملا_, ónci, _pänn, 
   {{0xf41c8b51,0x79f40124,0xca74760c,0xafd801bf}},	//   ttä_, _азҧх, _тууы, _drøj, 
   {{0x637004f3,0x00000000,0x00000000,0x00000000}},	//   _vänn, --, --, --, 
   {{0xf41c00fd,0xeee80208,0x00000000,0x00000000}},	//   rtä_, _đỏng_, --, --, 
   {{0xf41c99ac,0x63701b5d,0x81cc0183,0x06b00118}},	//   stä_, _tänn, _ৰিজ_, čící_, 
   {{0xde500092,0xf1a47fa5,0x00000000,0x00000000}},	//   _የሚያፈ, ургн, --, --, 
   {{0xde500092,0x63700432,0x00000000,0x00000000}},	// [25cf0] _የሚከፍ, _känl, --, --, 
   {{0xceb80131,0x4ee401e0,0x00000000,0x00000000}},	//   вәб_, рсаҡ, --, --, 
   {{0x6370014a,0xafd8fcf4,0x00000000,0x00000000}},	//   _zäno, _krøk, --, --, 
   {{0xc0c00020,0x973c07f5,0x712000db,0xa158004e}},	//   ቻልም_, koćo, _دۉرم, _баюу_, 
   {{0xf3fc00d8,0x00000000,0x00000000,0x00000000}},	//   nsã_, --, --, --, 
   {{0x4ea402dd,0x9db80133,0x00000000,0x00000000}},	//   _ұрға, ندۆز_, --, --, 
   {{0x320401bf,0x9cc801e0,0xabc802dd,0x00000000}},	//   _ænyd_, _ҡыуа_, _ﺗﻮﻧﺎ, --, 
   {{0x7c3c068f,0x7dd80024,0x480472fb,0x9f44110e}},	//   łpra, _mįsl, апив, _ìmò_, 
   {{0x2eb401d9,0x6e340175,0x00000000,0x00000000}},	//   _شێچھ_, lwxb, --, --, 
   {{0x6f140399,0x386001e6,0x6370013d,0xdd7401d9}},	//   ngxc, äkra_, _cänl, _پھۅک, 
   {{0x63700139,0x957c0064,0x00000000,0x00000000}},	//   _säno, mpąj, --, --, 
   {{0xdb080100,0x63700793,0x04456d5c,0x00000000}},	//   _akdè, _päno, аемн, --, 
   {{0x68f96d5d,0x2868030d,0x00000000,0x00000000}},	//   maud, _яржо_, --, --, 
   {{0xd1740184,0xafd8037e,0x27fd6d5e,0x6370007c}},	//   ҡыты, _trøj, msun_, _väno, 
   {{0x27fd6d5f,0x633802d3,0x01640063,0xdc240154}},	//   lsun_, _ብዝገበ, акво, পিএস_, 
   {{0x00e48233,0x68f802d5,0xc0e40798,0x00000000}},	//   ржан, naud, роак, --, 
   {{0x27fc3154,0x68f804cc,0x98b000f3,0x00000000}},	// [25d00] nsun_, iaud, đaću_, --, 
   {{0xfe70be0c,0x65656d60,0x68f96d61,0x27fd6d62}},	//   يدا_, _hoih, haud, isun_, 
   {{0x68f96d63,0x3ead6d64,0x656402b5,0xd1bc0092}},	//   kaud, æft_, _koih, ታሮች_, 
   {{0x27fd6d65,0x6564023a,0x2b10012c,0x68f96d66}},	//   ksun_, _joih, _ठाउँ_, jaud, 
   {{0x68f96d67,0x6564316f,0xfbc400c2,0xfbe4015b}},	//   daud, _moih, абдо, _নিহত, 
   {{0x6564123c,0x2000208d,0x4420003e,0xf53c01e3}},	//   _loih, msii_, itk_, llåt_, 
   {{0x20000270,0x68f806af,0x44200076,0x4a08035b}},	//   lsii_, faud, htk_, гьыҭ_, 
   {{0x68f96d68,0xada002d5,0x65656d69,0x2000054e}},	//   gaud, _дасл, _noih, osii_, 
   {{0x20016d6a,0x27fd6d6b,0xfca80133,0xeab4010b}},	//   nsii_, gsun_, _شارو_, лйә_, 
   {{0xe56830fb,0xb76404a9,0x20003431,0x442001e4}},	//   _אַ_, ртий, isii_, dtk_, 
   {{0x65640369,0x6370049f,0x68f96d6c,0x49746909}},	//   _boih, _vänl, baud, рлөс, 
   {{0x35696d6d,0x20016d6e,0x68f96d6f,0x64480aed}},	//   трон_, ksii_, caud, ādin, 
   {{0xb9e00201,0x49c4007b,0x63700166,0xf53c007c}},	//   _ያለ_, _اغلف, _tänl, boån_, 
   {{0x7c216d70,0xd6d0314e,0x20000ba7,0x628001e4}},	//   itor, _عقب_, dsii_, ĝmon, 
   {{0xf3fd6400,0x7c216d71,0x60cc03be,0xe2f89e08}},	//   ssã_, htor, ənmə, ресі_, 
   {{0x2000208d,0x656401c4,0xf484010a,0x00000000}},	//   fsii_, _goih, _вуон, --, 
   {{0x7c20044e,0x20000009,0x659c011a,0x00000000}},	// [25d10] jtor, gsii_, _שיחק, --, 
   {{0x7c200037,0x68f96d72,0x00000000,0x00000000}},	//   dtor, zaud, --, --, 
   {{0x7c200483,0x68f96d73,0x20003504,0x1fa40220}},	//   etor, yaud, asii_, іруг, 
   {{0x764800fe,0x27fd6d74,0x2000198f,0x425405d9}},	//   _mrfy, ysun_, bsii_, _انٽر, 
   {{0x8c44b169,0x92d803f4,0x68f96d75,0xf1bc01e1}},	//   селе, ারী_, vaud, _ihá_, 
   {{0x92d81c82,0x68f96d76,0x0dd0001f,0x00000000}},	//   াৰৰ_, waud, _እጥፍ_, --, 
   {{0x68f96d77,0xf1bc0016,0xf53c5c1b,0x1df8023a}},	//   taud, _khá_, nlås_, _весы_, 
   {{0x7c201590,0x60780092,0x00000000,0x00000000}},	//   btor, _በጉጉት_, --, --, 
   {{0x68f96d78,0x973c00f3,0xf1bc0332,0x65656d79}},	//   raud, moćj, _mhá_, _roih, 
   {{0x27fc4a98,0x68f96d7a,0x66041315,0x0708009f}},	//   rsun_, saud, ájko, ديدي_, 
   {{0x27fd6d7b,0x68f96d7c,0x65640374,0x00000000}},	//   ssun_, paud, _poih, --, 
   {{0xaca001f2,0xf1bc001e,0x27fc0108,0x20005604}},	//   _ndịn, _nhá_, psun_, ysii_, 
   {{0xd49812d7,0x6564023a,0xafd80162,0x7648015d}},	//   арё_, _voih, _frøi, _erfy, 
   {{0xf1bc0241,0x00000000,0x00000000,0x00000000}},	//   _ahá_, --, --, --, 
   {{0x637028ef,0x65656d7d,0xf1bc01e7,0x20000113}},	//   _hänk, _toih, _bhá_, wsii_, 
   {{0xf1bd6d7e,0x44216d7f,0x63701b99,0x51540137}},	//   _chá_, ptk_, _känk, отуу, 
   {{0xf1bc0491,0x7c216d80,0x63716d81,0xf53c0267}},	// [25d20] _dhá_, xtor, _jänk, rlåt_, 
   {{0x20016d82,0x7c216d83,0x9958002e,0xb4d96d84}},	//   rsii_, vtor, _péŋ_, ndàn, 
   {{0x637004f3,0x20016d85,0x7c216d86,0xc2c46762}},	//   _länk, ssii_, wtor, _ديدي, 
   {{0x7c21248f,0xf1bc007b,0x9f40004e,0x200001f4}},	//   ttor, _ghá_, spià_, psii_, 
   {{0x9f4019f5,0xefb0006c,0x20000009,0x7b64839a}},	//   ppià_, _کیلگ, qsii_, йтке, 
   {{0x7c2032ff,0xafe16d87,0x92d80c58,0x26000205}},	//   rtor, _хорл, াৰী_, kıo_, 
   {{0x3f881479,0x5a3402bf,0xba2804fb,0x00000000}},	//   _imbu_, інит, استم_, --, 
   {{0x63716d88,0x7d9400c6,0xdce002e2,0xf1c00220}},	//   _bänk, _الرؤ, _komč, _ﺣﺎﻟﻘ, 
   {{0x63700267,0x06c400cc,0x00000000,0x00000000}},	//   _vänj, _শ্লি, --, --, 
   {{0x8b6406d5,0xdce1354e,0xfafc005f,0x2bc40f1a}},	//   _والم, _momč, šība_, _глуп_, 
   {{0xaa080050,0x3a981b04,0x637001e3,0xc7b800e5}},	//   _معنے_, _стаю_, _tänj, mtől_, 
   {{0x7af85573,0x63716d89,0x3a3c00d7,0xc7b800e5}},	//   _hett, _fänk, _istp_, ltől_, 
   {{0xafd80feb,0xdb1801bf,0x00000000,0x00000000}},	//   _trøi, rmvæ, --, --, 
   {{0x7af96d8a,0xafd806ea,0xf1bc0332,0xc7b801d3}},	//   _jett, _krøv, _shá_, ntől_, 
   {{0xf1bc07ae,0x77a40014,0x918801e0,0x63700139}},	//   _phá_, _پُژِ_, араҡ_, _zänk, 
   {{0x92d803f4,0x3f880438,0xdb18007c,0xf53c4836}},	//   ারে_, _ambu_, lmvä, rlås_, 
   {{0x7af8509b,0xf53d38f2,0xc7b801ed,0x64c400cf}},	// [25d30] _oett, slås_, ktől_, _ىيىل, 
   {{0x7af96d8b,0xdce16d8c,0x00000000,0x00000000}},	//   _nett, _domč, --, --, 
   {{0x3a3c2a1f,0x2efc004a,0xb62804ce,0x63a01de4}},	//   _nstp_, _œufs_, _ｗｗ_, émne, 
   {{0x3f896d8d,0xdce0007f,0x7af802d2,0x61e80216}},	//   _embu_, _fomč, _aett, ídle, 
   {{0x7af80c3e,0xe3b10d6c,0x628800d0,0xa1942360}},	//   _bett, _زری_, údov, _хаяч, 
   {{0x7af83d24,0xafd8f5b8,0x31c402dd,0x2ee000d8}},	//   _cett, _brøv, _ءﺷﻮﭖ_, _ufjf_, 
   {{0x7af96d8e,0x63716d8f,0xaca0063f,0x8c440032}},	//   _dett, _sänk, _idọn, сеһе, 
   {{0x7af96d90,0xafd82b96,0x00000000,0x00000000}},	//   _eett, _drøv, --, --, 
   {{0x4758177b,0xafd801bf,0xd5b800ef,0x00000000}},	//   арня_, _usød, gtām_, --, 
   {{0x7af8dcfb,0xf41c00bd,0xc6056d91,0x69d40005}},	//   _gett, ধবার_, озой, íxes, 
   {{0xda0800aa,0x21d800b0,0x2d8c007b,0xdb5813f3}},	//   _هيله_, _kōhe_, oige_, _уют_, 
   {{0x63716d92,0x2d8d6d93,0x7af96d94,0x92d8015b}},	//   _tänk, nige_, _zett, ারো_, 
   {{0x7af96d95,0x2d8c005c,0x00000000,0x00000000}},	//   _yett, iige_, --, --, 
   {{0x2d8d6d96,0xb4d8004e,0x7af8f28f,0x63700432}},	//   hige_, ldàl, _xett, _käni, 
   {{0x32416d97,0xe924031c,0x6370005b,0x80f8681b}},	//   мерг, _རྡོབ_, _jäni, ихат_, 
   {{0xaca001f2,0x637029ef,0xb4d85b9e,0xc7b800e5}},	//   _adọn, _mäni, ndàl, ztől_, 
   {{0x2d8d6d98,0x42d4dbe2,0x92d80c58,0x65600267}},	// [25d40] dige_, _міну, াৰে_, ömhu, 
   {{0x4430035b,0x2d8c0158,0x6aa8012d,0x00000000}},	//   _ipy_, eige_, _ज़रूर, --, 
   {{0x7af82759,0x07201092,0x2d8d6d99,0xf4840344}},	//   _rett, _मानव_, fige_, _هایی, 
   {{0x2d8d6d9a,0xdce000d7,0x00000000,0x00000000}},	//   gige_, _tomč, --, --, 
   {{0xe924025c,0xb3440139,0xc7b801d3,0xac943997}},	//   _རྡེབ_, _kiçе, ttől_, ينما_, 
   {{0xafd87a1e,0x3dc40280,0xd9b41944,0x2d8c07f0}},	//   _prøv, smow_, ुष्ट, aige_, 
   {{0xfce402bf,0x2d8d6d9b,0xfe4017a5,0xc7b801d3}},	//   _мово, bige_, _تکذی, rtől_, 
   {{0x7af96d9c,0x3d740014,0x2d8c07f5,0x44300022}},	//   _wett, _بُرز, cige_, _opy_, 
   {{0x7af96d9d,0x4430045a,0x23bc043e,0xcdc401ec}},	//   _tett, _npy_, ोगाद, _хатқ, 
   {{0x9abc0327,0x7af805d5,0x80a000e1,0x637000fd}},	//   _acċe, _uett, _कुछे, _fäni, 
   {{0x44316d9e,0x9f401b5d,0x973c07f5,0xd5b80a2f}},	//   _apy_, mpiä_, noći, stām_, 
   {{0x44300165,0xafd805ac,0x758800c9,0x9f4001f4}},	//   _bpy_, _krøt, рсов_, lpiä_, 
   {{0xf7440364,0x44310a47,0x92d803d4,0x00000000}},	//   _медо, _cpy_, াৰো_, --, 
   {{0x2d8d6d9f,0xe7342bba,0x2d840309,0x63700139}},	//   zige_, _меч_, énez_, _yäni, 
   {{0x44316da0,0x236c01e6,0x2d8c0337,0x6370013d}},	//   _epy_, ödja_, yige_, _xäni, 
   {{0x2d8c102c,0x00000000,0x00000000,0x00000000}},	//   xige_, --, --, --, 
   {{0x2d8d6da1,0xb36400a7,0xa19401b9,0x00000000}},	// [25d50] vige_, _дънк, фатч, --, 
   {{0x2d8c5b5e,0x643401f7,0x6384119e,0x00000000}},	//   wige_, _آريء, _огња, --, 
   {{0xf1a80133,0x00000000,0x00000000,0x00000000}},	//   _ناحه_, --, --, --, 
   {{0x62581682,0xafd8b3f8,0x44300588,0x637021c6}},	//   _ḓod, _brøt, _ypy_, _räni, 
   {{0xdca807f7,0xe6c8148b,0x00000000,0x00000000}},	//   _छुआछ, íbúð, --, --, 
   {{0xcfa40022,0x49c8329e,0x8fa40066,0x00000000}},	//   _хымҩ, әлин_, _رمزه, --, 
   {{0x78a0009a,0x21d800b0,0xef20005f,0x5f8407d2}},	//   _axov, _tōhe_, _ceļš_, _تۇلە, 
   {{0xe29c0375,0xd5b800e2,0x63700267,0x5dcc0150}},	//   ישור, stāj_, _väni, _ﺑﺎﻳﺴ, 
   {{0x2d9c01f7,0xafd84098,0xb4d8004e,0x0f400092}},	//   _ijue_, _grøt, rdàl, _የማስረ, 
   {{0x63716da2,0x06841f39,0xe5e002dd,0x00000000}},	//   _hänv, згон, _ﺍﻟﻭﺜ, --, 
   {{0x4430b76c,0xdce0002b,0xc7b800e5,0x00000000}},	//   _spy_, _homā, ltők_, --, 
   {{0x7ab80375,0x443000b5,0xfa680116,0x3ab8011a}},	//   _הצעו, _ppy_, _учуқ_, _המענ, 
   {{0x2d9c01c8,0xdce000e2,0xc7b800e5,0x00000000}},	//   _mjue_, _jomā, ntők_, --, 
   {{0xe5180037,0x00000000,0x00000000,0x00000000}},	//   _थाकि_, --, --, --, 
   {{0xaac96da3,0xdce00a2f,0x72c000f0,0x00000000}},	//   ाधिक, _lomā, ебрз, --, 
   {{0x2d9c009f,0x64416da4,0x00000000,0x00000000}},	//   _njue_, æmis, --, --, 
   {{0x4430035b,0xdce000e2,0x9f4001f4,0x00000000}},	// [25d60] _upy_, _nomā, ypiä_, --, 
   {{0x2d9c01c8,0xa0683007,0x42240c69,0x00000000}},	//   _ajue_, баға_, _едов, --, 
   {{0x63700054,0xdce002b5,0x32d8011a,0xc0e4022e}},	//   _sänw, _aomā, _לחינ, _нонк, 
   {{0x2d9c0356,0xada0e8fc,0x6da0bb61,0x00000000}},	//   _cjue_, нахл, ниха, --, 
   {{0xdc544d2f,0xafd8143a,0xafe00dab,0x00000000}},	//   براک, _drøs, _поял, --, 
   {{0xdce000da,0xc0dc0023,0xdb0841bb,0x00000000}},	//   _domā, ሕያሽ_, _ölüs, --, 
   {{0x25a0003e,0xafd85522,0x4aa8000d,0x00000000}},	//   _ojil_, _frøs, _चुआव, --, 
   {{0xafd808fb,0xcdc40220,0x78a00139,0x63700166}},	//   _trøt, _жасқ, _pxov, _tänw, 
   {{0x6da15092,0x7d016da5,0x3ce56da6,0x37a82592}},	//   _чита, maos, mcov_, йтон_, 
   {{0x7d000c67,0x25a16da7,0x3ce40030,0xbb8430a7}},	//   laos, _ajil_, lcov_, _علاي, 
   {{0x81e00729,0xf1bc00d0,0x7bc8002f,0x00000000}},	//   নীত_, úške_, mmfu, --, 
   {{0x7d016da8,0x3ce401a2,0x63700036,0xdb08004b}},	//   naos, ncov_, _mänu, _دزړه_, 
   {{0x78a0014b,0xe924025c,0x00000000,0x00000000}},	//   _uxov, _རྡིབ_, --, --, 
   {{0x39456da9,0xa8540375,0x7d016daa,0xe60c6109}},	//   _haos_, _מידה_, haos, خشی_, 
   {{0xc7641dc8,0x7bc800f1,0x7108009d,0x35740117}},	//   _تانى, imfu, йхав_, _накӯ_, 
   {{0x7d0025e4,0x3ce56dab,0x39456dac,0x61e81155}},	//   jaos, jcov_, _jaos_, ídla, 
   {{0x3944255a,0xa06803b7,0x8c3c887f,0x3ce401f1}},	// [25d70] _maos_, паѓа_, _oxşa, dcov_, 
   {{0x39441590,0xdce00f40,0xafd95b21,0x00000000}},	//   _laos_, _romā, _brør, --, 
   {{0x7d000618,0x31e4015b,0xdce03da0,0x547450d8}},	//   faos, _ফিকশ, _somā, _رهگذ, 
   {{0x8c3c03be,0x3ce40218,0x7d016dad,0x7bc8004b}},	//   _axşa, gcov_, gaos, emfu, 
   {{0xcb680e92,0xe5e00220,0x0ea801f9,0x00000000}},	//   жале_, _ﺍﻟﻤﺜ, _कडकड, --, 
   {{0x072038b0,0xc0c01f0e,0xfafc005f,0xafd801bf}},	//   _माधव_, _рәси, šīna_, _frør, 
   {{0x9e34c11f,0x2d9c332c,0xafd81477,0x3ce56dab}},	//   _перч, _tjue_, _trøs, bcov_, 
   {{0xeee801dc,0x39456dae,0x7d016daf,0x637002f6}},	//   _động_, _caos_, caos, _hänt, 
   {{0x39440165,0x637001e3,0x31680210,0x00000000}},	//   _daos_, _känt, _mocz_, --, 
   {{0x06096db0,0x63703b22,0x00000000,0x00000000}},	//   онок_, _jänt, --, --, 
   {{0x39440156,0x6370023a,0xf1bc08e6,0x00000000}},	//   _faos_, _mänt, ्षान, --, 
   {{0xe8dc01f2,0x39456db1,0xd04c0198,0x6370005b}},	//   _kpọm_, _gaos_, ncaɓ, _länt, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x5ea80154,0x3ce400d0,0x7d0002f0,0x291c7db4}},	//   কেটে, zcov_, zaos, lgua_, 
   {{0x7d00009f,0x760001d3,0x291c00e4,0x00000000}},	//   yaos, _vízá, ogua_, --, 
   {{0x291d6db2,0x85047e89,0x6f040085,0xa084ca0f}},	//   ngua_, _کوکن, yébí, еңме, 
   {{0x3ce401f1,0x291c035b,0x7dd800c0,0x00000000}},	// [25d80] vcov_, igua_, _lįst, --, 
   {{0x64456db3,0x6370014a,0xefd8001f,0x7d000214}},	//   _isii, _pänu, ኖሪያ_, waos, 
   {{0x7d00b6c9,0xe6b803e5,0x3ce40419,0x00000000}},	//   taos, _उरोज, tcov_, --, 
   {{0x389c063f,0x00000000,0x00000000,0x00000000}},	//   ịri_, --, --, --, 
   {{0x3944255a,0x3ce5698f,0x7d016db4,0x00000000}},	//   _raos_, rcov_, raos, --, 
   {{0x3ce56db5,0x63716db6,0x3944fa68,0x7d016db7}},	//   scov_, _tänu, _saos_, saos, 
   {{0x39440438,0x637001e6,0xafd80a64,0x3ce40030}},	//   _paos_, _häns, _urør, pcov_, 
   {{0xd910d45b,0x637004f3,0x64456db8,0x21216db9}},	//   ایش_, _käns, _osii, ngih_, 
   {{0x7bc802c4,0x64440337,0x39456dba,0x637001f4}},	//   pmfu, _nsii, _vaos_, _jäns, 
   {{0x6370049f,0x21200399,0xfa3402dd,0x39440e47}},	//   _mäns, hgih_, _يراد, _waos_, 
   {{0x63716dbb,0x64456dbc,0x39456dbd,0x1cdc025c}},	//   _läns, _asii, _taos_, _རྔོ_, 
   {{0x21200007,0x291c00e4,0x00000000,0x00000000}},	//   jgih_, cgua_, --, --, 
   {{0xb4d8026c,0xb9dc0092,0xe58800db,0x00000000}},	//   ndài, _ባሻ_, بۅيۉ_, --, 
   {{0xf77001ed,0x337001f0,0x399800de,0x00000000}},	//   _جاؤ_, тҳор, dīsi_, --, 
   {{0xd84807ae,0x63716dbe,0x6444049b,0x31680063}},	//   _họ_, _ränt, _esii, ошао_, 
   {{0x21200502,0x63716dbf,0xa1580220,0x9f40026c}},	//   ggih_, _sänt, масу_, mpiù_, 
   {{0x84c00075,0xd8480ca8,0x637001f4,0xb5e40220}},	// [25d90] _бәрд, _jọ_, _pänt, _ﺍﻟﻠﻌ, 
   {{0xd848110e,0x973c01a6,0xb51c0037,0x5ea800eb}},	//   _mọ_, poću, _भाँय_, কেছে, 
   {{0xd8480570,0x637004f3,0x291c0588,0x929401af}},	//   _lọ_, _vänt, ygua_, _чанц, 
   {{0xafd80b1a,0x63700139,0xdce00356,0xc7b801d3}},	//   _frøp, _fäns, _romă, rtői_, 
   {{0xd84805db,0xe6b80cb3,0x6370e6f0,0x3cf00022}},	//   _nọ_, _उर्ज, _gäns, ñyva_, 
   {{0xce9402e8,0x00000000,0x00000000,0x00000000}},	//   _загъ, --, --, --, 
   {{0x2d845725,0x637000a2,0x00000000,0x00000000}},	//   ènes_, _känr, --, --, 
   {{0xd8496dc0,0x291d181f,0x19d401ec,0x00000000}},	//   _bọ_, ugua_, _ﺟﺎﻧﺠ, --, 
   {{0xc7940f45,0xaca001f2,0x6d596dc1,0xdd7401ed}},	//   ерны, _mpịa, _inua, _جھلک, 
   {{0x6d496dc2,0x21200369,0xaac42309,0x00000000}},	//   ldga, zgih_, _قتان, --, 
   {{0x644404ba,0xf1d88e37,0x6d480072,0x00000000}},	//   _ssii, _मंगन, odga, --, 
   {{0xd8480248,0x37500228,0x00000000,0x00000000}},	//   _fọ_, _ەپوس, --, --, 
   {{0x3998010f,0x63a000d7,0x00000000,0x00000000}},	//   _צינד, émno, --, --, 
   {{0x6b816dc3,0x61e802fb,0x637001f4,0x61a83599}},	//   nhng, ídlo, _räns, कक्ष, 
   {{0x6d596dc4,0x63700793,0x64440009,0x00000000}},	//   _onua, _säns, _wsii, --, 
   {{0x64456dc5,0x6d580134,0xd8480ca8,0x00000000}},	//   _tsii, _nnua, _yọ_, --, 
   {{0x64456dc6,0x2120011f,0x6d496dc7,0x3f140798}},	// [25da0] _usii, rgih_, ddga, еќет, 
   {{0x6d596dc8,0x637004f3,0xa0696ac2,0x6d48127b}},	//   _anua, _väns, паға_, edga, 
   {{0x1cdc025c,0x6370007c,0x00000000,0x00000000}},	//   _རྔུ_, _fänr, --, --, 
   {{0xfce4d3a6,0xbca40075,0xd5b8005f,0xf41c014a}},	//   ходо, ىماي, stāv_, izän_, 
   {{0xb5e40046,0x00000000,0x00000000,0x00000000}},	//   _ﺍﻟﻤﻌ, --, --, --, 
   {{0xd8496dc9,0x6d580428,0x6d4801bf,0x00000000}},	//   _rọ_, _enua, adga, --, 
   {{0xd8496dca,0x3ebc1873,0x81e000bd,0x6d5800ca}},	//   _sọ_, _átt_, নীর_, _fnua, 
   {{0xe730013f,0xb4d835f5,0xd8480ca8,0x79a40209}},	//   _abε_, ldàv, _pọ_, эрле, 
   {{0x49902d56,0x0bb80150,0x00000000,0x00000000}},	//   جینر, _ﺸﻬﺩﻫ, --, --, 
   {{0xb4d96dcb,0x795003e6,0x6b800208,0x290c0064}},	//   ndàv, _ڕێبا, chng, _edga_, 
   {{0x7bd80098,0xd7f806dc,0xd8480ca8,0xf934009d}},	//   _iitu, чуқ_, _wọ_, _зүйч_, 
   {{0x7bd96dcc,0x37e40107,0xd8480ca8,0x00000000}},	//   _hitu, _зодг, _tọ_, --, 
   {{0x7bd96dcd,0x28100ccb,0xfd64002b,0xa9640035}},	//   _kitu, _مونس, _dauḥ, _سموم_, 
   {{0x7bd96dce,0x9f4086ed,0xa884010a,0x00000000}},	//   _jitu, ppiù_, _яйча_, --, 
   {{0x7bd96dcf,0x2258248c,0x47880006,0x62340064}},	//   _mitu, ниры_, _ўсім_, леру, 
   {{0x61d87798,0xe60d6dd0,0x545414f0,0x00000000}},	//   емся_, _اشو_, _авит, --, 
   {{0x7bd85c71,0xe1356dd1,0x81e00011,0xd0101955}},	// [25db0] _oitu, ынты, নীল_, شلا_, 
   {{0xf53d6dd2,0x64480882,0x6d5801c3,0x77780175}},	//   leå_, ādit, _snua, nktx, 
   {{0xfc480165,0xe71402e4,0x1fa4010b,0xc33001e4}},	//   _aṭ_, תחבר_, уртг, _דוי_, 
   {{0x7bd96dd3,0xa2c801e0,0xbdb80014,0x6d496dd4}},	//   _aitu, _яуыз_, ونٕچ_, udga, 
   {{0x6d496dd5,0xd5b800e2,0xa3b8015e,0x00000000}},	//   rdga, ltās_, _زایر_, --, 
   {{0x7bd85914,0x9f940730,0x6d4802d0,0xc7b800e5}},	//   _citu, mäß_, sdga, ntőt_, 
   {{0x7bd96dd6,0x62581682,0xd5b81c52,0x00000000}},	//   _ditu, _ḽon, ntās_, --, 
   {{0x6d5804ac,0x7bd96dd7,0x6b8003a2,0x27ec05b1}},	//   _unua, _eitu, shng, _ptgn_, 
   {{0x7bd96dd8,0x07a4119e,0x08c40818,0x00000000}},	//   _fitu, каин, ъбин, --, 
   {{0x7bd94000,0xd5b80318,0x00000000,0x00000000}},	//   _gitu, ktās_, --, --, 
   {{0x68e80009,0x46a400d8,0x290801e7,0x00000000}},	//   _tfgd, танв, ócas_, --, 
   {{0x7bd96dd9,0xb90400bd,0x00000000,0x00000000}},	//   _zitu, _বড়_, --, --, 
   {{0x7bd96dda,0xd5b800de,0x52746191,0x35a00139}},	//   _yitu, etās_, қуру, раяг, 
   {{0xe1f80aa5,0x7bd807a9,0xd5e84e5c,0x58d40108}},	//   нҳо_, _xitu, بعین_, _сочт, 
   {{0x41285a41,0xd5b80171,0x00000000,0x00000000}},	//   мово_, gtās_, --, --, 
   {{0xaad03806,0x9f940112,0x765c0064,0x00000000}},	//   धेयक, fäß_, _špyg, --, 
   {{0x7fd40212,0xafe004b4,0x200c0055,0x00000000}},	// [25dc0] віжі, иотл, _ādis_, --, 
   {{0xef156ddb,0x1acc00bd,0xd5b848e1,0x637000fd}},	//   кму_, রুয়া, stāt_, _tänq, 
   {{0x527405a2,0x2be4000d,0x00000000,0x00000000}},	//   _буяу, _छूबू_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7bd96ddc,0xc7b801ed,0x14d401f9,0x00000000}},	//   _pitu, ntős_, ठेपण, --, 
   {{0x7bd807d6,0xf53c0004,0x00000000,0x00000000}},	//   _qitu, zeå_, --, --, 
   {{0x7bd96ddd,0x79a473b8,0x96f80588,0x57b40131}},	//   _vitu, крие, ҭеит_, һбит, 
   {{0x3c900bce,0x7bd96dde,0x69180254,0xed54d3ff}},	//   _پیتز, _witu, väeü, _иос_, 
   {{0xb908084a,0x57b56ddf,0xda7001d9,0x00000000}},	//   _मल_, лбит, شُک_, --, 
   {{0x7bd92067,0x1cdc0327,0xf5e401ec,0x00000000}},	//   _uitu, _རྔག_, кімм, --, 
   {{0xf53c01e6,0xab7400ec,0x569401ee,0x00000000}},	//   teå_, _جملا_, уант, --, 
   {{0x77780bc9,0x888001e0,0x5804014b,0x46f000d1}},	//   sktx, рғәл, _бодғ, لۋۇر, 
   {{0xf53d6de0,0x7980e193,0xc7b801d3,0x00000000}},	//   reå_, _ilow, ttőt_, --, 
   {{0xa3a41d39,0x00000000,0x00000000,0x00000000}},	//   ајск, --, --, --, 
   {{0x79816de1,0xd5b8005f,0xc76404b3,0xe734033a}},	//   _klow, utās_, _حانى, _реј_, 
   {{0xd5b800e2,0xc6d8008f,0x5f7401d5,0x200c002b}},	//   rtās_, _אַפר, یالر, _ādir_, 
   {{0xd5b8005f,0x798001f7,0x905402d5,0xb4440a89}},	// [25dd0] stās_, _mlow, ывац, _рэйк, 
   {{0x8c3c010b,0x79800142,0xb43000d7,0x00000000}},	//   _gyşy, _llow, ľúčo, --, 
   {{0xdebc0198,0x79816de2,0xb4d801ab,0xd2502ed7}},	//   _karƙ, _olow, beàc, _انج_, 
   {{0x798001e1,0x2dcc0116,0x00000000,0x00000000}},	//   _nlow, _ﺑﺎﻗﻤ, --, --, 
   {{0xfde000c5,0xdb080051,0x00000000,0x00000000}},	//   _औंअस_, _đoòn, --, --, 
   {{0x79803c2a,0x3998005f,0x2a84002e,0xa520012c}},	//   _alow, zīst_, _rёbb_, _मञ्च_, 
   {{0x79816de3,0x28f00131,0x52c001ad,0x06e00154}},	//   _blow, لۋاس, _एरोस, _মজলি, 
   {{0x79800d8b,0x00000000,0x00000000,0x00000000}},	//   _clow, --, --, --, 
   {{0x1d2801b9,0xc8b40137,0x00000000,0x00000000}},	//   _шўро_, ыскы, --, --, 
   {{0x79816de4,0x8a040166,0x9cc800c0,0x00000000}},	//   _elow, _бюдҗ, _рыса_, --, 
   {{0x98b800e2,0x09e000fe,0x00000000,0x00000000}},	//   īzāk_, _গৌৰৱ_, --, --, 
   {{0x9a856de5,0x7a78008f,0x79800e21,0xc7b801d3}},	//   _туул, _ארעס, _glow, ttős_, 
   {{0x68f96de6,0x8c3c0432,0x00000000,0x00000000}},	//   mbud, _pyşy, --, --, 
   {{0xade01152,0x68f817c1,0xe798b79f,0x38980375}},	//   गदान_, lbud, _تخصص_, _איננ, 
   {{0x66e000fb,0xc87800ee,0x00000000,0x00000000}},	//   _йоҙа, lyş_, --, --, 
   {{0x68f803a2,0xdebc0198,0x044401f0,0xade40037}},	//   nbud, _garƙ, _беин, _ओढ़न_, 
   {{0xc87800ee,0x68f8004c,0x7dd8012c,0x0f400092}},	// [25de0] nyş_, ibud, _důsl, _የማምረ, 
   {{0x4420e030,0x7dd80316,0x68f814ea,0x00000000}},	//   muk_, _půso, hbud, --, 
   {{0x2ff400d1,0xc87800a2,0x00000000,0x00000000}},	//   نتەڭ, hyş_, --, --, 
   {{0xc8780209,0x00000000,0x00000000,0x00000000}},	//   kyş_, --, --, --, 
   {{0x44216de7,0x68f96de8,0x00000000,0x00000000}},	//   nuk_, dbud, --, --, 
   {{0x79816de9,0x44200194,0xccf80210,0xc8780432}},	//   _slow, iuk_, _wośp_, dyş_, 
   {{0x44216dea,0xaa905026,0xb4d835fb,0xcee80014}},	//   huk_, йишч, ndàr, _جرُن_, 
   {{0x44203ce5,0x69c802c4,0xac8029db,0x7f4c058a}},	//   kuk_, _chge, ргәл, _habq, 
   {{0x44216deb,0x7f4c0218,0xdb196dec,0xc878010b}},	//   juk_, _kabq, llví, gyş_, 
   {{0x44216ded,0x3f982831,0x9f40d819,0xdebc03f9}},	//   duk_, nipu_, mpió_, _sarƙ, 
   {{0x7c216dee,0x26c40589,0x44207e7d,0x16340815}},	//   luor, _czno_, euk_, шеня, 
   {{0x44216def,0x79816df0,0x68f8011f,0x3f9800b0}},	//   fuk_, _ulow, cbud, hipu_, 
   {{0x44216df1,0xa8756df2,0x7c20e1db,0xf9f400cc}},	//   guk_, _محور_, nuor, _ঘটিল_, 
   {{0x3f98009f,0x69c80023,0xa1840032,0x6840084c}},	//   jipu_, _zhge, ҡытл, _ынча, 
   {{0x7c216df3,0x3f98004e,0x44201337,0x6fc80205}},	//   huor, dipu_, auk_, nüce, 
   {{0x44216df4,0xeee8001e,0x7c216df5,0x44b402e3}},	//   buk_, _đống_, kuor, ọsụ_, 
   {{0x44216df6,0x059403e6,0xb5e401ec,0xe3b00133}},	// [25df0] cuk_, _ڕایگ, _ﺍﻟﻀﻌ, ترێ_, 
   {{0x7c216df7,0xeea92361,0x3f980421,0x68f96df8}},	//   duor, нтек_, gipu_, zbud, 
   {{0x7f4c0429,0x68f96df9,0x00000000,0x00000000}},	//   _dabq, ybud, --, --, 
   {{0x91801b16,0x7c201570,0x71456dfa,0x3f980421}},	//   _بۇرۇ, fuor, _схож, aipu_, 
   {{0xf3fc0798,0x68f8005c,0x6ea0033f,0x6ee56dfb}},	//   ixão_, vbud, कपहु, _مسأل, 
   {{0x5c04652e,0x7f4c0429,0x3f98c992,0xb5e401ec}},	//   сяца, _gabq, cipu_, _ﺍﻟﻁﻌ, 
   {{0xd1c4693c,0x44216dfc,0x00000000,0x00000000}},	//   _ጸሎት_, zuk_, --, --, 
   {{0x44216dfd,0x6f040455,0x7c216dfe,0x81e000fe}},	//   yuk_, _hejc, buor, নীক_, 
   {{0x7c216dff,0xd90d6e00,0x44200429,0x0f5c001f}},	//   cuor, ریو_, xuk_, _ለማስረ, 
   {{0x5c740e26,0x47596e01,0x44216e02,0xa9a00014}},	//   _улут, трия_, vuk_, _گۅبى, 
   {{0x44216e03,0x6f04014f,0x77c401c0,0x66cc00e5}},	//   wuk_, _mejc, рлэг_, dóké, 
   {{0x44216e04,0x85951f22,0x68f8025c,0x99481e24}},	//   tuk_, ршоц, qbud, _ململ_, 
   {{0x99d42688,0x66080006,0x27b00075,0x44216e05}},	//   _اتلا, _šokė, _гәнс, uuk_, 
   {{0x44216e06,0x6f056e07,0x2cbc0139,0x3f9801c7}},	//   ruk_, _nejc, _myud_, xipu_, 
   {{0x442166e0,0x12196e08,0x7c200112,0x41b4007b}},	//   suk_, люты_, zuor, لمسر, 
   {{0x44200d51,0x21d800b0,0x7f4cc7e9,0xdce0013a}},	//   puk_, _kōhi_, _sabq, _domě, 
   {{0x3f996e09,0x6f04047e,0x7f4c0477,0x4420102c}},	// [25e00] tipu_, _bejc, _pabq, quk_, 
   {{0x7c216e0a,0x7f4d6e0b,0xafd8005c,0x6f0401ef}},	//   vuor, _qabq, _krøy, _cejc, 
   {{0x6f056e0c,0xf5541037,0x6cc002dd,0x00000000}},	//   _dejc, _صلیب_, _ﺩﺭﺍﺴ, --, 
   {{0x7c208d4a,0x3f996e0d,0x00000000,0x00000000}},	//   tuor, sipu_, --, --, 
   {{0x3f98026c,0xa08400fd,0xb4d800e4,0x7b6400db}},	//   pipu_, _уңае, ndàp, итке, 
   {{0x7c216e0e,0x6bd004b3,0x78b4168c,0x66000c8c}},	//   ruor, يتور, _øyvi, _ownk, 
   {{0xafd800b5,0x7c216e0f,0xefb0006c,0x5f44004b}},	//   _spøg, suor, _بیلگ, _پنځل, 
   {{0x7c2000b0,0x9f4005c7,0xbaa400d1,0xe9cc05af}},	//   puor, mpiñ_, луққ, وغي_, 
   {{0x7c216e10,0x2cbc22b9,0x66000784,0x9f400165}},	//   quor, _gyud_, _awnk, lpiñ_, 
   {{0xafd808fb,0x00000000,0x00000000,0x00000000}},	//   _brøy, --, --, --, 
   {{0x70c00034,0xd1c40b82,0xe94400a2,0x95d800d8}},	//   _शर्ल, _ጸሎቱ_, _üyşü, лдот_, 
   {{0xafd8168c,0x6be002dd,0x60800092,0x00000000}},	//   _drøy, _اكەم, _የመጡት_, --, 
   {{0x0f1000bd,0x66cc01d3,0x9aa400fb,0x00000000}},	//   স্টঃ_, tóké, _туҡһ, --, 
   {{0xafd8168c,0x1cdc0327,0x00000000,0x00000000}},	//   _frøy, _རྔབ_, --, --, 
   {{0xdce00316,0x6f040427,0x555801c6,0x00000000}},	//   _pomě, _rejc, _байя_, --, 
   {{0x6f04036e,0xa1140014,0x26d8011a,0x258800db}},	//   _sejc, ٲوٕت, _בקומ, _ۅنۉپ_, 
   {{0xe3b01d1f,0x0f14063b,0x3a3c0093,0x2eac0034}},	// [25e10] _ڪري_, ймаю, _lptp_, _जुड़त, 
   {{0xeee801dc,0x6f040455,0x8c880124,0x00000000}},	//   _đồng_, _qejc, қәба_, --, 
   {{0xdfd806bb,0xe3b00be2,0x6f0400bc,0x00000000}},	//   рът_, _تري_, _vejc, --, 
   {{0xdea4036b,0x00000000,0x00000000,0x00000000}},	//   زیقی, --, --, --, 
   {{0x65a803e0,0x00000000,0x00000000,0x00000000}},	//   zıho, --, --, --, 
   {{0x81e0045e,0x3a3c020b,0x21d802b5,0x0f343016}},	//   নীও_, _bptp_, _rōhi_, _دکرد, 
   {{0x62980008,0x9f40c7cc,0xf41c013d,0x00000000}},	//   _þvot, ppiò_, hrä_, --, 
   {{0xc96405f5,0x21d802b5,0xcc0801d9,0x8b8400db}},	//   свий, _pōhi_, _مٲرن_, _گەتە_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf8ad6e11,0x9b740597,0x7c249c2a,0xafd82dba}},	//   رکن_, _والص, _åkra, _prøy, 
   {{0xc76404a9,0xf1c42232,0xf5e401c0,0x7dc803b2}},	//   لاھى, लतान, ймэл_, lýsa, 
   {{0xaca0001e,0x21d802b5,0x398801c3,0xe5780107}},	//   _ngừn, _tōhi_, _rùsg_, рҷи_, 
   {{0x2b1802f8,0xf09c01ab,0xe7900014,0x74e402dd}},	//   _नयाँ_, _seàn_, _واتک, _ﺍﯞﻻﻳ, 
   {{0xafd84673,0xa8000724,0x00000000,0x00000000}},	//   _trøy, _çıqq, --, --, 
   {{0x1cdc0135,0xb6a16e12,0xafd80158,0xf8a403e6}},	//   _རྔན_, _нишл, _urøy, _نگیه_, 
   {{0x1724025c,0x057402f2,0x00000000,0x00000000}},	//   _འཐོམ_, _چاکد, --, --, 
   {{0x65656e13,0x00c8f880,0x00000000,0x00000000}},	// [25e20] _inih, улак_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x656403c6,0x00000000,0x00000000,0x00000000}},	//   _knih, --, --, --, 
   {{0x3cc40150,0x3c643947,0x00000000,0x00000000}},	//   _ﺩﻭﺍﻤ, йкег, --, --, 
   {{0x44300076,0x31540375,0x00000000,0x00000000}},	//   _jqy_, _היכן_, --, --, 
   {{0xbf140150,0xa3d800cd,0x6ed06ac2,0x9b586ed2}},	//   _دوسب, िषि_, _भृकु, рикт_, 
   {{0x637004cc,0xed600308,0x65640241,0xc9b400ec}},	//   _bänz, áží_, _onih, ڊشيڊ, 
   {{0xf41d6e14,0x57f41553,0xb0580036,0x65656e15}},	//   yrä_, опит, _szäi, _nnih, 
   {{0x637001c7,0x7e7c0b1a,0xdb180240,0xa3d8193d}},	//   _dänz, lypp, novë, िषा_, 
   {{0x65656e16,0xd90c01ed,0xb7656e17,0xfaa56e18}},	//   _anih, ریڈ_, стий, _лазо, 
   {{0x656400c6,0x61fc01fa,0x6bd4004b,0x63700166}},	//   _bnih, jprl, _اولس_, _fänz, 
   {{0x398801e1,0x63700e78,0x61fc0219,0xdb180240}},	//   _bùse_, _gänz, dprl, kovë, 
   {{0x9f40022c,0x7e7c023a,0xe5e002dd,0xba040092}},	//   ypið_, hypp, _ﺍﻟﻜﺜ, _ላለ_, 
   {{0x6564379d,0xb9e00020,0xf41c02f6,0xa71002dd}},	//   _enih, _ካለ_, rrä_, _емші, 
   {{0x569411f4,0xe2f80150,0x00000000,0x00000000}},	//   _файт, сесі_, --, --, 
   {{0x66700150,0xb4b000d1,0x656400b8,0x6ed000cd}},	//   _ءدور, _нийә, _gnih, _भृगु, 
   {{0x6ee44439,0xb6202e56,0x84c00046,0xdb180240}},	// [25e30] مسال, _ﺩﻩ_, _жәрд, govë, 
   {{0x9f4001a8,0xdb196e19,0x00000000,0x00000000}},	//   upið_, llvæ, --, --, 
   {{0x9f402833,0xf3e8015b,0xb404036b,0x00000000}},	//   rpið_, _কবির_, _тўққ, --, 
   {{0xd5c89d35,0x1acc0c58,0xdb18ff98,0xeee8004d}},	//   रतिज, ৰুৱা, lovè, _đổng_, 
   {{0xf1bc0270,0x9f4005f7,0x0c2402bf,0xb5e402dd}},	//   _iká_, ppið_, імкн, _ﺍﻟﻔﻌ, 
   {{0x637001b8,0xef911655,0xdb1826b7,0x33ec06be}},	//   _bäny, _عیاد, novè, _müx_, 
   {{0x625806d6,0x37cc0154,0x7dc800e4,0x4a4400d4}},	//   _ḓow, রদার, sýsa, інив, 
   {{0x1cdc0135,0x6370013d,0x17240327,0x00000000}},	//   _རྔམ_, _däny, _འཐུམ_, --, 
   {{0x61fc0010,0x8ca40133,0x00000000,0x00000000}},	//   zprl, _بڕاو, --, --, 
   {{0x6564037e,0x00000000,0x00000000,0x00000000}},	//   _snih, --, --, --, 
   {{0x2b456e1a,0x63703411,0x05a802f6,0xdb180561}},	//   menc_, _tänz, ивой_, dovè, 
   {{0xf8ac03e6,0x96956e1b,0x2b456e1c,0xdb18005c}},	//   رکۆ_, ярыш, lenc_, glvæ, 
   {{0xa81405d9,0xd7f81fbe,0x00000000,0x00000000}},	//   _اڪبر_, _луј_, --, --, 
   {{0x2b4466ce,0xf1bd6e1d,0x37a00220,0xdb196e1e}},	//   nenc_, _aká_, _оқығ, govè, 
   {{0x2b4400db,0x00000000,0x00000000,0x00000000}},	//   ienc_, --, --, --, 
   {{0x65656e1f,0x00856e20,0xdb180023,0x2b456e21}},	//   _unih, олбо, tovë, henc_, 
   {{0x7dc803b2,0x2b440200,0x00000000,0x00000000}},	// [25e40] fýsn, kenc_, --, --, 
   {{0xbc687d5a,0xf1bc01e1,0x201c0e04,0xdb18036e}},	//   یمان_, _eká_, čvi_, rovë, 
   {{0xdb18069c,0x2b456e22,0xbea805d9,0xbd8c037e}},	//   sovë, denc_, جهان_, _ism店_, 
   {{0x63bd6e23,0xdb18457c,0x6b800007,0x973c041a}},	//   lorn, mové, ekng, miće, 
   {{0x973c0989,0xdb196e24,0x99800135,0x00000000}},	//   liće, lové, ċiż_, --, 
   {{0x63bd6e25,0x2b44004e,0xb0580254,0x442000ad}},	//   norn, genc_, _kyän, irk_, 
   {{0x0ba80e5a,0xdb180306,0x973c1b24,0x8fd4891e}},	//   حانى_, nové, niće, _хәтә, 
   {{0x98740b3b,0xa9c0010b,0x00000000,0x00000000}},	//   злиц, мсык, --, --, 
   {{0x7d016e26,0x63bd6e27,0xdb180ceb,0x973c05a1}},	//   mbos, korn, hové, hiće, 
   {{0x63bc0c95,0x3dc4c2ce,0xdb196e28,0x973c0552}},	//   jorn, llow_, kové, kiće, 
   {{0x63bd6e29,0x44216e2a,0x973c0552,0xdb180122}},	//   dorn, erk_, jiće, jové, 
   {{0x7d016e2b,0xa9656e2c,0x973c1591,0x37e40364}},	//   nbos, _миха_, diće, _додг, 
   {{0xb0580bc9,0x81b0015b,0x7d000af9,0x00000000}},	//   _ayän, য়গা_, ibos, --, 
   {{0x63bc32ff,0x3dc44da0,0x1724025c,0x7d016e2d}},	//   gorn, hlow_, _འཐིམ_, hbos, 
   {{0x44216e2e,0x973c0384,0xafd80158,0xdb196e2f}},	//   ark_, giće, _osør, gové, 
   {{0xdb18049f,0x7c203ade,0x3f896e30,0x44200e04}},	//   llvä, kror, _albu_, brk_, 
   {{0x63bd6e31,0x3dc566b4,0xfbc80b33,0x7c20036e}},	// [25e50] born, dlow_, िताम, jror, 
   {{0x248495a0,0x973c2220,0xf3fc0589,0xdb180122}},	//   ømme_, biće, mpã_, bové, 
   {{0xc33025f9,0x973c00f3,0xdb1802fb,0x7d0001d5}},	//   _אוי_, ciće, cové, fbos, 
   {{0x3dc5477d,0x7c200e78,0xdce00139,0x82d4011a}},	//   glow_, fror, _qomğ, _מותג_, 
   {{0xe3b029a4,0x2b456e32,0xdc9802bf,0x7c216e33}},	//   _سری_, tenc_, овці_, gror, 
   {{0x7d0001ab,0x3dc40009,0x00000000,0x00000000}},	//   abos, alow_, --, --, 
   {{0x7d014d6f,0x29080589,0x2b456e34,0x3dc40009}},	//   bbos, ºca_, renc_, blow_, 
   {{0x63bc1b5c,0x44216e35,0x7c216e36,0x2b4456ed}},	//   zorn, yrk_, bror, senc_, 
   {{0x7c216e37,0x973c110c,0xdb180308,0x2b44068c}},	//   cror, ziće, zové, penc_, 
   {{0x6a651885,0x63bd6e38,0xf53c01e3,0x00000000}},	//   _وطال, xorn, snål_, --, 
   {{0xa5080131,0x96956e39,0x00000000,0x00000000}},	//   يىدە_, дряш, --, --, 
   {{0x973c0bb8,0x28dc0882,0xdb196e3a,0x63bc0210}},	//   viće, _पृथि, vové, worn, 
   {{0x7bc402b5,0x19b800ae,0x00000000,0x00000000}},	//   _ūkui, _بطلة_, --, --, 
   {{0x27fc0502,0xdb196e3b,0x973c0552,0xb0580166}},	//   mpun_, tové, tiće, _pyän, 
   {{0x27fd6e3c,0x63bd6e3d,0x7d000024,0xd7740150}},	//   lpun_, rorn, ybos, _تانع, 
   {{0x63bd6e3e,0x973c1591,0xdb18724d,0x00000000}},	//   sorn, riće, rové, --, 
   {{0x27fd6e3f,0x973c05ce,0xdb196e40,0x7dd80118}},	// [25e60] npun_, siće, sové, _můst, 
   {{0xdb18457c,0x64451e6a,0x3dc56e41,0x63bc20ac}},	//   pové, _ipii, wlow_, qorn, 
   {{0x27fc970d,0x7d016e42,0x8a5800e2,0x3dc4045a}},	//   hpun_, tbos, šējā, tlow_, 
   {{0x27fd6e43,0xc2c4004b,0x932401ed,0x741001d5}},	//   kpun_, _ويکي, _ٹرین, _تویا, 
   {{0xec1019c5,0xfb840166,0xdb180108,0x6ce003de}},	//   فوند, зыйн, ylvä, ніше, 
   {{0x7d016e44,0x20016e45,0x644404ba,0x95900023}},	//   sbos, mpii_, _mpii, _ሂወትን_, 
   {{0x6e416e46,0x2000054e,0xf41c0036,0x00000000}},	//   _перз, lpii_, nzär_, --, 
   {{0x20009279,0x7d0001a9,0x00000000,0x00000000}},	//   opii_, qbos, --, --, 
   {{0x20000113,0x7dd800bc,0x7c200200,0x28dc00cd}},	//   npii_, _důst, qror, _पृदि, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x64456e47,0xb344315a,0xc7b801d3,0x38580214}},	//   _apii, _liçõ, mről_, _گشاد_, 
   {{0xc7b801ed,0x7588005b,0x00000000,0x00000000}},	//   lről_, ссов_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7dd80316,0x6c9c01ec,0xe2f852c4,0x6aac0205}},	//   _zůst, _ﺃﺒﻴﺏ_, зері_, _çifç, 
   {{0xdce000e2,0xc7b801d3,0x00000000,0x00000000}},	//   _komē, iről_, --, --, 
   {{0x0ef41098,0x59dc2d6b,0x00000000,0x00000000}},	//   इड्स_, मगिर, --, --, 
   {{0xc7b800dd,0x29d8063f,0xb05800fd,0x93b402e8}},	// [25e70] kről_, _ụaka_, _azär, _обиц, 
   {{0x7dc80008,0xeb180490,0x00000000,0x00000000}},	//   sýsl, _नयेत_, --, --, 
   {{0x91c400c7,0x680001e1,0xc7b801d3,0x59dc3af7}},	//   _жәал, _kíjò, dről_, मगार, 
   {{0xdce000de,0x399803ef,0x00000000,0x00000000}},	//   _nomē, būsi_, --, --, 
   {{0x7dd800bc,0xb058008e,0x00000000,0x00000000}},	//   _růst, _ezär, --, --, 
   {{0xbb400801,0xc7b801d3,0x00000000,0x00000000}},	//   вешк, gről_, --, --, 
   {{0xdce805d1,0xdfd400fd,0x7dd801ef,0x490801f9}},	//   _çoğa, _чоры, _půst, सरलो_, 
   {{0x27fd6e48,0x2d8400e2,0x68000248,0x00000000}},	//   tpun_, īnes_, _níjò, --, 
   {{0x27fc15a5,0x2460001f,0xdce000de,0x00000000}},	//   upun_, _ሲካሄድ_, _domē, --, 
   {{0x27fd6e49,0x06840d1d,0x77c4009d,0x00000000}},	//   rpun_, дгон, млыг_, --, 
   {{0x64456e4a,0x27fd6e4b,0x00000000,0x00000000}},	//   _spii, spun_, --, --, 
   {{0x6d496e4c,0x89640014,0x27fd6e4d,0x00000000}},	//   nega, _زُتن, ppun_, --, 
   {{0x2d9c013f,0x69d96e4e,0xa5080131,0x68e80857}},	//   _mmue_, mmue, يىگە_, _iggd, 
   {{0x6d496e4f,0x69d80023,0x3330003a,0x73e073c7}},	//   hega, lmue, _ccxx_, кояз, 
   {{0x6d48b123,0x290d6e50,0x00000000,0x00000000}},	//   kega, _kega_, --, --, 
   {{0x6d496e51,0x27e56e52,0x515405f5,0x290c94af}},	//   jega, _hinn_, нтуу, _jega_, 
   {{0x290c6eb4,0x27e56e53,0x973c0d0f,0x6444020c}},	// [25e80] _mega_, _kinn_, lića, _upii, 
   {{0x290d6e54,0x27e4025a,0x62581682,0x20000a40}},	//   _lega_, _jinn_, _ḓor, rpii_, 
   {{0x27e56e55,0x6d496e56,0x27ec01e6,0x290c020c}},	//   _minn_, fega, _lugn_, _oega_, 
   {{0x27e56e57,0x290d6e58,0x6d496e59,0x20016e5a}},	//   _linn_, _nega_, gega, ppii_, 
   {{0xc7b801ed,0x25a00037,0xbce001e0,0x26c400c0}},	//   tről_, _mmil_, тҡаһ, _lyno_, 
   {{0x290c007d,0x973c0cf4,0xbf143378,0x6d480037}},	//   _aega_, kića, _زورب, aega, 
   {{0x290d6e5b,0x25a0036b,0x26c400cc,0xbe3402dd}},	//   _bega_, _omil_, _nyno_, _تىزب, 
   {{0xdb1806ed,0x27e40afe,0xc7b801ed,0x6d9000d8}},	//   moví, _ainn_, sről_, _açaf, 
   {{0x290d6e5c,0x6cc16e5d,0xb9040a28,0x27e445bc}},	//   _dega_, _айта, _यः_, _binn_, 
   {{0x27e49a0f,0x290d362c,0x25a16729,0x68e803cd}},	//   _cinn_, _eega_, _amil_, _eggd, 
   {{0xdce00029,0x27e56e5e,0x7af802d0,0xdb180306}},	//   _tomē, _dinn_, _iftt, noví, 
   {{0x27e400fc,0x290d6e5f,0x79500133,0x69d8036e}},	//   _einn_, _gega_, _شێخا, cmue, 
   {{0x27e42e5c,0x7bc8017a,0xdb196e60,0x00000000}},	//   _finn_, olfu, hoví, --, 
   {{0x27e41859,0x6d496e61,0x290c0356,0xdb18473a}},	//   _ginn_, zega, _zega_, koví, 
   {{0x290c006f,0x68e96e62,0x6d496e63,0x5654004b}},	//   _yega_, _yggd, yega, _سرغړ, 
   {{0x27e56e64,0x9268678d,0xd5b8005f,0x6d496e65}},	//   _zinn_, орға_, irāk_, xega, 
   {{0x90980801,0x4fd56e66,0xb2e80014,0xdd4000a2}},	// [25e90] чват_, ежат, _وعدٕ_, _iňňi, 
   {{0x6d496e67,0x2d9c05b1,0x6fc8002f,0x00000000}},	//   wega, _smue_, mück, --, 
   {{0x6d496e68,0x6fc80e78,0xa02800d1,0x03d4011a}},	//   tega, lück, كسەك_, _רותם_, 
   {{0x7af86974,0x46a000c5,0xd5b800ef,0x00000000}},	//   _aftt, _ओइसह, drāk_, --, 
   {{0x290d6e69,0xcb68119e,0xf7600092,0xdde4008e}},	//   _rega_, зале_, ውሮፕላ, тәрү, 
   {{0x6d496e6a,0x290c493b,0xca540640,0x004400f1}},	//   sega, _sega_, етињ, _سیمي_, 
   {{0x6d496e6b,0x290c1dec,0x27e40013,0x7af801ab}},	//   pega, _pega_, _rinn_, _dftt, 
   {{0x27e56e6c,0x27ec07c5,0x26c40ea0,0x7af803ac}},	//   _sinn_, _pugn_, _ryno_, _eftt, 
   {{0x6d900561,0x27e56e6d,0x26c4002f,0x00000000}},	//   _açag, _pinn_, _syno_, --, 
   {{0x25a05b47,0x290d6e6e,0x973c4bc9,0x69d80036}},	//   _smil_, _wega_, tića, smue, 
   {{0x290c0f72,0x27e4ba6b,0x442401e4,0x00000000}},	//   _tega_, _vinn_, _ŭo_, --, 
   {{0x6a500cc1,0x27e46399,0x290c0421,0x69d80007}},	//   _nəfə, _winn_, _uega_, qmue, 
   {{0x27e56e6f,0x5eb000fe,0x00000000,0x00000000}},	//   _tinn_, _কৰাই, --, --, 
   {{0x973c107d,0xdd40010e,0xe1f80107,0x53800150}},	//   lićn, _eňňi, мҳо_, иқыз, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x25a16e70,0x6a5000ac,0x6fc80112,0xbad00150}},	//   _umil_, _cəfə, lüch, _ﺘﺭﺴﺎ, 
   {{0xf9901a4c,0x6a5000ac,0x999800b8,0x00000000}},	// [25ea0] ארן_, _dəfə, _ūrū_, --, 
   {{0xdb196e71,0x996c012c,0xefc40262,0xa290069d}},	//   toví, měť_, елул_, _ጭፍጨፋ_, 
   {{0x7dc809cc,0x00000000,0x00000000,0x00000000}},	//   lýsi, --, --, --, 
   {{0xfd106248,0xdb196e72,0x6fc80e78,0x7bc8090e}},	//   اجا_, roví, hüch, wlfu, 
   {{0xac041248,0x6fc80e78,0x7bc80083,0xb4d800e8}},	//   енча_, küch, tlfu, mfàc, 
   {{0xeb94d022,0xdb180316,0x6a500213,0x00000000}},	//   нич_, poví, _zəfə, --, 
   {{0x1c1c09d9,0x00000000,0x00000000,0x00000000}},	//   _निकल_, --, --, --, 
   {{0xed553be3,0x80c40183,0x7dd400a2,0xf990007b}},	//   _пос_, লেণ্, _düsý, طبع_, 
   {{0xcbc400d1,0x00000000,0x00000000,0x00000000}},	//   رزۇي, --, --, --, 
   {{0xdca4c7b0,0x00000000,0x00000000,0x00000000}},	//   _зағи, --, --, --, 
   {{0xa6100276,0xb6c401c6,0xf53c007c,0x00000000}},	//   лмэч, эсий, tfå_, --, 
   {{0x6fc803fa,0x3998005f,0xdb1800db,0x7dc803b2}},	//   tück, gūst_, lovà, fýsi, 
   {{0x6fc803fa,0xf53c01e3,0x175401f4,0x00000000}},	//   büch, rfå_, _авля, --, 
   {{0x6fc96e73,0x6a500cc1,0xdb1806d9,0x00000000}},	//   rück, _səfə, novà, --, 
   {{0xc7640a52,0x569400fd,0xc7e80a81,0x6d90008e}},	//   _جانى, _шакт, _کى۪ن_, _uçag, 
   {{0x6a5003e3,0x00000000,0x00000000,0x00000000}},	//   _qəfə, --, --, --, 
   {{0xb50404af,0xa6e00022,0xdbd000d0,0x1c1c0210}},	// [25eb0] _व्यय_, _ижәл, _džús, _निगल_, 
   {{0x9f3401ec,0x00000000,0x00000000,0x00000000}},	//   леуі, --, --, --, 
   {{0x6a5000ac,0xb4d800db,0x22840166,0x9294e918}},	//   _təfə, bfàc, _буяг, _ранц, 
   {{0xf09c0295,0xdd956e74,0x6dc42309,0xdef80724}},	//   _beàt_, лахы, رزال, _җыр_, 
   {{0xd25800e2,0x00000000,0x00000000,0x00000000}},	//   āņu_, --, --, --, 
   {{0x7bc400b0,0x00000000,0x00000000,0x00000000}},	//   _ūkur, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc964a796,0x6fc8002f,0x00000000,0x00000000}},	//   твий, wüch, --, --, 
   {{0xdd945fd4,0x6fc80e78,0x00000000,0x00000000}},	//   _саты, tüch, --, --, 
   {{0xf7701a59,0x6d596e75,0x6f140354,0xafd8005c}},	//   لاپ_, _haua, naxc, _spøj, 
   {{0x6fc80730,0x6d596e76,0xc9540bd6,0x7bc400c7}},	//   rüch, _kaua, _атлы, _êkua, 
   {{0xdb18012c,0x6fc81196,0x969401c6,0x00000000}},	//   mová, süch, урьш, --, 
   {{0x6d596e77,0x399804ac,0xdb196e78,0xdce00024}},	//   _maua, _קינד, lová, _domė, 
   {{0x6d596e79,0x07a56e7a,0x68f803e0,0x490800bc}},	//   _laua, _шалн, lcud, सरको_, 
   {{0xdb18fb57,0xd7741d37,0xf2a00124,0x41c401d9}},	//   nová, _حانع, аирп, نزرِ, 
   {{0xfe70168d,0x6d596e7b,0x68f96e7c,0x44643129}},	//   یدا_, _naua, ncud, _авив, 
   {{0xdb196e7d,0xb4d8068c,0x00e402dd,0xc0e41d5b}},	// [25ec0] hová, rfàc, тжан, тоак, 
   {{0xcfb403f4,0x6d5804c9,0xdb180316,0x6fb16e7e}},	//   _জীবন, _aaua, ková, لمقا, 
   {{0x6d596e7f,0xf41c0793,0xdb196e80,0x00000000}},	//   _baua, nyän_, jová, --, 
   {{0xdb18031d,0x6d596e81,0x6d90247e,0xbbc800dc}},	//   dová, _caua, _açab, ित्क, 
   {{0x6d596e82,0xb4d800db,0xae400014,0x00000000}},	//   _daua, leàr, ُھہو, --, 
   {{0xfe440021,0x9b4401b9,0xdb1800bc,0x6c800131}},	//   _инго, انغو, fová, شلىم, 
   {{0x5ee02f8b,0x6d58ea98,0xdb181a58,0xaa5400f5}},	//   _প্রে, _faua, gová, вищу_, 
   {{0x6d596e83,0x68f8009a,0xf41c00a2,0x00000000}},	//   _gaua, gcud, dyän_, --, 
   {{0xdb356e84,0xa3c4012c,0xa8116e85,0xdce00153}},	//   _مذاک, ौता_, адыш, _romė, 
   {{0x6d58005a,0xdb196e86,0x68f801ab,0xb7640408}},	//   _zaua, bová, acud, ттий, 
   {{0xdb184ec5,0xafd9449a,0xdce00024,0x6d580139}},	//   cová, _spøk, _pomė, _yaua, 
   {{0x6448084c,0x68f804cc,0x8a4400db,0x281000e5}},	//   ădin, ccud, _حئكم, _چونس, 
   {{0xe4a42b42,0x39456e87,0xa2c00073,0x00000000}},	//   арро, _ibos_, लॅस्, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7790158b,0x538c02d3,0xb4b80451,0xe2f801ec}},	//   _میکا, _ሓገዛት_, _ڪاغذ_, тесі_, 
   {{0xe5c400d6,0x00000000,0x00000000,0x00000000}},	//   _всьо, --, --, --, 
   {{0x6d596e88,0xdb180316,0xd0100451,0x39444324}},	// [25ed0] _raua, zová, صلا_, _mbos_, 
   {{0x2fc44cc5,0x248402f6,0x6d596e89,0x6ee56e8a}},	//   ông_, ämme_, _saua, نسال, 
   {{0x6d58166a,0x39456e8b,0xdb180118,0x00000000}},	//   _paua, _obos_, xová, --, 
   {{0xdb18012c,0x4c942901,0xecb001e0,0xa240054e}},	//   vová, лиес, аҡбы, şiţă_, 
   {{0xa3b80502,0x68f800ac,0x7bd8107d,0x6d90029f}},	//   _سایر_, vcud, _bhtu, _açac, 
   {{0xdb187815,0x764804ce,0x6d580451,0x39456e8c}},	//   tová, _opfy, _waua, _abos_, 
   {{0x6d596e8d,0xf53c0158,0x00000000,0x00000000}},	//   _taua, nnås_, --, --, 
   {{0xdb18038e,0x39456e8e,0x6d580374,0x00000000}},	//   rová, _cbos_, _uaua, --, 
   {{0xdb18012c,0x68f80ad0,0x00000000,0x00000000}},	//   sová, rcud, --, --, 
   {{0x68f88f1f,0xdb18012c,0x6d9003e0,0x00000000}},	//   scud, pová, _uçab, --, 
   {{0x394400d2,0x38656e8f,0x1bec00af,0xfb5001d3}},	//   _fbos_, _eror_, _छूटल_, _دھند, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xaaa4a6cd,0xc95401ee,0x00000000,0x00000000}},	//   _केतक, _атһы, --, --, 
   {{0x7dc8148b,0x00000000,0x00000000,0x00000000}},	//   lýst, --, --, --, 
   {{0x41b4010b,0xb46000c7,0x61c80133,0x00000000}},	//   гсат, _ҳкыл, ندرێ_, --, 
   {{0xb4d8002e,0x07a401af,0x00000000,0x00000000}},	//   mfàn, _шаһн, --, --, 
   {{0xd1756e90,0x00000000,0x00000000,0x00000000}},	// [25ee0] шыры, --, --, --, 
   {{0x6600009f,0x7dc80162,0x00000000,0x00000000}},	//   _ktnk, hýst, --, --, 
   {{0x81d41682,0x00000000,0x00000000,0x00000000}},	//   _eḓan, --, --, --, 
   {{0x7bd8044e,0x80c4009e,0x9d0400ee,0x00000000}},	//   _shtu, লেষ্, рҗак, --, 
   {{0x67200841,0x629c009a,0x41c401d9,0xe60403e6}},	//   _odnj, lzro, _لٲگِ, _گش_, 
   {{0xafd805ac,0xf8040e46,0x5fb80fe6,0x00000000}},	//   _osøy, қчин, _आदिल, --, 
   {{0xe6051a59,0xf9c402f6,0x629c0007,0x80c403d4}},	//   _دش_, лщин, nzro, লেশ্, 
   {{0xfce422f7,0xce340014,0x3864003a,0xfe44013e}},	//   _бобо, _خوفک, _pror_, _инҳо, 
   {{0xa3c4038e,0x3dc403d9,0x58d802e8,0x57f42377}},	//   एका_, moow_, ъдия_, јпот, 
   {{0x3dc56e91,0x973c1505,0xf62802bf,0x2ca40640}},	//   loow_, mićk, німи_, _скуп_, 
   {{0xd6d03a3d,0xf7700131,0x973c0960,0xdb1800b5}},	//   تقد_, لاھ_, lićk, tovæ, 
   {{0x38656e92,0xb8656e93,0x39456e94,0x3dc40014}},	//   _tror_, _ماتو, _ubos_, noow_, 
   {{0x38640086,0x973c107d,0xdb18005c,0xe9d40114}},	//   _uror_, nićk, rovæ, _скц_, 
   {{0x798018a6,0x53340261,0x3dc40067,0xf77015b4}},	//   _hoow, јевт, hoow_, _داؤ_, 
   {{0x79816e95,0x3dc40067,0xdb18ff9d,0x1634004e}},	//   _koow, koow_, movä, _тейя, 
   {{0x398801e1,0x79801bce,0xa1596e96,0x30e401ec}},	//   _bùsi_, _joow, ласу_, гізб, 
   {{0x0f14224f,0x3dc40014,0x7980058a,0xdce00171}},	// [25ef0] имаю, doow_, _moow, _domī, 
   {{0x7980102c,0x973c01fa,0xf53c2729,0xf41c248c}},	//   _loow, dićk, pnås_, msä_, 
   {{0xf41c8b82,0xb0580166,0x3dc4058a,0x10dc01ec}},	//   lsä_, _ayät, foow_, _ﺃﺭﺩﻨ, 
   {{0x798004ba,0x7d0c004d,0x3dc40067,0x01e400d1}},	//   _noow, _đbsc, goow_, _ﺋﺎﻳﻨ, 
   {{0xf41c0664,0xdb180030,0x7dc802f0,0x00000000}},	//   nsä_, kovä, výst, --, 
   {{0xf41c023a,0xad4000db,0x00000000,0x00000000}},	//   isä_, _گىرۉ, --, --, 
   {{0x4a7477de,0x3dc40014,0x499414f0,0x7980058a}},	//   рылт, boow_, ишит, _boow, 
   {{0xaca002e3,0x798000e8,0x3dc4058a,0xf41c1572}},	//   _agụn, _coow, coow_, ksä_, 
   {{0x5d842961,0xf8acb57a,0x79816e97,0xb0580166}},	//   _القل, وکه_, _doow, _iyäs, 
   {{0x07a4e0c3,0xdb18007c,0x80b80154,0x00000000}},	//   раон, govä, _আরম্, --, 
   {{0x79800009,0xf41c01f4,0xa3bc06e3,0x00000000}},	//   _foow, esä_, _अदब_, --, 
   {{0x629c0fb7,0x2d8c27be,0x7980058a,0x7a78010f}},	//   vzro, nkge_, _goow, _ברעס, 
   {{0x69c96e98,0xdb18007c,0x00000000,0x00000000}},	//   _ikge, bovä, --, --, 
   {{0x629d6e99,0x00000000,0x00000000,0x00000000}},	//   tzro, --, --, --, 
   {{0x629c1225,0xf53c04ce,0xb6a03929,0x3dc401d9}},	//   uzro, rnår_, _мишл, yoow_, 
   {{0x410551f6,0x79800009,0x629c05c7,0x3dc40067}},	//   рзав, _xoow, rzro, xoow_, 
   {{0xc83402d3,0xf53c78d0,0xf4740150,0xfba40709}},	// [25f00] _ዮውሃን, pnår_, _көрі_, कोडम, 
   {{0x973c08a4,0x3dc40067,0xfe4407a5,0x00000000}},	//   vićk, woow_, инзо, --, 
   {{0x69c80998,0xd5b8005f,0x3dc4058a,0x00000000}},	//   _okge, prāt_, toow_, --, 
   {{0x69c801af,0x973c0331,0x7c840276,0xb0580139}},	//   _nkge, tićk, иуле, _pyät, 
   {{0x61e56e9a,0x3dc40014,0xbed001ec,0xb9c400f2}},	//   mmil, roow_, _ارﺗﻴ, یتبه, 
   {{0x9f4c0598,0x69c8af63,0x79802db1,0x973c01a6}},	//   ülät_, _akge, _soow, rićk, 
   {{0x34d01f13,0x798000e8,0x973c01a6,0x61e40254}},	//   _सर्द, _poow, sićk, omil, 
   {{0x61e56e9b,0xf41c0716,0x7980058a,0x973c0841}},	//   nmil, ysä_, _qoow, mići, 
   {{0x973c2f61,0x61e56e9c,0xdb18121f,0xa9641fbe}},	//   lići, imil, tovä, риња_, 
   {{0x69c96e9d,0xfaa56e9e,0x79800694,0x61e4c2f8}},	//   _ekge, _казо, _woow, hmil, 
   {{0x61e56e9f,0x79816ea0,0x80b80c58,0x973c0e3c}},	//   kmil, _toow, _আৰম্, nići, 
   {{0x61e408ad,0xf41c6c31,0x6aa40137,0x00000000}},	//   jmil, tsä_, _ئشكە, --, 
   {{0xb44402d5,0x00000000,0x00000000,0x00000000}},	//   шэнк, --, --, --, 
   {{0x2484049f,0xf41c0724,0x61e56ea1,0x973c0e3c}},	//   ämma_, rsä_, emil, kići, 
   {{0xf41c99ac,0xf1a535c2,0x973c01fa,0x61e4dca5}},	//   ssä_, аран, jići, fmil, 
   {{0x973c08ad,0x6d90442e,0x21fc02d2,0xf41c248c}},	//   dići, _açan, _díh_, psä_, 
   {{0xd2502050,0x53342c28,0x69c407f8,0x00000000}},	// [25f10] _کنج_, _лепт, ावती, --, 
   {{0x61e56ea2,0xaf04376d,0x973c08a4,0x6e640801}},	//   amil, рчак, fići, итеж, 
   {{0xdef80184,0xa05002d3,0x231801c0,0x973c0841}},	//   рыу_, ሕተኛታ, _өнөө_, gići, 
   {{0x61e56ea3,0x00000000,0x00000000,0x00000000}},	//   cmil, --, --, --, 
   {{0xa15802dd,0xa05c030d,0x25d8123b,0x00000000}},	//   _таяу_, _итрĕ_, בואן_, --, 
   {{0x2bb80491,0xccf80882,0x973c110c,0x3f98016d}},	//   خاصة_, _daśa_, bići, chpu_, 
   {{0x8e84bf17,0x69a8134e,0xc7ac0150,0x8ee40154}},	//   _الزه, _जगदी, _لاﻳﯩ, _প্রগ, 
   {{0xf34c044e,0x7e600034,0xa2b8011a,0x69c406ff}},	//   _ህዝብና, łopc, יפוד_, ावधी, 
   {{0x48e4015b,0x4c94004e,0x00000000,0x00000000}},	//   নড্র, _уиас, --, --, 
   {{0x61e56ea4,0x3a840050,0x00000000,0x00000000}},	//   zmil, _گُمہ, --, --, 
   {{0x85e80262,0xaab0004b,0x61e56ea5,0x77c4009d}},	//   лдов_, _بلاګ, ymil, слэг_, 
   {{0x85780261,0xccf800b8,0x00000000,0x00000000}},	//   усот_, _yaśa_, --, --, 
   {{0x61e45522,0xdb18007c,0x75fc00de,0x65d80116}},	//   vmil, sovå, _vīza, ﯜﭼﯩﻠ, 
   {{0x61e4232c,0x97c40345,0x44840023,0x00000000}},	//   wmil, _وتوم, _ዝኸፍኤ_, --, 
   {{0x61e56ea6,0x41282461,0x9f940166,0x00000000}},	//   tmil, лово_, läç_, --, 
   {{0x973c1225,0x61e56ea7,0x04940064,0x00000000}},	//   vići, umil, _гроў, --, 
   {{0x61e56ea8,0xbea850d8,0x00000000,0x00000000}},	// [25f20] rmil, گهان_, --, --, 
   {{0xef156ea9,0x973c1674,0xdcf405a1,0xf41004ae}},	//   йму_, tići, čačk, _צפת_, 
   {{0x44202d75,0x52b80153,0x4f940798,0x00000000}},	//   lsk_, _выяў_, црту, --, 
   {{0x61e4011f,0x80a4028e,0x973c2630,0xafd812e8}},	//   qmil, _همجن, rići, _spøt, 
   {{0x44216eaa,0xdc545945,0x996c012c,0xdce00115}},	//   nsk_, تراک, těž_, _kamĉ, 
   {{0x44216eab,0x973c107d,0x64400790,0xccf800b8}},	//   isk_, pići, çmiy, _vaśa_, 
   {{0x4420002d,0x2cbc01d5,0xfa4803cc,0x4e10012d}},	//   hsk_, _exud_, اشتى_, डीआई_, 
   {{0x44216eac,0xaaa40073,0xfc1896d3,0xb8640214}},	//   ksk_, _केळक, _مقرب_, ماخو, 
   {{0x442044ef,0x3b080108,0x9f94008e,0x00000000}},	//   jsk_, _безо_, gäç_, --, 
   {{0x7d009acb,0x7c2011ad,0x3058008f,0xfb6800ae}},	//   lcos, msor, נדיד, _حصرى_, 
   {{0x8b640131,0x9f94023a,0x44216ead,0x7bc8037e}},	//   _باقم, mää_, esk_, mofu, 
   {{0x7bc96eae,0x7d016eaf,0x9f94005b,0x7c20003a}},	//   lofu, ncos, lää_, osor, 
   {{0x7bc80421,0x442000b5,0xb8d56eb0,0x7d0003ac}},	//   oofu, gsk_, _اتاش, icos, 
   {{0x7bc805b8,0x56956eb1,0x7c200140,0x9f94023a}},	//   nofu, _малт, isor, nää_, 
   {{0x44200175,0x7c20047e,0x229401a9,0x00000000}},	//   ask_, hsor, пиря, --, 
   {{0x7c216eb2,0x7d000ffb,0x44216eb3,0x6440004e}},	//   ksor, jcos, bsk_, àmic, 
   {{0x7d00089c,0x7bc96eb4,0x9f9402f6,0x69a8012d}},	// [25f30] dcos, kofu, kää_, _जगसी, 
   {{0x9f9402f6,0xf3fc0120,0x7d00003a,0x32e025d9}},	//   jää_, lvão_, ecos, géyé_, 
   {{0xdfd80801,0x28ac17ee,0x7bc8bf18,0xaaa400c5}},	//   сът_, _जेनि, dofu, _केंक, 
   {{0x7d00209c,0x7c216eb5,0xdea4085b,0x00000000}},	//   gcos, fsor, سیقی, --, 
   {{0x7c205f03,0x7bc96eb6,0xef6402e8,0x4fc000d1}},	//   gsor, fofu, _лъво, _قەرە, 
   {{0x7bc96eb7,0x7d000ffb,0x7e600034,0xcb696eb8}},	//   gofu, acos, łopa, раке_, 
   {{0x7c200af5,0x499812b4,0x00000000,0x00000000}},	//   asor, ития_, --, --, 
   {{0x4420193f,0x7d016eb9,0x48040815,0x6e342bcc}},	//   ysk_, ccos, опив, muxb, 
   {{0x7bc8004c,0x7c216eba,0x2cbc058a,0x0bb41cb8}},	//   bofu, csor, _uxud_, _дбаю, 
   {{0x44216ebb,0x80c42aab,0x69c40254,0x62880fac}},	//   vsk_, লেক্, ावही, ødok, 
   {{0x442075a8,0x00000000,0x00000000,0x00000000}},	//   wsk_, --, --, --, 
   {{0x44216ebc,0xdce001e4,0x2bac4982,0x00000000}},	//   tsk_, _samĉ, _झगडा, --, 
   {{0x44200006,0x291d6ebd,0x00000000,0x00000000}},	//   usk_, maua_, --, --, 
   {{0x44216ebe,0x291d6ebf,0x420868ba,0xf87001f7}},	//   rsk_, laua_, инго_, _آهوج, 
   {{0x527400a8,0x6d9005d1,0x27fc06af,0xb6c80014}},	//   путу, _açam, lqun_, _پاوے_, 
   {{0x7bc96ec0,0x7c203a9f,0x291d6a13,0x34c8063f}},	//   zofu, ysor, naua_, ụdọ_, 
   {{0x741004a2,0x7bc96ec1,0x7d000a73,0x27fc1f94}},	// [25f40] _قويا, yofu, vcos, nqun_, 
   {{0xafd839c2,0x65656ec2,0x291d6ec3,0x244401b8}},	//   _spør, _haih, haua_, möm_, 
   {{0x65656ec4,0x9f940664,0x291d6ec5,0x7d000129}},	//   _kaih, vää_, kaua_, tcos, 
   {{0x7c216ec6,0x7bc81030,0xccf80055,0xb6b80375}},	//   tsor, wofu, _daśo_, בצעי, 
   {{0x9f94426d,0x656559a5,0x244429ef,0x7bc96ec7}},	//   tää_, _maih, nöm_, tofu, 
   {{0x65656ec8,0x7c20d5f5,0x21216ec9,0x00000000}},	//   _laih, rsor, laih_, --, 
   {{0x9f9402f6,0x291c1132,0x29080790,0x80c400fe}},	//   rää_, faua_, ıcan_, লেখ্, 
   {{0x9f940664,0x24456eca,0x291d6ecb,0x2c8000ef}},	//   sää_, köm_, gaua_, _būdā_, 
   {{0xb9006c95,0x7bc8b5c7,0x9f9416b5,0x7c6401d5}},	//   _धर_, pofu, pää_, _بازل, 
   {{0x24440793,0x21216ecc,0x6c3004fb,0xccf800cd}},	//   döm_, haih_, _آفلا, _yaśo_, 
   {{0x65656ecd,0x64440009,0x69c40764,0x6cd000e5}},	//   _baih, _aqii, ावशी, _فقہا, 
   {{0x65656ece,0xb4b000d1,0x291c0356,0xe60c43fb}},	//   _caih, димә, caua_, کشی_, 
   {{0x65640226,0x21200399,0xf3fc0120,0x24447536}},	//   _daih, daih_, rvão_, göm_, 
   {{0xca60022e,0x00000000,0x00000000,0x00000000}},	//   _kelа, --, --, --, 
   {{0x656403c1,0x569400fd,0x64440140,0x76c401b9}},	//   _faih, _хайт, _eqii, _بغشل, 
   {{0x65c46fbd,0x65640369,0x21216ecf,0x41840116}},	//   _обја, _gaih, gaih_, птуғ, 
   {{0x84c12610,0x3e740092,0xdce003e0,0xdb180254}},	// [25f50] _зәрд, _የሚረዳ_, _olmı, llvõ, 
   {{0x65640369,0x9f9801e7,0xccf80055,0x00000000}},	//   _zaih, _fáíl_, _paśo_, --, 
   {{0xe3b0038b,0x2000022f,0x6564216e,0x00000000}},	//   _جري_, aqii_, _yaih, --, 
   {{0xdce012ca,0xd5b800e2,0x27fc353d,0xf0740166}},	//   _almı, ksām_, yqun_, _димә_, 
   {{0x3d0805f9,0x6ec96ed0,0xcb0800e3,0xaf34004b}},	//   ाड़े_, _तुरु, ميشن_, _ورست, 
   {{0xf1bc6984,0x291c0451,0xdb1802e2,0x68a80241}},	//   _hjá_, waua_, nnvè, _ẹmó, 
   {{0x291c7e57,0x69c4454f,0x2d8406af,0xf1bc03b2}},	//   taua_, ावली, ênes_, _kjá_, 
   {{0x291cb1a8,0x1a6801b9,0x00000000,0x00000000}},	//   uaua_, غینی_, --, --, 
   {{0x65656ed1,0x291d6ed2,0xf1bc02d2,0x95700023}},	//   _raih, raua_, _mjá_, እኽትን_, 
   {{0x6d496ed3,0x65656ed4,0x291c0b23,0x27fcf2a1}},	//   lfga, _saih, saua_, rqun_, 
   {{0x65656ed5,0x6b800007,0x291d6ed6,0x2c100154}},	//   _paih, mjng, paua_, _সময়ই_, 
   {{0x99d401b9,0x6d48037e,0xf1bd6ed7,0x2bdc2802}},	//   _قتنا, nfga, _njá_, _पीता, 
   {{0x65640664,0x21216ed8,0xd9b001ec,0x194000c7}},	//   _vaih, vaih_, _جەيد, _рҭын, 
   {{0x65650e3c,0x24456ed9,0xf1bc0cad,0x6b8003a2}},	//   _waih, röm_, _ajá_, njng, 
   {{0x65656eda,0x2444012b,0x80c40011,0x52643d09}},	//   _taih, söm_, লেঞ্, мерғ, 
   {{0x4208016c,0xe5e401d9,0x51544f41,0x6d4801f5}},	//   инҳо_, _تٲبی, мтуу, jfga, 
   {{0x21216edb,0x671c1533,0x64440009,0x20000009}},	// [25f60] raih_, _मजाक_, _uqii, uqii_, 
   {{0x20000ba7,0x6d488c35,0x64a474f0,0x8fc42824}},	//   rqii_, efga, _нақа, وزلن, 
   {{0xfce0044e,0x2000022f,0x2624107d,0x6d4917df}},	//   _ዝመጸ_, sqii_, nđo_, ffga, 
   {{0x7e60068f,0xf09c01e1,0x34b043fb,0xf1bc032e}},	//   łopo, _ifàn_, _آمیز, _gjá_, 
   {{0x20016edc,0x00000000,0x00000000,0x00000000}},	//   qqii_, --, --, --, 
   {{0xdcfc5656,0x6d4802d2,0x42780023,0x00000000}},	//   ızıl, afga, _ኣመንት_, --, 
   {{0xafe0377b,0x4bd80006,0x00000000,0x00000000}},	//   _чорл, цьця_, --, --, 
   {{0xfce0044e,0x79a400fd,0x3f88000d,0x25dc033f}},	//   _ዝመጹ_, ярле, _hobu_, _गीली_, 
   {{0x3f880472,0x3154010f,0x48c0035b,0x00000000}},	//   _kobu_, ליקן_, кәша, --, 
   {{0x36380201,0xdce108c7,0xab24084c,0x3f896edd}},	//   _በተጨማ, _jamč, _ноуа_, _jobu_, 
   {{0x3f896ede,0xa3c01a2a,0x6aa40137,0xdce001ef}},	//   _mobu_, ंचन_, _ىشمە, _mamč, 
   {{0x3f880107,0x39e80114,0x00000000,0x00000000}},	//   _lobu_, _удео_, --, --, 
   {{0xf09c01e1,0x00000000,0x00000000,0x00000000}},	//   _afàn_, --, --, --, 
   {{0xf1bc00fc,0xdce001fa,0x6d480334,0x00000000}},	//   _sjá_, _namč, zfga, --, 
   {{0xb4d800e8,0x66e00114,0x918800fb,0x00000000}},	//   wgàd, _поља, ораҡ_, --, 
   {{0x59cd6cb8,0x00000000,0x00000000,0x00000000}},	//   ाविर, --, --, --, 
   {{0x3f896edf,0xf53c17b8,0xb0580108,0xdd0c012d}},	// [25f70] _bobu_, mgå_, _exän, kółk, 
   {{0xb4d801ab,0xa8540375,0xf53c005c,0x64480356}},	//   ggàe, הימה_, lgå_, ădit, 
   {{0x3f896ee0,0xb81c35e8,0xc330008d,0x6d90247e}},	//   _dobu_, _मौसम_, _בוי_, _uçak, 
   {{0x88bc2a09,0xf53c174e,0x7af80af9,0x6d4817da}},	//   naśc, ngå_, _agtt, ufga, 
   {{0x8c456ee1,0xf53c0158,0xeff00092,0x5f7800d1}},	//   феле, liås_, ግረው_, تمەس_, 
   {{0x290805d1,0x28c801ad,0x80c40154,0x00000000}},	//   ıcam_, ाथसि, লেঙ্, --, 
   {{0xaca001e1,0x00000000,0x00000000,0x00000000}},	//   _ifọn, --, --, --, 
   {{0xdb180122,0x3f88005f,0xdce00118,0x00000000}},	//   mový, _zobu_, _zamč, --, 
   {{0xf53c019b,0xdb180232,0x3f896ee2,0x88bc00cd}},	//   dgå_, lový, _yobu_, daśc, 
   {{0x6fbc00dc,0x6b800175,0xd8340116,0x00000000}},	//   ्विं, qjng, رۋىش_, --, 
   {{0xdb180232,0x6d9000d8,0x9bc4a3f8,0x00000000}},	//   nový, _açai, _чётк, --, 
   {{0xc8b401c0,0x262400f3,0x00000000,0x00000000}},	//   _ослы, rđo_, --, --, 
   {{0x6fbc00a5,0xdb180122,0x81d400cc,0xf78c0023}},	//   ्वां, hový, িগম_, _ዝፈጸመ_, 
   {{0x99800038,0xdb180232,0xe584009d,0x00000000}},	//   čiť_, kový, фтүү, --, 
   {{0xdb180122,0x00000000,0x00000000,0x00000000}},	//   jový, --, --, --, 
   {{0x3f894adf,0xaca001e1,0xdb1804bf,0x76b000c7}},	//   _sobu_, _afọn, dový, _шәыц, 
   {{0xb460916f,0xd54800c6,0x83c413f3,0xb17801e3}},	// [25f80] _акыл, _رجيم_, _обиж, _ihål, 
   {{0xb178072b,0x3f8806be,0x00000000,0x00000000}},	//   _uhån, _qobu_, --, --, 
   {{0x28ac1d8a,0xdb1802fb,0xe6a000a2,0x00000000}},	//   _जेसि, gový, _çuńń, --, 
   {{0x3f880134,0x00000000,0x00000000,0x00000000}},	//   _wobu_, --, --, --, 
   {{0x3f880481,0xfb8402d5,0xa9f4012c,0xd7800023}},	//   _tobu_, дыйн, ँदैछ_, _ክገብራ_, 
   {{0xdb196ee3,0xb4d800db,0xba08005b,0xcd2815bf}},	//   bový, mfàt, охие_, قسۇن_, 
   {{0xdb196ee4,0xb17801e3,0x00000000,0x00000000}},	//   cový, _ohål, --, --, 
   {{0x3941140b,0xfce400f7,0x9abc0003,0xed5401c6}},	//   üks_, _жобо, _neċe, _оос_, 
   {{0xdbdc01e1,0x4a7400c7,0xdb500133,0x00000000}},	//   _háíh, _ҿыцт, _مێش_, --, 
   {{0x59cc012c,0x00000000,0x00000000,0x00000000}},	//   ावहर, --, --, --, 
   {{0x56943cdf,0x88bc0882,0x2bc808f2,0x00000000}},	//   хант, taśc, िवरा, --, 
   {{0x7a08003a,0xcb8000c7,0xf41c010e,0x00000000}},	//   _cęte, _ақәп, dyär_, --, 
   {{0x2ed93de2,0xf8e089f0,0xf53c8ce1,0x9abc0135}},	//   _भर्त, _परिय, rgå_, _deċe, 
   {{0x75fc00e2,0x8cb007f7,0xf53c007c,0x00000000}},	//   _līzi, _आइसो, sgå_, --, 
   {{0xe2f8005e,0x88bcd0f6,0x6fbc00dc,0xdb180306}},	//   дері_, paśc, ्वसं, xový, 
   {{0xdb180122,0x64480276,0xf77005d9,0xf8e02429}},	//   vový, ădir, _ساڻ_, _पराय, 
   {{0xc7e80014,0xfe6001ec,0x61840023,0xc0c00166}},	// [25f90] _بى۪ن_, _ءﺟﯘﺭ_, _ነገራዊ_, гәри, 
   {{0xdb1803c6,0xa4fc0135,0x7c2403cd,0x00000000}},	//   tový, _དཔོག_, _åkry, --, 
   {{0x75fc0153,0xc0480092,0x00000000,0x00000000}},	//   _dūzg, _አያልፍ, --, --, 
   {{0xdb180232,0x29080790,0xdd9404b4,0x00000000}},	//   rový, ıcak_, кахы, --, 
   {{0xdb180122,0x00000000,0x00000000,0x00000000}},	//   sový, --, --, --, 
   {{0xdb1802fb,0x2484000d,0x00000000,0x00000000}},	//   pový, ämmi_, --, --, 
   {{0xa3c00037,0xdef40153,0x773c0092,0x88bc00dc}},	//   ंचत_, _апры, _በሠራተ, daśa, 
   {{0xa8000139,0xdea400f2,0x00000000,0x00000000}},	//   _çıkq, _جیمی, --, --, 
   {{0x2d9c01e1,0x9abc0003,0x00000000,0x00000000}},	//   _ilue_, _reċe, --, --, 
   {{0x7ae8004b,0x9abc0327,0x8b840132,0x068401f4}},	//   _کومې_, _seċe, _سەبە_, егон, 
   {{0x81d439db,0x9a1400d3,0xaa6401af,0x00000000}},	//   িগত_, _афіш, _ютак, --, 
   {{0xb17800b8,0x7bc400c7,0xdce000b8,0x97340214}},	//   _bhåm, _êkur, _hamā, _یکپا, 
   {{0x69d80369,0xdce12c13,0x00000000,0x00000000}},	//   mlue, _kamā, --, --, 
   {{0x69d96ee5,0xb1780055,0xf7700451,0x7cf406be}},	//   llue, _dhåm, _ماٺ_, _hürü, 
   {{0x7cf49d5d,0xdce00882,0xd77410de,0x69d842b9}},	//   _kürü, _mamā, _جانع, olue, 
   {{0x6b500598,0xa5e80150,0x7cf400a2,0xdce000de}},	//   lıgı, _توبە_, _jürü, _lamā, 
   {{0x3fe56ee6,0x25a01529,0x69d8f7c9,0x7cf40205}},	// [25fa0] ежав, _ilil_, ilue, _mürü, 
   {{0x69d96ee7,0x2d9c049b,0x0d400092,0xdce0002b}},	//   hlue, _alue_, _የምፈል, _namā, 
   {{0x2d9cc2ce,0x69d80007,0x2bc000dc,0x7e556ee8}},	//   _blue_, klue, वचना, этац, 
   {{0x2d9c7723,0xf19000c7,0x6da0f6a4,0x7c64036b}},	//   _clue_, _биџь, лиха, فاتل, 
   {{0x2004084c,0x75fc00e2,0x7f1800c0,0x00000000}},	//   _îmi_, _vīzi, _ніву_, --, 
   {{0x9f58069c,0xa3c16ee9,0xd24c01d9,0xbf140682}},	//   _mirë_, ंचि_, _دۆہ_, _سورب, 
   {{0x2d9d6eea,0x9f5802d3,0x69d9021b,0x7cf56eeb}},	//   _flue_, _lirë_, flue, _bürü, 
   {{0xc0dc0023,0x2d9c123b,0x7cf40205,0x58d56eec}},	//   ንጫል_, _glue_, _cürü, койт, 
   {{0xa3c005ba,0xfaf85dd0,0x6da16eed,0x88bc0882}},	//   ंचा_, _فراغ_, _сита, taśa, 
   {{0x25a00548,0x1dd800b4,0x69d8023a,0xdce000b8}},	//   _alil_, _ọhụụ_, alue, _gamā, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69d96eee,0x7cf4bd8f,0x7f5c0477,0x9f580200}},	//   clue, _gürü, hepq, _birë_, 
   {{0x6d900139,0xe9cc0451,0xf7700244,0xdce000cd}},	//   _içat, _اٺن_, _ماغ_, _yamā, 
   {{0x27e401ab,0x925801c0,0x25a00254,0xa8780a7c}},	//   _ghnn_, магт_, _elil_, _מאדר, 
   {{0x7cf407c4,0x66702010,0xe374035b,0x00000000}},	//   _yürü, _مدير, ылры, --, 
   {{0x26d806a9,0xf53c0194,0x75e40006,0x00000000}},	//   _מקומ, shåb_, _яўле, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [25fb0] --, --, --, --, 
   {{0x69d80399,0x2d9c0076,0x25a00010,0x98a40205}},	//   zlue, _slue_, _zlil_, nemı_, 
   {{0x9f58026c,0x3944056a,0x88bc0034,0x2d9c010f}},	//   _mirè_, _ocos_, jaśn, _plue_, 
   {{0xdce01161,0x3864cc75,0x69d80369,0x4c940120}},	//   _samā, _osor_, xlue, киес, 
   {{0xc0c0010b,0xdce01c52,0xcb684255,0x7f5c014f}},	//   _кәфи, _pamā, дале_, bepq, 
   {{0x7cf436b5,0x77680ba7,0x394400cc,0xc0c074f1}},	//   _sürü, _nafx, _acos_, _тәси, 
   {{0xfaa16eef,0x38656ef0,0xdddc01ed,0x7cf405d2}},	//   иашо, _asor_, _errő, _pürü, 
   {{0x39440048,0x7cf425a8,0x00000000,0x00000000}},	//   _ccos_, _qürü, --, --, 
   {{0x69d804d1,0xdce13e12,0x7cf4006a,0x88e402e8}},	//   rlue, _tamā, _vürü, ъжие, 
   {{0x69d96ef1,0x3168045a,0x27e40051,0x00000000}},	//   slue, _lacz_, _qhnn_, --, 
   {{0x69d80a40,0x9f58007f,0x7cf4510c,0xcd40001f}},	//   plue, _dirè_, _türü, _የምንለ, 
   {{0x69d80369,0x9f580240,0x39456ef2,0x9f9400a2}},	//   qlue, _pirë_, _gcos_, däý_, 
   {{0x25a00010,0x7f5c0455,0x00000000,0x00000000}},	//   _vlil_, yepq, --, --, 
   {{0x07080832,0x7e60033f,0x00000000,0x00000000}},	//   _غيبي_, łopi, --, --, 
   {{0x25a000fb,0x3f8c0008,0xfba400bc,0x00000000}},	//   _tlil_, öfum_, कोटम, --, 
   {{0x67216ef3,0x25a006df,0x69c40073,0x00000000}},	//   _henj, _ulil_, ावटी, --, 
   {{0x67216ef4,0xf59000c6,0x76a400e8,0x04c80066}},	// [25fc0] _kenj, _خليج, _téyé, _زودي_, 
   {{0x6600b579,0x67216ef5,0x7a08003a,0xdb080022}},	//   _kunk, _jenj, _lęta, _omdá, 
   {{0x67204020,0x6600019b,0xb4d803d1,0x82a46e1e}},	//   _menj, _junk, ngàn, _ранж, 
   {{0x66016ef6,0x67216ef7,0x9f940724,0x9f580407}},	//   _munk, _lenj, läü_, _miré_, 
   {{0x6d9020b2,0x69a82122,0x7d500092,0x88bc002b}},	//   _aças, _जगजी, _መዝገቦ, daśo, 
   {{0x3944084c,0x66000241,0xf410011a,0x00000000}},	//   _scos_, _ounk, ספו_, --, 
   {{0xe604034d,0x660003f9,0x39456ef8,0xc0c00092}},	//   _خش_, _nunk, _pcos_, ጵያም_, 
   {{0x6720000f,0x6a116ef9,0x7768058a,0x00000000}},	//   _aenj, جبور, _safx, --, 
   {{0xf1b01203,0x66000407,0x9f940139,0x00000000}},	//   יסה_, _aunk, käü_, --, 
   {{0x66016efa,0x67216efb,0x7b6401d9,0xa77116db}},	//   _bunk, _cenj, _جارٕ, альч, 
   {{0x67216efc,0x0b580b8d,0xd5b8005f,0x66016efd}},	//   _denj, _ярты_, ksāt_, _cunk, 
   {{0x66016efe,0x9f596eff,0x67200b4f,0x00000000}},	//   _dunk, _diré_, _eenj, --, 
   {{0x386400a8,0x9f596f00,0x6600005a,0x3ce40490}},	//   _usor_, _eiré_, _eunk, जेचे_, 
   {{0x67216f01,0x31688477,0xe7900114,0x9f4c01e1}},	//   _genj, _sacz_, _вишњ, _òdè_, 
   {{0x66016f02,0xf77000dd,0x81bc0f22,0x00000000}},	//   _gunk, _ماں_, েতন_, --, 
   {{0x67208a07,0xa158014b,0x00000000,0x00000000}},	//   _zenj, касу_, --, --, 
   {{0x67200944,0x10740c98,0x94180134,0x6600037e}},	// [25fd0] _yenj, ылаю, _ɔyɛe_, _zunk, 
   {{0x2d504e53,0x66016f03,0xf0e00abd,0xdb0c0241}},	//   _ṣe_, _yunk, _खरीद_, _òkèd, 
   {{0xdfd806bb,0x66000009,0x12940120,0xa3c003ce}},	//   тът_, _xunk, _синџ, ंचर_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d900139,0x00000000,0x00000000,0x00000000}},	//   _sças, --, --, --, 
   {{0xd1d40201,0x7d140790,0x00000000,0x00000000}},	//   ሪዎች_, ıysa, --, --, 
   {{0x6720003d,0xba5000c6,0x00000000,0x00000000}},	//   _renj, منوع, --, --, 
   {{0xdd956f04,0x66016f05,0x9f5800e4,0xaac40133}},	//   _касы, _runk, _riré_, _یتان, 
   {{0x67202c62,0x66016f06,0xdd956f07,0x4b4400dd}},	//   _penj, _sunk, _таты, _معاہ, 
   {{0x66016f08,0xd5b800e2,0xb4d807de,0x6720acd3}},	//   _punk, ksās_, tgàn, _qenj, 
   {{0x67201bb0,0x6d902347,0xf3f800fe,0xc76400d1}},	//   _venj, _uças, ্ঠাৰ_, ناھى, 
   {{0x67216f09,0x66000564,0x9f58557b,0xb4d800db}},	//   _wenj, _vunk, _viré_, rgàn, 
   {{0xa3c0033d,0x67216f0a,0x46801638,0x04b40108}},	//   ंचल_, _tenj, рққа, усня, 
   {{0x66016f0b,0x9f596f0c,0xb3a001e0,0x00000000}},	//   _tunk, _tiré_, йһыһ, --, 
   {{0x6600581e,0x7fd402dd,0xf694007b,0xdb1803b2}},	//   _uunk, ңізі, _منوع_, nnvá, 
   {{0x451c00fe,0xc5a800e5,0x00000000,0x00000000}},	//   _থাকক_, _سُخن_, --, --, 
   {{0x00e45424,0xd5b800e2,0x00000000,0x00000000}},	// [25fe0] ужан, rsāt_, --, --, 
   {{0xa0681669,0x8ccc01f9,0x00000000,0x00000000}},	//   наға_, _तडजो, --, --, 
   {{0x814401d5,0xdb0c01e1,0x00000000,0x00000000}},	//   _ینگن, _òkéd, --, --, 
   {{0x5bdc0b9c,0x8e7400f7,0xbc496f0d,0x00000000}},	//   यत्व, шууч, ечке_, --, 
   {{0xf8e000bc,0x00000000,0x00000000,0x00000000}},	//   _परेप, --, --, --, 
   {{0x437400c8,0x6da000d1,0xab6001c6,0x9b58009d}},	//   רײַן_, _һиса, йвчл, тикт_, 
   {{0xbea56f0e,0x8ed8014b,0x00000000,0x00000000}},	//   _савк, _афту_, --, --, 
   {{0xe3bc04c5,0x6da02472,0xada0009b,0x9f94010e}},	//   ৃতিব, _лиса, _ласл, mäñ_, 
   {{0x62fc015b,0xf0b4008f,0x3ce0032e,0x9f940139}},	//   ্রিয়_, ָליר_, _ákv_, läñ_, 
   {{0xd1d40020,0x524802d3,0x6d916f0f,0x57b551a5}},	//   ሪዎቹ_, _ዝግብኦ, _uçar, рбот, 
   {{0x7bd96f10,0x290c022e,0x073800d1,0x00000000}},	//   _iktu, _ffga_, ﯕﮕﯜ_, --, 
   {{0xc5ec00aa,0xdb180240,0x6a800209,0x3568ecab}},	//   وړي_, kivë, _ылха, хрон_, 
   {{0xa3c00574,0xdb180120,0x30bc00eb,0x29d00633}},	//   ंचं_, vivê, _আর্স, _اينس, 
   {{0x168404d3,0x77900214,0xdedc0092,0x00000000}},	//   _نابێ, _چیکا, ፕላን_, --, 
   {{0xb35432de,0x168403e6,0xd5b800e2,0xdd3800b8}},	//   نیکا_, _ڕاکێ, usās_, _kāńk, 
   {{0xdb0808a5,0x9f940166,0x00000000,0x00000000}},	//   _umdæ, däñ_, --, --, 
   {{0x7bd887d6,0xd0100131,0x5334021f,0x84c01a98}},	// [25ff0] _oktu, زلا_, _кепт, _дәрд, 
   {{0xb4c0471b,0x09e000dc,0x2fc40208,0x00000000}},	//   ्थी_, _पठ्य, õng_, --, 
   {{0x0e04016c,0xe47c01e1,0xf270009f,0x00000000}},	//   рӯго, _àwò̟, _اَجھ, --, 
   {{0x7bd96f11,0xdb1965d4,0xad241699,0x0c9408da}},	//   _aktu, vnvá, اراو, ишля, 
   {{0x8b24165d,0xcb0801f7,0xa3bc2e2a,0x00000000}},	//   адле, نيشن_, _आगम_, --, 
   {{0xdb1802e2,0x09dc00dc,0x00000000,0x00000000}},	//   nivè, मत्य, --, --, 
   {{0xddd4010e,0x22a001f4,0xce9428f3,0x00000000}},	//   _ýaşm, mäkö_, _тавъ, --, 
   {{0x7bd800df,0x7a08033f,0x22a0005b,0x1df80a89}},	//   _ektu, _tętn, läkö_, _бесы_, 
   {{0x0cd8034c,0x7bd81132,0x480416a4,0xdce00153}},	//   _شارژ_, _fktu, јпов, _pamą, 
   {{0x973002d3,0x22a0023a,0x62fc03d4,0x00000000}},	//   _ሰበይት, näkö_, ্ৰিয়_, --, 
   {{0xdb1801a8,0x38c800f2,0x00000000,0x00000000}},	//   fnvæ, فایی_, --, --, 
   {{0x7bc40124,0xdb180ec3,0x07141d3b,0x7ae801e2}},	//   _íkur, gnvæ, _द्रव_, _شونې_, 
   {{0xdd1401f1,0x97c403e6,0x87c00354,0x482400d1}},	//   núši, شتیم, _дιах, _ئىتق, 
   {{0xdb1801b8,0xf53c007c,0x00000000,0x00000000}},	//   sovö, lhål_, --, --, 
   {{0x4128e4c1,0x41b56f12,0xe1f8013e,0x00000000}},	//   ково_, асат, лҳо_, --, 
   {{0xdb180023,0xc0a8004b,0xf53c007c,0x00000000}},	//   tivë, پارل_, nhål_, --, 
  
   {{0x2608012d,0x66dc01e1,0x00000000,0x00000000}},	// [26000] _ठंडी_, bàkú, --, --, 
   {{0x44301459,0xef140058,0xdb18067c,0xbc6803e6}},	//   _ivy_, иму_, civè, ێمان_, 
   {{0x46a400c5,0xf53c007c,0xdb180200,0x00000000}},	//   खनिह, khål_, sivë, --, 
   {{0x63bd6f13,0x6d4c083c,0xdac401e0,0xbee40073}},	//   lirn, _öcal, ҡҡай, _करीन_, 
   {{0x629c00a3,0xdb196f14,0x63bc0332,0x00000000}},	//   lyro, livé, oirn, --, 
   {{0x63bd6f15,0x9f58011f,0xec3000d1,0xdd3800b8}},	//   nirn, _kirí_, زۈمگ, _sāńk, 
   {{0x0ba8568c,0x39a40131,0xdb1802fb,0xeb94399f}},	//   دانى_, ишив, nivé, риј_, 
   {{0x63bc122d,0x7c656f16,0x44300f7a,0x7e600210}},	//   hirn, _پارل, _ovy_, łops, 
   {{0xbee405ba,0x63bd6f17,0x629d6f18,0xda700050}},	//   _करुन_, kirn, hyro, زُک_, 
   {{0x7bd9404b,0xdb1800c5,0xb8ec0490,0x3dc50996}},	//   _uktu, tovõ, _रश_, lnow_, 
   {{0x4430325f,0xeb94026a,0x5ae400cf,0x629c0240}},	//   _avy_, _њих_, _اقاە, jyro, 
   {{0x99804077,0xb864d36d,0x3dc40784,0x629d6f19}},	//   čių_, _ناتو, nnow_, dyro, 
   {{0x79816f1a,0xb4c02f2e,0x9f58007b,0x63bd6f1b}},	//   _inow, ्थे_, _airí_, firn, 
   {{0xbee405ba,0x63bd6f1c,0xf7f001d9,0x443000b8}},	//   _करून_, girn, _بٲتھ, _dvy_, 
   {{0x79816f1d,0x3dc468c8,0xdb196f1e,0x629d6f1f}},	//   _know, know_, rivè, gyro, 
   {{0x63bc36f4,0x2a380092,0x71400137,0x00000000}},	//   airn, _አክብሮ, تىرۅ, --, 
   {{0x644000f7,0x20996f20,0x3dc43c36,0xb4440276}},	// [26010] àmit, акты_, dnow_, _тэйк, 
   {{0x63bd06bb,0x9f5801e1,0xdb196f21,0x3dc40009}},	//   cirn, _firí_, bivé, enow_, 
   {{0xdb1802f6,0x79816f22,0x773c001f,0xa3bc00af}},	//   invä, _onow, _በአስተ, _आगत_, 
   {{0x443007dd,0x3dc53fe8,0x75fc0064,0xc2780677}},	//   _yvy_, gnow_, _mūzo, _עררי, 
   {{0x0e040364,0xf53c01e3,0x00000000,0x00000000}},	//   рӯҳо, vhål_, --, --, 
   {{0x79800433,0x3dc4058a,0x00000000,0x00000000}},	//   _anow, anow_, --, --, 
   {{0xda640f1b,0xca742de5,0x9e356f23,0x3dc4010e}},	//   قايي, сулы, _мерч, bnow_, 
   {{0x63bd6f24,0x9f58011f,0x06880150,0x1d080798}},	//   zirn, _girâ_, _ﯗﺳﻨﯩ, _веѓи_, 
   {{0x798002fa,0xb4c009b4,0x629c0034,0x6d5800cc}},	//   _dnow, ्थो_, zyro, _ibua, 
   {{0x798003ac,0x63bcf3ff,0xdb1801e3,0xf53c007c}},	//   _enow, xirn, gnvä, shål_, 
   {{0xdce01b24,0x63bc0f03,0xb8fc0cb2,0x629c00b5}},	//   _pamć, virn, _दु_, xyro, 
   {{0x629c4e86,0xdb1801e3,0x63bd6f25,0x59640395}},	//   vyro, anvä, wirn, _мъча, 
   {{0x63bd6f26,0x291c05d9,0x6d596f27,0x99d4027a}},	//   tirn, mbua_, _mbua, _بتلا, 
   {{0x629d6f28,0xdb196f29,0x79800034,0xdd0400c0}},	//   tyro, tivé, _znow, _įsči, 
   {{0x3dc56f2a,0xd29800d6,0x6d596f2b,0x98a56f2c}},	//   ynow_, атті_, _obua, mamā_, 
   {{0xdb196f2d,0x291d6f2e,0x00000000,0x00000000}},	//   rivé, nbua_, --, --, 
   {{0x629cd026,0x291c17c4,0x35180375,0xa5040073}},	// [26020] syro, ibua_, _גופנ, रखीच_, 
   {{0x6d580085,0x629c00e4,0x98a56f2f,0xe5700c3c}},	//   _abua, pyro, namā_, _işığ, 
   {{0x44c01958,0x6d5800a3,0x3dc4e9af,0xb36c02d3}},	//   _hɔ_, _bbua, tnow_, _ብምዃን_, 
   {{0x44c0013b,0x69c8009a,0xa3c0443a,0xdce01b6e}},	//   _kɔ_, _njge, ंचक_, _unmī, 
   {{0x61e56f30,0x98a56f31,0xec100228,0xa3bc00af}},	//   mlil, kamā_, كوند, _आगा_, 
   {{0x61e54528,0x3dc56f32,0x6d58013f,0x69c801e4}},	//   llil, snow_, _ebua, _ajge, 
   {{0x44c00165,0x61e41577,0x98a40a88,0x00000000}},	//   _lɔ_, olil, damā_, --, 
   {{0x58396f33,0x61e56f34,0x99987283,0x67ec00b5}},	//   азия_, nlil, ркит_, højd, 
   {{0xeab40058,0x61e56dad,0xdcb00137,0x00000000}},	//   ийә_, ilil, _تۉش_, --, 
   {{0x61e56f35,0x00000000,0x00000000,0x00000000}},	//   hlil, --, --, --, 
   {{0xdb18049f,0x9f580ffb,0x61e56f36,0xe570e090}},	//   rnvä, _mirà_, klil, _aşığ, 
   {{0x798042e8,0x44c0013b,0x75880b32,0x6aa410de}},	//   _unow, _bɔ_, усов_, _اشكە, 
   {{0x61e56af7,0x212001fa,0xf1a401ec,0x9958013a}},	//   dlil, dbih_, ұран, _kéž_, 
   {{0x44c0013b,0x88f0004b,0x96f828e5,0xb4c000cd}},	//   _dɔ_, _غړيت, _келт_, ्थौ_, 
   {{0x44c0013f,0x212001fa,0x61e4498a,0x00000000}},	//   _eɔ_, fbih_, flil, --, 
   {{0x61e4357f,0x44c0016b,0x212001fa,0x0f202f0a}},	//   glil, _fɔ_, gbih_, यर्स_, 
   {{0x752c068f,0x3dbc00cc,0x6288007c,0x00000000}},	// [26030] macz, ইকাল, ädor, --, 
   {{0x61e56f37,0xb178049f,0x752c0034,0x6d596f38}},	//   alil, _skåd, lacz, _sbua, 
   {{0xb8c8003d,0x9f580b81,0x21216f39,0x93c801d9}},	//   _པཎ_, _dirà_, bbih_, _ماگہ_, 
   {{0x918043e8,0x752c006d,0x44c0013f,0x61e4020c}},	//   _تۇرۇ, nacz, _yɔ_, clil, 
   {{0x9f5805d5,0x67ec005c,0xe2c800f1,0x00000000}},	//   _firà_, løje, _نویو_, --, 
   {{0x9f5819f5,0x752c012d,0xb17801e3,0x00000000}},	//   _girà_, hacz, _thås, --, 
   {{0x2de400f1,0x752c1430,0x00000000,0x00000000}},	//   _هوسۍ_, kacz, --, --, 
   {{0x6d58009a,0xad240214,0x485802d5,0xc0f40092}},	//   _ubua, _درآو, ароў_, _ጉልህ_, 
   {{0x752d6d4f,0x6d48089c,0x98a43a71,0x67ec00b5}},	//   dacz, mgga, tamā_, høje, 
   {{0x61e42fbe,0x3c900014,0x21200841,0xb7d400e3}},	//   zlil, _تیٖز, zbih_, يويا_, 
   {{0x44c0016b,0x98a40b13,0x752c04cc,0x61e56f3a}},	//   _sɔ_, ramā_, facz, ylil, 
   {{0x9f5800eb,0x752c012d,0xdce00118,0xa5040073}},	//   _mirá_, gacz, _namě, रखेच_, 
   {{0x69d96f3b,0x61e56f3c,0x6d485dd8,0xbee407f7}},	//   moue, vlil, igga, _कर्न_, 
   {{0x69d93517,0x752c0175,0xd3b80212,0x67ec005c}},	//   loue, aacz, бусі_, føje, 
   {{0x61e56f3d,0x44c071c0,0x752c068f,0xf75c00b5}},	//   tlil, _wɔ_, bacz, _rh様_, 
   {{0x69d96f3e,0x44c0016b,0x9f5856eb,0x61e4000d}},	//   noue, _tɔ_, _sirà_, ulil, 
   {{0xb88409cc,0x61e56f3f,0x21200429,0x95480e76}},	// [26040] mtíð, rlil, rbih_, _اشىق_, 
   {{0x64a4c9c6,0x21216f40,0x7f840075,0x69d96f41}},	//   _мақа, sbih_, غلان, houe, 
   {{0x212005be,0x66056f42,0x69d96f43,0x82346728}},	//   pbih_, _kiik, koue, _برخا, 
   {{0x9f587d3d,0x66040083,0xbca56f44,0x69d81b79}},	//   _dirá_, _jiik, يماي, joue, 
   {{0x66056f45,0x69d96f46,0x9f5808e5,0x00000000}},	//   _miik, doue, _tirà_, --, 
   {{0x66042053,0xdce00316,0x6d496f47,0xcdc40022}},	//   _liik, _zamě, agga, _ҵасқ, 
   {{0x69d80a40,0x9f58011f,0xefb0006c,0xfd500241}},	//   foue, _girá_, _تیلگ, _majẹ, 
   {{0x69d803bd,0xa9c000d6,0x66056f48,0x69c40241}},	//   goue, дськ, _niik, _ìjel, 
   {{0xdb082d75,0x180400af,0x2004004a,0x9958012c}},	//   _omdø, रदेव_, _émis_, _též_, 
   {{0x752c0034,0x69d8030a,0x00000000,0x00000000}},	//   wacz, aoue, --, --, 
   {{0x6bd56f49,0xf09cb87c,0x6604005c,0xb4d80109}},	//   _بولس_, _ngàn_, _biik, ngàv, 
   {{0x69d84e01,0xb8840174,0xd7f800d1,0x8c600092}},	//   coue, gtíð, шуқ_, _ለውጦች, 
   {{0x66056f4a,0x7bc80b1d,0x752d6f4b,0xa5040209}},	//   _diik, onfu, racz, дярл, 
   {{0x67ec04ce,0xa8800014,0x7bc96f4c,0xd75800ae}},	//   tøje, _آلوى, nnfu, _طلبت_, 
   {{0x6d496f4d,0xdce00316,0xa3bcad78,0x7bc88700}},	//   ygga, _pamě, _आगर_, infu, 
   {{0x66056f4e,0xdb196f4f,0xb1782d8b,0x644004d4}},	//   _giik, diví, _skåb, ámic, 
   {{0x9abc038f,0x3cf4033f,0x67ec01bf,0xc0bc0092}},	// [26050] _deċi, ेशों_, søje, _ተክለ_, 
   {{0x660401e2,0xb28418d9,0x69d921f4,0xf41c0108}},	//   _ziik, _дымк, zoue, mpä_, 
   {{0x66040337,0x69d804ce,0xd7f80356,0x957c0023}},	//   _yiik, youe, imă_, _ሕማቕን_, 
   {{0x9f596f50,0x3f8c0008,0xf8c807b6,0x00000000}},	//   _virá_, öfur_, ापाय, --, 
   {{0x69d80489,0x4fc03cd9,0xf41c023a,0x7bc808a5}},	//   voue, _كەرە, npä_, fnfu, 
   {{0xc0b4001e,0x9f580798,0xf41c005b,0x7bc85522}},	//   _lưỡi_, _tirá_, ipä_, gnfu, 
   {{0x69d96f51,0x07a400d1,0xfb100b24,0xb88403b2}},	//   toue, җанн, رويج, ytíð, 
   {{0xf41c006a,0x7e980014,0x7bc80083,0x2004a8d8}},	//   kpä_, _انٲر_, anfu, _émir_, 
   {{0x69d96f52,0x6604007d,0x20040014,0xb88406ea}},	//   roue, _riik, _رِہِ, vtíð, 
   {{0x66056f53,0x464800c7,0xb110063f,0x69d96f54}},	//   _siik, бзон_, _tụwa, soue, 
   {{0x66056f55,0x69d96f56,0xb88403b2,0x00000000}},	//   _piik, poue, ttíð, --, 
   {{0xf09c001e,0xc0b401fb,0xd7f80311,0xf65000db}},	//   _ngào_, _cưỡi_, amă_, رئپ_, 
   {{0x66040664,0xb88408a7,0x9abc0003,0x98a4054e}},	//   _viik, rtíð, _reċi, ramă_, 
   {{0xaca0ae74,0x66042252,0xb8840ad9,0x443c0427}},	//   _ngọn, _wiik, stíð, čt_, 
   {{0x46a44a40,0x66056f57,0xdb1800db,0x00000000}},	//   _хайв, _tiik, xiví, --, 
   {{0xaca0063f,0xdb180077,0x4528005b,0x05740633}},	//   _agọn, viví, _ужин_, _رابد, 
   {{0xf06000c7,0x5154117e,0x00000000,0x00000000}},	// [26060] нктп, ьтру, --, --, 
   {{0xdb196f58,0xf09c05d5,0xc3240eac,0x2480f13a}},	//   tiví, _tgàn_, _বাকি_, _irim_, 
   {{0x42080276,0x98a40064,0x00000000,0x00000000}},	//   _ынно_, mamą_, --, --, 
   {{0x24805f70,0x7bc80368,0x98a400c0,0x00000000}},	//   _krim_, wnfu, lamą_, --, 
   {{0xc0bc001f,0x00000000,0x00000000,0x00000000}},	//   _ተክሌ_, --, --, --, 
   {{0x7fd41c26,0x2d9000fd,0x7bc8022f,0x98a40024}},	//   _хімі, дрәс, unfu, namą_, 
   {{0xdb196f59,0x00000000,0x00000000,0x00000000}},	//   invø, --, --, --, 
   {{0x24816f5a,0x29f401f2,0x4ba400d1,0x3eac2737}},	//   _orim_, _ṅara_, зләң, ıktı_, 
   {{0xc0b4004d,0x4c3400ee,0x98a40024,0x80c001ad}},	//   _rưỡi_, _жэхт, kamą_, _रेमे, 
   {{0xb110063f,0x6c300597,0xec3404ae,0x98a40024}},	//   _hụta, _أفلا, _מאמר_, jamą_, 
   {{0xd7f8084c,0x2480007f,0xb110063f,0x225809a8}},	//   rmă_, _arim_, _kụta, jtrk_, 
   {{0x2480c773,0xf41c0108,0xd7f8054e,0x6ef000c0}},	//   _brim_, tpä_, smă_, _užbū, 
   {{0x2480f5c6,0xb11002e3,0xdce0294f,0xf484074d}},	//   _crim_, _mụta, _komı, чунн, 
   {{0x75fc0029,0x2480309b,0xf41c0958,0x98a40064}},	//   _mūzi, _drim_, rpä_, gamą_, 
   {{0xf1a56f5b,0x2480155d,0xe3b0143e,0x64940010}},	//   пран, _erim_, ارُ_, _ržiš, 
   {{0x24816f5c,0xa19400f7,0xf41c023a,0x00000000}},	//   _frim_, насч, ppä_, --, 
   {{0x24816f5d,0xe53c011a,0x00000000,0x00000000}},	// [26070] _grim_, _התחר, --, --, 
   {{0x06fc00bc,0x9f58010b,0xf20400c0,0x00000000}},	//   čívá_, _nirä_, _нямо, --, 
   {{0x0d740209,0x20040014,0x00000000,0x00000000}},	//   дыля, رِمِ, --, --, 
   {{0x2480022e,0x00000000,0x00000000,0x00000000}},	//   _yrim_, --, --, --, 
   {{0x9f596f5e,0xdce00139,0xe538010f,0x00000000}},	//   _birä_, _bomı, לטאט_, --, 
   {{0x09d40a5a,0xef640107,0x00000000,0x00000000}},	//   दव्य, _эъмо, --, --, 
   {{0x9f5800a2,0x00000000,0x00000000,0x00000000}},	//   _dirä_, --, --, --, 
   {{0xcda8104a,0x4ea401ec,0x88bc002b,0x00000000}},	//   _بهره_, _ерға, daśr, --, 
   {{0xf7716f5f,0x00000000,0x00000000,0x00000000}},	//   چاپ_, --, --, --, 
   {{0xb11002e3,0xf77008c9,0x24800200,0xf09c0051}},	//   _zụta, ناپ_, _rrim_, _ngàm_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x24816f60,0xdc70035b,0xf1bc01e1,0x00000000}},	//   _prim_, _рҳәы, _nmá_, --, 
   {{0xdb18022c,0x24806064,0x98a40153,0x6aa06330}},	//   livá, _qrim_, tamą_, lynf, 
   {{0x981400c6,0xf1bc00d8,0x00000000,0x00000000}},	//   _أبنا, _amá_, --, --, 
   {{0x98a40024,0xf6b01ec7,0xdb24003e,0xdb1855c8}},	//   ramą_, _لموج, ésék, nivá, 
   {{0x2480ea77,0xd17401e0,0xfe700133,0x00000000}},	//   _trim_, ныуы, ێدا_, --, 
   {{0xdee80b82,0x2480d32e,0x2610ce3e,0x6aa00142}},	// [26080] ማይን_, _urim_, _hão_, hynf, 
   {{0xf1bc00d2,0x3ea407d6,0xb4d80561,0xbea56f61}},	//   _emá_, мизг, rgàt, мазк, 
   {{0x7e556f62,0xb11000b4,0x00000000,0x00000000}},	//   ьтац, _pụta, --, --, 
   {{0x261003b7,0xdee80020,0xada0151e,0xdb180518}},	//   _mão_, ማርኛ_, кахл, divá, 
   {{0x3ea40029,0x26100016,0x442005b1,0xb4d800db}},	//   ņot_, _lão_, npk_, lgàr, 
   {{0xfe4405f5,0xa3c05b82,0x6f14003a,0xdce00139}},	//   _онго, ूचि_, ccxc, _qomı, 
   {{0x26104b87,0xb110063f,0xdb1805d5,0x8fd40075}},	//   _não_, _tụta, rivà, _чәтә, 
   {{0x98742bbd,0x79e400e5,0x442006be,0x00000000}},	//   елиц, بوعہ_, kpk_, --, 
   {{0xa3c094f7,0x9f5800fd,0xdce00166,0x00000000}},	//   ूचा_, _tirä_, _tomı, --, 
   {{0x7c202b8a,0x26100016,0x88816f63,0xb7656f64}},	//   mpor, _bão_, ایون, фтий, 
   {{0x261006ed,0x644045a7,0x00000000,0x00000000}},	//   _cão_, ámin, --, --, 
   {{0x261006ed,0x00000000,0x00000000,0x00000000}},	//   _dão_, --, --, --, 
   {{0x7c216f65,0xe4e402bf,0x64416f66,0x00000000}},	//   npor, вірн, šmin, --, 
   {{0xf1bc1873,0x38640022,0x7c20035b,0xfe0c1414}},	//   _smá_, _ipor_, ipor, िदास_, 
   {{0xa2788eb4,0xdd1400d0,0x00000000,0x00000000}},	//   мбру_, dĺži, --, --, 
   {{0x06fc00bc,0x74680229,0xf41c0139,0x5454003b}},	//   čítá_, _дров_, fxät_, _звит, 
   {{0x7c20d863,0xd4c40724,0x76596f67,0x6aa0012d}},	// [26090] jpor, _чөнк, ltty, zynf, 
   {{0x7c204ea1,0x76580076,0x248401bf,0x00000000}},	//   dpor, otty, æmme_, --, 
   {{0x7c216f68,0x76596f69,0xc32400fe,0x5f74036b}},	//   epor, ntty, _বাচি_, ضالر, 
   {{0x386401c4,0x7c21452d,0x765875a1,0xb03001af}},	//   _opor_, fpor, itty, _иммә, 
   {{0x7c216f6a,0x76580076,0x6aa00042,0x00000000}},	//   gpor, htty, wynf, --, 
   {{0xdb183fb1,0x25bc07b7,0xc8380023,0x00000000}},	//   tivá, _उष्ण, _ኩርማን, --, 
   {{0x38640ca8,0x7c200588,0x30e000dc,0xdce0013d}},	//   _apor_, apor, _कुतः_, _tamğ, 
   {{0x09e402a6,0x7c2001e4,0xdb180518,0x6aa16f6b}},	//   _পূজা, bpor, rivá, rynf, 
   {{0x26100a16,0x7c20107d,0x6aa0002d,0x1fc400eb}},	//   _são_, cpor, synf, ্তরস, 
   {{0x261006ed,0x765812ed,0x6aa0000f,0x6a64007b}},	//   _pão_, ftty, pynf, _يطال, 
   {{0x38c861be,0x07a400d1,0x67ec01bf,0x06e800d4}},	//   قایی_, _җайн, bøjn, ямок_, 
   {{0x261003b7,0xb1788ce1,0x0444081d,0x99840597}},	//   _vão_, _skån, немн, _للمو, 
   {{0xa8a56f6c,0x0b5002d3,0x00000000,0x00000000}},	//   _تصاو, _ዘኽታማ, --, --, 
   {{0x261003b7,0x0708009f,0xf53c007c,0x7b0400a2}},	//   _tão_, _عيبي_, lkål_, _ýutý, 
   {{0x366406bb,0x7658c1d3,0x44216f6d,0xfbd0011a}},	//   _защо_, ctty, spk_, אתם_, 
   {{0x7c216f6e,0xb4d800db,0x568800ec,0x7a080210}},	//   ypor, rgàr, _آئوٽ_, _kętr, 
   {{0x65640537,0x7c216f6f,0x00000000,0x00000000}},	// [260a0] _ibih, xpor, --, --, 
   {{0x7c204bc1,0x00000000,0x00000000,0x00000000}},	//   vpor, --, --, --, 
   {{0x7c216f70,0x8188eb7c,0xaadd1f20,0x00000000}},	//   wpor, _فندق_, _पुलक, --, 
   {{0x7c21354e,0xd9d404c5,0xc0f400b7,0xbea40022}},	//   tpor, _হীনম, _ጉግል_, маҷк, 
   {{0x7c216f71,0x6564c6ce,0xf53c353e,0x00000000}},	//   upor, _mbih, dkål_, --, 
   {{0x7658f5dd,0x6c800691,0x00000000,0x00000000}},	//   ytty, الوم, --, --, 
   {{0x38656f72,0xed60012c,0x79a56f73,0x3a396f74}},	//   _spor_, íží_, ерпе, épp_, 
   {{0xfe440364,0xfce402bf,0xcdf4013d,0x00000000}},	//   _онҳо, _зобо, _ачуы, --, 
   {{0xa3e01b57,0x3dc40086,0x644002fb,0x4870036b}},	//   तवा_, miow_, ámil, لگوس, 
   {{0x65656f75,0x3dc404ba,0xf41c01e3,0xf99000db}},	//   _abih, liow_, lväg_, _ڭبئ_, 
   {{0xf7700131,0xaa4000d8,0x00000000,0x00000000}},	//   ناھ_, _бехл, --, --, 
   {{0xf41c049f,0x76596f76,0x09c4035b,0xfa680022}},	//   nväg_, rtty, _иахҟ, _маҷк_, 
   {{0x76580175,0x38640219,0xf60807d6,0xdb1801bf}},	//   stty, _upor_, _کتته_, rivæ, 
   {{0x65656f77,0xd5b80a2f,0xb9dc0092,0x00000000}},	//   _ebih, mpām_, _ሥም_, --, 
   {{0xdce0005f,0xdb181057,0xd5b800e2,0xf41c01e3}},	//   _kamē, mivä, lpām_, kväg_, 
   {{0xdb186583,0x29080de2,0xfa500023,0x00000000}},	//   livä, ñcax_, _ዘይሰማ, --, 
   {{0xe3b00832,0x62980798,0xf4841cb8,0x00000000}},	// [260b0] _گري_, _àvon, _чуйн, --, 
   {{0xdb180f23,0xdb0808a5,0x00000000,0x00000000}},	//   nivä, _aldí, --, --, 
   {{0xe3b0021a,0x6e64023a,0xb0300075,0x656801d3}},	//   _دري_, этаж, _әмгә, ődhe, 
   {{0x65640135,0xdb1857d9,0xa19400c0,0x80c00210}},	//   _xbih, hivä, _баюч, _रेवे, 
   {{0xdb18023a,0xdbe401e1,0xcf900014,0x00000000}},	//   kivä, _kéèy, _پۯاژ, --, 
   {{0xf09c001e,0x9f10031c,0x9b680640,0xcfa40588}},	//   _ngài_, _ཏུརཀ_, ешћа_, _рымҩ, 
   {{0x33300a40,0xca747406,0xdfd44494,0xdb180254}},	//   _mexx_, тулы, _соры, divä, 
   {{0x2f3c063f,0xdbe40241,0x00000000,0x00000000}},	//   _ọghu_, _léèy, --, --, 
   {{0xf8ac004b,0x2d9c0393,0xab600ef6,0x67ec005c}},	//   يکه_, _ioue_, _مۇشى, bøjl, 
   {{0x65640280,0xc7a56f78,0x2d9d6f79,0x20d800d0}},	//   _sbih, тиок, _houe_, _užiť_, 
   {{0x2d9c0660,0x46f400a7,0x9b680116,0x668001d5}},	//   _koue_, ъчит, _яшта_, ایبل, 
   {{0x18b0052f,0x2d9d6f7a,0xafd803b2,0x6e20000f}},	//   рҙәр, _joue_, _hvød, ânby, 
   {{0x290c0589,0xd9b017de,0x33300327,0xdbe40241}},	//   _igga_, _دەيد, _bexx_, _béèy, 
   {{0xf8b40375,0x2d9d6f7b,0x3dc40165,0x80c001f9}},	//   _בפני_, _loue_, ziow_, _रेषे, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x65640526,0x2d9d4252,0x515419bb,0xf53c369d}},	//   _ubih, _noue_, лтуу, shår_, 
   {{0x032400db,0x4174072d,0x00000000,0x00000000}},	// [260c0] _идпн, _یاحس, --, --, 
   {{0xa069061b,0xd094dcd2,0x68e96f7c,0x00000000}},	//   маға_, ышсы, _mygd, --, 
   {{0x752c145e,0x25a06368,0xdb185243,0x27e405b1}},	//   _ânzö, _koil_, nivå, _mknn_, 
   {{0x290c0490,0x1cb00327,0xa03400cf,0x00000000}},	//   _ngga_, ྒྱའ_, _مۉرت, --, 
   {{0x2d9c0dd4,0xec10094f,0x61e56f7d,0x3dc40428}},	//   _doue_, لوند, moil, riow_, 
   {{0x290c422c,0x61e56f7e,0xf41c0267,0xdce000e2}},	//   _agga_, loil, sväg_, _samē, 
   {{0x2d9d6f7f,0x25a000ad,0xdce000e2,0xd948010b}},	//   _foue_, _ooil_, _pamē, еҗек_, 
   {{0x68e96f80,0xada15080,0x61e50c23,0x2d9d6f81}},	//   _bygd, _касл, noil, _goue_, 
   {{0xada13900,0xdb186935,0x9928004b,0xa9640063}},	//   _татл, tivä, وتکې_, тиња_, 
   {{0x61e56f82,0x25a0464c,0x290c00cc,0x68e806ea}},	//   hoil, _aoil_, _egga_, _dygd, 
   {{0x61e4049b,0xe7300134,0x2bac2de3,0x48700131}},	//   koil, _deε_, जघरा, لگۈس, 
   {{0xb5a464d6,0x61e402f6,0xdb186583,0x521424ae}},	//   трой, joil, sivä, ғдат, 
   {{0x61e56f83,0xdb180108,0x00000000,0x00000000}},	//   doil, pivä, --, --, 
   {{0x1cb00135,0x25a001ab,0x2704013f,0x61e400ad}},	//   ྒྱར_, _eoil_, bɑn_, eoil, 
   {{0x9f4c79f6,0x32086610,0x61e56f84,0x62980129}},	//   _òdù_, дхан_, foil, _àvol, 
   {{0x25a003d5,0x61e56f85,0x68e800a2,0x00000000}},	//   _goil_, goil, _yygd, --, 
   {{0x2d9d6f86,0x50f45728,0x611419bb,0x33300221}},	// [260d0] _roue_, узат, рдуу, _texx_, 
   {{0x2d9c0036,0x61e400ad,0xfd640022,0xf36400d8}},	//   _soue_, aoil, pyrữ, _ртин, 
   {{0x1cb0003d,0xdbdc1873,0x2e24013f,0x2d9c017a}},	//   ྒྱལ_, _ráðh, rεfo_, _poue_, 
   {{0xdef96f87,0x61e56063,0x91c4013d,0x2284010a}},	//   тыу_, coil, _сәгл, _туьг, 
   {{0xef916f88,0x2d9c00ad,0xcb686193,0xa3e801f9}},	//   _پیاد, _voue_, еале_, बतच_, 
   {{0x2d9c0109,0x00000000,0x00000000,0x00000000}},	//   _woue_, --, --, --, 
   {{0x68e804ce,0x9f240131,0x2d9d6f79,0xfc3c0023}},	//   _sygd, _ئۈمۈ, _toue_, _ኣይፍለ, 
   {{0x3cb00209,0x0e0401f0,0x00000000,0x00000000}},	//   рйәр, _сӯзо, --, --, 
   {{0x2704013f,0x25a01713,0x2d0c04af,0x0904030d}},	//   wɑn_, _roil_, िशील_, ыпин, 
   {{0x2704013f,0x25a16f89,0x475802ac,0x2aa8009b}},	//   tɑn_, _soil_, хрия_, _отео_, 
   {{0xadc00016,0x25a007ea,0x61e4009f,0x00000000}},	//   _giản, _poil_, yoil, --, 
   {{0x25a0022e,0xd7c8141b,0x290d6f8a,0xdb18007c}},	//   _qoil_, _یونه_, _ugga_, rivå, 
   {{0x61e56f8b,0x25a01529,0x2704013f,0xb60401a8}},	//   voil, _voil_, sɑn_, _sjáð, 
   {{0xb88002fd,0x00000000,0x00000000,0x00000000}},	//   čítk, --, --, --, 
   {{0x61e56f8c,0xb7d8008d,0x324001e0,0x25a16f8d}},	//   toil, _אקסי, йерг, _toil_, 
   {{0xc5d40212,0xc3240131,0x61e40076,0x04940153}},	//   _щіль, _өмик, uoil, _броў, 
   {{0x61e56f8e,0x03a400d8,0x04c83cc6,0x00000000}},	// [260e0] roil, _бипо, _سودي_, --, 
   {{0x1cb0025c,0x61e56f8f,0xdbe401e1,0xb60408a5}},	//   ྒྱས_, soil, _tééy, _tjáð, 
   {{0x82a56f90,0xaac01889,0x61e4005b,0xbd696f91}},	//   _санж, _वेलक, poil, ерле_, 
   {{0x61540133,0x00000000,0x00000000,0x00000000}},	//   _خۆرئ, --, --, --, 
   {{0x9b58009d,0x909401ee,0xdef00023,0x315400df}},	//   вилт_, _кјрљ, ግዚኡ_, _גיכן_, 
   {{0x44300f7b,0xdb080005,0xeb956f92,0x9bc8007b}},	//   _mwy_, _aldá, лич_, ضوعك_, 
   {{0x4430040c,0x8e74004e,0x00000000,0x00000000}},	//   _lwy_, _кутч, --, --, 
   {{0xdb08049f,0xf644036b,0x6e2001d3,0x44300210}},	//   _omdö, қхон, ínbe, _owy_, 
   {{0x44300368,0xed4c0014,0x57b40229,0x5fa8000d}},	//   _nwy_, _ژپہ_, ибит, _गवाल, 
   {{0x8b64e5e7,0xdb0803b2,0x9f580332,0xe8f473b5}},	//   _نامم, _eldá, _bhré_, ыныч_, 
   {{0x7bc96f93,0x44310a06,0x9f5800ae,0xa3e800c5}},	//   mifu, _awy_, _chré_, यकन_, 
   {{0x443003cb,0x00000000,0x00000000,0x00000000}},	//   _bwy_, --, --, --, 
   {{0xe97024c5,0x2bd807c1,0x3acc06be,0x00000000}},	//   _دهند, _बदमा, _həp_, --, 
   {{0x443000a9,0x69c401e1,0x00000000,0x00000000}},	//   _dwy_, _ìjer, --, --, 
   {{0xc7640075,0x1948037e,0xca2824ae,0xf77001d3}},	//   _خانى, _ｆｐｓ_, ﻣﻤﺎ_, _ناں_, 
   {{0x44300cfd,0x7bc96f94,0x644000d8,0xf07400d1}},	//   _fwy_, hifu, âmic, либә_, 
   {{0x7bc96f95,0x4430015d,0xcfe80066,0x00000000}},	// [260f0] kifu, _gwy_, نفره_, --, 
   {{0x7bc805d9,0xd100000b,0x9f3402dd,0xafd8005c}},	//   jifu, लेषण_, йеуі, _svøb, 
   {{0x7bc8df98,0xaac0150d,0xce5828e8,0xcdc40124}},	//   difu, _वेंक, таец_, аӡак, 
   {{0x73740124,0x30e40816,0x224c00d7,0x00000000}},	//   _рыҩх, _бігб, ádke_, --, 
   {{0x7bc8002f,0x1b0c0154,0x00000000,0x00000000}},	//   fifu, সুমে_, --, --, 
   {{0x7bc96f96,0xdea413f9,0xcb685c83,0x00000000}},	//   gifu, _گیمی, таке_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3eac4675,0x7bc96f97,0x8c2401d5,0x2bb400c5}},	//   øfte_, aifu, _نفره, _अतवा, 
   {{0xc7940598,0x7bc819e1,0x06880150,0xe7440166}},	//   арны, bifu, _ﯗﻳﻘﯩ, гүле_, 
   {{0x443000a9,0x47c4e4c1,0x00000000,0x00000000}},	//   _rwy_, рбов, --, --, 
   {{0x7bf804ac,0x6d58020b,0xcd540092,0x00000000}},	//   _ספעצ, _kcua, _የምንገ, --, 
   {{0x6930267e,0x443000a9,0xb8800118,0x98b401e0}},	//   _اکثر, _pwy_, čírk, рһәт_, 
   {{0x67ec0194,0x682417b4,0x00000000,0x00000000}},	//   høji, _сьез, --, --, 
   {{0x4aa83f7e,0x00000000,0x00000000,0x00000000}},	//   _कथाव, --, --, --, 
   {{0xd7740b6c,0x00000000,0x00000000,0x00000000}},	//   _دانع, --, --, --, 
   {{0x7bc80928,0x6d580070,0x4db803d4,0x291c036e}},	//   zifu, _ncua, েকুৱ, ncua_, 
   {{0xbfc56f98,0x00000000,0x00000000,0x00000000}},	// [26100] абак, --, --, --, 
   {{0x7f440212,0x741010e8,0x00000000,0x00000000}},	//   режж, _گویا, --, --, 
   {{0x7bc8696c,0x00000000,0x00000000,0x00000000}},	//   vifu, --, --, --, 
   {{0x9324034c,0x7bc96f99,0x6e9001b9,0xa3c00118}},	//   _پرین, wifu, تلما, ूचक_, 
   {{0x7bc96f9a,0xed5493e4,0x21200010,0x00000000}},	//   tifu, роч_, mcih_, --, 
   {{0x6d596f9b,0xdb08002d,0x212009a8,0x703805d9}},	//   _ecua, _omdô, lcih_, _جسٽس_, 
   {{0x6e416f9c,0x3acc06be,0xab94178c,0x00000000}},	//   _мерз, _qəp_, شخور_, --, 
   {{0x7bc85b36,0x21216f9d,0x6d58007b,0x1cb0025c}},	//   sifu, ncih_, _gcua, ྒྱུ_, 
   {{0x7bc8055a,0x00000000,0x00000000,0x00000000}},	//   pifu, --, --, --, 
   {{0x58d402dd,0xbbd401ee,0x00000000,0x00000000}},	//   _қолт, _тібњ, --, --, 
   {{0xdce00024,0xc5ec004b,0xdb1802d2,0x00000000}},	//   _pamė, کړو_, fnvö, --, 
   {{0x21200427,0x00000000,0x00000000,0x00000000}},	//   jcih_, --, --, --, 
   {{0x9f580724,0x21200010,0x656001c3,0x23b4007c}},	//   _birü_, dcih_, òmha, _säja_, 
   {{0x9f58feac,0x92587765,0x00000000,0x00000000}},	//   _miró_, лагт_, --, --, 
   {{0x31c40c98,0x88bc002b,0x00000000,0x00000000}},	//   асав, daśy, --, --, 
   {{0x4e1c0c2e,0xdb0800fd,0x23b4007c,0xd9f83f7e}},	//   _बंबई_, _ildä, _väja_, ुषित_, 
   {{0xd0116f9e,0x32c4022e,0x2c0003d4,0xb3640395}},	// [26110] سلا_, _dеya_, ৰীয়ে_, _кънк, 
   {{0x2fc401dc,0x6d596f9f,0x1fb8026f,0x92e403d4}},	//   òng_, _scua, алуы_, _ফণী_, 
   {{0x39443e65,0x644000e4,0x00000000,0x00000000}},	//   _odos_, ámiv, --, --, 
   {{0x5194007b,0x00000000,0x00000000,0x00000000}},	//   _الحذ, --, --, --, 
   {{0xdcf804a9,0x76a803b9,0x00000000,0x00000000}},	//   ۇرۇش_, ləyd, --, --, 
   {{0x39456fa0,0x00000000,0x00000000,0x00000000}},	//   _ados_, --, --, --, 
   {{0x90b400d1,0x7bd800d7,0x76a806be,0x00000000}},	//   _тәңш, _djtu, nəyd, --, 
   {{0xac740046,0x6cb004b3,0x00000000,0x00000000}},	//   _پارش, _мөлт, --, --, 
   {{0x9f596fa1,0xcd540092,0x291c036e,0x00000000}},	//   _giró_, _የምናገ, rcua_, --, 
   {{0x291d6fa2,0x7e6c003e,0x67ec005c,0x21200010}},	//   scua_, _ypbp, højv, zcih_, 
   {{0x9a8801d9,0x060800f3,0x3f78010f,0x00000000}},	//   _پننٕ_, лнок_, אָכע, --, 
   {{0x629806af,0xdcac00db,0x76a803b9,0x00000000}},	//   _àvoi, _سۉۉ_, dəyd, --, 
   {{0x9f58011c,0xb0c405f9,0xdb193647,0x21200219}},	//   _mirò_, _रेलग, rnvö, vcih_, 
   {{0x6b800023,0x00000000,0x00000000,0x00000000}},	//   ndng, --, --, --, 
   {{0x21200219,0x394400c0,0x89f8010f,0x00000000}},	//   tcih_, _ydos_, ָפּה, --, 
   {{0xd6d800d1,0xbfa80014,0x3ebc032e,0x00000000}},	//   _әтә_, گارٕ_, _ýtti_, --, 
   {{0x21200365,0x3ff400c6,0xf41c0108,0xdee801f3}},	// [26120] rcih_, مكرر, lvän_, ዛይን_, 
   {{0x64444894,0x62780131,0x7b0c0254,0x21200010}},	//   _ivii, _پەرز_, _jõuü, scih_, 
   {{0x4ca4045e,0x6444005c,0x6b801bce,0x21200010}},	//   _খেলু, _hvii, ddng, pcih_, 
   {{0x9f583fa8,0xddd40030,0x61b4215c,0x57a40073}},	//   _cirò_, ťaži, _بەرا, _ओव्ह, 
   {{0x9f5802e8,0x88bc0882,0x644401f4,0xa3ac01f9}},	//   _dirò_, paśy, _jvii, _खवा_, 
   {{0xafd80579,0xba740736,0x1a9401d5,0x00000000}},	//   _hvøn, ماعت, жакў, --, 
   {{0xdce8887f,0x629d6fa3,0x64456fa4,0x3ebc05ac}},	//   ılıq, nxro, _lvii, _ått_, 
   {{0x9f596fa5,0x64456fa6,0x7a080118,0xdd1c0419}},	//   _girò_, _ovii, _křti, lážo, 
   {{0xa3e84da1,0x64441418,0xc62400eb,0x00000000}},	//   यका_, _nvii, _ময়লা_, --, 
   {{0xb7e403d4,0x999c0024,0x6cd006c2,0x65600e89}},	//   নষ্ট, tuvų_, _عقلا, òmhn, 
   {{0x96f96fa7,0x95d8a9c3,0x64456fa8,0x00000000}},	//   рент_, идот_, _avii, --, 
   {{0xb86404d3,0x3944014b,0xa80000dc,0x4a000022}},	//   _هاتو, _udos_, _ajñā, _ҭҟәа, 
   {{0xb0c4561f,0x64451065,0xdd1c02fb,0x6448007f}},	//   _रेंग, _cvii, kážo, ņdin, 
   {{0x9f580597,0x798002b5,0x1cb0025c,0xa84401b9}},	//   _bhrí_, _haow, ྒྱག_, _الوم_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x224c219b,0x4cdc03d4,0xf20400d4,0x00000000}},	//   ádka_, _বৰফু, сяго, --, 
   {{0x644029ac,0x79800810,0x9098bf29,0x6b80014f}},	// [26130] ámit, _maow, шват_, ydng, 
   {{0xf53c0bd7,0xd34001d3,0x00000000,0x00000000}},	//   laå_, _زہری, --, --, 
   {{0x644405b8,0x00000000,0x00000000,0x00000000}},	//   _zvii, --, --, --, 
   {{0x3eac332c,0xb178168c,0x628002b1,0x67ec005c}},	//   øfta_, _sjåf, āmot, løjt, 
   {{0x8c440262,0xd5b8005f,0xc5500023,0x00000000}},	//   целе, lpās_, _ቁጠባዉ, --, 
   {{0xcf9001d9,0xf41c023a,0x80c0033f,0x0c740092}},	//   _تژر_, yvän_, _रेटे, _በግማሽ_, 
   {{0x2ea40014,0x9f580bdf,0xdce000b8,0xfaa00395}},	//   _اپزی_, _tirò_, _yamī, дащо, 
   {{0x1cb00327,0xdb1802f0,0x67ec005c,0x9f4c0248}},	//   ྒྱང_, mivý, højt, _òdò_, 
   {{0xc8c801b9,0xdb180306,0x00000000,0x00000000}},	//   شودن_, livý, --, --, 
   {{0x64440d04,0xb1780158,0x86442bbd,0x0bb401b9}},	//   _rvii, _fjåg, онож, _بجرگ, 
   {{0x5c040323,0x69e40953,0xdb1802fb,0x644426bb}},	//   _хята, _людз, nivý, _svii, 
   {{0x3ebc0598,0xf41c3f3b,0x00000000,0x00000000}},	//   _ütte_, rvän_, --, --, 
   {{0x69c96fa9,0x7b0c000d,0xd5b800ef,0x00000000}},	//   _imge, _tõuü, epās_, --, 
   {{0xdce03a71,0x644404ba,0x998000d0,0x5c480257}},	//   _samī, _vvii, ďiť_, _ናይጀር, 
   {{0xcc9000dc,0x601001e1,0xdb1802f0,0xdce00171}},	//   _hṛdi_, _lómì, jivý, _pamī, 
   {{0xdb180306,0x2cac0174,0x644401f4,0x63bc01a9}},	//   divý, kygd_, _tvii, shrn, 
   {{0x64451e6a,0x85b80330,0x765c0022,0x00000000}},	// [26140] _uvii, _ماکس_, _ãpyr, --, 
   {{0x24800365,0x9f58007b,0xb17803cd,0x78a40158}},	//   _isim_, _thrí_, _skåt, økvi, 
   {{0x69c87890,0xdd1c0122,0xf53c007c,0xdce000b8}},	//   _omge, rážo, ckås_, _tamī, 
   {{0xf53c39c2,0x2480022e,0xafd80174,0xf41c0267}},	//   lkår_, _ksim_, _hvøl, kväl_, 
   {{0xafd81125,0x21340100,0xad8400db,0x00000000}},	//   _kvøl, čchč_, تالۇ, --, 
   {{0xcd2843e8,0x69c803cb,0xdb180306,0x7b6400d4}},	//   لسۇن_, _amge, bivý, ітле, 
   {{0x798002b1,0x0ef80953,0x225800c5,0x67ec3778}},	//   _paow, _гэты_, nurk_, højs, 
   {{0x248004b9,0x6e90678a,0x2cac2147,0xed5486e5}},	//   _osim_, _تلفا, bygd_, _мос_, 
   {{0xf53d6faa,0x60100248,0x2258257c,0x00000000}},	//   vaå_, _gómì, hurk_, --, 
   {{0x37a96fab,0x69c89e0b,0xfd64002b,0x798000b0}},	//   ртин_, _emge, _aduḥ, _waow, 
   {{0x24816fac,0x798099b7,0x22580d27,0x0ba800cf}},	//   _asim_, _taow, jurk_, _ااقى_, 
   {{0xfd640055,0x3ebc032e,0x00000000,0x00000000}},	//   _cduḥ, _ýttu_, --, --, 
   {{0xf53c0589,0xdb1802f0,0x14c40073,0xb8d40345}},	//   raå_, zivý, _लेखण, _بتاش, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x24816fad,0x67ec037e,0x69c800a9,0xafd80162}},	//   _esim_, røjt, _ymge, _dvøl, 
   {{0xf53c33b8,0x2bb400dc,0x00000000,0x00000000}},	//   rkås_, _अत्थ, --, --, 
   {{0x2bd8c725,0x9f5800a3,0xb1780158,0x63c82d8b}},	// [26150] _बदला, _bhrà_, _skås, ørnø, 
   {{0xdb196fae,0x22596faf,0x00000000,0x00000000}},	//   givü, burk_, --, --, 
   {{0x93c801d9,0x29d00356,0xa3e80263,0x92a800fe}},	//   _ناگہ_, nţac_, यकर_, _খেৰ_, 
   {{0x427800c8,0xb1780158,0xdb1800d0,0x2cac0162}},	//   _פארג, _bjåe, rivý, tygd_, 
   {{0xf41c01e6,0xc1980375,0xdb1802f0,0x00000000}},	//   kväm_, _השרי, sivý, --, 
   {{0xdb1802f0,0x2cac0174,0x00000000,0x00000000}},	//   pivý, rygd_, --, --, 
   {{0xb110063f,0x629807ea,0x00000000,0x00000000}},	//   _bụga, _àvot, --, --, 
   {{0x2a680092,0x48580006,0x00000000,0x00000000}},	//   ደተኞች_, броў_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x60c00790,0xf41c0267,0x00000000,0x00000000}},	//   _ümme, rväl_, --, --, 
   {{0x85e80a93,0x00000000,0x00000000,0x00000000}},	//   йдов_, --, --, --, 
   {{0x69c96fb0,0x24816fb1,0x67ec037e,0xafd80174}},	//   _umge, _psim_, tøjs, _svøl, 
   {{0x22580b21,0xe7340184,0x18805409,0x24800135}},	//   wurk_, _һеҙ_, _аңын, _qsim_, 
   {{0x22596fb2,0x81ac0154,0x645800b8,0x00000000}},	//   turk_, _ঔষধ_, _āvid, --, 
   {{0x41b400a7,0x69d962b1,0x45d40353,0xf53c007c}},	//   псат, onue, _нцит, rkår_, 
   {{0x24800190,0xd5b800da,0xb1781088,0x69d8f4c9}},	//   _tsim_, spār_, _skår, nnue, 
   {{0x24802b92,0x6604020c,0x237800d8,0x69d801ab}},	// [26160] _usim_, _ihik, perj_, inue, 
   {{0xafd803b2,0xe35401d9,0x8338005b,0x823400cf}},	//   _hvøj, _کٹھک, _учит_, _ىرجا, 
   {{0x9f5801e7,0x00000000,0x00000000,0x00000000}},	//   _chrá_, --, --, --, 
   {{0x6604009f,0x7c6418fd,0xee2c00ec,0x69d8036e}},	//   _jhik, كاتل, اٽن_, jnue, 
   {{0x6604006f,0xa2d45690,0x9f5801ab,0x00000000}},	//   _mhik, णपक्, _thrà_, --, 
   {{0x60c40928,0x00000000,0x00000000,0x00000000}},	//   mzim, --, --, --, 
   {{0x66056fb3,0x9f5800c6,0x60c56fb4,0x1cc0031c}},	//   _ohik, _ghrá_, lzim, གནང_, 
   {{0x69d80399,0x6ed80375,0xa9c002bf,0x60c42255}},	//   gnue, _החלפ, еськ, ozim, 
   {{0x60c56fb5,0xdb08145e,0xa3dc0490,0x95140055}},	//   nzim, _kodë, ढचा_, _iṅga, 
   {{0x66056fb6,0x81e002f5,0x60c40194,0x7c20022e}},	//   _ahik, ধতি_, izim, mqor, 
   {{0x66040a28,0xdb080023,0x8b645874,0xab8000db}},	//   _bhik, _modë, _تاقم, _سۇيۉ, 
   {{0x66056fb7,0xdb08036e,0xb9000154,0x00000000}},	//   _chik, _lodë, _ধর_, --, 
   {{0x66056fb8,0xafd8eda6,0x7c212962,0x7bd4002e}},	//   _dhik, _svøm, nqor, éyuw, 
   {{0x60c4fb31,0x660418a6,0x386403b9,0xd1bc0092}},	//   dzim, _ehik, _iqor_, ሰዱት_, 
   {{0xf628113e,0xa29402bf,0x777801c4,0x7c2001a9}},	//   _استى_, нарі, metx, hqor, 
   {{0x76596fb9,0x777805f5,0x60c403fa,0xb9f8001f}},	//   muty, letx, fzim, _ቅኝ_, 
   {{0x76596fba,0xdb0805ac,0x60c40139,0x00000000}},	// [26170] luty, _eldø, gzim, --, 
   {{0x1cb0003d,0x69d80399,0x951400dc,0x425405d9}},	//   ྒྱབ_, znue, _aṅga, _ڪنٽر, 
   {{0x76580432,0x60c424be,0xafd80162,0xf3fc00d8}},	//   nuty, azim, _hvøk, ltão_, 
   {{0x69d80226,0x9180215c,0x66040200,0x00000000}},	//   xnue, _جۇرۇ, _xhik, --, 
   {{0x8ccc068f,0xf3fc06ed,0x7658004b,0x7778005a}},	//   _देशो, ntão_, huty, ketx, 
   {{0x76596fbb,0xdb080100,0x9f5801e7,0xf41c00cc}},	//   kuty, _kodè, _thrá_, _ভবাৰ_, 
   {{0x777801c4,0xdb180306,0x09e42c25,0x69d80200}},	//   detx, chví, мокн, tnue, 
   {{0xdb096fbc,0x3eac3262,0x76584429,0xecf000d1}},	//   _modè, äfte_, duty, _كۋاد, 
   {{0x1cb01efe,0x69d96fbd,0x7778005a,0xdb080129}},	//   ྒྱད_, rnue, fetx, _lodè, 
   {{0x66056fbe,0x76581418,0x7778005a,0x46482d7f}},	//   _shik, futy, getx, озон_, 
   {{0x66056fbf,0x765871aa,0x9be402bf,0xf3fc0798}},	//   _phik, guty, _чітк, etão_, 
   {{0xd7f8084c,0xb110063f,0xd02404c5,0x04440166}},	//   ală_, _mụba, মীয়_, мемн, 
   {{0x6605346d,0x777801c0,0xd7f80276,0x76580072}},	//   _vhik, betx, blă_, auty, 
   {{0x76596fc0,0x57e80220,0xd7f80311,0x9f580165}},	//   buty, _едім_, clă_, _jirô_, 
   {{0x66056fc1,0xe2f800dd,0x52741e76,0x46a401c6}},	//   _thik, سورڈ_, нуту, _цайв, 
   {{0x66041442,0x60c4ef32,0xdb08036e,0x00000000}},	//   _uhik, tzim, _sodë, --, 
   {{0x60c40bb8,0x34800022,0x75c8033f,0x7c200009}},	// [26180] uzim, _агыг, języ, xqor, 
   {{0x60c56fc2,0xea9c00cd,0xdce00055,0xdb1801e7}},	//   rzim, _guṇo_, _samį, thví, 
   {{0xdd1c02f0,0xf41005d0,0x60c41c97,0x00000000}},	//   _vážk, _שפת_, szim, --, 
   {{0x8fc400c7,0xdb180413,0x77787125,0x00000000}},	//   _ҟасҵ, rhví, zetx, --, 
   {{0x6440019f,0x6ce001ec,0x00000000,0x00000000}},	//   âmih, кіше, --, --, 
   {{0x7c216fc3,0x777801c4,0x2d9005a2,0xb88402d2}},	//   rqor, xetx, ерәс, hríð, 
   {{0x7c200014,0x0e5400a7,0x765801e2,0x20180037}},	//   sqor, _пътя, xuty, _iiri_, 
   {{0x20196fc4,0x65640e78,0x7c20022e,0x765801f4}},	//   _hiri_, _ncih, pqor, vuty, 
   {{0x7c2032ff,0xdb096fc5,0x777801c0,0x76580472}},	//   qqor, _modé, tetx, wuty, 
   {{0x201805db,0x76596fc6,0xdb08003e,0x6c0000c7}},	//   _jiri_, tuty, _lodé, _азуз, 
   {{0x20196fc7,0x777805f5,0xf6e43cc5,0xd7f8054e}},	//   _miri_, retx, ьцин, rlă_, 
   {{0x20196fc8,0xadc0001e,0xdb0801c7,0xb88401a8}},	//   _liri_, _miến, _nodé, gríð, 
   {{0x777801c0,0x20180099,0x68416fc9,0xd7f80311}},	//   petx, _oiri_, _анча, plă_, 
   {{0xf3fc0cfc,0x20196fca,0x765803a2,0xdb081497}},	//   rtão_, _niri_, puty, _podè, 
   {{0xf3fc0cfc,0x66240030,0x7658009a,0x00000000}},	//   stão_, ľské, quty, --, 
   {{0x66240308,0x20196fcb,0xdb08cfe0,0x00000000}},	//   žské, _airi_, _codé, --, 
   {{0x33a800a7,0x00000000,0x00000000,0x00000000}},	// [26190] _дъно_, --, --, --, 
   {{0xadc001fb,0x00000000,0x00000000,0x00000000}},	//   _biến, --, --, --, 
   {{0x20196fcc,0xdfd800a7,0x00000000,0x00000000}},	//   _diri_, фът_, --, --, 
   {{0x20180332,0x4cdc0183,0xdce006be,0xab700092}},	//   _eiri_, _বৰষু, _anmı, _ጣቢያው_, 
   {{0x20196fcd,0x1c00007d,0xf1bc0248,0x656001ab}},	//   _firi_, _लीहल_, _ilá_, òmhi, 
   {{0x20196fce,0x60c16fcf,0x2604030a,0x00000000}},	//   _giri_, _ümma, oñoc_, --, 
   {{0xadc001fb,0x63a801e6,0x00000000,0x00000000}},	//   _giến, ödni, --, --, 
   {{0x9e04008e,0xdd94004e,0x08340107,0x00000000}},	//   _ачул, _иасы, нхоя, --, 
   {{0x20196fd0,0x764811ad,0x00000000,0x00000000}},	//   _yiri_, _avfy, --, --, 
   {{0x7c2400e8,0x20196fd1,0x23b40432,0x06c800db}},	//   _ékra, _xiri_, _täji_, згой_, 
   {{0xf1bd6fd2,0xb88408a7,0xdce00118,0x00000000}},	//   _olá_, tríð, _obmě, --, 
   {{0xf1bc0ca8,0x76a806be,0x00000000,0x00000000}},	//   _nlá_, məyl, --, --, 
   {{0xdb081497,0x76a803e3,0x00000000,0x00000000}},	//   _rodé, bəyo, --, --, 
   {{0xf1bd6fd3,0xdb180162,0xd8386c9c,0x03a400d8}},	//   _alá_, lhvá, _цэц_, ѕиво, 
   {{0x20196fd4,0xf1bd6fd5,0xdb096fd6,0xb17800fe}},	//   _riri_, _blá_, _podé, _sjåa, 
   {{0x20196fd7,0x6564003e,0x51546768,0xf1bc00d7}},	//   _siri_, _ucih, ктуу, _clá_, 
   {{0x20196fd8,0xf1bc00d2,0x6ad82894,0x058c0150}},	// [261a0] _piri_, _dlá_, यपुर, _ﺩﯗﺷﭙ, 
   {{0x705004a9,0x201819a2,0x7f856fd9,0x28a42c06}},	//   انلا, _qiri_, علان, _औपनि, 
   {{0x20196fda,0x00000000,0x00000000,0x00000000}},	//   _viri_, --, --, --, 
   {{0x20196fdb,0xadc0001e,0xccf8033f,0xaca00051}},	//   _wiri_, _viến, _byś_, _ngồn, 
   {{0x20196fdc,0x9f840124,0x434c0023,0x00000000}},	//   _tiri_, _иҳад, _ንምቕባ, --, 
   {{0xf09c431d,0xadc001dc,0x200ce0fd,0x201816b8}},	//   _ngày_, _tiến, _òdi_, _uiri_, 
   {{0xafe002dd,0x6e2800e4,0x00000000,0x00000000}},	//   _сорл, ĩmbý, --, --, 
   {{0x3f8802ce,0xdb1829ef,0xdb080139,0x6da0010a}},	//   _habu_, kivö, _ildü, _йиса, 
   {{0x3f896fdd,0x00000000,0x00000000,0x00000000}},	//   _kabu_, --, --, --, 
   {{0x3f8820ee,0xfaa4ff37,0x76a80213,0xd7f0007b}},	//   _jabu_, _пазо, bəyl, ؤكد_, 
   {{0x3f896fde,0xcca800db,0x76a806be,0x00000000}},	//   _mabu_, _ىچۇۇ_, cəyl, --, 
   {{0x3f896fdf,0xdb180122,0xdec40240,0x00000000}},	//   _labu_, chvá, ጻርና_, --, 
   {{0x7af80b34,0xb1780158,0xdb18014a,0xe8500472}},	//   _hytt, _bjån, givö, _منند, 
   {{0xf1bc2200,0x7af80e03,0x00000000,0x00000000}},	//   _slá_, _kytt, --, --, 
   {{0x7af8005c,0xf1bc00e4,0xd1b00214,0x601406be}},	//   _jytt, _plá_, لیدک, cümə, 
   {{0x21656fe0,0x717000db,0x00000000,0x00000000}},	//   лтуг, دۇحا, --, --, 
   {{0x3f883142,0x7af84c2e,0xdb0804cc,0xfd480142}},	// [261b0] _babu_, _lytt, _aldü, _fflẅ, 
   {{0x3f880548,0xdb180037,0xce9402e8,0x6ee415bf}},	//   _cabu_, livõ, казъ, ىسال, 
   {{0x7af80c58,0x8e9800c6,0x3f896fe1,0xede000c7}},	//   _nytt, بناء_, _dabu_, гәаҟ, 
   {{0x3eac01e6,0xdb180037,0x00000000,0x00000000}},	//   äfta_, nivõ, --, --, 
   {{0x61e800d2,0x7af8d7de,0xdb0801d3,0xa194004e}},	//   édle, _aytt, _oldó, _саяч, 
   {{0x7af800ed,0x3f888db1,0x06d40154,0xfbcc00ec}},	//   _bytt, _gabu_, _সুফি, يڪل_, 
   {{0x37d400eb,0x00000000,0x00000000,0x00000000}},	//   সকার, --, --, --, 
   {{0x7af80eef,0xccf8033f,0xb9900116,0x00000000}},	//   _dytt, _tyś_, للىب, --, 
   {{0x8be800f7,0xdb18000d,0x3f896fe2,0x07a507fa}},	//   _قىرق_, divõ, _yabu_, вапн, 
   {{0x847c02d3,0x7af803cd,0xeb90007b,0x2ac40114}},	//   _ዕላማን_, _fytt, _حظر_, _пљев, 
   {{0xe8e83253,0x7af8007c,0x00000000,0x00000000}},	//   _کراو_, _gytt, --, --, 
   {{0xdb080109,0x2b456fe3,0xdb180037,0x00000000}},	//   _modì, lanc_, givõ, --, 
   {{0x765c0fac,0x20d00210,0x00000000,0x00000000}},	//   _åpyn, _सेंध, --, --, 
   {{0x69e02f61,0x2b456fe4,0x07a40f5c,0x00000000}},	//   šteđ, nanc_, _јакн, --, 
   {{0x3f896fe5,0xfbd00375,0xadc00208,0x00000000}},	//   _rabu_, בתם_, _nhắn, --, 
   {{0x3f88aff4,0x2b44003a,0x04b4014b,0x00000000}},	//   _sabu_, hanc_, _асоя, --, 
   {{0x3f88030a,0xdd941ac1,0x31216fe6,0x00000000}},	// [261c0] _pabu_, ғалы, рдуг, --, 
   {{0x44316fe7,0x3f880a4d,0x2b440010,0x00000000}},	//   _ity_, _qabu_, janc_, --, 
   {{0x420801c0,0x3f880037,0xadc00051,0x2bd8000d}},	//   _оноо_, _vabu_, _chắn, _बदजा, 
   {{0x7af85629,0x443005da,0xf2d00375,0x3f8804ba}},	//   _rytt, _kty_, _כעת_, _wabu_, 
   {{0x3f896fe8,0xdc7431af,0x7af96fe9,0x443001e1}},	//   _tabu_, углы, _sytt, _jty_, 
   {{0x7af96fea,0xeb9505bc,0xafd806ea,0x00000000}},	//   _pytt, кич_, _svøv, --, 
   {{0x44300109,0xef14020a,0xf41c0108,0xeb9400f0}},	//   _lty_, _амр_, lvät_, тиј_, 
   {{0xa964026a,0x7c24020c,0x4430010e,0x39401427}},	//   вића_, _ékro, _oty_, úks_, 
   {{0xbc684111,0x443007a8,0x3a3c0618,0x57f56feb}},	//   _زمان_, _nty_, _wwtp_, лпит, 
   {{0x7af8049b,0xdb096fec,0xac040022,0xe9fc0208}},	//   _tytt, _hodí, _ануа_, _phảj_, 
   {{0x44316fed,0x9f58007b,0xd6d407e6,0xdb180037}},	//   _aty_, _bhrú_, ужны, tivõ, 
   {{0x29c00428,0xd1d40125,0x569401e0,0x2cc40205}},	//   _eñab_, ረበት_, _ҡалт, _övdü_, 
   {{0x4430001e,0xdb1800af,0xb1780158,0xc4300330}},	//   _cty_, rivõ, _sjåo, یکیت, 
   {{0x44300731,0xdb1800c5,0x779003e6,0xdb085b7b}},	//   _dty_, sivõ, _ئیدا, _lodí, 
   {{0x44300170,0xa6c442b5,0xdb18000d,0xb188009d}},	//   _ety_, _لوول_, pivõ, мсаж_, 
   {{0x11d80491,0x2b440213,0xe5a400f3,0xf204003b}},	//   روءة_, zanc_, _вићи, тяго, 
   {{0xcdc40e26,0x3dc40014,0xf4840111,0x644000d8}},	// [261d0] ۇۇسۇ_, dhow_, _руйн, âmit, 
   {{0x765800ad,0x717000db,0xa854011a,0x00000000}},	//   orty, دۇڭا, כימה_, --, 
   {{0xdb080306,0x00000000,0x00000000,0x00000000}},	//   _bodí, --, --, --, 
   {{0x765800cc,0x443000c7,0x2b456fee,0xc6d8008f}},	//   irty, _yty_, wanc_, ײַער, 
   {{0x6ad8085c,0xca90001f,0x00000000,0x00000000}},	//   यप्र, ኛውንም_, --, --, 
   {{0xadc00016,0xbb416fef,0xdd982cc8,0x20240131}},	//   _thắn, бешк, ешә_, _ئېلې, 
   {{0xda6427e9,0xdfd40724,0xca7401c0,0x00000000}},	//   لايي, _торы, уулы, --, 
   {{0x3dc56ff0,0xdb080789,0x2b440427,0x08880395}},	//   chow_, _godí, sanc_, ебий_, 
   {{0x7658017a,0xcc9000b8,0x2b440010,0x00000000}},	//   erty, _kṛmi_, panc_, --, 
   {{0x9f5801ab,0xb9047d2c,0xdb080798,0x44316ff1}},	//   _bhrù_, ыныз_, _zodí, _rty_, 
   {{0xb8f80c5a,0x44316ff2,0xafd80162,0xaa6400f3}},	//   _डे_, _sty_, _hvøs, _штак, 
   {{0xf41c049b,0x44316ff3,0x00000000,0x00000000}},	//   yvät_, _pty_, --, --, 
   {{0x44305e6e,0x76580363,0xadc00051,0x15b000cf}},	//   _qty_, arty, _nhận, تەيس, 
   {{0xe944004b,0x46b4027d,0x97c400db,0xc08c0023}},	//   _سرچی, _محبس, _ۅتۉم, _ቅርጻን_, 
   {{0xb1780158,0x3dc56ff4,0x656008c2,0xf770011a}},	//   _tjål, yhow_, òmhs, _הקו_, 
   {{0x056535ea,0x44316ff5,0xc4856ff6,0xb17803cd}},	//   _свин, _tty_, _блик, _ujål, 
   {{0x44316ff7,0xdb096ff8,0x068800d1,0x00000000}},	// [261e0] _uty_, _rodí, _ﺑﯧﻜﯩ, --, 
   {{0x3518025f,0x2d9c005a,0x201d6ff9,0xdb080306}},	//   _אופנ, _anue_, övi_, _sodí, 
   {{0xdb096ffa,0x25a0e3ba,0x4cdc015b,0xdd9401e0}},	//   _podí, _knil_, _বরগু, ғаһы, 
   {{0x2d9c0327,0x224c02fb,0x6da00aac,0xdca41206}},	//   _cnue_, ádku_, йиха, һаҗи, 
   {{0x61e56ffb,0xdb0813d5,0x74100133,0xc0bc0092}},	//   mnil, _vodí, _خویا, ሰቡም_, 
   {{0x3dc56ffc,0xec113508,0x61e4389c,0x5a34035b}},	//   show_, موند, lnil, анкт, 
   {{0x61e56ffd,0x75ec026c,0x00000000,0x00000000}},	//   onil, rùzz, --, --, 
   {{0x61e56ffe,0x6b600588,0xaca00208,0x2ca400d1}},	//   nnil, акәа, _ngỗn, ткәп_, 
   {{0x61e56fff,0x76a803be,0xadc0004d,0x977400d1}},	//   inil, məyi, _giằn, ңтүә, 
   {{0xafd81125,0x25a0de14,0x76a803be,0x61e57000}},	//   _hvør, _anil_, ləyi, hnil, 
   {{0x61e57001,0xec100517,0xafd80174,0x7658062c}},	//   knil, _اولد, _kvør, urty, 
   {{0xb11001f2,0x25a007ea,0x61e40122,0x76a803b9}},	//   _bụla, _cnil_, jnil, nəyi, 
   {{0xdb080798,0x068800d1,0x00000000,0x00000000}},	//   _fodã, _ﺑﯧﻘﯩ, --, --, 
   {{0xdb0803a2,0x56941b74,0xd23402e8,0x61e57002}},	//   _godã, _вакт, ингъ, enil, 
   {{0xe61064ec,0x61e40008,0x667000f1,0x32080408}},	//   تشی_, fnil, _هدير, ехан_, 
   {{0x61e57003,0x25a00010,0x98a40153,0x00000000}},	//   gnil, _gnil_, namį_, --, 
   {{0x39441730,0x4fd50e93,0x76a803e3,0x00000000}},	// [261f0] _meos_, ажат, dəyi, --, 
   {{0x61e57004,0x39457005,0xf3640311,0x643401f7}},	//   anil, _leos_, _стин, _اريء, 
   {{0x3eb97006,0x61e4022f,0xadc0004d,0xaf057007}},	//   gypt_, bnil, _nhản, учак, 
   {{0x39457008,0xe808130b,0xdef801e0,0x76a806be}},	//   _neos_, _सीना_, уыу_, gəyi, 
   {{0xcb682850,0xafd806ea,0x00000000,0x00000000}},	//   вале_, _dvør, --, --, 
   {{0xce94013d,0x3e6c0118,0x5d640022,0xdd8401ec}},	//   _кагъ, být_, атәз, _қысп, 
   {{0xadc0004d,0xda58005b,0x76a803e3,0x00000000}},	//   _chản, грыш_, bəyi, --, 
   {{0x39457009,0x2d9c00c8,0x76a803be,0xafd80162}},	//   _ceos_, _unue_, cəyi, _tvøs, 
   {{0x3945700a,0x6e24f362,0x47c528f8,0x00000000}},	//   _deos_, _hujb, ибив, --, 
   {{0x6d48511c,0x61e5700b,0x25a001ef,0x5c040153}},	//   laga, znil, _snil_, _ляха, 
   {{0x61e4be01,0xa8a40046,0x39451dc7,0x6d49700c}},	//   ynil, _әрек, _feos_, oaga, 
   {{0x6e24014f,0xdce0025c,0x2604002e,0x885800f3}},	//   _mujb, _qamħ, rñoo_, _аидс_, 
   {{0x61e5700d,0xdb0800c6,0x69d803a0,0x6e24014f}},	//   vnil, _iodá, miue, _lujb, 
   {{0x6b81700e,0x6d49700f,0x69d97010,0x39440010}},	//   neng, haga, liue, _zeos_, 
   {{0x6d497011,0x672017a3,0x6e240455,0x61e57012}},	//   kaga, _ignj, _nujb, tnil, 
   {{0x6b817013,0x61e57014,0x39440077,0x69d80093}},	//   heng, unil, _xeos_, niue, 
   {{0x6d497015,0x6b817016,0x4374074d,0x00000000}},	// [26200] daga, keng, _кунт, --, 
   {{0xe8080307,0x6b817017,0x6e240007,0xafd8022c}},	//   _सीमा_, jeng, _bujb, _svør, 
   {{0x6b817018,0x76a80cc1,0x61e40dfe,0x1c0003ce}},	//   deng, təyi, pnil, _लीगल_, 
   {{0x6d497019,0x644415fa,0x7c64710e,0x61e40113}},	//   gaga, _kwii, لاتل, qnil, 
   {{0x672015ad,0x6b81701a,0x394552b0,0x69d802d3}},	//   _ognj, feng, _reos_, diue, 
   {{0x6b81701b,0x6d48013c,0x3945701c,0xac04bc40}},	//   geng, aaga, _seos_, анча_, 
   {{0x6d49701d,0xafd80579,0x6e240b45,0xdb0802f0}},	//   baga, _tvør, _gujb, _bodá, 
   {{0x6d48074d,0xdb0801e7,0x932c0092,0x00000000}},	//   caga, _codá, ዳንዶቹ, --, 
   {{0xdb08278a,0x2d940122,0x6444013f,0x00000000}},	//   _dodá, ádež_, _nwii, --, 
   {{0x6b81701e,0xf8040e92,0xa7702d29,0xadc0004d}},	//   ceng, јчин, ольч, _thản, 
   {{0x394425e4,0x6444ea49,0x2b2804fb,0xdb0800d8}},	//   _teos_, _awii, _شغلی_, _fodá, 
   {{0xaad80375,0x3544010b,0x69d9701f,0x00000000}},	//   _בחבר, шхов, ciue, --, 
   {{0xdddc1494,0x29d00592,0x37e40117,0x00000000}},	//   _aprū, _بينس, _кодг, --, 
   {{0x6d497020,0x28e4008e,0xe73400f0,0xeda01546}},	//   zaga, _әдәп_, _кељ_, _ऐच्छ, 
   {{0x6d497021,0xf6080116,0x7d0403cd,0xdb0801d3}},	//   yaga, _ихий_, _øksf, _eldö, 
   {{0x6d497022,0x672016a3,0x00000000,0x00000000}},	//   xaga, _zgnj, --, --, 
   {{0x6d497023,0x6b817024,0xb11002e3,0x29c000e4}},	// [26210] vaga, yeng, _tụma, _oñan_, 
   {{0x6d497025,0x6b817026,0x6e240477,0x726401af}},	//   waga, xeng, _pujb, _књме, 
   {{0x64440084,0x6e24014f,0x00000000,0x00000000}},	//   _zwii, _qujb, --, --, 
   {{0x29c00086,0xb110063f,0x69d8004e,0x6a1400b8}},	//   _añan_, _jụka, xiue, _kṛśā_, 
   {{0x6b817027,0x6d497028,0xec697029,0xdb0802fb}},	//   teng, raga, трек_, _rodá, 
   {{0xbb413c1b,0x6b81404f,0x00000000,0x00000000}},	//   пешк, ueng, --, --, 
   {{0xdb080232,0x6b814ce2,0xed88c1ef,0x69d81c69}},	//   _podá, reng, _исак_, tiue, 
   {{0x6b81702a,0x6d49702b,0x62980064,0x00000000}},	//   seng, qaga, _švok, --, 
   {{0xdb080122,0x69d9702c,0x00000000,0x00000000}},	//   _vodá, riue, --, --, 
   {{0x6db16c79,0x7bc80e78,0x69d9702d,0x6b81702e}},	//   _уйғу, chfu, siue, qeng, 
   {{0xb11002e3,0x6445702f,0x00000000,0x00000000}},	//   _bụka, _swii, --, --, 
   {{0x29c00309,0x1ac800db,0x9a840108,0x00000000}},	//   _iñao_, _тууп_, _фуфл, --, 
   {{0x59f80276,0xdddc00e2,0x82a40588,0x00000000}},	//   _теця_, _sprū, әабж, --, 
   {{0x672005a1,0xb7780882,0x6a1400b8,0x78a4143a}},	//   _ugnj, ruṣā, _dṛśā_, åkve, 
   {{0x6444009a,0x6010013d,0x00000000,0x00000000}},	//   _wwii, lämg, --, --, 
   {{0xb11001f2,0xe808ae7a,0x644525c5,0xa06800fb}},	//   _gụka, _सीता_, _twii, һаға_, 
   {{0x64457030,0xf99027af,0x00000000,0x00000000}},	// [26220] _uwii, הרן_, --, --, 
   {{0xa068c5dc,0x438400c6,0x260000bc,0x00000000}},	//   лаға_, _الدق, रतकी_, --, 
   {{0x7bc80175,0x00000000,0x00000000,0x00000000}},	//   vhfu, --, --, --, 
   {{0xdb18022c,0x3ea40166,0x00000000,0x00000000}},	//   mhvø, _һигг, --, --, 
   {{0x7bc97031,0x6e3801a6,0x29d00356,0xdb180162}},	//   thfu, _čube, nţau_, lhvø, 
   {{0x6c800131,0x00000000,0x00000000,0x00000000}},	//   سلىم, --, --, --, 
   {{0xe80939fe,0xdb1806ea,0x5bb800cd,0x00000000}},	//   _सीधा_, nhvø, _अवीव, --, 
   {{0x7bc97032,0x24802b92,0xadc001fb,0x00000000}},	//   shfu, _opim_, _thạn, --, 
   {{0x3d94008e,0x00000000,0x00000000,0x00000000}},	//   _киңр, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x24817033,0x34b12a27,0x7bd80024,0xe8dc004d}},	//   _apim_, ुन्द, _imtu, _buồm_, 
   {{0x4cd4004b,0xdb1803b2,0x46a8000d,0x601000fd}},	//   _اغېز, dhvø, _छपरह, lämd, 
   {{0x6560007b,0xb1900075,0x69f8011a,0x00000000}},	//   ómha, үлгә, _גלאק, --, 
   {{0x888007d6,0x601033fe,0x00000000,0x00000000}},	//   _کیین, nämd, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb3e80491,0x7bd97034,0x00000000,0x00000000}},	// [26230] _معدل_, _omtu, --, --, 
   {{0x2fc40016,0xedd40bd6,0x29d00356,0x00000000}},	//   óng_, әлдә_, lţat_, --, 
   {{0xf3fc0798,0x9f0400be,0x1ad80037,0x00000000}},	//   stãs_, كوكو, _भेलथ, --, 
   {{0x7bd97035,0x29d0084c,0xcc980abe,0x00000000}},	//   _amtu, nţat_, ивец_, --, 
   {{0x7bc40024,0x8b24023a,0x9f580332,0xc0bc001f}},	//   _įkur, одле, _chró_, _ደርሶ_, 
   {{0x95280003,0x9514002b,0x1af400cc,0x46a8000d}},	//   _རུའི_, _aṅka, েইনে_, _छपलह, 
   {{0xfe6d7036,0xc9a97037,0x9e7c010a,0x37cc0154}},	//   _لگن_, ивке_, _йытă_, িচার, 
   {{0x7bd8014b,0x08c4be12,0x0c880020,0x3b50010b}},	//   _emtu, жбин, _በግልጽ_, пкәр, 
   {{0x601000a2,0xbb3c00d1,0x00000000,0x00000000}},	//   bämd, ﯞﻩﻥ_, --, --, 
   {{0xeb981a57,0x290000da,0x29c00022,0x0638001f}},	//   _حضرت_, āja_, _iñam_, _የሰውነ, 
   {{0x85e80364,0x24800427,0x9f640129,0x00000000}},	//   идов_, _spim_, ûtée_, --, 
   {{0x62980998,0x24800ac5,0x26c8033f,0x5b14009d}},	//   _ávoi, _ppim_, ąco_, _эмхт, 
   {{0xb8fc00bd,0xa904f0a5,0x60100724,0x26c009a8}},	//   _দু_, _ابان, läme, šjo_, 
   {{0x7d040ac8,0xaca00521,0x21e401ec,0xf5540092}},	//   _økse, _ntọa, _ﺍﻓﺘﺭ, _ፈንጂዎ, 
   {{0xe1f80c60,0x57240035,0x41b44a1a,0x00000000}},	//   йҳо_, _عروق, осат, --, 
   {{0x29c000a2,0xdb180174,0x020428f6,0x7afc000d}},	//   _oñam_, rhvø, ізан, üpti, 
   {{0xb4d8004e,0x60100112,0xc8c83d1d,0x00000000}},	// [26240] rbàc, häme, िनिट, --, 
   {{0x8234092f,0x6010002f,0xc564009f,0x00000000}},	//   _ورجا, käme, _اُکي, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc8c806ab,0x9f5800a3,0x601002f6,0xb17803cd}},	//   िनाट, _chrò_, däme, _sjåv, 
   {{0xf1b002e4,0x6ab403ce,0x601001e3,0x00000000}},	//   _חסר_, _अथॉर, tämd, --, 
   {{0x7498010f,0x92ac00fe,0x3fc40133,0x00000000}},	//   יינפ, কনৰ_, _بگری_, --, 
   {{0xc0e40020,0x29c00086,0x3ebc0a37,0x195810de}},	//   ኛውም_, _eñam_, _ætt_, байы_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbf080490,0x38c801c4,0x00000000,0x00000000}},	//   _वरुन_, руйн_, --, --, 
   {{0x7bd97038,0x65600332,0x00000000,0x00000000}},	//   _umtu, ómhn, --, --, 
   {{0x96f8010a,0xeb9401af,0x00000000,0x00000000}},	//   сент_, _фих_, --, --, 
   {{0x6aa400db,0x57e82002,0xa9440137,0x5eec00eb}},	//   _بشكە, рдүм_, _ۇعۇۇ, _করাও_, 
   {{0x29d00311,0x092800ae,0xec74010a,0x00000000}},	//   rţat_, _اسمي_, _юпă_, --, 
   {{0xbf080490,0xadc00051,0x00000000,0x00000000}},	//   _वरून_, _thần, --, --, 
   {{0x623473ad,0x1dbc00cd,0xa29400d4,0x00000000}},	//   десу, ्घात, марі, --, 
   {{0xf48401d5,0x645800b8,0x00000000,0x00000000}},	//   _дуон, _āviv, --, --, 
   {{0x999c0064,0x00000000,0x00000000,0x00000000}},	// [26250] lsvų_, --, --, --, 
   {{0xdb1800fc,0xaf040e92,0x29d00356,0x00000000}},	//   mkvæ, очек, nţar_, --, 
   {{0xeea97039,0xb14c0023,0x00000000,0x00000000}},	//   штак_, _ንጎይታ, --, --, 
   {{0xb50c05f9,0x601001f4,0x00000000,0x00000000}},	//   _सराय_, väme, --, --, 
   {{0x8c45703a,0x1c440845,0xc8d800e1,0x1cd82401}},	//   челе, днім, _बेंट, одцы_, 
   {{0x00b80375,0x92ac00cc,0xa29801d3,0x6011703b}},	//   _המשמ, কনী_, _ائیر_, täme, 
   {{0xc7240323,0xf1bd703c,0x00000000,0x00000000}},	//   үдий, _giác_, --, --, 
   {{0x60103b22,0x5d6400cf,0x00000000,0x00000000}},	//   räme, _отуз, --, --, 
   {{0x6d586fb2,0xe9a00220,0x629800e4,0xa9a001d5}},	//   _idua, зақп, _ávov, зиқд, 
   {{0xdb1801bf,0x61b800cd,0x5eec03d4,0x00000000}},	//   dkvæ, _इक्ष, _কৰিও_, --, 
   {{0x38c804fb,0x00000000,0x00000000,0x00000000}},	//   لایی_, --, --, --, 
   {{0xb1780158,0xf9b401f0,0x3d10000d,0x00000000}},	//   _mjås, _нахӯ, _तरमे_, --, 
   {{0x6d5801f7,0x69c9703d,0xdb1801a8,0xf3fc00d8}},	//   _mdua, _ilge, gkvæ, guão_, 
   {{0x290c01d5,0xf8b40375,0xe78401af,0x996401ee}},	//   _izga_, _מפני_, _фудо, _етәл, 
   {{0xf09c01e1,0xb17805ac,0x00000000,0x00000000}},	//   _arà_, _njås, --, --, 
   {{0x5bb806ab,0xf09c00a3,0x9f840724,0xb4d805da}},	//   _अव्व, _brà_, _köç_, mbàn, 
   {{0xb8840d12,0x30240124,0x85b84e5d,0xd17400c7}},	// [26260] msíð, зоуп_, _ناکس_, ьыры, 
   {{0x6d59703e,0xf09c03d1,0x5ec400d1,0x9f8400a2}},	//   _adua, _drà_, мизғ, _möç_, 
   {{0x69c8398e,0xbd840026,0xcee80b24,0x00000000}},	//   _olge, згек, يرمن_, --, 
   {{0xf09c2b1d,0x290c01d5,0x629c257c,0xb8840162}},	//   _frà_, _ozga_, mvro, nsíð, 
   {{0xed4cb184,0x629d703f,0xf09c05d5,0xb178713c}},	//   اپه_, lvro, _grà_, _småg, 
   {{0x69c8d503,0xa3cc00af,0x601000e4,0x00000000}},	//   _alge, लसि_, sämb, --, 
   {{0x629d7040,0x8c3c00a2,0x69c80139,0x3a38e612}},	//   nvro, _arşd, _blge, ëpp_, 
   {{0x5838084c,0x629c304b,0x290c002f,0x00000000}},	//   озия_, ivro, _bzga_, --, 
   {{0xa3cc01ad,0xdcf800e5,0x81ac00eb,0x00000000}},	//   लसा_, _بہشت_, _কতা_, --, 
   {{0x69c97041,0xdb08007b,0x16340107,0x3dc415c0}},	//   _elge, _modú, меоя, lkow_, 
   {{0xb8840008,0x23b09ad9,0x76a801f4,0x00000000}},	//   fsíð, ञानद, ётов_, --, 
   {{0xdb1801a8,0xcb8000c7,0x69c80332,0xb88403f2}},	//   tkvæ, _зқәп, _glge, gsíð, 
   {{0x629c597e,0x9f843712,0x00000000,0x00000000}},	//   evro, _göç_, --, --, 
   {{0xb1780fac,0xdb1898b1,0xe8f430ab,0x999c0064}},	//   _njår, rkvæ, _элч_, psvų_, 
   {{0x3a24007f,0x629c017a,0xa7780375,0xdb18366f}},	//   _kiop_, gvro, _הרופ, skvæ, 
   {{0xf09d7042,0xe8dc0208,0xdb18007c,0x41840150}},	//   _prà_, _cuỗm_, mkvä, мтуғ, 
   {{0x92ac04c5,0xdc740092,0xfbbc7239,0xdb1801e3}},	// [26270] কনে_, _የግሪክ_, ्साम, lkvä, 
   {{0xeea800cf,0x2d8001e4,0xb3e801f7,0x6d580200}},	//   йтек_, _ŝje_, _دعبل_, _sdua, 
   {{0x51f821db,0xdb180267,0xeae40154,0xdee00092}},	//   _мною_, nkvä, _ফর্ম, _ጓደኛ_, 
   {{0xf09d7043,0x00000000,0x00000000,0x00000000}},	//   _trà_, --, --, --, 
   {{0x53d000af,0xf09c004e,0xe3b050f0,0x2c240108}},	//   _हताश, _urà_, _شری_, чьег, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf8ac1c93,0xdb197044,0x3dc4467c,0x00000000}},	//   یکه_, jkvä, bkow_, --, 
   {{0x5b2407dd,0xbb2c0131,0xdd957045,0x88c80798}},	//   хьча, ﯩﻘﻰ_, _пасы, жлив_, 
   {{0x3a257046,0x6010005b,0xb8840162,0x00000000}},	//   _diop_, läma, vsíð, --, 
   {{0x629c01f5,0x7d0403b2,0x46e801b9,0x00000000}},	//   yvro, _øksa, ждон_, --, 
   {{0xdb1801e3,0xdd1c0f91,0xb3880023,0x4af800f2}},	//   gkvä, mášo, ቅኑዕን_, _بکشد_, 
   {{0xdd1c0306,0x629c0165,0xa2cc00cd,0x00000000}},	//   lášo, vvro, सनस्, --, 
   {{0xb8841bb0,0x290c1eca,0x8c3c00a2,0x601026bb}},	//   rsíð, _uzga_, _urşd, häma, 
   {{0xdd1c0030,0x629c0af9,0x601001f4,0x00000000}},	//   nášo, tvro, käma, --, 
   {{0xdb1801e6,0xdb0801e1,0xc87806be,0x00880150}},	//   ckvä, _sodú, ltş_, _ﻗﻴﺘﯘ, 
   {{0xb684066d,0x629d7047,0x6010014a,0x51840114}},	//   _کھیل_, rvro, däma, нуђа, 
   {{0x660400b4,0x629d1fe3,0xdd1c02f0,0x4414014b}},	// [26280] _ikik, svro, kášo, _офот, 
   {{0x629c01f5,0x00000000,0x00000000,0x00000000}},	//   pvro, --, --, --, 
   {{0x660404ba,0x412822d7,0xb178143a,0x823400ec}},	//   _kkik, _моно_, _småe, _ترخا, 
   {{0x7f4d7048,0xf09c01e1,0xdb240022,0x7c840116}},	//   _webq, _iyàn_, _ãsév, дуке, 
   {{0x61e57049,0x3dc4f863,0x660401f7,0xac64001f}},	//   miil, rkow_, _mkik, _ደግሞም_, 
   {{0x3dc421bd,0x3a2400a9,0x60c40223,0xec11704a}},	//   skow_, _siop_, myim, نوند, 
   {{0x60c4009a,0x6605704b,0x601001b8,0x19581411}},	//   lyim, _okik, cäma, пайы_, 
   {{0xa9c010f5,0x61e5704c,0x6605704d,0x26040005}},	//   вськ, niil, _nkik, iños_, 
   {{0x19c400fd,0xa9640120,0xb7880063,0xdd1c0419}},	//   _җәйг, фиња_, ољне_, bášo, 
   {{0x6605704e,0x61e5704f,0x60c40295,0x00000000}},	//   _akik, hiil, iyim, --, 
   {{0x61e42fa9,0x69d401f5,0x00000000,0x00000000}},	//   kiil, ëxec, --, --, 
   {{0x61e40a55,0xdb1801e6,0xaee000cd,0xfbbc1223}},	//   jiil, rkvä, _apṛc, ्सवम, 
   {{0x61e57050,0x29c00309,0xf09c01e1,0x26040789}},	//   diil, _añaw_, _ayàn_, eños_, 
   {{0x6605620f,0x78a0c73e,0xdb08003b,0x785401d3}},	//   _ekik, _irov, _bodø, _ٹیگز_, 
   {{0x61e57051,0x660403a0,0x60c41418,0x78a00427}},	//   fiil, _fkik, eyim, _hrov, 
   {{0x61e57052,0x6604020b,0x216400f7,0xdb080200}},	//   giil, _gkik, ктуг, _andë, 
   {{0x9f582242,0x79817053,0x26040077,0x04840166}},	// [26290] _skrá_, _mbow, años_, _пәри_, 
   {{0xb4c84d53,0xf1bc01fb,0x601001b8,0x6ee41291}},	//   लनी_, _gián_, täma, وسال, 
   {{0x61e56f48,0x7980068f,0xdb0800cc,0x60c40337}},	//   biil, _obow, _godø, ayim, 
   {{0xafd97054,0x61e400a8,0x78a17055,0xdb097056}},	//   _stød, ciil, _orov, _indè, 
   {{0x60c40223,0x60112d5f,0x60180521,0xd010007b}},	//   cyim, säma, ụmar, _ملح_, 
   {{0x60117057,0x7980299d,0xf1bc0077,0xdbcc0332}},	//   lämn, _abow, _xián_, _fóíl, 
   {{0x79801418,0x78a17058,0xaca00241,0x60100784}},	//   _bbow, _arov, _iyọn, qäma, 
   {{0x78a17059,0x6010049f,0x48b41422,0x00000000}},	//   _brov, nämn, ещот, --, 
   {{0x78a000ad,0x5c7401af,0x8bd801a9,0x00000000}},	//   _crov, _илтт, _емас_, --, 
   {{0x66044098,0x61e40276,0x79800241,0x60100267}},	//   _skik, ziil, _ebow, hämn, 
   {{0x78a1705a,0x61e40e14,0x60101f65,0x79e800e5}},	//   _erov, yiil, kämn, _کونہ_, 
   {{0x78a005c7,0xf1bc068c,0x79800ca8,0x60c40de2}},	//   _frov, _sián_, _gbow, yyim, 
   {{0xdb080100,0x78a02e49,0xe8e802f2,0x85180456}},	//   _andè, _grov, _براو_, नेंट_, 
   {{0x60c5705b,0xdb180267,0x61e40009,0x00000000}},	//   vyim, skvå, wiil, --, 
   {{0x61e5705c,0x78a0012c,0x660400b5,0x969402d5}},	//   tiil, _zrov, _tkik, _арыш, 
   {{0xaca00241,0x6605705d,0x60c44be4,0x614001ef}},	//   _ayọn, _ukik, tyim, kálů, 
   {{0x61e5705e,0xdb09030c,0x01080814,0xb9f80023}},	// [262a0] riil, _endè, سترو_, _ህዝ_, 
   {{0x61e5705f,0x60c57060,0x57cc010f,0x00000000}},	//   siil, ryim, ֿמאַ, --, 
   {{0xf1bc07ae,0x61e400a8,0x44317061,0x60100139}},	//   _giáo_, piil, _huy_, bämn, 
   {{0xdd9000db,0x44301574,0xc61004c5,0x60c400e4}},	//   شوت_, _kuy_, _সূতা_, pyim, 
   {{0xdb097062,0x44317063,0xd0940124,0x00000000}},	//   _indé, _juy_, _ишры, --, 
   {{0x44317064,0x78a00327,0x00000000,0x00000000}},	//   _muy_, _rrov, --, --, 
   {{0x78a17065,0x44301574,0x6010e73c,0x00000000}},	//   _srov, _luy_, lämo, --, 
   {{0x44300477,0x224c0216,0x1af40154,0x00000000}},	//   _ouy_, ádky_, েইলে_, --, 
   {{0x44317066,0x3b850684,0x00000000,0x00000000}},	//   _nuy_, _плаг, --, --, 
   {{0xbb2c1c5c,0xc76c0023,0x00000000,0x00000000}},	//   ﻨﺪﻯ_, _በበይኑ_, --, --, 
   {{0x398000d6,0xdb080036,0x8c3d59af,0xbbbc7c33}},	//   pаs_, _ondé, _irşa, ्सीक, 
   {{0x44317067,0xdce003be,0xb4b000d1,0xa2c4095f}},	//   _buy_, _hamı, гимә, रहन्, 
   {{0xb4c8006d,0x4430020b,0xdce00baa,0x601001e6}},	//   लने_, _cuy_, _kamı, vämn, 
   {{0x44317068,0xdb08003e,0xe9e400d7,0x00000000}},	//   _duy_, _andé, šúty_, --, 
   {{0x44303386,0xca2c0046,0x569489b6,0x60100267}},	//   _euy_, ﯩﻨﺎ_, _райт, tämn, 
   {{0x201800ca,0x4430002e,0xbbbc08a3,0x00000000}},	//   _ahri_, _fuy_, ्सुक, --, 
   {{0x76580953,0x44300375,0xb59000c7,0x7bc82147}},	// [262b0] lsty, _guy_, _аиқш, kkfu, 
   {{0xc3c00184,0x20197069,0xafd9706a,0x60100267}},	//   _көсл, _chri_, _støb, sämn, 
   {{0xc0f81ee0,0x7ce4022e,0xdfd800a7,0xabc001e0}},	//   _ፊደል_, _lаrd, хът_, ғайҙ, 
   {{0x7659706b,0x8c3d706c,0x44301574,0xe0d001d3}},	//   isty, _arşa, _yuy_, جزہ_, 
   {{0x44306313,0x0cbc012c,0x7d040feb,0x00000000}},	//   _xuy_, ्नेम, _øksl, --, 
   {{0xf1bc0016,0x76586dd3,0xf3fc0120,0x201842f7}},	//   _hoá_, ksty, irão_, _ghri_, 
   {{0x76580030,0xdce01b0d,0x29c0010e,0x2bd407b6}},	//   jsty, _damı, _oñat_, भोगा, 
   {{0x76580726,0xe6280208,0x8c3c2093,0x00000000}},	//   dsty, _chỗ_, _erşa, --, 
   {{0x2d8c6a66,0x20040014,0x765825a5,0xdddc0419}},	//   mege_, _شِہِ, esty, _uprš, 
   {{0x2d8d706d,0xf3fc03b7,0x4431706e,0x7659706f}},	//   lege_, drão_, _ruy_, fsty, 
   {{0x44316585,0x4974d2e8,0x2c78045f,0x598401ec}},	//   _suy_, _алес, lêd_, _әліб, 
   {{0x44317070,0x2d8d7071,0xf3fc0798,0x3ebc1574}},	//   _puy_, nege_, frão_, _àtte_, 
   {{0x443007ae,0x76580363,0xf3fc0120,0x98640451}},	//   _quy_, asty, grão_, _مُنه, 
   {{0x2d8d7072,0x29c00428,0xf1bc0789,0x76597073}},	//   hege_, _eñat_, _diám_, bsty, 
   {{0x2d8d7074,0x44301bce,0xf3fc00d8,0x76580334}},	//   kege_, _wuy_, arão_, csty, 
   {{0x443007ae,0xd1740184,0x8fd40184,0x2d8c372e}},	//   _tuy_, лыуы, ңәрә, jege_, 
   {{0x2d8d7075,0xf1bc0016,0xc0040212,0xe57801ec}},	// [262c0] dege_, _giám_, впак, _жзқ_, 
   {{0xa3040598,0xbea4e9cb,0x6010248c,0x02c400db}},	//   _бүге, казк, rämo, _айоо, 
   {{0xbea802da,0x601001f4,0x00000000,0x00000000}},	//   بهان_, sämo, --, --, 
   {{0x2d8d7076,0xdb0809c2,0x60108843,0xc1d000fd}},	//   gege_, _undé, mämm, _төгә, 
   {{0xdf74034c,0x6010c6cb,0x7658009a,0x6c30007b}},	//   _مگاب, lämm, zsty, لفنا, 
   {{0x76597077,0x2018023a,0x7bc80334,0xdce08411}},	//   ysty, _uhri_, ukfu, _qamı, 
   {{0xafe0052f,0x2d8d7078,0xb50c5b29,0xdce00166}},	//   _торл, bege_, _सर्प_, _vamı, 
   {{0x76584bc1,0xf1bc01fb,0x2c78002d,0x98740063}},	//   vsty, _xoá_, bêd_, глиц, 
   {{0x29c00784,0x7658463d,0x60117079,0x7c640150}},	//   _añas_, wsty, hämm, _جازل, 
   {{0x76581061,0xdb080793,0x6011707a,0xf3fc0798}},	//   tsty, _kodü, kämm, vrão_, 
   {{0x7658652e,0x7e7c04cc,0xb86400f1,0x60100108}},	//   usty, ntpp, راکو, jämm, 
   {{0x79e82832,0xf3fc0120,0x6011707b,0xdb0805d1}},	//   _کوچہ_, trão_, dämm, _modü, 
   {{0x7ce4022e,0x66c801d3,0x00000000,0x00000000}},	//   _hаrb, tökö, --, --, 
   {{0xf3fc06ed,0xb4d8004e,0x32540023,0xf66800f2}},	//   rrão_, nbài, _ገብረኣ, _قحبه_, 
   {{0x60100724,0xf1bc0120,0x7e7c0175,0xdb0803e0}},	//   räml, _poá_, jtpp, _nodü, 
   {{0x2d8c0548,0x00000000,0x00000000,0x00000000}},	//   xege_, --, --, --, 
   {{0xd4c4052f,0x66c82776,0x2d8c143a,0x84c0013d}},	// [262d0] _сөнк, pökö, vege_, _ләрд, 
   {{0x91802928,0x2d8ca989,0xdb180240,0x7cc80171}},	//   _گۇرۇ, wege_, gjvë, _mērā, 
   {{0x2d8c4539,0x5f95707c,0xc33006a9,0xf1bc0270}},	//   tege_, рихт, _לוי_, _toá_, 
   {{0x2c780b21,0x91803baf,0xdb080034,0xcdc400cf}},	//   têd_, _دۇرۇ, _lodó, دۇرۇ_, 
   {{0x2d8d707d,0x9f582d75,0x630407d6,0x00000000}},	//   rege_, _skrå_, _مویل, --, 
   {{0x2d8d707e,0x2c780142,0x00000000,0x00000000}},	//   sege_, rêd_, --, --, 
   {{0x2d8d707f,0x09e435dd,0x2fcc002e,0x2a9403b9}},	//   pege_, локн, ëggu_, _kəbə_, 
   {{0xdb08026c,0xdde40075,0xfaa404fb,0x9f040345}},	//   _indì, _кәчү, اجوی, _ئوفو, 
   {{0x6ce402bf,0x7af8127b,0x8ba401af,0x00000000}},	//   _ріве, _extt, _бәйð_, --, 
   {{0xa6400020,0xdb080005,0x3c9001d9,0x4649176e}},	//   _የተወሰ, _codó, _دیٖز, нзон_, 
   {{0x60100724,0x64b40213,0x96940395,0x9bc401f4}},	//   xämm, _məiş, аряш, _тётк, 
   {{0x0444aec2,0xb17800bf,0x6010088f,0x7afc002d}},	//   лемн, _smån, vämm, ûpte, 
   {{0x6d4801ab,0xdd1c013a,0x00000000,0x00000000}},	//   ibga, fářo, --, --, 
   {{0xadc0001e,0x60117080,0xf74021fa,0xdb180162}},	//   _khẳn, tämm, _лешо, tkvø, 
   {{0x29c004cf,0x8c3c0356,0xd7600244,0x00000000}},	//   _uñas_, _orşo, _بۆپی, --, 
   {{0xdb18022c,0xc610015b,0x601001e6,0x8fc401d5}},	//   rkvø, _সূরা_, rämm, یزلن, 
   {{0xdb18022c,0xafd80158,0x65640009,0xf484036b}},	// [262e0] skvø, _støa, _idih, _یایی, 
   {{0x64457081,0xdb0802e2,0x78a40158,0x31040145}},	//   _itii, _modò, åkvi, унуп_, 
   {{0xdb0801e1,0xdb200205,0x3f1400d8,0x00000000}},	//   _lodò, ütün, уќат, --, 
   {{0xb2b8011a,0x00000000,0x00000000,0x00000000}},	//   _נמכר, --, --, --, 
   {{0xa3b803f8,0x212400a3,0xfb840166,0xf1b0011a}},	//   छाप_, _àmh_, гыйн, _הסר_, 
   {{0x3e345085,0x644401f7,0x8c3c0139,0x00000000}},	//   _مفسر, _mtii, _erşo, --, 
   {{0xadc00016,0x65657082,0xcb740f14,0x7ce401d5}},	//   _chẳn, _odih, ручњ, _bаrc, 
   {{0x65657083,0x64457084,0x7cc80374,0xc60c0073}},	//   _ndih, _otii, _pērā, सतोय_, 
   {{0xdb097085,0xbb4463e8,0x64440337,0xbc682e44}},	//   _indí, _безк, _ntii, _سمان_, 
   {{0x65657086,0x7af80334,0x7ce4022e,0xf4840116}},	//   _adih, _txtt, _tаrb, қумн, 
   {{0x64457087,0x65640327,0xfa680415,0xca7402d5}},	//   _atii, _bdih, _чаек_, _вучы, 
   {{0x8ac40022,0x481400cf,0x00000000,0x00000000}},	//   _ӡқәа_, лмөс, --, --, 
   {{0xd9440116,0x1ccc031c,0x6564015d,0xdb0800ae}},	//   _беҗи, ྲཱི_, _ddih, _todó, 
   {{0x644401ab,0x2a9403b9,0x00000000,0x00000000}},	//   _dtii, _səbə_, --, --, 
   {{0x6d480050,0xe2f80220,0xa6c40345,0x64457088}},	//   ybga, гері_, _موول_, _etii, 
   {{0x7a3c00c0,0x00000000,0x00000000,0x00000000}},	//   _ištę, --, --, --, 
   {{0x90981b74,0x00000000,0x00000000,0x00000000}},	// [262f0] ъват_, --, --, --, 
   {{0xdfd800a7,0xdb080118,0xa494009f,0x00000000}},	//   лъх_, _andí, _اُٿڻ, --, 
   {{0x931404fb,0x00000000,0x00000000,0x00000000}},	//   _خودش, --, --, --, 
   {{0x5f943500,0x6444011f,0x5f2403f6,0x00000000}},	//   _қист, _ytii, сфуз, --, 
   {{0xa3b80244,0x00000000,0x00000000,0x00000000}},	//   _شایر_, --, --, --, 
   {{0xdb0826b7,0xadc001fb,0x5ba802dd,0x8ac401c6}},	//   _endí, _phẳn, лкім_, ийлж, 
   {{0xdef80acf,0xdb0802e2,0xda6400f2,0x00000000}},	//   _быт_, _sodò, مايي, --, 
   {{0xc9a861ff,0x4df8008f,0x9aa801d5,0x9f8400a2}},	//   твие_, _ספּא, ادوف_, _möý_, 
   {{0x2d9c9280,0x6e400345,0x00000000,0x00000000}},	//   _iaue_, _ئۆڵم, --, --, 
   {{0x0684c48f,0x2d9d7089,0xadc00016,0xb17810d1}},	//   агон, _haue_, _thẳn, _smål, 
   {{0x6445708a,0xd7c88863,0x00000000,0x00000000}},	//   _stii, اوپه_, --, --, 
   {{0x7d14033f,0xa2c4f059,0x00000000,0x00000000}},	//   żyse, रहस्, --, --, 
   {{0x2d9c0a73,0x65640219,0xf1bc012c,0x00000000}},	//   _maue_, _vdih, _एकजन, --, 
   {{0x46a403b7,0x2d9c0731,0xafd84675,0x290c0009}},	//   _вакв, _laue_, _støn, _iyga_, 
   {{0xfbd0011a,0x00000000,0x00000000,0x00000000}},	//   חתם_, --, --, --, 
   {{0x27e40280,0x2d9d708b,0x64440337,0x0565708c}},	//   _hmnn_, _naue_, _ttii, _твин, 
   {{0x64454b46,0x3fe5708d,0xb46000c7,0xadc00208}},	// [26300] _utii, ажав, _дкыл, _nhằn, 
   {{0x25a1708e,0x82340502,0xa0686f78,0x2d9c0076}},	//   _hail_, _پردا, каға_, _aaue_, 
   {{0x25a01c1d,0x6011708f,0x2d9c3f5b,0x290c0024}},	//   _kail_, nämi, _baue_, _lyga_, 
   {{0x2d9c0393,0x290c01d5,0x25a0e0f4,0x0e681b80}},	//   _caue_, _oyga_, _jail_, اصلي_, 
   {{0x25a064a2,0x2d9c1368,0xadc0004d,0x8c3c00a2}},	//   _mail_, _daue_, _chằn, _urşl, 
   {{0x25a17090,0x60100a43,0xb4d80ba1,0xe7e4012c}},	//   _lail_, kämi, mbàt, टोमा_, 
   {{0x5d8800d1,0x290c008e,0x60115898,0xcd2815bf}},	//   _бәлг_, _ayga_, jämi, نسۇن_, 
   {{0x60100840,0xce340014,0x2d9d7091,0xdea43321}},	//   dämi, _اڈٕک, _gaue_, _پیچی, 
   {{0x670801f9,0x3b942377,0x00000000,0x00000000}},	//   _सुबक_, _вјет, --, --, 
   {{0x37a81b16,0x25a0062c,0x779000f2,0x00000000}},	//   ттин_, _aail_, زیبا, --, 
   {{0x64417092,0x290c06ea,0x25a0da1e,0xd83001d9}},	//   ímin, _eyga_, _bail_, _کٍت_, 
   {{0x35e5234d,0x25a008c2,0x29c00113,0xa9640902}},	//   рцов, _cail_, _uñap_, _вица_, 
   {{0x25a17093,0x9f84010e,0xf53c007c,0x00000000}},	//   _dail_, _söý_, vdåd_, --, 
   {{0x25a0089c,0x6010010e,0x65600332,0x00000000}},	//   _eail_, bämi, ómhr, --, 
   {{0x25a00c18,0x320801c6,0x4fd401ec,0x00000000}},	//   _fail_, вхан_, ұжат, --, 
   {{0x25a01590,0xdce0007f,0x942403b9,0x00000000}},	//   _gail_, _admč, _ətək_, --, 
   {{0x2d9c0363,0x4fd40022,0xf53c01e3,0x33840117}},	// [26310] _raue_, бжат, rdåd_, _кунв, 
   {{0x53984263,0x25a0009d,0x2d9d7094,0x49180037}},	//   _своя_, _zail_, _saue_, _परसो_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa1941cb8,0x3f88032e,0x42900023,0xa2c400cd}},	//   _даюч, _ebbu_, _ምልኣት_, रहर्, 
   {{0xdb097095,0x6e3800f3,0xcb697096,0x00000000}},	//   _andà, _čubu, гале_, --, 
   {{0x2d400943,0xab8459df,0x290c0153,0x8c3c00a2}},	//   ṱe_, рудк, _ryga_, _urşm, 
   {{0xda59442e,0x00000000,0x00000000,0x00000000}},	//   арыш_, --, --, --, 
   {{0xadc00016,0xb17803cd,0xf8b401c6,0x02b87ef5}},	//   _thằn, _småj, өөч_, _उपसभ, 
   {{0xe8006d65,0x25a17097,0x4808004e,0x00000000}},	//   रकला_, _rail_, леин_, --, 
   {{0x25a17098,0x6010049b,0xec2000cf,0xdd1c01ef}},	//   _sail_, tämi, _بۉتپ, _nářk, 
   {{0x25a01561,0xf53c005c,0xf41c013d,0x00000000}},	//   _pail_, ddåb_, ktäb_, --, 
   {{0xafd813ce,0x60117099,0x88580166,0x693000e5}},	//   _støl, rämi, _бидс_, _بکثر, 
   {{0x290c036b,0xb6040321,0x38c8158b,0x6010005b}},	//   _uyga_, _sláð, _ماوی_, sämi, 
   {{0x25a1709a,0x00000000,0x00000000,0x00000000}},	//   _wail_, --, --, --, 
   {{0xe1f8016c,0x25a00c18,0xc83c0240,0x00000000}},	//   иҳо_, _tail_, _ኣተኣላ, --, 
   {{0x25a1709b,0x69d9709c,0x51b40063,0x00000000}},	//   _uail_, nhue, осуђ, --, 
   {{0xc2e4015b,0x40c80451,0x00000000,0x00000000}},	// [26320] _খুশি_, دوءَ_, --, --, 
   {{0xa3e40210,0x00000000,0x00000000,0x00000000}},	//   पोश_, --, --, --, 
   {{0x6e380023,0x00000000,0x00000000,0x00000000}},	//   _ብኣገባ, --, --, --, 
   {{0x7c6447b3,0xa3e4134e,0x00000000,0x00000000}},	//   ماتل, पोर_, --, --, 
   {{0x69d80023,0x00000000,0x00000000,0x00000000}},	//   dhue, --, --, --, 
   {{0x69d915b9,0x8f740006,0xe58c00bc,0xb6000135}},	//   ehue, _мусі, jížď, ġġij, 
   {{0x69d801c7,0x8fc40022,0xadc00051,0x00000000}},	//   fhue, _ьарҵ, _nhặn, --, 
   {{0x69d801c7,0x78a401bf,0xf99000ae,0x00000000}},	//   ghue, ækvo, سبع_, --, 
   {{0x6cc000d1,0xf804014b,0xdd2800de,0x6441709d}},	//   _ейта, йчон, _sēņo, ímil, 
   {{0x69d800d8,0xacc4004e,0x00000000,0x00000000}},	//   ahue, _угуз_, --, --, 
   {{0xadc001fb,0xfa5401d5,0x644000df,0x00000000}},	//   _chặn, _چرچگ, ŭmil, --, 
   {{0xca60022e,0x89a4007b,0x7f5c014f,0x00000000}},	//   _izlа, _وإنم, hapq, --, 
   {{0xc2e403d4,0xafd80fac,0x00000000,0x00000000}},	//   _খুলি_, _støm, --, --, 
   {{0x79500133,0xa3e40b27,0x00000000,0x00000000}},	//   _بێکا, पोल_, --, --, 
   {{0xd7f8084c,0x98a403ee,0xd9ec0490,0x601001f4}},	//   mnă_, mamı_, _जगात_, nämu, 
   {{0xdb0801b8,0x98a4956f,0x521402bf,0x00000000}},	//   _fodö, lamı_, ідат, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [26330] --, --, --, --, 
   {{0xdb09419b,0x95140142,0x69d80200,0x00000000}},	//   _indæ, lẅor, zhue, --, 
   {{0x3d3c01f2,0xf1bc068c,0xafd803cd,0xd7f80356}},	//   _ịwa_, _siáu_, _utøm, ină_, 
   {{0xd7f80311,0x98a41cce,0xb1903c1a,0x69d8036e}},	//   hnă_, hamı_, _элмә, xhue, 
   {{0x98a405d1,0xe0e402d5,0xace8015e,0xec140166}},	//   kamı_, _еўро, درال_, бедә_, 
   {{0xb1784cab,0xf09c0241,0x66cc0241,0xbf7002dd}},	//   _småh, _isà_, _jòkú, _оқуы, 
   {{0x98a40db1,0x66cc01e1,0xd7f80356,0x4ab868eb}},	//   damı_, _mòkú, dnă_, руля_, 
   {{0x3eac037e,0xd7f8054e,0x00000000,0x00000000}},	//   æfte_, enă_, --, --, 
   {{0x69d80a40,0xc79489f1,0x87b9709e,0x6d5803cb}},	//   rhue, орны, аунт_, _ieua, 
   {{0xafd8037e,0x6d59709f,0xf1bc00c6,0x69d970a0}},	//   _støj, _heua, _fhág_, shue, 
   {{0x6d5970a1,0xdb0802d2,0x69d80036,0x00000000}},	//   _keua, _andæ, phue, --, 
   {{0x8c3c0365,0xd7f8084c,0x052800c7,0x00000000}},	//   _arşi, ană_, ионк_, --, 
   {{0x4904129d,0x5a0c010f,0x98a40790,0x98f40024}},	//   _بوشق, _גלאַ, bamı_, _няшч, 
   {{0xa3e40034,0xadc00208,0xfda401ad,0x98a403e0}},	//   पों_, _thặn, _गफ्फ, camı_, 
   {{0xf09d70a2,0x66dc0241,0x248402d3,0xd7f8009d}},	//   _asà_, _dáké, _ክፋላት_, _ууц_, 
   {{0x6d5970a3,0x60100267,0xb4d8004e,0x00000000}},	//   _neua, hämt, rbàr, --, 
   {{0xbfc53758,0xb4d970a4,0x03a400f3,0x9f8522c4}},	// [26340] обак, lcàn, _дипо, _böð_, 
   {{0x6e380fcf,0x1df408f2,0x00000000,0x00000000}},	//   _čubr, ेक्ष_, --, --, 
   {{0x35ac44ab,0x6d580036,0xb4d805d5,0xf1bc00ae}},	//   _जोड़, _beua, ncàn, _bhád_, 
   {{0xbc485663,0xc0c802d3,0x7ce401d5,0x7f5c9231}},	//   ачке_, በሃል_, _qаro, sapq, 
   {{0x6d5970a5,0x629c03cb,0x66cc0241,0x00000000}},	//   _deua, lwro, _yòkú, --, 
   {{0x7f5c0455,0xba44030d,0x00000000,0x00000000}},	//   qapq, охий, --, --, 
   {{0x98a42c6f,0xb178713c,0xd7f80356,0x00000000}},	//   vamı_, _småi, vnă_, --, 
   {{0x6d580076,0x00000000,0x00000000,0x00000000}},	//   _geua, --, --, --, 
   {{0x98a4510c,0x60100108,0x00000000,0x00000000}},	//   tamı_, sämu, --, --, 
   {{0xd7f8084c,0x6d580489,0x0c78010b,0xf1bc0051}},	//   ună_, _zeua, _ыссы_, _thág_, 
   {{0xd7f8084c,0x7bd80165,0x98a467ab,0xc6e40327}},	//   rnă_, _iltu, ramı_, _སྟཱུ, 
   {{0xb90810fc,0x98a403e0,0x00000000,0x00000000}},	//   _кнез_, samı_, --, --, 
   {{0x77900014,0x55580139,0x00000000,0x00000000}},	//   _ہیکا, _һайя_, --, --, 
   {{0x386570a6,0x2810df98,0x98a403e3,0x00000000}},	//   _ivor_, _قونس, qamı_, --, 
   {{0x3864501b,0xf09c0ffb,0x9f840008,0x31c40063}},	//   _hvor_, _ssà_, _röð_, осав, 
   {{0x7ce4022e,0xdb080432,0x229001f4,0x00000000}},	//   _pаrl, _indä, _sökö_, --, 
   {{0x2290025a,0xf1bc180f,0x7bd970a7,0x6d580c6a}},	// [26350] _pökö_, _siás_, _oltu, _reua, 
   {{0xd01170a8,0x6d5970a9,0xc0e80023,0x8c3c0356}},	//   رلا_, _seua, መሰላ_, _urşi, 
   {{0xc0e8044e,0xdfd800a7,0x8db402bf,0xa3b84c19}},	//   መሰለ_, цът_, зслі, छार_, 
   {{0x2bd0024a,0xf1a80133,0x00000000,0x00000000}},	//   थस्थ, _ئاده_, --, --, 
   {{0x2fc401dc,0x6d580a73,0xf09c026c,0xc0c8001f}},	//   ưng_, _veua, _usà_, በቃል_, 
   {{0xccf80055,0x9bc800ae,0x00000000,0x00000000}},	//   _neśe_, يونك_, --, --, 
   {{0x6d5970aa,0xfe6c211f,0x5f440066,0x00000000}},	//   _teua, _مگن_, _آنفل, --, 
   {{0xc0e8044e,0x39440332,0x08c570ab,0x6010002f}},	//   መሰሉ_, _cfos_, збин, sämt, 
   {{0x3864110c,0xc95800cf,0x76580055,0x00000000}},	//   _cvor_, _ۇلاش_, _āpaṇ, --, 
   {{0x386439e2,0xdb0800d7,0x00000000,0x00000000}},	//   _dvor_, _podô, --, --, 
   {{0x02b8dde9,0xccf800cd,0x3944015d,0x06081887}},	//   _उपेन, _deśe_, _ffos_, йнок_, 
   {{0xe8dc02e3,0xb4d804cc,0x5c540023,0x00000000}},	//   nrịa_, rcàn, _ዝተጠር, --, 
   {{0xdb08013d,0xa8a410fc,0x670807f7,0x97c40133}},	//   _endä, _фрек, _सुरक_, ستیم, 
   {{0xc87807c4,0x07a473f7,0x98b4009f,0x00000000}},	//   muş_, _хакн, _آلوڙ, --, 
   {{0xc87970ac,0x6fd00205,0x00000000,0x00000000}},	//   luş_, _mıcı, --, --, 
   {{0xdddc0fcf,0xca28005e,0x2b8c05d1,0xe7e400e1}},	//   _sprž, _ﺤﺯﺏ_, lıcı_, टोरा_, 
   {{0xc0e8001f,0xc8786887,0xdb08005c,0xd6242372}},	// [26360] _መቼም_, nuş_, _indå, _تعوي, 
   {{0x2b8c0365,0xb1400323,0x9f840037,0xa30402dd}},	//   nıcı_, _үнэл, _löö_, _жүге, 
   {{0xc8780342,0x442801a9,0x9f9400c7,0xb03000d1}},	//   huş_, mmb_, зыҵә, رىمغ, 
   {{0x568c00c8,0xf41c023a,0xb1781f53,0xb2b80375}},	//   שטאַ, ntän_, _småv, _המטר, 
   {{0x44280109,0x2b8c05d1,0xb17808fb,0x7ce401a9}},	//   omb_, kıcı_, _blåf, _tаrm, 
   {{0x44280100,0x4f94004e,0x6010007c,0xc87970ad}},	//   nmb_, _орсу, räms, duş_, 
   {{0xf41c00fd,0x3f980810,0x38641f53,0x2b8c0213}},	//   ktän_, mepu_, _svor_, dıcı_, 
   {{0x6da0164a,0x3f98068f,0xada00953,0xf1c4013a}},	//   _писа, lepu_, _пасл, _tkáň_, 
   {{0x7ce401b9,0xda700050,0xc87820a9,0x00000000}},	//   _mаrk, رُک_, guş_, --, 
   {{0xf1bc01dc,0xfaa51fc9,0x7bd8127b,0x3f98037e}},	//   _khác_, _назо, _ultu, nepu_, 
   {{0xadf042e3,0x98b87975,0x7c28037e,0xf41c013d}},	//   _आगमन_, ğrı_, mmfr, ftän_, 
   {{0x394405d5,0xc8780356,0x00000000,0x00000000}},	//   _ufos_, buş_, --, --, 
   {{0xb4d80ffb,0x798002d0,0xc8780356,0x3f9800d7}},	//   ccàl, _icow, cuş_, kepu_, 
   {{0x3f981711,0xdb0805ac,0x44280099,0x78a170ae}},	//   jepu_, _endå, gmb_, _isov, 
   {{0x29c00784,0x7648168c,0xf1bc0208,0xb178007c}},	//   _añay_, _utfy, _nhác_, _omåt, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa5d80efb,0x00000000,0x00000000,0x00000000}},	// [26370] _ءبىر_, --, --, --, 
   {{0x3f980421,0x78a00334,0x7ce401a9,0xdea40271}},	//   gepu_, _msov, _tаrj, کیفی, 
   {{0x45080135,0x3a3c2a1f,0xb17803cd,0xf1bc0208}},	//   _གཙོར_, _nutp_, _småu, _chác_, 
   {{0x78a00552,0xf1bc001e,0x9f0570af,0x22e403e6}},	//   _osov, _giáp_, رونو, _ستپێ, 
   {{0x78a002b9,0x7b0c1682,0x2b8c0259,0x1c440220}},	//   _nsov, ṱulu, yıcı_, енім, 
   {{0xb1785c3d,0xc8783535,0x3f98d8d4,0x9f840037}},	//   _blåg, vuş_, cepu_, _söö_, 
   {{0xdb0807a8,0x78a0009b,0xf41c023a,0xfaa000a7}},	//   _indû, _asov, ytän_, ващо, 
   {{0xc87800ee,0x60102c4f,0x7c280036,0x0d6400f2}},	//   tuş_, lämp, amfr, _آگاپ, 
   {{0x64b406c8,0x2b8cb580,0xc8c804fb,0x09052274}},	//   _āin, tıcı_, زودن_, ьпин, 
   {{0x798170b0,0xc878e2ff,0xb4d800db,0x86449c9d}},	//   _ecow, ruş_, rcàl, множ, 
   {{0x9f84007d,0x78a00b6f,0x38c8034c,0x2b8c47af}},	//   _töö_, _esov, مایی_, rıcı_, 
   {{0xaa0800db,0x8cc0000d,0xc8780356,0xb3f00051}},	//   _ازئل_, लमपो, puş_, _đềtr, 
   {{0x60103bd5,0x69c834a2,0xf41c01b8,0x2b8c0790}},	//   kämp, _ioge, rtän_, pıcı_, 
   {{0xe78570b1,0x74103306,0x580570b2,0x69c970b3}},	//   _худо, َوَا, _كونك, _hoge, 
   {{0x69c970b4,0xf41d70b5,0x60114c87,0x4e0c000d}},	//   _koge, ptän_, dämp, िकाई_, 
   {{0x69c970b6,0x3f9800ec,0xbbd8012c,0x05e05ca7}},	//   _joge, wepu_, _भत्क, _पतिब, 
   {{0x69c970b7,0x3f9970b8,0x78a00998,0x4428036e}},	// [26380] _moge, tepu_, _xsov, pmb_, 
   {{0x69c970b9,0xb1780efa,0x3000036b,0xf1bc004d}},	//   _loge, _småt, взуг, _phác_, 
   {{0x69c970ba,0x3f98009b,0x7ce401d5,0xbef800dc}},	//   _ooge, repu_, _tаrk, ्थेन_, 
   {{0x69c807ad,0xdc4802e3,0x3f980618,0x00000000}},	//   _noge, _aṅụ_, sepu_, --, 
   {{0x29c000fd,0x7ce4022e,0x3f980254,0xc0c80092}},	//   _uñay_, _kаri, pepu_, በቃም_, 
   {{0xdb09078c,0xafd80627,0x69c804ba,0xf1bc001e}},	//   _indú, _støv, _aoge, _thác_, 
   {{0x69c970bb,0x78a0070d,0xb17800b5,0x8e741cd0}},	//   _boge, _ssov, _flåd, _путч, 
   {{0x69c970bc,0x78a02ce2,0xb1780217,0x7ce4022e}},	//   _coge, _psov, _umåt, _lаri, 
   {{0x69c8bcd7,0xfca84278,0xbb44068e,0x00000000}},	//   _doge, _بازو_, _жезк, --, 
   {{0xb8e49f23,0x69c8030a,0xb8d4000d,0x00000000}},	//   _उप_, _eoge, _चछ_, --, 
   {{0x69c970bd,0x6a80fd40,0x3ce47edf,0xd4900208}},	//   _foge, _алха, lzov_, ằm_, 
   {{0x69c970be,0xafd803a1,0x7980014b,0xdb0800e4}},	//   _goge, _utøv, _ucow, _ondú, 
   {{0x3a2404f3,0xf52400c0,0xccf8002b,0x00000000}},	//   _ihop_, ьфон, _keśa_, --, 
   {{0x69c970bf,0xdb180254,0xa424009d,0x00000000}},	//   _zoge, skvõ, вьсл, --, 
   {{0x69c970c0,0xf1a45c25,0xdb0848cb,0x6010005b}},	//   _yoge, мран, _andú, vämp, 
   {{0x69c80009,0xc4440244,0x00000000,0x00000000}},	//   _xoge, بیین_, --, --, 
   {{0x92c003f4,0xcfb41086,0x601001e3,0x536c0092}},	// [26390] ্ছে_, нбаъ, tämp, ስታወስ_, 
   {{0xab60012d,0x3ce40419,0x00000000,0x00000000}},	//   ążka, dzov_, --, --, 
   {{0xf3fc0120,0x60102306,0x33b00116,0x00000000}},	//   lsão_, rämp, _كەڭر, --, 
   {{0x60100108,0xf1d00b8f,0x00000000,0x00000000}},	//   sämp, _सविन, --, --, 
   {{0xf3fc03b7,0xdb08026c,0x638002f0,0x00000000}},	//   nsão_, _indù, _ušní, --, 
   {{0x69c970c1,0x8b24bb62,0xc2e4009e,0x7ce4022e}},	//   _soge, ндле, _খুটি_, _xаri, 
   {{0x69c970c2,0xccf800cd,0xdea41927,0xdef800cf}},	//   _poge, _deśa_, _لیلی, _жыт_, 
   {{0x3a2570c3,0xdbcc01e1,0x7970013f,0xb17800b5}},	//   _chop_, _bóól, _yɛwɔ, _flåe, 
   {{0x69c970c4,0xdd8471fe,0x202402d2,0x00000000}},	//   _voge, _шырп, _örið_, --, 
   {{0x69c970c5,0xe86005f5,0x1d7c001f,0x46e8322b}},	//   _woge, нхүү, _ጥናቶች_, здон_, 
   {{0x69c970c6,0x52c800ce,0x00000000,0x00000000}},	//   _toge, रहोस, --, --, 
   {{0x3a24016d,0x00000000,0x00000000,0x00000000}},	//   _ghop_, --, --, --, 
   {{0x1b600b82,0x20500023,0xf990011a,0x00000000}},	//   _ግንባራ, ማእሰር, _תרד_, --, 
   {{0xca6802d3,0x7ce4022e,0xb3f00208,0x00000000}},	//   _ኰይኖም_, _qаri, _đểtr, --, 
   {{0x41b570c7,0xb7d80375,0xc2e404c5,0xf3fc00d8}},	//   нсат, _מקסי, _খুজি_, asão_, 
   {{0x672170c8,0xe8dc01e1,0xc4840114,0xa3e404aa}},	//   _iznj, _lkọk_, _злик, पोज_, 
   {{0x34b00597,0x66040521,0xdb0800d8,0x7ce401a9}},	// [263a0] _مميز, _ijik, _cadê, _tаri, 
   {{0x7d14033f,0x03a40f5c,0xdbcc01e1,0xc1e001e0}},	//   żysk, _џино, _lóòl, төүҙ, 
   {{0xb17804ce,0x44380098,0x66040158,0xe7e400af}},	//   _slåe, _iip_, _kjik, _ओतना_, 
   {{0xafd8708a,0x7b0c06d6,0x4438029d,0x00000000}},	//   _støt, ṱuku, _hip_, --, 
   {{0x443970c9,0xf1bc0016,0x660401b3,0x61e570ca}},	//   _kip_, _khán_, _mjik, mhil, 
   {{0x443970cb,0xfaa570cc,0x3a2570cd,0x61e570ce}},	//   _jip_, ешин, _shop_, lhil, 
   {{0x0ba970cf,0x4438047e,0x660570d0,0x61e401e0}},	//   بانى_, _mip_, _ojik, ohil, 
   {{0x7e7d70d1,0x660405db,0x44382517,0xdb080200}},	//   mupp, _njik, _lip_, _hadë, 
   {{0x7e7d70d2,0x2ba80073,0x60c478aa,0x61e570d3}},	//   lupp, _टोका, nxim, ihil, 
   {{0x443970d4,0x66040ca8,0x60c4004e,0x2ca40d31}},	//   _nip_, _ajik, ixim, _якуп_, 
   {{0x7c380472,0x7e7d70d5,0x3a243657,0xba7400f7}},	//   _iitr, nupp, _thop_, _ساات, 
   {{0x7c3970d6,0x61e570d7,0xdbcc0241,0x4438045a}},	//   _hitr, jhil, _góòl, _aip_, 
   {{0x7e7c3bbe,0x61e570d8,0x7c3970d9,0xf41c0724}},	//   hupp, dhil, _kitr, stäm_, 
   {{0xf3fc03b7,0x443824e4,0x660400b4,0x7c3970da}},	//   rsão_, _cip_, _ejik, _jitr, 
   {{0x44381248,0xf3fc0cfc,0x7e7c20ac,0xa29402bf}},	//   _dip_, ssão_, jupp, ларі, 
   {{0x7c3970db,0x61e570dc,0xda1022e3,0x224c00bc}},	//   _litr, ghil, ावित_, ídka_, 
   {{0x20984c0f,0x60c401e2,0x70b8033f,0x14300023}},	// [263b0] нкты_, gxim, ईमेल, በረልኩ, 
   {{0x443970dd,0x251c04ac,0x611401c6,0xaf0570de}},	//   _gip_, _צוזא, удуу, нчек, 
   {{0x61e570df,0x7e7d70e0,0x37e00183,0xafd80fac}},	//   bhil, gupp, _পদাৰ, _støs, 
   {{0x61e570e1,0x44385e6e,0x7c3970e2,0xaf50134b}},	//   chil, _zip_, _aitr, _әнвә, 
   {{0xdb0957f4,0x1cd80064,0x2d8c002f,0x00000000}},	//   _fadë, ндцы_, rfge_, --, 
   {{0x44380137,0x7c38b180,0xdb080669,0x7e7c01e3}},	//   _xip_, _citr, _kadè, bupp, 
   {{0x7c3970e3,0x2fc4008c,0x7e7c0268,0x09e40120}},	//   _ditr, öngu_, cupp, кокн, 
   {{0x9e343129,0x7c385f87,0xdb080129,0x00000000}},	//   _бесч, _eitr, _madè, --, 
   {{0x7c3970e4,0x18740092,0x6d4803ac,0x00000000}},	//   _fitr, _በነገር_, mcga, --, 
   {{0x7c382819,0x6e3801ab,0x6604143a,0x61e4030a}},	//   _gitr, _hiub, _sjik, zhil, 
   {{0x61e570e5,0x6e3970e6,0xdb08557b,0xf1bc0208}},	//   yhil, _kiub, _nadè, _nháo_, 
   {{0x443970e7,0x6774001f,0x7c383370,0x61e42c76}},	//   _sip_, _በአዲሱ_, _zitr, xhil, 
   {{0x61e41aa1,0x60c481f1,0xf1bc001e,0xd84801f2}},	//   vhil, xxim, _phán_, _rọg_, 
   {{0x6b8170e8,0x61e570e9,0xb1781f53,0x69d970ea}},	//   ngng, whil, _småp, lkue, 
   {{0x61e570eb,0xdb0889a4,0xf1bc01fb,0x46a43981}},	//   thil, _cadè, _cháo_, _райв, 
   {{0xdb08020c,0x6e380f7e,0x69d970ec,0x7e7d70ed}},	//   _dadè, _niub, nkue, vupp, 
   {{0x443970ee,0x61e4a3ec,0xb1405bc5,0xdb080240}},	// [263c0] _tip_, rhil, рнул, _padë, 
   {{0xafd85b47,0x61e46fff,0x656570ef,0x64440093}},	//   _stør, shil, _heih, _iuii, 
   {{0x61e43058,0x7c3970f0,0x6e380481,0x6444166a}},	//   phil, _ritr, _biub, _huii, 
   {{0x7c3970f1,0x644570f2,0x973c1591,0x65640363}},	//   _sitr, _kuii, meće, _jeih, 
   {{0x656570f3,0x7e7d70f4,0x6e3970f5,0x7c3970f6}},	//   _meih, supp, _diub, _pitr, 
   {{0x57e00034,0xdb0800d5,0x644570f7,0xda700a81}},	//   _फतेह, _hadé, _muii, مُت_, 
   {{0xdb080438,0x973c0fcf,0x20189825,0x6e3801ab}},	//   _kadé, neće, _ikri_, _fiub, 
   {{0x6e3970f8,0x7c38068f,0x7cf00724,0x65640036}},	//   _giub, _witr, _cırç, _neih, 
   {{0xdb080109,0xd7c970f9,0x00000000,0x00000000}},	//   _madé, فوظه_, --, --, 
   {{0x7c382595,0xdb0806af,0xdbcc08ce,0x00000000}},	//   _uitr, _ladé, _góðl, --, 
   {{0x973c0b91,0x963570fa,0x656570fb,0xf98400c7}},	//   jeće, лноц, _beih, _агео, 
   {{0x973c0989,0x65640007,0xf7500075,0xdb0804fb}},	//   deće, _ceih, _ھۆجج, _radè, 
   {{0x65640007,0x6444020c,0xdb080214,0xf1bc0332}},	//   _deih, _cuii, _sadè, _dhál_, 
   {{0x20184862,0x64451f74,0xf1bc001e,0xdb08007f}},	//   _nkri_, _duii, _pháo_, _padè, 
   {{0x57a406ba,0x65640399,0xdb080c6a,0xc83c02d3}},	//   _ашқа, _feih, _badé, _ኣተሓሕ, 
   {{0x20180066,0xdb44a04e,0x64447dbf,0xdb08068c}},	//   _akri_, _ژێ_, _fuii, _vadè, 
   {{0x64440a73,0x623570fc,0x6e3800a3,0xdca400db}},	// [263d0] _guii, рету, _riub, _بۉ_, 
   {{0xf1bc001e,0x65643987,0x6e380192,0x69d8005a}},	//   _tháo_, _zeih, _siub, zkue, 
   {{0x6d48074d,0x69d970fd,0x6e3970fe,0x65640076}},	//   tcga, ykue, _piub, _yeih, 
   {{0x20186070,0xf1bc0016,0xdb08003e,0x644400b5}},	//   _ekri_, _khám_, _gadé, _yuii, 
   {{0x7e6c0066,0xf1bd70ff,0x6d4801e4,0x2d880139}},	//   _evbp, _iná_, rcga, _öcem_, 
   {{0xe50419e5,0xdf480117,0x00000000,0x00000000}},	//   रपति_, _азёд_, --, --, 
   {{0x6e38007b,0x07a402dd,0x6b80014f,0x69d80108}},	//   _tiub, қанн, rgng, tkue, 
   {{0x88840276,0xf3f80183,0x1a685022,0x7ce401d5}},	//   глиж, ৃতিৰ_, ئینی_, _pаrt, 
   {{0x65657100,0x69d82ec8,0xf1bd7101,0xdb0800e4}},	//   _reih, rkue, _mná_, _indý, 
   {{0x47c4094c,0x69d97102,0x973c0552,0x1bb80fb4}},	//   убов, skue, zeće, _لامع_, 
   {{0xf1bc0270,0x49757103,0x65643191,0xdce0012c}},	//   _oná_, _блес, _peih, _odmě, 
   {{0x19580022,0x7ce401d5,0xf1bc0241,0x00000000}},	//   _аацы_, _tаrt, _nná_, --, 
   {{0xd4f57104,0x973c1050,0x65657105,0xdb097106}},	//   аяры, veće, _veih, _radé, 
   {{0x65657107,0xdb0828b2,0xf1bd7108,0x644000cf}},	//   _weih, _sadé, _aná_, ímiq, 
   {{0x973c0bb8,0x65657109,0x6445710a,0xdb08a507}},	//   teće, _teih, _wuii, _padé, 
   {{0x6445710b,0xafd84606,0xbfa80014,0x00000000}},	//   _tuii, _støp, کارٕ_, --, 
   {{0x973c098d,0x00000000,0x00000000,0x00000000}},	// [263e0] reće, --, --, --, 
   {{0xd84801dc,0x973c0063,0xdb0800e4,0x7ae80175}},	//   _học_, seće, _andý, yzft, 
   {{0x2bc45168,0x973c00f3,0x1ee80214,0x2c0400cd}},	//   लाना, peće, خوای_, वचनं_, 
   {{0x7bc80369,0xfca800f1,0x51540212,0xf1bc02d2}},	//   wjfu, فاتو_, _втру, _gná_, 
   {{0xd848001e,0x6298014a,0x20180066,0xb4d8004e}},	//   _mọc_, _ävob, _tkri_, scàv, 
   {{0xd8480016,0x3c0c00af,0xf1bc00bc,0x9e840133}},	//   _lọc_, ाकेँ_, _zná_, _پاسۆ, 
   {{0xd9440124,0xafe1710c,0x8fd401ee,0x00000000}},	//   аҵеи, _уорл, _тәтә, --, 
   {{0x987403a6,0x7ce401a9,0xd8480208,0x18740107}},	//   алиц, _qаrs, _nọc_, агия, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3ba40092,0x57f401f4,0x00000000,0x00000000}},	//   ጋጌዎች_, рпот, --, --, 
   {{0x6c300491,0xd848001e,0x1dc801f9,0x56940117}},	//   _افلا, _bọc_, ळापत, шант, 
   {{0xd84801fb,0xdce0007f,0xadc000e4,0x00000000}},	//   _cọc_, _lemč, _okẽn, --, 
   {{0xd848001e,0x385407d8,0xb1781f53,0xe4e428f6}},	//   _dọc_, _съес, _blån, бірн, 
   {{0xdce0994e,0x2bc400dc,0xe5c40150,0xdd1c02f0}},	//   _nemč, लाया, _ۇقىپ, ráňo, 
   {{0xe78010de,0xdb09710d,0x5334003b,0x00000000}},	//   _الىپ, _indó, ревт, --, 
   {{0xb400b144,0xf1bc001e,0x2165710e,0x1154003b}},	//   рүүд, _thám_, йтуг, ркаю, 
   {{0x2bc4024a,0xdb08002f,0x60100108,0x00000000}},	// [263f0] लामा, _andü, lämy, --, 
   {{0x56540023,0xb61c01ec,0x00000000,0x00000000}},	//   _ዘሰንብ, _ﺤﻣ_, --, --, 
   {{0x5f1843aa,0x68800b82,0x69cc0205,0x00000000}},	//   _बुद्_, _ዮፍታሄ_, öcek, --, 
   {{0xd8480051,0x2bc400cd,0x00000000,0x00000000}},	//   _xọc_, लाभा, --, --, 
   {{0xdb0805d1,0x7ce4022e,0x00000000,0x00000000}},	//   _endü, _bаrq, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2bc410dc,0x4c140014,0x16140073,0xda1001f9}},	//   लाबा, _ێکتھ_, णकार_, ावंत_, 
   {{0xdb09066d,0xf7c400d1,0x00000000,0x00000000}},	//   _andó, _ﺩﯦﻤﻪ, --, --, 
   {{0x6b85710f,0x8b845f32,0xd8480051,0x6ce4187f}},	//   _مشال, _نەشە_, _rọc_, _сіве, 
   {{0x87b80276,0xd84801fb,0xa6400092,0x00000000}},	//   туит_, _sọc_, _ከተወሰ, --, 
   {{0x9b442586,0xdb5001d9,0x7d14033f,0x7ce801d3}},	//   _انمو, _ژَے_, żyst, _töré, 
   {{0xdb08021c,0x3eac013c,0x97c40150,0x00000000}},	//   _endó, æfti_, _ۇتىم, --, 
   {{0xb17801e6,0xda700014,0xdb0801e1,0x04441422}},	//   _plån, _وُے_, _ladì, регн, 
   {{0x443c023a,0xa42400cc,0x637002d2,0x986401f7}},	//   öt_, পদ্য_, dóní, _اُٻه, 
   {{0x981400c6,0xdce002e2,0xc3300014,0xe9fc0051}},	//   _ابنا, _remč, زٕر_, _gjảj_, 
   {{0xd8480016,0xdce002e2,0x60100139,0x00000000}},	//   _họa_, _semč, lämx, --, 
  
   {{0x973c071b,0x80b006ab,0x00000000,0x00000000}},	// [26400] meća, ीमें, --, --, 
   {{0xac78044e,0x11380137,0xff240b01,0x43757110}},	//   _ብሰላም_, уясы_, амзо, _туит, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7ce4022e,0x00000000,0x00000000,0x00000000}},	//   _bаrp, --, --, --, 
   {{0x1b040032,0xb4d8381a,0x212400ae,0x998400fb}},	//   әүен, lcàr, _ámh_, ҡтиһ, 
   {{0x3ea80a2e,0x9f4c005b,0x387003e3,0xbc1401d5}},	//   _tsbt_, älät_, _çarə_, шфеъ, 
   {{0xdb097111,0xb4d80137,0xbe357112,0x9980002e}},	//   _andò, ncàr, _نىسب, _ñiŋ_, 
   {{0x973c1727,0xf41d55fe,0x394003cd,0x00000000}},	//   jeća, ltät_, øks_, --, 
   {{0x973c0063,0x7ce4022e,0x00000000,0x00000000}},	//   deća, _tаrq, --, --, 
   {{0x0ba81b06,0xf41cc6cb,0xf0900375,0xdb080306}},	//   _مامى_, ntät_, קנת_, _hadí, 
   {{0xd848001e,0xb1784cab,0xdb240811,0x2bd8043e}},	//   _dọa_, _blål, _اوای, _भवता, 
   {{0xd1f80020,0x00000000,0x00000000,0x00000000}},	//   ለበት_, --, --, --, 
   {{0x2e3400df,0x00000000,0x00000000,0x00000000}},	//   ירטש_, --, --, --, 
   {{0x26f4121b,0xe7b024e0,0xdb08013a,0xf644030d}},	//   اریخ_, _ومند, _ladí, _кхин, 
   {{0x25b002f6,0x3cbc03d4,0x9f4c03b2,0x00000000}},	//   öllä_, ্নিৱ, ðlýs_, --, 
   {{0x76585e6e,0xdb097113,0xf1bc001e,0x630401d5}},	//   mpty, _kadâ, _khái_, زوقل, 
   {{0xfe7802dd,0xb4d8004e,0xf4857114,0x00000000}},	// [26410] _ءﺟﯘﻥ_, rcàs, _туйн, --, 
   {{0x3d18068f,0x7e7c010a,0xb284004e,0xa854011a}},	//   _बड़े_, frpp, _кымк, יימה_, 
   {{0xdb0800d7,0xee840153,0x00000000,0x00000000}},	//   _badí, рызо, --, --, 
   {{0xf1503fe6,0x00000000,0x00000000,0x00000000}},	//   _ذکرک, --, --, --, 
   {{0x7e7c013c,0xc0c01cd1,0xf1bc01fb,0xccf80055}},	//   arpp, _нәфи, _nhái_, _keśi_, 
   {{0x24857115,0xf09c01e1,0xdfd800a7,0x2bc40bca}},	//   àmmi_, _ipà_, _къс_, लाधा, 
   {{0xf1bc0022,0xeab00b8c,0x1a6875a7,0xf41c01f4}},	//   _ahái_, تعش_, لیلی_, ltäs_, 
   {{0x3ebc2833,0xf53c00fe,0xd6ac00cc,0x00000000}},	//   _átta_, ndås_, গমায, --, 
   {{0x973c0bb8,0x08c41086,0xf1bc0051,0xf41c01f4}},	//   veća, ёбон, _chái_, ntäs_, 
   {{0x7d1c033f,0xdb0801ef,0x00000000,0x00000000}},	//   ępst, _zadí, --, --, 
   {{0x38c836bd,0xa3b802ab,0xdce0005f,0xd1cc010c}},	//   نایی_, _घोष_, _iemā, _ባጀት_, 
   {{0x1a6401ed,0xdce0002b,0x00000000,0x00000000}},	//   _بیٹی_, _hemā, --, --, 
   {{0xd84801fb,0x76580ea0,0xf41c023a,0x98f40024}},	//   _tọa_, apty, ytät_, _мяшч, 
   {{0xf8b4025f,0xb0597116,0x973c0114,0xd8480241}},	//   _לפני_, _kräf, seća, _kọn_, 
   {{0xd8480521,0xd5ac00dd,0x70448337,0xd6a806f6}},	//   _jọn_, رہی_, ەرمە, _نديم_, 
   {{0xa3b800ab,0xb1782d8b,0xc04408de,0xd8480208}},	//   _घोर_, _flåm, مخطو, _mọn_, 
   {{0xdb0828ff,0xb4d800f7,0x682c0140,0xb178143a}},	// [26420] _radí, scàr, rødf, _glåm, 
   {{0xdce000e2,0xdb0802f0,0x3ea400db,0x00000000}},	//   _nemā, _sadí, йизг, --, 
   {{0xd848063f,0xdb080005,0x7dd8067c,0xf41c0112}},	//   _nọn_, _padí, _oïst, rtät_, 
   {{0xf41d7117,0xdb080166,0xf1bc00d0,0x682c03b2}},	//   stät_, _qadí, ášte_, lødd, 
   {{0x973c1711,0x76580306,0xa3cc033f,0x00000000}},	//   jećn, zpty, _रचा_, --, 
   {{0xd8480016,0x8f8004a2,0x22b802bd,0xdce0002b}},	//   _bọn_, _оқул, _kčk_, _cemā, 
   {{0xeaac3092,0xdb0801e1,0x00000000,0x00000000}},	//   فعي_, _tadí, --, --, 
   {{0xf1bc0016,0x27e40165,0x7de40150,0xd848001e}},	//   _phái_, _alnn_, _اسسم, _dọn_, 
   {{0xdce054bb,0x5fdc0118,0xa85007ee,0x9f0401e2}},	//   _femā, _मकाल, пкыч, _اوځو, 
   {{0xd84801e1,0x37a8009b,0xa3b8012d,0x00000000}},	//   _fọn_, утин_, _घोल_, --, 
   {{0xd8480016,0xf41c01e6,0xb17803cd,0xb05811a1}},	//   _gọn_, ktär_, _slåm, _gräf, 
   {{0xf1bc07ae,0xdce000da,0x7790004b,0x35e57118}},	//   _thái_, _zemā, _کیدا, сцов, 
   {{0x39457119,0x8c3c010e,0x682d711a,0x81dc015b}},	//   _igos_, _arşy, fødd, তফা_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa0000f22,0xf41d54da,0xf09c01c3,0xd8480051}},	//   ্তাব_, hräg_, _spà_, _xọn_, 
   {{0x38640295,0x2fc025d0,0xf41c01f4,0x00000000}},	//   _kwor_, _snjg_, ttäs_, --, 
   {{0x4fd408b7,0x00000000,0x00000000,0x00000000}},	// [26430] ожат, --, --, --, 
   {{0x53993f71,0xf365711b,0x764801c8,0x22b802e2}},	//   _твоя_, _утин, _kufy, _fčk_, 
   {{0x39440201,0x2bc41fbc,0x533436ca,0xf41c005b}},	//   _ogos_, लासा, _фент, stäs_, 
   {{0x682c037e,0x4cb800f5,0x00000000,0x00000000}},	//   møde, илею_, --, --, 
   {{0x7dd80129,0x682c332e,0x00000000,0x00000000}},	//   _aïss, løde, --, --, 
   {{0x3945711c,0xb0580d16,0x973c041a,0x67fc01e1}},	//   _agos_, _präf, jećo, _májè, 
   {{0x973c0552,0xf8ac04d3,0xdb080137,0x38648616}},	//   dećo, ێکه_, _cadà, _awor_, 
   {{0x2bc4190e,0x00000000,0x00000000,0x00000000}},	//   लाहा, --, --, --, 
   {{0xd8480570,0x31680034,0xb05826bc,0x9e341b0a}},	//   _wọn_, _mecz_, _dräg, _хетч, 
   {{0xb05804f3,0x973c17a3,0x31680034,0xb1781f53}},	//   _träf, rećn, _lecz_, _blåk, 
   {{0x46f42c71,0x06084963,0x682c8f9d,0x973c0e04}},	//   ючит, инок_, jøde, sećn, 
   {{0xd848063f,0x38c804d3,0x2bc417ee,0x682c08cb}},	//   _kọl_, _چاوی_, लावा, døde, 
   {{0x38c8168d,0x22b800d7,0x682c0162,0x00000000}},	//   _ناوی_, _sčk_, tødd, --, 
   {{0x02c401c0,0xb17803cd,0x682c01bf,0x00000000}},	//   ойго, _flåk, føde, --, 
   {{0x764807a8,0x682cb626,0x7410007b,0x00000000}},	//   _gufy, rødd, ذوفا, --, 
   {{0xdb080113,0x42240d30,0xb05801e3,0x7aec002f}},	//   _jadá, ідав, _oräd, _übte, 
   {{0xdb0801ed,0x9a9c0092,0xfbd8012d,0x00000000}},	// [26440] _madá, ወሰነው_, _बकलम, --, 
   {{0x6721711d,0xefc4084c,0xf41c7dcf,0x682c005c}},	//   _kynj, олул_, stär_, bøde, 
   {{0x67200649,0x829000db,0x764801a9,0x8c3c010e}},	//   _jynj, _تۇزچ, _xufy, _urşy, 
   {{0x6721711e,0xdb0802fd,0xb05801e6,0x973c01a6}},	//   _mynj, _nadá, _bräd, zećo, 
   {{0x61e5711f,0xf1bc0016,0x00000000,0x00000000}},	//   mkil, _cháu_, --, --, 
   {{0x61e57120,0xd848063f,0xdb08004e,0xac053ed4}},	//   lkil, _dọl_, _padà, онча_, 
   {{0xb0583714,0x9b680ae5,0xb178003b,0x38640327}},	//   _präg, ашқа_, _blåh, _swor_, 
   {{0x76484539,0xdb097121,0xc7640075,0x61e57122}},	//   _rufy, _cadá, ۋاپى, nkil, 
   {{0xf41c0724,0xb05801e6,0x67200363,0x973c110c}},	//   ktäp_, _gräd, _aynj, tećo, 
   {{0xfaa57123,0x61e401b9,0x00000000,0x00000000}},	//   _мазо, hkil, --, --, 
   {{0xdb097124,0xb0597125,0xf1bc001e,0x61e57126}},	//   _andö, _träg, _khát_, kkil, 
   {{0x67217127,0x2cc00166,0x00000000,0x00000000}},	//   _dynj, _ürdä_, --, --, 
   {{0xf7700f31,0x672004ba,0x61e4072b,0x387001d5}},	//   _ہاں_, _eynj, dkil, _ўқот, 
   {{0x61e401e0,0xdb080232,0x78a00395,0xedc4000d}},	//   ekil, _zadá, _ipov, _रच्छ, 
   {{0x629801b8,0x31680640,0xb5f002dd,0x61e40139}},	//   _ävol, ишао_, _жүні, fkil, 
   {{0x61e4ae45,0xf1bc01fb,0x74697128,0x682c08cb}},	//   gkil, _nhát_, _кров_, røde, 
   {{0x059404fb,0xf41c0267,0x261800bc,0x67200432}},	// [26450] _رايگ, träd_, नवरी_, _zynj, 
   {{0xdb44168d,0x78a0014b,0x6ee41d37,0x61e49f02}},	//   _لێ_, _mpov, يسال, akil, 
   {{0xd848063f,0x00000000,0x00000000,0x00000000}},	//   _sọl_, --, --, --, 
   {{0x61e57129,0x6dc4027a,0xd8480521,0xf1bd712a}},	//   ckil, غزال, _pọl_, _chát_, 
   {{0x6ab00c4c,0x6ca400c6,0x2bc4047f,0xdb080306}},	//   ंट्र, تصال, लाला, _radá, 
   {{0xdce0054e,0xdb0802f0,0xfe6c0133,0x00000000}},	//   _semă, _sadá, _ڕگه_, --, 
   {{0x78a1712b,0xdb0802fb,0xbb416917,0x3ad001f7}},	//   _apov, _padá, нешк, فيوز, 
   {{0xb05804f3,0xdb21712c,0xb1780158,0x672005b1}},	//   _träd, útán, _blåi, _rynj, 
   {{0xd84801f2,0x6721712d,0xdb0801ed,0xafd8168c}},	//   _fọm_, _synj, _vadá, _støy, 
   {{0x67200652,0x29140952,0x61e401c6,0xdb08011f}},	//   _pynj, ﺰﯨﭗ_, zkil, _wadá, 
   {{0x77c405f5,0x26180ce0,0xc8c80014,0x00000000}},	//   члэг_, नवली_, _گوشن_, --, 
   {{0x2cbc0036,0x61e5712e,0x5c7401ee,0x00000000}},	//   _krud_, xkil, _эҙәр_, --, 
   {{0x6720000f,0x2d9c00e4,0x8cc007f7,0x6a4000e5}},	//   _wynj, _mbue_, लमटो, _hőfo, 
   {{0x6720045f,0x00000000,0x00000000,0x00000000}},	//   _tynj, --, --, --, 
   {{0x61e5712f,0xafd80a64,0x78a000bc,0x00000000}},	//   tkil, _utøy, _zpov, --, 
   {{0xdb08005c,0x00000000,0x00000000,0x00000000}},	//   _fadæ, --, --, --, 
   {{0x61e57130,0x25a04a1f,0x95740092,0x00000000}},	// [26460] rkil, _ibil_, ያናችን_, --, 
   {{0x2d9c013f,0x4abc41ac,0xf1bc007b,0x00000000}},	//   _abue_, ्माव, _bhás_, --, 
   {{0xf1bd7131,0x61e57132,0x00000000,0x00000000}},	//   _phát_, pkil, --, --, 
   {{0x2cbd7133,0x224c00bc,0x01a800cf,0x00000000}},	//   _brud_, ídku_, _укмк_, --, 
   {{0x2cbd7134,0x25a0020b,0xdcb00131,0x00000000}},	//   _crud_, _mbil_, ئىت_, --, 
   {{0xf1bc007b,0x2cbc015d,0xf090010f,0x3c3000e4}},	//   _fhás_, _drud_, _אנש_, kâve_, 
   {{0x78a17135,0xb0580e78,0xf1bce26f,0xd8480051}},	//   _spov, _gräb, _ghás_, _gọj_, 
   {{0x2d9c02e3,0x1dd00e49,0x00000000,0x00000000}},	//   _gbue_, _सचित, --, --, 
   {{0x2cbc0142,0xb05801e3,0x00000000,0x00000000}},	//   _grud_, _träe, --, --, 
   {{0x25a17136,0xbb8401ec,0xe8f407ee,0x567803c5}},	//   _abil_, _ءلاي, яныч_, обоя_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7bd97137,0x25a005c7,0x973c0b4b,0xe94400f2}},	//   _hotu, _cbil_, lećk, _فرهی, 
   {{0x7bd8314a,0x667004d3,0x78a00419,0x00000000}},	//   _kotu, ودێر, _upov, --, 
   {{0x7bd92a70,0x28101fd6,0xa49403e6,0x00000000}},	//   _jotu, _كونس, ریپت, --, 
   {{0x7bd97138,0x41f001e1,0x7c6c0023,0x96f801af}},	//   _motu, _sísọ_, ትብሃል_, _фейт_, 
   {{0xd0117139,0x7bd9713a,0x00000000,0x00000000}},	//   ھلا_, _lotu, --, --, 
   {{0xd0100075,0xc7e80014,0x7bd9713b,0x00000000}},	// [26470] پلا_, _دى۪ن_, _ootu, --, 
   {{0x7bd9713c,0xdb09713d,0xf365713e,0xb05801c7}},	//   _notu, _kadä, _этин, _präb, 
   {{0x0ef80316,0xb0585b00,0xdfd800a7,0xce5806ed}},	//   ्पेस_, _bräc, чът_, цаец_, 
   {{0xdec4044e,0x71700075,0xdb080036,0x2cbc09e2}},	//   _ሸነኽ_, _سۇئا, _madä, _prud_, 
   {{0x7bd9713f,0xdb080793,0xb05805d5,0xd054016b}},	//   _botu, _ladä, _dräc, _ɛbɛk, 
   {{0xd1f80020,0x2cbc0156,0xb0580267,0x00000000}},	//   ፊዎች_, _vrud_, _träb, --, 
   {{0x7bd97140,0xfe6c6071,0xb0583672,0x682c0158}},	//   _dotu, _نگن_, _fräc, jøda, 
   {{0x08c43a33,0x80a000db,0x00000000,0x00000000}},	//   дбин, _سۅۅن, --, --, 
   {{0x7bd97141,0xb1780158,0x95740b82,0x25a00139}},	//   _fotu, _flåv, ያናትን_, _rbil_, 
   {{0xdb080793,0x7bd97142,0x3c3000e4,0x0904004e}},	//   _badä, _gotu, tâve_, зчүм, 
   {{0xff540375,0x2fc401d3,0xda0801e2,0x00000000}},	//   ובתך_, öngy_, _کينه_, --, 
   {{0x2d8c5d1a,0x7bd97143,0xfb1800c8,0xdb5001d9}},	//   ngge_, _zotu, _וועמ, _لَے_, 
   {{0x7bd97144,0xc76400d1,0x00000000,0x00000000}},	//   _yotu, _قاغى, --, --, 
   {{0x682c0158,0x7bd801a9,0xdb08007c,0x82a4009d}},	//   bøda, _xotu, _fadä, магж, 
   {{0x395000d2,0xdb080724,0x00000000,0x00000000}},	//   _însó_, _gadä, --, --, 
   {{0xbbd804fa,0x25a00219,0xf1bc0332,0x787401ee}},	//   _बक्क, _ubil_, _shár_, _эйәр_, 
   {{0xd848063f,0xf1bc0332,0xc514030d,0x00000000}},	// [26480] _rọk_, _phár_, _юькъ, --, 
   {{0x8fd418ce,0x7ce401a9,0x6d5c0784,0x00000000}},	//   нәсә, _tаrz, ñqan, --, 
   {{0x2454eabc,0xb0580ade,0x7bd8b76c,0x0164005b}},	//   _häm_, _präc, _rotu, _окно, 
   {{0x7bd97145,0xfca8004b,0x7d2400f3,0xe16400ec}},	//   _sotu, قاتو_, мфле, _سگري, 
   {{0x7bd97146,0x00000000,0x00000000,0x00000000}},	//   _potu, --, --, --, 
   {{0x2d8c00a7,0x7bd97147,0x24540139,0x00000000}},	//   agge_, _qotu, _mäm_, --, 
   {{0x7bd97148,0xd9117149,0x0ba800c6,0x24540166}},	//   _votu, گیش_, ثانى_, _läm_, 
   {{0x7bd8013b,0x00000000,0x00000000,0x00000000}},	//   _wotu, --, --, --, 
   {{0x7bd9714a,0xd911714b,0x24542a36,0x3941714c}},	//   _totu, دیش_, _näm_, äks_, 
   {{0xdd90021a,0x973c05a1,0xdb180023,0x7bd80393}},	//   _جوړ_, leći, ndvë, _uotu, 
   {{0xd84807ae,0xeb9400d6,0xdb0800fd,0x00000000}},	//   _mọi_, _цих_, _qadä, --, 
   {{0x7c29714d,0x24540036,0xf1bc004d,0xeb30237e}},	//   llfr, _bäm_, _nháp_, _شىند, 
   {{0x24540166,0x00000000,0x00000000,0x00000000}},	//   _cäm_, --, --, --, 
   {{0xd7c800c6,0x24540166,0x44280175,0x682c072b}},	//   _روعه_, _däm_, glb_, lødn, 
   {{0x2d8c708a,0xa2940212,0xdef80023,0x7c283627}},	//   ygge_, карі, _ፈቲኑ_, ilfr, 
   {{0x973c098d,0x442801ab,0x30e402dd,0xf1bc0051}},	//   jeći, alb_, мізб, _cháp_, 
   {{0x973c04b9,0x84c004a9,0x0ef801ad,0x4428014f}},	// [26490] deći, _йәрд, ्प्स_, blb_, 
   {{0x7c2800b5,0xd1580092,0xf2e401af,0x4fc00c75}},	//   jlfr, ያስቸግ, _жюмо, دەسە, 
   {{0xb178ce29,0xc3c00166,0x24540139,0x00000000}},	//   _blåt, _сөял, _zäm_, --, 
   {{0x7bdc0008,0xf1c40131,0x7c280112,0x24540139}},	//   öpun, _تۈرى_, elfr, _yäm_, 
   {{0x415804ae,0x00000000,0x00000000,0x00000000}},	//   _מדרג, --, --, --, 
   {{0x628800e4,0x00000000,0x00000000,0x00000000}},	//   ádog, --, --, --, 
   {{0xd84807ae,0xb1785c04,0xd6d004c5,0x34c82314}},	//   _gọi_, _flåt, ানুপ, ामुद, 
   {{0x7c28010a,0x9f3410da,0x682c005c,0x00000000}},	//   alfr, _ресі, gødn, --, 
   {{0x6d580451,0xdef80023,0xc7940139,0xe5040118}},	//   _ifua, _ፈቲና_, нрны, रपछि_, 
   {{0x24540166,0x00000000,0x00000000,0x00000000}},	//   _räm_, --, --, --, 
   {{0x86c410fe,0x44280175,0x2901714e,0x00000000}},	//   ريحن, vlb_, ńja_, --, 
   {{0x98a002d5,0x2bc52717,0x9a8409a0,0x00000000}},	//   _šią_, लाका, _шуул, --, 
   {{0x6d59714f,0x668013f9,0x00000000,0x00000000}},	//   _mfua, ریکل, --, --, 
   {{0x973c0552,0xdd0c033f,0xb178007c,0xe7840006}},	//   zeći, _różo, _olås, _цудо, 
   {{0x53143306,0xf1bc01dc,0x764c13d5,0x5274f880}},	//   نذِر, _pháp_, íbyt, куту, 
   {{0x3ebc2242,0x6d5802ea,0x4428009f,0xd848004d}},	//   _átti_, _nfua, slb_, _rọi_, 
   {{0x69c97150,0x43757151,0x973c16a3,0x7c28015d}},	// [264a0] _mnge, _пунт, veći, ylfr, 
   {{0xb1797152,0x6d581140,0x9f4c0086,0x3c3000c7}},	//   _slåt, _afua, _ödü_, kâva_, 
   {{0xdcf40552,0x973c0552,0xf1bc001e,0xb17801e6}},	//   đači, teći, _tháp_, _plåt, 
   {{0x7c2800a9,0x69c97153,0x00000000,0x00000000}},	//   wlfr, _nnge, --, --, 
   {{0x973c05ce,0x27081d8a,0xb058007c,0x7bdc01f4}},	//   reći, हपुर_, _träa, öpuo, 
   {{0x69c97154,0xb0597155,0xdb080428,0x63bc0109}},	//   _ange, _krän, _gadû, ndrn, 
   {{0x69c80263,0x7c297156,0xba4401c0,0xeb9400d8}},	//   _bnge, rlfr, нхий, хиј_, 
   {{0x629c54d7,0x9d040166,0xf2d005d0,0xa3b80037}},	//   itro, _иҗек, רעה_, _घोघ_, 
   {{0x8c943bb3,0xbc683cb9,0x629d7157,0x69c8020b}},	//   _архі, _رمان_, htro, _dnge, 
   {{0x69c97158,0x1754016c,0xeb940276,0x693001e0}},	//   _enge, ъвоя, _пиу_, ыныу, 
   {{0x629c009b,0xa3c401ad,0xca740166,0x3ce44831}},	//   jtro, _एफ़_, _аучы, lyov_, 
   {{0x629c01c3,0xf41c0267,0xb3540133,0xb924007b}},	//   dtro, grän_, کیدا_, _كفاي, 
   {{0x37e47201,0x629c9b7d,0xdb081b22,0xa964009b}},	//   _подг, etro, _nadú, _чича_, 
   {{0xb0597159,0x629d715a,0x00000000,0x00000000}},	//   _brän, ftro, --, --, 
   {{0x69c8f5ba,0x629d715b,0x31c4988b,0x00000000}},	//   _ynge, gtro, нсав, --, 
   {{0xb0596d02,0xe5a4009b,0x00000000,0x00000000}},	//   _drän, _бићи, --, --, 
   {{0xb179715c,0x6d5c0784,0x1c2007f7,0xb05801f4}},	// [264b0] _slås, ñqam, मकाल_, _erän, 
   {{0x20843306,0xb059715d,0xa0c40597,0xdb0801e1}},	//   اللّ, _frän, ديكو, _dadú, 
   {{0xb058049f,0xefb80023,0x3a240139,0xca2c00d1}},	//   _grän, _ሰኑይ_, _okop_, ﺩﻩﺭ_, 
   {{0xaa6001e0,0x4278010f,0x00000000,0x00000000}},	//   ңелһ, _קארג, --, --, 
   {{0x973c17a3,0x00000000,0x00000000,0x00000000}},	//   meću, --, --, --, 
   {{0x69c8138f,0xfce1715e,0x3a2403b9,0x3c3000e4}},	//   _snge, рошо, _akop_, tâva_, 
   {{0x9f34005e,0xdea415d6,0x69c80263,0xb178072b}},	//   _бері, _میلی, _pnge, _ulås, 
   {{0x6d5800ec,0x88c8152a,0x3c300124,0x00000000}},	//   _ufua, длив_, râva_, --, 
   {{0x629d715f,0x00000000,0x00000000,0x00000000}},	//   ztro, --, --, --, 
   {{0x3a242f32,0x46e94da4,0x00000000,0x00000000}},	//   _ekop_, ддон_, --, --, 
   {{0x613800d2,0x6f000077,0x00000000,0x00000000}},	//   _kúlí, únch, --, --, 
   {{0xdce00316,0x61380008,0xe4b800d1,0x629c0010}},	//   _nemě, _júlí, нъгә_, vtro, 
   {{0xf41cee1f,0x629c0327,0x00000000,0x00000000}},	//   rrän_, wtro, --, --, 
   {{0x629c7515,0x00000000,0x00000000,0x00000000}},	//   ttro, --, --, --, 
   {{0x629d7160,0x4908190c,0x00000000,0x00000000}},	//   utro, ापको_, --, --, 
   {{0x629c9045,0xf3840240,0x00000000,0x00000000}},	//   rtro, _ንዝክሮ_, --, --, 
   {{0x66057161,0xdb1800d0,0x00000000,0x00000000}},	// [264c0] _imik, rdvé, --, --, 
   {{0xb0580628,0x0fc80034,0x044408b7,0xf0a40c60}},	//   _trän, रागढ, _шепн, ъкул_, 
   {{0xfe412a84,0x443805b1,0xf1bc0241,0x7bdc005b}},	//   لکری, _ihp_, _ikán_, öpum, 
   {{0x443801ab,0xb058007c,0x0ca00092,0xf41400cc}},	//   _hhp_, _kräl, _ሃይሎች_, _দীপৰ_, 
   {{0x22417162,0x7c94084c,0x6e0400d1,0x00000000}},	//   mmik_, трец, خسلە, --, 
   {{0x22417163,0x3a257164,0xfaa57165,0xdce0012c}},	//   lmik_, _skop_, вшин, _země, 
   {{0x44397166,0xeaacf18a,0x66057167,0x19580046}},	//   _mhp_, قعي_, _omik, найы_, 
   {{0x6e9028ee,0xd8497168,0x2bc4df08,0xa9c002bf}},	//   _خلفا, _lọt_, еләп_, аськ, 
   {{0x44391f3e,0x22400869,0x3b9400d8,0x05d4190c}},	//   _ohp_, imik_, _ајет, धानब, 
   {{0x66057169,0x2240020c,0x37a9716a,0xd8480051}},	//   _amik, hmik_, фтин_, _nọt_, 
   {{0xadc001e1,0xaf740a7c,0x00000000,0x00000000}},	//   _ajẹn, כעיס_, --, --, 
   {{0x6f0003b7,0x3a2405be,0x3ebc09f3,0x7c380175}},	//   únci, _ukop_, _áttu_, _hhtr, 
   {{0xf8b4013a,0xd849000b,0x7981716b,0x973c0e04}},	//   _अनिय, _bọt_, _idow, veću, 
   {{0x6605716c,0x443803ee,0x22400429,0xb6c40075}},	//   _emik, _chp_, emik_, _асий, 
   {{0x973c07f5,0x6d5c0784,0x2240022e,0xb05801f4}},	//   teću, ñqak, fmik_, _eräl, 
   {{0xf8b5716d,0xe214f869,0xb0580267,0x443802f0}},	//   _अनाय, амсы, _fräl, _ehp_, 
   {{0x973c08ad,0xa0540220,0x7c39716e,0xd2507138}},	// [264d0] reću, ивті, _ohtr, _گنج_, 
   {{0x22400ad4,0x973c3341,0xdb0800b5,0xd848004d}},	//   amik_, seću, _fadø, _gọt_, 
   {{0x22400d04,0xd5e806d6,0x79800009,0x2bc400b8}},	//   bmik_, huḓ, _odow, लाघा, 
   {{0x7c39716f,0x79817170,0x660400b5,0xb17801e3}},	//   _ahtr, _ndow, _xmik, _glåp, 
   {{0xab0409f3,0xb0596d02,0x629800e4,0xdd957171}},	//   _íbúð_, _kräm, _ãvor, рачы, 
   {{0x7980d5d7,0xf41c0267,0xfcb401ec,0x00000000}},	//   _adow, kräm_, ығуы_, --, 
   {{0x81e4009e,0x9f5803b2,0x6cc001e0,0x6138032e}},	//   _ভগত_, _umrá_, уйҙа, _túlí, 
   {{0x5f7400dd,0x7c38005a,0x596400d1,0x60cc013d}},	//   _ماہر, _ehtr, анъғ, _ülmä, 
   {{0x6e38016c,0x79800042,0x00000000,0x00000000}},	//   _ihub, _ddow, --, --, 
   {{0x79817172,0x6e38014b,0x22411e4e,0x9b9400cf}},	//   _edow, _hhub, zmik_, _ەلەت, 
   {{0x6e380652,0x4438045a,0xd8480051,0x9be4003b}},	//   _khub, _rhp_, _rọt_, _тітк, 
   {{0x44380354,0xdb082d8b,0x6604022e,0xd8480208}},	//   _shp_, _radø, _qmik, _sọt_, 
   {{0x4438010a,0xc7a57173,0x6e387f88,0xe8e80014}},	//   _php_, _билк, _mhub, _تراو_, 
   {{0x66e001e0,0xb7c40055,0x00000000,0x00000000}},	//   _ҡоҙа, _vrãó, --, --, 
   {{0xd848004d,0x68f80083,0x443803b9,0xb058007c}},	//   _vọt_, lzud, _vhp_, _dräm, 
   {{0x66057174,0x22400eda,0xa4955a4c,0x6e38004c}},	//   _umik, umik_, _پیست, _nhub, 
   {{0x22416c97,0xb05804f3,0xd1757175,0x3ea805b1}},	// [264e0] rmik_, _främ, рысы, _spbt_, 
   {{0x6e38a183,0x24801509,0xb1417176,0x442c002d}},	//   _ahub, _ivim_, снул, _óf_, 
   {{0x6e382939,0xd84801f2,0xbd8800c6,0x224003b2}},	//   _bhub, _kọr_, فنان_, pmik_, 
   {{0x7c38069c,0x22400357,0xdd9033d2,0x3c300022}},	//   _shtr, qmik_, زوت_, tâvo_, 
   {{0x6e397177,0x69d97178,0x00000000,0x00000000}},	//   _dhub, djue, --, --, 
   {{0x6e397179,0xf41c0598,0x68f8055a,0x60c43917}},	//   _ehub, yräm_, dzud, mvim, 
   {{0x60c5717a,0x66f000ac,0x09cc015b,0xfca800f1}},	//   lvim, bəkə, িউনা, _ګازو_, 
   {{0x24801326,0xbc741d48,0x6e39717b,0x5a340261}},	//   _ovim_, _مهرب, _ghub, јнит, 
   {{0x26c5717c,0x2018020b,0x6bd00075,0x57f41d83}},	//   _arno_, _kjri_, شتۈر, ипит, 
   {{0x26c5717d,0x60c5717e,0x6e39717f,0x69d8035b}},	//   _brno_, ivim, _zhub, ajue, 
   {{0x26c40bb8,0x60c57180,0xbae400c6,0xf7280262}},	//   _crno_, hvim, _حكاي, эций_, 
   {{0x60c57181,0xdb1805f7,0x7980033f,0x6e38036e}},	//   kvim, ndví, _udow, _xhub, 
   {{0x7ae87107,0xb05803fa,0x57a402dd,0xf1a4ae3e}},	//   lyft, _präm, _ұшқа, һран, 
   {{0xe455001e,0xcd40005e,0x67d00209,0xb19001e0}},	//   скры, ﺭﺩﯨﯔ_, _гошу, өлгә, 
   {{0x77785d42,0x59b80034,0xa758008f,0x60c40393}},	//   matx, _आसार, _אדור, evim, 
   {{0x77797182,0x545519ab,0x20180240,0x37b400cc}},	//   latx, _квит, _ajri_, _অচিৰ, 
   {{0x6e397183,0x659411dc,0x623406ed,0x60c57184}},	// [264f0] _rhub, _اجىر, сету, gvim, 
   {{0x6e397185,0xf3fc0120,0x777801c4,0x9f98009d}},	//   _shub, mpão_, natx, лвуу_, 
   {{0x60c57186,0xf3fc0120,0xb0595407,0xaeb401ec}},	//   avim, lpão_, _kräk, _ءﺑﻴﺪ, 
   {{0x6e381449,0x777801c6,0xdce00205,0xf41c372c}},	//   _qhub, hatx, _acmı, kräk_, 
   {{0x6e3806d6,0x66f003be,0x7778009d,0xac880023}},	//   _vhub, rəkə, katx, _ነውራም_, 
   {{0xdd94005e,0x8c457187,0x68f8298d,0x777801a9}},	//   _қауы, шеле, vzud, jatx, 
   {{0x6e397188,0x09f4f01f,0x4ab8084c,0x77786f34}},	//   _thub, ичия, туля_, datx, 
   {{0x6e3800ca,0x1a6923dd,0x68f801c7,0xf41c0139}},	//   _uhub, اینی_, tzud, fräk_, 
   {{0xf41c0724,0x682c28b3,0x26c40427,0xf1bc01e1}},	//   gräk_, lødi, _srno_, _maá_, 
   {{0x48040acf,0x26c4c3c8,0x7778009d,0xf1bd7189}},	//   рпов, _prno_, gatx, _skál_, 
   {{0x24801326,0xc30802a6,0x60c40e8a,0x68f85d8b}},	//   _svim_, _শুনি_, zvim, szud, 
   {{0xf41c0724,0xf1bc01e1,0x00000000,0x00000000}},	//   bräk_, _naá_, --, --, 
   {{0xb0580267,0x777801c4,0xf4f000b8,0x00000000}},	//   _dräk, batx, _āśāṃ_, --, 
   {{0xb0584132,0xdb1800d7,0x00000000,0x00000000}},	//   _eräk, zdví, --, --, 
   {{0xf1bc01e1,0x26c53b37,0x06740334,0xb05801e3}},	//   _baá_, _urno_, _туля, _fräk, 
   {{0x60c41326,0xd848001e,0xd90c07d6,0xdb0802fb}},	//   tvim, _họp_, _آیی_, _nadý, 
   {{0xb88401e1,0xc00400c0,0x506400ae,0x00000000}},	// [26500] _idíó, апак, مطلق, --, 
   {{0x60c5718a,0x3f6801d5,0x48dc0037,0x70500271}},	//   rvim, тижо_, _कऊनो_, آنلا, 
   {{0x60c5718b,0xf1bc0418,0x682c01bf,0x6fdc03ce}},	//   svim, _faá_, rødh, पॉइं, 
   {{0x7778009d,0x00000000,0x00000000,0x00000000}},	//   zatx, --, --, --, 
   {{0xf53c5b47,0xf1bc01fb,0x60c54999,0x113800c0}},	//   leår_, _nháy_, qvim, _бяры_, 
   {{0x22b8007f,0x7778005a,0x682c2b96,0x1c38013d}},	//   _kōk_, xatx, bødi, ызлы_, 
   {{0x1dc40b8d,0x2b74970b,0x7778004e,0x00000000}},	//   _гөлн, شینگ_, vatx, --, 
   {{0xfce40137,0x7ae80af9,0x00000000,0x00000000}},	//   _кобо, ryft, --, --, 
   {{0xf1bc0016,0x77795155,0xb8640fb4,0xcdf401c6}},	//   _cháy_, tatx, جابو, _учры, 
   {{0x57f5718c,0xd848004d,0xb0580112,0x9f5800a2}},	//   спот, _cọp_, _dräh, _umrä_, 
   {{0xb059718d,0x77784eb0,0x2bb001f9,0x8b6400ae}},	//   _eräh, ratx, ंजरा, _طالم, 
   {{0x7779718e,0xdb0807c5,0x645800d7,0x00000000}},	//   satx, _madü, _čvir, --, 
   {{0x77780bc9,0x69f8008f,0x8a44036b,0xb0580267}},	//   patx, _בלאק, _ائلم, _vräk, 
   {{0x7791718f,0xf3fc0120,0x08fc0154,0x7bcd7190}},	//   _بیدا, rpão_, _উঁচু_, _óbud, 
   {{0xf8b42429,0xa5c4068f,0xb0597191,0xf53c05ac}},	//   _अनुप, _spół, _iräi, geår_, 
   {{0xd4b85336,0x38657192,0xb400009d,0xdc840023}},	//   _блиц_, _ktor_, сүүд, _ነፍሰይ_, 
   {{0xb0580221,0xfbc407b7,0x00000000,0x00000000}},	// [26510] _kräi, लयाम, --, --, 
   {{0xdb080793,0x22b80100,0x00000000,0x00000000}},	//   _badü, _fōk_, --, --, 
   {{0xf1bd7193,0x00000000,0x00000000,0x00000000}},	//   _taá_, --, --, --, 
   {{0x682d6f8a,0xf8b41b6e,0x00000000,0x00000000}},	//   rødi, _अनूप, --, --, 
   {{0xdc9800d4,0x00000000,0x00000000,0x00000000}},	//   ивці_, --, --, --, 
   {{0x22b8007f,0xf41c0036,0xa92002f0,0x4a4400d1}},	//   _yōk_, fräi_, _úžin, әнив, 
   {{0x38657194,0xdce00139,0x00000000,0x00000000}},	//   _ator_, _temğ, --, --, 
   {{0xf7703ce1,0x8c4401e0,0xb0582305,0x682c5522}},	//   ۋاپ_, шеһе, _präh, nødv, 
   {{0xd848063f,0xb05804e6,0x3864003a,0x07a40139}},	//   _pọp_, _bräi, _ctor_, бапн, 
   {{0xdb080429,0x386001a8,0x00000000,0x00000000}},	//   _cadó, íkra_, --, --, 
   {{0xb0580221,0x3864009d,0x07a57195,0xd8480208}},	//   _dräi, _etor_, _ғайн, _vọp_, 
   {{0x3864022e,0xb0597196,0xf53c1347,0xdb080332}},	//   _ftor_, _eräi, veår_, _eadó, 
   {{0xb05804c4,0xdb080332,0xb3400213,0x00000000}},	//   _fräi, _fadó, əçis, --, 
   {{0xd054013f,0xb0580221,0x1de4134e,0x04440b96}},	//   _ɛbɔk, _gräi, _कक्ष_, сегн, 
   {{0xb7d80375,0xd7600345,0x00000000,0x00000000}},	//   _תקצי, _تۆپی, --, --, 
   {{0x16640014,0x38640267,0xf53c00cc,0xdb1800e5}},	//   _باوَ, _ytor_, reår_, ndvá, 
   {{0x65640cad,0x38640175,0xbb4c0220,0x00c876b8}},	// [26520] _ifih, _xtor_, _ﺍﻟﻤ_, ылак_, 
   {{0xdb080ba1,0x70804258,0x6f1800cd,0x00000000}},	//   _madò, ягуз, _śuca, --, 
   {{0x44297197,0xc2c46248,0xb0580139,0x88ac0154}},	//   mob_, _ايجي, _asäd, কটিক, 
   {{0x44297198,0x82341c93,0x00000000,0x00000000}},	//   lob_, _درخا, --, --, 
   {{0x65640921,0x44297199,0xfb84013d,0x1cd80139}},	//   _mfih, oob_, быйн, рдлы_, 
   {{0x4429719a,0x8fd40724,0x6bd00c50,0x200d441f}},	//   nob_, _мәхә, كتىر, _ödi_, 
   {{0xde4400c6,0x6565719b,0x7ac5719c,0xdb080332}},	//   _мσмɪ_, _ofih, ссле, _radó, 
   {{0xada016a4,0x4428ad8c,0x6da0026a,0xbe1401d3}},	//   _насл, hob_, _ниса, _اورع, 
   {{0x4429719d,0xb0580a40,0x224c00bc,0x3cf000cc}},	//   kob_, _präi, ídky_, øyvd_, 
   {{0x4429719e,0x6565719f,0x3f980978,0x0ba80131}},	//   job_, _afih, ngpu_, _نامى_, 
   {{0x442971a0,0x6bd4004b,0x7bdc0037,0xdb080118}},	//   dob_, _دولس_, öpuu, _obdé, 
   {{0x7c2971a1,0xa2cc6236,0x3864005a,0xb3440798}},	//   lofr, हिन्, _ttor_, _loçõ, 
   {{0x442971a2,0xb05971a3,0xdce000de,0x6fd828e0}},	//   fob_, _träi, _iemē, नामू, 
   {{0xb05804f3,0x442971a4,0x656571a5,0xb3440120}},	//   _kräv, gob_, _efih, _noçõ, 
   {{0x6fd40490,0xb86403e6,0xdb0802e2,0xe2f855dd}},	//   ठासं, _ئاڵو, _zadò, бері_, 
   {{0x7790d653,0x7c280142,0x10900220,0x00000000}},	//   _بیگا, hofr, _ﺟﻪﺭﯨ, --, 
   {{0x442971a6,0x7c28005c,0x456001d9,0xf0b80214}},	// [26530] bob_, kofr, _تھپہ, دازش_, 
   {{0xd5a40574,0xa3b0eb47,0x442971a7,0x673003b2}},	//   ग्रज, _टॉप_, cob_, _ódjó, 
   {{0xdb182b96,0x00000000,0x00000000,0x00000000}},	//   ldvæ, --, --, --, 
   {{0xf1bc0022,0xa698008f,0x78a001a9,0xd0d402e8}},	//   _okái_, רשאפ, _oqov, _домъ, 
   {{0xdb1804ce,0xad240345,0x00000000,0x00000000}},	//   ndvæ, حراو, --, --, 
   {{0x7c280042,0xdb080100,0xdd9800c7,0x00000000}},	//   gofr, _radò, ашә_, --, 
   {{0x1a6804fb,0xdb080100,0x00000000,0x00000000}},	//   میلی_, _sadò, --, --, 
   {{0x08880aae,0xb05800fd,0x4428022e,0x00000000}},	//   абий_, _isäb, zob_, --, 
   {{0x442971a8,0xb058005b,0xab940354,0x00000000}},	//   yob_, _eräv, _лăпк, --, 
   {{0x6e2971a9,0x068571aa,0x2cbd71ab,0x7e680066}},	//   logb, огон, _isud_, _èmpè, 
   {{0x442971ac,0x38c8034c,0xb05801e6,0xd1e00092}},	//   vob_, هایی_, _gräv, ነሱት_, 
   {{0x2cbc0055,0x00000000,0x00000000,0x00000000}},	//   _ksud_, --, --, --, 
   {{0xb05803fa,0x682c1512,0x598402bf,0x00000000}},	//   _kräu, født, _хліб, --, 
   {{0x1cb8031c,0xd874eead,0xdce000e2,0x682c03b2}},	//   _མགལ_, _راهب, _zemē, tødu, 
   {{0x442971ad,0x27e400a3,0xfbd00375,0x00000000}},	//   rob_, _ionn_, ותם_, --, 
   {{0x442971ae,0x65640117,0x27e571af,0x2cbc13d5}},	//   sob_, _ufih, _honn_, _osud_, 
   {{0x27e4434d,0xe730013f,0x3fe423b3,0xdd940724}},	// [26540] _konn_, _hyε_, ожав, җалы, 
   {{0x27e571b0,0x7c2971b1,0x4428dab2,0xe18800fb}},	//   _jonn_, xofr, qob_, шөүе_, 
   {{0x27e571b2,0x2cbc0037,0xf1bc0118,0xca3001ec}},	//   _monn_, _asud_, ášce_, _ﺭﻭﺡ_, 
   {{0x27e407ab,0x5eac00bd,0x9a44002b,0xee3464cb}},	//   _lonn_, ছিলে, _oṣṭh, онх_, 
   {{0xb059113c,0x7c2971b3,0x25a00421,0x203400dd}},	//   _bräu, tofr, _mcil_, _فہرس, 
   {{0xa3b006ab,0xfa880075,0x27e45dad,0xb0580ade}},	//   _टॉम_, асий_, _nonn_, _präv, 
   {{0x2cbc0998,0xe730013f,0xb05801c7,0xd5dc0764}},	//   _esud_, _nyε_, _dräu, यामज, 
   {{0x7c2971b4,0x25a01529,0x987571b5,0xb05804e6}},	//   sofr, _ncil_, плиц, _eräu, 
   {{0xe730013f,0x3b8400c7,0x682c143a,0xb0580112}},	//   _ayε_, _млаг, jøds, _fräu, 
   {{0x25a003ee,0x682c143a,0x27e46b41,0xb05971b6}},	//   _acil_, døds, _conn_, _gräu, 
   {{0x27e51c5c,0x25a0004e,0x625801e4,0x2f5808a8}},	//   _donn_, _bcil_, _lŭob, ידינ, 
   {{0xf608134c,0x27e4020b,0x3dc4b183,0xb05971b7}},	//   рхой_, _eonn_, ndow_, _krät, 
   {{0x7d0171b8,0x27e571b9,0xe730013f,0x58d400ee}},	//   nzos, _fonn_, _eyε_, _холт, 
   {{0x27e4061c,0x7d00004c,0xdb18005c,0x00000000}},	//   _gonn_, izos, rdvæ, --, 
   {{0x320971ba,0xaee00055,0x918801e0,0xf41d489f}},	//   ахан_, _dvṛc, йраҡ_, drät_, 
   {{0x27e4662e,0xb0580267,0xf41c01f4,0x926800fb}},	//   _zonn_, _orät, erät_, ирға_, 
   {{0x27e40d29,0x3dc4da46,0x682c00ed,0xdd1c00d0}},	// [26550] _yonn_, ddow_, mødr, yššo, 
   {{0x7d000433,0x2cbc01f9,0xb61802dd,0xb4c403ba}},	//   dzos, _rsud_, _ﹼﻲ_, ईटी_, 
   {{0xa2cc0574,0xdb195403,0x7ea001f2,0x53340d1d}},	//   हिण्, ndvä, _ọpre, _хент, 
   {{0xb0581196,0x5f2571bb,0x00000000,0x00000000}},	//   _brät, ффуз, --, --, 
   {{0x6e2971bc,0xcb680354,0xf41c0166,0x00000000}},	//   rogb, бале_, brät_, --, 
   {{0x3dc4058a,0xf41c0139,0x00000000,0x00000000}},	//   adow_, crät_, --, --, 
   {{0x27e40a40,0x9f340046,0x3dc4058a,0xb0580108}},	//   _ronn_, _жері, bdow_, _erät, 
   {{0x27e571bd,0xb05801e3,0x00000000,0x00000000}},	//   _sonn_, _frät, --, --, 
   {{0xb0580e78,0x27e571be,0xa964013e,0xe79000f1}},	//   _träu, _ponn_, биқа_, وادک, 
   {{0x25a171bf,0xec2000cf,0x9b887b8f,0x00000000}},	//   _scil_, _تۉتپ, _ونقل_, --, 
   {{0x1cb8038f,0xb05971c0,0x27e405d5,0xca2c00d1}},	//   _མགོ_, _kräs, _vonn_, ﺩﻩﺕ_, 
   {{0x27e54a2d,0x00000000,0x00000000,0x00000000}},	//   _wonn_, --, --, --, 
   {{0x98c00022,0xbb4c02dd,0xb60402d2,0xf41c07d9}},	//   _аҩыж, _ﺍﻟﻰ_, _snáð, yrät_, 
   {{0x27e41570,0x682c21e3,0xd7c8015e,0x7a3c0200}},	//   _uonn_, røds, _وونه_, mëta, 
   {{0x7d0171c1,0x1cd4025c,0x2bd0012d,0x29fc0210}},	//   zzos, ེའོ_, _दफना, ałaś_, 
   {{0xc484bba2,0xdddc3a4a,0x80640826,0x0ae80c58}},	//   _елик, _ovrš, зваж, _কেৱল_, 
   {{0xc0e002d3,0xf41c1900,0x7a3c0200,0x00000000}},	// [26560] _ነይራ_, trät_, nëta, --, 
   {{0xd9b971c2,0x3dc40597,0xc0e0044e,0xdb180158}},	//   _आस्ट, wdow_, _ነይረ_, ldvå, 
   {{0x7a3c0023,0xf41c4022,0x7374008f,0x705064c8}},	//   hëta, rrät_, _מגיד_, رنما, 
   {{0xb0584562,0xdb186afa,0xc20801b9,0x7a3d71c3}},	//   _prät, ndvå, _چقگن_, këta, 
   {{0x61e571c4,0x7a3c0200,0x00000000,0x00000000}},	//   mjil, jëta, --, --, 
   {{0x7d0171c5,0xb058005b,0x386002f0,0x00000000}},	//   rzos, _eräs, íkrm_, --, 
   {{0xc0e0069c,0xb0585382,0x61e401f4,0x7d000827}},	//   _ነይሩ_, _fräs, ojil, szos, 
   {{0xb05971c6,0xf9900b73,0x58d44411,0xdb180200}},	//   _gräs, ربع_, доит, levë, 
   {{0xa96403b7,0x9f580156,0x672004ce,0x7a3c036e}},	//   чиња_, _alré_, _axnj, gëta, 
   {{0x61e4023a,0xdb18036e,0x00000000,0x00000000}},	//   hjil, nevë, --, --, 
   {{0xdddc00d0,0x00000000,0x00000000,0x00000000}},	//   _zvrš, --, --, --, 
   {{0xaad80302,0xdb080793,0x61e51111,0xdb186da3}},	//   _לחבר, _badö, jjil, rdvä, 
   {{0x61e4a104,0x600006be,0x682c072b,0x00000000}},	//   djil, _gömg, rødr, --, 
   {{0x56940372,0xddc001e4,0xdb180240,0x00000000}},	//   _жакт, _rimŝ, jevë, --, 
   {{0x61e40b21,0xb188084c,0x244401e3,0xdddc00d7}},	//   fjil, йсаж_, dömd_, _turň, 
   {{0x61e40023,0xd31c0073,0xdb18035b,0x00000000}},	//   gjil, _नशीब_, tevê, --, 
   {{0x2fc400d2,0xc1a400c7,0x00000000,0x00000000}},	// [26570] ôngo_, ьырқ, --, --, 
   {{0xdb4571c7,0xa3d404fa,0x8c3c008e,0x6440026c}},	//   _مێ_, _सोप_, _aqşn, ïmit, 
   {{0xb058958c,0xdddc08a4,0x1cb8025c,0x61f80789}},	//   _präs, _svrš, _མགུ_, ñalá, 
   {{0xdb186ede,0x00000000,0x00000000,0x00000000}},	//   mevè, --, --, --, 
   {{0xdb180036,0x4ecc009e,0xd838007f,0xb05801f4}},	//   bevë, লহেল, klč_, _erär, 
   {{0x3cf005ac,0x027c0118,0x7dd001a9,0x00000000}},	//   øyva_, říže_, sаsа, --, 
   {{0x1cd4003d,0x600001e6,0xb05801e6,0xcb4000a2}},	//   ེའུ_, _dömd, _träs, _galь, 
   {{0xa3d42017,0xdce00024,0x7bcc03f2,0x00000000}},	//   _सोन_, _nemė, _óbun, --, 
   {{0xdddc1a48,0xac740150,0x75fc01d5,0xdb18007f}},	//   _uvrš, _ءارش, _oëzb, hevè, 
   {{0x600171c8,0xd8380100,0xea600150,0x7a3c2568}},	//   _gömd, glč_, _كۇتپ, rëta, 
   {{0x4ac02ecf,0xf42000bd,0x7a3c0023,0x79e801d9}},	//   _शनिव, ফতার_, sëta, _ڈولہ_, 
   {{0xdb080793,0x7a3c02d3,0xa2cc878d,0x00000000}},	//   _padö, pëta, हिस्, --, 
   {{0x6b80009f,0x07a45211,0xf9a000c7,0x490415bf}},	//   oang, _жалн, _рқыҭ, _توشق, 
   {{0x60010b4e,0x1ae4015b,0x482400db,0xd4540212}},	//   _köme, _কেটে_, _تىتق, етсь, 
   {{0x6d5971c9,0xf41c0036,0xb7d4009f,0x00000000}},	//   _ogua, trär_, _زويا_, --, 
   {{0x6b8171ca,0x6d5971cb,0x2444049f,0x61e4002d}},	//   hang, _ngua, döme_, ujil, 
   {{0xfd54063f,0x61e571cc,0xbfc400f3,0xf41c0108}},	// [26580] _dibị, rjil, мбак, msän_, 
   {{0x6d58fa35,0x6b8171cd,0xb14031d5,0x61e4000f}},	//   _agua, jang, тнул, sjil, 
   {{0x63bd71ce,0xf8d804fa,0xa3d40490,0x61e4000f}},	//   mern, _बप्प, _सोय_, pjil, 
   {{0x63bd71cf,0xb0585d8a,0xf41c014a,0x40940229}},	//   lern, _isän, nsän_, _оргт, 
   {{0x6b8171d0,0x6c800131,0xd2000c75,0xf41c005b}},	//   fang, پلىم, _сүтк, isän_, 
   {{0x63bc5666,0x6b8171d1,0x6d5971d2,0xa3d4a4cd}},	//   nern, gang, _egua, _सोम_, 
   {{0x63bc1445,0xf41cadae,0x60000790,0x8eb000db}},	//   iern, ksän_, _cöme, _مەلت, 
   {{0x63bc1486,0x60000267,0xb0580254,0xa3b003ce}},	//   hern, _döme, _kräp, _टॉस_, 
   {{0x629d71d3,0x6b8171d4,0x63bcfcc6,0x60000267}},	//   huro, bang, kern, _tömd, 
   {{0x63bc0627,0xdb1971d5,0xbb8408f0,0xa84400ec}},	//   jern, hevé, _آلاي, وليم_, 
   {{0x6d5800c7,0xfdf000c5,0x600171d6,0xb5940014}},	//   _ygua, _अकास_, _göme, وٝدچ_, 
   {{0x629d71d7,0x28114a78,0xd838007f,0xdb1800e4}},	//   duro, _یونس, slč_, jevé, 
   {{0x1cd40ed9,0xe9f400d6,0xd5a406ab,0x629d71d8}},	//   ེའི_, _інші_, ग्गज, euro, 
   {{0x63bc1fcd,0xf41c01b8,0x629c01b4,0x17ac03d4}},	//   gern, asän_, furo, _কোৰি, 
   {{0x7a3c02d3,0x7bd80270,0xe45407d8,0x64540640}},	//   nëto, _mntu, ткры, тврђ, 
   {{0xf1bc00dd,0xca200131,0x8c3c0166,0x10c401c6}},	//   _akár_, ﺸﻘﺎ_, _aqşl, нөго, 
   {{0x63bd71d9,0x7bd8016b,0x909806bb,0x7e6c0280}},	// [26590] bern, _ontu, яват_, _atbp, 
   {{0x63bd71da,0x6d584d72,0x629d71db,0x6b8171dc}},	//   cern, _sgua, buro, xang, 
   {{0x629c042f,0xb05931e4,0x8d94007b,0xfbe00b98}},	//   curo, _eräp, فلاش, पानम, 
   {{0x6b8171dd,0x60000e78,0x24440112,0x8eb000cc}},	//   wang, _röme, röme_, ছিলগ, 
   {{0x7bd80a2e,0xcb6946d3,0xb0580036,0x60001ea0}},	//   _bntu, пале_, _gräp, _dömb, 
   {{0x6b800093,0x7bc8002d,0xd1f8001f,0xcb684f0c}},	//   uang, gdfu, ጊዎች_, чаке_, 
   {{0xf41c0716,0x7a3c0023,0xfb8408dc,0x60000139}},	//   ysän_, gëto, ردوی, _qöme, 
   {{0x6d5971de,0x7bc8136c,0x08c422bf,0x600171df}},	//   _ugua, adfu, ебин, _gömb, 
   {{0x63bd71e0,0x629d71e1,0x278400f7,0x00000000}},	//   yern, zuro, үрүү_, --, 
   {{0x6b8171e2,0x629c0163,0x600001ed,0x7a3c0240}},	//   qang, yuro, _töme, bëto, 
   {{0x63bd71e3,0xc9581acc,0x629ceb82,0xf41c005b}},	//   vern, _فلاش_, xuro, tsän_, 
   {{0x629d71e4,0x63bd71e5,0xdb0c0248,0x64a40022}},	//   vuro, wern, _ìhám, ҭаҟа, 
   {{0xdb18ec21,0x7bd8045f,0x97c4eb7d,0xdb500050}},	//   vevé, _yntu, رتیم, _مَے_, 
   {{0x27b01fc7,0xa2cc0490,0x63bc67c4,0xc7a571e6}},	//   _рәис, हिल्, uern, _чикк, 
   {{0x63bd71e7,0xdb185ed5,0xca2000d1,0xf41c0108}},	//   rern, tevé, ﺸﺘﺎ_, psän_, 
   {{0x63bd71e8,0xb05971e9,0x00000000,0x00000000}},	//   sern, _präp, --, --, 
   {{0x629d71ea,0x36180375,0x9418013f,0x95a40022}},	// [265a0] suro, _מוקד, ntsɛ_, _рлыҵ, 
   {{0xdb18ec21,0x63bd71eb,0xb058005b,0x60000166}},	//   sevé, qern, _isäl, _sömb, 
   {{0x39980790,0xdb1800c7,0xfe700966,0x7c242507}},	//   nüsü_, pevé, ادئ_, _íkri, 
   {{0xb05971ec,0xfe409f6d,0x00000000,0x00000000}},	//   _träp, اکسی, --, --, 
   {{0xdce0005f,0x600171ed,0x6e20003e,0x6a6403e0}},	//   _iemī, _cömc, énba, _rıfa, 
   {{0x6a6405d1,0x39980790,0x70cc00e4,0x7a3c036e}},	//   _sıfa, küsü_, _ñehẽ, tëto, 
   {{0x7bc971ee,0x1cd40327,0xdb180162,0x6000a40b}},	//   rdfu, ེའང_, ndvø, _tömb, 
   {{0x6d480129,0x883001d3,0x58d80b01,0x39980205}},	//   élaï, یکوئ, ддия_, düsü_, 
   {{0xdddc1bce,0xdbc40022,0xbb4c0220,0x7a3c0200}},	//   _jurō, _иааҩ, _ﺍﻟﻌ_, sëto, 
   {{0x7bd971ef,0x7a3c02d3,0xf090011a,0x040c0051}},	//   _untu, pëto, ננת_, rườn, 
   {{0x290971f0,0x8b640014,0x0ba801ec,0x666000fd}},	//   úcar_, _شالم, _تاقى_, лъяз, 
   {{0xb86402ef,0xdce000de,0x00000000,0x00000000}},	//   _كاتو, _nemī, --, --, 
   {{0xdddc00e8,0x09a80154,0x00000000,0x00000000}},	//   _nurō, _খোকা, --, --, 
   {{0x399805d1,0x6f980150,0x36882cdd,0x00000000}},	//   büsü_, _ﻀﺩﻫﺎ_, _есин_, --, 
   {{0x2fdc01fa,0x39981ae4,0xdb1803b2,0x6d5c022e}},	//   _đug_, cüsü_, gdvø, оqal, 
   {{0xb40031ee,0x28b45572,0x00000000,0x00000000}},	//   түүд, _अहमि, --, --, 
   {{0x64a41677,0xd6d80214,0xbb4c0150,0xf41c0139}},	// [265b0] _бања, _روکش_, _ﺍﻟﻔ_, lsäm_, 
   {{0x798000b5,0x251c00df,0x00000000,0x00000000}},	//   _leow, _מוחא, --, --, 
   {{0xb05971f1,0xc3c0013d,0x00000000,0x00000000}},	//   _isäm, _төял, --, --, 
   {{0x321c3d27,0x79804663,0xf08001d3,0x00000000}},	//   _ñuy_, _neow, _میرپ, --, 
   {{0xc0c00032,0x00000000,0x00000000,0x00000000}},	//   _вәхи, --, --, --, 
   {{0x79800428,0x39980790,0xdce00171,0x00000000}},	//   _aeow, yüsü_, _zemī, --, 
   {{0x244401b8,0x4dc401ee,0x00000000,0x00000000}},	//   nöma_, _ираҡ, --, --, 
   {{0x9f342626,0x09bc00dc,0xabb00124,0x00000000}},	//   _сесі, ्येय, _әажә, --, 
   {{0x600000b0,0xdd94010b,0x00000000,0x00000000}},	//   _höma, _щаты, --, --, 
   {{0x399805d1,0x29000024,0x8c18007b,0x00000000}},	//   tüsü_, ąja_, _غيار_, --, 
   {{0xd5dc00af,0xb17801e3,0x00000000,0x00000000}},	//   यांज, _knåd, --, --, 
   {{0x798045a7,0x244401e6,0x39981432,0x391001d3}},	//   _geow, döma_, rüsü_, اویز, 
   {{0x69c86d27,0x60000254,0x76200276,0xa4c00205}},	//   _iage, _löma, рмяз, _düşü_, 
   {{0x68040241,0x04440021,0x9984033f,0xf1bc1d1d}},	//   _déjù, тегн, kimś_, _skáp_, 
   {{0x69c8ef64,0x66d4063f,0xa82000dd,0x00000000}},	//   _kage, _ịko, _لکھن, --, 
   {{0x850403e6,0x00000000,0x00000000,0x00000000}},	//   _لوبن, --, --, --, 
   {{0x85b82927,0x00000000,0x00000000,0x00000000}},	// [265c0] _فاکس_, --, --, --, 
   {{0x69c971f2,0x24800086,0x74980a7c,0x261801f9}},	//   _lage, _iwim_, _קייפ, _पगडी_, 
   {{0x2480013f,0x69c804ba,0x62240617,0x00000000}},	//   _hwim_, _oage, _مودە, --, 
   {{0xbf201f5e,0x77ec0490,0x60000267,0x008408ca}},	//   _मशीन_, _चक्क_, _döma, _илмо, 
   {{0x6da171f3,0x69b400dc,0x312000d4,0xdb2003e0}},	//   рича, ्जनी, _вдяг, ştül, 
   {{0x60c48aa7,0x69c806f2,0x6bd00202,0x7980020b}},	//   mwim, _aage, لتىر, _seow, 
   {{0x60c571f4,0x7980030a,0x00000000,0x00000000}},	//   lwim, _peow, --, --, 
   {{0x69c971f5,0x5fe04f71,0xc87800ee,0x00000000}},	//   _cage, नावल, lyşy_, --, 
   {{0x69c84495,0x26c51d68,0xfebc0150,0xfca80451}},	//   _dage, _asno_, _ءﺗﯘﺱ_, _تازو_, 
   {{0xdb18a568,0xb8e80037,0x69c86853,0xec4400d8}},	//   leví, _लन_, _eage, _азул_, 
   {{0x0ba87d5d,0x60c571f6,0xe7e14dc5,0xb9c401b9}},	//   _سالى_, hwim, _कचरा_, _аёли, 
   {{0x69c971f7,0x60c571f8,0x00000000,0x00000000}},	//   _gage, kwim, --, --, 
   {{0xa88400db,0xc878010b,0x00000000,0x00000000}},	//   _айча_, kyşy_, --, --, 
   {{0x69c971f9,0x544571fa,0x94441370,0x24800042}},	//   _zage, انسك, اپسن, _dwim_, 
   {{0x69c80a03,0xdb180120,0xf1a571fb,0x44b002dd}},	//   _yage, levâ, кран, _құрс, 
   {{0xe61000aa,0x69c8de24,0xdb180118,0x00000000}},	//   _وشي_, _xage, jeví, --, 
   {{0xa1840daf,0xc6740092,0x60c4025c,0x00000000}},	// [265d0] рысл, _የተሳካ_, gwim, --, 
   {{0x3944107d,0xb058005b,0x6e380092,0x601c007c}},	//   _mzos_, _isäk, _እባካች, våmä, 
   {{0xf1a8033f,0x60c40009,0x05a81777,0x00000000}},	//   _छापन, awim, _कामब, --, 
   {{0xfd6401f2,0x3a240263,0x60c40526,0x9db80166}},	//   _izuụ, _njop_, bwim, вышу_, 
   {{0x9c6401b9,0xc198008d,0xf1bc03b2,0xe0e401d5}},	//   لهنو, _אשרי, _gjáa_, _кўро, 
   {{0x69c971fc,0xdea407d6,0x5f747f51,0x40d8008f}},	//   _sage, _چیلی, _نافر, _אַלײ, 
   {{0x69c971fd,0x39440077,0xdea4035c,0x5d8400db}},	//   _page, _azos_, _نیلی, الۇل, 
   {{0xb058049f,0xb1780158,0x88c8c2f3,0x09e0015b}},	//   _osäk, _unåd, елив_, বস্থ, 
   {{0x69c971fe,0xf1a8256a,0x06ac03d4,0x00000000}},	//   _vage, _छानन, গিছি, --, 
   {{0xe86001c0,0x46e8180b,0x06e8a3f8,0x00000000}},	//   лхүү, едон_, емок_, --, 
   {{0x69c971ff,0x2480123b,0x87c401d9,0x7a3c036e}},	//   _tage, _swim_, نتھٕ, këth, 
   {{0xd90c01e2,0x00000000,0x00000000,0x00000000}},	//   _ښیي_, --, --, --, 
   {{0x8c3c03e3,0x27b001ee,0x87d4022e,0x00000000}},	//   _aqşi, _кәнс, _бўйч, --, 
   {{0x37e009a5,0xb890007b,0x00000000,0x00000000}},	//   _гошг, _الوع, --, --, 
   {{0x75fc02d3,0x41b404ad,0x60c405b1,0x3d1877d7}},	//   _gëzo, лсат, wwim, _मेने_, 
   {{0x60c43a41,0xa3d400c5,0xb6b80375,0xc644009f}},	//   twim, _सोर_, _נצפי, _حَبي, 
   {{0x66057200,0x845806d4,0x360001d9,0x324013d6}},	// [265e0] _ilik, _прот_, _طوٝف, сетг, 
   {{0x7f857201,0x60c40223,0x6604030a,0xdb940023}},	//   الان, rwim, _hlik, _ዘሎዎም_, 
   {{0x60c57202,0x44397203,0x80b400c5,0xfbe02c2e}},	//   swim, _ikp_, _उहवे, पासम, 
   {{0xd1741e76,0x3ce4004e,0x60c4007f,0x00000000}},	//   _выры, txov_, pwim, --, 
   {{0x22417204,0xccf57205,0x66057206,0xb17828b3}},	//   mlik_, ақт_, _mlik, _toår, 
   {{0x22405a79,0x66040bf1,0x44381050,0x3e840597}},	//   llik_, _llik, _jkp_, _مشرف, 
   {{0x66057207,0x44397208,0xcd280075,0x629c0077}},	//   _olik, _mkp_, ىسۇن_, nrro, 
   {{0x22417209,0x77780218,0x6605720a,0x629c005b}},	//   nlik_, wbtx, _nlik, irro, 
   {{0x2241720b,0x2df40375,0x44380841,0xb865720c}},	//   ilik_, _עצמך_, _okp_, دابو, 
   {{0x37a874be,0x224007d6,0x66052403,0x443881ba}},	//   хтин_, hlik_, _alik, _nkp_, 
   {{0x2241720d,0x7a3c02d3,0xf1bc01f1,0x3a240af9}},	//   klik_, hëti, ššie_, _tjop_, 
   {{0xca400597,0x660521dc,0x4439720e,0x16341214}},	//   _мŝя_, _clik, _akp_, ремя, 
   {{0x2241720f,0x6604026c,0x394400df,0x629d7210}},	//   dlik_, _dlik, _uzos_, erro, 
   {{0x22417211,0x44380092,0x600001e6,0x2444007c}},	//   elik_, _ckp_, _sömn, sömn_, 
   {{0x66057212,0x731801e1,0x66e000ea,0x62880022}},	//   _flik, _bìjẹ, _гоја, ádop, 
   {{0x22417213,0x6fa403f3,0x443826bb,0xa18401e0}},	//   glik_, _चाहू, _ekp_, йыул, 
   {{0x7c380b21,0x629d7214,0x7a3c0240,0x69b402c3}},	// [265f0] _oktr, arro, gëti, ्जती, 
   {{0x22417215,0x660444ef,0x96a8012c,0x44380153}},	//   alik_, _zlik, _कमाउ, _gkp_, 
   {{0x22417216,0x6604023a,0x59b41546,0x00000000}},	//   blik_, _ylik, ंभार, --, 
   {{0x4438231e,0xdb1800cf,0x22417217,0x660401a9}},	//   _zkp_, devà, clik_, _xlik, 
   {{0x765c1571,0xdd940166,0x00000000,0x00000000}},	//   _miqy, сачы, --, --, 
   {{0xf1f8023e,0x00000000,0x00000000,0x00000000}},	//   _एकड़_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7c397218,0x48b400a7,0x89d40150,0x00000000}},	//   _ektr, ащот, рікш, --, 
   {{0x6e397219,0x3865721a,0xb9e40220,0x660401b9}},	//   _ikub, _cuor_, рмыз_, _rlik, 
   {{0x6605721b,0x2241721c,0xf7709498,0x7d04000d}},	//   _slik, zlik_, ياپ_, _üksa, 
   {{0x660414cf,0x224007d6,0x765c0477,0x6e382252}},	//   _plik, ylik_, _biqy, _kkub, 
   {{0x2c6804ce,0x3864011c,0x443826bb,0x629c0165}},	//   _kød_, _fuor_, _skp_, vrro, 
   {{0x6e3805d9,0x22414999,0x4438033f,0x765c0200}},	//   _mkub, vlik_, _pkp_, _diqy, 
   {{0x46f400d6,0x2c68037e,0x2241721d,0x68f80472}},	//   _вчит, _mød_, wlik_, myud, 
   {{0x6e3857d2,0x68f9721e,0x46a5721f,0x2c68318c}},	//   _okub, lyud, _тайв, _lød_, 
   {{0x66057220,0x6e380a03,0x2240cd17,0x7a3c0023}},	//   _ulik, _nkub, ulik_, tëti, 
   {{0x65657221,0x22417222,0xd6243738,0x44397223}},	// [26600] _igih, rlik_, _دعوي, _tkp_, 
   {{0x22417224,0x6aa17225,0x60017226,0xb4f80375}},	//   slik_, kunf, _göml, _ספיי, 
   {{0xfe7066a3,0x22417227,0x68f97228,0xddf800fd}},	//   زدا_, plik_, hyud, льдә_, 
   {{0x6000006a,0x22415a21,0x7a3c02d3,0x6aa17229}},	//   _tömo, qlik_, pëti, dunf, 
   {{0xfbe0038e,0x00000000,0x00000000,0x00000000}},	//   पालम, --, --, --, 
   {{0x6e38124c,0x2c685d16,0xab740a8e,0x6c800131}},	//   _ekub, _død_, لمها_, ڭلۈم, 
   {{0x3865722a,0x2018007f,0xaa602401,0xdae81913}},	//   _suor_, _imri_, отык, افعو_, 
   {{0x6565722b,0x6da0c44b,0x60000008,0xf1bc0162}},	//   _ngih, _миса, _mömm, _njál_, 
   {{0xed5448ad,0x38640086,0x765c02d1,0xdddc04a7}},	//   _вот_, _quor_, _riqy, _kvrž, 
   {{0x7c380113,0x4d140354,0x00000000,0x00000000}},	//   _uktr, _уьст, --, --, 
   {{0xb059722c,0x4fd800c8,0x6aa0b269,0x1cd4025c}},	//   _präz, אַרד, cunf, ེའམ_, 
   {{0x38640c86,0x68f800b5,0x6e380327,0x6000007c}},	//   _tuor_, byud, _xkub, _söml, 
   {{0x2019722d,0x187406a6,0xdddc0010,0x6fa40073}},	//   _omri_, _угля, _ovrž, _चालू, 
   {{0x6564014b,0x3cec068f,0x65bc00b5,0x6000032e}},	//   _egih, _आपने_, _påhæ, _bömm, 
   {{0xd8380f72,0xb68459e1,0x56940064,0x6a640205}},	//   moč_, _ئشتى, _уайт, _rıfk, 
   {{0x2019722e,0xe2f80046,0x418402dd,0x6000007c}},	//   _amri_, шесі_, йтуғ, _dömm, 
   {{0x6e3800d2,0x2f880640,0x2258023a,0xdca40137}},	// [26610] _rkub, вљен_, риты_, _تۉ_, 
   {{0x2c68fb11,0x6e39722f,0x7c800092,0xd8380010}},	//   _rød_, _skub, _ይሰራል_, noč_, 
   {{0x2c6804ce,0x60017230,0x0d98010b,0xdb18005c}},	//   _sød_, _gömm, гтлы_, levæ, 
   {{0x2018044e,0xb05801e6,0x68f80e14,0xdea40330}},	//   _emri_, _späd, yyud, تیفی, 
   {{0xd838151c,0x236c00f3,0xdb1808cb,0x2018045a}},	//   koč_, ždje_, nevæ, _fmri_, 
   {{0x00f406a9,0xd83809a8,0x6aa0002f,0x00000000}},	//   _המשך_, joč_, tunf, --, 
   {{0x7d0400af,0x7a3c0240,0xd8384b16,0x261800e1}},	//   _üksn, hëtu, doč_, _पगली_, 
   {{0x6e397231,0x88847eb9,0x49c97232,0x8c3c008e}},	//   _ukub, ближ, улин_, _aqşt, 
   {{0xdb180030,0x6aa00e78,0x87f801c0,0x4c940124}},	//   revá, sunf, гэнт_, _ыиас, 
   {{0xdb18a3ba,0xd8380f03,0x48043420,0x6aa00066}},	//   devæ, goč_, спов, punf, 
   {{0x98b80aed,0x0af97233,0x00000000,0x00000000}},	//   ārā_, _حفاظ_, --, --, 
   {{0x2cbc0263,0xe7d4000d,0xb05801f4,0x99d45868}},	//   _kpud_, _भोरप, _isäu, _وتنا, 
   {{0x60017234,0x5a0c00c8,0xdb181fcd,0x7a3c0240}},	//   _sömm, _בלאַ, gevæ, gëtu, 
   {{0x412802a9,0x00000000,0x00000000,0x00000000}},	//   қозо_, --, --, --, 
   {{0x969400c7,0xd8397235,0x00000000,0x00000000}},	//   _дрыш, _тэц_, --, --, 
   {{0x65640526,0xdb1800b5,0x7cdc0311,0x765c00e4}},	//   _ugih, bevæ, _hărţ, _épyp, 
   {{0x7a3c0a40,0xf26402dd,0xdb189f5c,0x00000000}},	// [26620] mëtt, _қиял_, cevæ, --, 
   {{0x60000267,0x00000000,0x00000000,0x00000000}},	//   _tömm, --, --, --, 
   {{0x2cbd7236,0x7cdc054e,0xdd3800ef,0x00000000}},	//   _apud_, _mărţ, dāšo, --, 
   {{0x7a3c04e6,0x00000000,0x00000000,0x00000000}},	//   nëtt, --, --, --, 
   {{0x7fd4187f,0x00000000,0x00000000,0x00000000}},	//   _ліві, --, --, --, 
   {{0x20197237,0xfce4006c,0x60000598,0x7a3c01c7}},	//   _umri_, _қозо, _mömk, hëtt, 
   {{0xae40121e,0xb0580139,0x00000000,0x00000000}},	//   _کھلو, _rräx, --, --, 
   {{0x1874113e,0x3f880451,0xd91004fb,0x75fc0240}},	//   огия, _hebu_, ویض_, _gëzh, 
   {{0xd8383c52,0x050800bd,0x3dc40295,0x3f8800f3}},	//   toč_, রপুর_, meow_, _kebu_, 
   {{0x7cdc084c,0xdb18037e,0x7a3c017a,0x00000000}},	//   _cărţ, vevæ, eëtt, --, 
   {{0xd83867e9,0xdb243bd6,0xca3801e4,0xb05801f4}},	//   roč_, _بوای, boŝ_, _isät, 
   {{0xd838151c,0x3dc40086,0x3f897238,0x7a3c0036}},	//   soč_, neow_, _lebu_, gëtt, 
   {{0x05a8012c,0xd79402e8,0xa504010b,0x00000000}},	//   _कारब, _дилъ, пярл, --, 
   {{0xdb1800b5,0xb0680961,0x6a6406be,0xd1a400ec}},	//   revæ, ғраж_, _sıfi, ڪٽري, 
   {{0x3dc48451,0xdb1800b5,0x3d18000d,0x7a3c0200}},	//   keow_, sevæ, _मेसे_, sëtu, 
   {{0x7a3c02d3,0x80d002f5,0xb178007c,0xdb197239}},	//   pëtu, সমন্, _enån, pevæ, 
   {{0x3f88914f,0xdb186583,0xa3d4000d,0x6224129d}},	// [26630] _bebu_, levä, _सोक_, سىكل, 
   {{0x3f89723a,0xf1a800ce,0x00000000,0x00000000}},	//   _cebu_, _छावन, --, --, 
   {{0xb8d81b4b,0x3f89723b,0xb8c80135,0x2cbc0072}},	//   _ཅད_, _debu_, _བའ_, _spud_, 
   {{0xf1a45fce,0x9f5c7c7b,0xdd940953,0xb05801c7}},	//   _урон, óvá_, зацы, _asät, 
   {{0xda7801f1,0x75fc0023,0xdb1816ca,0x7d04000d}},	//   _atď_, _vëzh, hevä, _üksl, 
   {{0x3f888581,0xdb1802f6,0x3dc40295,0xb3240327}},	//   _gebu_, kevä, aeow_, _རྨོང_, 
   {{0x3a7000fd,0xdb184268,0x00000000,0x00000000}},	//   үләр, jevä, --, --, 
   {{0x3d1801ad,0xdb1801e3,0xbe6000db,0xdb08010e}},	//   _मेवे_, devä, _قۇلي, _ýoýl, 
   {{0x7cdc084c,0x2cbc0004,0x75fc02d3,0x2d8c3af1}},	//   _părţ, _upud_, _gëzi, mage_, 
   {{0x2d8d723c,0x600000fd,0xb058005b,0x00000000}},	//   lage_, _cömh, _isäs, --, 
   {{0x3ab00022,0xdb18369a,0x00000000,0x00000000}},	//   _жәыт, gevä, --, --, 
   {{0x2d8c2f75,0x9985723d,0xf41c01f4,0x00000000}},	//   nage_, _فلمو, ksäs_, --, 
   {{0xf41c0958,0x00000000,0x00000000,0x00000000}},	//   ysät_, --, --, --, 
   {{0x2d8d723e,0xa3d41524,0x00000000,0x00000000}},	//   hage_, _सोख_, --, --, 
   {{0x3f89723f,0x244401b8,0xdb18007c,0x33600114}},	//   _rebu_, nömi_, cevä, дврг, 
   {{0x3f880af2,0xddc0002b,0x3d18000d,0x00000000}},	//   _sebu_, _vimū, _मइले_, --, 
   {{0x2d8d7240,0xf41c005b,0x00000000,0x00000000}},	// [26640] dage_, tsät_, --, --, 
   {{0xdb1808fb,0x3dc40810,0x60002b15,0xddc00064}},	//   levå, weow_, _kömi, _timū, 
   {{0x2d8c20ef,0xb058055e,0x80a4134e,0x00000000}},	//   fage_, _asäs, _चमके, --, 
   {{0x3f880e96,0xdb1800fe,0xfca800aa,0x244401b8}},	//   _webu_, nevå, لاتو_, dömi_, 
   {{0x3f88080b,0x600001b8,0x3dc40428,0x3f680276}},	//   _tebu_, _lömi, reow_, _виго_, 
   {{0x2d8c0270,0x7d040037,0x2d900139,0x00000000}},	//   aage_, _üksm, прәс, --, 
   {{0x3d18006d,0x2d8d7241,0x05a80d79,0x7dc4007b}},	//   _मेरे_, bage_, _कांब, _وترك, 
   {{0x2d8d7242,0xee340b3b,0x8e74030d,0x00000000}},	//   cage_, _днс_, _хурч, --, 
   {{0xb058007c,0x39408ecc,0x00000000,0x00000000}},	//   _isär, æks_, --, --, 
   {{0xdb197243,0xb8f000af,0xb0580036,0xca2400d1}},	//   tevä, _हई_, _usät, يۋەن_, 
   {{0xec117244,0xcfe0031c,0x1be0033f,0xf41c0166}},	//   _تولد, སྐྲྀ, _गोयल_, ksär_, 
   {{0xdb197245,0xf990179e,0x7a3c0036,0xc0dc0023}},	//   revä, _آبا_, rëts, _ሓጐስ_, 
   {{0xdb197246,0x8cdc033f,0x80c8012d,0x00000000}},	//   sevä, पियो, _सैले, --, 
   {{0x7c297247,0x2d8d7248,0xf1bc0022,0xf60807d6}},	//   nnfr, zage_, _ijái_, اتگه_, 
   {{0x2d8d7249,0x1b1c009e,0xefdc0023,0xa3440166}},	//   yage_, _পুতে_, ዒታዊ_, дэтл, 
   {{0x2d8c06af,0xed5c00bc,0x7c28002f,0x00000000}},	//   xage_, ížka_, hnfr, --, 
   {{0x3d180d0a,0x2d8c3046,0x236c0cf4,0x44282ab0}},	// [26650] _मेले_, vage_, ždja_, bnb_, 
   {{0x2d8c2622,0x7c2801e4,0x70200023,0x00000000}},	//   wage_, jnfr, _ተረዲኦ, --, 
   {{0x0d74010b,0x99840024,0x7d04000d,0xf41c0108}},	//   пыля, nomų_, _üksj, ssäs_, 
   {{0x7c280072,0x2d8c0129,0xdce00205,0xdb180037}},	//   enfr, uage_, _admı, ndvõ, 
   {{0x2d8d724a,0x7c28008c,0xf1bc0ca8,0xb058005b}},	//   rage_, fnfr, _ibá_, _epäa, 
   {{0x7c2801a8,0xce9402e8,0x99840153,0x00000000}},	//   gnfr, _нагъ, komų_, --, 
   {{0x5eb401c0,0xdeb4005b,0x00000000,0x00000000}},	//   _ойрт, _обры, --, --, 
   {{0x7c29724b,0x8e2801d9,0x088847b3,0x60000e78}},	//   anfr, _آرٕ_, ббий_, _römi, 
   {{0x60000793,0xf1bc6b3c,0x8b3400f2,0x00000000}},	//   _sömi, _mbá_, _کفاش, --, 
   {{0xaae40133,0xb17801e6,0xc0f00023,0x00000000}},	//   _وساو, _snål, _ፍቅሪ_, --, 
   {{0xb8f04a04,0x93f8013f,0x6e29724c,0xdb1803cd}},	//   _है_, ntsε_, ongb, tevå, 
   {{0xfa54cfc1,0x00000000,0x00000000,0x00000000}},	//   _فرنگ, --, --, --, 
   {{0x5fac0574,0xdb1803cd,0x42680092,0x00000000}},	//   _चालल, revå, ዳጅነት_, --, 
   {{0xf1bc0241,0x6e28006a,0x3cec033f,0xdb1803cd}},	//   _abá_, hngb, _आपसे_, sevå, 
   {{0xf740020a,0x442800b5,0x824800c6,0xdb1800cc}},	//   _пешо, rnb_, مشرف_, pevå, 
   {{0x7fd800d1,0x00000000,0x00000000,0x00000000}},	//   әфат_, --, --, --, 
   {{0x4375724d,0xf1bc0306,0x44280165,0x23c401d9}},	// [26660] _нунт, _dbá_, pnb_, _ہٕکہ, 
   {{0xa3d40abd,0x312001c0,0xf41c3bd2,0x0fe80116}},	//   _सोच_, хдуг, ssär_, олуқ_, 
   {{0x7de40220,0x7c280162,0xce3400e5,0x00000000}},	//   зілд, vnfr, ڈولک, --, 
   {{0x7d0400af,0xf1bc0ca8,0x412801c0,0xa3d401ad}},	//   _üksk, _gbá_, _гомо_, सएक_, 
   {{0x75fc0023,0x1bd49842,0x16a82802,0x6aa0002f}},	//   _gëzu, доля, _कम्ब, ernf, 
   {{0x6e280354,0x82b8025c,0xdce00327,0xeb9400d8}},	//   angb, _བྱོའ, _lemħ, пиљ_, 
   {{0xb0580598,0x7c29724e,0xeb9406ed,0xf1bc01a8}},	//   _isäp, rnfr, чиј_, _sjái_, 
   {{0xf1bc032e,0xf2d0011a,0xef1401c4,0x00000000}},	//   _pjái_, תעה_, _эмс_, --, 
   {{0x7e6c045a,0x00000000,0x00000000,0x00000000}},	//   _hubp, --, --, --, 
   {{0x7791589e,0x7d01724f,0xeb943cb7,0xed5c0006}},	//   ریبا, myos, _ниу_, įžta_, 
   {{0xbb497250,0x7bc97251,0x7d017252,0x676401e1}},	//   _الان_, mefu, lyos, _ẹmùr, 
   {{0x7bc97253,0x82b80135,0xf608030d,0xd1f80092}},	//   lefu, _བྱེའ, схой_, ፈበት_, 
   {{0x7e6c01d4,0x35457254,0x7d017255,0xe4e401ce}},	//   _lubp, яхов, nyos, нірн, 
   {{0x7bc898b0,0x39457256,0x59b401ad,0xed5c00d0}},	//   nefu, _iyos_, ंभकर, ížia_, 
   {{0x9f58044e,0x7d00014a,0x67b8011a,0x6e280142}},	//   _dorë_, hyos, _המוק, yngb, 
   {{0x7bc97257,0x7d000083,0xe4d801d9,0xe6440120}},	//   hefu, kyos, _کوٝت_, _пејп, 
   {{0x7bc8b44a,0xe1357258,0xc0f00020,0xb3c80276}},	// [26670] kefu, енты, _ፍቅር_, _лунж_, 
   {{0x7bc8002d,0x7d017259,0xb0580108,0x39440108}},	//   jefu, dyos, _epän, _myos_, 
   {{0x7bc9725a,0xd34000dd,0xda0c5096,0x00000000}},	//   defu, _شہری, िघात_, --, 
   {{0xf1a4085a,0x7e6c0477,0x3944020c,0xf1bc00d8}},	//   _эрон, _dubp, _oyos_, _ubá_, 
   {{0x394400ca,0x23700240,0x00000000,0x00000000}},	//   _nyos_, _çojë_, --, --, 
   {{0x7bc9725b,0xfce055a2,0x22b80543,0x00000000}},	//   gefu, тошо, _بدیع_, --, 
   {{0x3944bffa,0x7d00089c,0x00000000,0x00000000}},	//   _ayos_, ayos, --, --, 
   {{0xdb080124,0x88e5725c,0x7d01725d,0x600008a5}},	//   _abdó, джие, byos, _dömu, 
   {{0x7bc8abfb,0x7d0000ca,0x70a80034,0xde5800d4}},	//   befu, cyos, _चमोल, _хаті_, 
   {{0x3944079b,0x69cc0034,0x7bc86079,0xdd9000f1}},	//   _dyos_, _दसवी, cefu, _لوې_, 
   {{0x60000008,0xdebc0023,0x00000000,0x00000000}},	//   _gömu, _ደቁን_, --, --, 
   {{0xfd9000d1,0x00000000,0x00000000,0x00000000}},	//   ﻟﻤﺎﻥ_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb05804f3,0x9f58033b,0x42e80137,0x5fac03ba}},	//   _spän, _forè_, омго_, _चाइल, 
   {{0x9f58036e,0x244401e3,0x7d000210,0xc64800ae}},	//   _vorë_, dömt_, zyos, _وجعل_, 
   {{0x7bc898bc,0x3cec05ba,0x7d00102c,0x00000000}},	//   zefu, _आपले_, yyos, --, 
   {{0x7e6d725e,0x39440218,0xf650011a,0x806400d4}},	// [26680] _subp, _xyos_, _בצה_, дваж, 
   {{0x7d000451,0x7d04007d,0x39400037,0xbfa801d9}},	//   vyos, _üksi, üksi_, تارٕ_, 
   {{0x7bc9725f,0xb058023a,0x7ee400db,0xfe402094}},	//   vefu, _epäo, بكان, نکری, 
   {{0x9f580098,0x7d240b24,0x7d0000aa,0x7bc86616}},	//   _joré_, وفان, tyos, wefu, 
   {{0xb0582776,0x9f597260,0x645c01f5,0x600001a8}},	//   _kpäl, _moré_, omri, _sömu, 
   {{0x7d004cd3,0x7e6c0218,0x645c00fb,0x9f580066}},	//   ryos, _tubp, nmri, _loré_, 
   {{0x8d84001f,0x7bc97261,0x60000267,0x7d017262}},	//   ነታቸው_, refu, _dömt, syos, 
   {{0x7bc97263,0x645c01f7,0xeb940131,0x6a6415b7}},	//   sefu, hmri, пиә_, _sıfr, 
   {{0x7d00036b,0x24440793,0x7bc8a813,0xed400137}},	//   qyos, nöms_, pefu, _антп, 
   {{0x3154008f,0xdee00023,0x645c0200,0xb8d406b1}},	//   ויפן_, _ሓሰን_, jmri, _छम_, 
   {{0x2be85c0e,0x22411ecb,0x1b1c00eb,0x00000000}},	//   चारू_, koik_, _পুরে_, --, 
   {{0x645c0240,0xb9040139,0x00000000,0x00000000}},	//   emri, _озек, --, --, 
   {{0x9f587f70,0xa9644d87,0x00000000,0x00000000}},	//   _doré_, _жица_, --, --, 
   {{0x24440267,0x00000000,0x00000000,0x00000000}},	//   döms_, --, --, --, 
   {{0x6000007c,0x00000000,0x00000000,0x00000000}},	//   _löms, --, --, --, 
   {{0x645c59ad,0x2240005a,0xe7040214,0xb058005b}},	//   amri, goik_, _تسهی, _epäl, 
   {{0xdb4403e6,0xf04001d3,0x9054009b,0x69c400e5}},	// [26690] _چێ_, نٹری, евац, őjeg, 
   {{0xdb4403e6,0xd01001e2,0x00000000,0x00000000}},	//   _نێ_, دلئ_, --, --, 
   {{0x80d0009e,0x24443b52,0x00000000,0x00000000}},	//   সমষ্, römt_, --, --, 
   {{0x82b8025c,0xf1a82354,0xb3400327,0x00000000}},	//   _བྱིའ, _باده_, ħħdi, --, 
   {{0xdd942fe5,0xda7800d7,0x00000000,0x00000000}},	//   тачы, _brďo_, --, --, 
   {{0xb058025a,0x60c000c5,0x2c780356,0xc0c400f1}},	//   _kpäm, _ämma, _râdă_, _سېمه_, 
   {{0xbb417264,0x00000000,0x00000000,0x00000000}},	//   лешк, --, --, --, 
   {{0xe7d45361,0xe8041524,0xd5c028f0,0x80d00154}},	//   _भोजप, षस्थ_, ष्मज, সমর্, 
   {{0xdd957265,0x600001e3,0x5c9801ee,0x00000000}},	//   _шаты, _göms, _октя_, --, 
   {{0x9f597266,0x2240003e,0x06857267,0x6000032e}},	//   _soré_, zoik_, нгон, _hömr, 
   {{0x2240005a,0x6000399d,0x9f5801e1,0x07080472}},	//   yoik_, _kömr, _poré_, سيحي_, 
   {{0xb05801b8,0x224001c4,0x7c3c0427,0xf77c031c}},	//   _späl, xoik_, čpre, ħħam_, 
   {{0x07a428e5,0xdddc00e2,0xf50412e7,0xf7280023}},	//   _залн, _strū, енял_, _ብዘይን, 
   {{0x69d801c0,0xf8b004ae,0x00000000,0x00000000}},	//   ldue, _עשו_, --, --, 
   {{0x42546b83,0x04457268,0x7d040254,0x00000000}},	//   етат, _җенн, _üksv, --, 
   {{0x69d97269,0x600003be,0x2d9d726a,0x0164004e}},	//   ndue, _nömr, _ndue_, екбо, 
   {{0x25a1726b,0xd1752c0d,0xb058023a,0xb4a400c7}},	// [266a0] _idil_, тысы, _epäm, _зкыз_, 
   {{0x2480113c,0x704404a9,0x69d80007,0xb1401b04}},	//   _itim_, ىرلە, hdue, унул, 
   {{0x6fb053f0,0x69d9726c,0x244401b8,0x82b80327}},	//   امما, kdue, söms_, _བཱིའ, 
   {{0x24801529,0x69d80369,0xf1bc0030,0x5fac8b95}},	//   _ktim_, jdue, íšte_, _चाकल, 
   {{0x69d8020c,0xd2000139,0x00000000,0x00000000}},	//   ddue, _түтк, --, --, 
   {{0xf534010f,0x00000000,0x00000000,0x00000000}},	//   ענסי_, --, --, --, 
   {{0x09d802a6,0x25a001b9,0x00000000,0x00000000}},	//   থানা, _odil_, --, --, 
   {{0x600000ac,0x24806c34,0x69d80142,0x00000000}},	//   _gömr, _otim_, gdue, --, 
   {{0x24800070,0xbca405d4,0x6da0026b,0x00000000}},	//   _ntim_, _سماي, _щита, --, 
   {{0x80c8015b,0x00000000,0x00000000,0x00000000}},	//   রিপ্, --, --, --, 
   {{0x69d9726d,0x24800793,0x7bd800b0,0x25a00135}},	//   bdue, _atim_, _iatu, _bdil_, 
   {{0x7bd9726e,0x26c40175,0x60000166,0xb6000419}},	//   _hatu, _dpno_, _mömq, kláň, 
   {{0xb05825e4,0xddc00356,0xd8f401d3,0x00000000}},	//   _späm, _zimţ, _جزاک, --, 
   {{0x7bd9726f,0x25a00209,0x7d0400c5,0x672801d3}},	//   _jatu, _edil_, _üksu, áljá, 
   {{0x24817270,0xdddc00df,0x1cc0031c,0x62a801e1}},	//   _etim_, _surŝ, _ཀྱལ_, _ìsọ, 
   {{0x7bd97271,0x80c800bd,0xca440952,0x00000000}},	//   _latu, রিন্, ﻘﻘﺎ_, --, 
   {{0x7bd97272,0x25d8010f,0x05940137,0xb5f843e9}},	// [266b0] _oatu, _טוהן_, _شايگ, rmád, 
   {{0xb4bc08e9,0x37cc03d4,0x2934011a,0xa9200419}},	//   ीबी_, ়াকৰ, תאמן_, ížim, 
   {{0xb0580108,0xf3645bc6,0xb140010a,0x00000000}},	//   _ypäj, _ятин, ăнул, --, 
   {{0x7bd97273,0x09c4015b,0xb5f801d3,0xae000116}},	//   _aatu, _শোনা, lmáb, دۈرى, 
   {{0x7bd97274,0xddc0084c,0x1fb804c5,0xf1bc08a5}},	//   _batu, _simţ, ীয়স, _fjár_, 
   {{0x7bd946bc,0xf1bc0579,0xf53c12e8,0x8e84007b}},	//   _catu, _gjár_, lgås_, _للسه, 
   {{0xacd000fd,0x3ad0009f,0x00000000,0x00000000}},	//   _әбзә, ليوز, --, --, 
   {{0x9f58db64,0x09e57275,0x7bd80c8c,0xf53c1445}},	//   _morì_, тоин, _eatu, ngås_, 
   {{0x69d80323,0x290801a2,0xdddc062d,0x6000005b}},	//   rdue, áca_, _hurş, _kömp, 
   {{0xdddc05d1,0x53841772,0x69d80036,0x00000000}},	//   _kurş, ክሳዊት_, sdue, --, 
   {{0x24817276,0x69d80ba1,0xea8803e6,0x00000000}},	//   _stim_, pdue, _رخان_, --, 
   {{0x7bd97277,0xe9a80150,0x97c401ec,0xf65c01bf}},	//   _zatu, _ءدان_, _ەتيم, gmæ_, 
   {{0x7bd844c8,0x7d0400af,0xf53c00b5,0xdee002d3}},	//   _yatu, _ükst, dgås_, _ሓደን_, 
   {{0xc7a4859f,0xc6c4010a,0x7bd97278,0x00000000}},	//   _рикк, _айкк, _xatu, --, 
   {{0x41b57279,0x54c00046,0x99640cef,0xb058023a}},	//   ксат, _құрб, _итәл, _epäk, 
   {{0xdb1800c7,0x00000000,0x00000000,0x00000000}},	//   jevý, --, --, --, 
   {{0xf9901a4c,0x248030d7,0x40c800ec,0x00000000}},	// [266c0] ירן_, _utim_, بوءَ_, --, 
   {{0x8fd4052f,0x100400d4,0x6aa400fe,0x00000000}},	//   ләсә, ляєм, _কৈছো, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf53ce78f,0x629c05ac,0xdddc010b,0x61440131}},	//   mgår_, msro, _durş, _مىجە, 
   {{0xf53c072b,0xb5f828d1,0x985403b9,0xdb1001e1}},	//   lgår_, lmác, _nəğd_, _àfún, 
   {{0x7bd9727a,0xaee40327,0x9f5800d0,0xddc00064}},	//   _qatu, སའཁོ, _horí_, _dimš, 
   {{0x3cec006d,0x7bd9727b,0xf53c1700,0x629c1f53}},	//   _आपके_, _vatu, ngår_, nsro, 
   {{0x58d91eb7,0x7bd800b2,0x629c0730,0x7a3c0036}},	//   едия_, _watu, isro, lëtz, 
   {{0x7bd9727c,0x3c6435f6,0x9f59727d,0xbc6400f3}},	//   _tatu, _акаг, _morí_, _авак, 
   {{0xad18025f,0x7bd9727e,0x57f428eb,0x9f580248}},	//   _חומר, _uatu, упот, _lorí_, 
   {{0xa3c81715,0xb05801b8,0x9f58011f,0x55940120}},	//   ोजन_, _späk, _horâ_, ланѓ, 
   {{0xf53c04ce,0x629c0b34,0xa9200024,0x1cc0031c}},	//   dgår_, dsro, _įžva, _ཀྱོ_, 
   {{0xf65c003a,0x25b80419,0x69e00419,0x00000000}},	//   rmæ_, _želá_, ávež, --, 
   {{0xa3a415ed,0x629c007c,0x00000000,0x00000000}},	//   ијск, fsro, --, --, 
   {{0x9f580248,0xb5f801ed,0xc04001f2,0xf53c0267}},	//   _borí_, rmáb, ọọb_, ggår_, 
   {{0x30e402dd,0x225801af,0x00000000,0x00000000}},	//   кізб, висы_, --, --, 
   {{0x9f580248,0xc43000f2,0x60000108,0xf53c007c}},	// [266d0] _dorí_, شکیت, _pömp, rgås_, 
   {{0x1cc00003,0x629c017a,0x9f5801e1,0xddc04e96}},	//   _ཀྱེ_, bsro, _torì_, _rimš, 
   {{0x9f580ca8,0xaca001fb,0xfcc001e0,0xdddc03e3}},	//   _forí_, _trừn, ҙәтм, _qurş, 
   {{0x9f580ca8,0x00000000,0x00000000,0x00000000}},	//   _gorí_, --, --, --, 
   {{0x667c001f,0x23c02802,0x0c74085b,0x00000000}},	//   _የተሟላ_, श्वद, اگرد, --, 
   {{0x1c443334,0xdddd2af4,0x00000000,0x00000000}},	//   анім, _turş, --, --, 
   {{0x6e6484c8,0xeac002f5,0xe458008f,0x1cc0031c}},	//   _атаж, ্ম্ম, דיגט_, _ཀྱཻ_, 
   {{0x5f4400db,0x9f3402dd,0xb058002f,0x667c0092}},	//   _ئنفل, _тесі, _späh, _የተሞላ_, 
   {{0x5d84036b,0xb4bc033f,0xc8c869a6,0x00000000}},	//   _خلقل, ीबो_, رودن_, --, 
   {{0x4cb8045e,0x00000000,0x00000000,0x00000000}},	//   _ইনপু, --, --, --, 
   {{0x9f4c025a,0x63b8049f,0x2b440024,0x00000000}},	//   _ôdô_, _övni, _рэаг, --, 
   {{0x629ca934,0xa3c800af,0x66040124,0x80c800eb}},	//   vsro, ोड़न_, рҿиа, রিত্, 
   {{0xb058049b,0x9f580004,0x629c123b,0x00000000}},	//   _epäi, _korã_, wsro, --, 
   {{0x572401d5,0x9f580139,0x9784030d,0xd7c800ec}},	//   اریق, _sorí_, _вăрă_, _لوهه_, 
   {{0xf09c0c95,0x629cafa8,0xe9fc01fb,0x52980395}},	//   _avà_, usro, _ngẫm_, кътя_, 
   {{0xb5f9727f,0xf53c8232,0x00000000,0x00000000}},	//   rmác, rgår_, --, --, 
   {{0x7a3c0a40,0xbfc4020a,0xdb18f04f,0x9f580022}},	// [266e0] tëtz, лбак, nevò, _vorí_, 
   {{0xf53c0267,0xb68401d3,0x302400c7,0xf41c0166}},	//   pgår_, _جھیل_, гоуп_, lpän_, 
   {{0x44297280,0xa30400ee,0x7a3c04e6,0x9f580ca8}},	//   mib_, _түве, rëtz, _torí_, 
   {{0x44297281,0xf2d00bd9,0x9f580124,0x1cc00135}},	//   lib_, _פער_, _aorã_, _ཀྱུ_, 
   {{0xed5401c6,0x6da008da,0x7a3c04e6,0x00000000}},	//   гоц_, сича, pëtz, --, 
   {{0x44297282,0x80c8015b,0x00000000,0x00000000}},	//   nib_, রিদ্, --, --, 
   {{0xba445ded,0x3f980a8b,0x44280098,0x3ebcd909}},	//   лхий, mapu_, iib_, _ëtt_, 
   {{0x4428263e,0x3f997283,0x00000000,0x00000000}},	//   hib_, lapu_, --, --, 
   {{0xb058092e,0x44297284,0xdb080120,0x7e616b40}},	//   _späi, kib_, _abdô, mmop, 
   {{0x7e6001af,0x44282f2b,0x3f997285,0xfbac190e}},	//   lmop, jib_, napu_, _घाटम, 
   {{0x44297286,0x7c297287,0x3f9802b5,0x4550001f}},	//   dib_, mifr, iapu_, _ማስከበ, 
   {{0x3f997288,0x4428058a,0xdb1800e4,0x00000000}},	//   hapu_, eib_, sevó, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4428102c,0x3f980022,0x00000000,0x00000000}},	//   gib_, japu_, --, --, 
   {{0xf1bc01e1,0x3f98014f,0x00000000,0x00000000}},	//   _amáa_, dapu_, --, --, 
   {{0x7c29102d,0x7e6001a6,0xaad40118,0xdbd00432}},	//   hifr, jmop, _भईसक, lýäd, 
   {{0x44297289,0xaca00016,0xb178143a,0x7c284cab}},	// [266f0] bib_, _trứn, _snås, kifr, 
   {{0x4429728a,0xdbd00209,0x3f98020c,0x7e600430}},	//   cib_, nýäd, gapu_, emop, 
   {{0xb8e4025c,0x7c280334,0xad240344,0x1cc0031c}},	//   _ཎཱ_, difr, گراو, _ཀཱུ_, 
   {{0xdfd4005e,0xb64400b5,0xa13400ec,0x9db80166}},	//   _қосы, _ｋｏ_, _ڇوٽڪ, гышу_, 
   {{0xad24b4d5,0x9f580588,0x3f98063f,0x1cc0031c}},	//   دراو, _porã_, bapu_, _ཀྱཱ_, 
   {{0x9f58004e,0x7c29728b,0xe47c0375,0x7e6001f4}},	//   _forà_, gifr, ערוכ, amop, 
   {{0xcc8800aa,0xdbd0010e,0x00000000,0x00000000}},	//   رنګه_, dýäd, --, --, 
   {{0x4429728c,0x6d5400ac,0x7c29728d,0x8a055870}},	//   zib_, əxan, aifr, рзие, 
   {{0x4429728e,0x7c29728f,0xd5ec01fb,0x6e280165}},	//   yib_, bifr, _giả, migb, 
   {{0x44297290,0x6e2808cb,0xb058023a,0x3a2401f4}},	//   xib_, ligb, _epäv, _emop_, 
   {{0x44297291,0x386c0332,0x6e280076,0x00000000}},	//   vib_, _difr_, oigb, --, 
   {{0x6e297292,0x3a780375,0x3f980099,0x386c0042}},	//   nigb, _סטנד, zapu_, _eifr_, 
   {{0x4428006c,0x24840a40,0x3f980986,0xe9fc0208}},	//   tib_, ëmm_, yapu_, _ngẩm_, 
   {{0x7e600200,0x00000000,0x00000000,0x00000000}},	//   zmop, --, --, --, 
   {{0x44297293,0x6e28adaa,0xf1bc08a5,0x7e6001f4}},	//   rib_, kigb, _smáa_, ymop, 
   {{0xb5f8ba3b,0x80c8015b,0x73300131,0x7c280268}},	//   lmán, রিস্, زىقا, zifr, 
   {{0x3f997294,0x44297295,0x80a57296,0x6e297297}},	// [26700] tapu_, pib_, شمان, digb, 
   {{0x66040751,0x44297298,0x7c297299,0x7c800092}},	//   _hoik, qib_, xifr, _ይሰማል_, 
   {{0x6605729a,0x3f99729b,0xf1bc3eba,0x7a3c005f}},	//   _koik, rapu_, _imán_, līte, 
   {{0x3f99729c,0x9f5800c7,0x0ca0001f,0x6604117e}},	//   sapu_, _corá_, _ኃይሎች_, _joik, 
   {{0x6605729d,0x3f982ebf,0x71600150,0x7a3c1a14}},	//   _moik, papu_, _وپپە, nīte, 
   {{0xfaa5729e,0x9f5856eb,0x6604023a,0x6e2801ab}},	//   ашин, _torà_, _loik, aigb, 
   {{0x7c29729f,0xb178007c,0x30240120,0x6bd0129d}},	//   rifr, _knåp, _торп_, زتور, 
   {{0x195972a0,0x660572a1,0xea7402d3,0x386c0156}},	//   лайы_, _noik, _ኣቐዲመ_, _sifr_, 
   {{0x7c2972a2,0x1cc0031c,0xa89400c7,0xb0580108}},	//   pifr, _ཀཱི_, акыу_, _epäu, 
   {{0xf8051df7,0x1cc0025c,0x6604037e,0xbc680133}},	//   рчин, _ཀྱག_, _aoik, _شمان_, 
   {{0x660572a3,0xbb4406bb,0x3ce4014b,0xab740214}},	//   _boik, _тежк, lvov_, _ضمنا_, 
   {{0x3a240066,0x386c015d,0x4438045a,0xf98802c9}},	//   _umop_, _wifr_, _ajp_, _شخصه_, 
   {{0x798172a4,0x660572a5,0x4438045a,0x00000000}},	//   _ifow, _doik, _bjp_, --, 
   {{0x78a0035a,0x443972a6,0x3704003b,0x00000000}},	//   _ivov, _cjp_, _вчив, --, 
   {{0x4438020b,0x660406d9,0x9f58003a,0x228401c6}},	//   _djp_, _foik, _horæ_, жууг, 
   {{0x660401c0,0x44380334,0x7a3c00e2,0xe2140139}},	//   _goik, _ejp_, bīte, омсы, 
   {{0x798001f0,0xb0580030,0xdb18007c,0xefcc0023}},	// [26710] _mfow, _opät, lfvä, _ኣበየ_, 
   {{0xaaa402ab,0x6e280af9,0x00000000,0x00000000}},	//   _गिलक, wigb, --, --, 
   {{0x79800161,0x9f58056a,0x66056c8c,0x80c80154}},	//   _ofow, _porá_, _yoik, রিষ্, 
   {{0x1cc01f21,0xb5f972a7,0xd9ac0011,0x00000000}},	//   _ཀྱང_, zmán, ক্তম, --, 
   {{0x7c7000d1,0xe3b06e92,0x00000000,0x00000000}},	//   зғуч, _عری_, --, --, 
   {{0xda780232,0x798001e1,0x6e2972a8,0x644000e4}},	//   _buď_, _afow, sigb, ĩmig, 
   {{0x9f58cd11,0x7a3c00e2,0x78a0005b,0x7c380051}},	//   _torá_, zīte, _avov, _djtr, 
   {{0xb05802f6,0xa2d800e1,0x628801e4,0x798001ef}},	//   _epät, मबत्, ŭdog, _cfow, 
   {{0x6e3801f0,0xb5f801ed,0x660572a9,0x2d8c063f}},	//   _ijub, tmán, _roik, mbge_, 
   {{0x79800472,0x6d58a0f0,0x78a00010,0x27140213}},	//   _efow, _izua, _dvov, lənə_, 
   {{0xb5f8066d,0x66040664,0x78a1564d,0x7980015d}},	//   rmán, _poik, _evov, _ffow, 
   {{0x7a3c0b13,0x2d8c0066,0xb5f972aa,0xb340025c}},	//   tīte, nbge_, smán, ħħli, 
   {{0x660572ab,0xb5f80008,0x684003e6,0x00000000}},	//   _voik, mmál, _وێبل, --, 
   {{0x66040161,0xb5f80008,0x68f8022e,0x60c001f4}},	//   _woik, lmál, mxud, _ämmi, 
   {{0x660572ac,0x78a00099,0x7a3c411e,0x44380051}},	//   _toik, _zvov, sīte, _vjp_, 
   {{0x6d5802ea,0x6e3972ad,0xdddc00ef,0x00000000}},	//   _ozua, _njub, _otrš, --, 
   {{0x291d72ae,0x7f540092,0x271403e3,0x00000000}},	// [26720] nzua_, _ዜናዎች, dənə_, --, 
   {{0xefcc044e,0x6e3800d2,0x357c044e,0x80c8015b}},	//   _ኣበይ_, _ajub, _ቦታታት_, রিল্, 
   {{0x6d5846d8,0xe9fc001e,0x69c80221,0x1cc0031c}},	//   _azua, _ngắm_, _obge, _ཀཱང_, 
   {{0xb05972af,0x68e80477,0x3ea400e2,0x00000000}},	//   _spät, _orgd, ņoto_, --, 
   {{0x6e380960,0x80d004c5,0x61e572b0,0xfe9c0150}},	//   _djub, _সপক্, mdil, _اﻳﺘﺎ_, 
   {{0x60c572b1,0x69c809f0,0x7ff436fe,0x6e3972b2}},	//   mtim, _abge, _اسحا, _ejub, 
   {{0x6d58043b,0x78a01347,0x60c572b3,0xb058023a}},	//   _ezua, _svov, ltim, _epäs, 
   {{0xeaac0046,0xb5f80321,0xd7f8054e,0x76a801a9}},	//   رعى_, gmál, rmăm_, қтов_, 
   {{0x60c572b4,0x69c800e4,0x9f5851bb,0x61e5189a}},	//   ntim, _dbge, _borç_, idil, 
   {{0x765c02d3,0x61e572b5,0x60c572b6,0xcc840133}},	//   _shqy, hdil, itim, _بۆوه_, 
   {{0x60c418db,0xd5b0007b,0x61e572b7,0x99e401ef}},	//   htim, وفد_, kdil, _šňup, 
   {{0x60c572b8,0x7980009a,0x20180153,0x1dc80b98}},	//   ktim, _ufow, _llri_, रभित, 
   {{0x60c4044e,0x61e572b9,0xdb180793,0x8a440228}},	//   jtim, ddil, gevö, _بئلم, 
   {{0x61e572ba,0x56940006,0x38840153,0x237400ae}},	//   edil, _дакт, ėtrą_, كافح, 
   {{0x60c402d5,0x1dc80da0,0xf1a572bb,0xb6840132}},	//   etim, रभात, йран, _اشتى, 
   {{0x60c402d3,0x61e4ca60,0x2cac022c,0xdb181196}},	//   ftim, gdil, yrgd_, bevö, 
   {{0x60c44700,0x3e7c0129,0xdb18000d,0xa074004e}},	// [26730] gtim, _aït_, mevõ, згуч, 
   {{0xdb1800c5,0x63c80118,0x61e4b8b4,0xd838007f}},	//   levõ, ěrný, adil, nnč_, 
   {{0x61e572bc,0x60c56f37,0x0d980bb0,0xdddc07f5}},	//   bdil, atim, атлы_, _strš, 
   {{0xdb180037,0x60c40334,0x201802d2,0x35a803d4}},	//   nevõ, btim, _elri_, গ্ৰহ, 
   {{0x8c3c029f,0xb5e00154,0x00000000,0x00000000}},	//   _avşa, যাপচ, --, --, 
   {{0xb058005b,0xdb180037,0x00000000,0x00000000}},	//   _epär, hevõ, --, --, 
   {{0xb5f8041e,0x5f9572bd,0x63a8033f,0x6e38031c}},	//   tmál, _хист, ódni, _tjub, 
   {{0x291c05f5,0x6d5801c4,0x6e3802d0,0x3cb035e3}},	//   tzua_, _tzua, _ujub, чйәр, 
   {{0xb5f972be,0x6d580311,0xdb180037,0x00000000}},	//   rmál, _uzua, devõ, --, 
   {{0x61e4c50d,0xb5f82833,0x06c83da1,0xf1bd72bf}},	//   zdil, smál, агой_, _smál_, 
   {{0x61e572c0,0x9f5800a2,0x60c434ae,0x00000000}},	//   ydil, _gorä_, ztim, --, 
   {{0x60c481f1,0x69c802d0,0x61e40009,0xdb1801f4}},	//   ytim, _ubge, xdil, tevö, 
   {{0x07a4260d,0x60c4036b,0x58d401c6,0xc7a534a1}},	//   _далн, xtim, _ноцт, _дилк, 
   {{0xf1bc0154,0xc81c0092,0x00000000,0x00000000}},	//   _acá_, _ስለሆን, --, --, 
   {{0x60c572c1,0x61e572c2,0xdb180793,0x7a3c00de}},	//   wtim, tdil, sevö, līta, 
   {{0x60c572c3,0xe8c40327,0x9f58007c,0xd05c06be}},	//   ttim, _ཁྱོག, _jorå_, _irsə, 
   {{0x60c4e38b,0x43741b74,0x7a3c0aed,0xe9fc01fb}},	// [26740] utim, _мунт, nīta, _ngậm_, 
   {{0xb0596d88,0x21200010,0x600001f4,0x00000000}},	//   _spär, rzih_, _yömy, --, 
   {{0xc2c572c4,0x7a3c0882,0x00000000,0x00000000}},	//   _بيجي, hīta, --, --, 
   {{0x60c572c5,0x7a3c02b5,0xdce00139,0x61e401b9}},	//   ptim, kīta, _semı, qdil, 
   {{0x973c0989,0x60c572c6,0xbb500023,0x00000000}},	//   maće, qtim, _ምዕቡላ, --, 
   {{0xe8c40156,0x973c0989,0x7a3c00da,0x9f580124}},	//   _ཁྱེག, laće, dīta, _porä_, 
   {{0x2b740b43,0xd9103bd6,0x6d600024,0xaec000f3}},	//   زینگ_, کیش_, _įvaž, _обрл, 
   {{0x973c00f3,0xd9f8005b,0x00000000,0x00000000}},	//   naće, сниц_, --, --, 
   {{0xdcf8066d,0xd8380100,0xdce003e0,0x41a0000d}},	//   _دہشت_, tnč_, _temı, _ओजनस, 
   {{0x973c0114,0xb5f80005,0xac140063,0xeb9400d8}},	//   haće, rmám, _дођу_, _миу_, 
   {{0xdb18033d,0x7bc80368,0x973c0960,0xdb20005b}},	//   tevõ, mffu, kaće, ätän, 
   {{0x973c3421,0xeb301075,0x7bc80142,0x7a3c00ef}},	//   jaće, _تىمد, lffu, bīta, 
   {{0x973c009b,0xe4e40212,0x7a3c00e2,0xe3e40011}},	//   daće, мірн, cīta, মানব, 
   {{0x67d0010b,0x7bc80142,0x77900133,0xb4d8012d}},	//   _жошу, nffu, _تیدا, _ठनी_, 
   {{0xfd5401f2,0xb3540753,0xdb180254,0x00000000}},	//   tubọ, تیدا_, pevõ, --, 
   {{0x973c05ce,0xd9ac015b,0xdb1801d3,0x00000000}},	//   gaće, ক্রম, ggvé, --, 
   {{0x64404a34,0xb1440244,0x00000000,0x00000000}},	// [26750] émic, زیسم_, --, --, 
   {{0x58bc00cc,0x00000000,0x00000000,0x00000000}},	//   _অনাঅ, --, --, --, 
   {{0x7a3c00de,0x7bc80142,0x8f54007b,0x8d9400be}},	//   zīta, dffu, أناش, كلاش, 
   {{0x7c240024,0xb058005b,0xc3300677,0xa2d819cc}},	//   _įkra, _epäp, _טוי_, मबर्, 
   {{0x7c243012,0x00000000,0x00000000,0x00000000}},	//   _ůkra, --, --, --, 
   {{0x1c380166,0x00000000,0x00000000,0x00000000}},	//   озчы_, --, --, --, 
   {{0x20240075,0xb5f801ed,0x2d9401e0,0x00000000}},	//   _تېلې, rmáj, _һөҙө_, --, 
   {{0xdce8068f,0x7a3c1991,0xf1c800dc,0x63bc0427}},	//   _śląs, tīta, ाभिन, zgrn, 
   {{0xad2000db,0x00000000,0x00000000,0x00000000}},	//   _تۉشى, --, --, --, 
   {{0x87242e3f,0x7a3c198e,0x973c00f3,0x00000000}},	//   змож, rīta, zaće, --, 
   {{0x497402dd,0x7a3c00e2,0x00000000,0x00000000}},	//   _елес, sīta, --, --, 
   {{0x3ebc03a1,0x19b80276,0xda0800f1,0x998401e2}},	//   _åtte_, _душь_, _ويله_, _قلمو, 
   {{0x973c0989,0xae000037,0x9574004e,0x00000000}},	//   vaće, _रचनन_, дырч, --, 
   {{0x1e080950,0x00000000,0x00000000,0x00000000}},	//   _वक्ष_, --, --, --, 
   {{0x973c3421,0x83542162,0x00000000,0x00000000}},	//   taće, سپرا, --, --, 
   {{0x057432f3,0xd5ec0208,0x9244069d,0x00000000}},	//   _عابد, _già, _የብርሃ, --, 
   {{0xb14172c7,0x973c0b91,0x7bc8015d,0x00000000}},	// [26760] ентл, raće, yffu, --, 
   {{0x973c00f3,0x00000000,0x00000000,0x00000000}},	//   saće, --, --, --, 
   {{0x973c05ce,0xf4840424,0x42e8156c,0x00000000}},	//   paće, _وایی, _умно_, --, 
   {{0xfca800aa,0xc10400ec,0x9f5800e5,0x00000000}},	//   ماتو_, _فوجي, _korú_, --, 
   {{0xdb080036,0xf1b008a8,0x6e20017a,0xdb180162}},	//   _iddé, _אסר_, ënba, lfvø, 
   {{0xdddc00cd,0x3f6800d8,0x81bc00eb,0x81cc00eb}},	//   _kurū, _гиго_, _ইসি_, _শফি_, 
   {{0xd9e0009e,0x935400d1,0x7bc87f17,0x00000000}},	//   ভাসম, ﺘﯩﺪﯗ_, rffu, --, 
   {{0xb5f972c8,0xaa6172c9,0xf2d0011a,0x00000000}},	//   rmák, нтык, געה_, --, 
   {{0x80c8015b,0x3eb80115,0xe94000e5,0xf41c0037}},	//   রিক্, lupt_, ٹرٹی, späi_, 
   {{0x3cf80034,0x6fcc0406,0xf090011a,0x00000000}},	//   ्हीं_, स्पं, ענת_, --, 
   {{0xdddc00b8,0xb5f80332,0x00000000,0x00000000}},	//   _nurū, lmái, --, --, 
   {{0xb5f800c6,0xb4b00116,0x2f58011a,0xf990007b}},	//   omái, нимә, מדינ, _أبا_, 
   {{0xf8648e38,0x9330001f,0x7a3c00e2,0x67340023}},	//   _евдо, _አስቸኳ, līto, _ብዘይብ, 
   {{0xb34506c9,0x1cc00327,0xb5f802f0,0xc0f80092}},	//   _naçõ, _ཀཱན_, zmáh, _ሊሰራ_, 
   {{0xd6d000c6,0x6440067c,0x00000000,0x00000000}},	//   _شقة_, émia, --, --, 
   {{0x779001d5,0x630401d5,0x90980395,0x00000000}},	//   _تیگا, روقل, жват_, --, 
   {{0xd5ec01fb,0x764c1be1,0xc0c0728c,0xe63003e3}},	// [26770] _giá, mocy, кәри, _həşə, 
   {{0x13a404d3,0xd01000f1,0x00000000,0x00000000}},	//   _زۆری_, خلئ_, --, --, 
   {{0xdddc00cd,0xd2501424,0x00000000,0x00000000}},	//   _gurū, _لند_, --, --, 
   {{0x764d72ca,0xf0747400,0x5c4c02d3,0xe6300213}},	//   nocy, _нимә_, _ንሃገር, _məşə, 
   {{0x76a001e1,0x32e401e1,0x00000000,0x00000000}},	//   _yíyá, bíyá_, --, --, 
   {{0xdcac0491,0x764d72cb,0xdd1c00e2,0xac9401d5}},	//   _҉҉_, hocy, kšņo, قنچا_, 
   {{0x764d72cc,0xb5f800ae,0xe63003b9,0x3b0402e8}},	//   kocy, amái, _nəşə, дещо_, 
   {{0x0888036b,0x1cc0031c,0x5e6400d1,0xe7cc06ff}},	//   обий_, _ཀྱམ_, _كۆلە, त्नप, 
   {{0x32080034,0x8cd4033f,0x48bc0183,0x764cb180}},	//   _mocy_, _मैचो, ্ট্ৰ, docy, 
   {{0xf8ac168d,0x2d9c0076,0xe63000ac,0x7d142dba}},	//   شکه_, _heue_, _bəşə, øyse, 
   {{0x7a3c0171,0x00000000,0x00000000,0x00000000}},	//   cīto, --, --, --, 
   {{0x32080034,0x764ccc86,0xc9140063,0x00000000}},	//   _nocy_, gocy, _одећ, --, 
   {{0xe8e972cd,0xdddd72ce,0x69d8003e,0x70d40073}},	//   _دراو_, _surū, meue, डबोल, 
   {{0x69d972cf,0x2d9d72d0,0xdddd72d1,0x00000000}},	//   leue, _leue_, _purū, --, 
   {{0x27e40165,0xb3440798,0xe63006be,0x00000000}},	//   _iann_, _raçõ, _gəşə, --, 
   {{0x27e46984,0x2d9c09f0,0x764d72d2,0x69d803fa}},	//   _hann_, _neue_, cocy, neue, 
   {{0x27e572d3,0x80a802bf,0x7dfc0311,0x614400d1}},	// [26780] _kann_, ював_, _lăsâ, رىئە, 
   {{0x25a172d4,0x69d972d5,0x7c240024,0x92bc05ac}},	//   _heil_, heue, _įkro, _ইনৰ_, 
   {{0x25a172d6,0x27e572d7,0xe7cc0c00,0x24800076}},	//   _keil_, _mann_, त्यप, _huim_, 
   {{0x27e572d8,0x3eb972d9,0xa3c82ce6,0x0084136b}},	//   _lann_, rupt_, ोजक_, _олмо, 
   {{0x3cf8006d,0x25a0007d,0x6da03a33,0x27e40418}},	//   ्हें_, _meil_, тича, _oann_, 
   {{0xfa88006c,0xb5f80597,0x27e40489,0x2d9c05e4}},	//   осий_, rmái, _nann_, _eeue_, 
   {{0x25a04afb,0x764d72da,0xaa840075,0x2d9c0076}},	//   _oeil_, yocy, ونوم_, _feue_, 
   {{0x27e400a3,0x69d85ee8,0x25a00d92,0x7a3c0aea}},	//   _aann_, geue, _neil_, rīto, 
   {{0x27e572db,0xc81c069c,0xada09c3a,0x6da00131}},	//   _bann_, _ስለምን, _шатл, _шита, 
   {{0x27e40393,0x7d0001f0,0x2d9c0156,0x2c0800e5}},	//   _cann_, mxos, _zeue_, _وعلی_, 
   {{0x27e4536b,0xec1172dc,0x25a172dd,0x764c2a5c}},	//   _dann_, _جولد, _beil_, tocy, 
   {{0x27e403d5,0x644006af,0xd1f8001f,0x3a3003e0}},	//   _eann_, émin, ገበት_, _öyp_, 
   {{0x764d72de,0x27e572df,0x25a00c3a,0xadc0001e}},	//   rocy, _fann_, _deil_, _hoản, 
   {{0x27e572e0,0xe63003be,0xe72c104a,0x764c0113}},	//   _gann_, _təşə, اصی_, socy, 
   {{0x25a0964d,0xf64405f5,0x69c972e1,0x70d4072a}},	//   _feil_, _охин, थ्वी, डब्ल, 
   {{0x25a172e2,0x764c0175,0x80c803d4,0x00000000}},	//   _geil_, qocy, ৰিন্, --, 
   {{0x27e40dd4,0x2d9d2886,0x248000db,0xa15972e3}},	// [26790] _yann_, _reue_, _guim_, дату_, 
   {{0x25a172e4,0x27e400d8,0x00000000,0x00000000}},	//   _zeil_, _xann_, --, --, 
   {{0x53340262,0x6e2005e4,0x69d80208,0xd5ec0051}},	//   _чент, ënbo, yeue, _giã, 
   {{0x2dd8007b,0x22840354,0x00000000,0x00000000}},	//   تبطة_, _шуьг, --, --, 
   {{0x2d9c062c,0xf15003e6,0x69d80137,0xd250764c}},	//   _veue_, _شکرک, veue, _لنگ_, 
   {{0x9c6408f0,0xadec000d,0x00000000,0x00000000}},	//   نهنو, _घोरन_, --, --, 
   {{0x27e572e5,0x69d8cac5,0x2ee00109,0x2d9c0156}},	//   _rann_, teue, _usjf_, _teue_, 
   {{0x27e572e6,0xaca002e3,0x3ebc049f,0x2d9c02b5}},	//   _sann_, _arụn, _åtta_, _ueue_, 
   {{0x27e43462,0x69d972e7,0x973c353f,0x9f5800b5}},	//   _pann_, reue, vaća, _sorø_, 
   {{0x248172e8,0x25a172e9,0x69d972ea,0x5bb800cf}},	//   _ruim_, _seil_, seue, _олуя_, 
   {{0x27e542e9,0x2480327f,0x25a172eb,0xe9fc001e}},	//   _vann_, _suim_, _peil_, _ngầm_, 
   {{0x27e404d1,0x6fcc3abc,0x00000000,0x00000000}},	//   _wann_, स्तं, --, --, 
   {{0x27e572ec,0x973c0b91,0x24800137,0x9f580ba1}},	//   _tann_, raća, _quim_, _enrè_, 
   {{0x25a172ed,0x26c42263,0x37e172ee,0xc2100014}},	//   _weil_, _قطعی_, _бошг, گٔر_, 
   {{0x25a172ef,0xd87401f7,0xadc00051,0x00000000}},	//   _teil_, _شاهب, _xoản, --, 
   {{0x24801c1d,0xc0cc1ee0,0xa3dc00ab,0x00000000}},	//   _tuim_, _ብሔር_, _ठसक_, --, 
   {{0x527572f0,0x806400d4,0x00000000,0x00000000}},	// [267a0] туру, еваж, --, --, 
   {{0x65640944,0x00000000,0x00000000,0x00000000}},	//   _izih, --, --, --, 
   {{0xb5f8ec21,0xf41c023a,0x00000000,0x00000000}},	//   rmáv, rpät_, --, --, 
   {{0x645c8b1c,0xc5b0015b,0xe7cc412f,0x7d0064cb}},	//   llri, ট্রপ, त्तप, txos, 
   {{0x224172f1,0x98b84424,0xdb1801a8,0xfb84013d}},	//   mnik_, ārī_, rgví, ныйн, 
   {{0x224172f2,0x645c00fb,0x7c640131,0x973c01a6}},	//   lnik_, nlri, راشل, daćn, 
   {{0xcfdc0c58,0xb5f85178,0xeaad72f3,0x645c017a}},	//   ঠাখন, omát, معي_, ilri, 
   {{0x22400476,0xfce40d84,0x58d53a15,0x65640b6f}},	//   nnik_, _побо, воит, _ozih, 
   {{0x224172f4,0xd7f00597,0xd1f00020,0x65640223}},	//   inik_, لكة_, _ግንብ_, _nzih, 
   {{0x224172f5,0x645c0334,0x3ea400de,0xed54014b}},	//   hnik_, jlri, ņotu_, _чоу_, 
   {{0x65646105,0xa8200214,0x00000000,0x00000000}},	//   _azih, دکنن, --, --, 
   {{0x394572f6,0xdb140113,0x645c0076,0x6a98010f}},	//   _txos_, _ñañi, elri, _זשאנ, 
   {{0x628801e4,0xaca00051,0x786402d2,0x00000000}},	//   ŭdol, _trụn, eðve, --, 
   {{0x65640943,0x2240102c,0xf77000e5,0x00000000}},	//   _dzih, enik_, _یاں_, --, 
   {{0x65640928,0x973c0552,0x66e01b88,0xdb0800bc}},	//   _ezih, maćo, _боја, _oddí, 
   {{0xb5f85178,0xa7580375,0x224172f7,0x7a3c00de}},	//   gmát, _מדור, gnik_, dītk, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [267b0] --, --, --, --, 
   {{0x22400ad4,0xb27000d1,0xb5f803b2,0x09dc00bc}},	//   anik_, _әкмә, flág, _मस्य, 
   {{0x22400fb7,0x929572f8,0xf1bc68f1,0x00000000}},	//   bnik_, _шанц, _smáu_, --, 
   {{0x4c9402e8,0x817415bf,0xf41c01f4,0x00000000}},	//   видс, رنەچ, ppäs_, --, 
   {{0x01c80154,0x9e2400db,0x00000000,0x00000000}},	//   _লোকদ, دىنو, --, --, 
   {{0xd72002e5,0x5f840ae5,0x973c009b,0xf09c0241}},	//   मनाथ_, _مۇكە, jaćo, _iwà_, 
   {{0xb5f80022,0x09e572f9,0x7a3c0055,0x00000000}},	//   olád, войн, cītk, --, 
   {{0xb5e00154,0x89d401ec,0xe6c402d2,0x00000000}},	//   যাঁচ, тікш, _ógéð, --, 
   {{0xe9fc004d,0xceb80022,0x87b8da28,0x00000000}},	//   _ngấm_, _хәҷ_, мунт_, --, 
   {{0x224172fa,0x1a240014,0x78640162,0x00000000}},	//   znik_, ٖریُ, yðve, --, 
   {{0xb5f80316,0x00000000,0x00000000,0x00000000}},	//   klád, --, --, --, 
   {{0x22404ae6,0x9a8400a8,0x6d585559,0x3ab001ee}},	//   xnik_, _суфл, _kyua, _тәшт, 
   {{0xb5f80579,0xf09c01e1,0x13300092,0x78a40419}},	//   vmát, _nwà_, _አስገነ, škvr, 
   {{0x2240006d,0x9478005b,0x46f401a9,0x80b0012d}},	//   wnik_, ессу_, _ачит, ेंसे, 
   {{0xf09c0241,0x425448a9,0x00000000,0x00000000}},	//   _awà_, втат, --, --, 
   {{0x78641f60,0x224020ac,0xb5f82d3f,0x9f600205}},	//   rðve, unik_, umát, ğsün_, 
   {{0x6d580190,0x00000000,0x00000000,0x00000000}},	// [267c0] _nyua, --, --, --, 
   {{0x22408c7a,0xb5f972fb,0xf41c01c7,0x0fe804a9}},	//   snik_, smát, spär_, нлуқ_, 
   {{0x22401dd5,0xf09c0241,0x81c80154,0xadc00208}},	//   pnik_, _ewà_, লজব_, _soạn, 
   {{0xee2c0451,0xb5f85923,0xf41c00a2,0x00000000}},	//   يٽل_, lmár, lpäp_, --, 
   {{0x6cc00b87,0x55ac008f,0x00000000,0x00000000}},	//   ийца, ליאַ, --, --, 
   {{0xdd0c012d,0xc1a00037,0x00000000,0x00000000}},	//   _póło, _ओजुग, --, --, 
   {{0x7a3c00da,0x973c07f5,0xbea40fc0,0xab740214}},	//   līti, vaćo, _шавк, نمها_, 
   {{0x26140261,0x3ea4005f,0x8c9402dd,0xd948010b}},	//   _mãos_, ņots_, _әрті, нҗек_, 
   {{0x7a3c0f40,0x6fcc01f9,0x00000000,0x00000000}},	//   nīti, स्वं, --, --, 
   {{0xb5f800dd,0x00000000,0x00000000,0x00000000}},	//   ymás, --, --, --, 
   {{0x92bc03d4,0x62880115,0x52e0012d,0x00000000}},	//   _ইন্_, ŭdoj, _पनेस, --, 
   {{0x7a3c1d76,0x86f400f2,0x0b940023,0x00000000}},	//   kīti, اکوس_, _ግዕዙይ_, --, 
   {{0x6d580190,0xb5f80122,0x2edc07b6,0xe4a401d5}},	//   _xyua, vlád, _नन्त, ирро, 
   {{0x7a3c005f,0x00000000,0x00000000,0x00000000}},	//   dīti, --, --, --, 
   {{0xd8381aff,0x9f5801e1,0x228401c6,0xa878010f}},	//   mič_, _moró_, иутг, _קאור, 
   {{0xd8386185,0x9f5801e1,0x00000000,0x00000000}},	//   lič_, _loró_, --, --, 
   {{0xe7cc084a,0x746801c6,0x9f5801e1,0x22581572}},	// [267d0] त्वप, _оров_, _ooró_, титы_, 
   {{0xb5f972fc,0x6d5800b5,0xf65c0393,0x00000000}},	//   slád, _ryua, llæ_, --, 
   {{0xd370034c,0x6d5805b1,0x7d1405ac,0x5ea40ee8}},	//   _دهد_, _syua, øysn, لملل, 
   {{0xd8380427,0xb5f972fd,0x7a3c00de,0x00000000}},	//   hič_, lláb, bīti, --, 
   {{0xd83809a8,0x7a3c005f,0xdb1800b5,0xad2403e6}},	//   kič_, cīti, ngvæ, خراو, 
   {{0xcb6881a0,0xd838151c,0x251c0bd9,0x2704013f}},	//   нале_, jič_, וודא, sɑni_, 
   {{0x9f5801e1,0x00000000,0x00000000,0x00000000}},	//   _doró_, --, --, --, 
   {{0x9df80276,0xb5f800d2,0x3ed800c8,0x5fd40a59}},	//   _инст_, hláb, _אַמא, ठ्ठल, 
   {{0x79380020,0xd8380010,0x685c0092,0xebc400f0}},	//   _ኢንቨስ, fič_, _ህብረት, _аљен, 
   {{0x48050878,0xd83809a8,0x26c8012d,0x28a4009d}},	//   упов, gič_, ńcom_, нсүү_, 
   {{0x38c95a58,0x66040588,0x7a3c005f,0x00000000}},	//   وایی_, иҿка, zīti, --, 
   {{0x9f580241,0x628801e4,0x7c2400c0,0x00000000}},	//   _korò_, ŭdok, _įkri, --, 
   {{0xd83819d6,0xb5f801d3,0x00000000,0x00000000}},	//   bič_, tmár, --, --, 
   {{0xc7a556b9,0x00000000,0x00000000,0x00000000}},	//   _сикк, --, --, --, 
   {{0xb5f972fe,0x9f5801e1,0xca442d40,0x6ff800de}},	//   rmár, _lorò_, ﺘﺘﺎ_, _mācē, 
   {{0xe7cc810c,0x7a3c7028,0x261400d8,0xb5f972ff}},	//   त्रप, tīti, _vãos_, smár, 
   {{0xef140075,0x00000000,0x00000000,0x00000000}},	// [267e0] ңму_, --, --, --, 
   {{0x7a3c0f40,0xf59001d3,0x74980677,0x00000000}},	//   rīti, _پلیج, _רייפ, --, 
   {{0x7a3c00e2,0xdb080216,0xa2a008ec,0x00000000}},	//   sīti, _oddá, गीश्, --, 
   {{0xd8380010,0x9f5801e1,0x00000000,0x00000000}},	//   zič_, _soró_, --, --, 
   {{0x7a3c005f,0x9f5800d8,0x627c002e,0x00000000}},	//   nūte, _poró_, _yōon, --, 
   {{0xdb0881f1,0xdc84001f,0x3f9818a2,0xccf51bf5}},	//   _addá, _ምኒልክ_, _سپرد_, шқу_, 
   {{0xd83886f5,0xdddc0276,0x00000000,0x00000000}},	//   vič_, _curţ, --, --, 
   {{0x75f8013d,0x2010033f,0xd9f80108,0xab9000d1}},	//   _mäzä, żnić_, тниц_, للۇغ, 
   {{0xd8380dfe,0x313400df,0xb5f801ef,0x00000000}},	//   tič_, ָנים_, hlác, --, 
   {{0xb5f800d0,0x81c800eb,0x00000000,0x00000000}},	//   klác, লজি_, --, --, 
   {{0xeb952a6c,0xd8397300,0x7a3c00e2,0xb9c49dc7}},	//   _сих_, rič_, dītv, _مقاي, 
   {{0xd8380122,0xb5f81f98,0x3dc57301,0x00000000}},	//   sič_, dlác, ngow_, --, 
   {{0xd8383831,0x04a40124,0x00000000,0x00000000}},	//   pič_, иурҭ, --, --, 
   {{0x75f80139,0xf2e414a3,0xb5f8368c,0xd6ec0210}},	//   _bäzä, любо, flác, _जनपथ_, 
   {{0x78a00810,0x75f80139,0x26f450a3,0x59b800c5}},	//   _hwov, _cäzä, _مريخ_, _इयार, 
   {{0x973c0558,0xf60803e6,0xd66800ec,0x14f8009b}},	//   haćk, _ستبه_, _جمعو_, _анић_, 
   {{0xc5ec004b,0xc1a402dd,0xdb180254,0x940400f2}},	// [267f0] _کړۍ_, рысқ, lgvä, _نوظه, 
   {{0x78a017fa,0xc3c17302,0x3dc4058a,0x00000000}},	//   _mwov, _мөсл, egow_, --, 
   {{0x627c002e,0xdb180267,0x8d940131,0x7980058a}},	//   _kōol, ngvä, للاش, _ogow, 
   {{0x7980e4fc,0x8d785821,0x3dc40009,0xcd900023}},	//   _ngow, نماء_, ggow_, _ዝበዝሓ_, 
   {{0x627c002e,0xec14013d,0xa27403b9,0x00000000}},	//   _mōol, ледә_, ləşə_, --, 
   {{0x79800c8c,0x00000000,0x00000000,0x00000000}},	//   _agow, --, --, --, 
   {{0x75f800fd,0x6ff800ef,0xa27403b9,0x00000000}},	//   _xäzä, _vācē, nəşə_, --, 
   {{0x5f448efb,0x60d400e4,0x66d80139,0xca74010b}},	//   _انفل, _ñemú, _läkö, шулы, 
   {{0xabb00139,0xf8a4013d,0x3ad000d1,0x00000000}},	//   _газә, авык_, ميۈز, --, 
   {{0x66d8049b,0x798003ac,0x5c740484,0x7a3c00de}},	//   _näkö, _egow, _глут, dītu, 
   {{0x4e180dad,0x270c0490,0xdb180267,0x5c04104e}},	//   _दवाई_, ाहेर_, ggvä, _уята, 
   {{0xdddd7303,0x7a3c02b1,0x9f580252,0x2c000073}},	//   _kurš, tūte, _morð_, लावं_, 
   {{0x98b80276,0xdddd7304,0x2cac003e,0xbd0001e1}},	//   ără_, _jurš, nsgd_, _èéti, 
   {{0xe7850878,0xdddc0427,0xb5f802f0,0x070801c8}},	//   _судо, _murš, tlác, _ليتي_, 
   {{0x9f580d12,0x3dc4058a,0x00000000,0x00000000}},	//   _norð_, ygow_, --, --, 
   {{0xc4842082,0x7a3d7305,0x85046ea9,0x00000000}},	//   _клик, pūte, _نوبن, --, 
  
   {{0xb5f800d0,0x7a3c00ef,0x00000000,0x00000000}},	// [26800] slác, cītu, --, --, 
   {{0xb5f80122,0x9f5809f3,0x03c41e87,0xeff40092}},	//   plác, _borð_, _өсүм, _ለቀው_, 
   {{0x9f58002f,0xedd000ec,0x00000000,0x00000000}},	//   _darß_, ڪيند, --, --, 
   {{0xfca88b4d,0xd36c0132,0xdddc00ef,0xdb1801e3}},	//   ناتو_, _سۇق_, _burš, ngvå, 
   {{0x61e57306,0x9d2400bd,0xedd001f7,0x00000000}},	//   meil, বপ্ন_, تيند, --, 
   {{0x79808b2e,0xec101178,0x61e57307,0x60c57308}},	//   _sgow, يوند, leil, muim, 
   {{0x3ce4014f,0x00000000,0x00000000,0x00000000}},	//   swov_, --, --, --, 
   {{0x78a00d29,0x61e57309,0xdddc139f,0x4dfc000d}},	//   _pwov, neil, _furš, _रोपै_, 
   {{0x973c0bb8,0x60c5730a,0xdddc010e,0x7e61730b}},	//   maći, nuim, _gurš, mlop, 
   {{0x61e5730c,0x973c07f5,0xbc7000cf,0xa9640120}},	//   heil, laći, _بۇتب, шиња_, 
   {{0x61e4049b,0x7bd80218,0x44280597,0x60c5730d}},	//   keil, _ibtu, dhb_, huim, 
   {{0x78a007a8,0x7e61730e,0x60c5730f,0x6c800efb}},	//   _twov, nlop, kuim, _الەم, 
   {{0x61e57310,0x60c43306,0x66d801b8,0x66e8000d}},	//   deil, juim, _päkö, _छैठक_, 
   {{0xb4d423ef,0x7e617311,0x627c00e8,0x31280092}},	//   _सही_, hlop, _dōom, ዲያቀር, 
   {{0x7e617312,0xf1a4311b,0x61e57313,0x3a257314}},	//   klop, иран, feil, _klop_, 
   {{0x61e57315,0x60c40421,0xf1bc05f7,0xb5f8032e}},	//   geil, fuim, _bláa_, bláa, 
   {{0x7cd80a30,0x7e602d91,0x99840024,0xd5ec0208}},	// [26810] nārā, dlop, limų_, _nhả, 
   {{0x7e617316,0x3a240137,0x7af801b9,0x72e401d9}},	//   elop, _llop_, _ortt, _پہرِ_, 
   {{0x7cd80882,0x61e455e9,0x99840006,0x6440004e}},	//   hārā, beil, nimų_, èmie, 
   {{0xdef80184,0x7bd8011f,0x7cd80882,0x60c57317}},	//   шыу_, _abtu, kārā, buim, 
   {{0x7af8825f,0x8c3c00a2,0x60c55275,0xd5ec0208}},	//   _artt, _awşa, cuim, _chả, 
   {{0x7bd80076,0x99840006,0x7c2801ab,0x00000000}},	//   _cbtu, kimų_, ghfr, --, 
   {{0x99840006,0xdb64001f,0x7e617318,0x00000000}},	//   jimų_, _ትዕዛዝ_, blop, --, 
   {{0x7e617319,0x7bd8013f,0x99840006,0x3a240109}},	//   clop, _ebtu, dimų_, _clop_, 
   {{0xe7a40075,0x7af803ac,0x6e200af9,0x44280076}},	//   لۇشى_, _ertt, ënbu, yhb_, 
   {{0xd90c00dd,0x61e5731a,0x7c29731b,0x3a240108}},	//   ئیو_, zeil, chfr, _elop_, 
   {{0x99840153,0x61e5731c,0x60c4022e,0x00000000}},	//   gimų_, yeil, zuim, --, 
   {{0x08f9252c,0x3a252b05,0xd8980133,0x61e401f4}},	//   _مرتب_, _glop_, اڕۆژ_, xeil, 
   {{0x61e5731d,0x7a78008f,0x3940002d,0x05540108}},	//   veil, _ערנס, ûkst_, стня, 
   {{0x61e5731e,0x60c420e5,0x7af8023a,0x7e6001d3}},	//   weil, vuim, _yrtt, zlop, 
   {{0x61e5731f,0xc6941d93,0x7e617320,0xb5f83ac2}},	//   teil, _اشتع, ylop, mlán, 
   {{0xb5f80525,0x60c57321,0x3ebc03cd,0x96b8004e}},	//   llán, tuim, _åtti_, _тушу_, 
   {{0x7e602178,0x66043917,0x61e57322,0xf650008d}},	// [26820] vlop, _inik, reil, _מצה_, 
   {{0xdb08006a,0x61e57323,0x60c57324,0x660402d2}},	//   _dedê, seil, ruim, _hnik, 
   {{0x44397325,0x66045282,0x60c57326,0x7a3c0882}},	//   _imp_, _knik, suim, hūta, 
   {{0x44381c06,0x44f40135,0xb5f97327,0xd5ec01fb}},	//   _hmp_, _བློར_, hlán, _phả, 
   {{0x60c57328,0x44380656,0x7e617329,0x66051be7}},	//   quim, _kmp_, rlop, _mnik, 
   {{0x4439732a,0x7e61732b,0x3a242ee4,0x7af80334}},	//   _jmp_, slop, _slop_, _prtt, 
   {{0x6bd00372,0x44383d19,0xbf145c81,0x7e61732c}},	//   ستور, _mmp_, _اوزب, plop, 
   {{0x629d732d,0x99840006,0xd5ec004d,0x41b8000d}},	//   ipro, vimų_, _thả, ेलिस, 
   {{0x44380489,0xd9100344,0xa3c8912c,0x00000000}},	//   _omp_, بیش_, उला_, --, 
   {{0x4438020b,0x99840024,0x7af8008e,0xec747a9c}},	//   _nmp_, timų_, _trtt, _гпу_, 
   {{0x629d732e,0xeb940375,0x7c38035a,0x6a80030d}},	//   jpro, _הדבר_, _imtr, _елха, 
   {{0x4439732f,0x998402d5,0xf608b40e,0xf1bc0332}},	//   _amp_, rimų_, ухой_, _alán_, 
   {{0x44388d34,0xf1bc00d7,0xaa540035,0x00000000}},	//   _bmp_, _blán_, _النا_, --, 
   {{0x7bc97330,0x66057331,0x44397332,0x629d7333}},	//   ngfu, _enik, _cmp_, fpro, 
   {{0x752c14cf,0x629c7bad,0x228400f7,0x667401b9}},	//   szcz, gpro, зууг, تدیر, 
   {{0x66040055,0xf1bc0306,0x00000000,0x00000000}},	//   _gnik, _elán_, --, --, 
   {{0x7c397334,0x629c9154,0x4438009b,0x48240014}},	// [26830] _omtr, apro, _fmp_, _دى۪ق, 
   {{0x44385f24,0x6440004a,0x66040034,0x00cc0131}},	//   _gmp_, émit, _znik, _ﻗﻪﺷﻘ, 
   {{0x629d7335,0xdb080200,0x0cc400fe,0x00000000}},	//   cpro, _dedë, _এনেত, --, 
   {{0x31c4a577,0x4438056a,0xa758010f,0x7c386fe8}},	//   _усов, _zmp_, נדאר, _amtr, 
   {{0x09b003d4,0x7c3801d5,0x628801e4,0x443801f4}},	//   ছলমা, _bmtr, ŭdot, _ymp_, 
   {{0x973c2220,0x2a6c020b,0xdb0801c7,0x270c00cc}},	//   laću, _shgb_, _gedë, ানতো_, 
   {{0x683c01e1,0x921c4142,0xbca400d1,0x00000000}},	//   _ládè, _नवाज_, مگەك_, --, 
   {{0xdb0800f2,0x7a3d7336,0xe8240023,0xabd401d3}},	//   _medè, tūta, _ስለዘሎ, _گزرت, 
   {{0xb5f83b82,0x6e3894a7,0x00000000,0x00000000}},	//   tlán, _imub, --, --, 
   {{0x6604b02f,0xc6200882,0x5fcc0f44,0x7a3c1d76}},	//   _snik, मस्य_, ालयल, rūta, 
   {{0xa5ac0491,0x44397337,0xb5f8fd26,0x46497338}},	//   ḏǭǭ_, _rmp_, rlán, изон_, 
   {{0xb5f829f5,0x44382946,0x7a3c65d4,0xf1bc00c6}},	//   slán, _smp_, pūta, _slán_, 
   {{0x629d7339,0xf1bc0232,0xb5f825fd,0x6e381418}},	//   wpro, _plán_, plán, _mmub, 
   {{0x4add733a,0x7d1403d4,0x6604033f,0x7a3c01e1}},	//   _महाव, øysi, _wnik, _tàtè, 
   {{0x6e382f99,0x629c004c,0xdb08067c,0xd29801ec}},	//   _omub, upro, _cedè, йтті_, 
   {{0x4439733b,0x683c0241,0x973c04a7,0xdb080200}},	//   _wmp_, _fádè, gaću, _sedë, 
   {{0x64410ec1,0x1004038e,0x4439733c,0x291c00ec}},	// [26840] émis, रांश_, _tmp_, nyua_, 
   {{0x629c038f,0x6565733d,0x6e39733e,0x7f45733f}},	//   ppro, _iyih, _amub, оезж, 
   {{0x2c0000c5,0x20c8033f,0xb63004f2,0xd548072d}},	//   लाईं_, िंहध, _رفیع, _نجیم_, 
   {{0x6da0fda6,0x291c037e,0x62880115,0x00000000}},	//   дица, kyua_, ŭdos, --, 
   {{0xb5f800d2,0x22400869,0x7c380208,0x645c0037}},	//   dlál, miik_, _pmtr, oori, 
   {{0x656400ca,0x6e397340,0xdb08030a,0x22400037}},	//   _myih, _emub, _hedé, liik_, 
   {{0xa3dc08a3,0xb4c4032c,0x645d7341,0x7ac402dd}},	//   ण्य_, _उम्_, iori, іске, 
   {{0x2018152d,0x645d7342,0x65640921,0xdb08003e}},	//   _hori_, hori, _oyih, _jedé, 
   {{0x65643c72,0x212087ed,0x80b0033f,0x291c00b5}},	//   _nyih, nyih_, ेंटे, gyua_, 
   {{0x24d002a6,0xccf8033f,0x20197343,0x7c380112}},	//   িবাহ, _myśl_, _jori_, _umtr, 
   {{0x645d7344,0x20197345,0x65657346,0x6fcc02ab}},	//   dori, _mori_, _ayih, स्टं, 
   {{0x20180570,0x65657347,0x22400e14,0x2a8401d3}},	//   _lori_, _byih, jiik_, _főbb_, 
   {{0x1684168d,0x20197348,0x65640230,0x2240011f}},	//   _کاتێ, _oori_, _cyih, diik_, 
   {{0x20197349,0xb8640592,0x2c00033f,0x00000000}},	//   _nori_, _باصو, लाएं_, --, 
   {{0x6564379d,0xdb0804e6,0xb5f801ed,0x973c05be}},	//   _eyih, _bedé, llám, taću, 
   {{0x2240b1a4,0x2ab80a1e,0xdb08359e,0xa2ac5d4f}},	//   giik_, ימלא, _vedè, _जबर्, 
   {{0x2019734a,0xdb08020c,0x973c07f5,0xb5f80332}},	// [26850] _bori_, _wedè, raću, nlám, 
   {{0x2019734b,0x645d734c,0x3cfc0b98,0xf53c005c}},	//   _cori_, cori, लिने_, rbåd_, 
   {{0x2019734d,0xdb0801d3,0xf53c005c,0xb5f80332}},	//   _dori_, _fedé, sbåd_, hlám, 
   {{0x20d404c4,0xdb09734e,0xb5f800e7,0xedc4004b}},	//   bäi_, _gedé, klám, تېري_, 
   {{0x2019734f,0x433c0020,0x00000000,0x00000000}},	//   _fori_, _አስተባ, --, --, 
   {{0x20c40006,0x00000000,0x00000000,0x00000000}},	//   _ўсяг, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6e38a183,0xee3c00ee,0x6ce4003b,0x00000000}},	//   _umub, _öý_, _мізе, --, 
   {{0xa3dc060c,0xb178005c,0xb5f80332,0x00000000}},	//   ण्ड_, _ubåd, rlál, --, 
   {{0x9f58006a,0x65640230,0x645d7350,0x20197351}},	//   _torô_, _ryih, xori, _xori_, 
   {{0x645d7352,0xb5f801ed,0x7d140fac,0x5fcc00bc}},	//   vori, plál, øysv, ालतल, 
   {{0x645d7353,0x21200548,0x99d4007b,0x00000000}},	//   wori, yyih_, _يتنا, --, 
   {{0x645d7354,0xdb0807ea,0x3cfc52be,0xb5f89fd2}},	//   tori, _redé, लिये_, clám, 
   {{0x656407a8,0x78f80375,0xb9780375,0xf91408a8}},	//   _vyih, _לפנו, _פנסי, _מחנך_, 
   {{0x20197355,0x645cadfe,0xf7bc0873,0x6440004a}},	//   _rori_, rori, _ﻣﯘﻧﺪ, émiq, 
   {{0x20197356,0x69d80100,0x20d40037,0x704400d1}},	//   _sori_, nfue, täi_, ۋرلە, 
   {{0x20197357,0x22417358,0x656437ea,0xe6d88153}},	// [26860] _pori_, riik_, _uyih, _बहुज, 
   {{0x20197359,0x645d735a,0x68f80286,0x69d80007}},	//   _qori_, qori, ivud, hfue, 
   {{0xbd89735b,0x7c640075,0xd0580220,0x1ee804fb}},	//   منان_, ۋاتل, іруі_, توای_, 
   {{0x201800e8,0x34b010e8,0x20d426bb,0xb6b8011a}},	//   _wori_, _تمیز, päi_, מצעי, 
   {{0x69d8789d,0xac94007b,0x00000000,0x00000000}},	//   dfue, كننا_, --, --, 
   {{0xc0c01772,0x68f861c4,0x2018006f,0x0fc400d1}},	//   ስከር_, dvud, _uori_, _оқуп_, 
   {{0x3f880521,0xefb1735c,0xb5f801d3,0x68f8000d}},	//   _igbu_, _سینگ, rmáz, evud, 
   {{0xa9c010f5,0xbea42c1d,0x2b74036b,0x5a340120}},	//   нськ, _маҳк, سینگ_, ќнит, 
   {{0xa3ac7b05,0x60c4c352,0x68f80334,0x7a3c00e2}},	//   खरा_, nrim, gvud, sūto, 
   {{0x60c40491,0x2cb40316,0x0ed80014,0x313402e4}},	//   irim, ředí_, _دُہک_, פנים_, 
   {{0x79a5735d,0x3f880521,0xdb244f6f,0x68f80083}},	//   _ерле, _mgbu_, _توای, avud, 
   {{0x60c5735e,0x68f8006f,0xf54c063f,0x78641427}},	//   krim, bvud, kụta_, iðvi, 
   {{0xbabc0c58,0x5fcc012c,0x60c456df,0xa504010b}},	//   _আহিছ, ालाल, jrim, нярл, 
   {{0x60c5735f,0x2bdc0a99,0x00000000,0x00000000}},	//   drim, प्पा, --, --, 
   {{0x60c4033d,0x57a40046,0x3cfc02ab,0x27f400bc}},	//   erim, _ешқа, लिडे_, řená_, 
   {{0xd7f80276,0x25dc012c,0x9fdc0349,0xb8640133}},	//   ldă_, ग्दी_, ঠযোগ, _باڵو, 
   {{0xb5f80af2,0x545400d8,0x75800214,0x622400d1}},	// [26870] hlák, _овит, _سیسم, رىكل, 
   {{0xd7f800a8,0x69d80369,0xa1940116,0x3e6c00c7}},	//   ndă_, zfue, _җарч, výta_, 
   {{0x60c57360,0xa8540375,0xa9200024,0xf08801d5}},	//   arim, לימה_, įžim, _گئجه_, 
   {{0x3f880521,0x5f74f2ff,0x773c02d3,0x3e6c00c7}},	//   _egbu_, رالر, _ኣንስተ, týta_, 
   {{0x6304006c,0x03c80208,0x32d40432,0x00000000}},	//   _قویل, _điến, lçy_, --, 
   {{0xaca0063f,0x2f2800a7,0x3cdc033f,0x3e6c00e4}},	//   _nsụn, _любо_, _गहरे_, rýta_, 
   {{0x69d804e6,0x68f80175,0x3e6c0022,0x7c5406c2}},	//   tfue, wvud, sýta_, بلور_, 
   {{0x68f800af,0xfbd0012c,0xd5ec0208,0x3e6c473a}},	//   tvud, _साथम, _nhà, pýta_, 
   {{0xf1bc01e1,0x69d97361,0x7d1403d4,0x07a403f6}},	//   _alák_, rfue, øyst, мапн, 
   {{0x69d81ba6,0x32d400ee,0x2c00033f,0x68f80254}},	//   sfue, kçy_, लाओं_, rvud, 
   {{0xe0200c2e,0x68f8107d,0x59140327,0x60c40419}},	//   _मकसद_, svud, ིདུས_, zrim, 
   {{0xd7f8084c,0x60c57362,0xd5ec004d,0x00000000}},	//   adă_, yrim, _chà, --, 
   {{0xb8f01c82,0xe980006c,0xd7f80356,0xc33001d9}},	//   _হৈ_, _яқин, bdă_, ھٕر_, 
   {{0x60c57363,0x443d7364,0xd6a804fb,0xd6ec00cc}},	//   vrim, òt_, _کدوم_, _ওপৰা_, 
   {{0x2bdcb2b5,0x88bc012d,0xe46800db,0x60c57365}},	//   प्या, byśc, _ۉلبۉ_, wrim, 
   {{0xf54c00b4,0x00000000,0x00000000,0x00000000}},	//   tụta_, --, --, --, 
   {{0x60c57366,0xf1c00116,0x00000000,0x00000000}},	// [26880] urim, ﺭﯗﻧﻘ, --, --, 
   {{0x60c57367,0xb4600022,0x4f94041b,0x00000000}},	//   rrim, _икыл, ерцу, --, 
   {{0xdb08005c,0xf1bc00e5,0x00000000,0x00000000}},	//   _uddø, _oláh_, --, --, 
   {{0xf54c05db,0xd5ec001e,0x7864022c,0xb5f802fb}},	//   pụta_, _khá, rðvi, vlák, 
   {{0x05b405f9,0x60c40113,0x00000000,0x00000000}},	//   _अजनब, qrim, --, --, 
   {{0x3f8805db,0x88bc012d,0x00000000,0x00000000}},	//   _ugbu_, zyśc, --, --, 
   {{0xb5f97368,0x1ea800f1,0x00000000,0x00000000}},	//   noác, _ژاړي_, --, --, 
   {{0xf2d00d65,0xb5f97369,0x1b0401c0,0x7d142d8b}},	//   דעה_, zoáb, _үүдн, øyss, 
   {{0xd5ec0208,0xa99000d1,0xa9640114,0xbc64119e}},	//   _nhá, خشىت, мића_, _жвак, 
   {{0xb5f9736a,0xd7f80311,0x2bc400cf,0xe7f001f9}},	//   plák, udă_, _олуп_, _असणा_, 
   {{0xbb480014,0xd7f80276,0xb5f800c6,0x88bc012d}},	//   _بلان_, rdă_, llái, tyśc, 
   {{0x7a2c00a3,0x4e1000cd,0xb5f801e7,0x00000000}},	//   _dùtc, णायै_, olái, --, 
   {{0xdb082cd7,0xd5ec004d,0x88bc012d,0xb5f801e7}},	//   _medí, _chá, ryśc, nlái, 
   {{0xe94450b5,0x3e6c0030,0x00000000,0x00000000}},	//   _ترمی, kýto_, --, --, 
   {{0xb5f800c6,0xe7f00574,0xd5ec01fb,0xe2f8d5d9}},	//   hlái, _असता_, _thà, мері_, 
   {{0x909806bb,0x255802e3,0xdb080118,0xb40001c6}},	//   зват_, ọla_, _nedí, хүүд, 
   {{0x2285736b,0x1074005b,0x00000000,0x00000000}},	// [26890] тург, елаю, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd250106b,0xd2f80066,0x00000000,0x00000000}},	//   _مند_, _عکسا_, --, --, 
   {{0x925805f5,0xdb08026c,0x9f580022,0x0d7400ee}},	//   _хамт_, _vedì, _karê_, ныля, 
   {{0xdb090a26,0xc0c00bd6,0xb5f80332,0x09ac0154}},	//   _dedí, _бәхи, glái, _গালা, 
   {{0xf09c0268,0xd054016b,0x6298a547,0x00000000}},	//   _ità_, _ɔbɛh, _évoc, --, 
   {{0xb5f801e7,0x2a840208,0x00000000,0x00000000}},	//   alái, _bđbp_, --, --, 
   {{0xf1bc0d12,0xdd9001d9,0xb5f80332,0x00000000}},	//   _blái_, _نوِ_, blái, --, 
   {{0xb5f8007b,0xd7f80356,0x00000000,0x00000000}},	//   clái, hlău_, --, --, 
   {{0x764c0c8c,0xc5e80154,0x6fac0412,0x1d8801f7}},	//   ency, গাছা_, टरिं, _آئِي_, 
   {{0xf1bc6729,0xadc00208,0x00000000,0x00000000}},	//   _elái_, _hoằn, --, --, 
   {{0xd5ec01fb,0xf1bc6b3c,0x5ac801ec,0x4a54167f}},	//   _phá, _ndá_, _ілім_, _якес, 
   {{0x6fac0490,0xf09c01e1,0xa3ac000d,0x00000000}},	//   टरां, _ntà_, खरल_, --, 
   {{0xb5f80077,0x00000000,0x00000000,0x00000000}},	//   toác, --, --, --, 
   {{0xd6a8286d,0xf09c01ab,0xdb0800d0,0xadc00051}},	//   _قديم_, _atà_, _oddý, _loằn, 
   {{0x2bdc07f8,0xd76004d3,0xd5ec01fb,0x7d140108}},	//   प्ता, _خۆپی, _thá, äysk, 
   {{0x630400d1,0xdb1008a5,0x00000000,0x00000000}},	// [268a0] رۈڭل, _áfön, --, --, 
   {{0x25dc375c,0xdb0802fb,0x3cfc3be5,0x00000000}},	//   ग्री_, _sedí, लिसे_, --, 
   {{0xf09d736c,0xdb082b76,0x627c002e,0x7a2c08c2}},	//   _età_, _pedí, _dōor, _lùta, 
   {{0x6bd000d1,0x00000000,0x00000000,0x00000000}},	//   ۇتىر, --, --, --, 
   {{0xdb08067c,0x1bd41985,0xd094013d,0xb3400327}},	//   _vedí, воля, _ашсы, ħħew, 
   {{0xf1bc0122,0x627c00e8,0x442800b5,0xb5f801e7}},	//   _zdá_, _gōor, nkb_, rlái, 
   {{0x41740150,0x9f580240,0xf1bc0a87,0x764c0142}},	//   _زاڭس, _marë_, _slái_, yncy, 
   {{0x9f580240,0x44280200,0xb5f9736d,0x00000000}},	//   _larë_, hkb_, plái, --, 
   {{0xfbd07188,0xccd40588,0x7e608dd4,0xb5f800e4}},	//   _متا_, _ацхы, moop, oláv, 
   {{0x7e61736e,0x65940220,0x764c0042,0xa85000db}},	//   loop, ғару, wncy, лкыч, 
   {{0xdb0800d8,0x6c30007b,0x9f48020c,0xb76401c6}},	//   _dedã, _حفلا, éhèm_, этий, 
   {{0x98c400c7,0x7a3c02b5,0x0ae800c6,0x7e61736f}},	//   _аидҵ, kūti, _تركي_, noop, 
   {{0xdb08067c,0x7a3c0024,0x7d14005b,0xd7f40166}},	//   _hedà, jūti, äysh, _азлы, 
   {{0x7e617370,0x7c289df3,0x25a41432,0xb05801e3}},	//   hoop, nkfr, ımla_, _iväg, 
   {{0xf09d54e9,0xa81474e3,0x7e6069d6,0xf1a400d8}},	//   _stà_, _ستور_, koop, ерзн, 
   {{0xfd2407ae,0x627c00e8,0x066400c7,0x88c400db}},	//   _đình_, _sōor, _ихыҭ, _ستۇل, 
   {{0xf09c0395,0xb5f80120,0x7e611919,0x44280204}},	// [268b0] _qtà_, fláv, doop, bkb_, 
   {{0x9f580023,0xa0c416ac,0x00000000,0x00000000}},	//   _garë_, ايلو, --, --, 
   {{0xb8d0003d,0xd25000db,0x00000000,0x00000000}},	//   _ཟས_, _ۅنگ_, --, --, 
   {{0x7a3c2ba4,0x627c0de2,0x5fc400db,0x00000000}},	//   būti, _wōor, _ەەلۅ, --, 
   {{0xd25001d9,0x5db800db,0x00000000,0x00000000}},	//   _منگ_, رپوڭ_, --, --, 
   {{0xb5f80120,0xcb6870e4,0xef6402e8,0x7e6001f4}},	//   cláv, мале_, _зъбо, aoop, 
   {{0x7e6000b5,0xfe00000d,0x20540fac,0x00000000}},	//   boop, _रोवस_, _скря, --, 
   {{0x3ebd1ba3,0x7c2801a4,0xdb0800d8,0x48e40fbe}},	//   _ætta_, akfr, _sedã, воив, 
   {{0x0ec80490,0x9e34005b,0x00000000,0x00000000}},	//   ांकड, _сетч, --, --, 
   {{0x7c297371,0xdd9000aa,0x28a4009d,0x00000000}},	//   ckfr, _نوې_, мсүү_, --, 
   {{0xaac57372,0x9bc40108,0x00000000,0x00000000}},	//   _ستان, _щётк, --, --, 
   {{0x9f580100,0x00000000,0x00000000,0x00000000}},	//   _darè_, --, --, --, 
   {{0x9f58067d,0x2a7c0254,0x35b001d5,0x00000000}},	//   _parë_, mmub_, шбўр, --, 
   {{0x9f597373,0x7e60090c,0x2a7c0254,0x00000000}},	//   _farè_, zoop, lmub_, --, 
   {{0xd174e17f,0x7e6022a9,0xb3d00490,0xfbd00375}},	//   ғыты, yoop, _तारख, יתם_, 
   {{0xdb0801f1,0x05b40490,0x7a3cc436,0xb5f803b2}},	//   _jedá, _अजिब, tūti, fláu, 
   {{0x44280a2e,0xfbd0012c,0x52744f41,0xdd9402dd}},	// [268c0] pkb_, _सालम, ууру, қалы, 
   {{0x9f597374,0xf09c01ab,0x7a3d7305,0x7050007b}},	//   _haré_, _sràc_, rūti, لنقا, 
   {{0xce34036b,0x9f580419,0x00000000,0x00000000}},	//   گونک, _karé_, --, --, 
   {{0xdb080232,0x9f5800f2,0xf1bc041e,0xb5f97375}},	//   _nedá, _jaré_, _bláu_, sláv, 
   {{0x7e617376,0xce34021a,0x9f5810d8,0xdb08004e}},	//   roop, دونک, _maré_, _sedà, 
   {{0x9f580214,0xb5f801ed,0x769c002b,0x81b80011}},	//   _laré_, llát, _hīye, _আউট_, 
   {{0x7c297377,0xaab402dd,0x7e601140,0xdddc025c}},	//   rkfr, ندير_, poop, _kurż, 
   {{0xeb940032,0x769c0055,0x7c288504,0x9f580241}},	//   ниә_, _jīye, skfr, _rarè_, 
   {{0x8e5400d6,0x9f580268,0xb5f80077,0x69f00107}},	//   _стрі, _sarè_, ilát, рӯхт, 
   {{0x88bc068f,0x9f5808e5,0xf8057378,0xf1bc032e}},	//   myśl, _parè_, тчин, _hlát_, 
   {{0x9f580de2,0x7d014073,0xd6d4005b,0xe7f000c5}},	//   _baré_, lvos, ыжны, _असरा_, 
   {{0x39457379,0x769c0055,0xb05800d7,0x0ae801f7}},	//   _инег, _nīye, _zväd, _سرمي_, 
   {{0x7d00070d,0x9f580407,0xb5f9737a,0x69d40490}},	//   nvos, _daré_, dlát, _याती, 
   {{0x78a1737b,0x7d0001f4,0x370401f4,0x00000000}},	//   _itov, ivos, _ачив, --, 
   {{0x9f580137,0xbd000ca8,0xb5f8032e,0x00000000}},	//   _faré_, _èéfi, flát, --, 
   {{0xf524035b,0x9f587c6e,0x7a3c0882,0xb5f801ed}},	//   _афон, _garé_, tīty, glát, 
   {{0x7d000b4b,0xa194008e,0xc0c00209,0x64600100}},	// [268d0] jvos, рауч, йәри, èziè, 
   {{0x7d01737c,0x78a17030,0xef300124,0xa3d4010a}},	//   dvos, _mtov, аҭгы, _коьч, 
   {{0xc0c00131,0xe458010f,0xb5f83e33,0x00000000}},	//   _қәти, _ביזט_, blát, --, 
   {{0x9f5800e8,0xb5f801d3,0xf1a802f2,0x00000000}},	//   _xaré_, mlás, _تاده_, --, 
   {{0xb5f800dd,0xe7f00490,0xe3b002dd,0x712401d5}},	//   llás, _असला_, _ارۋ_, _شرحل, 
   {{0xdb095c61,0xdc75737d,0x09bc5ae4,0xb5f803b2}},	//   _sedá, агчы, ोल्य, olás, 
   {{0x78a1737e,0x7d0050bb,0x69d40073,0xe79001d5}},	//   _atov, avos, _यादी, یادک, 
   {{0x88d40882,0xca7401e0,0x644000d7,0x00000000}},	//   kṛti, ыулы, émiz, --, 
   {{0xb5f83b42,0xdb0800d7,0x00000000,0x00000000}},	//   hlás, _vedá, --, --, 
   {{0x9f59737f,0xb218003b,0xb5f936d2,0xe900009d}},	//   _marî_, _giæv, zlát, гцүү, 
   {{0x07097380,0x06853acc,0x9f597381,0x78a17382}},	//   ريحي_, лгон, _paré_, _etov, 
   {{0x2bdc085c,0xdb08005c,0x78a00200,0xb5f800e5}},	//   प्रा, _bedæ, _ftov, dlás, 
   {{0xaee006d6,0xb5f81ada,0xc1d001e0,0x00000000}},	//   _miṱa, elás, ҙөнә, --, 
   {{0xd45402bf,0x9f5800e8,0x00000000,0x00000000}},	//   атсь, _waré_, --, --, 
   {{0x842408b0,0x7d000433,0xb7d000cf,0x9f580129}},	//   نىڭن, zvos, _اقىب, _taré_, 
   {{0x7a3c00c0,0x00000000,0x00000000,0x00000000}},	//   būtu, --, --, --, 
   {{0xeb1c069f,0xf1bc0248,0xb5f801ed,0x3fe439c1}},	// [268e0] बहुत_, _alás_, rlát, лжав, 
   {{0xb5f91858,0xf1bc00c7,0x80688d51,0xa3040bd6}},	//   slát, _blás_, رماق_, _күге, 
   {{0xb5f97383,0xf1bc0306,0xafe01b0a,0xbf5800d4}},	//   clás, _plát_, сохл, храї_, 
   {{0x7d0028e5,0xb5f829c5,0xdb0801ed,0x00000000}},	//   tvos, llár, _ülés, --, 
   {{0x7d00023a,0xadb42f84,0xd7d47220,0x3e6c06ea}},	//   uvos, اهها_, _दालच, nýti_, 
   {{0x7d017384,0x92c80183,0x61e57385,0x78a0022e}},	//   rvos, োবৰ_, lfil, _rtov, 
   {{0x78a17386,0x61e401ee,0xfa897387,0x7d000024}},	//   _stov, ofil, нсий_, svos, 
   {{0xdb180023,0xb5f801e7,0xab80033a,0x00000000}},	//   lavë, hlár, љушк, --, 
   {{0xf1bc05f7,0x27e401c4,0xb5f8a873,0x7cf8003b}},	//   _klár_, _bbnn_, klár, _dørå, 
   {{0x61e57388,0x00000000,0x00000000,0x00000000}},	//   hfil, --, --, --, 
   {{0xab900491,0x7bd97389,0xb9e402bf,0xec1001d5}},	//   _المغ, _ictu, _біли, _دولد, 
   {{0x61e5738a,0x78a00a73,0x46c43af4,0xb5f802fb}},	//   jfil, _ttov, _विरह, vlás, 
   {{0x78a1738b,0xf09c01e1,0x05b409ab,0x39480354}},	//   _utov, _aràn_, _अजरब, _яздо_, 
   {{0x61e5738c,0xdb18036e,0xb5f801d3,0xe9441208}},	//   efil, javë, tlás, _حرمی, 
   {{0x0cd019e5,0x6299738d,0x61e5738e,0x320801c0}},	//   _सम्म, _évol, ffil, нхан_, 
   {{0xb5f800dd,0xf09c0109,0x3e6c06ea,0x7a3c5106}},	//   rlás, _dràn_, býti_, pūtu, 
   {{0x7bd9738f,0x69d40927,0xf1bc08a5,0x84c0013d}},	// [268f0] _octu, _यासी, _blár_, _мәрд, 
   {{0xf1bc007b,0xb5f97390,0x61e400c5,0x7af8d33f}},	//   _clár_, plás, afil, _ostt, 
   {{0xf09c04cc,0xaca001fb,0x8db40845,0x61e57391}},	//   _gràn_, _trịn, аслі, bfil, 
   {{0x9f5801e7,0xc0cc0023,0xdb180100,0x9f6829dc}},	//   _anró_, _ኣሲሩ_, mavè, уруз_, 
   {{0xb21800b5,0x00000000,0x00000000,0x00000000}},	//   _diæt, --, --, --, 
   {{0x7cf803cd,0xeac00014,0xf1a802f2,0x00000000}},	//   _sørå, مٕتێ, _تاگه_, --, 
   {{0xdb082045,0x29001a5a,0x2d9c025c,0x4af8c38a}},	//   _nedä, ājam_, _tfue_, тэля_, 
   {{0x6d580457,0x9f580268,0x26c001f1,0x7bd97392}},	//   _txua, _marì_, ájom_, _ectu, 
   {{0x7af80c8c,0x2c002e9a,0x7d14023a,0x3a7001e0}},	//   _estt, _гүлм, äyst, өләр, 
   {{0xaae4e540,0xdb08324c,0x00000000,0x00000000}},	//   _مسؤو, _bedä, --, --, 
   {{0x2ba805ba,0x61e401a8,0x00000000,0x00000000}},	//   _घ्या, yfil, --, --, 
   {{0x25a0031c,0xdb08007c,0xda0800ec,0x00000000}},	//   _qfil_, _dedä, _ٽيهه_, --, 
   {{0xa8a000db,0xa8a40120,0x25dc3885,0xc8f4004e}},	//   _التۉ, _срек, ग्गी_, _ъздъ, 
   {{0x61e4010a,0x57480220,0xd838834c,0xc7a46995}},	//   wfil, _өзім_, chč_, _тикк, 
   {{0x61e57393,0xdb0894fe,0x41b57394,0x36d00261}},	//   tfil, _gedä, исат, _дојр, 
   {{0xaca001f2,0x61e4022f,0xb5f800d7,0x00000000}},	//   _arọn, ufil, slár, --, 
   {{0x61e57395,0xb5f80306,0x764c007f,0x00000000}},	// [26900] rfil, plár, èbye, --, 
   {{0x442c0225,0x8fd4052f,0xf09c001e,0x769c00cd}},	//   _ôf_, йәсә, _tràn_, _hīya, 
   {{0x61e401a4,0xbd8804fb,0xdb18036e,0x00000000}},	//   pfil, چنان_, ravë, --, 
   {{0x63bd7396,0xbd88247f,0x7bd8003a,0x769c00b8}},	//   larn, ننان_, _sctu, _jīya, 
   {{0x62857397,0x7af801fa,0xdb18f8c5,0xdb08007c}},	//   mmio, _sstt, mavé, _medå, 
   {{0x62857398,0x9f5803b2,0x7ac412e7,0xdb1802f0}},	//   lmio, _harí_, асие, lavé, 
   {{0x63bc0869,0xb5f802fb,0x62857399,0x9f5800d7}},	//   iarn, kláp, omio, _karí_, 
   {{0x628400c6,0x63bd739a,0x2a040e8e,0x629c0369}},	//   nmio, harn, لقىپ_, iqro, 
   {{0x9f5800cf,0x229c0321,0xdb080108,0xada02b2e}},	//   _marí_, _lík_, _sedä, _фаул, 
   {{0x63bd739b,0x7bd80c8c,0x7c640131,0x9f5801e1}},	//   jarn, _uctu, _ئارل, _larí_, 
   {{0xeb94e20b,0x3cfc8054,0xbb840137,0xdb08007c}},	//   _тих_, लिके_, _ئلاي, _bedå, 
   {{0xf644085a,0x769c0055,0xdb08023a,0x2c78002d}},	//   рхон, _cīya, _vedä, rêde_, 
   {{0x6284006d,0x63bd739c,0xdce000da,0xb7d4dea3}},	//   dmio, farn, _izmē, _نقشب, 
   {{0x63bd739d,0x9f59739e,0x62840393,0x229c0051}},	//   garn, _marâ_, emio, _bík_, 
   {{0x629c0369,0x9f58013d,0xa3dc01ef,0x00000000}},	//   gqro, _barí_, _žďář, --, 
   {{0x80c1739f,0x63bc0eda,0x229c0308,0xdb1856ec}},	//   _लिखे, aarn, _dík_, ravè, 
   {{0x9f5973a0,0x209800fb,0xa50800d8,0x00000000}},	// [26910] _darí_, икты_, _вења_, --, 
   {{0x628573a1,0xdb1800c7,0xaf0428ed,0x229c01ef}},	//   amio, aavé, ичек, _fík_, 
   {{0x6ec40137,0xf09c001e,0x8d940075,0x91c40116}},	//   شتاق, _trào_, ملاش, _гәзл, 
   {{0x9f58004e,0x741001f7,0x00000000,0x00000000}},	//   _garí_, _اوڍا, --, --, 
   {{0xaca007ae,0xeb9402a9,0xc8e40037,0x1cd80108}},	//   _trọn, қиқ_, _कहेम_, идцы_, 
   {{0x201c10ee,0x1c440111,0x00000000,0x00000000}},	//   övit_, онім, --, --, 
   {{0xa3dc05dc,0xdef80262,0x09b0031c,0x5f2800db}},	//   ण्ट_, _кыт_, _དབྱ_, _коём_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x63bd73a2,0x9f58025a,0xd1b8044e,0x7a2c0013}},	//   yarn, _garâ_, _ኲናት_, _mùth, 
   {{0x7a2c01c3,0x63bd73a3,0x291800e8,0x00000000}},	//   _lùth, xarn, _àqam_, --, 
   {{0x9c644caa,0x62853f2b,0x769c002b,0x5b340efe}},	//   _بهلو, ymio, _pīya, _وعمر, 
   {{0x63bd73a4,0x09b00135,0xb0c45b99,0x229c0aab}},	//   warn, _དབྲ_, _लिंग, _rík_, 
   {{0x9f5800e4,0xdb18035b,0x229c31b7,0x00000000}},	//   _karã_, vavé, _sík_, --, 
   {{0x63bd73a5,0x5974431a,0x00000000,0x00000000}},	//   uarn, _بدمز, --, --, 
   {{0x63bd73a6,0xdb180124,0x7a2c01c3,0xf09c00a3}},	//   rarn, tavé, _bùth, _dràm_, 
   {{0x63bd73a7,0x9f591f5b,0x614c0092,0x3e6c0d12}},	//   sarn, _qarí_, _በመውጣ, nýtt_, 
   {{0xdb1803b7,0x628573a8,0x7a2c0013,0xbfc4013d}},	// [26920] ravé, rmio, _dùth, йбак, 
   {{0x63bc0680,0x9f5800c7,0x302400c7,0x229c09e8}},	//   qarn, _narã_, боуп_, _tík_, 
   {{0x261c6236,0x9358084c,0x62840175,0xee3400d1}},	//   यापी_, _вряу_, pmio, әнч_, 
   {{0x6d004da4,0xfca8082a,0xc0e4490c,0x00000000}},	//   लिंग_, هاتو_, _ломк, --, 
   {{0x201c1666,0x9d1973a9,0x00000000,0x00000000}},	//   övis_, ролт_, --, --, 
   {{0xd9b40f22,0xf1bc0051,0x00000000,0x00000000}},	//   _টাইম, _toác_, --, --, 
   {{0x9f58011f,0xba4401c0,0xb058007c,0xe94000c7}},	//   _warâ_, йхий, _kvän, ҧхьо, 
   {{0x5fa40574,0x6480023a,0xbe6801f4,0x00000000}},	//   खुरल, löid, _сабж_, --, 
   {{0x9f58068c,0x195973aa,0x261c0a8a,0x9d5400e5}},	//   _harà_, рапы_, यानी_, _بچات, 
   {{0xd9f4000d,0x648001f4,0x00000000,0x00000000}},	//   _आसकत_, nöid, --, --, 
   {{0xb05801e6,0x3e6c1427,0x00000000,0x00000000}},	//   _ovän, býtt_, --, --, 
   {{0xc0c00020,0x98c40e51,0xeb300150,0xefec0023}},	//   ድረስ_, ştık_, _عىند, _ቀዳድ_, 
   {{0x9f5800cf,0x6480005b,0xf3140075,0x00000000}},	//   _larà_, köid, әнбә_, --, 
   {{0x3a247890,0x6480023a,0x00000000,0x00000000}},	//   _hoop_, jöid, --, --, 
   {{0x3a241aa7,0x57640014,0x00000000,0x00000000}},	//   _koop_, _بخشہ, --, --, 
   {{0x3a2573ab,0xb9f00b82,0x16840133,0x00000000}},	//   _joop_, _ዞና_, _باتێ, --, 
   {{0x32040316,0xa5d80150,0xf09c004d,0x764d73ac}},	// [26930] ěny_, _ابىر_, _tràm_, micy, 
   {{0xdb080077,0x9f58004e,0x764d73ad,0x3a24011a}},	//   _dedú, _barà_, licy, _loop_, 
   {{0xf3240150,0x00000000,0x00000000,0x00000000}},	//   _اۋزى_, --, --, --, 
   {{0x764c0916,0xf1c0003d,0x3a2573ae,0x00000000}},	//   nicy, _diġà_, _noop_, --, 
   {{0x9f580004,0x7d1401f4,0x00000000,0x00000000}},	//   _parã_, äysp, --, --, 
   {{0x9f5973af,0x00000000,0x00000000,0x00000000}},	//   _farà_, --, --, --, 
   {{0x3a244f7f,0x764c00ca,0xdea48f52,0x9f5800e4}},	//   _boop_, kicy, _فیلی, _varã_, 
   {{0xdb080142,0x88c86af7,0xa2cd2370,0x00000000}},	//   _rddô, алив_, _तटस्, --, 
   {{0x3a2573b0,0x8c1805d9,0x1ca802f2,0x290800e4}},	//   _doop_, _پيار_, _هێنی_, íca_, 
   {{0xd90d114b,0x9f58dbd1,0x752c068f,0x06e973b1}},	//   ایو_, _hará_, dycz, амок_, 
   {{0x86980261,0xe3b8015b,0x26c0003e,0x764c012d}},	//   јтот_, _জালব, éjo_, ficy, 
   {{0x764c0223,0x84e401c0,0x3a24007c,0x35a00139}},	//   gicy, оомж, _goop_, маюг, 
   {{0x69d80007,0x79e80014,0x2584020c,0xa90573b2}},	//   mgue, _خونہ_, dèlé_, _دبان, 
   {{0x69d8311a,0xb058049f,0xdb08056a,0x9f580241}},	//   lgue, _svän, _redú, _lará_, 
   {{0xf2a0a863,0x6440004e,0x764d73b3,0x648001f4}},	//   дисп, èmiq, bicy, vöid, 
   {{0x69d80c38,0x3ebc008c,0x41a805f5,0xbb5802d3}},	//   ngue, _ætti_, рван_, _ዕንቅፋ, 
   {{0x9f5973b4,0x80a4bc05,0x69d8067c,0x666401d9}},	// [26940] _sarà_, زمان, igue, _وُڈٕ, 
   {{0x9f5973b5,0x69d80007,0xdb0801f1,0x660573b6}},	//   _aará_, hgue, _vedú, _haik, 
   {{0x660573b7,0x7dc4525b,0x443973b8,0x648002f6}},	//   _kaik, ققان, _ilp_, röid, 
   {{0x66040588,0x9f5807de,0xf1bc004d,0xce8800f2}},	//   _jaik, _varà_, _hoán_, مئنم_, 
   {{0xb05804f3,0x9f584dce,0x7c640131,0x3a240327}},	//   _kväl, _dará_, ياتل, _roop_, 
   {{0x660573b9,0x60c573ba,0xfaa573bb,0x764c0223}},	//   _laik, msim, ошин, zicy, 
   {{0x752c006d,0x443973bc,0x60c573bd,0x9f5810d8}},	//   zycz, _mlp_, lsim, _fará_, 
   {{0x69d973be,0x660573bf,0x2c78025a,0xa9c002bf}},	//   ggue, _naik, rêda_, мськ, 
   {{0x443973c0,0xf53c4bc1,0xdb0801bf,0xb058007c}},	//   _olp_, nbåt_, _ledø, _oväl, 
   {{0x60c573c1,0x7b140597,0x59dc0574,0x6604000f}},	//   isim, _وظائ, _यावर, _aaik, 
   {{0x764c00ca,0x7c380585,0x19580588,0xabd00014}},	//   ticy, _iltr, раҿы_, _زٲنت, 
   {{0x752c14cf,0x443973c2,0xdb180436,0x660400dc}},	//   tycz, _alp_, naví, _caik, 
   {{0x3ce573c3,0x660573c4,0x2584020c,0x60c573c5}},	//   ntov_, _daik, vèlé_, jsim, 
   {{0xdb08019b,0x443806a3,0x752c068f,0x60c573c6}},	//   _bedø, _clp_, rycz, dsim, 
   {{0x443811ce,0x660403c1,0x3ce409a8,0xdb0804cc}},	//   _dlp_, _faik, htov_, _pedù, 
   {{0xdb1973c7,0x3ce4b8dd,0x4438002e,0x6604546d}},	//   javí, ktov_, _elp_, _gaik, 
   {{0x7c380c04,0xdb184e4c,0x60c48b14,0x443973c8}},	// [26950] _oltr, daví, gsim, _flp_, 
   {{0x443973c9,0x660573ca,0x69d80789,0x7c3801f5}},	//   _glp_, _zaik, zgue, _nltr, 
   {{0x660573cb,0x60c4c20b,0x9f5973cc,0x69d8004a}},	//   _yaik, asim, _pará_, ygue, 
   {{0x69d80007,0x3ce40010,0x63800241,0xdb0801e1}},	//   xgue, ftov_, _wání, _àlùs, 
   {{0x60c40548,0xf53c143a,0x261c62a8,0x00000000}},	//   csim, mbås_, याती_, --, 
   {{0xf1bc172e,0x4438062c,0xef6402e8,0xfc000150}},	//   _xoán_, _xlp_, _дъбо, епшо, 
   {{0xdb1802fb,0x3ce4022e,0x9f580241,0x00000000}},	//   baví, atov_, _tará_, --, 
   {{0x7c3973cd,0x69d973ce,0xfe54002e,0x2ba800dc}},	//   _eltr, ugue, _ba鯵a_, _घ्रा, 
   {{0x660573cf,0x6e395c32,0x2d88004a,0x2ba40063}},	//   _raik, _ilub, _àce_, _дјев, 
   {{0xf8ac8bf7,0x660573d0,0x68f81f29,0x69d809c2}},	//   اکن_, _saik, rwud, sgue, 
   {{0x660573d1,0x4438002f,0x00000000,0x00000000}},	//   _paik, _rlp_, --, --, 
   {{0x60c40429,0x44387c84,0xb5f80120,0xb05801e6}},	//   ysim, _slp_, zoáv, _sväl, 
   {{0x660573d2,0x39980a1e,0x60c40429,0x69c973d3}},	//   _vaik, _הינד, xsim, _idge, 
   {{0x290c0548,0x6e38004e,0x60c573d4,0xf54c02e3}},	//   _irga_, _llub, vsim, zụga_, 
   {{0x660573d5,0x6e38b23d,0x290c0a2e,0x261c924b}},	//   _taik, _olub, _hrga_, यादी_, 
   {{0xae080034,0xf53c0158,0x9f582ac2,0xea900220}},	//   _सोलन_, tbåt_, _harç_, _ﺟﺎﺯﯞ, 
   {{0x60c573d6,0xf1bc07ae,0x443973d7,0xb4d804cc}},	// [26960] usim, _toán_, _tlp_, lzàn, 
   {{0x60c40680,0x88bc03f4,0x290d73d8,0x44380393}},	//   rsim, _আমাক, _mrga_, _ulp_, 
   {{0x60c573d9,0x9f5973da,0x6e3973db,0xdb185768}},	//   ssim, _març_, _blub, taví, 
   {{0xfe701456,0x290d73dc,0xfce42c2c,0x23dc00bc}},	//   ردا_, _orga_, зодо, _बाँद, 
   {{0x60c573dd,0xdb180122,0x200c0120,0xd17410de}},	//   qsim, raví, _ódio_, _жыры, 
   {{0x645d73de,0x6e3973df,0x22400280,0x3ce571ce}},	//   nnri, _elub, lhik_, rtov_, 
   {{0x3ce573e0,0x290d73e1,0x645c0112,0x7c380381}},	//   stov_, _arga_, inri, _vltr, 
   {{0xfce40364,0x6e3973e2,0x2240079b,0x3ce454b0}},	//   _нобо, _glub, nhik_, ptov_, 
   {{0x98a40006,0x23dcc725,0x76a80032,0xb1780efa}},	//   kymą_, _बांद, әтов_, _ubåt, 
   {{0x69c81a68,0x7c3904e7,0x2120011f,0x645c00f3}},	//   _edge, _ultr, ixih_, jnri, 
   {{0x290d73e3,0x2240db5d,0x645c0109,0x98a40006}},	//   _erga_, khik_, dnri, dymą_, 
   {{0x6b7800c8,0x3ebc0008,0x645c5d43,0xb5f82af5}},	//   _פראנ, _ættu_, enri, joát, 
   {{0x290c1710,0x795003e6,0x224004fb,0xb0580267}},	//   _grga_, _سێدا, dhik_, _sväm, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x656418f7,0xdb1807c5,0xaee00055,0x00000000}},	//   _exih, navà, _muṃc, --, 
   {{0x9f582776,0xeb38008f,0x645c017a,0x00000000}},	//   _marä_, זעלש, anri, --, 
   {{0xdb180109,0x00000000,0x00000000,0x00000000}},	// [26970] havà, --, --, --, 
   {{0x2f880063,0x6e385f0b,0xceb80124,0x00000000}},	//   бљен_, _slub, жәа_, --, 
   {{0x6e3801ab,0x00000000,0x00000000,0x00000000}},	//   _plub, --, --, --, 
   {{0x224173e4,0xdb1804cc,0x6e38025c,0x0d740153}},	//   chik_, davà, _qlub, мыля, 
   {{0xf1bc0077,0xe81c09ab,0x00000000,0x00000000}},	//   _joám_, बामा_, --, --, 
   {{0x237400db,0x00000000,0x00000000,0x00000000}},	//   _تاۋح, --, --, --, 
   {{0xf75c00b5,0x398001d5,0x3c880150,0x004401e2}},	//   _gb様_, lаsh_, _ﺗﻮﺗﻰ_, _تیلي_, 
   {{0x6e38068f,0x683c000f,0x291c01c6,0x2d040153}},	//   _ulub, _mêde, txua_, _нязг, 
   {{0x645c0652,0x261c352c,0xb5f801d3,0xf1bc01e7}},	//   ynri, यासी_, bláz, _meá_, 
   {{0xf1bd73e5,0x22400004,0xf54c01f2,0xb5f80407}},	//   _leá_, zhik_, kụba_, zoát, 
   {{0xc0cc044e,0x683c000f,0x290c020c,0xb3e00154}},	//   _ኣዲስ_, _rêdd, _wrga_, য়াজ, 
   {{0x645c232c,0x290c1a48,0x2120011f,0x69c80c8c}},	//   wnri, _trga_, yxih_, _udge, 
   {{0xe3b81b4b,0x9f582776,0x290000da,0xcfd402f5}},	//   _དབྱང, _zarä_, ājas_, স্যন, 
   {{0x683c002d,0x261c1098,0xdb1803da,0x62880153}},	//   _bêde, याही_, lavá, įdom, 
   {{0x81e42f04,0x2240034c,0x98a40024,0x00000000}},	//   _যোগ_, thik_, rymą_, --, 
   {{0x22400d04,0xb5f942bd,0xdb0802f0,0x00000000}},	//   uhik_, gnád, _nedý, --, 
   {{0xc0043c85,0x2018020c,0xdb1806d9,0xb4d800db}},	// [26980] мпак, _pnri_, zavà, nzàl, 
   {{0x22405848,0x261c0574,0xf0604727,0xd7d80327}},	//   shik_, यावी_, вкуп, ཱུརྱ, 
   {{0x22413c18,0x258401e1,0xf1bc0332,0x4ea40212}},	//   phik_, _fèlí_, _feá_, еріа, 
   {{0xf09c004e,0xb5f802f0,0x00000000,0x00000000}},	//   _fuà_, loár, --, --, 
   {{0xfc6400a7,0xdce000ef,0x00000000,0x00000000}},	//   мъкн, _izmī, --, --, 
   {{0x8db40046,0x9f580139,0x93c40208,0xd0580150}},	//   _үсті, _parä_, _nhằ, _ерсі_, 
   {{0xafe173e6,0x3980022e,0xb5f800e5,0x00000000}},	//   _шорл, mаsi_, rláz, --, 
   {{0xdb180109,0xbe140eff,0xec1001b9,0x64400240}},	//   ravà, _تورع, _یوقد, ëmij, 
   {{0xa3c01b6e,0xdb180109,0xb5f800e5,0x00000000}},	//   ुणा_, savà, pláz, --, 
   {{0x9f58145e,0xb86573e7,0xfbdcad47,0x7118008f}},	//   _tarä_, بابو, _øª_, קויפ, 
   {{0x8c3c2057,0x69d401f9,0xdb1800e5,0x00000000}},	//   _duşd, _याची, bavá, --, 
   {{0x683c045f,0x398001a9,0x00000000,0x00000000}},	//   _rêde, hаsi_, --, --, 
   {{0x3980036b,0xf54c01f2,0xd8e80327,0xe4e400d4}},	//   kаsi_, wụba_, _འདིི, кірн, 
   {{0x7980014b,0xf1bc0270,0x77300588,0x8c3c010e}},	//   _izow, _seá_, _аҭоу, _guşd, 
   {{0xf1bc1132,0x261c0490,0xdb080139,0x00000000}},	//   _peá_, याशी_, _üläs, --, 
   {{0xc7ac01ed,0x002c001f,0x00000000,0x00000000}},	//   _پڑی_, _በማከና, --, --, 
   {{0xf09d73e8,0x261c23ef,0x491002c3,0xe9fc004d}},	// [26990] _quà_, यारी_, तियो_, hiến_, 
   {{0xdb0803fa,0xe454035b,0xdb1801d3,0x6480005b}},	//   _bedü, _акьы, zavá, löin, 
   {{0xdb180413,0xb5f803b2,0x00000000,0x00000000}},	//   lavæ, pnád, --, --, 
   {{0x79800117,0xdb0804cc,0x8c3d5c5e,0x6480005b}},	//   _ozow, _dedü, _muşe, nöin, 
   {{0x7980009f,0xb5f80077,0x11880116,0x00000000}},	//   _nzow, onáb, _хәвп_, --, 
   {{0x62988607,0x00000000,0x00000000,0x00000000}},	//   _évor, --, --, --, 
   {{0x798105e7,0x648002f6,0xdb1803da,0xdb081196}},	//   _azow, köin, tavá, _gedü, 
   {{0x090573e9,0xdb1806ea,0xb5f800d8,0x64800108}},	//   епин, kavæ, zoár, jöin, 
   {{0xdb08068c,0xdb181897,0x2c840118,0xcb0800f2}},	//   _bedó, ravá, _půdě_, زيکن_, 
   {{0x9bf412b4,0x79800099,0x8b8402dd,0x8c3c25a8}},	//   _изуч, _dzow, _كەشە_, _buşe, 
   {{0x79800921,0x475973ea,0x77c401c0,0x261c503c}},	//   _ezow, ярия_, элэг_, याली_, 
   {{0x8c3c0209,0xf65c003a,0xdb18005c,0x3980022e}},	//   _duşe, gnæ_, favæ, zаsi_, 
   {{0x9f580086,0xb058023a,0x93c4004d,0xdb1802d2}},	//   _barû_, _eväi, _thằ, gavæ, 
   {{0x443c01ed,0xfcb00030,0xf65c003a,0x8cc01684}},	//   ót_, ýšiť_, anæ_, रीयो, 
   {{0x49fc0327,0x83543345,0x8c3c0790,0xf7d00220}},	//   _དྲོལ_, رپرا, _kuşb, _ﻛﯘﻧﻪ, 
   {{0xdb0973eb,0xd90c61be,0x765c00e4,0x80a82d29}},	//   _redü, _ایی_, _ípyp, звав_, 
   {{0x398001d5,0x03a400d8,0x00000000,0x00000000}},	// [269a0] tаsi_, _пипо, --, --, 
   {{0xdb080ba1,0x6e900131,0x8c3ca75a,0x2bb00118}},	//   _medò, ۇللا, _yuşe, ँडफा, 
   {{0x671c10dc,0x39600b82,0x3eac0221,0x88bc012d}},	//   यमिक_, _ውድድራ, ëft_, zyśp, 
   {{0x9f580022,0xf5540517,0xf7700a1e,0xb5f80118}},	//   _karú_, _آلیب_, נקא_, mnác, 
   {{0x629807ea,0x49fc025c,0x00000000,0x00000000}},	//   _évoq, _དྲེལ_, --, --, 
   {{0x9f5800ae,0x8c4000c7,0x3980022e,0x7f740229}},	//   _marú_, аҵуе, qаsi_, _зубц, 
   {{0xdb08004e,0xaba40592,0x8cc007f7,0x00000000}},	//   _redó, رهيم_, रीबो, --, 
   {{0xaa6173ec,0xf09c08c2,0x8c3c03e0,0x00000000}},	//   лтык, _gràs_, _ruşe, --, 
   {{0xe3d804c5,0xdb083822,0xcdc402dd,0x8c3c0205}},	//   দ্যব, _pedó, _шатқ, _suşe, 
   {{0x7d000223,0x0ba802dd,0x8c3c00a2,0xd838007f}},	//   mwos, _قامى_, _puşe, ukč_, 
   {{0xdb244c12,0x6480023a,0xb5f8022a,0x3a3801c7}},	//   _جوای, töin, jnác, ëpps_, 
   {{0x2f58008d,0xb4b00075,0xb5f8013a,0x00000000}},	//   לדינ, лимә, dnác, --, 
   {{0x798173ed,0x7d003185,0x6480023a,0xf65c0393}},	//   _uzow, nwos, röin, rnæ_, 
   {{0x3dc40009,0xc8780356,0x64800108,0x7d1401f4}},	//   haow_, tuşe_, söin, äysy, 
   {{0x7d000810,0xb0580267,0x78a0005b,0xb5f800d0}},	//   hwos, _kväv, _huov, gnác, 
   {{0xf6092931,0xb344315a,0x7d0173ee,0xdb183110}},	//   _رتبه_, _acçõ, kwos, mavä, 
   {{0xc1a40220,0xdb1973ef,0x909800a7,0x78a0005b}},	// [269b0] тысқ, lavä, дват_, _juov, 
   {{0xd2500cd2,0x78a173f0,0x8c3c0311,0x00cc00d1}},	//   _چند_, _muov, _muşc, _ﺗﻪﺗﻘ, 
   {{0xd25173f1,0xad24168d,0x78a002f6,0x9f340816}},	//   _نند_, کراو, _luov, лефі, 
   {{0xe3b15ccd,0x8d940131,0x648001f4,0x00000000}},	//   _پری_, نلاش, höil, --, 
   {{0x78a0156b,0xdb180037,0x201c0306,0x64800108}},	//   _nuov, havä, ázií_, köil, 
   {{0xd0ac016b,0x5eb40cef,0x6480023a,0xdb1973f2}},	//   _dɔɔs, _әйтт, jöil, kavä, 
   {{0x320801af,0x48bc00bd,0xdb195bf3,0x8ccc00e1}},	//   _kacy_, _আমের, javä, _सिको, 
   {{0x7d0000ca,0xdb18014a,0x2fc000f3,0xdb08004e}},	//   bwos, davä, _hejg_, _pedò, 
   {{0x2d9c00e4,0x4c9400c7,0x0ed0012c,0x8c3c0356}},	//   _igue_, _аиас, _हिँड, _cuşc, 
   {{0x5d54bb47,0x3208232c,0x2cbc0295,0xe7dc00cc}},	//   _скут, _lacy_, _iwud_, বজ্য, 
   {{0xdb18fb94,0x00000000,0x00000000,0x00000000}},	//   gavä, --, --, --, 
   {{0xb5f80118,0x00000000,0x00000000,0x00000000}},	//   vnác, --, --, --, 
   {{0x78a00165,0xb0580036,0xd4f43c8f,0x18a400c0}},	//   _guov, _zwäe, ляры, _баім, 
   {{0x0ed058fc,0xb5f800bc,0x1994010b,0x468002dd}},	//   _हिंड, tnác, _сачя, ыққа, 
   {{0x2d9c00c7,0x9f5801e1,0xe9fc0051,0x00000000}},	//   _ogue_, _warú_, nhắn_, --, 
   {{0xb5f80f57,0x2d9cd9dd,0x8c4406be,0x00000000}},	//   rnác, _ngue_, _diğə, --, 
   {{0xc4840228,0x2fc00327,0x64800108,0x00000000}},	// [269c0] _илик, _bejg_, löim, --, 
   {{0x2d9c145e,0xa3040184,0xdb1800cc,0xfd5000b8}},	//   _ague_, _йүге, lavå, _greṇ, 
   {{0x0368dd37,0x43440116,0x648001f4,0x00000000}},	//   _цинк_, _ренв, nöim, --, 
   {{0x9f580140,0x7d0000ca,0xec100214,0xadb4007b}},	//   _marø_, twos, یوند, نهما_, 
   {{0x1bd4578a,0xec1000ec,0x61e44831,0xb5c40150}},	//   голя, ڌوند, mgil, _ﻓﺸﻴﺌ, 
   {{0x61e573f3,0x7d0173f4,0xb0580267,0x78a00108}},	//   lgil, rwos, _sväv, _ruov, 
   {{0x78a173f5,0x320800b5,0x25a0022e,0xf1bc004d}},	//   _suov, _yacy_, _ogil_, _soái_, 
   {{0x25a016a5,0x8c3c0311,0x44280175,0xeb940063}},	//   _ngil_, _puşc, hjb_, њић_, 
   {{0x7e60dc02,0xfbc42a83,0x78a173f6,0x987573f7}},	//   mnop, _абзо, _quov, ллиц, 
   {{0xf09c01e1,0x7e600866,0x6be000cf,0xdb183167}},	//   _osàn_, čopu, _ەكەم, tavä, 
   {{0x61e4000a,0x7e6173f8,0x64800108,0xe73400d8}},	//   kgil, onop, röil, веќ_, 
   {{0x25a000a7,0x7e6173f9,0x69040724,0x78a002f6}},	//   _cgil_, nnop, ärdä, _tuov, 
   {{0x49fc003d,0x320863c6,0x58d4f49b,0x7e6173fa}},	//   _དྲིལ_, _racy_, _солт, inop, 
   {{0xe3b00375,0x61e45bae,0x7e6173fb,0x25a0b02f}},	//   قرف_, egil, hnop, _egil_, 
   {{0xb5f00046,0xe81c228d,0x320973fc,0xaee000b8}},	//   _күні, बारा_, _pacy_, _miṣa, 
   {{0x61e573fd,0x7e6146e8,0x8c3c3b33,0x629973fe}},	//   ggil, jnop, _muşa, _èvol, 
   {{0xe13548c8,0xefc80020,0xc87973ff,0xa158014b}},	// [269d0] анты, _አሳይ_, luşa_, вату_, 
   {{0x16202413,0x61e56ba6,0x7e6004e6,0xaee000dc}},	//   यावर_, agil, enop, _niṣa, 
   {{0x3208033f,0xc87925bb,0x00000000,0x00000000}},	//   _tacy_, nuşa_, --, --, 
   {{0xaee001e1,0x7e617400,0x61e40e89,0x40a00248}},	//   _aiṣa, gnop, cgil, _ìṣọ́_, 
   {{0xd25050e9,0xf09c00a3,0xc8780205,0x00000000}},	//   _ننگ_, _gràp_, huşa_, --, 
   {{0x7e617401,0x8c3c008e,0xcb0801c8,0x00000000}},	//   anop, _buşa, فيتن_, --, 
   {{0xb0580036,0x9be402bf,0xaca00241,0x7e600010}},	//   _ewäc, річк, _isọn, bnop, 
   {{0x60cc0598,0x8c3d7402,0x3cb000ee,0xb0580108}},	//   _älmä, _duşa, шйәр, _evät, 
   {{0xe81c0d0a,0xdd957403,0x00000000,0x00000000}},	//   बाला_, _ваты, --, --, 
   {{0x6d480369,0x25a17404,0x61e41258,0xfbb800dc}},	//   mzga, _sgil_, zgil, _उभयम, 
   {{0xdb180158,0x8c3c010b,0x61e40bbc,0x6d48002f}},	//   tavå, _guşa, ygil, lzga, 
   {{0x6480023a,0x00000000,0x00000000,0x00000000}},	//   röim, --, --, --, 
   {{0x6d480007,0x61e549e2,0x2a7c0218,0x54c43e28}},	//   nzga, vgil, mlub_, аңын_, 
   {{0xf54c01f2,0x6d4801c4,0x7e600010,0x2a7c0254}},	//   mụla_, izga, znop, llub_, 
   {{0x61e57405,0x25a005d5,0x821800a8,0x7e617406}},	//   tgil, _tgil_, нцат_, ynop, 
   {{0x9694100e,0x25a0da19,0xb05801e3,0xb5f801d3}},	//   _крыш, _ugil_, _oväs, lnán, 
   {{0x7e60098d,0xefc80020,0xb5f804d4,0x00000000}},	// [269e0] vnop, _አኳያ_, onán, --, 
   {{0x61e57407,0x840400d6,0xb5f808de,0x769c002b}},	//   sgil, _спож, nnán, _hūya, 
   {{0x2a7d7408,0xaee00055,0xf7d002dd,0x00000000}},	//   klub_, _riṣa, _ﻛﯘﻳﻪ, --, 
   {{0xb05801f1,0x2a7c0218,0x7e600099,0xb5f80118}},	//   _svät, jlub_, unop, hnán, 
   {{0x648001f4,0x00000000,0x00000000,0x00000000}},	//   jöik, --, --, --, 
   {{0x7e600108,0x2a7c00e8,0x769c0055,0xada00b01}},	//   snop, elub_, _lūya, _ғафл, 
   {{0xaee00a28,0xb5f80316,0xb05802f6,0x90705f32}},	//   _viṣa, dnán, _eväs, _بۇلش, 
   {{0x5a3409ed,0xdd0801a2,0x387c0175,0x00000000}},	//   рнит, môže, wltr_, --, 
   {{0xb058049f,0xd9117409,0xdb0801b8,0xa9640063}},	//   _tvät, تیش_, _nedö, лића_, 
   {{0xf804cdd2,0xed5424fc,0xc879740a,0xfaa401a9}},	//   учин, _соу_, tuşa_, _бажо, 
   {{0x7bc8d78f,0x2a7c01d4,0x8c3d740b,0x8ac40022}},	//   mafu, blub_, _kuşn, _ҩқәа_, 
   {{0x2a7d740c,0x7bc9740d,0xdb09740e,0x387c01ab}},	//   club_, lafu, _bedö, sltr_, 
   {{0x769c0055,0x32640107,0x00000000,0x00000000}},	//   _dūya, ҳтав, --, --, 
   {{0x7bc97053,0xd79400a7,0xd7f8054e,0xf1bc0208}},	//   nafu, _килъ, onăm_, _loát_, 
   {{0xe2f8005e,0x77911ea4,0x6d4805ac,0xb0580267}},	//   лері_, _دیدا, zzga, _ovär, 
   {{0xf125740f,0x7bc97410,0xdb4401d9,0x00000000}},	//   льзо, hafu, _ہێ_, --, 
   {{0x7bc97411,0x90540953,0x64400798,0xdb18003a}},	// [269f0] kafu, авац, êmic, tavû, 
   {{0x7bc801c8,0xf4a00024,0x64800108,0xdb440133}},	//   jafu, įžęs_, jöih, _فێ_, 
   {{0x7bc9392b,0xddc800f3,0x8c3c0166,0x22940276}},	//   dafu, _šoša, _buşn, риӂя, 
   {{0xb5f8012c,0x6d482321,0x419800d1,0x769c00dc}},	//   znán, tzga, رمەڭ_, _yūya, 
   {{0x7bc97412,0xb0580267,0xd6f0015b,0xdb080254}},	//   fafu, _dvär, টিয়া_, _medõ, 
   {{0x40b4008f,0x00000000,0x00000000,0x00000000}},	//   _כּלל_, --, --, --, 
   {{0xb5f80316,0xf54c01f2,0x7e600010,0x9f3401ec}},	//   vnán, wụla_, čopr, _лері, 
   {{0x4df8008f,0x6e280334,0x6480005b,0x2bc4166d}},	//   _שפּא, qjgb, töik, _रजवा, 
   {{0x7bc85b36,0x2a7c0076,0xb5f829e8,0xfa30107b}},	//   bafu, rlub_, tnán, تىيج, 
   {{0x2a7d7413,0xc79400c9,0xf54c01f2,0x7bc94d8a}},	//   slub_, ирны, rụla_, cafu, 
   {{0xb5f830cf,0x69cc0615,0x769c00b8,0x8cc03f7e}},	//   rnán, óces, _sūya, रीरो, 
   {{0xdb080793,0xf54c01f2,0x49744037,0x769c002b}},	//   _pedö, pụla_, _клес, _pūya, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x99840597,0xdb08014a,0xb7e0000d,0x00000000}},	//   _الهو, _vedö, _खाएम_, --, 
   {{0xb8540532,0x7c2c180f,0xb5f828d1,0x00000000}},	//   _خلوص_, _òbre, onál, --, 
   {{0xdb0801b8,0x7bc97219,0xb5f97414,0x00000000}},	//   _tedö, zafu, nnál, --, 
   {{0x7bc97415,0xbfb40150,0x16640014,0xc0e47927}},	// [26a00] yafu, لحات, _داوَ, розк, 
   {{0xf1bc001e,0xb05801e6,0x0fe80075,0x7bc8005a}},	//   _soát_, _svär, ллуқ_, xafu, 
   {{0x645d7416,0x7f4919b2,0x7bc8006f,0x09dc00eb}},	//   miri, خلاق_, vafu, ভ্যা, 
   {{0x645d7417,0x7bc83f5d,0xd0040046,0xf1bc067c}},	//   liri, wafu, _қосқ, _doás_, 
   {{0x7bc97418,0x98d40316,0x6480023a,0x22400175}},	//   tafu, _दिइए, töih, mkik_, 
   {{0xb5f8007b,0x5be0033f,0xe3d80154,0x116815b4}},	//   enál, नलेव, দ্রব, _صلّی_, 
   {{0xb058049f,0xf1bc004d,0xba457419,0xdb0800d0}},	//   _tvär, _toát_, ихий, _nedô, 
   {{0xb5f803f7,0x3f880030,0x22404fdf,0x8c3c00a2}},	//   gnál, _izbu_, nkik_, _huşl, 
   {{0x645d741a,0x7bc80bd7,0x8c3c05d1,0xee340958}},	//   kiri, pafu, _kuşl, _тнт_, 
   {{0x645d741b,0xb5f800c6,0xed4c0014,0xb21801bf}},	//   jiri, anál, _تھٔ_, _uhæv, 
   {{0x2241741c,0x8c3c0205,0x00000000,0x00000000}},	//   kkik_, _muşl, --, --, 
   {{0x645d741d,0x74100349,0x8c3c00a2,0x00000000}},	//   eiri, _সকেট_, _luşl, --, 
   {{0xef28044e,0x261c2017,0xe3b80205,0x00000000}},	//   _ተጋደል, याजी_, ıın_, --, 
   {{0x645c3182,0x9f580086,0x65600332,0x00000000}},	//   giri, _barü_, úmha, --, 
   {{0x9f580429,0x779004fb,0x66e01fbe,0xe7340798}},	//   _maró_, _گیگا, _доја, _веј_, 
   {{0x645c0597,0x9f58df8a,0x61d80a8f,0xd9f804aa}},	//   airi, _ebrë_, имся_, ्जित_, 
   {{0x645c9d20,0x7790036b,0x8c3c2347,0xf4840354}},	// [26a10] biri, _دیگا, _buşl, _вунн, 
   {{0x2fc401dc,0x645d741e,0x62880137,0xf1bcc17e}},	//   úng_, ciri, ïdor, _poás_, 
   {{0x261c2d6c,0xa4f40dd4,0x9258170a,0x8c3c062d}},	//   याची_, _བདོག_, _бант_, _duşl, 
   {{0xf1a83c5b,0xdef94661,0xb218005c,0xa2dc0118}},	//   _جاده_, рыф_, _skæf, _फित्, 
   {{0xe45000dd,0x9f59741f,0xb5f80306,0x00000000}},	//   _رضی_, _baró_, miád, --, 
   {{0x9f580561,0x01340375,0x8c3c00ee,0xb0580112}},	//   _obrè_, _הרשת_, _guşl, _zwän, 
   {{0x25e805ba,0x9f58011f,0xdd1000bc,0x4af8084c}},	//   _झाली_, _daró_, _výšc, уэля_, 
   {{0x956c1e38,0x08c57420,0xb5f800d7,0x00000000}},	//   በራትን_, ббин, niád, --, 
   {{0x645d7421,0xb5f97422,0xd9f802e5,0x00000000}},	//   yiri, rnál, ्ज़त_, --, 
   {{0x645d7423,0x224001c4,0x8c3c013d,0xac740133}},	//   xiri, zkik_, _kuşm, _ئارش, 
   {{0x645d7424,0x4424001e,0x1ce4025c,0xf54c01f2}},	//   viri, _đo_, _ཨའོ_, bụka_, 
   {{0x645d7425,0xc8400092,0x64800108,0x00000000}},	//   wiri, _ሕገመን, nöiv, --, 
   {{0xa8a57426,0x00000000,0x00000000,0x00000000}},	//   _трек, --, --, --, 
   {{0x9f580395,0x26182017,0x645c0e89,0x07381063}},	//   _marò_, _बोरी_, uiri, _مسبب_, 
   {{0x46b435b6,0x648020e5,0x2bdc1408,0x224003e0}},	//   _احتس, köiv, _नयना, tkik_, 
   {{0x645d7427,0x0ed01414,0xdb180162,0xe81c00bc}},	//   siri, _हिजड, ravø, बाका_, 
   {{0x645d7428,0x2240011f,0x1ce4031c,0xe5a400d1}},	// [26a20] piri, rkik_, _ཨའེ_, _лиқи, 
   {{0x645d7429,0x22400660,0x8c3c7a0e,0xb5f800e4}},	//   qiri, skik_, _quşl, tiág, 
   {{0xb5f80122,0xfec801e2,0x00000000,0x00000000}},	//   znám, ابطو_, --, --, 
   {{0x8c3c0209,0xb05801c7,0x1620012c,0x27140051}},	//   _duşm, _uwän, याएर_, _măn_, 
   {{0x2714001e,0x9f59742a,0xf1b00375,0x8c3c083c}},	//   _lăn_, _paró_, _מסר_, _tuşl, 
   {{0x9f580395,0xb5f80306,0x79a400fb,0x00000000}},	//   _darò_, vnám, әрйе, --, 
   {{0x245800ac,0x2714004d,0xb218005c,0x62840165}},	//   _cümə_, _năn_, _ihær, olio, 
   {{0x2618361b,0x9f5800a7,0x58d9742b,0x00000000}},	//   _बोली_, _farò_, адия_, --, 
   {{0x9f580428,0x6285742c,0xada001af,0x3ea80051}},	//   _garò_, ilio, _хаул, _hubt_, 
   {{0x32e8013b,0xb5f80ad9,0x271401fb,0xb4d80ffb}},	//   _wɔyɛ_, rnám, _băn_, zzàs, 
   {{0xbb85742d,0x271407ae,0xa4f4025c,0x6285398f}},	//   _الاي, _căn_, _བདུག_, klio, 
   {{0xeb9405f5,0x98280014,0x00000000,0x00000000}},	//   _уих_, اتکہ_, --, --, 
   {{0xb99475ad,0x00000000,0x00000000,0x00000000}},	//   _الشب, --, --, --, 
   {{0x7980738c,0x6285742e,0x769c0241,0x27140051}},	//   _iyow, elio, _bàyì, _făn_, 
   {{0x79800204,0x27e0012d,0x00000000,0x00000000}},	//   _hyow, ójne_, --, --, 
   {{0x6285742f,0x79800083,0x00000000,0x00000000}},	//   glio, _kyow, --, --, 
   {{0xf65c0393,0xb5f80cde,0x623556ff,0xc5ec00f1}},	// [26a30] miæ_, riád, чету, _ګړۍ_, 
   {{0x62857430,0xf53c0004,0xf65c0393,0x8c3c0432}},	//   alio, myå_, liæ_, _puşm, 
   {{0x9f5800a7,0xb5f80306,0x8c3c0724,0x1ce4031c}},	//   _sarò_, piád, _quşm, _ཨའུ_, 
   {{0xf1253718,0x7980014b,0x9f597431,0x62857432}},	//   _льго, _oyow, _parò_, clio, 
   {{0x79800687,0xdef802dd,0x6480005b,0x251c010f}},	//   _nyow, _қыр_, röiv, ָווא, 
   {{0xf1ec012d,0xb5f801d3,0x00000000,0x00000000}},	//   _छाड़_, niáb, --, --, 
   {{0x79800117,0xbab17433,0x6fbc07af,0xb5f800e5}},	//   _ayow, وموب, _ल्यू, rnáj, 
   {{0x8c082f8b,0x6480023a,0x8c3c247e,0x2714004d}},	//   লাইন_, löit, _kuşk, _răn_, 
   {{0xdb180122,0xaca0001e,0x2714001e,0xf65c0393}},	//   mavý, _trốn, _săn_, diæ_, 
   {{0x79801c06,0x89d804d3,0x6480023a,0x8c3c0139}},	//   _dyow, _چوار_, nöit, _muşk, 
   {{0x1bb89eec,0x62857434,0xdb0800b5,0x7c2c1497}},	//   _طالع_, ylio, _afdæ, _òbra, 
   {{0x271401dc,0xf65c003a,0xdb180306,0x59c400ae}},	//   _văn_, giæ_, navý, _فيمك, 
   {{0xda0826c0,0x644006ed,0x69c97435,0x27b000d1}},	//   _دينه_, êmio, _iege, _нәнс, 
   {{0x69c97436,0x648002f6,0x290c0067,0x0708143e}},	//   _hege, jöit, _isga_, _نيتي_, 
   {{0x4910038e,0x2bf806ab,0xdb181705,0x04f8015b}},	//   तिको_, ल्यू_, kavý, ইটের_, 
   {{0x69c97437,0x8c3c013d,0xf65c003a,0xdb1800e4}},	//   _jege, _buşk, ciæ_, javý, 
   {{0x69c97438,0x62857439,0x3ea80334,0xb2180393}},	// [26a40] _mege, rlio, _subt_, _phær, 
   {{0x69c81e56,0xb5f83b82,0x62840fcf,0x9f580413}},	//   _lege, ciáb, slio, _barð_, 
   {{0x62843247,0xff0880e7,0x69c8f633,0xfe4000e5}},	//   plio, реек_, _oege, وکری, 
   {{0x5bb461b8,0x69c9743a,0xbd447c8a,0xf2d0010f}},	//   ुर्व, _nege, يناي, _קער_, 
   {{0xf650025d,0x51542c28,0xb5f8810d,0x00000000}},	//   וצא_, _етру, liác, --, 
   {{0x69c9743b,0x126c02d3,0x648001f4,0x00000000}},	//   _aege, _ደብዳበ_, möis, --, 
   {{0xf53c0004,0xbf140220,0x290c0009,0x9f580321}},	//   zyå_, _بوزب, _asga_, _garð_, 
   {{0x69c81459,0x8c3c0166,0xfce5743c,0xb5f85923}},	//   _cege, _yuşk, _мобо, rnák, 
   {{0x69c9743d,0x1ce4025c,0x6480005b,0x6e3000d1}},	//   _dege, _ཨའི_, nöis, _تېنچ, 
   {{0x69c9743e,0x290c011c,0x37a81823,0xb5f800ae}},	//   _eege, _dsga_, штин_, mnái, 
   {{0x69c9743f,0xd7f80276,0x41a843d1,0x290c01d5}},	//   _fege, rfă_, कशास, _esga_, 
   {{0x69c97440,0x648002f6,0xb5f9389c,0x6b7808a8}},	//   _gege, köis, diác, _דרבנ, 
   {{0xb5f80597,0x3a240004,0x798001f0,0x38700220}},	//   nnái, _inop_, _uyow, _оқит, 
   {{0x69c97441,0xf65c16b8,0xb5f80419,0xe9fc0051}},	//   _zege, siæ_, fiác, thần_, 
   {{0x69c82045,0x3a241ad5,0xb5f97442,0xe8c40327}},	//   _yege, _knop_, riáb, _གསོག, 
   {{0xb40005f5,0xb218037e,0x683c045f,0xa2dc012c}},	//   чүүд, _skæb, _rêdi, _फिर्, 
   {{0x683c0af9,0x6480023a,0x7bd803ca,0xdb180306}},	// [26a50] _sêdi, töit, _odtu, vavý, 
   {{0x7bdc0789,0xd0109edc,0x00000000,0x00000000}},	//   ópul, علا_, --, --, 
   {{0x6480049b,0xb5f97443,0x4ee401e0,0xdb18d74c}},	//   röit, ciác, ясаҡ, tavý, 
   {{0x9f581bb0,0x7bd97444,0xd6bc00cc,0x648001f4}},	//   _varð_, _adtu, _আটায, söit, 
   {{0x90600131,0xa184026f,0xdb1802fb,0xdca8000d}},	//   _كۆرۇ, _жырл, ravý, _छूआछ, 
   {{0x8cc093d3,0x00000000,0x00000000,0x00000000}},	//   रीगो, --, --, --, 
   {{0x69c97445,0x81cc03f4,0xdb184a4a,0xb5f800c6}},	//   _pege, _রাত_, cavü, anái, 
   {{0xdea40517,0x8c3c0139,0x88c800d8,0x00000000}},	//   _قیلی, _muşi, блив_, --, 
   {{0x386c0354,0x69c97446,0xc8780311,0x8cc005d7}},	//   _bjfr_, _vege, luşi_, रीखो, 
   {{0xa2dc22e3,0x69c97447,0xadc001ee,0x00000000}},	//   _फिल्, _wege, _хаҡһ, --, 
   {{0x69c97448,0xc878054e,0x8c3c03b9,0x1d7c0092}},	//   _tege, nuşi_, _nuşi, _እናቶች_, 
   {{0xaca00016,0x69c8003a,0x00000000,0x00000000}},	//   _trồn, _uege, --, --, 
   {{0x04b46582,0x00000000,0x00000000,0x00000000}},	//   ясня, --, --, --, 
   {{0x648001f4,0x00000000,0x00000000,0x00000000}},	//   vöis, --, --, --, 
   {{0x22b80010,0x6cf80327,0x00000000,0x00000000}},	//   _očke_, _ནཱའེ_, --, --, 
   {{0xb5f90ebd,0x6480023a,0x1fd4102f,0xf2a03523}},	//   riác, töis, दण्ड, еисп, 
   {{0x80a57449,0x9abc0135,0xb5f800d0,0x00e40153}},	// [26a60] سمان, _irċe, siác, яжан, 
   {{0x44f40381,0x64800108,0x00000000,0x00000000}},	//   mæ_, röis, --, --, 
   {{0x4438560b,0x44f5744a,0x8c3c0356,0x64800108}},	//   _iop_, læ_, _guşi, söis, 
   {{0x4439744b,0x83680092,0x64800108,0x00000000}},	//   _hop_, ተዋወቅ_, pöis, --, 
   {{0x4439744c,0xc1e4004b,0x10f4010b,0x44f40381}},	//   _kop_, _وکړل_, _ояря, næ_, 
   {{0x4439744d,0xb5f80597,0xe81800af,0xed4c0f31}},	//   _jop_, rnái, _भोला_, چھے_, 
   {{0x4439744e,0x6bd1744f,0xc878054e,0x7f48007b}},	//   _mop_, رتور, cuşi_, _الأق_, 
   {{0x44397450,0x8e74dd5c,0x3878001f,0xe9e002e8}},	//   _lop_, _жууч, _አባላቱ_, нцьо, 
   {{0xb5f91d9e,0xfd482692,0x44397451,0x7e60117e}},	//   onáv, _узак_, _oop_, miop, 
   {{0x7e617452,0x1cdc031c,0x31540375,0x6cd0007b}},	//   liop, _རྗར_, פיין_, _أقلا, 
   {{0x9f5835f5,0x7c3803ac,0x764c0142,0xdb180124}},	//   _obrí_, _iotr, thcy, ravó, 
   {{0x7c397453,0x7e60c2ff,0x8c3c0276,0x1dcc1b61}},	//   _hotr, niop, _ruşi, ारित, 
   {{0x7ae81455,0x8c3c0432,0x7e6001ab,0x85a400ee}},	//   luft, _atşy, iiop, дырҗ, 
   {{0x7e609f02,0x9f580407,0xb8657454,0x7c397455}},	//   hiop, _abrí_, _عاشو, _jotr, 
   {{0xb5f803c6,0x1dcc0db3,0x7e61609c,0x7c397456}},	//   dnáv, ारात, kiop, _motr, 
   {{0x62357457,0x387c03d1,0x44f401a8,0xbb800150}},	//   несу, lotr_, bæ_, _ﺨﺼﻤﻪ_, 
   {{0x7c39151f,0x44386c2b,0x9f5800e4,0x44f40393}},	// [26a70] _ootr, _fop_, _marõ_, cæ_, 
   {{0x7c397458,0xc8780276,0x22b8007f,0x44380f85}},	//   _notr, tuşi_, _sčke_, _gop_, 
   {{0x38b00156,0x8c3c0139,0xdd94035b,0x00000000}},	//   _lâr_, _kuşv, ҭахы, --, 
   {{0x7c3803bd,0x4438068c,0x7e603a5b,0xc878054e}},	//   _aotr, _zop_, giop, ruşi_, 
   {{0x7c397459,0xc8780311,0x387c05da,0x5f9400fd}},	//   _botr, suşi_, kotr_, _җитт, 
   {{0x7c39745a,0xb05801b8,0x4438004e,0xc8780311}},	//   _cotr, _stäf, _xop_, puşi_, 
   {{0x7c391ecb,0x7ae8003a,0xdce80327,0x7c3c0254}},	//   _dotr, guft, ħoġb, öpra, 
   {{0x7e61745b,0x22b801a6,0x38b00042,0x7c3803ac}},	//   ciop, _učke_, _bâr_, _eotr, 
   {{0x7c381c69,0x387c0109,0x261800e1,0x38b00042}},	//   _fotr, fotr_, _बोगी_, _câr_, 
   {{0x6e39745c,0x7c39745d,0x8bd401d5,0x38b00042}},	//   _houb, _gotr, _آقاش, _dâr_, 
   {{0x4439745e,0x6e39745f,0xb0580166,0xeb4864c2}},	//   _rop_, _koub, _itäd, _учак_, 
   {{0x44397460,0x7c397461,0x2b4c0365,0xb5f80232}},	//   _sop_, _zotr, ımcı_, znáv, 
   {{0x6e382819,0x683c145e,0x387c05da,0x44382d58}},	//   _moub, _sêdu, botr_, _pop_, 
   {{0x6e397462,0x7c380077,0x4438e236,0x1cdc031c}},	//   _loub, _xotr, _qop_, _རྗས_, 
   {{0xb5f82358,0x44397463,0x44f40393,0x00000000}},	//   vnáv, _vop_, sæ_, --, 
   {{0x44397464,0x6e390adb,0x03a4013e,0x00000000}},	//   _wop_, _noub, зиҳо, --, 
   {{0x44397465,0xb5f80122,0x8c3d282a,0x7e6001f4}},	// [26a80] _top_, tnáv, _huşu, viop, 
   {{0xdbcc05f7,0xb0580030,0x2a7c0100,0x8c3c5775}},	//   jóði, _zväz, houb_, _kuşu, 
   {{0x7e617466,0x3eac0b21,0x7c38b368,0xdce00037}},	//   tiop, êft_, _rotr, _निहछ, 
   {{0x7c397467,0xfce41f0f,0xb5f800e5,0x3f9c0aab}},	//   _sotr, додо, hián, _útum_, 
   {{0x6da00e58,0xc8781ae4,0x80a000c7,0x9ca40372}},	//   вица, luşu_, _аҳаҧ, ىشتۇ, 
   {{0x9b940323,0x7e617468,0x7ae80158,0xdbcc1d0e}},	//   нилц, siop, tuft, góði, 
   {{0x7c389083,0x201802b5,0x6e380100,0x7e60f96b}},	//   _votr, _iari_, _foub, piop, 
   {{0x20181f29,0x6e3921f4,0xaa613716,0xb5f801a8}},	//   _hari_, _goub, ктык, nnát, 
   {{0x7c397469,0x3dc5746a,0xb5f82358,0x387c06d9}},	//   _totr, mbow_, fián, totr_, 
   {{0x6c00026a,0xb5f9746b,0x6e39746c,0x8c3d282a}},	//   _изуз, hnát, _zoub, _buşu, 
   {{0x2019746d,0x6e39746e,0x387c05da,0xd5ec004d}},	//   _mari_, _youb, rotr_, _nhạ, 
   {{0x2019746f,0x8c3c09a5,0x6e380005,0x1cdc031c}},	//   _lari_, _duşu, _xoub, _རྗོ_, 
   {{0xf48431fd,0xb5f97470,0x3ce423cc,0x00000000}},	//   дувн, dnát, nrov_, --, 
   {{0x20182dab,0xb5f804d4,0x32b8007b,0x6840014b}},	//   _nari_, cián, قدرة_, _инча, 
   {{0xd5ec004d,0x8c3c0432,0x00000000,0x00000000}},	//   _chạ, _guşu, --, --, 
   {{0x20197471,0x22943b78,0x3ce57472,0xb0580419}},	//   _aari_, вися, krov_, _uväz, 
   {{0x6e397473,0x8c3c1f02,0x917400c7,0x00000000}},	// [26a90] _roub, _kuşt, хгац, --, 
   {{0x20197474,0x6e38038e,0x2600033d,0x3ce57475}},	//   _cari_, _soub, ष्ठी_, drov_, 
   {{0x201971ef,0x6e397476,0x8c3d7477,0x88d400b8}},	//   _dari_, _poub, _muşt, _hṛts, 
   {{0xb0589577,0x6e380109,0x2018f682,0xb5f97478}},	//   _städ, _qoub, _eari_, mnás, 
   {{0x201805ec,0xad241c07,0x3ce57479,0x00000000}},	//   _fari_, براو, grov_, --, 
   {{0x2019747a,0x6e39747b,0xb5f80077,0x88d4002b}},	//   _gari_, _woub, xián, _mṛts, 
   {{0x6e39747c,0xb5f800e4,0x3dc40014,0x1a6803e6}},	//   _toub, vián, bbow_, ژیمی_, 
   {{0x20180516,0x2ec80574,0x5f947e8c,0x3ce5747d}},	//   _zari_, ाठीत, _рист, brov_, 
   {{0x2018633d,0x8c3d3479,0x2a7c01f7,0xb05800fd}},	//   _yari_, _buşt, roub_, _itäb, 
   {{0xc05000c8,0xab2802dd,0xb5f80122,0x9f5800d8}},	//   ָזט_, _وسال_, znát, _tarô_, 
   {{0xb5f81a09,0x22b853f5,0x8c3d747e,0x00000000}},	//   rián, _očka_, _quşu, --, 
   {{0xb218037e,0xfb180375,0xcfb40154,0xb5f800e4}},	//   _skæn, _מועמ, টরিন, sián, 
   {{0xb5f8022a,0x00000000,0x00000000,0x00000000}},	//   vnát, --, --, --, 
   {{0x291c01c8,0x8c3c05d1,0xd5ec004d,0xdb1801e3}},	//   mvua_, _tuşu, _phạ, bbvä, 
   {{0x2019747f,0xaca0063f,0x68f97480,0x6684004b}},	//   _rari_, _apịn, ltud, _لیدل, 
   {{0x2cbc05a1,0xb5f85955,0xc8781432,0x8c3c0139}},	//   _otud_, niál, ruşu_, _kuşs, 
   {{0x6604633d,0x68f97481,0xa2dc28d4,0x67200960}},	// [26aa0] _ibik, ntud, _फिक्, _hrnj, 
   {{0xb4f8025f,0x20197482,0x672007f5,0x22b800f3}},	//   _צפיי, _qari_, _krnj, _ečka_, 
   {{0x20197483,0x68f800af,0xefbc001f,0x6604037e}},	//   _vari_, htud, ድሚያ_, _kbik, 
   {{0x20197484,0x3ce57485,0x67200e3c,0x68f97486}},	//   _wari_, trov_, _mrnj, ktud, 
   {{0x20197487,0xb5f97488,0xf48403e6,0xb0580221}},	//   _tari_, onár, _زایی, _stäe, 
   {{0x60c57489,0x2bf834ef,0x20180ffb,0xb5f83168}},	//   mpim, ल्लू_, _uari_, nnár, 
   {{0x68f9748a,0x6605748b,0x2cbc007f,0xdb10014a}},	//   etud, _obik, _etud_, _äfün, 
   {{0x3ce5748c,0xdff00bb2,0x60c4009f,0x2b7412e9}},	//   prov_, _चाँद_, opim, رینگ_, 
   {{0x68f9748d,0x3f880368,0x21200097,0xed54036b}},	//   gtud, _hybu_, nvih_, _зот_, 
   {{0x672005a1,0xdb1801b8,0xb5f802fb,0x8c3ce73c}},	//   _brnj, davö, jnár, _duşs, 
   {{0x672008ad,0xb5f9748e,0x569421fa,0x00000000}},	//   _crnj, dnár, каот, --, 
   {{0xb5f81dee,0x212004b9,0xdb1801b8,0x60c40309}},	//   ciál, kvih_, favö, kpim, 
   {{0xa50429e1,0xdb0800b5,0xdff0447d,0x3af8002e}},	//   лярл, _afdø, _चांद_, lëp_, 
   {{0x66040c8a,0xb5f9748f,0x00000000,0x00000000}},	//   _ebik, gnár, --, --, 
   {{0x60c4000d,0x00000000,0x00000000,0x00000000}},	//   epim, --, --, --, 
   {{0x6604006a,0x066400c7,0xb5f97490,0xcfcc0eac}},	//   _gbik, _ахьҭ, rnás, _লাইন, 
   {{0x21200007,0xf1bc01fb,0x67201a48,0x42a40131}},	// [26ab0] gvih_, _xoáy_, _zrnj, турғ, 
   {{0x9418016b,0xb0580112,0x3af800e8,0xd8380100}},	//   _ɛyɛe_, _stäb, këp_, njč_, 
   {{0x2cbd7491,0xc8840730,0x6604005c,0x60c4000d}},	//   _stud_, äßig_, _ybik, apim, 
   {{0x22b828b5,0xb5f80306,0x78a8007c,0x31c49a9a}},	//   _učka_, xiál, _lifv, _ясов, 
   {{0x6448049f,0xdd9402d5,0xedd400d1,0xb5f80518}},	//   ödig, гацы, _үлгә_, viál, 
   {{0xdb180037,0x68f8005c,0x09d801f9,0x00000000}},	//   havõ, vtud, णण्य, --, 
   {{0x5f956065,0xdb1800c5,0xd83802e2,0xe8181116}},	//   _бирт, kavõ, djč_, _भोगा_, 
   {{0x68f97492,0x78a8011c,0xaca00241,0xdbe401e1}},	//   ttud, _aifv, _ipọn, _lèèw, 
   {{0xb5f82195,0x2c000b8d,0x2038001f,0x1cb0025c}},	//   riál, _бүлм, _በማቅረ, _དངར_, 
   {{0x68f97493,0x67201505,0xb21837e6,0x1cdc031c}},	//   rtud, _prnj, _skæl, _རྗི_, 
   {{0xca6001a9,0x291c023a,0x2454000d,0xb5f802f0}},	//   _islо, svua_, _jäme_, piál, 
   {{0x60c57494,0x67217495,0x24540139,0x9f4c0129}},	//   ypim, _vrnj, _mäme_, ûlés_, 
   {{0x95997496,0xf1bc0429,0x95740139,0x224c00ef}},	//   етру_, _ináh_, гырч, _ēdk_, 
   {{0x6aa80421,0x672016a3,0xdb197497,0x1af4015b}},	//   _higf, _trnj, ravö, _আনতে_, 
   {{0x245409a5,0x60c402d1,0x161c07f7,0xdb18000d}},	//   _näme_, wpim, _बोकर_, bavõ, 
   {{0x66057498,0xc44c2e1f,0x3f880306,0x7eb8002b}},	//   _ubik, _ፕሮፌሰ, _rybu_, _nįpa, 
   {{0xb1411e2f,0x60c40784,0xd42003d4,0xa3140139}},	// [26ac0] антл, upim, _নকৰি_, _өянә, 
   {{0x07142db8,0x60c57499,0x6aa9749a,0x212005d5}},	//   _तनाव_, rpim, _ligf, rvih_, 
   {{0xb05801c7,0x60c40784,0xb5f800e5,0x00000000}},	//   _stäc, spim, diáj, --, 
   {{0x60c5749b,0x24540139,0xf77000df,0x0165749c}},	//   ppim, _däme_, סקא_, _акмо, 
   {{0x3f880142,0xe5c80150,0x00000000,0x00000000}},	//   _wybu_, _ﺒﺘﻤﺜ, --, --, 
   {{0xdef802d3,0x8c3c0166,0xb5f81a74,0x62854cc5}},	//   _ወሲኹ_, _buşq, viám, loio, 
   {{0xb05801c7,0xf7e80131,0x6aa95311,0x44f80154}},	//   _ewäs, ۈردى_, _bigf, েটিক_, 
   {{0xf2d00375,0x6aa80042,0x8c3c0139,0xbe140eff}},	//   בעה_, _cigf, _duşq, _جورع, 
   {{0xada00116,0x6aa8058a,0x22b80306,0xa9640063}},	//   _ватл, _digf, _očko_, кића_, 
   {{0x63bc0fcf,0xb5f80077,0x3af8002e,0xb8d88153}},	//   jcrn, riám, pëp_, _आं_, 
   {{0x25ac0085,0x6aa8007f,0xb218005c,0x70dc000d}},	//   ɛklɛ_, _figf, _skæm, _फट्ल, 
   {{0xf645418a,0x6aa80142,0xb5f8003a,0xa2dc000d}},	//   тхон, _gigf, piám, _फिज्, 
   {{0x1cb0025c,0xb4b00116,0x8c3c03b9,0xdb180254}},	//   _དངས_, ригә, _kuşp, ravõ, 
   {{0x8c3c0166,0xdb180037,0x6aa80171,0x00000000}},	//   _yuşq, savõ, _zigf, --, 
   {{0xa3d40574,0xe2f80220,0xa3e40037,0x00000000}},	//   _हजर_, кері_, _पएर_, --, 
   {{0x6258007b,0x62840165,0x24540254,0x35440006}},	//   _líof, goio, _räme_, _ахов, 
   {{0xa5d82abb,0x90980798,0x201c022e,0x00000000}},	// [26ad0] _شبير_, еват_, оvi_, --, 
   {{0xc1a401ec,0xa0680114,0x00000000,0x00000000}},	//   уысқ, вађа_, --, --, 
   {{0xd2504a4c,0x62840165,0x00000000,0x00000000}},	//   _هند_, boio, --, --, 
   {{0x7bc80218,0x0d982cc8,0x60e81432,0xc33005d0}},	//   ebfu, нтлы_, ürmü, _הוט_, 
   {{0xf1bc0570,0xea6000f2,0x00000000,0x00000000}},	//   _ifá_, یپتی, --, --, 
   {{0x6aa96804,0x24540166,0xf1bc00d7,0x8c880022}},	//   _sigf, _täme_, _snáh_, хәба_, 
   {{0x9f34fc53,0x62580332,0x6aa80142,0x8c3c013d}},	//   _кері, _díof, _pigf, _quşq, 
   {{0xe8c40156,0xe81800af,0x7d500139,0x00000000}},	//   _གསདག, _भोजा_, рвәх, --, 
   {{0xde6400a7,0x07f801c0,0x6aa808a5,0x00000000}},	//   _търп, нхны_, _vigf, --, 
   {{0xf8ac70c8,0x62840810,0x00000000,0x00000000}},	//   سکه_, zoio, --, --, 
   {{0xf1bc1132,0x1cb0031c,0x628401c8,0xf1d001bc}},	//   _ofá_, _དངོ_, yoio, तरान, 
   {{0x442400ee,0x00000000,0x00000000,0x00000000}},	//   _şo_, --, --, --, 
   {{0x62580332,0x6284054e,0x48e4011c,0x00000000}},	//   _híog, voio, _солв, --, 
   {{0xf1bc0270,0xfbc42894,0xd90d2766,0x00000000}},	//   _afá_, रुपम, _کیی_, --, 
   {{0x62840156,0x80d401ad,0xa3040661,0x699c01f9}},	//   toio, मीने, шүне, खेरी, 
   {{0xe81800bc,0x80e0000d,0xf77005d0,0x00000000}},	//   भएका_, _पिआइ, _לקו_, --, 
   {{0x62840489,0xc005749d,0xb5c001e0,0x00000000}},	// [26ae0] roio, лпак, _уйыл, --, 
   {{0xf5340677,0xa3b80037,0x00000000,0x00000000}},	//   _עניי_, _छलि_, --, --, 
   {{0x6284009f,0x7de402dd,0x625801e7,0x39980023}},	//   poio, гілд, _ríof, _ቅድስቲ_, 
   {{0x201c07f5,0xd04c0b45,0xeee401b9,0xb5f800e4}},	//   žvi_, kraɗ, اغلی, viák, 
   {{0x6f8401d9,0xb0580108,0x00000000,0x00000000}},	//   نچہِ_, _itän, --, --, 
   {{0x62580332,0x00340064,0xdbf80055,0xb5f800e4}},	//   _bíog, _сэмю, _pāñi, tiák, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6258007b,0xb5f800e5,0xfcd401f7,0xdbf80055}},	//   _díog, riák, _ميرج, _vāñi, 
   {{0xdca40184,0x62580332,0xa0380092,0x7bdc00e5}},	//   _ҡағи, _tíof, _በማንሳ, ópus, 
   {{0x0d7445b3,0x00000000,0x00000000,0x00000000}},	//   _тыся, --, --, --, 
   {{0xb0580267,0xe93400db,0xa3b8000d,0x6c7800df}},	//   _otän, _ەسىت_, _छल़_, _טאמפ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf991749e,0x58d40e76,0xd04c0198,0x00000000}},	//   _ابا_, _толт, craɗ, --, 
   {{0x81cc015b,0x338402e8,0x00000000,0x00000000}},	//   _রাগ_, губв, --, --, 
   {{0x56940c04,0x44d00165,0xf7700451,0x00000000}},	//   _какт, aņ_, _ھاڻ_, --, 
   {{0xf77016cb,0x7c24013b,0xa6c002dd,0x00000000}},	//   _پاڻ_, _ɔkra, _اقيى, --, 
   {{0xa15832b0,0x4fd4ac8a,0xb5f800e4,0xd2f800e5}},	// [26af0] гату_, ижат, viáh, رکھا_, 
   {{0x764c0009,0xb05801f4,0x00000000,0x00000000}},	//   lkcy, _etän, --, --, 
   {{0x625800c6,0x1cb00327,0x00000000,0x00000000}},	//   _bíod, _དངུ_, --, --, 
   {{0x9f5c012c,0x6258007b,0x764c033f,0x4338010f}},	//   ývá_, _ríog, nkcy, _סערב, 
   {{0x6259749f,0x24540254,0xd2500214,0x00000000}},	//   _díod, _häma_, _هنگ_, --, 
   {{0xcb6974a0,0x13d80eac,0xb05801f4,0x00000000}},	//   кале_, _তাড়, _itäo, --, 
   {{0xceb81321,0xfd4c0241,0x625801e7,0x15e40073}},	//   _рәз_, _kikọ, _fíod, कणार_, 
   {{0xfd4c0521,0x80d80316,0xdb2401ed,0x4a4400d8}},	//   _jikọ, _पौडे, ásáh, рнив, 
   {{0xdd947aa6,0x2908068c,0x98c401d5,0x00000000}},	//   _гаты, ïca_, یغین, --, 
   {{0x60c00036,0x625800ae,0x2900003d,0x6d4800c0}},	//   _émme, _tíog, ċja_, myga, 
   {{0x6d4974a1,0x00000000,0x00000000,0x00000000}},	//   lyga, --, --, --, 
   {{0x44d00109,0x89640014,0x00000000,0x00000000}},	//   tņ_, _پُتن, --, --, 
   {{0x6d48ce33,0x1cdc025c,0x69d974a2,0x98a00790}},	//   nyga, ྡེག_, maue, _çiğ_, 
   {{0xb05974a3,0x69d974a4,0x07a402e8,0x02c401b9}},	//   _stän, laue, _калн, ийго, 
   {{0xd1d40020,0x03a4871a,0x7c3c007c,0x00000000}},	//   ርጉት_, риво, öpri, --, 
   {{0x69d974a5,0x6d4802d0,0x4528b27b,0x00000000}},	//   naue, kyga, _ажин_, --, 
   {{0xd8380100,0xd50807d6,0x41a80cb6,0x6d48010b}},	// [26b00] kmčl_, _یغین_, тван_, jyga, 
   {{0x69d80639,0x6d4974a6,0xdd9401e0,0xff5174a7}},	//   haue, dyga, ҙалы, يخا_, 
   {{0xfd4c0241,0xb058f4b5,0x69d974a8,0x2fd40214}},	//   _fikọ, _itäl, kaue, شوند_, 
   {{0x72d80375,0x69d8067c,0x6d4803ac,0x00000000}},	//   _בקטג, jaue, fyga, --, 
   {{0x69d974a9,0xfd10211f,0x6fa401ad,0x626c0356}},	//   daue, تجا_, केबं, cşoa, 
   {{0xac0406b3,0x8fd40022,0xbae574aa,0x69d80076}},	//   инча_, _гәцә, аций, eaue, 
   {{0x69d8fc7f,0x7f440354,0x3f6801a9,0x00000000}},	//   faue, _тевж, _риво_, --, 
   {{0x6d4910ef,0x5a341fbd,0x69d974ab,0x62580332}},	//   byga, снит, gaue, _híob, 
   {{0xeb940184,0xdb2403e6,0x00000000,0x00000000}},	//   лиә_, _گوای, --, --, 
   {{0xb8fc534e,0x7d0174ac,0xf1bc01ef,0xb8cc01f9}},	//   _तब_, mtos, _hnát_, _कळ_, 
   {{0xdb24168d,0x69d974ad,0x04f403d4,0xfa341bf4}},	//   _دوای, baue, ইবোৰ_, _پراد, 
   {{0x69d91594,0xa96401d3,0x79a41fbe,0xca7400c0}},	//   caue, امیم_, _крле, _лучы, 
   {{0xcaa40ada,0x764c01e3,0x00000000,0x00000000}},	//   _اصلي, rkcy, --, --, 
   {{0xf48574ae,0x7d001e76,0xd4580240,0x00000000}},	//   румн, itos, _ግዝያዊ, --, 
   {{0x7d0174af,0x32640006,0x81cc0154,0xb5f80c63}},	//   htos, атав, _রাজ_, diáv, 
   {{0x7d0174b0,0xd5880116,0x9f5801e7,0xc1c80131}},	//   ktos, _бәгл_, _gcré_, _ﺑﯩﺮﺍ, 
   {{0x7d0174b1,0x625800ae,0x6d484e2d,0x00000000}},	// [26b10] jtos, _bíob, xyga, --, 
   {{0xd7f8084c,0xb5f800e5,0xdb440133,0x00000000}},	//   ngă_, giáv, _قێ_, --, 
   {{0x625800c6,0x69d80036,0x7d0174b2,0x445400f1}},	//   _díob, yaue, etos, _دريځ, 
   {{0x6d4974b3,0x24540267,0xb058adae,0xdce01b0d}},	//   tyga, _jämn_, _itäm, _azmı, 
   {{0x765c0064,0x00000000,0x00000000,0x00000000}},	//   _įpyl, --, --, --, 
   {{0x6d4974b4,0xb5f80798,0x00000000,0x00000000}},	//   ryga, ciáv, --, --, 
   {{0xeea835f2,0x7d007881,0xce9401c6,0x00000000}},	//   _атак_, atos, _гавъ, --, 
   {{0x7d00381a,0x2454007c,0x00000000,0x00000000}},	//   btos, _nämn_, --, --, 
   {{0x69d974b5,0x9f4c0086,0x088806b3,0xda64014d}},	//   raue, _ùdò_, лбий_, تاوي, 
   {{0xf1bc00bc,0x00000000,0x00000000,0x00000000}},	//   _znát_, --, --, --, 
   {{0x068574b6,0x69d974b7,0x48a80116,0x3208012d}},	//   йгон, paue, ктүм_, _obcy_, 
   {{0xb0580628,0xda080acb,0xd7f80276,0x06540953}},	//   _stäl, _نيمه_, agă_, стоў, 
   {{0x27b01884,0x3a8401ed,0x199400c0,0x00000000}},	//   _мәнс, _اُنہ, _даця, --, 
   {{0x290c022e,0x9478005b,0x00000000,0x00000000}},	//   _ipga_, ассу_, --, --, 
   {{0x7d00066d,0xb5f80124,0x6258007b,0x7c2c01a8}},	//   ztos, viáv, _níoc, _óbre, 
   {{0x7d0174b8,0x26c40198,0x625801e7,0x00000000}},	//   ytos, _itno_, _síob, --, 
   {{0x625800ae,0xf1bc0332,0xb05801f4,0x7f8400d1}},	// [26b20] _aíoc, _anás_, _etäm, ڭلان, 
   {{0x40940fc0,0x7d0001d5,0x00000000,0x00000000}},	//   ёрат, vtos, --, --, 
   {{0x290c02fa,0xb5f974b9,0x683c002d,0x645c07f0}},	//   _lpga_, riáv, _bêdz, mhri, 
   {{0x7d0174ba,0xb218037e,0xee3401c0,0x1cb00327}},	//   ttos, _skæv, йнх_, _དངང_, 
   {{0xb5f8ec21,0x7d0174bb,0x9abc0135,0xd17574bc}},	//   piáv, utos, _irċi, _дыры, 
   {{0x224174bd,0x6f101709,0x645d74be,0x625800ae}},	//   ljik_, ñecí, nhri, _fíoc, 
   {{0x7d004c28,0xf1bc00ae,0x9b580395,0x00000000}},	//   stos, _inár_, рийт_, --, 
   {{0x7d0174bf,0xa3e81d97,0x795c0248,0x6d50030a}},	//   ptos, मृत_, _nàwé, ñjañ, 
   {{0x645c730f,0x026401fb,0x3ea574c0,0x7d0001a9}},	//   khri, _đến_, mmot_, qtos, 
   {{0xd7f800a8,0x3ea574c1,0x2bcc1d72,0xddc00421}},	//   ugă_, lmot_, _स्पा, _momō, 
   {{0xd7f80276,0x645d74c2,0xb5f828c8,0x7bd800e2}},	//   rgă_, dhri, mnáz, _ietu, 
   {{0x7bd974c3,0x644974c4,0x8b6574c5,0x3ea4007f}},	//   _hetu, ödin, _ظالم, nmot_, 
   {{0xa9640faa,0x7bd974c6,0xb05804f3,0x2240022e}},	//   _лица_, _ketu, _stäm, djik_, 
   {{0xe944066d,0x645d74c7,0x9abc0003,0x7bd974c8}},	//   _درمی, ghri, _arċi, _jetu, 
   {{0x7bd974c9,0xe73410fc,0x32080408,0xb5f802f0}},	//   _metu, _геј_, лхан_, fiát, 
   {{0x7bd974ca,0x2bcc1db2,0x224002d3,0x625800c6}},	//   _letu, _स्ना, gjik_, _ríoc, 
   {{0x625800c6,0x645d74cb,0x7bd802d0,0xf4851197}},	// [26b30] _síoc, bhri, _oetu, _гунн, 
   {{0x645d7447,0x7bd974cc,0xddd404a7,0xe2340023}},	//   chri, _netu, _čašo, _ኣረሜና, 
   {{0x8db400d4,0x225400e4,0x7cd406be,0x00000000}},	//   ослі, ñaká_, hərı, --, 
   {{0xdef800fd,0x7bd8093f,0x68480023,0x00000000}},	//   сыф_, _aetu, _ዝወስድ, --, 
   {{0x7bd974cd,0x8c4574ce,0x00000000,0x00000000}},	//   _betu, желе, --, --, 
   {{0x7bd974cf,0x62580332,0x3ea40108,0x00000000}},	//   _cetu, _tíoc, amot_, --, 
   {{0x7bd974d0,0xaee00150,0xb5f800c7,0xdfd401c6}},	//   _detu, _رۋشى, chág, _хосы, 
   {{0x7bd974d1,0x08c4fd92,0x1cdc025c,0x00000000}},	//   _eetu, обин, _རྗམ_, --, 
   {{0x7bd974d2,0x1cd4036b,0xdef80240,0x00000000}},	//   _fetu, _нотў, _ወሲነ_, --, 
   {{0x7bd974d3,0x645c036e,0x00000000,0x00000000}},	//   _getu, xhri, --, --, 
   {{0x2bcd351b,0x00000000,0x00000000,0x00000000}},	//   _स्या, --, --, --, 
   {{0x7bd974d4,0x22b801a6,0x00000000,0x00000000}},	//   _zetu, _učki_, --, --, 
   {{0x645d74d5,0x7bd974d6,0xf4200183,0xa9240214}},	//   thri, _yetu, মানৰ_, _دعاه, 
   {{0x2bcc0c70,0xa8a4084c,0xdef802d3,0x7bd800e8}},	//   _स्मा, _урек, _ወሲኑ_, _xetu, 
   {{0x769c0a28,0x645c0008,0x2240020c,0xd33484e8}},	//   ṣyat, rhri, tjik_, пэты, 
   {{0x645d74d7,0xdb1974d8,0x81c848d4,0xf1bc00d7}},	//   shri, ncvá, ргав_, _snár_, 
   {{0x645d74d9,0x1cdc031c,0x22400bbc,0x00000000}},	// [26b40] phri, ྡེབ_, rjik_, --, 
   {{0xd17450c0,0x409412fa,0xb21802d2,0xb5f974da}},	//   чысы, ірат, _skæt, siát, 
   {{0x7bd974db,0x68480023,0xb5f848cb,0x03a400f3}},	//   _retu, _ዝወሰድ, bhád, _фино, 
   {{0xb5f974dc,0x7bd974dd,0x935801e0,0x765c00c0}},	//   chád, _setu, _ырыу_, _įpyk, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7bd800fb,0x6bd000d1,0x7ac4014b,0x00000000}},	//   _qetu, وتىر, осие, --, 
   {{0x7bd974de,0x2454000d,0x2900030a,0xb5f801d3}},	//   _vetu, _nämm_, ńjal_, rnáz, 
   {{0x7bd974df,0x6f0005d5,0x8e5402dd,0x58d402e8}},	//   _wetu, ànce, _етуі, поит, 
   {{0x7bd974e0,0x620c00bc,0xed5574e1,0xb864009a}},	//   _tetu, ड्यौ_, _дот_, قادو, 
   {{0xb8647b1d,0x7bd974e2,0xf84867b7,0xb5f802f0}},	//   تابو, _uetu, рчий_, zhád, 
   {{0xb5f974e3,0xb9e40212,0xb05801f4,0x41a800cd}},	//   diár, _діли, _stäk, चेतस, 
   {{0xb5f800d8,0x85e000d1,0x00000000,0x00000000}},	//   viás, ىۋىن, --, --, 
   {{0x9e3801ec,0xb8640efe,0x00000000,0x00000000}},	//   ртiб, _واتو, --, --, 
   {{0xb5f974e4,0x8c3c00a2,0x31d01cba,0x00000000}},	//   giár, _buşy, तर्ध, --, 
   {{0x795004d3,0x1fc00154,0x00000000,0x00000000}},	//   _رێگا, ইরাস, --, --, 
   {{0xa7580302,0x8c3c010e,0xb9e00023,0xb058005b}},	//   _כדור, _duşy, _ኩን_, _itäi, 
   {{0x50f4169c,0xb5f974e5,0x2fc81d93,0xa19411db}},	// [26b50] язат, siás, لباً_, датч, 
   {{0xb5f8d02b,0x8c3c0205,0x00000000,0x00000000}},	//   ciár, _fuşy, --, --, 
   {{0xb5f800c6,0xc1d00150,0xc878010e,0x00000000}},	//   mháb, _ﭘﻪﺩﺍ, guşy_, --, 
   {{0x798003ac,0xb5f801d3,0x00000000,0x00000000}},	//   _oxow, lháb, --, --, 
   {{0x260005ba,0x823827af,0x8d280276,0xa69c00df}},	//   ष्टी_, _הערצ, солв_, בשאפ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6258007b,0x4a741d37,0xe0640244,0x00000000}},	//   _míon, зыпт, _تێلی, --, 
   {{0x62580597,0xb5f800d2,0xb0580b70,0xe37c011a}},	//   _líon, hháb, _stäh, ירור, 
   {{0x2bcc37f3,0x38c87be0,0x00000000,0x00000000}},	//   _स्था, یایی_, --, --, 
   {{0x62580332,0xc0dc0092,0x00000000,0x00000000}},	//   _níon, ዕከሉ_, --, --, 
   {{0xb5f974e6,0x89d812ea,0x7c2c02d2,0x00000000}},	//   viár, _هوار_, _óbra, --, 
   {{0x625800c6,0x2bcc15e0,0x02a80073,0x00000000}},	//   _aíon, _स्ता, _कळेन, --, 
   {{0x62580597,0x7980014b,0xb058023a,0xa6380092}},	//   _bíon, _gxow, _etäi, _እየወሰ, 
   {{0xb5f801d3,0x9f580332,0x00000000,0x00000000}},	//   gháb, _scrí_, --, --, 
   {{0x425574e7,0x62585e4f,0x82a40212,0xb5f800e5}},	//   птат, _díon, завж, riár, 
   {{0xb21974e8,0xa3b80307,0x9238004e,0x00000000}},	//   _skær, _छलक_, очуу_, --, 
   {{0x6258007b,0x37dc00cc,0x00000000,0x00000000}},	// [26b60] _fíon, _মাতৰ, --, --, 
   {{0xd1789e08,0xb5f80077,0x25a00165,0x03a40556}},	//   істі_, cháb, _izil_, _нипо, 
   {{0x3898010f,0x622400db,0xfbc4000d,0x00000000}},	//   ציענ, _قودە, _र्गम, --, 
   {{0xf42003d4,0x6e9000d1,0x00000000,0x00000000}},	//   মাণৰ_, ىللا, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2e3400db,0x00000000,0x00000000,0x00000000}},	//   تبەڭ, --, --, --, 
   {{0x7c6424a2,0x9f580120,0x22b801a6,0x00000000}},	//   _کارل, _ecrã_, _učku_, --, 
   {{0xb05804e6,0xbc645a41,0xe11001ec,0xee34009d}},	//   _stäi, _евак, есiн_, _энт_, 
   {{0x8db402dd,0x3ce4b2ce,0x7e700244,0x00000000}},	//   _істі, msov_, _تۆڵڵ, --, 
   {{0x625801e7,0x43b400cd,0x00000000,0x00000000}},	//   _ríon, ंशोऽ, --, --, 
   {{0x62580332,0xa2c00303,0x00000000,0x00000000}},	//   _síon, वदन्, --, --, 
   {{0x3ce4319c,0xb5f8007b,0xb058023a,0x625801e7}},	//   nsov_, tháb, _itäv, _píon, 
   {{0xf2c51cc2,0x00000000,0x00000000,0x00000000}},	//   зсан, --, --, --, 
   {{0x3a240c6a,0x92953f48,0x1cb0031c,0x59e000dc}},	//   _kaop_, давц, _དངན_, नरपर, 
   {{0xd5c01d8a,0x3ce4892f,0x77480023,0xa778011a}},	//   _एलिज, ksov_, _ዝመሓደ, _לרופ, 
   {{0xb5f800d2,0xc0d4001f,0x625801e7,0x00000000}},	// [26b70] pháb, _ይቅር_, _tíon, --, 
   {{0x2fc40016,0x3a240066,0xb5f80332,0x00000000}},	//   ùng_, _laop_, bhác, --, 
   {{0x9f042bc6,0xb05801b8,0xb5f80308,0xf09c00a3}},	//   فولو, _otäv, chác, _spàs_, 
   {{0x2bcc145f,0x76640139,0x00000000,0x00000000}},	//   सुना, _çuyı, --, --, 
   {{0xf4283ae9,0xf1a8bc05,0x3ce400f3,0x625801e7}},	//   _སྣོད_, _داده_, gsov_, _míol, 
   {{0xe7c40154,0xc0d40023,0x8c880022,0x00000000}},	//   _শয্য, ርኹም_, цәба_, --, 
   {{0x22b800b0,0x6e6400a7,0x7e6c002d,0xfbdc0118}},	//   _kōka_, _етаж, únpú, _नजरम, 
   {{0x88c974e9,0x625801e7,0x4a740022,0x00000000}},	//   олив_, _níol, ьылт, --, 
   {{0xb5f800e4,0x00000000,0x00000000,0x00000000}},	//   viáp, --, --, --, 
   {{0x46e800f7,0xb0580108,0x06e8c867,0x13b40154}},	//   одон_, _etäv, омок_, জুয়, 
   {{0x2cbd74ea,0xcb54117d,0xb5f800c7,0x00000000}},	//   _huud_, _تناظ, tiáp, --, 
   {{0x2cbc007d,0xdb0802d2,0x00000000,0x00000000}},	//   _kuud_, _ílát, --, --, 
   {{0x62580597,0xb5f83a6c,0x00000000,0x00000000}},	//   _díol, riáp, --, --, 
   {{0x68f974eb,0x2a6c070d,0x2cbc007d,0x291d74ec}},	//   muud, _hmgb_, _muud_, mwua_, 
   {{0x2cbd74ed,0x68f8198f,0xd6a8036b,0x245401f4}},	//   _luud_, luud, تدیم_, _jämi_, 
   {{0x09b000bd,0xb6c80050,0x22b8007f,0x8214007b}},	//   _ট্যা, _باوے_, _sčks_, بورص, 
   {{0x660574ee,0x68f974ef,0xd1740032,0x25a001a9}},	// [26b80] _icik, nuud, ныфы, _uzil_, 
   {{0x3940049b,0xe730013f,0x2bcc08e6,0x3dc40210}},	//   äksi_, _eyεe_, सुमा, wcow_, 
   {{0x68f974f0,0x24540793,0xce345dcd,0x625800ae}},	//   huud, _nämi_, کونک, _híom, 
   {{0x68f974f1,0xa52c0003,0x3ce4a75a,0x44380af9}},	//   kuud, _སློག_, tsov_, _hnp_, 
   {{0x61e574f2,0x68f974f3,0x443806df,0x2cbc058a}},	//   mail, juud, _knp_, _cuud_, 
   {{0x61e574f4,0x68f83388,0x6bd00075,0x44380076}},	//   lail, duud, پتور, _jnp_, 
   {{0x60c574f5,0x3ce4047e,0x443974f6,0x6258007b}},	//   lqim, ssov_, _mnp_, _líom, 
   {{0x61e574f7,0x66040d81,0x68f974f8,0x442801e2}},	//   nail, _ncik, fuud, hdb_, 
   {{0x2bcc23c1,0x6720069c,0x2cbd74f9,0x68f974fa}},	//   _स्वा, _asnj, _guud_, guud, 
   {{0x660574fb,0x61e574fc,0x7e604d11,0x6258007b}},	//   _acik, hail, lhop, _síol, 
   {{0x61e574fd,0x7c3974fe,0x60c4044e,0x44280113}},	//   kail, _intr, hqim, ddb_, 
   {{0x4438282c,0x7c2974ff,0x61e57500,0x68f80a55}},	//   _anp_, ldfr, jail, buud, 
   {{0x68f801d9,0xb95404fb,0x44280334,0x7588248c}},	//   cuud, _تئات, fdb_, юсов_, 
   {{0x7c297501,0x66045617,0x60c40548,0x4438054e}},	//   ndfr, _ecik, dqim, _cnp_, 
   {{0x7e617502,0x625800ae,0xd75801c6,0x00000000}},	//   khop, _tíol, _хийц_, --, 
   {{0x61e57503,0x4438031c,0x442801ab,0x7e60007c}},	//   gail, _enp_, adb_, jhop, 
   {{0x7c3814dc,0x44380a85,0xa29402bf,0x60c4401f}},	// [26b90] _ontr, _fnp_, таті, gqim, 
   {{0x2cbd7504,0x443851d0,0x20c40036,0x44297505}},	//   _ruud_, _gnp_, _döi_, cdb_, 
   {{0x61e57506,0x03d40302,0x60c40140,0x2120011f}},	//   bail, _אותם_, aqim, awih_, 
   {{0x28dc0cb3,0x61e57507,0x4438009f,0x359402d3}},	//   पीडि, cail, _znp_, _መሕትት_, 
   {{0x7c380184,0xb058b1e1,0x21200548,0x646800c5}},	//   _bntr, _stäu, cwih_, _äriü, 
   {{0x7c38366e,0x68f802f6,0x3cf000e4,0x00000000}},	//   _cntr, vuud, áyva_, --, 
   {{0x2a6c070d,0x7e6072ab,0x68f97508,0x628000d7}},	//   _pmgb_, bhop, wuud, čmov, 
   {{0x68f97509,0xa2c000dc,0x7c28002d,0x2bcc1100}},	//   tuud, वदत्, adfr, _स्रा, 
   {{0x6e381c06,0x00000000,0x00000000,0x00000000}},	//   _inub, --, --, --, 
   {{0x62580491,0x61e40323,0x1cb80502,0x68f9750a}},	//   _ríom, zail, _قالب_, ruud, 
   {{0x68f961f6,0x61e40d04,0x2a6c022f,0xabb00124}},	//   suud, yail, _tmgb_, _ражә, 
   {{0x4439750b,0x473405f5,0x68f800af,0x00000000}},	//   _snp_, _үндс, puud, --, 
   {{0x44384ba8,0x61e5750c,0x7c380b21,0x68f81db9}},	//   _pnp_, vail, _yntr, quud, 
   {{0x61e4c6e8,0x7e61750d,0x00000000,0x00000000}},	//   wail, zhop, --, --, 
   {{0xb5f800c6,0x6720151c,0x6e389e69,0x2120011f}},	//   mhán, _usnj, _onub, wwih_, 
   {{0x66055730,0x61e5750e,0x3ebc0098,0x969400c7}},	//   _ucik, uail, _étti_, _ирыш, 
   {{0x61e5750f,0x7e6001e3,0x00000000,0x00000000}},	// [26ba0] rail, vhop, --, --, 
   {{0x6e397510,0x61e405f5,0x2bcc03f3,0x2a7c0218}},	//   _anub, sail, _स्ला, hnub_, 
   {{0x61e57511,0x69c804c4,0xfeb80228,0xdcb801e4}},	//   pail, _ofge, ساات_, _riĉ_, 
   {{0xfce495be,0x61e401ee,0xdcb801e4,0xb0580b70}},	//   еодо, qail, _siĉ_, _stät, 
   {{0x7e60049f,0xd4693bdb,0x6e380135,0xb5f800d2}},	//   rhop, _رحیم_, _dnub, khán, 
   {{0x69c8bbd7,0x3b48034b,0xad840137,0x320400e5}},	//   _afge, зяин_, رانۇ, őnyt_, 
   {{0x4f957512,0xcead7513,0x7c297514,0x68e8004e}},	//   _арту, _вә_, rdfr, _avgd, 
   {{0x5a34db74,0x7e6001e2,0x0dc8007b,0x6e3801bf}},	//   тнит, qhop, _يبقى_, _gnub, 
   {{0xb0580724,0xbc7400c6,0x7c3800d7,0x6cf4030d}},	//   _itär, _كهرب, _tntr, _петĕ, 
   {{0xe730013f,0xbc6827b4,0xb5f80118,0xf804010b}},	//   _brε_, _عمان_, ghán, хчин, 
   {{0x38a008a5,0x00000000,0x00000000,0x00000000}},	//   gðra_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb5f97515,0x00000000,0x00000000,0x00000000}},	//   bhán, --, --, --, 
   {{0xb5f97516,0xe730013f,0x7bc807c5,0xa424cff4}},	//   chán, _frε_, ncfu, льсл, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa2941cb8,0xa798011a,0x00000000,0x00000000}},	//   гасі, _משוח, --, --, 
   {{0x1ccc1b4b,0x7ae8074d,0x2cfc1ab2,0x00000000}},	// [26bb0] ྱམས_, hsft, _ईमेल_, --, 
   {{0x6e397517,0xd2500014,0xd0101291,0x00000000}},	//   _snub, اچھ_, ؤلا_, --, 
   {{0xb8e0038f,0xbd941870,0x00000000,0x00000000}},	//   _ཏང_, _ﭘﺮﻭﮔ, --, --, 
   {{0xce340244,0x7c2c02d2,0x00000000,0x00000000}},	//   کوچک, _óbrj, --, --, 
   {{0x53a00075,0x62800010,0x9db8013d,0x00000000}},	//   _ﺋﯜﭼﯜ, čmot, нышу_, --, 
   {{0xb058008e,0x00000000,0x00000000,0x00000000}},	//   _etär, --, --, --, 
   {{0x7ae8074d,0x626c75c0,0x00000000,0x00000000}},	//   gsft, rşov, --, --, 
   {{0xc8c80133,0x00000000,0x00000000,0x00000000}},	//   ووبن_, --, --, --, 
   {{0x2a7cfa88,0x87f80024,0xb5f801e7,0x00000000}},	//   rnub_, мэнт_, thán, --, 
   {{0x55c4774d,0x24540267,0x00000000,0x00000000}},	//   ғарғ, _jämt_, --, --, 
   {{0x0a15017f,0x48c001e0,0x46a40395,0x00000000}},	//   _لواح, ыҙҙа, каов, --, 
   {{0xb5f92315,0xf1bc00ae,0x4974030d,0x00000000}},	//   shán, _ngá_, _илес, --, 
   {{0xb5f808de,0xa3b41a55,0x00000000,0x00000000}},	//   mhál, जेन_, --, --, 
   {{0xf1bc208e,0x2454007c,0x00000000,0x00000000}},	//   _ináy_, _nämt_, --, --, 
   {{0x1ccc0489,0x6f0004cc,0x6b60002e,0xca800092}},	//   ྱམོ_, àncl, _yёga, _ይህንም_, 
   {{0xd29801ec,0xd90c1e4b,0x2790014b,0x00000000}},	//   етуі_, _بیی_, _ишқр, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [26bc0] --, --, --, --, 
   {{0xb21807ad,0xb0595caa,0xc3180154,0x7ed400d4}},	//   _hjæl, _stär, ডিবি_, відч, 
   {{0x645d7518,0xe810810c,0xb2182c95,0x9f5c05d5}},	//   mkri, त्या_, _kjæl, üvà_, 
   {{0x645d7519,0x4f944ecc,0x3cf000e4,0x00000000}},	//   lkri, уруу, áyvo_, --, 
   {{0xf4842b09,0xb5f808de,0x645c01f5,0xadf001ec}},	//   _سایی, dhál, okri, рпіш, 
   {{0xe8105843,0xd1380092,0x00000000,0x00000000}},	//   त्मा_, _አሉባል, --, --, 
   {{0xfcf40020,0x6cb00228,0x2b745598,0xb5f80332}},	//   ለወጡ_, рөтт, پینگ_, fhál, 
   {{0x645c02d3,0xb5f8655d,0xf1bc01ef,0x00000000}},	//   hkri, ghál, _snáz_, --, 
   {{0x645d751a,0xb058013d,0xe7f00456,0x00000000}},	//   kkri, _muän, _आयशा_, --, 
   {{0x645d751b,0xeb300075,0x00000000,0x00000000}},	//   jkri, _ھىند, --, --, 
   {{0x645cfe4f,0xadc001e1,0xb5f80597,0xb21800b5}},	//   dkri, _abẹn, bhál, _bjæl, 
   {{0x645c0af9,0xb5f9751c,0x3ebc02d2,0x675400e5}},	//   ekri, chál, _éttu_, ئیٹس_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa74c0882,0xe9a04109,0x00000000,0x00000000}},	//   ṣeṇa_, _тачп, --, --, 
   {{0xc1a401ec,0xae105b29,0x00000000,0x00000000}},	//   ғытқ, ण्डन_, --, --, 
   {{0x645cd6a8,0xbd9c0092,0x00000000,0x00000000}},	//   akri, ግስትም_, --, --, 
   {{0xadc00241,0x53a402dd,0xa3b40c70,0x985c00de}},	// [26bd0] _gbẹn, таңб, जेब_, _lāču_, 
   {{0xe1140eac,0x645d751d,0x25a40790,0x1fd8007b}},	//   সিংহ_, ckri, ümle_, نظمة_, 
   {{0xfcf4001f,0x00000000,0x00000000,0x00000000}},	//   ለወጥ_, --, --, --, 
   {{0xa2c0085c,0xaca401d3,0xb05801f4,0x0b4401a9}},	//   वदर्, چھئے_, _etäp, ғнин, 
   {{0xe7f00073,0x00000000,0x00000000,0x00000000}},	//   _आयला_, --, --, --, 
   {{0xdfd400c0,0x00000000,0x00000000,0x00000000}},	//   _воры, --, --, --, 
   {{0xb5f80efe,0x5c04023a,0x6cc001e0,0x00000000}},	//   thál, ряча, ыйҙа, --, 
   {{0x645d751e,0xfb1400c6,0x0928023a,0xee840006}},	//   zkri, اقيع_, ежий_, _рыго, 
   {{0xb5f895f4,0xdea40244,0x4878011c,0x00000000}},	//   rhál, _ئینی, есня_, --, 
   {{0xb218019b,0xa3b401ad,0xee980150,0x00000000}},	//   _sjæl, जेड_, _ﺘﻌﻠﻥ_, --, 
   {{0x645c4cab,0xcb0801c8,0x00000000,0x00000000}},	//   vkri, _سيشن_, --, --, 
   {{0x893453f3,0x09340b24,0x2bcc01bc,0x798c0036}},	//   _معتا, _مرتج, सुरा, éiwé, 
   {{0xb5f9751f,0x09b000bd,0x69d80588,0xf7880790}},	//   chám, _ট্রা, mbue, _alçı_, 
   {{0x69d97520,0x68f80ccb,0x07a400ee,0xc7640220}},	//   lbue, mrud, _йалн, _ماعى, 
   {{0x645d7521,0xb0580254,0x68f801bf,0x28dc012d}},	//   rkri, _puän, lrud, पीरि, 
   {{0xb05801b8,0x68f97522,0x057402e9,0x69d92aa7}},	//   _stäp, orud, _ماخد, nbue, 
   {{0x68f87cea,0x645c02d5,0x15280220,0x80a817a0}},	// [26be0] nrud, pkri, _анық_, евав_, 
   {{0x68f805b1,0x69d801c7,0xe5a4267c,0x88c400cc}},	//   irud, hbue, _йиқи, _এবাক, 
   {{0x68f97523,0x23a8012c,0x50b4ada8,0xb5f97524}},	//   hrud, _गरिद, рсту, dháj, 
   {{0xe810202e,0xbd880a52,0x6e4001e0,0xb5f800e4}},	//   त्ता_, ىنان_, йехз, yhám, 
   {{0x68f97525,0xb21802d2,0xc15401af,0x6fe000fe}},	//   jrud, _ojæj, _сњнњ, _পাৰে, 
   {{0x27300cad,0xdb540724,0x626c054e,0x69d80381}},	//   _ẹni_, ивлы, cşor, ebue, 
   {{0x68f97526,0x62840254,0xb5f80518,0xf0600815}},	//   erud, onio, riáz, _укрп, 
   {{0x62857527,0x68f80368,0x69d801bf,0xd9100d73}},	//   nnio, frud, gbue, قیص_, 
   {{0x6da17528,0x8e7569ee,0x68f97529,0x201825a9}},	//   _гита, _турч, grud, _kbri_, 
   {{0x7d00c406,0xad1806a9,0x80a80c5a,0xdb500133}},	//   muos, _אומר, _जीमे, _وێش_, 
   {{0xdb25752a,0x7d006b01,0x68f8208d,0xfaf83321}},	//   _خوای, luos, arud, _سراغ_, 
   {{0x68f9752b,0x4a7005d9,0x569401c0,0x67d000d1}},	//   brud, _وڏير, рамт, _һошу, 
   {{0x68f8067c,0x6284068f,0x7d000006,0x201800cf}},	//   crud, dnio, nuos, _obri_, 
   {{0x6285752c,0x7d00000d,0x00000000,0x00000000}},	//   enio, iuos, --, --, 
   {{0x62840042,0x81cc03d4,0xa3440139,0xa734007b}},	//   fnio, _ৰাজ_, бэтл, _مثير_, 
   {{0x20185fbc,0x6285752d,0x7d00652e,0x9538014b}},	//   _abri_, gnio, kuos, _азит_, 
   {{0x20180083,0x7d000006,0x9098039b,0x9f580332}},	// [26bf0] _bbri_, juos, вват_, _gcrú_, 
   {{0x09d019e5,0xc0cc0020,0xb5f81705,0x7d00897c}},	//   _सभ्य, _እኔም_, skád, duos, 
   {{0x62840210,0x00000000,0x00000000,0x00000000}},	//   bnio, --, --, --, 
   {{0x2019752e,0x69d80399,0xc0d40023,0x6284012d}},	//   _ebri_, xbue, _ይህሉ_, cnio, 
   {{0x7d01752f,0xa15801ec,0x00000000,0x00000000}},	//   guos, _баяу_, --, --, 
   {{0xb5f801ed,0xb05800e4,0x2bc80107,0x68f80156}},	//   nkáb, _kuäm, худо_, vrud, 
   {{0x1a684bf3,0x9db81e4a,0xfd640241,0x69d80036}},	//   گینی_, ندۇز_, _kupọ, tbue, 
   {{0xfe740107,0x7d000153,0x00000000,0x00000000}},	//   _кӯч_, buos, --, --, 
   {{0x69d80a40,0x1a697530,0x68f80810,0x7d00003a}},	//   rbue, دینی_, urud, cuos, 
   {{0x69d80221,0x2d9c0098,0x68f97531,0x5d557532}},	//   sbue, _iyue_, rrud, _укут, 
   {{0x62857533,0xc7a57534,0x6a1458c5,0xf3f80154}},	//   ynio, ринк, _مبشر, ইভার_, 
   {{0x68f97535,0x7ea800c7,0x99d400c0,0x00000000}},	//   prud, pýpe, _люшч, --, 
   {{0x68f8025c,0x00000000,0x00000000,0x00000000}},	//   qrud, --, --, --, 
   {{0xb0580e78,0x6284033f,0x00000000,0x00000000}},	//   _quäl, wnio, --, --, 
   {{0x46a4418d,0x22b800b0,0x27e40165,0x62840210}},	//   _какв, _hōki_, _ienn_, tnio, 
   {{0x27e57536,0x62857537,0xb3440120,0x26c416b8}},	//   _henn_, unio, _seçõ, _iuno_, 
  
   {{0x27e43d27,0x62857538,0x26c406d6,0x7d017539}},	// [26c00] _kenn_, rnio, _huno_, xuos, 
   {{0x26c5753a,0x27e5753b,0x7d00822d,0x6285753c}},	//   _kuno_, _jenn_, vuos, snio, 
   {{0x27e40aab,0x6284fea4,0x7f8400d1,0xb03000d1}},	//   _menn_, pnio, جلان, تىلغ, 
   {{0x27e5753d,0x26c5753e,0x7d01753f,0x2498f0bc}},	//   _lenn_, _muno_, tuos, lorm_, 
   {{0xb6d00014,0x26c57540,0x1bd40801,0x22b802b5}},	//   _कश्à_, _luno_, боля, _nōki_, 
   {{0x2d54bd12,0x7d017541,0x27e57542,0x26c00069}},	//   ришь_, ruos, _nenn_, _liio_, 
   {{0xb5f80e96,0x7d0031af,0xeb440395,0x00000000}},	//   nkác, suos, ичък_, --, 
   {{0xe81028d4,0xeb940640,0x7d00897c,0x80a82cf5}},	//   त्सा_, јић_, puos, _जीते, 
   {{0x27e57543,0x7d0033e7,0x6258007b,0x00000000}},	//   _benn_, quos, _híos, --, 
   {{0x27e57544,0xb5f80597,0x26c57545,0xb21801bf}},	//   _cenn_, mhái, _buno_, _pjæk, 
   {{0x27e57546,0x26c40014,0x41c40b6d,0xaee00055}},	//   _denn_, _cuno_, वशास, _ikṣa, 
   {{0x6f011c3e,0x26c4e7f6,0x625800c6,0xb5f8022a}},	//   ànci, _duno_, _míos, dkác, 
   {{0x27e57547,0xb0580793,0x24997548,0x58d400c0}},	//   _fenn_, _suäm, form_, _уолт, 
   {{0x27e41574,0x62880129,0xb5f80022,0x00000000}},	//   _genn_, édon, ihái, --, 
   {{0x26c42252,0x625800ae,0xfd640248,0xf6500107}},	//   _guno_, _níos, _pupọ, _мекӯ, 
   {{0x27e464d3,0x00000000,0x00000000,0x00000000}},	//   _zenn_, --, --, --, 
   {{0xe8101161,0x27e57549,0x26c40306,0xe135754a}},	// [26c10] त्वा_, _yenn_, _zuno_, онты, 
   {{0x6ec806ab,0xb5f9754b,0x273001e1,0x26c400d8}},	//   _तंदु, dhái, _ẹnu_, _yuno_, 
   {{0x929405f5,0x26c4f3ff,0x625801e7,0x9f051e4f}},	//   _ганц, _xuno_, _cíos, قولو, 
   {{0x625800c6,0xaee00882,0x6e0000d1,0xd25000ec}},	//   _díos, _akṣa, تېرن, _ڀنگ_, 
   {{0xa1943334,0xa18400c7,0xb5f800ae,0xbe100137}},	//   _маюч, _дырл, ghái, سووع, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x27e403d4,0xb5f80124,0x625800ae,0xd3e00139}},	//   _renn_, ahái, _tíot, _üsеş, 
   {{0xb5f806d5,0x27e5754c,0x26c5754d,0x22b806c8}},	//   bhái, _senn_, _runo_, _pōki_, 
   {{0x27e403bd,0xb5f9754e,0x26c5754f,0x24980790}},	//   _penn_, chái, _suno_, yorm_, 
   {{0xc7a400db,0x00000000,0x00000000,0x00000000}},	//   йипк, --, --, --, 
   {{0x27e57550,0x24997551,0x1a6804d3,0x5c840014}},	//   _venn_, vorm_, دیۆی_, _ظلمٕ, 
   {{0x27e491e1,0x24988628,0x07a48abb,0xb5f80122}},	//   _wenn_, worm_, _қайн, vkác, 
   {{0x26c404ba,0x27e57552,0x26c00254,0x00000000}},	//   _wuno_, _tenn_, _viio_, --, 
   {{0xb5f80122,0xddc001e4,0x6258007b,0x00000000}},	//   tkác, _nomŝ, _níor, --, 
   {{0x65c40046,0xd87401d9,0x93597553,0xc354001f}},	//   _мұна, _بانب, арту_, _ያዘጋጀ, 
   {{0xe8101d8a,0x2c697554,0xb5f97555,0x0608009b}},	//   त्रा_, _hødd_, rkác, _сник_, 
   {{0x41a97556,0xb5f802fb,0x2c680fac,0x00000000}},	// [26c20] уван_, skác, _kødd_, --, 
   {{0x6258007b,0xf53405d0,0xb5f80306,0x00000000}},	//   _píos, _פריז_, pkác, --, 
   {{0xa3b4000b,0x625800ae,0xc2c4484d,0x7dc412fd}},	//   जेश_, _díor, _ديجي, مقان, 
   {{0xb5f800c6,0x6258007b,0x37dc00cc,0x00000000}},	//   thái, _víos, _মাছৰ, --, 
   {{0x13bc0729,0x625800c6,0x5108010a,0xa3b400bc}},	//   _অভয়, _fíor, _вĕчĕ, जेर_, 
   {{0xa3d80316,0x2c680158,0x625801e7,0x92e800f2}},	//   ाडि_, _nødd_, _tíos, _حریق_, 
   {{0xafe0b5f5,0x3f680e58,0x6d4c0129,0x290800a3}},	//   _хосл, _сиво_, _àcan, àcan_, 
   {{0xb5f97557,0x8e7405f5,0xbba00020,0xbe157558}},	//   phái, _дууч, _ምንጭጌ_, _دورع, 
   {{0xa3d80027,0x7e60005f,0xe9cc16ac,0xd95400f2}},	//   ाडा_, mkop, رغي_, زندخ, 
   {{0x7e617559,0x99840618,0xb5f801e7,0xaee00055}},	//   lkop, lemū_, nháv, _ukṣa, 
   {{0x2c6833b8,0xb098011a,0xf8ac0014,0x8b640244}},	//   _dødd_, רייר, ٘کژ_, _وامم, 
   {{0x7e601958,0xb5f800d2,0x1dbc06b1,0x00000000}},	//   nkop, hháv, _ऋणात, --, 
   {{0x2c680183,0x7e600ea0,0x24980092,0x00000000}},	//   _fødd_, ikop, _መፅሄት_, --, 
   {{0x22b804fe,0xa3d400d1,0x7e61653c,0x3da800fe}},	//   _mōku_, зорч, hkop, _ওলাল, 
   {{0x0b78069c,0xa3d81533,0xfa24025c,0xa8780375}},	//   _ክንደይ_, ाड़_, _རྒོན_, _תאור, 
   {{0xc0d40201,0xf7701973,0x7e6001a4,0xb05800b0}},	//   _ይህም_, _واں_, jkop, _tuäk, 
   {{0x7e600ae3,0x90543849,0x22b80374,0x625801e7}},	// [26c30] dkop, овац, _nōku_, _píor, 
   {{0x7e61755a,0xb5f800d2,0x387c03d1,0x91d82a27}},	//   ekop, tháw, nitr_, _फ्रै, 
   {{0xeff40201,0x2c680ac8,0x38a008a5,0x00000000}},	//   _ዋናው_, _jøde_, gðri_, --, 
   {{0x7e61755b,0x2c6804ce,0x387c0170,0x00000000}},	//   gkop, _møde_, hitr_, --, 
   {{0xb5f800d2,0x625800c6,0x387c05da,0xb21801bf}},	//   bháv, _tíor, kitr_, _bjæv, 
   {{0x6ab007f8,0xb5f845be,0x7e6000b0,0x6b5c01e1}},	//   ुद्र, cháv, akop, _nàgú, 
   {{0x387c06d9,0xfcb00030,0x2c6806ea,0xb21800b5}},	//   ditr_, úšať_, _rødd_, _djæv, 
   {{0x4ab82401,0xdb140432,0x49c80108,0x00000000}},	//   шуля_, _çaýh, шлин_, --, 
   {{0x387c03d1,0x88c800f0,0x5d5401ee,0x00000000}},	//   fitr_, јлов_, _ектт, --, 
   {{0x2c68037e,0xb21805ac,0x5d540276,0xd83802bd}},	//   _bøde_, _gjæv, _экут, blčm_, 
   {{0xddc003ee,0x00000000,0x00000000,0x00000000}},	//   _komş, --, --, --, 
   {{0x2c68708a,0x91d81d15,0xdb58004e,0x00000000}},	//   _døde_, _फ्लै, _уюу_, --, 
   {{0xb05800b0,0x6288cb71,0xba9400ec,0x31e40154}},	//   _tuäh, édom, _بالڪ, _ফাংশ, 
   {{0x2c6828b3,0x7e6012fe,0x00000000,0x00000000}},	//   _føde_, zkop, --, --, 
   {{0xa3b4006d,0xe7201b4b,0x4255755c,0xb9f0010c}},	//   जें_, _འགྲན_, отат, _ነት_, 
   {{0xb5f8fb52,0x00000000,0x00000000,0x00000000}},	//   lkán, --, --, --, 
   {{0x7e608a8a,0x52746c68,0x00000000,0x00000000}},	// [26c40] vkop, чуру, --, --, 
   {{0xc4845322,0xa4940344,0xb5f9755d,0x00000000}},	//   _флок, _ریزت, nkán, --, 
   {{0xb5f80306,0x10d40150,0x00000000,0x00000000}},	//   rháv, _ﺘﻨﺜﻨ, --, --, 
   {{0xfbe4009e,0xddc164ba,0x6e902c39,0x00000000}},	//   _নাইত, _comş, وللا, --, 
   {{0x7e61755e,0xff0803f4,0xbc4815ed,0x1bd42f34}},	//   rkop, রবেশ_, ичке_, поля, 
   {{0xbfa801d9,0xb5f843e9,0xb538010f,0xbc1800d4}},	//   _نازٕ_, lhát, יגנש, ріді_, 
   {{0x387c0170,0xfa24025c,0x7e61755f,0x22b802b5}},	//   vitr_, _རྒུན_, pkop, _wōku_, 
   {{0x8eb01b92,0x22b80325,0x2c68fb11,0xaab031ed}},	//   _كەلت, _tōku_, _røde_, وصيت, 
   {{0x2c6804ce,0x387c05da,0x00000000,0x00000000}},	//   _søde_, titr_, --, --, 
   {{0x7c657560,0x3ea57561,0xd83809a8,0xb21800b5}},	//   _بارل, llot_, koče_, _ujæv, 
   {{0xd838151c,0x82481772,0x387c0170,0xd6d42f6a}},	//   joče_, _ነገስታ, ritr_, яжны, 
   {{0x3ea4008b,0x387c05da,0x3944004e,0x00000000}},	//   nlot_, sitr_, _мнег, --, 
   {{0x7d017562,0x387c05da,0x6a8001b9,0xb5f80332}},	//   nros, pitr_, _ўлча, dhát, 
   {{0x49b00184,0x7d000d19,0x68400276,0x3ea40036}},	//   _яҙыу, iros, _онча, hlot_, 
   {{0xd8380fb7,0x17040156,0xe2f80220,0x3ea4a1ee}},	//   goče_, _མའིམ_, жесі_, klot_, 
   {{0x47883334,0x320c01d3,0x00000000,0x00000000}},	//   _усім_, ügy_, --, --, 
   {{0x3ea57563,0x7d00a39f,0xe0d13bab,0x00000000}},	// [26c50] dlot_, jros, نزل_, --, 
   {{0xd83809a8,0x30a40006,0x2fc401bf,0x00000000}},	//   ločb_, ірав, øng_, --, 
   {{0x3ea57564,0x7d0000c7,0x00000000,0x00000000}},	//   flot_, eros, --, --, 
   {{0xb5f97565,0x00000000,0x00000000,0x00000000}},	//   chát, --, --, --, 
   {{0x8c457566,0xad256792,0x00000000,0x00000000}},	//   зеле, تراو, --, --, 
   {{0x6d4c00d8,0x00000000,0x00000000,0x00000000}},	//   _àcam, --, --, --, 
   {{0x3ea57567,0x00000000,0x00000000,0x00000000}},	//   blot_, --, --, --, 
   {{0xb2180158,0x3ea40429,0x7afc0005,0x5f841d00}},	//   _gjæt, clot_, ápta, _تۇمە, 
   {{0x7d0033a4,0x9f58007f,0xb5f97568,0x0d2000cf}},	//   cros, _adrè_, tkán, _чүлү, 
   {{0x9f580332,0x13c400fe,0x00000000,0x00000000}},	//   _gcró_, ্ৰয়, --, --, 
   {{0xdb4c168d,0xb5f801ed,0x3a840050,0xb8d0466d}},	//   _نێو_, rkán, _کُنہ, _झी_, 
   {{0xb5f800bc,0xd83800d7,0x00000000,0x00000000}},	//   skán, voče_, --, --, 
   {{0xb5f803b2,0x00000000,0x00000000,0x00000000}},	//   vhát, --, --, --, 
   {{0xd8380ebd,0x00000000,0x00000000,0x00000000}},	//   toče_, --, --, --, 
   {{0xb5f8007b,0x29080030,0x3ea4011f,0x7d0004af}},	//   thát, žiaľ_, ylot_, zros, 
   {{0x7d00780b,0xb5f801ed,0x2c1800dc,0xc61800eb}},	//   yros, nkál, प्तं_, _তোরা_, 
   {{0xb5f90b0a,0xd8380219,0xc4840440,0x7d000ba7}},	// [26c60] rhát, soče_, _нлик, xros, 
   {{0x7d017569,0xb5f9756a,0xb5380375,0x00000000}},	//   vros, shát, _פגיש, --, 
   {{0x3ea5756b,0x44280ea0,0xb5f8673f,0x00000000}},	//   tlot_, meb_, phát, --, 
   {{0x442810fa,0x932416f5,0xb5f800e5,0xf2d000df}},	//   leb_, _کرین, lhár, _רער_, 
   {{0x61e5756c,0x6a6405c7,0x4428020c,0xb2b8011a}},	//   mbil, _añfo, oeb_, _למטר, 
   {{0x3ea5756d,0x4429756e,0xb5f800e5,0x00000000}},	//   slot_, neb_, nhár, --, 
   {{0x3ea5756f,0xb21805ac,0xb5f80022,0x00000000}},	//   plot_, _gjæs, ihár, --, 
   {{0x44297570,0xeb940063,0x58d96eec,0x6f017571}},	//   heb_, џић_, одия_, ánce, 
   {{0x61e57572,0xb2181a82,0x44297573,0x4f400020}},	//   ibil, _kjær, keb_, _የሚደር, 
   {{0x61e4036b,0x44297574,0xac800153,0x00000000}},	//   hbil, jeb_, _згул, --, 
   {{0x4ce002a6,0x442800a9,0x58840588,0x00000000}},	//   _নিযু, deb_, зыҟа, --, 
   {{0x7c2812ed,0x44280204,0xc9840451,0x61e4025c}},	//   lefr, eeb_, _ڪشمي, jbil, 
   {{0x44296dc7,0xb058008e,0x195801af,0x00000000}},	//   feb_, _kuät, _фалы_, --, 
   {{0x44297575,0xb2180158,0x61e4bd3b,0xb5f80332}},	//   geb_, _njær, ebil, thás, 
   {{0x2c6803b2,0x61e401bf,0x18b4008e,0xd5740092}},	//   _jøda_, fbil, _нәүр, _አዕምሮ_, 
   {{0x61e57576,0xba04044e,0x7c2805d5,0xb5f80124}},	//   gbil, _ዉን_, hefr, ahár, 
   {{0x7c2846a0,0x44297577,0xdef402d3,0xb5f90ca1}},	// [26c70] kefr, beb_, _ልብኻ_, shás, 
   {{0xb5f97578,0x08180156,0x44297579,0xb2180162}},	//   chár, ྱུརཝ_, ceb_, _smæd, 
   {{0x61e41f21,0x6ec457d4,0x7d0401e3,0xa184013d}},	//   bbil, ستاق, _åksj, _җыял, 
   {{0x998401ef,0x00000000,0x00000000,0x00000000}},	//   jemů_, --, --, --, 
   {{0xb218168c,0x7c28005c,0x998401ef,0x00000000}},	//   _fjær, fefr, demů_, --, 
   {{0x7c29757a,0xb218168c,0xdb2002fb,0x251c08a8}},	//   gefr, _gjær, _štáb, צווא, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xac740502,0x4428068f,0x9e34005b,0x00000000}},	//   _کارش, zeb_, _песч, --, 
   {{0x4429757b,0xb5f88310,0x628839b2,0x7c29757c}},	//   yeb_, yhár, édoi, befr, 
   {{0xb5f8c4cd,0x7c280857,0x2c6805ac,0x752c033f}},	//   skál, cefr, _føda_, dwcz, 
   {{0x4429757d,0x61e458b1,0x752c068f,0xb5f801d3}},	//   veb_, ybil, ewcz, pkál, 
   {{0x61e43bdc,0x6e284e18,0x00000000,0x00000000}},	//   xbil, negb, --, --, 
   {{0x4429757e,0x69c8127b,0xe9a80137,0x6ab8016b}},	//   teb_, _igge, _ادان_, mmuf, 
   {{0x61e403a2,0xb5f801ed,0x6e28063f,0xf1bc00ae}},	//   wbil, nkáj, hegb, _mbád_, 
   {{0x4429757f,0x61e57580,0x61380af2,0x4e0c00bc}},	//   reb_, tbil, kúlá, हलाई_, 
   {{0x44297581,0x61e57582,0x6ab801bf,0x7c297583}},	//   seb_, ubil, nmuf, zefr, 
   {{0x6e282655,0xd8388356,0x44297584,0x6ab80810}},	// [26c80] degb, loča_, peb_, imuf, 
   {{0x61e43468,0x30240588,0x603c007f,0x00000000}},	//   sbil, моуп_, fٍma, --, 
   {{0x69c97585,0x68e80399,0x61e47338,0xccf800cd}},	//   _ogge, _lwgd, pbil, _avś_, 
   {{0x69c8034c,0xdcb01a59,0x7c2800a9,0x63e401ec}},	//   _ngge, گىت_, wefr, _تيگە, 
   {{0x7c289cfd,0x358c02d3,0x6284009f,0xb21812ed}},	//   tefr, _ዓድታት_, miio, _tjær, 
   {{0x69c97586,0x62845320,0xd8381fe6,0xb058013d}},	//   _agge, liio, koča_, _quät, 
   {{0xd83809a8,0x68e802d0,0xbf14030c,0xbe6801c0}},	//   joča_, _awgd, _توزب, _давж_, 
   {{0x7c297587,0xefb00cb8,0x6284022f,0xd8380427}},	//   sefr, _شینگ, niio, doča_, 
   {{0x6da04640,0x644000e2,0xb5f800e4,0x00000000}},	//   _аита, ēmij, ukám, --, 
   {{0x2bc40cb4,0x6284037e,0xb5f800e4,0x6ab97088}},	//   _ललचा, hiio, eháp, amuf, 
   {{0xd8380fb7,0x78b81512,0x6284009f,0xb5f82fda}},	//   goča_, rmtv, kiio, skám, 
   {{0x4ce004c5,0x6a803edd,0xb5f80419,0x00000000}},	//   _নিতু, _илха, pkám, --, 
   {{0xaa5400f2,0x00000000,0x00000000,0x00000000}},	//   _تلنا_, --, --, --, 
   {{0xb5f800c7,0x6e2909da,0x3d04012d,0x00000000}},	//   aháp, zegb, _हटने_, --, 
   {{0xf2c401c0,0xe72c007b,0xb5f801d3,0x00000000}},	//   дсан, _نصي_, nkák, --, 
   {{0xb5f845be,0xe8f400b1,0x00000000,0x00000000}},	//   cháp, _элә_, --, --, 
   {{0x7bd8208d,0x3ebc003e,0xbae00150,0x00000000}},	// [26c90] _oftu, _étty_, _ﺍﻨﺴﺎ, --, 
   {{0x6d4c01c3,0x32c4015d,0x6e282963,0x25740241}},	//   _àcai, _gŵyn_, wegb, _wúlé_, 
   {{0x6e28398f,0x00000000,0x00000000,0x00000000}},	//   tegb, --, --, --, 
   {{0x7bd90412,0x8d942002,0x6284002d,0x00000000}},	//   _aftu, ىلاش, ciio, --, 
   {{0x6e2822ec,0x8228025c,0x6fd407f7,0xa15802dd}},	//   regb, _སྒྲི_, _बलपू, _жаяу_, 
   {{0xdea407d6,0x81d40154,0xb5f80022,0x00000000}},	//   _ییلی, হরণ_, ukáj, --, 
   {{0xfee801b9,0xb5f82def,0x00000000,0x00000000}},	//   _нутқ_, rkáj, --, --, 
   {{0xa3b410dc,0x7bd806ea,0xd83800d0,0x92c00183}},	//   जेट_, _eftu, voča_, ঁৱৰ_, 
   {{0x08c40107,0x202402d2,0x00000000,0x00000000}},	//   нбин, _þrið_, --, --, 
   {{0x691007f5,0xd8385a54,0xdd9401af,0x00000000}},	//   jžeš, toča_, _рауы, --, 
   {{0x442401e4,0x69cc01e4,0x9c64009f,0xb5f800e5}},	//   _ĝo_, ɾcen, _جهلو, ckák, 
   {{0xd838151c,0x69c8127b,0x442401e4,0x2c1800cd}},	//   roča_, _ugge, _ŝo_, प्रं_, 
   {{0xbb240092,0x00000000,0x00000000,0x00000000}},	//   _ሰርተዋ, --, --, --, 
   {{0xe5e400d1,0x03a400c7,0x97c4029e,0x00000000}},	//   _ﺋﯩﻨﻜ, еиго, عتیم, --, 
   {{0xc7680323,0x48f83507,0x66f0000d,0x00000000}},	//   _хийж_, ोंको_, _आबिक_, --, 
   {{0xcfb40154,0x59800092,0x00000000,0x00000000}},	//   ঝখান, ርጋችሁ_, --, --, 
   {{0xa3b407f7,0xdb081155,0x62840254,0x7ea800d7}},	// [26ca0] जेज_, _mzdá, riio, sýpk, 
   {{0xf0a40276,0x00000000,0x00000000,0x00000000}},	//   екул_, --, --, --, 
   {{0x44380652,0x00000000,0x00000000,0x00000000}},	//   _iap_, --, --, --, 
   {{0x44397588,0xa0d80131,0x42540108,0x00000000}},	//   _hap_, _يېزا_, _чтот, --, 
   {{0x44397589,0x00000000,0x00000000,0x00000000}},	//   _kap_, --, --, --, 
   {{0x4439758a,0x00000000,0x00000000,0x00000000}},	//   _jap_, --, --, --, 
   {{0x44380302,0x7ac4b6d1,0xa3b40490,0x00000000}},	//   _map_, нсие, जेच_, --, 
   {{0x4439758b,0x9fe800cc,0x00000000,0x00000000}},	//   _lap_, _পায়গ, --, --, 
   {{0x999800bc,0xd838007f,0x2bc405a2,0x00000000}},	//   ěrů_, klčt_, мләп_, --, 
   {{0x4439758c,0xb178010f,0xacf8011a,0x00000000}},	//   _nap_, פטיר, _מהמכ, --, 
   {{0x7c380649,0x25ac0213,0xb7d80014,0x32440023}},	//   _iatr, ədli_, _ہوشا_, _መጻእኩ, 
   {{0x7c38325f,0x4439758d,0x5f0809bb,0x498800ec}},	//   _hatr, _aap_, _हिन्_, _ڪئمپ_, 
   {{0x7c39758e,0x4439758f,0xf1bc01e7,0xb5f801d3}},	//   _katr, _bap_, _mbác_, nkái, 
   {{0x44397590,0x7c397591,0xe87c0023,0x00000000}},	//   _cap_, _jatr, _ትፈልጡ_, --, 
   {{0x44397592,0x7c381e3d,0x56940022,0x00000000}},	//   _dap_, _matr, _иакт, --, 
   {{0x32c40368,0x228400f7,0xb3d000d1,0x225801ee}},	//   _gŵyl_, гууг, _әйнә, нисы_, 
   {{0x44397593,0x7c3805da,0xd838007f,0xfd4c0248}},	// [26cb0] _fap_, _oatr, blčt_, _tunṣ, 
   {{0x7c397594,0xe1346215,0x4439647d,0x6a840241}},	//   _natr, ынуы, _gap_, _kèfè, 
   {{0x28980677,0x00000000,0x00000000,0x00000000}},	//   לימא, --, --, --, 
   {{0x44397595,0xd8380427,0x7c397596,0xb5f800e4}},	//   _zap_, kočo_, _aatr, ukáh, 
   {{0x44388d5e,0xd83809a8,0x74b40034,0xc1f40375}},	//   _yap_, jočo_, ोगपृ, _במרץ_, 
   {{0x7c397597,0x4438a8cf,0xaca0063f,0xd8380427}},	//   _catr, _xap_, kwụb, dočo_, 
   {{0x7c397598,0x9f240131,0xfcc17599,0x00000000}},	//   _datr, _مۈلۈ, рәтм, --, 
   {{0x7c39759a,0x00000000,0x00000000,0x00000000}},	//   _eatr, --, --, --, 
   {{0x7c39759b,0xdb0802fd,0xed581e2f,0x391012ea}},	//   _fatr, _vzdá, _عشرت_, لويز, 
   {{0x290054ff,0x7c3825a9,0x78845725,0x1cb0031c}},	//   čja_, _gatr, _révè, _ནེར_, 
   {{0x6e39759c,0x4439759d,0x7884004a,0x32c40142}},	//   _kaub, _rap_, _sévè, _pŵyl_, 
   {{0xf770ad68,0x6e3801c4,0x443853ea,0x00000000}},	//   شاپ_, _jaub, _sap_, --, 
   {{0x44380d29,0x6e388de8,0x7c39759e,0xba143cc6}},	//   _pap_, _maub, _yatr, _شيوا_, 
   {{0x07a40124,0x7c38004e,0x4438016d,0xe7340022}},	//   _иалн, _xatr, _qap_, _зҵо_, 
   {{0x03a45aa6,0x6a64030a,0x1cb0025c,0x68f86a39}},	//   тиво, _añfi, _ནེལ_, lsud, 
   {{0x4439759f,0x69d830cf,0x6e38583c,0x0fd0015b}},	//   _wap_, ncue, _naub, িরোধ, 
   {{0x68f975a0,0x02d081e9,0xdc1800ef,0xdec00092}},	// [26cc0] nsud, _दूरभ, _pāļi, _ስለኛ_, 
   {{0x44389c2d,0x69d80007,0xb9c802d3,0x68f80ba7}},	//   _uap_, hcue, _ዲዩ_, isud, 
   {{0x7c3975a1,0x7dc575a2,0x6e3975a3,0x68f8022e}},	//   _ratr, چقان, _baub, hsud, 
   {{0x7c38325f,0xfce4b5d6,0x6e3975a4,0xbd885694}},	//   _satr, водо, _caub, ونان_, 
   {{0x6e3975a5,0xceac0022,0xb5f800e4,0x23bc01e1}},	//   _daub, _ҳә_, ukái, bájé_, 
   {{0x68f946e8,0x9b9401c0,0x7c38ad1b,0x6e380129}},	//   dsud, лилц, _qatr, _eaub, 
   {{0x7c3804b9,0xceac1d25,0x6e384e01,0x00000000}},	//   _vatr, _гә_, _faub, --, 
   {{0x7c3975a6,0x5a340e91,0x69d80399,0xcee80014}},	//   _watr, унит, gcue, _سرفن_, 
   {{0x7c3975a7,0x68f90d75,0x20d81152,0xca7400cf}},	//   _tatr, gsud, _भूमध, دەنت_, 
   {{0x3ce575a8,0x6e3975a9,0x6a840100,0xb5f82dd4}},	//   mpov_, _zaub, _pèfè, nkáv, 
   {{0x6e380333,0x2c140073,0x3ce43493,0x00000000}},	//   _yaub, _नातू_, lpov_, --, 
   {{0x9f580004,0x6b780bd9,0x69d975aa,0x02bc30a4}},	//   _zdrã_, _קראנ, ccue, ्दोन, 
   {{0x02bc012c,0x765c01a9,0x00000000,0x00000000}},	//   ्दैन, _voqy, --, --, 
   {{0x67d00372,0xf48575ab,0x3944008f,0xf00801fb}},	//   _кошу, тумн, _iros_, _đắng_, 
   {{0x21d800b4,0x00000000,0x00000000,0x00000000}},	//   _ọha_, --, --, --, 
   {{0x39440bed,0x201975ac,0x57a40b01,0x5f440092}},	//   _kros_, _acri_, _ишқа, _የሚላቸ, 
   {{0x6e3975ad,0x3ce40218,0xe3b001d3,0x0fd000fe}},	// [26cd0] _raub, jpov_, مرہ_, িৰোধ, 
   {{0x6f0000e5,0x2f880114,0x6288ea5b,0x00000000}},	//   ánco, мљен_, édor, --, 
   {{0x2fc575ae,0x6e3975af,0x2018026c,0x68f80122}},	//   äng_, _paub, _dcri_, zsud, 
   {{0x39450f04,0x69d80399,0xdce006be,0x72a000d1}},	//   _oros_, xcue, _axmı, _ئەرن, 
   {{0x394401d4,0x93c800dd,0x68f8020c,0xa2b175b0}},	//   _nros_, _تاکہ_, xsud, ंतर्, 
   {{0xcfe975b1,0x69d80399,0x9f040131,0x15e00131}},	//   _سفره_, wcue, _ھوقو, _ﺋﯩﺰﺩ, 
   {{0x6e3975b2,0x394400a9,0x89d402bf,0x3b8001c0}},	//   _taub, _aros_, ліпш, йлшг, 
   {{0x68f975b3,0x5f080882,0x394533a1,0xca3801e4}},	//   tsud, _हित्_, _bros_, roŝo_, 
   {{0x39440a2c,0x69d975b4,0x6cb02e51,0x88c80120}},	//   _cros_, rcue, _көкт, нлив_, 
   {{0x46e90879,0x39440f7b,0x7d2800aa,0x3a24004e}},	//   ндон_, _dros_, _سيمې_, _ebop_, 
   {{0x39440483,0x68f975b5,0x9854f229,0xdef4010c}},	//   _eros_, ssud, ртыш, _ልብን_, 
   {{0x84e40323,0x9a8407d6,0x394405b1,0x6d4c00d8}},	//   ломж, _кучл, _fros_, _àcas, 
   {{0x394575b6,0x2aa002d3,0xdb080139,0x19580022}},	//   _gros_, _ምህናጽ_, _ezdä, _иацы_, 
   {{0x291c036e,0x28a80037,0x00000000,0x00000000}},	//   mtua_, _घीचि, --, --, 
   {{0x291c049b,0xb890007b,0x23a40210,0x00000000}},	//   ltua_, _دلوع, _खुशद, --, 
   {{0x20184a1f,0x00000000,0x00000000,0x00000000}},	//   _scri_, --, --, --, 
   {{0x291d75b7,0x660575b8,0xc58801d9,0xb4d826b7}},	// [26ce0] ntua_, _idik, _سپدم_, lvàn, 
   {{0x291d75b9,0x1cb00327,0xb5f8035b,0x00000000}},	//   itua_, _ནེེ_, ukáv, --, 
   {{0x7f8575ba,0x291c02f6,0x00000000,0x00000000}},	//   دلان, htua_, --, --, 
   {{0x291c05f5,0xfdd000bd,0xb5f800bc,0xd7f80165}},	//   ktua_, ার্ড, skáv, zaă_, 
   {{0x6604090c,0x291c0023,0x5bcc00dc,0x6584001f}},	//   _mdik, jtua_, ाश्व, _አንቀፅ_, 
   {{0x224175bb,0x645d75bc,0x3ce4f024,0x3988007d}},	//   ldik_, njri, rpov_, _हs_, 
   {{0x21200548,0x660575bd,0xddc00171,0x291c01f4}},	//   ltih_, _odik, _komū, etua_, 
   {{0x660575be,0x394575bf,0x224175c0,0x6f900597}},	//   _ndik, _pros_, ndik_, _الفض, 
   {{0xa9c010f5,0x212175c1,0x987575c2,0x3ea575c3}},	//   йськ, ntih_, илиц, moot_, 
   {{0x660575c4,0x3ea575c5,0x21200548,0x645c0784}},	//   _adik, loot_, itih_, jjri, 
   {{0x291d75c6,0xa3d82017,0x8b641eeb,0x6d4ca547}},	//   atua_, िशन_, _پالم, _àcar, 
   {{0x3ea575c7,0x394575c8,0x66041529,0x212175c9}},	//   noot_, _tros_, _cdik, ktih_, 
   {{0x291d75ca,0x66040135,0x224175cb,0x394575cc}},	//   ctua_, _ddik, ddik_, _uros_, 
   {{0x660463d1,0x3ea41c1d,0x224001f5,0x79a401ee}},	//   _edik, hoot_, edik_, _ирһе, 
   {{0x3ea575cd,0x66e010fc,0x53343452,0xe7340798}},	//   koot_, _лоја, шевт, _беј_, 
   {{0xb4003bfd,0x2120011f,0x3ea40036,0x62880022}},	//   шүүд, ftih_, joot_, édop, 
   {{0x0f40001f,0xb6c001ee,0x115428f6,0x00000000}},	// [26cf0] _የሚመረ, _киҫһ, шкаю, --, 
   {{0x5ff401c0,0xb5f800e4,0x224175ce,0xb63c02dd}},	//   йзуу, akát, adik_, _ﺇﻴ_, 
   {{0x291c01c0,0x63680801,0xf1bc01e1,0x6ee4007b}},	//   ztua_, _бряг_, _gbán_, اسئل, 
   {{0x3ea401f5,0xddc000b8,0x224000a2,0x00000000}},	//   goot_, _gomū, cdik_, --, 
   {{0xf1a88efb,0x8d84001f,0x291c01c4,0x317000fb}},	//   _ساحه_, _ፓርቲው_, xtua_, _уғат, 
   {{0x8c4575cf,0xa3d80574,0xdfd575d0,0x985c00ef}},	//   реке, िशय_, _горы, _cāļu_, 
   {{0x3ea575d1,0x5c045238,0x2c6803b2,0xb5f975d2}},	//   boot_, сяча, _jødi_, nkás, 
   {{0x291d75d3,0x090411e5,0xce940c60,0x23bc013a}},	//   ttua_, апин, _табъ, _hájí_, 
   {{0xaca001f2,0xdef41772,0xdea46bef,0x291d75d4}},	//   _awụn, _ልብና_, _اینی, utua_, 
   {{0xb5f8038e,0x291d75d5,0x660406df,0x888401c6}},	//   cház, rtua_, _sdik, рлож, 
   {{0x291d75d6,0x6d4c0077,0x2ca575d7,0x2240616c}},	//   stua_, _ácab, mond_, ydik_, 
   {{0x2ca575d8,0x291d75d9,0x5f08032c,0x985c005f}},	//   lond_, ptua_, _हिस्_, _zāļu_, 
   {{0x696404fb,0x99d4eead,0x2ca4017a,0xc76400f7}},	//   _حداق, _اتما, oond_, _چاعى, 
   {{0x2ca407c5,0xc764021f,0x00000000,0x00000000}},	//   nond_, _ناعى, --, --, 
   {{0xc0c80ed1,0x3ea40204,0x22416070,0x430805d9}},	//   _ﺑﻮﻻﺗ, yoot_, tdik_, ضيءَ_, 
   {{0x2ca575da,0x660575db,0x21206b79,0x3ea4002e}},	//   hond_, _udik, ttih_, xoot_, 
   {{0x2ca575dc,0x224175dd,0xb5f801ed,0xb1400166}},	// [26d00] kond_, rdik_, yház, онтл, 
   {{0x212175de,0xf0080016,0x224175df,0xb5f975e0}},	//   rtih_, _đảng_, sdik_, skát, 
   {{0x212049ad,0x3ea41af3,0x23bc01e1,0x2ca575e1}},	//   stih_, toot_, _dájí_, dond_, 
   {{0x22400429,0x1fb80154,0x21200010,0xb5f83df9}},	//   qdik_, _জলদস, ptih_, lkár, 
   {{0x3ea575e2,0x21200477,0x985c00ef,0x52b000d1}},	//   root_, qtih_, _pāļu_, _رەكئ, 
   {{0x3ea404c4,0x2ca575e3,0xb5f90ebd,0x6f081432}},	//   soot_, gond_, nkár, ümcü, 
   {{0x3ea575e4,0xb5f801ed,0x9d5521eb,0x6c800b24}},	//   poot_, rház, _گۆشت, تلوم, 
   {{0xd838151c,0xb5f801ed,0x6f00054e,0x00000000}},	//   moči_, sház, ânce, --, 
   {{0xd5a40c66,0xb8640a12,0xe8f51dbc,0xd838151c}},	//   _गुंज, لادو, аныч_, loči_, 
   {{0x2ca575e5,0xb60400e4,0x987400d8,0xb5f81de4}},	//   cond_, _otáñ, слоц, jkár, 
   {{0xd83809a8,0xb5f83afd,0xeb9400c7,0xa820036b}},	//   noči_, dkár, _киф_, تکنن, 
   {{0x7ae83262,0xb5f800d7,0xfa680798,0x00000000}},	//   mpft, ekár, _шаек_, --, 
   {{0xf9900345,0xb8640682,0xe944085b,0x00000000}},	//   _ببا_, _پاشو, _پرنی, --, 
   {{0xd83815ad,0x00000000,0x00000000,0x00000000}},	//   koči_, --, --, --, 
   {{0xd838151c,0x24580276,0x23bc0241,0xabe002dd}},	//   joči_, шарь_, _rájí_, _ﺍﺘﻔﺎ, 
   {{0x2ca40cf9,0x27740375,0xb5f800bc,0x356975e6}},	//   zond_, _כגון_, ujád, _арон_, 
   {{0xd2500d62,0x91b80ed6,0xf8b803ce,0x2ca4ca87}},	// [26d10] _ہند_, угат_, _उठाय, yond_, 
   {{0xb5f800e5,0x205400db,0x00000000,0x00000000}},	//   ckár, окуя, --, --, 
   {{0x2ca575e7,0xd83809a8,0xd250009f,0x00000000}},	//   vond_, goči_, _فند_, --, 
   {{0xc0d4044e,0x2ca4bdd0,0xa2a80073,0x92580107}},	//   _ክህሉ_, wond_, चवण्, _самт_, 
   {{0x2ca575e8,0x5cf4005b,0x70540354,0xad4000db}},	//   tond_, оящу, _вĕле, تىشۉ, 
   {{0x1a68177a,0xdb0808a5,0xb37c0023,0xf07401af}},	//   ییلی_, _eydí, _ሓመድን_, _тигә_, 
   {{0x2ca575e9,0xa3d826d9,0xf65c0158,0xc0c111f6}},	//   rond_, िशत_, kjæ_, _хәти, 
   {{0x2ca575ea,0xb5f803b2,0x00000000,0x00000000}},	//   sond_, hjáb, --, --, 
   {{0x2ca575eb,0x87f801c0,0x07f8009d,0x00000000}},	//   pond_, лэнт_, лхны_, --, 
   {{0x2ca401e2,0x00000000,0x00000000,0x00000000}},	//   qond_, --, --, --, 
   {{0xf8ac04d3,0xb8fc033d,0x06c805f5,0xb4d800cf}},	//   رکه_, _दू_, лгой_, svàl, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc84409a5,0x60c00036,0xb5f8ea0f,0x7e8c01e4}},	//   _гелй, _ëmmg, tkár, nŝpa, 
   {{0x7e8c01e4,0xb5f800e4,0x00000000,0x00000000}},	//   nĝpr, ukár, --, --, 
   {{0xcfac04c5,0xb5f90b1d,0xa3b4033f,0xfbd0011a}},	//   কেতন, rkár, ड़ें_, לתם_, 
   {{0xb5f97568,0xd8380419,0x00000000,0x00000000}},	//   skár, voči_, --, --, 
   {{0x9f582776,0xbadc0150,0xa3d802c3,0x00000000}},	// [26d20] _gerê_, _ﺇﻟﺤﺎ, िशद_, --, 
   {{0xd83901dd,0x25a001c4,0x8fd40022,0x201c03e0}},	//   toči_, _ixil_, жәтә, üvi_, 
   {{0x26c00217,0x82a497c3,0x7de50086,0x00000000}},	//   _khio_, _ганж, білд, --, 
   {{0x9f58069c,0xd8380fb7,0x82340372,0x0eb800fd}},	//   _herë_, roči_, _اردا, аучы_, 
   {{0xd8380010,0x36180a7c,0xff0800fe,0xdb08013a}},	//   soči_, רונד, ৰবেশ_, _vydí, 
   {{0x4ce00729,0x2d540108,0x00000000,0x00000000}},	//   _নিখু, сишь_, --, --, 
   {{0x2d9c0393,0x26c00c18,0x00000000,0x00000000}},	//   _exue_, _ohio_, --, --, 
   {{0x9f58036e,0x00000000,0x00000000,0x00000000}},	//   _lerë_, --, --, --, 
   {{0x81a803f4,0xa3d82356,0xb2181b25,0xdb245598}},	//   গের_, िशा_, _smæk, _ژوئی, 
   {{0x26c003a0,0x7d0175ec,0xfb1975ed,0xdea4006c}},	//   _ahio_, msos, _مقطع_, _ایچی, 
   {{0x26c001ab,0x25a0507c,0x7d0175ee,0xcb0802bf}},	//   _bhio_, _axil_, lsos, _вхід_, 
   {{0x26c175ef,0x7d000472,0xf60801d5,0xb8fc0154}},	//   _chio_, osos, دتده_, _তব_, 
   {{0x92d40d42,0x7d0175f0,0x9f58036e,0x00000000}},	//   _হবে_, nsos, _berë_, --, 
   {{0x91b805d7,0x7d000108,0x00000000,0x00000000}},	//   ्धसै, isos, --, --, 
   {{0x26c01682,0x7d00089c,0x7684010b,0x9f59118a}},	//   _fhio_, hsos, _гыпж, _derë_, 
   {{0x9f5824ba,0x7d0175f1,0xca3801e4,0x559401af}},	//   _terê_, ksos, toŝi_, _майѓ, 
   {{0xa15975f2,0x55c43c1a,0xb5f800e5,0x00000000}},	// [26d30] бату_, _фәнз, pjáb, --, 
   {{0x7d0000cc,0xb37001ec,0x00000000,0x00000000}},	//   dsos, _еңгі, --, --, 
   {{0x2c68037e,0xd2500014,0x24840221,0x7d000042}},	//   _mødt_, _ہنگ_, ëmme_, esos, 
   {{0x7d0002a8,0xd8380841,0xe78400bc,0xbae001ec}},	//   fsos, moču_, náší, _ﺍﺨﺘﺎ, 
   {{0x7d0175f3,0x9f580100,0xd8385160,0xddc001ef}},	//   gsos, _lerè_, loču_, _domů, 
   {{0x2c684e9b,0xcb680262,0x058c02d3,0xc0f002d3}},	//   _nødt_, иале_, _ነንብብ_, ልኹም_, 
   {{0x7d00b398,0x16080073,0xb5f800e4,0x00000000}},	//   asos, वणार_, ykáp, --, 
   {{0x2c4c00e2,0x88e402e8,0x39bc0ca8,0x00000000}},	//   _sēdē_, ожие, _ọsan_, --, 
   {{0x4c942e9c,0x2d9c009d,0x26c0007f,0x92d40154}},	//   _диас, _uxue_, _rhio_, _হবো_, 
   {{0x26c175f4,0xd83801fa,0xab2975f5,0x08885889}},	//   _shio_, koču_, _مسؤل_, рбой_, 
   {{0x60c0092e,0x26c001ee,0x2c681512,0xc1a408df}},	//   _ëmme, _phio_, _dødt_, _खड्ग, 
   {{0xdbd403f2,0x9f58036e,0xb5f800e4,0x906c0150}},	//   _húðk, _serë_, ukáp, _ﺴﻠﺴﺔ_, 
   {{0x2c68fb11,0x95740139,0xc33001d9,0x00000000}},	//   _født_, пырч, ژٕس_, --, 
   {{0x9f58003a,0x26c002b1,0xb5f80321,0xe94575f6}},	//   _ferè_, _whio_, skáp, _پرچی, 
   {{0x9f580023,0x00000000,0x00000000,0x00000000}},	//   _verë_, --, --, --, 
   {{0x7d0084ad,0xc1e801c0,0x26c00175,0x00000000}},	//   ysos, рдаж_, _uhio_, --, 
   {{0x9f582776,0x80650029,0x8cd809bb,0x4ce00154}},	// [26d40] _terë_, оваж, _फूलो, _নিঝু, 
   {{0x752800fd,0x00000000,0x00000000,0x00000000}},	//   _ägza, --, --, --, 
   {{0xddc00316,0x00000000,0x00000000,0x00000000}},	//   _pomů, --, --, --, 
   {{0x7d0175f7,0x4428009d,0x6f000356,0xdecc0ef6}},	//   tsos, lfb_, ânca, _ﺑﺎﺷﺒ, 
   {{0x61e4f3aa,0x9f580098,0xe7a82e05,0x7d002401}},	//   mcil, _meré_, _घुसप, usos, 
   {{0x932411c2,0x7d0175f8,0x61e575f9,0x1ab40146}},	//   _برین, rsos, lcil, ुष्ठ, 
   {{0x7d0175fa,0x2c68a76f,0x6d4c0077,0x3d040401}},	//   ssos, _rødt_, _ácan, _हटके_, 
   {{0xead009fe,0x2c6800b5,0x9b680075,0x7d002401}},	//   мощь, _sødt_, ишқа_, psos, 
   {{0xe51d0a71,0x61e4102c,0x9f5800cf,0xa02c00b7}},	//   भूमि_, icil, _serè_, _ሳምንታ, 
   {{0x7e600bb8,0xefd402d3,0x4ce000fe,0x2c680fac}},	//   ljop, _ክትዕ_, _নিচু, _døds_, 
   {{0x4428002d,0x1fb8012d,0x61e575fb,0x6fd80115}},	//   dfb_, _अरोड, kcil, יקיס, 
   {{0x9f58003e,0x7e6175fc,0x61e4ae70,0x683c0064}},	//   _ceré_, njop, jcil, ešdė, 
   {{0x5924003d,0x7c28014b,0x98c4035b,0x61e402f0}},	//   _འདིས_, offr, _еидҵ, dcil, 
   {{0x9f58007f,0x7c2900d7,0x44280205,0x00000000}},	//   _terè_, nffr, gfb_, --, 
   {{0xa3d575fd,0xd8380cf4,0x9f5808ce,0x32640d1d}},	//   дорч, meč_, _edrú_, отав, 
   {{0xd83936f5,0x61e4003c,0x66b4fad3,0xdb440133}},	//   leč_, gcil, _общу, _یێ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [26d50] --, --, --, --, 
   {{0x61e40077,0xd839438e,0x00000000,0x00000000}},	//   acil, neč_, --, --, 
   {{0x9f5800e8,0x6ee400cf,0x00000000,0x00000000}},	//   _yeré_, زسال, --, --, 
   {{0x81a80729,0x61e575fe,0x236c01e6,0x042000cc}},	//   গেই_, ccil, ädje_, য়ণী_, 
   {{0x7874054e,0x00000000,0x00000000,0x00000000}},	//   _râvn, --, --, --, 
   {{0xd8381727,0x32c4015d,0x4e8401d9,0xdc9800d4}},	//   ječ_, _gŵyr_, _کٔرٕ, овчі_, 
   {{0xd838488c,0x4df4033f,0xdd983c1a,0x2dd8007b}},	//   deč_, आरआई_, йшә_, _نبذة_, 
   {{0xba200395,0x9aa80472,0x00000000,0x00000000}},	//   едък, يديف_, --, --, 
   {{0xdd940dd8,0xdb080316,0x62880129,0xcfac0154}},	//   _жаты, _vydá, èdoi, কেশন, 
   {{0x9f5975ff,0xac757600,0x61e403db,0xdc0800db}},	//   _seré_, _بارش, zcil, _وققو_, 
   {{0x9f5800d5,0x8d740092,0x61e40205,0x00000000}},	//   _peré_, _ጠፍቷል_, ycil, --, 
   {{0x61e57601,0x764803b2,0xabd00116,0x00000000}},	//   xcil, _ógyl, ﻟﯘﻣﺎ, --, 
   {{0xd06000ac,0x9f580407,0x19400588,0xd838a7ab}},	//   ştər, _veré_, _аҭын, beč_, 
   {{0x386402d3,0xf65c03b2,0xd83801ef,0x00000000}},	//   _ዝፈልጥ, lmæl_, ceč_, --, 
   {{0x61e57602,0x6b800007,0xe78400fb,0x8754011c}},	//   tcil, nzng, _файҙ_, _хълц, 
   {{0x2a7c020b,0xf65c0158,0x61e40841,0x9694013d}},	//   nhub_, nmæl_, ucil, _орыш, 
   {{0x9f5800d0,0x056406ed,0x7c280368,0x00000000}},	// [26d60] _udrú_, _ѕвон, yffr, --, 
   {{0x2168774d,0xc0cc001f,0x00000000,0x00000000}},	//   биғи_, ባችሁ_, --, --, 
   {{0x7de40220,0x7e600af9,0x00000000,0x00000000}},	//   пілд, tjop, --, --, 
   {{0x7b2c3421,0xf008004d,0xd8380118,0x82a4444e}},	//   nđuš, _đấng_, zeč_, _хамж, 
   {{0xca3801e4,0x2a7c0009,0x72d000f7,0x3eb800e2}},	//   deŝ_, dhub_, _سەكچ, ēpt_, 
   {{0x7e617603,0xe6c800e1,0xdcb00131,0x7c28002f}},	//   sjop, रगुज, خىت_, uffr, 
   {{0xd8380fb7,0xe51c0f4c,0x8f8000b5,0x5924031c}},	//   več_, भूति_, _iv期a, _འདངས_, 
   {{0xdb080205,0x5a341d0f,0x3bd400f1,0x00000000}},	//   _izdü, фнит, _ځغاس, --, 
   {{0xd83814b2,0x7c28002f,0x00000000,0x00000000}},	//   teč_, pffr, --, --, 
   {{0xf80400d6,0xb80400dd,0xb21802d2,0x00000000}},	//   ччин, سکتے_, _glæf, --, 
   {{0x7bd8d9a6,0xd8397604,0xca380115,0xa5280327}},	//   _igtu, reč_, beŝ_, _ཧཱུྂ_, 
   {{0xb5f801ed,0x2a7d7605,0xf78001c6,0xd8386b92}},	//   aján, chub_, двүү, seč_, 
   {{0xb21808a5,0x03ec00eb,0x998801af,0x00000000}},	//   _hlæg, _জয়ী_, _фәйз_, --, 
   {{0x37040131,0xd94400ee,0x00000000,0x00000000}},	//   _ечив, _неҗи, --, --, 
   {{0x320848ae,0xe2f801ec,0xb4b00166,0x00000000}},	//   йхан_, зесі_, _җинә, --, 
   {{0x5fb0000d,0x00000000,0x00000000,0x00000000}},	//   _झड़ल, --, --, --, 
   {{0xa15801ca,0x1c1c03ba,0x00000000,0x00000000}},	// [26d70] пату_, नलाल_, --, --, 
   {{0xd0102a1a,0x7bd80093,0x6f000311,0xf1bc00d0}},	//   ئلا_, _ngtu, ânco, _obáv_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7bd80357,0xddd002d5,0x85480014,0x929401c6}},	//   _agtu, _šešt, _آیے_, _цамц, 
   {{0x8c448af4,0x6b800369,0xdb080210,0x00000000}},	//   деле, wzng, _ozdó, --, 
   {{0x290800d7,0x00000000,0x00000000,0x00000000}},	//   ácam_, --, --, --, 
   {{0x9f357606,0x2a7d04aa,0x952c0327,0x620803b2}},	//   _пері, thub_, _ཧཱའི_, _óslæ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9e24075e,0xca3801e4,0xb5f8655d,0x0d2000db}},	//   _سىلو, reŝ_, tján, _рүлү, 
   {{0x2a7c585b,0x00000000,0x00000000,0x00000000}},	//   shub_, --, --, --, 
   {{0xb2197607,0x0aa00139,0xb4d400bc,0xb5f800e5}},	//   _klæd, _иңкү, िदै_, rján, 
   {{0x4974cda6,0x2a7c0472,0xcca800db,0x68e80051}},	//   _олес, qhub_, _اچچۇ_, _ttgd, 
   {{0xddc02aef,0x394000b5,0x04b412fa,0x80cc0073}},	//   _komš, ækst_, дсвя, _तळले, 
   {{0x02c44a18,0xc8c8009f,0x00000000,0x00000000}},	//   लग्न, _بوتن_, --, --, 
   {{0xc6880014,0x05741411,0x00000000,0x00000000}},	//   _وَتن_, ساڭد, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [26d80] --, --, --, --, 
   {{0xb5f808a7,0x9f5804cc,0xe5e40075,0xb21802d2}},	//   hjál, _ferì_, _ﺋﯩﻜﻜ, _smæt, 
   {{0xb5f8041e,0xb2185cf2,0x00000000,0x00000000}},	//   kjál, _blæd, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb218f113,0x2478007f,0xfca800f1,0x00000000}},	//   _slæg, _kٍm_, ياتو_, --, 
   {{0xb21802d2,0xf1a40118,0x00000000,0x00000000}},	//   _plæg, _कुटन, --, --, 
   {{0xb4d81186,0xb21802d2,0xddc00064,0x7ac4520c}},	//   lvàt, _flæd, _domš, мсие, 
   {{0xb218037e,0x1cb0025c,0xf278008f,0x00000000}},	//   _glæd, _ནེམ_, ַריש, --, 
   {{0xdb0802f6,0x7bd80334,0xdcc801e0,0x00000000}},	//   _sydä, _tgtu, _еңде_, --, 
   {{0xada000c7,0x92d800cc,0x6da001ec,0x6cc001ec}},	//   _раул, ঠীয়_, _риуа, _айуа, 
   {{0xb5f80174,0x00000000,0x00000000,0x00000000}},	//   bjál, --, --, --, 
   {{0xb4d4102f,0xddc00064,0x00000000,0x00000000}},	//   िद्_, _zomš, --, --, 
   {{0x19584caf,0xd05c00ac,0x41ac012d,0xfbe00210}},	//   _халы_, _etsə, _झुलस, _पलाम, 
   {{0x9f58026c,0xa9640063,0xb5f800e5,0x00000000}},	//   _perì_, _циља_, nkáz, --, 
   {{0xa4d410f5,0x5694d10a,0x32dc00a2,0x00000000}},	//   торі, _пакт, kçyň_, --, 
   {{0x78b848bb,0x236c01e3,0xe78401ef,0x00000000}},	//   lltv, ädja_, jáří, --, 
   {{0xb2180413,0xa1944a7a,0x00000000,0x00000000}},	// [26d90] _smæs, ватч, --, --, 
   {{0xb218005c,0x00000000,0x00000000,0x00000000}},	//   _slæd, --, --, --, 
   {{0xddc00427,0xc4d0011a,0x00000000,0x00000000}},	//   _romš, _תגי_, --, --, 
   {{0xc33004ac,0x00000000,0x00000000,0x00000000}},	//   _גוט_, --, --, --, 
   {{0x4278010f,0x00000000,0x00000000,0x00000000}},	//   _זארג, --, --, --, 
   {{0x251c0a1e,0x211803e6,0xf1bc0118,0x99840153}},	//   קווא, _کتێب_, _dbát_, hemų_, 
   {{0x8f68007b,0xcfc40150,0x00000000,0x00000000}},	//   _عمرك_, _ﺩﺍﻣﺒ, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb2180627,0xddc00010,0xf41403d4,0xaadca5b3}},	//   _klæb, _tomš, দ্যৰ_, _पूरक, 
   {{0xb5f97608,0xe900009d,0x00000000,0x00000000}},	//   ckáz, нцүү, --, --, 
   {{0x89d81291,0x00000000,0x00000000,0x00000000}},	//   _فوار_, --, --, --, 
   {{0x7c3c0115,0x81a80154,0x3f7800df,0x00000000}},	//   ĵpre, গেট_, פארס, --, 
   {{0x6ab80112,0xf1bc00ae,0x00000000,0x00000000}},	//   mluf, _mbás_, --, --, 
   {{0xc7a4117e,0x00000000,0x00000000,0x00000000}},	//   _пилк, --, --, --, 
   {{0x42541dbc,0x17c40022,0x7dd43361,0x9f580ca8}},	//   нтат, _иашҭ, _küsü, _perí_, 
   {{0xb2180436,0x6ab8002f,0x96940064,0x00000000}},	//   _smær, nluf, _арьш, --, 
   {{0x7dd400ee,0x9f597609,0xb21802d2,0x6ab80112}},	// [26da0] _müsü, _verí_, _blæb, iluf, 
   {{0xf1bc0241,0x44e40109,0xb140d673,0x6ab80112}},	//   _abás_, _iô_, ынул, hluf, 
   {{0x44e4001e,0x7964002e,0x6ab85794,0x92c003d4}},	//   _hô_, _kéwë, kluf, ুৱে_, 
   {{0x44e401fb,0x6cd402dd,0x57cc010f,0x3d0c000d}},	//   _kô_, _ﺘﺎﺭﻴ, קמאַ, _सिआइ_, 
   {{0x62847ea1,0x44e40798,0x6ab801bf,0xd24c0345}},	//   mhio, _jô_, dluf, _بۆق_, 
   {{0x44e5760a,0xb5f81d55,0x62845a1e,0xb218005c}},	//   _mô_, ukáz, lhio, _umær, 
   {{0x44e40016,0x6ab870fa,0x00000000,0x00000000}},	//   _lô_, fluf, --, --, 
   {{0x44e40109,0x6ab809e8,0x9f580124,0xbe0400e5}},	//   _oô_, gluf, _terâ_, _سوئٹ, 
   {{0x6da1760b,0xada005f5,0x44e5760c,0xdc84013e}},	//   _бита, _батл, _nô_, _иқдо, 
   {{0xdb2410e8,0xac1400f3,0x00000000,0x00000000}},	//   _لوئی, _пођу_, --, --, 
   {{0x7dd4014a,0x7be00421,0x6ab80267,0xeb300228}},	//   _füsü, ātuā, bluf, _مىلد, 
   {{0x44e401fb,0x7dd400a2,0x00000000,0x00000000}},	//   _bô_, _güsü, --, --, 
   {{0x44e401dc,0x3a240117,0x62840035,0x0a8800f7}},	//   _cô_, _icop_, dhio, _تئلى_, 
   {{0x77904768,0x44e5760d,0xb4a80243,0x00000000}},	//   _میخا, _dô_, गके_, --, 
   {{0x44e408e7,0xd7f8084c,0x67d00131,0x62849a14}},	//   _eô_, mbă_, _йошу, fhio, 
   {{0x44e5264b,0xb218037e,0x67b80375,0xd7f8054e}},	//   _fô_, _slæb, _ממוק, lbă_, 
   {{0x44e4006a,0x13f40395,0x00000000,0x00000000}},	// [26db0] _gô_, _изпя, --, --, 
   {{0x9f5800db,0x545407d8,0x49a00023,0xb62802dd}},	//   _berà_, _рвот, _ውድቀቱ_, _ﺗﻪ_, 
   {{0x44e401fb,0x62840332,0xda2001f9,0x00000000}},	//   _zô_, bhio, _यांत_, --, 
   {{0x6285760e,0x3a25760f,0x39453324,0x9f597610}},	//   chio, _ncop_, _osos_, _derà_, 
   {{0x44e4001e,0xf3e403d4,0x6ab8007c,0x00000000}},	//   _xô_, কৰণৰ_, vluf, --, 
   {{0x9f582b1d,0xd7f80311,0x7dd456f8,0x00000000}},	//   _ferà_, jbă_, _süsü, --, 
   {{0x3944036b,0x6ab97611,0x00000000,0x00000000}},	//   _asos_, tluf, --, --, 
   {{0xb4bc0a28,0x637c0793,0x6ab80b23,0x00000000}},	//   ेषु_, länö, uluf, --, 
   {{0x3944004e,0x6ab97612,0x9f58035b,0x6cb000fb}},	//   _csos_, rluf, _terã_, _йөкт, 
   {{0x628407e4,0x6ab97613,0xb4a80316,0xeaf87b43}},	//   zhio, sluf, गको_, _فرصت_, 
   {{0x44e4f165,0x07a400d3,0xf42403f4,0x3944db58}},	//   _sô_, танн, য়ার_, _esos_, 
   {{0xd7f8084c,0x44e57614,0xd1d00092,0x00000000}},	//   abă_, _pô_, _እጦት_, --, 
   {{0xb6a17615,0x386c013a,0x00000000,0x00000000}},	//   риял, _fofr_, --, --, 
   {{0x44e407ae,0x291c0451,0x9f580077,0x03a40276}},	//   _vô_, muua_, _lerá_, виго, 
   {{0x62857616,0xc2b4026a,0x291c0270,0xa30801d3}},	//   thio, вљањ, luua_, عرسے_, 
   {{0x44e57617,0x80a40131,0x00000000,0x00000000}},	//   _tô_, ھمان, --, --, 
   {{0x9f597618,0x291c0607,0xf41403d4,0xc484004e}},	// [26dc0] _serà_, nuua_, দ্ধৰ_, _алпк, 
   {{0x66057619,0x0395761a,0x628474da,0x7874013c}},	//   _heik, _армя, shio, _pâvi, 
   {{0x6605761b,0x24980421,0x6fb0007b,0x7f8433d2}},	//   _keik, mirm_, لمكا, خلان, 
   {{0x6605761c,0x291d761d,0x41c40014,0x249803e0}},	//   _jeik, kuua_, _لٲجِ, lirm_, 
   {{0x6605761e,0xf26400d1,0xf184004e,0x22400254}},	//   _meik, _риял_, _айял_, meik_, 
   {{0x3a25761f,0x6604bf06,0x2240783c,0x637c01b8}},	//   _scop_, _leik, leik_, cänö, 
   {{0xfaa4220f,0xbbe00073,0x8e5401ec,0xcc642a8b}},	//   кшин, _पलीक, _өтті, انىۋ, 
   {{0xeaac3497,0x60dd7620,0x249804ef,0x66057621}},	//   يعي_, _hirm, hirm_, _neik, 
   {{0x60dceec9,0xfce4f79d,0x2498020b,0x58d97622}},	//   _kirm, _розо, kirm_, ндия_, 
   {{0x60dd7623,0x224001c7,0x00000000,0x00000000}},	//   _jirm, heik_, --, --, 
   {{0xba257624,0x60dd7625,0xd7f80276,0x66057626}},	//   _адек, _mirm, rbă_, _beik, 
   {{0x6f0003b7,0x66040a73,0x39440211,0x75a00023}},	//   ânci, _ceik, _tsos_, _ዘሕልፎ_, 
   {{0x24997627,0x39457628,0x386c0607,0x6604fbff}},	//   firm_, _usos_, _tofr_, _deik, 
   {{0x60dc0882,0x637c01b8,0xe4a40818,0x00000000}},	//   _nirm, xänö, арсо, --, 
   {{0x66057629,0x35c40034,0x66e00f5c,0xf04000e5}},	//   _feik, रेज़, _која, یٹری, 
   {{0x60dd762a,0xea9c0a28,0x660400a3,0x249800a3}},	//   _airm, reṇa_, _geik, airm_, 
   {{0x212005b1,0x11541e76,0x637c01b8,0x7e8c01e4}},	// [26dd0] guih_, ыкаю, tänö, nŝpu, 
   {{0x9f581a36,0xea9c0882,0x66040d27,0x60dd762b}},	//   _será_, peṇa_, _zeik, _cirm, 
   {{0x60dd762c,0x66040099,0x9f04fb12,0xb8ec031c}},	//   _dirm, _yeik, لولو, _ྱེ_, 
   {{0x60dc8648,0x637c01b8,0x2120003e,0x1278008f}},	//   _eirm, sänö, buih_, _נאָע, 
   {{0x9f587d3d,0x637c01b8,0x3d04033f,0x2164004e}},	//   _verá_, pänö, _सौदे_, _ктрг, 
   {{0x60dd762d,0x8ba459e6,0xdd95762e,0xb3e01a4e}},	//   _girm, лилж, шачы, पशिख, 
   {{0x9f587c36,0xaca001f2,0xfef00451,0xfcc00139}},	//   _terá_, _ntụn, _هڻند, сәтм, 
   {{0x4a4400d1,0x07a40220,0x291d762f,0x60dd237a}},	//   унив, ғамн, tuua_, _zirm, 
   {{0x66057630,0xaca002e3,0x4c2400dd,0xac240311}},	//   _reik, _atụn, _مظاہ, _афек, 
   {{0x66057631,0x22402e10,0x60dc11f2,0xdc700124}},	//   _seik, zeik_, _xirm, _ҳҳәы, 
   {{0x66057632,0x291c0194,0x00000000,0x00000000}},	//   _peik, suua_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x66057633,0x224058f7,0xdb0800b5,0xd1e40240}},	//   _veik, veik_, _sydø, ምካት_, 
   {{0x66057634,0xb6a002dd,0xd838007f,0x764c0142}},	//   _weik, _қиыл, nnčl_, adcy, 
   {{0x66057635,0x60dc208d,0x22406b78,0x00000000}},	//   _teik, _rirm, teik_, --, 
   {{0x60dd7636,0x66040270,0x24980254,0x00000000}},	//   _sirm, _ueik, sirm_, --, 
   {{0x60dd7637,0x22400926,0x3ebc00e8,0x9f580139}},	// [26de0] _pirm, reik_, _ëtti_, _kerç_, 
   {{0xb1140075,0x22417638,0xa49404d3,0xd1740572}},	//   اقلا_, seik_, _ئیست, шысы, 
   {{0xc35402e8,0x00000000,0x00000000,0x00000000}},	//   _съпъ, --, --, --, 
   {{0xfce57639,0x60dc0c89,0x290c01a9,0xfeb80b24}},	//   годо, _wirm, _ovga_, راات_, 
   {{0xdd90475c,0x8eb00202,0xb2180174,0x6da000f3}},	//   غوت_, زەكت, _klæn, бица, 
   {{0x60dc02d0,0xdb080419,0xab60009d,0x00000000}},	//   _uirm, _ozdô, өвчл, --, 
   {{0x290c0fac,0x764c0142,0x2d90013d,0x00000000}},	//   _avga_, ydcy, ирәс, --, 
   {{0x0024004b,0xf96827a8,0xf65c005c,0x7ac40108}},	//   _جګړو_, ерой_, mlæg_, ысле, 
   {{0xf65c037e,0x9f5800a2,0x9d5403e6,0x00000000}},	//   llæg_, _berç_, _خۆشت, --, 
   {{0x9f58003a,0xe934785c,0x00000000,0x00000000}},	//   _veræ_, اسيت_, --, --, 
   {{0xf65c04ce,0x6cd0e256,0xb5f80022,0x0bc401ec}},	//   nlæg_, _اقلا, ijáv, _ﺯﺍﻳﻮ, 
   {{0xf8a00323,0x99840618,0x00000000,0x00000000}},	//   ргүү, lamō_, --, --, 
   {{0x6d4c0077,0xb21800b5,0x25f439a1,0xb8641291}},	//   _ácat, _blæn, ंड़ी_, _ماثو, 
   {{0x9f5800fd,0x00000000,0x00000000,0x00000000}},	//   _kerä_, --, --, --, 
   {{0xbec0002e,0xf65c01bf,0xfcf40023,0x904400f2}},	//   _ñëwi, jlæg_, ፈለጠ_, ینره, 
   {{0xf65d763a,0x11f4036b,0x00000000,0x00000000}},	//   dlæg_, شترگ, --, --, 
   {{0x91c41b15,0xb21800b5,0x0594cdd1,0x21a80166}},	// [26df0] рәнл, _flæn, _پايگ, гәрү_, 
   {{0xf0080016,0xb21808a5,0x937800d8,0x00000000}},	//   _đẳng_, _glæn, _абот_, --, 
   {{0x2fc404f3,0x201c00d8,0xd54401e1,0x00000000}},	//   ång_, óvia_, bẹ̀t, --, 
   {{0xd1c8013d,0x0d980352,0x4dd8072d,0x00000000}},	//   _үлүе_, ктлы_, نواح_, --, 
   {{0x9db8088b,0x8d640212,0x3d281888,0x00000000}},	//   лышу_, рвле, نتوی_, --, 
   {{0xf1bc0248,0x00000000,0x00000000,0x00000000}},	//   _iyá_, --, --, --, 
   {{0x290c0076,0xadf0008e,0xca2c0150,0x00000000}},	//   _svga_, _гобә, _ﺩﻴﺭ_, --, 
   {{0x6f000311,0x9f5800a2,0x77780175,0x6ce400d4}},	//   âncu, _derä_, dytx, _біже, 
   {{0xf2dc022f,0xb905763b,0x290c0051,0x00000000}},	//   _miâ_, аныз_, _qvga_, --, 
   {{0x5d851fa6,0xdd7401ed,0x480400d1,0x00000000}},	//   _الكل, _دھمک, шпов, --, 
   {{0x0a1441ff,0x9c64086e,0x98540108,0x8f480240}},	//   _نواح, _دهلو, стыш, _ነዚኣቶ, 
   {{0x6d4c0005,0x7aec02fb,0x290c058a,0xb21801bf}},	//   _ácas, žité, _tvga_, _slæn, 
   {{0xb21800b5,0x9f585c17,0x00000000,0x00000000}},	//   _plæn, _terç_, --, --, 
   {{0x4758040e,0xc79403e6,0x00000000,0x00000000}},	//   _ария_, _پشتب, --, --, 
   {{0xf1bc01e1,0x00000000,0x00000000,0x00000000}},	//   _ayá_, --, --, --, 
   {{0xd90c04d3,0x2a7c1bce,0xc5f40139,0xbbe000bc}},	//   _تیی_, nkub_, _тякъ, _पल्क, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [26e00] --, --, --, --, 
   {{0x757823e4,0x9c7c01fa,0x2a7c00c5,0xdb08010e}},	//   _סטיפ, _kiče, hkub_, _aydý, 
   {{0xdb08003b,0x2a7c291e,0x7e293540,0x7fd80798}},	//   _åløs, kkub_, віла_, тфат_, 
   {{0xb17804f3,0xf65c0388,0x00000000,0x00000000}},	//   _igån, rlæg_, --, --, 
   {{0x44380656,0xb3000135,0x9c7c09a8,0xd8388256}},	//   _kbp_, _མཆོང_, _liče, liče_, 
   {{0x9f58005b,0xf65c005c,0xb5f801d3,0x7c3c0115}},	//   _perä_, plæg_, lját, ĵpro, 
   {{0x9c7c2a10,0xd838268d,0x7b65763c,0x4438045a}},	//   _niče, niče_, ртле, _mbp_, 
   {{0x2a7d763d,0xa2cc02ab,0x9f5800e4,0x2fc4002f}},	//   gkub_, _थीम्, _verä_, ünge_, 
   {{0x98b80598,0x4439763e,0xbc640064,0xeaac0b24}},	//   ллит_, _obp_, _квак, بعو_, 
   {{0x9f583596,0xd83800f3,0xb5f803b2,0x4438012d}},	//   _terä_, kiče_, hját, _nbp_, 
   {{0x6d4c2cd7,0xaadc1d72,0xd83800f3,0xb5f800e5}},	//   _ácar, _पंचक, jiče_, kját, 
   {{0x4439763f,0xd838012c,0x3ea57640,0x9db8031c}},	//   _abp_, diče_, nnot_, _བཪྙེ, 
   {{0x3ea57641,0x44397642,0x3ebc0de2,0xb5f801d3}},	//   inot_, _bbp_, _ëttu_, dját, 
   {{0xb9e00201,0x44397643,0x00000000,0x00000000}},	//   _ያሉ_, _cbp_, --, --, 
   {{0x4438e432,0xcf2002f5,0x00000000,0x00000000}},	//   _dbp_, _নন্দ_, --, --, 
   {{0xf008001e,0x78740165,0x64590790,0x88bc033f}},	//   _đằng_, _gâvr, _óvin, puśc, 
   {{0x1bf80c2e,0x7c397644,0xf2dc003a,0x3ea41404}},	// [26e10] ुराल_, _obtr, _viâ_, dnot_, 
   {{0xd8380232,0x3ce80dad,0x8e7c01e4,0xd5ec01fb}},	//   biče_, _चढ़े_, _miŝe, _hoà, 
   {{0xef640107,0x985c00ef,0x00000000,0x00000000}},	//   шъао, _zāģu_, --, --, 
   {{0x7c38c08d,0x3ea57645,0xb2180174,0x00000000}},	//   _abtr, gnot_, _klæm, --, 
   {{0x4254004b,0xdb081155,0x00000000,0x00000000}},	//   _انټر, _vydý, --, --, 
   {{0x8c457646,0x8af800ac,0xd5ec0051,0x00000000}},	//   секе, htəş, _loà, --, 
   {{0x2a7c00af,0x0b4401b9,0x4b5400a7,0xcebc0213}},	//   tkub_, ёнин, сълт, _atəş_, 
   {{0x9c7c0010,0x0a480276,0x00000000,0x00000000}},	//   _riče, узий_, --, --, 
   {{0x6e397647,0x00000000,0x00000000,0x00000000}},	//   _ibub, --, --, --, 
   {{0x6d58005a,0x888466b4,0xb21802d2,0x2a7c000d}},	//   _irua, слож, _slæl, skub_, 
   {{0x4438070d,0x25f47e29,0x00000000,0x00000000}},	//   _rbp_, ंडली_, --, --, 
   {{0x44380ac5,0x9c7c0e3c,0x8e7c0115,0xd83802f0}},	//   _sbp_, _viče, _fiŝe, viče_, 
   {{0xaca001f2,0x6e397648,0x2d8c000f,0x95991b70}},	//   _ndịo, _mbub, nzge_, атру_, 
   {{0xd8380bb8,0x68f97649,0x2d8c000f,0x9c7c0427}},	//   tiče_, mpud, izge_, _tiče, 
   {{0x6e382f99,0x97c40150,0xb5f801d3,0x06f41c43}},	//   _obub, _وتىم, tját, _استج, 
   {{0x6d582b3b,0x443801f5,0x291c02b1,0xb218032e}},	//   _orua, _wbp_, orua_, _flæm, 
   {{0x6d580457,0x44380156,0xb5f895f4,0xd8380122}},	// [26e20] _nrua, _tbp_, rját, siče_, 
   {{0x6e384437,0xa3040220,0x291c01c4,0xd83814b2}},	//   _abub, _мүге, irua_, piče_, 
   {{0x6e380083,0x6d59764a,0x3ea4007c,0x68f8003e}},	//   _bbub, _arua, tnot_, hpud, 
   {{0x6d59764b,0xb5f801ed,0x291c0240,0x69c8062d}},	//   _brua, ljár, krua_, _ozge, 
   {{0x6d59764c,0xce3400aa,0x32540375,0x6da00305}},	//   _crua, تونک, _הסכם_, пица, 
   {{0x442803a2,0x6e380521,0x6d59764d,0x291d3eca}},	//   ngb_, _ebub, _drua, drua_, 
   {{0x7f840491,0x6d59764e,0x291c00b0,0x3ea45b68}},	//   _الأن, _erua, erua_, pnot_, 
   {{0x6d59764f,0x201801c7,0xd1d4001f,0xb5f80174}},	//   _frua, _hdri_, _ጨርቅ_, hjár, 
   {{0x6d597650,0x442834fe,0x8e7c01e4,0x6d4c0077}},	//   _grua, kgb_, _fiŝb, _ácap, 
   {{0x97140861,0xf8488f99,0x8aa40137,0x7c380857}},	//   омоц, учий_, йрөд, _ubtr, 
   {{0xb2180008,0x69c8005a,0x2120011f,0x291d7651}},	//   _slæm, _ezge, hrih_, arua_, 
   {{0x291d7652,0x7c2808cb,0x9f587712,0x7c84010a}},	//   brua_, lgfr, _berú_, _куçе, 
   {{0xddc1225e,0xb5f801a8,0x2018892f,0x2120003e}},	//   _lomž, fjár, _odri_, jrih_, 
   {{0x7c28c506,0x2018020c,0xdef41772,0x201c0789}},	//   ngfr, _ndri_, _ውጥን_, óvil_, 
   {{0xd5ec01fb,0xb2a801c0,0x2898010f,0x00000000}},	//   _toà, гтаж_, _גיגא, --, 
   {{0x78b805ce,0xb87c01e4,0x22957653,0x7c28013f}},	//   lotv, _diƭe, пися, hgfr, 
   {{0x9098db74,0x7ae17654,0x225802f6,0x4428002f}},	// [26e30] ават_, _miot, щиты_, bgb_, 
   {{0x248404c4,0x7ae17655,0x2978008d,0x6d597656}},	//   ëmmt_, _liot, אטמא, _rrua, 
   {{0x7ae00270,0x21200548,0xd2502651,0xa3d8012d}},	//   _oiot, arih_, _قند_, ़ेद_, 
   {{0xddc009a8,0x7c28014b,0x6d58cd00,0x28cc17cb}},	//   _domž, egfr, _prua, _सीनि, 
   {{0x6d580083,0x849002d3,0x2bb8000d,0xd0d40395}},	//   _qrua, _ሃገሩን_, _ऊँहा, _момъ, 
   {{0xf00801fb,0x7c283be7,0x7ae17657,0xfcc400c7}},	//   _đặng_, ggfr, _aiot, ҩшәҟ, 
   {{0x78b82f61,0xdea4a268,0x6e3801ab,0x3208022a}},	//   dotv, _کینی, _tbub, _kecy_, 
   {{0x7ae17658,0x6d597659,0x6e382dab,0x291d765a}},	//   _ciot, _trua, _ubub, trua_, 
   {{0x6d59765b,0x6f040218,0x7ae1765c,0x291c02b5}},	//   _urua, _hwjc, _diot, urua_, 
   {{0x291d765d,0x78b8110c,0xb21800b5,0x7ae002d0}},	//   rrua_, gotv, _blæk, _eiot, 
   {{0x7ae1765e,0x68f8107d,0x027c0092,0x6d4947b2}},	//   _fiot, spud, _የፈጠራ_, lwga, 
   {{0x9f59765f,0x7ae17660,0x68f8162a,0x21200548}},	//   _perú_, _giot, ppud, yrih_, 
   {{0x6d4801af,0xfd4c00cd,0x78b8017a,0x69c8fcad}},	//   nwga, _bhiṣ, botv, _uzge, 
   {{0x7ae001c0,0xb2196da4,0xfd4c00b8,0x9c7c0010}},	//   _ziot, _flæk, _chiṣ, _kiča, 
   {{0x68e0021a,0x68e80bcd,0xfd4c00cd,0x44280175}},	//   _iind, _hugd, _dhiṣ, rgb_, 
   {{0x68e17661,0x44297662,0x20180a2e,0x3208002d}},	//   _hind, sgb_, _sdri_, _cecy_, 
   {{0x8490069c,0x68e09c1c,0x81e000bd,0x2018020b}},	// [26e40] _ሃገርን_, _kind, নুন_, _pdri_, 
   {{0x28cc089a,0x68e17663,0x68e97664,0x6ab80109}},	//   _सीमि, _jind, _mugd, houf, 
   {{0x68e17665,0x68e97666,0xd838ab3d,0xfde801d5}},	//   _mind, _lugd, niča_, адек_, 
   {{0x68e17667,0x80740597,0x1ccc031c,0xf554036b}},	//   _lind, _žĕĥô, _ླེང_, _الیب_, 
   {{0x7ae17668,0x9f580fac,0x6ab8aef5,0x7738001f}},	//   _riot, _lerø_, douf, _እያስተ, 
   {{0x68e17669,0x9c7c0471,0x7ae003a0,0x201807f5}},	//   _nind, _biča, _siot, _udri_, 
   {{0x78b82630,0x7ae1766a,0x6ab9766b,0x0b180451}},	//   votv, _piot, fouf, مريڊ_, 
   {{0x68e1766c,0x6285766d,0xd838db08,0x68e800ee}},	//   _aind, nkio, diča_, _bugd, 
   {{0x7ae008e5,0xf2d006a9,0x68e1766e,0xf09c0100}},	//   _viot, ועה_, _bind, _mwàn_, 
   {{0x23c0243c,0x20d00118,0x00000000,0x00000000}},	//   _शुभद, _तीमध, --, --, 
   {{0x68e1766f,0x7ae17670,0x9f580395,0x6ab826be}},	//   _dind, _tiot, _perù_, bouf, 
   {{0x68e0606b,0xe5700166,0xd83802e2,0x6a800408}},	//   _eind, _ağış, sfč_, _олха, 
   {{0x68e17671,0x8e7c01e4,0x78b802f0,0xf8a801f0}},	//   _find, _jiŝa, potv, _квдк_, 
   {{0x68e17672,0x8e7c01e4,0xd8383493,0xddc00055}},	//   _gind, _miŝa, biča_, _samś, 
   {{0xb21800b5,0x32097673,0x00000000,0x00000000}},	//   _ulæk, ихан_, --, --, 
   {{0x50f47855,0x6d480142,0x151401af,0x00000000}},	//   ззат, ywga, _едия, --, 
   {{0xf09c0100,0x55c40075,0x918000f7,0x00000000}},	// [26e50] _dwàn_, _хәнз, رۇسۇ, --, 
   {{0x6ef0003d,0x68e17674,0x80dc0c58,0xf36401a9}},	//   _aħba, _xind, যৱস্, _дтмн, 
   {{0x64900036,0xaca00208,0x94c800f1,0x00000000}},	//   _bäif, _luợn, _پاکې_, --, 
   {{0x9c7d7675,0x00000000,0x00000000,0x00000000}},	//   _riča, --, --, --, 
   {{0xbe10282b,0x248c02d5,0x3d04012c,0x270400e5}},	//   رووع, šimų_, सीले_, zőn_, 
   {{0x6ad001bc,0x270400e5,0x00000000,0x00000000}},	//   दग्र, yőn_, --, --, 
   {{0x68e8409c,0x6ab8b5da,0x5f28023a,0x00000000}},	//   _sugd, touf, _моём_, --, 
   {{0x68e17676,0x8e7c0115,0xd838ebf6,0xaca00ca8}},	//   _sind, _fiŝa, viča_, _iwọn, 
   {{0xe520ea74,0x6ab97677,0x00000000,0x00000000}},	//   _बिधि_, rouf, --, --, 
   {{0x68e17678,0x6ab97679,0x628405f5,0x9c7c0010}},	//   _qind, souf, zkio, _tiča, 
   {{0x68e08bab,0x6ab8009f,0x47c493fb,0x00000000}},	//   _vind, pouf, ябов, --, 
   {{0x68e14c65,0x6490007d,0x941000ac,0x68e8e0c4}},	//   _wind, _käig, mizə_, _tugd, 
   {{0x68e1767a,0x9c7c0010,0x64900037,0x645803b2}},	//   _tind, _mičn, _jäig, _óvik, 
   {{0x9c7cb485,0x68e0d325,0xd8388c05,0x78f8011a}},	//   _ličn, _uind, piča_, _הפסו, 
   {{0x9359767b,0x941000ac,0xf65c00b5,0x6490000d}},	//   орту_, nizə_, mlæn_, _läig, 
   {{0x9c7c5a54,0x62840024,0xaac818cc,0x7d140153}},	//   _ničn, ukio, ातिक, šysi, 
   {{0x6285767c,0xaca00241,0x941003b9,0x00000000}},	// [26e60] rkio, _awọn, hizə_, --, 
   {{0x8235767d,0x6285767e,0x71a001ee,0x941006be}},	//   _کردا, skio, хауз, kizə_, 
   {{0x649001c7,0xfe440108,0x00000000,0x00000000}},	//   _päif, знео, --, --, 
   {{0x64900221,0x6fb0029c,0xd05c03b9,0x2fd405af}},	//   _bäig, رمنا, _musə, سوند_, 
   {{0xa3d80dba,0x94740133,0x72d800d9,0x00000000}},	//   ़ेर_, _رپێچ, _לקטג, --, 
   {{0x941000ac,0x8e7c01e4,0xd83802e2,0x6da16dfb}},	//   fizə_, _viŝa, nnčt_, عموم, 
   {{0xdb081b0d,0x3d3c02b1,0xd05406be,0x0ef80006}},	//   _ölür, wāwā_, _nizə, _мэты_, 
   {{0x19c429db,0xdea407d6,0x64900108,0x00000000}},	//   мәлг, _کیچی, _häid, --, 
   {{0x649000c5,0x20d404e6,0x00000000,0x00000000}},	//   _käid, räif_, --, --, 
   {{0x64901b99,0xf65c01bf,0xa8000213,0x6ba400e5}},	//   _jäid, glæn_, _çılp, árgá, 
   {{0xec100046,0x91680241,0xaa840066,0x00000000}},	//   _سوند, _kọ́r_, زنیم_, --, 
   {{0x64900254,0xca3801e4,0x3689767f,0xaca00051}},	//   _läid, piŝa_, ссон_, _tuợn, 
   {{0xb21805ac,0x80bcc59b,0xe9dc00d7,0x00000000}},	//   _klæv, ्ताइ, žúr_, --, 
   {{0x649018db,0xa4e40006,0x9c7c00ef,0x00000000}},	//   _näid, еўск, _mičo, --, 
   {{0xd83800d0,0x662800e5,0x00000000,0x00000000}},	//   ličo_, áské, --, --, 
   {{0xe8dc0016,0x81d403d4,0x00000000,0x00000000}},	//   ược_, িখন_, --, --, 
   {{0xe1f0495f,0x649004e6,0x662802fb,0x9c7c00d0}},	// [26e70] اسف_, _bäid, šské, _ničo, 
   {{0x64900037,0x205401d5,0x00000000,0x00000000}},	//   _räig, нкуя, --, --, 
   {{0x6ee40075,0xd05403e3,0x9294009d,0x00000000}},	//   سسال, _xizə, _жанц, --, 
   {{0x9c7c02f0,0xad10010b,0x00000000,0x00000000}},	//   _bičo, епдә, --, --, 
   {{0x9c7c01a6,0xb21802d2,0x00000000,0x00000000}},	//   _vičn, _blæv, --, --, 
   {{0xea6000dd,0x18801954,0x705000ec,0x00000000}},	//   کھئی, _ይፈጥር_, _ڪنڀا, --, 
   {{0xfcf4001f,0x5f840150,0x9f9800f3,0x00000000}},	//   ፈለገ_, _كۇكە, _евру_, --, 
   {{0x941003be,0xc96401c6,0xd05406be,0xdef8030d}},	//   rizə_, двий, _rizə, _хыр_, 
   {{0xdd957680,0x6b8800b0,0xd05406be,0x00000000}},	//   _заты, _ōngā, _sizə, --, 
   {{0x5d54274b,0x64900037,0x88bc0210,0xe57801f0}},	//   _якут, _käie, muśk, ҷҷи_, 
   {{0xdb080267,0x00000000,0x00000000,0x00000000}},	//   _sydö, --, --, --, 
   {{0xdc7003a5,0xfcf40092,0x6b800051,0x00000000}},	//   _аҳәы, ፈለጉ_, myng, --, 
   {{0x6b817681,0xd8380419,0x00000000,0x00000000}},	//   lyng, cičo_, --, --, 
   {{0x98f400c6,0x9c7c0219,0xc7a400d8,0x00000000}},	//   _أثنا, _ničl, _оилк, --, 
   {{0xa3d8068f,0xfd540521,0x42540598,0xd3b57682}},	//   ़ें_, _babị, мтат, есть, 
   {{0x6490040e,0xb82003d4,0xf26401fe,0x00000000}},	//   _säid, ব্দত_, мисл_, --, 
   {{0x00e4b8eb,0x6b80015d,0x6490340f,0x00000000}},	// [26e80] джан, hyng, _päid, --, 
   {{0x8e7c01e4,0xca3801e4,0x64900166,0x35980023}},	//   _biŝo, kiŝo_, _qäid, _ቅሩባት_, 
   {{0x649000af,0x7f497683,0x8e7c0115,0x00000000}},	//   _väid, تلاق_, _viŝn, --, 
   {{0x64900036,0xb21803b2,0xbd88027d,0xca3801e4}},	//   _däie, _blæu, ينان_, diŝo_, 
   {{0x649000af,0x20d40254,0x00000000,0x00000000}},	//   _täid, täid_, --, --, 
   {{0xd6e80729,0x6b8000a9,0x8e7c010f,0xca380115}},	//   কীয়া_, fyng, _fiŝo, fiŝo_, 
   {{0x6b800cfd,0x649000af,0xceac3d48,0xdbb400c7}},	//   gyng, _käib, _бә_, хәаэ, 
   {{0xf1bc0597,0x5a340801,0xddc0010e,0xfcf4001f}},	//   _gcás_, хнит, _gamş, ፈለግ_, 
   {{0x20d40254,0x00000000,0x00000000,0x00000000}},	//   päid_, --, --, --, 
   {{0x7d017684,0x9c7c0552,0x0d481c4e,0x7c640220}},	//   mpos, _kičm, _عشقي_, _تارل, 
   {{0x7d017685,0xb21808ce,0x00000000,0x00000000}},	//   lpos, _klæt, --, --, 
   {{0x7d000064,0x00000000,0x00000000,0x00000000}},	//   opos, --, --, --, 
   {{0x7d017686,0xe5c40323,0xee3c010b,0x00000000}},	//   npos, всро, _öýe_, --, 
   {{0x7d000cf4,0x39440175,0x00000000,0x00000000}},	//   ipos, _ipos_, --, --, 
   {{0xdb097687,0x649004e6,0x7d00020b,0xe908031c}},	//   _äläs, _bäib, hpos, _གསོབ_, 
   {{0x320c01ed,0xd7f80311,0x7d017688,0x62480108}},	//   úgy_, lcă_, kpos, мчуг_, 
   {{0x7d017689,0x9c7c0427,0x81e00154,0x00000000}},	// [26e90] jpos, _pičl, নুস_, --, 
   {{0xd7f800a8,0xb21802d2,0x9f588f63,0x00000000}},	//   ncă_, _alæt, _neró_, --, 
   {{0x2fc404ce,0x7d001730,0x9f5008a7,0x3944010a}},	//   æng_, epos, ðaði_, _lpos_, 
   {{0xbf7001ec,0x9294399f,0x39445aae,0x6b8000e4}},	//   ықсы, _чамц, _opos_, vyng, 
   {{0x7d01768a,0x3945768b,0x8c440276,0x6eb000dc}},	//   gpos, _npos_, ееле, ेकबु, 
   {{0x6490033d,0x6b80b5cd,0x81e00183,0x20d40037}},	//   _täie, tyng, নুহ_, täie_, 
   {{0xce9406bb,0x7d01768c,0x3945768d,0xb2180feb}},	//   _завъ, apos, _apos_, _flæt, 
   {{0x42d40150,0x7d000393,0xb218032e,0x00000000}},	//   _ءﺩﺍﭖ_, bpos, _glæt, --, 
   {{0xb17800cc,0x2908180f,0x7d0001bf,0x0d200137}},	//   _egåv, èca_, cpos, _сүлү, 
   {{0x9c7c0427,0xca3800df,0xc79404b4,0x00000000}},	//   _ličj, piŝo_, ермы, --, 
   {{0x39449546,0x649004e6,0x00000000,0x00000000}},	//   _epos_, _läic, --, --, 
   {{0x28cc1533,0xd7f80276,0x3944010a,0xd04c01e4}},	//   _सीरि, acă_, _fpos_, jpaɾ, 
   {{0x649004d1,0xe9a80214,0x04b40138,0xd9140006}},	//   _näic, _بدان_, есвя, _адчы, 
   {{0xd8000408,0x00000000,0x00000000,0x00000000}},	//   _вăр_, --, --, --, 
   {{0x7d01768e,0xb5f80306,0x00000000,0x00000000}},	//   zpos, ddáf, --, --, 
   {{0x7d01768f,0x98a400e2,0x39440175,0x00000000}},	//   ypos, mumā_, _ypos_, --, 
   {{0x3944010a,0x98a400e2,0x00000000,0x00000000}},	// [26ea0] _xpos_, lumā_, --, --, 
   {{0x65657690,0xb218553d,0x649004e6,0x7d000158}},	//   _irih, _blæs, _däic, vpos, 
   {{0x7d00a8cf,0x8e7c01e4,0x7e440108,0x00000000}},	//   wpos, _tiŝl, ехле, --, 
   {{0x81e003f4,0x7d0004b9,0x9f58004e,0x65640200}},	//   নুষ_, tpos, _seró_, _krih, 
   {{0x9f5856ed,0x7d000118,0x645c0254,0x00000000}},	//   _peró_, upos, odri, --, 
   {{0x645d7691,0x98a40029,0x7d00ccab,0x6564020c}},	//   ndri, kumā_, rpos, _mrih, 
   {{0x98a40029,0x39457692,0x7d017693,0x645d7694}},	//   jumā_, _spos_, spos, idri, 
   {{0x65657695,0x7d017696,0x39440175,0x82cc031c}},	//   _orih, ppos, _ppos_, _ཉེསའ, 
   {{0xb2180212,0xdce40022,0x81e0015b,0x9f580022}},	//   _klær, _абаҩ, নুর_, _teró_, 
   {{0xada05ab1,0x645d7697,0x9c7ca7ab,0x313408c3}},	//   _саул, jdri, _mičk, ענים_, 
   {{0x6564f213,0x56957698,0xd7f8084c,0x37a96328}},	//   _arih, вант, rcă_, ятин_, 
   {{0xd7f800a8,0x3944079b,0x65640010,0x80bc0490}},	//   scă_, _tpos_, _brih, ्तुं, 
   {{0x39441c06,0x656418b0,0x9c7c0010,0xb4d800db}},	//   _upos_, _crih, _ničk, ntàg, 
   {{0x645d0929,0x656405da,0x81d402f5,0x64900221}},	//   gdri, _drih, িখা_, _räic, 
   {{0x32657699,0x22400af5,0x6565769a,0x98a400da}},	//   нтав, ffik_, _erih, cumā_, 
   {{0x6565769b,0xe375769c,0x81e000cc,0x9c7c25ad}},	//   _frih, ылсы, _ন্ধ_, _bičk, 
   {{0xb219769d,0xdc3c01fa,0x6565769e,0x764c04ce}},	// [26eb0] _blær, _ašči, _grih, mecy, 
   {{0x764d553c,0x22416ba6,0x15f801ad,0xb8200154}},	//   lecy, afik_, ंडकर_, ব্রত_, 
   {{0x65640219,0x3ea40311,0x64900036,0x81e0015b}},	//   _zrih, fiot_, _wäic, নুল_, 
   {{0x9f59769f,0x764d76a0,0x6ec406b3,0x9c7c0010}},	//   _però_, necy, رتاق, _fičk, 
   {{0x787407a8,0x06d404c5,0x6564031c,0x93f401f9}},	//   _wâvy, _সংমি, _xrih, _आलाच_, 
   {{0x9f58bfc1,0x64900037,0x8c440354,0xb2181d1d}},	//   _verò_, _käia, теке, _glær, 
   {{0xdfd576a1,0x3ea40129,0xb21801bf,0x1a683451}},	//   _боры, biot_, _ulæs, کینی_, 
   {{0x7bf40598,0x9f580086,0x98a400e2,0x645c0841}},	//   ннәр_, _terò_, vumā_, zdri, 
   {{0x9f58003a,0x764d76a2,0xac10010a,0x00000000}},	//   _uerò_, decy, _йĕпе_, --, 
   {{0x752c060a,0x98a4005f,0x65640240,0x787c0118}},	//   ducz, tumā_, _rrih, _návě, 
   {{0x2ca576a3,0x764c0f85,0xbc78010f,0x00000000}},	//   mind_, fecy, _קװעט, --, 
   {{0x656576a4,0x2ca576a5,0x98a400da,0x645d76a6}},	//   _prih, lind_, rumā_, wdri, 
   {{0xb3dc0154,0x224176a7,0xa82001d9,0x98a40a2f}},	//   _ব্লজ, vfik_, _یکھن, sumā_, 
   {{0x2ca576a8,0x9c7c01fa,0x98a4005f,0x668401ed}},	//   nind_, _ričk, pumā_, ئیکل, 
   {{0xe3b80598,0x3ea40086,0x764c00b5,0xd87404b3}},	//   çı_, yiot_, becy, _حانب, 
   {{0x2ca576a9,0x9c7c2230,0x05643bd4,0x39bc01f2}},	//   hind_, _pičk, _авин, ịse_, 
   {{0x22400af5,0x2ca4325d,0x656401b2,0x3ea576aa}},	// [26ec0] rfik_, kind_, _urih, viot_, 
   {{0x69c80731,0x8e7c010f,0x04c800c6,0x9f58032e}},	//   _myge, _fiŝk, _زوجي_, _berð_, 
   {{0x50b5646b,0x3ea576ab,0x43740276,0xe3e801d5}},	//   усту, tiot_, _рупт, _سکسن_, 
   {{0x787c0316,0x2ca403b2,0x8e7576ac,0x00000000}},	//   _závě, eind_, лучч, --, 
   {{0x3ea576ad,0x645809f3,0x2ba47dad,0x201c00d8}},	//   riot_, _óvis, _केबा, óvis_, 
   {{0x9f581ffb,0x031405f9,0x9c7c00f3,0x2ca576ae}},	//   _ferð_, _तबाह_, _kiči, gind_, 
   {{0x9f581873,0x764c00ca,0xdc3c0010,0x3ea4c1be}},	//   _gerð_, yecy, _ušči, piot_, 
   {{0x69c86739,0xab8176af,0xaa6176b0,0x9c7c36dd}},	//   _byge, рушк, атьк, _miči, 
   {{0x2ca56f79,0x9c7c0b3d,0xb8640472,0x00000000}},	//   bind_, _liči, نادو, --, 
   {{0x2bb80c2e,0x2ca576b1,0xeb3000cf,0x00000000}},	//   _ऊँचा, cind_, _چىلد, --, 
   {{0x80bc02f5,0x9c7c3858,0x764c0223,0x69c86367}},	//   ্গপ্, _niči, tecy, _eyge, 
   {{0x752c0034,0x69c801bf,0x00000000,0x00000000}},	//   tucz, _fyge, --, --, 
   {{0x69c91c6b,0xa2b8102f,0x25f40037,0x98a40356}},	//   _gyge, ्कन्, ूड़ी_, gumă_, 
   {{0x752c1570,0x9c7c0006,0x764c014b,0x80bc000d}},	//   rucz, _biči, secy, ्तों, 
   {{0x8e7c0115,0x764c0223,0xf2c576b2,0x77900133}},	//   _fiŝh, pecy, всан, _ڕیگا, 
   {{0x9c7c0e3c,0xd8380ebd,0x2ca576b3,0x00000000}},	//   _diči, diči_, zind_, --, 
   {{0xc0dc02d3,0x6ef0031c,0xb5f80077,0x9c7c0064}},	// [26ed0] _ንሶም_, _iħbi, rdád, _eiči, 
   {{0x5454283c,0x81e005ac,0x00000000,0x00000000}},	//   _свот, _ন্হ_, --, --, 
   {{0x2ca576b4,0x649000af,0xf53c007c,0xa0c40b24}},	//   vind_, _käin, ltå_, جيلو, 
   {{0x9f581873,0x8e7c01e4,0xb2180008,0xf09c01ab}},	//   _verð_, _kiŝi, _glæp, _stàd_, 
   {{0x2ca576b5,0x1d34d7b1,0x649001c7,0x20d401c7}},	//   tind_, инця, _mäin, mäin_, 
   {{0x6ac84ead,0x69c804ce,0x649000af,0x8e7c01e4}},	//   ात्र, _ryge, _läin, _miŝi, 
   {{0x2ca576b6,0x69c804ce,0xcac80c75,0x98a40356}},	//   rind_, _syge, нгке_, zumă_, 
   {{0x2ca576b7,0x649005a7,0xb4d800cf,0x69301bf4}},	//   sind_, _näin, ntàb, لکتر, 
   {{0x2ca576b8,0x08c4e0dd,0x6448000d,0x00000000}},	//   pind_, лбин, õdik, --, 
   {{0xdd95367e,0x69c86f6a,0x2ca40240,0x20d404e6}},	//   _тауы, _vyge, qind_, häin_, 
   {{0x64900036,0x69c91592,0x20d401f4,0xca2c0150}},	//   _bäin, _wyge, käin_, _ﺩﻴﺙ_, 
   {{0x69c976b9,0xf53c05ac,0x20d401f4,0xcb600023}},	//   _tyge, ftå_, jäin_, ተደለየ_, 
   {{0xb6a0b132,0x64900036,0x9c7c0064,0x19940024}},	//   сиял, _däin, _siči, _каця, 
   {{0x9c7c009b,0xb21802d2,0x00000000,0x00000000}},	//   _piči, _slæp, --, --, 
   {{0xa28412ea,0x92f401ec,0xd7f800f3,0x00000000}},	//   لیدو, ичті, _руч_, --, 
   {{0xd1bc0020,0x8e7c00df,0xd8380010,0x9c7c00c0}},	//   ተሰቡ_, _fiŝi, viči_, _viči, 
   {{0x527576ba,0x00000000,0x00000000,0x00000000}},	// [26ee0] шуру, --, --, --, 
   {{0xd8382a92,0x9c7c549d,0xe05800f1,0x00000000}},	//   tiči_, _tiči, خیست_, --, 
   {{0x4438b7be,0x82a48e21,0x00000000,0x00000000}},	//   _icp_, _банж, --, --, 
   {{0x44380230,0x425476ac,0x98a40024,0xd8380010}},	//   _hcp_, _стот, mumą_, riči_, 
   {{0xd1741248,0xd8380122,0x98a40024,0xd24c0014}},	//   _кыры, siči_, lumą_, _زۆل_, 
   {{0xbb1873c5,0x44380334,0xd83853f5,0x6e30035b}},	//   ىزعا_, _jcp_, piči_, ахәх, 
   {{0x44393aa3,0xe5140882,0x2ba4c8ce,0x9b948c91}},	//   _mcp_, तीति_, _केदा, рийц, 
   {{0x6f000137,0x9c7c0010,0xa3bc01ad,0x705000e5}},	//   ínce, _ničv, _आखन_, _پنہا, 
   {{0x443801e7,0x2bc458c7,0x98b80166,0xb4d800db}},	//   _ocp_, кләп_, клит_, ntàc, 
   {{0x3154025f,0x44380652,0xfce4bb7a,0x64904abe}},	//   ניין_, _ncp_, _созо, _säin, 
   {{0xb864034c,0x6490023a,0x7dd80139,0xab2495a2}},	//   ناگو, _päin, _fäsí, _боха_, 
   {{0xd1bc0125,0x7b140022,0xb86403e6,0xf53c0158}},	//   ተሰብ_, _адҧх, _ڕابو, ttå_, 
   {{0x443976bb,0x649025e4,0xcb600023,0x60dc002f}},	//   _bcp_, _väin, ተደልየ_, _ohrm, 
   {{0x8e7c0115,0x7c380175,0x649004e6,0x20d40036}},	//   _viŝi, _jctr, _wäin, wäin_, 
   {{0x569576bc,0x65680882,0x98a40024,0x20d576bd}},	//   _вайт, ādha, gumą_, täin_, 
   {{0x2258cf10,0x22840137,0x64900108,0x00000000}},	//   лисы_, бууг, _häil, --, 
   {{0x7c3976be,0x9f580124,0x64900036,0x1da466eb}},	// [26ef0] _octr, _merõ_, _käil, _खेलत, 
   {{0x443976bf,0x60dc0fac,0x98a40024,0xaee0002b}},	//   _gcp_, _chrm, bumą_, _koṇa, 
   {{0x20d4049b,0x56540023,0x9f054f62,0xdd9400c7}},	//   päin_, _ዝማዕበ, مولو, ҩахы, 
   {{0xd8383a4a,0x60dc769b,0x9c7c15b2,0x64900036}},	//   miču_, _ehrm, _miču, _läil, 
   {{0xa18401af,0x00000000,0x00000000,0x00000000}},	//   _лырл, --, --, --, 
   {{0x649002f6,0x60dc0175,0x1da40073,0x7c700116}},	//   _näil, _ghrm, _खेळत, оғуч, 
   {{0xd8381aff,0x0b581de6,0x00000000,0x00000000}},	//   niču_, трлы_, --, --, 
   {{0xca84152d,0x7c3976c0,0x3dd0012d,0x00000000}},	//   ргий, _ectr, żywa_, --, 
   {{0x6e3868d7,0x649004e6,0xb5f802f0,0x00000000}},	//   _icub, _bäil, zdác, --, 
   {{0x6d5976c1,0x28cc09bb,0x47c80154,0x00000000}},	//   _isua, _सीखि, _রণবী, --, 
   {{0x443804ce,0x4a740276,0x6d5800d8,0xabb0035b}},	//   _rcp_, _вылт, _hsua, _уажә, 
   {{0x9c7c007f,0x06d400fe,0x39bc02e3,0xf77004da}},	//   _chčf, _সংহি, ịsa_, زاپ_, 
   {{0x44380334,0x8e7c01e4,0x80b800dc,0x249976c2}},	//   _pcp_, _fiŝv, ्वमे, thrm_, 
   {{0x649001c7,0x46680daf,0x20d40036,0x98a40024}},	//   _gäil, хрүм_, gäil_, tumą_, 
   {{0x68f83df1,0x00000000,0x00000000,0x00000000}},	//   lqud, --, --, --, 
   {{0x020576c3,0x602800da,0x6d580134,0x98a40006}},	//   рзан, zīmē, _osua, rumą_, 
   {{0x291c016b,0x2ba40490,0x44380d63,0xb6c800e5}},	// [26f00] nsua_, _केसा, _tcp_, _جاوے_, 
   {{0xa49453f3,0x6e380005,0x649000af,0x291d76c4}},	//   _ایست, _acub, _käim, isua_, 
   {{0x6d580134,0x291c0421,0x765c058a,0x64900641}},	//   _asua, hsua_, _yaqy, _jäim, 
   {{0xfe700075,0x82902002,0x291d76c5,0xf4000327}},	//   غدا_, _بۇرچ, ksua_, _མཅོད_, 
   {{0xe2980124,0x6da0010b,0x649001f4,0x00000000}},	//   _ааҟ_, оица, _läim, --, 
   {{0x6e380117,0x21200c6a,0x60dc0112,0x2ba4000d}},	//   _ecub, msih_, _uhrm, _केहा, 
   {{0x201976c6,0x6d5897c7,0x9f5800c7,0x21200010}},	//   _ieri_, _esua, _perõ_, lsih_, 
   {{0xe8dc01dc,0x6490102e,0x9c7c00ef,0x8e740408}},	//   ước_, _säil, _riču, _лууч, 
   {{0x7c38208d,0x5ecc015b,0x68f80472,0xed540500}},	//   _tctr, িষদে, gqud, _кот_, 
   {{0x201976c7,0x7e6176c8,0x2ba42017,0x21200429}},	//   _jeri_, ldop, _केवा, isih_, 
   {{0x20182af2,0x291d76c9,0x2120020c,0x00000000}},	//   _meri_, asua_, hsih_, --, 
   {{0x20180c11,0x21201060,0x7bd8ebe2,0xf8a001c0}},	//   _leri_, ksih_, _iztu, сгүү, 
   {{0x3a2405b1,0x21200097,0x201803cb,0xda7801e0}},	//   _idop_, jsih_, _oeri_, _аяҙ_, 
   {{0x201976ca,0xd8380989,0x765c02d1,0x649001f4}},	//   _neri_, tiču_, _waqy, _häij, 
   {{0x61ec03be,0xa878008f,0x765cba3d,0x241976cb}},	//   ənlə, _באגר, _taqy, росы_, 
   {{0x201976cc,0xa8001ae4,0xd8380e3c,0x7e6001f5}},	//   _aeri_, _çırp, riču_, jdop, 
   {{0x201976cd,0x7e6176ce,0x212003a2,0x5fad1487}},	// [26f10] _beri_, ddop, gsih_, _टेबल, 
   {{0x201976cf,0x7e6001f5,0xd83802e2,0x7bd976d0}},	//   _ceri_, edop, ngč_, _oztu, 
   {{0x201976d1,0x6d5976d2,0x2120102c,0xa85402e4}},	//   _deri_, _ssua, asih_, שיבה_, 
   {{0x201945a1,0x7e600b4f,0x752c033f,0x2ba400cd}},	//   _eeri_, gdop, orcz, _केषा, 
   {{0x7bd801c4,0x79940034,0xc278008f,0x00000000}},	//   _aztu, _żywn, _ערשי, --, 
   {{0x201976d3,0xaf346728,0x7e60017a,0x3a240356}},	//   _geri_, _پرست, adop, _adop_, 
   {{0x0fe40c58,0x6e380477,0x06cc0154,0x7e60002b}},	//   _প্ৰধ, _tcub, রগতি, bdop, 
   {{0x6d580190,0x291cfcc5,0x201976d4,0x64900037}},	//   _tsua, tsua_, _zeri_, _räim, 
   {{0xdea576d5,0x2018373d,0x6d58d5c5,0x291d76d6}},	//   _بینی, _yeri_, _usua, usua_, 
   {{0x291d5f8a,0x3e6c022e,0x9b6800c7,0x00000000}},	//   rsua_, lаtа_, ушәа_, --, 
   {{0x291d76d7,0x46e800f7,0x06e80228,0x21200007}},	//   ssua_, лдон_, лмок_, zsih_, 
   {{0xa9240006,0x6490000d,0x291c01f4,0xabc001ec}},	//   _pažį, _väim, psua_, _ﺨﻼﻓﺎ, 
   {{0xa2b80882,0xaca00208,0xf79401b9,0x00000000}},	//   ्कस्, _ngừo, لنیب_, --, 
   {{0x41b40184,0x2120110c,0x7e600306,0xb5f803b2}},	//   ҡсат, vsih_, zdop, rdáa, 
   {{0x212006a3,0x201976d8,0x6490005b,0x00000000}},	//   wsih_, _reri_, _häik, --, 
   {{0x2720956f,0x201976d9,0x649000c5,0xb5f801d3}},	//   mın_, _seri_, _käik, ldán, 
   {{0x272005f3,0xd6a80330,0x649016ca,0x644801a9}},	// [26f20] lın_, _خدوم_, _jäik, еdit, 
   {{0x21208590,0x230805d9,0x7e600034,0xb4d800cf}},	//   rsih_, _نڪري_, wdop, ltàn, 
   {{0x272176da,0x2a7c72e2,0x64903110,0xbc240131}},	//   nın_, kjub_, _läik, ەربى, 
   {{0xb4d976db,0x201976dc,0xf1bc0248,0x21200cf4}},	//   ntàn, _weri_, _idán_, psih_, 
   {{0x201976dd,0x7bd8006d,0x272007b3,0x660418f7}},	//   _teri_, _sztu, hın_, _mfik, 
   {{0x40940491,0x27200d9c,0x20180381,0xccf80055}},	//   _السر, kın_, _ueri_, _duś_, 
   {{0xa3e009d9,0x660400aa,0x7b6400ee,0xc61c0eac}},	//   _तरफ_, _ofik, стле, _থানা_, 
   {{0x27202799,0x649001c7,0x20d400c5,0x8e380150}},	//   dın_, _bäik, käik_, _ەسەر_, 
   {{0xf65c2c95,0x67200267,0x64900108,0x78e87e7e}},	//   klær_, _avnj, _väij, льов_, 
   {{0x660576de,0x8e7c01e4,0x272006b9,0xd83800e2}},	//   _afik, _fiŝs, fın_, vičs_, 
   {{0x2721677c,0x7bd800da,0xf1bd0358,0xfaa40114}},	//   gın_, _uztu, _ndán_, _лажо, 
   {{0xda700014,0x6490005b,0x1ddc00e1,0x00000000}},	//   _زُت_, _häih, _बरात, --, 
   {{0xf1bd3a9e,0x81cc00eb,0x00000000,0x00000000}},	//   _adán_, ষেত_, --, --, 
   {{0x7af976df,0x27200bfc,0xe98402dd,0x7854028e}},	//   _kutt, bın_, _دامۋ, _ایدز_, 
   {{0x7af976e0,0x92a8052f,0x66040589,0x2720050e}},	//   _jutt, асаҡ_, _ffik, cın_, 
   {{0x7af976e1,0xb4d976e2,0xddc000cd,0x81e0009e}},	//   _mutt, ctàn, _camū, দশন_, 
   {{0x7af976e3,0xe1f000c6,0xddc00055,0x65940117}},	// [26f30] _lutt, فسك_, _damū, _наъу, 
   {{0x7af976e4,0x6490023a,0x00000000,0x00000000}},	//   _outt, _näih, --, --, 
   {{0x7af976e5,0x8f5403cc,0x550400d1,0x00000000}},	//   _nutt, تناش, _учқа, --, 
   {{0x8d943baf,0x316801a6,0x630401d3,0x483c0092}},	//   يلاش, _trcz_, _ڈویل, ባሳደሮ, 
   {{0x2720956f,0x823804ac,0x7af8049b,0xa2b8002b}},	//   zın_, _דערצ, _autt, ्कर्, 
   {{0x27200ba5,0x7af8c2ce,0x6490ac03,0x251c008f}},	//   yın_, _butt, _räik, נווא, 
   {{0x2720654f,0x6f040054,0x28a8038e,0x7af81382}},	//   xın_, _utjc, टोफि, _cutt, 
   {{0x7af976e6,0x6490007d,0xf78803ee,0x2720ce56}},	//   _dutt, _päik, _maçı_, vın_, 
   {{0x7af80076,0xc98400c6,0xfaa42099,0x2a7c0037}},	//   _eutt, تشغي, تجوی, rjub_, 
   {{0x272012ca,0x6490033d,0x8cc000d1,0x2d8c005c}},	//   tın_, _väik, _تەتۈ, myge_, 
   {{0x7af8a805,0x64900036,0x6cc001e0,0xb5f81bbf}},	//   _gutt, _wäik, _диҡҡ, rdán, 
   {{0x272005f3,0xf09c0ffb,0x229c01e1,0x64900254}},	//   rın_, _otào_, _kíke_, _täik, 
   {{0x27200abc,0xdce000a8,0xb4d91b40,0x6aa82076}},	//   sın_, _urmă, rtàn, _imgf, 
   {{0xb4d8e848,0x272007c4,0x7af976e7,0x443d1e03}},	//   stàn, pın_, _yutt, üt_, 
   {{0x27202523,0xaca0001e,0x430805d9,0xb4d804cc}},	//   qın_, _huỳn, شيءَ_, ptàn, 
   {{0x660576e8,0xb5f976e9,0xf65c0158,0x97d80ada}},	//   _ufik, ndál, slær_, _اظهر_, 
   {{0x229c01e1,0x80a974e9,0x6448000d,0x00000000}},	// [26f40] _níke_, авав_, õdis, --, 
   {{0x6fc800c5,0x644801e4,0x35503fb8,0x00000000}},	//   _तुहू, ĵdis, _کنیز, --, 
   {{0xfca800f1,0x649001f4,0xddc00055,0xb81c00cc}},	//   یاتو_, _räih, _tamū, _দামত_, 
   {{0x82352596,0x649001f4,0xb5f801ef,0x00000000}},	//   _بردا, _säih, jdál, --, 
   {{0x7af976ea,0x649002f6,0xb5f8011f,0xc0e54541}},	//   _sutt, _päih, ddál, _момк, 
   {{0xa5c401e1,0x7af976eb,0xbb2976ec,0x00000000}},	//   _gbóń, _putt, ацие_, --, 
   {{0x46c86236,0x7af90c64,0x9f980022,0x00000000}},	//   रवाह, _qutt, páña_, --, 
   {{0xd05c016b,0x2d8c12e8,0xd7f80356,0x80b8043e}},	//   _wusɔ, byge_, rdăm_, ्ववे, 
   {{0x9c7c033b,0x7af8677c,0xefc40023,0x2c0800cd}},	//   _chčc, _wutt, ጽዋይ_, _स्वं_, 
   {{0x7af86cce,0xdea483eb,0xed5406ed,0x00000000}},	//   _tutt, _بیچی, _фоф_, --, 
   {{0x7af976ed,0xdc3cb0e8,0x00000000,0x00000000}},	//   _uutt, _ašći, --, --, 
   {{0x76a80c9e,0xc764515c,0x00000000,0x00000000}},	//   ртов_, ساپى, --, --, 
   {{0xf990dcb5,0xf7881432,0x28c40764,0xe9d40395}},	//   _تبا_, _saçı_, रकशि, _дкц_, 
   {{0x7ae0014b,0xa90401e2,0x00000000,0x00000000}},	//   _hhot, _بيول_, --, --, 
   {{0x7ae176ee,0x56940137,0xb5f803b2,0x629800c0}},	//   _khot, _накт, ldám, _įvor, 
   {{0xb374044e,0x00000000,0x00000000,0x00000000}},	//   _ኪኸውን_, --, --, --, 
   {{0x7ae176ef,0x78b801f5,0xef2c0208,0xb5f976f0}},	// [26f50] _mhot, ontv, _đựoc_, ndám, 
   {{0x7ae176f1,0xb5f801ed,0x229c0241,0xd39401ee}},	//   _lhot, zdál, _ríke_, _еҙгә_, 
   {{0x7ae176f2,0xb4d8026c,0x4254004b,0xfcf40092}},	//   _ohot, ntàm, _کنټر, ገወጥ_, 
   {{0x7ae0063f,0x00000000,0x00000000,0x00000000}},	//   _nhot, --, --, --, 
   {{0x427804ae,0xb5f803b2,0x00000000,0x00000000}},	//   _הארג, vdál, --, --, 
   {{0x7ae176f3,0x649004e6,0x2d8c005c,0x00000000}},	//   _ahot, _däiw, ryge_, --, 
   {{0x7ae176f4,0x2b5404fb,0x2d8c00b5,0xdfd4f628}},	//   _bhot, تیاد_, syge_, _жоры, 
   {{0x7ae176f5,0x78b80334,0x2ea401d3,0x5e6400d1}},	//   _chot, entv, _بھئی_, _يۆلە, 
   {{0xaca0001e,0x07f805f5,0x7ae000a3,0x05a806e3}},	//   _quỳn, йхны_, _dhot, _चेंब, 
   {{0x7ae176f6,0x6c944352,0x6490005b,0xd90c1d10}},	//   _ehot, _بشرط, _häiv, جیو_, 
   {{0x9b747467,0x7ae00354,0x6490007d,0x06c800db}},	//   _يامص, _fhot, _käiv, йгой_, 
   {{0x7ae00842,0xf1bc011f,0x86980261,0xfb880131}},	//   _ghot, _adám_, стот_, _уруқ_, 
   {{0x9f5800fe,0x6ab801f7,0xa7a400c7,0x00000000}},	//   _ifrå_, mnuf, скҟа_, --, 
   {{0xdf9401e1,0x7ae00122,0x7d040098,0x39e001e0}},	//   _bọ́s_, _zhot, _ékse, _яҙығ, 
   {{0xb4d800db,0x7ae000b5,0x00000000,0x00000000}},	//   ctàm, _yhot, --, --, 
   {{0x6ab976f7,0x7afc5cca,0xd5ac0f31,0x7ae00076}},	//   nnuf, ípti, اہی_, _xhot, 
   {{0x26c001e1,0x6ab8002f,0x00000000,0x00000000}},	// [26f60] _ijio_, inuf, --, --, 
   {{0x6ab80d16,0x00000000,0x00000000,0x00000000}},	//   hnuf, --, --, --, 
   {{0xd4c576f8,0x6ab801f5,0x20d40254,0xa3e005c0}},	//   _تغيي, knuf, käiv_, _तरि_, 
   {{0x6274215c,0x01a800ec,0xe2980244,0x00000000}},	//   _تۇرئ, _هُجي_, _بێرت_, --, 
   {{0x7ae002c4,0x68e0009a,0x26c00036,0xdb140162}},	//   _rhot, _ohnd, _mjio_, _óbúg, 
   {{0x7ae176f9,0x82340244,0x6ab8000d,0x1bd408da}},	//   _shot, _برگا, enuf, моля, 
   {{0x7ae176fa,0xbf140150,0x64900036,0xe81c033f}},	//   _phot, _ءورب, _wäiw, _मज़ा_, 
   {{0x7ae001ee,0x9c7c01ab,0x628576fb,0x68e0002f}},	//   _qhot, _dhča, njio, _ahnd, 
   {{0x81cc03f4,0x7ae176fc,0xada009a5,0xfcd4007b}},	//   ষের_, _vhot, _затл, _فيرج, 
   {{0x2db400c8,0xb5f96940,0x8c9400d4,0xba44013a}},	//   _זלמן_, rdám, _орхі, dhůř, 
   {{0x7ae176fd,0x1634c6dd,0x7a3405d1,0x78b80fac}},	//   _thot, меня, gütü, rntv, 
   {{0x78b805be,0xeb9404ae,0x68e002d0,0xb4d856eb}},	//   sntv, _מדבר_, _ehnd, rtàm, 
   {{0xb4d85d7e,0x7d0176fe,0x00000000,0x00000000}},	//   stàm, nqos, --, --, 
   {{0xd8a800b2,0x81e0015b,0xe72c0214,0xe9240327}},	//   _گهڻو_, দশা_, خصی_, _ལྗིབ_, 
   {{0x67d10ee8,0xb5f976ff,0xf7e800db,0x7d0001a9}},	//   _пошу, ndák, _ارشى_, hqos, 
   {{0x628402d3,0x35440510,0xb5f801d3,0x00000000}},	//   gjio, _ехов, zdáj, --, 
   {{0x64480137,0xb4d80109,0x00000000,0x00000000}},	// [26f70] òdic, ntàk, --, --, 
   {{0xa5d800c6,0x00000000,0x00000000,0x00000000}},	//   _عبير_, --, --, --, 
   {{0x6490426d,0xda1c0b26,0x00000000,0x00000000}},	//   _päiv, नरात_, --, --, 
   {{0xb8dc2fb5,0xa3bc0490,0x1ca8025c,0x5f74036b}},	//   _ཁམ_, ेअर_, _བཏུ_, عالر, 
   {{0x39440218,0x7d00014b,0xdd940006,0x6ab803b2}},	//   _nqos_, gqos, нацы, vnuf, 
   {{0x7a340790,0x00000000,0x00000000,0x00000000}},	//   yütü, --, --, --, 
   {{0x65680882,0x7d0123b3,0x212c0055,0x00000000}},	//   ādhi, _pãrã, _ādhi_, --, 
   {{0x68e002d3,0x229c0248,0x64900108,0xa3e0230e}},	//   _shnd, _kíka_, _häit, _तरस_, 
   {{0x9f5802e2,0x6490007d,0xdd9000aa,0x00000000}},	//   _agrè_, _käit, _یوې_, --, 
   {{0x290800da,0x64917700,0x6ab80b4f,0xb0bc072e}},	//   īca_, _jäit, snuf, ्विग, 
   {{0x229c1c38,0x07a4134b,0x77c401c0,0x20d40254}},	//   _líka_, фанн, длэг_, päiv_, 
   {{0x7a3405d1,0x39cc02e3,0x20d40036,0xb5f800e4}},	//   rütü, ịzị_, läit_, ndáh, 
   {{0xa3e04425,0x229c00d2,0xb0bc00cd,0x19580153}},	//   _तरह_, _níka_, ्वाग, _нацы_, 
   {{0x64917701,0x38c804d3,0xd4f4dacb,0x20d40254}},	//   _näit, _واوی_, еясы, näit_, 
   {{0x0708092f,0x7c3c1497,0x4ae00037,0x00000000}},	//   _بيبي_, òpri, _पठाव, --, 
   {{0x26c000ec,0x79941afd,0x20d404e6,0x7d00022e}},	//   _ujio_, _żywi, häit_, yqos, 
   {{0x64900221,0x850454f0,0x00000000,0x00000000}},	// [26f80] _bäit, _توخن, --, --, 
   {{0x65640928,0x51b80006,0x998000c0,0x00000000}},	//   _isih, чыся_, _žiū_, --, 
   {{0x645ce25d,0x649004c4,0x82a57702,0x20d40036}},	//   meri, _däit, _жанж, däit_, 
   {{0x645d7703,0x955c00b7,0x65640200,0xd12c00cf}},	//   leri, _ዲያቆን_, _ksih, _گۅك_, 
   {{0x2240005c,0x3cc82c12,0x00000000,0x00000000}},	//   mgik_, олдо_, --, --, 
   {{0x649000c5,0x65643545,0x7d017704,0x932430cd}},	//   _täiu, _msih, rqos, _ترین, 
   {{0x645d7705,0x649176bd,0x00000000,0x00000000}},	//   ieri, _häis, --, --, 
   {{0x64917706,0xafe000d6,0x6564209c,0x645d7707}},	//   _zäit, _росл, _osih, heri, 
   {{0x645d7708,0x64900f23,0x7d0001b9,0x00000000}},	//   keri, _jäis, qqos, --, 
   {{0x645d7709,0xf74802bf,0xb178008f,0x80bc00cc}},	//   jeri, оїми_, קטיר, ্গক্, 
   {{0x6565770a,0x224097a8,0xb39002d3,0x64900108}},	//   _asih, kgik_, _ግፍዕን_, _läis, 
   {{0x645c00c5,0x2ba4012c,0xd838007f,0x7738001f}},	//   eeri, _केटा, chčn_, _በደረሰ, 
   {{0x6491770b,0x645c9ff4,0xb5f9770c,0x224000b5}},	//   _näis, feri, ndái, dgik_, 
   {{0x2240005a,0x229c0aab,0xe4e4187f,0xef1c0210}},	//   egik_, _ríka_, вісн, óżka_, 
   {{0x65642a73,0x229c00d2,0x20d40036,0xa3d5770d}},	//   _esih, _síka_, häis_, ворч, 
   {{0x64900221,0x20d40221,0x22400369,0x229c0a87}},	//   _säit, zäit_, ggik_, _píka_, 
   {{0xdebc02d3,0x909800a7,0x64900821,0xa1840139}},	// [26f90] ቲአን_, пват_, _päit, кыфл, 
   {{0x64900a40,0x20d40036,0x9f040271,0x229c013a}},	//   _däis, däis_, چولو, _víka_, 
   {{0x9f045b7a,0x64900d77,0x00000000,0x00000000}},	//   نولو, _väit, --, --, 
   {{0x20d4092e,0x64900221,0x00000000,0x00000000}},	//   wäit_, _wäit, --, --, 
   {{0x6490007d,0xb5f800c6,0x52bc05d7,0xe81c0073}},	//   _täit, meád, ्कीस, _मजला_, 
   {{0xaf50fdf4,0x64900d77,0x92341e4a,0xe9fc0208}},	//   _ингә, _häir, _تىڭش, _trẫm_, 
   {{0x66c805d1,0xb5f8007b,0x20d4a6f8,0x5ff4014b}},	//   lıke, adái, räit_, _азру, 
   {{0x645d770e,0x20d404c4,0xe8c402ab,0x229c1427}},	//   zeri, säit_, रक्च, _líkn_, 
   {{0x645d770f,0x1a682a60,0x7bf40724,0xc8b42e70}},	//   yeri, بینی_, мнәр_, есны, 
   {{0x645d7710,0x1ca8025c,0x6d497711,0x6fc06d65}},	//   xeri, _བཏག_, mtga, _शशां, 
   {{0x645c6351,0x6d497712,0x00000000,0x00000000}},	//   veri, ltga, --, --, 
   {{0x645d7713,0x00000000,0x00000000,0x00000000}},	//   weri, --, --, --, 
   {{0x6d497714,0xf09c026c,0xb21801bf,0x00000000}},	//   ntga, _etài_, _knæf, --, 
   {{0x64900598,0x645d7715,0x26106b9b,0x290c01a9}},	//   _räis, ueri, _थ्री_, _itga_, 
   {{0x645d7716,0xd8741f3c,0x03a43129,0x6d490187}},	//   reri, _جانب, хиво, htga, 
   {{0x28a805d7,0x64917717,0x65657718,0x9f4c01e1}},	//   टोरि, _päis, _tsih, _àdé_, 
   {{0x656457e3,0x00e57719,0x64900166,0x229c08a5}},	// [26fa0] _usih, ежан, _däir, _fíkn_, 
   {{0x645d771a,0x6d480158,0x64900f23,0xfc4800d0}},	//   qeri, dtga, _väis, _kríž_, 
   {{0x6491771b,0xecc00034,0x20d401c7,0x6d48022e}},	//   _wäis, वचनफ, wäis_, etga, 
   {{0x6490007d,0x2fc4145e,0x6d4801a9,0x20d416b5}},	//   _täis, ûnga_, ftga, täis_, 
   {{0x5fd0000d,0x00000000,0x00000000,0x00000000}},	//   _तुरल, --, --, --, 
   {{0x7b6444c1,0x20d40a40,0xb5f801f6,0x229c0cad}},	//   етие, räis_, rdái, _kíko_, 
   {{0xafe073a3,0x6c800372,0x290c01b9,0x6d49771c}},	//   _борл, الىم, _atga_, atga, 
   {{0xfca824bd,0xb5f88bac,0x995400d8,0x0e000117}},	//   _کارو_, ldáv, вкиц, _кӯшо, 
   {{0x6d4801f5,0x6a1000d1,0x00000000,0x00000000}},	//   ctga, دبىر, --, --, 
   {{0xb5f8035b,0x48702dfc,0xb4d8026c,0xd8380100}},	//   ndáv, لگىس, ltàv, chčl_, 
   {{0x6594185c,0x068402d3,0x00000000,0x00000000}},	//   қару, _ክረኽቡ_, --, --, 
   {{0x6f002cd7,0xf8a005f5,0xb4d8642b,0xe9cc0451}},	//   ínci, тгүү, ntàv, _ڏٺم_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb865771d,0xb21800b5,0x7bd80254,0xf485771e}},	//   _ساتو, _knæg, _kytu, хумн, 
   {{0x420c00b4,0x6d4807de,0x00000000,0x00000000}},	//   _ọsọ_, ztga, --, --, 
   {{0x6d48036b,0x7bd80162,0x64400153,0xd54800ec}},	//   ytga, _mytu, ėmia, _قلعو_, 
   {{0xd131771f,0xa1597720,0x6d480051,0x00000000}},	// [26fb0] شما_, нату_, xtga, --, 
   {{0x7bd8022e,0xf65c003a,0x00000000,0x00000000}},	//   _oytu, leæ_, --, --, 
   {{0x9c7c007f,0x44b00220,0x5f94d227,0x93c800e5}},	//   _chčm, _тұрс, лифт, _زادہ_, 
   {{0x6d497721,0xb2180008,0xf65c0393,0x6490005b}},	//   ttga, _snæf, neæ_, _häip, 
   {{0x8c457722,0x7bd97723,0x6158001f,0x8d640c9e}},	//   веле, _aytu, _ምርቶች, твле, 
   {{0x01340302,0x6d497724,0x7bd821e3,0x290c022e}},	//   _ברשת_, rtga, _bytu, _rtga_, 
   {{0x7bd97725,0x6d497726,0x290c022e,0x81b40011}},	//   _cytu, stga, _stga_, _চুপ_, 
   {{0x6d48074d,0xb5f800dd,0xdfd40220,0x9e2400cf}},	//   ptga, ldáu, _сосы, _مىفو, 
   {{0x0d200b38,0x8cc8215c,0x6d4801d5,0x00000000}},	//   _түлү, _قورق_, qtga, --, 
   {{0x769c0de2,0x701c015b,0x81cc00cc,0xf3900055}},	//   _rëya, _পাঁড়_, ষেক_, _kṣā_, 
   {{0x7bd80368,0xb4d8067c,0xd838007f,0xb21802d2}},	//   _gytu, ntàu, chčm_, _gnæg, 
   {{0x769c002e,0xa6340023,0xddc00419,0xc95400cf}},	//   _pëya, _ኤምዲሰ, _hamš, _аткы, 
   {{0xb5f80122,0x290c00d4,0xddc00024,0xdbdc032e}},	//   zdáv, _utga_, _kamš, _háði, 
   {{0xc8c80244,0x00000000,0x00000000,0x00000000}},	//   _توتن_, --, --, --, 
   {{0x5030044e,0xd1740220,0x39bc0521,0xc7a404b4}},	//   _ኣምላኽ, қыты, ịst_, _шикк, 
   {{0xf65c02bd,0x229c0118,0x00000000,0x00000000}},	//   ceæ_, _víko_, --, --, 
   {{0xdbdc02d2,0xc4e401c6,0x00000000,0x00000000}},	// [26fc0] _láði, _ижий, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x03a402bf,0xdbdc0321,0x00000000,0x00000000}},	//   _рино, _náði, --, --, 
   {{0x7bd92eb5,0xa1f40220,0x6d5c0327,0x00000000}},	//   _rytu, _مۋزت, ħqan, --, 
   {{0x7bd8068f,0x6d4c0793,0x76a80198,0x9d5400db}},	//   _sytu, _äcal, nƙya, انتت, 
   {{0xdbdc08a7,0xb5f800c6,0x7bd80124,0x0dc800be}},	//   _báði, leác, _pytu, ربنى_, 
   {{0x58d40032,0xfe440fbe,0x3fe40037,0xfe400066}},	//   ғонт, _инво, _करिआ_, _نکشی, 
   {{0x7d040c6a,0x7bd91d01,0xdbdc02d2,0x32d400a2}},	//   _ékso, _vytu, _dáði, lçyr_, 
   {{0xb5f803df,0xeaac0a2c,0xcdc401ec,0xe7cc000d}},	//   ndát, تعو_, _батқ, _सँउप, 
   {{0xada17727,0x7bd8068f,0x7c64030c,0xace40022}},	//   _таул, _tytu, _جارل, _амуа_, 
   {{0xf09008a8,0xb218005c,0xbb8401c8,0x00000000}},	//   ינז_, _unæg, _جلاي, --, 
   {{0xf53c0004,0x3ea57728,0xdbe400e8,0xb21800b5}},	//   tuå_, nhot_, _nééx, _knæe, 
   {{0x649004e6,0xf65c003a,0xeaac01d3,0xb5f800d7}},	//   _päip, reæ_, _بٹن_, deác, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3ea4020b,0xf20401f4,0xca7402f2,0x00000000}},	//   khot_, вязо, _جنۆک, --, 
   {{0xb5d0030d,0x00000000,0x00000000,0x00000000}},	//   _кιел, --, --, --, 
   {{0x3ea40214,0xb5f80077,0x905400d8,0xa194004e}},	// [26fd0] dhot_, seáb, лвац, аатч, 
   {{0x2fc4019f,0x769c00e8,0x70bc00bc,0xb21808a5}},	//   ûngo_, _xëyn, ्वेल, _snæd, 
   {{0x66c80724,0xddc00010,0xa6c812ea,0xee840022}},	//   lıka, _ramš, _سویل_, кыдо, 
   {{0xdbdc1f60,0x3ea40589,0xdf80001f,0x00000000}},	//   _ráði, ghot_, ከርካሪ_, --, 
   {{0xa1841df9,0xdbdc03b2,0x4c957729,0x4238010f}},	//   _кырл, _sáði, лидс, _אײרא, 
   {{0xb5f800dd,0x8c4402dd,0x7d7400ae,0xefd80092}},	//   ldás, уеке, امور_, ፖራው_, 
   {{0xf39000b8,0x4a7400cf,0x00000000,0x00000000}},	//   _uṣā_, гыпт, --, --, 
   {{0x3ea53a9c,0x6f0004d4,0xb5f801d3,0xdbdc0162}},	//   chot_, íncu, ndás, _váði, 
   {{0xbe60c9c6,0xb4d800f7,0xb21801bf,0x201c0165}},	//   _دۇني, ntàs, _knæb, ñvig_, 
   {{0xb9e49db8,0x6d580421,0xe90005f5,0xe9fc0208}},	//   ымыз_, _ipua, лцүү, _trắm_, 
   {{0xecdc07f7,0xf1bc0118,0x00000000,0x00000000}},	//   _पीएफ, _zdát_, --, --, 
   {{0xdd900014,0x5ba40276,0x03a40fc0,0x00000000}},	//   _اوے_, _труз, қибо, --, 
   {{0xf5040d1d,0x382000cc,0x00000000,0x00000000}},	//   лнял_, _মাৰো_, --, --, 
   {{0x6d5801ee,0xd9b00131,0x54340022,0x09180154}},	//   _mpua, _گەۋد, ихсу, _দিপু_, 
   {{0x4254713a,0x3ea4022e,0x00000000,0x00000000}},	//   лтат, yhot_, --, --, 
   {{0xc61c00bd,0x8645772a,0x6d5800b0,0xd9b001ec}},	//   _থাকা_, _сниж, _opua, _دەۋد, 
   {{0x6d580070,0xc1d000fb,0x3ea4007c,0xd2f8009d}},	// [26fe0] _npua, сөнә, vhot_, тэрч_, 
   {{0x80680220,0xc1d001e0,0xf1bc01d3,0xa9184142}},	//   عماق_, _ғөбә, _adás_, पीएफ_, 
   {{0x4429772b,0x3ea47333,0x769c00e8,0xb4d80137}},	//   mab_, thot_, _xëyo, rtàt, 
   {{0x4429772c,0xb4d86457,0x3ea4083e,0x9f4c01e1}},	//   lab_, gràf, uhot_, _àdí_, 
   {{0xdce00882,0x3ea5772d,0x1ca8031c,0xf6500375}},	//   _asmā, rhot_, _བཏད_, מצא_, 
   {{0x3ea5772e,0x008401d5,0xadb400f2,0x00000000}},	//   shot_, _ёлво, دهها_, --, 
   {{0xb5f83bd4,0x6d580093,0x66c800fd,0x3ea40072}},	//   ndár, _epua, zıka, phot_, 
   {{0x4429772f,0xb4d9033e,0x769c00e8,0xa59002d3}},	//   hab_, ntàr, _rëyo, _ዝጸንሔ_, 
   {{0x7e617730,0x44297731,0x6e900966,0x3b840b65}},	//   meop, kab_, _القا, _әлег, 
   {{0x7e617732,0x4428946e,0x17540c69,0xf848074d}},	//   leop, jab_, авоя, хчий_, 
   {{0x44297733,0x3cfc0472,0x69c89223,0x7c284a21}},	//   dab_, _iitv_, _exge, mafr, 
   {{0x7e617734,0x39e401d5,0x00000000,0x00000000}},	//   neop, _йўлб, --, --, 
   {{0x3cfc00b5,0x769c002e,0x00000000,0x00000000}},	//   _kitv_, _wëyo, --, --, 
   {{0x44297735,0x7c297736,0xb4dc0882,0xb4d80ba1}},	//   gab_, nafr, तते_, etàr, 
   {{0x7e617737,0xf2c401c0,0x7c2803cb,0x3204012d}},	//   keop, гсан, iafr, śnym_, 
   {{0x78b8341a,0x52157738,0x66c80724,0xb4d8026c}},	//   litv, рдат, lıkn, ttàs, 
   {{0x3cfc022e,0x7c280413,0xefc40023,0xa63c011a}},	// [26ff0] _oitv_, kafr, ጽዋዕ_, _נגזר, 
   {{0x44297739,0x78b9773a,0x9c7c01ab,0x54541d0f}},	//   cab_, nitv, _fhči, _твот, 
   {{0x6d584317,0xb4d800db,0x13a40345,0x998401ef}},	//   _spua, tràf, _ئۆزی_, kamů_, 
   {{0xb4d80137,0xdef8ba3e,0x6d5805b1,0x7c28009f}},	//   ctàr, гыч_, _ppua, eafr, 
   {{0xa0240154,0x7c2946d5,0x00000000,0x00000000}},	//   _পারব_, fafr, --, --, 
   {{0x78b9773b,0x7c29773c,0xa3bc02c3,0x00000000}},	//   jitv, gafr, _अधम_, --, 
   {{0x78b9773d,0x25dc0cbf,0xb4d8004e,0x7e6001bf}},	//   ditv, _गुनी_, mràd, beop, 
   {{0x4429773e,0x50e40034,0x4a7429a3,0x7e60072b}},	//   zab_, _कठुआ_, рыкт, ceop, 
   {{0x6d582c53,0x6f04014f,0xb5f803da,0x6e2800e5}},	//   _upua, _hujc, zdár, magb, 
   {{0x6e280ca8,0xb4cc012c,0x4878013e,0x4428addf}},	//   lagb, षको_, тсия_, xab_, 
   {{0x4429773f,0x06e8094f,0xadc001af,0x00000000}},	//   vab_, кмок_, _таҡһ, --, 
   {{0x6e283433,0x644002d5,0x6f04014f,0x00000000}},	//   nagb, ėmim, _mujc, --, 
   {{0x44297740,0x69302b49,0x78b809a8,0x6f04014f}},	//   tab_, _اکبر, bitv, _lujc, 
   {{0x6ab97741,0x391000f7,0x386c0042,0x78b8002b}},	//   liuf, _بووز, _gafr_, citv, 
   {{0x44297742,0xa284c570,0x6e297743,0x3a240ac5}},	//   rab_, میدو, kagb, _yeop_, 
   {{0x44297744,0x6ab80618,0xb6d05821,0x9f58007b}},	//   sab_, niuf, _وقوع, _ngrá_, 
  
   {{0x4428c79a,0x6e2895a4,0x66040537,0x67200097}},	// [27000] pab_, dagb, _igik, _hwnj, 
   {{0x44297745,0x6ab80810,0xf0a57746,0xb4d97747}},	//   qab_, hiuf, акул_, stàr, 
   {{0x6f040399,0x229d7748,0xb5f80789,0x6ab801f7}},	//   _cujc, _líki_, neán, kiuf, 
   {{0x67200369,0x6f04014f,0x2a6c0076,0x7d040c6a}},	//   _mwnj, _dujc, _nagb_, _éksk, 
   {{0x78b80882,0x7c296cf0,0x6f00004e,0xb5f97749}},	//   yitv, tafr, íncr, heán, 
   {{0x7e605f92,0xb4d800db,0x7b6401d9,0x00000000}},	//   seop, rràg, لابٕ, --, 
   {{0xfaa5774a,0x78b80f72,0x6ab80421,0xe7840122}},	//   ишин, vitv, fiuf, yšší, 
   {{0x6605774b,0xf1bc0597,0x229c00d2,0x2efc05d5}},	//   _ngik, _meán_, _bíki_, _giuf_, 
   {{0x78b9774c,0x2a6c0076,0x6da0030d,0x58d80395}},	//   titv, _dagb_, _дита, лдия_, 
   {{0x67200007,0x6604cd30,0x3cfc01f5,0xfce40137}},	//   _bwnj, _agik, _uitv_, _тозо, 
   {{0x78b9774d,0xed6c1b49,0x60dc00e4,0xb098008f}},	//   ritv, _ቻርተር_, _mkrm, דייר, 
   {{0x6ab8011c,0x78b8247a,0x8b94f3f0,0xb4dc00dc}},	//   ciuf, sitv, _уруч, तत्_, 
   {{0x78b9774e,0x00000000,0x00000000,0x00000000}},	//   pitv, --, --, --, 
   {{0x66c8b753,0x6605774f,0xe7900882,0xe4a57750}},	//   lıkl, _egik, ṣaṇa, орсо, 
   {{0x67200369,0x5694e560,0xb5f800c6,0xd9d802f5}},	//   _gwnj, _гайт, ceán, দেশম, 
   {{0xf1bd7751,0x66c81918,0xaa100124,0x00000000}},	//   _deán_, nıkl, hẽng, --, 
   {{0xb4d80137,0xc32c03e6,0xe2f81d31,0x6f04014f}},	// [27010] tràd, وڕێ_, реті_, _sujc, 
   {{0x6f057752,0x3d081a2a,0xa158890b,0xf53c01e6}},	//   _pujc, ादने_, рафу_, mrå_, 
   {{0x6e297753,0x6f04014f,0xf53c0217,0xfbd47dad}},	//   tagb, _qujc, lrå_, _ढुलम, 
   {{0xcd340efe,0x11d800ae,0x00000000,0x00000000}},	//   مرتب, _موجة_, --, --, 
   {{0x6e28eb67,0x66c80365,0xa2d4258d,0xf53c01bf}},	//   ragb, dıkl, भकर्, nrå_, 
   {{0x229c09f3,0x6f057754,0x00000000,0x00000000}},	//   _ríki_, _tujc, --, --, 
   {{0x1cb819db,0x6e297755,0xe458008f,0x6ab80194}},	//   جانب_, pagb, ייגט_, tiuf, 
   {{0xca840323,0x5fd00073,0x9f4c0248,0x60dc01ef}},	//   сгий, _तुटल, _àdá_, _zkrm, 
   {{0x6ab80140,0x9d540014,0x2720002d,0x8fa402dd}},	//   riuf, _ونِت, wűn_, _таңе, 
   {{0x6ab80618,0x088813f3,0xb900030d,0x229c032e}},	//   siuf, убой_, язьк, _víki_, 
   {{0xf53c0004,0x2a6c020c,0x2ce00073,0xb4d81f40}},	//   erå_, _tagb_, गतील_, tuàn, 
   {{0xf7700533,0xf53c03d4,0xdc3c0135,0x66c803e0}},	//   ساپ_, frå_, _iġġi, cıkl, 
   {{0xf1bc00c6,0xb5f95333,0xc5d428f6,0x00000000}},	//   _seán_, seán, сінь, --, 
   {{0xb5f97756,0x3204013f,0x25dd6b62,0x00000000}},	//   rdáp, ɛnyi_, _गुणी_, --, 
   {{0xb5f800c6,0xd7f800f3,0x00000000,0x00000000}},	//   leál, _кућ_, --, --, 
   {{0x66040526,0x649001c7,0xf53c2d62,0xb4d805d5}},	//   _ugik, _jäiz, brå_, quàn, 
   {{0xb5f800c6,0x0108135f,0xc1e801c6,0x0444337e}},	// [27020] neál, اترو_, удаж_, _лепн, 
   {{0x66c8456f,0x7d040d51,0x00000000,0x00000000}},	//   zıkl, _éksi, --, --, 
   {{0xa3bc5444,0x66c85775,0xb5f800ae,0x00000000}},	//   _अधि_, yıkl, heál, --, 
   {{0xcf2400c6,0x00000000,0x00000000,0x00000000}},	//   تركي, --, --, --, 
   {{0xb21803b2,0xfce40107,0xbb2c00d1,0x00000000}},	//   _knæn, бодо, ﯨﺪﻩ_, --, 
   {{0xdcb02f7c,0xd5ec004d,0x00000000,0x00000000}},	//   بىت_, _hoạ, --, --, 
   {{0x649004e6,0x66c8510c,0x00000000,0x00000000}},	//   _bäiz, tıkl, --, --, 
   {{0xf53d2b8c,0x9e840244,0x2ed017c6,0x00000000}},	//   yrå_, _باسۆ, तवृत, --, 
   {{0x0eb80716,0x66c8247e,0xae84009d,0x00000000}},	//   _туры_, rıkl, _убтз_, --, 
   {{0xd5ec01fb,0x98a40024,0xf53c0158,0x66c80790}},	//   _loạ, ksmą_, vrå_, sıkl, 
   {{0x64900166,0xec10552d,0x66c803e0,0xbad40153}},	//   _fäiz, _روند, pıkl, _ліды, 
   {{0xb5f89cba,0x769c1bce,0x3688a943,0x00000000}},	//   beál, _këyi, усон_, --, 
   {{0xe9fc001e,0xb5f8007b,0xf4844a03,0x00000000}},	//   _trạm_, ceál, бувн, --, 
   {{0x29340115,0x00000000,0x00000000,0x00000000}},	//   _פאון_, --, --, --, 
   {{0x56957757,0x81b4015b,0x2418023a,0xa8540375}},	//   _макт, _চুল_, сосы_, _ליגה_, 
   {{0xdee40046,0xb5a47a9c,0x00000000,0x00000000}},	//   _سۋ_, _грой, --, --, 
   {{0x442c113c,0x21a80724,0xb4d8004e,0x00000000}},	// [27030] _оf_, бәрү_, gràc, --, 
   {{0x92d8009e,0xd8380100,0x00000000,0x00000000}},	//   াষে_, chčt_, --, --, 
   {{0x92597758,0x984c005f,0xa15802dd,0x92957759}},	//   _кант_, dēļu_, _қару_, _данц, 
   {{0x769c0de2,0x0d980166,0xfdf4012d,0x00000000}},	//   _bëyi, итлы_, ेशंस_, --, 
   {{0xb4d835fb,0x00000000,0x00000000,0x00000000}},	//   cràc, --, --, --, 
   {{0xcc892221,0xb1380092,0x00000000,0x00000000}},	//   شنبه_, _እርዳታ, --, --, 
   {{0x620802d2,0x00000000,0x00000000,0x00000000}},	//   _áslá, --, --, --, 
   {{0xb5f8007b,0x271401fb,0x00000000,0x00000000}},	//   teál, _hăng_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd90c2b49,0xb5f80553,0x2b4405f5,0xadc0004d}},	//   دیو_, reál, _гэдг, _ngẩn, 
   {{0x271401fb,0xb5f800c6,0x229c08a5,0x06c80108}},	//   _măng_, seál, _kíkt_, игой_, 
   {{0x2714001e,0x60100241,0xb5f800ae,0x00000000}},	//   _lăng_, _kòmó, peál, --, 
   {{0x66c800fd,0x20d40036,0x99580356,0x00000000}},	//   lıkk, räiz_, râţe_, --, 
   {{0x271401dc,0xc7a5775a,0xf2dc0022,0x229c09f3}},	//   _năng_, _милк, _akâ_, _líkt_, 
   {{0x98a40024,0x2b440393,0x2bdc00dc,0x03a400f0}},	//   usmą_, nunc_, _पुमा, циво, 
   {{0xe9240489,0xb4d8004e,0x48f000bc,0xa4941bf4}},	//   _རྦོབ_, tràc, ँगको_, _کیست, 
   {{0xf46c044e,0x27140016,0x2b44003a,0xd83802e2}},	// [27040] _ብምሉእ_, _băng_, hunc_, chčs_, 
   {{0x2714001e,0x769c002e,0x229c0d12,0xbd894db6}},	//   _căng_, _rëyi, _ríku_, ینان_, 
   {{0x44380472,0xce3400aa,0xadc00241,0xb218005c}},	//   _idp_, ړونک, _ifẹn, _knæl, 
   {{0x44395c61,0xb4d800db,0x229c02d2,0x00000000}},	//   _hdp_, pràc, _píku_, --, 
   {{0x30e800cd,0x00000000,0x00000000,0x00000000}},	//   _जीवः_, --, --, --, 
   {{0x4438009b,0x271401fb,0x2b440477,0x229c01ef}},	//   _jdp_, _găng_, func_, _víku_, 
   {{0x4439775b,0xbea40276,0x9c7c007f,0x2b440165}},	//   _mdp_, _давк, _shčs, gunc_, 
   {{0x5a35775c,0x4439775d,0x769c00e8,0x27140051}},	//   чнит, _ldp_, _tëyi, _zăng_, 
   {{0x2bc40b8d,0x4439775e,0xce340214,0xcee800ec}},	//   йләп_, _odp_, _رولک, _طرفن_, 
   {{0x4438010a,0x2714001e,0x66c80139,0x00000000}},	//   _ndp_, _xăng_, bıkk, --, 
   {{0x2b4445a7,0xb4d8026c,0x883000e5,0x01ac02dd}},	//   cunc_, jràa, رکوئ, _ﺴﻁﻴﻨ, 
   {{0x4439775f,0xadc00241,0x6ee00254,0x00000000}},	//   _adp_, _afẹn, tõbi, --, 
   {{0x0a8800cf,0x85a4010b,0x160c012d,0x00000000}},	//   _دئلى_, пырҗ, सखबर_, --, 
   {{0x44397760,0xdc0800da,0x00000000,0x00000000}},	//   _cdp_, rēķi, --, --, 
   {{0x27140016,0x4438584c,0xf09c16b8,0x4f4c01ec}},	//   _răng_, _ddp_, _quàm_, _ءﻭﻟﻰ_, 
   {{0x56941d0f,0x81b400fe,0x44381a9f,0x27140051}},	//   _хаит, _চুই_, _edp_, _săng_, 
   {{0xb80c7f1a,0x44397761,0x77780175,0x229c0aab}},	// [27050] _सलाम_, _fdp_, lvtx, _ríkt_, 
   {{0x44380d63,0x246000b5,0x00000000,0x00000000}},	//   _gdp_, とmpo_, --, --, 
   {{0xe9fc001e,0x271401fb,0x2bdc0073,0xfbfc0154}},	//   _trầm_, _văng_, _पुढा, ুরুষ_, 
   {{0x7c397762,0x44397763,0x00000000,0x00000000}},	//   _adtr, _zdp_, --, --, 
   {{0x271407ae,0x44380ac5,0x7c380139,0x644800db}},	//   _tăng_, _ydp_, _bdtr, ódig, 
   {{0x7c3800a3,0x251c008d,0x443801b9,0x2b44003a}},	//   _cdtr, סווא, _xdp_, tunc_, 
   {{0x643c011a,0x00000000,0x00000000,0x00000000}},	//   בעונ, --, --, --, 
   {{0x2fc400d2,0x66c8495b,0x2b45672d,0x78a8007c}},	//   ûngu_, rıkk, runc_, _alfv, 
   {{0x9d1807d5,0x00000000,0x00000000,0x00000000}},	//   _мотт_, --, --, --, 
   {{0x29013b7a,0xf6b4031c,0x7c380051,0xc0c80b82}},	//   öja_, _བཏུང, _gdtr, _ጠቀስ_, 
   {{0x44397764,0xb21801bf,0xdce00024,0xf8ac00f2}},	//   _rdp_, _anæm, _armė, دکن_, 
   {{0x44397765,0x998001f1,0x78a801e3,0x00000000}},	//   _sdp_, _žiť_, _elfv, --, 
   {{0x44397766,0x77780218,0xa9c47092,0x38c83c5b}},	//   _pdp_, avtx, _بزاو, شایی_, 
   {{0x291c01f4,0x6fa805c0,0x00000000,0x00000000}},	//   mpua_, चनां, --, --, 
   {{0x07a57767,0x6e38014b,0x6ee00254,0x00000000}},	//   _хайн, _odub, lõbu, --, 
   {{0x6e397768,0xb4d8026c,0xcfe00011,0x00000000}},	//   _ndub, rràa, বধান, --, 
   {{0x44380263,0xb4d8002e,0x386000e5,0x00000000}},	// [27060] _tdp_, mràn, őkre_, --, 
   {{0x44380652,0xb06001a2,0x65657769,0x6e39776a}},	//   _udp_, jväč, _ipih, _adub, 
   {{0x6e380332,0x00000000,0x00000000,0x00000000}},	//   _bdub, --, --, --, 
   {{0x9f440227,0xfe70d783,0x65640254,0xfbfc03d4}},	//   _ąmä_, عدا_, _kpih, ুৰুষ_, 
   {{0x6da04727,0xfce5776b,0x6e385ffe,0x51549e3a}},	//   ница, подо, _ddub, _отру, 
   {{0x65640851,0x6e39776c,0x7534008f,0x2121776d}},	//   _mpih, _edub, לאנד_, mpih_, 
   {{0x65680882,0x645c009a,0x38c00248,0xeb940798}},	//   ādhy, ifri, _lérè_, зиј_, 
   {{0x6565776e,0x00000000,0x00000000,0x00000000}},	//   _opih, --, --, --, 
   {{0xcdc4005e,0x3ea4562c,0x77780218,0xb4d80109}},	//   _жатқ, mkot_, wvtx, dràn, 
   {{0x7c38019b,0x3ea4005f,0x6aa803cd,0xb198008f}},	//   _udtr, lkot_, _elgf, צייכ, 
   {{0x6565776f,0x6838001f,0xf090011a,0x291c0108}},	//   _apih, _በአምስ, תנת_, apua_, 
   {{0x76a97770,0xb5f80597,0x38c001e1,0x645c0d27}},	//   стов_, leái, _bérè_, efri, 
   {{0x645d7771,0x20180699,0x3ea57772,0x7d0001e1}},	//   ffri, _ofri_, ikot_, _gírì, 
   {{0xb5f80597,0x645c00dd,0x24197773,0x769c002e}},	//   neái, gfri, зоры_, _rëyu, 
   {{0x3ea57774,0xf77002f2,0xaab17775,0x00000000}},	//   kkot_, _ساغ_, ükçü_, --, 
   {{0x66e42424,0x645d7776,0x20197777,0xf6b4025c}},	//   _поја, afri, _afri_, _བཏིང, 
   {{0x7ae0009a,0x817801f0,0x00000000,0x00000000}},	// [27070] _mkot, оатӣ_, --, --, 
   {{0xb218037e,0x6e3801fa,0xa074004e,0x3ea40171}},	//   _knæk, _sdub, нгуч, ekot_, 
   {{0x7ae17778,0xb5f800c6,0x6f0001e1,0xb9d40023}},	//   _okot, deái, _nìbì, _ሽግ_, 
   {{0x3ea57779,0x2019777a,0x7ae1777b,0x3b040194}},	//   gkot_, _efri_, _nkot, _nioq_, 
   {{0x20180042,0x4278011a,0x00000000,0x00000000}},	//   _ffri_, _וארג, --, --, 
   {{0x7ae1777c,0x81b402f5,0x7d0001e1,0xb5f801e7}},	//   _akot, _চুক_, _rírì, geái, 
   {{0x66c8002d,0xb4d80022,0xdfd400fa,0x82940133}},	//   lűke, guài, _зоры, _ردێڕ, 
   {{0x6e39777d,0xaee000b8,0xe8b401bc,0x645c01e4}},	//   _udub, _koṭa, ेच्च, zfri, 
   {{0x645d777e,0x291c0421,0xb4d805d5,0xfd4d399e}},	//   yfri, upua_, vràn, _ojiṣ, 
   {{0x7ae01aac,0xb5f9777f,0x2ac0f21a,0x291c009d}},	//   _ekot, ceái, _bèbè_, rpua_, 
   {{0x6d497780,0x7ae00418,0xb4d80109,0x65640010}},	//   luga, _fkot, tràn, _spih, 
   {{0x291d7781,0x00000000,0x00000000,0x00000000}},	//   ppua_, --, --, --, 
   {{0x6d497782,0xb4d800f7,0x15e0000d,0x00000000}},	//   nuga, rràn, _गुदर_, --, 
   {{0x290d7783,0x6d480618,0x98b001a6,0x65640427}},	//   _iuga_, iuga, _ćaći_, _vpih, 
   {{0x6d497784,0x290404c9,0x290c1873,0x3ea57785}},	//   huga, _iina_, _huga_, ykot_, 
   {{0x29057786,0x6d497787,0x854800f3,0x00000000}},	//   _hina_, kuga, _дзив_, --, 
   {{0x290c7020,0x29057788,0x6d497789,0x65640810}},	// [27080] _juga_, _kina_, juga, _upih, 
   {{0x290554f6,0x6d49778a,0x21200a2e,0x290d778b}},	//   _jina_, duga, rpih_, _muga_, 
   {{0x2905778c,0x290d778d,0x3ea5778e,0x7f8433d2}},	//   _mina_, _luga_, tkot_, بلان, 
   {{0x2905778f,0x3d081d8a,0x290c0086,0x2fc400d2}},	//   _lina_, ादले_, _ouga_, únga_, 
   {{0xb5f80597,0x290404c9,0x3ea57790,0xd25401b9}},	//   teái, _oina_, rkot_, _سیلش_, 
   {{0x3ea57791,0x00000000,0x00000000,0x00000000}},	//   skot_, --, --, --, 
   {{0x290d7792,0xb5f80597,0x6d497793,0xbb140131}},	//   _auga_, reái, auga, _ﻳﯩﻞ_, 
   {{0x29057794,0x290d7795,0xb5f80597,0xab8032eb}},	//   _aina_, _buga_, seái, тушк, 
   {{0x290d7796,0xb5f97797,0x6d4800cf,0xb8680640}},	//   _cuga_, peái, cuga, ојне_, 
   {{0x26c004c9,0xfca80e53,0x9f5801ab,0x00000000}},	//   _amio_, _بارو_, _sgrù_, --, 
   {{0x29057798,0x290c004e,0xf09c0051,0x00000000}},	//   _dina_, _euga_, _quài_, --, 
   {{0x29057799,0x7ae000ca,0x27e4015d,0x5694a0d5}},	//   _eina_, _ukot, _dynn_, хамт, 
   {{0x290d779a,0x2d88004a,0xdcc80051,0x00000000}},	//   _guga_, _àcet_, hỉm_, --, 
   {{0x2905779b,0x26c001e4,0x27e400ad,0x7981716b}},	//   _gina_, _emio_, _fynn_, _irow, 
   {{0x6d48ef32,0x290c02a8,0xaee000b8,0x92a801e0}},	//   zuga, _zuga_, _joṣa, псаҡ_, 
   {{0x2905779c,0x6d49779d,0xf1a40f5c,0xb21803b2}},	//   _zina_, yuga, мрзн, _knæi, 
   {{0x6448fc30,0x29040296,0x50f43667,0x6d481892}},	// [27090] ódic, _yina_, езат, xuga, 
   {{0x6d49779e,0x29040137,0xb15c00b7,0x62800162}},	//   vuga, _xina_, _ህይወታ, _ómon, 
   {{0x6d482dab,0xa0c4027d,0x1b140011,0xd25000e5}},	//   wuga, خيلو, ণীতে_, _ینگ_, 
   {{0x7981779f,0xb4d80022,0x00000000,0x00000000}},	//   _orow, guàv, --, --, 
   {{0x6d48013c,0xdce00118,0x00000000,0x00000000}},	//   uuga, _usmě, --, --, 
   {{0x66c82706,0x290d77a0,0xb21802d2,0x00000000}},	//   lıkt, _ruga_, _snæh, --, 
   {{0x6d4977a1,0x798177a2,0x8e7c0115,0xaee00055}},	//   suga, _arow, _ekŝa, _coṣa, 
   {{0x798177a3,0x6d4879b8,0x5f780014,0x290c311a}},	//   _brow, puga, _تمِس_, _puga_, 
   {{0x2bdc1d8a,0x7980378c,0x6d4820ac,0x27e401f5}},	//   _पुरा, _crow, quga, _synn_, 
   {{0x798177a4,0x290d77a5,0x26c07553,0x290577a6}},	//   _drow, _vuga_, _smio_, _qina_, 
   {{0x79800428,0x07a577a7,0x35a0036b,0x38680254}},	//   _erow, ханн, қарг, õbra_, 
   {{0x290577a8,0x798177a9,0x2d8806af,0x00000000}},	//   _wina_, _frow, _àces_, --, 
   {{0x290577aa,0x2bc007b6,0x79800c3e,0x66c803ee}},	//   _tina_, _वेता, _grow, dıkt, 
   {{0xfd4c01f2,0x2904096b,0x27e577ab,0x443c06af}},	//   _alkọ, _uina_, _tynn_, ût_, 
   {{0x7c3c03b7,0xd3340276,0x00000000,0x00000000}},	//   ópri, кэты, --, --, 
   {{0x26c001fa,0xe6640588,0xe818166d,0x00000000}},	//   _umio_, _реиҿ, पुरा_, --, 
   {{0x09e0015b,0x7cf4030a,0x769c0142,0x00000000}},	// [270a0] মেরা, lâre, _tëyr, --, 
   {{0x9c7c0232,0x3e3802d3,0xb5f800d8,0x34d800cd}},	//   _akčn, _ከምዘየ, teáv, णवृद, 
   {{0x705177ac,0xf454008d,0x2bdca4cd,0x82a401b9}},	//   انما, _אייר_, _पुला, _занж, 
   {{0xb5f80798,0x38b00311,0x2fd40214,0x66c803e0}},	//   reáv, _târg_, روند_, cıkt, 
   {{0x8c2002a6,0x71a03e71,0x66c80e2d,0x2388012d}},	//   _নয়ন_, _баяз, lıks, łuję_, 
   {{0xaee0002b,0xefcc0023,0x00000000,0x00000000}},	//   _poṣa, ኣይዎ_, --, --, 
   {{0x2bc007b7,0x66c803e0,0x00000000,0x00000000}},	//   _वेदा, nıks, --, --, 
   {{0x798177ad,0xafe09c0b,0x6ee000af,0xb5f80789}},	//   _prow, _сосл, sõbr, nfác, 
   {{0x58d577ae,0xf990821f,0x38b0030a,0x00000000}},	//   коит, ابع_, _lâre_, --, 
   {{0xdee4036b,0x79800076,0xaee000cd,0xf15400df}},	//   _чоғи, _vrow, _toṣa, עשיץ_, 
   {{0x09e00011,0x66c80205,0x7a0c00b8,0x00000000}},	//   মেলা, yıkt, _ṛtub, --, 
   {{0x798177af,0x33700c60,0x0ae800e3,0x00000000}},	//   _trow, ҳҳор, _قرني_, --, 
   {{0x187402d5,0xa3d40107,0x00000000,0x00000000}},	//   _агля, ҳорч, --, --, 
   {{0xe0c402f5,0xd794007b,0xf65c03b2,0x3ae80244}},	//   ্তুন, _للتخ, sfæ_, _ببڕی_, 
   {{0xb9d8044e,0x66c80e2d,0xa3d42083,0xa878011a}},	//   _ኢላ_, tıkt, горч, _מאגר, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa8000352,0x905400c0,0x00000000,0x00000000}},	// [270b0] _изәл, квац, --, --, 
   {{0xd0200131,0xadc00208,0x61f40139,0x66c80205}},	//   شۈرۋ, _ngạn, _şelä, sıkt, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6ee577b0,0xb2a4007b,0x00000000,0x00000000}},	//   رسال, _أحده, --, --, 
   {{0xa1840184,0x5e5446c6,0xaf500116,0xa63c00df}},	//   _йырл, ائمر, _әнбә, לגאר, 
   {{0x7d04020c,0xcb680107,0x03300118,0xe10402d5}},	//   _èksl, даке_, říži_, _бясп, 
   {{0x0b586566,0xfbcc00ec,0x00000000,0x00000000}},	//   фрлы_, يڪم_, --, --, 
   {{0xca8405f5,0xb5f80332,0x00000000,0x00000000}},	//   тгий, neás, --, --, 
   {{0xdef800f7,0x00000000,0x00000000,0x00000000}},	//   _чыр_, --, --, --, 
   {{0x6d58014b,0x7cf400e4,0x66c80205,0x00000000}},	//   _iqua, târe, yıks, --, 
   {{0x4a54004e,0xca741219,0x00000000,0x00000000}},	//   _акес, _аулы, --, --, 
   {{0x7cf489be,0xe5780107,0x00000000,0x00000000}},	//   râre, еҷи_, --, --, 
   {{0x6288016b,0x9944009f,0x00000000,0x00000000}},	//   _ɔdod, _مَنه, --, --, 
   {{0x7a380419,0x66c80205,0x00000000,0x00000000}},	//   pätí, tıks, --, --, 
   {{0x42540661,0x5ee400cd,0x00000000,0x00000000}},	//   ктат, टकम्_, --, --, 
   {{0x6d580428,0x63c40032,0xb5f80518,0x6d440055}},	//   _oqua, _ҡапҡ, teát, _ājan, 
   {{0x6d580070,0xc05802f6,0x07a40014,0x2f1403b9}},	// [270c0] _nqua, дрец_, _سمکُ, _açg_, 
   {{0x2d58006a,0xf534008f,0x00000000,0x00000000}},	//   dêe_, _שניי_, --, --, 
   {{0x6d5826c2,0x1af800eb,0x00000000,0x00000000}},	//   _aqua, ঁদতে_, --, --, 
   {{0xb2195cbe,0x0eb8008e,0x00000000,0x00000000}},	//   _snæv, нучы_, --, --, 
   {{0xdce000da,0x442800a3,0x00000000,0x00000000}},	//   _apmā, obb_, --, --, 
   {{0x6d580165,0xb4d800db,0x00000000,0x00000000}},	//   _dqua, quàt, --, --, 
   {{0x442801af,0xf1bc0077,0x6d58bb99,0xb5f825fd}},	//   ibb_, _feás_, _equa, neár, 
   {{0x4428014b,0xb4d80109,0xf1bc00e5,0x00000000}},	//   hbb_, tràk, _teát_, --, 
   {{0x6930052f,0xdc5416e0,0xed540798,0x00000000}},	//   аныу, _مراک, _иот_, --, 
   {{0x7e604f99,0x2f140076,0x38b00356,0x00000000}},	//   lfop, _yçg_, _sârb_, --, 
   {{0x163577b1,0xfd4c004d,0x497401c6,0x44280064}},	//   леня, _ngoặ, влөс, dbb_, 
   {{0x4428009a,0x7bd8127b,0x7dc401d5,0x644803b2}},	//   ebb_, _ixtu, _tаsd, ódin, 
   {{0xf60801b9,0x8ad8010f,0x6d580051,0x39340153}},	//   بتده_, _אַספ, _xqua, _рэес, 
   {{0x7dc4022e,0x00000000,0x00000000,0x00000000}},	//   _kаsb, --, --, --, 
   {{0x24182de5,0x77900133,0xdef00240,0x00000000}},	//   тосы_, _ئیجا, ልምን_, --, 
   {{0xd8380331,0x7e6001f5,0x63a805ac,0xe2f80150}},	//   lač_, jfop, ødna, весі_, 
   {{0xb5f80332,0x00000000,0x00000000,0x00000000}},	// [270d0] reás, --, --, --, 
   {{0x2ed8503c,0xd839121f,0x7bd800b5,0x7e6001f5}},	//   यक्त, nač_, _oxtu, efop, 
   {{0x7bcc4dfc,0x93c801ed,0x7e6003cd,0x1f1401a9}},	//   _žbun, _سادہ_, ffop, амхў, 
   {{0x92945884,0x9f5800db,0xb4d8004e,0xf65c0217}},	//   _самц, _agró_, cuàr, mnæs_, 
   {{0xd83814a6,0xf65c0162,0x00000000,0x00000000}},	//   kač_, lnæs_, --, --, 
   {{0x106401d9,0x63c8032e,0x00000000,0x00000000}},	//   _حُسُ, _örnó, --, --, 
   {{0x9f3400d6,0x5f9577b2,0xaf0400db,0x00000000}},	//   _весі, _кирт, _ачак, --, 
   {{0xdfd577b3,0xaca00ca8,0x6f1802f0,0x3af80200}},	//   _тосы, _ikọl, _čuch, jëpd_, 
   {{0x6d580d04,0x7bd977b4,0x2bc0098a,0x38c800f1}},	//   _uqua, _extu, _वेरा, کايی_, 
   {{0x2c004494,0xd8381a48,0xac741001,0xb218366f}},	//   _күлм, gač_, _جارش, _knæs, 
   {{0x65940213,0x00000000,0x00000000,0x00000000}},	//   _məhş, --, --, --, 
   {{0xaca001fb,0x00000000,0x00000000,0x00000000}},	//   _ruộn, --, --, --, 
   {{0x2a7c01d4,0xd838dc02,0xe9a81ec7,0x2b800790}},	//   mdub_, bač_, _تدان_, _hıc_, 
   {{0xd83805a1,0x2a7c00c5,0xe79001d9,0x7d1400e4}},	//   cač_, ldub_, _نابک, íysi, 
   {{0x6d48aa59,0x7cf40194,0x00000000,0x00000000}},	//   hrga, nâra, --, --, 
   {{0x670c006d,0x2a7c007d,0xd838007f,0xdb2404e6}},	//   _सूचक_, ndub_, skčt_, üséi, 
   {{0xaca00ca8,0xb218005c,0x81840006,0xc9900092}},	// [270e0] _akọl, _anæs, ыгаж, _ፀሐፊው_, 
   {{0x6d480427,0x7fd807d9,0x7cf40022,0xb21802d2}},	//   drga, нфет_, kâra, _snæt, 
   {{0x6d4977b5,0x659400ac,0x7cf40194,0x2bc11769}},	//   erga, _dəhş, jâra, _वेला, 
   {{0xd838098d,0xcd600952,0xe2540133,0x644c0210}},	//   zač_, ﺎﻧﯩﯔ_, _خێرخ, łnią, 
   {{0xdd9577b6,0xf65c4453,0x7d0407b0,0x2a7c00e8}},	//   ралы, onær_, _èksk, ddub_, 
   {{0xa3e87db3,0xb4d808c2,0x7c28002f,0x6da0033a}},	//   _बडा_, trài, ubfr, сиља, 
   {{0xceac6833,0x8c3401e1,0x6d484f82,0x9a8400d1}},	//   _дә_, _ko̟j, arga, ғуқл, 
   {{0x2bc00490,0x8c3401e1,0x6d4801b9,0x09bc0154}},	//   _वेळा, _jo̟j, brga, আপনা, 
   {{0xd838cc1a,0xb21800d4,0x6d480076,0xed6000bc}},	//   tač_, _knær, crga, ěží_, 
   {{0x2bdc924b,0xa3b42e05,0xe87000d1,0x9f4c0ca8}},	//   _पुका, झना_, مچىگ, _àdó_, 
   {{0xd8380bb8,0xec10221d,0x569401c0,0x2a7d77b7}},	//   rač_, _اومد, аант, bdub_, 
   {{0xa3e8033d,0x387c00fe,0xe89000c7,0x00000000}},	//   _बड़_, sdtr_, _ҳашь, --, 
   {{0xded40020,0x91e400b5,0x00000000,0x00000000}},	//   ክምና_, meでb, --, --, 
   {{0x1cdc025c,0xb4d800e4,0x6930009d,0x00000000}},	//   _ྣམས_, guàp, _уншу, --, 
   {{0x326577b8,0x7cd800ef,0x30e401ec,0x6d440055}},	//   лтав, _gārņ, ңізб, _ājam, 
   {{0xf65c12e8,0x00000000,0x00000000,0x00000000}},	//   rnæs_, --, --, --, 
   {{0xaca0063f,0xf65c5522,0xb21802d2,0xa194498b}},	// [270f0] _skọl, snæs_, _snæs, батч, 
   {{0x1418007b,0x00000000,0x00000000,0x00000000}},	//   _جيدة_, --, --, --, 
   {{0x65940213,0x8e1413d6,0x94e0033f,0xf53c007c}},	//   _vəhş, адец, पकीआ, lså_, 
   {{0x6d480427,0x00000000,0x00000000,0x00000000}},	//   trga, --, --, --, 
   {{0x6d482619,0xf53c003b,0xd04400ec,0x00000000}},	//   urga, nså_, _نھاي, --, 
   {{0xb2180381,0x251c008f,0x6d480162,0x6b800083}},	//   _inæq, עווא, rrga, tvng, 
   {{0xb4d8004e,0xcfe802e9,0x8c4400fb,0xe458010f}},	//   bràv, _شفره_, геһе, טיגט_, 
   {{0xf53c0628,0x637c0158,0x672000f3,0x8c340241}},	//   kså_, _hånå, _rtnj, _ko̟k, 
   {{0x20241c38,0x38b024ba,0x2a7d77b9,0x636c0139}},	//   _árið_, _sâra_, rdub_, _könö, 
   {{0x08c577ba,0x229c0316,0x9d1811d2,0x7cd8005f}},	//   рбон, _díky_, _софт_, _pārņ, 
   {{0x2a7d77bb,0x00000000,0x00000000,0x00000000}},	//   pdub_, --, --, --, 
   {{0x636c01b8,0xf53c0158,0x229c01ef,0x5ba41188}},	//   _lönö, fså_, _fíky_, _уруз, 
   {{0x7d0c442e,0xb4d800e4,0x00000000,0x00000000}},	//   _ünsü, tuàp, --, --, 
   {{0xc8c80592,0x00000000,0x00000000,0x00000000}},	//   _جوتن_, --, --, --, 
   {{0xc30577bc,0xdc08005f,0xd8741d0a,0xca60022e}},	//   لبرو, mēģi, _دانب, _mulо, 
   {{0x422577bd,0xb4d800cf,0xdc0800e2,0xf65c0fac}},	//   рдав, dràu, lēģi, snær_, 
   {{0xee0c07f7,0x81440244,0x3120447e,0x00000000}},	// [27100] िशोध_, شنان, ждуг, --, 
   {{0xdb1801ed,0x446400f3,0x3024035b,0x00000000}},	//   szvé, _твов, иоуп_, --, 
   {{0xb1781445,0x437577be,0xbe1433d2,0x00000000}},	//   _byås, _тупт, لوضع, --, 
   {{0x33d806a9,0x7d0401ed,0x57cc010f,0x00000000}},	//   _יחיד, _éksz, עמאַ, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf0b40014,0x940006be,0xcd280137,0x00000000}},	//   _پێمژ_, _anhə_, اسنن_, --, 
   {{0xdd940831,0x9f5c0664,0xb21801bf,0x00000000}},	//   раһы, ävä_, _knæp, --, 
   {{0xeb940640,0x229c01ef,0x00000000,0x00000000}},	//   рић_, _píky_, --, --, 
   {{0x7d080022,0x4274069d,0xb4d801ab,0xdce00153}},	//   _анаг_, _ቢዝነስ_, nsàc, _apmą, 
   {{0x7cf4025a,0x6b780882,0x3f8802fb,0x9aa40092}},	//   mâro, ṅgal, _krbu_, ላችኋል_, 
   {{0xe8dc0208,0x00000000,0x00000000,0x00000000}},	//   _cuốj_, --, --, --, 
   {{0xf53c39c2,0x00000000,0x00000000,0x00000000}},	//   tså_, --, --, --, 
   {{0x74a4033a,0x00000000,0x00000000,0x00000000}},	//   ајве, --, --, --, 
   {{0x3f880268,0xf53d77bf,0x68400139,0x98a400e2}},	//   _orbu_, rså_, _cídı, rsmē_, 
   {{0xe72c05d4,0xf2c577c0,0xb178a2ec,0xb4d80137}},	//   _قصي_, асан, _nyår, dràt, 
   {{0x96353d5e,0x00000000,0x00000000,0x00000000}},	//   _униц, --, --, --, 
   {{0x92000c66,0x3f88022e,0x636c01f4,0x99840064}},	// [27110] लेंज_, _arbu_, _pönö, mamų_, 
   {{0x3cfc01f5,0x54540798,0x64a40114,0x00000000}},	//   _nhtv_, _увот, _мања, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x92b4030c,0x99840024,0x8c3401e1,0x00000000}},	//   _اڭسا, namų_, _to̟k, --, 
   {{0x2bdc07af,0xb4d801ab,0x3f8802f0,0x38480023}},	//   _पुजा, bràt, _erbu_, ሓሳስብ, 
   {{0xb4d800f7,0x99840064,0x00000000,0x00000000}},	//   cràt, hamų_, --, --, 
   {{0x3f880e3c,0x99840024,0xcba45b7f,0xdfd4688a}},	//   _grbu_, kamų_, сайй, _доры, 
   {{0x99840006,0xdea412fd,0x4a742f09,0x64a4012d}},	//   jamų_, _ویلی, сыкт, _ऐक्श, 
   {{0xdc08005f,0x998400c0,0x00000000,0x00000000}},	//   tēģi, damų_, --, --, 
   {{0x487977c1,0xb5f801e7,0x6d4400b8,0x00000000}},	//   усия_, rfál, _ājah, --, 
   {{0xb69853ab,0x00000000,0x00000000,0x00000000}},	//   rmân, --, --, --, 
   {{0x660001f1,0x869806ed,0x69c80490,0x99840064}},	//   ýmko, утот_, _तेथी, gamų_, 
   {{0x44240198,0x769c0de2,0x46a4039b,0x09e02b1b}},	//   _ƙo_, _jëyy, _ҳайв, মেজা, 
   {{0x78b977c2,0x00000000,0x00000000,0x00000000}},	//   chtv, --, --, --, 
   {{0x8af800df,0x00000000,0x00000000,0x00000000}},	//   ָפּק, --, --, --, 
   {{0x7bcc28b5,0xb4d800cf,0x57242586,0x6ab8005b}},	//   _žbuk, fràs, _بروق, nhuf, 
   {{0x66f801e1,0x3f8801a6,0x870401ed,0xca800139}},	// [27120] _e̟kó, _srbu_, _پڑھے_, _ütеr, 
   {{0xa49416e6,0xb1407927,0x7cf400a2,0xb5f800e5}},	//   _بیست, янул, gârl, kfáj, 
   {{0xd5e8c0e3,0xb5f801d3,0x00000000,0x00000000}},	//   _معین_, jfáj, --, --, 
   {{0x443977c3,0x27140356,0x3f8801ef,0x00000000}},	//   _hep_, _căni_, _vrbu_, --, 
   {{0x443977c4,0x2efc022f,0x6ab80a63,0x1c3800b1}},	//   _kep_, _dhuf_, dhuf, азлы_, 
   {{0x443977c5,0x628577c6,0x5f940451,0x7cf40356}},	//   _jep_, ldio, _وڄائ, cârl, 
   {{0x4438047e,0x69cc0077,0x66080118,0x00000000}},	//   _mep_, úcen, ědky, --, 
   {{0x44380219,0xcaa40075,0x6ab801f7,0x00000000}},	//   _lep_, قلىۋ, ghuf, --, 
   {{0x98b800a8,0x39400c6a,0x2bc40075,0xae1805d0}},	//   илит_, éks_, иләп_, _תומכ, 
   {{0x628405da,0xad180375,0xb178008f,0x7c6577c7}},	//   hdio, _עובר, נטיר, _دارل, 
   {{0xbb840fa2,0x15e02122,0x99840153,0x7c3800de}},	//   _دلاي, _गुजर_, tamų_, _ietr, 
   {{0x7c3977c8,0xeb9402e4,0xf98977c9,0x62840356}},	//   _hetr, _לדבר_, _مخته_, jdio, 
   {{0x62840f7b,0x443977ca,0x7c3977cb,0xb1780fac}},	//   ddio, _bep_, _ketr, _nyåp, 
   {{0xf77177cc,0x7c3977cd,0x443977ce,0x628548fb}},	//   _فاع_, _jetr, _cep_, edio, 
   {{0x443977cf,0x62840b4f,0x67d0059f,0x7cf40356}},	//   _dep_, fdio, _ношу, vârl, 
   {{0x443977d0,0x8c3401e1,0x656000a3,0x656c007c}},	//   _eep_, _fo̟w, àmhc, ålhä, 
   {{0x443977d1,0xe3b01893,0xaee00055,0x7c38035a}},	// [27130] _fep_, ورہ_, _haṇa, _oetr, 
   {{0x443977d2,0x2efc0a63,0x628400c5,0xaee000b8}},	//   _gep_, _shuf_, adio, _kaṇa, 
   {{0xaee00055,0x00000000,0x00000000,0x00000000}},	//   _jaṇa, --, --, --, 
   {{0x8d74db35,0x443977d3,0x7c380109,0xb8f8025c}},	//   قاتا, _zep_, _aetr, _ཡམ_, 
   {{0x443817c7,0x7cf40356,0x00000000,0x00000000}},	//   _yep_, pârl, --, --, 
   {{0x4438004d,0x63b800e4,0x60191ee7,0x00000000}},	//   _xep_, _ñaní, _горя_, --, 
   {{0x6ab802ce,0xdb0c01ef,0x00000000,0x00000000}},	//   thuf, _škád, --, --, 
   {{0x4aa80025,0x7c3977d4,0x769c0de2,0x3cb0010b}},	//   ркин_, _eetr, _tëyy, зйәр, 
   {{0xeb9577d5,0x7c3977d6,0xed140014,0x6cb00032}},	//   риқ_, _fetr, _طفاں_, _нөкт, 
   {{0x7c3840e9,0x6e3977d7,0x6ab977d8,0x7dc4022e}},	//   _getr, _heub, shuf, _mаsl, 
   {{0x6ab802c4,0x443977d9,0x628403cb,0xc05002e4}},	//   phuf, _rep_, ydio, וזי_, 
   {{0x7c38171e,0x443933f2,0x00000000,0x00000000}},	//   _zetr, _sep_, --, --, 
   {{0x443977da,0x6e3977db,0x7c3977dc,0xaca0001e}},	//   _pep_, _meub, _yetr, _huốn, 
   {{0x6e3977dd,0x44380978,0x7d0577de,0xd7c80451}},	//   _leub, _qep_, _èkst, _ڏوهه_, 
   {{0x4438ac5c,0x86c40fb4,0xdce00024,0xb4d8381a}},	//   _vep_, _ويتن, _esmė, tràr, 
   {{0x4438047e,0x6e3977df,0x628577e0,0xaca0004d}},	//   _wep_, _neub, udio, _muốn, 
   {{0x443977e1,0x291d77e2,0x00c90fe0,0xaca00208}},	// [27140] _tep_, nqua_, алак_, _luốn, 
   {{0x2564014a,0xb4d805d5,0x44380139,0xaee00055}},	//   möl_, lsàn, _uep_, _yaṇa, 
   {{0x256429ef,0x7c3977e3,0x6e380438,0xe7ec6c95}},	//   löl_, _retr, _beub, _घुमा_, 
   {{0x7c3977e4,0x82900137,0xcfa8007b,0x00000000}},	//   _setr, _تۇرچ, حاكم_, --, 
   {{0x256429ef,0x8eb00533,0x22400489,0xfce41c13}},	//   nöl_, رەكت, maik_, оодо, 
   {{0x645d77e5,0x224177e6,0x4d3802bf,0x00a00244}},	//   ngri, laik_, сяця_, _تیئێ, 
   {{0x645d77e7,0x25654e48,0xaca0004d,0x00000000}},	//   igri, höl_, _cuốn, --, 
   {{0xf96956bd,0x256429ef,0x22400ac5,0x7c380b6f}},	//   арой_, köl_, naik_, _wetr, 
   {{0x256577e8,0x00000000,0x00000000,0x00000000}},	//   jöl_, --, --, --, 
   {{0x256429ef,0x224177e9,0x6e38005a,0x98b83e2e}},	//   döl_, haik_, _zeub, слот_, 
   {{0x224177ea,0xab24030d,0x6e380208,0xd79402e8}},	//   kaik_, _доха_, _yeub, чинъ, 
   {{0x256429ef,0x8b64005e,0xb4d800e8,0xaee00055}},	//   föl_, _ءالم, gsàn, _vaṇa, 
   {{0x291c0622,0x256577eb,0x658577ec,0x1dbc1a2a}},	//   cqua_, göl_, мырз, ्छित, 
   {{0x645c2ebe,0xb4d805da,0x656001c3,0x20180200}},	//   ggri, asàn, àmha, _ngri_, 
   {{0xaca007ae,0xa8540375,0x00000000,0x00000000}},	//   _xuốn, _ויוה_, --, --, 
   {{0x201977ed,0x256429ef,0x21200548,0x645c26bb}},	//   _agri_, böl_, fqih_, agri, 
   {{0xb3600f16,0x6e3977ee,0x11540816,0x11f400db}},	// [27150] ስቲያን_, _reub, якаю, سترگ, 
   {{0x6e3977ef,0x645d77f0,0xddc0012d,0x00000000}},	//   _seub, cgri, _odmł, --, 
   {{0x2fc577f1,0x224177f2,0x2120011f,0xb3840244}},	//   àng_, baik_, aqih_, _بێزم_, 
   {{0x394410ba,0x2120011f,0x201977f3,0x61f81427}},	//   _ovos_, bqih_, _egri_, ðalæ, 
   {{0x21642377,0x00000000,0x00000000,0x00000000}},	//   _отрг, --, --, --, 
   {{0xc170008d,0xc0c000d1,0x628003b2,0xe3dc00fe}},	//   _רחם_, _пәхи, _ómor, _ধৰিব, 
   {{0x8fa4fa1c,0x6e3977f4,0x394577f5,0x25641f96}},	//   _عمره, _teub, _avos_, zöl_, 
   {{0x63a84e9b,0x291c0208,0xf1dc3cbe,0xdec801c4}},	//   ødni, tqua_, _नखान, _дуул_, 
   {{0x1a6977f6,0x645c115d,0xdea401b9,0x291c068c}},	//   تینی_, ygri, _تینی, uqua_, 
   {{0x8e7c01e4,0x25640793,0x291c06af,0x4b200131}},	//   _ekŝt, völ_, rqua_, _كېتە, 
   {{0x291d77f7,0x46e83d51,0x9c0000c7,0x06e800cf}},	//   squa_, йдон_, _иҧше, ймок_, 
   {{0x2564014a,0xda781d0b,0x645c0175,0x00000000}},	//   töl_, _мяч_, wgri, --, 
   {{0x645d77f8,0x291c0194,0xb4d801ab,0x22400254}},	//   tgri, qqua_, rsàn, vaik_, 
   {{0xb4d807c5,0x645c0158,0x256577f9,0x00000000}},	//   ssàn, ugri, röl_, --, 
   {{0x645d77fa,0x224177fb,0x25643690,0x7dc4022e}},	//   rgri, taik_, söl_, _rаsm, 
   {{0xa2cc05ba,0x645c00a9,0x256401b8,0xada000d0}},	//   _सगळ्, sgri, pöl_, _klúč, 
   {{0x224177fc,0x20185552,0x00000000,0x00000000}},	// [27160] raik_, _pgri_, --, --, 
   {{0x7080013e,0xaca00051,0x00000000,0x00000000}},	//   нгуз, _muồn, --, --, 
   {{0xaca001fb,0x224000c5,0x7e280024,0xb11002c9}},	//   _luồn, paik_, біла_, رومغ, 
   {{0x644801a9,0x9e7400cf,0x00000000,0x00000000}},	//   аdig, بۇرت, --, --, 
   {{0x6e4177fd,0x568c008f,0x80d00137,0x2c6c0139}},	//   رنوم, יטאַ, _كۅرچ, kıdı_, 
   {{0x51740150,0x2a6c002f,0x20180037,0x80d80154}},	//   _تەكس_, _abgb_, _ugri_, _বীর্, 
   {{0xafe177fe,0x200c01e1,0xb5f80332,0x1b1c00cc}},	//   _зорл, _àdi_, rfái, _নবহে_, 
   {{0x3af802d3,0xaca001fb,0xca60022e,0xba750fec}},	//   rëpo_, _buồn, _qulа, ساعت, 
   {{0xaca0001e,0x00000000,0x00000000,0x00000000}},	//   _cuồn, --, --, --, 
   {{0x2c6c08a9,0x00000000,0x00000000,0x00000000}},	//   gıdı_, --, --, --, 
   {{0xf0900375,0x00000000,0x00000000,0x00000000}},	//   גנת_, --, --, --, 
   {{0x4b5400a7,0x3a2400d8,0x00000000,0x00000000}},	//   _цъфт, _ufop_, --, --, 
   {{0x6f00fd3a,0xf1bc2b76,0x3944009a,0xaca00208}},	//   ïnci, _afán_, _uvos_, _guồn, 
   {{0x9418013f,0x798177ff,0xb8646722,0x00000000}},	//   ɛyɛn_, _isow, _راتو, --, 
   {{0xdce0002b,0xada000d0,0x00000000,0x00000000}},	//   _asmī, _zlúč, --, --, 
   {{0x78a80ea0,0x22840137,0x56940022,0x00000000}},	//   _hofv, нууг, _цаит, --, 
   {{0x62d404fb,0xb4d800db,0xaca0004d,0xa17401ec}},	// [27170] رآفر, lsàm, _xuồn, нгті, 
   {{0x79800161,0xbb4c0150,0x4fc000d1,0x00000000}},	//   _msow, _ﺃﻋﻁ_, پەرە, --, 
   {{0x3b1c01b9,0x00000000,0x00000000,0x00000000}},	//   _nutq_, --, --, --, 
   {{0x79817800,0x6ee400c6,0x00000000,0x00000000}},	//   _osow, أسئل, --, --, 
   {{0x25d8010f,0x1d240150,0x00000000,0x00000000}},	//   ּוון_, емім, --, --, 
   {{0x7dc401a9,0x8b94009b,0x6134022e,0xaca00208}},	//   _mаsh, дрич, mоlо, _ruồn, 
   {{0x798004ba,0xf41c03d4,0x00000000,0x00000000}},	//   _asow, _বজাৰ_, --, --, 
   {{0x7eb800b0,0x092816ab,0xab60012d,0x7bf400db}},	//   _tïpa, ожий_, łżon, بىىز_, 
   {{0xec697801,0x09043da1,0xcda800c6,0x7dc4022e}},	//   _грек_, мпин, _بهذه_, _nаsh, 
   {{0x7d057802,0x2c24030d,0x00000000,0x00000000}},	//   _èksp, _хьаг, --, --, 
   {{0x79817803,0x38c80133,0x00000000,0x00000000}},	//   _esow, ڵایی_, --, --, 
   {{0xb4d8067c,0xaca00208,0x00000000,0x00000000}},	//   ssàl, _tuồn, --, --, 
   {{0x19940006,0xfa5411c5,0x00000000,0x00000000}},	//   _паця, _زرنگ, --, --, 
   {{0xc76438eb,0xa65800fd,0x443c3add,0x00000000}},	//   _قاعى, _şöğe, út_, --, 
   {{0x07a401c0,0x00000000,0x00000000,0x00000000}},	//   _цайн, --, --, --, 
   {{0x7cf40276,0xdb2401ed,0x78a80010,0x43080451}},	//   râri, éséh, _zofv, زيءَ_, 
   {{0x80a80cc9,0x69cc0419,0x00000000,0x00000000}},	// [27180] овав_, úceh, --, --, 
   {{0x823405d9,0x00000000,0x00000000,0x00000000}},	//   _ڪردا, --, --, --, 
   {{0xbea4005b,0x00000000,0x00000000,0x00000000}},	//   мажк, --, --, --, 
   {{0x82345767,0x6aa80042,0x7e9858c5,0xf65c072b}},	//   _تردا, _nogf, تنصر_, liær_, 
   {{0xd1740139,0x8c3401e1,0xe7ec0456,0x00000000}},	//   _пыры, _ro̟r, _घुसा_, --, 
   {{0x3e4c0016,0xbb28084c,0x00000000,0x00000000}},	//   ột_, оцие_, --, --, 
   {{0x6aa8037e,0xeb940e92,0x00000000,0x00000000}},	//   _bogf, диј_, --, --, 
   {{0x3e8402d5,0x78a801e4,0xd1480244,0xb2b800df}},	//   _būtų_, _sofv, _بشێن_, ַמיר, 
   {{0x6aa97804,0xbc64026a,0xb5f81dec,0x6f000311}},	//   _dogf, _овак, nfát, înce, 
   {{0x3ea405ac,0x00000000,0x00000000,0x00000000}},	//   ljot_, --, --, --, 
   {{0xf1bc011f,0xd6d46cea,0xf65c05ac,0x3dc4009a}},	//   _afál_, ежны, diær_, lzow_, 
   {{0x3ea406a3,0x79800198,0xc7641884,0x00000000}},	//   njot_, _tsow, راپى, --, 
   {{0x3dc40327,0x00000000,0x00000000,0x00000000}},	//   nzow_, --, --, --, 
   {{0xe8900124,0x00000000,0x00000000,0x00000000}},	//   _аашь, --, --, --, 
   {{0xb2a90add,0x7ae00327,0x24182f6a,0xf6e4234c}},	//   отаж_, _kjot, доры_, _оцин, 
   {{0x260c0490,0x7dc401b9,0xb5f80599,0x00000000}},	//   ठेही_, _tаsh, rgáb, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [27190] --, --, --, --, 
   {{0x20c401c7,0x7ae08731,0x3ea001d5,0x3ea400ef}},	//   _löif_, _ljot, ғишг, ejot_, 
   {{0x7ae000e4,0x00000000,0x00000000,0x00000000}},	//   _ojot, --, --, --, 
   {{0x7ae0002e,0x62080790,0x00000000,0x00000000}},	//   _njot, örlü, --, --, 
   {{0x6aa80217,0x7e9c0356,0x00000000,0x00000000}},	//   _rogf, _săpâ, --, --, 
   {{0x7ae0005b,0x3ea40108,0xfcc00139,0xe7fc01f9}},	//   _ajot, ajot_, ләхм, _उरला_, 
   {{0x6e6401d5,0x00000000,0x00000000,0x00000000}},	//   _отаж, --, --, --, 
   {{0x3b0431c5,0xd1c8001f,0xc9a809ed,0x59d007af}},	//   _choq_, _በሞት_, звие_, _तेहर, 
   {{0x7ae17805,0x3dc48767,0xac8001a9,0x00000000}},	//   _djot, czow_, _аҳлл, --, 
   {{0x48cc0f22,0xa3e052f2,0x6ca40006,0x00000000}},	//   রক্র, _दखल_, _ўраж, --, 
   {{0x6aa8780b,0x00000000,0x00000000,0x00000000}},	//   _togf, --, --, --, 
   {{0xddc0007f,0x3b04014f,0x59d017ee,0x00000000}},	//   _bemň, _ghoq_, _तेवर, --, 
   {{0x5a4400c0,0x00000000,0x00000000,0x00000000}},	//   _рэха, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7cf4019f,0x68e0009a,0x8c100154,0x2c0c00cd}},	//   câru, _ijnd, _স্তন_, ाधिं_, 
   {{0x7eb800b0,0x05640212,0x00000000,0x00000000}},	//   _rïpo, _звин, --, --, 
   {{0x26c0166a,0x410428e8,0x3af8008f,0xb5f800e5}},	// [271a0] _ilio_, езав, פּלע, rgác, 
   {{0x66048cdb,0xe0580330,0xf0600798,0xa2780092}},	//   _izik, بیست_, лкуп, ርቱካን_, 
   {{0xb5f802f0,0x7e280024,0x00000000,0x00000000}},	//   sfát, піла_, --, --, 
   {{0x9f5802d3,0x44280332,0x3dc4002f,0x00000000}},	//   _hyrë_, lcb_, tzow_, --, 
   {{0x26c000ec,0x29040477,0x3ea4ba5d,0x4428007c}},	//   _mlio_, _ohna_, rjot_, ocb_, 
   {{0x66057806,0xaca001fb,0x26c00042,0x3b040240}},	//   _mzik, _muỗn, _llio_, _shoq_, 
   {{0x26c17807,0x3dc57808,0xb5f802f0,0xac14081b}},	//   _olio_, szow_, nfár, ношу_, 
   {{0x2904ad1e,0x6604542c,0x68e0009b,0x39a40353}},	//   _ahna_, _ozik, _ajnd, ешов, 
   {{0xed557809,0x6605780a,0x44280175,0x00000000}},	//   _пот_, _nzik, kcb_, --, 
   {{0x26c1780b,0xb865780c,0xccd40124,0x29040064}},	//   _alio_, راخو, _ицхы, _chna_, 
   {{0x6604714b,0x7ae01a83,0x7d19780d,0x7e6000ec}},	//   _azik, _tjot, _iits, ogop, 
   {{0x7e61780e,0x7d19780f,0x7ae061b5,0x2904009d}},	//   ngop, _hits, _ujot, _ehna_, 
   {{0x7d197810,0x00000000,0x00000000,0x00000000}},	//   _kits, --, --, --, 
   {{0x66057811,0x7d18000f,0x26c17812,0x4ddc0c58}},	//   _dzik, _jits, _elio_, _বৰুৱ, 
   {{0x7d197813,0x66046643,0x7e617814,0x27f00122}},	//   _mits, _ezik, kgop, čané_, 
   {{0x7d197815,0x26c001ab,0x442800a3,0x35680117}},	//   _lits, _glio_, acb_, _ерон_, 
   {{0x77c4002e,0x7d1801a9,0xb28400c7,0x00000000}},	// [271b0] _féxé, _oits, _ҧымк, --, 
   {{0x7d180851,0x93b400c7,0x387c0165,0x00000000}},	//   _nits, _абоц, netr_, --, 
   {{0xa854011a,0x9f480241,0x00000000,0x00000000}},	//   תיבה_, _éhìn_, --, --, 
   {{0x7d197816,0x387c0109,0x9f580240,0x7e617817}},	//   _aits, hetr_, _zyrë_, ggop, 
   {{0x7d197818,0x09b4015b,0x2f04000d,0x00000000}},	//   _bits, _জেনা, jõge_, --, 
   {{0xd0440cc1,0x7d197819,0x7e6001f5,0xd10801d5}},	//   yihə, _cits, agop, _آقسه_, 
   {{0x7d19781a,0x7cf4054e,0x5f9401b9,0x3de003d4}},	//   _dits, vârt, _йирт, _বৰদল, 
   {{0x7d19781b,0x29040652,0x4a74807e,0x00000000}},	//   _eits, _shna_, тыкт, --, 
   {{0x7d181311,0x290401ab,0x394050d5,0xdd580cc9}},	//   _fits, _phna_, аныг, _патч_, 
   {{0x7d19781c,0xf1bc011f,0x81e40eac,0x00000000}},	//   _gits, _afák_, _ফরম_, --, 
   {{0x6f19781d,0x6d49781e,0xa2c416d1,0x660401ed}},	//   _kiuc, lsga, रसम्, _szik, 
   {{0x7d186e1a,0x6d4800a3,0x86980798,0x00000000}},	//   _zits, osga, фтот_, --, 
   {{0x95981142,0x6d49781f,0x7d197820,0x6ab801f7}},	//   нтру_, nsga, _yits, mkuf, 
   {{0x7d1806e4,0x6d497821,0x39540375,0x99d49dc7}},	//   _xits, isga, _ישנם_, _حتما, 
   {{0x44280589,0x6b800369,0x6ab97822,0x6d48022e}},	//   rcb_, nwng, okuf, hsga, 
   {{0x3af8044e,0x6d484bc1,0x26c000ec,0x6ab97823}},	//   tëpi_, ksga, _ulio_, nkuf, 
   {{0x6d4801a4,0x44280175,0x7c280076,0xb58400db}},	// [271c0] jsga, pcb_, ycfr, _айыз_, 
   {{0x67217824,0x6d497825,0xf55802e4,0x03240107}},	//   _kunj, dsga, _קדימ, _идон, 
   {{0x7d197826,0xb5f97827,0x6f180286,0x67217828}},	//   _rits, ngán, _biuc, _junj, 
   {{0x6f197829,0x7d183917,0xc1d00131,0x00000000}},	//   _ciuc, _sits, _көзә, --, 
   {{0x7d19782a,0x6b800649,0x6d49782b,0x6721782c}},	//   _pits, ewng, gsga, _lunj, 
   {{0x6b800007,0x7d180869,0x67200cad,0xed4c01d9}},	//   fwng, _qits, _ounj, تھِ_, 
   {{0x67200264,0x7d19782d,0xf1bc011f,0xbae41ebb}},	//   _nunj, _vits, _afáh_, кций, 
   {{0x7d1808e7,0x6f19782e,0xafe117ea,0x6d4801bf}},	//   _wits, _giuc, _тосл, bsga, 
   {{0xf2d01203,0x7d19782f,0x20c400c5,0x387c030a}},	//   יעה_, _tits, _töid_, tetr_, 
   {{0x7d18bbd7,0x6ab804ba,0x7dc401d5,0xaca00432}},	//   _uits, akuf, _dаst, _diỳl, 
   {{0x6b800007,0x67200427,0x78b82963,0xaa840244}},	//   cwng, _cunj, rktv, رنیم_, 
   {{0x67200fcf,0x2a7c0c6a,0xb4d800db,0xb994007b}},	//   _dunj, ceub_, nsàv, _للصب, 
   {{0x6720248b,0x48fc07f7,0xf5e401ec,0x7bc8002f}},	//   _eunj, _रीको_, тінм, lzfu, 
   {{0x9f580077,0x33701086,0xa4e402d5,0xbeec01f9}},	//   _eyré_, аҳор, аўск, जवुन_, 
   {{0x67217830,0x56957831,0xcd4c02d3,0x6d4801d3}},	//   _gunj, _байт, _ኣይንፈ, zsga, 
   {{0x42780023,0x61700092,0x6d497832,0x00000000}},	//   _ኣማኢት_, _አካላዊ_, ysga, --, 
   {{0xe2f8eeec,0x6f18026c,0x667400db,0x9a34001f}},	// [271d0] теті_, _riuc, _ئدىر, _በኢንዱ, 
   {{0xdb44168d,0x6f1800a3,0x67217833,0xd2500451}},	//   _وێ_, _siuc, _yunj, _ڏند_, 
   {{0xbeec0490,0x2a7c0c6a,0x6ee474dd,0x00000000}},	//   जवून_, yeub_, پسال, --, 
   {{0x7bc800de,0x00000000,0x00000000,0x00000000}},	//   dzfu, --, --, --, 
   {{0x6d497834,0xb5f800e4,0x00000000,0x00000000}},	//   usga, zgán, --, --, 
   {{0x6b80009a,0x80d001ad,0x00000000,0x00000000}},	//   twng, णोदे, --, --, 
   {{0x6d497835,0xdce000da,0xabc00032,0x6f18010f}},	//   ssga, _apmē, райҙ, _tiuc, 
   {{0xb69800d2,0x63a801e6,0x6720107d,0xdcb800df}},	//   hlâb, ädni, _runj, _riĉe_, 
   {{0x67217836,0x6ab97837,0x6b800399,0xdef8039e}},	//   _sunj, rkuf, swng, _рыр_, 
   {{0x2a7c003e,0x00000000,0x00000000,0x00000000}},	//   seub_, --, --, --, 
   {{0xca757838,0x4a757839,0x9f580306,0x00000000}},	//   _булы, _былт, _pyré_, --, 
   {{0xcfc403f4,0x672000ec,0xe5780107,0x00000000}},	//   _এখান, _vunj, вҷи_, --, 
   {{0x8cb81b76,0xef1c012d,0x00000000,0x00000000}},	//   ्सपो, ężyc_, --, --, 
   {{0xaee01682,0x6721783a,0xd45400d4,0x00000000}},	//   _maṱa, _tunj, итсь, --, 
   {{0xb5f8066d,0xd3b4524d,0xd87530ed,0x00000000}},	//   lgál, асть, _خانب, --, 
   {{0xfa0800fe,0x00000000,0x00000000,0x00000000}},	//   _ষ্টল_, --, --, --, 
   {{0xb5f9783b,0x0204013e,0x8fc401e2,0x00000000}},	// [271e0] ngál, узан, یزمن, --, 
   {{0x03a412b9,0xb538011a,0x8cb804af,0x00000000}},	//   _биоо, _רגיש, ्सफो, --, 
   {{0x63f801d9,0x00000000,0x00000000,0x00000000}},	//   _شہرس_, --, --, --, 
   {{0xfe4489d2,0xbd69783c,0xfde9783d,0x4f9401c6}},	//   ундо, ерке_, ндек_, шруу, 
   {{0xee35783e,0x20c4000d,0x00000000,0x00000000}},	//   унч_, _vöib_, --, --, 
   {{0xb4d8004e,0x7bc80112,0x518400d8,0x00000000}},	//   ssàv, tzfu, _туџа, --, 
   {{0x7bc80156,0x00000000,0x00000000,0x00000000}},	//   uzfu, --, --, --, 
   {{0xdc549f6d,0xc0e401f0,0x00000000,0x00000000}},	//   _چراک, _роҳк, --, --, 
   {{0xdcc80304,0xd6ac00cc,0xae340107,0x32dc0139}},	//   _иңде_, খসময, _сӯхт_, läyä_, 
   {{0x58d45acb,0xcdc401ec,0x57f4004e,0x59b81cd2}},	//   роот, _тауқ, иппт, ेनबर, 
   {{0x290c01e1,0x497401c4,0x00000000,0x00000000}},	//   _ẹkún_, глөс, --, --, 
   {{0xb90425a2,0x2f94008f,0x36882e1d,0x81b800fe}},	//   _өзек, אכטן_, хсон_, _অইন_, 
   {{0xf9905b9b,0xdee40023,0x00000000,0x00000000}},	//   _دبا_, _ምኻን_, --, --, 
   {{0x76980724,0x32dc0166,0x00000000,0x00000000}},	//   _bäyä, käyä_, --, --, 
   {{0xd6d1783f,0x77904f2c,0x76980166,0x00000000}},	//   _وقت_, _ایجا, _cäyä, --, 
   {{0xb5a4a5cb,0x1dc41fc4,0xdee402dd,0xe2f801ec}},	//   _брой, वनात, _رۋ_, гесі_, 
   {{0xd1300058,0x2294020f,0xe134004e,0x00000000}},	// [271f0] زما_, щитя, йнты, --, 
   {{0xb5f800e4,0x00000000,0x00000000,0x00000000}},	//   ngám, --, --, --, 
   {{0xde5002d3,0x00000000,0x00000000,0x00000000}},	//   _ከምዝፈ, --, --, --, 
   {{0xb1445598,0x8db400d4,0x43380677,0xb2a801f4}},	//   _میرم_, ислі, _שערב, _чтож_, 
   {{0xa17c0354,0x00000000,0x00000000,0x00000000}},	//   _пурĕ_, --, --, --, 
   {{0x2164005b,0x32dc013d,0xee34010a,0x00000000}},	//   _утюг, bäyä_, ăнч_, --, 
   {{0xdd94052f,0x76980166,0xef9000f1,0x00000000}},	//   _һаты, _xäyä, _دیاد, --, 
   {{0xdef801af,0x00000000,0x00000000,0x00000000}},	//   _быу_, --, --, --, 
   {{0x09e47c85,0x6448022e,0xfe6c01f7,0x00000000}},	//   ропн, аdil, _آگم_, --, 
   {{0x388c03b9,0xb5f831b7,0x48b401f4,0x00000000}},	//   gәr_, rgál, рщит, --, 
   {{0x5eb803d4,0x00000000,0x00000000,0x00000000}},	//   _আগতে, --, --, --, 
   {{0xd490004d,0x49d8005b,0x00000000,0x00000000}},	//   ồn_, _идею_, --, --, 
   {{0x76980598,0x00000000,0x00000000,0x00000000}},	//   _säyä, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x323002e3,0x98f43adf,0xb7d400f2,0x00000000}},	//   _ụnụ_, _اثنا, _پويا_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdee4044e,0x00000000,0x00000000,0x00000000}},	// [27200] _ምኻኑ_, --, --, --, 
   {{0x442c0793,0x769802d1,0xbd8803e6,0xc0cc0092}},	//   _üf_, _täyä, ێنان_, ጣችሁ_, 
   {{0x7e240a83,0xb4d800db,0x85b80214,0x65600332}},	//   адеж, rsàt, _ساکس_, ámhf, 
   {{0x75d00150,0xfe7000ae,0x00000000,0x00000000}},	//   _ديۋا, تدئ_, --, --, 
   {{0xdd941555,0x62857840,0x00000000,0x00000000}},	//   салы, meio, --, --, 
   {{0x6284030a,0x00000000,0x00000000,0x00000000}},	//   leio, --, --, --, 
   {{0x3f88014b,0xeb4411cf,0xafe04eb0,0xbd3400cf}},	//   _usbu_, ачык_, _дорл, _چىرع, 
   {{0x62847801,0x5a3400a7,0x00000000,0x00000000}},	//   neio, щнит, --, --, 
   {{0x63bc691c,0xdb1801d3,0x394177de,0x38a400d8}},	//   hyrn, nyvé, èks_, ајнб, 
   {{0x628400d8,0x7c6400d1,0x00000000,0x00000000}},	//   heio, _خارل, --, --, 
   {{0x569430cb,0x63bc03a2,0x628402b5,0xfa3402dd}},	//   бант, jyrn, keio, _күйі_, 
   {{0xda700050,0xdb1800c7,0xd67800d1,0x00000000}},	//   _رُت_, kyvé, اڭغا_, --, 
   {{0x9934473f,0x670801c0,0x62857841,0xb604117e}},	//   _افتت, рээг_, deio, рянк, 
   {{0x2978010f,0x00000000,0x00000000,0x00000000}},	//   _סטוא, --, --, --, 
   {{0xd9e800bd,0x3228109a,0x63bd7842,0x00000000}},	//   _পরিম, візм_, gyrn, --, 
   {{0xf1bc004d,0x6284015d,0xf2040139,0x35440354}},	//   _ngác_, geio, аязо, _кхов, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [27210] --, --, --, --, 
   {{0xd9e800bd,0x63bc00a2,0xe6100769,0x00000000}},	//   _পরাম, byrn, _غشي_, --, 
   {{0xd93002d3,0x6285631a,0x00000000,0x00000000}},	//   _ተጣበቕ, beio, --, --, 
   {{0xdcb8008f,0x62840798,0x00000000,0x00000000}},	//   _riĉa_, ceio, --, --, 
   {{0xdce00166,0x00000000,0x00000000,0x00000000}},	//   _armı, --, --, --, 
   {{0x359c0023,0x00000000,0x00000000,0x00000000}},	//   ውሞታት_, --, --, --, 
   {{0x4a74004e,0x98c0012d,0xcfe80633,0x00000000}},	//   быпт, एसईए, _صفره_, --, 
   {{0x3ab00116,0x00000000,0x00000000,0x00000000}},	//   зәшт, --, --, --, 
   {{0x85a001ec,0xce3400f1,0x00000000,0x00000000}},	//   _ﳌﺎﺫﺍ_, _نوځک, --, --, 
   {{0x08c4059f,0x8d7403e6,0x62840165,0x20c401f4}},	//   сбон, _ناڕا, zeio, _löin_, 
   {{0x6284009f,0xe90001c6,0xdce000c0,0xaee000b8}},	//   yeio, йцүү, _apmė, ciṣe, 
   {{0x9abc0327,0x00000000,0x00000000,0x00000000}},	//   _luċj, --, --, --, 
   {{0x66080034,0x59c400c6,0x87c40014,0x63bc0042}},	//   ędko, _ويمك, شتھٕ, wyrn, 
   {{0x63bcc8bb,0x1cbc0327,0xdb1800c7,0x00000000}},	//   tyrn, ཅིག_, vyvé, --, 
   {{0xb4d80109,0x42549a52,0x00000000,0x00000000}},	//   tsàr, йтат, --, --, 
   {{0x86457843,0xb6980a85,0xd9e80183,0x01640229}},	//   _униж, llân, _পৰিম, йкбо, 
   {{0x62857844,0x312000f7,0xb4d8004e,0xf46c0023}},	// [27220] reio, здуг, rsàr, _ኣጻምእ_, 
   {{0xb4d819c6,0xb6997845,0x62857846,0x3af801c7}},	//   ssàr, nlân, seio, hëpp_, 
   {{0x201c0724,0xd9e80183,0xdb180022,0x00000000}},	//   ävi_, _পৰাম, syvé, --, 
   {{0xf410025f,0x93249a5a,0x9f5800e4,0xdb1800c7}},	//   _מפת_, _گرین, _ayrã_, pyvé, 
   {{0x22417847,0xf65c01bf,0x00000000,0x00000000}},	//   mbik_, skæg_, --, --, 
   {{0x399c145e,0x932401d9,0xaee00882,0x3618008f}},	//   _lâsô_, _درین, tiṣe, אונד, 
   {{0x09b400bd,0xeb8c31ed,0xb698000f,0xdd9401e0}},	//   _জেলা, فظي_, dlân, саһы, 
   {{0x224007ab,0xeb940640,0x1cbc0327,0xbb4800db}},	//   nbik_, сић_, ཅིང_, _ەلان_, 
   {{0x41dc0316,0x8eb00c50,0x7d2401d9,0x22400254}},	//   _नेमस, _تەنت, _طفان, ibik_, 
   {{0xa2d800dc,0x00000000,0x00000000,0x00000000}},	//   नोत्, --, --, --, 
   {{0xdce00166,0x00000000,0x00000000,0x00000000}},	//   _urmı, --, --, --, 
   {{0x76a97848,0xb5f800c6,0x7eb802b5,0x00000000}},	//   утов_, lgái, _tïpu, --, 
   {{0x3a24004e,0x77900bce,0xb698054e,0xb5f800ae}},	//   _igop_, زیکا, blân, ogái, 
   {{0xb5f97849,0x20c4005b,0x00000000,0x00000000}},	//   ngái, _söin_, --, --, 
   {{0xf7712554,0xf484008e,0x2900025c,0xf2c4022e}},	//   _راغ_, _һунн, ċjat_, бсан, 
   {{0x386c06af,0xb4d800e4,0x9634117e,0xed5c00d7}},	//   _hcfr_, asàp, _ьниц, ôžko_, 
   {{0x764d784a,0xdcb80115,0xf4841e28,0x20c40254}},	// [27230] macy, _niĉo_, _лунн, _vöin_, 
   {{0xf0b9784b,0x764c0034,0x905402bf,0x746802e8}},	//   دارش_, lacy, івец, _срив_, 
   {{0x7bdc5178,0x2241784c,0xa6200023,0x39440332}},	//   úpul, bbik_, ተዘይኰ, _lwos_, 
   {{0x764d784d,0x3a25784e,0x63a801bf,0x1dc403ce}},	//   nacy, _ngop_, ådne, वनंत, 
   {{0x9f580c67,0xac9400e5,0x00000000,0x00000000}},	//   _pyrã_, ینچا_, --, --, 
   {{0x0fe400fd,0x94000213,0x764c058a,0xdef80961}},	//   _һөҗү, _sahə_, hacy, _ғыс_, 
   {{0x764d784f,0x66d001e1,0x66e400e5,0xb5f800e5}},	//   kacy, _jòkù, lőke, gfáz, 
   {{0xb5f800c6,0xb4d8004e,0x764c033f,0xcc8800f1}},	//   agái, bpàg, jacy, انګه_, 
   {{0xb69800d8,0x3af80036,0x88c97850,0x764d7851}},	//   tlân, rëpp_, илив_, dacy, 
   {{0xac757852,0x00000000,0x00000000,0x00000000}},	//   _دارش, --, --, --, 
   {{0xb698334b,0x39440158,0x46e81606,0x06e80cc9}},	//   rlân, _ewos_, идон_, имок_, 
   {{0x764d7853,0xb698002d,0x6f000356,0x00000000}},	//   gacy, slân, înch, --, 
   {{0x3944007f,0x7540084c,0x2908068c,0x88940166}},	//   _gwos_, мняз, ïcas_, _мидх, 
   {{0x66d001e1,0x42c4015b,0x764c0334,0x66e400e5}},	//   _bòkù, _এদেশ, aacy, dőke, 
   {{0x2efc0270,0x764c0230,0xa3040166,0x224003e0}},	//   _okuf_, bacy, зүне, tbik_, 
   {{0x05640b87,0x2240030a,0x764c035a,0xd7f822cb}},	//   _двин, ubik_, cacy, _ууч_, 
   {{0x2240011f,0x23280fc0,0x00000000,0x00000000}},	// [27240] rbik_, роғи_, --, --, 
   {{0x66057854,0x6724003e,0xb69800d2,0xdcb80115}},	//   _iyik, _hiij, hlâl, _riĉo_, 
   {{0x7f857855,0x8e5402d3,0x606400d1,0xbf880395}},	//   تلان, _ከምዝጸ, يۇڭل, рбеж_, 
   {{0x7dc40137,0xdcb801e4,0x2240011f,0x67244cbd}},	//   يقان, _piĉo_, qbik_, _jiij, 
   {{0x3f840030,0xddc80034,0x67240009,0xafc00153}},	//   ňou_, _żołn, _miij, _įžūl, 
   {{0x764d7856,0x312002bf,0xdcb801e4,0x00000000}},	//   zacy, _одяг, _viĉo_, --, 
   {{0xb5f97857,0x7b640220,0x764d7858,0x601002d2}},	//   rgái, ітке, yacy, _dómí, 
   {{0x66040944,0xeaf414a5,0x9e7402dd,0xcaa400d1}},	//   _oyik, يريت_, _ءۇشت, كلىۋ, 
   {{0xda780597,0x66057859,0x764d785a,0xef1400d4}},	//   _ąяą_, _nyik, vacy, _єму_, 
   {{0xb178008f,0x764d785b,0x60100241,0xdde401ee}},	//   סטיר, wacy, _gómí, _мәҙү, 
   {{0xb5f9785c,0xf1bc2b5f,0x67244e40,0x9abc025c}},	//   ngáv, _ngán_, _biij, _luċi, 
   {{0x99e800bd,0x66040526,0x8b64215c,0xb1980023}},	//   _পরীক, _byik, _رامم, ፈልጥዎ_, 
   {{0x764d785d,0x66040526,0xe9cc04fb,0x6f0061bd}},	//   racy, _cyik, _لغو_, înci, 
   {{0x660402b9,0x67240083,0x79805fa6,0xcfb000cc}},	//   _dyik, _eiij, _ipow, চনতন, 
   {{0xd7580451,0x6605785e,0x67240009,0x94040214}},	//   _البت_, _eyik, _fiij, سوره, 
   {{0x7980063f,0xb880012c,0x6724058a,0x66e401d3}},	//   _kpow, řídi, _giij, tőke, 
   {{0xb4240736,0xd52c004d,0x00000000,0x00000000}},	// [27250] _وعدو, _dựn, --, --, 
   {{0x67240472,0xf53c143a,0xf8c81a4e,0x00000000}},	//   _ziij, mpå_, िसिय, --, 
   {{0xb5f8022c,0xb600031c,0x00000000,0x00000000}},	//   ggáv, ġġuk, --, --, 
   {{0x7980068f,0xe8a413e0,0x67240009,0xae6400db}},	//   _opow, _कच्च, _xiij, تەرن_, 
   {{0xed881c3e,0x7980e456,0x4aa80118,0xc234123b}},	//   рсек_, _npow, कासव, _מארז_, 
   {{0xe53c123b,0x00000000,0x00000000,0x00000000}},	//   סתור, --, --, --, 
   {{0x7981785f,0x225000fd,0x00000000,0x00000000}},	//   _apow, _ölkä_, --, --, 
   {{0x4aa97860,0xfe6c2a77,0x2efc031c,0xf53c143a}},	//   скин_, _مگه_, _ukuf_, kpå_, 
   {{0xaca001f2,0xeb942310,0x00000000,0x00000000}},	//   _ahụl, сиқ_, --, --, 
   {{0x9fec1c82,0x88c97861,0x66040223,0xf53c11c0}},	//   _কৰিব_, слов_, _ryik, dpå_, 
   {{0x07a57862,0x79800086,0x660405b1,0x6724030a}},	//   чанн, _epow, _syik, _piij, 
   {{0xf7705841,0x67240194,0xf1bc004d,0x00000000}},	//   راپ_, _qiij, _ngáo_, --, 
   {{0x99e80183,0xf53c00b5,0xb6a00946,0xb5f800e4}},	//   _পৰীক, gpå_, хиял, zgáv, 
   {{0x660407a8,0x80b8033f,0x00000000,0x00000000}},	//   _vyik, _इवें, --, --, 
   {{0x7cf40276,0x67257863,0x969001d5,0x00000000}},	//   târz, _tiij, رییش, --, 
   {{0x65c40220,0x2d9c01c4,0xf7d40677,0x00000000}},	//   _жұма, _orue_, _מוצש_, --, 
   {{0x66046837,0xd52c0051,0x00000000,0x00000000}},	// [27260] _uyik, _vựn, --, --, 
   {{0x9abc031c,0x25a0010e,0xdb1802f0,0xe584004e}},	//   _vuċi, _iril_, vyví, _етүү, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2d9cbe79,0x25a17864,0x20c4000d,0xb5f83168}},	//   _brue_, _kril_, _köik_, rgáv, 
   {{0x2d9c14a9,0xb5f9192c,0x71a000c0,0x00000000}},	//   _crue_, sgáv, _заяз, --, 
   {{0xb5f80579,0xd24c0014,0x2d9c5522,0x2d540108}},	//   pgáv, _مۆہ_, _drue_, чишь_, 
   {{0x92c00c58,0xf65c037e,0x79810bdd,0x2d9c0393}},	//   ্চৰ_, mhæv_, _spow, _erue_, 
   {{0x2d9c008f,0x25a001e1,0xf968005b,0xaff484a1}},	//   _frue_, _oril_, брой_, _رفقا_, 
   {{0xeaac3cd9,0x2d9d7865,0x00000000,0x00000000}},	//   اعى_, _grue_, --, --, 
   {{0xac980092,0x2d5405d0,0x00000000,0x00000000}},	//   ቀበልም_, _משמש_, --, --, 
   {{0xb698006a,0x25a17866,0x32040083,0xdb2400ae}},	//   slâm, _aril_, ęnyi_, úsói, 
   {{0x25a17867,0x8b6401d5,0xf53c0b1a,0x00000000}},	//   _bril_, _آالم, tpå_, --, 
   {{0x25a0067c,0xba180137,0x4aa8193d,0x7980033f}},	//   _cril_, _ايشا_, कारव, _upow, 
   {{0xf53c2ab7,0x25742f7c,0x6560007b,0x0aec0055}},	//   rpå_, رۇپس, ámha, _ṣaḍū, 
   {{0xa8780375,0xf2c57868,0x25a0004e,0xf6e40276}},	//   _האור, псан, _eril_, _нцин, 
   {{0xf53c0158,0xb5f802d2,0x00000000,0x00000000}},	//   ppå_, fgát, --, --, 
   {{0x25a17869,0xa0c401e2,0x00000000,0x00000000}},	// [27270] _gril_, کيلو, --, --, 
   {{0xb0e802f5,0x34480510,0x00000000,0x00000000}},	//   কত্ব_, _учин_, --, --, 
   {{0x2fc401dc,0x23280120,0x5ea401b9,0xceb801ef}},	//   áng_, _ноќи_, کمنل, _poř_, 
   {{0xde580212,0x0cc400cd,0xb5f80162,0xa2a401f9}},	//   заці_, वस्म, sgáu, _चोप्, 
   {{0xa184010b,0x9f04009f,0x00000000,0x00000000}},	//   _пырл, روهو, --, --, 
   {{0x2fc401dc,0xf04001ed,0x00000000,0x00000000}},	//   ơng_, _سٹری, --, --, 
   {{0xf2dd786a,0xfc4400bc,0x537c0023,0x00000000}},	//   _kmâ_, _říci_, _ኣራዊት_, --, 
   {{0x2d9c2403,0xb5f801d3,0x09b400cc,0x00000000}},	//   _true_, ngás, _জেগা, --, 
   {{0xac25786b,0x2f04000d,0x89a9786c,0x00000000}},	//   _ефек, jõgi_, іков_, --, 
   {{0xa7400184,0x5c756e18,0xa2a40243,0x47c42c31}},	//   ндоҙ, _плут, _चोन्, дбов, 
   {{0xb698025a,0xc0500375,0x2c5c00e2,0x4a74030c}},	//   doâb, כזי_, rādē_, _жылт, 
   {{0x25a00115,0x9f640129,0x9f8802d2,0x3f9c5752}},	//   _pril_, étée_, _móða_, _štuk_, 
   {{0x9f88032e,0x25a006be,0x00000000,0x00000000}},	//   _lóða_, _qril_, --, --, 
   {{0xdb1800d7,0x00000000,0x00000000,0x00000000}},	//   myvá, --, --, --, 
   {{0x46f41b10,0x00000000,0x00000000,0x00000000}},	//   _очит, --, --, --, 
   {{0x25a094fc,0x42780023,0x00000000,0x00000000}},	//   _tril_, _ኣማኒት_, --, --, 
   {{0x25a00472,0x2730004d,0x628000e4,0xdb1800e5}},	// [27280] _uril_, _hãn_, _ñmom, nyvá, 
   {{0xf0600022,0x00000000,0x00000000,0x00000000}},	//   ккуп, --, --, --, 
   {{0x44391e1d,0x23080451,0xb5f801d3,0x00000000}},	//   _ifp_, _فڪري_, sgát, --, 
   {{0x6700084a,0x2730001e,0x44394401,0x4488009f}},	//   ैतिक_, _mãn_, _hfp_, _انگُ_, 
   {{0xb5f800dd,0x6d5c0986,0x27300051,0x00000000}},	//   lgár, šqan, _lãn_, --, 
   {{0x7528007f,0x00000000,0x00000000,0x00000000}},	//   _ègze, --, --, --, 
   {{0x4439786d,0x9f8805a4,0xd9b83806,0x9f58369d}},	//   _mfp_, _góða_, ेन्ट, _byrå_, 
   {{0x44389ec6,0xb4b81be1,0x13e000eb,0x00000000}},	//   _lfp_, _अक्_, _মুড়, --, 
   {{0xb864021a,0x443804cc,0xdb1801d3,0x00000000}},	//   وادو, _ofp_, gyvá, --, 
   {{0x443926ad,0xb5f801ed,0x27300051,0x00000000}},	//   _nfp_, zgás, _bãn_, --, 
   {{0xa2c4190c,0x00000000,0x00000000,0x00000000}},	//   रसञ्, --, --, --, 
   {{0xec10006c,0x4439786e,0x2730001e,0x368801c0}},	//   _شوند, _afp_, _dãn_, цсон_, 
   {{0x77481e38,0x44380004,0xe97000ec,0x00000000}},	//   _መደምደ, _bfp_, _لهند, --, 
   {{0x77300124,0x00000000,0x00000000,0x00000000}},	//   _иҭоу, --, --, --, 
   {{0x59280135,0xb4cc012d,0x00000000,0x00000000}},	//   _ལྤགས_, _शती_, --, --, 
   {{0x9f8802d2,0x66e400e5,0x81e400eb,0xe78400ec}},	//   _róða_, lőkn, _ফরজ_, _آپيه_, 
   {{0xb5f801ed,0xa2c400dc,0x7c380036,0xa2a001ad}},	// [27290] rgás, रसज्, _oftr, _ऑफर्, 
   {{0xe45400c7,0x2ec408ec,0x4438123b,0x2fc8007b}},	//   _икьы, लस्त, _gfp_, يباً_, 
   {{0x77780175,0x9f4801e1,0x00000000,0x00000000}},	//   nttx, _èhìn_, --, --, 
   {{0x7c39786f,0x3dc41c5c,0x690c0fac,0x00000000}},	//   _aftr, ﯩﻠﯩﻘ, jøen, --, 
   {{0xdd940006,0x4438045a,0x8238010f,0xd1f80092}},	//   кацы, _yfp_, _מערצ, ዋቾች_, 
   {{0x8b94026a,0xd04405d9,0xdb180306,0x7c700075}},	//   ерич, _سپري, vyvá, лғуч, 
   {{0x7d0400ef,0x66e400e5,0x00000000,0x00000000}},	//   _īkst, dőkn, --, --, 
   {{0x78a8007f,0x7c38002d,0x2cb800c0,0xdef800fb}},	//   _anfv, _eftr, _žydą_, _жыу_, 
   {{0x68ec2b76,0x7bcc1a80,0xdea451ae,0x27300051}},	//   écdo, _übun, _جینی, _sãn_, 
   {{0x9d14084c,0x6d5806be,0x00000000,0x00000000}},	//   _адуч, _ivua, --, --, 
   {{0x44397870,0x00000000,0x00000000,0x00000000}},	//   _rfp_, --, --, --, 
   {{0x44380334,0x2730004d,0x656000e5,0x00000000}},	//   _sfp_, _vãn_, ámho, --, 
   {{0x6aa97871,0x6e380526,0xfa5518a2,0x38c82a77}},	//   _ingf, _mfub, _سرنگ, زایی_, 
   {{0x4438031c,0x2a7c00e8,0x43080451,0x00000000}},	//   _qfp_, lfub_, ڳيءَ_, --, 
   {{0x4438011c,0x6e3804ba,0x7778010a,0xc7a400cf}},	//   _vfp_, _ofub, cttx, _чийк, 
   {{0x44397872,0x6e3804ba,0x3d140034,0xb5f97873}},	//   _wfp_, _nfub, _पीने_, rgár, 
   {{0xb4d97874,0xe3d800fe,0x00000000,0x00000000}},	// [272a0] mpàn, _দুখব, --, --, 
   {{0x6e381418,0xa2c416d1,0xc10477a7,0xb4d804cc}},	//   _afub, रसङ्, رواي, lpàn, 
   {{0x6aa8035a,0x6d5c0784,0xce3401e2,0x00000000}},	//   _ongf, šqal, ږونک, --, 
   {{0xddc0012c,0xaff4007b,0xc1d0008e,0x66e401d3}},	//   _zemř, رفنا_, _йөзә, zőkn, 
   {{0xdd949b96,0x6da01b10,0xf2a00150,0x00000000}},	//   талы, лица, _сияп, --, 
   {{0x6aa89f72,0x6e3804ba,0x2a7c00e8,0x6f000356}},	//   _angf, _efub, efub_, încr, 
   {{0x7ac57875,0x3f9c003e,0x00000000,0x00000000}},	//   еспе, _étu_, --, --, 
   {{0x9e9400ec,0xab242377,0x00000000,0x00000000}},	//   _جهرڪ, ноја_, --, --, 
   {{0xf53c05ac,0x66e401d3,0x77780477,0xd9f80cc9}},	//   mvåg_, tőkn, wttx, ьниц_, 
   {{0x7c3804cc,0xbc6802dd,0x0c6800d1,0xf53c2dba}},	//   _uftr, _ءمان_, _озуқ_, lvåg_, 
   {{0x96f80588,0x3d14007d,0x848c0023,0x387c030a}},	//   дент_, _पीये_, _ምምራሕ_, rftr_, 
   {{0xb69800d2,0x78a80356,0x387c0175,0xba7400e5}},	//   hlâv, _şovă, sftr_, _ساؤت, 
   {{0x7ae17876,0x3dc4058a,0x00000000,0x00000000}},	//   _imot, nyow_, --, --, 
   {{0x7ae003c6,0x3dc40009,0x3af800e4,0x00000000}},	//   _hmot, iyow_, vëpy_, --, 
   {{0xa73400c6,0x7ae002fb,0xf53c0217,0x368800d8}},	//   _كثير_, _kmot, kvåg_, _еспн_, 
   {{0x925806ed,0xa2a400cd,0x00000000,0x00000000}},	//   ќаат_, _चोद्, --, --, 
   {{0x7ae17877,0xf53c0158,0x151400d1,0x8178013e}},	// [272b0] _mmot, dvåg_, _идия, матӣ_, 
   {{0x3dc40067,0xdb18005b,0x916c0051,0x25d8011a}},	//   dyow_, lyvä, _cốt_, _רוזן_, 
   {{0x7ae17878,0x3dc4058a,0x00000000,0x00000000}},	//   _omot, eyow_, --, --, 
   {{0x59b03be5,0xf53c00fe,0x261800e1,0x6d5c0309}},	//   जमार, gvåg_, _नरमी_, šqam, 
   {{0xfd4c00cd,0x00000000,0x00000000,0x00000000}},	//   _kliṣ, --, --, --, 
   {{0x7ae17879,0xdb18005b,0xf1bc0208,0xdbcc01e1}},	//   _amot, hyvä, _ngái_, _róòm, 
   {{0x09c853c3,0xdb1802f6,0xc0c00116,0x643c008f}},	//   िन्य, kyvä, _тәти, לעגנ, 
   {{0x3dc4058a,0xaee000cd,0xdb18005b,0x00000000}},	//   byow_, _kaṭa, jyvä, --, 
   {{0x7ae001c7,0xf65c00b5,0x4c940124,0xaee00055}},	//   _dmot, rkæl_, _ииас, _jaṭa, 
   {{0x7ae1787a,0x00000000,0x00000000,0x00000000}},	//   _emot, --, --, --, 
   {{0x55c417de,0x7ae00175,0x207c010f,0x00000000}},	//   қарғ, _fmot, לאזא, --, 
   {{0x6aa9787b,0x7ae00427,0x88c401ef,0x00000000}},	//   _ungf, _gmot, dměř, --, 
   {{0x20c40254,0x61480ca8,0xaee0002b,0x00000000}},	//   _köit_, _mélò, _naṭa, --, 
   {{0x7ae13b78,0xb4d87172,0x88a00345,0x00000000}},	//   _zmot, spàn, _ئیدۆ, --, 
   {{0x68e0014b,0x2905787c,0xdb1801e3,0x4ebc00eb}},	//   _imnd, _ikna_, byvä, _আগৈল, 
   {{0x3dc4011f,0x8c4403b9,0x32e40241,0x916c0051}},	//   yyow_, _dağə, _rìyè_, _sốt_, 
   {{0x3208002d,0x26c1787d,0xaee000b8,0x41044b89}},	// [272c0] _cycy_, _ioio_, _caṭa, взав, 
   {{0x66e402dd,0x00000000,0x00000000,0x00000000}},	//   _шоқа, --, --, --, 
   {{0x26c000b0,0x75280100,0xb21801bf,0x77440092}},	//   _koio_, _ègza, _ubæn, _የተስተ, 
   {{0xcfa80491,0x7de40046,0x4f940228,0x26c001e4}},	//   عالم_, кілд, ыруу, _joio_, 
   {{0x29050b29,0x68e00107,0xf53c0ac8,0x916c01fb}},	//   _okna_, _omnd, rvåg_, _tốt_, 
   {{0x26c0123c,0xf53c6525,0x71f801c8,0xddc00210}},	//   _loio_, svåg_, _آرٽس_, _zemś, 
   {{0x26c00093,0xc0580220,0xdd940032,0xa3e80cb4}},	//   _ooio_, _нің_, таһы, _मेम_, 
   {{0xf8c80b26,0x68e00857,0xeb940640,0x2905787e}},	//   िस्प, _amnd, тић_, _akna_, 
   {{0xe8dc0248,0x00000000,0x00000000,0x00000000}},	//   apọn_, --, --, --, 
   {{0xb699787f,0xfca81541,0x00000000,0x00000000}},	//   hlât, _تارو_, --, --, 
   {{0x8b644130,0xdb1802f6,0xdbcc032e,0x3d0c00c5}},	//   _مانم, tyvä, _góðm, ितीं_, 
   {{0x7ae17880,0x68e10c26,0x20c40254,0x3d14033f}},	//   _umot, _emnd, _köis_, _पीते_, 
   {{0xd1d40020,0xb89400c6,0x98a401e0,0x00000000}},	//   ረቡት_, _للشع, _буйҙ, --, 
   {{0xdb18023a,0xe5c80276,0xaee000b8,0xb0500241}},	//   syvä, тыюл_, _kaṣa, _olóṣ, 
   {{0x50f4013e,0xc1a40220,0xdb1801f4,0x940406c2}},	//   ҳзат, қытқ, pyvä, اوزه, 
   {{0x26c16ce3,0x3d0c00dc,0xaee000dc,0x00000000}},	//   _goio_, ितुं_, _paṭa, --, 
   {{0xa158c4b4,0x52141d0f,0x00000000,0x00000000}},	// [272d0] кату_, удат, --, --, 
   {{0x7d1800f3,0xf4841422,0x6d5c02d1,0xaee0002b}},	//   _nhts, _руин, šqak, _vaṭa, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7d180076,0x26c00077,0x0b4401b9,0x20c401f4}},	//   _ahts, _xoio_, қнин, _söit_, 
   {{0xde5800d4,0x00000000,0x00000000,0x00000000}},	//   тачі_, --, --, --, 
   {{0xa0284418,0x6ad85325,0x7d18002f,0xa184008e}},	//   رسەك_, यफ्र, _chts, _тыюл, 
   {{0xaee000b8,0x00000000,0x00000000,0x00000000}},	//   _caṣa, --, --, --, 
   {{0x29d00882,0x7d180037,0x00000000,0x00000000}},	//   ṣam_, _ehts, --, --, 
   {{0xdd9568e7,0x09057881,0x26c00156,0x89340633}},	//   _каты, лпин, _roio_, دعبا, 
   {{0x26c00077,0x92c02cc5,0x29c400cf,0x67d006be}},	//   _soio_, ্চয়_, етүү_, ləjə, 
   {{0x6f1887b9,0x26c0056a,0xc72400f7,0xfd4c0ca8}},	//   _khuc, _poio_, лдой, _onkọ, 
   {{0x02d01d20,0xd6a80014,0x869800d8,0x35a000c7}},	//   _सतेन, ندُم_, хтот_, әарг, 
   {{0x6f18464c,0x6ab80174,0xeb0cac66,0x88b000eb}},	//   _mhuc, mjuf, ातीत_, য়োগক, 
   {{0x68e17882,0x6ab97883,0x00000000,0x00000000}},	//   _umnd, ljuf, --, --, 
   {{0x46a405f5,0x69d80036,0xd8380024,0x00000000}},	//   _байв, lzue, _рэч_, --, 
   {{0x6ab97884,0x00000000,0x00000000,0x00000000}},	//   njuf, --, --, --, 
   {{0x69d97885,0x3f88562c,0x7744001f,0x008401d5}},	// [272e0] nzue, _spbu_, _የተሳተ, ллао, 
   {{0x69d8005a,0xa2a408df,0x00000000,0x00000000}},	//   izue, _चोर्, --, --, 
   {{0x6f197886,0x2be00574,0xbe897887,0x2b4400b5}},	//   _bhuc, _केलं_, есле_, jpnc_, 
   {{0x7d18022e,0xaaa0033f,0x1da40022,0x00000000}},	//   _shts, _खोलक, илеҭ, --, 
   {{0x54a407d6,0x6f18dac6,0x113802dd,0x00000000}},	//   _صحیف, _dhuc, _аясы_, --, 
   {{0x62840395,0x00000000,0x00000000,0x00000000}},	//   lfio, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa3bc367a,0x5a3464e1,0x628403c5,0xcaa40145}},	//   _आपन_, шнит, nfio, للىۋ, 
   {{0x6da0fefc,0x628400a9,0xaab4515c,0xad8400cf}},	//   _лита, ifio, ادىر_, _مالۇ, 
   {{0xdee401b9,0x62840042,0x71780a7c,0x00000000}},	//   _соғи, hfio, עניס, --, 
   {{0xbec0044e,0x15880150,0xa8a0013d,0x00000000}},	//   _çësh, _ﺑﻴﺸﯩ, срык, --, 
   {{0xfa34007b,0x2f58011a,0x00000000,0x00000000}},	//   _إراد, עדכנ, --, --, 
   {{0x62fc015b,0x7bc97888,0xf1bc00e4,0x3bec06be}},	//   ্ষায়_, lyfu, _ygáu_, _həq_, 
   {{0x27ecfb52,0xe5340108,0x00000000,0x00000000}},	//   álná_, серь, --, --, 
   {{0xb2a87863,0x62851208,0xe4e43334,0xb9dc1b49}},	//   нтаж_, ffio, сіян, _ኤር_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x20197889,0x667402de,0x90540452,0xf1bc004d}},	// [272f0] _azri_, _ادىر, ивац, _ngát_, 
   {{0x6f19788a,0x3d0c033f,0xe1f0007b,0x00000000}},	//   _shuc, ितों_, أسف_, --, 
   {{0x6f19788b,0x69d80083,0x8e5402d5,0xf1bc00d7}},	//   _phuc, zzue, атлі, _agát_, 
   {{0x8d75788c,0x6f1802d1,0x628401ab,0xceb8013a}},	//   لاتا, _qhuc, cfio, _ohře_, 
   {{0xe8081533,0x6440033f,0x10640014,0xdce04dd9}},	//   _सुना_, śmie, _پُزُ, _asmı, 
   {{0x64b800a2,0x00000000,0x00000000,0x00000000}},	//   _işiñ, --, --, --, 
   {{0x6f19788d,0x2fc4049f,0x7a24022e,0x60180395}},	//   _thuc, ängd_, hаtd, _боря_, 
   {{0x69d80323,0x4aa8c920,0xc964036b,0x921805d7}},	//   tzue, ткин_, авий, _दराज_, 
   {{0xd90d788e,0xc8b5788f,0xeb9407d6,0xdef8f5a4}},	//   کیو_, асны, тиқ_, _сыр_, 
   {{0x1cb42fb5,0xddc005d1,0x88c801f4,0x00000000}},	//   _ཞོར_, _hemş, тлов_, --, 
   {{0x69d801c7,0x62850905,0x86c4027d,0xcd4c0023}},	//   szue, yfio, ليدن, _ዝተኣወ, 
   {{0x065402d5,0xddc00432,0x00000000,0x00000000}},	//   штоў, _jemş, --, --, 
   {{0xb6a03a21,0xdb240008,0xcb1001ad,0xb6640166}},	//   циял, _ósát, _डीएड_, шияз_, 
   {{0x20f42356,0xc7a4bbd5,0xf504034b,0xb88000d0}},	//   _आदेश_, _викк, инял_, čích, 
   {{0x425417fb,0x1cb40135,0x5f080882,0x670400ee}},	//   итат, _ཞོལ_, िकम्_, _гүнб, 
   {{0xc2457890,0x9814182f,0xdb0800d8,0xf1bc0332}},	//   рнак, _ابها, _ardê, _ngás_, 
   {{0x057404a9,0x00e57891,0x62853661,0x882000d1}},	// [27300] _ئابد, ажан, rfio, _دېگۈ, 
   {{0xf1bc172e,0x43740228,0x6284003a,0xdca4000d}},	//   _agás_, _кумт, sfio, _गोंछ, 
   {{0x645d7892,0x7bc800e4,0x562c0023,0xb5f802d2}},	//   mari, xyfu, ተዘይበ, gaáf, 
   {{0x645d7893,0x0eb800fd,0x00000000,0x00000000}},	//   lari, лучы_, --, --, 
   {{0x40940261,0x645c6f89,0x224003e0,0x00000000}},	//   _крвт, oari, mcik_, --, 
   {{0x7b657894,0x0c9410e0,0xfb640640,0x00000000}},	//   атие, مدىگ, ањим, --, 
   {{0x645c01c4,0x2018022e,0xcdc401f0,0x00000000}},	//   iari, _uzri_, _қафқ, --, 
   {{0x22400264,0x2fc57895,0x1ab57896,0x7bc80042}},	//   ncik_, änge_, сбия, ryfu, 
   {{0x6ac0d91c,0x00000000,0x00000000,0x00000000}},	//   تقيم, --, --, --, 
   {{0x645d7897,0xdbdc0122,0x98b97898,0x58d4005b}},	//   jari, lším, улот_, соот, 
   {{0x22400092,0xb034010f,0xeb9432b0,0x59d400bc}},	//   kcik_, יניג_, _вих_, धनहर, 
   {{0xdbdc0306,0x645c0538,0xb4d808c2,0x22405f0b}},	//   nším, eari, mpài, jcik_, 
   {{0x645d7899,0xe5c43580,0x8a7402dd,0x00000000}},	//   fari, осро, _اڭىس_, --, 
   {{0x645d701b,0xa3e8000d,0x37a8010a,0xdbdc00d7}},	//   gari, _मेह_, _атин_, hším, 
   {{0xa3bc05ba,0x24587979,0xe7341fbe,0xb5f800e5}},	//   _आपण_, рась_, _кеј_, ngáz, 
   {{0x645d789a,0x66e403b7,0xdbdc0122,0x39440034}},	//   aari, _моја, jším, _ktos_, 
   {{0xd131789b,0xf4840ed3,0xbb3801ec,0xdbdc0c5e}},	// [27310] سما_, _кунн, _ﺒﻘﻴ_, dším, 
   {{0x394400d8,0x3d14012d,0x224000d7,0xdb24032e}},	//   _mtos_, _पीले_, acik_, _ósæt, 
   {{0x9295789c,0x2fc5789d,0x32040034,0x00000000}},	//   _ланц, âng_, łny_, --, 
   {{0x3945789e,0x9f580429,0x00000000,0x00000000}},	//   _otos_, _ayró_, --, --, 
   {{0x8c44d40d,0x3945789f,0x00000000,0x00000000}},	//   беле, _ntos_, --, --, 
   {{0x01340375,0xc0c009a5,0xeb0c0825,0x4e8401d9}},	//   _לרשת_, _нәхи, ात्त_, _گٔرٕ, 
   {{0x394578a0,0xdbdc02f0,0x7b1c0200,0x00000000}},	//   _atos_, bším, këud, --, 
   {{0x1a695312,0xaca00248,0xede401d5,0xee3c00a2}},	//   لیمی_, _imọl, _кўзн, _üý_, 
   {{0x645d78a1,0x39440ac5,0x26c40793,0xf8ac01b9}},	//   yari, _ctos_, ömom_, ککن_, 
   {{0x645d78a2,0x22400369,0xac7400f2,0x6d48007c}},	//   xari, zcik_, _خارش, mpga, 
   {{0x394578a3,0x645d78a4,0x9cc8030d,0x00000000}},	//   _etos_, vari, _тыта_, --, 
   {{0x26c81638,0x6d4875fa,0xa3e808e9,0x00000000}},	//   рғин_, opga, _मेष_, --, 
   {{0x64480165,0x6d4802d0,0x7afc00e5,0xb7d400f2}},	//   ñdio, npga, épte, لویا_, 
   {{0xdb08cc04,0x00000000,0x00000000,0x00000000}},	//   _ardè, --, --, --, 
   {{0x6b8003a2,0x7a24022e,0xaad8012d,0x4344011c}},	//   ntng, rаte, _बताक, себв, 
   {{0x645d78a5,0x00000000,0x00000000,0x00000000}},	//   sari, --, --, --, 
   {{0x394402fa,0x6b8003a2,0x645d78a6,0x80640111}},	// [27320] _xtos_, htng, pari, йваж, 
   {{0x645d78a7,0xb60800d1,0x22400419,0x00000000}},	//   qari, _ﯲﺯ_, scik_, --, 
   {{0xbbb41d34,0x6b800427,0xdbdc0118,0x00000000}},	//   _अपेक, jtng, tším, --, 
   {{0x3dc400fe,0x00000000,0x00000000,0x00000000}},	//   _শেষল, --, --, --, 
   {{0xc21001d9,0xdbdc0306,0x00000000,0x00000000}},	//   _رٔس_, rším, --, --, 
   {{0xa0240790,0x6b80045a,0x7fd40816,0xa3bc134e}},	//   taöğ, ftng, _лібі, _आपा_, 
   {{0x394578a8,0xbea4c43c,0xdbdc0122,0xbae473b3}},	//   _stos_, _лавк, pším, йций, 
   {{0x394455f7,0xe80813e0,0x00000000,0x00000000}},	//   _ptos_, _सुधा_, --, --, 
   {{0x58d978a9,0x39440798,0x59f800a7,0xdb0800e4}},	//   идия_, _qtos_, репя_, ñoña, 
   {{0x2740001f,0xa3b8012c,0xf1b00375,0xd90c01d3}},	//   _የተመሠ, चमा_, פסת_, کیڈ_, 
   {{0xa3e8107c,0x30f800dc,0x6564002b,0x56940f64}},	//   _मेल_, ्वतः_, _avih, оант, 
   {{0x7d0978aa,0xdb080077,0x81ac0154,0x00000000}},	//   lofs, _ordé, _কথন_, --, 
   {{0x394578ab,0xb6049919,0xf1bc0208,0x19580166}},	//   _utos_, сянк, _ngáp_, _талы_, 
   {{0xefe802d3,0x656578ac,0xe4e40024,0x53340798}},	//   _ቆልዑ_, _dvih, пісн, жевт, 
   {{0xa3d578ad,0xdb080129,0xed5c0153,0x326578ae}},	//   порч, _ardé, ėžia_, йтав, 
   {{0x7d0817da,0xb40001c6,0x236c00e5,0x00000000}},	//   hofs, жүүд, ádja_, --, 
   {{0x7d08deb6,0x6440012d,0x00000000,0x00000000}},	// [27330] kofs, śmia, --, --, 
   {{0x92e80eac,0x39800413,0x00000000,0x00000000}},	//   মকে_, iðs_, --, --, 
   {{0x7d080421,0x65640099,0xdb0801ed,0x68400092}},	//   dofs, _zvih, _erdé, _የቱሪስ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa69c010f,0xf0440064,0x00000000,0x00000000}},	//   טשאפ, _гэбо, --, --, 
   {{0xa3e82871,0x00000000,0x00000000,0x00000000}},	//   _मेँ_, --, --, --, 
   {{0x8c4401e0,0x00000000,0x00000000,0x00000000}},	//   беһе, --, --, --, 
   {{0xa3bc0c2e,0x6d481700,0xefe802d3,0x1b1c00fe}},	//   _आपस_, ppga, _ቆልዓ_, _পূবে_, 
   {{0x5eb40139,0x7d080200,0x6b8178af,0x6ce4003b}},	//   _эйтт, bofs, stng, _ліже, 
   {{0x2d9c020b,0x6f0978b0,0x6838010c,0x65640055}},	//   _isue_, logc, _በዓላት, _rvih, 
   {{0xa3e86398,0x00000000,0x00000000,0x00000000}},	//   _में_, --, --, --, 
   {{0x9b640092,0x00000000,0x00000000,0x00000000}},	//   _ሊሰጣቸ, --, --, --, 
   {{0x30f80882,0xed900092,0x19944f55,0x0dc40092}},	//   ्वाः_, _ማክበር_, _наця, _ጸሃፊ_, 
   {{0x291400d1,0x2d9c0200,0x00000000,0x00000000}},	//   ﻳﯘﭖ_, _msue_, --, --, 
   {{0xd3b800d4,0x00000000,0x00000000,0x00000000}},	//   буті_, --, --, --, 
   {{0x7d0805a1,0x6564aea2,0x65600332,0x850400e5}},	//   zofs, _tvih, ámhs, _ڈوبن, 
   {{0x02c82d8f,0x10080075,0x814402e9,0x7d08020c}},	// [27340] _रवीन, ەتنى_, زنان, yofs, 
   {{0x25a178b1,0x9f5803b2,0x8014084c,0xf590150e}},	//   _isil_, _byrð_, офец, _کلیج, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2fc4049f,0x6f080b6f,0x25a178b2,0xf53c05ac}},	//   änga_, gogc, _ksil_, kvål_, 
   {{0xee3418ce,0xe734013f,0x7d0978b3,0x00000000}},	//   әнә_, _nsεm_, tofs, --, 
   {{0x24980194,0x93240014,0x3618010f,0xaab40014}},	//   nerm_, _ورێن, בונד, ۪گٕر_, 
   {{0xe7340134,0xb4d94a79,0x6f08009a,0x00000000}},	//   _asεm_, mpàt, bogc, --, 
   {{0x24980cf9,0x7d08198f,0x6f0800d2,0x2d9c0327}},	//   herm_, sofs, cogc, _fsue_, 
   {{0xdb2401ed,0x24984e1b,0x3ea40175,0x7c840092}},	//   _ہوئی, kerm_, mdot_, ነበረው_, 
   {{0x3ea42045,0x320c00dd,0x2498e73f,0x3980066a}},	//   ldot_, ügyi_, jerm_, rðs_, 
   {{0x25a178b4,0xf65c01bf,0x3ea40108,0x00000000}},	//   _asil_, dkær_, odot_, --, 
   {{0x3ea578b5,0xeb303955,0xd6d8033f,0x0b580166}},	//   ndot_, _قىلد, ół_, _ыруы_, 
   {{0x24980585,0x3ea578b6,0x77900345,0x00000000}},	//   ferm_, idot_, سیکا, --, 
   {{0x3ea402f6,0x6440146b,0x6f080107,0xe80801ad}},	//   hdot_, śmin, zogc, _सुवा_, 
   {{0x25a00472,0x6f080107,0xa8140220,0x3dc000eb}},	//   _esil_, yogc, _وتىر_, ্ছিল, 
   {{0xe45000e5,0x00000000,0x00000000,0x00000000}},	//   فضہ_, --, --, --, 
   {{0x3ea40548,0xc610015b,0x00000000,0x00000000}},	// [27350] ddot_, সেবা_, --, --, 
   {{0x3ea578b7,0xdb1800e4,0x048401af,0x00000000}},	//   edot_, vyvý, _нәси_, --, 
   {{0xa6c801ed,0xc4980375,0xa0c4027d,0x00000000}},	//   _طویل_, _השתת, بيلو, --, 
   {{0x9f0400f7,0x23280120,0xca380150,0x00000000}},	//   وولو, _моќи_, _ﺒﻨﺎ_, --, 
   {{0x8c4578b8,0x6f0801bf,0x394003b2,0x00000000}},	//   пеле, rogc, íksl_, --, 
   {{0xa158b159,0x8c440137,0xaaa00ebb,0x7d2800f1}},	//   _фару_, чеке, _खोजक, مينې_, 
   {{0x60080962,0x7b8400d1,0x00000000,0x00000000}},	//   _днём_, كايە, --, --, 
   {{0x2484013f,0x6d5c03f0,0xdb08007b,0xf53c007c}},	//   ɑmmu_, šqaq, يزيه_, tvål_, 
   {{0x7afc0077,0xe86001c6,0x3d1408e9,0x00000000}},	//   épta, үхүү, _पीके_, --, 
   {{0x1cb4081f,0x5c7400f7,0xb9e402dd,0x61e0010e}},	//   _ཞོག_, _олут, ямыз_, _ümle, 
   {{0x3cf8008f,0x00000000,0x00000000,0x00000000}},	//   _פלענ, --, --, --, 
   {{0xe9b40050,0x2498017a,0xf1b803ce,0x00000000}},	//   _وناں_, werm_, ईमान, --, 
   {{0x249978b9,0x25a0022e,0x6b4403e0,0xf3f40051}},	//   term_, _qsil_, _dıge, ộng_, 
   {{0x690c003b,0x1dac21b8,0x00000000,0x00000000}},	//   røes, चितत, --, --, 
   {{0xf65c00b5,0x3ea40175,0x7a24022e,0xca380150}},	//   rkær_, ydot_, nаtn, _ﺒﻨﺕ_, 
   {{0x249978ba,0x0564b86d,0xf65c005c,0x9f5801f4}},	//   serm_, _евин, skær_, _kyrö_, 
   {{0x25a178bb,0x24980c12,0x409417b4,0x00000000}},	// [27360] _usil_, perm_, зрет, --, 
   {{0x660402c4,0xa4940244,0x00000000,0x00000000}},	//   _ixik, _تیست, --, --, 
   {{0x443978bc,0xadc001e1,0x3ea4a28f,0xbf3418fd}},	//   _igp_, _iyẹn, tdot_, سراغ, 
   {{0x1cb4025c,0x44380175,0xedd00451,0x4b980092}},	//   _ཞོང_, _hgp_, ڙيند, _መርካቶ_, 
   {{0x3ea578bd,0x67240135,0x30f800dc,0x443815c0}},	//   rdot_, _mhij, ्वशः_, _kgp_, 
   {{0x9b9409b7,0x7c6400f7,0x61e578be,0x3618008f}},	//   дикц, ساتل, mzil, זונד, 
   {{0x61e578bf,0x44382b96,0x30f800dc,0x6d5c0784}},	//   lzil, _mgp_, ्वरः_, šqap, 
   {{0x61e40334,0x6ff8011a,0x418801ec,0xab80009b}},	//   ozil, _הפלג, _ﺗﻴﮕﯩ, хушк, 
   {{0x7e60123c,0x6f010520,0xf1c40306,0x999801d3}},	//   maop, énce, cháč_, تھار_, 
   {{0x67240198,0x44380004,0x6fb000dd,0x61e42625}},	//   _ahij, _ngp_, _تمہا, izil, 
   {{0x7c38089c,0x6724002b,0xbff800eb,0x00000000}},	//   _igtr, _bhij, _অরুণ_, --, 
   {{0x7e6178c0,0xaa54007b,0x00000000,0x00000000}},	//   naop, _فلما_, --, --, 
   {{0x690cb626,0x67240200,0xdb180022,0x656001e7}},	//   røer, _dhij, syvó, ámhp, 
   {{0x61e578c1,0x293400c8,0x7e6178c2,0x44380010}},	//   dzil, _זאגן_, haop, _cgp_, 
   {{0x660406e4,0x61e40076,0x443815c0,0x00000000}},	//   _exik, ezil, _dgp_, --, 
   {{0x6724047e,0x44385eb2,0x777801c4,0x7a24022e}},	//   _ghij, _egp_, mutx, nаto, 
   {{0x4438f17c,0x777864cb,0xf0740352,0x00000000}},	// [27370] _fgp_, lutx, зизә_, --, 
   {{0x44381bb6,0x7c380280,0xc0c80020,0x10080131}},	//   _ggp_, _ngtr, _በቀር_, ەتچى_, 
   {{0xdb0804d4,0x765c0200,0x00000000,0x00000000}},	//   _ardí, _keqy, --, --, 
   {{0xf40000bd,0x7e600005,0xb8fc031c,0x00000000}},	//   _এরপর_, gaop, _ལཾ_, --, 
   {{0x61e401f4,0x00000000,0x00000000,0x00000000}},	//   czil, --, --, --, 
   {{0xd054013f,0x7c380175,0x21d8037e,0x7778009d}},	//   _ɛbɛh, _cgtr, _ｍhz_, kutx, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfe6d78c3,0x9f240131,0x7778005a,0x7e60d312}},	//   _نگه_, _كۈلۈ, dutx, caop, 
   {{0x6e38409c,0x67240564,0x68ec00cf,0x00000000}},	//   _igub, _rhij, ècdo, --, 
   {{0x672578c4,0x7a2401a9,0x00000000,0x00000000}},	//   _shij, mаtl, --, --, 
   {{0x61e4031c,0x6e3800fb,0x44380006,0x6724020c}},	//   zzil, _kgub, _rgp_, _phij, 
   {{0x443978c5,0x668401b9,0xbff800cc,0x00000000}},	//   _sgp_, ریخل, _অৰুণ_, --, 
   {{0x6e380921,0xd9b00075,0xf9a00588,0x4438045a}},	//   _mgub, _مەيد, _ақыҭ, _pgp_, 
   {{0x2a7d78c6,0x6d5801f7,0x777800db,0x490407d6}},	//   lgub_, _mwua, butx, _توتق, 
   {{0xa3e8069f,0x672578c7,0x6e380337,0x27240139}},	//   _मेख_, _thij, _ogub, eñne_, 
   {{0x6e383917,0x660578c8,0x2a7d78c9,0x7a2401a9}},	//   _ngub, _txik, ngub_, kаtl, 
   {{0x44380354,0x7e600b23,0x00c901e6,0x00000000}},	// [27380] _tgp_, vaop, олак_, --, 
   {{0xdb0c2776,0x7e602ce9,0x00000000,0x00000000}},	//   _âköd, waop, --, --, 
   {{0x6d58016b,0x765c0175,0x03243a49,0xdb080118}},	//   _awua, _yeqy, _одон, _srdí, 
   {{0x61e40408,0xfe7178ca,0xd8380010,0xdb08013a}},	//   pzil, ئدا_, meče_, _prdí, 
   {{0x9f58011f,0xd2000228,0xfce4fe1c,0xd8380219}},	//   _ayrô_, _бүтк, модо, leče_, 
   {{0x6e3978cb,0x7e6000d8,0x00000000,0x00000000}},	//   _egub, saop, --, --, 
   {{0x8f7402bf,0x7e6178cc,0x777801c4,0xb21801bf}},	//   _путі, paop, xutx, _ubær, 
   {{0xf96850e3,0x4504009e,0x2a7c00e8,0x7a2401a9}},	//   орой_, োগিক_, ggub_, bаtl, 
   {{0x6d58063f,0x20180023,0x765c0477,0xf53c00d4}},	//   _gwua, _hyri_, _reqy, rvåk_, 
   {{0x6e3978cd,0x7c38005a,0x777801c4,0xec74011c}},	//   _zgub, _ugtr, tutx, _опу_, 
   {{0xd83978ce,0x6d580036,0x3f68010f,0x20180821}},	//   ječe_, _zwua, nĝu_, _jyri_, 
   {{0x2018003a,0xd8380219,0x7778009d,0x3f680115}},	//   _myri_, deče_, rutx, iĝu_, 
   {{0x941803be,0x00000000,0x00000000,0x00000000}},	//   əyən_, --, --, --, 
   {{0x7778dd5c,0x20180174,0x00000000,0x00000000}},	//   putx, _oyri_, --, --, 
   {{0x3d1409d9,0xe53578cf,0x569578d0,0x32d404fb}},	//   _पीछे_, терь, _зайт, وزرس, 
   {{0x21380363,0x00000000,0x00000000,0x00000000}},	//   _airh_, --, --, --, 
   {{0xb698025a,0x20180fe5,0x75e000fd,0x21240014}},	// [27390] boâr, _ayri_, _рәнҗ, ھٹمُ, 
   {{0x213802e2,0xf0f872c0,0x6e3978d1,0x00000000}},	//   _cirh_, ्वेद_, _sgub, --, 
   {{0x201948fb,0xd8380427,0x3d0000dc,0xe610bab9}},	//   _cyri_, beče_, वचने_, _مشی_, 
   {{0x20180158,0xa3e804fa,0x7a2401a9,0x637c00d7}},	//   _dyri_, _मेट_, tаtl, sťná, 
   {{0x313007dd,0x201802d2,0xdea407d6,0x00000000}},	//   _аҵар, _eyri_, ضیلی, --, 
   {{0x20188c07,0x290001a6,0x30e000dc,0x2d88013d}},	//   _fyri_, čjak_, _गतिः_, _äcem_, 
   {{0xabc00032,0xca7001a9,0x00000000,0x00000000}},	//   тайҙ, аgаn, --, --, 
   {{0x63a8553d,0xdd1c02fb,0x6e39002b,0x5f9400a7}},	//   ædni, rášl, _ugub, _шист, 
   {{0x2a7c000d,0xdb2400ae,0x30e000cd,0x00000000}},	//   rgub_, úsái, _गताः_, --, 
   {{0x47c409fe,0xd8382438,0x00000000,0x00000000}},	//   ебов, zeče_, --, --, 
   {{0xf2dc022f,0x00000000,0x00000000,0x00000000}},	//   _olâ_, --, --, --, 
   {{0xc1d801e1,0x00000000,0x00000000,0x00000000}},	//   _ọ̀gè, --, --, --, 
   {{0xd838c2bf,0x16c00032,0xa3e8012d,0x998400ae}},	//   veče_, рҡын, _मेज_, _للنو, 
   {{0xf2dc0109,0x03a408ca,0xb88002f0,0x72c001d5}},	//   _alâ_, ниго, žíru, қбуз, 
   {{0xd838488c,0xeb90001f,0x7b280118,0x00000000}},	//   teče_, _ሁልጊዜ_, _křup, --, 
   {{0x97d800c6,0x00000000,0x00000000,0x00000000}},	//   _تظهر_, --, --, --, 
   {{0xd334d6f3,0xd838e8a2,0x20194eb2,0x95a40124}},	// [273a0] тэры, reče_, _syri_, _алыҵ, 
   {{0xd8385946,0xf0a45e0c,0x1768010b,0x80a4007b}},	//   seče_, нкул_, _эрәп_, عمان, 
   {{0xa3e807f7,0xd83801ef,0x613406be,0x00000000}},	//   _मेच_, peče_, nülə, --, 
   {{0x3f680115,0x9c7c0118,0x00000000,0x00000000}},	//   rĝu_, _mlče, --, --, 
   {{0x1cb40003,0x13d4015b,0xddc000de,0xc6100154}},	//   _ཞོད_, _হইয়, _iemū, সেরা_, 
   {{0x0c940046,0x20180393,0xf1bc004d,0x61340213}},	//   ندىگ, _tyri_, _ngáy_, külə, 
   {{0x6ad8068f,0xdb0800c6,0xd838007f,0x00000000}},	//   बसूर, _ardá, ndčt_, --, 
   {{0xba741291,0xdb1c03b9,0x613403e3,0x00000000}},	//   راعت, _özüv, dülə, --, 
   {{0xa3e880a0,0xc1d801e1,0x00000000,0x00000000}},	//   _मेघ_, _ọ̀dè, --, --, 
   {{0x58d4005b,0x200c01bf,0x5d6801af,0xb88001ef}},	//   тоот, _ødis_, _ниғм_, _číst, 
   {{0xb4b00116,0x00000000,0x00000000,0x00000000}},	//   қивә, --, --, --, 
   {{0xcc080531,0x368801c6,0xddc000ef,0x00000000}},	//   _غزلن_, чсон_, _nemū, --, 
   {{0xe97178d2,0x00000000,0x00000000,0x00000000}},	//   _مهند, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x1cb40135,0xad180302,0x61340213,0x7bcc01e1}},	//   _ཞོན_, פולר, cülə, _àbud, 
   {{0x2284a6e6,0xdbe00227,0x56940116,0x78a801e3}},	//   лууг, nïña, _раит, _hafv, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [273b0] --, --, --, --, 
   {{0x71080212,0xe0d001d9,0xdef80022,0x00000000}},	//   їхав_, ٝزم_, ҭыц_, --, 
   {{0x2ae401e1,0xb5f801d3,0x2d880055,0x00000000}},	//   _lákọ_, zaál, _ūce_, --, 
   {{0x1fa558fb,0x1daca740,0x00000000,0x00000000}},	//   ыруг, चिंत, --, --, 
   {{0xfd240133,0x00000000,0x00000000,0x00000000}},	//   چونێ, --, --, --, 
   {{0xddc000e2,0x13d400eb,0x00000000,0x00000000}},	//   _zemū, _হেয়, --, --, 
   {{0x6a7829ef,0x00000000,0x00000000,0x00000000}},	//   jäfü, --, --, --, 
   {{0x9f3578d3,0xdea400f2,0xb5f803b2,0xceb801ef}},	//   _бесі, _میمی, taál, _ohři_, 
   {{0x09e4bb62,0x00000000,0x00000000,0x00000000}},	//   топн, --, --, --, 
   {{0x2ae401e1,0x290000c5,0xc0c80092,0xada000d0}},	//   _dákọ_, õja_, _በቀስ_, _vnúč, 
   {{0x8e7c01e4,0xe80802c3,0x00000000,0x00000000}},	//   _elŝe, _सुखा_, --, --, 
   {{0x497401c0,0x613400ac,0x9c7c0306,0x00000000}},	//   _алдс, rülə, _vlče, --, 
   {{0x38c804d3,0xdb1800e4,0x78a8007c,0x00000000}},	//   سایی_, tyvö, ömvä, --, 
   {{0x3af80a30,0x6aa978d4,0x443c00d4,0x00000000}},	//   rūpe_, _hagf, øt_, --, 
   {{0x07a4696b,0x27b001ee,0x00000000,0x00000000}},	//   _райн, _сәпс, --, --, 
   {{0x06f40502,0x03a4016c,0x00000000,0x00000000}},	//   _جستج, ниҳо, --, --, 
   {{0xd838009b,0x324002dd,0x8fd40131,0x00000000}},	// [273c0] meča_, реуг, қәрә, --, 
   {{0x6aa8e4c3,0xb5c80011,0x57a40124,0x78a8022e}},	//   _lagf, _লেকচ, _ршәа, _xafv, 
   {{0xd09578d5,0xdd1c01f1,0x00000000,0x00000000}},	//   ышты, _nášh, --, --, 
   {{0xa3dc0882,0x6aa80076,0xd8380219,0x01640117}},	//   तैः_, _nagf, neča_, _икмо, 
   {{0xcead0a6d,0xc1d00075,0x7410331c,0xdd9414d4}},	//   _һә_, _төвә, _مویا, уалы, 
   {{0x628578d6,0xdc4800db,0x00000000,0x00000000}},	//   lgio, رستۇ_, --, --, 
   {{0xceac0831,0x6aa863b3,0xfe440107,0xefb02099}},	//   _лә_, _bagf, _анбо, _پینگ, 
   {{0x628578d7,0x78a978d8,0x6bd00372,0xd8391bb5}},	//   ngio, _safv, شتىر, ječa_, 
   {{0xbd880502,0x6aa80579,0xada178d9,0x78a800df}},	//   _زنان_, _dagf, _катл, _pafv, 
   {{0xbc689528,0x6c80021f,0xb5f801e1,0x00000000}},	//   _آمان_, _ەلەم, baáj, --, 
   {{0x6aa811c0,0xb0780a1e,0x848c02d3,0x307808a8}},	//   _fagf, וניז, _ዝምራሕ_, ואינ, 
   {{0x9c7c0100,0xfaa40063,0xdb180588,0x2fc40254}},	//   _flčc, _јадо, tyvõ, ängi_, 
   {{0x5eac009e,0xb604117e,0x00000000,0x00000000}},	//   ছাপে, тянк, --, --, 
   {{0x7ae178da,0xb86415f6,0x78a801bf,0x62840042}},	//   _hlot, _شاتو, _uafv, egio, 
   {{0x24182e70,0xd8380010,0x6aa8013d,0xf3f000cc}},	//   воры_, beča_, _yagf, _আঁহৰ_, 
   {{0x628578db,0x00000000,0x00000000,0x00000000}},	//   ggio, --, --, --, 
   {{0x7ae178dc,0xd0100131,0xdb080166,0x7a2401a9}},	// [273d0] _mlot, ڭلا_, _irdä, fаti, 
   {{0x7ae178dd,0x6284011c,0x6600002d,0xd4c402dd}},	//   _llot, agio, úmke, _сөмк, 
   {{0x7ae178de,0xd01021ec,0x00000000,0x00000000}},	//   _olot, حلا_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6aa978df,0x00000000,0x00000000,0x00000000}},	//   _ragf, --, --, --, 
   {{0xe3b02a60,0x3b04013c,0x6aa80334,0xfcc001e0}},	//   _اری_, _ajoq_, _sagf, йәхм, 
   {{0x7ae178e0,0x35a00092,0x00000000,0x00000000}},	//   _blot, ጎልበት_, --, --, 
   {{0xdd1c01a2,0x7ae0b239,0xb5f808a5,0x00000000}},	//   _vášh, _clot, gaák, --, 
   {{0xd83809a8,0x9f240131,0x7ae00042,0x596401e0}},	//   veča_, _ئۈنۈ, _dlot, анығ, 
   {{0x7ae178e1,0xbc5400d0,0xb90400ee,0x08c40107}},	//   _elot, čšíc, лныз_, убон, 
   {{0x7ae178e2,0x6aa978e3,0x628403cb,0xcb540063}},	//   _flot, _tagf, ygio, _свећ, 
   {{0x7a24022e,0x00000000,0x00000000,0x00000000}},	//   zаti, --, --, --, 
   {{0xd8388b19,0x6d4c00d8,0x394003b2,0x00000000}},	//   reča_, _écad, íkst_, --, 
   {{0xd83809a8,0xdb081af9,0x99646ba3,0x00000000}},	//   seča_, _erdä, _өтәл, --, 
   {{0x1e200316,0xb698054e,0x62840051,0x00000000}},	//   _बर्ष_, mnân, tgio, --, 
   {{0x0504015b,0x9c7c00d0,0x6d5c02d1,0x704400d1}},	//   োগের_, _mlča, šqay, ۇرمە, 
   {{0x26c000df,0x4224f0c2,0xb698054e,0x00000000}},	// [273e0] _inio_, удав, onân, --, 
   {{0x27540020,0x628408e5,0xb698002d,0x00000000}},	//   _የተሰጠ, sgio, nnân, --, 
   {{0x645d78e4,0x7a2401d5,0x77440b82,0x201c06ea}},	//   mbri, rаti, _ከተስተ, ævi_, 
   {{0x645d78e5,0xa30402dd,0x7e293540,0x7a24022e}},	//   lbri, _түбе, ніла_, sаti, 
   {{0xf53c3be7,0x9238014b,0x06ac00eb,0xe808000d}},	//   lvår_, _ачру_, গাপি, _सुघा_, 
   {{0x645d78e6,0xfba978e7,0xed540063,0x00000000}},	//   nbri, етий_, ћој_, --, 
   {{0x2d8c35fb,0x645c00c6,0x7ae178e8,0xac1578e9}},	//   atge_, ibri, _plot, лошу_, 
   {{0xd0042d40,0x2904008f,0x00000000,0x00000000}},	//   _тосқ, _ajna_, --, --, 
   {{0x7ae0715e,0xa29002d3,0x645d78ea,0x7ce41427}},	//   _vlot, _ምጽናሕ_, kbri, _aðre, 
   {{0x26c00851,0x645c365a,0xda7001d9,0x7ae00210}},	//   _anio_, jbri, حُک_, _wlot, 
   {{0x645d78eb,0x7ae0f456,0x6ec809bb,0xca380115}},	//   dbri, _tlot, _सचमु, reŝa_, 
   {{0x7ae178ec,0xe9f40220,0x7c3000e2,0x00000000}},	//   _ulot, _әнші_, ķerē, --, 
   {{0xab60033f,0x645c0112,0xb9540640,0xab240395}},	//   ążen, fbri, _стећ, _соца_, 
   {{0x26c178ed,0x7b280198,0x645c0b4f,0x00000000}},	//   _enio_, _uƙub, gbri, --, 
   {{0x98780306,0x00000000,0x00000000,0x00000000}},	//   náči_, --, --, --, 
   {{0xddc00316,0xd8380010,0x00000000,0x00000000}},	//   _nemů, lečo_, --, --, 
   {{0x645cdfc1,0x394402d5,0x50f4230c,0x987802f0}},	// [273f0] bbri, _juos_, азат, háči_, 
   {{0x39441a44,0x0f0c39de,0x3d0c0034,0x1cb0031c}},	//   _muos_, िक्स_, ाकों_, ྐབས_, 
   {{0x929447cf,0x0f342ea3,0x21a4039b,0x64480306}},	//   _канц, لکرد, _қиём, ždic, 
   {{0x7d1978ee,0x2bb001ad,0x00000000,0x00000000}},	//   _akts, ंटसा, --, --, 
   {{0x9e6400d6,0xb698011f,0x7d2800f1,0x00000000}},	//   свід, ynân, چينې_, --, 
   {{0x2d8c0c86,0xc0c0010b,0xd8380219,0x00000000}},	//   rtge_, _мәхи, ječo_, --, 
   {{0xa2dd4491,0x25fc05f9,0x8e7c01e4,0x7b840131}},	//   _नवम्, _लेनी_, _elŝa, لايە, 
   {{0x645c04a7,0x9c7c02f0,0x4a440798,0xa3a8000d}},	//   zbri, _vlča, шнив, _खईस_, 
   {{0x6f1978ef,0x29201b49,0x06ac02f5,0xdea578f0}},	//   _ikuc, _ትእዛዛ, গামি, _دینی, 
   {{0x394578f1,0x08d4094e,0xfd4c0241,0xdfd000f1}},	//   _duos_, рция, _lakọ, _بيې_, 
   {{0xb69809b1,0xdcac00cf,0x4808aec3,0x47580395}},	//   rnân, _سۉي_, тенн_, ърпя_, 
   {{0x645c63ce,0x3944003a,0x00000000,0x00000000}},	//   wbri, _fuos_, --, --, 
   {{0x6f1801c8,0x2bb000ab,0x7afc068c,0x957400cf}},	//   _mkuc, ंटवा, èpte, йырч, 
   {{0x290416a3,0x6b8001f7,0xca380115,0x00000000}},	//   _ujna_, oung, leŝo_, --, 
   {{0x6b8178f2,0x6f181629,0x2d4805ac,0x067412e7}},	//   nung, _okuc, _løe_, _купя, 
   {{0x645c1aa7,0x26c178f3,0x6f1978f4,0xca3801e4}},	//   sbri, _unio_, _nkuc, neŝo_, 
  
   {{0xfd4c01f2,0xc0c82440,0xf53c0158,0x00000000}},	// [27400] _dakọ, _በቀለ_, rvår_, --, 
   {{0x6b808684,0x6564019f,0x6f1978f5,0x2328024c}},	//   kung, _iwih, _akuc, тоғи_, 
   {{0x6b8178f6,0x74780375,0xca3801e4,0x00000000}},	//   jung, _בניג, keŝo_, --, 
   {{0x6b8178f7,0x656464ee,0xfd4c063f,0x2d48143a}},	//   dung, _kwih, _gakọ, _bøe_, 
   {{0x6d48074d,0x6b8178f8,0xca3800df,0x00000000}},	//   gqga, eung, deŝo_, --, 
   {{0x6b8178f9,0x6f1848b5,0x6564bf65,0x7054010a}},	//   fung, _ekuc, _mwih, _варĕ, 
   {{0x39440483,0xbea53818,0x2fc541ae,0x00000000}},	//   _suos_, _кавк, ängt_, --, 
   {{0x8d78001f,0xad8400db,0x7a2401a9,0x00000000}},	//   ረባቸው_, _چالۇ, zаtu, --, 
   {{0x39440de4,0xcf24ea80,0x2754001f,0xd8380010}},	//   _quos_, _طرفي, _የሰለጠ, tečo_, 
   {{0x6b8178fa,0x9f240058,0xb698002d,0x98780030}},	//   bung, _ئۈچۈ, anâl, páči_, 
   {{0x6b80e988,0x7744044e,0x59a805f9,0x7ac43c55}},	//   cung, _ፕረሲደ, _कनवर, _всле, 
   {{0x6564015c,0x394578fb,0xd8380010,0x9c7c00d7}},	//   _bwih, _tuos_, sečo_, _klčo, 
   {{0xd95578fc,0x1fcc1c82,0xdb080332,0x00000000}},	//   _انتخ, লনিস, _ordú, --, 
   {{0x65640098,0xa4e402d5,0x96f80022,0x9c7c013a}},	//   _dwih, оўск, _әеит_, _mlčo, 
   {{0x32652bd8,0x3cec007d,0x7a2401a9,0x77914db6}},	//   итав, _अतने_, rаtu, _بیجا, 
   {{0x7c3403f9,0x6750d87e,0xe57800e2,0x31b400fb}},	//   ƙarƙ, _بخور, ņķa_, аҫмы_, 
   {{0x6b817053,0x909978fd,0xf65c003a,0x81780107}},	// [27410] zung, лват_, mbæ_, латӣ_, 
   {{0x2d481445,0x61300e78,0xc0c8001f,0x7bc80327}},	//   _røe_, hälf, _በቀል_, kxfu, 
   {{0x656406d6,0xd2f801af,0x6b800472,0x2d4801bf}},	//   _zwih, _бенц_, xung, _søe_, 
   {{0x6b8178fe,0x8d7578ff,0x25fc121d,0x00000000}},	//   vung, ماتا, _लेडी_, --, 
   {{0xed881411,0x9c7c01ef,0x00000000,0x00000000}},	//   тсек_, _vlčn, --, --, 
   {{0x2fc401e6,0xcc880108,0x00000000,0x00000000}},	//   ängs_, убке_, --, --, 
   {{0x6b817900,0xeea8023a,0xee84034b,0xf1c402f0}},	//   uung, _итак_, _вызо, skáč_, 
   {{0x6f180928,0x00000000,0x00000000,0x00000000}},	//   _ukuc, --, --, --, 
   {{0xdef97901,0xb990007b,0x6ca40798,0xeca4009b}},	//   _тыр_, كليب, _вреж, _вјен, 
   {{0x65640230,0x88c83afa,0x00000000,0x00000000}},	//   _rwih, улов_, --, --, 
   {{0x656406e4,0x07a4010b,0x6b817902,0xaac400f2}},	//   _swih, щанн, qung, _پتان, 
   {{0x7c2c01ab,0x7ce408ce,0x6f000332,0x00000000}},	//   _ùbra, _iðra, énch, --, 
   {{0xb6a00276,0x19940153,0x00000000,0x00000000}},	//   чиял, _маця, --, --, 
   {{0x3a340302,0x61300724,0x25fc0490,0x8a6002f2}},	//   _פרסם_, mälg, _लेणी_, _بێکۆ, 
   {{0xd3b434d8,0xbb2400d1,0x00000000,0x00000000}},	//   ость, ﻠﯘﻕ_, --, --, 
   {{0x65648aa7,0xab74001f,0x03240107,0xc244578a}},	//   _twih, _አይደል_, ёдан, снак, 
   {{0xa3a845bf,0x8e7c01e4,0x65657903,0x857400db}},	// [27420] _खैर_, _alŝo, _uwih, _ادبئ, 
   {{0x25a0020c,0x8068215c,0xc5f404af,0x00000000}},	//   _ipil_, اماق_, ीपीय_, --, 
   {{0x8234402b,0x2d9c013f,0x25fc060e,0x00000000}},	//   _گردا, _apue_, _लेती_, --, 
   {{0xfde97904,0xddc00311,0x7de401ec,0x00000000}},	//   лдек_, _nemţ, йілд, --, 
   {{0x82357905,0x7ce405a4,0x8e7c0115,0xfe440022}},	//   _دردا, _aðra, _elŝo, анҵо, 
   {{0xb5f800bc,0x7a24022e,0x6da00116,0x00000000}},	//   lbác, zаts, سمىم, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x25a0005a,0x24980175,0xb9480023,0x613001e3}},	//   _opil_, hfrm_, _መሲልዎ, fälg, 
   {{0x7a24022e,0x2010012d,0xab600210,0x00000000}},	//   vаts, źnię_, ążan, --, 
   {{0xd8f802bf,0x9c7c007f,0x2d54011a,0x2d98025c}},	//   рної_, _klčm, _לשמש_, ħqet_, 
   {{0x61317906,0x25a051e2,0x7118010f,0x69cc01bf}},	//   mäld, _apil_, רויפ, øcer, 
   {{0x39040228,0xf1bc01ed,0xab24030d,0x61300166}},	//   рдүү_, _szám_, _лоха_, bälg, 
   {{0x6f009b4c,0x2fc4001e,0xa2cc04e4,0xf65c01a8}},	//   énci, ̣ng_, हान्, rbæ_, 
   {{0x6448b745,0xa8700220,0xf65c01a8,0x3ea4003e}},	//   ždin, _елші, sbæ_, heot_, 
   {{0x569447ba,0xa90401c8,0xd6d0009f,0x00000000}},	//   _дайт, _ديول_, _يقت_, --, 
   {{0x92580cfc,0xe2f80220,0x00000000,0x00000000}},	//   раат_, бесі_, --, --, 
   {{0x3ea57907,0x623402dd,0x00000000,0x00000000}},	// [27430] deot_, зету, --, --, 
   {{0xc05400b8,0x00000000,0x00000000,0x00000000}},	//   _kīṭa_, --, --, --, 
   {{0x2fc4001e,0x61e800ac,0xf3f000cc,0x00000000}},	//   ãng_, _ədli, _আঁকৰ_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8c44ac62,0x5f780131,0xf1bc025c,0x00000000}},	//   оеле, لمەس_, ġġsu_, --, 
   {{0x8c940220,0x6130ff6c,0x00000000,0x00000000}},	//   ірлі, gäld, --, --, 
   {{0xd52c0208,0xbb501e57,0x00000000,0x00000000}},	//   _mừn, ونوب, --, --, 
   {{0xa2cc53b7,0xca8401c6,0x1a683267,0xab8401a9}},	//   हाय्, цгий, میمی_, _ҳудк, 
   {{0xa8740137,0xf1bc00e5,0x00000000,0x00000000}},	//   бөйт_, _száj_, --, --, 
   {{0xab857908,0xc7940276,0x76580309,0xb5f802f0}},	//   _гудк, ормы, ñuyn, zbác, 
   {{0x25a14608,0x2740020c,0xb5f80306,0x00000000}},	//   _spil_, dènè_, ybác, --, 
   {{0x2ca49613,0x61317909,0xdd900014,0x00000000}},	//   lend_, mäle, _توے_, --, 
   {{0xb5f80306,0xe6040116,0x04b4234c,0xddc00064}},	//   vbác, яҗин, освя, _kemš, 
   {{0x2ca45475,0x17a800cc,0x00000000,0x00000000}},	//   nend_, _ওপৰি, --, --, 
   {{0x443c578c,0x613026f8,0x6b44000f,0x2ca45d43}},	//   ät_, näle, _fűge, iend_, 
   {{0x2ca5790a,0x03242626,0x3ae80241,0xddc000ef}},	//   hend_, ідан, _tùpe_, _lemš, 
   {{0x2ca5790b,0xb5f9790c,0x25a06abe,0x61300e78}},	// [27440] kend_, rbác, _upil_, häle, 
   {{0xddc00fb7,0x2ca5790d,0x61315898,0x00000000}},	//   _nemš, jend_, käle, --, 
   {{0x613001e3,0x3ea401f4,0x00000000,0x00000000}},	//   väld, teot_, --, --, 
   {{0xb87c01e4,0x613008c6,0x7e24005b,0x2ca406be}},	//   _alƭl, wäld, одеж, eend_, 
   {{0xcd380952,0x82340214,0x2ca40e21,0xd52c0051}},	//   ﻤﻨﯩﯔ_, _گرگا, fend_, _hứn, 
   {{0x2ca5790e,0x6ca000a7,0x3ea40108,0x6131790f}},	//   gend_, дръж, seot_, fäle, 
   {{0x61317910,0x823446ca,0xddc00010,0x5bc400cd}},	//   räld, _درگا, _demš, वमेव, 
   {{0x6b440139,0xd8380010,0xef140fac,0x6d480162}},	//   _nıgu, sečk_, _дмс_, úlaí, 
   {{0x7e617911,0x2ca57912,0xed540f64,0x6f0000cf}},	//   mbop, bend_, _мот_, ènce, 
   {{0x2ca525cd,0xac800209,0xd8388e70,0x9c7c02f0}},	//   cend_, _огул, leči_, _mlčk, 
   {{0xed000014,0xd52c0051,0x6130008e,0x00000000}},	//   _توٕپ, _rừn, cäle, --, 
   {{0xb9c41671,0x64480306,0xd8380010,0x2744033b}},	//   _وقاي, ždil, neči_, vènè_, 
   {{0x6a980375,0x00000000,0x00000000,0x00000000}},	//   _כשאנ, --, --, --, 
   {{0x2744007f,0x00000000,0x00000000,0x00000000}},	//   tènè_, --, --, --, 
   {{0x3e60022e,0xd52c0208,0xca380150,0x00000000}},	//   _oаt_, _cứn, _ﻔﺎﺕ_, --, 
   {{0x25b00664,0xd8381883,0x01d40183,0x2ca54bc7}},	//   ällä_, ječi_, _সেইদ, zend_, 
   {{0x91c40724,0xa1945a52,0xd52c004d,0xd8381a48}},	// [27450] чәнл, матч, _từn, deči_, 
   {{0x160002ab,0xc79401d3,0x25a80451,0x00000000}},	//   _लेयर_, _بھیا_, _بگٽي_, --, 
   {{0x2ca57913,0xb4e40034,0xddc00010,0xa0c40849}},	//   vend_, पसी_, _remš, ظيمو, 
   {{0x2ca57914,0x61301611,0x00000000,0x00000000}},	//   wend_, väle, --, --, 
   {{0x2ca57915,0x6cb0035b,0x7e940244,0x00000000}},	//   tend_, мҩат, سنور_, --, 
   {{0xf1bd7916,0x613170b5,0xdebc02a8,0x0ba802de}},	//   _irá_, täle, _murƙ, ماعى_, 
   {{0x2ca57917,0xf1bc0030,0x7e600fac,0xd8380427}},	//   rend_, _hrá_, bbop, beči_, 
   {{0xdef8039e,0x9f3402dd,0xf1bc02d2,0x00000000}},	//   _дыу_, _жесі, _krá_, --, 
   {{0xdd587979,0x61317918,0xa2cc0a94,0x2ca4f828}},	//   _матч_, säle, हात्, pend_, 
   {{0x6d597919,0xab609498,0xf1bc0332,0x6130005b}},	//   _itua, _قۇتى, _mrá_, päle, 
   {{0x4ab8004e,0xdb0802f0,0x6f080208,0x16003d1d}},	//   _гуля_, _hrdý, ongc, _लेबर_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6b800194,0x6f0800f1,0xaa0400ec,0xf1bc01e1}},	//   lrng, ingc, _بظاه, _nrá_, 
   {{0xdebd791a,0x6d59791b,0xf65c01bf,0x8da00150}},	//   _durƙ, _mtua, fjæs_, _ﺍﺴﺤﻕ_, 
   {{0xf1bc0cad,0x6130002f,0x8a1000f1,0x00000000}},	//   _ará_, hälc, _تېښت, --, 
   {{0x1cd40156,0xb5f9791c,0x6d5803a0,0xf1bc0321}},	//   ེཡོ_, mbán, _otua, _brá_, 
   {{0x6d580211,0xe1f800dc,0xf1bc00ae,0xd8380427}},	// [27460] _ntua, ूपेण_, _crá_, veči_, 
   {{0xf6140302,0x6f0800f1,0x31200556,0x9c7c0306}},	//   _מחפש_, engc, едуг, _vlčk, 
   {{0x6d59791d,0xc2c40491,0xd83809a8,0x9f780023}},	//   _atua, _فيدي, teči_, _ኣልዒሉ_, 
   {{0xf1bc6984,0x2fc401e6,0x3e6001a9,0x00000000}},	//   _frá_, ånga_, _qаt_, --, 
   {{0x63bc074d,0xb8cc081f,0x7e611844,0xba4405f5}},	//   lvrn, _ཕྲ_, rbop, үхий, 
   {{0x6d5800c6,0xd83809a8,0x5bc40107,0x6f080051}},	//   _dtua, seči_, дриҷ, angc, 
   {{0x6d59791e,0xd8380010,0x00000000,0x00000000}},	//   _etua, peči_, --, --, 
   {{0x6d5802d3,0x9c7c00d7,0xfd4801af,0xb5f8013a}},	//   _ftua, _mlči, _гзак_, dbán, 
   {{0xf65c1477,0x9ab40055,0x25fc00c5,0x7f4c0009}},	//   kjær_, _chāṃ, _लेली_, _hubq, 
   {{0x7f4c0548,0xdc3c00d0,0x63bc16a3,0x5ce80345}},	//   _kubq, _háči, kvrn, _ببرێ_, 
   {{0x3cfc014b,0xfaa5791f,0xb5f8398f,0xf80475d7}},	//   _imtv_, _нажо, gbán, ячин, 
   {{0x98bc00cd,0x00000000,0x00000000,0x00000000}},	//   _divā_, --, --, --, 
   {{0x255800bc,0xf65c03cd,0xd7f8054e,0x00000000}},	//   vělý_, fjær_, mbăm_, --, 
   {{0x2458040e,0x3a2400ca,0xb4e4202e,0xf65c143a}},	//   зарь_, _iyop_, पसे_, gjær_, 
   {{0x28b40375,0xb2840022,0x28980677,0xf4800023}},	//   _מפגש_, зызк, _ליגא, _ክዝረብ_, 
   {{0xf1bc10d8,0xdc3c02fb,0xf2d001b9,0xe2f801ec}},	//   _prá_, _náči, رآز_, песі_, 
   {{0xe73000b2,0x30a5772a,0x37180014,0x98e00cf1}},	// [27470] _حصو_, зрев, _پرژھ_, _पकाए, 
   {{0x3a240998,0xdb0807c5,0x386c004e,0xf1bc03b2}},	//   _myop_, _ardü, _jefr_, _vrá_, 
   {{0x386c002d,0xae1c0037,0x00000000,0x00000000}},	//   _mefr_, _बडहन_, --, --, 
   {{0xf1bd7920,0x9f4c01ed,0x6f080c6a,0x5f2800d4}},	//   _trá_, álás_, ungc, поєм_, 
   {{0xd8380cf4,0x6b44013d,0x00000000,0x00000000}},	//   meču_, _nıgr, --, --, 
   {{0xdb097921,0x00000000,0x00000000,0x00000000}},	//   _ordó, --, --, --, 
   {{0x3a24089c,0x00000000,0x00000000,0x00000000}},	//   _ayop_, --, --, --, 
   {{0x6130049f,0x99800f03,0x00000000,0x00000000}},	//   mäla, _šiš_, --, --, 
   {{0x386c030d,0xdb0801e7,0xa8740137,0x6d597922}},	//   _befr_, _ardó, пөйт_, _utua, 
   {{0x5f7400e5,0x00000000,0x00000000,0x00000000}},	//   _زاہر, --, --, --, 
   {{0x61300840,0x00000000,0x00000000,0x00000000}},	//   näla, --, --, --, 
   {{0xd8384473,0xb5f86428,0x00000000,0x00000000}},	//   ječu_, rbán, --, --, 
   {{0xa2cc0825,0x9a841ebb,0x61301572,0x00000000}},	//   हास्, _чухл, häla, --, 
   {{0xd1f4010c,0xb5f83b2c,0x613001f4,0x00000000}},	//   ዉነት_, mbál, käla, --, 
   {{0x8e7c00df,0x61303167,0xc9846b21,0x00000000}},	//   _elŝi, jäla, _хуҗи, --, 
   {{0x04fc015b,0xb698000f,0xf2a0084c,0x9c7c0f91}},	//   ংকের_, liân, кисп, _vlči, 
   {{0x453400c9,0x67257923,0x40940166,0x7f4d3322}},	// [27480] _охот, _ikij, дрет, _subq, 
   {{0x27440241,0x84e401c0,0x3af83d4f,0xd52c0051}},	//   _fènì_, _цоож, rūpi_, _vữn, 
   {{0xdc3c01f1,0x7f4c014f,0x070002fe,0x00000000}},	//   _páči, _qubq, _लगाव_, --, 
   {{0xf1bc0ca8,0x3f6800df,0x00000000,0x00000000}},	//   _iyán_, rŝu_, --, --, 
   {{0xed54da98,0x672401f7,0xb7c000e2,0xd8380010}},	//   وشوت_, _mkij, ļģij, lečt_, 
   {{0x61e57924,0xa2b40073,0x00000000,0x00000000}},	//   myil, _उघड्, --, --, 
   {{0x386d7925,0xdd940032,0xe2080034,0x60dc01ab}},	//   _refr_, фаһы, _wróć_, _iorm, 
   {{0x60dd7926,0x6724895d,0x61e401e2,0x6a78013d}},	//   _horm, _nkij, oyil, _näfı, 
   {{0x60dd7927,0x386c0142,0x5ddc00fe,0x00000000}},	//   _korm, _pefr_, _মেৰু, --, 
   {{0xfbc57928,0x61e40d04,0x67240451,0x60dca94d}},	//   _обзо, iyil, _akij, _jorm, 
   {{0x60dc0ba9,0xb8e405d7,0x311c1fad,0x61e40108}},	//   _morm, _उफ_, भवतः_, hyil, 
   {{0x61e403a2,0x5ee00154,0x386c015d,0x00000000}},	//   kyil, পোরে, _wefr_, --, 
   {{0xf1bc0005,0x60dc05e4,0x19c40166,0x61e40108}},	//   _ayán_, _oorm, _чәйг, jyil, 
   {{0x67240a49,0x98bc0311,0x61e401f4,0x00000000}},	//   _ekij, _divă_, dyil, --, 
   {{0xb5f885a0,0x00000000,0x00000000,0x00000000}},	//   mbám, --, --, --, 
   {{0x61300844,0x78b8072b,0x2284004e,0x62240116}},	//   väla, ldtv, кууг, ھىلل, 
   {{0x60dd7929,0xd839089a,0x61e401d3,0x521401f0}},	// [27490] _borm, reču_, gyil, хдат, 
   {{0x60dd792a,0x6130248c,0xe61000be,0xfafc002b}},	//   _corm, täla, _خشى_, _śīla_, 
   {{0x92582d3c,0x00000000,0x00000000,0x00000000}},	//   _нант_, --, --, --, 
   {{0x61e4002d,0xc43808a8,0xb69800d8,0x78b802d0}},	//   byil, _מתתי, ziân, hdtv, 
   {{0xa2cc6b26,0x61314a5c,0x00000000,0x00000000}},	//   हार्, mäln, --, --, 
   {{0xc210010f,0x613001f4,0x0bb40395,0x00000000}},	//   _עהם_, päla, ещия, --, 
   {{0x75c80574,0x4a740220,0x160001ad,0x6cc001e0}},	//   ामुळ, ныпт, _लेसर_, ейҙа, 
   {{0xe57800e2,0x60dd792b,0xdb800023,0xce580354}},	//   ņķi_, _zorm, ከቡዎም_, _хаац_, 
   {{0x80b40034,0x60dc5b92,0x6a78013d,0x9f05792c}},	//   _उसमे, _yorm, _räfı, _شوكو, 
   {{0x6724098d,0x237800d8,0xb5f826f6,0x60dc79fa}},	//   _skij, ysrj_, rbál, _xorm, 
   {{0x386402d3,0xb69800d8,0x61e40205,0x00000000}},	//   _ዘጠራጥ, riân, zyil, --, 
   {{0xf2dc015d,0x61e40de2,0x00000000,0x00000000}},	//   _siân_, yyil, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7de8006a,0x6ab9562b,0x61e4005b,0x00000000}},	//   lësö, lduf, vyil, --, 
   {{0x46a402bf,0x60dc0175,0x25fc00af,0xaad06b26}},	//   _зайв, _rorm, _लइकी_, थापक, 
   {{0x61e5792d,0x6725792e,0x00000000,0x00000000}},	//   tyil, _ukij, --, --, 
   {{0x60dc89f7,0xf55400c6,0x00000000,0x00000000}},	// [274a0] _porm, _كليب_, --, --, 
   {{0xb2211394,0x26f046c7,0x60dd792f,0xb5f4011a}},	//   умул, _चतुर_, _qorm, _נציג_, 
   {{0x60dd7930,0x442c03b2,0xafe001d5,0x61e401f4}},	//   _vorm, _áf_, лофл, syil, 
   {{0x60dc061d,0x3ae801e1,0x61e401f4,0xa2cc01f9}},	//   _worm, _rùpo_, pyil, हाळ्, 
   {{0x60dd7931,0x6ab803f9,0xaad0716d,0x00000000}},	//   _torm, dduf, थानक, --, 
   {{0x613001b8,0x3f980327,0x00000000,0x00000000}},	//   mälo, ptpu_, --, --, 
   {{0xcead7932,0x8e7c010f,0x61300166,0x00000000}},	//   _кә_, _alŝu, lälo, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6e900597,0x613001b8,0xcf24038b,0x6da0010a}},	//   _حلقا, nälo, _شرفي, _йита, 
   {{0x6ab80e14,0x78b80af9,0x49e00131,0xceb801ef}},	//   aduf, udtv, شۋىق, _zař_, 
   {{0x8e7c00c8,0xad1827af,0x78b803cd,0xeaac0050}},	//   _elŝu, _צובר, rdtv, _گٹن_, 
   {{0x248002d3,0xa2dc1116,0x0ba800d1,0x6ab8031c}},	//   _ክምለስ_, _नवग्, _تاكى_, cduf, 
   {{0xca747626,0x7ce42242,0x916c001e,0x4a740006}},	//   _рухы, _aðri, _một_, _рыхт, 
   {{0xdb8002d3,0x916c0051,0x00000000,0x00000000}},	//   _ከይዶም_, _lột_, --, --, 
   {{0xe3b000dd,0xf2c57933,0xdebc0092,0x00000000}},	//   یرہ_, нсан, ቱንና_, --, 
   {{0xd7f80116,0x00000000,0x00000000,0x00000000}},	//   _нуқ_, --, --, --, 
   {{0x613001b8,0x00000000,0x00000000,0x00000000}},	// [274b0] gälo, --, --, --, 
   {{0x6d4c6c80,0x635c007f,0x65600332,0xa0b8009d}},	//   _écai, _sčne, ímhe, нгуу_, 
   {{0x6130071f,0xe610004b,0xd7f80311,0xd0100fba}},	//   mäll, _نشی_, nză_, جلا_, 
   {{0xdef97934,0x8d741887,0x61317935,0x916c0051}},	//   ныч_, ناتا, läll, _cột_, 
   {{0x61300793,0xdea401d5,0x00000000,0x00000000}},	//   cälo, طیلی, --, --, 
   {{0x6130023a,0x20180208,0x00000000,0x00000000}},	//   näll, _fxri_, --, --, 
   {{0x611400a7,0x601800d4,0x64480419,0x00000000}},	//   _сдру, _зоря_, ždiv, --, 
   {{0x635c0427,0x49c803f6,0x00000000,0x00000000}},	//   _učne, длин_, --, --, 
   {{0xeb94136b,0x61314a5c,0xadb400d1,0x9e0800ae}},	//   фиқ_, käll, _سۇغا_, _كيفك_, 
   {{0x61302c4f,0x8e7c01e4,0x25fc033f,0x3a200139}},	//   jäll, _elŝt, _लेगी_, рмьг, 
   {{0x2d8c0bb8,0xf2dc022f,0x61305dcf,0xc05000d9}},	//   luge_, _ooâ_, däll, יזי_, 
   {{0x998000d7,0x00000000,0x00000000,0x00000000}},	//   _šiť_, --, --, --, 
   {{0x61317936,0xd7f80262,0xc8f40801,0x24800023}},	//   fäll, ază_, _издъ, _ክምልስ_, 
   {{0x61317937,0x07a4004e,0x00000000,0x00000000}},	//   välo, _аакн, --, --, 
   {{0x2d8c00ca,0x14180276,0x7bcc0248,0x00000000}},	//   huge_, ецть_, _àbut, --, 
   {{0x2d8cc586,0x00000000,0x00000000,0x00000000}},	//   kuge_, --, --, --, 
   {{0x9c7c151c,0x7afc588b,0x61300112,0xf2dc0051}},	// [274c0] _hoče, èpti, bäll, _giâm_, 
   {{0x9c7c1d49,0xf060634c,0xd0580006,0x2d8d7938}},	//   _koče, икуп, ерці_, duge_, 
   {{0x6130023a,0x9c7c0010,0x00000000,0x00000000}},	//   sälo, _joče, --, --, 
   {{0x645c0393,0x9c7c3831,0x613001b8,0xcf24004b}},	//   lcri, _moče, pälo, هرني, 
   {{0x9c7c151c,0x2d8c7c60,0x645c0393,0xada002f0}},	//   _loče, guge_, ocri, _naúč, 
   {{0xd40801d5,0xed540640,0x00000000,0x00000000}},	//   _آتیم_, њој_, --, --, 
   {{0x9c7c09a8,0x2d8c0158,0xff24013e,0xac140276}},	//   _noče, auge_, _амво, кошу_, 
   {{0x2fc404ce,0x1ab57939,0xceb42f16,0x645c00d8}},	//   ænge_, убия, _бәш_, hcri, 
   {{0x645d793a,0x46d400bc,0x61300108,0x53800240}},	//   kcri, धानह, yäll, _ንግደድ_, 
   {{0x394801b8,0x7778208d,0x7790331c,0xda700014}},	//   öbs_, tstx, لیتا, جُک_, 
   {{0x9aa4052f,0x6131793b,0xeb94fbd3,0xd7f80356}},	//   _булһ, väll, _аих_, uză_, 
   {{0x9c7c04b9,0x795004d3,0x645c01f5,0xd7f8054e}},	//   _doče, _پێدا, ecri, rză_, 
   {{0x61300628,0x645c0393,0x1ce00327,0x00000000}},	//   täll, fcri, _སྭོ_, --, 
   {{0x645c00a3,0x2c0401f9,0x00000000,0x00000000}},	//   gcri, _वेडं_, --, --, 
   {{0x06ac015b,0x6130088f,0xada013d5,0x68e40267}},	//   গাজি, räll, _zaúč, öjde, 
   {{0x6130049b,0x8e7c01e4,0xe781793c,0xdb080112}},	//   säll, _koŝe, _тушо, _erdö, 
   {{0x61300108,0x00000000,0x00000000,0x00000000}},	// [274d0] päll, --, --, --, 
   {{0x2d8c015c,0x25fc00e1,0x00000000,0x00000000}},	//   vuge_, _लेटी_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf2c40276,0x2d8d793d,0x69b42894,0x61300254}},	//   _рсон, tuge_, ्टमी, nälj, 
   {{0x644800f3,0x7de800e2,0x00000000,0x00000000}},	//   ždit, _nēsā, --, --, 
   {{0x2d8d793e,0xdf380131,0x7c700075,0x00000000}},	//   ruge_, ىكەت_, йғуч, --, 
   {{0xdfd40724,0x2d8d793f,0x1a68036b,0x00000000}},	//   _коры, suge_, چیمی_, --, 
   {{0x8e7c0115,0x61306775,0x9c7c02f0,0xdea40345}},	//   _boŝe, jälj, _roče, _نیمی, 
   {{0x7ce40162,0x9c7c0427,0xae1400c5,0x6ca4007b}},	//   _aðru, _soče, _दखिन_, _لصال, 
   {{0x9c7c0b9d,0x645c0334,0x00000000,0x00000000}},	//   _poče, xcri, --, --, 
   {{0xf77000ec,0x00000000,0x00000000,0x00000000}},	//   ٽاپ_, --, --, --, 
   {{0x2cf02c35,0xdc700022,0x00000000,0x00000000}},	//   _अतुल_, _лҳәы, --, --, 
   {{0x645c9ccd,0x00000000,0x00000000,0x00000000}},	//   tcri, --, --, --, 
   {{0xb6d00efb,0x9c7c19d6,0x00000000,0x00000000}},	//   _ۇقىع, _toče, --, --, 
   {{0x27b00075,0x9c7c041a,0x83382e91,0x07a4d808}},	//   _тәпс, _uoče, ечат_, _сайн, 
   {{0x645cef30,0x430800b2,0x765802d1,0x9c7c01ef}},	//   scri, ريءَ_, ñuyt, _kočc, 
   {{0x52746768,0x645c003a,0x00000000,0x00000000}},	// [274e0] русу, pcri, --, --, 
   {{0x65657940,0x00000000,0x00000000,0x00000000}},	//   _itih, --, --, --, 
   {{0x7498025f,0x71a01ee3,0x00000000,0x00000000}},	//   _אייפ, _қарз, --, --, 
   {{0x3f841d55,0x0b140154,0xef1c0327,0xdb2403e0}},	//   čou_, াতুল_, żżna_, örüy, 
   {{0xd1742b41,0xfce44d0b,0xf2d0008f,0x6564031c}},	//   _высы, лодо, _הער_, _jtih, 
   {{0x65640451,0x412800d6,0x7bdc023a,0x00000000}},	//   _mtih, _чого_, äpuo, --, 
   {{0x3f9c002e,0xeb9400d8,0x00000000,0x00000000}},	//   _ëtu_, гиј_, --, --, 
   {{0xb5f97941,0x1334001f,0xa3ac1b76,0xaba41c43}},	//   mbáv, _በእነዚ, _गहन_, اهيم_, 
   {{0x65657942,0x61317943,0xbd886248,0xcd28104b}},	//   _ntih, välj, _سنان_, رسۇن_, 
   {{0x7f40006c,0xed557944,0x7de800e2,0xbb8401f7}},	//   lmoq, _соф_, _vēsā, _ملئي, 
   {{0x6565497d,0xd6d4e12b,0x613001e6,0xfa6802e8}},	//   _atih, ажны, tälj, _заек_, 
   {{0x7f4007d6,0x00000000,0x00000000,0x00000000}},	//   nmoq, --, --, --, 
   {{0x58d4189d,0x656402f0,0x67040073,0xa9640354}},	//   _волт, _ctih, शोधक_, _бича_, 
   {{0x6130049f,0x7f4001b9,0xaee0002b,0x656403e3}},	//   sälj, hmoq, _kiṃn, _dtih, 
   {{0x7ae17945,0x65657946,0x7f4001a9,0x00000000}},	//   _koot, _etih, kmoq, --, 
   {{0x81ac09bd,0x7ae11bfd,0xb5f80306,0xc7ac01d3}},	//   কিন_, _joot, dbáv, _کڑی_, 
   {{0x7ae00ba7,0x909800a7,0x1074003b,0x953800f3}},	// [274f0] _moot, кват_, илаю, _изит_, 
   {{0x7ae17947,0x3b0401d5,0xb5f803df,0x20980139}},	//   _loot, _lmoq_, rcád, лкуы_, 
   {{0x53342cfe,0xd250103c,0x74100451,0xb5f800e4}},	//   _вент, _وند_, _چوڌا, scád, 
   {{0x7ae17948,0xdb1800b5,0x7f40022e,0x00000000}},	//   _noot, lvvæ, gmoq, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x0ba80dd8,0x8e7c0115,0x394d7949,0x1ce00327}},	//   ناعى_, _elŝp, _nifs_, _སྭཱ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7ae1794a,0xd1f8001f,0x28b41b6e,0x00000000}},	//   _coot, _ለይቶ_, _असहि, --, 
   {{0x7ae1794b,0x88d40953,0x6f0801e2,0x613001e3}},	//   _doot, аўні, migc, fälh, 
   {{0x6f081ae8,0x35800023,0xfd4c0ca8,0x00000000}},	//   ligc, ራጃታት_, _oniṣ, --, 
   {{0x7ae1794c,0x07a5794d,0xc7a40416,0x55c40032}},	//   _foot, шанн, шинк, ҙарғ, 
   {{0x7ae1794e,0x6f08014b,0x394c0142,0x79ac02dd}},	//   _goot, nigc, _eifs_, _ﺳﻴﯩﻤ, 
   {{0xfd4c00cd,0x6d4c021c,0x6d404230,0x29080332}},	//   _aniṣ, _écas, omna, écas_, 
   {{0x7ae1794f,0x2d9c003a,0x7f4001b9,0x6d4003d5}},	//   _zoot, _mque_, zmoq, nmna, 
   {{0x044400e6,0x7ae17950,0x29057951,0x7f40036b}},	//   ревн, _yoot, _imna_, ymoq, 
   {{0x68e17952,0x16002007,0x2d9c06ed,0x394c2045}},	//   _hond, _लेकर_, _oque_, _zifs_, 
   {{0x68e17953,0x8be800bd,0x41044855,0x26c0004e}},	// [27500] _kond, _কেমন_, азав, _iaio_, 
   {{0x68e17954,0x248c0023,0x27540092,0xf53c007c}},	//   _jond, ሕዳራት_, _ከተሰጠ, vtåg_, 
   {{0x7f4007d6,0x2d9c0393,0x26c0005a,0x8fd41b15}},	//   tmoq, _aque_, _kaio_, бәтә, 
   {{0x81ac39db,0x6f097955,0xd1f8044e,0xbea57956}},	//   কিব_, gigc, _ለይቲ_, радк, 
   {{0x823442c5,0x26c07c36,0x7f417957,0x68e17958}},	//   _خردا, _maio_, rmoq, _oond, 
   {{0x68e17959,0x6131795a,0xbf6404d3,0x1ec800d1}},	//   _nond, käli, _ندرو, _әһди_, 
   {{0x7ae1795b,0x7d08008c,0x26c008e7,0x2d9c0381}},	//   _poot, rifs, _oaio_, _eque_, 
   {{0x26c008cd,0x68e1795c,0x2905795d,0x9c7c3ebb}},	//   _naio_, _aond, _amna_, _doča, 
   {{0x68e1795e,0x7ae1795f,0xa9740032,0x635c0e04}},	//   _bond, _voot, айыу_, _očno, 
   {{0x7ae12ddd,0x9c7c193c,0x290405b1,0xfbd0030f}},	//   _woot, _foča, _cmna_, _وتا_, 
   {{0x68e17960,0x7ae17961,0x26c0056a,0x2b4d7962}},	//   _dond, _toot, _baio_, _figc_, 
   {{0x29040c86,0x6d4c4aee,0x26c17963,0x7ae00418}},	//   _emna_, _écar, _caio_, _uoot, 
   {{0x6f000e26,0x26c006c8,0x4438009d,0xfbac009e}},	//   ènci, _daio_, _azp_, _কপটত, 
   {{0x68e17964,0x29044862,0x7980004c,0x6f081cdf}},	//   _gond, _gmna_, _ivow, zigc, 
   {{0x26c00077,0x6f084b26,0x61300139,0x3328009d}},	//   _faio_, yigc, cäli, вцан_, 
   {{0x68e00460,0x26c01701,0x6d417965,0x972400e3}},	//   _zond, _gaio_, zmna, _دفعو, 
   {{0x68e17966,0x6d417967,0xb5f804d4,0x3ea401e3}},	// [27510] _yond, ymna, scáb, dfot_, 
   {{0x26c005f5,0xdb1801e6,0x68e001a9,0xc05400b8}},	//   _zaio_, lvvä, _xond, _kūṭa_, 
   {{0x26c00a73,0x6f08003c,0x2d9c003a,0xa0540212}},	//   _yaio_, tigc, _sque_, івці, 
   {{0x9f0427e9,0xe3b17968,0x9c7c09a8,0xd25001d9}},	//   يولو, _کری_, _roča, _ڈنگ_, 
   {{0xb5f8b4b9,0x44380196,0x28b405f9,0x10880724}},	//   mbás, _zzp_, _असलि, _бөек_, 
   {{0x9c7d7969,0x6f09796a,0xd250014d,0x6d4008c2}},	//   _poča, sigc, _ونگ_, umna, 
   {{0x6d41796b,0x79800c21,0x7b8400d1,0xa2cc23e9}},	//   rmna, _avow, مايە, हाच्, 
   {{0x68e1796c,0x6130db6d,0x2d9c003a,0x6d4002d0}},	//   _sond, väli, _tque_, smna, 
   {{0x26c1796d,0x0904abfc,0x7c380165,0x2fcc0210}},	//   _raio_, йпин, _eztr, łogę_, 
   {{0x6e38015c,0x68e1796e,0x26c05260,0x9c7c1674}},	//   _izub, _qond, _saio_, _toča, 
   {{0x26c1796f,0x68e028ab,0x9c7c05ce,0x6f180113}},	//   _paio_, _vond, _kočn, _kjuc, 
   {{0x2d8c0944,0x81ac11ba,0x68e17970,0x443802f0}},	//   orge_, কিত_, _wond, _rzp_, 
   {{0x9c7c0fb7,0x07a4035b,0x00000000,0x00000000}},	//   _močn, шаҽн, --, --, 
   {{0x69c8717b,0x68e17971,0x2904022f,0x2d8d7972}},	//   _irge, _uond, _umna_, irge_, 
   {{0x26c03b28,0x764801d3,0x430800ec,0x935800d4}},	//   _taio_, _úgyn, ٿيءَ_, ирту_, 
   {{0x9c7d7973,0x6f1802ce,0x6e3802fb,0x25a0025c}},	//   _nočn, _njuc, _ozub, _tqil_, 
   {{0x6e397974,0xd5b001fb,0x69c8007c,0x00000000}},	// [27520] _nzub, ắc_, _jrge, --, 
   {{0xb5f8022c,0x2d8c0427,0x7bdc005b,0x160028d4}},	//   rbát, drge_, äpuk, _लेटर_, 
   {{0x2d8cae4d,0x9c7ccc1a,0x6e397975,0xa3ac02c3}},	//   erge_, _bočn, _azub, _गहि_, 
   {{0x6e900597,0x8e7c0115,0x59bc02ab,0xb5f80c63}},	//   كلما, _poŝa, ्टमर, mbár, 
   {{0x7d18010a,0x7c3858a5,0x6e38012d,0x8eb80022}},	//   _pjts, _sztr, _czub, рыхт_, 
   {{0x635c02e2,0xa3cc1f13,0x313000c0,0x00000000}},	//   _lčnm, लिप_, _неўр, --, 
   {{0x6e3801f2,0xdb20006a,0x2d8c045f,0x2fc40267}},	//   _ezub, ëtïn, arge_, ångt_, 
   {{0xbf157976,0x69c8003e,0x7c38151c,0xab800a89}},	//   _اورب, _brge, _vztr, чушк, 
   {{0x62880171,0x00000000,0x00000000,0x00000000}},	//   _ēdol, --, --, --, 
   {{0x6d4c8607,0x7d2400db,0x71b80a7c,0x00000000}},	//   _écap, _افئن, נציג, --, 
   {{0x81dc03d4,0x7c381ebf,0xd7f80356,0xb4f000ee}},	//   তনি_, _uztr, acăn_, җүнч, 
   {{0x7e617977,0xa3cc141f,0x9c7c02f0,0xe66411f7}},	//   ncop, लिन_, _kočo, зтро, 
   {{0x69c801a6,0xdd0800d7,0xdb18000d,0x6ac00101}},	//   _grge, _môžn, rvvä, _رقوم, 
   {{0x9c7c0122,0xa9980375,0x12c400fe,0x00000000}},	//   _močo, _עבור, _একেদ, --, 
   {{0x7bdc005b,0xd05403b9,0x61300108,0x00000000}},	//   äpuh, _gozə, nälu, --, 
   {{0x387c05da,0xc9080eac,0x4abc00cd,0x00000000}},	//   latr_, রকৃত_, ्ययव, --, 
   {{0x9c7c4ea1,0x6f18000f,0x8be80154,0x7e6003ac}},	// [27530] _ročn, _rjuc, _কোন_, dcop, 
   {{0x6f18000f,0x387c05da,0x32cc0139,0xf4180183}},	//   _sjuc, natr_, _böyä_, _ধৰণৰ_, 
   {{0x3e5c02e3,0x7e60003a,0x6e3858a5,0xa8540375}},	//   _ịta_, fcop, _szub, ציאה_, 
   {{0x635c110c,0x387c03d1,0x7e6002d0,0x00000000}},	//   _očnj, hatr_, gcop, --, 
   {{0x2d8d7978,0x387c0170,0x9c7c01a6,0xb63800b5}},	//   urge_, katr_, _vočn, _ｇｈ_, 
   {{0x2d8c0332,0x2fc4007c,0x00000000,0x00000000}},	//   rrge_, ångs_, --, --, 
   {{0x9c7d20ca,0x09d005ba,0xb69800e4,0xa3cc3f7e}},	//   _točn, तम्य, châg, लिय_, 
   {{0x7e617979,0x69d8009d,0xf2dc015d,0x0ae9797a}},	//   ccop, txue, _giât_, рдий_, 
   {{0xc8b5797b,0xfd5401f2,0x6e39797c,0x387c03d1}},	//   осны, _mgbị, _uzub, fatr_, 
   {{0xa3cc2d8f,0x5ce425ec,0x6d5816b8,0x69c8ad46}},	//   लिम_, _нюха, _iuua, _vrge, 
   {{0x6d58009f,0x61304ab3,0x7aec0022,0xfd240345}},	//   _huua, mält, äité, _بولێ, 
   {{0x6d59797d,0x9c7c09a8,0xe9800131,0xd04c00ac}},	//   _kuua, _ločl, _еқин, ükəl, 
   {{0x387c05da,0x6d5826bb,0x8cdc07f7,0x69cc9907}},	//   batr_, _juua, पापो, æced, 
   {{0x2a7c0730,0x6d59797e,0x31dc02f5,0x613000fd}},	//   laub_, _muua, ণনাশ, nält, 
   {{0x6b8006a3,0x6d580037,0x46a42179,0x98c4004b}},	//   nsng, _luua, _дайв, _رغون, 
   {{0x61302155,0xa3cc06ab,0x9f4c0fac,0x7e61797f}},	//   hält, लिब_, _ådø_, xcop, 
   {{0xb5f97980,0x6d597981,0x6b800649,0xc058152a}},	// [27540] lcán, _nuua, hsng, арец_, 
   {{0x2a7c0211,0x61300520,0xb5f800e4,0xdc3c00d7}},	//   haub_, jält, mbáp, váľm, 
   {{0xf1bc00d7,0x613001f4,0x9c7c0171,0x00000000}},	//   _esá_, dält, _sočo, --, 
   {{0x6d5801af,0xb698013c,0xbd6957bd,0x613001f4}},	//   _buua, liâr, арке_, välu, 
   {{0x7e617982,0x61317983,0x2a7c0076,0x387c0205}},	//   rcop, fält, daub_, yatr_, 
   {{0x7e617984,0xe6f40327,0xd5b80327,0x68e401e3}},	//   scop, _བཞྀན_, _བརྣག, öjdl, 
   {{0x46c8012c,0x387c05da,0x00000000,0x00000000}},	//   ियाह, vatr_, --, --, 
   {{0x387c003e,0xb2f400df,0x00000000,0x00000000}},	//   watr_, ַציס_, --, --, 
   {{0xdc541547,0x387c0109,0xf1bc01ed,0x6d580166}},	//   _فراک, tatr_, _száz_, _guua, 
   {{0x998002d5,0xd8f800d6,0xec74030d,0x00000000}},	//   _šių_, сної_, _мпу_, --, 
   {{0xfaa57985,0x387c03d1,0x00000000,0x00000000}},	//   _мажо, ratr_, --, --, 
   {{0x387c0109,0xec101075,0x9c7c0427,0x00000000}},	//   satr_, _تومد, _močm, --, 
   {{0xe3b97986,0xb5f80332,0x9c7c0171,0x00000000}},	//   çın_, acán, _ločm, --, 
   {{0xa3c001ef,0x764800e5,0x00000000,0x00000000}},	//   _hýří_, _úgym, --, --, 
   {{0x61305df4,0xe4541e76,0xf1bc01ed,0xe4e4109a}},	//   häls, дкры, _nyár_, фіян, 
   {{0x9c7c0219,0xd7f8054e,0xd0540213,0x925931b9}},	//   _sočl, ncăm_, əbəl, саат_, 
   {{0x67fc00dd,0x9c7c0010,0x61300267,0x59bc00cd}},	// [27550] _tájé, _počl, jäls, ्टिर, 
   {{0xd13013d7,0x4ad0069f,0x6d5802f6,0x8e7c00df}},	//   رما_, _दोनव, _ruua, _poŝo, 
   {{0x5334871a,0x613002f6,0x6d589c81,0xb6980194}},	//   _неот, vält, _suua, liâq, 
   {{0x6d589c81,0x61313515,0x59bc012a,0x92a800fe}},	//   _puua, wält, ्टार, _গোৰ_, 
   {{0xf1bc0120,0x613004ab,0x00000000,0x00000000}},	//   _usá_, tält, --, --, 
   {{0x9c7c1505,0x6b800109,0x00000000,0x00000000}},	//   _uočl, tsng, --, --, 
   {{0x2a7d7987,0x6d4c011c,0x61300108,0xdb0802d2}},	//   taub_, _ècam, rält, _nsdó, 
   {{0xa3cc2d8f,0x61300664,0x6d58096b,0xca8405f5}},	//   लित_, sält, _tuua, чгий, 
   {{0xfc44008c,0xb69800d2,0x9c7c0219,0xe7b00139}},	//   _þínu_, khâb, _močj, _küçе, 
   {{0x480400d6,0x2a7c0218,0xc9080154,0xb90000d4}},	//   зпов, saub_, রক্ত_, езьк, 
   {{0xb698013c,0x7e680c6a,0x00000000,0x00000000}},	//   viâr, _émpé, --, --, 
   {{0x635c04fe,0xd5b0004d,0x9c7c0010,0x7c38011a}},	//   _hōng, ắn_, _nočj, _התעס, 
   {{0x635c0374,0x03257988,0xb5f97989,0x7bdc0108}},	//   _kōng, җдан, scán, äpuv, 
   {{0x26c4022a,0x158802dd,0xd1ec0092,0x00000000}},	//   žmo_, _ﺑﻪﺗﯩ, ሀኒት_, --, 
   {{0x635c00b0,0xd05c013f,0x8e7c0115,0x00000000}},	//   _mōng, _ɑyɔn, _poŝl, --, 
   {{0xf2dc0042,0x443c01e4,0x0324003b,0x00000000}},	//   _siâr_, ĥt_, їдан, --, 
   {{0x58940220,0x27240205,0x00000000,0x00000000}},	// [27560] _ءجۇز, gıne_, --, --, 
   {{0x81ac2158,0x9c7c107d,0x27240205,0xa3cc0210}},	//   কিল_, _počm, sınd_, लिद_, 
   {{0x4abc92c2,0x00000000,0x00000000,0x00000000}},	//   ्याव, --, --, --, 
   {{0x6131492d,0x00000000,0x00000000,0x00000000}},	//   täls, --, --, --, 
   {{0xb324031c,0x00000000,0x00000000,0x00000000}},	//   _རྩིང_, --, --, --, 
   {{0x613001e6,0x10e8004b,0xcd2401b9,0xe7d8041c}},	//   räls, _وژلی_, وژلی, यमाप, 
   {{0x9c7c00f3,0x613033b4,0x00000000,0x00000000}},	//   _hočk, säls, --, --, 
   {{0xdb0802e2,0x9c7c012c,0x3f980618,0x6130007c}},	//   _asdò, _kočk, mupu_, päls, 
   {{0x3f99798a,0xd7f80311,0x00000000,0x00000000}},	//   lupu_, rcăm_, --, --, 
   {{0xfca9798b,0x9c7c00d7,0x00000000,0x00000000}},	//   _دارو_, _močk, --, --, 
   {{0x3f9802b9,0x59bc00bc,0xd6d00127,0x418802dd}},	//   nupu_, ्टहर, نقد_, _ﺗﻪﮔﯩ, 
   {{0x3f9804c9,0xfaa455b6,0x7bdc01f4,0x00000000}},	//   iupu_, _хадо, äpuu, --, 
   {{0x3f99798c,0xd580010b,0x9c7c01ef,0x00000000}},	//   hupu_, _гeнк, _nočk, --, 
   {{0x33700107,0xf36468eb,0xe4e400d4,0x00000000}},	//   нҳор, зтан, нісн, --, 
   {{0xf3f0007b,0x53342ded,0xa878010f,0x00000000}},	//   رأس_, девт, _פאהר, --, 
   {{0x78b8066d,0xb40005f5,0x8e7c01e4,0x96f80798}},	//   letv, дүүд, _poŝm, _феит_, 
   {{0xd25000e5,0x00000000,0x00000000,0x00000000}},	// [27570] کچھ_, --, --, --, 
   {{0x81ac11ba,0x9c7c0122,0x78b8147b,0x3f9800b5}},	//   কিং_, _dočk, netv, fupu_, 
   {{0x09a8ad78,0x8fb800c6,0x272403e0,0x13a402f2}},	//   _कह्य, تهاء_, sıne_, _تۆزی_, 
   {{0x8db40006,0x00000000,0x00000000,0x00000000}},	//   дскі, --, --, --, 
   {{0x635c02b1,0x78b80112,0x5dd40108,0x272403e3}},	//   _pōng, ketv, еющу, lınc_, 
   {{0x65600413,0x00000000,0x00000000,0x00000000}},	//   ímhi, --, --, --, 
   {{0x3f98090c,0x00000000,0x00000000,0x00000000}},	//   cupu_, --, --, --, 
   {{0x10e401ec,0xea6000cf,0x00000000,0x00000000}},	//   _ﺍﻷﺠﻨ, رۇتپ, --, --, 
   {{0xda64004b,0x635d798d,0xdd9409a5,0x78b80158}},	//   رايي, _fčnw, _паты, fetv, 
   {{0x635c02b5,0xab605f32,0xb5f80efe,0x78b800e5}},	//   _hōne, _كۇتى, rcál, getv, 
   {{0x635c0374,0xb5f800c6,0x07081e5a,0x4e10000d}},	//   _kōne, scál, قيدي_, _देतै_, 
   {{0xa3cc5345,0x635c151c,0x28d800bc,0x00000000}},	//   लिस_, _učni, बाहि, --, 
   {{0x635c02b5,0x6ab801f7,0x20e0085c,0x3f9800b5}},	//   _mōne, meuf, नामध, zupu_, 
   {{0x6ab80421,0x61300267,0x9c7c0f03,0xf2dc03cb}},	//   leuf, jälp, _ročk, _siâp_, 
   {{0x9c7c00ef,0x00000000,0x00000000,0x00000000}},	//   _sočk, --, --, --, 
   {{0x9c7c2b57,0x6ab80072,0x670400db,0x00000000}},	//   _počk, neuf, _чүмб, --, 
   {{0xb5c028b6,0x3f980161,0x0458007b,0x00000000}},	// [27580] _айыл, wupu_, _وجدت_, --, 
   {{0x3f99798e,0x31200323,0x32400220,0x98b00cf4}},	//   tupu_, вдуг, теуг, čaću_, 
   {{0xc2c40451,0x00000000,0x00000000,0x00000000}},	//   _قيدي, --, --, --, 
   {{0x9c7c341a,0x78b801ed,0x016400f7,0x00000000}},	//   _točk, zetv, _окмо, --, 
   {{0xdd940209,0x3f9825d0,0x78b83fb2,0x00000000}},	//   халы, supu_, yetv, --, 
   {{0x3f980e8a,0x6285798f,0xac2c00b8,0x00000000}},	//   pupu_, laio, _ṣaṣt, --, 
   {{0x78b97990,0xceac0b8d,0x9c7c00f3,0x00000000}},	//   vetv, _йә_, _joči, --, 
   {{0x6285746a,0x9c7d7991,0x3ed5062e,0x6cd001b9}},	//   naio, _moči, _تقرر, _یققا, 
   {{0x6284166a,0x9c7c151c,0x78b8e009,0x00000000}},	//   iaio, _loči, tetv, --, 
   {{0x200400ac,0x764801d3,0x7bdc01f4,0x00000000}},	//   _əmin_, _úgyi, äpus, --, 
   {{0x78b97992,0x62857993,0x9c7c151c,0xb5f80077}},	//   retv, kaio, _noči, rcám, 
   {{0x0ba80046,0x6284009f,0x3cfc007b,0xd7f8054e}},	//   _ءالى_, jaio, _hltv_, ncăi_, 
   {{0x779105b4,0x62844d01,0xa964009b,0x00000000}},	//   ریکا, daio, _жича_, --, 
   {{0x9c7c04a7,0x8e7c00df,0xccf8002b,0x00000000}},	//   _boči, _poŝk, _kuśa_, --, 
   {{0xf2c57994,0x62841140,0x28980a1e,0x28d82e05}},	//   мсан, faio, _ויוא, बारि, 
   {{0x62857995,0xc0c00131,0xa84401e2,0x00000000}},	//   gaio, һәси, _غليم_, --, 
   {{0x3f8c01fa,0x30a43129,0xd0117996,0x00000000}},	// [27590] šful_, древ, گلا_, --, 
   {{0x27240ba5,0xa3cc073d,0xa19402e8,0xe7e00205}},	//   mına_, लिश_, тафч, nışç, 
   {{0x27240bfc,0x635c04fe,0x6284013f,0x6ab8009f}},	//   lına_, _pōne, baio, yeuf, 
   {{0x628406ee,0xa3b80014,0x4814008f,0x918000f7}},	//   caio, _کایر_, ײַען_, _مۇرۇ, 
   {{0x27249d58,0x8e7c0115,0xf1a81272,0xe7e00166}},	//   nına_, _joŝi, _باجه_, kışç, 
   {{0x8c457997,0xd5b80135,0x00000000,0x00000000}},	//   неле, _བརླག, --, --, 
   {{0x635c00b0,0x272493ba,0xa1580063,0x4b5400d1}},	//   _tōne, hına_, _цару_, нъит, 
   {{0x2724ae47,0x2014033f,0x34c86956,0x00000000}},	//   kına_, ócił_, ायुद, --, 
   {{0x27257998,0x28d83228,0x7bdc1057,0x00000000}},	//   jına_, बालि, äpur, --, 
   {{0x27244947,0x5c980228,0x628401c6,0xe3b80baa}},	//   dına_, _окуя_, zaio, çık_, 
   {{0xd90c1129,0x54d801ec,0x00000000,0x00000000}},	//   تیو_, _ﺀﺗﯘﺯ, --, --, 
   {{0x272445a5,0xbb740375,0xf53c93e0,0x00000000}},	//   fına_, _נענו_, stål_, --, 
   {{0x9a857999,0x9c7d799a,0x27240724,0x6284aa91}},	//   _рухл, _soči, gına_, vaio, 
   {{0x62840069,0xf1bc0327,0x00000000,0x00000000}},	//   waio, ġġlu_, --, --, 
   {{0x38c83fe8,0x2efc87c2,0x00000000,0x00000000}},	//   _راوی_, _oluf_, --, --, 
   {{0x27247230,0x00000000,0x00000000,0x00000000}},	//   bına_, --, --, --, 
   {{0x409417a2,0x67240428,0x628401c4,0x27242573}},	// [275a0] ерет, _ijij, raio, cına_, 
   {{0x6285799b,0x9c7d438e,0x83c40153,0x00000000}},	//   saio, _toči, _збож, --, 
   {{0x6285799c,0x9c7c1b24,0x2efc0549,0xa5d800f1}},	//   paio, _uoči, _bluf_, _راکړ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x443800dc,0x9c7c70b1,0x00000000,0x00000000}},	//   _hyp_, _močv, --, --, 
   {{0x44380204,0x2efc0003,0x7c65799d,0x61e4009a}},	//   _kyp_, _eluf_, راتل, mxil, 
   {{0x6725799e,0x27244952,0x4439799f,0xefb000f2}},	//   _ojij, zına_, _jyp_, _میلگ, 
   {{0x27244944,0x6bd179a0,0x443979a1,0x672579a2}},	//   yına_, اتور, _myp_, _njij, 
   {{0x61e579a3,0x44380240,0xca6c0150,0x00000000}},	//   nxil, _lyp_, _ﺴﺘﻌﺩ_, --, 
   {{0xf2dc01dc,0x672579a4,0x2724456f,0xdd0400e2}},	//   _nhân_, _ajij, vına_, ēsēj, 
   {{0x80c800bd,0xed4c034c,0x1be4121d,0xe7e01b0d}},	//   রাপ্, _اپل_, _कपिल_, rışç, 
   {{0x27250b83,0xaaa40642,0xb5f86d6c,0x00000000}},	//   tına_, _गायक, mbáz, --, 
   {{0xe9cc021a,0x45a00075,0x6724090c,0x443979a5}},	//   _هغو_, لەيك, _djij, _ayp_, 
   {{0x27244944,0xf2dc07ae,0x672401f2,0x4438000f}},	//   rına_, _chân_, _ejij, _byp_, 
   {{0x272405f3,0x443979a6,0xc5ec021a,0x61e400e4}},	//   sına_, _cyp_, مړی_, exil, 
   {{0x7c380801,0x443979a7,0x60dc0356,0x59c40b4c}},	//   _mytr, _dyp_, _anrm, _वनार, 
   {{0x80c803f4,0x61e40912,0x44380280,0xa34579a8}},	// [275b0] রান্, gxil, _eyp_, уэрл, 
   {{0x611401c0,0x93f40022,0x7c3802d0,0x0f340133}},	//   гдуу, _апоц, _oytr, چکرد, 
   {{0x0f3416e6,0x61e4022f,0x60dc02d0,0xa3cc00cd}},	//   نکرد, axil, _dnrm, लिः_, 
   {{0xc91c7ebc,0xda2012eb,0x417802dd,0x00000000}},	//   _पद्म_, मपात_, _ﺠﻨﺩﻱ_, --, 
   {{0x9f0579a9,0x7c38035a,0x9c7c0219,0x1df8005b}},	//   دونو, _aytr, _loču, нецы_, 
   {{0x7c380158,0x7c700131,0x00000000,0x00000000}},	//   _bytr, иғуч, --, --, 
   {{0x635c04fe,0x7c38033f,0x7b840131,0xf65c005c}},	//   _kōna, _cytr, نايە, gdæk_, 
   {{0xb5f801e7,0xef1c0139,0x00000000,0x00000000}},	//   acái, _ñü_, --, --, 
   {{0x7c3802d0,0xb69800d8,0x200403b9,0x00000000}},	//   _eytr, thân, _əmim_, --, 
   {{0x6e388aa7,0x50d000cd,0x00000000,0x00000000}},	//   _iyub, सयिष, --, --, 
   {{0xf8ac5c81,0x7c3979aa,0xb698002d,0x1cb81956}},	//   تکن_, _gytr, rhân, _ثاقب_, 
   {{0xe3c02158,0x6e38020b,0x1bb979ab,0x635c0374}},	//   _উপলব, _kyub, _سامع_, _nōna, 
   {{0xf2dc07ae,0xb69800d2,0x3c4402d2,0x61e579ac}},	//   _phân_, phân, _tíví_, xxil, 
   {{0x443979ad,0x6e380223,0xdb08000f,0xb698000f}},	//   _pyp_, _myub, _opdû, lhâl, 
   {{0x44385ab3,0x6e391c62,0x6724017a,0x80c80011}},	//   _qyp_, _lyub, _tjij, রাম্, 
   {{0x61e47bb3,0xb6980b21,0x672579ae,0xb2180393}},	//   txil, nhâl, _ujij, _adæq, 
   {{0xf2dc07ae,0x61e40810,0x00c801a9,0x00000000}},	// [275c0] _thân_, uxil, млак_, --, 
   {{0x443979af,0xb6980b21,0x61e579b0,0xa3cc01ad}},	//   _typ_, hhâl, rxil, लिआ_, 
   {{0x656433d4,0x6e3979b1,0xb0d40034,0xb69979b2}},	//   _huih, _ayub, ठाजग, khâl, 
   {{0x6e380796,0x656579b3,0x61e4022f,0x00000000}},	//   _byub, _kuih, pxil, --, 
   {{0x6e380796,0xfce579b4,0xb698000f,0x7c380072}},	//   _cyub, кодо, dhâl, _sytr, 
   {{0x656402f6,0xb698000f,0xb5f801ed,0x6e38002b}},	//   _muih, ehâl, tbáz, _dyub, 
   {{0x81ac04c5,0xafe179b5,0xb5f800c6,0x7b1c0421}},	//   কিও_, _корл, rcái, līui, 
   {{0xab240cfc,0xb5f80597,0x3ea179b6,0x7c380122}},	//   која_, scái, _økt_, _vytr, 
   {{0x656400b0,0x7c380034,0x8e7c01e4,0xee3579b7}},	//   _nuih, _wytr, _poŝv, _ант_, 
   {{0x9c7d79b8,0xbf1400a2,0x00000000,0x00000000}},	//   _poču, _üçbö, --, --, 
   {{0x81ac0eac,0x571802d5,0xac04005b,0x9c7c0118}},	//   কিট_, ежня_, _инфа_, _dočt, 
   {{0x973c041a,0x65640051,0xaee00055,0x195800c7}},	//   kuće, _buih, _veṇa, ьаҿы_, 
   {{0x973c0989,0x6564020c,0x19940209,0xa9a00107}},	//   juće, _cuih, _саля, _вичд, 
   {{0x973c08ad,0x656401ab,0x635c0374,0x042801e1}},	//   duće, _duih, _rōna, _ìyọk, 
   {{0xb60409f3,0x386c0077,0x929403fb,0x00000000}},	//   _bráð, _iffr_, лавц, --, 
   {{0x635c02b5,0x2bd000dc,0x66e40114,0x00000000}},	//   _pōna, थिता, _воћа, --, 
   {{0x973c071b,0x65644ba8,0x3568036b,0x8e7c010f}},	// [275d0] guće, _guih, _ўрин_, _moŝt, 
   {{0xc7ac066d,0x6e380526,0xd7f80356,0x00000000}},	//   _بڑی_, _ryub, scău_, --, 
   {{0x6e381f29,0x1e70063f,0x46a80b40,0xbb280150}},	//   _syub, _ịtọl, _कामह, _ﺤﻜﻡ_, 
   {{0x3fc40046,0x635c316f,0xf2dc004d,0xb60401a8}},	//   ыруғ, _tōna, _khâm_, _gráð, 
   {{0xa1842ecc,0xf2dc0548,0x2038001f,0xdea407d6}},	//   _высл, _inâ_, ያመለክ, شیلی, 
   {{0x6e38019f,0x00000000,0x00000000,0x00000000}},	//   _vyub, --, --, --, 
   {{0xa3cc028a,0xb6980b21,0xeea8003b,0xc0bc0240}},	//   लिए_, thâl, _отак_, ተኦም_, 
   {{0x49c8020f,0x6e38022e,0xab4c01ec,0x00000000}},	//   елин_, _tyub, _ﺟﺎﺗﯟ_, --, 
   {{0x9c7c2195,0xb6980b21,0x6e3800ca,0xfe6c01d9}},	//   _počt, rhâl, _uyub, _رگن_, 
   {{0x81ac0c58,0x656579b9,0xb6980b21,0x88c80108}},	//   কিচ_, _ruih, shâl, хлов_, 
   {{0x656432cb,0x00000000,0x00000000,0x00000000}},	//   _suih, --, --, --, 
   {{0x656579ba,0x8e7c0115,0xb8f800e1,0x00000000}},	//   _puih, _goŝt, _ढो_, --, 
   {{0xf2dc001e,0x80c8015b,0x9b4400db,0xb6040413}},	//   _châm_, রাত্, _ئننو, _rráð, 
   {{0x07a40261,0xc7a40304,0xf99000d9,0xb6042507}},	//   _бакн, _бикк, _פרו_, _sráð, 
   {{0x6564194f,0xf2dc015d,0x00000000,0x00000000}},	//   _wuih, _thâl_, --, --, 
   {{0xf2a00276,0x6564316f,0xd1f80092,0x00000000}},	//   йисп, _tuih, ወጡት_, --, 
   {{0x98ac005f,0xc2441f0f,0x00000000,0x00000000}},	// [275e0] lodā_, унак, --, --, 
   {{0x973c16a3,0x708179bb,0xf0a400d4,0xab4c0150}},	//   ruće, йгуз, лкул_, _ﺟﺎﺑﯟ_, 
   {{0x515400f7,0xb60406ea,0x3f8c02f0,0x00000000}},	//   ртту, _tráð, éfu_, --, 
   {{0x973c05a1,0x5274013e,0xf574179e,0x704414fb}},	//   puće, _вуру, _جمیع_, اركە, 
   {{0xa3cc1d8a,0x635d79bc,0xb5f800d8,0x81440fba}},	//   लिक_, _hōno, scáv, _منحن, 
   {{0x635c02b1,0xed5579bd,0x00000000,0x00000000}},	//   _kōno, гоч_, --, --, 
   {{0x8e7c00c8,0xff08010b,0x3f980175,0x6ecc0709}},	//   _poŝt, _зевк_, qrpu_, _ठोकु, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7f940131,0xbc747da6,0xb884010b,0x9c7d57b9}},	//   _шаңх, _مهذب, лунй, _anče, 
   {{0xd8f802bf,0x3ea401ed,0xbd4420d4,0x7790030f}},	//   тної_, lgot_, _صناي, میتا, 
   {{0xeb942826,0x394000da,0x635c02b5,0x31340375}},	//   _бих_, ēks_, _nōno, רנים_, 
   {{0x3ea579be,0x8b640075,0x6d4c011c,0x39440220}},	//   ngot_, _ئالم, _ècar, _өнег, 
   {{0xf2dc0016,0xdc340419,0x00000000,0x00000000}},	//   _giây_, _múčk, --, --, 
   {{0x79800bd7,0xdc340419,0xe4a4009d,0x00000000}},	//   _iwow, _lúčk, йрсо, --, 
   {{0xa3cc0034,0x7bcc0142,0x6fe00150,0x00000000}},	//   लिग_, _âbud, _ﺍﻧﺎﺷ, --, 
   {{0x798179bf,0xf2dc001e,0xf5e400d4,0x56940d1d}},	//   _kwow, _thâm_, _біом, _таит, 
   {{0x92580261,0x613001f4,0xd30401f9,0x00000000}},	// [275f0] таат_, läly, _रतीब_, --, 
   {{0xa3cc00e1,0xc2440408,0x00000000,0x00000000}},	//   लिख_, ăнак, --, --, 
   {{0x7980012d,0x00000000,0x00000000,0x00000000}},	//   _lwow, --, --, --, 
   {{0x3ea579c0,0x79800083,0x3f8c0421,0xf2dc0393}},	//   ggot_, _owow, âfua_, _unâ_, 
   {{0x7980013f,0x9ad401f2,0xb5f80393,0x6130005b}},	//   _nwow, _pịny, ccát, häly, 
   {{0x8b9579c1,0x31ac4a98,0x8fc40014,0x00000000}},	//   арич, müz_, _پٲرن, --, 
   {{0x798179c2,0x9c7c0010,0x02b802d2,0x31ac06be}},	//   _awow, _počr, _þíða_, lüz_, 
   {{0x798004ba,0x24180375,0x1a6861be,0xb0cc01c6}},	//   _bwow, טחון_, هیمی_, сгvй, 
   {{0x090579c3,0x31acb580,0x6ca475b0,0x00000000}},	//   ипин, nüz_, _مصال, --, 
   {{0xd5b80003,0x290000dd,0x61300112,0xaaa40073}},	//   _བརྟག, ója_, wälz, _गावक, 
   {{0xc84400ee,0xac2400d8,0x00000000,0x00000000}},	//   ренй, _сфак, --, --, 
   {{0xd1f801f3,0xe3b80150,0x00000000,0x00000000}},	//   _ወርቁ_, құм_, --, --, 
   {{0x38c89163,0x798004ba,0x199400ee,0x48e40902}},	//   رایی_, _gwow, _гачя, _волв, 
   {{0x69c979c4,0x635c00b0,0x430805d9,0x2d8c08c2}},	//   _isge, _pōno, ھيءَ_, isge_, 
   {{0x07a579c5,0x833802bf,0xd7f80356,0x443c01bf}},	//   _тайн, вчат_, scăr_, æt_, 
   {{0x05648416,0x03a40818,0x973c0210,0x00000000}},	//   _квин, лиҳо, erćf, --, 
   {{0x73300372,0xf26400a8,0xd1f802d3,0xdc3400d0}},	// [27600] زىكا, риул_, _ወርቂ_, _rúčk, 
   {{0x635c150c,0xa4940344,0x98ac0356,0xd5b00051}},	//   _tōno, _دیست, modă_, ắt_, 
   {{0xbfc579c6,0x0fd82b41,0x34b423e4,0xc058117e}},	//   рбек, льцы_, _דפים_, трац_, 
   {{0x69c80142,0xbda450a2,0x00000000,0x00000000}},	//   _osge, لحتو, --, --, 
   {{0xee346c33,0x3ea554be,0x69c8002f,0xddb800d4}},	//   анц_, rgot_, _nsge, углі_, 
   {{0x80c803f4,0xb698025a,0x3ea42819,0x79800099}},	//   রাহ্, thâk, sgot_, _rwow, 
   {{0xb5f803b7,0x7ac402dc,0xb86579c7,0xbb280276}},	//   ncár, аспе, یادو, кцие_, 
   {{0xd1f80020,0x613001f4,0xabd000d1,0x00000000}},	//   _ወርቅ_, väly, ززىت, --, 
   {{0x798000b5,0x6b4800a2,0x7f4179c8,0x00000000}},	//   _qwow, _sögý, mloq, --, 
   {{0x7f4179c9,0x6d4c3fa8,0xb69800d2,0xa3c828f5}},	//   lloq, _ècap, phâk, ोटा_, 
   {{0x69c979ca,0x78a80076,0xf090011a,0x7f4003b9}},	//   _esge, _vcfv, חנת_, oloq, 
   {{0xd838009b,0x888001e0,0x7bd80857,0x7f4016b8}},	//   ngči_, оғәл, _irtu, nloq, 
   {{0x7ae179cb,0x973c0bb8,0x58d579cc,0xd3940032}},	//   _inot, guća, _голт, әҙмә_, 
   {{0x31ac06b9,0x7ae008a5,0xe81402f2,0xb8640133}},	//   vüz_, _hnot, ازیت_, _ئاشو, 
   {{0xb2a800f7,0xd79414ef,0x00000000,0x00000000}},	//   ктаж_, _البخ, --, --, 
   {{0xa3cc146c,0x3568013e,0xc90803d4,0x69c80042}},	//   लिज_, _ирон_, ৰকৃত_, _ysge, 
   {{0xc0d0069c,0xb5f80005,0xc7e80014,0x7f400327}},	// [27610] _ኩሎም_, acár, _لى۪ن_, dloq, 
   {{0x7bd9325c,0x3b040784,0x7f40003a,0x31ac1432}},	//   _ortu, _lloq_, eloq, rüz_, 
   {{0x7ae179cd,0x31ad2828,0x00000000,0x00000000}},	//   _onot, süz_, --, --, 
   {{0xaea00efb,0xa8540302,0x80c8015b,0x0ee01fca}},	//   تەري, ביבה_, রাষ্, फाइड, 
   {{0x601c01bf,0xfe7401f0,0xe2c802f2,0x00000000}},	//   _påmø, сӯс_, _ئاپۆ_, --, 
   {{0x7ae179ce,0x2bd06bf6,0x3b04022e,0x7bd800d8}},	//   _anot, थिला, _aloq_, _brtu, 
   {{0x7f4007ea,0x3b040213,0x5f9401a9,0x00000000}},	//   bloq, _bloq_, _мирт, --, 
   {{0x7bd979cf,0xcac81c22,0xd5b803ce,0x3f5c010e}},	//   _drtu, угие_, ेबाज, _uįup_, 
   {{0x80c800bd,0x7bd979d0,0xf2dc0142,0xfd4c0241}},	//   রার্, _ertu, _châi_, _laiṣ, 
   {{0x7ae179d1,0x98ac054e,0xe860009d,0x9b680124}},	//   _enot, vodă_, өхүү, ышәа_, 
   {{0x7ae00175,0xfd4c00dc,0x00000000,0x00000000}},	//   _fnot, _naiṣ, --, --, 
   {{0x6d4004f3,0x7ae00192,0x98ac0311,0xcb540640}},	//   llna, _gnot, todă_, _увећ, 
   {{0x2a7c6539,0xdce179d2,0x00000000,0x00000000}},	//   mbub_, _humā, --, --, 
   {{0xdce00882,0x7ae12777,0x973c0cf4,0xb978008f}},	//   _kumā, _znot, ruća, _ענצי, 
   {{0xf1bc110e,0x68e031a2,0x2904025c,0x6d4179d3}},	//   _apá_, _innd, _ilna_, ilna, 
   {{0x290402c4,0xb5f80599,0xf1bc0332,0x7f40022e}},	//   _hlna_, rcár, _bpá_, xloq, 
   {{0xb5f82760,0x41040fc0,0xa3cc37c8,0x00000000}},	// [27620] scár, бзав, लिङ_, --, 
   {{0xf6140375,0x2a7c10f2,0x00000000,0x00000000}},	//   _לחפש_, hbub_, --, --, 
   {{0x7f408726,0xdce000cd,0x9f640432,0xf53c007c}},	//   tloq, _numā, _öwüp_, rtåt_, 
   {{0xbea4c3bc,0x6d4000ad,0x7e28109a,0xf770011a}},	//   садк, elna, ліла_, פקד_, 
   {{0xdce000b0,0x7f4179d4,0x29040109,0x6da0262e}},	//   _aumā, rloq, _olna_, зича, 
   {{0x7ae089bc,0x973c0e3c,0xf8a407f7,0x28d4302b}},	//   _snot, mrće, _खाइय, _भोलि, 
   {{0x973c1326,0xf65c12ed,0x7ae00055,0xed540114}},	//   dućn, ndær_, _pnot, љој_, 
   {{0x68e179d5,0x79a46345,0x7bd80122,0x290579d6}},	//   _annd, брое, _vrtu, _alna_, 
   {{0xa9640261,0xd91001d9,0xb8640345,0x6e740354}},	//   биња_, ٘یش_, یاگو, _ыйтă, 
   {{0x973c04b9,0x68e007a8,0xb17800fe,0x98ac0210}},	//   gućn, _cnnd, _fråf, kodą_, 
   {{0x290579d7,0x7d180b6f,0x7bd979d8,0x2a7c0204}},	//   _dlna_, _imts, _urtu, bbub_, 
   {{0x7ae005b8,0x68e179d9,0x290579da,0x3b0401d5}},	//   _unot, _ennd, _elna_, _uloq_, 
   {{0xfd4c00cd,0xe66400a2,0xba540271,0x00000000}},	//   _saiṣ, _çoýý, _انشع, --, 
   {{0x64742f6a,0xfd4c00b8,0x00000000,0x00000000}},	//   згру, _paiṣ, --, --, 
   {{0xf1bd525e,0x98ac0210,0xae1c0412,0x17c8010a}},	//   _spá_, godą_, _मेनन_, _тӳпи_, 
   {{0x637811b6,0xfd4c00dc,0x00000000,0x00000000}},	//   ссёр_, _vaiṣ, --, --, 
   {{0x50f579db,0x7d18004b,0x7bc8009a,0x00000000}},	// [27630] озат, _omts, hwfu, --, 
   {{0x270800e5,0x9990002b,0x87380092,0x00000000}},	//   dőny_, _śaśi_, ደገለፀ, --, 
   {{0xf53c17aa,0x00000000,0x00000000,0x00000000}},	//   stås_, --, --, --, 
   {{0x7d1979dc,0xdce000de,0x00000000,0x00000000}},	//   _amts, _rumā, --, --, 
   {{0x6d4004ba,0xf1bc03b2,0x2b4c0142,0xdce000cd}},	//   tlna, _upá_, _rhgc_, _sumā, 
   {{0x973c04a7,0xf4240327,0x068c00d1,0x6d4001ab}},	//   kućo, _རྨོད_, _ﻛﯩﻠﯩ, ulna, 
   {{0x973c1591,0x81c004c5,0x8e7c0115,0x46a85096}},	//   jućo, ্মণ_, _enŝa, _कालह, 
   {{0x7d185107,0x973c05a1,0xf53c1654,0x2904004d}},	//   _emts, dućo, lråd_, _slna_, 
   {{0x6f1979dd,0x9c7c0e04,0x29040306,0x2a7c0327}},	//   _imuc, _inčn, _plna_, rbub_, 
   {{0xf53c05ac,0x00000000,0x00000000,0x00000000}},	//   nråd_, --, --, --, 
   {{0xb1780628,0xdd90021a,0x973c08a4,0x290402fb}},	//   _fråg, _يوې_, gućo, _vlna_, 
   {{0x050400bd,0xb17805ac,0xf2dc01fb,0xf4240327}},	//   _ঈদের_, _gråg, _khâu_, _རྨེད_, 
   {{0xf53c05ac,0x00000000,0x00000000,0x00000000}},	//   kråd_, --, --, --, 
   {{0x29041fc0,0x973c05ce,0x6b5402e3,0x68e02110}},	//   _ulna_, vrće, _ụgha, _unnd, 
   {{0x635c02b5,0xc7448a4b,0xf53c08fb,0x6f1872f5}},	//   _hōni, _وضعي, ttår_, _omuc, 
   {{0x635c02b5,0x98ac0006,0xfbd005d0,0xd77801f7}},	//   _kōni, rodą_, ותל_, _اليڪ_, 
   {{0xdce0084c,0xf53c0158,0x9f5c00bc,0xaaa40118}},	// [27640] _jumă, rtår_, áví_, _गाईक, 
   {{0x6f1979de,0x635c02b5,0xb698002d,0xf53c01bf}},	//   _amuc, _mōni, nkân, gråd_, 
   {{0x398c02d3,0x00000000,0x00000000,0x00000000}},	//   _ሓደስቲ_, --, --, --, 
   {{0xb1780267,0xc2c401f7,0x10e40150,0x4f9401c4}},	//   _bråd, _بيحي, _ﺍﻷﺜﻨ, яруу, 
   {{0xdce000a8,0xf2dc07ae,0xb698000f,0x6f18033f}},	//   _numă, _châu_, kkân, _dmuc, 
   {{0x6f1979df,0xf36401d5,0x81c0015b,0x64400213}},	//   _emuc, _دئیی, ্মদ_, əmir, 
   {{0x46a86ea7,0xcae40412,0x00000000,0x00000000}},	//   _कांह, कांड_, --, --, 
   {{0xb17979e0,0x8d9c0092,0xeb940114,0x05c80709}},	//   _fråd, ለባቸው_, цић_, िबाब, 
   {{0xb17828b3,0xf9c400d4,0x00000000,0x00000000}},	//   _gråd, іщин, --, --, 
   {{0x7d1979e1,0x48dc1b97,0x00000000,0x00000000}},	//   _umts, _कोदो_, --, --, 
   {{0xb69800d2,0xb178007c,0x00000000,0x00000000}},	//   khât, _tråg, --, --, 
   {{0x635c0270,0xec1000aa,0x8c24031c,0xdce0054e}},	//   _fōni, _غوند, _སྨྲྀ_, _fumă, 
   {{0x9cc979e2,0x00000000,0x00000000,0x00000000}},	//   _གྲོས, --, --, --, 
   {{0xe9340a2c,0xe4e402bf,0x973c01a6,0x200403e3}},	//   _وسوت_, місн, pućo, _əmir_, 
   {{0xf53c05ac,0xa87808a8,0x77900345,0x00000000}},	//   vråd_, _דאור, _تیجا, --, 
   {{0xf2dc004d,0xd468010b,0x64480254,0x00000000}},	//   _nhât_, риңе_, üdia, --, 
   {{0xf53c3be7,0xddd00432,0x940806be,0x30680a5b}},	// [27650] tråd_, _ýeňs, _əkən_, ајен_, 
   {{0x2724000f,0x297800df,0x00000000,0x00000000}},	//   rűne_, יטמא, --, --, 
   {{0x9c7c02f0,0x20ac06b1,0xffc000db,0x00000000}},	//   _ančo, _चारध, нөтп, --, 
   {{0xb698d0d1,0xf53c0ac8,0xf2dc0051,0x67b8010f}},	//   chât, sråd_, _chât_, שמאק, 
   {{0xf53c0267,0x00000000,0x00000000,0x00000000}},	//   pråd_, --, --, --, 
   {{0x635c02b5,0xb1780158,0xf53c01bf,0xcb680108}},	//   _rōni, _vråd, lråb_, баке_, 
   {{0x4bd802d5,0x00000000,0x00000000,0x00000000}},	//   сьля_, --, --, --, 
   {{0x6f18a183,0xb1784491,0x635c02b5,0xf2dc004d}},	//   _umuc, _tråd, _pōni, _thâu_, 
   {{0x98ac00c0,0x00000000,0x00000000,0x00000000}},	//   lodę_, --, --, --, 
   {{0x2fc0030d,0x635c033b,0x973c0301,0x07a400ea}},	//   _kpjg_, _dčny, sućl, паон, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb698002d,0xe5780107,0x00000000,0x00000000}},	//   skân, оҷи_, --, --, 
   {{0x6ab979e3,0x7b0c01e1,0x09e55870,0xf53c01bf}},	//   mfuf, _dùud, _холн, dråb_, 
   {{0xb97802e4,0x194000c7,0x98ac012d,0x068000d1}},	//   _הנסי, _иҭын, kodę_, ﯩﻨﻠﯩ, 
   {{0x8a6004d3,0xf8b4007b,0x00000000,0x00000000}},	//   _تێکۆ, _رهيب_, --, --, 
   {{0x0684e91b,0xfbd00a1e,0x6ab80083,0xd5ac01ed}},	//   _эгин, עתן_, nfuf, دہی_, 
   {{0x5bb81524,0x69d804d4,0xc7480014,0x26c000ef}},	// [27660] _आह्व, nvue, _پٔکو_, _ibio_, 
   {{0x69d80a73,0xb14179e4,0xd4900208,0xa494072d}},	//   ivue, енул, ừa_, _زیرت, 
   {{0x69d80097,0xb4f80375,0x98ac033f,0x434410fc}},	//   hvue, _הפיי, godę_, _неов, 
   {{0xb17800b5,0xf424031c,0x48dc2ba2,0xfde839b8}},	//   _dråb, _རྨིད_, _कोसो_, йдек_, 
   {{0x62842d7b,0x26c00451,0x8e7c0115,0xfe14000d}},	//   mbio, _mbio_, _enŝo, _देखस_, 
   {{0x62840115,0xbf1480c2,0x98ac0210,0xe2c801f7}},	//   lbio, _کورب, bodę_, _اوڏو_, 
   {{0xb17826cc,0xceac0220,0x62840113,0xf2dc0208}},	//   _gråb, _иә_, obio, _thât_, 
   {{0x79a579e5,0x628401c4,0xbe0401ed,0xa9c000d1}},	//   прое, nbio, _ٹوئٹ, ﯩﻤﯩﺴ, 
   {{0x6da179e6,0xada179e7,0x5a340212,0xa9640063}},	//   _пита, _патл, ьнит, пиња_, 
   {{0x26c179e8,0x80c8015b,0x00000000,0x00000000}},	//   _abio_, রাক্, --, --, 
   {{0x635c06c8,0x787401d9,0xfa351e01,0x4d4c01e1}},	//   _hōnu, _ہُشا, _کراد, _ẹ̀ṣo, 
   {{0x635c02b1,0xb3440798,0x973c01a6,0xadf0000d}},	//   _kōnu, _maçô, mućk, _आपमन_, 
   {{0xc548063f,0x62840254,0xceb801ef,0x00000000}},	//   _áhị̄, dbio, _umře_, --, 
   {{0x26c0013f,0xb87c01e4,0xb6a40166,0x62840210}},	//   _ebio_, _inƭo, _şäğb, ebio, 
   {{0x635c0270,0x26c00175,0xe45400c0,0x00000000}},	//   _lōnu, _fbio_, екры, --, 
   {{0xa84486bf,0x00000000,0x00000000,0x00000000}},	//   _عليم_, --, --, --, 
   {{0x225945f9,0xe2f800d4,0x030c0037,0x00000000}},	// [27670] зиты_, четі_, _सतरह_, --, 
   {{0x8e7c00df,0x26c016a3,0xb69800e4,0x98ac012d}},	//   _enŝl, _zbio_, châr, todę_, 
   {{0x6284f5e9,0xd01179e9,0x69d80007,0xb178007c}},	//   bbio, خلا_, zvue, _bråc, 
   {{0x628401e4,0x98ac38a5,0x290800de,0x00000000}},	//   cbio, rodę_, īcai_, --, 
   {{0x9f5c0316,0x69d80369,0x313000c7,0x712000db}},	//   ává_, xvue, _зҵар, _كۉرم, 
   {{0x8c4579ea,0x69d80158,0x00000000,0x00000000}},	//   меле, vvue, --, --, 
   {{0x98c400bc,0xfe6c01d3,0x28d41bd6,0x00000000}},	//   štěm_, اگہ_, _भोगि, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x0d74036b,0xb698002d,0xdce000c0,0x00000000}},	//   _آخرگ, rkâl, _sumą, --, 
   {{0x4804090b,0x068c0131,0x69d8fb40,0xb698002d}},	//   дпов, _ﻛﯩﻴﯩ, rvue, skâl, 
   {{0x6ab81682,0xb87c0115,0x6b840220,0xd87400db}},	//   pfuf, _inƭl, _رشال, رۅيت_, 
   {{0x8d9008b0,0x00000000,0x00000000,0x00000000}},	//   ﻟﺴﺎﻕ_, --, --, --, 
   {{0x628545fb,0x00000000,0x00000000,0x00000000}},	//   vbio, --, --, --, 
   {{0xc4bc02f5,0xc7a4004e,0xf990011a,0x2900ff6c}},	//   েঞ্জ, _жикк, _ירד_, öjad_, 
   {{0x98ac012c,0x588400cf,0x00000000,0x00000000}},	//   hodě_, _чыча, --, --, 
   {{0x26c01326,0xd9940133,0x4208004e,0x00000000}},	//   _ubio_, _تۆیت_, онбо_, --, 
   {{0x9c14063f,0xf2dc0142,0x704400d1,0xdbd000a2}},	// [27680] _tọgz, _phâr_, ۈرمە, dýýe, 
   {{0x9c7c0100,0xe7cc00fe,0x00000000,0x00000000}},	//   _enčj, িমীয, --, --, 
   {{0x25741f65,0x00000000,0x00000000,0x00000000}},	//   _häl_, --, --, --, 
   {{0x25740221,0xb80c0456,0x00000000,0x00000000}},	//   _käl_, ानतम_, --, --, 
   {{0x25740166,0x00000000,0x00000000,0x00000000}},	//   _jäl_, --, --, --, 
   {{0x25740793,0xfca800f1,0x3eb00210,0x00000000}},	//   _mäl_, زاتو_, żyt_, --, 
   {{0x932403e6,0x0c940133,0x00000000,0x00000000}},	//   _زرێن, ردوگ, --, --, 
   {{0x635c02b1,0x998401e0,0x8c84035b,0x98ac013a}},	//   _tōnu, нтоһ, _ҟәша_, bodě_, 
   {{0xbd34d81f,0x69cc0381,0x2574007c,0x7c9403c5}},	//   _قىرع, æcep, _näl_, _жрец, 
   {{0x57f4bd06,0x2ca40228,0xada00daf,0x77900345}},	//   епот, _окуп_, _шаул, نیتا, 
   {{0x69d000c5,0x973c0841,0x80c80183,0x64480254}},	//   _बैठी, lući, ৰাপ্, üdil, 
   {{0x9f580724,0xf2dc0208,0xdb2401f4,0x00000000}},	//   _üzäk_, _nhâp_, äsäi, --, 
   {{0x25740793,0x9c7c0064,0x00000000,0x00000000}},	//   _cäl_, _sočy, --, --, 
   {{0x257409a5,0x00000000,0x00000000,0x00000000}},	//   _däl_, --, --, --, 
   {{0x9c7d0454,0x80c80154,0xf3640117,0x53341219}},	//   _ančk, রাঞ্, дтан, еевт, 
   {{0x973cc75b,0x00000000,0x00000000,0x00000000}},	//   kući, --, --, --, 
   {{0x973c2d2b,0xa1940228,0x80c80183,0x1154005b}},	// [27690] jući, катч, ৰান্, екаю, 
   {{0x973c0552,0xc5f002e4,0x461579eb,0x316405d5}},	//   dući, _עדי_, _سوپر, önz_, 
   {{0xb4c80574,0x257401b8,0x635c003a,0x9294390e}},	//   ळजी_, _zäl_, _cōns, _панц, 
   {{0x72e401d9,0x7984063f,0x8db4331d,0x74b82894}},	//   _تہرِ_, ̣kwa, ескі, श्रृ, 
   {{0x973c04b9,0x42780bd9,0x25740724,0x9f040f1c}},	//   gući, _מארג, _xäl_, خونو, 
   {{0xb17812e8,0xb80c00cd,0x00000000,0x00000000}},	//   _gråa, ानाम_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3ab001e0,0x18800092,0x00000000,0x00000000}},	//   гәшт, _የሠፈረ_, --, --, 
   {{0xc8b41e76,0x09e56442,0x28c40150,0x00000000}},	//   нсны, хопн, _ﺒﻤﺭﺠ, --, 
   {{0x5d549094,0x8ca80210,0x00000000,0x00000000}},	//   _акут, _घाटो, --, --, 
   {{0x80c8015b,0x7bdc713c,0x2574007c,0x9ad400e5}},	//   রাচ্, åput, _säl_, رمیڈ, 
   {{0xb3c00327,0x257400a2,0x64480037,0x00000000}},	//   _ཝརྟུ, _päl_, üdim, --, 
   {{0xaa040199,0x15b00131,0x598400c0,0xca48009a}},	//   _تظاه, لەيس, _аліб, _علته_, 
   {{0x25740628,0xa000015b,0x00000000,0x00000000}},	//   _väl_, _এইসব_, --, --, 
   {{0x257579ec,0x80c803d4,0x00000000,0x00000000}},	//   _wäl_, ৰাম্, --, --, 
   {{0x935801c6,0x25740958,0x46a8000d,0x00000000}},	//   друу_, _täl_, _काटह, --, 
   {{0xae1c0764,0x00e4004e,0x41a802e8,0x00000000}},	// [276a0] _मेलन_, нжан, яван_, --, 
   {{0x973c0e04,0x00000000,0x00000000,0x00000000}},	//   vući, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3f840030,0xf53c007c,0x00000000,0x00000000}},	//   ďou_, nrån_, --, --, 
   {{0x6e900a0a,0x81a800cc,0x00000000,0x00000000}},	//   الها, _খনক_, --, --, 
   {{0xb17801e6,0x973c05a1,0x80c80154,0xace40114}},	//   _krån, rući, রাঙ্, емља_, 
   {{0x63bc01e0,0x973c01a6,0x7b64b149,0xbea403fb}},	//   ntrn, sući, нтие, _павк, 
   {{0x6e900491,0x973c00f3,0xf454011a,0xe7e007b7}},	//   _ملفا, pući, עיקר_, गिना_, 
   {{0x7f400140,0xbd880244,0x31c000ef,0x00000000}},	//   mooq, _رنان_, cīzā_, --, 
   {{0x7f40013c,0x63bc0946,0x00000000,0x00000000}},	//   looq, ktrn, --, --, 
   {{0xf53c04f3,0xec6c05d9,0x2ba4000d,0xac9400e5}},	//   från_, _اٿم_, _गिया, _سننا_, 
   {{0xa9c00150,0x7790179e,0x00000000,0x00000000}},	//   _ﯩﻠﯩﺴ, پیکا, --, --, 
   {{0x9c7d79ed,0x00000000,0x00000000,0x00000000}},	//   _anči, --, --, --, 
   {{0x25a401d3,0xb178007c,0x00000000,0x00000000}},	//   ámla_, _brån, --, --, 
   {{0x7f400140,0xf7280276,0x395c0112,0x77900133}},	//   kooq, _нций_, mmts_, _حیجا, 
   {{0xdb1801f1,0x7f400194,0xe2f80220,0x635c00a3}},	//   ftvé, jooq, несі_, _sōnr, 
   {{0x30a41734,0x96340353,0x7d08037e,0x151400c0}},	// [276b0] ерев, _шниц, kkfs, _адпя, 
   {{0xb17801e6,0x00000000,0x00000000,0x00000000}},	//   _från, --, --, --, 
   {{0xe7e000af,0x2fc408c8,0xa5c400b8,0x00000000}},	//   गिया_, ïng_, _įųim, --, 
   {{0x7f400140,0x91801e4a,0x752401f5,0x63a80f91}},	//   gooq, _نۇرۇ, lijz, ádne, 
   {{0xe0b802f5,0xa69c010f,0x00000000,0x00000000}},	//   ীয়ভ, לשאפ, --, --, 
   {{0x7b0c01ab,0xe7e007f7,0x00000000,0x00000000}},	//   _rùua, गिमा_, --, --, 
   {{0xf53c10d1,0x7f400009,0x00000000,0x00000000}},	//   yrån_, booq, --, --, 
   {{0x817400aa,0xfbc0302b,0x00000000,0x00000000}},	//   _سپېڅ, _शहरम, --, --, 
   {{0x0edc068f,0x9e340166,0x3ec001d3,0xec681219}},	//   _नोएड, _бетч, értő_, _ерек_, 
   {{0x18800020,0xfb0400e8,0x48084d01,0x64480254}},	//   _የአገር_, ñëri_, деон_, üdik, 
   {{0x3cf8008f,0x6d4179ee,0x752401f5,0xf53c01e3}},	//   _קלענ, mona, dijz, trån_, 
   {{0x386c1590,0xfbd006a9,0x00000000,0x00000000}},	//   _egfr_, _כתב_, --, --, 
   {{0x2efc003a,0x752401f5,0x6d400076,0xf53c007c}},	//   _mouf_, fijz, oona, rrån_, 
   {{0x6d4179ef,0x290800da,0x2efc0036,0x752401f5}},	//   nona, īcas_, _louf_, gijz, 
   {{0x8e7c00df,0x0444119e,0xded40023,0x00000000}},	//   _enŝi, тевн, ረድኦ_, --, 
   {{0xf770011a,0xb178007c,0x0ccc00eb,0x00000000}},	//   _דקה_, _vrån, লায়ত, --, 
   {{0x6d4179f0,0x973c1b24,0x672579f1,0x63bc0166}},	// [276c0] kona, guću, _imij, strn, 
   {{0x6d4179f2,0xb17801e6,0xdbd0010e,0x798401f2}},	//   jona, _trån, _aýýa, ̣kwo, 
   {{0x2efc0221,0xdb1801ed,0xd1740032,0x7f400869}},	//   _bouf_, stvé, _ҡыры, tooq, 
   {{0x249979f3,0x44380005,0xbe6400c6,0x6d4001ab}},	//   larm_, _ixp_, نهاي, eona, 
   {{0x6d4179f4,0x42546758,0x7f4166fe,0x043800b8}},	//   fona, _штот, rooq, _īkṣi, 
   {{0x6d4179f5,0x7c640075,0xdbd00209,0x7f4179f6}},	//   gona, پاتل, _eýýa, sooq, 
   {{0x60dc1552,0xefb0be04,0x3cfc00db,0x672579f7}},	//   _iarm, _نیلگ, _votv_, _omij, 
   {{0x2efc092e,0x249800b5,0x7f40011f,0xe6dcc853}},	//   _gouf_, harm_, qooq, ययोज, 
   {{0x60dd79f8,0x24980210,0xe9b400e5,0x00000000}},	//   _karm, karm_, نچوں_, --, 
   {{0x6d4179f9,0x6724003e,0x6e900014,0x2efc007f}},	//   cona, _amij, _ملہا, _zouf_, 
   {{0x6bd40050,0x48c402dd,0x2498002f,0x00000000}},	//   _لولس_, ушығ, darm_, --, 
   {{0x60dd79fa,0x75240936,0x7c380135,0x6f004b91}},	//   _larm, wijz, _ixtr, ªnci, 
   {{0x6f000cfc,0x249979fb,0x60dc000f,0x75240d27}},	//   ênci, farm_, _oarm, tijz, 
   {{0x6724610b,0x60dd79fc,0x44380175,0x798003ac}},	//   _emij, _narm, _bxp_, _itow, 
   {{0x75240cf9,0x443979fd,0x67240240,0x00000000}},	//   rijz, _cxp_, _fmij, --, 
   {{0x60dd0c55,0x9c7cb2be,0x00000000,0x00000000}},	//   _aarm, _inču, --, --, 
   {{0x60dd79fe,0x443979ff,0x249805ac,0x46141c3b}},	// [276d0] _barm, _exp_, barm_, _موٹر, 
   {{0x67241326,0x6d40036b,0x236001d9,0x2efd4a2d}},	//   _zmij, xona, amij_, _souf_, 
   {{0x60dd7a00,0x6d417a01,0x2efd7a02,0x7c38031c}},	//   _darm, vona, _pouf_, _nxtr, 
   {{0x60dd7a03,0x6d417a04,0x79806b20,0xe7e09f23}},	//   _earm, wona, _otow, गिता_, 
   {{0x60dd7a05,0x00000000,0x00000000,0x00000000}},	//   _farm, --, --, --, 
   {{0x60dd7a06,0x00000000,0x00000000,0x00000000}},	//   _garm, --, --, --, 
   {{0x5f957a07,0x4a743b5f,0x79817a08,0x2efc02e2}},	//   _вист, лыпт, _atow, _touf_, 
   {{0x60dd7a09,0x6d417a0a,0xdbd0010b,0xb3a8000d}},	//   _zarm, sona, _uýýa, _छिनख, 
   {{0x60dd7a0b,0x68100213,0x00000000,0x00000000}},	//   _yarm, mədə, --, --, 
   {{0x67241727,0x6e380b6f,0x6d400050,0x7c38031c}},	//   _smij, _ixub, qona, _fxtr, 
   {{0x79800428,0x394001c0,0x2498005c,0xeab00736}},	//   _etow, снэг, varm_, _نعش_, 
   {{0x24997a0c,0x9c1401f2,0x68100213,0x1c1c00c5}},	//   warm_, _kọnz, nədə, _भेटल_, 
   {{0x2498031c,0x644003be,0xf2dc00e4,0x44380166}},	//   tarm_, əmiy, _akâo_, _sxp_, 
   {{0x69c800e4,0x27b0035f,0x44380175,0xb1780267}},	//   _ipge, _кәмс, _pxp_, _vrål, 
   {{0x24997a0d,0x60dd7a0e,0x4439351c,0x973c00f3}},	//   rarm_, _rarm, _qxp_, gućs, 
   {{0x67242630,0x24989b61,0x6e38014b,0xb1781f53}},	//   _umij, sarm_, _oxub, _trål, 
   {{0x2498022f,0xb17801e3,0x271000ce,0x681003e3}},	// [276e0] parm_, _urål, ासीर_, dədə, 
   {{0x60dd7a0f,0x04b42519,0x00000000,0x00000000}},	//   _qarm, _ссия, --, --, 
   {{0x6e38014b,0xbea8034c,0x681000ac,0x25a00450}},	//   _axub, فهان_, fədə, _hvil_, 
   {{0x69c97a10,0x60dd7a11,0x25a005ac,0x8c3401e1}},	//   _opge, _warm, _kvil_, _ke̟f, 
   {{0x60dd7a12,0x1c1c00af,0x00000000,0x00000000}},	//   _tarm, _भेजल_, --, --, 
   {{0xff7495ad,0x61e57a13,0x271001ad,0x60dc0036}},	//   _مُسج, mvil, ासुर_, _uarm, 
   {{0x79817a14,0xbe84454b,0x81c0009e,0x69c800ef}},	//   _stow, _مجذو, ্মও_, _apge, 
   {{0x25a00100,0x29000267,0x61e40037,0xed540032}},	//   _ovil_, öjan_, ovil, _ҡот_, 
   {{0xee340801,0xef140212,0xe7e00154,0xed4c179e}},	//   _бнт_, _смт_, মহোয, _کپل_, 
   {{0x61e4b7f7,0x973c01fa,0x7c380455,0x31b8010f}},	//   ivil, mrći, _txtr, עזינ, 
   {{0x8e7c01e4,0x61e40e03,0x25a00166,0x3b846ee4}},	//   _enŝu, hvil, _avil_, _слег, 
   {{0x61e57a15,0x00000000,0x00000000,0x00000000}},	//   kvil, --, --, --, 
   {{0x79800214,0xdce802e2,0x45700220,0x61e4dc67}},	//   _utow, _lidč, оңыр, jvil, 
   {{0x61e57a16,0x81c80154,0xe8680356,0x00000000}},	//   dvil, লটা_, ârţâ, --, 
   {{0x61e57a17,0xa8780302,0xf2c57a18,0x681000ac}},	//   evil, _ארוח, лсан, yədə, 
   {{0x9f9801ec,0x34a00014,0x61e402d2,0x00000000}},	//   _ءﺎﻤﻟ, _گۅسٲ, fvil, --, 
   {{0x61e41579,0x320c01d3,0x00000000,0x00000000}},	// [276f0] gvil, ágy_, --, --, 
   {{0x7bd8007d,0xae1c01ad,0xa0b801c6,0x22580139}},	//   _ostu, _मेगन_, лгуу_, _şekä_, 
   {{0x7bd802ea,0x61e57a19,0xb1785243,0x4fd44727}},	//   _nstu, avil, _kråk, ржет, 
   {{0xaf4853f3,0x61e4a723,0xdef89b0f,0x80c803d4}},	//   رشال_, bvil, лыч_, ৰাষ্, 
   {{0x681000ac,0xdea47611,0x00000000,0x00000000}},	//   rədə, صیلی, --, --, 
   {{0xdce8007f,0xb6980109,0xdbd000a2,0x69c800d8}},	//   _fidč, ghâz, _aýña, _rpge, 
   {{0x6114026a,0xf2dc66db,0x20c40006,0x681003b9}},	//   _удру, _kaâ_, _усяг, pədə, 
   {{0x6a680139,0x49c87b0e,0x2cb800c0,0x00000000}},	//   _nöfü, влин_, _šydą_, --, 
   {{0xdb18012c,0x6e38014b,0x9f0407d6,0x00000000}},	//   ctví, _uxub, _اوقو, --, 
   {{0xf2dc24ba,0x47c4360a,0x8e7c01e4,0x00000000}},	//   _laâ_, абов, _enŝt, --, 
   {{0x6aa400bd,0xb1786afa,0x5f1c00cd,0x5ac80150}},	//   ক্ষো, _bråk, _मतम्_, _әлім_, 
   {{0xb1797a1a,0x61e49d07,0xf53c369d,0x271000af}},	//   _isåf, yvil, bråk_, ासेर_, 
   {{0x61e40793,0x69c802c1,0x29840139,0x00000000}},	//   xvil, _upge, _сыег, --, 
   {{0x9a840220,0x61e408fb,0x7bd8015d,0x00000000}},	//   _куәл, vvil, _ystu, --, 
   {{0xf2dc208d,0x437463eb,0x836401b9,0x00000000}},	//   _baâ_, ругт, لدرل, --, 
   {{0x25a0e73f,0xb69800d2,0xd294010b,0x00000000}},	//   _tvil_, khây, йруь, --, 
   {{0x3fe0000e,0x61e57a1b,0xdce8007f,0xc0740640}},	// [27700] _যথেষ, uvil, _sidč, аћењ, 
   {{0x9c7d7a1c,0x52740fc0,0x00000000,0x00000000}},	//   _kače, _ҳуру, --, --, 
   {{0x61e4014a,0x9c7c07f5,0xf7640b82,0x442c0166}},	//   svil, _jače, ተፈጸመ_, _äf_, 
   {{0x52742f0d,0xf2dc208d,0x61e5377a,0xdb180436}},	//   _гуру, _gaâ_, pvil, ttví, 
   {{0xd8380dfe,0x245c01e1,0x9c7c0219,0x00000000}},	//   mače_, _fámí_, _lače, --, 
   {{0xd83804a7,0xdb1806ea,0x00000000,0x00000000}},	//   lače_, rtví, --, --, 
   {{0xed54026a,0xf65c0ac8,0x2bb4007b,0xdb180162}},	//   јој_, neær_, لاية_, ství, 
   {{0x2ba41533,0x3ed97a1d,0x7bd80e96,0xd8397a1e}},	//   _गिरा, _جورج_, _vstu, nače_, 
   {{0xf2dc0208,0x00000000,0x00000000,0x00000000}},	//   _chây_, --, --, --, 
   {{0x9c7c0552,0x57b51ed9,0xd83802f0,0x00000000}},	//   _bače, ббот, hače_, --, 
   {{0x7bd97a1f,0x6a68014a,0xad18011a,0x0ba814fb}},	//   _ustu, _pöfü, _שובר, _مانى_, 
   {{0xf53c2ff9,0xb17800cc,0x2b9001d3,0x93780b01}},	//   pråk_, _fråh, _بیٹس, ғбат_, 
   {{0xd8397a20,0x9c7c009b,0x9a5400db,0xf53c05ac}},	//   dače_, _tačd, _اعاچ, nsåg_, 
   {{0xf80402bf,0x00000000,0x00000000,0x00000000}},	//   _вчин, --, --, --, 
   {{0xb178d961,0x8e7c01e4,0xe4e40006,0x32f400c7}},	//   _tråk, _haŝe, ціян, аҭны_, 
   {{0xd8380fb7,0x8e7c00df,0x00000000,0x00000000}},	//   gače_, _kaŝe, --, --, 
   {{0x9c7c0f72,0x00000000,0x00000000,0x00000000}},	// [27710] _zače, --, --, --, 
   {{0x2bd4000d,0x00000000,0x00000000,0x00000000}},	//   _भईला, --, --, --, 
   {{0xf2dd7a21,0xd83817a3,0x64480037,0xf60803e6}},	//   _taâ_, bače_, üdit, _ستکه_, 
   {{0x0d9800ee,0x03d40677,0x95340092,0x00000000}},	//   гткы_, _פורם_, _ባለአደ, --, 
   {{0xe4ec4ca3,0xd8380010,0x00000000,0x00000000}},	//   _छोडि_, načb_, --, --, 
   {{0x8b957a22,0x973c01fa,0xca3800df,0x00000000}},	//   брич, mrću, naŝe_, --, 
   {{0xdfd800a7,0x00000000,0x00000000,0x00000000}},	//   _кът_, --, --, --, 
   {{0x0b5846fd,0xb7e805d7,0xf2dc0051,0xe438011a}},	//   ырлы_, टिनम_, _phây_, ירוח_, 
   {{0x3ce0069f,0x4a740184,0x9c7c597f,0xd5ec001e}},	//   _टोके_, _һылт, _sače, _ngà, 
   {{0x29002242,0xdbd0022c,0x80c8134e,0xe7e005dc}},	//   ðja_, _týða, स्पे, गिला_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf2dc004d,0x38c97a23,0xfc540a7c,0x98fc0115}},	//   _thây_, پایی_, _הבעש_, rmĉa, 
   {{0xd8380e8b,0xda780c04,0x4df800c8,0x95980276}},	//   vače_, _тях_, נפֿא, итру_, 
   {{0x19c00e2c,0x9c7c00f3,0x63a8022a,0x8c44010a}},	//   _ﻣﻪﻣﻠ, _tače, ádno, _теçе, 
   {{0xd8380232,0x80c802ab,0x07a40395,0x00000000}},	//   tače_, स्फे, _уайн, --, 
   {{0xded41540,0xf7403d6b,0x80c811bc,0x443c031c}},	//   ረትን_, _нещо, स्ने, ħt_, 
   {{0xd8385946,0x00c80ce1,0xdb1800e5,0x7330129d}},	// [27720] rače_, ллак_, ntvá, سىكا, 
   {{0x644800af,0xd8381a48,0x7bcc0139,0x00000000}},	//   üdis, sače_, _äbug, --, 
   {{0xd83863e0,0xdce800cd,0xbfc57a24,0x3898010f}},	//   pače_, _nidā, сбек, ריענ, 
   {{0xf48436bd,0xbda400c6,0x00000000,0x00000000}},	//   _پایی, محتو, --, --, 
   {{0x1df8005b,0x00000000,0x00000000,0x00000000}},	//   релы_, --, --, --, 
   {{0x6da0007b,0x4128004e,0xccf421fe,0xf53c01e3}},	//   أموم, _сого_, оқу_, rsåg_, 
   {{0xba4401c0,0xdce800cd,0xf53c007c,0xeb940a5b}},	//   өхий, _cidā, ssåg_, биј_, 
   {{0x6bd02033,0x8e7c01e4,0x0ac40022,0x6d4c002b}},	//   ستىر, _paŝe, ошьҭ, _ūcat, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x58d401c6,0xd5ec0051,0x5f0401af,0xbd4401c8}},	//   цоот, _ngá, _узға, _انئي, 
   {{0xd6d57a25,0x80c80a94,0x00000000,0x00000000}},	//   ожны, स्ये, --, --, 
   {{0x30540375,0x00000000,0x00000000,0x00000000}},	//   משיך_, --, --, --, 
   {{0xdb1800d7,0x00000000,0x00000000,0x00000000}},	//   ctvá, --, --, --, 
   {{0x7ae17a26,0x973c0e3c,0xd7940139,0x80c816ae}},	//   _haot, vrću, _дикъ, स्मे, 
   {{0x7ae17a27,0x24185a19,0xdebc0092,0xb4bc00a2}},	//   _kaot, боры_, ደሆን_, _çümş, 
   {{0x7ae000af,0x57640014,0xfdf80073,0x00000000}},	//   _jaot, _بختہ, ्हास_, --, 
   {{0x7ae17a28,0x90997a29,0xca3801e4,0x00000000}},	// [27730] _maot, иват_, paŝe_, --, 
   {{0x78b803cd,0x13d40064,0x00000000,0x00000000}},	//   ngtv, _джоў, --, --, 
   {{0xdce00270,0x7ae00165,0x648801c6,0x88bc00cc}},	//   _lumē, _oaot, _усыг_, _অসমক, 
   {{0x7ae06863,0xdb184c5d,0x00000000,0x00000000}},	//   _naot, ltvæ, --, --, 
   {{0x23840014,0x6dc4009d,0x00000000,0x00000000}},	//   _ؤیِ, ссеж, --, --, 
   {{0xdef80184,0xdb1801a8,0xb17801e3,0x00000000}},	//   _һыу_, ntvæ, _bråv, --, 
   {{0x7ae17a2a,0xf054036b,0x98ac0064,0xc0d00092}},	//   _baot, _ایاغ_, lodė_, ረንም_, 
   {{0x7ae17a2b,0xc9a80801,0x9f687cf4,0x94f8025c}},	//   _caot, авие_, _груз_, _ཕོའི_, 
   {{0x7ae051e2,0xdd940228,0x88d40953,0x3b040009}},	//   _daot, _наты, оўні, _dooq_, 
   {{0xb17800fe,0xdce80055,0xdb1800e5,0x092801a9}},	//   _fråv, _tidā, rtvá, ржой_, 
   {{0x7ae16bb2,0x3b040009,0xdb194093,0x36380092}},	//   _faot, _fooq_, stvá, _ያስገኛ, 
   {{0x7ae17a2c,0x00000000,0x00000000,0x00000000}},	//   _gaot, --, --, --, 
   {{0xdb1800b5,0x00000000,0x00000000,0x00000000}},	//   ftvæ, --, --, --, 
   {{0xdebc0201,0x9c7d5d06,0xded41ee0,0xdb18005c}},	//   ደሆነ_, _kača, ረትና_, gtvæ, 
   {{0x29057a2d,0x9c7c0b91,0x68e17a2e,0xe748010b}},	//   _iona_, _jača, _iand, _гүне_, 
   {{0x6ab8bf56,0x29057a2f,0xc0d00020,0x4ad805f9}},	//   nguf, _hona_, _የኑሮ_, ढ़िव, 
   {{0x68e0633d,0x29057a30,0x41052cb4,0xd838151c}},	// [27740] _kand, _kona_, озав, mača_, 
   {{0xd8382a3f,0x591c0327,0x00000000,0x00000000}},	//   lača_, ོ༵གས_, --, --, 
   {{0x68e17a31,0x29057a32,0xdebc001f,0x9c7c02fb}},	//   _mand, _mona_, ደሆኑ_, _nača, 
   {{0x29057a33,0x69d80198,0xfde8036b,0xd8385a54}},	//   _lona_, kwue, идек_, nača_, 
   {{0x29057a34,0x68e00b21,0xdd949dc3,0x7ae0da61}},	//   _oona_, _oand, чалы, _raot, 
   {{0x68e17a35,0x29057a36,0x62857a37,0x7ae17a38}},	//   _nand, _nona_, lcio, _saot, 
   {{0x26c01280,0x7ae17a39,0x3328030d,0xceac008e}},	//   _ocio_, _paot, _ymcx_, _пә_, 
   {{0xbf140372,0x68e0292b,0x9c7c8c2c,0x6ab8022f}},	//   _بورب, _aand, _dača, gguf, 
   {{0x68e17a3a,0x2904a92e,0x628409d7,0xd83808a4}},	//   _band, _bona_, icio, dača_, 
   {{0x29057a3b,0x26c00077,0x3dc4013f,0x7ae0009f}},	//   _cona_, _acio_, mtow_, _waot, 
   {{0x68e17a3c,0x62857a3d,0x7ae17a3e,0x7d18009a}},	//   _dand, kcio, _taot, _ilts, 
   {{0x2904052f,0x68e17a3f,0xd83804a7,0x80c8859c}},	//   _eona_, _eand, gača_, स्ते, 
   {{0x68e17a40,0x9c7c4ea1,0x3dc57a41,0x29057a42}},	//   _fand, _zača, ntow_, _fona_, 
   {{0x29057a43,0x25fc05f9,0x8e7c0115,0x62849b0e}},	//   _gona_, _ऊपरी_, _maŝa, ecio, 
   {{0x64743420,0xd8380331,0xa6d0009e,0x628401ab}},	//   дгру, bača_, িয়ট, fcio, 
   {{0xdb185cf2,0xd83816a3,0x1aac0183,0xaee000b8}},	//   stvæ, cača_, ক্ৰা, _meṣa, 
   {{0x29057a44,0x6aa4009e,0x7d184b0a,0xdb1801e3}},	// [27750] _yona_, ক্কো, _olts, mtvä, 
   {{0x62857a45,0x68e17a46,0x290406e4,0x98ac02d5}},	//   acio, _xand, _xona_, rodė_, 
   {{0x3cfc34ef,0xb364004e,0x00000000,0x00000000}},	//   लाने_, _мъмк, --, --, 
   {{0x62857a47,0x8e7c0115,0xb1785243,0x9c7d7a48}},	//   ccio, _baŝa, _bråt, _rača, 
   {{0x9c7c0171,0x8c540092,0x00000000,0x00000000}},	//   _sača, _ምንጮች, --, --, 
   {{0xd8380989,0x8b941bc4,0x80c000e1,0x6448002d}},	//   zača_, прич, _लाये, ûdig, 
   {{0x29057a49,0xce957a4a,0x3dc40086,0x1fa401b9}},	//   _rona_, _навъ, atow_, _ортг, 
   {{0x29057a4b,0x7d180a85,0xb178143a,0xdb180267}},	//   _sona_, _elts, _fråt, jtvä, 
   {{0xd83808ad,0x29043d81,0xb1782ff9,0x6ab97a4c}},	//   vača_, _pona_, _gråt, rguf, 
   {{0x68e17a4d,0x26c17a4e,0x9c7c4beb,0x6f1802fb}},	//   _qand, _scio_, _tača, _hluc, 
   {{0x29040c11,0x6f197a4f,0xd8397a50,0xdb1801e6}},	//   _vona_, _kluc, tača_, ftvä, 
   {{0x68e17a51,0x29057a52,0xab6002dd,0x6120013d}},	//   _wand, _wona_, _تۇبى, _gölf, 
   {{0x29057a53,0xd83804b9,0x070801d5,0xceb801ef}},	//   _tona_, rača_, ليگي_, _umřu_, 
   {{0x68e00451,0x6f197a54,0x29041d04,0x9c7c1156}},	//   _uand, _lluc, _uona_, _lačn, 
   {{0x6f197a55,0xd83808ad,0x612001ed,0x43080451}},	//   _oluc, pača_, _hölg, ٽيءَ_, 
   {{0x26c005a1,0x61217a56,0xf53c01bf,0x941003b9}},	//   _ucio_, _kölg, frås_, nazə_, 
   {{0xb6b8011a,0x00000000,0x00000000,0x00000000}},	// [27760] _הצפי, --, --, --, 
   {{0x987801a6,0x00000000,0x00000000,0x00000000}},	//   ršći_, --, --, --, 
   {{0x62857a57,0x6f180363,0xb178143a,0xdb1801e3}},	//   pcio, _bluc, _brås, ltvå, 
   {{0x6f181561,0xcf2405e6,0x8e7c00df,0x2484013f}},	//   _cluc, ورني, _paŝa, ɛmma_, 
   {{0x2b800205,0xdb18007c,0x00000000,0x00000000}},	//   _rıca_, ntvå, --, --, 
   {{0x3dc4f863,0x3f880158,0xf53c00cc,0xac94007b}},	//   rtow_, _ttbu_, lrår_, كنها_, 
   {{0x3dc57a58,0xb17800fe,0x6f180d63,0xca3800df}},	//   stow_, _frås, _fluc, vaŝa_, 
   {{0x61204ba9,0xeb94026a,0xb17803cd,0xe80c07c1}},	//   _bölg, чић_, _tråt, ाहना_, 
   {{0x8e7c0115,0xca380115,0xb9f82cc5,0x00000000}},	//   _kaŝn, taŝa_, ইন্ড_, --, 
   {{0x9c7c9a4d,0xe9cc36e9,0x7c640cd6,0x612017da}},	//   _začn, اغي_, _فاضل, _wölf, 
   {{0xd1f00201,0x612001a8,0xdb180267,0x00000000}},	//   _ሂደት_, _tölf, ttvä, --, 
   {{0x612001a8,0xf53c03cd,0xdb18072b,0x6f1800d7}},	//   _höld, yrås_, ftvå, _xluc, 
   {{0xe6657a59,0x6120510c,0x9c7c16a3,0xdb180267}},	//   етро, _gölg, _jačo, rtvä, 
   {{0xdb1801e6,0x256401a8,0x19c000d1,0x9c7c0171}},	//   stvä, jöld_, _ﻣﻪﻳﻠ, _mačo, 
   {{0xd83809a8,0x24180b7e,0x612057d9,0x80c803d4}},	//   mačo_, поры_, _möld, ৰাঞ্, 
   {{0x80c8813f,0xd8380427,0xe73803f6,0x00000000}},	//   स्से, lačo_, _неј_, --, 
   {{0x25642bb4,0xa34401c6,0x9c7cf0ac,0x00000000}},	// [27770] föld_, хэрл, _račn, --, 
   {{0xe3b000dd,0x6120f875,0xd8380427,0x28cc00cd}},	//   ضرہ_, _nöld, načo_, त्पि, 
   {{0x6f18a032,0xfa101c82,0x09d8012c,0x00000000}},	//   _pluc, িছিল_, _भन्य, --, 
   {{0x9c7c0419,0x00000000,0x00000000,0x00000000}},	//   _bačo, --, --, --, 
   {{0x6f197a5a,0x6120496e,0x80c80183,0x5f7475f5}},	//   _vluc, _böld, ৰাজ্, رامر, 
   {{0xb1780158,0xd83809a8,0xfd240133,0xe80c0118}},	//   _frår, jačo_, وونێ, ाहमा_, 
   {{0x9c7c1467,0xb1780fac,0xdfd4005b,0x6120a75a}},	//   _tačn, _trås, _поры, _döld, 
   {{0x6f197a5b,0xf0b001d9,0xab600131,0x00000000}},	//   _uluc, _زیچھ, رۇشى, --, 
   {{0x612000dd,0x88e00154,0x80c85347,0x00000000}},	//   _föld, বাসক, स्वे, --, 
   {{0xaca001f2,0x8e7c0115,0x61217a5c,0xd8380010}},	//   _maịl, _kaŝo, _göld, gačo_, 
   {{0x2ba42ecf,0x2564002f,0xfd240244,0x00000000}},	//   _गिटा, nöle_, _تولێ, --, 
   {{0x612001d3,0xdb194356,0x8e7c0115,0x09f800c6}},	//   _zöld, ttvå, _maŝo, _وفاة_, 
   {{0x39e00032,0x09e401c0,0xdc700124,0x00000000}},	//   _аҙығ, _цолн, _иҳәы, --, 
   {{0x61217a5d,0xf8cc001e,0xd88801d3,0xdb18007c}},	//   _köle, _hứng_, _ٹپٹن_, rtvå, 
   {{0x58940597,0x25640008,0xd1f0001f,0x3cfc02a0}},	//   _أجهز, völd_, _ሂደቱ_, लाते_, 
   {{0x61217a5e,0x04fc00eb,0x00000000,0x00000000}},	//   _möle, ঁসের_, --, --, 
   {{0x80c01fad,0xf53c0158,0x25640267,0x00e404b3}},	// [27780] _लादे, rrår_, töld_, мжан, 
   {{0xc0586d2a,0x8e7c01e4,0xa49401d3,0x226403e0}},	//   орец_, _baŝo, _سیرت, _ırkı_, 
   {{0x28cc690c,0x04442e3f,0x256443e5,0x00000000}},	//   त्यि, _ценн, röld_, --, 
   {{0xaca000b4,0xf8cc004d,0x61200112,0x00000000}},	//   _faịl, _nứng_, _söld, --, 
   {{0x61440124,0xbd6957bd,0x8fd40139,0x00000000}},	//   _зҵаа, орке_, _җәхә, --, 
   {{0xaa340020,0x612009a5,0x8e7c0115,0x63bc0334}},	//   _እስካሁ, _böle, _faŝo, ourn, 
   {{0x63bc08a7,0x61200008,0xd8380010,0xf8cc0051}},	//   nurn, _völd, vačo_, _bứng_, 
   {{0xf8cc0016,0x9c7c02fb,0x612000a2,0xddc000a2}},	//   _cứng_, _začl, _döle, _gymş, 
   {{0x63bd7a5f,0xd8380427,0xf8cc0051,0x612001a8}},	//   hurn, tačo_, _dứng_, _töld, 
   {{0x63bd7a60,0xdd9000aa,0x00000000,0x00000000}},	//   kurn, _لوړ_, --, --, 
   {{0x63bc2b1d,0xb90400e1,0x9c7c00d0,0x612115df}},	//   jurn, _पस_, _jačm, _göle, 
   {{0x7bc80af2,0xd8380427,0xdb1800c7,0xeb940353}},	//   mtfu, sačo_, kuvé, _циц_, 
   {{0x63bc00d5,0x7bc83098,0xdb1800e4,0x00000000}},	//   eurn, ltfu, juvé, --, 
   {{0x63bd7a61,0x290001e3,0x612001f4,0x00000000}},	//   furn, öjat_, _yöle, --, 
   {{0x63bc04b9,0x7bc8003c,0x5bdc197c,0xa9640214}},	//   gurn, ntfu, _मनोव, _تموم_, 
   {{0xaca0063f,0xf8cc001e,0xe2f80220,0x7bc80f85}},	//   _paịl, _xứng_, месі_, itfu, 
   {{0x62357a62,0x50f400c7,0x7bc891db,0x88e00154}},	// [27790] вету, нзат, htfu, বারক, 
   {{0x7bc87c1d,0xb17878d0,0x8e7c010f,0x6448002d}},	//   ktfu, _dråp, _paŝo, ûdic, 
   {{0x63bc7541,0x2fc40356,0x00000000,0x00000000}},	//   curn, îng_, --, --, 
   {{0x26dc00c8,0x61217a63,0xaca0063f,0xe80c02c3}},	//   ַקומ, _röle, _taịl, ाहता_, 
   {{0x61200790,0xca3801e4,0x317001ec,0xf0b800f2}},	//   _söle, vaŝo_, _ағат, _واسش_, 
   {{0x7bc81654,0x61200254,0x00000000,0x00000000}},	//   ftfu, _pöle, --, --, 
   {{0x7bc800b5,0x900801d9,0x9c7c0427,0x0134123b}},	//   gtfu, _عٲرق_, _kačj, _טרשת_, 
   {{0x4aa848ce,0x8e7c0115,0x499411e7,0x61202737}},	//   чкин_, _kaŝm, ншот, _gölb, 
   {{0x63bc07ab,0x9f34005e,0x9c7c84c4,0xeb9401b9}},	//   zurn, _реті, _mačj, чиқ_, 
   {{0x61204afc,0x63bd7a64,0x7bc835ff,0x29c40137}},	//   _töle, yurn, btfu, птүү_, 
   {{0x88e004c5,0x7bc97a65,0xca3801e4,0x612000a2}},	//   বালক, ctfu, paŝo_, _yölb, 
   {{0x612001ed,0x63bd3cfc,0xfc14010f,0xb8f00137}},	//   _kölc, vurn, _אקעי_, _ەكوب, 
   {{0x29000267,0x63bc003e,0x59c4007b,0xf53c007c}},	//   öjas_, wurn, _لينك, rsån_, 
   {{0x59d8033f,0xc7a4010a,0xb6041d1d,0x00000000}},	//   _बैटर, _зикк, _spáð, --, 
   {{0xf8b002e4,0x58857a66,0xe8a801f9,0xfcb00419}},	//   _עשה_, _рыча, चणीच, íšiť_, 
   {{0x77440201,0xf7d40302,0x63bd7a67,0xdb197a68}},	//   _ሪፖርተ, _נופש_, rurn, tuvé, 
   {{0x9c7c0331,0x5bdc002b,0x28cc00cd,0xd5e401ec}},	// [277a0] _sačm, _मन्व, त्थि, _айық, 
   {{0x63bd7a69,0xb0e57a6a,0xb978010f,0xdb180124}},	//   purn, ндуз_, פרעז, ruvé, 
   {{0x74980375,0xd9ac07f7,0x82a401b9,0x3cfc0f90}},	//   _מייפ, _टट्ट, _панж, लासे_, 
   {{0x28cd7a6b,0x73e17a6c,0x06b000bd,0x612001ed}},	//   त्ति, _союз, ট্রি, _bölc, 
   {{0x52753739,0xf2d0010f,0xf77000df,0x00000000}},	//   _ауру, _גער_, אקא_, --, 
   {{0x7bc801e3,0xfca8004b,0x61201196,0x7638010f}},	//   ttfu, ساتو_, _wölb, הענג, 
   {{0x99bc03f4,0x7bc80354,0xeaac005e,0x88bc02f5}},	//   _অনেক, utfu, ڭعى_, _অসংক, 
   {{0x9c7ca355,0x8c3401e1,0x3cfc01ad,0xb178007c}},	//   _kačk, _ke̟j, लाहे_, _osål, 
   {{0xb8c41473,0x3ea40bed,0x61205775,0xbd3400db}},	//   ىزدى, maot_, _gölc, _كىرع, 
   {{0x3ea562c8,0x9c7c3466,0xf1b00bd4,0xdb180356}},	//   laot_, _mačk, נסת_, cuvî, 
   {{0x31340375,0xa850035b,0x4c0000f1,0x36200248}},	//   תנים_, лҵшә, _نېول, _ẹ̀sì, 
   {{0x3cfc19ec,0x3ea408cd,0x290001e6,0xfaa4041b}},	//   लावे_, naot_, öjar_, _чадо, 
   {{0x9c7c0010,0x6b6001d3,0xdce0002b,0x00000000}},	//   _račj, _nőgy, _numī, --, 
   {{0xe4e40212,0x3ea4022e,0x00000000,0x00000000}},	//   лісн, haot_, --, --, 
   {{0x3ea57a6d,0xf3652d29,0x9c7c01a6,0x00000000}},	//   kaot_, етан, _pačj, --, 
   {{0x9c7ca5e2,0x798001f7,0x8e7c01e4,0x648801c0}},	//   _bačk, _kuow, _paŝm, _үсэг_, 
   {{0x3ea451e2,0x645813ce,0x80c0033f,0x00000000}},	// [277b0] daot_, _øvin, _लाशे, --, 
   {{0x2f140432,0x9c7c0064,0x68800023,0x00000000}},	//   _içgi_, _dačk, _ከበድቲ_, --, 
   {{0xc4d0011a,0xa0c40b24,0x5ebc00eb,0x00000000}},	//   _דגי_, ايمو, োজনে, --, 
   {{0x990c012c,0x9c7c00d7,0x00000000,0x00000000}},	//   ाउँछ_, _fačk, --, --, 
   {{0xa2f40a89,0x5ed00154,0x61f80153,0x00000000}},	//   _спяч, _সোহে, _зняў_, --, 
   {{0x636800e4,0xfa2400eb,0x00000000,0x00000000}},	//   tÿng, মপাল_, --, --, 
   {{0x3ea42b92,0xcb680691,0x35c00210,0x00000000}},	//   baot_, ومته_, वंड़, --, 
   {{0x4a7400cf,0x00000000,0x00000000,0x00000000}},	//   кыпт, --, --, --, 
   {{0xd90c00f1,0x00000000,0x00000000,0x00000000}},	//   ړیو_, --, --, --, 
   {{0x7980e3ba,0x61200793,0x256401b8,0xab84014b}},	//   _duow, _köla, köla_, _зудк, 
   {{0x8c1800b2,0x2ca49c1c,0xf53c005c,0x6448031c}},	//   _تيار_, mand_, rsål_, żdiz, 
   {{0x2d9c02e3,0x6121549b,0x0a38013d,0x6b540124}},	//   _kwue_, _möla, _очлы_, tãgu, 
   {{0x61200793,0xe5780107,0x2498022e,0x58dc00eb}},	//   _löla, нҷи_, tbrm_, বাড়ী, 
   {{0x8e7c01e4,0x9c7d7a6e,0x9ab4002b,0x6b5400c7}},	//   _baŝk, _račk, _imāṃ, rãgu, 
   {{0x29c80158,0x2ca405c7,0x9c7c00d7,0x6b5400e4}},	//   løa_, iand_, _sačk, sãgu, 
   {{0xded402d3,0xd17401e0,0x28b40073,0x6b5400e4}},	//   የትን_, ғыуы, _आयडि, pãgu, 
   {{0x3ea41509,0x02e00c2e,0xb6980109,0x2ca57a6f}},	// [277c0] vaot_, _पसीन, djâh, kand_, 
   {{0x2ca57a70,0x31205225,0x52740228,0x256401b8}},	//   jand_, адуг, уусу, böla_, 
   {{0x2ca404fb,0x3ea41028,0x25a005c7,0x6800013f}},	//   dand_, taot_, _hwil_, pɑdu, 
   {{0x9c7d7a71,0x627400db,0x257c01e1,0x00000000}},	//   _tačk, _مۇزئ, bálè_, --, 
   {{0x3ea57a72,0x201c05be,0x2ca43c53,0x3cfc012c}},	//   raot_, švi_, fand_, लाले_, 
   {{0x2ca57a73,0x61e400ec,0x9c7d7a74,0x51080408}},	//   gand_, mwil, _kači, _пĕчĕ, 
   {{0x61e57a75,0x9c7c1b24,0x9ab40055,0x25a002bd}},	//   lwil, _jači, _amāṃ, _lwil_, 
   {{0x9c7d1fa0,0x69c80334,0x28cc00dc,0xf410011a}},	//   _mači, _bqge, त्सि, שפה_, 
   {{0xd8388e70,0x6e9001d5,0x61e57a76,0x7f400393}},	//   mači_, _خلقا, nwil, mnoq, 
   {{0xd1042d8f,0x2ca4084c,0xd83807f5,0x61e403fa}},	//   रायण_, cand_, lači_, iwil, 
   {{0x61e57a77,0x25a17a78,0x3cfc03b9,0x26ec0154}},	//   hwil, _awil_, _intv_, টানো_, 
   {{0x61e57a79,0xd8382aac,0xeabc0086,0x7f400194}},	//   kwil, nači_, òùt_, nnoq, 
   {{0x58d57a7a,0x61e57a7b,0x69c80175,0x4aa801d3}},	//   _болт, jwil, _gqge, _سانپ_, 
   {{0x61e57a7c,0x65940117,0x00000000,0x00000000}},	//   dwil, рару, --, --, 
   {{0xd8380427,0x61e4a9e9,0x24593796,0x7c2817da}},	//   kači_, ewil, варь_, nzfr, 
   {{0x2ca57a7d,0x61e4090c,0x395d2985,0x256404cc}},	//   zand_, fwil, llts_, röla_, 
   {{0x3568152d,0x9c7c026a,0x28cc243c,0x61e57a7e}},	// [277d0] _орон_, _dači, त्वि, gwil, 
   {{0x7bd80bb8,0xdce80316,0xd49800d6,0x61200793}},	//   _optu, _vidě, _якої_, _pöla, 
   {{0x2ca57a7f,0x8e7c00df,0x4428012d,0x00000000}},	//   vand_, _haŝi, czb_, --, 
   {{0x3cfc3743,0x61e4090c,0x2ca51ea3,0x61200793}},	//   _antv_, bwil, wand_, _völa, 
   {{0x7bd97a80,0x3cfc01fa,0x61e57a81,0xd7c40073}},	//   _aptu, _bntv_, cwil, लंडच, 
   {{0x9c7d7a82,0x8c44cc3b,0x7bd80066,0x612001b8}},	//   _zači, леле, _bptu, _töla, 
   {{0x61205380,0x98ac0356,0x69300753,0x00000000}},	//   _köln, zidă_, یکتر, --, 
   {{0x2ca57a83,0xd83801fa,0x29c80158,0x613c007c}},	//   sand_, cači_, tøa_, pålä, 
   {{0x2ca57a84,0x80c84728,0x612001e6,0x7bd803ac}},	//   pand_, स्के, _möln, _eptu, 
   {{0x2ca41188,0x1880001f,0x98ac054e,0x2cf800db}},	//   qand_, _ከአገር_, vidă_, _تةرة_, 
   {{0x61e4013e,0x2efd7a85,0x6d417a86,0x25a0015d}},	//   zwil, _knuf_, mnna, _swil_, 
   {{0xc9f48079,0x61e57a87,0x00000000,0x00000000}},	//   _مستع, ywil, --, --, 
   {{0x6d417a88,0x9a846e1f,0x9c7c00d7,0xdb2001e1}},	//   onna, _тухл, _rači, _ìtáb, 
   {{0x9c7c1225,0xd8381591,0x61e402ea,0xdb180276}},	//   _sači, zači_, vwil, cuvâ, 
   {{0x6d417a89,0x9c7c02d5,0xfbc4725a,0x7f4001b9}},	//   inna, _pači, रूपम, ynoq, 
   {{0x28cc07b6,0x61e55f4b,0xb1142928,0x98ac0276}},	//   त्रि, twil, ۇققا_, pidă_, 
   {{0xd8380bb8,0x67257a8a,0x8e7c010f,0xfdbc015b}},	// [277e0] vači_, _ilij, _faŝi, _ইন্ড, 
   {{0x80a57a8b,0x61e57a8c,0x00000000,0x00000000}},	//   امان, rwil, --, --, 
   {{0x67257a8d,0x9c7c0953,0xd1757a8e,0xd8380c5e}},	//   _klij, _tači, рыты, tači_, 
   {{0x6d417a8f,0x612000fd,0xdb195c28,0x6fec002b}},	//   enna, _göln, tuví, _ṛcch, 
   {{0x67241f7f,0xd8380bb8,0x25640793,0x61e40472}},	//   _mlij, rači_, nölo_, qwil, 
   {{0xd83807f5,0x67240784,0x9c7c0114,0xdb1801a8}},	//   sači_, _llij, _mačv, ruví, 
   {{0x9a849098,0xd8380e3c,0x67257a90,0x2b5c0036}},	//   қуқл, pači_, _olij, fluc_, 
   {{0x6d417a91,0xd9d84251,0x7c281a80,0x25640793}},	//   anna, তিসম, rzfr, kölo_, 
   {{0xfe440120,0x00000000,0x00000000,0x00000000}},	//   _снао, --, --, --, 
   {{0x67257a92,0x25640793,0x23600978,0xee357a93}},	//   _alij, dölo_, hlij_, _сну_, 
   {{0x67257a94,0x3154008d,0x7bd8035a,0x00000000}},	//   _blij, ריין_, _uptu, --, 
   {{0x9c7c2375,0x25640793,0x2b5c0548,0x23617a95}},	//   _bačv, fölo_, cluc_, jlij_, 
   {{0x395c0d27,0x25640793,0x672401a6,0x8e7c00df}},	//   plts_, gölo_, _dlij, _paŝi, 
   {{0x67257a96,0x00000000,0x00000000,0x00000000}},	//   _elij, --, --, --, 
   {{0x56957a97,0x8e7c010f,0x67257a98,0x69300276}},	//   _кайт, _vaŝi, _flij, _ыншу, 
   {{0xf2057a99,0x67240196,0x256401b8,0x32280845}},	//   лязо, _glij, bölo_, нізм_, 
   {{0x6d417a9a,0x00000000,0x00000000,0x00000000}},	// [277f0] ynna, --, --, --, 
   {{0x94d405f5,0x8e7c0115,0x2efc0549,0x611400f7}},	//   _тооц, _kaŝv, _snuf_, бдуу, 
   {{0xa2d00714,0x6724005b,0x2360016d,0x6dc400a2}},	//   _डॉक्, _ylij, blij_, _oōaý, 
   {{0x61217a9b,0x2564ee18,0x228428f3,0x6d40a2e5}},	//   _höll, höll_, _гург, wnna, 
   {{0x61217a9c,0xd8382375,0xca380115,0x9c7c5106}},	//   _köll, maču_, paŝi_, _maču, 
   {{0x6d417a9d,0x8b040034,0x3e78510c,0xd838107d}},	//   unna, _mięś, _sütü_, laču_, 
   {{0x6cc00184,0x61217a9e,0x6d400857,0x8e7c01e4}},	//   айҙа, _möll, rnna, _naŝv, 
   {{0x09d402d5,0xfef00451,0x6d400175,0xca8401c6}},	//   ацоў, _وڻند, snna, шгий, 
   {{0x25649632,0x2b5c0200,0x7ac40354,0x00000000}},	//   föll_, rluc_, ăске, --, 
   {{0x9c7c16a3,0x67257a9f,0xacf407d6,0xd83801a6}},	//   _račv, _slij, _حسرت, haču_, 
   {{0x67240dd4,0x80c81b42,0x1bb97aa0,0x2b5c00db}},	//   _plij, स्टे, _مانع_, pluc_, 
   {{0xd83804a7,0xca7426f8,0x25640793,0x23600369}},	//   jaču_, _кулы, tölo_, xlij_, 
   {{0x67257aa1,0xd8380331,0x61217aa2,0xc7ac0150}},	//   _vlij, daču_, _böll, _راﻳﻮ, 
   {{0x2360014f,0x00000000,0x00000000,0x00000000}},	//   wlij_, --, --, --, 
   {{0x61202ca8,0x2360016d,0xdb1819cd,0x8ccc0118}},	//   _döll, tlij_, luvá, _सानो, 
   {{0x67257aa3,0xd83816a3,0xb1782611,0x461400f2}},	//   _ulij, gaču_, _gråz, _نوعر, 
  
   {{0x09b400c8,0x8e7c0115,0xb2180ac8,0x61217aa4}},	// [27800] יפּט_, _kaŝu, _sfær, _föll, 
   {{0x409407dd,0x9c7c0b3d,0x2360016d,0x00000000}},	//   ррат, _začu, slij_, --, 
   {{0x23617aa5,0x91c400d1,0x3fe40108,0xd838260c}},	//   plij_, _һаяҗ, ржев, baču_, 
   {{0x383c02d3,0x61200b70,0x23617aa6,0x3f8c0115}},	//   _ኣቕሪብ, _zöll, qlij_, ŭfuo_, 
   {{0x6120023a,0xfce457c6,0x41a8000d,0x00000000}},	//   _yöll, иодо, _छबिस, --, 
   {{0x71a0085a,0x61200139,0xdb1803b2,0x3f940798}},	//   _фарз, _kölm, duvá, _враѓ, 
   {{0x90e40014,0x1958774d,0xb21801bf,0x9c7c0118}},	//   _اسُن, ғаны_, _ufær, _načt, 
   {{0x3f9802f6,0xef1400fb,0x42a40023,0x3f683860}},	//   mppu_, _кмс_, _ጉድኣት_, _рибо_, 
   {{0x9c7c8847,0x777c01d5,0xca3801e4,0xf968005b}},	//   _raču, _riqx, kaŝu_, крой_, 
   {{0x9c7c0bb8,0x777c022f,0xd83807f5,0x00000000}},	//   _saču, _siqx, začu_, --, 
   {{0xb8cc13f5,0xa6b000cc,0x61200108,0x28b41cd2}},	//   _ओज_, কলনট, _röll, _आयरि, 
   {{0x3cfc4244,0x6120002f,0x3f9801f4,0x8b04012d}},	//   लाके_, _söll, ippu_, _pięś, 
   {{0xd8380989,0x61217aa7,0x8ccc0073,0xbec00171}},	//   vaču_, _pöll, _सामो, _čīle, 
   {{0x80c07ff3,0x61200cc1,0x80a802ab,0x2d58017a}},	//   _लागे, _bölm, टरफे, lêer_, 
   {{0x80a869af,0x61217aa8,0xd83832fe,0x96f81eec}},	//   टरने, _völl, taču_, _бейт_, 
   {{0x8e7c0115,0xa87805d0,0x61217aa9,0xb5a4020f}},	//   _kaŝt, _באור, _wöll, _крой, 
   {{0xd83805ce,0xa34405f5,0x61200821,0xe6100014}},	// [27810] raču_, цэрл, _töll, _ہشی_, 
   {{0x8c340241,0xd83804a7,0x612001e3,0x00000000}},	//   _ke̟t, saču_, _hölj, --, 
   {{0x0eb809a5,0x13a403e6,0x612003b9,0x8eb800c7}},	//   гулы_, _دۆزی_, _gölm, гылт_, 
   {{0xb1781f53,0x5ea40372,0x00000000,0x00000000}},	//   _spåd, ۅمۅل, --, --, 
   {{0x3f980194,0xdea407d6,0x3ed000cf,0x00000000}},	//   appu_, زیلی, سقور, --, 
   {{0xdb0807c5,0x931400d1,0x1dc800c5,0xe7e400bc}},	//   _avdà, _ئوڭش, _रमरत, टौडा_, 
   {{0x25640267,0x5f48001f,0x5c140022,0x00000000}},	//   följ_, ካከላቸ, жьыу, --, 
   {{0x0ae97aaa,0xd104185b,0xcda80a0a,0x98ac0064}},	//   удий_, रावण_, _مهره_, midę_, 
   {{0xdd940006,0xee3c00a2,0x00000000,0x00000000}},	//   _маты, _äý_, --, --, 
   {{0xdb18c542,0xa8a400a2,0x00000000,0x00000000}},	//   ruvá, _ümüş_, --, --, 
   {{0x612001e3,0xdcac00cf,0xf79401b9,0xdb18032e}},	//   _bölj, _شۉي_, ینیب_, duvæ, 
   {{0xb8257aab,0x442400b0,0x9c6406c2,0x00000000}},	//   союз_, _āo_, _بهمو, --, 
   {{0xb0c402ab,0x612001e6,0x46a40116,0x987800e2}},	//   _लांग, _dölj, _һайв, kšķi_, 
   {{0xf9900302,0x07440bd6,0x00000000,0x00000000}},	//   _צרו_, рхүм, --, --, 
   {{0x61200628,0xc7957aac,0x00000000,0x00000000}},	//   _följ, _اشتب, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x95c803b7,0x8c3401e1,0x7c680092,0x00000000}},	// [27820] _куќа_, _ke̟s, ስመሰል_, --, 
   {{0xf0a4004e,0x00000000,0x00000000,0x00000000}},	//   йкул_, --, --, --, 
   {{0x39400c6a,0x61200108,0x442c3b3b,0x00000000}},	//   éksi_, _hölk, _åf_, --, 
   {{0x61217aad,0x3f99799f,0xce3400f1,0x00000000}},	//   _kölk, rppu_, ښونک, --, 
   {{0x9c7c0fb7,0x25640267,0xb17801bf,0x6d0003ce}},	//   _načr, jölk_, _spåe, लांग_, 
   {{0x61200716,0xbfa801d9,0x00000000,0x00000000}},	//   _mölk, _مارٕ_, --, --, 
   {{0x82e40003,0x988801ed,0x2bb400c6,0x256401e3}},	//   _སྒོའ, یحدہ_, ماية_, tölj_, 
   {{0x8e7c010f,0x79e401d3,0x00000000,0x00000000}},	//   _paŝt, موعہ_, --, --, 
   {{0x3f880306,0x6da001af,0x5a3401f4,0x00000000}},	//   _hubu_, _нита, юнит, --, 
   {{0x57b57aae,0x8e7c0115,0x64400790,0xdb180419}},	//   обот, _vaŝt, şmiy, mrví, 
   {{0x3f8800e8,0xe9cc40be,0x61200108,0x8d7801ec}},	//   _jubu_, وغی_, _pölj, _ﺠﺎﺀﺕ_, 
   {{0x3f8851e2,0xac04010b,0x00000000,0x00000000}},	//   _mubu_, _ынха_, --, --, 
   {{0x82e40135,0x3f8933f7,0x60dc02d0,0x00000000}},	//   _སྒེའ, _lubu_, _obrm, --, 
   {{0x92c400bd,0x00000000,0x00000000,0x00000000}},	//   _এসে_, --, --, --, 
   {{0x3f880230,0xe5340b7e,0xa3e400e1,0x9c7c1a48}},	//   _nubu_, черь, पौल_, _začr, 
   {{0x8c340241,0x00000000,0x00000000,0x00000000}},	//   _ke̟r, --, --, --, 
   {{0x3f88079b,0xd7f80311,0x6fc800af,0x61200205}},	// [27830] _aubu_, lvă_, _हमहू, _gölk, 
   {{0x3f897aaf,0xdb1825e4,0x00000000,0x00000000}},	//   _bubu_, luvä, --, --, 
   {{0x61200139,0x00000000,0x00000000,0x00000000}},	//   _zölk, --, --, --, 
   {{0x3f883142,0x78a8007c,0xdb180037,0xe7d805dc}},	//   _dubu_, _lefv, nuvä, _बहसप, 
   {{0xf1a8007b,0x6d8400e5,0xfbc40118,0x00000000}},	//   _حاجه_, حمتہ_, रूसम, --, 
   {{0xe3b04f6f,0x8b941a21,0xa1957ab0,0x3f880036}},	//   _تری_, орич, _харч, _fubu_, 
   {{0x251c04ac,0x3f88022f,0x63780115,0xce9402a9}},	//   רווא, _gubu_, _eŭnu, _мавъ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x09e002a6,0x3f8802f0,0xdb180037,0xf53c01e3}},	//   বিভা, _zubu_, duvä, nsås_, 
   {{0x3f880223,0xfe6c01b9,0x92c40154,0xdca4009b}},	//   _yubu_, _شگن_, _এসো_, _нађи, 
   {{0x7d1c0112,0x612002d2,0x9be40064,0x00000000}},	//   öpse, _sölk, _ніцк, --, 
   {{0xdb18000d,0x61200108,0xf53c007c,0x00000000}},	//   guvä, _pölk, ksås_, --, 
   {{0x6a640f11,0x3cfc0490,0xd7f80356,0x15b97ab1}},	//   _اطال, लाचे_, avă_, йыры_, 
   {{0x61217ab2,0xc7a40563,0xf53c01e3,0x00000000}},	//   _völk, _дикк, dsås_, --, 
   {{0x83382e91,0x00000000,0x00000000,0x00000000}},	//   ачат_, --, --, --, 
   {{0x3f882375,0xf53c0158,0x61201611,0x00000000}},	//   _rubu_, fsås_, _tölk, --, 
   {{0x6aa8066d,0xe20400dc,0x80a82cc9,0x3f897ab3}},	// [27840] _megf, रमेण_, ивав_, _subu_, 
   {{0x6aa800dd,0x310400f7,0x61203b22,0x2564216d}},	//   _legf, онуп_, _köli, köli_, 
   {{0x3f8801ee,0x436865cb,0x43740aac,0x00000000}},	//   _qubu_, _ванн_, _мумт, --, 
   {{0x3f8802ea,0x57cc00c8,0x61217ab4,0x00000000}},	//   _vubu_, רמאַ, _möli, --, 
   {{0x612029ef,0xf53c01e3,0x00000000,0x00000000}},	//   _löli, psåt_, --, --, 
   {{0x41289dc2,0x3f8803b4,0xf53c5f03,0x716401c6}},	//   _того_, _tubu_, lsår_, _маяг_, 
   {{0x78a803cd,0xbb2800a8,0x00000000,0x00000000}},	//   _refv, ицие_, --, --, 
   {{0x6aa80a73,0xf53c0423,0x0ed00a8a,0x7d1c007c}},	//   _cegf, nsår_, _हायड, öpsb, 
   {{0x6aa80042,0x612001f4,0xb9f80154,0x7c94009b}},	//   _degf, _pölh, েন্ড_, _дрец, 
   {{0xdce800da,0x612000a2,0x00000000,0x00000000}},	//   _vidē, _böli, --, --, 
   {{0xf0900302,0x6aa80086,0x8b64dc89,0xf53c0fac}},	//   ונת_, _fegf, _کالم, ksår_, 
   {{0xd7f80276,0x8e7c0115,0xf53c007c,0x00000000}},	//   rvă_, _kaŝp, ysås_, --, 
   {{0x3b0401a9,0xdb1800c5,0xe9d40120,0xb504012d}},	//   _inoq_, ruvä, _мкц_, शालय_, 
   {{0xdb18000d,0x00000000,0x00000000,0x00000000}},	//   suvä, --, --, --, 
   {{0x6120013d,0xdb18000d,0x00000000,0x00000000}},	//   _göli, puvä, --, --, 
   {{0xf53c0250,0xf62800db,0x00000000,0x00000000}},	//   gsår_, _ەسگى_, --, --, 
   {{0xd0105dcd,0xc7e80050,0x61200112,0x00000000}},	// [27850] کلا_, _نى۪ن_, _zöli, --, 
   {{0xf53c0267,0x667401c8,0xb1440133,0x612001f4}},	//   rsås_, _غدير, زیزم_, _yöli, 
   {{0x12940120,0xf53c2611,0xdfd401c6,0xdb18000d}},	//   _нинџ, bsår_, дохы, ltvõ, 
   {{0x7f8400c7,0x98ac0118,0x00000000,0x00000000}},	//   _ẽvév, tidě_, --, --, 
   {{0xc33000c8,0xdce0029f,0xa6b003d4,0xdb18000d}},	//   _טוט_, _atmı, _কামট, ntvõ, 
   {{0x3b04022e,0x9c7c007f,0x6aa80332,0x4278011a}},	//   _anoq_, _občd, _segf, _לארג, 
   {{0xdb18000d,0x00000000,0x00000000,0x00000000}},	//   htvõ, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf2dc145e,0x6aa89285,0xdce00205,0x61200205}},	//   _mbâ_, _vegf, _etmı, _söli, 
   {{0xfc4874bb,0x61217ab5,0x6aa80e78,0xab840b2c}},	//   ãíç_, _pöli, _wegf, _дудк, 
   {{0xf8acb57a,0x6aa80042,0x229c0118,0x0ba800cf}},	//   اکه_, _tegf, láků_, _چاچى_, 
   {{0xdb18007c,0x00000000,0x00000000,0x00000000}},	//   tuvå, --, --, --, 
   {{0xe6500023,0xf53c01e3,0x00000000,0x00000000}},	//   _ዘንጸላ, vsår_, --, --, 
   {{0x2bcc1cba,0x00000000,0x00000000,0x00000000}},	//   संपा, --, --, --, 
   {{0x29057ab6,0x3b04022e,0x6120007c,0x83682824}},	//   _inna_, _ynoq_, _kölv, مصرف_, 
   {{0x2904003e,0x9694084c,0x00000000,0x00000000}},	//   _hnna_, _орьш, --, --, 
   {{0xd838007f,0x229c0118,0xa7d827a6,0xd77800ec}},	// [27860] hbčl_, jáků_, _बहुउ, _بليڪ_, 
   {{0x9f8c0139,0xf53c072b,0xb5f8010f,0x229c013a}},	//   _sοñ_, ssår_, _פליכ, dáků_, 
   {{0xf53c3bdc,0x00000000,0x00000000,0x00000000}},	//   psår_, --, --, --, 
   {{0xf2dc145e,0xdb1802f0,0x7c3c03e3,0x62980205}},	//   _gbâ_, krvá, _üzrə, üboğ, 
   {{0x29057ab7,0xfe403a56,0x00000000,0x00000000}},	//   _onna_, رکری, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x81cc00bd,0x9c7c1f48,0xbea402bf,0xafe000c2}},	//   _শনি_, _obče, _навк, _порл, 
   {{0x973cf2df,0x63a800d0,0x3ea008a5,0x229c01ef}},	//   opće, ádny, _ýkt_, báků_, 
   {{0x7f4020ac,0xac8000fb,0x229c01ef,0x00000000}},	//   mioq, мгәл, cáků_, --, 
   {{0x7f417ab8,0x5fd00892,0x81cc03d4,0x00000000}},	//   lioq, _हमाल, _শনা_, --, 
   {{0x67082c33,0x7d1802d0,0x00000000,0x00000000}},	//   षांक_, _iots, --, --, 
   {{0x29040395,0x7f40ab03,0xfa6800fd,0xf9b4010b}},	//   _enna_, nioq, _лаек_, _еңиш_, 
   {{0x7d197ab9,0xd4c40228,0xe944a268,0x58d56d3d}},	//   _kots, мөнк, _کرنی, _жолт, 
   {{0x6d4c013d,0x00000000,0x00000000,0x00000000}},	//   _ícat, --, --, --, 
   {{0x7d197aba,0x395d7abb,0x7bc81653,0x647400f3}},	//   _mots, mots_, nufu, егру, 
   {{0x395d7abc,0x7d197abd,0xa81401ec,0x612002d2}},	//   lots_, _lots, _ءتور_, _mölu, 
   {{0x29057abe,0x7f417abf,0x50f40131,0x7d197ac0}},	// [27870] _ynna_, dioq, мзат, _oots, 
   {{0x395d7ac1,0x7d197ac2,0x229c00bc,0x39900142}},	//   nots_, _nots, váků_, _mâs_, 
   {{0x7f40013c,0x9f057ac3,0x7bc80162,0x533429c6}},	//   fioq, کونو, jufu, _жент, 
   {{0x7d181028,0x7bc80223,0xfb9404ce,0x7f40003a}},	//   _aots, dufu, dオ_, gioq, 
   {{0x7d181a89,0x395d7ac4,0x8d7442b5,0xcc8801ee}},	//   _bots, kots_, واتا, обле_, 
   {{0x7bc97ac5,0x7d197ac6,0x61217ac7,0x7ae4022e}},	//   fufu, _cots, _sölv, еkto, 
   {{0x395d7ac8,0x7d197ac9,0x7bc904c4,0xb8b001e1}},	//   dots_, _dots, gufu, _lẹsè, 
   {{0xfd4c01f2,0xdb1802fb,0x256401ed,0xa2a0a1f3}},	//   _kekọ, trvá, lölt_, गुप्, 
   {{0x7d181311,0xfd4c02e3,0xad400e26,0x395c0793}},	//   _fots, _jekọ, _كىرۉ, fots_, 
   {{0x395d7abc,0x6f18002d,0x7d197aca,0x7bc97acb}},	//   gots_, _houc, _gots, bufu, 
   {{0x612000fc,0x6f197acc,0xfd4c01f2,0xdce800c0}},	//   _tölv, _kouc, _lekọ, _aidė, 
   {{0x7d180925,0xaac40150,0x39900142,0x00000000}},	//   _zots, _ءتان, _fâs_, --, 
   {{0x395d7acd,0x6f197ace,0x612000dd,0x290401af}},	//   bots_, _mouc, _költ, _tnna_, 
   {{0x6d417acf,0x6f197ad0,0x29041a82,0x61200793}},	//   nina, _louc, _unna_, _jölt, 
   {{0x6120032e,0xfcb80092,0x00000000,0x00000000}},	//   _mölt, ደመጣ_, --, --, 
   {{0x6f197ad1,0xb8b001e1,0x2b5c0165,0x00000000}},	//   _nouc, _fẹsè, nouc_, --, 
   {{0x7f40437d,0x32400798,0x7bc886ea,0x4ad402c3}},	// [27880] vioq, ветг, zufu, _धानव, 
   {{0xfd4c01f2,0x6f180165,0x256401a8,0xb0500050}},	//   _dekọ, _aouc, tölu_, چھِت, 
   {{0x6f197ad2,0x7f417ad3,0x6d409698,0x7bc8009a}},	//   _bouc, tioq, dina, xufu, 
   {{0x7d1833f0,0x6d400006,0x6f183046,0xfe4400d8}},	//   _sots, eina, _couc, мнео, 
   {{0x7d197ad4,0x61200008,0x7bc82747,0x6f183046}},	//   _pots, _sölu, wufu, _douc, 
   {{0x6d417ad5,0x7bc97ad6,0x7d197ad7,0x7f400eda}},	//   gina, tufu, _qots, sioq, 
   {{0x395c29ef,0x256401b8,0x7d197ad8,0x7f40003a}},	//   vots_, löls_, _vots, pioq, 
   {{0x7bc97ad9,0x6f180007,0x7d18055a,0x91e00183}},	//   rufu, _gouc, _wots, নিৰ্, 
   {{0x3ea57ada,0x395d7adb,0x7d197adc,0x2564014a}},	//   mbot_, tots_, _tots, nöls_, 
   {{0x6120008c,0x3ea57add,0x7bc97ade,0x23600007}},	//   _tölu, lbot_, pufu, hoij_, 
   {{0x6f197adf,0x395d7ae0,0x3dc40334,0x98fc01e4}},	//   _youc, rots_, lrow_, voĉd, 
   {{0x3ea57ae1,0x25657ae2,0x395c01b8,0xba245b6d}},	//   nbot_, köls_, sots_, _одек, 
   {{0xf9f0045e,0x612001b8,0x3dc47b30,0x7ae17ae3}},	//   জমহল_, _jöls, nrow_, _ibot, 
   {{0xb34403b7,0xfd4cba77,0x2564014a,0xe4e40212}},	//   _opçõ, _rekọ, döls_, кісн, 
   {{0x3ea4079b,0xfd4c01f2,0xa3d55a71,0xceb80118}},	//   kbot_, _sekọ, корч, _hoře_, 
   {{0x9f4c0570,0xdb097ae4,0x3ea40267,0xe8240066}},	//   _èdè_, _avdú, jbot_, _تذهی, 
   {{0x6d417ae5,0x7ae17ae6,0x6f18d005,0x91740588}},	// [27890] yina, _mbot, _rouc, егац, 
   {{0x6d417ae7,0xeb1805ba,0x6f197ae8,0xceb8012c}},	//   xina, _फक्त_, _souc, _moře_, 
   {{0x6d417ae9,0x6f1810b4,0x7ae17aea,0x3dc4058a}},	//   vina, _pouc, _obot, erow_, 
   {{0x6d401269,0x3ea4409c,0x2564014a,0x612002d2}},	//   wina, gbot_, böls_, _böls, 
   {{0x6d417aeb,0x7bc404fe,0xdd98151e,0x61200112}},	//   tina, _ākua, үшә_, _pölt, 
   {{0x7ae17aec,0x3ea4417f,0x691c05e4,0xe3b04013}},	//   _abot, abot_, _lêer, _حری_, 
   {{0x7ae00083,0x6f197aed,0x3ea57aee,0x6d417aef}},	//   _bbot, _touc, bbot_, rina, 
   {{0x7ae80dd4,0x7ae00472,0x3dc4b594,0x61203b7b}},	//   _རྒྱལ, _cbot, brow_, _föls, 
   {{0x6d417af0,0x61204f49,0x27340016,0xdecc001f}},	//   pina, _tölt, _hãng_, _ባንኩ_, 
   {{0x09e02158,0x6d402e95,0x7ae17af1,0xdd9801ec}},	//   বিলা, qina, _ebot, _ішу_, 
   {{0xa2a00950,0x00000000,0x00000000,0x00000000}},	//   गुड्, --, --, --, 
   {{0x941c0605,0xdcb801e4,0xab6001ec,0x27340208}},	//   _ɛwɔ_, _voĉe_, _جۇبى, _mãng_, 
   {{0x2734001e,0x8b6405a9,0x25080345,0x09e401a9}},	//   _lãng_, _قاچم, ورسی_, _чолн, 
   {{0x25640793,0x69d80023,0x7ae00332,0x98fc01e4}},	//   völs_, mtue, _zbot, toĉe, 
   {{0x69d80a85,0x68e000ca,0x7ae09f4e,0x00000000}},	//   ltue, _ibnd, _ybot, --, 
   {{0x256401b8,0x3dc41741,0x37240327,0x9af8002b}},	//   töls_, yrow_, རྒྱལ_, _khāṇ, 
   {{0x3ea57af2,0x46440014,0x41040153,0x00000000}},	// [278a0] vbot_, _سپدِ, нзав, --, 
   {{0x25a17af3,0x3ea5687f,0x66057af4,0xb1417af5}},	//   _itil_, wbot_, _irik, гнул, 
   {{0x9c7c4ea1,0x27e40263,0x261800f3,0x69d97af6}},	//   _obča, _jpnn_, _džoš_, htue, 
   {{0x200c038f,0x66057af7,0x256401b8,0x973c107d}},	//   _ġdid_, _krik, pöls_, opća, 
   {{0xdecc0125,0x69d8044e,0x919400d8,0xa2a000cd}},	//   _ባንክ_, jtue, _ајсш, गुण्, 
   {{0x6604034c,0x3dc57af8,0x69d80165,0x7ae17af9}},	//   _mrik, rrow_, dtue, _sbot, 
   {{0x26c17afa,0x3ea57afb,0x2d9c02f0,0xdb18007c}},	//   _odio_, pbot_, _etue_, yrvä, 
   {{0x26c000b2,0x66057afc,0x68e000ca,0x69d802d3}},	//   _ndio_, _orik, _abnd, ftue, 
   {{0x25a00083,0x69d80200,0x4900000d,0x2a9400ae}},	//   _ntil_, gtue, _वोहो_, رئية_, 
   {{0x26c17afd,0x8e757afe,0x7ae00e14,0xadb400c6}},	//   _adio_, _русч, _wbot, _أهلا_, 
   {{0x66057aff,0x25a06b20,0xb698145e,0x31340375}},	//   _arik, _atil_, ndâg, גנים_, 
   {{0x3b042776,0x7ae00b6f,0x38c40248,0x3bd80113}},	//   _dêpä_, _ubot, _bírà_, mëq_, 
   {{0xae000307,0x69d97b00,0x66057b01,0xa9a001c6}},	//   लियन_, ctue, _crik, _бичд, 
   {{0x66046ab9,0xd7f00597,0xdb08119a,0x00000000}},	//   _drik, _نكت_, _avdø, --, 
   {{0x66057b02,0x96f800cf,0xdb2001e1,0x00000000}},	//   _erik, _жейт_, _ìtób, --, 
   {{0x66057b03,0xae0000c5,0x66e4009b,0xa7f400ae}},	//   _frik, लिमन_, _боћа, _أعوذ_, 
   {{0x66057b04,0xb4b00116,0x201c005b,0x00000000}},	// [278b0] _grik, _йипә, ävin_, --, 
   {{0x7bc402b5,0xdce80055,0x88dc0327,0x7d1c0267}},	//   _ākun, _didī, ྱུརར, öpsl, 
   {{0x2d9c7eb1,0x69d8009d,0x1cc00327,0xd838007f}},	//   _stue_, ztue, ཀུན_, nzč_, 
   {{0x682829ef,0x2734004d,0x2bcc5a17,0x00000000}},	//   lödö, _vãng_, संसा, --, 
   {{0x7bd825de,0x69d806af,0x00000000,0x00000000}},	//   _aqtu, xtue, --, --, 
   {{0x8c455b3c,0xa3b8029e,0x70540354,0x00000000}},	//   келе, _تایر_, _пĕле, --, 
   {{0x10640014,0x4f8400fb,0x00000000,0x00000000}},	//   _شُرُ, _атаҡ, --, --, 
   {{0x798802d0,0x69d97b05,0x09e406ed,0xdb18007f}},	//   _aifw, ttue, воин, nsvè, 
   {{0x68282776,0x26c00009,0x2bcc74c8,0x69d85184}},	//   ködö, _rdio_, संहा, utue, 
   {{0xdd9001d9,0xfe6c04fb,0x69d97b06,0x66048ad5}},	//   _اوٕ_, _بگم_, rtue, _rrik, 
   {{0x69d97b07,0x66057b08,0x79880042,0xf8b401c6}},	//   stue, _srik, _difw, төч_, 
   {{0x69d97b09,0x25a00fac,0xda300022,0x00000000}},	//   ptue, _ptil_, рҵәы, --, 
   {{0xbb3800c8,0x59c401ec,0x2d88003e,0x25a00135}},	//   _קעני, _مينك, _éces_, _qtil_, 
   {{0x6b897b0a,0x25a0020b,0x35a000fd,0x644800d0}},	//   _higg, _vtil_, рарг, údio, 
   {{0x6b88af24,0x0ed002ab,0x660401f5,0xd5e402dd}},	//   _kigg, _हांड, _wrik, _ұйық, 
   {{0x6b897b0b,0x26c01e31,0xc60401c0,0x7988009f}},	//   _jigg, _udio_, _азий, _zifw, 
   {{0x25a17b0c,0x66057b0d,0x6b88d29e,0x98fc01e4}},	// [278c0] _util_, _urik, _migg, loĉa, 
   {{0xb5b4008d,0xdce800b8,0x00000000,0x00000000}},	//   _שליח_, _vidī, --, --, 
   {{0x03a4016c,0x51555036,0x6fb0007b,0xf7881cce}},	//   _шино, утту, لملا, _üçü_, 
   {{0x8fc419b6,0xa6b00154,0x217401a9,0x00000000}},	//   ازلن, _কাঁট, туғр, --, 
   {{0xf2d01229,0x52757b0e,0xdd917b0f,0x00000000}},	//   _דער_, _буру, حوت_, --, 
   {{0x61200205,0xac880023,0x6da00114,0x00000000}},	//   _gölp, _ሓዳሮም_, шиља, --, 
   {{0x6b889427,0x98fc01e4,0x2bb4007b,0x61f00205}},	//   _bigg, joĉa, ناية_, şilı, 
   {{0x6b880429,0x98fc01e4,0xe97001d9,0x79e400e5}},	//   _cigg, doĉa, ینٹھ, نوعہ_, 
   {{0x6b897b10,0x00000000,0x00000000,0x00000000}},	//   _digg, --, --, --, 
   {{0x6b89126e,0xf1b0011a,0x00000000,0x00000000}},	//   _eigg, ססת_, --, --, 
   {{0x6b897b11,0x98fc01e4,0xb178072b,0x64480419}},	//   _figg, goĉa, _spåk, údil, 
   {{0xfaa50aaf,0x6b897b12,0x00000000,0x00000000}},	//   _радо, _gigg, --, --, 
   {{0x7988031c,0xf65c03b2,0x6ad800cc,0x00000000}},	//   _tifw, vgæs_, _মোকো, --, 
   {{0x6b897b13,0xf8043bbd,0x98fc0115,0x63bc0166}},	//   _zigg, _ачин, boĉa, fsrn, 
   {{0x6b880083,0xf3657b14,0x00000000,0x00000000}},	//   _yigg, втан, --, --, 
   {{0x6b882878,0x0ed01f14,0xb4004f41,0x3228109a}},	//   _xigg, _हाइड, гүүд, мізм_, 
   {{0xb17812ed,0x7bc8002f,0x1b2400fe,0x1ae000cc}},	// [278d0] _upåk, hrfu, _বগাই_, _মোৱা, 
   {{0xe13425a2,0x00000000,0x00000000,0x00000000}},	//   ануы, --, --, --, 
   {{0x01e402f5,0xa18400ee,0xb06802e8,0x8afc013a}},	//   নিষদ, рытл, фраж_, hořa, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6b891176,0x7bc847b4,0x5dd4005b,0x00000000}},	//   _rigg, erfu, ающу, --, 
   {{0x6b897b15,0xaf5000c7,0x040400eb,0x00000000}},	//   _sigg, ынҵә, রহরী_, --, 
   {{0x6f840022,0xcb680063,0x00000000,0x00000000}},	//   _ауаж, наке_, --, --, 
   {{0xdcb800df,0x5f74036b,0x98fc0115,0x8c4400fb}},	//   _voĉa_, _ناقر, voĉa, кеһе, 
   {{0x7bc80165,0xc8b401c0,0x00000000,0x00000000}},	//   arfu, лсны, --, --, 
   {{0xa6b004c5,0x9cec0327,0x98fc01e4,0x6ad800fe}},	//   _কাইট, _རིགས, toĉa, _মোখো, 
   {{0xac100354,0x00000000,0x00000000,0x00000000}},	//   _тĕне_, --, --, --, 
   {{0x28a00490,0x7e6800d2,0x6b880194,0xf1bc46dc}},	//   _ख्रि, _ímpé, _uigg, _ová_, 
   {{0x48e57b16,0x4df8010f,0x00000000,0x00000000}},	//   _болв, עפֿא, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf1bc00e4,0x79500014,0xc6200154,0x00000000}},	//   _avá_, _دَوا, _পেশা_, --, 
   {{0x15cc1870,0x00000000,0x00000000,0x00000000}},	//   _ﺑﻪﺩﻩ, --, --, --, 
   {{0x56840014,0x66e446ee,0x00e57b17,0x02040006}},	// [278e0] _پگَہ, _боқа, лжан, ызан, 
   {{0xc0cc02d3,0x59280327,0x614400d1,0x7bc80042}},	//   _ኣቱም_, རིགས_, جىئە, yrfu, 
   {{0xbfc441e5,0x48e426e4,0x00000000,0x00000000}},	//   убек, ज्यो_, --, --, 
   {{0x2fc40124,0x00000000,0x00000000,0x00000000}},	//   ánga_, --, --, --, 
   {{0xfe457b18,0x44297b19,0xee3c00a2,0x00000000}},	//   ындо, lyb_, _ýýl_, --, 
   {{0x5bc40107,0x6ed00022,0x15cc02dd,0xacf015bf}},	//   ариҷ, ацәх, _ﺑﻪﺯﻩ, مسىت, 
   {{0x7b6402cd,0x00000000,0x00000000,0x00000000}},	//   лтие, --, --, --, 
   {{0x705022de,0x4cc40154,0x7bc80327,0x00000000}},	//   _انفا, ল্লু, rrfu, --, 
   {{0x44280122,0x4ad40d01,0xa2dc0037,0x388c03b9}},	//   hyb_, _धारव, _फान्, lәri_, 
   {{0xfa240156,0x80a83885,0xdb180022,0x00000000}},	//   ལགཏན_, टरटे, tuvó, --, 
   {{0x3b083804,0x8afc00bc,0x44284a11,0x00000000}},	//   _пежо_, mořn, jyb_, --, 
   {{0x0ba8215c,0x3cfc0fac,0xa9200153,0x15cc0220}},	//   _شامى_, _hatv_, _įžen, _ﺑﻪﺭﻩ, 
   {{0x3cfd7b1a,0x7c297b1b,0x00000000,0x00000000}},	//   _katv_, lyfr, --, --, 
   {{0x65957b1c,0x94d400d8,0x00000000,0x00000000}},	//   сару, јовц, --, --, 
   {{0x78b83a71,0x3cfc05da,0xa024015b,0xf1bc00bc}},	//   matv, _matv_, _যেসব_, _svá_, 
   {{0x78b97b1d,0xe2f80046,0xa2a00243,0x3cfc0171}},	//   latv, лесі_, गुल्, _latv_, 
   {{0x30a445c4,0x7c280368,0x200c0327,0x4428022e}},	// [278f0] грев, hyfr, _ġdia_, ayb_, 
   {{0x78b97b1e,0x7c2802d0,0xf1c83769,0x00000000}},	//   natv, kyfr, _ﺗﻪﻧﺘ, --, 
   {{0xf4880cb9,0xb178007c,0x35d8000d,0x00000000}},	//   _ящик_, _opåv, _बमड़, --, 
   {{0x78b80882,0x20682374,0x7c28015d,0xf1bd7b1f}},	//   hatv, ушуп_, dyfr, _tvá_, 
   {{0x78b80a28,0x386c00a9,0x9f5c012c,0x201c0162}},	//   katv, _lyfr_, ívá_, øvir_, 
   {{0x3cfd7b20,0x78b97b21,0x3cc400c7,0xdce800c0}},	//   _catv_, jatv, алшо_, _didį, 
   {{0x78b97b22,0xa158013e,0x7c297b23,0x00000000}},	//   datv, _сару_, gyfr, --, 
   {{0x3cfc01c8,0x8b257b24,0xabb00124,0xdef801ee}},	//   _eatv_, рдие, _ҳажә, _йыу_, 
   {{0x4a740137,0x67400023,0xee7005a2,0x44280210}},	//   шыкт, _ኣህዛብ, _уңды, zyb_, 
   {{0x78b97b25,0x2efc0c3a,0xa87400cf,0x00000000}},	//   gatv, _hauf_, лөйт_, --, 
   {{0x2efc0730,0x7c280c8c,0x3cf002ab,0xfbf4013e}},	//   _kauf_, cyfr, ंजरे_, _вохӯ, 
   {{0xc9f400dd,0xd5f4025c,0x7ae4022e,0x98ac0064}},	//   _نستع, _བརྡབ_, еktu, kidė_, 
   {{0x6ab97b26,0xebbc1682,0x78b8017a,0x99817b27}},	//   mauf, piḓa_, batv, _çiş_, 
   {{0x6ab97b28,0x2efd7b29,0xf53c007c,0x78b800cd}},	//   lauf, _lauf_, spån_, catv, 
   {{0xf77000dd,0x46a4008e,0xa30400cf,0x00000000}},	//   _ڈاٹ_, _кайв, бүне, --, 
   {{0x97c57b2a,0x6ab97b2b,0x0608023b,0xf77000e5}},	//   _اتوم, nauf, _аник_, _واٹ_, 
   {{0x47343e86,0x7c291ced,0x41c464e6,0xdb180162}},	// [27900] _مرکز, zyfr, شقاق, rrvø, 
   {{0x6ab97b2c,0xf0a400a8,0x4428014b,0x672401f4}},	//   hauf, икул_, pyb_, _hoij, 
   {{0x6ab97b2d,0x39417b2e,0xd174e380,0x672400ef}},	//   kauf, èksi_, сыты, _koij, 
   {{0x7c2c0639,0x2efc039a,0x6ab8000f,0x78b800d7}},	//   _übri, _cauf_, jauf, zatv, 
   {{0x78b80a28,0x3cfc0099,0x2efc4985,0x6ab97b2f}},	//   yatv, _patv_, _dauf_, dauf, 
   {{0xdcb8008f,0xd5f4031c,0xace467ba,0x98fc01e4}},	//   _voĉo_, _བརྣབ_, имча_, voĉo, 
   {{0x6ab8096b,0x78b97b30,0x2bc4213a,0xaca00241}},	//   fauf, vatv, ңләп_, _gbọl, 
   {{0x6ab97b31,0x5b1400a8,0xa3b80316,0x67241418}},	//   gauf, смит, घीय_, _noij, 
   {{0x78b97b32,0xada002f4,0x6da00305,0xeaf40472}},	//   tatv, _матл, _мита, شريت_, 
   {{0x70500050,0x7aa40073,0xdb18041e,0x9f9801e7}},	//   _انہا, _ट्रॅ, msví, háín_, 
   {{0x78b80882,0x672401f5,0x6ab8d6d1,0x6bd400f1}},	//   ratv, _boij, bauf, _نولس_, 
   {{0x78b80882,0x6ab8067c,0x7bc40374,0xb1782b96}},	//   satv, cauf, _ākuh, _upåv, 
   {{0x78b97b33,0x6aa40137,0x56940952,0x00000000}},	//   patv, _ئشمە, _қапт, --, 
   {{0xa5f80063,0x3bec06be,0x8afc013a,0x00000000}},	//   јеру_, _vəqf_, hořl, --, 
   {{0x644001e4,0xe804041c,0xa978011a,0xe978011a}},	//   ŝmin, षिणा_, _שאוכ, _שנוש, 
   {{0xdb181125,0x70ac07af,0x00000000,0x00000000}},	//   ksví, टर्ल, --, --, 
   {{0x2efd7b34,0xb2840108,0x00000000,0x00000000}},	// [27910] _rauf_, рывк, --, --, 
   {{0x2efc20ef,0x2fc41aac,0x6ab80161,0xdb180118}},	//   _sauf_, ángo_, zauf, dsví, 
   {{0x672400b5,0x00000000,0x00000000,0x00000000}},	//   _yoij, --, --, --, 
   {{0xdb1801a8,0xe80400dc,0x00000000,0x00000000}},	//   fsví, षिता_, --, --, 
   {{0xd1b01a4b,0x60dc0153,0xdb180321,0x00000000}},	//   _ریاک, _fcrm, gsví, --, 
   {{0x6e280ea0,0x7cb400d1,0x6ce410da,0x00000000}},	//   rygb, йқут_, ріде, --, 
   {{0xadc007ae,0xc0c0044e,0x6ab97b35,0x00000000}},	//   _trắn, ትኩም_, tauf, --, 
   {{0x4a7410de,0x5f940117,0x00000000,0x00000000}},	//   йыпт, _фитт, --, --, 
   {{0x6ab80730,0x9f4c0248,0x00000000,0x00000000}},	//   rauf, _èdá_, --, --, 
   {{0x6ab97b36,0x06800131,0x6724023a,0x2bc800fb}},	//   sauf, ﺩﻩﻧﯩ, _soij, _аудо_, 
   {{0x9f580ffb,0xa544001f,0x6ab80113,0x5f7401ed}},	//   _arrù_, _የሶማሊ, pauf, _طاہر, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc0c00023,0x00000000,0x00000000,0x00000000}},	//   _ስድሪ_, --, --, --, 
   {{0x42540032,0xc8c805d9,0x00000000,0x00000000}},	//   ҡтат, _صوبن_, --, --, 
   {{0x03a46ec2,0xdb180118,0x67240108,0x00000000}},	//   сибо, zsví, _toij, --, 
   {{0xded40023,0x03a401a9,0x00000000,0x00000000}},	//   ከድና_, _қимо, --, --, 
   {{0x26c400d7,0x00000000,0x00000000,0x00000000}},	// [27920] ómou_, --, --, --, 
   {{0xc0c0044e,0x40957b37,0xb69887e0,0x61200e78}},	//   _ስድራ_, срат, ndân, _hölz, 
   {{0x63e40150,0x0574dc96,0x407801f4,0xa2d80118}},	//   _بيجە, _پاکد, ущаю_, यलद्, 
   {{0xb1780423,0xee3401c6,0x8f4400d4,0xcf240633}},	//   _spåt, өнх_, охід, يرني, 
   {{0x12180024,0x00000000,0x00000000,0x00000000}},	//   _кюры_, --, --, --, 
   {{0x3f9403b7,0x7b640b8d,0xdb181d0e,0x71a0a0d5}},	//   _граѓ, әтке, rsví, _харз, 
   {{0x22417b38,0x9bf4003b,0x00000000,0x00000000}},	//   lzik_, ізич, --, --, 
   {{0x5a346d2a,0x61e57b39,0x9f3401d3,0xa9200153}},	//   жнит, otil, _بورڈ, _įžan, 
   {{0x22400007,0x3f840156,0x999810fc,0x403401ec}},	//   nzik_, mmou_, јкот_, _теңс, 
   {{0x3f840165,0x61e57b3a,0x2240030a,0xb9e40220}},	//   lmou_, itil, izik_, _ۇستى, 
   {{0x9c7c2e6a,0xd6d00014,0x3f840093,0xa6b0015b}},	//   _obči, وقد_, omou_, _কাজট, 
   {{0x61e57b3b,0x3f840699,0x973c3c52,0x37a803d4}},	//   ktil, nmou_, opći, _কিদৰ, 
   {{0x8b640491,0x3f8410d8,0x61e57b3c,0xf1c400bc}},	//   _بالم, imou_, jtil, _लिइन, 
   {{0x22417b3d,0xdce025a8,0x290c0205,0x00000000}},	//   dzik_, _kumı, ğlaç_, --, 
   {{0x61e57b3e,0x7a3c01e1,0x2240030a,0x490000e1}},	//   etil, _fàté, ezik_, _वोटो_, 
   {{0x3f857b3f,0x21380076,0x61e4a75a,0x6120013d}},	//   jmou_, _alrh_, ftil, _gölz, 
   {{0x388c9f20,0x25ac0122,0x224001d3,0x402c0092}},	// [27930] lər_, čilý_, gzik_, _በሚገኙ, 
   {{0xf2dc0109,0x3d00033f,0x612001d3,0xdb18000d}},	//   _imâm_, लयों_, _köly, muvõ, 
   {{0x0eb97b40,0x61e57b41,0xdb180037,0x388c0213}},	//   аулы_, atil, luvõ, nər_, 
   {{0x3f840399,0xa9200024,0x61200108,0x00000000}},	//   gmou_, ęžim, _möly, --, 
   {{0x388c0cc1,0xdea46071,0x2dc80114,0xdb180037}},	//   hər_, سیلی, ућен_, nuvõ, 
   {{0x388c0213,0xdef802dd,0x3f840419,0x00000000}},	//   kər_, _қыс_, amou_, --, 
   {{0xcda8cf73,0x628002f0,0xdb18000d,0xadb400ec}},	//   _چهره_, _úmor, huvõ, جهڙا_, 
   {{0x388c0cc1,0x49c97b42,0xaf346f80,0x1a6804d3}},	//   dər_, алин_, _ارست, ڕینی_, 
   {{0xa2dc134e,0xdb18000d,0x4cc400eb,0x00000000}},	//   _फास्, juvõ, ল্গু, --, 
   {{0x388c0cc1,0x47c48148,0xdb180037,0x00000000}},	//   fər_, обов, duvõ, --, 
   {{0x388c0cc1,0xb69887e0,0x4b200131,0x8af873e6}},	//   gər_, rdân, _يېتە, _внес_, 
   {{0x61e43606,0x224001d3,0x61200205,0x2d840254}},	//   ytil, yzik_, _döly, lmne_, 
   {{0x683c0248,0xdb1830e9,0x2d84208d,0x7ae800f1}},	//   _bádé, tuvö, omne_, _خونې_, 
   {{0x388c0cc1,0x3f840399,0x61e4dac1,0x00000000}},	//   bər_, zmou_, vtil, --, 
   {{0x97b4035b,0x61200139,0x388c03e3,0x87b801af}},	//   _есыш, _göly, cər_, _тулт_, 
   {{0x4910038e,0x26cc02d5,0x224001c6,0x00000000}},	//   ताको_, ėdos_, tzik_, --, 
   {{0x61e40af5,0x95d0010a,0xb44c0092,0x00000000}},	// [27940] util, _пăта_, _አድርጉ, --, 
   {{0x61e57b43,0xb178049f,0x22417b44,0x00000000}},	//   rtil, _spår, rzik_, --, 
   {{0x224001ed,0x071c83e3,0xbea808f0,0x00000000}},	//   szik_, _बचाव_, لهان_, --, 
   {{0xa5080075,0x644801f1,0xdce043bc,0x00000000}},	//   _ئىگە_, údiu, _rumı, --, 
   {{0x61e40cfe,0x388c03be,0xee800276,0xada002fb}},	//   qtil, zər_, мышо, _neúč, 
   {{0xdef802d3,0x388c00ac,0xed54dd5c,0xbfa80050}},	//   ወትካ_, yər_, ооч_, _نارٕ_, 
   {{0xbea4a4a9,0xdce0008e,0xafe000cf,0x00000000}},	//   _мавк, _qumı, _оорл, --, 
   {{0x1ae004c5,0x2fc40311,0x2d840381,0x388c0213}},	//   _খোজে_, ânge_, amne_, vər_, 
   {{0x98fc01e4,0x2ae80037,0x00000000,0x00000000}},	//   loĉi, _अउरु_, --, --, 
   {{0x388c00ac,0x6120023a,0xa96400e3,0xdce0008e}},	//   tər_, _pöly, يميم_, _tumı, 
   {{0x934c044e,0xadc00208,0xda700050,0x00000000}},	//   _ነጥብታ, _trản, بُک_, --, 
   {{0x388c00ac,0xdb18000d,0x00000000,0x00000000}},	//   rər_, tuvõ, --, --, 
   {{0x388c0213,0x00000000,0x00000000,0x00000000}},	//   sər_, --, --, --, 
   {{0xc5ec021a,0xdb180254,0x388c03b9,0x00000000}},	//   اړي_, ruvõ, pər_, --, 
   {{0xb864168d,0xe944035c,0xdef8010c,0x73480815}},	//   _باشو, _برنی, ለስን_, ачав_, 
   {{0xe8e4025c,0x61200139,0x00000000,0x00000000}},	//   _འཁོག, _zölx, --, --, 
   {{0xa2dc58c1,0x2d8403b2,0x00000000,0x00000000}},	// [27950] _फार्, ymne_, --, --, 
   {{0xc62003d4,0xc7ac00e5,0x00000000,0x00000000}},	//   _পইচা_, _جڑی_, --, --, 
   {{0xdb197b45,0x8d740131,0xd2f80139,0xab6003e0}},	//   msvæ, ۋاتا, _ленц_, çüky, 
   {{0xdb185266,0x0044004b,0x73c001af,0x00000000}},	//   lsvæ, سیقي_, _нәғе, --, 
   {{0x9f0401e2,0x0e4400c7,0x00000000,0x00000000}},	//   بونو, џьеҭ, --, --, 
   {{0xdb18332e,0x98fc01e4,0xd5f4031c,0xceb800bc}},	//   nsvæ, boĉi, _བརླབ_, _moři_, 
   {{0x9c7c0fb7,0x2d840427,0x614400db,0x89a801e0}},	//   _obču, rmne_, _تۉلە, әков_, 
   {{0x69cc35e0,0xc8dc000d,0x00000000,0x00000000}},	//   _दिदी, _माहट, --, --, 
   {{0xdb197b46,0x9f240131,0x9da802e8,0x6ca400f3}},	//   ksvæ, _تۈنۈ, _дъха_, _дреж, 
   {{0x7e480014,0xaaa8257b,0xec6817cd,0x00000000}},	//   _اسِہ_, _ट्रक, _крек_, --, 
   {{0xdb18037e,0xa2dc3507,0xfd2001d9,0xae0006b1}},	//   dsvæ, _फाल्, _سکوٝ, लिकन_, 
   {{0x29005946,0x8afc013a,0x00000000,0x00000000}},	//   žja_, koři, --, --, 
   {{0xdcb801e4,0x1a0000c7,0xdb1801a8,0xba98011a}},	//   _soĉi_, _аҿым, fsvæ, _הסני, 
   {{0xdb184c5d,0x00000000,0x00000000,0x00000000}},	//   gsvæ, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf1c42aa1,0xdcb801e4,0xdb1803b2,0x98fc01e4}},	//   _लिखन, _voĉi_, asvæ, voĉi, 
   {{0xa820066d,0xdb18005c,0x00c81a71,0x73300145}},	// [27960] _رکھن, bsvæ, йлак_, رىكا, 
   {{0x8de40150,0x06bc00d1,0x00000000,0x00000000}},	//   _ﺍﺴﺘﻁ, _ﻣﯩﻼﺩ, --, --, 
   {{0xc62003d4,0x3978010f,0x00000000,0x00000000}},	//   _পেচা_, צטענ, --, --, 
   {{0x8afc0118,0x00000000,0x00000000,0x00000000}},	//   boři, --, --, --, 
   {{0xdce8003d,0x52742078,0x13b0009e,0x741007d6}},	//   _jidħ, _журу, _ছিয়, _قویا, 
   {{0xdce8025c,0x00000000,0x00000000,0x00000000}},	//   _midħ, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4ed40323,0x6ac00131,0xa3e4107c,0x7ba00150}},	//   _оюут, ىقىم, _नमन_, _ﻏﺎﺼﺏ_, 
   {{0xadc00016,0xdce8025c,0x00000000,0x00000000}},	//   _trạn, _nidħ, --, --, 
   {{0xbd442781,0xbb341df2,0x69ccc305,0x2734004d}},	//   _عناي, ﺮﺍﻥ_, ácea, _hãnh_, 
   {{0xfbd17b47,0x37a81fbe,0xdb18005c,0x64580064}},	//   _ستا_, љтон_, vsvæ, _žvin, 
   {{0x6c7800c8,0x79a45aba,0x2fc40165,0x3ea400e5}},	//   _פראד, _ерке, ángi_, ncot_, 
   {{0x7ae05ba5,0x273401fb,0x3dc43afb,0xdb18005c}},	//   _icot, _mãnh_, nsow_, tsvæ, 
   {{0x27340016,0x7bcc0158,0x8afc00bc,0x3dc40009}},	//   _lãnh_, _åbus, voři, isow_, 
   {{0xdb18008c,0xb698006a,0x387801ed,0x6b8c0166}},	//   rsvæ, ndâk, _ápr_, _çigä, 
   {{0xf77000ec,0x63a80174,0x00000000,0x00000000}},	//   _ڪاڻ_, ídna, --, --, 
   {{0x69bc06ab,0xdb19782b,0x925887e6,0x645808a5}},	// [27970] लीपी, msvä, цаат_, _þvin, 
   {{0xdb180267,0x758001b9,0xb1441046,0x59d42e37}},	//   lsvä, _سیزم, سیزم_, _दिनर, 
   {{0x2fc57b48,0x7ae0f140,0x0f340133,0x61f40166}},	//   éng_, _ocot, وکرد, _ƅelä, 
   {{0xdb18049f,0x00000000,0x00000000,0x00000000}},	//   nsvä, --, --, --, 
   {{0x2fc401fb,0xdb1801f4,0x748c0116,0x5e58003b}},	//   ũng_, isvä, _ﻛﯜﭼﯩ, пиця_, 
   {{0xcfe4015b,0xe81c012c,0xe3b003ff,0x7d1c01e3}},	//   নববন, यममा_, _جری_, öpsp, 
   {{0xf2dc145e,0xdb1801e6,0x3dc40009,0x5cc401d5}},	//   _amâi_, ksvä, asow_, رغوق, 
   {{0x5f845f32,0xc9a8020f,0xae2000db,0xdb180419}},	//   _كۇلە, овие_, _كوزۉ, jsvä, 
   {{0xdb1801e6,0x9f5808a5,0x00000000,0x00000000}},	//   dsvä, _erró_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x74e00154,0x00000000,0x00000000,0x00000000}},	//   য়াউ, --, --, --, 
   {{0x29081161,0x2d9c00c5,0xdb180267,0x7ae000ae}},	//   śca_, _kuue_, gsvä, _gcot, 
   {{0x7bd000e2,0x2b4c0356,0x59d40037,0x00000000}},	//   ījuš, _imgc_, _दियर, --, 
   {{0x99d40330,0xdef8069d,0x00000000,0x00000000}},	//   _ستها, ለትና_, --, --, 
   {{0x29057b49,0x3ea57b4a,0x00000000,0x00000000}},	//   _iana_, ycot_, --, --, 
   {{0x29057b4b,0xdce8003d,0x3dc40009,0x00000000}},	//   _hana_, _tidħ, ysow_, --, 
   {{0x69d80618,0x2734004d,0x4104bbb8,0x00000000}},	// [27980] nuue, _rãnh_, мзав, --, 
   {{0x29057b4c,0x25a003d5,0x5274013e,0x40780212}},	//   _jana_, _iuil_, хусу, ощею_, 
   {{0x29057b4d,0x3518159d,0x2d9c0270,0x26c17b4e}},	//   _mana_, _ווינ, _auue_, _keio_, 
   {{0x29057b4f,0x2fc57b50,0x25a0f169,0x66040a73}},	//   _lana_, ânga_, _kuil_, _ksik, 
   {{0x26c003b7,0x88d402a6,0x25a03a6d,0x29057b51}},	//   _meio_, ত্যক, _juil_, _oana_, 
   {{0x29057b52,0x66057b53,0x25a17b54,0x7ae17b55}},	//   _nana_, _msik, _muil_, _scot, 
   {{0x6604009a,0x69cc012c,0x25a00100,0x200c3847}},	//   _lsik, ácen, _luil_, _édi_, 
   {{0xbf146886,0x69bc0034,0xdb18b529,0x79a40aac}},	//   _تورب, लीभी, ksvå, мрое, 
   {{0x29057b56,0x64580006,0x66040a49,0x69cc85a2}},	//   _bana_, _žvil, _nsik, šcen, 
   {{0x29057b57,0xdb183402,0xa96406ed,0x8cb400cd}},	//   _cana_, dsvå, миња_, _उभयो, 
   {{0x29041326,0x7d197b58,0x26c0015d,0xdb180267}},	//   _dana_, _ints, _beio_, tsvä, 
   {{0x29040086,0x25a17b59,0x66040165,0x7ae0009a}},	//   _eana_, _buil_, _bsik, _ucot, 
   {{0x29057b5a,0x25a17b5b,0xdb1807b9,0x7d1801c4}},	//   _fana_, _cuil_, rsvä, _knts, 
   {{0x25a0e614,0xdb1801e6,0x00000000,0x00000000}},	//   _duil_, ssvä, --, --, 
   {{0x6604cf3f,0x26c17b5c,0x395c0267,0x65940354}},	//   _esik, _feio_, mnts_, тару, 
   {{0x25a17b5d,0x26c0005a,0x2b14033f,0xe3b17b5e}},	//   _fuil_, _geio_, थाएँ_, شرف_, 
   {{0x29057b5f,0x7d18292b,0x25a0003a,0x395c07c5}},	// [27990] _yana_, _onts, _guil_, onts_, 
   {{0x29040c11,0x7d197b60,0xda0801fb,0xe0d17b61}},	//   _xana_, _nnts, _mỏ_, لزم_, 
   {{0x395d7b62,0x06e002f5,0x25a001a4,0x8f340a89}},	//   ints_, _বসতি, _zuil_, нежц, 
   {{0xf1a40d5f,0x7d197b63,0x69cc1098,0x7f400477}},	//   _कंपन, _ants, _दिली, ghoq, 
   {{0x2b4c0311,0x78a800e4,0xda080208,0x00000000}},	//   _rmgc_, _offv, _nỏ_, --, 
   {{0xe6dc16d1,0x00000000,0x00000000,0x00000000}},	//   _मञ्ज, --, --, --, 
   {{0x29043142,0x7f400117,0x00000000,0x00000000}},	//   _rana_, bhoq, --, --, 
   {{0x395d7b64,0xda0807ae,0x7f417b65,0x69cc0a90}},	//   ents_, _bỏ_, choq, áceo, 
   {{0x29057b66,0xc954e277,0xda08001e,0x26c15d1a}},	//   _pana_, етны, _cỏ_, _reio_, 
   {{0x25a075e2,0x26c01d47,0x5e8485a1,0xb6a17b67}},	//   _ruil_, _seio_, _русз, ғирл, 
   {{0x29057b68,0x6d400ea3,0x6f181590,0x6604ec3a}},	//   _vana_, mhna, _knuc, _ssik, 
   {{0x29057b69,0x395d7b6a,0x25a17b6b,0xaac401d5}},	//   _wana_, ants_, _puil_, _آتان, 
   {{0x29057b6c,0x26c17b6d,0x7d18045f,0xe9800116}},	//   _tana_, _veio_, _ynts, _иқин, 
   {{0x6d412a45,0x25a02a28,0x68e0014b,0x430800b2}},	//   nhna, _vuil_, _ucnd, ڻيءَ_, 
   {{0x6d400007,0x3bec0213,0xdb1801e3,0x83380395}},	//   ihna, _nəql_, ssvå, пчат_, 
   {{0x66057b6e,0x3f9d7b6f,0x41a813dc,0x25a17b70}},	//   _tsik, _étui_, зван_, _tuil_, 
   {{0x66057b71,0xe80477ca,0xda08004d,0x3024035b}},	// [279a0] _usik, षिका_, _xỏ_, ҭоуп_, 
   {{0xb1142033,0x6f1800cd,0xd98800d1,0x00000000}},	//   ىققا_, _anuc, ﺮﯨﺪﻩ_, --, 
   {{0x6d417b72,0x69c8009a,0xb8800162,0x69bc0073}},	//   dhna, _lvge, _íítr, लीती, 
   {{0x6f180332,0x657c00ad,0x6d40058a,0x52b000db}},	//   _cnuc, llrh, ehna, _نەفئ, 
   {{0xd2001fd6,0x7f40f7b1,0x2360033f,0x00000000}},	//   _күтк, rhoq, mnij_, --, 
   {{0x6d417b73,0xa3d40034,0x7f417b74,0x6f18003a}},	//   ghna, _हटा_, shoq, _enuc, 
   {{0x7ac4aec2,0x69c80579,0x6f180165,0x7f40013e}},	//   нспе, _avge, _fnuc, phoq, 
   {{0xff240801,0x7f400117,0x2b5c04cc,0x6d40058a}},	//   _ямбо, qhoq, gnuc_, ahna, 
   {{0xbc689a99,0x7d180129,0x6d400332,0x00000000}},	//   _کمان_, _tnts, bhna, --, 
   {{0x6d417b75,0x6da17b76,0xda08001e,0xada13d56}},	//   chna, _сифа, _vỏ_, _сафл, 
   {{0x2360068f,0x69c97b77,0xf9740023,0x19580022}},	//   knij_, _evge, _ከባቢኡ_, заҿы_, 
   {{0xda08001e,0x7bc8376e,0x6fd00210,0x00000000}},	//   _tỏ_, msfu, _डिसू, --, 
   {{0x29d051d1,0x98ac00fd,0x0ae80451,0x2360012d}},	//   _مينس, şlıy_, _آرمي_, dnij_, 
   {{0xd7f40124,0xf1c802dd,0x8afc01ef,0x00000000}},	//   _азкы, _ﺗﻪﻛﺘ, bořs, --, 
   {{0x241806a6,0x2360012d,0x5ed80154,0x5ed001f9}},	//   норы_, fnij_, ণ্যে, हणाऱ, 
   {{0x23617b78,0xa87802e4,0xf1a4234c,0xfbb000eb}},	//   gnij_, _מאור, ержн, _ঘটাত, 
   {{0xb000002b,0x00000000,0x00000000,0x00000000}},	// [279b0] _viḍa, --, --, --, 
   {{0x6f1800a3,0x2fc4019f,0xc0c0001f,0x7bc83402}},	//   _snuc, ângo_, _ስትል_, ksfu, 
   {{0x2c4400e8,0xf3c8007b,0x8d780092,0x00000000}},	//   _xёdd_, _عبده_, ይገባው_, --, 
   {{0x7bc8005c,0x6488009d,0x00000000,0x00000000}},	//   dsfu, _ясыг_, --, --, 
   {{0x22857b79,0x6d417b7a,0x7bc801a4,0x6f180306}},	//   _бург, thna, esfu, _vnuc, 
   {{0xf1bc01e1,0x48e400dc,0x6f18012d,0xdd9400db}},	//   _iwá_, ज्ञो_, _wnuc, гачы, 
   {{0xdfd80c04,0x7bc808ce,0xcb684e69,0x00000000}},	//   _път_, gsfu, маке_, --, 
   {{0x6d417b7b,0x5f957b7c,0x6f180e3c,0x00000000}},	//   shna, _бист, _unuc, --, 
   {{0xc8b53c01,0x6d4003ac,0xa2f8011a,0x00000000}},	//   ксны, phna, תמחה_, --, 
   {{0x7bc801bf,0x00000000,0x00000000,0x00000000}},	//   bsfu, --, --, --, 
   {{0x08881064,0x5f7401ed,0x0ba400c7,0x4c940108}},	//   ьбой_, _شاہر, _рызҭ, _рижс, 
   {{0x4a5400fd,0x48e40b7d,0xf1bc0248,0x00000000}},	//   _икес, ज्जो_, _owá_, --, 
   {{0x657c02c4,0x09e42ccd,0xc69001d9,0x090401a9}},	//   tlrh, _ролн, شِس_, _аплн, 
   {{0x1cdc025c,0x2360012d,0x00000000,0x00000000}},	//   འུར_, wnij_, --, --, 
   {{0x03a42c1d,0xf1bc0309,0x23600210,0x00000000}},	//   тибо, _awá_, tnij_, --, 
   {{0x98fc01e4,0x00000000,0x00000000,0x00000000}},	//   rnĉe, --, --, --, 
   {{0x23617b7d,0xf2a0005b,0x00e40121,0x00000000}},	// [279c0] rnij_, риуп, кжан, --, 
   {{0x05741473,0xf53c0267,0xec080055,0x00000000}},	//   _جابد, spår_, _oḿ_, --, 
   {{0x838810f5,0xadc00241,0x14d8008f,0x101400d4}},	//   _обов_, _irẹn, _אַרמ, льця, 
   {{0xa2dd7b7e,0x53480408,0x00000000,0x00000000}},	//   _फाट्, _пăхă, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7bc811ad,0xdb1803b2,0x00000000,0x00000000}},	//   tsfu, lsvø, --, --, 
   {{0x6d440227,0xf1bc0085,0x9af800b8,0x7bc80221}},	//   _ŋjac, _zwá_, _akāṇ, usfu, 
   {{0x8d9c001f,0xff2400b5,0x7bc801e3,0xdb18c300}},	//   ገባቸው_, _forと, rsfu, nsvø, 
   {{0x7bc97b7f,0xac80013d,0x00000000,0x00000000}},	//   ssfu, лгәл, --, --, 
   {{0xec1005d9,0x7bc803cd,0x00000000,0x00000000}},	//   _ھوند, psfu, --, --, 
   {{0xec1000b2,0x313400d9,0xdb180162,0x00000000}},	//   _پوند, דריך_, ksvø, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x36880139,0x59f80276,0xee34010a,0x00000000}},	//   ьсон_, _челя_, _тнă_, --, 
   {{0x628000d2,0x00000000,0x00000000,0x00000000}},	//   _úmoy, --, --, --, 
   {{0xdee0001f,0xb37401d5,0xe4540024,0x00000000}},	//   ኑንና_, ندرش, акры, --, 
   {{0xe2f80220,0x3204033f,0xd83802e2,0xd6f000fe}},	//   кесі_, łnym_, myč_, _জোৰা_, 
   {{0x50f57b80,0x24d8009e,0x2258c23e,0x5214824d}},	// [279d0] лзат, দ্ধহ, виты_, ыдат, 
   {{0x1cdc031c,0xf77c036e,0x00000000,0x00000000}},	//   འུས_, llç_, --, --, 
   {{0x66740502,0x4fd416a4,0xd838033b,0xa0c416ac}},	//   _مدیر, ужет, nyč_, شينو, 
   {{0x51857b81,0xd25000ec,0x4ec000eb,0xdb0c01e1}},	//   туға, _هنج_, উল্ল, _òkèb, 
   {{0xdd2c0006,0x00000000,0x00000000,0x00000000}},	//   _dėžu, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x0c78044e,0x764800dd,0x209800c7,0x9f580100}},	//   _ኣዳራሽ_, _ügyf, _акры_, _oprè_, 
   {{0xb698006a,0x9f340220,0x00000000,0x00000000}},	//   ndâs, _кесі, --, --, 
   {{0x9f3410da,0xea6000e5,0x00000000,0x00000000}},	//   _теті, جھای, --, --, 
   {{0x9f580699,0xb338496e,0x29c400db,0x00000000}},	//   _aprè_, _hiçd, нтүү_, --, 
   {{0x77c405f5,0x9cc80166,0x6ec57b82,0x00000000}},	//   ллэг_, _шыта_, ारपु, --, 
   {{0xf4e000fe,0x00000000,0x00000000,0x00000000}},	//   য়োব, --, --, --, 
   {{0x6ab97b83,0x7f3800c8,0x17c8013e,0x310000cd}},	//   mbuf, גערו, нгӯи_, रजाः_, 
   {{0x58fc0135,0x35a17b84,0x69d801c4,0x6d080327}},	//   _ཐིགས_, сарг, mrue, _གལཆེ_, 
   {{0x443d7b85,0x09e40131,0xdb4c0133,0x54340354}},	//   át_, _роһн, _رێی_, ахту, 
   {{0x6ab8005c,0x85e806ed,0x01085598,0x443c031c}},	//   nbuf, _здив_, کترو_, ġt_, 
   {{0xdb197b86,0x69d8003a,0x00000000,0x00000000}},	// [279e0] rsvø, nrue, --, --, 
   {{0x88d4015b,0x6b880076,0xe4e40137,0xb6980129}},	//   ত্রক, _lhgg, _өсүү, rdât, 
   {{0xfe701e0e,0xb33800a2,0x00000000,0x00000000}},	//   ڭدا_, _biçd, --, --, 
   {{0x69d815e7,0x59d401ad,0xfe44156c,0xd1e40137}},	//   krue, _दिलर, лнео, ايەۋ, 
   {{0xf59040ec,0xd83802bd,0x00000000,0x00000000}},	//   _خلیج, zyč_, --, --, 
   {{0x6b880083,0xfca8004b,0xdd957b87,0x69d88e64}},	//   _ahgg, راتو_, шалы, drue, 
   {{0xcead7b88,0x7c642310,0x2bb400ae,0x00000000}},	//   _мә_, داشل, هاية_, --, 
   {{0x20197b89,0x69d801c7,0x58fc031c,0xb338010e}},	//   _irri_, frue, _ཐིངས_, _giçd, 
   {{0x69d97b8a,0x00000000,0x00000000,0x00000000}},	//   grue, --, --, --, 
   {{0x6ab80083,0xd8380100,0x57f45788,0x00000000}},	//   abuf, tyč_, апот, --, 
   {{0x9f586ede,0x79a402dd,0xb33800a2,0x798802d0}},	//   _apré_, _өрле, _hiçe, _vhfw, 
   {{0x56957b8b,0xfaa57b8c,0x69d86dff,0xb3380724}},	//   иант, _садо, brue, _kiçe, 
   {{0x69d97b8d,0x7988035a,0xd83802e2,0x69c40165}},	//   crue, _thfw, syč_, ņjer, 
   {{0x20197b8e,0xb3380139,0x798802d0,0xf1a400d1}},	//   _orri_, _miçe, _uhfw, ғран, 
   {{0xa3e418e5,0x27f40232,0xf3641f10,0x53341669}},	//   _नमः_, čená_, гтан, аевт, 
   {{0x96341436,0x00000000,0x00000000,0x00000000}},	//   _вниц, --, --, --, 
   {{0x20194233,0xb3380724,0x94d40153,0x00000000}},	// [279f0] _arri_, _niçe, _копц, --, 
   {{0xaf50052f,0xe6100150,0x3c9000d1,0x00000000}},	//   әндә, _ءشي_, ﻟﯘﺑﻰ_, --, 
   {{0x8eb40075,0x69d80369,0x00000000,0x00000000}},	//   لماش, zrue, --, --, 
   {{0x8e1400e4,0xb3382ac2,0x5f942143,0x8db40153}},	//   идец, _biçe, бихт, аскі, 
   {{0x20197b8f,0x6f8c0150,0xdfd40150,0x00000000}},	//   _erri_, _ﺑﯟﻋﺎ_, _қоты, --, 
   {{0x32d80241,0x69d80200,0xf12400c0,0x00000000}},	//   _fàyà_, vrue, _сьмо, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb3380ab7,0x00000000,0x00000000,0x00000000}},	//   _hiçb, --, --, --, 
   {{0xdef8010b,0xdd9001d9,0xb8b001e1,0x8934007b}},	//   _щыр_, _کوٕ_, _tẹlè, لعدا, 
   {{0x69d97b90,0xbb340ae5,0x32d80241,0x3f9c032e}},	//   rrue, ﺮﺍﻕ_, _yàyà_, _étur_, 
   {{0xb3a800cc,0x9f5801e7,0x59d4000d,0x00000000}},	//   গীতজ, _spré_, _दिअर, --, 
   {{0xab6001ec,0x69d97b91,0x00000000,0x00000000}},	//   _دۇبى, prue, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb200108,0x00000000,0x00000000,0x00000000}},	//   ötöl, --, --, --, 
   {{0x6b440139,0x4808549f,0x00000000,0x00000000}},	//   _eñge, _рейн_, --, --, 
   {{0xdef81540,0x25a80451,0x00000000,0x00000000}},	//   ወትን_, _مگسي_, --, --, 
   {{0xb7780375,0xb698002d,0x201801ab,0xb11c01e1}},	// [27a00] _שאפש, leân, _srri_, _ṣẹbọ_, 
   {{0x6d440227,0x20180327,0x06e4000d,0x3120009d}},	//   _ŋjan, _prri_, _काँव_, одуг, 
   {{0x3bec06be,0x7f9400c7,0x00000000,0x00000000}},	//   _təqi_, ҳаҧх, --, --, 
   {{0xd5a400e1,0x00000000,0x00000000,0x00000000}},	//   _गूँज, --, --, --, 
   {{0xb3380139,0x59d400bc,0x00000000,0x00000000}},	//   _qiçe, _दिइर, --, --, 
   {{0x764801ed,0x2ae00316,0xb338004e,0xed4c00ec}},	//   _ügye, _गाउँ_, _viçe, وپن_, 
   {{0x30240251,0x2018102c,0x61e57b92,0xbaa40e46}},	//   _корп_, _urri_, luil, қуққ, 
   {{0x59d4000d,0x09bc00eb,0x00000000,0x00000000}},	//   _दिआर, _আমজা, --, --, 
   {{0xd5a40c2e,0x61e403d5,0xfce57b93,0xeb940640}},	//   _गूंज, nuil, _возо, шић_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb8cc023e,0xed4c0811,0x00000000,0x00000000}},	//   _कल_, _تپل_, --, --, 
   {{0x61e57b94,0x2fc4006a,0x00000000,0x00000000}},	//   kuil, ângi_, --, --, 
   {{0x2f94008f,0x61e57b95,0x00000000,0x00000000}},	//   יכטן_, juil, --, --, 
   {{0x61e57b96,0x00000000,0x00000000,0x00000000}},	//   duil, --, --, --, 
   {{0xf2c451e4,0x09283092,0xc5ec004b,0x23bc0248}},	//   исан, _حسني_, وړی_, _ràjò_, 
   {{0xadc000e4,0x61e57b97,0x2c1400dc,0x660c01f4}},	//   _arẽn, fuil, थितं_, älkä, 
   {{0x30a57b98,0x64580064,0xe214009d,0x00000000}},	// [27a10] арев, _žvit, омты, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x61e4062c,0x764801d3,0x6594009f,0x00000000}},	//   auil, _ügyb, _بجير, --, 
   {{0xb8d0025c,0x00000000,0x00000000,0x00000000}},	//   _ྐུ_, --, --, --, 
   {{0x61e57b99,0xefe802d3,0x23bc0248,0x99840064}},	//   cuil, _መኣዲ_, _tàjò_, nymų_, 
   {{0x8c440220,0xc1e00150,0x1144009f,0x00000000}},	//   йеле, _رۋمي, _اَسُ, --, 
   {{0xa1593758,0x4c14007b,0xdfd400c0,0x00000000}},	//   _тару_, إبتس, _моры, --, 
   {{0x99840006,0x25e801f9,0x00000000,0x00000000}},	//   kymų_, _जमली_, --, --, 
   {{0xba203740,0x50440150,0x00000000,0x00000000}},	//   здык, _теңб, --, --, 
   {{0x1a6804fb,0x99840024,0xb304031c,0xdcf800f2}},	//   جیهی_, dymų_, _ཅིའང_, _نرمش_, 
   {{0x61e57b9a,0x48c00032,0x00000000,0x00000000}},	//   zuil, оҙҙа, --, --, 
   {{0x59c40316,0x00000000,0x00000000,0x00000000}},	//   लीहर, --, --, --, 
   {{0x9b740491,0x389402d3,0x1b740451,0x04b40024}},	//   _بالص, _መዓልቱ_, _بدلج, йсвя, 
   {{0xdef81e38,0x9f584d72,0x61e4049b,0x201c0158}},	//   ወትና_, _aprì_, vuil, åvik_, 
   {{0x394000da,0x98b80034,0x80dc015b,0x6d440327}},	//   īkst_, órą_, ন্ড্, _ċjal, 
   {{0x61e57b9b,0x3940005f,0xe7941550,0x59c413e0}},	//   tuil, ūkst_, _باتک, लीवर, 
   {{0x2fdc0607,0x672400f3,0xa3e409bb,0xe81c00bc}},	// [27a20] _āuga_, _inij, _नमक_, यमका_, 
   {{0x40942db2,0x4428010a,0x58fc0327,0x672402f0}},	//   брет, pxb_, _ཐིབས_, _hnij, 
   {{0x61e57b9c,0x67257b9d,0xe04400d1,0xcfa80244}},	//   suil, _knij, әнҗи, لانم_, 
   {{0x80c40316,0x61e57b9e,0x91e400b5,0x84640092}},	//   िरहे, puil, moのc, ቸዋለን_, 
   {{0x67241710,0x7c8401ec,0x00000000,0x00000000}},	//   _mnij, әуле, --, --, 
   {{0x1c3805a2,0x398003b2,0xd1740153,0x00000000}},	//   излы_, rðsk_, _дысы, --, 
   {{0xafe05b7f,0xf2dc0142,0x63bc007f,0xa6e000cc}},	//   _норл, _mlân_, nprn, য্যট, 
   {{0x1de05347,0x3f80032e,0x0c4000c7,0x00000000}},	//   _निपत, _óku_, ьҭхо, --, 
   {{0xcf2412ea,0x00000000,0x00000000,0x00000000}},	//   _ظرفي, --, --, --, 
   {{0x67257b9f,0xb33801df,0xee3400a8,0xdd900133}},	//   _anij, _miça, _уну_, _کوڕ_, 
   {{0xdecc0201,0xb3380561,0xdb080200,0xb178010f}},	//   _ቢሆን_, _liça, _judë, רטיר, 
   {{0x0ba80075,0x99840006,0x7f400309,0x00000000}},	//   _ئالى_, tymų_, nkoq, --, 
   {{0xb3381497,0x58d4014b,0x59c40210,0x00000000}},	//   _niça, _долт, लीशर, --, 
   {{0x79e801d9,0x00000000,0x00000000,0x00000000}},	//   _لوچہ_, --, --, --, 
   {{0x82540020,0x7f4020ac,0x395d7ba0,0x64580153}},	//   _ለመረዳ, kkoq, mits_, _žvir, 
   {{0x32283334,0x67241710,0xb3392dcf,0x65b000e4}},	//   лізм_, _gnij, _biça, ẽhag, 
   {{0xd1340063,0x22940395,0x00000000,0x00000000}},	// [27a30] онаћ, зитя, --, --, 
   {{0x395d7ba1,0x30a43fbb,0xe00402ab,0xddd41432}},	//   nits_, срав, रबंद_, _şaşm, 
   {{0x05957ba2,0x395c003e,0x53340902,0x9f0400f1}},	//   _بايگ, iits_, _дент, ګونو, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8d740a2c,0x395d7ba3,0x824002d3,0xb628037e}},	//   ياتا, kits_, _ጭርሖታ, _ｔｂ_, 
   {{0x395c002d,0x6ce402dd,0x0bb40395,0x425000e5}},	//   jits_, сіде, ощия, _کچہر, 
   {{0x395d7ba4,0x2d48143a,0xfe6c023f,0xc0c00b82}},	//   dits_, _røed_, _یگه_, ስኩም_, 
   {{0xdb080ba1,0xa2bc00dc,0x00000000,0x00000000}},	//   _judè, षुप्, --, --, 
   {{0x1de04c83,0xdb080ba1,0x395d7ba5,0x5f94030d}},	//   _नियत, _mudè, fits_, _хитт, 
   {{0x395d7ba6,0x67257ba7,0xfe540014,0xeb9406b3}},	//   gits_, _snij, _بیٖب_, шиқ_, 
   {{0x1cb83765,0x6d417ba8,0x5c04009d,0xc908012d}},	//   _طالب_, mkna, _няца, _वसीम_, 
   {{0x6d417ba9,0x613c0092,0x47580108,0x00000000}},	//   lkna, _በፊታች, рроя_, --, 
   {{0x395d7baa,0xd9b00220,0xf2dc0142,0x00000000}},	//   bits_, _كەيد, _plân_, --, 
   {{0x6d417bab,0xdb08067c,0x395d7bac,0x03a498cc}},	//   nkna, _audè, cits_, живо, 
   {{0xdecc001f,0x6d40a194,0x044403fb,0xb33803e3}},	//   _ቢሆኑ_, ikna, цевн, _siça, 
   {{0x8254001f,0x2b5c054e,0xf2dc015d,0x6d400254}},	//   _ለመርዳ, niuc_, _wlân_, hkna, 
   {{0x6d417bad,0x00c8035b,0x00000000,0x00000000}},	// [27a40] kkna, илак_, --, --, 
   {{0x6d4141af,0xdb080200,0x00000000,0x00000000}},	//   jkna, _pudë, --, --, 
   {{0x6d417bae,0x82a57baf,0x657c0158,0x201c06ea}},	//   dkna, _манж, morh, ívi_, 
   {{0x657c18f7,0x395c04cc,0xb3380166,0x6d4002d0}},	//   lorh, zits_, _hiçn, ekna, 
   {{0x395c022f,0xb21801bf,0xb3380166,0x98fc00df}},	//   yits_, _hyæn, _kiçn, liĉe, 
   {{0x657d7bb0,0x395c0137,0x6d400fac,0x23600009}},	//   norh, xits_, gkna, liij_, 
   {{0x224000dd,0x395d7bb1,0x3bec0213,0xb604032e}},	//   lyik_, vits_, _rəqs_, _kváð, 
   {{0x5a340a31,0xdb08003e,0x657d7bb2,0x395cb3fd}},	//   знит, _kudé, horh, wits_, 
   {{0x395d7bb3,0x657d7bb4,0x22417bb5,0x3f840421}},	//   tits_, korh, nyik_, mlou_, 
   {{0x6d400385,0x3f857bb6,0xdb0804d4,0xed540354}},	//   ckna, llou_, _mudé, _доу_, 
   {{0x213828b5,0x395c6a3a,0x7790030f,0x2b5c0356}},	//   _morh_, rits_, ویتا, biuc_, 
   {{0x2b5d7bb7,0x2138030a,0x58fc031c,0x395cffe4}},	//   ciuc_, _lorh_, _ཐིམས_, sits_, 
   {{0x657c6ab9,0x3f840198,0xdb080ba1,0x395c6b56}},	//   forh, ilou_, _rudè, pits_, 
   {{0x213801ee,0x22401e92,0x657c7aaf,0xdb08007f}},	//   _norh_, dyik_, gorh, _sudè, 
   {{0x6d440227,0x3f853d0a,0x27f000d7,0x00000000}},	//   _ŋjak, klou_, ľaní_, --, 
   {{0x3f840369,0x27f000d0,0x00000000,0x00000000}},	//   jlou_, žaní_, --, --, 
   {{0x657cf24e,0x88f0004b,0x224001ed,0xe2c800f1}},	// [27a50] borh, _غړیت, gyik_, زولو_, 
   {{0xdb080789,0x80dc05ac,0x6b700356,0xdca400db}},	//   _dudé, ন্স্, măge, _لۉ_, 
   {{0x2fc404fb,0x6b08025c,0x213828b5,0x98b8033f}},	//   èng_, _ཁྲའོ_, _dorh_, órę_, 
   {{0x3f84002e,0xdea00051,0x6d4002d0,0x00000000}},	//   glou_, _pmmư, wkna, --, 
   {{0xdd1401a2,0xdb08011f,0x228411dc,0x21380165}},	//   _dĺžk, _gudé, _жург, _forh_, 
   {{0x7b840075,0x00000000,0x00000000,0x00000000}},	//   ۋايە, --, --, --, 
   {{0x6d417bb8,0x3f857bb9,0x80a005c0,0x00000000}},	//   rkna, blou_, _कृपे, --, 
   {{0x3f8400f7,0x93f00135,0x6d409442,0xdb08020c}},	//   clou_, _བྱབྱ_, skna, _yudé, 
   {{0xb3380ba1,0x2b5c0311,0x30d406ba,0x6d40007c}},	//   _liço, riuc_, ﻟﮕﻪﻧ, pkna, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb3387d4f,0x657d7bba,0xfcc0013d,0x00000000}},	//   _niço, vorh, _чәчм, --, 
   {{0x657d69d1,0x00000000,0x00000000,0x00000000}},	//   worh, --, --, --, 
   {{0x657d7bbb,0xf1a40c2e,0xeb0401ad,0x2d840037}},	//   torh, _कंगन, वजीत_, olne_, 
   {{0xb3386f35,0xdb08013a,0x00000000,0x00000000}},	//   _biço, _rudé, --, --, 
   {{0x764801d3,0xb3380139,0x2d857bbc,0x657c03ac}},	//   _ügyn, _viçn, ilne_, rorh, 
   {{0x21f400af,0xdb0800d8,0x00000000,0x00000000}},	//   täh_, _pudé, --, --, 
   {{0x657d12f8,0xa2e43174,0x2d84013d,0x00000000}},	// [27a60] porh, गलौज_, klne_, --, 
   {{0x40945882,0x66057bbd,0xb3382093,0xdb2401e7}},	//   прет, _ipik, _hiçl, ásúi, 
   {{0x3f857bbe,0xbea8038b,0x2d840030,0x26140254}},	//   tlou_, مهان_, dlne_, दिकी_, 
   {{0x3f841529,0x2d857bbf,0x62240150,0xce3400f1}},	//   ulou_, elne_, _قوجە, ژونک, 
   {{0x6e9057d7,0xb3380166,0xfaa41719,0x00000000}},	//   ىلما, _miçl, үшин, --, 
   {{0x3f857bc0,0x66057bc1,0x7c3c1455,0x00000000}},	//   slou_, _mpik, øpro, --, 
   {{0x200c00a7,0x6604003e,0x3f840306,0x00000000}},	//   _èdi_, _lpik, plou_, --, 
   {{0x2d857bc2,0x66057bc3,0x9f58003a,0x9f940124}},	//   alne_, _opik, _uprà_, _цыгә, 
   {{0xdcf90a96,0xa92000d0,0x61e57bc4,0xee34068e}},	//   lovč, _šľap, nril, _ент_, 
   {{0x61e57bc5,0x3254011a,0x2ba40051,0x1ec801ec}},	//   iril, פסים_, _cđcs_, _ылғи_, 
   {{0x66057bc6,0x2d1404d3,0xdcf86bcb,0x71180a7c}},	//   _apik, _رکوک_, novč, זויפ, 
   {{0x7d080162,0x00000000,0x00000000,0x00000000}},	//   lefs, --, --, --, 
   {{0xdcf801fa,0x61e400df,0xf3140116,0xb33806be}},	//   hovč, jril, үнгә_, _siço, 
   {{0x61e57bc7,0xdcf828b5,0x6b700356,0xd4840150}},	//   dril, kovč, răge, _ﺫﻜﺭﻨ_, 
   {{0x66057bc8,0x96f80228,0x61e57bc9,0x00000000}},	//   _epik, _дейт_, eril, --, 
   {{0x7d0805e4,0xd7f8054e,0xb3397bca,0x61e57bcb}},	//   hefs, mtă_, _viço, fril, 
   {{0x61e57bcc,0xd7f8084c,0xf77d7bcd,0x7d080200}},	// [27a70] gril, ltă_, moç_, kefs, 
   {{0x611496da,0xf77c004e,0xc0e40014,0x00000000}},	//   ндуу, loç_, وہُن_, --, 
   {{0xd7f80262,0x61e43401,0xb3380205,0xa3d4030d}},	//   ntă_, aril, _hiçm, _поэч, 
   {{0xd7f80276,0xa2bc146b,0xb3380166,0x00000000}},	//   ită_, षुद्, _kiçm, --, 
   {{0x61e57bce,0x00000000,0x00000000,0x00000000}},	//   cril, --, --, --, 
   {{0xc2100302,0xdcf801a6,0x644812ed,0xaf34cdc2}},	//   _שהם_, bovč, ødig, _کرست, 
   {{0xa19539ad,0xf77c0790,0xa07400f3,0x00000000}},	//   _чарч, koç_, _згрч, --, 
   {{0xdb18000d,0x00000000,0x00000000,0x00000000}},	//   ksvõ, --, --, --, 
   {{0x6ca40046,0x2d840030,0xb698002d,0x8cf4010a}},	//   _ереж, plne_, nfâd, _озац, 
   {{0x6f0859fc,0xd7f8054e,0x00000000,0x00000000}},	//   legc, ftă_, --, --, 
   {{0x66057bcf,0xb3380205,0x00000000,0x00000000}},	//   _spik, _piçl, --, --, 
   {{0x61e57bd0,0x6f08379d,0xb3382ca8,0x00000000}},	//   yril, negc, _biçm, --, 
   {{0xd7f8084c,0xdb08026c,0x6b98000d,0x764800e5}},	//   ată_, _mudì, mmug, _ügyl, 
   {{0x61e57bd1,0xb698145e,0x6b997bd2,0x00000000}},	//   vril, ndây, lmug, --, 
   {{0x35a0bd8c,0xd7f8084c,0x833853e9,0xf77c00cf}},	//   тарг, ctă_, очат_, boç_, 
   {{0x378406bb,0x61e57bd3,0xf77c00cf,0x6b997bd4}},	//   _общо_, tril, coç_, nmug, 
   {{0x61e57bd5,0x6604aa77,0x6b980099,0x826801c0}},	// [27a80] uril, _upik, imug, цаав_, 
   {{0x61e41e56,0x6b982ad7,0x93c40208,0x363400e5}},	//   rril, hmug, _khắ, _آرٹس, 
   {{0x02c40228,0x1de000dc,0x98fc01e4,0x5f0401f0}},	//   _ойно, _निहत, niĉa, нҷва, 
   {{0x61e4041a,0xdcf8009b,0xc4f800dd,0xdb082dba}},	//   pril, rovč, _اٹھا_, _utdø, 
   {{0xa46402d3,0xf2d0008f,0xf1a4c59b,0xd20001ee}},	//   _ፍልጠት, _בער_, _कंचन, _йүтк, 
   {{0x6b980618,0xdcf80841,0xc0d57bd6,0x6bd00116}},	//   emug, povč, _زيرب, ھتىر, 
   {{0x69c801d9,0x6f0801f0,0x6bd02002,0xf1a40cf1}},	//   _awge, begc, پتىر, _कूटन, 
   {{0x7d097bd7,0x6b987bad,0x48c007dd,0xda140640}},	//   sefs, gmug, қәша, едињ, 
   {{0x44e402a6,0x58d57bd8,0xf1bc00ae,0xe9b401d3}},	//   খ্যক_, нопт, _grád_, وچوں_, 
   {{0xd8f800d6,0x79980218,0x6aa80072,0x6b981418}},	//   чної_, umtw, _eggf, amug, 
   {{0xdb0800e4,0xbc6803b6,0x2d4828b3,0x93c4004d}},	//   _hudí, _بمان_, _køen_, _chắ, 
   {{0xd7f800a8,0x3b0801af,0x00000000,0x00000000}},	//   rtă_, _федо_, --, --, 
   {{0xd7f800a8,0xdb097bd9,0x2d480158,0xf77c004e}},	//   stă_, _judí, _møen_, roç_, 
   {{0xd7f8084c,0xf8040276,0x00000000,0x00000000}},	//   ptă_, _жчин, --, --, 
   {{0x6f0801f0,0xe8900124,0xdb100162,0x24180a89}},	//   yegc, _иашь, _ófól, моры_, 
   {{0x56957bda,0x95d81d0f,0x248c000d,0xa73800ae}},	//   _пайт, _едит_, üdma_, _يثير_, 
   {{0xb3397bdb,0x851802e5,0xdb0802f0,0x92580120}},	// [27a90] _hiçk, _फोकट_, _nudí, чаат_, 
   {{0x6b98005f,0xb33800fd,0x00000000,0x00000000}},	//   zmug, _kiçk, --, --, 
   {{0xdb097bdc,0x2d4800cc,0xd3702f84,0xa1e800d1}},	//   _pudì, _bøen_, _مهد_, كرەك_, 
   {{0xdb080122,0xc49802e4,0xb3380166,0x555400f2}},	//   _budí, _משתת, _miçk, _آپگر, 
   {{0x7bd8020c,0xdcec02b1,0x00000000,0x00000000}},	//   _avtu, _ōhāk, --, --, 
   {{0xf1bcd6bb,0x6f080117,0x1de000cd,0x00000000}},	//   _itá_, segc, _निरत, --, 
   {{0x1b18015b,0x66e00037,0x6b98031c,0x6f7400e5}},	//   থানে_, _खएलक_, tmug, _قارء, 
   {{0x49c80311,0x394c0327,0x0b582d55,0x2d4801bf}},	//   плин_, _alfs_, ярлы_, _gøen_, 
   {{0xca840323,0x7bd802d0,0x6b98fae8,0x00000000}},	//   эгий, _evtu, rmug, --, 
   {{0x98fc0115,0x48780395,0x00000000,0x00000000}},	//   tiĉa, зсмя_, --, --, 
   {{0x1da805f9,0x0aa0010b,0x482400cf,0x00000000}},	//   _छूटत, _өңкү, رىحق, --, 
   {{0x44243351,0xf2dc2776,0xb338044e,0x28bc0b7c}},	//   _čo_, _ndâ_, _diçk, _श्रि, 
   {{0xdb08056a,0x15b81c3c,0x00000000,0x00000000}},	//   _xudí, дысы_, --, --, 
   {{0xf2dc0548,0x93c4004d,0xb3380432,0x00000000}},	//   _adâ_, _thắ, _hiçh, --, 
   {{0xf1bc06d5,0xb3394db1,0xdcf81a14,0x8cc000bc}},	//   _atá_, _kiçh, novā, रुयो, 
   {{0xc7957bdd,0x00000000,0x00000000,0x00000000}},	//   _ярлы, --, --, --, 
   {{0xa3dc45c7,0xb0c802ab,0xafe001d5,0xd04406be}},	// [27aa0] _ठिक_, िरंग, ғочл, mahə, 
   {{0x2d484c5d,0x6b2c0327,0x2b4c0042,0xd04403e3}},	//   _søen_, _ཨོའོ_, _llgc_, lahə, 
   {{0xf1bc45a7,0xdb0801ef,0x63842cdd,0x00000000}},	//   _etá_, _sudí, _аҳва, --, 
   {{0x359002d3,0xa30401ec,0xd04406be,0x00000000}},	//   _ዞባታት_, _шүбе, nahə, --, 
   {{0xee80c133,0x4f640f54,0xfe457bde,0x3240014b}},	//   лышо, خالف, эндо, _беяг, 
   {{0xee3401c0,0xe2980124,0xada00b83,0xa2bc00cd}},	//   энч_, _наҟ_, гачл, षुर्, 
   {{0x9c7c02fb,0x6b700083,0x00000000,0x00000000}},	//   _odče, wăga, --, --, 
   {{0xdb0800bc,0x4f94dd5c,0x6ff8011a,0x00000000}},	//   _tudí, _аруу, _מפלג, --, 
   {{0x9e8403e6,0xd04406be,0x00000000,0x00000000}},	//   _شارۆ, dahə, --, --, 
   {{0xad640124,0x8b64315b,0x6b700356,0x00000000}},	//   _зауз_, _یانم, răga, --, 
   {{0x315400c8,0x00000000,0x00000000,0x00000000}},	//   גיין_, --, --, --, 
   {{0x7d197bdf,0x00000000,0x00000000,0x00000000}},	//   _hats, --, --, --, 
   {{0x7d197be0,0xcb3801d5,0xc0dc0023,0x00000000}},	//   _kats, _تينچ_, _ቕድሚ_, --, 
   {{0x7d197be1,0x79640066,0xb3380139,0x74a400d8}},	//   _jats, _déwè, _tiçk, ејбе, 
   {{0x7d197be2,0xc8840730,0x15ec0034,0x68400014}},	//   _mats, ößte_, _जमकर_, _مَول, 
   {{0x7d197be3,0xb33947a6,0xdb08067c,0xe3b025ef}},	//   _lats, _kiçi, _judà, صرف_, 
   {{0xb5a47da1,0x69040158,0x7d180857,0xb6980129}},	// [27ab0] _прой, _årdø, _oats, geât, 
   {{0x7d197be4,0x1fd8009e,0xb3390db0,0xd1e40092}},	//   _nats, _সহজস, _miçi, ምረቻ_, 
   {{0x34bc0118,0xabb800d1,0x00000000,0x00000000}},	//   ्रीद, _ﻧﺎﻫﺎ, --, --, 
   {{0x7d180af5,0xb8d00003,0xdb0805d5,0xedd405a2}},	//   _aats, _ཐུ_, _nudà, елдә_, 
   {{0x7d197be5,0xb338a697,0xb64000b5,0x00000000}},	//   _bats, _niçi, _ｌｓ_, --, 
   {{0x7d197be6,0xdb0835f5,0xcc882cc8,0x98fc0115}},	//   _cats, _audà, мбле_, diĉo, 
   {{0x7d197be7,0x6b6402e2,0xd04400ac,0x7b940014}},	//   _dats, _nègè, yahə, چھنس_, 
   {{0xdd94052f,0xb3397be8,0x7d197be9,0x9510031c}},	//   _ҡаты, _biçi, _eats, _ཎིའི_, 
   {{0x7d197bea,0x6f180204,0xdb0800d8,0x00000000}},	//   _fats, _iauc, _sudã, --, 
   {{0x7d197beb,0x6f197bec,0x6b64007f,0x29017bed}},	//   _gats, _hauc, _bègè, ýja_, 
   {{0x6f197bee,0xcb140276,0x2c001d37,0xb17801e3}},	//   _kauc, _афлы, _сүйм, _tvåf, 
   {{0x6f197bef,0x7d1886ba,0xd1e41ee0,0x3f9c04cc}},	//   _jauc, _zats, ምረት_, _ètut_, 
   {{0xf2101c82,0xa3d40c66,0x6f197bf0,0xd04400ac}},	//   সমুহ_, सीन_, _mauc, rahə, 
   {{0x6f180c3a,0xdcf8054e,0x3a7001e0,0x70c8012c}},	//   _lauc, movă, _әләр, िरोल, 
   {{0x69d97bf1,0x6b6400f2,0x94797bf2,0xdb0800d0}},	//   lsue, _gègè, есту_, _hudá, 
   {{0x6f188c79,0x7c3c1347,0x00000000,0x00000000}},	//   _nauc, øpri, --, --, 
   {{0x69d97bf3,0xdcf8054e,0xdb0800d0,0x41a9114a}},	// [27ac0] nsue, novă, _judá, дван_, 
   {{0xf210febc,0xdb080077,0xc79401e0,0xaca0010e}},	//   সমূহ_, _mudá, _ярһы, _jaỳl, 
   {{0x7d197bf4,0x6f197bf5,0xf1bc0030,0x1b1804c5}},	//   _rats, _bauc, _prác_, থাতে_, 
   {{0x7d197bf6,0x00000000,0x00000000,0x00000000}},	//   _sats, --, --, --, 
   {{0x7d197bf7,0x6f197bf8,0xdd900075,0x69d80007}},	//   _pats, _dauc, مۈر_, jsue, 
   {{0x7d1820ac,0xdb080c8e,0xccf44942,0x98fc0115}},	//   _qats, _sudà, лқу_, viĉo, 
   {{0x7d197bf9,0x6f197bfa,0x3f688a6f,0xdb0800d8}},	//   _vats, _fauc, _живо_, _audá, 
   {{0x7d197bfb,0x5b1574a0,0x6f197bfc,0xa3d49201}},	//   _wats, умит, _gauc, सीय_, 
   {{0x7d197bfd,0xaca0010e,0x00000000,0x00000000}},	//   _tats, _baỳl, --, --, 
   {{0x7d197bfe,0x764801d3,0xb338036e,0x6f1800d7}},	//   _uats, _ügyi, _viçi, _zauc, 
   {{0x96f80311,0x6f180099,0xd7f400fd,0x69d80124}},	//   нент_, _yauc, ызны, asue, 
   {{0x69d841ca,0x00000000,0x00000000,0x00000000}},	//   bsue, --, --, --, 
   {{0x7ae17bff,0x69d801ab,0x00000000,0x00000000}},	//   _idot, csue, --, --, 
   {{0x7ae00175,0x58d400db,0x00000000,0x00000000}},	//   _hdot, _сокт, --, --, 
   {{0x22b80521,0x20192c07,0x3f680115,0x33700107}},	//   _ọka_, _nsri_, nĝus_, иҳор, 
   {{0x3a2404ce,0xf1bc01e1,0xb5f00220,0xe37404b3}},	//   _krop_, _aráa_, _күмі, алсы, 
   {{0x20197c00,0x6f197c01,0x3b057c02,0xceb800bc}},	// [27ad0] _asri_, _rauc, _mboq_, _jaře_, 
   {{0xe3b000dd,0x306800d8,0x00000000,0x00000000}},	//   صرہ_, мјен_, --, --, 
   {{0x6f197c03,0x7ae0049b,0x30a57c04,0xdb08003a}},	//   _pauc, _odot, трав, _iudæ, 
   {{0xe3b17c05,0x7ae17c06,0x3a240de2,0xf2dc015d}},	//   _گری_, _ndot, _orop_, _plâu_, 
   {{0xdef82ecc,0x6f197c07,0x6d440227,0xaca40014}},	//   тых_, _vauc, _ŋjaq, چھاے_, 
   {{0xe3b07f22,0x7ae17c08,0x6f180099,0xdb080381}},	//   _دری_, _adot, _wauc, _judæ, 
   {{0x6f1803b4,0xdb08e10d,0x7ae00327,0xc0c00f7c}},	//   _tauc, _sudá, _bdot, ድኩም_, 
   {{0x69d8a9ed,0xaca0010e,0x00000000,0x00000000}},	//   tsue, _saỳl, --, --, 
   {{0x6ab806af,0x0d20121c,0x7ae17c09,0x3a257c0a}},	//   rcuf, _гүлү, _ddot, _crop_, 
   {{0x69d97c0b,0x7ae005f5,0x3a240375,0x2bc8bb65}},	//   rsue, _edot, _drop_, _жудо_, 
   {{0x69d97c0c,0x3a241cca,0xabb80ae5,0x7aec3b88}},	//   ssue, _erop_, _ﻧﺎﻣﺎ, áité, 
   {{0xdb0801ed,0x69d80007,0xdcf8054e,0xceb801ef}},	//   _tudá, psue, povă, _faře_, 
   {{0x3a241497,0x09e4f0c0,0xc0dc02d3,0x69d8036e}},	//   _grop_, _солн, _ሕድሪ_, qsue, 
   {{0x0ce40c58,0x55c40032,0x14a40c6f,0xb3380166}},	//   প্ৰত, рарғ, _गृहण, _miçu, 
   {{0xf990008d,0x29040009,0x68e0127b,0x670404b3}},	//   _הרג_, _ibna_, _idnd, _күнб, 
   {{0x7c2d7c0d,0xf48400e5,0x00000000,0x00000000}},	//   _ábre, چاہی, --, --, 
   {{0xa3d403f3,0x05753441,0x20197c0e,0x41040798}},	// [27ae0] _सौर_, _مادد, _ssri_, лзав, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x04457c0f,0xef0c004b,0x3fe57c10,0xf2dc03cb}},	//   _сенн, ګټن_, ужев, _plât_, 
   {{0xf1bc09c2,0xb3380139,0x4f9463da,0xdce8294f}},	//   _irán_, _biçu, арчу, _ılıs, 
   {{0xf1bc19cd,0x645c002f,0x9e340395,0x5fe0000d}},	//   _tráa_, lzri, релч, _पटकल, 
   {{0xa3b82208,0x6380054e,0x7c3c3b22,0x00000000}},	//   _चढा_, _dânş, äpro, --, 
   {{0x645d2577,0x764801ed,0x9a9002d3,0xfba97c11}},	//   nzri, _ügyv, _ምትካል_, нтий_, 
   {{0x3a257c12,0xbea44e0c,0x29040548,0xee34013d}},	//   _prop_, _бабк, _abna_, тнә_, 
   {{0xe04401b9,0x3dc40175,0xa3d4043e,0x00000000}},	//   _ёнғи, qpow_, सीत_, --, 
   {{0x26c0e64d,0x58d400c2,0xa9640261,0x0d080131}},	//   _afio_, шоот, лиња_, _идуқ_, 
   {{0x3134025f,0xb338013d,0x98fc01e4,0xf1bc0ca8}},	//   אריך_, _kiçt, liĉk, _nrán_, 
   {{0x3a257c13,0xa3b80c2e,0x7ae03e61,0x645c05b1}},	//   _trop_, _चढ़_, _udot, dzri, 
   {{0x3a2408cd,0xb5f801ed,0x76a80b7e,0xf1bc7479}},	//   _urop_, zzáf, этов_, _arán_, 
   {{0xf65c037e,0xf4846ff7,0xf1bc0f91,0x6a800454}},	//   lbæk_, губн, _brán_, _улча, 
   {{0xdb180267,0xd1e40023,0x00000000,0x00000000}},	//   ppvä, ምየት_, --, --, 
   {{0x98bc007f,0xf65c005c,0x00000000,0x00000000}},	//   _movč_, nbæk_, --, --, 
   {{0x6234084c,0xe1f00014,0x00000000,0x00000000}},	// [27af0] бету, ۪سہ_, --, --, 
   {{0xd1303009,0xb38403e6,0x00000000,0x00000000}},	//   غما_, _ڕێزم_, --, --, 
   {{0x3f8403a0,0xf1bc01e7,0xb3380b97,0x63c40118}},	//   foou_, _grán_, _biçt, ětné, 
   {{0xb3380139,0x4094030d,0x00000000,0x00000000}},	//   _piçu, ăрат, --, --, 
   {{0xf65c00b5,0x8e841fbe,0x00000000,0x00000000}},	//   dbæk_, јгле, --, --, 
   {{0x8c445aba,0x64480e78,0xf2040117,0x5bac02dd}},	//   иеле, ädig, _ияҳо, _ﺷﺎﺭﻻ, 
   {{0x8cc0c126,0x4c3401c0,0xcc3401c0,0xb17801e3}},	//   रुषो, рэлт, рхлы, _tvåb, 
   {{0x0b440517,0x256c0241,0xd5b40d79,0x00000000}},	//   рнин, _kólè_, ंदाज, --, 
   {{0x357402d3,0x256c01e1,0xf4080154,0x00000000}},	//   በኛታት_, _jólè_, শটির_, --, 
   {{0x480478d2,0x9f5808fb,0x26c00165,0xfc700014}},	//   апов, _sprø_, _sfio_, _ژھٹھ, 
   {{0xc7940276,0xa3d40764,0x256c01e1,0xfd2402f2}},	//   ирмы, _सौं_, _lólè_, _خولێ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7f3804ac,0x04b400d6,0x2d8400af,0x9f4c01d3}},	//   דערו, исвя, oone_, élés_, 
   {{0x645c03fa,0x35c401f0,0x00000000,0x00000000}},	//   tzri, ргро_, --, --, 
   {{0xb698002d,0x645c009a,0x2d853bdc,0x00000000}},	//   lfâl, uzri, ione_, --, 
   {{0x2d857c14,0x589400c6,0x0cd00316,0x2bd400dc}},	//   hone_, _اجهز, हरुम, णीया, 
   {{0x2d857c15,0xb6980b21,0x00000000,0x00000000}},	// [27b00] kone_, nfâl, --, --, 
   {{0x2d857c16,0xc0e4716a,0xf1bc01fb,0x63b40124}},	//   jone_, рожк, _trán_, _гәах, 
   {{0x2d857c17,0x46b84103,0xb698002d,0xf1bc0308}},	//   done_, _इलाह, hfâl, _hrál_, 
   {{0x3eb008fb,0x256c0241,0xf1bc00bc,0xbea800ec}},	//   øyt_, _fólè_, _král_, نهان_, 
   {{0x63a57c18,0x0cd00316,0x98bc007f,0x5d0800c7}},	//   mmin, हरूम, _sovč_, лҭан_, 
   {{0x2d857c19,0xb5f800dd,0x63a57c1a,0x0dc800be}},	//   gone_, szág, lmin, ابنى_, 
   {{0x63a57c1b,0x6ca00801,0x3178010f,0x00000000}},	//   omin, оръж, _סאלד, --, 
   {{0x63a57c1c,0xf1bc03da,0x00000000,0x00000000}},	//   nmin, _orál_, --, --, 
   {{0x5a3412d7,0xf65c00b5,0x98fc00df,0xaba401c8}},	//   ёнот, rbæk_, liĉi, جهيم_, 
   {{0x63a57c1d,0x2d857c1e,0xf65c01bf,0x00000000}},	//   hmin, cone_, sbæk_, --, 
   {{0x63a57c1f,0x1ae800fe,0x98fc01e4,0xda700050}},	//   kmin, ক্ষই_, niĉi, تُک_, 
   {{0x7bc97c20,0x63a57c21,0x00000000,0x00000000}},	//   mpfu, jmin, --, --, 
   {{0x7bc80375,0x63a42d61,0xfaa40672,0x602c0248}},	//   lpfu, dmin, _тадо, _o̟mo, 
   {{0xb86404fb,0xf1bc03b2,0x229c0024,0x3f6801e4}},	//   _پاتو, _drál_, iškį_, kŝuo_, 
   {{0xf3657c22,0x6d9c145e,0x7c8c044e,0x63a57c23}},	//   атан, bêaf, _ምዕባለ_, fmin, 
   {{0x63a57c24,0xe73815ed,0x23bc01ed,0x7bc80099}},	//   gmin, _већ_, _díj_, ipfu, 
   {{0x2d857c25,0x00000000,0x00000000,0x00000000}},	// [27b10] yone_, --, --, --, 
   {{0x2d852903,0x98fc00df,0x1de00950,0x3e4c00ef}},	//   xone_, fiĉi, _निजत, _mētā_, 
   {{0x2d857c26,0x63a57c27,0xf1bc0208,0x3e4c0171}},	//   vone_, bmin, _tráo_, _lētā_, 
   {{0x2d85596b,0x63a57c28,0x64497c29,0x9f040fb4}},	//   wone_, cmin, ädie, قومو, 
   {{0x9f0445ff,0xf1a40261,0x6e641f5a,0xf1bc013a}},	//   تونو, _врвн, јтеж, _krám_, 
   {{0x6b700311,0x673802d3,0xa194be81,0xa1840064}},	//   măgi, _ብዛዕብ, _маяч, _дысл, 
   {{0x2d857c2a,0xb5f80077,0xb3380139,0xcb697c2b}},	//   rone_, nzáb, _hiçq, лаке_, 
   {{0x2d857c2c,0x00000000,0x00000000,0x00000000}},	//   sone_, --, --, --, 
   {{0xc8b401c0,0x4aa801e0,0x893400ae,0x00000000}},	//   йсны, ыкин_, معدا, --, 
   {{0x63a57c2d,0xec6829db,0xb698002d,0x2d84058a}},	//   zmin, _ирек_, rfâl, qone_, 
   {{0xdc80036b,0x63a41bb3,0xb5f96f14,0x7bdc03b2}},	//   _оқшо, ymin, jzáb, áput, 
   {{0x63a4298d,0x7c2d5f41,0x00000000,0x00000000}},	//   xmin, _ábra, --, --, 
   {{0x63a57c2e,0x4e78008f,0xb5c400e5,0x00000000}},	//   vmin, ראָצ, یڈیم_, --, 
   {{0x044423b3,0x63a47f17,0x1de00490,0x9c7c00d7}},	//   бегн, wmin, _निघत, _odčl, 
   {{0x63a4007d,0x98bc00ef,0xc7a44eca,0x7aec0248}},	//   tmin, _elvē_, _ликк, _íntó, 
   {{0xaca002e3,0x93580228,0x63a57c2f,0x98fc01e4}},	//   _adịl, аруу_, umin, viĉi, 
   {{0x00e57c30,0x78c400dd,0xd40801d9,0x7ae40174}},	// [27b20] йжан, _érvé, ُتہم_, ókti, 
   {{0xdb0801e3,0xb140064d,0x00000000,0x00000000}},	//   _utdö, пнул, --, --, 
   {{0xb3380205,0x63a57c31,0x00000000,0x00000000}},	//   _shçe, pmin, --, --, 
   {{0x63a40369,0x6fb000f1,0x98fc00df,0x7de4007b}},	//   qmin, سمها, riĉi, مستم, 
   {{0x52757c32,0xa3d41d8a,0x7f940022,0x00000000}},	//   _дуру, सीर_, ааҧх, --, 
   {{0xb1780267,0xa3dc0073,0x784806be,0x00000000}},	//   _tvåa, _डबा_, ləve, --, 
   {{0x7bc8006f,0x3154010f,0x3e4c00de,0x8cd8012d}},	//   upfu, _פילן_, _sētā_, _नजरो, 
   {{0xb5f8ea0f,0x7bc801e4,0x2bd4000d,0x00000000}},	//   nzác, rpfu, णीधा, --, 
   {{0x3cf8473f,0x00000000,0x00000000,0x00000000}},	//   _معاد_, --, --, --, 
   {{0x7bc85794,0x81e80011,0x00000000,0x00000000}},	//   ppfu, _মহা_, --, --, 
   {{0x3e4c02b1,0x9ab400b8,0x1e1800ce,0x64580327}},	//   _wētā_, _enāṃ, _धनुष_, _żvin, 
   {{0xdcb80115,0x3cfc058a,0xeb9432b0,0x497400cf}},	//   _kaĉo_, _hctv_, _лих_, йлөс, 
   {{0xba4400b8,0x9a740244,0x00000000,0x00000000}},	//   _bhįũ, _بئاڵ, --, --, 
   {{0xdcb80115,0x6a800408,0x6db400a2,0x00000000}},	//   _maĉo_, _элча, lşaý, --, 
   {{0xdcb801e4,0x245800a8,0xa3d403ce,0xdb0c01e1}},	//   _laĉo_, барь_, सील_, _òkób, 
   {{0xe2f80046,0x2d4801bf,0x00000000,0x00000000}},	//   йесі_, _høet_, --, --, 
   {{0xdb0801a2,0xf1bc833a,0xb5f800e5,0x00000000}},	// [27b30] _budú, _trám_, száb, --, 
   {{0x30a55efe,0x7580030f,0x00000000,0x00000000}},	//   брев, _ریزم, --, --, 
   {{0x5fa40490,0x6b5c01e1,0x2fc57c33,0x00000000}},	//   _ओळखल, _jàgù, ëng_, --, 
   {{0x3cfc011c,0x00000000,0x00000000,0x00000000}},	//   _actv_, --, --, --, 
   {{0x918043e8,0xf1257c34,0x9f5801ed,0x98fc0115}},	//   _قۇرۇ, _льво, _apró_, liĉu, 
   {{0x1088008e,0xcd280108,0xe1040024,0x00000000}},	//   _көек_, ржке_, _нясп, --, 
   {{0xa4fc008f,0xd5b4033f,0x00000000,0x00000000}},	//   אלוט, ंदुओ, --, --, 
   {{0x7a3c0024,0x1618012c,0x6db400a2,0x00000000}},	//   kštą, धबार_, gşaý, --, 
   {{0xba20004e,0x00000000,0x00000000,0x00000000}},	//   ддык, --, --, --, 
   {{0x764c068f,0x9ec80014,0xaa440116,0xbd8401c8}},	//   dycy, _نِہم_, ипқа_, _وچون_, 
   {{0x07a57c35,0xf1bc02d2,0xdcf80118,0x8c1800ae}},	//   жанн, _brák_, hově, _خيار_, 
   {{0xa6a800eb,0x3ff800df,0xdcf8013a,0x00000000}},	//   _ক্ষয়, ספרע, kově, --, 
   {{0xf1e4002e,0x65a003fa,0x26cc01e4,0x597400f2}},	//   _d斡kk_, höhe, ĝdo_, _کدنز, 
   {{0x8494069c,0xdcf800bc,0x98fc0115,0xeac00345}},	//   _መስርሕ_, dově, fiĉu, _بڕژێ, 
   {{0xc3300014,0x92540092,0xa3d46766,0x65a000e5}},	//   وٕس_, _የመረጃ, सीं_, jöhe, 
   {{0x42c97c36,0x3eb00024,0x00000000,0x00000000}},	//   рган_, žyti_, --, --, 
   {{0xb5f81155,0x00000000,0x00000000,0x00000000}},	// [27b40] rzác, --, --, --, 
   {{0x67257c37,0xaca0063f,0x6604009a,0x630c03d4}},	//   _haij, _adọl, _iqik, ৱাইট_, 
   {{0x67257c38,0x3cfc0789,0xb17801e6,0x41c40014}},	//   _kaij, _rctv_, _tvån, _ڈٲجِ, 
   {{0x44280491,0x3cfd7c39,0xcfa82ea3,0x6724005a}},	//   mvb_, _sctv_, مانم_, _jaij, 
   {{0x672400da,0x6e917c3a,0x3cfc3040,0xb17808fb}},	//   _maij, ولما, _pctv_, _kvål, 
   {{0x61e57c3b,0x67257c3c,0x6604009a,0xdb080fac}},	//   msil, _laij, _mqik, _hudø, 
   {{0x60dc6809,0x3cfc004d,0x764c012d,0x00000000}},	//   _ierm, _vctv_, zycy, --, 
   {{0x61e57c3d,0x67257c3e,0xefb00517,0x00000000}},	//   osil, _naij, _قیلگ, --, 
   {{0x6458003d,0x44280175,0x764c045a,0x8eb01183}},	//   _żvil, hvb_, xycy, _كەمت, 
   {{0x61e57c3f,0xf1bc00d7,0xbae00150,0x7c2c02d2}},	//   isil, _dráh_, _ﺍﺩﻩﺕ, _ábro, 
   {{0x67257c40,0x66040b6f,0x61e4b6d6,0x60dd1d11}},	//   _baij, _aqik, hsil, _merm, 
   {{0x442804fb,0x60dc0998,0x61e57c41,0x67254043}},	//   dvb_, _lerm, ksil, _caij, 
   {{0x61e57c42,0x7e617c43,0x60dd7c44,0x67257c45}},	//   jsil, nzop, _oerm, _daij, 
   {{0x61e406f2,0x7d080204,0x7e60004c,0x28f400a8}},	//   dsil, nffs, izop, _дешь_, 
   {{0x61e57c46,0x66057c47,0x2d482142,0x776c045f}},	//   esil, _eqik, _køer_, picx, 
   {{0x67240226,0x1b180729,0x61e4a46b,0x60dc008e}},	//   _gaij, থাকে_, fsil, _aerm, 
   {{0x60dd7c48,0x61e49b58,0x66040117,0x51b400e3}},	// [27b50] _berm, gsil, _gqik, سماء, 
   {{0x60dd7c49,0x2d4805ac,0x61142be5,0x98bc012c}},	//   _cerm, _løer_, мдуу, ोडिए, 
   {{0x61e57c4a,0xd7f80276,0x00000000,0x00000000}},	//   asil, nuă_, --, --, 
   {{0x4418025f,0xdcf8038e,0x61e40354,0xb178007c}},	//   _פורס, pově, bsil, _tvåo, 
   {{0x433804ae,0x61e57c4b,0x00000000,0x00000000}},	//   _הערב, csil, --, --, 
   {{0x8d64d3a6,0x60dd7c4c,0xa3b815f6,0x00000000}},	//   явле, _germ, _دایر_, --, 
   {{0x92cc0154,0xa0c40b73,0xc2600241,0x00000000}},	//   রণী_, _آيفو, _ọ̀rà, --, 
   {{0x60dd7c4d,0xb5f801ed,0xaf357c4e,0x4a440329}},	//   _zerm, zzáa, _برست, знив, 
   {{0xb698025a,0x67257c4f,0x9f04ae94,0x5e580138}},	//   ngâd, _raij, _توقو, _дитя_, 
   {{0x395d7c50,0x60dc1709,0x67244c97,0xa3dc1062}},	//   ghts_, _xerm, _saij, _डबल_, 
   {{0x67243743,0x7d7800c8,0x6d400399,0xec697c51}},	//   _paij, _פרעג, mjna, _трак_, 
   {{0x61e57c52,0xadfc05f9,0x00540375,0x00000000}},	//   ysil, _ईमान_, פשרת_, --, 
   {{0x67257c53,0x3a2800f1,0x00000000,0x00000000}},	//   _vaij, _هغوۍ_, --, --, 
   {{0x395d7c54,0x2604025a,0x67257c55,0xf1bc0413}},	//   chts_, röo_, _waij, _grái_, 
   {{0x67257c56,0x61e57c57,0x7e60011c,0x03a57c58}},	//   _taij, wsil, zzop, зиво, 
   {{0x61e57c59,0x60dd7c5a,0x91b0004d,0xf1bc0419}},	//   tsil, _serm, _đáp_, _osád_, 
   {{0x61e57c5b,0x66044b2a,0x6f08022e,0xb17801e3}},	// [27b60] usil, _uqik, dfgc, _tvål, 
   {{0x61e57c5c,0x3120dfe6,0x60dc003a,0x80d400e1}},	//   rsil, ндуг, _qerm, धरें, 
   {{0x61e57c5d,0x3518011a,0x00000000,0x00000000}},	//   ssil, _פוטנ, --, --, 
   {{0x61e57c5e,0x69c8004e,0xf65c0388,0xdd9000d1}},	//   psil, _otge, mbær_, چۈر_, 
   {{0x657c009a,0x61e4e4a3,0xf65c21e3,0xd24c0133}},	//   onrh, qsil, lbær_, _پۆل_, 
   {{0x60dc003a,0x2d4800b5,0xdd900a11,0x98bc0024}},	//   _uerm, _søer_, خوت_, _kovą_, 
   {{0x69c97c5f,0x7d0812e8,0x2bd428fe,0x7e600827}},	//   _atge, rffs, णीला, szop, 
   {{0x5a3464e1,0xcee81698,0xa3d4033f,0x991408f2}},	//   днит, _ورقن_, सीए_, तज्ञ_, 
   {{0xa6c402f5,0x6e0400db,0x98bc0153,0x00000000}},	//   ্ণাট, _ىسكە, _lovą_, --, 
   {{0xeb300150,0x779000f2,0xd7f80356,0x00000000}},	//   _ۋىلد, کیبا, tuă_, --, 
   {{0x69c80036,0xbd9000b5,0x9c7c19d6,0x6da007b5}},	//   _etge, _kgb型_, _odči, _џиха, 
   {{0x66c8016c,0x00000000,0x00000000,0x00000000}},	//   зург_, --, --, --, 
   {{0xf1bc07ae,0x8b641df2,0x64497c60,0x3da80150}},	//   _trái_, _تالم, ädin, _ﺷﻮﯕﻘ, 
   {{0x187400d6,0x657c0211,0x9c7c0427,0xf1bc00d7}},	//   _огля, gnrh, _večf, _kráv_, 
   {{0x2d5801f2,0xb37002dd,0xa998011a,0x00000000}},	//   ụego_, еңні, _הבגר, --, 
   {{0xa87806a9,0x21380142,0x2360014f,0x25540213}},	//   _לאור, _anrh_, ghij_, _ağlı_, 
   {{0xc0cc02d3,0xe6100af6,0x69c97c61,0xe2c80ee8}},	// [27b70] ብጋስ_, _یشی_, _xtge, سولو_, 
   {{0x92cc00bd,0x30a57c62,0xb17801e3,0x00000000}},	//   রণে_, прев, _tvåm, --, 
   {{0x0eb800fb,0xb0a4012d,0x00000000,0x00000000}},	//   оулы_, केंग, --, --, 
   {{0x3578001f,0x6d400007,0x2360c329,0x91780051}},	//   _ባለበት_, wjna, chij_, _bận_, 
   {{0x22840323,0x7bd97c63,0xdfd0005e,0xb62c037e}},	//   _зург, _awtu, نيە_, _ｓｑ_, 
   {{0x62800953,0x21397c64,0xdea4006c,0xa3d417e6}},	//   _žmog, _gnrh_, ریلی, सीक_, 
   {{0x69c807de,0x2b5d7c65,0x4fc00220,0x00000000}},	//   _stge, thuc_, _شەشە, --, 
   {{0x49c93c1b,0x5f94df68,0x6d400158,0x1ca80133}},	//   олин_, _зист, sjna, سێنی_, 
   {{0x9f057c66,0xf2dc003a,0x2b5c0036,0x657c0142}},	//   _سولو, _meâ_, rhuc_, ynrh, 
   {{0x47c473b7,0xf4240327,0x65a0340f,0x00000000}},	//   мбов, རྗོད_, köha, --, 
   {{0x2b5c004d,0xb178007c,0x00000000,0x00000000}},	//   phuc_, _avåk, --, --, 
   {{0x22400429,0xf1bc032e,0x00000000,0x00000000}},	//   yxik_, _hráu_, --, --, 
   {{0xb5f801d3,0xdb5401c6,0x69c82b15,0x22400327}},	//   szán, _явцы, _utge, xxik_, 
   {{0x1a6401d5,0xdc3002f0,0x00000000,0x00000000}},	//   _سیپی_, zýče, --, --, 
   {{0xb990505a,0x9c7c0010,0xb5f800e5,0xa3040166}},	//   _جلوب, _večg, lzál, нүне, 
   {{0xf2dc022f,0x224001c6,0xf65c08a5,0x00000000}},	//   _ceâ_, txik_, rbær_, --, 
   {{0xb5f81b73,0x52740107,0x9c7c0171,0x05280395}},	// [27b80] nzál, нуфу, _ieče, _допк_, 
   {{0x23617c67,0xc0740063,0x2240022e,0x00000000}},	//   shij_, мћењ, rxik_, --, 
   {{0x9c7c05be,0x409452f7,0x7f4402d5,0xdd1000d0}},	//   _keče, фрат, межж, týžd, 
   {{0xf1bc0093,0x62240150,0x82f800f2,0x9c7c01ef}},	//   _fuá_, _كوجە, _بردز_, _ječe, 
   {{0x9c7d7c68,0xf1bce81d,0x2e44011c,0x00000000}},	//   _meče, _guá_, дящо_, --, 
   {{0x9c7c0640,0xf1bc0313,0x23b40248,0x9594010c}},	//   _leče, _práv_, _fújì_, _ሃብትን_, 
   {{0x2bc418c7,0x00d40150,0x9b58009d,0x00000000}},	//   үләп_, _ﺟﯘﺗﻘ, зийт_, --, 
   {{0x35780020,0x9c7cd392,0xdcb801e4,0x9178004d}},	//   _ባለቤት_, _neče, _maĉi_, _tận_, 
   {{0x310800cd,0x00000000,0x00000000,0x00000000}},	//   स्वः_, --, --, --, 
   {{0x6da00022,0xf1bd7c69,0x65a001f4,0x00000000}},	//   _аиуа, _gráu_, yöha, --, 
   {{0x9c7c0063,0xf1bc012c,0xdb080790,0x00000000}},	//   _beče, _hrát_, _kudü, --, 
   {{0xf1bc2195,0x9c7c0219,0xeb300150,0x4aa80330}},	//   _krát_, _večd, _لىمد, _کامپ_, 
   {{0x9c7c0f03,0xeb3057d4,0x3688022e,0x00000000}},	//   _deče, _جىند, юсон_, --, 
   {{0x25e0000d,0xe5ec010e,0x65a001f4,0x00000000}},	//   _कबरी_, _önýä, töha, --, 
   {{0x9c7c3b81,0x734800d4,0x00000000,0x00000000}},	//   _hečb, очав_, --, --, 
   {{0x799800a9,0xf1c006ab,0xb338010e,0xb5f8022a}},	//   lltw, _वंदन, _hiçz, lzám, 
   {{0xf1bc07ae,0xb5a401c0,0xd6ac0154,0x31700332}},	// [27b90] _quá_, _орой, _ক্রয, tixz_, 
   {{0xb5f80085,0x9c7d7c6a,0x65a0002f,0xdb0801ef}},	//   nzám, _zeče, löhn, _rudý, 
   {{0x8e7c01e4,0x1ae40eac,0xdb080432,0x4fc000cf}},	//   _meŝe, _গানে_, _sudý, اەرە, 
   {{0x0fd4068f,0xf1bc00bc,0xb270008e,0x271c010f}},	//   डीगढ, _brát_, _акмә, ַווײ, 
   {{0x957002d3,0x88d4002b,0xd05c06be,0xdb080210}},	//   _ኣብተን_, _kṛtr, _əyən, _ludó, 
   {{0x20c402a9,0xf1bc0118,0x00000000,0x00000000}},	//   _айём, _drát_, --, --, 
   {{0xaf0406bb,0x6834063f,0xb5f81155,0x00000000}},	//   _очак, _ọda, dzám, --, 
   {{0xdb08014a,0x9f3402dd,0xce9400a7,0xced400f1}},	//   _gudü, _иесі, _забъ, _سحرګ, 
   {{0xf1bd7c6b,0x443c01fb,0xdcf000fd,0xf8d808df}},	//   _irás_, ̣t_, _äfğa, णरूप, 
   {{0xb5f81dee,0x9c7c5d39,0x290000af,0xa6dc015b}},	//   rzál, _seče, üja_, _ভাইয়, 
   {{0xb5f800dd,0x65a00036,0xf1bc1897,0xc8c801d9}},	//   szál, föhn, _krás_, _ہوشن_, 
   {{0x79980142,0x0be001ec,0xcb0801c8,0x9c6401c8}},	//   altw, _ﺍﻹﻳﺮ, _ريتن_, _جهمو, 
   {{0xb17801e3,0x38c8030f,0x6b98010e,0x00000000}},	//   _tvåh, غایی_, mlug, --, 
   {{0x6b997c6c,0xa3cc01ad,0x00000000,0x00000000}},	//   llug, रऑल_, --, --, 
   {{0x9c7c1154,0x6b997c6d,0xb3380166,0x34a40107}},	//   _teče, olug, _hiçy, евро_, 
   {{0x06d80c58,0x6b997c6e,0x46a4016c,0x7eb4010e}},	//   _থাকি, nlug, _пайв, _jüpü, 
   {{0x00d800c6,0x00000000,0x00000000,0x00000000}},	// [27ba0] كبات_, --, --, --, 
   {{0x417401d3,0x64480158,0x6b98dca6,0x80c803ce}},	//   راءس, ødis, hlug, िडें, 
   {{0x6b997c6f,0xa4948bee,0x2fc40220,0xf1bd0227}},	//   klug, _شیرت, ерің, _brás_, 
   {{0xeaa406d5,0xf1bd7c70,0x6b980218,0xdb0800db}},	//   _مع_, _prát_, jlug, _ludò, 
   {{0xfe717c71,0xb3380139,0x6b997c72,0x00000000}},	//   ددا_, _niçy, dlug, --, 
   {{0x6b98000d,0xf1bc00d7,0x35fc0055,0x00000000}},	//   elug, _vrát_, _ṭīkā_, --, 
   {{0x6b997c73,0xd0957c74,0x00000000,0x00000000}},	//   flug, _ашты, --, --, 
   {{0x6b997c75,0xada00032,0xf1bc6ec0,0x8bf800cc}},	//   glug, _ҡатл, _grás_, _আনখন_, 
   {{0xe9cc006c,0xf1bc02d2,0x3ec00a2f,0x141c000d}},	//   یغی_, _hrár_, āstā_, _पन्ह_, 
   {{0x6b98096b,0x65a00730,0x9c7c0427,0x6a1016ac}},	//   alug, wöhn, _večb, ابير, 
   {{0x96f97c76,0xec10594c,0x6b983209,0x00000000}},	//   мент_, _مولد, blug, --, 
   {{0xb5f800dd,0x6b984079,0x7eb456f8,0x388400e2}},	//   szám, clug, _güpü, _ātrā_, 
   {{0x7ae001ab,0x75e40006,0x00000000,0x00000000}},	//   _ieot, эўне, --, --, 
   {{0x20197c77,0x7ae00374,0x3a257c78,0xdb0801ed}},	//   _opri_, _heot, _isop_, _tudó, 
   {{0xa8317c79,0xdef81772,0x394c01e6,0x24e40006}},	//   _معيش, ፈስን_, _iofs_, ыцяг, 
   {{0x394c04cc,0x7a44002e,0x7ae17c7a,0x9634119e}},	//   _hofs_, _gétë, _jeot, _аниц, 
   {{0x20197c7b,0x7ae0ec8a,0xb87c01e4,0xb5f801ed}},	// [27bb0] _apri_, _meot, _deƭe, zzáj, 
   {{0xb1441c93,0x7ae17c7c,0x1f3401e1,0x00000000}},	//   ریزم_, _leot, _àìjẹ_, --, 
   {{0x20181529,0x2ac40241,0xf9fc00cc,0xdfd4009d}},	//   _cpri_, _jíbó_, ্টটল_, гохы, 
   {{0xb5f80306,0x65a00112,0xdce8031c,0xf540004e}},	//   vzáj, höhl, _ħoġo, _рдүү, 
   {{0x2018009a,0x5e5800d6,0x01c40022,0xdb00023a}},	//   _epri_, ниця_, _арсҭ, immä, 
   {{0x394c003d,0x7eb47b37,0x4df402ab,0xbea01d39}},	//   _nofs_, _süpü, ुंबई_, јашк, 
   {{0xf1bd7c7d,0x7ae17c7e,0x3a2401e1,0x9c7c01fa}},	//   _trás_, _beot, _asop_, _rečc, 
   {{0x7ae001ab,0x6b997c7f,0x2720012c,0xd7f8054e}},	//   _ceot, ulug, _बसेर_, dră_, 
   {{0x6b9831ec,0x3a240048,0x7ae0be13,0x2fc00477}},	//   rlug, _csop_, _deot, _hujg_, 
   {{0xdd940046,0x64480112,0xd7f8054e,0xdb000108}},	//   _бауы, ädik, fră_, emmä, 
   {{0x6b997c80,0x7ae17c81,0xd7f80276,0x2908033f}},	//   plug, _feot, gră_, ęca_, 
   {{0x7ae17c82,0x6b980cfe,0x3a24030d,0x2ac40241}},	//   _geot, qlug, _fsop_, _díbó_, 
   {{0xd7f8084c,0x55c40116,0x00000000,0x00000000}},	//   ară_, лаяғ, --, --, 
   {{0xd7f80276,0x762000d8,0x00000000,0x00000000}},	//   bră_, јмрз, --, --, 
   {{0x68e17c83,0x9c7c110c,0x7ae00165,0xd7f8054e}},	//   _iend, _keča, _yeot, cră_, 
   {{0x7ae00005,0x9c7c0e04,0xdef81772,0x00000000}},	//   _xeot, _ječa, ፈትን_, --, 
   {{0x68e17c84,0x98bc012c,0x72c0f492,0x2018d452}},	// [27bc0] _kend, _nově_, рбуз, _spri_, 
   {{0x68e17c85,0x201801c4,0x2b4c0175,0x9c7c0427}},	//   _jend, _ppri_, _logc_, _leča, 
   {{0xb6980311,0x00000000,0x00000000,0x00000000}},	//   ngân, --, --, --, 
   {{0x9c7c0232,0x35940023,0x00000000,0x00000000}},	//   _neča, _ማእቶት_, --, --, 
   {{0xfcd00020,0x68e0004c,0x29040311,0x7ae008c2}},	//   _የሕግ_, _oend, _ocna_, _reot, 
   {{0x68e000c5,0x7ae17c86,0xcbcc00bd,0x3f5c04cc}},	//   _nend, _seot, _রয়েছ, _gïun_, 
   {{0x9c7c01a6,0xdb0000fd,0x7ae17c87,0x00000000}},	//   _beča, ymmä, _peot, --, 
   {{0x68e17c88,0x26c000b0,0x1ee801d3,0xdcf800e2}},	//   _aend, _ngio_, _سوئی_, tovē, 
   {{0xceb4052f,0x9c7c026a,0x68e00839,0x2b4d7c89}},	//   _йәш_, _deča, _bend, _dogc_, 
   {{0x2905733b,0xd7f800a8,0x26c00395,0xa9640114}},	//   _ccna_, tră_, _agio_, киња_, 
   {{0x68e12618,0x3a240100,0x2bb81533,0x31540375}},	//   _dend, _wsop_, _ऊंचा, דיין_, 
   {{0x68e17c8a,0x9c7c0064,0x00000000,0x00000000}},	//   _eend, _geča, --, --, 
   {{0xf1bc01e1,0x3a2405b1,0x68e01486,0x394d7c8b}},	//   _asán_, _usop_, _fend, _tofs_, 
   {{0x68e0bdcb,0xb8657c8c,0xd7f8054e,0x00000000}},	//   _gend, _لابو, pră_, --, 
   {{0x8e7c0115,0x64740064,0xb4b000d1,0xc0dc0023}},	//   _meŝa, агру, ривә, _ዕስራ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc92400fe,0x00000000,0x00000000,0x00000000}},	// [27bd0] বাৰত_, --, --, --, 
   {{0x8e7c00df,0x68e06d50,0xf1bc1427,0xdb180254}},	//   _neŝa, _xend, _dráp_, mpvõ, 
   {{0xb9c8044e,0xe8d40375,0x9074009a,0x00000000}},	//   _ደገ_, דובר_, دهاش, --, 
   {{0x041c1b49,0xe3b0009f,0x00000000,0x00000000}},	//   _ስልጣን, _ورَ_, --, --, 
   {{0xb6980311,0x9c7ce8a8,0x42a4022e,0x00000000}},	//   zgân, _reča, _бурғ, --, 
   {{0x9c7c0cf4,0xfce01f0f,0x00000000,0x00000000}},	//   _seča, бошо, --, --, 
   {{0x68e07963,0x4c140491,0x7d1c00c5,0x00000000}},	//   _rend, ابتس, õpsa, --, 
   {{0x8b24412c,0x9b340124,0x61ec08e2,0xcb0800ec}},	//   удие, ахьш, _ällä, ريخن_, 
   {{0x68e17c8d,0x9c7c15ad,0x2904045a,0x60e8010e}},	//   _pend, _veča, _pcna_, _ösmä, 
   {{0x68e0069c,0x26c17c8e,0x00000000,0x00000000}},	//   _qend, _sgio_, --, --, 
   {{0x68e02b9d,0x9c7c55a6,0x2c0177b3,0x5c040024}},	//   _vend, _teča, _түйм, _вяча, 
   {{0xb17805ac,0xb698042f,0xfc4400bc,0x9b440451}},	//   _kvås, rgân, žích_, _پنهو, 
   {{0x68e17c8f,0x9c7c013a,0x00000000,0x00000000}},	//   _tend, _ječn, --, --, 
   {{0xd4f4cc3b,0x68e17c90,0x9c7c0010,0xf1bc01ef}},	//   иясы, _uend, _mečn, _psán_, 
   {{0x1ccc0327,0xe8e400ec,0x83380fac,0x00000000}},	//   _ྲུལ_, _ٻرڙو_, нчат_, --, 
   {{0x26c15221,0x060800d4,0x00000000,0x00000000}},	//   _ugio_, _зник_, --, --, 
   {{0x41a97c91,0xd3b80212,0x82a400c7,0x00000000}},	// [27be0] еван_, турі_, уааж, --, 
   {{0x25740131,0x00000000,0x00000000,0x00000000}},	//   _ئۇسس, --, --, --, 
   {{0x8e7c00df,0x00000000,0x00000000,0x00000000}},	//   _reŝa, --, --, --, 
   {{0x2fd57c92,0xf424084c,0xf1bc0208,0xe0e40154}},	//   اوند_, _союл_, _tráp_, মলেন, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x16c006bc,0x3a397c93,0xbc0405f5,0x00000000}},	//   _एल्ब, _čpp_, гчий, --, 
   {{0x50b43f51,0x00000000,0x00000000,0x00000000}},	//   _всту, --, --, --, 
   {{0xbfa801d9,0xeb941fbe,0xcf2401c8,0x00000000}},	//   _سازٕ_, лиј_, _پرفي, --, 
   {{0x09280451,0xb17801e3,0x8f7400d4,0xbc6800f1}},	//   چسپي_, _tvåt, _турі, _ګمان_, 
   {{0xd6e0015b,0x784401c0,0x69cc01e7,0x00000000}},	//   _ভাইয, гэмж, ícea, --, 
   {{0xd05403b9,0x00000000,0x00000000,0x00000000}},	//   _bezə, --, --, --, 
   {{0x2fc400d2,0x78480213,0x57e80137,0x3c0c06be}},	//   íngi_, nəvi, ндүм_, _nəvi_, 
   {{0x62804077,0x8e7c01e4,0xe6657c94,0x666400a7}},	//   _žmon, _leŝn, бтро, бърз, 
   {{0x58d40372,0x326400d1,0xb4bc000d,0x66640395}},	//   _токт, ңтав, इशे_, съюз, 
   {{0xb5f80306,0x9c7c0306,0xb178007c,0xbb5001ec}},	//   jzáv, _mečo, _ovår, _ﺎﻁﻕ_, 
   {{0x7bc80007,0xdb180037,0x74680051,0xb3ac17ee}},	//   iqfu, ppvõ, _đãđư, ंगे्, 
   {{0x91744690,0x784806be,0x00000000,0x00000000}},	// [27bf0] агац, dəvi, --, --, 
   {{0x9c7d5d06,0x4374001f,0x395c005f,0x92e4015b}},	//   _rečn, _ተገለፀ_, nkts_, নলে_, 
   {{0x30a50fce,0x52d0009e,0x9c7c0219,0x8d740244}},	//   урав, তৃগৃ, _sečn, یاتا, 
   {{0x6ee410fe,0x13057c95,0x9c7c2a53,0x2894008f}},	//   اسال, _өзүм, _pečn, נדאן_, 
   {{0xdcf80024,0x26dc011a,0x9c7c01ef,0x00000000}},	//   novė, תקדמ, _bečo, --, 
   {{0x9c7d7c96,0x71600137,0x5ed40131,0x5ba401e0}},	//   _večn, _اپسە, لتۇز, ҙлығ, 
   {{0x7bc400b0,0xc0dc0023,0x00000000,0x00000000}},	//   _ōkur, ሕኩም_, --, --, 
   {{0x9c7c248d,0x2bc8013e,0xb1780267,0x4ab802e8}},	//   _tečn, _ҷудо_, _tvås, купя_, 
   {{0xb9e40046,0x9e357c97,0xdcf80153,0xdb2401f6}},	//   амыз_, _летч, jovė, ásái, 
   {{0xc8b402f6,0xdcf80024,0xd05403b9,0x00000000}},	//   исны, dovė, _sezə, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x65a000b0,0xdb080254,0x490400d1,0x475801f4}},	//   möhi, _budõ, _چوشق, троя_, 
   {{0xfd4c0248,0xb5f801ed,0x06a00220,0x65a001f4}},	//   _afiṣ, zzáv, _ﺍﺭﻗﯩ, löhi, 
   {{0x3ea00212,0x395c26bc,0x00000000,0x00000000}},	//   _økte_, ckts_, --, --, 
   {{0xa414045e,0x4374586c,0x9c7c19d6,0x92e40183}},	//   াট্য_, ауат, _nečl, নলৈ_, 
   {{0xc3241d39,0x03240114,0x00000000,0x00000000}},	//   јмак, јдан, --, --, 
  
   {{0x00e57c98,0x96940153,0x00000000,0x00000000}},	// [27c00] ижан, _грэш, --, --, 
   {{0xb1780628,0xb1406a17,0xf6540375,0x00000000}},	//   _svår, онул, _כספי_, --, 
   {{0x03a4209b,0xb4f8025f,0x657c1b91,0x9c7c0419}},	//   _вино, _בפיי, mirh, _rečo, 
   {{0x44397c99,0x9c7c10bf,0x657c009a,0x645d2420}},	//   _irp_, _sečo, lirh, myri, 
   {{0x44397c9a,0x9e34010b,0x9c7d7c9b,0xaec005a2}},	//   _hrp_, селч, _pečo, әбәл, 
   {{0x44397c9c,0x7c3c003b,0x645c00ad,0x00000000}},	//   _krp_, åpro, oyri, --, 
   {{0x645c18d9,0x7b643b55,0xed540b3e,0x69cc00bc}},	//   nyri, итие, рој_, ícen, 
   {{0xc0380020,0x3a04036b,0x6c8000d1,0x9a900023}},	//   _የሚታወ, لکتی_, تلىم, _ዝትከል_, 
   {{0x645c98a6,0x3f840122,0x657c02c4,0xb5f825fd}},	//   hyri, mnou_, kirh, nzát, 
   {{0x3f8404bf,0x80a800af,0x395c00e2,0x7c9401ee}},	//   lnou_, _कराइ, ukts_, _крец, 
   {{0x3f8410ba,0x657d7c9d,0x44380327,0x395d7c9e}},	//   onou_, dirh, _nrp_, rkts_, 
   {{0x3f857c9f,0xdcf80024,0x645c0072,0x9c7c25e2}},	//   nnou_, tovė, dyri, _ječm, 
   {{0x3f84e8d8,0x8e7c01e4,0xeb9400f5,0x00000000}},	//   inou_, _neŝl, _тиц_, --, 
   {{0x44397ca0,0x645d7ca1,0xdcf80006,0x3f8400bc}},	//   _brp_, fyri, rovė, hnou_, 
   {{0x35a4001f,0x3f857ca2,0x645d7ca3,0xe45406a6}},	//   ለከቱት_, knou_, gyri, окры, 
   {{0x7d1802c4,0x44382a1f,0x3d140b7c,0x3f854555}},	//   _lbts, _drp_, प्ते_, jnou_, 
   {{0x3f84031f,0x645c69f7,0x657d7ca4,0x50f400db}},	// [27c10] dnou_, ayri, birh, йзат, 
   {{0x443803a1,0x9c7c00bc,0x3f840165,0x7c3870a9}},	//   _frp_, _pečl, enou_, _ortr, 
   {{0x2fc407ae,0x44382679,0x645d7ca5,0x667400f1}},	//   êng_, _grp_, cyri, _هدیر, 
   {{0x7d18009a,0x3f857ca6,0xf66803b2,0x236001e4}},	//   _abts, gnou_, _græð_, ckij_, 
   {{0x228401c0,0x7bc400b0,0x312001d9,0xb5f801d3}},	//   _дург, _ōkup, _وہرٲ, mzás, 
   {{0x644828b3,0xe900031c,0x3f840139,0xb5f800e5}},	//   ådig, _མཐེབ_, anou_, lzás, 
   {{0x4c3405f5,0x3f840122,0x251c010f,0x00000000}},	//   сэлт, bnou_, דווא, --, 
   {{0xc6e0000e,0x3f857ca7,0x7d18035a,0x0b443ae4}},	//   _মঞ্চ, cnou_, _ebts, снин, 
   {{0x7c397ca8,0x6f1918eb,0x657c0472,0x4a440117}},	//   _ertr, _ibuc, yirh, ёнов, 
   {{0x6e397ca9,0x657c18f7,0xc96400c0,0x645c0108}},	//   _irub, xirh, свой, yyri, 
   {{0x6e38fdd0,0x645c0e14,0xb5f801ed,0x657c3474}},	//   _hrub, xyri, zzát, virh, 
   {{0x6e397caa,0x645d7cab,0x8b840137,0xb5f80cde}},	//   _krub, vyri, _دەبە_, jzás, 
   {{0x657c0c11,0x2d845725,0x44397cac,0x6f1800f2}},	//   tirh, onne_, _srp_, _mbuc, 
   {{0x645d7cad,0x3f857cae,0x69d97caf,0x8e7c0115}},	//   tyri, znou_, mpue, _reŝl, 
   {{0x2d8435b8,0x14590be1,0x657c0008,0x645c0076}},	//   inne_, ашты_, rirh, uyri, 
   {{0x657c07a9,0x6e3801c4,0xb7d4004b,0x44380129}},	//   sirh, _orub, _اويا_, _vrp_, 
   {{0x3f840232,0x11e8ac15,0x614c001f,0x9c7c0010}},	// [27c20] vnou_, لعلي_, _በማውጣ, _rečm, 
   {{0x6f197cb0,0x9c7c0640,0x657c004b,0x4438f242}},	//   _abuc, _dečj, qirh, _trp_, 
   {{0x6e397cb1,0x44397cb2,0x3f857cb3,0x784800ac}},	//   _arub, _urp_, tnou_, səvv, 
   {{0x57cc010f,0xe81c0210,0x00000000,0x00000000}},	//   דמאַ, _बहना_, --, --, 
   {{0xf2d01a4c,0x3f857cb4,0x6e397cb5,0x2d857cb6}},	//   _מער_, rnou_, _crub, fnne_, 
   {{0x6f185b36,0x6e3805c7,0x3f857cb7,0xbf1400db}},	//   _ebuc, _drub, snou_, _گورب, 
   {{0x6e397cb8,0x63a53376,0x92cc0c58,0x3f8402fb}},	//   _erub, olin, ৰণৰ_, pnou_, 
   {{0x2d857cb9,0xbf14034c,0xd9f81064,0x9c7c02f0}},	//   anne_, _دورب, аниц_, _hečk, 
   {{0x63a57cba,0x6e397cbb,0x44280218,0x8ac40588}},	//   ilin, _grub, hwb_, әқәа_, 
   {{0xb5f800f8,0x63a57cbc,0x57f40138,0x6f18054e}},	//   zzás, hlin, опот, _zbuc, 
   {{0x319800c8,0x4429729c,0xb198008f,0x9c7c892f}},	//   רבינ, jwb_, רייכ, _mečk, 
   {{0xb76548db,0x63a57cbd,0x31ac0274,0x00000000}},	//   стой, jlin, müze_, --, 
   {{0x63a47ada,0x7a34f3d7,0x65a00e78,0xe66400d8}},	//   dlin, _دعائ, höhu, птро, 
   {{0x9c7c8bbb,0xb6980311,0x7bc001f4,0xa4d400d4}},	//   _rečj, ngâi, _hiou, зорі, 
   {{0x63a4cb9b,0x7998401f,0x7bc0062c,0xa90400f7}},	//   flin, motw, _kiou, _ايىل_, 
   {{0xe3b019dd,0x79997cbe,0xf1bc00e4,0x9c7c0427}},	//   فرق_, lotw, _isái_, _pečj, 
   {{0xc0380020,0x9c7c05ce,0x6f180295,0x569400a8}},	// [27c30] _የሚለው, _bečk, _rbuc, _фапт, 
   {{0x9c7c0fb7,0x6f197cbf,0xf77d7cc0,0x79981cf4}},	//   _večj, _sbuc, liç_, notw, 
   {{0x9c7c7313,0x6e38ea1f,0xb3380205,0x44280327}},	//   _dečk, _srub, _akçe, cwb_, 
   {{0x6e382b1d,0x63a426c2,0x59c8b1e3,0x7bc17cc1}},	//   _prub, clin, रदार, _niou, 
   {{0x958c044e,0x79994df7,0x8db57cc2,0xf1bc02fb}},	//   _ዓብደላ_, kotw, оскі, _mráz_, 
   {{0x7bc00270,0xefd80020,0x3d0c1098,0xdd940006}},	//   _aiou, ኖረው_, _ठाणे_, пачы, 
   {{0x4c6931f1,0x7bc005c7,0xa1857cc3,0xf77c0898}},	//   рийн_, _biou, _хыял, kiç_, 
   {{0x6e38217c,0x6f197cc4,0x7bc00086,0x6834063f}},	//   _trub, _ubuc, _ciou, _ụdi, 
   {{0x6e380537,0x7bc003bd,0xf77d7cc5,0x79990590}},	//   _urub, _diou, diç_, fotw, 
   {{0x63a57cc6,0x79985b62,0x69d80bf2,0x1ccc031c}},	//   zlin, gotw, rpue, _ྲུག_, 
   {{0x69d803f4,0x7bc04056,0x63a57cc7,0xa3ac0fe3}},	//   spue, _fiou, ylin, गतम_, 
   {{0x7bc005d5,0x63a57cc8,0x65a003fa,0x69d802f6}},	//   _giou, xlin, höht, ppue, 
   {{0x79997cc9,0x63a57cca,0x75240b4b,0x00000000}},	//   botw, vlin, fejz, --, 
   {{0x6b98601a,0x63a43d25,0x79997ccb,0x69c816b8}},	//   loug, wlin, cotw, _iuge, 
   {{0x69c01140,0x63a57ccc,0x35a17ccd,0x668401b9}},	//   _iine, tlin, фарг, تیکل, 
   {{0x69c9779e,0x69c17cce,0xf8b00302,0x7bc00561}},	//   _kuge, _hine, _קשה_, _xiou, 
   {{0x69c80a5c,0x63a57ccf,0x00d819f9,0xb5f801ed}},	// [27c40] _juge, rlin, لبات_, szár, 
   {{0x69c17cd0,0x8504034c,0x6b997cd1,0xdcf83a50}},	//   _jine, _بودن, houg, rovī, 
   {{0x69c97cd2,0xc2c57cd3,0x9c7c151c,0xfa000327}},	//   _luge, _ويدي, _večk, མངོན_, 
   {{0x63a57cd4,0x69c80086,0x1ccc025c,0x7998009a}},	//   qlin, _ouge, _ྲུང_, zotw, 
   {{0x6b997cd5,0x69c17cd6,0x7bc0a573,0x799972ae}},	//   doug, _oine, _riou, yotw, 
   {{0xc0a97cd7,0x7bc17cd8,0xe65402d3,0x63ac0153}},	//   _نازل_, _siou, _ዝጸናሕ, šonė, 
   {{0x69c97cd9,0x799834ca,0x64597cda,0x6b980618}},	//   _auge, votw, _àvid, foug, 
   {{0x79997cdb,0x69c17cdc,0x00000000,0x00000000}},	//   wotw, _aine, --, --, 
   {{0x7d08074d,0xf77d7cdd,0x69c95c5f,0x9c7d7cde}},	//   pgfs, viç_, _cuge, _meči, 
   {{0x69c97cdf,0x9c7c0114,0x69c17ce0,0xdbcc01e1}},	//   _duge, _leči, _cine, _lóéj, 
   {{0x799801e0,0x6b980af9,0x7bc00036,0x7524009b}},	//   rotw, boug, _tiou, vejz, 
   {{0x69c02d65,0x69c97ce1,0x6b9814ac,0x7bd97ce2}},	//   _eine, _fuge, coug, _ittu, 
   {{0x69c97ce3,0x79997ce4,0xf77d7ce5,0x69c17ce6}},	//   _guge, potw, riç_, _fine, 
   {{0xb4b00131,0x80a8033f,0x00000000,0x00000000}},	//   дигә, _करूं, --, --, 
   {{0x69c80639,0x9c7c05a1,0xba00001f,0xe9641d39}},	//   _zuge, _beči, _ፍሬ_, _фајл_, 
   {{0x56940775,0x69c17ce7,0x2554013d,0x69c85e7c}},	//   _найт, _zine, _aşlı_, _yuge, 
   {{0x9c7c0640,0x69c17ce8,0x752401e4,0x00000000}},	// [27c50] _deči, _yine, pejz, --, 
   {{0x69c17ce9,0x7bd8003d,0xd131178c,0x30a41734}},	//   _xine, _ottu, عما_, орев, 
   {{0x6f08074d,0x6b997cea,0x7bd80083,0x62740150}},	//   tggc, youg, _nttu, _ﺗﯘرا_, 
   {{0xf1bc4822,0x5f7402f2,0x9f4c0241,0x00000000}},	//   _spád_, وانر, _ìdì_, --, 
   {{0x7bd97ceb,0x91800131,0x6b982625,0x00000000}},	//   _attu, _كۇرۇ, voug, --, 
   {{0x69c80516,0x9c7c39ae,0x8e7c0115,0x8ec401b9}},	//   _ruge, _zeči, _jeŝi, زآچم, 
   {{0x69c9727c,0x69c17cec,0x8e7c01e4,0x80d40490}},	//   _suge, _rine, _meŝi, मुळे, 
   {{0x69c17ced,0x69c97cee,0xf1ac0034,0x645800db}},	//   _sine, _puge, _जीतन, _àvie, 
   {{0x6b98025f,0x7bd80a49,0xca8401c0,0x69c17cef}},	//   roug, _ettu, ягий, _pine, 
   {{0x69c032ff,0x69c97cf0,0xdd940046,0x6b98770e}},	//   _qine, _vuge, _жауы, soug, 
   {{0x07a57cf1,0xc7a46997,0x69c8014b,0x69c17cf2}},	//   занн, зинк, _wuge, _vine, 
   {{0x69c97cf3,0x69c17cf4,0x00000000,0x00000000}},	//   _tuge, _wine, --, --, 
   {{0x9c7d7cf5,0x79e402dd,0xdd38002b,0x03a400c7}},	//   _reči, _еқыұ_, _nāśi, ҧиго, 
   {{0x9c7d7cf6,0x69c082be,0x00000000,0x00000000}},	//   _seči, _uine, --, --, 
   {{0x80a8068f,0x8e7c00df,0x33f4031c,0x7d1c000d}},	//   _करें, _deŝi, għx_, õpsi, 
   {{0xf2e40183,0xda94001f,0x37f8008f,0x42c8d021}},	//   _ফাউণ, _ውስጥና_, _פּוב, сган_, 
   {{0x9c7c0fb7,0x02043f48,0xdd3800b8,0x00000000}},	// [27c60] _veči, язан, _cāśi, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf99002e4,0x9c7c00d0,0x80a4007b,0x70140154}},	//   ערב_, _teči, أمان, ণিঝড়_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdef8052f,0xfe44a006,0x7338008f,0x9f4c110e}},	//   быҙ_, яндо, _העכס, _ìdí_, 
   {{0xee341955,0x00000000,0x00000000,0x00000000}},	//   янч_, --, --, --, 
   {{0x90e401d9,0x00000000,0x00000000,0x00000000}},	//   _تسُن, --, --, --, 
   {{0xa3ac007a,0x90700228,0x00000000,0x00000000}},	//   गति_, _جۇمش, --, --, 
   {{0x9e74215c,0x00000000,0x00000000,0x00000000}},	//   _تۇشت, --, --, --, 
   {{0x6df0007b,0x00000000,0x00000000,0x00000000}},	//   _أكلا, --, --, --, 
   {{0xa3ac7f1e,0x7bd91ede,0x6a10451a,0xdcf8002b}},	//   गता_, _uttu, وبیر, civā, 
   {{0x7b748370,0x9c7c0118,0xdb0003b2,0x00000000}},	//   _عطاا, _bečv, rmmó, --, 
   {{0xda3400c9,0x6298002f,0x00000000,0x00000000}},	//   _целы, ßvol, --, --, 
   {{0x13c40882,0x660003da,0xcca80137,0xdd3800cd}},	//   वद्भ, ámka, _اچۇۇ_, _rāśi, 
   {{0xb33870f7,0xf3650f52,0x659401ee,0x7844009d}},	//   _akça, птан, хару, _хэлж, 
   {{0xb87c01e4,0xdd3800b8,0x00000000,0x00000000}},	//   _neƭi, _pāśi, --, --, 
   {{0x65a00e78,0x9c7c00ef,0xa29400d4,0x00000000}},	// [27c70] röhr, _ieču, еаті, --, 
   {{0xdd380055,0x00000000,0x00000000,0x00000000}},	//   _vāśi, --, --, --, 
   {{0x9c7d573e,0xf484010a,0x00000000,0x00000000}},	//   _keču, _хупн, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb87c01e4,0x7e617cf7,0xa8000205,0x00000000}},	//   _deƭi, gyop, ğıiy, --, 
   {{0xdcf80a30,0x00000000,0x00000000,0x00000000}},	//   tivā, --, --, --, 
   {{0x7534022e,0x6458031c,0xfbcc00ec,0x00000000}},	//   _maxz, _żviz, لڪن_, --, 
   {{0xb698025a,0x92c0015b,0xdcf80882,0xa2b466eb}},	//   ngâs, ুরী_, rivā, _आरम्, 
   {{0x5f940724,0x92c003d4,0x10400092,0x00000000}},	//   _читт, ুৰৰ_, _የሚቀመ, --, 
   {{0x7ae4022e,0xdbdc0248,0x00000000,0x00000000}},	//   аkts, bàày, --, --, 
   {{0xabb000c7,0xec68013d,0xa2b400cd,0x00000000}},	//   _зажә, _урак_, _आरभ्, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4a4401ca,0xaa4401af,0x00000000,0x00000000}},	//   _інкв, _холҡ_, --, --, 
   {{0x1ccc025c,0x9c7c0010,0xf9a00124,0xa2b400dc}},	//   _ྲུབ_, _večv, _иқыҭ, _आरब्, 
   {{0x03a57cf8,0xa2c02886,0x00000000,0x00000000}},	//   диво, लेन्, --, --, 
   {{0x02443306,0x80a807f7,0x6d4408a5,0x00000000}},	//   وَأَ, _करौं, _ójaf, --, 
   {{0x3ab800c8,0xb5f800e5,0x00000000,0x00000000}},	// [27c80] ַמענ, lyán, --, --, 
   {{0x7e600451,0xb220013e,0x1ae40154,0x00000000}},	//   vyop, ъмул, _গাছে_, --, 
   {{0x7fd41cd0,0xb5f97cf9,0x00000000,0x00000000}},	//   фізі, nyán, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa52c08ea,0xf1ac28d4,0xf1bc012c,0x00000000}},	//   _སྲོག_, _जीवन, _psát_, --, 
   {{0x7e6000cd,0x00000000,0x00000000,0x00000000}},	//   ryop, --, --, --, 
   {{0x1b040184,0x7e600882,0x3f6853d1,0x9c7c013a}},	//   еүен, syop, _диво_, _nečt, 
   {{0x5a344149,0x2bb400ae,0x00000000,0x00000000}},	//   енит, واية_, --, --, 
   {{0x92c003d4,0xacf000d1,0x00000000,0x00000000}},	//   ুৰী_, رسۈت, --, --, 
   {{0x21380a2e,0x7c289b81,0x00000000,0x00000000}},	//   _jarh_, _мозг_, --, --, 
   {{0xa52c003d,0x9c7d7cfa,0x8e7c01e4,0x2138030a}},	//   _སྲེག_, _peču, _deŝu, _marh_, 
   {{0x3cfc11ce,0xf524025c,0xe81c00af,0xb9e40150}},	//   _hdtv_, _སིངྒ_, _बहरा_, _قستى, 
   {{0x64495d33,0x9c7cbc4a,0x00000000,0x00000000}},	//   ådin, _veču, --, --, 
   {{0x8e7c01e4,0x2138022e,0x00000000,0x00000000}},	//   _geŝu, _narh_, --, --, 
   {{0x1ccc0327,0x98bc0064,0x00000000,0x00000000}},	//   _ྲུན_, _rovė_, --, --, 
   {{0x3a244175,0x00000000,0x00000000,0x00000000}},	//   _kpop_, --, --, --, 
   {{0xe1f17cfb,0x20197cfc,0x3a240051,0xd7f8054e}},	// [27c90] لسل_, _aqri_, _jpop_, lsă_, 
   {{0x9b8001f2,0x3cfc045a,0xdca40137,0x00000000}},	//   ịghị, _ndtv_, _نۉ_, --, 
   {{0xb4e802e5,0xd7f8084c,0x92c000bd,0xa2c107c7}},	//   मरी_, nsă_, ুরে_, लेब्, 
   {{0xb0dc4a01,0x00000000,0x00000000,0x00000000}},	//   _प्रग, --, --, --, 
   {{0x8e7c0115,0xdea401b9,0x313000c7,0x00000000}},	//   _neŝt, پیلی, _иҵар, --, 
   {{0xa2b40073,0x00000000,0x00000000,0x00000000}},	//   _आरत्, --, --, --, 
   {{0x8e7c01e4,0xc0dc0023,0x0b44010b,0xb1600023}},	//   _reŝu, ዕኩም_, енйн, _ወረዳታ, 
   {{0x9c7c0010,0xdcf80356,0xdb240248,0x00000000}},	//   _rečt, tivă, _òsìs, --, 
   {{0x0d217cfd,0x9f0400cf,0x3a240051,0x9c7c013a}},	//   _бүлү, _جوقو, _cpop_, _sečt, 
   {{0x398402d3,0x9c7c02f0,0xb5f800e5,0x00000000}},	//   _ክብርቲ_, _pečt, tyán, --, 
   {{0xc678069c,0x7aec00c7,0x00000000,0x00000000}},	//   _ኣስመራ_, ãité, --, --, 
   {{0x660002fb,0x9c7c0010,0x6d18012d,0x00000000}},	//   ámko, _večt, प्रग_, --, 
   {{0xd7f8084c,0x6608033f,0x2574000d,0x6a64007b}},	//   asă_, ądko, _jälg_, _تطال, 
   {{0x16c001e0,0xb5f80022,0xb0dc03ce,0x7ae40205}},	//   шҡын, pyán, _प्लग, ıkte, 
   {{0x55c44ef9,0x20057cfe,0x644000b0,0xdb0003b2}},	//   тарғ, _āmio_, āmio, llmá, 
   {{0x02c5710c,0xc7642ba5,0x03a401f0,0x00000000}},	//   ейбо, _ساعى, хибо, --, 
   {{0x6724e601,0xf1bc0162,0x213846f4,0x2574000d}},	// [27ca0] _ibij, _spáa_, _parh_, _nälg_, 
   {{0x95a40022,0x2efc0129,0x00000000,0x00000000}},	//   _илыҵ, _aduf_, --, --, 
   {{0x213802c4,0x40950fe0,0xaadc0316,0xafe001d5}},	//   _varh_, храт, नडाक, гохл, 
   {{0x3cfc0066,0xc1d001e0,0x92c003d4,0xc4f800e5}},	//   _sdtv_, _бөжә, ুৰে_, _بٹھا_, 
   {{0x3cfd7cff,0xb178fcc6,0x67257d00,0xcf2405d9}},	//   _pdtv_, _ståe, _mbij, ئرمي, 
   {{0xb88000bc,0x2240143a,0xa2c03cc3,0x6e405957}},	//   _říms, mvik_, लेण्, انوم, 
   {{0x67240e3c,0x2efc1529,0x22400eef,0x61e57d01}},	//   _obij, _fduf_, lvik_, lpil, 
   {{0x8e7c01e4,0x61e40641,0x25740267,0x9f9400c7}},	//   _peŝt, opil, _fälg_, _рыгә, 
   {{0x61e57d02,0x6d4800c6,0x2240a20f,0xfd100103}},	//   npil, álaí, nvik_, _مجا_, 
   {{0x3f857d03,0x67257d04,0x22417d05,0xee357d06}},	//   liou_, _abij, ivik_, _яну_, 
   {{0xdb00995d,0x9c7c0219,0x224000c5,0x00000000}},	//   nomë, _večs, hvik_, --, 
   {{0x3f857d07,0xd7f80276,0x22401f53,0x0ba811dc}},	//   niou_, rsă_, kvik_, _قانى_, 
   {{0x224000f3,0x8b640132,0x61e40115,0xdb00036e}},	//   jvik_, _جالم, jpil, homë, 
   {{0x61e57d08,0x67240a49,0xd7f80276,0xb4e97d09}},	//   dpil, _ebij, psă_, मरे_, 
   {{0xa3ac28e1,0x3f8400d7,0x00000000,0x00000000}},	//   गतं_, kiou_, --, --, 
   {{0xe45412db,0x224003cd,0xdec00b82,0x00000000}},	//   ыксы, fvik_, ትልን_, --, 
   {{0x61e54fbd,0x3f857d0a,0x25740793,0x224003cd}},	// [27cb0] gpil, diou_, _bäld_, gvik_, 
   {{0x61144f41,0xdb00036e,0xb178376e,0x00000000}},	//   лдуу, fomë, _ståb, --, 
   {{0x2240bca1,0x61e57d0b,0x3f843f04,0x764801d3}},	//   avik_, apil, fiou_, _ágyb, 
   {{0xb4bc433a,0x61e4005f,0x224005ac,0x3f857d0c}},	//   ेशी_, bpil, bvik_, giou_, 
   {{0x22400122,0x60e401ed,0x82600131,0x61e400de}},	//   cvik_, ítmé, _پۇلن, cpil, 
   {{0xdb017d0d,0x3f840093,0x6448005c,0xf204014b}},	//   lomè, aiou_, ædig, _ояҳо, 
   {{0x8b94036b,0xa194013e,0x3f857d0e,0x86401954}},	//   крич, _сарч, biou_, ክርነት, 
   {{0xdb017d0f,0x0b44006c,0x3f857d10,0x81b400cc}},	//   nomè, тнин, ciou_, _চূপ_, 
   {{0x3cb00209,0x00000000,0x00000000,0x00000000}},	//   лйәр, --, --, --, 
   {{0x672400f3,0x9c7c0010,0x272c0208,0x13d803d4}},	//   _sbij, _večr, _ến_, ধীয়, 
   {{0x2d857d11,0x61e4005f,0x07088ee7,0xdb00007f}},	//   mine_, zpil, ويدي_, komè, 
   {{0x48ec012c,0x61e4023a,0x6448013c,0x3eb00210}},	//   _आजको_, ypil, ådim, żyte_, 
   {{0x2d8450c2,0xdb005c17,0x53b400af,0x25740432}},	//   oine_, domè, ंतनश, _läle_, 
   {{0x61e400da,0x3f857d12,0x2240143a,0x67243af2}},	//   vpil, ziou_, vvik_, _wbij, 
   {{0xc8a402ab,0x42d4187f,0x6aa80051,0xb5f800e5}},	//   _ऑडिट, візу, _hygf, nyáj, 
   {{0x2d857d13,0x67241326,0x61e41730,0x3f84682a}},	//   hine_, _ubij, tpil, xiou_, 
   {{0x3f8410ba,0x61e57d14,0xfccc0023,0x80d4012d}},	// [27cc0] viou_, upil, _ኣድጊ_, मुझे, 
   {{0x22417d15,0x85b80150,0x3ea00174,0xc0dc0092}},	//   rvik_, _تابس_, _økti_, _ዕትም_, 
   {{0x2d84a1f5,0x61e57d16,0x22400efa,0x246801e1}},	//   dine_, spil, svik_, _dìmú_, 
   {{0xdb017d17,0x2240dac1,0x61e4b4bb,0x2d8401ab}},	//   comè, pvik_, ppil, eine_, 
   {{0x63a57d18,0x3f857d19,0x22400357,0x2d857d1a}},	//   moin, riou_, qvik_, fine_, 
   {{0x63a57d1b,0x2d857d1c,0x3f8400d0,0xdb00a8d8}},	//   loin, gine_, siou_, momé, 
   {{0x63a497d3,0xdb017d1d,0x3f857d1e,0x2eb001e0}},	//   ooin, lomé, piou_, лсәс, 
   {{0x63a57d1f,0x7ac57d20,0x8fd4506f,0x6aa80175}},	//   noin, кспе, _сәфә, _bygf, 
   {{0xefb004d3,0x63a40618,0xb5f801d3,0x3ea400c7}},	//   _ئینگ, ioin, száz, _риаг, 
   {{0x63a57d21,0xec1001d5,0x2dc801ec,0x995400d8}},	//   hoin, _چولد, _قالۋ_, укоц, 
   {{0x63a57d22,0xbc68675b,0x6aa803b2,0xad840150}},	//   koin, _تمان_, _eygf, _شاكۇ, 
   {{0xaadc0316,0x63a57d23,0xb76441b9,0x6c7800df}},	//   _नभएक, join, ттой, _קאאפ, 
   {{0xe9340345,0x00000000,0x00000000,0x00000000}},	//   رسیت_, --, --, --, 
   {{0xdb017d24,0xb5f800e5,0x00000000,0x00000000}},	//   domé, lyák, --, --, 
   {{0x63a57d25,0xa2c058fc,0xb8640372,0xb4bc0882}},	//   foin, लेस्, _جاشو, ेशे_, 
   {{0x63a57d26,0xf84401c6,0x00000000,0x00000000}},	//   goin, _зүүд_, --, --, 
   {{0xdb017d27,0x7790a79f,0x2574002f,0x00000000}},	// [27cd0] romè, _میگا, _säle_, --, 
   {{0xdb005df4,0x758003e6,0x63a49663,0xf52400c7}},	//   llmä, _ئیسم, aoin, _рфин, 
   {{0x63a57d28,0x00000000,0x00000000,0x00000000}},	//   boin, --, --, --, 
   {{0x2d840084,0x62094c85,0x9f057d29,0x0eb83671}},	//   wine_, ürlü, لومو, нулы_, 
   {{0xdb00056a,0x71340724,0x246801e1,0x9e1400d4}},	//   comé, _иҗат_, _tìmú_, идці, 
   {{0xa2c001bc,0x6aa801bf,0x2d840129,0xdb00002f}},	//   वधर्, _rygf, uine_, hlmä, 
   {{0x2d857d2a,0xf1ac07f7,0x00000000,0x00000000}},	//   rine_, _जीएन, --, --, 
   {{0x2d857d2b,0x9c7c0219,0x80bc0073,0x00000000}},	//   sine_, _večp, वेळे, --, 
   {{0x2d857d2c,0xad247e89,0x9e345378,0x637801e1}},	//   pine_, _لراو, _кетч, _fínf, 
   {{0x2d84d0c2,0x7ae504ff,0x63a57d2d,0x00000000}},	//   qine_, ıkta, zoin, --, 
   {{0x63a43cc6,0x3664036b,0xb4bd12d8,0xadc000fb}},	//   yoin, қаро_, ेशो_, _баҡһ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2b4c2959,0x63a57d2e,0xb9907f51,0x387003e3}},	//   _ingc_, voin, _گلوب, _əyri_, 
   {{0xf2dc0548,0x00000000,0x00000000,0x00000000}},	//   _afâ_, --, --, --, 
   {{0x7bcc00d2,0xb99000f1,0x00000000,0x00000000}},	//   _ébut, _دلوب, --, --, 
   {{0x6378043b,0x63a40421,0x28dc2cca,0xdb0073a0}},	//   _míng, uoin, पुरि, tomé, 
   {{0x63a57d2f,0x63797d30,0xb17800fe,0xc2440137}},	// [27ce0] roin, _líng, _ståa, ынак, 
   {{0xdb00503f,0x7de40220,0x764801d3,0xa2c008df}},	//   romé, ңілд, _ágya, लेष्, 
   {{0xdb0078d0,0xdec002d3,0x351800df,0x00000000}},	//   llmå, ትውን_, _אוינ, --, 
   {{0x44383d97,0x63780139,0x00000000,0x00000000}},	//   _isp_, _sínf, --, --, 
   {{0x44380f85,0x9d18041b,0xfcd00092,0xfcf40092}},	//   _hsp_, волт_, _ከሕግ_, _ለሕግ_, 
   {{0x6da00640,0xed5401a9,0x00000000,0x00000000}},	//   бича, лоч_, --, --, 
   {{0x44380408,0xbc240447,0xc0dc001f,0xafe017a0}},	//   _jsp_, ارتى, _ዕድሜ_, _госл, 
   {{0x6378004e,0x39e89bf1,0x4438045a,0x00000000}},	//   _díng, ньон_, _msp_, --, 
   {{0xfce4085a,0x443804fb,0x2b74107f,0xd91007d6}},	//   _бозо, _lsp_, دینگ_, قیش_, 
   {{0x63797d31,0x20b80d26,0x44385f0b,0x00000000}},	//   _hínd, _अराध, _osp_, --, 
   {{0xa3c4006d,0x6cd000f7,0x175458d5,0x63780789}},	//   एगा_, _اقما, авня, _kínd, 
   {{0xa3d837c8,0x7c397d32,0x00000000,0x00000000}},	//   ादन_, _istr, --, --, 
   {{0x4438074d,0xb4bd7d33,0x63780332,0xeb30ba84}},	//   _asp_, ेश्_, _mínd, _دىند, 
   {{0x44397d34,0x1c18eb47,0xb8640133,0x3ea00174}},	//   _bsp_, _धमाल_, _مابو, _øktu_, 
   {{0x44397d35,0xb4b004a9,0xdb000042,0x5de801ec}},	//   _csp_, сивә, nomï, _ﺎﻨﻴﻴ, 
   {{0x44397d36,0x1dd406bc,0x00000000,0x00000000}},	//   _dsp_, ददात, --, --, 
   {{0x44397d37,0xa2c02413,0x50f45728,0x0f341b8f}},	// [27cf0] _esp_, लेल्, изат, یکرد, 
   {{0x637836ed,0x320402fb,0x64480381,0x3d0c012d}},	//   _aínd, čny_, ædic, सलों_, 
   {{0xc0dc044e,0x44397d38,0x7c380115,0x00000000}},	//   _ዕድመ_, _gsp_, _nstr, --, 
   {{0x7d18127b,0x00000000,0x00000000,0x00000000}},	//   _acts, --, --, --, 
   {{0x44397d39,0x63797d3a,0x00000000,0x00000000}},	//   _zsp_, _síng, --, --, 
   {{0x443802fa,0xe0d40640,0xe5f8010f,0x8be800cc}},	//   _ysp_, _горњ, נזור_, _গিবন_, 
   {{0x7c397d3b,0xb3380166,0x66080210,0x00000000}},	//   _cstr, _akçi, ądki, --, 
   {{0x7c3801f5,0x7d197d3c,0x637803f2,0x00000000}},	//   _dstr, _ects, _víng, --, 
   {{0x7c396d3d,0xc9553c01,0x49940107,0xca7401e0}},	//   _estr, атны, ишот, руйы, 
   {{0x6e397d3d,0x63797d3e,0x00000000,0x00000000}},	//   _isub, _tíng, --, --, 
   {{0x29c40228,0x91780051,0x00000000,0x00000000}},	//   ктүү_, _cẩn_, --, --, 
   {{0x44389825,0xc7a400d6,0x07a532c6,0x6e3801e4}},	//   _rsp_, римк, рамн, _ksub, 
   {{0xda0800aa,0x9f5c01d3,0x00000000,0x00000000}},	//   _مينه_, évé_, --, --, 
   {{0x69d97d3f,0xb17801e6,0x6e38009f,0x2574008e}},	//   mque, _stån, _msub, _bäla_, 
   {{0x63797d40,0x7c381730,0x03a97d41,0x6f180117}},	//   _líne, _xstr, ندرو_, _ocuc, 
   {{0x6e397d42,0x46497d43,0xeaf0000d,0x00000000}},	//   _osub, _азин_, _इजोत_, --, 
   {{0x42c8006c,0x6e38cd30,0x63780241,0xa5500023}},	// [27d00] тган_, _nsub, _rínd, _ኣገልጊ, 
   {{0x6f197d44,0xb5f808a8,0x69d800db,0x9f4c0241}},	//   _acuc, _שליכ, ique, _ìdú_, 
   {{0x6e397d45,0x69d8faf0,0x3fc407d6,0x63797d46}},	//   _asub, hque, لگری_, _pínd, 
   {{0xf8b00302,0xb1780fac,0x69d802d0,0x70500345}},	//   חשב_, _utån, kque, تنما, 
   {{0x7c380208,0xd2b8498b,0x00000000,0x00000000}},	//   _sstr, _бурч_, --, --, 
   {{0x6f18014b,0x947001d9,0x69d80113,0xbc041ebb}},	//   _ecuc, _بۯہا, dque, ачий, 
   {{0x6e397d47,0x7c380175,0x69d8002f,0x6378032e}},	//   _esub, _qstr, eque, _tínd, 
   {{0x29d8025a,0x7c397d48,0x6378007b,0x6e380175}},	//   _bêa_, _vstr, _fíne, _fsub, 
   {{0x69d80113,0x7c38033f,0x637802d2,0xb17801e3}},	//   gque, _wstr, _gíne, _otål, 
   {{0x7d1803ac,0x7f40022e,0x8e84009f,0x00000000}},	//   _ucts, ldoq, _الٰه, --, 
   {{0x7c397d49,0x96f97d4a,0xdb000421,0x69d8a547}},	//   _ustr, лент_, lomí, aque, 
   {{0x7f417d4b,0x69d97d4c,0x70d0694b,0xaa843c5b}},	//   ndoq, bque, _तल्ल, انیم_, 
   {{0xdb0026c8,0x7ae17d4d,0x6e38037e,0x25740139}},	//   nomí, _ifot, _xsub, _säla_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb0002f0,0x92a8012d,0xf3840798,0x00000000}},	//   homí, kołó, аѓам, --, 
   {{0xe92031d9,0xb4b43027,0x25740267,0xe3746518}},	//   _འཁོབ_, _जरी_, _väla_, олсы, 
   {{0x2ba40073,0x620401d9,0x00000000,0x00000000}},	// [27d10] खवता, ٲومٕ, --, --, 
   {{0x9f580801,0x6f1819f5,0xdb000306,0x00000000}},	//   _avrà_, _scuc, domí, --, 
   {{0x53348d20,0x69d97d4e,0x7ae17d4f,0x63780aaa}},	//   _лент, zque, _ofot, _síne, 
   {{0x3b057d50,0x201c381a,0x00000000,0x00000000}},	//   _ndoq_, àvia_, --, --, 
   {{0x0354008d,0x69d807ea,0x6f1801ef,0x00000000}},	//   _הירש_, xque, _vcuc, --, 
   {{0x7ae17d51,0x6adc1524,0x63784158,0x00000000}},	//   _afot, नड्र, _víne, --, 
   {{0x92a80210,0x00000000,0x00000000,0x00000000}},	//   bołó, --, --, --, 
   {{0x6e397d52,0x69d97d53,0xdfb87f51,0xa3d80034}},	//   _tsub, tque, _ناقص_, ादत_, 
   {{0x69d81497,0x8e840597,0xf1bc00e4,0x7ae00221}},	//   uque, _الذه, _apái_, _dfot, 
   {{0x7ae17d54,0xde7400e3,0xdd9001d3,0x00000000}},	//   _efot, _بدفع, _ہوۓ_, --, 
   {{0x7ae04e0b,0xb6a0134b,0x00000000,0x00000000}},	//   _ffot, җирл, --, --, 
   {{0x6d417d55,0x69d83af1,0x25dc012d,0x00000000}},	//   ldna, pque, _गंदी_, --, 
   {{0xc9280323,0xf1bc0085,0x637800d2,0xa9a001d9}},	//   _болж_, _epái_, _línc, _وۅبى, 
   {{0x6d417d56,0x81d404c5,0xf1d81d15,0x2b5c01a6}},	//   ndna, _সবল_, _बढ़न, ljuc_, 
   {{0x2904009a,0x3b04022e,0x00000000,0x00000000}},	//   _idna_, _ydoq_, --, --, 
   {{0x6d40f72e,0xb33803e0,0xb5f80022,0xf8b0011a}},	//   hdna, _okçu, vyáv, _משו_, 
   {{0xdb000798,0xfd9c063f,0x00000000,0x00000000}},	// [27d20] lomã, hụọ_, --, --, 
   {{0x41b4085a,0x660472e9,0xb17808cb,0xdb000419}},	//   ёсат, _ivik, _utål, vomí, 
   {{0xa2b428d4,0x80a400f7,0x04440724,0xfd9c063f}},	//   _आरक्, حمان, _уенн, jụọ_, 
   {{0x66057d57,0xdb002b76,0x645c0007,0x4f957d58}},	//   _kvik, tomí, mxri, орчу, 
   {{0x6d400d27,0xde583981,0x9e140212,0x2fc4000f}},	//   fdna, ралі_, ідкі, ïnga_, 
   {{0xdb017d59,0x7ae17d5a,0x6da01bc4,0x86640092}},	//   romí, _sfot, пича, _ልዩነት, 
   {{0xa3d8258d,0x7ae17d5b,0x645d7d5c,0xdb017d5d}},	//   ादि_, _pfot, nxri, somí, 
   {{0x66057d5e,0xdb00031d,0x29057d5f,0x657c0036}},	//   _ovik, pomí, _adna_, hhrh, 
   {{0x2fdc00f3,0xaa50005b,0xf1bc032e,0x39a400d4}},	//   _čugi_, звыш, _spái_, йшов, 
   {{0xa3d80d5f,0xb8640372,0x29040f85,0xd8f800d4}},	//   ादा_, ماجو, _cdna_, шної_, 
   {{0x66043209,0x2c0813de,0x7bcc011c,0xdb000311}},	//   _avik, _معنی_, _èbuo, româ, 
   {{0x7bd80393,0xbfb401fb,0x68e008a5,0xfbcc00ec}},	//   _iutu, _điềm_, _efnd, _ڪڪڙ_, 
   {{0x66057d60,0x7bd97d61,0x59f80276,0x644803b2}},	//   _cvik, _hutu, _теля_, ædin, 
   {{0x7bd97d62,0x53901772,0x66045b7c,0xfbcc00ec}},	//   _kutu, _ነብያት_, _dvik, _تڪڙ_, 
   {{0x7bd818db,0x66057d63,0x332801c0,0xdec002d3}},	//   _jutu, _evik, лцан_, _ስዉእ_, 
   {{0x25757d64,0x7bd8adfe,0xdb00004e,0x6d400010}},	//   _häll_, _mutu, nomà, zdna, 
   {{0x6d417d65,0x68e0062c,0x92597d66,0x22580108}},	// [27d30] ydna, _yfnd, шаат_, биты_, 
   {{0x7bd87c36,0x657c002f,0x00000000,0x00000000}},	//   _outu, chrh, --, --, 
   {{0x7bd97d67,0x66041cbd,0xc0e800b7,0x00000000}},	//   _nutu, _zvik, ቅላላ_, --, 
   {{0x6379108d,0xb300025c,0x00000000,0x00000000}},	//   _vínc, _མཇིང_, --, --, 
   {{0xfd9c063f,0x7bd81948,0x6d4003ac,0x2c440051}},	//   wụọ_, _autu, tdna, _sđd_, 
   {{0x637800d2,0xb5f801ed,0x80a802ab,0x00000000}},	//   _tínc, lyás, _जुवे, --, 
   {{0x7bd97d68,0x6d417d69,0x63780022,0x251c010f}},	//   _cutu, rdna, _hína, אווא, 
   {{0x7bd81d54,0xa2c007af,0x637800e7,0xb5f801d3}},	//   _dutu, लेक्, _kína, nyás, 
   {{0x257401c7,0x64580129,0xfb8401d5,0x0d2000cf}},	//   _bäll_, _àviv, تدوی, _жүлү, 
   {{0x63782833,0xcdc40137,0x88d80022,0xaee00055}},	//   _mína, _بۇتۇ_, шьит_, biṃb, 
   {{0x7bd894a7,0x66057d6a,0x98bc02e2,0x7988035a}},	//   _gutu, _svik, _favč_, _dmfw, 
   {{0x798803ac,0xca7401af,0x00000000,0x00000000}},	//   _emfw, _мулы, --, --, 
   {{0x7bd97d6b,0x25754818,0x6b880334,0x637802d2}},	//   _zutu, _fäll_, _imgg, _nína, 
   {{0x7bd97d6c,0x25740036,0xdb2400e4,0x00000000}},	//   _yutu, _gäll_, _ęsév, --, 
   {{0xdb0001ed,0x81d4015b,0x00000000,0x00000000}},	//   lomá, _সবই_, --, --, 
   {{0x66040158,0xb5f801ed,0x6378013d,0x00000000}},	//   _tvik, gyás, _bína, --, 
   {{0xc2086abd,0x66057d6d,0x957805f5,0x53140276}},	// [27d40] شقان_, _uvik, рөөс_, яфру, 
   {{0x644801e3,0x052800cf,0xdb100166,0x00000000}},	//   ådis, _тоок_, _öföl, --, 
   {{0x3978008f,0x00000000,0x00000000,0x00000000}},	//   סטענ, --, --, --, 
   {{0x7bd97d6e,0x637805f7,0xdd90129e,0xdb0000e5}},	//   _rutu, _fína, کوت_, komá, 
   {{0x7bd97d6f,0xd5ac01d9,0xbda4a864,0xb5f801d3}},	//   _sutu, _شہہ_, يحتو, lyár, 
   {{0x7bd95d6e,0xdb0000dd,0x98ac054e,0x00000000}},	//   _putu, domá, nedă_, --, 
   {{0x7bd97d70,0xdb0000f7,0x7f18177b,0x798802d0}},	//   _qutu, tomà, _візу_, _rmfw, 
   {{0x7bd97d71,0x257401c7,0xdb015ce3,0xef144965}},	//   _vutu, _säll_, fomá, _ммс_, 
   {{0x7bd97d72,0xdb00311a,0xda340276,0xe5200dba}},	//   _wutu, gomá, чепы, _बाढि_, 
   {{0x32540375,0xada002dd,0xdb00004e,0x798802d0}},	//   קסים_, _жаул, somà, _qmfw, 
   {{0x7bd802f6,0x257401e6,0xb17803cd,0x313402e4}},	//   _uutu, _väll_, _ståk, חנים_, 
   {{0xdbf000bd,0x257404e6,0xdd900244,0x00000000}},	//   _টিপস_, _wäll_, _توڕ_, --, 
   {{0x7bc00b6f,0x5a240003,0xdb000789,0x96f800d1}},	//   _ihou, _འདྲེ_, comá, _һейт_, 
   {{0x7bc005c7,0x98ac0356,0x637802d2,0x00000000}},	//   _hhou, gedă_, _rína, --, 
   {{0xf36470df,0x7bc0052f,0x7998d059,0x637809cc}},	//   отан, _khou, mntw, _sína, 
   {{0x63780174,0x96f80022,0x00000000,0x00000000}},	//   _pína, _уеит_, --, --, 
   {{0xb1780158,0x52140212,0x799801a4,0x64480fac}},	// [27d50] _utåk, ядат, ontw, ådir, 
   {{0x79997d73,0x7bc00076,0x6378b8a3,0x30e97d74}},	//   nntw, _lhou, _vína, рфан_, 
   {{0x7bc00270,0xe520007d,0x799802d0,0xfbc800cd}},	//   _ohou, _बाति_, intw, ागाम, 
   {{0x6378022c,0xdb0001ed,0x64580427,0x00000000}},	//   _tína, yomá, _švig, --, 
   {{0xea9c0055,0x63780ca8,0x00000000,0x00000000}},	//   _dhṛk_, _kínn, --, --, 
   {{0x79980218,0x7bc06c98,0xdb0002f0,0xf1bc013a}},	//   jntw, _ahou, vomá, _cpát_, 
   {{0x4c685ded,0x7bc005c7,0x64580129,0x637801e1}},	//   сийн_, _bhou, _àvit, _mínn, 
   {{0xdb005599,0x79997d75,0xb17801e3,0xc050011a}},	//   tomá, entw, _ståh, _אזל_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7bc00270,0xdb017d76,0x0d20004e,0xa2c006e3}},	//   _ehou, romá, _чүкү, लेट्, 
   {{0xf8cc085c,0x5eb0015b,0x00000000,0x00000000}},	//   _हृदय, জেদে, --, --, 
   {{0x7bc04f82,0xdb000122,0x917801fb,0x64480194}},	//   _ghou, pomá, _lần_, ædim, 
   {{0xdb4c03e6,0x7f38008f,0xb8d00406,0x98ac0356}},	//   _ڵێی_, זערו, _झु_, tedă_, 
   {{0x7bc17d77,0x6b9803b2,0x6ea00037,0xb5f800e5}},	//   _zhou, lnug, _छुछु, tyár, 
   {{0x69c17d78,0x35a17d79,0xb3e400cc,0x48080395}},	//   _ihne, харг, _ফিউজ, _уейн_, 
   {{0x6b997d7a,0x46a40826,0x637801e1,0x98ac054e}},	//   nnug, _найв, _eínn, sedă_, 
   {{0x00d80e76,0x63797d7b,0x2574000d,0xc2c400ec}},	// [27d60] مبات_, _fínn, _jälk_, سيئي, 
   {{0x254c043b,0x917801fb,0x63780241,0x61440131}},	//   kɔlɔ_, _cần_, _gínn, بىئە, 
   {{0x04c80451,0x6b980162,0x91780208,0x823400e5}},	//   _دودي_, knug, _dần_, _کرجا, 
   {{0x03a4039b,0xf1bc0118,0x98bc0055,0x00000000}},	//   _химо, _spát_, _javā_, --, 
   {{0x69c14264,0x501c02dd,0xbfc40022,0x95740092}},	//   _ohne, _ءﻣﺎﻥ_, _ҕбак, _ያለብን_, 
   {{0x7bc06c7c,0x98bd31bf,0x64595368,0x257401e6}},	//   _shou, _lavā_, _àvis, _sälj_, 
   {{0x7bc17d7c,0x64585178,0x62857d7d,0x3154010f}},	//   _phou, _ávid, lzio, _צילן_, 
   {{0x26c0011c,0x69c17d7e,0x79980407,0x98bc00b8}},	//   _ozio_, _ahne, wntw, _navā_, 
   {{0x62849933,0x257404f3,0x69c00332,0xe23002dd}},	//   nzio, _välj_, _bhne, етiн_, 
   {{0x62857d7f,0x79980c8c,0xcce406f6,0x69c17d80}},	//   izio, untw, _قسمي, _chne, 
   {{0x7bc0771c,0x26c0008f,0xad400372,0x69c00175}},	//   _thou, _azio_, _سۉيۉ, _dhne, 
   {{0x628405f5,0xba2804fb,0x7bc00418,0x69c0005a}},	//   kzio, _هستم_, _uhou, _ehne, 
   {{0x0ba843a0,0x63780241,0x3cfc00c0,0xbab8fae3}},	//   _بالى_, _pínn, _ketv_, _اداء_, 
   {{0x62857d81,0xa3d80a94,0xf8057d82,0x69c000a3}},	//   dzio, ादं_, _ечин, _ghne, 
   {{0x92b803f4,0x62857d83,0x26c097d0,0xf7e80c75}},	//   _চলে_, ezio, _ezio_, _ارتى_, 
   {{0x63684afa,0x46ac0521,0x98bc00b8,0xa3440276}},	//   пруг_, ọtọ_, _gavā_, нэул, 
   {{0x6234084c,0xa6140064,0x00000000,0x00000000}},	// [27d70] нету, _змыч, --, --, 
   {{0x64580953,0xdb003167,0x637800d7,0x00000000}},	//   _švie, lomä, _fíno, --, 
   {{0x62857d84,0xf1bc00c6,0x3a2401a9,0xa3d800dc}},	//   azio, _spás_, _lqop_, ादः_, 
   {{0x63780241,0x9314007b,0xf2040153,0x00000000}},	//   _jínl, _توحش, _няго, --, 
   {{0x91780051,0x00000000,0x00000000,0x00000000}},	//   _tần_, --, --, --, 
   {{0x3cfc01ef,0x00000000,0x00000000,0x00000000}},	//   _cetv_, --, --, --, 
   {{0xb3280003,0x6b997d85,0x251c010f,0xdb000821}},	//   _སྡོང_, tnug, צוהא, komä, 
   {{0xfaec004b,0x69c17d86,0x74bc00eb,0x00000000}},	//   لګه_, _shne, _আলাউ, --, 
   {{0x254c0085,0x2bdc00af,0x6b997d87,0xdef80022}},	//   sɔlɔ_, _पंवा, rnug, _хыс_, 
   {{0x98bc00da,0x6448392f,0x7e74332c,0xdd957d88}},	//   _savā_, ædik, øype, _зауы, 
   {{0x07a57d89,0xc7a561b7,0x62840ba3,0xbb780014}},	//   данн, динк, zzio, _ڈلٕچ_, 
   {{0x3cfc0472,0xdb00000d,0x7c2c0139,0xb6000419}},	//   _zetv_, gomä, _äbra, zváň, 
   {{0x3cfd7d8a,0x2efc004a,0x2574010b,0x00000000}},	//   _yetv_, _meuf_, _häli_, --, 
   {{0x69c00175,0xfa3000db,0xcfa80116,0x00000000}},	//   _uhne, _شىىج, ﺴﭙﺎﺗ, --, 
   {{0x2efd7d8b,0x98bc1c52,0xb9b00244,0x7d1c00db}},	//   _oeuf_, _tavā_, _جموع, òpsi, 
   {{0x2efd7d8c,0x637802fb,0x6284009d,0xbd9c0023}},	//   _neuf_, _víno, tzio, ልኪቶም_, 
   {{0x26c001c8,0x6284e2ac,0x00000000,0x00000000}},	// [27d80] _uzio_, uzio, --, --, 
   {{0x62857d8d,0x51443e64,0xf1bd7d8e,0xd87400db}},	//   rzio, ндуғ, _spár_, _تاۇب, 
   {{0x83c49fb7,0x2efc3012,0xd5e801d5,0x98ac0064}},	//   _обож, _beuf_, _وعین_, pedą_, 
   {{0x628401c0,0x44280407,0x9178004d,0x00000000}},	//   pzio, mtb_, _vấn_, --, 
   {{0x442801f5,0x00000000,0x00000000,0x00000000}},	//   ltb_, --, --, --, 
   {{0x2d54023a,0xefb0006c,0x91780208,0x2f500166}},	//   дишь_, _ییلگ, _tấn_, етәс, 
   {{0x672422c1,0x442818b0,0xac9412e3,0x63780332}},	//   _ocij, ntb_, ونها_, _línm, 
   {{0x25757d8f,0x60dc0076,0x6d5000e2,0xdcf800e2}},	//   _däli_, _hgrm, _ādaž, tivē, 
   {{0x44297d90,0x61e57d91,0xceb40131,0x463c0023}},	//   htb_, nqil, _пәш_, ራተጅያ, 
   {{0x98bc0311,0x21e40254,0xb7e40220,0x51c802dd}},	//   _navă_, _möh_, _ﺍﻟﺭﻏ, _ﺒﺎﻟﺸ, 
   {{0xed4c15fa,0xdb00040e,0x2efc00e8,0x63781d0e}},	//   _خپل_, tomä, _yeuf_, _pínl, 
   {{0xfbd042b5,0x44280175,0xd5e80327,0x3e3c0092}},	//   _شتا_, dtb_, _འཕྱག, _ባይኖር, 
   {{0x7e6002c4,0x7c281196,0xdb003167,0xf988004b}},	//   nxop, ltfr, gomå, _وخته_, 
   {{0x67240656,0x22417d92,0x44280334,0x00000000}},	//   _ecij, dwik_, ftb_, --, 
   {{0x7c297d93,0xe520000d,0x91780051,0xd7940395}},	//   ntfr, _बारि_, _lẫn_, _пикъ, 
   {{0x64597d94,0xc0dc02d3,0xb4004ecc,0x637802d2}},	//   _švic, _ንስለ_, нүүд, _fínm, 
   {{0x2efc01fa,0x61e4016c,0x4428009d,0x7c2802d0}},	// [27d90] _reuf_, gqil, atb_, htfr, 
   {{0x7c297d95,0x2efc01bf,0x00000000,0x00000000}},	//   ktfr, _seuf_, --, --, 
   {{0xe5703229,0x61e4013c,0x6f8401ee,0x00000000}},	//   _خطي_, aqil, мудж, --, 
   {{0x7c28077b,0x3de400cc,0x00000000,0x00000000}},	//   dtfr, _নিজল, --, --, 
   {{0x8db402d5,0x2efc0129,0xb178007c,0x00000000}},	//   нскі, _veuf_, _ståu, --, 
   {{0x7c280423,0x9178004d,0x2574010e,0xb0300ce8}},	//   ftfr, _dẫn_, _päli_, _имгә, 
   {{0x7c2800b5,0x3d2800f1,0x2efc0129,0x00000000}},	//   gtfr, ستوی_, _teuf_, --, 
   {{0x25757d96,0x4a4415ab,0x60dc0010,0xaf342bef}},	//   _väli_, енив, _zgrm, _ترست, 
   {{0x3ab041fd,0x5eb434b1,0xe5201524,0x257400fd}},	//   ләшт, _айтт, _बालि_, _wäli_, 
   {{0x08880262,0x67254401,0x63780241,0x3de400cc}},	//   збой_, _scij, _rínm, _নিচল, 
   {{0x44285948,0x00000000,0x00000000,0x00000000}},	//   xtb_, --, --, --, 
   {{0x1bb97d97,0xc050008f,0xbe6000db,0x00000000}},	//   _قانع_, אזט_, _جۇۇي, --, 
   {{0x44280175,0x00000000,0x00000000,0x00000000}},	//   wtb_, --, --, --, 
   {{0x6378004e,0x44280113,0xdb0001e3,0x00000000}},	//   _gínj, ttb_, romå, --, 
   {{0x91f4031c,0xb978011a,0x21e406be,0x00000000}},	//   _བསྔག_, _מנסי, _söh_, --, 
   {{0x61e40d04,0x67240841,0x06080022,0x96900344}},	//   tqil, _ucij, _еник_, اییش, 
   {{0x98bc0356,0x00000000,0x00000000,0x00000000}},	// [27da0] _tavă_, --, --, --, 
   {{0x31217d98,0x61e57d99,0x00000000,0x00000000}},	//   лдуг, rqil, --, --, 
   {{0x61e40113,0x7c28aa3d,0x22408d0f,0x00000000}},	//   sqil, xtfr, swik_, --, 
   {{0xb178ce29,0x3ea40220,0x7e60005a,0x78840129}},	//   _ståt, ниег, txop, _hévé, 
   {{0x61e57d9a,0xb328025c,0x8fd40daf,0x637803b2}},	//   qqil, _སྡིང_, тәрә, _línk, 
   {{0xa3d80acd,0x917801fb,0x1138013d,0xabd401ec}},	//   ादक_, _vẫn_, _оясы_, _ﺟﺎﺭﻋ, 
   {{0x50b4da7c,0x71a0013e,0x98bc0153,0x00000000}},	//   _асту, _сарз, _kavą_, --, 
   {{0x5a349780,0x7c297d9b,0xbfa80014,0x29000ad9}},	//   внит, rtfr, _رازٕ_, ðjan_, 
   {{0x25dc01ad,0x7338010f,0x00000000,0x00000000}},	//   _गंगी_, לעקס, --, --, 
   {{0xbd897d9c,0x7bdd7d9d,0x7c297d9e,0xb92401d5}},	//   _عنان_, ípus, ptfr, хфий, 
   {{0xe97001d9,0x65e400c7,0x00000000,0x00000000}},	//   انپھ, қәыҧ, --, --, 
   {{0x63780241,0x257400c5,0xa4fc031c,0xdce802e2}},	//   _dínk, _mälu_, _དབུག_, _modč, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x199414f7,0x637802d2,0xa9640dab,0x00000000}},	//   _шаля, _fínk, _пича_, --, 
   {{0xf8b40220,0x24597d9f,0x00000000,0x00000000}},	//   _سۇحب_, нарь_, --, --, 
   {{0xb28400c7,0x00000000,0x00000000,0x00000000}},	//   нызк, --, --, --, 
   {{0xe9d4013d,0x00000000,0x00000000,0x00000000}},	// [27db0] _юкә_, --, --, --, 
   {{0xe2c800aa,0xe290007b,0xdcf80166,0x00000000}},	//   رولو_, حذف_, kovı, --, 
   {{0xb1780b34,0x059400f2,0x00000000,0x00000000}},	//   _stås, _جايگ, --, --, 
   {{0x637801e1,0x9f5003b2,0xdcf80139,0xf36401f4}},	//   _nính, áaði_, dovı, _чтон, 
   {{0x63a816d9,0x00000000,0x00000000,0x00000000}},	//   édne, --, --, --, 
   {{0xdb000005,0xb17801bf,0x7e740158,0x6ce400d4}},	//   comú, _etår, øypa, хіде, 
   {{0xc0dc02d3,0xdbcc0241,0x8b68009d,0x00000000}},	//   ንኩም_, _róòj, дийв_, --, 
   {{0x2574097d,0xdfd57da0,0xc0dc0092,0x80a83be5}},	//   _hält_, _босы, _ንስሐ_, _जुटे, 
   {{0x637800d2,0x25740036,0x15e002e5,0x7bdc03b2}},	//   _sínk, _kält_, _गूलर_, ípur, 
   {{0x6378032e,0x00000000,0x00000000,0x00000000}},	//   _pínk, --, --, --, 
   {{0x7884a4e8,0x78600276,0x6378032e,0xd7f80006}},	//   _révé, акэз, _fính, нуў_, 
   {{0xf2dc05bb,0xc62400bd,0xf42400bd,0x788406af}},	//   _ngâ_, যবসা_, মবার_, _sévé, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x63797da1,0x26c401e4,0x98bc00c0,0xa2b001f9}},	//   _tínk, ĥmo_, _savą_, ंथस्, 
   {{0xd41402d5,0x55c46518,0xa3040661,0xefbc0023}},	//   льты, уарғ, лүне, ስምዕ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc0e42f45,0x788401ed,0xdce80010,0x02bc043e}},	// [27dc0] возк, _tévé, _sodč, ्धेन, 
   {{0xb17800fe,0xdce8a409,0xb6180150,0x361800df}},	//   _står, _podč, _ﺠﺩ_, _קויד, 
   {{0x63797da2,0x60980014,0xdb000332,0x7578011a}},	//   _líni, رۆرس_, romú, _חטיפ, 
   {{0x44397da3,0xdb0040fc,0x00000000,0x00000000}},	//   _ipp_, llmö, --, --, 
   {{0x2575696f,0xb3c406a6,0x443802f0,0xcf2406c2}},	//   _fält_, _шлюз_, _hpp_, ارمي, 
   {{0xc0e400d8,0xed5400db,0x00000000,0x00000000}},	//   _јовк, коч_, --, --, 
   {{0x4438007f,0x51540276,0x257401c7,0xed541677}},	//   _jpp_, _стяу, _häls_, тој_, 
   {{0x44397da4,0xee340cef,0xdb000112,0xdce40022}},	//   _mpp_, хнә_, hlmö, _ӡбаҩ, 
   {{0xfd1042b5,0x44397da5,0x657c02d0,0x69c4003d}},	//   _نجا_, _lpp_, kkrh, ċjen, 
   {{0x44397da6,0x3f857da7,0x637801e7,0x98ac01ef}},	//   _opp_, lhou_, _díni, cedě_, 
   {{0x63797da8,0x3f857da9,0x17980474,0x7118010f}},	//   _tính, ohou_, евны_, וויפ, 
   {{0x3f857daa,0x7c380857,0xeb309498,0x63797dab}},	//   nhou_, _iptr, _نىمد, _fíni, 
   {{0xb5f800dd,0x79a40daf,0x39a40117,0x00000000}},	//   lyáz, _ирке, _ишкв, --, 
   {{0x779008dc,0x79500345,0xea7400d9,0x00000000}},	//   _چیدا, _ئێدا, _בגדר_, --, 
   {{0xb35439b1,0x7c3804ce,0x3f843438,0x44397dac}},	//   نیدا_, _jptr, khou_, _cpp_, 
   {{0x4438055a,0x31d800dc,0xdec00b82,0x28a800cd}},	//   _dpp_, बद्ध, ስልን_, _घुटि, 
   {{0x44397dad,0x645801a8,0x3f849df9,0xa3d43edd}},	// [27dd0] _epp_, _ávin, dhou_, ротч, 
   {{0x7c388aad,0x44380175,0x657c6460,0xa698011a}},	//   _optr, _fpp_, ckrh, _שכזה_, 
   {{0x443804a4,0x6448003a,0x2574007c,0xdb000254}},	//   _gpp_, ædit, _vält_, llmõ, 
   {{0x257404cc,0x5ecc015b,0x3f840ea0,0x15cc01ec}},	//   _wält_, িশনে, ghou_, _ﻓﻌﻠﻬ, 
   {{0xb284100e,0x443809a8,0x7c397dae,0x25740267}},	//   _рынк, _zpp_, _aptr, _tält_, 
   {{0x7c397daf,0x00000000,0x00000000,0x00000000}},	//   _bptr, --, --, --, 
   {{0x63780597,0x4438010a,0xe8dc063f,0xa1957db0}},	//   _síni, _xpp_, ndụl_, _тарч, 
   {{0x3f84d926,0x0b457db1,0x0a4811ac,0x63797db2}},	//   chou_, унин, езий_, _dínw, 
   {{0x6e0000d1,0x91b801f9,0x00000000,0x00000000}},	//   _ئېتن, ्तपै, --, --, 
   {{0x6e38014b,0x637803f2,0x00000000,0x00000000}},	//   _ipub, _víni, --, --, 
   {{0x2d847ea1,0xada002fb,0x00000000,0x00000000}},	//   mhne_, _vyúč, --, --, 
   {{0x44397db3,0x19c401c0,0x63781d0e,0xb8ec01e1}},	//   _rpp_, лбөм, _tíni, _lẹhì, 
   {{0x63780008,0xdce80055,0xaac400c5,0x4438045a}},	//   _kínv, _hodā, _लरिक, _spp_, 
   {{0x3f857db4,0x5eb0015b,0x19a8151e,0x257401e3}},	//   zhou_, জেকে, _үтәп_, _räls_, 
   {{0xdb000254,0x00000000,0x00000000,0x00000000}},	//   almõ, --, --, --, 
   {{0xe520007d,0x6e380034,0x25740267,0x42d402dd}},	//   _बाकि_, _opub, _päls_, гізу, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [27de0] --, --, --, --, 
   {{0x44397db5,0x2d84151c,0xc0f00023,0x48e00154}},	//   _tpp_, jhne_, _ሂቦም_, _মজুর, 
   {{0x44397db6,0x3f840591,0x442c00e8,0x2d840192}},	//   _upp_, thou_, _ëf_, dhne_, 
   {{0x3f857db7,0x749827af,0x6e3801e7,0xeaa4007b}},	//   uhou_, _טייפ, _bpub, _هع_, 
   {{0x63a57db8,0x3f840660,0x7c3800d8,0x98bc0064}},	//   mnin, rhou_, _sptr, _davę_, 
   {{0x63a57db9,0x3f857dba,0xd1745680,0x2d857dbb}},	//   lnin, shou_, _кысы, ghne_, 
   {{0x6e397dbc,0xdce8002b,0x3f8405e4,0x200c0248}},	//   _epub, _codā, phou_, _ìdi_, 
   {{0x2d840030,0x98bc0153,0x9cc80022,0x00000000}},	//   ahne_, _gavę_, нықа_, --, 
   {{0xbea4e737,0xefb026f0,0x63a57dbd,0x2d847ea6}},	//   _саак, _اینگ, inin, bhne_, 
   {{0x63a57dbe,0x7f40003a,0x00000000,0x00000000}},	//   hnin, leoq, --, --, 
   {{0x63a439c3,0xa3b57dbf,0x7c38009f,0xdce81981}},	//   knin, टवा_, _uptr, _godā, 
   {{0x63a57dc0,0x7d097dc1,0xac1005d9,0xf0900375}},	//   jnin, lafs, _اڳوڻ, מנת_, 
   {{0x7ae17dc2,0x91b85162,0xa2b01b76,0x00000000}},	//   _igot, ्तमै, _अँग्, --, 
   {{0x7d0800b2,0x63782242,0x58d510b2,0xba9405d9}},	//   nafs, _mínu, _колт, _لاڙڪ, 
   {{0x7ae17dc3,0x64582792,0x9814168d,0x63a57dc4}},	//   _kgot, _ávil, _ڵبژا, fnin, 
   {{0x63a45537,0x7d097dc5,0x79997dc6,0xd7f80311}},	//   gnin, hafs, litw, mpă_, 
   {{0x799801c8,0x23380220,0xd7f80311,0x779003e6}},	// [27df0] oitw, ыпты_, lpă_, _نیگا, 
   {{0x7998970f,0xf5257dc7,0x63a57dc8,0x394c0fac}},	//   nitw, _сфин, anin, _jafs_, 
   {{0x63a57dc9,0x53357dca,0x79980433,0x6e38022e}},	//   bnin, _кент, iitw, _spub, 
   {{0x7ae17dcb,0x79997dcc,0x63a41a33,0x6e380003}},	//   _ngot, hitw, cnin, _ppub, 
   {{0x2d840fa3,0x11d80597,0x3ddc0042,0x79997dcd}},	//   thne_, _لوحة_, _bitw_, kitw, 
   {{0x394d7dce,0x7ae11d8c,0x3b0408e7,0x79997dcf}},	//   _nafs_, _agot, _aeoq_, jitw, 
   {{0x4c69137a,0x79997dd0,0x7f40003a,0x2d840306}},	//   тийн_, ditw, beoq, rhne_, 
   {{0x6378041e,0x201c0306,0xdce80055,0x00000000}},	//   _fínu, ávie_, _vodā, --, 
   {{0x2d857dd1,0xad249cc3,0x6f080163,0x79997dd2}},	//   phne_, _مراو, magc, fitw, 
   {{0x63a4006c,0x7ae17dd3,0x79997dd4,0x6f0953fb}},	//   znin, _egot, gitw, lagc, 
   {{0x63a41bb7,0x6ca4016a,0x7ae00175,0x394c002f}},	//   ynin, _сраж, _fgot, _dafs_, 
   {{0x63a473df,0x00000000,0x00000000,0x00000000}},	//   xnin, --, --, --, 
   {{0x79997dd5,0x6d407ae3,0x6b98013c,0xd7f80311}},	//   bitw, oena, miug, apă_, 
   {{0x63a57dd6,0x15b80372,0x6b997dd7,0x2fdc8d4a}},	//   wnin, гысы_, liug, _liug_, 
   {{0x29040395,0x63780005,0x6f09468a,0x03940945}},	//   _iena_, _oínt, kagc, арая, 
   {{0x63a57dd8,0x29044d6f,0x6b997dd9,0x6d417dda}},	//   unin, _hena_, niug, hena, 
   {{0x29057ddb,0x27e404d1,0x6d417ddc,0x63a57ddd}},	// [27e00] _kena_, _hunn_, kena, rnin, 
   {{0x6d417dde,0x29057ddf,0x66046661,0xda180574}},	//   jena, _jena_, _iwik, _दिसत_, 
   {{0x63781c38,0x63a57de0,0x68e00280,0x80a40ca7}},	//   _sínu, pnin, _mgnd, جمان, 
   {{0x29057de1,0x66057de2,0x6d40074d,0x63a57de3}},	//   _lena_, _kwik, eena, qnin, 
   {{0x7d097de4,0x2bdc31a0,0x6d417de5,0x7998015c}},	//   tafs, _पंजा, fena, yitw, 
   {{0x66057de6,0x7ae17de7,0xf1bc0022,0x7f40003a}},	//   _mwik, _sgot, _opáy_, seoq, 
   {{0x7d097de8,0x2fdc0c86,0x6f082ffc,0x394c05d5}},	//   rafs, _fiug_, bagc, _rafs_, 
   {{0x27e0426d,0x6f08074d,0x9f4c0598,0x79997de9}},	//   _niin_, cagc, älär_, witw, 
   {{0x6d40dede,0x29057dea,0xfe002871,0x7d097deb}},	//   bena, _bena_, रीशस_, pafs, 
   {{0x27e001ab,0x27e57dec,0x7d080194,0x00000000}},	//   _aiin_, _bunn_, qafs, --, 
   {{0x29040323,0xf400003d,0x2bdc18ef,0x660400ca}},	//   _dena_, _མཆེད_, _पंचा, _awik, 
   {{0x7ae00fb7,0x27e57ded,0x66057dee,0x6b9800a7}},	//   _ugot, _dunn_, _bwik, ciug, 
   {{0x27e17def,0x25b81529,0x799801c8,0x29057df0}},	//   _diin_, forl_, pitw, _fena_, 
   {{0x29057df1,0x660425ab,0x27e57df2,0xf3f44a4e}},	//   _gena_, _dwik, _funn_, имгә_, 
   {{0x27e57df3,0x66040099,0x64740640,0x27e00009}},	//   _gunn_, _ewik, огру, _fiin_, 
   {{0x6d417df4,0x27e00036,0x00000000,0x00000000}},	//   zena, _giin_, --, --, 
   {{0x29057df5,0xdb000615,0x2fdc07c5,0x660405c7}},	// [27e10] _yena_, lomó, _riug_, _gwik, 
   {{0x29057df6,0x63797921,0x6d417df7,0x6f088062}},	//   _xena_, _sínt, xena, wagc, 
   {{0x660406d6,0x63780005,0x6f0800d2,0x6d401da7}},	//   _zwik, _pínt, tagc, vena, 
   {{0x6d417df8,0x27e02db1,0xdec00023,0xdd380171}},	//   wena, _xiin_, ስግን_, _jāņi, 
   {{0x6b997df9,0xcdc40372,0xa3b40490,0xedd40032}},	//   viug, مۇرۇ_, टवर_, алдә_, 
   {{0x6d417dfa,0x2bdc8109,0x6f08a84e,0x63780030}},	//   uena, _पूजा, sagc, _fíns, 
   {{0x29047483,0x6d4027f8,0x637801e1,0x6b980332}},	//   _rena_, rena, _tínt, tiug, 
   {{0x29057dfb,0x6d417dfc,0x201c00f3,0x27e4007c}},	//   _sena_, sena, švic_, _runn_, 
   {{0x6d417dfd,0x6b997dfe,0x27e57dff,0x637801e1}},	//   pena, riug, _sunn_, _kínr, 
   {{0x27e17e00,0xdd94774d,0x6d400054,0x6b997e01}},	//   _siin_, _дауы, qena, siug, 
   {{0x66057e02,0x637801e1,0x27e026bb,0x4b5402e8}},	//   _swik, _mínr, _piin_, _гълт, 
   {{0x29057e03,0x07a40276,0x27e404e6,0x8d842c11}},	//   _wena_, самн, _vunn_, _туғд, 
   {{0x29057e04,0xb6a17e05,0x27e401c7,0x27e00037}},	//   _tena_, зиял, _wunn_, _viin_, 
   {{0x29040184,0x27e40267,0x645806ea,0x2718063f}},	//   _uena_, _tunn_, _ávik, ọn_, 
   {{0x27e17e06,0x443c4d74,0x9478cfa1,0xfa5404d3}},	//   _tiin_, ït_, асту_, _پرۆگ, 
   {{0x66057e07,0x3c7800df,0x00000000,0x00000000}},	//   _twik, אָמב, --, --, 
   {{0x66057e08,0x42c81e49,0x66e401d5,0xdec00023}},	// [27e20] _uwik, уган_, _лоқа, ስግኖ_, 
   {{0xa3480046,0xc9180c58,0x82a4036b,0xe4b40139}},	//   ызға_, ত্ৰত_, _ҳамж, _дөбъ, 
   {{0x63780241,0xb6c80014,0x7ee5003d,0x00000000}},	//   _dínr, _لایے_, مكان, --, 
   {{0x637809e8,0x00000000,0x00000000,0x00000000}},	//   _víns, --, --, --, 
   {{0x63780248,0x645802fb,0xd3981321,0xdb000037}},	//   _fínr, _švih, _тәрә_, romü, 
   {{0x13bc00bd,0xdd9005e0,0x00000000,0x00000000}},	//   _আওয়, بوت_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3cec00e2,0x15b40150,0x7ac4014b,0x00000000}},	//   _šovā_, _ﹼﻬﻤﻬ, йспе, --, 
   {{0x3298010f,0xa1600092,0x00000000,0x00000000}},	//   ָביד, _ለማስቆ, --, --, 
   {{0xdb017e09,0x1d8403e6,0x99997e0a,0x0ba40137}},	//   tomó, _بدرێ, ркот_, йшөм, 
   {{0x26c40793,0x31b80a7c,0x71b800df,0x00000000}},	//   ümon_, רזינ, רציג, --, 
   {{0xdb017e0b,0xec1001ec,0xaa5400f2,0x5fb8012d}},	//   romó, _ءوند, _گلها_, इकिल, 
   {{0xe944072d,0x00000000,0x00000000,0x00000000}},	//   _گرنی, --, --, --, 
   {{0xdb000210,0xaa5400f2,0x00000000,0x00000000}},	//   pomó, _دلها_, --, --, 
   {{0x96f97e0c,0x65940329,0x24180961,0x10380092}},	//   _кейт_, чару, йоры_, _አቋቁመ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x521470e5,0x637801e1,0x83a400c7,0x00000000}},	// [27e30] юдат, _pínr, цырҵ, --, 
   {{0xef9400d1,0x973400e5,0x00000000,0x00000000}},	//   әйдә_, _اکھا, --, --, 
   {{0xf400025c,0x63780a87,0xe0d00116,0x00000000}},	//   _མཆིད_, _vínr, ىزم_, --, 
   {{0x201d7e0d,0x637801e1,0xd7c8f059,0x00000000}},	//   ávia_, _wínr, रतिच, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe8c00150,0x00000000,0x00000000,0x00000000}},	//   _ﺭﺍﯞﻋ, --, --, --, 
   {{0x6d0400f4,0xd7c80574,0x00000000,0x00000000}},	//   _ۇباق, रताच, --, --, 
   {{0xa2d019ec,0xd1cc001f,0xca8401c0,0x9f3410da}},	//   _दरम्, ባዎች_, жгий, _несі, 
   {{0xdfd405f5,0xb4f8041c,0xdb0000cf,0x8ea40244}},	//   _хоты, ्राय_, tomò, _بڵان, 
   {{0xe8dc01dc,0xdce8012d,0x00000000,0x00000000}},	//   _giới_, _podą, --, --, 
   {{0xdb000ba1,0x00000000,0x00000000,0x00000000}},	//   romò, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xaac402de,0x05540801,0x41bc00cd,0x00000000}},	//   _اتان, отвя, ्तमस, --, 
   {{0x7e7405ac,0xb5c401d9,0x00000000,0x00000000}},	//   øypi, ٲوِم_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x769c0882,0x7c3006be,0x00000000,0x00000000}},	//   ṣyas, _çerş, --, --, 
   {{0x82a401c6,0x00000000,0x00000000,0x00000000}},	// [27e40] цааж, --, --, --, 
   {{0xb14000a8,0x04457e0e,0xc05800d8,0x00000000}},	//   мнул, _деон, ирец_, --, 
   {{0xd6a9691a,0x63780a87,0x04c81541,0x00000000}},	//   _ندیم_, _fínp, _خودي_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbd68223e,0x5e580212,0x82347b8f,0x00000000}},	//   ирке_, силя_, _برجا, --, 
   {{0x7c6501ff,0xdd901867,0x85080412,0x00000000}},	//   قابل, عوث_, वरिट_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbe140a2c,0x6bd0009a,0x9cfc030d,0x00000000}},	//   _ووزع, وتير, ăччĕ_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d200063,0x00000000,0x00000000,0x00000000}},	//   _одуз, --, --, --, 
   {{0xeaad75f6,0xd7f57e0f,0x00000000,0x00000000}},	//   فعی_, язны, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x19580064,0x00000000,0x00000000,0x00000000}},	//   _галы_, --, --, --, 
   {{0x64400276,0x00000000,0x00000000,0x00000000}},	//   ămin, --, --, --, 
   {{0xa9041075,0x63780241,0xe45400c7,0x00000000}},	//   _بيىل_, _pínp, мкры, --, 
   {{0x48a800d4,0x00000000,0x00000000,0x00000000}},	//   _утім_, --, --, --, 
   {{0xe1f05263,0x623406ed,0x30e800d8,0xe9440133}},	// [27e50] نسل_, мету, афен_, _درۆی, 
   {{0x7d1800ca,0x94d4084c,0x00000000,0x00000000}},	//   _ndts, _нопц, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb4d41af8,0x00000000,0x00000000,0x00000000}},	//   िधी_, --, --, --, 
   {{0x8d644ee6,0x5f7401d5,0x798803ac,0x00000000}},	//   звле, بالر, _olfw, --, 
   {{0xdfd004a9,0xc278011a,0xb9240092,0x27081100}},	//   ىيە_, _הרשי, _ተጠሪዎ, _वज्र_, 
   {{0x601877c1,0xfce17e10,0x00000000,0x00000000}},	//   _моря_, ношо, --, --, 
   {{0x79883cf7,0x997c00e2,0xdfd401ec,0x00000000}},	//   _alfw, _jāņu_, _жосы, --, 
   {{0x6f197e11,0x00000000,0x00000000,0x00000000}},	//   _iduc, --, --, --, 
   {{0x38e0004b,0x80a000cf,0x5d840066,0x00000000}},	//   کيپې, _تۅۅن, _قلقل, --, 
   {{0xc8d402a0,0x29c400cf,0x00000000,0x00000000}},	//   डेंट, йтүү_, --, --, 
   {{0x3e444be7,0xaadc00dc,0x798803ac,0xe8dc004d}},	//   _መልእክ, _पृथक, _elfw, _giời_, 
   {{0x6b8800e2,0x00000000,0x00000000,0x00000000}},	//   _ilgg, --, --, --, 
   {{0x38680491,0x59240327,0x00000000,0x00000000}},	//   óirí_, _འཐགས_, --, --, 
   {{0x6f1814dc,0x2618ad78,0x00000000,0x00000000}},	//   _oduc, _भटकी_, --, --, 
   {{0xb69826cd,0x7c2c03cd,0x00000000,0x00000000}},	//   mbân, _åbre, --, --, 
   {{0x46a402e8,0x997c00de,0x12c40022,0x00000000}},	// [27e60] _хапв, _dāņu_, дитҟ, --, 
   {{0x6f1800a8,0x201c0120,0x798802d0,0x091c0154}},	//   _aduc, ávio_, _xlfw, ব্রু_, 
   {{0x75780302,0xfe7004d3,0x40940124,0x0ed8012d}},	//   _הטיפ, کدا_, чрат, बेसड, 
   {{0x442858a0,0xdb012dbf,0x39a001e1,0x645c257c}},	//   mub_, lomö, _késè_, mvri, 
   {{0x45286d7e,0x645d7e12,0x7d180334,0x6f1801bf}},	//   _སྐོར_, lvri, _pdts, _dduc, 
   {{0x6f197e13,0xdb000793,0x7638008f,0x39a001e1}},	//   _educ, nomö, מענג, _mésè_, 
   {{0x44297e14,0x645d7e15,0x00000000,0x00000000}},	//   nub_, nvri, --, --, 
   {{0x6c8015eb,0x00000000,0x00000000,0x00000000}},	//   عليم, --, --, --, 
   {{0x44297e16,0x3f840122,0x7f940131,0x645c00c5}},	//   hub_, mkou_, _даңх, hvri, 
   {{0x44297e17,0x57f46a0c,0x41bc4407,0x3f844ec5}},	//   kub_, мпот, ्तिस, lkou_, 
   {{0x44297e18,0xdb00f83f,0x645c1710,0xa3ac482a}},	//   jub_, domö, jvri, कचा_, 
   {{0x3f8411c1,0x44297e19,0x645d7e1a,0x6448031c}},	//   nkou_, dub_, dvri, ħdil, 
   {{0xab241ed2,0x41bc5168,0xdb000793,0x645c01f5}},	//   _хоча_, ्तास, fomö, evri, 
   {{0xcaa50741,0x9f440023,0x3f8402fb,0x645c01a4}},	//   _تصمي, _bimë_, hkou_, fvri, 
   {{0x44297e1b,0x69c4003d,0x3f857e1c,0x201c0306}},	//   gub_, ċjet, kkou_, ávil_, 
   {{0x9f440023,0x3f8402fb,0xdb000023,0xdec002d3}},	//   _dimë_, jkou_, dimë, ድልን_, 
   {{0x7bc00421,0x201c3421,0x3f840308,0xd838007f}},	// [27e70] _mkou, švil_, dkou_, ltč_, 
   {{0x645c011c,0x44297e1d,0x7c297e1e,0x00000000}},	//   bvri, bub_, kufr, --, 
   {{0x7bc063d2,0x44297e1f,0xd838033b,0x3f8402f0}},	//   _okou, cub_, ntč_, fkou_, 
   {{0x3f840198,0xd2f80014,0xe0d0007b,0x99840118}},	//   gkou_, _ذکرا_, ازك_, kumů_, 
   {{0x0594e8e1,0x20180bed,0x98bc00de,0x8db40024}},	//   _رایگ, _evri_, _kavē_, мскі, 
   {{0x7bc17e20,0x60d80054,0xdb00804e,0xd83802bd}},	//   _akou, ñamä, limè, ktč_, 
   {{0x9f440268,0x3f8402fb,0x7c280d12,0x00000000}},	//   _oimè_, bkou_, gufr, --, 
   {{0x3f840e96,0x6f180230,0x09a40490,0xdb000561}},	//   ckou_, _uduc, गच्य, nimè, 
   {{0x44280213,0x645c1710,0x7e740158,0x7bc001ef}},	//   zub_, zvri, øypt, _dkou, 
   {{0x44297e21,0x7bc066dd,0xdb00008c,0x888448e5}},	//   yub_, _ekou, rnmá, длож, 
   {{0x8af80c04,0x44297e22,0xdb000ba1,0x2d8402f0}},	//   _днес_, xub_, kimè, mkne_, 
   {{0x39a001e1,0xb698dbd9,0x9f440200,0x00000000}},	//   _pésè_, rbân, _rimë_, --, 
   {{0x45282fb5,0x6e2835b7,0xdb00eda4,0x645c01f5}},	//   _སྐུར_, nugb, dimè, wvri, 
   {{0x44297e23,0x7bc00316,0x3f840122,0xb5f80122}},	//   tub_, _zkou, zkou_, dvád, 
   {{0x645d7e24,0x9f4402e2,0x2d840158,0x69c00171}},	//   uvri, _fimè_, ikne_, _ikne, 
   {{0x44297e25,0x645d7e26,0x201c00d7,0x00000000}},	//   rub_, rvri, ávim_, --, 
   {{0x4428d6ac,0x3f840232,0x645c0af4,0x81e402f5}},	// [27e80] sub_, vkou_, svri, _যৌগ_, 
   {{0x44297e27,0x645c0d27,0x7c280099,0xdb00036e}},	//   pub_, pvri, yufr, timë, 
   {{0x3f840232,0x44297e28,0x00000000,0x00000000}},	//   tkou_, qub_, --, --, 
   {{0x2b800bc9,0xdb001762,0x3f840100,0x00000000}},	//   _uñch_, cimè, ukou_, --, 
   {{0xb5f80579,0x3f840122,0x69c00ebb,0x7c280117}},	//   rvág, rkou_, _okne, wufr, 
   {{0x63a57e29,0x7bc17e2a,0x3f857e2b,0xb5f806ea}},	//   liin, _skou, skou_, svág, 
   {{0xdb017e2c,0x63a57e2d,0x3f8402fb,0x6284007f}},	//   limé, oiin, pkou_, lyio, 
   {{0x6e297e2e,0x9f4400e4,0xfe44004e,0x00000000}},	//   bugb, _oimé_, _онбо, --, 
   {{0x9f44033b,0xdb017e2f,0x7c297e30,0x628400d7}},	//   _rimè_, nimé, sufr, nyio, 
   {{0x63a57e31,0xbb4801d9,0xfcc00092,0x00000000}},	//   hiin, _ژلان_, ድርግ_, --, 
   {{0x9f457e32,0x63a57e33,0x69c00066,0x7bc00270}},	//   _aimé_, kiin, _dkne, _tkou, 
   {{0x63a57e34,0x69c00158,0xfa6800f7,0x7bc17e35}},	//   jiin, _ekne, _маек_, _ukou, 
   {{0x63a57e36,0xab74ba4f,0x62840100,0xd838033b}},	//   diin, _تمنا_, jyio, stč_, 
   {{0x63a40d47,0x19580d31,0x00000000,0x00000000}},	//   eiin, _хакы_, --, --, 
   {{0x63a57e37,0xdb017e38,0x69c80034,0x9f44007f}},	//   fiin, rnmæ, हतरी, _timè_, 
   {{0x63a57e39,0xb4ac0574,0x51f85541,0xb4d400dc}},	//   giin, _कशी_, знаю_, िधौ_, 
   {{0xdce8012c,0xdb017e3a,0x2d8413d5,0x00000000}},	// [27e90] _podě, rimè, ykne_, --, 
   {{0x63a41140,0xdb0808fb,0xdb000ba1,0xddd4010b}},	//   aiin, _ålær, simè, _ýaňk, 
   {{0x63a57e3b,0xdce80118,0x1af400cc,0x00000000}},	//   biin, _vodě, _ইজনে_, --, 
   {{0x63a57e3c,0x6e281b26,0x628400ca,0xceb800d1}},	//   ciin, tugb, byio, пәз_, 
   {{0xdb000597,0x64580579,0x2d840306,0x63a80100}},	//   cimé, _ávir, tkne_, èdne, 
   {{0x6e297e3d,0x00000000,0x00000000,0x00000000}},	//   rugb, --, --, --, 
   {{0x6e280004,0x41bc102f,0x2d857e3e,0x2bc82886}},	//   sugb, ्तरस, rkne_, ातला, 
   {{0x2d857e3f,0x00000000,0x00000000,0x00000000}},	//   skne_, --, --, --, 
   {{0x30e000dc,0x09e403c5,0x00000000,0x00000000}},	//   _कृतः_, ноин, --, --, 
   {{0x63a57e40,0x64480213,0xdb000108,0x7c2c01e7}},	//   ziin, çdik, enmä, óiré, 
   {{0x63a57e41,0x49740220,0x07a4013d,0x88c8022e}},	//   yiin, _үлес, еанн, ялов_, 
   {{0x8bd80e26,0x1cb8c69a,0x63a57e42,0xb5f802fb}},	//   _эмес_, _غالب_, xiin, dváb, 
   {{0x63a57e43,0xdb0090d4,0x7780084c,0xe7ec000d}},	//   viin, romô, уляз, _घूरा_, 
   {{0x201d7e44,0xdb000267,0x63a4153a,0x62f400cc}},	//   ávik_, anmä, wiin, জৰাট_, 
   {{0xf8c45345,0x98540228,0xdb0000d0,0x00000000}},	//   _रुपय, _атыш, pomô, --, 
   {{0xdb017e45,0x63a40140,0x00000000,0x00000000}},	//   timé, uiin, --, --, 
   {{0xf48400e5,0x637800e5,0x00000000,0x00000000}},	// [27ea0] واہی, _kínz, --, --, 
   {{0x41c407d2,0xdb017e46,0x72c000f7,0x71a07af6}},	//   رقاق, rimé, убуз, гауз, 
   {{0x63a57e47,0xdb0115b9,0xb5f830df,0x628402e2}},	//   piin, simé, rváe, syio, 
   {{0x63a4852e,0x00000000,0x00000000,0x00000000}},	//   qiin, --, --, --, 
   {{0xdb001e10,0x63a80118,0xdd58009d,0x00000000}},	//   nnmå, édnu, далч_, --, 
   {{0x4f080131,0xb5f806c6,0x00000000,0x00000000}},	//   كتۇپ_, lvác, --, --, 
   {{0x961c11b1,0x7cf40ba1,0xee3400ee,0xc1bc0073}},	//   _भट्ट_, _aüró, _үнс_, ्तीग, 
   {{0xa3d0b500,0xafe0009d,0x00000000,0x00000000}},	//   षति_, _босл, --, --, 
   {{0xd910006c,0x79a57e48,0xece40166,0x00000000}},	//   لیش_, ерне, мдәл_, --, 
   {{0x7c957e49,0x25f406ab,0x8d280510,0x323400df}},	//   _прец, ंदनी_, _онуң_, עטין_, 
   {{0xa3d019e5,0x294c01e1,0x00000000,0x00000000}},	//   षता_, _ńṣíp, --, --, 
   {{0xb338010e,0xc1bc095f,0xeb940395,0x00000000}},	//   _omça, ्तुग, _пих_, --, 
   {{0x87701219,0xdb00007c,0x00000000,0x00000000}},	//   рғыш, rnmä, --, --, 
   {{0x44395bf0,0x67440150,0xe5c401c6,0x00000000}},	//   _bqp_, _ەپيك, гссо, --, 
   {{0x44380129,0x71241c3b,0xe45001d3,0xa424b6ac}},	//   _cqp_, ہرال, یضہ_, льтл, 
   {{0x637801e1,0xb5f8b941,0x00000000,0x00000000}},	//   _kíny, rváb, --, --, 
   {{0x09280150,0x0f340133,0x35e40120,0xa29400d4}},	// [27eb0] _ءسۇي_, ێکرد, _пцов, гаті, 
   {{0x44380175,0x777c022e,0x9f5800ae,0x3c380200}},	//   _fqp_, _hoqx, _dtrí_, këv_, 
   {{0xfbb016d1,0x00000000,0x00000000,0x00000000}},	//   ुकाम, --, --, --, 
   {{0x441804ae,0xd25001c8,0x00000000,0x00000000}},	//   _קורס, _پچر_, --, --, 
   {{0x59d05096,0x00000000,0x00000000,0x00000000}},	//   हतार, --, --, --, 
   {{0x81f40014,0xe5f8011a,0x00000000,0x00000000}},	//   _شۂر_, עזור_, --, --, 
   {{0xd9b802f5,0x21657e4a,0x00000000,0x00000000}},	//   ুগাম, _стяг, --, --, 
   {{0x4a440251,0xc4ac00cc,0x00000000,0x00000000}},	//   внив, _গৰুজ, --, --, 
   {{0x9f44011c,0x5f940032,0xfe6c0133,0xc0f00240}},	//   _mimì_, _ситт, _وگه_, ፍጸም_, 
   {{0x6e3800b5,0x0888022e,0x00000000,0x00000000}},	//   _iqub, дбой_, --, --, 
   {{0x998435b6,0x00000000,0x00000000,0x00000000}},	//   الپو, --, --, --, 
   {{0x6e38009a,0xab280220,0x201c02f0,0x07a40334}},	//   _kqub, _ءسال_, ávii_, тамн, 
   {{0xfc480306,0x00000000,0x00000000,0x00000000}},	//   číš_, --, --, --, 
   {{0x443806ed,0xdb000158,0x00000000,0x00000000}},	//   _pqp_, rnmå, --, --, 
   {{0xf9900375,0xb5f80030,0x43c401d9,0x00000000}},	//   _דרג_, tvác, نزرٲ, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6e380107,0xb5f80122,0x00000000,0x00000000}},	// [27ec0] _nqub, rvác, --, --, 
   {{0xc4840fc0,0x442c00d8,0x00000000,0x00000000}},	//   _алок, _ªf_, --, --, 
   {{0x6e9001b9,0x98bc0024,0x3fc46103,0x7c24002b}},	//   یلما, _davė_, نگری_, _ākro, 
   {{0xbea83296,0x637800db,0x34b40375,0xb33800a2}},	//   وهان_, _nínx, _יפים_, _tmça, 
   {{0x753853fb,0x244c01e1,0x00000000,0x00000000}},	//   đuzv, bòmò_, --, --, 
   {{0xf650011a,0x00000000,0x00000000,0x00000000}},	//   יצד_, --, --, --, 
   {{0x6e380b6f,0x9f440270,0x71a0be59,0xb3380139}},	//   _equb, _himí_, _тарз, _mmçn, 
   {{0x26cc03be,0x442801ab,0x29017e4b,0x63780241}},	//   ədov_, irb_, ñjan_, _píny, 
   {{0x6280b4a2,0x1dc4013d,0xb4ac448b,0x6a8401e1}},	//   _àmod, _йөкн, _कश्_, _réfú, 
   {{0x777c208d,0xdb0000c7,0x386801bf,0x6378032e}},	//   _soqx, mimí, åbro_, _víny, 
   {{0x7e617e4c,0xe0b00154,0xdb0001e7,0x00000000}},	//   lvop, _করুন, limí, --, 
   {{0x7ac40510,0x7f417e4d,0x5924031c,0xab801cb8}},	//   _исле, nfoq, _འཐམས_, _вушк, 
   {{0xba740137,0x00000000,0x00000000,0x00000000}},	//   _جاات, --, --, --, 
   {{0x44280004,0xc1bc0b7d,0xe9a000cf,0x00000000}},	//   frb_, ्तोग, _качп, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf2dc006a,0x395c0267,0x00000000,0x00000000}},	//   _abâa_, ldts_, --, --, 
   {{0x25f40574,0x9f4401e7,0x442803d5,0x7c28002f}},	// [27ed0] ंदणी_, _cimí_, arb_, hrfr, 
   {{0xdb000122,0x354400f3,0x00000000,0x00000000}},	//   dimí, _рхив, --, --, 
   {{0x6d8c0158,0x7e600165,0x82880014,0x00000000}},	//   _bøan, evop, وٕہے_, --, 
   {{0x9f4401e1,0x99840118,0xdb000332,0xd34001d3}},	//   _fimí_, krmů_, fimí, _دہری, 
   {{0x7c280732,0x6378004e,0x59b4243c,0x03d400d9}},	//   erfr, _rínx, ुवार, _תורם_, 
   {{0x3cfc0120,0xa1840166,0x2c5403e3,0x00000000}},	//   _cftv_, _кысл, _hədə_, --, 
   {{0xc1e001ec,0x997c00ef,0xdde4013d,0x00000000}},	//   _اۋلي, _bāžu_, рәтү, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6e395027,0x2c5403e3,0x9f44013d,0x00000000}},	//   _uqub, _mədə_, _ximí_, --, 
   {{0x6ca40022,0x2bf0030d,0x00000000,0x00000000}},	//   _иреж, _кӏир, --, --, 
   {{0x997c00ef,0xc4ac0154,0x00000000,0x00000000}},	//   _fāžu_, _গর্জ, --, --, 
   {{0x2c5403e3,0x6fb003ce,0x4ab94d06,0x00000000}},	//   _nədə_, ंचिं, _пуля_, --, 
   {{0xfd540943,0xe81c02ab,0x6d40022f,0x18b00032}},	//   _phaḓ, _मटका_, ofna, йҙәр, 
   {{0x2bc813da,0x4428110c,0x2b5c0129,0x00000000}},	//   ातका, trb_, lduc_, --, 
   {{0x6d40022f,0x6fb00034,0xc844010b,0x2b5c0208}},	//   ifna, ंचां, _сейй, oduc_, 
   {{0x2b5d7e4e,0x00000000,0x00000000,0x00000000}},	//   nduc_, --, --, --, 
   {{0xb5f800dd,0xe0b0015b,0xc79400c7,0x67240ca8}},	// [27ee0] lván, _করেন, _арҿы, _idij, 
   {{0x66057e4f,0x2b5c0051,0xb63c0220,0x00000000}},	//   _itik, hduc_, _ﻀﺩ_, --, 
   {{0x03a41d56,0x80a53689,0x3bd80200,0x11380108}},	//   _бино, دمان, lëqe_, ъяты_, 
   {{0x6604d720,0x9f440270,0xdb00007b,0x6d4001a8}},	//   _ktik, _timí_, timí, efna, 
   {{0x52740372,0x6d4005b1,0x2b5c19f5,0xde580845}},	//   _куру, ffna, dduc_, талі_, 
   {{0x660400ec,0x7e6000cd,0x2360045f,0x9f5801e7}},	//   _mtik, rvop, ldij_, _dtrá_, 
   {{0x67241711,0x62800129,0x7e617e50,0x00000000}},	//   _odij, _àmob, svop, --, 
   {{0x67257e51,0xdb0013ce,0x66057e52,0x6f0801fa}},	//   _ndij, nnmø, _otik, cbgc, 
   {{0x22417e53,0x7ac402dd,0x657c0332,0x00000000}},	//   ntik_, ыске, kjrh, --, 
   {{0x6e900491,0x22417e54,0x32540375,0x67257e55}},	//   _الكا, itik_, נסים_, _adij, 
   {{0x66057e56,0xeaad7e57,0xdb240ec9,0x57b4020a}},	//   _atik, قعی_, _نوای, ибот, 
   {{0x22417e58,0x395c009a,0xabf8011a,0x2bb40356}},	//   ktik_, sdts_, _נהדר, păca_, 
   {{0x66041529,0x9fa8013d,0x195800db,0x00000000}},	//   _ctik, _eşç_, _аалы_, --, 
   {{0x9f44026c,0x67257e59,0xb5f801d3,0xd7f8054e}},	//   _limà_, _edij, bván, lvăm_, 
   {{0x779011c2,0x68f80375,0x92b00154,0x22417e5a}},	//   _هیدا, _אלוה, _ওরে_, etik_, 
   {{0x67240841,0x23600d86,0xdb0001bf,0xf0740131}},	//   _gdij, gdij_, gnmø, һизә_, 
   {{0x2240089c,0x68f40200,0xdce80171,0x2c5406be}},	// [27ef0] gtik_, _çadë, _kodē, _vədə_, 
   {{0x91c400fd,0x67240219,0x611401c6,0xb9d00023}},	//   рәмл, _zdij, йдуу, _ትኽ_, 
   {{0x22417e5b,0x236001f5,0x66040175,0x2284013d}},	//   atik_, bdij_, _ztik, _һург, 
   {{0x22402819,0xa3d03f55,0x283400c8,0xdce80171}},	//   btik_, षतः_, רנאך_, _lodē, 
   {{0xb5f80232,0x9f440004,0xa2cc012c,0xb2840a89}},	//   zván, _simã_, _थुप्, _сынк, 
   {{0x6d4003fa,0xdce800de,0x00000000,0x00000000}},	//   ufna, _nodē, --, --, 
   {{0xefcc044e,0x6c6400dd,0x8b9401d5,0x201d7e5c}},	//   _ብጻይ_, البہ_, ирич, ávit_, 
   {{0x6d4002d0,0xc8240023,0x00000000,0x00000000}},	//   sfna, _ተሰማዕ, --, --, 
   {{0x499810f5,0x3cb000ee,0x7cd400fb,0xdce800ef}},	//   втня_, ййәр, лмәр_, _bodē, 
   {{0xb5f800dd,0x23600369,0x00000000,0x00000000}},	//   tván, zdij_, --, --, 
   {{0x224001c0,0x0b580961,0xec680166,0x00000000}},	//   ztik_, _арлы_, _ярак_, --, 
   {{0x22417e5d,0xb5f83add,0xdd1c00c0,0x00000000}},	//   ytik_, rván, _išši, --, 
   {{0xda640fb4,0x96b81c35,0xdce800ef,0xdb0001bf}},	//   _هاوي, гуру_, _indā, vnmø, 
   {{0x80d40490,0x66040219,0xba98011a,0x00000000}},	//   _भरले, _vtik, _בסני, --, 
   {{0x443cff0c,0xdb017e5e,0xe7ec52be,0xe0b0015b}},	//   ît_, limá, _घंटा_, _কর্ন, 
   {{0x22417e5f,0x430805d9,0x66057e60,0x67241710}},	//   ttik_, ئيءَ_, _ttik, _udij, 
   {{0x66057e61,0x57257e62,0xdb001dee,0x22403386}},	// [27f00] _utik, _طريق, nimá, utik_, 
   {{0x22417e63,0xdb00004e,0x3618010f,0x40c800ec}},	//   rtik_, zimà, _שויד, نوءَ_, 
   {{0xb5f80232,0x2360014f,0xb03000d1,0x00000000}},	//   hvál, pdij_, قىلغ, --, 
   {{0x22417e64,0x7e2804db,0x7f4402bf,0xb5f801d3}},	//   ptik_, віка_, редж, kvál, 
   {{0xee342b97,0x7e540212,0x00000000,0x00000000}},	//   инц_, ртец, --, --, 
   {{0xdb000085,0xd24c0014,0xb5f8013a,0x00000000}},	//   dimá, _سۆم_, dvál, --, 
   {{0xdb00004e,0x195802dd,0x00000000,0x00000000}},	//   timà, қаны_, --, --, 
   {{0x7ac42bbd,0x7b654187,0x92d80183,0x61400248}},	//   испе, ртке, াশৰ_, bàló, 
   {{0xb5f801ed,0xfe70007b,0xd7f8054e,0x3ea4022e}},	//   gvál, _بدأ_, rvăm_, _тиаг, 
   {{0xdb000109,0xada04c17,0x6da06518,0xa3e80073}},	//   simà, _даул, _диуа, यगड_, 
   {{0x6cf4030d,0x00000000,0x00000000,0x00000000}},	//   _техĕ, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb000077,0xd67800cf,0x2bc00cb2,0x00000000}},	//   cimá, اڭعا_, शवरा, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x5fb933ab,0x94d400f3,0x241801f4,0x00000000}},	//   ेकाल, совц, иоры_, --, 
   {{0xb35400f2,0x8a4002f2,0x8d880092,0x00000000}},	//   جیحا_, _بێین, ማምተው_, --, 
   {{0x67543c4b,0xe2f802dd,0x630401d5,0x00000000}},	// [27f10] _ذخير, реуі_, توقل, --, 
   {{0x62240058,0x69c409a8,0x3ddc0051,0x25f40401}},	//   زىمل, čjeg, _nhtw_, ंदरी_, 
   {{0xd37000c6,0xa1597e65,0xe0d121e7,0x30e80107}},	//   _فهد_, раху_, وزم_, тфан_, 
   {{0xdfd401c6,0xb5f800e5,0xdb1401e1,0x00000000}},	//   оохы, yvál, _àbèg, --, 
   {{0xdb017e66,0xd6e803d4,0x8e4800ae,0x00000000}},	//   ximá, কুৰা_, التك_, --, 
   {{0xdb00366f,0x00000000,0x00000000,0x00000000}},	//   nimæ, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb001a09,0x6fd80034,0x9f685d6b,0x29c800cc}},	//   timá, _बठिं, _круз_, jøar_, 
   {{0x49c88b46,0xad240133,0xea6000db,0x00000000}},	//   ллин_, _نراو, تۇشپ, --, 
   {{0x79997e67,0xb5f801d3,0xd6e803d4,0x6cb001af}},	//   ghtw, rvál, কুৱা_, _мөйт, 
   {{0x6ca57e68,0xa87401c6,0xb5f87009,0xef340092}},	//   _траж, рөлт_, svál, _የምንኖ, 
   {{0x44240115,0x25f40ce0,0x66000306,0x6d44007c}},	//   _ĉo_, ंदली_, ímko, _öjab, 
   {{0x81cc02f5,0x6b981427,0x7c240055,0x00000000}},	//   শগত_, mhug, _ākri, --, 
   {{0x79989230,0x00000000,0x00000000,0x00000000}},	//   chtw, --, --, --, 
   {{0x29c80162,0xded40092,0x2758030d,0xe74801af}},	//   bøar_, _ይዘን_, _кĕвв, _күне_, 
   {{0x6b997e69,0x2fdc0208,0xc79401ee,0x00000000}},	//   nhug, _nhug_, _ырлы, --, 
   {{0x27e1646d,0x67d801e1,0xc14801c0,0x9f4c01e1}},	// [27f20] _ihin_, _e̟jó, лзаж_, _ìléw_, 
   {{0x6b980477,0x00000000,0x00000000,0x00000000}},	//   hhug, --, --, --, 
   {{0x6b980cfe,0x442c022c,0xdf580724,0x2fdc0055}},	//   khug, _íf_, иядә_, _bhug_, 
   {{0x6b982784,0x2fdd7e6a,0x7c2c0fac,0x303801d9}},	//   jhug, _chug_, _åbri, اتٕک_, 
   {{0x6b997e6b,0x27e001c3,0x2fdd7e6c,0xdb00d96c}},	//   dhug, _mhin_, _dhug_, limç, 
   {{0x27e00076,0x6b98623d,0xbbb01bcf,0x9f58036e}},	//   _lhin_, ehug, ुक्क, _kurë_, 
   {{0xefb0006c,0xad200131,0x7dd40022,0xdb0003b9}},	//   _کینگ, سىيى, sâso, nimç, 
   {{0x6b98ca60,0x27e17e6d,0xdb2400a2,0xd9e000cd}},	//   ghug, _nhin_, _ösüs, नष्ट, 
   {{0x39e87111,0x0d480832,0x9f580200,0x999800c7}},	//   льон_, _چشمي_, _lurë_, икит_, 
   {{0x0d480375,0x27e00493,0xdb000139,0x00000000}},	//   _نشمي_, _ahin_, kimç, --, 
   {{0x26c0020b,0x7d197e6e,0x6b98ebff,0xd7f40c98}},	//   _axio_, _iets, bhug, юзны, 
   {{0x27e01590,0x7d197e6f,0x6b980978,0x8b657e70}},	//   _chin_, _hets, chug, _وانم, 
   {{0x7d197e71,0x98b80bc7,0x26c000e8,0x27e084eb}},	//   _kets, ırı_, _cxio_, _dhin_, 
   {{0x27e00248,0x6a10009d,0xa5f854d9,0xb8640244}},	//   _ehin_, _эмшу, серу_, _هابو, 
   {{0x7d197e72,0x27e008c2,0x61940023,0xdb0000a2}},	//   _mets, _fhin_, _ጃምላዊ_, gimç, 
   {{0x7d197e73,0x5214223a,0x27e17e74,0x963400f3}},	//   _lets, ждат, _ghin_, _дниц, 
   {{0xdb0002f6,0x7d18bebf,0x00000000,0x00000000}},	// [27f30] mimä, _oets, --, --, 
   {{0x2fdc07d6,0xdb017e75,0x5454516a,0x6b980165}},	//   _shug_, limä, _двот, zhug, 
   {{0x92d8015b,0x9f580023,0x628006af,0x2fdc01ab}},	//   াশে_, _gurë_, _àmon, _phug_, 
   {{0xb9ec0125,0x555400dd,0xdb0025e4,0x6b980117}},	//   _ነገ_, _اپگر, nimä, xhug, 
   {{0x7d197e76,0x28cc3174,0xdce802d5,0x15f80c66}},	//   _bets, _सुनि, _kodė, ंदिर_, 
   {{0xdb00b6a5,0x7d197e77,0x00000000,0x00000000}},	//   himä, _cets, --, --, 
   {{0x2fdc0ea3,0x7d197e78,0xcfe80597,0xfce0013e}},	//   _thug_, _dets, _نفسه_, мошо, 
   {{0x7d180c8c,0x316001fa,0x3338013f,0x8a044130}},	//   _eets, _hajz_, ngqx_, озие, 
   {{0x7d197e79,0xfaec00aa,0x6b997e7a,0x27e17e7b}},	//   _fets, نګه_, rhug, _rhin_, 
   {{0x6b997e7c,0x6f197e7d,0x7d197e7e,0x9f58067c}},	//   shug, _heuc, _gets, _aurè_, 
   {{0x27e00649,0x245000b0,0xdb0001b8,0x5f7401d3}},	//   _phin_, _mömö_, fimä, _ظاہر, 
   {{0x6b980cfe,0xdc897e7f,0x15b801e0,0xdb000254}},	//   qhug, _усул_, ҡыры_, gimä, 
   {{0x6f1810d8,0x6a6400aa,0x7d197e80,0xdb000332}},	//   _meuc, _دطال, _yets, anmó, 
   {{0x6f197e81,0x27e00493,0x602001e1,0x9b9401ec}},	//   _leuc, _whin_, _jámá, _ولەت, 
   {{0x27e079c1,0xdb0021c6,0x00000000,0x00000000}},	//   _thin_, bimä, --, --, 
   {{0x6f180731,0x26c001c4,0x27e001c6,0x60201bd4}},	//   _neuc, _txio_, _uhin_, _lámá, 
   {{0x26c00077,0x42240801,0x41a80536,0xb6997e82}},	// [27f40] _uxio_, юдав, аван_, lcân, 
   {{0xb5f802fb,0x854800d4,0x7dd40022,0xc79401af}},	//   dváh, _тзов_, tâsm, _ырһы, 
   {{0x7d197e83,0x28cc1a22,0x6f1801ab,0x85b801d9}},	//   _rets, _सुमि, _beuc, _ماگس_, 
   {{0x7d1868d6,0x6f197e84,0xf8b00375,0xd2f801c6}},	//   _sets, _ceuc, ושב_, _гэрч_, 
   {{0x7d197e85,0xfe717e86,0x6f197e87,0x645c0042}},	//   _pets, بدا_, _deuc, lwri, 
   {{0x7d180240,0xbc0401c6,0xc5500023,0x00000000}},	//   _qets, очий, _ህዝባዉ, --, 
   {{0x645d7e88,0x6f197e89,0xac940b73,0x00000000}},	//   nwri, _feuc, ينها_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7d197e8a,0x68ec00ac,0xaca0010b,0x28cc302b}},	//   _tets, əkdə, _beỳl, _सुबि, 
   {{0x60100086,0x9f58026c,0x6f1801f7,0x7d18037e}},	//   _gòmò, _surè_, _zeuc, _uets, 
   {{0x26182068,0xdb017e8b,0x9f58011c,0x6f197e8c}},	//   बीसी_, timä, _purè_, _yeuc, 
   {{0xc0d4044e,0x645c0368,0x4aa800ec,0x00000000}},	//   ራርሓ_, dwri, _ڏاهپ_, --, 
   {{0xdb017e8d,0x645c02c4,0x9f586c80,0xf1bc00dc}},	//   rimä, ewri, _curé_, ्वमन, 
   {{0x645c00a9,0xdb001073,0x9f58004a,0x00000000}},	//   fwri, simä, _duré_, --, 
   {{0x645d7e8e,0xd79400a7,0x244401c0,0xdb0016ca}},	//   gwri, _никъ, мхтг, pimä, 
   {{0x7c2c168c,0xe2f810da,0x00000000,0x00000000}},	//   _åbru, жеті_, --, --, 
   {{0xdce80953,0x6f18003e,0x712400d1,0xceb80118}},	// [27f50] _todė, _reuc, قرال, _keře_, 
   {{0x934403e6,0x30680063,0x6f180112,0x645c015d}},	//   _کردۆ, ијен_, _seuc, bwri, 
   {{0x6f1854b2,0x3b04022e,0x31600240,0xe3b001d3}},	//   _peuc, _ofoq_, _vajz_, ررہ_, 
   {{0x3a2402ce,0xdbd8013c,0x388c03b9,0x00000000}},	//   _ovop_, lææl, mərd_, --, 
   {{0x20180327,0x629801e4,0x00000000,0x00000000}},	//   _ewri_, ŝvor, --, --, 
   {{0xdd957e8f,0xe8dc0208,0x2dc80114,0x00000000}},	//   мачы, _chới_, шћен_, --, 
   {{0x6f182ff3,0x20180165,0x00000000,0x00000000}},	//   _teuc, _gwri_, --, --, 
   {{0xd83801a6,0xefb001b9,0x00000000,0x00000000}},	//   duč_, _کیچگ, --, --, 
   {{0x5f8402dd,0x89d402dd,0x0b5800c7,0xceb80150}},	//   _تۇنە, зінш, арҿы_, _уәж_, 
   {{0x645d7e90,0x2ac000c0,0x1d0800f3,0x00000000}},	//   ywri, _rūbą_, _међи_, --, 
   {{0x272004c5,0x2018003a,0x48b400a7,0x53bc2314}},	//   _ভাবো_, _xwri_, ящит, ्काश, 
   {{0x9f589223,0xf8ac44e7,0xb6980311,0x00000000}},	//   _puré_, دکه_, rcân, --, 
   {{0xb698042f,0xc6900050,0x78a401e4,0x8a04013d}},	//   scân, رِس_, ĝkva, _эзле, 
   {{0x645d7e91,0x2a6c005a,0xdb00007c,0xd5740024}},	//   twri, _irgb_, rimå, мусь, 
   {{0x3a240219,0x645c01a4,0xb978011a,0x00000000}},	//   _zvop_, uwri, _לנסי, --, 
   {{0x645c4b10,0x44f400db,0x00000000,0x00000000}},	//   rwri, تسڭز, --, --, 
   {{0x7dd407a8,0x645c0175,0x201801ab,0x28cc6a60}},	// [27f60] bâsh, swri, _swri_, _सुति, 
   {{0x2b4c0334,0x645c0076,0x00000000,0x00000000}},	//   _lbgc_, pwri, --, --, 
   {{0x14010b47,0xb4f80302,0xa494024e,0xa2cc00dc}},	//   _аҧсн, _לפיי, _غیرت, _थुर्, 
   {{0xaac80118,0x00000000,0x00000000,0x00000000}},	//   ाथाक, --, --, --, 
   {{0x290402fa,0xf1bd1291,0xe8dc0208,0x00000000}},	//   _ofna_, _iván_, _phới_, --, 
   {{0x51557e92,0x6da0bd08,0xf1bc03b2,0x111000d1}},	//   _отсу, нича, _tváa_, _لېكس, 
   {{0xfccc02d3,0x6bd0083b,0x3f68014b,0xc0e401af}},	//   _ብዋጋ_, کتور, _ливо_, _ховк, 
   {{0xb8840077,0x29057e93,0x00000000,0x00000000}},	//   _laíñ, _afna_, --, --, 
   {{0xaa500c9e,0x3ea001e6,0xe8dc004d,0xdce800ef}},	//   евыш, _åkt_, _thới_, _kodī, 
   {{0x9f5800b0,0x9f4401e1,0xfa480150,0xd5ec0208}},	//   _kurï_, _nimú_, _ۇشتى_, _trả, 
   {{0xaab57e94,0x6e540014,0xed5402a9,0x28cc243c}},	//   قدیر_, _ؤہر_, _хох_, _सुदि, 
   {{0xd838627e,0x3dcc003a,0x290401a8,0xdce80171}},	//   ruč_, lofw_, _efna_, _lodī, 
   {{0xb8840005,0x60c0013f,0xdcf80139,0x00000000}},	//   _baíñ, _ɛmma, livı, --, 
   {{0x25f431a0,0x00000000,0x00000000,0x00000000}},	//   ंदगी_, --, --, --, 
   {{0xb3b40327,0x70d80037,0x00000000,0x00000000}},	//   _དམྱུ, _भरेल, --, --, 
   {{0xb6980356,0xa3f53198,0x00000000,0x00000000}},	//   lcâm, епсі, --, --, 
   {{0xdce80171,0xd250007b,0x00000000,0x00000000}},	// [27f70] _bodī, ضنا_, --, --, 
   {{0xd13000c6,0xdce80055,0x00000000,0x00000000}},	//   ئما_, _codī, --, --, 
   {{0x66740cb8,0x7988007f,0x30a40116,0x6d5401a9}},	//   _قدیر, _mofw, чрав, еxan, 
   {{0x7988017a,0xa0c401e2,0xe8dc0051,0x8eb40472}},	//   _lofw, رينو, _nhời_, وماش, 
   {{0x798804e6,0x636801c6,0xdef802d5,0xf92003d4}},	//   _oofw, _эрэг_, чых_, _মানৱ_, 
   {{0xdce8005f,0x79880042,0x00000000,0x00000000}},	//   _godī, _nofw, --, --, 
   {{0x2a6d7e95,0x61e004e6,0x9f9c0241,0x00000000}},	//   _srgb_, _ëmla, bíà_, --, 
   {{0xe8dc0208,0xca440150,0x00000000,0x00000000}},	//   _chời_, _ﺘﻤﺭ_, --, --, 
   {{0x9f580268,0x09e400f0,0x00000000,0x00000000}},	//   _murì_, моин, --, --, 
   {{0xf1bc206b,0x2fcc3402,0x9f580b34,0x48042d3c}},	//   ्विन, logg_, _strø_, мпов, 
   {{0xb8841709,0x2bc81d1c,0x3d0407af,0x00000000}},	//   _raíñ, _лудо_, _स्टे_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf1bc739b,0xc9280120,0x2900030a,0x6d4400b8}},	//   ्वान, _долж_, ñjas_, _ñjas, 
   {{0x6b88423f,0x2fcc03cd,0x55f40114,0xb5f800e4}},	//   _hogg, hogg_, ечсу, yváv, 
   {{0xb8840005,0x330801f2,0x6b88d41c,0x55c40116}},	//   _vaíñ, _ụbọ_, _kogg, харғ, 
   {{0xdce800e2,0x2fcc0fac,0x00000000,0x00000000}},	//   _sodī, jogg_, --, --, 
   {{0x6b897e96,0xc2097e97,0x2fcc08a5,0xc4f80592}},	// [27f80] _mogg, زقان_, dogg_, _وعدا_, 
   {{0x6b8887c9,0x39902776,0x65140131,0xb6340a7c}},	//   _logg, _pâsi_, _سۈرئ, _קריס_, 
   {{0x03a407d6,0x6b897e98,0x75780302,0xdb000174}},	//   _жино, _oogg, _וטיפ, rimú, 
   {{0x6b897e99,0x00000000,0x00000000,0x00000000}},	//   _nogg, --, --, --, 
   {{0x7ea4022e,0x9e3400ee,0xa3e4000d,0x00000000}},	//   _kаpi, хелч, _पीय_, --, 
   {{0x6b880083,0xdd900035,0x00000000,0x00000000}},	//   _aogg, طوب_, --, --, 
   {{0x6b897e9a,0x79880af9,0x6ca002e8,0xfca800f1}},	//   _bogg, _rofw, кръж, غاتو_, 
   {{0x6b897e9b,0xdb0003b2,0xd6e80154,0x00000000}},	//   _cogg, nimø, কুয়া_, --, 
   {{0x6b8817c7,0xf1bc0518,0xbb142d40,0xb9c401a9}},	//   _dogg, _ovál_, ﻳﺴﻰ_, дёни, 
   {{0xb338a493,0x79880067,0x3f840af9,0x3ea401a9}},	//   _ilçe, _qofw, ljou_, mzot_, 
   {{0x31346da4,0xe8dc01dc,0x6b897e9c,0xb6980120}},	//   ונים_, _thời_, _fogg, rcâm, 
   {{0x3f857e9d,0xb5f802fb,0xa774030d,0x00000000}},	//   njou_, kvát, влюч, --, 
   {{0xf98401c6,0x3ea47b02,0xdb00032e,0x00000000}},	//   _огдо, nzot_, fnmö, --, 
   {{0x28cc06e3,0xe8dc001e,0x7bc0002d,0x3f84022e}},	//   _सुवि, _giỏi_, _hjou, hjou_, 
   {{0xa4d402bf,0xe98401ec,0x6b880bfa,0xf1bc29d9}},	//   ворі, _تانۋ, _yogg, ्वसन, 
   {{0xdb000240,0x6b88058a,0xdedc01f3,0x70d8000d}},	//   dhmë, _xogg, _ሕጉን_, _भरौल, 
   {{0xe8dc0016,0x569464c2,0x3f857e9e,0xc4440330}},	// [27f90] _khởi_, _чапт, djou_, ویین_, 
   {{0x7bc00225,0x3ea400da,0xa3e45345,0x7ea4022e}},	//   _ljou, dzot_, _पीठ_, _gаpi, 
   {{0x99840153,0x00000000,0x00000000,0x00000000}},	//   lumų_, --, --, --, 
   {{0x7ae17e9f,0x1cdc025c,0xd2f802f2,0x00000000}},	//   _ozot, _རྪེ_, _رکرا_, --, 
   {{0x7ae03d81,0x2fcc007c,0xca2c0150,0x99840153}},	//   _nzot, rogg_, _ﺩﻫﺎ_, numų_, 
   {{0x7bc17ea0,0x6b8806bb,0x9f580393,0x5f7401d5}},	//   _ajou, _sogg, _curâ_, _یاقر, 
   {{0x6b897ea1,0x7bc057b7,0xb3380139,0xdb0001c7}},	//   _pogg, _bjou, _elçe, chmë, 
   {{0x0b44a283,0x99840153,0x00000000,0x00000000}},	//   хнин, kumų_, --, --, 
   {{0x7bc17ea2,0x3574044e,0x9f057ea3,0x6b881368}},	//   _djou, ጠኛታት_, _شولو, _vogg, 
   {{0x7ae01682,0x0d2000d1,0x00000000,0x00000000}},	//   _dzot, _сүкү, --, --, 
   {{0x6b897ea4,0x7bc00a85,0x60c0016b,0x28cc086b}},	//   _togg, _fjou, _ɛmmo, _सुशि, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3d040037,0x99840153,0x9c7c00ef,0x28cc07af}},	//   सुके_, gumų_, _izča, _सुरि, 
   {{0x628006af,0x00000000,0x00000000,0x00000000}},	//   _àmoi, --, --, --, 
   {{0x4374009b,0xdb0089b7,0x00000000,0x00000000}},	//   нуат, timø, --, --, 
   {{0x864402bf,0xdce800bc,0xb5f801ed,0x42080114}},	//   _зниж, _andě, gvás, знао_, 
   {{0x5a0c008f,0xf2a0004e,0x00000000,0x00000000}},	// [27fa0] ַלאַ, гитп, --, --, 
   {{0xb5f97ea5,0xdb000200,0x00000000,0x00000000}},	//   rvát, thmë, --, --, 
   {{0xe8dc0016,0xe7c400fe,0x201c1f3f,0x3f84007f}},	//   _khối_, োষীয, èvi_, tjou_, 
   {{0xcfa82a60,0x7ee492b5,0x3ea4009d,0x03a400d4}},	//   وانم_, нцле, tzot_, _чимо, 
   {{0x63a57ea6,0xdb00044e,0xb5f81aa9,0x3f84002d}},	//   mhin, shmë, lvár, rjou_, 
   {{0x63a57ea7,0x7bc067c3,0xedd005d9,0x81c803d4}},	//   lhin, _sjou, هيند, _লওক_, 
   {{0x44297ea8,0x71d40375,0x63a402b5,0x2b757ea9}},	//   nsb_, _נולד_, ohin, کینگ_, 
   {{0x63a57eaa,0x69c17eab,0x64480213,0x2d840240}},	//   nhin, _ajne, çdiy, ajne_, 
   {{0x7f400117,0x62840005,0x63a57eac,0x2fc40221}},	//   mgoq, nxio, ihin, énge_, 
   {{0xb5f80e33,0x63a4641b,0x2d980200,0x2fc40022}},	//   kvár, hhin, ëqet_, ĩnge_, 
   {{0x63a57ead,0x69c0002d,0x7bc00100,0x9f9c003a}},	//   khin, _djne, _tjou, ríæ_, 
   {{0x7c28564c,0x3cfc051f,0x69c09fc6,0xe8dc001e}},	//   msfr, _hgtv_, _ejne, _chối_, 
   {{0x63a57eae,0x7ae0ad83,0xeb941064,0x44280af9}},	//   dhin, _uzot, _яиц_, esb_, 
   {{0x18b97eaf,0x779001ed,0x2a98010f,0x00000000}},	//   _оглы_, ئیکا, _ציגײ, --, 
   {{0x395d7eb0,0x63a40dc9,0xa96414b7,0xdcb801e4}},	//   mets_, fhin, _чија_, _meĉo_, 
   {{0x7c289df3,0x63a57eb1,0x6c78008f,0x388c03b9}},	//   isfr, ghin, האלפ, cəra_, 
   {{0x2d840034,0x62357eb2,0x63b40139,0x00000000}},	// [27fb0] yjne_, лету, _şenç, --, 
   {{0x63a57eb3,0x9f58180f,0x59a400cd,0x0f181cd2}},	//   ahin, _aurà_, गोचर, दर्स_, 
   {{0x63a57eb4,0x752401a6,0xb5f801d3,0x7c2801bf}},	//   bhin, majz, svás, jsfr, 
   {{0x63a57eb5,0x7c28cf77,0x9f5819f5,0x75257eb6}},	//   chin, dsfr, _curà_, lajz, 
   {{0x9f597eb7,0xa5d801ed,0xdb0004e6,0x7c280036}},	//   _durà_, _زبیر_, chmé, esfr, 
   {{0x395d7eb8,0x0fd00729,0x9f597eb9,0xd83802e2}},	//   jets_, িষেধ, _purã_, krč_, 
   {{0x395d7eba,0x9f5804cc,0xc61c00bc,0x4c68009d}},	//   dets_, _furà_, _भब्य_, фийн_, 
   {{0x69c40219,0x00000000,0x00000000,0x00000000}},	//   čjem, --, --, --, 
   {{0x272003f4,0x3b803e02,0x395d7ebb,0xba217ebc}},	//   _ভালো_, рлыг, fets_, адык, 
   {{0x63a57ebd,0x6ca40b7e,0x395d7ebe,0x9f580589}},	//   zhin, _преж, gets_, _turã_, 
   {{0x07a4a6bb,0xe8dc0016,0x75240552,0xb698006a}},	//   ванн, _phối_, dajz, mbây, 
   {{0x63a402d3,0x00000000,0x00000000,0x00000000}},	//   xhin, --, --, --, 
   {{0x63a57ebf,0x395d7ec0,0x62842112,0x6d40346e}},	//   vhin, bets_, xxio, ogna, 
   {{0x6d417ec1,0x63a404fe,0x395d7ec2,0x59f80276}},	//   ngna, whin, cets_, _зечя_, 
   {{0x44297ec3,0x63a40c18,0x6d417ec4,0xb5f8dce6}},	//   usb_, thin, igna, tvár, 
   {{0x63a40cfe,0x6b980009,0xdb017ec5,0x6284005a}},	//   uhin, nkug, thmé, txio, 
   {{0x63a57ec6,0x2c60000f,0x44297ec7,0xb5f801ed}},	// [27fc0] rhin, _lűd_, ssb_, rvár, 
   {{0x63a57ec8,0x67257ec9,0xb5f82cda,0x6d400083}},	//   shin, _heij, lwán, jgna, 
   {{0x66057eca,0x67257ecb,0x9f58067c,0xdd94774d}},	//   _huik, _keij, _aurá_, ғайы, 
   {{0x66057ecc,0x6d417ecd,0x63a57ece,0x7c297ecf}},	//   _kuik, egna, qhin, vsfr, 
   {{0x67257ed0,0x23600369,0xf770008f,0xdcb801e4}},	//   _meij, meij_, יקא_, _peĉo_, 
   {{0x6d4004f3,0x7c297ed1,0x67257ed2,0x395c01b8}},	//   ggna, tsfr, _leij, xets_, 
   {{0x7c2800c6,0x395c5629,0x66057ed3,0x3cfc0212}},	//   usfr, vets_, _luik, _vgtv_, 
   {{0x6b98409c,0x5bcc1a04,0x7e6002e2,0xd8380427}},	//   gkug, ावेव, pwop, vrč_, 
   {{0x395c5629,0x66040270,0x61fd7ed4,0xd9100af6}},	//   tets_, _nuik, _kirl, میش_, 
   {{0x60dc0649,0xa3e406ab,0xe8dc01fb,0x6b997ed5}},	//   _kyrm, _पीस_, _nhồi_, akug, 
   {{0x67257ed6,0xb9081533,0x61fd7ed7,0x60dc0076}},	//   _beij, _मर_, _mirl, _jyrm, 
   {{0x66057ed8,0x79980227,0x61fc0115,0x24980076}},	//   _buik, sktw, _lirl, dyrm_, 
   {{0x67240793,0x395d7ed9,0x61fc01ab,0xdce803e3}},	//   _deij, pets_, _oirl, _ildı, 
   {{0x25b97eda,0x66057edb,0x5694052f,0x61fd7edc}},	//   girl_, _duik, _ҡайт, _nirl, 
   {{0x67257edd,0xb3397ede,0xb5f80085,0xa5f97edf}},	//   _feij, _alça, bwán, теру_, 
   {{0x67240007,0x66040093,0xb4004ecc,0x9f4400e4}},	//   _geij, _fuik, лүүд, _mimó_, 
   {{0x66040589,0x9f440548,0x60dc00a2,0x22417ee0}},	// [27fd0] _guik, _limó_, _ayrm, guik_, 
   {{0x61fc0598,0x672401f5,0x611401c6,0x00000000}},	//   _cirl, _zeij, идуу, --, 
   {{0xdb017ee1,0x66057ee2,0xd47800c8,0x67257ee3}},	//   nimó, _zuik, _װאָל, _yeij, 
   {{0x224137a8,0x5ecc00bd,0x660404ce,0x60dc0432}},	//   buik_, ়েছে, _yuik, _dyrm, 
   {{0x22857ee4,0x9e657ee5,0x61fc06f2,0x6d417ee6}},	//   _кург, لاون, _firl, tgna, 
   {{0xdce812ca,0x6d40113c,0xdb000998,0x61fd7ee7}},	//   _aldı, ugna, kimó, _girl, 
   {{0x6d417ee8,0xdc2800c6,0x2b5c067c,0x60dc010b}},	//   rgna, نسيه_, teuc_, _gyrm, 
   {{0x5f9408ca,0x61fcf309,0x6d409c91,0x7eb000fd}},	//   _кист, _zirl, sgna, _qıpç, 
   {{0x67257ee9,0x7ea402b5,0x62800129,0x52c0012c}},	//   _reij, tōpū, _àmot, _एशोस, 
   {{0x6d40074d,0x6724019b,0xca740184,0x66057eea}},	//   qgna, _seij, _ҡулы, _ruik, 
   {{0x660502f3,0xec68036b,0x7ea402b1,0x7eb00205}},	//   _suik, _юрак_, rōpū, _tıpç, 
   {{0x66057eeb,0x00000000,0x00000000,0x00000000}},	//   _puik, --, --, --, 
   {{0x9b74121a,0x67240108,0xb5f80174,0x764c00a2}},	//   _خالص, _veij, tváp, gtcy, 
   {{0x67240428,0x66040481,0x044424fc,0x00000000}},	//   _weij, _vuik, легн, --, 
   {{0x67240428,0xb5f803b2,0x00000000,0x00000000}},	//   _teij, rváp, --, --, 
   {{0x61fd7eec,0x98c40184,0x249802c4,0xd3c40150}},	//   _sirl, _әсәл, ryrm_, لتقى, 
   {{0xade01533,0x60dd7eed,0x98fc01e4,0xdb00000d}},	// [27fe0] गतान_, _syrm, reĉe, vimü, 
   {{0x22403441,0x60dc06a3,0xa3e4375c,0xb5f80085}},	//   ruik_, _pyrm, _पीर_, nwál, 
   {{0x9f4429ef,0x61fd7eee,0x69c40010,0xdb000037}},	//   _timü_, _virl, čjeh, timü, 
   {{0x61fc0036,0xff241a71,0xbfc404b3,0x82a40153}},	//   _wirl, умдо, ыбек, _бамж, 
   {{0x61fc0368,0x2fc400d2,0x9f4400cf,0xdb000037}},	//   _tirl, énga_, _simó_, rimü, 
   {{0xdd90fcc0,0x61fc0597,0x60dc005b,0xdb000037}},	//   توت_, _uirl, _tyrm, simü, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7e64025a,0x628000d8,0xe5142ac3,0x00000000}},	//   _âkpo, _àmos, तुति_, --, 
   {{0x6f900597,0x6a1013f9,0x1ee81291,0x00000000}},	//   _القض, یبیر, _شوئی_, --, 
   {{0x9f4400db,0x9f5851bb,0x20b8000d,0xdb0000e4}},	//   _timó_, _burç_, _आधाध, timó, 
   {{0x3d040882,0x6df000c6,0x71d40a1e,0x9840001f}},	//   ātvā_, _اكلا, רויד_, _ተደራጅ, 
   {{0xdb0000d8,0xab805df2,0x487000cf,0x00000000}},	//   rimó, _гушк, زگىس, --, 
   {{0xa3d80118,0x00000000,0x00000000,0x00000000}},	//   िवन_, --, --, --, 
   {{0x23a8001f,0x00000000,0x00000000,0x00000000}},	//   _መለወጥ_, --, --, --, 
   {{0x5fd40da5,0x00000000,0x00000000,0x00000000}},	//   धकाल, --, --, --, 
   {{0x5678084c,0xdce802fb,0xe8dc004d,0x764c035a}},	//   _абия_, _nadč, _chổi_, ptcy, 
   {{0x0ce058fc,0xe8f4008e,0x00000000,0x00000000}},	// [27ff0] _फर्म, _илә_, --, --, 
   {{0xf3f4052f,0xdb0000c6,0x00000000,0x00000000}},	//   _әммә_, dhmí, --, --, 
   {{0xe61039b1,0x45f8011a,0x00000000,0x00000000}},	//   _وشی_, _שהתג, --, --, 
   {{0x0eb85067,0xf3650341,0xda0409bb,0x8eb80022}},	//   кулы_, _стон, रदात_, кылт_, 
   {{0xe8080764,0x00000000,0x00000000,0x00000000}},	//   _संभा_, --, --, --, 
   {{0xf3fc00e4,0xf150004b,0x91c400d1,0x00000000}},	//   _hiã_, _دکرک, _тәбл, --, 
   {{0x6280a37d,0xdde4013d,0x00000000,0x00000000}},	//   _àmor, сәтү, --, --, 
   {{0xa0c400c6,0x200c020c,0xca48036b,0x28cc0037}},	//   _ايفو, _édia_, پلده_, _सुगि, 
   {{0x2ab46f78,0x49c97eef,0x0ae801a9,0xee7001af}},	//   ыңды_, клин_, ъдий_, _ыңды, 
   {{0xf3fc0004,0x00000000,0x00000000,0x00000000}},	//   _liã_, --, --, --, 
   {{0xdb0066ce,0x47c512d7,0xabb000c7,0x9d180107}},	//   rimò, ибов, _лажә, _сохт_, 
   {{0xf3fc0004,0xa3e400c5,0x00000000,0x00000000}},	//   _niã_, _पीं_, --, --, 
   {{0xf2dc019f,0xf3e80154,0x98b400d1,0x00000000}},	//   _nyâ_, কদার_, иһәт_, --, 
   {{0x4524045e,0x48797ef0,0x7ae405d1,0x690402d5}},	//   _বাহক_, _асия_, ükte, _сядз, 
   {{0xe8dc01fb,0x07a57ef1,0xa27402d3,0x9f9c00ae}},	//   _phổi_, _вайн, ከውንን_, ríú_, 
   {{0xf2dc006a,0xda08001e,0xe7940133,0x052400eb}},	//   _byâ_, _hỏa_, _چاکک, বলের_, 
  
   {{0xdce801ef,0xfafc00ef,0x00000000,0x00000000}},	// [28000] _radč, _čīka_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe8dc001e,0x806428f1,0x717032f7,0x9c7c013a}},	//   _thổi_, рвеж, تهلا, _kyče, 
   {{0xf3fc01fb,0xadc00241,0x00000000,0x00000000}},	//   _giã_, _itẹn, --, --, 
   {{0xa0500092,0xbfa80050,0x28cc00c5,0x9c7c013a}},	//   _ማግኘታ, _یارٕ_, _सँझि, _myče, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7c843c1f,0x7b64e36e,0x9b58009d,0x00000000}},	//   руле, атпе, гийт_, --, 
   {{0xbe14216b,0x00000000,0x00000000,0x00000000}},	//   _نورع, --, --, --, 
   {{0xe80800ab,0x4ed400f5,0xefb01dd8,0x00000000}},	//   _सूबा_, _люфт, _بینگ, --, 
   {{0x83040135,0x00000000,0x00000000,0x00000000}},	//   _མུའུ_, --, --, --, 
   {{0xdb2453f3,0x9f580004,0x9a843500,0xadc001e1}},	//   _هوای, _turä_, руқл, _ntẹn, 
   {{0x3da801f0,0x00000000,0x00000000,0x00000000}},	//   _якҷо_, --, --, --, 
   {{0x0ba810fe,0xadc00241,0x19597ef2,0x00000000}},	//   _حالى_, _atẹn, _балы_, --, 
   {{0xe9703738,0x48700137,0x00000000,0x00000000}},	//   _وهند, زگۉس, --, --, 
   {{0xf3fc0589,0xe5c97ef3,0xf2dc0142,0xdce800ef}},	//   _piã_, рыял_, _syâ_, _indē, 
   {{0xe8080d0a,0x28cc00bc,0x32f40124,0xb9d40092}},	//   _संता_, _सुटि, иҭны_, _ችሎ_, 
   {{0xb5f001ec,0x00000000,0x00000000,0x00000000}},	// [28010] _мүмі, --, --, --, 
   {{0xf2dc019f,0x2258b5d4,0x7580277d,0x00000000}},	//   _vyâ_, рифы_, _بیسم, --, 
   {{0xbf2002ab,0x2fc40124,0x00000000,0x00000000}},	//   मरून_, éngo_, --, --, 
   {{0x7c2c03cd,0x00000000,0x00000000,0x00000000}},	//   _åbry, --, --, --, 
   {{0x6e64c91b,0x313000c7,0x9f2400d1,0xceb801ef}},	//   ртеж, _мҵар, زۈلۈ, _keři_, 
   {{0xb4e8000d,0x2eb400cd,0x00000000,0x00000000}},	//   _टराय_, _अधीत, --, --, 
   {{0x6f840022,0x8afc01ef,0x00000000,0x00000000}},	//   _куаж, deřa, --, --, 
   {{0x62800077,0xdfd49684,0x9f580267,0x00000000}},	//   _ámoc, _досы, _strö_, --, 
   {{0x28cc044b,0x10a40166,0x9c7c00c0,0x00000000}},	//   _सुजि, _тиңн, _ryče, --, 
   {{0x9c7c01ef,0x00000000,0x00000000,0x00000000}},	//   _syče, --, --, --, 
   {{0x45240011,0x00000000,0x00000000,0x00000000}},	//   _বালক_, --, --, --, 
   {{0x6810054e,0xf1bc01ef,0x00000000,0x00000000}},	//   _năde, _zvát_, --, --, 
   {{0xeab0fdc2,0x9c7c0122,0xda08004d,0x98fc00df}},	//   _بعض_, _vyče, _tỏa_, reĉa, 
   {{0xb2197ef4,0x4df800c8,0x69cc06af,0x7cc806be}},	//   _kræf, רפֿא, éced, _fәrd, 
   {{0x68100311,0xdce800dc,0x28cd7ef5,0x9c7c01ef}},	//   _băde, _kadā, _सुचि, _tyče, 
   {{0x68100311,0xca440150,0x00000000,0x00000000}},	//   _căde, _ﺘﻤﺕ_, --, --, 
   {{0x68100311,0xdce800cd,0xda080051,0x00000000}},	// [28020] _dăde, _madā, _lỏn_, --, 
   {{0x6d8c1682,0x00000000,0x00000000,0x00000000}},	//   _ṱanz, --, --, --, 
   {{0x9f580022,0x9c7c013a,0xf1bca1f3,0x00000000}},	//   _otrô_, _myčc, _rvát_, --, 
   {{0x43840491,0xdb2405d1,0x7e280a4a,0xdce80055}},	//   _الحق, ürüy, гіка_, _nadā, 
   {{0xdd94597d,0x7e554a2a,0xcee80b38,0xa3e400e1}},	//   жалы, стец, ۇرۇن_, _पीए_, 
   {{0xf48404d3,0xc0cc001f,0x22417ef6,0xa364009f}},	//   _ئایی, ጥላል_, mrik_, _اُڏو, 
   {{0x409400c6,0x2478007f,0x22401f53,0xda080051}},	//   _الزر, _jčm_, lrik_, _cỏn_, 
   {{0x2018011c,0x224001c6,0xada00022,0xdb981078}},	//   _itri_, orik_, _ҵаул, рвич_, 
   {{0xdce80882,0x0bb404fb,0xd07c001f,0x388c00ac}},	//   _dadā, تجوگ, _የሚሰሩ_, məri_, 
   {{0x388c11a9,0xf9697ef7,0x2240c710,0xdb000332}},	//   ləri_, урий_, irik_, ghmá, 
   {{0x22417ef8,0x3bd40845,0xec102f84,0xbb4800ec}},	//   hrik_, _людс, _فولد, _ملان_, 
   {{0x22417ef9,0xdce80aed,0xab240798,0x388c03b9}},	//   krik_, _gadā, _гоца_, nəri_, 
   {{0x9f580ca8,0xba7400db,0x68100356,0x6bd410e8}},	//   _burú_, _داات, _răde, _اونس_, 
   {{0x22400efa,0x9f58006a,0x7ae17efa,0x20197efb}},	//   drik_, _purû_, _iyot, _otri_, 
   {{0xd794013d,0xca4402dd,0xdce800dc,0x388c03e3}},	//   _микъ, _ﺘﺤﺕ_, _yadā, kəri_, 
   {{0x7ae17efc,0x2240753f,0x67d406bb,0x99d400db}},	//   _kyot, frik_, _нощу, _اتچا, 
   {{0x20197efd,0x7ae00882,0x91b80801,0x68100356}},	// [28030] _atri_, _jyot, агат_, _văde, 
   {{0x622404a9,0x24780100,0x9f583eba,0xdb000254}},	//   سىمل, _fčm_, _gurú_, bimö, 
   {{0x388c03be,0x9f4400c7,0x22417efe,0xa3e40d79}},	//   fəri_, _limõ_, arik_, _पीक_, 
   {{0x7ae17eff,0x3b04016d,0x8afc00bc,0x388c00ac}},	//   _oyot, _ngoq_, deřn, gəri_, 
   {{0x7ae17f00,0x59c8228a,0x22400c6a,0xdce800e2}},	//   _nyot, िचार, crik_, _radā, 
   {{0x37cc00bd,0xdce83a71,0xb2197f01,0x2478007f}},	//   রতির, _sadā, _præf, _yčm_, 
   {{0x7ae17f02,0xdce80882,0x388c00ac,0x290007f5}},	//   _ayot, _padā, bəri_, žjak_, 
   {{0x7ae17f03,0xdb0000af,0xaf344e10,0xda080208}},	//   _byot, himõ, _درست, _vỏn_, 
   {{0x394c01ee,0x7ae000ca,0xdce80b13,0x37cc015b}},	//   _bcfs_, _cyot, _vadā, রতার, 
   {{0xb218037e,0x320005da,0x7ae000cd,0x09b82cc5}},	//   _træf, _jijy_, _dyot, ুত্থ, 
   {{0x7ae0379d,0xdce80882,0x5ba8dc64,0x3a240100}},	//   _eyot, _tadā, ркөм_, _ewop_, 
   {{0x4524045e,0x7ae00085,0xdb000998,0x2240991b}},	//   _বাইক_, _fyot, shmá, yrik_, 
   {{0xa3d874f6,0x7ae08164,0x2478007f,0xe80800e1}},	//   िवस_, _gyot, _sčm_, _संवा_, 
   {{0x2a6c3b6a,0x22408b9f,0x388c0213,0x614001e1}},	//   _isgb_, vrik_, zəri_, _málà, 
   {{0xc3940640,0x290401d5,0x388c00ac,0x61400241}},	//   ојањ, _igna_, yəri_, _lálà, 
   {{0x42246575,0xdb017f04,0x7ae0009f,0xa3e4000d}},	//   ждав, rimö, _yyot, _पीख_, 
   {{0x27e17f05,0x68e17f06,0x20197f07,0x76483262}},	// [28040] _ikin_, _hynd, _stri_, _ägyp, 
   {{0x22417f08,0x68e17f09,0x2fdc0694,0x2b4c020b}},	//   rrik_, _kynd, _akug_, _lcgc_, 
   {{0x22406475,0x27e0005a,0x68e0062c,0x322400bc}},	//   srik_, _kkin_, _jynd, _čtyř_, 
   {{0x68e17f0a,0xb2183b9d,0x2a6c0205,0x00000000}},	//   _mynd, _bræd, _osgb_, --, 
   {{0x63a57f0b,0x68e17f0c,0x29057f0d,0x27e00166}},	//   mkin, _lynd, _ogna_, _mkin_, 
   {{0x63a57f0e,0x2b4c004e,0x7ae0da47,0x6da00e92}},	//   lkin, _acgc_, _ryot, мича, 
   {{0x63a57f0f,0xbf657f10,0x7ae0079b,0xb218037e}},	//   okin, _ودرو, _syot, _præg, 
   {{0x7ae17f11,0x29057f12,0x61400241,0x3a24033b}},	//   _pyot, _agna_, _fálà, _pwop_, 
   {{0x63a57f13,0x68e00363,0xb2194607,0x20040254}},	//   ikin, _aynd, _græd, _iimi_, 
   {{0x63a57f14,0x7ae17f15,0x68e00649,0x20057f16}},	//   hkin, _vyot, _bynd, _himi_, 
   {{0x20057f17,0x2a6c009a,0x27e00263,0x68e00b6a}},	//   _kimi_, _esgb_, _bkin_, _cynd, 
   {{0x29057f18,0x63a40cf9,0x27e003f9,0x68e17f19}},	//   _egna_, jkin, _ckin_, _dynd, 
   {{0x200416cb,0x7ae00107,0x68e001f5,0xb21801bf}},	//   _mimi_, _uyot, _eynd, _kræe, 
   {{0x200407d6,0x1dbc1944,0x27e17f1a,0x68e0cf5f}},	//   _limi_, ्चित, _ekin_, _fynd, 
   {{0x6458014a,0xd8a8004b,0x68e17f1b,0x32080129}},	//   _ävil, _دهغو_, _gynd, _sucy_, 
   {{0x20048234,0x5214330e,0x63a57f1c,0xe3b001d5}},	//   _nimi_, здат, gkin, نرق_, 
   {{0x1dbc1b61,0x3e5c00e2,0xa3e401ad,0x888007d6}},	// [28050] ्चात, nātā_, _पीओ_, _قیین, 
   {{0x20057f1d,0x63a57f1e,0xf4840262,0xb5a55b1f}},	//   _aimi_, akin, _думн, _фрий, 
   {{0x63a57f1f,0x20057f20,0xdce80024,0xa3d80406}},	//   bkin, _bimi_, _indė, िवश_, 
   {{0x63a40fa9,0xedc0206b,0xb2197f21,0x8e380035}},	//   ckin, वच्छ, _præd, مستر_, 
   {{0x20057f22,0xa3e40c2e,0xa77c00c8,0xf1a4033a}},	//   _dimi_, _पीट_, יראפ, _дрвн, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x20057f23,0xda08004d,0x20c4022e,0x00000000}},	//   _fimi_, _dỏm_, _жстг, --, 
   {{0x20057f24,0x68e006a3,0xb21804ce,0x614001e1}},	//   _gimi_, _rynd, _træd, _tálà, 
   {{0x68e04df4,0x9c7c1155,0x00000000,0x00000000}},	//   _synd, _vyča, --, --, 
   {{0x63a40323,0x2a6c070d,0x68e0138f,0x2004098d}},	//   zkin, _vsgb_, _pynd, _zimi_, 
   {{0x20057f25,0xb3387236,0x764000b8,0x50bc00cd}},	//   _yimi_, _elçi, _ānya, ्पिष, 
   {{0x1cb801b9,0x68e17f26,0x40b4010f,0x20040200}},	//   _ظالب_, _vynd, פּיל_, _ximi_, 
   {{0x3f88013f,0x29040ac5,0x68e17f27,0x63a57f28}},	//   _ɑbu_, _tgna_, _wynd, vkin, 
   {{0x63a57f29,0x68e17f2a,0xdb0006ed,0x00000000}},	//   wkin, _tynd, rimô, --, 
   {{0x9478188c,0xa3d8012c,0x07a40640,0x6fd82e3c}},	//   осту_, िवल_, _накн, यकां, 
   {{0xc7240323,0x27e00bc9,0x63a57f2b,0x00c80032}},	//   _эдий, _ukin_, ukin, ҙлек_, 
   {{0x63a57f2c,0xc6480491,0x00c829db,0xbb3c001f}},	// [28060] rkin, _اجعل_, әлек_, _ባጠቃላ, 
   {{0x63a57f2d,0x20041bb7,0xb6b8025f,0x6744012d}},	//   skin, _simi_, _לצפי, łują, 
   {{0x63a57f2e,0x0368713a,0x20057f2f,0xd20000d1}},	//   pkin, _линк_, _pimi_, түрк, 
   {{0xb218019b,0xdce8012d,0xa3d801f9,0x00000000}},	//   _dræb, _jadą, िवळ_, --, 
   {{0xb218003a,0x200401a6,0x00000000,0x00000000}},	//   _præe, _vimi_, --, --, 
   {{0x3e5c00e2,0x6e400131,0xb21802d2,0x00000000}},	//   vātā_, رنىم, _fræb, --, 
   {{0x20057f30,0x9b940354,0x201c03b2,0xdd840150}},	//   _timi_, дийц, ívid_, зықп, 
   {{0x3e5d7f31,0xdb00023a,0xd91001b9,0x20040356}},	//   tātā_, yhmä, چیش_, _uimi_, 
   {{0xadc007ae,0xd910d36d,0xb218037e,0x6e400395}},	//   _quản, نیش_, _træe, _петз, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x65b17f32,0x62800f91,0x19580022,0x00000000}},	//   _mähd, _šmol, баҿы_, --, 
   {{0x37a97f33,0xeb944e87,0x65b0049b,0xe704150e}},	//   стон_, _них_, _lähd, کسپی, 
   {{0xa3d00b02,0x57e8004e,0x00000000,0x00000000}},	//   वचन_, йдүм_, --, --, 
   {{0x65b0049b,0x0ae86762,0xaa380375,0x98ac007f}},	//   _nähd, _برمي_, _פתוח, ladč_, 
   {{0xe7e804af,0x5fdc000d,0x00000000,0x00000000}},	//   _टीका_, बवाल, --, --, 
   {{0x9c7c00ef,0x00000000,0x00000000,0x00000000}},	//   _uzču, --, --, --, 
   {{0xe2f978d3,0x00000000,0x00000000,0x00000000}},	// [28070] зеті_, --, --, --, 
   {{0xb2180393,0xa6f42b95,0x00000000,0x00000000}},	//   _præb, _языш, --, --, 
   {{0x8f750617,0x16840133,0x00000000,0x00000000}},	//   дулі, _راکێ, --, --, 
   {{0x6804020c,0x60f80212,0x00000000,0x00000000}},	//   lèjè, їнця_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb2189e56,0x9c7c0306,0x00000000,0x00000000}},	//   _træb, _vyčn, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xca8405f5,0xb218003a,0xd1f00092,0x4aa801af}},	//   дгий, _græc, ቃዎች_, жкин_, 
   {{0x9f9c1427,0xc0500092,0x00000000,0x00000000}},	//   míð_, _ያልተፈ, --, --, 
   {{0xd838007f,0x9f9c148b,0x65b0340f,0xc198010f}},	//   ryčn_, líð_, _kähe, ַשרי, 
   {{0x4b540801,0xd7240154,0x65b0010b,0xd83802e2}},	//   _жълт, _ভাড়া_, _jähe, syčn_, 
   {{0x65b17f34,0xd838007f,0xade40244,0x2cac0205}},	//   _mähe, myčl_, _بفڕم_, ımdı_, 
   {{0x65b03859,0xe60400d1,0xbf34010f,0x21f40139}},	//   _lähe, нҗин, וארץ_, lähe_, 
   {{0x49040aaf,0x9c7c09a8,0x482400db,0x7bcc02d2}},	//   _قوشق, _izčr, _قىتق, _íbur, 
   {{0x65b17f35,0x21f40112,0xd838007f,0x00000000}},	//   _nähe, nähe_, nyčl_, --, 
   {{0x25b40006,0x65b000a2,0x4ae001f9,0x00000000}},	//   _šalį_, _sähd, _पडाव, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [28080] --, --, --, --, 
   {{0xb140e29b,0x65b00432,0xd838007f,0x00000000}},	//   кнул, _bähe, kyčl_, --, 
   {{0xb2197f36,0xe3e80050,0x80697f37,0x00000000}},	//   _præc, _فکرن_, تماق_, --, 
   {{0x201c00da,0x44397f38,0xd838007f,0x2614000d}},	//   īvi_, _ivp_, dyčl_, _käo_, 
   {{0x65b002f6,0x05d00034,0x42d40212,0x8fd40166}},	//   _tähd, _सदाब, _ціну, хәрә, 
   {{0x65b179ec,0x44397f39,0xd17402dd,0x2614000d}},	//   _fähe, _kvp_, _пысы, _mäo_, 
   {{0x4a080156,0x443801a6,0xf66803b2,0x65b0013d}},	//   _གངུལ_, _jvp_, _kvæð_, _gähe, 
   {{0xda0801dc,0xe8dc01fb,0xdb00000f,0x69cc056a}},	//   _hỏi_, _chọi_, chmû, écen, 
   {{0xe6c802ab,0x65b0010b,0x261400c5,0x9c7c0306}},	//   रपोज, _zähe, _näo_, _tyčo, 
   {{0x4438b188,0x98ac0100,0x6e9873cd,0x00000000}},	//   _ovp_, sadč_, _ובמח, --, 
   {{0xda08001e,0x4438009a,0xbca4212d,0x7d18127b}},	//   _mỏi_, _nvp_, _تماي, _ifts, 
   {{0x7ac41a39,0xda080208,0xded00092,0xbb440395}},	//   _осле, _lỏi_, _ሥራን_, _цедк, 
   {{0x44383c36,0x7c380109,0x00000000,0x00000000}},	//   _avp_, _hvtr, --, --, 
   {{0x58d44963,0x38c8010b,0x44380153,0x39e0190b}},	//   _полт, _муйн_, _bvp_, _шәйғ, 
   {{0x9f597f3a,0x65b00209,0x7988007f,0x44397f3b}},	//   _burü_, _bähb, _infw, _cvp_, 
   {{0x395c2963,0x090000eb,0x00000000,0x00000000}},	//   lfts_, লুহু_, --, --, 
   {{0x65b000ee,0x9f9c2200,0x7d180857,0x62348cf8}},	// [28090] _sähe, víð_, _ofts, кету, 
   {{0xd1317f3c,0x30e84f33,0x65b05f82,0x32057f3d}},	//   اما_, офен_, _pähe, öny_, 
   {{0x9f9c1ffb,0x53341142,0x44380218,0x4524009e}},	//   tíð_, _пент, _gvp_, _বাচক_, 
   {{0x65b17701,0x8e540046,0x7d18127b,0x9c7c0306}},	//   _vähe, еткі, _afts, _vyčl, 
   {{0x9f9c08a7,0x9f58004e,0x7c397f3e,0x8d642218}},	//   ríð_, _auró_, _avtr, евле, 
   {{0x65b0033d,0x9f580048,0xd838007f,0x62340063}},	//   _tähe, _buró_, ksč_, _јеру, 
   {{0xe8dc063f,0xda08004d,0xfce05960,0x68100356}},	//   tbọl_, _gỏi_, лошо, _rădo, 
   {{0x9f5809d7,0x7988b5fd,0x7d1803ac,0x21f402b5}},	//   _duró_, _anfw, _efts, rähe_, 
   {{0xc954d822,0xaca00241,0x995800bc,0x9f3402dd}},	//   нтны, _iyọl, láři_, _шеті, 
   {{0x6e380223,0xaee0002b,0x21f40254,0xa9c000db}},	//   _ivub, _arṇa, pähe_, ئمدۉ, 
   {{0x9958012c,0xb338010e,0x99e800a2,0xb6a001d5}},	//   náři_, _goçg, _siňý, қирл, 
   {{0x44380cf9,0x7988007f,0x4ab81d82,0x9f4400d0}},	//   _rvp_, _enfw, _нуля_, _shmú_, 
   {{0x6b8906cd,0x44397f3f,0x6f18014b,0x7c3805da}},	//   _ingg, _svp_, _mfuc, _zvtr, 
   {{0x6e38d489,0x8ac402dd,0x44382238,0x2614000d}},	//   _mvub, _оққа_, _pvp_, _väo_, 
   {{0x6f1816a3,0x4438022e,0x99580118,0x2a7c0254}},	//   _ofuc, _qvp_, jáři_, lvub_, 
   {{0xae0c09ab,0xda080051,0x995801ef,0x00000000}},	//   ादान_, _rỏi_, dáři_, --, 
   {{0x6b880a2e,0xe8dc0016,0xc2080447,0x03a4016c}},	// [280a0] _mngg, _khỏi_, سقان_, _ҷино, 
   {{0x6b880083,0x6f18035a,0x2fcc0066,0x3ec00213}},	//   _lngg, _afuc, engg_, _üstə_, 
   {{0x6e38046a,0x03a4139b,0x6b897f40,0x44380e78}},	//   _avub, _зино, _ongg, _uvp_, 
   {{0x645d7f41,0x9f580ffb,0x00000000,0x00000000}},	//   mtri, _aurò_, --, --, 
   {{0xb21801bf,0x98fc010f,0xd838007f,0x00000000}},	//   _træa, reĉi, vyčm_, --, 
   {{0x6b88046b,0xdd900597,0x9f5949ad,0xb218037e}},	//   _angg, شوب_, _curò_, _kræn, 
   {{0x6e380e61,0x9f580bdf,0x6b88003e,0xd8380100}},	//   _evub, _durò_, _bngg, tyčm_, 
   {{0x2fc40a40,0x9f58026c,0x645d7f42,0x00000000}},	//   éngt_, _eurò_, itri, --, 
   {{0x645d7f43,0x7d1802d0,0x1af40395,0x00000000}},	//   htri, _tfts, ъпия, --, 
   {{0x6b882ebe,0x9f580137,0xded00092,0x3ea44831}},	//   _engg, _turó_, _ሥራና_, myot_, 
   {{0xa3d013b4,0xd8f800d6,0x645c00fb,0x3ea4263e}},	//   वचा_, ьної_, jtri, lyot_, 
   {{0x645d7f44,0xd83804cc,0xb33808a9,0x00000000}},	//   dtri, rsč_, _koçe, --, 
   {{0xb5f82cd7,0x645c00c5,0x7bc08a15,0xe6640a5b}},	//   ntág, etri, _imou, лтро, 
   {{0xb218019b,0x645d7f45,0x3ea40086,0xb6c401c6}},	//   _bræn, ftri, iyot_, _үсий, 
   {{0x645d7f46,0xa4d400d6,0x7bc016eb,0xa81400c6}},	//   gtri, горі, _kmou, _كتير_, 
   {{0x3ea4113c,0xb21800b5,0x00000000,0x00000000}},	//   kyot_, _dræn, --, --, 
   {{0x56941fe2,0x8afc00bc,0x95d812e7,0xb3380200}},	// [280b0] _рапт, teři, _одит_, _noçe, 
   {{0x3ea4079b,0x645c01e0,0xb2180252,0x6f180268}},	//   dyot_, btri, _fræn, _sfuc, 
   {{0xb2183f87,0x645cc6d9,0x7bc17f47,0x764c012d}},	//   _græn, ctri, _omou, lucy, 
   {{0x201c17cd,0xf420004e,0x00000000,0x00000000}},	//   ívia_, _изүү, --, --, 
   {{0xc3c17f48,0x3ea57f49,0xddd57f4a,0x00000000}},	//   _төрл, gyot_, _šašk, --, 
   {{0x7bc17f4b,0x3ea0006c,0xbea17f4c,0x644800da}},	//   _amou, ришг, рашк, šdie, 
   {{0x2fc40a40,0x06e001ec,0xd7e00a59,0x61e0008e}},	//   éngs_, _ﺍﺼﻁﺩ, नवाच, _ímla, 
   {{0x764d7f4d,0x65b17f4e,0xffc0004e,0x5f940408}},	//   kucy, _mäha, _көчп, _йист, 
   {{0x645d7f4f,0x98ac005f,0x680801e1,0x6ee4007b}},	//   ztri, vadā_, _lèjì, _أسأل, 
   {{0x645c01ee,0x7bc17f50,0x6b880399,0xda6400db}},	//   ytri, _emou, _wngg, اايي, 
   {{0x645d7f51,0x200c1dd4,0x6b880a2e,0xe8080c2e}},	//   xtri, _édit_, _tngg, _सूखा_, 
   {{0x6b897f52,0x2ca41f60,0x645c01e0,0xdce80118}},	//   _ungg, mynd_, vtri, _ladě, 
   {{0x645d7f53,0x764c0223,0x98ac0b13,0xe8dc004d}},	//   wtri, gucy, radā_, _thỏi_, 
   {{0x645d7113,0xdce800bc,0x65b00166,0x88c4007b}},	//   ttri, _nadě, _bäha, _لتعل, 
   {{0x645d7f54,0x657c03fa,0x69c17f55,0x65b00166}},	//   utri, rdrh, _imne, _cäha, 
   {{0x764d7f56,0x06840139,0x3ea4011f,0xc7640046}},	//   bucy, _агин, yyot_, _شاعى, 
   {{0x645d7f57,0x00000000,0x00000000,0x00000000}},	// [280c0] stri, --, --, --, 
   {{0xb218105c,0x814400db,0x2ca44f5a,0x0574030f}},	//   _træn, ئنان, kynd_, _شاخد, 
   {{0x645c7cde,0x69c0037e,0x9c7c0306,0x9f5802d2}},	//   qtri, _mmne, _vyčk, _burð_, 
   {{0xdce80038,0x03a400ea,0x38780129,0xb3380166}},	//   _podľ, _римо, _âpre_, _poçe, 
   {{0x69c0f892,0xa24897d1,0x9c7c0306,0x2fc4020c}},	//   _omne, _سیال_, _tyčk, ènga_, 
   {{0xc1d046e8,0x7bc17f58,0x2ca40267,0x98ac054e}},	//   _төбә, _smou, fynd_, nadă_, 
   {{0x6da08fad,0x764c00b5,0x2ca4005c,0x00000000}},	//   рија, zucy, gynd_, --, 
   {{0xd0049bcb,0x3b6402e8,0x9e3400ec,0x9a7800db}},	//   _босқ, тъкв, _مورڙ, ейит_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa00002e3,0x9c7c0153,0x00000000,0x00000000}},	//   _ịchị, _lyči, --, --, 
   {{0x1ab40046,0x31340302,0x69c00175,0xaca0010e}},	//   _әбля, כנים_, _dmne, _diỳm, 
   {{0x69c0fb11,0x98a40184,0xb218032e,0x7bc17f59}},	//   _emne, _ҡуйҙ, _bræl, _umou, 
   {{0xb86432de,0x00000000,0x00000000,0x00000000}},	//   راگو, --, --, --, 
   {{0x98ac054e,0xb4b00124,0xd99800ec,0x1958004e}},	//   gadă_, аигә, _سنبت_, _чакы_, 
   {{0x24597f5a,0xdce8012c,0xe98402dd,0x659402dd}},	//   карь_, _radě, _جانۋ, шару, 
   {{0xb2180579,0x17549392,0x80a400cc,0x00000000}},	//   _fræl, _свия, _গেভ্, --, 
   {{0x65b002b5,0x848002d3,0x69c00042,0xdce80118}},	// [280d0] _wäha, _ሓያልን_, _ymne, _padě, 
   {{0x65b154da,0x557402e8,0x30a400d8,0x98ac054e}},	//   _hähn, _сгот, крев, cadă_, 
   {{0xe0d17f5b,0xf65c0393,0xb21801bf,0x00000000}},	//   يزم_, ltæ_, _træo, --, 
   {{0xceb84cdd,0x4814010f,0x9c7c00c0,0x21f400c7}},	//   нәз_, אַסן_, _gyči, räha_, 
   {{0xb21800b5,0xa3e0033f,0xf65c0393,0x65b17f5c}},	//   _kræm, दकर_, ntæ_, _mähn, 
   {{0x91d003d4,0xb5f8b941,0x5fc419cc,0x00000000}},	//   _তীৰ্, ltáb, लोबल, --, 
   {{0x4c69137a,0xa158117e,0x09e401d5,0x00000000}},	//   хийн_, _шару_, ғонн, --, 
   {{0xb5f8057f,0x65b002f6,0x2ca57f5d,0x99840024}},	//   ntáb, _nähn, rynd_, ksmų_, 
   {{0x50440220,0xb5f80077,0xba202309,0x07a401b9}},	//   _шеңб, itáb, бдык, ҳанн, 
   {{0x3ed8008f,0xdef847c5,0x9d5400db,0x2afc00cd}},	//   _אַבא, _рыс_, _ەنەت, शेषु_, 
   {{0x07a57f5e,0xcb542fee,0x98ac0311,0xc7a4001b}},	//   ганн, _مناظ, vadă_, гинк, 
   {{0xb2189907,0x00000000,0x00000000,0x00000000}},	//   _præl, --, --, --, 
   {{0x69c17f5f,0xb21801bf,0x9c7c0064,0x99840064}},	//   _tmne, _bræm, _ryči, gsmų_, 
   {{0x69c072e9,0x6ab80112,0x98c401b9,0x00000000}},	//   _umne, mzuf, اغین, --, 
   {{0x98ac0276,0x443d7f60,0xb218032e,0x65b0002f}},	//   radă_, ét_, _dræm, _fähn, 
   {{0x65b00295,0xb2197f61,0xc98400d1,0xa6540133}},	//   _gähn, _træl, _шуҗи, _پێست, 
   {{0x6ab80730,0x9c7d7f62,0x98ac0311,0xf65c0381}},	// [280e0] nzuf, _vyči, padă_, ctæ_, 
   {{0x201c0120,0x65b003fa,0x7c3d7f63,0x6b997f64}},	//   ívio_, _zähn, špri, hjug, 
   {{0x9c7ca017,0x6ab80e78,0x68100356,0xecc00d2e}},	//   _tyči, hzuf, _bădi, _वेलफ, 
   {{0x65b002b1,0xb5f80077,0x6280022a,0x0164004e}},	//   _käho, ctáb, _šmou, _өкмо, 
   {{0xb93801e1,0x3f80032e,0x00000000,0x00000000}},	//   _kẹtà, _ókum_, --, --, 
   {{0x64580793,0x6e900276,0x1dc40073,0x6e85160f}},	//   _ävis, сишу, _वगळत, انوف_, 
   {{0xfca800aa,0xb5f85f5b,0x64584606,0xb33806be}},	//   عاتو_, ltác, _åvid, _hoça, 
   {{0xb3388eac,0x9f4c0724,0x6b980c6a,0x6ab80112}},	//   _koça, çlär_, gjug, fzuf, 
   {{0x628403bd,0xb5f97f65,0x4ed400a7,0x65b00c48}},	//   nvio, ntác, _кюфт, _rähn, 
   {{0xb3397f66,0xdee4992f,0x6b997f67,0x38880092}},	//   _moça, _боғи, ajug, ንግሥቱ_, 
   {{0xbca57f68,0x6b997f69,0x98ac38a5,0x614800e2}},	//   _حماي, bjug, kadą_, mīlē, 
   {{0x7a845220,0x98ac012d,0xb5f80419,0x00000000}},	//   _مشتم, jadą_, ktác, --, 
   {{0x19957f6a,0x78b800dd,0xb218037e,0xf77d7f6b}},	//   _валя, sztv, _præm, goça_, 
   {{0xf65c0393,0xb218032e,0x65b0002f,0x628400c0}},	//   rtæ_, _fræj, _wähn, dvio, 
   {{0xd3c40588,0xb21801a8,0xf65c0393,0x65b00254}},	//   араҿ, _græj, stæ_, _tähn, 
   {{0xb3381762,0xf65c0393,0xb4b000c7,0x00000000}},	//   _boça, ptæ_, аиҳә, --, 
   {{0xb3380798,0xb218005c,0xdb00e391,0xdb080139}},	// [280f0] _coça, _træm, mhmó, _çlär, 
   {{0xb3380ba1,0xb5f8ba0f,0x61fc0306,0x68100356}},	//   _doça, stáb, _chrl, _sădi, 
   {{0xb5f84da9,0x8e380214,0x62857f6c,0xb2181d12}},	//   ptáb, چستر_, avio, _kræk, 
   {{0x62840354,0x61fc0730,0xa8540375,0xb3380205}},	//   bvio, _ehrl, ריאה_, _foça, 
   {{0xb5f97f6d,0x6b9801fa,0xb338010e,0xdb003b52}},	//   ctác, vjug, _goça, nkmä, 
   {{0x71700131,0xef94804b,0x777c0327,0x0c240064}},	//   _دۇئا, _өйгә_, _laqx, амкн, 
   {{0x7d7400f1,0x216401f4,0x00000000,0x00000000}},	//   شمير_, _утяг, --, --, 
   {{0xdd940184,0x6cc001e0,0x4a45277b,0xcba57f6e}},	//   _һауы, ийҙа, анив, раий, 
   {{0x65b000a2,0xfc5002d3,0xdb000112,0xdfd802e8}},	//   _bähl, _ዘይፍለ, chmü, _сър_, 
   {{0x89a8165d,0xa2d8412f,0xb218003a,0x6ab80e78}},	//   тков_, _यशस्, _præj, rzuf, 
   {{0x6ab97f6f,0xb2182f48,0x8afc012c,0x2d540022}},	//   szuf, _bræk, teřs, _аиҕь_, 
   {{0x62840024,0x00000000,0x00000000,0x00000000}},	//   yvio, --, --, --, 
   {{0x777c031c,0x98ac0153,0x00000000,0x00000000}},	//   _daqx, vadą_, --, --, 
   {{0xb3380120,0x0900009e,0x44e40014,0x00000000}},	//   _roça, লুগু_, ٔسرٲ, --, 
   {{0xb2185266,0x33380327,0xdce80139,0x00000000}},	//   _fræk, faqx_, _yodı, --, 
   {{0x03240aa5,0xc324d687,0x65b00730,0xb2197f70}},	//   рдан, рмак, _zähl, _græk, 
   {{0x61fc00a3,0xdb003468,0x73301b56,0x62840129}},	// [28100] _phrl, ckmä, زىلا, uvio, 
   {{0x62857f71,0xc0442f5e,0xb5f803da,0x65b00821}},	//   rvio, لخصو, rtác, _kähm, 
   {{0x62840798,0x4f4002d3,0x65b00108,0x40940124}},	//   svio, _ከምዝር, _jähm, шрат, 
   {{0xb5f843ed,0xdb000158,0x62e80014,0x65b00139}},	//   ptác, lkmå, _مِجہ_, _mähm, 
   {{0xfe7047e5,0x65b0260b,0xdce80139,0xee74007b}},	//   تدا_, _lähm, _rodı, لصوت_, 
   {{0x22417f72,0x247802e2,0xdb000165,0xcee80633}},	//   msik_, _kōm_, nkmå, درمن_, 
   {{0x22405f99,0x4f0804da,0x65b00ade,0xd8380100}},	//   lsik_, نتۇپ_, _nähm, nyčt_, 
   {{0xafe0d888,0x20194aa3,0x213801f5,0x5a343252}},	//   _досл, _iuri_, _herh_, бнит, 
   {{0x20197f73,0x22417f74,0xdb0008fb,0x0e680592}},	//   _huri_, nsik_, kkmå, _مصلي_, 
   {{0x20197f75,0x65b000a2,0x999806ed,0x39a4ec5a}},	//   _kuri_, _bähm, укот_, ршив, 
   {{0x20197f76,0x21380165,0xb218005c,0x00000000}},	//   _juri_, _merh_, _præk, --, 
   {{0x20197f77,0x22417f78,0x65b00639,0x213805c7}},	//   _muri_, ksik_, _wähl, _lerh_, 
   {{0x20197f79,0x22400007,0x00000000,0x00000000}},	//   _luri_, jsik_, --, --, 
   {{0x79513df8,0x9c7c007f,0x2018bdc6,0x3a24010a}},	//   _بێدا, _fyčt, _ouri_, _itop_, 
   {{0xb218019b,0x20197f7a,0x7e60023a,0x2240dc67}},	//   _træk, _nuri_, htop, esik_, 
   {{0xf77c06ed,0x2240011f,0x21380142,0xb21802d2}},	//   moço_, fsik_, _aerh_, _hræi, 
   {{0x7e601505,0x20197f7b,0x22401187,0x65b0010b}},	// [28110] jtop, _auri_, gsik_, _zähm, 
   {{0x20197f7c,0x7e602315,0x24780100,0x3a240175}},	//   _buri_, dtop, _fōm_, _mtop_, 
   {{0x20197f7d,0x22417f7e,0xd6d80154,0x7c297f7f}},	//   _curi_, asik_, _সরিয, jpfr, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x20197f80,0x7e617f81,0x2138025c,0x224001ed}},	//   _euri_, gtop, _ferh_, csik_, 
   {{0x20197f82,0x623401b9,0x2b800208,0xdea401b9}},	//   _furi_, _феру, _ực_, غیلی, 
   {{0x3a253406,0x7e617f83,0x20197f84,0xcc8803e6}},	//   _atop_, atop, _guri_, انبه_, 
   {{0x7e611ded,0x7eb40032,0x65b001f4,0x00000000}},	//   btop, ргәс_, _rähm, --, 
   {{0x20197f85,0xb21803b2,0x00000000,0x00000000}},	//   _zuri_, _bræi, --, --, 
   {{0x499412e7,0x65b0010e,0x91a800fe,0x98ac0210}},	//   сшит, _pähm, ছোৰ্, ladę_, 
   {{0x3a2404ba,0x2018005a,0x00000000,0x00000000}},	//   _etop_, _xuri_, --, --, 
   {{0x22417f86,0xf3fc001e,0x31ac05d1,0x3a240175}},	//   ysik_, _nhã_, _hızı_, _ftop_, 
   {{0x31ac2706,0x44280589,0x68100276,0x3a257f87}},	//   _kızı_, wpb_, _rădu, _gtop_, 
   {{0xf77c0120,0xc4c4007b,0x65b000a2,0x22400205}},	//   boço_, متزو, _tähm, vsik_, 
   {{0x68100276,0x7e617f88,0x07a57f89,0x31ac0205}},	//   _pădu, ztop, _гайн, _mızı_, 
   {{0x20182ee9,0xf3fc0004,0xb338067c,0x65b00641}},	//   _ruri_, _chã_, _doço, _kähk, 
   {{0x44287dcd,0x67240248,0x6810054e,0x7e6001f5}},	// [28120] spb_, _ifij, _vădu, xtop, 
   {{0x20197f8a,0x22417f8b,0x40957f8c,0x65b016e1}},	//   _puri_, rsik_, йрет, _mähk, 
   {{0x22417f8d,0x7e617f8e,0x20184c27,0x213875c1}},	//   ssik_, wtop, _quri_, _verh_, 
   {{0xb5f809c2,0x7e617f8f,0xdef80184,0xa3bc3d1d}},	//   ntán, ttop, һыҙ_, _अति_, 
   {{0x20197f90,0xb5f80077,0xdd1c00bc,0xf1bc01e1}},	//   _wuri_, itán, _záři, _itán_, 
   {{0x20197f91,0x7e6000c8,0x3a240175,0xbec00171}},	//   _turi_, rtop, _rtop_, _šīsd, 
   {{0x7e617f92,0xbae405f5,0x20182bdf,0x5c740212}},	//   stop, өций, _uuri_, ілит, 
   {{0x3a24b80e,0x7e617f93,0x5ac801e0,0x6ad02802}},	//   _ptop_, ptop, ғлүм_, दपूर, 
   {{0x2a6d7f94,0x9c7c007f,0xb21801bf,0x65b00254}},	//   _cpgb_, _pyčs, _præi, _vähj, 
   {{0x67257f95,0x57e001f9,0x00000000,0x00000000}},	//   _afij, नव्ह, --, --, 
   {{0x17997f96,0x65b00254,0xaab4036b,0x00000000}},	//   авны_, _tähj, لدیر_, --, 
   {{0xbb140046,0xf77c0798,0xdd7400e5,0x00000000}},	//   ﻳﺪﻯ_, roço_, _دھچک, --, 
   {{0xf3fc0ecf,0xb2183bb4,0x60c003b9,0x00000000}},	//   _rhã_, _træi, _əmma, --, 
   {{0xb218019b,0xf1bc0077,0x672406d9,0xb3380120}},	//   _kræv, _atán_, _efij, _poço, 
   {{0x64980084,0x77900133,0xd7f8054e,0x00000000}},	//   _ḽif, _فیدا, ltăm_, --, 
   {{0xb5f82b76,0xb338010e,0x795003e6,0x00000000}},	//   ctán, _goçl, _بێگا, --, 
   {{0xd7f80311,0xa29400d4,0x00000000,0x00000000}},	// [28130] ntăm_, паті, --, --, 
   {{0xf1bc0ca8,0x00000000,0x00000000,0x00000000}},	//   _etán_, --, --, --, 
   {{0xf3fc0589,0x00000000,0x00000000,0x00000000}},	//   _thã_, --, --, --, 
   {{0x8eb40f1b,0x09b0009e,0xb3380205,0x31ac03e0}},	//   يماش, টোপা, _koçm, _sızı_, 
   {{0xa77c00c8,0x6e657f97,0x98ace1eb,0x00000000}},	//   טראפ, стеж, radę_, --, 
   {{0x649806d6,0x31ac467d,0xb218022c,0xb338036e}},	//   _ḓif, _qızı_, _bræv, _moçm, 
   {{0x65b00664,0x21b40166,0xb5f84e00,0x00000000}},	//   _sähk, _эйря, ytán, --, 
   {{0x0a4807d6,0x0ba80220,0x65b033eb,0xa0240112}},	//   азий_, شاعى_, _pähk, stöß, 
   {{0xb218037e,0x5f94010b,0x499800d4,0x00000000}},	//   _usæd, _эитт, атня_, --, 
   {{0x3eb13721,0x2fcd7f98,0xbd840014,0x65b00037}},	//   øyte_, ligg_, _وۆنن_, _vähk, 
   {{0xb21801bf,0x248c0092,0x7bdc0129,0x98ac0118}},	//   _græv, _ማካሄድ_, épuc, madě_, 
   {{0x4e1c1e61,0x98ac00bc,0x65b00108,0xb33803b9}},	//   _पढाई_, ladě_, _tähk, _qoçl, 
   {{0x69cd631c,0x23bc0ca8,0xd7f8054e,0x835401d9}},	//   éces, _jíje_, ctăm_, ۪پرا, 
   {{0xb5f97f99,0xdbd000a2,0x65b00254,0xf1bc01e7}},	//   stán, _eýän, _kähi, _stán_, 
   {{0x833858d5,0x34a4013e,0xb9780375,0x4b6c0b82}},	//   ичат_, овро_, _כנסי, _ቶሮንቶ_, 
   {{0x65b000ee,0x290001d9,0x0674014b,0x98ac01ef}},	//   _mähi, _وژھِ, _дуоя, hadě_, 
   {{0x65b0102e,0xb33800a2,0xb5f801e7,0x07342d40}},	// [28140] _lähi, _goçm, otál, _ﺗﻪﯓ_, 
   {{0xb5f819fd,0x00000000,0x00000000,0x00000000}},	//   ntál, --, --, --, 
   {{0x65b00209,0xdce8031c,0x43681180,0xf65c03cd}},	//   _nähi, _indħ, _канн_, tzæg_, 
   {{0xf1bc066d,0xb5f800c6,0xeaa534f5,0xb4f8011a}},	//   _után_, htál, _قع_, _כפיי, 
   {{0xef141cd1,0xdd9556aa,0x91b803d4,0x7de40b24}},	//   әмә_, залы, _আদৰ্, يستم, 
   {{0x65b00139,0xb2197f9a,0x6e9006c2,0x00000000}},	//   _bähi, _præv, بلها, --, 
   {{0x64980943,0xdce80171,0x70540024,0x116800e5}},	//   _ḓig, _radē, _маёр_, _دلّی_, 
   {{0x5a3413d6,0x19580588,0x00000000,0x00000000}},	//   пнит, әаны_, --, --, 
   {{0x290000ee,0x21f40037,0x00000000,0x00000000}},	//   ýjan_, tähh_, --, --, 
   {{0x65b13aa0,0xd7f80311,0xb2183774,0x3f84002d}},	//   _fähi, rtăm_, _træv, ldou_, 
   {{0xd7f8054e,0xb218032e,0x0d9800fb,0x00000000}},	//   stăm_, _hræt, _утты_, --, 
   {{0xec117f9b,0xd7f80276,0xdb240793,0xdb0003cd}},	//   _قولد, ptăm_, öpäd, kkmø, 
   {{0xdce800ef,0x00000000,0x00000000,0x00000000}},	//   _tadē, --, --, --, 
   {{0x7ae0014b,0x00000000,0x00000000,0x00000000}},	//   _ixot, --, --, --, 
   {{0x3f840369,0x998400db,0x00000000,0x00000000}},	//   kdou_, _ولچو, --, --, 
   {{0x3f84012c,0x8a400244,0x00000000,0x00000000}},	//   jdou_, _تێین, --, --, 
   {{0x64581445,0x3f840129,0x91b80166,0xb5f800e5}},	// [28150] _åvin, ddou_, бгат_, ltám, 
   {{0x3f8400d0,0x23bc01e1,0x00000000,0x00000000}},	//   edou_, _ríje_, --, --, 
   {{0xb5f867ac,0xdb00002f,0x00000000,0x00000000}},	//   ntám, chmö, --, --, 
   {{0x649806d6,0xb5f800dd,0xb2189574,0x65b01e7f}},	//   _ḓid, ztál, _bræt, _rähi, 
   {{0x7ae0009a,0x3cfc0213,0x2fcc0072,0x65b001f4}},	//   _nxot, _aztv_, rigg_, _sähi, 
   {{0xb21808a5,0x65b0010b,0x00000000,0x00000000}},	//   _dræt, _pähi, --, --, 
   {{0x7ae0014b,0x6ad07e92,0x98ac0118,0x65b00139}},	//   _axot, दप्र, radě_, _qähi, 
   {{0x65b0db6d,0xb218022c,0x21f40037,0x0b457f9c}},	//   _vähi, _fræt, vähi_, чнин, 
   {{0x3cfc0204,0x65b17f9d,0x2fdc0010,0x49c839b8}},	//   _eztv_, _gähw, _ijug_, йлин_, 
   {{0x499809a5,0x5d540228,0x65b0007d,0x08c4020a}},	//   стия_, _окут, _tähi, збон, 
   {{0xb5f81dee,0x2d8400d2,0x08d4e244,0x00000000}},	//   rtál, mdne_, яция, --, 
   {{0xb5f97f9e,0x7f90022e,0x00000000,0x00000000}},	//   stál, nаqа, --, --, 
   {{0xbb140451,0xfbd000d9,0x2d840254,0xcb0801c8}},	//   _عيوض_, _אתא_, odne_, _ايشن_, 
   {{0x2d84353e,0x3f8402fb,0x7ae4000f,0x65b00254}},	//   ndne_, zdou_, ûkte, _lähv, 
   {{0x3f85791b,0xb5f804d4,0x75d07286,0xb3380205}},	//   ydou_, ctám, ريفا, _koçh, 
   {{0x4224326d,0x07a40139,0x65b00254,0xb5f800e5}},	//   здав, _хаин, _nähv, ntáj, 
   {{0x27e17f9f,0x3f8402fb,0x7d000248,0xc1487676}},	// [28160] _ijin_, vdou_, _kírí, йзаж_, 
   {{0x2fdc2cc3,0x25740150,0xccc80150,0x00000000}},	//   _ajug_, _تۇسس, _ﺭﺠﺎل_, --, 
   {{0x7f90022e,0x00000000,0x00000000,0x00000000}},	//   fаqа, --, --, --, 
   {{0xb2197fa0,0x3f840a3a,0xafe001d5,0xb5f800e5}},	//   _præt, udou_, нохл, jtáj, 
   {{0x3f8410d8,0x63a538fb,0x27e0009f,0x38c17fa1}},	//   rdou_, mjin, _mjin_, _kéré_, 
   {{0xb5f800c7,0x00000000,0x00000000,0x00000000}},	//   ytám, --, --, --, 
   {{0x81d406d6,0x38c00438,0xad200131,0xdd940032}},	//   _nḓil, _méré_, رىيى, заһы, 
   {{0xb2184e95,0x2d857fa2,0x27e002e3,0x7ae0022e}},	//   _græs, adne_, _njin_, _pxot, 
   {{0x63a402c4,0x7d000241,0xb21801a8,0xaa600024}},	//   ijin, _bírí, _hrær, нтэк, 
   {{0x27e00b45,0x44380589,0x63a408e5,0x69cc06af}},	//   _ajin_, _owp_, hjin, écep, 
   {{0x7d00007b,0xf77c0200,0x00000000,0x00000000}},	//   _dírí, loçi_, --, --, 
   {{0x63a57fa3,0x7ae001c6,0x38c006af,0x8b6400d1}},	//   jjin, _txot, _aéré_, _يانم, 
   {{0x38c00c6a,0x63a40363,0x7ae00117,0x2c0800dd}},	//   _béré_, djin, _uxot, _اعلی_, 
   {{0x38c0003e,0x7d0001e1,0x27e00200,0xf1bc0118}},	//   _céré_, _gírí, _ejin_, _ptám_, 
   {{0x7f4003b4,0x20057fa4,0x645803cd,0x65b00254}},	//   kaoq, _ohmi_, _åvil, _nähu, 
   {{0x27e00385,0x63a4456c,0xa3bc687b,0x4438015d}},	//   _gjin_, gjin, _अतः_, _dwp_, 
   {{0x52142c1d,0xb5f831b7,0x00000000,0x00000000}},	// [28170] ддат, nták, --, --, 
   {{0x64981682,0x38c0004a,0x65b0000d,0x63040116}},	//   _ḓib, _géré_, _sähv, رولل, 
   {{0xb2197fa5,0x2d840427,0x8ed803d4,0x27e0010e}},	//   _præs, vdne_, _তৰংগ, _yjin_, 
   {{0x7d180ea0,0x8e74004e,0x00000000,0x00000000}},	//   _agts, дукч, --, --, 
   {{0x7c380327,0x38c000e8,0x20040205,0x7f9001a9}},	//   _awtr, _yéré_, _dhmi_, rаqа, 
   {{0x3eb02d8b,0x2d84000d,0x00000000,0x00000000}},	//   øyta_, udne_, --, --, 
   {{0x2d857fa6,0x7f400a73,0xb2184e95,0x69b802ab}},	//   rdne_, baoq, _træs, एससी, 
   {{0x2fdd7fa7,0x395c00da,0x7d0021f1,0xf77c06be}},	//   _ujug_, egts_, _sírí, boçi_, 
   {{0x7c397fa8,0x6f197fa9,0x3b800ede,0x23bc01e1}},	//   _ewtr, _iguc, тлыг, _jíja_, 
   {{0x6e38379d,0xb5f801ed,0x63a4045f,0x395c0267}},	//   _iwub, stáj, zjin, ggts_, 
   {{0x6d417faa,0x6f0001e1,0xb5f800e4,0x38c08e4a}},	//   mana, _fìbí, aták, _réré_, 
   {{0x65b005c3,0x6e380eb4,0x44380221,0x00000000}},	//   _läht, _kwub, _rwp_, --, 
   {{0x44390e72,0x63a57fab,0xea880691,0xb33800a2}},	//   _swp_, vjin, _دخان_, _goçi, 
   {{0x65b018db,0x273c07ae,0x6e380526,0x6d4027f8}},	//   _näht, ận_, _mwub, nana, 
   {{0x63a57fac,0x6d40d13b,0x04457fad,0x00000000}},	//   tjin, iana, ьевн, --, 
   {{0x6f197fae,0x63a57faf,0x27e00023,0x6e386f16}},	//   _nguc, ujin, _ujin_, _owub, 
   {{0x41a97fb0,0x63a57fb1,0x44380f64,0x38c17fb2}},	// [28180] ован_, rjin, _wwp_, _téré_, 
   {{0x6d417fb3,0x63a57fb4,0x6f1856ea,0x4439553c}},	//   jana, sjin, _aguc, _twp_, 
   {{0x6d417fb5,0x6e397fb6,0x840413d6,0xdedc0023}},	//   dana, _awub, _опож, ንውን_, 
   {{0x6e380230,0x63a40784,0x6d400363,0x42240395}},	//   _bwub, qjin, eana, _одмв, 
   {{0x6d417fb7,0x645d7fb8,0x72c000c0,0x5274010a}},	//   fana, luri, _абяз, _пуру, 
   {{0x657cfa18,0xdce800b8,0xb2183c02,0x645c0156}},	//   nerh, _abdā, _trær, ouri, 
   {{0x6e397fb9,0x657c02c1,0xdd8402dd,0xb33800fd}},	//   _ewub, ierh, дықп, _soçi, 
   {{0x657c127b,0x6d417fba,0xef0c00aa,0xab38001f}},	//   herh, aana, اڼې_, _በኢየሱ, 
   {{0x657d7fbb,0x00000000,0x00000000,0x00000000}},	//   kerh, --, --, --, 
   {{0x645d7fbc,0x6d417fbd,0x657d7fbe,0xed540798}},	//   kuri, cana, jerh, _ооу_, 
   {{0x6da00daf,0xbc641d83,0x31540375,0xb5f801d3}},	//   _шифа, _цвек, ויין_, sták, 
   {{0x645d7fbf,0x8e8000c7,0xb33800a2,0xf1bc013a}},	//   duri, _рҳәе, _toçi, _pták_, 
   {{0xe6657fc0,0xdce80953,0x657d7fc1,0x645c002e}},	//   ктро, _padė, ferh, euri, 
   {{0x645d7fc2,0xb5f8007b,0xf1bc0419,0x00000000}},	//   furi, otái, _vták_, --, 
   {{0xb5f80597,0x645c6bfc,0xa5f801ca,0xb3540133}},	//   ntái, guri, феру_, ویدا_, 
   {{0x6d417fc3,0xb5f800e4,0x00000000,0x00000000}},	//   zana, kuág, --, --, 
   {{0x657d7fc4,0x6280145e,0xb5f800c6,0x00000000}},	// [28190] berh, _âmol, htái, --, 
   {{0x6d417fc5,0x49040316,0x6e380230,0x6f180268}},	//   xana, हेको_, _rwub, _sguc, 
   {{0x645d7fc6,0x8f7401ec,0x00000000,0x00000000}},	//   curi, еулі, --, --, 
   {{0x6d417fc7,0x93c800dd,0x64a400f3,0x670c06e3}},	//   wana, _راجہ_, _раџа, सेवक_, 
   {{0x65b0246f,0x6d417fc7,0xbf700046,0xb5f800c7}},	//   _täht, tana, ықты, guág, 
   {{0x6d417fc8,0xdd9400f7,0x84140107,0x00000000}},	//   uana, качы, _омӯх, --, 
   {{0x65b0000d,0x69cc0129,0x2a7c00e8,0x00000000}},	//   _kähr, ècem, wwub_, --, 
   {{0x6d417fc9,0x65b00f2a,0x6e3801b2,0x6f197fca}},	//   sana, _jähr, _twub, _uguc, 
   {{0x6d417fcb,0x6e397fcc,0xeb94472b,0x657c6eb6}},	//   pana, _uwub, зиқ_, yerh, 
   {{0x6d417fcd,0x645d7fce,0x88c8068e,0xd6d803d4}},	//   qana, yuri, злов_, _সৰ্প, 
   {{0x657d7fcf,0x645c0d63,0x8c180154,0x00000000}},	//   verh, xuri, ণীজন_, --, 
   {{0x657d7fd0,0x645d7fd1,0x65b0c08d,0x6bd40014}},	//   werh, vuri, _nähr, _کوچس_, 
   {{0x657d15a6,0x80a404c5,0x645c06e4,0xbb506ea9}},	//   terh, _গেঞ্, wuri, _صنوب, 
   {{0x9aa57fd2,0x48e41d3e,0x657c9cfd,0x394c0332}},	//   _جمهو, _полв, uerh, _gdfs_, 
   {{0xa3bc2aa1,0x65b020a9,0x645c0037,0x00000000}},	//   असल_, _bähr, uuri, --, 
   {{0xb2197fd3,0x82a4c133,0xd018010e,0xb874011a}},	//   _præp, набж, _niń_, _נתפס_, 
   {{0x02055fa8,0x645d7fd4,0x23600219,0x42c97fd5}},	// [281a0] езан, suri, rgij_, чган_, 
   {{0x645d7fd6,0xc4841422,0x00000000,0x00000000}},	//   puri, _злок, --, --, 
   {{0x645d7fd7,0x65b00730,0x21f403fa,0xd5e8082e}},	//   quri, _fähr, fähr_, _تعين_, 
   {{0xfe451cc4,0xb3380ba1,0x65b00086,0xff0807d8}},	//   ендо, _boçu, _gähr, пеек_, 
   {{0xee3400ee,0xb3380139,0xaff4007b,0x5314014b}},	//   енч_, _poçv, رفها_, _афру, 
   {{0x6da0ed5a,0xb3380798,0x57ac1098,0x65b00a43}},	//   лича, _doçu, _चव्ह, _zähr, 
   {{0x2fc402b1,0xe0440124,0x6da0075e,0xc0e40395}},	//   ūnga_, _рҽеи, امىم, _човк, 
   {{0xb5f80597,0x787401b8,0xd01800a2,0x00000000}},	//   rtái, _lüvö, _giń_, --, 
   {{0xb5f80491,0x77bc0de2,0xa3e809bb,0xb3380432}},	//   stái, _nëxa, _बदन_, _goçu, 
   {{0xcd280451,0x602c03e0,0xc4b0012d,0xb5f8ea5b}},	//   _قسمن_, _eğme, ीनाओ, ptái, 
   {{0x88817fd8,0xdce800cd,0xb33803e0,0x00000000}},	//   لیون, _madī, _koçt, --, 
   {{0xb5f97fd9,0xab80e0a5,0xf8a001c0,0x00000000}},	//   ntáv, _бушк, вгүү, --, 
   {{0xb5f845c1,0x81e4009e,0x00000000,0x00000000}},	//   itáv, _পঠন_, --, --, 
   {{0xdce800dc,0x65b000ee,0x3d1c012d,0xe020012d}},	//   _nadī, _sähr, _पलों_, यदाद_, 
   {{0x432c0248,0x00000000,0x00000000,0x00000000}},	//   _ọpọ_, --, --, --, 
   {{0xdcf8009b,0x00000000,0x00000000,0x00000000}},	//   jevč, --, --, --, 
   {{0xd2517fda,0x7988009f,0xf77c03e0,0xe37404b3}},	// [281b0] شنا_, _kafw, meç_, ылты, 
   {{0x65b009a4,0x21f403fa,0xb5f800e4,0xf77c0bbc}},	//   _währ, währ_, etáv, leç_, 
   {{0xb5f800e4,0x65b02b95,0x00000000,0x00000000}},	//   guáe, _tähr, --, --, 
   {{0x79897fdb,0x1304004e,0xa83400df,0x00000000}},	//   _lafw, _үзүм, גראד_, --, 
   {{0xb33803b9,0x60c006be,0x00000000,0x00000000}},	//   _qoçu, _əmmi, --, --, 
   {{0xdce80029,0x79880067,0xb5f80124,0x00000000}},	//   _gadī, _nafw, atáv, --, 
   {{0x64980084,0xf77c36d9,0x00000000,0x00000000}},	//   _ḽin, keç_, --, --, 
   {{0xb5f800d8,0x1adc033f,0xad8400db,0x00000000}},	//   ctáv, मपंथ, باچۇ, --, 
   {{0x7988007f,0x8e1400c7,0xdce800cd,0x9bc400f7}},	//   _bafw, _адац, _yadī, دەنۉ, 
   {{0x79880368,0xf65c003a,0xadb400db,0x3eb00108}},	//   _cafw, duæ_, _سۇعا_, äyte_, 
   {{0xb90000d6,0x00000000,0x00000000,0x00000000}},	//   изьк, --, --, --, 
   {{0x290001e4,0xcb340395,0xf77c008e,0x00000000}},	//   ĥja_, _редъ, geç_, --, 
   {{0xb5f802d2,0x00000000,0x00000000,0x00000000}},	//   duáb, --, --, --, 
   {{0x6b897fdc,0x649806d6,0x798803cb,0x61c000dc}},	//   _hagg, _ḓin, _gafw, _एतेष, 
   {{0xb5f8035b,0xdce800da,0x6b897fdd,0x443c2508}},	//   ytáv, _radī, _kagg, èt_, 
   {{0x6b884867,0x77bc0de2,0xdce800ef,0x86c40472}},	//   _jagg, _tëxa, _sadī, _ليبن, 
   {{0x6b897fde,0x787401b8,0xb7d40769,0x00000000}},	// [281c0] _magg, _tüvö, _جويا_, --, 
   {{0x6b897fdf,0xb658008d,0x00d81375,0x00000000}},	//   _lagg, _קדיש, وبات_, --, 
   {{0xdce80029,0xb338d88f,0xdbd000a2,0x6b8802d0}},	//   _vadī, _poçt, _aýýn, _oagg, 
   {{0x70517fe0,0x6b897fe1,0x6cc0005e,0xb5f80118}},	//   شنها, _nagg, ﺭﺍﺌﻴ, utáv, 
   {{0xb5f80261,0x5d78084c,0xdce8002b,0x54c4014b}},	//   rtáv, ейля_, _tadī, _абӯб, 
   {{0xb5f9389a,0x133c0125,0x6b880014,0xdd9002da}},	//   stáv, _ኢኮኖሚ, _aagg, صوب_, 
   {{0x6b897fe2,0xb5f80316,0x8db40006,0x7c84fad8}},	//   _bagg, ptáv, ысці, туле, 
   {{0x79880597,0x6b883150,0x00000000,0x00000000}},	//   _safw, _cagg, --, --, 
   {{0x6b897fe3,0x75f8019f,0xf77c3535,0x798802bd}},	//   _dagg, sîzi, veç_, _pafw, 
   {{0x6b880072,0xb338010b,0xb5f85955,0x5f0401ec}},	//   _eagg, _inçe, ntát, _азға, 
   {{0x6b897fe4,0xeaac4c9a,0xf77c03e0,0x00000000}},	//   _fagg, معی_, teç_, --, 
   {{0x6b897fe5,0x79880161,0xb5f80419,0xdee40023}},	//   _gagg, _wafw, kuác, _ሜላን_, 
   {{0xf77d7fe6,0x19597fe7,0x79897fe8,0x7bc001f4}},	//   reç_, _залы_, _tafw, _ilou, 
   {{0xea740302,0x7bc0012c,0x6b8804ba,0x3ea400db}},	//   _סגור_, _hlou, _zagg, ixot_, 
   {{0xf804e77b,0xf3653154,0x7bc17fe9,0x6b897fea}},	//   _ичин, ктан, _klou, _yagg, 
   {{0x6b894e25,0x00000000,0x00000000,0x00000000}},	//   _xagg, --, --, --, 
   {{0xf8e0190c,0x56957c74,0xf65c0393,0xa3440006}},	// [281d0] _पशुप, _сапт, quæ_, рэсл, 
   {{0xceb800c7,0x00000000,0x00000000,0x00000000}},	//   ҭәа_, --, --, --, 
   {{0x7bc17feb,0xb3397fec,0x2fc400e4,0x00000000}},	//   _olou, _ançe, ëngo_, --, 
   {{0xf3c8036b,0xb5f800e4,0x00000000,0x00000000}},	//   _آبده_, atát, --, --, 
   {{0x6b897fed,0x00000000,0x00000000,0x00000000}},	//   _ragg, --, --, --, 
   {{0x7bc17fee,0x6b880afa,0xcee002dd,0xbea1042a}},	//   _alou, _sagg, _құлқ, сашк, 
   {{0x6b897695,0x7bc17fef,0xb3380209,0xb5f801ed}},	//   _pagg, _blou, _ençe, ltás, 
   {{0x6b88011f,0x7bc00d8b,0x200c004e,0x00000000}},	//   _qagg, _clou, _èdip_, --, 
   {{0x5ba5367e,0x7bc0038e,0x6b897ff0,0xb5f80d10}},	//   рлығ, _dlou, _vagg, ntás, 
   {{0x6b897ff1,0x7bc17ff2,0xf3f803d4,0x888401c6}},	//   _wagg, _elou, ্দিৰ_, глож, 
   {{0x7bc17ff3,0x6284012d,0x00000000,0x00000000}},	//   _flou, zwio, --, --, 
   {{0x7bc17ff4,0x649806d6,0x62840368,0x7aec0129}},	//   _glou, _ḓil, ywio, éité, 
   {{0x63a00137,0xb5f8804d,0x1bb81075,0xf3f800fe}},	//   _òmni, jtás, _جالع_, ্দাৰ_, 
   {{0x88c4454b,0x7bc02d2b,0x64a402dd,0x00000000}},	//   _متعل, _zlou, қаға, --, 
   {{0x41b4005e,0x43744294,0x69c000fd,0xa86001e0}},	//   қсат, луат, _ilne, _тейҙ, 
   {{0xb5f801f1,0x78f8008f,0x7c2c01d3,0x6284012d}},	//   tuác, _אפצו, _ébre, twio, 
   {{0xdee4069c,0x7bdc0129,0x957801c6,0x00000000}},	// [281e0] ዝኾነ_, épui, хөөс_, --, 
   {{0x81457b47,0xb1417ff5,0x62841430,0x4584447e}},	//   انان, йнул, rwio, _сгов, 
   {{0xb5f97ff6,0x40940387,0x69c001ab,0x00000000}},	//   rtát, ырат, _mlne, --, 
   {{0x03a45267,0xf1bd7ff7,0xb5f97ff8,0xe278010b}},	//   _симо, _stát_, stát, _ишгә_, 
   {{0xdcf8198e,0x1db800dc,0xf1bc0118,0xb5f800e5}},	//   devā, _अवदत, _ptát_, mtár, 
   {{0x7bc00316,0xdd942f09,0xdee402d3,0x645d7ff9}},	//   _slou, ракы, ዝኾኑ_, orri, 
   {{0x7bc17ffa,0x645c01ee,0x6da0147e,0x454c02d3}},	//   _plou, nrri, сија, _ንዝነበ, 
   {{0xb5f97ffb,0xada00184,0x645d7ffc,0x69c09b7b}},	//   ntár, _һаул, irri, _alne, 
   {{0x7dc40008,0x2904022e,0xdef00150,0x645d7ffd}},	//   _aðse, _azna_, _بۋش_, hrri, 
   {{0xf9686f34,0xb5f80022,0x98740408,0x645c0200}},	//   хрий_, kuáa, алоц, krri, 
   {{0x7e617ffe,0xb5f801d3,0x7bc000bc,0xbb541867}},	//   luop, ktár, _tlou, _منضب, 
   {{0x7bc17fff,0x957c001f,0x69c03add,0x645c0200}},	//   _ulou, _ሕዝቡን_, _elne, drri, 
   {{0x649806d6,0x69c002c4,0x645d8000,0x3b0407d6}},	//   _ḓim, _flne, erri, _uzoq_, 
   {{0xb5f98001,0xf9882756,0xf484022e,0x00000000}},	//   etár, _سخته_, лубн, --, 
   {{0x2604025a,0x7e600108,0xb5f808a5,0xa964009b}},	//   pöon_, huop, ftár, _сија_, 
   {{0x7e618002,0x53347401,0x3cfc0208,0xdee40023}},	//   kuop, реат, _mytv_, ዝኾና_, 
   {{0x645d8003,0x22581b9f,0x7e60023a,0x00000000}},	// [281f0] arri, литы_, juop, --, 
   {{0xb5f801ed,0x764c01e3,0x00000000,0x00000000}},	//   rtás, mscy, --, --, 
   {{0xb5f830df,0xdb0001e3,0xf1bc0162,0x7bc4031c}},	//   tráf, ckmö, _stás_, _ċkun, 
   {{0xb5f98004,0x7bc4094a,0x09e18005,0x0f340133}},	//   ctár, _ŋkun, _पद्य, شکرد, 
   {{0x764d382e,0x8d74007b,0x78b801f4,0x42a40117}},	//   nscy, لاثا, hytv, _курғ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x645808fb,0xdce800b8,0xf41c0139,0xb5f8da0d}},	//   _åvit, _dadį, _kiä_, mrád, 
   {{0x69c001f1,0xd838007f,0x78b802d0,0x98ac0064}},	//   _slne, dpč_, dytv, ladė_, 
   {{0xf41c0004,0x69c001f1,0x3a24004d,0x37c80183}},	//   _miä_, _plne, _cuop_, াচাৰ, 
   {{0xb5f919ac,0xf41c0139,0x645806ea,0x98bc002b}},	//   ztár, _liä_, _ævig, _sevā_, 
   {{0x69c00419,0xb5f8ea5b,0x00000000,0x00000000}},	//   _vlne, ytár, --, --, 
   {{0xb5f98006,0x86c401c8,0x9be40064,0x00000000}},	//   hrád, ليجن, _лічк, --, 
   {{0xb5f98007,0xf484136e,0xdce80055,0xbb3800df}},	//   vtár, یافی, _yadį, _סעסי, 
   {{0x645d8008,0x6fd40521,0x6ab80337,0x69c082ff}},	//   trri, ụcha, myuf, _ulne, 
   {{0x645d8009,0x0445800a,0xb5f81a62,0xc8a80037}},	//   urri, ребн, ttár, _छपिट, 
   {{0xdb003b52,0xdcf80356,0xb5f800c7,0x00000000}},	//   rkmö, levă, yrág, --, 
   {{0x67240117,0x7330185e,0xb5f90c98,0xf41c0139}},	// [28200] _igij, تىقا, rtár, _diä_, 
   {{0xb5f8429f,0x4095800b,0x35a0030d,0x00000000}},	//   stár, ирет, _даьг, --, 
   {{0xb5f83b87,0x8504297d,0xf558011a,0x00000000}},	//   ptár, _خودن, _בדימ, --, 
   {{0x64981682,0x2e2800b5,0x6ab81418,0xf41c0139}},	//   _ḽik, _bøf_, kyuf, _giä_, 
   {{0x6ab800b5,0x6fd400ab,0xd36c00db,0xcc6400d1}},	//   jyuf, _मगरू, _سۇل_, ەنىۋ, 
   {{0x3241800c,0x645808fb,0xb5f81ada,0x74880131}},	//   _ферг, _åvis, rrág, _ﺗﯧﭙﯩ, 
   {{0x67240117,0x7e9401ed,0x2e28072b,0xa2c42cc8}},	//   _ogij, انڈر_, _eøf_, _тәңк, 
   {{0x6725800d,0xf1bd03e2,0x78b953a1,0x764c0210}},	//   _ngij, _juán_, vytv, yscy, 
   {{0x79a5800e,0x6bd015bf,0x00000000,0x00000000}},	//   арне, تتور, --, --, 
   {{0x6725800f,0xdb0c0165,0x764c6130,0x00000000}},	//   _agij, _ákíe, vscy, --, 
   {{0x649806d6,0xf77d8010,0x58d800d6,0x3b840261}},	//   _ḓik, ença_, удня_, _влег, 
   {{0xb3398011,0xb5f8dc99,0x764c0142,0x8ac4035b}},	//   _onça, zrád, tscy, рқәа_, 
   {{0x19958012,0xdce8013d,0x3d1002a0,0xd838033b}},	//   _галя, _indı, धेरे_, spč_, 
   {{0x672484a2,0xe5c4023a,0xf41c01f4,0x00000000}},	//   _egij, оссо, _siä_, --, 
   {{0xf77d4e2c,0xd7f80356,0x45180154,0x00000000}},	//   ança_, luăm_, _ত্বক_, --, 
   {{0xf1bc0407,0xbb140131,0x3cdc00c5,0x88500092}},	//   _cuán_, _ﻳﻮﻕ_, _कइने_, _መሰባሰ, 
   {{0x649806d6,0x241811db,0xf1bc01e7,0xb4000137}},	// [28210] _ḽih, роты_, _duán_, йүүд, 
   {{0xf41c0c67,0xe1f04caa,0x8850001f,0x00000000}},	//   _wiä_, وسل_, _መሰብሰ, --, 
   {{0x26f88341,0x6b24025c,0x30a4013e,0xf4840354}},	//   _مریخ_, _ལྔའོ_, шрав, _тупн, 
   {{0xb21800b5,0x8d7403e6,0xf1bc00d7,0xb5f803b2}},	//   _spæd, ڵاتا, _etáp_, srád, 
   {{0x8db402d5,0xb5f802fb,0x6458003b,0xf65c0174}},	//   йскі, prád, _åvir, nræ_, 
   {{0xdce80c02,0xdef80953,0xa16401af,0x00000000}},	//   _andı, шых_, _мњск, --, 
   {{0x6ce40220,0xef6400a7,0x0c7804b4,0x00000000}},	//   шіде, _възо, услы_, --, 
   {{0x64981682,0x2e2801bf,0x06cc0154,0xb5f800d7}},	//   _ḓih, _tøf_, রপতি, ztáp, 
   {{0xb5f800c7,0x9e3403c5,0x00000000,0x00000000}},	//   ytáp, _метч, --, --, 
   {{0xf8ac9c96,0x89a98013,0xb218005c,0x99f400ec}},	//   ککه_, уков_, _upæd, يقيڪ, 
   {{0xa3e852f2,0xb5f98014,0xdbd00174,0x3cdc0037}},	//   _बदल_, tuán, _týðn, _कइये_, 
   {{0x7c2c06af,0x9cc80032,0x7bdc0129,0x6fc4134e}},	//   _ébra, _тыуа_, éput, लसिं, 
   {{0xb5f80306,0xf1bc0332,0xdce801ef,0x00000000}},	//   ruán, _ruán_, _obdě, --, 
   {{0x3ed8008f,0xd9b000d1,0x00000000,0x00000000}},	//   אַלא, _يەيد, --, --, 
   {{0x06840131,0x88d40154,0xb5f98015,0x03a40114}},	//   ﻪﻧﻠﯩ, _সুরক, puán, биво, 
   {{0xf1bc0016,0x6724b579,0xf65c0393,0xc324bd80}},	//   _quán_, _ugij, bræ_, смак, 
   {{0xc1e805f5,0xa1a40184,0x7330581f,0xf65c0393}},	// [28220] гдаж_, ҙыҡһ, سىلا, cræ_, 
   {{0xb5f98016,0xc92402f5,0xc0441291,0x00000000}},	//   nuál, _মজুত_, مخصو, --, 
   {{0xb5f836e2,0x4ad80ce0,0x00000000,0x00000000}},	//   bráb, _बेसव, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x44200115,0x319c005f,0x4f081e87,0x09b80490}},	//   _iik_, _bāzē_, ۇتۇپ_, ेसाठ, 
   {{0x44218017,0x3ea401d5,0xbea401ec,0x00000000}},	//   _hik_, _қизг, _қазк, --, 
   {{0xb5f80232,0x44218018,0x00000000,0x00000000}},	//   duál, _kik_, --, --, 
   {{0x5a347411,0x0c94581f,0x44218019,0xd9c001ad}},	//   онит, زدىگ, _jik_, एस्ट, 
   {{0x4421801a,0x64980084,0x3f840587,0x88d400cc}},	//   _mik_, _ḓii, meou_, _সুলক, 
   {{0x3f85801b,0xfce4c2f3,0x985400d4,0x79a4011c}},	//   leou_, _лозо, окої, срие, 
   {{0x44201368,0xf4c0015b,0x6bd00131,0x7bdc06af}},	//   _oik_, _ঈশ্ব, تتۈر, épus, 
   {{0x4421801c,0xf65c4e95,0xb5f801d3,0x00000000}},	//   _nik_, træ_, krác, --, 
   {{0x7c200194,0x3e700548,0xdb10002f,0x00000000}},	//   _iior, nât_, ßfän, --, 
   {{0xf1bd801d,0x4421801e,0x7c21801f,0xf65c0381}},	//   _cuál_, _aik_, _hior, rræ_, 
   {{0x44200598,0x7c2004fe,0xa99056e8,0x00000000}},	//   _bik_, _kior, _رشوت, --, 
   {{0x44218020,0x64980943,0x3e700109,0x7c20062c}},	//   _cik_, _ḽiw, kât_, _jior, 
   {{0x44218021,0x7c218022,0x3f840587,0x1db802ab}},	// [28230] _dik_, _mior, deou_, _अवंत, 
   {{0x44200579,0x7c2002a4,0x00000000,0x00000000}},	//   _eik_, _lior, --, --, 
   {{0x4420105c,0x847002d3,0x98680023,0x746801f0}},	//   _fik_, ብባርን_, _ተሰሪሑ_, _ёров_, 
   {{0x4420019b,0x7c218023,0xb5f83b0f,0x3f8400d8}},	//   _gik_, _nior, zuál, geou_, 
   {{0x3e700129,0xb5f80022,0x00000000,0x00000000}},	//   gât_, crác, --, --, 
   {{0xc0b80201,0x44218024,0xb5f804bf,0x7c20fadc}},	//   ዲሁም_, _zik_, xuál, _aior, 
   {{0x44200ac5,0x7c218025,0x4c840212,0xa9c80150}},	//   _yik_, _bior, ілив, _ﯗﺭﯨﺴ, 
   {{0x7c218026,0x44218027,0x3f8400d8,0xbb1400d1}},	//   _cior, _xik_, ceou_, _ﻳﻮﻝ_, 
   {{0x7c218028,0xb5f95eef,0x3e7000a8,0x49c98029}},	//   _dior, tuál, cât_, илин_, 
   {{0x80bc03f4,0x00000000,0x00000000,0x00000000}},	//   ্পর্, --, --, --, 
   {{0x2d85802a,0x7c213506,0x08d5802b,0x4c9448e5}},	//   mene_, _fior, юция, _фиес, 
   {{0x7c20156b,0x2d85802c,0x00000000,0x00000000}},	//   _gior, lene_, --, --, 
   {{0x2d840660,0x26c5802d,0xca3802dd,0x3ff8010f}},	//   oene_, ámo_, _ﺒﺩﺃ_, שפרע, 
   {{0x4421802e,0x2d85802f,0xf3fc0124,0x7c21655f}},	//   _sik_, nene_, _akã_, _zior, 
   {{0x64981682,0x2d858030,0x26c40024,0x00000000}},	//   _ḽiv, iene_, šmo_, --, 
   {{0xb5f98031,0x2d851323,0x3f840077,0x44200240}},	//   trác, hene_, xeou_, _qik_, 
   {{0x2d851ca2,0x4420b529,0xb5f801f1,0x4ac800dc}},	// [28240] kene_, _vik_, urác, िनिव, 
   {{0x44218032,0xbea8030f,0x00000000,0x00000000}},	//   _wik_, یهان_, --, --, 
   {{0x44218033,0x2d84119a,0xb7d04517,0x3f84021c}},	//   _tik_, dene_, _رقیب, teou_, 
   {{0xb5f80232,0x82a405f5,0x44380034,0x3e7004cc}},	//   prác, _дамж, _itp_, tât_, 
   {{0x7c218034,0x2d858035,0x3f858036,0xc838001f}},	//   _rior, fene_, reou_, _የደህን, 
   {{0x2d858037,0x44398038,0x64981aa1,0x7c218039}},	//   gene_, _ktp_, _ḓiv, _sior, 
   {{0x7c21803a,0x50b400a8,0x2900000d,0x00000000}},	//   _pior, _есту, üjal_, --, 
   {{0x7c200140,0x4438c6c2,0x2d840083,0x3e700129}},	//   _qior, _mtp_, aene_, pât_, 
   {{0x2d85803b,0xf4100bd4,0x7c21803c,0xbb4c037e}},	//   bene_, ופה_, _vior, _comの_, 
   {{0x7e60020c,0x4438501d,0x7c2c002e,0x65b0005b}},	//   mrop, _otp_, _ébro, _tähy, 
   {{0x4439803d,0xdb240214,0x7ae403b2,0x00000000}},	//   _ntp_, _فوای, úktb, --, 
   {{0x7c38003d,0x7c20054e,0x7e60045a,0xeb3000db}},	//   _ittr, _uior, orop, _قىمد, 
   {{0x7e60002d,0x6bd40c4f,0x3cdc000d,0x00000000}},	//   nrop, _بونس_, _केते_, --, 
   {{0xf3fc0004,0x4439803e,0x00000000,0x00000000}},	//   _skã_, _btp_, --, --, 
   {{0x7349803f,0x6a100116,0xc99400f1,0x00000000}},	//   ичав_, _юмшу, _راوګ, --, 
   {{0x44398040,0x3dc000cc,0x00000000,0x00000000}},	//   _dtp_, ্চিল, --, --, 
   {{0x2d858041,0x0680030d,0x00000000,0x00000000}},	// [28250] yene_, _пӳрн, --, --, 
   {{0x7f40003a,0x44385f5c,0x7c3802d0,0x656800a3}},	//   eboq, _ftp_, _ottr, òdht, 
   {{0xf8c98042,0x2d858043,0x3dc00729,0x7e6149b8}},	//   ानिय, vene_, ্চাল, erop, 
   {{0x2d840605,0x7e600522,0x1fb40150,0x00000000}},	//   wene_, frop, мсір, --, 
   {{0x2d858044,0x7c398045,0x4ad80037,0xdd140419}},	//   tene_, _attr, _बेंव, _rúšk, 
   {{0xf8c807d0,0x21a801af,0x00000000,0x00000000}},	//   ानाय, _мәхү_, --, --, 
   {{0x7dc403b2,0xb3bc000d,0x00000000,0x00000000}},	//   _iðsl, _एकाख, --, --, 
   {{0x2d858046,0x61300241,0xfb5000d1,0xcfe80244}},	//   sene_, _tòló, ىپىد, _افره_, 
   {{0x2d858047,0x7e618048,0xb5f80124,0x00000000}},	//   pene_, crop, guák, --, 
   {{0x6ca45c9e,0x6e398049,0x2d85804a,0x49c9804b}},	//   _وصال, _itub, qene_, слон_, 
   {{0x6d41804c,0x7c380998,0x290001a8,0xbe7400f1}},	//   mbna, _gttr, æja_, _وپېژ, 
   {{0xbb1400d1,0x6d40002f,0x00000000,0x00000000}},	//   ﺳﻪﻥ_, lbna, --, --, 
   {{0xb9001b13,0x4439804d,0x64980943,0x629800da}},	//   _ने_, _stp_, _ḽit, āvok, 
   {{0x7c38049f,0xf66802d2,0x00000000,0x00000000}},	//   _yttr, _stæð_, --, --, 
   {{0x6d40058a,0xb990009f,0x00000000,0x00000000}},	//   ibna, _سليب, --, --, 
   {{0x7e61804e,0x6e39804f,0x3cdc033d,0x44380421}},	//   yrop, _otub, _कइसे_, _vtp_, 
   {{0x6e3801b2,0x4438020b,0x00000000,0x00000000}},	// [28260] _ntub, _wtp_, --, --, 
   {{0x44383223,0x7e609008,0xf77c010e,0x00000000}},	//   _ttp_, vrop, doçy_, --, 
   {{0x6e398050,0x7e604a40,0xb5f8007b,0xfd500055}},	//   _atub, wrop, orán, cceṅ, 
   {{0x64980084,0x3fd804c5,0x6d406688,0xbbd80118}},	//   _ḓit, ধক্ষ, ebna, _बगेक, 
   {{0xdd949a21,0x7f40f13a,0x6f800150,0x00000000}},	//   далы, rboq, _ﺭﺤﻬﺎ_, --, 
   {{0xb5f98051,0x7e618052,0xf2d000c8,0x7f40067c}},	//   hrán, rrop, _טער_, sboq, 
   {{0xb5f81873,0x6e3804ba,0xa02403fa,0x6280014a}},	//   krán, _etub, größ, _ämob, 
   {{0x7e605337,0x2fc404e6,0x00000000,0x00000000}},	//   prop, ëngt_, --, --, 
   {{0xfa8807d6,0xb5f882e3,0x224002bd,0x6d4050d2}},	//   ёсий_, drán, npik_, bbna, 
   {{0xed544fdb,0x95700023,0x6d4001ab,0x18040118}},	//   _ноу_, ብታትን_, cbna, रत्व_, 
   {{0xb5f98053,0x7c3877d4,0xbb4800ec,0xeaac029e}},	//   frán, _uttr, _هلان_, نعی_, 
   {{0x64981682,0x2240356c,0xec105f32,0x41f800dc}},	//   _ḽis, kpik_, _كولد, ्तुः_, 
   {{0xb33800a2,0xb9e4247f,0x6e38045a,0x195800db}},	//   _goçy, _ىستى, _xtub, _далы_, 
   {{0xb5f800ae,0xd1f00092,0xf77c27ac,0x00000000}},	//   arán, ቁበት_, diçe_, --, 
   {{0xb5f802fd,0xe9780302,0xa9780375,0xdcf800e4}},	//   brán, _הנוש, _האוכ, tevę, 
   {{0xb5f8ea0f,0x656801ab,0xdb2401e1,0x00000000}},	//   ntáz, òdhr, _àsót, --, 
   {{0x645809f3,0x91b800d8,0x3cdc012d,0xf77c010b}},	// [28270] _ævin, огат_, _केसे_, giçe_, 
   {{0xa1940166,0xb5f800c7,0x2ba0000d,0x00000000}},	//   науч, kuái, _खोना, --, 
   {{0x649806d6,0x6e398054,0x394c051f,0x25d800c8}},	//   _ḓis, _stub, _mefs_, _מוזן_, 
   {{0x394c05d5,0x3b0401b9,0x6e400133,0x2c54054e}},	//   _lefs_, _oyoq_, فۆرم, văd_, 
   {{0xda0c0490,0x22846206,0xdea401d3,0x00000000}},	//   हतात_, _пург, ٹیلی, --, 
   {{0x3ea007d6,0xbea18055,0xdea497d1,0x6d400009}},	//   тишг, ташк, عیلی, ubna, 
   {{0x6d4014e0,0xb5f80588,0x2fc401c7,0x00000000}},	//   rbna, guái, ëngs_, --, 
   {{0x5f9434da,0x6e398056,0x00000000,0x00000000}},	//   _пист, _ttub, --, --, 
   {{0xad243ccd,0x6e398057,0x60181c22,0xd07c04ce}},	//   _فراو, _utub, _хотя_, l欄_, 
   {{0x08c42cb8,0xc278011a,0x7ae406ea,0x00000000}},	//   дбон, קרתי, úkta, --, 
   {{0xb5f85ced,0x24b002dd,0x224001c4,0x00000000}},	//   trán, _ءﻭﺭﯨ, zpik_, --, 
   {{0xfc4803f2,0x00000000,0x00000000,0x00000000}},	//   smíð_, --, --, --, 
   {{0xb5f839b3,0xab098058,0xb33800ad,0x602c0139}},	//   rrán, _اتاق_, _inçh, _işme, 
   {{0xb2194608,0xf77c236c,0x00000000,0x00000000}},	//   _spæn, viçe_, --, --, 
   {{0xf1bc00e4,0x64c811e1,0xf5000108,0x00000000}},	//   _guái_, रनेश, взро, --, 
   {{0x29040009,0x00000000,0x00000000,0x00000000}},	//   _iyna_, --, --, --, 
   {{0x42258059,0x27e1805a,0x76497fd3,0x2904015d}},	// [28280] ддав, _imin_, _ægyp, _hyna_, 
   {{0x2241805b,0x3cdc367a,0x2fdc00e8,0x394c00db}},	//   rpik_, _कइले_, _amug_, _xefs_, 
   {{0x2240420d,0xb7d426a8,0xe6ac0139,0x661c0076}},	//   spik_, _رویا_, _läüç, mmrk, 
   {{0xb5f8012c,0x2240000d,0x7f4400c0,0x00000000}},	//   hrál, ppik_, федж, --, 
   {{0xa2485896,0x29040810,0xb5f825fd,0xdcf80118}},	//   _ریال_, _lyna_, král, bevě, 
   {{0xad200075,0x2905805c,0xb5f8007b,0xada00395}},	//   ھىيى, _oyna_, tuái, качл, 
   {{0x6da010f3,0x0ca0001f,0x27e03930,0xad200131}},	//   тија, ግራሞች_, _omin_, پىيى, 
   {{0x27e1805d,0xeb940640,0x6b58013d,0xd7f8054e}},	//   _nmin_, дић_, _nägı, trăm_, 
   {{0x2905805e,0xb5f9805f,0x00000000,0x00000000}},	//   _ayna_, rtáz, --, --, 
   {{0x27e16d1d,0x29058060,0x0a2c02d3,0xb5f826f6}},	//   _amin_, _byna_, _ተኣምራ, stáz, 
   {{0xf1bc0016,0x6b580166,0x394c08a5,0x00000000}},	//   _quái_, _bägı, _vefs_, --, 
   {{0x290400a9,0xdef802d3,0x27e005da,0xb5f80332}},	//   _dyna_, _ፈተነ_, _cmin_, arál, 
   {{0xb5f89cba,0x394c0793,0x29058061,0x3b04022e}},	//   brál, _tefs_, _eyna_, _uyoq_, 
   {{0x27e051c8,0xb338036e,0x1da41684,0x847c0257}},	//   _emin_, _inçi, _गोमत, _ሕልምን_, 
   {{0xe4e400d6,0x200402ea,0x7dc401a8,0x29058062}},	//   вітн, _okmi_, _aðsk, _gyna_, 
   {{0xf8c83c71,0xe7e80166,0x27e0012d,0x799802d0}},	//   ानीप, _офык_, _gmin_, ldtw, 
   {{0x52141d83,0x38440020,0x29040432,0xdef80023}},	// [28290] едат, _የተባበ, _zyna_, _ፈተኑ_, 
   {{0x2fdd8063,0x26000490,0x799802d0,0x6b58013d}},	//   _smug_, ळवणी_, ndtw, _zägı, 
   {{0x3cdc05ba,0x00000000,0x00000000,0x00000000}},	//   _केले_, --, --, --, 
   {{0xae0000d1,0xb5f80588,0x00000000,0x00000000}},	//   چۈرى, guáv, --, --, 
   {{0xf8c844af,0xde5802bf,0x66281e0c,0xb5f8fc2d}},	//   ानुप, дачі_, _ürkü, hrám, 
   {{0x160000bc,0x00000000,0x00000000,0x00000000}},	//   ोतिर_, --, --, --, 
   {{0x4c685ded,0xfd34007b,0x00000000,0x00000000}},	//   чийн_, ركيب_, --, --, 
   {{0x290405b1,0xb00000b8,0xb5f85821,0x00000000}},	//   _ryna_, _kaḍa, drám, --, 
   {{0xb5f800dd,0xb00000cd,0xbe600150,0x3b800d31}},	//   trál, _jaḍa, _مۇني, улыг, 
   {{0x6b58013d,0xb5f89cba,0x27e000dc,0xbd940023}},	//   _sägı, frám, _smin_, _መሬቶም_, 
   {{0x27e0020b,0x1dac1fbc,0xabb00588,0xb5f98064}},	//   _pmin_, चारत, _иажә, grám, 
   {{0xb2181125,0xc5f80882,0x29040093,0x193804ce}},	//   _spæl, ृत्य_, _vyna_, _ｗｅｂ_, 
   {{0xb6a00e76,0x29040142,0xb0000055,0x6b58013d}},	//   гиял, _wyna_, _naḍa, _vägı, 
   {{0x6b998065,0x2ba01b57,0x29040356,0x7c3c00df}},	//   ldug, _खोता, _tyna_, ŭpre, 
   {{0x589401e0,0x27e00327,0x443c017a,0x29040166}},	//   _ашыу, _tmin_, ët_, _uyna_, 
   {{0x6b998066,0x64980084,0x27e0020b,0xb00000b8}},	//   ndug, _ḓip, _umin_, _baḍa, 
   {{0x6b980254,0x00000000,0x00000000,0x00000000}},	// [282a0] idug, --, --, --, 
   {{0x20040098,0x00000000,0x00000000,0x00000000}},	//   _skmi_, --, --, --, 
   {{0xb5f80122,0x71700597,0x84e4009d,0x6b98010b}},	//   kráj, اهما, _чонж, kdug, 
   {{0x7c2c00d8,0x6b980e04,0x00000000,0x00000000}},	//   _ébri, jdug, --, --, 
   {{0x6b998067,0xf77c0561,0xb5f802f0,0x00000000}},	//   ddug, niça_, zrám, --, 
   {{0xac980240,0x2f1400db,0x00000000,0x00000000}},	//   _ቀይሮም_, رۉلگ_, --, --, 
   {{0x6b9800e8,0x00000000,0x00000000,0x00000000}},	//   fdug, --, --, --, 
   {{0x6b998068,0x8cb061f2,0xe8dc01fb,0xefcc001f}},	//   gdug, _अपरो, _chửi_, ባቢው_, 
   {{0x60e002d5,0xb9500023,0x799802d0,0x00000000}},	//   žymė, _መበገሲ, tdtw, --, 
   {{0xf77c0798,0xc0c4032e,0x6b9801e1,0x00000000}},	//   diça_, _óásæ, adug, --, 
   {{0x5fc411b1,0x3cf80037,0x6a100b24,0xe7cc1408}},	//   _वकाल, _ऊँटे_, دبير, ासंप, 
   {{0xb5f800e4,0x5bb828f6,0x00000000,0x00000000}},	//   rrám, _ілля_, --, --, 
   {{0x7dc402d2,0xb5f800e4,0xa92400ef,0x00000000}},	//   _aðsi, kuát, evžī, --, 
   {{0x4ad800c5,0x00000000,0x00000000,0x00000000}},	//   _बेटव, --, --, --, 
   {{0xd7f400c7,0x58d400db,0xd69801ec,0xf80400d8}},	//   _изкы, _шокт, _ﺘﻅﻬﺭ_, _пчин, 
   {{0xf77c00d8,0xdd100064,0xf7701291,0x00000000}},	//   biça_, _ažūr, _صاع_, --, 
   {{0xf77c0120,0x00000000,0x00000000,0x00000000}},	// [282b0] ciça_, --, --, --, 
   {{0x8cb0068f,0xb5f80022,0x55c405a2,0x6b98054e}},	//   _अपलो, guát, _рәмз, zdug, 
   {{0x6b982c13,0xb5f802d2,0x00000000,0x00000000}},	//   ydug, hrák, --, --, 
   {{0xdfd405f5,0x211801b9,0x00000000,0x00000000}},	//   лохы, رتلب_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb5f809c2,0x4fc000d1,0x00000000,0x00000000}},	//   cuát, _ھەشە, --, --, 
   {{0x6b998069,0x8c9402dd,0x1fa401c6,0x4fc000db}},	//   tdug, трлі, _өртг, _پەشە, 
   {{0x71640150,0xca8401c6,0x00000000,0x00000000}},	//   _تاڭك, вгий, --, --, 
   {{0xeb94472b,0xdfd40220,0x00000000,0x00000000}},	//   диқ_, _соты, --, --, 
   {{0x6b98050a,0x0d208087,0x88c8c02c,0xb21808a5}},	//   sdug, _күлү, длов_, _spæj, 
   {{0xc2100375,0x00000000,0x00000000,0x00000000}},	//   שהי_, --, --, --, 
   {{0x29080a28,0xb5f802f0,0xa8a000f7,0x00000000}},	//   āca_, brák, _ۅلتۉ, --, 
   {{0xaf6c001f,0x660400c7,0x00000000,0x00000000}},	//   _ጥናትና_, лҿиа, --, --, 
   {{0x15b8f4fc,0xc9540882,0xf77c00d8,0xdb2402d2}},	//   нысы_, bhūṣ, riça_, _ását, 
   {{0x60181dec,0x0574f2af,0xb5f806ea,0x00000000}},	//   líme, _یادد, ksáf, --, 
   {{0x12980023,0x00000000,0x00000000,0x00000000}},	//   _ዘራኽብ_, --, --, --, 
   {{0xc3243ae5,0x02047503,0x03240209,0x601800e4}},	// [282c0] тмак, взан, тдан, níme, 
   {{0xb1412bcc,0x00000000,0x00000000,0x00000000}},	//   инул, --, --, --, 
   {{0xd6a830c0,0xb5f80306,0x0444117e,0x00000000}},	//   _قدیم_, dráh, _шенн, --, 
   {{0xbe880640,0xd0940166,0x00000000,0x00000000}},	//   дске_, ышуы, --, --, 
   {{0x645c017a,0x6ff000af,0x60180118,0xccc40075}},	//   lsri, _अदरख_, jíme, ңғул_, 
   {{0xf1bc01fb,0xb5f93eb8,0x008401a9,0x00000000}},	//   _quát_, quát, _илго, --, 
   {{0xac7002dd,0x31980375,0xc0e40104,0x318001d3}},	//   لايش, _קבלנ, _ровк, észő_, 
   {{0xb5f9806a,0x92b40183,0x645d806b,0xb4f8011a}},	//   nuár, জনৰ_, isri, ופצי, 
   {{0x60183eba,0x3cdc007d,0x1958010b,0xf8c800dc}},	//   gíme, _कइके_, напы_, ान्प, 
   {{0x79a475f1,0x98b80261,0xada000f3,0xb5f801d3}},	//   трие, елот_, _каул, mság, 
   {{0xb5f9806c,0xf1bc00e4,0xbb8400c6,0xed54013e}},	//   lság, _kuár_, _للاي, _рох_, 
   {{0xbb4412b4,0xb5f9806d,0x37a8024c,0x00000000}},	//   _редк, prák, фтон_, --, 
   {{0xb5f9806e,0x645c017a,0xb99400c6,0x55c40116}},	//   nság, esri, _للشب, гәнз, 
   {{0xb5f8007b,0x48fc07f7,0xb810035b,0x00000000}},	//   orái, _रुको_, ыҧқә, --, 
   {{0x645c01e6,0xe454005b,0x9a540022,0xb5f800ae}},	//   gsri, икры, _рхҵә, nrái, 
   {{0x6368716a,0xf77c0798,0xb5f92d30,0x00000000}},	//   круг_, miço_, kság, --, 
   {{0xb5f800c6,0xf77c00d8,0xe6980166,0x645c000d}},	// [282d0] hrái, liço_, _авыш_, asri, 
   {{0xb5f8fdec,0x71248944,0x00000000,0x00000000}},	//   dság, نرال, --, --, 
   {{0xf1c0025c,0x2ec800dc,0xdb2408a5,0x68240023}},	//   _raġġ_, ऽन्त, _ásæt, ተወሲድ, 
   {{0x8c4418ce,0xb5f94d3f,0xe4a402bf,0xa3446c9c}},	//   ңеле, cuár, _трьо, _вэрл, 
   {{0x8e85806f,0xb5f919a1,0x1f6402dd,0x00000000}},	//   угле, gság, ркім, --, 
   {{0x1d8800d1,0x00000000,0x00000000,0x00000000}},	//   نئىي_, --, --, --, 
   {{0xc17002e4,0x2c0c0490,0xb5f800ae,0x20980108}},	//   _לחם_, ातलं_, grái, _икры_, 
   {{0x7c3c03c6,0x1fa432eb,0x92b403d4,0xf77c00d8}},	//   ípra, _круг, জনী_, diço_, 
   {{0xb5f8007b,0x602c0139,0x00000000,0x00000000}},	//   arái, _uşma, --, --, 
   {{0x3cdc1524,0x49958070,0xb3380432,0xb5f856fa}},	//   _केके_, ушит, _haçd, brái, 
   {{0xb3380432,0x6018021c,0xb5f801e7,0x00000000}},	//   _gaçg, síme, crái, --, 
   {{0x1be401d5,0x00000000,0x00000000,0x00000000}},	//   _кўчг, --, --, --, 
   {{0x26c58071,0xff78008f,0x645c017a,0x260001f9}},	//   âmo_, עטשמ, wsri, ळवली_, 
   {{0x645c0af9,0xe8c4014b,0xc89400f3,0x00000000}},	//   tsri, _аҳол_, _брињ, --, 
   {{0x07a58072,0xaee00943,0x2a7c00af,0xb5f98073}},	//   _байн, _miṱo, ltub_, tuár, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb5f93eb8,0x2a7c1bce,0x8184009d,0x3a3400df}},	// [282e0] ruár, ntub_, лгаж, ָרעם_, 
   {{0xc2083e52,0xddd401a2,0xa4941547,0x3844001f}},	//   رقان_, _ťažk, _پیرت, _የተቀበ, 
   {{0x2a7c00af,0x63e40150,0x00000000,0x00000000}},	//   htub_, _نيدە, --, --, 
   {{0x2a7d8074,0x2ba00b40,0xb5f98075,0xfdbc1546}},	//   ktub_, _खोला, tság, ्स्फ, 
   {{0x2a7c01d4,0xce34004b,0x2fd400f2,0x00000000}},	//   jtub_, لونک, دوند_, --, 
   {{0xb5f80e55,0x00000000,0x00000000,0x00000000}},	//   trái, --, --, --, 
   {{0xb5f800dd,0xbc044ed4,0x9fb80118,0xdef00023}},	//   sság, лчий, lčí_, ግዜኡ_, 
   {{0x7dc400fc,0xb5f800c6,0x0084039b,0xb338010b}},	//   _aðst, rrái, _илҳо, _gaçd, 
   {{0x9fb80232,0xfd74446a,0x8d840014,0x5a34041b}},	//   nčí_, _مداخ, _چشمن, јнот, 
   {{0xf77c0798,0xf278008f,0x784401c6,0x00000000}},	//   tiço_, עריש, лэмж, --, 
   {{0x9fb8219b,0xd914005b,0xac640137,0x195800c7}},	//   hčí_, рдны, _مئنۇ, наҿы_, 
   {{0x2a7cc95a,0x2cf8010f,0xf77c17cd,0xb33827ac}},	//   btub_, _אלבא, riço_, _kaçe, 
   {{0xe6658076,0x9fb80216,0xe9cc00f2,0x00000000}},	//   йтро, jčí_, زغی_, --, 
   {{0xb5f98077,0x7bc0123c,0x9fb802fb,0xea60009f}},	//   hráv, _hoou, dčí_, _اهوپ, 
   {{0xa4d402bf,0x53343007,0x33842077,0x2900025c}},	//   борі, иевт, луав, żjar_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x115566be,0x7bc03012,0x588401e0,0xb33800a2}},	// [282f0] икаю, _moou, _сыҙа, _naçe, 
   {{0xb5f80022,0xb33845d8,0x00000000,0x00000000}},	//   eráv, _saçd, --, --, 
   {{0xb5f803f2,0xddd00139,0x30a47bca,0x00000000}},	//   fráv, _şeşt, ырав, --, 
   {{0xb3380213,0xb5f803b2,0x00000000,0x00000000}},	//   _qaçd, ssád, --, --, 
   {{0x8db400d4,0x09b000fe,0x6ee400f2,0x00000000}},	//   искі, য়োটা, دسال, --, 
   {{0x2a7c0218,0x6018012c,0x00000000,0x00000000}},	//   vtub_, tímc, --, --, 
   {{0xb5f80120,0x248802d3,0xdcf8005f,0x8c440150}},	//   bráv, _ምውሳድ_, devē, шейе, 
   {{0xb5f81709,0x7bc00076,0x2a7c6539,0x00000000}},	//   nsáb, _coou, ttub_, --, 
   {{0x3f80025a,0x7bc000ad,0xb3380166,0x5ba401e0}},	//   _ökua_, _doou, _gaçe, слығ, 
   {{0x3a2c056a,0x09e44ecc,0x49c8016c,0x2a7d8078}},	//   _cifp_, роон, тлон_, rtub_, 
   {{0x7bc003a0,0x2a7c00af,0xe6b40432,0x9fb80118}},	//   _foou, stub_, _düýä, zčí_, 
   {{0xf8ac04d3,0xb3380139,0x7bc0013a,0xfc4000e5}},	//   بکه_, _yaçe, _goou, _بھوپ, 
   {{0x60191a6d,0x63a18079,0x00000000,0x00000000}},	//   níma, _ómni, --, --, 
   {{0x7bc00218,0x9fb8012c,0xfa6401a9,0x00000000}},	//   _zoou, včí_, _ташк_, --, 
   {{0x69c1807a,0xb5f80f52,0x00000000,0x00000000}},	//   _ione, yráv, --, --, 
   {{0xb5f868b1,0x69c1807b,0x00000000,0x00000000}},	//   dráu, _hone, --, --, 
   {{0x6018076f,0xaa380092,0xb5f806c6,0x00000000}},	// [28300] jíma, _በባህላ, vráv, --, 
   {{0xbbd0df24,0x69c0b8c9,0x36580a1e,0x9fb8022a}},	//   _तत्क, _jone, _שכינ, rčí_, 
   {{0x69c1807c,0xb5f802fb,0x7de40330,0xb62c0150}},	//   _mone, tráv, یستم, _ﺒﺭ_, 
   {{0x03a5807d,0x42e880e2,0xb0300046,0x69c0975e}},	//   _тимо, _аммо_, ініш, _lone, 
   {{0x69c1807e,0xfe40006c,0xb33806be,0xb5f800e4}},	//   _oone, تکزی, _qaçe, rráv, 
   {{0x69c00516,0x7bc00607,0xcf2400c6,0x00000000}},	//   _none, _soou, حرمي, --, 
   {{0xb5f847f5,0x64480115,0x00000000,0x00000000}},	//   práv, ŭdif, --, --, 
   {{0x69c066a1,0x7fd40220,0x7c3c0115,0x00000000}},	//   _aone, _тігі, ŭpro, --, 
   {{0x995802fb,0xee340024,0x00000000,0x00000000}},	//   ráži_, _вну_, --, --, 
   {{0x69c1807f,0xfce58080,0xf9c416ab,0x99580306}},	//   _cone, _козо, рщин, sáži_, 
   {{0x69c18081,0x31350b71,0x00000000,0x00000000}},	//   _done, ינים_, --, --, 
   {{0x69c0035a,0x3f84060f,0xaa5401d3,0xb5f852a2}},	//   _eone, nfou_, _چلنا_, hrát, 
   {{0x69c18082,0xc5ec021a,0xb5f93800,0xe69802e8}},	//   _fone, کړي_, krát, авяш_, 
   {{0x69c003b4,0xf65c0393,0x49680240,0x00000000}},	//   _gone, rsæ_, _ተጠቂሱ_, --, 
   {{0xe4a58083,0xb5f98084,0xf65c0393,0xa96400f0}},	//   орто, drát, ssæ_, _тија_, 
   {{0x69c18085,0x3ea4007c,0x00000000,0x00000000}},	//   _zone, kvot_, --, --, 
   {{0x69c18086,0x60180077,0xe8dc0208,0x00000000}},	// [28310] _yone, xíma, _phủi_, --, 
   {{0x6fd0013d,0x3f8406af,0x69c06313,0x0f340133}},	//   _cçcn, efou_, _xone, ڵکرد, 
   {{0xa5080120,0xe1340006,0x00000000,0x00000000}},	//   _веќа_, інцы, --, --, 
   {{0x60198087,0x00000000,0x00000000,0x00000000}},	//   tíma, --, --, --, 
   {{0xb5f85955,0xe8dc0208,0xa2640395,0x00000000}},	//   brát, _thủi_, _мърл, --, 
   {{0x7bc4840d,0xfde007af,0x00000000,0x00000000}},	//   ökun, कोलस_, --, --, 
   {{0x69c18088,0x9c580184,0x4a440032,0x00000000}},	//   _rone, ашыу_, әнов, --, 
   {{0x69c18089,0x251c010f,0x644800df,0xdc740022}},	//   _sone, כווא, ŭdig, цышь, 
   {{0xad6400ec,0x00000000,0x00000000,0x00000000}},	//   _نااه, --, --, --, 
   {{0x49983f92,0x6f180cf4,0xfe6d808a,0x7b8400d1}},	//   утия_, _izuc, _سگه_, لاۋە, 
   {{0x69c1808b,0x07a5808c,0xc7a408b7,0x48051db0}},	//   _vone, банн, бинк, йпов, 
   {{0x69c1808d,0xb5f95fd2,0x2da00327,0x60180139}},	//   _wone, krás, żreġ_, hímn, 
   {{0x69c1808e,0x2d840ba7,0x9fb800d7,0x00000000}},	//   _tone, ofne_, nčá_, --, 
   {{0x69c0b5c7,0xb5f801ed,0x2f2800c0,0x00000000}},	//   _uone, drás, mėgį_, --, 
   {{0x04442424,0xb5f80122,0x2d840ba7,0xb7d5808f}},	//   себн, vrát, ifne_, _گويا_, 
   {{0xb5f8022c,0x6f18010e,0xe8dc0051,0x00000000}},	//   frás, _ozuc, _chụi_, --, 
   {{0xaaa400c5,0x3ea40007,0xb5f81bbf,0x013440bb}},	// [28320] कटिक, xvot_, trát, معاد, 
   {{0x2d8401fa,0xb5f803da,0xcfa8158b,0x3ea4022e}},	//   jfne_, urát, یانم_, vvot_, 
   {{0x6f1809ff,0x425402dd,0x00840108,0x00000000}},	//   _azuc, ртұт, слео, --, 
   {{0x7dc401a8,0xb2188ecc,0x6f1800d7,0x2d840254}},	//   _aðsp, _spæt, _bzuc, efne_, 
   {{0x248c003d,0xd2b800f7,0x82344c84,0x3f847d9b}},	//   ħdmu_, _курч_, _درجا, rfou_, 
   {{0x44398090,0x628401e6,0xd174cfb1,0x3ea4005b}},	//   _kup_, mtio, _мысы, rvot_, 
   {{0x63a58091,0x44380978,0x62858092,0xf41c02f6}},	//   odin, _jup_, ltio, _yhä_, 
   {{0x4f64585a,0xb3398093,0x62840393,0xd00401ec}},	//   _واقف, _kaça, otio, _досқ, 
   {{0x63a58094,0x44398095,0x6285149c,0x7d540451}},	//   idin, _lup_, ntio, _هئائ, 
   {{0x63a58096,0xb3398097,0x62858098,0xf77c05d1}},	//   hdin, _maça, itio, miçi_, 
   {{0x44398099,0xb5f9809a,0x7e607813,0x26c40793}},	//   _nup_, krár, lsop, ämon_, 
   {{0x63a5809b,0x8ac407dd,0x7f400393,0x7e6001f4}},	//   jdin, сқәа_, ncoq, osop, 
   {{0x63a40fa9,0x44380ba1,0xb33910d1,0x7e61809c}},	//   ddin, _aup_, _naça, nsop, 
   {{0x7c39809d,0xd1cc02d3,0x63a562b8,0x7e6001f5}},	//   _kutr, ቢታት_, edin, isop, 
   {{0xdce80ab7,0xf365809e,0x6285809f,0x63a41eb9}},	//   _kadı, йтан, etio, fdin, 
   {{0x395d80a0,0x443980a1,0x63a580a2,0x7c3801c0}},	//   lats_, _dup_, gdin, _mutr, 
   {{0xb33859f9,0x443906f7,0x7e6001a4,0x601813d5}},	// [28330] _caça, _eup_, jsop, tímn, 
   {{0x7c3810b0,0x395d80a3,0x63a580a4,0x7e600b34}},	//   _outr, nats_, adin, dsop, 
   {{0x628580a5,0x63a4584c,0xb5f980a6,0x7e6003cd}},	//   atio, bdin, brár, esop, 
   {{0xb33980a7,0x7e600408,0x395d80a8,0x63a505c5}},	//   _faça, fsop, hats_, cdin, 
   {{0x7c3980a9,0x628580aa,0x395d80ab,0x44382b5d}},	//   _autr, ctio, kats_, _zup_, 
   {{0x395d80ac,0xdcf802d5,0x7c3980ad,0x44380f85}},	//   jats_, nevė, _butr, _yup_, 
   {{0x395d80ae,0x7c3980af,0x60180077,0x7e600af9}},	//   dats_, _cutr, címo, asop, 
   {{0x7c3980b0,0x4a440868,0x7f40003a,0x7e6000b5}},	//   _dutr, онив, ccoq, bsop, 
   {{0x7c3980b1,0x395d80b2,0x7e6001d3,0xdce80c3c}},	//   _eutr, fats_, csop, _dadı, 
   {{0x395d80b3,0x63a580b4,0xa3b002ab,0x0888eb9b}},	//   gats_, zdin, _टोन_, абой_, 
   {{0x7c381446,0x628401c0,0x6e3980b5,0xc1700375}},	//   _gutr, ztio, _huub, וחי_, 
   {{0x6e3980b6,0x4438016d,0x63a580b7,0xdce800a2}},	//   _kuub, _rup_, xdin, _gadı, 
   {{0x443980b8,0x395d80b9,0x63a580ba,0x628580bb}},	//   _sup_, bats_, vdin, xtio, 
   {{0x395d80bc,0x4438016d,0xb33980bd,0x63a4410f}},	//   cats_, _pup_, _raça, wdin, 
   {{0x63a580be,0xb338d814,0xdce8d7c2,0x60180077}},	//   tdin, _saça, _yadı, xímo, 
   {{0x63a580bf,0x628580c0,0x4438014f,0xb33803e0}},	//   udin, ttio, _vup_, _paça, 
   {{0xb338723e,0x6e380ba7,0x628580c1,0xc1e8009d}},	// [28340] _qaça, _nuub, utio, адаж_, 
   {{0x63a4e9e1,0x443980c2,0x62840c46,0xb218037e}},	//   sdin, _tup_, rtio, _spær, 
   {{0x443980c3,0x128801b9,0xb5f80419,0x00000000}},	//   _uup_, _қирқ_, prár, --, 
   {{0x7e6180c4,0x628580c5,0x7c381730,0x6e3980c6}},	//   tsop, ptio, _rutr, _buub, 
   {{0x6e38320d,0x5275010c,0x44200e78,0x7f400393}},	//   _cuub, _нуру, _ihk_, rcoq, 
   {{0x7c3980c7,0x6e38bfa3,0x395d80bc,0xdce980c8}},	//   _putr, _duub, xats_, _sadı, 
   {{0x395d80c9,0x7c380113,0x7e613809,0x442084cd}},	//   vats_, _qutr, ssop, _khk_, 
   {{0xdce80cc1,0x7e6180ca,0xed4c00dd,0x442001f5}},	//   _qadı, psop, ٹھے_, _jhk_, 
   {{0x395d486b,0x6e3931eb,0x442055e3,0xf77c03e3}},	//   tats_, _guub, _mhk_, qiçi_, 
   {{0x23612587,0x2240011f,0x44200fac,0xed5416a8}},	//   haij_, iqik_, _lhk_, _моу_, 
   {{0x4420a997,0xdce805d1,0xb5f80d12,0x8bd8009d}},	//   _ohk_, _tadı, dráp, рмөс_, 
   {{0x4420105c,0xb0980375,0x56941f5a,0x6e387d85}},	//   _nhk_, ביטר, памт, _yuub, 
   {{0x395d80cb,0x7c2180cc,0x3704fbac,0x2ba00316}},	//   pats_, _ihor, ючов, _खोटा, 
   {{0x7c2001e4,0x795003e6,0x442180cd,0x00000000}},	//   _hhor, _تێدا, _ahk_, --, 
   {{0x7c2180ce,0x442180cf,0xb3380139,0x2eb401bc}},	//   _khor, _bhk_, _daçn, _आप्त, 
   {{0xedb407f8,0xf2dc006a,0x442180d0,0xb5f980d1}},	//   _इच्छ, _afâa_, _chk_, rráq, 
   {{0x7c2180d2,0x44200fac,0xd7f80356,0x00000000}},	// [28350] _mhor, _dhk_, nsăm_, --, 
   {{0x4420033d,0x6e380429,0x64480005,0x764c0210}},	//   _ehk_, _ruub, ídic, mpcy, 
   {{0x7c2180d3,0x23600007,0x6e3980d4,0x442003b2}},	//   _ohor, baij_, _suub, _fhk_, 
   {{0x7c200433,0x44205931,0x00000000,0x00000000}},	//   _nhor, _ghk_, --, --, 
   {{0x6e380ba7,0xe2980006,0x00000000,0x00000000}},	//   _quub, _даў_, --, --, 
   {{0x7c2180d5,0x2ba4001e,0xb3380200,0xb5f800e5}},	//   _ahor, _ốc_, _kaço, zsán, 
   {{0x7c2180d6,0x6e380009,0xabc001e0,0x00000000}},	//   _bhor, _wuub, дайҙ, --, 
   {{0x6e389cfb,0xb33980d7,0x6d4000c6,0xbb140046}},	//   _tuub, _maço, scna, _ﺳﻮﻝ_, 
   {{0x7c2180d8,0xb338315a,0x2b5d80d9,0xd8380100}},	//   _dhor, _laço, rauc_, jwčb_, 
   {{0xaca00521,0xba20f869,0x7c2110f9,0x26c401b8}},	//   _ahụm, ндык, _ehor, ämom_, 
   {{0x7c200491,0xb3380077,0xb5f800d2,0x07a580da}},	//   _fhor, _naço, tsán, панн, 
   {{0x23600218,0x07a41180,0x00000000,0x00000000}},	//   xaij_, чамн, --, --, 
   {{0xb5f825fd,0xbb3802e4,0x44200254,0x31480023}},	//   tráp, _העני, _rhk_, ምንታይ, 
   {{0x7c200122,0x496802d3,0x23600086,0x442180db}},	//   _zhor, _ተጠቒሱ_, waij_, _shk_, 
   {{0x44205bf4,0xb3380ba1,0xb5f8012c,0x91e4037e}},	//   _phk_, _caço, psán, _inとg, 
   {{0x97c47a3f,0xc245203a,0x7c200240,0x69f001c0}},	//   _يتيم, знак, _xhor, _хүүт, 
   {{0x23600a2e,0x44200270,0xb7780375,0x8afc0118}},	// [28360] raij_, _vhk_, _האפש, baře, 
   {{0xb33980dc,0x4420017a,0x055406d3,0xb5f802f0}},	//   _faço, _whk_, _этия, nsál, 
   {{0x44200205,0x5f440023,0xe5041546,0x6fb10db3}},	//   _thk_, _ንበረኸ, _शुचि_, کمنا, 
   {{0x442001ef,0x00000000,0x00000000,0x00000000}},	//   _uhk_, --, --, --, 
   {{0xb33980dd,0x2240013c,0x6018022a,0xb5f80174}},	//   _maçl, qqik_, límk, ksál, 
   {{0x7c2079c1,0xf48402f2,0xd12c0137,0x412941f6}},	//   _shor, _بایی, _چۅك_, _гого_, 
   {{0x212c01ab,0xb5f980de,0x00000000,0x00000000}},	//   _àdh_, guáy, --, --, 
   {{0xdcf8005f,0x7c200784,0x996c00ef,0x00000000}},	//   levī, _qhor, dēšu_, --, 
   {{0x7c200099,0x6bd40014,0xb5f8032e,0x9e840244}},	//   _vhor, سوٝس_, fsál, _تازۆ, 
   {{0x6e903ded,0x7c2180df,0xd8f802bf,0x58d45192}},	//   _سلما, _whor, жної_, доот, 
   {{0x17991f2c,0x7c2180e0,0x601802fb,0x6094001f}},	//   овны_, _thor, jímk, _ማውጣት_, 
   {{0x7c2180e1,0xb5f80332,0x3904004e,0xe870215c}},	//   _uhor, asál, ждүү_, رچىگ, 
   {{0xeb302dfc,0x00000000,0x00000000,0x00000000}},	//   _كىمد, --, --, --, 
   {{0xb3380798,0x602c0139,0xe5c401c6,0x996c00ef}},	//   _paço, _işmu, нссо, bēšu_, 
   {{0x257980e2,0x784405f5,0xdcf80f40,0x79980af2}},	//   ябрь_, _ээлж, devī, metw, 
   {{0x799980e3,0x925807d6,0xb3380432,0x00000000}},	//   letw, жаат_, _gaçl, --, 
   {{0xb5f980e4,0x28140014,0xa29400d4,0x00000000}},	// [28370] lsám, _سوٝس, наті, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6628012c,0xb46400ae,0x00000000,0x00000000}},	//   řské, _عدده, --, --, 
   {{0xb3387225,0x95140055,0x26f400fe,0xb5f800e5}},	//   _kaçm, _aṅgo, _ঘৰটো_, zsál, 
   {{0x799813c4,0x1ea8007b,0x00000000,0x00000000}},	//   ketw, كاوي_, --, --, 
   {{0x9f240131,0x98dc0210,0x00000000,0x00000000}},	//   رۈلۈ, मनाए, --, --, 
   {{0xd0440451,0x98bc00dc,0x7998007f,0xb5f80174}},	//   _آپري, _devī_, detw, vsál, 
   {{0x0a4836da,0xec2000cf,0xed88010a,0x00000000}},	//   озий_, رۉشپ, _ӳсек_, --, 
   {{0x799980e5,0x00000000,0x00000000,0x00000000}},	//   fetw, --, --, --, 
   {{0x79982a28,0xb3383630,0x8ca00456,0xe97000db}},	//   getw, _saçl, _कैथो, رۇعد, 
   {{0xdd1c0232,0xb5f980e6,0xb338010e,0x2900036e}},	//   _záži, rsál, _paçl, çja_, 
   {{0x26c82097,0xb3380139,0x4a74004e,0x2900031c}},	//   зғин_, _baçm, _жыкт, ħja_, 
   {{0x799980e7,0x6b995c32,0x00000000,0x00000000}},	//   betw, meug, --, --, 
   {{0xdb4c168d,0x6b9980e8,0x84586d64,0x00000000}},	//   _پێی_, leug, жрат_, --, 
   {{0x07a580e9,0x443c0208,0xe7cc03d4,0xb33803e0}},	//   _жайн, êt_, _লগীয, _taçl, 
   {{0x42d4187f,0x00000000,0x00000000,0x00000000}},	//   мізу, --, --, --, 
   {{0xa3e428d4,0xb338010b,0x98fc0115,0x0554447e}},	// [28380] भोग_, _gaçm, maĉa, _отня, 
   {{0x6b980cf9,0x00d800c6,0x98fc0115,0x00000000}},	//   heug, يبات_, laĉa, --, 
   {{0x6018a275,0x00000000,0x00000000,0x00000000}},	//   lími, --, --, --, 
   {{0x799980ea,0xfc480008,0x98bc00e2,0x6b980582}},	//   zetw, hlíð_, _sevī_, jeug, 
   {{0x60185efb,0x6b9980eb,0xb33800ac,0xde5802d5}},	//   ními, deug, _xaçm, чалі_, 
   {{0xed4c04d3,0xf3f8025c,0xbc4980ec,0xdd1c02fb}},	//   لپه_, _དམོད_, очие_, _váži, 
   {{0x79984b65,0x7c8400d8,0x00000000,0x00000000}},	//   vetw, фуле, --, --, 
   {{0x6b9980ed,0x79980337,0x4128059f,0x1b04013d}},	//   geug, wetw, _гоҳо_, нүен, 
   {{0x5a3580ee,0x98bc0171,0x00000000,0x00000000}},	//   ннит, _tevī_, --, --, 
   {{0xec1007d6,0x60180332,0x290803e0,0x00000000}},	//   _یولد, dími, ğcan_, --, 
   {{0x799980ef,0xb33980f0,0x8bf800aa,0xd7f51ed9}},	//   retw, _saçm, _کونړ_, езны, 
   {{0xb3380200,0x799980f1,0xb5f800e5,0x00000000}},	//   _paçm, setw, csáj, --, 
   {{0x799980f2,0x8b6407d2,0xb3380213,0xfc4803b2}},	//   petw, _سانم, _qaçm, blíð_, 
   {{0xe9b000c7,0xb338010e,0xd1f00092,0x7c3c01e4}},	//   _абшь, _gaçj, ሁበት_, ŭpru, 
   {{0x28a050d5,0xa8a02fe5,0xf7f4007b,0xf80580f3}},	//   _ашыг, _арык, _يسعد, _очин, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd250c578,0xdb00067c,0x62240116,0x00000000}},	// [28390] انئ_, ndmà, ھىمل, --, 
   {{0x6b9980f4,0xb33980f5,0x00000000,0x00000000}},	//   zeug, _kaçk, --, --, 
   {{0x6b98009f,0xb3780023,0x00000000,0x00000000}},	//   yeug, _ይጽውዕ_, --, --, 
   {{0xb33803e0,0xde540023,0x00000000,0x00000000}},	//   _maçk, _ዝተኸል, --, --, 
   {{0xb33800a2,0x6e640395,0x00000000,0x00000000}},	//   _laçk, фтеж, --, --, 
   {{0x6b997391,0x00000000,0x00000000,0x00000000}},	//   weug, --, --, --, 
   {{0x6b981140,0xe134eb13,0x00000000,0x00000000}},	//   teug, _анры, --, --, 
   {{0xee701219,0xb5f8032e,0x00000000,0x00000000}},	//   _аңды, fsák, --, --, 
   {{0x5ba40184,0x9f44011f,0x6b9980f6,0x06ec0037}},	//   тлығ, _ummá_, reug, _चेंव_, 
   {{0x6b980618,0xad241d0a,0xdd940022,0x08c46c00}},	//   seug, _قراو, _иауы, ебон, 
   {{0x2fdd80f7,0xfc4803b2,0x66140133,0xb06000a2}},	//   _klug_, rlíð_, ێژخا, _ýädy, 
   {{0x2fdc003e,0xb5a8002e,0xfc4803b2,0x00000000}},	//   _jlug_, _j斡fl, slíð_, --, 
   {{0x80d40073,0x98fc0115,0xb66400d1,0x00000000}},	//   _मॅने, raĉa, нияз_, --, 
   {{0x15b8247f,0x64480120,0x27000073,0x601980f8}},	//   мысы_, ídio, _उशीर_, rími, 
   {{0xb3380309,0xd4f40c98,0xf62000f3,0x2fdc013d}},	//   _kaçh, вяты, удро, _olug_, 
   {{0xe8c80073,0x601803b2,0x068400d4,0x00000000}},	//   ाहीच, pími, _згин, --, 
   {{0x27e180f9,0x42244f9b,0xb3380113,0x7778056a}},	// [283a0] _ilin_, едав, _maçh, óuxe, 
   {{0x6724bee3,0x2fdc089c,0xdb011003,0xa3e444eb}},	//   _izij, _alug_, ndmá, भोज_, 
   {{0x27e180fa,0x2fdc3e24,0x40941fe9,0xb5f801d3}},	//   _klin_, _blug_, эрат, zsák, 
   {{0x705180fb,0x8afc012c,0x75d001ec,0x00000000}},	//   اننا, zařa, _ليۋا, --, 
   {{0xfe40072d,0xb1800419,0x00000000,0x00000000}},	//   اکری, šťac, --, --, 
   {{0x2fdc0254,0x27e180fc,0xb5f803b2,0xdd94013d}},	//   _elug_, _llin_, gsáh, такы, 
   {{0x27e00d77,0x2fdd80fd,0x0c400022,0x7b643947}},	//   _olin_, _flug_, аҭхо, нтпе, 
   {{0x67242784,0x2fdd80fe,0x80252596,0x417453f0}},	//   _ozij, _glug_, _سرزم, _تاڭس, 
   {{0x20dc1682,0x67240337,0xafe00131,0x50a000cf}},	//   ḽi_, _nzij, _сотл, _مەەل, 
   {{0x27e180ff,0x32000354,0x2c540034,0x1cd0031c}},	//   _alin_, _xjjy_, _będę_, ུརད_, 
   {{0x27e18100,0xad840b38,0xcdc4023b,0x6d880432}},	//   _blin_, _سالۇ, _шафқ, _ỳagd, 
   {{0xa3b017ee,0xb33800a2,0x27e0da1e,0x00000000}},	//   _टोल_, _gaçh, _clin_, --, 
   {{0x7d18002d,0x7bc40037,0xb5f80332,0x00000000}},	//   _hyts, ökuu, lsái, --, 
   {{0x672400de,0xb5f80332,0xb8658101,0x00000000}},	//   _dzij, osái, _كابو, --, 
   {{0x6724b00f,0xe4e400d6,0xb33803f0,0x27e003cb}},	//   _ezij, гітн, _yaçh, _flin_, 
   {{0x20dc1aa1,0x27e18102,0xb5f800bc,0xb3398103}},	//   ḓi_, _glin_, zsáh, _kaçi, 
   {{0x7d180225,0x98ac4952,0xa3c401ad,0x52141c90}},	// [283b0] _lyts, madı_, _्वर_, вдат, 
   {{0x98ac4947,0x98fc01e4,0x94740330,0x2fdc50eb}},	//   ladı_, naĉo, _لگرا, _slug_, 
   {{0x27e002f6,0xb3398104,0x7d198105,0x00000000}},	//   _ylin_, _laçi, _nyts, --, 
   {{0x98ac858b,0xa0a46215,0x13a403e6,0xb19000d1}},	//   nadı_, ышул, _جۆری_, _өлмә, 
   {{0x2fdc5b5e,0x7d1844b2,0xdb003778,0xb5f803b2}},	//   _vlug_, _ayts, ldmæ, tsáh, 
   {{0x7d180a85,0x2004009b,0x0c9400a7,0x3ed0515c}},	//   _byts, _ejmi_, вшия, شقىر, 
   {{0x30180597,0xdb005266,0xb3380309,0x7d18015d}},	//   _فترة_, ndmæ, _saçh, _cyts, 
   {{0x2fdc07d6,0xb33802d1,0xae0c1d72,0x601800c0}},	//   _ulug_, _paçh, िवहन_, _зося_, 
   {{0x8ca18106,0xb3380784,0x1a68035c,0xc9558107}},	//   _कैरो, _qaçh, فینی_, ктны, 
   {{0x7d180a85,0x4e342d4b,0x9f440108,0x27e0560e}},	//   _fyts, _شفاء, _emmä_, _slin_, 
   {{0xde5402d3,0x50e000dc,0xb3398108,0x3a218109}},	//   _ዝተዳለ, पनिष, _waçh, рмэг, 
   {{0x4a941fbe,0x3d240241,0x98ac0139,0x00000000}},	//   _ајку, _wíwí_, gadı_, --, 
   {{0x21e40730,0x7d18005a,0x98fc01e4,0xd838007f}},	//   _höhe_, _zyts, baĉo, mwčl_, 
   {{0x99840133,0x6fc00073,0x8b641888,0x00000000}},	//   _ملهو, ळाडू, _ساچم, --, 
   {{0x3dc80086,0x798c0428,0x2a7c0067,0x3210045a}},	//   _òbwe_, òbwe, luub_, doxy_, 
   {{0x27e1810a,0x6f180205,0xb3380166,0x7a240d12}},	//   _ulin_, _oyuc, _zaçi, rðte, 
   {{0x6f19810b,0xd5b001fb,0x0708143e,0x2a7c0009}},	// [283c0] _nyuc, ốc_, _زيدي_, nuub_, 
   {{0x8afc01ef,0x00000000,0x00000000,0x00000000}},	//   hařo, --, --, --, 
   {{0x3d1405ba,0x2a7c0009,0x8ca000ce,0x71a00022}},	//   _पुढे_, huub_, _कैलो, рахз, 
   {{0x2a7c0fd4,0x00000000,0x00000000,0x00000000}},	//   kuub_, --, --, --, 
   {{0x7d180b21,0x32100306,0x6ad807f7,0x2a7c058a}},	//   _syts, boxy_, यनोर, juub_, 
   {{0x7d18000f,0x2a7c0014,0xd12c01d9,0x00000000}},	//   _pyts, duub_, _کۅم_, --, 
   {{0x98ac29af,0xbc040116,0x00000000,0x00000000}},	//   yadı_, кчий, --, --, 
   {{0x3d1405ba,0xb5f80597,0x3f800194,0x6f1801a9}},	//   _पुणे_, rsái, _øku_, _fyuc, 
   {{0x7d180b21,0x98ad2bf6,0x98fc01e4,0xda140120}},	//   _wyts, vadı_, taĉo, лдињ, 
   {{0x7d19810c,0xb5f824b0,0xb33806be,0x00000000}},	//   _tyts, lsáv, _qaçi, --, 
   {{0x717825f9,0x3b85810d,0xb5f80518,0xa9c000f7}},	//   וניס, _алег, práz, рсык, 
   {{0xb5f9810e,0x8ac40588,0x2a7c058a,0x00000000}},	//   nsáv, тқәа_, buub_, --, 
   {{0x98ac9d58,0x70bc072a,0x19940024,0x2a7c0009}},	//   radı_, _एप्ल, _баля, cuub_, 
   {{0x98ac0724,0x00000000,0x00000000,0x00000000}},	//   sadı_, --, --, --, 
   {{0xa9646ea9,0x98ac0205,0x00000000,0x00000000}},	//   _شميم_, padı_, --, --, 
   {{0xdb00005c,0xe6c0107d,0x98ac06be,0x00000000}},	//   rdmæ, žišć, qadı_, --, 
   {{0x241812c4,0x91b9810f,0x38680135,0x00000000}},	// [283d0] тоты_, нгат_, ġbru_, --, 
   {{0xa2943bb3,0x6f18037e,0xe1f0009a,0x00000000}},	//   рафі, _ryuc, يسل_, --, 
   {{0x94d58110,0x97340014,0x62800fac,0xdb000254}},	//   _сонц, _جکھا, _åmon, ldmä, 
   {{0x2a7d6bf9,0x00000000,0x00000000,0x00000000}},	//   yuub_, --, --, --, 
   {{0x70518111,0x9ac40003,0xdb00369a,0x8afc0118}},	//   انچا, _jiċċ, ndmä, vařo, 
   {{0x394c003b,0x6f198112,0x26dc011a,0x00000000}},	//   _nffs_, _vyuc, וקדמ, --, 
   {{0xef642c1d,0x00000000,0x00000000,0x00000000}},	//   _аъзо, --, --, --, 
   {{0xdfd4af8f,0x4aa806ed,0x00000000,0x00000000}},	//   _косы, екин_, --, --, 
   {{0xdfd576a1,0x9ac40003,0x89d402dd,0xd00801ec}},	//   _тоты, _niċċ, гінш, _жеңе_, 
   {{0x2d8004ce,0x88c816a8,0x2a7c058a,0xb9080cad}},	//   _øje_, елов_, ruub_, _ìkọ_, 
   {{0x8afc0118,0x00000000,0x00000000,0x00000000}},	//   pařo, --, --, --, 
   {{0x9ac4003d,0x27b4134b,0xdce8002b,0x00000000}},	//   _biċċ, рәкс, _uddā, --, 
   {{0xb338036e,0xaa6001e0,0x2a7c058a,0x00000000}},	//   _kaçu, _телһ, quub_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x98fc01e4,0xecb001ad,0x02040107,0x00000000}},	//   haĉj, ंटिफ, ҳзан, --, 
   {{0xea9c002b,0x00000000,0x00000000,0x00000000}},	//   ciṣo_, --, --, --, 
   {{0xc1780114,0x00000000,0x00000000,0x00000000}},	// [283e0] есец_, --, --, --, 
   {{0xe58400f7,0x764c01d3,0x00000000,0x00000000}},	//   _өтүү, őnyö, --, --, 
   {{0x0368033a,0x7fd40212,0x00000000,0x00000000}},	//   _пинк_, ліді, --, --, 
   {{0xb3c406a6,0xbe898113,0xdb00005c,0xde540023}},	//   _блюз_, еске_, ldmå, _ዝተወለ, 
   {{0x44318114,0xbec00171,0x00000000,0x00000000}},	//   mmy_, _ķīse, --, --, 
   {{0x44302a5c,0xb3380798,0x00000000,0x00000000}},	//   lmy_, _caçu, --, --, 
   {{0x44318115,0x98fc0115,0xac70104c,0xb5f803b2}},	//   omy_, taĉm, مايش, msát, 
   {{0x44318116,0x1bd4016c,0x77b800fd,0x60198117}},	//   nmy_, роия, _mäxä, ríms, 
   {{0x29740092,0x386c08a5,0x4430012d,0xaee000b8}},	//   _በአፋር_, _svfr_, imy_, _viṣo, 
   {{0x2a940491,0x79a58118,0x3f858119,0xdd00456f}},	//   ائية_, урие, lgou_, ştıl, 
   {{0x2b4c0142,0xbb841987,0xed540bb1,0x98c401c6}},	//   _ffgc_, _ملاي, _сох_, рөлж, 
   {{0x3f85811a,0x44302a5c,0xb33805d1,0x31340375}},	//   ngou_, jmy_, _kaçt, טנים_, 
   {{0xec11811b,0x3f840198,0x443000d7,0xabf8010f}},	//   _اوند, igou_, dmy_, _אפאז, 
   {{0x44300034,0x77b800fd,0xb33805d1,0x394c00d8}},	//   emy_, _bäxä, _maçt, _uffs_, 
   {{0xe2f80220,0x9ac40003,0x6574013a,0x00000000}},	//   ңесі_, _wiċċ, _řehá, --, 
   {{0x7124167e,0x9ac40003,0xdb000200,0x00000000}},	//   ۇرال, _tiċċ, jemë, --, 
   {{0xb3380139,0xd2504559,0x00000000,0x00000000}},	// [283f0] _naçt, زنا_, --, --, 
   {{0x4431811c,0x7124c665,0xba180113,0x7af402d2}},	//   amy_, هرال, pa鯵o, _þytu, 
   {{0x7988035a,0xa29401ec,0xdb000200,0xa3b002db}},	//   _mcfw, _қарі, femë, _टोक_, 
   {{0xb4c005ba,0xa34401c0,0xdb000036,0x3f8400e8}},	//   ्ही_, _гэрл, gemë, ggou_, 
   {{0x8d64230c,0xddc80030,0xc0c401a8,0x1f640006}},	//   авле, _šošo, _óánæ, скім, 
   {{0xc2780375,0xb5f801ed,0xb3380166,0xe1e40395}},	//   _ברשי, csát, _qaçu, _люсп, 
   {{0xdb00068c,0x25d800df,0x00000000,0x00000000}},	//   lemè, רוון_, --, --, 
   {{0x0b45811d,0xf0b09105,0x0c2406ed,0xd1f00092}},	//   шнин, _پیچھ, јмин, ፃዎች_, 
   {{0x4a441b6b,0xb5f80296,0x7988035a,0xdb00004e}},	//   јнов, nsás, _bcfw, nemè, 
   {{0x443148e4,0x21e40037,0x65bc01e3,0x00000000}},	//   zmy_, _köha_, _måhä, --, 
   {{0x4431811e,0x4805811f,0xdb00007f,0x15d00131}},	//   ymy_, ипов, hemè, _ﮔﯜﺯﻩ, 
   {{0xd5b001fb,0x5fc80490,0x77b800fd,0x2ca40042}},	//   ốn_, ळायल, _räxä, mwnd_, 
   {{0x2d840e14,0x77b8008e,0xe3b98120,0x26c40022}},	//   ogne_, _säxä, _ğı_, ãmo_, 
   {{0x2d840652,0x44318121,0x3f840007,0xdb018122}},	//   ngne_, wmy_, zgou_, demè, 
   {{0x2d858123,0x44301327,0x7b0c06d6,0xdb0001e3}},	//   igne_, tmy_, ṱuts, rdmå, 
   {{0x86441d0d,0x67040131,0xc7640131,0xc2080131}},	//   _книж, _гүмб, _ئاغى, ھقان_, 
  
   {{0x44302f53,0xf3458124,0xb5f98125,0xc20816a0}},	// [28400] rmy_, рпул_, tsát, پقان_, 
   {{0xc8c80316,0x44318126,0x77b80166,0x38440092}},	//   िमपट, smy_, _täxä, _ከተቀበ, 
   {{0x9d540e76,0xc10400f1,0x7578011a,0xb3380790}},	//   ەنتت, جواي, _בטיפ, _saçt, 
   {{0xb5f98127,0x03958128,0x7050035c,0x2d858129}},	//   ssát, _троя, زنها, egne_, 
   {{0x63a5812a,0x3f84617f,0xb5f843e5,0xb3380139}},	//   mein, rgou_, msár, _qaçt, 
   {{0x63a5812b,0x5ec405c2,0x3f8400d8,0xce342a9f}},	//   lein, _қизғ, sgou_, مونک, 
   {{0xec648f6a,0x3ea44471,0xdb0000c7,0x8afc01ef}},	//   арык_, swot_, memé, bařk, 
   {{0xdb00066d,0x63a5812c,0xb5f8032e,0xb338010e}},	//   lemé, nein, nsár, _gaçs, 
   {{0x6fb06bd8,0x6285812d,0x63a40112,0x5e640131}},	//   _بمقا, nuio, iein, _چۆچە, 
   {{0x63a5812e,0x3e3000dd,0xbe300137,0x98fc01e4}},	//   hein, _بہتر, _بۉتب, laĉi, 
   {{0xce3407d6,0x77780077,0x00000000,0x00000000}},	//   _اولک, óuxo, --, --, 
   {{0x6284949e,0xab8028a8,0xdb000036,0x75e8008e}},	//   kuio, _душк, hemé, _küzg, 
   {{0x7bc1812f,0x34dc0882,0xdb0001ed,0x67d401e1}},	//   _inou, नन्द, kemé, _ọlám, 
   {{0x63a58130,0x62858131,0xdb000098,0x7bc001ef}},	//   eein, duio, jemé, _hnou, 
   {{0xb4c07e29,0x65bc01e6,0x7bc00036,0x80a405f9}},	//   ्हे_, _såhä, _knou, _टैले, 
   {{0xe3b019db,0x62840607,0x65bc01e3,0xb5f8c469}},	//   ورق_, fuio, _påhä, tsás, 
   {{0xe61000ec,0x66e4009b,0x00000000,0x00000000}},	// [28410] _ڪشي_, _моћа, --, --, 
   {{0xf484084c,0xf1a40e92,0xb5f800e4,0xb338496e}},	//   _кумн, јран, asár, _saçs, 
   {{0x63a40eef,0x7bc18132,0xdb003040,0xa5d8007b}},	//   bein, _onou, semè, _خبير_, 
   {{0x63a420ef,0x5f740597,0xac74001f,0x7bc0007f}},	//   cein, قاهر, _አክሱም_, _nnou, 
   {{0xa3bc05f9,0xf1a4147e,0x1ea815eb,0x00000000}},	//   _आफत_, _крвн, لاوي_, --, 
   {{0x75e85556,0x7bc18133,0xa1850436,0x0ae801b9}},	//   _düzg, _anou, _мысл, ғдой_, 
   {{0x2d858134,0x00000000,0x00000000,0x00000000}},	//   rgne_, --, --, --, 
   {{0x91440259,0x00000000,0x00000000,0x00000000}},	//   şığı_, --, --, --, 
   {{0x75e98135,0xed88004e,0x00000000,0x00000000}},	//   _küzd, _асек_, --, --, 
   {{0x63a58136,0xb9e40046,0x7bc03f49,0x49c80107}},	//   zein, ймыз_, _enou, улон_, 
   {{0xea2005f5,0x34b04c3d,0x63a58137,0x75e84dd9}},	//   йчүү, ुमोद, yein, _müzd, 
   {{0x7bc005d5,0x63a40077,0xdb0001ed,0xd7c800f1}},	//   _gnou, xein, zemé, لوپه_, 
   {{0x63a403c1,0x5fc80073,0x7e9800b8,0x8afc01ef}},	//   vein, ळातल, cāpā, kaři, 
   {{0x63a58138,0xec1001d5,0x00000000,0x00000000}},	//   wein, _اوچد, --, --, 
   {{0x8afc012c,0x00000000,0x00000000,0x00000000}},	//   daři, --, --, --, 
   {{0x62847dcd,0x2a7c00e8,0x601400a2,0x63a4045a}},	//   tuio, orub_, _kümş, uein, 
   {{0xb5f80261,0xdb0001ed,0x75e82b24,0x601400a2}},	// [28420] rsár, temé, _büzd, _jümş, 
   {{0xb5f98139,0x05a84f35,0x45849af2,0x75e805d1}},	//   ssár, _свой_, _угов, _rüzg, 
   {{0x63a5813a,0x75e878a3,0xdb0001ed,0x62840311}},	//   pein, _süzg, remé, suio, 
   {{0x69c00165,0x7ee4010b,0xd01800d4,0xdb0000e5}},	//   _lnne, йцле, афі_, semé, 
   {{0x69c1813b,0x6285813c,0x52740234,0x7bc00100}},	//   _onne, quio, _муру, _rnou, 
   {{0x7bc1813d,0x75e806be,0x52640150,0x00000000}},	//   _snou, _güzd, _ферғ, --, 
   {{0x27040d54,0xa3cc0316,0xb338010b,0x70900107}},	//   रपुर_, लाप_, _haçp, _наёф, 
   {{0x69c1813e,0x91440c02,0x645c3199,0x75e80139}},	//   _anne, ğışı_, ipri, _tüzg, 
   {{0x75e80365,0xdb002188,0xb338003a,0xfe5401d5}},	//   _yüzd, ndmø, _jaçp, _ایتب_, 
   {{0xd9103737,0x69c00789,0x645d813f,0xee343849}},	//   ویش_, _cnne, kpri, _гну_, 
   {{0x645c70b1,0x23600196,0xbb240150,0xe7c401f9}},	//   jpri, kbij_, _ﹼﺎﻩ_, षांप, 
   {{0x645c0724,0xa3cc09fd,0x7bc0006f,0xf7e80a52}},	//   dpri, लाफ_, _unou, اردى_, 
   {{0xa3cc47b8,0x2a7c0c6a,0x00000000,0x00000000}},	//   लान_, crub_, --, --, 
   {{0x645d3238,0xa2cc00dc,0x63a00139,0x00000000}},	//   fpri, समन्, _ımna, --, 
   {{0x645c0726,0x506c01ec,0x1cb0031c,0x0f04033f}},	//   gpri, _ءﺍﻟﻰ_, _ྟགས_, _शख्स_, 
   {{0xb5f800c7,0x75e85656,0x00000000,0x00000000}},	//   asáp, _süzd, --, --, 
   {{0x29080311,0x69c03602,0x00000000,0x00000000}},	// [28430] şcat_, _ynne, --, --, 
   {{0x645d8140,0xb338afeb,0x75e80139,0x6fc800c5}},	//   bpri, _qaçq, _qüzd, _सचहू, 
   {{0x645c4663,0x644800d7,0x00000000,0x00000000}},	//   cpri, ídit, --, --, 
   {{0x75e90fe6,0x21e40036,0x00000000,0x00000000}},	//   _düze, _höhl_, --, --, 
   {{0x0f342a60,0x22858141,0xf41c6c0f,0x91800131}},	//   زکرد, _нург, _ikä_, _يۇرۇ, 
   {{0x271807ae,0x75e8b748,0xd838007f,0x00000000}},	//   ọng_, _füze, rvčy_, --, 
   {{0x75e8079d,0x66fc1d76,0x50ac4a01,0x21e400a2}},	//   _güze, mākū, _घनिष, _möhl_, 
   {{0xa9f04802,0x5f9428cf,0xa3cc00a5,0x95140055}},	//   ेच्छ_, _нист, लाय_, _aṅko, 
   {{0xb33803b9,0x6ee4007b,0xb5f80022,0x00000000}},	//   _xaçp, _اسأل, ysáp, --, 
   {{0x645d8142,0x75e803ee,0x2b5c054e,0x999c013a}},	//   ypri, _yüze, sbuc_, _divů_, 
   {{0x645c0f64,0x07a40354,0x69c00051,0x00000000}},	//   xpri, оанн, _vnne, --, 
   {{0x645c21e3,0x6560016b,0x00000000,0x00000000}},	//   vpri, ɔmhy, --, --, 
   {{0x645c7baa,0xb5f800d2,0xd5b80327,0xa80400cf}},	//   wpri, tsáp, _བལྡག, _ۉكتۉ, 
   {{0x69c18143,0x5edc04c5,0xf41c00c7,0x0444b89d}},	//   _unne, _মেডে, _akä_, жевн, 
   {{0x23600196,0x645c0165,0x00000000,0x00000000}},	//   tbij_, upri, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x23600460,0x42c8006c,0xc1741b06,0xa3cc3e63}},	// [28440] rbij_, шган_, قدات, लाब_, 
   {{0xf77caa4a,0x645d8144,0xf6500302,0x6724019f}},	//   rkçe_, ppri, _קצת_, _iyij, 
   {{0x80a41158,0x3978008f,0x2bbc0b67,0x75e806be}},	//   تمان, שטענ, _शोभा, _qüze, 
   {{0x7ee425aa,0x3898008f,0x64480115,0xb89800df}},	//   يكان, ייענ, ŭdis, יבעש, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x22958145,0x661c1897,0x75e98146,0x61300332}},	//   mäk_, nork, _tüze, _cólí, 
   {{0x22958147,0x75e8083c,0x6da00e92,0x6724005b}},	//   läk_, _yüzb, фија, _lyij, 
   {{0x9ad43252,0x67258148,0x00000000,0x00000000}},	//   зжич, _oyij, --, --, 
   {{0x661d8149,0x229400fd,0x79a40408,0x6130032e}},	//   kork, näk_, орне, _fólí, 
   {{0x661d814a,0xed600064,0x5edc00eb,0x7de40244}},	//   jork, gožė_, _মেথে, _بسرم, 
   {{0x6725814b,0xf2dc0016,0xdb0000e4,0xa2a0013a}},	//   _ayij, _ngân_, memí, děčů_, 
   {{0x67240223,0x26c401e4,0x2294010e,0x00000000}},	//   _byij, ĥmon_, käk_, --, 
   {{0x672400ca,0x661d814c,0xeb940a31,0xab24030d}},	//   _cyij, fork, _фич_, _доца_, 
   {{0x661d814d,0x21e40b8b,0x995800d7,0x2294013d}},	//   gork, _böhm_, báši_, däk_, 
   {{0x672401b3,0x94d40395,0x00000000,0x00000000}},	//   _eyij, човц, --, --, 
   {{0x61fc022e,0x661c000d,0x2294013d,0x00000000}},	//   _amrl, aork, fäk_, --, 
   {{0x661d814e,0xa3bc02e5,0x2cc80241,0xb3380166}},	// [28450] bork, _आफर_, _ḿmọ_, _obçe, 
   {{0x661c4694,0x75e805d1,0xcc9000b8,0x98fc0115}},	//   cork, _düzc, _kṛtu_, saĉu, 
   {{0xdb01814f,0x90982bb6,0xe78400f2,0x6448008f}},	//   demí, свет_, _علیپ, ŭdir, 
   {{0x22940724,0x60d80267,0x4fd4005b,0x61fc06be}},	//   bäk_, ävma, яжет, _emrl, 
   {{0xcfcc1c82,0x9e6400d6,0x61fc00db,0x66fc02b5}},	//   লসলন, двід, _fmrl, pākū, 
   {{0xb5f80005,0x9d440092,0x4338011a,0x00000000}},	//   lpáb, _ራሳችሁ, _לערב, --, 
   {{0xefc8013d,0x38b80055,0x00000000,0x00000000}},	//   _куак_, _nīr_, --, --, 
   {{0xdb000311,0xce9402e8,0x6eb01cd2,0x680400e5}},	//   demâ, _набъ, _इनपु, ződb, 
   {{0x81ac0d42,0xa3cc5345,0x661d8150,0x1a68036b}},	//   কার_, लात_, york, قینی_, 
   {{0x661c4f40,0x67258151,0x09c800eb,0x00000000}},	//   xork, _ryij, ষস্থ, --, 
   {{0x661d8152,0xe6b4008e,0xed600064,0x00000000}},	//   vork, _küçä, rožė_, --, 
   {{0x661d8153,0x9f4419f5,0x799804e6,0xd8380100}},	//   work, _immò_, aftw, dwčs_, 
   {{0xdce8012c,0x6b9802c4,0xe6b400a2,0x2618012d}},	//   _oddě, mfug, _müçä, पकली_, 
   {{0x6b982b96,0x00000000,0x00000000,0x00000000}},	//   lfug, --, --, --, 
   {{0x661d8154,0x6b980083,0x99d4007b,0x00000000}},	//   rork, ofug, _تتنا, --, 
   {{0x661c009b,0x6b998155,0xdb000c5e,0x00000000}},	//   sork, nfug, zemí, --, 
   {{0x661d1eec,0x67240513,0x6b9877ae,0xa2cc0073}},	// [28460] pork, _uyij, ifug, समध्, 
   {{0x22940598,0x661c01d9,0xb220f0be,0x73300c50}},	//   räk_, qork, емул, رىلا, 
   {{0x81ac2f8b,0x85041b06,0xa3cc03ce,0xdb0000e4}},	//   কাল_, _روحن, लाद_, vemí, 
   {{0x22940227,0xdfd01d57,0x8afc00bc,0x3d14012c}},	//   päk_, ضيت_, nařs, _पुगे_, 
   {{0x44203774,0x2bbc0490,0xdb0098a0,0x00000000}},	//   _ikk_, _शोधा, temí, --, 
   {{0x442001a6,0x6b980083,0x75e8008e,0xb5f802f0}},	//   _hkk_, efug, _küza, mpác, 
   {{0x64598156,0x8afc012c,0xd5b0004d,0x6b980381}},	//   _évid, kařs, ối_, ffug, 
   {{0x75e80cc1,0x26c048d4,0xbe0400dd,0x442131c8}},	//   _müza, _orio_, _کوئٹ, _jkk_, 
   {{0x5a353046,0xf2dc0142,0xbe640ccb,0xd9d00154}},	//   мнит, _ngâl_, _رهاي, িসসম, 
   {{0x62840006,0x7c64764c,0x44200115,0x6b99134b}},	//   irio, _فاصل, _lkk_, afug, 
   {{0x26c18157,0x62858158,0xdb0075ee,0x00000000}},	//   _ario_, hrio, ldmü, --, 
   {{0x442003cd,0x62840115,0x7a2403b2,0x59bc00bc}},	//   _nkk_, krio, iðti, ्ञहर, 
   {{0x7c200516,0x26c18159,0xdb01815a,0xdce80010}},	//   _ikor, _crio_, ndmü, _medč, 
   {{0x6285815b,0x7c20030a,0xb900015b,0x26c0015d}},	//   drio, _hkor, _নই_, _drio_, 
   {{0x26c0014b,0x6285815c,0x7c21815d,0xa998011a}},	//   _erio_, erio, _kkor, _הבור, 
   {{0x26c12b0b,0x6285815e,0x9f44008e,0x97540055}},	//   _frio_, frio, _almí_, _aṇva, 
   {{0x4421815f,0x7c2001c8,0x5edc015b,0xf1a413f3}},	// [28470] _dkk_, _mkor, _মেসে, зрен, 
   {{0xda0c2d8f,0x98b00316,0x442002d2,0xdb0003b2}},	//   िचित_, _जनाए, _ekk_, ldmó, 
   {{0x628428f2,0x7c218160,0x4420c537,0x75e86cba}},	//   ario, _okor, _fkk_, _güza, 
   {{0x7c218161,0x09a800dc,0xa3b800cd,0xa854123b}},	//   _nkor, _कस्य, चयः_, פידה_, 
   {{0xf3fc0120,0x62858162,0x6b98bc85,0x00000000}},	//   _imã_, crio, vfug, --, 
   {{0x5edc00bd,0x6ab98163,0xf07400fd,0x200c0241}},	//   _মেহে, vvuf, _нигә_, _ìdin_, 
   {{0x6234084c,0x611410f3,0x7c540372,0x6b98ec52}},	//   _черу, _здру, ولور_, tfug, 
   {{0x7c201529,0x6458004a,0x4420022e,0x25b80010}},	//   _ckor, _évie, _xkk_, zdrl_, 
   {{0x628008fb,0x161c0a8a,0x00000000,0x00000000}},	//   _åmot, पकार_, --, --, 
   {{0x7c218164,0xf2dc01fb,0x89a80139,0x00000000}},	//   _ekor, _ngâm_, цков_, --, 
   {{0x6b98006f,0xdb0000d8,0x6284030a,0xc170011a}},	//   pfug, temã, zrio, כחי_, 
   {{0x7c200165,0x26c0134a,0x62841e6e,0x29080356}},	//   _gkor, _prio_, yrio, ăca_, 
   {{0xa3cc0412,0x3580001f,0x24840092,0xab2800ae}},	//   लास_, _ክምችት_, _ኬክሮስ_, _اسال_, 
   {{0x62840dd4,0xf3fc0589,0x442001f1,0xfaa18165}},	//   vrio, _amã_, _skk_, _рашо, 
   {{0xb9002158,0x44200ba5,0x628403cb,0xf1640116}},	//   _নে_, _pkk_, wrio, _ﺷﯘﻏﯘ, 
   {{0xdb018166,0x26c18167,0x62858168,0xdc1006be}},	//   lemá, _trio_, trio, _məğf, 
   {{0xc2458169,0x6285816a,0x26c008f0,0xdce80427}},	// [28480] днак, urio, _urio_, _redč, 
   {{0xa3cca432,0x6285816b,0x442001f5,0x75e81432}},	//   लाह_, rrio, _wkk_, _hüzn, 
   {{0x75e80166,0x442001f4,0xb5f80022,0x00000000}},	//   _küzn, _tkk_, spác, --, 
   {{0x81ac2158,0xf3fc0589,0x4421816c,0x5f780014}},	//   কাই_, _gmã_, _ukk_, سمتس_, 
   {{0xa28404fb,0x83200124,0x3d140037,0x9f4400d7}},	//   _سیاو, _рҿаҧ, _पुजे_, _tlmí_, 
   {{0x00840323,0xa3cc068f,0xfd44009d,0x00000000}},	//   _олго, लाव_, мэйн, --, 
   {{0x212c007b,0xbfa801d9,0x00000000,0x00000000}},	//   _ádh_, _وارٕ_, --, --, 
   {{0xdb01816d,0x1ab5816e,0x8fd40139,0xefdc0092}},	//   temà, ебия, _пәчә, ናቀው_, 
   {{0x34a808dd,0x7c200010,0xbe1410e0,0x2bdc000d}},	//   _चन्द, _vkor, _قورع, _फकरा, 
   {{0x7e61816f,0x21e404cc,0xd8f80212,0x3948005c}},	//   mpop, _böhi_, зної_, øbs_, 
   {{0xf1b00375,0xd7940395,0x888001e2,0x00000000}},	//   דסת_, нинъ, هیون, --, 
   {{0x7c218170,0x7e6033db,0x390400f7,0xac9400f2}},	//   _ukor, opop, здүү_, _زنها_, 
   {{0x7e60d3d3,0x6bd42cc0,0xe7f005d7,0x7b6401ee}},	//   npop, _تونس_, _चतरा_, _етһе, 
   {{0x7e6001c8,0x39080153,0xdc280345,0x00000000}},	//   ipop, _мэйн_, _بسڕه_, --, 
   {{0x21e400a2,0xa5040006,0x41d01be1,0x00000000}},	//   _göhi_, вятл, सानस, --, 
   {{0x29340a7c,0x7e600010,0x3d140037,0x6848007f}},	//   _קאהן_, kpop, _पुछे_, rèdè, 
   {{0x7e612a51,0x00000000,0x00000000,0x00000000}},	// [28490] jpop, --, --, --, 
   {{0x7e600175,0x00000000,0x00000000,0x00000000}},	//   dpop, --, --, --, 
   {{0xdec8044e,0xa3cc166d,0x00000000,0x00000000}},	//   _ኾይኑ_, लाश_, --, --, 
   {{0x9e840020,0xb2700daf,0x92ac00fe,0x00000000}},	//   _አውሮፓ_, _икмә, _কপী_, --, 
   {{0xa3cc02e5,0x7e6013a4,0xf9f8025c,0xdb00d02e}},	//   लार_, gpop, ྒྲོན_, lemæ, 
   {{0xa2cc0e85,0x64580129,0x8cb402e8,0xf1a80345}},	//   समर्, _évic, есич, _باحه_, 
   {{0xdb0000b5,0x7e6000c7,0xa1941c56,0x00000000}},	//   nemæ, apop, _шарч, --, 
   {{0x7e60045a,0x00000000,0x00000000,0x00000000}},	//   bpop, --, --, --, 
   {{0xdb002cd7,0x8e140153,0x00000000,0x00000000}},	//   temá, _здац, --, --, 
   {{0x7c3c0006,0x75e8008e,0x00000000,0x00000000}},	//   įpra, _süzn, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x1cb80150,0xdb018171,0x0cbc694b,0x00000000}},	//   _زامب_, demæ, ्मीम, --, 
   {{0x6d4400dd,0xf7701178,0xaae4ef10,0xdec80023}},	//   _újab, داپ_, _تساو, _ኾይና_, 
   {{0x8458023b,0xc89400f3,0x00000000,0x00000000}},	//   зрат_, _зрињ, --, --, 
   {{0xa3cc00e1,0x07a52fa0,0xb218143a,0x03a401a9}},	//   लाल_, _зайн, _kvæf, ниво, 
   {{0x7e600334,0xd72002e3,0x3d0000af,0xb33800a2}},	//   ypop, ụrịr, _वइसे_, _haçy, 
   {{0xb6a00220,0xb5f82942,0x75e800fd,0x7e600175}},	// [284a0] _биыл, mpán, _küzl, xpop, 
   {{0xd5b00208,0xdb0001bf,0x7e600455,0xdce80171}},	//   ốt_, bemæ, vpop, _ledā, 
   {{0x7f851386,0xc22001ed,0xb33800a2,0xdb0001bf}},	//   فلان, نکڑو, _maçy, cemæ, 
   {{0x7e6001f5,0xddc8007f,0xb3380432,0xdce824b8}},	//   tpop, _zidň, _laçy, _nedā, 
   {{0xdd958172,0x2bd007b7,0x3f98068f,0x00000000}},	//   валы, थाना, ępu_, --, 
   {{0x7e618173,0xce3400f1,0xed4c0345,0x00000000}},	//   rpop, نونک, مپه_, --, 
   {{0x3f683117,0x1cd80156,0x7e618174,0x7c6401b9}},	//   _ниво_, ོདེ_, spop, راثل, 
   {{0xa2c5306e,0xdce800b8,0xdd900131,0x7c780092}},	//   रिप्, _cedā, _چۈش_, _ሲደረግ_, 
   {{0xa3e819e5,0x8fd40352,0x6bd000f7,0x00000000}},	//   _भवन_, _шәфә, اتىر, --, 
   {{0x6d540bc9,0x81ac02f5,0xf65c01a8,0x7e740153}},	//   ñxat, কাক_, lvæg_, šyps, 
   {{0x75e87b37,0xbb486b73,0x00000000,0x00000000}},	//   _düzl, _فلان_, --, --, 
   {{0xc02c01dc,0xf65c01bf,0x4cd800fe,0xdb0001bf}},	//   _điều_, nvæg_, _ভেকু, vemæ, 
   {{0xf9f80327,0x41b000dc,0x680400e5,0x00000000}},	//   ྒྲུན_, ीयास, pődn, --, 
   {{0xa2c49201,0xb33800ee,0x75e80205,0xdb0001bf}},	//   रिन्, _gaçy, _güzl, temæ, 
   {{0xb4c98175,0xa3cc28b8,0xf8700150,0xe4b403e6}},	//   लमे_, लां_, _حۇجج, ۆڤێک, 
   {{0xc5ec00aa,0x795004d3,0xdb00037e,0x3dc0013f}},	//   مړۍ_, _جێگا, remæ, _ɔkwa_, 
   {{0x75e87a36,0x05b401d5,0x97140395,0x00000000}},	// [284b0] _yüzl, رگیت_, _шмиц, --, 
   {{0xf5698176,0xa19400fd,0x356860a1,0xd70c0073}},	//   _эшик_, лауч, _эрин_, सपीठ_, 
   {{0xdb018177,0xede000c7,0x00000000,0x00000000}},	//   lemä, қәаҟ, --, --, 
   {{0xa3cc09b4,0xa4940014,0xe500258d,0xa3d4004e}},	//   लाः_, _حیٲت, ोपरि_, _боюч, 
   {{0xdb000f23,0x00000000,0x00000000,0x00000000}},	//   nemä, --, --, --, 
   {{0xb21808a5,0xdce800de,0x00000000,0x00000000}},	//   _svæf, _sedā, --, --, 
   {{0xdb0000c5,0xef901888,0xdce800de,0x7d1c0205}},	//   hemä, _میاد, _pedā, üpsp, 
   {{0xdb00049b,0x75e80598,0xdfd400fd,0xc60c2d6b}},	//   kemä, _süzl, _йосы, _सद्य_, 
   {{0x5ba46f78,0xdce80882,0x2bd000bc,0x00000000}},	//   улығ, _vedā, थाबा, --, 
   {{0xad2424e0,0x3ea001e6,0x75e82057,0xdb018178}},	//   _كراو, _äkta_, _büzm, demä, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf8ac9c96,0x75e98179,0x386c0b88,0x2fdc0129}},	//   تکه_, _düzm, _dwfr_, _joug_, 
   {{0x26c40316,0xdb00b83f,0x2fdc0165,0xb5f800bc}},	//   ímo_, gemä, _moug_, rpán, 
   {{0xb5f83a6c,0xca240075,0x6e21817a,0x2fdd817b}},	//   spán, ﻠﯩﺶ_, nonb, _loug_, 
   {{0xb5f808de,0x26c400df,0x00000000,0x00000000}},	//   mpál, ŭmo_, --, --, 
   {{0x6e20014f,0xa3cc0316,0xdb00000d,0x07a400f3}},	//   honb, लाइ_, bemä, _раин, 
   {{0x6e21817c,0xc8c8105d,0x42250261,0x2398013a}},	// [284c0] konb, _روکن_, вдав, _nějž_, 
   {{0xa2c40034,0xc4e4036b,0x75e805d1,0x6e21817d}},	//   रिब्, _ажой, _yüzm, jonb, 
   {{0x27e1817e,0x2fdc0585,0x6e21817f,0x845c0023}},	//   _koin_, _boug_, donb, ታቶምን_, 
   {{0x27e18180,0xdb0048a1,0xdd1c0306,0x6e200175}},	//   _join_, lemå, _náši, eonb, 
   {{0x6e218181,0x27e18182,0xf65c005c,0x2fdd8183}},	//   fonb, _moin_, rvæg_, _doug_, 
   {{0x6e218184,0x27e020ef,0xdb0012e8,0xdd940124}},	//   gonb, _loin_, nemå, уакы, 
   {{0x9ca404a9,0xb5f936d2,0xac801de6,0xdb0001e3}},	//   اشتۇ, dpál, ңгәл, ndmö, 
   {{0x27e00664,0xeb9430ba,0x2fdc007f,0x6ce002bf}},	//   _noin_, вић_, _goug_, ріше, 
   {{0x6e2000b5,0xbf100032,0x75e841bb,0xafe11b52}},	//   bonb, _әүҙә, _düzj, _тотл, 
   {{0xee3405f5,0x27e003d5,0xdb018185,0xada01d0f}},	//   _ану_, _aoin_, jemå, _вафл, 
   {{0xdb0048a1,0x27e0022e,0xfbd04028,0xad8404b3}},	//   demå, _boin_, _پتا_, _جاقۇ, 
   {{0x81ac045e,0xdb018186,0x27e0e6fa,0xf7718187}},	//   কাট_, temä, _coin_, گاھ_, 
   {{0xa3cd8188,0xb4c80882,0xb21801bf,0xdecc010c}},	//   लाई_, लम्_, _uvæg, በብኩ_, 
   {{0x27e0047c,0xd1cc001f,0xdb018189,0x75e8415b}},	//   _eoin_, ጡበት_, remä, _tüzm, 
   {{0x27e1818a,0x1cb0025c,0x5214013e,0xdb01818b}},	//   _foin_, _ཟགས_, ҳдат, semä, 
   {{0xded40020,0x27e03d19,0xe41400d6,0x5eb80154}},	//   ካሁን_, _goin_, адсь, _আপনে, 
   {{0x52140166,0x64585f5e,0x6e20628c,0xe3b0007b}},	// [284d0] гдат, _évin, yonb, غرف_, 
   {{0x2004011f,0x27e0005a,0xb5f002dd,0xa3cc28fe}},	//   _ammi_, _zoin_, _түгі, लाउ_, 
   {{0x21a410f5,0x27e000ad,0x6e2001a9,0x3d00012d}},	//   риєм, _yoin_, vonb, _वेले_, 
   {{0x28c0185d,0xb5f91a6d,0x27e0022e,0x00000000}},	//   षिति, zpál, _xoin_, --, 
   {{0x6e21818c,0x2fdc0165,0xde580212,0x0cbc4a76}},	//   tonb, _voug_, вачі_, ्म्म, 
   {{0xdea4036b,0x78a802d0,0x00000000,0x00000000}},	//   شیمی, _opfv, --, --, 
   {{0x6e20016b,0xa0b9818d,0xdce80356,0x64480165}},	//   ronb, _игру_, _redă, ïdig, 
   {{0xa3cc2982,0x9c480150,0x00000000,0x00000000}},	//   लाए_, _ﺗﺎﻧﯟ_, --, --, 
   {{0x6e21818e,0x0a48e2cc,0x27e1818f,0x7d1803ac}},	//   ponb, нзий_, _roin_, _exts, 
   {{0xfe6c168d,0xa2c4085c,0x27e18190,0xd70c033f}},	//   _رگه_, रित्, _soin_, सपैठ_, 
   {{0x27e18191,0xdb013221,0x9f440139,0x81ac00fe}},	//   _poin_, vemå, _elmä_, কাচ_, 
   {{0xa6840075,0xb5f81aa9,0x00000000,0x00000000}},	//   аһид, spál, --, --, 
   {{0x27e10c23,0x7a2401a8,0xb5f82af5,0xdb0003cd}},	//   _voin_, rðtr, apám, temå, 
   {{0x7a78011a,0x00000000,0x00000000,0x00000000}},	//   _טרנס, --, --, --, 
   {{0xdb018192,0x94793d00,0xb99000cf,0x128c0023}},	//   remå, ксту_, _الىب, _ንርከብ_, 
   {{0xdb0155f0,0x6f1800ac,0x42d40111,0x65dc0150}},	//   semå, _oxuc, лізу, _ﺀﺗﯩﻠ, 
   {{0xb5a8002e,0x0708007b,0x00000000,0x00000000}},	// [284e0] _c斡sl, _سيدي_, --, --, 
   {{0x3c3802d3,0x7648ff09,0x2004014b,0xf2dc0051}},	//   mëve_, _égyp, _smmi_, _ngâu_, 
   {{0x3c38044e,0x515430af,0xd33c01e4,0xbfa98193}},	//   lëve_, ртуу, _lasʈ, етле_, 
   {{0xa2c41a2a,0x41d000dc,0x00000000,0x00000000}},	//   रिद्, साहस, --, --, 
   {{0x63a58194,0x3c38044e,0x7e28dbe2,0x4da40154}},	//   mfin, nëve_, ніка_, _গোধূ, 
   {{0xdcb03ee0,0xa3cc49f1,0x6d88010e,0xb5f800e4}},	//   قىت_, लाक_, _ỳard, ypám, 
   {{0x63a58195,0x3c3802d3,0x5edc00fe,0x21e4002f}},	//   ofin, hëve_, _মেখে, _föhr_, 
   {{0x3c38044e,0x20058196,0x63a46937,0x41740137}},	//   këve_, _ummi_, nfin, _جاڭس, 
   {{0x3c3802d3,0xef1407d6,0xefb0dd80,0x63a401a8}},	//   jëve_, _бмт_, _دینگ, ifin, 
   {{0x3c3802d3,0x7d18010a,0x21e403e3,0x62880171}},	//   dëve_, _txts, _zöhr_, _ādol, 
   {{0xbc6501a1,0x2bbc07b7,0xbd0002f0,0xa9c00209}},	//   _свек, _शोका, _šéfu, ссык, 
   {{0x63a416a3,0x3c380240,0xb5f802f0,0x8ac400c7}},	//   jfin, fëve_, rpám, уқәа_, 
   {{0x6b7825f9,0x5eb809bd,0x3c3802d3,0x8b640131}},	//   _טראנ, _আপডে, gëve_, _ئامم, 
   {{0x63a58197,0xdcf80139,0x00000000,0x00000000}},	//   efin, levı, --, --, 
   {{0xa96426c0,0x81d8015b,0xdb000254,0x00000000}},	//   _صميم_, ়সা_, rdmõ, --, 
   {{0x75e80365,0xa3cc0bb2,0x18a40184,0x3c380023}},	//   _müzi, लाग_, _баҫм, bëve_, 
   {{0x9174889a,0xf4a002d3,0xfba40882,0x92951938}},	// [284f0] игац, _ምፍላጥ_, क्यम, разц, 
   {{0x395c1570,0x63a58198,0xba900873,0x00000000}},	//   ncts_, afin, _ﻛﻪﻟﮕ, --, 
   {{0x387c0b70,0xa3cc0709,0x8ee000cc,0x00000000}},	//   nstr_, लाख_, _মেংগ, --, 
   {{0x844400aa,0x4e9401d5,0x387c0042,0x00000000}},	//   _پخپل, لشتر, istr_, --, 
   {{0x6b4855e1,0x387c6144,0xa5d948f1,0x644806af}},	//   _mögü, hstr_, _شبیر_, ïdie, 
   {{0xc0c80092,0xdcf800c0,0x00000000,0x00000000}},	//   _በሁሉ_, ngvė, --, --, 
   {{0x3c380023,0xc2100375,0x387c7198,0x75e806be}},	//   zëve_, _והם_, jstr_, _cüzi, 
   {{0xca8405f5,0x999008a4,0x387d515e,0x75e89c11}},	//   агий, _čaši_, dstr_, _düzi, 
   {{0x7a3c0118,0x00000000,0x00000000,0x00000000}},	//   _oště, --, --, --, 
   {{0x88c809ac,0x8a058199,0x3c380023,0x63a407c5}},	//   влов_, рзое, vëve_, zfin, 
   {{0x387c0502,0x63a5819a,0x6b488021,0x5ba802dd}},	//   gstr_, yfin, _bögü, _әкім_, 
   {{0x3c38044e,0x5edc009e,0x00000000,0x00000000}},	//   tëve_, _মেটে, --, --, 
   {{0xaa646193,0xaa6000cf,0x387c05c7,0xe604010b}},	//   _стек, _انتۉ, astr_, йҗин, 
   {{0x3c38069c,0x15b96a49,0x7ae552bb,0x387c010a}},	//   rëve_, лысы_, äkte, bstr_, 
   {{0x387c030d,0x3c380023,0x8afc013a,0x00000000}},	//   cstr_, sëve_, dbři, --, 
   {{0x4aa845bf,0x6b4851bb,0x2b5c0113,0x63a406af}},	//   _कहाव, _gögü, ncuc_, ufin, 
   {{0x63a5819b,0x2a7d819c,0xc1540640,0x3c380240}},	// [28500] rfin, nsub_, ањењ, qëve_, 
   {{0xd8380100,0x266800cf,0x7678011a,0x00000000}},	//   ntčn_, _ичүү_, _שטיח, --, 
   {{0xe058114f,0x00000000,0x00000000,0x00000000}},	//   ایرت_, --, --, --, 
   {{0x657d819d,0x2a7d819e,0xbe895d25,0xa3cc012d}},	//   larh, ksub_, вске_, लाओ_, 
   {{0x4431819f,0xfe440364,0x644581a0,0x245c00e5}},	//   mly_, андо, mmii, _hím_, 
   {{0x657d81a1,0x443181a2,0xee3581a3,0x644581a4}},	//   narh, lly_, анч_, lmii, 
   {{0xa2c48bb5,0x645c01e0,0x644581a5,0x657c0472}},	//   रिव्, nqri, omii, iarh, 
   {{0x657c07a9,0x443181a6,0x23600219,0x64440e14}},	//   harh, nly_, ncij_, nmii, 
   {{0x657d81a7,0x443181a8,0x644581a9,0xdb0021e3}},	//   karh, ily_, imii, nemø, 
   {{0x2c0830c0,0x443181aa,0x23600007,0x387cb188}},	//   _یعنی_, hly_, hcij_, tstr_, 
   {{0x245c0232,0x387d81ab,0x657d81ac,0x236009a8}},	//   _ním_, ustr_, darh, kcij_, 
   {{0x2a7c2819,0xfaa581ad,0x387d81ae,0xddc00213}},	//   bsub_, _вадо, rstr_, _yumş, 
   {{0x443181af,0xdb0005ac,0xb35403e6,0x657d81b0}},	//   dly_, jemø, ییدا_, farh, 
   {{0x657d81b1,0x387c010a,0x644581b2,0x245d81b3}},	//   garh, pstr_, emii, _bím_, 
   {{0x245c00dd,0x28f4023a,0x68e0036b,0x680401d3}},	//   _cím_, _вещь_, _мўъж, ződi, 
   {{0x443009a5,0x5edc009e,0x00000000,0x00000000}},	//   gly_, _মেছে, --, --, 
   {{0xd25181b4,0xa2c41944,0xdb000212,0x69c80490}},	// [28510] سنا_, रिष्, gemø, _थोडी, 
   {{0x443181b5,0xfba40882,0x644581b6,0x32040109}},	//   aly_, क्तम, amii, òny_, 
   {{0x443181b7,0x2b5c0051,0x00000000,0x00000000}},	//   bly_, ycuc_, --, --, 
   {{0xa2c4ffeb,0x44303d4a,0xfba402a0,0x64440067}},	//   रिश्, cly_, _कॉलम, cmii, 
   {{0x228581b8,0xb3380139,0xbf7002dd,0xed540e46}},	//   _мург, _obçi, яқты, қоқ_, 
   {{0x2a7c0334,0x00000000,0x00000000,0x00000000}},	//   vsub_, --, --, --, 
   {{0xa3cc0574,0x2bd000bc,0x2a7c002e,0x00000000}},	//   लाच_, थाला, wsub_, --, 
   {{0x5f9581b9,0x2a7d81ba,0xd1f00020,0xddc0010e}},	//   _мист, tsub_, ጃዎች_, _tumş, 
   {{0x1cd803bd,0x657d81bb,0xb5f815b0,0xc954008e}},	//   ོདཔ_, yarh, apái, йтны, 
   {{0x44300209,0x6444022f,0x2a7c0175,0xa2f80677}},	//   zly_, zmii, rsub_, ימחה_, 
   {{0x443181bc,0x9e24278f,0x2c6003e0,0x657d81bd}},	//   yly_, _بىلو, _bıde_, varh, 
   {{0x657c0564,0x245c0419,0x2a7c0334,0x0a94117e}},	//   warh, _rím_, psub_, _гадю, 
   {{0xf3fc00bd,0x2908068f,0x657d81be,0xb6a002dd}},	//   ্কার_, ńca_, tarh, пиял, 
   {{0xdb0000b5,0xc8c80014,0x7f38010f,0x00000000}},	//   vemø, _موتن_, טערו, --, 
   {{0x443181a6,0x9f4400d8,0xb9780375,0x75e82791}},	//   tly_, _comê_, _ענקי, _nüzu, 
   {{0x657d81bf,0x245c012c,0x64449585,0xdb000b1a}},	//   sarh, _vím_, umii, temø, 
   {{0x443181c0,0x644581c1,0x657c0978,0x42c859b7}},	// [28520] rly_, rmii, parh, ыган_, 
   {{0x245c038e,0x443181c2,0xdb001455,0x657c0477}},	//   _tím_, sly_, remø, qarh, 
   {{0x443181c3,0xdb0012ed,0x3c3800e4,0x00000000}},	//   ply_, semø, hëva_, --, 
   {{0x6444011f,0x75e800a2,0x00000000,0x00000000}},	//   qmii, _düzu, --, --, 
   {{0x1aec00bd,0x00000000,0x00000000,0x00000000}},	//   _জেনে_, --, --, --, 
   {{0x75e800ac,0x6dc002e8,0x00000000,0x00000000}},	//   _füzu, зсъж, --, --, 
   {{0x41cc0412,0xb21966b6,0x9f440200,0x763800df}},	//   _होयस, _kvæn, _komë_, װעקג, 
   {{0xba44010b,0x111000d1,0xb5f80332,0xdbf0013a}},	//   әхий, _تېمس, rpái, _tříf, 
   {{0xd9f8034b,0xb5f81941,0xfd98007b,0x00000000}},	//   иниц_, spái, _مئات_, --, 
   {{0xb5f800d8,0xf2d00375,0xdcf80010,0x4aa8000d}},	//   lpáv, פעת_, lavč, _कहरव, 
   {{0xec1007d6,0x19580124,0x00000000,0x00000000}},	//   _کوند, лаҿы_, --, --, 
   {{0x313406a9,0xf0b40375,0xdcf882c7,0x00000000}},	//   מנים_, זלטר_, navč, --, 
   {{0x7bc016eb,0xb5f800e4,0x00000000,0x00000000}},	//   _iaou, ipáv, --, --, 
   {{0x7bc00a3a,0x00000000,0x00000000,0x00000000}},	//   _haou, --, --, --, 
   {{0x7bc003bd,0xdcf83116,0x81a00150,0x00000000}},	//   _kaou, kavč, _ﺎﺤﻘﺔ_, --, 
   {{0x7bc0a573,0xdcf80010,0x76640139,0x76b4010b}},	//   _jaou, javč, _ƅuyı, gşyç, 
   {{0x7bc00489,0xdcf809a8,0xf77c05d2,0xd838007f}},	// [28530] _maou, davč, maç_, ntčm_, 
   {{0x7bc00489,0xf77d81c4,0x799803ac,0x5bc42c2e}},	//   _laou, laç_, ngtw, वयुव, 
   {{0x973400dd,0x92d80eac,0x23c4024a,0x00000000}},	//   _دکھا, ়নে_, _लोकद, --, 
   {{0x7bc181c5,0x9f4539bc,0xf77c12e4,0x4fd400f5}},	//   _naou, _komè_, naç_, южет, 
   {{0xb8d80003,0x201c0261,0x2744020c,0x3db400d1}},	//   _ངར_, évia_, mèné_, ﺸﻠﯩﺘ, 
   {{0xdc3c005f,0x2744020c,0xfba4185d,0x445400f1}},	//   kšēj, lèné_, क्सम, _دریځ, 
   {{0xf4241b4b,0x7bc00489,0xf77cac4c,0x4c68702f}},	//   _རྩོད_, _baou, kaç_, шийн_, 
   {{0x7bc0fd9a,0x2744020c,0x75e80139,0xb5f8013a}},	//   _caou, nèné_, _küzs, cpáv, 
   {{0x7bc003bd,0xf77c04f0,0xd7dc8497,0x00000000}},	//   _daou, daç_, यानच, --, 
   {{0x88844ced,0x7ae401e6,0x8a0400d4,0x00000000}},	//   олож, äkta, ізне, --, 
   {{0x5e480014,0x7bc00156,0x9958005f,0xdc3c00e2}},	//   _ألف_, _faou, kšņi_, gšēj, 
   {{0x7bc00dd4,0xf77d2e16,0x4a741f72,0x24840023}},	//   _gaou, gaç_, _дыкт, _ክፍሊት_, 
   {{0xf4240867,0x9f4402d3,0x00000000,0x00000000}},	//   _རྩེད_, _romë_, --, --, 
   {{0xdce80316,0x6b9981c6,0x7bc00156,0xdcf8107d}},	//   _nedě, lgug, _zaou, zavč, 
   {{0x7bc003bd,0x69c181c7,0x07a463ed,0xf65c03b2}},	//   _yaou, _iane, _дайн, lvæl_, 
   {{0x69c181c8,0x6b9981c9,0x436981ca,0xf77c9972}},	//   _hane, ngug, раан_, caç_, 
   {{0x9f440100,0xb6a001ec,0xc1e00220,0x00000000}},	// [28540] _gomè_, _жиыл, _ﺍﻷﺭﺍ, --, 
   {{0x69c181cb,0x26c029ef,0x32400046,0x05a874b0}},	//   _jane, _isio_, деуг, _твой_, 
   {{0x7f842097,0x69c0402f,0x2744020c,0xd7f80311}},	//   قلان, _mane, bèné_, mpăr_, 
   {{0x69c181cc,0xd7dc0574,0x44c80115,0x2744020c}},	//   _lane, यायच, _iĝ_, cèné_, 
   {{0x7bc181cd,0x69c181ce,0xb21981cf,0xdcf85a54}},	//   _raou, _oane, _kvæl, ravč, 
   {{0x69c181d0,0x7bc04eff,0x26c0009f,0xb5f80306}},	//   _nane, _saou, _msio_, spáv, 
   {{0x7bc181d1,0xb5f87917,0xf77c03ee,0xed4c0133}},	//   _paou, mpát, yaç_, نپه_, 
   {{0x69c05cc6,0x6b9981d2,0x62840006,0x9f440129}},	//   _aane, ggug, osio, _lomé_, 
   {{0x628581d3,0xfba42f2e,0x7bc00489,0x5b140cc9}},	//   nsio, क्षम, _vaou, ямит, 
   {{0x628581d4,0x9f44007f,0x7bc0387a,0x3ea40098}},	//   isio, _romè_, _waou, mtot_, 
   {{0x69c181d5,0x26c181d6,0xdb0181d7,0x7bc181d8}},	//   _dane, _asio_, lemü, _taou, 
   {{0x628581d9,0x69c00857,0x0ae80451,0xde680023}},	//   ksio, _eane, _گرمي_, _ዝተነግ, 
   {{0x69c181da,0x3ea581db,0xf77d81dc,0x25b8037e}},	//   _fane, ntot_, raç_, ferl_, 
   {{0xfba412ec,0x69c181dd,0x628581de,0x25b939c2}},	//   क्रम, _gane, dsio, gerl_, 
   {{0xf77cbbc6,0x9f440165,0xb21801bf,0x274400f2}},	//   paç_, _domé_, _dvæl, tèné_, 
   {{0x3ea41187,0x9f4404cc,0x798802d0,0xdce800bc}},	//   ktot_, _tomè_, _hdfw, _sedě, 
   {{0x247c02d3,0x3c380022,0xf5e401ec,0x62840332}},	// [28550] ባህለት_, hëvo_, _дінм, gsio, 
   {{0x69c00f71,0xdb0181df,0x75800acb,0x201c39b4}},	//   _xane, lemó, _زیرم, évin_, 
   {{0x628581e0,0x27440066,0x3ea400de,0x00000000}},	//   asio, pèné_, etot_, --, 
   {{0x75e80139,0xa6c80271,0xb6000327,0x00000000}},	//   _tüzs, _اویل_, ġġuh, --, 
   {{0x3e3019bc,0xdb000112,0x798802d0,0x0f3403e6}},	//   کفور, gemü, _odfw, سکرد, 
   {{0xb218032e,0x00000000,0x00000000,0x00000000}},	//   _kvæm, --, --, --, 
   {{0x69c00325,0xc18001ed,0x3ea40051,0x7ae401e3}},	//   _rane, _سینٹ, atot_, äktn, 
   {{0x69c181e1,0x64580395,0x251c00c8,0x798802d0}},	//   _sane, _èvie, יווא, _adfw, 
   {{0x6b997f64,0x5ba400fb,0xce94009d,0x7b8400cf}},	//   rgug, флығ, _хазъ, سايە, 
   {{0x69c181e2,0xf65c0174,0x00000000,0x00000000}},	//   _qane, rvæl_, --, --, 
   {{0x69c181e3,0xfd54008f,0xfaa400e5,0xdecc0092}},	//   _vane, _זשעי_, _ہجوی, _በቡና_, 
   {{0x69c0398e,0x2c6003ee,0x628581e4,0xb218005c}},	//   _wane, _gıda_, ysio, _svæl, 
   {{0xdcf80882,0x24984d7c,0x66000036,0xb5f806c6}},	//   mavā, wurm_, ëmko, jpás, 
   {{0x69c0166a,0x6b880036,0x44c80115,0x24980112}},	//   _uane, _hdgg, _pĝ_, turm_, 
   {{0xdb0000e5,0x6284015d,0xb978011a,0x00000000}},	//   zemü, wsio, _הנצי, --, 
   {{0x628581e5,0x26c1207c,0xdcf80882,0x25b8002f}},	//   tsio, _tsio_, navā, serl_, 
   {{0x628581e6,0x26c000ec,0xb21803b2,0xdb00007f}},	// [28560] usio, _usio_, _tvæl, lemò, 
   {{0x628581e7,0xdcf80882,0x5bb8a3a7,0xf41c00a2}},	//   rsio, havā, _आस्व, _ejä_, 
   {{0x201c0261,0x409581e8,0xb698042f,0xd6242bd8}},	//   évio_, ярат, nzân, _تعيي, 
   {{0x628581e9,0x3ea581ea,0x788001d3,0x3fe40395}},	//   psio, ttot_, _hívá, яжев, 
   {{0x788000dd,0xb5f981eb,0xf424031c,0x3ea581ec}},	//   _kívá, mpár, _རྩིད_, utot_, 
   {{0x3ea581ed,0x81f810ac,0xf264084c,0xc0582fc3}},	//   rtot_, _افسر_, _хирл_, _грац_, 
   {{0xa2c41b6e,0x3ea581ee,0x324181ef,0xada01677}},	//   रिक्, stot_, _черг, хајл, 
   {{0x4f940323,0xdcf80a28,0xdb0181f0,0x99e800fe}},	//   _оруу, gavā, xemó, _পষেক, 
   {{0xb5f80022,0x67240200,0x00000000,0x00000000}},	//   ipár, _nxij, --, --, 
   {{0xeaac951b,0x7e60014b,0x00000000,0x00000000}},	//   اعي_, mqop, --, --, 
   {{0xb5f801ed,0x7e600113,0xdb00004e,0x89a80014}},	//   kpár, lqop, gemò, تھنہ_, 
   {{0xbae400db,0x8bc400d4,0x00000000,0x00000000}},	//   _ىكاي, _осід, --, --, 
   {{0x7e60d58b,0xa3c06225,0xeb940510,0xdb0181f1}},	//   nqop, ंजन_, _хич_, remó, 
   {{0x7ae40162,0xfbd800cd,0x00000000,0x00000000}},	//   øktu, भावम, --, --, 
   {{0x672581f2,0x7880634d,0xa4d40212,0x195801af}},	//   _exij, _dívá, норі, _лаһы_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa2c400cd,0x83a400c7,0x00000000,0x00000000}},	// [28570] रिग्, ьырҵ, --, --, 
   {{0x316405d5,0x00000000,0x00000000,0x00000000}},	//   ùnz_, --, --, --, 
   {{0x7dd001ec,0x00000000,0x00000000,0x00000000}},	//   _وﻟﮕﻪ, --, --, --, 
   {{0xb21801bf,0x91e401ec,0x00000000,0x00000000}},	//   _kvæk, _ﺍﺷﯩﻼ, --, --, 
   {{0xb8cc0135,0x7e600117,0xeea80961,0x7ae4007c}},	//   _ཕཱ_, gqop, стек_, äktl, 
   {{0xdce806be,0x00000000,0x00000000,0x00000000}},	//   _acdı, --, --, --, 
   {{0x645820ef,0xdcf80882,0x765c014f,0x321002f0}},	//   _évit, tavā, _luqy, mixy_, 
   {{0xa2e400bd,0xf65c037e,0xa3c005c0,0x1fa50844}},	//   _নেটও, gvæk_, ंजय_, _пруг, 
   {{0x661c03a2,0xdcf80882,0xde940114,0x6da800f3}},	//   ynrk, ravā, _патњ, _гњев_, 
   {{0x088981f3,0x00000000,0x00000000,0x00000000}},	//   обой_, --, --, --, 
   {{0x02b85829,0x7c380008,0x9f4401e1,0xfd4c0cad}},	//   _उन्न, ðbrö, _lomì_, _oriṣ, 
   {{0xdb006f8d,0xd80007d5,0xb6980356,0x00000000}},	//   remò, лăх_, rzân, --, 
   {{0x76540009,0xfbd8197c,0xf8c401d3,0x25580055}},	//   _bixy, भारम, óért_, _ārṣṭ, 
   {{0xfd4c002b,0x765c0009,0x00000000,0x00000000}},	//   _ariṣ, _duqy, --, --, 
   {{0x76540009,0x84540114,0x00000000,0x00000000}},	//   _dixy, дњач, --, --, 
   {{0x67240218,0x69cc0030,0x00000000,0x00000000}},	//   _txij, šieľ, --, --, 
   {{0xc1e96562,0x274401e1,0x76540f85,0xdecc010c}},	// [28580] одаж_, _dèní_, _fixy, በብን_, 
   {{0xb5f8b941,0x00000000,0x00000000,0x00000000}},	//   spár, --, --, --, 
   {{0xb7b800e4,0x00000000,0x00000000,0x00000000}},	//   moãr, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4420010f,0x7de40212,0x00000000,0x00000000}},	//   _ijk_, дійд, --, --, 
   {{0x4420023a,0x91c001af,0x7ae4007c,0xad2c0ca8}},	//   _hjk_, _йҙул, äktm, _ṣaṣe, 
   {{0xd83805ce,0x44200165,0x645800d8,0x7e600309}},	//   luče_, _kjk_, _évis, sqop, 
   {{0x44200108,0xfa88009d,0x0c94075e,0x00000000}},	//   _jjk_, осой_, ردىگ, --, 
   {{0x22580c3a,0x442181f4,0x0e68324b,0xd8380219}},	//   _kirk_, _mjk_, _فصلي_, nuče_, 
   {{0x765c03f0,0x44200263,0xe7ac01ad,0x6a8001e1}},	//   _ruqy, _ljk_, ट्सप, _sìfá, 
   {{0x22580493,0x4420020b,0xb21800b5,0xb9240108}},	//   _mirk_, _ojk_, _svæk, ьфий, 
   {{0xb8e4068f,0xe59c01ec,0xef1c0327,0x00000000}},	//   _उन_, _ﺁﺫﺍﺭ_, żżen_, --, 
   {{0x7c204a73,0x199581f5,0xd83815ad,0x6a8000db}},	//   _ijor, _заля, juče_, _алча, 
   {{0x7c201455,0x44202a1f,0xb8f00022,0x22580254}},	//   _hjor, _ajk_, _аҧош, _nirk_, 
   {{0x7c200158,0x442181f6,0xe534005b,0x21380432}},	//   _kjor, _bjk_, верь, _nyrh_, 
   {{0x4420579d,0x765c0784,0x7c20017a,0x00000000}},	//   _cjk_, _tuqy, _jjor, --, 
   {{0x225981f7,0xf1a4871a,0xd83804a7,0x44203fbd}},	// [28590] _birk_, дрен, guče_, _djk_, 
   {{0x7c2181f8,0x9f449223,0xa2c407d0,0xa294109a}},	//   _ljor, _comí_, रिज्, тафі, 
   {{0x225981f9,0x7c2181fa,0x3210022a,0xf1900124}},	//   _dirk_, _ojor, rixy_, еиҕь, 
   {{0x7c201bce,0xd83801fa,0x44200200,0xab60012d}},	//   _njor, buče_, _gjk_, ążko, 
   {{0xd1c8044e,0xdd740014,0x00000000,0x00000000}},	//   _ጽድቂ_, چھمک, --, --, 
   {{0x7c2181fb,0x2b0c00dc,0xc2780375,0xdea4150e}},	//   _ajor, _तेषु_, _מרשי, ئیلی, 
   {{0x1aec0154,0x9f0400e5,0x68280205,0x00000000}},	//   _জেলে_, _یوفو, lıde, --, 
   {{0xa2c4043e,0x00000000,0x00000000,0x00000000}},	//   रिच्, --, --, --, 
   {{0x7c2181fc,0xdea402f2,0xa924013a,0x68280205}},	//   _djor, _لینی, _mužů, nıde, 
   {{0x7c2181fd,0x89a83580,0xdf4581fe,0xba20807e}},	//   _ejor, чков_, _рэсп, лдык, 
   {{0x7c200c58,0x07a41feb,0xf3fc0589,0xc7a40334}},	//   _fjor, нанн, _olã_, нинк, 
   {{0x7c2039c3,0x2d540022,0xd1c80092,0x0c7c0092}},	//   _gjor, _еиҕь_, _ጽድቅ_, _ጥቅሶች_, 
   {{0x7c2d81ff,0x9734009d,0x00000000,0x00000000}},	//   _íbra, вэрч, --, --, 
   {{0x6a14669d,0xd8380989,0x3ea0049f,0x41cc000d}},	//   _تبصر, vuče_, _åkte_, _होंस, 
   {{0x44200a2e,0x9f440589,0x7c200200,0xb5f803b2}},	//   _pjk_, _komã_, _yjor, rpáp, 
   {{0x22598200,0xf3fc0120,0xca4805d9,0xd83801a6}},	//   _sirk_, _clã_, _بلڪه_, tuče_, 
   {{0x22580006,0xc2440064,0x00000000,0x00000000}},	// [285a0] _pirk_, енак, --, --, 
   {{0xe7ac1092,0x70500075,0xf3fc00d8,0x71a07696}},	//   ट्रप, ۇنلا, _elã_, лауз, 
   {{0x22598201,0x44200205,0xa2c4190c,0x00000000}},	//   _virk_, _tjk_, रिङ्, --, 
   {{0x22581c1d,0xd8388c7a,0x4420036e,0x36701888}},	//   _wirk_, puče_, _ujk_, _جهیز, 
   {{0xdb0001b8,0x22580072,0xf77402e4,0x00000000}},	//   lemö, _tirk_, געני_, --, 
   {{0x44318202,0xf3fc0004,0xf4840ec5,0xf2dc001e}},	//   loy_, _zlã_, _تایی, _ngây_, 
   {{0xdb000793,0x2d540108,0x00000000,0x00000000}},	//   nemö, нишь_, --, --, 
   {{0xa3c00037,0x38700131,0x9b58004e,0x00000000}},	//   ंजि_, ққит, мийт_, --, 
   {{0xe7e447d0,0x70140375,0xf65c01bf,0x0354010f}},	//   गाना_, _נחמד_, lvæv_, עיִש_, 
   {{0xfce47f64,0x44318203,0x3f840dd4,0xd8f800d6}},	//   _позо, hoy_, laou_, дної_, 
   {{0x44318204,0x7c2003cd,0xa3c0134e,0x00000000}},	//   koy_, _tjor, ंजा_, --, 
   {{0x44318205,0xdb0001b8,0xdc558206,0x7c200240}},	//   joy_, demö, _شراک, _ujor, 
   {{0x44318207,0x68fc06be,0x00000000,0x00000000}},	//   doy_, _əqdi, --, --, 
   {{0xdcb80115,0x00000000,0x00000000,0x00000000}},	//   _kpĉ_, --, --, --, 
   {{0x44300170,0xa4d98208,0xf3fc0589,0x48c4678d}},	//   foy_, ндру_, _plã_, _ашығ, 
   {{0x44318209,0x00000000,0x00000000,0x00000000}},	//   goy_, --, --, --, 
   {{0xdee40046,0x3f840165,0x92595a41,0x7ae4007c}},	// [285b0] _اۋ_, daou_, даат_, äkth, 
   {{0x6458011c,0x71240b38,0xdb00007c,0x2ba40073}},	//   _èvin, ىرال, bemö, _गाभा, 
   {{0x998c0118,0x62240145,0x6ee40066,0x00000000}},	//   hodů_, دىلل, کسال, --, 
   {{0x4431820a,0x38a80428,0x28980a7c,0xdb00000d}},	//   coy_, iùr_, ליבא, lemõ, 
   {{0x9f4400d8,0xa3440024,0x00000000,0x00000000}},	//   _romã_, _бэрл, --, --, 
   {{0xdce80029,0x38a80086,0xdb00000d,0x8cb40395}},	//   _nedē, kùr_, nemõ, всич, 
   {{0xe7e400ce,0x2a6c0e78,0x3f84007f,0x69f000fb}},	//   गामा_, _stgb_, baou_, һүдт, 
   {{0xa1581c26,0xdb000254,0xe7d00073,0x00000000}},	//   _часу_, hemõ, _तोंप, --, 
   {{0xdcb801e4,0x9f4400db,0x0a4801b9,0x0b4401d5}},	//   _epĉ_, _gomà_, мзий_, ънин, 
   {{0x4430022e,0x00000000,0x00000000,0x00000000}},	//   zoy_, --, --, --, 
   {{0xd7dc2413,0x9f45820b,0x4431820c,0x00000000}},	//   यांच, _tomã_, yoy_, --, 
   {{0x44301bce,0xdcb000db,0xe7943fe6,0x00000000}},	//   xoy_, _چىە_, دادک, --, 
   {{0x4431820d,0x9f440085,0x2d85820e,0xc050010f}},	//   voy_, _komá_, oane_, יזט_, 
   {{0x2d85820f,0xfb180375,0xf7880139,0x3f840165}},	//   nane_, _קוסמ, _auçı_, zaou_, 
   {{0x44318210,0x2aa8019b,0x8458b94f,0x2d840ffb}},	//   toy_, løb_, драт_, iane_, 
   {{0x9f440270,0x42d40220,0x00000000,0x00000000}},	//   _lomá_, кізу, --, --, 
   {{0x44318211,0x2d858212,0x86440124,0xdb00002f}},	// [285c0] roy_, kane_, _иниж, semö, 
   {{0x9f440137,0x7ae401e6,0x00000000,0x00000000}},	//   _romà_, äkti, --, --, 
   {{0x2d858213,0x44318214,0x6458011c,0xe0580214}},	//   dane_, poy_, _èvio, فیست_, 
   {{0x2d8401e0,0x2aa8037e,0x4430016d,0x1fe801e2}},	//   eane_, køb_, qoy_, رکزي_, 
   {{0x2d84342f,0xdd958215,0x7e283334,0x63a58216}},	//   fane_, галы, міка_, mgin, 
   {{0x63a58217,0x998c012c,0xb21800b5,0x00000000}},	//   lgin, vodů_, _svæv, --, 
   {{0x63a406d9,0xf1700244,0x00000000,0x00000000}},	//   ogin, _ئێمگ, --, --, 
   {{0x63a58218,0x9f4405da,0xdd0c012d,0x1b04008e}},	//   ngin, _tomà_, _półm, лүен, 
   {{0x2d858219,0x5a341f5c,0xf4101203,0xd005821a}},	//   bane_, лнит, יפה_, _сотқ, 
   {{0x2d85821b,0x63a40007,0xbd8804fb,0x38a80086}},	//   cane_, hgin, _آنان_, tùr_, 
   {{0x3ddc0472,0x63a5821c,0xde880521,0x78a80334}},	//   _intw_, kgin, lị_, _qqfv, 
   {{0x63a40196,0xeaac0014,0x7d0406be,0xfce4014b}},	//   jgin, _ژٹن_, _əksl, _поҷо, 
   {{0xde8805db,0x6bd41541,0xe8880023,0xda7001c8}},	//   nị_, _جونس_, _መደርኡ_, _اُت_, 
   {{0x63a40493,0xe9cc0451,0x00000000,0x00000000}},	//   egin, _وٺن_, --, --, 
   {{0xde88063f,0x63a40036,0xf7880166,0xa90400ec}},	//   hị_, fgin, _puçı_, _ليول_, 
   {{0x2d85821d,0x63a5821e,0xde8801f2,0x557400d1}},	//   zane_, ggin, kị_, _өгит, 
   {{0x2d85821f,0xde88063f,0x388c002d,0xe4558220}},	// [285d0] yane_, jị_, lęr_, ркты, 
   {{0x2d858221,0x62240075,0x75e804cc,0xde8800b4}},	//   xane_, لىقل, _lüzz, dị_, 
   {{0xcfb00f22,0xd13002f2,0x63a401d5,0x68298222}},	//   _ঘোষন, حما_, bgin, lıda, 
   {{0x2d858223,0x75e807c5,0x3ddc3a5e,0x00000000}},	//   wane_, _nüzz, _antw_, --, 
   {{0x2d858224,0x1ea88b4d,0xa3c083e3,0xde8801f2}},	//   tane_, ناوي_, ंजर_, gị_, 
   {{0x2d840072,0xdcf800c0,0x00000000,0x00000000}},	//   uane_, lavę, --, --, 
   {{0x8fd004b4,0x68280bb9,0x61f8007c,0x00000000}},	//   _гәлә, hıda, övle, --, 
   {{0x2d8462bc,0x68285aeb,0x75e80205,0xfbd80b98}},	//   sane_, kıda, _cüzz, भागम, 
   {{0x2d858225,0x8e98182c,0x5f380276,0x75e800a2}},	//   pane_, _سناء_, _аптя_, _düzz, 
   {{0x63a4831a,0x2d858226,0x7d1c0332,0x00000000}},	//   zgin, qane_, úpsc, --, 
   {{0x63a4c3a9,0x6e2000b5,0xb218d379,0xdcf80064}},	//   ygin, mnnb, _hvæs, kavę, 
   {{0x75e804cc,0xb21800b5,0x63a40007,0xd7c8004b}},	//   _güzz, _kvæs, xgin, نوپه_, 
   {{0x63a58227,0x6e200332,0xdcf80153,0xb8e86a60}},	//   vgin, onnb, davę, _रै_, 
   {{0xd8382375,0xca3801e4,0x15b807ee,0x4f340092}},	//   ruča_, buŝa_, кысы_, _እናድር, 
   {{0x63a58228,0xa3c02ba2,0xde8801f2,0x6e200fac}},	//   tgin, ंजल_, zị_, innb, 
   {{0x63a58229,0xdcf80153,0x00000000,0x00000000}},	//   ugin, gavę, --, --, 
   {{0x27e1822a,0x442404ac,0x68281432,0x4224009d}},	// [285e0] _inin_, ĵo_, cıda, гдав, 
   {{0x63a5822b,0xfbd8000d,0x00000000,0x00000000}},	//   sgin, _मोनम, --, --, 
   {{0x27e1822c,0x1b240183,0x00000000,0x00000000}},	//   _knin_, _পৰাই_, --, --, 
   {{0xf65c1477,0x63a40399,0xde8802e3,0x136801f0}},	//   mvær_, qgin, tị_, _ашёи_, 
   {{0xf65c08fb,0x0244009f,0x00000000,0x00000000}},	//   lvær_, _مَحَ, --, --, 
   {{0xde8805db,0xadb002dd,0x704410e0,0xdb080248}},	//   rị_, йбіш, _ەركە, _ìlér, 
   {{0x27e1822d,0xde8805db,0x2fdc01bf,0xdd9401e0}},	//   _onin_, sị_, _fnug_, гаһы, 
   {{0x9bf4288a,0x68287236,0x9f44003a,0x1aec015b}},	//   рзич, yıda, _romæ_, _জেগে_, 
   {{0x2005822e,0xb218ebd4,0xba740956,0x00000000}},	//   _ilmi_, _ivær, داعت, --, 
   {{0x27e1822f,0xaab400c6,0x195806a6,0xef142bbd}},	//   _anin_, ادير_, капы_, _сму_, 
   {{0xb2181455,0x27e0025c,0x32340a1e,0x28d80210}},	//   _kvær, _bnin_, רטין_, यमगि, 
   {{0x3154159d,0x388c000f,0xf65c0fac,0x68280db1}},	//   טיין_, ręr_, dvær_, tıda, 
   {{0x4f34001f,0xeaf44739,0x00000000,0x00000000}},	//   _እናደር, _مروت_, --, --, 
   {{0x682812ca,0x27e18230,0x75e803ee,0x69000174}},	//   rıda, _enin_, _yüzy, óvdó, 
   {{0xe4e41ed2,0x2004c7cc,0x27e001ab,0x34480063}},	//   бітн, _olmi_, _fnin_, ечан_, 
   {{0x27e004cc,0x6828029f,0x320001f4,0xca3001ec}},	//   _gnin_, pıda, _sljy_, _ﺫﺍﺕ_, 
   {{0x52158231,0xdcf80024,0x00000000,0x00000000}},	// [285f0] адат, ravę, --, --, 
   {{0x2fdc47b4,0x2004067c,0x98a81f14,0x6674027d}},	//   _snug_, _almi_, _कमाए, _ادير, 
   {{0xb218032e,0x00000000,0x00000000,0x00000000}},	//   _svæs, --, --, --, 
   {{0xe8d40375,0x13a40133,0x984c013a,0x773c0092}},	//   טובר_, _خۆری_, _měď_, _በሦስተ, 
   {{0xb21800b5,0x260c0118,0x00000000,0x00000000}},	//   _dvær, डोकी_, --, --, 
   {{0x200403be,0xb88004bf,0x9f4c007b,0x0c940395}},	//   _elmi_, _číns, ílár_, ашия, 
   {{0xd83801fa,0xdcf800bc,0x2d880135,0xdce80064}},	//   jučo_, mavě, _ġieħ_, _medė, 
   {{0x2fdc058a,0x81400244,0x00000000,0x00000000}},	//   _unug_, _بۆمن, --, --, 
   {{0xb218005c,0x8fd001af,0x00000000,0x00000000}},	//   _uvæs, _гәһә, --, --, 
   {{0x2ba405ba,0x27e0038f,0xeff40125,0xc9558232}},	//   _गावा, _snin_, _ጉዳዩ_, итны, 
   {{0x27b43c1a,0x09c40b67,0x00000000,0x00000000}},	//   бәпс, _वसीय, --, --, 
   {{0xdcf8013a,0x00000000,0x00000000,0x00000000}},	//   havě, --, --, --, 
   {{0x09e4b7ef,0x7ae401e3,0x491477ca,0x00000000}},	//   _волн, äktt, _फेरो_, --, 
   {{0xd838107d,0x00000000,0x00000000,0x00000000}},	//   vrče_, --, --, --, 
   {{0x44158233,0xfbd828fe,0x00000000,0x00000000}},	//   афат, _मोडम, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc174113e,0xf65c1477,0x41740137,0xa8540032}},	// [28600] لدات, rvær_, لااس, _кеҫә, 
   {{0xb2182759,0xf65c7214,0x93598234,0xc4858235}},	//   _svær, svær_, урсу_, _клок, 
   {{0x661d8236,0x0444005b,0x5274ffac,0xa24400cf}},	//   mirk, _венн, _ҳусу, _ۇرسۇ, 
   {{0x661d1b13,0xca3801e4,0x515460a1,0x00000000}},	//   lirk, kuŝo_, стуу, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x661d8237,0xdcb00145,0x00000000,0x00000000}},	//   nirk, كىت_, --, --, 
   {{0x6da06997,0xb21804ce,0x491401ad,0x9b94010a}},	//   ција, _tvær, _फेलो_, бийц, 
   {{0xb2182ab7,0x2004003a,0xcbc400d1,0x60100022}},	//   _uvær, _ulmi_, ممىۋ, ẽmba, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x661c11d3,0x00000000,0x00000000,0x00000000}},	//   jirk, --, --, --, 
   {{0xd49001fb,0x2e38045f,0x00000000,0x00000000}},	//   ời_, rêft_, --, --, 
   {{0xb8840241,0xeb948c67,0xe784022e,0xdce80064}},	//   _atíò, _виц_, журо, _sedė, 
   {{0x661c3223,0xec100517,0x19c401ee,0x1fd800cc}},	//   firk, _بوند, _ләнг, _থকাস, 
   {{0x661c7547,0xd1cc02d3,0x00000000,0x00000000}},	//   girk, ኢታት_, --, --, 
   {{0xe65400d6,0xdce80006,0xf84800a8,0x00000000}},	//   івсь, _vedė, _ичий_, --, 
   {{0xb88401e1,0x66000036,0x00000000,0x00000000}},	//   _etíò, ëmkr, --, --, 
   {{0x24583549,0x661d8238,0x91b8761e,0x00000000}},	// [28610] рать_, birk, лгат_, --, 
   {{0xf4a0044e,0x661d8239,0x31c40114,0x00000000}},	//   _ዝፍለጥ_, cirk, јсав, --, 
   {{0x61f801e6,0x62800240,0x8f740d30,0x2ba42ce6}},	//   övla, _çmon, булі, _गाला, 
   {{0x4e94eb7c,0xa9e04707,0x0c7c0092,0x00000000}},	//   مشتر, _कच्छ_, _ጥቅሞች_, --, 
   {{0x201c00f7,0xeea82cc8,0xe61016d0,0x1fe800eb}},	//   èvia_, ттек_, _رشی_, পসংস, 
   {{0xaee000b8,0xe1f800fb,0x00000000,0x00000000}},	//   _akṣo, _кѳс_, --, --, 
   {{0xa194084c,0x9da80395,0xcfd40114,0x00000000}},	//   _фасч, ръча_, _ловћ, --, 
   {{0x661c09a5,0xca3801e4,0xdfd8030d,0x00000000}},	//   zirk, tuŝo_, _къу_, --, 
   {{0x1a684bf3,0x7d0400ac,0xb5f80077,0x0ae818fd}},	//   لینی_, _əksi, bpáx, ارعي_, 
   {{0x2c2402f5,0x6ab4000d,0x661c0067,0x88c801c4}},	//   মতেই_, _अहीर, xirk, глов_, 
   {{0x661d823a,0x7ae401b8,0xe7e40073,0x00000000}},	//   virk, äktr, गाला_, --, 
   {{0x661d823b,0xca3801e4,0x00000000,0x00000000}},	//   wirk, puŝo_, --, --, 
   {{0x661d823c,0xf1c400dc,0xaac40133,0xf1a40c6e}},	//   tirk, रजान, _ختان, खलान, 
   {{0xbb38008f,0x3664974c,0x95989130,0x00000000}},	//   _געני, саро_, итсу_, --, 
   {{0xaab4000d,0x00000000,0x00000000,0x00000000}},	//   _अहँक, --, --, --, 
   {{0x661d823d,0xbd00002e,0xefe40023,0x78f8011a}},	//   sirk, _ñéet, ማሳዊ_, _תפקו, 
   {{0x661c5914,0xd45400d4,0x62500254,0x00000000}},	// [28620] pirk, ітсь, näog, --, 
   {{0x661c0009,0x00000000,0x00000000,0x00000000}},	//   qirk, --, --, --, 
   {{0x04b40801,0x00000000,0x00000000,0x00000000}},	//   _успя, --, --, --, 
   {{0xaab48153,0x44c80115,0xb7e807f7,0x00000000}},	//   _अहंक, _iŝ_, टायम_, --, 
   {{0xf4540375,0x4f640133,0x644400bb,0x39400210}},	//   _ליטר_, زانف, mlii, ęksi_, 
   {{0x6445823e,0x26c1823f,0xa3c0107c,0x00000000}},	//   llii, _mpio_, ंजक_, --, 
   {{0x64458240,0xdce800ef,0x00000000,0x00000000}},	//   olii, _iedī, --, --, 
   {{0x26c0166a,0x64458241,0xb478008f,0x6be000d1}},	//   _opio_, nlii, אָזי, ككىم, 
   {{0x64458242,0xa3e002ab,0x4ed40395,0xbb840137}},	//   ilii, _दफन_, _мюфт, _ۇلاي, 
   {{0x98b803b7,0x3ea422d0,0x64458243,0x00000000}},	//   алот_, muot_, hlii, --, 
   {{0xeaac3135,0x26c060d4,0x644400af,0xdce8005f}},	//   وعی_, _apio_, klii, _medī, 
   {{0xfaa40953,0x64440286,0x3940005f,0x00000000}},	//   _гадо, jlii, āks_, --, 
   {{0x3ea58244,0x19940006,0x64440254,0x00000000}},	//   nuot_, _даля, dlii, --, 
   {{0x9f4401e1,0x64458245,0xdce80055,0x195800db}},	//   _bomú_, elii, _nedī, _калы_, 
   {{0x9f4400f7,0x555800a7,0x3ea58246,0x64440036}},	//   _comú_, равя_, huot_, flii, 
   {{0x93798247,0x64440548,0x3ea400c0,0x00000000}},	//   рбат_, glii, kuot_, --, 
   {{0x1ca81e81,0xe3b000c6,0x3688024c,0x3ea400c0}},	// [28630] _བཀའ_, عرف_, _ёсин_, juot_, 
   {{0x64458248,0x32058249,0x9f4401e1,0xdce800b8}},	//   alii, óny_, _fomú_, _cedī, 
   {{0x79880085,0x64442323,0xdce8002b,0xd01000f1}},	//   _mefw, blii, _dedī, ولئ_, 
   {{0x644401d9,0x4fc002de,0x3ea400c0,0x00000000}},	//   clii, بەرە, fuot_, --, 
   {{0x8d644e87,0xfe6d01e2,0x3ea5824a,0x8e540a4a}},	//   овле, نگل_, guot_, откі, 
   {{0x64b451ae,0xc1a401ec,0x00000000,0x00000000}},	//   _بحیر, _мысқ, --, --, 
   {{0xfbd81d7d,0x9e940092,0x50640092,0x00000000}},	//   _मोहम, _ኃይልና_, ልዶላች, --, 
   {{0x7c54282b,0x251c008f,0x798803ac,0x1af400cc}},	//   يلور_, טווא, _aefw, েছনে_, 
   {{0xb53c00d1,0x5db800cc,0x00000000,0x00000000}},	//   ﺨﯩﻤﯘ_, _আফৰু, --, --, 
   {{0xd83801a6,0xc8b40108,0x00000000,0x00000000}},	//   vrča_, осмы, --, --, 
   {{0x29005f5b,0x1ca80135,0x798802e2,0x6444023a}},	//   ája_, _བཀར_, _defw, ylii, 
   {{0x2908068f,0x070806f6,0xdc88151e,0x6444919d}},	//   ąca_, ليجي_, _ысул_, xlii, 
   {{0x2900151c,0x3ae850b5,0xd490001e,0x64440254}},	//   šja_, _نبوی_, ần_, vlii, 
   {{0x6b8834a7,0x386800c6,0x64440014,0x2ca40175}},	//   _hegg, úirí_, wlii, ound_, 
   {{0x6b89824b,0x64440e14,0x2ca46eb8,0xdce80171}},	//   _kegg, tlii, nund_, _redī, 
   {{0x1ca803bd,0x6b881bce,0x00000000,0x00000000}},	//   _བཀལ_, _jegg, --, --, 
   {{0x6445824c,0x6b89824d,0x43080451,0x40c80451}},	// [28640] rlii, _megg, جيءَ_, ڌوءَ_, 
   {{0x6b89824e,0xdb000436,0x6445824f,0x44c801e4}},	//   _legg, ngmá, slii, _tŝ_, 
   {{0x00c830cb,0x644400af,0x40940cc9,0x2ca48e5d}},	//   рлек_, plii, юрат, jund_, 
   {{0x2ca41570,0x6b898250,0x6444058a,0x00000000}},	//   dund_, _negg, qlii, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x1e140dce,0x2ca58251,0xdd918252,0xd3880046}},	//   ямля, fund_, روب_, _ﯗﮔﯩﺖ_, 
   {{0x798841f2,0x2ca5252f,0x3ea422d0,0x05b00456}},	//   _refw, gund_, suot_, _जानब, 
   {{0x41740150,0x79880142,0xb4f80a7c,0x3ea40064}},	//   _داڭس, _sefw, יפצי, puot_, 
   {{0x6b898253,0x3ea41730,0x05c80bae,0x00000000}},	//   _degg, quot_, ाजाब, --, 
   {{0x2ca58254,0xaee00882,0x6b880a55,0x1a6801d5}},	//   bund_, saṃb, _eegg, لیچی_, 
   {{0x2ca58255,0xd8380989,0x6b898256,0x00000000}},	//   cund_, luči_, _fegg, --, 
   {{0x6b898257,0x00000000,0x00000000,0x00000000}},	//   _gegg, --, --, --, 
   {{0xdb080248,0x00000000,0x00000000,0x00000000}},	//   _ìlàr, --, --, --, 
   {{0x6b880936,0xd838007f,0x00000000,0x00000000}},	//   _zegg, ntčz_, --, --, 
   {{0xfaa400b2,0x1ca80135,0x6b881bce,0xa4d40212}},	//   _اهڙي_, _བཀས_, _yegg, морі, 
   {{0x195801af,0xef1c031c,0x00000000,0x00000000}},	//   _каһы_, żżin_, --, --, 
   {{0xd8381a48,0xdeb40198,0xd76003e6,0x2ca404cc}},	// [28650] juči_, ƙaƙi, _سۆسی, zund_, 
   {{0xd8380841,0x00000000,0x00000000,0x00000000}},	//   duči_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2ca407de,0xddc00153,0x00000000,0x00000000}},	//   vund_, _rumš, --, --, 
   {{0x6b898258,0x42a40075,0xf20400a7,0x2ca4002f}},	//   _regg, _нурғ, _дяво, wund_, 
   {{0x2ca58259,0x6b89825a,0xa0500023,0x00000000}},	//   tund_, _segg, _ንዲክታ, --, 
   {{0x6b89825b,0x76440076,0xdb0001bf,0x00000000}},	//   _pegg, iljy, ngmæ, --, 
   {{0x2ca5825c,0x1fa4004e,0xb5bc01ec,0x00000000}},	//   rund_, _оруг, _ﺠﻤﻴﻌ, --, 
   {{0x2ca45be9,0x6b89825d,0x7bc40022,0x00000000}},	//   sund_, _vegg, õkua, --, 
   {{0x6b88fb35,0xddc0005f,0x08f8211f,0x0ef8134e}},	//   _wegg, _tumš, مرجب_, ्नीस_, 
   {{0x9f44033b,0x6b881bce,0x5d1000f1,0x00000000}},	//   _anmè_, _tegg, _لېوا, --, 
   {{0xc04c0023,0x69c8000d,0x00000000,0x00000000}},	//   _ዝኣተወ, _तक़री, --, --, 
   {{0x1ca8031c,0x0d0c00b8,0x00000000,0x00000000}},	//   _བཀོ_, _ṣaṭś, --, --, 
   {{0x9a85825e,0xeef0000d,0x7f3800df,0xdb0801e1}},	//   _цуцл, _आपनऽ_, מערו, _ìlár, 
   {{0xf2dc00c7,0x0ef800bc,0x00000000,0x00000000}},	//   _arâ_, ्नुस_, --, --, 
   {{0xb898011a,0xb460442d,0x46e800f3,0x00000000}},	//   _הבקש, ексл, _гдин_, --, 
   {{0xf2dc0129,0x00000000,0x00000000,0x00000000}},	// [28660] _crâ_, --, --, --, 
   {{0x601c0213,0x9c7c0010,0xd8380841,0x00000000}},	//   _içmə, _hrče, vuči_, --, 
   {{0x04451567,0xf2dc0588,0x9c7c0427,0xb5f80375}},	//   _неон, _erâ_, _krče, _הליכ, 
   {{0x7c6400d1,0xd01800d4,0x00000000,0x00000000}},	//   ۋابل, офі_, --, --, 
   {{0x9c7c0f03,0x3f680022,0x00000000,0x00000000}},	//   _mrče, аиҵо_, --, --, 
   {{0xd8389ac0,0x2a7c010a,0xcee8009f,0x00000000}},	//   ruči_, dpub_, ترمن_, --, 
   {{0x64580395,0xa3e00ebb,0xc044009f,0x00000000}},	//   _èvis, _दफा_, _فخرو, --, 
   {{0x8cbc0034,0xff245cf7,0x00000000,0x00000000}},	//   _शहरो, _ембо, --, --, 
   {{0xe7b00131,0xe81019cc,0x76454ad2,0x7054074d}},	//   _ﺳﯚﺯﻟ, ासना_, yljy, _хатĕ, 
   {{0x9c7d825f,0x5a340120,0x00000000,0x00000000}},	//   _arče, ќнот, --, --, 
   {{0x6da18260,0xece4c133,0xada05b66,0x00000000}},	//   _чиха, _ндфл_, _чахл, --, 
   {{0xd4900208,0x00000000,0x00000000,0x00000000}},	//   ầm_, --, --, --, 
   {{0xb8649cad,0xdca4013d,0x6280036e,0x00000000}},	//   _کاتو, _хаҗи, _çmoh, --, 
   {{0x6be00150,0x00000000,0x00000000,0x00000000}},	//   _يكەم, --, --, --, 
   {{0x9c7c01ef,0x00000000,0x00000000,0x00000000}},	//   _frče, --, --, --, 
   {{0x9c7c05ce,0xf0740075,0x00000000,0x00000000}},	//   _grče, җидә_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [28670] --, --, --, --, 
   {{0x20c8b4a8,0x758001d5,0x386d8261,0xca3801e4}},	//   रबंध, _سیرم, _kufr_, tuŝi_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfc74037e,0x00000000,0x00000000,0x00000000}},	//   dキ_, --, --, --, 
   {{0x386c030a,0xdcf8005f,0xf2dc00c7,0x1ca80327}},	//   _lufr_, kavē, _urâ_, _བཀུ_, 
   {{0x273c004d,0xca380115,0xb0688b0a,0x00000000}},	//   ửng_, puŝi_, _граж_, --, 
   {{0xe810012c,0x00000000,0x00000000,0x00000000}},	//   ासमा_, --, --, --, 
   {{0xdfd58262,0x00000000,0x00000000,0x00000000}},	//   _посы, --, --, --, 
   {{0xae2000cf,0x7d2406be,0x00000000,0x00000000}},	//   _كورۉ, _əssə, --, --, 
   {{0xe8100cf1,0x9c7c6b48,0x49c8009d,0x00000000}},	//   ासभा_, _srče, цлон_, --, 
   {{0xc7a58263,0xad08009d,0x2a7c1e0b,0x7c2c0332}},	//   минк, _ухаж_, spub_, úiré, 
   {{0x6e218264,0x2a7c0de2,0xe7ac00fe,0x00000000}},	//   linb, ppub_, গজ্য, --, 
   {{0xdb000267,0xc9f4007b,0x00000000,0x00000000}},	//   ggmä, _يستع, --, --, 
   {{0xf41c006a,0x244c00c7,0x00000000,0x00000000}},	//   _amä_, tÿmo_, --, --, 
   {{0x9c7c9ae3,0x43f8005b,0x6e2001ab,0x2a6c02d2}},	//   _trče, охая_, iinb, _hugb_, 
   {{0x9c7d8265,0x6e218266,0x00000000,0x00000000}},	//   _urče, hinb, --, --, 
   {{0x41b40640,0x952c001f,0x43440120,0x6e2002d0}},	// [28680] дсет, ደሚከተ, феав, kinb, 
   {{0x6e2004ce,0xf41c01f4,0x00000000,0x00000000}},	//   jinb, _emä_, --, --, 
   {{0xb69800d2,0x6e2052bc,0x4368014b,0x05540395}},	//   nyân, dinb, _манн_, _ютия, 
   {{0xd17400fd,0x6e20002f,0xbea401a9,0x00000000}},	//   _җыры, einb, дадк, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6e20d595,0xdd9400fd,0x00000000,0x00000000}},	//   ginb, хакы, --, --, 
   {{0xd5ec01fb,0x324000fb,0x00000000,0x00000000}},	//   _quả, _рерг, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3f858267,0x61fd8268,0x6e218269,0x00000000}},	//   mbou_, _korl, binb, --, 
   {{0x61fc014f,0x3f85826a,0xca380115,0x47a400cc}},	//   _jorl, lbou_, kuŝu_, গ্মী, 
   {{0x61fd826b,0x3ea4143a,0xa3c1205a,0x00000000}},	//   _morl, lrot_, ूजा_, --, 
   {{0x3f85826c,0xd838007f,0x3ea40108,0x00000000}},	//   nbou_, prčm_, orot_, --, 
   {{0x61fc225e,0xb698025a,0x3f840198,0x5bbc4a18}},	//   _oorl, ayân, ibou_, ्जीव, 
   {{0x61fd826d,0xb698006a,0x7bc0009a,0x7ae00036}},	//   _norl, byân, _hbou, _irot, 
   {{0x7ae1826e,0x3ea4324c,0x00000000,0x00000000}},	//   _hrot, hrot_, --, --, 
   {{0x3f84045f,0x3ea400e5,0x6e2022d9,0xb28401f4}},	//   jbou_, krot_, zinb, дыжк, 
   {{0x61fd826f,0x7bc00207,0x7ae00607,0x3f8402fb}},	// [28690] _borl, _mbou, _jrot, dbou_, 
   {{0x71258270,0x61fd8271,0xf3fc0016,0x3f840036}},	//   ورال, _corl, _giãn_, ebou_, 
   {{0x61fd8272,0xe7e40490,0x7bc18273,0x5ec8009e}},	//   _dorl, गाचा_, _obou, লিফে, 
   {{0x3f840354,0x3ea40a40,0x7ae18274,0xb21800b5}},	//   gbou_, frot_, _orot, _stæd, 
   {{0x9f406984,0x6e218275,0x3ea4017a,0xd250007b}},	//   ðið_, tinb, grot_, _منح_, 
   {{0x7bc18276,0x61fd0de7,0x8d740eff,0xc3300302}},	//   _abou, _gorl, راتا, _תוך_, 
   {{0x7ae18277,0x6e218278,0x8c458279,0x00000000}},	//   _arot, rinb, неке, --, 
   {{0x3ea5827a,0x61fc3630,0x7ae1827b,0x6e201600}},	//   brot_, _zorl, _brot, sinb, 
   {{0x7ae1827c,0x0e349db1,0x61fd827d,0x7bc000b5}},	//   _crot, _знаю, _yorl, _dbou, 
   {{0x61fc01a9,0xace80220,0x1b000131,0x60e80139}},	//   _xorl, _ورال_, рүшн, _üsmä, 
   {{0xdd94b400,0x2d84151c,0x61f82bea,0x00000000}},	//   _рахы, mbne_, övli, --, 
   {{0x7ae1827e,0xb698019f,0x7bc001e1,0x00000000}},	//   _frot, ryân, _gbou, --, 
   {{0x7ae1827f,0x392802d3,0xab280592,0x00000000}},	//   _grot, _ብዘይካ, _بسال_, --, 
   {{0x9c7c4bc9,0x3f8402fb,0x7bc00118,0x91c02314}},	//   _hrča, zbou_, _zbou, र्मै, 
   {{0x69c18280,0x3f858281,0xb7b800d8,0x00000000}},	//   _ibne, ybou_, cião, --, 
   {{0x61fd8282,0x6ab8009f,0x638001ef,0x00000000}},	//   _sorl, otuf, kánů, --, 
   {{0x61fd8283,0x6ab98284,0x9c7c00f3,0x3f8402fb}},	// [286a0] _porl, ntuf, _mrča, vbou_, 
   {{0x68e096c0,0x2d8400f3,0x61fd8285,0x3ea401a9}},	//   _krnd, jbne_, _qorl, vrot_, 
   {{0x61fc0730,0x3f844865,0x69c00108,0x3ea40210}},	//   _vorl, tbou_, _mbne, wrot_, 
   {{0x91c00050,0x61fd8286,0xfbacc881,0x3ea58287}},	//   र्बै, _worl, _टाइम, trot_, 
   {{0x1ca80f50,0x61fd8288,0x2ca40bac,0x3f858289}},	//   _བཀང_, _torl, ernd_, rbou_, 
   {{0x7ae002d3,0xf2d0008d,0x3f856501,0xdcb01473}},	//   _rrot, _געש_, sbou_, لىت_, 
   {{0x44216305,0x9f440395,0x9c7c0558,0x3ea40221}},	//   _kmk_, _comò_, _brča, srot_, 
   {{0x69c1828a,0x961cd3a8,0x78b80a73,0x3ea5828b}},	//   _abne, _नष्ट_, vttv, prot_, 
   {{0x44200a28,0x69c00158,0x68e1828c,0x2ca4000f}},	//   _mmk_, _bbne, _arnd, arnd_, 
   {{0x7ae143c8,0x44217e3e,0x00000000,0x00000000}},	//   _vrot, _lmk_, --, --, 
   {{0x7ae1828d,0x9f45828e,0x9c7c0427,0x7bc00076}},	//   _wrot, _tomó_, _frča, _tbou, 
   {{0x68e0b0e8,0x4421828f,0x9c7c0010,0x69c18290}},	//   _drnd, _nmk_, _grča, _ebne, 
   {{0x68e00998,0x7ae18291,0xf3fc00d8,0x78b801a6}},	//   _ernd, _urot, _sião_, sttv, 
   {{0x44218292,0xf3fc00d8,0x2614000d,0xb4b00075}},	//   _amk_, _pião_, _näod_, лигә, 
   {{0x58d58293,0xe5358294,0x442003b9,0x98a400bc}},	//   _ройт, герь, _bmk_, _खटिए, 
   {{0x4420a8e2,0x7c200003,0xd9b800ec,0x00000000}},	//   _cmk_, _jmor, _رنڊڪ_, --, 
   {{0x7c218295,0xfbc00a28,0x44200036,0x24180c98}},	// [286b0] _mmor, व्यम, _dmk_, хоты_, 
   {{0x91800075,0x442003cd,0xf3fc00d8,0x00000000}},	//   شۇرۇ, _emk_, _tião_, --, 
   {{0x7c218296,0xd1318297,0x7cc800ac,0x2d840010}},	//   _omor, جما_, _hərf, vbne_, 
   {{0x4e9400db,0x7c2001e1,0x6250005b,0x98bc0153}},	//   نشتر, _nmor, läol, _gyvą_, 
   {{0xefb8044e,0xb8e0025c,0x00000000,0x00000000}},	//   _ሰናይ_, _ཌད_, --, --, 
   {{0x9c7c0989,0x6250007d,0x925805f5,0x0d658298}},	//   _srča, näol, _цагт_, نگاپ, 
   {{0x9c7c00f3,0x25d80375,0x69c0003b,0x62358299}},	//   _prča, גוון_, _rbne, _серу, 
   {{0x0ae81b6d,0xf3fc0c67,0x6ab80eda,0x69c0020b}},	//   ддий_, _joã_, ttuf, _sbne, 
   {{0xdea54a78,0x9f340046,0x68e0110c,0x2fcc020c}},	//   _مینی, _беті, _srnd, megg_, 
   {{0x7c200c8c,0xaca000b4,0x2fcc1a82,0xdeec0150}},	//   _emor, _amụm, legg_, _رۋى_, 
   {{0x6ab9829a,0x9c7c098d,0xdcf80153,0xc170011a}},	//   stuf, _trča, davė, יחי_, 
   {{0x9c7d3542,0x2fcc002f,0x6285829b,0xcae401af}},	//   _krčn, negg_, ypio, _ағиҙ_, 
   {{0x9aa441ff,0x4421829c,0xabb00022,0x5ec800cc}},	//   _ممنو, _rmk_, _ааҵә, লিথে, 
   {{0x442002b4,0x7c213b78,0x69c002d0,0xdcf80153}},	//   _smk_, _zmor, _ubne, gavė, 
   {{0x4420e7a3,0x2fcca98d,0x36640117,0xf18800d1}},	//   _pmk_, kegg_, таро_, _ﺗﯘﻏﯘ, 
   {{0x2fcc143a,0x7c200327,0x59c4215c,0x39a40241}},	//   jegg_, _xmor, _ليۇك, _tísà_, 
   {{0x49080316,0x2fcc0065,0x6285829d,0xf3fc0051}},	// [286c0] ानको_, degg_, upio, _giãm_, 
   {{0xd1780006,0xa074013d,0xddc800cd,0x00000000}},	//   есці_, гъдә, _vidū, --, 
   {{0x44200181,0x628401e7,0xdd9402dd,0x7cc803e3}},	//   _tmk_, spio, қайы, _zərf, 
   {{0x6285829e,0x78f80375,0xd83816a3,0x7cc803b9}},	//   ppio, ופעו, trči_, _hərg, 
   {{0x4431829f,0xd24c105d,0xefb0036b,0x6444022e}},	//   mny_, _کۆل_, شیلگ, moii, 
   {{0x44302a5c,0x64440069,0x5bbc07b7,0x91c00a99}},	//   lny_, loii, ्ज्व, र्दै, 
   {{0x44310f8a,0x64440270,0x7c2001f7,0x7f84007b}},	//   ony_, ooii, _pmor, _للأن, 
   {{0x443182a0,0x64440099,0x1bec00af,0x787c00cd}},	//   nny_, noii, झाइल_, _jīve, 
   {{0x443182a1,0x64440618,0xdb000162,0x79c801ec}},	//   iny_, ioii, ngmø, _ﺒﻤﻭﻀ, 
   {{0x4430092e,0x6444166a,0xd8f802bf,0xaa8404fb}},	//   hny_, hoii, еної_, کنیم_, 
   {{0xb698019f,0xd7945c08,0x64440083,0x7c20025c}},	//   ryâm, линъ, koii, _tmor, 
   {{0x443182a2,0x7ac40372,0x787c00ef,0x00000000}},	//   jny_, _аске, _rīvd, --, 
   {{0x44309637,0x34c80f4c,0xc8f4013e,0x7cc806be}},	//   dny_, ाब्द, взӯъ, _bərg, 
   {{0xb8803680,0x44300204,0x7cc803e3,0x8ca809ab}},	//   üíst, eny_, _cərg, _टिमो, 
   {{0xf3fc0004,0x659582a3,0x64440421,0x746982a4}},	//   _poã_, расу, foii, драв_, 
   {{0x443182a5,0x57b427a8,0x7cc803b9,0x62500108}},	//   gny_, _сбит, _tərf, säol, 
   {{0x2fcc933c,0x7cc80213,0xe4d80014,0xdcf80064}},	// [286d0] vegg_, _hərd, _یوٝت_, pavė, 
   {{0x4430a4d1,0x7cc800ac,0x2fcd82a6,0x998c0064}},	//   any_, _gərg, wegg_, modų_, 
   {{0x2608006d,0x9c7c151c,0x44300609,0x48e4012c}},	//   _सकती_, _srčn, bny_, टियो_, 
   {{0x4430182d,0xfbc002ab,0x7cc803e3,0xef480023}},	//   cny_, _वॉलम, _mərd, _ንሓይል, 
   {{0x7cc803e3,0x1bec00c5,0x998c0064,0x00000000}},	//   _lərd, झाईल_, nodų_, --, 
   {{0xdce803be,0x2fcc03b2,0x787c0171,0xb03000c7}},	//   _addı, segg_, _zīve, ымҵә, 
   {{0x6ecc0316,0x7cc803b9,0x787c00ef,0x00000000}},	//   _धनकु, _nərd, _līvb, --, 
   {{0x0ba81dc8,0xa158009b,0xdc740124,0x3f10013d}},	//   راعى_, _расу_, шышь, рдәс, 
   {{0xcdc404a9,0x9f047099,0x4a4582a7,0x00000000}},	//   _مۇشۇ_, _پولو, лнив, --, 
   {{0x44308864,0x6ca40b5e,0x08880391,0x7cc80213}},	//   zny_, _ардж, нбой_, _bərd, 
   {{0x443182a8,0x644401f7,0xd9b0129d,0x00000000}},	//   yny_, yoii, زەيد, --, 
   {{0x7cc800ac,0x0a940139,0x26c801d5,0x00000000}},	//   _sərg, _бадю, вғин_, --, 
   {{0x443003c6,0x98540276,0x3910cddb,0x6624022e}},	//   vny_, ртэш, لویز, аvkа, 
   {{0x443182a9,0x7cc800ac,0x298400c7,0x00000000}},	//   wny_, _fərd, _рыдг, --, 
   {{0x1ca80d46,0x8458ad44,0x03a582aa,0x443182ab}},	//   _བཀབ_, ерат_, ливо, tny_, 
   {{0x443182ac,0x387800d8,0x41c44721,0xaab4012c}},	//   uny_, _épra_, र्नस, _आमाक, 
   {{0x44300609,0xc1e801c0,0x644426bb,0x7cc803e3}},	// [286e0] rny_, ндаж_, roii, _zərd, 
   {{0x443182ad,0x644405da,0xf344084c,0xa34800fb}},	//   sny_, soii, упул_, езға_, 
   {{0xd1740032,0x90880014,0x00000000,0x00000000}},	//   рыуы, نمٕے_, --, --, 
   {{0xa3040b8d,0x9f8402a9,0x47a40154,0x00000000}},	//   _күбе, рҳад, গ্রী, --, 
   {{0x47dc02f5,0xff240137,0x002400f1,0xdd9496f0}},	//   যাপী, ымдо, نګړو_, аалы, 
   {{0xc2100a81,0x1ca8025c,0x6da00063,0x00000000}},	//   _أس_, _བཀད_, биља, --, 
   {{0x16b044af,0x201c02e2,0x00000000,0x00000000}},	//   _जम्ब, èvis_, --, --, 
   {{0xfa8982ae,0x00000000,0x00000000,0x00000000}},	//   нсой_, --, --, --, 
   {{0x7cc80213,0x625001f4,0x91c000cd,0x00000000}},	//   _sərd, väoj, र्वै, --, 
   {{0x32b800c8,0x9c7c02fb,0x7cc80213,0xf2d0011a}},	//   עזיד, _určo, _pərd, צעת_, 
   {{0x41c43711,0xd7f45e8e,0x9c7c0419,0xfb88022e}},	//   र्यस, азны, _krčm, _збек_, 
   {{0xab80004e,0x7cc80213,0x00000000,0x00000000}},	//   _лушк, _vərd, --, --, 
   {{0x66c982af,0x7d0805e4,0x394401c6,0x00000000}},	//   лург_, lyfs, _өндг, --, 
   {{0x41c40b7c,0x998c0024,0x00000000,0x00000000}},	//   र्मस, rodų_, --, --, 
   {{0x799982b0,0x7cc80cc1,0xe978011a,0x96e80022}},	//   matw, _hərb, _אנוש, хьҟа_, 
   {{0x79980429,0x1ca8031c,0x24f801e0,0xd8380100}},	//   latw, _བཀན_, ынсы_, grčt_, 
   {{0xe448129d,0x394c007c,0x00000000,0x00000000}},	// [286f0] القى_, _hyfs_, --, --, 
   {{0x799982b1,0xf9f80327,0x00000000,0x00000000}},	//   natw, ནཡིན_, --, --, 
   {{0x4f9582b2,0xe80c00bc,0xf56802ac,0x00000000}},	//   арлу, _हकमा_, _яшик_, --, 
   {{0x799982b3,0x76440100,0x216400cf,0xa3cc0412}},	//   hatw, lojy, стуг, _शॉप_, 
   {{0x799982b4,0x1ea80691,0x394c02d2,0x00000000}},	//   katw, هاوي_, _lyfs_, --, 
   {{0x7644037e,0xc0cc0240,0x00000000,0x00000000}},	//   nojy, _ኣሰሩ_, --, --, 
   {{0xa15982b5,0x79980526,0x7d08002d,0xed1000cc}},	//   _бару_, datw, gyfs, িপ্স_, 
   {{0x7cc80213,0x00000000,0x00000000,0x00000000}},	//   _bərb, --, --, --, 
   {{0x79980516,0xaca00248,0x00000000,0x00000000}},	//   fatw, _irọl, --, --, 
   {{0x5ec800bd,0x08c41086,0x2fdd82b6,0xa3cc01ad}},	//   লিশে, абон, _haug_, _शॉन_, 
   {{0x257c01e1,0x0c040014,0x2fdc000d,0x442401e4}},	//   _làló_, _پوشُ, _kaug_, ϲo_, 
   {{0xd8380100,0x2608000d,0x00000000,0x00000000}},	//   drčs_, _सकही_, --, --, 
   {{0x79989dc9,0x6b9982b7,0x41c489b2,0xf3fc0208}},	//   batw, maug, र्डस, _giãi_, 
   {{0x6b9982b8,0x2fdc0070,0x799802c4,0xb218037e}},	//   laug, _laug_, catw, _stæn, 
   {{0x039582b9,0x7cc800ac,0xc3940f14,0xd5ec004d}},	//   ирая, _zərb, ијањ, _quá, 
   {{0x6b9982ba,0x07a582bb,0x7cc806be,0x46e80354}},	//   naug, _таин, _hərc, _адин_, 
   {{0x27e00013,0x4224d1b4,0xf3f401fb,0xdcf848e1}},	// [28700] _iain_, адав, ợng_, tavī, 
   {{0x91c001d9,0x27e182bc,0x6b9982bd,0xc0cc02d3}},	//   र्लै, _hain_, haug, _ኣሰር_, 
   {{0x27e02af2,0x7f8404a9,0xdcf80a2b,0x6b9982be}},	//   _kain_, للان, ravī, kaug, 
   {{0x2fdc0070,0x6b9982bf,0x787c0882,0x79980230}},	//   _caug_, jaug, _jīva, zatw, 
   {{0x2fdc0953,0x27e182c0,0x799982c1,0x6b9982c2}},	//   _daug_, _main_, yatw, daug, 
   {{0x27e182c3,0x787c0265,0x3940033f,0x5ec8009e}},	//   _lain_, _līva, ększ_, লিলে, 
   {{0x79987e42,0x6b981140,0x7cc800ac,0x27e001c4}},	//   vatw, faug, _sərb, _oain_, 
   {{0x27e182c4,0xeca44103,0x799982c5,0x2fdc0ba1}},	//   _nain_, _गिरफ, watw, _gaug_, 
   {{0x9c7c1710,0x41c40303,0x7cc800ac,0x3ddc0142}},	//   _krčk, र्थस, _qərb, _tatw_, 
   {{0x27e00194,0x2fdc0457,0x200582c6,0xcee81698}},	//   _aain_, _zaug_, _homi_, _حرفن_, 
   {{0x6b9982c7,0x200582c8,0x2fdc01d4,0x4df582c9}},	//   baug, _komi_, _yaug_, _уятт, 
   {{0xb3240135,0xb8cc00ab,0x7998194f,0xddc801e4}},	//   _ལྟའང_, _ओट_, satw, _midŭ, 
   {{0x27e182ca,0x200582cb,0x799982cc,0x2c080403}},	//   _dain_, _momi_, patw, _جعلی_, 
   {{0x200582cd,0x79980227,0x27e00e89,0xb8e80276}},	//   _lomi_, qatw, _eain_, _афие_, 
   {{0x27e182ce,0x20056dad,0xf8d800e1,0x344982cf}},	//   _fain_, _oomi_, _बनिय, вчан_, 
   {{0x27e00dee,0xe4140212,0x6498022e,0x00000000}},	//   _gain_, одсь, ртёр_, --, 
   {{0x2fdc0190,0x9c7c3ad4,0x81c00183,0x00000000}},	// [28710] _raug_, _brčk, ্যন_, --, 
   {{0xf8d8068f,0x27e182d0,0x7cc800ac,0xd83802e2}},	//   _बनाय, _zain_, _xərc, prčs_, 
   {{0x2fdc0211,0x27e00198,0x200582d1,0x44b00220}},	//   _paug_, _yain_, _bomi_, _нұрс, 
   {{0x200582d2,0x2fdc0070,0xdb000162,0x27e003b9}},	//   _comi_, _qaug_, ngmó, _xain_, 
   {{0x200582d3,0x9c7c32fe,0xedd4446e,0xdfd802e8}},	//   _domi_, _frčk, илдә_, ръх_, 
   {{0x9c7c0bb8,0x41c46ace,0x6b98009f,0xb0e4031c}},	//   _grčk, र्दस, waug, སའདེ, 
   {{0x6b9982d4,0x20040793,0x2fdc0457,0xdc9800fd}},	//   taug, _fomi_, _taug_, атыш_, 
   {{0x20040048,0x2fdc004b,0x3c380318,0xcfe802da}},	//   _gomi_, _uaug_, tīva_, _حفره_, 
   {{0x6b9982d5,0x0a483633,0x9bc400db,0x00000000}},	//   raug, лзий_, تەنۉ, --, 
   {{0x6b980953,0x20040296,0xdd940032,0xe81000cd}},	//   saug, _zomi_, _мауы, ास्थ_, 
   {{0x200582d6,0x27e182d7,0xfcb40327,0x787c00b8}},	//   _yomi_, _pain_, _དཀརཆ, _pīva, 
   {{0xb21808a5,0x7d54011a,0x00000000,0x00000000}},	//   _stæl, _היעד_, --, --, 
   {{0x27e182d8,0x7bd806a9,0x7cc803be,0x603c007f}},	//   _vain_, _תקנו, _tərc, nčma, 
   {{0x27e182d9,0x7cc80213,0x00000000,0x00000000}},	//   _wain_, _həra, --, --, 
   {{0x27e182da,0x9478468b,0xbd0000e8,0xded4001f}},	//   _tain_, исту_, _ñétt, _የደን_, 
   {{0x9c7c0219,0x27e03e7c,0xd3c415bf,0x00000000}},	//   _srčk, _uain_, يتقى, --, 
   {{0x60dc02fa,0x7cc803be,0x430805d9,0x9c7c01a6}},	// [28720] _ssrm, _məra, ديءَ_, _prčk, 
   {{0x200582db,0x60dc1509,0xe810012c,0x00000000}},	//   _somi_, _psrm, ासका_, --, 
   {{0x200582dc,0x044582dd,0x247809a8,0x9c7c0010}},	//   _pomi_, _генн, _očmi_, _vrčk, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9c7c0b94,0x200582de,0x7e283334,0x201c0153}},	//   _trčk, _vomi_, ліка_, ūvio_, 
   {{0x9c7c00d7,0x200401e1,0xade00395,0x6da000d8}},	//   _hrči, _womi_, зцък, пиља, 
   {{0x7cc800ac,0x9c7c0010,0x1ee800e5,0x6da0033a}},	//   _bəra, _krči, _ھوئی_, чија, 
   {{0x5b141301,0xef14d4b3,0x90700220,0x8fd40166}},	//   жмит, рмә_, _قۇلش, _мәчә, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7cc803e3,0x88800efc,0x00000000,0x00000000}},	//   _fəra, ویون, --, --, 
   {{0xbc6582df,0x7cc803b9,0x00000000,0x00000000}},	//   _увек, _gəra, --, --, 
   {{0x6a1007d6,0x00000000,0x00000000,0x00000000}},	//   زبیر, --, --, --, 
   {{0xe84c012c,0x9c7c0024,0x00000000,0x00000000}},	//   ětší, _arči, --, --, 
   {{0xe65400d6,0x9c7c01a6,0x00000000,0x00000000}},	//   ївсь, _brči, --, --, 
   {{0x54540212,0x7cc803b9,0xdb080241,0x2934011a}},	//   іват, _xəra, _ìlór, _לאון_, 
   {{0x245882f2,0x20e80139,0xe2f80150,0x168402f2}},	// [28730] сать_, _aği_, беті_, _بابێ, 
   {{0x787c00b8,0x00000000,0x00000000,0x00000000}},	//   _jīvo, --, --, --, 
   {{0xc0c00131,0x00000000,0x00000000,0x00000000}},	//   мәти, --, --, --, 
   {{0x9c7d82e0,0x603c007f,0xb3d000fb,0x00000000}},	//   _grči, tčma, _эймә, --, 
   {{0xeea80c75,0x42a40c60,0x91c400fb,0x41c408df}},	//   утек_, _мурғ, _мәжл, र्हस, 
   {{0xf2dc002d,0x261400c5,0x603d82e1,0x7cc803b9}},	//   _dyât_, _näol_, rčma, _səra, 
   {{0x7cc803e3,0x00000000,0x00000000,0x00000000}},	//   _pəra, --, --, --, 
   {{0x7cc80cc1,0xca8582e2,0x0c080262,0xb3240327}},	//   _qəra, огий, реий_, _ལྟོང_, 
   {{0x41c4243c,0xddd400a2,0x00000000,0x00000000}},	//   र्वस, _çaşk, --, --, 
   {{0x88c81166,0x1a683e66,0x7d20004b,0x625001f4}},	//   алов_, مینی_, _ښځين, säov, 
   {{0xfe6c08dc,0x7cc80213,0x00000000,0x00000000}},	//   _شگه_, _təra, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x81c002a6,0x00000000,0x00000000,0x00000000}},	//   ্যত_, --, --, --, 
   {{0x9c7c0010,0xb3240327,0x15b802dd,0xaa6461ac}},	//   _srči, _ལྟེང_, йысы_, _утек, 
   {{0xf38402e3,0x03a401b9,0x9c7c560e,0x00000000}},	//   _ụtọa, жибо, _prči, --, 
   {{0xc32000fe,0x47dc00cc,0x419001ec,0xe8040037}},	//   _ভুগি_, যাহী, _ﺟﯘﮔﯩ, _लवटा_, 
   {{0x9c7c0e3c,0x020582e3,0xc1785211,0x64a801f9}},	// [28740] _isče, озан, асец_, गळहळ, 
   {{0x425400d4,0x00000000,0x00000000,0x00000000}},	//   ітат, --, --, --, 
   {{0x9c7c15ad,0x41c4fa4a,0x3fe40108,0x00000000}},	//   _trči, र्षस, жжев, --, 
   {{0x9c7c03c6,0xbe8982e4,0x2a7c009a,0x00000000}},	//   _urči, аске_, kqub_, --, 
   {{0xfe453acc,0x00000000,0x00000000,0x00000000}},	//   ондо, --, --, --, 
   {{0xee3582e5,0x3c3800da,0x72d019c5,0x7cc803e3}},	//   онч_, tīvo_, _تەكچ, _dərn, 
   {{0x24780100,0xb7b88d02,0x6c80004b,0x00000000}},	//   _fōme_, lhãe, ولوم, --, 
   {{0xfaa582e6,0x984c033f,0xf2dc0022,0x00000000}},	//   ошон, _iść_, _ysâ_, --, 
   {{0xf1c00327,0x2b4001c0,0xef146fe4,0x7bd40139}},	//   _feġġ_, дээг, _дмт_, _ıyud, 
   {{0xbcf401b9,0xc0f00023,0xb8e800d8,0xa7a40150}},	//   _وساغ, _ሃሰስ_, афме_, _ﻋﺸﺭﺓ_, 
   {{0xb2180008,0x62500108,0x00000000,0x00000000}},	//   _stæk, läos, --, --, 
   {{0x81c00eac,0x8ac4035b,0x00000000,0x00000000}},	//   ্যি_, цқәа_, --, --, 
   {{0x5ec80f22,0x625000c5,0x00000000,0x00000000}},	//   লিকে, näos, --, --, 
   {{0x99e8010e,0x00000000,0x00000000,0x00000000}},	//   _doňý, --, --, --, 
   {{0xe4c400c0,0x625001f4,0x37e000eb,0x00000000}},	//   мётн, häos, যাবর, --, 
   {{0xb3240135,0xb86415b4,0x937815d1,0xa8480066}},	//   _ལྟུང_, _باتو, сбат_, _ولوم_, 
   {{0xb60400a7,0x662803cd,0x00000000,0x00000000}},	// [28750] _дянк, ørkø, --, --, 
   {{0xd2504c84,0xb18803f5,0x30e800d8,0x00000000}},	//   رنا_, рсаж_, ифен_, --, 
   {{0x6ad000bd,0x7cc800ac,0x628000d8,0x6ab429d9}},	//   তিযো, _sərn, _émon, _आम्र, 
   {{0xcf900023,0xe4d49f6d,0x00000000,0x00000000}},	//   _ዝበጽሐ_, _کتیب, --, --, 
   {{0x337000c7,0xb3640395,0x41c403ce,0x00000000}},	//   _цҳар, _фънк, _रॉकस, --, 
   {{0xc2780302,0x00000000,0x00000000,0x00000000}},	//   _לרשי, --, --, --, 
   {{0x625001f4,0x00000000,0x00000000,0x00000000}},	//   räot, --, --, --, 
   {{0x70500133,0x00000000,0x00000000,0x00000000}},	//   _کۆڤا, --, --, --, 
   {{0x9f34005e,0x6ad000cc,0x7cc806be,0x00000000}},	//   _жеті, তিভো, _hərl, --, 
   {{0x77c405f5,0xe8a400fb,0x2a7c025c,0x00000000}},	//   үлэг_, обоҙ_, rqub_, --, 
   {{0x9e2400db,0x9a24007b,0xb33803b9,0x00000000}},	//   _تىلو, بعين, _heçd, --, 
   {{0xb33982e7,0x6ad000fe,0xf77000f2,0x00000000}},	//   _keçd, তিবো, کاپ_, --, 
   {{0x3f8800ac,0x2ba8033f,0x7cc803b9,0x26c400e4}},	//   _əbu_, घृणा, _lərl, îmo_, 
   {{0xc8c86ea9,0x38c800f2,0x66980107,0x0ae800ec}},	//   _هوتن_, جایی_, йёҳӣ_, _پرچي_, 
   {{0x7c6400b8,0xa8280150,0x09e000eb,0xfc4800d7}},	//   _hṛṣi, _ويتە_, বাদা, žíť_, 
   {{0xaca0063f,0xd3980032,0x7c64002b,0x00000000}},	//   _anịm, жәрә_, _kṛṣi, --, 
   {{0x41a8c156,0x96940276,0x3a700139,0xc324008e}},	// [28760] йван_, _орэш, _юләр, чмак, 
   {{0x754401d3,0x625001f4,0x00000000,0x00000000}},	//   érzé, väos, --, --, 
   {{0xdb0000d2,0x75780375,0x00c81b15,0x00000000}},	//   gamê, _לטיפ, слек_, --, 
   {{0x62800036,0x10080a11,0x0444010a,0x00000000}},	//   _émoo, يتنى_, _хемн, --, 
   {{0x443182e8,0x70501e95,0x787c00ef,0xd7c007b7}},	//   miy_, رنها, _rīvm, ष्टच, 
   {{0xe3c40323,0x443182e9,0x9f44036e,0x7cc806be}},	//   _эрүү, liy_, _hamë_, _fərl, 
   {{0x39a40491,0xeabc0ffb,0x6250005b,0xc8840112}},	//   hísí_, àùn_, säos, üßle_, 
   {{0xafe182ea,0x443182eb,0x39a402ea,0x9f44036e}},	//   _посл, niy_, kísí_, _jamë_, 
   {{0xb3380209,0x443000b5,0xade403ce,0x00000000}},	//   _geçd, iiy_, _टोकन_, --, 
   {{0x44301bb7,0x3f840005,0x7c4000f3,0x9f440240}},	//   hiy_, lcou_, _štrč, _lamë_, 
   {{0x443182ec,0xec1000aa,0x3ea400e2,0x00000000}},	//   kiy_, _ګوند, lsot_, --, 
   {{0x3f8582ed,0x443007d6,0x313402e4,0xdb0001c7}},	//   ncou_, jiy_, לנים_, namë, 
   {{0x4430006c,0x7bc00b6f,0xb3389f9b,0x7cc80213}},	//   diy_, _icou, _keçe, _mərm, 
   {{0xe07c044e,0x44300295,0xdb00036e,0x00000000}},	//   _ብጣዕሚ_, eiy_, hamë, --, 
   {{0x443007d6,0xb33982ee,0x395803b2,0x9f440200}},	//   fiy_, _meçe, _áps_, _bamë_, 
   {{0x9c7c0122,0x44300548,0x78b83bdc,0x7bc000d8}},	//   _urču, giy_, mutv, _jcou, 
   {{0x78b836b2,0x62800129,0xb88c0092,0x7cc803e3}},	// [28770] lutv, _émol, _የተፃፈ_, _sərl, 
   {{0x7ae0e27a,0xb33800a2,0x00000000,0x00000000}},	//   _msot, _neçe, --, --, 
   {{0x443182ef,0x78b8bb54,0x9f440023,0xb3380213}},	//   biy_, nutv, _famë_, _seçd, 
   {{0x7ae182f0,0xa1840598,0x443000e8,0x7cc806be}},	//   _osot, _җырл, ciy_, _cərm, 
   {{0x7ae182f1,0x9f4402e2,0x7cc800ac,0xb33800a2}},	//   _nsot, _jamè_, _dərm, _beçe, 
   {{0xb2180393,0x78b8a2ec,0x7cc803e3,0x3f840419}},	//   _quæd, kutv, _tərl, acou_, 
   {{0x7ae182f2,0x7cc800ac,0x9f4402e2,0xdb00067c}},	//   _asot, _fərm, _lamè_, lamè, 
   {{0x7bc01529,0x3f84067c,0x78b80217,0x7cc806be}},	//   _ccou, ccou_, dutv, _gərm, 
   {{0x09e0015b,0x8ca80254,0xdb00020c,0x3ea401d3}},	//   বাসা, _टिको, namè, csot_, 
   {{0xb33982f3,0x4430006c,0x7bc182f4,0x09bc0011}},	//   _geçe, ziy_, _ecou, _অসহা, 
   {{0x7ae182f5,0xf1cc28e1,0x443058a4,0x78b808fb}},	//   _esot, स्यन, yiy_, gutv, 
   {{0x443007d6,0x9cc8031c,0xdb00007f,0x7c64002b}},	//   xiy_, _གྱིས, kamè, _tṛṣi, 
   {{0x44300517,0x9f44036e,0x998c013a,0xba5000db}},	//   viy_, _ramë_, cidů_, رچۇع, 
   {{0x6ab80a55,0xdb00004e,0x9c7c0100,0xf1cc3ad3}},	//   muuf, damè, _trčt, स्मन, 
   {{0x443182f6,0x6ab80ba7,0x69c00175,0x9f440240}},	//   tiy_, luuf, _icne, _pamë_, 
   {{0x68e0003e,0x787c0171,0xb898011a,0xdb00007c}},	//   _isnd, _būvf, _ובקש, rgmö, 
   {{0x443178a7,0x6ab80ba7,0x3ea40548,0x48e4095f}},	// [28780] riy_, nuuf, xsot_, टिको_, 
   {{0x44300517,0x7cc80213,0x0134009a,0x00000000}},	//   siy_, _sərm, وعاد, --, 
   {{0x69c09af9,0x24780607,0xb33982f7,0x6ab88ebb}},	//   _mcne, _fōma_, _reçe, huuf, 
   {{0xb3380365,0x4430006c,0x6ab982f8,0x3ea54090}},	//   _seçe, qiy_, kuuf, tsot_, 
   {{0x63a582f9,0x3f8410ba,0x9f4582fa,0x6ab96edc}},	//   main, rcou_, _kamé_, juuf, 
   {{0x7bc182fb,0x3f8582fc,0xb21804ce,0x9f44020c}},	//   _scou, scou_, _stæv, _jamé_, 
   {{0xcd34044e,0x63a40421,0x7ae0031c,0xdb00036e}},	//   _እንከለ, oain, _ssot, pamë, 
   {{0x228582fd,0xdb0182fe,0x69c182ff,0x9f44003e}},	//   _kök_, lamé, _acne, _lamé_, 
   {{0x69c0004e,0x63a58300,0x6ab80ba7,0x9c7c0100}},	//   _bcne, iain, guuf, _prčs, 
   {{0x63a58301,0x78b98302,0x7ae009a8,0xdb007dec}},	//   hain, tutv, _vsot, namé, 
   {{0x63a4d073,0x7cc80cc1,0x228401e6,0x69c00175}},	//   kain, _mərk, _lök_, _dcne, 
   {{0x7ae18303,0x63a4ddee,0x78b98304,0x9c7c007f}},	//   _tsot, jain, rutv, _frčr, 
   {{0x63a58305,0x78b867df,0x7ae18306,0xfaa400ec}},	//   dain, sutv, _usot, _کهڙي_, 
   {{0x63a40b23,0x247800b0,0xaca0010e,0x69c00332}},	//   eain, _rōma_, _goỳm, _gcne, 
   {{0x63a58307,0xdb003a6c,0x2ed80782,0x9f44003e}},	//   fain, damé, _यन्त, _damé_, 
   {{0x63a58308,0x228400a2,0xdb018309,0xb3380205}},	//   gain, _bök_, tamè, _reçb, 
   {{0xd1303ff4,0xdb0006af,0x7cc803e3,0x69d00412}},	// [28790] گما_, famé, _bərk, _बॉडी, 
   {{0xdb01830a,0x63a40810,0x22841355,0x62240131}},	//   ramè, aain, _dök_, نىقل, 
   {{0xd1300597,0x7cc803b9,0x00000000,0x00000000}},	//   دما_, _dərk, --, --, 
   {{0xf72c0201,0x63a5830b,0x6ab8d988,0xdb00020c}},	//   _አንዳን, cain, yuuf, pamè, 
   {{0x0f34e326,0x22844252,0x79880c8c,0xf41c008e}},	//   رکرد, _gök_, _offw, _ilä_, 
   {{0x9f4400e8,0x00000000,0x00000000,0x00000000}},	//   _xamé_, --, --, --, 
   {{0x8fd11de3,0xf41c01e6,0x6ab804ba,0xa15801f4}},	//   _бәлә, _klä_, wuuf, _жару_, 
   {{0x2285830c,0x7cc803be,0x3eb00006,0x2d84007b}},	//   _yök_, _mərh, šyta_, scne_, 
   {{0x316001a6,0x69c00205,0x7b8400f7,0x41c4858a}},	//   _hzjz_, _pcne, رايە, र्कस, 
   {{0x63a5830d,0x6ab974f0,0x0905830e,0xf41c023a}},	//   zain, ruuf, епон, _llä_, 
   {{0x63a40cfe,0xf65c037e,0x09e0015b,0x9f4454ba}},	//   yain, rtæl_, বালা, _ramé_, 
   {{0x9f440122,0x798802d0,0x63a40077,0xf1cc00dc}},	//   _samé_, _effw, xain, स्तन, 
   {{0x63a5830f,0x6ab8208d,0xae000cf1,0x89d400d4}},	//   vain, quuf, लापन_, _зійш, 
   {{0x63a58310,0x2284e4c3,0xf41c0139,0x787c00e2}},	//   wain, _rök_, _alä_, _būvd, 
   {{0x22840628,0x63a58311,0x68e0014b,0x04447c20}},	//   _sök_, tain, _usnd, еевн, 
   {{0x3c3800da,0x63a40b23,0x7cc80213,0x228400a2}},	//   tīvi_, uain, _dərh, _pök_, 
   {{0xdb00a90d,0x41b58312,0x63a58313,0xe66400c7}},	// [287a0] tamé, есет, rain, _иеиҿ, 
   {{0x63a58314,0xa49404d3,0x7cc800ac,0xf41c248c}},	//   sain, _لیست, _fərh, _elä_, 
   {{0x63a58315,0x41c4085c,0x03a455f3,0x97440092}},	//   pain, र्गस, _пино, _ያስደስ, 
   {{0x63a40286,0x40558316,0xb2181427,0x2284655d}},	//   qain, رئاس, _stæt, _tök_, 
   {{0x7cc803be,0xe8dc063f,0x628420ac,0xb2180393}},	//   _tərk, diọm_, qqio, _quæc, 
   {{0x7cc803e3,0x00000000,0x00000000,0x00000000}},	//   _həri, --, --, --, 
   {{0x324061a9,0x7cc803be,0x51540228,0xf41c023a}},	//   _серг, _kəri, _атту, _ylä_, 
   {{0xd91087a9,0x320401d3,0x00000000,0x00000000}},	//   ییش_, önyv_, --, --, 
   {{0xb9c4036b,0xbe340137,0x7cc803b9,0xef1c0432}},	//   нёни, _كىرب, _məri, _ýüp_, 
   {{0xf3fc001e,0x7cc80213,0xb21800b5,0x6da00107}},	//   _nhãn_, _ləri, _utæt, _бифа, 
   {{0x0dc8007b,0xb3380200,0xcd2800cf,0x00000000}},	//   _تبقى_, _meça, _ۉسۅن_, --, 
   {{0x7cc800ac,0x798802d0,0x00000000,0x00000000}},	//   _nəri, _wffw, --, --, 
   {{0x7cc803be,0x8cc002a0,0x00000000,0x00000000}},	//   _sərh, रंथो, --, --, 
   {{0x7e798317,0xb3380139,0xa5e40166,0x00000000}},	//   _jitp, _neça, люсл, --, 
   {{0xf41c0793,0x787c00e2,0x7cc806be,0xa4d40212}},	//   _plä_, _būve, _bəri, лорі, 
   {{0x7cc800ac,0x3c3800e2,0x00000000,0x00000000}},	//   _cəri, būve_, --, --, 
   {{0x7cc803be,0x7e7800e4,0x6b3401e1,0xa6d401d5}},	// [287b0] _dəri, _oitp, _kámẹ, _یغیش, 
   {{0xe6c01427,0x00000000,0x00000000,0x00000000}},	//   _ónáð, --, --, --, 
   {{0xb2180212,0xb3380240,0x7cc80213,0xaee000b8}},	//   _stæs, _deça, _fəri, _kuṇa, 
   {{0x7e78035a,0xb1900131,0x7cc803b9,0xdce80205}},	//   _aitp, _әлвә, _gəri, _nedı, 
   {{0x64498318,0x7e780334,0x8d78001f,0x73c000c7}},	//   édie, _bitp, _ራሳቸው_, _аӡҕа, 
   {{0xde9400c6,0x7cc800ac,0x7e78411e,0x8d7401d9}},	//   اجنب, _zəri, _citp, پاتا, 
   {{0x7e78020c,0xaef801e2,0x00000000,0x00000000}},	//   _ditp, _کرزئ_, --, --, 
   {{0x7cc800ac,0xcec0033f,0x7e798319,0x00000000}},	//   _xəri, _pięć_, _eitp, --, 
   {{0xdce80790,0x7e780419,0x00000000,0x00000000}},	//   _dedı, _fitp, --, --, 
   {{0x08881d3e,0x9f3401ec,0x00000000,0x00000000}},	//   мбой_, _сеуі, --, --, 
   {{0xdd9400ee,0xf3fc0208,0x41c4190e,0x00000000}},	//   _сахы, _nhão_, र्टस, --, 
   {{0x7e780d27,0xb884066a,0x603c02e2,0x787c00ef}},	//   _zitp, _skíð, tčmi, _būvb, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x62804a85,0x7cc80213,0x00000000,0x00000000}},	//   _émoi, _səri, --, --, 
   {{0xf3fc0261,0xb339831a,0x603c0093,0x7cc803e3}},	//   _chão_, _reça, lōme, _pəri, 
   {{0xaee00882,0x7cc800ac,0x3cf001ad,0xc0d001f3}},	//   _guṇa, _qəri, ंटते_, _ከነሱ_, 
   {{0xb33803b7,0x59700014,0xe284036b,0x0cbc00cc}},	// [287c0] _peça, _پۯێز, اطری, _আনোত, 
   {{0xb2191577,0x417400cf,0x6448004a,0xc1741c3e}},	//   _stær, نااس, édib, ندات, 
   {{0xb338044e,0x7cc800ac,0x0444013d,0x7e78007c}},	//   _veça, _təri, _аенн, _ritp, 
   {{0xdfd1831b,0x7e7805e4,0x515400f7,0x41c4095f}},	//   صيت_, _sitp, утуу, र्जस, 
   {{0x4421831c,0x8fc4034c,0x7e780072,0xb33803e3}},	//   _ilk_, ازمن, _pitp, _heçn, 
   {{0xdcb12374,0x3205831d,0x5274074d,0x7cc803b9}},	//   مىت_, önyt_, _бусу, _mərv, 
   {{0x225805d5,0x7e7801e3,0x71d4010f,0xe6c0032e}},	//   _ikrk_, _vitp, _שולד_, _ónæð, 
   {{0x7e784471,0x26140254,0xd8380100,0x3b380b82}},	//   _witp, _käos_, nsčt_, _እስርቤ, 
   {{0x442000d8,0x7e78025c,0x201c0024,0xaee000b8}},	//   _mlk_, _titp, ūvis_, _ruṇa, 
   {{0x81c00729,0x7e78bdd0,0x4420002f,0x84e000bc}},	//   ্যক_, _uitp, _llk_, खबाट_, 
   {{0x44201368,0x71b8010f,0x661c013a,0x00000000}},	//   _olk_, וציג, dkrk, --, 
   {{0x3c38005f,0xab809b44,0x569402dd,0x92a8033f}},	//   tīvu_, _кушк, ламт, nałó, 
   {{0x0ba84d2d,0x7c21831e,0x387801fb,0x26140254}},	//   _سانى_, _ilor, _viqr_, _näos_, 
   {{0x7c21831f,0x44218320,0x77902a77,0x7cc803e3}},	//   _hlor, _alk_, دیکا, _dərv, 
   {{0x44208e96,0x58d58321,0x05d08109,0x78540345}},	//   _blk_, _сойт, द्धब, _لیدز_, 
   {{0x9f44145e,0x44218322,0x7c20007f,0x00000000}},	//   _mamâ_, _clk_, _jlor, --, 
   {{0x2458169c,0xf1a544d9,0x7c2000f2,0xdee401ec}},	// [287d0] тать_, врен, _mlor, _بۋ_, 
   {{0x7c218323,0x44218324,0x9f440228,0xdb000022}},	//   _llor, _elk_, _camí_, jamí, 
   {{0x7c218325,0x0cbc2f8b,0x4420020c,0xa8498326}},	//   _olor, _আন্ত, _flk_, _سلیم_, 
   {{0x40e40150,0x00000000,0x00000000,0x00000000}},	//   ысуғ, --, --, --, 
   {{0xf3fc0589,0xa3cc06ab,0x3c3800da,0x7cc800ac}},	//   _inã_, _शॉट_, hīvs_, _məru, 
   {{0x7c218327,0xdb0000c7,0xa194011c,0x00000000}},	//   _alor, gamí, _варч, --, 
   {{0x7c218328,0x21780209,0x623421fe,0xdce80208}},	//   _blor, _айры_, _теру, _bgdđ, 
   {{0xdea4020e,0x603c00b0,0x09bc00dc,0x00000000}},	//   _چینی, tōme, ्भ्य, --, 
   {{0x1a6827a1,0xf3fd8329,0x7c20047e,0x0a3812c4}},	//   چینی_, _mnã_, _dlor, ечны_, 
   {{0xf3fc0589,0x7c21832a,0x1a6878dd,0xb339832b}},	//   _lnã_, _elor, نینی_, _leço, 
   {{0x07a5832c,0x7cc800ac,0xd5e801f2,0x4bd4036b}},	//   ланн, _sərv, ̣ọk, _бўлу, 
   {{0xcaf42e6f,0x7c2113e4,0x7cc80213,0x00000000}},	//   _مستب, _glor, _pərv, --, 
   {{0x6b99832d,0x78b801a4,0x442002e2,0x7cc806be}},	//   mbug, artv, _rlk_, _qərv, 
   {{0x6b99832e,0x7c212cdb,0x250803e6,0xf3fc00d8}},	//   lbug, _zlor, پرسی_, _anã_, 
   {{0x2c1400cd,0x00000000,0x00000000,0x00000000}},	//   _तवां_, --, --, --, 
   {{0x4420011c,0x47c40945,0xb218003a,0x9f4402f0}},	//   _qlk_, _сбив, _quæn, _samí_, 
   {{0x4420e65e,0x9f45832f,0x7cc80213,0x8284036b}},	// [287e0] _vlk_, _mamã_, _hərt, اجرل, 
   {{0xf3fc0589,0x7cc803e3,0x6ab80e14,0x9f440139}},	//   _enã_, _zəru, iruf, _qamí_, 
   {{0x44218330,0x52758331,0xb2b000d1,0xb3381366}},	//   _tlk_, руту, _қәтъ, _heçl, 
   {{0x44218332,0x7cc800ac,0xadc00241,0xb3380139}},	//   _ulk_, _mərt, _imẹl, _keçl, 
   {{0xdb018333,0x64458334,0x6b980083,0x92a8012d}},	//   tamí, mnii, dbug, rałó, 
   {{0x69d0b4ff,0x6ab95a4f,0x7c218335,0x6b980083}},	//   _बॉली, druf, _slor, ebug, 
   {{0xdb018336,0x64458337,0xb2218338,0xa3e801ad}},	//   ramí, onii, _умрл, _मघा_, 
   {{0x64458339,0x1ab5833a,0x6b992054,0x6ab80730}},	//   nnii, абия, gbug, fruf, 
   {{0x7c20044e,0x6445833b,0xdb01833c,0x450800eb}},	//   _vlor, inii, pamí, রনিক_, 
   {{0xddc83306,0xd8f800d6,0x5a34721f,0x3c38005f}},	//   _hidž, вної_, рнот, tīvs_, 
   {{0x6445833d,0x6ab800ec,0x32540302,0x6b99833e}},	//   knii, aruf, רסים_, bbug, 
   {{0x7c2020ac,0xfaa401fe,0x6ab8002f,0xdb00015d}},	//   _ulor, _бадо, bruf, ramâ, 
   {{0x9f440998,0xb33807ea,0x64440014,0xddc80cf4}},	//   _jamà_, _reço, dnii, _midž, 
   {{0x644466db,0xda705e13,0x9f45833f,0x00000000}},	//   enii, _بُت_, _mamà_, --, 
   {{0x9f440109,0x55580801,0x6444208d,0xdb018340}},	//   _lamà_, тавя_, fnii, lamà, 
   {{0x644401d9,0x9f4400d8,0x00000000,0x00000000}},	//   gnii, _xamã_, --, --, 
   {{0x92580a16,0x644807ea,0xa8485759,0xb3380023}},	// [287f0] ваат_, édia, _حليم_, _veço, 
   {{0x64458341,0x068c08b0,0xb03001e0,0x6b980327}},	//   anii, _ﻛﻮﻣﯩ, әмдә, zbug, 
   {{0xddc800f3,0x4184e36e,0x64440009,0x7cc803b9}},	//   _bidž, ртуғ, bnii, _mərs, 
   {{0x4fc02544,0xb33806be,0x37e00154,0x00000000}},	//   تەرە, _heçm, যাকর, --, 
   {{0xddc80953,0xb33803be,0xdb000ffb,0xd5440241}},	//   _didž, _keçm, jamà, bẹ̀r, 
   {{0xdb0004cc,0x00000000,0x00000000,0x00000000}},	//   damà, --, --, --, 
   {{0x6b989033,0xe8080316,0xddc80171,0x6dc400db}},	//   tbug, षामा_, _fidž, _ۅزال, 
   {{0x6ab98342,0x8cc00412,0xe8dc0051,0x00000000}},	//   truf, रूषो, hiểm_, --, 
   {{0x62818343,0x6b992161,0xcda800c6,0x7cc80213}},	//   _émot, rbug, _لهذه_, _sərt, 
   {{0x6b9851e2,0x6ab98344,0x0d200075,0xd90c00f1}},	//   sbug, rruf, _мүлү, ځیو_, 
   {{0x5d8408e8,0x6ab80548,0x7cc800ac,0x6444331f}},	//   _المل, sruf, _dərs, ynii, 
   {{0x613c0158,0xbc34023a,0x6ab98345,0x7d1c03cd}},	//   _hålø, äätö, pruf, øpse, 
   {{0xdb000798,0x8a04005b,0xd5f40327,0x7cc806be}},	//   ramã, _взле, _བལྡབ_, _fərs, 
   {{0x9f4445a7,0x7cc800ac,0x35a0b5f5,0xb218003a}},	//   _jamá_, _tərt, жарг, _quæl, 
   {{0x9f458346,0x84598347,0x613c48a1,0x7cc80213}},	//   _mamá_, врат_, _målø, _hərr, 
   {{0x64443436,0xdb018348,0x603d61b3,0x7cc806be}},	//   unii, lamá, kōma, _kərr, 
  
   {{0x64458349,0x2bd40a28,0x97c40046,0xb33800a2}},	// [28800] rnii, भ्या, _اتىم, _heçj, 
   {{0xb338aa4a,0x9f44931c,0xdb01834a,0x613c003b}},	//   _geçm, _ramà_, namá, _nålø, 
   {{0xc0e40588,0x00c80cef,0x00e46af7,0x9f44004e}},	//   роек, тлек_, ржен, _samà_, 
   {{0xeaa400c6,0x01e4015b,0x05d0024a,0x09e000fe}},	//   _وع_, নাইদ, द्रब, বাটা, 
   {{0xdd9438c2,0x37a80183,0xcf240451,0xc0cc0023}},	//   балы, _কামৰ, ٽرني, _ኣደም_, 
   {{0x40940577,0x9c7c0841,0x6a6c1512,0x3cf001ad}},	//   _врат, _isči, løff, ंटले_, 
   {{0xdb000579,0xb33800a2,0x00000000,0x00000000}},	//   damá, _neçj, --, --, 
   {{0x20e89f19,0xdb000109,0x2e280fac,0x505801c0}},	//   _işi_, tamà, _nøff_, _бшуя_, 
   {{0x787c00da,0x5a340801,0x7d1c00d4,0x6280065c}},	//   _būvn, йнит, øpsb, _émos, 
   {{0x2478007f,0xdb01834b,0x7cc806be,0xbb480133}},	//   _dōmi_, gamá, _dərr, _یلان_, 
   {{0xf96801b9,0x1a6801d5,0x00000000,0x00000000}},	//   ърий_, نیچی_, --, --, 
   {{0xb3384a4a,0x9db80220,0x7cc803b9,0x00000000}},	//   _seçm, _шығу_, _fərr, --, 
   {{0x09e003f4,0xb3380139,0x6d480356,0x7cc803e3}},	//   বাজা, _peçm, ălaţ, _tərs, 
   {{0xaad80bd9,0xe93490b2,0x64480129,0x3a3802d2}},	//   _סחור, اسیت_, édin, _öpp_, 
   {{0xa90400aa,0xb339834c,0x7cc803e3,0x37a800fe}},	//   _نيول_, _geçj, _zərr, _কাঠৰ, 
   {{0xe9780302,0x533400db,0x00000000,0x00000000}},	//   _בנוש, бебт, --, --, 
   {{0x20e80356,0x7cc806be,0x96f83e4f,0x00000000}},	// [28810] _aşi_, _xərr, _септ_, --, 
   {{0xb33803b9,0x00000000,0x00000000,0x00000000}},	//   _heçk, --, --, --, 
   {{0xef1c0209,0xb33800fd,0x5ec0009e,0x6a6c005c}},	//   _ýüz_, _keçk, _এনগে, bøff, 
   {{0x0594034c,0x603ccf1c,0x926801e0,0x9f440306}},	//   _پایگ, tōma, трға_, _samá_, 
   {{0xd9f8a73d,0x20e805d1,0x613c0450,0xf3fc0051}},	//   ्ञात_, _eşi_, _pålø, _nhãi_, 
   {{0x764400b5,0x37e00154,0x00000000,0x00000000}},	//   nnjy, যাটর, --, --, 
   {{0x320005da,0xeb1d834d,0x76440076,0x7cc803e3}},	//   _injy_, यन्त_, injy, _bərq, 
   {{0xd045834e,0xb33800fd,0x00000000,0x00000000}},	//   _اپري, _neçk, --, --, 
   {{0x0b580372,0xdb00632c,0xfed805d9,0x2e28143a}},	//   ыркы_, tamá, _مالڪ_, _røff_, 
   {{0x9df80124,0x5e841a51,0xc3300375,0x956c001f}},	//   _кнут_, _футз, פוי_, በሩትን_, 
   {{0x7cc803be,0xdb01834f,0xddd800d7,0x00000000}},	//   _fərq, ramá, dovň, --, 
   {{0xdb0036e4,0x44886171,0x00000000,0x00000000}},	//   samá, ғбан_, --, --, 
   {{0x1cc4025c,0x4a7400cf,0x00000000,0x00000000}},	//   _ཏའོ_, _лыкт, --, --, 
   {{0x7cc803e3,0xdb0002d2,0x00000000,0x00000000}},	//   _kərp, famæ, --, --, 
   {{0x07a58350,0x64480120,0x2e28168c,0x6cf401ad}},	//   _лайн, édio, _tøff_, ंटिग_, 
   {{0x3eb002d5,0x320006d9,0x69d001ad,0xb3380205}},	//   šyti_, _anjy_, ब्री, _geçk, 
   {{0xca740201,0xddd98351,0x741000c6,0xa92000bc}},	// [28820] _አሁንም_, bovň, أوقا, ěžuj, 
   {{0xddd800d0,0xb3380790,0x73780107,0x00000000}},	//   covň, _meçh, урсӣ_, --, 
   {{0xf77c0261,0xe0586694,0x7f846caa,0x1cc4031c}},	//   meça_, لیست_, ملان, _ཏའེ_, 
   {{0xf77c0798,0xf65c365a,0x00000000,0x00000000}},	//   leça_, stæt_, --, --, 
   {{0xcfa808dc,0x9c7c007f,0x00000000,0x00000000}},	//   شانم_, _trčz, --, --, 
   {{0x7cc803be,0xf77c0798,0xdb018352,0x00000000}},	//   _bərp, neça_, lamç, --, 
   {{0x20e80311,0xdd9401e0,0x2f8802dd,0x787c00de}},	//   _uşi_, баһы, _ﯗﻛﯩﻢ_, _būvl, 
   {{0x9c7c01a6,0x603c02b5,0xf65c0ac8,0xeb940640}},	//   _opče, mōmo, ntær_, бић_, 
   {{0x20040113,0x9c7c007f,0xf1cc16d1,0x320000a2}},	//   _inmi_, _osčv, स्कन, _ynjy_, 
   {{0xb3380cc1,0xef158353,0xd1d00023,0xdb015545}},	//   _seçk, _уму_, _ብቤት_, hamç, 
   {{0xf77c0798,0x2004282c,0xddd800d7,0xed541188}},	//   deça_, _knmi_, vovň, _лоф_, 
   {{0xbb840597,0x644806af,0xf3fc0051,0x00000000}},	//   _الإي, édil, _thãi_, --, 
   {{0x6bc400e4,0x00000000,0x00000000,0x00000000}},	//   ẽhág, --, --, --, 
   {{0x65958354,0xf1c42366,0x00000000,0x00000000}},	//   зару, _लाइन, --, --, 
   {{0x439444fc,0xdb000205,0xddd800d7,0x00000000}},	//   _ọrụ_, famç, rovň, --, 
   {{0x53987afc,0x2898010f,0xddd800d7,0x64984109}},	//   рвая_, _גיהא, sovň, стёр_, 
   {{0xb33811a9,0xf77c03b7,0x853c0092,0xf36400d8}},	// [28830] _keçi, beça_, ደሚፈጥ, ствн, 
   {{0x20040309,0x9c7c16a3,0x80e000cc,0xdb000821}},	//   _anmi_, _isču, ফিন্, mamä, 
   {{0xdb000724,0xb3380200,0x31680063,0xf65c005c}},	//   lamä, _meçi, ушао_, træf_, 
   {{0xf65c02d2,0x00000000,0x00000000,0x00000000}},	//   fræg_, --, --, --, 
   {{0x287c00c8,0xdb01549b,0x9f4400a2,0x00000000}},	//   אנאמ, namä, _namä_, --, 
   {{0xae001ab2,0x200402e2,0xb33803b9,0xdea40345}},	//   लाइन_, _enmi_, _neçi, سیمی, 
   {{0xdb000054,0xf41c0793,0x00000000,0x00000000}},	//   hamä, _tiäd_, --, --, 
   {{0xdb018355,0xa4b80302,0x787c00e2,0x7d1c0fac}},	//   kamä, צלחה_, _būvm, øpsa, 
   {{0xdb018356,0x4a740022,0x00000000,0x00000000}},	//   jamä, жынт, --, --, 
   {{0xf7c800bc,0x09e401c6,0x7cc80213,0x00000000}},	//   ážní_, цоон, _tərp, --, 
   {{0xb3380200,0xf1c46d65,0x00000000,0x00000000}},	//   _deçi, _लाईन, --, --, 
   {{0xe8dc07ae,0x38c80133,0xb33803e0,0x00000000}},	//   hiệm_, گایی_, _teçh, --, 
   {{0x89d40212,0xdb00f6b3,0x00000000,0x00000000}},	//   _дійш, gamä, --, --, 
   {{0xb3390a1d,0xf7718357,0x38c8bb0b,0x00000000}},	//   _geçi, باپ_, دایی_, --, 
   {{0xf77d8358,0xddd00327,0x4414022e,0x00000000}},	//   reça_, _ġeżr, офат, --, 
   {{0xdb0000c5,0x38c803e6,0xf1c400bc,0x446400d4}},	//   bamä, _ئاوی_, _लाउन, івав, 
   {{0xf77c0798,0x41a98359,0x05080154,0x00000000}},	// [28840] peça_, иван_, রনের_, --, 
   {{0xc4e47863,0x00000000,0x00000000,0x00000000}},	//   _джой, --, --, --, 
   {{0xae003daa,0xbf884727,0xbfa84b1f,0xdb0021e3}},	//   लाईन_, абеж_, атле_, mamå, 
   {{0x70503009,0x247800b0,0xd5b001fb,0xdb01835a}},	//   ونلا, _pōmu_, ức_, lamå, 
   {{0xdd94eaae,0x4375835b,0x787c00de,0xf410011a}},	//   палы, _фунт, _būvj, _חפר_, 
   {{0xf4840344,0x00000000,0x00000000,0x00000000}},	//   _دایی, --, --, --, 
   {{0xb339835c,0x1f8401af,0x00000000,0x00000000}},	//   _reçi, _еҫен, --, --, 
   {{0xb33851b7,0x5b15835d,0xef140032,0xae00012c}},	//   _seçi, змит, смә_, लाउन_, 
   {{0xdb000158,0xba08e41f,0xb338467e,0x00000000}},	//   kamå, ахне_, _peçi, --, 
   {{0xfce5835e,0xee341734,0xd12c00f7,0xa6d000cc}},	//   _мозо, _дну_, _جۅۅ_, িবাট, 
   {{0x1cc40f50,0xbd440451,0xdb0001e6,0x8e7445c9}},	//   _ཏའི_, _بناي, damå, _хутч, 
   {{0xb7b80022,0x28d800c5,0xdb01835f,0x195800c7}},	//   akãn, _बहरि, tamä, иаҿы_, 
   {{0xec1004d3,0xb33806be,0xe78401e5,0x59f80108}},	//   _توند, _heçv, дуро, _геля_, 
   {{0xdb0026bb,0x00000000,0x00000000,0x00000000}},	//   ramä, --, --, --, 
   {{0xdb001057,0xe65400d4,0x00000000,0x00000000}},	//   samä, євсь, --, --, 
   {{0xdb0001f1,0x00000000,0x00000000,0x00000000}},	//   pamä, --, --, --, 
   {{0xf77c0261,0xe8e4025c,0x3cfc07c5,0x463801f3}},	// [28850] meço_, _འགོག, _lrtv_, _አህጉራ, 
   {{0x7ae18360,0x628002e8,0x3cfc05d5,0xf1c001fb}},	//   _mpot, _èmol, _ortv_, _giờ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x47c02158,0x4cb800eb,0x00000000,0x00000000}},	//   ষ্ঠী, _আহলু, --, --, 
   {{0x5f380212,0x00000000,0x00000000,0x00000000}},	//   опця_, --, --, --, 
   {{0x787c00de,0x00000000,0x00000000,0x00000000}},	//   _būvk, --, --, --, 
   {{0xe8e449a6,0x00000000,0x00000000,0x00000000}},	//   _འགེག, --, --, --, 
   {{0x4aa801ee,0xc310015b,0x7ae001e7,0x3cfc01bf}},	//   бкин_, _সেটি_, _bpot, _drtv_, 
   {{0xeb9484bc,0x0b458361,0x2fdc009a,0xf77c06ed}},	//   биқ_, янин, _ibug_, deço_, 
   {{0x88c801b9,0x37a800fe,0x6d0400ae,0xf7ac00d1}},	//   блов_, _কাষৰ, _وباق, _ﻳﯩﻤﻪ, 
   {{0x7ae18362,0xdb0005ac,0xd018012d,0xe80801f9}},	//   _epot, vamå, _koń_, षाला_, 
   {{0xdd1001ef,0x00000000,0x00000000,0x00000000}},	//   _nýřa, --, --, --, 
   {{0x7ae00327,0xd79000b8,0xae1c00cd,0x00000000}},	//   _gpot, _aṃsa_, _भवान_, --, 
   {{0x2bd400dc,0x00000000,0x00000000,0x00000000}},	//   भ्रा, --, --, --, 
   {{0xaee006d6,0xd4d402d5,0x03a401a9,0x00000000}},	//   _muṱa, мітэ, зибо, --, 
   {{0x044495be,0x7ae00857,0x00000000,0x00000000}},	//   чебн, _ypot, --, --, 
   {{0x27e18363,0xe8d80f90,0x24780092,0x00000000}},	// [28860] _ibin_, _बहुच, _በእርስ_, --, 
   {{0x2fdc089c,0xd5b00208,0xaad05a17,0x00000000}},	//   _abug_, ứa_, _दमनक, --, 
   {{0x2efc3223,0x27e0002d,0x80047e7e,0x2f2000de}},	//   _aruf_, _kbin_, зчле, _līgā_, 
   {{0xf3ec001e,0xea9c0943,0x68e00109,0x3c2800e4}},	//   _ۣۣۜ_, heṱo_, _mpnd, _oùva_, 
   {{0x27e00399,0xbd6805a2,0x3cfc0356,0x33f80375}},	//   _mbin_, әрле_, _srtv_, _ההכנ, 
   {{0x63a58364,0xce3400aa,0x52740137,0x13b00eac}},	//   lbin, وونک, _жусу, _ছায়, 
   {{0x50b51f7c,0x27e18365,0x16a8000d,0x9c7c00ef}},	//   _осту, _obin_, _कब्ब, _apča, 
   {{0x63a58366,0xeb940063,0x00000000,0x00000000}},	//   nbin, пић_, --, --, 
   {{0x63a58367,0x7f740323,0xe8e40135,0xa9b80ed1}},	//   ibin, _хувц, _འགུག, ﻠﻤﯩﺴ, 
   {{0x27e04437,0x63a4045d,0x98b98368,0x2fdc05c7}},	//   _abin_, hbin, олот_, _zbug_, 
   {{0x27e00083,0x3b84a9e8,0xef1c0037,0x00000000}},	//   _bbin_, _елег, _üür_, --, 
   {{0x63a40399,0x09dc0154,0x8ac40124,0x00000000}},	//   jbin, _ভোদা, чқәа_, --, 
   {{0x7ae00bb8,0xf77c03b7,0x27e00175,0x68e003ac}},	//   _upot, reço_, _dbin_, _epnd, 
   {{0x63a41559,0x82b80327,0xb3380139,0x998c0010}},	//   ebin, _བྷེའ, _meçt, lidž_, 
   {{0x1c200c2e,0xf77c00d8,0xe4e400d3,0x3e70054e}},	//   _बवाल_, peço_, нітн, câte_, 
   {{0x63a58369,0xd2509105,0x27e00248,0xdcf8247e}},	//   gbin, ھنا_, _gbin_, navı, 
   {{0x798803ac,0xd2500532,0x67bc0375,0x00000000}},	// [28870] _kgfw, پنا_, _המחק, --, 
   {{0x63a4102c,0xb189836a,0xb5a48748,0xd018010b}},	//   abin, ссаж_, _эрий, _soń_, 
   {{0x1ad82158,0xb3387c93,0x7d1c00d4,0x90981422}},	//   তিয়া, _reçu, øpsl, цвет_, 
   {{0x2efc05b1,0x35d00cb4,0x27e00327,0x787c262b}},	//   _pruf_, _ताड़, _xbin_, _būvi, 
   {{0xe6100e3f,0xc0fc01ec,0xdcf808a9,0x00000000}},	//   _ششی_, _ءﻣﯘﺭ, davı, --, 
   {{0x2f200029,0x9e3400d3,0x00000000,0x00000000}},	//   _rīgā_, нечч, --, --, 
   {{0xb3380023,0xcfb400a7,0x00000000,0x00000000}},	//   _veçu, _обвъ, --, --, 
   {{0x13b000bd,0xaca0063f,0x9f44011c,0x2efc0135}},	//   _ছাড়, _haịm, _lamù_, _truf_, 
   {{0xb3380365,0x2efc05b1,0x5f840150,0x00000000}},	//   _geçt, _uruf_, _كۇمە, --, 
   {{0x8c8800c6,0x63a40399,0x66e4032e,0x00000000}},	//   _дшдғ_, zbin, _líkö, --, 
   {{0x63a5836b,0x798802d0,0xb33803e3,0x70a8000d}},	//   ybin, _dgfw, _keçs, _चबोल, 
   {{0x63a40369,0x3c2800e4,0x3e70054e,0x00000000}},	//   xbin, _tùva_, râte_, --, 
   {{0xc5f0015b,0x787c0055,0xd83802bd,0x9f4400d7}},	//   ঞাসা_, _jīvy, nsčy_, _samú_, 
   {{0x59d41df1,0xc5fc0eac,0x00000000,0x00000000}},	//   _दायर, ুস্থ_, --, --, 
   {{0x63a4bb30,0x366401f0,0x00000000,0x00000000}},	//   tbin, фаро_, --, --, 
   {{0x27e04405,0x985400c7,0x63a40153,0x82b80327}},	//   _ubin_, _птыш, ubin, _བྷུའ, 
   {{0xf7d40375,0xd1740124,0x00000000,0x00000000}},	// [28880] _חופש_, ҭыхы, --, --, 
   {{0x63a5836c,0xc2080116,0x00000000,0x00000000}},	//   sbin, غقان_, --, --, 
   {{0x6aa80399,0xb33803ee,0xfcc80092,0x63a40051}},	//   _lwgf, _seçt, _በቅጡ_, pbin, 
   {{0x70501176,0x63a40455,0xb4f80677,0x00000000}},	//   پنها, qbin, _ולטר, --, 
   {{0x91ac0183,0x2bd400c5,0x00000000,0x00000000}},	//   _চাৰ্, _भउजा, --, --, 
   {{0x787c00b8,0xdb005522,0x8db400d1,0x25ac022e}},	//   _dīvy, mamø, ىشىچ, аdli_, 
   {{0x7cc806be,0x6be000d1,0x7e800150,0x6d4402d2}},	//   _hərz, چكىم, _ﺨﺎﺼﺎ_, _þjal, 
   {{0xb33841b5,0x603c02b5,0x7cc803b9,0x4f080137}},	//   _geçs, kōmi, _kərz, تتۅپ_, 
   {{0x998c009b,0x6e90007b,0x798802d0,0x00000000}},	//   ridž_, _للقا, _pgfw, --, 
   {{0xb33803b9,0x7cc803b9,0x7c2c0064,0x00000000}},	//   _keçr, _mərz, _įbru, --, 
   {{0xa3c052f2,0x7cc806be,0x00000000,0x00000000}},	//   ीला_, _lərz, --, --, 
   {{0xdb000158,0x7e680162,0x98ac00ef,0x00000000}},	//   kamø, llfp, gzdā_, --, 
   {{0x4431836d,0x69c40210,0x00000000,0x00000000}},	//   dhy_, ójec, --, --, 
   {{0x2b18012c,0x877001e0,0x00000000,0x00000000}},	//   यहरु_, ығыш, --, --, 
   {{0xa4d400d4,0x156800ec,0xea6000ec,0x6594a99d}},	//   корі, سٽري_, _جهوپ, тасу, 
   {{0x4431836e,0xeab40184,0x7cc803b9,0x00000000}},	//   ghy_, _эйә_, _bərz, --, 
   {{0xa6f40022,0x787c00e2,0x00000000,0x00000000}},	// [28890] _азыш, _būvv, --, --, 
   {{0x44300170,0x6f0c0561,0x3c2800e4,0x7cc803b9}},	//   ahy_, _àcci, _oùvo_, _dərz, 
   {{0xc5f00375,0x787c00b8,0x998c00c0,0x443000b8}},	//   _גדי_, _sīvy, lidų_, bhy_, 
   {{0x44302201,0x7cc803e3,0x8f740153,0x00000000}},	//   chy_, _fərz, нулі, --, 
   {{0xaca0063f,0xb3380023,0xb2180381,0x6448004e}},	//   _taịm, _veçs, _quæs, èdie, 
   {{0x82b80327,0xd0d402e8,0x00000000,0x00000000}},	//   _བྷིའ, _погъ, --, --, 
   {{0x3ab00032,0xb33800a2,0x00000000,0x00000000}},	//   ңәшт, _geçr, --, --, 
   {{0x3f100166,0x00000000,0x00000000,0x00000000}},	//   тдәс, --, --, --, 
   {{0xca840323,0x9f04004b,0xeb940131,0x7cc803e3}},	//   нгий, _ټولو, пиқ_, _məry, 
   {{0xf1ac0e49,0x89d401c8,0x00000000,0x00000000}},	//   टरिन, رتخط, --, --, 
   {{0x9e2400cf,0x95740023,0x4430035b,0x00000000}},	//   _جىلو, ረኸበን_, yhy_, --, 
   {{0x3e70025a,0xdce800e2,0x37a800fe,0x00000000}},	//   mâta_, _uzdā, _কাউৰ, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x5b240022,0x7f38010f,0x461401fd,0x00000000}},	//   _шьха, לערו, روزر, --, 
   {{0x6458032e,0xf77c0327,0xab2401af,0x00000000}},	//   _ívik, ħħak_, _хоҙа_, --, 
   {{0x3e8401e1,0x787c00e2,0x00000000,0x00000000}},	//   _kítì_, _būvu, --, --, 
   {{0x4431836f,0xb3380139,0x020490d2,0x03f00011}},	// [288a0] rhy_, _beçq, нзан, ঙালী_, 
   {{0x82641ec7,0xdb0005ac,0x4430b77d,0x7d1c0fac}},	//   رهان, ramø, shy_, øpsk, 
   {{0xbfc58370,0x44318371,0x8b0400bc,0x7cc803e3}},	//   ебек, phy_, _hořč, _fəry, 
   {{0xbe8815ed,0x76880034,0xb2180381,0x7cc800ac}},	//   пске_, _użyc, _quær, _tərz, 
   {{0x1df80b7e,0x6fb0484d,0x63e401ec,0xe2858372}},	//   делы_, امها, _كيگە, _аған, 
   {{0xe8dc02e3,0x7a4401e1,0xa2840133,0x00000000}},	//   ghịm_, _métè, _شیاو, --, 
   {{0x7ccc00e5,0xec300116,0x00000000,0x00000000}},	//   dőrá, گۈنگ, --, --, 
   {{0xfaa46a7c,0xb33800a2,0x00000000,0x00000000}},	//   ншон, _keçp, --, --, 
   {{0x3ea4036b,0x1e8400c7,0xbea800ec,0xdf6400c7}},	//   _чизг, _акаҭ, _رهان_, _рнаҩ, 
   {{0x6b700032,0xab718373,0x8f753540,0x00000000}},	//   ылыу, ыгыш, _русі, --, 
   {{0xf65c01a8,0x261401ad,0x6da18374,0xada02360}},	//   fræn_, दानी_, _сиха, _сахл, 
   {{0xdecc0020,0x6a6c0158,0x17a4069d,0xac94007b}},	//   _አቡነ_, bøfo, _ገንዘቡ_, _أننا_, 
   {{0xfa4800cf,0x00000000,0x00000000,0x00000000}},	//   _ىشتى_, --, --, --, 
   {{0x8754001f,0xaa54007b,0xe66401c6,0x998c00c0}},	//   _የፕሮጀ, _كلنا_, гтсо, ridų_, 
   {{0x92bc0183,0xe4c58375,0x7d1c03cd,0x787c0171}},	//   _আহে_, лётн, øpsh, _būvt, 
   {{0x24198376,0x998c0064,0x00000000,0x00000000}},	//   носы_, pidų_, --, --, 
   {{0x78b98377,0xe4558378,0x31c40120,0xf77c010b}},	// [288b0] lstv, укты, есев, keçi_, 
   {{0x958c001f,0x799803ac,0xf77c00a2,0x00000000}},	//   ጅታችን_, nctw, jeçi_, --, 
   {{0x78b80118,0xb218003a,0xd7c40490,0x76449d12}},	//   nstv, _quæq, _वयाच, mijy, 
   {{0x64498379,0x76440699,0x603c02b5,0x78b86327}},	//   édit, lijy, kōmu, istv, 
   {{0x81e4009e,0x4df40395,0x00000000,0x00000000}},	//   ভয়_, вяйт, --, --, 
   {{0x26140bc0,0x2284009d,0x7bc534a5,0x6d4402d2}},	//   दायी_, _бусг, ókun, _þjak, 
   {{0x9164034c,0xb7b800e4,0xa1585b66,0x216801f0}},	//   _شهره, akãi, _зару_, _зиёи_, 
   {{0x5fd80c66,0x3e70098c,0xa3e40b4c,0x00000000}},	//   _डायल, râta_, प्प_, --, 
   {{0xce9400c9,0x7645837a,0xed8801ec,0x504401ec}},	//   _разъ, kijy, _есек_, _зеңб, 
   {{0x3b804afc,0xca4c0150,0x3a200022,0x1fbc0154}},	//   шлыг, _ﺃﻜﺒ_, имыг, _ইউএস, 
   {{0x637800d2,0xaca0063f,0x290037b5,0x78b9837b}},	//   _kúní, _kpọl, íja_, gstv, 
   {{0xdb0002f0,0x6378032e,0x3e840248,0xe7b000eb}},	//   lamý, _júní, _títì_, কল্য, 
   {{0xfc440232,0xf65c3b9d,0x7cc80213,0x764402e2}},	//   ších_, rræn_, _sərx, fijy, 
   {{0xb6a02838,0x6ab801e4,0xa3e400bc,0x26e400fe}},	//   рирл, msuf, प्न_, খিলো_, 
   {{0xf41c0589,0x6ab805f7,0x78b815b2,0x6fb00073}},	//   _boä_, lsuf, cstv, ुणां, 
   {{0x6b99837c,0x7d1c0fac,0x3dc800eb,0x00000000}},	//   ncug, øpsi, ল্পল, --, 
   {{0x76440230,0xd04c013f,0x9f4402d2,0x00000000}},	// [288c0] bijy, _ɔkɔh, _samþ_, --, 
   {{0x7cc803b9,0xa4945b74,0x00000000,0x00000000}},	//   _tərx, _میست, --, --, 
   {{0x644873a0,0x25b801ab,0x00000000,0x00000000}},	//   édis, marl_, --, --, 
   {{0x7f4810fe,0x7f846caa,0x25b80129,0xf41c002f}},	//   ولاق_, نلان, larl_, _goä_, 
   {{0x78b9837d,0x637801e1,0x66f41025,0x6a6c03cd}},	//   zstv, _dúní, ेटिक_, tøfl, 
   {{0x71a00364,0x2481837e,0x78b9837f,0x25b80413}},	//   _варз, lmim_, ystv, narl_, 
   {{0x32418380,0x61fd8381,0x6d5c9c13,0x6a6c0158}},	//   _терг, _iarl, şqan, røfl, 
   {{0x61fd34dd,0x6b98003c,0x76440526,0x603c00b0}},	//   _harl, gcug, zijy, tōmu, 
   {{0x61fd8382,0xa3e42cbc,0x76440526,0x25b98383}},	//   _karl, प्य_, yijy, karl_, 
   {{0x78b80bb3,0x61fd8384,0x248001a9,0x8c64004e}},	//   tstv, _jarl, hmim_, ктөд, 
   {{0x61fc0af5,0x3ea58385,0x6ab8013c,0x02dc00af}},	//   _marl, lpot_, asuf, नझुन, 
   {{0x6b98026c,0x61fd8386,0xca4c0150,0x7b64db2e}},	//   ccug, _larl, _ﺃﻜﺜ_, _итле, 
   {{0x61fd1e80,0x3ea402bd,0x7bc00295,0x78b81e00}},	//   _oarl, npot_, _idou, sstv, 
   {{0x78b93b4d,0x3b04036b,0x61fd8387,0x67200267}},	//   pstv, _iroq_, _narl, ämja, 
   {{0x76458388,0xdb000254,0x7bc001ef,0x2398110e}},	//   rijy, hamü, _kdou, _ọja_, 
   {{0x61fd8389,0xe4551056,0xdb01838a,0x9f44022a}},	//   _aarl, аксы, kamü, _samý_, 
   {{0x61fd838b,0xa8580375,0xdb01838c,0x9f440332}},	// [288d0] _barl, _שיחה_, mamó, _mamó_, 
   {{0xdb01838d,0x644806af,0x98ac012d,0x00000000}},	//   lamó, édir, azdą_, --, 
   {{0x61fd838e,0xf41c01b8,0x3b04022e,0x3ea401a4}},	//   _darl, _toä_, _lroq_, epot_, 
   {{0x7bc1838f,0x61fc43ef,0xdb000793,0x3ea4257c}},	//   _ndou, _earl, famü, fpot_, 
   {{0x01b00154,0x00000000,0x00000000,0x00000000}},	//   _চারদ, --, --, --, 
   {{0x7bc18390,0x61fd8391,0x9e640153,0x20dc01e1}},	//   _adou, _garl, авід, bíi_, 
   {{0x8c44e2d8,0x3b0401d5,0x6a6c0158,0x20980137}},	//   леке, _aroq_, bøfj, _аксы_, 
   {{0x6ab98392,0x61fc2c3c,0xaab4158b,0xdb00db98}},	//   tsuf, _zarl, نگتر_, bamü, 
   {{0x61fc00fd,0xc0f40023,0xdb018393,0x00000000}},	//   _yarl, _ወቐሳ_, damó, --, 
   {{0x7bc18394,0x6b998395,0x61fc002e,0x6ab98396}},	//   _edou, scug, _xarl, rsuf, 
   {{0x24800113,0x2d800ca8,0x00000000,0x00000000}},	//   ymim_, _àje_, --, --, 
   {{0xdb00148b,0xc17000d9,0x9cc801af,0x00000000}},	//   gamó, מחי_, _шыуа_, --, 
   {{0x09e58397,0xf3fc00e4,0x7d1c1445,0x7c3c017a}},	//   _болн, _akão_, øpsv, ëpre, 
   {{0x7f38010f,0x00000000,0x00000000,0x00000000}},	//   געשו, --, --, --, 
   {{0x69c0dac9,0x04958398,0xb8e80183,0x61fc0205}},	//   _idne, الرح, _ৰৈ_, _rarl, 
   {{0x61fd8399,0x29040115,0x543401c0,0x248004a7}},	//   _sarl, _irna_, ахуу, umim_, 
   {{0x25b9839a,0x9f4402e2,0x24805d49,0xdb000ba1}},	// [288e0] parl_, _lamò_, rmim_, lamò, 
   {{0x2904511d,0x2480442d,0xc1740633,0xdb000254}},	//   _krna_, smim_, هدات, vamü, 
   {{0x16446073,0x3e70019f,0x04440139,0x814442b5}},	//   _түрк_, wâto_, _бенн, دنان, 
   {{0x61fd839b,0xbfb4837d,0x2905839c,0xdfd04706}},	//   _warl, احات, _mrna_, زيت_, 
   {{0x6d5d839d,0x4421839e,0x2c1400dc,0x7a340129}},	//   şqal, _iok_, थानं_, _hâte, 
   {{0x44200652,0x2905839f,0x9f440332,0xfaa40107}},	//   _hok_, _orna_, _samó_, қшин, 
   {{0x3ea583a0,0x442183a1,0x41000131,0x9f440ca8}},	//   spot_, _kok_, _ھېچك, _pamó_, 
   {{0x3b0407d6,0x69c16c23,0x3ea4030a,0xef144eac}},	//   _proq_, _adne, ppot_, тмә_, 
   {{0x5a348262,0x442183a2,0x290583a3,0xa3dc05f9}},	//   инит, _mok_, _arna_, _ठान_, 
   {{0xa3e40d0d,0x01b000bd,0x290400bc,0xe23001ec}},	//   प्त_, _চাঁদ, _brna_, йтiн_, 
   {{0x4420cf32,0x29040bb8,0x26c183a4,0x80e0015b}},	//   _ook_, _crna_, _avio_, ফিক্, 
   {{0x44207a1e,0x7bc00921,0x69c183a5,0x107c0131}},	//   _nok_, _udou, _edne, ﺭﯨﺪﯨ, 
   {{0xdb0183a6,0x69c002c4,0x290583a7,0xec742096}},	//   ramó, _fdne, _erna_, _спц_, 
   {{0x7c2183a8,0x442183a9,0x7a340129,0x7b6401e0}},	//   _hoor, _aok_, _bâte, _итһе, 
   {{0x7a34084c,0xdb0000d8,0x9c7c00c0,0x58d401ec}},	//   _câte, pamó, _apči, _тойт, 
   {{0x44200365,0x69c183aa,0x7c2183ab,0x00000000}},	//   _cok_, _zdne, _joor, --, 
   {{0x44201326,0x7c2183ac,0xf1a40209,0x69c0035a}},	// [288f0] _dok_, _moor, грен, _ydne, 
   {{0x7c2183ad,0x4420000d,0xe2c8027d,0x237800d1}},	//   _loor, _eok_, اولو_, ھمەد_, 
   {{0x442183ae,0x7a3407ea,0xa40001ad,0x92e40154}},	//   _fok_, _gâte, _लोकप_, পটে_, 
   {{0x7c2183af,0x442183b0,0xe8d406a9,0xa194016c}},	//   _noor, _gok_, רואר_, _ҳарч, 
   {{0xfcc80092,0x00000000,0x00000000,0x00000000}},	//   _በህገ_, --, --, --, 
   {{0x7a3407a8,0xa194b155,0x2bb4012d,0x00000000}},	//   _yâte, _гарч, _इजहा, --, 
   {{0x442183b1,0x7c2183b2,0xa3dc561f,0xabc00184}},	//   _yok_, _boor, _ठाम_, байҙ, 
   {{0xf3fc0589,0x6280468a,0x290583b3,0x44201180}},	//   _jaã_, _èmor, _rrna_, _xok_, 
   {{0x290405ce,0x7c212879,0xdec8014b,0x7c2583b4}},	//   _srna_, _door, _бухл_, ökra, 
   {{0x4a44f6a1,0xdb00004e,0x26c437b5,0x8cc401f7}},	//   рнов, tamò, ámom_, _نقطه, 
   {{0x7c2183b5,0x4c9402dd,0x661c0175,0x7d1c143a}},	//   _foor, _тиес, vjrk, øpst, 
   {{0x7c2183b6,0xb6997e82,0x7a3406af,0xf65c01bf}},	//   _goor, rvân, _râte, bræk_, 
   {{0x29040a2e,0x2ba80316,0x76d80107,0x9aa442ed}},	//   _wrna_, _ट्या, курӣ_, _همنو, 
   {{0x442183b7,0xbb3823e4,0x7a3407ea,0xf41c013d}},	//   _sok_, _בעני, _pâte, _kiäw_, 
   {{0x442183b8,0x290583b9,0x07a583ba,0x6a6c0158}},	//   _pok_, _urna_, _кайн, jøfi, 
   {{0x7c200067,0x261405c0,0x00000000,0x00000000}},	//   _xoor, दाही_, --, --, 
   {{0xc24583bb,0xa3dc00e1,0x070800ec,0xd5ec0208}},	// [28900] анак, _ठाठ_, _شيدي_, _quạ, 
   {{0x4420398e,0xb77802e4,0xf990010f,0xb6b8011a}},	//   _wok_, _באפש, ַרד_, _שציי, 
   {{0x442183bc,0xf3fc00d8,0x6fec0055,0x00000000}},	//   _tok_, _faã_, _ṛcai, --, 
   {{0x996800df,0x00000000,0x00000000,0x00000000}},	//   ניאַ_, --, --, --, 
   {{0xe7e983bd,0x7c2183be,0xefb007d6,0x3eb0007f}},	//   ट्या_, _roor, زیلگ, èyt_, 
   {{0x7c2183bf,0xc21001d9,0xfcc8001f,0x2d9001e0}},	//   _soor, _بٔس_, _በህግ_, ҙрәс, 
   {{0xed4cdc7e,0x320407a8,0x7fd40024,0xd12c00f7}},	//   وپه_, ônye_, _візі, _كۅك_, 
   {{0xf65c037e,0x7c2183c0,0x19583419,0x3ea4020f}},	//   træk_, _qoor, ғамы_, _виаг, 
   {{0x7c2151e9,0xd1e0001f,0x2bb41f14,0x19c418c7}},	//   _voor, _ሐሳብ_, _इजरा, бәйг, 
   {{0x7c2183c1,0x5a34d70d,0xfd100133,0x7d1c03cd}},	//   _woor, снот, _وجا_, øpss, 
   {{0xa3dc000d,0xed54014b,0xae4000e5,0x00000000}},	//   _ठाढ_, _коф_, _بھنو, --, 
   {{0xfb84010b,0x33cc01ec,0x00000000,0x00000000}},	//   _кылн, _ﯗﻧﺎﻣ, --, --, 
   {{0xaca0010e,0x00000000,0x00000000,0x00000000}},	//   biỳa, --, --, --, 
   {{0xa3e43d60,0xf3fc0589,0xaca0010e,0x4e1800cd}},	//   प्स_, _saã_, ciỳa, पायै_, 
   {{0xf3fc0004,0x77916e8a,0xaa5802dd,0x00000000}},	//   _paã_, _ویدا, _шешi, --, 
   {{0x57b43d2a,0x35d00210,0x00000000,0x00000000}},	//   _убит, _ताक़, --, --, 
   {{0x92580261,0x33840aac,0xa3c8012d,0x257c013a}},	// [28910] гаат_, рувв, _ईयर_, _pálí_, 
   {{0xe7e8006d,0xf1a4aaf9,0xb1a4bb5c,0xdce80210}},	//   ट्ठा_, рран, ршак, _wzdę, 
   {{0x26141889,0x96e8004b,0x257c013a,0x00000000}},	//   दारी_, _شبکې_, _válí_, --, 
   {{0xe3b983c2,0x00000000,0x00000000,0x00000000}},	//   _ключ_, --, --, --, 
   {{0x2d6c0131,0x8414011a,0x45440092,0x00000000}},	//   ﺴﯩﻨﻰ_, _הקרב_, _የሆነበ, --, 
   {{0xc0e802d3,0x00000000,0x00000000,0x00000000}},	//   _መሲሉ_, --, --, --, 
   {{0x47c004c5,0x8178014b,0xb5ec0055,0x00000000}},	//   ষ্টী, _барӣ_, _śṛtv, --, 
   {{0x0c7983c3,0x26c429c5,0xa1580121,0x59d40118}},	//   ыслы_, ámok_, _тасу_, _दाउर, 
   {{0x7d1c0fac,0xdef80108,0x7c3c0200,0x00000000}},	//   øpsr, _вых_, ëpra, --, 
   {{0x6ce410f5,0x89a983c4,0xf65c0162,0x00000000}},	//   _віде, ыков_, nsæd_, --, 
   {{0x08880228,0x9c7c0171,0x635406be,0x00000000}},	//   лбой_, _apču, mənş, --, 
   {{0x76880210,0x00000000,0x00000000,0x00000000}},	//   _użyj, --, --, --, 
   {{0x8458039b,0x26f400bc,0x06d80166,0x00000000}},	//   ҳрат_, ेटेर_, ыфны_, --, 
   {{0x35a183c5,0xadf401ad,0xda641913,0xab60012d}},	//   зарг, ंजिन_, _واوي, óżuj, 
   {{0x845800c7,0x480801ec,0x66140066,0x00000000}},	//   грат_, _бейн_, مژگا, --, 
   {{0xdb0001e3,0x635406be,0x00000000,0x00000000}},	//   bbmä, hənş, --, --, 
   {{0xd3b84077,0xc1e801c0,0x00000000,0x00000000}},	// [28920] русі_, лдаж_, --, --, 
   {{0xfa74001f,0xddd80118,0xf65c01bf,0x00000000}},	//   _የባንክ_, bovř, vsæg_, --, 
   {{0x052800d8,0x850401e2,0x00000000,0x00000000}},	//   _сонк_, _اوجن, --, --, 
   {{0x3e7000d2,0xdb00840d,0x464c001f,0x00000000}},	//   mâti_, mamö, _አቅጣጫ, --, 
   {{0x443003c6,0xb7d80a7c,0x00000000,0x00000000}},	//   mky_, רקני, --, --, 
   {{0x443183c6,0x409583c7,0xb6540020,0xa3e49295}},	//   lky_, _грат, _የቅንጅ, प्र_, 
   {{0x443183c8,0x16181533,0xf484315b,0x7a1800e2}},	//   oky_, दातर_, _خایی, nātņ, 
   {{0x443183c9,0x93c40208,0xd8380100,0xafe00902}},	//   nky_, _ngắ, npčt_, _носл, 
   {{0x44300851,0x9b5983ca,0x1de06a60,0x00000000}},	//   iky_, рипт_, _नापत, --, 
   {{0x3e7087e5,0xdea40133,0xdb0183cb,0x5ee800fe}},	//   kâti_, _هیچی, kamö, পিআই, 
   {{0x4430019b,0xd7f44c8c,0xbca81575,0xad6407a5}},	//   kky_, озны, _свеж_, _лафз_, 
   {{0x44300232,0xdb00deda,0x81dc05ac,0x00000000}},	//   jky_, damö, ঢ়ি_, --, 
   {{0x44300745,0x2e0c03a0,0x386400f7,0x6d4402d2}},	//   dky_, _fēfē_, изүү_, _þjar, 
   {{0x7ae00117,0x9aa404fb,0xb3380432,0x00000000}},	//   _iqot, _همچو, _geçy, --, 
   {{0x443183cc,0x6f7c01ec,0xdb0183cd,0x00000000}},	//   fky_, _ﺩﻭﻤﺎ_, gamö, --, 
   {{0x7e6804cc,0xf41c013d,0xe7e800bc,0x00000000}},	//   hofp, _niät_, ट्दा_, --, 
   {{0x91b8a4cb,0x1dc853c7,0x96f80276,0x7e680af9}},	// [28930] игат_, रणात, _тепт_, kofp, 
   {{0x53a401e0,0x00000000,0x00000000,0x00000000}},	//   саҡб, --, --, --, 
   {{0x443003c6,0x4f9583ce,0xdce80316,0x13940b7e}},	//   bky_, орлу, _vzdě, _миню, 
   {{0x2e282d75,0x7ae00107,0x6a6c1477,0x92683d09}},	//   _løft_, _oqot, løft, урға_, 
   {{0xf41c03fa,0x3cfc002b,0xf2040600,0xf1a400d8}},	//   _diät_, _astv_, _ляво, _грбн, 
   {{0xdb0000c5,0xb628037e,0x02b40107,0xf0b8009a}},	//   namõ, _ｔｃ_, _фирӯ, _مارش_, 
   {{0x7ae001f0,0xf65c022c,0x7d1c1445,0xa3c001f9}},	//   _aqot, bræv_, øpsp, ीलच_, 
   {{0x3cfd83cf,0x320000ee,0xcac80a93,0x00000000}},	//   _dstv_, _hajy_, агие_, --, 
   {{0xc0500bd9,0x9c7c007f,0x320003d1,0x0b4400d1}},	//   _חזן_, _apčs, _kajy_, юнин, 
   {{0x443003c6,0x32000022,0x2efc0240,0x08c40117}},	//   zky_, _jajy_, _isuf_, обон, 
   {{0x44304132,0x7ae0401f,0x35d00034,0x320183d0}},	//   yky_, _eqot, _ताज़, _majy_, 
   {{0xf41c01f4,0x5c040064,0x44300419,0x00000000}},	//   _miäs_, _няча, xky_, --, 
   {{0x44302d2a,0x3cfc00d7,0x00000000,0x00000000}},	//   vky_, _zstv_, --, --, 
   {{0x80c8015b,0x5a6402dd,0x44300072,0xdb00000d}},	//   _রহস্, _екіб, wky_, gamõ, 
   {{0x44303b42,0x7498013e,0x00000000,0x00000000}},	//   tky_, истӣ_, --, --, 
   {{0x3e70025a,0x7688012d,0xdb0044b3,0x00000000}},	//   râti_, _ożyw, ramö, --, 
   {{0x4224eb89,0x443183d1,0x27e003ee,0xe8dc00e4}},	// [28940] одав, rky_, _icin_, _raỹi_, 
   {{0x44300745,0x01340a2c,0xf1c815bf,0x00000000}},	//   sky_, يعاد, لامۇ_, --, 
   {{0x443183d2,0xe058732b,0x00000000,0x00000000}},	//   pky_, میست_, --, --, 
   {{0x68e0005a,0x3cfc058a,0x00000000,0x00000000}},	//   _mqnd, _rstv_, --, --, 
   {{0x7e6844b6,0xdb0000d8,0x3e88014b,0x00000000}},	//   tofp, namô, айдо_, --, 
   {{0xceac01e0,0x00000000,0x00000000,0x00000000}},	//   _үә_, --, --, --, 
   {{0x2e2803cd,0x7c3cf428,0x7e680175,0xed8402e8}},	//   _røft_, ëpro, rofp, осък_, 
   {{0x27e00198,0x7e68030d,0x3cfc05be,0x9b5800db}},	//   _ncin_, sofp, _vstv_, йийт_, 
   {{0x63a583d3,0x19c40131,0x8ea40271,0x7e688767}},	//   icin, пәйг, _فصلن, pofp, 
   {{0x27e0d1b0,0x63a40399,0xcdc40220,0x00000000}},	//   _acin_, hcin, _науқ, --, 
   {{0x200583d4,0x63a583d5,0x27e0004e,0x2ba800bc}},	//   _kami_, kcin, _bcin_, _ट्वा, 
   {{0x200583d6,0x63a40007,0x00000000,0x00000000}},	//   _jami_, jcin, --, --, 
   {{0xdb20088b,0x7ae001f0,0x2e2808fb,0x63a40210}},	//   ätäl, _uqot, _tøft_, dcin, 
   {{0x63a400da,0x27e183d7,0x00000000,0x00000000}},	//   ecin, _ecin_, --, --, 
   {{0x344983d8,0xb864064c,0x659583d9,0x63a401fa}},	//   ачан_, _وابو, дару, fcin, 
   {{0x63a42935,0xaee0002b,0xdb00000d,0x00000000}},	//   gcin, _juṣa, samõ, --, 
   {{0x3e70006a,0xa3dc0490,0xaee00055,0x320000a2}},	// [28950] lâtu_, _ठार_, _muṣa, _pajy_, 
   {{0x20050986,0xdb000ba1,0x63a583da,0x953800d8}},	//   _aami_, rcmè, acin, _гзот_, 
   {{0x200583db,0xe7e80882,0x63a583dc,0xf41c0139}},	//   _bami_, ट्वा_, bcin, _diär_, 
   {{0x200583dd,0x2164013e,0xaee000b8,0x00000000}},	//   _cami_, фтуг, _nuṣa, --, 
   {{0x20048b14,0xf65c00b5,0x32000124,0xaee00055}},	//   _dami_, bræt_, _tajy_, _tuṭa, 
   {{0x3ed00aaf,0x9e340826,0xaee0002b,0x41e01408}},	//   رقىر, мечч, _auṣa, _पायस, 
   {{0x200583de,0xdd980cef,0xa15983df,0x239801f2}},	//   _fami_, әшә_, _дару_, _ọji_, 
   {{0x200583e0,0x7a34004a,0x2f2000b8,0x00000000}},	//   _gami_, _bâto, _pūgā_, --, 
   {{0x7688006d,0xaee00055,0x7a34054e,0x45f40327}},	//   _używ, _duṣa, _câto, _བྲྀས_, 
   {{0x2ba8d3a8,0x63a40399,0x2004013e,0x27e00393}},	//   _ट्रा, zcin, _zami_, _scin_, 
   {{0x20045c2e,0x63a583e1,0xbd8400db,0xab94010a}},	//   _yami_, ycin, _ىچىن_, _мăнк, 
   {{0x2f200421,0x20041574,0x00000000,0x00000000}},	//   _tūgā_, _xami_, --, --, 
   {{0x9b000124,0xdd10010e,0xfa5401d5,0xf1c84668}},	//   _аҷыд, _aýňa, _کرنگ, ाणान, 
   {{0x8b04006d,0xda087224,0x6d400210,0x00000000}},	//   _częś, _وينه_, ozna, --, 
   {{0x6d400007,0x5ae80003,0x63a55c5f,0xd57400d4}},	//   nzna, _འདོམ, tcin, дуть, 
   {{0x27e00209,0xe3d4009e,0xd9b0247f,0x9854013d}},	//   _ucin_, হ্নব, _كەۋد, _отыш, 
   {{0xf65c366f,0xb7d8011a,0x00000000,0x00000000}},	// [28960] græs_, _הקפי, --, --, 
   {{0x63a583e2,0x26c402fb,0xe7e872c0,0x98c401ee}},	//   scin, ámou_, ट्रा_, _эсәл, 
   {{0x200583e3,0x6d400989,0x57242633,0x63a400c0}},	//   _pami_, jzna, _فریق, pcin, 
   {{0x63a40369,0xd0580212,0x35180115,0x00000000}},	//   qcin, орчі_, _הוטנ, --, 
   {{0x200583e4,0xe1f005d9,0xdec40092,0x437426ef}},	//   _vami_, _لڳا_, ሸፈን_, _хунт, 
   {{0x200583e5,0xdd90066d,0xf7ac06ba,0x8024187c}},	//   _wami_, نڈا_, _ﺳﯩﻠﻪ, _کرسم, 
   {{0x200583e6,0x00000000,0x00000000,0x00000000}},	//   _tami_, --, --, --, 
   {{0x5b1426c7,0x00000000,0x00000000,0x00000000}},	//   дмит, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf1c00208,0xee3401ec,0x6da001af,0xcee800e5}},	//   _nhờ_, _ену_, _зифа, _گرہن_, 
   {{0xa3dc3027,0xaee000b8,0x6d400210,0x00000000}},	//   ठला_, _tuṣa, czna, --, 
   {{0x315410df,0xd33c01e4,0xe7e8b213,0xf7702d4b}},	//   ליין_, _fesʈ, ट्ला_, ّاس_, 
   {{0x7ae400f1,0x8be40154,0xe78460a7,0x00000000}},	//   _روغې_, _খোকন_, еуро, --, 
   {{0x58d400f7,0xf1c00208,0xd4c40139,0x00000000}},	//   _жокт, _chờ_, мөмк, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdd1002f0,0xf65c01bf,0xa40400d8,0x00000000}},	//   _výňa, træs_, нџук, --, 
   {{0x26c401d3,0x661800c7,0x00000000,0x00000000}},	// [28970] ámot_, ñakã, --, --, 
   {{0x4cdc0154,0x6d400210,0x16840244,0xbb8802dd}},	//   _মনসু, yzna, _تابێ, _ﻗﻭﻟﻪ_, 
   {{0xe3b001ed,0x00000000,0x00000000,0x00000000}},	//   ئرہ_, --, --, --, 
   {{0xe0d10096,0xc8c427a6,0xb1900ce8,0xcf7800d8}},	//   ازل_, _विघट, _үлмә, обец_, 
   {{0x9f3400d4,0x00000000,0x00000000,0x00000000}},	//   неці, --, --, --, 
   {{0x6d400112,0xd1d40092,0x00000000,0x00000000}},	//   tzna, ከቦች_, --, --, 
   {{0x6d400c67,0xc2100302,0x5ae80327,0xcc880108}},	//   uzna, _בהם_, _འདུམ, обке_, 
   {{0x4fc002dd,0x6d40ab10,0x00000000,0x00000000}},	//   _شەتە, rzna, --, --, 
   {{0xca84152d,0x6d4000dd,0x3e7007ea,0x8fd004a9}},	//   мгий, szna, gâts_, _зәһә, 
   {{0x88c93718,0x7bc580de,0x00000000,0x00000000}},	//   олов_, ókur, --, --, 
   {{0xbd840e26,0x691401e1,0x00000000,0x00000000}},	//   _ۉچۉن_, _ṣeb, --, --, 
   {{0x6d5c0213,0x00000000,0x00000000,0x00000000}},	//   şqas, --, --, --, 
   {{0x77801262,0x00000000,0x00000000,0x00000000}},	//   клюз, --, --, --, 
   {{0xda140037,0x00000000,0x00000000,0x00000000}},	//   _थोपत_, --, --, --, 
   {{0xd4f442cd,0xf65c1445,0x03a4014b,0x9b180137}},	//   няты, trær_, дибо, _وتۇز_, 
   {{0x26c400dd,0xcf84105d,0x314401f3,0x00000000}},	//   ámos_, _مژ_, ፒዩተር, --, 
   {{0x02040408,0xf1c00051,0xc76400d1,0x7c2401f4}},	// [28980] мзан, _thờ_, _تاغى, ökri, 
   {{0x05748780,0xc1780064,0xb3806aa8,0xddd827ac}},	//   _يادد, осец_, тлул, dovş, 
   {{0x361804ac,0x04442e8d,0xc48401af,0x3fe4011c}},	//   _וויד, _женн, _олок, джев, 
   {{0x93480092,0x00000000,0x00000000,0x00000000}},	//   ሪያዎቹ, --, --, --, 
   {{0xbe8808e1,0x61e801e3,0x33f800d9,0xbc3401f4}},	//   оске_, _ödlo, _והכנ, äämö, 
   {{0x768814cf,0xa248006c,0xf2d0010f,0xddd400d7}},	//   _użyt, _عیال_, _בעש_, ňaži, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2be00490,0xbda40133,0xee340166,0x00000000}},	//   _गाणं_, سۆڤۆ_, знә_, --, 
   {{0xe7f45360,0x00000000,0x00000000,0x00000000}},	//   ेजना_, --, --, --, 
   {{0xaa848b71,0xdb2401e1,0x00000000,0x00000000}},	//   ونيم_, _ésít, --, --, 
   {{0x6d5c0724,0x00000000,0x00000000,0x00000000}},	//   şqar, --, --, --, 
   {{0x3e7006af,0x00000000,0x00000000,0x00000000}},	//   pâts_, --, --, --, 
   {{0xec1183e7,0x8c10015b,0xf6500451,0x19c40150}},	//   _جوند, িউশন_, نئس_, _пәнг, 
   {{0xbbbc2e05,0x940400f2,0x00000000,0x00000000}},	//   _एजुक, کوره, --, --, 
   {{0xe69405a2,0x26141431,0xdce800ef,0x00000000}},	//   тиры, दाजी_, _izdē, --, 
   {{0xb86459c7,0x2c14033f,0x00000000,0x00000000}},	//   _تاتو, थाएं_, --, --, 
   {{0xf6280046,0x67bc011a,0x00000000,0x00000000}},	// [28990] _діни_, _ומחק, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc0c8069d,0x4fd583e8,0xc690011a,0x00000000}},	//   _ሽብር_, ежет, _תאי_, --, 
   {{0x64481daa,0x32041d55,0x628000e4,0xa18401e0}},	//   èdit, žny_, _ëmon, тыул, 
   {{0x26140073,0xf000010b,0x1ea80b24,0x00000000}},	//   दाची_, нүңи, واوي_, --, 
   {{0x26dc00df,0x00000000,0x00000000,0x00000000}},	//   קקומ, --, --, --, 
   {{0xa19400cf,0xe7f400bc,0x00000000,0x00000000}},	//   _аарч, ेजमा_, --, --, 
   {{0xaca0063f,0x64c4013a,0x00000000,0x00000000}},	//   _nrụl, _učiň, --, --, 
   {{0xa3e408e9,0xde7400cf,0x00000000,0x00000000}},	//   प्ट_, ردۇع, --, --, 
   {{0x3b80916f,0x00000000,0x00000000,0x00000000}},	//   ылыг, --, --, --, 
   {{0x61cc00eb,0x00000000,0x00000000,0x00000000}},	//   র্কআ, --, --, --, 
   {{0x58040046,0xd7c80753,0x00000000,0x00000000}},	//   نوپك, ووپه_, --, --, 
   {{0xb6a183e9,0xabb00022,0xb8d40037,0x00000000}},	//   лиял, _заҵә, _चढ़_, --, 
   {{0x7f9403b9,0xb7000139,0x1ad4000d,0x00000000}},	//   _hüqü, _şäül, _दितथ, --, 
   {{0xc0c8010c,0x3d10000d,0x36640884,0x00000000}},	//   ጠቅስ_, थिये_, харо_, --, 
   {{0x2af000af,0x00000000,0x00000000,0x00000000}},	//   _अहाँ_, --, --, --, 
   {{0x53e00073,0x7c3c0ea0,0xcdc401e2,0xb4600304}},	// [289a0] _फारश, ëpri, _پښ_, уктл, 
   {{0xa3dc2793,0xe81405f9,0xc20800af,0x00000000}},	//   _ठाक_, _तोता_, _होखब_, --, 
   {{0x6448020c,0xbc3401f4,0x00000000,0x00000000}},	//   èdis, ääkö, --, --, 
   {{0x41e00574,0x85b82c26,0x7d0c29d3,0x717037ba}},	//   _पावस, _باکس_, _ábsi, دهما, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x20e00574,0x09d40f22,0x644c0210,0x00000000}},	//   खंदळ_, ত্তা, żnią, --, 
   {{0xdb1406ea,0x00000000,0x00000000,0x00000000}},	//   _íbúg, --, --, --, 
   {{0xd12d7ea3,0x64440254,0x00000000,0x00000000}},	//   _ظۅن_, nhii, --, --, 
   {{0xeaac3e58,0x7a340129,0x64441eba,0x7050007b}},	//   یعی_, _hâti, ihii, _إنقا, 
   {{0x5a340a83,0xf2d0011a,0x00000000,0x00000000}},	//   тнот, נעת_, --, --, 
   {{0x6444058a,0x3ea583ea,0x2ba8000d,0x00000000}},	//   khii, lqot_, _ट्का, --, 
   {{0xfaa583eb,0xe94000c7,0x00000000,0x00000000}},	//   _задо, ухьо, --, --, 
   {{0x64441990,0x29000008,0xec6c0451,0x3ea40327}},	//   dhii, æjar_, _اٿن_, nqot_, 
   {{0x3b040194,0x7b04005f,0xeb04007b,0x463000c7}},	//   _isoq_, ērtī, _أقوى_, иҭыр, 
   {{0x5fd00574,0x7bc00270,0xa3dc01f9,0x00000000}},	//   हणाल, _keou, ठलं_, --, 
   {{0x64440276,0x7bc002e2,0x3ea4011f,0xa978123b}},	//   ghii, _jeou, kqot_, _מאוכ, 
   {{0x7bc0007f,0xe2f8cea4,0xb70c0354,0x00000000}},	// [289b0] _meou, неті_, _уçнă_, --, 
   {{0x6444aaa1,0x7a3420ef,0x569400a8,0x7bc0030a}},	//   ahii, _bâti, _шапт, _leou, 
   {{0x41e017ee,0x64440083,0x7a340356,0xe7e8000d}},	//   _पारस, bhii, _câti, ट्का_, 
   {{0x644583ec,0x00000000,0x00000000,0x00000000}},	//   chii, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3ea00aac,0x5f747aaf,0xe29800c0,0x00000000}},	//   шишг, دامر, _паў_, --, 
   {{0xcc881ec7,0x7a340129,0x27ec01d3,0xd0e80ed8}},	//   ونته_, _gâti, ődni_, _زکام_, 
   {{0x09d80490,0x00000000,0x00000000,0x00000000}},	//   ढल्य, --, --, --, 
   {{0x7bc00165,0xdd9401e0,0xcf2400f1,0x00000000}},	//   _deou, _ҡауы, _ګرځي, --, 
   {{0x6444208d,0x9f5400f3,0x00000000,0x00000000}},	//   zhii, _свуч, --, --, 
   {{0x5d10021a,0x2bb0098a,0x38c40332,0x6444058a}},	//   _هېوا, ीरदा, _rírá_, yhii, 
   {{0x7bc183ed,0x2c14033f,0xbb500133,0x00000000}},	//   _geou, थाओं_, انیب, --, 
   {{0xefc802d3,0x00000000,0x00000000,0x00000000}},	//   ጠትዶ_, --, --, --, 
   {{0x6444208d,0x7bc00036,0x161803ce,0x00000000}},	//   whii, _zeou, दागर_, --, 
   {{0x644583ee,0x69c183ef,0xba9400ec,0x00000000}},	//   thii, _iene, _شاهڪ, --, 
   {{0x69c183f0,0x290583f1,0x64440cfe,0x3d1000dc}},	//   _hene, _isna_, uhii, थिते_, 
   {{0x69c183f2,0x64440641,0x06846418,0x9e7401af}},	// [289c0] _kene, rhii, _игин, _итhе, 
   {{0x69c183f3,0x644583f4,0x7af40724,0x7a3407ea}},	//   _jene, shii, _äyte, _pâti, 
   {{0x6444198f,0x00c80139,0x44880137,0xbfc45bc6}},	//   phii, флек_, _обон_, вбек, 
   {{0x69c09461,0x03a416c3,0x02c4036b,0xdbd401e1}},	//   _lene, _шимо, _иймо, _fùùf, 
   {{0x69c068a1,0x7bc183f5,0x57cc010f,0xf4240395}},	//   _oene, _reou, למאַ, _роял_, 
   {{0x2904464c,0xbf1407d6,0xdb6c0092,0xee2c00ec}},	//   _osna_, _یوزب, _አሳዛኝ_, يٽن_, 
   {{0x409583f6,0x629d83f7,0x7bc0007f,0x1ad4000d}},	//   _арат, _iiro, _peou, _दिहथ, 
   {{0x629d83f8,0x69c00483,0x3a2c010a,0x0dc80023}},	//   _hiro, _aene, _sofp_, _ጽዩፍ_, 
   {{0x629d83f9,0xbea406bb,0x290583fa,0x7054010a}},	//   _kiro, _разк, _asna_, _ратĕ, 
   {{0x69c183fb,0x629d83fc,0x8f7402bf,0x7bc00036}},	//   _cene, _jiro, _сусі, _weou, 
   {{0x69c183fd,0xada183fe,0x6da00d1d,0x00000000}},	//   _dene, _тахл, _тиха, --, 
   {{0xf8a00323,0x26c00086,0x69c183ff,0x629d8400}},	//   лгүү, _bwio_, _eene, _liro, 
   {{0x69c18401,0x3b040194,0x2904c7bf,0x85780150}},	//   _fene, _usoq_, _esna_, _ﺤﺼﺭﺍ_, 
   {{0x629d8402,0xab600166,0x1db400cd,0xe66401f0}},	//   _niro, _әвәл, ुरित, атсо, 
   {{0x6448005f,0xe4a418ac,0x69f80375,0x00000000}},	//   īdin, ирто, _חלוק, --, 
   {{0x69c18403,0x629d8404,0x030c4d53,0xb69800d2}},	//   _zene, _airo, सिंह_, cwân, 
   {{0x69c18405,0x368822f7,0x26c001ab,0x1db4043e}},	// [289d0] _yene, _осон_, _gwio_, ुरात, 
   {{0x69c0172e,0xe1f00491,0x29040254,0x70800092}},	//   _xene, قسم_, _ysna_, _ይባላሉ_, 
   {{0x629d8406,0xdce8012c,0xc5f001ed,0xa0c416ac}},	//   _diro, _vydě, _آپ_, ليلو, 
   {{0x629c0029,0xddd800bc,0x8538011a,0x00000000}},	//   _eiro, livň, _נגרי, --, 
   {{0x629d8407,0x6da02c1d,0xe7e809ab,0xf41c0139}},	//   _firo, қиқа, ट्टा_, _inä_, 
   {{0x629d8408,0xf41c0139,0x00000000,0x00000000}},	//   _giro, _niäz_, --, --, 
   {{0xf41c01e6,0x69c18409,0x8ca40014,0x00000000}},	//   _knä_, _rene, دٕبو, --, 
   {{0x69c1840a,0x629c829f,0x6ed809ae,0x51840220}},	//   _sene, _ziro, _निपु, _ауға, 
   {{0xf65c00b5,0x5f946d66,0x629d840b,0xc050011a}},	//   gsæk_, _витт, _yiro, _הזן_, 
   {{0x69c1840c,0x5f75840d,0x629d840e,0xee840c9e}},	//   _qene, _ئافر, _xiro, _рыбо, 
   {{0x49940108,0x00000000,0x00000000,0x00000000}},	//   ышит, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69c1840f,0x00000000,0x00000000,0x00000000}},	//   _tene, --, --, --, 
   {{0x69c18410,0xe81400af,0xb6a048fb,0x46158411}},	//   _uene, _तोरा_, сирл, دوسر, 
   {{0x629d8412,0xed68001f,0x290416a3,0xb698045f}},	//   _riro, _ድንበር_, _usna_, mwâl, 
   {{0x4808004e,0x00000000,0x00000000,0x00000000}},	//   _чеин_, --, --, --, 
   {{0x629d8413,0xd3a400d1,0x4368009d,0xd7f800f3}},	// [289e0] _piro, рлуқ, хаан_, _руј_, 
   {{0xa4941169,0xa6540272,0x09d42aab,0x9c1401f2}},	//   _چیست, _ئێست, ত্রা, _nọny, 
   {{0xa494034c,0xe0598414,0x7a340311,0xa0d403e6}},	//   _نیست, نیست_, _gâtu, شحاڵ, 
   {{0x629d8415,0x71a06bfd,0x7f840472,0x00000000}},	//   _wiro, _ҳарз, هلان, --, 
   {{0x629d8416,0x24818417,0x00000000,0x00000000}},	//   _tiro, mlim_, --, --, 
   {{0x24818418,0x629c16b8,0xfe1c28d4,0x00000000}},	//   llim_, _uiro, पाइस_, --, 
   {{0x9c14063f,0x39a800d2,0xb698000f,0x9d0400ee}},	//   _dọny, _lîsó_, dwâl, рҗек, 
   {{0x21740131,0x71180375,0xe81404af,0xdd9001e2}},	//   _буғр, _אולפ, _तोला_, موږ_, 
   {{0x6ed89201,0xbe6801c0,0x248141ea,0x00000000}},	//   _नियु, _зааж_, ilim_, --, 
   {{0x24809041,0xeaf40f17,0x00000000,0x00000000}},	//   hlim_, اريت_, --, --, 
   {{0x6e91742d,0x24818419,0x5cc401c4,0x00000000}},	//   _اللا, klim_, _төлв, --, 
   {{0xdd20013a,0x00000000,0x00000000,0x00000000}},	//   _kůže, --, --, --, 
   {{0x768400b8,0x00000000,0x00000000,0x00000000}},	//   _aśaṅ, --, --, --, 
   {{0xdd20038e,0x199402d5,0x7a3406af,0xb8e800cc}},	//   _může, _каля, _pâtu, _লম_, 
   {{0xdd200118,0xb4b000d1,0xd3c40022,0x69d401c8}},	//   _lůže, сибә, ираҿ, _صبوح_, 
   {{0x93b40b5e,0xb8640150,0x00000000,0x00000000}},	//   рбац, _حاتو, --, --, 
   {{0xdd2001ef,0x00000000,0x00000000,0x00000000}},	// [289f0] _nůže, --, --, --, 
   {{0x6fc40aff,0x2480003e,0x6d4c06be,0x41740055}},	//   ारभू, alim_, _əcab, _ṭaṅk, 
   {{0x2481841a,0xe4e40064,0x00000000,0x00000000}},	//   blim_, _ліян, --, --, 
   {{0x7e780200,0x00000000,0x00000000,0x00000000}},	//   _aktp, --, --, --, 
   {{0x7e780334,0x76480153,0x00000000,0x00000000}},	//   _bktp, _įgyj, --, --, 
   {{0xfe6c7b7a,0x00000000,0x00000000,0x00000000}},	//   وگل_, --, --, --, 
   {{0xd7b40073,0x2bb000bc,0x8fd001ee,0x00000000}},	//   ंडाच, ीरला, _дәлә, --, 
   {{0x99801432,0xf074013d,0x9c140cad,0x4ff8010f}},	//   _şiş_, _сибә_, _wọny, _שפּײ, 
   {{0x4a440075,0xb698002d,0x4b88013e,0x00000000}},	//   инив, twâl, ъйин_, --, 
   {{0x89a80395,0x00000000,0x00000000,0x00000000}},	//   ъков_, --, --, --, 
   {{0x8bd42004,0xb698045f,0x99181cb8,0x0b2400cc}},	//   _نقاش, rwâl, гіях_, যনেল_, 
   {{0xdd940124,0x9a2402dd,0x5ab40075,0x00000000}},	//   _уахы, _ۇعىن, шқәр_, --, 
   {{0xb88409f3,0x0bc00046,0x00000000,0x00000000}},	//   _smíð, _ﺭﻩﻓﻮ, --, --, 
   {{0xf7705841,0xfd4c00cd,0xe86401c6,0xa3b801f9}},	//   تاپ_, _aviṣ, рхүү, घुन_, 
   {{0x87d407d6,0x64480006,0xd4d852c4,0x00000000}},	//   _кўпч, ūdim, льті_, --, 
   {{0x248008cd,0xfd4c0055,0x00000000,0x00000000}},	//   ulim_, _cviṣ, --, --, 
   {{0x64a4416c,0xc324efd5,0xfd4c00dc,0x2be000c5}},	// [28a00] раға, шмак, _dviṣ, _गाईं_, 
   {{0x41b5841b,0xb2201fb7,0xdd200118,0x2019841c}},	//   рсат, омул, _růže, _şri_, 
   {{0x4095841d,0x28a80037,0x00000000,0x00000000}},	//   ардт, _घूमि, --, --, 
   {{0xf99002e4,0x35180375,0xdfd03226,0xc2440124}},	//   קרא_, _סוכנ, سيت_, ынҷк, 
   {{0x7a34003a,0x44208a83,0xe57800e2,0x00000000}},	//   _mâtr, _ink_, ļķu_, --, 
   {{0x4420f2df,0x03c00055,0x43740117,0x00000000}},	//   _hnk_, _ākṣa, _буҳт, --, 
   {{0x44200a73,0xc00400c7,0xdce800ef,0x918801af}},	//   _knk_, _кпвк, _izdī, _барғ_, 
   {{0x44200b1d,0xafe0036b,0x00000000,0x00000000}},	//   _jnk_, _мосл, --, --, 
   {{0xbb6400b5,0x4420107d,0xfb840139,0x00000000}},	//   _bitか_, _mnk_, шыкн, --, 
   {{0x4421841e,0x8504012c,0x1da00092,0x64480200}},	//   _lnk_, शबाट_, _ሃሳቦች_, ëdij, 
   {{0x4421841f,0x19587a3b,0xbc2401af,0x00000000}},	//   _onk_, уаны_, _вєли, --, 
   {{0xcfdc009e,0x4420058a,0x7d180857,0xca640075}},	//   ণ্ঠন, _nnk_, _irts, _һечқ, 
   {{0x7c218420,0x59f80395,0xdb2001f4,0xcbb401af}},	//   _inor, _беля_, ötäm, _уғыш_, 
   {{0x44218421,0xdbf803f4,0x7d1800b8,0xfd4c002b}},	//   _ank_, _অফিস_, _krts, _sviṣ, 
   {{0xf1cc0150,0x00000000,0x00000000,0x00000000}},	//   _ﻗﯘﻟﻘ, --, --, --, 
   {{0x71240e3f,0x7d180076,0xda7802f0,0xa998011a}},	//   یرال, _mrts, loď_, _בבור, 
   {{0xd6d18422,0xdee402dd,0x23387bf7,0x22580332}},	// [28a10] _عقد_, _تۋ_, апты_, _bmrk_, 
   {{0x7d198423,0x44200a40,0xdb00007c,0xdca400db}},	//   _orts, _enk_, bbmö, _يۉ_, 
   {{0x7c218424,0x1bf81f14,0xfd4c0055,0xd578030d}},	//   _onor, ्जाल_, _tviṣ, _тlак, 
   {{0x4420d167,0x2258002f,0xda7802f0,0xa13401d5}},	//   _gnk_, _emrk_, hoď_, غرلش, 
   {{0x7d198425,0xa3cc6611,0xaf040f15,0x00000000}},	//   _arts, _रजत_, рчек, --, 
   {{0x7c218426,0xc33004ac,0x0ae801a9,0x00000000}},	//   _anor, _צום_, ҳдий_, --, 
   {{0x49c800d1,0x00000000,0x00000000,0x00000000}},	//   ңлин_, --, --, --, 
   {{0x0c258427,0x44218428,0xf0440108,0x00000000}},	//   смин, _xnk_, _тэго, --, 
   {{0x3cfc3756,0x1de00401,0x78b40064,0x00000000}},	//   _eptv_, _नाचत, _čyva, --, 
   {{0xaca00521,0x4a453aa1,0xca48182c,0x8e84007b}},	//   _anụm, снов, الده_, _الطه, 
   {{0xc7a46073,0x3cfc002d,0x18b00184,0x49980a8f}},	//   йинк, _gptv_, үҙәр, ытия_, 
   {{0x6f198429,0xa92402f0,0x00000000,0x00000000}},	//   _kruc, _alží, --, --, 
   {{0x3994069c,0x44200581,0x00000000,0x00000000}},	//   _መዓልቲ_, _rnk_, --, --, 
   {{0x7c200427,0x80c800fe,0x6f1838f2,0x00000000}},	//   _znor, _ৰহস্, _mruc, --, 
   {{0x442005b1,0xc8b4034b,0x00000000,0x00000000}},	//   _pnk_, _услы, --, --, 
   {{0x47c47e81,0x6f19842a,0xf1c402f0,0x22582438}},	//   _убив, _oruc, hráč_, _smrk_, 
   {{0x4421842b,0x97c40150,0x83880120,0x00000000}},	// [28a20] _vnk_, _بتىم, убав_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd1780953,0xd29802dd,0x6f19842c,0x00000000}},	//   асці_, ртті_, _aruc, --, 
   {{0xdd2c02d5,0x44205c01,0xb7d8010f,0xa3cc06e3}},	//   _nėšt, _unk_, ָקסי, _रजि_, 
   {{0x21d9842d,0x7c2001ab,0xefb0036b,0x00000000}},	//   _نژاد_, _rnor, سیلگ, --, 
   {{0x6f19842e,0x7d1801f5,0x44f4031c,0xddf800fd}},	//   _druc, _prts, _བྱོར_, рьдә_, 
   {{0xa3cc2ecf,0x6f19842f,0x00000000,0x00000000}},	//   _रजा_, _eruc, --, --, 
   {{0xf0618430,0xf65c037e,0xb62400d1,0x1ab42901}},	//   _експ, lsæt_, _ﯬﯓ_, обия, 
   {{0x7c2002f0,0x6f198431,0xf410011a,0xaab401d5}},	//   _vnor, _gruc, לפה_, یدیر_, 
   {{0xd8f802bf,0xf65c005c,0x00000000,0x00000000}},	//   аної_, nsæt_, --, --, 
   {{0x78b80112,0x7d198432,0x2db4011a,0xa3c810fa}},	//   uptv, _urts, _הלבן_, उरा_, 
   {{0x7c218433,0x316487e5,0xdb24004b,0x44f4031c}},	//   _unor, ûnzi_, _ووای, _བྱེར_, 
   {{0x6c78008f,0x61fc0175,0x1dac033f,0xf65c01bf}},	//   _גראד, _obrl, _चलात, ksæt_, 
   {{0x1bf8b577,0x9c1c063f,0xf3640032,0x00000000}},	//   ्जवल_, ị̄á_, ҡтан, --, 
   {{0xf65c00b5,0x74680212,0xa99000db,0x5fa80118}},	//   dsæt_, грав_, _ىشىت, गशाल, 
   {{0x660c013f,0x1dac00c5,0x00000000,0x00000000}},	//   _ɔnkɛ, _चलऽत, --, --, 
   {{0x787001d9,0xb6042401,0x78a801e3,0x00000000}},	// [28a30] _وُڈا, _лянк, _hufv, --, 
   {{0xf1a40124,0xf65c005c,0x64580064,0x00000000}},	//   сран, gsæt_, _įvie, --, 
   {{0x09d40154,0x6f1800b8,0x6ed80550,0xb188009d}},	//   ত্কা, _sruc, _निहु, усаж_, 
   {{0x6f182b1d,0x21a801e0,0x2fc89cba,0x00000000}},	//   _pruc, _ғәфү_, اباً_, --, 
   {{0x59d80073,0x929400d8,0xdb800116,0x00000000}},	//   ढणार, _мамц, ﺧﯩﺮﻯ_, --, 
   {{0x6f1913ad,0x2bb0043e,0x00000000,0x00000000}},	//   _vruc, ीर्थ, --, --, 
   {{0xc21004ae,0x00000000,0x00000000,0x00000000}},	//   _קהל_, --, --, --, 
   {{0x61fc01a6,0x2be000ab,0x0b448f47,0x904400f2}},	//   _zbrl, _गाओं_, жнин, _بنره, 
   {{0x6f198434,0x6ab80b23,0x4b24496f,0x0a48267c}},	//   _uruc, upuf, імов, изий_, 
   {{0x2fcc1511,0x00000000,0x00000000,0x00000000}},	//   lagg_, --, --, --, 
   {{0x6ab85d8b,0x00000000,0x00000000,0x00000000}},	//   spuf, --, --, --, 
   {{0xc85802bf,0x2fcd8435,0x6ab84ce6,0x78a80847}},	//   ршої_, nagg_, ppuf, _dufv, 
   {{0xd9c80154,0x00000000,0x00000000,0x00000000}},	//   _শারম, --, --, --, 
   {{0x44f4025c,0x00000000,0x00000000,0x00000000}},	//   _བྱུར_, --, --, --, 
   {{0x35a04276,0x6aa80bcd,0xfa547405,0xf65c01bf}},	//   дарг, _hugf, _برنگ, vsæt_, 
   {{0x13400020,0x6aa8009a,0x6aa18436,0xf9900375}},	//   _የመጽሐ, _kugf, _hinf, _קרה_, 
   {{0x76480006,0x6aa00064,0xf65c01bf,0xd05c03b9}},	// [28a40] _įgyv, _kinf, tsæt_, _özəy, 
   {{0x6aa00003,0xa3498437,0x648800e4,0xe7f40118}},	//   _jinf, азға_, mÿim, ेजका_, 
   {{0x6aa0003d,0x6aa80af9,0xf65c00b5,0xc104742b}},	//   _minf, _lugf, rsæt_, تواي, 
   {{0x6aa18438,0x6ed80f4c,0x92e803d4,0x2fcc2988}},	//   _linf, _निशु, _মনৰ_, gagg_, 
   {{0x63b40034,0x64440067,0xf65c01bf,0x00000000}},	//   ągną, mkii, psæt_, --, 
   {{0x64458439,0x6aa1843a,0x6ed8243c,0xefd0001f}},	//   lkii, _ninf, _निरु, _ራዕይ_, 
   {{0xbc487c0c,0x6445843b,0x63440020,0xa2b00073}},	//   ичие_, okii, _የመጠበ, _अंड्, 
   {{0x6445843c,0x4431843d,0x6aa1843e,0x7ee4007b}},	//   nkii, njy_, _ainf, _وكأن, 
   {{0x64440270,0x00000000,0x00000000,0x00000000}},	//   ikii, --, --, --, 
   {{0x6aa8005c,0x64444702,0x7af400fd,0xcf58009d}},	//   _dugf, hkii, _äytm, _урсч_, 
   {{0x6aa00007,0x00000000,0x00000000,0x00000000}},	//   _dinf, --, --, --, 
   {{0x6aa1843f,0xfaa579e7,0xfbd18440,0xec100131}},	//   _einf, _дадо, _آتا_, _يولد, 
   {{0x6aa18441,0x64440050,0x00000000,0x00000000}},	//   _finf, dkii, --, --, 
   {{0x6aa03257,0x4430035b,0x78a8007c,0x00000000}},	//   _ginf, ejy_, _tufv, --, 
   {{0x64440014,0x6aa80112,0x98ac00c0,0xa9640114}},	//   fkii, _zugf, mzdį_, _миља_, 
   {{0xdb100413,0x64440254,0xa83400ae,0x00000000}},	//   _áfól, gkii, _يعيش, --, 
   {{0xf7702310,0x6aa002d0,0xe81401f9,0x00000000}},	// [28a50] _تاغ_, _yinf, _तोटा_, --, 
   {{0x6444fa60,0x6aa00327,0x2fcc0327,0x00000000}},	//   akii, _xinf, wagg_, --, 
   {{0x644401d9,0xceb8012c,0x98ac0153,0x2fcc1b9c}},	//   bkii, _stř_, izdį_, tagg_, 
   {{0x644401f4,0x00000000,0x00000000,0x00000000}},	//   ckii, --, --, --, 
   {{0xf3fc0589,0x00000000,0x00000000,0x00000000}},	//   _ibã_, --, --, --, 
   {{0xa2b006e3,0x2fcc0327,0x00000000,0x00000000}},	//   _अंत्, sagg_, --, --, 
   {{0x6aa18442,0x81400116,0x040c00eb,0x00000000}},	//   _rinf, _كۆكن, হারী_, --, 
   {{0x44040156,0xef9000dd,0x00000000,0x00000000}},	//   གབརྡ_, _قیاد, --, --, 
   {{0x6aa0e539,0xdc7400c7,0x00000000,0x00000000}},	//   _pinf, ьышь, --, --, 
   {{0x4430000f,0xad2416ac,0x00000000,0x00000000}},	//   zjy_, _وراو, --, --, 
   {{0xd90c4b99,0x6aa0c300,0x44317eaf,0x00000000}},	//   لیو_, _vinf, yjy_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6aa00003,0x64440790,0xf1c81408,0x28dc00cd}},	//   _tinf, vkii, िरान, पूजि, 
   {{0xca48021a,0x00000000,0x00000000,0x00000000}},	//   _دلته_, --, --, --, 
   {{0xf9f405e6,0x76480024,0x644480be,0x6d44025c}},	//   _رفيع_, _įgyt, tkii, _żjaj, 
   {{0x44258443,0x64880022,0x00000000,0x00000000}},	//   ño_, pÿim, --, --, 
   {{0x64458444,0xdcf42220,0x85041a90,0xfa540244}},	// [28a60] rkii, _đačk, _کوجن, _برۆگ, 
   {{0x64458445,0xf3fc0589,0xf65c5f03,0x00000000}},	//   skii, _ebã_, ssær_, --, 
   {{0xc00400d6,0xbb3c001f,0x00000000,0x00000000}},	//   зпек, ራርተዋ, --, --, 
   {{0x82a4009d,0x00000000,0x00000000,0x00000000}},	//   _намж, --, --, --, 
   {{0x627404a9,0x9cf800bd,0xcfa804d3,0x00000000}},	//   _قۇرئ, _আছেন_, زانم_, --, 
   {{0x41298446,0x00000000,0x00000000,0x00000000}},	//   _лого_, --, --, --, 
   {{0xdcc802dd,0xfca800f1,0x00000000,0x00000000}},	//   іңде_, حاتو_, --, --, 
   {{0x7af400fd,0xd0580153,0x00000000,0x00000000}},	//   _äytk, _друі_, --, --, 
   {{0x09bc0eac,0x00000000,0x00000000,0x00000000}},	//   _আয়া, --, --, --, 
   {{0xcf2400c6,0x4adc0073,0x50a00137,0x00000000}},	//   _ترفي, _मिरव, _كەەل, --, 
   {{0xbd898447,0x80c82b1b,0xedd0e25c,0xb4d80210}},	//   _انان_, াংক্, _سيند, _डटे_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7f4001b9,0x00000000,0x00000000,0x00000000}},	//   nyoq, --, --, --, 
   {{0x76480064,0x00000000,0x00000000,0x00000000}},	//   _įgys, --, --, --, 
   {{0x92e86569,0x5fcd1b20,0x7f40022e,0xe65801c6}},	//   _মনে_, ाराल, hyoq, чирч_, 
   {{0x24f801ee,0x00000000,0x00000000,0x00000000}},	//   янсы_, --, --, --, 
   {{0xfa08025c,0xdee402dd,0x52143740,0x00000000}},	// [28a70] _ཀྲོན_, _حۋ_, мдат, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf7702832,0x00000000,0x00000000,0x00000000}},	//   _تاں_, --, --, --, 
   {{0xf3fc0589,0x4adc0dad,0xf1c80316,0x58fc031c}},	//   _ubã_, _मिलव, िरहन, _ྐྱབས_, 
   {{0x3384013d,0xe1680023,0x4e9400f2,0xddd001ef}},	//   _хунв, _ተኸቢሩ_, وشتر, _řešt, 
   {{0x48ec012d,0x00000000,0x00000000,0x00000000}},	//   _अमलो_, --, --, --, 
   {{0xdea4036b,0xfa08031c,0xa2940212,0x5f780014}},	//   ریمی, _ཀྲེན_, _чарі, _ہمِس_, 
   {{0x3cdc0dad,0xe13422f9,0xdce80153,0x80c800cc}},	//   _गिरे_, _янсы, _lydė, াংখ্, 
   {{0x4adc0574,0xca74010b,0x00000000,0x00000000}},	//   _मिळव, дуны, --, --, 
   {{0x9f04210e,0x09bc0154,0x7d140210,0x00000000}},	//   _سومو, _আযহা, łysa, --, 
   {{0x2900004e,0x8c180451,0x00000000,0x00000000}},	//   ïja_, _ويئر_, --, --, 
   {{0x6d400006,0x6fdc00fe,0x00000000,0x00000000}},	//   myna, ফ্ৰে, --, --, 
   {{0x6d418448,0x22940108,0x7fd4011a,0x00000000}},	//   lyna, läke_, וורס_, --, 
   {{0x31e0009e,0xdbdc0248,0xda3400c0,0x00000000}},	//   ন্তশ, _láìw, _печы, --, 
   {{0xb6a06888,0x4414dfe7,0x6d418449,0x00000000}},	//   тирл, мфат, nyna, --, 
   {{0x6d40062c,0xa96401af,0x00000000,0x00000000}},	//   iyna, _миҙа_, --, --, 
   {{0x64bc0989,0x6d417804,0x436801c6,0xb9f80092}},	// [28a80] _očig, hyna, цаан_, _ሙት_, 
   {{0xdce80064,0x6d406873,0x00000000,0x00000000}},	//   _gydė, kyna, --, --, 
   {{0x6d405873,0x00000000,0x00000000,0x00000000}},	//   jyna, --, --, --, 
   {{0xb7d8008f,0x7f40022e,0x00000000,0x00000000}},	//   ַקצי, tyoq, --, --, 
   {{0x62400036,0x6d400014,0xa5d400a2,0x3de80327}},	//   _böot, eyna, _eỳer, _རྐུན, 
   {{0xdd94496b,0x6d410da3,0x7f40022e,0x7af400fd}},	//   налы, fyna, ryoq, _äyti, 
   {{0x6d41844a,0x418c0150,0x00000000,0x00000000}},	//   gyna, _ﺒﺭﺃﻱ_, --, --, 
   {{0x5b1414a4,0xfd4c01f2,0x21740e46,0x00000000}},	//   емит, _zukọ, _жуғр, --, 
   {{0x6d400363,0xb9e40212,0xfa080327,0xbe68009d}},	//   ayna, міни, _ཀྲུན_, _дааж_, 
   {{0x6d41844b,0x00000000,0x00000000,0x00000000}},	//   byna, --, --, --, 
   {{0x6d41844c,0xbc1800d4,0x44d8013a,0x00000000}},	//   cyna, _міді_, jď_, --, 
   {{0xb9041b61,0x7b64241e,0x3bd400f2,0xe3b80139}},	//   _पि_, _отле, _آغاس, _şın_, 
   {{0x6a10036b,0x00000000,0x00000000,0x00000000}},	//   ربیر, --, --, --, 
   {{0x3fcc00d1,0x00000000,0x00000000,0x00000000}},	//   _ﻗﯩﺰﻧ, --, --, --, 
   {{0xa5f800f5,0x00000000,0x00000000,0x00000000}},	//   ьеру_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d4075ae,0xe2f810da,0x00000000,0x00000000}},	// [28a90] zyna, меті_, --, --, 
   {{0xa2b001ad,0xb9d40023,0x00000000,0x00000000}},	//   _अंर्, _ኾን_, --, --, 
   {{0xe3b0066d,0x7580114f,0x00000000,0x00000000}},	//   ارہ_, _شیرم, --, --, 
   {{0xdcb801e4,0x64bc01ab,0x6d406af9,0x46a40107}},	//   _arĉo_, _dčid, vyna, _ошӯб, 
   {{0x6d4070d4,0x00000000,0x00000000,0x00000000}},	//   wyna, --, --, --, 
   {{0x6d41844d,0x2d64013f,0xdb1401e1,0x00000000}},	//   tyna, _pɑe_, _ìbùg, --, 
   {{0x3130121e,0x3b04022e,0x6ed80b98,0x6d400076}},	//   _جہاز, _apoq_, _निकु, uyna, 
   {{0x6d41844e,0xa194b2f3,0xb110063f,0x00000000}},	//   ryna, _расч, wụwk, --, 
   {{0x6d41844f,0xaee000b8,0xdfd401ec,0x22940108}},	//   syna, _doṣo, _шоты, säke_, 
   {{0xd01805c7,0x2fdc030a,0xed80010b,0x08c58450}},	//   _hań_, _hdug_, _иңли, нбон, 
   {{0x1df8abba,0x00000000,0x00000000,0x00000000}},	//   _цехы_, --, --, --, 
   {{0x9ac4025c,0x00000000,0x00000000,0x00000000}},	//   _boċċ, --, --, --, 
   {{0xd01805c7,0x96b800db,0x00000000,0x00000000}},	//   _mań_, дусу_, --, --, 
   {{0x9ac4025c,0x25ac0158,0x38c8085b,0xc4c401e2}},	//   _doċċ, ødl_, _کاوی_, فترو, 
   {{0xfa080135,0x8a6004d3,0x09bc01ad,0x64bc00d7}},	//   _ཀྲིན_, _لێکۆ, ोरीय, _očie, 
   {{0x14e00073,0x941806be,0x00000000,0x00000000}},	//   _फिरण, _kisə_, --, --, 
   {{0x27e18451,0x29040098,0x24818452,0x4224988b}},	// [28aa0] _idin_, _hpna_, roim_, ндав, 
   {{0x67258453,0x2fdc0c6a,0xb7780375,0x26c00393}},	//   _irij, _adug_, _מאפש, _itio_, 
   {{0x26c01f7f,0x3fe40063,0x0444010b,0x800400fd}},	//   _htio_, ежев, _зенн, ечле, 
   {{0x67258454,0xbce001e0,0x00000000,0x00000000}},	//   _krij, ҫҡаһ, --, --, 
   {{0x2fdc0042,0x941803b9,0xd0187def,0x627800d1}},	//   _ddug_, _nisə_, _dań_, _قەرز_, 
   {{0x29058455,0x7c6413f9,0x3b04013c,0x67240841}},	//   _opna_, کاتل, _rpoq_, _mrij, 
   {{0x27e18456,0xa3e409fd,0x6240007c,0xefd00023}},	//   _odin_, _नया_, _föor, _ራዕዲ_, 
   {{0xdd940184,0x26c016b8,0x76a401e1,0x27e18457}},	//   наһы, _otio_, _kéyì, _ndin_, 
   {{0x8fd429db,0x2b4001c0,0x29040010,0xeb940640}},	//   _рәхә, гээг, _apna_, нић_, 
   {{0x27e18458,0xef1402d5,0x9ac40327,0x00000000}},	//   _adin_, _яму_, _roċċ, --, 
   {{0x195850db,0x26c0003a,0xf96800d1,0xa3c0012c}},	//   фаны_, _atio_, ярий_, ँडा_, 
   {{0x67258459,0x27e00076,0x00000000,0x00000000}},	//   _brij, _cdin_, --, --, 
   {{0x672439ca,0x00000000,0x00000000,0x00000000}},	//   _crij, --, --, --, 
   {{0x6724c425,0x27e1845a,0xfaa400b2,0x569401c0}},	//   _drij, _edin_, _ڪهڙي_, тагт, 
   {{0x67246732,0x27e000a3,0x3448004e,0xe4e40a4a}},	//   _erij, _fdin_, пчан_, літн, 
   {{0x67240225,0x27e001fa,0x00000000,0x00000000}},	//   _frij, _gdin_, --, --, 
   {{0x6725845b,0x2458e498,0xa3c000c5,0x21b801d9}},	// [28ab0] _grij, хать_, ँड़_, کھُک_, 
   {{0x76a401e1,0xd9f01b76,0xd5e800e5,0x00000000}},	//   _déyì, चलित_, _کٹھن_, --, 
   {{0xd018012d,0x27e1845c,0x00000000,0x00000000}},	//   _pań_, _ydin_, --, --, 
   {{0xd371845d,0xa0c401e2,0x21840798,0x00000000}},	//   _نهج_, اينو, уѓув, --, 
   {{0x60dc0c67,0x79880af9,0x64bc0419,0xeea80139}},	//   _evrm, _lyfw, _včie, чтек_, 
   {{0x8e840395,0x32cc0210,0x00000000,0x00000000}},	//   ъгле, mży_, --, --, 
   {{0xa194006c,0x21a401f0,0x00000000,0x00000000}},	//   _барч, _биём, --, --, 
   {{0x2fdc0009,0x0c25845e,0xdc98004e,0x00000000}},	//   _udug_, тмин, нтыш_, --, 
   {{0x32cc0034,0x00000000,0x00000000,0x00000000}},	//   nży_, --, --, --, 
   {{0x4a44df30,0x67240023,0x7a3c00bc,0x27e00200}},	//   тнов, _rrij, _nátě, _sdin_, 
   {{0x67241727,0x26c0011c,0x79880368,0x00000000}},	//   _srij, _stio_, _cyfw, --, 
   {{0x67255e63,0x79880142,0x3fd40131,0xddd80427}},	//   _prij, _dyfw, ﻟﻤﺎﻧ, movš, 
   {{0x464c36bc,0xddd8151c,0x27e00076,0xa6840116}},	//   _ፕሮግራ, lovš, _vdin_, лғий, 
   {{0x6725845f,0x31c841ac,0x64980115,0xc8c80451}},	//   _vrij, िरोध, _oƭic, _قوتن_, 
   {{0x67240d27,0x32cc0034,0x2904005a,0x798803cb}},	//   _wrij, eży_, _upna_, _gyfw, 
   {{0x67258460,0x27e18461,0xc724030d,0x7868007c}},	//   _trij, _udin_, _адий, rövä, 
   {{0x7af40724,0xfbd00375,0x38680ba1,0xddd80010}},	// [28ac0] _äytt, יתן_, èbre_, hovš, 
   {{0x38b802b5,0xddd82230,0x052800db,0x00000000}},	//   _hīra_, kovš, _жоок_, --, 
   {{0xf41c0724,0x38b838af,0x6b8802d2,0x00000000}},	//   _ikän_, _kīra_, _lygg, --, 
   {{0x6b880579,0xddd8b515,0x0444023a,0x7a3c00bc}},	//   _oygg, dovš, _ремн, _zátě, 
   {{0x6b8806ea,0x923000db,0xa1c40150,0x00000000}},	//   _nygg, _گۉلش, _бұзд, --, 
   {{0x5bbc00dc,0x00000000,0x00000000,0x00000000}},	//   ैर्व, --, --, --, 
   {{0xddd80010,0xed4c01b9,0x64580064,0xd1740132}},	//   govš, يپه_, _įvij, _быты, 
   {{0x9b940354,0x32380092,0xec64008e,0x6b7800b8}},	//   лийц, _በማሰባ, крык_, _ṅgan, 
   {{0xdc0401ec,0x1ee805af,0x00000000,0x00000000}},	//   _ەستۋ, _سوای_, --, --, 
   {{0x040c0183,0x6b88041e,0xddd80010,0x00000000}},	//   হাটী_, _dygg, bovš, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfdf000bc,0x00000000,0x00000000,0x00000000}},	//   _घाँस_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x79880142,0x6ed80073,0x29000327,0x00000000}},	//   _tyfw, _निघु, ħjar_, --, 
   {{0x795004d3,0x00000000,0x00000000,0x00000000}},	//   _ڕێگا, --, --, --, 
   {{0x57f58462,0x31c8194b,0x7af4008e,0xa8a40024}},	//   _спит, िर्ध, _äyts, _крык, 
   {{0x93798463,0xfce80092,0xd54401e1,0x00000000}},	// [28ad0] хбат_, መረጠ_, bè̟r, --, 
   {{0x32cc0210,0x00000000,0x00000000,0x00000000}},	//   rży_, --, --, --, 
   {{0xc0c00116,0xfbd0190c,0x00000000,0x00000000}},	//   йәти, सराम, --, --, 
   {{0x62818464,0x80ac00e4,0xa3d40166,0xe3b0009f}},	//   _ímon, _ẽtén, _коюч, _ورُ_, 
   {{0xffc00220,0xccdc0150,0x8fd8002b,0x00000000}},	//   сөсп, _ﺘﻘﺘل_, _āśīv, --, 
   {{0xfce8001f,0xddd80f03,0x1e840153,0x00000000}},	//   መረጡ_, tovš, алім, --, 
   {{0x30a43ffb,0x6b8803b2,0x00000000,0x00000000}},	//   _арав, _sygg, --, --, 
   {{0xc1700302,0x3a2c0789,0xddd814b2,0x0c94005b}},	//   _החל_, _anfp_, rovš, ышля, 
   {{0xca840323,0xe3b803ee,0x89d40220,0xfde403e6}},	//   лгий, _şık_, лінш, _ڵکوو_, 
   {{0x3f7804ac,0x5ba40184,0x88c801b9,0xddd80010}},	//   _אָבע, шлығ, нлов_, povš, 
   {{0x38b802b1,0x64bc00d0,0x00000000,0x00000000}},	//   _pīra_, _očia, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x38b80aed,0x044401b9,0x96f80166,0x00000000}},	//   _vīra_, қеан, кэру_, --, 
   {{0xed84044e,0x38b80374,0x00000000,0x00000000}},	//   _ምንታይ_, _wīra_, --, --, 
   {{0x38b98465,0x00000000,0x00000000,0x00000000}},	//   _tīra_, --, --, --, 
   {{0x0cd000bc,0x00000000,0x00000000,0x00000000}},	//   _सबैम, --, --, --, 
   {{0x8c1c39db,0x28d40acd,0x02045acb,0xf37401c6}},	// [28ae0] থাপন_, _भौति, лзан, гөрч_, 
   {{0x1fcc610a,0xdd2c00c0,0xfce80092,0x00000000}},	//   ार्ड, _rėžt, መረጥ_, --, 
   {{0x00e4524d,0xb5f8011a,0x00000000,0x00000000}},	//   ужен, _אליכ, --, --, 
   {{0x4414651a,0x11f801d9,0x7d14012d,0x80181291}},	//   _сфот, _یوُک_, łysk, عزاز_, 
   {{0xbe898466,0x9f356689,0x8fd40032,0xb7d8011a}},	//   нске_, релі, рәсә, תקני, 
   {{0xd39801af,0x00000000,0x00000000,0x00000000}},	//   _рәсә_, --, --, --, 
   {{0x629c0c6a,0x6360001f,0x6d44003d,0x00000000}},	//   _ihro, _ለመጠበ, _żjar, --, 
   {{0x9c7c00d7,0x00000000,0x00000000,0x00000000}},	//   _ovče, --, --, --, 
   {{0x629c06a3,0x1dc443c2,0x8b0401ef,0x00000000}},	//   _khro, _көйн, _nařč, --, 
   {{0x3ea46f63,0x44fc006a,0x8f9800a7,0x5fcc1100}},	//   _сизг, kï_, _ръст_, ारकल, 
   {{0xec118467,0x9c7c0010,0x3ce801a8,0x323408a8}},	//   _گوند, _avče, _íbv_, אטין_, 
   {{0x6ac000bd,0x7d180857,0x7e680175,0x68e400e5}},	//   _শিরো, _ists, lifp, ájda, 
   {{0xa2b019e5,0x629c0232,0x79a58468,0xec10085b}},	//   _अंग्, _ohro, _өрке, _دوند, 
   {{0xda098469,0xca6401b9,0x629c0042,0xdca4013d}},	//   _شيعه_, _кечқ, _nhro, _саҗи, 
   {{0xa9b80375,0x94d400d4,0x00000000,0x00000000}},	//   _אזור, робц, --, --, 
   {{0x2419846a,0x38b80036,0x629d846b,0xdb0c0248}},	//   лосы_, _iër_, _ahro, _àkób, 
   {{0x629c0fa3,0x999c00bc,0x64a400d8,0x00000000}},	// [28af0] _bhro, _kovů_, саѓа, --, 
   {{0x7d19846c,0x629d846d,0x38b81574,0x62800077}},	//   _osts, _chro, _kër_, _ímol, 
   {{0x629c14d0,0x84c00139,0xa0c4027d,0x00000000}},	//   _dhro, _мәтд, ميلو, --, 
   {{0x629d846e,0x38b8a814,0x685c01e1,0x64bc00d7}},	//   _ehro, _mër_, _kómọ, _učia, 
   {{0x629c0afe,0x7d19846f,0x38b8036e,0x00000000}},	//   _fhro, _asts, _lër_, --, 
   {{0x629c00ad,0x00000000,0x00000000,0x00000000}},	//   _ghro, --, --, --, 
   {{0xf41c0589,0x38b80200,0x00000000,0x00000000}},	//   _kaä_, _nër_, --, --, 
   {{0x6ee50596,0x629c2b57,0x64bc39ae,0x32118470}},	//   _مسئل, _zhro, _očin, lexy_, 
   {{0x38b80393,0x7d198471,0x00000000,0x00000000}},	//   _aër_, _ests, --, --, 
   {{0x38b8e64a,0xf41c049f,0xc3300375,0xc928009d}},	//   _bër_, _skäl_, קוי_, воож_, 
   {{0x38b80de2,0x00000000,0x00000000,0x00000000}},	//   _cër_, --, --, --, 
   {{0x38c8b888,0x38b98472,0x15b8054a,0x6bd00451}},	//   کایی_, _dër_, ғыры_, _اڪثر, 
   {{0xeaf80ca5,0x00000000,0x00000000,0x00000000}},	//   _سرشت_, --, --, --, 
   {{0x44fd8473,0x38b800e8,0x55f4010b,0x23b8000d}},	//   tï_, _fër_, йчсу, _अलहद, 
   {{0xf41c0589,0x846c001f,0x32100306,0x04458474}},	//   _baä_, _አብረን_, dexy_, аевн, 
   {{0x629d8475,0x6f18837c,0xb97808a8,0x0444005b}},	//   _shro, _osuc, _בנצי, шебн, 
   {{0xf41c2776,0x629d8476,0x41b42083,0x8678014b}},	// [28b00] _daä_, _phro, асет, _аёну_, 
   {{0x38b81bce,0xd3a400d1,0x41280b01,0x00000000}},	//   _yër_, слуқ, козо_, --, 
   {{0x6f198477,0xa4941272,0x2a640175,0x38b800e8}},	//   _asuc, _هیست, _mmnb_, _xër_, 
   {{0x3fc40bce,0x230800ec,0x00000000,0x00000000}},	//   شگری_, _ٽڪري_, --, --, 
   {{0x629c20c6,0xb88401a8,0x00000000,0x00000000}},	//   _thro, _hlíð, --, --, 
   {{0xb88402d2,0x629c0419,0x00000000,0x00000000}},	//   _klíð, _uhro, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6f180334,0x69c4030a,0x00000000,0x00000000}},	//   _fsuc, ñjen, --, --, 
   {{0x38b80200,0x9b5800d8,0x00000000,0x00000000}},	//   _sër_, ѓиот_, --, --, 
   {{0x38b92762,0x2cac00fe,0xba44352d,0x7d180036}},	//   _për_, _eigd_, рхий, _tsts, 
   {{0xdbe804c5,0x7d18035a,0xf41c007c,0x0ce800db}},	//   ক্ষস_, _usts, _skäm_, _مةنى_, 
   {{0x64bc009b,0x38b80200,0x3b8401ee,0x8ac40124}},	//   _pčin, _vër_, _клег, шқәа_, 
   {{0x7bc00472,0xcca400db,0x38b98478,0xbbd00073}},	//   _ifou, _احلى, _wër_, सरीक, 
   {{0xb88405f7,0x38b82568,0x999801d3,0x386803cb}},	//   _blíð, _tër_, űrő_, sicr_, 
   {{0x2d80037e,0xe7140139,0x65e400c7,0x00000000}},	//   _øjet_, _tüğä, цәыҧ, --, 
   {{0x83c800d1,0x00000000,0x00000000,0x00000000}},	//   _ﺑﯩﺮﺳ, --, --, --, 
   {{0x98a401e0,0xa87c011a,0x00000000,0x00000000}},	// [28b10] _киҫе, _שאחר, --, --, 
   {{0x6f180295,0x7ae00472,0x31c58479,0x1af800fe}},	//   _rsuc, _mvot, рсав, _অনাই_, 
   {{0x6f18107d,0xb8840174,0x7bc0035a,0x622400d1}},	//   _ssuc, _glíð, _ofou, تىلل, 
   {{0x3211847a,0x61fc01ab,0x7ae1847b,0x00000000}},	//   sexy_, _ecrl, _ovot, --, 
   {{0x533404ac,0x48dc007d,0x7ae000d7,0x7bc403e0}},	//   _האָב_, _कौनो_, _nvot, ıkul, 
   {{0x9e64090b,0x7bc0be21,0xc330010f,0x741000ec}},	//   овід, _afou, _זוך_, _اوڏا, 
   {{0x7ae1847c,0xc2100302,0x00000000,0x00000000}},	//   _avot, _מהם_, --, --, 
   {{0x6f18019b,0xf0740bd6,0x3d284dc1,0x00000000}},	//   _tsuc, _тибә_, اتوی_, --, 
   {{0x6f19847d,0x2cac05ac,0x26180ce0,0xe0640133}},	//   _usuc, _vigd_, _फसली_, _بێنی, 
   {{0x7bc00d81,0x49c800c7,0x00000000,0x00000000}},	//   _efou, ылон_, --, --, 
   {{0x8d940491,0x7ae1847e,0x00000000,0x00000000}},	//   _الاش, _evot, --, --, 
   {{0xf65c06ea,0x00000000,0x00000000,0x00000000}},	//   spæl_, --, --, --, 
   {{0x0f78008f,0x9c6404fb,0x4ac40a52,0xb88403f2}},	//   ראָב, _بهنو, _ايتق, _slíð, 
   {{0x98a00064,0xb340031c,0x00000000,0x00000000}},	//   _čią_, ħħlu, --, --, 
   {{0x7ae0004c,0xe82059c9,0x00000000,0x00000000}},	//   _zvot, _बसपा_, --, --, 
   {{0x61fc0175,0x7ae0035b,0x1458013d,0x54800023}},	//   _scrl, _yvot, ашуы_, _የብርህ_, 
   {{0x3ab800c8,0xe3a40ed8,0x00000000,0x00000000}},	// [28b20] ָמענ, زشری, --, --, 
   {{0x41b5847f,0x64bc3ad4,0x64a40046,0xb6998480}},	//   ссат, _učio, саға, ltân, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb6998481,0xa4e40073,0x6fc802dd,0x24540345}},	//   ntân, गळीच_, _ﺗﯩﺮﺷ, _بۆرس, 
   {{0xf2e4021a,0x44218482,0x7e780334,0x7bc400e8}},	//   _هکله_, _iak_, _pjtp, ñkum, 
   {{0x4420080b,0xadd00640,0x7bc001ef,0x00000000}},	//   _hak_, пошљ, _sfou, --, 
   {{0x4420fe56,0x8c08009e,0x00000000,0x00000000}},	//   _kak_, _শোধন_, --, --, 
   {{0x44218483,0x69c18484,0x20c40521,0x786c007f}},	//   _jak_, _afne, _ịkwụ_, _mòvè, 
   {{0x44218485,0x23618486,0x68e00083,0xb03400df}},	//   _mak_, nzij_, _avnd, _פאמפ_, 
   {{0x44218487,0x7ae0031c,0xa06801e0,0x38c80a5b}},	//   _lak_, _vvot, _саға_, лумн_, 
   {{0x786c02e2,0x44218488,0x58380395,0x00000000}},	//   _nòvè, _oak_, азня_, --, 
   {{0x44202295,0x69c18489,0x77280092,0xbaa40116}},	//   _nak_, _efne, _ስላልተ, шуққ, 
   {{0x7ae00fec,0x23600010,0x395c0175,0x69c0002f}},	//   _uvot, jzij_, szts_, _ffne, 
   {{0x4421848a,0x7c200053,0x64bc16a3,0x245c02d2}},	//   _aak_, _haor, _ičij, _límd_, 
   {{0x7c21848b,0x00000000,0x00000000,0x00000000}},	//   _kaor, --, --, --, 
   {{0xb698054e,0x39ac06be,0x00000000,0x00000000}},	//   ctân, məs_, --, --, 
   {{0x1cb86d7e,0x7c21848c,0x4421848d,0x36f0025c}},	// [28b30] _མངའ_, _maor, _dak_, _བཀྲལ_, 
   {{0xf1a4a6fa,0x7c200483,0xb9f00020,0x442001c6}},	//   брен, _laor, _ዞን_, _eak_, 
   {{0x4421848e,0xd130007b,0x3dcc0011,0xa5080120}},	//   _fak_, بما_, রণাল, _леќа_, 
   {{0x4421848f,0x64bc098d,0x8f5400d1,0x00000000}},	//   _gak_, _očij, يناش, --, 
   {{0xb8d8081f,0xa924013a,0xaf0400d8,0x00000000}},	//   _ཆང_, _koží, счек, --, 
   {{0x4420a9e2,0xc33025f9,0xd0d400a7,0x39ac0213}},	//   _zak_, _קום_, _могъ, kəs_, 
   {{0x7c218490,0x44218491,0x69c40165,0x69c0013d}},	//   _baor, _yak_, ñjem, _rfne, 
   {{0x7c218492,0x09e000a5,0x0ae98493,0x004400aa}},	//   _caor, पण्य, адий_, _ویلي_, 
   {{0x7c218494,0x0a38d54f,0x00000000,0x00000000}},	//   _daor, ачны_, --, --, 
   {{0xa9240306,0x39ac0213,0xddc80118,0x00000000}},	//   _noží, fəs_, _oldř, --, 
   {{0x1cb80003,0x7c2001ab,0x00000000,0x00000000}},	//   _མངར_, _faor, --, --, 
   {{0xc0e002d3,0xd90c004b,0x7c201db0,0xf41c0166}},	//   _ነባሪ_, ایي_, _gaor, _ikäw_, 
   {{0x44218495,0xb698dee9,0x09e40a83,0x7d140034}},	//   _rak_, rtân, _долн, łyst, 
   {{0xb6998496,0x55c41c5c,0x245c00e4,0x5ba4009d}},	//   stân, зарғ, _míme_, _эрхз, 
   {{0x44218497,0x7c200810,0xb6980311,0xa9240306}},	//   _pak_, _yaor, ptân, _doží, 
   {{0x22958498,0x1cb80135,0x7c200077,0x23600d27}},	//   mäki_, _མངལ_, _xaor, tzij_, 
   {{0x44218499,0x245c00e4,0x229401f4,0xd1c00092}},	// [28b40] _vak_, _níme_, läki_, _ድሆች_, 
   {{0x4421849a,0x23600010,0x00000000,0x00000000}},	//   _wak_, rzij_, --, --, 
   {{0x0445849b,0x229401f4,0x00000000,0x00000000}},	//   _денн, näki_, --, --, 
   {{0x4421849c,0x00000000,0x00000000,0x00000000}},	//   _uak_, --, --, --, 
   {{0x245c01ed,0x7c21849d,0x00000000,0x00000000}},	//   _címe_, _raor, --, --, 
   {{0x41288148,0x7c21849e,0xc21001d9,0xfcc40114}},	//   _кого_, _saor, _تٔس_, ољим, 
   {{0x7c21849f,0x998c033f,0xdb500133,0x00000000}},	//   _paor, zedł_, کێش_, --, 
   {{0x22940209,0x9c7c02e2,0x6ee001f2,0x9c3800d8}},	//   däki_, _evčn, _ọber, спит_, 
   {{0x7c2184a0,0x00000000,0x00000000,0x00000000}},	//   _vaor, --, --, --, 
   {{0x38b800b0,0x7c2184a1,0xd8f80212,0x00000000}},	//   _hīri_, _waor, бної_, --, 
   {{0x7c2184a2,0x64bc0270,0x31b80a1e,0x6e901541}},	//   _taor, _hōif, יזינ, _غلما, 
   {{0x3b080e2a,0x00000000,0x00000000,0x00000000}},	//   _ведо_, --, --, --, 
   {{0xa9240306,0x64bc0219,0xeb940354,0xc1d801e1}},	//   _poží, _učij, _диц_, _ẹ̀wè, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x1cb80f50,0xa3c80521,0x746984a3,0xa5040139}},	//   _མངས_, _ọbịa_, арав_, мятл, 
   {{0x427800b7,0xe3b80166,0x6b780055,0x00000000}},	//   _በረከት_, _şır_, _ṅgin, --, 
   {{0x2458023a,0xdee404b3,0xdb240139,0x925800d8}},	// [28b50] цать_, _جۋ_, _üsäs, баат_, 
   {{0x245c00d0,0xa2280114,0x00000000,0x00000000}},	//   _ríme_, ожђа_, --, --, 
   {{0xc0e0069d,0x00000000,0x00000000,0x00000000}},	//   _ነባር_, --, --, --, 
   {{0x3fcc1d00,0xc8b4010f,0x00000000,0x00000000}},	//   _ﺗﯩﺮﻧ, פּעה_, --, --, 
   {{0xce940801,0x5f748ee7,0x38380092,0xdb2401e1}},	//   падъ, واهر, _እየተበ, _òsèr, 
   {{0x245c012c,0x1ea84d49,0x82d402e4,0x050c00fe}},	//   _víme_, ياوي_, _מושג_, হিৰৰ_, 
   {{0xa194001b,0x00000000,0x00000000,0x00000000}},	//   _жарч, --, --, --, 
   {{0x0b44006c,0x245c96f1,0x2294005b,0xf1d001af}},	//   знин, _tíme_, väki_, _хөҡө, 
   {{0x6f6c0131,0x00000000,0x00000000,0x00000000}},	//   ﻻﺭﻏﺎ_, --, --, --, 
   {{0xad2000db,0xe3b84982,0x229401f4,0xc9640395}},	//   _يۉشى, _अल्झ, täki_, звой, 
   {{0xda640a2c,0xd9b008b0,0x0888d56b,0x00000000}},	//   بايي, پەيد, йбой_, --, 
   {{0xb698002d,0x00000000,0x00000000,0x00000000}},	//   stâl, --, --, --, 
   {{0x1cb80327,0x0bcc0150,0x00000000,0x00000000}},	//   _མངོ_, _ﺔﻘﻳﺮ, --, --, 
   {{0x7cc8000f,0x35c40114,0x00000000,0x00000000}},	//   _dęrf, згро_, --, --, 
   {{0x84591567,0x366401f0,0x6fc80b4c,0xdb20007c}},	//   брат_, чаро_, ाडां, åtöl, 
   {{0x3880001f,0x06dc00fe,0x13400092,0x00000000}},	//   _ሪፖርቱ_, ভূষি, _ከመጽሐ, --, 
   {{0xd57802d3,0xc1e801c6,0xf8b005d0,0x00000000}},	// [28b60] _የድልዮ_, йдаж_, _אשה_, --, 
   {{0xc1d40210,0x00000000,0x00000000,0x00000000}},	//   धरेग, --, --, --, 
   {{0x8e8400df,0x00d8072d,0x00000000,0x00000000}},	//   _meŝĉ, صبات_, --, --, 
   {{0x48dc05d7,0x00000000,0x00000000,0x00000000}},	//   कीयो_, --, --, --, 
   {{0x38b800de,0x00000000,0x00000000,0x00000000}},	//   _vīri_, --, --, --, 
   {{0xdd941e1d,0x6444002e,0x00000000,0x00000000}},	//   малы, ljii, --, --, 
   {{0x64bc01ab,0x6444208d,0x38b80171,0xdd900451}},	//   _dōig, ojii, _tīri_, ڙوڪ_, 
   {{0xacf004a9,0x64440a55,0x6be000d1,0x6ca00124}},	//   رسىت, njii, ىكىم, нрыж, 
   {{0xc5e003d4,0x00000000,0x00000000,0x00000000}},	//   _বানপ, --, --, --, 
   {{0x64440108,0xf77c036e,0x00000000,0x00000000}},	//   hjii, naçe_, --, --, 
   {{0xf4b40154,0xa9c00137,0x00000000,0x00000000}},	//   _জব্ব, رۅيۉ, --, --, 
   {{0x7ac4005e,0x644422a9,0xbb4400f3,0x00000000}},	//   _еске, jjii, _неек, --, 
   {{0x81e02158,0xae4001d9,0x6444058a,0xae6402f2}},	//   _ধান_, _تھۆو, djii, _بڕۆن_, 
   {{0x6444022f,0x6b60013e,0xe3b8294f,0xf7400023}},	//   ejii, _якча, _şıp_, _ንኸይን, 
   {{0x7cc8002d,0xdb24030f,0xa904009f,0xddc8013a}},	//   _węrf, _روژی, _فيول_, _vodň, 
   {{0xe9780375,0xdb2401e1,0xa978011a,0x00000000}},	//   _לנוש, _àsós, _לאוכ, --, 
   {{0x2484001f,0x38b800cd,0xe73c010e,0x98ac0064}},	// [28b70] _የጥራት_, _dūre_, _küýü, lydį_, 
   {{0xf1a41d83,0xe3b000c6,0xf77c0200,0x644401f4}},	//   прен, طرق_, gaçe_, ajii, 
   {{0x21a800fd,0x00000000,0x00000000,0x00000000}},	//   зәтү_, --, --, --, 
   {{0x2c1c0183,0x20540150,0x00000000,0x00000000}},	//   ভাৱে_, нтір, --, --, 
   {{0x44240115,0x00000000,0x00000000,0x00000000}},	//   ɾo_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4c68352d,0xabc000fb,0xc5e00154,0x817801f0}},	//   жийн_, найҙ, _বামপ, _дарӣ_, 
   {{0xcac834d8,0xe1f00014,0x00000000,0x00000000}},	//   огие_, _لسہ_, --, --, 
   {{0x89f4efcc,0x2c1c00fe,0xa05c010a,0xdfd80395}},	//   мянц, ভালৈ_, _утрĕ_, _хъс_, 
   {{0x2fdc0438,0x2bfc0f22,0x628003b2,0x08c4854b}},	//   _heug_, ্যেই_, _ímot, мбон, 
   {{0x245c08ce,0xd90c2d56,0x6b840ee8,0x00000000}},	//   _líma_, میو_, _کشال, --, 
   {{0x2fdc0660,0x245c00e4,0xd1e4069d,0x229401e3}},	//   _jeug_, _oíma_, _ምድብ_, läkt_, 
   {{0x2fdc01b8,0xf400015b,0x9c7d7604,0x159000d1}},	//   _meug_, উজার_, _ovčj, ﺘﯩﺸﯩ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x38b824cb,0xc8c80244,0x48080150,0x00000000}},	//   _pūre_, _بوبن_, _дейн_, --, 
   {{0x38c8331c,0x64bc2e31,0x00000000,0x00000000}},	//   _باوی_, _očiv, --, --, 
   {{0x64448ebb,0x06840798,0xb7e0012d,0x00000000}},	// [28b80] rjii, _огин, _ख़तम_, --, 
   {{0x6724e3cb,0x442584a4,0xc1740472,0x728400e5}},	//   _isij, žo_, ودات, والے, 
   {{0x661d84a5,0x27e184a6,0x2fdc1bce,0xfd540241}},	//   merk, _kein_, _beug_, _dibọ, 
   {{0x26c00270,0x6ee00521,0x27e184a7,0x67240327}},	//   _kuio_, _ọbar, _jein_, _ksij, 
   {{0x27e184a8,0x2fdc0192,0xefd40020,0xa3d400dc}},	//   _mein_, _deug_, ሮሚያ_, _स्य_, 
   {{0x27e184a9,0x672579e3,0xfd100a11,0x3b0401a9}},	//   _lein_, _msij, نجع_, _rqoq_, 
   {{0x661c01c7,0xfbe00154,0x40940108,0x18640092}},	//   ierk, _যাবত, _жрат, _ሲፈጠር_, 
   {{0x672584aa,0x27e184ab,0xa3d40882,0xdd940184}},	//   _osij, _nein_, _स्म_, маһы, 
   {{0x29040309,0xafe0b4f2,0x20040e02,0xeb940640}},	//   _aqna_, _шотл, _icmi_, мић_, 
   {{0x661d84ac,0x2fdc1298,0x58d40798,0xd8f800d4}},	//   jerk, _zeug_, ноот, пної_, 
   {{0x27e184ad,0x672584ae,0x2fdc0de2,0xa3c00073}},	//   _bein_, _asij, _yeug_, ुडा_, 
   {{0x26c000a7,0x98ac0153,0x00000000,0x00000000}},	//   _buio_, rydį_, --, --, 
   {{0x661d84af,0x27e174a2,0x26c00077,0xe73c00a2}},	//   ferk, _dein_, _cuio_, _tüýü, 
   {{0x661d84b0,0x9c7c0427,0x245c827c,0x00000000}},	//   gerk, _ovčk, _ríma_, --, 
   {{0x27e184b1,0x67241cdf,0x245c0008,0x659584b2}},	//   _fein_, _esij, _síma_, вару, 
   {{0x27e0030a,0xb69800e4,0x195801af,0x982800e5}},	//   _gein_, kuâg, _маһы_, _رتبہ_, 
   {{0x17ac1c82,0x26c00022,0x20c4063f,0x2fdc003e}},	// [28b90] _ক্ৰি, _guio_, _ịkpụ_, _reug_, 
   {{0xd1e4044e,0x27e00323,0x2fdc0438,0xe1f184b3}},	//   _ምስቲ_, _zein_, _seug_, لسم_, 
   {{0x26c0009f,0x27e0062c,0xb5a45f3c,0x38b800de}},	//   _zuio_, _yein_, _юрий, _tīru_, 
   {{0x245c31ac,0x23b52374,0x27e0003a,0x00000000}},	//   _tíma_, رمەس, _xein_, --, 
   {{0x229584b4,0x8488001f,0x20dc0115,0xfd5401e1}},	//   täkt_, _መኖሩን_, aŭi_, _tibọ, 
   {{0xdce81ae4,0x200400a3,0x05940150,0x82440354}},	//   _azdı, _ecmi_, _تاۋگ, _пĕчч, 
   {{0xe8200490,0x2fdc0af9,0x22940267,0xd1e40023}},	//   _बसला_, _teug_, räkt_, _ምስታ_, 
   {{0x229401e6,0xa0a584b5,0x661d84b6,0x8b2584b7}},	//   säkt_, _ашул, zerk, едие, 
   {{0x661c1ff6,0xd450001f,0x64bc02fb,0x6d4c06be}},	//   yerk, _የወደፊ, _učiv, _əcay, 
   {{0x27e184b8,0x20040a73,0x1a691d33,0x7cc8000f}},	//   _sein_, _zcmi_, وینی_, _dęrb, 
   {{0x661c2a0e,0x27e184b9,0xc210010f,0x00000000}},	//   verk, _pein_, נהט_, --, 
   {{0x661c899d,0x1cb80135,0x00000000,0x00000000}},	//   werk, _མངག_, --, --, 
   {{0x443c0016,0x27e01948,0x35a0024c,0xcac80354}},	//   _đt_, _vein_, ғатг, _эгле_, 
   {{0x27e184ba,0x64bd84bb,0x443c01ed,0x661d84bc}},	//   _wein_, _očit, _őt_, uerk, 
   {{0x661d84bd,0x27e184be,0x84581d0f,0x6d4003ac}},	//   rerk, _tein_, прат_, nxna, 
   {{0x46e80c04,0x42c984bf,0x4278044e,0xf41c01e6}},	//   _един_, зган_, _በረኸት_, _skär_, 
   {{0x672584c0,0x814400f2,0x84880092,0x00000000}},	// [28ba0] _usij, کنان, _መኖርን_, --, 
   {{0x73300131,0xd3a400d1,0x661c0200,0x229401f4}},	//   دىكا, тлуқ, qerk, väks_, 
   {{0xf77d6372,0x64bc00a3,0x80f80220,0xb9c8001f}},	//   maça_, _cčit, яхат_, _ሰዉ_, 
   {{0xc09584c1,0x7f8403cc,0x38b846e4,0xf77c56eb}},	//   رجات, ىلان, _jūra_, laça_, 
   {{0x7964002e,0x4374374e,0x38b800de,0x00000000}},	//   _kéwé, _чунт, _mūra_, --, 
   {{0xf77c9972,0x9c7c01a6,0x21740107,0xa3d493d3}},	//   naça_, _ivči, _ҷуғр, _स्त_, 
   {{0xf65025f9,0x6e401dc8,0x7964003e,0x71a0a7f2}},	//   רצו_, انىم, _méwé, _барз, 
   {{0x7964003e,0x248184c2,0x245c0248,0x9b94010a}},	//   _léwé, nnim_, _mímo_, кийц, 
   {{0x6f0802d0,0x248141ea,0xbd880066,0xf77c0139}},	//   ctgc, inim_, _کنان_, kaça_, 
   {{0x248184c3,0x00000000,0x00000000,0x00000000}},	//   hnim_, --, --, --, 
   {{0x7cc8002d,0x81ac0183,0xe784013e,0xa7980150}},	//   _węrb, ওঁক_, ҳуро, _ﺄﺜﺭﺓ_, 
   {{0x2480041a,0xdce80598,0x9c7c0419,0x49100037}},	//   jnim_, _uzdı, _ovči, _तहरो_, 
   {{0x24801326,0x64bc14a6,0xe78584c4,0x38b800b8}},	//   dnim_, _očis, гуро, _dūra_, 
   {{0x245c0ca8,0xd9140124,0x2480102c,0xf77d84c5}},	//   _bímo_, _адкы, enim_, gaça_, 
   {{0x81e404c5,0x796584c6,0x38b8005f,0xaca0063f}},	//   ফলা_, _déwé, _vīrs_, shụa, 
   {{0x24800b02,0x29080311,0x29980375,0x00000000}},	//   gnim_, ăcat_, _מסומ, --, 
   {{0xf77c0798,0x38c801d3,0x649801a9,0x00000000}},	// [28bb0] baça_, _باڈی_, хтёр_, --, 
   {{0x24802d9e,0xf77c068c,0x81a800fe,0x38b800de}},	//   anim_, caça_, খখন_, _tīrs_, 
   {{0xf77000dd,0x69c449ad,0x00000000,0x00000000}},	//   _جاں_, žjeg, --, --, 
   {{0x24800b91,0xddc8110c,0x8f7401ce,0x00000000}},	//   cnim_, _ćoša, кулі, --, 
   {{0x79640694,0x00000000,0x00000000,0x00000000}},	//   _yéwé, --, --, --, 
   {{0xb64000b5,0x00000000,0x00000000,0x00000000}},	//   _ｌｒ_, --, --, --, 
   {{0x64bcceba,0x6d400399,0xd70c0154,0x00000000}},	//   _učit, uxna, শিয়া_, --, 
   {{0xf2dc006a,0xf3fc0798,0x0fa8033f,0x00000000}},	//   _kwâ_, _imãs_, _औरपढ, --, 
   {{0x4aa984c7,0xddc800e5,0x89d40150,0x00000000}},	//   мкин_, _eldő, кінш, --, 
   {{0x24801505,0x5ba584c8,0x9ab4002b,0xeb9401a9}},	//   znim_, ылығ, _prāṃ, миқ_, 
   {{0x7964003e,0xdb080330,0x38b80055,0xfe6c00f2}},	//   _réwé, وزیه_, _sūra_, _بگن_, 
   {{0xc0c80023,0x5f0800cd,0x38b80a88,0x00000000}},	//   _ኽብሪ_, _समम्_, _pūra_, --, 
   {{0x65b008b0,0xf77c2347,0x3eb8007f,0xa3d40c5a}},	//   ﻳﺘﯩﻠ, taça_, ňpte_, सुफ_, 
   {{0xa3d40490,0xfd4c002b,0x9c440124,0xe86401c0}},	//   सुन_, _atiṣ, _ахәл, тхүү, 
   {{0xf77c2852,0xd4f584c9,0x9ab40055,0x4e0800bc}},	//   raça_, ляты, _urāṃ, _सानै_, 
   {{0xf2dc019f,0x24801509,0x64bc0427,0x03a400d4}},	//   _bwâ_, unim_, _sčis, вибо, 
   {{0xf77d84ca,0x0324059f,0xf77001c8,0x00000000}},	// [28bc0] paça_, ъдан, _ناٿ_, --, 
   {{0x248008ad,0x64a40220,0xf65c01bf,0x00000000}},	//   snim_, таға, spær_, --, 
   {{0x88400023,0xe43c013a,0x00000000,0x00000000}},	//   _ክከታተ, _hříč, --, --, 
   {{0x24800200,0xc0cc0240,0x17e000cc,0x00000000}},	//   qnim_, _ብወረ_, _ভাৱি, --, 
   {{0xbe88634c,0x628001e1,0x00000000,0x00000000}},	//   мске_, _ìmoo, --, --, 
   {{0x3eb801e3,0x00000000,0x00000000,0x00000000}},	//   öpt_, --, --, --, 
   {{0xc0e46ee2,0x2484001f,0x00000000,0x00000000}},	//   _шовк, _የእሳት_, --, --, 
   {{0xee3421bf,0x00000000,0x00000000,0x00000000}},	//   енә_, --, --, --, 
   {{0xfec87f51,0x8fd40ce8,0x00000000,0x00000000}},	//   _آبرو_, _сәхә, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x195984cb,0xbd4494b9,0x426004b2,0x88f001e2}},	//   ханы_, _جناي, _ሰከንድ_, مړيت, 
   {{0xed54059f,0x7d180857,0x2c084689,0x69c40156}},	//   _шох_, _ipts, _يعنی_, ñjer, 
   {{0xec107735,0x1af4187f,0x00000000,0x00000000}},	//   _خوند, _спля, --, --, 
   {{0x63a000d2,0x00000000,0x00000000,0x00000000}},	//   _úmny, --, --, --, 
   {{0xe4c401b9,0x00000000,0x00000000,0x00000000}},	//   иётн, --, --, --, 
   {{0x24180b7e,0x00000000,0x00000000,0x00000000}},	//   косы_, --, --, --, 
   {{0xf77c00d8,0x59bc033f,0x00000000,0x00000000}},	// [28bd0] maço_, ोडकर, --, --, 
   {{0xf77d84cc,0x3204002d,0xc0cc0092,0x00000000}},	//   laço_, üny_, _ብለሽ_, --, 
   {{0xa3d584cd,0x50f4026a,0xefbc0023,0xfd4c0055}},	//   _स्व_, узет, _ስመይ_, _ttiṣ, 
   {{0x32040034,0xa2800092,0x38b80153,0x00000000}},	//   żny_, ናወኑን_, _mūro_, --, 
   {{0x64bc02b1,0xdd100308,0x81e00154,0x91a4000d}},	//   _kōin, výše, _ধার_, _करवै, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb338010e,0x4a7401ec,0x0d740345,0x00000000}},	//   _byçg, ғыпт, دیاک_, --, 
   {{0x0c2584ce,0xae000075,0xf77c00d8,0x00000000}},	//   умин, _چۈشى, jaço_, --, 
   {{0xf77c06ed,0x7d18035a,0x00000000,0x00000000}},	//   daço_, _epts, --, --, 
   {{0x6f180342,0x5cac0055,0x00000000,0x00000000}},	//   _ipuc, _vṛṅk, --, --, 
   {{0x7afc0055,0x00000000,0x00000000,0x00000000}},	//   _āpte, --, --, --, 
   {{0x6f1802e3,0xe43c012c,0x798802d0,0xf77c0798}},	//   _kpuc, _příč, _dxfw, gaço_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x38c984cf,0x7d1802d0,0x09e40139,0xab0400b8}},	//   بایی_, _ypts, _сокн, _ūṣṇī, 
   {{0xaee00943,0x42540046,0xf77c0798,0x44140b01}},	//   _maṱo, қтат, baço_, лфат, 
   {{0x6f18e475,0x64ac0e78,0x670410de,0xe43c013a}},	//   _opuc, ißig, _күмб, _tříč, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [28be0] --, --, --, --, 
   {{0x26c4022a,0x05280137,0x232801d5,0x00000000}},	//   ímou_, _зоок_, ноғи_, --, 
   {{0x6f1984d0,0x7d14033f,0xb698003a,0x00000000}},	//   _apuc, łysz, rtât, --, 
   {{0x044584d1,0xb4f8159d,0xa4940345,0x00000000}},	//   _семн, _אפטי, _ئیرت, --, 
   {{0x6f180175,0xb698003a,0x0fc400d1,0x00000000}},	//   _cpuc, ptât, рқуп_, --, 
   {{0x7cc8045f,0x64bc02b5,0x9e3418bc,0x00000000}},	//   _dęrn, _kōio, рекч, --, 
   {{0x0164d99e,0x6f1819f5,0xdd909448,0xda7800d7}},	//   _скво, _epuc, غوب_, viď_, 
   {{0x4e080316,0x64bc00b0,0xdd840220,0x1af482c8}},	//   _साथै_, _mōio, лықп, апия, 
   {{0xa3cc4328,0x307802e4,0x38b80055,0xbea4014b}},	//   _ललन_, _נאמנ, _sūro_, _баак, 
   {{0x9c7c0100,0xdc240154,0x9f44036e,0xa5d403ce}},	//   _avčt, ভাইস_, _lemë_, _ब्लौ, 
   {{0x3ebc022f,0x7ac4008e,0x64b401f9,0x3cf800ae}},	//   _iitt_, _өсле, ंगाळ, _سعاد_, 
   {{0x3ebc2833,0x621400dc,0x38a800e4,0x00000000}},	//   _hitt_, न्तौ_, kùre_, --, 
   {{0x3ebd84d2,0xf77c0261,0x5a50001f,0xb338036e}},	//   _kitt_, raço_, _ይገልጻ, _kyçe, 
   {{0x7ae00472,0xba28009a,0xf3640150,0x00000000}},	//   _iwot, _سستم_, ңтан, --, 
   {{0x3ebc0267,0xf77c03b7,0x7ae00810,0xf4840064}},	//   _mitt_, paço_, _hwot, гуан, 
   {{0x3ebc1a84,0x7ae184d3,0xfaa405d9,0x656800a3}},	//   _litt_, _kwot, _جهڙي_, ùdha, 
   {{0x1cb8031c,0xe2f802dd,0x9f440200,0x066400cf}},	// [28bf0] _མངན_, леті_, _demë_, _چاپپ, 
   {{0xe70400dd,0x3ebd8472,0x78bc0455,0x7ae0dbe3}},	//   _اسٹی, _nitt_, _hiqv, _mwot, 
   {{0x81e404c5,0x7ae00083,0xb1a40a93,0xe1340166}},	//   ফলং_, _lwot, ушак, йнфы, 
   {{0x7bc184d4,0x3ebc0363,0x7ae0009a,0x1a200154}},	//   _ngou, _aitt_, _owot, বায়ু_, 
   {{0xb8141e61,0x3ebd84d5,0x78bd84d6,0x2aa801bf}},	//   ध्यम_, _bitt_, _miqv, løbe_, 
   {{0x3ebc0395,0x9f440ffb,0x00000000,0x00000000}},	//   _citt_, _memè_, --, --, 
   {{0x3ebc4e97,0x7ae184d7,0x7cc8000f,0x30a47737}},	//   _ditt_, _awot, _dęro, _брав, 
   {{0x3ebd84d8,0x7ae184d9,0x78bc0477,0x4c340006}},	//   _eitt_, _bwot, _niqv, рэкт, 
   {{0x6f180989,0x3ebc022c,0x7ae00042,0x256c0241}},	//   _upuc, _fitt_, _cwot, _kólé_, 
   {{0x3ebd84da,0x09e400f7,0x7bc05dae,0x2aa801bf}},	//   _gitt_, шоон, _egou, købe_, 
   {{0x88842c71,0x6e2009a5,0x78bc014f,0x7ae02ad1}},	//   илож, menb, _biqv, _ewot, 
   {{0x6e2184db,0x7ae0033b,0x3ebc0221,0x256c01e1}},	//   lenb, _fwot, _zitt_, _lólé_, 
   {{0x7ae184dc,0x6e200b4f,0x491000bc,0x00000000}},	//   _gwot, oenb, _तहको_, --, 
   {{0x6e2184dd,0x5f08150d,0xba400153,0x3ad001e2}},	//   nenb, _समस्_, _šįva, _بيوز, 
   {{0x69c184de,0x7ae01682,0x9f440023,0x6e200065}},	//   _igne, _zwot, _pemë_, ienb, 
   {{0x636c019f,0x26c584df,0x6e2184e0,0xf484dbed}},	//   _nôné, ímos_, henb, لاقی, 
  
   {{0x69c001ee,0x68e00369,0x4e040316,0xb8980302}},	// [28c00] _kgne, _hwnd, रलाई_, _בבקש, 
   {{0xb6989fe2,0x6e2001f5,0xf41c007c,0x245c02d2}},	//   stâr, jenb, _hjäl_, _mími_, 
   {{0x3ebc1347,0x9f4402d3,0x69c0010a,0xbfc49277}},	//   _ritt_, _temë_, _mgne, абек, 
   {{0x3ebc2a0e,0xb698054e,0xb3380200,0x00000000}},	//   _sitt_, nuân, _syçe, --, 
   {{0x6e2184e1,0x9f3584e2,0x1df807e6,0x4430010b}},	//   fenb, селі, гелы_, mdy_, 
   {{0x44300510,0x6e210f4a,0x69c0009a,0x7bc00268}},	//   ldy_, genb, _ngne, _sgou, 
   {{0x3ebd84e3,0xddc8068f,0x7ae002b9,0x721804ae}},	//   _vitt_, _podł, _swot, _שולח, 
   {{0x7ae00d29,0x443184e4,0x245c0241,0x7cc8045f}},	//   _pwot, ndy_, _bími_, _węro, 
   {{0x443184e5,0x3ebd5d41,0x6e2184e6,0x68e00857}},	//   idy_, _titt_, benb, _awnd, 
   {{0x1cb80156,0x443184e7,0x3ea40017,0x68e00042}},	//   _མངམ_, hdy_, _тизг, _bwnd, 
   {{0x4430fbd7,0x9f44007f,0x00000000,0x00000000}},	//   kdy_, _semè_, --, --, 
   {{0x7ae184e8,0x69c011aa,0x7bc04e2b,0x60c184e9}},	//   _twot, _egne, _ugou, _jimm, 
   {{0x60c184ea,0x629d84eb,0x443184ec,0xf8a001c6}},	//   _mimm, _okro, ddy_, йгүү, 
   {{0x68e00369,0x629c016b,0x443184ed,0xe6640415}},	//   _fwnd, _nkro, edy_, отсо, 
   {{0xfa540014,0x78bc014f,0x4430015d,0xe578009d}},	//   _مرژگ, _tiqv, fdy_, айрч_, 
   {{0x613000f8,0x60c184ee,0x6e2184ef,0x443184f0}},	//   zólá, _nimm, zenb, gdy_, 
   {{0x6e2184f1,0xe7b40050,0x31c48392,0xb8640345}},	// [28c10] yenb, _وۅپد, асев, _ماکو, 
   {{0x6e20e9e8,0x44309be7,0x48dc012c,0x60c000d0}},	//   xenb, ady_, कीको_, _aimm, 
   {{0x6e2184f2,0x60c184f3,0x46153e5b,0x3dcc0183}},	//   venb, _bimm, _اوپر, ৰণাল, 
   {{0x60c023db,0x6e200036,0x256c01e1,0x443000a2}},	//   _cimm, wenb, _wólé_, cdy_, 
   {{0x7cc8000f,0x9f98223e,0x60c03fe5,0x8e5402dd}},	//   _dęrm, авцу_, _dimm, йткі, 
   {{0x5f08045b,0x6e200112,0x60c002d2,0x245c02d2}},	//   _समर्_, uenb, _eimm, _rími_, 
   {{0x60c0008c,0x245cfdc6,0xe920031c,0x998c01d3}},	//   _fimm, _sími_, _འགེབ_, kedő_, 
   {{0x6e2184f4,0x60c184f5,0x68e00223,0x1b2004c5}},	//   senb, _gimm, _rwnd, বিনে_, 
   {{0x6e2184f6,0xd140001f,0x69c0004e,0x2ab414d4}},	//   penb, _የሚበል, _pgne, аңды_, 
   {{0x443184f7,0x60c184f8,0xc0cc0020,0xf41c01e6}},	//   zdy_, _zimm, _ብለህ_, _själ_, 
   {{0x443184f9,0xd90c7380,0x69c00010,0x60c0058a}},	//   ydy_, نیو_, _vgne, _yimm, 
   {{0x245c09f3,0x68e00097,0x60c00429,0x38680076}},	//   _tími_, _vwnd, _ximm, ghcr_, 
   {{0x44300122,0x69c004cc,0xf77c0784,0xc794013d}},	//   vdy_, _tgne, naçh_, срны, 
   {{0x69c184fa,0x443184fb,0x86280023,0x75d00118}},	//   _ugne, wdy_, _ትምኒት, vězí, 
   {{0x44300209,0xf77c0784,0x37e400fe,0x00000000}},	//   tdy_, haçh_, _কাৰো_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x443184fc,0x64bc00b0,0x59040327,0x00000000}},	// [28c20] rdy_, _hōik, _མའོས_, --, 
   {{0x60c184fd,0x443184fe,0xb7d404fb,0x388c000f}},	//   _simm, sdy_, _پویا_, ręre_, 
   {{0x60c184ff,0x44300209,0x629c0306,0xb3e400eb}},	//   _pimm, pdy_, _vkro, _ফারজ, 
   {{0x60c18500,0xf41c0036,0x28cc00dc,0x629c012d}},	//   _qimm, _okäy_, _संनि, _wkro, 
   {{0x60c18501,0xbea4004e,0x00000000,0x00000000}},	//   _vimm, бадк, --, --, 
   {{0x4128090b,0x5be01b6e,0xa3d58502,0xe3b80220}},	//   _його_, नर्व, सुर_, _бұұ_, 
   {{0x60c18503,0xe7c8012c,0x00000000,0x00000000}},	//   _timm, रखाप, --, --, 
   {{0xcefc05d1,0xfca800f1,0xec64064e,0x00000000}},	//   üğün_, داتو_, йрык_, --, 
   {{0x40340220,0x9d080154,0x09d80011,0x00000000}},	//   _кеңс, লবেন_, _দয়া, --, 
   {{0x3e30121e,0x3e8405c6,0x1e640133,0xba4401c6}},	//   _رہبر, _اشرف, _بخرێ, схий, 
   {{0x6e91267b,0xf77c036e,0xb8641291,0xedd001f7}},	//   _علما, maçi_, ماحو, _ريند, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x25a400ac,0xac9440bb,0x19c401ec,0xab80011c}},	//   əmli_, _اننا_, _мәнг, _нушк, 
   {{0x64bc0053,0xae1802ab,0x245c0241,0x38b80171}},	//   _hōih, प्पन_, _mímu_, _mūri_, 
   {{0x64bc02b5,0x2804012c,0x81cc015b,0xaa8400f1}},	//   _kōih, ásné_, ররা_, _دنوم_, 
   {{0xd5d82871,0x985c0034,0x940404fb,0xa3d4146c}},	//   _ब्रज, _błąd_, توره, सुल_, 
   {{0xc3c001c0,0xb33800a2,0x00000000,0x00000000}},	// [28c30] дөрл, _byça, --, --, 
   {{0x31c58504,0x28cc07b7,0x00000000,0x00000000}},	//   ссав, _संमि, --, --, 
   {{0xb11002e3,0x50b804fb,0xf77c00a2,0x00000000}},	//   rụok, لگرد_, daçi_, --, 
   {{0x7e780227,0x397802d3,0x38b800ef,0x00000000}},	//   _amtp, _ኣንስቲ_, _būri_, --, 
   {{0xddc8007f,0x00000000,0x00000000,0x00000000}},	//   _modņ, --, --, --, 
   {{0xdce84ba9,0x82280327,0xf77c0200,0x00000000}},	//   _aydı, _ཤྲྭི_, gaçi_, --, 
   {{0xb7f8072a,0xde9400c6,0x6a7c01e1,0x8d7400d1}},	//   ्लाम_, أجنب, _láfè, غاتا, 
   {{0x5f758505,0x6ee0063f,0x28cc012c,0x60d83168}},	//   _کافر, _ọbur, _संबि, ívme, 
   {{0xd46c001f,0x200401d9,0x00000000,0x00000000}},	//   _ለወደፊ, _ژِہِ, --, --, 
   {{0x7e780998,0x64bc02b5,0x395c002d,0x00000000}},	//   _gmtp, _pōik, fyts_, --, 
   {{0x088801a9,0xb6980022,0xc9a80452,0x00000000}},	//   ибой_, guâm, рвне_, --, 
   {{0xac940133,0x00000000,0x00000000,0x00000000}},	//   _دۆعا_, --, --, --, 
   {{0x76540165,0xde8802e3,0x7a20063f,0x602002d2}},	//   _boxy, lịa_, ọtak, _hámæ, 
   {{0x64bc00b0,0x38a801ab,0x7ba001e0,0x245c02d2}},	//   _tōik, rùra_, _юҫыҡ, _límt_, 
   {{0xb6a001b9,0x25ac0fac,0x18780023,0xdee00092}},	//   фирл, ådl_, _ኣህጉር_, _ነፃና_, 
   {{0x765402d0,0xb3380432,0x54800023,0x00000000}},	//   _eoxy, _syça, _ከብርህ_, --, 
   {{0xde8805db,0x76558506,0xb338010b,0x2c1800cd}},	// [28c40] hịa_, _foxy, _pyça, भ्यं_, 
   {{0x38b80374,0xd140001f,0xb2200107,0x00000000}},	//   _rūri_, _የሚችል, ммул, --, 
   {{0x3618011a,0xf77c0200,0x38b800ef,0x00000000}},	//   _דויד, vaçi_, _sūri_, --, 
   {{0xdfd05706,0x1b20015b,0x7e798507,0x3de40154}},	//   ريت_, বিতে_, _smtp, _নাইল, 
   {{0x24800009,0x829000f7,0xa3d400dc,0x7afc00b8}},	//   miim_, _قۇرچ, सुः_, _āpto, 
   {{0x72c0169c,0x248044db,0xb3380166,0x245c032e}},	//   _обяз, liim_, _uyça, _vímu_, 
   {{0x7cc80165,0xf77ccae1,0xceac0166,0xf650011a}},	//   _kęri, raçi_, _җә_, וצג_, 
   {{0x22582e22,0x245c0030,0x38b80171,0xdcb00228}},	//   _hork_, _tímu_, _tūri_, رۉش_, 
   {{0x22598508,0x23600007,0x69cc0118,0x9a7801d5}},	//   _kork_, nyij_, ěcen, ййит_, 
   {{0x24803431,0xde8802e3,0x2258c609,0x50940124}},	//   hiim_, bịa_, _jork_, _дуӡӡ, 
   {{0x76558509,0x22582b6f,0x64bc00b0,0x248003d9}},	//   _roxy, _mork_, _tōih, kiim_, 
   {{0x24800009,0xdce80166,0xc1d801e1,0x3b640395}},	//   jiim_, _uydı, _ẹ̀fè, _мълв, 
   {{0x24806ed5,0x00000000,0x00000000,0x00000000}},	//   diim_, --, --, --, 
   {{0x225805f5,0x64bc04fe,0x1b2000cc,0x38c8011c}},	//   _nork_, _kōiw, বিদে_, _куин_, 
   {{0xe91400d4,0x00000000,0x00000000,0x00000000}},	//   _дощі_, --, --, --, 
   {{0xd1400092,0x00000000,0x00000000,0x00000000}},	//   _የሚቻል, --, --, --, 
   {{0x2259850a,0xde88063f,0x82f40327,0x23380150}},	// [28c50] _bork_, zịa_, _བྷཱུ_, опты_, 
   {{0x2259850b,0x7bc40205,0x00000000,0x00000000}},	//   _cork_, ıkuy, --, --, 
   {{0x9f4445a7,0xb11001f2,0x24800083,0x9c7c007f}},	//   _demí_, pụmk, biim_, _pwčl, 
   {{0x9f4404cc,0xa3d400af,0x2480e20a,0x69c4030a}},	//   _temì_, सुआ_, ciim_, ñjez, 
   {{0x2259850c,0x3ff1850d,0xf41c014a,0x78980521}},	//   _fork_, ركور, _ibä_, ụkwọ_, 
   {{0x2259850e,0x8d5402e8,0x26dc010f,0xdd0000de}},	//   _gork_, зтич, סקומ, _štāb, 
   {{0xe8c40867,0x28cc0b02,0x61140212,0x3d045ca7}},	//   _གཤེག, _संधि, _одру, सूले_, 
   {{0x9f44012c,0xde8805db,0xabc001e0,0xddc800bc}},	//   _zemí_, rịa_, майҙ, _modř, 
   {{0x2259850f,0xaca001f2,0x8d956f16,0xde8802e3}},	//   _york_, _nhụj, _کلاش, sịa_, 
   {{0x28cc4614,0x09045b8e,0x29c40228,0xde8801f2}},	//   _संदि, ппон, өтүү_, pịa_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xaca001f2,0xda1c5d4f,0x24800067,0x5d841291}},	//   _kwọl, ब्बत_, xiim_, _تلمل, 
   {{0xdd1001f1,0xd8740137,0x00000000,0x00000000}},	//   _výťa, بۅيت_, --, --, 
   {{0xc4c58510,0xbb380bd4,0xac940137,0x00000000}},	//   كترو, _לעני, _انچا_, --, 
   {{0xc1a8068f,0x55c4774d,0x044402bf,0xda644138}},	//   _करेग, дарғ, певн, _زاوي, 
   {{0x47342be7,0x78f80375,0x2258007c,0x9f4402d2}},	//   _فرخز, _הפקו, _sork_, _semí_, 
   {{0x24818511,0x778000a7,0x2258123b,0xaca001e1}},	// [28c60] riim_, _плъз, _pork_, _nwọl, 
   {{0x672400e4,0xb7780375,0x41b401f4,0xb380011c}},	//   _ipij, _לאפש, псет, хлул, 
   {{0xaca001e1,0x22580d27,0x24800037,0x3658011a}},	//   _awọl, _vork_, piim_, _הכינ, 
   {{0xf41c006a,0x22588a83,0x69c01b37,0x425424c5}},	//   _gbä_, _work_, _रणनी, _کنسر, 
   {{0xbea43bb3,0x22598512,0x9e348c91,0xf77c00d8}},	//   падк, _tork_, делч, baçu_, 
   {{0x67240170,0xdfd005d9,0xefb0006c,0x5ed80154}},	//   _mpij, ريڪ_, ریلگ, _সিআই, 
   {{0x7cf400ee,0x7c780240,0x00000000,0x00000000}},	//   dürý, _ክህልው_, --, --, 
   {{0x672405be,0x3f6834d8,0x20f88bdf,0x28cc000d}},	//   _opij, _либо_, mči_, _सूधि, 
   {{0x20f814b2,0x7b640220,0x1ab4f46f,0x00000000}},	//   lči_, ятке, мбия, --, 
   {{0x58d43580,0x64bc00b0,0xd8f800d4,0x3374011a}},	//   моот, _tōiw, оної_, פעים_, 
   {{0x672400f3,0xb6980311,0xc1a84142,0x1958005b}},	//   _apij, frân, _करोग, цаны_, 
   {{0xb69806ed,0xc1a8000d,0xef1c0139,0x00000000}},	//   grân, _करैग, _äüc_, --, 
   {{0xf1bc0030,0xeaac00f2,0x00000000,0x00000000}},	//   čšie_, ضعی_, --, --, 
   {{0x20f801fa,0xddc800bc,0x1dcc4ead,0x06d001ec}},	//   kči_, _podř, ाशित, _ﻛﻮﺷﻪ, 
   {{0x20f84b16,0x74698513,0xb6998514,0xe694009d}},	//   jči_, брав_, brân, хиры, 
   {{0xa3d4038e,0x38b802b1,0xb698054e,0x20f85752}},	//   सँग_, _pūru_, crân, dči_, 
   {{0x2458e99a,0xdebc044e,0x1dcc078a,0x00000000}},	// [28c70] чать_, ቶምን_, ाशात, --, 
   {{0x61fc02fa,0x7d080b4b,0x00000000,0x00000000}},	//   _cdrl, kufs, --, --, 
   {{0x38b802b1,0xde8801f2,0xc0c80023,0x00000000}},	//   _wūru_, tịn_, _ኽብል_, --, 
   {{0x38b804fe,0xee3c00a2,0x00000000,0x00000000}},	//   _tūru_, _şý_, --, --, 
   {{0x67f800dd,0xde8801f2,0xc0cc02d3,0x3578001f}},	//   lújí, rịn_, _ብገለ_, _ባሉበት_, 
   {{0x9f4400f7,0xddc805be,0x7d08022f,0xb62c00b5}},	//   _demà_, _emdž, fufs, _ｓｐ_, 
   {{0xa19401c0,0xde88063f,0xa3d417e6,0xfe0c0d2c}},	//   _зарч, mịl_, सुक_, _सारस_, 
   {{0x0b458515,0x69c00034,0x601802e8,0x9d800023}},	//   днин, _रणबी, _нося_, _ክንጽሊ_, 
   {{0x28cc07d0,0xa0c400c6,0x7d080112,0xb6980356}},	//   _संहि, _سيكو, aufs, vrân, 
   {{0xc9640024,0x8964447e,0x00000000,0x00000000}},	//   двой, дкож, --, --, 
   {{0x67258516,0x2d0405f5,0x6f080028,0x64bc02b5}},	//   _spij, _хязг, lugc, _kōit, 
   {{0x06e011ba,0xddd816a3,0xdd94009d,0x00000000}},	//   _বিবি, mivš, _яахы, --, 
   {{0x28cc0d2b,0xb6980120,0xddd805a1,0x00000000}},	//   _संवि, rrân, livš, --, 
   {{0x67240219,0xf41c0254,0x090401a9,0x00000000}},	//   _vpij, _mjäu_, _жпкн, --, 
   {{0xddd807f5,0x8458c051,0x2c8001e1,0xfa5483eb}},	//   nivš, орат_, _gèdè_, _ترنگ, 
   {{0x6f082747,0x20f809a8,0xa304010b,0x9c840118}},	//   kugc, vči_, нүме, _tučň, 
   {{0x60dc1a48,0x672405ce,0x430805d9,0xd7a447b8}},	// [28c80] _strm, _upij, تيءَ_, _गुपच, 
   {{0x9f4403c6,0xb3380240,0xa3486518,0x20f81155}},	//   _nemá_, _kyçj, озға_, tči_, 
   {{0x81447b6d,0x20f896c0,0xddd8110c,0x61fc0010}},	//   بنان, uči_, jivš, _vdrl, 
   {{0x7f8487ad,0xddd81a48,0x00000000,0x00000000}},	//   ولان, divš, --, --, 
   {{0x44218517,0xed4c0133,0x06e0015b,0xd24c4451}},	//   _ibk_, یپه_, _বিডি, _گۆل_, 
   {{0x44218518,0x7d08007c,0xdb2402d2,0x00000000}},	//   _hbk_, tufs, _ósér, --, 
   {{0xd24c01d9,0xe3b000cc,0x9f4400d7,0x00000000}},	//   _دۆل_, _কলিব, _demá_, --, 
   {{0x7d080730,0x6f0800aa,0x44200036,0xff2401b9}},	//   rufs, bugc, _jbk_, _омбо, 
   {{0x6f080af2,0x9ab400b8,0x7d080cf4,0x5ed803d4}},	//   cugc, _asāṃ, sufs, _ঠিকে, 
   {{0x5a340801,0xddd807f5,0x2c800ca8,0x8e7402e8}},	//   хнот, bivš, _pèdè_, _пухч, 
   {{0xbd898519,0xddd80fcf,0x4420017a,0xbb4801d9}},	//   _بنان_, civš, _obk_, _ڈلان_, 
   {{0xbb482df0,0xfe0c032c,0x7cc8000f,0xb338010e}},	//   _ولان_, _साँस_, _dęrt, _syçm, 
   {{0x7c21851a,0x8228031c,0x75e00116,0x00000000}},	//   _ibor, _ཤྲྰི_, кәнҗ, --, 
   {{0x4420e9e8,0x199402d5,0x00000000,0x00000000}},	//   _abk_, _паля, --, --, 
   {{0xe5043306,0x4421851b,0xaa900395,0x00000000}},	//   َبِي, _bbk_, _шишч, --, 
   {{0x442000ef,0xb865851c,0x00000000,0x00000000}},	//   _cbk_, _زابو, --, --, 
   {{0x7c200588,0xfe0c130b,0xddc8033f,0xddd816a3}},	// [28c90] _mbor, _सांस_, _podś, zivš, 
   {{0xf64400c7,0x442001c4,0xe3b000c6,0x8c3d685b}},	//   _цхин, _ebk_, شرق_, moşe, 
   {{0x7c21851d,0x4421597d,0x64bc02b5,0x6f086580}},	//   _obor, _fbk_, _pōit, wugc, 
   {{0xddd805ce,0x5f00007d,0x442006d1,0xde88063f}},	//   vivš, _रिश्_, _gbk_, sịl_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xddd805ce,0x4420009d,0x00000000,0x00000000}},	//   tivš, _zbk_, --, --, 
   {{0x7c20005a,0x20240086,0x64bc00b0,0x4c683edb}},	//   _bbor, üriò_, _tōit, зийн_, 
   {{0xddd807f5,0xb698045f,0x00000000,0x00000000}},	//   rivš, wrâl, --, --, 
   {{0x64bc02b1,0xa3d40316,0xddd807f5,0x00000000}},	//   _kōir, सुट_, sivš, --, 
   {{0xc3300bd4,0x7c21851e,0xddd80e3c,0xae1825c9}},	//   נוי_, _ebor, pivš, प्शन_, 
   {{0x89a807d8,0x0d200228,0x64bc00b0,0x00000000}},	//   яков_, _сүйү, _mōir, --, 
   {{0xf2dc006a,0x7c200ca8,0x00000000,0x00000000}},	//   _otâ_, _gbor, --, --, 
   {{0xf2dc07a8,0x442000d4,0x7cc8002d,0xb82000a2}},	//   _ntâ_, _rbk_, _węrt, _şåýl, 
   {{0x4421851f,0x7c218520,0xf3fc003e,0x2c1807b7}},	//   _sbk_, _zbor, _adã_, भ्रं_, 
   {{0xf2dd8521,0xaca0063f,0xe8180316,0x44203d4f}},	//   _atâ_, _ebụm, _थापा_, _pbk_, 
   {{0x7c3c013f,0x7c2001d5,0x4e080037,0x00000000}},	//   _ɔpro, _xbor, _साढ़े_, --, 
   {{0xf4845ec2,0xdbcc01e1,0x8c3c0356,0xc2440124}},	// [28ca0] رافی, _kóòk, coşe, ннак, 
   {{0x64bc01ab,0xa3cc05f9,0x44200210,0x00000000}},	//   _cōir, _ललक_, _wbk_, --, 
   {{0x44200263,0x00000000,0x00000000,0x00000000}},	//   _tbk_, --, --, --, 
   {{0x798c0086,0xdbcc01e1,0x00000000,0x00000000}},	//   ûbwi, _lóòk, --, --, 
   {{0xe8181533,0x9f34eeec,0x8fd401e0,0xa2c401af}},	//   _थाना_, телі, тәсә, _аҙак, 
   {{0x7c218522,0x3de400fe,0x00000000,0x00000000}},	//   _sbor, _নাঙল, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x50b4152d,0x1f8401e0,0xd1e40023,0xad2000db}},	//   _асуу, _иҫен, _ዝስተ_, اىيى, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa0a40075,0xef80b971,0x6b700022,0x8fb401af}},	//   _чағд, _слуп, ульу, _рљсљ, 
   {{0x7c20010a,0x199401fe,0x00000000,0x00000000}},	//   _tbor, таня, --, --, 
   {{0x7c218523,0x7d1806be,0x8c3d679c,0x00000000}},	//   _ubor, _iqts, toşe, --, 
   {{0x3db000fe,0x177c02d3,0xeaf4007b,0x37a80107}},	//   _চলিল, _ኣስዒቡ_, _كروت_, ятон_, 
   {{0x6288007f,0xed840023,0x12c80150,0x00000000}},	//   _ňdon, _ንሕብር_, _ﺒﺎﻫﺭ, --, 
   {{0x65958524,0xdee40046,0x2bd4076e,0x25e0023e}},	//   гару, _گۋ_, णुका, कड़ी_, 
   {{0x95c802dd,0x644003b2,0x3db000cc,0x00000000}},	//   зуға_, _ómil, _চলাল, --, 
   {{0xf8bd8525,0xb3380200,0x92680014,0x00000000}},	// [28cb0] mmé_, _kyçi, وٝرٕ_, --, 
   {{0xf8bd8526,0xf41d6766,0x00000000,0x00000000}},	//   lmé_, _pjäs_, --, --, 
   {{0xe2c8009a,0x00000000,0x00000000,0x00000000}},	//   رومو_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x15e405f9,0x64bc02b5,0x7d180139,0x3dc8016b}},	//   _कभार_, _tōir, _aqts, ɛhwɛ_, 
   {{0x6b64398f,0x00000000,0x00000000,0x00000000}},	//   _légú, --, --, --, 
   {{0x64bc00b0,0xf8bc0306,0x1fa42cc8,0x14b40073}},	//   _kōip, kmé_, крәг, ंतपण, 
   {{0x06e0015b,0x9d441370,0xf8bc0216,0xb3380790}},	//   _বিসি, ائون, jmé_, _ayçi, 
   {{0x5f95783d,0x4a7400a8,0xf8bc0118,0xd15c0092}},	//   _битт, вынт, dmé_, _ለሚበል, 
   {{0x7eb400e4,0xdee400d8,0x00000000,0x00000000}},	//   tâpe, _соѕи, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x5c14143e,0x7afc0055,0x2be800cc,0x00000000}},	//   _مظهر, _āptv, _টাকৈ_, --, 
   {{0x9f440295,0x69c01f14,0x2cbd8527,0xeff401f3}},	//   _gemä_, _रणवी, mmud_, _ላንድ_, 
   {{0x2cbd8528,0x6b640ca8,0x00000000,0x00000000}},	//   lmud_, _eégú, --, --, 
   {{0x48b4023a,0xf9f4082e,0x9598004e,0x00000000}},	//   _ищит, _شفيع_, етту_, --, 
   {{0xde8801f2,0x00000000,0x00000000,0x00000000}},	//   tịk_, --, --, --, 
   {{0x4dac03d4,0x82a401c6,0x2cbc000d,0xc0280092}},	// [28cc0] _চলোৱ, вааж, imud_, _ሰምቻለ, 
   {{0x2cbd8529,0x23280b01,0x056401f0,0x00000000}},	//   hmud_, моғи_, _авон, --, 
   {{0x6f180309,0xf48401ed,0xc0a800c6,0x84e40150}},	//   _aquc, راہی, واصل_, _шонж, 
   {{0xc4080014,0xb9c80023,0x44fc0153,0x00000000}},	//   _کتھٕ_, _ደዉ_, mį_, --, 
   {{0x44fc0953,0xaf30027d,0xd6a800f2,0x00000000}},	//   lį_, لروت, _زدیم_, --, 
   {{0xdd9577b6,0x72d00131,0x2c1c00fe,0x4f9400c7}},	//   лалы, _ئەلچ, _মোলৈ_, ырху, 
   {{0x44fc0953,0xda18069f,0x00000000,0x00000000}},	//   nį_, _दाबत_, --, --, 
   {{0x66e80139,0x00000000,0x00000000,0x00000000}},	//   _xөkü, --, --, --, 
   {{0xa2b8215d,0xef14009b,0x6c500022,0xcf2401c8}},	//   ्गप्, _имт_, ркыу, _مرلي, 
   {{0x44fc0006,0x7bc4022e,0x29000327,0x00000000}},	//   kį_, оkur, ġjan_, --, 
   {{0x7afc00b8,0x44fc00c0,0x00000000,0x00000000}},	//   _āptu, jį_, --, --, 
   {{0xdbcc0579,0x3b85852a,0x44fc0024,0x7f8401d5}},	//   _góðk, _илег, dį_, _tаqd, 
   {{0xf8bd852b,0x7f41852c,0x987800e4,0x00000000}},	//   rmé_, nvoq, néĩ_, --, 
   {{0xb7e00cf1,0x7ae1852d,0x7f41852e,0x213801a6}},	//   _क्रम_, _itot, ivoq, _osrh_, 
   {{0xf8bc0109,0x44fc0153,0x00000000,0x00000000}},	//   pmé_, gį_, --, --, 
   {{0x06e00154,0xc6e000cc,0x00000000,0x00000000}},	//   _বিরি, _বিৰচ, --, --, 
   {{0xa3d46ff7,0xe2f81ac3,0xaee000b8,0x9294009d}},	// [28cd0] роуч, кеті_, _paṭo, гаац, 
   {{0x7ae005d9,0x44fc00c0,0x00000000,0x00000000}},	//   _mtot, bį_, --, --, 
   {{0x6234030d,0x00000000,0x00000000,0x00000000}},	//   реху, --, --, --, 
   {{0x7ae00428,0x84c00022,0x0f740022,0x2cbd852f}},	//   _otot, _гәуд, ллеџ, xmud_, 
   {{0x8fd00184,0x7ae14e83,0x9ac40135,0xb9c8001f}},	//   _һәлә, _ntot, _kaċċ, _ደጉ_, 
   {{0x9ac40135,0x3cfc0208,0xdeb4064e,0x00000000}},	//   _jaċċ, _bvtv_, абчы, --, 
   {{0x7ae18530,0xc2100302,0x8fd00032,0x2cbc0098}},	//   _atot, _להם_, _ләлә, tmud_, 
   {{0x9ac40327,0x6044074d,0x64480064,0x06d002dd}},	//   _laċċ, _кхуз, _ėdik, _ﻛﻮﺑﻪ, 
   {{0x89f43334,0x9f340046,0x6f180309,0x2cbd8531}},	//   лянц, _кеті, _uquc, rmud_, 
   {{0x9ac40135,0x06e00011,0x00000000,0x00000000}},	//   _naċċ, _বিলি, --, --, 
   {{0xe73c0ab7,0x7ae18532,0xed301a90,0xdd9401ee}},	//   _küçü, _etot, _خواھ, _кафы, 
   {{0x8c3c00b5,0x00000000,0x00000000,0x00000000}},	//   boşa, --, --, --, 
   {{0x9ac40327,0xb3380240,0x8c3c0356,0x7bc40153}},	//   _baċċ, _kyçu, coşa, žkur, 
   {{0x44fc0006,0x03a40107,0x6d4003b2,0xaa6404c2}},	//   tį_, ҳибо, ovna, _штек, 
   {{0xd938064e,0x6d4002e2,0x062401d3,0x7ae0013a}},	//   _ачыш_, nvna, نےکی_, _ztot, 
   {{0x44fc02d5,0x03a44965,0xb5c40014,0x7ae002d0}},	//   rį_, гибо, اوِم_, _ytot, 
   {{0x42258533,0x9ac40135,0x44fc0006,0x27e001e1}},	// [28ce0] лдав, _faċċ, sį_, _ifin_, 
   {{0x44fc0006,0xf770011a,0x7e9800e2,0x00000000}},	//   pį_, _לקח_, _kāpņ, --, 
   {{0xf3fc00d8,0x361800df,0x00000000,0x00000000}},	//   _clãs_, _אויד, --, --, 
   {{0x7bdc013f,0x3fd00154,0x00000000,0x00000000}},	//   _ɑpus, ার্ষ, --, --, 
   {{0x44318534,0xe73c06be,0x14b400df,0xaff442f4}},	//   mey_, _düçü, _כּשר_, افها_, 
   {{0x4430b0ec,0xaee00055,0x7f418535,0xdd9400fb}},	//   ley_, _saṣo, rvoq, һаһы, 
   {{0x2d400139,0x2fdc03cb,0x28cc4a01,0x443000ad}},	//   _cıe_, _ffug_, _संगि, oey_, 
   {{0xdd94052f,0x44318536,0x8c3c0276,0x2d400205}},	//   лаһы, ney_, toşa, _dıe_, 
   {{0x9b9400a8,0x44318537,0xeb94026a,0x68e00139}},	//   рипц, iey_, лић_, _atnd, 
   {{0x44318538,0x27e00231,0x20045497,0x8c3c054e}},	//   hey_, _afin_, _hdmi_, roşa, 
   {{0xdc5433f5,0x6da0022e,0x62980118,0x98b80120}},	//   _پراک, _лифа, čvoh, клот_, 
   {{0x443003a5,0x7ae0005a,0x00000000,0x00000000}},	//   jey_, _ttot, --, --, 
   {{0x44318539,0x68e000d2,0x7ae04180,0x27e14e8c}},	//   dey_, _etnd, _utot, _dfin_, 
   {{0xf2dd853a,0x27e1853b,0x4431853c,0x00000000}},	//   _brân_, _efin_, eey_, --, 
   {{0x4431853d,0x27e00368,0x9ac4025c,0x00000000}},	//   fey_, _ffin_, _vaċċ, --, 
   {{0x4431853e,0x00000000,0x00000000,0x00000000}},	//   gey_, --, --, --, 
   {{0xf77002e1,0xe3b000c6,0x9ac40135,0x8cc400dc}},	// [28cf0] _داغ_, كرك_, _taċċ, ागतो, 
   {{0xf2dc0042,0x27e00327,0xc1d80241,0x6d40007c}},	//   _frân_, _zfin_, _ẹ̀lè, yvna, 
   {{0xd131853f,0x4fd41d5b,0x44318540,0x00000000}},	//   تما_, ажет, bey_, --, 
   {{0x44318541,0xfafc00e2,0xb33800a2,0x00000000}},	//   cey_, _ķīna_, _syçu, --, 
   {{0x8fa4147e,0x8e540212,0x2d400139,0xde880051}},	//   јале, иткі, _sıe_, hịu_, 
   {{0x8d648046,0x2004662e,0x26dc00c8,0x00000000}},	//   ивле, _edmi_, עקומ, --, 
   {{0x73f40154,0x6e200175,0xe81800bc,0x00000000}},	//   ইলীয়_, rfnb, थलमा_, --, 
   {{0xf0b82c10,0x6d4117b7,0x290000d7,0x00000000}},	//   _سازش_, rvna, ájam_, --, 
   {{0x2aa8005c,0x8fd001af,0x00000000,0x00000000}},	//   købt_, _ләһә, --, --, 
   {{0x44318542,0xe8180316,0xca84519b,0x27e00356}},	//   zey_, _थाहा_, ргой, _sfin_, 
   {{0x44300d62,0x2aa801bf,0xa2b800cd,0x00000000}},	//   yey_, døbt_, ्गत्, --, 
   {{0x44308531,0x7648016b,0x17a40092,0x9f4401e1}},	//   xey_, _ɔgye, _ለሕዝቡ_, _remú_, 
   {{0x44318543,0x4a74023a,0x9f4401e1,0x00000000}},	//   vey_, _выйт, _semú_, --, 
   {{0x44318544,0x09e45b7f,0x08d400fb,0x3b04030d}},	//   wey_, _токн, _кция, _тешо_, 
   {{0x44318545,0xd3c404a9,0x00000000,0x00000000}},	//   tey_, ەتلى, --, --, 
   {{0xaa400075,0x27e00fac,0x44300076,0x657c002f}},	//   _ئۆگى, _ufin_, uey_, rzrh, 
   {{0x44318546,0x75880020,0xf6747b16,0xc0e402d3}},	// [28d00] rey_, _አድርጎ_, _چاپخ, _ዝብላ_, 
   {{0x44318547,0xf2dc001e,0xbf64129e,0xf6741291}},	//   sey_, _trân_, یدشو, _ناپخ, 
   {{0x44318548,0xf41c013d,0x2aa8005c,0xd10c01f9}},	//   pey_, _imän_, løbs_, ांगण_, 
   {{0x03a400d6,0x04448148,0xa49407d6,0x44318549}},	//   _вимо, _темн, _ایرت, qey_, 
   {{0xc35402e8,0xdcb01183,0xd3b8003b,0x00000000}},	//   _тънъ, ۋىت_, _бурі_, --, 
   {{0x52740022,0x1af40154,0xf4000327,0x00000000}},	//   _лусу, _আমলে_, _མཇོད_, --, 
   {{0xc0e4044e,0x80c40073,0x1d34013e,0x1b20009e}},	//   _ዝብሉ_, िषदे, ёния, বিছে_, 
   {{0x9c7c0100,0x31640e78,0x9c38005b,0xec6400c7}},	//   _etčn, änze_, упит_, ирык_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb9c401b9,0xdbdc0419,0x00000000,0x00000000}},	//   иёни, mšík, --, --, 
   {{0x6e9001d9,0xc3200f22,0x00000000,0x00000000}},	//   _ظلما, নিটি_, --, --, 
   {{0xf400031c,0x245c00d0,0xda18012d,0x00000000}},	//   _མཇེད_, _tímy_, _दावत_, --, 
   {{0x62800953,0xab80f514,0x6c780a1e,0x2aa8005c}},	//   _įmon, _мушк, _בראד, tøbt_, 
   {{0x8c3c010e,0x06d400eb,0x00000000,0x00000000}},	//   hoşl, _তৌহি, --, --, 
   {{0xa5f8107a,0x28d01cb7,0xe93400c6,0xae180141}},	//   ресу_, _संचि, _نسيت_, प्टन_, 
   {{0xb864254e,0xc0e4044e,0x57f40063,0x9f4401bf}},	//   _خاتو, _ዝብሎ_, _упит, _femø_, 
   {{0xb4b405f9,0x75e00075,0xb2b40131,0x7af400a2}},	// [28d10] _छठी_, _мәвҗ, иңму_, _çytd, 
   {{0xfafc0171,0x00000000,0x00000000,0x00000000}},	//   _ķīla_, --, --, --, 
   {{0xc0e4067d,0xc5f00302,0xf7702832,0x3164054e}},	//   _ዝብል_, _מדי_, _داں_, ânz_, 
   {{0x90981e76,0x1ea800f1,0x00000000,0x00000000}},	//   ывет_, یاوي_, --, --, 
   {{0xb4b006ab,0x28c8c853,0xc5ec004b,0x28d0912c}},	//   टती_, रगति, _زړۀ_, _संघि, 
   {{0x14b40574,0xccc40131,0x1e8400d4,0x00000000}},	//   ंतवण, әбий, олім, --, 
   {{0x6040063f,0xa159854a,0xa1942e26,0xf1c000cd}},	//   _ịmef, _кару_, _дарч, वेशन, 
   {{0x705004d3,0x5fa8000d,0x00000000,0x00000000}},	//   _گۆڤا, _छुवल, --, --, 
   {{0x4aa9854b,0x89d402dd,0xca8401c6,0x00000000}},	//   лкин_, йінш, йгий, --, 
   {{0xeb946287,0xca540063,0x644000e4,0x5f7406c2}},	//   лиқ_, стињ, _ómiv, _بافر, 
   {{0x8c181b45,0x88c8023a,0x487433ae,0xda640b6c}},	//   _ميار_, ллов_, مدحس, تايي, 
   {{0x8d740133,0x38b80064,0xb7e01116,0x00000000}},	//   _پاڕا, _kūry_, कुलम_, --, 
   {{0x20f000ee,0x8afc0118,0x2bc800f3,0x00000000}},	//   _işiň_, kyři, _ружо_, --, 
   {{0x3ebc0208,0xda3400c0,0xf77c010e,0x00000000}},	//   _xhtt_, _мечы, naçy_, --, 
   {{0xa2b800dc,0x09c4015b,0x00000000,0x00000000}},	//   ्गस्, _শ্রা, --, --, 
   {{0x47580801,0x28d01a47,0x00000000,0x00000000}},	//   _броя_, _सूचि, --, --, 
   {{0x0205854c,0xb338010e,0xf77c010e,0x00000000}},	// [28d20] йзан, _syçr, kaçy_, --, 
   {{0xa6540133,0x00000000,0x00000000,0x00000000}},	//   _بێست, --, --, --, 
   {{0x64ad854d,0x3ebc0076,0x00000000,0x00000000}},	//   ußis, _rhtt_, --, --, 
   {{0x3ebc0208,0x14340023,0x77000244,0x00000000}},	//   _shtt_, ርበልኩ, _بژێن, --, 
   {{0xefcc044e,0xbe880114,0x98bc0064,0x8c3c0205}},	//   _ኣቦይ_, лске_, _urvą_, roşl, 
   {{0x6445854e,0x6fb0007b,0x00000000,0x00000000}},	//   ldii, أمها, --, --, 
   {{0x629c07d6,0x64440014,0x7164084c,0x3ebc004d}},	//   _ijro, odii, _ларг_, _vhtt_, 
   {{0x6445854f,0x00000000,0x00000000,0x00000000}},	//   ndii, --, --, --, 
   {{0x3ebd8550,0x00000000,0x00000000,0x00000000}},	//   _thtt_, --, --, --, 
   {{0x64445604,0xad200116,0x00000000,0x00000000}},	//   hdii, زىۋى, --, --, 
   {{0xc0640055,0x00000000,0x00000000,0x00000000}},	//   _ṛṇa_, --, --, --, 
   {{0x2db4008f,0xb4b409bb,0x00000000,0x00000000}},	//   _פלאן_, _छठे_, --, --, 
   {{0x64458551,0xfaa58552,0x60c00477,0x629c3012}},	//   ddii, _ладо, _mhmm, _ojro, 
   {{0xeb04007b,0x64458553,0x999801d3,0x00000000}},	//   _اقوى_, edii, űrű_, --, 
   {{0x77904a23,0xe5c40801,0xf8e40066,0x00000000}},	//   تیکا, зсто, _استپ, --, 
   {{0xb4b00574,0x64441c06,0x629c0023,0xda189e51}},	//   टते_, gdii, _ajro, _दाँत_, 
   {{0xf2dc01fb,0xa8180137,0xb8644715,0x00000000}},	// [28d30] _trâm_, _اتىر_, _ناکو, --, 
   {{0x60c18554,0x64449f02,0xdd000118,0xca2c00d1}},	//   _ahmm, adii, átěn, ﻧﻐﺎ_, 
   {{0x629c020c,0x6444011f,0x5558487f,0x00000000}},	//   _djro, bdii, _таня_, --, 
   {{0xdd00038e,0x64440067,0x00000000,0x00000000}},	//   štěn, cdii, --, --, 
   {{0xd34001ed,0xda18121d,0xe0d0216b,0x00000000}},	//   _تہذی, _दांत_, رزم_, --, 
   {{0x59c82977,0x60c139fd,0x2c1806e3,0x5c0800cc}},	//   रधार, _ehmm, _याहू_, লভোগ_, 
   {{0x7f84022e,0x00000000,0x00000000,0x00000000}},	//   _hаql, --, --, --, 
   {{0xe0e401d5,0x00000000,0x00000000,0x00000000}},	//   _хўро, --, --, --, 
   {{0xed54006c,0xfbcc00ec,0x66c00847,0x00000000}},	//   роқ_, نڪه_, löke, --, 
   {{0x09058555,0x776c0175,0x00000000,0x00000000}},	//   опон, dycx, --, --, 
   {{0x64440a81,0x8d942586,0x290004fb,0x00000000}},	//   ydii, _بلاش, éja_, --, 
   {{0x29098556,0x1cb80135,0x644401d9,0xb4b00490}},	//   čca_, _ཚེར_, xdii, टतो_, 
   {{0x87b80276,0x64440200,0x00000000,0x00000000}},	//   рунт_, vdii, --, --, 
   {{0x896401d9,0x6444058a,0x66c18557,0x4df800df}},	//   _وُشن, wdii, köke, יפֿא, 
   {{0x64440083,0x39100137,0x044401d5,0x00000000}},	//   tdii, _قووز, оевн, --, 
   {{0x629c0066,0x64446a83,0xefe80023,0x7b00013d}},	//   _sjro, udii, ቆላዊ_, _äxtä, 
   {{0x64458558,0xa2b80b98,0xfbdc00cd,0x43740798}},	// [28d40] rdii, ्गल्, फुटम, цувт, 
   {{0x272429ef,0x7cc8000f,0x41b50e28,0xc174cd07}},	//   mön_, _dęry, осет, يدات, 
   {{0x27258559,0x06e00eac,0xa4941056,0x00000000}},	//   lön_, _বিটি, _فیست, --, 
   {{0x2a641529,0xf3fc01fb,0x60c001a9,0x6724036e}},	//   _lonb_, _hoãn_, _qhmm, _kqij, 
   {{0x2725855a,0xf04400dd,0x00000000,0x00000000}},	//   nön_, تعلی, --, --, 
   {{0x2a6402e2,0xf770011a,0x8234216b,0x425401f7}},	//   _nonb_, וקד_, _برحا, _بنسر, 
   {{0x27256677,0x61fc7bee,0x2cac010a,0x6a7c017a}},	//   hön_, _ierl, _bkgd_, _kêff, 
   {{0x2724420d,0x60c01c06,0x69c002db,0x00000000}},	//   kön_, _uhmm, _रणजी, --, 
   {{0x61fd855b,0x60dd855c,0x2a648d29,0x2725855d}},	//   _kerl, _hurm, _bonb_, jön_, 
   {{0x2724420d,0x60dd855e,0x61fc84d6,0xf1ac00ab}},	//   dön_, _kurm, _jerl, _जुडन, 
   {{0x60dd0fb2,0xb2b808a8,0x00000000,0x00000000}},	//   _jurm, שמיר, --, --, 
   {{0x61fc23ee,0x67240003,0x26dc041a,0x27242045}},	//   _lerl, _bqij, _čvor_, fön_, 
   {{0x61fc0225,0x272429ef,0x60dc444e,0x00000000}},	//   _oerl, gön_, _lurm, --, 
   {{0x61fd855f,0xfaa40451,0x60dc58b4,0xf98850d8}},	//   _nerl, _گهڙي_, _ourm, _پخته_, 
   {{0x60dd8560,0x9f44011f,0xf3fc004d,0x7f8401a9}},	//   _nurm, _kemó_, _doãn_, _sаql, 
   {{0x1cb86d7e,0xe598005e,0x61fd8561,0x272429ef}},	//   _ཚེས_, ікті_, _aerl, bön_, 
   {{0x4614006c,0x6d440174,0x00000000,0x00000000}},	// [28d50] _کوپر, _ájav, --, --, 
   {{0x9f458562,0xe1f001b9,0x00bc08b0,0x394c003b}},	//   _demü_, نسم_, ﺭﯨﺸﺘ, _krfs_, 
   {{0x60dd8563,0x61fd8564,0xd01006f6,0x7cc8002d}},	//   _curm, _derl, فلا_, _węry, 
   {{0x60dd8565,0x61fc0e29,0x7e798566,0xdbdc0306}},	//   _durm, _eerl, _altp, yšák, 
   {{0x61fd8567,0x66c184e3,0x9f400008,0xcf90028e}},	//   _ferl, söke, úið_, رژر_, 
   {{0x60dd8568,0xdce806be,0x8c3c054e,0x394c045a}},	//   _furm, _axdı, moşi, _orfs_, 
   {{0x60dd8569,0xf3fd856a,0xe5f80375,0x76440076}},	//   _gurm, _joão_, חזור_, idjy, 
   {{0x61fd856b,0x27248573,0x2a640100,0x06e000cc}},	//   _zerl, yön_, _sonb_, _বিঘি, 
   {{0x61fcd0f5,0x5f9410f5,0x60dc8bea,0x2724007c}},	//   _yerl, _житт, _zurm, xön_, 
   {{0x272429ef,0x60dc4455,0x62800024,0x787c0240}},	//   vön_, _yurm, _įmok, _lëvd, 
   {{0x60dd856c,0x3db0009e,0xedec0022,0x00000000}},	//   _xurm, টেবল, _уаaн_, --, 
   {{0x2725856d,0xf2dc0124,0x07a5856e,0xc7a40aac}},	//   tön_, _erâi_, замн, зимк, 
   {{0x2a64007f,0xb698d4dd,0xb8842507,0xcbc8009f}},	//   _tonb_, rsân, _sníð, _اِشو_, 
   {{0x2725856f,0x2b4c01fa,0xbb40764a,0xb698045f}},	//   rön_, _irgc_, _чешк, ssân, 
   {{0xb6a18570,0x27258571,0x2eec0208,0x00000000}},	//   хирл, sön_, hpgf_, --, 
   {{0x61fd8572,0x2724014a,0x60dc016d,0x76440076}},	//   _serl, pön_, _rurm, adjy, 
   {{0x61fd8573,0x60dd8574,0x941c0574,0x6724031c}},	// [28d60] _perl, _surm, _फारच_, _uqij, 
   {{0x60dd8575,0x61fc0194,0x2e2c05d1,0x2b10012c}},	//   _purm, _qerl, nıfı_, _दिनु_, 
   {{0x61fce7d2,0x60dd8576,0xb5f40375,0x00000000}},	//   _verl, _qurm, _מציג_, --, 
   {{0x60dd8577,0x7e78003e,0xa03400cf,0xbfc40150}},	//   _vurm, _sltp, بۉرت, пбек, 
   {{0x61fd8578,0xd36c04a9,0x60dd8579,0x8c3c0356}},	//   _terl, _پۇل_, _wurm, coşi, 
   {{0x60dc53ee,0x29040e3c,0x442001f4,0x00000000}},	//   _turm, _ovna_, _hck_, --, 
   {{0x2b4c0175,0x44200790,0xdb2403b2,0x00000000}},	//   _argc_, _kck_, _ósúr, --, 
   {{0x2480309c,0x628c16a3,0xb19808d8,0x00000000}},	//   nhim_, žnoć, _הילכ, --, 
   {{0x9ab40055,0x44200332,0xda7001d9,0x00000000}},	//   _apāṃ, _mck_, ہُک_, --, 
   {{0x3a0400dd,0x0e680fb4,0xf1c00764,0x787c036e}},	//   سکتی_, _وصلي_, वेकन, _mëve, 
   {{0x4421857a,0x248030b5,0xda7001d9,0xfd1000e5}},	//   _ock_, khim_, فُک_, _سجا_, 
   {{0x387800d8,0x9c7c00d7,0xe27001ec,0x00000000}},	//   _qlqr_, _otči, _ﺴﻠﻴﻡ_, --, 
   {{0x2481857b,0x2904cade,0x3b04013c,0x7c21857c}},	//   dhim_, _evna_, _uvoq_, _icor, 
   {{0x4421857d,0x395c0bc9,0x3eac0200,0x7bc8031c}},	//   _ack_, pxts_, noft_, ħmuġ, 
   {{0x764404ce,0xa2c0b500,0x44206f7b,0xc0c00092}},	//   rdjy, वतन्, _bck_, ትሮስ_, 
   {{0x44200363,0xa8a402d5,0x3eac3c56,0x5f3c001f}},	//   _cck_, _прык, hoft_, _በግንቦ, 
   {{0xd1bc1b49,0x442004e6,0x3eac68a1,0x00000000}},	// [28d70] ሳይት_, _dck_, koft_, --, 
   {{0x4421857e,0x78acd514,0x8c3d857f,0xa2b40022}},	//   _eck_, locv, roşi, ебуч, 
   {{0x7c218580,0x442004ce,0xd5c005d7,0x3eac007c}},	//   _ocor, _fck_, _एरिज, doft_, 
   {{0x7c201446,0x9f440100,0x98bc0118,0xfe6c1888}},	//   _ncor, _remò_, _osvč_, یگل_, 
   {{0x28e002dd,0x66c00108,0x9f0401e2,0x2e2c0205}},	//   _ﺍﻟﺤﺠ, löka, فونو, yıfı_, 
   {{0x4420003e,0xd1f80092,0x78ac0051,0xda180037}},	//   _zck_, ገቦች_, hocv, _दागत_, 
   {{0x787c02d3,0x00000000,0x00000000,0x00000000}},	//   _zëve, --, --, --, 
   {{0xf2dc025a,0x0ae8036b,0x14ac05c0,0x00000000}},	//   _kuâ_, одий_, चविण, --, 
   {{0xaca002e3,0x7c2001ab,0x0a380024,0xddd4009b}},	//   _nkụj, _dcor, очны_, čaši, 
   {{0x7c218581,0xf3fc0004,0x3eac0204,0x24800023}},	//   _ecor, _leã_, coft_, zhim_, 
   {{0xddc800bc,0x89a98582,0x00000000,0x00000000}},	//   _ondř, юков_, --, --, 
   {{0x7c20007b,0x2480bd71,0x00000000,0x00000000}},	//   _gcor, xhim_, --, --, 
   {{0x2b4c05d5,0x87d403af,0x00000000,0x00000000}},	//   _urgc_, بغدا, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x44218583,0x24818584,0x9c7c00a3,0x9ab4002b}},	//   _pck_, thim_, _stči, _upāṃ, 
   {{0xf2dc208d,0x44200051,0x3eac0200,0x255000b8}},	//   _buâ_, _qck_, zoft_, _āvṛṇ, 
   {{0x9f6005ac,0x2480045f,0x44200208,0xb6f4129d}},	// [28d80] _årøy_, rhim_, _vck_, _قىيا_, 
   {{0x24818585,0xf2dc208d,0x686400e5,0x00000000}},	//   shim_, _duâ_, _آپکے, --, 
   {{0x24818586,0x23600211,0x44200790,0x41b58587}},	//   phim_, sxij_, _tck_, фсат, 
   {{0xa9240122,0x2ce8025c,0x44218588,0x7f8401d5}},	//   _zaží, _ལྕེབ, _uck_, _hаqi, 
   {{0x9c7c22c1,0x7c20e6e4,0xdb1008fb,0xc0f002d3}},	//   _juče, _rcor, _åføl, _ፍጻመ_, 
   {{0x91ac00fe,0xa6e000cc,0x00000000,0x00000000}},	//   কেইখ, _ভবাট, --, --, 
   {{0x9c7cef6b,0x00000000,0x00000000,0x00000000}},	//   _luče, --, --, --, 
   {{0x3ead8589,0x6d301b74,0xbae40408,0x8c3c0205}},	//   soft_, теъф, мцой, koşu, 
   {{0xf2dc0356,0x5fa8000d,0x00000000,0x00000000}},	//   _frâu_, _छँटल, --, --, 
   {{0xaec1858a,0xf2dc0311,0x66c0005b,0x3f8405c7}},	//   _абул, _grâu_, yöka, mzou_, 
   {{0x19596d13,0xed4c0014,0x78ac3974,0x39a400d4}},	//   чаны_, _پپن_, tocv, ьшив, 
   {{0x7c200513,0x06c801ec,0x00000000,0x00000000}},	//   _ucor, _ﻓﻌﻨﺩ, --, --, 
   {{0x3f85858b,0xa9240419,0x37a9858c,0xeaac0066}},	//   nzou_, _paží, ютон_, طعی_, 
   {{0x66c0023a,0x3f8400d8,0x47300451,0x2900025c}},	//   töka, izou_, اڙيء, ġjar_, 
   {{0xf3fc0589,0xf2dc0393,0x7afc00cd,0x00000000}},	//   _peã_, _suâ_, _āpty, --, 
   {{0xdb0c0003,0x66c001e3,0x00000000,0x00000000}},	//   _གྷོཌ_, röka, --, --, 
   {{0x66c004f3,0x9c7c00f3,0xf2dc0381,0x32080736}},	// [28d90] söka, _guče, _quâ_, قتاً_, 
   {{0x8e7c0115,0x3f841155,0x00000000,0x00000000}},	//   _kuŝe, dzou_, --, --, 
   {{0xf3fc0589,0x81b0015b,0x00000000,0x00000000}},	//   _teã_, ঞেস_, --, --, 
   {{0x8c3c084c,0x7bc00810,0x8e7c01e4,0xf2dc003a}},	//   noşt, _ozou, _muŝe, _tuâ_, 
   {{0x8e7c0115,0x83a400c7,0x00000000,0x00000000}},	//   _luŝe, _зырҵ, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7bc02622,0x8d7410de,0x3f840077,0x00000000}},	//   _azou, عاتا, azou_, --, 
   {{0x0c2476c5,0x00000000,0x00000000,0x00000000}},	//   хмин, --, --, --, 
   {{0xf2dd858d,0x28e00150,0x225c013a,0x00000000}},	//   _trâu_, _ﺍﻟﺸﺠ, _úzká_, --, 
   {{0x7bc00433,0x8e7c0115,0x9c7c04bf,0x4a440816}},	//   _dzou, _buŝe, _ruče, хнов, 
   {{0x8bd80efb,0x4998656c,0x9c7c0d0f,0x7bc00165}},	//   _емес_, ятия_, _suče, _ezou, 
   {{0x1cb80135,0x8e7c0115,0x9c7c01ef,0x00000000}},	//   _ཚེག_, _duŝe, _puče, --, 
   {{0x2d84310a,0x35a001b9,0xbb2801d3,0x00000000}},	//   lzne_, ҳарг, _فتوے_, --, 
   {{0x9c7c1674,0x8e7c01e4,0xc21c0037,0x00000000}},	//   _vuče, _fuŝe, _पाइब_, --, 
   {{0x38c804d3,0x35a1858e,0x35c46e3e,0x00000000}},	//   تایی_, гарг, егро_, --, 
   {{0x69c00bb8,0x9c7c01a6,0xf77003e6,0xc84400db}},	//   _izne, _tuče, _ڕاپ_, _чеий, 
   {{0xb8980375,0xb3380200,0xf751858f,0x00000000}},	// [28da0] _מבקש, _kyçy, _منيج, --, 
   {{0x9f44025a,0x77c4009d,0x00000000,0x00000000}},	//   _kemö_, _ялыг_, --, --, 
   {{0x66c002f6,0xe05804d3,0x00d800c6,0x68e80356}},	//   löko, ویست_, سبات_, _îndă, 
   {{0x44fc012c,0x00000000,0x00000000,0x00000000}},	//   mů_, --, --, --, 
   {{0x44fc012c,0xddc80034,0xf55401d5,0x3f84037e}},	//   lů_, łoże, _قلیب_, uzou_, 
   {{0xdd940dd8,0x9e340228,0x3f858590,0x11d4005e}},	//   калы, текч, rzou_, رتەد, 
   {{0x44fc0316,0xb80803d4,0xf2a18591,0x2d840171}},	//   nů_, ষ্টত_, _сирп, gzne_, 
   {{0x315402e4,0x66c00108,0x00000000,0x00000000}},	//   _אילן_, köko, --, --, 
   {{0x44fc012c,0xf2dc054e,0x65680267,0x69c003e3}},	//   hů_, _urât_, ädhj, _azne, 
   {{0x44fc012c,0x8e7c01e4,0xed4c01ed,0x7af400a2}},	//   ků_, _puŝe, جھے_, _çytm, 
   {{0x2d8414cf,0x44fc0316,0xc21c000d,0x00000000}},	//   czne_, jů_, _पाईब_, --, 
   {{0x44fc0316,0x2ce8031c,0xb198010f,0x387c03b2}},	//   dů_, _ལྕིབ, לייכ, óur_, 
   {{0x69c0009a,0x7bc001ef,0x00000000,0x00000000}},	//   _ezne, _uzou, --, --, 
   {{0x66c0049f,0xba28310b,0x8e7c0115,0x44fc0118}},	//   sökn, _رستم_, _tuŝe, fů_, 
   {{0x7ae06329,0xe53532ba,0x44fc0118,0xdef00023}},	//   _huot, лерь, gů_, _ግዛእ_, 
   {{0xf2dc025a,0xb8640345,0x1754022e,0x00000000}},	//   _asâa_, _سابو, _авия, --, 
   {{0x7ae0023a,0x998c012d,0x61600092,0x00000000}},	// [28db0] _juot, jedź_, _ተቋማዊ_, --, 
   {{0x7ae18592,0xf3fc00e4,0x44fc00bc,0xb1a402dd}},	//   _muot, _moãi_, bů_, ншек, 
   {{0x7ae0049b,0x43e800ec,0x44fc01ef,0x00000000}},	//   _luot, _ڪرپٽ_, ců_, --, 
   {{0x20540046,0xe0d0489b,0xf8b00243,0x00000000}},	//   лтір, مزن_, ीतिय, --, 
   {{0x7ae18593,0xbf700220,0xdea4036b,0xddc801ef}},	//   _nuot, ақты, گیلی, _bodů, 
   {{0x2d84005a,0xd06801ec,0xb28400db,0xc21c000d}},	//   tzne_, _ﺍﺗﯩﭗ_, _чымк, _पाएब_, 
   {{0x4c68152d,0xdea400dd,0x8e7c01e4,0x61f80156}},	//   дийн_, دیلی, _puŝb, ñvle, 
   {{0xabc00184,0x7ae12988,0x2d840034,0x8fd02cc8}},	//   лайҙ, _buot, rzne_, _кәлә, 
   {{0x7ae000bd,0xadf00116,0x2d84033f,0xdef800c7}},	//   _cuot, _бозә, szne_, _зых_, 
   {{0xc3300302,0x7ae00006,0x00000000,0x00000000}},	//   סוי_, _duot, --, --, 
   {{0x0d2000f7,0x99d40a4a,0x94200073,0xf41c007c}},	//   _түйү, лююч, यलाच_, _kläd_, 
   {{0x7ae00a85,0x69c06185,0x44fc00bc,0x66c0023a}},	//   _fuot, _vzne, vů_, töko, 
   {{0x7ae005d5,0x6d400142,0x00000000,0x00000000}},	//   _guot, lwna, --, --, 
   {{0x44fc012c,0xb898001f,0x22840432,0x66c000e5}},	//   tů_, ፈለገው_, _köke_, röko, 
   {{0x6d4001ee,0x66c00793,0xf48401b9,0x9c7c00d7}},	//   nwna, söko, چاقی, _huča, 
   {{0x7ae000c6,0x44fc0316,0x68e05320,0x9c7c1a48}},	//   _yuot, rů_, _iund, _kuča, 
   {{0x68e18594,0x27e00c67,0x44fc0316,0x38c81acf}},	// [28dc0] _hund, _igin_, sů_, _تاوی_, 
   {{0x44fc012c,0x6d400099,0x9c7c01a6,0x2138007f}},	//   pů_, kwna, _muča, _pprh_, 
   {{0x9c7c0cf4,0xba400024,0x20e803e0,0x00000000}},	//   _luča, _šįka, _eğin_, --, 
   {{0xc2f40f22,0x5d8402dd,0x2aa8005c,0x42e8014b}},	//   _চিঠি_, ңғаж, røby_, _оммо_, 
   {{0x44318595,0x3cfc0618,0x00000000,0x00000000}},	//   mfy_, _swtv_, --, --, 
   {{0x7ae18596,0x68e014dc,0x44318597,0xcfa81547}},	//   _ruot, _ound, lfy_, رانم_, 
   {{0x7ae18598,0x68e18599,0x27e0058a,0x91c40166}},	//   _suot, _nund, _ogin_, _барҗ, 
   {{0x27e00652,0xdd940184,0x2284010e,0x7ae1859a}},	//   _ngin_, каһы, _döke_, _puot, 
   {{0x7ae1859b,0x68e1859c,0xeb940640,0xc2f400cc}},	//   _quot, _aund, кић_, _চিডি_, 
   {{0x7ae1859d,0x2004398e,0x68e09a62,0x27e00493}},	//   _vuot, _hemi_, _bund, _agin_, 
   {{0x2004069c,0x68e1859e,0x58d4016c,0x27e00334}},	//   _kemi_, _cund, лоот, _bgin_, 
   {{0x7ae1859f,0x68e01574,0x200585a0,0x38702097}},	//   _tuot, _dund, _jemi_, рқит, 
   {{0xda3445b3,0x68e185a1,0xb8c8012c,0xec24007b}},	//   _белы, _eund, _खद_, _شكوى_, 
   {{0x27e0152d,0xd95527e0,0x68e02b9d,0xadc00241}},	//   _egin_, _منتخ, _fund, _abẹl, 
   {{0x443185a2,0x344800f5,0x659401c4,0x00000000}},	//   ffy_, мчан_, аару, --, 
   {{0x200585a3,0x8e7c01e4,0xab60003d,0x00000000}},	//   _nemi_, _muŝa, żżej, --, 
   {{0xe37585a4,0x32000851,0xf8bc91f8,0x722807d8}},	// [28dd0] алты, _pejy_, mlé_, дцев_, 
   {{0xf8bd85a5,0x68e185a6,0x00000000,0x00000000}},	//   llé_, _yund, --, --, 
   {{0x20040921,0x68e0058a,0x27e0022e,0xf41c007c}},	//   _bemi_, _xund, _ygin_, _pläd_, 
   {{0x76580198,0x787c0240,0xcfe83518,0xbf0c0490}},	//   ɓuya, _mëvo, رفته_, सळून_, 
   {{0x32000481,0x200585a7,0xf8bcfbcd,0x787c036e}},	//   _tejy_, _demi_, ilé_, _lëvo, 
   {{0x9c7c098d,0x8e7c0115,0x200401e1,0xf8bc62d0}},	//   _ruča, _buŝa, _eemi_, hlé_, 
   {{0xf8bc219b,0x200585a8,0xcd340127,0xa29400d4}},	//   klé_, _femi_, ارتب, _тарі, 
   {{0x68e05b47,0x8e7c01e4,0x9c7c0301,0x200585a9}},	//   _rund, _duŝa, _puča, _gemi_, 
   {{0x68e185aa,0xf8bc02fb,0x4a751dbc,0x27e07d10}},	//   _sund, dlé_, гынт, _rgin_, 
   {{0x200585ab,0x8e7c00df,0x7f8401a9,0x27e00142}},	//   _zemi_, _fuŝa, _vаqt, _sgin_, 
   {{0x200585ac,0xf8bc7c6e,0x4c3405f5,0x68e185ad}},	//   _yemi_, flé_, _бэлт, _qund, 
   {{0x68e185ae,0xf8bd85af,0x00000000,0x00000000}},	//   _vund, glé_, --, --, 
   {{0x68e185b0,0xc794e277,0x9c7c01a6,0x20e806be}},	//   _wund, урны, _kučn, _ağil_, 
   {{0x68e185b1,0x396c044e,0x2cbcce85,0x66c185b2}},	//   _tund, _ስጉምቲ_, llud_, mökk, 
   {{0x68e185b3,0x9c7c07f5,0xf8bd85b4,0x090401d5}},	//   _uund, _mučn, blé_, _ёпин, 
   {{0x27e01859,0xf8bd85b5,0x03e0015b,0xd4f400ee}},	//   _ugin_, clé_, বর্ণ, ряры, 
   {{0x7410104a,0x42c80354,0x20e80205,0x443015c0}},	// [28de0] صولا, еган_, _eğil_, rfy_, 
   {{0x2004271d,0x443185b6,0x00000000,0x00000000}},	//   _semi_, sfy_, --, --, 
   {{0x7a7800c8,0x2cbc005c,0x200585b7,0x00000000}},	//   ערעס, klud_, _pemi_, --, 
   {{0x9f4402d2,0x51540137,0xf1c800cf,0x00000000}},	//   _afmá_, штуу, رالۇ_, --, 
   {{0x9c7c1a48,0x4374798c,0x2004036e,0xd6a800f2}},	//   _bučn, _сунт, _vemi_, _سدیم_, 
   {{0x5274676b,0x8e7c00df,0x2cbc0254,0x9cf400d4}},	//   _кусу, _puŝa, elud_, азкі, 
   {{0xdcb00372,0x11d42626,0xf8bd85b8,0x1cb80327}},	//   يىت_, _вітр, ylé_, _ཚེད_, 
   {{0x5b1585b9,0x5c741fbd,0xf8bc00e8,0x00000000}},	//   амит, рлит, xlé_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfce585ba,0x8e7c010f,0xf8bc00e8,0x00000000}},	//   _божо, _tuŝa, wlé_, --, 
   {{0xf8bd85bb,0x7f84022e,0x00000000,0x00000000}},	//   tlé_, _tаqs, --, --, 
   {{0xf8bce1b9,0x2cbd85bc,0x66c0032e,0x00000000}},	//   ulé_, clud_, bökk, --, 
   {{0xf8bd85bd,0xe784072c,0x75e000d1,0x00000000}},	//   rlé_, буро, йәнҗ, --, 
   {{0xf8bd85be,0xa3d809ab,0x6fd80139,0xd05406be}},	//   slé_, ाधन_, _häcü, _duzə, 
   {{0xf8bc58f4,0x998c110c,0x661401ef,0x00000000}},	//   plé_, ledž_, _řeká, --, 
   {{0x77900edf,0xf8bc011f,0xa7e54959,0x93f4c38a}},	//   _هیجا, qlé_, _гөрҗ, рпац, 
   {{0xd5b000e1,0x6fd8013d,0x03e000fe,0x00000000}},	// [28df0] _आँकड़, _mäcü, বৰ্ণ, --, 
   {{0x201802b5,0x20e803e0,0x1dd400cd,0x00000000}},	//   _ēria_, _eğim_, दधात, --, 
   {{0x9c7d85bf,0xd01185c0,0x4e9407d6,0xf77001d3}},	//   _ručn, قلا_, یشتر, _خاں_, 
   {{0x66c029a8,0x7004072d,0x00000000,0x00000000}},	//   yökk, اذال, --, --, 
   {{0x9c7c0427,0x2cbd85c1,0x4e2800d8,0x00000000}},	//   _pučn, vlud_, волн_, --, 
   {{0xd250036b,0x9c7d3b9b,0x37c400eb,0x00000000}},	//   _بنآ_, _bučo, _এলার, --, 
   {{0x20240086,0x9c7c0331,0x00000000,0x00000000}},	//   ûriò_, _vučn, --, --, 
   {{0xa0085821,0x00000000,0x00000000,0x00000000}},	//   _مقفل_, --, --, --, 
   {{0x9c7c5652,0x6f601e87,0xca8585c2,0xcd3400ec}},	//   _tučn, _دۇشم, игий, ارڪب, 
   {{0xc95400fd,0x00000000,0x00000000,0x00000000}},	//   атмы, --, --, --, 
   {{0x88c985c3,0xfe6c3089,0x66c001d3,0x9d1801f0}},	//   клов_, _تگن_, sökk, _бохт_, 
   {{0x8e7c0115,0x66c0023a,0xa3d82c30,0x00000000}},	//   _kuŝo, möki, ाधम_, --, 
   {{0xf8a400c0,0x66c001f4,0x00000000,0x00000000}},	//   рвяк_, löki, --, --, 
   {{0x7cc80198,0x8e7c00df,0x96b800db,0x00000000}},	//   _iƙra, _muŝo, гусу_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6fd80139,0x00000000,0x00000000,0x00000000}},	//   _xäcü, --, --, --, 
   {{0x020403a6,0xb6980af2,0xaefc01ec,0xd78801d3}},	// [28e00] изан, tsât, _نﺎﺴﻧ, _منٹو_, 
   {{0xc1540063,0x2284007c,0xcea40451,0x66c001f4}},	//   ињењ, _böka_, _رڙ_, köki, 
   {{0x3fe41d39,0x361805d0,0x00000000,0x00000000}},	//   ажев, _בויד, --, --, 
   {{0x8e7c010f,0x00000000,0x00000000,0x00000000}},	//   _buŝo, --, --, --, 
   {{0x24801c06,0x6444009f,0xfe4585c4,0xbe883004}},	//   mkim_, meii, индо, кске_, 
   {{0x644585c5,0x248185c6,0xdec0010c,0xee342cdd}},	//   leii, lkim_, ትፎን_, инч_, 
   {{0x31641196,0x71a00117,0x248000c0,0x00000000}},	//   änzt_, _дарз, okim_, --, 
   {{0x248185c7,0x8e7c01e4,0x644585c8,0x19c401e0}},	//   nkim_, _fuŝo, neii, ҙәлг, 
   {{0x248185c9,0xfaa40117,0x84880092,0x28bc07f7}},	//   ikim_, ишон, _መወሰን_, ैतनि, 
   {{0x4f9485a8,0x6444587b,0x1cb8031c,0x9c7c107d}},	//   _урсу, heii, _ཚེམ_, _tučo, 
   {{0xa3d8069f,0xfc640801,0xda7001d9,0x24800210}},	//   ाधड_, _вълн, قُک_, kkim_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfaa4016c,0xfbd0047f,0x248065d2,0x644585ca}},	//   _кадо, देशम, dkim_, deii, 
   {{0x64440a73,0x04f00154,0x54540131,0xaab0007b}},	//   eeii, _জয়ের_, әват, _وصوت, 
   {{0x9c7c0427,0x644416ca,0x58d4005b,0x657c0042}},	//   _lučm, feii, _локт, gyrh, 
   {{0x6444022f,0x228401e6,0x20e803e0,0x00000000}},	//   geii, _röka_, _eğik_, --, 
   {{0x2284049f,0x56940139,0xbb2401ec,0x25800108}},	// [28e10] _söka_, _гапт, _ﺠﻤﻊ_, tälö_, 
   {{0x2480016b,0x67bc011a,0x00000000,0x00000000}},	//   akim_, _במחק, --, --, 
   {{0x64440393,0x24800010,0x69cc012d,0x00000000}},	//   beii, bkim_, ęceg, --, 
   {{0x248185cb,0x8e7c0115,0x3204012d,0x00000000}},	//   ckim_, _puŝo, źny_, --, 
   {{0xd1b02832,0xb36400a7,0xe8e001fb,0x9f045a16}},	//   _کیاک, _тънк, _ngời_, قونو, 
   {{0x52840597,0x66c185cc,0x00000000,0x00000000}},	//   _السك, töki, --, --, 
   {{0xddc802fb,0xc18001d9,0x00000000,0x00000000}},	//   _podš, _ٹینٹ, --, --, 
   {{0x8e7c0115,0x8c484979,0xa02801ec,0x00000000}},	//   _tuŝo, упив_, _ەسەك_, --, 
   {{0x0044004b,0x768806be,0x00000000,0x00000000}},	//   _دیني_, _küyd, --, --, 
   {{0x248185cd,0x6444002f,0x00000000,0x00000000}},	//   zkim_, zeii, --, --, 
   {{0x248185ce,0x29001497,0x76880205,0xdd9000e5}},	//   ykim_, èja_, _müyd, _ہوے_, 
   {{0x9c7c0219,0x3b900092,0x00000000,0x00000000}},	//   _lučj, ሞያዎች_, --, --, 
   {{0x6444022f,0x0ae800ec,0x24800205,0x00000000}},	//   veii, _ڌرڻي_, vkim_, --, 
   {{0xe9a002dd,0x657c0113,0xf74000f0,0x00000000}},	//   _қақп, tyrh, џеро, --, 
   {{0x44140724,0x644585cf,0x00000000,0x00000000}},	//   йфат, teii, --, --, 
   {{0x5bc400cf,0x9cbc0327,0x00000000,0x00000000}},	//   _اقۇل, _ཕེབས, --, --, 
   {{0xf8b01775,0x248185d0,0x644400fe,0x38c83ee6}},	// [28e20] _משה_, rkim_, reii, _حاوی_, 
   {{0x03a43461,0xc20985d1,0x64440e14,0x232801d5}},	//   _ҳимо, اقان_, seii, лоғи_, 
   {{0x044437fb,0x6444022f,0xbdf80131,0xf41c0166}},	//   _ленн, peii, ۇرغا_, _ilän_, 
   {{0x44ec010e,0x04440166,0xeb841867,0xdec001f3}},	//   _iý_, _уемн, _فظ_, ትፎና_, 
   {{0x44ec0208,0x00000000,0x00000000,0x00000000}},	//   _hý_, --, --, --, 
   {{0x44ec01dc,0x010985d2,0x00000000,0x00000000}},	//   _ký_, _مترو_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3178008f,0x44ed85d3,0x1af429c6,0x00000000}},	//   _גאלד, _mý_, опия, --, 
   {{0x44ec01dc,0xeaf40502,0xa3d81a22,0x66c002f6}},	//   _lý_, یریت_, ाधि_, löku, 
   {{0x33740302,0x9c7c08a4,0x6f100118,0x44ec010b}},	//   צעים_, _kučk, řecí, _oý_, 
   {{0x44ec008c,0xb2b8010f,0xbb240150,0x00000000}},	//   _ný_, רמיר, _ﺠﻤﻌ_, --, 
   {{0x9c7c107d,0x00000000,0x00000000,0x00000000}},	//   _mučk, --, --, --, 
   {{0xeb302580,0x9c7c341a,0xeb9400c9,0x44ec0209}},	//   _فروخ, _lučk, _лиц_, _aý_, 
   {{0x7bc0014b,0x2558033b,0x66c185d4,0x44ec0ad9}},	//   _iyou, _bčl_, köku, _bý_, 
   {{0x787c044e,0x83140135,0x7bc0019b,0x66c001a8}},	//   _lëvi, ྲེའུ_, _hyou, jöku, 
   {{0x7bc0019b,0x44ec0142,0xf41c0108,0x768800a2}},	//   _kyou, _dý_, _elän_, _süyd, 
   {{0x24580c9e,0x7bc004ce,0x44ec00ee,0xdebc0b82}},	// [28e30] щать_, _jyou, _eý_, ዶምን_, 
   {{0x2558007f,0x9c7c19d6,0x7bc004ce,0x44ec0162}},	//   _fčl_, _bučk, _myou, _fý_, 
   {{0x9c7c07f5,0x7bc00175,0xf77c00ee,0x00000000}},	//   _vučj, _lyou, lyç_, --, 
   {{0x768800a2,0x76440100,0xf2340133,0x8c3c0205}},	//   _düye, lejy, شبڕک, mişg, 
   {{0x7bc185d5,0x83a400c7,0x25580100,0x65b40150}},	//   _nyou, _дырҵ, _zčl_, _ﭼﺎﯕﺠ, 
   {{0x9c7c01a6,0x394c0036,0x05940150,0x228402d2}},	//   _fučk, _osfs_, _داۋگ, _jökl_, 
   {{0x7bc185d6,0x394c0472,0x32cc0205,0x52c42894}},	//   _ayou, _nsfs_, güye_, वतीस, 
   {{0x7bc049db,0x6ab00882,0x00000000,0x00000000}},	//   _byou, ुत्र, --, --, 
   {{0xf2dc0022,0xb00001e0,0x28e002dd,0x75240200}},	//   _asâi_, _моңһ, _ﺍﻟﺘﺠ, hujz, 
   {{0x8e7c01e4,0x8cc8652f,0x0f3002d3,0x8274008f}},	//   _muŝk, _हीरो, በኣርከ, ַערע_, 
   {{0x7bc0007f,0x66e00248,0x32cc0790,0x64ac0205}},	//   _eyou, _lákì, cüye_, dğin, 
   {{0x25580100,0x44ec00d7,0xc154011a,0x00000000}},	//   _rčl_, _rý_, קשרו_, --, 
   {{0xc1c40846,0x22840998,0xf41c0793,0x4a740228}},	//   _वर्ग, _bökl_, _plän_, _мыкт, 
   {{0x2558007f,0x66c0023a,0x00000000,0x00000000}},	//   _pčl_, yöku, --, --, 
   {{0x88c585d7,0xddc8033f,0x7af400a2,0x8c3c00a2}},	//   _وتعل, _zadł, _çytr, gişg, 
   {{0x9c7c07f5,0x07a585d8,0x8e7c01e4,0x29040455}},	//   _ručk, _майн, _buŝk, _iwna_, 
   {{0x8c3c0cc1,0x0674ed48,0x76880432,0xc6900023}},	// [28e40] mişd, _дуня, _düyb, _ሃገርካ_, 
   {{0x44ed85d9,0x66c185da,0x9c7c92ca,0xa49407d6}},	//   _tý_, töku, _pučk, _کیرت, 
   {{0x814474e3,0x69c00493,0x68e55bf3,0x44ec0208}},	//   تنان, _jyne, _kiid, _uý_, 
   {{0x7f840222,0x69c00cfd,0x68e401d9,0x9c7c0552}},	//   يلان, _myne, _jiid, _vučk, 
   {{0x68e585db,0x66c00008,0x228400ac,0x00000000}},	//   _miid, söku, _hökm_, --, 
   {{0x68e585dc,0x29040048,0x7bc0019b,0x32cc0790}},	//   _liid, _owna_, _ryou, tüye_, 
   {{0x6e003306,0x69c00618,0xc044027a,0x629cc08a}},	//   ذِين, _nyne, _وخرو, _imro, 
   {{0x68e4db6d,0x629c037e,0x7bc05dad,0xddc8012d}},	//   _niid, _hmro, _pyou, _padł, 
   {{0x3ea585dd,0x66c002d6,0x69c185de,0xbea4030d}},	//   _диаг, nöks, _ayne, _даак, 
   {{0x69c01dda,0x34a41b37,0x5a34721f,0x394c04cc}},	//   _byne, _गद्द, чнот, _psfs_, 
   {{0x1cac1efe,0x68e585df,0x9c7c0331,0x69c185e0}},	//   ྗོད_, _biid, _luči, _cyne, 
   {{0x68e40d62,0x69c185e1,0x752400ca,0xeff402d3}},	//   _ciid, _dyne, vujz, _ዋሕዚ_, 
   {{0x629cf9ff,0x68e585e2,0x8e7c01e4,0xac9401d3}},	//   _omro, _diid, _buŝh, _بننا_, 
   {{0xf41c0793,0x199585e3,0x69c00368,0xaa500064}},	//   _pläo_, _наля, _fyne, _овіш, 
   {{0x68e401d9,0x290403cb,0xe5c4187f,0x94d40b3b}},	//   _fiid, _gwna_, дсто, зовц, 
   {{0x68e585e4,0x8e7c0115,0x1df807d0,0x9c7c4a52}},	//   _giid, _puŝk, ुरुष_, _buči, 
   {{0x69c00036,0xd9d007d2,0xe4b802dd,0x75240427}},	// [28e50] _zyne, _زەڭگ, ілуі_, sujz, 
   {{0x9c7c8bbb,0x8c3c00ee,0x68e40472,0xd25000c6}},	//   _duči, mişe, _ziid, عنا_, 
   {{0x7580424b,0x8c3d85e5,0x00000000,0x00000000}},	//   _غیرم, lişe, --, --, 
   {{0xe0d00014,0x66c001e6,0x68e4058a,0xb42428ee}},	//   نزن_, sökt, _xiid, _بعدو, 
   {{0x629c0158,0x513c0150,0x9f980063,0x8c3d85e6}},	//   _fmro, _ءﺳﺎﻥ_, овцу_, nişe, 
   {{0x8e7c010f,0x999c00c0,0xa3d85612,0xb8980092}},	//   _kuŝi, _javų_, ाधर_, ገለጠው_, 
   {{0x60c00270,0x30a40124,0x8c3cb6d6,0xdcf800e2}},	//   _fkmm, _драв, yişd, dzvē, 
   {{0x8c3c03ee,0x69c00034,0x629c0210,0x00000000}},	//   kişe, _ryne, _zmro, --, 
   {{0x69c039c2,0x68e585e7,0xed540046,0x629c0368}},	//   _syne, _riid, соқ_, _ymro, 
   {{0x69c006a3,0x68e585e8,0x8c3c0274,0x00000000}},	//   _pyne, _siid, dişe, --, 
   {{0x8c3cffea,0x68e40254,0xef1c031c,0x00000000}},	//   tişd, _piid, ħżun_, --, 
   {{0x69c00122,0x68e4011f,0x798c0086,0x84f00073}},	//   _vyne, _qiid, ùbwa, _आंबट_, 
   {{0x68e585e9,0x8c3d85ea,0x69c000a9,0x39580092}},	//   _viid, rişd, _wyne, _ሌዋውያ, 
   {{0x68e4045f,0x00000000,0x00000000,0x00000000}},	//   _wiid, --, --, --, 
   {{0x68e585eb,0x2a6403cd,0x9c7c00c0,0x00000000}},	//   _tiid, _innb_, _suči, --, 
   {{0x8e7c01e4,0x66c0023a,0x9c7c3a4c,0x8c3c0166}},	//   _duŝi, töks, _puči, bişe, 
   {{0xb7b00323,0x0324373e,0x07a402e8,0x00000000}},	// [28e60] _зөрч, ядан, _хапн, --, 
   {{0x9c7c026a,0x8e7c00df,0x66c000e5,0x00000000}},	//   _vuči, _fuŝi, röks, --, 
   {{0x66c0049f,0xf6780302,0x00000000,0x00000000}},	//   söks, _האימ, --, --, 
   {{0x9c7c01fa,0x66c0005b,0x228402d2,0x00000000}},	//   _tuči, pöks, _kökk_, --, 
   {{0x3d0c01f9,0x00000000,0x00000000,0x00000000}},	//   णीने_, --, --, --, 
   {{0x629d85ec,0x93240133,0xd12c0137,0x00000000}},	//   _umro, _کرێن, _چۅل_, --, 
   {{0x409408bf,0x00000000,0x00000000,0x00000000}},	//   _ерат, --, --, --, 
   {{0x76880205,0x00000000,0x00000000,0x00000000}},	//   _müya, --, --, --, 
   {{0x8a580171,0x00000000,0x00000000,0x00000000}},	//   _ķērā, --, --, --, 
   {{0x02bc012a,0x8c3c0790,0x2bd807b7,0x00000000}},	//   ्तिभ, vişe, मेधा, --, 
   {{0xe8e00016,0x98bc0055,0x69c4031c,0x00000000}},	//   _ngồi_, _urvī_, żjen, --, 
   {{0x8c3ca697,0x999c0153,0xcc0800f7,0x00000000}},	//   tişe, _savų_, _ۇزۇن_, --, 
   {{0x2bd81533,0xac9400c6,0x1cdc031c,0x02bc725a}},	//   मेदा, _عنها_, _རྫར_, ्ताभ, 
   {{0x8e7c010f,0x2284032e,0xa5f84b4d,0x7eb400c7}},	//   _puŝi, _dökk_, зеру_, tâpy, 
   {{0x7e78a2ec,0x2a3805d0,0x6a38011a,0x8c3c0205}},	//   _motp, _העומ, _הגופ, sişe, 
   {{0x52c40882,0x768800a2,0xf41c0139,0xc9840592}},	//   वत्स, _düya, _iläk_, _تشهي, 
   {{0xf8bc4185,0x7e786686,0x9dec02dd,0x8c3c06be}},	// [28e70] moé_, _ootp, _өтiн, qişe, 
   {{0x7e7800cd,0xf8bd407e,0x8e7c010f,0x00000000}},	//   _notp, loé_, _tuŝi, --, 
   {{0x3af00051,0x00000000,0x00000000,0x00000000}},	//   _lâp_, --, --, --, 
   {{0x9c7c0b4b,0x3dd02b1b,0xf8bc0129,0x00000000}},	//   _kuču, াশাল, noé_, --, 
   {{0x72a001ec,0x7e780200,0xa3445fd0,0xa0c4009f}},	//   _كەرن, _botp, _пэрл, ريهو, 
   {{0x7e7800cd,0xa2e40006,0x630402da,0x00000000}},	//   _cotp, _поўд, _سوفل, --, 
   {{0x7e788767,0x25f01bbb,0x765415c0,0x00000000}},	//   _dotp, _आलसी_, _maxy, --, 
   {{0x10640014,0x321185ed,0x00000000,0x00000000}},	//   _تُرُ, laxy_, --, --, 
   {{0x7e795d41,0xcd4401d3,0x3af00208,0x5f94004e}},	//   _fotp, سپکٹ, _câp_, _зитт, 
   {{0x89a93c1b,0x3af0015d,0x00000000,0x00000000}},	//   жков_, _dâp_, --, --, 
   {{0x8eb00145,0xed880166,0x228408a5,0x00000000}},	//   _كەچت, _усак_, _sökk_, --, 
   {{0x76880365,0x3ce4011c,0xc7a4e0dc,0x07a585ee}},	//   _rüya, _giov_, димк, дамн, 
   {{0x2cbc0067,0xf3fc0798,0x76540067,0x7e7985ef}},	//   moud_, _anão_, _baxy, _yotp, 
   {{0x2cbd85f0,0x4904036b,0x7b040118,0xf1c00153}},	//   loud_, _قوتق, ístř, _košė_, 
   {{0xf8bc020c,0xa3e000dc,0x00000000,0x00000000}},	//   boé_, धेन_, --, --, 
   {{0x2cbd85f1,0x00000000,0x00000000,0x00000000}},	//   noud_, --, --, --, 
   {{0xaca0063f,0xe3a403c7,0x00000000,0x00000000}},	// [28e80] _nfọm, رشری, --, --, 
   {{0x2cbd85f2,0x8e7c0115,0x228585f3,0xd3a476c5}},	//   houd_, _kuŝu, _köki_, хлуқ, 
   {{0x2cbc017a,0x20e84dd9,0x00000000,0x00000000}},	//   koud_, _ağir_, --, --, 
   {{0x7e781028,0x84500137,0x00000000,0x00000000}},	//   _sotp, _جۉرچ, --, --, 
   {{0x7e7804b9,0x7654ad04,0x2cbd40a8,0x00000000}},	//   _potp, _yaxy, doud_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6044033b,0xd17801ec,0x7e7800b8,0xad640114}},	//   _pčmč, _есті_, _votp, дајз_, 
   {{0x225985f4,0x2cbc0493,0xfba801c6,0x787c0240}},	//   _hark_, goud_, жтой_, _lëvr, 
   {{0x7e781f40,0xb0340a7c,0x9974012d,0x225985f5}},	//   _totp, _קאמפ_, _węże_, _kark_, 
   {{0x225850d4,0x8e7c01e4,0xed4c01d3,0x69cc033f}},	//   _jark_, _buŝu, دھے_, ęcen, 
   {{0x2cbd85f6,0x2258e397,0xf8bc0798,0xfce41422}},	//   boud_, _mark_, toé_, _жожо, 
   {{0x225985f7,0x3b8437fb,0x6a7c045f,0x3af168b8}},	//   _lark_, _олег, _sêft, _tâp_, 
   {{0x7d180109,0x2258002d,0x7688010e,0xf8bc0129}},	//   _hvts, _oark_, _düyn, roé_, 
   {{0x8e7c01e4,0x9c7c2625,0x4628031c,0x7d18022e}},	//   _fuŝu, _vuču, _སྐྱས_, _kvts, 
   {{0xf8bc0438,0x8c3d85f8,0x1b0000eb,0x00000000}},	//   poé_, lişa, _এটিই_, --, 
   {{0x76540050,0x2bd81d27,0xed5c00d0,0x00000000}},	//   _waxy, मेवा, úžil_, --, 
   {{0x58fc031c,0x22582517,0x3210045a,0x8c3d85f9}},	// [28e90] དེམས_, _bark_, taxy_, nişa, 
   {{0x2cbd85fa,0x00000000,0x00000000,0x00000000}},	//   zoud_, --, --, --, 
   {{0x225826e7,0x2cbc02e2,0x00000000,0x00000000}},	//   _dark_, youd_, --, --, 
   {{0x8c3c0cc1,0x20540220,0x7e7c6b4e,0xf1c00064}},	//   kişa, ктір, öppn, _rošė_, 
   {{0x1cdc025c,0x4df40cb9,0x22591d11,0x2cbc0156}},	//   _རྫེ_, няйт, _fark_, voud_, 
   {{0x8d5585fb,0x2cbd85fc,0x95740020,0x8c3c0ac1}},	//   етич, woud_, _ያሉትን_, dişa, 
   {{0x20e80259,0x623402dd,0x32cc0205,0x02bc06ff}},	//   _işin_, _шеру, lüyo_, ्तरभ, 
   {{0xf41c0036,0x3a3c0208,0x8fd001af,0x00000000}},	//   _bläi_, eftp_, _йәлә, --, 
   {{0xd0081de6,0x32cc03e0,0xe0640244,0x00000000}},	//   _меңе_, nüyo_, _جێنی, --, 
   {{0x2cbd85fd,0x61b000cc,0x00000000,0x00000000}},	//   soud_, _কৰিআ, --, --, 
   {{0xaca000b4,0x8e7c0115,0xdd3401d5,0x2cbc0165}},	//   _ajụj, _duŝt, _لرنظ, poud_, 
   {{0xf41c008e,0xddc80118,0x32cc0205,0x00000000}},	//   _iläw_, _nadř, küyo_, --, 
   {{0x3a3c0175,0xcb6985fe,0x27e40267,0x8c3c0356}},	//   bftp_, _хале_, ämn_, cişa, 
   {{0xf41c0589,0xd68c01e4,0x867400c7,0x00000000}},	//   _adä_, _spaϲ, хымц, --, 
   {{0x04449fb7,0x9c7c0064,0x386801e7,0x2bd836c7}},	//   невн, _tučt, áirí_, मेरा, 
   {{0x22580493,0x6f1803b9,0x00000000,0x00000000}},	//   _sark_, _ovuc, --, --, 
   {{0x6d440793,0x768803b9,0x00000000,0x00000000}},	// [28ea0] _äjaf, _küyl, --, --, 
   {{0x41b585ff,0xc2c5685f,0x22580240,0xdcf80064}},	//   нсет, رياي, _qark_, lyvą, 
   {{0x6f198600,0x225805e4,0x41b4023b,0x1b0000cc}},	//   _avuc, _vark_, хсат, _এয়াই_, 
   {{0x22580c3a,0x20e803e0,0x7d1c0162,0x0cb80118}},	//   _wark_, _eşin_, ápsm, उकोम, 
   {{0xde58242f,0x225877a6,0xcfa80fba,0x3cfc0051}},	//   далі_, _tark_, واهم_, _sttv_, 
   {{0xd36c0150,0x84240150,0x44318601,0x20e80205}},	//   _بۇك_, _تىڭن, lgy_, _eğip_, 
   {{0x44300170,0x1cdc0135,0x6f198602,0x02bc7a18}},	//   ogy_, _རྫུ_, _evuc, ्तीन, 
   {{0x44310f8f,0x8c3c3535,0x00000000,0x00000000}},	//   ngy_, tişa, --, --, 
   {{0x8e7c01e4,0x3a3c00e4,0x9b9400d8,0x64ac010e}},	//   _puŝt, tftp_, типц, mşid, 
   {{0x4880001f,0xd8f802bf,0x3f8400b5,0x8c3c137e}},	//   _ድረገጽ_, мної_, myou_, rişa, 
   {{0x6f180b91,0xddc80558,0x23600477,0x6e1401f7}},	//   _zvuc, _hodž, hvij_, _سينس_, 
   {{0xddc80e3c,0x390400f7,0x02bc0b7c,0x23602230}},	//   _kodž, мдүү_, ्तुन, kvij_, 
   {{0x4430232c,0x3f84b0d7,0x61fc0841,0x228402d2}},	//   dgy_, nyou_, _ofrl, _höku_, 
   {{0x0ba800cf,0x228408a5,0xddc800ef,0x00000000}},	//   _تامى_, _köku_, _modž, --, 
   {{0xfbb0015b,0xddc82890,0x3f8404ce,0x821400eb}},	//   _চরিত, _lodž, hyou_, ালাপ_, 
   {{0x3f858603,0x7ae80393,0x44318604,0xf7e800c6}},	//   kyou_, _hift, ggy_, _عربى_, 
   {{0x92598605,0x3f8404ce,0x02bc448b,0xf2480108}},	// [28eb0] маат_, jyou_, ्तून, зяек_, 
   {{0x7ae80003,0x32cc03e0,0x00000000,0x00000000}},	//   _jift, rüyo_, --, --, 
   {{0x7ae98606,0x2efd8607,0x35dc0183,0x00000000}},	//   _mift, _stuf_, _ব্ৰহ, --, 
   {{0x7ae98608,0xddc800c0,0xf6080244,0x00000000}},	//   _lift, _bodž, _بتکه_, --, 
   {{0x84140375,0x3f84105c,0x20e80139,0xdfd4009d}},	//   _בקרב_, gyou_, _tşin_, гоцы, 
   {{0x7ae98609,0xd5b400e1,0x00000000,0x00000000}},	//   _nift, _उखाड़, --, --, 
   {{0x8cb48fe2,0x00000000,0x00000000,0x00000000}},	//   ксич, --, --, --, 
   {{0x0b4407d6,0x7ae80493,0x3f84037e,0xd0d402e8}},	//   внин, _aift, byou_, _робъ, 
   {{0x6f180286,0x8c3c054e,0x3f84037e,0xddc825ad}},	//   _uvuc, bişn, cyou_, _godž, 
   {{0x7ae9860a,0xf41c01b8,0x443000ee,0x8fd00032}},	//   _cift, _gläv_, zgy_, _йәһә, 
   {{0x44300510,0x7ae9860b,0x9918109a,0xad25860c}},	//   ygy_, _dift, ніях_, _سراو, 
   {{0x8c3c084c,0x76880213,0x25880241,0x2d846069}},	//   mişo, _düym, _lìlú_, myne_, 
   {{0x1cdc0135,0x768805d1,0x7ae9860d,0x00000000}},	//   _རྫི_, _tüyl, _fift, --, 
   {{0xb699860e,0x44310e15,0x82bc0327,0x36c00395}},	//   spân, wgy_, _མཉེའ, ибяг, 
   {{0xc4c5860f,0x84580131,0x3f858509,0x35a001c0}},	//   نترو, мрат_, zyou_, аарг, 
   {{0xfbb00183,0x391000d1,0x768800a2,0x5434009d}},	//   _চৰিত, _өмәр, _jüyj, лхуу, 
   {{0x4431243b,0x7ae8208d,0x2d841155,0x00000000}},	// [28ec0] rgy_, _yift, hyne_, --, 
   {{0xddc983a4,0x23600489,0x7ae8031c,0x02bc00dc}},	//   _rodž, rvij_, _xift, ्तेन, 
   {{0xc058d5d9,0x59180327,0xddc80064,0x00000000}},	//   діл_, ྱེགས_, _sodž, --, 
   {{0xddc80010,0x2d843d44,0x3f8404ce,0x00000000}},	//   _podž, dyne_, tyou_, --, 
   {{0x6aa002d0,0x2d840067,0x00000000,0x00000000}},	//   _omnf, eyne_, --, --, 
   {{0x3f84019b,0xeaa400c6,0x20e8aa57,0x69cc012d}},	//   ryou_, _ضع_, _işim_, ęcej, 
   {{0x2d858610,0x7ae98611,0x4421126f,0x3f8404ce}},	//   gyne_, _rift, _kdk_, syou_, 
   {{0x44218612,0x7ae81caa,0x228408a5,0x00000000}},	//   _jdk_, _sift, _vöku_, --, 
   {{0x44218613,0x8c3c51b7,0x7ae98614,0xdea401b9}},	//   _mdk_, mişl, _pift, _ییچی, 
   {{0x44218615,0x8c3d8616,0x7ae80023,0x81e405ac}},	//   _ldk_, lişl, _qift, _য্য_, 
   {{0x7ae80450,0xddc80100,0x4ea40798,0xb87801ef}},	//   _vift, _indů, _срѓа, jmíc, 
   {{0x387d8617,0xa9c010f5,0x8c3c4a4a,0x4420bde6}},	//   ður_, рськ, nişl, _ndk_, 
   {{0x7c218618,0x7ae8038f,0x5918025c,0x64ac0205}},	//   _idor, _tift, ྱེངས_, kşib, 
   {{0x4420070d,0x998c012d,0x8c3c03b9,0x00000000}},	//   _adk_, radł_, hişl, --, 
   {{0x442053d5,0x7c200219,0x8c3c1e0c,0x9a800092}},	//   _bdk_, _kdor, kişl, _ይለናል_, 
   {{0x649801e1,0x44218619,0x998c012d,0xa5040209}},	//   _líif, _cdk_, padł_, рярл, 
   {{0x24780020,0x249c0020,0x8c3c442e,0x7c21861a}},	// [28ed0] _አገራት_, _ሀገራት_, dişl, _mdor, 
   {{0x36a000d1,0x720000d1,0x00000000,0x00000000}},	//   _ئەسق, شۈرم, --, --, 
   {{0x20e805d1,0x44200334,0x22840267,0xddc800a2}},	//   _eşim_, _fdk_, _rökt_, _ýoňl, 
   {{0x8c3c09a5,0x228401e6,0x00000000,0x00000000}},	//   gişl, _sökt_, --, --, 
   {{0x8e7c01e4,0xe61002dd,0x23e80798,0x2d8454ac}},	//   _buŝp, _اشۋ_, _афро_, wyne_, 
   {{0x2d85861b,0x44200b94,0xf8dc0764,0x7688010e}},	//   tyne_, _zdk_, नगुप, _süyj, 
   {{0x4c6805f5,0x41e401d9,0xf0b8215c,0xe2c8007b}},	//   еийн_, _مسٲف, _قارش_, _شوفو_, 
   {{0x7998068f,0x25d80375,0x8c3d67dd,0x00000000}},	//   dztw, כוון_, rişo, --, 
   {{0x7c20025a,0x2d852ef7,0xaca000b4,0x8e7c01e4}},	//   _ddor, syne_, _ndụm, _fuŝp, 
   {{0x7c21861c,0xaca00241,0x2d840ea0,0xf41c007c}},	//   _edor, _ikọj, pyne_, _kläs_, 
   {{0x8c3c0365,0x2c0001ec,0x48e401c4,0x00000000}},	//   lişm, _күйм, лоов, --, 
   {{0x228401f4,0x00000000,0x00000000,0x00000000}},	//   _yöks_, --, --, --, 
   {{0x8c3cf740,0x64ac0c3c,0x442045ae,0x00000000}},	//   nişm, hşic, _rdk_, --, 
   {{0xfbc40183,0x44200f85,0x7c200139,0x7fd4011a}},	//   শেহত, _sdk_, _zdor, טורס_, 
   {{0x4421861d,0xd4f58373,0x8c3c3361,0x7cec007f}},	//   _pdk_, ияты, yişl, mòrè, 
   {{0x8c3c373d,0x949400fd,0x29d001d5,0x47a40154}},	//   kişm, ашуч, _йўқс, _গুণী, 
   {{0x6b980730,0x442000ef,0xc2440022,0x00000000}},	// [28ee0] nzug, _vdk_, лнак, --, 
   {{0xf41c0267,0x6b98002f,0x8c3c00a2,0x00000000}},	//   _slät_, izug, dişm, --, 
   {{0x4420480d,0x97c40014,0x7a2c022e,0xaf300131}},	//   _tdk_, _متیم, _mеtа, ەرىت, 
   {{0x20e80f7d,0x22880022,0x023401e2,0x00000000}},	//   _işik_, хәҭо_, _څښاک_, --, 
   {{0x8c3c2ed2,0xa3e04328,0xb6c80014,0x8e7c01e4}},	//   rişl, धेश_, _زایے_, _puŝp, 
   {{0xb5a801ed,0x82a4010b,0x7c200142,0xfca812ea}},	//   _آئیے_, _сагж, _sdor, کاتو_, 
   {{0xdd94d1da,0x644516c8,0x9a80001f,0x768800a2}},	//   райы, ofii, _ይለኛል_, _süyk, 
   {{0x64441559,0x6b980e78,0xed2400f1,0x8c3c00a2}},	//   nfii, fzug, اړلي_, lişj, 
   {{0xb7bc0183,0x8e7c0115,0xf41c3672,0x7c200427}},	//   _ইণ্ট, _tuŝp, _klär_, _vdor, 
   {{0x7c2000b5,0x8e8000c7,0x38a80241,0x0a300092}},	//   _wdor, _ҳҳәе, _oòrè_, _በበርካ, 
   {{0xaa613716,0x6444058a,0xada000d7,0xc0380092}},	//   стык, kfii, _chúď, _የምትወ, 
   {{0xfbc4045e,0x7c200117,0x23b444d0,0x6b980112}},	//   শেষত, _udor, ंपाद, bzug, 
   {{0xfbd00dd8,0x20e80205,0x00000000,0x00000000}},	//   _اتا_, _aşik_, --, --, 
   {{0x66f4084c,0x6445861e,0x00000000,0x00000000}},	//   спру, efii, --, --, 
   {{0x6445861f,0xf3fc0589,0x195802dd,0x65958620}},	//   ffii, _pfã_, _райы_, бару, 
   {{0x2458230c,0x2bd808e6,0xb4bc1d8a,0x8c3c00ac}},	//   лась_, मेका, इवे_, yişm, 
   {{0xddc801e4,0x20e84246,0x00000000,0x00000000}},	// [28ef0] _radŝ, _eşik_, --, --, 
   {{0x8c3c083c,0x64458621,0x66c00108,0x00000000}},	//   vişm, afii, köky, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8c3d02ea,0x53340026,0xd478008f,0x00000000}},	//   tişm, _кемт, _סאָל, --, 
   {{0x44180375,0xa3ac07af,0x00000000,0x00000000}},	//   _בורס, _केप_, --, --, 
   {{0x8c3c1934,0x5fa40073,0x6b9801b9,0x00000000}},	//   rişm, _खेळल, vzug, --, 
   {{0xd1b036ba,0x0d740209,0x6b9800ee,0xf424010e}},	//   _بیاک, рыля, wzug, _enäň_, 
   {{0x4c852910,0x6b9966ec,0x8c3c3361,0x00000000}},	//   рлив, tzug, mişk, --, 
   {{0x8c3c0790,0x4fc0215c,0xed5401d5,0xca74008e}},	//   lişk, _بەشە, тоқ_, ауны, 
   {{0xd90c021a,0x6b980730,0xba7405a9,0x1fa401c0}},	//   ډیو_, rzug, لاپت, _урсг, 
   {{0xa3ac09b4,0x6b9803fa,0x29000023,0x20e803b9}},	//   _केन_, szug, ëja_, _bşih_, 
   {{0xc794c862,0x2900005f,0xdda804bb,0x7d78010f}},	//   аргы, īja_, _стул_, _ברעג, 
   {{0x9b880066,0x00000000,0x00000000,0x00000000}},	//   _مخوف_, --, --, --, 
   {{0x64440014,0xb87804d4,0x09e468ba,0x8c3c0205}},	//   wfii, rmía, _колн, kişk, 
   {{0x44158622,0xc8b4034b,0x644402d0,0xa3c8000d}},	//   ифат, _вспы, tfii, _ऊँह_, 
   {{0xc1744a23,0x99d406c2,0x64458623,0x70bc00bc}},	//   یدات, _اتها, ufii, एकोल, 
   {{0x64440af5,0x23e0032c,0xb7740220,0x7410a054}},	// [28f00] rfii, पेंद, _көру_, زولا, 
   {{0x64458624,0x66c00108,0x00000000,0x00000000}},	//   sfii, yöky, --, --, 
   {{0xf67804ac,0x04458625,0x76400342,0x04c80472}},	//   _סאטמ, _кенн, _önya, _لودي_, 
   {{0xdec001f3,0x64440009,0x3518011a,0x00000000}},	//   ስዎን_, qfii, _בוטנ, --, 
   {{0xe28450e5,0x4374030d,0x3e140014,0xff501699}},	//   _лған, _тунт, ٔٹتھ_, تخا_, 
   {{0xa3e000dc,0x71400014,0x7d24005b,0x66c001f4}},	//   धेः_, _ژھنٕ, афие, töky, 
   {{0xb878038e,0x661c0158,0xc0e4ffc0,0x6f0c0139}},	//   dmín, iark, _вовк, _çccn, 
   {{0x661d8626,0x6c800075,0xef8000d1,0xdde000e5}},	//   hark, قلىم, сләп, ítőa, 
   {{0xa3ac02ab,0x59f80395,0xc0380092,0x00000000}},	//   _केम_, лепя_, _የምታወ, --, 
   {{0x661c5df1,0x00000000,0x00000000,0x00000000}},	//   jark, --, --, --, 
   {{0x661d8627,0x3f4001fb,0x7f40e913,0xed541188}},	//   dark, _hưu_, ltoq, _вох_, 
   {{0xaba4598b,0x7d083262,0x3154010f,0x00000000}},	//   اهیم_, mpfs, ביטן_, --, 
   {{0x661d8628,0xe784f98f,0x7f418629,0xdb1c0241}},	//   fark, оуро, ntoq, _àyàf, 
   {{0x661d862a,0x3f40001e,0x7f40013c,0xf9680139}},	//   gark, _mưu_, itoq, _арий_, 
   {{0x3f4007ae,0x88d400bd,0xaad804ae,0x00000000}},	//   _lưu_, _সংরক, _שחור, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x24581de1,0xe2f80220,0x1cdc025c,0x1634020f}},	// [28f10] шать_, иеті_, _རྫབ_, _лепя, 
   {{0x661d862b,0x8c3c05d1,0x3b04022e,0x98780304}},	//   cark, tişk, _mtoq_, _рәүф_, 
   {{0x22597b40,0xd0100131,0xd5b068e1,0x00000000}},	//   рихы_, كلا_, _رفح_, --, 
   {{0x3f40001e,0x795402d3,0x4f9401c0,0xb8784822}},	//   _bưu_, _ዜጋታት, йрлу, zmín, 
   {{0xb87826d3,0x3f40004d,0xddc803e3,0x00000000}},	//   hmío, _cưu_, _padş, --, 
   {{0x8c3d2af5,0x00000000,0x00000000,0x00000000}},	//   mişi, --, --, --, 
   {{0x8c3c9d6a,0x7f400140,0x91e40eac,0x5194007b}},	//   lişi, atoq, _প্রখ, _الأذ, 
   {{0x1a690689,0x661d862c,0x00000000,0x00000000}},	//   یینی_, zark, --, --, 
   {{0x8c3c7b4e,0x7f4018df,0xcac8005b,0xd13400f1}},	//   nişi, ctoq, лгие_, _خوځښ, 
   {{0x661d862d,0x76880139,0x00000000,0x00000000}},	//   xark, _küyu, --, --, 
   {{0xb8780232,0x661d862e,0x08c4024c,0x09c00011}},	//   rmín, vark, йбон, ৈধভা, 
   {{0x661d862f,0xae083d1d,0x8c3c4a98,0xc844010b}},	//   wark, _स्तन_, kişi, щемй, 
   {{0xfa5404d3,0xd018010e,0xc7b01291,0x00000000}},	//   _گرنگ, _meń_, سّس_, --, 
   {{0x8c3d6eeb,0xf41c0267,0xb8780166,0x00000000}},	//   dişi, _släp_, lmíl, --, 
   {{0x661c0a81,0x6d418630,0xb6a162bf,0x48e44623}},	//   rark, ntna, чирл, _локв, 
   {{0x661d8631,0x29040421,0x03a41f67,0x58940022}},	//   sark, _itna_, бибо, _мшыу, 
   {{0x25580100,0x7f40003a,0x20e80356,0x422400d4}},	// [28f20] _wōl_, xtoq, _uşii_, йдав, 
   {{0x6d418632,0x661d8633,0x00000000,0x00000000}},	//   ktna, qark, --, --, 
   {{0xc9244251,0x3f400016,0x6d401654,0x64a400c7}},	//   _বহুত_, _sưu_, jtna, _ҳаҟа, 
   {{0x7f400af5,0xa4958634,0x50b401c0,0x70100154}},	//   ttoq, _بیرت, осчу, _হাউজ_, 
   {{0x2904070d,0x6d40001e,0x7f400140,0xd018010e}},	//   _ltna_, etna, utoq, _deń_, 
   {{0x7f400af5,0x2480098d,0x6d400354,0x2bd8012c}},	//   rtoq, ljim_, ftna, मेछा, 
   {{0x7f40003d,0xc0d401c8,0xf650011a,0x8c3c00a2}},	//   stoq, _هيسب, פצה_, nişw, 
   {{0xee34535f,0x67240427,0xd01800a2,0x7f400393}},	//   анә_, _ovij, _geń_, ptoq, 
   {{0x29058635,0x7f400194,0x6d418636,0x00000000}},	//   _atna_, qtoq, atna, --, 
   {{0x6fb025ef,0x6d4001ef,0x00000000,0x00000000}},	//   _عملا, btna, --, --, 
   {{0x9a800020,0x7d098637,0x67258638,0x6d418639}},	//   _ይገኛል_, _снег_, _avij, ctna, 
   {{0x8c3c03be,0x248046e1,0x7c6400f1,0xb87801e7}},	//   yişi, jjim_, _داطل, rmío, 
   {{0x2905863a,0x672404b9,0x248008a4,0x3a840139}},	//   _etna_, _cvij, djim_, _гыйв, 
   {{0x6725863b,0x19950edd,0x657c0158,0x8c3c1432}},	//   _dvij, _маля, fxrh, vişi, 
   {{0x65942763,0xc0c0001f,0x3449599c,0x672400e2}},	//   пару, ድሮስ_, лчан_, _evij, 
   {{0x8c3c0ab7,0x24800023,0x00000000,0x00000000}},	//   tişi, gjim_, --, --, 
   {{0x591831d9,0x3eac365a,0x80ac0073,0x00000000}},	// [28f30] ྱེམས_, kift_, ूचने, --, 
   {{0x8c3c2ed2,0x6d40022c,0x1d8c0020,0x78ac0356}},	//   rişi, ytna, ንያቶች_, licv, 
   {{0x67241f7f,0x64ac0311,0x24800010,0x6d407c8c}},	//   _zvij, oşil, bjim_, xtna, 
   {{0x4fd4d3a6,0xd018030a,0x70b0000d,0x00000000}},	//   ожет, _zońj_, ंचेल, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d41863c,0x8d740228,0xaee00055,0xb8780118}},	//   ttna, قابا, _maṇo, dmím, 
   {{0x8cc400ae,0x00000000,0x00000000,0x00000000}},	//   يقته, --, --, --, 
   {{0x6d41863d,0xcc89863e,0xc04c00aa,0x13ac0154}},	//   rtna, рбие_, _لږه_, _কুয়, 
   {{0xa3ac07f7,0xdb08029e,0x7d1c03b2,0x00000000}},	//   _केा_, یزیه_, ápsr, --, 
   {{0x24800114,0x6d410841,0x4aa801a9,0x66f401e1}},	//   zjim_, ptna, ркон_, _nńka, 
   {{0x6724036f,0x1cdc0156,0x2d640989,0xb87800e4}},	//   _svij, _རྫམ_, _uđe_, amím, 
   {{0xd01805c7,0x29040051,0x00000000,0x00000000}},	//   _sońj_, _vtna_, --, --, 
   {{0x24800010,0x00000000,0x00000000,0x00000000}},	//   vjim_, --, --, --, 
   {{0xd49001fb,0x2bac0037,0xfbb000cc,0x00000000}},	//   ền_, _जेया, _চৰকত, --, 
   {{0x644001b8,0x248009a8,0xda644d49,0xdbd40ad9}},	//   _ömik, tjim_, _راوي, _húði, 
   {{0xdbd409c2,0x64ac0356,0xb8cc00cc,0x00000000}},	//   _zúñi, cşil, _কৱ_, --, 
   {{0x6724036f,0xd39800fd,0xb9240248,0x8c3c0166}},	// [28f40] _uvij, бәрә_, _ootọ_, bişv, 
   {{0x24800010,0x8c3c0356,0x00000000,0x00000000}},	//   sjim_, mişu, --, --, 
   {{0x06b40131,0x8c3c0356,0x24800200,0x64ac0432}},	//   _ﭼﯜﺷﻪ, lişu, pjim_, lşim, 
   {{0x00c846e8,0x3eac00b5,0xb8780022,0xca4801ec}},	//   шлек_, wift_, ymím, _ﻀﻴﺔ_, 
   {{0x3eac13ee,0x8c3c0356,0x00000000,0x00000000}},	//   tift_, nişu, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2bac000d,0x00000000,0x00000000,0x00000000}},	//   _जेबा, --, --, --, 
   {{0xdbd401a8,0xf3640023,0x8c3c03e0,0x93240345}},	//   _búði, _ትርእዮ_, kişu, _برێن, 
   {{0x3fb401ed,0x46d80490,0x78ac02d0,0x00000000}},	//   _بھاگ_, णताह, vicv, --, 
   {{0xfa89863f,0x20e805d1,0xcfa800c6,0x13ac0011}},	//   рсий_, _eşit_, _طاقم_, _কুড়, 
   {{0xa3acc7f9,0x32540375,0x78ac003a,0x6c801888}},	//   _केस_, חסים_, ticv, سلیم, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x795003e6,0x78ac003a,0x59f812e7,0x00000000}},	//   سێکا, ricv, _леля_, --, 
   {{0x78ad8640,0xdee40023,0x6d5001e4,0x00000000}},	//   sicv, _ምቹእ_, ŭfaŝ, --, 
   {{0x1994010b,0x3d0c0073,0x7bcc0205,0x64ac00a2}},	//   _хайя, णीचे_, şbud, mşij, 
   {{0x73f800fe,0xa3ac00ab,0x00000000,0x00000000}},	//   েণ্ট_, _केह_, --, --, 
   {{0x8c3c0365,0xb9d8069d,0xded80023,0x00000000}},	// [28f50] mişt, _ቢል_, ሖምን_, --, 
   {{0x8c3d8641,0x3209710e,0x00000000,0x00000000}},	//   lişt, рхан_, --, --, 
   {{0x27f400bc,0xc69008a8,0x8658011a,0x00000000}},	//   čanů_, _נאט_, _הדתי, --, 
   {{0x8c3c084c,0xa3ac0037,0x768803e0,0x00000000}},	//   nişt, _केव_, _tüys, --, 
   {{0xb4d40574,0x00000000,0x00000000,0x00000000}},	//   िती_, --, --, --, 
   {{0x8c3c4560,0x00000000,0x00000000,0x00000000}},	//   hişt, --, --, --, 
   {{0x7bc00005,0x8c3c05d1,0xdbd403b2,0xa2d403ce}},	//   _axou, kişt, _súði, _बीट्, 
   {{0x8c3c0356,0xdbd402d2,0x25bc011a,0x00000000}},	//   jişt, _púði, יצומ, --, 
   {{0x24840086,0x8c3c9736,0xb8780413,0x00000000}},	//   _òmme_, dişt, mmíh, --, 
   {{0xeb94267c,0xb4d407d0,0x00000000,0x00000000}},	//   йиқ_, ितु_, --, --, 
   {{0x88c82312,0x7d28004b,0x10400092,0x3940009d}},	//   йлов_, _هيلې_, _የምትመ, ннэг, 
   {{0xa3ac367a,0x8c3c56a3,0x87c401d9,0x00000000}},	//   _कइल_, gişt, ۪تھٕ, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xca498642,0x8c3c0311,0xe7f017ee,0x768800a2}},	//   _طلبه_, rişu, _घृणा_, _süyr, 
   {{0x6ac40a94,0x04940953,0x00000000,0x00000000}},	//   रकीर, праў, --, --, 
   {{0x8c3d8643,0xc72400ee,0x00000000,0x00000000}},	//   mişs, _едий, --, --, 
   {{0x68e40472,0x7de001e1,0xa3ac04af,0x386c01e7}},	// [28f60] _ihid, _kísí, _केश_, _ógra_, 
   {{0x604400b0,0x705001d3,0x54800092,0xa6540345}},	//   _mōmō, ہنما, _ከወርቅ_, _تێست, 
   {{0x68e58644,0xa3ac0c66,0xdce801ef,0x00000000}},	//   _khid, _केर_, _srdč, --, 
   {{0x39a00438,0x68e40036,0x6ac41a2a,0x26d80158}},	//   _hésé_, _jhid, रकुर, llro_, 
   {{0x85b80014,0x68e4b2f8,0xd9d803ba,0xbe8803cf}},	//   _خاکس_, _mhid, _डर्ट, йске_, 
   {{0x63a449e1,0xc2100050,0x8c3d67dd,0xa2840345}},	//   mzin, _سٔر_, zişt, _تیئو, 
   {{0x63a58645,0x68e4005a,0x629c01e7,0x8c3c03e0}},	//   lzin, _ohid, _ilro, yişt, 
   {{0x63a58646,0x27e000a2,0x00000000,0x00000000}},	//   ozin, _ozin_, --, --, 
   {{0xb9380020,0x7de001e1,0x8c3c19b2,0x2b40009d}},	//   _በተካሄ, _bísí, vişt, нээг, 
   {{0x63a58647,0x68e401f7,0x20e806be,0x00a00244}},	//   izin, _ahid, _işiq_, _تیڤێ, 
   {{0x27e07b06,0x68e58648,0x8c3d8649,0xcdcc004b}},	//   _azin_, _bhid, tişt, _پښو_, 
   {{0x68e5864a,0x63a5864b,0x69cc003a,0xbb840228}},	//   _chid, kzin, ęcep, _ىلاي, 
   {{0x68e5864c,0x63a40cf9,0x8c3d864d,0xc8f802f5}},	//   _dhid, jzin, rişt, _আবৃত_, 
   {{0x63a5864e,0x27e1864f,0x41bc043e,0x8c3c56a3}},	//   dzin, _dzin_, ्थास, sişt, 
   {{0x27e00323,0x68e41554,0x76880432,0x63a446b5}},	//   _ezin_, _fhid, _düyp, ezin, 
   {{0xb4d4739b,0x68e58650,0xb864fdb1,0xa3c8000d}},	//   िते_, _ghid, _رابو, _ऊँख_, 
   {{0x63a401a4,0xd9d00150,0x00000000,0x00000000}},	// [28f70] gzin, _سەڭگ, --, --, 
   {{0x629c0175,0x68e58651,0xddd802f0,0x00000000}},	//   _clro, _zhid, pevň, --, 
   {{0x20e80213,0xf1a40166,0x00000000,0x00000000}},	//   _aşiq_, чран, --, --, 
   {{0x629c00e5,0x00000000,0x00000000,0x00000000}},	//   _elro, --, --, --, 
   {{0x7d181529,0xf6e8025c,0x5f9402bf,0x5dd40150}},	//   _awts, _རྫོང, ницт, _ﺘﺼﻭﻴ, 
   {{0x7d180142,0x9c580022,0x00000000,0x00000000}},	//   _bwts, ҧшыу_, --, --, 
   {{0x7d180042,0xb4d400cd,0x00000000,0x00000000}},	//   _cwts, ितॊ_, --, --, 
   {{0xfd5c0016,0x8fd000fb,0xa3ac00c5,0x8b940108}},	//   _huyề, _иәлә, _केँ_, дроч, 
   {{0x68e4025a,0xf41c0589,0x7d1802d0,0x7bdc01e4}},	//   _rhid, _meä_, _ewts, _ŝpur, 
   {{0x68e58652,0x09058653,0x6f18633b,0x69c00334}},	//   _shid, мпон, _iwuc, _pxne, 
   {{0x63a58654,0x6e218655,0x6f180810,0x68e40393}},	//   zzin, manb, _hwuc, _phid, 
   {{0xb4d4043e,0x6f1801f2,0x63a40139,0x61ec00ac}},	//   ितो_, _kwuc, yzin, ünlə, 
   {{0x68e406d6,0x2efc002e,0xa3ac6c95,0xb4d40243}},	//   _vhid, _juuf_, _कें_, ितै_, 
   {{0x6e218656,0x16c00184,0x68e40280,0x2cac0175}},	//   nanb, лҡын, _whid, _hmgd_, 
   {{0x68e40e89,0x63a400d8,0xcb0801f7,0x00000000}},	//   _thid, wzin, _ايڪن_, --, 
   {{0x63a58657,0x6e218658,0x6f18379d,0x68e58659}},	//   tzin, hanb, _owuc, _uhid, 
   {{0x6e21865a,0x63a40165,0x2efc0a55,0x27e0030a}},	// [28f80] kanb, uzin, _nuuf_, _uzin_, 
   {{0x2a640100,0x6e21865b,0x41b4151e,0xc0280023}},	//   _janb_, janb, мсет, _ሽበራው, 
   {{0x6f18293d,0x81d409bd,0x2a64cd62,0x6e200014}},	//   _awuc, াইভ_, _manb_, danb, 
   {{0x38a80034,0x63a400e2,0x7d180042,0xdb0000e5}},	//   _górę_, pzin, _rwts, szmé, 
   {{0xa3c80927,0x09b0015b,0x14bc090a,0x9f9c08a5}},	//   _ऊँट_, _ঘুমা, ्करण, gæða_, 
   {{0x6e21865c,0x2efc6ed5,0x5f3402d3,0x81d4015b}},	//   ganb, _duuf_, _ኣይረኸ, াইব_, 
   {{0x6f180117,0x2360047e,0xadb400f2,0x324001ee}},	//   _ewuc, lwij_, وهها_, _шерг, 
   {{0x2efc0de2,0x6e2001f5,0xb3bc00cc,0xa92400d7}},	//   _fuuf_, aanb, _আৰিজ, zkľú, 
   {{0x9ce800f8,0x6e21865d,0x2360016d,0x7f0400f2}},	//   _ہوئے_, banb, nwij_, _آذرم, 
   {{0xee35865e,0x6e200009,0x99d40014,0x62880248}},	//   _ону_, canb, ى۪شا, _òdod, 
   {{0x7e78127b,0xaa6000f7,0xf9c40212,0x23600978}},	//   _intp, ттык, ьщин, hwij_, 
   {{0x8e8000c7,0x2bac0073,0x6f240166,0xfb70022e}},	//   _аҳәе, _जेवा, _ärcä, _ақия, 
   {{0xfbe0193d,0x2a640789,0x2360016d,0xae080037}},	//   _परिम, _fanb_, jwij_, सुवन_, 
   {{0xb4d512a4,0x2360016d,0x00000000,0x00000000}},	//   ित्_, dwij_, --, --, 
   {{0x3ce40070,0xdef80003,0xdec00257,0xa5f95dc7}},	//   _khov_, _miċ_, ድሎና_, деру_, 
   {{0x6e2007ab,0xfbe0a3c6,0xdef80135,0x50600092}},	//   zanb, _पराम, _liċ_, _ለሌሎች, 
   {{0xf8bd865f,0x7e782595,0xf41c0c67,0xb4d400dc}},	// [28f90] mné_, _ontp, _veä_, ितौ_, 
   {{0xf8bc0300,0xfd5c07ae,0x6f18004c,0x7e784ef5}},	//   lné_, _quyề, _rwuc, _nntp, 
   {{0x2efc1574,0x6e218660,0x59d400af,0xf8bd8661}},	//   _suuf_, vanb, _ठुमर, oné_, 
   {{0xf8bd8662,0x7e798663,0x3a2c07c5,0x9f9c0008}},	//   nné_, _antp, _ldfp_, tæða_, 
   {{0x6e218664,0xe0d800d6,0xdef80135,0xf8bc2d59}},	//   tanb, єві_, _biċ_, iné_, 
   {{0x9f9c0008,0x9e640826,0xf8bcf85d,0xc330011a}},	//   ræða_, квід, hné_, _תום_, 
   {{0xf8bd8665,0xdef8025c,0xa2cc41ac,0xb0580b24}},	//   kné_, _diċ_, तकर्, _وشرط_, 
   {{0x6ac40ebb,0x6e204e35,0x3ce411c4,0xf8bc0e96}},	//   रक्र, sanb, _chov_, jné_, 
   {{0xf8bc0745,0x6f180921,0xdef8003d,0x70d801f9}},	//   dné_, _uwuc, _fiċ_, बतील, 
   {{0xf8bc020c,0xb87801a8,0x89a828e8,0x6e211663}},	//   ené_, nlíf, зков_, qanb, 
   {{0x23600210,0x00000000,0x00000000,0x00000000}},	//   zwij_, --, --, --, 
   {{0xf8bd8666,0x3ce58667,0x497401c0,0xdd940209}},	//   gné_, _ghov_, _үлдс, _шахы, 
   {{0x2cbc0649,0xb87800e4,0x00000000,0x00000000}},	//   mnud_, ymív, --, --, 
   {{0x2cbc007d,0xf8bd2b60,0x81d400fe,0x1bb800db}},	//   lnud_, ané_, াইত_, _تامع_, 
   {{0xf8bcb7f2,0x1fdc0b68,0x2360014f,0x40080037}},	//   bné_, _बर्ड, wwij_, हुँआ_, 
   {{0xf8bc0232,0x2cbc00af,0xa3040209,0x2360047e}},	//   cné_, nnud_, күме, twij_, 
   {{0x82347cf6,0x2cbc0254,0x00000000,0x00000000}},	// [28fa0] فراا, inud_, --, --, 
   {{0x05658668,0x2cbc0652,0xb879075e,0x324002dd}},	//   _звон, hnud_, glíf, леуг, 
   {{0x2cbd8669,0xf6e80327,0x2360016d,0x00000000}},	//   knud_, _རྫིང, swij_, --, 
   {{0xb7d40131,0xbfc5866a,0x2360016d,0x306400d8}},	//   _توۋا_, нбек, pwij_, ејшн_, 
   {{0x2cbc007d,0xb024543c,0x4421866b,0x23600978}},	//   dnud_, ركوم_, _iek_, qwij_, 
   {{0xf8bc031d,0xb8780077,0x52740124,0x3ce401b9}},	//   zné_, lmít, _иусу, _shov_, 
   {{0x3ce40218,0xe0440022,0x95800023,0xf8bc7cda}},	//   _phov_, _аҽеи, _ኪኸደላ_, yné_, 
   {{0x3ce40e37,0x2cbc03a2,0xf8bc0030,0x5c740902}},	//   _qhov_, gnud_, xné_, тлит, 
   {{0xf8bc8ea8,0x442008e7,0x7e7801f5,0x00000000}},	//   vné_, _mek_, _tntp, --, 
   {{0x79a51ead,0x610c0365,0x2ec800dc,0x7e7802d0}},	//   ерме, _eğle, िवृत, _untp, 
   {{0xf8bc0745,0x3ce40190,0x2cbc0254,0x7aa40073}},	//   tné_, _thov_, bnud_, टोगॅ, 
   {{0xb8650b3f,0xf8bcb59b,0x00000000,0x00000000}},	//   راجو, uné_, --, --, 
   {{0xf8bd866c,0xeb300a52,0xb878013a,0x00000000}},	//   rné_, _مىند, dmít, --, 
   {{0xf8bc03c6,0x7c21866d,0x442001c0,0x76840150}},	//   sné_, _heor, _aek_, хымж, 
   {{0x44202af2,0xf8bc03c6,0x7c20020b,0x00000000}},	//   _bek_, pné_, _keor, --, 
   {{0x4421866e,0x7c21866f,0x00000000,0x00000000}},	//   _cek_, _jeor, --, --, 
   {{0x44218670,0x7c2016b8,0xe4540228,0x00000000}},	// [28fb0] _dek_, _meor, ыкты, --, 
   {{0x44218671,0xd0185345,0x7c218672,0xe3b04363}},	//   _eek_, दर्भ_, _leor, حرف_, 
   {{0xd01020ea,0x44202171,0xb87801a8,0x00000000}},	//   للا_, _fek_, rlíf, --, 
   {{0x44218673,0xa3ac0f4a,0xa13401b9,0x3e380092}},	//   _gek_, _केक_, ارلش, _አሽከር, 
   {{0xdcf80153,0xb8780166,0x00000000,0x00000000}},	//   lyvė, lmís, --, --, 
   {{0x44218674,0x7c200086,0xc3c0b3a6,0x8d54d20e}},	//   _zek_, _aeor, _төсл, втич, 
   {{0x44218675,0x2cbc007d,0xa15841bd,0x7c206785}},	//   _yek_, tnud_, _пару_, _beor, 
   {{0x61e801ab,0x2cbc0254,0xc1e4012d,0x0b1800ae}},	//   _ùdla, unud_, _करतब_, وقعة_, 
   {{0x7c218676,0xd0480198,0x2cbd140b,0x7bd40158}},	//   _deor, _sheɗ, rnud_, _øyul, 
   {{0xb878012c,0x2cbc00c5,0xbd400137,0x00000000}},	//   hlíd, snud_, اچەي, --, 
   {{0x7c2000a3,0x3cf8012d,0x2cbc0037,0x09b000cc}},	//   _feor, _ऊंचे_, pnud_, _ঘঁহা, 
   {{0x7c218677,0xf3fc001e,0x9c6426c6,0x64ad76d0}},	//   _geor, _ngã_, _مهمو, nşit, 
   {{0x44218678,0xc62400bd,0xfc14011a,0x922001ef}},	//   _rek_, _বাবা_, _סקסי_, यराज_, 
   {{0xfe0c0208,0x245c0051,0x00000000,0x00000000}},	//   hững_, _ậm_, --, --, 
   {{0x44218679,0xf62039f3,0x7c201b21,0x799001e0}},	//   _pek_, рдсо, _yeor, _ҡиәф, 
   {{0x7c20056a,0xdb4c0133,0xddc83e9d,0x00000000}},	//   _xeor, _بێی_, _sadū, --, 
   {{0xd90d0249,0xb879867a,0x4421629d,0xddc800c0}},	// [28fc0] _ویی_, rmít, _vek_, _padū, 
   {{0x4421867b,0x26dc00c7,0xb8780118,0x96006efa}},	//   _wek_, _óvo_, smít, _гүрж, 
   {{0x4421867c,0x057400db,0xb8780162,0x00000000}},	//   _tek_, _شادد, blíd, --, 
   {{0xb878056a,0x4420005a,0x11e8678e,0xb03000d1}},	//   lmír, _uek_, رعلي_, لىمغ, 
   {{0x7c21867d,0xdee40023,0xb03000d4,0xddc800b8}},	//   _reor, ምጽእ_, рніш, _tadū, 
   {{0x7c205589,0x00000000,0x00000000,0x00000000}},	//   _seor, --, --, --, 
   {{0x7c21867e,0xed54026a,0xc1e40316,0xf650011a}},	//   _peor, вој_, _करिब_, יצג_, 
   {{0x6445867f,0xfca8004b,0xc0e40108,0xfa1c00fe}},	//   ngii, باتو_, _робк, _দাইল_, 
   {{0x3dd00034,0x644546c7,0x7c200254,0xb8780118}},	//   ływ_, igii, _veor, zmís, 
   {{0xbbe01d8a,0x7db416a4,0xb87802f0,0x6e402309}},	//   _परीक, _исец, jmír, _ەنەم, 
   {{0x79a416a4,0xda700a81,0x8ca000db,0xb878013a}},	//   трпе, لُک_, _گەيو, dmír, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7ac58680,0x00000000,0x00000000,0x00000000}},	//   _иске, --, --, --, 
   {{0x3f840798,0x64440009,0x48fc07f7,0x2b4800e8}},	//   ixou_, egii, _रूको_, àcce_, 
   {{0xa5049008,0x58d4013d,0xe5b400db,0x00000000}},	//   иятл, _йокт, айры, --, 
   {{0x64458681,0x00000000,0x00000000,0x00000000}},	//   ggii, --, --, --, 
   {{0xb8787d3d,0x5694ca77,0xb9ec0023,0x00000000}},	// [28fd0] smís, _бапт, _ዓሚ_, --, 
   {{0x644409f1,0x27e400c5,0x66e40e92,0xa3ac0037}},	//   agii, ümne_, _коња, _केओ_, 
   {{0xddc98682,0xd05802dd,0xc69000d9,0x25f401f9}},	//   _andž, ерлі_, _האי_, ंधणी_, 
   {{0x0d8406dc,0x00000000,0x00000000,0x00000000}},	//   ғлин, --, --, --, 
   {{0xc438025f,0xd490001e,0x9f058683,0x64ac0311}},	//   _אתרי, ều_, لونو, rşit, 
   {{0x0b4407d6,0xa3ac547d,0xc0cc0023,0x00000000}},	//   ҳнин, _केट_, _እገለ_, --, 
   {{0xb87806ed,0xddc800f3,0x64ac05d1,0x1ea80338}},	//   ilíb, _endž, mşir, ضاوي_, 
   {{0x0b4401b9,0x64ac0432,0x00000000,0x00000000}},	//   гнин, lşir, --, --, 
   {{0xaca002e3,0x610c0724,0x0a30001f,0x00000000}},	//   _ntụl, _iğla, _በአማካ, --, 
   {{0xd90c066d,0x9f040345,0x64ac03b9,0x95680092}},	//   ڈیو_, _ئولو, nşir, ችሁትን_, 
   {{0xaca00521,0xd90d8684,0x64440014,0x00000000}},	//   _atụl, ویو_, ygii, --, 
   {{0xfc4803b2,0x00000000,0x00000000,0x00000000}},	//   rbíð_, --, --, --, 
   {{0xca740831,0x4a74004e,0x9b7450d8,0x00000000}},	//   _буйы, _быйт, _پانص, --, 
   {{0x64440014,0x09e400d1,0xfa64c331,0x00000000}},	//   wgii, _йолн, _башк_, --, 
   {{0x610c3235,0x6444013c,0x09b00154,0x15b80166}},	//   _oğla, tgii, _ঘুরা, выты_, 
   {{0xb8782b57,0x8ec80011,0x00000000,0x00000000}},	//   smír, ষতিগ, --, --, 
   {{0x64458685,0xb8780316,0xc304004b,0xe9a40451}},	// [28fe0] rgii, blíb, ابرو, _سگھن_, 
   {{0x610c4a4a,0x644435a3,0xb2200733,0x64ac00a2}},	//   _ağla, sgii, ймул, gşir, 
   {{0x85b89a3e,0x661d8686,0x64ac0356,0x00000000}},	//   _سادس_, mbrk, uşis, --, 
   {{0xd5ac00dd,0x81d40f22,0x03a41eb8,0x00d98687}},	//   _کہہ_, াইল_, _бимо, ربات_, 
   {{0xa2850d72,0xbbe00316,0x70441b92,0x787808e2}},	//   _پیاو, _परेक, ارمە, _hävä, 
   {{0xdd9569ef,0xbd680395,0x78780958,0xbdf800d1}},	//   иалы, ерие_, _kävä, ىرغا_, 
   {{0xe0940214,0x30240022,0xc0580024,0x00000000}},	//   _پیشخ, _әоуп_, _прац_, --, 
   {{0xa6bc0349,0x35d8033f,0x00000000,0x00000000}},	//   ৃতিট, _मुफ़, --, --, 
   {{0xafe00246,0x787801f4,0xb878013a,0x00000000}},	//   _готл, _lävä, hlíc, --, 
   {{0x26c40036,0xc0c00023,0xc0cc01f3,0x00000000}},	//   émol_, ድዮም_, _እገሌ_, --, 
   {{0xb66c0023,0xb878022a,0x00000000,0x00000000}},	//   _ብምኻኑ_, jlíc, --, --, 
   {{0xd7f420e5,0x387ccd03,0xb8780118,0x2bac000d}},	//   изны, ñur_, dlíc, _जेका, 
   {{0x6cd00046,0x79a439fb,0x7f400393,0xab940ee8}},	//   _اقنا, _әрле, nuoq, _مخور_, 
   {{0xb8780005,0x0ba8075e,0x6b600137,0x00000000}},	//   flíc, _جامى_, _ыкча, --, 
   {{0xaa4000db,0x6eb400dc,0x6ac000f1,0x290000e5}},	//   _انىى, ्चतु, _دقوم, íjat_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbbe0258d,0xded80023,0xd46800ee,0x233800cf}},	// [28ff0] _परोक, ዖምን_, ниңе_, лпты_, 
   {{0xb6000316,0xb878056a,0xb1a402dd,0x7f40003a}},	//   část, blíc, лшек, duoq, 
   {{0x64ad8688,0xe2c8004b,0x27ec0034,0x3f4c00e4}},	//   rşir, دولو_, ędne_, yñuã_, 
   {{0x628802e2,0x7e9401d5,0x00000000,0x00000000}},	//   _òdon, یچلر_, --, --, 
   {{0xa1e80131,0x35d8000d,0x64ac25a8,0x00000000}},	//   پرەك_, _मँड़, pşir, --, 
   {{0x76458689,0x2ab80248,0x64ac00a2,0x00000000}},	//   ngjy, _mábè_, lşip, --, 
   {{0x4c680323,0xa194030d,0x0b0000cc,0x00000000}},	//   вийн_, _ларч, _এবেল_, --, 
   {{0xd044004b,0x4ea4010b,0xe3c40139,0x610c013d}},	//   _خپري, ырҗа, _ulıñ_, _uğla, 
   {{0xc624015b,0x00000000,0x00000000,0x00000000}},	//   _বাসা_, --, --, --, 
   {{0xdfd80c04,0x9af80a28,0xf3e400fe,0x39880023}},	//   _със_, _prāṇ, _কলাৰ_, ዕግስቲ_, 
   {{0x2f0803d4,0x09e45aa6,0x26c401f1,0x08c402f4}},	//   _høg_, ронн, émom_, ибон, 
   {{0x7d0c0122,0x0b580137,0x7878005b,0xcc9801af}},	//   žisé, _аркы_, _rävä, _швец_, 
   {{0x6d41868a,0x78780108,0x9c6400f2,0x00000000}},	//   luna, _sävä, _دهنو, --, 
   {{0xbb380302,0x6b980223,0x2f0836e0,0x6d40007f}},	//   _יעני, myug, _møg_, ouna, 
   {{0x6d41868b,0x2f08b626,0x04b5868c,0x00000000}},	//   nuna, _løg_, асая, --, 
   {{0xded0044e,0x29040194,0x00000000,0x00000000}},	//   _እየን_, _iuna_, --, --, 
  
   {{0x6d41868d,0x2905868e,0x42254677,0x2fdc01d4}},	// [29000] huna, _huna_, идав, _nyug_, 
   {{0x6d4118d1,0x290000b0,0x7f843cde,0x27e00248}},	//   kuna, _hiia_, یلان, _iyin_, 
   {{0x26d9868f,0x29058690,0x29000053,0x6b9800ca}},	//   moro_, _juna_, _kiia_, hyug, 
   {{0x26d98691,0x29058692,0x6d418693,0x67258694}},	//   loro_, _muna_, duna, _kwij, 
   {{0x29058695,0x6d4000d5,0x29000821,0x79980210}},	//   _luna_, euna, _miia_, zytw, 
   {{0x29018696,0x29040069,0x67258697,0x35d80dad}},	//   _liia_, _ouna_, _mwij, _मुड़, 
   {{0x6d413ca9,0x29058698,0xed840801,0x27e18699}},	//   guna, _nuna_, исък_, _lyin_, 
   {{0x26d801b2,0xbf1456a7,0x27e00cad,0xc0a800e5}},	//   horo_, _نورب, _oyin_, _شازل_, 
   {{0x2905869a,0x6b99869b,0x7ac400c9,0x3b04003a}},	//   _auna_, gyug, исое, _quoq_, 
   {{0x6d401841,0x781c0141,0x29000069,0x26d9869c}},	//   buna, पर्क_, _aiia_, joro_, 
   {{0x26d9869d,0x27e023db,0x2905869e,0x67240241}},	//   doro_, _ayin_, _cuna_, _awij, 
   {{0x2905869f,0x6724406f,0x27e186a0,0x6b9986a1}},	//   _duna_, _bwij, _byin_, byug, 
   {{0x26d80605,0x27e0020b,0x6b980223,0x7644036e}},	//   foro_, _cyin_, cyug, tgjy, 
   {{0x26d986a2,0x290586a3,0x67243743,0x00000000}},	//   goro_, _funa_, _dwij, --, 
   {{0x290450f9,0x27e00ca8,0x29000036,0x672401f5}},	//   _guna_, _eyin_, _fiia_, _ewij, 
   {{0xb87808a5,0x00000000,0x00000000,0x00000000}},	//   blía, --, --, --, 
   {{0x26d986a4,0x6d4186a5,0xf41c29ef,0x672401c8}},	// [29010] boro_, zuna, _soäs_, _gwij, 
   {{0x6d4186a6,0x26d986a7,0x2f08037e,0x20040194}},	//   yuna, coro_, _røg_, _agmi_, 
   {{0x2f08105c,0x672586a8,0x2904058a,0x94d40816}},	//   _søg_, _zwij, _xuna_, _гонц, 
   {{0x6d4186a9,0xb9080055,0x61140212,0x00000000}},	//   vuna, _dhiḥ_, ідчу, --, 
   {{0x95e8066d,0x6d4186aa,0x00000000,0x00000000}},	//   _جبکہ_, wuna, --, --, 
   {{0xce481064,0xdb000732,0x00000000,0x00000000}},	//   узке_, nzmä, --, --, 
   {{0xaf840184,0x6d400280,0x00000000,0x00000000}},	//   ыҡҡа_, uuna, --, --, 
   {{0x29041bb7,0x4c8586ab,0x5dd401ec,0x00000000}},	//   _runa_, слив, _ﺘﺼﻌﻴ, --, 
   {{0x6d4186ac,0x290586ad,0x290000c5,0x3b80ea10}},	//   suna, _suna_, _riia_, злыг, 
   {{0x2900007d,0x26d807d6,0x67240223,0x64980241}},	//   _siia_, xoro_, _rwij, _jíir, 
   {{0x26d986ae,0x6d4186af,0x29040113,0x6724045f}},	//   voro_, quna, _quna_, _swij, 
   {{0x26d986b0,0x290586b1,0x27e00204,0x09e408b0}},	//   woro_, _vuna_, _pyin_, _қойн, 
   {{0x290186b2,0x00000000,0x00000000,0x00000000}},	//   _viia_, --, --, --, 
   {{0x6cd00372,0x290586b3,0xfb180375,0x25f40401}},	//   _اقچا, _tuna_, _עוצמ, ंधली_, 
   {{0x26d986b4,0x290586b5,0x290186b6,0xe9d001d5}},	//   roro_, _uuna_, _tiia_, _بغش_, 
   {{0x26d986b7,0x67240cf9,0x27e00217,0xb87906e2}},	//   soro_, _twij, _tyin_, plía, 
   {{0x26d986b8,0x6724020c,0x27e0022e,0xc7951375}},	// [29020] poro_, _uwij, _uyin_, _ыркы, 
   {{0x26d986b9,0x00000000,0x00000000,0x00000000}},	//   qoro_, --, --, --, 
   {{0x1108acdc,0x04c8e540,0xb878007b,0x85040214}},	//   لغني_, _مودي_, ilín, _دوجن, 
   {{0xb9ec0201,0xb8780332,0x00000000,0x00000000}},	//   _ነዉ_, hlín, --, --, 
   {{0xb87802fb,0xef1c0166,0x9f340816,0xd3343671}},	//   klín, _çül_, целі, _мэры, 
   {{0xb2040408,0xf770011a,0x00000000,0x00000000}},	//   _герз_, פקו_, --, --, 
   {{0x9d1800f7,0xb879066d,0x9cf4003b,0x00000000}},	//   шойт_, dlín, озкі, --, 
   {{0x5c9986ba,0xef140b8d,0x6c800131,0xbc4808e1}},	//   ркия_, шмә_, كلىم, учке_, 
   {{0xf53002d3,0xb878032e,0x00000000,0x00000000}},	//   _ክውንነ, flín, --, --, 
   {{0x3f500368,0x0e4801ec,0xdb1c01e1,0xb87808a5}},	//   mâu_, _ەكەۋ_, _òyíg, glín, 
   {{0x81d40c58,0xed5586bb,0xfbd00ef4,0x3f50c92b}},	//   াইক_, _гох_, _کتا_, lâu_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa524031c,0x9ab40055,0xb87801e7,0xdb000112}},	//   _འཆུག_, _evāṃ, blín, tzmä, 
   {{0xb878021c,0x7d0186bc,0x6d4c0210,0x00000000}},	//   clín, _hios, łkań, --, 
   {{0x27ec012d,0x3f50c92b,0xc0300092,0x00000000}},	//   ędna_, hâu_, ጠቀሰው, --, 
   {{0x7d000851,0x9418dd3c,0xd13000d1,0x00000000}},	//   _jios, ржат_, ېما_, --, 
   {{0x7d0186bd,0xb878007b,0x00000000,0x00000000}},	// [29030] _mios, llío, --, --, 
   {{0xf8bd86be,0x7d007e9f,0x00000000,0x00000000}},	//   lié_, _lios, --, --, 
   {{0x712448cd,0xb8780332,0x00000000,0x00000000}},	//   صرال, nlío, --, --, 
   {{0x92680831,0x7d001aac,0xf8bc06af,0x3f500042}},	//   ырға_, _nios, nié_, fâu_, 
   {{0xa34405f5,0x3f500142,0xb87801e7,0x00000000}},	//   _нэрл, gâu_, hlío, --, 
   {{0x518401e0,0x3f800010,0x00000000,0x00000000}},	//   _һуға, _škuc_, --, --, 
   {{0x202408e7,0xcc8986bf,0xb878022a,0x20dc03b2}},	//   ùriò_, ибке_, vlín, ríir_, 
   {{0x51840fc0,0xb87801e7,0x7d006cb4,0x00000000}},	//   _луға, dlío, _cios, --, 
   {{0x7d0186c0,0xf8bc20ef,0x96000154,0x9ab400b8}},	//   _dios, dié_, ্রিম_, _svāṃ, 
   {{0xcc884a23,0xf0b00014,0xee78009f,0x9e350831}},	//   انکه_, _بیچھ, _حصرت_, _неуч, 
   {{0xf8bc0231,0x7d000876,0x88c848f2,0xb87986c1}},	//   fié_, _fios, илов_, rlín, 
   {{0x7d0186c2,0x2d5006ed,0xdd9800f7,0xf8bc004a}},	//   _gios, mãe_, _ушу_, gié_, 
   {{0xb87986c3,0x2cbc003a,0x20180213,0x6e0001e2}},	//   plín, miud_, _əri_, _بېګن, 
   {{0x2cbc0098,0x59d4033f,0x96b80452,0xb87800ae}},	//   liud_, _ठुकर, бусу_, blío, 
   {{0xf8bc004e,0x00000000,0x00000000,0x00000000}},	//   bié_, --, --, --, 
   {{0x032586c4,0xf8bd86c5,0x37dc00fe,0x00000000}},	//   ждан, cié_, নেধৰ, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [29040] --, --, --, --, 
   {{0x82180276,0x36c0005b,0xd3a400d1,0xc17800d8}},	//   рцат_, _обыг, члуқ, исец_, 
   {{0x37dc0183,0x2cbc0254,0x2d9001e3,0x9f5801e1}},	//   নেদৰ, kiud_, äxel_, _ńrà_, 
   {{0xddc85e64,0x3fe40251,0x3f500042,0x412801f3}},	//   _nadš, ожев, tâu_, _ስነልቦ, 
   {{0xbe88075b,0xf8b0025f,0x7d0000c6,0x00000000}},	//   иске_, ושא_, _rios, --, 
   {{0x7d0186c6,0x3da586c7,0x3f5003cb,0x00000000}},	//   _sios, жриб, râu_, --, 
   {{0x7d00068f,0x00000000,0x00000000,0x00000000}},	//   _pios, --, --, --, 
   {{0x7c6586c8,0xc21401e1,0xacf00472,0x00000000}},	//   زابل, _ẹ̀bì, وسيت, --, 
   {{0xf8bc928e,0x81d42b1b,0x7d00009f,0x2b4001c6}},	//   vié_, াইও_, _vios, мээг, 
   {{0x7d0186c9,0x7f4001a9,0x2bb4007b,0xb87800ae}},	//   _wios, mroq, غاية_, tlío, 
   {{0xf8bd86ca,0x7d000784,0xf2d008a8,0xd9140eed}},	//   tié_, _tios, ועז_, ядны, 
   {{0xbb841b4d,0xb8780597,0x7d18035a,0xec1000cf}},	//   _ولاي, rlío, _itts, _قومد, 
   {{0xf8bd86cb,0x960003d4,0x7f4001a9,0xb8780332}},	//   rié_, ্ৰাম_, nroq, slío, 
   {{0xf8a82c04,0xf8bd86cc,0xf9883b89,0x00000000}},	//   ادگه_, sié_, _نخبه_, --, 
   {{0xf8bd86cd,0xe81c0882,0x7f40003a,0x00000000}},	//   pié_, _भ्वा_, hroq, --, 
   {{0x7f40022e,0x00000000,0x00000000,0x00000000}},	//   kroq, --, --, --, 
   {{0x32040419,0x7f40022e,0x00000000,0x00000000}},	// [29050] žnym_, jroq, --, --, 
   {{0x7d180857,0xb8780332,0x71e40108,0x00000000}},	//   _otts, ilím, оцеж, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x26c401f1,0xef1c1ea0,0x00000000,0x00000000}},	//   émov_, _çük_, --, --, 
   {{0x8e8586ce,0xddc80313,0xb4d46236,0x7d187209}},	//   згле, _radš, ाकी_, _atts, 
   {{0xb8780118,0x81d40154,0x00000000,0x00000000}},	//   dlím, াইজ_, --, --, 
   {{0x2cbc00a3,0x00000000,0x00000000,0x00000000}},	//   tiud_, --, --, --, 
   {{0x2718012c,0x7f404879,0x8fd00075,0x2d500124}},	//   něný_, broq, _пәлә, rãe_, 
   {{0x7f40a09e,0xdb140241,0xb87802d2,0x00000000}},	//   croq, _àbìd, glím, --, 
   {{0x4aa800cf,0xb4d4190c,0x00000000,0x00000000}},	//   скон_, ाकु_, --, --, 
   {{0xd01800a2,0x8d78007b,0x00000000,0x00000000}},	//   _sońy_, _دماء_, --, --, 
   {{0x290586cf,0x61e80fac,0xefc80092,0x6d4002d0}},	//   öma_, _ødle, _ጠሰድ_, mrna, 
   {{0x27180118,0x6d4002d0,0x320400d7,0x00000000}},	//   děný_, lrna, ľnyj_, --, 
   {{0x6d4186d0,0x247801f2,0xf1a8043e,0x00000000}},	//   orna, _ọm_, चनान, --, 
   {{0xb4d4121d,0x00000000,0x00000000,0x00000000}},	//   ाकू_, --, --, --, 
   {{0x7f4001d5,0xd00400ec,0x00000000,0x00000000}},	//   yroq, _لڄ_, --, --, 
   {{0x6f180223,0x38c80753,0x6d40581c,0x00000000}},	// [29060] _ntuc, _داوی_, hrna, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6f1802d1,0x8064b576,0x6d400113,0x408400cf}},	//   _atuc, звеж, jrna, зулб, 
   {{0x7f414a86,0x6d4186d1,0x261800c5,0x00000000}},	//   troq, drna, बुरी_, --, 
   {{0x443186d2,0x6d4186d3,0xcfa80691,0xf41c01e3}},	//   may_, erna, ياهم_, _knän_, 
   {{0x7f4186d4,0x443186d5,0x9f44036e,0xb87800e4}},	//   rroq, lay_, _hymë_, poíg, 
   {{0x7f400561,0x8cec00b8,0x00000000,0x00000000}},	//   sroq, _ṣaḍg, --, --, 
   {{0x443186d6,0x7f4186d7,0x338c01e1,0xb87800d7}},	//   nay_, proq, _aáṣé, tlím, 
   {{0x6d4186d8,0x1af400fb,0x7f4001a9,0xdb080432}},	//   arna, мпия, qroq, _ölüp, 
   {{0x443186d9,0xfa89868c,0x6d4186da,0xfec8cae0}},	//   hay_, ссий_, brna, _ابرو_, 
   {{0xb87986db,0x6da06584,0xaa380092,0x7d1802d0}},	//   slím, _пифа, _በአምላ, _utts, 
   {{0x443186dc,0xb87986dd,0x70340023,0x00000000}},	//   jay_, mlík, _ከምዚኦ, --, 
   {{0x443186de,0x271800bc,0xe78401af,0xb87803b2}},	//   day_, věný_, нуро, llík, 
   {{0x44300076,0x64ac06be,0x00000000,0x00000000}},	//   eay_, mşiy, --, --, 
   {{0x44303ff0,0x27180118,0xb8781d0e,0x00000000}},	//   fay_, těný_, nlík, --, 
   {{0xb4d409d9,0x998c00bc,0xed740092,0x00000000}},	//   ाके_, ladů_, _በክብር_, --, 
   {{0x819402d3,0x57f40354,0x285800c6,0x6d400219}},	// [29070] ዘይብሉ_, _юпит, _رؤية_, zrna, 
   {{0x44300280,0x6d400b88,0x6754007b,0x00000000}},	//   aay_, yrna, _أخير, --, 
   {{0x44305cba,0x4614036b,0xb87802fb,0x6f180c18}},	//   bay_, _توپر, jlík, _stuc, 
   {{0x443186df,0x3ebc0227,0x6d417bc0,0xb878219b}},	//   cay_, _amtt_, vrna, dlík, 
   {{0xdea4ff22,0x6d4003cb,0x00000000,0x00000000}},	//   کیلی, wrna, --, --, 
   {{0x6d4008ad,0xb87986e0,0x7fb47b8f,0x560000eb}},	//   trna, flík, ظهور_, ্রীক_, 
   {{0x3ebc0051,0x00000000,0x00000000,0x00000000}},	//   _dmtt_, --, --, --, 
   {{0xdb0006af,0xb328031c,0xb4b81d94,0x00000000}},	//   lymè, _སྦོང_, _अगो_, --, 
   {{0x8f54034c,0x657c02fb,0xfccc0023,0xdef80092}},	//   _زناش, zvrh, _ብጌጋ_, _ሊገኝ_, 
   {{0x443186e1,0xb87986e2,0x7e680113,0xa2c00073}},	//   zay_, blík, cefp, ळोप्, 
   {{0x443186e3,0xa3e42efd,0x7bcc0112,0xb87802f0}},	//   yay_, _पुन_, ßbur, clík, 
   {{0x44300d62,0xb4d402f8,0x34c400cd,0x00000000}},	//   xay_, ाको_, रचोद, --, 
   {{0x610d0a1d,0xb4d400bc,0x7bcc0bbc,0x00000000}},	//   _işle, ाकै_, şbur, --, 
   {{0x4430181d,0xb3280327,0x00000000,0x00000000}},	//   way_, _སྦེང_, --, --, 
   {{0x443186e4,0x88c400c6,0x84e400d4,0x00000000}},	//   tay_, _يتعل, довж, --, 
   {{0xef1c00a2,0x69cc0205,0x00000000,0x00000000}},	//   _çüw_, şces, --, --, 
   {{0x68e586e5,0x443186e6,0x7e680334,0x00000000}},	// [29080] _ikid, ray_, yefp, --, 
   {{0x443186d9,0xdebc1772,0x850401e2,0x00000000}},	//   say_, ታቱን_, _ښودن, --, 
   {{0x443186e7,0x00000000,0x00000000,0x00000000}},	//   pay_, --, --, --, 
   {{0x443186e8,0xbfc4b850,0xb8780306,0xc6240154}},	//   qay_, мбек, vlík, _বাটা_, 
   {{0x68e4009f,0x3ebc0051,0xd71c00cc,0x00000000}},	//   _mkid, _pmtt_, _তিৱা_, --, 
   {{0xb87802fb,0x63a400f1,0xb7d80375,0x41280212}},	//   tlík, myin, חקני, _мого_, 
   {{0x63a586e9,0x68e586ea,0x21380841,0x7e680205}},	//   lyin, _okid, _uvrh_, refp, 
   {{0x63a40a81,0x629c9769,0xb878041e,0x68e40a1d}},	//   oyin, _horo, rlík, _nkid, 
   {{0xdb0186eb,0x00000000,0x00000000,0x00000000}},	//   lymé, --, --, --, 
   {{0x68e586ec,0x610c7bfb,0x629d86ed,0x63a40086}},	//   _akid, _eşle, _joro, iyin, 
   {{0x63a586ee,0x28c0146b,0x00000000,0x00000000}},	//   hyin, शोभि, --, --, 
   {{0x63a586ef,0x629d86f0,0xa9c000d6,0x3b080261}},	//   kyin, _loro, тськ, _дедо_, 
   {{0x63a586f1,0x629c01f5,0x998c00bc,0xd7c8032f}},	//   jyin, _ooro, padů_, سوسه_, 
   {{0x63a586f2,0x68e586f3,0xeb940640,0xb4d44f3c}},	//   dyin, _ekid, _циљ_, ाक्_, 
   {{0x63a44fd4,0x25780276,0xf77000f1,0xe5c400d4}},	//   eyin, мбрь_, راڼ_, всто, 
   {{0x63a586f4,0x629c0810,0x56400023,0x00000000}},	//   fyin, _aoro, _ንዝኽእ, --, 
   {{0x63a4013b,0x629d86f5,0xb864141b,0xdedc0023}},	// [29090] gyin, _boro, _فاکو, _ሕጊን_, 
   {{0x55740120,0xe2f801ec,0x00000000,0x00000000}},	//   _згот, деуі_, --, --, 
   {{0x610c4a4a,0x63a517b5,0xa84801d3,0xdb0001d3}},	//   _oğlu, ayin, _علیم_, gymé, 
   {{0x63a586f6,0x629d86f7,0x45f80375,0x4fd586f8}},	//   byin, _eoro, _מהתג, нжет, 
   {{0x629c657a,0x63a40223,0xa1340133,0x00000000}},	//   _foro, cyin, فرۆش, --, 
   {{0x6d4403cd,0xbf100244,0x00000000,0x00000000}},	//   _åjak, دووب, --, --, 
   {{0x61140006,0x7bc40bcd,0x00000000,0x00000000}},	//   _адсу, úkun, --, --, 
   {{0x95380020,0x8b94005b,0xa3e401f9,0x00000000}},	//   _እውነተ, ероч, _पुड_, --, 
   {{0x629d86f9,0xd6a00150,0xc6240154,0x3c600139}},	//   _yoro, _ﺍﻀﻁﺭ_, _বাঘা_, укыг, 
   {{0x629c56d7,0xdfd40022,0x5f740244,0x00000000}},	//   _xoro, _роуы, _جافر, --, 
   {{0x6298023a,0x63a40007,0x5d54010a,0x00000000}},	//   övoi, zyin, _акхт, --, 
   {{0x63a586fa,0x7d780375,0xfb1400e5,0x00000000}},	//   yyin, _מנעו, بقیع_, --, 
   {{0xb9900228,0x1cb80244,0x00000000,0x00000000}},	//   _ەلىب, _تالب_, --, --, 
   {{0x770003e6,0x63a58151,0xdb140241,0xb87801e7}},	//   ێژین, vyin, _àbád, toíc, 
   {{0x629d86fb,0x68e40327,0x997401ee,0xf3f40208}},	//   _roro, _tkid, _ауыш, ệng_, 
   {{0x68e42d2b,0x63a586fc,0x00000000,0x00000000}},	//   _ukid, tyin, --, --, 
   {{0xc7a4033a,0x3d14000d,0x00000000,0x00000000}},	// [290a0] _чипк, _पूने_, --, --, 
   {{0x63a4a0b0,0x629d86fd,0x4ee00154,0x35d8012d}},	//   ryin, _qoro, যগুল, _मुक़, 
   {{0x629d86fe,0x1fa807f7,0x63a46af6,0x00000000}},	//   _voro, कन्ड, syin, --, 
   {{0x629d86ff,0x63a58700,0xdd9000e5,0x00000000}},	//   _woro, pyin, یڈا_, --, 
   {{0x5314136b,0x3fc40214,0x63a40477,0xe8900092}},	//   _афсу, رگری_, qyin, _እየሰጡ_, 
   {{0x629c0857,0x00000000,0x00000000,0x00000000}},	//   _uoro, --, --, --, 
   {{0xa3e40037,0xb87803b2,0x5154010a,0x7164030d}},	//   _पुत_, mlív, _итту, _парг_, 
   {{0xb8780162,0x00000000,0x00000000,0x00000000}},	//   llív, --, --, --, 
   {{0x7ac4eb89,0xbbc808e6,0x00000000,0x00000000}},	//   есне, ापेक, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7e7808cd,0x35d80456,0x39400100,0xdb00002f}},	//   _hatp, _मुग़, čks_, lzmü, 
   {{0x28c0ff88,0xfaa51eaa,0x7e780162,0xe9340133}},	//   शोधि, _падо, _katp, وسێت_, 
   {{0x91d8000d,0x00000000,0x00000000,0x00000000}},	//   _बुझई, --, --, --, 
   {{0x7e798701,0x1db021b8,0x00000000,0x00000000}},	//   _matp, जनित, --, --, 
   {{0x7e78020b,0x00000000,0x00000000,0x00000000}},	//   _latp, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [290b0] --, --, --, --, 
   {{0x7e78098d,0x644800da,0xe374026f,0x1db021b8}},	//   _natp, _ēdie, ылуы, जनात, 
   {{0x3ce40e04,0x00000000,0x00000000,0x00000000}},	//   _okov_, --, --, --, 
   {{0xc5f10b71,0x83501c3b,0x21c8035b,0xe3b000e5}},	//   _כדי_, _چھلا, хыуп_, جرہ_, 
   {{0x7e7801e4,0xce9402e8,0x15f8012d,0x00000000}},	//   _batp, кадъ, ंधकर_, --, 
   {{0x7e790639,0xfe418702,0xbbc80073,0xe3e401ec}},	//   _catp, аншо, ापैक, _сөсқ, 
   {{0x7e780cf9,0x691400da,0x2cac003e,0x0d7400ee}},	//   _datp, _aģen, _plgd_, тыля, 
   {{0x4c8472fb,0x4fc007d2,0xaa100124,0x00000000}},	//   тлив, _پەتە, hẽte, --, 
   {{0x513c0150,0xed540fc0,0xdfd40139,0x610c0432}},	//   _ءﺗﺎﻥ_, фоқ_, _боты, _işla, 
   {{0x89a858f0,0x9f058703,0x2054010a,0x00000000}},	//   дков_, _موقو, _ӳтĕр, --, 
   {{0x9aa400f2,0x20b801f9,0x00000000,0x00000000}},	//   امپو, _आतमध, --, --, 
   {{0x87f801c0,0xdd040356,0x07a41180,0x00000000}},	//   дэгт_, ăpăd, вамн, --, 
   {{0xaa6001e0,0x490401d5,0x7e7800dc,0x00000000}},	//   _белһ, _یوتق, _yatp, --, 
   {{0xbb402424,0xfaa18704,0x5ba802d5,0x2d380092}},	//   _тешк, _вашо, _якім_, _አይኖረ, 
   {{0xe908025c,0xb87803b2,0x00000000,0x00000000}},	//   _གཤིབ_, vlív, --, --, 
   {{0xbd0001a8,0x70d80073,0xd52c01e1,0x00000000}},	//   _þétt, यकोल, _sọ́t, --, 
   {{0xb8780162,0xeb9c03b2,0xb46000d8,0x00000000}},	// [290c0] tlív, øøh_, јкул, --, 
   {{0xb220d4d0,0x610c00fd,0xb87800d8,0x9694005b}},	//   имул, _aşla, noín, _брюш, 
   {{0x7e798705,0xb8780174,0x00000000,0x00000000}},	//   _ratp, rlív, --, --, 
   {{0x7e798706,0xb8780252,0x00000000,0x00000000}},	//   _satp, slív, --, --, 
   {{0x7e781c06,0xb8798707,0xf3e40150,0x256c01e1}},	//   _patp, plív, _ақтқ_, bòlò_, 
   {{0x3ce58708,0xa3040724,0xb87801ed,0x610c0139}},	//   _skov_, _сүзе, llít, _eşla, 
   {{0x3cdcec91,0x7e7801bf,0xaa1000e4,0x11d400d4}},	//   खवले_, _vatp, hẽse, _бітр, 
   {{0x7e78116c,0x6c800075,0x5c743529,0xb87801ed}},	//   _watp, للىم, улит, nlít, 
   {{0x7e798709,0xbbd003e6,0x3fe40148,0xb87800ae}},	//   _tatp, جڕاک, _ржав, ilít, 
   {{0x26c400cf,0x999806ed,0xb87801ef,0x00000000}},	//   èmol_, екот_, hlít, --, 
   {{0xa3e41d24,0xef1c45d8,0xaa100022,0x00000000}},	//   _पुस_, _çür_, vẽte, --, 
   {{0x7b640137,0x610c00a2,0xeb300228,0xb87800e5}},	//   _атке, _yşla, _چىند, jlít, 
   {{0xeb3000db,0xa77400c0,0x35d8012d,0xb878013a}},	//   _نىند, аляч, _मुज़, dlít, 
   {{0xb87802d2,0x00000000,0x00000000,0x00000000}},	//   elít, --, --, --, 
   {{0xaa401fbe,0x00000000,0x00000000,0x00000000}},	//   _тејл, --, --, --, 
   {{0xe8f80798,0xe8f40116,0x5ac80244,0x00000000}},	//   _илј_, _پسىخ, _تاڵێ_, --, 
   {{0x93f5870a,0xb87801e7,0x00000000,0x00000000}},	// [290d0] упац, loío, --, --, 
   {{0xf1a4399f,0x70d88153,0x00000000,0x00000000}},	//   крен, यक्ल, --, --, 
   {{0xd011870b,0x3074001f,0x3204023a,0xdb0000e4}},	//   ملا_, _በምግብ_, äny_, jymí, 
   {{0xf1c002d5,0x30a40801,0xa1580640,0x904400f2}},	//   _rašė_, ързв, ђачу_, انشه, 
   {{0xb8785a8b,0x395c01ab,0x00000000,0x00000000}},	//   llís, htts_, --, --, 
   {{0x4df462d9,0x999c01d3,0xaa1000c7,0x6298007c}},	//   ляйт, _levő_, hẽre, övot, 
   {{0xa195870c,0x21a4059f,0xb87800c7,0x00000000}},	//   _карч, _киём, voín, --, 
   {{0xb878007b,0x0cd0015b,0xd138074d,0x00000000}},	//   ilís, াত্ত, ăхĕ_, --, 
   {{0x4fd4023a,0x00000000,0x00000000,0x00000000}},	//   _сжат, --, --, --, 
   {{0xb87802ea,0x00000000,0x00000000,0x00000000}},	//   klís, --, --, --, 
   {{0x0904094f,0xb87802f0,0x00000000,0x00000000}},	//   лпон, jlís, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x395c014b,0xcb680006,0x28c00b67,0x00000000}},	//   atts_, _чале_, शोषि, --, 
   {{0x1bb8764c,0x07a40032,0x443c045f,0xb89001ec}},	//   _جامع_, _ҡайн, _śt_, _ۇلىع, 
   {{0xba5004b3,0x04446584,0x2b5c0356,0x44f80006}},	//   _انىع, левн, ltuc_, ехаў_, 
   {{0x261800c5,0x63840818,0x88340153,0x00000000}},	//   बुजी_, аҳма, _сэкц, --, 
   {{0x2b5c0208,0xa96401b9,0xd3a401ec,0xb87802d2}},	// [290e0] ntuc_, _чиқа_, алтқ, alís, 
   {{0xb8780122,0x25740075,0x67246011,0x00000000}},	//   slít, _پۇرس, _itij, --, 
   {{0x86c4021a,0x67241710,0xb87800d8,0x79580166}},	//   _ليکن, _htij, clís, _iäwç, 
   {{0xb9fc001f,0x247800db,0xdb0000c7,0xb9d82829}},	//   _ሀያ_, _جەرج_, vymí, _አያ_, 
   {{0xbea4d3a6,0xde580953,0x64a40022,0x5f95870d}},	//   ладк, валі_, _баҟа, рилт, 
   {{0x23600218,0xd36c02dd,0x70440eff,0x395c1876}},	//   mtij_, _تۇك_, _ەرلە, ytts_, 
   {{0xddd801d3,0x98fc01e4,0xd174064e,0x71a021f3}},	//   tevő, ltĉe, _кыты, _ларз, 
   {{0x2481870e,0xc5c4009e,0xc0e46537,0x00000000}},	//   ndim_, _এডাপ, _собк, --, 
   {{0x67240223,0x1bd400a8,0x248000c6,0xe1f40d0b}},	//   _ntij, ропя, idim_, _अरुण_, 
   {{0x5a355212,0xee3402d5,0x2481870f,0xdb0000e4}},	//   шнот, _бнф_, hdim_, pymí, 
   {{0xddc83ad4,0x67258710,0x24800724,0xda7001d9}},	//   _hadž, _atij, kdim_, مُک_, 
   {{0xddc800c0,0x00000000,0x00000000,0x00000000}},	//   _kadž, --, --, --, 
   {{0xa3e405d7,0x24818711,0x2b5c01a6,0x999c01d3}},	//   _पुल_, ddim_, ctuc_, _vevő_, 
   {{0xddc9083f,0xeb9400ee,0xe610007b,0x610c0356}},	//   _madž, _щич_, كشف_, _oşlo, 
   {{0x67245ccf,0x0a8800db,0xf3980023,0x00000000}},	//   _etij, _جئنى_, ለፍናዮ_, --, 
   {{0xd7c80244,0x680c00de,0xb8798712,0x00000000}},	//   _لوعه_, _bēdī, rlís, --, 
   {{0xddc805a1,0x925803b7,0x236001f5,0x3d14000d}},	// [290f0] _nadž, каат_, gtij_, _पूसे_, 
   {{0x15fc000d,0x00000000,0x00000000,0x00000000}},	//   _एरपर_, --, --, --, 
   {{0x2480011f,0xc690011a,0x00000000,0x00000000}},	//   bdim_, _ואי_, --, --, 
   {{0x2480399d,0x6298000d,0x2d88013a,0x00000000}},	//   cdim_, övor, _čce_, --, 
   {{0xe3f800ec,0x0eb8008e,0xea1001e1,0x00000000}},	//   _موٽڻ_, кукы_, _ọ̀lẹ, --, 
   {{0x8d742620,0x9f058713,0xa3d406ed,0x9e640212}},	//   لابا, مونو, _ѓорч, йвід, 
   {{0x630401ec,0x91c400c7,0x82c4030d,0x00000000}},	//   _اۋلە, _тәал, _тарç, --, 
   {{0x0b444f20,0x00000000,0x00000000,0x00000000}},	//   анин, --, --, --, 
   {{0xddc80171,0xb87800ae,0x00000000,0x00000000}},	//   _gadž, roíl, --, --, 
   {{0x4aa80137,0x00000000,0x00000000,0x00000000}},	//   ткон_, --, --, --, 
   {{0x9f04006c,0x67258714,0xec300ec9,0x24804a0f}},	//   _اولو, _stij, _هواگ, ydim_, 
   {{0x9c589dc7,0x5fdc37cc,0x00000000,0x00000000}},	//   _مجهز_, _मखमल, --, --, 
   {{0x24818715,0xa3e4448b,0x864c0240,0x00000000}},	//   vdim_, _पुं_, _ንምክት, --, 
   {{0x23600211,0x49b80127,0x5c04009d,0x00000000}},	//   vtij_, _لابد_, _уяха, --, 
   {{0x95280156,0x24818716,0x6aa0007b,0x6684006c}},	//   ལེཊི_, tdim_, _ionf, لیکل, 
   {{0x07a46523,0x543401c6,0x6aa18717,0x00000000}},	//   _ваин, йхуу, _honf, --, 
   {{0x24816071,0x29040014,0x25f80073,0x5f080950}},	// [29100] rdim_, _پژھِ, _एरवी_, िगम्_, 
   {{0x23611515,0x24818718,0x6aa18719,0x733005a9}},	//   rtij_, sdim_, _jonf, تىكا, 
   {{0x6aa1871a,0x2361871b,0xddc80cf4,0x98fc01e4}},	//   _monf, stij_, _sadž, stĉe, 
   {{0x24814543,0x9f44011f,0x7cfc036e,0xf41c007c}},	//   qdim_, _aymá_, mërg, _snäv_, 
   {{0x4421871c,0x6aa00204,0x753800e2,0x00000000}},	//   _ifk_, _oonf, ņuzt, --, 
   {{0x6aa1871d,0x442003d4,0xddc8591d,0xd36c0150}},	//   _nonf, _hfk_, _vadž, _سۇم_, 
   {{0x4420022f,0x6d4c00b8,0x00000000,0x00000000}},	//   _kfk_, _ācac, --, --, 
   {{0x6aa0078c,0x5c14015b,0x4420045a,0x7b640395}},	//   _aonf, সর্গ_, _jfk_, атое, 
   {{0x6aa1871e,0x3d14068f,0x2ee400e3,0x4421871f}},	//   _bonf, _पूरे_, bonf_, _mfk_, 
   {{0xfaa58720,0x2ee401ab,0xf1e8032c,0x6bd01a02}},	//   ршин, conf_, _जुड़_, تتىر, 
   {{0x44218721,0x3f8410d8,0x6448005f,0xdb0001ed}},	//   _ofk_, lvou_, _ēdin, gymá, 
   {{0x44200fac,0x3f8402f0,0x7cfc0200,0x00000000}},	//   _nfk_, ovou_, dërg, --, 
   {{0x7c218722,0xfbd18723,0x6aa001e1,0x7cfc0200}},	//   _ifor, _بتا_, _fonf, tërf, 
   {{0x44218724,0x195800ee,0x7c200175,0x387c0e04}},	//   _afk_, _бакы_, _hfor, žur_, 
   {{0x7c21399f,0x4a3001f1,0xda781c5c,0xddc80210}},	//   _kfor, äčší_, _аяқ_, _nadż, 
   {{0x44200789,0x7c20025c,0x6b9400d8,0x3f840419}},	//   _cfk_, _jfor, _àagê, kvou_, 
   {{0x8afc038e,0x7cfc02d3,0x7c218725,0x4420c990}},	// [29110] stře, përf, _mfor, _dfk_, 
   {{0x44200093,0x7988035a,0xa6c40150,0x3f8400d0}},	//   _efk_, _krfw, _وقيى, dvou_, 
   {{0xe1f048c1,0x7c218726,0x91880184,0x442033b8}},	//   وسم_, _ofor, ыраҡ_, _ffk_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa34400cf,0xb4e021bd,0x8f6800ae,0x00000000}},	//   _мэрл, धवी_, امتك_, --, 
   {{0x7c218727,0x9e3c01f1,0x3ea0036b,0xbea028f6}},	//   _afor, _poďa, зишг, зашк, 
   {{0x4c684e90,0x6aa03d8b,0xddc80034,0x7c200332}},	//   гийн_, _ronf, _gadż, _bfor, 
   {{0x6aa00115,0xef90030f,0x20c4004e,0x00000000}},	//   _sonf, _ویاد, _дсуг, --, 
   {{0x13f40574,0x6aa02b76,0x79880142,0x7c200200}},	//   _आरोह_, _ponf, _arfw, _dfor, 
   {{0x7c218728,0x3988044e,0x6204002d,0x6aa00166}},	//   _efor, ንግስቲ_, _útlê, _qonf, 
   {{0x7c200cfd,0x09e4036b,0xfaec004b,0x7cfc0036}},	//   _ffor, сонн, رګه_, fërd, 
   {{0x7c200175,0x6aa18729,0xfdf40375,0x00000000}},	//   _gfor, _wonf, _הצעת_, --, 
   {{0x6aa1872a,0x00000000,0x00000000,0x00000000}},	//   _tonf, --, --, --, 
   {{0xf6207a9c,0x26c844fb,0x2d8401bf,0x7c20013a}},	//   здро, рғон_, ovne_, _zfor, 
   {{0x3f8402fb,0xdb000112,0x7c2003cb,0x7cfc036e}},	//   zvou_, tzmö, _yfor, bërd, 
   {{0xfd54063f,0x2d8400af,0x589400c7,0x1ae401ec}},	//   _albọ, ivne_, _дшьу, _ﺍﳌﺸﺮ, 
   {{0x2901872b,0x6b981709,0x090401ed,0x802400d1}},	// [29120] _ihia_, nxug, _پڑھی_, ەرتم, 
   {{0x27e0005a,0x7cfc036e,0xe16411e6,0x3f840175}},	//   _ixin_, përg, يگزي, vvou_, 
   {{0x29000652,0xaca00248,0x3a3800c5,0x44200fac}},	//   _khia_, _amọj, _õppe_, _tfk_, 
   {{0xa2b40490,0x3f85872c,0x6b8801f4,0xb8780022}},	//   _इतक्, tvou_, _orgg, voík, 
   {{0x3f840286,0x2d8421e3,0xdfd005d9,0x1e140d4b}},	//   uvou_, evne_, ڻيڪ_, омля, 
   {{0x7c21872d,0x3f85872e,0x26d800b5,0xdd9400db}},	//   _sfor, rvou_, nnro_, жакы, 
   {{0x2901872f,0x6da0147e,0x609801ed,0x7c200112}},	//   _ohia_, зија, _پچاس_, _pfor, 
   {{0xc0d58730,0x2900016b,0x7c200175,0x752001c7}},	//   _ايرب, _nhia_, _qfor, _énze, 
   {{0x6b98009a,0x7cfc0023,0x27e00200,0x00000000}},	//   gxug, jëre, _nxin_, --, 
   {{0x29018731,0x91e400b5,0x7f40022e,0x6e4003c5}},	//   _ahia_, _mmのd, msoq, _неуз, 
   {{0x2900007b,0x7f400393,0x7c2029b3,0x38b8036e}},	//   _bhia_, lsoq, _tfor, _lëre_, 
   {{0x290007ae,0x7c2039c2,0xed4d8732,0x6b980077}},	//   _chia_, _ufor, _سپه_, bxug, 
   {{0x29018733,0x7d198734,0x77902a60,0x7f418735}},	//   _dhia_, _huts, سیدا, nsoq, 
   {{0x7d198736,0x7f400af5,0x2900013b,0x79980227}},	//   _kuts, isoq, _ehia_, pxtw, 
   {{0x7d198737,0x7cfc0240,0x6a10106b,0x38b80393}},	//   _juts, përd, _عبور, _aëre_, 
   {{0x7d198738,0x38b88a64,0x7cfc0023,0x2d44010e}},	//   _muts, _bëre_, bëre, _ỳeke_, 
   {{0x7d198739,0xd9d000d1,0x7a400118,0xdb00010e}},	// [29130] _luts, _رەڭگ, cítí, gymç, 
   {{0x7d19873a,0x00000000,0x00000000,0x00000000}},	//   _outs, --, --, --, 
   {{0x7d19873b,0x7f40003a,0x9474085b,0x00000000}},	//   _nuts, esoq, _وگرا, --, 
   {{0xdb0001f4,0x00000000,0x00000000,0x00000000}},	//   lymä, --, --, --, 
   {{0x7d19873c,0x00000000,0x00000000,0x00000000}},	//   _auts, --, --, --, 
   {{0x7d19873d,0x6b88037e,0xdb0001f4,0x20d40116}},	//   _buts, _rrgg, nymä, يقەس, 
   {{0x7f400eda,0x0d991d0f,0x7cfc036e,0xd1b00244}},	//   asoq, ртлы_, dërb, _تیاک, 
   {{0x7d19873e,0x2fdc01d4,0x2d848e70,0x6b98009d}},	//   _duts, _txug_, rvne_, txug, 
   {{0x290075ca,0x7d1801c0,0xdb00023a,0x4fc00131}},	//   _rhia_, _euts, kymä, _تەشە, 
   {{0x7d1813c4,0x2901873f,0xdb0001f4,0x00000000}},	//   _futs, _shia_, jymä, --, 
   {{0x7d18f790,0x6ce402bf,0xe80c08e9,0x29018740}},	//   _guts, _ліде, सेना_, _phia_, 
   {{0x29000b89,0x6f198741,0x7cfc0240,0x4ea450e5}},	//   _qhia_, _kuuc, tëre, _урға, 
   {{0x6d40ee60,0x61300100,0x61400241,0x07f801c6}},	//   lsna, _kòlò, _kálá, рхны_, 
   {{0x6f198742,0x290002b1,0x614001e1,0x3a8401d9}},	//   _muuc, _whia_, _jálá, _وُنہ, 
   {{0x6d418743,0x29018744,0x6f198745,0x6130007f}},	//   nsna, _thia_, _luuc, _mòlò, 
   {{0x6d400cc0,0x613002e2,0x29004f67,0x27e0005a}},	//   isna, _lòlò, _uhia_, _txin_, 
   {{0x42c905e0,0x6f180014,0x6d4002d0,0x38c802f2}},	// [29140] аган_, _nuuc, hsna, _خاوی_, 
   {{0x6d400bc9,0x610c41b5,0x6d4c0055,0x00000000}},	//   ksna, _işli, _ācan, --, 
   {{0x38b800e8,0x998c033f,0xd90c0244,0x00000000}},	//   _wëre_, wadź_, _جیێ_, --, 
   {{0x7d198746,0x6d418747,0x6f1800b5,0x7f400869}},	//   _ruts, dsna, _buuc, tsoq, 
   {{0x4430b1de,0x61405ebf,0x7d198748,0x6130007f}},	//   mby_, _bálá, _suts, _bòlò, 
   {{0x7d198749,0x7f400af5,0x6f18022f,0x2580143a}},	//   _puts, rsoq, _duuc, _gålå_, 
   {{0x4431874a,0x7d180869,0x6d41874b,0x7f41581c}},	//   oby_, _quts, gsna, ssoq, 
   {{0x5c9806bb,0x7d18bf6b,0xed4c32db,0x00000000}},	//   ския_, _vuts, کھے_, --, 
   {{0x7d19874c,0x61400241,0x6d4008c2,0x7cfc0200}},	//   _wuts, _fálá, asna, tërb, 
   {{0x44303c36,0x6d40013a,0xee3426b1,0xca2c0150}},	//   hby_, bsna, _мну_, _ﺩﯨﺮ_, 
   {{0x44300034,0x6f1801c7,0x00000000,0x00000000}},	//   kby_, _zuuc, --, --, 
   {{0x4431874d,0xedd00150,0x6f180175,0x38b80200}},	//   jby_, _تيمد, _yuuc, _sërb_, 
   {{0x4430c514,0x7cfc02d3,0xdb0002f6,0xe7840fc0}},	//   dby_, përb, tymä, муро, 
   {{0x7d00014b,0xdea80c09,0x443001a4,0x0ba800cf}},	//   _hhos, _ƙoƙa, eby_, _دامى_, 
   {{0x7d01874e,0x610c70f7,0xa3d016da,0x4430fdbd}},	//   _khos, _eşli, _वेब_, fby_, 
   {{0x2eb43f55,0x7d00b50d,0xdb00023a,0x5fbc190c}},	//   _अत्त, _jhos, symä, ्छाल, 
   {{0x7d0005b8,0xdb000108,0x00000000,0x00000000}},	// [29150] _mhos, pymä, --, --, 
   {{0xa6c8021a,0x6d41874f,0xda7801f1,0xe8b80327}},	//   _وويل_, ysna, neď_, _བཞོག, 
   {{0x6140c00f,0x7d000022,0x6d408ce1,0x98ac03b9}},	//   _rálá, _ohos, xsna, ltdı_, 
   {{0xd478008f,0x7d00031c,0x6f198750,0x44305f0b}},	//   _פאָל, _nhos, _puuc, cby_, 
   {{0x9ac4031c,0x614001e7,0x6d4002d0,0x00000000}},	//   _keċċ, _pálá, wsna, --, 
   {{0x6d418751,0x7d018752,0x3d1402ab,0x9ac4025c}},	//   tsna, _ahos, _पंखे_, _jeċċ, 
   {{0x7d018753,0xdea40330,0xf8bc0de2,0x614001d3}},	//   _bhos, بیلی, khé_, _válá, 
   {{0x6d418754,0x7d018755,0x6f18002e,0xa3d0044b}},	//   rsna, _chos, _tuuc, _वेड_, 
   {{0x6d418756,0xf8bc0502,0x61400ca8,0x00000000}},	//   ssna, dhé_, _tálá, --, 
   {{0x7d000488,0x44302b57,0x9ac40327,0x7cfc0200}},	//   _ehos, zby_, _neċċ, tërc, 
   {{0x44306b4d,0x7d000fa3,0xf8bc1682,0x6d400054}},	//   yby_, _fhos, fhé_, qsna, 
   {{0x957c02d3,0x7d018757,0x4430045a,0x645800e5}},	//   ሕነትን_, _ghos, xby_, őviz, 
   {{0x443003c6,0x0a9401f4,0x00000000,0x00000000}},	//   vby_, _надю, --, --, 
   {{0x443002ea,0x7cfc0240,0xf8bc00e4,0x2cbc047e}},	//   wby_, përc, ahé_, lhud_, 
   {{0x44318758,0xf8bc00ae,0x00000000,0x00000000}},	//   tby_, bhé_, --, --, 
   {{0x03244fe8,0x7d018759,0x4430012c,0xc3240dbe}},	//   здан, _xhos, uby_, змак, 
   {{0x421800c6,0x5ef000cd,0x86780064,0x00000000}},	// [29160] مزاج_, ेतम्_, _лёну_, --, 
   {{0xb8782815,0x86c40592,0x9e3c00d0,0xc56468eb}},	//   gníf, _ريجن, _poďm, _екок, 
   {{0x7cfc0023,0x2cbc00b5,0x9f9401ef,0x00000000}},	//   hëra, khud_, _vžít_, --, 
   {{0x3da4013e,0x7cfc2568,0xa494072d,0x00000000}},	//   ҷриб, këra, _تیرت, --, 
   {{0x2cbc079b,0x7d005129,0x7cfc0023,0x00000000}},	//   dhud_, _rhos, jëra, --, 
   {{0x7d01875a,0x33f80375,0x2cbc0810,0x9f9400bc}},	//   _shos, _להכנ, ehud_, _užít_, 
   {{0xda780038,0xc0d412fc,0x52b000db,0x9e3c01ef}},	//   veď_, _فيسب, _جەلئ, _hoďk, 
   {{0x7d000113,0x7c640131,0xa3e00073,0x00000000}},	//   _qhos, سابل, _तशा_, --, 
   {{0x7cfc0694,0xbd880014,0xe7e8000d,0x00000000}},	//   gëra, _گنان_, _टँगा_, --, 
   {{0x7d00ea67,0x760401d3,0x00000000,0x00000000}},	//   _whos, nézé, --, --, 
   {{0x7d01875b,0x38b8003a,0xf8bd875c,0xbd884319}},	//   _thos, _aëra_, thé_, _دنان_, 
   {{0x7d01875d,0x38b80023,0xf8bc012c,0x3154010f}},	//   _uhos, _bëra_, uhé_, היטן_, 
   {{0xec10075e,0x36480023,0x00000000,0x00000000}},	//   _كومد, _ንምግማ, --, --, 
   {{0x8d1801ec,0xf8bc557b,0xa3d00073,0x95700023}},	//   _ازەر_, shé_, _वेध_, _ብጾቱን_, 
   {{0x6594a3ea,0xf8bc97e9,0xcaa40f13,0x344800fd}},	//   нару, phé_, _تصني, йчан_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa3d008ec,0xb879875e,0xd37000c6,0x9ac4031c}},	// [29170] _वेद_, eníg, ضها_, _teċċ, 
   {{0x337c0023,0xd250a970,0x00000000,0x00000000}},	//   _ብክልተ_, ئنا_, --, --, 
   {{0x38b80240,0x6f0002d2,0x5194009f,0xb4b001af}},	//   _zëra_, _líbý, بلاذ, _зинә, 
   {{0xd0100075,0x4fc000d1,0x00000000,0x00000000}},	//   نلا_, نەزە, --, --, 
   {{0x158802dd,0x3d1402ab,0xb87800d8,0x8e84c89d}},	//   _ءﺗﺎﯕ, _पंजे_, loís, дгле, 
   {{0xd22800ae,0x00000000,0x00000000,0x00000000}},	//   _ذكره_, --, --, --, 
   {{0xb145875f,0x00000000,0x00000000,0x00000000}},	//   _ریشم_, --, --, --, 
   {{0xb8780077,0x7cfc036e,0x00000000,0x00000000}},	//   alíz, tëra, --, --, 
   {{0xb87802f0,0x2cbc7fff,0x00000000,0x00000000}},	//   blíz, rhud_, --, --, 
   {{0x94fc1e81,0x3f80145e,0x7cfc036e,0x3ca001ec}},	//   _དེའི_, _âkua_, rëra, _ﺃﻗﺼﻰ_, 
   {{0x8afc0118,0x7cfc0200,0x20c400cd,0x00000000}},	//   střo, sëra, लोकध, --, 
   {{0x38b800b0,0xd1e4001f,0x7cfc036e,0x00000000}},	//   _përa_, ዛኞቹ_, përa, --, 
   {{0x9b958760,0x32cc012d,0x00000000,0x00000000}},	//   _пицц, eżym_, --, --, 
   {{0xcb0800ec,0x00000000,0x00000000,0x00000000}},	//   _بيتن_, --, --, --, 
   {{0xd57435dd,0xb8780332,0x5ef000cd,0x00000000}},	//   нуть, fníd, ेतत्_, --, 
   {{0x634c001f,0x38b98761,0x38c800f1,0xe8b80327}},	//   _እርግጠ, _tëra_, _وايی_, _བཞིག, 
   {{0x4ae00cb2,0xb87801e7,0x00000000,0x00000000}},	// [29180] _पदाव, roít, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4084967a,0x806413f3,0x00000000,0x00000000}},	//   дулб, двеж, --, --, 
   {{0xb03000d1,0x00000000,0x00000000,0x00000000}},	//   نىمغ, --, --, --, 
   {{0x64447801,0xf8c802d2,0xb03000d3,0x00000000}},	//   maii, _hnéð_, тніш, --, 
   {{0x67003be5,0x64458762,0x10080a11,0x998c0118}},	//   ोगिक_, laii, ستنى_, vadž_, 
   {{0x615446c6,0xdd9042f4,0x2dc0b071,0x00000000}},	//   _سچائ, اوب_, ﺭﺍﻳﻤ, --, 
   {{0x64458763,0xb8780ba1,0x00000000,0x00000000}},	//   naii, oníe, --, --, 
   {{0x64440093,0xfe704ea7,0x7cd80327,0x26e400cc}},	//   iaii, _لدا_, nċri, _গঠনো_, 
   {{0x64458764,0x998c05be,0x00000000,0x00000000}},	//   haii, radž_, --, --, 
   {{0x64458765,0x6c8000dd,0x32540302,0xfc2800f5}},	//   kaii, رلیم, וסים_, _джек_, 
   {{0x7cfc02d3,0x26c40200,0x00000000,0x00000000}},	//   mëro, ëmon_, --, --, 
   {{0x6444004c,0xb9240ca8,0x7cfc0200,0x00000000}},	//   daii, _yatọ_, lëro, --, 
   {{0xe9cd622e,0x644401ab,0xabf8011a,0x00000000}},	//   اغی_, eaii, _והדר, --, 
   {{0x64444894,0x6d4c00cd,0x38c81188,0x58d4014b}},	//   faii, _ācak, _муин_, _покт, 
   {{0xb4f858c1,0x6444f4d4,0xb8780332,0x00000000}},	//   ्षेप_, gaii, roís, --, 
   {{0x3d142aa1,0xb4ac0490,0x28dc1fad,0x569400d8}},	// [29190] _पूछे_, _कवी_, मचरि, _запт, 
   {{0xb8780789,0xa6f400c7,0x76441c3b,0xc0c004a9}},	//   coír, _изыш, _زیرِ_, қәси, 
   {{0x7cfc0023,0x90544a03,0x00000000,0x00000000}},	//   jëro, евец, --, --, 
   {{0xe80d8766,0xe3b000dd,0xa3d01a22,0x656801ab}},	//   सेवा_, درہ_, _वेव_, àdhe, 
   {{0x7cfc0240,0xdb00005c,0x8eb800db,0x4e2857c6}},	//   tërn, bymø, зыйт_, полн_, 
   {{0xb8780561,0x9f0400f1,0xdcf4002b,0x998c0064}},	//   nníb, نونو, _ābād, nadų_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7cfc044e,0x998c00c0,0x00000000,0x00000000}},	//   përn, kadų_, --, --, 
   {{0x64440472,0x7cfc0240,0x3ebc0208,0x25f00d79}},	//   zaii, bëro, _gltt_, _इडली_, 
   {{0x6ca58767,0x7e7c00c5,0x64440099,0x7cfc0200}},	//   _ордж, õppe, yaii, cëro, 
   {{0x7b040579,0xaf7002d3,0x7af801f4,0x00000000}},	//   yðug, _ኩላትና_, altt, --, 
   {{0x6444006f,0x00000000,0x00000000,0x00000000}},	//   vaii, --, --, --, 
   {{0xa3d0e079,0x09e4229d,0x64442278,0xc6900050}},	//   _वेष_, _полн, waii, دِس_, 
   {{0x64458768,0xe8e0004d,0x7ae400e5,0x00000000}},	//   taii, _ngủi_, ékte, --, 
   {{0x03a40107,0x9974010a,0x00000000,0x00000000}},	//   нибо, _рушш, --, --, 
   {{0x68e58769,0x4255876a,0x7cfc036e,0xa3d0098a}},	// [291a0] _ijid, етет, zëro, _वेश_, 
   {{0x644426bb,0xb3804990,0xa304008e,0x458400f3}},	//   saii, ылул, түге, _згов, 
   {{0x6444166a,0xdb000158,0x044401f4,0x00000000}},	//   paii, rymø, _пенн, --, 
   {{0x03a4b280,0xb878012c,0x6444009a,0x5a0c008f}},	//   _зимо, mníc, qaii, קלאַ, 
   {{0xb8780316,0xe28400d1,0x9f8401d5,0x00000000}},	//   lníc, _иған, ъҳад, --, 
   {{0x7cfc044e,0x63a4bc84,0x0f3400a8,0xed3000e5}},	//   tëro, mxin, тэця, گوٹھ, 
   {{0x629d876b,0xb87800bc,0x27ec012d,0x00000000}},	//   _inro, nníc, ędny_, --, 
   {{0x68e5876c,0x63a4031c,0x5058004e,0x00000000}},	//   _njid, oxin, _ошуя_, --, 
   {{0x63a4f3da,0x69080077,0x9af800b8,0x2b4001c0}},	//   nxin, iñed, _apāṇ, лээг, 
   {{0x68e4299d,0x63a5876d,0x2bb4007b,0x7cfc0200}},	//   _ajid, ixin, عاية_, përo, 
   {{0x7cfc044e,0xb8780308,0x3948020c,0x7f7801ec}},	//   qëro, jníc, ébs_, _ﺃﻫل_, 
   {{0xb87803c6,0x8d554671,0xa9c0003b,0x00000000}},	//   dníc, _штуч, уськ, --, 
   {{0xe80c10f7,0x629d876e,0x60c00472,0xa3d010eb}},	//   सेला_, _onro, _mlmm, _वेल_, 
   {{0x68e402e3,0x195800db,0x00000000,0x00000000}},	//   _ejid, _жакы_, --, --, 
   {{0x63a400e8,0x60c00857,0xa96400d8,0x998c0064}},	//   exin, _olmm, _зија_, radų_, 
   {{0x629d876f,0x200401a9,0x68e4036e,0xd75802c9}},	//   _anro, _ozmi_, _gjid, _قلبت_, 
   {{0x63a4021a,0x09d400bd,0xd0180165,0x395d15c1}},	// [291b0] gxin, _সুপা, _hańv_, luts_, 
   {{0xb5f0005e,0xa3d005ba,0xb878031d,0x60c002d0}},	//   _бүгі, _वेळ_, bníc, _almm, 
   {{0x395d8770,0x20058771,0x76458772,0xb878e4dc}},	//   nuts_, _azmi_, majy, cníc, 
   {{0x629d8773,0x7cfc01c7,0x6918054e,0x92e00011}},	//   _enro, fërm, _nţel, দতে_, 
   {{0xf41c0139,0xa0c416ac,0x63a40051,0x00000000}},	//   _igä_, دينو, cxin, --, 
   {{0x5370206f,0xb9002b88,0xdcb80115,0x76458774}},	//   _ስርዓት_, _ཨམ_, _buĉo_, najy, 
   {{0x09d4015b,0x395c01e6,0x7cfc036e,0x00000000}},	//   _সুনা, juts_, përl, --, 
   {{0x76458775,0x395c067c,0x00000000,0x00000000}},	//   hajy, duts_, --, --, 
   {{0xb8780232,0x76440796,0xe0e407d6,0x629c002d}},	//   zníc, kajy, _сўро, _ynro, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x09e58776,0x395c19c6,0x3c2800e4,0x76443258}},	//   тонн, guts_, _ỹve_, dajy, 
   {{0xf41c0053,0xb8780e96,0x63a40051,0x00000000}},	//   _ngä_, vníc, yxin, --, 
   {{0x3e6003a0,0xa3d00034,0x77800276,0x63a49b59}},	//   _uōtí_, _वें_, аляз, xxin, 
   {{0xf41d8777,0xb87803c6,0x395d80b9,0x2cac05ac}},	//   _agä_, tníc, buts_, _hogd_, 
   {{0x68e4020c,0xb6a18778,0x395d8779,0x00000000}},	//   _tjid, ширл, cuts_, --, 
   {{0xb8780232,0x63a419bb,0x9e3c02f0,0x00000000}},	//   rníc, txin, _hoďt, --, 
   {{0x46e87724,0xb8780122,0x76440230,0x93580229}},	// [291c0] _один_, sníc, bajy, ерху_, 
   {{0x63a5877a,0x2a640140,0xb878219b,0x41b401af}},	//   rxin, _jcnb_, pníc, ксет, 
   {{0x26d9877b,0x672402f6,0x63a4009a,0x629c0051}},	//   miro_, _huij, sxin, _vnro, 
   {{0x26d9877c,0x6725877d,0x7050182c,0x680801e1}},	//   liro_, _kuij, لنما, _gèjí, 
   {{0x2481877e,0xdcb801e4,0x7cfc036e,0x8afc013a}},	//   meim_, _suĉo_, bërj, atři, 
   {{0x26d80537,0x6725877f,0x24818780,0x629d8781}},	//   niro_, _muij, leim_, _unro, 
   {{0x71a18782,0x7cfc0023,0x6724f842,0x26d80083}},	//   _карз, sërm, _luij, iiro_, 
   {{0x26d98783,0x764401aa,0x7cfc044e,0x67258784}},	//   hiro_, zajy, përm, _ouij, 
   {{0x26d98785,0x2004098d,0xfe458786,0x9e742002}},	//   kiro_, _uzmi_, _анзо, _مۇشت, 
   {{0x395d8787,0x26d98788,0xb4dc0882,0xbb680075}},	//   tuts_, jiro_, _तद्_, _ﻳﻪﻧﻪ_, 
   {{0x26d98789,0x2480b93c,0x3c64004e,0x7c84010a}},	//   diro_, keim_, _акег, _ауле, 
   {{0x26d93bd7,0x672401a4,0x61fc03cd,0x2b5c0067}},	//   eiro_, _buij, _myrl, buuc_, 
   {{0x67243836,0x26d9878a,0x2481878b,0x7644aa21}},	//   _cuij, firo_, deim_, tajy, 
   {{0x26d9878c,0x6724282c,0x7cfc0240,0x395d878d}},	//   giro_, _duij, kërk, puts_, 
   {{0x25b80354,0x3a2c04cc,0xa5f9878e,0x7645878f}},	//   gyrl_, _iffp_, веру_, rajy, 
   {{0x656801c3,0xf8c40037,0x00000000,0x00000000}},	//   àdha, _लतिय, --, --, 
   {{0x80a40118,0x00000000,0x00000000,0x00000000}},	// [291d0] छाने, --, --, --, 
   {{0x26d84c99,0x75818790,0x537802d3,0x61fd8791}},	//   ciro_, _پیرم, _ከካይድ_, _byrl, 
   {{0x672401f5,0x61fc0042,0x9e3c01ef,0xf608010a}},	//   _zuij, _cyrl, _loďs, _юхий_, 
   {{0x61fc1600,0xdb0002f0,0x418401ec,0x00000000}},	//   _dyrl, vymý, ытуғ, --, 
   {{0x8afc012c,0x7cfc0200,0x9f400bcd,0xf204012d}},	//   stři, përj, æið_, वेज़_, 
   {{0x62341b6b,0x61fd8792,0x9e64003b,0x00000000}},	//   _веру, _fyrl, ивід, --, 
   {{0x61fc0432,0xa1840166,0xadc000fb,0x22841887}},	//   _gyrl, _кытл, райһ, _туяг, 
   {{0x7d7400c6,0x4b880cdd,0x26d98793,0x4c854da4}},	//   امير_, ейин_, ziro_, улив, 
   {{0x26d98794,0x9f04bd96,0x9e3c00d0,0x3ce400d7}},	//   yiro_, _چوقو, _poďt, _djov_, 
   {{0x2b5c01d9,0x672401f5,0xc9a8005b,0x26d8022e}},	//   ruuc_, _ruij, евое_, xiro_, 
   {{0x67240399,0xc84400ee,0x7ae401d3,0x2d800241}},	//   _suij, ленй, ékta, _èje_, 
   {{0x26d98795,0x672523f1,0x00000000,0x00000000}},	//   wiro_, _puij, --, --, 
   {{0x26d98796,0x1cb80502,0x67258797,0x00000000}},	//   tiro_, _جالب_, _quij, --, 
   {{0xd018030a,0x672401f5,0x256c00e4,0x00000000}},	//   _hańs_, _vuij, tÿl_, --, 
   {{0x26d87752,0xb8780077,0x00000000,0x00000000}},	//   riro_, snía, --, --, 
   {{0x26d98798,0x6724023a,0x66d40213,0x93c4004d}},	//   siro_, _tuij, _mükə, _trắ, 
   {{0x24818799,0x61fd879a,0xf794bbd6,0x00000000}},	// [291e0] reim_, _syrl, _منيب_, --, 
   {{0xd018030a,0x7cfc0240,0x832000c7,0x61fc349b}},	//   _lańs_, tërk, _ҳҿаҧ, _pyrl, 
   {{0x3ab800c8,0x28a80c4c,0xb87801e7,0x741000e5}},	//   עמענ, गापि, inín, لوہا, 
   {{0xbfc48abc,0x00000000,0x00000000,0x00000000}},	//   лбек, --, --, --, 
   {{0xb87801ef,0x00000000,0x00000000,0x00000000}},	//   knín, --, --, --, 
   {{0x7cfc0023,0x3ce404ce,0x442028b5,0xa30425a2}},	//   mëri, _sjov_, _hgk_, _түзе, 
   {{0x44200263,0x72c00640,0x7cfc0240,0xdb000210}},	//   _kgk_, _убрз, lëri, zymó, 
   {{0x44202a1f,0x717001d5,0xfba8005b,0x00000000}},	//   _jgk_, _دهفا, етой_, --, 
   {{0x28a849f1,0x7cfc02d3,0x44200205,0x00000000}},	//   गानि, nëri, _mgk_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfe44016c,0x4420030a,0x7cfc0240,0xed54014b}},	//   _анҷо, _ogk_, hëri, _бох_, 
   {{0x44210e35,0x7cfc044e,0x38b80de2,0x752000d5}},	//   _ngk_, këri, _këri_, _énzi, 
   {{0x7c21879b,0x7cfc02d3,0x9ab400b8,0x1cb40327}},	//   _igor, jëri, _etāṃ, _ཝྭར_, 
   {{0x4421879c,0x64480129,0x38b80200,0x7cfc0200}},	//   _agk_, _œdip, _mëri_, dëri, 
   {{0x7c21879d,0x9ae80372,0x4421879e,0xc5240116}},	//   _kgor, _كىچك_, _bgk_, иятқ, 
   {{0x442006d1,0x7c20b516,0x5fc44c5b,0x57b44979}},	//   _cgk_, _jgor, वनाल, _вбит, 
   {{0x7c20009f,0xf8bc020c,0x7cfc0240,0xbec01bce}},	// [291f0] _mgor, mké_, gëri, _ñëwu, 
   {{0xf8bc0316,0x3f84007f,0x00000000,0x00000000}},	//   lké_, dwou_, --, --, 
   {{0x7c21879f,0xb8780597,0xe730136e,0x7cfc0200}},	//   _ogor, nnío, _وصی_, përh, 
   {{0x7c200c6a,0xf8bd87a0,0x38b987a1,0x7cfc0023}},	//   _ngor, nké_, _bëri_, bëri, 
   {{0xb87800c6,0x0ed8033f,0xa8580375,0x7cfc036e}},	//   hnío, _भगदड, רידה_, cëri, 
   {{0x7c2187a2,0xf8bd8665,0xa92400bc,0x00000000}},	//   _agor, hké_, _ježí, --, 
   {{0xf8bc67fc,0x38b80023,0x3c280588,0x28a800cd}},	//   kké_, _tërh_, _ỹva_, गामि, 
   {{0x0c24328e,0xa9240118,0x00000000,0x00000000}},	//   шмин, _leží, --, --, 
   {{0xf8bc0122,0xada0825e,0x7988035a,0x6da187a3}},	//   dké_, рақл, _asfw, риқа, 
   {{0x7c2187a4,0x4a440fbe,0x66d40213,0x34b00073}},	//   _egor, шнов, _tükə, ीसुद, 
   {{0xaca002e3,0x38b802d3,0x7cfc02d3,0x798803ac}},	//   _agụm, _zëri_, zëri, _csfw, 
   {{0xf3fc0589,0xf8bc0438,0xb8780332,0x39c001e1}},	//   _oyã_, gké_, snín, _ọsà_, 
   {{0x2d8400d2,0xa92400d7,0xb51c0037,0x00000000}},	//   lwne_, _beží, _मंजय_, --, 
   {{0x7c2187a5,0x442187a6,0xf8bc00f2,0xa3d0a4cd}},	//   _zgor, _sgk_, aké_, _वेग_, 
   {{0x4420070d,0x55c4054a,0xb878007b,0xf8bc02f0}},	//   _pgk_, барғ, cnío, bké_, 
   {{0xf8bcf057,0x7cfc02d3,0xddd800f3,0xc4840063}},	//   cké_, tëri, nevš, јлак, 
   {{0xc2451cc4,0x8674084c,0x44212049,0x7b040d12}},	// [29200] инак, _кынц, _vgk_, iðun, 
   {{0xb6d002dd,0x7cfc0de2,0x2cbc0254,0x00000000}},	//   _وقيع, rëri, hkud_, --, 
   {{0x4420001f,0x7cfc0023,0xc0d40092,0x86c41fae}},	//   _tgk_, sëri, _ይሻል_, _ميکن, 
   {{0x7cfc069c,0xddd80841,0x44200477,0x3f84017a}},	//   përi, jevš, _ugk_, twou_, 
   {{0x7cfc044e,0xddd80316,0xd1740220,0x2d855bb6}},	//   qëri, devš, _қыры, ewne_, 
   {{0x7c2187a7,0xf8bc012c,0x62980030,0xefb0036b}},	//   _sgor, zké_, ôvod, غیلگ, 
   {{0x38b8002e,0x3f8401c7,0x7b0402d2,0x00000000}},	//   _wëri_, swou_, fðun, --, 
   {{0x2cbc0098,0x38b8036e,0x7cfc036e,0x7b0401a8}},	//   gkud_, _tëri_, hërv, gðun, 
   {{0x81d40116,0x7ae40098,0x7cfc0200,0x00000000}},	//   _соңх, ékto, kërv, --, 
   {{0x7c2000a3,0xf8bc020c,0x798802d0,0x3374011a}},	//   _wgor, wké_, _psfw, סעים_, 
   {{0x7c2187a8,0xa9240306,0xf8bc00f2,0x7cfc036e}},	//   _tgor, _reží, tké_, dërv, 
   {{0xb8641541,0xb8780332,0x7c2187a9,0x09d400eb}},	//   جادو, rnío, _ugor, _সুহা, 
   {{0xf8bd87aa,0xb8dc0a28,0xa2bc0490,0x00000000}},	//   rké_, _इव_, _एवढ्, --, 
   {{0xf8bc0300,0xb8780118,0x00000000,0x00000000}},	//   ské_, mním, --, --, 
   {{0xb87800bc,0x746923a6,0xf8bd87ab,0xa71402dd}},	//   lním, крав_, pké_, імсі, 
   {{0xdcb801e4,0xd7c80133,0x9b480092,0x28a801f9}},	//   _buĉi_, _موعه_, _መሐንዲ, गाणि, 
   {{0x53980c9e,0x7cfc036e,0xb8780118,0x2d84007f}},	// [29210] ывая_, bërv, nním, zwne_, 
   {{0x395c01a4,0x7cfc0023,0x2d84033f,0x36a000db}},	//   orts_, mëru, ywne_, _بەسق, 
   {{0xceb90b47,0x81d8045e,0xb4b004b4,0xb8780332}},	//   қәа_, _ডুব_, _динә, hním, 
   {{0x395c0493,0xf07404a9,0xe0d047ea,0x85980375}},	//   irts_, ридә_, وزن_, _עשרו, 
   {{0xb87802fb,0x395c002f,0x1f6412fa,0x00000000}},	//   jním, hrts_, жкім, --, 
   {{0x8d7587ac,0xb878012c,0xa3d028d4,0x65942bef}},	//   مابا, dním, _वेट_, _اجیر, 
   {{0x3f9802b5,0xa3e8000d,0x0d8401d5,0x00000000}},	//   āpua_, यपथ_, ёлин, --, 
   {{0x38b80694,0x0b44036b,0x7cfc036e,0xcc882dbf}},	//   _këru_, бнин, zërv, убие_, 
   {{0x395d87ad,0x7b0409f3,0x7cfc0240,0xddc801ef}},	//   erts_, rðun, jëru, _ledň, 
   {{0x2cbd87ae,0x8ee40154,0x00000000,0x00000000}},	//   skud_, _পীরগ, --, --, 
   {{0x4dc401e0,0x999c00d7,0x7cfc0200,0x89d401ec}},	//   _ураҡ, _pevš_, vërv, сіпш, 
   {{0x9f400023,0xb87800bc,0x6f000076,0x452802dd}},	//   çiç_, bním, llnc, ғжан_, 
   {{0x395d87af,0x7cfc0240,0xe3c40139,0xe87403e6}},	//   arts_, tërv, _mnıñ_, مۆژگ, 
   {{0x07a40022,0xddc800d7,0x9b053540,0x09b835b6}},	//   _ҳаин, _bedň, _дзід, _مطبع_, 
   {{0x6aa187b0,0x0934f4ef,0xdcb80115,0xa3d00c4c}},	//   _innf, _ارتج, _suĉi_, _वेज_, 
   {{0x75d187b1,0x38b8002e,0x7cfc036e,0x8a600244}},	//   سيقا, _bëru_, bëru, _بێگۆ, 
   {{0x3fe000bd,0x38b80de2,0x7cfc036e,0x00000000}},	// [29220] _বর্ষ, _cëru_, mërt, --, 
   {{0xe3c41248,0x778187b2,0x7cfc0200,0x48f00118}},	//   _anıñ_, _эльз, qërv, ीतको_, 
   {{0xccf80034,0xd9fc0b45,0x25bc01bf,0xc058346d}},	//   koś_, ɓaɓɓ, _ævl_, гіл_, 
   {{0x230800f1,0x37d800fe,0x00000000,0x00000000}},	//   اتړي_, _যঁতৰ, --, --, 
   {{0x4430033f,0x3c2800e4,0x00000000,0x00000000}},	//   mcy_, _ỹvo_, --, --, 
   {{0xb878012c,0x823404fb,0x2b5c004e,0x23600549}},	//   vním, _درحا, druc_, mrij_, 
   {{0x67dc005f,0x44300076,0x00000000,0x00000000}},	//   lājī, ocy_, --, --, 
   {{0x4431243b,0x6aa187b3,0xccf80034,0xb878012c}},	//   ncy_, _annf, goś_, tním, 
   {{0xbfc40372,0x39ac03be,0x28cc9201,0x6c74007b}},	//   _убак, məsi_, ासनि, صحيح_, 
   {{0x39ac03be,0x44fc00fe,0xb87800bc,0xdc3c0118}},	//   ləsi_, ংগিক_, rním, máčk, 
   {{0x395d057e,0xb87802fb,0xdc3c219b,0x6da012b9}},	//   urts_, sním, láčk, _нифа, 
   {{0x6aa187b4,0x236187b5,0xb8782b57,0x7cfc0023}},	//   _ennf, krij_, mník, tëru, 
   {{0xb8780232,0x02f83812,0x4430033f,0xdc3c022a}},	//   lník, ्ताह_, dcy_, náčk, 
   {{0x39ac03be,0x79a4004e,0xac18010a,0x443131f8}},	//   həsi_, _грие, _сачĕ_, ecy_, 
   {{0xb87801f1,0x39ac00ac,0x690805c7,0xdc3c02f0}},	//   nník, kəsi_, oñel, háčk, 
   {{0x2360000f,0x7cfc036e,0xdc3c013a,0x00000000}},	//   frij_, përu, káčk, --, 
   {{0xfa240135,0x7cfc02d3,0x39ac00ac,0x7af987b6}},	// [29230] _རྔོན_, qëru, dəsi_, oott, 
   {{0x7af987b7,0xdc3c02fb,0x3fe00183,0xf1a587b8}},	//   nott, dáčk, _বৰ্ষ, йрен, 
   {{0x39ac00ac,0x320801c0,0xb8780216,0x38b8002e}},	//   fəsi_, ухан_, jník, _wëru_, 
   {{0x443187b9,0xb8780232,0x7af987ba,0x38b8002e}},	//   ccy_, dník, hott, _tëru_, 
   {{0x7af987bb,0x0f3401b9,0xbda80133,0x00000000}},	//   kott, تکزد, ینهۆ_, --, 
   {{0x7af987bc,0xb8e80327,0xbea187bd,0x00000000}},	//   jott, _ཊཾ_, дашк, --, 
   {{0x7af987be,0x64a81682,0x39ac03be,0x7b040aab}},	//   dott, _ḓiim, bəsi_, rðul, 
   {{0x39ac00ac,0xdc3c0306,0xe3c40139,0x00000000}},	//   cəsi_, báčk, _unıñ_, --, 
   {{0x9f05050c,0xb87800bc,0x7af83eb9,0x4e840014}},	//   _کولو, mníh, fott, _ؤرٕ, 
   {{0xb87804bf,0x7cfc0240,0xccf80b67,0xca84009d}},	//   bník, fërs, soś_, цгой, 
   {{0xb87802fb,0x7cfc0240,0x4430033f,0x69180356}},	//   cník, tërt, ycy_, _oţet, 
   {{0xdcb801e4,0xb87800bc,0x7af80108,0x00000000}},	//   _buĉu_, nníh, aott, --, 
   {{0x3ec80153,0x0a94014b,0x00000000,0x00000000}},	//   šutų_, _мадю, --, --, 
   {{0x4430068f,0x23600196,0x39ac00ac,0x6aa033b8}},	//   wcy_, vrij_, zəsi_, _unnf, 
   {{0x443187bf,0x7cfc0240,0x04b41d37,0x39ac00ac}},	//   tcy_, përt, осая, yəsi_, 
   {{0x2258003e,0xb87800bc,0x69080022,0x00000000}},	//   _sdrk_, jníh, oñem, --, 
   {{0xb87803c6,0x290000ec,0xd5ac01d3,0x00000000}},	// [29240] zník, _ikia_, نہی_, --, 
   {{0x4430068f,0xdc3c2b57,0x6aa40073,0x4584041b}},	//   scy_, váčk, _कचोर, _дгов, 
   {{0x39ac03be,0xd17802d5,0x443187c0,0x80a4000d}},	//   təsi_, йсці_, pcy_, छाले, 
   {{0xb87803c6,0x7af800dd,0x6fd806ab,0x290001f7}},	//   vník, zott, _मेहं, _jkia_, 
   {{0x7af987c1,0x39ac03be,0x290001c8,0xadc00241}},	//   yott, rəsi_, _mkia_, _ifẹl, 
   {{0xb8780232,0x7af8011c,0x39ac03be,0x9d180588}},	//   tník, xott, səsi_, әоит_, 
   {{0x7af987c2,0x7cfc02d3,0xb878012c,0x6da014b7}},	//   vott, dërr, bníh, дија, 
   {{0xb8782195,0x39ac00ac,0x19580032,0x00000000}},	//   rník, qəsi_, ҙамы_, --, 
   {{0x7af987c3,0xb8780122,0x386c02d2,0x00000000}},	//   tott, sník, _ögri_, --, 
   {{0x7cfc044e,0x290187c4,0xb87802fb,0x00000000}},	//   tërs, _akia_, pník, --, 
   {{0xd8f802bf,0x2ef400db,0x92b40154,0x212401bf}},	//   йної_, _بىلد_, _জগৎ_, _kimh_, 
   {{0x8308025c,0x7af987c5,0xb87800bc,0xa9c00212}},	//   _ཀེའུ_, sott, diíc, фськ, 
   {{0xdb2400af,0x00000000,0x00000000,0x00000000}},	//   öpäe, --, --, --, 
   {{0x212400a3,0x7cfc036e,0x7af8022f,0xb8780118}},	//   _limh_, përs, qott, zníh, 
   {{0x38b800e8,0x344987c6,0x6595416a,0x0a880137}},	//   _dërr_, ичан_, мару, _دئنى_, 
   {{0x95c87601,0x00000000,0x00000000,0x00000000}},	//   ауға_, --, --, --, 
   {{0x28a8f820,0xba04069c,0xb8780316,0x00000000}},	// [29250] गारि, _ዋላ_, vníh, --, 
   {{0xe784034d,0x212400a3,0xb5f00220,0x2900005a}},	//   _کلیپ, _aimh_, _жүгі, _zkia_, 
   {{0x20040784,0xb8780118,0x662800bc,0x00000000}},	//   _aymi_, tníh, ňské, --, 
   {{0xb3380790,0x45f80375,0x00000000,0x00000000}},	//   _arçe, _להתג, --, --, 
   {{0xb878012c,0x399800de,0x00000000,0x00000000}},	//   rníh, _līs_, --, --, 
   {{0xb87800bc,0x00000000,0x00000000,0x00000000}},	//   sníh, --, --, --, 
   {{0xb87936af,0xceb80116,0xdea401d3,0x30e400d4}},	//   aníi, _қәд_, ظیمی, _діаб, 
   {{0x212401ab,0x31c0009e,0x0b4587c7,0xba1800e8}},	//   _gimh_, ্পদশ, пнин, nu鯵o, 
   {{0x7cfc02d3,0x00000000,0x00000000,0x00000000}},	//   tërr, --, --, --, 
   {{0x290008fb,0x49b81532,0x00000000,0x00000000}},	//   _skia_, ماجد_, --, --, 
   {{0xddc400d8,0x00000000,0x00000000,0x00000000}},	//   _обѕи, --, --, --, 
   {{0xab600220,0x00000000,0x00000000,0x00000000}},	//   _قۇبى, --, --, --, 
   {{0x4ab8009d,0x00000000,0x00000000,0x00000000}},	//   _гуйя_, --, --, --, 
   {{0x6b980230,0x9b000124,0x7cfc0200,0x3ff8010f}},	//   mvug, _иҷыд, qërr, מפרע, 
   {{0x84593ecf,0x35a187c8,0x95980137,0xd5740212}},	//   йрат_, нарг, отту_, муть, 
   {{0xb87800bc,0xd1dc0023,0x7bc406ea,0x00000000}},	//   riíc, ሒነት_, økug, --, 
   {{0x6b9987c9,0x84840023,0x00000000,0x00000000}},	// [29260] nvug, _ምኽርን_, --, --, 
   {{0x74102eac,0x6b98013c,0x00000000,0x00000000}},	//   رولا, ivug, --, --, 
   {{0xdcf404a7,0x200400c7,0x30700023,0x7ae4525e}},	//   _šači, _symi_, _የምጽእ_, ékti, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x64453618,0x14c80073,0x00000000,0x00000000}},	//   mbii, रसरण, --, --, 
   {{0x644587ca,0x8f8001b9,0xcf3800d4,0x00000000}},	//   lbii, ъқул, іччі_, --, 
   {{0x51540058,0x6444208d,0x6b980083,0xb87800bc}},	//   _отту, obii, evug, mnív, 
   {{0x212587cb,0x9c940882,0x200587cc,0x26f80ce0}},	//   _uimh_, _bhāṣ, _tymi_, ंकुर_, 
   {{0x30243159,0x20040113,0x788003b2,0xbfc4004e}},	//   _хоуп_, _uymi_, _lívæ, _эбак, 
   {{0x39ac03e3,0x8ac40588,0x00000000,0x00000000}},	//   kəst_, ҷқәа_, --, --, 
   {{0x6b980869,0xfe080f87,0x9a44001f,0x6f0c002e}},	//   avug, _اقاي_, _የአክሱ, _ëcca, 
   {{0x8ac40124,0x7cfc036e,0x387d5143,0xb87801ef}},	//   зқәа_, përq, ýur_, hnív, 
   {{0xfaa587cd,0x7d0187ce,0x6cc187cf,0x64440009}},	//   _надо, _ikos, _яйца, dbii, 
   {{0x644400ef,0x00000000,0x00000000,0x00000000}},	//   ebii, --, --, --, 
   {{0xd01404c5,0x00000000,0x00000000,0x00000000}},	//   িশয়_, --, --, --, 
   {{0x81b004c5,0x09d40154,0x00000000,0x00000000}},	//   টনা_, _সুকা, --, --, 
   {{0xa3f40220,0x7d0001c8,0xba18002e,0xa4d40212}},	// [29270] епті, _mkos, ru鯵o, хоті, 
   {{0x644587d0,0xf644b3f0,0xf2dc0042,0x66e400f3}},	//   abii, _эхин, _gwâl_, _поња, 
   {{0x7d0187d1,0x64457ff1,0x712400d1,0x94d400c0}},	//   _okos, bbii, سرال, _жонц, 
   {{0xc5f00d65,0xaf5024ce,0x7d0187d2,0x64440009}},	//   _ידי_, ендә, _nkos, cbii, 
   {{0x2268012c,0x00000000,0x00000000,0x00000000}},	//   átké_, --, --, --, 
   {{0x7d0187d3,0xc33000c8,0x00000000,0x00000000}},	//   _akos, _בוך_, --, --, 
   {{0xfe6c04fb,0xd1b00133,0x7cfc036e,0x00000000}},	//   شگل_, _جیاک, tërp, --, 
   {{0x6b9800c5,0xcba57f6e,0xc61800fe,0x00000000}},	//   tvug, даий, তুকা_, --, 
   {{0x6b980140,0x66d147af,0x00000000,0x00000000}},	//   uvug, _häke, --, --, 
   {{0x7d001aac,0x66d0007c,0x6b980254,0x2dd0010a}},	//   _ekos, _käke, rvug, _пре́, 
   {{0x7d0003a0,0xbb2c0075,0x7cfc0240,0x66d04268}},	//   _fkos, ﯨﻨﻰ_, përp, _jäke, 
   {{0x66d00958,0x00000000,0x00000000,0x00000000}},	//   _mäke, --, --, --, 
   {{0x66d0049f,0x59b42be5,0x00000000,0x00000000}},	//   _läke, дөөс, --, --, 
   {{0x69080005,0x4df8008f,0x28cc4c5b,0x7d00013a}},	//   iñei, ַפּא, ासहि, _zkos, 
   {{0x66d0049b,0x69c400b5,0xc4c4691d,0xf41800cc}},	//   _näke, øjed, وترو, _ফ্লৰ_, 
   {{0x64440083,0xaa400116,0x00000000,0x00000000}},	//   ubii, _تۆگى, --, --, 
   {{0x032587d4,0x644587d5,0x07380597,0x00000000}},	// [29280] ддан, rbii, _بسبب_, --, 
   {{0x244c0016,0x6444bf69,0x66d00166,0x2734005b}},	//   ếm_, sbii, _bäke, _iän_, 
   {{0x27340664,0xb8783d5a,0x00000000,0x00000000}},	//   _hän_, rnív, --, --, 
   {{0x27340209,0xb87987d6,0xa0349fbb,0x00000000}},	//   _kän_, snív, رىتت, --, 
   {{0x27340054,0x66d00724,0x8320035b,0xb87801e7}},	//   _jän_, _täkd, _аҿаҧ, mnít, 
   {{0x273404f3,0x7d0187d7,0xb87802f0,0x00000000}},	//   _män_, _skos, lnít, --, 
   {{0x273587d8,0x3d080490,0x66d0007c,0xc0e40212}},	//   _län_, ातले_, _käkb, _жовк, 
   {{0x1ee800f8,0xb87801e7,0x5c74c939,0x00000000}},	//   _کوئی_, nnít, хлит, --, 
   {{0x2734008e,0xb87801e7,0x00000000,0x00000000}},	//   _nän_, inít, --, --, 
   {{0x7f4187d9,0x80d82c35,0xb87801e7,0x00000000}},	//   mpoq, पोरे, hnít, --, 
   {{0xec1001b9,0x7f4001d5,0x7e7c0037,0x7bc40174}},	//   _یومد, lpoq, õppu, økub, 
   {{0x7d00314c,0x2ba43806,0x27340166,0xbb840150}},	//   _ukos, _औपचा, _bän_, _يلاي, 
   {{0xad1804ac,0xb3380261,0x6bd02d8d,0xb8f40c6f}},	//   _וואר, _orça, _لتور, _ित_, 
   {{0x27340724,0x00000000,0x00000000,0x00000000}},	//   _dän_, --, --, --, 
   {{0x7ae400d5,0x00000000,0x00000000,0x00000000}},	//   éktu, --, --, --, 
   {{0x27340724,0xb3382b95,0x66d00267,0x09d403d4}},	//   _fän_, _arça, _räke, _সঁচা, 
   {{0x66d00628,0xbf0cc725,0x2734013d,0xd370007b}},	// [29290] _säke, िताभ_, _gän_, طها_, 
   {{0x66d000b0,0xd0100b38,0x3204033f,0x559400d8}},	//   _päke, ۇلا_, żnym_, _заоѓ, 
   {{0x273401b8,0xd5b187da,0x00000000,0x00000000}},	//   _zän_, _صفح_, --, --, 
   {{0x9014063b,0xd01000c6,0x66d0023a,0xdce80139}},	//   нфлі, هلا_, _väke, _ordı, 
   {{0x8e841e80,0xe8d80bd9,0x6fac0073,0x66d00139}},	//   егле, וואר_, ंमधू, _wäke, 
   {{0x66d00139,0xa0a40352,0x00000000,0x00000000}},	//   _täke, ешәл, --, --, 
   {{0xdce86f30,0x66d00e78,0xe1342fe5,0xa0340050}},	//   _ardı, _häkc, _ансы, رى۪ت, 
   {{0xcd0001ef,0x6e9c0b26,0x00000000,0x00000000}},	//   _ověř_, _गोरु, --, --, 
   {{0x443c00ac,0xca740209,0x8b24a5de,0x4a740124}},	//   _ət_, нуны, ндие, нынт, 
   {{0x75e0022e,0x00000000,0x00000000,0x00000000}},	//   _mеzb, --, --, --, 
   {{0x88e5553f,0x27340139,0x09d40154,0x00000000}},	//   ежне, _sän_, _সুজা, --, 
   {{0x6d4187db,0x273401b8,0x290587dc,0x1dd80073}},	//   mpna, _pän_, ôma_, _भेटत, 
   {{0x35a0036b,0x6d4187dd,0xb87802f0,0x66d0007c}},	//   қатг, lpna, vnít, _räkb, 
   {{0x2734049f,0x6d4001c7,0x8afc0118,0xe1940023}},	//   _vän_, opna, kuři, _ዘጋጥሞ_, 
   {{0x48e587de,0x660401e0,0xb87802f0,0x7bcc0115}},	//   _покв, товҡ, tnít, ŝbut, 
   {{0x273587df,0xd80001f2,0xf6200117,0x7f4001a9}},	//   _tän_, ụsịr, удсо, ypoq, 
   {{0x09d402f5,0x42c8036b,0xb87843ed,0xc328007b}},	// [292a0] _সুচা, пган_, rnít, سكان_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa3bc0d01,0x8064156c,0x66d00166,0xcd000118}},	//   _अथक_, евеж, _täkb, _zvěř_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7050eedd,0xe04400ee,0x6d4002d0,0x1dd8012d}},	//   انها, енҗи, epna, _भेजत, 
   {{0x6d40030d,0x52640014,0x248000d8,0x7f400240}},	//   fpna, _لافٲ, lfim_, rpoq, 
   {{0x657d87e0,0x98fc0115,0x00000000,0x00000000}},	//   ntrh, suĉi, --, --, 
   {{0x2480b3a4,0x705000e3,0x98fc01e4,0x317800df}},	//   nfim_, _منفا, puĉi, _מאלד, 
   {{0xfe7003e6,0x3d90059f,0x1bd40395,0xbe6801c4}},	//   _مدا_, тиқр, топя, _нааж_, 
   {{0xafe000f3,0x00000000,0x00000000,0x00000000}},	//   _соул, --, --, --, 
   {{0x6d4003ac,0x58d421f3,0x0d980108,0xf2d0011a}},	//   cpna, вонт, _отцы_, רעת_, 
   {{0x3ebc7593,0x657c022a,0x00000000,0x00000000}},	//   _hott_, dtrh, --, --, 
   {{0xe78413cf,0x3ebc00c5,0xdce80139,0x248002d2}},	//   луро, _kott_, _urdı, dfim_, 
   {{0x3ebd31aa,0x66d0007c,0x00000000,0x00000000}},	//   _jott_, _räkc, --, --, 
   {{0x39a4006a,0xa3d401d5,0x00000000,0x00000000}},	//   _dësô_, ҳотч, --, --, 
   {{0x3ebc34fe,0xade0007d,0xe5b400fd,0x00000000}},	//   _lott_, _कइसन_, ыйсы, --, 
   {{0xe2c800aa,0xad180302,0x32640b87,0xa3d400db}},	// [292b0] کولو_, לולר, етев, готч, 
   {{0x3ebd87e1,0x78bc0455,0x657c01ef,0x00000000}},	//   _nott_, _hoqv, btrh, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb4b0013d,0x656802f0,0x6594004e,0xf54001c4}},	//   _симә, ádhe, _саюу, _идүү, 
   {{0x3ebd7ebe,0x8eb8004e,0x00000000,0x00000000}},	//   _bott_, дыйт_, --, --, 
   {{0x8d740137,0x3ebc4312,0xaca401ed,0x66d187e2}},	//   نابا, _cott_, کھئے_, _käka, 
   {{0x3ebd87e3,0x6d400175,0x00000000,0x00000000}},	//   _dott_, upna, --, --, 
   {{0x66d0008e,0xac980023,0x00000000,0x00000000}},	//   _mäka, _ቁጽሮም_, --, --, 
   {{0x66d004f3,0x3ebc01c7,0x657c02fb,0x6d404c43}},	//   _läka, _fott_, ztrh, spna, 
   {{0x3ebd87e4,0x6d415dad,0x3a2c04e6,0x20f800d7}},	//   _gott_, ppna, _cgfp_, rčie_, 
   {{0x6f000c8c,0x3a2c054e,0x7ae4007f,0xdef8004e}},	//   monc, _dgfp_, èkta, _чыт_, 
   {{0x48e4529e,0x7ae43386,0x8c180150,0x3a2c045a}},	//   томв, éktr, _قيار_, _egfp_, 
   {{0x78bc0477,0x5bc40346,0x20f801a6,0x7b0401a8}},	//   _doqv, _متوف, lčic_, gðus, 
   {{0x6f0187e5,0x8a052342,0x66d0014a,0xf74187e6}},	//   nonc, _изле, _bäka, реро, 
   {{0x76040945,0xb6a00640,0x20f80010,0xe81401f9}},	//   верг_, јисл, nčic_, _ठरवा_, 
   {{0x6f0007d6,0x03f40154,0x00000000,0x00000000}},	//   honc, _আরবী_, --, --, 
   {{0x6f0187e7,0x68e587e8,0x657d87e9,0x248187ea}},	// [292c0] konc, _imid, strh, rfim_, 
   {{0x6f0187eb,0x66d130fe,0x6908035b,0x00000000}},	//   jonc, _fäka, añet, --, 
   {{0x78bc014f,0x00000000,0x00000000,0x00000000}},	//   _yoqv, --, --, --, 
   {{0x3ebc2b1d,0x00e40801,0x00c80724,0xbfc40137}},	//   _sott_, ъжен, ьлек_, кбек, 
   {{0x6f0020ef,0x68e587ec,0x7b040d12,0x00000000}},	//   fonc, _mmid, iður, --, 
   {{0x324187ed,0xade00037,0x00000000,0x00000000}},	//   _верг, _केहन_, --, --, 
   {{0x68e401e1,0x629c06a3,0x3ebc032e,0x409401ee}},	//   _omid, _iaro, _vott_, _ират, 
   {{0xdb98ca6c,0xee344990,0x00000000,0x00000000}},	//   евич_, ннә_, --, --, 
   {{0x6f0187ee,0xda340108,0x00000000,0x00000000}},	//   bonc, лепы, --, --, 
   {{0x60c187ef,0x68e587f0,0x629d87f1,0x705001ed}},	//   _homm, _amid, _jaro, _منہا, 
   {{0x629d87f2,0xddc8068f,0x5de00183,0x3254011a}},	//   _maro, _wedł, _পুৰু, כסים_, 
   {{0x629d87f3,0x60c187f4,0xcfa800dd,0x7790034c}},	//   _laro, _jomm, _تاہم_, لیبا, 
   {{0x629c01e0,0x60c187f5,0x9aa401e0,0x00000000}},	//   _oaro, _momm, _буйһ, --, 
   {{0x68e41629,0x79a44a2e,0x78bc047e,0x66d00037}},	//   _emid, _арие, _woqv, _päka, 
   {{0x94d4573e,0x75e0022e,0x60c00009,0x00000000}},	//   говц, _bеza, _oomm, --, 
   {{0xf41c006a,0x60c187f6,0xe8f81945,0x798803ac}},	//   _abäa_, _nomm, _үлә_, _ipfw, 
   {{0x629d87f7,0x7b30068f,0x798802d0,0x66d00166}},	// [292d0] _baro, _dług, _hpfw, _wäka, 
   {{0x248c02d3,0xade0007d,0x66d000b0,0x31c51d0b}},	//   _ሕጽረት_, _कइलन_, _täka, ксев, 
   {{0x60c187f8,0x6f0187f9,0xe1f01e95,0xa1580114}},	//   _bomm, vonc, يسم_, ваху_, 
   {{0x60c187fa,0x4fd40046,0x6f00003c,0xf2dc015d}},	//   _comm, лжет, wonc, _stâd_, 
   {{0x629d87fb,0x6f0187fc,0x60c000d4,0x0f346276}},	//   _faro, tonc, _domm, اکرد, 
   {{0x629d87fd,0x60c00073,0xdd0c01e1,0x8e38015e}},	//   _garo, _eomm, _lóńj, رستر_, 
   {{0x7bc4022c,0x60c0025c,0x7b040174,0x00000000}},	//   økun, _fomm, yður, --, 
   {{0x60c187fe,0x6f0187ff,0xe8140073,0x00000000}},	//   _gomm, sonc, _ठरला_, --, 
   {{0x5f9418ce,0x6f000118,0xb80c04fa,0x20dc0115}},	//   _китт, ponc, _सरगम_, aŭis_, 
   {{0x68e58800,0x629d8801,0x4a4569e7,0x6f018802}},	//   _smid, _xaro, ынов, qonc, 
   {{0x60c022a9,0x66d00166,0x9e24129d,0xca480753}},	//   _yomm, _bäkn, _نىكو, ولکه_, 
   {{0xad240014,0xb3380432,0x6fa41524,0x00000000}},	//   _شراو, _arçm, चिपू, --, 
   {{0x2d0c05ba,0x7b041bb0,0x20f82aa9,0x4b7800c8}},	//   ातील_, rður, nčia_, _נאַו, 
   {{0x98b81a14,0xf3f803d4,0xb8780162,0x7b300210}},	//   īrā_, ্ধাৰ_, sníp, _sług, 
   {{0x629d8803,0x798803ac,0x98b81a14,0x20f800d0}},	//   _raro, _gpfw, ūrā_, hčia_, 
   {{0x629d8804,0x47d41216,0x69080407,0x20f80064}},	//   _saro, _ميعر, añer, kčia_, 
   {{0x629d8805,0x60c18806,0xc7a54194,0x20f800d7}},	// [292e0] _paro, _romm, _сипк, jčia_, 
   {{0x629d8807,0x20f800d0,0xd3a40131,0xb7d805d0}},	//   _qaro, dčia_, шлуқ, _נקיי, 
   {{0x60c18808,0x629d8809,0x66d000b0,0x20f80006}},	//   _pomm, _varo, _häko, ečia_, 
   {{0x629d880a,0x48b0015b,0x60c0047e,0xcf7000d1}},	//   _waro, _চতুর, _qomm, ﭼﯘﺭﯗ, 
   {{0x629d880b,0x60c003cd,0x5fb40073,0x00000000}},	//   _taro, _vomm, ंमधल, --, 
   {{0x60c1438f,0x63a5880c,0x629d880d,0xf8bc07ea}},	//   _womm, mvin, _uaro, mmée_, 
   {{0x63a5880e,0xf8bc06af,0x00000000,0x00000000}},	//   lvin, lmée_, --, --, 
   {{0x63a5880f,0x00000000,0x00000000,0x00000000}},	//   ovin, --, --, --, 
   {{0x66d036c4,0x958402d3,0x69080113,0x69c400b5}},	//   _räkn, _ምፍታን_, jñeq, øjen, 
   {{0x63a58810,0x798802d0,0x9cb401d3,0x00000000}},	//   ivin, _ppfw, امکت, --, 
   {{0x7c84094c,0x7dc58811,0x63a58812,0x6bd007d6}},	//   _буле, _حقان, hvin, لتیر, 
   {{0x63a4f5b8,0xed4c04d3,0xb864a32b,0x798803ac}},	//   kvin, _رپه_, دادو, _vpfw, 
   {{0x63a40936,0x3ce40139,0x7bc401f4,0x00000000}},	//   jvin, _imov_, äkud, --, 
   {{0x3ce40211,0x26d8014f,0x00000000,0x00000000}},	//   _hmov_, ghro_, --, --, 
   {{0x58d58813,0xa5f98814,0xf2c51717,0xf48402dd}},	//   _войт, геру_, қсан, луан, 
   {{0x20f80006,0x66d15898,0xaee000b8,0xb8658815}},	//   yčia_, _häkl, _kiṃl, _صابو, 
   {{0x395c11f9,0x63a58816,0x61fc022e,0x26d98817}},	// [292f0] lsts_, gvin, _axrl, bhro_, 
   {{0x66d001e6,0x52140006,0x00000000,0x00000000}},	//   _jäkl, адзт, --, --, 
   {{0x63a58818,0x66d0049f,0xf1a49219,0x8c3d8819}},	//   avin, _mäkl, ыран, ldşe, 
   {{0xb0f00729,0x7e7802d0,0x395d881a,0xa29402dd}},	//   জত্ব_, _actp, ists_, _қасі, 
   {{0xb4c07220,0xa18402dd,0x63a40208,0x69080022}},	//   ्सी_, _қырл, cvin, iñep, 
   {{0x395c0029,0x20f80024,0xfe400107,0xddc800ef}},	//   ksts_, rčia_, оншо, _medņ, 
   {{0x7e7802d0,0x75e0022e,0xe2f801ec,0x752c0210}},	//   _dctp, _mеzo, _сері_, _kicz, 
   {{0xccc5881b,0x8fd00032,0x7654062c,0x999c01ed}},	//   рбий, _мәлә, _lexy, _nevű_, 
   {{0x395d881c,0x753400b5,0x66d0008e,0xa0c4007b}},	//   ests_, _luxz, _bäkl, _ايقو, 
   {{0x752c006d,0x66d00267,0x89a8020f,0xb4c000dc}},	//   _licz, _räko, вков_, ्सु_, 
   {{0x63a41cbd,0x66d001b8,0x69080113,0x395c00e2}},	//   zvin, _säko, wñeq, gsts_, 
   {{0x66d00793,0x63a5881d,0x752c0034,0x2cac03cd}},	//   _päko, yvin, _nicz, _ungd_, 
   {{0x26d9881e,0xdcf40cf4,0x395d64e4,0x2d500356}},	//   thro_, _šaći, asts_, lţe_, 
   {{0x63a4031c,0x20f808a4,0x06740395,0x00000000}},	//   vvin, jčin_, шумя, --, 
   {{0x2d5000a8,0x69080113,0x752c0e10,0x7b300210}},	//   nţe_, sñeq, _bicz, _głub, 
   {{0x9418013f,0x47c402bf,0x04440798,0x24700023}},	//   _ansɑ_, _вбив, реан, _ድኽመት_, 
   {{0x63a5881f,0x752c07de,0x66d00139,0x00000000}},	// [29300] uvin, _dicz, _yäkl, --, 
   {{0x96b80323,0x64a46f78,0xf8bc6953,0x63a58820}},	//   _буюу_, шаға, rmée_, rvin, 
   {{0x752c04cc,0x7b300210,0x00000000,0x00000000}},	//   _ficz, _kłuc, --, --, 
   {{0x7e7802d0,0x98bc0055,0x00000000,0x00000000}},	//   _sctp, _ktvā_, --, --, 
   {{0xff24fb0f,0x7c3c0139,0x00000000,0x00000000}},	//   амдо, _şpro, --, --, 
   {{0x395c1caa,0x752d8821,0x644c033f,0xef1401c0}},	//   ysts_, _zicz, śnię, амч_, 
   {{0x69c404ce,0xb338062c,0x7cfc1d86,0xf650011a}},	//   øjel, _arçh, hīre, חצו_, 
   {{0x225801f5,0x7cfc1d76,0x20f83aba,0xefcc0023}},	//   _herk_, kīre, mčio_, ባኣያ_, 
   {{0x2258225e,0xefcc1ee0,0x20f80153,0x66d00432}},	//   _kerk_, ባባይ_, lčio_, _päkl, 
   {{0x79a58822,0x7ac58823,0x22580f85,0x395c0036}},	//   арме, рсие, _jerk_, tsts_, 
   {{0x20f802d5,0x6da001f4,0x00000000,0x00000000}},	//   nčio_, _мифа, --, --, 
   {{0x76558824,0x395d8825,0x20f80024,0x2f18045f}},	//   _sexy, rsts_, ičio_, rêge_, 
   {{0x66d000a2,0x395c002f,0x00000000,0x00000000}},	//   _täkl, ssts_, --, --, 
   {{0xb8658826,0x20f80024,0xddc800ef,0x00000000}},	//   داگو, kčio_, _vedņ, --, 
   {{0xaa840137,0x6a100150,0x27f006be,0x00000000}},	//   _ئنىم_, _وبىر, _ənnə_, --, 
   {{0x24f98827,0x2ed0078a,0x7b30012d,0x00000000}},	//   ансы_, _थत्त, _głuc, --, 
   {{0xf2dc2776,0x22580209,0x941877f7,0xe3b000c6}},	// [29310] _atâa_, _berk_, ужат_, ورك_, 
   {{0xf1a44e5a,0x2138003e,0xa2b40354,0x00000000}},	//   ирен, _burh_, обуч, --, 
   {{0xba000020,0x28cc03f8,0x20f807f5,0x22591925}},	//   _ልክ_, ासचि, rčin_, _derk_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8fa58828,0x4fa44961,0x7de806be,0x248401e3}},	//   сале, силв, _mәsu, _ömma_, 
   {{0x201800c6,0x22598829,0xcf140154,0xdef40006}},	//   جتمع_, _gerk_, াদ্দ_, опчы, 
   {{0xdea4006c,0x2c10015b,0x00000000,0x00000000}},	//   تیلی, _হলেই_, --, --, 
   {{0xdcf80a28,0x20f80232,0x2d500311,0xe5f80375}},	//   ttvā, nčil_, rţe_, יזור_, 
   {{0x2259882a,0x8618007f,0xfef00451,0x6da001b9}},	//   _yerk_, _rapٍ_, _کڻند, сиқа, 
   {{0x7b300034,0x8fd039c7,0x2b5c054e,0x20f800d7}},	//   _słuc, _мәһә, rsuc_, hčil_, 
   {{0x9f040e26,0x23600399,0x7b30012d,0xbfb000cf}},	//   _بولو, zsij_, _płuc, _وڭۇت, 
   {{0x957c1b49,0xb4c0acda,0x20f80c5e,0x00000000}},	//   ንነትን_, ्सो_, jčil_, --, 
   {{0xcb6886de,0x20f80306,0x32cc0790,0xab6000d1}},	//   _сале_, dčil_, _kıyı_, _بۇخى, 
   {{0x2cbd882b,0x75e0022e,0x0f140154,0x66d0248c}},	//   ljud_, _tеzl, াদকঃ_, _iäkk, 
   {{0x66d01073,0x5edc009e,0x6f0c00e8,0xddc80118}},	//   _häkk, _বদমে, _ëccu, _bedř, 
   {{0x2259882c,0x66d00254,0x00000000,0x00000000}},	//   _serk_, _käkk, --, --, 
   {{0x225808c8,0x60c401f4,0xe940009f,0x00000000}},	// [29320] _perk_, öimm, _انڊپ, --, 
   {{0x66d1882d,0x2cbc00c5,0xbed00150,0x00000000}},	//   _mäkk, hjud_, _ورﺗﺎ, --, 
   {{0x2259882e,0x98b80006,0x20f896c0,0x00000000}},	//   _verk_, ūrą_, učio_, --, 
   {{0x2259882f,0x2cbd8830,0x20f80153,0x75e00139}},	//   _werk_, jjud_, rčio_, _xеzm, 
   {{0x20f80006,0x225902a5,0x787800c8,0x66d025c6}},	//   sčio_, _terk_, אָוו, _näkk, 
   {{0x52758831,0x20f801a6,0x02c401d5,0x00000000}},	//   _мусу, mčim_, _уйго, --, 
   {{0xfd080276,0xed54399f,0x00000000,0x00000000}},	//   лэий_, бој_, --, --, 
   {{0xed24004b,0x6d44025c,0x66d00108,0x00000000}},	//   مړني_, _ħjat, _bäkk, --, 
   {{0x940c0198,0x20f800d7,0x00000000,0x00000000}},	//   ɓoɓi_, nčim_, --, --, 
   {{0xbd4401c8,0x00000000,0x00000000,0x00000000}},	//   _هنئي, --, --, --, 
   {{0xc0f0001f,0xb2b80a7c,0xd8f800d4,0x2cbc007c}},	//   ልጿል_, אמיר, иної_, bjud_, 
   {{0x6cd007d2,0xa2e001e1,0xdcb000d1,0x00000000}},	//   _ىقلا, _sọ̀k, _زىت_, --, 
   {{0x61e003be,0xeaf400f1,0x00000000,0x00000000}},	//   _əmla, شریت_, --, --, 
   {{0x81dc03f4,0xb4c000b8,0xf8bc0217,0xac0401b9}},	//   _তখন_, ्स्_, sjé_, _унча_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2c1c00cd,0x00000000,0x00000000,0x00000000}},	//   मेकं_, --, --, --, 
   {{0x3998002d,0xe4e40212,0x20f802f0,0xe4558832}},	// [29330] _hūs_, чірн, rčil_, якты, 
   {{0x2cbc0327,0x00000000,0x00000000,0x00000000}},	//   zjud_, --, --, --, 
   {{0x39998833,0x00000000,0x00000000,0x00000000}},	//   _jūs_, --, --, --, 
   {{0x3998005f,0xf07404a9,0xeff002d3,0x2d800055}},	//   _mūs_, сидә_, _ውራይ_, _īje_, 
   {{0x2cbc07d6,0xabd40150,0xd0080114,0x00000000}},	//   vjud_, _ﺘﻁﺎﻋ, јеле_, --, 
   {{0x228400ee,0x66d001f4,0x00000000,0x00000000}},	//   _нусг, _räkk, --, --, 
   {{0xd0d400a7,0x66d0005b,0xb87800e4,0x90b40022}},	//   _довъ, _säkk, chíg, _қәҧш, 
   {{0x0b4407d6,0x358802d3,0x69f001c0,0x66d00254}},	//   онин, _ሕግታት_, үүдт, _päkk, 
   {{0x2cbc0037,0x00000000,0x00000000,0x00000000}},	//   rjud_, --, --, --, 
   {{0x05b8772c,0x39980029,0x0ae98834,0x7ae80334}},	//   _उपलब, _būs_, рдой_, _cmft, 
   {{0xc2780375,0xe0d001ed,0x2d800022,0x00000000}},	//   ברתי, _غزہ_, _ëje_, --, 
   {{0x66d0000d,0x00000000,0x00000000,0x00000000}},	//   _täkk, --, --, --, 
   {{0x66d00209,0x9b943cc5,0x2fcc01e3,0x00000000}},	//   _häki, _ницц, nygg_, --, 
   {{0xf2dc0a85,0x6b980526,0xf3fc0798,0x66d18835}},	//   _stân_, mwug, _adão_, _käki, 
   {{0x84598836,0x6aa001ab,0x15b800c0,0x9a240132}},	//   ират_, _ianf, быты_, _ىعىن, 
   {{0x6aa000a9,0x9e3c2195,0xdb4c04d3,0x66d0023a}},	//   _hanf, _maďa, _جێی_, _mäki, 
   {{0x6aa18837,0x66d00598,0xb33803e0,0x00000000}},	// [29340] _kanf, _läki, _orçu, --, 
   {{0x6aa18838,0x16a400c7,0xa3480131,0x2fcc03b2}},	//   _janf, _егьҭ, изға_, dygg_, 
   {{0x6aa094b2,0xb87800d2,0x9e3c01f1,0x66d00f23}},	//   _manf, bhíd, _naďa, _näki, 
   {{0x6aa0b496,0xc30000cc,0xb87801e7,0x22880022}},	//   _lanf, ৌষধি_, chíd, шәҭо_, 
   {{0x6aa00385,0xdfd18839,0xb87800d2,0x3ea00032}},	//   _oanf, عيت_, shíg, мғаҡ, 
   {{0x6aa1883a,0x66d001b8,0x6445883b,0x7d680a5b}},	//   _nanf, _bäki, lcii, ашив_, 
   {{0x71643d76,0x00000000,0x00000000,0x00000000}},	//   _марг_, --, --, --, 
   {{0x6445883c,0x6aa05cc9,0x2fcc03a1,0x3b3c0092}},	//   ncii, _aanf, bygg_, _በባለቤ, 
   {{0xfb8402d5,0x00000000,0x00000000,0x00000000}},	//   цыйн, --, --, --, 
   {{0x6aa16df9,0xbb4c105c,0xf8bc525e,0x2748054e}},	//   _canf, _comは_, gmén_, _mînă_, 
   {{0x6aa1883d,0x3f840a62,0xd9140b7e,0x6444010f}},	//   _danf, ltou_, здны, kcii, 
   {{0x6b980526,0x3f840270,0x00000000,0x00000000}},	//   bwug, otou_, --, --, 
   {{0x6aa1883e,0x3f85883f,0x81b0015b,0x75e0022e}},	//   _fanf, ntou_, য়নি_, _tеzk, 
   {{0x387c0e5e,0x3f858840,0x6aa00368,0x2ba401f9}},	//   żur_, itou_, _ganf, कटरा, 
   {{0x58d54c7f,0x66d000fd,0x75e0022e,0x00000000}},	//   _нокт, _xäki, _kеzi, --, 
   {{0x6aa064d3,0x3f840165,0x81b00154,0x00000000}},	//   _zanf, ktou_, য়না_, --, 
   {{0x6aa02388,0xe4480b8c,0xb8780077,0x20f800d7}},	// [29350] _yanf, تلقى_, rhíd, ačik_, 
   {{0xb8780077,0x6aa00009,0x6444058a,0x5678030d}},	//   eníx, _xanf, acii, _убоя_, 
   {{0xb144030f,0x7af98841,0x00000000,0x00000000}},	//   تیزم_, intt, --, --, 
   {{0x64458842,0x0d8400d1,0x859805d0,0x66d001f4}},	//   ccii, җлин, _פשרו, _räki, 
   {{0x3f840165,0x66d007d9,0xd3e800fe,0x00000000}},	//   gtou_, _säki, _কুৰি_, --, 
   {{0x8d558843,0x66d000ee,0x2fcc5794,0x00000000}},	//   птич, _päki, rygg_, --, 
   {{0x6aa03462,0x826066a3,0x4c6873b3,0x7bc54af9}},	//   _ranf, _سۇنن, бийн_, äkun, 
   {{0x66d0578c,0x6b9800ca,0x00000000,0x00000000}},	//   _väki, twug, --, --, 
   {{0x3f840587,0x6aa18844,0x66d00724,0xf8bc003e}},	//   ctou_, _panf, _wäki, tmén_, 
   {{0x7cfc0882,0x6aa0031c,0x66d001f4,0x09e4004e}},	//   rīra, _qanf, _täki, зоон, 
   {{0xbb4c037e,0xf8bc003e,0x6aa0007c,0xade000cd}},	//   _comク_, rmén_, _vanf, _केचन_, 
   {{0x6aa18845,0xf2dc045f,0xf8bc0c6a,0x6444003a}},	//   _wanf, _stâl_, smén_, xcii, 
   {{0x6aa18846,0x60c40108,0x7c38123b,0x00000000}},	//   _tanf, öimi, _התנס, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfad4011a,0xb6840023,0x7c3c25a8,0x7bc40162}},	//   _מוסך_, _ምዝመዛ_, _şpri, økuv, 
   {{0x27480276,0x3f858847,0x00000000,0x00000000}},	//   _pînă_, ytou_, --, --, 
   {{0xf41c0589,0x64458848,0x2d8400af,0x3f840de2}},	// [29360] _czä_, rcii, htne_, xtou_, 
   {{0x2d858849,0x6445884a,0x99640139,0x4584119e}},	//   ktne_, scii, _этәл, _егов, 
   {{0x73300c50,0x2d840219,0x0134c0a8,0x64440115}},	//   رىما, jtne_, سعاد, pcii, 
   {{0x1708025c,0x272408a5,0x00000000,0x00000000}},	//   _གཉོམ_, föng_, --, --, 
   {{0x3f840077,0x2d84033f,0x75e0022e,0x7af8005b}},	//   utou_, etne_, _rеzi, yntt, 
   {{0x3f8578b9,0x2d84f086,0xd2940209,0x75e0022e}},	//   rtou_, ftne_, _орсь, _sеzi, 
   {{0x3f85884b,0x00000000,0x00000000,0x00000000}},	//   stou_, --, --, --, 
   {{0x290000b2,0x3f85884c,0x7bc40108,0x80e81f0d}},	//   _njia_, ptou_, äkuo, _طرزِ_, 
   {{0x261c0084,0xafe001b9,0x2d8457d9,0x69c401f4}},	//   _ḽo_, _зотл, atne_, äjen, 
   {{0x2900009f,0x2d840010,0x79600ca8,0x3f40032e}},	//   _ajia_, btne_, _níwá, _iðu_, 
   {{0x7f40014f,0x394804e6,0x00000000,0x00000000}},	//   lqoq, ëbs_, --, --, 
   {{0x2d40008e,0x0ca8475d,0x66d000d7,0xf7700345}},	//   _kıen_, _وطني_, _mäku, _ئاù_, 
   {{0xcce4188d,0x6cc00014,0x290001e3,0x21240254}},	//   _تسلي, _سٲوٕ, _djia_, _mhmh_, 
   {{0xa9540ccb,0xdab800ae,0x7bc40162,0x00000000}},	//   _کجور_, _ذهبت_, økuu, --, 
   {{0x7f40014f,0x7468141c,0x00000000,0x00000000}},	//   hqoq, йрав_, --, --, 
   {{0x261c0dc9,0x95c80046,0x00000000,0x00000000}},	//   _ḓo_, буға_, --, --, 
   {{0xba04001f,0x7cfc1d76,0x7f400477,0x57f40212}},	// [29370] _ኋላ_, hīro, jqoq, _іпот, 
   {{0x538c04c7,0x2d840122,0xc5ec00aa,0x7cfc00b0}},	//   _ሕይወት_, ytne_, اړی_, kīro, 
   {{0x3f400a87,0xb87800e4,0x59dc043e,0x316401d3}},	//   _aðu_, chíc, मनिर, énz_, 
   {{0x1ac800bc,0xd6b801f7,0x00000000,0x00000000}},	//   ाउँथ, _انڍڙ_, --, --, 
   {{0x7f40009a,0x272401a8,0x2d40013d,0x7bc4005b}},	//   gqoq, bönd_, _cıen_, äkul, 
   {{0x2d85884d,0xa3e00790,0x59dc74c8,0xf8bc013a}},	//   ttne_, lüğü_, मनार, dmém_, 
   {{0xa1953ed0,0x9e64bd87,0xdce803b9,0x66d00139}},	//   _парч, راون, _asdı, _täkv, 
   {{0x2d85884e,0x66d001e6,0x7f400477,0x61c40154}},	//   rtne_, _häkt, bqoq, _এইচআ, 
   {{0x2d85884f,0x4a7400a8,0xc0c00304,0x3b80008e}},	//   stne_, мынт, _шәфи, влыг, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x66d01248,0x00000000,0x00000000,0x00000000}},	//   _mäkt, --, --, --, 
   {{0x1cbc025c,0x2d400588,0x66d001e6,0x79600cad}},	//   _ཅོར_, _iñe_, _läkt, _síwá, 
   {{0x27240730,0xe79c03ee,0xa3e005d1,0x66d0007c}},	//   höne_, _düğü, düğü_, _oäkt, 
   {{0xfa8c0208,0x66d0007c,0x272401f4,0x00000000}},	//   _hừng_, _näkt, köne_, --, 
   {{0x044461ff,0xfb1002e9,0x00000000,0x00000000}},	//   дебн, _جووج, --, --, 
   {{0xe79c03e0,0x7f40014f,0x796001e1,0x28c8000d}},	//   _güğü, yqoq, _wíwá, _लवटि, 
   {{0xfa8c0016,0x848402d3,0x1cbc025c,0x66d00112}},	// [29380] _mừng_, _ዝኽርን_, _ཅོལ_, _säku, 
   {{0xfa8c004d,0x2d400588,0x7f40014f,0xe79c0205}},	//   _lừng_, _oñe_, vqoq, _züğü, 
   {{0x2724012b,0x307002d3,0x7f400455,0x5edc0154}},	//   rönd_, _ከምጽእ_, wqoq, _বদলে, 
   {{0x657c023a,0x7f408e61,0x3164054e,0x00000000}},	//   murh, tqoq, ânza_, --, 
   {{0x2d411c20,0x66d001e3,0x657c03cb,0x00000000}},	//   _añe_, _fäkt, lurh, --, 
   {{0x66d13c8c,0x26d98850,0x2481792b,0x7f418851}},	//   _täku, nkro_, lgim_, rqoq, 
   {{0x657d8852,0xfa8c01fb,0x7f400113,0xdb10032e}},	//   nurh, _bừng_, sqoq, _ífél, 
   {{0x24818853,0xcc640131,0x7f40014f,0x6cb0004e}},	//   ngim_, ىنىۋ, pqoq, көчт, 
   {{0x2d400295,0xfa8c001e,0x657d8854,0x44200175}},	//   _eñe_, _dừng_, hurh, _jzk_, 
   {{0x657d8855,0x7b30068f,0x66d021c6,0x776803b9}},	//   kurh, _tłum, _mäks, _çoxə, 
   {{0x66d0d62e,0xa9c0206e,0x386400f7,0x44200171}},	//   _läks, всяк, үзүү_, _lzk_, 
   {{0xc3200f22,0xfa8c01fb,0x657d8856,0x8ac40022}},	//   _ভূমি_, _gừng_, durh, дқәа_, 
   {{0xe7858857,0x6b608dc7,0x7d018858,0x66d0000d}},	//   куро, _акча, _ijos, _näks, 
   {{0x7c218859,0x657c18f7,0x6d44004a,0x00000000}},	//   _izor, furh, _éjac, --, 
   {{0x77903135,0x657d885a,0x7d00baa1,0x4420005a}},	//   ریگا, gurh, _kjos, _azk_, 
   {{0x4421885b,0x1cbc031c,0x66d00166,0x272400e4}},	//   _bzk_, _ཅོས_, _bäks, vöne_, 
   {{0x44200122,0x7d01885c,0x20f80006,0xb8780077}},	// [29390] _czk_, _mjos, nčiu_, chía, 
   {{0x657c00aa,0x2d400598,0x7d01885d,0x44200010}},	//   burh, _bıel_, _ljos, _dzk_, 
   {{0x4420005a,0x7d01885e,0x66d00267,0x06540375}},	//   _ezk_, _ojos, _väkt, _איתך_, 
   {{0x7c2015f5,0xf4200323,0xd478010f,0x3c1c0037}},	//   _ozor, _үзүү, _צאָל, _परूँ_, 
   {{0x7c21885f,0xfa8c0016,0x733000c7,0x00000000}},	//   _nzor, _rừng_, _аҕац, --, 
   {{0xfa8c01fb,0x7d018860,0xb1917599,0xa77c00d9}},	//   _sừng_, _ajos, _илгә, קרופ, 
   {{0x7c218861,0x4c687a16,0x623400fd,0x4420bc4a}},	//   _azor, пийн_, _аеру, _zzk_, 
   {{0x4c843d6b,0x00000000,0x00000000,0x00000000}},	//   хлив, --, --, --, 
   {{0xfa8c004d,0xed54023b,0x2264008e,0x20f80064}},	//   _vừng_, чоқ_, _öskä_, gčiu_, 
   {{0x7d00009a,0x7c218862,0x00000000,0x00000000}},	//   _ejos, _dzor, --, --, 
   {{0xfa8c07ae,0xaca000b4,0x7c218863,0x657c02c4}},	//   _từng_, _azụm, _ezor, xurh, 
   {{0x9cb80156,0x7ae57802,0x7d00036e,0x00000000}},	//   _ཐོགས, èktr, _gjos, --, 
   {{0x657c009a,0x394c2238,0x2484013d,0x00000000}},	//   wurh, _etfs_, _ömmi_, --, 
   {{0x4ebc045e,0xfaa0023b,0x26d98864,0x66d0403a}},	//   _অতুল, _башо, ukro_, _räks, 
   {{0x4420037e,0xb878007b,0x5a440006,0x248001a9}},	//   _szk_, mhín, _рэча, tgim_, 
   {{0x657cad43,0x20f800bc,0x00000000,0x00000000}},	//   rurh, nčit_, --, --, 
   {{0x26e00156,0x24818865,0x657c005b,0xd018010e}},	// [293a0] ོལདཔ, rgim_, surh, _nyń_, 
   {{0xe9fc01dc,0xe890004d,0x744401c6,0x20f8013a}},	//   _giải_, _xẻng_, _үзэг_, hčit_, 
   {{0x657c0472,0x36580375,0x24940023,0x00000000}},	//   qurh, _מכינ, ዝበለት_, --, 
   {{0x442001a6,0x2d400139,0x20f80118,0x7b30012d}},	//   _tzk_, _cıem_, jčit_, _płuk, 
   {{0xdb003c02,0xddc801d3,0x20f801ef,0x00000000}},	//   lvmå, _redő, dčit_, --, 
   {{0x3da40e26,0xdd0405d1,0x00000000,0x00000000}},	//   ериб, _ısıt, --, --, 
   {{0x409478d2,0x7c218866,0xb8d00327,0xad2000d1}},	//   _прат, _szor, _ཝྃ_, گىيى, 
   {{0xf8bc00dd,0x7c6418fd,0xb87800e4,0x00000000}},	//   rmék_, رابل, ehín, --, 
   {{0xa2c4449f,0xb0980302,0xd10c3806,0xad200131}},	//   राप्, _צימר, िकरण_, دىيى, 
   {{0x7c2023e2,0xf8bc01c7,0x8fd40166,0x00000000}},	//   _vzor, mméi_, _шәхә, --, 
   {{0x7c200034,0x7d010d41,0x20f80153,0x58780014}},	//   _wzor, _tjos, sčiu_, وٝدس_, 
   {{0x7d000173,0x6d440214,0x8e2401ec,0x00000000}},	//   _ujos, _éjaa, _جۋىق_, --, 
   {{0x7c2007f5,0xfbd01537,0xb87801e7,0x69c4005c}},	//   _uzor, _حتا_, bhín, øjer, 
   {{0x66d0049f,0xa2c41b76,0xb8798867,0x00000000}},	//   _säkr, राफ्, chín, --, 
   {{0x65958868,0xa2c41221,0xf5258869,0x16840133}},	//   лару, रान्, ефан, _یادێ, 
   {{0x57b58118,0xb87800ae,0x00000000,0x00000000}},	//   _абит, mhío, --, --, 
   {{0xd3702088,0x00000000,0x00000000,0x00000000}},	// [293b0] شها_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x07340375,0x39880393,0x66d00139,0xf77c010e}},	//   _שאתם_, nùs_, _täkr, luç_, 
   {{0x98bc0100,0x272404cc,0x9268190b,0x00000000}},	//   _ouvč_, möna_, ярға_, --, 
   {{0xf77c03ee,0x272401e3,0xb87800e4,0x048401ee}},	//   nuç_, löna_, yhín, _шәри_, 
   {{0x71700075,0x2ea800cd,0x00000000,0x00000000}},	//   _مۇئا, चयेत, --, --, 
   {{0x798802d0,0x90440066,0x28c42314,0x00000000}},	//   _nqfw, _لنزه, षामि, --, 
   {{0xb878007b,0x00000000,0x00000000,0x00000000}},	//   dhío, --, --, --, 
   {{0x0c25886a,0x209800fd,0x2d400139,0xada000d1}},	//   ъмин, _якты_, _kıek_, тақл, 
   {{0x80a000cf,0xb87801e7,0x272401e3,0x00000000}},	//   _مۅۅن, fhío, köna_, --, 
   {{0x20f80421,0x2d400139,0x0d200137,0x00000000}},	//   lōia_, _mıek_, _күкү, --, 
   {{0xb87819e4,0xfd540a7c,0x29040254,0x00000000}},	//   shín, _ישעי_, õma_, --, 
   {{0xa2c406ff,0xb8780332,0x00000000,0x00000000}},	//   राम्, mhíl, --, --, 
   {{0xca481194,0xb87801e7,0x73f800cc,0x00000000}},	//   _غلبه_, bhío, _আৰ্ট_, --, 
   {{0xb87801e7,0xc8c801e2,0x00000000,0x00000000}},	//   chío, _يوتن_, --, --, 
   {{0xa2c400dc,0xf77c0205,0xe51c000d,0x00000000}},	//   राभ्, buç_, _भीखि_, --, 
   {{0xc7240075,0xc33001d9,0x872426ef,0x00000000}},	// [293c0] _идий, لٕر_, _имиж, --, 
   {{0x8c3c0209,0xb5a8002e,0xe8e00051,0x7bc401f4}},	//   leşd, r斡ri, _độg_, äkui, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf8bc0036,0x044400d8,0x8c3c010e,0x00000000}},	//   tméi_, _шемн, neşd, --, 
   {{0xf8b0008d,0xb8780332,0x00000000,0x00000000}},	//   ישא_, dhíl, --, --, 
   {{0x63a4555e,0xf4100302,0x100802ef,0xf8bc0036}},	//   mwin, _כפר_, رتنى_, rméi_, 
   {{0x63a5886b,0xb4d800db,0x813400c7,0xcf8c0014}},	//   lwin, _diàf, _ахац, _ہژو_, 
   {{0x63a4011f,0xeb60001f,0x3fc401ed,0x60c400e4}},	//   owin, _መነጋገ, _لگتی_, ŷimb, 
   {{0xfe71886c,0x248401a8,0x5b140a0e,0xee200116}},	//   _ندا_, _ömmu_, лмит, лмәп, 
   {{0xb87800c6,0x63a42437,0xf77c0790,0x00000000}},	//   thío, iwin, vuç_, --, 
   {{0x63a5886d,0x487000d1,0xf2d00677,0x58d42360}},	//   hwin, ڭگىس, יעז_, гонт, 
   {{0x2fe40790,0x00000000,0x00000000,0x00000000}},	//   _övgü_, --, --, --, 
   {{0x63a55453,0x63700055,0xb8780332,0x195800c7}},	//   jwin, _jñnā, shío, ьаҽы_, 
   {{0xd048013f,0xeaac01d9,0x63a42bab,0x97248370}},	//   _ɑnɑn, _وٹن_, dwin, افسو, 
   {{0x63a5886e,0x199400ee,0xf484014b,0x00000000}},	//   ewin, _сайя, куан, --, 
   {{0x63a4a84e,0x27240267,0x2d400166,0x3ebc0051}},	//   fwin, röna_, _sıek_, _lntt_, 
   {{0x63a5886f,0xe53416ab,0x9294009d,0x00000000}},	// [293d0] gwin, реть, лаац, --, 
   {{0x00d80150,0x00000000,0x00000000,0x00000000}},	//   _ﺃﺠﺭﺘ, --, --, --, 
   {{0x8c3c4c61,0x63a58870,0x1b0400fe,0xe730007b}},	//   leşe, awin, _উঠাই_, _بصي_, 
   {{0x63a40925,0xf2dc00a8,0xb4b0506f,0xe0d005d9}},	//   bwin, _atât_, _тимә, يزن_, 
   {{0x78a8022c,0x63a4009a,0x00000000,0x00000000}},	//   _ógvu, cwin, --, --, 
   {{0x3ebd8871,0xa2c4de9c,0x7fb401e2,0x00000000}},	//   _cntt_, राण्, اهور_, --, 
   {{0xd1b0429e,0x00000000,0x00000000,0x00000000}},	//   _دیاک, --, --, --, 
   {{0x522404a9,0x20f800b0,0x9db8004e,0xca48036b}},	//   _афға, pōia_, тышу_, کلده_, 
   {{0x4fc00137,0x3ebc0153,0x00000000,0x00000000}},	//   _دەشە, _fntt_, --, --, 
   {{0xfff450b5,0x49c83efd,0x4aa808ca,0x8c3c0205}},	//   _حکمت_, елон_, хкон_, deşe, 
   {{0x63a58872,0xa2c407b7,0x00000000,0x00000000}},	//   zwin, रात्, --, --, 
   {{0x63a58873,0x28c58874,0x3ebc022e,0x00000000}},	//   ywin, षाधि, _zntt_, --, 
   {{0x32dc019f,0x6f000076,0xb87800e4,0x63a40175}},	//   _nîyo_, onnc, chím, xwin, 
   {{0xf7409c0b,0x63a4014b,0xfcc40588,0x8c3c0311}},	//   серо, vwin, _ашәҟ, geşe, 
   {{0x63a58875,0x6f00286e,0x7bc40108,0x7c44036e}},	//   wwin, innc, äkuv, _çrrë, 
   {{0x03a41ee3,0x07a4014b,0xbec000ef,0x7950009f}},	//   либо, _баин, _ģīme, _اَيا, 
   {{0x63a525ce,0x68e58876,0x4384007b,0x8c3c0139}},	// [293e0] uwin, _ilid, طلاق, beşe, 
   {{0xa2c417e6,0x8264221d,0x442400df,0x68e462d0}},	//   राध्, اهان, ĥo_, _hlid, 
   {{0x63a58877,0x68e4012c,0xccf80034,0x41b40150}},	//   swin, _klid, kiś_, ысат, 
   {{0x63a48d78,0x362001d3,0x00000000,0x00000000}},	//   pwin, _دوپہ, --, --, 
   {{0xa2c41971,0x63a4ce6b,0x68e4009f,0xb8780174}},	//   राद्, qwin, _mlid, skíg, 
   {{0x9f340046,0x3240074d,0x1cbc025c,0xf8bc01ed}},	//   шелі, _герг, _ཅོང_, lmét_, 
   {{0x68e58878,0x6d4400d2,0x5ce4013e,0x00000000}},	//   _olid, _éjal, исиҷ, --, 
   {{0x6f0000ae,0x7c9415eb,0x7cfc0064,0x00000000}},	//   annc, اشغا, kūre, --, 
   {{0x33140014,0xc00559c5,0x657c0142,0x3ebc0051}},	//   _شٲہد_, _спак, hrrh, _tntt_, 
   {{0xbda40502,0xed4d8879,0x68e5887a,0xfaa44af0}},	//   _محصو, تھے_, _alid, ушин, 
   {{0x3a043321,0x95840023,0x19c49816,0xf27800df}},	//   دکشی_, _ዝፍትን_, рәлг, ערטש, 
   {{0x68e40200,0xccf80055,0x38c4003b,0x00000000}},	//   _clid, ciś_, ущов, --, 
   {{0x8c3c236c,0x00000000,0x00000000,0x00000000}},	//   teşe, --, --, --, 
   {{0x68e5887b,0x79a40276,0x7e6801a4,0x7bc416ca}},	//   _elid, _брие, nafp, äkuu, 
   {{0x7af9887c,0x163400c9,0x8c3d887d,0x68e40072}},	//   mitt, ревя, reşe, _flid, 
   {{0x7af9887e,0x5455887f,0x2c7c01b8,0xdc340419}},	//   litt, рват, mädü_, _lúči, 
   {{0xb9dc067d,0xe0200c2e,0x7af8023a,0x9e3c0100}},	// [293f0] _እሞ_, _बरगद_, oitt, _taďw, 
   {{0x7af98880,0x68e401d5,0x1dc400dc,0xe57800e2}},	//   nitt, _zlid, वमात, šķa_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7af98881,0xf8bc004a,0x2804032e,0x98bc002b}},	//   hitt, mmés_, _árný_, _yuvā_, 
   {{0x7af98882,0xddd0012c,0xf8bd0baf,0xe6040014}},	//   kitt, _češt, lmés_, _نِیَ, 
   {{0x7af98883,0x60c0513f,0xf8bc003e,0xf41c008e}},	//   jitt, _enmm, blég_, _iyä_, 
   {{0x3f800fac,0x00000000,0x00000000,0x00000000}},	//   _åkun_, --, --, --, 
   {{0x8b94e444,0x7af8005b,0x00000000,0x00000000}},	//   ароч, eitt, --, --, 
   {{0xf53c0589,0x7af89ff4,0x358802d3,0x10a40116}},	//   _miå_, fitt, _ዕግበት_, _йиңн, 
   {{0x68e58884,0x00000000,0x00000000,0x00000000}},	//   _slid, --, --, --, 
   {{0x68e58885,0x98a8031c,0xb8780588,0x00000000}},	//   _plid, _ghaċ_, chík, --, 
   {{0xf53c0004,0x9ca800e3,0x7af801f4,0x00000000}},	//   _niå_, _مهمل_, aitt, --, 
   {{0x7af98886,0x4b78010f,0x7bc41b99,0x00000000}},	//   bitt, _סאַו, äkut, --, 
   {{0x7af98887,0x00000000,0x00000000,0x00000000}},	//   citt, --, --, --, 
   {{0xa2c41fe7,0x0444376d,0x68e53c2d,0x48e402e8}},	//   रास्, иевн, _tlid, _войв, 
   {{0x68e58888,0x853cba77,0x2cac416d,0x98bc00ef}},	//   _ulid, _ọgbọ_, _jagd_, _tuvā_, 
  
   {{0x9e3c0100,0x2a64007f,0x234804fb,0xd4540212}},	// [29400] _haďt, _kenb_, اسری_, стсь, 
   {{0x42558889,0x2cac6525,0x72c06391,0x41b42377}},	//   ртат, _lagd_, обуз, исет, 
   {{0x76780375,0xf6780375,0x008401d5,0x7b300210}},	//   _בטיח, _באימ, илжо, _złus, 
   {{0xa2c42314,0x7af9888a,0xdc340030,0xa494114f}},	//   राह्, zitt, _súči, _دیرت, 
   {{0x7af9888b,0xf8bc0098,0x85040133,0xdc340419}},	//   yitt, omér_, _موگن, _púči, 
   {{0xf2dc01fb,0x7af80548,0xf8bc002e,0x2c1403d4}},	//   _huân_, xitt, mlée_, দেৱে_, 
   {{0x7af9888c,0xf8bd888d,0x7cfc0882,0x2cac03b2}},	//   vitt, llée_, kīrt, _bagd_, 
   {{0xa2c4041c,0x0db801d3,0xd12c00f7,0xdb2401e1}},	//   राव्, ائوں_, _كۅل_, _èsús, 
   {{0x7af9888e,0x64400120,0xb3380432,0x2cac00a2}},	//   titt, _úmid, _arçy, _dagd_, 
   {{0xd6c00729,0xf2d000c8,0xf2dc001e,0xf8bc0129}},	//   _উত্প, ַער_, _luân_, ilée_, 
   {{0x7af9888f,0x2a658890,0xfce400f7,0x7b30033f}},	//   ritt, _denb_, _кожо, _słus, 
   {{0x7af98891,0x3164006a,0x00000000,0x00000000}},	//   sitt, ânzi_, --, --, 
   {{0x7af98892,0x00000000,0x00000000,0x00000000}},	//   pitt, --, --, --, 
   {{0x3ce40218,0x2a64031c,0x7af98893,0x00000000}},	//   _hlov_, _genb_, qitt, --, 
   {{0xf53c0589,0x99840597,0x58d4074d,0xc6b800fe}},	//   _piå_, _العو, _гойт, ুসূচ, 
   {{0xf8bd8894,0x2a6401c0,0x7b300034,0x00000000}},	//   rmés_, _zenb_, _tłus, --, 
   {{0xf8bc2a78,0x00000000,0x00000000,0x00000000}},	// [29410] glée_, --, --, --, 
   {{0xa2c43174,0xf53c0589,0xe80400ab,0x00000000}},	//   राष्, _wiå_, रपरा_, --, 
   {{0x3ce5360d,0xe2980212,0xe81800f2,0x690803b9}},	//   _olov_, рає_, _مزیت_, kıel, 
   {{0xefc8001f,0xf8bc07ea,0x00000000,0x00000000}},	//   _በሰው_, blée_, --, --, 
   {{0xa2c40b7c,0xf8bc06af,0x00000000,0x00000000}},	//   राश्, clée_, --, --, 
   {{0x2cac0158,0x6d44003e,0x3ce403e3,0x00000000}},	//   _sagd_, _éjak, _alov_, --, 
   {{0xa2c4243c,0x3ce58895,0xb8780548,0xe2f802dd}},	//   रार्, _blov_, ahíi, _тері_, 
   {{0xf2dc0016,0xccc51535,0x00000000,0x00000000}},	//   _xuân_, сбий, --, --, 
   {{0xcdc58896,0x2a6401ef,0x00000000,0x00000000}},	//   раққ, _penb_, --, --, 
   {{0xcac8100e,0xf3fc06ed,0xafe400a2,0xddd801e4}},	//   угое_, _leão_, _edĸä, lavŝ, 
   {{0x3ce4365a,0x2d8000e4,0x4c94014b,0x7bc40108}},	//   _flov_, _êje_, _гиес, äkur, 
   {{0xe7a80075,0xf8bc0129,0xc7a40395,0xc19800df}},	//   لۇبى_, ylée_, бимк, נשרי, 
   {{0x2a640100,0x07f8009d,0x00000000,0x00000000}},	//   _tenb_, ухны_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9a240150,0x3ce4022e,0xc95401af,0x00000000}},	//   _وعىن, _ylov_, _утлы, --, 
   {{0xf2dc07ae,0xf77001d3,0x044400d8,0xb978011a}},	//   _quân_, _کاٹ_, сеан, _ענפי, 
   {{0xa2c40764,0xf8bc06af,0xb23400d1,0x69c40419}},	// [29420] राल्, ulée_, ەكلا_, ťjed, 
   {{0xf8bd8897,0x0684005b,0x00000000,0x00000000}},	//   rlée_, _угон, --, --, 
   {{0xf2dc01fb,0x6d4400d5,0x7a3c0205,0x00000000}},	//   _tuân_, _éjah, _içtü, --, 
   {{0x7cfc02b5,0xf8bc06af,0x2d8000c7,0x29040098}},	//   kūra, plée_, _ãjey_, éjah_, 
   {{0x3518025f,0x00000000,0x00000000,0x00000000}},	//   _תוכנ, --, --, --, 
   {{0x3ce40232,0x7cfd8898,0x00000000,0x00000000}},	//   _slov_, dūra, --, --, 
   {{0x629d8899,0x1cbc025c,0x3ce5889a,0x8c3c0205}},	//   _ibro, _ཅོད_, _plov_, veşa, 
   {{0x44200591,0xb87801ed,0xfba801c6,0x00000000}},	//   _kyk_, lhív, гтой_, --, 
   {{0x7cfc4a97,0x4420010e,0x23c800cd,0x00000000}},	//   gūra, _jyk_, रमिद, --, 
   {{0x7ac5889b,0x4421889c,0x99980261,0x00000000}},	//   ссие, _myk_, акот_, --, 
   {{0x629c069c,0x4421889d,0x8c3c19b2,0xddc84a38}},	//   _mbro, _lyk_, reşa, _medū, 
   {{0x23c8cdf8,0x3ce5889e,0x00000000,0x00000000}},	//   रमाद, _ulov_, --, --, 
   {{0x4421889f,0x3f84617f,0x8c3c008e,0x00000000}},	//   _nyk_, nuou_, leşn, --, 
   {{0x7c2188a0,0x7b300034,0x59b005d7,0x38bc8021}},	//   _iyor, _głup, _जनपर, _bärä_, 
   {{0xf3fc0798,0x7c2188a1,0xc5cc00fe,0x00000000}},	//   _peão_, _hyor, _ৱেবপ, --, 
   {{0x442188a2,0x7c2188a3,0x38bc0139,0x3f8400b5}},	//   _byk_, _kyor, _därä_, kuou_, 
   {{0x629c01ab,0x1cbc025c,0x00000000,0x00000000}},	// [29430] _bbro, _ཅོན_, --, --, 
   {{0x442188a4,0x7c200083,0x3f840077,0xb87801ed}},	//   _dyk_, _myor, duou_, ghív, 
   {{0x66d0049b,0x629c02b9,0x690801a8,0x7ae4007f}},	//   _näky, _dbro, _ásdí, èkty, 
   {{0x629d88a5,0x442188a6,0x7c200083,0x8c3c0139}},	//   _ebro, _fyk_, _oyor, deşn, 
   {{0x7c2188a7,0xe0d058c5,0x629c0334,0x98b80024}},	//   _nyor, عزم_, _fbro, ūrė_, 
   {{0x8d547863,0xb8787448,0x00000000,0x00000000}},	//   отич, chív, --, --, 
   {{0x7c2188a8,0x26dc0a1e,0xdba00150,0x00000000}},	//   _ayor, רקומ, _ﺃﺴﺭﻯ_, --, 
   {{0x7cfc5c07,0x7c2188a9,0x629c44ef,0x7b301afd}},	//   tūra, _byor, _zbro, _słup, 
   {{0x7c200230,0x0ae8e360,0x3f840798,0xe0e40006}},	//   _cyor, идий_, cuou_, _эўро, 
   {{0x7c201e92,0x0a38005b,0x00000000,0x00000000}},	//   _dyor, ичны_, --, --, 
   {{0x7c2188aa,0x00000000,0x00000000,0x00000000}},	//   _eyor, --, --, --, 
   {{0x2d8588ab,0x7c203040,0x00000000,0x00000000}},	//   mune_, _fyor, --, --, 
   {{0x7c20066d,0x2d8588ac,0x38bc01f4,0x66d00139}},	//   _gyor, lune_, _särä_, _zäky, 
   {{0x442188ad,0x2d840a40,0xfaa00372,0x09e588ae}},	//   _ryk_, oune_, _жашо, _молн, 
   {{0x2d8588af,0x442188b0,0xc4c40b24,0x00000000}},	//   nune_, _syk_, يترو, --, 
   {{0x629c0bdf,0x4420002d,0x2d8400a3,0xca7400f2}},	//   _sbro, _pyk_, iune_, _انژک, 
   {{0x2d8418a6,0xc76410e0,0x8ca0000d,0x00000000}},	// [29440] hune_, _باعى, _कउनो, --, 
   {{0xeae400cc,0x442188b1,0x272401f4,0x00000000}},	//   _পদুম, _vyk_, köni_, --, 
   {{0x442188b2,0x41a83576,0x3634004b,0x00000000}},	//   _wyk_, рвен_, _ورپس, --, 
   {{0x2d8588b3,0x3f84e099,0x4420037e,0x629c0175}},	//   dune_, tuou_, _tyk_, _wbro, 
   {{0x5e5802f6,0x66d00108,0xb8780332,0xe28401af}},	//   биля_, _säky, mhít, _нған, 
   {{0x7c202d6f,0xdc1c005f,0x629d88b4,0x00000000}},	//   _ryor, zņēm, _ubro, --, 
   {{0x1fd8045e,0x2d8588b5,0x7c202a1f,0xc0e40212}},	//   _দেশস, gune_, _syor, _довк, 
   {{0x3f840421,0x3588001f,0x7c2035e5,0x2d40008e}},	//   puou_, _ዕውቀት_, _pyor, _sıer_, 
   {{0x2d84f856,0x9fd800fe,0x00000000,0x00000000}},	//   aune_, _দেৰগ, --, --, 
   {{0x2d84b76c,0x1cbc0327,0x7c2188b6,0x66d001f4}},	//   bune_, _ཅོམ_, _vyor, _täky, 
   {{0x6e902b49,0x2d8588b7,0x7e78009a,0x8c3c00fd}},	//   _آلما, cune_, _idtp, leşl, 
   {{0x7c200055,0x00000000,0x00000000,0x00000000}},	//   _tyor, --, --, --, 
   {{0x8c3d88b8,0x7c2000ca,0xeaac1888,0xdc1c00de}},	//   neşl, _uyor, رعی_, rņēm, 
   {{0xb3380798,0x8b640ccb,0x00000000,0x00000000}},	//   _opça, _راهم, --, --, 
   {{0xb4d8004e,0x746988b9,0x3a380de2,0xca60022e}},	//   _diàn, ирав_, _àpp_, molа, 
   {{0x395c2517,0x2ea400bc,0xf7e80137,0x644806be}},	//   mpts_, _गस्त, _ەرگى_, _şdir, 
   {{0x2d8588ba,0x68e001e3,0x00000000,0x00000000}},	// [29450] zune_, ömde, --, --, 
   {{0xb4d8001e,0x8c3c41b5,0xe3b001ed,0x2d8588bb}},	//   _giàn, deşl, کرہ_, yune_, 
   {{0x2d8414ce,0x053c0092,0x00000000,0x00000000}},	//   xune_, _በቴሌቪ, --, --, 
   {{0xd0101b16,0x2d8588bc,0x7cfc0024,0x81440588}},	//   ىلا_, vune_, dūro, _ẽtév, 
   {{0xba000201,0x2d8588bd,0xca6001a9,0x00000000}},	//   _ውጭ_, wune_, kolа, --, 
   {{0x2d8588be,0x0594034c,0x272401f4,0x00000000}},	//   tune_, _بایگ, töni_, --, 
   {{0x7cfc0024,0x6cb001c6,0x00000000,0x00000000}},	//   gūro, дөлт, --, --, 
   {{0x2d8588bf,0x2d4000fd,0x8c3ccb7d,0xa1141291}},	//   rune_, _cıep_, beşl, _قوّت, 
   {{0x2d84019b,0xca60022e,0x395c00ef,0x00000000}},	//   sune_, folа, epts_, --, 
   {{0x63a004f3,0xdd000029,0x2d8588c0,0x00000000}},	//   _ämne, ētāj, pune_, --, 
   {{0xb4d804cc,0xc8c811e6,0xb87801d3,0x7d080162}},	//   _riàn, مودن_, yhít, ómsá, 
   {{0x8c3d88c1,0x7ae988c2,0xb4d804cc,0xc6900050}},	//   leşm, _elft, _siàn, کِس_, 
   {{0x7cec01ab,0xb4d800a3,0x5c140408,0x00000000}},	//   _dùrd, _piàn, _оьшу, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x09e401c0,0x5ed80154,0xb8780332,0x00000000}},	//   _хойн, ভোকে, thít, --, 
   {{0x75d06ac4,0x00000000,0x00000000,0x00000000}},	//   ريقا, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [29460] --, --, --, --, 
   {{0xb87800c6,0x85e80064,0x00000000,0x00000000}},	//   bhís, _гдов_, --, --, 
   {{0xb87988c3,0x5ba80d2c,0xaaf40086,0xc0583327}},	//   chís, _कन्व, ûrùò_, біл_, 
   {{0x5a0c008f,0x98bc0024,0xca60022e,0xdcf80064}},	//   סלאַ, _buvę_, zolа, buvę, 
   {{0x2558007f,0xb4d80109,0x947800aa,0xf8bc003e}},	//   _dčle_, _miàl, _بشپړ_, klén_, 
   {{0x7cfc02d5,0x8c3c0724,0xbd680262,0x395c003b}},	//   tūro, reşl, брие_, ypts_, 
   {{0x71a000cf,0x412800f3,0x00000000,0x00000000}},	//   _парз, _гово_, --, --, 
   {{0xa2c4243c,0xf38002d3,0x00000000,0x00000000}},	//   राक्, _ንርእዮ_, --, --, 
   {{0x7f4813de,0xf93401c0,0xfba801b9,0x00000000}},	//   _طلاق_, үүлч_, ётий_, --, 
   {{0x7cfc02b5,0xdea06646,0x59b0033f,0x2a60004e}},	//   pūro, _شیعی, _जनदर, нъюг, 
   {{0xbc68cf73,0x9af800b8,0x5a340212,0xb87801f6}},	//   _همان_, _cvāṇ, ьнот, dhír, 
   {{0xee3401c6,0x395c0f85,0x00000000,0x00000000}},	//   _энх_, rpts_, --, --, 
   {{0xb4d800f7,0x00000000,0x00000000,0x00000000}},	//   _diàl, --, --, --, 
   {{0xa3c003f3,0x395c0112,0xb87801d3,0x00000000}},	//   ंटन_, ppts_, ghír, --, 
   {{0xb4d80109,0x6a980375,0xf4843252,0x00000000}},	//   _fiàl, _השונ, зузн, --, 
   {{0xa4d402d5,0x00000000,0x00000000,0x00000000}},	//   носі, --, --, --, 
   {{0xa87c025f,0xb87800d2,0xe2c800f1,0x52d80117}},	// [29470] _האחר, shís, ګولو_, омаю_, 
   {{0xe3c43306,0x6eed88c4,0x2ed80a28,0xa2c4193d}},	//   عْلَ, _købe, _भवेत, राग्, 
   {{0x50b44316,0x720000d1,0x8c3c0356,0x00000000}},	//   дслу, رۈرم, veşm, --, 
   {{0x6eec1088,0x00000000,0x00000000,0x00000000}},	//   _møbe, --, --, --, 
   {{0x6eec019b,0x394c07c5,0xa2c411bc,0x00000000}},	//   _løbe, _lufs_, राख्, --, 
   {{0xbea188c5,0xca380131,0x3ea001d5,0x00000000}},	//   вашк, ﺒﻪﺭ_, вишг, --, 
   {{0x394c04cc,0x20c80137,0x00000000,0x00000000}},	//   _nufs_, تبەي_, --, --, 
   {{0x8c44010b,0x2724007c,0xcc8801e2,0x00000000}},	//   мейе, lönt_, څنګه_, --, 
   {{0xfd54063f,0x394c03fa,0x98a0022e,0xb87800e5}},	//   _kabọ, _aufs_, _a築ol, gkím, 
   {{0xe578005f,0x09e42be5,0x8c3c008e,0x00000000}},	//   šķi_, доон, leşk, --, 
   {{0x6f0188c6,0x2d8000c7,0x8afc013a,0x00000000}},	//   minc, _íje_, jpře, --, 
   {{0xb3388607,0x394c01bf,0x6eec005c,0xf8bc0332}},	//   _opço, _dufs_, _døbe, slén_, 
   {{0xf8bc04d4,0x272401e3,0x0af401d5,0x00000000}},	//   plén_, könt_, _очкў, --, 
   {{0x6f0188c7,0xb4d800cf,0xf8bc0158,0x8a040209}},	//   ninc, _diàm, llél_, _озле, 
   {{0xf740fe80,0x55c588c8,0xd90c0133,0xd61401af}},	//   теро, нарғ, شیی_, ефть, 
   {{0x2b4588c9,0x6f0188ca,0x480801f4,0x00000000}},	//   _hinc_, hinc, _мейн_, --, 
   {{0x6f0188cb,0x00000000,0x00000000,0x00000000}},	// [29480] kinc, --, --, --, 
   {{0x6f0188cc,0x055400a7,0x00000000,0x00000000}},	//   jinc, _отмя, --, --, 
   {{0x6f0188cd,0x2b442d42,0x00000000,0x00000000}},	//   dinc, _minc_, --, --, 
   {{0x2360432f,0x2b4400a9,0x320401d3,0x00e40108}},	//   ppij_, _linc_, únya_, ьжен, 
   {{0x6f0188ce,0xde580024,0xef1c012d,0x00000000}},	//   finc, палі_, ężna_, --, 
   {{0x6f0188cf,0x272404cc,0x23800023,0x81d400eb}},	//   ginc, möns_, _ንርዳእ_, িনব_, 
   {{0x290188d0,0x6da01677,0xc0a801d9,0x3240013d}},	//   _omia_, вија, _وارل_, _аерг, 
   {{0x6f0001ab,0xf8bd88d1,0x6eec0450,0x6ec400bc}},	//   ainc, glél_, _røbe, लाउँ, 
   {{0xbf1404d3,0x6f000de9,0x2b440042,0x6eec01bf}},	//   _قورب, binc, _binc_, _søbe, 
   {{0x2b449022,0x290188d2,0x6eec2b96,0x9abc0327}},	//   _cinc_, _amia_, _pøbe, koċe, 
   {{0x2b4588d3,0xeaf40979,0x195801c6,0x9abc0327}},	//   _dinc_, بريت_, яаны_, joċe, 
   {{0x6ba40267,0x2dc802dd,0x195800c7,0x7790cdc2}},	//   örgå, _باكۋ_, _ҵакы_, نیبا, 
   {{0x59b007c1,0xfbd01867,0x272401e3,0x68e0007c}},	//   _जनवर, _جتا_, jöns_, ömda, 
   {{0x290188d4,0x27e405ac,0x2724002f,0x2b4400ef}},	//   _emia_, ømna_, döns_, _ginc_, 
   {{0x3f8588d5,0x7bc188d6,0x65940228,0x00000000}},	//   hrou_, _hrou, кару, --, 
   {{0x6f0188d7,0x7bc007e4,0xe5340024,0xb87800e4}},	//   zinc, _krou, весь, chíp, 
   {{0x6f0188d8,0xe1f0b167,0x27240112,0x0a3400db}},	// [29490] yinc, یسم_, tönt_, _قوۇڭ, 
   {{0x3f8405a0,0x7bc0030a,0xddd80153,0x00000000}},	//   drou_, _mrou, ngvų, --, 
   {{0xa2c44f4b,0x3208c8a6,0x3f8588d9,0xe45000e5}},	//   राज्, цхан_, erou_, اضہ_, 
   {{0x6f0188da,0x3f8588db,0x4f94084c,0x7bc00857}},	//   winc, frou_, ерку, _orou, 
   {{0x6f0188dc,0x3f84e099,0x8458011a,0x7bc4007c}},	//   tinc, grou_, _מכרז, åkul, 
   {{0x8ca0068f,0x6f001730,0x63a001e3,0xf8bc013a}},	//   क्नो, uinc, _ämna, dlém_, 
   {{0x6f00fcd7,0x7bc188dd,0x99d004c5,0xb4d80241}},	//   rinc, _arou, ানুক, _niàk, 
   {{0x7bc188de,0x8c3c37be,0x6f0188df,0x3f8588e0}},	//   _brou, leşi, sinc, brou_, 
   {{0x7bc188e1,0x0b447510,0x6f0188e2,0xa2c400a5}},	//   _crou, ннин, pinc, राच्, 
   {{0x7bc188e3,0x6f017d70,0x29002d8b,0x8c3c9d25}},	//   _drou, qinc, _smia_, neşi, 
   {{0x7bc188e4,0xdd9407dd,0x2b44004e,0x09e588e5}},	//   _erou, _аахы, _vinc_, хонн, 
   {{0xf8bc03c6,0x7bc188e6,0x2b440142,0x4ea400fb}},	//   blém_, _frou, _winc_, _юрға, 
   {{0x7bc188e7,0x2b440228,0x6908010e,0x8c3c45d8}},	//   _grou, _tinc_, dıet, keşi, 
   {{0x2b44003a,0xfc080118,0x00000000,0x00000000}},	//   _uinc_, šťák_, --, --, 
   {{0x35a188e8,0x45342c0b,0x7bc005c7,0x35c40107}},	//   ларг, ехат, _zrou, нгро_, 
   {{0x3f8588e9,0x2d8414d0,0x290004c9,0x69c188ea}},	//   yrou_, irne_, _umia_, _irne, 
   {{0x6b9988eb,0xa9a007d6,0x69c000bc,0x8ca0262c}},	// [294a0] ntug, _чиқд, _hrne, क्यो, 
   {{0x3f8405e4,0x69c015ad,0xb7b0008e,0x8c3c00a2}},	//   vrou_, _krne, _сөюч, geşi, 
   {{0x008400d8,0x48d00154,0xc058753d,0xc0e4005b}},	//   елео, াসীর, піл_, ножк, 
   {{0x3f846254,0x70500502,0x6b9988ec,0xa2c408df}},	//   trou_, هنما, ktug, राङ्, 
   {{0x2d8588ed,0x6fe400b8,0x73e07c85,0x8c3c03e0}},	//   erne_, _nīcā, _бояз, beşi, 
   {{0xdd900372,0x3f84b998,0xe57800e2,0x6b9801bf}},	//   لوت_, rrou_, šķu_, dtug, 
   {{0x3f84026c,0xbea40166,0x7bc0013a,0xdd9000d1}},	//   srou_, _җаек, _srou, شۈش_, 
   {{0x7cec01ab,0xb22000fd,0xb1980a7c,0x6b9803b2}},	//   _bùra, _смсл, _מילכ, ftug, 
   {{0x6b994fbd,0x7cec0e89,0x7bc006be,0x4f9400f3}},	//   gtug, _cùra, _qrou, _арху, 
   {{0x7bc0400c,0x7cec08c2,0x69c002f0,0x2d8588ee}},	//   _vrou, _dùra, _brne, brne_, 
   {{0x69c00072,0x6b9988ef,0x7c840139,0x7bc0045a}},	//   _crne, atug, _зуле, _wrou, 
   {{0x7bc177e3,0x3ead88f0,0x7cfc0006,0xa3c023ef}},	//   _trou, left_, kūri, ंटा_, 
   {{0x81d4000e,0x7bc188f1,0x7d006a2a,0x1ab50a3f}},	//   িনি_, _urou, _imos, _абля, 
   {{0x7cfc0fda,0x9aa4117d,0xf8042f8d,0xaf380092}},	//   dūri, _شمعو, _үчин, ትፈልገ, 
   {{0xd91400c7,0x463000c7,0x00000000,0x00000000}},	//   _идкы, иҕьу, --, --, 
   {{0x3ead88f2,0x00000000,0x00000000,0x00000000}},	//   heft_, --, --, --, 
   {{0x7d0001fa,0x69c00427,0x6eec003b,0xd32400e5}},	// [294b0] _mmos, _zrne, _løba, نٹرٹ, 
   {{0x27f80724,0x3eac00f3,0xf8bc003e,0x737400c7}},	//   şenä_, jeft_, klék_, дыҧх, 
   {{0x7d0188f3,0x8c3c00ee,0x6b9801c4,0x6fb00037}},	//   _omos, reşi, ztug, _इनहू, 
   {{0xd47800c8,0x2d840219,0x62240131,0x7cfc0153}},	//   _קאָל, vrne_, دىمل, būri, 
   {{0xb1900724,0xe9fc01fb,0x4474010f,0x2d84015d}},	//   _әлбә, _khải_, _בערל_, wrne_, 
   {{0x7cec01ab,0x2d841821,0x66140205,0x00000000}},	//   _rùra, trne_, _çekç, --, 
   {{0x623588f4,0x2d8588f5,0x7d000166,0x7cec00a3}},	//   _беру, urne_, _bmos, _sùra, 
   {{0x6b9988f6,0x2d840200,0x00000000,0x00000000}},	//   ttug, rrne_, --, --, 
   {{0x78ac0276,0x3eac257c,0xf8bc0098,0x5f8400d1}},	//   decv, beft_, mléh_, _مۇنە, 
   {{0x69c05f24,0xf8bc011f,0x99d0009e,0x2d840010}},	//   _prne, lléh_, ানৈক, prne_, 
   {{0xca48006c,0x7cec01ab,0x4c9400d8,0x6ce4003b}},	//   بلده_, _iùrn, _аиес, _піде, 
   {{0x69c009a8,0x7cec01c3,0x3af00129,0x00000000}},	//   _vrne, _tùra, _râpe_, --, 
   {{0x6b9988f7,0x6d4988f8,0xe63001e1,0x00000000}},	//   qtug, _iiga, _èfúù, --, 
   {{0x6d4988f9,0xe9fc01fb,0x66840f1c,0x613801e7}},	//   _higa, _chải_, دیدل, míle, 
   {{0x6d4988fa,0x69c188fb,0x7d0000a9,0x00000000}},	//   _kiga, _urne, _ymos, --, 
   {{0x7cfd88fc,0x6d4988fd,0x19b8005b,0x03a41171}},	//   tūri, _jiga, _чушь_, кибо, 
   {{0x6d4988fe,0x032588ff,0x27e401e3,0x00000000}},	// [294c0] _miga, вдан, ämnd_, --, 
   {{0x6d498900,0x8ca02314,0x0738007b,0x00000000}},	//   _liga, क्तो, _تسبب_, --, 
   {{0x6d498901,0x8c3c0356,0x04c800e5,0x00000000}},	//   _oiga, meşu, _ہوگي_, --, 
   {{0x8ca002a0,0xe1f800c7,0x00000000,0x00000000}},	//   _कॉलो, _ҧҳа_, --, --, 
   {{0x3ead8902,0x6eec072b,0x00000000,0x00000000}},	//   teft_, _søba, --, --, 
   {{0x7d018903,0x6d498904,0x795c02b5,0x613800bc}},	//   _smos, _aiga, _hīwe, díle, 
   {{0x6d498905,0x795c02b5,0x3ead8906,0xf8bc003e}},	//   _biga, _kīwe, reft_, bléh_, 
   {{0x6d482720,0x69a86bcf,0x5bb98907,0x3eac282c}},	//   _ciga, _जनजी, елия_, seft_, 
   {{0x7cec01ab,0x6b7001e0,0xab700f15,0x00000000}},	//   _fùrn, алыу, агыш, --, 
   {{0x6d48bf06,0xf8bc003e,0xb87800e5,0x9ad40108}},	//   _eiga, plék_, nkív, ужоч, 
   {{0x6d498908,0x7d001529,0x00000000,0x00000000}},	//   _figa, _tmos, --, --, 
   {{0x6d498909,0x7d001717,0x7cec01ab,0x6139890a}},	//   _giga, _umos, _iùro, bíle, 
   {{0xe9fc01dc,0xb8f82c30,0xaab401b9,0x4a0000c7}},	//   _phải_, _डच_, ردیر_, иҟәа, 
   {{0x8c3c054e,0x00000000,0x00000000,0x00000000}},	//   geşu, --, --, --, 
   {{0x6d49890b,0xf8bc6eb4,0xab241fbe,0x00000000}},	//   _yiga, hléi_, _шоља_, --, 
   {{0x6d49890c,0xfbb41df0,0x65941fbe,0x00000000}},	//   _xiga, _अनाम, јату, --, 
   {{0xa7b8052f,0xe9fc001e,0x386804cc,0xf8bd890d}},	// [294d0] _алыу_, _thải_, mbcr_, mdé_, 
   {{0x8c3d61fc,0x27e5481b,0xf8bc06af,0xef1c012d}},	//   meşt, ämne_, ldé_, ężka_, 
   {{0x8c3c9012,0x62240131,0x658400cf,0x00000000}},	//   leşt, لىكل, _кыяз, --, 
   {{0xf8bd890e,0x00000000,0x00000000,0x00000000}},	//   ndé_, --, --, --, 
   {{0x6d49890f,0x8c3d8910,0x8fa58911,0xf8bc0129}},	//   _riga, neşt, уале, idé_, 
   {{0x6aa42158,0x6d482b10,0x8c3c084c,0xa3c034ef}},	//   _কোনো, _siga, ieşt, ंटर_, 
   {{0x6d498912,0xb4d80ffb,0xf8bc0c6a,0x00000000}},	//   _piga, _diàv, pléh_, --, 
   {{0x6d48036b,0x7cec00a3,0x7cfc0024,0xf8bc0036}},	//   _qiga, _dùro, kūru, bléi_, 
   {{0x8b258913,0xc32c00cf,0xf8bc91f8,0xca743e1f}},	//   лдие, _بەە_, ddé_, луны, 
   {{0x6d48034c,0x92e41c82,0x7cec01e1,0x8c3c3119}},	//   _wiga, বোৰ_, _fùro, deşt, 
   {{0x613800bc,0x48e402e8,0x00000000,0x00000000}},	//   síle, гонв, --, --, 
   {{0x2904068c,0x6d498914,0x8c3c0356,0x61380162}},	//   òma_, _uiga, feşt, píle, 
   {{0xc7940124,0xae040d0a,0xca48036b,0x8c3ce07a}},	//   ырны, _वेतन_, بلگه_, geşt, 
   {{0x2cbc007d,0xf8bc06af,0xaab40243,0x80c80073}},	//   ldud_, adé_, _असिक, _सोने, 
   {{0x795c00b0,0x946002e3,0x8c24015b,0x8c3c054e}},	//   _pīwe, _ụdịd, মেশন_, reşu, 
   {{0xa3c003f3,0xf9900bd9,0x2cbc00af,0x8c3c0276}},	//   ंटल_, _הרה_, ndud_, beşt, 
   {{0x42c98915,0x7330049e,0x7cfc0882,0x8c3c0276}},	// [294e0] нган_, ڭىلا, pūrv, ceşt, 
   {{0x3af0025a,0xc3285734,0x2cbc0213,0x8c3d8916}},	//   _kâpa_, ركان_, hdud_, leşs, 
   {{0x795c02b1,0x00000000,0x00000000,0x00000000}},	//   _tīwe, --, --, --, 
   {{0x5928031c,0x613801ef,0x00000000,0x00000000}},	//   _ལེབས_, dílc, --, --, 
   {{0xdfd58917,0xa3d80882,0x2cbce0aa,0xb4f8011a}},	//   ролы, _ऽपि_, ddud_, _טפטי, 
   {{0xb4d8026c,0x8ca00db3,0xfc500023,0x00000000}},	//   _diàu, क्सो, _ኣበጋግ, --, 
   {{0x8c3c0311,0xbda40c4f,0x9e34013d,0x00000000}},	//   zeşt, احتو, шекч, --, 
   {{0x11f801d9,0x00000000,0x00000000,0x00000000}},	//   _شوقک_, --, --, --, 
   {{0x958002d3,0xfe7000ae,0x00000000,0x00000000}},	//   _ክፍታሕ_, _هدا_, --, --, 
   {{0x8c3d8918,0x00000000,0x00000000,0x00000000}},	//   veşt, --, --, --, 
   {{0xedd016cb,0x8c3c00fd,0xda34248c,0xda780306}},	//   _ٿيند, weşt, рены, raď_, 
   {{0x8c3ce732,0x3ebd8919,0x7cfc0467,0x8f8000c7}},	//   teşt, _hatt_, tūru, _уқәл, 
   {{0x3ebd891a,0xf8bd891b,0x6c78008f,0xdcf8007f}},	//   _katt_, rdé_, _טראד, nsvč, 
   {{0x8c3cade4,0x3ebc0036,0x7cfc02b5,0x569400d8}},	//   reşt, _jatt_, rūru, јавт, 
   {{0x8c3c00a8,0xadc000e4,0x3ebd891c,0x19940209}},	//   seşt, _okẽm, _matt_, _тайя, 
   {{0xa9980375,0x3ebd891d,0x8c3c9736,0xae0400c5}},	//   _נבחר, _latt_, peşt, _वइसन_, 
   {{0xb4b001e0,0x32640108,0xa3d40108,0x00000000}},	// [294f0] _һинә, гтев, ботч, --, 
   {{0x78bc03e3,0x1db40073,0x00000000,0x00000000}},	//   _haqv, ंबात, --, --, 
   {{0x6eec00b5,0x662802fb,0x611c2a92,0x9055891e}},	//   _søbo, čské, zčle, авец, 
   {{0xb4d8004e,0x00000000,0x00000000,0x00000000}},	//   _ciàt, --, --, --, 
   {{0xae1404f2,0x00000000,0x00000000,0x00000000}},	//   گذشت, --, --, --, 
   {{0x3ebc240a,0xb4d808c2,0x59d41bd6,0x00000000}},	//   _catt_, _bhàg, धमार, --, 
   {{0x3ebd891f,0xd22800c6,0x02d00b98,0x00000000}},	//   _datt_, _شكره_, सारभ, --, 
   {{0x78bc014f,0x036801d9,0x611c007f,0x9db801ec}},	//   _naqv, _سٔہی_, tčle, уышу_, 
   {{0x3ebc003d,0xce94016c,0x8ca02a09,0x6018004e}},	//   _fatt_, _вазъ, क्षो, _ботя_, 
   {{0x3ebd8920,0x6eec037e,0xb4d80e89,0x49c98921}},	//   _gatt_, _købm, _fhàg, влон_, 
   {{0xc608045e,0xdcf800e2,0x644000c7,0x3cdc01ec}},	//   _শুনা_, guvē, _úmiv, _ﺃﻗﺩﻤ, 
   {{0x17c407dd,0x1cb4031c,0x3c1c01f2,0x65ac01f4}},	//   әарҭ, _ཞིར_, ịva_, _löhö, 
   {{0x083470c9,0x78bc016d,0x07a407b5,0x3ebd8922}},	//   рхня, _daqv, јагн, _yatt_, 
   {{0x8ca017c6,0x96b80137,0x3ebc0135,0x00000000}},	//   क्रो, лусу_, _xatt_, --, 
   {{0x6efc0153,0x1ae803d4,0xb87800e5,0x00000000}},	//   _išbė, টোহে_, gkís, --, 
   {{0x61380784,0x44658923,0x00000000,0x00000000}},	//   kíla, рвав, --, --, 
   {{0x42558924,0x43842c11,0xcdc400f1,0x473400db}},	// [29500] атет, شلاق, _کښ_, _پرةز, 
   {{0x68e418db,0x795c02b5,0xa2540213,0x61380166}},	//   _hoid, _hīwa, _düşə_, díla, 
   {{0x68e58925,0x795c0374,0x00000000,0x00000000}},	//   _koid, _kīwa, --, --, 
   {{0x3ebd8926,0x68e4aa0a,0xb4d8004e,0x23780014}},	//   _satt_, _joid, _diàs, _مۅرد_, 
   {{0x3ebd8927,0x68e41713,0x81d40154,0x00000000}},	//   _patt_, _moid, িনই_, --, 
   {{0x68e40192,0x3ebc003d,0xb4d801ab,0xa2f4009f}},	//   _loid, _qatt_, _phàg, _ايسڪ, 
   {{0x629c0c8c,0xb4d801ab,0x00000000,0x00000000}},	//   _icro, _tiàt, --, --, 
   {{0x68e58928,0x3ebd8929,0xb4d801ab,0x613801a8}},	//   _noid, _watt_, _ghàd, bíla, 
   {{0x3ebc964d,0x65ac0108,0x00000000,0x00000000}},	//   _tatt_, _yöhö, --, --, 
   {{0x60c1892a,0x68e41554,0x629c0129,0x1df84e10}},	//   _hamm, _aoid, _jcro, _مکعب_, 
   {{0x68e5892b,0x78bc016d,0x32540375,0xaab405d7}},	//   _boid, _paqv, יסים_, _असरक, 
   {{0x60c1892c,0x68e4172e,0x78bc0477,0x8c240011}},	//   _jamm, _coid, _qaqv, মেইন_, 
   {{0x68e5892d,0xeff40020,0x629ce727,0xe7840816}},	//   _doid, _ፈቃድ_, _ocro, жусо, 
   {{0x60c1892e,0x78bc014f,0x27e40267,0x2bc01d94}},	//   _lamm, _waqv, ämna_, वटरा, 
   {{0xbbb49ad9,0x78bc01b9,0x68e5892f,0x94d40212}},	//   _अनुक, _taqv, _foid, бовц, 
   {{0x60c18930,0x1cb40135,0x7af98931,0x68e41cf8}},	//   _namm, _ཞིས_, lhtt, _goid, 
   {{0x56958932,0xb4d80ba1,0x80c80cf1,0x65ac01f4}},	// [29510] _лапт, _biàr, _सोधे, _pöhö, 
   {{0x60c00680,0x629c02c4,0x68e58933,0x32658934}},	//   _aamm, _ccro, _zoid, ртав, 
   {{0x60c00a49,0xb4d98935,0x629c0af9,0xf8bc0098}},	//   _bamm, _diàr, _dcro, blét_, 
   {{0x60c18936,0x629d8937,0x6f600131,0x4fd402dd}},	//   _camm, _ecro, قۇرم, йжет, 
   {{0x60c18938,0xf8bd8939,0xc1a402dd,0x00000000}},	//   _damm, llés_, _қырқ, --, 
   {{0x629c007b,0x60c003ac,0x00000000,0x00000000}},	//   _gcro, _eamm, --, --, 
   {{0x60c1893a,0x6139893b,0xd1bc001f,0x5dd802e8}},	//   _famm, síla, ተቶች_, ифър_, 
   {{0x60c1893c,0xdb00806d,0xf8bc0129,0xa618011a}},	//   _gamm, ltmè, ilés_, יקוד_, 
   {{0x68e5893d,0x795c0374,0xb4d800a3,0xa0c4007b}},	//   _roid, _rīwa, _ghàe, _بيقو, 
   {{0x7af8db94,0x60c1893e,0x68e5893f,0x611c0010}},	//   ghtt, _zamm, _soid, mčla, 
   {{0x68e58940,0x60c18941,0x795c02b1,0xbdb80014}},	//   _poid, _yamm, _pīwa, _منٕچ_, 
   {{0x60c18942,0x68e407d6,0xbd8407d6,0x9ba40014}},	//   _xamm, _qoid, _اچون_, _ژٕنى, 
   {{0x68e58943,0x00000000,0x00000000,0x00000000}},	//   _void, --, --, --, 
   {{0x7af98944,0xf8bc0129,0x00000000,0x00000000}},	//   chtt, flés_, --, --, 
   {{0xf8bd8945,0x795c0053,0x68e4007d,0xc9942303}},	//   glés_, _tīwa, _toid, _العظ, 
   {{0x629d8946,0x6ab41fb2,0x09ac00cc,0xa3bc01ad}},	//   _scro, _असुर, গিদা, _आनद_, 
   {{0xb4d801ab,0xf8bc00cc,0x9abc0327,0x93580114}},	// [29520] _bhàb, rlét_, doċj, арху_, 
   {{0x60c0ec97,0xb4d800a3,0xf8bd8947,0x627400cf}},	//   _samm, _chàb, blés_, تۇسئ, 
   {{0xa494168d,0xb4d84d74,0xf8bc73a0,0x0708352e}},	//   _ویست, _viàr, clés_, _ليکي_, 
   {{0x03a41fbd,0x60c18948,0xf41c9226,0xf8bc1872}},	//   _лимо, _qamm, _idän_, llér_, 
   {{0x60c18949,0xbbb407f8,0x81e400bd,0xb4d800a3}},	//   _vamm, _अनेक, _বেশ_, _fhàb, 
   {{0x63a4398e,0x60c08378,0xeaa402dd,0xd36c2002}},	//   mtin, _wamm, _عع_, _شۇم_, 
   {{0x81e400bd,0x63a5894a,0xc0e00023,0x00000000}},	//   _বের_, ltin, _ቐጠር_, --, 
   {{0xa3bc60c7,0x63a513e9,0x906401ee,0xdc3c0171}},	//   _आना_, otin, _мњђл, ešāk, 
   {{0xbb600241,0x7cec0165,0xf8bc00d0,0xef0c00f1}},	//   _bọọg, _jùri, klér_, _ګټل_, 
   {{0xf2d0008f,0xf8bc74f2,0x00000000,0x00000000}},	//   ִער_, ylés_, --, --, 
   {{0x7dc400f1,0xcdc4014b,0x00000000,0x00000000}},	//   _دقان, _мафқ, --, --, 
   {{0x7e781509,0xf8bc003e,0xa3e802e5,0x7af8036e}},	//   _hetp, coél_, बहा_, shtt, 
   {{0x6cc001d9,0x7e780165,0xdb0001c7,0x00000000}},	//   _رٲوٕ, _ketp, htmé, --, 
   {{0x63a4262a,0x3ce4000d,0xdce803b9,0xba68007b}},	//   dtin, _hoov_, _iqdı, _صحتك_, 
   {{0x3ce401d4,0xf4843e25,0xa5f80220,0x63a529bc}},	//   _koov_, йуан, беру_, etin, 
   {{0x7cec0086,0x63a5894b,0x7e78d540,0xf8bc01ed}},	//   _bùri, ftin, _letp, rlés_, 
   {{0x63a5894c,0x81e44251,0x3ce5894d,0xb33800fd}},	// [29530] gtin, _বেল_, _moov_, _aqça, 
   {{0xe234001f,0x3ce40037,0xf8bd894e,0x00000000}},	//   _ይታመና, _loov_, plés_, --, 
   {{0x91b8cd11,0xb4d801c3,0x63a5894f,0x80c82017}},	//   ргет_, _chàc, atin, _सोहे, 
   {{0x63a58950,0xb4d801ab,0xb11400fe,0x611c0010}},	//   btin, _dhàc, ়ত্ব_, tčla, 
   {{0x63a58951,0x2a880134,0x92580209,0x7e78010e}},	//   ctin, _wɔbɔ_, _вагт_, _betp, 
   {{0x7e78002b,0xfe6c030f,0x9abc003d,0x613801ef}},	//   _cetp, نگم_, soċj, bílo, 
   {{0x3f740034,0xc3300375,0x611c01a6,0xf8bc0c6a}},	//   ału_, _חום_, sčla, toél_, 
   {{0x4b882097,0x7e78057b,0x09d004c5,0x6eec03b2}},	//   айин_, _eetp, াহমা, _møbi, 
   {{0x7e78002d,0x00000000,0x00000000,0x00000000}},	//   _fetp, --, --, --, 
   {{0x7e797f8e,0xc9a811db,0x06ac00cc,0x00000000}},	//   _getp, авое_, _ছোনি, --, 
   {{0x63a58952,0x00000000,0x00000000,0x00000000}},	//   ztin, --, --, --, 
   {{0x63a58953,0x7e7801f5,0xdcf80064,0x00000000}},	//   ytin, _zetp, duvė, --, 
   {{0x2d9400fb,0x2da80150,0x00000000,0x00000000}},	//   _төҙө_, _ﺴﻴﻀﻤ, --, --, 
   {{0x3ce40070,0x09d0009e,0x2b5c003a,0xda0800ec}},	//   _zoov_, াহবা, mquc_, _ڏيهه_, 
   {{0x3ce401d4,0xeb940184,0xb990007b,0x63a46ed1}},	//   _yoov_, _тиҙ_, _قلوب, wtin, 
   {{0x63a58954,0x8afc013a,0x00000000,0x00000000}},	//   ttin, dpři, --, --, 
   {{0x63a58955,0x08f98956,0xb4d801ab,0x00000000}},	// [29540] utin, _مرکب_, _shàc, --, 
   {{0x63a58957,0x7c3400fe,0x00000000,0x00000000}},	//   rtin, _øyre, --, --, 
   {{0x7e78008f,0x80681a59,0x84e4774c,0xf1c000c0}},	//   _retp, لماق_, _донж, _nešė_, 
   {{0x63a58958,0x7e780324,0x4374010b,0x61380306}},	//   ptin, _setp, _мугт, rílo, 
   {{0x63a58959,0x2481895a,0xff2400f7,0xa64400f1}},	//   qtin, maim_, омдо, _بخښن, 
   {{0x2481895b,0x3ce400af,0x80c800e1,0x7e780477}},	//   laim_, _soov_, _सोरे, _qetp, 
   {{0x7e79895c,0xc8c8177c,0x3f74033f,0x00000000}},	//   _vetp, ियाट, słu_, --, 
   {{0x7e783cb1,0x2481895d,0xfba9895e,0x21740117}},	//   _wetp, naim_, атой_, _муғр, 
   {{0x2b7401d5,0x9abc0003,0x00000000,0x00000000}},	//   قینگ_, loċi, --, --, 
   {{0x4420022e,0x00000000,0x00000000,0x00000000}},	//   _mxk_, --, --, --, 
   {{0x24802b92,0x46dc012c,0xda7001d9,0x7c8400f3}},	//   kaim_, मानह, وُک_, _дуле, 
   {{0x7c3c010f,0x24804e79,0x00000000,0x00000000}},	//   _ŝpru, jaim_, --, --, 
   {{0x442002c4,0xed4c00aa,0x2480007b,0xf8bc0066}},	//   _nxk_, _شپه_, daim_, loék_, 
   {{0x7c200ac5,0xdcf80006,0x6eec03b2,0xe9cc00f1}},	//   _ixor, tuvė, _pøbi, رغۍ_, 
   {{0x94d42ed8,0x8ca00c6e,0x613800e4,0x00000000}},	//   повц, क्को, tíll, --, 
   {{0x2458dd4f,0x24f9895f,0x7ae800da,0x248008de}},	//   жать_, онсы_, žotā, gaim_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [29550] --, --, --, --, 
   {{0x28ac5572,0x00000000,0x00000000,0x00000000}},	//   ट्ठि, --, --, --, 
   {{0x24818960,0x320405da,0xe2c92d62,0x00000000}},	//   baim_, àny_, تولو_, --, 
   {{0x1db40490,0x248000ae,0x00000000,0x00000000}},	//   ंबईत, caim_, --, --, 
   {{0x7c200023,0xa0c40b24,0x00000000,0x00000000}},	//   _nxor, بينو, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc33000df,0x00000000,0x00000000,0x00000000}},	//   _נול_, --, --, --, 
   {{0xba74005e,0x8b94de2f,0x4c841436,0x9d441913}},	//   ۋاپت, проч, члив, وئين, 
   {{0x7bc403cd,0x00000000,0x00000000,0x00000000}},	//   åkup, --, --, --, 
   {{0x24800109,0xbb2c00d1,0xdb240241,0x00000000}},	//   zaim_, ﻨﯩﻲ_, _èsìs, --, 
   {{0x7c218961,0xdd000882,0x2b5c003a,0x2d800248}},	//   _exor, ūtān, squc_, _ìje_, 
   {{0x1cb43aaf,0xf41c008e,0x8ca0033f,0xa3bc000d}},	//   _ཞིག_, _adäm_, क्खो, _आनल_, 
   {{0x24818962,0x7af400e5,0x00000000,0x00000000}},	//   vaim_, ágtó, --, --, 
   {{0xb8f019e5,0x36657232,0x7c2c002f,0xfaa0011c}},	//   _हो_, заро_, ßbre, _зашо, 
   {{0x24800bed,0x1a6403e6,0x1fb809ab,0x2904068c}},	//   taim_, _تیپی_, _इन्ड, èjas_, 
   {{0x776c00b5,0x248001ab,0x00000000,0x00000000}},	//   bpcx, uaim_, --, --, 
   {{0x24818963,0xcfe00154,0x389800d9,0xa55c0092}},	// [29560] raim_, _মেঘন, _היפנ, ግባራዊ, 
   {{0x72c001b9,0x9abc031c,0x00000000,0x00000000}},	//   нбуз, toċi, --, --, 
   {{0x1ae8045e,0x24818964,0x00000000,0x00000000}},	//   টোকে_, paim_, --, --, 
   {{0x00e434d8,0x2cac00f3,0x9abc0327,0x00000000}},	//   яжен, _nbgd_, roċi, --, 
   {{0x9f980212,0xb4d80051,0xd05800d4,0x00000000}},	//   івку_, _khàn, ірці_, --, 
   {{0x1cb41efe,0x4374039b,0x00000000,0x00000000}},	//   _ཞིང_, _муҳт, --, --, 
   {{0xb4d801c3,0x00000000,0x00000000,0x00000000}},	//   _mhàn, --, --, --, 
   {{0x6c800873,0xf8bc0098,0xf650011a,0x50940114}},	//   ىلىم, roék_, עצה_, _оруђ, 
   {{0xdd90e0d7,0x00000000,0x00000000,0x00000000}},	//   روک_, --, --, --, 
   {{0xb4d8001e,0x3f840369,0x7c200393,0xf8bc003e}},	//   _nhàn, msou_, _vxor, poék_, 
   {{0x2a64070d,0x3f840587,0xeaf4314c,0x6e9000c6}},	//   _dfnb_, lsou_, ثريت_, _ألما, 
   {{0x7b658965,0x7c2001c0,0xddc98966,0x7cec00a3}},	//   _етке, _txor, _kedž, _cùrt, 
   {{0x3f850c42,0x7c218967,0xddc801fa,0xb4d800a3}},	//   nsou_, _uxor, _jedž, _bhàn, 
   {{0xb4d98968,0xddc80953,0x7bc18969,0x3f8400d8}},	//   _chàn, _medž, _isou, isou_, 
   {{0xb4d800a3,0xfa480132,0x7ae802d0,0xa5f800d3}},	//   _dhàn, _اششى_, _ioft, перу_, 
   {{0x7ae82188,0xa99802e4,0x799843c4,0x65680332}},	//   _hoft, _הבהר, mutw, ídha, 
   {{0x6eec04ce,0xddc80b4b,0x3f85896a,0xb4d801ab}},	// [29570] _købt, _nedž, jsou_, _fhàn, 
   {{0x81b40eac,0x7bc00334,0x3f84007f,0x613801ef}},	//   জিন_, _msou, dsou_, bílk, 
   {{0x79980086,0xea9c0055,0x7ae8b835,0xc690011a}},	//   nutw, _asṛk_, _moft, _באי_, 
   {{0x7bc0037e,0x7ae9896b,0x00000000,0x00000000}},	//   _osou, _loft, --, --, 
   {{0x7999896c,0x7ae80e14,0x8fa40798,0x00000000}},	//   hutw, _ooft, фале, --, 
   {{0x7999896d,0xddc805be,0xcce8013f,0x7ae9896e}},	//   kutw, _dedž, _soכ_, _noft, 
   {{0x7bc0005c,0x1ea8007b,0xaad82052,0x00000000}},	//   _asou, ساوي_, बासक, --, 
   {{0xddc801fa,0x3f840369,0x7999896f,0x518401e0}},	//   _fedž, bsou_, dutw, _нуға, 
   {{0x7ae98970,0x0b4407d6,0xddc853fb,0x0c258971}},	//   _boft, мнин, _gedž, ьмин, 
   {{0x79998972,0x795c00b0,0xcda800c6,0x7ae80200}},	//   futw, _kīwh, _وهذه_, _coft, 
   {{0x7bc18973,0x79988875,0x7ae98974,0x7cec0e89}},	//   _esou, gutw, _doft, _cùrs, 
   {{0x7bc0010a,0x611c0100,0x00000000,0x00000000}},	//   _fsou, yčlm, --, --, 
   {{0xe9d804fb,0xb4d80208,0xc02c0240,0x00000000}},	//   _گذشت_, _phàn, _እናተወ, --, 
   {{0x79998975,0x6b980194,0x7c3400cc,0x3948054e}},	//   butw, muug, _øyra, amcs_, 
   {{0x6b998976,0x35a047ca,0x799802d0,0x00000000}},	//   luug, карг, cutw, --, 
   {{0x6eec037e,0x53c80882,0x2d858977,0x3f840109}},	//   _købs, रिंश, isne_, ysou_, 
   {{0xb4d8431d,0x6b998978,0xdc6c001f,0x98a80327}},	// [29580] _thàn, nuug, _በታሪክ_, _siaħ_, 
   {{0x613961bc,0x2d842759,0x81e40729,0xddc82f61}},	//   míli, ksne_, _বেগ_, _redž, 
   {{0xddd808ad,0x2d84727d,0xddc80b4b,0x6eec00b5}},	//   kavš, jsne_, _sedž, _løbs, 
   {{0x69c00334,0x6b998979,0x3f840100,0x00000000}},	//   _msne, kuug, tsou_, --, 
   {{0xddd808ad,0x6b98013c,0x3f840007,0xb4d800a3}},	//   davš, juug, usou_, _mhàl, 
   {{0xbd68b715,0x3f85897a,0x6b98e2e6,0x69c1897b}},	//   орие_, rsou_, duug, _osne, 
   {{0x3f85897c,0xcd4c00d1,0x2d8400de,0x00000000}},	//   ssou_, ﻟﻨﯩﯔ_, gsne_, --, 
   {{0x7ae8644e,0xddc801fa,0x3b64013e,0x799801c8}},	//   _soft, _tedž, мъов, vutw, 
   {{0x69c00076,0x7ae8084c,0x79980223,0x39480077}},	//   _asne, _poft, wutw, vmcs_, 
   {{0x7ae9897d,0x69c004ce,0x79980337,0x00000000}},	//   _qoft, _bsne, tutw, --, 
   {{0xb4d801ab,0x611c09a8,0x6da0035b,0xd914cf02}},	//   _bhàl, včlj, _аиха, едны, 
   {{0x79985bae,0x6cd09924,0xb4d801ab,0x12e402dd}},	//   rutw, _لقما, _chàl, _ﺍﻷﻤﻭ, 
   {{0x7ae9897e,0x69c1897f,0x7bc18980,0x61398981}},	//   _toft, _esne, _usou, gíli, 
   {{0x7cec01c3,0x79980c8c,0xd7f40139,0x5bbc47b8}},	//   _tùrs, putw, _үзкы, ्टीव, 
   {{0xb4d801ab,0xaad80ebb,0x5ec80154,0xa9c039af}},	//   _fhàl, बारक, লাপে, _асык, 
   {{0x795c02b5,0x61398982,0x00000000,0x00000000}},	//   _rīwh, bíli, --, --, 
   {{0x61398983,0xa87c0375,0x539800c0,0x00000000}},	// [29590] cíli, _ואחר, явая_, --, 
   {{0x795c00b0,0x31640077,0xddd807f5,0xe0d04e5c}},	//   _pīwh, ínzo_, zavš, یزن_, 
   {{0x50b44d87,0x1aac03d4,0x00000000,0x00000000}},	//   еслу, _কোৱা, --, --, 
   {{0x6b998984,0x3ea00107,0x00000000,0x00000000}},	//   yuug, ҳишг, --, --, 
   {{0xb4c800e1,0xbb4000d1,0xa3bc0037,0x5ec800eb}},	//   लयी_, _ﻛﯜﻥ_, _आनए_, লানে, 
   {{0x2d858985,0x795c02b1,0xb4d801ab,0xbea18986}},	//   tsne_, _tīwh, _mhàm, гашк, 
   {{0x61386361,0xddd807f5,0x2d84022f,0x6b981418}},	//   zíli, tavš, usne_, wuug, 
   {{0x61f817c1,0x6b998987,0x620401d9,0x00000000}},	//   øvle, tuug, _شوقٕ, --, 
   {{0x6138d02b,0xcb15797b,0xddd80419,0x2d843bd2}},	//   xíli, ефны, ravš, ssne_, 
   {{0x69c00998,0xddd80e3c,0x7c2c0112,0x6b980009}},	//   _psne, savš, ßbra, ruug, 
   {{0xc33025f9,0xb4d98988,0x6b998989,0xf42000fe}},	//   רוי_, _ahàm, suug, _মৰমৰ_, 
   {{0x6b98000d,0x00000000,0x00000000,0x00000000}},	//   puug, --, --, --, 
   {{0xb4d800a3,0xb8800077,0x7cfc0024,0x00000000}},	//   _chàm, ñías, jūry, --, 
   {{0x61395536,0xe86401c0,0x69c00332,0x00000000}},	//   ríli, эхүү, _tsne, --, 
   {{0x6139898a,0x38680597,0x69c000bc,0xb4d808c2}},	//   síli, éirí_, _usne, _thàl, 
   {{0x1cb41b35,0x07a47d11,0x045800c6,0x436801c6}},	//   _ཞིབ_, _заин, سلطة_, заан_, 
   {{0x44240a16,0x2901898b,0x6f000175,0x00000000}},	// [295a0] ço_, _ilia_, khnc, --, 
   {{0x28ac7df0,0x0cbc07b7,0x37e00408,0xae1c0073}},	//   ट्रि, ्युम, _соьг, यपान_, 
   {{0x29000bed,0x5ec800bd,0x81e4009e,0xb8780306}},	//   _klia_, লামে, _বেজ_, zjím, 
   {{0x0135898c,0x7170036b,0xd5ac0014,0xa2d00709}},	//   رعاد, اهنا, _گہہ_, _डोर्, 
   {{0x61f80194,0x00000000,0x00000000,0x00000000}},	//   øvlb, --, --, --, 
   {{0x8f7402bf,0x6eec01bf,0xdd940166,0x450000eb}},	//   туці, _søbr, вакы, _এদিক_, 
   {{0x795c00b0,0xb87801f1,0x6da010f3,0x2901898d}},	//   _kūwe, rkíz, гија, _olia_, 
   {{0xed5415ed,0x81b40eac,0x90b400f3,0x00000000}},	//   ној_, জিদ_, _иљуш, --, 
   {{0x53c80d01,0x6f0001ab,0xb87800d0,0x5ec80154}},	//   रिएश, bhnc, ujím, লাবে, 
   {{0x2901898e,0xdb000162,0xfaa51bf5,0xdb1c0205}},	//   _alia_, ftmá, хшин, _özüt, 
   {{0x290001c3,0x19c4d73a,0xb4d800a3,0x9f2400d1}},	//   _blia_, тәлг, _shàm, _كۈچۈ, 
   {{0xd0480605,0x290000a3,0x5fa4012d,0x00000000}},	//   _nneɛ, _clia_, _ऐमाल, --, 
   {{0x290000a3,0x35780092,0x00000000,0x00000000}},	//   _dlia_, _ጠብቋት_, --, --, 
   {{0xf9f80156,0xa2d00316,0x7f58003d,0x57e000e1}},	//   ྒྱུན_, _डोल्, _jitq, _पपीह, 
   {{0x7f580d04,0x2901898f,0x35440108,0x00000000}},	//   _mitq, _flia_, ехав, --, 
   {{0x98a4005f,0xb4c81a2a,0xb4d801c3,0x4a680023}},	//   ēlē_, लये_, _thàm, _ተሓተቲ_, 
   {{0x54540a83,0x00000000,0x00000000,0x00000000}},	// [295b0] тват, --, --, --, 
   {{0x7af811a8,0x7f598990,0xe784014b,0x00000000}},	//   nktt, _nitq, _суъо, --, 
   {{0xa2d00574,0x46dc190c,0x00000000,0x00000000}},	//   _डोळ्, मारह, --, --, 
   {{0x7f58003a,0xf8bc0036,0x1c20012d,0x00000000}},	//   _aitq, neé_, मपाल_, --, 
   {{0x7f58014f,0x00000000,0x00000000,0x00000000}},	//   _bitq, --, --, --, 
   {{0xa3c011b1,0xf8bc0418,0x7f580139,0x9f400321}},	//   ूटर_, heé_, _citq, áið_, 
   {{0xa9280313,0xf0000ce8,0xdea46e0d,0x6d440171}},	//   nažé, _әүли, ایمی, _ījab, 
   {{0x8fd000fb,0x0cbc11bc,0x61380162,0xdb0001bf}},	//   _вәкә, ्येम, fílu, ntmæ, 
   {{0x3b80cced,0x7f580393,0xb3380139,0xca74010b}},	//   алыг, _fitq, _aqçi, куны, 
   {{0xdb000579,0xb0e00154,0x1c440022,0x00000000}},	//   ttmá, _মতিঝ, ымыҭ, --, 
   {{0xfde405d9,0x29018991,0xdd958992,0xdb0001bf}},	//   _لکيو_, _plia_, _бахы, ktmæ, 
   {{0xdb000232,0x611c0100,0x80b400cd,0x613808a5}},	//   rtmá, tčli, ोजये, bílu, 
   {{0x3330037e,0x7f58014f,0xdb0002cc,0x00000000}},	//   koxx_, _yitq, stmá, --, 
   {{0x2cbd8993,0xf8c401ed,0xf8bc020c,0xd0540213}},	//   leud_, áért_, woét_, übəl, 
   {{0x795c02b1,0x290008c2,0x4a680023,0xdb0001bf}},	//   _pūwe, _tlia_, _ተሓታቲ_, ftmæ, 
   {{0x2cbc0cfd,0x29018994,0xdb00005c,0xdcf80118}},	//   neud_, _ulia_, gtmæ, dsvě, 
   {{0x42c98995,0x5ec80011,0x00000000,0x00000000}},	// [295c0] мган_, লাতে, --, --, 
   {{0xf8bc00f2,0x2cbc3677,0xfbd000dc,0x05640798}},	//   boés_, heud_, तितम, _ивон, 
   {{0x795c02b5,0x42558996,0x69240841,0x2cbc030a}},	//   _tūwe, ттат, nđeo, keud_, 
   {{0x7f580393,0x00000000,0x00000000,0x00000000}},	//   _sitq, --, --, --, 
   {{0x7f580cfe,0x634400c7,0x2cbc003e,0x333001e7}},	//   _pitq, _бҕаж, deud_, boxx_, 
   {{0xdd918997,0xf8bc06af,0x7f58014f,0xefb001d5}},	//   موت_, mnée_, _qitq, شیمگ, 
   {{0x7f580455,0x2cbc12e8,0xdce800ef,0x5bbc00cd}},	//   _vitq, feud_, _atdā, ्ट्व, 
   {{0x80c8084a,0x2cbc005c,0x7c2c002f,0x00000000}},	//   _सोचे, geud_, ßbro, --, 
   {{0xf8bd8998,0xbfa80050,0x9eb40131,0x7f598999}},	//   nnée_, _تازٕ_, _مەشغ, _titq, 
   {{0x1cb40003,0xf8bc06af,0x3024035b,0x7f580857}},	//   _ཞིམ_, inée_, _роуп_, _uitq, 
   {{0x69240b91,0x2cbc0dd4,0x2ef40ef6,0x7af813ee}},	//   rđen, beud_, _جىلد_, rktt, 
   {{0x98dc012c,0x8ac400c7,0x7af80162,0x69a0000d}},	//   याइए, вқәа_, sktt, _कमरी, 
   {{0x7d01899a,0x69d40077,0xe7840138,0x00000000}},	//   _ilos, _áxen, иуро, --, 
   {{0xf8bc068c,0x39580327,0xaf380092,0x6a10691d}},	//   toés_, _wiqs_, ስፈልገ, ابیر, 
   {{0x7d000bed,0xf8bd899b,0x58d43129,0x613800d8}},	//   _klos, peé_, _бойт, níls, 
   {{0x6925031e,0xc65401ed,0xf8bd1512,0xda3401af}},	//   nđel, افِک, roés_, _иеһы, 
   {{0xf8bc20ef,0x7d000e39,0x27e401e3,0xdfc40244}},	// [295d0] gnée_, _mlos, ämnt_, _بۊ_, 
   {{0x7d01899c,0xb4d80013,0xdb0001bf,0x67d4030d}},	//   _llos, _mhài, stmæ, _тоьу, 
   {{0x7d01899d,0xc8a8069f,0xf41c01b8,0xa8340405}},	//   _olos, _कामट, _adät_, _معیش, 
   {{0xb4d801ab,0x09ac009e,0x61f800cc,0x45f8011a}},	//   _ohài, গিচা, øvla, _נהרג, 
   {{0xaf500131,0x79980112,0x00000000,0x00000000}},	//   андә, hrtw, --, --, 
   {{0x7d01899e,0xdb00049f,0x2cbc00a9,0x00000000}},	//   _alos, ntmä, weud_, --, 
   {{0x7d01899f,0x4c6989a0,0xae0001e0,0x88c80154}},	//   _blos, нийн_, ройҙ, ষাতক, 
   {{0x7d0189a1,0xb4d80e89,0xdb00000d,0xe3b00345}},	//   _clos, _bhài, htmä, _ارێ_, 
   {{0xb4d80e89,0xdb000267,0x2cbd89a2,0x6a800075}},	//   _chài, ktmä, reud_, аһла, 
   {{0xb4d808c2,0x81b4015b,0x7d0189a3,0x613801a8}},	//   _dhài, জির_, _elos, bíls, 
   {{0xb4d800e4,0x20100024,0x613800d7,0xdb240162}},	//   _ehài, ėlių_, cíls, ðsáv, 
   {{0x611c0421,0xb4d808c2,0xc198008f,0xdef80327}},	//   pōle, _fhài, עשרי, _viċe_, 
   {{0xb4d80876,0x799802d0,0xfd540a7c,0xdb00007c}},	//   _ghài, artw, _עשני_, ftmä, 
   {{0x7d00098d,0x6d4801ab,0x96b989a4,0x6b98010e}},	//   _zlos, _hhga, кусу_, mrug, 
   {{0x6b980d04,0x04b589a5,0x00000000,0x00000000}},	//   lrug, лсая, --, --, 
   {{0x3a7091cb,0x19b800a8,0x59a80073,0x00000000}},	//   _кләр, _рушь_, _कमतर, --, 
   {{0x032589a6,0xc29821fa,0x613800d0,0x00000000}},	// [295e0] гдан, етец_, zíls, --, 
   {{0xf8bc0231,0x795c02b5,0x3cd805f9,0x6b985893}},	//   rnée_, _hūwa, _खोने_, irug, 
   {{0x795c1e27,0x6b980042,0x00000000,0x00000000}},	//   _kūwa, hrug, --, --, 
   {{0xbfa834b1,0x6d4800b5,0x3da401b9,0x00846418}},	//   етке_, _nhga, ҳриб, улдо, 
   {{0x31bc0a28,0xb338013d,0xd0f4257b,0x5ec80154}},	//   ānaṃ_, _aqçu, _आवरण_, লাসে, 
   {{0x7d0189a7,0xfbd008df,0x00000000,0x00000000}},	//   _slos, तिसम, --, --, 
   {{0x6d4801fa,0x7d0189a8,0xb4d800a3,0xdb0005ac}},	//   _bhga, _plos, _shài, ntmå, 
   {{0xb884172e,0x6b9989a9,0xb4d80013,0x6d4801d5}},	//   _muíñ, frug, _phài, _chga, 
   {{0x6b9989aa,0x6d480009,0x00000000,0x00000000}},	//   grug, _dhga, --, --, 
   {{0x6d48005a,0xdb00003b,0xba0802e8,0x7d00012d}},	//   _ehga, ktmå, ехме_, _wlos, 
   {{0x6b980d04,0x7d002f07,0x6d4801ab,0x00000000}},	//   arug, _tlos, _fhga, --, 
   {{0x6b9989ab,0x7d0189ac,0xb4d80192,0x8e8000c7}},	//   brug, _ulos, _thài, _лҳәе, 
   {{0xdb0189ad,0x10340023,0x3cd8012d,0xfbd03fe6}},	//   numë, _እናተመ, _खोये_, _دتا_, 
   {{0x3d1801e1,0xdb0000cc,0x6d48036e,0x00000000}},	//   _fàwè_, ftmå, _zhga, --, 
   {{0xb8840005,0xdb0189ae,0xc47001f2,0x28d0012c}},	//   _cuíñ, rtmä, _ọtọb, _तोकि, 
   {{0xdb0189af,0x95c802dd,0x57f4005b,0x00000000}},	//   stmä, нуға_, _впит, --, 
   {{0xd370314e,0x569589b0,0xdb0000d2,0x758022cd}},	// [295f0] زها_, _капт, vumê, _گیزم, 
   {{0x2bb40c2e,0x72290684,0x824002d3,0x00000000}},	//   _अहसा, нцев_, _ክኢላታ, --, 
   {{0x52140261,0x28ac302b,0x00000000,0x00000000}},	//   јдет, ट्कि, --, --, 
   {{0x6b9989b1,0x4fd41583,0xe5c402bf,0x81b40154}},	//   yrug, ижет, _усьо, জিং_, 
   {{0xa2d00574,0x8e840024,0x00000000,0x00000000}},	//   _डोक्, агле, --, --, 
   {{0x6d4801b9,0x6b9805e4,0x00000000,0x00000000}},	//   _shga, vrug, --, --, 
   {{0xbf101eeb,0x00000000,0x00000000,0x00000000}},	//   تووب, --, --, --, 
   {{0x2d6407f5,0xa1585ab1,0x6b9989b2,0xdb0035f5}},	//   _uđem_, _басу_, trug, lumè, 
   {{0x60c400c5,0x00000000,0x00000000,0x00000000}},	//   õime, --, --, --, 
   {{0x6b9976e6,0x795c00b0,0xdb002a4a,0x8cd40a8a}},	//   rrug, _rūwa, numè, _मोरो, 
   {{0x88e44f55,0x2bb40490,0x6b9801a8,0xd1d00092}},	//   ажне, _अहवा, srug, _ጥብቅ_, 
   {{0x6b9804b9,0x290589b3,0x795c02b1,0x229c0241}},	//   prug, óma_, _pūwa, _kákà_, 
   {{0x290c02d5,0xdb0004fb,0x4a7473b5,0x5ec800eb}},	//   ėda_, kumè, _кыйт, লারে, 
   {{0x0500015b,0xdb000efa,0x3d1801e1,0x00000000}},	//   _এদের_, ttmå, _tàwè_, --, 
   {{0x611c7343,0xdb0003cd,0x29d000ef,0x959800db}},	//   hōla, utmå, _uģa_, лтту_, 
   {{0x611c0069,0x795c0374,0xdb00007c,0xc6a40022}},	//   kōla, _tūwa, rtmå, ырҭи, 
   {{0xdb004bc1,0x1aac015b,0x194c00b5,0xd5ac00e5}},	// [29600] stmå, _কোয়া, _ａｋｉ_, وہی_, 
   {{0xdb0000f2,0x00000000,0x00000000,0x00000000}},	//   gumè, --, --, --, 
   {{0x41a81f87,0x806403fb,0x00000000,0x00000000}},	//   твен_, авеж, --, --, 
   {{0xdd9400fb,0xb62c01ec,0x00000000,0x00000000}},	//   ҡалы, _ﺒﺢ_, --, --, 
   {{0xdb000066,0x7ee400db,0x00000000,0x00000000}},	//   bumè, ицке, --, --, 
   {{0x63a589b4,0x7c340217,0x92647531,0xf41c00a2}},	//   muin, _øyri, _هدفم, _idäp_, 
   {{0x63a589b5,0x7de40046,0x194c00b5,0x11d400d3}},	//   luin, рілд, _ａｋｏ_, _літр, 
   {{0xefb003e6,0x0fe800d1,0xf41c01f4,0xd1d00257}},	//   _ژینگ, тләқ_, _meän_, _ጥብቆ_, 
   {{0xdb0006af,0x63a589b6,0x3f6821f3,0x3ea403f5}},	//   lumé, nuin, _ризо_, _визг, 
   {{0x63a40b23,0x00000000,0x00000000,0x00000000}},	//   iuin, --, --, --, 
   {{0x63a589b7,0xd1bc0240,0x00000000,0x00000000}},	//   huin, _ሰቲት_, --, --, 
   {{0xaba40066,0x00000000,0x00000000,0x00000000}},	//   دهیم_, --, --, --, 
   {{0x315400c8,0x63a49c81,0xb4d80e89,0xdb000129}},	//   ייטן_, juin, _mhàt, humé, 
   {{0x63a589b8,0x46dc13f5,0xdb0000d5,0xabf800d9}},	//   duin, मागह, kumé, _בהדר, 
   {{0xb6640020,0xc7ac01ed,0xca60022e,0xc1b0012d}},	//   ዲስማማ_, وڑی_, milа, ीबोग, 
   {{0x63a4a535,0x2ed01bf9,0x00000000,0x00000000}},	//   fuin, _दफ्त, --, --, 
   {{0x63a589b9,0x3264fb98,0x00000000,0x00000000}},	// [29610] guin, атев, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb4d80e89,0x63a41140,0xa88402dd,0xdb00065c}},	//   _bhàt, auin, _الۋى, gumé, 
   {{0x63a589ba,0xb4d801ab,0xca6001b9,0x00000000}},	//   buin, _chàt, hilа, --, 
   {{0x63a4084c,0x28ac1b6e,0xb4d801ab,0x8eb80166}},	//   cuin, ट्टि, _dhàt, гыйт_, 
   {{0x844400aa,0xdb00003e,0x60080111,0x00000000}},	//   _دخپل, bumé, шнім_, --, 
   {{0xb4d800a3,0xa19589bb,0xaca002e3,0xdb0000e4}},	//   _fhàt, _марч, shọn, cumé, 
   {{0xb4d801ab,0x00000000,0x00000000,0x00000000}},	//   _thàu, --, --, --, 
   {{0x9a800020,0x6b4c0158,0x8cb800f2,0xdcc401ec}},	//   _የአካል_, nøgg, ندکس_, іңше_, 
   {{0x0ae880e7,0xca60022e,0xc11001e1,0x49c8009d}},	//   удой_, gilа, _àárú, глон_, 
   {{0x63a40196,0x6b4c0174,0xdef800db,0xc954013d}},	//   zuin, høgg, _тыт_, йтмы, 
   {{0x63a40d04,0xfc7001d3,0x9cfc030d,0xf77c0432}},	//   yuin, _ٹھٹھ, _иччĕ_, lyçy_, 
   {{0x8d7403e6,0x00000000,0x00000000,0x00000000}},	//   _ئاڕا, --, --, --, 
   {{0x2f080162,0xf8bc020c,0x63a44ce6,0x00000000}},	//   _døgg_, rnéa_, vuin, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x63a589bc,0x2f0803d4,0x03a407a5,0x00000000}},	//   tuin, _høgd_, йибо, --, 
   {{0x68e589bd,0x63a40b23,0x044989be,0x70800092}},	// [29620] _inid, uuin, упак_, _ይሠራሉ_, 
   {{0x63a43e7a,0xb4d808c2,0x7c2c03fa,0xdb0097e9}},	//   ruin, _bhàs, ßbri, tumé, 
   {{0x63a589bf,0xb4d800a3,0x68e54756,0x00000000}},	//   suin, _chàs, _knid, --, 
   {{0x63a589c0,0x2f08022c,0xb4d801c3,0xdb000098}},	//   puin, _løgd_, _dhàs, rumé, 
   {{0xdef8052f,0x248189c1,0xdb0189c2,0x3f9000e8}},	//   ғыҙ_, mbim_, sumé, éyu_, 
   {{0x2f096545,0xdd940032,0xb4d808c2,0x24816071}},	//   _nøgd_, ҡаһы, _fhàs, lbim_, 
   {{0x68e589c3,0xb4d801ab,0x71a00c60,0x704401ec}},	//   _onid, _ghàs, _нарз, _ۇركە, 
   {{0x248003f9,0x6b4c2dba,0x907000db,0x71340055}},	//   nbim_, høgd, _قۇمش, _āṇān_, 
   {{0xc0044408,0x611c0093,0xb4f800bc,0x8f7400d4}},	//   _упак, lōlo, _एकसय_, _духі, 
   {{0x68e589c4,0xca6001a9,0x00000000,0x00000000}},	//   _anid, tilа, --, --, 
   {{0x69cc0034,0xb4d80e89,0x8db40153,0x00000000}},	//   łcen, _mhàr, _мсці, --, 
   {{0x6e0410e0,0xca6001d5,0x3ea40244,0x00000000}},	//   _اسكە, rilа, _ئێژێ_, --, 
   {{0xeb94010b,0xdb000217,0x61342e00,0x2bcc0037}},	//   _гич_, ktmø, _gülş, _तईया, 
   {{0x68e40117,0x611c0093,0x00000000,0x00000000}},	//   _enid, kōlo, --, --, 
   {{0x68e401bf,0x156c00d1,0x8aa4003b,0x00000000}},	//   _fnid, _ﻳﺎﺷﯩ, _фрід, --, 
   {{0x68e589c5,0x036800a2,0x00000000,0x00000000}},	//   _gnid, _çaỳg, --, --, 
   {{0x2f0803d4,0xb4d808c2,0x2bd8924b,0xf8bc06af}},	// [29630] _høge_, _bhàr, बिया, lnéo_, 
   {{0x2f0869e8,0xb4d80e89,0x6b4c03b2,0x8c400112}},	//   _køge_, _chàr, røgg, ößig, 
   {{0x24808dbf,0x2bcc547d,0x06880131,0x68e401d5}},	//   bbim_, _तैना, _ﺑﯘﻧﯩ, _ynid, 
   {{0xb4d80022,0xb3d001af,0x681c0055,0x00000000}},	//   _ehàr, _еймә, bādī, --, 
   {{0x60c400af,0xb4d801c3,0x6b4c01bf,0x289c00df}},	//   õima, _fhàr, løge, רידא, 
   {{0x6f8407d6,0xe81c007d,0xb4d808c2,0xaad402e5}},	//   _ҳужж, _पइसा_, _ghàr, _भोंक, 
   {{0xf2cc0154,0x00000000,0x00000000,0x00000000}},	//   রাদণ, --, --, --, 
   {{0x8b9562ea,0x2f080174,0xf8bc0306,0x00000000}},	//   ороч, _søgd_, liéf_, --, 
   {{0x68e4036b,0xaea80066,0x00000000,0x00000000}},	//   _rnid, _مطال_, --, --, 
   {{0x68e4019b,0x3dd0033f,0x2f0801bf,0xed5401b9}},	//   _snid, ływa_, _bøge_, шоқ_, 
   {{0x48e407f7,0x3cd8000d,0x00000000,0x00000000}},	//   टालो_, _खोवे_, --, --, 
   {{0x68e4003a,0x6b4c0158,0xe18002d3,0xdd940124}},	//   _qnid, døge, _ይነብሩ_, _хацы, 
   {{0x4c2401d3,0xf8bc00e5,0x00000000,0x00000000}},	//   _بظاہ, mnél_, --, --, 
   {{0x2bcc2007,0x2c5c00b8,0xf8bc00e5,0xfbc001c8}},	//   _तैया, _vādī_, lnél_, _آڊيٽ, 
   {{0xf7407401,0xdce801e4,0x692400e5,0x00000000}},	//   феро, _sudĉ, tőed, --, 
   {{0xb4d801c3,0xf8bc01d3,0x00000000,0x00000000}},	//   _shàr, nnél_, --, --, 
   {{0x248189c6,0xdb00e73f,0xb4d80192,0x00000000}},	// [29640] rbim_, ttmø, _phàr, --, 
   {{0x681c0029,0x6b4c04ce,0xc8a800ab,0x0574036d}},	//   rādī, bøge, _काँट, _واجد, 
   {{0xf8bc01ed,0x41c4bd92,0x156c00d1,0xc1741d37}},	//   knél_, تقاق, _ﻳﺎﺳﯩ, زدات, 
   {{0x40940220,0xb7d400f1,0x673d89c7,0xdb00383d}},	//   ірет, _اویا_, lorj, stmø, 
   {{0xb4d800a3,0x9abc0003,0x00000000,0x00000000}},	//   _thàr, liċe, --, --, 
   {{0x40c80451,0x673c036e,0xb7d8011a,0x00000000}},	//   _ھوءَ_, norj, יקני, --, 
   {{0x32403cd9,0xd9a81533,0x2cac0175,0xc8a817cb}},	//   _жерг, _कमेट, _bcgd_, _कांट, 
   {{0xdcb00075,0x673c09a8,0xe62801fb,0xd174010b}},	//   رىخ_, horj, _đồ_, _хыры, 
   {{0x2f0804ce,0x81b40eac,0x673d89c8,0x2d8006be}},	//   _søge_, জিও_, korj, _çjen_, 
   {{0x673c0010,0x00000000,0x00000000,0x00000000}},	//   jorj, --, --, --, 
   {{0x69d400cd,0x7f5801ee,0x00000000,0x00000000}},	//   यिषी, _баҡс_, --, --, 
   {{0xf8a819b6,0xf8bc6085,0x9abc031c,0x2fe00139}},	//   جدده_, rnéo_, diċe, _ürgä_, 
   {{0xdcf8005f,0x673d89c9,0xdb0000d8,0x81b40154}},	//   ssvē, forj, lumí, জিট_, 
   {{0x3ce40457,0x7bc00418,0xf8bc0118,0x9abc031c}},	//   _hnov_, _ipou, mném_, fiċe, 
   {{0xf8bc0ac0,0x66b401ee,0xfbd00303,0x00000000}},	//   lném_, ьбру, तिकम, --, 
   {{0x6b4c037e,0x92a80034,0x00000000,0x00000000}},	//   røge, kułó, --, --, 
   {{0x6b4c04ce,0x673d89ca,0xf8bc6815,0xdb0058bb}},	// [29650] søge, borj, nném_, humí, 
   {{0x99e800a2,0xe8ec0139,0x92a8012d,0xf8bc00e5}},	//   _goňü, _kеşе, dułó, znél_, 
   {{0x692456c0,0x9078044e,0xdb0000e4,0x00000000}},	//   rđev, _ብሓይሊ_, jumí, --, 
   {{0x7bc189cb,0x3cd80da3,0x61f801e3,0x260800bc}},	//   _opou, _खोले_, ävla, सनरी_, 
   {{0x72a00131,0x40900137,0x7bc40240,0xf8bc00bc}},	//   _يەرن, رلور, çkul, jném_, 
   {{0xf8bc012c,0x3ce40946,0xa5d800e5,0x00000000}},	//   dném_, _anov_, _ابیر_, --, 
   {{0x7bc00124,0xf8bc01ed,0xf0740116,0x0dc801a9}},	//   _apou, tnél_, _мивә_, ёлий_, 
   {{0x673c151c,0x7d7400c6,0x622400d1,0xe81c000d}},	//   zorj, أمير_, _تۈمە, _पइला_, 
   {{0x2bd8012c,0xf8bc01d3,0x00000000,0x00000000}},	//   बिधा, rnél_, --, --, 
   {{0x795c00b0,0xf8bc01d3,0x9f040137,0xdb0000d7}},	//   _hūwh, snél_, _قوقو, bumí, 
   {{0x7bc189cc,0x673c151c,0x795c02b5,0x2fdc0327}},	//   _epou, vorj, _kūwh, _hrug_, 
   {{0x2fdc098d,0xf8bc0118,0xcb0800ec,0x00000000}},	//   _krug_, bném_, _گيتن_, --, 
   {{0x673d89cd,0x6ad004c5,0xe81c28f5,0x387c0113}},	//   torj, তাবো, _पेशा_, ñura_, 
   {{0x7bd80302,0x00000000,0x00000000,0x00000000}},	//   _לקנו, --, --, --, 
   {{0xb99002dd,0xb4d800a3,0x673c1753,0x00000000}},	//   _كلوب, _phàp, rorj, --, 
   {{0x673d89ce,0x69c00455,0x088802e8,0x9abc0327}},	//   sorj, _ipne, _убий_, riċe, 
   {{0x2fdc0211,0xdb0000bc,0x8cbc448b,0x673c0427}},	// [29660] _nrug_, zumí, व्यो, porj, 
   {{0x27e189cf,0x434400a7,0x00000000,0x00000000}},	//   _irin_, чезв, --, --, 
   {{0xf8bc294d,0x00000000,0x00000000,0x00000000}},	//   zném_, --, --, --, 
   {{0x2fdc105c,0x27e00165,0x92a8012d,0x26d803cb}},	//   _brug_, _krin_, tułó, ldro_, 
   {{0x2fdc0042,0x27e00009,0xdfd001c8,0xef94003b}},	//   _crug_, _jrin_, ئيت_, зкіш_, 
   {{0x26d989d0,0xdd90594c,0x69c00ae3,0x2fdd89d1}},	//   ndro_, نوت_, _opne, _drug_, 
   {{0x629d89d2,0x7bc189d3,0x25b80184,0xf8bc004a}},	//   _idro, _spou, ntrl_, liée_, 
   {{0x27e189d4,0xf8bc29ae,0x2fdc0076,0x629c030a}},	//   _orin_, tném_, _frug_, _hdro, 
   {{0x63a589d5,0xac7189d6,0x3ea40139,0xdb010520}},	//   nrin, رايش, _ниаг, sumí, 
   {{0x999803b7,0xf8bc0ac0,0xb14808a5,0x00000000}},	//   окот_, rném_, _þóró, --, 
   {{0x27e189d7,0x19586264,0xed4c03e6,0xf8bcd43e}},	//   _arin_, жаны_, _ڵپه_, sném_, 
   {{0x27e189d8,0x3ce45dcd,0x26d8ca7e,0x9abc031c}},	//   _brin_, _unov_, edro_, inċi, 
   {{0x27e189d9,0x60c005b1,0x629c44ef,0x63a41096}},	//   _crin_, _mbmm, _odro, jrin, 
   {{0x63a589da,0x27e189db,0xf8bc07ea,0xa3e000ab}},	//   drin, _drin_, diée_, थिन_, 
   {{0x27e189dc,0xf8bc01ed,0xe5c4da86,0xaab8011a}},	//   _erin_, nnék_, нсто, _הזוכ, 
   {{0x63a589dd,0x629c0cfd,0xf8bc20ef,0x26d989de}},	//   frin, _adro, fiée_, adro_, 
   {{0x63a589df,0x2458049b,0x27e01590,0x795c02b5}},	// [29670] grin, зать_, _grin_, _rūwh, 
   {{0x629d89e0,0x69c00175,0x2fdc0240,0xc02403d4}},	//   _cdro, _ypne, _rrug_, _বৰ্ণ_, 
   {{0x320428cb,0x163548db,0x795c0374,0xe73005d9}},	//   ány_, _ценя, _pūwh, _حصي_, 
   {{0x6ebc038e,0x629d89e1,0x2fdc0076,0xdb00004e}},	//   ल्नु, _edro, _prug_, humà, 
   {{0xf8bc07ea,0x3204219b,0x00000000,0x00000000}},	//   ciée_, šny_, --, --, 
   {{0xb8fc0135,0x2fdc05e4,0x2f0803b2,0x69243421}},	//   _ཤལ_, _vrug_, _bøga_, nđer, 
   {{0x30a40cb9,0x795c04fe,0x623409a5,0x068808b0}},	//   _нрав, _tūwh, _зеру, _ﺑﯘﻳﯩ, 
   {{0x629c489c,0x26d8132c,0x2fdc26bd,0xd1087af8}},	//   _zdro, zdro_, _trug_, _بقره_, 
   {{0x2fdd89e2,0x629c0c8c,0xa158d619,0x69c00010}},	//   _urug_, _ydro, _хату_, _spne, 
   {{0x7c2405a4,0x692401a6,0x27e00240,0x5f940a0e}},	//   úkra, jđer, _rrin_, _чифт, 
   {{0x2bd832ed,0x3eb802e2,0x6ce400d4,0x00000000}},	//   बिहा, òpte_, _ніде, --, 
   {{0x27e01142,0x63a4cade,0x9f0801ec,0x26d80042}},	//   _prin_, yrin, _وزەك_, wdro_, 
   {{0x6d5989e3,0xac4800f2,0x63a4022e,0x46b0000d}},	//   mmua, _اجاق_, xrin, _जादह, 
   {{0x63a589e4,0xc6bc0c58,0x6d59183c,0x27e00c86}},	//   vrin, েঞ্চ, lmua, _vrin_, 
   {{0x63a589e5,0x36641f67,0xdb0000d8,0x26d8aa3c}},	//   wrin, даро_, sumã, rdro_, 
   {{0x27e189e6,0xf8bc06af,0x6d5989e7,0x838800d8}},	//   _trin_, tiée_, nmua, жбав_, 
   {{0x27e00986,0x224c009b,0x04440120,0xf8bc01d3}},	// [29680] _urin_, _šdk_, феан, znék_, 
   {{0x63a589e8,0xf8bc5725,0x6d5802d3,0x611c0421}},	//   rrin, riée_, hmua, mōli, 
   {{0x63a589e9,0x611c0270,0xca5400d1,0x99640166}},	//   srin, lōli, _ﺋﺎﺯ_, _ютәл, 
   {{0x63a589ea,0x6d5989eb,0x629c033f,0xf8bc0129}},	//   prin, jmua, _wdro, piée_, 
   {{0x2f080579,0xb3800139,0x63a40009,0x00000000}},	//   _søga_, _илял, qrin, --, 
   {{0xf8bd5efa,0x5ea4036b,0xdb000aab,0x00000000}},	//   tnék_, رمعل, kumá, --, 
   {{0xdb00148b,0xdef801ec,0xdfd000ec,0xdda400c7}},	//   jumá, жық_, ئيڪ_, хылҿ, 
   {{0x6d580218,0xe8e001fb,0x795c02b5,0xed540b3e}},	//   gmua, _trội_, _tūwi, мој_, 
   {{0xdb0019f5,0xefb000f6,0x00000000,0x00000000}},	//   tumà, _لینگ, --, --, 
   {{0x6d58020c,0xaec001af,0x6ff8011a,0xdb00032e}},	//   amua, _ибул, _והמפ, fumá, 
   {{0xf2d00302,0x1bec33ee,0xdb00148b,0x00000000}},	//   דעת_, जमहल_, gumá, --, 
   {{0xb4d80241,0xf7840798,0x6d584498,0x00000000}},	//   _akàn, íços_, cmua, --, 
   {{0xac940502,0x580400db,0xb8640fb4,0x6b4c06ea}},	//   _آنها_, روسك, بادو, søga, 
   {{0x2f0828b3,0x6b4d89ec,0xac0400db,0x2bd801f9}},	//   _løgn_, løgn, _юнча_, बिरा, 
   {{0xdb001475,0xf8bc0221,0x7ae8266b,0x3d0801e1}},	//   cumá, hnéi_, _inft, _jùwo_, 
   {{0x66f80bc7,0x57b402bf,0xa9280306,0x00000000}},	//   _aşkı, _збит, _vyží, --, 
   {{0xf66800c6,0x00000000,0x00000000,0x00000000}},	// [29690] _وحده_, --, --, --, 
   {{0x62240058,0x6d58036e,0x00000000,0x00000000}},	//   چىكل, zmua, --, --, 
   {{0xa738007b,0x62240116,0x00000000,0x00000000}},	//   _تثير_, نىكل, --, --, 
   {{0x6b4c022c,0x64640ba1,0x66f803e0,0xfafc00b8}},	//   jøgn, ütiè, _eşkı, _śīlo_, 
   {{0x2f080e38,0x6d5801d4,0x250848ef,0x8fa521e9}},	//   _døgn_, vmua, _آرپی_, хале, 
   {{0x0594932b,0x00000000,0x00000000,0x00000000}},	//   _تایگ, --, --, --, 
   {{0x6d580023,0x00000000,0x00000000,0x00000000}},	//   tmua, --, --, --, 
   {{0x7e7989ed,0x6d580421,0x2f0803b2,0x6b4c0162}},	//   _eftp, umua, _gøgn_, gøgn, 
   {{0x6d5989ee,0x00000000,0x00000000,0x00000000}},	//   rmua, --, --, --, 
   {{0xa3e000ce,0x6d5989ef,0x89a81422,0x00000000}},	//   थित_, smua, пков_, --, 
   {{0xf8bd89f0,0x9f040137,0x2bcc0950,0x00000000}},	//   ffé_, _جولو, _तैरा, --, 
   {{0x7ae8007f,0x611c0418,0x07a41eca,0xdb0112e3}},	//   _enft, tōli, намн, rumá, 
   {{0xdb0002d2,0x00000000,0x00000000,0x00000000}},	//   dumæ, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x09e45e76,0x00000000,0x00000000,0x00000000}},	//   _чойн, --, --, --, 
   {{0xdef80135,0xc9540139,0x2cbc031c,0xdb0002d2}},	//   _viċi_, _ятлы, nfud_, gumæ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [296a0] --, --, --, --, 
   {{0x068589f1,0xba040020,0x2cbc25a9,0x2f0806ea}},	//   _ягон, _ፎቶ_, hfud_, _søgn_, 
   {{0x73301c5c,0x00c80724,0x00000000,0x00000000}},	//   دىلا, злек_, --, --, 
   {{0x3978008f,0xb234007b,0x00000000,0x00000000}},	//   לטענ, ركنا_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdce800cd,0x2f080174,0x6da0009a,0x00000000}},	//   _audā, _tøgn_, هموم, --, 
   {{0x515400f7,0xd24c03e6,0xfba821cb,0x00000000}},	//   _атуу, _بۆم_, птой_, --, 
   {{0xdf6400c7,0x8c380107,0x6b4c01bf,0x00000000}},	//   _анаҩ, моъӣ_, røgn, --, 
   {{0x6b4c6964,0xb4d801e1,0x00000000,0x00000000}},	//   søgn, _akàl, --, --, 
   {{0xba440323,0x6da189f2,0xddc8033f,0xfce45232}},	//   эхий, _биха, _wzdł, _пожо, 
   {{0x7d04007c,0x00000000,0x00000000,0x00000000}},	//   öksd, --, --, --, 
   {{0x1ce00135,0xdce80055,0x00000000,0x00000000}},	//   _སྣར_, _gudā, --, --, 
   {{0x6b4c00b5,0xf8bc29c2,0x00000000,0x00000000}},	//   nøgl, sfé_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa4d402bf,0x799989f3,0xdb000332,0x00000000}},	//   лосі, mstw, irmí, --, 
   {{0x7998033f,0xdb0001bf,0x8a400133,0xe50800ae}},	// [296b0] lstw, rumæ, _مێین, ريكو_, 
   {{0x1ce00327,0x368822cb,0xe28400d8,0x62980022}},	//   _སྣལ_, _эсин_, глѕи, óvop, 
   {{0x799989f4,0x00000000,0x00000000,0x00000000}},	//   nstw, --, --, --, 
   {{0xdb0000c5,0x7998030a,0x225c0306,0x00000000}},	//   lumä, istw, ývka_, --, 
   {{0x004400f1,0xdb000213,0x00000000,0x00000000}},	//   پیلي_, cumç, --, --, 
   {{0xf3fc01fb,0xdb000793,0x7998000f,0x2f0801bf}},	//   _ngãi_, numä, kstw, _gøgl_, 
   {{0x7998033f,0x3eb8067c,0xdea40f1c,0xdce800cd}},	//   jstw, òpta_, طینی, _sudā, 
   {{0x4c69137a,0xe9801638,0xdb000037,0x8c44190b}},	//   мийн_, ққин, humä, кейе, 
   {{0xdb0033eb,0x799872c4,0x00000000,0x00000000}},	//   kumä, estw, --, --, 
   {{0x229c0085,0x81b4015b,0x49b800c6,0x7998002f}},	//   mákí_, ড়ির_, واجد_, fstw, 
   {{0x229c0085,0x799801a4,0x580401ec,0xdb00000d}},	//   lákí_, gstw, қорғ, dumä, 
   {{0x7b8400d1,0xba218582,0xfdc801d5,0x65c40150}},	//   راۋە, рдюк, _ютуқ_, құма, 
   {{0x7d04049b,0x79980076,0x2f0803b2,0x3cd80073}},	//   ökse, astw, _løgm_, _खोटे_, 
   {{0xb3d402f5,0x6b980728,0xd90c01d9,0x79980210}},	//   সমাজ, msug, ٲیی_, bstw, 
   {{0x55c589f5,0x6b9989f6,0xd90c0133,0xbac00131}},	//   ларғ, lsug, زیی_, ﯩﺴﺴﺎ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x1ce00135,0x0369431f,0x436801c0,0x97c50d39}},	// [296c0] _སྣས_, диак_, даан_, _یتیم, 
   {{0x29016e88,0xdb0000ac,0x733015c3,0x6b9958a8}},	//   _hoia_, rumç, لىقا, isug, 
   {{0x290189f7,0x332001bf,0xf8bc00e5,0x00000000}},	//   _koia_, _dmjx_, rnév_, --, 
   {{0x290189f8,0x6b9989f9,0x10f40139,0xc0040150}},	//   _joia_, ksug, лячя, кпек, 
   {{0x290003c1,0x4a6802d3,0xd12c0137,0x00000000}},	//   _moia_, _ሰዓብቲ_, سۅك_, --, 
   {{0x2900096b,0xdcbc0882,0x3cd816f0,0xde581fe2}},	//   _loia_, ्ज्ञ, _खोजे_, налі_, 
   {{0xf8bc6085,0xa3e021b8,0x23e000dc,0x6b980254}},	//   dién_, थिव_, निवद, esug, 
   {{0x290189fa,0xdb00007c,0x00000000,0x00000000}},	//   _noia_, ntmö, --, --, 
   {{0x6b987bc3,0xb87800d2,0x7998733d,0x6ebc2d8f}},	//   gsug, ndíe, wstw, ल्हु, 
   {{0x290018a6,0x2124003e,0xbae401c0,0x799802d0}},	//   _aoia_, _hmmh_, тций, tstw, 
   {{0x29010ef7,0x6b9989fb,0x2b440175,0x3f84021c}},	//   _boia_, asug, _dknc_, lpou_, 
   {{0xe8e007ae,0x7998068f,0xaa600372,0x2900a3dc}},	//   _trời_, rstw, штык, _coia_, 
   {{0xa9cc03d4,0x2900005a,0xeb9400a8,0x3f844e31}},	//   িমগঞ, _doia_, _аич_, npou_, 
   {{0xf8bc04cf,0x3f840421,0x212401ab,0x79980210}},	//   cién_, ipou_, _lmmh_, pstw, 
   {{0x29001140,0xdb00049f,0x9f4402d3,0x247805db}},	//   _foia_, rumä, _armë_, _ọma_, 
   {{0x290189fc,0xf8bc00d5,0x521401ec,0x660801bf}},	//   _goia_, gnét_, ңдат, ødka, 
   {{0x545589fd,0x6474152d,0x23e0043e,0x5694010b}},	// [296d0] уват, ргуу, निषद, _йапт, 
   {{0x72281064,0xe3b000c6,0xf2e40107,0x00000000}},	//   мцев_, ترف_, ъюбо, --, 
   {{0x7c340008,0x76440014,0xb80400f2,0x00000000}},	//   _þyrf, _شیرِ_, _سبکه, --, 
   {{0x26000316,0x2900056a,0x6b980014,0xf8bc276b}},	//   रहरी_, _xoia_, ysug, mnés_, 
   {{0x1ce0003d,0xf8bc056a,0xa2a000dc,0xa31c0248}},	//   _སྣེ_, lnés_, गृह्, _kọ̀w, 
   {{0xb8785178,0x21240098,0x32d40014,0xa3e007af}},	//   ndíb, _emmh_, _جگرک_, थिर_, 
   {{0xf8bc20ef,0xf41c0036,0x00000000,0x00000000}},	//   nnés_, _geär_, --, --, 
   {{0x6b9989fe,0x2bb40490,0x3f84007f,0xb908002b}},	//   tsug, _आमदा, bpou_, _gniḥ_, 
   {{0x0b447510,0x290002b1,0x6b9951bf,0xf8bc0077}},	//   лнин, _roia_, usug, tién_, 
   {{0x290189ff,0x6b980eda,0xeda4010b,0x9abc0327}},	//   _soia_, rsug, _ашдо, liċj, 
   {{0x6b998a00,0x2900b1a8,0x06881884,0x00000000}},	//   ssug, _poia_, _ﺑﯘﻟﯩ, --, 
   {{0x61f95403,0xf8bc0c6a,0xab600327,0x39580051}},	//   ävli, sién_, _ħżun, _chqs_, 
   {{0x29000276,0x7d1c04e6,0x8ba401d5,0xcba401ee}},	//   _voia_, ëpse, _силж, _салй, 
   {{0xb8e802a0,0x1a2401d9,0x00000000,0x00000000}},	//   _रॉ_, اریُ, --, --, 
   {{0xf8bc07ea,0x29018a01,0x48e401d5,0xdb00007c}},	//   gnés_, _toia_, _бойв, ttmö, 
   {{0xa3e04c1e,0x06840075,0xc1d001e0,0x00000000}},	//   थिल_, _өгин, ҙөгә, --, 
   {{0xf8bd8a02,0xdb003b52,0x9abc031c,0xd4f4010b}},	// [296e0] rnét_, rtmö, diċj, шяры, 
   {{0xb460d40d,0xdb018a03,0xf8bc0098,0xded00023}},	//   скул, stmö, snét_, _ቦታኡ_, 
   {{0x42540588,0x9abc038f,0xc0e410d9,0x9e3c00d7}},	//   утат, fiċj, ложк, _odďa, 
   {{0xc0958a04,0x2f08005c,0x425400db,0x00000000}},	//   اجات, _høgh_, _ەنسر, --, 
   {{0x3f8475b2,0x2088010b,0x00000000,0x00000000}},	//   upou_, ейҗи_, --, --, 
   {{0xf8bc318c,0x6ebc5b29,0x00000000,0x00000000}},	//   nnér_, ल्लु, --, --, 
   {{0x2b040316,0xb87843ed,0xdd9000d1,0x00000000}},	//   ाउनु_, ndíc, زۈش_, --, 
   {{0x5d540261,0x3f85105a,0x5c740d1d,0xef800304}},	//   јкит, ppou_, шлит, шләп, 
   {{0x5b14b7f6,0x2d84b306,0x60c40254,0x00000000}},	//   имит, apne_, õimu, --, 
   {{0xfc4801e1,0x1ee8136e,0x300028e5,0xf8bc0419}},	//   _akíó_, _جوئی_, _узуг, jnér_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8ac400c7,0x32c4022e,0xec7497d0,0x00000000}},	//   гқәа_, zеy_, _бпц_, --, 
   {{0xed5455f0,0xdb0000c6,0x9f458a05,0x2f08005c}},	//   _соц_, armá, _armé_, _bøgh_, 
   {{0x7d018a06,0x3dd0033f,0xa3b807f7,0xf8bc013a}},	//   _hoos, ływu_, घंन_, gnér_, 
   {{0x7d018a07,0x068802dd,0x00000000,0x00000000}},	//   _koos, _ﺑﯘﻛﯩ, --, --, 
   {{0xf8bd8a08,0x7d00b81e,0x23e00456,0x00000000}},	//   rnés_, _joos, निंद, --, 
   {{0x2418c2e2,0x7d00eea1,0xf37401b9,0xd83848e5}},	// [296f0] готы_, _moos, اطرد, _шпиц_, 
   {{0xb87835f5,0x7d018a09,0x05b40066,0x00000000}},	//   bdíc, _loos, دگیت_, --, 
   {{0xd0958a0a,0xef9003e6,0x94740214,0x3f50054e}},	//   ашлы, ڵیاد, _نگذا, râul_, 
   {{0xd0118a0b,0xa264085a,0x00000000,0x00000000}},	//   يلا_, съул, --, --, 
   {{0x35a805f9,0x2f0803b2,0x9abc0327,0x00000000}},	//   _छिड़, _høgi_, riċj, --, 
   {{0xa77c010f,0xabc001e0,0x00000000,0x00000000}},	//   ערופ, ҡайҙ, --, --, 
   {{0x7d018a0c,0x3b2c0092,0x00000000,0x00000000}},	//   _boos, _እሥራኤ, --, --, 
   {{0x7d018a0d,0x7fb400db,0xdde8d204,0x00000000}},	//   _coos, اۇەر_, اروه_, --, 
   {{0x7d018a0e,0x6b4c022c,0x2f080174,0xa3e8012d}},	//   _doos, løgi, _løgi_, _मज़ा_, 
   {{0x16040db3,0x4b24fddb,0xf8bc0de2,0x91c80037}},	//   रहार_, рмов, siél_, _रहाई, 
   {{0x7d018a0f,0xca6001a9,0x4cb80816,0x28500092}},	//   _foos, shlо, _алею_, _መንኮራ, 
   {{0x7d018a10,0xabb01248,0xda59417d,0x3df80375}},	//   _goos, _гадә, ырыш_, _בלעד, 
   {{0x6d498a11,0xcb340395,0x24780241,0x00000000}},	//   _ikga, _кедъ, _ọmo_, --, 
   {{0x7d018a12,0xc6900050,0xcb38010f,0x09e40006}},	//   _zoos, تِس_, _שײַכ, _вокн, 
   {{0x7d0037cf,0xa3b80490,0x00000000,0x00000000}},	//   _yoos, घून_, --, --, 
   {{0xb8780120,0xc484c085,0x7d000067,0x48040798}},	//   rdíc, рлак, _xoos, _впив, 
   {{0x03258a13,0xc3240209,0x4ad80073,0x00000000}},	// [29700] адан, амак, _बघाव, --, 
   {{0xefd0069d,0x060800d8,0x00000000,0x00000000}},	//   _ሩሲያ_, _анок_, --, --, 
   {{0x8068a9f2,0xb87804d4,0xb89001ec,0x47340014}},	//   چماق_, ldía, _الۋع, _مرگز, 
   {{0x6d4854ef,0x3fe41614,0x25400882,0x75980375}},	//   _nkga, ижев, śiṣṭ, _ביטח, 
   {{0x7d018a14,0xb8798a15,0x24800205,0x00000000}},	//   _roos, ndía, mcim_, --, 
   {{0x7d018a16,0x65640014,0x6d493955,0x257cd6dd}},	//   _soos, lmih, _akga, _kíl_, 
   {{0x7d018a17,0x71a06b10,0x6564058a,0xae9400d1}},	//   _poos, _марз, omih, شەنچ_, 
   {{0x65658a18,0x7d001db9,0x5bb98a19,0x24818a1a}},	//   nmih, _qoos, глия_, ncim_, 
   {{0x6e2c0213,0x65640009,0x2b753e06,0x7d009e7a}},	//   _əkbə, imih, لینگ_, _voos, 
   {{0x5b158a1b,0x7d000142,0xdb0003b2,0xeb940798}},	//   смот, _woos, numø, јиќ_, 
   {{0x257c0491,0xbca42614,0x7d018a1c,0xfe400214}},	//   _níl_, _نماي, _toos, _بکشی, 
   {{0xdb00005c,0xfc6402e8,0x248000d7,0xfc2801af}},	//   humø, _кълн, jcim_, _ижек_, 
   {{0xdc54066d,0x1ce00135,0x65658a1d,0x24800009}},	//   _اراک, _སྣག_, dmih, dcim_, 
   {{0x257c0008,0x6564000d,0xab2528d4,0x00000000}},	//   _bíl_, emih, _коча_, --, 
   {{0x257c00bc,0x569402dd,0x7a0806be,0x00000000}},	//   _cíl_, _қант, dətg, --, 
   {{0x257c012c,0x9abc0003,0x00000000,0x00000000}},	//   _díl_, diċi, --, --, 
   {{0xd3708a91,0xabc000d1,0x00000000,0x00000000}},	// [29710] سها_, ﯩﻤﺎﺋ, --, --, 
   {{0x65658a1e,0x257c08ce,0x248000d0,0x9abc025c}},	//   amih, _fíl_, acim_, fiċi, 
   {{0xc6900bd4,0x94d431e2,0xb144029e,0x00000000}},	//   _מאי_, _лонц, لیسم_, --, 
   {{0x7a0800ac,0x24818a1f,0x65640067,0x8f740212}},	//   mətd, ccim_, cmih, букі, 
   {{0xa0c4027d,0x7a080213,0x00000000,0x00000000}},	//   تينو, lətd, --, --, 
   {{0xe3b004d3,0xdce8003a,0xa3ac0ebb,0x9f0400f1}},	//   _کرێ_, _iudę, _गित_, يونو, 
   {{0x1ce00ed9,0x2d90067c,0x62341b0a,0x7a0803e3}},	//   _སྣང_, èxe_, _деру, nətd, 
   {{0x5c740184,0xdb00002f,0x00000000,0x00000000}},	//   ҙҙәр_, hrmä, --, --, 
   {{0x4a7493c9,0x7a0800ac,0x3b8000b1,0xc32c0137}},	//   йынт, hətd, плыг, _تەە_, 
   {{0x6e0000f1,0x69a000fb,0x7a0803e3,0x00000000}},	//   _وېشن, олоҡ, kətd, --, 
   {{0xce5400cf,0x6564058a,0x00000000,0x00000000}},	//   _اپاب, ymih, --, --, 
   {{0x6d480117,0x8934007b,0x257c0332,0xdb00002f}},	//   _ukga, إعدا, _ríl_, ermä, 
   {{0x257c00d0,0xa3ac000d,0x0ae831b1,0x00000000}},	//   _síl_, _गिध_, _مرغي_, --, 
   {{0x257c8aa2,0xdcac0137,0x7a0803e3,0x81dc00eb}},	//   _píl_, _كۉۉ_, fətd, তমত_, 
   {{0xba98025f,0x65641577,0x0578007b,0x24800205}},	//   _עסקי, tmih, امرة_, tcim_, 
   {{0x257c02f0,0x9abc031c,0x65640254,0x00000000}},	//   _víl_, viċi, umih, --, 
   {{0x42c874a1,0x24818a20,0x2f080174,0x83558a21}},	// [29720] лган_, rcim_, _høgu_, مپرا, 
   {{0xb8798a22,0x2480070d,0x65656e97,0x7a080213}},	//   ndín, scim_, smih, bətd, 
   {{0x05280107,0x41a802e8,0xb8780332,0xdb000162}},	//   _бонк_, увен_, idín, rumø, 
   {{0x6b4c06ea,0x2f0803b2,0x7ae400e2,0x9abc031c}},	//   møgu, _møgu_, ēkti, riċi, 
   {{0x6b4c022c,0x6aac00cc,0x2f0803b2,0xd9a4134e}},	//   løgu, জ্যো, _løgu_, _खट्ट, 
   {{0x6e90e8bb,0x00000000,0x00000000,0x00000000}},	//   пишу, --, --, --, 
   {{0x7de40220,0x0eb80724,0xa3e025c9,0xc0e42077}},	//   сілд, ручы_, थिक_, _ловк, 
   {{0x9a280208,0x00000000,0x00000000,0x00000000}},	//   _nươc_, --, --, --, 
   {{0xfe718a23,0x6b4c03b2,0xdb003626,0xf1bc031c}},	//   _فدا_, høgu, yrmä, ġġes_, 
   {{0x3f698a24,0x5a343576,0x7a0800ac,0x7f44005b}},	//   _сизо_, жнот, yətd, _уезж, 
   {{0xb1840023,0x00000000,0x00000000,0x00000000}},	//   _ዝቐንዐ_, --, --, --, 
   {{0x6b4c06ea,0x00000000,0x00000000,0x00000000}},	//   døgu, --, --, --, 
   {{0x6ebc1533,0x395c00e2,0x5d840451,0xdb0004e6}},	//   ल्कु, ķus_, _اڄڪل, nsmë, 
   {{0x81dc045e,0x1ddc38bf,0x7c240008,0x1994010b}},	//   _তপন_, _मनात, úkru, _дакя, 
   {{0x042c001f,0xdb000267,0x00000000,0x00000000}},	//   _በመገን, rrmä, --, --, 
   {{0x2f08cefd,0x7a0803be,0x25ac0308,0x00000000}},	//   _høgt_, rətd, ádla_, --, 
   {{0x9f44013d,0x7a080213,0x00000000,0x00000000}},	// [29730] _armí_, sətd, --, --, 
   {{0x394882b2,0xddc8012d,0x7a0806be,0x00000000}},	//   locs_, _mydł, mətb, --, 
   {{0xb4d80694,0xb878007b,0x55598a25,0x6ad005ac}},	//   _njàg, ndío, _ваня_, তাচো, 
   {{0xe1f000c6,0x90543d6b,0xdb000036,0x6b4c03b2}},	//   عسل_, овец, fsmë, løgt, 
   {{0xb4d801e1,0x83a40022,0x24e4009d,0x8c3c00a2}},	//   _ajàg, _мырҵ, _эцэг, maşg, 
   {{0xb8c80156,0x394804cc,0x2f0803b2,0x8c3c00ee}},	//   _བཧ_, hocs_, _nøgt_, laşg, 
   {{0x6ebc0b6d,0x00000000,0x00000000,0x00000000}},	//   ल्गु, --, --, --, 
   {{0x39480137,0x6b4c3619,0xddc8012d,0x60100022}},	//   jocs_, høgt, _bydł, ẽman, 
   {{0x0c258a26,0x2f08022c,0x02c42894,0x9aa40092}},	//   юмин, _søgu_, र्वभ, _ለአካል_, 
   {{0x2fdc058a,0xdb0035fe,0x8b240212,0x28dc000d}},	//   _isug_, nsmè, ідне, _बसहि, 
   {{0xb8798a27,0x394800cf,0xdcf58a28,0x00000000}},	//   rdín, focs_, _çaği, --, 
   {{0x637001e1,0xf78c0118,0x8ac401d5,0x00000000}},	//   _kónì, ěžné_, ёққа_, --, 
   {{0xdce80118,0xfd240345,0x00000000,0x00000000}},	//   _ludě, _بونێ, --, --, 
   {{0x9f4406ed,0x63700241,0x28dc01f9,0x00000000}},	//   _irmã_, _mónì, _बसवि, --, 
   {{0x63700ca8,0xca6001a9,0x394885b5,0x00000000}},	//   _lónì, chlа, bocs_, --, 
   {{0xdb018a29,0xdeb001e4,0x69c00139,0x00000000}},	//   ysmë, _ĉeƭu, _iqne, --, 
   {{0x6b4c022c,0x68e40332,0x867400c0,0x00000000}},	// [29740] søgu, _iaid, _мынц, --, 
   {{0x27e18a2a,0xdce8012c,0x425403f6,0x5fb8012d}},	//   _isin_, _budě, отет, उंसल, 
   {{0x8c3ceedf,0x37b579e2,0x68e58a2b,0xdb0113e1}},	//   laşd, _བཀོད, _kaid, ermû, 
   {{0x25b80408,0x68e40652,0x29c18a2c,0xdce801ef}},	//   murl_, _jaid, iña_, _dudě, 
   {{0x25b82076,0x68e46b41,0x7050350a,0x5f9401c6}},	//   lurl_, _maid, ونما, чилт, 
   {{0xf4100d65,0x68e58a2d,0x29c00784,0xdb000036}},	//   _חפש_, _laid, kña_, rsmë, 
   {{0x63a58a2e,0x629d8a2f,0x88b0045e,0x26d8070d}},	//   lsin, _iero, ট্যক, iero_, 
   {{0x68e40876,0xf1c0031d,0x2f08037e,0x27e18a30}},	//   _naid, žší_, _søgt_, _osin_, 
   {{0x629d8a31,0x27e18a32,0x29c00407,0x7ed40050}},	//   _kero, _nsin_, eña_, _وٲرا, 
   {{0x629d8a33,0x63a58a34,0x26d98a35,0x68e58a36}},	//   _jero, isin, jero_, _aaid, 
   {{0x68e58a37,0x27e18a38,0x63a4155d,0x8e7431a8}},	//   _baid, _asin_, hsin, _хууч, 
   {{0x629d8a39,0x68e58a3a,0x25b98a3b,0x00000000}},	//   _lero, _caid, durl_, --, 
   {{0x68e58a3c,0x27e01529,0x629d8a3d,0x63a58a3e}},	//   _daid, _csin_, _oero, jsin, 
   {{0x26d89d20,0x25b8010a,0xf10400bc,0x00000000}},	//   gero_, furl_, _शव्द_, --, 
   {{0x27e00cad,0x68e58a3f,0x63a58a40,0x25b98a41}},	//   _esin_, _faid, esin, gurl_, 
   {{0x68e58a42,0x63a58a43,0x6b4c037e,0x8c3c00ee}},	//   _gaid, fsin, søgt, başd, 
   {{0x63a58a44,0x26d98a45,0x27e001c7,0xb8781e0b}},	// [29750] gsin, bero_, _gsin_, ndím, 
   {{0x68e416cb,0xf77052c8,0xa3ac1533,0x26d98a46}},	//   _zaid, _تاع_, _गिर_, cero_, 
   {{0x68e417f3,0x63a5894f,0x25b8037e,0xdb00000d}},	//   _yaid, asin, curl_, dumü, 
   {{0x63a58a47,0x9f44e8c4,0x79880af2,0x60c001f7}},	//   bsin, _armà_, _mtfw, _ccmm, 
   {{0x63a45923,0x29c00784,0x00000000,0x00000000}},	//   csin, zña_, --, --, 
   {{0xf53c03d4,0xfbc002f5,0x29c0bccd,0xdb000254}},	//   _hjå_, ্টাত, yña_, gumü, 
   {{0x798800d2,0x30a41515,0x00000000,0x00000000}},	//   _ntfw, _мрав, --, --, 
   {{0x629d8a48,0x2fdc0218,0xefb80092,0xb8780118}},	//   _zero, _tsug_, ተለው_, udíl, 
   {{0x26d98a49,0x629c8928,0x798802d0,0x68e42278}},	//   yero_, _yero, _atfw, _raid, 
   {{0x68e4a1ef,0x629d2863,0x26d80393,0xf53c0158}},	//   _said, _xero, xero_, _ljå_, 
   {{0x26d98a4a,0x68e4138f,0x63a58a4b,0x79886974}},	//   vero_, _paid, zsin, _ctfw, 
   {{0x63a58a4c,0x27e008cd,0x68e58a4d,0x9f441709}},	//   ysin, _psin_, _qaid, _irmá_, 
   {{0x68e58a4e,0x798800d2,0x25b8030d,0x63a40bc9}},	//   _vaid, _etfw, wurl_, xsin, 
   {{0x68e58a4f,0x25ac0232,0x63a51c6a,0x25b98a50}},	//   _waid, ádlo_, vsin, turl_, 
   {{0x26d98a51,0x63a58a52,0x629d8a53,0x68e58a54}},	//   rero_, wsin, _rero, _taid, 
   {{0x26d98a55,0x629d8a56,0x27e18a57,0x25b8e017}},	//   sero_, _sero, _tsin_, rurl_, 
   {{0x629d8a58,0x63a58a59,0x27e18a5a,0x25b8010a}},	// [29760] _pero, usin, _usin_, surl_, 
   {{0x63a58a5b,0x25b80354,0x1ce00327,0x629c036e}},	//   rsin, purl_, _སྣན_, _qero, 
   {{0x41b4be6c,0x63a58a5c,0x7d040267,0xf678011a}},	//   ясат, ssin, öksk, _לאימ, 
   {{0x63a58a5d,0x629d8a5e,0xdce80115,0xf9900677}},	//   psin, _wero, _budĝ, גרא_, 
   {{0x629d8a5f,0x4abc33af,0x63a58a60,0xd5b001fb}},	//   _tero, ्भाव, qsin, ớc_, 
   {{0xb87801ed,0x629d20cd,0xe8e0004d,0x00000000}},	//   gdíj, _uero, _trỗi_, --, 
   {{0x32418a61,0xdb000254,0x33600a5b,0x00000000}},	//   _зерг, rumü, _чврг, --, 
   {{0x225c02f0,0x50b4004e,0x10e800f1,0x8c3c03b9}},	//   ývku_, _осуу, _وژنی_, daşb, 
   {{0x0dbc044e,0xdb00000d,0x00000000,0x00000000}},	//   ተረፈ_, pumü, --, --, 
   {{0xef1434d8,0x9e74a67e,0xb87802f0,0x66ec000d}},	//   _ему_, _قۇشت, rdím, _छोलक_, 
   {{0x58d86c20,0x13e4009e,0x6d480d12,0xfca80066}},	//   одня_, নময়, ómað, _هاشو_, 
   {{0x47d404c5,0x23ac000d,0x00000000,0x00000000}},	//   দিনী, _चिंद, --, --, 
   {{0xed00fc25,0x798803ac,0xf770621e,0x00000000}},	//   _سووپ, _wtfw, فاس_, --, 
   {{0xf53c1c82,0x0dbc0023,0xdb0003b2,0x39a401af}},	//   _sjå_, ተረፉ_, rumó, _ешив, 
   {{0xf988004b,0xb9e40150,0x661400bc,0x798803ac}},	//   _اخته_, _ءستى, _čeká, _utfw, 
   {{0x2a380375,0xdb0003cd,0x7d04007c,0x00000000}},	//   _לעומ, ermø, öksh, --, 
   {{0xe2c800aa,0x3ce400f3,0xe784005e,0x8c3c0356}},	// [29770] ړولو_, _maov_, _كليپ, maşc, 
   {{0x32640139,0x95d801f0,0x068007a5,0x00000000}},	//   птев, _ддот_, _аҳён, --, 
   {{0x7b14054e,0xc69001e4,0x00000000,0x00000000}},	//   _râul, _שאט_, --, --, 
   {{0xf8bd8a62,0xe1f01b06,0xdb000158,0xd01800d1}},	//   ngé_, دسك_, armø, يقاش_, 
   {{0xf8bc7c92,0x9f841ed7,0x2ef00107,0x00000000}},	//   liés_, егід, нҷар, --, 
   {{0x77740135,0x64404b16,0xf8bc01d3,0xbba4012d}},	//   _jixx, _žmig, gnéz_, _खिड़क, 
   {{0x77740548,0x3ce40fac,0xf8bc0036,0xd5dc012d}},	//   _mixx, _baov_, chég_, मबिज, 
   {{0xdef80327,0x7774031c,0x00000000,0x00000000}},	//   _enċ_, _lixx, --, --, 
   {{0x8c3c0356,0x765401e3,0xa0c4413a,0x7c3401a8}},	//   daşc, _lyxy, _سيلو, _þyrl, 
   {{0xc9a800c9,0x89a94dac,0x777531b2,0x00000000}},	//   овое_, оков_, _nixx, --, 
   {{0x1ce00135,0xdd9405f5,0x1df800c0,0x00000000}},	//   _སྣམ_, _захы, _нефы_, --, 
   {{0xf8bd8a63,0x07a473f7,0x668407d6,0x00000000}},	//   ggé_, мамн, کیدل, --, 
   {{0x2cbd8a64,0x7774022f,0x6698013e,0xf8bc0c6a}},	//   mgud_, _bixx, зёбӣ_, viét_, 
   {{0xf8bc5725,0xa91001e4,0xded01772,0x9408016b}},	//   fiés_, _diɾa, _ቦታን_, _ɔkɔm_, 
   {{0xbb504e25,0x77740003,0xf8bc276b,0xdbd808a5}},	//   _جنوب, _dixx, giés_, _hæða, 
   {{0x2cbd8a65,0x2d50baac,0x00000000,0x00000000}},	//   ngud_, mães_, --, --, 
   {{0x7774208d,0x7d04023a,0x2d50021c,0x00000000}},	// [29780] _fixx, öksi, lães_, --, 
   {{0xf8bc003e,0x00000000,0x00000000,0x00000000}},	//   biés_, --, --, --, 
   {{0xaacc179f,0xf8bd8a66,0x42544727,0xdbd8032e}},	//   त्यक, ciés_, фтат, _læða, 
   {{0xf8bc02fb,0x660801bf,0x10905f32,0x00000000}},	//   liér_, ødku, _ﺟﯩﺮﯨ, --, 
   {{0xdfd18a67,0x777c0e14,0x777405b1,0xbf6405af}},	//   ايت_, _xuqx, _yixx, ودتو, 
   {{0x7774208d,0xaacc00dc,0xf8bc0c6a,0x3ce4022e}},	//   _xixx, त्मक, niér_, _saov_, 
   {{0x98a801fa,0xf8bc011f,0x11b45b66,0x00000000}},	//   _smač_, anéy_, _пётр, --, 
   {{0xfba883b5,0x2cbc011f,0xef1535da,0x00000000}},	//   отой_, ggud_, змә_, --, 
   {{0x237801f4,0x5b140a5b,0x00000000,0x00000000}},	//   _kirj_, емпт, --, --, 
   {{0x7e78004e,0x777c01d5,0x225800ee,0x6e90007b}},	//   _ugtp, _ruqx, _kyrk_, _للكا, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x22580174,0xf8bc002e,0xdbd808a5,0x00000000}},	//   _myrk_, khée_, _fæða, --, 
   {{0xf8bd8a68,0xb4d8002e,0xdbd801a8,0x7774025c}},	//   rgé_, _njàa, _gæða, _pixx, 
   {{0x7774198f,0xf8bd8a69,0x0ba80220,0x09c8009e}},	//   _qixx, tiés_, _ءانى_, ষিজা, 
   {{0x8c3d8a6a,0x94d41677,0x7ae8005f,0xdb0054fc}},	//   maşa, новц, ļotā, nsmí, 
   {{0xf8bc20ef,0x777c208d,0x7774022f,0x38780472}},	//   riés_, _tuqx, _wixx, _ugqr_, 
   {{0x245834d8,0x7774025c,0xf8bc0264,0xf2c4030d}},	// [29790] дать_, _tixx, siés_, дсен, 
   {{0xf8bc0129,0x00000000,0x00000000,0x00000000}},	//   piés_, --, --, --, 
   {{0x7bd40793,0x3330031c,0xd24400c7,0x22580210}},	//   _äyuf, rixx_, хьаҩ, _cyrk_, 
   {{0xa5d8ff4e,0x225808cb,0xdb00032e,0x00000000}},	//   _کبیر_, _dyrk_, dsmí, --, 
   {{0xf8bc4aee,0x337000c7,0x8c3c0205,0x00000000}},	//   chée_, _аҳар, kaşa, --, 
   {{0xdbd80d12,0xb3380139,0xdb00032e,0x00000000}},	//   _ræða, _ovçi, fsmí, --, 
   {{0x2cbc1028,0xc3300a1e,0xe0640014,0x22580108}},	//   tgud_, _עול_, _یێمی, _жиры_, 
   {{0x2d5000d8,0x2cbc12ce,0x2164009d,0x00000000}},	//   vães_, ugud_, _атуг, --, 
   {{0x2cbc0037,0xa05400d4,0x00000000,0x00000000}},	//   rgud_, _авті, --, --, 
   {{0x2d5000d8,0xdbd802d2,0x8c3c010e,0xcb081913}},	//   tães_, _væða, gaşa, سيجن_, 
   {{0xf1dc095f,0x80e000eb,0x00000000,0x00000000}},	//   नबिन, ফার্, --, --, 
   {{0x2d50baac,0x7a0800ac,0x00000000,0x00000000}},	//   rães_, mətl, --, --, 
   {{0xcfcc009e,0x7a0800ac,0x6d5801ab,0x8c3c06be}},	//   লিকন, lətl, mlua, başa, 
   {{0x6d598a6b,0x78b8067c,0x7d04007c,0x04180055}},	//   llua, òuvr, öksv, cūṣa, 
   {{0xf8bc0232,0x7a080213,0xfb180375,0x6d58bc77}},	//   riér_, nətl, _מוסמ, olua, 
   {{0x47c41b4f,0xf8bc39b4,0x6d598a6c,0xd938013d}},	//   _збив, thée_, nlua, _очыш_, 
   {{0x6d598a6d,0xc2b4026a,0x7a080213,0xd574010a}},	// [297a0] ilua, ељењ, hətl, турь, 
   {{0x15b00075,0x7a0800ac,0x66f0013f,0x6d58078c}},	//   _ھەقس, kətl, kɔkɔ, hlua, 
   {{0xf990008f,0x318402dd,0x6d580200,0x02c408a3}},	//   ָרד_, етің, klua, र्गभ, 
   {{0xf8bc7f70,0x00841086,0x7a080213,0xaacc102f}},	//   phée_, хлдо, dətl, त्तक, 
   {{0x6d598a6e,0x22a402b5,0x818000e4,0x8d8801ec}},	//   dlua, tūkē_, _ẽtĩr, _ﻗﺎﺭﺕ_, 
   {{0xde580006,0x5e58deeb,0x6d580254,0x8244010a}},	//   малі_, миля_, elua, _пĕлч, 
   {{0x6d5886ca,0xdef80220,0x8c3c1432,0xcfcc00cc}},	//   flua, зық_, vaşa, লিগন, 
   {{0xa3c405dc,0xb87800c7,0x00000000,0x00000000}},	//   _एमा_, ldív, --, --, 
   {{0xefb01b8d,0xd12c0014,0x00000000,0x00000000}},	//   _مینگ, _بۅن_, --, --, 
   {{0xb878adb8,0x7a0803be,0x6d58c675,0xb4d81574}},	//   ndív, bətl, alua, _njàn, 
   {{0x6d598a6f,0x8c3d8a70,0xdb00014a,0x2e340092}},	//   blua, raşa, kumö, ርቫይዘ, 
   {{0x39a401e1,0x6d5807ea,0x2cac04ce,0xaa600006}},	//   _aísá_, clua, _gdgd_, ытык, 
   {{0xac9400c6,0xdb00000d,0xed4c10e8,0x80d000cd}},	//   _أنها_, dumö, _اپن_, ण्ये, 
   {{0x0e340023,0x7a080213,0x00000000,0x00000000}},	//   _እንኣም, lətm, --, --, 
   {{0xaa558a71,0xa5f80f37,0xe9cc004b,0x7ae801bf}},	//   _пишу_, неру_, _هغي_, _iaft, 
   {{0x7ae98a72,0x92bc00bd,0x57f4446e,0x156c0ed1}},	//   _haft, _আসে_, _апит, _ﺳﺎﺗﯩ, 
   {{0x7ae98a73,0x9724065f,0x7d1c0100,0x660812e8}},	// [297b0] _kaft, _لفظو, èpsy, ødkr, 
   {{0x7a0803be,0x7ae8017a,0x3dd0012d,0xf1a400f5}},	//   yətl, _jaft, ływy_, ердн, 
   {{0x7ae98a74,0xb8798a75,0x6d580393,0x00000000}},	//   _maft, seíd, ylua, --, 
   {{0x7ae85603,0x41d005d7,0x00000000,0x00000000}},	//   _laft, _सहरस, --, --, 
   {{0x6d580218,0xdb000254,0xf8d01fe7,0x00000000}},	//   vlua, lumõ, ध्यय, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe57004fb,0x1ea812fc,0x91c40022,0xdde800ec}},	//   _خطی_, راوي_, _шәал, فريه_, 
   {{0x6d580357,0x7a0803be,0x25ac0306,0x00000000}},	//   ulua, rətl, ádli_, --, 
   {{0x6d589e49,0x0b4407d6,0x7ae98a76,0x09a80490}},	//   rlua, книн, _baft, कळ्य, 
   {{0x7ae98a77,0x6d598a78,0xdce800ef,0xdb000254}},	//   _caft, slua, _budē, kumõ, 
   {{0x7ae98a79,0x7a0800ac,0x6d586fae,0x00000000}},	//   _daft, qətl, plua, --, 
   {{0x2c8401e1,0xa91001e4,0x7d046916,0x63740213}},	//   _dídó_, _viɾo, ökst, rünə, 
   {{0x7ae80421,0xb87800bc,0x39413a74,0x00000000}},	//   _faft, zdív, рняг, --, 
   {{0x7ae8058a,0xf41c0166,0x8c3c0139,0x00000000}},	//   _gaft, _efäk_, laşo, --, 
   {{0x80d02d8f,0xcce8013f,0x6aa00b21,0xb6a18a7a}},	//   ण्डे, _nkכk_, _ienf, рисл, 
   {{0x7ae803f9,0x6aa18a7b,0xdb0001a8,0x00000000}},	//   _zaft, _henf, msmá, --, 
   {{0x03a40364,0x7ae93a4c,0x6aa005c7,0xdb018a7c}},	// [297c0] тизо, _yaft, _kenf, lsmá, 
   {{0xc7640a52,0xdb000793,0x6aa00135,0xc304708e}},	//   _جاعى, sumö, _jenf, خبرو, 
   {{0x6aa18a7d,0x8244074d,0x00000000,0x00000000}},	//   _menf, тĕнч, --, --, 
   {{0xdd94005e,0x6aa18a7e,0xb8798a7f,0x9e3c0030}},	//   ңалы, _lenf, rdív, _neďa, 
   {{0x8c3c0213,0x00000000,0x00000000,0x00000000}},	//   daşo, --, --, --, 
   {{0x6aa0014a,0xdb000413,0x7c3402d2,0x00000000}},	//   _nenf, ksmá, _þyri, --, 
   {{0x20001142,0x7de40046,0x7afc0137,0xcead8a80}},	//   ţii_, тілд, _òpti, _қә_, 
   {{0xaacc726a,0x6aa00036,0xb4d81bce,0x00000000}},	//   त्सक, _aenf, _njàl, --, 
   {{0xafe18a81,0x6aa18a82,0x3ea40124,0xb878804d}},	//   _котл, _benf, _аизг, ndít, 
   {{0xf8e805f9,0x6aa06330,0x8c3c0e2d,0x99980120}},	//   _जोड़ा_, _cenf, maşl, нкот_, 
   {{0xdb00066a,0x8c3c6b5f,0xd1f00b82,0x7ae84e99}},	//   gsmá, laşl, _ፍኖተ_, _vaft, 
   {{0x7ae81d32,0x6aa07664,0xba7401d5,0x60c401c3}},	//   _waft, _eenf, _یاغت, òimh, 
   {{0x7ae8ba9c,0x98a80165,0x6aa00381,0xb8780118}},	//   _taft, _amaă_, _fenf, deíc, 
   {{0x6aa18a83,0x7a0800ac,0x773000c7,0x00000000}},	//   _genf, nətk, рҭоу, --, 
   {{0x46d02894,0xdb0000e5,0xe658009d,0x00000000}},	//   द्धह, csmá, вирч_, --, 
   {{0x6aa01529,0x39ac0024,0xdb000254,0x8c3c0205}},	//   _zenf, męs_, rumõ, kaşl, 
   {{0xaacc143b,0x6aa00007,0x98a80165,0x39ac0024}},	// [297d0] त्वक, _yenf, _emaă_, lęs_, 
   {{0x8c3c0baf,0x6aa001fb,0xb4d80241,0x70b800e1}},	//   daşl, _xenf, _ijàm, उल्ल, 
   {{0xd250f81a,0x2284a6e6,0x39ac02d5,0xca60022e}},	//   حنا_, рууг, nęs_, nklа, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb005266,0xa05402bf,0xb9dc0092,0x8c3c010e}},	//   msmæ, авці, _ቦጅ_, gaşl, 
   {{0xb2840046,0x39ac0006,0xa29400d6,0x059404fb}},	//   _шымк, kęs_, _варі, _جایگ, 
   {{0x6aa18a84,0x39ac02d5,0xdea47811,0x8d543eae}},	//   _renf, jęs_, شینی, лтич, 
   {{0x6aa0008f,0x39ac0006,0x61f8005c,0xdb000388}},	//   _senf, dęs_, ævle, nsmæ, 
   {{0x5ba44ef9,0x6aa013e9,0xb4d80de2,0xc0ec001f}},	//   алығ, _penf, _njàm, ቁንም_, 
   {{0x09e401c0,0xef640395,0xdb0003f2,0xefb80092}},	//   гоон, _ръбо, tsmá, _ታቅዶ_, 
   {{0x6cb034b1,0x39ac0024,0xdb4c0014,0xdb0001bf}},	//   _көпт, gęs_, بێو_, ksmæ, 
   {{0x8c3c864e,0xa3e4033d,0xdb00148b,0x5ce400db}},	//   laşm, _भईल_, rsmá, _ۅكۅل, 
   {{0x6aa0025c,0xdb00037e,0x083400d4,0xaa9001af}},	//   _tenf, dsmæ, ухня, _кѳйә, 
   {{0x81d8000e,0x8c3d8a85,0x7d1c00e2,0xcb38010f}},	//   ়িত_, naşm, ūpst, _רײַכ, 
   {{0xd90c1056,0xb878032e,0x00000000,0x00000000}},	//   سیی_, fdís, --, --, 
   {{0xaacc0404,0x430800b2,0xa5f401c0,0xb87801a8}},	//   त्रक, ڙيءَ_, гүүц, gdís, 
   {{0x29018a86,0x446410ad,0x7a0800ac,0x3fbc00cc}},	// [297e0] _inia_, ував, yətk, _ইন্ষ, 
   {{0x29000211,0xb87800dd,0x8c3c2c78,0x00000000}},	//   _hnia_, rdít, vaşl, --, 
   {{0x290003a2,0xdb00005c,0x8c3c8021,0x00000000}},	//   _knia_, bsmæ, daşm, --, 
   {{0x8c3c62c7,0x7a78010f,0x00000000,0x00000000}},	//   taşl, גרעס, --, --, 
   {{0x2900003a,0x9f4c0432,0x00000000,0x00000000}},	//   _mnia_, _şoña_, --, --, 
   {{0x8c3d8a87,0x81f8025c,0xbb240150,0x00000000}},	//   raşl, དཀྱི_, _ﯼﺎﻫ_, --, 
   {{0xb8798a88,0x29012e4d,0x6da01614,0xc21001d9}},	//   ndír, _onia_, бија, _أز_, 
   {{0x39ac02d5,0xed540640,0x9d140138,0xfca88863}},	//   vęs_, лој_, рдич, رابو_, 
   {{0x7a0803be,0x1da4033f,0x9f4401bf,0x5fc80118}},	//   məti, _गौरत, _ormø_, _रमिल, 
   {{0x29018a89,0x39ac0006,0x4abc00dc,0x7a080213}},	//   _ania_, tęs_, ्भगव, ləti, 
   {{0x13dc015b,0xb90800b8,0xf9340116,0x00000000}},	//   ঠিয়, _kaiḥ_, лүкч_, --, 
   {{0x39ac0006,0x7a0800ac,0xb9080055,0x7f7c02dd}},	//   ręs_, nəti, _jaiḥ_, _ﺎﻭل_, 
   {{0x2900068f,0x6440107d,0xeb958a8a,0x863c0092}},	//   _dnia_, _žmin, _бич_, _አስከት, 
   {{0x29000ca8,0x39ac0024,0x7a080213,0x00000000}},	//   _enia_, pęs_, həti, --, 
   {{0xaab44fb6,0xb4f000f7,0x6ac002dd,0x7a080213}},	//   _صدور_, бүнч, _اقىم, kəti, 
   {{0x290007c5,0xe5340024,0x195841e5,0x00000000}},	//   _gnia_, бесь, _шайы_, --, 
   {{0xb8798a8b,0xdb000388,0x7a0803e3,0x00000000}},	// [297f0] rdís, rsmæ, dəti, --, 
   {{0x9d24022e,0x6474009d,0x00000000,0x00000000}},	//   g双zl, сгуу, --, --, 
   {{0x7a0800ac,0x32641ff1,0xa3d400d1,0x8c3c0342}},	//   fəti, утав, _қорч, vaşm, 
   {{0x4f958a8c,0xdb0001e6,0xd0d400a7,0x7a0806be}},	//   арку, lsmä, родъ, gəti, 
   {{0x3fc98a8d,0xf8bc01d3,0x00000000,0x00000000}},	//   ندوی_, yhén_, --, --, 
   {{0x3ff00372,0xdb005b00,0x00000000,0x00000000}},	//   زكىر, nsmä, --, --, 
   {{0x8c3c1934,0x7a0803be,0xdce80006,0x00000000}},	//   raşm, bəti, _judė, --, 
   {{0x4c858a8e,0x8d758a8f,0xe3b002f2,0x7d0401e3}},	//   шлив, جاتا, _برێ_, öksp, 
   {{0xb4d801e1,0x8c44ab37,0xdb018a90,0x9f042f4d}},	//   _ajàk, репе, ksmä, _گولو, 
   {{0x8c3c6656,0xa2d800cd,0xaa6000fb,0x37c800fe}},	//   laşk, न्प्, йепһ, িবাৰ, 
   {{0x9f058a91,0xdb0001e6,0xdfd0004b,0xdce80064}},	//   _دولو, dsmä, _ويې_, _nudė, 
   {{0x8c3c00fd,0x228c0248,0xdb000037,0x09340006}},	//   naşk, _kòkó_, esmä, рхоў, 
   {{0xdce80064,0x7c5405af,0x00000000,0x00000000}},	//   _audė, _پلور_, --, --, 
   {{0x317c0007,0xb6a007d6,0xf86002bf,0xdb0001e3}},	//   _liuz_, жирл, івро, gsmä, 
   {{0x45358a92,0x7a0803be,0xa2d80d2e,0x15b80166}},	//   ахат, yəti, न्फ्, лыты_, 
   {{0x1cc00156,0xb87804d4,0xa2d8185d,0x04c8007b}},	//   གཔར_, seía, न्न्, ضوئي_, 
  
   {{0xe9a001ec,0x00000000,0x00000000,0x00000000}},	// [29800] _тақп, --, --, --, 
   {{0xd9ec20f0,0x7410007b,0xd5b00051,0x47340066}},	//   _जनमत_, غولا, ấc_, _خربز, 
   {{0x673c1fe6,0xf8bc002e,0xb9080055,0x8fd400fb}},	//   mirj, khél_, _paiḥ_, ҙәтә, 
   {{0x661c1368,0x46d02c2e,0xf1d4012d,0x673d8a93}},	//   myrk, द्रह, _ठहरन, lirj, 
   {{0x317c0097,0x7a0800ac,0xf8bc0214,0xadc001e1}},	//   _diuz_, rəti, dhél_, _ilẹm, 
   {{0xa91001e4,0x673d7b21,0x7a0800ac,0xc92032ed}},	//   _diɾi, nirj, səti, मसुम_, 
   {{0x3204049b,0x3240ada6,0x661d22ac,0xc0e400f5}},	//   änyt_, _дерг, nyrk, _ковк, 
   {{0x317c0007,0x673d8a94,0x228c0241,0x387c0e3c}},	//   _giuz_, hirj, _fòkó_, žuri_, 
   {{0x673d8a95,0xdb0007d9,0x0c8c0092,0x00000000}},	//   kirj, ysmä, ፒታሎች_, --, 
   {{0x661d8a96,0xdb00168c,0xfbd00014,0x00000000}},	//   kyrk, ksmå, ٕتھ_, --, 
   {{0xd5b001fb,0x429002d3,0x661c0254,0xf1c00208}},	//   ới_, _ዝዀነት_, jyrk, _ngờ_, 
   {{0x8ac403a5,0x661c1347,0xdb001347,0x6cc00108}},	//   ақәа_, dyrk, dsmå, _дёше, 
   {{0xdce802d5,0xdb005df4,0x673c0010,0x9b9400ae}},	//   _sudė, tsmä, firj, _التت, 
   {{0xadc001e1,0x69cc0276,0x673c0024,0x7d0002d2}},	//   _alẹm, ăcer, girj, _hnos, 
   {{0xdb018a97,0x74a40120,0x00000000,0x00000000}},	//   gsmå, ијае, --, --, 
   {{0x779000f1,0x79980857,0xe8180133,0xdb0001e3}},	//   _ویجا, mptw, ازێت_, ssmä, 
   {{0x317c0007,0xb9fc001f,0x673c4c91,0xdb0001e3}},	// [29810] _riuz_, _ፀረ_, birj, psmä, 
   {{0x81c00c58,0x673d8a98,0x00000000,0x00000000}},	//   ্বন_, cirj, --, --, 
   {{0x7d0004c9,0x940400ac,0xf41c013d,0xceb81321}},	//   _onos, _ələ_, _afät_, ғәз_, 
   {{0x7d0001ee,0x154401ec,0x818000c7,0x8a78010f}},	//   _nnos, _اۋرۋ_, _ẽtér, אָנק, 
   {{0xef918a99,0xa3c40d2e,0x7a0806be,0x00000000}},	//   زیاد, _एमए_, mətu, --, 
   {{0x7d018a9a,0xbea00408,0xa9100115,0x3ea001b9}},	//   _anos, пашк, _viɾi, пишг, 
   {{0x8c3d8a9b,0xf8bc0036,0x00000000,0x00000000}},	//   maşi, ckég_, --, --, 
   {{0x4c684e90,0xcd0468ae,0x673d4158,0xfe6c7405}},	//   лийн_, спий, zirj, رگل_, 
   {{0x7d000334,0x5f94c526,0x7b14054e,0x00000000}},	//   _dnos, _митт, _râur, --, 
   {{0x7d000fb7,0xb87960b7,0x37bc015b,0x4b240798}},	//   _enos, teín, েবার, смов, 
   {{0x673c151c,0xdd940022,0x5f74007b,0x7a0806be}},	//   virj, _дахы, _ذاكر, kətu, 
   {{0xaa54044e,0xdb000158,0x661c0158,0x673c0e02}},	//   _ላዕለዋ, vsmå, vyrk, wirj, 
   {{0x673d8a9c,0xa2d8190e,0xb87810d8,0xf8bc0118}},	//   tirj, न्ड्, seín, chém_, 
   {{0x661d8a9d,0x6370007d,0xdb004cab,0x6b998a9e}},	//   tyrk, mäng, tsmå, mpug, 
   {{0x63718a9f,0x36c18aa0,0x673d8aa1,0x8c3c03e0}},	//   läng, ябрг, rirj, daşi, 
   {{0x6ab40c70,0xdb001f53,0x88c89fb7,0x19b8c133}},	//   _आयुर, rsmå, _слив_, _тушь_, 
   {{0x673c151c,0x6b98089c,0xe79428b1,0xdb000217}},	// [29820] pirj, npug, _بابک, ssmå, 
   {{0x27e00ca8,0x1cc00156,0x673c0054,0x661c0649}},	//   _ipin_, གཔོ_, qirj, pyrk, 
   {{0x63718aa2,0x84e401f4,0x00000000,0x00000000}},	//   häng, _лонж, --, --, 
   {{0xa2d803f3,0x27e0003e,0x6d480083,0xf9900375}},	//   _नॉर्, _kpin_, _njga, פרד_, 
   {{0x78a80254,0x6564025c,0x637001e3,0x8c3c453a}},	//   _õgve, mlih, jäng, başi, 
   {{0x7d0056c0,0x6370025a,0x26d800a9,0x7998035a}},	//   _snos, däng, nfro_, yptw, 
   {{0x6da007b5,0xf2a00114,0x00000000,0x00000000}},	//   пија, _хисп, --, --, 
   {{0x63718aa3,0x27e028a1,0x9d191e4c,0x26e42b1b}},	//   fäng, _opin_, роит_, খাটো_, 
   {{0x63718aa4,0x7d00151c,0x6b98d2b2,0xa2d81d27}},	//   gäng, _vnos, gpug, न्थ्, 
   {{0x7d00012d,0x6370002f,0x2b7400f2,0x00000000}},	//   _wnos, sänf, مینگ_, --, 
   {{0x63718aa5,0xbca517a3,0x27e130d2,0x6b980ffb}},	//   mänd, _هماي, _apin_, apug, 
   {{0x63718aa6,0xa2d98aa7,0x19595ab3,0x225c02fb}},	//   länd, न्त्, рамы_, ývky_, 
   {{0x6c801e95,0x26d98aa8,0x6bd000be,0x65658aa9}},	//   _علوم, ffro_, _فتور, dlih, 
   {{0x59f8084c,0x6370cc35,0x98b802e2,0x7a0803e3}},	//   _векя_, nänd, misč_, fətt, 
   {{0x27e0030d,0x58d4c10f,0xb4f000d1,0x65658aaa}},	//   _epin_, _дойт, пүнч, flih, 
   {{0x3eac928b,0x63703714,0x656451e2,0x95c80046}},	//   haft_, händ, glih, луға_, 
   {{0x63714800,0x3ead10de,0x8c3c054e,0x98b8007f}},	// [29830] känd, kaft_, taşi, nisč_, 
   {{0x79898aab,0x7a0800ac,0x65646607,0x46a800bc}},	//   _kufw, bətt, alih, करणह, 
   {{0x3cfc4802,0x65658aac,0x3eac003e,0xa2d8aa34}},	//   _शोभे_, blih, daft_, न्ध्, 
   {{0xddd58aad,0xe298024c,0x7a080213,0x00000000}},	//   _şaşk, _ҳаё_, ləts, --, 
   {{0xd0098aae,0x8e841377,0xf8bc004a,0xb36400a7}},	//   реле_, огле, ckée_, _гъвк, 
   {{0xa2d80b98,0xd5dc05f9,0x63714800,0x3ea00051}},	//   न्द्, _पहाड़, gänd, _đktc_, 
   {{0x9f440789,0x8d7400c6,0x271c008f,0x6370002f}},	//   _armó_, يابا, רווײ, wäng, 
   {{0x63702776,0xa63c0302,0x7d7401f7,0x0c2401b9}},	//   täng, טגור, يمور_, жмин, 
   {{0x63718aaf,0x7988481f,0x6b981140,0x26d80142}},	//   bänd, _aufw, upug, yfro_, 
   {{0x63718ab0,0x6b998ab1,0x4aa821a8,0x8c3c43bc}},	//   räng, rpug, шкон_, kaşv, 
   {{0x6b998ab2,0x65658ab3,0x4c9400ee,0x88e4e99a}},	//   spug, ylih, _диес, ожне, 
   {{0x2ee401ee,0x6b9820ac,0x63718ab4,0x27e0003e}},	//   lenf_, ppug, mäne, _ppin_, 
   {{0x637170b5,0x6d58ea98,0x290471e1,0xd5b0004d}},	//   läne, moua, ıma_, ấn_, 
   {{0x81c00729,0x6d598ab5,0x65640014,0xdebc0023}},	//   ্বত_, loua, wlih, _ታትን_, 
   {{0x6b898ab6,0x6b818ab7,0x65658ab8,0x798800ca}},	//   _hugg, _iing, tlih, _gufw, 
   {{0x6b818ab9,0x6b890165,0x65640d04,0x6d598aba}},	//   _hing, _kugg, ulih, noua, 
   {{0x6b88b03b,0x65658abb,0x27e00ac5,0x6b818abc}},	// [29840] _jugg, rlih, _upin_, _king, 
   {{0x6b802f6e,0x6b898abd,0x6d598abe,0x63708b82}},	//   _jing, _mugg, houa, käne, 
   {{0x63718abf,0x6b818ac0,0x6d597a39,0x6b8885d8}},	//   vänd, _ming, koua, _lugg, 
   {{0x6b818ac1,0x6d598ac2,0x80640801,0x63718ac3}},	//   _ling, joua, овеж, wänd, 
   {{0x637167fb,0x6d598ac4,0x6b800c8c,0x6b8817c7}},	//   tänd, doua, _oing, _nugg, 
   {{0x44300354,0xd5b00208,0x63700166,0x00000000}},	//   mzy_, ớt_, fäne, --, 
   {{0x63718ac5,0x52b00075,0xdb001455,0x6b880194}},	//   ränd, _سەنئ, msmø, _augg, 
   {{0x6b818ac6,0x6370049f,0x6d58030a,0x1ee801d3}},	//   _aing, sänd, goua, _گوئی_, 
   {{0x6b88102c,0x00000000,0x00000000,0x00000000}},	//   _cugg, --, --, --, 
   {{0x6b881574,0x6b818ac7,0xfec8021a,0xdb002d75}},	//   _dugg, _cing, _خبرو_, nsmø, 
   {{0x6b8072a1,0xdc541dd8,0xb8780124,0x69d40139}},	//   _ding, _کراک, reím, _äxel, 
   {{0x6b818ac8,0x6b898ac9,0xb4d819f5,0x443004cc}},	//   _eing, _fugg, _imàg, kzy_, 
   {{0x6b818aca,0xdb000162,0xb8642ed7,0x00000000}},	//   _fing, ksmø, تادو, --, 
   {{0x4430068f,0x6b818acb,0xb5a41b0a,0x8c3c0356}},	//   dzy_, _ging, жрай, gaşu, 
   {{0xdb00bc85,0x6b88002f,0x65958acc,0x63700139}},	//   dsmø, _zugg, дасу, känb, 
   {{0x6b80541f,0x81c00eac,0x27140166,0xa2d81c54}},	//   _zing, ্বা_, _aşnı_, न्स्, 
   {{0xc0e00023,0x0fc400cc,0x4430010e,0x00000000}},	// [29850] _ነበሮ_, _এন্ধ, gzy_, --, 
   {{0x6b818acd,0xb4d8026c,0x8c3d8ace,0xdb000162}},	//   _xing, _omàg, maşt, gsmø, 
   {{0x8c3c2706,0x4430b85f,0xc69000df,0x00000000}},	//   laşt, azy_, _ראט_, --, 
   {{0xc0e02295,0xdb000158,0xb87800c7,0x85f8010f}},	//   _ነበር_, asmø, jeík, _פּיק, 
   {{0x4430006d,0x6d598acf,0x8c3c0724,0x8fa4a319}},	//   czy_, voua, naşt, чале, 
   {{0xf3fd8ad0,0x637002f6,0xe7e00cb4,0x6b8826de}},	//   _irã_, täne, खौटा_, _rugg, 
   {{0xd0080184,0x6b898ad1,0x6d598ad2,0xca8405f5}},	//   реһе_, _sugg, toua, үгий, 
   {{0x6b898ad3,0xf3fc0004,0x637000fd,0x3f103052}},	//   _pugg, _krã_, räne, ддәс, 
   {{0x6b818ad4,0x6d598ad5,0x10a41b15,0x23840014}},	//   _ping, roua, _миңн, _رٔہِ, 
   {{0x49c8bcf8,0x6b894094,0x6d580607,0x637001b8}},	//   блон_, _vugg, soua, päne, 
   {{0x6b818ad6,0x44318ad7,0x6d58ea26,0x9c2400db}},	//   _ving, zzy_, poua, здөд, 
   {{0x443000ee,0x6b898ad8,0x6b818ad9,0x00000000}},	//   yzy_, _tugg, _wing, --, 
   {{0xc7957e0f,0x00000000,0x00000000,0x00000000}},	//   ярны, --, --, --, 
   {{0x6b818ada,0x32c400c5,0x00000000,0x00000000}},	//   _uing, _लागऽ, --, --, 
   {{0x8c3c0724,0xf3fc035b,0xc6080154,0xda080451}},	//   raşu, _arã_, রন্থ_, _ويهه_, 
   {{0xf3fc0004,0x44300267,0x8c3d8adb,0x00000000}},	//   _brã_, tzy_, başt, --, 
   {{0xc324010b,0xdb0021e3,0x02040107,0x765803e0}},	// [29860] пмак, tsmø, ӯзан, ğuya, 
   {{0x44308864,0xf3fc0004,0x613c03b9,0xdecc0023}},	//   rzy_, _drã_, _içlə, ኡትን_, 
   {{0x44258adc,0x4430006d,0xf3fc07dd,0xac8802dd}},	//   šo_, szy_, _erã_, _өзiн, 
   {{0xf3fc0589,0xdb000b1a,0x86c400ec,0xd1380006}},	//   _frã_, ssmø, _بيگن, охі_, 
   {{0xf3fd8add,0xdb000217,0x3f680fbe,0x8d6c0092}},	//   _grã_, psmø, бидо_, ስከትል_, 
   {{0x3eb8045f,0xd36c00cf,0x3da4003b,0x00000000}},	//   ûpt_, _نۇق_, приб, --, 
   {{0xefb80023,0x81340024,0x11b4014b,0x00000000}},	//   ደለየ_, _ехац, _оётр, --, 
   {{0xdb998ade,0x7c94007b,0x00000000,0x00000000}},	//   ович_, أشغا, --, --, 
   {{0xa0340228,0x00000000,0x00000000,0x00000000}},	//   _تۉشت, --, --, --, 
   {{0xab9400c6,0x8c3c05d1,0xb8780162,0x00000000}},	//   أخير_, vaşt, lfíg, --, 
   {{0xfce4d646,0xada110a0,0x5be40014,0xb8780022}},	//   _ножо, _захл, ستکہ, peík, 
   {{0xdcb001ec,0xd5b00208,0xb87803b2,0x00000000}},	//   _شىت_, ấm_, nfíg, --, 
   {{0x8bf00124,0x394801e2,0x3dbc0183,0xb4d801e1}},	//   _аҧых, rncs_, _আহিল, _ojàr, 
   {{0x8c3c0724,0xb4d800e8,0x00000000,0x00000000}},	//   raşt, _njàr, --, --, 
   {{0x6458467d,0xb8780077,0xaad80375,0x7bc403b2}},	//   şvil, ndíz, _החור, ákuf, 
   {{0xf3fc0c67,0x00000000,0x00000000,0x00000000}},	//   _prã_, --, --, --, 
   {{0x7d04005b,0xb86401d3,0xe4558adf,0x00000000}},	// [29870] öksy, _ڈاکو, екты, --, 
   {{0xb8647aaf,0x00000000,0x00000000,0x00000000}},	//   _واکو, --, --, --, 
   {{0xe7ec0139,0x151801ee,0x00000000,0x00000000}},	//   _käşç, _донъ_, --, --, 
   {{0xf3fd8ae0,0x70a400bc,0xf8bc9f23,0xb8780166}},	//   _trã_, खरेल, ्लिय, ddíz, 
   {{0xe0d065a2,0xf3fc035b,0xf0740075,0x00000000}},	//   ازم_, _urã_, чидә_, --, 
   {{0xb87800e4,0x6614010e,0xccf80210,0x00000000}},	//   reíh, _ýekä, kośc_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xefb80092,0x00000000,0x00000000,0x00000000}},	//   ሰለው_, --, --, --, 
   {{0x92c00183,0x6370014a,0x00000000,0x00000000}},	//   ্জী_, läna, --, --, 
   {{0x81c003f4,0x511c0037,0x00000000,0x00000000}},	//   ্বর_, _भकुआ_, --, --, 
   {{0x637001b8,0xdb2001d3,0x00000000,0x00000000}},	//   näna, ótáj, --, --, 
   {{0x98b80270,0xd8e80327,0x00000000,0x00000000}},	//   tisā_, _ཧྲཱི, --, --, 
   {{0x8c3c09a5,0xb4d81bce,0x63700108,0x00000000}},	//   raşs, _njàq, häna, --, 
   {{0x63718ae1,0x7c24143a,0x00000000,0x00000000}},	//   käna, økre, --, --, 
   {{0x637001e6,0xea600046,0x00000000,0x00000000}},	//   jäna, _سۇحپ, --, --, 
   {{0x637029ef,0x8c3c0dde,0x00000000,0x00000000}},	//   däna, laşq, --, --, 
   {{0x3a700116,0x2cac03b2,0xe9fc0208,0x475800c0}},	// [29880] _пләр, _megd_, mlằm_, _мроя_, 
   {{0x2cac0158,0x08e800cc,0xd5b00208,0x6844014b}},	//   _legd_, গাওঁ_, ớp_, _онқа, 
   {{0x9e3c013a,0x00000000,0x00000000,0x00000000}},	//   _jeďt, --, --, --, 
   {{0x98b80311,0x53a80490,0x2cac0334,0x00000000}},	//   misă_, _चौकश, _negd_, --, 
   {{0xb8780174,0x00000000,0x00000000,0x00000000}},	//   rfíg, --, --, --, 
   {{0x6e200042,0xb8780174,0xf834011a,0x00000000}},	//   fynb, sfíg, וננת_, --, 
   {{0x66e0007d,0x63700139,0xdd909cba,0x00000000}},	//   ख्यक_, cäna, دوب_, --, 
   {{0x9bf4e91f,0x00000000,0x00000000,0x00000000}},	//   езич, --, --, --, 
   {{0x98b80276,0xd175645d,0x6f90007b,0x06c400eb}},	//   hisă_, _чыры, _للقض, শ্যি, 
   {{0xb8780789,0x9e740220,0x00000000,0x00000000}},	//   nfíe, _كۇشت, --, --, 
   {{0x3ebcd5c3,0xdb00003a,0xb87800c7,0x6d4803f2}},	//   _idtt_, msmü, neív, ðmað, 
   {{0xb4d80de2,0x2548029f,0x2984004e,0x06c400eb}},	//   _njàp, oğlu_, кыяг, শ্মি, 
   {{0x3164019f,0x8e8007dd,0xf8bc0165,0xb70c074d}},	//   înzi_, _иҳәе, bkén_, аçнă_, 
   {{0xf53c00cc,0xdb00b1e1,0x2c18012c,0x63718ae2}},	//   _små_, nsmü, यहरू_, yäna, 
   {{0x6d8401ed,0xdef80135,0x98a80219,0x7c2c01e4}},	//   _műan, _maċ_, _hlač_, ĝbru, 
   {{0x765803ee,0xe944030d,0x637001f4,0x00000000}},	//   şuyo, _ахьо, väna, --, 
   {{0x54542dc0,0x65847d9f,0x00000000,0x00000000}},	// [29890] хват, тырз, --, --, 
   {{0x6370014a,0xb338008e,0x647401c6,0x00000000}},	//   täna, _otçe, тгуу, --, 
   {{0x69cc0034,0x98b8054e,0xdb000162,0xadf0000d}},	//   ąceg, cisă_, lsmó, _आनधन_, 
   {{0x3cfc06ab,0x63718ae3,0x92c0015b,0x69c40219}},	//   _शोले_, räna, ্জে_, šjeg, 
   {{0x63718ae4,0x3d100c00,0xf8bcf27f,0x6378063f}},	//   männ, थाने_, lhés_, ụnar, 
   {{0x63718ae5,0x98a40153,0x996c013a,0x00000000}},	//   länn, ėlę_, _věř_, --, 
   {{0xf8bc0561,0x93140137,0xdd740014,0x00000000}},	//   nhés_, _قوڭش, چھنک, --, 
   {{0x2bd006ab,0xe7f4012c,0x8fd001ee,0x637001f4}},	//   _दमदा, ेटमा_, _бәкә, nänn, 
   {{0x9e3c00d7,0x8b240395,0xcee00150,0x6f8401f4}},	//   _seďt, едпе, _бұлқ, _жужж, 
   {{0x6e200652,0x63718ae6,0x00000000,0x00000000}},	//   pynb, hänn, --, --, 
   {{0x63714aa8,0x27346ed3,0x3eac00e5,0x00000000}},	//   känn, _häng_, öltő_, --, 
   {{0xfe6c034c,0x273401c7,0x6370005b,0x2014033f}},	//   _اگه_, _käng_, jänn, ścił_, 
   {{0x067806ba,0x6370023a,0xdb00032e,0x765803e0}},	//   ﻠﯩﻨﯩ, dänn, gsmó, şuyl, 
   {{0x273400af,0x64580790,0x00000000,0x00000000}},	//   _mäng_, şvik, --, --, 
   {{0x691800d8,0x637000c5,0xc0b80023,0x00000000}},	//   _mãez, fänn, _ሳዕሪ_, --, 
   {{0x98b80276,0x637000fd,0xd5b009ab,0x00000000}},	//   risă_, gänn, _जबरज, --, 
   {{0x68e58ae7,0x08440014,0xd408007b,0x00000000}},	// [298a0] _ibid, _سندُ, وتكم_, --, 
   {{0xb460d112,0xb8780022,0x00000000,0x00000000}},	//   укул, teív, --, --, 
   {{0xf8bd8ae8,0x42541607,0xe1640451,0xbabc00d1}},	//   chés_, хтат, نگري, _ﻣﯘﺳﺎ, 
   {{0x68e40135,0xdef80327,0x6b0c0327,0x2734007c}},	//   _jbid, _saċ_, _ཏོའོ_, _bäng_, 
   {{0x68e58ae9,0x77740175,0xdb00002f,0x351800df}},	//   _mbid, _yhxx, tsmü, _זוכנ, 
   {{0xf1c00118,0x63700419,0xb87800e4,0x98b80064}},	//   ýší_, mäno, peív, misą_, 
   {{0x68e58aea,0x63718aeb,0x63a58aec,0x4ea40212}},	//   _obid, läno, lpin, тріа, 
   {{0x68e58aed,0x98a98aee,0x80a40014,0xdb0004cc}},	//   _nbid, _plač_, _سحرٕ, ssmü, 
   {{0xdef8003d,0x273401e6,0x3ebc004d,0xae840131}},	//   _taċ_, _känd_, _tdtt_, мбәз_, 
   {{0x68e58aef,0x63a58af0,0x60c00221,0x2004022e}},	//   _abid, ipin, _hdmm, _irmi_, 
   {{0xfbc00da0,0x19598af1,0x68e400a3,0x63a4f1f5}},	//   _शिवम, даны_, _bbid, hpin, 
   {{0x98a801f1,0x200401a6,0x8b8c0023,0x637001f4}},	//   _tlač_, _krmi_, _ነቐፌታ_, käno, 
   {{0x629c044e,0x63703f64,0x1bd53376,0x63a58af2}},	//   _ofro, vänn, _роля, jpin, 
   {{0x68e58af3,0x63a51405,0x63718af4,0x00000000}},	//   _ebid, dpin, wänn, --, 
   {{0x63a58af5,0x63718af6,0xf8bc00bc,0x6aa40165}},	//   epin, tänn, lkém_, ñjfe, 
   {{0x20058af7,0x68e40241,0xa96800d8,0x34c80118}},	//   _ormi_, _gbid, _пија_, िलेद, 
   {{0x63718af8,0x63a54fbd,0xf8bd8af9,0x629c0175}},	// [298b0] ränn, gpin, ्लीप, _bfro, 
   {{0x60c0026c,0xd01139ea,0x6370023a,0x00000000}},	//   _admm, یلا_, sänn, --, 
   {{0x20058afa,0xd2506396,0x273401e6,0x6370088f}},	//   _armi_, جنا_, _säng_, pänn, 
   {{0x629d8afb,0xa1842123,0x864400c7,0xa15800f3}},	//   _efro, гычл, _шьыҵ, наху_, 
   {{0x60c00fac,0x691800d8,0x629c03cb,0x27340112}},	//   _ddmm, _pãez, _ffro, _fänd_, 
   {{0xb8780789,0xf8bc013a,0x00000000,0x00000000}},	//   leís, dkém_, --, --, 
   {{0x8d540138,0x20040037,0xc58c0150,0x00000000}},	//   ктич, _ermi_, _ﻓﺎﻟﺨ_, --, 
   {{0x13d4015b,0x12e80150,0x00000000,0x00000000}},	//   _সৈয়, _ﺎﻤﻠﻭ, --, --, 
   {{0x68e401ab,0xa2d81c54,0x63700474,0x00000000}},	//   _rbid, न्क्, känl, --, 
   {{0x7c243c02,0x6370007c,0x2fcc007c,0x00000000}},	//   økra, jänl, mugg_, --, 
   {{0x63718afc,0x68e40175,0x60c00175,0x27340139}},	//   zäno, _pbid, _ydmm, _jäne_, 
   {{0x63a58afd,0x2734010b,0x6cb0004e,0x00000000}},	//   ypin, _mäne_, _сөкт, --, 
   {{0xe7d00c58,0xf8bc012c,0x68480023,0xaa9001ee}},	//   িব্য, ckém_, _ካድራት, _йѳйә, 
   {{0xa3d402ab,0x63a40254,0x637008e2,0xd71800d4}},	//   सूफ_, vpin, väno, нюсі_, 
   {{0xa3d405ba,0x16589db1,0x3664340b,0xb3440327}},	//   सून_, ерть_, варо_, _moħġ, 
   {{0x63a40bc9,0x54d40323,0x629d8afe,0x68e58aff}},	//   tpin, лцуу, _sfro, _ubid, 
   {{0xb8798b00,0xc4847a83,0x9fbc015b,0xc2b40063}},	// [298c0] rfíc, тлак, _আঙ্গ, вљењ, 
   {{0x63a58b01,0x2fcc0332,0xb8780022,0x00000000}},	//   rpin, dugg_, reít, --, 
   {{0x27340267,0xddc800c0,0xa2d81fc4,0x9f600205}},	//   _vänd_, _vydū, न्ग्, ğsüm_, 
   {{0x63a58b02,0x23b40014,0x27340432,0x404800d8}},	//   ppin, _مۅرس, _däne_, мпео_, 
   {{0x63a40d04,0x637000fd,0x64a40022,0x65651397}},	//   qpin, länm, _иаҟа, moih, 
   {{0xb87809c2,0x65658b03,0x629d8b04,0x2734008e}},	//   nfía, loih, _ufro, _fäne_, 
   {{0xdef8005e,0x41a8063b,0x60c00109,0xb87800e4}},	//   дық_, _іван_, _tdmm, neír, 
   {{0xed5423a4,0x7c858b05,0x65658b06,0xefb0036b}},	//   кој_, купе, noih, _چینگ, 
   {{0x2004003e,0xefb001d9,0x067806ba,0xf1700345}},	//   _urmi_, _نینگ, ﻠﯩﻤﯩ, _ئێنگ, 
   {{0x5b143461,0x65658b07,0x7f747711,0xfe40678a}},	//   умот, hoih, _рубц, _پکتی, 
   {{0xf8bc012c,0x637033da,0x65658b08,0xf2d00375}},	//   ském_, vänl, koih, בעת_, 
   {{0xf8bc00dd,0x6564005b,0x63701572,0x00000000}},	//   mkék_, joih, dänm, --, 
   {{0xb8e8069f,0xa3d402a0,0x00000000,0x00000000}},	//   _लय_, सूम_, --, --, 
   {{0x7de806be,0x00000000,0x00000000,0x00000000}},	//   _vəsf, --, --, --, 
   {{0xb8780077,0x63700139,0x00000000,0x00000000}},	//   teís, gänm, --, --, 
   {{0x56940124,0x656401f4,0x6d4401e1,0x00000000}},	//   _әант, goih, _ìjat, --, 
   {{0xb338010e,0x93781d0f,0x63700108,0x00000000}},	// [298d0] _atça, ебат_, pänl, --, 
   {{0xb8790bef,0x7de80213,0x63700108,0xf1a40798}},	//   seís, _kəsd, länj, врдн, 
   {{0x672801e6,0xb8780005,0xb14428c4,0x6440032e}},	//   ödje, peís, نیسم_, _ýmin, 
   {{0x2fcc0267,0xdce80139,0xd5b00208,0xa0c4bd5e}},	//   tugg_, _otdı, ấu_, ليمو, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x27358b09,0x2fcc9263,0x3ce400d7,0x00000000}},	//   _täne_, rugg_, _abov_, --, 
   {{0x28d40b40,0x9e7002d3,0xdce80213,0xfe400395}},	//   _थालि, _ኣቢልና_, _atdı, йншо, 
   {{0x8d7404b3,0xf8bc227c,0x00000000,0x00000000}},	//   داتا, ्लोप, --, --, 
   {{0x81f40327,0x399800ef,0xef98431a,0x00000000}},	//   _པནྜི_, _rīsa_, _آئرش_, --, 
   {{0x89a8b191,0xa3d406ab,0x7de803e3,0x00000000}},	//   нков_, संत_, _bəsd, --, 
   {{0x656401f7,0x6e640276,0xa2d80bc0,0xfed800ec}},	//   yoih, _ртаж, न्ट्, _سالڪ_, 
   {{0x893400c6,0x6564005a,0xe7e807f7,0x7de806be}},	//   اعدا, xoih, _ओहदा_, _səsg, 
   {{0x6564023a,0x00000000,0x00000000,0x00000000}},	//   voih, --, --, --, 
   {{0x65640099,0x00000000,0x00000000,0x00000000}},	//   woih, --, --, --, 
   {{0x15b80598,0xde44001f,0x65658b0a,0x85798b0b}},	//   кыты_, _እንደፈ, toih, есат_, 
   {{0xb8780124,0x00000000,0x00000000,0x00000000}},	//   reír, --, --, --, 
   {{0xb8780306,0x656400c3,0x59700014,0x07f8007b}},	// [298e0] lfín, roih, _گۯێز, _أربع_, 
   {{0x6370aa6c,0x6564023a,0xdef00092,0x00000000}},	//   mänk, soih, ሁትን_, --, 
   {{0x00c85228,0xaca00521,0x6370049f,0xd5b0001e}},	//   елек_, _asọm, länk, ất_, 
   {{0x57f40327,0xa2d80709,0x00000000,0x00000000}},	//   _བརྩོ_, न्ज्, --, --, 
   {{0xb8042f0a,0xf504005b,0x5eb4009d,0xdeb40166}},	//   शियम_, _снял_, айлт, аблы, 
   {{0x684002d3,0x6e9006c2,0x00000000,0x00000000}},	//   _ነንሕድ, ملها, --, --, 
   {{0x7afc4dce,0x3d8800c9,0x63704523,0x0eb800fd}},	//   _ópti, нщин_, hänk, тучы_, 
   {{0xd24c03e6,0xdb018b0c,0xfba8f7c9,0x6370007c}},	//   _تۆم_, nsmö, нтой_, känk, 
   {{0x3ea539ad,0xde440020,0x6371835f,0x7de803b9}},	//   _бизг, _እንዲፈ, jänk, _səsd, 
   {{0xef801d83,0xb4d8004e,0x6370005b,0x6cd000cf}},	//   _глуп, _amàl, dänk, _ۇقما, 
   {{0x6e90b255,0xd9142b41,0x7de80213,0xdce0007f}},	//   _الما, адны, _qəsd, lomč, 
   {{0xbc6800c6,0x63700221,0x260880a0,0x3e4c06be}},	//   _كمان_, fänk, हिनी_, _iət_, 
   {{0xac94007b,0xdce0007f,0x6ed87875,0xdb0001e3}},	//   _إنها_, nomč, _नामु, dsmö, 
   {{0x7de803be,0xde440b82,0xf8bc00c7,0x63700108}},	//   _təsd, _እንዳፈ, ikéi_, sänj, 
   {{0x6370005b,0xe9a0119e,0x00000000,0x00000000}},	//   mänh, _лајп, --, --, 
   {{0x06c411ba,0x63718b0d,0xa9a00150,0xdb018b0e}},	//   শ্লি, bänk, _اميى, gsmö, 
   {{0x39498b0f,0xe6101a90,0x00000000,0x00000000}},	// [298f0] mics_, يشہ_, --, --, 
   {{0xdb00007c,0x69cc0327,0xd9340092,0x00000000}},	//   asmö, żież, ርኬቲን, --, 
   {{0x32040232,0x36880131,0x6ec00490,0xe7f40166}},	//   íny_, _ясин_, रणसु, _küşä, 
   {{0x228400f7,0x3998002e,0x00000000,0x00000000}},	//   сууг, _mës_, --, --, 
   {{0xa3d402ab,0x00000000,0x00000000,0x00000000}},	//   सूद_, --, --, --, 
   {{0x2294aeb2,0x81c0009e,0x39489337,0x3e4c06be}},	//   _гиря, ্বজ_, hics_, _bət_, 
   {{0x637001f4,0x3ea006be,0x7bc40413,0x00000000}},	//   dänh, _şktc_, ákun, --, 
   {{0x273402b5,0x4c6831a8,0x7c34033f,0x00000000}},	//   _mäna_, кийн_, _żyra, --, 
   {{0x3948b497,0x27340793,0xe1f001d9,0x00000000}},	//   dics_, _läna_, _وسہ_, --, 
   {{0xef6406bb,0x39980de2,0xb4d801c3,0x63700108}},	//   _събо, _bës_, _smàl, vänk, 
   {{0x39482508,0x399800e8,0x273400b0,0xe7f40139}},	//   fics_, _cës_, _näna_, _büşä, 
   {{0x637004f3,0x3998092e,0x394976e2,0xb8790758}},	//   tänk, _dës_, gics_, rfín, 
   {{0xc7640222,0xe7f400fd,0x76400153,0x2ba40063}},	//   لاسى, _düşä, _žnyp, _сјев, 
   {{0x63714c88,0x39980de2,0x2d8c01ab,0xb8780022}},	//   ränk, _fës_, _hige_, reíp, 
   {{0x63704ab3,0x399801c7,0xa2cc0154,0x6b980135}},	//   sänk, _gës_, র্ডও, lqug, 
   {{0x63718b10,0x2d8d8b11,0x6b980194,0x3948004e}},	//   mäni, _jige_, oqug, cics_, 
   {{0x2900123c,0x63718b12,0xdb009632,0x436801c6}},	// [29900] _iaia_, läni, rsmö, ваан_, 
   {{0x2d8d8b13,0x27e002d1,0xdb0026bc,0xeaf001f9}},	//   _lige_, _iqin_, ssmö, _असोत_, 
   {{0x29018b14,0x4adc1810,0x7de800ac,0x63717d8f}},	//   _kaia_, _मानव, _məsc, näni, 
   {{0x2d8c983f,0x290001c0,0xc0e41b30,0x26d805d5}},	//   _nige_, _jaia_, родк, lgro_, 
   {{0x29018b15,0x057483c9,0xf2e400f2,0xd12c0228}},	//   _maia_, _ماڭد, _چکمه_, رۅك_, 
   {{0x2d8c0ea3,0x26d98b16,0x29018b17,0x637029ef}},	//   _aige_, ngro_, _laia_, käni, 
   {{0x63718b18,0x2d8d8b19,0x29007684,0x27e001b9}},	//   jäni, _bige_, _oaia_, _lqin_, 
   {{0x63718b1a,0x29000649,0x394856ed,0x8c3c0209}},	//   däni, _naia_, xics_, laşy, 
   {{0x2d8c1bce,0xf8a45168,0x6b980173,0x399800e8}},	//   _dige_, _क्षय, gqug, _sës_, 
   {{0x2900070d,0x2d8c0183,0x7bc40024,0x69cc012d}},	//   _aaia_, _eige_, škuo, ącen, 
   {{0x6da0c018,0x29018b1b,0x3948c820,0x2d8c2230}},	//   _диха, _baia_, tics_, _fige_, 
   {{0x29017846,0x2d8c0248,0x6c44b649,0x7de80213}},	//   _caia_, _gige_, الیف_, _təsb, 
   {{0x21240007,0x39498b1c,0x8c3c00a2,0x00000000}},	//   _momh_, rics_, kaşy, --, 
   {{0x39498b1d,0x7bc00165,0x212401ab,0x3998036e}},	//   sics_, _ivou, _lomh_, _tës_, 
   {{0x29002f06,0xa3d44103,0x2d8c0223,0x35698b1e}},	//   _faia_, सूस_, _yige_, вран_, 
   {{0x290005f5,0x38c8036b,0xb8640330,0x00000000}},	//   _gaia_, _рукн_, _پابو, --, 
   {{0x61fc036b,0x3cdc0034,0x7bc00129,0xe49802e8}},	// [29910] _asrl, _गाने_, _jvou, ркуч_, 
   {{0x27358b1f,0x29000395,0x7bc00165,0xd04801ec}},	//   _täna_, _zaia_, _mvou, _ﯨﺮﯨﭗ_, 
   {{0xa29402bf,0x6288219b,0x27340267,0x2608530e}},	//   іаці, _údol, _känn_, हिणी_, 
   {{0xeaf00d2c,0x212437a8,0xb4d800e8,0x2900005a}},	//   _अस्त_, _comh_, _njàx, _xaia_, 
   {{0x2d8d8b20,0x21258b21,0x7bc58b22,0x7ae8003a}},	//   _rige_, _domh_, ákul, _obft, 
   {{0x2d8d8b23,0x63700793,0xf1a58b24,0xb87803b2}},	//   _sige_, yäni, _вран, vfíl, 
   {{0x2d8c04ce,0x7bc18b25,0xddb80220,0xa6e400eb}},	//   _pige_, _avou, ауыш_, _ফোঁট, 
   {{0x260805ba,0x429802d3,0x26d808a4,0x7db003e6}},	//   हिती_, _ቅሳነት_, zgro_, سڵما, 
   {{0x290005d9,0x0ba873c5,0x0b458b26,0x8c4400f7}},	//   _raia_, داعى_, йнин, сепе, 
   {{0x29018b27,0x2d8c4539,0x7bc00316,0x6370014a}},	//   _saia_, _wige_, _dvou, täni, 
   {{0x2d8c334b,0x29018b28,0x7bc18b29,0x273401c7}},	//   _tige_, _paia_, _evou, _bänn_, 
   {{0x63718b2a,0xc91404c5,0x3cdc05f9,0x2d8c0afe}},	//   räni, াস্ত_, _गाये_, _uige_, 
   {{0x29018b2b,0x27340036,0x6b980140,0x317c0327}},	//   _vaia_, _dänn_, qqug, _mhuz_, 
   {{0xb6a0a6cf,0x29000374,0x7de806be,0x637001f4}},	//   зирл, _waia_, _həsa, länv, 
   {{0x29018b2c,0x63700054,0xf740034b,0x7bc00433}},	//   _taia_, qäni, черо, _zvou, 
   {{0x29000b23,0x26d80472,0x07a421b5,0x63700108}},	//   _uaia_, sgro_, _лаин, nänv, 
   {{0x21240007,0x7de800ac,0xdce01c52,0xd46800ae}},	// [29920] _romh_, _məsa, nomā, لحكم_, 
   {{0x273404e6,0xc7640372,0x637001e3,0x21240332}},	//   _zänn_, _داعى, hänv, _somh_, 
   {{0x8c3c0209,0xc0b802d3,0xd2000116,0xc0e80023}},	//   raşy, _ሳሕል_, мүрк, ዘድሊ_, 
   {{0x63718b2d,0xdec4001f,0xf77c05d1,0x3578001f}},	//   yänw, ቸዉን_, rtçe_, _በጥቂት_, 
   {{0x572410e5,0x60186690,0x63718b2e,0x7e780334}},	//   _طریق, роля_, xänw, _sztp, 
   {{0xdce000da,0x69c032b8,0xb000002b,0x29c003e0}},	//   domā, _ovne, _guḍa, kıa_, 
   {{0xa3d403f3,0x7bc007de,0x91c40166,0x7d6802e8}},	//   सूर_, _svou, _марҗ, лшив_, 
   {{0x7bc402d5,0x5c9800a7,0x7de80213,0xbc640014}},	//   škum, шкия_, _cəsa, یمژن_, 
   {{0x69c00ffb,0x00000000,0x00000000,0x00000000}},	//   _avne, --, --, --, 
   {{0x69c0009a,0xa0680220,0x1ee84c8b,0x4adc00cd}},	//   _bvne, _баға_, _خوئی_, _माणव, 
   {{0x94f80135,0x7de80213,0x1cb80327,0x78b803b2}},	//   _ཕྲའི_, _fəsa, མཛད_, ðuvo, 
   {{0xde4402d3,0x8ac400c7,0x760000e5,0x00000000}},	//   _ንሕናው, бқәа_, hízá, --, 
   {{0xf7703009,0x63700227,0xdc5403e6,0x00000000}},	//   كاس_, qänw, _براک, --, 
   {{0xf8d800dc,0x7d00588d,0x273401c7,0x2bf4010f}},	//   _भावय, _haos, _wänn_, _למדן_, 
   {{0x69c0010a,0x00000000,0x00000000,0x00000000}},	//   _gvne, --, --, --, 
   {{0x7d018b2f,0x7de800ac,0xf8bc0036,0x55740212}},	//   _jaos, _xəsa, gkét_, ігат, 
   {{0x24180948,0xa3d40406,0x7d018b30,0xf8bc0270}},	// [29930] боты_, सूल_, _maos, maé_, 
   {{0x7d018b31,0x673c000f,0x92a801e0,0x00000000}},	//   _laos, chrj, рсаҡ_, --, 
   {{0xd094023a,0x909800ee,0x32098b32,0x06802d40}},	//   ошлы, авет_, ыхан_, ﯩﺮﻟﯩ, 
   {{0x7d0004ce,0x65840510,0xe0d00244,0x00000000}},	//   _naos, _ныяз, فزه_, --, 
   {{0x67546112,0x63700108,0xa99c01ec,0x00000000}},	//   _ذخیر, vänv, _ﺍﻟﻤﺜ_, --, 
   {{0x4adc4d21,0xf3fc0004,0x81c000da,0xf8bc020c}},	//   _माधव, _isã_, ģērb, haé_, 
   {{0x7d000a73,0xb4d801ab,0x0d8400c9,0x317c020c}},	//   _baos, _amài, олкн, _thuz_, 
   {{0xdce0005f,0x3cdc0490,0x69c4012c,0x7d000051}},	//   tomā, _गाणे_, ájem, _caos, 
   {{0x7de803be,0x7d018b33,0xa0c40451,0x69cc0210}},	//   _vəsa, _daos, _ريلو, ącem, 
   {{0x7c240267,0xdce18b34,0x94f80327,0x69c40010}},	//   äkra, romā, _ཕིའི_, šjem, 
   {{0x63700793,0x7d011dfb,0x7de800ac,0x00000000}},	//   mänt, _faos, _təsa, --, 
   {{0x7d001140,0x63715515,0x00000000,0x00000000}},	//   _gaos, länt, --, --, 
   {{0x3cdc06ab,0x6d498b35,0x2cbd8b36,0xc794005b}},	//   _गाते_, _imga, maud_, юрны, 
   {{0x2cbd8b37,0x69c000da,0x7de806be,0xdb0003b2}},	//   laud_, _tvne, _məsn, ppmá, 
   {{0x6a14004b,0x6d480009,0xc6080183,0x00000000}},	//   _دبشر, _kmga, ৰন্থ_, --, 
   {{0x2cbd8b38,0x95990a1b,0x2734014a,0xf8bc0798}},	//   naud_, стру_, _täno_, caé_, 
   {{0xf3e00323,0x63700054,0xc32407b5,0x7de803b9}},	// [29940] мжто, känt, омак, _nəsn, 
   {{0x2cbd8b39,0x49000316,0xf8bcae51,0x637037e9}},	//   haud_, षयको_, skét_, jänt, 
   {{0x6370adae,0xbd040005,0xf8bc06af,0x41b43695}},	//   dänt, ntéñ, ckés_, زمشر, 
   {{0xbfa95d25,0x6ed40316,0x9a9c0092,0x00000000}},	//   атке_, _ठाउँ, ወስነው_, --, 
   {{0x7d018b3a,0x03a469a4,0x98a80210,0x00000000}},	//   _raos, _фиго, _wlać_, --, 
   {{0x7d018b3b,0x6d482ac5,0x3da401a9,0xfda40114}},	//   _saos, _amga, ориб, ојим, 
   {{0x7d018b3c,0xf8bc020c,0x2cbc0129,0x00000000}},	//   _paos, yaé_, faud_, --, 
   {{0x2cbd8b3d,0xb33800ad,0xf3fc0124,0x00000000}},	//   gaud_, _atçh, _ysã_, --, 
   {{0x7d018b3e,0x64407236,0x637001f4,0x00000000}},	//   _vaos, _ümid, sänu, --, 
   {{0x6d480dd4,0x63718b3f,0xba080801,0x7d018b40}},	//   _emga, mäns, ахме_, _waos, 
   {{0x7d018b41,0x2cbd8b42,0x637004ab,0xf8bc7dec}},	//   _taos, baud_, läns, taé_, 
   {{0x2cbc0129,0x00000000,0x00000000,0x00000000}},	//   caud_, --, --, --, 
   {{0x6370023a,0xf8bc00e8,0x00000000,0x00000000}},	//   näns, jjée_, --, --, 
   {{0xf8bc0066,0x00000000,0x00000000,0x00000000}},	//   saé_, --, --, --, 
   {{0xf5241606,0x24900213,0x6d4881f0,0x00000000}},	//   офан, ənmə_, _ymga, --, 
   {{0x637001e6,0xf8bcaf18,0x1cb80327,0xa6340212}},	//   käns, rkés_, _ཙབས_, єнті, 
   {{0x6370049f,0xf7487092,0x00000000,0x00000000}},	// [29950] jäns, _نجده_, --, --, 
   {{0xc7b18b43,0xd3718b44,0x63700108,0x00000000}},	//   _רבי_, رها_, däns, --, 
   {{0x6370ee1f,0xdb000267,0x50f4010b,0x151401ee}},	//   vänt, mpmä, ззет, _едня, 
   {{0x6440038f,0x26080316,0x00000000,0x00000000}},	//   _żmie, हिरी_, --, --, 
   {{0xd0098b45,0x63718b46,0xb4d47347,0x2cbd8b47}},	//   селе_, tänt, सली_, vaud_, 
   {{0xa8580375,0x69c400e4,0x00000000,0x00000000}},	//   חידה_, ájek, --, --, 
   {{0x63718b48,0x2cbd8b49,0x00000000,0x00000000}},	//   ränt, taud_, --, --, 
   {{0x7de80213,0x63700474,0xe214009d,0x00000000}},	//   _təsn, sänt, _юмсы, --, 
   {{0x2cbc200c,0x60c401a8,0x63700108,0x26cc00e5}},	//   raud_, ðime, pänt, ódok_, 
   {{0x3b810b4e,0x2cbc0311,0x7de80213,0xeca800bc}},	//   нлыг, saud_, _kəsl, _ट्रफ, 
   {{0x2cbd8b4a,0xadb40228,0x644000e4,0x00000000}},	//   paud_, _بۇعا_, _ýmiv, --, 
   {{0x6d498b4b,0x7de803be,0x00000000,0x00000000}},	//   _umga, _məsl, --, --, 
   {{0xb3380205,0x00000000,0x00000000,0x00000000}},	//   _etçi, --, --, --, 
   {{0x26080490,0x290401fa,0xccf81be1,0x8d740244}},	//   हिली_, žma_, leś_, _باڕا, 
   {{0x27340036,0xdb4c03e6,0x7de80213,0x6d58bbaa}},	//   _hänk_, _ڕێی_, _nəsl, onua, 
   {{0x6d598b4c,0xc4d40490,0xccf82144,0x0ae801c8}},	//   nnua, धलेख, neś_, _خرچي_, 
   {{0x42c98b4d,0xf9900375,0xb460377b,0x637001f4}},	// [29960] йган_, _ארה_, ектл, dänr, 
   {{0x270c0085,0x637002f6,0x6d5800c6,0x7de80213}},	//   kɔnɔ_, väns, hnua, _bəsl, 
   {{0x273404f3,0xdce000c0,0x00000000,0x00000000}},	//   _länk_, lomą, --, --, 
   {{0x6d580240,0x63700958,0x3998010f,0x00000000}},	//   jnua, täns, צינד, --, 
   {{0x6d580200,0xb8780332,0x00000000,0x00000000}},	//   dnua, rgíg, --, --, 
   {{0x538000c7,0x63701f65,0x7de803e3,0x443001f4}},	//   _ақуз, räns, _fəsl, myy_, 
   {{0x44318b4e,0x6e900454,0x6370081d,0x00000000}},	//   lyy_, нишу, säns, --, 
   {{0x27358b4f,0x63700793,0xf8d8033f,0xd25400f2}},	//   _bänk_, päns, _भाइय, _تیمش_, 
   {{0x64458b50,0xb4d8004e,0xb3380432,0x2734007c}},	//   nzii, _imàt, _awçy, _vänj_, 
   {{0xfe70495f,0x3cdc1094,0xbec000da,0x5a340a83}},	//   _كدا_, _गावे_, šība, днот, 
   {{0x58d46be2,0x3ebc05d1,0x4adc447d,0x7de80213}},	//   монт, _iett_, _मारव, _kəsm, 
   {{0x3ebd8b51,0x4430aa0a,0x27340036,0x8ac400c7}},	//   _hett_, kyy_, _fänk_, пқәа_, 
   {{0x3ebc8e5d,0x7de806be,0x443001f4,0x00000000}},	//   _kett_, _məsm, jyy_, --, 
   {{0x64458b52,0x3ebc735b,0xb338036e,0x2d50054e}},	//   dzii, _jett_, _kuçe, mţea_, 
   {{0x3ebd8b53,0xaa540640,0xe664d70a,0x79a400db}},	//   _mett_, _нишу_, етто, _эрле, 
   {{0x3ebd8b54,0xb4d42765,0x44300175,0x43b80ca8}},	//   _lett_, सले_, fyy_, _ọrẹ_, 
   {{0xa3d40316,0x7de803be,0xb4d800cf,0xed5c02fb}},	// [29970] संग_, _səsl, _llàg, ížil_, 
   {{0x3ebd8b55,0xe3740166,0x00000000,0x00000000}},	//   _nett_, елуы, --, --, 
   {{0x7af800a7,0x6444b3e0,0x6d598b56,0x91f90b6a}},	//   iett, azii, ynua, تفاء_, 
   {{0x7af98b57,0x98a40024,0x81640133,0x25ac02f0}},	//   hett, ėlė_, ونلۆ, ídle_, 
   {{0x4add8b58,0xb4d80ca8,0xf8d805f9,0x78bc047e}},	//   _मालव, _alàg, _भाईय, _meqv, 
   {{0x7af98b59,0x3ebc004e,0x7de80213,0x27340037}},	//   jett, _cett_, _təsl, _ränk_, 
   {{0x7af98b5a,0xd0080184,0xb4d405f9,0x3ebc03cd}},	//   dett, сеһе_, _साफ़_, _dett_, 
   {{0x6b800649,0x6d588b6b,0x78bc003a,0xa29402bf}},	//   _shng, unua, _neqv, _часі, 
   {{0x7af98b5b,0x3ebd8b5c,0x6d5805f5,0xc0c00b8d}},	//   fett, _fett_, rnua, _рәхи, 
   {{0x7af98b5d,0x3ebd8b5e,0x659c02b1,0x49c98b5f}},	//   gett, _gett_, _hōhe, олон_, 
   {{0x659c0374,0x78bc0455,0x00000000,0x00000000}},	//   _kōhe, _beqv, --, --, 
   {{0x2734049f,0x7e7c260b,0x3ebc0fac,0x7d2800f1}},	//   _tänk_, üppe, _zett_, _ويلې_, 
   {{0x659c02b1,0xf8bc01ed,0x3ebd8b60,0xb6a000a8}},	//   _mōhe, rkép_, _yett_, ӂисл, 
   {{0x7af98b61,0x273400a2,0xb338013d,0x3ebc06be}},	//   cett, _käni_, _yuçe, _xett_, 
   {{0xb6a18b62,0x63700108,0xf51c0092,0xd5ac00e5}},	//   тисл, dänp, _ታማኝነ, یہی_, 
   {{0x443002f6,0x659c02b5,0xaa8401d9,0x00000000}},	//   tyy_, _nōhe, _وچھم_, --, 
   {{0x7de80cc1,0xb4d80268,0x273401b8,0x03a58b63}},	// [29980] _rəsm, _amàs, _läni_, физо, 
   {{0x64440036,0x42c801ec,0xb3380205,0x00000000}},	//   rzii, іген_, _otçu, --, 
   {{0x00e410f5,0x3ebca1e9,0x443032cb,0x3cdc00e1}},	//   джен, _rett_, syy_, _गाले_, 
   {{0x3ebd8b64,0x7af98b65,0x44300108,0x00000000}},	//   _sett_, zett, pyy_, --, 
   {{0x7af98b66,0x3ebc0bfa,0x7f4401ec,0xb3380139}},	//   yett, _pett_, медж, _suçe, 
   {{0x63a4434b,0x27340139,0x00000000,0x00000000}},	//   mqin, _bäni_, --, --, 
   {{0x68e58b67,0xceac052f,0x63a53614,0x3ebd300a}},	//   _ocid, _ҙә_, lqin, _vett_, 
   {{0x7af98b68,0x64400008,0x3ebc0732,0x63a40194}},	//   wett, _ýmis, _wett_, oqin, 
   {{0x7af98b69,0x63a58b6a,0x3ebd8b6b,0x7de800ac}},	//   tett, nqin, _tett_, _kəsk, 
   {{0x60c18b6c,0x2004ccfc,0x68e58b6d,0x2734013d}},	//   _hemm, _ismi_, _acid, _fäni_, 
   {{0x7af98b6e,0x60c00ad3,0x629c0998,0x78bc014f}},	//   rett, _kemm, _mgro, _peqv, 
   {{0x60c18b6f,0x68e4e38d,0x78bc014f,0x7d78007b}},	//   _jemm, _ccid, _qeqv, _بمصر_, 
   {{0xb904fa1a,0x629d8b70,0x68e401ab,0x06780075}},	//   _पा_, _ogro, _dcid, ﻠﯩﻘﯩ, 
   {{0x60c18b71,0x629d8b72,0x68e4127b,0x7af80455}},	//   _lemm, _ngro, _ecid, qett, 
   {{0xe5c44712,0x60c0020b,0x6370005b,0x78bc06be}},	//   ксто, _oemm, vänp, _teqv, 
   {{0x60c11378,0x20040bb3,0x23a401e3,0x98b8f356}},	//   _nemm, _osmi_, _böj_, _элит_, 
   {{0x63a4004b,0xd250136e,0xa96816a2,0x637001f4}},	// [29990] gqin, گنا_, _تميم_, tänp, 
   {{0x60c0013f,0x629c01ab,0xe2f80150,0x00000000}},	//   _aemm, _cgro, меуі_, --, 
   {{0xd2518b73,0x659c02b5,0x63a58b74,0x99bc02f5}},	//   دنا_, _pōhe, aqin, _অমুক, 
   {{0x60c18b75,0x22840228,0xa1589e06,0x63a40009}},	//   _cemm, тууг, маху_, bqin, 
   {{0x60c18b76,0x629c0175,0x23a40139,0xa3a400d8}},	//   _demm, _fgro, _göj_, _ајск, 
   {{0x60c0007f,0xe8dc0b98,0x2d840ae5,0x8414010f}},	//   _eemm, _मञ्च, ﺯﯨﻨﻰ_, _אַלף_, 
   {{0x60c18b77,0xd0d40801,0x00000000,0x00000000}},	//   _femm, _повъ, --, --, 
   {{0x60c0ed22,0xd5b001fb,0x629d191b,0x7de806be}},	//   _gemm, ấy_, _zgro, _məsh, 
   {{0x40e401d9,0xe0e401d5,0xeea8003b,0x00000000}},	//   _سٲلہ, _шўро, _дтек_, --, 
   {{0x60c11746,0x68e40393,0x7e7c002f,0x00000000}},	//   _zemm, _scid, üppc, --, 
   {{0x68e404fb,0x60c18b78,0x57f4031c,0x63a401a9}},	//   _pcid, _yemm, _བརྔོ_, zqin, 
   {{0x60c01bce,0x63a402d1,0x00000000,0x00000000}},	//   _xemm, yqin, --, --, 
   {{0xdd9402d5,0x68e400ef,0x00000000,0x00000000}},	//   _рацы, _vcid, --, --, 
   {{0xa3d4012c,0x23a4007c,0xcfc00154,0x63a401d5}},	//   संघ_, _röj_, _ঈমান, vqin, 
   {{0x629d0de1,0x63a403f0,0xdb1401e1,0xef2000de}},	//   _rgro, wqin, _èbád, ceļš_, 
   {{0x629d8b79,0x68e550d4,0x6ef00baa,0xf1a039a1}},	//   _sgro, _ucid, lıbı, _ओढ़न, 
   {{0xb4d800a3,0x00000000,0x00000000,0x00000000}},	// [299a0] _blàb, --, --, --, 
   {{0x60c18b7a,0x63a58b7b,0xb4d800a3,0x6ef00724}},	//   _semm, rqin, _clàb, nıbı, 
   {{0xf53c0b34,0x60c18b7c,0x03a4013e,0xb6b8011a}},	//   _flå_, _pemm, фиҷо, _מציי, 
   {{0x60c00429,0x7a458b7d,0x417400db,0xc1750ee6}},	//   _qemm, _hété, رااس, ردات, 
   {{0x63a40af5,0x60c18b7e,0xf990010f,0x7de803b9}},	//   qqin, _vemm, ארא_, _təsk, 
   {{0x629c0bb8,0xefc8001f,0x60c18b7f,0xf8bc00e8}},	//   _ugro, በሪያ_, _wemm, jjén_, 
   {{0x57f40d46,0x60c18b80,0x7a4420ef,0xd36c189c}},	//   _བརྐོ_, _temm, _mété, _بۇل_, 
   {{0x43cc0150,0xed84013d,0x00000000,0x00000000}},	//   _ﺗﻪﯕﻪ, нсык_, --, --, 
   {{0x7de80213,0xd1740022,0xe8000c70,0xa1180171}},	//   _məsi, _рыры, _लैला_, _mīļā_, 
   {{0x7a440c6a,0xa3e85219,0x3e8400bc,0x6ef0008e}},	//   _nété, _यमन_, _cítí_, gıbı, 
   {{0x399800ef,0xf2d000df,0x00000000,0x00000000}},	//   _rīss_, װער_, --, --, 
   {{0xfc6406bb,0x7de803be,0xf1c400bc,0xb3380200}},	//   _пълн, _nəsi, _žáky_, _muça, 
   {{0xb4d8004e,0xabd001d9,0x64400003,0xdc3001ef}},	//   _llàc, _مٲنت, _żmin, _kýčo, 
   {{0xb9c40491,0xeb94bb89,0xb33800d8,0x98a80139}},	//   _كتبه, _зич_, _ouça, _flağ_, 
   {{0x7a44004a,0x7de803e3,0xe2840150,0x00000000}},	//   _dété, _bəsi, _ﺩﺍﻻﻡ_, --, 
   {{0x25ac13d5,0xb4d801ab,0x7644000f,0xdce80139}},	//   ídla_, _slàb, rzjy, _kudı, 
   {{0xb338068c,0x28b41b80,0x00000000,0x00000000}},	// [299b0] _auça, _صحيح, --, --, 
   {{0x7a4425d9,0x2d4000e4,0x2d50054e,0xc76401ec}},	//   _gété, _iñee_, eţel_, _لاپى, 
   {{0x54b8034b,0x7de80213,0x32658b81,0x7e7801f4}},	//   _огня_, _fəsi, хтав, _nytp, 
   {{0x3ce401d4,0xb3382b95,0xd0d402e8,0x00000000}},	//   _ncov_, _duça, тодъ, --, 
   {{0x93c80014,0x656808de,0xb4bc202e,0xe13402d5}},	//   _تاجہ_, édhe, ीणी_, ынцы, 
   {{0x659c02b5,0xbec000da,0x98a805be,0x7e78017a}},	//   _hōha, šīna, _mlađ_, _bytp, 
   {{0x659c0053,0x752d2e75,0x00000000,0x00000000}},	//   _kōha, _kocz, --, --, 
   {{0x2734049f,0xa1940276,0x3e8400bc,0xdce80139}},	//   _hänt_, _басч, _sítí_, _budı, 
   {{0x659cf43c,0x6c5401e1,0x273401e6,0x752c0034}},	//   _mōha, _bálẹ, _känt_, _mocz, 
   {{0x89a80b7e,0xdc3000d7,0x39980171,0x00000000}},	//   мков_, _gýčo, _rūsa_, --, 
   {{0x3b8005f5,0x6ef00724,0x6d540077,0xf8bcae51}},	//   рлэг, rıbı, éxas, rjén_, 
   {{0xaca002e3,0x659c02b1,0x07a47fa5,0x00000000}},	//   _kpọm, _nōha, камн, --, 
   {{0xfcd80014,0x7de803b9,0x3e840cad,0x00000000}},	//   _زانڈ_, _rəsi, _títí_, --, 
   {{0xfaa01c89,0x7de800ac,0x4b78008f,0xdce00118}},	//   _кашо, _səsi, _קאַו, komě, 
   {{0xb8782760,0x7a4407ea,0xc8b400c9,0x752c0034}},	//   rgía, _vété, _испы, _bocz, 
   {{0xdce00118,0x7de806be,0xdce80166,0x387c0135}},	//   domě, _qəsi, _yudı, żura_, 
   {{0x7a440438,0x7de800ac,0x752c033f,0xb3380129}},	// [299c0] _tété, _vəsi, _docz, _suça, 
   {{0x7c2404f3,0xb4d800db,0x00000000,0x00000000}},	//   äkri, _plàc, --, --, 
   {{0x7de803be,0xb87800d8,0x6ed82072,0x6728007c}},	//   _təsi, ngín, _नाजु, ödju, 
   {{0xb8780332,0x7e780064,0x00000000,0x00000000}},	//   igín, _rytp, --, --, 
   {{0xff2401b9,0xdb00143a,0x00000000,0x00000000}},	//   кмдо, ppmø, --, --, 
   {{0x4adc0574,0x273400af,0x3f8c02f0,0xdce80139}},	//   _मागव, _tänu_, umfu_, _rudı, 
   {{0xdce8013d,0x260828fe,0x00000000,0x00000000}},	//   _sudı, हिटी_, --, --, 
   {{0xef1481fc,0xd1740184,0x2734007c,0x90a4007b}},	//   емә_, _быуы, _käns_, _محكم, 
   {{0xdce80166,0x195800c7,0x00000000,0x00000000}},	//   _qudı, ҵаны_, --, --, 
   {{0x27340267,0x3ea81196,0xa06801ec,0x3cdc0037}},	//   _mäns_, _übt_, _жаға_, _गाके_, 
   {{0x27358b82,0x195801e8,0xbf1001ee,0xb878032e}},	//   _läns_, еаны_, _бүҙә, ggín, 
   {{0xdce80724,0x8c400022,0x2d909c97,0x00000000}},	//   _tudı, рҵәе, _ﺟﺎﻳﻰ_, --, 
   {{0x752c0034,0x7b6401e0,0x00000000,0x00000000}},	//   _rocz, _итке, --, --, 
   {{0x752c033f,0xf0900375,0xaf5c0092,0x00000000}},	//   _socz, ינר_, ንፈልገ, --, 
   {{0x752c006d,0x7e840316,0x94d428a8,0xf9680276}},	//   _pocz, _úspě, ловц, _орий_, 
   {{0x659c1e2b,0x27340267,0x00000000,0x00000000}},	//   _pōha, _sänt_, --, --, 
   {{0x24581c31,0x644004cc,0x9f440139,0x28a805b3}},	// [299d0] вать_, _ümil, _aqmí_, _गलति, 
   {{0xddd401e4,0xdce000bc,0x00000000,0x00000000}},	//   _ŝaŝk, tomě, --, --, 
   {{0x32040109,0x2734369a,0x752c033f,0x10d402d5}},	//   ìny_, _vänt_, _tocz, гілё, 
   {{0x659c00b0,0xdce000bc,0xb87801e7,0x00000000}},	//   _tōha, romě, ngío, --, 
   {{0x7de803be,0x273434a4,0x067800d1,0x00000000}},	//   _məsu, _gäns_, ﺠﯩﻠﯩ, --, 
   {{0xf77c7236,0x0f3403e6,0xdce000bc,0x00000000}},	//   ftçi_, دکرد, pomě, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb3380240,0xd3440244,0x00000000,0x00000000}},	//   _kuço, _جیڕه_, --, --, 
   {{0x0b586f65,0xa1580640,0x673c002d,0x7bc403b2}},	//   ерны_, _рату_, ykrj, ákup, 
   {{0x4add026a,0x8b258b83,0x4b241436,0xb3380200}},	//   _माओव, удое, умов, _muço, 
   {{0x7de800ac,0xb3380129,0x7bc401a6,0x7b8400d1}},	//   _səsv, _luço, škup, دايە, 
   {{0xb8781c69,0x0c040014,0x7de803e3,0x6cb00132}},	//   rgín, _موصُ, _cəsu, _төкт, 
   {{0xc6d40395,0x00000000,0x00000000,0x00000000}},	//   лювъ, --, --, --, 
   {{0x25ac0216,0xe6b401d5,0x06740395,0x7de803b9}},	//   ídlo_, شلرگ, губя, _vəsv, 
   {{0x36646fe4,0xe80000af,0x29040165,0xb8780139}},	//   гаро_, _लईका_, ômas_, lgíl, 
   {{0x7de800ac,0x99740354,0x00000000,0x00000000}},	//   _təsv, _вуьш, --, --, 
   {{0xc7a402e8,0xa4943bdb,0xc48406d4,0x838800d8}},	// [299e0] _щипк, شیست, улак, ебав_, 
   {{0x27340267,0x6370002f,0xc8bc19cc,0x00000000}},	//   _väns_, länz, ्णकट, --, 
   {{0xb4d803d1,0xc7640131,0xb1400116,0x00000000}},	//   _ilàn, _لاھى, әнчл, --, 
   {{0x7de803b9,0x00000000,0x00000000,0x00000000}},	//   _məst, --, --, --, 
   {{0x659c04fe,0x31640085,0x656402e3,0x43840aaa}},	//   _hōho, énza_, mnih, _ملحق, 
   {{0x659c02b5,0xde583981,0x399801e1,0x5f9460a1}},	//   _kōho, калі_, _kàsì_, шилт, 
   {{0x38940118,0x7de806be,0x65641ae7,0x00000000}},	//   měrů_, _nəst, onih, --, 
   {{0x659c02b1,0xb4d8004e,0x1d358b84,0x43d00ef6}},	//   _mōho, _llàn, рния, _ﺟﻪﯕﺪ, 
   {{0x7de803be,0xb4d93e94,0x64400210,0xf77c0166}},	//   _rəsu, _olàn, _żmij, luçe_, 
   {{0x7de800ac,0x7f74084c,0x6564030a,0x00000000}},	//   _bəst, _субц, hnih, --, 
   {{0x659c02b5,0x65640ab9,0x1dc401c6,0x286801f0}},	//   _nōho, knih, _төлн, ҳрро_, 
   {{0x7de80cc1,0x63702155,0xb4d80109,0xaa600139}},	//   _dəst, gänz, _alàn, стьк, 
   {{0x3f9d8b85,0x656447e4,0x6bd43c97,0x3154010f}},	//   _kitu_, dnih, _مونس_, ריכן_, 
   {{0x65658b86,0x61fc0010,0x9b587c3f,0x00000000}},	//   enih, _oprl, _шилт_, --, 
   {{0x3f9d8b87,0x7bc0006f,0xa5f82401,0x98b803a0}},	//   _mitu_, _hwou, леру_, nisī_, 
   {{0x7bc00433,0xb33800db,0x7de80213,0x3f9d8b88}},	//   _kwou, _puço, _həss, _litu_, 
   {{0x9378020a,0x656804f2,0x549802d5,0x7de803b9}},	// [299f0] вбат_, édha, тваў_, _kəss, 
   {{0x3f9d8b89,0x799c0455,0xb4d800db,0x46c412eb}},	//   _nitu_, _hiqw, _glàn, वरणह, 
   {{0x7de803e3,0x65640014,0xaad8011a,0x00000000}},	//   _xəst, bnih, תחבר, --, 
   {{0x3f9d8b8a,0xdef8025c,0xa0c40979,0x65658b8b}},	//   _aitu_, _abċ_, ميمو, cnih, 
   {{0xd0080262,0x3f9d8b8c,0x8d740330,0x3cdc00e1}},	//   теле_, _bitu_, یابا, _गाजे_, 
   {{0x3f9d8b8d,0xddc80006,0x799c01e2,0xb3389e1f}},	//   _citu_, _dydž, _liqw, _kuçm, 
   {{0x3f9d8b8e,0x7bc0bdc6,0xff2401d9,0x62343cc5}},	//   _ditu_, _awou, شبوی, _леру, 
   {{0x3f9d8b8f,0x7bc00100,0x799c009a,0x716000f7}},	//   _eitu_, _bwou, _niqw, _اپرە, 
   {{0x0b440517,0x6ee436c1,0x3f9d8b90,0x2d5000a8}},	//   инин, _مسال, _fitu_, nţei_, 
   {{0x3f9d8b91,0x7bc0007f,0xf8bc0098,0xb87800d8}},	//   _gitu_, _dwou, bjék_, rgíl, 
   {{0x6f018b92,0x656401d9,0x7c4007f5,0x7bc001f5}},	//   menc, ynih, _čvrš, _ewou, 
   {{0x3f9c02ea,0xb3382fbe,0x49b804fb,0xb4d808c2}},	//   _zitu_, _suçl, _یابد_, _slàn, 
   {{0x7bc00d29,0xb4d98b93,0xc60d0256,0x6d58013c}},	//   _gwou, _plàn, ाट्य_, miua, 
   {{0x6d598b94,0x6370145e,0x659c02b5,0x7de803b9}},	//   liua, sänz, _pōho, _təst, 
   {{0x7de800ac,0x6f0000db,0x7bc00036,0x09e4db2e}},	//   _həsr, ienc, _zwou, _тойн, 
   {{0x6f005669,0x7de803b9,0x75e8ea5e,0x6d598b95}},	//   henc, _kəsr, _sözç, niua, 
   {{0xfa0008ea,0x6f018b96,0xe5a41638,0x61fc0010}},	// [29a00] _མགོན_, kenc, риғи, _sprl, 
   {{0xaa380020,0x6f018b97,0x799c00f1,0x659d8b98}},	//   _ይመስላ, jenc, _ziqw, _tōho, 
   {{0x0205409c,0x3f9d8b99,0x6d58cfe1,0x826400ec}},	//   рзен, _ritu_, kiua, جهان, 
   {{0x3f9cef54,0xc0580046,0x6d58026c,0xf990008f}},	//   _situ_, кіл_, jiua, ַרג_, 
   {{0x3f9d8b9a,0x6d598b9b,0x7de80213,0x00000000}},	//   _pitu_, diua, _nəsr, --, 
   {{0x69c18b9c,0x7bc0006f,0x6aa00010,0x2d90004e}},	//   _owne, _rwou, _ngnf, ïxen_, 
   {{0x3f9d6ddd,0xbd683529,0x6d593635,0x7de800ac}},	//   _vitu_, крие_, fiua, _rəss, 
   {{0x6d580869,0x6f00005a,0x7bc0033b,0x3f9c016d}},	//   giua, aenc, _pwou, _witu_, 
   {{0x69c00493,0xe09401d5,0x00000000,0x00000000}},	//   _awne, _ایشخ, --, --, 
   {{0x6370049b,0xb4d80170,0xbc689c96,0x6da0110c}},	//   täny, _alàl, _یمان_, _rđav, 
   {{0x799c0113,0x99980120,0x7de803e3,0x00000000}},	//   _piqw, лкот_, _vəss, --, 
   {{0x7bc00699,0x69c00042,0x6d598b9d,0xf8a001c6}},	//   _twou, _dwne, ciua, өгүү, 
   {{0x69c00175,0xb88400ee,0x7de803e3,0x81880023}},	//   _ewne, рунй, _təss, _ዝኣትዉ_, 
   {{0x79a41e2d,0x69c00334,0x00000000,0x00000000}},	//   _крие, _fwne, --, --, 
   {{0x69c00f7b,0x799c016d,0x00000000,0x00000000}},	//   _gwne, _tiqw, --, --, 
   {{0x6f018b9e,0x00000000,0x00000000,0x00000000}},	//   zenc, --, --, --, 
   {{0xf8bd8b9f,0x6f000741,0x00000000,0x00000000}},	// [29a10] mbé_, yenc, --, --, 
   {{0x6f00172e,0x2d500311,0xf8bc00cf,0xa87c011a}},	//   xenc, rţei_, lbé_, _באחר, 
   {{0x55583993,0xd05000ac,0x50b42218,0xe2c83346}},	//   _баня_, əfəs, бслу, شونو_, 
   {{0x6f018ba0,0x62240131,0x228c0248,0x00000000}},	//   wenc, تىمل, _sókí_, --, 
   {{0xa0540212,0xe0d9786c,0x8e540150,0x00000000}},	//   овці, рві_, өткі, --, 
   {{0x929401c6,0x6f000142,0xe3b0009f,0x289c010f}},	//   _гагц, uenc, _ترَ_, דידא, 
   {{0xdea40ec9,0x6d598ba1,0xa2b4012d,0x00000000}},	//   زینی, tiua, इडर्, --, 
   {{0x6d58013c,0x71400228,0x3eb80205,0x00000000}},	//   uiua, _بىرۅ, ıpta_, --, 
   {{0x6d598ba2,0x0c780137,0x7de803b9,0x00000000}},	//   riua, ыскы_, _qəsr, --, 
   {{0x6d58013c,0x24841512,0xf41c0139,0xefb00214}},	//   siua, _ømme_, _iyäd_, _هیچگ, 
   {{0xad2443c5,0xb4d80241,0x4da400fe,0x44240051}},	//   _پراو, _alàm, _গৌৰৱ, ̣o_, 
   {{0x69c0005c,0x81880023,0xb3380200,0xc9541f39}},	//   _vwne, _ዝኣተዉ_, _buçk, ётны, 
   {{0x2bbc2e1e,0x2cbd8ba3,0x3f8002b1,0x00000000}},	//   _शौचा, mbud_, _ūkui_, --, 
   {{0x2cbd8ba4,0xf8bc011f,0xf1a407af,0x69c00042}},	//   lbud_, abé_, गदान, _twne, 
   {{0xd90c04d3,0xf8bc01ed,0x00000000,0x00000000}},	//   ریی_, bbé_, --, --, 
   {{0x2cbc00d4,0x4808014b,0x00000000,0x00000000}},	//   nbud_, _беин_, --, --, 
   {{0x442403b7,0x43683bfd,0xb89001ec,0x2cbc000d}},	// [29a20] ão_, гаан_, _ىلىع, ibud_, 
   {{0xdecc001f,0x2cbc03b9,0x00000000,0x00000000}},	//   ጡትን_, hbud_, --, --, 
   {{0x2cbcef64,0xb3380784,0xfde0015b,0x00000000}},	//   kbud_, _muçh, _মন্ড, --, 
   {{0x0574215c,0xc0e401f0,0x00000000,0x00000000}},	//   _چاڭد, содк, --, --, 
   {{0x2cbd8ba5,0xb4d801e1,0x9f34753d,0xa4e401f9}},	//   dbud_, _olàj, желі, गलीच_, 
   {{0x764c00d2,0x83c00150,0x00000000,0x00000000}},	//   _ínyô, _мұғж, --, --, 
   {{0xed4c01d9,0xbabc0150,0x00000000,0x00000000}},	//   کھٕ_, _ﺣﯘﺟﺎ, --, --, 
   {{0xfc4402fb,0x5fe000ab,0xf77c0327,0x00000000}},	//   šími_, _निपल, ħħih_, --, 
   {{0xdb500014,0x00000000,0x00000000,0x00000000}},	//   ٘ێش_, --, --, --, 
   {{0x6e9016e0,0x9b598ba6,0xb3380a43,0xbf641291}},	//   _کلما, риот_, _ruçk, _ادرو, 
   {{0xf8bc011f,0x6da000c7,0xb3380139,0x59f8117e}},	//   tbé_, _еиха, _suçk, шеня_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2b4419f5,0xf8bd8ba7,0xf7700244,0x00000000}},	//   _flnc_, rbé_, _جاù_, --, 
   {{0xf8bc01ed,0x854c01e1,0x6e940408,0x00000000}},	//   sbé_, _rírọ, _евĕр_, --, 
   {{0xf3fc0589,0x44b401f2,0x00000000,0x00000000}},	//   _spã_, _ọsụ_, --, --, 
   {{0x54b98ba8,0x00000000,0x00000000,0x00000000}},	//   ргая_, --, --, --, 
   {{0x3958009a,0xe5340212,0xf48400d4,0x00000000}},	// [29a30] _imqs_, четь, сувн, --, 
   {{0x2124007f,0x7c24143a,0xb338cae1,0x91c40124}},	//   _anmh_, økry, _kuçi, жәал, 
   {{0x3384013e,0x32cc00a2,0xa59401d5,0x00000000}},	//   _ҳувв, _añyñ_, تگیچ, --, 
   {{0x39983d4f,0x2cbc0267,0xb338036e,0x00000000}},	//   _būsi_, xbud_, _muçi, --, 
   {{0x4f940107,0x7f5806be,0xb3380200,0x00000000}},	//   орку, _bmtq, _luçi, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd1e00020,0xcd2807d8,0x2cbd8ba9,0x00000000}},	//   ነቶች_, ижке_, tbud_, --, 
   {{0x61e805ac,0x8c8800c7,0xdce00171,0xe3b002f2}},	//   _ådla, қәҵа_, domē, _ترێ_, 
   {{0x2cbc0654,0x399800ef,0xa194022e,0x00000000}},	//   rbud_, _gūsi_, _хатч, --, 
   {{0xb3398baa,0x06ec1fca,0x2cbd3ac3,0x3b800661}},	//   _quçh, _जाधव_, sbud_, млыг, 
   {{0x2d8c01ee,0x00000000,0x00000000,0x00000000}},	//   _thge_, --, --, --, 
   {{0xc278011a,0x2cbc031c,0x00000000,0x00000000}},	//   ירתי, qbud_, --, --, 
   {{0x06ec0073,0x00000000,0x00000000,0x00000000}},	//   _जादव_, --, --, --, 
   {{0x40980375,0xb3382330,0xf86000d4,0x00000000}},	//   יברס, _fuçi, євро, --, 
   {{0xb6a0b38e,0x659c04fe,0x3f80013f,0xb3380139}},	//   дирл, _hōhi, _ɔku_, _guçi, 
   {{0x659c0374,0x2d4000e4,0x45840024,0xd9b800ec}},	//   _kōhi, _oñem_, ігав, _انيڪ_, 
   {{0x42c8006c,0x6594010a,0x00000000,0x00000000}},	// [29a40] иган_, çару, --, --, 
   {{0x659c1f4c,0x212401ab,0xefd00092,0x8218011c}},	//   _mōhi, _snmh_, _ከሃያ_, ицет_, 
   {{0x73300f78,0x80a80120,0xc0c80108,0x9868179e}},	//   بىلا, авев_, ауле_, _نحیف_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x659c0374,0x34a402bf,0x00000000,0x00000000}},	//   _nōhi, _євро_, --, --, 
   {{0x6fd807d0,0x80a4000d,0x00000000,0x00000000}},	//   _निरू, _छलके, --, --, 
   {{0x12180006,0x7e2800d4,0x00000000,0x00000000}},	//   _люты_, ріла_, --, --, 
   {{0xdd900058,0x387c003d,0xb3380200,0x00000000}},	//   رۈش_, żuri_, _ruçi, --, 
   {{0xb3398bab,0x00000000,0x00000000,0x00000000}},	//   _atçy, --, --, --, 
   {{0xb338036e,0x00000000,0x00000000,0x00000000}},	//   _puçi, --, --, --, 
   {{0xb8780798,0xb3380139,0xbe6405af,0x00000000}},	//   ngív, _quçi, _بهاي, --, 
   {{0xb338036e,0x00000000,0x00000000,0x00000000}},	//   _vuçi, --, --, --, 
   {{0x8b6404d3,0xef80030d,0x00000000,0x00000000}},	//   _کانم, _алăп, --, --, 
   {{0xdb20005b,0xeb9400f3,0x00000000,0x00000000}},	//   ätäm, _дич_, --, --, 
   {{0x28c80d2c,0x00000000,0x00000000,0x00000000}},	//   लरशि, --, --, --, 
   {{0xa5dc3be5,0xe3b0211f,0xf8ac000d,0xe6942bda}},	//   _फिरौ, چرل_, _टलिय, фисы, 
   {{0xb2a813f3,0x54543252,0xd1ec0092,0x00000000}},	// [29a50] атеж_, чват, ቆየት_, --, 
   {{0x5ee00183,0x23747f51,0xdb24013d,0xb2ac0051}},	//   প্তে, والح, _üsär, _đồng, 
   {{0xe8e00022,0xa91001e4,0x51f8003b,0x00000000}},	//   _apỹi_, _skɾi, снею_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x45a000d1,0x00000000,0x00000000,0x00000000}},	//   _سەكك, --, --, --, 
   {{0x659c00b0,0x645801e4,0x00000000,0x00000000}},	//   _rōhi, ŝvic, --, --, 
   {{0x3ea022f7,0xc3300bd9,0x050c1c82,0xd04800ac}},	//   нишг, _אום_, হাৰৰ_, _ənən, 
   {{0xb4d801c3,0x317c0472,0x659c0374,0x8fd0728c}},	//   _blài, _ukuz_, _pōhi, _зәкә, 
   {{0x39980029,0xb4d801c3,0x64400790,0xcfb40327}},	//   _jūsu_, _clài, _ümit, _པཕྲྀ, 
   {{0x39980029,0x7c249c2a,0x00000000,0x00000000}},	//   _mūsu_, åkra, --, --, 
   {{0x4c1401e2,0x00000000,0x00000000,0x00000000}},	//   زبکس, --, --, --, 
   {{0xb4d800a3,0x659c02b5,0x2054010a,0x00000000}},	//   _flài, _tōhi, _итĕр, --, 
   {{0x6d48eed3,0x6edc00bc,0x00000000,0x00000000}},	//   _ilga, _नयाँ, --, --, 
   {{0x26cd8bac,0xb33820b2,0x00000000,0x00000000}},	//   údo_, _kuçu, --, --, 
   {{0xf41d8bad,0x7e840150,0x4dd800cc,0x00000000}},	//   _arä_, _ﺯﺍﻟﺕ_, _ভঙুৱ, --, 
   {{0xb3380120,0x5ae8025c,0xf9d8010f,0x00000000}},	//   _muçu, _འཐོམ, _פֿול, --, 
   {{0x29000428,0x43440120,0xf8bc00e5,0x00000000}},	// [29a60] _ibia_, пеав, rjét_, --, 
   {{0xb3800262,0xb4600022,0xe79400e5,0x00000000}},	//   елул, хкул, _تابک, --, 
   {{0xf41d8bae,0x6d48006c,0x41b400aa,0x4254082d}},	//   _erä_, _olga, سمشر, чтат, 
   {{0x99800064,0x03a4014b,0x00000000,0x00000000}},	//   _čiū_, _нимо, --, --, 
   {{0xb4d80248,0x29006e25,0x00000000,0x00000000}},	//   _alàw, _mbia_, --, --, 
   {{0x6d498baf,0xb3380790,0xe5080451,0x1300014b}},	//   _alga, _buçu, _ايڏو_, _иҷум, 
   {{0x290001f2,0xb4d80192,0x72d0129d,0x1df800fb}},	//   _obia_, _slài, _سەنچ, цейы_, 
   {{0x5bb98bb0,0x6da014b7,0xb4d800a3,0x64400254}},	//   олия_, нија, _plài, _ümis, 
   {{0xfb851499,0xafe18bb1,0x00000000,0x00000000}},	//   зынн, _потл, --, --, 
   {{0x29018bb2,0x6d498bb3,0x399800ef,0x00000000}},	//   _abia_, _elga, _lūst_, --, 
   {{0x659c02b5,0x2d400022,0xf1c0004d,0x00000000}},	//   _hōhu, _oñeh_, _nhớ_, --, 
   {{0x659c0053,0x27340036,0xb3400003,0xb75c01e1}},	//   _kōhu, _gänz_, ħħit, _ẹ̀rù_, 
   {{0x31540bd9,0xaab453e2,0xe8258bb4,0x00000000}},	//   ליטן_, غدیر_, нфро, --, 
   {{0x2900013b,0x659c02b5,0xead401ec,0x5694009d}},	//   _ebia_, _mōhu, _емші_, дагт, 
   {{0x4af80276,0x20cc043e,0x80d00011,0x6d4800ee}},	//   _фэчя_, ाराध, _হান্, _ylga, 
   {{0xf41c002f,0xa968119e,0x00000000,0x00000000}},	//   _prä_, _нија_, --, --, 
   {{0xf8c039c5,0xe94400e5,0xf7480066,0x00000000}},	// [29a70] _व्यय, _سرٹی, _هجده_, --, 
   {{0x72298bb5,0xe9fc01fb,0xb6c401c6,0xd0100133}},	//   йцев_, _hoại_, _эсий, ێلا_, 
   {{0x37ac0154,0x50f40024,0x20040200,0x27ec012d}},	//   _কবির, дзет, _apmi_, ądne_, 
   {{0xe29800d6,0xf41c01e6,0xe8e0004d,0x399800e2}},	//   чає_, _trä_, _trụi_, _gūst_, 
   {{0xf4858bb6,0xb33805d1,0xdce000c0,0x00000000}},	//   _хунн, _suçu, lomė, --, 
   {{0xe9fc01dc,0x40300640,0x1cb80327,0x8e2000fb}},	//   _loại_, тељс, _མཅུ_, лhа_, 
   {{0x8e0800d4,0x9c580022,0xdce000c0,0x00000000}},	//   інив_, ҧшьу_, nomė, --, 
   {{0x0c24d562,0xb8798bb7,0x6d48022e,0x5ae80327}},	//   дмин, ngís, _qlga, _འཐུམ, 
   {{0x6568114f,0xc6640092,0x00000000,0x00000000}},	//   édhi, ደሚሰራ_, --, --, 
   {{0x4a4453ef,0xcdc400db,0xdce00153,0xdee400f3}},	//   днов, _قۇتۇ_, komė, _пођи, 
   {{0x6d481c06,0x23c401e1,0x80a000f7,0x0fe40166}},	//   _tlga, _kéjò_, _كۅۅن, _хөҗү, 
   {{0x6d4809a5,0xdce00006,0x2d4000e4,0xe9dc00d0}},	//   _ulga, domė, _oñei_, čú_, 
   {{0x7d5400c8,0x0c240006,0x00000000,0x00000000}},	//   _קינד_, _імкн, --, --, 
   {{0xf4000154,0x00000000,0x00000000,0x00000000}},	//   উটার_, --, --, --, 
   {{0x39980171,0x00000000,0x00000000,0x00000000}},	//   _pūst_, --, --, --, 
   {{0x2900b130,0xa93401b9,0xe9440066,0x00000000}},	//   _ubia_, _سببچ, _سرعی, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [29a80] --, --, --, --, 
   {{0x00cc1c5c,0xf7710365,0x2004045a,0x00000000}},	//   _ﻗﯩﺴﻘ, _لاپ_, _rpmi_, --, 
   {{0xc2081a59,0x5f1802ab,0x5fe001ad,0x00000000}},	//   تقان_, _योग्_, _निहल, --, 
   {{0x96958bb8,0x2004870e,0x659c02b1,0xb3380790}},	//   _ярыш, _ppmi_, _pōhu, _suçt, 
   {{0xb4d80137,0x656400b0,0x00000000,0x00000000}},	//   _clàu, miih, --, --, 
   {{0x65658bb9,0xb5a801ed,0x64440036,0x44218bba}},	//   liih, _دئیے_, myii, _irk_, 
   {{0x4420b964,0x6444956c,0x00000000,0x00000000}},	//   _hrk_, lyii, --, --, 
   {{0xfe7004d3,0x659c02b5,0x65658bbb,0x64440009}},	//   _یدا_, _tōhu, niih, oyii, 
   {{0x64458bbc,0x4420003e,0x2004003e,0x9f940022}},	//   nyii, _jrk_, _upmi_, _зыжә, 
   {{0x5a3447bf,0x5b14014b,0x00000000,0x00000000}},	//   енот, хмот, --, --, 
   {{0x656400b5,0x00000000,0x00000000,0x00000000}},	//   kiih, --, --, --, 
   {{0xad8404a9,0x5d140014,0x644404ba,0x395c068c}},	//   _قانۇ, _سِتا, kyii, òus_, 
   {{0xb8d402fe,0x44201a82,0x6b801132,0x273c001f}},	//   _जल_, _nrk_, _fkng, _ዓለምአ, 
   {{0x5ee000bd,0x7c218bbd,0xb4d800db,0x70a800e1}},	//   প্রে, _iror, _llàt, _छल्ल, 
   {{0x44201590,0x44300354,0xb87800cf,0xb5a4020f}},	//   _ark_, exy_, tgís, драй, 
   {{0x7c2001e4,0x059401b9,0x7d003b64,0x00000000}},	//   _kror, فاقگ, _jbos, --, 
   {{0x7d018bbe,0xa8146bb9,0x23c401e1,0x00000000}},	// [29a90] _mbos, _адыш, _réjò_, --, 
   {{0x44218bbf,0x7d0001d5,0x00000000,0x00000000}},	//   _drk_, _lbos, --, --, 
   {{0x7d018bc0,0xb4d801c3,0x64451ee9,0x74b00032}},	//   _obos, _blàt, ayii, _аҡбу, 
   {{0xd1d4069c,0x7c218bc1,0x644400ca,0xb3d0010b}},	//   _ከባቢ_, _oror, byii, _иймә, 
   {{0xe4a4022e,0x00000000,0x00000000,0x00000000}},	//   _арро, --, --, --, 
   {{0x7d018bc2,0x9f5401e1,0x00000000,0x00000000}},	//   _abos, _òfìn_, --, --, 
   {{0x7c218bc3,0x7d000337,0xb4d8004e,0xce480108}},	//   _aror, _bbos, _coàg, язке_, 
   {{0x7c2011ad,0x5ee00eac,0xa29402d5,0x442003b2}},	//   _bror, প্লে, _расі, _yrk_, 
   {{0xc0c01b15,0x44200175,0x7c20b4bb,0x27340254}},	//   _сәхи, _xrk_, _cror, _tänx_, 
   {{0x7c203ec2,0x7d018bc4,0x00000000,0x00000000}},	//   _dror, _ebos, --, --, 
   {{0x7c218bc5,0x0d202002,0xdd4000a2,0x65640009}},	//   _eror, _бүйү, _oňňu, yiih, 
   {{0xaca00521,0x7c200005,0x64447840,0x00000000}},	//   _arụm, _fror, yyii, --, 
   {{0x4430463d,0xb4d800cf,0x7c200ca6,0x59b419bb}},	//   xxy_, _llàs, _gror, нөөс, 
   {{0x6b80009a,0x4420017a,0x7d0001d5,0x00000000}},	//   _ukng, _rrk_, _zbos, --, 
   {{0x442040f9,0x41cc00e1,0x00000000,0x00000000}},	//   _srk_, _हौंस, --, --, 
   {{0xf77c0113,0x6445861e,0x44218bc6,0x39480036}},	//   huçh_, tyii, _prk_, ëbst_, 
   {{0xb4d801ab,0x65640108,0xc32400db,0x00000000}},	// [29aa0] _alàs, riih, нмак, --, 
   {{0xb4d801ab,0x316c0226,0x4420822d,0x6444022f}},	//   _blàs, engz_, _vrk_, ryii, 
   {{0xb4d80137,0x00e58bc7,0x1af400fe,0xb338036e}},	//   _clàs, ежен, _অসমে_, _puçr, 
   {{0x44218bc8,0x05758bc9,0x651400d1,0x00000000}},	//   _trk_, _ساجد, _جۈرئ, --, 
   {{0xb4d800db,0x7d0001a9,0xab980092,0x00000000}},	//   _elàs, _rbos, ፈቅደው_, --, 
   {{0xf1c002dd,0x00000000,0x00000000,0x00000000}},	//   _әйтп, --, --, --, 
   {{0xb4d98bca,0xc0e40798,0x9f540241,0x00000000}},	//   _ilàr, _повк, _òfín_, --, 
   {{0x7de803b9,0x06b400cc,0x00000000,0x00000000}},	//   _məsx, _জজফি, --, --, 
   {{0x7b658bcb,0x79c41884,0xec6404b4,0xe0580244}},	//   етне, ﯩﺘﯩﻤ, ерэк_, _تیشت_, 
   {{0xf0618bcc,0x7d00039a,0x73f8010f,0x00000000}},	//   _скуп, _wbos, פּחו, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7d018bcd,0x8e74004e,0xed5403cf,0x00000000}},	//   _ubos, _рууч, _пох_, --, 
   {{0x53b40574,0x7c200c09,0xbb44dba2,0xa3580241}},	//   _अंधश, _uror, _педк, _pọ̀s, 
   {{0x39e0052f,0x7de806be,0xf090011a,0x897c0092}},	//   _йәмғ, _səsy, טנר_, ከለከለ_, 
   {{0xe61045fa,0x94d41173,0x97358bce,0xdce000e2}},	//   یشہ_, ковц, _یکسا, jomī, 
   {{0xdce000de,0x00000000,0x00000000,0x00000000}},	//   domī, --, --, --, 
   {{0xb4d801c3,0xb3380200,0xe3b00014,0x987401f4}},	// [29ab0] _blàr, _buçp, ٕرم_, _шлиц, 
   {{0xb4d98bcf,0xe4a4180b,0x316c0399,0xf99c7c99}},	//   _plàs, урсо, wngz_, lmè_, 
   {{0x20cc448b,0xe6040014,0x00000000,0x00000000}},	//   ारूढ, _یِیَ, --, --, 
   {{0xf99c0699,0x00000000,0x00000000,0x00000000}},	//   nmè_, --, --, --, 
   {{0x60c40086,0x7644010b,0x00000000,0x00000000}},	//   ñima, lyjy, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf53c0c67,0x2d400086,0xa29443e1,0xec2001e1}},	//   _koå_, _oñet_, _барі, _ẹ̀fú, 
   {{0x7eb400fb,0x00000000,0x00000000,0x00000000}},	//   нгәс_, --, --, --, 
   {{0xf99c02e2,0xeea802dd,0x4c34009d,0x00000000}},	//   dmè_, _етек_, тэйт, --, 
   {{0x776400b5,0xaab40214,0x0b44004e,0x764400a2}},	//   jijx, رگتر_, тнон, kyjy, 
   {{0xe7e4000d,0x00000000,0x00000000,0x00000000}},	//   _कटहा_, --, --, --, 
   {{0xfe6c16e6,0x29058bd0,0x3b640014,0xaf8400fb}},	//   _بگه_, ýma_, _یَنہ, _юҡһа_, 
   {{0xc76416a0,0x8c440f14,0xdd9402d5,0x2d9c0158}},	//   ناسى, _јеле, _сацы, mmue_, 
   {{0xf99c026c,0x00000000,0x00000000,0x00000000}},	//   amè_, --, --, --, 
   {{0xf53c0589,0x9a2415eb,0x00000000,0x00000000}},	//   _boå_, _معين, --, --, 
   {{0xdc3402f0,0x00000000,0x00000000,0x00000000}},	//   zúčt, --, --, --, 
   {{0x35a0039b,0xd72003d4,0xdca400bc,0x00000000}},	// [29ac0] ратг, _নকৰা_, खेपछ, --, 
   {{0xc7a40b96,0x2cac0064,0x2d9c0200,0x00000000}},	//   _шипк, _lggd_, hmue_, --, 
   {{0x26d98bd1,0x70500f00,0x00000000,0x00000000}},	//   maro_, ینما, --, --, 
   {{0x26d98bd2,0xf53c0004,0x80a40133,0x00000000}},	//   laro_, _goå_, نمان, --, 
   {{0x25a18bd3,0x6fb13487,0x7fd801af,0x00000000}},	//   mmil_, لمنا, ффет_, --, 
   {{0x26d98bd4,0x02058bd5,0x25a00793,0xc21001d9}},	//   naro_, _изгн, lmil_, _پٔر_, 
   {{0x6704202e,0x52758bd6,0x2dd40597,0x26d80374}},	//   श्यक_, _буту, نبية_, iaro_, 
   {{0x26d98bd7,0x21fc011f,0x25a002e2,0x00000000}},	//   haro_, míh_, nmil_, --, 
   {{0x26d98bd8,0x25a18bd9,0xd1758bda,0x764400ee}},	//   karo_, imil_, _сыры, zyjy, 
   {{0x26d8d689,0xb4d8004e,0x25a0003e,0x3f4008a5}},	//   jaro_, _llàp, hmil_, _eður_, 
   {{0x26d98bdb,0x21fc00d7,0x25a0cf1b,0x00000000}},	//   daro_, níh_, kmil_, --, 
   {{0x3c64151e,0x3f8c025c,0xbc64011c,0x00000000}},	//   _икег, llfu_, _ивек, --, 
   {{0x26d98bdc,0xf53c0004,0xed540375,0x6c3003c7}},	//   faro_, _roå_, _בבאר_, _نعوذ, 
   {{0x26d813b6,0x7bc18bdd,0x25a00548,0x6fd80490}},	//   garo_, _itou, emil_, _निघू, 
   {{0xf53c0589,0xa5f803de,0x98a80419,0x6a1000ec}},	//   _poå_, керу_, _inač_, _نبير, 
   {{0x21fc011f,0x7d0401a9,0x25a000a2,0x00000000}},	//   díh_, еksi, gmil_, --, 
   {{0x53984f35,0xe4a4009b,0x00000000,0x00000000}},	// [29ad0] евая_, арфо, --, --, 
   {{0x26d98bde,0x25a05a7a,0x64a40063,0x798c02d0}},	//   caro_, amil_, рађа, llcw, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7bc02035,0xf52400c7,0x00000000,0x00000000}},	//   _otou, _рфон, --, --, 
   {{0x752c035a,0x21a8008e,0x00000000,0x00000000}},	//   _incz, тәрү_, --, --, 
   {{0x62240131,0x996c0118,0xdbdc032e,0x00000000}},	//   _ھۈنە, _něž_, _ráðv, --, 
   {{0x7bc18bdf,0x80d000bd,0x62356689,0xb1a400ee}},	//   _atou, _হার্, _керу, _ашак, 
   {{0x26d98be0,0x09e00183,0xe7e40037,0x00000000}},	//   zaro_, _বহলা, _कटला_, --, 
   {{0x26d98be1,0x2d9c7eb1,0xc18001d3,0x6fd400e1}},	//   yaro_, rmue_, _اینٹ, _डबिं, 
   {{0x2fdc00ca,0x6440004a,0x853802a8,0x7bdc02b1}},	//   _ivug_, _àmie, ruɗɗ, _āput, 
   {{0x7bc18be2,0x22c00093,0x3b8001c0,0x25a18be3}},	//   _etou, lākí_, слэг, ymil_, 
   {{0x26d98be4,0x6a5006be,0x00000000,0x00000000}},	//   waro_, nəfə, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x59d00316,0x00000000,0x00000000,0x00000000}},	//   थीहर, --, --, --, 
   {{0x25a002e2,0xf740447e,0x00000000,0x00000000}},	//   tmil_, щеро, --, --, 
   {{0x69c0127b,0x25a0000d,0x00000000,0x00000000}},	//   _itne, umil_, --, --, 
   {{0x2e140cc1,0x25a18be5,0xdce00f40,0x69c001a6}},	// [29ae0] _dəfə_, rmil_, nimā, _htne, 
   {{0x46f4722e,0xdcf42220,0x42543a33,0x26d98be6}},	//   _счит, _čačk, лтет, qaro_, 
   {{0x2fdc00ca,0x4424010f,0x00000000,0x00000000}},	//   _avug_, ŭo_, --, --, 
   {{0x631400bd,0x27e000c8,0x86b801d9,0x442401e4}},	//   সাইট_, _kvin_, _تُھر_, ƭo_, 
   {{0x84680020,0x7f458be7,0x68e58be8,0x00000000}},	//   _በመሆን_, ледж, _mdid, --, 
   {{0x7bc00100,0x68e4022e,0x69c003cd,0x00000000}},	//   _rtou, _ldid, _otne, --, 
   {{0x5fe009d9,0x68e58be9,0x7bc01da7,0xe9c416ac}},	//   _निकल, _odid, _stou, _دغ_, 
   {{0x68e58bea,0x27e18beb,0x00000000,0x00000000}},	//   _ndid, _ovin_, --, --, 
   {{0x69c18bec,0xbc24129d,0x5b14004e,0x00000000}},	//   _atne, اربى, ампт, --, 
   {{0x705010fe,0xdd0403ee,0x990c013a,0x7e780334}},	//   _انكا, ırıy, िज्ञ_, _txtp, 
   {{0x19598bed,0x27e003d1,0xf8bc01ed,0x68e40139}},	//   ваны_, _avin_, ndég_, _bdid, 
   {{0xfe440107,0x69c00208,0x00000000,0x00000000}},	//   _инҷо, _dtne, --, --, 
   {{0x69c00548,0x27e0007f,0x68e400a9,0xa294010c}},	//   _etne, _cvin_, _ddid, _ውሳኔን_, 
   {{0x68e58bee,0xab240063,0x00000000,0x00000000}},	//   _edid, _боља_, --, --, 
   {{0x27e01ae4,0xe5c40801,0x2cc0003e,0x158c0150}},	//   _evin_, йсто, _ésdé_, _ﺒﻌﺭﺽ_, 
   {{0x68e40135,0xfa0c01e1,0xb864187c,0x00000000}},	//   _gdid, _eṣìn_, _ماخو, --, 
   {{0x24598bef,0xd5b0033f,0x659404b3,0x9f940419}},	// [29af0] гать_, _आंकड़, сату, _džús_, 
   {{0x6fcc00ab,0xe2f801ec,0xb14400f2,0x00000000}},	//   _सौगं, леуі_, گیرم_, --, 
   {{0xf8bc0c6a,0x27e00010,0x5214bbf1,0x55940798}},	//   gdég_, _zvin_, рдет, _ванѓ, 
   {{0xf8bc0231,0xa1598bf0,0x22c00270,0x4638010f}},	//   ncé_, лаху_, tākí_, _סערע, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8d543e1e,0x62040118,0x00000000,0x00000000}},	//   итич, ětlí, --, --, 
   {{0xdce00aed,0x7bdc0374,0xd7b40490,0x1fd000e5}},	//   timā, _āpur, ंदाच, _کےوز, 
   {{0xa1586943,0x00000000,0x00000000,0x00000000}},	//   _сату_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4a740046,0x27e18bf1,0x68e4009f,0x00000000}},	//   рыпт, _svin_, _pdid, --, 
   {{0x27e00055,0x00000000,0x00000000,0x00000000}},	//   _pvin_, --, --, --, 
   {{0x26180037,0x00000000,0x00000000,0x00000000}},	//   _पनही_, --, --, --, 
   {{0x69c005d1,0xcb680556,0xb6c800e5,0x98540f06}},	//   _ttne, _шале_, ہاہے_, стюш, 
   {{0x69c04673,0x89d40220,0x23ac01e1,0x68e40051}},	//   _utne, _тілш, _lójì_, _tdid, 
   {{0x9a8405f5,0x68e58bf2,0xc4c402e9,0x27e00010}},	//   _уучл, _udid, شترو, _tvin_, 
   {{0x5ee02f8b,0x95980063,0xdce00356,0x00000000}},	// [29b00] প্টে, утру_, limă, --, 
   {{0x46480b01,0xb7d800d9,0x00000000,0x00000000}},	//   _азон_, _שקיי, --, --, 
   {{0xc7640131,0xe79402f2,0x00000000,0x00000000}},	//   _ماھى, _پاکک, --, --, 
   {{0xb4d807ae,0x00000000,0x00000000,0x00000000}},	//   _hoàn, --, --, --, 
   {{0x5274fdc4,0x00000000,0x00000000,0x00000000}},	//   _ғуру, --, --, --, 
   {{0x97340023,0x00000000,0x00000000,0x00000000}},	//   _ኣወዳድ, --, --, --, 
   {{0xd24c0131,0xf8bc0129,0x0654010f,0x00000000}},	//   _كۆك_, ldée_, ייַך_, --, 
   {{0x958c0092,0x00000000,0x00000000,0x00000000}},	//   _መብትን_, --, --, --, 
   {{0xf8bd8bf3,0xcee800db,0x51540815,0xaca000a2}},	//   ndée_, ئرۇن_, _утру, dyỳa, 
   {{0xf2d0008f,0x1c1c00c5,0xb8780332,0x6f601422}},	//   ֿער_, _बईठल_, laíg, _двуз, 
   {{0x58d80108,0x00000000,0x00000000,0x00000000}},	//   лдня_, --, --, --, 
   {{0x9a900201,0x19580184,0xf8bc0129,0x00000000}},	//   _ማዕከል_, уамы_, ucé_, --, 
   {{0xf8bd1954,0x2868016c,0x7d040254,0x00000000}},	//   rcé_, арро_, õksu, --, 
   {{0x58fc031c,0x00000000,0x00000000,0x00000000}},	//   ྐུངས_, --, --, --, 
   {{0x93781b74,0xfa3402dd,0xaa540212,0x56940108}},	//   ҳбат_, _түні_, _вищу_, савт, 
   {{0x32cc07d2,0x2988003b,0x7c2400d7,0x00000000}},	//   _ﺗﯘﮔﻪ, _всьо_, ťkru, --, 
   {{0xb4c40490,0x3f9c00c5,0xe97c011a,0xd6d80066}},	// [29b10] _उभी_, _ohtu_, _שנחש, _یوکش_, 
   {{0xf2c455a7,0x950401d3,0x5fe00bae,0x00000000}},	//   рсан, _گہرے_, _निजल, --, 
   {{0xf1a4545f,0xd7580022,0xb4b03c1a,0xf8bc0129}},	//   ардн, _аиҿц_, _минә, adée_, 
   {{0xe61019d2,0x62240116,0x00000000,0x00000000}},	//   _کشی_, غىنل, --, --, 
   {{0x2cbc00ac,0x80c400ab,0xf074134b,0x00000000}},	//   vcud_, ाड़े, шидә_, --, 
   {{0x6440026c,0xa3d4010a,0xb4d80051,0x1f6412fa}},	//   _àmia, _форч, _xoàn, окім, 
   {{0xb87915ab,0xdef98bf4,0xb14400f2,0x9258014b}},	//   laíd, рыч_, _پیشم_, _савт_, 
   {{0xe6780302,0x5fe005b3,0x00000000,0x00000000}},	//   יתוח_, _निचल, --, --, 
   {{0xca8405f5,0x6018084c,0xa1340214,0x2cbc015d}},	//   өгий, _котя_, _ظرفش, rcud_, 
   {{0xaca0063f,0xdce0054e,0x00000000,0x00000000}},	//   lfịn, timă, --, --, 
   {{0x7d74bbed,0x1c1c00c5,0x00000000,0x00000000}},	//   شمیر_, _बैठल_, --, --, 
   {{0x87f805f5,0xca7401ec,0x958c0092,0x4a7401ec}},	//   лэгт_, _қулы, _መብቱን_, _қылт, 
   {{0x4ca400bd,0x07f839f6,0x2bb8007b,0x857801d5}},	//   _গ্রু, ыхны_, _شاشة_, ҳсат_, 
   {{0x6d598bf5,0x00000000,0x00000000,0x00000000}},	//   lhua, --, --, --, 
   {{0x49e40014,0xaa00004b,0x753c0175,0xab2400fb}},	//   _آبٕ, _بېجي, fjqz, _боҙа_, 
   {{0x6d598bf6,0xe4f4036b,0x06c8009d,0x00000000}},	//   nhua, تقرگ, _өгий_, --, 
   {{0x6d580113,0xaad8228d,0xb4d80051,0xd7f800d8}},	// [29b20] ihua, _मजाक, _toàn, _куќ_, 
   {{0xf8bc07ea,0xe5a40853,0x6d598bf7,0x9f980332}},	//   rdée_, сиғи, hhua, táíl_, 
   {{0x6d582a1f,0x3c8808b0,0xdce00153,0x00000000}},	//   khua, ﺗﯩﺴﻰ_, limą, --, 
   {{0x00d98bf8,0x6d580211,0x3f9c036e,0x00000000}},	//   ابات_, jhua, _shtu_, --, 
   {{0xb8780cc3,0x6d598bf9,0xdeb40150,0xdce000c0}},	//   caíd, dhua, облы, nimą, 
   {{0x6d580798,0x00000000,0x00000000,0x00000000}},	//   ehua, --, --, --, 
   {{0x0ef802d5,0x6d5836f4,0x0e440124,0x00000000}},	//   рэчы_, fhua, жьыҭ, --, 
   {{0x629d8bfa,0x4208013e,0x6d58078c,0x7c2401bf}},	//   _izro, _инҳо_, ghua, ækro, 
   {{0xfba8b46d,0x3ea800eb,0xd12c00f7,0xdce000c0}},	//   лтой_, _ºbto_, _جۅن_, jimą, 
   {{0x6d598bfb,0xdce000c0,0x00000000,0x00000000}},	//   ahua, dimą, --, --, 
   {{0xd91445b3,0xcf2421ec,0x6d580e9e,0x79a4004e}},	//   одны, _برقي, bhua, йрме, 
   {{0xf53c049f,0xb4c408e6,0x3ce40010,0x00000000}},	//   _ihåg_, _उभे_, _udov_, --, 
   {{0xbfb401dc,0x7c9400cf,0x1b20009e,0x387c0240}},	//   _điểm_, _اشاا, বাবে_, çur_, 
   {{0xac941375,0x629d8bfc,0x387c025c,0x00000000}},	//   _انها_, _ozro, ħur_, --, 
   {{0x8b641888,0x195801af,0x00000000,0x00000000}},	//   _بانم, _вайы_, --, --, 
   {{0xea740375,0x42800023,0xf48401f4,0x00000000}},	//   _לגור_, ራዉነት_, бузн, --, 
   {{0x629d8bfd,0x52d80cc9,0xc3200154,0xf7f4763a}},	// [29b30] _azro, имаю_, নানি_, _اسعد, 
   {{0xb878748d,0x6d598bfe,0x7af80194,0xb60400f5}},	//   raíd, zhua, ngtt, _лямк, 
   {{0xfbd81b37,0x50b462d9,0xf41c0166,0x64400798}},	//   _मौसम, ослу, _ayät_, _àmin, 
   {{0x6d598bff,0x910402bf,0x1014036b,0xbdfc0154}},	//   xhua, іпле, قبتد, ংবাদ_, 
   {{0x1af000fe,0x00000000,0x00000000,0x00000000}},	//   জ্যই_, --, --, --, 
   {{0xf41c578c,0x00000000,0x00000000,0x00000000}},	//   _isä_, --, --, --, 
   {{0xbea18c00,0x6d582b9d,0x645801e4,0x3ea0024c}},	//   машк, thua, ŝvit, мишг, 
   {{0xdea44013,0xfd540248,0x6d5800d8,0x387c0210}},	//   سینی, _igbọ, uhua, żury_, 
   {{0x6d580784,0x16b801ad,0xdfd4013d,0x00000000}},	//   rhua, _आलूब, _ноты, --, 
   {{0x7af8074d,0x6d598c01,0x4a040135,0x00000000}},	//   ggtt, shua, _མྱུལ_, --, 
   {{0x0d2000cf,0x9e3400f3,0xdfa81e24,0x00000000}},	//   _жүйү, _нефч, _اُلو_, --, 
   {{0xfd5401f2,0x6d580218,0x00000000,0x00000000}},	//   _mgbọ, qhua, --, --, 
   {{0x60c40407,0xdc7400c7,0x7d0801d3,0x00000000}},	//   ñimi, _нышь, élső, --, 
   {{0xd6c404a9,0xca7401e0,0x00000000,0x00000000}},	//   зирқ, _муйы, --, --, 
   {{0xf41c0793,0x2b4401ab,0xa2d807f7,0xdce00024}},	//   _asä_, _ionc_, यरस्, simą, 
   {{0xc4c801c0,0x15b84660,0xb6a016c0,0xdce00064}},	//   рлаж_, сыры_, фисл, pimą, 
   {{0xfd54413b,0x2b440427,0xd6d803d4,0x629c0210}},	// [29b40] _agbọ, _konc_, _তাৰপ, _szro, 
   {{0x2b452b05,0x00000000,0x00000000,0x00000000}},	//   _jonc_, --, --, --, 
   {{0x2b44030a,0xdb240022,0x00000000,0x00000000}},	//   _monc_, ûsév, --, --, 
   {{0x629d108f,0xb4d801e1,0x9f5401e1,0x00000000}},	//   _vzro, _olày, _òfún_, --, 
   {{0x629c068f,0x03a425ff,0x15b021ef,0xb87801e7}},	//   _wzro, _мимо, _سەكس, maíc, 
   {{0xdd903451,0xf8bc0332,0xb8780332,0xae400014}},	//   کوب_, idéa_, laíc, ژھنو, 
   {{0x629c04b9,0xb4d80241,0x11d400d4,0x00000000}},	//   _uzro, _alày, _нітр, --, 
   {{0x29018c02,0x6da00261,0xada00798,0x00000000}},	//   _ncia_, мија, мајл, --, 
   {{0x212436f4,0x51540064,0xbf1400db,0x00000000}},	//   _iamh_, _этру, _وورب, --, 
   {{0x3f74068f,0xa3dc2ef1,0x2b458c03,0x20040784}},	//   dług_, णीय_, _conc_, _iqmi_, 
   {{0x2b458c04,0x19958c05,0x7f58025c,0xda340108}},	//   _donc_, заня, _iltq, чены, 
   {{0xf9698c06,0xa9c000d6,0x2c800024,0xae680137}},	//   ррой_, ьськ, _būdą_, _ئشكە_, 
   {{0x261c01e4,0xad840e56,0x2b440129,0xb4c400dc}},	//   _aŭo_, _بالۇ, _fonc_, _उभौ_, 
   {{0x21258c07,0x34d008ec,0x2c800153,0xb8780174}},	//   _lamh_, तर्द, _dūdą_, taíb, 
   {{0xf41c02f6,0x3568e7bf,0x1b200011,0xf5698c08}},	//   _ssä_, аран_, বাদে_, ашак_, 
   {{0xb8798c09,0x21240007,0xe5340024,0xa96800f3}},	//   raíb, _namh_, месь, _мија_, 
   {{0xc21c02dd,0x059401d5,0x271000cc,0x00000000}},	// [29b50] _ءﺟﯘﺭ, سافگ, ায়ো_, --, 
   {{0x72280124,0xb87800d8,0xe8b80327,0xae18000d}},	//   ицев_, paíb, _དཔོག, _भईलन_, 
   {{0x56958c0a,0x661c074d,0x20058c0b,0x559403b7}},	//   _хант, cwrk, _aqmi_, _наоѓ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x21243e7c,0xc17000f2,0x00000000,0x00000000}},	//   _damh_, رگفت, --, --, 
   {{0x212400a3,0x2f880114,0xff2000d8,0x00000000}},	//   _eamh_, шљен_, емшо, --, 
   {{0x21240007,0x20040113,0x316c0077,0x00000000}},	//   _famh_, _eqmi_, pigz_, --, 
   {{0xb4d8004e,0x212401ab,0x61140063,0x4a7400c7}},	//   _clàx, _gamh_, _одсу, ҧынт, 
   {{0x65680066,0x2b457e2f,0xe53c011a,0x00000000}},	//   èdhi, _ponc_, שתחר, --, 
   {{0x29018c0c,0xfbcc05d9,0x00000000,0x00000000}},	//   _scia_, اڪن_, --, --, 
   {{0x29000789,0x6ad8000d,0x60e00166,0x00000000}},	//   _pcia_, _मजीर, _özmä, --, 
   {{0x276c010c,0x7e980375,0x00000000,0x00000000}},	//   _ቃለመጠ, _הסעו, --, --, 
   {{0x2d40005a,0xc320009e,0xab6000db,0xcb340395}},	//   _oñez_, নাতি_, _يۇبى, _недъ, 
   {{0x79e400e5,0x00000000,0x00000000,0x00000000}},	//   _کوٹہ_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2f0c0598,0x317c17a3,0x63618c0d,0x7cf40342}},	//   lıgı_, _njuz_, _köng, mürü, 
   {{0x212401c3,0x24600092,0xdce00064,0x7cf406be}},	// [29b60] _ramh_, ዲካሄድ_, gimę, lürü, 
   {{0x947802bf,0xf8bc0c6a,0x212401e7,0xfb0400e8}},	//   істу_, ndén_, _samh_, ñëxu_, 
   {{0x63600008,0xb6b80375,0xf77005d9,0x29e416a3}},	//   _löng, _לציי, _ساٿ_, nđa_, 
   {{0x80d0015b,0x5a0c008f,0xc05801ec,0x00000000}},	//   _হাঙ্, שלאַ, йіл_, --, 
   {{0xf53c08fb,0x7cf403e3,0x00000000,0x00000000}},	//   _tiår_, hürü, --, --, 
   {{0x44218c0e,0x8f803b9f,0x7cf40342,0x00000000}},	//   _isk_, вқул, kürü, --, 
   {{0x7e2801ce,0x93540023,0x212408c2,0xf8bc002e}},	//   сіла_, _ዘረባታ, _tamh_, ddén_, 
   {{0x7cf44a4a,0x636001ed,0x212408c2,0x00000000}},	//   dürü, _böng, _uamh_, --, 
   {{0x06e000bd,0x44218c0f,0x1b200011,0x46bc0b6d}},	//   _বানি, _jsk_, বাসে_, ्डाह, 
   {{0x44218c10,0x6360f044,0x00000000,0x00000000}},	//   _msk_, _döng, --, --, 
   {{0x442003cd,0x3f8c037e,0xc05802dd,0xa3dc041c}},	//   _lsk_, mofu_, _тің_, णीत_, 
   {{0x636001a8,0x3f8d8c11,0x00000000,0x00000000}},	//   _hönd, lofu_, --, --, 
   {{0x7d005628,0x63618c12,0xdc542263,0x3f8c0421}},	//   _icos, _göng, _تراک, oofu_, 
   {{0x7c218c13,0x3f8c037e,0xab240022,0x00000000}},	//   _isor, nofu_, _ноча_, --, 
   {{0x4420e397,0x636008a5,0xaa90009b,0x00000000}},	//   _ask_, _mönd, _пишч, --, 
   {{0x63618c14,0x44218c15,0x3f8ce3a5,0xe5b40032}},	//   _lönd, _bsk_, hofu_, ейсы, 
   {{0x3f8d8c16,0x00000000,0x00000000,0x00000000}},	// [29b70] kofu_, --, --, --, 
   {{0x44218c17,0x2ca800ac,0x58fc031c,0xb4b000d1}},	//   _dsk_, ükdə_, ྐུམས_, _җигә, 
   {{0x44218c18,0x98b80166,0x00000000,0x00000000}},	//   _esk_, lisı_, --, --, 
   {{0x90998c19,0x7c218c1a,0x44218c1b,0xe1f0bfae}},	//   овет_, _osor, _fsk_, اسل_, 
   {{0x44218c1c,0x3f8d8c1d,0x7c218c1e,0x795c00e8}},	//   _gsk_, fofu_, _nsor, _gëwe, 
   {{0xb8dc0135,0x3f8c01f7,0x667401b9,0xef90015e}},	//   _ཇུ_, gofu_, _آدیر, ریاد, 
   {{0x63618c1f,0x798c0117,0x2bdc878d,0x00000000}},	//   _söng, kocw, पीना, --, 
   {{0x7d0007ab,0x7c200175,0x63600108,0x442003e0}},	//   _ccos, _bsor, _pöng, _ysk_, 
   {{0x7c218c20,0x63616a71,0x3f8d8c21,0xcba4010b}},	//   _csor, _fönd, bofu_, маий, 
   {{0x63618c22,0xca74da8f,0x7cf42c6f,0x7c200175}},	//   _gönd, думы, türü, _dsor, 
   {{0x6360006a,0x09bc015b,0x3b80009d,0x7bc40022}},	//   _wöng, _আবহা, тлэг, ãkur, 
   {{0x636005bb,0x29e4727d,0x7d00007b,0x798c009a}},	//   _töng, rđa_, _gcos, gocw, 
   {{0x6360029f,0x6d4802d0,0x7cf40790,0x00000000}},	//   _yönd, _ioga, sürü, --, 
   {{0x6d498c23,0x636026f8,0x46a4009d,0x7cf44e7e}},	//   _hoga, _köne, дагв, pürü, 
   {{0x6d498c24,0x798c2959,0x4420ce28,0x7d0002d0}},	//   _koga, bocw, _ssk_, _ycos, 
   {{0x6d498c25,0x798d468a,0xf8bc003e,0x7c200129}},	//   _joga, cocw, ndél_, _ysor, 
   {{0xb7d425aa,0x63618c26,0xb87800c6,0x83540f1c}},	// [29b80] _قويا_, _löne, laín, وپرا, 
   {{0x64a40046,0x44218c27,0x98a801a6,0xbd9c02d3}},	//   даға, _vsk_, _snać_, ልከቶም_, 
   {{0x6d498c28,0xb87800d8,0x41040006,0x6360032e}},	//   _ooga, naín, дзев, _rönd, 
   {{0x6d482af2,0x63618c29,0xaca00241,0xc4f98c2a}},	//   _noga, _sönd, _afọj, _بعدا_, 
   {{0x44218c2b,0x3f8d8c2c,0xbfa811ed,0x80187932}},	//   _usk_, tofu_, отке_, تزاز_, 
   {{0x7d018c2d,0x3eb803a1,0x6d498c2e,0x63618c2f}},	//   _scos, øpt_, _aoga, _böne, 
   {{0x798c014b,0x2cb000ac,0x7c200327,0xd6d80154}},	//   yocw, əbdə_, _ssor, _তাৎপ, 
   {{0x6d498c30,0x63600ab7,0xf2a00276,0x3f8d8c31}},	//   _coga, _döne, _рисп, sofu_, 
   {{0x3f8d8c32,0x63618c33,0x798c014b,0xfb8400fd}},	//   pofu_, _tönd, vocw, дынн, 
   {{0x6d4803ac,0xba0802e8,0x78a80162,0x6bd40014}},	//   _eoga, охме_, _úgvi, بوٝس_, 
   {{0x6d498c34,0x63618c35,0xb81004c5,0xee2c0451}},	//   _foga, _könb, িয়াত_, _پٽن_, 
   {{0x7c218c36,0x6d498c37,0x6b5c002d,0x7d000857}},	//   _tsor, _goga, _rêge, _ucos, 
   {{0xf7718c38,0x7c2005db,0x6b5c002d,0x68d40640}},	//   ناس_, _usor, _sêge, ђорђ, 
   {{0x63600ab7,0x6d498c39,0x00000000,0x00000000}},	//   _yöne, _zoga, --, --, 
   {{0x6d498c3a,0xb8791a82,0x2b540214,0x2bdcdc75}},	//   _yoga, caín, _آیپد_, पीठा, 
   {{0x6d480f71,0x06e011ba,0x00000000,0x00000000}},	//   _xoga, _বাণি, --, --, 
   {{0x65958c3b,0xb8780597,0x82380092,0x62980327}},	// [29b90] тату, maío, _የሚረዳ, żvol, 
   {{0xb8780491,0x5f00068f,0x822c1772,0xa7740064}},	//   laío, _राष्_, _ሰላምታ, _альч, 
   {{0x50f43252,0xb3dc12eb,0xe3b000ae,0x00000000}},	//   езет, _पौरख, شرك_, --, 
   {{0xb8780597,0x63618c3c,0x00000000,0x00000000}},	//   naío, _röne, --, --, 
   {{0x63618c3d,0xf48407d5,0x00000000,0x00000000}},	//   _söne, _цунн, --, --, 
   {{0x6d498c3e,0xb8798c3f,0xf8bc002e,0x00cc01ec}},	//   _soga, haío, ddém_, _ﺗﯩﺸﻘ, 
   {{0x2c142ba2,0x63600139,0x7bc401e4,0x00000000}},	//   _बैजू_, _qöne, ŭkul, --, 
   {{0xa3dc0490,0x6d4801a9,0xcd040116,0x00000000}},	//   णीव_, _qoga, хпий, --, 
   {{0x6d498c40,0xb8780597,0xf8bc003e,0xc3200154}},	//   _voga, daío, rdél_, নারি_, 
   {{0x4a441d83,0x6b5c145e,0x6d498c41,0x63617c29}},	//   енов, _sêgb, _woga, _töne, 
   {{0x6d498c42,0xb878007b,0x5f7400ae,0x00000000}},	//   _toga, faío, _شاكر, --, 
   {{0x29058c43,0xb878007b,0x6d480153,0x3d140037}},	//   üma_, gaío, _uoga, _भउये_, 
   {{0xb8780005,0x6fa001f9,0x19400022,0x8a6002f2}},	//   saín, _ओठां, рҭын, _ڕێدۆ, 
   {{0x636017da,0xa9240024,0x29040135,0x8d7402f2}},	//   _mönc, _ąžuo, żma_, _تاڕا, 
   {{0xba500597,0x636007de,0x6b8000b5,0x453493fb}},	//   _منوع, _lönc, _ijng, нхат, 
   {{0xb8780491,0xfa08003d,0x0444109a,0x00000000}},	//   caío, _ཀྱིན_, небн, --, 
   {{0xd3c40131,0x383000f7,0x00000000,0x00000000}},	// [29ba0] نتلى, _مىيز, --, --, 
   {{0xf77000ec,0xaa400023,0x9f4c03e0,0x00000000}},	//   _ماپ_, _ንመስዋ, ülüp_, --, 
   {{0xb878007b,0xc32000eb,0x00000000,0x00000000}},	//   haíl, নালি_, --, --, 
   {{0x26d801bf,0x00000000,0x00000000,0x00000000}},	//   lbro_, --, --, --, 
   {{0x795c002e,0x25dc012c,0x49101bd6,0x00000000}},	//   _jëwa, गीरी_, ध्यो_, --, 
   {{0x6720000d,0x6444022f,0x26d84f44,0x863c0023}},	//   मजिक_, mxii, nbro_, _ኣመንት, 
   {{0x6e90036b,0x64440014,0x795c00e8,0x63600139}},	//   лишу, lxii, _lëwa, _tönb, 
   {{0x65640c67,0x1d3400a7,0x1e218c44,0x00000000}},	//   nhih, тния, _मनीष_, --, 
   {{0x65658c45,0x64443a73,0xfd64004d,0x8c840124}},	//   ihih, nxii, _khuế, кәша_, 
   {{0x5a358c46,0x65658c47,0xdb1001b8,0xf7c40131}},	//   внот, hhih, _äfüm, _ﺩﯙﻟﻪ, 
   {{0xb8780597,0x65658c48,0xd52c0241,0x26d875f9}},	//   taío, khih, _jọ́s, dbro_, 
   {{0xa3c0038e,0x8ac40588,0x00000000,0x00000000}},	//   ँदा_, нқәа_, --, --, 
   {{0xb8780597,0x65658c49,0xdedc069d,0x00000000}},	//   raío, dhih, _ፕላን_, --, 
   {{0xb8780597,0x3ebc0481,0x64440076,0x26d98c4a}},	//   saío, _jgtt_, dxii, gbro_, 
   {{0x56940032,0xb87801e7,0xf8bd8c4b,0x62980327}},	//   тавт, paío, ndék_, żvoj, 
   {{0x65658c4c,0xb87801e7,0x65940e3b,0x00000000}},	//   ghih, laím, гасу, --, 
   {{0x26d80395,0x241812c4,0x3ebc01a6,0xf41c0108}},	// [29bb0] bbro_, ноты_, _ogtt_, _exän_, 
   {{0x7bc00810,0xb87801e7,0x69c8032e,0x00000000}},	//   _muou, naím, _ómeð, --, 
   {{0x40cc01f2,0x64440009,0x52e0012d,0x656400dc}},	//   _ịrị_, axii, _फ़ीस, bhih, 
   {{0x65658c4d,0x6444198f,0x356801e0,0xb878498d}},	//   chih, bxii, _хрон_, haím, 
   {{0xe8c00156,0xdb180120,0x6444003a,0x00000000}},	//   _ཚུལག, _vivê, cxii, --, 
   {{0xc47408a8,0x73c001e0,0x00000000,0x00000000}},	//   _יתרו_, _аҡҡа, --, --, 
   {{0x62346128,0x6b640241,0xb8780332,0x2284022e}},	//   _йеру, _légù, daím, _бутг, 
   {{0x69c4278a,0x22940108,0xa2940064,0x00000000}},	//   íjem, _сися, _сасі, --, 
   {{0xa1842cd0,0xdb180100,0xc6180349,0x6360007c}},	//   _сырл, _kivè, ডিযা_, _höna, 
   {{0x1620012c,0x63600139,0x00000000,0x00000000}},	//   मबार_, _köna, --, --, 
   {{0x63600793,0xc33004ae,0xb878007b,0x00000000}},	//   _jöna, בוי_, saíl, --, 
   {{0x4ad008ec,0xdb18067c,0x64440548,0x63600139}},	//   _द्रव, _livè, yxii, _möna, 
   {{0x8b249333,0x63615408,0x3ebc0198,0x1bd400d1}},	//   _адле, _löna, _ygtt_, _бочя, 
   {{0x6d58d073,0xdb181497,0xf8bc0098,0xb8780332}},	//   lkua, _nivè, hdéh_, caím, 
   {{0x65641aa1,0x26d851dc,0x64453d3b,0x00000000}},	//   thih, rbro_, wxii, --, 
   {{0x6d598c4e,0x69c00194,0x64dc02ab,0x9598004e}},	//   nkua, _iune, बरेश, етуу_, 
   {{0x6b6401e1,0xa3dc043e,0x6d58035b,0x00000000}},	// [29bc0] _gégù, णीं_, ikua, --, 
   {{0x65658c4f,0x7410021a,0x27e18c50,0x6d586f9e}},	//   shih, شوما, _iwin_, hkua, 
   {{0x6d598c51,0x69c18c52,0xdb198c53,0x2fdc0098}},	//   kkua, _june, _divè, _awug_, 
   {{0x27e01509,0x63600793,0x68e400ad,0x6444022f}},	//   _kwin_, _döna, _jeid, pxii, 
   {{0x69c18c54,0x68e58c55,0x796803f9,0x27e0007f}},	//   _lune, _meid, nƙwa, _jwin_, 
   {{0xd5e8dd80,0x27e18c56,0x6d5800c7,0x7bc00051}},	//   _تعین_, _mwin_, ekua, _ruou, 
   {{0x69c18c57,0x324001d2,0x63bc00a3,0x41b4f7ef}},	//   _nune, _керг, _iirn, _асат, 
   {{0x68e58c58,0x44318c59,0x63bd8c5a,0x78b80024}},	//   _neid, ovy_, _hirn, žuvi, 
   {{0x69c18c5b,0x63bd8c5c,0x7bc016b8,0xc21c0220}},	//   _aune, _kirn, _quou, _ءﺗﯘﺭ, 
   {{0x629d0f61,0x63bd8c5d,0xdb198c5e,0x2ee400b5}},	//   _kyro, _jirn, _kivé, canf_, 
   {{0x68e58c5f,0x27e18c60,0xb87800ae,0x6d940022}},	//   _beid, _awin_, raím, tãat, 
   {{0x629cac24,0x27e16120,0x18741ee0,0x68e40368}},	//   _myro, _bwin_, _አንጻር_, _ceid, 
   {{0x68e58c61,0x69c01e0b,0x63bc0192,0xfb240209}},	//   _deid, _eune, _oirn, _үпҗү, 
   {{0x629c0280,0x52e00034,0x63bd8c62,0xac1400a8}},	//   _oyro, _फ़ेस, _nirn, _рошу_, 
   {{0x68e40491,0x69c18c63,0x27e18c64,0x6d8401d9}},	//   _feid, _gune, _ewin_, _سۅیہ_, 
   {{0xf98853f3,0x68e58c65,0x48c000c7,0x443000e4}},	//   _تخته_, _geid, _гәра, fvy_, 
   {{0x63bd8c66,0xe4558c67,0x27e07c48,0x629d8c68}},	// [29bd0] _birn, акты, _gwin_, _ayro, 
   {{0x69c18c69,0x629d8c6a,0x63bd8c6b,0x68e41190}},	//   _yune, _byro, _cirn, _zeid, 
   {{0x6d598c6c,0x4431662e,0x68e40286,0x27e01529}},	//   ykua, avy_, _yeid, _zwin_, 
   {{0xdb198c6d,0x6360014a,0x629c152c,0x63bd8506}},	//   _divé, _vöna, _dyro, _eirn, 
   {{0x629c2819,0x63bc0694,0xe0d802bf,0xddd80419}},	//   _eyro, _firn, тві_, lyvň, 
   {{0x63bd8c6e,0x63618c6f,0xf99c07c5,0x629c0200}},	//   _girn, _hönn, hlè_, _fyro, 
   {{0x63618c70,0x6d598c71,0xf8e008e6,0x60c40006}},	//   _könn, tkua, पराय, žima, 
   {{0x636001ed,0x637c0267,0x63bd8c72,0x6d5800e4}},	//   _jönn, pånä, _zirn, ukua, 
   {{0x6d598c73,0x63600008,0xcc3400c6,0x6e9c01ad}},	//   rkua, _mönn, اربع, _ओरकु, 
   {{0x69c18c74,0x6d598c75,0x89d40046,0x63bc0014}},	//   _pune, skua, лімш, _xirn, 
   {{0xc33004ac,0x27e18c76,0x6d580cfe,0x68e58c77}},	//   זוי_, _swin_, pkua, _peid, 
   {{0x69c018f7,0xf99c0699,0x27e00585,0xfd640882}},	//   _vune, glè_, _pwin_, karṣ, 
   {{0x68e58c78,0x69c18c79,0x00000000,0x00000000}},	//   _veid, _wune, --, --, 
   {{0x68e4092e,0xf99c19f5,0x2d9d8c7a,0xa9240064}},	//   _weid, alè_, llue_, _įžul, 
   {{0x68e58c7b,0x2bdc34ef,0xf99c0100,0x636008a5}},	//   _teid, पीरा, blè_, _bönn, 
   {{0x63bd8c7c,0x0904234c,0x4430219b,0x27e087c4}},	//   _sirn, _спин, tvy_, _twin_, 
   {{0x629c3e9e,0x15b98c7d,0x63bcbc8a,0x82f87f51}},	// [29be0] _syro, тыры_, _pirn, فراز_, 
   {{0x63bc0d04,0x872434d8,0x44318c7e,0xc694007b}},	//   _qirn, _смож, rvy_, _مشجع, 
   {{0x63bd8c7f,0x644000f3,0x44300af9,0xd3b40108}},	//   _virn, _šmid, svy_, рсть, 
   {{0x629d8c80,0xb7d44da2,0xdb18067c,0x636017da}},	//   _vyro, _جویا_, _vivé, _gönn, 
   {{0x629c0034,0x25a0009a,0xca280023,0x3fc4158f}},	//   _wyro, mlil_, _ድያብሎ, اگری_, 
   {{0x629d8c81,0xdb198c82,0x25a18c83,0x0734008f}},	//   _tyro, _tivé, llil_, ראַם_, 
   {{0xdd918c84,0x2d9d3e9b,0xd36c21ef,0x636001e3}},	//   يوت_, flue_, _تۇل_, _höno, 
   {{0x5d546a0b,0x63600139,0x9bf40120,0x00000000}},	//   ркит, _köno, азич, --, 
   {{0xd1752573,0x795c002e,0x25a0011f,0x71500035}},	//   _тыры, _dëwl, ilil_, _انقض, 
   {{0xc3200729,0x25a18c85,0x2d9c0b30,0x9b5803b7}},	//   নাকি_, hlil_, alue_, тиот_, 
   {{0x2d9d8c86,0x25a18799,0x6fb0e541,0xac900aac}},	//   blue_, klil_, _املا, _қашш, 
   {{0x2d9d8c87,0xf99c007f,0x19940024,0xb87803b2}},	//   clue_, ulè_, рамя, nbíg, 
   {{0x63618c88,0x25a00306,0x00000000,0x00000000}},	//   _rönn, dlil_, --, --, 
   {{0xfd640882,0x63617a9c,0xf99c02e2,0x00000000}},	//   varṣ, _sönn, slè_, --, 
   {{0x58d40c04,0x636001a8,0xf99d8c89,0x25a00327}},	//   _койт, _pönn, plè_, flil_, 
   {{0x58397997,0x6361493a,0xe5c4005b,0x2c1403d4}},	//   _азия_, _böno, ссро, তিৰে_, 
   {{0xeab40116,0xa9bc0375,0xe8d80375,0xdd00013a}},	// [29bf0] _ийә_, _אזהר, _עוזר_, _štěc, 
   {{0x25a0000d,0xc76400cf,0x64a40114,0x00000000}},	//   alil_, _ناپى, сађа, --, 
   {{0xb4d801ab,0x63618c8a,0x64400135,0xcfbc01ec}},	//   _cnàc, _tönn, _ġmie, _ﺠﺎﻨﺒ, 
   {{0x7580035c,0xfbd800fe,0xd10000db,0x00000000}},	//   _ایرم, _দিনত, تۋرۋ, --, 
   {{0x6360723e,0x504400a7,0xf1a402dd,0x5f0000bc}},	//   _könl, релб, _ұран, _राख्_, 
   {{0xb8780af2,0xe61000f2,0x752d8c8b,0xe1f000cf}},	//   mbíd, _بشی_, _hacz, زسۅ_, 
   {{0xf1a42082,0x752d8c8c,0x777400b5,0x6b5c0af9}},	//   _бран, _kacz, _mmxx, _sêgo, 
   {{0x6360007c,0x60c401e4,0x00000000,0x00000000}},	//   _lönl, ɾimo, --, --, 
   {{0x752c0210,0x00000000,0x00000000,0x00000000}},	//   _macz, --, --, --, 
   {{0x2d9c0158,0xb928004d,0x35940092,0x752c06d8}},	//   slue_, _thuỳ_, _መጥቀስ_, _lacz, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x752c0034,0x25a001a9,0x4c9401ec,0x4c3400c0}},	//   _nacz, xlil_, _киес, _вэкт, 
   {{0x25a00427,0x00000000,0x00000000,0x00000000}},	//   vlil_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x752d8c8d,0x25a136e3,0xd3c41870,0x00000000}},	//   _bacz, tlil_, ەتمى, --, 
   {{0x63600793,0xbdf8015b,0xb99000f1,0x25a0000d}},	//   _pöno, _আহমদ_, _ولوب, ulil_, 
  
   {{0x752c04cc,0x7d140139,0x02d400be,0x00000000}},	// [29c00] _dacz, _öyse, لتاخ, --, 
   {{0x25a00dfe,0x6360fa44,0xfa7802d3,0x638401b9}},	//   slil_, _vöno, _ኣንባቢ_, ёҳва, 
   {{0xa5640020,0x733007a7,0x752c04cc,0x4224014b}},	//   _መፈለጊ, تىلا, _facz, рдев, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x63602fbe,0x60c58c8e,0xff240117,0x00000000}},	//   _yönl, žimo, имдо, --, 
   {{0x752c068f,0x00000000,0x00000000,0x00000000}},	//   _zacz, --, --, --, 
   {{0x7e280212,0xaee000dc,0xc0e401a9,0x00000000}},	//   тіла_, _saṃl, _вобк, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfba8499d,0x99580118,0x70f8011a,0x19580124}},	//   ктой_, též_, _שהמח, ҳаны_, 
   {{0x65680023,0xf410011a,0xef1414a3,0xe8e00051}},	//   ëdhj, קפת_, _вмф_, ướn_, 
   {{0xceac36d8,0x79a40209,0xd20c01ec,0xeb4400fd}},	//   _хә_, ирме, _ءﺩﯨﻨ, рчык_, 
   {{0xec10021a,0xc3200154,0x00000000,0x00000000}},	//   _ژوند, নাটি_, --, --, 
   {{0xb8cc4a04,0x752c068f,0xb8780124,0x00000000}},	//   _कर_, _racz, haív, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x752c0034,0xb9e4075e,0xb87800e4,0x00000000}},	//   _pacz, _ئستى, jaív, --, 
   {{0x636043eb,0x24f98c8f,0x25e80073,0x1ae401af}},	//   _dönm, инсы_, _जबरी_, _тоҫм, 
   {{0xf2c58c90,0x6360013d,0xe508009f,0x65840124}},	// [29c10] асен, _tönl, شيلو_, цырз, 
   {{0x34a409d9,0x241811db,0xb1e00588,0xb87820ab}},	//   _खरीद, рофы_, жәақ, rbíd, 
   {{0x5f001533,0x57b400bc,0x752c15c0,0x00000000}},	//   _राज्_, ूदीह, _tacz, --, 
   {{0xf8bc004e,0x92c8009e,0x00000000,0x00000000}},	//   sdéu_, োণে_, --, --, 
   {{0xb444013d,0x64a41fbe,0x636001f4,0x00000000}},	//   _тэнк, _маџа, _mönj, --, 
   {{0xf8bd8c91,0x00000000,0x00000000,0x00000000}},	//   ldés_, --, --, --, 
   {{0xdb181709,0xdf48007b,0xecf000d1,0x7144010a}},	//   _civí, شؤون_, قۋاد, _кхаж, 
   {{0xf8bc6320,0xcd2802f6,0x98a40034,0xdb18810d}},	//   ndés_, ужие_, ślę_, _diví, 
   {{0xdfd4081d,0x9cd403e6,0xf8bc0129,0x00000000}},	//   _моты, ڵڕۆژ, idés_, --, 
   {{0xcb68dc6f,0x00000000,0x00000000,0x00000000}},	//   امده_, --, --, --, 
   {{0x4a740150,0x00000000,0x00000000,0x00000000}},	//   сыпт, --, --, --, 
   {{0xf41c00d7,0x5ba8004e,0x00000000,0x00000000}},	//   _opä_, лкөм_, --, --, 
   {{0xa2e803f4,0x63607b37,0xdc758c92,0x00000000}},	//   _পাসও, _sönm, _мышь, --, 
   {{0xd1f80020,0x443c0316,0xdc8000c7,0x38400023}},	//   _ወጣት_, _čt_, _цқьо, _ንጸላእ, 
   {{0xf41c006a,0x46a4136b,0x29045c99,0x36646b2a}},	//   _apä_, савв, òmas_, баро_, 
   {{0xb87800c7,0x00000000,0x00000000,0x00000000}},	//   vaív, --, --, --, 
   {{0x48dc2122,0xa4940214,0x00000000,0x00000000}},	// [29c20] _क्यो_, زیست, --, --, 
   {{0x06e000bd,0xf8bc0129,0xc2b40114,0x00000000}},	//   _বাকি, adés_, бљењ, --, 
   {{0xc7640075,0xe7a802dd,0x63618c93,0xf41c01f4}},	//   _ناھى, _مۇڭى_, _hönk, _epä_, 
   {{0x26380232,0x63608b82,0xf53c0419,0xb87800e4}},	//   _ičo_, _könk, áťte_, raív, 
   {{0x6360049f,0xb8780022,0x00000000,0x00000000}},	//   _jönk, mbíc, --, --, 
   {{0xbc241b56,0x6360023a,0xb87801e7,0x00000000}},	//   ەردى, _mönk, maít, --, 
   {{0xf8bc737d,0xb878007b,0xa28430cd,0x11d40024}},	//   ndér_, laít, _بیاو, _мітр, 
   {{0xdd90a9da,0xdb1809ff,0x3d2400d4,0x00000000}},	//   بوب_, _viví, ськв, --, 
   {{0x80640945,0xa6c000bd,0xb878007b,0xa3dc0490}},	//   _уваж, ্রিয়, naít, णीच_, 
   {{0xa560001f,0xf8bc01d3,0xbb28084c,0xefb0029e}},	//   ለምአቀ, zdés_, уцие_, _فینگ, 
   {{0x3f9c0113,0xb87900fd,0x00000000,0x00000000}},	//   _iktu_, haít, --, --, 
   {{0x06e004c5,0x636008a5,0xe8e00208,0x00000000}},	//   _বাগি, _bönk, ườn_, --, 
   {{0x34a40574,0x63600139,0x613c0092,0x00000000}},	//   _खरेद, _cönk, _በጌታች, --, 
   {{0xb878007b,0x29040192,0xdb1401e1,0x00000000}},	//   daít, òmar_, _íbàd, --, 
   {{0x7ae800a8,0x795c002e,0xf41c007c,0x00000000}},	//   _ieft, _lëwi, _spä_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf8bd8c94,0x93781367,0x00000000,0x00000000}},	// [29c30] rdés_, абат_, --, --, 
   {{0x7ae804b9,0xf2c58c95,0xb4d807c5,0xd1f8001f}},	//   _jeft, ссан, _gnàn, _ወጣቱ_, 
   {{0x24180046,0x33300076,0x72a000d1,0x7ae815b7}},	//   _қоры_, rdxx_, سەرن, _meft, 
   {{0x3f9d8c96,0x7ae98c97,0xe29800d4,0xdb0800a2}},	//   _aktu_, _left, щає_, lmdä, 
   {{0x7ae802c1,0xdce00024,0xb8780332,0x00000000}},	//   _oeft, limė, caít, --, 
   {{0x7ae8ff42,0xc0f40023,0x00000000,0x00000000}},	//   _neft, _ወዓል_, --, --, 
   {{0xaf840032,0xdce00064,0x00000000,0x00000000}},	//   аҡҡа_, nimė, --, --, 
   {{0x21640220,0x00000000,0x00000000,0x00000000}},	//   _етуг, --, --, --, 
   {{0x3f9c03a0,0x795c01c7,0x7ae80240,0xdce00139}},	//   _fktu_, _gëwi, _beft, gomı, 
   {{0x2d8001ed,0xdce00024,0x4ab800a8,0xa6c003d4}},	//   ője_, kimė, иуня_, ্ৰিয়, 
   {{0x7bc435f1,0x7ae98c98,0x3a2c0100,0xfbc800eb}},	//   íkur, _deft, _csfp_, লীলত, 
   {{0x9f642f08,0x636122ac,0x6b680092,0xdce00166}},	//   ötön_, _pönk, _ስለሌለ_, bomı, 
   {{0x6ca4c3bd,0x7ae8003a,0xcb08009f,0x7bc401e4}},	//   _اصال, _feft, _نيشن_, ŭkur, 
   {{0x7ae89b14,0x36d00454,0x00000000,0x00000000}},	//   _geft, доёр, --, --, 
   {{0x85783e07,0x7bd40139,0xdce000c0,0x00000000}},	//   асат_, _çyur, gimė, --, 
   {{0x243c069c,0xf8bcc623,0xb87826d3,0x636001d3}},	//   _ሓላፍነ, rdér_, taít, _tönk, 
   {{0x1cc80135,0x7ae98c99,0x42e80114,0x00000000}},	// [29c40] _ཉུལ_, _yeft, имао_, --, 
   {{0x6b5c006a,0xdb1800dd,0x63618c9a,0x6aa00008}},	//   _bêgi, _kivá, _köni, _kynf, 
   {{0x63600793,0xb878007b,0x69c4a98b,0x778012fa}},	//   _jöni, saít, _kiie, _ілюз, 
   {{0x02a80d0a,0x044400a8,0x3f9c05b1,0xb8780077}},	//   _करीन, _демн, _sktu_, caís, 
   {{0x63600793,0x69c40036,0x92e80183,0x61f00064}},	//   _löni, _miie, _যাৰ_, _šklė, 
   {{0x44200263,0xb0300212,0x2fc402dd,0x6564b1a0}},	//   _ipk_, ьніш, ірің, lkih, 
   {{0x7ae80175,0x44218c9b,0xdb2402d2,0xbd6810e4}},	//   _reft, _hpk_, _ásér, ирие_, 
   {{0x44200073,0x7ae98c9c,0x65658c9d,0x3f9c4a95}},	//   _kpk_, _seft, nkih, _wktu_, 
   {{0x44218c9e,0xb87800c7,0x02a8483e,0x00000000}},	//   _jpk_, haír, _करुन, --, 
   {{0xb4d80228,0x636004cc,0x65658c9f,0xbf6402da}},	//   _anàl, _böni, hkih, _بدرو, 
   {{0x69c402ea,0x7ae80008,0xdb1804cc,0x6564023a}},	//   _biie, _veft, _vivà, kkih, 
   {{0xdb180232,0x7ae801d9,0xb8780407,0x63600139}},	//   _divá, _weft, daír, _döni, 
   {{0x644007f5,0x442081ec,0x7ae98ca0,0x00000000}},	//   _šmin, _npk_, _teft, --, 
   {{0x7c200588,0x6aa0002d,0xab24209b,0x02a80073}},	//   _ipor, _fynf, _моча_, _करून, 
   {{0x44218ca1,0x63618aeb,0x69c505d5,0x6aa0015d}},	//   _apk_, _göni, _fiie, _gynf, 
   {{0x44208983,0x7c2002e3,0x65658ca2,0x57f42082}},	//   _bpk_, _kpor, gkih, _епит, 
   {{0xd250e01a,0xdce00024,0x44200153,0x85980092}},	// [29c50] کنا_, simė, _cpk_, _መጥፋቱ_, 
   {{0x7c218ca3,0x442005b1,0xb878056a,0x656400b0}},	//   _mpor, _dpk_, saís, akih, 
   {{0x06e004c5,0x644005f7,0xe2c8004b,0xf53c00b8}},	//   _বাচি, _ámin, زونو_, _bhåt_, 
   {{0x69c40561,0xf8ac00bc,0xe1d8003b,0x00000000}},	//   _xiie, _घराय, ідчі_, --, 
   {{0xd6bc6569,0x442005b1,0x6008177b,0xb36402e8}},	//   _অভিয, _gpk_, жнім_, _дъвк, 
   {{0x0e54013e,0x645803e0,0x00000000,0x00000000}},	//   зъия, çbiş, --, --, 
   {{0xf41c01f4,0xdb0801e1,0x00000000,0x00000000}},	//   _exät_, _àlùp, --, --, 
   {{0x06e0009e,0x442082a9,0x7c218ca4,0x714000db}},	//   _বাছি, _ypk_, _bpor, _تىرۅ, 
   {{0x6aa1597d,0x69c400af,0x795c00e8,0x06e002f5}},	//   _synf, _riie, _jëwu, _বাঘি, 
   {{0x7c2028b5,0xdb180419,0xb87800c7,0xfbd800cc}},	//   _dpor, _pivá, yaír, _দিশত, 
   {{0x7c218ca5,0x6fd000cc,0x00000000,0x00000000}},	//   _epor, _সিয়ে, --, --, 
   {{0x63600793,0x65640332,0xb8780022,0x00000000}},	//   _vöni, xkih, vaír, --, 
   {{0x69c400af,0xb4d801c3,0x8c458ca6,0x6aa18ca7}},	//   _viie, _cnàm, _хеле, _wynf, 
   {{0x69c40036,0x6360c2f8,0xb87800c7,0xa3c00118}},	//   _wiie, _töni, taír, ँदछ_, 
   {{0x69c401ee,0x02a85536,0x36642143,0x656401f4}},	//   _tiie, _करेन, паро_, tkih, 
   {{0x44218ca8,0x65640270,0xb8780077,0x60c46e53}},	//   _ppk_, ukih, mbín, žimi, 
   {{0x07f81564,0x0288678d,0x25e81524,0x00000000}},	// [29c60] _اربع_, әйек_, _जबकी_, --, 
   {{0x44218ca9,0xfbcc8bb5,0x65658caa,0xc2b40063}},	//   _vpk_, _हंसम, skih, пљењ, 
   {{0xb6a11804,0x00000000,0x00000000,0x00000000}},	//   éâtr, --, --, --, 
   {{0x442002b5,0xb878007b,0x00000000,0x00000000}},	//   _tpk_, ibín, --, --, 
   {{0x9f3402dd,0x44218cab,0xd3f802dd,0x2484000d}},	//   делі, _upk_, _мэрі_, _ämm_, 
   {{0xb3e40003,0x00000000,0x00000000,0x00000000}},	//   _སྦྲུ, --, --, --, 
   {{0x45281b4b,0xc0e4074d,0xb8780124,0xdd9001d3}},	//   _སྒོར_, _новк, haíp, پڈا_, 
   {{0xd24c168d,0x3f90020c,0x00000000,0x00000000}},	//   _خۆم_, éyub_, --, --, 
   {{0xaec000fd,0x00000000,0x00000000,0x00000000}},	//   мбәл, --, --, --, 
   {{0x7e540276,0x3ea40124,0xfbd001d9,0x00000000}},	//   _нтец, _еизг, ٘تھ_, --, 
   {{0x44c0016b,0xb4d801c3,0xbea86ea9,0x05bc0b6d}},	//   hɔ_, _snàm, _اهان_, ्दाब, 
   {{0x7c20b745,0x7f58014f,0x44c00134,0xae6800db}},	//   _tpor, _hotq, kɔ_, _اشكە_, 
   {{0x7c218cac,0x45280ed9,0x6c14aaab,0xbb440395}},	//   _upor, _སྒེར_, _فتوح_, _недк, 
   {{0x68e02ed0,0xdce00270,0x7f580455,0x3dc4062c}},	//   ımda, kimī, _jotq, _hiow_, 
   {{0x35684afa,0x3a3801ed,0x7f580455,0x00000000}},	//   бран_, _épp_, _motq, --, 
   {{0x63600254,0x333c06be,0xe9a400d8,0xddd400b8}},	//   _mönu, _şux_, _пајп, _śaśk, 
   {{0x3dc408e7,0x644008a5,0x00000000,0x00000000}},	// [29c70] _miow_, _ámil, --, --, 
   {{0x3dc405b1,0x7f580477,0x00000000,0x00000000}},	//   _liow_, _notq, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x44c0013b,0x795c00e8,0x00000000,0x00000000}},	//   bɔ_, _tëwu, --, --, 
   {{0x7f598cad,0x50b80b28,0xdb18005b,0xfe6c00f2}},	//   _botq, زگرد_, _kivä, یگم_, 
   {{0x636002d2,0xdee00023,0x00000000,0x00000000}},	//   _bönu, _ዓድኻ_, --, --, 
   {{0x3dc4013f,0xa29400d4,0x00000000,0x00000000}},	//   _biow_, _зарі, --, --, 
   {{0x6360014a,0xc210011a,0x9abc0135,0xb8780022}},	//   _dönu, _שהן_, peċj, yaíp, 
   {{0xd6c409bd,0xc9880150,0x00000000,0x00000000}},	//   ্রিয, _داﻟﺪ, --, --, 
   {{0x7f598cae,0x7c8c001f,0xb87800e4,0x3b802b95}},	//   _gotq, ቅላላው_, vaíp, клыг, 
   {{0x6e658caf,0x63618cb0,0x1fd80154,0xd9b00116}},	//   _этаж, _gönu, _সিএস, گەيد, 
   {{0x39580129,0x63600108,0x9da8030d,0xd6c400eb}},	//   _coqs_, _hönt, _еъча_, ্রায, 
   {{0x02a81889,0xd71c0201,0xc0dc02d3,0x7f5801b9}},	//   _कर्न, _ስምምነ, _ዓቕሊ_, _yotq, 
   {{0x48dc01ad,0x2d9c0129,0x636001f4,0xb87800c7}},	//   _क्रो_, loue_, _yönu, raíp, 
   {{0x45280135,0xb6a07a22,0x44c0013f,0x3dc40363}},	//   _སྒུར_, вирл, wɔ_, _yiow_, 
   {{0xdb180664,0x44c0016b,0x2d9c40e8,0x05a8109a}},	//   _eivä, tɔ_, noue_, івай_, 
   {{0xfc481f60,0x35a18cb1,0xdb0801ef,0x00000000}},	// [29c80] mtíð_, татг, _šlép, --, 
   {{0x2d9d8cb2,0xe7b40372,0x7410591c,0xfc480ad9}},	//   houe_, _سۅزد, ئولا, ltíð_, 
   {{0x44c0016b,0x2d9d8cb3,0x26d80010,0xb9903b93}},	//   sɔ_, koue_, mcro_, _سلیب, 
   {{0xfc480579,0x26d98cb4,0x7680022e,0x7f58e236}},	//   ntíð_, lcro_, _dеyd, _sotq, 
   {{0x25a00366,0x2d9cad72,0xa3c8012d,0x00000000}},	//   moil_, doue_, _ऊंट_, --, 
   {{0x26d98cb5,0x3dc405b1,0x795c0694,0x25a0062c}},	//   ncro_, _siow_, _jëwr, loil_, 
   {{0x636000dd,0xd12c00cf,0x00000000,0x00000000}},	//   _dönt, _گۅن_, --, --, 
   {{0x25a00363,0x2d9c030a,0xc0dc0023,0xb87808a5}},	//   noil_, goue_, _ዓቕሉ_, fbíl, 
   {{0x7f5800fd,0xd12d8cb6,0x25a000ad,0x5bc81408}},	//   _totq, _دۅن_, ioil_, रदेव, 
   {{0xd6c40c58,0x25a01368,0x7f5802d0,0x6360002f}},	//   ্ৰিয, hoil_, _uotq, _tönu, 
   {{0x25a18cb7,0xdb18ce29,0x2d9c0660,0x63600267}},	//   koil_, _nivå, boue_, _höns, 
   {{0x2d9c7d4f,0x636001e6,0x25a00076,0xbc641fbe}},	//   coue_, _köns, joil_, _овек, 
   {{0x63618cb8,0x3f8c026c,0xa3c00f4a,0xec118cb9}},	//   _yönt, onfu_, ुदा_, _لوند, 
   {{0x6360049f,0x25a00363,0x1b1c0154,0x9b9400ec}},	//   _möns, eoil_, _ভোরে_, _ڪلڪت, 
   {{0x25a00076,0x3f8c0204,0x636001e6,0x00000000}},	//   foil_, infu_, _löns, --, 
   {{0x26d8003a,0x63600267,0x25a008c2,0xca740139}},	//   acro_, _oöns, goil_, _яучы, 
   {{0x798c00f1,0xb9fc001f,0x93b40063,0x9abc0003}},	// [29c90] mncw, _ቀረ_, ебац, deċi, 
   {{0x25a00363,0xdbe400e8,0x2d9c030a,0x3398007b}},	//   aoil_, gééy, zoue_, آخرة_, 
   {{0xeff802d3,0x36a00075,0x25a06af6,0xb14400f2}},	//   _ሊብያ_, _شەرق, boil_, ویسم_, 
   {{0x0f3403e6,0x25a18cba,0x6360007c,0xd0d402e8}},	//   ککرد, coil_, _böns, ходъ, 
   {{0x2d9c083a,0x6360d7af,0xb1100521,0xa3c830fd}},	//   voue_, _pönt, hụgh, _ऊंच_, 
   {{0x63618cbb,0x00000000,0x00000000,0x00000000}},	//   _döns, --, --, --, 
   {{0x3ea0006c,0xbea18cbc,0x2d9c007f,0x6360032e}},	//   лишг, лашк, toue_, _vönt, 
   {{0x636004f3,0x3ddc02fa,0x3050004b,0x317c0205}},	//   _föns, _dttw_, _لږتر, _umuz_, 
   {{0x2d9c0660,0xb4d801c3,0x636001e3,0xfc480162}},	//   roue_, _cnài, _tönt, vtíð_, 
   {{0xdbdc2242,0x798c004b,0x6e64399f,0x09e400cf}},	//   ráðh, encw, _отеж, ноон, 
   {{0x25a0062c,0xfc4803b2,0x9e140024,0xdb1003b2}},	//   yoil_, ttíð_, _адхі, ðfán, 
   {{0x25a005b1,0x636001f4,0x00000000,0x00000000}},	//   xoil_, _yöns, --, --, 
   {{0xc7940a8f,0xfc48041e,0x26cc01f1,0x1cc8031c}},	//   ервы, rtíð_, ždom_, _ཉུག_, 
   {{0xfc480bcd,0x00000000,0x00000000,0x00000000}},	//   stíð_, --, --, --, 
   {{0x26d804fb,0x25a07675,0x06640150,0x07a46b21}},	//   rcro_, toil_, راسپ, _җанн, 
   {{0x6d4806a3,0x35a005f5,0x3b500124,0x25a00076}},	//   _jnga, гасг, _акәр, uoil_, 
   {{0x6d4861b5,0x290019a2,0x2fdc0070,0x25a18cbd}},	// [29ca0] _mnga, _idia_, _ntug_, roil_, 
   {{0x25a18cbe,0x27e002d5,0x63600108,0xdb0803b2}},	//   soil_, _itin_, _röns, umdø, 
   {{0x6d498cbf,0x09040729,0x2fdc0270,0x25a00129}},	//   _onga, ষ্ণু_, _atug_, poil_, 
   {{0x6d498cc0,0xdef002d3,0x41b5265f,0x0708009f}},	//   _nnga, _ግዚኡ_, رمشر, _بيگي_, 
   {{0x27e00076,0x9abc0327,0xa03400d1,0x00000000}},	//   _jtin_, reċi, ئىتت, --, 
   {{0xdb18003a,0x673c002d,0x2fdc00ae,0xdd040790}},	//   _divû, ndrj, _dtug_, _ısıs, 
   {{0x1cc81b4b,0x29018cc1,0x661c00fb,0x6d4801ab}},	//   _ཉུང_, _odia_, ntrk, _bnga, 
   {{0x29018cc2,0x6da01b6b,0x5bc81bd6,0x44300034}},	//   _ndia_, лија, रद्व, owy_, 
   {{0x6d483223,0x27e01c06,0x443000a9,0xb1100521}},	//   _dnga, _ntin_, nwy_, wụgh, 
   {{0x29018cc3,0x6d498cc4,0x60c40fcf,0xb11001f2}},	//   _adia_, _enga, žims, tụgh, 
   {{0x27e18cc5,0x7e9810ef,0xfa881b16,0x6d480270}},	//   _atin_, _عنصر_, ясий_, _fnga, 
   {{0xfe440117,0x44300210,0x00000000,0x00000000}},	//   _онҷо, kwy_, --, --, 
   {{0x27e003a2,0xb8798cc6,0xf77000ec,0x57340023}},	//   _ctin_, mbík, هاس_, _ብምፍራ, 
   {{0x44300cfd,0x29018cc7,0xb11001f2,0xec34011a}},	//   dwy_, _edia_, pụgh, _נאור_, 
   {{0x79a42c71,0x44304baa,0xb8d4015b,0x27e18cc8}},	//   _прие, ewy_, _জল_, _etin_, 
   {{0xe5340c98,0x7bc81099,0x88800344,0x00000000}},	//   лесь, _hifu, ایین, --, 
   {{0x7bc98cc9,0x44313cc3,0xb8780306,0x00000000}},	// [29cb0] _kifu, gwy_, zbíj, --, 
   {{0x7bc80451,0x00000000,0x00000000,0x00000000}},	//   _jifu, --, --, --, 
   {{0x7bc98cca,0x61fc0cf4,0x2fdc01a4,0x320801c0}},	//   _mifu, _cvrl, _stug_, яхан_, 
   {{0x7bc80085,0xb4d800cf,0x6a6801b8,0xe0d147c8}},	//   _lifu, _anàv, löfö, مزه_, 
   {{0x6d4803a2,0x7bdc02b5,0xf4858ccb,0x44300042}},	//   _rnga, _ōpun, _чунн, cwy_, 
   {{0x7bc98ccc,0x6d4806a3,0x6a6801b8,0x00000000}},	//   _nifu, _snga, nöfö, --, 
   {{0x6d4881be,0x00000000,0x00000000,0x00000000}},	//   _pnga, --, --, --, 
   {{0x7bc8006f,0x0c240e46,0xdea4b1d2,0x3f74012d}},	//   _aifu, вмин, دیمی, słup_, 
   {{0x7bc9211c,0x6d485a90,0x00000000,0x00000000}},	//   _bifu, _vnga, --, --, 
   {{0x7bc98ccd,0x4a444834,0x29000009,0x8c640166}},	//   _cifu, внов, _sdia_, етүд, 
   {{0x27e00a40,0x6d480270,0x4a741411,0x48e40006}},	//   _stin_, _tnga, тыпт, конв, 
   {{0x6d498cce,0x5c70052f,0x4430033f,0xdc7000c7}},	//   _unga, рһәт, ywy_, рҳәы, 
   {{0x6a6801b8,0x7bc80ca8,0x27e001a9,0x00000000}},	//   föfö, _fifu, _qtin_, --, 
   {{0x7bc848d8,0xf8bc0548,0x37e0039b,0x00000000}},	//   _gifu, ndéy_, рорг, --, 
   {{0xf8c401d3,0x00000000,0x00000000,0x00000000}},	//   éért_, --, --, --, 
   {{0x7bc98ccf,0x27e0022f,0x44300034,0x29018cd0}},	//   _zifu, _ttin_, twy_, _udia_, 
   {{0xf770781d,0xc2f40729,0x7bc8015c,0xc794a17f}},	// [29cc0] _چاپ_, _চাবি_, _yifu, _арны, 
   {{0x44301cf9,0x7bc806e4,0xf770179e,0xb87801ef}},	//   rwy_, _xifu, _ناپ_, dbíh, 
   {{0xc1d00184,0x00000000,0x00000000,0x00000000}},	//   рөгә, --, --, --, 
   {{0x36342586,0xb1400166,0xcfc80150,0x408400db}},	//   _شرپس, инхл, _ﺨﺎﺭﻗ, кулб, 
   {{0x6b800b6f,0xdfd043b5,0x52740022,0xded00092}},	//   _omng, حيت_, _ҩусу, _ብሩክ_, 
   {{0x420822cb,0x00000000,0x00000000,0x00000000}},	//   _онго_, --, --, --, 
   {{0x7bc98cd1,0xb9c80020,0x00000000,0x00000000}},	//   _rifu, _ሰፊ_, --, --, 
   {{0x7bc82935,0x6b818cd2,0x9d180588,0x2a600092}},	//   _sifu, _amng, хоит_, ሌክትሮ, 
   {{0xbfc58cd3,0xbff001c0,0x71180375,0xed4c01d9}},	//   _абак, _түлш, _קומפ, تھٕ_, 
   {{0x30380014,0x7bc80200,0x3ce00401,0x00000000}},	//   _تتِک_, _qifu, _ट्रे_, --, 
   {{0x7bc80451,0x2b10ec40,0x8f74003b,0x00000000}},	//   _vifu, _दारु_, _суті, --, 
   {{0xfce41bc4,0x6b800163,0x7bc801b2,0xace4b34e}},	//   _родо, _emng, _wifu, _амца_, 
   {{0xc0dc044e,0x7bc98cd4,0x7d018cd5,0xb4d800a3}},	//   _ዓቕሚ_, _tifu, _idos, _mnàt, 
   {{0xb8c800bc,0x779000f2,0xba444c91,0x00000000}},	//   _औँ_, شیجا, _ахий, --, 
   {{0xeaac10fe,0xe6649951,0x487001d5,0x7d00013a}},	//   _وعى_, атто, لگیس, _kdos, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7d0001f7,0xb1100521,0x7680022e,0xf8bc2a78}},	// [29cd0] _mdos, hụch, _dеya, ffée_, 
   {{0x7d00036b,0xe374026f,0x12d00154,0x32640108}},	//   _ldos, алуы, ির্দ, ктев, 
   {{0x7d0001a2,0xe1f001d5,0x00000000,0x00000000}},	//   _odos, قسن_, --, --, 
   {{0x7d018cd6,0xdb1806ea,0xe4e402bf,0x00000000}},	//   _ndos, _eivø, _вірн, --, 
   {{0xe0d001f7,0x00000000,0x00000000,0x00000000}},	//   ززن_, --, --, --, 
   {{0x7d018cd7,0x69c800bc,0x069401ec,0xdce8002b}},	//   _ados, íjez, _جاۋھ, _ālāp, 
   {{0x4e298cd8,0xe3b003e6,0x31c400c0,0x02b4014b}},	//   хойн_, _گرێ_, _асав, _бирӯ, 
   {{0x229400d6,0xb4d80e89,0xc0dc02d3,0x00000000}},	//   _тися, _gnàt, _ዓቕሙ_, --, 
   {{0x7d000368,0xcfdc03d4,0xe3b00133,0xa18401af}},	//   _ddos, _ঠিকন, _درێ_, _тырл, 
   {{0x7d018cd9,0x1fb820b0,0x8c2400cc,0x00000000}},	//   _edos, _алуы_, বিলন_, --, 
   {{0x644000e4,0xdef80150,0x00000000,0x00000000}},	//   _ámiv, _шыт_, --, --, 
   {{0xf3fc0589,0xf53c01bf,0xac100354,0x00000000}},	//   _ovã_, _skån_, _кĕме_, --, 
   {{0xc3180eac,0xb4d80241,0xbce001e0,0x6d598cda}},	//   ড়তি_, _maàd, _уҡыһ, mjua, 
   {{0x6b80136f,0x59b421cb,0x00000000,0x00000000}},	//   _umng, лөөс, --, --, 
   {{0xfcc400c7,0x00000000,0x00000000,0x00000000}},	//   _ишәҟ, --, --, --, 
   {{0x6d5815a5,0xccf800dc,0xa9280122,0xdee00023}},	//   njua, naś_, _drží, _ዓድን_, 
   {{0x03258cdb,0xc3242692,0x6d580194,0xd4f4010b}},	// [29ce0] лдан, лмак, ijua, рясы, 
   {{0xb4d801c3,0xc2980276,0x7410007b,0xdb1000e5}},	//   _snàt, нтец_, صوما, őföl, 
   {{0xccf87e2a,0x3f90002e,0x00000000,0x00000000}},	//   kaś_, éyum_, --, --, 
   {{0xba04044e,0x320401ed,0x6d58013c,0x00000000}},	//   _ገዛ_, ánya_, jjua, --, 
   {{0x6d598cdc,0xdef4d4aa,0xb1100521,0xbfa80c75}},	//   djua, аплы, wụch, нтке_, 
   {{0xb8780332,0xdce80139,0x00000000,0x00000000}},	//   scíg, _ılıq, --, --, 
   {{0x64458cdd,0x615400ec,0x00000000,0x00000000}},	//   lvii, _پچائ, --, --, 
   {{0x42080aa5,0x6d5802d3,0x64440421,0x629c031c}},	//   _онҳо_, gjua, ovii, _ixro, 
   {{0xb7dc2158,0x64443ed2,0xec64013d,0x00000000}},	//   _ভট্ট, nvii, грэк_, --, 
   {{0xa0a58cde,0xf060026a,0xcf2406f6,0x6d580869}},	//   _бағд, _укуп, _نرمي, ajua, 
   {{0xac7000f2,0x64440108,0xdb1401e1,0x2bb4007b}},	//   لایش, hvii, _ìbíd, داية_, 
   {{0x64458cdf,0x7d018ce0,0x8e758ce1,0xccf8002b}},	//   kvii, _udos, _тууч, caś_, 
   {{0x7ac40220,0x7e680af9,0x63bc01ef,0xa3b41fe7}},	//   _өске, lyfp, _ohrn, ञता_, 
   {{0x28e40075,0x64440194,0xe7845192,0x00000000}},	//   _ﺋﯩﺸﻠ, dvii, бусо, --, 
   {{0x7af98ce2,0xf3640046,0xf3fc0589,0xaad80375}},	//   matt, қтан, _svã_, _אחור, 
   {{0x7af98ce3,0xb4d8004e,0xdb080332,0x630c00eb}},	//   latt, _anàr, ildí, স্ময়_, 
   {{0x64458cdf,0x7af8011c,0x629c022e,0xa84801f7}},	// [29cf0] gvii, oatt, _axro, _مليم_, 
   {{0x7af98ce4,0x00000000,0x00000000,0x00000000}},	//   natt, --, --, --, 
   {{0x64440af5,0x7af820ac,0xccf80882,0x64400171}},	//   avii, iatt, yaś_, _šmit, 
   {{0x865808a8,0x6444000d,0x63bc3b22,0x00000000}},	//   _סדרי, bvii, _ehrn, --, 
   {{0x6444003a,0x35d8000d,0xded00023,0x00000000}},	//   cvii, _मंड़, _ብሩኽ_, --, 
   {{0x6d440029,0x7af98ce5,0x63bc01ab,0xa2e4009d}},	//   ējam, jatt, _ghrn, _гоёд, 
   {{0xf53c0589,0xccf80882,0xb8780077,0x30e402dd}},	//   _kaå_, taś_, ncíb, _бізб, 
   {{0x4d649caa,0x6d580140,0x63bc00d0,0xefd0001f}},	//   ркив, ujua, _zhrn, ረሻው_, 
   {{0x6d5850f9,0xf53c0004,0xccf800dc,0x7eb40032}},	//   rjua, _maå_, raś_, лгәс_, 
   {{0x7af98ce6,0x4fc13b7b,0x3330002d,0x8b680120}},	//   gatt, _بەتە, nexx_, тиов_, 
   {{0x644405b8,0xd5b402a0,0x491800af,0x6d580240}},	//   zvii, ंताज, _भादो_, pjua, 
   {{0x5c74052f,0x7af8360c,0x5ef00ca8,0x64440108}},	//   рҙәр_, aatt, _iṣẹl, yvii, 
   {{0x64458ce7,0x5da40014,0x290c47af,0x9b9405d9}},	//   xvii, _امنٕ, ğda_, _گهوڙ, 
   {{0x7af98ce8,0x290d17cf,0xdee002d3,0x64458ce9}},	//   catt, şda_, _ዓድና_, vvii, 
   {{0x3330855d,0x00000000,0x00000000,0x00000000}},	//   dexx_, --, --, --, 
   {{0xc4e42db7,0x63bc00bc,0x6444000d,0x36a00137}},	//   ржай, _shrn, tvii, تەپق, 
   {{0x64440194,0x15b80417,0x1b1c00eb,0x00000000}},	// [29d00] uvii, уыры_, _ভোটে_, --, 
   {{0x64458cea,0x00000000,0x00000000,0x00000000}},	//   rvii, --, --, --, 
   {{0x644425e4,0x42540261,0xefd00023,0x86981d39}},	//   svii, штат, ረኻዊ_, _штит_, 
   {{0xb878215a,0x7af801d3,0xe3f800db,0xd4d40153}},	//   rbív, zatt, _مۉرت_, _гірэ, 
   {{0x64440d04,0x7af98ceb,0x15b00150,0x2fd46ea9}},	//   qvii, yatt, _رەكس, لوند_, 
   {{0x1fb8a7d2,0x7af80227,0xb87867ed,0x26cd4555}},	//   ыллы_, xatt, mbít, ždou_, 
   {{0xdef400fb,0x00000000,0x00000000,0x00000000}},	//   апһы, --, --, --, 
   {{0x5d544170,0x7af98cec,0x2cad8ced,0xb238008f}},	//   скит, watt, _bygd_, _בעלז, 
   {{0x7af98cee,0xafe00184,0xb8780419,0x00000000}},	//   tatt, _мотл, nbít, --, 
   {{0x7b64d3bb,0x7ac45232,0x2cad1c6a,0x7af80113}},	//   ртие, исне, _dygd_, uatt, 
   {{0x7af98cef,0xfe70007b,0xb87800bc,0x00000000}},	//   ratt, _بدء_, kcíc, --, 
   {{0x7af98cf0,0x95d83769,0xf9698cf1,0xb87801ef}},	//   satt, ғдат_, трой_, jcíc, 
   {{0x7af80a28,0x8c2400fe,0xb8780118,0x00000000}},	//   patt, বিউন_, dcíc, --, 
   {{0x7af98cf2,0x7a840345,0xdb140ca8,0xf1bc0419}},	//   qatt, _پشتم, _ìbàd, ľšia_, 
   {{0xf1bc0030,0x00000000,0x00000000,0x00000000}},	//   žšia_, --, --, --, 
   {{0xdb18014a,0xb8780077,0x13a40133,0x00000000}},	//   _livü, rcíb, ڵۆزی_, --, 
   {{0x54b83c1b,0xa4d800f7,0xe4a403de,0xa99c011a}},	// [29d10] угая_, рдуу_, орфо, _שבחר, 
   {{0xf53c0004,0xf728084c,0x69d001e1,0x00000000}},	//   _waå_, _рций_, _òdeò, --, 
   {{0xb878013a,0x00000000,0x00000000,0x00000000}},	//   bcíc, --, --, --, 
   {{0xb87801ed,0x333000b5,0xe2980212,0x00000000}},	//   bbít, sexx_, шає_, --, 
   {{0xb87800d2,0x50440261,0xdb1800d7,0xe01800d4}},	//   mbís, селб, _sivý, ижці_, 
   {{0x1fb80733,0x8eb800db,0x00000000,0x00000000}},	//   алчы_, лыйт_, --, --, 
   {{0xc3c001c0,0x21fc01ef,0x00000000,0x00000000}},	//   _хөтл, _váhá_, --, --, 
   {{0x4fd40139,0x00000000,0x00000000,0x00000000}},	//   _гжат, --, --, --, 
   {{0x9f7c01ef,0x00000000,0x00000000,0x00000000}},	//   _šňůř, --, --, --, 
   {{0xcdc58cf3,0xb8780118,0x00000000,0x00000000}},	//   шаққ, zcíc, --, --, 
   {{0x49c87ef2,0xb87802f0,0x00000000,0x00000000}},	//   ллон_, ycíc, --, --, 
   {{0x693401b9,0x00000000,0x00000000,0x00000000}},	//   زکبر, --, --, --, 
   {{0xc198008f,0xfcd0001f,0xb87800bc,0x00000000}},	//   רשרי, ረጋጋ_, vcíc, --, 
   {{0x77758cf4,0xdb180798,0x660828d1,0x49182314}},	//   _clxx, _divó, ádko, _भावो_, 
   {{0x261834ef,0x7774003a,0x8bf8015b,0xb8780118}},	//   बंधी_, _dlxx, _আমিন_, tcíc, 
   {{0xb8780118,0x00000000,0x00000000,0x00000000}},	//   ucíc, --, --, --, 
   {{0xb8798cf5,0x68e58cf6,0x6720000d,0x00000000}},	// [29d20] rcíc, _ifid, _बापक_, --, 
   {{0x261803f3,0x263800e8,0x456001d9,0xb87801ef}},	//   बंदी_, _tōo_, _کھسہ, scíc, 
   {{0x86c40811,0xcea400ec,0xb878072d,0x00000000}},	//   _ديدن, _آڙ_, sbít, --, 
   {{0xdee002d3,0xb8780077,0x25743e52,0x00000000}},	//   _ናትካ_, lcía, _بۇرس, --, 
   {{0x68e400ec,0xf9900115,0x00000000,0x00000000}},	//   _mfid, הרא_, --, --, 
   {{0xb8782b76,0x44200009,0xe3b802dd,0xb7d8010f}},	//   ncía, _iqk_, _тұз_, אקסי, 
   {{0x41b4034c,0xcf240c8b,0xdb1805d5,0x24800023}},	//   _همسر, ترني, _vivü, lzim_, 
   {{0xdb18067c,0xef146cf7,0x68e401e1,0xf1c800cf}},	//   _nivò, амә_, _nfid, _ماقۇ_, 
   {{0x24818cf7,0x26180c2e,0x6fb001d9,0x5c3401d5}},	//   nzim_, बूती_, _کملا, تکاز, 
   {{0x4f640491,0x68e58cf8,0x00000000,0x00000000}},	//   _والف, _afid, --, --, 
   {{0x1958fe8d,0x999803b7,0x3f8c009f,0x1a6407d6}},	//   ааны_, икот_, mifu_, تیغی_, 
   {{0x3f8d4880,0x24807547,0xfd100150,0xeb9400fd}},	//   lifu_, kzim_, _ءجا_, _һич_, 
   {{0xdb18359e,0x274801d3,0x44200051,0x00000000}},	//   _divò, zínű_, _nqk_, --, 
   {{0x3f8d4880,0x68e4013f,0x2480012c,0xeb942bbd}},	//   nifu_, _efid, dzim_, _лич_, 
   {{0xb9e410e0,0x68e4015d,0xcaa001ec,0xaa9000d8}},	//   _استى, _ffid, _ﺎﮭﺗﺪ_, _нишч, 
   {{0xc5ec00aa,0xdb0802d3,0xdb1805d5,0x3f8c01f7}},	//   کړی_, kodë, _givò, hifu_, 
   {{0xdd1c0122,0x798c127b,0x3f8d8cf9,0x24580108}},	// [29d30] kážk, micw, kifu_, бать_, 
   {{0x63618cfa,0x6d44005f,0x14c42894,0xe2f801ec}},	//   _köny, ējai, लेषण, йеуі_, 
   {{0xd25000c6,0x3f8c009f,0xd9f801ad,0x200400c0}},	//   بنا_, difu_, ंठित_, _avmi_, 
   {{0x7c2003b4,0x798c127b,0x3cf0012d,0x00000000}},	//   _oqor, nicw, घरों_, --, 
   {{0x3f8c01c8,0x29c800a2,0x00000000,0x00000000}},	//   fifu_, _ỳaka_, --, --, 
   {{0x3f8c00ca,0x798c03ac,0x00000000,0x00000000}},	//   gifu_, hicw, --, --, 
   {{0xdb180232,0x798c01b2,0x7c200194,0xdb080ba1}},	//   _chví, kicw, _aqor, modè, 
   {{0xcfe8221d,0x44200175,0x6c600124,0x00000000}},	//   _نفره_, _yqk_, зеиҕ, --, 
   {{0x0b580598,0x3f8c0451,0x5f7400aa,0xcc898cfb}},	//   арны_, bifu_, _ډالر, شنده_, 
   {{0x68e58cfc,0xb87800e5,0xbe1000db,0x00000000}},	//   _sfid, ybír, سوۋع, --, 
   {{0x68e40099,0x798c5e05,0x00000000,0x00000000}},	//   _pfid, ficw, --, --, 
   {{0x13e03fae,0x63600598,0x798c03ac,0xbd8401c8}},	//   মীয়, _döny, gicw, _وچين_, 
   {{0xdb080100,0x00000000,0x00000000,0x00000000}},	//   kodè, --, --, --, 
   {{0x257c00c6,0x81e8015b,0x00000000,0x00000000}},	//   _míle_, _মিস_, --, --, 
   {{0xb87804d4,0x798d8cfd,0x257c0248,0xe6b401d5}},	//   rcía, bicw, _líle_, سلرگ, 
   {{0x68e58cfe,0x3f8c0083,0x290c0024,0x00000000}},	//   _ufid, zifu_, ėdas_, --, 
   {{0xa4944a23,0x3f8c009a,0x5ea824ae,0xb878634d}},	// [29d40] سیست, yifu_, ﺷﻘﯘﺭ, sbír, 
   {{0xb7d42580,0xb87800e4,0xc2b40063,0x257c08a5}},	//   _گویا_, mbíp, ољењ, _síld_, 
   {{0x05298cff,0x021800d4,0x00000000,0x00000000}},	//   _конк_, різь_, --, --, 
   {{0x01a80372,0x66e001e1,0x41282db7,0xdb080240}},	//   шкек_, _fàkó, родо_, todë, 
   {{0x3f8d8d00,0xaaa805f9,0x46dc0490,0x257c00bc}},	//   tifu_, _घुसक, _मलाह, _cíle_, 
   {{0x7050ad99,0xdb0835f5,0xb87802fb,0x798d8d01}},	//   بنها, codè, kcín, zicw, 
   {{0x3f8d8d02,0x798d0d18,0xdd1c0122,0x6e900035}},	//   rifu_, yicw, rážk, ولها, 
   {{0x3f8d8d03,0xdb08bda7,0x798c9da5,0x66e001e1}},	//   sifu_, modé, xicw, _yàkó, 
   {{0xdd1c022a,0x00000000,0x00000000,0x00000000}},	//   pážk, --, --, --, 
   {{0x798c0223,0xb4d801e1,0xb60000d0,0x7b6401ec}},	//   wicw, _naàn, žšie, ітпе, 
   {{0x798c0c8c,0xdb080129,0x63600139,0xbf1000fb}},	//   ticw, nodé, _qöny, _еүҙә, 
   {{0xed558d04,0x6e9001d5,0x00000000,0x00000000}},	//   _мох_, _تلما, --, --, 
   {{0x798d8d05,0xcce400aa,0x7c20058a,0x28680107}},	//   ricw, _رسني, _uqor, орро_, 
   {{0x798c00aa,0x63600724,0x290405f7,0xb7b80798}},	//   sicw, _töny, ómar_, rtão, 
   {{0xb7b80120,0x555800a7,0x768001d5,0x798c0857}},	//   stão, бавя_, _kеyi, picw, 
   {{0x4cc02baf,0x5ea80131,0x00000000,0x00000000}},	//   _ষ্টু, ﺷﺘﯘﺭ, --, --, 
   {{0x93798d06,0xd3740063,0x00000000,0x00000000}},	// [29d50] ббат_, плаћ, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x67d40227,0xdb080066,0x257d8d07,0xe0d00133}},	//   _uńja, rodè, _síle_, ۆزه_, 
   {{0xdb098d08,0xf8bc01d3,0x00000000,0x00000000}},	//   lldä, yfél_, --, --, 
   {{0xe0d025f4,0x00000000,0x00000000,0x00000000}},	//   نزه_, --, --, --, 
   {{0xa5d80214,0x0dc80131,0xb3900066,0x00000000}},	//   _دبیر_, әлий_, _غیاث, --, 
   {{0xd4780116,0x090400eb,0x00000000,0x00000000}},	//   _тәңш_, ষ্টু_, --, --, 
   {{0xe13402dd,0xa69c0115,0x00000000,0x00000000}},	//   _онсы, ישופ, --, --, 
   {{0xd0111f54,0x76804831,0x00000000,0x00000000}},	//   _سلا_, _dеyi, --, --, 
   {{0x3b80e44f,0xca8406d4,0x672007f7,0x2d7c0210}},	//   ельг, згой, _बाधक_, dłeś_, 
   {{0x89a98d09,0x752d8d0a,0xaa5c02d3,0xf8bc01d3}},	//   йков_, _obcz, _ፈደራላ, sfél_, 
   {{0xaca002e3,0xdcf800f7,0xb879014e,0x8934007b}},	//   _ahụk, _ۇرۇش_, rcín, أعدا, 
   {{0xb8787e9b,0xdef80327,0x48b402e8,0x76400064}},	//   scín, _soċi_, ящот, _šnyp, 
   {{0x1cb813f9,0xa2cc01ad,0xb8780332,0x00000000}},	//   _بامب_, थेड्, pcín, --, 
   {{0x2d7c033f,0x28ac0b4c,0x00000000,0x00000000}},	//   ałeś_, _टुरि, --, --, 
   {{0x6124007f,0xa2cc00dc,0xd6c40022,0x00000000}},	//   _kōlō, _थृष्, фисқ, --, 
   {{0x69c58d0b,0xb878021c,0x00000000,0x00000000}},	// [29d60] _ihie, ncíl, --, --, 
   {{0xdb098d0c,0x273400cf,0x090400e5,0x00000000}},	//   todé, _تۉسس, _بڑھی_, --, 
   {{0x69c401fb,0x00000000,0x00000000,0x00000000}},	//   _khie, --, --, --, 
   {{0xa3e406ab,0xe7c00490,0xdb080129,0xc0dc0023}},	//   _पंप_, _शीतप, rodé, _ናሕሲ_, 
   {{0x26180c2e,0x65658d0d,0x69c4031c,0x7c2c033f}},	//   बूरी_, mjih, _mhie, łbrz, 
   {{0x69c402a4,0xc2f400fe,0xbbb800bc,0x7f18187f}},	//   _lhie, _চাকি_, _उठेक, сіду_, 
   {{0x69c4009d,0x2d7c033f,0xe81c00cd,0x00000000}},	//   _ohie, złeś_, भूता_, --, 
   {{0x69c40016,0x6564036e,0xfd10007b,0x2d7c012d}},	//   _nhie, njih, رجع_, yłeś_, 
   {{0xfba98d0e,0x00000000,0x00000000,0x00000000}},	//   йтой_, --, --, --, 
   {{0x69c400b0,0x30780375,0x0b44010a,0x00000000}},	//   _ahie, _האמנ, çнин, --, 
   {{0xcf243ed4,0x69c50b3a,0xdb180122,0xf8bc02fb}},	//   _ترقي, _bhie, _chvá, rfém_, 
   {{0x69c56a1c,0x320401ed,0xeb3005a9,0x7c841214}},	//   _chie, ányi_, _ۋىند, _нуле, 
   {{0x69c400ad,0x6564020c,0x8d84036b,0x64480100}},	//   _dhie, djih, _تشلن, _ņdin, 
   {{0xb87800c6,0xded00092,0x00000000,0x00000000}},	//   scío, _ብሩን_, --, --, 
   {{0x69c40327,0x56940117,0x00000000,0x00000000}},	//   _fhie, фавт, --, --, 
   {{0x69c58d0f,0x42a402d3,0xddd401ec,0xb87800e5}},	//   _ghie, ላዉነት_, _ﺟﺎﺯﺑ, lcím, 
   {{0x24580b32,0x2bdc098a,0x24f80006,0xfd480142}},	// [29d70] пать_, नदया, янты_, fflẅ, 
   {{0xa87c0302,0x00bc0ed1,0xf2c40a3b,0x00000000}},	//   _לאחר, ﺭﻩﺗﺘ, псен, --, 
   {{0x3204066d,0xe3b0007b,0x657800c7,0x00000000}},	//   ény_, ارق_, ñahá, --, 
   {{0x752c0589,0xe2c800aa,0xa18400fd,0x69c40003}},	//   _ubcz, سونو_, нычл, _xhie, 
   {{0x3ddc01ab,0xd008084c,0xc0e00063,0x1b140154}},	//   _autw_, целе_, њошк, ত্যে_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x60c0009a,0xc33000c8,0x5ed00f22,0xe0d003cc}},	//   _ezmm, _שול_, _স্বে, نزۇ_, 
   {{0xdea4c56d,0x257c01e7,0x018001af,0x00000000}},	//   رینی, _kíla_, _иҫєп, --, 
   {{0x2d8002d5,0x69c400a9,0x7bdc02b5,0xb4d801ab}},	//   ėje_, _rhie, _ōpur, _raàl, 
   {{0xefdc02d3,0x69c4bbd2,0xb87957a0,0x257d8d10}},	//   _ናህዳ_, _shie, rcíl, _míla_, 
   {{0x69c58d11,0x9f05082e,0x8e998d12,0xc278008f}},	//   _phie, _سونو, _بناء_, ַרשי, 
   {{0x8c940816,0x00000000,0x00000000,0x00000000}},	//   _орлі, --, --, --, 
   {{0x8c44f9e0,0x2d8c0205,0x7ec002d2,0x7d74009a}},	//   _целе, _imge_, _típí, _زمور_, 
   {{0x6f018d13,0x69c40204,0x1b14015b,0x79e40150}},	//   nanc, _whie, ত্বে_, _ﺍﻟﯩﻤ, 
   {{0x2b440b6f,0x2fdc089c,0x69c58d14,0x45d4005b}},	//   _ianc_, _luug_, _thie, дцат, 
   {{0x2b440de4,0xdb080109,0x257c0008,0x00000000}},	//   _hanc_, hodì, _bíla_, --, 
   {{0x6564207a,0xf9c46112,0xdb1801b8,0x2fdc0009}},	// [29d80] rjih, _تحوی, _vivö, _nuug_, 
   {{0x2900143a,0x257c00bc,0xed600064,0x37e0030d}},	//   _heia_, _díla_, lužė_, _шоьг, 
   {{0x673c151d,0x29004774,0x2b458d15,0x6f018d16}},	//   merj, _keia_, _manc_, danc, 
   {{0x27e0426d,0x673d8d17,0x2fdc0014,0x6f00062c}},	//   _kuin_, lerj, _buug_, eanc, 
   {{0x29018d18,0x27e18d19,0x661d8d1a,0xaf3000d1}},	//   _meia_, _juin_, lurk, چرىت, 
   {{0x6f018d1b,0x29018d1c,0x673d8d1d,0x2d8c0198}},	//   ganc, _leia_, nerj, _amge_, 
   {{0xdb1805da,0x27e18d1e,0xa3e4000d,0x00000000}},	//   _mivô, _luin_, _पंड_, --, 
   {{0x2b4401ee,0x290018a6,0xf1cc0952,0x27e07afe}},	//   _aanc_, _neia_, _ﺑﺎﻳﻘ, _ouin_, 
   {{0x673c27ed,0x661d8d1f,0xb4d801e1,0x27e18d20}},	//   kerj, hurk, _baàj, _nuin_, 
   {{0xa0a4005e,0x290018a6,0x661d8d21,0x2b440de2}},	//   _жағд, _aeia_, kurk, _canc_, 
   {{0x2900026c,0x2b4401e4,0x7f58ffb6,0xcf24004b}},	//   _beia_, _danc_, _intq, _سرلي, 
   {{0x2b44014b,0x661d8d22,0x27e18d23,0x29014713}},	//   _eanc_, durk, _buin_, _ceia_, 
   {{0xdb082d86,0x290096da,0x3dc400b0,0x27e092eb}},	//   lodí, _deia_, _ihow_, _cuin_, 
   {{0x27e00c3a,0xe8e001fb,0x779001d3,0x661c0009}},	//   _duin_, _muội_, ئیدا, furk, 
   {{0x67d58d24,0x79a41b8c,0x29018d25,0x35698d26}},	//   тору, _орие, _feia_, оран_, 
   {{0x27e004cc,0x290007c5,0x257ce9f0,0xb7b800e4}},	//   _fuin_, _geia_, _píla_, kuãg, 
   {{0x673c193f,0x27e07dcc,0xdb0802fb,0x48c115bb}},	// [29d90] berj, _guin_, hodí, _бәра, 
   {{0x2fdc1dd0,0x61fc015d,0x257c0306,0x6f018d27}},	//   _ruug_, _bwrl, _víla_, xanc, 
   {{0x661c0e02,0x6f00db22,0xa3e41889,0x56958d28}},	//   curk, vanc, _पंथ_, _чант, 
   {{0x6f018d29,0xf99c033b,0xe4d40116,0x00000000}},	//   wanc, nnè_, رقەد, --, 
   {{0xd47800c8,0xe8e00208,0x00000000,0x00000000}},	//   _זאָל, _cuội_, --, --, 
   {{0xa3e406ab,0xf8bc0548,0x3dc490dc,0x61fc015d}},	//   _पंत_, rféh_, _ahow_, _fwrl, 
   {{0x2b4401ab,0x88d400b8,0xdb1401e1,0x00000000}},	//   _ranc_, _hṛtp, _ìbùd, --, 
   {{0x6f018d2a,0x3dc58d2b,0x2b441574,0x673c09a8}},	//   sanc, _chow_, _sanc_, zerj, 
   {{0x6f018d2c,0x3dc40050,0x661d8d2d,0x67200562}},	//   panc, _dhow_, zurk, _बालक_, 
   {{0x29018d2e,0x7ae803ac,0x6f018d2f,0x3dc58d30}},	//   _seia_, _cfft, qanc, _ehow_, 
   {{0x673d8d31,0x29018d32,0xc33000c8,0x27e00c3a}},	//   verj, _peia_, נוט_, _suin_, 
   {{0x27e00b4f,0x3dc40731,0xf99c068c,0xdd94035b}},	//   _puin_, _ghow_, gnè_, _иахы, 
   {{0x673d8d33,0x661c334b,0x27e18d34,0x2900b618}},	//   terj, wurk, _quin_, _veia_, 
   {{0x661d8d35,0xbb418d36,0x37a001ec,0xab600116}},	//   turk, _бешк, лқығ, _شۇجى, 
   {{0x29018d37,0xb6a00131,0x673c1753,0x857800d8}},	//   _teia_, гирл, rerj, псат_, 
   {{0x27e18d38,0x2d9d8d39,0x673c09a8,0xf53c0ac8}},	//   _tuin_, nnue_, serj, _skår_, 
   {{0x673c003d,0x2d9c00a3,0x00000000,0x00000000}},	// [29da0] perj, inue_, --, --, 
   {{0x317c020c,0x74114246,0x661c9331,0xb0600166}},	//   _aluz_, اولا, purk, _çäyx, 
   {{0x317cec0f,0x661c0113,0x06740395,0x00000000}},	//   _bluz_, qurk, _чупя, --, 
   {{0xc0e46eec,0xdb0802fb,0x80a400d1,0x00c80304}},	//   ходк, vodí, ىمان, плек_, 
   {{0xdd912371,0x26180034,0x25a18d3a,0x00000000}},	//   یوت_, बंकी_, mnil_, --, 
   {{0x2d9c0069,0x25a06185,0xdfd00451,0x64580882}},	//   enue_, lnil_, جيت_, āvid, 
   {{0x320401ed,0xa3e400c5,0x25a000c5,0x8eb010e0}},	//   ányt_, _पूत_, onil_, لەكت, 
   {{0x25a18d3b,0x5d540aa8,0xc10446bc,0x0164013e}},	//   nnil_, ткит, _سوئي, _якбо, 
   {{0x3dc40076,0x257c0ca8,0x7ae802d0,0x25a0000d}},	//   _vhow_, _lílo_, _pfft, inil_, 
   {{0xf8bc7c92,0x25a00219,0xafe001a9,0x9b580395}},	//   ngée_, hnil_, _софл, фиот_, 
   {{0x3dc58d3c,0x25a009a8,0x257c01e1,0xf99c033b}},	//   _thow_, knil_, _nílo_, tnè_, 
   {{0x25a002fb,0x9f04eb01,0x7ae80042,0x00000000}},	//   jnil_, _سوچو, _wfft, --, 
   {{0xec109132,0xdb080261,0x7a3400ac,0x25a00306}},	//   _موند, godã, _bütö, dnil_, 
   {{0x7d001368,0xf99c007f,0x5a34004e,0x25a18d3d}},	//   _heos, snè_, _анкт, enil_, 
   {{0xf67402ef,0xaa400a5b,0x00000000,0x00000000}},	//   راسخ, _бејл, --, --, 
   {{0xdb24025a,0x7d000109,0x25a009a8,0x6b600124}},	//   _âsâr, _jeos, gnil_, _акәа, 
   {{0x81dc00fe,0x00000000,0x00000000,0x00000000}},	// [29db0] _দৌল_, --, --, --, 
   {{0xded01e38,0x25a163b3,0xf8bc0de2,0x2c100073}},	//   ብርን_, anil_, ggée_, _दिसू_, 
   {{0x201802b5,0x25a00419,0x00000000,0x00000000}},	//   _āria_, bnil_, --, --, 
   {{0x7d0000ad,0x31c80a28,0xb40805f5,0x25a019d6}},	//   _neos, िषेध, _нэгж_, cnil_, 
   {{0x05b404fb,0xb0c8033f,0x504400cf,0xb6380150}},	//   _شگفت_, ़ेंग, телб, _ﺇﻋ_, 
   {{0x257c00d2,0x00000000,0x00000000,0x00000000}},	//   _yílo_, --, --, --, 
   {{0xb87801ed,0x61dc4466,0x7d018d3e,0xf1a412fa}},	//   gbíz, यदृष, _beos, _зран, 
   {{0xe8e00051,0xb14405af,0x00000000,0x00000000}},	//   _duới_, _سیتم_, --, --, 
   {{0x7d0000a8,0x98b8033b,0x2d9c0129,0x4fd400cf}},	//   _deos, fesč_, rnue_, _ажат, 
   {{0x5ba40184,0x67200034,0xdb080109,0x25a13542}},	//   ллығ, _बाइक_, godà, znil_, 
   {{0x7d018d3f,0x371800af,0x772400fe,0x257c01a8}},	//   _feos, _बाड़ी_, য়াছ_, _bíll_, 
   {{0x7d018d40,0x2d9c011c,0x7a3401d3,0x00000000}},	//   _geos, qnue_, _sütö, --, 
   {{0x7df80882,0x7a3404cc,0x8ccc8bb5,0x257c08a5}},	//   ṃsth, _pütö, देशो, _díll_, 
   {{0x6d498d41,0xf53c10d1,0xfc4400bc,0xbae001ec}},	//   _haga, _skåp_, řích_, _ﺍﺯﺳﺎ, 
   {{0x6d498d42,0x25a00306,0x257c02d2,0x85b40063}},	//   _kaga, tnil_, _fíll_, вљач, 
   {{0x6d498d43,0x00000000,0x00000000,0x00000000}},	//   _jaga, --, --, --, 
   {{0x6d498d44,0x25a18d45,0xc32473b5,0xdb0801ed}},	// [29dc0] _maga, rnil_, кмак, lodá, 
   {{0x6d498d46,0x25a13180,0xb3818d47,0x64a40116}},	//   _laga, snil_, алул, ваға, 
   {{0x6d480295,0xf8bc07ea,0x25a010bf,0xdb080f57}},	//   _oaga, rgée_, pnil_, nodá, 
   {{0xc4f89924,0xe29800c7,0x00000000,0x00000000}},	//   _تعدا_, маҕ_, --, --, 
   {{0xdb0802fb,0x7d0000c5,0x00000000,0x00000000}},	//   hodá, _reos, --, --, 
   {{0x7d018d48,0x6d498d49,0xdb0801ed,0x03a4033a}},	//   _seos, _aaga, kodá, _риго, 
   {{0x26dc0232,0x64458d4a,0x7d000037,0x3da401f0}},	//   _úvod_, lwii, _peos, криб, 
   {{0xdb0813d5,0x00000000,0x00000000,0x00000000}},	//   dodá, --, --, --, 
   {{0x5c758d4b,0x6444045f,0x7d00000d,0xfb84013d}},	//   улпт, nwii, _veos, вынн, 
   {{0x6d498d4c,0xefc40276,0xf0a40022,0x3dd401ec}},	//   _eaga, _алул_, _ркул_, _ﺟﯟﯨﻘ, 
   {{0x6d498d4d,0x7d00793d,0x33740302,0xa3e40037}},	//   _faga, _teos, דעים_, _पूस_, 
   {{0x6444004b,0x98b8033b,0xd9140022,0x00000000}},	//   kwii, sesč_, ыдмы, --, 
   {{0xac0408a2,0x6444058a,0x7b6401af,0x00000000}},	//   _анча_, jwii, _атйе, --, 
   {{0x6d498d4e,0x6444000f,0xdb0802f0,0x00000000}},	//   _zaga, dwii, bodá, --, 
   {{0x6d483182,0x8b6401ec,0x9f440139,0xaa600108}},	//   _yaga, _حانم, _itmä_, _втык, 
   {{0x6d4881f1,0xded00020,0xf8bc011f,0x569400fb}},	//   _xaga, ብርና_, ffét_, _ҡапт, 
   {{0x54542ecc,0xb8780120,0x64440a49,0x5334004e}},	// [29dd0] ыват, ecív, gwii, леат, 
   {{0x1b1403f4,0x29c40113,0x00000000,0x00000000}},	//   ত্রে_, nñan_, --, --, 
   {{0xb88408a7,0x521410ad,0x630401b9,0x999c0064}},	//   _fríð, удет, شونل, _urvų_, 
   {{0xb8840008,0x86e0004b,0xc2e80116,0x28d087ea}},	//   _gríð, _نړېو, _җурҗ_, सेवि, 
   {{0x6fb41086,0xf4840166,0xf2e48a4a,0xdb08f7b3}},	//   вҳар_, _рунн, _аюбо, zodá, 
   {{0x0c24059f,0xa87c010f,0x4c8401d5,0x00000000}},	//   ҳмин, ואדר, ғлов, --, 
   {{0x16c001ad,0x00000000,0x00000000,0x00000000}},	//   _एरोब, --, --, --, 
   {{0x6d48011f,0x26dc008d,0x81e800cc,0xd0d4011c}},	//   _qaga, וקומ, _মিচ_, _бобъ, 
   {{0x7bc874bb,0xc1a402dd,0x50183229,0xf000013d}},	//   _bhfu, _сырқ, _سياح_, _түли, 
   {{0x6d498d4f,0x3b80cced,0x4a441f80,0x00000000}},	//   _waga, йлыг, гнов, --, 
   {{0x6d498d50,0xede401b9,0xfc481d0e,0x4a740150}},	//   _taga, _рўзн, tríð_, уыпт, 
   {{0x29058d51,0xca74052f,0xdb087815,0x6d498d52}},	//   úma_, _ҡуйы, rodá, _uaga, 
   {{0x6d8400e4,0xdb0801ed,0x81e800fe,0x00000000}},	//   _añag, sodá, _মিছ_, --, 
   {{0xf1c402fb,0x5468001f,0xdb0801d3,0x1a2401d9}},	//   _šály_, _ታላላቅ_, podá, دریُ, 
   {{0x69c4068f,0x6445606e,0xf8bc06af,0xb8840413}},	//   रतदी, wwii, ffés_, _príð, 
   {{0x04443c85,0x64443f50,0x5ee40154,0x00000000}},	//   лебн, twii, _নড়াই, --, 
   {{0x2618007d,0x00000000,0x00000000,0x00000000}},	// [29de0] बूजी_, --, --, --, 
   {{0x64458d53,0x81c81c82,0xf770029e,0x00000000}},	//   rwii, োৱা_, _هاپ_, --, 
   {{0x9f440798,0x64440548,0x425401ec,0x31bc00cc}},	//   _fumê_, swii, ытат, েদনশ, 
   {{0x98b80421,0xc0c84c04,0x00000000,0x00000000}},	//   lesā_, нуле_, --, --, 
   {{0x7958013d,0xb87800d8,0x29c402d1,0x00000000}},	//   _häwä, scív, yñan_, --, 
   {{0x32c4022e,0x00000000,0x00000000,0x00000000}},	//   zеyi_, --, --, --, 
   {{0x8fd4151e,0x00000000,0x00000000,0x00000000}},	//   рәтә, --, --, --, 
   {{0xdd918d54,0xf6540bd9,0x6b800455,0xc0d438b7}},	//   توب_, רסקי_, _alng, _ميزب, 
   {{0x51b80276,0x00000000,0x00000000,0x00000000}},	//   _рыря_, --, --, --, 
   {{0x6d858d55,0x5a340aa8,0x9b940114,0x00000000}},	//   _añad, анот, риоц, --, 
   {{0x9f440023,0xda34005b,0x00000000,0x00000000}},	//   _lumë_, шены, --, --, 
   {{0xfce58d56,0xdb08002f,0x58d4b27b,0x00000000}},	//   _содо, lldü, ионт, --, 
   {{0xa3e403f3,0xe81c033d,0x7bc80295,0x3ebc0250}},	//   _पूल_, भंगा_, _thfu, _hytt_, 
   {{0x88d40a28,0x00000000,0x00000000,0x00000000}},	//   vṛtt, --, --, --, 
   {{0x79580139,0xb4d801e1,0x387c4b16,0xab241fbe}},	//   _cäwä, _laàt, šur_, _соја_, 
   {{0x79580166,0x65944af2,0x00000000,0x00000000}},	//   _däwä, басу, --, --, 
   {{0x3ebc319f,0x241811db,0x9f80067c,0x00000000}},	// [29df0] _lytt_, лоты_, còç_, --, 
   {{0x98b8005f,0x3ebc03b2,0xe4a4419d,0xb1903c1a}},	//   cesā_, _oytt_, ёрто, әлдә, 
   {{0x3ebc1121,0xdb08008c,0xb2a82cc8,0xa9683321}},	//   _nytt_, lldó, хтаж_, _شمیم_, 
   {{0x35441fe2,0xe4e40212,0x90558d57,0xa4e4022e}},	//   _схов, _гірн, ивец, _гўрк, 
   {{0x98a8033f,0x113800fb,0xdce0008e,0x00000000}},	//   _dbać_, еяһы_, jimı, --, 
   {{0x3ebd34d2,0xdb0805d5,0xdde800f2,0x00000000}},	//   _bytt_, gldü, گروه_, --, 
   {{0x27780302,0x9f440200,0x00000000,0x00000000}},	//   רגון_, _zumë_, --, --, 
   {{0x3ebc143a,0xb87801e7,0x00000000,0x00000000}},	//   _dytt_, ncís, --, --, 
   {{0x6b800270,0x3ebc0008,0x00000000,0x00000000}},	//   _plng, _eytt_, --, --, 
   {{0x91e400b5,0x15e45c0e,0x00000000,0x00000000}},	//   niはa, कदार_, --, --, 
   {{0x49c83acc,0xb4d801e1,0x00000000,0x00000000}},	//   клон_, _kaàs, --, --, 
   {{0xdee01b49,0x7e7c0fac,0x4994003b,0x00000000}},	//   _ናትና_, øppe, ршот, --, 
   {{0x6e2001c4,0x7958013d,0x00000000,0x00000000}},	//   lunb, _säwä, --, --, 
   {{0x9f4419f5,0x9f80067c,0xcb680114,0x00000000}},	//   _cumè_, ròç_, _јаке_, --, 
   {{0x9f4419f5,0x6e2001d5,0x00000000,0x00000000}},	//   _dumè_, nunb, --, --, 
   {{0xdb18007f,0x959801c0,0x29c4002e,0xb7b800e4}},	//   _akvè, гтуу_, oñam_, yrãg, 
   {{0x9f44011c,0x29c402d1,0x68e58d58,0xf8bc003e}},	// [29e00] _fumè_, nñam_, _igid, sfér_, 
   {{0x42558d59,0x6e218d5a,0xddd80153,0x7958013d}},	//   итет, kunb, tyvū, _täwä, 
   {{0x00e42d29,0x68e401ee,0x2480001f,0xc2440220}},	//   ажен, _kgid, _የመሬት_, рнек, 
   {{0x6e218d5b,0x802401d5,0x00000000,0x00000000}},	//   dunb, لرتم, --, --, 
   {{0x68e4009a,0x3f6817a0,0x3ebc4cab,0x20540064}},	//   _mgid, кидо_, _sytt_, скля, 
   {{0x3ebc33b8,0x4430037e,0x6e200334,0x8fd404b4}},	//   _pytt_, mty_, funb, бәхә, 
   {{0xe8e0001e,0x44318d5c,0x1c18007d,0x68e40248}},	//   _muối_, lty_, _दिहल_, _ogid, 
   {{0x68e58d5d,0x44300034,0xf53c0217,0x00000000}},	//   _ngid, oty_, _njål_, --, 
   {{0x7b65315d,0x61e001ab,0x5bb801f0,0x257c0118}},	//   атне, _iiml, ллия_, _cíli_, 
   {{0x44318d5e,0x61e18d5f,0x68e58d60,0xe8e0004d}},	//   ity_, _himl, _agid, _nuối_, 
   {{0x44318d61,0x61e051c8,0x60c00649,0xac70034c}},	//   hty_, _kiml, _hymm, مایش, 
   {{0x4430489c,0x60c0049b,0x61e18d62,0x6d840428}},	//   kty_, _kymm, _jiml, _eñab, 
   {{0x60c18d63,0xdbdc012c,0x61e18d64,0x63bc0427}},	//   _jymm, lšíh, _miml, _okrn, 
   {{0xe8e007ae,0x61e007d6,0xeb94cb80,0xd7c88b25}},	//   _cuối_, _liml, _кич_, اوسه_, 
   {{0x44318d65,0x9f4419f5,0x1958273e,0xdbdc0118}},	//   ety_, _cumé_, _байы_, nšíh, 
   {{0x61e18d66,0x68e4011f,0x44318d67,0x26180037}},	//   _niml, _ggid, fty_, _फिरी_, 
   {{0x44300209,0x6d840724,0xb8780798,0x6e20005a}},	// [29e10] gty_, _uñae, rcís, zunb, 
   {{0x9f442d7d,0x6e21518f,0xe3b000f1,0x68e49323}},	//   _fumé_, yunb, ورل_, _zgid, 
   {{0x44318d68,0x62240131,0xdbdc00bc,0x32658d69}},	//   aty_, قىلل, jšíh, штав, 
   {{0x60c003a2,0x7580030b,0x4430009f,0x61e00139}},	//   _bymm, _بیرم, bty_, _ciml, 
   {{0x443002f0,0x60c0015d,0x6f7001a9,0x00000000}},	//   cty_, _cymm, оҳаф, --, 
   {{0x6e201a56,0x60c18d6a,0x6d8400e4,0x00000000}},	//   tunb, _dymm, _oñac, --, 
   {{0x61e008a7,0xb4d80248,0x29c40784,0x257c02d2}},	//   _fiml, _gaàr, wñam_, _síli_, 
   {{0x6e2005f5,0x386805b1,0x4d658d6b,0xd254179e}},	//   runb, kxcr_, скив, _پیچش_, 
   {{0x60c18d6c,0x6440025a,0x6e20009d,0x5f7401d3}},	//   _gymm, _âmit, sunb, _ڈالر, 
   {{0x5f740491,0x61e004c4,0x6e20034c,0x68e4015d}},	//   _والر, _ziml, punb, _sgid, 
   {{0x61e09ff3,0x28d05b82,0xc330011a,0x6e20014f}},	//   _yiml, _सृजि, הוי_, qunb, 
   {{0x44318d6d,0x5ed02158,0xe8e001fb,0x60c00076}},	//   yty_, _স্কে, _suối_, _yymm, 
   {{0x44316ee0,0xc8b42ecb,0x29c40309,0x00000000}},	//   xty_, ссны, qñam_, --, 
   {{0x443001f5,0x8a7801e2,0x00000000,0x00000000}},	//   vty_, _محبس_, --, --, 
   {{0xc9f42586,0x44318d6e,0xfaa17128,0x98b80356}},	//   _استع, wty_, _нашо, tesă_, 
   {{0x44318d6f,0x63bd8d70,0x68e40117,0x29c4005a}},	//   tty_, _skrn, _ugid, iñak_, 
   {{0x98b80276,0x44302517,0xe8e00051,0x00000000}},	// [29e20] resă_, uty_, _tuối_, --, 
   {{0x44318d71,0x60c18d72,0x61e0bf5f,0x00000000}},	//   rty_, _rymm, _siml, --, 
   {{0x44318d73,0x06d4015b,0x3f80005f,0x38c80424}},	//   sty_, _ত্রি, _ēku_, _لایی_, 
   {{0x44318d74,0x3ab8008f,0x113800cf,0x4084004e}},	//   pty_, אמענ, иячы_, йулб, 
   {{0xc4d44bcf,0xb8798d75,0xb4d80241,0x35a005f5}},	//   _دغدغ, ncíp, _abàf, _хаяг, 
   {{0xe82035e8,0x2fd40199,0xdbdc0118,0x1ee801b9}},	//   _बिना_, موند_, tšíh, گوژی_, 
   {{0xa2498684,0x61e18d76,0xdd940220,0x00000000}},	//   _خیال_, _timl, жайы, --, 
   {{0x60c00649,0xdbdc00bc,0x9bf400d4,0x5dd40220}},	//   _tymm, ršíh, озич, _ﺟﺎﻗﺴ, 
   {{0x4094007b,0xe8e00051,0x00000000,0x00000000}},	//   _الذر, _muồi_, --, --, 
   {{0x7b658d77,0xdbdc00bc,0x3ea40120,0xffb801af}},	//   стие, pšíh, _лизг, _субъ_, 
   {{0x7de80034,0xa2cc0073,0xf2d0010f,0x408401af}},	//   _męsk, थेच्, ּער_, _туңб, 
   {{0xf968034b,0xdca40075,0x00000000,0x00000000}},	//   урой_, _һаҗи, --, --, 
   {{0xa3b800bc,0x257c01ef,0x00000000,0x00000000}},	//   ङका_, _jílu_, --, --, 
   {{0x6d840de2,0x257c02d2,0x00000000,0x00000000}},	//   _iñaa, _mílu_, --, --, 
   {{0x6d84094a,0xe8e00208,0x00000000,0x00000000}},	//   _uñac, _buồi_, --, --, 
   {{0xe9a41b6b,0xb8cc00bd,0xa3e411d7,0x659400d8}},	//   _најп, _কর_, _पंख_, пасу, 
   {{0xe820033d,0x53986bf1,0xf99c506b,0xb4d8002e}},	// [29e30] _बिया_, авая_, miè_, _mbàg, 
   {{0x37040116,0xf99c007f,0x00000000,0x00000000}},	//   _учив, liè_, --, --, 
   {{0xd17522cf,0x0734011a,0x00000000,0x00000000}},	//   жылы, _ואתם_, --, --, 
   {{0x59c81a04,0xf99d8d78,0x22840137,0x06940220}},	//   रतिर, niè_, чууг, _گاۋھ, 
   {{0x7774031c,0x79e40150,0x212000e4,0x00000000}},	//   _koxx, _ﺍﻟﻔﻀ, óiha_, --, 
   {{0xb2f0025c,0x257c00bc,0x98b80024,0xb7b800c7}},	//   _བཅིང_, _dílu_, cesą_, kuãm, 
   {{0x6d84002e,0x59c8090a,0xa77c00df,0x00000000}},	//   _añaa, रतार, ררופ, --, 
   {{0x4c8410f5,0x8d758d79,0x2bb000dc,0x257c1d0e}},	//   жлив, تاتا, ुत्थ, _fílu_, 
   {{0xf99c007f,0x4b8800db,0x00000000,0x00000000}},	//   diè_, ийин_, --, --, 
   {{0x6468010e,0x00000000,0x00000000,0x00000000}},	//   _äpiş, --, --, --, 
   {{0x89a8169c,0xc9a8023a,0x8cf402d5,0xb7b800e4}},	//   иков_, ивое_, _дзец, guãm, 
   {{0xfe6c04d3,0xb4d80cad,0xadb402dd,0x4cb8117e}},	//   _جگه_, _gbàg, _دۇعا_, _клею_, 
   {{0xcb680364,0x7774031c,0xe8e001fb,0x02c403ba}},	//   _вале_, _boxx, _ruồi_, _वर्न, 
   {{0x5ed009bd,0x752c04cc,0xbb40af15,0x777406be}},	//   _স্টে, _accz, _жешк, _coxx, 
   {{0x2d9c0093,0x5b2400c7,0x777400d7,0x00000000}},	//   oiue_, _хьча, _doxx, --, 
   {{0x2d9c0270,0xb4d801e1,0x61402507,0x21b802dd}},	//   niue_, _obàd, _málæ, _ﺸﻌﺎﺭ, 
   {{0x77758d7a,0x2d9c2499,0xb8cc03d4,0x35a001d5}},	// [29e40] _foxx, iiue_, _কৰ_, фатг, 
   {{0x2d9c0069,0xca3c0ed1,0x201800df,0x81f8165e}},	//   hiue_, ﻟﺠﺎ_, _ĉri_, لفطر_, 
   {{0x98b80006,0x61400008,0x257c00bc,0xb9e000a2}},	//   resą_, _nálæ, _sílu_, _üçül, 
   {{0xaca001f2,0x257c0419,0x00000000,0x00000000}},	//   _atọm, _pílu_, --, --, 
   {{0x7de8012d,0x25a06ed1,0xd78810e8,0x00000000}},	//   _tęsk, miil_, _ضخیم_, --, 
   {{0x25a18d7b,0xf99c02e2,0x00000000,0x00000000}},	//   liil_, ziè_, --, --, 
   {{0xefc8001f,0x9d180137,0xfd880107,0x00000000}},	//   ጠሪያ_, бойт_, иёии_, --, 
   {{0x25a01c06,0x5c740116,0x6140032e,0x00000000}},	//   niil_, злит, _dálæ, --, 
   {{0xfba85191,0xb4d80248,0xf99c0100,0xb14012fa}},	//   итой_, _gbàd, viè_, _інфл, 
   {{0x9f440093,0x25a00014,0x23798d7c,0x00000000}},	//   _kumí_, hiil_, _jorj_, --, 
   {{0xa2a013b4,0x25a001d9,0x19598d7d,0x6d858d7e}},	//   _गेम्, kiil_, баны_, _iñan, 
   {{0x25a01bce,0xad640107,0x5ba800d1,0xfd10132f}},	//   jiil_, _махз_, ркүм_, _آجا_, 
   {{0xb8f005ba,0xf99c7903,0x24800070,0x25a00254}},	//   _वर_, riè_, jyim_, diil_, 
   {{0xdd90004b,0x6b60014b,0x00000000,0x00000000}},	//   _غوږ_, _окча, --, --, 
   {{0x25a000c5,0x00000000,0x00000000,0x00000000}},	//   fiil_, --, --, --, 
   {{0xf8bd8d7f,0x00000000,0x00000000,0x00000000}},	//   ngék_, --, --, --, 
   {{0xe8e00016,0x6d840588,0x98c4009d,0x00000000}},	// [29e50] _buổi_, _oñan, _хөнж, --, 
   {{0xf2c44f55,0x6d8400e4,0x257c032e,0xe820012d}},	//   осен, _nñan, _bíls_, _बिता_, 
   {{0x25a18d80,0x00000000,0x00000000,0x00000000}},	//   biil_, --, --, --, 
   {{0x6d842e95,0x25a00050,0x604001f2,0xb5a58d81}},	//   _añan, ciil_, _ịmag, _фрой, 
   {{0x23798d82,0x3384013e,0xa3e40fe3,0x00000000}},	//   _forj_, _дувв, _पंच_, --, 
   {{0x23798d83,0x00000000,0x00000000,0x00000000}},	//   _gorj_, --, --, --, 
   {{0xf1a4eb44,0x2d9c0393,0xcc880133,0x00000000}},	//   _дран, tiue_, ڵنده_, --, 
   {{0x6d8400c7,0x00000000,0x00000000,0x00000000}},	//   _eñan, --, --, --, 
   {{0x7d0401c0,0x2d9c003a,0x8c440276,0x00000000}},	//   чныг_, riue_, чепе, --, 
   {{0x64400793,0x25a0022f,0x2d9c003a,0xaee00150}},	//   _ämie, ziil_, siue_, _قۋشى, 
   {{0x3b8001c0,0x2d90068c,0xdd74072d,0x00000000}},	//   хлэг, èxes_, سپیک, --, 
   {{0xe8e001f2,0x2fc40175,0xe8200550,0x25a00067}},	//   stọm_, llng_, _बिदा_, xiil_, 
   {{0x25a18d84,0xf8bc0098,0x6b740139,0x00000000}},	//   viil_, ngéh_, _дөня_, --, 
   {{0x2558063f,0x161c01ad,0x25a0058a,0x248406be}},	//   _ọl_, _फिशर_, wiil_, _ümmi_, 
   {{0xf8bc003e,0x25a07285,0xe8e00208,0xb0600139}},	//   hgéh_, tiil_, _ruổi_, _şäly, 
   {{0x2bcc08ec,0x2508034c,0xcfd0009e,0x00000000}},	//   _सीता, ترسی_, াদিন, --, 
   {{0x25a13e7e,0x07a41188,0xb7b80022,0x00000000}},	// [29e60] riil_, _наин, kuãh, --, 
   {{0x25a18d85,0x00000000,0x00000000,0x00000000}},	//   siil_, --, --, --, 
   {{0xcfd002a6,0x248025a9,0xb7780302,0x7de80006}},	//   াদান, syim_, _האיש, _tęsi, 
   {{0x25a00009,0xdb080200,0x00000000,0x00000000}},	//   qiil_, tndë, --, --, 
   {{0xe8e007ae,0x3f8c0493,0xdb1801a8,0xf990008f}},	//   _tuổi_, thfu_, _skví, ערד_, 
   {{0xb7b80022,0xd3b800d4,0x82681188,0x00000000}},	//   guãh, _дусі_, _лагв_, --, 
   {{0xb4d80241,0xdef80220,0xdb080200,0xeaa400ae}},	//   _gbàb, бық_, sndë, _أع_, 
   {{0x3f8c009f,0x00000000,0x00000000,0x00000000}},	//   shfu_, --, --, --, 
   {{0xacf00a11,0x79e402dd,0xa2a00118,0x00000000}},	//   رسيت, _ﺍﻟﻘﻀ, _गेत्, --, 
   {{0x822c044e,0x6d840113,0xdb08002e,0x7014011a}},	//   _ዲክታቶ, _uñan, ondé, _מחמד_, 
   {{0xa3e42871,0x7e7c01e3,0x00000000,0x00000000}},	//   _पूछ_, äppd, --, --, 
   {{0x9f4400f7,0xdb080332,0x7d7800f1,0x00000000}},	//   _humà_, indé, _دمصر_, --, 
   {{0xe8e001fb,0xf1bc00d0,0x00000000,0x00000000}},	//   _muỗi_, ýšia_, --, --, 
   {{0xb7b800e4,0xf8bc00e4,0x61fc013a,0x00000000}},	//   arãn, ngéi_, _otrl, --, 
   {{0x7bd8008c,0x00000000,0x00000000,0x00000000}},	//   mmtu, --, --, --, 
   {{0x5ecc00d1,0x00000000,0x00000000,0x00000000}},	//   ﻗﺘﯘﺭ, --, --, --, 
   {{0x57b47111,0x61fc0998,0xda6400aa,0x93798d86}},	// [29e70] _обит, _atrl, _راډي, обат_, 
   {{0x39498d87,0xb7b800c7,0x00000000,0x00000000}},	//   lecs_, kuãi, --, --, 
   {{0x61fd8d88,0x00000000,0x00000000,0x00000000}},	//   _ctrl, --, --, --, 
   {{0x6d94084c,0x3f9c208d,0x07e80014,0x61f802fb}},	//   nţat, _amtu_, _دِیی_, ívla, 
   {{0xe0d000c6,0xe8e0004d,0x45a007d2,0x00000000}},	//   هزه_, _duỗi_, _شەكك, --, 
   {{0x3f9c05b1,0x6f000218,0x39498d89,0x8ea40133}},	//   _cmtu_, ubnc, hecs_, وڵان, 
   {{0x9f440589,0xf3ec03d4,0xb7b8035b,0xa3d47995}},	//   _sumã_, _ছবিৰ_, guãi, _чорч, 
   {{0x7bd8022f,0x1c18000d,0x1d9401f4,0x00000000}},	//   emtu, _दिखल_, ерьё, --, 
   {{0x9f4419f5,0x00000000,0x00000000,0x00000000}},	//   _fumà_, --, --, --, 
   {{0xaca0063f,0x6d84035b,0x00000000,0x00000000}},	//   _nkụk, _iñam, --, --, 
   {{0xddc801ed,0x394800cf,0x7d7401d5,0x00000000}},	//   _erdő, fecs_, سمیر_, --, 
   {{0xaca005db,0x7e7d8d8a,0x499800d6,0xdd9400ee}},	//   _akụk, äppe, ітня_, _пахы, 
   {{0x6d840055,0x00000000,0x00000000,0x00000000}},	//   _jñam, --, --, --, 
   {{0x799c009a,0xdd1c02f0,0xcb6800d8,0xa6ec0154}},	//   _emqw, mášk, _факе_, কর্ম_, 
   {{0x37e015d4,0x4ad05612,0x673c2167,0xdd1c0306}},	//   торг, _हरिव, rfrj, lášk, 
   {{0x6d840022,0x00000000,0x00000000,0x00000000}},	//   _oñam, --, --, --, 
   {{0x69c400ec,0x61fd8d8b,0xdd1c0f91,0xdedc0023}},	// [29e80] _ikie, _strl, nášk, _ሒዘን_, 
   {{0x387c03fa,0x7de80024,0xf34400a8,0x4ad002c3}},	//   äure_, _kęst, мпул_, _हराव, 
   {{0x6d858d8c,0xb9b02099,0x689400f1,0x6d940356}},	//   _añam, _سمیع, _زدکړ, nţas, 
   {{0x80a58d8d,0xdb080de2,0xdfd000ec,0xdd1c00d7}},	//   ومان, rndé, گيت_, kášk, 
   {{0x7de80b21,0xd36c198a,0x69c58d8e,0x7f48031c}},	//   _lęst, _گۇل_, _mkie, tefq, 
   {{0x7c340108,0xdd1c013a,0x00000000,0x00000000}},	//   _äyri, dášk, --, --, 
   {{0x6d8408e7,0x69c58d8f,0x61fc08a4,0x29c40113}},	//   _eñam, _okie, _utrl, nñas_, 
   {{0x29c40077,0x2dd400c6,0x1d345cfa,0x9d180124}},	//   iñas_, وبية_, хния, чоит_, 
   {{0x9f440ffb,0xdb1828c8,0xacf000d1,0x00000000}},	//   _tumà_, _akvá, خسىت, --, 
   {{0x69c58d90,0x7de8045f,0x3078011a,0x00000000}},	//   _akie, _bęst, _ואמנ, --, 
   {{0x39498d91,0x19598d92,0xe81405f9,0xfe4400d4}},	//   tecs_, паны_, _तौबा_, _індо, 
   {{0xa9100115,0xbc6894f1,0xff2403e6,0x4e4400db}},	//   _foɾm, _ومان_, _ربڕی, _سئمف, 
   {{0x6d940311,0x02ec01ad,0xa2a01b76,0xdb180f91}},	//   rţat, जशाह_, _गेस्, _ekvá, 
   {{0x7de8045f,0xbfe4019b,0x39488fdd,0x00000000}},	//   _fęst, _bit版_, secs_, --, 
   {{0x69c40327,0x7de8033f,0xb7b80124,0x394801bf}},	//   _fkie, _gęst, kuãv, pecs_, 
   {{0x58d58d93,0x9998033f,0x00000000,0x00000000}},	//   _пойт, żyła_, --, --, 
   {{0xdb080793,0x00000000,0x00000000,0x00000000}},	// [29e90] kodü, --, --, --, 
   {{0x6d94084c,0xa84801d3,0x768400db,0x00000000}},	//   nţar, _کلیم_, _жымж, --, 
   {{0xe1f18d94,0xf2c4a96f,0x2604010b,0xb864004b}},	//   لسن_, фсан, _ичяг, _راکو, 
   {{0x91800131,0x69c40135,0xe2c8009a,0x657800d7}},	//   دۇرۇ, _xkie, ذونو_, ľahá, 
   {{0xd0087327,0x60083981,0x92c0015b,0x8d580124}},	//   челе_, днім_, ুশে_, ҧшит_, 
   {{0x83518d95,0x00000000,0x00000000,0x00000000}},	//   _مھما, --, --, --, 
   {{0xdb08012d,0x00000000,0x00000000,0x00000000}},	//   hodó, --, --, --, 
   {{0x6d84c862,0x7de8000f,0xe8202ba2,0xdb087379}},	//   _iñak, _ręst, _बिला_, rodý, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69c58d96,0x7e7c1a80,0x00000000,0x00000000}},	//   _skie, äppc, --, --, 
   {{0xdb080142,0x00000000,0x00000000,0x00000000}},	//   andï, --, --, --, 
   {{0xaee00055,0x3eb8000f,0x4c940a0e,0x00000000}},	//   _arṇo, ûpte_, _пиес, --, 
   {{0xdb082b76,0x8c458d97,0xc31400fe,0x2d8c000d}},	//   godó, _челе, ালতি_, _ilge_, 
   {{0x6d5801c6,0x7de80006,0x6d840124,0x311c00dc}},	//   ldua, _tęst, _oñak, मृतः_, 
   {{0xf3fc035b,0x29c40789,0x36641f67,0x00000000}},	//   _atã_, uñas_, наро_, --, 
   {{0x6d598d98,0x69c58d99,0xaca001f2,0xe94417ae}},	//   ndua, _ukie, _nhịk, _شرعی, 
   {{0x6d858d9a,0x88e4084c,0x6d58003a,0x00000000}},	// [29ea0] _añak, _яжие, idua, --, 
   {{0xaca0063f,0x6d5805b1,0x00000000,0x00000000}},	//   _ahịk, hdua, --, --, 
   {{0x2d8c00c5,0x660401af,0x00000000,0x00000000}},	//   _olge_, _шонҡ, --, --, 
   {{0xaca002e3,0xc0590575,0xb4d80241,0x00000000}},	//   _chịk, зік_, _ibàn, --, 
   {{0xdb0804cc,0x9f340d30,0xefb001b9,0x6d5803e0}},	//   todü, велі, گیلگ, ddua, 
   {{0xc0c0044e,0x2d8d8d9b,0x6d580175,0xafe006ed}},	//   _ትካል_, _alge_, edua, гочл, 
   {{0x6d580334,0xdb08bd88,0xdd94004e,0x00000000}},	//   fdua, rodü, какы, --, 
   {{0x6e4026c0,0xb4d8002e,0x6d5805c7,0xf3fc0022}},	//   انيم, _mbàn, gdua, _ytã_, 
   {{0x3024009b,0x00000000,0x00000000,0x00000000}},	//   _потп_, --, --, --, 
   {{0x6d58013f,0xebd58d9c,0x2d8c0064,0x386401ef}},	//   adua, ндыш_, _elge_, _čnr_, 
   {{0xdb080034,0x6f1401d9,0x8d980092,0x00000000}},	//   wodó, _سٲنس_, ዎቻቸው_, --, 
   {{0x9f800086,0x00000000,0x00000000,0x00000000}},	//   mòñ_, --, --, --, 
   {{0xb8640137,0x84980240,0x00000000,0x00000000}},	//   راحو, _ፊልሞን_, --, --, 
   {{0x77909a79,0xdb082389,0x98a4035b,0x65940150}},	//   ایدا, rodó, еиҭе, ңару, 
   {{0xa2a00574,0x8b644e74,0xf3fc0589,0x19598d9d}},	//   _गेल्, _جانم, _stã_, _жайы_, 
   {{0xb4d801ab,0x059401d5,0x00000000,0x00000000}},	//   _dbàn, ناقگ, --, --, 
   {{0x545400c2,0x161c03e5,0xf8bc77aa,0xa8a473f6}},	// [29eb0] ъват, _फिकर_, ggét_, _брэк, 
   {{0x9f800428,0x00000000,0x00000000,0x00000000}},	//   kòñ_, --, --, --, 
   {{0xdb1801e6,0x9f800428,0xb4d80241,0x6440008e}},	//   _ikvä, jòñ_, _gbàn, _ämin, 
   {{0xa1940408,0x00000000,0x00000000,0x00000000}},	//   лахч, --, --, --, 
   {{0x7f580166,0x6d58f77f,0xc43001ed,0xb9f80023}},	//   _batq, vdua, _نکلت, _መጹ_, 
   {{0x1f640150,0x00000000,0x00000000,0x00000000}},	//   лкім, --, --, --, 
   {{0x6d840054,0x7f58003a,0x5ec40116,0x00000000}},	//   _uñak, _datq, лишғ, --, 
   {{0x8d6461ff,0xf8bd8d9e,0x6cb001c0,0x7e7c0267}},	//   твие, ngés_, лөлт, äppa, 
   {{0x6d598d9f,0x13b40183,0x6d8400b8,0x8fd00139}},	//   rdua, _জীয়, _jñai, _кәкә, 
   {{0x9f800086,0x6d5807de,0x35980092,0x3b800139}},	//   bòñ_, sdua, ቀምበት_, илыг, 
   {{0x09d58da0,0x2d8c0093,0xdb08180f,0xda7802d5}},	//   _সংবা, _tlge_, todò, еяў_, 
   {{0x6d4802fb,0xb7b800e4,0x7f580139,0x00000000}},	//   ínač, kuãs, _zatq, --, 
   {{0x3958003d,0x7f58008e,0x00000000,0x00000000}},	//   _daqs_, _yatq, --, --, 
   {{0x7af8074d,0x8ba405f5,0x317c0007,0x7f580166}},	//   cctt, _шилж, _louz_, _xatq, 
   {{0x6d8400e4,0xda6400db,0x39598da1,0x00000000}},	//   _añai, _مايي, _faqs_, --, 
   {{0xf8bd8da2,0x00000000,0x00000000,0x00000000}},	//   ggés_, --, --, --, 
   {{0x15b8010b,0xc4c8011c,0x00000000,0x00000000}},	// [29ec0] хыры_, флаж_, --, --, 
   {{0x06858da3,0x644000c7,0xdb0801a8,0xf8bc0098}},	//   _агон, _ãmim, yndí, rgét_, 
   {{0x317c2b05,0xf53c05ac,0xd3b41def,0xd3c404da}},	//   _bouz_, _småe_, усть, اتقى, 
   {{0x7f58afeb,0xe5080451,0xb7b800e4,0xd174121c}},	//   _satq, _ڪيڏو_, erãh, лычы, 
   {{0x317c24b4,0x9f8008e7,0x7f587a06,0xdd9400fb}},	//   _douz_, wòñ_, _patq, ҫалы, 
   {{0xaca00521,0xe8141408,0x9f800428,0x7f58047e}},	//   _chọk, तीया_, tòñ_, _qatq, 
   {{0xf8bc003e,0x8eb01456,0x5724010f,0x661c02d0}},	//   ngér_, مەكت, אַפּ_, nsrk, 
   {{0x317c0007,0x5d544727,0xdea401b9,0xc1d000fd}},	//   _gouz_, укит, پیچی, _төзә, 
   {{0x7f580357,0x395801b9,0xe814012c,0xffb8009f}},	//   _tatq, _raqs_, तीमा_, _قُرب_, 
   {{0xf410025f,0xfec80451,0x9b5800d8,0x00000000}},	//   ספת_, _قبضو_, хиот_, --, 
   {{0xee3405f5,0x317c0097,0x29040790,0x00000000}},	//   _анх_, _youz_, ıman_, --, 
   {{0xec1000b2,0xac7025da,0xdb180267,0x5ed800de}},	//   _چوند, _چاوش, _skvä, ēķēš, 
   {{0x6d840784,0xac700424,0x6d600306,0x8ac4035b}},	//   _añaw, _ناوش, ávaž, кқәа_, 
   {{0x6018007b,0x43bc00dc,0x00000000,0x00000000}},	//   _zúmá, ्तोऽ, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa9c40212,0x98c4009d,0x39ac00c0,0x00000000}},	//   _вськ, _бөгж, kęsi_, --, 
   {{0x317d8da4,0xf8bcaa46,0xb4d80241,0x96f800a8}},	// [29ed0] _rouz_, rgés_, _gbàl, _пепт_, 
   {{0x17540801,0xaa2c001f,0x317d8da5,0xf20402d5}},	//   _своя, _ተሰጥቷ, _souz_, вядо, 
   {{0x6d8400e4,0x00000000,0x00000000,0x00000000}},	//   _iñav, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x90440127,0x7e7c01e3,0x00000000,0x00000000}},	//   انته, äppn, --, --, 
   {{0x601800ae,0x4814010f,0x4ed4003b,0x00000000}},	//   _súmá, אַקן_, люйт, --, 
   {{0x5398001f,0xb4d81bce,0x3ea0036b,0x317c030a}},	//   _መረዳት_, _mbàm, йишг, _touz_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdd1c0118,0x00000000,0x00000000,0x00000000}},	//   nářk, --, --, --, 
   {{0x7d04236c,0x00000000,0x00000000,0x00000000}},	//   ıksa, --, --, --, 
   {{0x09e41c13,0x8e98489b,0xc9a98da6,0x9f0400d1}},	//   лоон, _ثناء_, евне_, _ئومو, 
   {{0xb4d80248,0x26cc0793,0xdeec01ec,0x7c2402f0}},	//   _abàm, üdom_, _تۋى_, škra, 
   {{0xabb00598,0xc8dc0210,0x00000000,0x00000000}},	//   _кадә, नेंट, --, --, 
   {{0x58040032,0xe7a800d1,0xc794010b,0x00000000}},	//   рорғ, ئۇدى_, урмы, --, 
   {{0xb958026c,0xda598da7,0xd1e80092,0xe8200c70}},	//   glìs, _арыш_, ቅምት_, _बिका_, 
   {{0xb0d09856,0x78f0014b,0x00000000,0x00000000}},	//   _तरंग, _гӯру, --, --, 
   {{0xd04801e4,0x320000a2,0x44648727,0x43687c3f}},	// [29ee0] _afeɾ, _atjy_, ывав, наан_, 
   {{0x6d8401c4,0x161c012c,0xb4d801e1,0x3898010f}},	//   _iñau, _फिचर_, _gbàm, _ניינ, 
   {{0xdb0801e7,0x42240395,0x00000000,0x00000000}},	//   nndá, удев, --, --, 
   {{0x09d400fe,0xf678008f,0xb4d82ef9,0x00000000}},	//   _সূতা, _נאכמ, _mbàj, --, 
   {{0x867400c7,0xb11000d4,0x34900024,0x00000000}},	//   _рыҿц, сміш, _гаўр, --, 
   {{0x29000270,0xdb0801b8,0x03a402ff,0x44318da8}},	//   _lfia_, lodö, _сиго, muy_, 
   {{0x44318da9,0x29000618,0xc21001d9,0xeea402e8}},	//   luy_, _ofia_, _دٔز_, лтък_, 
   {{0xdb098daa,0x0108004b,0x443000e8,0xc0e4011c}},	//   cidê, _سترو_, ouy_, _бобк, 
   {{0x44318dab,0xe284036b,0xbf341888,0xfb84008e}},	//   nuy_, _ёлғи, _مراغ, гынн, 
   {{0xdeb0005e,0x290004c9,0x2004008e,0xdb08036e}},	//   _құқы, _afia_, _itmi_, midë, 
   {{0x44300bf1,0xdb098dac,0xfd44009d,0x00000000}},	//   huy_, kodö, _бэлн, --, 
   {{0x44304375,0x7c642674,0x0ac40022,0x7e7c03b2}},	//   kuy_, _ماتل, ршьҭ, øppu, 
   {{0x44318dad,0xdb098dae,0xa3b401f9,0x00000000}},	//   juy_, andá, जचा_, --, 
   {{0x2900013f,0x3f8c039a,0x6cc05b7f,0x00000000}},	//   _efia_, nkfu_, _уйча, --, 
   {{0x6d8401c4,0xa3d807af,0x35450b01,0xdb080200}},	//   _eñau, ातन_, лхав, hidë, 
   {{0xdd1c0118,0xf41c0108,0x00000000,0x00000000}},	//   tářk, _pvä_, --, --, 
   {{0x44318171,0xdb0806ed,0x00000000,0x00000000}},	// [29ef0] guy_, vidê, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd25003e4,0x20058daf,0x50f4011c,0x7ce401d5}},	//   تنا_, _atmi_, азет, lаrd, 
   {{0x3d0c068f,0x6d8400b8,0x45e400d1,0xa674009f}},	//   सरों_, _jñat, _ﺋﺎﻳﻼ, _اَٽڪ, 
   {{0xf3fc06ed,0xf48577ba,0x44315a62,0x271804c5}},	//   _irão_, _сунн, cuy_, _তাতো_, 
   {{0xdb080261,0x8e841b88,0xb7b800e4,0x00000000}},	//   sidê, игле, arãv, --, 
   {{0x6d843cdf,0x3dc00873,0xa0a40131,0x00000000}},	//   _oñat, ﺭﻟﯩﻘ, ишәл, --, 
   {{0x8d753508,0x9f4c02bd,0xdb080ba1,0x00000000}},	//   شابا, _lidè_, lidè, --, 
   {{0xa9100115,0x00000000,0x00000000,0x00000000}},	//   _moɾt, --, --, --, 
   {{0x6d84094a,0xb4d801e1,0x257c012c,0x3f8c039a}},	//   _añat, _abàk, _díly_, ckfu_, 
   {{0x2fc58db0,0x2bc407f7,0x0d740408,0x06a800eb}},	//   mong_, रकबा, _выля, _খুনি, 
   {{0x7bc8010f,0x2fc4c33c,0xede401b9,0x88e4234c}},	//   _ekfu, long_, _сўзн, ижне, 
   {{0x7bc803a0,0x2fc4003e,0x44300113,0xddc4009f}},	//   _fkfu, oong_, xuy_, _اينٿ, 
   {{0x2fc58db1,0xf3fc00d8,0xca741424,0xcac800f3}},	//   nong_, _arão_, _نابغ, _игле_, 
   {{0x6b818db2,0xdb080793,0x28d80073,0xfaa008ca}},	//   _iong, todö, _ठरवि, _машо, 
   {{0x2fc58db3,0x6d840124,0x44318db4,0x7ce4022e}},	//   hong_, _iñas, tuy_, bаrd, 
   {{0x2fc58db5,0xd6d80034,0x44300789,0xdb098db6}},	// [29f00] kong_, ęła_, uuy_, fidè, 
   {{0x2fc58db7,0x44318db8,0xdb098db9,0xf3fc0055}},	//   jong_, ruy_, vidë, _trãn_, 
   {{0x6b818dba,0x2fc58dbb,0x44318dbc,0x6d8400b8}},	//   _mong, dong_, suy_, _jñas, 
   {{0x44318dbd,0xf3fc0120,0xd1d40b82,0x41280137}},	//   puy_, _grão_, _ይፈቱ_, тодо_, 
   {{0x44300bf1,0x2fc58dbe,0x6b818dbf,0x9f4c0332}},	//   quy_, fong_, _oong, _hidé_, 
   {{0x2fc58dc0,0x6b80b032,0xdb098dc1,0xd1740032}},	//   gong_, _nong, cidè, _һыуы, 
   {{0xf8d041ac,0x257c00bc,0x6d4400f3,0x7ce4022e}},	//   _सर्प, _síly_, đjan, zаrd, 
   {{0x6b818dc2,0xdb098dc3,0x44218dc4,0x257c0030}},	//   _aong, midé, _kvk_, _píly_, 
   {{0x6b818dc5,0x2fc58dc6,0x6d840bc9,0x90494a1e}},	//   _bong, bong_, _añas, _مؤلف_, 
   {{0x2fc58dc7,0xbea4063b,0xfc480248,0x44200526}},	//   cong_, _казк, _abíó_, _mvk_, 
   {{0xdb080129,0x442000ef,0x00000000,0x00000000}},	//   nidé, _lvk_, --, --, 
   {{0x6b818dc8,0x44218dc9,0x39a482e2,0x62980162}},	//   _eong, _ovk_, ршов, úvoy, 
   {{0xfce4ae8f,0x6b818dca,0x9f4c07ea,0x7d0001e1}},	//   _тодо, _fong, _aidé_, _ifos, 
   {{0x6b818dcb,0x7bc8014b,0x395c1d64,0x77900214}},	//   _gong, _ukfu, žus_, زیجا, 
   {{0x7c20d7d5,0xb5a58dcc,0xe6658dcd,0x9f4c026c}},	//   _hvor, арай, отто, _vidè_, 
   {{0x6b818dce,0x2fc58dcf,0x7c200e04,0x44200174}},	//   _zong, zong_, _kvor, _bvk_, 
   {{0x2fc58dd0,0x98b8005f,0xa91000df,0x442000e2}},	// [29f10] yong_, resē_, _voɾt, _cvk_, 
   {{0x6b803143,0x98b80421,0xdb0806af,0xb4b40073}},	//   _xong, sesē_, fidé, _जशी_, 
   {{0x9f4c0429,0xdb08068c,0x44218dd1,0x2fc40051}},	//   _gidé_, ridè, _evk_, vong_, 
   {{0x2fc58dd2,0xdb0800f7,0x44200ac5,0x7c218dd3}},	//   wong_, sidè, _fvk_, _ovor, 
   {{0x2fc58dd4,0xe82005f9,0x6d8439cb,0x00000000}},	//   tong_, _बिछा_, _oñar, --, 
   {{0x7d018dd5,0x26e40241,0x00000000,0x00000000}},	//   _afos, _òroó_, --, --, 
   {{0x6b818dd6,0x7c218dd7,0xdb098dd8,0x12e40c58}},	//   _rong, _avor, cidé, _প্ৰদ, 
   {{0x6b818dd9,0x2fc58dda,0x6d852b9b,0x7d006ec0}},	//   _song, song_, _añar, _cfos, 
   {{0x6b818ddb,0x3ebd8ddc,0x998000a2,0x00000000}},	//   _pong, _extt_, _ňiş_, --, 
   {{0x7c203858,0x2a9403be,0x6b800978,0xeea80bd6}},	//   _dvor, ləbə_, _qong, _итек_, 
   {{0x7c218ddd,0x7d0003cb,0xda580395,0x3d10000d}},	//   _evor, _ffos, аряш_, _धड़के_, 
   {{0x6b818dde,0x48080276,0x5d1400db,0x00000000}},	//   _wong, лемн_, _ۇبۇز, --, 
   {{0x6b818ddf,0xdb080798,0xab6000ef,0x00000000}},	//   _tong, todô, _šļup, --, 
   {{0x6b8005d9,0x442169c1,0x59b40137,0x5bc4007b}},	//   _uong, _rvk_, йөөс, _وتوف, 
   {{0x7c218de0,0x6d840113,0x44218de1,0x09e40798}},	//   _zvor, _uñas, _svk_, _локн, 
   {{0x9f4c5eb5,0x442000ca,0x959800f7,0x7c20118f}},	//   _vidé_, _pvk_, атуу_, _yvor, 
   {{0x7b04066d,0xc3242487,0x07a4036b,0x6d480014}},	// [29f20] _érté, ймак, _гапн, _mbga, 
   {{0x44202301,0xdb08004a,0x87240690,0x00000000}},	//   _vvk_, tidé, _اعظم, --, 
   {{0x4420017a,0x24800092,0x36f400df,0x6d480210}},	//   _wvk_, _ከመሬት_, _לצים_, _obga, 
   {{0x4420a403,0x00e4c133,0xdb080129,0x04c801f7}},	//   _tvk_, бжен, ridé, _موجي_, 
   {{0x65658de2,0xdb098de3,0x44200010,0xdef40108}},	//   mdih, sidé, _uvk_, оплы, 
   {{0x81f8cb3a,0x6d498de4,0xdb0800c6,0x64440ba7}},	//   _مفسر_, _abga, pidé, mtii, 
   {{0x7c20dba9,0x64458de5,0xbe4804fb,0x7d000112}},	//   _svor, ltii, اشتم_, _pfos, 
   {{0x65658de6,0x6445606e,0x52b000cf,0x67e001e3}},	//   ndih, otii, _تەمئ, löjd, 
   {{0x6444641c,0x90700075,0xccf400d1,0xec640139}},	//   ntii, _يۇمش, әқә_, брэк_, 
   {{0x64458de7,0xa3d80882,0x6d498de8,0x7c20003a}},	//   itii, ाति_, _ebga, _vvor, 
   {{0x7d000a73,0x644402f6,0xfe44084c,0x00000000}},	//   _tfos, htii, _ынжо, --, 
   {{0x7c2002fb,0x64458de9,0xb4d80241,0x67e001e3}},	//   _tvor, ktii, _gbàw, höjd, 
   {{0xa3d81fe5,0x3998069c,0xfb840724,0x7c2001fa}},	//   ाता_, _nëse_, _гыйн, _uvor, 
   {{0xa5241f21,0x63bc009a,0x6444d29e,0x8cdc2977}},	//   _འཇུག_, _njrn, dtii, _परतो, 
   {{0x64440290,0xd6d8033f,0x00000000,0x00000000}},	//   etii, ęło_, --, --, 
   {{0x64458dea,0x7ddc0036,0x6d8400b8,0x00000000}},	//   ftii, bëse, _jñap, --, 
   {{0x09b002f5,0x64458deb,0x00000000,0x00000000}},	// [29f30] _টীকা, gtii, --, --, 
   {{0x399804c4,0x00000000,0x00000000,0x00000000}},	//   _dëse_, --, --, --, 
   {{0x644432c2,0xd6d8034c,0x62240075,0x925800c9}},	//   atii, _خودش_, كىلل, рает_, 
   {{0x6444fb7a,0x00000000,0x00000000,0x00000000}},	//   btii, --, --, --, 
   {{0x6444084c,0xaacc03f8,0xe1f01acc,0x491823e9}},	//   ctii, _सुनक, رسم_, परतो_, 
   {{0x6d483223,0x6d858dec,0x0f3404d3,0x00000000}},	//   _sbga, _añap, تکرد, --, 
   {{0x62358ded,0x02b4013e,0x10080145,0x00000000}},	//   _неру, _дирӯ, اتچى_, --, 
   {{0xfa240135,0x00000000,0x00000000,0x00000000}},	//   _རྗེན_, --, --, --, 
   {{0x6d480100,0xb4d801ab,0x00000000,0x00000000}},	//   _vbga, _ucàd, --, --, 
   {{0x09d00a94,0xb4d801ab,0x0a48023a,0x8b842309}},	//   सत्य, _gcàe, азой_, تەتە_, 
   {{0x09e401d5,0x67e001e3,0xb7b80022,0x7b8400db}},	//   жонн, nöje, yrãr, تايە, 
   {{0x64458dee,0x7ddc0240,0x00000000,0x00000000}},	//   ytii, tëse, --, --, 
   {{0x65654e51,0x64440009,0x00000000,0x00000000}},	//   vdih, xtii, --, --, 
   {{0x7ddce5c8,0x6f002c76,0x65646f19,0x865401f3}},	//   rëse, ncnc, wdih, _ምልክት, 
   {{0xe3b80205,0xf7400108,0x00000000,0x00000000}},	//   _ıı_, ьеро, --, --, 
   {{0x64458def,0x7ddd4b37,0x7e7c26bb,0x00000000}},	//   ttii, mësc, äppi, --, 
   {{0x64458df0,0x07a43cbb,0x656400c5,0x7ddc04e6}},	// [29f40] utii, _маин, rdih, lësc, 
   {{0x64458df1,0x03240212,0x693400f2,0x00000000}},	//   rtii, іден, _بکگر, --, 
   {{0x64458df2,0x38c81272,0x7ddc04e6,0x67e0007c}},	//   stii, _مایی_, nësc, röjd, 
   {{0xa524038f,0x64458df3,0x6564058a,0x6e200327}},	//   _འཇིག_, ptii, qdih, dsnb, 
   {{0x64440357,0xa18801ec,0x00000000,0x00000000}},	//   qtii, _құда_, --, --, 
   {{0x44318df4,0x7ddc04e6,0x00000000,0x00000000}},	//   mry_, kësc, --, --, 
   {{0x8698010f,0xdd9404b3,0x00000000,0x00000000}},	//   ייַז, зайы, --, --, 
   {{0x44318df5,0x7ddc01c7,0xc5ec00eb,0xdb080205}},	//   ory_, dësc, য়ীরা_, şlüy, 
   {{0x7bd400e8,0x00000000,0x00000000,0x00000000}},	//   _ëyuk, --, --, --, 
   {{0x44302a1f,0xa0a58df6,0x61fd8df7,0x7ddc04e6}},	//   iry_, _дағд, _kurl, fësc, 
   {{0x44318df8,0x7ddc01c7,0x35a8000d,0xb4b40950}},	//   hry_, gësc, घोड़, _जश्_, 
   {{0x44300151,0x2ba800bc,0x3cc800f3,0x9abc031c}},	//   kry_, टोबा, _клео_, jaċe, 
   {{0xf7701b31,0x9f4c0316,0x61fd8df9,0xdb098dfa}},	//   واس_, _lidí_, _lurl, lidí, 
   {{0x4430233e,0xb4d800a3,0x61fc0129,0x7ddc04e6}},	//   dry_, _mbàt, _ourl, bësc, 
   {{0x44318dfb,0x61fd8dfc,0xf3fc00e4,0x67d4c939}},	//   ery_, _nurl, _irãi_, фору, 
   {{0x443004af,0xb4d80241,0x00000000,0x00000000}},	//   fry_, _obàt, --, --, 
   {{0x44318dfd,0x61fd8dfe,0xb4d800a3,0x9f4c0332}},	// [29f50] gry_, _aurl, _scàb, _aidí_, 
   {{0xdb240724,0xef1c0034,0x67e0023a,0xf99c068c}},	//   _äsär, ążka_, töje, lhè_, 
   {{0x61fd8dff,0xd17440bd,0x46d00927,0xd13000e3}},	//   _curl, зылы, _दुपह, فما_, 
   {{0xe1f93d53,0x44300609,0x61fc1288,0xf99c067c}},	//   ігі_, bry_, _durl, nhè_, 
   {{0xd478008f,0x67e0005b,0x9f440ca8,0x273c0118}},	//   _האָל, söje, _numó_, _ušní_, 
   {{0xdb0849ab,0x9f8401ec,0x8eb8004e,0x1fb80139}},	//   andú, мгід, йыйт_, олчы_, 
   {{0x61fc09a5,0xa3d80d2c,0x78a003e3,0x92b800cc}},	//   _gurl, ातर_, _ənva, _চৰৰ_, 
   {{0x4c841d16,0x45e40131,0x673c0841,0x00000000}},	//   злив, _ﺋﺎﻟﻼ, zgrj, --, 
   {{0x61fc00fd,0x2bc58e00,0xf99c00f2,0x7ddc0221}},	//   _zurl, रकला, dhè_, wësc, 
   {{0x61fc01f5,0x7ddc0221,0x61380092,0x00000000}},	//   _yurl, tësc, _ጥናቶች, --, 
   {{0x8a057956,0xdb090520,0x9f4c0548,0x49c8020f}},	//   язне, cidí, _fidâ_, йлон_, 
   {{0x44308f76,0x7644037e,0x7ddc0a40,0xf3fc00c7}},	//   yry_, dtjy, rësc, _erãi_, 
   {{0x7ce401b9,0x2d9c0208,0x7ddc0036,0x998c013a}},	//   lаrn, mhue_, sësc, ardů_, 
   {{0x44318e01,0xca4800aa,0x7ddc01c7,0xefbc0023}},	//   vry_, _هلته_, pësc, _ስማዊ_, 
   {{0xb4d80241,0x19840451,0x7ddc036e,0x764400a2}},	//   _obàs, _ڊجيٽ, lësa, gtjy, 
   {{0xf99d8e02,0x44318e03,0x61fd8e04,0x2d9c0051}},	//   chè_, try_, _rurl, nhue_, 
   {{0x4430052f,0x2d9c06c8,0x61fd8e05,0xa3d801ad}},	// [29f60] ury_, ihue_, _surl, ातल_, 
   {{0x44311fb6,0x61fd8e06,0x00000000,0x00000000}},	//   rry_, _purl, --, --, 
   {{0x4430578f,0xdb080120,0x7ddc00e4,0x61fc06be}},	//   sry_, lidã, hësa, _qurl, 
   {{0x25741a59,0x9f4c0122,0x6af8031c,0x7c240419}},	//   _تۇرس, _vidí_, _ནུའོ_, škri, 
   {{0xa3040046,0x15b01066,0x25a00165,0xff2801d5}},	//   _жүзе, _شەكس, mhil_, бўйи_, 
   {{0x61fc006c,0x9f4c011f,0x39980de2,0x2d9c003e}},	//   _turl, _sidâ_, _mësa_, ehue_, 
   {{0x9f443eba,0x61fc0d47,0x00000000,0x00000000}},	//   _sumó_, _uurl, --, --, 
   {{0x2d9d8e07,0x5c7418ac,0x9f4c011f,0x25a0020b}},	//   ghue_, длит, _qidâ_, nhil_, 
   {{0xf99c0ffb,0xdb098e08,0xec64010b,0x00000000}},	//   vhè_, sidí, прэк_, --, 
   {{0x4f9400d1,0xf060008e,0xdb080217,0x7ac47e7e}},	//   _орху, _якуп, nndø, зсме, 
   {{0x25a04c8f,0xceacfff2,0xbd6800f3,0x02bc07b7}},	//   khil_, _рә_, _грле_, ्थिभ, 
   {{0xada00117,0x6da00251,0x2d9cbc38,0x00000000}},	//   _пахл, _пиха, chue_, --, 
   {{0x25a18e09,0x06a80729,0xf3fc01fb,0x00000000}},	//   dhil_, _খুলি, _trãi_, --, 
   {{0xe7843417,0xf99c56ec,0x2cb40f91,0x1ab4156e}},	//   нусо, shè_, šedá_, _обля, 
   {{0x9f4c07de,0x1db01098,0x5ac80244,0x00000000}},	//   _midà_, _जगात, _باشێ_, --, 
   {{0xdb084d74,0x98b8005f,0x9418036b,0x1dcc17c6}},	//   lidà, nesī_, жжат_, ावित, 
   {{0x7644037e,0xa3d80b7c,0xe4553993,0x5fdc095f}},	// [29f70] stjy, ातं_, нкты, यताल, 
   {{0xdb080158,0x25a00009,0x64a40063,0x00000000}},	//   gndø, ahil_, хађа, --, 
   {{0x1dcc0b7c,0x25a0009a,0x00000000,0x00000000}},	//   ावात, bhil_, --, --, 
   {{0x25a18e0a,0xe81400bc,0x8cdc6c52,0xa8480345}},	//   chil_, तीका_, _परलो, _بلیم_, 
   {{0x237816a3,0xe4c406a6,0x9f440ca8,0x67e0007c}},	//   _fnrj_, _зёрн, _rumò_, löja, 
   {{0xa3d800dc,0xdea4be6e,0x00000000,0x00000000}},	//   ातः_, کیمی, --, --, 
   {{0xceb803a5,0xf3fd8e0b,0xb4d80248,0xf1a50bea}},	//   цәа_, _huã_, _gbàr, _еран, 
   {{0xf3fc0ed2,0xb1441888,0x6ed006be,0x7ddc0200}},	//   _kuã_, _ریتم_, _sәbә, tësa, 
   {{0x9f4cb269,0xcc8825da,0x0b598e0c,0x2d9c01bf}},	//   _fidà_, زنده_, орны_, rhue_, 
   {{0xf3fc0004,0x9f4c07c5,0xdb080798,0x94fc031c}},	//   _muã_, _gidà_, vidã, _ཐུའི_, 
   {{0x7e7c049f,0x9f340212,0x2d9c01bf,0x9f440ca8}},	//   äppt, _чехі, phue_, _tumò_, 
   {{0xdb080120,0x7c2c00e2,0xb9e40451,0x3eb800d7}},	//   tidã, ņbra, وڙين_, úpte_, 
   {{0x6d5800ec,0x9f4c011f,0x24800548,0xefbc0023}},	//   meua, _hidá_, xxim_, _ስማዕ_, 
   {{0x6d598e0d,0xdb080120,0x24800218,0x3e4c00ac}},	//   leua, ridã, vxim_, _mətn_, 
   {{0x25a046a3,0x3664013e,0xe6b407d6,0xdb0803b2}},	//   thil_, маро_, رلرگ, vndø, 
   {{0x6d598e0e,0xdb0800d8,0x485800c0,0x00000000}},	//   neua, pidã, _дроў_, --, 
   {{0xa4948375,0xf3fc0004,0xdb098e0f,0xb9b000c6}},	// [29f80] ریست, _cuã_, lidá, _جميع, 
   {{0x61b93493,0x25a18e10,0x614800d2,0x6d598e11}},	//   ेक्ष, shil_, kéló, heua, 
   {{0x25a18e12,0x6d598e13,0xdebc0f7c,0x26dc0124}},	//   phil_, keua, ታተን_, _ávo_, 
   {{0xdb080109,0x00000000,0x00000000,0x00000000}},	//   zidà, --, --, --, 
   {{0xf3fc0589,0x23b40372,0xded80092,0x00000000}},	//   _guã_, _كۅرس, ሮውን_, --, 
   {{0xc2100014,0x6d580076,0x00000000,0x00000000}},	//   _لٔس_, eeua, --, --, 
   {{0x9f4c0077,0xdb0804cc,0xdb204158,0x1f8400fb}},	//   _cidá_, vidà, átím, _үҫен, 
   {{0xefb001d5,0x00000000,0x00000000,0x00000000}},	//   _یینگ, --, --, --, 
   {{0x9bf42377,0x00000000,0x00000000,0x00000000}},	//   нзич, --, --, --, 
   {{0x7e7c42a7,0x00000000,0x00000000,0x00000000}},	//   äpps, --, --, --, 
   {{0x61440020,0xeb9400d8,0x00000000,0x00000000}},	//   _የምትች, фиќ_, --, --, 
   {{0x7c640075,0x8f8000c7,0x6a100133,0x46d0000d}},	//   _ياشل, _ақәл, کبیر, _दुधह, 
   {{0x7ddc02d3,0xdb080ba1,0x3b84022e,0x00000000}},	//   lëso, pidà, _олдг, --, 
   {{0xeaac6aa5,0xac940502,0xdb080077,0x67e001f4}},	//   اعی_, _تنها_, bidá, töja, 
   {{0x7ddc0240,0xaa602503,0xeb3808c3,0x00000000}},	//   nëso, _атык, _ועוש, --, 
   {{0x5ecc0131,0x67e001e3,0xdeec0092,0x00000000}},	//   ﺗﺘﯘﺭ, röja, ቅርና_, --, 
   {{0x7ddc0023,0x3f9ce77e,0x321c00e8,0x72a000d1}},	// [29f90] hëso, _oltu_, _ňuy_, ھەرن, 
   {{0x7ddc02d3,0x68e0a697,0x3998036e,0xdb0801f4}},	//   këso, ümde, _këso_, _äläp, 
   {{0x6d598e14,0x7ddc0240,0x27f80030,0x51545847}},	//   yeua, jëso, ženú_, етлу, 
   {{0x3f9d8e15,0x7bd80112,0x3998036e,0x4638010f}},	//   _altu_, hltu, _mëso_, _צערע, 
   {{0x64580356,0x00000000,0x00000000,0x00000000}},	//   ăvic, --, --, --, 
   {{0x67e00267,0x3cf007f7,0x7bd8005c,0x00000000}},	//   höjn, ँधने_, jltu, --, 
   {{0xdb0806ed,0x6d84005a,0x6d580438,0x7ce4022e}},	//   xidá, _iñaz, teua, sаrl, 
   {{0x7bd80d27,0xcc886134,0x3f9c0a87,0x00000000}},	//   eltu, збие_, _eltu_, --, 
   {{0x8fd00131,0x6d598e16,0x00000000,0x00000000}},	//   _йәкә, reua, --, --, 
   {{0x765400b5,0x7bd80158,0xa2d4033f,0x7ddc0240}},	//   _opxy, gltu, _बुड्, bëso, 
   {{0x9eb00075,0x752c0034,0x3a200b83,0xc0300092}},	//   _پەيغ, _odcz, лмэг, _አልተወ, 
   {{0xaca001f2,0x7bd98e17,0xfe6c02f2,0x00000000}},	//   _ajụk, altu, _دگه_, --, 
   {{0xaacc0cf1,0xb4d8026c,0x6d84005a,0xcb086af3}},	//   _सुरक, _scàn, _oñaz, _فيشن_, 
   {{0xb88403b2,0x66080118,0x00000000,0x00000000}},	//   _spíð, ídko, --, --, 
   {{0x7c240122,0xdef80003,0x7bc40098,0xdb08009a}},	//   škrt, _paċi_, ékue, _غزوه_, 
   {{0xe7e000af,0x00000000,0x00000000,0x00000000}},	//   _खीरा_, --, --, --, 
   {{0x69c40003,0x03185734,0xf9900115,0x00000000}},	// [29fa0] _ijie, كتات_, _תרח_, --, 
   {{0x68e58e18,0xf48403e6,0x09d400fe,0x00000000}},	//   _izid, راقی, _সূচা, --, 
   {{0x4254084c,0x67e0007c,0x66f401f9,0x00000000}},	//   этат, löjo, _आणिक_, --, 
   {{0x7ddc0200,0xd17418bc,0x00000000,0x00000000}},	//   vëso, кычы, --, --, 
   {{0xe8140574,0x69c4009f,0x3f9d8e19,0x00000000}},	//   तीचा_, _mjie, _pltu_, --, 
   {{0x7ddc044e,0x68e4009f,0xa2d400cd,0x00000000}},	//   tëso, _mzid, _बुथ्, --, 
   {{0xa284168d,0x8fd400c7,0xeaa400ae,0x00000000}},	//   _جیاو, тәтә, _إع_, --, 
   {{0xafe0052f,0x7ddc044e,0xbfa80014,0xa3d809b2}},	//   _ҡотл, rëso, _کارٕ_, ातक_, 
   {{0x68e401ab,0x6d840055,0xdb0800e4,0x09c802c3}},	//   _nzid, _jñay, andý, रवैय, 
   {{0xdd0070f7,0x69c4009f,0x9b940640,0x7ce4022e}},	//   ıtıl, _ajie, тиоц, qаrm, 
   {{0x68e58e1a,0x7ddc02d3,0xf1b42432,0x5fc40137}},	//   _azid, qëso, _आगमन, _كەچۅ, 
   {{0xc0c0069c,0x23a4049f,0xaacc01f9,0x3cf844e3}},	//   _ስራሕ_, _höjd_, _सुळक, _उलटे_, 
   {{0xa3d001b0,0x69c4002e,0x22580200,0xec7400f5}},	//   शवा_, _djie, _lprk_, _ппц_, 
   {{0x68e405b8,0x69c58e1b,0x00000000,0x00000000}},	//   _dzid, _ejie, --, --, 
   {{0x68e40912,0x6d840784,0x67e001e6,0x6be000c6}},	//   _ezid, _añay, möjl, _حكوم, 
   {{0xa2d44a76,0x98740124,0xdce00790,0x29c4010e}},	//   _बुध्, _алиц, lkmı, lıan_, 
   {{0x24583549,0x98b80006,0x00000000,0x00000000}},	// [29fb0] нать_, mesį_, --, --, 
   {{0x23a4049f,0xf2c4bf38,0xb38402f2,0x00000000}},	//   _nöjd_, нсен, رێزم_, --, 
   {{0xa2d4194b,0x3a3c0263,0x3e4c00ac,0xd7580022}},	//   _बुद्, nutp_, _qətl_, _еиҿц_, 
   {{0xe2c8021a,0x98b802d5,0xe1f0007b,0xdb08415b}},	//   رونو_, nesį_, مسن_, lidä, 
   {{0xe4e40046,0x6d84005a,0x628806af,0x600802dd}},	//   _бірн, _iñax, _àdon, енім_, 
   {{0x409004a9,0x9f4c013d,0xdb0803b2,0xeb1c01f9}},	//   شلىر, _nidä_, tndý, _मजेत_, 
   {{0x2258005b,0x1dcc0073,0x225400d7,0x00000000}},	//   _пиры_, ावंत, čaká_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x98b800c0,0xdb08415b,0x00000000,0x00000000}},	//   desį_, kidä, --, --, 
   {{0x09c8215d,0x69c4688b,0x00000000,0x00000000}},	//   रव्य, _sjie, --, --, 
   {{0x0e44035b,0xdb2000e5,0xdb080139,0x68e400e5}},	//   _шьаҭ, átám, didä, _szid, 
   {{0xcc980b87,0x69c40327,0x98b80024,0x3e4c06be}},	//   _овец_, _qjie, gesį_, _xətm_, 
   {{0x8c444623,0x43280023,0xfa840023,0x00000000}},	//   _реле, ትሕብባ, _ንዘክር_, --, 
   {{0x2d8d8e1c,0x6d840054,0x9b4408f0,0x68e40010}},	//   _hoge_, _añax, _منهو, _vzid, 
   {{0xf6218e1d,0x2d8c00b5,0xecc000e2,0x69c58e1e}},	//   идро, _koge_, šķās_, _tjie, 
   {{0x2d8d8e1f,0x80e003d4,0x69c4009f,0xb5c182df}},	//   _joge_, _ফলস্, _ujie, айсл, 
   {{0x2d8d8e20,0x03680334,0x225800de,0xdb080139}},	// [29fc0] _moge_, миак_, _sprk_, bidä, 
   {{0x2d8d8e21,0xf53c037e,0xf0340023,0xd4f40137}},	//   _loge_, _småt_, _ብሰላም, уясы, 
   {{0x23a404f3,0x2d8c0067,0xb734010f,0x02bc07b7}},	//   _nöje_, _ooge_, _בריװ_, ्थेन, 
   {{0xc058005e,0xdb0c0252,0x626c01e1,0x272c01e1}},	//   дік_, ðhús, _s̟os, bóní_, 
   {{0x6d840724,0x9f35089c,0x00000000,0x00000000}},	//   _uñay, гелі, --, --, 
   {{0x2b440198,0xfe7000d1,0xe58400db,0x00000000}},	//   _ncnc_, لدع_, _ртүү, --, 
   {{0x2d8d8e22,0x290001c6,0x02e400c5,0xcf24009f}},	//   _boge_, _ogia_, _करिह_, ارهي, 
   {{0x2d8d8e23,0x29009334,0x7ce401b9,0x00000000}},	//   _coge_, _ngia_, lаri, --, 
   {{0x2d8c7efe,0x9f4c02f6,0x00000000,0x00000000}},	//   _doge_, _pidä_, --, --, 
   {{0x2d8c05ac,0x613801e1,0x2b440142,0x02e400e1}},	//   _eoge_, _fúlà, _ccnc_, _कराह_, 
   {{0x20058e24,0x46d18e25,0x2d8d8e26,0x199401ce}},	//   _humi_, _दुलह, _foge_, ганя, 
   {{0x20058e27,0x2d8d8e28,0x2900011c,0xf2d023e4}},	//   _kumi_, _goge_, _cgia_, יעת_, 
   {{0xe824c43c,0x2004f04d,0xddc800e5,0x00000000}},	//   ифро, _jumi_, _élős, --, 
   {{0x20058e29,0x290005f5,0x2b440332,0xdbcc02d2}},	//   _mumi_, _egia_, _gcnc_, _góðh, 
   {{0x200403b4,0xf568dfe6,0x35698e2a,0x66b40a5b}},	//   _lumi_, мшак_, мран_, абру, 
   {{0xa2b80b98,0x00000000,0x00000000,0x00000000}},	//   ्पन्, --, --, --, 
   {{0x91c40588,0x20058e2b,0x7ddc036e,0xdb080108}},	// [29fd0] ҳәал, _numi_, tësj, pidä, 
   {{0xdec00b82,0x7ce4022e,0xe3b001e2,0x7af400a2}},	//   _ስጋን_, gаri, يرل_, _şyty, 
   {{0x20040421,0x6440713c,0x7ddc0240,0x622400d1}},	//   _aumi_, _åmin, rësj, لىلل, 
   {{0xf53c00cc,0x00000000,0x00000000,0x00000000}},	//   _blåe_, --, --, --, 
   {{0x20040516,0x7ddc02d3,0x2d8c180f,0xf8bc030a}},	//   _cumi_, mësh, _roge_, zaén_, 
   {{0x80e0045e,0x20058e2c,0x06a804c5,0x2d8c00cc}},	//   _ফলশ্, _dumi_, _খুটি, _soge_, 
   {{0x20040069,0x2d8c0421,0x3ce53433,0x9f2400d1}},	//   _eumi_, _poge_, _azov_, شۈنۈ, 
   {{0x20058e2d,0x3d340134,0x7ddc0240,0x9f4c01e3}},	//   _fumi_, _yɛwɔ_, nësh, _ridå_, 
   {{0x20058e2e,0xa3d80574,0xb0b58e2f,0x2d8c0332}},	//   _gumi_, ातच_, _अधिग, _voge_, 
   {{0x7ddc0240,0xdd1c0118,0x9abc031c,0x613801e1}},	//   hësh, háňk, maċj, _túlà, 
   {{0x20058415,0x2d8c0e02,0x7ddc02d3,0xaca00ca8}},	//   _zumi_, _toge_, kësh, _ikọk, 
   {{0x2004271e,0xea9c00b8,0x7ddc0240,0x0c7401b9}},	//   _yumi_, _akṣi_, jësh, _مدتد, 
   {{0x317c014b,0xc8b58e30,0x7ddc0240,0xbd4000db}},	//   _mnuz_, усны, dësh, _اچىي, 
   {{0x6a7401f2,0x39980023,0x00000000,0x00000000}},	//   _ụfo, _lësh_, --, --, 
   {{0xf1d00882,0x06a803d4,0xb6a00209,0x8578084c}},	//   तवान, _খুজি, бирл, нсат_, 
   {{0x29000077,0x7ddc0240,0xb6a00276,0x09e40212}},	//   _ugia_, gësh, щисл, _щойн, 
   {{0x83386874,0x04c801c8,0x6fd00073,0x00000000}},	// [29fe0] ечет_, روئي_, दकां, --, 
   {{0x20058e31,0xaca0063f,0x3e4c0213,0xd3600166}},	//   _rumi_, _nkọk, _fəth_, _äğlä_, 
   {{0x77f40302,0x20058e32,0xc7a40588,0x39980023}},	//   _תמיד_, _sumi_, _аиҿк, _bësh_, 
   {{0xaca00cad,0x00c81cd1,0x6288004a,0x9abc031c}},	//   _akọk, нлек_, _àdom, faċj, 
   {{0x20040286,0xa2d417ee,0x00000000,0x00000000}},	//   _qumi_, _बुर्, --, --, 
   {{0xf42800fd,0x7ddc0023,0x3e680cab,0x9e141cb8}},	//   şäü_, mësi, ешин_, адкі, 
   {{0x7ddc02d3,0x44218e33,0x2ff40276,0x704410de}},	//   lësi, _hwk_, ыншь_, _ەرمە, 
   {{0x20040605,0xc04436e7,0x00000000,0x00000000}},	//   _tumi_, _مخطو, --, --, 
   {{0x20058e34,0x7ddc02d3,0x00000000,0x00000000}},	//   _uumi_, nësi, --, --, 
   {{0x7fd50575,0x4420009f,0x39980240,0xaacc033f}},	//   _сібі, _mwk_, _zësh_, सअंक, 
   {{0x7ddc02d3,0xbf100184,0x00000000,0x00000000}},	//   hësi, _күҙә, --, --, 
   {{0x7ddc02d3,0x4420020c,0x6e9080c2,0x907000db}},	//   kësi, _owk_, _دلما, _دۇۇش, 
   {{0xec1016cb,0x7d018e35,0xedd000b2,0x44200af9}},	//   _هوند, _igos, _ايند, _nwk_, 
   {{0x7c218e36,0x918c00d1,0x64580356,0x7ddc0200}},	//   _iwor, ﯩﻐﯘﭼ, ăvil, dësi, 
   {{0xa2d58e37,0x7d005bae,0x4420393c,0x7c20004c}},	//   _बुल्, _kgos, _awk_, _hwor, 
   {{0x7c200099,0x442031e5,0x00000000,0x00000000}},	//   _kwor, _bwk_, --, --, 
   {{0x7d0001c8,0x7ddc0240,0x7c2000b5,0x317001e0}},	// [29ff0] _mgos, rësh, _jwor, ҙғат, 
   {{0x7c218e38,0x44200097,0x17540801,0x7ddc036e}},	//   _mwor, _dwk_, _твоя, sësh, 
   {{0x7c200083,0xd13000d1,0x7ddc036e,0xc04c01e2}},	//   _lwor, قما_, pësh, ېږم_, 
   {{0x7d018e39,0x7ddc036e,0x7c2002d0,0xf99c5eb0}},	//   _ngos, bësi, _owor, nkè_, 
   {{0x44218e3a,0x3998036e,0x00000000,0x00000000}},	//   _gwk_, _vësh_, --, --, 
   {{0xaf340330,0xa18400fb,0x9f0400ae,0x00000000}},	//   ارشت, _һыул, موهو, --, 
   {{0x7c200cad,0x929401c6,0xdb080129,0x00000000}},	//   _awor, _тавц, sidû, --, 
   {{0x7c218e3b,0xfa38001f,0x317c03e0,0x00000000}},	//   _bwor, _በሰላማ, _unuz_, --, 
   {{0x23a401e6,0x1d880131,0x7c200042,0x00000000}},	//   _höja_, ائىي_, _cwor, --, 
   {{0x7d0000b4,0xd1e80020,0xe0d0805c,0x5ba41669}},	//   _egos, ቄዎች_, _رزق_, йлығ, 
   {{0x26e4038e,0x7c218e3c,0x80d8009e,0x6fdc0129}},	//   _गरेर_, _ewor, বেদ্, vêch, 
   {{0xa2b98e3d,0xe9842c11,0x0cd400cf,0x00000000}},	//   ्पत्, сқин, _коею, --, 
   {{0x93e40073,0x4bc0030d,0x00000000,0x00000000}},	//   कताच_, _дιас, --, --, 
   {{0xebbc1682,0x442000b5,0x7d000427,0xbb400137}},	//   raḓo_, _rwk_, _zgos, _дешк, 
   {{0x2b98045f,0x23a40267,0xbb38010f,0x00000000}},	//   _rêch_, _nöja_, _סעקי, --, 
   {{0x7ddc069c,0x44200e02,0xb958026c,0x3e4c0213}},	//   tësi, _pwk_, nnìl, _qəti_, 
  
   {{0x03258e3e,0x044400d6,0x6fdc20ef,0xf50400a8}},	// [2a000] идан, резн, pêch, рнул_, 
   {{0x7ddc069c,0x764c01ed,0xb380084c,0x23a401e3}},	//   rësi, önyö, олул, _böja_, 
   {{0xadf439de,0x2d9c02f6,0xb4d8002e,0x7ddc0240}},	//   ुदान_, kkue_, _mbày, sësi, 
   {{0x7ddc0240,0x05740075,0x04440724,0x00000000}},	//   pësi, _ئادد, _кемн, --, 
   {{0x7ddc044e,0x25a0009a,0x44204471,0x65658e3f}},	//   qësi, mkil_, _uwk_, meih, 
   {{0x25a18e40,0x7c20006f,0x65658e41,0x64458e42}},	//   lkil_, _rwor, leih, muii, 
   {{0x5274d771,0x64458e43,0x7c202517,0x3da46bce}},	//   _луту, luii, _swor, ириб, 
   {{0x65658e44,0x25a18e45,0x6d48004e,0xbf341079}},	//   neih, nkil_, _ccga, _چراغ, 
   {{0x6444166a,0x7c200175,0xf0440101,0x7ddc036e}},	//   nuii, _qwor, _نعلی, kësv, 
   {{0x50b57f6e,0x6d4803ac,0xc0c02440,0x2d9c00e4}},	//   _уссу, _ecga, _ስያሜ_, akue_, 
   {{0x25a18e46,0x6444166a,0x33740375,0x7d0007de}},	//   kkil_, huii, בעים_, _tgos, 
   {{0x7d001326,0x7c20068f,0x6444166a,0xf99c0100}},	//   _ugos, _twor, kuii, ukè_, 
   {{0xf99c0395,0x7c2000ca,0x65650ee7,0x999801d3}},	//   rkè_, _uwor, deih, érő_, 
   {{0x6bd18e47,0xb4d80241,0xf99c0100,0x64440254}},	//   _وتور, _gbày, skè_, duii, 
   {{0x8b658e48,0x3e380023,0xf5258e49,0x629803cd}},	//   _دانم, _ከይኣክ, ифан, øvol, 
   {{0x65640007,0x6a1003e6,0x25a001b8,0xf53c0267}},	//   geih, _ببور, gkil_, _blåa_, 
   {{0x6444013c,0xa5f98e4a,0xf8b8000d,0x00000000}},	// [2a010] guii, рету_, _उधिय, --, 
   {{0x0a50066d,0x7e798e4b,0x2d9c005a,0x25a0058a}},	//   _بھیج, _ortp, zkue_, akil_, 
   {{0x7ddc0023,0x2ba801ad,0x6564002f,0x9abc025c}},	//   lësu, टोटा, beih, faċi, 
   {{0x798c0369,0x5f14012c,0xcfe80214,0x998c012d}},	//   njcw, नुस्_, گفته_, erdź_, 
   {{0x7e787635,0x7ddc0023,0xf8bc0098,0x4adc0037}},	//   _artp, nësu, daék_, _नुनव, 
   {{0x28c8227c,0x7bc40687,0x23a4007c,0x00000000}},	//   रपति, ékul, _töja_, --, 
   {{0x6d480064,0x31680063,0x62352fbe,0x7c3c0055}},	//   _pcga, _ишао_, _меру, _āpra, 
   {{0x7bc80083,0x0d841c83,0x0c240474,0xf1a40261}},	//   _ajfu, слин, бмин, _тргн, 
   {{0x8d7403e6,0xdb080036,0x7ddc036e,0x2d9c036e}},	//   لاکا, chdë, jësu, rkue_, 
   {{0x4a45575d,0x3998002e,0x2d9d8e4c,0xf8bc003e}},	//   бнов, _mësu_, skue_, maéh_, 
   {{0x3b8005f5,0x5f74d113,0xf8bc003e,0xfde40451}},	//   члэг, _باقر, laéh_, _ڏکيو_, 
   {{0x6d480077,0x25a0025c,0x29040feb,0x00000000}},	//   _ucga, xkil_, øma_, --, 
   {{0x65658e4d,0xd9b01df2,0x7ddc0240,0xdb08000d}},	//   veih, بەيد, tësv, endõ, 
   {{0x65640ade,0x00000000,0x00000000,0x00000000}},	//   weih, --, --, --, 
   {{0x453416c3,0x6b817554,0x2fc58e4e,0xb6a18e4f}},	//   йхат, _inng, inng_, пирл, 
   {{0xba1400cf,0x64440083,0x7ddc036e,0xa2b800cd}},	//   _اييا_, tuii, bësu, ्पस्, 
   {{0x25a18e50,0x87b8533f,0x9abc0327,0x00000000}},	// [2a020] rkil_, _бунт_, vaċi, --, 
   {{0xc328f88e,0x65658e51,0x7ddc0240,0x00000000}},	//   اكان_, seih, qësv, --, 
   {{0x64458e52,0x6564ba5c,0xcfac00cc,0x24700023}},	//   suii, peih, কচান, ስተራት_, 
   {{0x64440607,0xc0c002d3,0xc56400cf,0x7ddc0200}},	//   puii, _ድራር_, _укмк, nëst, 
   {{0x5f940323,0x64458e53,0xb03002bf,0x6b81008b}},	//   жилт, quii, зніш, _onng, 
   {{0x44318e54,0xfe240108,0xccf80210,0x75380171}},	//   msy_, бьин, reśl_, _ķuzi, 
   {{0x32405a92,0x1d0800c7,0x9abc003d,0x00000000}},	//   _нерг, аҵеи_, paċi, --, 
   {{0x6b818e55,0x443003d1,0xf0a40131,0x0eb87bca}},	//   _anng, osy_, ркәл_, шучы_, 
   {{0x7ddc0036,0xf8bc0098,0x80240066,0x00000000}},	//   dëst, raék_, _درزم, --, 
   {{0x6b800589,0x5a351078,0xc0c000fb,0x00000000}},	//   _cnng, онот, _мәҙи, --, 
   {{0x44300209,0x80d802f5,0x00000000,0x00000000}},	//   hsy_, বেশ্, --, --, 
   {{0x6b818e56,0x7ddd8e57,0xf8bc0421,0x44318e58}},	//   _enng, tësu, laéi_, ksy_, 
   {{0x77a80139,0x44300e0f,0xb5a401ec,0x00000000}},	//   _lüxe, jsy_, ұрай, --, 
   {{0x7ddc044e,0x44300151,0x8cc40243,0x57240145}},	//   rësu, dsy_, ापरो, تىسك, 
   {{0x7bd98e59,0x44300b1d,0xb5a58e5a,0x7ce401a9}},	//   motu, esy_, брай, mаrq, 
   {{0x7ddc0036,0xf8bc00e4,0x00000000,0x00000000}},	//   mëss, haéi_, --, --, 
   {{0x399804c4,0x7ddd8e5b,0xe4502303,0x44318e5c}},	// [2a030] _dëst_, qësu, فضل_, gsy_, 
   {{0x7bd98e5d,0x00000000,0x00000000,0x00000000}},	//   notu, --, --, --, 
   {{0x7bd80607,0x3e4c00ac,0x55580410,0x7ddc01c7}},	//   iotu, _xətt_, _каня_, nëss, 
   {{0x4430789d,0x76440796,0xb9e0001f,0x7bd98e5e}},	//   bsy_, mujy, _የኛ_, hotu, 
   {{0x7bd98e5f,0x7ddc0036,0xa6c40150,0xb64001ec}},	//   kotu, hëss, _وقۋى, _ﺎﻉ_, 
   {{0xf8bc0c6a,0xa2b80ad7,0x7bd81f39,0xb9f00023}},	//   raéh_, ्पश्, jotu, _ሑጻ_, 
   {{0x7bd98e60,0xdb080036,0x59d89a09,0x00000000}},	//   dotu, chdé, णकार, --, 
   {{0xa2b98e61,0xd0d406bb,0x399804e6,0x8db402d5}},	//   ्पर्, _добъ, _mëss_, ўскі, 
   {{0x7bd98e62,0xf3fc00e4,0x77a800ac,0xaf48004b}},	//   fotu, _asãi_, _müxb, _مشال_, 
   {{0x76451645,0x680001e1,0x7bd8bfb6,0x2098013d}},	//   kujy, _májì, gotu, _укуы_, 
   {{0x399801c7,0x68000241,0x49b82a9f,0x49c98e63}},	//   _nëss_, _lájì, لاحد_, илон_, 
   {{0x443009a5,0xdd9400c7,0x7e7c005c,0x8274010f}},	//   ysy_, _нахы, æppe, קערע_, 
   {{0x7bd98e64,0xc7640aaf,0x7ddc0036,0x00000000}},	//   botu, ياسى, rëst, --, 
   {{0x6b80174e,0x39980036,0x29c80228,0xc03c0023}},	//   _unng, _bëss_, ртүү_, _ኣይበለ, 
   {{0x44318e65,0x00000000,0x00000000,0x00000000}},	//   wsy_, --, --, --, 
   {{0x4430325f,0x39980221,0x5044001f,0x00000000}},	//   tsy_, _dëss_, _የግንባ, --, 
   {{0x833401b9,0x44258e66,0xe83801f7,0x00000000}},	// [2a040] قراض, èo_, _ازبڪ_, --, 
   {{0x44318e67,0x76440223,0x68e58e68,0x438402ef}},	//   rsy_, bujy, _iyid, غلاق, 
   {{0x443007d5,0x76440097,0x82698e69,0x399804e6}},	//   ssy_, cujy, раев_, _gëss_, 
   {{0x00e40d5c,0x7bd98e6a,0xadc000c7,0x6d4c00a3}},	//   ожен, zotu, _peẽm, òcal, 
   {{0x7bd80451,0x8c3c0209,0x00000000,0x00000000}},	//   yotu, nyşd, --, --, 
   {{0x68e4019f,0x7bd801c4,0xd24c0133,0x6fb0009a}},	//   _myid, xotu, _ڕۆم_, ومنا, 
   {{0x7bd98e6b,0x24540724,0xf8bc004a,0x6d440024}},	//   votu, läm_, mbée_, ėjan, 
   {{0x68e4036b,0xb4d8004e,0x1d3400a7,0x98a8012d}},	//   _oyid, _icàr, чния, _udać_, 
   {{0x7bd98e6c,0x7ddc0221,0x68e4032b,0x24558e6d}},	//   totu, wëss, _nyid, näm_, 
   {{0x1ab40150,0x00000000,0x00000000,0x00000000}},	//   збоя, --, --, --, 
   {{0x7bd98e6e,0xddc801fa,0x2454349e,0x00000000}},	//   rotu, _irdž, häm_, --, 
   {{0x7bd8419d,0x399801c7,0x62880129,0x7ddc01c7}},	//   sotu, _rëss_, _àdou, rëss, 
   {{0x7644af78,0x8c3c010e,0x245400a2,0x00000000}},	//   wujy, gyşd, jäm_, --, 
   {{0x6c8004fb,0x2454014a,0x76458e6f,0xdb080793}},	//   _آلوم, däm_, tujy, nidü, 
   {{0x68e58e70,0x00000000,0x00000000,0x00000000}},	//   _eyid, --, --, --, 
   {{0x63bc035a,0x1fd0009e,0x58d4009d,0x0ae8009f}},	//   _amrn, িতিস, _нойт, _ارهي_, 
   {{0x68e4013b,0x5fbc37e3,0xdb080205,0x24540139}},	// [2a050] _gyid, ्चाल, kidü, gäm_, 
   {{0xd37000c6,0x9f4c004e,0xdb080789,0x28c91769}},	//   عها_, _midó_, midó, रपरि, 
   {{0x211801f2,0x9258005b,0x660801e4,0xf2c4009d}},	//   _ịtụl, сает_, ŭdkr, цсан, 
   {{0xe1f05019,0xb74401d5,0x3f9801a8,0x75800214}},	//   نسن_, _ائکو, öpun_, _تیرم, 
   {{0x7f780131,0x6448002b,0xc0c0104e,0x00000000}},	//   ﻠﻠﯩﻲ_, _ādig, нәфи, --, 
   {{0xb4d4cc83,0x00000000,0x00000000,0x00000000}},	//   िथी_, --, --, --, 
   {{0xa91001e4,0x00000000,0x00000000,0x00000000}},	//   _jaɾc, --, --, --, 
   {{0x9f4c004e,0xfc3c0092,0xa2d40e49,0x00000000}},	//   _bidó_, _ተነጋግ, _बुट्, --, 
   {{0xcc340597,0x5f7400ec,0x00000000,0x00000000}},	//   أربع, _ڊالر, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x0c040014,0x68e40108,0xc0e40092,0x37c000eb}},	//   _کوتُ, _syid, ሜይል_, োতার, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d5800ec,0x8b24010a,0xcc8801e2,0x00000000}},	//   mfua, _едле, _دنشه_, --, 
   {{0xa2d4012c,0x2454007c,0x00000000,0x00000000}},	//   _बुझ्, väm_, --, --, 
   {{0x6d5801c8,0xf1d829d9,0x23480014,0x00000000}},	//   ofua, यकान, ۪سری_, --, 
   {{0xdce0166a,0xf53c2d8b,0x00000000,0x00000000}},	//   lemā, _flåm_, --, --, 
   {{0xb4618e71,0x6d58cb5e,0x68e58e72,0xb4d801ab}},	// [2a060] нктл, ifua, _uyid, _scàr, 
   {{0x24553c88,0x61d400dc,0xdce03a2f,0x67e0007c}},	//   räm_, धक्ष, nemā, röjs, 
   {{0xf8bc06af,0x38c80345,0x00000000,0x00000000}},	//   rbée_, _نایی_, --, --, 
   {{0x80d809bd,0xddc80558,0xa1580212,0x00000000}},	//   _বৃষ্, _srdž, іалу_, --, 
   {{0x00d80efb,0x00000000,0x00000000,0x00000000}},	//   حبات_, --, --, --, 
   {{0x63bc01a9,0x64440009,0xaf30c947,0x48fc00cd}},	//   _umrn, mrii, ىرىت, रेयो_, 
   {{0xdd940510,0x9f4c01e1,0x6d580042,0x644435f8}},	//   дайы, _bidò_, ffua, lrii, 
   {{0x77a803be,0x52b00075,0x00000000,0x00000000}},	//   _müxa, _جەمئ, --, --, 
   {{0x64458e73,0x7f4400f3,0x00000000,0x00000000}},	//   nrii, _неаж, --, --, 
   {{0x644400b0,0x88e40150,0xdce000ef,0x00000000}},	//   irii, _ﺍﺭﺘﻀ, gemā, --, 
   {{0x644401d9,0x68e800ac,0x8c3c0432,0x00000000}},	//   hrii, əddi, gyşb, --, 
   {{0xe3c402a6,0x64458e74,0x00000000,0x00000000}},	//   ্তিব, krii, --, --, 
   {{0x80a00490,0x6444003e,0x4c7000fb,0x6ce00150}},	//   _कॅमे, jrii, _аҫыр, _піше, 
   {{0x64440429,0x00000000,0x00000000,0x00000000}},	//   drii, --, --, --, 
   {{0xe3c409bd,0x6a100597,0x64458df1,0x67d4014b}},	//   ্তাব, _كبير, erii, хору, 
   {{0x65958e75,0x64458e76,0x00000000,0x00000000}},	//   насу, frii, --, --, 
   {{0x53998e77,0x64440014,0xb4d44709,0x5fdc1157}},	// [2a070] овая_, grii, िथे_, मकाल, 
   {{0xc7646abd,0x00000000,0x00000000,0x00000000}},	//   _قاپى, --, --, --, 
   {{0xd1740aeb,0x64458e78,0x00000000,0x00000000}},	//   дылы, arii, --, --, 
   {{0x64458e79,0x77740ba7,0xb0318e7a,0x00000000}},	//   brii, _haxx, емдә, --, 
   {{0x3ce40218,0x777481f1,0x6444058a,0x00000000}},	//   _nyov_, _kaxx, crii, --, 
   {{0xedf437cc,0x6d440006,0x24180ebe,0x64580356}},	//   ुद्ध_, ėjam, _хоры_, ăvit, 
   {{0x77758e7b,0x3330037e,0x9f4c026c,0x6d5805b1}},	//   _maxx, maxx_, _pidò_, tfua, 
   {{0x7774022f,0x6d598e7c,0x33300135,0x3f100166}},	//   _laxx, ufua, laxx_, ндәс, 
   {{0x752c0034,0xdce0005f,0xd6d8033f,0x6d58003a}},	//   _mecz, temā, ęły_, rfua, 
   {{0x752c6b0f,0x4fc00a52,0x77740135,0xa0740166}},	//   _lecz, _جەتە, _naxx, _ягуч, 
   {{0xc3300375,0x00000000,0x00000000,0x00000000}},	//   כוי_, --, --, --, 
   {{0x64458e7d,0x5dd800d4,0x00000000,0x00000000}},	//   yrii, _ефір_, --, --, 
   {{0x77758e7e,0xace810de,0x64440067,0x0134011a}},	//   _baxx, _ارال_, xrii, וררת_, 
   {{0x77740429,0xf428025c,0xdb08004e,0x644564ba}},	//   _caxx, _སྦེད_, sidò, vrii, 
   {{0x7774031c,0x8cc4033f,0x752c012d,0x64440009}},	//   _daxx, ापको, _becz, wrii, 
   {{0x64458e7f,0x959800f7,0x7aec0112,0x85e80212}},	//   trii, птуу_, übte, ідав_, 
   {{0x3ce40070,0x64458e80,0x7774fe56,0x3cf8008f}},	// [2a080] _xyov_, urii, _faxx, ַלענ, 
   {{0x64458e81,0x76580054,0x77740327,0x00000000}},	//   rrii, ńuya, _gaxx, --, 
   {{0xb4d801e1,0x64458e82,0x42550326,0x00000000}},	//   _adàd, srii, ьтат, --, 
   {{0xdb0801b8,0x290401fa,0xa1140137,0x00000000}},	//   _älöp, žmau_, روتت, --, 
   {{0x77740548,0x6444058a,0x64840139,0x00000000}},	//   _yaxx, qrii, _яңаб, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd2980220,0x752c014b,0xf41c0036,0x52640150}},	//   _етті_, _yecz, _präg_, _перғ, 
   {{0x5c758e83,0x23780194,0xdd9000c6,0x64401445}},	//   елит, _harj_, اوة_, _åmis, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbfa801d9,0x7ac58e84,0x7b640166,0x00000000}},	//   _بارٕ_, дсме, фтие, --, 
   {{0x77758e85,0xf8bc003e,0xceac1914,0x00000000}},	//   _raxx, jaér_, _сә_, --, 
   {{0x77740429,0x23780100,0x00000000,0x00000000}},	//   _saxx, _larj_, --, --, 
   {{0x752c012d,0x00000000,0x00000000,0x00000000}},	//   _recz, --, --, --, 
   {{0x752c0c86,0x77740ba7,0x00000000,0x00000000}},	//   _secz, _qaxx, --, --, 
   {{0x94180213,0x77740166,0x6a800798,0x00000000}},	//   əyəm_, _vaxx, _алја, --, 
   {{0xf428031c,0x6aa400b5,0x77740009,0xa9c4c03b}},	//   _སྦུད_, øjfe, _waxx, _аськ, 
   {{0x0484053f,0x7774fa36,0x245800c9,0xf8bc00d5}},	// [2a090] нәри_, _taxx, мать_, raés_, 
   {{0xdeec0023,0xa3d44ea0,0x9f580248,0x00000000}},	//   ህርን_, воуч, _òrè_, --, 
   {{0xf8bc0c6a,0x752c012d,0x3330025c,0x00000000}},	//   paés_, _tecz, raxx_, --, 
   {{0x6458054e,0xa184013d,0x00000000,0x00000000}},	//   ăvir, кычл, --, --, 
   {{0x337000c7,0xa5040026,0x8c3c00a2,0xb06800ae}},	//   _иҳар, _аярл, kyşa, تصال_, 
   {{0xf41c0598,0x00000000,0x00000000,0x00000000}},	//   _itä_, --, --, --, 
   {{0x12ac00d1,0xe21400db,0x8c3c00a2,0x00000000}},	//   ﺳﻜﻪﺭ, _амсы, dyşa, --, 
   {{0xf040040b,0xf41c01e6,0xe1f01d93,0xef1c03b9}},	//   _لٹری, _träd_, _نسق_, _şüd_, 
   {{0xcc8804fb,0x656001e3,0xa1580166,0x00000000}},	//   سنده_, _ömhe, _юату_, --, 
   {{0x5ff42f09,0x26fc00fe,0x00000000,0x00000000}},	//   _азуу, ্ৰটো_, --, --, 
   {{0xf41c005b,0x5f94022e,0x00000000,0x00000000}},	//   _ltä_, _шифт, --, --, 
   {{0xe9841955,0x5d84007b,0xac8001a9,0x00000000}},	//   тқин, _للمل, _аҳил, --, 
   {{0x2905573c,0x3f940014,0x00000000,0x00000000}},	//   äma_, _تھۆد_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x5804678d,0xb4d8002e,0x310c0950,0x00000000}},	//   торғ, _ndàb, िशाः_, --, 
   {{0xf8bc0077,0x629801b8,0x237803e0,0x395c000d}},	//   mbén_, ävom, _sarj_, õust_, 
   {{0xb4d801e1,0xe87c00a2,0x76440363,0x0324033a}},	// [2a0a0] _adàb, _düţü, arjy, едзн, 
   {{0x9324129e,0x00000000,0x00000000,0x00000000}},	//   نرمن, --, --, --, 
   {{0x81440597,0x26dc00c7,0xf41c0958,0x9f580241}},	//   فنان, _âvo_, _etä_, _òré_, 
   {{0x2574113e,0x4b0000cc,0x00000000,0x00000000}},	//   _جۇرس, _এভাগ_, --, --, 
   {{0x2378022e,0xd2000166,0x00000000,0x00000000}},	//   _tarj_, рүтк, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x41281b10,0x24818e86,0xdb0801b8,0x76402dba}},	//   _ново_, lvim_, lidö, _ånyt, 
   {{0x24800960,0x91f40139,0x84740092,0x00000000}},	//   ovim_, _ачуч, _የራስን_, --, 
   {{0x8c3c0209,0xdb0801b8,0x5154041b,0xff507aaf}},	//   tyşa, nidö, _штру, _مخا_, 
   {{0x5b1400a7,0xafe02e73,0x1008007b,0x00000000}},	//   ъмот, _боул, _قتلى_, --, 
   {{0x2a6401f5,0x6fb00a8e,0xbae401c0,0x6e401188}},	//   _cpnb_, _حملا, эций, _бехз, 
   {{0x2480041a,0x3f9d8e87,0xdb098e88,0x00000000}},	//   kvim_, _hotu_, kidö, --, 
   {{0x3f9d8e89,0xc03c0023,0x00000000,0x00000000}},	//   _kotu_, _ኣይሃል, --, --, 
   {{0x3f9c0de2,0xeb9402e8,0xa2b800cd,0x00000000}},	//   _jotu_, _пич_, ्पञ्, --, 
   {{0xf41d8e8a,0x80d80f22,0xdb0801e7,0x00000000}},	//   _stä_, বেচ্, bhdá, --, 
   {{0x3f9d8e8b,0xdb0801b8,0x1dd0194b,0x00000000}},	//   _lotu_, fidö, तचित, --, 
   {{0x937802de,0xe9d000aa,0x3f9c022f,0xdb08014a}},	// [2a0b0] мбат_, _دغو_, _ootu_, gidö, 
   {{0x3f9d8e8c,0xf7280276,0x6d440153,0x00000000}},	//   _notu_, _эций_, ėjai, --, 
   {{0x799c0b6f,0x00000000,0x00000000,0x00000000}},	//   _koqw, --, --, --, 
   {{0x7ae80023,0x799c014f,0x59e004e4,0xf41c01f4}},	//   _myft, _joqw, नविर, _ttä_, 
   {{0x7ae8b345,0x3f9d8e8d,0x799c014f,0x8ff8158b}},	//   _lyft, _botu_, _moqw, ورتر_, 
   {{0xb1903786,0x09a80154,0x00000000,0x00000000}},	//   _өлгә, খোপা, --, --, 
   {{0x3f9c00de,0xa3d40408,0x5c1400c7,0x00000000}},	//   _dotu_, _сорч, қьыу, --, 
   {{0x0d850dff,0x799c009a,0x06c40154,0x00000000}},	//   тлин, _noqw, _এডমি, --, 
   {{0x3f9d6a13,0x2a640ac5,0x2d880205,0x00000000}},	//   _fotu_, _spnb_, ıce_, --, 
   {{0x09c82413,0x3b80f026,0xa91001e4,0x5f740451}},	//   ाच्य, альг, _paɾo, _مامر, 
   {{0x06c42158,0x2fc58e8e,0x799c047e,0x0d2000f7}},	//   _শুনি, ming_, _boqw, _күйү, 
   {{0xaca0063f,0x8474001f,0xf8bc0005,0x23a40267}},	//   _amụk, _የራሱን_, rbén_, _höjt_, 
   {{0x799c0455,0x2fc58e8f,0x4c9520fe,0x7bc400e4}},	//   _doqw, oing_, _шидс, ĩkur, 
   {{0x7ae80b21,0xdb0829ef,0xf8bc003e,0x0b44004e}},	//   _fyft, vidö, mbél_, _рнкн, 
   {{0x2fc58e90,0xe87c010e,0x48ec012c,0x49b800f2}},	//   iing_, _düšü, _घरको_, _يابد_, 
   {{0xdb080793,0x888401d5,0x20500240,0x00000000}},	//   tidö, _алиж, _ዘፍቀረ, --, 
   {{0x2fc58e91,0x69c58e92,0x00000000,0x00000000}},	// [2a0c0] king_, _imie, --, --, 
   {{0x69c40327,0x799c009a,0xdb0801b8,0x24800356}},	//   _hmie, _zoqw, ridö, rvim_, 
   {{0x69c40003,0x799c009a,0x3f9d8e93,0x439401e0}},	//   _kmie, _yoqw, _rotu_, наҡс, 
   {{0x00c98e94,0x2fc58e95,0xba98011a,0x00000000}},	//   млек_, eing_, וסעי, --, 
   {{0x2fc58e96,0x3f9d14c3,0x69c40134,0x248048d3}},	//   fing_, _potu_, _mmie, qvim_, 
   {{0x2fc58e97,0x44218e98,0x3f9d8e99,0xdb2403cd}},	//   ging_, _itk_, _qotu_, _åsør, 
   {{0x69c58e9a,0x3f9d8e9b,0x9d180137,0x0e4400c7}},	//   _omie, _votu_, нойт_, гьыҭ, 
   {{0x44218e9c,0x3f9c016b,0xd17401e0,0xef141a98}},	//   _ktk_, _wotu_, _йыуы, нмә_, 
   {{0x2fc58e9d,0x7ae98e9e,0x3f9d8e9f,0xc0e40022}},	//   bing_, _syft, _totu_, _роак, 
   {{0x2fc40fa9,0x69c58ea0,0xbea40588,0xef8007b5}},	//   cing_, _amie, _иазк, _клуп, 
   {{0x799c0477,0x23a40267,0x200c058a,0xbea80592}},	//   _poqw, _höjs_, _iidi_, _تهان_, 
   {{0xbc680879,0x200d8ea1,0x79a4ed5a,0x7ae805e4}},	//   _يمان_, _hidi_, трое, _vyft, 
   {{0x200d8ea2,0x9f4c011f,0x69c40036,0x44200208}},	//   _kidi_, _fidô_, _dmie, _ntk_, 
   {{0x7c214873,0x69c58ea3,0x799d39df,0xfa84009b}},	//   _itor, _emie, _woqw, _аћим, 
   {{0xf8bc0a16,0x44200b7e,0xbbdc76f8,0xdb0800d8}},	//   mbém_, _atk_, नकीक, tidõ, 
   {{0x7c218ea4,0x99554a73,0x2fc58ea5,0x200c012c}},	//   _ktor, _скиц, zing_, _lidi_, 
   {{0x2fc4025f,0x80a00490,0x442001ef,0x69a801f9}},	// [2a0d0] ying_, _कॅले, _ctk_, _चवती, 
   {{0x69c43f8e,0x200c0134,0x7c20009f,0x2fc58ea6}},	//   _zmie, _nidi_, _mtor, xing_, 
   {{0x2fc58ea7,0xf53c00b5,0xe2c800f1,0x69c40139}},	//   ving_, _blåt_, پونو_, _ymie, 
   {{0xc69030fb,0x7c218ea8,0x2fc58ea9,0x22840228}},	//   _האט_, _otor, wing_, шууг, 
   {{0x2fc58eaa,0x200d8eab,0x8c3c0209,0x7c218eac}},	//   ting_, _bidi_, gyşl, _ntor, 
   {{0x2fc405e4,0x200c0014,0x004400f1,0x661802d2}},	//   uing_, _cidi_, ایلي_, _þakí, 
   {{0x7c218ead,0x2294bcaa,0xf53c01bf,0xa29452c4}},	//   _ator, _киря, _flåt_, _карі, 
   {{0x200d8eae,0xf99c02e2,0xcdf4013d,0x00000000}},	//   _eidi_, nmèd_, ычлы, --, 
   {{0x2fc58eaf,0xd010cf73,0x200d8eb0,0x7c20003a}},	//   ping_, _طلا_, _fidi_, _ctor, 
   {{0x69c58eb1,0x200d8eb2,0xaca002e3,0xeea80b7e}},	//   _smie, _gidi_, _ntụm, _отек_, 
   {{0x7c218eb3,0xdb18005c,0x00000000,0x00000000}},	//   _etor, _omvæ, --, --, 
   {{0xaca000b4,0x200c01f7,0x7c20022e,0x6298005b}},	//   _atụm, _zidi_, _ftor, ävoi, 
   {{0x2d8d8eb4,0xbab001d5,0x69c40419,0x00000000}},	//   _inge_, لمیب, _vmie, --, 
   {{0x44218eb5,0xbccc00d7,0x00000000,0x00000000}},	//   _rtk_, ššák, --, --, 
   {{0x44218eb6,0x69c4003d,0xbb500137,0x36641341}},	//   _stk_, _tmie, _انىب, ларо_, 
   {{0x69c58eb7,0xaca0063f,0x7c20295b,0xc724009d}},	//   _umie, _njịk, _ytor, _өдий, 
   {{0x07a400d8,0x8c3c00a2,0x00000000,0x00000000}},	// [2a0e0] _бапн, kyşm, --, --, 
   {{0x8894035b,0xf53c0250,0x00000000,0x00000000}},	//   _аиҩх, _blås_, --, --, 
   {{0x5ea80183,0x200d8eb8,0x2d8c07a9,0xf53c0267}},	//   _কেনে, _ridi_, _onge_, _plåt_, 
   {{0x0134db35,0x44218eb9,0x00000000,0x00000000}},	//   اعاد, _ttk_, --, --, 
   {{0x442015a5,0x6564136f,0xd1743db0,0x200c00af}},	//   _utk_, mfih, рыхы, _pidi_, 
   {{0x2d8d8eba,0x200c0429,0xc60002e3,0xf41c007f}},	//   _ange_, _qidi_, _ọchọ, _krän_, 
   {{0x52758ebb,0xcfa8158b,0x1ee80133,0x9f580248}},	//   _куту, خانم_, کوژی_, _òrí_, 
   {{0x200d7f52,0xdef802dd,0x7c200139,0x6564015d}},	//   _widi_, нық_, _ptor, nfih, 
   {{0x200d8ebc,0xf53c2d62,0x600800c7,0xaec02cc8}},	//   _tidi_, _klår_, _амаҭ_, ибәл, 
   {{0x2d8d8ebd,0x200c0381,0xacf40032,0xf41c010e}},	//   _enge_, _uidi_, ыныу_, _orän_, 
   {{0x7c200034,0xb4d81bce,0x999800bc,0xfbe00022}},	//   _wtor, _ndàn, érů_, _қәиҭ, 
   {{0x05c4012d,0xdce00210,0x00000000,0x00000000}},	//   रोमब, zemę, --, --, 
   {{0x3dc4058a,0xf8bc0098,0x6bd007d6,0xd7f40b83}},	//   _imow_, mbék_, شتیر, измы, 
   {{0x79a401ec,0x06c400eb,0x69c800e4,0x00000000}},	//   _әрке, _এড়ি, ũjep, --, 
   {{0x8b643ef3,0x163400a7,0x656401a8,0x00000000}},	//   _خانم, ребя, ffih, --, 
   {{0xa9680063,0x00000000,0x00000000,0x00000000}},	//   _бића_, --, --, --, 
   {{0xf53d8ebe,0x5ea80183,0x7e780175,0xf41c005b}},	// [2a0f0] _slås_, _কেমে, _lstp, _erän_, 
   {{0x7e780c8c,0xf41c007c,0x00000000,0x00000000}},	//   _ostp, _frän_, --, --, 
   {{0x56958ebf,0x925834d8,0xfbd40729,0xa3c40034}},	//   _тант, тает_, _হঠাত, एफ़_, 
   {{0xdb1806ea,0xd4c40137,0xb9f80092,0x2a54010f}},	//   _umvæ, _көзк, _ፅኑ_, רבאן_, 
   {{0x4f94220f,0x7e78127b,0xf53c01bf,0x414401ec}},	//   ирку, _astp, _flår_, рдің, 
   {{0x1f64346d,0x98b80205,0x00000000,0x00000000}},	//   йкім, nesı_, --, --, 
   {{0xe2f80046,0x00000000,0x00000000,0x00000000}},	//   _бері_, --, --, --, 
   {{0x2ab80ca8,0x3ed00137,0x3e600248,0x00000000}},	//   _lábé_, تقىر, _ọtí_, --, 
   {{0xdb18049f,0x8c4407d8,0x7e796349,0x2d800118}},	//   _omvä, шепе, _estp, ěje_, 
   {{0x317c06be,0x7d04009d,0xca2c02dd,0x00000000}},	//   _hauz_, шныг_, _ﺩﻩﺭ_, --, 
   {{0x317d8ec0,0x6448002b,0x00000000,0x00000000}},	//   _kauz_, _ādim, --, --, 
   {{0x2d8c39c2,0x00000000,0x00000000,0x00000000}},	//   _unge_, --, --, --, 
   {{0x317c0369,0xac240276,0x98b80166,0x00000000}},	//   _mauz_, _сфек, fesı_, --, 
   {{0xa91001e4,0x317c005a,0xdd980022,0x15b80220}},	//   _maɾi, _lauz_, _ашә_, қысы_, 
   {{0x45346ecf,0x65b801ef,0x8c4401ee,0x00000000}},	//   ихат, _líhe, _сеһе, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x34a400f5,0x00000000,0x00000000,0x00000000}},	// [2a100] авто_, --, --, --, 
   {{0x25f401f9,0x09c4000d,0x00000000,0x00000000}},	//   ंतही_, _लगुय, --, --, 
   {{0x673d8ec1,0xb6a18ec2,0x114002d3,0x65640099}},	//   marj, _диэл, _ከምዝሓ, pfih, 
   {{0x673d8ec3,0xc0c86aa4,0xd17406d3,0xcf300023}},	//   larj, куле_, йычы, _ጽሕፈታ, 
   {{0x66058ec4,0x09c004c5,0x261c0005,0xc0580276}},	//   mmik, োকপা, _hío_, трец_, 
   {{0x673d8ec5,0x66058ec6,0xd1740220,0x3e6801c0}},	//   narj, lmik, _қысы, вшин_, 
   {{0x3240ae78,0xa28401d9,0xdb10003e,0xdb08003b}},	//   _мерг, _دیاو, _éfém, _åløp, 
   {{0x261c04cf,0x317c0007,0x66058ec7,0x3a3c0051}},	//   _mío_, _gauz_, nmik, vstp_, 
   {{0x261c3eba,0xa91001e4,0xb300031c,0x66040821}},	//   _lío_, _faɾi, _མཛོང_, imik, 
   {{0x673d8ec8,0xdb180267,0xdb080332,0x05c40bae}},	//   jarj, _omvå, mhdú, रोतब, 
   {{0x673d8ec9,0xb4d80109,0xe7cc015b,0x6d4c01e7}},	//   darj, _adàl, লকাঠ, ócac, 
   {{0x673c002d,0x2ab801e1,0x66040937,0x5ea800cc}},	//   earj, _sábé_, jmik, _কেথে, 
   {{0xf770414d,0x673d8eca,0x2ab801e1,0x00000000}},	//   ياس_, farj, _pábé_, --, 
   {{0x673d8ecb,0x261c0407,0x660425c6,0x81bc009e}},	//   garj, _bío_, emik, ীকি_, 
   {{0xabf8011a,0x6d500356,0x5ea800fe,0x7b1401af}},	//   _שהור, şeaţ, _কেতে, _йоҙр_, 
   {{0x25d8010b,0x660403b2,0x00000000,0x00000000}},	//   амсы_, gmik, --, --, 
   {{0x81bc045e,0x317c0369,0x673d8ecc,0xf41c01e3}},	// [2a110] ীকা_, _rauz_, barj, _gräl_, 
   {{0x261c1709,0x673d8ecd,0x660426bb,0xe4e40006}},	//   _fío_, carj, amik, цісн, 
   {{0x261c0051,0x00000000,0x00000000,0x00000000}},	//   _gío_, --, --, --, 
   {{0x48fc0316,0xf99c033b,0x94d400d8,0x00000000}},	//   रेको_, njè_, _гомц, --, 
   {{0xe0d16cd6,0xf8bc0129,0xf41c0267,0xa1580408}},	//   وزه_, nzé_, _kräm_, рачу_, 
   {{0xf99c0268,0xc0c00092,0x00000000,0x00000000}},	//   hjè_, _ድካም_, --, --, 
   {{0x3208da12,0x00000000,0x00000000,0x00000000}},	//   _ахан_, --, --, --, 
   {{0x673d8ece,0x3d080248,0x00000000,0x00000000}},	//   zarj, _ẹwa_, --, --, 
   {{0xdb08000f,0xf8bc0098,0xf99c02bd,0x69c8007f}},	//   chdú, ncéd_, djè_, èjem, 
   {{0xb4d80de2,0x66058ecf,0x5f4400ae,0x00000000}},	//   _ndàm, zmik, _ونقل, --, 
   {{0x673d8ed0,0x66040bf1,0x6b7406be,0x09e400db}},	//   varj, ymik, _ağgü, йоон, 
   {{0x261c1b73,0xdd9517ea,0x26cc0419,0x673d8ed1}},	//   _río_, _махы, údom_, warj, 
   {{0x673d8ed2,0xa91001e4,0x2d9c009f,0xcb6834ac}},	//   tarj, _laɾv, mjue_, _бале_, 
   {{0x261c097a,0x660400b5,0x00000000,0x00000000}},	//   _pío_, wmik, --, --, 
   {{0x66058ed3,0x673d8ed4,0x4df8010f,0x00000000}},	//   tmik, rarj, ָפּא, --, 
   {{0x673d8ed5,0x66058ed6,0xf99c0ba1,0x7c2401e4}},	//   sarj, umik, rmèc_, ŭkre, 
   {{0x673d8ed7,0x436805f5,0x00000000,0x00000000}},	// [2a120] parj, лаан_, --, --, 
   {{0x261c8694,0x64a402dd,0x673c0175,0xd3c400d1}},	//   _tío_, баға, qarj, يتلى, 
   {{0x9f4c0016,0x00000000,0x00000000,0x00000000}},	//   _đoàn_, --, --, --, 
   {{0xc0440736,0x04e400fe,0x81380066,0x00000000}},	//   مختو, _কণীৰ_, اساز_, --, 
   {{0x2d9c1368,0xb6d00150,0x00000000,0x00000000}},	//   djue_, _وقۋع, --, --, 
   {{0xd9a40574,0x74101ec7,0xa304010b,0x25a00219}},	//   _ऑक्ट, _روفا, _дүзе, ljil_, 
   {{0xf8bd8ed8,0xf7700375,0x00000000,0x00000000}},	//   zzé_, פקה_, --, --, 
   {{0x25a18ed9,0x5d5413d6,0x2d9c036e,0xdb1402d2}},	//   njil_, цкит, gjue_, _ábúe, 
   {{0x5bb82950,0xfb84760c,0x00000000,0x00000000}},	//   илия_, бынн, --, --, 
   {{0xf8bc20ef,0xbf6401e2,0x00000000,0x00000000}},	//   ncée_, _ددرو, --, --, 
   {{0x77a803be,0x25a0020b,0xf41c03d4,0x6db8012d}},	//   _müxt, kjil_, _পিছৰ_, właś, 
   {{0x0eb86215,0xada06f42,0x25a18eda,0x6da06031}},	//   _тууы_, _нахл, jjil_, _ниха, 
   {{0xf99c067c,0x25a00066,0x3eac0267,0x00000000}},	//   gmèa_, djil_, lyft_, --, 
   {{0xda3400a8,0x9b942377,0x00000000,0x00000000}},	//   _декы, _фикц, --, --, 
   {{0xcbc457fb,0xf9b001f0,0x00000000,0x00000000}},	//   _بزني, _накӯ, --, --, 
   {{0x58d400a7,0xf99096b4,0x03f000cc,0x00000000}},	//   _мойт, _ربع_, _অংগী_, --, 
   {{0x64a40a16,0xbb3004a2,0xa5f80114,0x77a803b9}},	// [2a130] паѓа, ﺭﮔﻪ_, сету_, _süxu, 
   {{0xba040092,0x00000000,0x00000000,0x00000000}},	//   _ለማ_, --, --, --, 
   {{0xf41c007c,0x61440240,0x00000000,0x00000000}},	//   _kräk_, _ከምዝባ, --, --, 
   {{0x9f4c0016,0x50f41d0f,0xd3a00220,0x00000000}},	//   _đoán_, озет, _ﺍﺷﯩﻖ_, --, 
   {{0x7bc80944,0x8fa42e3f,0xcd400150,0x00000000}},	//   _omfu, жале, _ﺭﺩﯨﯔ_, --, 
   {{0xa8580375,0xd00801df,0xf48401f0,0x09c40118}},	//   מידה_, шеле_, _куҳн, _लग्य, 
   {{0x9988068f,0x8e54d5d9,0x9e6400be,0x00000000}},	//   _miał_, іткі, كاين, --, 
   {{0x0c24cc40,0x7c6c0020,0x7bc98edb,0xb4d8002e}},	//   омин, _ጠቁመው_, _amfu, _ndàk, 
   {{0x82c4031c,0x8d746b18,0xdc28030f,0x00000000}},	//   _གཟོའ, ماکا, یسیه_, --, 
   {{0x9f048d3c,0x2cbc030a,0x80a001f9,0x00000000}},	//   _کومو, rzud_, _कॅटे, --, 
   {{0x4ed5692e,0x9e2400f7,0x00000000,0x00000000}},	//   _بقاء, _فىلو, --, --, 
   {{0x7bc98edc,0x4c94010b,0x00000000,0x00000000}},	//   _emfu, _миес, --, --, 
   {{0x6d58016b,0xf8bc0036,0x00000000,0x00000000}},	//   mgua, ycée_, --, --, 
   {{0x6d598edd,0x15b80184,0xd5b001fb,0x3ec400c7}},	//   lgua, ҡыты_, ến_, _усӡб, 
   {{0x6b818ede,0xf41c0036,0x48fc00e1,0x00000000}},	//   _iang, _fräk_, रेजो_, --, 
   {{0x6d598edf,0x05640006,0x00000000,0x00000000}},	//   ngua, ўван, --, --, 
   {{0x6b8106cd,0x65b80166,0x7bc8015d,0x6d5800c7}},	// [2a140] _kang, _cíha, _ymfu, igua, 
   {{0x6b802c3e,0x430800b2,0xf7701178,0xf99c007f}},	//   _jang, ليءَ_, _قاپ_, nmèn_, 
   {{0xf8bc07ea,0x6d5802d0,0x00000000,0x00000000}},	//   rcée_, kgua, --, --, 
   {{0xc4340166,0xdfd000f1,0x00000000,0x00000000}},	//   _мэгъ, کيت_, --, --, 
   {{0x6b818ee0,0x6d580522,0x00d94559,0x06900131}},	//   _oang, dgua, جبات_, _ﻟﯧﻜﯩ, 
   {{0x64458ee1,0x6d4d8ee2,0xf8bc003e,0xfe480798}},	//   msii, ócan, mbét_, аџии_, 
   {{0x64458ee3,0xe234030f,0xe1880166,0x84f80073}},	//   lsii, _رکاب, _гөле_, ्धवट_, 
   {{0x6b818ee4,0x64458ee5,0x6d587ffa,0xbda41291}},	//   _aang, osii, ggua, تحتو, 
   {{0x64458ee6,0x00000000,0x00000000,0x00000000}},	//   nsii, --, --, --, 
   {{0x6b818ee7,0x70500502,0x64458ee8,0x6d580194}},	//   _cang, _آنلا, isii, agua, 
   {{0x6b818ee9,0x64440548,0xeb9400d8,0x00000000}},	//   _dang, hsii, циќ_, --, 
   {{0x64458eea,0x6b818eeb,0x5824025c,0x6d5800a3}},	//   ksii, _eang, _འཕྱོ_, cgua, 
   {{0x6b818eec,0x395c005f,0x6444208d,0xcdd8008f}},	//   _fang, ļus_, jsii, _פֿער, 
   {{0x6b818eed,0x7bc8136f,0x644436b7,0x753c0472}},	//   _gang, _umfu, dsii, waqz, 
   {{0x64458eee,0x588400c7,0xb6f400db,0x00000000}},	//   esii, цыҟа, تۉدا_, --, 
   {{0x6b8053dd,0x64458eef,0xa91001e4,0x65958ef0}},	//   _zang, fsii, _paɾt, масу, 
   {{0x6b818ef1,0x582403bd,0x545406bb,0x7bd98ef2}},	// [2a150] _yang, _འཕྲོ_, яват, ontu, 
   {{0x6b818ef3,0x7bd8008c,0x3328009d,0x00000000}},	//   _xang, nntu, рцан_, --, 
   {{0x64458ef4,0x91740276,0x6d58035b,0x00000000}},	//   asii, згец, ygua, --, 
   {{0x64458ef5,0xf07400d1,0xba040092,0xb9e00092}},	//   bsii, жидә_, _ለኛ_, _ከኛ_, 
   {{0x85980302,0x64443396,0xf8bc06af,0x69fc010f}},	//   _השרו, csii, mbés_, בלאק, 
   {{0xf8bc0005,0x8e080116,0x21fc00d7,0x00000000}},	//   lbés_, әнив_, ríha_, --, 
   {{0x6b818ef6,0x5f744630,0x6d58921c,0x63e801e2}},	//   _rang, ظاهر, tgua, _بېلې_, 
   {{0x7bd98ef7,0xd0080032,0xa15929e4,0x65b8013a}},	//   entu, шеһе_, _масу_, _líhn, 
   {{0x6b811a3b,0x6d598ef8,0xf41c0036,0xe800012c}},	//   _pang, rgua, _bräi_, ोगमा_, 
   {{0x6d581570,0x6b818ef9,0xcb6800c6,0x7bd803cd}},	//   sgua, _qang, حمده_, gntu, 
   {{0xddc800da,0xf41c0a40,0xf99c2adc,0x5e5802dd}},	//   žoša, _dräi_, rmèn_, _ۇلەس_, 
   {{0x64443516,0x7bd98efa,0x00000000,0x00000000}},	//   ysii, antu, --, --, 
   {{0xf41c0221,0x7bd801d4,0x644427a2,0x6d4803ac}},	//   _fräi_, bntu, xsii, _idga, 
   {{0x6d4804fb,0x61a89201,0x6b800af5,0x7bd8003a}},	//   _hdga, _कक्ष, _uang, cntu, 
   {{0x64458ab3,0x7aec02fb,0x00000000,0x00000000}},	//   wsii, čité, --, --, 
   {{0x64458efb,0xdb1835f5,0x95980137,0xf99c033b}},	//   tsii, _alvè, отуу_, nmèl_, 
   {{0x43741de1,0x64458efc,0xc7940153,0x00000000}},	// [2a160] зует, usii, _ерны, --, 
   {{0xb9018efd,0x64458efe,0x64a402dd,0x8c3c010e}},	//   _язык, rsii, паға, lyşs, 
   {{0x64458eff,0x6d498f00,0x741000c6,0x42558f01}},	//   ssii, _odga, روما, ятат, 
   {{0xdb180561,0xf8bc065c,0x64458f02,0x00000000}},	//   _elvè, mbér_, psii, --, 
   {{0x7bd80649,0xb9e0001f,0x64440067,0xefb001b9}},	//   yntu, _ከዛ_, qsii, کیلگ, 
   {{0x6d498f03,0x00000000,0x00000000,0x00000000}},	//   _adga, --, --, --, 
   {{0x7bd80218,0x82c40327,0x00000000,0x00000000}},	//   vntu, _གཟིའ, --, --, 
   {{0x29000109,0x7bd8df02,0x515400db,0x7a40013a}},	//   _ozia_, wntu, _отуу, _lítá, 
   {{0x68e401ab,0x23c000cd,0x00000000,0x00000000}},	//   _nxid, _एताद, --, --, 
   {{0x7bd98f04,0x6d484c28,0x00000000,0x00000000}},	//   untu, _edga, --, --, 
   {{0x29018f05,0x21fc0316,0x68e40113,0xd95400f1}},	//   _azia_, ního_, _axid, وندخ, 
   {{0x58d400d4,0x00000000,0x00000000,0x00000000}},	//   домт, --, --, --, 
   {{0xed558f06,0xf74802d3,0x63bc01ab,0xd5b0004d}},	//   _хоч_, _ንምፍላ, _olrn, ếm_, 
   {{0x29001682,0x7b640014,0x1cdc0327,0xf41c01e3}},	//   _dzia_, _راتٕ, _རྨར_, _kräv_, 
   {{0x68e58f07,0x21fc00bc,0xf1bc00d0,0x00000000}},	//   _exid, jího_, úška_, --, 
   {{0x21fc01ef,0x00000000,0x00000000,0x00000000}},	//   dího_, --, --, --, 
   {{0xf8bd8f08,0x68e4009a,0xdb18cb71,0x6fa4015b}},	// [2a170] rbés_, _gxid, _alvé, কোয়ে, 
   {{0x8c40002f,0x644800dc,0x98b8002b,0x00000000}},	//   üßig, _ādit, casā_, --, 
   {{0x27e40030,0xdb0801e7,0x00000000,0x00000000}},	//   émne_, mhdó, --, --, 
   {{0x06c40154,0x00000000,0x00000000,0x00000000}},	//   _শুকি, --, --, --, 
   {{0xfcf40020,0xdb1801ed,0xe87c0205,0xe4e41cd0}},	//   ፈላጊ_, _elvé, _müşü, _зірн, 
   {{0x65b800d2,0xa4c04e7e,0x21fc01ef,0x00000000}},	//   _líhl, lüşü_, bího_, --, 
   {{0x21fc0316,0x00000000,0x00000000,0x00000000}},	//   cího_, --, --, --, 
   {{0xf53c0004,0xf41c0022,0xa4c0029f,0xae0000d1}},	//   _jeå_, _kuä_, nüşü_, رۈشى, 
   {{0xf09c07ea,0xf99c020c,0xc170011a,0x4b5402e8}},	//   _çà_, rmèl_, _בחן_, мънт, 
   {{0xf53c0004,0x0a48a982,0xa3b006e3,0x00000000}},	//   _leå_, озой_, टॉप_, --, 
   {{0x8eb58f09,0x290000dd,0x09e58f0a,0xf41c01e3}},	//   _تماش, _szia_, донн, _gräv_, 
   {{0x6d48019b,0xbdb80014,0xdeec0150,0x7a406791}},	//   _udga, _ونٕچ_, _دۋى_, _sítá, 
   {{0xe87c9e1c,0x21fc012c,0xb4d801ab,0x00000000}},	//   _düşü, zího_, _leàb, --, 
   {{0x1a240014,0xdb0800ae,0x00000000,0x00000000}},	//   بریُ, ghdó, --, --, 
   {{0xf53c0004,0xf41c0421,0x7a4000bc,0x00000000}},	//   _beå_, _auä_, _vítá, --, 
   {{0x290001c4,0x6004004e,0xdce00171,0x00000000}},	//   _tzia_, mòme, cemē, --, 
   {{0x600400f7,0x2900166a,0xc7a4004e,0x7a4001e1}},	// [2a180] lòme, _uzia_, _жипк, _títá, 
   {{0x1cdc0003,0x21fc00bc,0x273400db,0xeff40023}},	//   _རྨས_, tího_, _سۉرس, ፈሻዊ_, 
   {{0x38c80502,0xf8bd8f0b,0x60054847,0x00000000}},	//   _هایی_, ncén_, nòme, --, 
   {{0xbba84d53,0x02dc7f90,0x203400e5,0x00000000}},	//   _चक्क, _मशीन, فہرس, --, 
   {{0x1f741eea,0x98b8054e,0x00000000,0x00000000}},	//   елля, masă_, --, --, 
   {{0x4430233e,0x32a81161,0xdce0005f,0xa3c401ad}},	//   mpy_, ṇaṃ_, zemē, एफओ_, 
   {{0x44318f0c,0x98b80311,0x24800135,0xf770011a}},	//   lpy_, oasă_, lwim_, דקו_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4430d008,0x9f640332,0x00000000,0x00000000}},	//   npy_, ótón_, --, --, 
   {{0x65b80af2,0x5a3400a7,0x443000c7,0x76440108}},	//   _síhl, ннот, ipy_, ysjy, 
   {{0x6fb00edf,0x2480013f,0x59f802d5,0xa4c01b0d}},	//   _جملا, hwim_, зеня_, yüşü_, 
   {{0x7e68074d,0x24802a1f,0x00000000,0x00000000}},	//   mtfp, kwim_, --, --, 
   {{0xfb840228,0x2f2400e8,0xa4c00205,0x443015c0}},	//   _жыйн, _yёg_, vüşü_, jpy_, 
   {{0x60040137,0x00000000,0x00000000,0x00000000}},	//   lòmb, --, --, --, 
   {{0xc1ec06ab,0x44307c8f,0x00000000,0x00000000}},	//   जवाब_, epy_, --, --, 
   {{0x1cdc0135,0x69c8007f,0xe3b000f1,0x644800b8}},	//   _རྨོ_, èjet, یرل_, _ādir, 
   {{0xa4c07236,0xf8040117,0x00000000,0x00000000}},	// [2a190] rüşü_, _очон, --, --, 
   {{0xc7640075,0x13a403e6,0x6fb01a47,0x622400d1}},	//   _كاپى, رۆزی_, _अवधू, چىلل, 
   {{0x44300588,0xd6d80066,0x00000000,0x00000000}},	//   apy_, _روحش_, --, --, 
   {{0x62581682,0x7d018f0d,0xf41c002f,0x00000000}},	//   ḓod, _ozos, _brät_, --, 
   {{0x7d018f0e,0x03bc00fe,0x443001ef,0x00000000}},	//   _nzos, _আদৰণ, cpy_, --, 
   {{0x1cdc0135,0xed7c105c,0x40901375,0x06c40154}},	//   _རྨེ_, _ch美_, الور, _শুটি, 
   {{0x7d018f0f,0xe2f80220,0x8db40220,0xf41c005b}},	//   _azos, _жері_, еспі, _erät_, 
   {{0x4c8448e5,0x290400ee,0x00000000,0x00000000}},	//   елив, ýmak_, --, --, 
   {{0xf41c0267,0xdde802e9,0x7d00033f,0x7c3400a2}},	//   _grät_, بروه_, _czos, _çyrl, 
   {{0x7d000e8a,0x00000000,0x00000000,0x00000000}},	//   _dzos, --, --, --, 
   {{0x7d018f10,0x38680051,0x9c2400db,0x00000000}},	//   _ezos, etcr_, ндөд, --, 
   {{0x44300124,0x5ea8009e,0x600400cf,0x00000000}},	//   ypy_, _কেকে, ròme, --, 
   {{0xdd1c00bc,0x00000000,0x00000000,0x00000000}},	//   ušťk, --, --, --, 
   {{0x387c39c6,0xca481ec7,0x00000000,0x00000000}},	//   çura_, _فلته_, --, --, 
   {{0xb7d419b6,0xca7404b4,0x80d409ab,0x4a74013d}},	//   روفا_, _чулы, _मेने, _чылт, 
   {{0x4eac00cc,0x00000000,0x00000000,0x00000000}},	//   _কেৱল, --, --, --, 
   {{0xb7b00323,0xf8bc00d5,0x98b80311,0x44318f11}},	// [2a1a0] _өөрч, ncél_, rasă_, upy_, 
   {{0x26cd8f12,0x44318f13,0x43858f14,0xd398008e}},	//   údos_, rpy_, علاق, мәсә_, 
   {{0x44318f15,0x439400fb,0x00000000,0x00000000}},	//   spy_, маҡс, --, --, 
   {{0x44309982,0x41a800a7,0x5bbc090a,0x00000000}},	//   ppy_, явен_, _ऋत्व, --, 
   {{0x2480b25b,0x06c4009e,0x35180375,0x00000000}},	//   qwim_, _শুচি, _מוכנ, --, 
   {{0xf41c023a,0x44200334,0x7c240306,0xeda00022}},	//   _eräs_, _iuk_, íkrm, ҳшьо, 
   {{0x44204375,0xf41c0267,0xc1d00166,0x7d018f16}},	//   _huk_, _fräs_, _йөдә, _szos, 
   {{0x44218f17,0x1cdc0135,0xf41c01e6,0x5c740120}},	//   _kuk_, _རྨུ_, _gräs_, влит, 
   {{0x44218f18,0x7b658f19,0xef142e2d,0x70540408}},	//   _juk_, нтне, ммә_, _патĕ, 
   {{0x7d000030,0x7c34010e,0x7b64022e,0x00000000}},	//   _vzos, _çyrm, хтие, --, 
   {{0x44218f1a,0x19591eb7,0xceac0348,0x7f5800fb}},	//   _luk_, маны_, _тә_, _маҡс_, 
   {{0x3ce401d4,0x44200393,0x6eb80115,0x13dc00cd}},	//   _txov_, _ouk_, _מזבח, _मद्भ, 
   {{0x442007db,0x7d00d9f2,0x00000000,0x00000000}},	//   _nuk_, _uzos, --, --, 
   {{0xdca400d1,0x644800b8,0x773000c7,0xe78404c2}},	//   _паҗи, _ādip, ыҭоу, лусо, 
   {{0x44218f1b,0x2bf402e4,0x7c218f1c,0x27e4c04b}},	//   _auk_, _רמון_, _huor, émna_, 
   {{0x7c218f1d,0x44202af2,0xac8000c7,0x16e001f9}},	//   _kuor, _buk_, _ргәл, _नशीब, 
   {{0x44206cd2,0xe45400f7,0x6d4c007b,0x7c20005b}},	// [2a1b0] _cuk_, лкты, ócai, _juor, 
   {{0x44204437,0x7c218f1e,0x65b80af2,0xe50800ec}},	//   _duk_, _muor, _líhh, ريلو_, 
   {{0xd1318f1f,0x4420009a,0x7c20f03e,0xdb180407}},	//   لما_, _euk_, _luor, _olví, 
   {{0x44200399,0x00000000,0x00000000,0x00000000}},	//   _fuk_, --, --, --, 
   {{0x7c218f20,0xf8b02274,0x442005f5,0x316c0077}},	//   _nuor, ुनिय, _guk_, rfgz_, 
   {{0x7ddc00de,0x00000000,0x00000000,0x00000000}},	//   bīsk, --, --, --, 
   {{0x442005f5,0x7c20003a,0xe61003e6,0xb3940092}},	//   _zuk_, _auor, _خشی_, _ለማዳን_, 
   {{0x44218f21,0x7c218f22,0x7bc4036e,0x00000000}},	//   _yuk_, _buor, ëkun, --, 
   {{0x7c218f23,0xe1e4064d,0xa06806ed,0xd5c801ad}},	//   _cuor, _сюрп, _паѓа_, _रतनज, 
   {{0x7c218f24,0x2cc401fb,0xdb1802d2,0x4b240395}},	//   _duor, _đtdđ_, _elví, ъмов, 
   {{0x37e40154,0x00000000,0x00000000,0x00000000}},	//   ফতার, --, --, --, 
   {{0x7c218f25,0x3eb803a1,0x3ab00daf,0x5d8403e6}},	//   _fuor, øpte_, рәшт, _ململ, 
   {{0x2470001f,0x7c20003a,0xfb8403e6,0x87f801c0}},	//   _አካሄድ_, _guor, ردیی, дэвт_, 
   {{0x1cdc0003,0x44218f26,0x5ea80011,0x55c40150}},	//   _རྨི_, _ruk_, _কেটে, ңарғ, 
   {{0xf7400d84,0x44202045,0x7c2008d5,0x60040ba1}},	//   ресо, _suk_, _zuor, nòma, 
   {{0x4420123c,0x00000000,0x00000000,0x00000000}},	//   _puk_, --, --, --, 
   {{0x2c680450,0x600408c2,0x044400ea,0x00000000}},	// [2a1c0] nød_, hòma, тезн, --, 
   {{0x44200989,0x600402bd,0xa5c400fb,0x00000000}},	//   _vuk_, kòma, төүе, --, 
   {{0xb9918f27,0x26dc00c7,0x0dc00092,0x98b80064}},	//   _صلیب, _ãvo_, ዴአፓ_, rasą_, 
   {{0x44218f28,0xf41d1fe7,0x2c68037e,0x318401ec}},	//   _tuk_, _isän_, kød_, ктің, 
   {{0xf99025f9,0x9f4c011f,0x00000000,0x00000000}},	//   ירא_, _akdá_, --, --, 
   {{0x60040d29,0x65640008,0x2c681477,0xf41c007c}},	//   fòma, lgih, død_, _trär_, 
   {{0x7c218f29,0xf2a080b2,0x7ddc005f,0x6fb005d7}},	//   _suor, _кирп, līsi, _अवरू, 
   {{0x65658f2a,0x7c218f2b,0xdef801ec,0x00000000}},	//   ngih, _puor, мық_, --, 
   {{0x7c218f2c,0x7ddc00e2,0x00000000,0x00000000}},	//   _quor, nīsi, --, --, 
   {{0x7c218592,0x65640369,0x00000000,0x00000000}},	//   _vuor, hgih, --, --, 
   {{0x3f9d8f2d,0x6004004e,0x00000000,0x00000000}},	//   _intu_, còma, --, --, 
   {{0x7c218f2e,0x6bd4965c,0x0ac40022,0x3d080248}},	//   _tuor, _یونس_, ушьҭ, _ẹwu_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb8c8ccc0,0x3f8c0204,0x7ddc005f,0x65640009}},	//   _गप_, ndfu_, dīsi, egih, 
   {{0xb4d801e1,0x3f9c00aa,0x6b7800df,0x00000000}},	//   _adàp, _mntu_, _חרונ, --, 
   {{0xb4d801ab,0x65658f2f,0xf8bc00e5,0xb4bc0205}},	//   _deàn, ggih, ncék_, çüoğ, 
   {{0x799c1cdf,0xa5f8e20b,0x84c000fd,0x1cb80327}},	// [2a1d0] _inqw, тету_, бәрд, ངགི_, 
   {{0x6564089c,0x5ea800cc,0x04a40022,0x6c540115}},	//   agih, _কেছে, ыусҭ, כימא_, 
   {{0xf41c010e,0x3f8c878f,0xd1780024,0x23240166}},	//   _eräp_, ddfu_, еслі_, рфуг, 
   {{0x3f9d8f30,0x3f8c0204,0x31300124,0x00000000}},	//   _antu_, edfu_, рҵар, --, 
   {{0xe0840a2c,0x799c01e2,0xdb0804cc,0xa184010b}},	//   لجوي, _mnqw, chdö, рыхл, 
   {{0xae182ce1,0x600456eb,0x00000000,0x00000000}},	//   _पूजन_, tòma, --, --, 
   {{0x799c00f1,0x06a802dd,0x9e658f31,0x228401b9}},	//   _onqw, _ءﺩﺍﯞ, لاين, _кутг, 
   {{0x1cdc0003,0x0d8450cf,0x3f9c37e7,0x2c6826ff}},	//   _རྨང_, улин, _entu_, tød_, 
   {{0x8d748a4c,0x8f343f72,0x60040ba1,0x21b800e5}},	//   ناکا, _безц, sòma, _جھلک_, 
   {{0x5f746d9c,0x2c684c2e,0x799c0921,0xbe54004b}},	//   _نامر, rød_, _anqw, _څرنګ, 
   {{0x46a40220,0x3a20010b,0x00000000,0x00000000}},	//   _ءﻭﻣﯩ, ймэг, --, --, 
   {{0xaca002e3,0x7b9400cf,0xf09c01e1,0x00000000}},	//   _alụk, _ەپوس_, _ààs_, --, 
   {{0x7ae8003a,0xb4d801ab,0xeb9400d1,0xf99c007f}},	//   _exft, _seàn, _җиқ_, klèf_, 
   {{0x799d8f32,0xe8040cb4,0x6b744eac,0xa2b40490}},	//   _enqw, _शीशा_, _рәис_, _इथल्, 
   {{0xf8a40424,0x67040137,0x3db400cc,0xaa6001ee}},	//   نگیه_, рүнб, _জগতল, _тейһ, 
   {{0x8884db20,0x7ddc005f,0x00000000,0x00000000}},	//   _ближ, tīsi, --, --, 
   {{0x69c58f33,0xf99c0561,0x395c0077,0x98b80064}},	// [2a1e0] _ilie, gmèu_, óuse_, kasę_, 
   {{0x69c58f34,0x00000000,0x00000000,0x00000000}},	//   _hlie, --, --, --, 
   {{0x26dc00e4,0x82342162,0x00000000,0x00000000}},	//   _ävo_, ارئا, --, --, 
   {{0x14d40574,0xd5b0001e,0xc10415eb,0x47840022}},	//   _ठेवण, ết_, هواي, _рыҩб, 
   {{0x69c58f35,0x9f5c004e,0x00000000,0x00000000}},	//   _mlie, llvé_, --, --, 
   {{0x5f940e26,0xbe88f01f,0xf99c067c,0x69c58f36}},	//   рикт, есие_, lmèt_, _llie, 
   {{0x69c58f37,0xeaa58f38,0x61b400db,0x00000000}},	//   _olie, _اع_, _پەشا, --, 
   {{0x724001d9,0xf99c02bd,0x919400f3,0x00000000}},	//   _چھۆل, nmèt_, _кјуш, --, 
   {{0x7bc4b700,0x11d401f4,0x00000000,0x00000000}},	//   ūkum, _тюря, --, --, 
   {{0x3f9d8f39,0x69c55702,0x7e78020c,0xdb1801ed}},	//   _untu_, _alie, _tptp, _alvá, 
   {{0x69c58f3a,0x3878026c,0x65b80241,0xe7f800e1}},	//   _blie, _spqr_, _híhu, ंकना_, 
   {{0xd9158f3b,0xf2d000d9,0x00000000,0x00000000}},	//   идны, מעת_, --, --, 
   {{0x69c401c3,0x9f580241,0xfd6400b8,0x00000000}},	//   _dlie, _òró_, dauḥ, --, 
   {{0x69c58f3c,0xb4d800a3,0xdb1801ed,0xb8c40150}},	//   _elie, _deàl, _elvá, _ەزدى, 
   {{0x7bd98f3d,0x779001a9,0x69c5790e,0x80d40d0b}},	//   mitu, لیکا, _flie, _मेसे, 
   {{0x69c4060a,0x799c00f1,0x7bd80d92,0x986401ed}},	//   _glie, _unqw, litu, _پیسے_, 
   {{0x24581c65,0x7bd8005b,0x97e400db,0x00000000}},	// [2a1f0] лать_, oitu, _ۅتگۅ, --, 
   {{0x39498f3e,0xf2c58f3f,0x81e00f22,0x6b743535}},	//   lacs_, лсен, _নীল_, _işgü, 
   {{0x69c439ed,0x168402f2,0x00000000,0x00000000}},	//   _ylie, _ئاخێ, --, --, 
   {{0x7bd98f40,0x50b58f41,0x39480137,0x80d47220}},	//   hitu, ислу, nacs_, _मेहे, 
   {{0xf99c004e,0x10a54396,0x048404b4,0x00000000}},	//   lmès_, рилн, _вәхи_, --, 
   {{0x7bd98f42,0x40900075,0x6a7801b8,0x200d8f43}},	//   jitu, زلىر, _jäfö, _chdi_, 
   {{0x7bd98f44,0xda040574,0x200c01f7,0xf99c007f}},	//   ditu, रतात_, _dhdi_, nmès_, 
   {{0x225c0030,0x3948058e,0x200c005b,0x7bd98f45}},	//   ávke_, jacs_, _ehdi_, eitu, 
   {{0xe1358f46,0x600400cf,0x8bb4007b,0xe7f800bc}},	//   _ынты, còmo, لإدا, ंकमा_, 
   {{0x7f480139,0x7ddc00ef,0x00000000,0x00000000}},	//   cafq, dīsu, --, --, 
   {{0x69c58f47,0x3948004e,0x6d4c0005,0xbf98011a}},	//   _plie, facs_, ócas, _שיעש, 
   {{0x7bd80421,0x7cd401ed,0x69c4025c,0x0c78013d}},	//   aitu, اویز_, _qlie, _аскы_, 
   {{0x69c47890,0x2d8c009a,0xaca001f2,0x7bd80d63}},	//   _vlie, _iage_, _mmịk, bitu, 
   {{0x7bd98f48,0x62580943,0x29c800f7,0x69c40135}},	//   citu, ḓon, ттүү_, _wlie, 
   {{0x69c4882e,0x2d8d8f49,0xdb180158,0x7ddc0270}},	//   _tlie, _kage_, _alvæ, sūse, 
   {{0x69c58f4a,0xfaa00364,0x394856ed,0x2b440489}},	//   _ulie, _фаъо, cacs_, _henc_, 
   {{0xf99c180f,0x2d8c3046,0x00000000,0x00000000}},	// [2a200] rmèt_, _mage_, --, --, 
   {{0x2d8d8f4b,0x80a4183b,0xaca001f2,0x03180a2c}},	//   _lage_, یمان, _amịk, نتات_, 
   {{0x29000134,0x27f96e29,0x2d8c0270,0x82698f4c}},	//   _hyia_, morn_, _oage_, таев_, 
   {{0xc0581c26,0xe800012c,0x25740150,0x27f805c7}},	//   вік_, ोगका_, _دۇرس, lorn_, 
   {{0x527577d5,0x7bd98f4d,0x9f349e08,0x11e801e2}},	//   _қуру, yitu, белі, دعلي_, 
   {{0x7bd98f4e,0x2d8d8f4f,0xdc5002d3,0x1e1400fd}},	//   xitu, _aage_, ዚኣብሔ, әмия, 
   {{0x7bd98f50,0x2d8d8f51,0x80d403ba,0x9f580248}},	//   vitu, _bage_, _मेरे, _órí_, 
   {{0xdd918f52,0x8c3c00ee,0x25ec0d2c,0x6e9400a7}},	//   سوخ_, lyşy, चवटी_, рвър_, 
   {{0x2d8d8f53,0x29016bff,0x39498f54,0x00000000}},	//   _dage_, _nyia_, vacs_, --, 
   {{0x90e48117,0x8c3c09a5,0x27f8180f,0x7bd8003a}},	//   _اسفن, nyşy, jorn_, uitu, 
   {{0xbea941f2,0x27f80dd4,0x2d8c0c09,0x2b441bce}},	//   _جهان_, dorn_, _fage_, _denc_, 
   {{0xada18f55,0x2d8d8f56,0xfca83cc6,0x00000000}},	//   _махл, _gage_, _لاتو_, --, 
   {{0x27f88fe9,0x3dc40009,0x2c0403d4,0x8c3c00ee}},	//   forn_, _ilow_, োৱেই_, kyşy, 
   {{0x7bd802d3,0x2d8c0b45,0x2b458f57,0x3948354d}},	//   qitu, _zage_, _genc_, sacs_, 
   {{0x39498f58,0xadc00ca8,0x2d8d3ba5,0xeaf4004b}},	//   pacs_, _atẹl, _yage_, _پروت_, 
   {{0xf99d508d,0x2d8c0548,0xcb080212,0xeb9401af}},	//   rmès_, _xage_, _схід_, _биә_, 
   {{0xb86404d3,0x734800a7,0xb4d801ab,0xf48401b9}},	// [2a210] _ئابو, вчев_, _teàm, шувн, 
   {{0x3dc40295,0x27f81948,0x8c3c010e,0x00000000}},	//   _llow_, corn_, gyşy, --, 
   {{0x569400c7,0x00000000,0x00000000,0x00000000}},	//   _уант, --, --, --, 
   {{0xa8498f59,0x2258005b,0xddc80064,0x00000000}},	//   _حلیم_, рицы_, _apdž, --, 
   {{0x2d8d8f5a,0x3384cc5a,0xd478008f,0x60f828f6}},	//   _rage_, _кувв, _גאָל, анця_, 
   {{0x7ddc00da,0x6fa4004b,0x4908000d,0x3dc4058a}},	//   zīst, شنبې_, _सरसो_, _alow_, 
   {{0x4e9400c6,0x3dc58f5b,0x2b440165,0xed5408ca}},	//   إشتر, _blow_, _renc_, ҳоқ_, 
   {{0xdea401b9,0x630401ec,0x2b458f5c,0x27f8030a}},	//   تیمی, _بۋمە, _senc_, zorn_, 
   {{0x1cdc0135,0x2b4400e8,0xab6000d1,0x00000000}},	//   _རྨད_, _penc_, قۇشى, --, 
   {{0x2d8c0f85,0x00000000,0x00000000,0x00000000}},	//   _wage_, --, --, --, 
   {{0x2d8d8f5d,0x7ddc0029,0x3dc58f5e,0x2b4400db}},	//   _tage_, tīst, _flow_, _venc_, 
   {{0xc9751386,0x27f84e13,0x2d8c0334,0x09e4fcc3}},	//   حادث, worn_, _uage_, сомн, 
   {{0x27f98f5f,0x2b4400db,0xc1980677,0x4aa8000d}},	//   torn_, _tenc_, אשרי, _छपवव, 
   {{0xa2d80490,0xd7c8004b,0x7c5401c8,0x00000000}},	//   _मधल्, لوټه_, _الور_, --, 
   {{0x96940220,0x85780006,0xf99c180f,0xeb9401af}},	//   ортш, лсат_, rmèr_, _биҙ_, 
   {{0xd5b001fb,0x42c86b62,0x2478013a,0x27f801e3}},	//   ếp_, ңган_, _němý_, sorn_, 
   {{0x27f80408,0xf37401c6,0xdb18007c,0xd61400d4}},	// [2a220] porn_, өөрч_, _elvä, іфсь, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xce94005f,0x8c3c00ee,0x30200107,0xf8c8032e}},	//   šējā_, ryşy, ҷҷуҳ, _tréð_, 
   {{0x00c80daf,0x00000000,0x00000000,0x00000000}},	//   ллек_, --, --, --, 
   {{0x66058f60,0xc058005b,0x80d000c5,0x00000000}},	//   mlik, урец_, _देखइ, --, 
   {{0x82498f61,0xdfd14ea7,0x3dc58f62,0x3e6801c0}},	//   _مشرف_, بيت_, _slow_, гшин_, 
   {{0x6604cfab,0x3dc4045a,0x00000000,0x00000000}},	//   olik, _plow_, --, --, 
   {{0x629d8f63,0x399c0139,0xbd680b3b,0x00000000}},	//   _irro, _mäsä_, урке_, --, 
   {{0xf8bc737d,0x66058f64,0x9f5c00db,0xbd4402dd}},	//   ncét_, ilik, llví_, _ۇناي, 
   {{0x66058f65,0x7ddc0241,0x9bd41cb8,0x34b4011a}},	//   hlik, _bàsè, іжні, צפים_, 
   {{0x29046648,0xceac00ec,0x00000000,0x00000000}},	//   üman_, _لڙي_, --, --, 
   {{0x66052936,0x3be421cb,0x629c036e,0x59f81422}},	//   jlik, рлүү_, _mrro, ремя_, 
   {{0x6cd00137,0x29040327,0x00000000,0x00000000}},	//   _ىقما, żman_, --, --, 
   {{0x629c7ae4,0x7d018f66,0x66058f67,0xec10d180}},	//   _orro, _iyos, elik, _فوند, 
   {{0x98a441d5,0x7d018f68,0x66058f69,0xfa540014}},	//   ğlı_, _hyos, flik, _آبک_, 
   {{0x98a47b54,0x7d0004ba,0x9538aa4e,0xb4f0004e}},	//   şlı_, _kyos, рзат_, зүмч, 
   {{0x545400d6,0x629d8f6a,0x7d0004ce,0x64400200}},	// [2a230] юват, _arro, _jyos, _çmil, 
   {{0xd2500014,0x66058f6b,0xe4d4007b,0xf8bc007f}},	//   ِنا_, alik, ستقب, myé_, 
   {{0xb4d801ab,0x7d006c34,0x1dc800cd,0x00000000}},	//   _meài, _lyos, िघात, --, 
   {{0x225c0232,0xfbcc00bd,0x66058f6c,0x7d000117}},	//   ávka_, িচিত, clik, _oyos, 
   {{0x7d001aac,0x629d8f6d,0xf8bd8f6e,0x1be80490}},	//   _nyos, _erro, nyé_, टचाल_, 
   {{0x629c0240,0x250800f2,0xb62001ec,0x35dc000d}},	//   _frro, _درپی_, _ﺩﻭ_, _नगड़, 
   {{0x7d018f6f,0xb4d801ab,0x28e003ce,0x00000000}},	//   _ayos, _seàh, _पेनि, --, 
   {{0xf8bd8f70,0x7d004c99,0x0d980228,0x60040e89}},	//   ncés_, _byos, рткы_, hòmh, 
   {{0x7d002da1,0xa3b003f3,0xdfa80014,0x00000000}},	//   _cyos, टॉक_, _گُلو_, --, 
   {{0x7d018f71,0xb4d808c2,0xa0b80228,0x629d8f72}},	//   _dyos, _ceài, _угуу_, _yrro, 
   {{0x66058f73,0x7d018f74,0xc9a98f75,0x600408c2}},	//   ylik, _eyos, авне_, dòmh, 
   {{0xdb200118,0x66058f76,0x00000000,0x00000000}},	//   ítám, xlik, --, --, 
   {{0x66049041,0xb4d800a3,0x7d0004ce,0x6d4800de}},	//   vlik, _feài, _gyos, _iega, 
   {{0x66058f77,0x6d498f78,0x87f805f5,0x5fac0490}},	//   wlik, _hega, рэмт_, चायल, 
   {{0x6d498f79,0x66058f7a,0x7d018f7b,0x85b40114}},	//   _kega, tlik, _zyos, ољач, 
   {{0x66058f7c,0x6d498f7d,0xab60005e,0xf99c067c}},	//   ulik, _jega, _بۇگى, rlèc_, 
   {{0x66057209,0x2cbc0c6a,0x090400e5,0x00000000}},	// [2a240] rlik, nyud_, _گڑھی_, --, 
   {{0x66058f7e,0x6440044e,0xf99c067c,0x8338020f}},	//   slik, _çmim, plèc_, рчат_, 
   {{0x66058f7f,0x6d48ad51,0x42540395,0x00000000}},	//   plik, _oega, ютат, --, 
   {{0xf8bc1c69,0xf6500302,0x66049169,0x410400d8}},	//   ccés_, _קצר_, qlik, озев, 
   {{0xbfa98f80,0xb620313e,0x9f3403de,0x00000000}},	//   итке_, _ﺩﺭ_, пелі, --, 
   {{0x7d018f81,0x6d498f82,0x7dcc01ab,0xe3e80451}},	//   _ryos, _aega, _kùsg, _اکرن_, 
   {{0x60040372,0x7d00037e,0xd140001f,0x6d498f83}},	//   nòmi, _syos, ነታቸው, _bega, 
   {{0x5d5464e1,0x7dcc01ab,0xf8bc0548,0x82a401a9}},	//   чкит, _mùsg, yyé_, _лаҳж, 
   {{0x6d498f84,0x3fe4010a,0x3f680117,0x00000000}},	//   _dega, _джав, _визо_, --, 
   {{0x7d005975,0x6d48bfa3,0x00000000,0x00000000}},	//   _vyos, _eega, --, --, 
   {{0x6d498f85,0xce343886,0xa3dc0574,0xba080801}},	//   _fega, _فولک, तोय_, ихме_, 
   {{0xdd918f86,0x2cbc020c,0xb02402dd,0xbca4007b}},	//   _سوت_, byud_, _اكەم_, _وماي, 
   {{0x7d001449,0x1c3807d8,0xec7452d1,0xcd28143e}},	//   _uyos, _узлы_, _мпц_, _اسمن_, 
   {{0xf8bc019f,0x6d498f87,0x60040100,0x80b0012d}},	//   ryé_, _zega, fòmi, _आपने, 
   {{0xfa4800f7,0x7bc802d0,0x629805ac,0xf8bc007f}},	//   _ئشتى_, _ilfu, ævol, syé_, 
   {{0x7dcc08c2,0xfaa400ec,0xaae40244,0x9b440244}},	//   _dùsg, _ههڙي_, _بتهۆ, _بچکو, 
   {{0xf8bc1497,0x33280114,0x69c00037,0x00000000}},	// [2a250] rcés_, ацен_, ömee, --, 
   {{0xded0010c,0xca740244,0x00000000,0x00000000}},	//   ጥርን_, _بڕیت_, --, --, 
   {{0x1b1c00bd,0xe7f802c3,0x00000000,0x00000000}},	//   পুরে_, ंकरा_, --, --, 
   {{0xf41c01e3,0xa3dc0073,0x00000000,0x00000000}},	//   _späd_, तोब_, --, --, 
   {{0x8fa41c26,0x6d48cd6c,0x9f5c0798,0x00000000}},	//   зале, _rega, movê_, --, 
   {{0x6d487cba,0x00000000,0x00000000,0x00000000}},	//   _sega, --, --, --, 
   {{0x22580108,0x00000000,0x00000000,0x00000000}},	//   _миры_, --, --, --, 
   {{0x8d7509bf,0x7bc98f88,0x8da8013e,0x2164004e}},	//   سابا, _alfu, свиб_, _отуг, 
   {{0x6d498f89,0x6da0036b,0xbe8002dd,0xada000d1}},	//   _vega, зиқа, _үңіл, зақл, 
   {{0x6d498f8a,0xd1340092,0xcb6800ea,0xce940395}},	//   _wega, ሮፕላኖ, љане_, _назъ, 
   {{0x5f7401ec,0x0ba800d1,0x00000000,0x00000000}},	//   _تاقر, لاھى_, --, --, 
   {{0x7dcc08c2,0x21d800b0,0x80b0012d,0x00000000}},	//   _rùsg, tōhi_, _आपमे, --, 
   {{0xa3dc10f7,0x60040428,0x290401a8,0x50bc00dc}},	//   तोड_, gòmw, æma_, ्निष, 
   {{0x9f580428,0x600400db,0xabc80150,0x31c400bc}},	//   _òrô_, tòmi, _ﯗﺭﻣﺎ, लसुध, 
   {{0x317c009a,0xacb00131,0xb6a01180,0xba8800cd}},	//   _obuz_, _رەھب, нирл, _viṣñ, 
   {{0xf99c067c,0xf6200a5b,0x09f800ae,0x00000000}},	//   llèn_, едсо, _دفعة_, --, 
   {{0x78ac003a,0x600400db,0x00000000,0x00000000}},	// [2a260] cxcv, sòmi, --, --, 
   {{0x389825f9,0x317c084c,0x43080451,0x00000000}},	//   _פיינ, _abuz_, ميءَ_, --, 
   {{0x02c408a3,0x27e400d7,0x6f9cf894,0x00000000}},	//   लनेन, émnu_, _गोधू, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb0300212,0x5a0c00df,0x00000000,0x00000000}},	//   еніш, בלאַ, --, --, 
   {{0x845c0023,0x00000000,0x00000000,0x00000000}},	//   _ኲልሳዕ_, --, --, --, 
   {{0x7bc8020c,0xc140001f,0x273c063f,0xf99c007f}},	//   _rlfu, _ይጠይቃ, ụnwu_, dlèn_, 
   {{0x41c4031c,0x00000000,0x00000000,0x00000000}},	//   _གཞིཟ, --, --, --, 
   {{0x48cc015b,0x7dcc01ab,0x9f5c0240,0x00c81999}},	//   রপুর, _rùsd, novë_, _улак_, 
   {{0x5a347939,0x2018eaa6,0xfba98f8b,0x3a3c020c}},	//   мнот, _òri_, стий_, tptp_, 
   {{0xe7b05444,0xf41c023a,0xeb940120,0x9f5c0200}},	//   ञानप, _isät_, чиќ_, hovë_, 
   {{0x9f5c0240,0xef14009d,0x81d800fe,0x00000000}},	//   kovë_, _эмх_, ঠকক_, --, 
   {{0x7bc40200,0x00000000,0x00000000,0x00000000}},	//   ëkus, --, --, --, 
   {{0xeb940262,0xcc8403e6,0xa6d80f22,0x77903451}},	//   _нич_, _کۆیه_, _দুইট, ریجا, 
   {{0x44300066,0x00000000,0x00000000,0x00000000}},	//   eqy_, --, --, --, 
   {{0x26040395,0xe944030d,0xb4b0013d,0x00000000}},	//   ечуг, _пхьо, нибә, --, 
   {{0x57f58f8c,0xb0d801ad,0x7ddc00e2,0x9f5c036e}},	// [2a270] _опит, _मेंग, jūsm, govë_, 
   {{0xdef01772,0x00000000,0x00000000,0x00000000}},	//   ውሞን_, --, --, --, 
   {{0xdb18017a,0x59e0044b,0xc5ec00f1,0x00000000}},	//   _sovê, _पगार, اړۍ_, --, 
   {{0xf0740075,0x9f5c004e,0x3568005b,0xe1340024}},	//   зидә_, lovè_, _урон_, енцы, 
   {{0x22580064,0x947400f2,0x00000000,0x00000000}},	//   _evrk_, _تگزا, --, --, 
   {{0xf6e80003,0x98b800e2,0x00000000,0x00000000}},	//   _རྨོང, lasē_, --, --, 
   {{0x1144009f,0x00000000,0x00000000,0x00000000}},	//   _يَسُ, --, --, --, 
   {{0x317c009a,0x00000000,0x00000000,0x00000000}},	//   _ubuz_, --, --, --, 
   {{0x22598f8d,0x52dc2802,0x8ca40133,0xd0e800f2}},	//   _zvrk_, _मधुस, بڕاو, _بکام_, 
   {{0x0ae81de1,0xdb18007f,0x82600137,0x00000000}},	//   ждой_, _kovè, _سۇۇن, --, 
   {{0x5f742a77,0x290c003a,0x1b000116,0x5a5400fb}},	//   _سالر, ędam_, лүшн, нъяу, 
   {{0x88e58f8e,0xdb1802e2,0xf99c007f,0x7bc400e4}},	//   джме, _movè, slèn_, ëkur, 
   {{0xf99c007f,0x20140210,0x00000000,0x00000000}},	//   plèn_, łcił_, --, --, 
   {{0xf99c068c,0x0cc8078a,0x00000000,0x00000000}},	//   llèl_, िनीम, --, --, 
   {{0xdb182508,0x9b9401c8,0xfbc82c2e,0x00000000}},	//   _novè, _سهيڙ, िसरम, --, 
   {{0x9f5c0023,0xc9f4007b,0xdbd802d2,0x78c401d3}},	//   tovë_, _تستع, _hæðn, örvé, 
   {{0x2fc4020c,0x4374005b,0xb8800306,0xd48400c7}},	// [2a280] kkng_, дует, šírs, нктқ, 
   {{0xdb18067c,0x9f5c036e,0x00000000,0x00000000}},	//   _bovè, rovë_, --, --, 
   {{0x9f5c044e,0xd3c408b0,0xd258187f,0xdb08007c}},	//   sovë_, رتكى, зці_, skdö, 
   {{0x9f5c02fd,0x00000000,0x00000000,0x00000000}},	//   mové_, --, --, --, 
   {{0x9f5c03c6,0x00000000,0x00000000,0x00000000}},	//   lové_, --, --, --, 
   {{0x94080073,0x00000000,0x00000000,0x00000000}},	//   वतःच_, --, --, --, 
   {{0x9f5c0e96,0xc2441fe2,0x63bd64a8,0xdb198f8f}},	//   nové_, _інак, _iorn, _govè, 
   {{0x008401c0,0x2fc4020c,0xdcb800db,0x6e30013a}},	//   _олбо, akng_, згич_, _žebí, 
   {{0x9f5c0232,0x61e005d5,0xf41c0267,0xfbd001d9}},	//   hové_, _imml, _isär_, ہتھ_, 
   {{0x63bd8f90,0x9f5c0300,0x3fa58f91,0xbd88168d}},	//   _jorn, kové_, _تصرف, _ژنان_, 
   {{0x9f5c0232,0x2fd4034c,0x63bc0c30,0x00000000}},	//   jové_, _تولد_, _morn, --, 
   {{0x9f5c031d,0xb4d800a3,0x00000000,0x00000000}},	//   dové_, _meàr, --, --, 
   {{0xdb180005,0x63bc0660,0xae18008f,0xa92801ec}},	//   _mové, _oorn, _וואכ, діре_, 
   {{0xe7849f59,0x9f5c0118,0x5694fbd3,0x00000000}},	//   кусо, fové_, нагт, --, 
   {{0x9f5c04bf,0x52dc012c,0x5ee003d4,0x00000000}},	//   gové_, _मधेस, _পুতে, --, 
   {{0xdb198f92,0xca2800c8,0xa3dc0073,0xdef0010c}},	//   _nové, _צופֿ, तोस_, ውሞና_, 
   {{0x75f00327,0x00000000,0x00000000,0x00000000}},	// [2a290] għza, --, --, --, 
   {{0x9f5c0232,0xb4d80e89,0x00000000,0x00000000}},	//   bové_, _beàr, --, --, 
   {{0xb4d80192,0x9f5c0122,0x646800c0,0x00000000}},	//   _ceàr, cové_, _įsiš, --, 
   {{0xb4d801c3,0x63bc36f4,0x47180375,0xe2380023}},	//   _deàr, _eorn, _מותג, _ብኣሽሓ, 
   {{0x63bd8f93,0xdb18013a,0xc0c038be,0x63c40419}},	//   _forn, _dové, ләфи, ätné, 
   {{0xb4d801c3,0x9258010b,0x28d00037,0xa3a4009b}},	//   _feàr, _нагт_, हनति, _ијск, 
   {{0xb4d80e89,0x6234004e,0x4814010f,0xa2780818}},	//   _geàr, _аесу, ײַסן_, _обру_, 
   {{0x6004007f,0x00000000,0x00000000,0x00000000}},	//   fòms, --, --, --, 
   {{0x9f5c0232,0x63bc01a9,0xfce00107,0x0c2477a8}},	//   zové_, _yorn, лоъо, нмин, 
   {{0x63bd8f94,0x4a44e846,0xecc000f7,0xf53c01e3}},	//   _xorn, ннов, ешүү, _snål_, 
   {{0x5fac205d,0x63b801e6,0x9f5c02fb,0x00000000}},	//   चारल, övni, xové_, --, 
   {{0xf99c0d29,0x9f5c0232,0xba7412b7,0x00000000}},	//   blèm_, vové_, راپت, --, 
   {{0x1c443334,0x48cc015b,0xdd940022,0xca4800f2}},	//   _анім, রপ্র, _шацы, _کلبه_, 
   {{0x9f5c03c6,0xee800131,0x859400f1,0x05d00118}},	//   tové_, ﯩﮕﻪﻥ_, کټرا, _सतहब, 
   {{0xb90484b7,0x28e06bcf,0x3b040395,0xbb500023}},	//   _ये_, _पेरि, _пешо_, _መበቆላ, 
   {{0x9f5c03c6,0x63bd8f95,0x55f4009d,0x00000000}},	//   rové_, _sorn, вчуу, --, 
   {{0x9f5c03c6,0x916801fb,0xb4d801ab,0x64bc1025}},	// [2a2a0] sové_, _gửi_, _seàr, ोनेश, 
   {{0x63bd8f96,0x9f5c0122,0xdb1808a5,0x78f8011a}},	//   _qorn, pové_, _sové, _מלפפ, 
   {{0x6b800cf9,0xa3dc7f1a,0x63bc0730,0x3ce400c5}},	//   _mbng, तोष_, _vorn, _जेने_, 
   {{0xc608009e,0xfb14008f,0x63bc0455,0x07080ee8}},	//   _শংকা_, ײַבט_, _worn, _ويکي_, 
   {{0x6b800083,0xdb1800e4,0xb1400131,0x00000000}},	//   _obng, _vové, унчл, --, 
   {{0x64458f97,0xb4d80e89,0xdce00327,0x3ce4000d}},	//   mpii, _teàr, lemħ, _जइबे_, 
   {{0x44288186,0xdb180022,0xf41c008e,0xfe246584}},	//   _iib_, _tové, _isäp_, ньин, 
   {{0x442802e3,0xa3dc0037,0x644401f4,0x00000000}},	//   _hib_, तोर_, opii, --, 
   {{0x44298f98,0xd1758f99,0x6aa162ab,0x28e005d7}},	//   _kib_, _шыры, _arnf, _पेलि, 
   {{0x44298f9a,0x69c0c2f8,0x00000000,0x00000000}},	//   _jib_, ömen, --, --, 
   {{0x3f8c039a,0x5928031c,0xde2000b8,0x44290f07}},	//   mefu_, _རུངས_, _aṃśo_, _mib_, 
   {{0x44298f9b,0x3e7802d3,0x3f8d8f9c,0x5fa4000d}},	//   _lib_, mët_, lefu_, _गोतल, 
   {{0x3e78069c,0x44298f9d,0xb4d801e1,0xc02c004d}},	//   lët_, _oib_, _ifàg, _điểu_, 
   {{0x44298f9e,0x3f8d8f9f,0xab901219,0x7ddc00c0}},	//   _nib_, nefu_, _биші, dūsi, 
   {{0x3e78044e,0x7c280472,0x98a801fa,0xeb9406ed}},	//   nët_, _iifr, _igač_, _чиј_, 
   {{0x3f8d18ee,0x65958fa0,0x7c2801e7,0x61bc2802}},	//   hefu_, ласу, _hifr, ्घोष, 
   {{0x24f90cab,0x44298fa1,0x3e78044e,0x64440280}},	// [2a2b0] енты_, _bib_, hët_, gpii, 
   {{0x3e78069c,0x44298fa2,0x7c28bde4,0xf99c020c}},	//   kët_, _cib_, _jifr, klèk_, 
   {{0x44298fa3,0x3e78044e,0x3f8c0204,0x170400dd}},	//   _dib_, jët_, defu_, _شہری_, 
   {{0x3568085a,0x3e780023,0x7ddc3d4f,0x7c298fa4}},	//   _эрон_, dët_, būsi, _lifr, 
   {{0x3e78017a,0x56e00150,0x00000000,0x00000000}},	//   eët_, _сұңғ, --, --, 
   {{0x44298fa5,0x798c014b,0x7c2800ac,0x3e780023}},	//   _gib_, hecw, _nifr, fët_, 
   {{0x3e7802d3,0xddd4009b,0x241800fd,0x9f5c07c5}},	//   gët_, _šaši, _чоры_, movì_, 
   {{0x4c841301,0x44298fa6,0x9f900248,0x7c2837a8}},	//   влив, _zib_, _hàì_, _aifr, 
   {{0x44298fa7,0x7c280008,0x3f8c0fec,0xf99c0214}},	//   _yib_, _bifr, befu_, alèk_, 
   {{0x44280457,0x3e7802d3,0x28d006ab,0x3f8c0493}},	//   _xib_, bët_, हनसि, cefu_, 
   {{0x7c298fa8,0x3e780023,0x798c02d0,0x00000000}},	//   _difr, cët_, fecw, --, 
   {{0x3fe00729,0x7dcc0e89,0x4a5400f7,0x7c280112}},	//   মকৃষ, _tùsa, нкүс, _eifr, 
   {{0x7c298fa9,0x6b8001c7,0x00000000,0x00000000}},	//   _fifr, _tbng, --, --, 
   {{0x6e280589,0x77758faa,0x7c298fab,0x290c0318}},	//   _higb, _ccxx, _gifr, āda_, 
   {{0x26cc1705,0x798c0921,0x77740393,0x6e298fac}},	//   ádo_, becw, _dcxx, _kigb, 
   {{0x44280b89,0x7c298fad,0x3f8d8fae,0x6e298faf}},	//   _sib_, _zifr, zefu_, _jigb, 
   {{0x44280457,0xb8b0005e,0x7c280b6f,0x3e7802d3}},	// [2a2c0] _pib_, _көрі, _yifr, zët_, 
   {{0x44298fb0,0xa3dc006d,0x7c2800f7,0x64458fb1}},	//   _qib_, तों_, _xifr, rpii, 
   {{0x44280211,0x64458fb2,0x00000000,0x00000000}},	//   _vib_, spii, --, --, 
   {{0x6e280570,0x44298fb3,0x3f8c0161,0x64458fb4}},	//   _nigb, _wib_, wefu_, ppii, 
   {{0x44280190,0xb03004a9,0x3f8c0204,0x6604005b}},	//   _tib_, لىنغ, tefu_, moik, 
   {{0x3e78044e,0x6e280ca8,0x7a3c02b1,0x44298fb5}},	//   tët_, _aigb, _hīte, _uib_, 
   {{0x3f8d8fb6,0x6e298fb7,0x7a3c00b0,0xa3dc0882}},	//   refu_, _bigb, _kīte, तोः_, 
   {{0x3e78067d,0x7c298fb8,0x3f8d8fb9,0xbbc83fec}},	//   rët_, _sifr, sefu_, िस्क, 
   {{0x66040069,0x6e298fba,0x7a3c00b0,0x7c280ba1}},	//   ioik, _digb, _mīte, _pifr, 
   {{0x798c0921,0xbfa801d9,0x6604c2d0,0x3e780240}},	//   wecw, _تارٕ_, hoik, pët_, 
   {{0x6604ba5c,0x6e2801e1,0x9f5d8fbb,0xf7718fbc}},	//   koik, _figb, noví_, یاس_, 
   {{0x6e28299d,0x7c280042,0x3ce40073,0x7a3c00de}},	//   _gigb, _wifr, _जेथे_, _rītd, 
   {{0x7c298fbd,0x66058fbe,0x9f5c013a,0x00000000}},	//   _tifr, doik, hoví_, --, 
   {{0xb86404d3,0x6e28037e,0xfaa43ed6,0x9f5c022a}},	//   _یاخو, _zigb, _ашин, koví_, 
   {{0x660405da,0x9f5c02f0,0x68ec06be,0x00000000}},	//   foik, joví_, _əndə, --, 
   {{0x6e28011f,0x6604009d,0x6440025c,0x9f900248}},	//   _xigb, goik, _ħmir, _sàì_, 
   {{0x24589d9c,0x29040598,0x941808e0,0xdb1809c2}},	// [2a2d0] кать_, ümat_, ежат_, _moví, 
   {{0xf2c58fbf,0xdb1801a8,0xd76003e6,0xb9ec00b7}},	//   ксен, _loví, _دۆسی, _ዓም_, 
   {{0xd13004a9,0x660405da,0xdbd003b2,0x00000000}},	//   مما_, boik, _nýíl, --, 
   {{0xf99c0699,0xb5f00220,0xc0f0001f,0xdb1800d0}},	//   ndè_, _түбі, _ሌላም_, _noví, 
   {{0xe0d18fc0,0x659402dd,0xa158074d,0x9f9001e1}},	//   يزه_, _таяу, тачу_, _tàì_, 
   {{0x24840598,0x6e28b898,0x46b81152,0xabc802dd}},	//   _ämma_, _sigb, _उपमह, _ﯗﺭﻋﺎ, 
   {{0x9f5c01ef,0x00000000,0x00000000,0x00000000}},	//   coví_, --, --, --, 
   {{0x0a500092,0x00000000,0x00000000,0x00000000}},	//   _መሰማራ, --, --, --, 
   {{0xf99c0268,0xcc88221d,0xa0c400f1,0xdb18013a}},	//   ddè_, رنده_, _پيلو, _doví, 
   {{0x60c402f6,0x6e280784,0x00000000,0x00000000}},	//   äime, _wigb, --, --, 
   {{0x6e282819,0x66055140,0x3fc401d5,0x00000000}},	//   _tigb, yoik, _ёруғ, --, 
   {{0x6440004a,0x3ed8010f,0x7a3c00ef,0x7e8806be}},	//   _émig, _אַדא, _bītb, _səpg, 
   {{0x7dcc01ab,0xcb682e70,0xdb18054e,0x660417ad}},	//   _mùsl, _зале_, _covâ, voik, 
   {{0x7a3c00b8,0x00000000,0x00000000,0x00000000}},	//   _sīte, --, --, --, 
   {{0xf74006bb,0x9f5c0589,0x66058fc1,0x998800ee}},	//   сесо, lovã_, toik, _okaň_, 
   {{0x2d9d8fc2,0x290407de,0x00000000,0x00000000}},	//   ndue_, ümas_, --, --, 
   {{0x66058fc3,0x9f5c0589,0x08e0015b,0x7a3c0171}},	// [2a2e0] roik, novã_, _গুরু_, _vīte, 
   {{0x9f5d20c2,0x66058fc4,0x3ce4033d,0x79380023}},	//   toví_, soik, _जइसे_, _ቦታታት, 
   {{0x9f5c0589,0x7a3cf987,0x66058fc5,0x21cc01ec}},	//   hovã_, _tīte, poik, _ﺒﻀﺭﻭ, 
   {{0x9f5c02fb,0x614400c7,0x257400d1,0x00000000}},	//   roví_, рҵаа, _خۇرس, --, 
   {{0x998800b8,0x00000000,0x00000000,0x00000000}},	//   _ahaś_, --, --, --, 
   {{0x25a1140b,0xdb1803b2,0x9f5c0118,0xaad0278e}},	//   ldil_, _soví, poví_, दनाक, 
   {{0x24818fc6,0xdb18012c,0x25a000c5,0x00000000}},	//   ltim_, _poví, odil_, --, 
   {{0x25a18fc7,0x225c0232,0x1d340801,0x00000000}},	//   ndil_, ávku_, шния, --, 
   {{0x24818fc8,0x7f442c08,0x25a18fc9,0x7e8806be}},	//   ntim_, _безж, idil_, _səpd, 
   {{0x24818fca,0x212007f7,0x25a00009,0x7478010f}},	//   itim_, यधीश_, hdil_, עניג, 
   {{0x3f9d8fcb,0x7ac47136,0x2480036e,0xfe4043fb}},	//   _iatu_, успе, htim_, _اکتی, 
   {{0x3f9d8fcc,0x7ddc005f,0x25a0003e,0xceac009f}},	//   _hatu_, gūst, jdil_, _آڙو_, 
   {{0x3f9c07dd,0x24818fcd,0x9f900248,0x25a06035}},	//   _katu_, jtim_, _kàà_, ddil_, 
   {{0x3f9d8fce,0x7d0400c5,0x9f5c07c5,0x25a00254}},	//   _jatu_, üksu, novà_, edil_, 
   {{0x3f9d8fcf,0x0ba810de,0x290404cc,0x569401ee}},	//   _matu_, _جانى_, ümar_, шавт, 
   {{0xf9908fcb,0x3f9d8fd0,0x24818fd1,0x00000000}},	//   _طبع_, _latu_, ftim_, --, 
   {{0x3f9c08f5,0xdb1805da,0x24800200,0x00000000}},	// [2a2f0] _oatu_, _hovà, gtim_, --, 
   {{0x3f9d8fd2,0x799cf1f5,0x25a18fd3,0xbf2400dc}},	//   _natu_, _haqw, adil_, _kṣīr, 
   {{0x25a18fd4,0x799d8fd5,0x24818fd6,0x92940006}},	//   bdil_, _kaqw, atim_, раец, 
   {{0x3f9d8fd7,0x9f9001e1,0x799c014f,0x32081291}},	//   _aatu_, _aàà_, _jaqw, رتاً_, 
   {{0x3f9d8fd8,0x9f9001e1,0x799d8fd9,0x24818f5b}},	//   _batu_, _bàà_, _maqw, ctim_, 
   {{0x3f9c011f,0x8fa58fda,0xb4c06ac3,0x00000000}},	//   _catu_, раке, ौनी_, --, 
   {{0x3f9d8fdb,0xdb1805da,0x9e648944,0xe7f8447d}},	//   _datu_, _novà, ماين, ूकता_, 
   {{0x3f9d8fdc,0xaa6001e0,0x00000000,0x00000000}},	//   _eatu_, ҙемһ, --, --, 
   {{0x2d9d8fdd,0x3f9d14c3,0x9f900241,0xf99c180f}},	//   rdue_, _fatu_, _fàà_, nlèu_, 
   {{0x9f5c0589,0x64403ae2,0x25a002fb,0xca84010a}},	//   rovã_, _émie, zdil_, агой, 
   {{0x799c0fec,0x0d980209,0x25a001d5,0x00000000}},	//   _baqw, _атлы_, ydil_, --, 
   {{0x9f5c0122,0x8274010f,0x2480022e,0x00000000}},	//   mová_, סערע_, ytim_, --, 
   {{0x9f5c03c6,0x6d598fde,0x3f9d8fdf,0x799c0455}},	//   lová_, maua, _yatu_, _daqw, 
   {{0x6d596dad,0x3f9c00e8,0x9f900241,0xcb6801f4}},	//   laua, _xatu_, _kàá_, _раке_, 
   {{0x9f5c03c6,0x857838ce,0x7ddc1d64,0x9f900241}},	//   nová_, ксат_, pūst, _jàá_, 
   {{0x24818fe0,0x6d598fe1,0x9f900241,0x941806be}},	//   ttim_, naua, _màá_, _irsə_, 
   {{0x4b2004a9,0x24802b92,0x25a18fe2,0x69c4005a}},	// [2a300] _دېگە, utim_, rdil_, _ioie, 
   {{0x24818fe3,0x6d598fe4,0x9f5c0e96,0x7a3c1d77}},	//   rtim_, haua, ková_, _hīta, 
   {{0x3f9d8fe5,0x6d598fe6,0x9f5c0122,0x7a3c0374}},	//   _ratu_, kaua, jová_, _kīta, 
   {{0x3f9c7020,0x6d5847d8,0x69c58fe7,0x9f5c04bf}},	//   _satu_, jaua, _joie, dová_, 
   {{0x3f9c0053,0x69c404c4,0x24818fe8,0xf99c180f}},	//   _patu_, _moie, qtim_, clèu_, 
   {{0x69c58fe9,0x9f900248,0xdfd014a0,0x9e344cd0}},	//   _loie, _bàá_, ثيت_, бекч, 
   {{0x3f9d8fea,0x69c40926,0x6d580e39,0x9f5d8feb}},	//   _vatu_, _ooie, faua, gová_, 
   {{0x3f9c16cb,0x69c58fec,0x629c036b,0xdb1802fd}},	//   _watu_, _noie, _isro, _nová, 
   {{0x3f9d8fed,0xef141cd1,0xf53c01e3,0x3f940798}},	//   _tatu_, лмә_, _inåt_, _вреѓ, 
   {{0x9f5c0232,0x6d580421,0xdb18067c,0x9f900241}},	//   bová_, aaua, _povà, _fàá_, 
   {{0x1958520b,0x9f5c0122,0x69c4b835,0x9f900248}},	//   ланы_, cová_, _boie, _gàá_, 
   {{0x6d598fee,0x69c41fe1,0x799c014f,0x26380419}},	//   caua, _coie, _qaqw, _ečok_, 
   {{0xdb1802fb,0x629c0327,0x799c0455,0xb8840209}},	//   _dová, _lsro, _vaqw, шунй, 
   {{0x799c5c5d,0x9b5800fb,0xad18011a,0x629c22e2}},	//   _waqw, _сикт_, _סוגר, _osro, 
   {{0x69c58fef,0xdb180008,0x35e402d5,0xf99c02e2}},	//   _foie, _alvö, ацав, flèt_, 
   {{0x69c405f5,0x7a3c00cd,0xd6d8012d,0xe534026b}},	//   _goie, _gīta, ął_, жеть, 
   {{0x1cac025c,0x9f5c0308,0x00000000,0x00000000}},	// [2a310] པའི_, zová_, --, --, 
   {{0xd7940597,0x69c40cf9,0xcc800952,0x7bd98ff0}},	//   _الدخ, _zoie, _ﻣﻪﺯﮔ, nhtu, 
   {{0x69c400b5,0xf99c8afa,0x9f5c0306,0xe2c800f1}},	//   _yoie, slèu_, xová_, ټونو_, 
   {{0x9f5c0122,0x69c40005,0xb4b08595,0x200c03e0}},	//   vová_, _xoie, _димә, _akdi_, 
   {{0xf99c0228,0x10a58ff1,0x629c003a,0xef9400d1}},	//   llès_, силн, _esro, ийдә_, 
   {{0x9f5c2195,0x40900131,0xfba406b1,0x6d5801f7}},	//   tová_, سلىر, _कोलम, waua, 
   {{0x6d598ff2,0x7bd82b60,0x00000000,0x00000000}},	//   taua, dhtu, --, --, 
   {{0x9f5c04bf,0x200c485b,0xd36c00db,0x623400f0}},	//   rová_, _ekdi_, _زۇچ_, _фету, 
   {{0xdb182def,0x9f5c0232,0x6d58aa2e,0x69c501c2}},	//   _rová, sová_, raua, _roie, 
   {{0x6d598ff3,0x69c58ff4,0x9f5c0122,0x5f7813d7}},	//   saua, _soie, pová_, _ەمەس_, 
   {{0x6d598ff5,0xdb18f1d4,0x1cd80327,0x321c004d}},	//   paua, _lovæ, ོནཔ_, _khuy_, 
   {{0x9f5801e1,0x00000000,0x00000000,0x00000000}},	//   _órò_, --, --, --, 
   {{0x81d40943,0x69c58ff6,0x7bd800ae,0x76d80107}},	//   nḓan, _voie, bhtu, ҳутӣ_, 
   {{0x7bd98ff7,0x61c40882,0x7a3c00b0,0xf740e99a}},	//   chtu, _वक्ष, _wīta, зеро, 
   {{0xdb1800f8,0xf99d8ff8,0x7a3c65c9,0x69c58ff9}},	//   _tová, glès_, _tīta, _toie, 
   {{0x6fcc0fac,0x78c4036e,0x00000000,0x00000000}},	//   _bøck, ërvë, --, --, 
   {{0xf99c0ba1,0x15b8346d,0xe8f001f7,0x00000000}},	// [2a320] rlèt_, шыры_, _آڻج_, --, 
   {{0xf99c033b,0x44140b01,0x7a3c00de,0xb4600153}},	//   blès_, ёфат, _mītn, якул, 
   {{0xf99d8ffa,0x222801e2,0x00000000,0x00000000}},	//   clès_, لګري_, --, --, 
   {{0xa3a805dc,0x321c0051,0x12180006,0xc05843a2}},	//   _खोर_, _chuy_, аючы_, гік_, 
   {{0xdb18007c,0xb87800d7,0x69c800e4,0x00000000}},	//   _ulvö, mzíc, ëjey, --, 
   {{0x03940276,0x9f4c007c,0xbe843fe6,0x00000000}},	//   _урмя, _ojdå_, مجبو, --, 
   {{0x4f6801ec,0x8fd4035b,0x27e40419,0x00000000}},	//   ршім_, цәтә, émny_, --, 
   {{0xdef84acd,0x321c016d,0x4128f9c9,0x7e9401ed}},	//   лық_, _ghuy_, _бобо_, لنڈر_, 
   {{0xbda401ed,0x9f4c007c,0x7bd8b4bb,0x00000000}},	//   لحکو, _ajdå_, thtu, --, 
   {{0x9b5803b7,0xa3dc0490,0x00000000,0x00000000}},	//   шиот_, तोच_, --, --, 
   {{0xdb180139,0xfbd001d9,0x00000000,0x00000000}},	//   _movç, قتھ_, --, --, 
   {{0x7bd98ffb,0xf2d000c8,0x2e340375,0x1cd80327}},	//   shtu, פער_, _הראש_, ོནད_, 
   {{0xb4d80248,0xb8780030,0xae180375,0x7f580208}},	//   _afàn, dzíc, _עודכ, _ketq, 
   {{0xa3a83eaf,0x81bc0154,0x00000000,0x00000000}},	//   _खोल_, ইসি_, --, --, 
   {{0x3dc4058a,0x7d04002d,0x5724075e,0x00000000}},	//   _koow_, ûksf, زىرك, --, 
   {{0x7a3c0053,0x3dc4002e,0x7f58014f,0xf99c00db}},	//   _hīto, _joow_, _letq, rlès_, 
   {{0x3dc40036,0x68200267,0xdc740092,0x00000000}},	// [2a330] _moow_, född, _በነበረ_, --, 
   {{0xd76004d3,0xf99c007f,0xdb1001e1,0x00000000}},	//   _زۆری, plès_, _àfój, --, 
   {{0x321c0051,0x7a3c0171,0x00000000,0x00000000}},	//   _phuy_, _mīto, --, --, 
   {{0xdb1801bf,0x2f0c02d2,0x50b40108,0x00000000}},	//   _tovæ, _lögþ_, жску, --, 
   {{0xdb180030,0xd478008f,0x23b400d1,0x00000000}},	//   _hovä, _דאָל, تمەس, --, 
   {{0xdb18007c,0xce480108,0x00000000,0x00000000}},	//   _kovä, азке_, --, --, 
   {{0x321d8ffc,0x7f58003a,0x0eb80572,0x0d9800db}},	//   _thuy_, _detq, рулы_, атпы_, 
   {{0x3dc41bce,0x321c0687,0x3078007b,0xaaa400bc}},	//   _coow_, _uhuy_, _محطة_, गिसक, 
   {{0x68205b00,0x00000000,0x00000000,0x00000000}},	//   löde, --, --, --, 
   {{0xcb6800ea,0x7a3c0171,0x00000000,0x00000000}},	//   јане_, _vītn, --, --, 
   {{0x67f001e1,0x6820002f,0x91dc0037,0x00000000}},	//   _lójè, nöde, _मताई, --, 
   {{0x2e1400f2,0x00000000,0x00000000,0x00000000}},	//   _ابطح, --, --, --, 
   {{0x7f58022e,0x6820002f,0x7a3c00ef,0x00000000}},	//   _yetq, höde, _hītl, --, 
   {{0x7a3c0055,0xdb18007c,0x6820002f,0x00000000}},	//   _gīto, _bovä, köde, --, 
   {{0xb6a109bf,0xf99c04cc,0x96b87a93,0x00000000}},	//   мирл, rlèr_, буту_, --, 
   {{0x29000211,0x682001e3,0x48580024,0xc89400f3}},	//   _txia_, döde, _кроў_, _дроњ, 
   {{0x2900067c,0x8338005b,0x446400d4,0x00000000}},	// [2a340] _uxia_, ачет_, ював, --, 
   {{0x7d140158,0x317c0356,0x68208504,0x00000000}},	//   _øyse, _acuz_, föde, --, 
   {{0xaa1400c7,0x682044b3,0x00000000,0x00000000}},	//   hẽmb, rödd, --, --, 
   {{0x60c401c7,0x00000000,0x00000000,0x00000000}},	//   äimo, --, --, --, 
   {{0xaca0063f,0x24840036,0x75f0031c,0xd9200023}},	//   _blọk, _ëmm_, għzu, _ተንተን, 
   {{0x3dc41dd0,0x7f580477,0xdb183be7,0x68200112}},	//   _soow_, _qetq, _hovå, böde, 
   {{0x6e418ffd,0x682001b8,0xd14000b8,0xf53c007c}},	//   ونوم, cöde, _aṇuḥ_, _knåp_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7a3c02b5,0x395806be,0x00000000,0x00000000}},	//   _pīto, _reqs_, --, --, 
   {{0x92bc00fe,0x34b4011a,0x00000000,0x00000000}},	//   ইনৰ_, קפים_, --, --, 
   {{0x2da0005b,0x7a3c00e2,0x5b1400f5,0xceac00ec}},	//   öreä_, _vīto, ямот, _مڙي_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7a3c0374,0x3eb0012d,0x00000000,0x00000000}},	//   _tīto, łatę_, --, --, 
   {{0x7d00014b,0xec101df2,0xeb94008e,0xd7c83bea}},	//   _ixos, _قوند, _мич_, حوسه_, 
   {{0x1cd80dd4,0x195801af,0xdb200108,0x70b407b7}},	//   ོནམ_, _лайы_, ätäj, _आप्ल, 
   {{0xcc84168d,0x682001b8,0x69c00108,0x00000000}},	//   _بۆیه_, vöde, ömet, --, 
   {{0xf41c00d7,0xd25001d3,0x60c4000d,0x49000117}},	// [2a350] _opät_, ڑنا_, äiml, _зӯрг, 
   {{0x68200267,0xc3c000fb,0x00000000,0x00000000}},	//   töde, нөсл, --, --, 
   {{0x64418ffe,0xe29802bf,0x07980a1e,0xf20421f3}},	//   _émin, жає_, _הסתל, оядо, 
   {{0x7d0063dd,0x68218fff,0x00000000,0x00000000}},	//   _oxos, röde, --, --, 
   {{0xc77002d3,0x00000000,0x00000000,0x00000000}},	//   _እምብዛ_, --, --, --, 
   {{0x940404fb,0x9ac4025c,0xf1a8000d,0xaa140022}},	//   _روزه, _kuċċ, _घोरन, vẽmb, 
   {{0x7d003e61,0x2ab001e1,0x7a3c00ef,0xe2f80150}},	//   _axos, _ọba_, _bītm, _дері_, 
   {{0x317c046c,0xccc402e8,0x4d640120,0xc33000d9}},	//   _ucuz_, збий, чкив, _טום_, 
   {{0x601401d5,0x6cd402dd,0x00000000,0x00000000}},	//   _tоmо, _ﺘﻁﺒﻴ, --, --, 
   {{0x4fc02ba5,0x5f840137,0x1f7400cf,0x00000000}},	//   _سەبە, _يۇنە, _олуя, --, 
   {{0x7d000393,0x9ac40135,0xea00004d,0xaa1400c7}},	//   _exos, _nuċċ, _ngải_, sẽmb, 
   {{0x3ce400e1,0xa3a800ce,0x7bc400e4,0x00000000}},	//   _जेके_, _खोई_, êkur, --, 
   {{0x2d8c0120,0x8c4400ee,0x7d54010f,0x6c000117}},	//   _ibge_, _эеле, _זינד_, _оҷиз, 
   {{0x2bb806d5,0xda7802f0,0x00000000,0x00000000}},	//   _خاصة_, buď_, --, --, 
   {{0x290c033f,0x69c00821,0x45d40798,0x00000000}},	//   łda_, ömes, пцат, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x75d000c6,0xa3e802ab,0xb978011a,0x00000000}},	// [2a360] ريكا, यफल_, _הנפי, --, 
   {{0x60c40108,0x00000000,0x00000000,0x00000000}},	//   äimm, --, --, --, 
   {{0xb8780122,0x2bc00b7c,0x82341291,0xaac80b02}},	//   nzín, _वचना, سراا, ाहिक, 
   {{0xf41c03fa,0x8c200154,0x76b8011a,0x00000000}},	//   _spät_, নদিন_, _המטפ, --, 
   {{0xf534025f,0x9f5c0419,0x5f382f78,0x00000000}},	//   _מרכז_, movú_, опля_, --, 
   {{0x9f5c0030,0xd6a801d5,0xaac800bc,0xe58400cf}},	//   lovú_, _ادیم_, ाहाक, _этүү, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xade000d6,0x9f5c0030,0x00000000,0x00000000}},	//   ецьк, novú_, --, --, 
   {{0xbf341424,0x6d4c002e,0x3f6801f0,0x3fe4009b}},	//   _فراغ, ñcaa, _гизо_, _ежав, 
   {{0x9f5c00d0,0x50b4010b,0x00000000,0x00000000}},	//   hovú_, _юссу, --, --, 
   {{0xbea804fb,0xa05402d3,0xfe719000,0x9f5c0030}},	//   _دهان_, _ዝተኣሳ, _سدا_, kovú_, 
   {{0x7d0005f5,0xf8bc004e,0x9f5c00d0,0x7b000055}},	//   _txos, txé_, jovú_, _āttā, 
   {{0x9ac4003d,0x7d0001f0,0x781c00b8,0x9f5c0030}},	//   _suċċ, _uxos, _aśaṭ, dovú_, 
   {{0xf6442d31,0xdca40166,0x69c03b22,0x56959001}},	//   зхан, _наҗи, ömer, магт, 
   {{0x35699002,0xeaac00c6,0xfa4810de,0x9ac40003}},	//   йран_, _معي_, _اشتى_, _quċċ, 
   {{0x7bc99003,0xa6340220,0x82e8031c,0x80bc00c5}},	//   _hofu, енсі, _རྟེའ, ्हाइ, 
   {{0x7bc99004,0x2b44010a,0x64a40798,0x00000000}},	// [2a370] _kofu, _yfnc_, наѓа, --, 
   {{0xd370007b,0x7bc80200,0xdce00205,0x00000000}},	//   ئها_, _jofu, nemı, --, 
   {{0x7bc99005,0x9f5c00d0,0x00000000,0x00000000}},	//   _mofu, bovú_, --, --, 
   {{0xd1319006,0x7bc99007,0x630400d1,0x6820007c}},	//   نما_, _lofu, رونل, möda, 
   {{0x92bc00bd,0x7bc8198f,0xb4559008,0x6820014a}},	//   ইনে_, _oofu, _ریاض_, löda, 
   {{0x7bc90a64,0x00000000,0x00000000,0x00000000}},	//   _nofu, --, --, --, 
   {{0x22940d99,0x00000000,0x00000000,0x00000000}},	//   _пиря, --, --, --, 
   {{0x8c4800d4,0x62240116,0x00000000,0x00000000}},	//   опив_, _كۈلە, --, --, 
   {{0x7bc99009,0xea00001e,0xcd04ff20,0x0c25900a}},	//   _bofu, _ngại_, ьпий, ммин, 
   {{0x320d900b,0xe7d8045e,0x7bc809a9,0xaa54001f}},	//   logy_, _সদ্য, _cofu, _የተረጋ, 
   {{0x7bc9900c,0x6820007c,0x00000000,0x00000000}},	//   _dofu, jöda, --, --, 
   {{0x3ab00032,0x9e240c50,0x682001e3,0x00000000}},	//   тәшт, _كىلو, döda, --, 
   {{0xb87800dd,0x7bc81a06,0xcb69900d,0x2904123d}},	//   szín, _fofu, _дале_, çma_, 
   {{0x7bc80270,0xab8400c2,0x320c01ed,0x7d140217}},	//   _gofu, _худк, hogy_, _øysa, 
   {{0x320c0109,0x9f5c0030,0x63a80174,0x9a940354}},	//   kogy_, tovú_, _ódni, _пăрл, 
   {{0x7bc8055a,0xf77001b9,0xe3a407d6,0x0578007b}},	//   _zofu, _یاپ_, کشری, تمرة_, 
   {{0x7bc80bd7,0x9f5c0030,0x48040798,0x00000000}},	// [2a380] _yofu, rovú_, _опив, --, 
   {{0xf41c4a41,0x9f5c00d0,0xd3a400d1,0x7e8803b9}},	//   _spär_, sovú_, нлуқ, _səpm, 
   {{0xba00001f,0x9f9001e1,0x9f5c0419,0x00000000}},	//   _ግቢ_, _gàù_, povú_, --, 
   {{0x320d900e,0x7a3c00b8,0x00000000,0x00000000}},	//   gogy_, _sītk, --, --, 
   {{0x6565900f,0xf41c0139,0x80241e24,0xdce00205}},	//   maih, _iqän_, ورتم, yemı, 
   {{0xb03000d6,0x6d4c0882,0xdfd000c6,0x8f800150}},	//   вніш, ñcan, طيب_, лқул, 
   {{0x52759010,0x7a3c00b8,0x6444058a,0x6d4c0790}},	//   _путу, _gīth, lqii, ıcan, 
   {{0x7bc99011,0xdb08004a,0x64440548,0x65659012}},	//   _sofu, _élép, oqii, naih, 
   {{0xbb28040d,0x7bc80925,0x64440ba7,0x9070313e}},	//   _ﻣﺎﻝ_, _pofu, nqii, _مۇنش, 
   {{0x65659013,0x7a3c00b0,0xfe5401d5,0x24440166}},	//   haih, _hīti, _قیتب_, _möm_, 
   {{0x33740302,0x65659014,0x7a3c02b5,0x7bc80099}},	//   ועים_, kaih, _kīti, _vofu, 
   {{0x65640525,0x7bc80bd7,0x682029ef,0x290c3535}},	//   jaih, _wofu, vöda, ğdan_, 
   {{0x7bc99015,0x290d17cf,0x656468c8,0x244406be}},	//   _tofu, şdan_, daih, _nöm_, 
   {{0x7bc80418,0x00000000,0x00000000,0x00000000}},	//   _uofu, --, --, --, 
   {{0x65640418,0x6b78011a,0xec34010f,0x00000000}},	//   faih, _ורונ, _קאור_, --, 
   {{0x656402b1,0x682001e3,0x7a3c002b,0xca440150}},	//   gaih, röda, _nīti, _ﺘﺘﺠ_, 
   {{0xf8a00406,0x58d4001b,0x6a140345,0xa5f863da}},	// [2a390] _ओनिय, _чопт, _جبور, фету_, 
   {{0x38bc01e1,0x244404ab,0x68200267,0x99880419}},	//   _ẹrù_, _döm_, lödn, _diať_, 
   {{0x6564113c,0xaaa400bc,0x00000000,0x00000000}},	//   baih, गिएक, --, --, 
   {{0xc690008f,0xa13401d5,0x7a3c002b,0x00000000}},	//   _גאט_, چرهش, _vīth, --, 
   {{0x24459016,0x00000000,0x00000000,0x00000000}},	//   _göm_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa3a80ce0,0x682001d3,0xb87800d7,0x00000000}},	//   _खोट_, ködn, dzím, --, 
   {{0xdb185051,0x3f8c0ffb,0x82e8031c,0x7a3c002b}},	//   _invè, affu_, _རྟིའ, _gīti, 
   {{0x61140024,0xa18401af,0x00000000,0x00000000}},	//   _адту, _шырл, --, --, 
   {{0xddc8005f,0x0ae80415,0xf99c007f,0x8f54007b}},	//   ļoša, здой_, nnèf_, _أناش, 
   {{0x65640113,0x682001e3,0x00000000,0x00000000}},	//   yaih, födn, --, --, 
   {{0x8470001f,0xc3300375,0x00000000,0x00000000}},	//   _እርሱን_, טוי_, --, --, 
   {{0x65659017,0x64440548,0x6d4802d0,0x00000000}},	//   vaih, xqii, _ifga, --, 
   {{0x65659018,0x60c46583,0x2444002f,0x00000000}},	//   waih, äimi, _röm_, --, 
   {{0x65659019,0x3ad0384b,0x24445804,0x394800ae}},	//   taih, _ميوز, _söm_, éisí_, 
   {{0xa3a844ab,0x64440357,0x35a000ee,0x7e8803b9}},	//   _खोज_, tqii, ласг, _səpk, 
   {{0x6565901a,0xdb180ba1,0xb4d800e8,0x437402dd}},	// [2a3a0] raih, _anvè, _ngàd, еует, 
   {{0x64a4774d,0xb380010b,0x64440449,0x6565901b}},	//   наға, ллул, rqii, saih, 
   {{0x6d49901c,0x7a3c7bc9,0x6565901d,0xd2580212}},	//   _ofga, _pīti, paih, дці_, 
   {{0x04c805d9,0x24441f65,0x00000000,0x00000000}},	//   _فوجي_, _töm_, --, --, 
   {{0x64440af5,0xdb189da2,0x6d4c0e2d,0x7e8803b9}},	//   qqii, _envè, ıcal, _təpk, 
   {{0x5f9473b6,0x83549347,0x3f8c026c,0x30a00150}},	//   тикт, _سپرا, uffu_, ығуғ, 
   {{0x7a3c1d76,0x3f8c00f3,0x00000000,0x00000000}},	//   _kūte, rffu_, --, --, 
   {{0x7dcc00a3,0x00000000,0x00000000,0x00000000}},	//   _cùsp, --, --, --, 
   {{0xdb19901e,0x320401ed,0x61e001b9,0xfb84008e}},	//   _invé, énye_, _ilml, нынн, 
   {{0x6d4800a2,0x7e8806be,0x00000000,0x00000000}},	//   _efga, _ləpi, --, --, 
   {{0x63bc0af9,0xf99c033b,0x00000000,0x00000000}},	//   _mnrn, nnèg_, --, --, 
   {{0x225c03c6,0x205402d3,0xf99c007f,0x46b802c3}},	//   ávky_, _ዝተሰር, znèf_, _उपजह, 
   {{0x26cc0793,0xaa8445cc,0x7a3c002b,0xb8780419}},	//   ädon_, ونیم_, _nītv, mzík, 
   {{0x682000e5,0x00000000,0x00000000,0x00000000}},	//   södn, --, --, --, 
   {{0x779015f6,0x7a3c0006,0xab240640,0xaba4009a}},	//   نیکا, _būte, _поља_, _سهيم_, 
   {{0xdb140784,0xb9c402f2,0x00000000,0x00000000}},	//   _ñañu, _ستبه, --, --, 
   {{0x7a3c00b8,0x48c00304,0x3d0c00eb,0x00000000}},	// [2a3b0] _dūte, _кәра, াইক্_, --, 
   {{0xdce08bdf,0xf99c0ffb,0xdd0c033f,0x66180064}},	//   jamč, leè_, _kółk, _ūvkt, 
   {{0xc2f00022,0x25f001f9,0x00000000,0x00000000}},	//   аҟры, ीचशी_, --, --, 
   {{0xf99c506b,0x201c05ac,0x7a3c00ef,0x00000000}},	//   neè_, elvi_, _gūte, --, 
   {{0x10a5901f,0x2638002e,0x7bd91818,0xe6300213}},	//   тилн, _mōol_, kktu, ləşə, 
   {{0xdb199020,0x61e000ac,0x7764002e,0x6d4801ef}},	//   _envé, _elml, najx, _sfga, 
   {{0xb64004ce,0x6820007c,0x0cc8043e,0x00000000}},	//   _ｏｚ_, dödl, ाङ्म, --, 
   {{0x9f5c0122,0x77640218,0x7bd99021,0xf99c0ffb}},	//   mový_, hajx, ektu, jeè_, 
   {{0x9f5c0232,0x39480789,0x7a3c00ef,0x906000d1}},	//   lový_, dccs_, _mītu, _ئۆتۇ, 
   {{0xecc001c0,0x38686e24,0x66dc023a,0x0b4401d5}},	//   вшүү, dscr_, näkö, ънон, 
   {{0x9f5c0232,0x91d405d7,0x3868003a,0x09e41eca}},	//   nový_, _दवाई, escr_, вонн, 
   {{0x263800e8,0x7bd99022,0x66dc01f4,0xca440150}},	//   _cōol_, aktu, häkö, _ﺘﺘﺼ_, 
   {{0x9f5c0122,0x7a3d9023,0xb8800118,0x66dc0108}},	//   hový_, _rūte, šíns, käkö, 
   {{0x9f5c031d,0x2d9c0618,0xdb180022,0xbb400220}},	//   kový_, leue_, _hový, _кешк, 
   {{0x7a3c0053,0x9f5c0122,0x8a040395,0x00000000}},	//   _pūte, jový_, _изке, --, 
   {{0x9f5c0232,0x2d9d515e,0xf99c0ffb,0x63bd9024}},	//   dový_, neue_, ceè_, _snrn, 
   {{0x090400f5,0x35a001a9,0x00000000,0x00000000}},	// [2a3c0] _шпин, шатг, --, --, 
   {{0x80a404d3,0x2d9c05e4,0xf53c005c,0x7764002e}},	//   ێمان, heue_, _egå_, cajx, 
   {{0x9f5c02fb,0x7a3c0374,0x7e8803e3,0x00000000}},	//   gový_, _tūte, _təpi, --, 
   {{0xdb1803c6,0x26d80158,0x7d0c012d,0x00000000}},	//   _nový, myro_, ębsz, --, 
   {{0x80bc03f3,0xe0e000bd,0x7bd80321,0x35a19025}},	//   ्हें, বপ্ন, yktu, _таяг, 
   {{0x25a19026,0x9f5c6b07,0x212401f5,0xc5f800cc}},	//   leil_, bový_, _vzmh_, _আঠটা_, 
   {{0x24800e89,0x9f5d8feb,0xdd9400cf,0x9b580022}},	//   luim_, cový_, гайы, ҭиит_, 
   {{0x25a19027,0x4428020b,0x27f80e78,0x41280137}},	//   neil_, _hhb_, hirn_, _жобо_, 
   {{0x442803a2,0x24808ee5,0x26d800e4,0x49100118}},	//   _khb_, nuim_, hyro_, _धुलो_, 
   {{0x25a12ac9,0x44280ea0,0xdd0c0034,0x7bd83d4f}},	//   heil_, _jhb_, _półk, uktu, 
   {{0x2fd46fb7,0x5a359028,0x24819029,0xf99c0ffb}},	//   _جولد_, лнот, huim_, teè_, 
   {{0x2638002e,0x2480017a,0x25a00076,0xa3d4012c}},	//   _bōom_, kuim_, jeil_, िउड_, 
   {{0x9f5c0122,0xf99c0ffb,0x25a0abf3,0x7764002e}},	//   zový_, reè_, deil_, tajx, 
   {{0x2481902a,0x2638002e,0xd7c804fb,0xf99c0ffb}},	//   duim_, _dōom_, روزه_, seè_, 
   {{0x1af000bd,0x25a1902b,0x9f5c0306,0x7764002e}},	//   _ঘুরে_, feil_, xový_, rajx, 
   {{0x25a00192,0x9f5c0232,0x00000000,0x00000000}},	//   geil_, vový_, --, --, 
   {{0x80bc006d,0x44289e4d,0x9405902c,0x24800137}},	// [2a3d0] ्हों, _bhb_, هوره, guim_, 
   {{0x9f5c03c6,0x442800f3,0x36a00131,0x635401c4}},	//   tový_, _chb_, _پەرق, ивуу, 
   {{0x4429902d,0xd174b590,0x96f80276,0x25a032e4}},	//   _dhb_, гылы, _чент_, beil_, 
   {{0x9f5c0232,0x66dc02f6,0x25a092eb,0x6d4c0790}},	//   rový_, säkö, ceil_, ıcak, 
   {{0x9f5c0232,0x56e00220,0x6ac8009e,0x2480054e}},	//   sový_, _тұңғ, ানযো, cuim_, 
   {{0x9f5c02fb,0x00000000,0x00000000,0x00000000}},	//   pový_, --, --, --, 
   {{0x4e940597,0x2d9c009f,0xdb18022a,0x00000000}},	//   اشتر, teue_, _pový, --, 
   {{0x7c280327,0xa2a89401,0x92940022,0x2d9c9334}},	//   _ahfr, _घनत्, _иаҳц, ueue_, 
   {{0x7c2800c6,0xab600131,0x612c004a,0x2d9c0112}},	//   _bhfr, لۇشى, rôlé, reue_, 
   {{0x25a001f5,0xaea00150,0xfe6c0228,0x00000000}},	//   zeil_, _نەتي, زگۅ_, --, 
   {{0x81e400fe,0x248001a9,0x00000000,0x00000000}},	//   _পদত_, zuim_, --, --, 
   {{0x26cc01b8,0xf3f80183,0x6820007c,0x26d80022}},	//   ädom_, ্তিৰ_, rödm, vyro_, 
   {{0x6d5827ed,0x25a1902e,0x26d8015d,0x00000000}},	//   mbua, veil_, wyro_, --, 
   {{0x25a1902f,0x6d599030,0x6ac800fe,0x3e78001f}},	//   weil_, lbua, ানবো, _አርብቶ_, 
   {{0x25a19031,0x4a74b6cb,0x4428ccbb,0x27f80198}},	//   teil_, _сылт, _rhb_, rirn_, 
   {{0x24819032,0xf99c067c,0x44280208,0x9a8401ee}},	//   tuim_, soèr_, _shb_, _туљл, 
   {{0x25a19033,0x4428f7fa,0x27f8000d,0x00000000}},	// [2a3e0] reil_, _phb_, pirn_, --, 
   {{0x24819034,0x25a19035,0x7a3c1d76,0xf99c011c}},	//   ruim_, seil_, _hūta, rnèe_, 
   {{0x6e340943,0x7a3c0b10,0x44280112,0x25a09df9}},	//   ̭aoṱ, _kūta, _vhb_, peil_, 
   {{0x00e46d2a,0xdce00882,0x7a3c005f,0xdfd00451}},	//   лжен, hamā, _jūta, ڪيت_, 
   {{0xdce04f67,0x24819036,0xdb180793,0x7a3c0055}},	//   kamā, quim_, _sovü, _mūta, 
   {{0x660572f2,0xdce0198e,0x9f64013d,0x6fb40150}},	//   lnik, jamā, _ütüe_, лгір_, 
   {{0x2f14084c,0x660400af,0x4cd0009e,0x6820007c}},	//   лошь_, onik, _তেলু, tödj, 
   {{0x629d9037,0x7c2802d3,0x6d58089c,0x6da00131}},	//   _ipro, _shfr, gbua, ممىم, 
   {{0xa3e809d9,0x66059038,0x71d40375,0xef159039}},	//   _बता_, inik, _עומד_, кмә_, 
   {{0xdce00882,0x629c122b,0x00000000,0x00000000}},	//   gamā, _kpro, --, --, 
   {{0x1958b421,0xb878f9a7,0x7cf805ac,0x6d58003e}},	//   каны_, nzív, _børø, bbua, 
   {{0x629d903a,0x7a3c00b8,0x7e7c7a70,0x0dc00023}},	//   _mpro, _cūta, àppu, ስታፍ_, 
   {{0xdb1804d4,0x629d903b,0x7a3c00cd,0x00000000}},	//   _inví, _lpro, _dūta, --, 
   {{0xc0c80020,0xdce00318,0x6fc402a0,0x6604083e}},	//   _ጠቃሚ_, camā, लायं, enik, 
   {{0xaab426a0,0x9f90002e,0xa3e8012d,0x00000000}},	//   _مدير_, _jàñ_, बसन_, --, 
   {{0x6605903c,0x00000000,0x00000000,0x00000000}},	//   gnik, --, --, --, 
   {{0x7a3c00de,0xbb2801ec,0xa410012d,0x682000e5}},	// [2a3f0] _gūta, _ﺣﺎﻥ_, ़कंप_, ködh, 
   {{0x6605903d,0x629c2233,0x00000000,0x00000000}},	//   anik, _bpro, --, --, 
   {{0x66040f72,0x629c1529,0x23743adf,0x4344329e}},	//   bnik, _cpro, صالح, рфуғ, 
   {{0x91801823,0x629c3627,0x00000000,0x00000000}},	//   تۇرۇ, _dpro, --, --, 
   {{0x629d903e,0x92d41c82,0xdce00a28,0x90c4023a}},	//   _epro, িছে_, yamā, рбле, 
   {{0x629d903f,0x76880213,0x09e011bc,0xc3c08b0a}},	//   _fpro, _göyç, _पत्य, _мөхл, 
   {{0x6d580cc1,0xdce00882,0x0eb8004b,0x00000000}},	//   tbua, vamā, کاږغ_, --, 
   {{0x8db402d5,0x6304027d,0x3e30027d,0xe1f0072d}},	//   рскі, _اوفل, يفور, _فسق_, 
   {{0x6d589f31,0xdce00882,0xcd280801,0x629c012c}},	//   rbua, tamā, ъжие_, _zpro, 
   {{0x66059040,0xdb1828f2,0x7cf81477,0x6d580158}},	//   znik, _enví, _sørø, sbua, 
   {{0xdce00a28,0x66059041,0x8b24010e,0x4a740137}},	//   ramā, ynik, рдне, шыпт, 
   {{0x7a3c0053,0x6820014a,0x66056990,0xdce00a28}},	//   _pūta, mödi, xnik, samā, 
   {{0xdce000dc,0x68200267,0x9a1400a8,0x27b40352}},	//   pamā, lödi, сфэш, бәнс, 
   {{0x6604006d,0x00000000,0x00000000,0x00000000}},	//   wnik, --, --, --, 
   {{0x09ac0154,0xa92802f0,0x5724007b,0x461400f1}},	//   গাবা, _buží, مرفق, لوسر, 
   {{0x7a3c0053,0x66059042,0x395c09f3,0xf99c067c}},	//   _tūta, unik, ðust_, rnèc_, 
  
   {{0x66059043,0x629d9044,0xddd805a1,0xfa3008b0}},	// [2a400] rnik, _spro, nuvš, _بىيج, 
   {{0x66041b24,0xf9f00ed9,0x629c003d,0x682000dd}},	//   snik, _བཏོན_, _ppro, ködi, 
   {{0x66045667,0x4638007b,0xb77808c3,0x00000000}},	//   pnik, _لأحد_, _באיש, --, 
   {{0x660402d1,0xb87802f0,0x00000000,0x00000000}},	//   qnik, rzív, --, --, 
   {{0x629c068f,0x9f9000e8,0xb87801d3,0xb14005a2}},	//   _wpro, _sàñ_, szív, әнәл, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x629d9045,0x68200e78,0xefb00517,0xd36c075e}},	//   _upro, gödi, تیلگ, _سۇن_, 
   {{0xf654011a,0x00000000,0x00000000,0x00000000}},	//   בסקי_, --, --, --, 
   {{0x64419046,0x9988002b,0xefb001d3,0x7a3c00de}},	//   _émis, _ekaś_, _ڈینگ, _būtn, 
   {{0x60e80c07,0xe06403e6,0xcdc400d1,0x53c8146b}},	//   ırmı, _نێچی, _қачқ, रायश, 
   {{0xb4d977f1,0x8e7449b4,0xc0440240,0x00000000}},	//   _ngàn, _гучч, _ንተቃወ, --, 
   {{0xdd90214b,0x00000000,0x00000000,0x00000000}},	//   _روت_, --, --, --, 
   {{0x28680107,0xa9280419,0x00000000,0x00000000}},	//   ирро_, _ruží, --, --, 
   {{0xeaf40133,0xba440408,0x81bc00eb,0x00000000}},	//   اریت_, _кхий, েসি_, --, 
   {{0xf1c400af,0x75880798,0xdef80023,0xdb2001f4}},	//   _रचलन, ксав_, _ጉቡእ_, ötäk, 
   {{0xdb18004e,0x00000000,0x00000000,0x00000000}},	//   _invà, --, --, --, 
   {{0x22a80365,0x7a3c02b5,0xdef80327,0xb87801ed}},	// [2a410] _aşk_, _hūto, _deċi_, gzít, 
   {{0x7a3c02b5,0xa2a806b1,0x22a803e0,0x00000000}},	//   _kūto, _घनश्, _bşk_, --, 
   {{0x7a3c00e2,0xf2c43dad,0x00000000,0x00000000}},	//   _jūto, шсан, --, --, 
   {{0xe1f19047,0xf54c063f,0x00000000,0x00000000}},	//   وسن_, _rụwa_, --, --, 
   {{0x30a4010b,0x22a8013d,0x60c401f4,0x00000000}},	//   ррев, _eşk_, äimp, --, 
   {{0xc1a40046,0xdce00311,0xa2e00ca8,0x00000000}},	//   _қысқ, zamă, _kọ́k, --, 
   {{0x31c40064,0x7a08012d,0xfe6c211f,0x00000000}},	//   _ксав, zęta, فگن_, --, 
   {{0x904404fb,0x6fa4004b,0x644073a0,0xa2e001e1}},	//   _هنره, انګې_, _émir, _mọ́k, 
   {{0xdb1804cc,0xa2e001e1,0x8eb4ba4f,0xe1f801af}},	//   _anvà, _lọ́k, _گماش, _тѳр_, 
   {{0xf9f00327,0x22a80432,0xa0c4007b,0x2d88012d}},	//   _བཏུན_, _yşk_, _بيكو, żce_, 
   {{0x0a34044e,0x8eb4004b,0x4ee401e0,0x29c8010b}},	//   _ባህርያ, _دماش, _усаҡ, иңки_, 
   {{0x6820007c,0x00000000,0x00000000,0x00000000}},	//   nödv, --, --, --, 
   {{0xdb1800cf,0xaee000b8,0xb88403b2,0x8ac401d5}},	//   _envà, _diṅm, _rtíð, рққа_, 
   {{0xb88403b2,0x7a08012d,0x00000000,0x00000000}},	//   _stíð, ręta, --, --, 
   {{0x9f5c022c,0x7a3c00ef,0x00000000,0x00000000}},	//   nnvá_, _gūto, --, --, 
   {{0xbb3800c8,0x3ed8008f,0x00000000,0x00000000}},	//   _געצי, אַמא, --, --, 
   {{0x69c59048,0xdb199049,0xf99008d8,0x4529904a}},	// [2a420] _inie, _invá, _זרח_, ужан_, 
   {{0x430816cb,0xc0580046,0xb4d807c5,0x205402d3}},	//   هيءَ_, ңіл_, _tgàn, _ዝተሞር, 
   {{0xb878066d,0x69c5904b,0x8145904c,0x00000000}},	//   szít, _knie, منان, --, 
   {{0x69c4031c,0x7a08012d,0xd2b8009d,0x733002de}},	//   _jnie, hętn, шууч_, سىنا, 
   {{0x69c4068f,0x4095904d,0x0bd401ec,0x00000000}},	//   _mnie, срет, _ﺘﺠﺎﻫ, --, 
   {{0x7a08033f,0xdce00024,0x22a8083c,0x9f6403e3}},	//   jętn, namą, _tşk_, _ötüb_, 
   {{0x69c5904e,0xf1c00118,0x24814d01,0x00000000}},	//   _onie, áší_, lrim_, --, 
   {{0x69c4016b,0x7a3c0153,0xc0e41b0a,0x00000000}},	//   _nnie, _rūto, _лобк, --, 
   {{0xf1c00316,0xb4d8002e,0x7a3c411e,0xdce000c0}},	//   šší_, _ngàl, _sūto, kamą, 
   {{0x69c5904f,0xf54c01f2,0x248000c6,0x7a3c0374}},	//   _anie, _hụta_, irim_, _pūto, 
   {{0x69c4038f,0xf54c063f,0xfd1004fb,0x200c047e}},	//   _bnie, _kụta_, _کجا_, _ijdi_, 
   {{0x24819050,0x225801a9,0xdd200118,0x00000000}},	//   krim_, _mtrk_, můžo, --, 
   {{0xf54c0521,0x69c4b1cf,0x24808186,0x22580171}},	//   _mụta_, _dnie, jrim_, _ltrk_, 
   {{0x7a3c04fe,0x5ac803e6,0x69c59051,0xdd9000ec}},	//   _tūto, _نابێ_, _enie, _روڪ_, 
   {{0x69c4025c,0x24819052,0xabf8011a,0x531c000d}},	//   _fnie, erim_, _תפוז, _बुढउ_, 
   {{0x69c59053,0x24819054,0x91ac004d,0x00000000}},	//   _gnie, frim_, _thẻ_, --, 
   {{0x24819055,0x147842b5,0x00000000,0x00000000}},	// [2a430] grim_, شماخ_, --, --, 
   {{0xf2c4769c,0x69c59056,0x290c0e2d,0xa2e001e1}},	//   йсен, _znie, ğdat_, _tọ́k, 
   {{0x69c40b21,0x2480011f,0x8ff80330,0x3328009d}},	//   _ynie, arim_, یرتر_, уцан_, 
   {{0xdb1801b8,0x200c0098,0x205402d3,0x644004cc}},	//   _fovö, _ajdi_, _ዝተመር, _èmin, 
   {{0x24800798,0x00000000,0x00000000,0x00000000}},	//   crim_, --, --, --, 
   {{0xf2e410d9,0x6f840212,0x9f5c033b,0xd0080114}},	//   _любо, судж, nivè_, јеке_, 
   {{0xb8c8031c,0x7a08012d,0x00000000,0x00000000}},	//   _པག_, jęto, --, --, 
   {{0xa19411ed,0xf99c020c,0x684001e1,0x8e380472}},	//   _насч, lièf_, _kádì, جستر_, 
   {{0x321c009a,0xc0e401d9,0xdb08005c,0xa3e000cd}},	//   _ikuy_, _وہمن_, nddæ, _तवम_, 
   {{0x69c59057,0xf54c02e3,0x92bc009e,0x8b680798}},	//   _snie, _zụta_, েনী_, шиов_, 
   {{0x69c59058,0x684001e1,0x81bc0154,0x9f5c036e}},	//   _pnie, _ládì, েসর_, zivë_, 
   {{0x24819059,0x09d0009e,0x638001e1,0x69c40135}},	//   yrim_, াসভা, _kánà, _qnie, 
   {{0x682001d3,0x7a3c0171,0x69c40419,0xad24009f}},	//   ködt, _gūtm, _vnie, _اراو, 
   {{0x5ee00a28,0x7c54193a,0x248005d1,0x8b8400db}},	//   _कथम्_, _بلور_, vrim_, _بەدە_, 
   {{0x4dec033f,0x92bc00fe,0x63800241,0x69c40135}},	//   _जताई_, েনু_, _lánà, _tnie, 
   {{0x69c5905a,0x2481905b,0x9f5c02d3,0xf99c033b}},	//   _unie, trim_, tivë_, nnèl_, 
   {{0xb878066d,0x7d15905c,0x2259905d,0xf48401b9}},	// [2a440] szír, _øyst, _strk_, قالی, 
   {{0x321c0113,0x2481905e,0xf4840345,0x00000000}},	//   _akuy_, rrim_, تافی, --, 
   {{0xf54c0521,0x9f5c036e,0x2480007c,0x00000000}},	//   _pụta_, sivë_, srim_, --, 
   {{0x2481905f,0x9f5c02f0,0x00000000,0x00000000}},	//   prim_, mivé_, --, --, 
   {{0x9f5c0306,0x7a080210,0x00000000,0x00000000}},	//   livé_, zęto, --, --, 
   {{0xfeb86ea9,0x00000000,0x00000000,0x00000000}},	//   لاعت_, --, --, --, 
   {{0xe0d802f5,0x9f5c02fb,0x90e40131,0x00000000}},	//   _দেশভ, nivé_, يسۇن, --, 
   {{0xf99c067c,0xdd902f01,0xaf042309,0xd17401af}},	//   mièg_, روخ_, تقىم_, _ныуы, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbea42c1d,0x2b44026c,0x3ea400fd,0x200c036e}},	//   _мазк, _cgnc_, _мизг, _ujdi_, 
   {{0x22440010,0x9f5c0306,0x00000000,0x00000000}},	//   _kimk_, jivé_, --, --, 
   {{0x201d3b4d,0xfca80517,0x9f5c03da,0x26380de2}},	//   lovi_, _ناتو_, divé_, _xōot_, 
   {{0x3dc40009,0x6bd02c04,0x9f5c0100,0xdc0400db}},	//   _inow_, ستیر, tivè_, _ىستۋ, 
   {{0x62800093,0xdca400d1,0x9f5c0022,0xe0d800cc}},	//   _āmon, _маҗи, povõ_, _দেৱন, 
   {{0x3dc4025f,0x35683181,0xaee00055,0x773000c7}},	//   _know_, иран_, _viṇm, ьҭоу, 
   {{0x54542cfe,0x8cb0134e,0x9f5c007f,0x682001e3}},	//   зват, _अनमो, sivè_, föds, 
   {{0x73499060,0x937889b6,0x1ca80327,0x682001e3}},	// [2a450] ачев_, йбат_, _བགས_, göds, 
   {{0x201c2b1d,0x9f5c0306,0xdb08005c,0xa84800f2}},	//   jovi_, bivé_, rddæ, _گلیم_, 
   {{0x201c04b9,0x68400248,0x42800240,0x8798009f}},	//   dovi_, _wádì, _ካልኢት_, _اَپر_, 
   {{0x3f9c011f,0xdb1801e6,0x50b42401,0xe51c00dc}},	//   _abtu_, _invä, зску, _भुवि_, 
   {{0x92bc0729,0x3ebc00a7,0x201c0960,0x62880fac}},	//   েনে_, _artt_, fovi_, _ådon, 
   {{0x201c05ce,0xb4e4000d,0x3ebc02d2,0x8cb0000d}},	//   govi_, बनी_, _brtt_, _अनबो, 
   {{0x1ea80ee8,0xdb08002f,0x0eb801ec,0x5334030d}},	//   قايي_, nddä, сулы_, _хевт, 
   {{0x321c0472,0xf8c817c6,0x0dc8c6c2,0x00000000}},	//   _ukuy_, ामाय, слий_, --, 
   {{0x201c0989,0x9f5c0306,0xed5401b9,0x00000000}},	//   bovi_, zivé_, боқ_, --, 
   {{0x201d9061,0x3dc4058a,0xf99c007f,0x00000000}},	//   covi_, _enow_, snèl_, --, 
   {{0xc04402d3,0x799c03ac,0xde580153,0x00000000}},	//   _ንተቓወ, _bbqw, _дахі_, --, 
   {{0x1e8402dd,0xdcac00db,0x9f059062,0x9da80395}},	//   _ілім, _چۉي_, _تومو, _мъча_, 
   {{0xdb189c56,0x9f5c00e4,0x00000000,0x00000000}},	//   _anvä, povô_, --, --, 
   {{0x9f5d9063,0x2a640120,0x3dc40210,0x45340022}},	//   tivé_, _twnb_, _znow_, ҧхат, 
   {{0x1ca88d8d,0xfaa00c04,0x3ebc003e,0x3b045211}},	//   _བགོ_, _защо, _xrtt_, _нешо_, 
   {{0x201c08a4,0x9f5d9064,0x387c4b16,0x8964004e}},	//   zovi_, rivé_, šura_, _экиж, 
   {{0x9f5c0306,0x92bc00cc,0xdb18007c,0x201d01c9}},	// [2a460] sivé_, েনো_, _envä, yovi_, 
   {{0x26cc0793,0x9f5c0306,0x201c02f0,0x6820007c}},	//   ädos_, pivé_, xovi_, röds, 
   {{0x201c0b91,0xdce00552,0x263800e8,0xb7d80375}},	//   vovi_, pamć, _dōor_, _הקיי, 
   {{0x044434d8,0x00c94fe1,0x00000000,0x00000000}},	//   _немн, йлек_, --, --, 
   {{0x65659065,0xdb1801e6,0x00000000,0x00000000}},	//   mbih, _invå, --, --, 
   {{0x65659066,0x26381bce,0x3dc59067,0x28a4000d}},	//   lbih, _gōor_, _snow_, _ओहनि, 
   {{0x4280069c,0x00000000,0x00000000,0x00000000}},	//   _ካልኦት_, --, --, --, 
   {{0x81e402a6,0x44380998,0x6564009f,0x00000000}},	//   _পদক_, lmp_, nbih, --, 
   {{0x201c0bb8,0x93242832,0xdb0806ed,0x00e400ee}},	//   povi_, _فرہن, cedê, _эжан, 
   {{0x6564003e,0x7ed400cf,0x00000000,0x00000000}},	//   hbih, _ىزاا, --, --, 
   {{0x7a3c7bc9,0x44380165,0xa6dc00eb,0x8ac40124}},	//   _hūti, imp_, _ডেসট, ҧқәа_, 
   {{0x7a3c0383,0xbea40022,0x39e80108,0x00000000}},	//   _kūti, _маҷк, сьон_, --, 
   {{0x320401d3,0x7a3c00de,0x00000000,0x00000000}},	//   ényi_, _jūti, --, --, 
   {{0x3f8d9068,0xec119069,0x6564b620,0x00000000}},	//   ngfu_, _كوند, ebih, --, 
   {{0x752c14cf,0x6bd153b4,0xb4d801c3,0x44396ce3}},	//   _szcz, _ستور, _igài, dmp_, 
   {{0x65641187,0x7c38005c,0x752c010a,0x4438030a}},	//   gbih, lmtr, _pzcz, emp_, 
   {{0xb4e430fd,0x4438039a,0x7c3823f3,0x93b401c6}},	// [2a470] बने_, fmp_, omtr, мбац, 
   {{0x4438014b,0x65640014,0x693400fb,0x00000000}},	//   gmp_, abih, _яныу, --, 
   {{0x98b81ae6,0x6565906a,0x60c0017a,0x92580108}},	//   ması_, bbih, _armm, цает_, 
   {{0x98b8538f,0x7a3c5c07,0x26381bce,0x4438045a}},	//   lası_, _būti, _wōor_, amp_, 
   {{0x60c002b9,0x263800e8,0xa99c00df,0x00000000}},	//   _crmm, _tōor_, מבאר, --, 
   {{0x98b89d58,0x7a3c0055,0xdb0801c7,0x245801c6}},	//   nası_, _dūti, gedë, _харь_, 
   {{0x60c1906b,0xd5e009bb,0x00000000,0x00000000}},	//   _ermm, _नवाज, --, --, 
   {{0xb4d801ab,0x60c00175,0x98b8083c,0x7c3801e4}},	//   _agài, _frmm, hası_, emtr, 
   {{0x98b8538f,0xcdc40220,0xd7300092,0x614400db}},	//   kası_, заққ, _በድህነ, _كۉمە, 
   {{0xca748715,0x69a027c6,0x00000000,0x00000000}},	//   мумы, ग्नी, --, --, 
   {{0x98b812ca,0xdb0800f7,0xc9a815a3,0x7a3c002b}},	//   dası_, nedè, овне_, _hīty, 
   {{0x7c380254,0x65647aac,0x090400d8,0x00000000}},	//   amtr, xbih, дпмн, --, 
   {{0x4439906c,0x98b86d5b,0x6e3803f2,0x00000000}},	//   ymp_, fası_, mmub, --, 
   {{0xa3ac0307,0x290c0356,0x98b8008e,0x00000000}},	//   कड़ा_, ăda_, gası_, --, 
   {{0x9bb400ec,0xdce001ef,0x00000000,0x00000000}},	//   _سليڪ, kamě, --, --, 
   {{0xab601df2,0x44380042,0x00000000,0x00000000}},	//   _تۇگى, wmp_, --, --, 
   {{0x81b439db,0x6565906d,0x4439906e,0x98b8494d}},	// [2a480] জাম_, rbih, tmp_, bası_, 
   {{0x64a44d50,0x6565906f,0x98b99070,0x7a3c0171}},	//   маға, sbih, cası_, _rūti, 
   {{0x6d499071,0xc7a40588,0xf9f42fc0,0x67f0007c}},	//   _ogga, _еиҿк, _رفیع_, _väjd, 
   {{0x6d499072,0x7a3d9073,0xf1a01b88,0xc0e80592}},	//   _ngga, _pūti, вршн, يفان_, 
   {{0x66059074,0x00000000,0x00000000,0x00000000}},	//   miik, --, --, --, 
   {{0x66040a82,0x6d499075,0x9f3580da,0x4adc084d}},	//   liik, _agga, нелі, महाव, 
   {{0xdb0800cf,0xbe8802dd,0x00000000,0x00000000}},	//   cedè, іске_, --, --, 
   {{0x98b805f3,0xb4d91ef9,0x6e382819,0x66059076}},	//   zası_, _afày, gmub, niik, 
   {{0x98b80cc1,0x6da00114,0xfb842f89,0x29040419}},	//   yası_, тиња, мынн, úmal_, 
   {{0x6d499077,0x6e3804ba,0x660444db,0xdb0800e5}},	//   _egga, amub, hiik, ledé, 
   {{0x66059078,0x7c399079,0x98b83e67,0x0c9401b9}},	//   kiik, rmtr, vası_, ودیگ, 
   {{0xf99c0561,0x660490ae,0x38ac031c,0x3e7800e2}},	//   dièc_, jiik, _pżr_, mīt_, 
   {{0x98b812ca,0x64c81533,0x3e78005f,0x7c300022}},	//   tası_, रमोश, līt_, _иҵих, 
   {{0xdce000bc,0x81b80154,0x387c0010,0x6fc403ce}},	//   zamě, আউট_, šuro_, लाएं, 
   {{0x98b84944,0xdb0800dd,0x3e7800da,0x7ac40220}},	//   rası_, kedé, nīt_, _іске, 
   {{0x6605907a,0x98b80ba5,0x00000000,0x00000000}},	//   giik, sası_, --, --, 
   {{0xd7f000c6,0x98b80aba,0x91ac01fb,0xdb0952df}},	// [2a490] _مكة_, pası_, _nhé_, dedé, 
   {{0xd3708a91,0x68e04c51,0xf99c007f,0x332800d8}},	//   اها_, ämde, lfè_, оцен_, 
   {{0xe0d01812,0xf99c0ba1,0x6605907b,0xc7b00375}},	//   یزه_, cièc_, biik, _גבי_, 
   {{0x3e780029,0xdb09907c,0xba00044e,0xd13000c6}},	//   dīt_, gedé, _ጌና_, هما_, 
   {{0x8fa4f4f2,0xf8bc0137,0x7bc854c7,0xdb080100}},	//   еале, nvé_, _onfu, sedè, 
   {{0x7bc80327,0x67f000a2,0x00000000,0x00000000}},	//   _nnfu, _täje, --, --, 
   {{0x7a3c00b0,0xdb080221,0xfbd06d58,0x8cb0e1ff}},	//   _hūtu, bedé, तानम, _अनहो, 
   {{0x8d740228,0x7bc9907d,0xdb080005,0x7a3c0055}},	//   رابا, _anfu, cedé, _tīty, 
   {{0xf99c007f,0xf53c005c,0xed5401b9,0x91ac0051}},	//   dfè_, _ubåd_, поқ_, _ghé_, 
   {{0x2e480801,0x6d480334,0x6605907e,0x3e780171}},	//   _дядо_, _wgga, ziik, bīt_, 
   {{0x8a040724,0xf99d279d,0xdd00005f,0x3e7800e2}},	//   езне, ffè_, ātāj, cīt_, 
   {{0x7bc82252,0x6d49907f,0x00000000,0x00000000}},	//   _enfu, _ugga, --, --, 
   {{0x660402f6,0xc324015b,0x1ca80327,0x7ad001b9}},	//   viik, _বলছি_, _བགག_, نقیص, 
   {{0x7bc804ba,0x8c4400d8,0x00000000,0x00000000}},	//   _gnfu, _џеке, --, --, 
   {{0x66059080,0xe7946b5d,0xdb0801d3,0xd9b000db}},	//   tiik, _یادک, yedé, اەۋد, 
   {{0x7bc800f3,0xf62001c0,0x7a3c0153,0x00000000}},	//   _znfu, гдсо, _būtu, --, 
   {{0x66049f02,0x0630001f,0x3e78005f,0xdb0801d3}},	// [2a4a0] riik, _በእውነ, zīt_, vedé, 
   {{0x66059081,0x317d3b92,0x83380354,0x628803cd}},	//   siik, _aduz_, пчет_, _ådok, 
   {{0x2bb40d01,0x07080150,0x66059082,0x74119083}},	//   _असना, _ريحي_, piik, دولا, 
   {{0x3e780882,0x66040194,0x9f5c0077,0x00000000}},	//   vīt_, qiik, riví_, --, 
   {{0xf120224f,0x717004fb,0xdb0801d3,0x7e78007c}},	//   льшо, اهها, redé, _svtp, 
   {{0x3e780029,0xdb0801d3,0x25a00afa,0x00000000}},	//   tīt_, sedé, lfil_, --, 
   {{0x25a19084,0x2cbc0037,0xdb0801d3,0x00000000}},	//   ofil_, evud_, pedé, --, 
   {{0x3e7800da,0x320401ed,0xed840212,0x2cbc37e9}},	//   rīt_, ényt_, нськ_, fvud_, 
   {{0x3e780029,0x81b40154,0xdb0801bf,0x9d180124}},	//   sīt_, জাদ_, lddø, ьоит_, 
   {{0x3e7800e2,0xf99c02e2,0x3078011a,0x00000000}},	//   pīt_, nnèv_, _מאמנ, --, 
   {{0xd9b400fe,0xbd6818c7,0x2ec800cd,0x1ee802f2}},	//   টাসম, _ерле_, ऽमृत, _توای_, 
   {{0xf8bc0122,0x9f5d199a,0xf99c02e2,0x00000000}},	//   tvé_, livà_, ufè_, --, 
   {{0xf8bc0231,0xa3e000dc,0x25a0007c,0xf99c0100}},	//   uvé_, _तवं_, dfil_, rfè_, 
   {{0xf8bd9085,0xdb1802d3,0xf99c02bd,0xa6dc00fe}},	//   rvé_, _javë, sfè_, _ডেইট, 
   {{0x25a00368,0xdb080142,0x80c077ca,0x00000000}},	//   ffil_, medï, लिडे, --, 
   {{0x7a3c02b5,0x00000000,0x00000000,0x00000000}},	//   _pūtu, --, --, --, 
   {{0x26c51248,0xb4d8002e,0x2bb40b9a,0x58d4011c}},	// [2a4b0] āmoa_, _ngàt, _असमा, _ропт, 
   {{0x8d94001f,0x25a00254,0x41c4012d,0x9438007b}},	//   ኙበታል_, afil_, _रोबस, ذكاء_, 
   {{0x92959086,0x00000000,0x00000000,0x00000000}},	//   таец, --, --, --, 
   {{0x7a3c0325,0x225c219b,0x796800d1,0x00000000}},	//   _tūtu, ívka_, _ﻳﯩﯖﻰ_, --, 
   {{0x61f8017a,0x30a00014,0xc0d401f3,0x7d040162}},	//   ëvla, التہ, ራጣሪ_, úksl, 
   {{0x4fa422d7,0xc0e0cb3d,0x7a3c0171,0x8fa46b01}},	//   тикв, рошк, _kūts, таке, 
   {{0xb8e00d46,0xf1a59087,0x2bb400e1,0xfe6c036b}},	//   _ཌན_, _пран, _असबा, قگن_, 
   {{0xa91001e4,0x2cbc00f3,0x00000000,0x00000000}},	//   _heɾe, tvud_, --, --, 
   {{0x6eac0073,0xd0e80345,0x00000000,0x00000000}},	//   ंबहु, _تکام_, --, --, 
   {{0xdb18007f,0x2cbc0254,0xe1fc01e1,0x00000000}},	//   _kavè, rvud_, _ṣùẹ̀, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9f5c0f91,0xabdc01ec,0xbed400d9,0xe0d800eb}},	//   mivá_, _ﺇﻀﻌﺎ, _בועז_, _দেয়ন, 
   {{0xdb1802e2,0x9f5c02fb,0xd6c40116,0x6d595749}},	//   _lavè, livá_, қитқ, mcua, 
   {{0x6d580789,0xdce0008e,0x00000000,0x00000000}},	//   lcua, lamğ, --, --, 
   {{0x3ad05789,0xdb18180f,0x9f5c02fb,0x25a19088}},	//   _نيوز, _navè, nivá_, tfil_, 
   {{0x6d599089,0x15b801e0,0x00000000,0x00000000}},	//   ncua, ныуы_, --, --, 
   {{0x25a059bd,0x9f5c0093,0x4374005b,0x9f5800a2}},	// [2a4c0] rfil_, hivá_, вует, _örç_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb18068c,0xd2581fe2,0xb4d80e89,0x9f5c13d5}},	//   _cavè, еці_, _sgàt, jivá_, 
   {{0x6d580218,0x9f5c02fb,0xdd100118,0x8145908a}},	//   jcua, divá_, _rýžo, ننان, 
   {{0x40940b32,0xf9900302,0x9f5d1cdd,0xdb196c67}},	//   трет, שרד_, tivà_, _pavë, 
   {{0xbea5908b,0xdb18004e,0x6d580113,0x78f80375}},	//   вший, _favè, ecua, ופנו, 
   {{0x63bc7e9c,0xe7a40846,0xdb180561,0x9f5d1cdd}},	//   _iarn, ख्यप, _gavè, rivà_, 
   {{0x629c01d5,0x229c0306,0xf99c02bd,0x00000000}},	//   _iqro, mík_, nnèt_, --, 
   {{0x61e07e9f,0x229d908c,0xdb180023,0xddc80210}},	//   _ioml, lík_, _tavë, _pudł, 
   {{0x2bb40574,0xdbd002f5,0x61e1908d,0x9f5c02f0}},	//   _असणा, িস্ফ, _homl, bivá_, 
   {{0x229c0300,0x6d580070,0x00000000,0x00000000}},	//   ník_, bcua, --, --, 
   {{0x63bc5950,0x61e1908e,0xdb1800c7,0x6d59908f}},	//   _larn, _joml, _javé, ccua, 
   {{0x6ba401e6,0x63bc84d6,0x2ec0009d,0x0ba40150}},	//   ärgå, _oarn, _бөөм, _әшім, 
   {{0xe784d87d,0x61e19090,0x67f001b8,0x7ac400c7}},	//   иусо, _loml, _päja, _асие, 
   {{0x2bb405ba,0x25580521,0xb4d800e8,0x229c0306}},	//   _असता, _ọla_, _ngàr, jík_, 
   {{0x63bd9091,0x61e14e22,0xd1d4044e,0x229d9092}},	//   _aarn, _noml, ራታት_, dík_, 
   {{0x629d18a6,0x7bd801d4,0xdb18067c,0x9f5c0f91}},	// [2a4d0] _aqro, ojtu, _savè, zivá_, 
   {{0x229c3606,0xe85807d5,0x7bd8036e,0x00000000}},	//   fík_, _шаьш_, njtu, --, 
   {{0x61e19093,0x229c0166,0x00000000,0x00000000}},	//   _boml, gík_, --, --, 
   {{0x61e19094,0x63bd9095,0xbc980092,0x9f5c0419}},	//   _coml, _earn, _ፈጣንና_, vivá_, 
   {{0x63bd7736,0xa1342928,0x61e19096,0x608400d1}},	//   _farn, ۇرۇش, _doml, ۇشۈك, 
   {{0xb4dc0574,0xdb185b80,0x229c02fb,0x9f5c02f0}},	//   तही_, _tavè, bík_, tivá_, 
   {{0x61e003cd,0xf99c033b,0x229c02f0,0x6d4c00d7}},	//   _foml, nnès_, cík_, žcam, 
   {{0x61e00579,0x63bd9097,0xdb180129,0x9f5c00d0}},	//   _goml, _zarn, _gavé, rivá_, 
   {{0x0c24042f,0x63bc4cd5,0x6d599098,0x9f5c0518}},	//   лмин, _yarn, rcua, sivá_, 
   {{0x61e00944,0x63bc1574,0xf99c0129,0x7a2c00a3}},	//   _zoml, _xarn, knès_, lùth, 
   {{0x81b40d42,0x61e01cdf,0x4a459099,0x09e4dead}},	//   জার_, _yoml, лнов, гонн, 
   {{0xdb09909a,0x7a3c0882,0x7bd80023,0xf99c00f2}},	//   cedí, _sūtr, ajtu, sièn_, 
   {{0x229d909b,0x8ba409a5,0x00000000,0x00000000}},	//   zík_, _билж, --, --, 
   {{0x6fb002ab,0x35a000c7,0x00000000,0x00000000}},	//   ंजिं, ҩарг, --, --, 
   {{0x98a40029,0x63bd909c,0x229c0306,0x6b800208}},	//   ālā_, _rarn, xík_, _idng, 
   {{0x63bd909d,0x229c11c3,0xf99cfc6e,0x55f441b9}},	//   _sarn, vík_, nièl_, ачуу, 
   {{0x61e1909e,0xd5743334,0xf99d909f,0xb4d801ab}},	// [2a4e0] _roml, русь, anès_, _sgàr, 
   {{0x61e0f0ba,0x229d90a0,0x69a02f2e,0x63bd90a1}},	//   _soml, tík_, ग्री, _qarn, 
   {{0x63bc81ec,0x61e190a2,0x69d8a4cd,0xdb1990a3}},	//   _varn, _poml, यापी, _pavé, 
   {{0xc17478e3,0x63bd90a4,0x229d90a5,0x61e190a6}},	//   ادات, _warn, rík_, _qoml, 
   {{0x63bd90a7,0x1f740408,0x3a3800e8,0x81b40011}},	//   _tarn, алля, _ëppe_, জাল_, 
   {{0xa30477de,0x61e00944,0x63bc003e,0x229c02fb}},	//   _күзе, _woml, _uarn, pík_, 
   {{0x4428009a,0x290c05d1,0xfbd01c15,0x80c000c5}},	//   _ikb_, ğday_, तासम, लिहे, 
   {{0x5d5414a4,0x1ca8025c,0x923800f7,0x6e940395}},	//   шкит, _བགད_, _ачуу_, увър_, 
   {{0x71704876,0x9bf40601,0x64400066,0x98a8107d}},	//   _دهقا, изич, _èmis, _izać_, 
   {{0x6fb8012d,0x31040395,0x44280118,0x00000000}},	//   _एसयू, _снуп_, _jkb_, --, 
   {{0xfbd00d83,0x44282e10,0xdb0990a8,0x00000000}},	//   لتھ_, _mkb_, pedí, --, 
   {{0xf2d004ac,0x4428010a,0xdb1805d5,0xadb400c6}},	//   צער_, _lkb_, _invü, _مهما_, 
   {{0x442802d3,0x1bd42bbe,0x67f0007c,0x7af800e5}},	//   _okb_, _воля, _väjn, sztt, 
   {{0xf41c049f,0x442800ca,0xd9b40154,0x00000000}},	//   _iväg_, _nkb_, টাইম, --, 
   {{0xeb9400f3,0x00000000,0x00000000,0x00000000}},	//   _сиј_, --, --, --, 
   {{0x4428019b,0xdb080120,0x9594001f,0xf99c00cf}},	//   _akb_, pedâ, _ጌታችን_, rnès_, 
   {{0x442990a9,0xa4d400d4,0x6a140472,0xf9d0022e}},	// [2a4f0] _bkb_, боті, _دبور, _воқэ, 
   {{0x442990aa,0xdce190ab,0x00000000,0x00000000}},	//   _ckb_, lamē, --, --, 
   {{0xdb1800d8,0x4428002f,0xefd00023,0x96f80902}},	//   _invó, _dkb_, ራቓዊ_, _рент_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x442990ac,0x7a2c00a3,0x7c2802d2,0x9f5c01f4}},	//   _fkb_, rùth, _okfr, kivä_, 
   {{0x442805d5,0x60f80276,0x00000000,0x00000000}},	//   _gkb_, ынчя_, --, --, 
   {{0x77742087,0x764c00ca,0x2418760c,0x0eb838be}},	//   _mexx, _kicy, _соры_, тулы_, 
   {{0x4c8418ac,0x2bb428f5,0x76540067,0x777400d7}},	//   алив, _असहा, _muxy, _lexx, 
   {{0x764c51c5,0x4f8401d3,0x442800a2,0xe0640133}},	//   _micy, _نااہ, _ykb_, _هێنی, 
   {{0x764c0034,0x4428009a,0x00000000,0x00000000}},	//   _licy, _xkb_, --, --, 
   {{0x638000bc,0xea9c00cd,0x7d0c03b9,0x273c013a}},	//   lání, _maṇi_, _əhsə, _mání_, 
   {{0x764c0796,0x7c280115,0xdb2401d3,0x2bb400ab}},	//   _nicy, _ekfr, ásáv, _असवा, 
   {{0x69d81b57,0x77740263,0x63800118,0x00000000}},	//   याबी, _bexx, nání, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xca740348,0x442990ad,0xdb080798,0x764d90ae}},	//   _тулы, _rkb_, redã, _bicy, 
   {{0x056590af,0x442990b0,0x59a41af8,0x965400a7}},	//   рван, _skb_, ग्दर, сърч, 
   {{0x273c01e1,0xb878011f,0xb460188c,0xdb081de4}},	// [2a500] _bání_, yyíi, жкул, medá, 
   {{0x7774102c,0x638000bc,0xdb080118,0x06e800c0}},	//   _gexx, dání, ledá, _амок_, 
   {{0x9f5cce29,0x62800270,0x273c0248,0x442990b1}},	//   nivå_, _āmos, _dání_, _vkb_, 
   {{0x764c00ca,0xdb080306,0x00000000,0x00000000}},	//   _gicy, nedá, --, --, 
   {{0x44298e66,0x7774011f,0x00000000,0x00000000}},	//   _tkb_, _yexx, --, --, 
   {{0x248190b2,0x81b40729,0x764c0223,0x77740429}},	//   msim_, জাই_, _zicy, _xexx, 
   {{0x764c0526,0xd3340953,0xe1c401e0,0x752c012d}},	//   _yicy, _гэты, _гөлй, _zycz, 
   {{0x806400d6,0x2481903b,0x5c74180b,0xf99c0100}},	//   _вваж, osim_, блит, tièm_, 
   {{0x248190b3,0x22580549,0xfbd0227c,0x6aac015b}},	//   nsim_, _hurk_, तालम, টিফো, 
   {{0x248190b4,0x225990b5,0x7ac4466e,0x9ca400db}},	//   isim_, _kurk_, асме, _ۇشتۇ, 
   {{0x225990b6,0x1ca8031c,0x2bb401ad,0xeb940120}},	//   _jurk_, _བགམ_, _असरा, шиќ_, 
   {{0x225916ae,0x7e680112,0xccf400d1,0x068801ec}},	//   _murk_, mpfp, рқә_, _ﯗﺷﻘﯩ, 
   {{0xfd10c69a,0x24800c5e,0x764cdecf,0x00000000}},	//   _بجا_, jsim_, _ricy, --, 
   {{0x7774011f,0xdb1990b7,0x752c012d,0x764d90b8}},	//   _qexx, _haví, _rycz, _sicy, 
   {{0x248045a7,0x225990b9,0xdb1802d2,0x00000000}},	//   esim_, _nurk_, _kaví, --, 
   {{0xdb1800dd,0x9984b5ed,0xdb0804d4,0x61e4023a}},	//   _javí, _الظو, cedá, öill, 
   {{0x2608007d,0x953885a8,0x764c00b8,0xa96800d8}},	// [2a510] _सगरी_, узат_, _vicy, _тиња_, 
   {{0xf3655bc3,0x63800316,0x764c00ca,0x225990ba}},	//   ртан, vání, _wicy, _burk_, 
   {{0x752c0034,0x04840116,0x2480058a,0x2374210e}},	//   _wycz, _қәти_, asim_, زالح, 
   {{0xb5a590bb,0x22580b21,0xdb180316,0x248190bc}},	//   _трой, _durk_, _naví, bsim_, 
   {{0x69d800a5,0x42a563b1,0x273c013a,0x00000000}},	//   याती, _қурғ, _tání_, --, 
   {{0x7e680036,0x638000bc,0x35c00022,0x2258045a}},	//   fpfp, rání, _уаҭҳ, _furk_, 
   {{0xdb180ab9,0xdb0801bf,0xc44400e5,0x00000000}},	//   _baví, ledæ, _ایلن_, --, 
   {{0xa194013e,0xc3300375,0xbac80220,0xcd3400f2}},	//   _масч, _זול_, _ﯗﺳﺘﺎ, یرکب, 
   {{0x10a404a2,0xd0e800dd,0xdb180008,0x50f590bd}},	//   ﺎﻧﺪﯨ, _حکام_, _daví, _узат, 
   {{0xa1f800e2,0xdec80150,0x00000000,0x00000000}},	//   _cīņā_, ууәл_, --, --, 
   {{0x248190be,0x00000000,0x00000000,0x00000000}},	//   zsim_, --, --, --, 
   {{0x69d81025,0x248000c0,0xdef800fb,0x00000000}},	//   याधी, ysim_, _тыу_, --, 
   {{0xfd540302,0xdb0801f1,0x6a500356,0x29040e89}},	//   _השני_, redá, _răfu, àma_, 
   {{0xdb180308,0xdb0990bf,0x24800790,0xb8e80014}},	//   _zaví, ازیه_, vsim_, ابَے_, 
   {{0x2b4401c0,0x09e4010b,0x69d800cd,0x7d0403b2}},	//   _тэдг, _гойн, यादी, úksv, 
   {{0x248190c0,0x26080490,0x237990c1,0xae4c0150}},	//   tsim_, _सगळी_, _serj_, _ﺟﺎﺯﯞ_, 
   {{0x23780200,0x61e40108,0x00000000,0x00000000}},	// [2a520] _perj_, öilm, --, --, 
   {{0x2258000d,0x99880055,0x73e00114,0x00000000}},	//   _purk_, _ojaś_, поуз, --, 
   {{0x248190c2,0x83387939,0x1cd0025c,0x86c590c3}},	//   ssim_, учат_, ུའོ_, _ايجن, 
   {{0x22580ea0,0x00000000,0x00000000,0x00000000}},	//   _vurk_, --, --, --, 
   {{0x22580225,0x2a64070d,0x248190c4,0x99880055}},	//   _wurk_, _ltnb_, qsim_, _ajaś_, 
   {{0x23780798,0x00000000,0x00000000,0x00000000}},	//   _uerj_, --, --, --, 
   {{0xdb18283a,0x6700012c,0xb87800e5,0x00000000}},	//   _paví, ोपटक_, lyít, --, 
   {{0x5274016c,0x9f5c00d0,0x821400e5,0x00000000}},	//   _фуру, nivú_, _اورص, --, 
   {{0xb87800dd,0x1cd0031c,0x9d1801c6,0x00000000}},	//   nyít, ུའེ_, ропт_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfe7190c5,0x3f9c16b8,0xdb18a088,0xaaa40139}},	//   _ردا_, _ictu_, _savâ, бъяз_, 
   {{0x3ebc0227,0xfe44084c,0xf96801ec,0x2a6000e5}},	//   _istt_, _унео, ырой_, íjba_, 
   {{0x3d34021f,0x6a500356,0x012c0023,0x9f5c00d7}},	//   _اعاس, _săft, _እናበዝ, divú_, 
   {{0xad180115,0x00000000,0x00000000,0x00000000}},	//   _גודר, --, --, --, 
   {{0xa3cc8fa7,0x6b780bd9,0x3f9c0161,0x9ac801ed}},	//   _शोध_, _גרונ, _mctu_, _خدشہ_, 
   {{0x96340111,0x00000000,0x00000000,0x00000000}},	//   інац, --, --, --, 
   {{0x9378039b,0xb87801d3,0x2458002e,0x3f9c7392}},	// [2a530] ибат_, gyít, 斡mam_, _octu_, 
   {{0xe3b0114f,0xdb2001e1,0xb0c4012d,0x00000000}},	//   فرم_, _àwóy, लिसग, --, 
   {{0x59dc078a,0xe1f0141d,0x9f5c00d0,0x168402f2}},	//   यापर, کسل_, bivú_, _باخێ, 
   {{0x3f9d90c6,0x00000000,0x00000000,0x00000000}},	//   _actu_, --, --, --, 
   {{0xb364011c,0xdb08415b,0x2bd83f7e,0x00000000}},	//   _гъбк, ledä, बामा, --, 
   {{0xa87c00df,0x00000000,0x00000000,0x00000000}},	//   ראגר, --, --, --, 
   {{0xdb1800cf,0xa2940212,0x3ebc0051,0xdb0800a2}},	//   _navà, _нарі, _cstt_, nedä, 
   {{0x2a641419,0xb638019b,0xdce00153,0x00000000}},	//   _rtnb_, _ｆｘ_, namė, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd0100128,0x320d90c7,0x4aa8020f,0x7cfc0241}},	//   _غلا_, ligy_, акон_, _sàré, 
   {{0x1cd0003d,0x3ebc05b1,0x4b24014b,0xd9b40154}},	//   ུའུ_, _gstt_, юмов, য়ানম, 
   {{0xdb1805d5,0x3f9c004c,0xe984036b,0x2bf8009e}},	//   _davà, _zctu_, чқин, ীকেই_, 
   {{0x89347b63,0xdb180798,0xdd94010b,0xd7d40073}},	//   تعدا, _pavã, _хачы, दांच, 
   {{0xcb6800d6,0x66f00024,0xfcf8010f,0x00000000}},	//   _таке_, _lėkš, _כּול, --, 
   {{0x26cc74c3,0xdb0811a8,0x00000000,0x00000000}},	//   ído_, gedä, --, --, 
   {{0x67f00139,0x00000000,0x00000000,0x00000000}},	//   _mäji, --, --, --, 
   {{0x69c4004e,0x26cc010f,0xdb200248,0x9f5c00d7}},	// [2a540] _iaie, ŭdo_, _àwòy, rivú_, 
   {{0x69c590c8,0x2d44001f,0x69d80073,0x2d880210}},	//   _haie, _የኢንቨ, यावी, ócej_, 
   {{0x05745214,0x69c590c9,0xdb1800bc,0x320c0076}},	//   _واحد, _kaie, _kavá, figy_, 
   {{0x69c401c0,0x00c811ca,0xdb186293,0x7afc0139}},	//   _jaie, илек_, _javá, _üpte, 
   {{0x69c590ca,0x3ebd90cb,0x43940952,0x65640067}},	//   _maie, _sstt_, _қаңс, mcih, 
   {{0x69c590cc,0xbe882564,0xdb1990cd,0x65640166}},	//   _laie, асие_, _lavá, lcih, 
   {{0x320c0209,0x69c4062c,0x52740131,0x59dc0404}},	//   bigy_, _oaie, _нуту, यामर, 
   {{0x69c40575,0xdb1990ce,0x65640e14,0x5c7448e5}},	//   _naie, _ravà, ncih, плит, 
   {{0xee340032,0xef14151e,0xd174010b,0xae0000cf}},	//   өнә_, ймә_, _хысы, بويى, 
   {{0xbd8990cf,0x69c5293e,0x60c003f9,0x3f9d90d0}},	//   _چنان_, _aaie, _ismm, _uctu_, 
   {{0x69c590d1,0x200d90d2,0x80c01fbc,0xdb180332}},	//   _baie, _imdi_, लिके, _bavá, 
   {{0x69c590d3,0xdb180109,0xdb0801f4,0x7d040162}},	//   _caie, _vavà, vedä, úkss, 
   {{0x99a401ed,0x69c590d4,0x59dc0490,0x195801ec}},	//   ítők_, _daie, याबर, _қапы_, 
   {{0xa91001e4,0xdb08014a,0x2d9001ee,0xf09000d9}},	//   _geɾm, tedä, _ерәс, ונש_, 
   {{0x69d8276a,0xe730007b,0xe818009d,0xf6082360}},	//   याशी, نصف_, цорч_, ахай_, 
   {{0x69c590d5,0xf54c063f,0x9f4c00fd,0xdb0801bf}},	//   _gaie, _rụba_, _ildä_, gedå, 
   {{0x1cd01b4b,0x80b80406,0x8cccd857,0xb864c019}},	// [2a550] ུའི_, _शैले, तियो, _بابو, 
   {{0xdb190749,0x69c401c0,0xd7f0007b,0xa8140108}},	//   _zavá, _zaie, _أكد_, _одыш, 
   {{0xdb1801b8,0x69c4004c,0x65640009,0x00000000}},	//   _envö, _yaie, bcih, --, 
   {{0x2bb40412,0x69c400cf,0xe2c8004b,0xb7d4009f}},	//   _अस्थ, _xaie, غونو_, _اوڍا_, 
   {{0x45a051d4,0x320c01d3,0x28040166,0x00000000}},	//   _سەلك, rigy_, _ärnü_, --, 
   {{0x409004a9,0x9a9c001f,0x600812fa,0x00000000}},	//   رلىر, _ጉባኤው_, онім_, --, 
   {{0xaf24001f,0xe2980024,0x8fd0008e,0x81b40154}},	//   _ስንመለ, _маё_, _җәлә, জাজ_, 
   {{0x200c01a9,0x80c00aff,0x99ac00fe,0x0d840116}},	//   _emdi_, लिखे, গযুক, члин, 
   {{0x69c590d6,0x0b5801c0,0xbc6801ed,0x004400f1}},	//   _raie, йрны_, یجیے_, _ځیني_, 
   {{0x67f00209,0xefd4001f,0x8ccc08ec,0xdfd8011c}},	//   _täji, ሬዳዋ_, तिबो, _мъх_, 
   {{0x69c590d7,0x3b8001c0,0xdd0000e2,0x69d80b6d}},	//   _paie, элэг, ētāk, याली, 
   {{0x20140210,0x00000000,0x00000000,0x00000000}},	//   ącił_, --, --, --, 
   {{0x69c590d8,0xf770004b,0xdb080450,0x61e401f4}},	//   _vaie, کاټ_, vedå, öili, 
   {{0x69c590d9,0xdc2800f1,0x00000000,0x00000000}},	//   _waie, _وسوه_, --, --, 
   {{0x69c590da,0xf74057c6,0x00000000,0x00000000}},	//   _taie, ееро, --, --, 
   {{0xd90d63e6,0x09e4059f,0x44646baf,0x00000000}},	//   ایی_, _хоин, звав, --, 
   {{0x656403ee,0xf9f8011a,0x00000000,0x00000000}},	// [2a560] rcih, _להקמ, --, --, 
   {{0xca84069c,0xdb1820e4,0x39400166,0xdb08007c}},	//   _ኮይኖም_, _davæ, _яныг, rddö, 
   {{0x77c401c6,0x00000000,0x00000000,0x00000000}},	//   _элэг_, --, --, --, 
   {{0xa3cc0c2e,0xb0c40027,0x3b000098,0x7a3c0153}},	//   _शोर_, लिंग, _hépé_, _būty, 
   {{0x59dc72a2,0xb358010a,0x00000000,0x00000000}},	//   यातर, _ӳкрĕ_, --, --, 
   {{0x9f340220,0x7a3c00b8,0xf99c0100,0xfeb86722}},	//   мелі, _dūty, chèf_, ماعت_, 
   {{0xcfa80b28,0x00000000,0x00000000,0x00000000}},	//   تانم_, --, --, --, 
   {{0xdef80046,0xf99c068c,0x225c022a,0xe3f8009f}},	//   йық_, nièt_, ívku_, _اوڳڻ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x200c100c,0x051800cc,0x00000000,0x00000000}},	//   _umdi_, _দৰৱৰ_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfca80e60,0x6e904fca,0xfe44498b,0xcfb003d4}},	//   _هاتو_, _سلها, _энео, _টোপন, 
   {{0xf99c068c,0xce04143e,0x80c019cc,0x00000000}},	//   dièt_, _تذلي, लिटे, --, 
   {{0x201c1d59,0xf99c007f,0x00000000,0x00000000}},	//   nnvi_, nnèz_, --, --, 
   {{0xa3e05d4f,0xdce190db,0x3b00003e,0xb9580109}},	//   थान_, kamī, _dépé_, ndìk, 
   {{0xd1d402d3,0xf99cff32,0xe6540212,0xdce000e2}},	//   ያታት_, gièt_, евсь, jamī, 
   {{0x54540395,0x64400064,0xb63c0092,0xdce00055}},	// [2a570] дват, _ūmia, _በእውቀ, damī, 
   {{0xf8bc07a8,0x67f00784,0xa87c0375,0xf99c007f}},	//   mwé_, _bäju, _האזר, lgè_, 
   {{0xfbac1b61,0xddc80115,0xea9c0241,0x3e7800de}},	//   ज्यम, _sudŝ, _inṣi_, jūt_, 
   {{0xf99d90dc,0x50b518e9,0xe2900035,0x00000000}},	//   ngè_, дску, اذل_, --, 
   {{0xf3f00597,0xf99c5d7e,0x224400a2,0x10a40395}},	//   _كأس_, liès_, _dhmk_, филн, 
   {{0x80c000e1,0xd0102d4b,0x224400d7,0x00000000}},	//   लिजे, ضلع_, _ehmk_, --, 
   {{0xb8cc1b4b,0x3e7800da,0xf8bc020c,0x2bd80073}},	//   _ནད_, gūt_, hwé_, बासा, 
   {{0xf8bc019f,0x9f240131,0xdce000de,0x3e4c0210}},	//   kwé_, رۈنۈ, camī, _kęty_, 
   {{0x8fd004a9,0xdb081f08,0xa91001e4,0x9f5c0216}},	//   _җәһә, cedú, _veɾk, livý_, 
   {{0x3e7800da,0x317c0165,0xa3e000dc,0x00000000}},	//   būt_, _heuz_, थाय_, --, 
   {{0xad24168d,0xfc44012c,0x9f5c02fb,0x317c0156}},	//   _کراو, _říct_, nivý_, _keuz_, 
   {{0x317c0165,0x00000000,0x00000000,0x00000000}},	//   _jeuz_, --, --, --, 
   {{0x3b009ec6,0x317c05c7,0xf99c068c,0x2d9c00e4}},	//   _pépé_, _meuz_, vièt_, mgue_, 
   {{0x2d9c0d19,0x1c4402bf,0x7f700240,0x00000000}},	//   lgue_, _знім, _ጥዕናዊ_, --, 
   {{0xb6a0287a,0x9f5c0306,0xf41c01f4,0x00000000}},	//   кирл, jivý_, _pvän_, --, 
   {{0xdb18014a,0x2d9c5c66,0x317c0156,0xf8bc0098}},	//   _davä, ngue_, _neuz_, bwé_, 
   {{0x69c0529d,0xf99c067c,0x068024ae,0x7a08033f}},	// [2a580] ômeu, rièt_, _ﺩﯨﻨﯩ, jęty, 
   {{0xaca002e3,0x00000000,0x00000000,0x00000000}},	//   _nnọk, --, --, --, 
   {{0xf99d90dd,0x317c05c7,0x23e00490,0xdce00318}},	//   mièr_, _beuz_, नाबद, tamī, 
   {{0xaca002e3,0xf99c1497,0x00000000,0x00000000}},	//   _anọk, lièr_, --, --, 
   {{0x317d90de,0xdb1800d0,0x2cbc0327,0x25a00205}},	//   _deuz_, _zavä, jwud_, mgil_, 
   {{0x3e68118f,0xa91001e4,0xdb180158,0x2d9c04d4}},	//   ошин_, _ceɾi, _havå, egue_, 
   {{0x317c04cc,0x25a00e14,0x1df801e0,0x80b80210}},	//   _feuz_, ogil_, зейы_, _एनके, 
   {{0x443803f0,0x317c0007,0x2d9c002e,0x4128004e}},	//   llp_, _geuz_, ggue_, _добо_, 
   {{0x25a00254,0x59dc185d,0x00000000,0x00000000}},	//   igil_, यासर, --, --, 
   {{0x3dc401c7,0x443804ce,0x2d9d90df,0x92e000fe}},	//   _waow_, nlp_, ague_, ধনৰ_, 
   {{0x4a840032,0xf99ce74b,0x4438464c,0x00000000}},	//   нъяғ, dièr_, ilp_, --, 
   {{0x2cc00598,0xfbd000bc,0x877001ec,0x00000000}},	//   ärdä_, ताङम, ңғыш, --, 
   {{0x25a00158,0x9f5c0306,0x4438003b,0x00000000}},	//   dgil_, zivý_, klp_, --, 
   {{0x59dc0316,0xf99c068c,0xf8bc01c7,0x64400153}},	//   याहर, gièr_, rwé_, _ūmin, 
   {{0x44380b6f,0xdb080158,0xdcc8004d,0x2bd81b87}},	//   dlp_, jedø, _hỉ_, बारा, 
   {{0x7c3990e0,0x8de80156,0x69c00120,0xdcc8001e}},	//   lltr, འཡརལ, ômet, _kỉ_, 
   {{0x1cb40156,0x317c0489,0x26cc0267,0xf99c0066}},	// [2a590] ཝསི_, _reuz_, ådor_, siès_, 
   {{0x59dc00a5,0xedd839de,0xdb080428,0xf99c068c}},	//   यावर, _मच्छ, wedù, cièr_, 
   {{0x925834d8,0xe29800d6,0xaa080014,0x317c030a}},	//   чает_, дає_, _رٲیل_, _peuz_, 
   {{0x443803e0,0x0b14008f,0x7c380112,0x9f5c00d0}},	//   alp_, ײַער_, hltr, rivý_, 
   {{0xdb080086,0xdcc801fb,0x317c0165,0x9f5c0306}},	//   redù, _nỉ_, _veuz_, sivý_, 
   {{0xdb082142,0x317c05c7,0x9f5c02f0,0x7c3801bf}},	//   bedø, _weuz_, pivý_, jltr, 
   {{0x6354016c,0x245961b5,0x02b4013e,0x317c030a}},	//   _авру, _царь_, _пирӯ, _teuz_, 
   {{0xdcc801fb,0x2d9c021c,0x7c38178a,0xccc40395}},	//   _bỉ_, ugue_, eltr, ебий, 
   {{0x2d9c987e,0x8d7404d3,0xe13402d5,0x8fd07c4c}},	//   rgue_, واکا, _анты, _бәйә, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf99c0ba1,0xa3e01546,0x00000000,0x00000000}},	//   vièr_, थात_, --, --, 
   {{0x9f040228,0x7c3990e1,0x00000000,0x00000000}},	//   _جومو, altr, --, --, 
   {{0xd13402d3,0x18800220,0xdcc8004d,0x8a0400fd}},	//   _እናበል, аңын, _gỉ_, _үзле, 
   {{0x6e3990e2,0xab600150,0x7c3802d0,0x00000000}},	//   llub, _جۇدى, cltr, --, 
   {{0x45d41e2d,0xb8781709,0xf99c180f,0x92e00154}},	//   нцат, rxía, rièr_, ধনু_, 
   {{0x6e3990e3,0xdb081347,0x9f5c0100,0x00000000}},	//   nlub, vedø, nivò_, --, 
   {{0xdcc801fb,0x6e380c90,0xf99c180f,0x873c0092}},	// [2a5a0] _xỉ_, ilub, pièr_, _በድምቀ, 
   {{0x6e380535,0xdb080623,0x00000000,0x00000000}},	//   hlub, tedø, --, --, 
   {{0x6e3990e4,0xd9b4015b,0x88e400fe,0x00000000}},	//   klub, য়ারম, _পেচক, --, 
   {{0xdb0805ac,0x73301183,0x02040006,0xb9580022}},	//   redø, دىما, эзен, reìg, 
   {{0x6e3990e5,0x7c3990e6,0x66040099,0xf99c067c}},	//   dlub, yltr, mhik, lhèc_, 
   {{0x66040ecf,0xdcc801fb,0x26dc004a,0x3ec485a8}},	//   lhik, _rỉ_, _àvos_, есиб, 
   {{0xdcc8001e,0xf99c0ba1,0x6604316f,0xf7700375}},	//   _sỉ_, nhèc_, ohik, נקה_, 
   {{0x660590e7,0x9f5c3eba,0x00000000,0x00000000}},	//   nhik, tivó_, --, --, 
   {{0x9f4c2776,0xf54c063f,0x60c42fbe,0xf53c0efa}},	//   _kodë_, _nụla_, çimd, _ubåt_, 
   {{0x7c3990e8,0x660590e9,0x2d8d90ea,0x9f5cea68}},	//   ultr, hhik, _edge_, rivó_, 
   {{0x59dc0316,0x660590eb,0x9f4c0240,0xadb001ec}},	//   यालर, khik, _modë_, _әбіш, 
   {{0x6e3990ec,0xf54c44fc,0xdcc80016,0x7c840798}},	//   club, _bụla_, _tỉ_, _зуке, 
   {{0x660590ed,0xec6c05d9,0x00000000,0x00000000}},	//   dhik, _هٿن_, --, --, 
   {{0x2bd409d9,0x779050b5,0x9b940276,0x69c000d8}},	//   _भोपा, دیدا, _рикц, ômer, 
   {{0xf644db15,0x66b590ee,0x00000000,0x00000000}},	//   ехан, лбру, --, --, 
   {{0xe6100302,0x7bc822a9,0x660590ef,0xeb38011a}},	//   مشق_, _hafu, ghik, _מעוש, 
   {{0x7bc990f0,0xa89800c7,0x00000000,0x00000000}},	// [2a5b0] _kafu, _зкыу_, --, --, 
   {{0x7bc990f1,0x66040109,0xa5340228,0x241802bf}},	//   _jafu, ahik, унуч, нією_, 
   {{0x7bc990f2,0x9f4c0200,0xd2509a73,0x660590f3}},	//   _mafu, _dodë_, لچر_, bhik, 
   {{0x7bc990f4,0x15140024,0x00000000,0x00000000}},	//   _lafu, _адмя, --, --, 
   {{0xa3cc1a22,0xc1f0000d,0xd25800ef,0x00000000}},	//   _शोक_, _अकरब_, _viņ_, --, 
   {{0x7bc990f5,0x667401d5,0xa158074d,0xbb3802dd}},	//   _nafu, _جدیر, хачу_, _ﻓﻬﻡ_, 
   {{0x6e39397e,0x00000000,0x00000000,0x00000000}},	//   tlub, --, --, --, 
   {{0x7bc802ce,0x6e380481,0x9f4c007f,0x9e64280f}},	//   _aafu, ulub, _modè_, داون, 
   {{0x6e3990f6,0x9f5c0622,0x5dd411ed,0x9f4c007f}},	//   rlub, rivò_, ующу, _lodè_, 
   {{0x6e3990f7,0x60c40205,0x00000000,0x00000000}},	//   slub, çime, --, --, 
   {{0x91f41b57,0x7bc8d565,0x4a4411ed,0xda780953}},	//   _आवाज_, _dafu, кнов, няў_, 
   {{0x7bc80083,0x6e38025c,0x6604036e,0x00000000}},	//   _eafu, qlub, xhik, --, 
   {{0x7bc990f8,0x6cb00220,0x66043664,0xdb0800a2}},	//   _fafu, _сөйт, vhik, medý, 
   {{0x7bc990f9,0x9f4c01e1,0x660404fe,0xdb08010e}},	//   _gafu, _bodè_, whik, ledý, 
   {{0x6b80002d,0x96b80969,0x4614004b,0xaa9000fb}},	//   _ieng, нуту_, نوسر, _сѳлә, 
   {{0x6b8190fa,0x66040d04,0x3930063f,0xab6002dd}},	//   _heng, uhik, ụfụ_, _جۇگى, 
   {{0x6b8190fb,0x7bc93bbe,0x660590fc,0xc7940022}},	// [2a5c0] _keng, _yafu, rhik, _ирны, 
   {{0x660590fd,0x389804ac,0xaee0002b,0x0318007b}},	//   shik, _קיינ, _guṇo, وتات_, 
   {{0x6b8190fe,0x660590ff,0x8c3c03be,0x6aac0f22}},	//   _meng, phik, muşd, টিকো, 
   {{0xdb1800d0,0x8c3c2d9a,0x00000000,0x00000000}},	//   _pavú, luşd, --, --, 
   {{0x00d842c6,0x6b800793,0x81b40154,0x5f9401a9}},	//   ببات_, _oeng, ড়াল_, гилт, 
   {{0xdfd016a2,0xd17801ec,0xb03000d4,0x8c3c03b9}},	//   صيب_, _үсті_, аніш, nuşd, 
   {{0x645d9100,0x52980801,0x7bc99101,0xb5f804d4}},	//   _iiri, _пътя_, _rafu, _diáf, 
   {{0x645d9102,0x6b800369,0x9d0400ee,0x00000000}},	//   _hiri, _aeng, лҗек, --, 
   {{0x645d9103,0x7bc99104,0xf06003b7,0x7638008f}},	//   _kiri, _pafu, _вкуп, ועקג, 
   {{0x6b819105,0x645d9106,0x7bc806be,0x00000000}},	//   _ceng, _jiri, _qafu, --, 
   {{0x6b8171ef,0xcfa8e9d0,0x7bc83664,0xb4dc07f7}},	//   _deng, _سالم_, _vafu, _थप्_, 
   {{0x7bc87ab0,0x6b819107,0x9f4c04cc,0x00000000}},	//   _wafu, _eeng, _rodè_, --, 
   {{0x6b80dc7c,0x7bc8f0e6,0x645c0597,0x6aac02f5}},	//   _feng, _tafu, _oiri, টিগো, 
   {{0x6b819108,0x645d9109,0x7bc80418,0x9f4c068c}},	//   _geng, _niri, _uafu, _podè_, 
   {{0x1cd0031c,0xb5a4a517,0xba4401c6,0xe6640354}},	//   ུའམ_, край, _ихий, итто, 
   {{0x6b81910a,0x645d910b,0x9f4c0129,0xd1d40092}},	//   _zeng, _airi, _codé_, ረቤት_, 
   {{0xca28008f,0x00000000,0x00000000,0x00000000}},	// [2a5d0] _רופֿ, --, --, --, 
   {{0x6b800564,0xdb1804cc,0x00000000,0x00000000}},	//   _xeng, _savù, --, --, 
   {{0x69d80073,0xf2c402e8,0x00000000,0x00000000}},	//   याची, ъсан, --, --, 
   {{0x645d910c,0xa2941ed2,0xe1f07427,0xdb0825e6}},	//   _eiri, раці, يسن_, ledó, 
   {{0xe1352605,0x30a41efc,0x645d910d,0xa4e401b9}},	//   анцы, трев, _firi, _кўрк, 
   {{0x645cd95c,0xdb182ab7,0x4f2400cf,0xc0e000d8}},	//   _giri, _favø, лдлб, сошк, 
   {{0x09c8009e,0x00000000,0x00000000,0x00000000}},	//   ষাতা, --, --, --, 
   {{0x645d910e,0x00000000,0x00000000,0x00000000}},	//   _ziri, --, --, --, 
   {{0x6b81910f,0x645d9110,0xdb080209,0x00000000}},	//   _peng, _yiri, redý, --, 
   {{0x645d9111,0x6b80016d,0x5fc0012c,0xdb099112}},	//   _xiri, _qeng, _एसएल, bedü, 
   {{0x6b819113,0xaca00241,0x34dc00cd,0x00000000}},	//   _veng, _isọj, नमुद, --, 
   {{0x6b819114,0x00000000,0x00000000,0x00000000}},	//   _weng, --, --, --, 
   {{0xb9580ffb,0x9f4c0129,0x068000d1,0x00000000}},	//   ddìs, _rodé_, _ﺩﯨﻴﯩ, --, 
   {{0x7c900597,0x998805c7,0xc7948305,0xf1e401ec}},	//   _الوص, _amań_, ырмы, _ﺍﻗﻴﻘ, 
   {{0x645d9115,0xa9100115,0x8c3c6656,0xd1bc01f3}},	//   _riri, _peɾs, ruşd, ደስት_, 
   {{0x95980372,0xa3cc04fa,0x00000000,0x00000000}},	//   ктуу_, _शोज_, --, --, 
   {{0x645d9116,0xdb08068c,0xa3e007f7,0x2d600092}},	// [2a5e0] _piri, bedó, थाल_, _ለኢንቨ, 
   {{0x645d9117,0x64a4c5dc,0x4384215c,0xdb085923}},	//   _qiri, лаға, الاق, yedü, 
   {{0xdb080ba1,0x96940139,0x4ca800eb,0xfba409ab}},	//   ledò, _кряш, _কনফু, _खासम, 
   {{0x645d9118,0xd25802bf,0xdb080793,0xbea401d5}},	//   _wiri, вці_, vedü, ҳший, 
   {{0xdb080428,0x40941b50,0x55c457aa,0x34900006}},	//   wedü, урет, _таяғ, _лаўр, 
   {{0x645d9119,0xccf80034,0xbea401c0,0x3ec80640}},	//   _uiri, dyś_, гший, ећим_, 
   {{0xf99c034c,0x00000000,0x00000000,0x00000000}},	//   dhèn_, --, --, --, 
   {{0x69d41f13,0x00000000,0x00000000,0x00000000}},	//   _बोली, --, --, --, 
   {{0x2dd400c6,0xfb84760c,0xa3e8060e,0xdb080790}},	//   طبية_, лынн, _मचा_, sedü, 
   {{0x670438d2,0x20189ab0,0xdb080205,0x00000000}},	//   रनाक_, _öri_, pedü, --, 
   {{0xa3ac0fc8,0x7051207f,0xaee00055,0x00000000}},	//   _गान_, _انلا, _viṣm, --, 
   {{0xccf8033f,0xfe442b2d,0xda34005b,0x00000000}},	//   byś_, _ёндо, ремы, --, 
   {{0xdb08007f,0x1b0c0154,0xe87401d5,0xccf80210}},	//   gedò, _সুখে_, یچیگ, cyś_, 
   {{0xed5401b9,0xf99c02e2,0x68e003cd,0x00000000}},	//   _соч_, chèn_, åmda, --, 
   {{0xdb09911a,0x4c34004e,0x00000000,0x00000000}},	//   redó, _тэцт, --, --, 
   {{0x5575911b,0xd1f802d3,0x00000000,0x00000000}},	//   ргат, ቋታት_, --, --, 
   {{0x7af9911c,0xdb0856ed,0xd79400a7,0x98a401e0}},	// [2a5f0] lytt, cedò, _кипъ, _туйҙ, 
   {{0x59dc041c,0x8c3c0356,0x81b000eb,0x33f40066}},	//   याकर, muşc, _ঝোল_, دسرس, 
   {{0x7af80ac7,0x8c3c06be,0x00000000,0x00000000}},	//   nytt, luşc, --, --, 
   {{0x26140574,0xfff40214,0x6b4c00e5,0x00000000}},	//   नोदी_, یکلت_, lógé, --, 
   {{0x7af8383d,0xc44401d5,0xa2940150,0x00000000}},	//   hytt, _چیقن_, _қаті, --, 
   {{0xa3ac4614,0x7af83167,0xa3e00882,0x35a8000d}},	//   _गाय_, kytt, थाः_, _छाड़, 
   {{0x7af80108,0x00000000,0x00000000,0x00000000}},	//   jytt, --, --, --, 
   {{0xd1bc044e,0x5334016c,0xb5f801ed,0x8cb5911d}},	//   ደስቲ_, _беҳт, _hiáb, асоч, 
   {{0xfde40372,0xa3ac00af,0xf99c00f2,0xfa18009e}},	//   рдык_, _गाम_, thèn_, ণকাল_, 
   {{0x7af803cd,0x00000000,0x00000000,0x00000000}},	//   fytt, --, --, --, 
   {{0xa72000bd,0xb60000d0,0x00000000,0x00000000}},	//   _ধর্ম_, _zháň, --, --, 
   {{0xf99c0561,0x0d2000cf,0x00000000,0x00000000}},	//   shèn_, _мүйү, --, --, 
   {{0xdb1800e4,0x930000cc,0x00000000,0x00000000}},	//   _iavý, _এখোপ_, --, --, 
   {{0x7af812ed,0x07a42377,0x291c00b8,0x00000000}},	//   bytt, јавн, _śvas_, --, 
   {{0x7af8383d,0xf4180154,0x8ccc2802,0x00000000}},	//   cytt, তকার_, तिको, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [2a600] --, --, --, --, 
   {{0x78f80a7c,0x37e00354,0x69ac2052,0x00000000}},	//   _סליפ, _доьг, _झाडी, --, 
   {{0xa3ad911e,0x222800f1,0x46a8000d,0x00000000}},	//   _गाठ_, هګري_, _छमिह, --, 
   {{0xdb1802fb,0x2a60058a,0x00000000,0x00000000}},	//   _navý, _jiib_, --, --, 
   {{0xd5ac040b,0xb5f80077,0xf99c04fb,0x00000000}},	//   _سہل_, _fiáb, dhèl_, --, 
   {{0x7af802f6,0x00000000,0x00000000,0x00000000}},	//   yytt, --, --, --, 
   {{0x44280113,0xdd95911f,0xc1d00304,0x00000000}},	//   _ijb_, байы, _мөдә, --, 
   {{0x4428017a,0x7af8023a,0xd24c00d1,0xdb1403e0}},	//   _hjb_, vytt, _كۆل_, ğaüs, 
   {{0xdd940046,0xa0d4004b,0xb60000d7,0x00000000}},	//   _ғалы, _دښاغ, _uháň, --, 
   {{0x34b4025f,0x7af802f6,0x9f4c0122,0x00000000}},	//   ספים_, tytt, _hodí_, --, 
   {{0xfbd00a81,0x2a6000e8,0x5a35589d,0x201c09a8}},	//   متھ_, _biib_, йнот, mivi_, 
   {{0xf2d004ac,0x201d9120,0x2a600421,0xb878011f}},	//   קער_, livi_, _ciib_, lxíi, 
   {{0x1bd40c04,0x7af8049b,0x2a600009,0x6b4c01d3}},	//   _голя, sytt, _diib_, tógé, 
   {{0x9f4c0122,0x201d9121,0x7af8ea7d,0x00000000}},	//   _lodí_, nivi_, pytt, --, 
   {{0xb4dc0882,0xf99c068c,0xa3e00da3,0x66f401f4}},	//   थम्_, lhèm_, थाई_, опру, 
   {{0x4428020b,0x8c3d9122,0x257405a9,0x6b4c01d3}},	//   _ajb_, muşa, يۇپس, sógé, 
   {{0xf3659123,0x201d9124,0x44297603,0xf65c003a}},	// [2a610] атен, kivi_, _bjb_, _viæ_, 
   {{0x44280cf4,0xa3ac01f9,0x00000000,0x00000000}},	//   _cjb_, _गाण_, --, --, 
   {{0x201d9125,0xd1746b28,0xb5f80077,0x931800c6}},	//   divi_, былы, _viáb, دقاء_, 
   {{0xb5f83822,0x201c0327,0x59dc190e,0x00000000}},	//   _diác, eivi_, याटर, --, 
   {{0x44289877,0x201c0010,0x712433d2,0x00000000}},	//   _fjb_, fivi_, جرال, --, 
   {{0x201c014a,0x00000000,0x00000000,0x00000000}},	//   givi_, --, --, --, 
   {{0x2294bdc4,0xa29402bf,0x1ea819bc,0xb5f800d8}},	//   _миря, _марі, لايي_, _giác, 
   {{0xf1cc0c2e,0xf20418ac,0x4c842ccb,0x22857e0c}},	//   _सोचन, _тяго, блив, _фург, 
   {{0x201c07f5,0x202409cc,0xa158040e,0x00000000}},	//   bivi_, ðrið_, _вату_, --, 
   {{0x201c03b4,0x2a640ac5,0x2a60058a,0xd0111b44}},	//   civi_, _punb_, _siib_, _علا_, 
   {{0xdb180022,0x59d820f0,0xdd100419,0xecb400eb}},	//   _tavý, _बोहर, _výšo, জিইড, 
   {{0xc0bc001f,0x60e0e73c,0x2bd40acd,0x00000000}},	//   ሰጥም_, _üzmä, _भोरा, --, 
   {{0x091805f5,0x2a6000af,0xa3e80307,0x893400c6}},	//   уцны_, _viib_, _मचल_, إعجا, 
   {{0x6d499126,0x62880200,0x8c3c0139,0x00000000}},	//   _izga, _çdog, buşa, --, 
   {{0xca7401c0,0xe74800fd,0x2a605a7a,0xc7a400fb}},	//   _уулы, рүне_, _tiib_, _һипк, 
   {{0x201d9127,0x05640801,0xc5659128,0x065401d5}},	//   zivi_, сван, скак, стгў, 
   {{0xc7a4040e,0xdb1800c7,0x764c0175,0x201c4cba}},	// [2a620] _липк, _favó, _dhcy, yivi_, 
   {{0x201c86da,0x00000000,0x00000000,0x00000000}},	//   xivi_, --, --, --, 
   {{0x201d9129,0x59dc1a04,0x6d480175,0xf5200023}},	//   vivi_, याचर, _lzga, _ተዘርዚ, 
   {{0x6d4801d5,0x00000000,0x00000000,0x00000000}},	//   _ozga, --, --, --, 
   {{0x201d912a,0xdb1804cc,0x26d80165,0x15b000d1}},	//   tivi_, _savü, lvro_, _تەقس, 
   {{0xdb080793,0xc2100a81,0xbe4800f2,0x00000000}},	//   medö, _کٔر_, گشتم_, --, 
   {{0x4439912b,0x201d912c,0x26d92584,0x93580114}},	//   mop_, rivi_, nvro_, _врту_, 
   {{0x5c75912d,0x201d912e,0x9df8084c,0x5c99912f}},	//   олит, sivi_, рнит_, акия_, 
   {{0x9f4c0589,0xef141fc7,0xdb080793,0x7b6428e5}},	//   _bodã_, имә_, nedö, йтне, 
   {{0x44395377,0x79a40598,0x81b40154,0x7c6400f1}},	//   nop_, әрне, ড়াও_, ټاکل, 
   {{0x7e9401d9,0x6d4801c6,0x3f8c0e05,0x5c980092}},	//   _اۆبر_, _ezga, mafu_, _ቀነኒሳ_, 
   {{0x3f8d9130,0x19599131,0x8d840372,0x6c8001ed}},	//   lafu_, ианы_, _ۇشۇن, _کلوم, 
   {{0x63bc0219,0xdb18dfd4,0xdb0801b8,0xada06d7d}},	//   _obrn, _cavò, jedö, _хачл, 
   {{0x443806a3,0x3f8d9132,0x7e600332,0x8c3c0356}},	//   jop_, nafu_, _hiop, puşa, 
   {{0x7c399133,0x44399134,0x9f4c0170,0x2bb40302}},	//   motr, dop_, _jodà_, _הפוך_, 
   {{0x3f8d9135,0x7c380851,0x9f4c011c,0xdd0800d0}},	//   hafu_, lotr, _modà_, _môžm, 
   {{0x3f8d9136,0x798c0921,0x9f4d0416,0x60c40259}},	// [2a630] kafu_, macw, _lodà_, çiml, 
   {{0x7c399137,0x44399138,0x7e619139,0x00000000}},	//   notr, gop_, _liop, --, 
   {{0x1634016c,0x3f8d913a,0x00000000,0x00000000}},	//   _меоя, dafu_, --, --, 
   {{0x7c39913b,0xf99c0066,0xdb080267,0x798c2f0f}},	//   hotr, dhèk_, bedö, nacw, 
   {{0x7c39913c,0x4439913d,0x3f8d913e,0xdb080793}},	//   kotr, bop_, fafu_, cedö, 
   {{0x4439913f,0x7c399140,0x63bc020b,0x3f8d9141}},	//   cop_, jotr, _gbrn, gafu_, 
   {{0x22840323,0x60c00175,0x798c1418,0x59c84196}},	//   _нутг, _epmm, kacw, िजार, 
   {{0x3f8c0083,0x7e60054e,0xf2c0134b,0xf12401f4}},	//   aafu_, _ciop, _мөҗи, _льзо, 
   {{0x7c399142,0x3f8d1c9a,0x8fc40014,0xa184010b}},	//   fotr, bafu_, _وٲرن, _хысл, 
   {{0x6d480219,0x09c000dc,0x8b240395,0x28c4190e}},	//   _vzga, षज्य, ждое, _लैगि, 
   {{0x2fc59143,0x7e600093,0xdb18068c,0xb38802d3}},	//   meng_, _fiop, _savò, _ቅኑዕን_, 
   {{0x2fc59144,0xf1b82ecf,0x7e603eb9,0x6f0803ee}},	//   leng_, ोजिन, _giop, ımcı, 
   {{0x29043ad5,0x6d480598,0x44399145,0x6e380989}},	//   áma_, _uzga, yop_, moub, 
   {{0x2fc59146,0x290c068f,0xdb08014a,0x6e399147}},	//   neng_, ąda_, vedö, loub, 
   {{0x798c53ff,0x44399148,0x99880432,0x00000000}},	//   bacw, vop_, _olaň_, --, 
   {{0x2fc59149,0xdb0801b8,0x6e38002d,0x629800d0}},	//   heng_, tedö, noub, ávom, 
   {{0x2fc49d8d,0xdb4c04d3,0xdb1803b2,0x3f8c0083}},	// [2a640] keng_, _لێی_, _havð, yafu_, 
   {{0x2fc45d1a,0x9f880252,0xdb080267,0x6e380100}},	//   jeng_, jóði_, redö, houb, 
   {{0x42c80dd8,0x2fc5914a,0xdb0801b8,0x6e3804ce}},	//   рген_, deng_, sedö, koub, 
   {{0x4439914b,0x7c380170,0xb5f800dd,0xa3ac7662}},	//   sop_, zotr, _hián, _गाव_, 
   {{0x4439914c,0x2fc5914d,0x3f8d914e,0x6604009f}},	//   pop_, feng_, tafu_, mkik, 
   {{0x2fc5914f,0x7e619150,0x9f4c05d5,0x660431af}},	//   geng_, _siop, _podà_, lkik, 
   {{0x7e619151,0x7c399152,0x3f8d9153,0xdd948ef8}},	//   _piop, votr, rafu_, пайы, 
   {{0x66059154,0xb5f8283a,0x52759155,0x3f8d1c9a}},	//   nkik, _lián, _хуру, safu_, 
   {{0x7c381311,0x2fc4c6ee,0x3f8d9156,0xf6500302}},	//   totr, beng_, pafu_, וצה_, 
   {{0x2fc59157,0x5b1418a4,0x66059158,0x00000000}},	//   ceng_, змот, hkik, --, 
   {{0x7c381311,0x66059159,0x7e602b3b,0x8c3d915a}},	//   rotr, kkik, _tiop, muşl, 
   {{0x7c39915b,0x8c3cec7b,0x6e3806af,0x7e600798}},	//   sotr, luşl, coub, _uiop, 
   {{0x7c39915c,0x7e78fa13,0x798c00ca,0x66045948}},	//   potr, _http, racw, dkik, 
   {{0x660401c6,0x798c009a,0x998833dc,0x8c3c1432}},	//   ekik, sacw, _ukaž_, nuşl, 
   {{0x660401f5,0x75880212,0x7d0403cd,0xcce40137}},	//   fkik, исав_, øksf, _وسۇي, 
   {{0x6605915d,0x1dbc0882,0x2fc52d23,0x62f000eb}},	//   gkik, ्जित, zeng_, চনায়_, 
   {{0x2fc5915e,0x32e8016b,0xdb0800d8,0x69d40073}},	// [2a650] yeng_, mɔyɛ_, redõ, _बोटी, 
   {{0x69bc779e,0xb5f8001e,0x6605915f,0x28c4033f}},	//   ष्ठी, _gián, akik, _लैटि, 
   {{0xc7b006a9,0x1dbc1361,0x2fc404cc,0xa3ac0490}},	//   _אבי_, ्जात, veng_, _गार_, 
   {{0x2fc47bd2,0xd1306923,0x6e380077,0x00000000}},	//   weng_, ىما_, xoub, --, 
   {{0x2fc59160,0x7e782110,0x6e38017a,0x48dc10fa}},	//   teng_, _attp, voub, खियो_, 
   {{0x2fc40036,0x6e380100,0x8c3c4283,0x00000000}},	//   ueng_, woub, vuşo, --, 
   {{0x2fc59161,0x63b404bf,0x32e8016b,0x9f4c0306}},	//   reng_, žený, kɔyɛ_, _podá_, 
   {{0x2fc4c6ee,0x4c84524d,0x2d8800d0,0x00000000}},	//   seng_, плив, úce_, --, 
   {{0x2fc59162,0x6e399163,0xf99c0ba1,0x7e78007c}},	//   peng_, roub, chèi_, _ettp, 
   {{0x660401c4,0x2fc4047e,0xd1400210,0x00000000}},	//   zkik, qeng_, gnął_, --, 
   {{0x66040986,0x626c0790,0x00000000,0x00000000}},	//   ykik, _eşof, --, --, 
   {{0x2a647c7b,0x91c805f9,0x8c3c0205,0xfc4402d2}},	//   ömb_, _रसोइ, muşm, _þínr_, 
   {{0xad24583f,0xec699164,0xa3ac0c66,0x8c3c05d1}},	//   _براو, _трек_, _गाल_, luşm, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x66059165,0xbb419166,0x8c3c0365,0xb6c801d3}},	//   tkik, _пешк, nuşm, یاہے_, 
   {{0x66045b83,0x6f0c16b8,0x7d0403cd,0x257c013a}},	//   ukik, _ęccl, øksg, kálů_, 
   {{0x66041c65,0x69bc00dc,0x03a59167,0x00000000}},	// [2a660] rkik, ष्णी, зизо, --, 
   {{0x66059168,0x04451d84,0x8c3c56f8,0x257c01ef}},	//   skik, чезн, kuşm, dálů_, 
   {{0xb5f800dd,0x4424041a,0x161801ad,0xb7f8011a}},	//   _kiál, đo_, नोहर_, _הפית, 
   {{0x09c8009e,0x733010e0,0x00000000,0x00000000}},	//   ষাকা, رىنا, --, --, 
   {{0x26dc0427,0x9f5c0216,0xd1400210,0xdfd4009d}},	//   _švoh_, rkví_, ynął_, долы, 
   {{0x24819169,0x9f5c0118,0xf1bc0003,0x00000000}},	//   mpim_, skví_, ġġar_, --, 
   {{0x24802af2,0x78680003,0x9e3446e5,0xf99c007f}},	//   lpim_, _iżve, мекч, chèw_, 
   {{0x23ac1df1,0x00000000,0x00000000,0x00000000}},	//   _चाँद, --, --, --, 
   {{0x79a41688,0x248002d1,0xa11400db,0xbd8800db}},	//   үрме, npim_, _تۈشت, _ۇنان_, 
   {{0x76ac0134,0x30780375,0x00000000,0x00000000}},	//   _wɔyɛ, _לאמנ, --, --, 
   {{0x200d916a,0xe8b80327,0xda341de6,0x7e7802d0}},	//   _ildi_, _བདུག, дены, _uttp, 
   {{0x24800309,0xa2c4012c,0xdd9006c2,0xd1400210}},	//   kpim_, _रहन्, _شوت_, snął_, 
   {{0xb5f84dce,0x23ac0a1c,0x7d040fac,0xbc2400db}},	//   _diál, _चांद, øksd, _ىرتى, 
   {{0x960439de,0xd9b400cc,0x00000000,0x00000000}},	//   रस्ट_, _জোখম, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x200c0175,0x00000000,0x00000000,0x00000000}},	//   _lldi_, --, --, --, 
   {{0xc3180183,0x200c07d6,0xa5f9916b,0x777400b5}},	// [2a670] _তুলি_, _oldi_, чету_, _tfxx, 
   {{0xb880012c,0x00000000,0x00000000,0x00000000}},	//   říst, --, --, --, 
   {{0x8c400730,0xd7585285,0x99980118,0x272000eb}},	//   äßig, _گلگت_, nosů_, _মুঠো_, 
   {{0x200d916c,0x98b01524,0x8c3c029f,0xc69008a8}},	//   _aldi_, _जमाए, vuşm, _באט_, 
   {{0x92ac00bd,0xb1914977,0x40900131,0x31300022}},	//   কবে_, _үлгә, پلىر, хҵар, 
   {{0xdb1800e4,0xc4d00375,0x213400d0,0x257c0118}},	//   _havõ, _שגם_, _ťahá_, rálů_, 
   {{0x0e54016c,0x74d94d23,0xfe6cd719,0x2bd43af4}},	//   мъия, निवृ, لگن_, _भोगा, 
   {{0xcfcc2aab,0x200d916d,0x8c3c1ae4,0x13a40133}},	//   লাইন, _eldi_, ruşm, _رۆڵی_, 
   {{0x741c02f5,0x4c35916e,0xb8780005,0xdb180254}},	//   বকীয়_, дэнт, nvíd, _mavõ, 
   {{0xa0c5916f,0xa3d001ad,0xb87800e4,0x8c3c0205}},	//   _سيمو, वजय_, ivíd, muşk, 
   {{0x9f059170,0xe7ec6b9b,0xaf04004e,0x00000000}},	//   _كوكو, ञासा_, _эчак, --, 
   {{0x24800986,0x41901870,0x6f0000a2,0x00000000}},	//   ypim_, ﻟﻤﺎﻱ_, mync, --, 
   {{0xaca001f2,0x9f5801ed,0xbb2c0131,0x6f00514c}},	//   _maịk, özök_, ﯩﻜﻰ_, lync, 
   {{0x2d8d1e6d,0xb5f809ff,0x60c59171,0xb8780308}},	//   _hege_, _diám, çimi, dvíd, 
   {{0xf740055f,0xdb1801b8,0xf7c80131,0x248002d1}},	//   веро, _savö, ﻪﺗﻠﻪ, wpim_, 
   {{0x23781591,0xdb1801b8,0x2d8c0694,0x44880139}},	//   _sfrj_, _pavö, _jege_, жбан_, 
   {{0x2d8c0548,0xdb180254,0x92ac0154,0x2480007f}},	// [2a680] _mege_, _davõ, কবো_, upim_, 
   {{0x4ad00f44,0x5f1000dc,0x24559172,0xe8545902}},	//   _तनाव, तनम्_, käme_, _سۆزد, 
   {{0x2d8c000f,0x26dc0124,0x00000000,0x00000000}},	//   _oege_, _évo_, --, --, 
   {{0x2d8d9173,0x6f000034,0xb87800d8,0x9f4c10d1}},	//   _nege_, dync, bvíd, _jodå_, 
   {{0xf99c0561,0x248002d1,0xb8780d12,0x245401e3}},	//   chèu_, qpim_, rvíg, tämd_, 
   {{0x23780798,0xdbcc0008,0xf99c180f,0x00000000}},	//   _ufrj_, jóðu, lhèt_, --, 
   {{0x2d8d9174,0xe7c000cd,0x24543f3b,0x6f5401a9}},	//   _bege_, श्यप, rämd_, машё_, 
   {{0xf99c180f,0xb0500131,0xabc40150,0x8c3c0139}},	//   nhèt_, ىھەت, _ﺒﻤﻨﺎ, buşk, 
   {{0x2d8c5113,0xb140022e,0xdbcc1d1d,0x00000000}},	//   _dege_, _антл, fóðu, --, 
   {{0x6c808bee,0x2d8d9175,0x2b440142,0xdbcc148b}},	//   کلیم, _eege_, _bync_, góðu, 
   {{0x2d8c002e,0xdb192722,0xa3acdd53,0x7d0403cd}},	//   _fege_, _navô, _गाई_, øksb, 
   {{0x2d8c110e,0xf99c0066,0x6f140014,0x2b44010e}},	//   _gege_, akèn_, _غٲنس_, _dync_, 
   {{0x6bd0036b,0x6ba400b5,0xf99c0066,0x3f9c0166}},	//   رتیر, ærgå, dhèt_, _kdtu_, 
   {{0x2d8d9176,0x368801c6,0x00000000,0x00000000}},	//   _zege_, жсан_, --, --, 
   {{0x36200014,0x2d8c0ca8,0x97240066,0x00000000}},	//   نوسہ, _yege_, رفرو, --, 
   {{0x7bd91687,0xf4859177,0x2244022e,0xa3ac00bc}},	//   ldtu, дужн, _nkmk_, _गाउ_, 
   {{0x84c0c7e0,0x5454470c,0x656000d2,0x00000000}},	// [2a690] ләрд, еват, _úmhl, --, 
   {{0xaca002e3,0x241800d4,0x00000000,0x00000000}},	//   _saịk, мією_, --, --, 
   {{0xd0580220,0x92a80032,0x91ac0208,0xe57001d3}},	//   үрлі_, ясаҡ_, _nhẹ_, اطہ_, 
   {{0x3f9c0004,0x50b40c9e,0xf99c3c51,0xf1bc031c}},	//   _adtu_, еску, chèt_, ġġor_, 
   {{0x2d8cf751,0xd478008f,0x62880240,0x91c4008e}},	//   _rege_, _מאָל, _çdon, _җәел, 
   {{0x6f019178,0xb4c80ce0,0x2d8c0ea0,0xd010007b}},	//   tync, लबी_, _sege_, طلع_, 
   {{0x2d8d9179,0x6ed003e3,0x00000000,0x00000000}},	//   _pege_, _kəbə, --, --, 
   {{0xa2cc02ab,0x321c0309,0xd0d402e8,0xa1a80137}},	//   सबर्, _umuy_, _побъ, _отуз_, 
   {{0x2d8c0158,0x4fc007d2,0x8c3c054e,0x629802f0}},	//   _vege_, _مەشە, luşi, ávov, 
   {{0xaf041b6b,0x2d8c03fa,0xf99c068c,0x2b44015d}},	//   _очек, _wege_, zhèt_, _pync_, 
   {{0x2d8d917a,0xdbcc022c,0x8c3c054e,0x7ee000ec}},	//   _tege_, róðu, nuşi, _مڃين, 
   {{0xaca00521,0xb5f801ed,0xc330025d,0xabc40150}},	//   _abụk, _diák, רוט_, _ﺒﻤﻬﺎ, 
   {{0xea9c0241,0x487802e8,0x00000000,0x00000000}},	//   _baṣi_, ясня_, --, --, 
   {{0x29c800f7,0x7aec0332,0x8c3c496e,0x00000000}},	//   чтүү_, óití, kuşi, --, 
   {{0xba180113,0xf99c00f2,0x6ed003b9,0x00000000}},	//   _ay鯵i, thèt_, _bəbə, --, 
   {{0x6ed006be,0xc724009d,0x00000000,0x00000000}},	//   _cəbə, _үдий, --, --, 
   {{0x69c40135,0x6ed006be,0xb5c00166,0x00000000}},	// [2a6a0] _ibie, _dəbə, ыйтл, --, 
   {{0x68e5917b,0x69c5917c,0x75400137,0x59c16da3}},	//   _irid, _hbie, унуз, ष्ठर, 
   {{0x7868025c,0xf99c02bd,0x5275917d,0xc1e80139}},	//   _iżva, chès_, вучу, зьле_, 
   {{0x68e5917e,0x69c40135,0xf99c180f,0x65c402dd}},	//   _krid, _jbie, lhèr_, _шұба, 
   {{0x69c5917f,0x68e40003,0x00d82dd0,0x00000000}},	//   _mbie, _jrid, ثبات_, --, 
   {{0xb3cc00bd,0xc0e802d3,0x69c4025c,0xb878021c}},	//   রাউজ, _መደረ_, _lbie, lvíc, 
   {{0x69c59180,0x4f9400d8,0x00000000,0x00000000}},	//   _obie, трчу, --, --, 
   {{0x6ed011a9,0x68e59181,0x387c0276,0x44d002e2}},	//   _xəbə, _orid, ţuri_, _kņ_, 
   {{0x68e40472,0xed540063,0x601401e1,0x80a4085b}},	//   _nrid, ноћ_, _ràmf, _سمان, 
   {{0x69c59182,0xb87801ef,0x00000000,0x00000000}},	//   _abie, hvíc, --, --, 
   {{0x625800c6,0xfbd00a81,0x7bd80217,0x44d0007f}},	//   ríof, نتھ_, rdtu, _lņ_, 
   {{0xb878012c,0x68e52446,0x91e4037e,0x26cc0327}},	//   jvíc, _brid, _liのb, ħdol_, 
   {{0x68e59183,0x69c4031c,0x44d0007f,0x625801e7}},	//   _crid, _dbie, _nņ_, míod, 
   {{0x6ed00cc1,0x69c4016b,0x68e59184,0x6258007b}},	//   _səbə, _ebie, _drid, líod, 
   {{0x5a34004e,0x35e40006,0xba440354,0x00000000}},	//   _инкт, нцав, _пхий, --, 
   {{0x68e59185,0x44d00100,0xaa581064,0x6ed000ac}},	//   _frid, _bņ_, _пищу_, _qəbə, 
   {{0x1b4c069c,0x68e59186,0x629c0cc1,0x6b600022}},	// [2a6b0] _ማሕበራ, _grid, _avro, _икәа, 
   {{0x69c43f8e,0xf99c067c,0x62580332,0x00000000}},	//   _zbie, chèr_, híod, --, 
   {{0xf6080691,0x6ed000ac,0x68e40055,0xa1580124}},	//   _فتحه_, _təbə, _zrid, ҭаху_, 
   {{0x44d00100,0x69c40135,0x68e402d0,0x8c3c054e}},	//   _fņ_, _xbie, _yrid, ruşi, 
   {{0x629d9187,0x8c3c054e,0xe3b800cc,0xa99c00df}},	//   _evro, suşi, ীয়ব, לבאר, 
   {{0x60080a4a,0x8c3c054e,0x528400ae,0x00000000}},	//   ннім_, puşi, _للسك, --, 
   {{0x9f5c04cc,0x31c400c0,0x00000000,0x00000000}},	//   chvü_, _псав, --, --, 
   {{0x625800ae,0x00000000,0x00000000,0x00000000}},	//   gíod, --, --, --, 
   {{0x9f4c01e1,0x4fd40166,0x24540139,0x00000000}},	//   _modù_, _ижат, läma_, --, 
   {{0x68e4b010,0x69c40003,0x09a829d7,0x629c007f}},	//   _rrid, _sbie, कल्य, _yvro, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x68e59188,0xa2c42d8f,0xb5f8007b,0x69c40327}},	//   _prid, _रहस्, _fiái, _qbie, 
   {{0xc19805d0,0x07e800e5,0x00000000,0x00000000}},	//   ושרי, ورسٹ_, --, --, 
   {{0x68e44cab,0x8bec009e,0x5fc403ce,0x3e6802e2}},	//   _vrid, য়োজন_, ल्पल, pòtè_, 
   {{0x69c40135,0xb8780118,0x00000000,0x00000000}},	//   _tbie, tvíc, --, --, 
   {{0x245429ef,0x69c59189,0x00000000,0x00000000}},	//   däma_, _ubie, --, --, 
   {{0x056505ec,0xfab4037e,0x98c407d6,0x6d480432}},	// [2a6c0] тван, _zカ_, _یغین, _jyga, 
   {{0x6d480e89,0xf41c0030,0xb3800276,0xd6b003d4}},	//   _myga, _zväz_, илул, _চনৰপ, 
   {{0x6d49918a,0x47580108,0xabc40150,0x00000000}},	//   _lyga, _юрия_, _ﺒﺤﻤﺎ, --, 
   {{0xaca00ca8,0xb87829d3,0x6d49918b,0x8c3c3361}},	//   _apọj, lvía, _oyga, muşu, 
   {{0x8c3d918c,0x00000000,0x00000000,0x00000000}},	//   luşu, --, --, --, 
   {{0xb87825e6,0x3eac0158,0x9f3403de,0x629800d7}},	//   nvía, tuft_, лелі, ávos, 
   {{0x81d8045e,0x8c3c03ee,0xf7700375,0x6d49918d}},	//   ়াব_, nuşu, סקה_, _ayga, 
   {{0x6d480493,0xade002bf,0x3eacdca6,0x9f4c0142}},	//   _byga, ацьк, ruft_, _yndê_, 
   {{0x625893c8,0xf99c020c,0xfab400b5,0x6d48012d}},	//   ríod, dhèp_, _sカ_, _cyga, 
   {{0x91e4037e,0x6258007b,0xd1d4001f,0x6d49918e}},	//   _jpのd, síod, _የአቶ_, _dyga, 
   {{0x601400f7,0x19940209,0x6d4c012c,0x6d480174}},	//   _càme, ланя, ýcar, _eyga, 
   {{0x6d480fac,0xada1918f,0xdddc033f,0x00000000}},	//   _fyga, _вацл, żyłe, --, 
   {{0x656000d2,0x9f4c01e1,0x00000000,0x00000000}},	//   _úmhh, _rodù_, --, --, 
   {{0x9f4c168c,0xac047c4a,0x00000000,0x00000000}},	//   _bodø_, _инча_, --, --, 
   {{0xa3ac02ab,0x6014002e,0x92ac00fe,0xb4c8424e}},	//   _गाज_, _kàmb, _কন্_, लब्_, 
   {{0x3ce4098d,0x58d59190,0x60140694,0x62580332}},	//   _krov_, _боит, _jàmb, híob, 
   {{0x60141bce,0xc3c001c0,0x00000000,0x00000000}},	// [2a6d0] _màmb, өөрл, --, --, 
   {{0xf8bd9191,0x60141bce,0x5fc56da3,0x8c3c0356}},	//   mté_, _làmb, ल्मल, buşu, 
   {{0xf8bc20ef,0xf364e90a,0x8c3d9192,0x9f4c05ac}},	//   lté_, ттан, muşt, _godø_, 
   {{0xb4b00184,0x9f4c08e5,0x8c3c05d1,0x64401427}},	//   _кимә, _indè_, luşt, _ímin, 
   {{0xf8bd9193,0x3ce40070,0x90c49a41,0xf4840724}},	//   nté_, _nrov_, убле, _шунн, 
   {{0xf8bd9194,0x3dc4011f,0x8c3c03ee,0x00000000}},	//   ité_, _abow_, nuşt, --, 
   {{0x601400e8,0x229448a5,0xdbe40241,0x1e9429db}},	//   _bàmb, _вися, _gèés, арыр, 
   {{0x60159195,0x6d480209,0xf8bd9196,0x8db40d30}},	//   _càmb, _pyga, kté_, ускі, 
   {{0x601400e8,0x626c0276,0x4cbc009e,0x0c780023}},	//   _dàmb, _uşoa, ্টভু, _ኣደራሽ_, 
   {{0x3ce407c5,0xed54023b,0xa3ac00c5,0xdb180419}},	//   _drov_, ноқ_, _गाछ_, _obvä, 
   {{0xf8bd9197,0x8b24e4c1,0x6d48033f,0x26cc025c}},	//   eté_, удне, _wyga, ħdok_, 
   {{0x60159198,0x625800c6,0x3dc40076,0x8c3c1432}},	//   _gàmb, míoc, _gbow_, vuşu, 
   {{0x62580597,0x6d499199,0xf8bd919a,0xc02400fe}},	//   líoc, _uyga, gté_, মকৰণ_, 
   {{0x6015919b,0xab84188c,0x8c3c56a3,0x00000000}},	//   _tàme, _рудк, tuşu, --, 
   {{0x81d839db,0x09e5919c,0x625800c6,0xf8bc0066}},	//   ়াত_, _бойн, níoc, até_, 
   {{0x8c3c47af,0xb87804d4,0x6014002e,0x00000000}},	//   ruşu, svía, _xàmb, --, 
   {{0xf8bc0231,0x2cbd919d,0x625800c6,0x8c3c054e}},	// [2a6e0] cté_, ntud_, híoc, buşt, 
   {{0x62880240,0x8c3c0342,0x0684004e,0x2cbc000d}},	//   _çdok, muşs, _йгон, itud_, 
   {{0x2cbc007d,0x41a80a83,0xf9f42f4d,0xb878004e}},	//   htud_, евен_, _شفیع_, nvín, 
   {{0x2cbc089c,0x6259919e,0xc6a400c7,0x64ac0073}},	//   ktud_, díoc, _ирҭи, _चिपळ, 
   {{0x317c0369,0x9f4cba1f,0x76400af2,0x79b4011a}},	//   _dfuz_, _indé_, _ínya, רלנד_, 
   {{0x601400e8,0x62580332,0xdfd006c5,0xb03000d4}},	//   _sàmb, fíoc, زيب_, бніш, 
   {{0x645d919f,0x62580491,0x3e69342f,0x2cbd91a0}},	//   _ihri, ríob, ншин_, etud_, 
   {{0x3ce591a1,0xf8bd1a6d,0x7d0403cd,0x00000000}},	//   _prov_, yté_, økso, --, 
   {{0x645c138f,0xb8780022,0xf8bc0de2,0xa2dc21bd}},	//   _khri, evín, xté_, फिक्, 
   {{0x75e80139,0x614458cb,0x625801e7,0x9b940114}},	//   _közä, _беға, bíoc, шиоц, 
   {{0x5a358622,0x625800c6,0x8c3c05d1,0x60141574}},	//   инот, cíoc, vuşt, _tàmb, 
   {{0xf8bc102c,0x6748044e,0x3ce40419,0x00000000}},	//   tté_, _መስዋእ, _trov_, --, 
   {{0xf8bc0231,0x7b64005e,0x645d91a2,0x52d00709}},	//   uté_, _өтке, _ohri, _सन्स, 
   {{0xf8bd91a3,0x9f4c0109,0x645c0042,0x00000000}},	//   rté_, _andé_, _nhri, --, 
   {{0xf8bd91a4,0x6b7805e1,0xdce007c4,0x8c3c03ee}},	//   sté_, _ארונ, mamı, ruşt, 
   {{0xdce071e1,0xf8bc4aee,0xddc000b0,0x6ed40e49}},	//   lamı, pté_, komō, _मनसु, 
   {{0x58d40a52,0x645c0fa3,0xd4c400fb,0x00000000}},	// [2a6f0] _топт, _bhri, шөнк, --, 
   {{0x645d91a5,0x6440022c,0xdce05531,0xe3b000ae}},	//   _chri, _ímil, namı, كرم_, 
   {{0x645d91a6,0x62980f91,0xf2053981,0x00000000}},	//   _dhri, ávop, лядо, --, 
   {{0xb5f824c8,0xa2940212,0xdce126df,0x00000000}},	//   _ciát, саці, hamı, --, 
   {{0x712448c1,0x645c35ab,0xdce00259,0xbef0033f}},	//   درال, _fhri, kamı, _अपॉन_, 
   {{0x645c3084,0x62580597,0x287c00c8,0xaca001f2}},	//   _ghri, tíoc, ענומ, shịo, 
   {{0xdce0e948,0x75e80139,0x31ac0205,0x235801af}},	//   damı, _gözä, gözü_, _бирњ_, 
   {{0x62580491,0x5ba401e0,0x66d0007f,0x92580107}},	//   ríoc, ҡлығ, lòkò, _рабт_, 
   {{0xb5f80022,0x6258007b,0xc2100375,0x3d180241}},	//   _ehág, síoc, _והן_, _ràwé_, 
   {{0x2cbd8901,0xb5f800c6,0xb878022a,0xdea001d3}},	//   rtud_, _fhág, tvín, _کیٹی, 
   {{0x2cbd91a7,0x998800a2,0x66cc0108,0x00000000}},	//   stud_, _olań_, _mökö, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc954210c,0x8ac43500,0xdce0083c,0x229c01e1}},	//   ртны, уққа_, bamı, _káká_, 
   {{0x83240003,0x7d0402f6,0x97d82e01,0xdce005d1}},	//   _རྟའུ_, äkse, льсу_, camı, 
   {{0x601400e8,0xb6a0084c,0x4ab8b464,0x26f00210}},	//   _jàma, жисл, _руля_, ङमेर_, 
   {{0x15b80184,0x38bc0109,0x645d8d14,0xf74109e0}},	//   лыуы_, bîr_, _shri, цесо, 
   {{0x645d91a8,0x07a40311,0x44a46201,0x17e40183}},	// [2a700] _phri, _капн, شماق, _নকৰি, 
   {{0x389800c8,0x2c780b21,0x03a591a9,0x62580166}},	//   _שיינ, _mêd_, рижо, díoa, 
   {{0x60140109,0xb5f801e7,0x03240f5c,0xb8781427}},	//   _nàma, _bhád, јден, hvíl, 
   {{0x00e462bd,0xb5f80005,0xdce0029f,0xd57591aa}},	//   ижен, _diás, zamı, _гурь, 
   {{0x228c02e2,0xdce01ae4,0xb5f804d4,0x645c2517}},	//   _bòkò_, yamı, _viát, _thri, 
   {{0x645c023a,0xddc000b0,0xfe7018fd,0xb5f80332}},	//   _uhri, romō, يدع_, _phág, 
   {{0xdce191ab,0x999801a2,0x601514d7,0x88bc0154}},	//   vamı, losť_, _càma, েটিক, 
   {{0x2c780b21,0xc21001d9,0xb5f800e4,0x6014b153}},	//   _bêd_, _بٔر_, _hiár, _dàma, 
   {{0x999801a2,0xdce003ee,0x31ac0790,0xc0c80092}},	//   nosť_, tamı, sözü_, _በቃሉ_, 
   {{0x61e00978,0x9f4c014a,0xbea400d6,0xbc0591ac}},	//   _haml, _kodü_, _важк, рчий, 
   {{0x61e0598f,0xdce00abc,0x33740302,0x601400a3}},	//   _kaml, ramı, יעים_, _gàma, 
   {{0x61e191ad,0x99980030,0xdce0c6da,0xba0801f0}},	//   _jaml, kosť_, samı, тхое_, 
   {{0x61e191ae,0x63bc05a1,0xfb84807e,0xdce005d1}},	//   _maml, _ocrn, _кыйн, pamı, 
   {{0x999801f1,0x61e191af,0x784401c0,0xb87804d4}},	//   dosť_, _laml, рэмж, svío, 
   {{0x79a4119e,0x00000000,0x00000000,0x00000000}},	//   _крпе, --, --, --, 
   {{0xd1f8044e,0x61e191b0,0x66cc014a,0x63bc02d0}},	//   ላታት_, _naml, _sökö, _acrn, 
   {{0x2ed0102f,0x00000000,0x00000000,0x00000000}},	// [2a710] _दन्त, --, --, --, 
   {{0xb4d400e1,0xb5f800ae,0x4af40345,0x00000000}},	//   _ानी_, _shád, _ئکید_, --, 
   {{0xb5f8f505,0x61e0e163,0x764000d2,0x00000000}},	//   _diár, _baml, _ínyo, --, 
   {{0x61e191b1,0xc0c8001f,0x999800d0,0x798c02d0}},	//   _caml, _በኃላ_, bosť_, nbcw, 
   {{0x69bc0574,0x61e191b2,0x7bc898a6,0x228c007f}},	//   ष्टी, _daml, _obfu, _pòkò_, 
   {{0x2c78000f,0x61e0035a,0xd01005d9,0x64ac0073}},	//   _rêd_, _eaml, ڪلڻ_, _चितळ, 
   {{0x61e00bed,0x2c78000f,0xe2f80220,0x74100451}},	//   _faml, _sêd_, _кері_, _هوڏا, 
   {{0x61e100b0,0x62580597,0xb5f991b3,0xc0e81b49}},	//   _gaml, líon, _hháb, _መሰሉ_, 
   {{0x0c242472,0x7ae808a5,0x8d9400db,0x00000000}},	//   ймин, _arft, _ۇلاش, --, 
   {{0x625800c6,0x61e191b4,0x601401c3,0xaaf4002e}},	//   níon, _zaml, _tàma, _ŋaññ_, 
   {{0x81d803f4,0x8f5591b5,0x61e191b6,0x4a453005}},	//   ়ার_, _اناش, _yaml, йнов, 
   {{0xf53c01e6,0xdcac0e26,0xc33004ae,0xf748001f}},	//   _oxå_, رۉۉ_, לוי_, _መስዋዕ, 
   {{0xdbf00118,0x7ae8002f,0x62880200,0xfd68010a}},	//   _zříd, _erft, _çdov, _йышǎ, 
   {{0x999801a2,0x9f4c00db,0x7ae80175,0x24540036}},	//   vosť_, _godó_, _frft, tämm_, 
   {{0x6258007b,0x00000000,0x00000000,0x00000000}},	//   díon, --, --, --, 
   {{0x999801f1,0x9f4c01e1,0x00000000,0x00000000}},	//   tosť_, _kodò_, --, --, 
   {{0x2aa00cc1,0x61e191b7,0xf4850d39,0x9f5c03b2}},	// [2a720] lıb_, _raml, مالی, skvø_, 
   {{0x25e82aa1,0x9f4d91b8,0xb5f800ae,0x99980419}},	//   _चोरी_, _modò_, _cháb, rosť_, 
   {{0x2aa00cc1,0x61e191b9,0x2a600211,0xb5f80798}},	//   nıb_, _paml, _khib_, _viár, 
   {{0xc0e8693c,0x61e034dd,0x7d0433b8,0x3ab8010f}},	//   _መሰል_, _qaml, øksk, טמענ, 
   {{0x61e00162,0x71e4007b,0x00000000,0x00000000}},	//   _vaml, صفوف_, --, --, 
   {{0x61e191ba,0x7a2c0100,0xdbf000bc,0x20c00ba1}},	//   _waml, _kòtè, _příd, ròi_, 
   {{0x61e191bb,0x442991bc,0x9f4d91bd,0xb7d80375}},	//   _taml, _imb_, _rodó_, רקצי, 
   {{0x6b800066,0x2aa000ac,0x7a2c02e2,0x261c01e7}},	//   _afng, dıb_, _mòtè, _díog_, 
   {{0x7a2c033b,0xa06800fb,0x00000000,0x00000000}},	//   _lòtè, _ҡаға_, --, --, 
   {{0xb5f801dc,0x442991be,0xdbf00316,0x00000000}},	//   _khác, _jmb_, _tříd, --, 
   {{0x4428010e,0x29040309,0xaa841888,0x00000000}},	//   _mmb_, äman_, ینیم_, --, 
   {{0x7868038f,0x2a6191bf,0xddc8033f,0x201c0477}},	//   _iżvi, _chib_, _ludź, lhvi_, 
   {{0xa3b809d9,0x442991c0,0x2a6001d9,0x2ca45316}},	//   छला_, _omb_, _dhib_, _гкчп_, 
   {{0x442991c1,0xb87801a8,0x2a600254,0x7e780200}},	//   _nmb_, lvík, _ehib_, _kutp, 
   {{0xf65c003a,0xb5a441e5,0x7ae802d0,0xb5f80051}},	//   _phæ_, йрай, _urft, _nhác, 
   {{0x4428e83d,0xb5f800c6,0x2a60b01d,0x95d80261}},	//   _amb_, _sháb, _ghib_, јдат_, 
   {{0x4428a08d,0x53980a8f,0xb8780122,0xb5f800e4}},	// [2a730] _bmb_, ивая_, zvíj, _diáp, 
   {{0x7e7991c2,0x7a2c02e2,0x9f4c013d,0xb5f801e7}},	//   _outp, _fòtè, _andí_, _bhác, 
   {{0x62580597,0xb5f991c3,0x7e78002b,0x96f861ac}},	//   ríon, _chác, _nutp, _тент_, 
   {{0xd130fc3b,0x442991c4,0x6258007b,0x2a600200}},	//   وما_, _emb_, síon, _xhib_, 
   {{0x7c282f05,0x2aa003be,0x4428ab00,0xb5f8007b}},	//   _omfr, zıb_, _fmb_, _tháb, 
   {{0x2aa00cc1,0x442991c5,0x62580077,0x7e79310f}},	//   yıb_, _gmb_, líol, _butp, 
   {{0x1ea81129,0x7e7800e4,0x2aa000ac,0xc4445c81}},	//   مايي_, _cutp, xıb_, _بیلن_, 
   {{0x4c84d093,0x625800c6,0xf99c506b,0x4428020c}},	//   олив, níol, jaè_, _zmb_, 
   {{0x2a600218,0x442805b1,0x2ce010eb,0x00000000}},	//   _rhib_, _ymb_, कटेल_, --, 
   {{0x2aa003be,0x2a6007d6,0x625800c6,0x7e780798}},	//   tıb_, _shib_, híol, _futp, 
   {{0x7e78398e,0xfe6c0228,0x00000000,0x00000000}},	//   _gutp, رگۅ_, --, --, 
   {{0x2a600457,0x2aa003be,0x7c2991c6,0x9f4c01e1}},	//   _qhib_, rıb_, _emfr, _todò_, 
   {{0x2d9d91c7,0x6e2991c8,0x7e7809b6,0xcba40116}},	//   maue_, _imgb, _zutp, _далй, 
   {{0xcb68af9e,0xf41c0793,0x601401ab,0x2aa00213}},	//   _кале_, _stän_, _nàml, pıb_, 
   {{0x442991c9,0x2a600070,0xbb40008e,0x00000000}},	//   _rmb_, _thib_, _оешк, --, 
   {{0x2d9d91ca,0x4df8010f,0x82f8030f,0x959800db}},	//   naue_, ספּא, یراز_, йтуу_, 
   {{0x44280156,0x2d9c0270,0xf99c020c,0xddd4003d}},	// [2a740] _pmb_, iaue_, rkèt_, _ħażi, 
   {{0xb5f801fb,0x2d9d91cb,0xf99c0669,0xb4600395}},	//   _phác, haue_, skèt_, дкул, 
   {{0x59c00b9a,0xd7c800aa,0xb878022c,0x2d9c0374}},	//   ष्कर, _اوپه_, yvík, kaue_, 
   {{0x7e780784,0x62580077,0x2d9c067c,0xe8e80327}},	//   _rutp, cíol, jaue_, _སློག, 
   {{0x25a191cc,0x442991cd,0x5374044e,0x7e7807c5}},	//   mail_, _tmb_, ኽንያት_, _sutp, 
   {{0x4aa82413,0x81d8000e,0xb5f8001e,0xf50002d5}},	//   _किंव, ়াই_, _thác, _ўзро, 
   {{0x09b0015b,0x248191ce,0x6e2800a2,0x4438037e}},	//   ট্যা, lqim_, _bmgb, mnp_, 
   {{0x25a191cf,0x2d9c1132,0x2dd00801,0x7e78047e}},	//   nail_, gaue_, джър, _vutp, 
   {{0x62580597,0xb87809f3,0xf99c0ffb,0x1d3428e8}},	//   níom, rvík, vaè_, яния, 
   {{0x25a191d0,0x7e7991d1,0x7ac40cb6,0x44380175}},	//   hail_, _tutp, осме, nnp_, 
   {{0x1ee8168d,0x25a15239,0xf7c81c5c,0xce3400aa}},	//   _دوای_, kail_, ﻪﺗﻜﻪ, _کونک, 
   {{0x9f4c19f5,0xba2800d6,0xfe402eac,0x601400e8}},	//   _indà_, ріод_, _تکتی, _màmm, 
   {{0x0e6991d2,0x7e6191d3,0x25a0c699,0x60141bce}},	//   _اصلي_, _ihop, dail_, _làmm, 
   {{0x7c2991d4,0x245400a2,0x5de40046,0x00000000}},	//   _umfr, bämi_, _ﻋﻤﻠﻴ, --, 
   {{0x7e602f07,0x25a191d5,0x7c38007c,0xdb200241}},	//   _khop, fail_, mntr, _àtàn, 
   {{0x25a191d6,0xf99c04cc,0xeb9401ee,0x00000000}},	//   gail_, rkès_, _лиә_, --, 
   {{0x7c38127b,0x290408fb,0x4438002d,0x7e600042}},	// [2a750] ontr, ømat_, fnp_, _mhop, 
   {{0x7c3991d7,0x60141bce,0xa3d416a8,0x2d9c0561}},	//   nntr, _bàmm, моуч, zaue_, 
   {{0x25a00491,0x601591d8,0x7c3991d9,0x7e618bad}},	//   bail_, _càmm, intr, _ohop, 
   {{0x92581de1,0x25a01549,0x7c3991da,0x7e600810}},	//   щает_, cail_, hntr, _nhop, 
   {{0xc5f80302,0x9f4c2b1d,0x2d9c067c,0x338401f0}},	//   _הפרט, _andà_, vaue_, _мувв, 
   {{0x7e6191db,0x2d9c009f,0x4438037e,0x7c3991dc}},	//   _ahop, waue_, cnp_, jntr, 
   {{0x7e60017a,0x601400e8,0x02b4013e,0x2d9d91dd}},	//   _bhop, _gàmm, _нирӯ, taue_, 
   {{0x7e6191de,0x00000000,0x00000000,0x00000000}},	//   _chop, --, --, --, 
   {{0x2d9d91df,0x261c00ae,0x69c00100,0x7c38032e}},	//   raue_, _híoc_, òmem, fntr, 
   {{0x4b24063b,0x7e600099,0x7c38003b,0x2454fba5}},	//   змов, _ehop, gntr, tämi_, 
   {{0x60141bce,0x09e4322f,0x00000000,0x00000000}},	//   _xàmm, понн, --, --, 
   {{0x7c3991e0,0x25a191e1,0x7e600978,0x644000e4}},	//   antr, xail_, _ghop, _ímiv, 
   {{0x25a00231,0x9f4c019f,0x27b45a0b,0x00000000}},	//   vail_, _indá_, мәнс, --, 
   {{0x25a191e2,0x24540784,0x7c3800d8,0x37840107}},	//   wail_, pämi_, cntr, збро_, 
   {{0x25a191e3,0x7d0403cd,0xcb34010f,0x17c400c7}},	//   tail_, øksv, _מאַי_, ьарҭ, 
   {{0x6e3991e4,0xe7ec012c,0x6014002e,0x24800784}},	//   nnub, _छोरा_, _ràmm, tqim_, 
   {{0x25a191e5,0x74108efb,0xe94441b3,0x60141bce}},	// [2a760] rail_, کولا, _ترغی, _sàmm, 
   {{0x25a191e6,0x625800c6,0x06740276,0x8458023b}},	//   sail_, ríom, _нумя, ёрат_, 
   {{0x26dc007f,0xb7780375,0x6ed40406,0x25a191e7}},	//   _èvo_, _לאיש, _मनगु, pail_, 
   {{0x3f4806d6,0x443800d8,0x00000000,0x00000000}},	//   ṱuku_, snp_, --, --, 
   {{0xb5f80016,0x660591e8,0x6e3991e9,0x24808761}},	//   _khán, mjik, dnub, qqim_, 
   {{0x3010005e,0x7e603af1,0x6605083f,0x9f4c0789}},	//   ндір, _shop, ljik, _andá_, 
   {{0x7e6191ea,0xd08802d3,0x6604009f,0x6e38032e}},	//   _phop, _ዝደልዩ_, ojik, fnub, 
   {{0x660591eb,0x7e60009a,0x51b40640,0x333802e4}},	//   njik, _qhop, _осуђ, _התלמ, 
   {{0x324001b9,0xacf400c7,0x7c383a26,0xb5f801ef}},	//   _четг, зныу_, tntr, _ohán, 
   {{0xb5f8001e,0x7c3926b0,0x66044432,0x5b1413d6}},	//   _nhán, untr, hjik, дмот, 
   {{0x7e60b483,0xb8780798,0x7c3826bc,0x3f9d91ec}},	//   _thop, nvív, rntr, _ietu_, 
   {{0x81d80c58,0xddc805be,0x7e6001b3,0x6f140014}},	//   ়াক_, _hudž, _uhop, _عٲنس_, 
   {{0x66040cfe,0x3f9c044e,0x6e000014,0xb5f97515}},	//   djik, _ketu_, _سِون, _bhán, 
   {{0xf7703d45,0x3f9d91ed,0xb5f991ee,0xfaa4dbd3}},	//   ّار_, _jetu_, _chán, _ешин, 
   {{0x3f9d91ef,0x7bd991f0,0xddc805be,0xb5f800ae}},	//   _metu_, metu, _mudž, _dhán, 
   {{0x7bd991f1,0x3f9cdc79,0x6604044e,0x00000000}},	//   letu, _letu_, gjik, --, 
   {{0x3f481682,0x84c000fd,0x656001c3,0xb5f801e7}},	// [2a770] ṱuhu_, кәрд, _ùmhl, _fhán, 
   {{0x2bcc0882,0xb5f8143c,0xf364030c,0xf41c0166}},	//   त्पा, _ghán, птен, _itäk_, 
   {{0x7bd87925,0xc0c40023,0xd2500cd2,0x66040055}},	//   ietu, _ኸተማ_, نچر_, bjik, 
   {{0x7bd991f2,0x515401c0,0xddc803ef,0x00000000}},	//   hetu, мтлу, _audž, --, 
   {{0xddc991f3,0x3f9d91f4,0xd0080261,0x799c014f}},	//   _budž, _betu_, желе_, _meqw, 
   {{0x799d91f5,0x7bd991f6,0x6e3804ba,0xe0d80212}},	//   _leqw, jetu, wnub, яві_, 
   {{0x7bd991f7,0x3f9c026c,0x6e38113c,0x262806be}},	//   detu, _detu_, tnub, aşou_, 
   {{0x3f9d91f8,0x799c009a,0x60140e89,0x2bcc08e6}},	//   _eetu_, _neqw, _làmh, त्ना, 
   {{0x3f9d91f9,0xddc802f0,0xe0d000f1,0x00000000}},	//   _fetu_, _fudž, _مزل_, --, 
   {{0x7bd991fa,0x291c0618,0x601408c2,0x3f9c01a8}},	//   getu, _āva_, _nàmh, _getu_, 
   {{0x799c014f,0x5f743260,0x00000000,0x00000000}},	//   _beqw, _كامر, --, --, 
   {{0x3f9c05d9,0xce3404fb,0xb5f800bc,0x270c0154}},	//   _zetu_, _کوچک, _shán, _হইলো_, 
   {{0x7bd991fb,0x3f9c00b2,0x799c014f,0x7d0406ea}},	//   betu, _yetu_, _deqw, økst, 
   {{0x7bd991fc,0x601400a3,0xec680276,0x3f9c00e8}},	//   cetu, _càmh, _урек_, _xetu_, 
   {{0x660591fd,0x60140e89,0x92c0015b,0x09e401b9}},	//   tjik, _dàmh, ্টু_, _жойн, 
   {{0x4a7400e3,0x96540063,0x25e80037,0x2454002f}},	//   _تُعر, еђуј, _चोखी_, hämt_, 
   {{0xb5f801dc,0xc79591fe,0x660591ff,0x245401e3}},	// [2a780] _thán, _орны, rjik, kämt_, 
   {{0x68e56ce0,0x66059200,0x245401e3,0xb5f801ef}},	//   _isid, sjik, jämt_, _uhán, 
   {{0x2bcd9201,0xb7f80375,0x41e400d4,0xb5f80051}},	//   त्या, _ופית, діла, _khál, 
   {{0x3f9c03bd,0xed900125,0x224000af,0x68e401a9}},	//   _setu_, መንበር_, õik_, _ksid, 
   {{0x7bd80451,0xb5f800ae,0x00d8007b,0xd4d40064}},	//   yetu, _mhál, تبات_, _пірэ, 
   {{0x2bcc0882,0x68e59202,0x2584032e,0x7bd8d2f3}},	//   त्मा, _msid, _féló_, xetu, 
   {{0x69c460db,0x7bd99203,0xb8780008,0xeaa402e9}},	//   _ocie, vetu, lvít, _جع_, 
   {{0x3f9d9204,0x68e59205,0x7bd99206,0x3d1800bc}},	//   _wetu_, _osid, wetu, यनले_, 
   {{0x68e41529,0xed54026a,0xd24c01d9,0x60159207}},	//   _nsid, моћ_, _اۆن_, _làmi, 
   {{0x69c59208,0xf0600006,0xb4f80375,0x7bd8003a}},	//   _acie, _акуп, קפיי, uetu, 
   {{0x7bd80de4,0xb5f800d2,0xda359209,0x68e5920a}},	//   retu, _bhál, еены, _asid, 
   {{0xdd91920b,0xfe7004d3,0x799c0477,0x601408c2}},	//   _صوت_, _شدا_, _qeqw, _sàmh, 
   {{0x200d920c,0xb5f800ae,0x273c0419,0x00000000}},	//   _kodi_, _dhál, yšné_, --, 
   {{0x200c0699,0xb8f40a28,0xb8d400c5,0x69c4127b}},	//   _jodi_, _सह_, _चट_, _ecie, 
   {{0x68e5920d,0xf6502ad5,0x69c4003a,0xb5f801e7}},	//   _esid, نئر_, _fcie, _fhál, 
   {{0x200d920e,0xd018010e,0x00000000,0x00000000}},	//   _lodi_, _muńa_, --, --, 
   {{0x200d920f,0x629d9210,0xe53400e6,0x601401ab}},	// [2a790] _oodi_, _awro, веть, _tàmh, 
   {{0x200d9211,0xb86468c0,0xe1f001a9,0x00000000}},	//   _nodi_, _تابو, یسن_, --, 
   {{0x68e401ed,0xddc80034,0xf2c401c6,0xd1d80108}},	//   _zsid, _budż, ьсан, здец_, 
   {{0xa29400d6,0x68e4003a,0x5ef400dc,0x3d0c0118}},	//   таці, _ysid, ्मन्_, िहाइ_, 
   {{0x200d9212,0x629d9213,0x92c00f22,0x25e84c19}},	//   _bodi_, _ewro, ্টে_, _चोटी_, 
   {{0x200d9214,0xb87809f3,0xb03000f1,0xdb080d12}},	//   _codi_, lvís, ضوعګ, ngdó, 
   {{0x442402a8,0x629c015d,0x31c40452,0x2454007c}},	//   ɗo_, _gwro, _осав, rämt_, 
   {{0x261c0597,0xfe6c036b,0xed5c00d7,0x00000000}},	//   _líon_, مگن_, ážom_, --, 
   {{0x629c0034,0x200c00d8,0x50f40212,0x69c40327}},	//   _zwro, _fodi_, _язат, _rcie, 
   {{0x69c59215,0x200d9216,0x261c01e7,0xb5f80332}},	//   _scie, _godi_, _níon_, _shál, 
   {{0xb5f80f51,0x3944013f,0x68e4037e,0xb87800bc}},	//   _ahám, _ɛnse_, _ssid, zvít, 
   {{0x200d9217,0x00000000,0x00000000,0x00000000}},	//   _zodi_, --, --, --, 
   {{0xb5f81709,0x2f24002e,0x9f4c008e,0x200c022e}},	//   _chám, _bёgg_, _endä_, _yodi_, 
   {{0x321c02d1,0x6014642b,0xb5f800ae,0xdb0800e8}},	//   _lluy_, _pàmi, _dhám, ggdó, 
   {{0xf74103d4,0x1cbc031c,0x261c007b,0xfb100345}},	//   геро, _ཆའོ_, _díon_, _مووج, 
   {{0xb4d80137,0x68e59218,0x69c40034,0xb8780321}},	//   _exàm, _tsid, _ucie, gvís, 
   {{0x261c007b,0x2bcc1fe7,0x92c00011,0xc9540166}},	// [2a7a0] _fíon_, त्था, ্টো_, _яткы, 
   {{0x6fd00ab7,0x81d8009e,0xb8781d55,0xf99c0214}},	//   nıcı, ়াছ_, rvít, njèn_, 
   {{0x2c0400dc,0x2b0c00bc,0xb8780118,0x03a40107}},	//   _वचनं_, ाहिँ_, svít, диҷо, 
   {{0x2bcc296e,0x200d9219,0x09b0015b,0xe3b000ec}},	//   त्ता, _sodi_, ট্রা, _چڱا_, 
   {{0x409405a2,0x6fd00790,0x00000000,0x00000000}},	//   хрет, kıcı, --, --, 
   {{0x629c013f,0x9f340220,0x200c058a,0x2454007c}},	//   _twro, келі, _qodi_, räms_, 
   {{0x6fd003be,0xb8780005,0x68181432,0x00000000}},	//   dıcı, nvír, _iğdı, --, 
   {{0x200c0134,0x217400d1,0xddc80064,0x6fb000cf}},	//   _wodi_, _җуғр, _rudų, _ەملا, 
   {{0x200d921a,0x0ca0001f,0x00000000,0x00000000}},	//   _todi_, _ለነገሩ_, --, --, 
   {{0xd1780220,0xf0700c4f,0xefbc0092,0xa2c408a3}},	//   _істі_, _مُقد, ቷቸው_, ांप्, 
   {{0xef14033a,0x1994011c,0x00000000,0x00000000}},	//   _пмф_, каня, --, --, 
   {{0xf2d004ac,0xf3fc0356,0x00000000,0x00000000}},	//   נער_, ăţie_, --, --, 
   {{0x6fd00205,0xd1d40092,0x7bcc0254,0x00000000}},	//   bıcı, _ከአብ_, õbus, --, 
   {{0x9f4c03d4,0x9988029f,0x368860a1,0xad18010f}},	//   _endå_, _flaş_, зсан_, _צוגר, 
   {{0xb8780bcd,0x6af000c6,0x458c0cad,0x00000000}},	//   tvís, _مثير, _ọwọ_, --, 
   {{0xd1f80023,0x681806be,0x99980064,0x00000000}},	//   ዋታት_, _ağdı, rosų_, --, 
   {{0xb8781125,0x5455921b,0xe664233a,0x00000000}},	// [2a7b0] rvís, вват, утро, --, 
   {{0xf8bc0789,0xe2c800f1,0x00000000,0x00000000}},	//   mué_, ځولو_, --, --, 
   {{0xa858025f,0xf8bc07ea,0x92c0009e,0xb8780252}},	//   _איזה_, lué_, ্ট্_, svís, 
   {{0xb4b000d1,0x6fd005d1,0x50b4005b,0x64400241}},	//   _йимә, zıcı, вску, _ìmin, 
   {{0x6fd00259,0xf8bc4afb,0x7f58022e,0xc5c800fe}},	//   yıcı, nué_, _aytq, _লোকপ, 
   {{0xd1b00133,0x37dc03d4,0x00000000,0x00000000}},	//   _چیاک, মাকৰ, --, --, 
   {{0x3dc401ee,0x3ce4022e,0x261801ad,0x83dc012d}},	//   _bcow_, _asov_, _नवमी_, नजरआ, 
   {{0x62880005,0x61f80213,0xf8bc00c7,0x9f0400e5}},	//   _édoa, ğalç, kué_, اوٹو, 
   {{0x6fd02fbe,0xdef80588,0x7d04143a,0x4c68004e}},	//   tıcı, _ҿыц_, øksp, миин_, 
   {{0xed54036b,0xb058063f,0xf8bca801,0x86300092}},	//   моқ_, ịịrị_, dué_, _በወንድ, 
   {{0xb5f80124,0x6fd07236,0x00000000,0x00000000}},	//   _chák, rıcı, --, --, 
   {{0x7d740101,0x00000000,0x00000000,0x00000000}},	//   عمیر_, --, --, --, 
   {{0xf8bd921c,0x261c00c6,0x6fd003e0,0x00000000}},	//   gué_, _díol_, pıcı, --, 
   {{0x2bc81b74,0x2cbc0050,0xb5f801ef,0x00000000}},	//   _худо_, muud_, _uháj, --, 
   {{0x317c0209,0x418808b0,0x4a45921d,0x998803e0}},	//   _oguz_, _ﺗﯩﮕﯩ, _инкв, _ulaş_, 
   {{0xf8bc5725,0x00000000,0x00000000,0x00000000}},	//   bué_, --, --, --, 
   {{0x2cbc7bc3,0xf485921e,0xb87802fb,0xf8bc0129}},	// [2a7c0] nuud_, نالی, rvír, cué_, 
   {{0x7d043110,0xa65403e6,0x00000000,0x00000000}},	//   äksi, _ڕێزت, --, --, 
   {{0x4374084c,0x15ec02e5,0x2cbc0067,0x00000000}},	//   туат, _चोकर_, huud_, --, 
   {{0x60140051,0x2cbc000d,0x00000000,0x00000000}},	//   _làmt, kuud_, --, --, 
   {{0x2cbcbc8c,0xf7503321,0x6259921f,0x00000000}},	//   juud_, _منیج, díot, --, 
   {{0x09d46569,0x2cbc1af4,0x04441180,0x3dc40076}},	//   _তোমা, duud_, _регн, _scow_, 
   {{0xd1740032,0x9e34ac9b,0xd2b806a6,0x3e680139}},	//   _ҡыуы, лекч, _путч_, мшин_, 
   {{0x2bcc1157,0x3ce4b515,0x2cbc0067,0xc8b0012d}},	//   त्सा, _psov_, fuud_, _जिंट, 
   {{0xdb204e53,0x2cbc0009,0xfc64074d,0x00000000}},	//   _àtún, guud_, къон, --, 
   {{0x261c007b,0x00000000,0x00000000,0x00000000}},	//   _síol_, --, --, --, 
   {{0x09bc0011,0xa92400d7,0x00000000,0x00000000}},	//   েজনা, ážni, --, --, 
   {{0xf8bc20ef,0x3ce40070,0x2cbc0036,0x00000000}},	//   tué_, _tsov_, buud_, --, 
   {{0x1bd40510,0x2cbc058a,0xa2c40a8a,0x6a84004e}},	//   _боля, cuud_, ांड्, нөөм_, 
   {{0xb5f8035b,0x261c00ae,0xeb3033ae,0x00000000}},	//   _ihái, _díom_, اریخ, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69c000cf,0x00000000,0x00000000,0x00000000}},	//   òmet, --, --, --, 
   {{0x2bcd9201,0xf8bd9220,0x62580332,0x00000000}},	// [2a7d0] त्वा, qué_, híos, --, 
   {{0xb5f800c6,0xa4d40212,0x00000000,0x00000000}},	//   _mhái, рофі, --, --, 
   {{0xe7ec06ab,0xe29800d6,0x9f4c00db,0x163401fe}},	//   _छोटा_, ває_, _endú_, _беня, 
   {{0xb5f800e4,0x62580166,0x7b780092,0x00000000}},	//   _ohái, díos, _አጠናቆ_, --, 
   {{0x9f4c08e5,0x70500b38,0x20c8069b,0x71259221}},	//   _indù_, ۇنچا, نبوي_, خرال, 
   {{0xb5f803b2,0x8e38583d,0x00000000,0x00000000}},	//   _sháh, کستر_, --, --, 
   {{0x1ea8182f,0xb5f80022,0x2cbd9222,0xf1a41188}},	//   نايي_, _ahái, wuud_, _арзн, 
   {{0x2cbc51e2,0xb5f800c6,0x00000000,0x00000000}},	//   tuud_, _bhái, --, --, 
   {{0xb5f800c6,0xcdc400c2,0xa31c110e,0x00000000}},	//   _chái, ваққ, _lọ́w, --, 
   {{0x2cbc0014,0xb5f800c6,0xf0b001d9,0x656021e3}},	//   ruud_, _dhái, _میچھ, _ømhe, 
   {{0xb5f80124,0xf8bc01ed,0x8fc400f1,0x00000000}},	//   _ehái, szél_, _لېږل_, --, 
   {{0xb5f80491,0x2cbc00c5,0xe98410cf,0xa2c46ea8}},	//   _fhái, puud_, шқин, ांत्, 
   {{0x9e7007d2,0xb5f8007b,0x8934007b,0x2cbc0009}},	//   _بۇيت, _ghái, اعجا, quud_, 
   {{0x013400c8,0x8c440138,0x461401b9,0x00000000}},	//   אָלט_, _щеле, گورر, --, 
   {{0xe7483e1f,0x45d4011c,0x00000000,0x00000000}},	//   түне_, лцат, --, --, 
   {{0x2bccb658,0x69c004d4,0xb5f800e4,0x032402dd}},	//   त्रा, ómed, _yhái, ңдан, 
   {{0x05659223,0x9f4c0120,0x932401e2,0x00000000}},	// [2a7e0] уван, _cadê_, یرمن, --, 
   {{0x389825f9,0xd01006c8,0x47ac04c5,0xb978008f}},	//   _ריינ, _nō_, ঞ্জী, _אנפי, 
   {{0xa494004b,0x00000000,0x00000000,0x00000000}},	//   _چیرت, --, --, --, 
   {{0x2c680158,0x00000000,0x00000000,0x00000000}},	//   lødd_, --, --, --, 
   {{0xc0580953,0x625800ae,0x00000000,0x00000000}},	//   нік_, fíor, --, --, 
   {{0x2d8c017a,0xa2c401f9,0x00000000,0x00000000}},	//   _afge_, ांद्, --, --, 
   {{0x44399224,0xdd840220,0x93584990,0x201c1821}},	//   mip_, қықп, _арту_, rkvi_, 
   {{0x44399225,0xb5f80597,0x201c17a3,0x625800c6}},	//   lip_, _phái, skvi_, ríos, 
   {{0xdb099226,0x3d0c007d,0xa92402fb,0xf41c008e}},	//   cadê, िहें_, ážli, _itär_, 
   {{0x44399227,0xd1d40092,0xd1f80092,0x7c0400db}},	//   nip_, _ከአቶ_, _ለአቶ_, ابةك, 
   {{0xfeb80e26,0x6d4801c4,0x4438003e,0x2c680fac}},	//   _ساات_, _exga, iip_, dødd_, 
   {{0xb5f99228,0xdb080200,0x39e800c7,0xdb2401e1}},	//   _thái, ladë, хьон_, _ìsír, 
   {{0x2c680158,0xb5f80022,0x260807f7,0x2e38010f}},	//   fødd_, _uhái, हानी_, _אגאנ, 
   {{0x44399229,0x69c0004e,0x2d900166,0xdb080200}},	//   jip_, òmer, _крәс, nadë, 
   {{0x4439922a,0xec34011a,0x4f340092,0x9aa401ee}},	//   dip_, _תאור_, _እንደር, _тулһ, 
   {{0x7ae8030d,0x49540521,0xf8bc00e5,0xdb2400e4}},	//   _isft, ọtụ_, nzék_, ãsõv, 
   {{0x4438013c,0xdb080240,0x7c380142,0xf7a80395}},	// [2a7f0] fip_, kadë, oitr, _пънк_, 
   {{0x7c38325f,0x7348418d,0x4439922b,0xdb08036e}},	//   nitr, нчев_, gip_, jadë, 
   {{0xf365922c,0x0cc00027,0x00000000,0x00000000}},	//   утан, _शम्म, --, --, 
   {{0x7c38325f,0x2c68037e,0xb5f800c7,0x709c02d3}},	//   hitr, møde_, _aháv, _ዝተረፉ_, 
   {{0x9f4c2776,0x7c39922d,0xb5f800d2,0xdb08006a}},	//   _fadë_, kitr, _bháv, fadë, 
   {{0x4439922e,0xb5f93648,0xac940075,0x9f4c02e2}},	//   cip_, _cháv, ۇچتا_, _kadè_, 
   {{0x7c381311,0xb8e40327,0x625801e7,0xa294003b}},	//   ditr, _ཋཀ_, ríor, _гасі, 
   {{0x0d85922f,0xc3300302,0xb5f80022,0x7bc80332}},	//   шлин, _וול_, _eháv, _acfu, 
   {{0x7c381311,0x4c841677,0xdb099230,0x00000000}},	//   fitr, јлов, ladè, --, 
   {{0x7c399231,0xb5f800d2,0xf99c00f2,0xf074013d}},	//   gitr, _tháw, bjèk_, _сизә_, 
   {{0x8a059232,0x8c840032,0xdb087d47,0xeb0c0073}},	//   азне, ыҙҙа_, nadè, ाहेत_, 
   {{0x44399233,0x2c681477,0x2d8c04cc,0x23bc0241}},	//   zip_, døde_, _ufge_, _kájà_, 
   {{0x44399234,0x6e380357,0xf1d4043e,0x2c680162}},	//   yip_, miub, ण्यन, tødd_, 
   {{0x7c399235,0x9f4c0100,0x6014002e,0x44399236}},	//   citr, _badè_, _jàmp, xip_, 
   {{0x46a402e8,0xdd1c00c0,0x2c683ad2,0x00000000}},	//   рабв, _iššv, rødd_, --, 
   {{0x44380428,0x60159237,0xa2c40b7c,0xdb0804fb}},	//   wip_, _làmp, ांस्, dadè, 
  
   {{0x44399238,0x23bc0248,0x625800e4,0x64400241}},	// [2a800] tip_, _nájà_, díop, _ìmik, 
   {{0x6e380589,0x2c6800b5,0x60140de2,0x44380194}},	//   hiub, bøde_, _nàmp, uip_, 
   {{0xba00044e,0x44399239,0x9f4c007f,0xc1a40e92}},	//   _ልቢ_, rip_, _gadè_, ајли, 
   {{0x7c39923a,0x935800f7,0x00000000,0x00000000}},	//   zitr, уруу_, --, --, 
   {{0x4439923b,0x5f9459df,0x272c01e1,0x7c39923c}},	//   pip_, билт, _fóné_, yitr, 
   {{0x4439923d,0x6015923e,0x9f4c0438,0x23bc0248}},	//   qip_, _càmp, _hadé_, _dájà_, 
   {{0x7c38325f,0x21204d3c,0x9f4c0c6a,0xdb09923f}},	//   vitr, ših_, _kadé_, cadè, 
   {{0xdb080023,0x7c399240,0x00000000,0x00000000}},	//   sadë, witr, --, --, 
   {{0x7c380851,0x62819241,0x6aa002d0,0x645c031c}},	//   titr, _iimo, _awnf, _kkri, 
   {{0xdb099242,0x6280006c,0x7ed400d6,0x6fb19243}},	//   ladé, _himo, _відч, _ومقا, 
   {{0x62819244,0x7c38325f,0x6e380a73,0x645c00ec}},	//   _kimo, ritr, biub, _mkri, 
   {{0x7c399245,0x6280016d,0x00000000,0x00000000}},	//   sitr, _jimo, --, --, 
   {{0x7c399246,0xb5f800c6,0x6aa00076,0x395c013c}},	//   pitr, _mhát, _ewnf, æus_, 
   {{0xe8259247,0xdb099248,0x9f4c01e1,0x00000000}},	//   офсо, hadé, _padè_, --, 
   {{0x9f4c0438,0xb5a4665a,0x628000e4,0xdb084e79}},	//   _badé_, ирай, _oimo, kadé, 
   {{0x645d9249,0x6281924a,0x5694005e,0x2c68318c}},	//   _akri, _nimo, _қамт, røde_, 
   {{0xdb0804fb,0xf99d924b,0x00000000,0x00000000}},	// [2a810] dadé, mbè_, --, --, 
   {{0x6281924c,0xb5f80022,0xdb086f8d,0xf99c007f}},	//   _aimo, _ahát, tadè, lbè_, 
   {{0x6281924d,0x645c0036,0xb5f80332,0xf8bc01e7}},	//   _bimo, _dkri, _bhát, lré_, 
   {{0x645d924e,0x383c0020,0x9f4c007f,0xf8bc004a}},	//   _ekri, _ባለሀብ, _gadé_, oré_, 
   {{0x6281924f,0xb5f98c3f,0x6014004e,0xb818000d}},	//   _dimo, _akág, _pàmp, _नकाम_, 
   {{0x645c030a,0xa2c400dc,0xf8bc0332,0x00000000}},	//   _gkri, ांश्, iré_, --, 
   {{0x62819250,0xb5f801e7,0xfde00f4a,0x00000000}},	//   _fimo, _fhát, _खसखस_, --, 
   {{0x62819251,0xdb086320,0xf8bc02fb,0x9258013e}},	//   _gimo, cadé, kré_, _сабт_, 
   {{0x645c00b5,0x601400e8,0x3158007b,0x260823ef}},	//   _ykri, _tàmp, _شجرة_, हाती_, 
   {{0x0c2452f7,0x62819252,0x629800e4,0x00000000}},	//   смон, _zimo, ívog, --, 
   {{0x09d4009e,0x628097f5,0x8e84007b,0x26180037}},	//   _তোষা, _yimo, _الصه, _नवली_, 
   {{0x62819253,0xf8bc4d74,0xb5f80332,0x1c440137}},	//   _ximo, fré_, _mhás, йнөм, 
   {{0xc9541c22,0x2d9c0588,0xf8bd9254,0x7998002e}},	//   стны, mbue_, gré_, ñuwa, 
   {{0x9f4c0248,0x2d9c0139,0x00000000,0x00000000}},	//   _sadé_, lbue_, --, --, 
   {{0xf99c02e8,0xf8bc3d5a,0xb6a020c2,0xdb0804fb}},	//   bbè_, aré_, зисл, yadé, 
   {{0xf8bc03c6,0xcb0805d9,0x2cbc0254,0xdb2401e1}},	//   bré_, _ليڪن_, orud_, _ìsár, 
   {{0x62819255,0xf8bcc90c,0xdb099256,0x2cbc03cd}},	// [2a820] _rimo, cré_, vadé, nrud_, 
   {{0x62819257,0xb5f800ae,0x9f4c08a5,0x00000000}},	//   _simo, _bhás, _andý_, --, 
   {{0x62819258,0x383c0020,0xb5f99259,0x7c38010f}},	//   _pimo, _ባለሃብ, _chás, נגעז, 
   {{0xd2581ed2,0xd20000f7,0x628168d9,0x2cbcfb94}},	//   аці_, мүск, _qimo, krud_, 
   {{0x25a05088,0x6281925a,0xdb0801ed,0x645c007f}},	//   mbil_, _vimo, radé, _tkri, 
   {{0x645d925b,0x25a1925c,0xdb08f27f,0x62804370}},	//   _ukri, lbil_, sadé, _wimo, 
   {{0x09b000bd,0xb5f8a749,0x629802fb,0xdb0801d3}},	//   য়্যা, _ihár, ívod, padé, 
   {{0x25a093e0,0x62817e4c,0xd36c0c71,0x2cbc031c}},	//   nbil_, _uimo, _شۇن_, frud_, 
   {{0x2cbc003b,0x25a1925d,0xb538010f,0xcdd40116}},	//   grud_, ibil_, ָגיש, تېنت_, 
   {{0xf8bc20ef,0xc04475f5,0x3ea4022e,0x00000000}},	//   vré_, _اخرو, _гижг, --, 
   {{0x1ee804d3,0x60640020,0xafe0f261,0xb5f800ae}},	//   _خوای_, ስወገድ_, _хохл, _mhár, 
   {{0xf8bd925e,0x2cbd925f,0xad2004da,0xba080a89}},	//   tré_, brud_, تىۋى, ухое_, 
   {{0xf8bc37a7,0x81a800cc,0x19d40116,0x00000000}},	//   uré_, _গঞা_, ﭘﻪﻳﻠ, --, 
   {{0xf8bd9260,0x25a01445,0x00000000,0x00000000}},	//   rré_, ebil_, --, --, 
   {{0x9f4c068c,0x00000000,0x00000000,0x00000000}},	//   _indó_, --, --, --, 
   {{0xb5f800c7,0xf84401c0,0x25a001e3,0x7c6c0023}},	//   _ahár, рүүд_, gbil_, _ትብሃል_, 
   {{0x2bcc1b6e,0xb5f800ae,0xb3840338,0x940400f2}},	// [2a830] त्का, _shás, مجاه, يوره, 
   {{0x25a0f103,0xb5f99261,0x00000000,0x00000000}},	//   abil_, _chár, --, --, 
   {{0xb9080055,0x25a19262,0xb5f80332,0xb86400f1}},	//   _asiḥ_, bbil_, _dhár, _پاکو, 
   {{0x925802f6,0xb5f80588,0x00000000,0x00000000}},	//   шает_, _ehár, --, --, 
   {{0xd7100154,0x00000000,0x00000000,0x00000000}},	//   _হইয়া_, --, --, --, 
   {{0xb5f800ae,0x53340251,0xa6d401b9,0x7bcc00db}},	//   _thás, _дегт, _بغیش, òbul, 
   {{0xfe6c036b,0x753800a2,0x0dd81ef7,0x00000000}},	//   چگن_, _ýuzb, _ዮሱፍ_, --, 
   {{0xfe6d9263,0x8cb4ae46,0x2cbc0fac,0x8cbc01f9}},	//   نگن_, осоч, trud_, _शिदो, 
   {{0xb5f800e4,0x2c000131,0x88d80327,0xbe30215c}},	//   _yhár, зүлм, ིསབར, بىيب, 
   {{0x25a00ebd,0x2cbc0254,0xa068009b,0xa0c59264}},	//   zbil_, rrud_, _гађа_, _ريمو, 
   {{0xcb699265,0x2cbc08fb,0x37bc00eb,0x00000000}},	//   ране_, srud_, ইভার, --, 
   {{0xe0d00050,0x25a0007c,0x00000000,0x00000000}},	//   _تٲے_, xbil_, --, --, 
   {{0x63700248,0x2608000d,0x00000000,0x00000000}},	//   _kóní, हासी_, --, --, 
   {{0x637001a8,0x06dc00eb,0x00000000,0x00000000}},	//   _jóní, ডিসি, --, --, 
   {{0x4b78008f,0x6b8804fe,0x660400fb,0x00000000}},	//   _דאַו, āngā, повҡ, --, 
   {{0xb5f800c6,0x3cb00032,0x637001e1,0x00000000}},	//   _shár, _эйәр, _lóní, --, 
   {{0x25a19266,0x940406ab,0xb5f801e7,0x7e880210}},	// [2a840] rbil_, रांच_, _phár, _pępk, 
   {{0x25a19267,0x26080073,0x73e00022,0x00000000}},	//   sbil_, हाही_, моуз, --, 
   {{0x74119268,0xb87800e5,0x42e800d8,0x00000000}},	//   بولا, yvíz, рмео_, --, 
   {{0x538800c7,0x00000000,0x00000000,0x00000000}},	//   _ҳарҭ_, --, --, --, 
   {{0x63700241,0xb5f99269,0x261c01e7,0x5f4801e0}},	//   _bóní, _iháp, _díot_, әүен_, 
   {{0x443c01ed,0x5f95926a,0x26080490,0xb5f80022}},	//   _öt_, чикт, हावी_, _uhár, 
   {{0x9f4cda8b,0x2a60022e,0x00000000,0x00000000}},	//   _andò_, _okib_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4429926b,0x63700248,0xb8783df9,0x00000000}},	//   _klb_, _fóní, rvíz, --, 
   {{0x69c1926c,0x9aa40023,0x9f4c0c5e,0x113800db}},	//   ómen, _ዘሰክፍ_, _hadí_, _уясы_, 
   {{0x44294b39,0x1cbc031c,0xb0300131,0x799800e8}},	//   _mlb_, _ཆའམ_, _تىلغ, ñuwo, 
   {{0x442803a2,0x261c0407,0xbf1405f9,0x2c680158}},	//   _llb_, _míos_, तहीन_, røda_, 
   {{0x261c04d4,0x298436a0,0xf99c02e2,0xf1b00375}},	//   _líos_, дырг, djèt_, וסר_, 
   {{0xb5f80022,0x4428570b,0x2a605ee1,0x999800bc}},	//   _aháp, _nlb_, _ekib_, pisů_, 
   {{0x261c06d5,0xe69401c0,0xdb080248,0x67d4003b}},	//   _níos_, дисы, _ìlàp, ьору, 
   {{0x4429926d,0xb5f80122,0xc5e40135,0xd1d402d3}},	//   _alb_, _cháp, _སྒྱི, ጫታት_, 
   {{0x24f9926e,0x7bd8198f,0x7af803b2,0x44b001ec}},	// [2a850] онты_, oftu, lvtt, нұяс, 
   {{0xf36473b8,0x44280016,0xb5f80124,0x94040034}},	//   отен, _clb_, _eháp, राइच_, 
   {{0x7af8074d,0x261c00c6,0x7bd80ba7,0xe2c80fb4}},	//   nvtt, _cíos_, iftu, قولو_, 
   {{0x442903d1,0x9f4c00cf,0x5214034b,0x00000000}},	//   _elb_, _cadí_, ядет, --, 
   {{0x26083eaf,0x4429926f,0x7c2803ac,0xf8bc01d3}},	//   हारी_, _flb_, _olfr, mzés_, 
   {{0x44299270,0x261c056a,0xf8bc01ed,0x62999271}},	//   _glb_, _fíos_, lzés_, ívoc, 
   {{0x3af800ef,0x25b00166,0xce38009d,0x00000000}},	//   _nīp_, _öllä_, йчич_, --, 
   {{0x9f4c006a,0xdb099272,0x7bd801f5,0xf8bd9273}},	//   _badâ_, gadí, eftu, nzés_, 
   {{0x7bd80042,0x63700248,0x8c4401af,0x00000000}},	//   fftu, _tóní, зепе, --, 
   {{0x2a60037e,0x7d040158,0x00000000,0x00000000}},	//   _skib_, åksa, --, --, 
   {{0x5ad001d3,0xdb0801d3,0x8cbc07b6,0x97540055}},	//   نےوا, badí, _शिवो, _uṇho, 
   {{0x8c940046,0x00000000,0x00000000,0x00000000}},	//   _еркі, --, --, --, 
   {{0xf7380201,0xbe1000cf,0x0d2000cf,0xf8bc00e5}},	//   _አስፈላ, _سووع, _чүпү, dzés_, 
   {{0x261c0597,0x00000000,0x00000000,0x00000000}},	//   _níor_, --, --, --, 
   {{0x260816da,0xf99c0ba1,0xb5f800ae,0xb9340023}},	//   हाली_, tjèt_, _pháp, _ኣድልዎ, 
   {{0x261c34ea,0x44280489,0x00880131,0x2a60022e}},	//   _ríos_, _slb_, _ﻗﻮﺑﯘ, _ukib_, 
   {{0x261c0491,0x6ad99274,0xdb186f90,0x9f4c0122}},	// [2a860] _síos_, _बहुर, _advè, _radí_, 
   {{0xb4607083,0x29019275,0x261c27b9,0x68e43bfb}},	//   екул, _iria_, _píos_, _ipid, 
   {{0xc43c0020,0xf8bc01ed,0x00000000,0x00000000}},	//   _በከፍተ, szét_, --, --, 
   {{0x7ab80302,0x290001e4,0xdb080798,0xb600219b}},	//   מצעו, _kria_, ladã, ášte, 
   {{0x26d99276,0x44299277,0x261c0597,0x9f4c0308}},	//   ltro_, _tlb_, _fíor_, _vadí_, 
   {{0x44299278,0x261d9279,0x68e406d9,0xf99c0066}},	//   _ulb_, _tíos_, _mpid, njèr_, 
   {{0xdb0800cf,0xd7f00051,0x63b80162,0x6e9000d4}},	//   tadí, ỗi_, óvnu, нищу, 
   {{0x2901927a,0x629d927b,0x69c0043b,0x68e5927c}},	//   _oria_, _itro, ómel, _opid, 
   {{0x80a45662,0xdb09927d,0x629c0165,0x22b80010}},	//   _رمان, radí, _htro, lčk_, 
   {{0x6e280fac,0xdb0802f0,0x8cbc08a3,0x629c00d7}},	//   _elgb, sadí, _शिरो, _ktro, 
   {{0x290061a5,0xdb08d02b,0xcead927e,0x68e40857}},	//   _aria_, dadã, _шә_, _apid, 
   {{0x2900006a,0x6289927f,0xc0dc02d3,0x779003c7}},	//   _bria_, _édou, _ፕረስ_, کیدا, 
   {{0x7e619280,0x29019281,0x26d80395,0x6da19282}},	//   _ikop, _cria_, etro_, _чича, 
   {{0x629d9283,0x26d80295,0xdb0800d8,0xaa8414d1}},	//   _otro, ftro_, gadã, _کنيم_, 
   {{0x29002b92,0x7e619284,0x629d5f4b,0xf8bc00db}},	//   _eria_, _kkop, _ntro, tzés_, 
   {{0x29019285,0x9f4c05da,0x7e600003,0x76800142}},	//   _fria_, _madà_, _jkop, _gŵyl, 
   {{0x629d9286,0x26d99287,0x6830049f,0x7e6000ec}},	// [2a870] _atro, atro_, _bädd, _mkop, 
   {{0xdb191121,0xdd380055,0xdb080798,0xd3b8003b}},	//   _advé, _cāũv, cadã, ілеї_, 
   {{0x7e619288,0xf8bc01ed,0xdb080109,0x1634020f}},	//   _okop, pzés_, nadà, _женя, 
   {{0x7e619289,0x2375928a,0x629d023b,0x00000000}},	//   _nkop, رالح, _dtro, --, 
   {{0x629d928b,0x99880cf4,0x6a4401d3,0xc5f8011a}},	//   _etro, _omaž_, nőfa, _ופרט, 
   {{0x7e611b71,0x9f4d928c,0x683001e6,0x22b8007f}},	//   _akop, _badà_, _gädd, bčk_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd228007b,0x00000000,0x00000000,0x00000000}},	//   _بكره_, --, --, --, 
   {{0x7e6001af,0x8cbc0073,0x6830007c,0x629c013a}},	//   _dkop, _शिळो, _häde, _ztro, 
   {{0x7e600296,0x4b2400d6,0x09c400a5,0x683002f6}},	//   _ekop, дмов, वल्य, _käde, 
   {{0x26d80381,0x68e44ded,0x6830007c,0x629c007c}},	//   xtro_, _spid, _jäde, _xtro, 
   {{0x257400fc,0x29000574,0x6831928d,0x68e4022e}},	//   _júlí_, _pria_, _mäde, _ppid, 
   {{0x6831928e,0xdb080120,0x290000d8,0x00000000}},	//   _läde, tadã, _qria_, --, 
   {{0x26d9928f,0x7e60219b,0x683000a2,0xe73800c7}},	//   ttro_, _zkop, _oäde, зҵо_, 
   {{0x68319290,0x2ba074c8,0xdb082852,0x26d80005}},	//   _rädd, _ख्या, radã, utro_, 
   {{0x29019291,0xa7840184,0x26d80450,0x257401e1}},	//   _tria_, _үҫме, rtro_, _núlí_, 
   {{0x29019292,0xd7c8107f,0x20180428,0xdb098075}},	// [2a880] _uria_, _کوپه_, _òrig_, madá, 
   {{0xdb0829c5,0x68319293,0x26d99294,0x22b802e2}},	//   ladá, _bäde, ptro_, tčk_, 
   {{0x6ad802c3,0x6830007c,0x24580354,0xf2c4030d}},	//   _बहोर, _vädd, çать_, çсен, 
   {{0x81459295,0x629c0393,0x68300432,0x22b802e2}},	//   ونان, _vtro, _däde, rčk_, 
   {{0x42cc015b,0x7e60031c,0x22b802e2,0xef0c00f1}},	//   রবেশ, _rkop, sčk_, یټه_, 
   {{0x02c41c13,0xdb08011f,0x6830702e,0x9f4c0cad}},	//   _ойго, hadá, _fäde, _padà_, 
   {{0x629d9296,0xdb0801ed,0x00000000,0x00000000}},	//   _utro, kadá, --, --, 
   {{0xbb64037e,0x9e7403cc,0x733000db,0x3d2402e8}},	//   _netが_, رۇشت, _شىقا, дьов, 
   {{0xdb080f71,0x683001b8,0x9f4c021c,0x7e600427}},	//   dadá, _zäde, _dadá_, _vkop, 
   {{0x5b140a15,0xafe00022,0x2bf00073,0x68300166}},	//   емот, _иоул, _असणं_, _yäde, 
   {{0x59f802d5,0x7e600003,0x765c0113,0x00000000}},	//   пеня_, _tkop, yoqy, --, 
   {{0x7e619297,0xb5f91e04,0xdb0801ed,0x19599298}},	//   _ukop, _akán, gadá, замы_, 
   {{0x8f800124,0x7f580124,0x9948007b,0x00000000}},	//   _иқәл, _уаҧс_, سلسل_, --, 
   {{0x8d740184,0xbb180014,0x3ce40139,0x9f4c0306}},	//   _яҙыу_, _وٲشا_, _ipov_, _zadá_, 
   {{0x2bf00574,0x7d019299,0xdb080332,0xfa340150}},	//   _असतं_, _hros, badá, _жүні_, 
   {{0x683003fa,0xda7000e3,0x681806be,0x98b80a0e}},	//   _räde, _حُب_, _aşdı, _елит_, 
   {{0x96000eac,0x6831929a,0x00000000,0x00000000}},	// [2a890] _একদম_, _säde, --, --, 
   {{0x6831929b,0x7d000066,0x765c0113,0x00000000}},	//   _päde, _mros, soqy, --, 
   {{0xf3640364,0x765c0309,0x6830008e,0xa3b806c2}},	//   фтан, poqy, _qäde, باقر_, 
   {{0x6830049f,0x7d01929c,0xd1757ab1,0x00000000}},	//   _väde, _oros, нылы, --, 
   {{0xd009310e,0x3ce40066,0x0ef802ab,0x683004cc}},	//   зеле_, _npov_, ्म्स_, _wäde, 
   {{0x160c0574,0xdb085955,0x9f4c00d7,0x257401e1}},	//   हावर_, zadá, _sadá_, _wúlí_, 
   {{0x9f4c02fb,0x7d000d63,0x8db401ca,0x008000c7}},	//   _padá_, _aros, нспі, ылшо, 
   {{0x7d01929d,0xe3b001d3,0x00000000,0x00000000}},	//   _bros, _مرہ_, --, --, 
   {{0x3ce41529,0x7d00b561,0x4c85929e,0xe0d0007b}},	//   _cpov_, _cros, нлив, _نزل_, 
   {{0x7d01929f,0xa2c405ba,0x68300730,0xa074ab4b}},	//   _dros, ांच्, _mädc, _агуч, 
   {{0x7d0192a0,0xdb0808de,0x00000000,0x00000000}},	//   _eros, tadá, --, --, 
   {{0xb878ebee,0xb5f809e8,0x00000000,0x00000000}},	//   ntíf, _skán, --, --, 
   {{0xdb0992a1,0xad2592a2,0x7d003046,0xbd000129}},	//   radá, _تراو, _gros, ïéti, 
   {{0x0ae80d2f,0x00000000,0x00000000,0x00000000}},	//   _فرعي_, --, --, --, 
   {{0xdb0803f7,0xf8bc00e5,0xb8780139,0x7d000210}},	//   padá, szép_, ktíf, _zros, 
   {{0xca741cd1,0x7d00e1f8,0x00000000,0x00000000}},	//   _яулы, _yros, --, --, 
   {{0xda643090,0xb5f80118,0x00000000,0x00000000}},	// [2a8a0] _جاوي, _tkán, --, --, 
   {{0x998801e4,0x00000000,0x00000000,0x00000000}},	//   _joaŝ_, --, --, --, 
   {{0x95040014,0xdb0c00e5,0x00000000,0x00000000}},	//   _یہٲے_, űköd, --, --, 
   {{0xf990010f,0x00000000,0x00000000,0x00000000}},	//   ָרג_, --, --, --, 
   {{0x14880451,0xdfd40121,0xae003d22,0x00000000}},	//   _ڊپٽي_, волы, _शोधन_, --, 
   {{0x7d00036e,0x00000000,0x00000000,0x00000000}},	//   _rros, --, --, --, 
   {{0x057402dd,0x7d0001ef,0x78b8031c,0x9e3400db}},	//   _زاڭد, _sros, ġuvi, кекч, 
   {{0xb8781e0b,0xe7e0228d,0xdb080139,0x00000000}},	//   ctíf, ख्ता_, ladç, --, 
   {{0xfd10e9ad,0x7d0003e3,0x00000000,0x00000000}},	//   اجع_, _qros, --, --, 
   {{0xfe7003e6,0x00000000,0x00000000,0x00000000}},	//   _ڵدا_, --, --, --, 
   {{0x200d92a3,0x0ae80451,0xbd88007b,0x00000000}},	//   _indi_, ورٽي_, _فنان_, --, 
   {{0x7d0192a4,0x200c22d0,0xfe70105f,0x00000000}},	//   _tros, _hndi_, _صدا_, --, 
   {{0xb87992a5,0x200c00ca,0x3ce40010,0xf41c0166}},	//   ntíg, _kndi_, _upov_, _kuät_, 
   {{0xbaf400c7,0x64480100,0x998401b9,0x6830002f}},	//   _зҭоу_, _ňdin, _یلغو, _rädc, 
   {{0x569592a6,0x62985cca,0x19380092,0x00000000}},	//   табт, ívol, _አዕምሮ, --, 
   {{0xddc000b0,0xa9c400d4,0x00000000,0x00000000}},	//   kimō, _йськ, --, --, 
   {{0x200c9041,0x6298010f,0x00000000,0x00000000}},	// [2a8b0] _ondi_, ŭvol, --, --, 
   {{0xe7e0012c,0x37a80137,0xe3b00345,0x7d0401f4}},	//   ख्दा_, _этин_, مرم_, äksy, 
   {{0xdb1802fb,0x00000000,0x00000000,0x00000000}},	//   _odví, --, --, --, 
   {{0x200d0ce8,0xdb080793,0xa29400d4,0x00000000}},	//   _andi_, madä, уаці, --, 
   {{0x683000af,0x31700032,0xe1f0007b,0xc4440014}},	//   _häda, уғат, إسم_, ریہن_, 
   {{0xdb180005,0x28980302,0xe13592a7,0xdc1800ef}},	//   _adví, עדון_, ынчы, _cāļu, 
   {{0xe454e277,0x4ac4230e,0x21642cc8,0xb8780162}},	//   _скры, _विधव, ктәг, mtíd, 
   {{0x60c40953,0x200c0e83,0x68300037,0x82e40327}},	//   šima, _endi_, _mäda, _ྤྱིའ, 
   {{0xaca002e3,0x2258005b,0xd010bbcc,0x623401f4}},	//   kwụn, _читы_, _پلا_, _сету, 
   {{0xb5f992a8,0xb87806c6,0x0c2407a5,0x46e0000d}},	//   _skál, ntíd, тмон, _पहलह, 
   {{0x6830033d,0xb5f97f95,0x321c00e8,0xcdf40d31}},	//   _näda, _akám, _kouy_, _ачлы, 
   {{0xff140375,0x321c0129,0xf41c0139,0x00000000}},	//   _בקעת_, _jouy_, _kuäs_, --, 
   {{0x290592a9,0x2d8d92aa,0x321c0de2,0x200ccb92}},	//   íma_, _igge_, _mouy_, _yndi_, 
   {{0x321c00e8,0x8c4592ab,0xdb1800d0,0x7d0401bf}},	//   _louy_, _шеле, _zdví, ækse, 
   {{0x9f4c0139,0xf740034f,0xf1b011a6,0x23bc0118}},	//   _gadä_, аеро, ुणान, hájí_, 
   {{0x321c02e2,0xfaa0023b,0x26c40010,0x00000000}},	//   _nouy_, _таъо, čmo_, --, 
   {{0xf8bc01ed,0x9f4c0139,0x99980064,0x00000000}},	// [2a8c0] lyén_, _zadä_, ansų_, --, 
   {{0x03a407d6,0xca7401e0,0xdb08008e,0xc724022e}},	//   тижо, _яуһы, badä, _адой, 
   {{0x321d356e,0x26dc00e4,0x490800bc,0x2d8c007c}},	//   _bouy_, _ëvo_, ामको_, _ogge_, 
   {{0xfb1800c8,0x2d8c0066,0x9f4c007c,0x8fd401e0}},	//   וועמ, _ngge_, _jadå_, ғәфә, 
   {{0xc05801ce,0x00000000,0x00000000,0x00000000}},	//   мік_, --, --, --, 
   {{0x2d8c017a,0xb878004e,0xf41c0139,0x00000000}},	//   _agge_, rtíg, _quät_, --, 
   {{0x321c8cf6,0xb87992ac,0xefb02cef,0xd24c03e6}},	//   _fouy_, stíg, شینگ, _کۆن_, 
   {{0x26081414,0x00000000,0x00000000,0x00000000}},	//   हाटी_, --, --, --, 
   {{0x9cb4c25a,0x9f4c0166,0x00000000,0x00000000}},	//   دمخت, _sadä_, --, --, 
   {{0x200d92ad,0xff24136b,0xdb080724,0x2d8c03cd}},	//   _undi_, _имзо, yadä, _egge_, 
   {{0xa3e592ae,0xb87826b7,0x321c0de2,0x00000000}},	//   भ्य_, ntíe, _youy_, --, 
   {{0xf2d004ac,0xda3400c9,0xdb0804cc,0xb2b80375}},	//   סער_, уемы, vadä, ומטר, 
   {{0xdeb00220,0x2e3402e4,0x2ba0924b,0x68300166}},	//   _тұқы, _בראש_, _ख्वा, _säda, 
   {{0x683192af,0xed4c02f2,0xab90009b,0x00000000}},	//   _päda, _بپه_, _кашљ, --, 
   {{0x36880323,0x12d40150,0x62980115,0x54540b01}},	//   дсан_, _ﯞﻗﻮﺭ, ŭvoj, ҳват, 
   {{0xe65402bf,0x00000000,0x00000000,0x00000000}},	//   авсь, --, --, --, 
   {{0xb5f800e4,0x84c058a7,0xb8640b24,0x54540395}},	// [2a8d0] _ukám, йәрд, _لادو, гват, 
   {{0x57f421c3,0x06dc00cc,0x73481d0f,0x1b1400eb}},	//   _спот, ডিজি, мчев_, ানীং_, 
   {{0x321d92b0,0xa3c4072a,0x3ebc0051,0xb8792924}},	//   _pouy_, _एयर_, _nvtt_, rtíd, 
   {{0x4ac40037,0x50b40064,0x00000000,0x00000000}},	//   _विसव, гску, --, --, 
   {{0xb87810d8,0xe7e007f7,0x2bf00073,0x00000000}},	//   ptíd, ख्वा_, _असलं_, --, 
   {{0x85480208,0x00000000,0x00000000,0x00000000}},	//   _ýmuố, --, --, --, 
   {{0x321c0585,0x22440109,0x26080073,0xfbb4012d}},	//   _touy_, _fmmk_, हाची_, _आज़म, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4bd80953,0x7ae85732,0xb5f800d0,0xc0c400f1}},	//   ньня_, _apft, _akák, _مېنه_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xca8405f5,0x2018067c,0x8c9401ec,0x00000000}},	//   лгой, _òria_, _өрлі, --, 
   {{0x26dc00e4,0x00000000,0x00000000,0x00000000}},	//   _ävoi_, --, --, --, 
   {{0x9f4c0267,0xf1c80150,0x00000000,0x00000000}},	//   _vadå_, _ﻗﺩﻤﺘ, --, --, 
   {{0x4a440116,0x999800d0,0x00000000,0x00000000}},	//   _әнив, visť_, --, --, 
   {{0xae143daa,0x00000000,0x00000000,0x00000000}},	//   थापन_, --, --, --, 
   {{0x5f0400cd,0x00000000,0x00000000,0x00000000}},	//   वित्_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [2a8e0] --, --, --, --, 
   {{0x97b4e643,0x99980419,0x00000000,0x00000000}},	//   _ксюш, risť_, --, --, 
   {{0x69c4003e,0x05040154,0xfbb400bc,0x00000000}},	//   _kdie, োনের_, _आजसम, --, 
   {{0xb878004e,0x4734004e,0xe7e000bc,0x00000000}},	//   rtíe, _анүс, ख्रा_, --, 
   {{0x69c40369,0x75400024,0x6114009d,0x00000000}},	//   _mdie, _гняз, рдлу, --, 
   {{0x60c57a74,0xa2cc09b2,0x00000000,0x00000000}},	//   šimo, _हिप्, --, --, 
   {{0x69c51670,0xdb180122,0x9e1402bf,0x9f340220}},	//   _odie, _odvá, идкі, рейі, 
   {{0x11d4005e,0x00000000,0x00000000,0x00000000}},	//   _ەتەد, --, --, --, 
   {{0x7c9c01f2,0xb8787917,0xf8bc01ed,0xbc483420}},	//   _bọọl_, ntíc, gyél_, ечне_, 
   {{0x69c592b1,0xdb0800ae,0x5f043711,0x31200354}},	//   _adie, madú, विद्_, _удуг, 
   {{0x7de40046,0x69c4003d,0x6f9000c6,0x0eb80166}},	//   _білд, _bdie, _المض, _аучы_, 
   {{0xa2cc44ab,0x7f940588,0xd1bc069d,0xceb400fb}},	//   _हिन्, _раҧх, _ታቦት_, _өҙә_, 
   {{0xaa640139,0x69c403cb,0xeaf403e6,0xe3cc0154}},	//   стэк, _ddie, نرێت_, র্যব, 
   {{0x69c592b2,0x56000154,0xac18030d,0x707c0092}},	//   _edie, _একেক_, _пачĕ_, ትፈልጉ_, 
   {{0xf608eb9f,0x00000000,0x00000000,0x00000000}},	//   нхай_, --, --, --, 
   {{0x69c05793,0xa5f992b3,0xed5c0064,0x00000000}},	//   ómet, лесу_, _ūžia_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [2a8f0] --, --, --, --, 
   {{0x69c401a2,0xb8785cca,0xd9e02e1e,0xa4d40845}},	//   _zdie, stíb, ग्रत_, софі, 
   {{0xe29800d6,0xf8bc4fc1,0xf748a5f4,0xb8780005}},	//   гає_, lsé_, _سجده_, ptíb, 
   {{0xd13192b4,0xf99d92b5,0xb5f80022,0x9f4c0332}},	//   يما_, ncè_, _okái, _fadú_, 
   {{0xf8bd92b6,0xb87992b7,0x9f4c00d8,0x00000000}},	//   nsé_, ctíc, _gadú_, --, 
   {{0x412592b8,0xf8bc07ea,0xe3cc015b,0xfde007af}},	//   рошо_, isé_, র্বব, क्सस_, 
   {{0x4df407d6,0xb5f800e4,0x59c40574,0xdea42050}},	//   аяпт, _akái, वणार, میلی, 
   {{0xccc4576f,0xd24c0133,0x20180248,0x00000000}},	//   абий, _کۆچ_, _òrin_, --, 
   {{0xa1582f89,0x6aa00009,0xdb080332,0xed100154}},	//   _бату_, _stnf, cadú, িন্স_, 
   {{0xa0c40597,0x6ee4ad6b,0x69c4ab10,0x2c6801bf}},	//   _ديكو, _مسؤل, _sdie, jødt_, 
   {{0xca7592b9,0xcac800a7,0x208415b0,0x2c6801bf}},	//   иумы, ъгне_, _اللّ, dødt_, 
   {{0xfe980302,0x69c4031c,0x6830a7d4,0x629800e4}},	//   _סינמ, _qdie, _pädo, ívoi, 
   {{0xd1ec0020,0x2c681512,0xeca40114,0x6ca41422}},	//   _ቀናት_, født_, _сјен, _среж, 
   {{0xcb680276,0xc050008f,0x2c6803b2,0x3e78036e}},	//   _иале_, ַזן_, tødu_, rëte_, 
   {{0xbb4048ab,0x2cbc011c,0xf8bc00e4,0x00000000}},	//   _мешк, lsud_, asé_, --, 
   {{0x69c592ba,0xf99c19f5,0xa2cc06b1,0x2d9c6fca}},	//   _udie, ccè_, _हिब्, ncue_, 
   {{0x78580882,0xdb240ca8,0x00000000,0x00000000}},	// [2a900] ṃvar, _ìsòr, --, --, 
   {{0x2cbc0037,0x04440114,0x48080798,0x00000000}},	//   isud_, шезн, _реон_, --, 
   {{0x42d4003b,0x00000000,0x00000000,0x00000000}},	//   різу, --, --, --, 
   {{0x2cbc8590,0x00000000,0x00000000,0x00000000}},	//   ksud_, --, --, --, 
   {{0x25a00263,0x0084c9ff,0x00000000,0x00000000}},	//   mcil_, алдо, --, --, 
   {{0x3ec41c22,0x9f3401ec,0xc2c82b9f,0xdb080419}},	//   асиб, йелі, _لبرل_, radú, 
   {{0xb878a921,0x25a00009,0x00000000,0x00000000}},	//   ntía, ocil_, --, --, 
   {{0x613c003a,0xc1040451,0x1e140c60,0x2cbc0135}},	//   _cælé, _پوئي, смия, fsud_, 
   {{0x2cbc409c,0x80a50ee6,0xfde007d0,0x28d8102f}},	//   gsud_, _ضمان, क्षस_, भूमि, 
   {{0xdb20025a,0x25a001ab,0xddc00118,0x443992bb}},	//   _âtën, hcil_, pomů, nhp_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xba4592bc,0xbd68104e,0x3cc800d8,0x00000000}},	//   рхой, _ирле_, _алдо_, --, 
   {{0xf99c00f7,0x3dc4003e,0xf8bc06af,0x2cb40014}},	//   rcè_, _idow_, usé_, _نُند_, 
   {{0xf8bd92bd,0xf99c0268,0xf7704caa,0x69c029d3}},	//   rsé_, scè_, قاز_, ómer, 
   {{0xf8bd92be,0xf644a69a,0x2c682f48,0x4ddc012c}},	//   ssé_, ахан, rødt_, क्कै_, 
   {{0x4438009a,0x9b680075,0xaa441f5a,0xbbb400c5}},	//   ehp_, _ишқа_, _мејл, _आजुक, 
   {{0xcc8404d3,0x394c0267,0x00000000,0x00000000}},	// [2a910] _خۆیه_, _ägs_, --, --, 
   {{0x7c3801fb,0xb4c4012d,0x740400eb,0x00000000}},	//   nhtr, _ईटी_, োস্ট_, --, 
   {{0xb9080055,0x55c40166,0x81c005ac,0x7c240200}},	//   _apiḥ_, _гәзз, ্ভন_, ëkry, 
   {{0xb5f800c7,0x672801e6,0x00000000,0x00000000}},	//   _akáv, ädje, --, --, 
   {{0x7c380b6f,0x91043d2a,0x8fa4ec77,0xdb1800b5}},	//   khtr, спле, бале, _udvæ, 
   {{0x3dc40009,0x443815c0,0x00000000,0x00000000}},	//   _adow_, chp_, --, --, 
   {{0x7c3800a3,0x1e940276,0xa3bc000d,0xdfd80395}},	//   dhtr, орыр, _इजत_, ръч_, 
   {{0x7c380109,0xa3b801ed,0x8d740133,0x60cc1432}},	//   ehtr, _ماہر_, یاکا, ülmü, 
   {{0xc0e0044e,0x6da0013e,0x61e400a3,0x00000000}},	//   ነብር_, биқа, òile, --, 
   {{0x5f9592bf,0xed541621,0x2d9d92c0,0x3e300014}},	//   _дифт, лоқ_, scue_, ٲفیر, 
   {{0xf8bc6085,0x2cbc21c6,0x24a800eb,0x00000000}},	//   byék_, ssud_, _ওয়াহ, --, 
   {{0x8d940597,0xb5f803b2,0x2cbc0037,0xf3f000fe}},	//   _الإش, _hjáf, psud_, ঘাটৰ_, 
   {{0x6e3992c1,0xf8bc0098,0x4438a8cf,0x2cbc263e}},	//   mhub, nyéh_, yhp_, qsud_, 
   {{0x7c3992c2,0x6e39047b,0x27580092,0x2c6801bf}},	//   chtr, lhub, _የስልጠ, røds_, 
   {{0x21e000b0,0x6cc00032,0x89d400d4,0x00000000}},	//   _hōhō_, _уйҙа, _ліпш, --, 
   {{0xb8784c25,0x6e3992c3,0x3cec000d,0x3d1c00cc}},	//   rtía, nhub, _अहमे_, _বেট্_, 
   {{0x15b992c4,0x25a06fca,0xb8782b76,0xe9840131}},	// [2a920] рысы_, rcil_, stía, _باغۋ, 
   {{0x6e380117,0x25a192c5,0xb8780332,0xdb080feb}},	//   hhub, scil_, ltín, tadø, 
   {{0x6e382935,0xdb20022c,0x4df80118,0x00000000}},	//   khub, ðtøk, ्याई_, --, 
   {{0xd5b805cc,0x3e780023,0x932407d6,0xdb0803b2}},	//   _всё_, këta_, غرلن, radø, 
   {{0x660592c6,0x443804ce,0x6e3992c7,0x1fb805a2}},	//   mdik, php_, dhub, аллы_, 
   {{0xdfd0bd0e,0xb9780375,0x7fd400d4,0xa4440345}},	//   ذيب_, ננסי, сіді, _بێئو, 
   {{0x81c000bd,0x28d80882,0xf99c067c,0x6d4c00d0}},	//   ্ভব_, भूति, ndèc_, úcan, 
   {{0x6e394fbd,0x1d3402e8,0xa3e405c0,0x00000000}},	//   ghub, жния, भ्र_, --, 
   {{0x6280047e,0x61549cce,0x6da0147e,0x68300267}},	//   _ihmo, _بچائ, чиња, _vädj, 
   {{0x6604023a,0x00000000,0x00000000,0x00000000}},	//   hdik, --, --, --, 
   {{0x6e38136f,0x66055545,0x00000000,0x00000000}},	//   bhub, kdik, --, --, 
   {{0x6e381cea,0x7c38044e,0x3e780240,0x337400d9}},	//   chub, shtr, bëta_, מעים_, 
   {{0x660592c8,0x395c5725,0x62800455,0x60c400ae}},	//   ddik, çus_, _mhmo, áimh, 
   {{0x66048f1e,0x569468ba,0xb8780419,0x00000000}},	//   edik, жавт, atín, --, 
   {{0x62800477,0xe78400d8,0x3d1c00cc,0x00000000}},	//   _ohmo, зуто, _বেচ্_, --, 
   {{0x66044cd3,0x645d92c9,0x58d400d8,0x68300166}},	//   gdik, _ajri, _доит, _yädk, 
   {{0x5fc81715,0x24580022,0x00000000,0x00000000}},	// [2a930] रणाल, әахь_, --, --, 
   {{0x7bd992ca,0xb5f992cb,0xdb1807ea,0x628001b9}},	//   ngtu, _akát, _revê, _ahmo, 
   {{0x628005be,0x660449f0,0x645d92cc,0x6e38009a}},	//   _bhmo, bdik, _djri, yhub, 
   {{0x6280b0e8,0xaf50010b,0xb5f8032e,0xa9240064}},	//   _chmo, үндә, _sjáf, _ūžim, 
   {{0xdb1804e6,0xb87800ae,0x109001ec,0x00000000}},	//   _bevë, ntío, _ﺟﻮﺭﯨ, --, 
   {{0xd00992cd,0x768c01e1,0xb87801e7,0xf1e400db}},	//   реке_, _fòyì, itío, _گورۉ_, 
   {{0x6e3992ce,0xdb180200,0x15fc0037,0x705000db}},	//   thub, _devë, _उघार_, _ۉچتا, 
   {{0x7bd80e29,0x4e2992cf,0x72343868,0xb87800d7}},	//   egtu, роин_, _ارسط, xtín, 
   {{0x6e3815a5,0x90540024,0xd7a801f9,0x00000000}},	//   rhub, _двац, कडाच, --, 
   {{0x3e780240,0x62800c53,0x5fe00412,0x0ae81f39}},	//   rëta_, _zhmo, _नायल, адой_, 
   {{0x6e3800d2,0x6604a6a6,0x00000000,0x00000000}},	//   phub, ydik, --, --, 
   {{0x6e388cdb,0xa2cc02fe,0x7bd80211,0x37b000cc}},	//   qhub, _हिस्, agtu, _জাগৰ, 
   {{0xdb1856ec,0x6604029f,0x39400006,0x1cb80327}},	//   _levè, vdik, дняг, _མཆར_, 
   {{0x62880395,0xdb0800ee,0x29c800f7,0x68300432}},	//   _èdov, ladý, штүү_, _kädi, 
   {{0xb5f81aac,0xc7642544,0x96942f33,0x660592d0}},	//   _nkás, زاسى, зруш, tdik, 
   {{0x60c592d1,0xc62004c5,0x645c020c,0x660592d2}},	//   šimi, নসভা_, _sjri, udik, 
   {{0x660592d3,0xaa880014,0x44a47577,0xb5f800d7}},	// [2a940] rdik, _پچھم_, زماق, _akás, 
   {{0xb5f86492,0x290192d4,0x628001d5,0xe7e00118}},	//   _ajád, _isia_, _shmo, ख्खा_, 
   {{0x683000ee,0x27f992d5,0x660592d6,0xa6540133}},	//   _nädi, mern_, pdik, _فێست, 
   {{0x26d992d7,0xdb186f90,0x27f992d8,0x33240227}},	//   muro_, _devè, lern_, änxa_, 
   {{0x26d992d9,0xf99c067c,0xdb0992da,0x7bd8007c}},	//   luro_, ndèa_, dadý, ygtu, 
   {{0x27f97125,0x29002a1f,0x68300139,0x6298056a}},	//   nern_, _msia_, _bädi, ívos, 
   {{0x26d862f9,0x63bd92db,0x6830013d,0x27f82ad7}},	//   nuro_, _iern, _cädi, iern_, 
   {{0x27f992dc,0x629d92dd,0x290192de,0x6830010e}},	//   hern_, _iuro, _osia_, _dädi, 
   {{0x629d92df,0x26d91adb,0x27f992e0,0x2900013f}},	//   _huro, huro_, kern_, _nsia_, 
   {{0x629d92e1,0x63bc7a1e,0x26d992e2,0x27f992e3}},	//   _kuro, _jern, kuro_, jern_, 
   {{0x629d92e4,0x63bd92e5,0x68e592e6,0xdb1800dd}},	//   _juro, _mern, _aqid, _kevé, 
   {{0x26d992e7,0x63bd92e8,0x629d92e9,0x2900020b}},	//   duro_, _lern, _muro, _bsia_, 
   {{0x27f992ea,0x63bd92eb,0x26d8011c,0x629c014f}},	//   fern_, _oern, euro_, _luro, 
   {{0x27f992ec,0x63bd92ed,0xeb8c2be7,0xb87800c6}},	//   gern_, _nern, عظی_, rtío, 
   {{0x290192ee,0x629d92ef,0xb8780597,0xba74007b}},	//   _esia_, _nuro, stío, _واعت, 
   {{0x63bd92f0,0xdb1992f1,0xb5f992f2,0x67280267}},	//   _aern, _nevé, _akár, ädja, 
   {{0x63bd92f3,0x27f992f4,0x26d80618,0xb8790ca8}},	// [2a950] _bern, bern_, auro_, ltím, 
   {{0x629d92f5,0x63bd92f6,0xd9d0040d,0xa84806f6}},	//   _buro, _cern, _تەڭگ, _وليم_, 
   {{0x63bd92f7,0xb878057f,0x629d92f8,0xdb080e55}},	//   _dern, ntím, _curo, madó, 
   {{0x629d92f9,0x63bd92fa,0xdb0992fb,0xb5f801e1}},	//   _duro, _eern, dadü, _ekár, 
   {{0x63bd92fc,0xddc8068f,0xdb1903e2,0x61e401ab}},	//   _fern, łośc, _devé, òila, 
   {{0x63bd92fd,0xe4d4168d,0x68300793,0x9f4c0137}},	//   _gern, _کتێب, _pädi, _nadó_, 
   {{0x629d92fe,0x68300166,0x629800df,0x048401ee}},	//   _guro, _qädi, ŭvor, _хәти_, 
   {{0xf1bc0f99,0x27f992ff,0x63bc1570,0x7bc816b8}},	//   _þá_, zern_, _zern, _adfu, 
   {{0x27f99300,0x26d99301,0x63bd9302,0x7bc80005}},	//   yern_, zuro_, _yern, _bdfu, 
   {{0x9f4c0429,0x2900020b,0x629d9303,0x68319304}},	//   _cadó_, _rsia_, _yuro, _tädi, 
   {{0xcb699305,0xb8799306,0x27f86a3a,0x8d94ba4b}},	//   сане_, rtíl, vern_, _فلاش, 
   {{0x62881a44,0xb87808a7,0x27f99307,0x26d805d5}},	//   _èdot, stíl, wern_, vuro_, 
   {{0xdb0800c6,0xfde405d9,0x26d83185,0x68e4022e}},	//   fadó, _رکيو_, wuro_, _qqid, 
   {{0x27f8481f,0xc7940cdd,0xdb099308,0x28d800dc}},	//   uern_, ярмы, gadó, भूषि, 
   {{0x63bc56c0,0x1cb8025c,0x27f99309,0x69c80134}},	//   _rern, _མཆོ_, rern_, ɔden, 
   {{0x26d80516,0x2901930a,0x27f9930b,0x9f4c007f}},	//   ruro_, _tsia_, sern_, _kadò_, 
   {{0x63bc122d,0x629d930c,0xdb18ebee,0x27f9930d}},	// [2a960] _pern, _suro, _revé, pern_, 
   {{0x26d80516,0x63bc20ac,0xdb09930e,0xdb1800e4}},	//   puro_, _qern, cadó, _sevé, 
   {{0x629c07d6,0xdb180124,0x7dd40790,0xb16c0023}},	//   _quro, _pevé, nüsü, _እናኾነ_, 
   {{0x63bd930f,0x629c0165,0x00000000,0x00000000}},	//   _wern, _vuro, --, --, 
   {{0x63bd9310,0x1cb80135,0x9f4c004e,0xdb08067c}},	//   _tern, _མཆེ_, _nadò_, nadò, 
   {{0x19c00075,0x63bc6a97,0x44e4003a,0xb5f802d2}},	//   _ﻣﯩﻠﻠ, _uern, mô_, _gjáb, 
   {{0x44299311,0xdb1800dd,0x629d314e,0x44e4003a}},	//   _iob_, _tevé, _uuro, lô_, 
   {{0x44299312,0xdd959313,0x7a3c0240,0x9d140131}},	//   _hob_, майы, _këte, ддич, 
   {{0xf8bd9314,0x44299315,0xdb0847af,0x317c031c}},	//   nyét_, _kob_, sadü, _gzuz_, 
   {{0x44299316,0x2a619317,0x7a3c0023,0x406002e3}},	//   _job_, _ajib_, _mëte, bọọl, 
   {{0x44299318,0x9f4c068c,0x3eac014b,0xb87806ea}},	//   _mob_, _vadó_, qpft_, utím, 
   {{0x44299319,0x44e40770,0xb878066a,0x60c40006}},	//   _lob_, kô_, rtím, šimu, 
   {{0xb87950c2,0x442801d4,0x9f4d931a,0xa3cc01f9}},	//   stím, _oob_, _gadò_, ळणा_, 
   {{0x7d01931b,0x4429931c,0xb5f847f1,0x44e458a4}},	//   _isos, _nob_, _akáp, dô_, 
   {{0x3ce40218,0x44e40086,0x7dd43361,0xb87802f0}},	//   _hqov_, eô_, cüsü, ltík, 
   {{0xdb09931d,0x7d000100,0x7c29931e,0x4428005c}},	//   badò, _ksos, _hofr, _aob_, 
   {{0x81c00d42,0xdb09931f,0x44e4145e,0x7c299320}},	// [2a970] ংলা_, padó, gô_, _kofr, 
   {{0x44299321,0x7d015019,0x7c2800db,0xdb08011f}},	//   _cob_, _msos, _jofr, qadó, 
   {{0x7c299322,0xd6d40b30,0x1ddc1d68,0x629800e4}},	//   _mofr, _южны, _यांत, ívop, 
   {{0x7d019323,0x44e4011f,0x44280fac,0x7bcc033f}},	//   _osos, bô_, _eob_, óbuj, 
   {{0x3ce401d4,0x7d00013f,0x44e59324,0x7c283471}},	//   _nqov_, _nsos, cô_, _oofr, 
   {{0x44299325,0x7c299326,0x7dd40b97,0x00000000}},	//   _gob_, _nofr, yüsü, --, 
   {{0x7d00b502,0x1cb80003,0xead400eb,0x00000000}},	//   _asos, _མཆུ_, _তন্ম, --, 
   {{0x44299327,0x00000000,0x00000000,0x00000000}},	//   _zob_, --, --, --, 
   {{0x44280211,0x7c280115,0x4c8505c6,0x8c4400a8}},	//   _yob_, _bofr, млив, депе, 
   {{0x7c299328,0x44299329,0xcac80a8f,0x2a60017a}},	//   _cofr, _xob_, огое_, _sjib_, 
   {{0x37e003f4,0x60c402d5,0x7d01932a,0xf99c00f2}},	//   য়ার, šimt, _esos, rdèn_, 
   {{0x7c2805da,0x7dd41432,0x26cc0e33,0xf42000eb}},	//   _eofr, rüsü, ádom_, ফসির_, 
   {{0x7c28013f,0x44e40429,0xefb80b82,0xfbd001ec}},	//   _fofr, xô_, _ሰንዓ_, _ﻛﯘﺭﻛ, 
   {{0x7c2800a9,0x6e28022f,0xb5f80321,0xdb081f3f}},	//   _gofr, _hogb, _skáp, radò, 
   {{0x7a3c006a,0x6e280241,0x442823bd,0x00000000}},	//   _sëte, _kogb, _rob_, --, 
   {{0x4429932b,0xf99c6f90,0x3d000490,0xdb087491}},	//   _sob_, ndèl_, वटचे_, padò, 
   {{0x4429932c,0x15fc0034,0xb90000f7,0x6e280241}},	// [2a980] _pob_, उज़र_, _азык, _mogb, 
   {{0x6e29932d,0x683029ef,0x7c28056a,0x44e5932e}},	//   _logb, _pädu, _xofr, rô_, 
   {{0x44280334,0x44e42776,0x06854afd,0x6e280b4f}},	//   _vob_, sô_, _огон, _oogb, 
   {{0x442801f5,0x7a3c0036,0xda200c6f,0x6e28058a}},	//   _wob_, _tëte, यायत_, _nogb, 
   {{0x245404a9,0x4429932f,0x44e4011f,0x76200276}},	//   _كۆرس, _tob_, qô_, _рмяз, 
   {{0x453401a9,0xdd94035b,0x00000000,0x00000000}},	//   _ехҳт, ҭакы, --, --, 
   {{0x6e28493a,0xf8bc01ed,0xf8d807f7,0x7d0013be}},	//   _bogb, nyér_, _बम्प, _ssos, 
   {{0x7c299330,0x249800c5,0x6d4401e4,0x60c40332}},	//   _sofr, _hirm_, ĝjan, áims, 
   {{0x6e299331,0x7c28067c,0x908801d9,0x00000000}},	//   _dogb, _pofr, _کمٕے_, --, 
   {{0xb878022a,0x6fb0007b,0x19580022,0x00000000}},	//   rtík, _لمكا, ҧаны_, --, 
   {{0xb8780306,0x6830002f,0x00000000,0x00000000}},	//   stík, _läds, --, --, 
   {{0x7d0083c6,0x7c28016b,0x58d400c7,0xee34014b}},	//   _tsos, _wofr, номт, _онх_, 
   {{0x1cb80003,0x7d00180e,0x7e600022,0x7c2800a2}},	//   _མཆི_, _usos, _ijop, _tofr, 
   {{0x69c8013f,0x57a801f9,0x00000000,0x00000000}},	//   ɔdem, कडेह, --, --, 
   {{0x7790034c,0x7e6003cd,0x5f0407f7,0xaab416a2}},	//   ضیحا, _kjop, विट्_, _قدير_, 
   {{0x24999332,0x6a8403b7,0xdb18013a,0x00000000}},	//   _airm_, _илја, _jeví, --, 
   {{0x24980139,0xf99c7d47,0xb87800e4,0xb86407fc}},	// [2a990] _birm_, ndèm_, juíg, _ياخو, 
   {{0xdb187ae7,0x237803b2,0xdc80001f,0xf77000d1}},	//   _leví, _byrj_, _የባህር_, _ۋاھ_, 
   {{0x7e600124,0x06a001ec,0x00000000,0x00000000}},	//   _ojop, _ﻋﺎﻳﯩ, --, --, 
   {{0xdb180316,0x00000000,0x00000000,0x00000000}},	//   _neví, --, --, --, 
   {{0x24983d4a,0xb5f80174,0xe4a4041b,0x6e280248}},	//   _firm_, _gjáa, _арсо, _rogb, 
   {{0xfd64063f,0x7e619333,0xdea407d6,0x6e2801e1}},	//   sspọ, _ajop, چیلی, _sogb, 
   {{0xdb180162,0xdea401b9,0x00000000,0x00000000}},	//   _beví, نیلی, --, --, 
   {{0xb8799334,0xfde400a7,0x0404015b,0x683001e3}},	//   luíd, едък_, রাণী_, _jädr, 
   {{0xdb180122,0x6e28017a,0x683000fd,0xb1440244}},	//   _deví, _vogb, _mädr, _تیشم_, 
   {{0x7e600124,0x99891bb5,0xb87810d8,0x4b2448e5}},	//   _ejop, _blaž_, nuíd, емов, 
   {{0x6e299335,0x09e4022e,0x00000000,0x00000000}},	//   _togb, нонн, --, --, 
   {{0xea680137,0x00000000,0x00000000,0x00000000}},	//   بەبي_, --, --, --, 
   {{0x27b46cf7,0x9d440066,0x00000000,0x00000000}},	//   кәнс, _لئون, --, --, 
   {{0x683001e6,0x00000000,0x00000000,0x00000000}},	//   _räds, --, --, --, 
   {{0x6830008e,0x765c0175,0x37842b39,0xb5f808a5}},	//   _bädr, fnqy, ебро_, _sjáa, 
   {{0x249805da,0x00000000,0x00000000,0x00000000}},	//   _sirm_, --, --, --, 
   {{0x05659336,0xc7a40353,0x684401ec,0x2498139f}},	// [2a9a0] хван, _пипк, _үнқа, _pirm_, 
   {{0x0a1002f5,0x6810013f,0x6b80037e,0xdb0801e3}},	//   _হকিং_, kɔdɔ, _kzng, bbdä, 
   {{0x6aa80311,0x26dc0124,0x32a401ec,0x80d0000d}},	//   _înfă, _êvo_, еуің, _सिहइ, 
   {{0xa3b017cb,0xb5f803b2,0x04040154,0x00000000}},	//   _ट्र_, _hján, রাধী_, --, 
   {{0xb87810ba,0xdb1803a7,0x057401d5,0xb5f808a5}},	//   buíd, _reví, _ساحد, _kján, 
   {{0x3010005e,0x26099337,0xdf78aa47,0x7e6008a5}},	//   лдір, ाएकी_, мблі_, _sjop, 
   {{0x68300139,0x00000000,0x00000000,0x00000000}},	//   _yädr, --, --, --, 
   {{0x26d80009,0x9f5c036e,0x00000000,0x00000000}},	//   irro_, levë_, --, --, 
   {{0xd24ca04e,0xdb080793,0xd058013f,0x806400d3}},	//   _بۆن_, nadö, ntwɛ, _зваж, 
   {{0xe7dc0034,0x6810013f,0xb8783b82,0x26d80023}},	//   _बागप, bɔdɔ, ltív, krro_, 
   {{0x7e600ea0,0x3f9c0009,0x8ac40124,0x00000000}},	//   _tjop, _igtu_, ҭқәа_, --, 
   {{0xb5f8066d,0x7a3c0de2,0x19599338,0xb8799339}},	//   _aján, _bëta, дамы_, ntív, 
   {{0x443805b1,0x6cd05085,0x3f9c0139,0xb5f808a5}},	//   kkp_, _مقنا, _kgtu_, _bján, 
   {{0x4cd804c5,0xad180375,0xab6001c0,0x9f5c0240}},	//   _বৈকু, _מודר, _өвчл, jevë_, 
   {{0xb878c2f1,0x68300793,0x4438036e,0x6aa400fe}},	//   ktív, _pädr, dkp_, কীবো, 
   {{0xd00809bd,0x387c06af,0x2608033f,0xb8d40154}},	//   লায়_, œur_, ाएगी_, _চট_, 
   {{0xb87810ba,0x799c00f1,0x683001e6,0x26d80009}},	// [2a9b0] tuíd, _igqw, _vädr, arro_, 
   {{0xf3647b0f,0x7c380334,0x04840116,0xb5f802d2}},	//   нтен, nktr, вәси_, _gján, 
   {{0xf365933a,0xb879933b,0x9318007b,0x712451ae}},	//   хтан, ruíd, بقاء_, کرال, 
   {{0xb8780005,0x95840166,0xfcf40023,0xc6b4011a}},	//   suíd, _үлүе, _ፈለጡ_, _שהרי_, 
   {{0xd008b076,0x3f9c0263,0x7c39933c,0x04a400c7}},	//   деле_, _bgtu_, kktr, _аусҭ, 
   {{0xb879933d,0xcef40120,0x68300139,0x00000000}},	//   quíd, вчињ, _yädq, --, 
   {{0xd9d86569,0x799c0472,0x244401e6,0x40300b3e}},	//   ধ্যম, _ogqw, _dömd_, рејс, 
   {{0x799c01e2,0x7c38022f,0xb87800e4,0x00000000}},	//   _ngqw, ektr, ctív, --, 
   {{0x20240436,0x0d20049e,0x0d8401a9,0x00000000}},	//   ýrið_, рүлү, ълин, --, 
   {{0x799c009a,0x244401e3,0x4aa801f0,0x614400f3}},	//   _agqw, _gömd_, мкон_, _сеђа, 
   {{0x2fc5933e,0xdb180589,0x7a3c00e8,0x3e780200}},	//   mang_, _revã, _sëta, zëti_, 
   {{0x2fc5933f,0x3ea803c6,0x00000000,0x00000000}},	//   lang_, žité_, --, --, 
   {{0x6e399340,0x2fc401e0,0x7d04005c,0xddc027ac}},	//   mkub, oang_, ækst, limş, 
   {{0x2fc59341,0x799c00f1,0x7c399342,0x6e38058a}},	//   nang_, _egqw, cktr, lkub, 
   {{0x2fc40295,0x6e3824be,0x26d80009,0x157c1884}},	//   iang_, okub, urro_, ﻣﯩﺘﯩ, 
   {{0x6e399343,0x2fc59344,0x7a3d9345,0x09340006}},	//   nkub, hang_, _tëta, _ахоў, 
   {{0x6e38efd2,0x69c400e2,0x35a000fd,0xb5f801a8}},	// [2a9c0] ikub, _ieie, рауг, _tján, 
   {{0xb5f81bb0,0x2fc59346,0x69c59347,0x6aa19348}},	//   _hjál, jang_, _heie, _kunf, 
   {{0x2fc487d3,0x69c59349,0x6e3822a9,0xb8780077}},	//   dang_, _keie, kkub, buíb, 
   {{0x69c5934a,0x6aa00083,0xb8780798,0x00000000}},	//   _jeie, _munf, cuíb, --, 
   {{0x69c5934b,0xf6bc0135,0x6aa1934c,0x44380194}},	//   _meie, _མཆོང, _lunf, pkp_, 
   {{0x69c5934d,0xb8780261,0x9f5c07ea,0x6fb02088}},	//   _leie, stív, levé_, لمها, 
   {{0xb879934e,0x6aa1934f,0xa2cc0db3,0x3f9c0153}},	//   ptív, _nunf, _हिट्, _vgtu_, 
   {{0x69c59350,0xdb180232,0x6e384cd3,0xdcc80032}},	//   _neie, _nevá, gkub, еңде_, 
   {{0xda219351,0xf650025f,0x5c740075,0x9f4c011f}},	//   यासत_, יצה_, ллит, _aadô_, 
   {{0x2fc42946,0x6e381418,0x9f5c06af,0x6aa001e7}},	//   cang_, akub, hevé_, _bunf, 
   {{0x6aa13321,0x69c59352,0x7ae80354,0x9f4c0548}},	//   _cunf, _beie, _qqft, _cadô_, 
   {{0x200d9353,0x6aa0fa81,0x7d0401bf,0xaad023ef}},	//   _hadi_, _dunf, ækss, _थिरक, 
   {{0x69c59354,0x200d9355,0x9f5c0137,0xdb180118}},	//   _deie, _kadi_, devé_, _devá, 
   {{0x200d9356,0x6aa00cad,0xb8c80316,0xab5001d3}},	//   _jadi_, _funf, _औं_, ائیش, 
   {{0x69c59357,0x200d9358,0x6aa19359,0xf1bc0122}},	//   _feie, _madi_, _gunf, áška_, 
   {{0xb7e01aba,0x200c006c,0x2fc4c250,0x69c5935a}},	//   য়েট, _ladi_, zang_, _geie, 
   {{0x2fc5935b,0xe4a5935c,0xb87800d8,0xe5c52581}},	// [2a9d0] yang_, архо, ruíb, рссо, 
   {{0xda2010f7,0x200d935d,0x69c40221,0x6aa0022e}},	//   यावत_, _nadi_, _zeie, _yunf, 
   {{0x2fc5935e,0x6e39935f,0xd3700127,0xe3b0007b}},	//   vang_, ykub, حها_, ترق_, 
   {{0x2fc59360,0x200d9361,0xb1444fe0,0x7a3c036e}},	//   wang_, _aadi_, نیزم_, _mëto, 
   {{0x200d9362,0xb878215a,0xb5f802f0,0xc69000d9}},	//   _badi_, btít, _okáz, _לאט_, 
   {{0x200d9363,0xa2cd9364,0x2fc59365,0x6e380083}},	//   _cadi_, _हिच्, uang_, wkub, 
   {{0x2fc58573,0x200c1060,0xb8780137,0xc4440014}},	//   rang_, _dadi_, ltís, _حیلن_, 
   {{0xc3301229,0x6aa003f9,0x6e38216b,0x62342bcb}},	//   _פון_, _runf, ukub, _кесу, 
   {{0x2fc59366,0x69c59367,0x200c23db,0xdb180077}},	//   pang_, _reie, _fadi_, _revá, 
   {{0xb5f90412,0x200d9368,0x69c59369,0x7a3c0036}},	//   _sjál, _gadi_, _seie, _bëto, 
   {{0xb5f80241,0x7d0401bf,0x69b00a8a,0x00000000}},	//   _ajám, æksr, ंडली, --, 
   {{0xb7e003d4,0x200c1529,0x00000000,0x00000000}},	//   য়োট, _zadi_, --, --, 
   {{0x200c0a28,0x69c5936a,0xc955936b,0x61e401ab}},	//   _yadi_, _veie, утны, òili, 
   {{0x69c4e875,0x6aa003cd,0x200c058a,0xcb683db7}},	//   _weie, _tunf, _xadi_, _пале_, 
   {{0x1ce0025c,0x69c5936c,0xf7401422,0xb5f803b2}},	//   _སའོ_, _teie, беро, _tjál, 
   {{0x28dc19ec,0xdb18a3ba,0x3a28010a,0x5a940022}},	//   _बिपि, _bevæ, cjcp_, _крыф, 
   {{0x75d04caa,0x4585391a,0x44882826,0x7a3c0036}},	// [2a9e0] صيلا, угав, ебан_, _mëtl, 
   {{0x48040845,0x00000000,0x00000000,0x00000000}},	//   _спов, --, --, --, 
   {{0x200c1326,0x00000000,0x00000000,0x00000000}},	//   _radi_, --, --, --, 
   {{0x200d936d,0xe80c0316,0xb879936e,0x26cc02fb}},	//   _sadi_, िएका_, stít, ádou_, 
   {{0xdb1812ed,0x1ce00327,0x00000000,0x00000000}},	//   _gevæ, _སའེ_, --, --, 
   {{0x28dc012c,0x200c6f19,0x9f3402dd,0x3e780036}},	//   _बिनि, _qadi_, иелі, hëtt_, 
   {{0x434401f0,0x00000000,0x00000000,0x00000000}},	//   _севв, --, --, --, 
   {{0x200d936f,0xb5f80241,0x321c00e8,0x53740640}},	//   _wadi_, _ajáj, _gnuy_, _ђурђ, 
   {{0x200c4460,0x00000000,0x00000000,0x00000000}},	//   _tadi_, --, --, --, 
   {{0x6298012c,0x72400a81,0xf99c02e2,0x3acc033f}},	//   ůvod, _پھۅل, ndèv_, tęp_, 
   {{0x4508015b,0x6d4cdd69,0x7ac4346d,0x2ef400db}},	//   রমিক_, úcar, ыспе, _مىلد_, 
   {{0xd91401c0,0x3e7804e6,0xdb180139,0x5fb4000d}},	//   адмы, gëtt_, _levç, ुरवल, 
   {{0x7bcc1de4,0x88c400dc,0x00000000,0x00000000}},	//   óbus, _niśā, --, --, 
   {{0xb5f8031d,0xddc00118,0x9b940835,0x81c000eb}},	//   _ukáz, nomž, _килц, ্ভট_, 
   {{0xb8782b76,0x940404fb,0xdb18037e,0x88c400b8}},	//   guía, یوره, _sevæ, _aiśā, 
   {{0xb5f80022,0xb87806ea,0xf84401c6,0x00000000}},	//   _iják, kríg, түүд_, --, 
   {{0xb8642ed7,0xb5f808ce,0xddcc00b8,0x00000000}},	// [2a9f0] _مادو, _hják, _śiśy, --, 
   {{0x1cb81b4b,0xb8780cc3,0xb9ec044e,0x3dc405b1}},	//   _མཆན_, dríg, _ንሳ_, _leow_, 
   {{0x889808a8,0xb87800e4,0xb86401e2,0x00000000}},	//   _שבתי, stís, _ټاکو, --, 
   {{0x50b400c0,0xb8782be1,0x00000000,0x00000000}},	//   аску, fríg, --, --, 
   {{0xa2d400d1,0x0fc4009d,0x855801e1,0xa3b00037}},	//   ليەت, айлн, _títẹ, _ट्क_, 
   {{0x3dc40428,0xdb18049b,0xc4f4008f,0x672c02d2}},	//   _aeow_, _kevä, _דזשי_, _ímjö, 
   {{0x1ce0025c,0x28dc0864,0x53340334,0x998c02f0}},	//   _སའུ_, _बिभि, _тевт, žeň_, 
   {{0x1ea815eb,0x00000000,0x00000000,0x00000000}},	//   داوي_, --, --, --, 
   {{0x909800d1,0xdb18023a,0x7e9400f1,0x7d04005c}},	//   _ават_, _levä, جنير_, æksp, 
   {{0x28dd9370,0x00000000,0x00000000,0x00000000}},	//   _बिबि, --, --, --, 
   {{0xcb681f91,0xda200490,0xdb1800d7,0x00000000}},	//   тане_, यांत_, _nevä, --, 
   {{0xaa640032,0xb5f8032e,0xb8780332,0x00000000}},	//   семһ, _dják, hríd, --, 
   {{0x0ea800e1,0x3e7801c7,0xb8780419,0xfa640139}},	//   _चूतड, rëtt_, kríd, раяк_, 
   {{0xc7640075,0x5d8400c6,0xb8780005,0xdb180267}},	//   لازى, _الهل, tuía, _bevä, 
   {{0x4b7800c8,0x3dc405b1,0x23ac01e1,0xa8240014}},	//   _באַו, _yeow_, _lòjó_, لکھن, 
   {{0x7aec0232,0xdb180030,0x998800a2,0x88c400cd}},	//   žití, _devä, _unaş_, _piśā, 
   {{0x317c07ab,0xb8799371,0x290c005f,0x250800f2}},	// [2aa00] _nyuz_, suía, ādas_, درزی_, 
   {{0xb8799372,0x88c400dc,0x00000000,0x00000000}},	//   luín, _viśā, --, --, 
   {{0x28dc6407,0xb87804d4,0xdb1890c5,0x26dc0124}},	//   _बिडि, quía, _gevä, _ívo_, 
   {{0x317c0369,0x391001d9,0xb87810d8,0x24440267}},	//   _byuz_, _اویز, nuín, _döma_, 
   {{0x03a4e96f,0x3dc40295,0x00000000,0x00000000}},	//   _виго, _reow_, --, --, 
   {{0x66050412,0xc07415ed,0xade020f0,0x04441d0f}},	//   leik, шћењ, _गाउन_, _тегн, 
   {{0x7e440276,0x69d80270,0x9f5c026c,0x9f3401ec}},	//   ихие, _ēven, cevì_, сейі, 
   {{0x66059373,0xbe880063,0x00000000,0x00000000}},	//   neik, њске_, --, --, 
   {{0x673c02d3,0x66040270,0xf99d26bb,0x2e44011c}},	//   hyrj, ieik, ndèt_, рящо_, 
   {{0x66059374,0x00000000,0x00000000,0x00000000}},	//   heik, --, --, --, 
   {{0x66059375,0x3dc40ac5,0x7b640220,0xb8780789}},	//   keik, _teow_, ртпе, nríe, 
   {{0x66040c63,0xb8791388,0xdb1801f4,0x673d9376}},	//   jeik, guín, _revä, dyrj, 
   {{0xdb1829ef,0x9988009b,0xb95800e4,0x7c859377}},	//   _sevä, _boaš_, haìv, _куке, 
   {{0xdb1829ef,0xb5f800e4,0xd7c80a8e,0xac7001d5}},	//   _pevä, _ijái, طوره_, _واوش, 
   {{0xb8781709,0xdb180728,0xf7704e10,0x673c010e}},	//   buín, _bevå, زاس_, gyrj, 
   {{0xb8780137,0x6a6805d1,0x9f5c012c,0x00000000}},	//   dríe, nıfl, jeví_, --, 
   {{0xddc00064,0x39080064,0x00000000,0x00000000}},	// [2aa10] lomų, _рэйн_, --, --, 
   {{0x673d9378,0x7a3c022e,0x3cec858c,0x1fe0033f}},	//   byrj, _oëtk, _आमने_, नलोड, 
   {{0xe2c8004b,0xf99c1497,0x6a680790,0xf2e400f5}},	//   لولو_, rdèu_, kıfl, рюзо, 
   {{0x9e3c02f0,0x80d0000d,0x00000000,0x00000000}},	//   _buďm, _सिखइ, --, --, 
   {{0x80c801ad,0xb8789655,0xdebc0240,0x00000000}},	//   _सौदे, príd, _ደቅኻ_, --, 
   {{0xddc00153,0xb878032e,0x00000000,0x00000000}},	//   komų, bríe, --, --, 
   {{0xb87800ae,0x00000000,0x00000000,0x00000000}},	//   huío, --, --, --, 
   {{0xf99c7172,0xccc4036b,0xa1e80150,0xb88c0092}},	//   ndès_, ббий, _ەرەك_, መረጠው_, 
   {{0x317c03e0,0x00000000,0x00000000,0x00000000}},	//   _uyuz_, --, --, --, 
   {{0x66059379,0xb87800d7,0x00000000,0x00000000}},	//   zeik, hríb, --, --, 
   {{0xd0100069,0xb878eb5e,0x7a3c036e,0x3b800166}},	//   _iā_, tuín, _këth, злэг, 
   {{0xd01006c8,0xcf480790,0x00000000,0x00000000}},	//   _hā_, ışık_, --, --, 
   {{0x6605937a,0xb8780005,0x9e7000cf,0x5c700131}},	//   veik, ruín, _تۇيت, яһәт, 
   {{0x6604063f,0x673d937b,0xb878021c,0x00000000}},	//   weik, tyrj, suín, --, 
   {{0x660504ef,0xf7401cb5,0x4ec4009e,0x64900254}},	//   teik, перо, _এমুল, läig, 
   {{0xd0100069,0xb8780120,0x8b6400ec,0x00000000}},	//   _lā_, quín, _پاڻم, --, 
   {{0x6605937c,0x673c0108,0x00000000,0x00000000}},	// [2aa20] reik, syrj, --, --, 
   {{0xaca002e3,0x6605937d,0xd0100069,0xd04801e4}},	//   _adịk, seik, _nā_, _apeɾ, 
   {{0x66043d7c,0x6a6803ee,0x673c0240,0xb878004e}},	//   peik, yıfl, qyrj, uríe, 
   {{0xb879937e,0x649000af,0x2900005a,0xfebc00d1}},	//   críb, käig, _kpia_, _ﺭﯨﯟﺍ, 
   {{0xc059937f,0xd5ac01d9,0x69d800de,0xc17401e2}},	//   лік_, _شہل_, _ēvel, حدات, 
   {{0xa2e404a9,0x00000000,0x00000000,0x00000000}},	//   _қоғд, --, --, --, 
   {{0xd01003f9,0x271802e2,0xb5f801a8,0x1ce0031c}},	//   _dā_, _jčn_, _sjái, _སའང_, 
   {{0xbdf804a9,0xbe88023a,0x13cc0154,0x00000000}},	//   ارغا_, ысле_, _লায়, --, 
   {{0x64900221,0x71a000f3,0xd25404f2,0x80a415b4}},	//   räif, _хауз, _بینش_, _طمان, 
   {{0x941003be,0xbbe001ad,0x30240022,0x6a6803e0}},	//   _bizə_, पलेक, _лоуп_, sıfl, 
   {{0x7f8406d5,0x29019380,0xb5f800c7,0xb60000d0}},	//   _الان, _apia_, _ijáv, ššie, 
   {{0x7a3c069c,0x94f80156,0xfce40a8f,0xb5f80d12}},	//   _këti, _ཕྱའི_, _годо, _hjáv, 
   {{0x6da00811,0xb8780077,0x9f5d199a,0x7d94007b}},	//   _عموم, buíl, levà_, _الشؤ, 
   {{0x69c01125,0xeaac53e2,0x7a3c02b5,0x244401e6}},	//   ðmer, بعی_, _mëti, _sömn_, 
   {{0x2bf406a9,0xf6449f1e,0xe8e00208,0xb8780332}},	//   _המון_, бхан, _ược_, suío, 
   {{0x7bc80f99,0x8b640ccb,0xf65000cf,0x00000000}},	//   _hefu, _باهم, سئز_, --, 
   {{0x7bc92c85,0x659412d7,0xf99d9381,0xb8799382}},	// [2aa30] _kefu, зату, adèr_, quío, 
   {{0x9f5c00d2,0xb864208f,0x7bc80311,0x73480aa8}},	//   ndvó_, _دابو, _jefu, лчев_, 
   {{0x7bc883c6,0x16340801,0x38ac0790,0xb87800d7}},	//   _mefu, _деня, _hür_, príb, 
   {{0x7bc99383,0xb5f800e4,0x1138054a,0xb8788607}},	//   _lefu, _ajáv, иялы_, bríc, 
   {{0x38ac00a2,0xb87801e7,0x22580108,0xf48400f3}},	//   _jür_, huím, щицы_, _гувн, 
   {{0x7bc99384,0x38ac07c5,0x1cb80327,0x00000000}},	//   _nefu, _mür_, མཚན_, --, 
   {{0xb8c831d9,0x985c0210,0x00000000,0x00000000}},	//   _བཤ_, _głąb_, --, --, 
   {{0x765c0d04,0xefdc02d3,0x7e9400be,0x00000000}},	//   niqy, _ቐንዲ_, ينور_, --, 
   {{0x7bc99385,0x941003be,0xb8780005,0x229400d1}},	//   _befu, _sizə_, tuíl, _хитя, 
   {{0x13cc009e,0x00000000,0x00000000,0x00000000}},	//   _লাড়, --, --, --, 
   {{0x7bc99386,0x765c0cfe,0x29019387,0xb8780077}},	//   _defu, kiqy, _spia_, guím, 
   {{0x38ac01b8,0x7bc80241,0x60c40311,0xbf2001c8}},	//   _bür_, _eefu, ţime, _آڱوٺ, 
   {{0x7bc99388,0xfe4000d6,0x38ac03be,0x2718007f}},	//   _fefu, _іншо, _cür_, _sčn_, 
   {{0x7bc99389,0xb878021c,0xb5f803b2,0x00000000}},	//   _gefu, buím, _mjáu, --, 
   {{0x2bbc16ae,0x244401b8,0x6830013d,0x38ac002f}},	//   _श्या, _sömo_, _mädx, _eür_, 
   {{0x38ac2d65,0xb879938a,0x068402bf,0xb0cc1a04}},	//   _für_, tríc, іган, _सौभग, 
   {{0x75d00597,0x38ac9f97,0x7bc81418,0x430805d9}},	// [2aa40] بيقا, _gür_, _yefu, ڌيءَ_, 
   {{0xdb19938b,0x6aa4058a,0x6b8086cf,0xf8b00375}},	//   _revú, _hiif, _kyng, _קשת_, 
   {{0x41a818ec,0xaca001f2,0xf7c824ae,0x6490000d}},	//   авен_, _ndọk, _ﺑﯘﻧﺪ, väid, 
   {{0xb5f80008,0x6aa401d9,0x6b81938c,0xb87800e4}},	//   _sjáv, _jiif, _myng, príc, 
   {{0x6b80138f,0xaca001f2,0x1ccc025c,0x64903110}},	//   _lyng, _adọk, ླེབ_, täid, 
   {{0xdfd14ea7,0x6aa4000f,0x63e40150,0xb8780005}},	//   ريب_, _liif, _ءۋال, oría, 
   {{0x645d938d,0x6b80138f,0x7bc9938e,0xb8780005}},	//   _imri, _nyng, _refu, nría, 
   {{0x7bc9938f,0x3ea0049f,0xb8780077,0x6aa4009f}},	//   _sefu, ökt_, iría, _niif, 
   {{0x7bc99390,0x80641064,0x645c020b,0x64900108}},	//   _pefu, _дваж, _kmri, päid, 
   {{0xb8780077,0x6b802a3e,0x22a80139,0x649001c7}},	//   tuím, _byng, _eşke_, bäie, 
   {{0x6b800f7b,0x6aa4198f,0x7bc80008,0x7050006c}},	//   _cyng, _biif, _vefu, _تنلا, 
   {{0xb5f800bd,0xb878204e,0x7bc99391,0x6b819392}},	//   _imág, dría, _wefu, _dyng, 
   {{0x6aa59393,0x645d3630,0x7bc99394,0xb87804d4}},	//   _diif, _omri, _tefu, ería, 
   {{0x6b819395,0x81c000fe,0xb8799396,0x2bc401f0}},	//   _fyng, ূলি_, fría, _дуъо_, 
   {{0x6b8000a9,0x56940f12,0x6aa4045f,0xb87809c2}},	//   _gyng, завт, _fiif, gría, 
   {{0x645d9397,0x38ad9398,0x6aa59399,0xc7b80107}},	//   _amri, _tür_, _giif, иёӣ_, 
   {{0xb87809c2,0x00000000,0x00000000,0x00000000}},	// [2aa50] aría, --, --, --, 
   {{0x7d01939a,0xf8bd939b,0xb8782b76,0x6aa40472}},	//   _mpos, mpé_, bría, _ziif, 
   {{0xf8bc3d8b,0x6aa4009a,0xb5f808a5,0xbb440150}},	//   lpé_, _yiif, _sjáu, _ﻅﻠﻪ_, 
   {{0x645d149f,0x76440014,0x6aa400e8,0xb5f80aab}},	//   _emri, _بیرِ_, _xiif, _smáf, 
   {{0x0404015b,0xdee80023,0xe0d400d8,0x00000000}},	//   রাজী_, _ሙዃኑ_, дочњ, --, 
   {{0x1138052f,0xf8bc07ea,0x628000df,0xd008f87a}},	//   ияһы_, ipé_, _ekmo, секе_, 
   {{0x628003c1,0x00000000,0x00000000,0x00000000}},	//   _fkmo, --, --, --, 
   {{0x6b81939c,0x28dc02e5,0x7d0000c6,0x29049f97}},	//   _ryng, _बिलि, _bpos, çmak_, 
   {{0x6b80fed0,0x6aa4208d,0xb5f90c98,0xc210008f}},	//   _syng, _riif, _imád, _אהן_, 
   {{0x6b800649,0x2ca001e6,0x7d000036,0x7a3c0240}},	//   _pyng, öjd_, _dpos, _mëtu, 
   {{0x6aa40270,0x64900221,0x00000000,0x00000000}},	//   _piif, läic, --, --, 
   {{0x7d000327,0x00000000,0x00000000,0x00000000}},	//   _fpos, --, --, --, 
   {{0xc8b41e76,0x6b800af9,0xb3c80118,0x00000000}},	//   ясны, _wyng, िराख, --, 
   {{0x6b800652,0x6aa5939d,0x2d8c0724,0xb87809c2}},	//   _tyng, _wiif, _izge_, tría, 
   {{0xc7644da8,0x28ac17cb,0xb8f1939e,0x649000e4}},	//   ساسى, _टूरि, _हौ_, häic, 
   {{0x7a3c002e,0xb878ee9c,0x49c80116,0x00000000}},	//   _bëtu, rría, _улин_, --, 
   {{0xe51c07f7,0x44a54cfe,0x044400f0,0xc4e40150}},	// [2aa60] निधि_, سماق, пеан, яжай, 
   {{0xeff00023,0xe5a401d5,0x00000000,0x00000000}},	//   ጌሳዊ_, зиғи, --, --, 
   {{0xdc18033f,0x93582bbd,0x00000000,0x00000000}},	//   głęb, орцу_, --, --, 
   {{0x645c0196,0xb5f802d2,0xd258cea6,0x2d8c0205}},	//   _wmri, _djás, оці_, _ozge_, 
   {{0x33cc04a2,0xb5f80bcd,0x36640139,0xb87801e7}},	//   _ﺗﯘﺭﻣ, _smág, _хаяо_, irín, 
   {{0x645d939f,0xb5f800d2,0x2cbc0280,0xf8b0011a}},	//   _umri, _emád, dpud_, עשו_, 
   {{0xb5f95813,0x425444e4,0xb95800e4,0x9e3441b9}},	//   _ijár, _етат, haìp, дейч, 
   {{0xb5f803b2,0x7d0001a9,0xdcb8979a,0x9f540241}},	//   _hjár, _ppos, огич_, _àfín_, 
   {{0x7a3c04c4,0xdd90d50d,0x00000000,0x00000000}},	//   _mëtt, کوک_, --, --, 
   {{0x5fd00316,0xfbd001d9,0xfc4401ef,0x3f68014b}},	//   _सजिल, ڈتھ_, _šíbr_, _лизо_, 
   {{0xfbd00a81,0xd1e400db,0xacf0082a,0x7b6593a0}},	//   وتھ_, _ريەۋ, وسیت, ятие, 
   {{0x7d0006ea,0xb87802d2,0x00000000,0x00000000}},	//   _tpos, grín, --, --, 
   {{0x7d000558,0x2e340375,0x49a463eb,0xf8bd93a1}},	//   _upos, _מראש_, дырғ, upé_, 
   {{0xa8a4319b,0xf8bc0129,0xa9c400c7,0xb8780162}},	//   ерск, rpé_, _ҧсык, arín, 
   {{0xf6457187,0xabf80375,0xb8780077,0x7a3c00e8}},	//   пхан, _ההור, brín, _sëtu, 
   {{0x79a51a47,0xf8bd93a2,0x06a00131,0x00000000}},	//   _эрке, ppé_, _ﺋﺎﻧﯩ, --, 
   {{0x3ea593a3,0x9f5c023a,0xb5f801a8,0x00000000}},	// [2aa70] _miot_, levä_, _sjás, --, 
   {{0xb5f80bcd,0xb8780332,0xb9e00023,0xfbdc0154}},	//   _smád, mrío, _ጩራ_, ব্রত, 
   {{0x3d0c1889,0x9f5c005b,0x64900036,0xb8780139}},	//   _तैसे_, nevä_, wäic, ktíz, 
   {{0xb5f800c7,0x7a3d93a4,0xda0c1b87,0x00000000}},	//   _ejár, _gëtt, िजित_, --, 
   {{0xb5f800fc,0xe1f193a5,0xb878007b,0x3c380118}},	//   _fjár, اسم_, nrío, _kávě_, 
   {{0x649004c4,0xb5f80bcd,0x9f5c005b,0x3ea4005b}},	//   räic, _gjár, kevä_, _aiot_, 
   {{0xb87800ae,0xda0c0263,0x769000a2,0x00000000}},	//   hrío, िजात_, mçyb, --, 
   {{0xda1c19ec,0x3ea40356,0x64900036,0x040403d4}},	//   _बोलत_, _ciot_, päic, ৰাণী_, 
   {{0x3ea55e76,0xfd7802d3,0xd9c4015b,0xb87800d7}},	//   _diot_, _ኣቓልቦ_, ্লাম, vrín, 
   {{0x611401c6,0x0b440120,0x00000000,0x00000000}},	//   _ядуу, днон, --, --, 
   {{0x09e45c97,0x3ea40077,0x2cbc01ab,0xa3c002c3}},	//   монн, _fiot_, spud_, ीरत_, 
   {{0x2cbc06a3,0xb87800c6,0x19b8084c,0x3ea40741}},	//   ppud_, frío, зурь_, _giot_, 
   {{0x082405d9,0xc95407e6,0xb87801e7,0x290582fa}},	//   ورسٽ, фтны, grío, ïma_, 
   {{0x64900254,0x00000000,0x00000000,0x00000000}},	//   käia, --, --, --, 
   {{0x7a3c01c7,0x2cac00d4,0xb878311a,0x4638005b}},	//   _pëtt, _hugd_, prín, очая_, 
   {{0x2ca593a6,0xb8780597,0xb5f80077,0xdb1800c7}},	//   _hind_, brío, _amáb, _jevý, 
   {{0x2ca593a7,0xb878007b,0xcfe400fe,0x79b400e5}},	// [2aa80] _kind_, crío, প্যন, _تھپڑ_, 
   {{0x2ca40165,0x7a3c00e8,0x22a8c6da,0xdb18013a}},	//   _jind_, _wëtt, _aşka_, _levý, 
   {{0x2ca593a8,0x2cac003a,0xb5f802d2,0xd398013d}},	//   _mind_, _lugd_, _smáe, зәтә_, 
   {{0x2ca593a9,0xdb180122,0x00000000,0x00000000}},	//   _lind_, _nevý, --, --, 
   {{0xc058003b,0x00000000,0x00000000,0x00000000}},	//   жій_, --, --, --, 
   {{0x3ea593aa,0x46d00c2e,0xb5f803b2,0xdef4004e}},	//   _siot_, _तबाह, _hjáp, епкы, 
   {{0x26d80142,0xf7c80150,0x24b000cc,0x00000000}},	//   nsro_, _ﺑﯘﻳﺪ, _ছবিহ, --, 
   {{0x44283a4a,0x386001c8,0x2ca4000d,0x9d140f06}},	//   _hnb_, zijr_, _aind_, едич, 
   {{0x2ca41574,0x3ea405c7,0x442993ab,0xb8780419}},	//   _bind_, _viot_, _knb_, rtíz, 
   {{0x2ca4084c,0x44280076,0x9f5c023a,0x3e7801c7}},	//   _cind_, _jnb_, tevä_, nëtz_, 
   {{0x9e3c0232,0x2ca40bfa,0x1ce0025c,0x442800e5}},	//   _buďt, _dind_, _སའམ_, _mnb_, 
   {{0x2ca593ac,0xb87800c6,0xdebc001f,0x7a3c04e6}},	//   _eind_, trío, _ደህና_, _rëts, 
   {{0x2ca593ad,0xa3c00d41,0x9f5c0108,0x00000000}},	//   _find_, ीरा_, sevä_, --, 
   {{0x0ec40073,0x2ca40356,0x00000000,0x00000000}},	//   ळीकड, _gind_, --, --, 
   {{0xb879014e,0xda1c000d,0x00000000,0x00000000}},	//   srío, _बोअत_, --, --, 
   {{0xac8002d3,0xd1f802d3,0xb5f80ad9,0xb668001f}},	//   _ርእሶም_, ጋታት_, _smáb, _በወያኔ_, 
   {{0x442949c3,0x00000000,0x00000000,0x00000000}},	// [2aa90] _bnb_, --, --, --, 
   {{0xe8d80375,0x2ca401f5,0xb86402e9,0xd9d083c9}},	//   _חוזר_, _xind_, _زاخو, _جەڭگ, 
   {{0xdb1800e5,0x00000000,0x00000000,0x00000000}},	//   _nevü, --, --, --, 
   {{0x442993ae,0xb87800c7,0x99bc00cc,0x00000000}},	//   _enb_, guív, _অযুক, --, 
   {{0x71254d5a,0x442993af,0x7c28349c,0x649193b0}},	//   برال, _fnb_, _onfr, mäin, 
   {{0x442993b1,0xdb1829ef,0x649002f6,0xb8780162}},	//   _gnb_, _bevü, läin, krím, 
   {{0x2ca593b2,0x2cac003b,0x00000000,0x00000000}},	//   _rind_, _sugd_, --, --, 
   {{0x2ca491e1,0x7c280730,0x6490023a,0x6a6805d1}},	//   _sind_, _anfr, näin, nıft, 
   {{0x2ca47578,0x244404cc,0xb87800d8,0x00000000}},	//   _pind_, _sömi_, tríl, --, 
   {{0x2ca4044e,0x2a6193b3,0x649176bd,0x2cac00de}},	//   _qind_, _smib_, häin, _vugd_, 
   {{0x2ca593b4,0xb878066a,0x2fc4020c,0x64900e03}},	//   _vind_, grím, mbng_, käin, 
   {{0x7c2993b5,0x2bbc2c82,0x2ca4ee0c,0x9e24215c}},	//   _enfr, _श्रा, _wind_, _لىمو, 
   {{0x6e2993b6,0x2ca593b7,0xdebc02d3,0x7a3c0221}},	//   _ingb, _tind_, _ደቅና_, _pëtr, 
   {{0x764c003a,0xea2401c6,0xb87800ae,0x26d8007c}},	//   _alcy, хчүү, brím, tsro_, 
   {{0xdb180077,0x649001b8,0x290c00ee,0x44281a9f}},	//   _devó, fäin, ňda_, _rnb_, 
   {{0x49c8405c,0x442993b8,0x26d81654,0xd90c1176}},	//   _элин_, _snb_, rsro_, حیی_, 
   {{0x7c28000f,0x3e780036,0x04481171,0x701800cc}},	// [2aaa0] _ynfr, tëtz_, ппак_, _তকৈও_, 
   {{0x78f8025f,0x395406a9,0x764c7c52,0x27b41945}},	//   _צפיו, _נשים_, _elcy, _шәмс, 
   {{0x6e2993b9,0xb8780798,0x3e7801c7,0x442993ba}},	//   _ongb, tuív, rëtz_, _vnb_, 
   {{0x3e7804e6,0x3ab8010f,0xd36c15bf,0xb6b8011a}},	//   sëtz_, למענ, زۇق_, _מצטי, 
   {{0x442993bb,0xc76400d1,0x60180395,0xdec80023}},	//   _tnb_, _زاھى, доля_, በማኤ_, 
   {{0x6e2993bc,0x44280798,0xb8780077,0x2bbc00dc}},	//   _angb, _unb_, buíu, _श्ला, 
   {{0xbea401c0,0x9f3402dd,0x6254012d,0x6a6803e0}},	//   нший, тейі, eżoś, nıfs, 
   {{0xb8785133,0xa3f04ca3,0x00000000,0x00000000}},	//   quív, _चाँप_, --, --, 
   {{0x8db40131,0x28d00d0d,0x5c74329b,0x00000000}},	//   خشىچ, _तौलि, клит, --, 
   {{0x6e280728,0xb8780419,0x00000000,0x00000000}},	//   _engb, trím, --, --, 
   {{0x2fd41001,0xdb181dec,0x6a6803e0,0x00000000}},	//   _سوند_, _revó, yıft, --, 
   {{0xdc3c1505,0xdb180124,0x00000000,0x00000000}},	//   _išču, _sevó, --, --, 
   {{0x7e60054e,0x6490005b,0xfe04033f,0xb95800e4}},	//   _imop, väin, _वॉयस_, mbìk, 
   {{0x7c2993bd,0x201c061c,0xdb18067c,0xb8780005}},	//   _unfr, ndvi_, _devò, prím, 
   {{0xf8bc004e,0x61e00306,0xf99c0100,0x64903f50}},	//   txés_, _odml, ndèz_, täin, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7e60b0dd,0xb8781f60,0x64915708,0xf8bc004e}},	// [2aab0] _mmop, nrík, räin, rxés_, 
   {{0xd130c0e3,0x61e000a2,0xb8780005,0x649193be}},	//   یما_, _adml, tuíu, säin, 
   {{0x7e60035b,0x63bc00df,0xd3703a16,0x64900f23}},	//   _omop, _dfrn, جها_, päin, 
   {{0x249801f5,0xb87800d0,0x64900108,0x602800de}},	//   _ehrm_, krík, läil, _līmē, 
   {{0x61e00175,0x00000000,0x00000000,0x00000000}},	//   _ddml, --, --, --, 
   {{0x7e60bfc7,0x63bc022e,0x649001f4,0xb87802d2}},	//   _amop, _gfrn, näil, drík, 
   {{0xbf1000db,0xfeb00022,0x1ea800f1,0x647401f4}},	//   لووب, аҩхь, ډايي_, _сгру, 
   {{0x9f4c004e,0xb87993bf,0x2444032e,0x22843a49}},	//   _abdó_, frík, _dömu_, _бууг, 
   {{0xf00005f5,0x320c01d3,0xb878021c,0x6490005b}},	//   _бүли, megy_, nuís, käil, 
   {{0x7e609f4e,0xdb1926bb,0x320c9119,0xb8780332}},	//   _emop, _revò, legy_, lsíf, 
   {{0xb8780030,0x00000000,0x00000000,0x00000000}},	//   príj, --, --, --, 
   {{0xb87800d0,0x6e286492,0x320c00e5,0x00000000}},	//   brík, _ungb, negy_, --, 
   {{0xb87806ea,0x597400db,0x00000000,0x00000000}},	//   juís, гыру, --, --, 
   {{0x64900036,0xfd540375,0xfce039af,0x274801e1}},	//   gäil, _בשני_, _тошо, _nìnú_, 
   {{0x177800c9,0xb5f809f3,0xe6b401d5,0x8cd40210}},	//   есть_, _smáa, الرگ, _मौतो, 
   {{0xa898005f,0x6028005f,0x29040240,0x320c01d3}},	//   _šķēr, _zīmē, çmas_, jegy_, 
   {{0xdb181125,0xb878172e,0x28dc0dad,0xc484f14d}},	// [2aac0] _hevð, tuít, _बिटि, влак, 
   {{0xa4941927,0x00000000,0x00000000,0x00000000}},	//   ایست, --, --, --, 
   {{0x3e7800e2,0xb8780332,0x76900432,0x00000000}},	//   līte_, ruít, mçyn, --, 
   {{0xb87993c0,0x7690010e,0x00000000,0x00000000}},	//   suít, lçyn, --, --, 
   {{0x2444008c,0x3e7848e1,0x6490005b,0x60dc0171}},	//   _sömu_, nīte_, läim, _ārms, 
   {{0x1aac04c5,0xb87810d8,0x1b080154,0x9d180588}},	//   কীয়া, luír, ষিতে_, ҵоит_, 
   {{0xe8e00016,0xe804878d,0x244401e3,0xdcec00d7}},	//   _ước_, श्या_, _dömt_, úhľu, 
   {{0xdd9593c1,0xb87993c2,0x32400209,0xf7700375}},	//   лайы, trík, _кесг, יקו_, 
   {{0x527593c3,0x7690010e,0x00000000,0x00000000}},	//   _суру, kçyn, --, --, 
   {{0x28dc0490,0xb8782200,0x4438037e,0x24440267}},	//   _बिजि, rrík, njp_, _gömt_, 
   {{0x6b4801b8,0xdc3c01a6,0xb8780321,0x77340092}},	//   vögö, _ušču, srík, _ባካሄደ, 
   {{0xb87801a2,0x6cd001b9,0xfd480166,0xf8bc01d3}},	//   prík, _چقنا, _озек_, yvéd_, 
   {{0xb8785799,0x64900108,0x00000000,0x00000000}},	//   nsíg, täil, --, --, 
   {{0xf7706ea9,0x1bd4010b,0xb8e80037,0x7690010e}},	//   لاز_, _сокя, _ऊऽ_, gçyn, 
   {{0x67d593c4,0x6490023a,0x5ed000cc,0x6b4800e5}},	//   росу, räil, সংকে, rögö, 
   {{0x649002f6,0xda700050,0xb8781a96,0x3e780171}},	//   säil, _دُب_, tuís, bīte_, 
   {{0x1cb00003,0xa3c000dc,0x6490005b,0x3e7800de}},	// [2aad0] _ཟངས_, ीरं_, päil, cīte_, 
   {{0xd1740032,0x53340d1d,0xb4e06c5a,0x00000000}},	//   һылы, лезт, _नटी_, --, 
   {{0x80d003d4,0xb87810d8,0x00000000,0x00000000}},	//   _সমষ্, buír, --, --, 
   {{0xd174a7d2,0x163435c7,0x274801e1,0x28d005c0}},	//   лылы, _семя, _wìnú_, तीवि, 
   {{0x91047e97,0x61f802f0,0xda0400dc,0xd0080798}},	//   упле, _žalá, ष्यत_, ееле_, 
   {{0x244401e6,0x44380175,0x4e9400f2,0x28dc000d}},	//   _döms_, cjp_, گشتر, _बिघि, 
   {{0x649000c5,0x8fd000d1,0x3e7800e2,0x00000000}},	//   käij, _һәйә, zīte_, --, 
   {{0x80d000bd,0x00000000,0x00000000,0x00000000}},	//   _সমর্, --, --, --, 
   {{0x2444007c,0x0d200166,0x00000000,0x00000000}},	//   _göms_, сүлү, --, --, 
   {{0x0b58005b,0x00000000,0x00000000,0x00000000}},	//   ермы_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x33680023,0xb5f802d2,0x8a140014,0xf77c0327}},	//   _ተኸስተ_, _smán, چِھت, ħħli_, 
   {{0x8274008f,0x443804ce,0xb87803b2,0x00000000}},	//   רערע_, yjp_, ksíd, --, 
   {{0x3e781c52,0x00000000,0x00000000,0x00000000}},	//   rīte_, --, --, --, 
   {{0xb8780d2a,0x69bc02ab,0x869813d6,0x670400f7}},	//   tuír, _एलपी, етат_, шүнб, 
   {{0x6e382252,0x96540063,0x649001f4,0xe8000037}},	//   njub, ађуј, räim, _लउका_, 
   {{0x6d5993c5,0x76900209,0x15b92c0d,0xb8780587}},	// [2aae0] nzua, mçyl, тысы_, ruír, 
   {{0xf8bc20ef,0x61cc0c00,0xb8780077,0xdc800092}},	//   uvée_, ार्ष, suír, _ከባሕር_, 
   {{0x6e3993c6,0xf8bc07ea,0x44380109,0x64900641}},	//   kjub, rvée_, rjp_, läik, 
   {{0x769009a5,0xb878056a,0x4438037e,0x6e3993c7}},	//   nçyl, quír, sjp_, jjub, 
   {{0x660593c8,0xb878315a,0x6e3801fa,0x1fd8015b}},	//   mfik, bsíd, djub, _সাবস, 
   {{0x6d582a1f,0xb978010f,0xc0580276,0xb87803b2}},	//   dzua, ענסי, эрец_, rsíg, 
   {{0x09d80eac,0x660401c8,0x5f9593c9,0x491407f7}},	//   _থানা, ofik, шикт, _पैसो_, 
   {{0x66040640,0xe80449fc,0xd36c01ec,0x51f40150}},	//   nfik, श्ता_, _تۇم_, _ەسەر, 
   {{0xa0a801af,0xa3e800cd,0x72400241,0x769000a2}},	//   _абаҡ_, _यया_, _áljẹ, dçyl, 
   {{0x6e380083,0xb140084c,0x80c80154,0x2f50104e}},	//   ajub, _унул, _রিপ্, ртәс, 
   {{0x9b94b3e4,0xeee4179e,0xda340166,0xf7c802dd}},	//   ринц, _مغنی, аены, _ﺑﯘﻟﺪ, 
   {{0x57cc00cd,0x769000ee,0x00000000,0x00000000}},	//   ऽर्ह, gçyl, --, --, 
   {{0x2ec000db,0x3cec06e3,0x00000000,0x00000000}},	//   _көөм, _आमटे_, --, --, 
   {{0x7c6593ca,0x97c407d6,0x660401e4,0xac140117}},	//   _حاصل, شقرو, efik, _бошу_, 
   {{0x7bd993cb,0x660593cc,0x4da802f5,0xd5a000b5}},	//   matu, ffik, ছুদূ, _cmのf_, 
   {{0xdb183262,0x6604009a,0x64900036,0x00000000}},	//   _bevö, gfik, bäik, --, 
   {{0x7bd80607,0xb87803b2,0x2c1403d4,0xe6940417}},	// [2aaf0] oatu, drív, তাৰে_, ситы, 
   {{0x660400af,0x7bd993cd,0x280400bc,0x47d40451}},	//   afik, natu, ěrný_, _پيٽر, 
   {{0xd5b06bdb,0x569593ce,0x7bd993cf,0xb8781ca9}},	//   _وفد_, _вант, iatu, frív, 
   {{0x7bd993d0,0x6604010f,0xb87800d8,0xe2c801e2}},	//   hatu, cfik, ssíd, اونو_, 
   {{0xdb180793,0x09d80154,0x00000000,0x00000000}},	//   _gevö, _থামা, --, --, 
   {{0xd00993d1,0xd1740184,0x6d5805d1,0x10a55b1f}},	//   теке_, лыһы, vzua, шилн, 
   {{0x7bd993d2,0xe45411db,0xd37001d9,0x6e380114}},	//   datu, _укры, _بێاک, tjub, 
   {{0xb87993d3,0x6d5805f5,0x7bd993d4,0xb5f802f0}},	//   crív, tzua, eatu, _omám, 
   {{0x6e3993d5,0x69bc01ad,0xcc34013d,0xa1941f39}},	//   rjub, _एलबी, ахны, _гатч, 
   {{0x6e38a80a,0xb5f993d6,0x769000ee,0x6d58036e}},	//   sjub, _smál, wçyl, rzua, 
   {{0x76900209,0x66040034,0x4e2800d1,0x6d58002f}},	//   tçyl, yfik, _җоһн_, szua, 
   {{0x3cec0490,0x7bd80951,0x00000000,0x00000000}},	//   _आमचे_, aatu, --, --, 
   {{0xd91993d7,0x76900432,0xddc00311,0x1fd800fe}},	//   льё_, rçyl, simţ, _সাতস, 
   {{0x7bd993d8,0x00000000,0x00000000,0x00000000}},	//   catu, --, --, --, 
   {{0x07a43aeb,0x45d4db74,0xdb1801b8,0x660593d9}},	//   равн, ицат, _sevö, tfik, 
   {{0xdb1801b8,0x6604009f,0x9988010e,0xc4c4007b}},	//   _pevö, ufik, _obaň_, لتطو, 
   {{0x660593da,0x44640006,0x05a88675,0xaa880014}},	// [2ab00] rfik, авав, твай_, _لۆگم_, 
   {{0x69bc07f7,0x22a80139,0xb8780162,0x00000000}},	//   _एलडी, _işki_, fríu, --, 
   {{0x321c0004,0x2d8c05ac,0x660593db,0x947993dc}},	//   _bauy_, _lyge_, pfik, усту_, 
   {{0x7bd993dd,0x73302dfc,0x321c003e,0xc0f002d3}},	//   zatu, تىما, _cauy_, _ፍሹል_, 
   {{0xb87806ed,0x9988029f,0xc17400d1,0x00000000}},	//   rrív, _maaş_, جدات, --, 
   {{0x7bd993de,0x3e780f40,0x2098ea10,0xfcf400b7}},	//   xatu, dīta_, ыклы_, _ገለጻ_, 
   {{0x7bd993df,0xfcf41ee0,0xb878067c,0x00000000}},	//   vatu, _ገለጸ_, críu, --, 
   {{0x7bd824be,0xf53d93e0,0x2718007f,0x2d8c005c}},	//   watu, _igår_, _mōn_, _byge_, 
   {{0x7bd993e1,0x80a801c6,0x00000000,0x00000000}},	//   tatu, _авав_, --, --, 
   {{0x39480204,0x04040183,0x7bd80381,0x9c380120}},	//   vycs_, ৰাকী_, uatu, упот_, 
   {{0x2718003a,0x649001c7,0xb81c00cc,0x22a815b7}},	//   _nōn_, räih, দামত_, _aşki_, 
   {{0xfcf400b7,0x7a3c0221,0xeaf40133,0x649000e4}},	//   _ገለጹ_, _hëtz, گریت_, säih, 
   {{0x649001f4,0x3e7800de,0x00000000,0x00000000}},	//   päih, cīta_, --, --, 
   {{0xfd1005d9,0x7a3c0036,0x7bd993e2,0xed4c30cd}},	//   _هجڻ_, _jëtz, qatu, _تپه_, 
   {{0x368801c6,0xd7940395,0x27480108,0xdb0c0108}},	//   всан_, сивъ, ачто_, ähäs, 
   {{0x7a3c04d1,0xe65400d6,0xb5f800e4,0xb86400f1}},	//   _lëtz, овсь, _imák, _چادو, 
   {{0xb8654652,0xb87993e3,0x76900432,0x00000000}},	// [2ab10] _نادو, rsíb, lçyk, --, 
   {{0x57f44712,0x7a3c04e6,0xb8640244,0x00000000}},	//   _упот, _nëtz, _خابو, --, 
   {{0x3e7800e2,0x27f40419,0x00000000,0x00000000}},	//   zīta_, ňaní_, --, --, 
   {{0x5558011c,0x00000000,0x00000000,0x00000000}},	//   _бамя_, --, --, --, 
   {{0xd1091386,0x271802e2,0xe4e40024,0xb8780332}},	//   اقته_, _zōn_, _мірн, brít, 
   {{0xb878215a,0x2d8c037e,0x2098916f,0xd01000c6}},	//   crít, _ryge_, акчы_, سلع_, 
   {{0xf1d0052f,0x2d8c037e,0x00000000,0x00000000}},	//   _һөҙө, _syge_, --, --, 
   {{0x3e780f40,0x06a00131,0xdb1401e1,0x2778011a}},	//   tīta_, _ﺋﺎﻟﯩ, _àbùb, יגון_, 
   {{0x4bd993e4,0xf0340451,0x00000000,0x00000000}},	//   льня_, _پٺاڻ_, --, --, 
   {{0x7a3c0036,0x3e781c52,0xab6000d1,0x00000000}},	//   _gëtz, rīta_, يۇشى, --, 
   {{0xaca001f2,0xeaa00055,0xb87801e7,0x229c0022}},	//   _nfụk, _neṣi_, hrís, síke_, 
   {{0x7a3c044e,0x7bcc0008,0x2d8d93e5,0xdb180109}},	//   _këty, ðbur, _tyge_, _revô, 
   {{0x7e7c01ed,0xdee40023,0xdd1400d7,0x00000000}},	//   éppe, _ዞባና_, púšt, --, 
   {{0x2bc8009b,0x00000000,0x00000000,0x00000000}},	//   _рудо_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xda64009a,0xb87802d2,0x00000000,0x00000000}},	//   _وايي, frís, --, --, 
   {{0x69c593e6,0xb87993e7,0x43080451,0x35a0024c}},	// [2ab20] _ifie, trít, ڏيءَ_, затг, 
   {{0xb878dd69,0x68e593e8,0x00000000,0x00000000}},	//   rsíc, _ivid, --, --, 
   {{0x68e4019b,0xf8bc056a,0x64900037,0x00000000}},	//   _hvid, nvén_, käiv, --, 
   {{0xe8040c2e,0x7a3c0a40,0x69c4031c,0x527406ed}},	//   श्रा_, _sëtz, _jfie, оучу, 
   {{0x7a3c0036,0xb8781315,0xd57401c0,0x14200240}},	//   _pëtz, prít, _дурь, _ደጊምኩ, 
   {{0xfc20015b,0x68e40208,0x03a4020f,0x34900024}},	//   _পক্ষ_, _mvid, _гиго, _наўр, 
   {{0x2bd80034,0x69c472c4,0x673c0175,0x00000000}},	//   _मज़ा, _ofie, nxrj, --, 
   {{0x68e414dc,0x69c40327,0x5d5400a7,0x7a3c0200}},	//   _ovid, _nfie, жкит, _fëty, 
   {{0xb5f80321,0xf2a112e2,0x41cc00cd,0x2e440395}},	//   _smák, _хитп, _ह्यस, сящо_, 
   {{0x40940597,0x69c4996f,0xafe0084c,0x6fcc0401}},	//   _الطر, _afie, _ноул, _स्पं, 
   {{0x68e593e9,0x91e400b5,0xfba8023a,0x7b640a5b}},	//   _avid, _mmのb, ытий_, стпе, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x68e593ea,0x00000000,0x00000000,0x00000000}},	//   _cvid, --, --, --, 
   {{0x68e593eb,0x69c49d54,0x7d000b6f,0xd7c87af1}},	//   _dvid, _efie, _iqos, شوره_, 
   {{0x7ac4026a,0x69c40042,0x00000000,0x00000000}},	//   _усле, _ffie, --, --, 
   {{0xaa64004e,0x87cc0150,0x00000000,0x00000000}},	//   _нтык, _ﺑﯘﭘﻠ, --, --, 
   {{0x68e593ec,0x1680001f,0xbdf80154,0x557400c7}},	// [2ab30] _gvid, _የእርሻ_, _আসাদ_, цгат, 
   {{0xe2c800f1,0x00000000,0x00000000,0x00000000}},	//   څولو_, --, --, --, 
   {{0x80d0000e,0xb86593ed,0x68e405b8,0xb8780005}},	//   _সমগ্, _ناگو, _zvid, brír, 
   {{0x200cebf1,0x998804b9,0xb878022c,0x7d0001f0}},	//   _abdi_, _znaš_, prís, _oqos, 
   {{0x68e593ee,0x04040c58,0x69bc3885,0x00000000}},	//   _xvid, ৰাজী_, _एलसी, --, 
   {{0xf8bc011f,0xb5f808a5,0x00000000,0x00000000}},	//   iqé_, _smáh, --, --, 
   {{0x7d000117,0xaad405f9,0xb8780789,0xb5f9014e}},	//   _aqos, _भौंक, nríq, _amái, 
   {{0x6b4c01e1,0xccc401d5,0x225801f4,0x00000000}},	//   _lògú, обий, _лисы_, --, 
   {{0x69c400e4,0xcdc402dd,0x6b4c01e1,0x649000e4}},	//   _rfie, баққ, _oògú, räiv, 
   {{0x69c593ef,0x4c691228,0x6f00003b,0x229c02f0}},	//   _sfie, рион_, ptnc, míka_, 
   {{0x64900664,0x7d0001f0,0x229d93f0,0x3b8001c0}},	//   päiv, _eqos, líka_, длэг, 
   {{0xc9a8bbc9,0xf8bc67ac,0xaca00cad,0x69c4031c}},	//   ивне_, rvén_, _itọj, _qfie, 
   {{0xad2593f1,0x229c0122,0x25f80f44,0x14b40073}},	//   _دراو, níka_, एलसी_, _अंगण, 
   {{0x649000af,0x6ca402e8,0x17c40022,0x00000000}},	//   näit, _уреж, зарҭ, --, 
   {{0x6b4c0241,0xdb18037e,0x69c40327,0x3b040212}},	//   _dògú, _afvæ, _tfie, _дещо_, 
   {{0x15cc1c5c,0x69c40093,0xb5f800e4,0x68e593f2}},	//   _ﺑﯩﺮﻩ, _ufie, _ymái, _tvid, 
   {{0x68e593f3,0x17d80c58,0x649025c6,0x769000a2}},	// [2ab40] _uvid, _তাৰি, käit, hçyw, 
   {{0xb87801a8,0x229c13d5,0xc3940114,0x00000000}},	//   lsín, díka_, ојењ, --, 
   {{0x1fd81c82,0xd3c40075,0x4224173e,0x07a41086}},	//   _সালস, ستلى, ждев, _фанн, 
   {{0xb87993f4,0x229c02f0,0x00000000,0x00000000}},	//   nsín, fíka_, --, --, 
   {{0x00849bb1,0xb878007b,0x18940092,0xfbd800eb}},	//   олдо, isín, _መቅጠር_, _দাসত, 
   {{0xd1c81e87,0x3e781c52,0x3998008f,0x3ec40a93}},	//   لبۇم_, tīto_, בינד, осиб, 
   {{0xb5f80d12,0x2ec0132f,0x91d800cc,0xb8780166}},	//   _smái, وقوف, _ডাৰ্, ksín, 
   {{0x00c800a7,0x229c02f0,0xdc1c01e1,0x00000000}},	//   _влак_, bíka_, _ẹ̀gh, --, 
   {{0xf8bc01a8,0xb8780118,0x50b400f3,0x00000000}},	//   gvél_, dsín, _есху, --, 
   {{0x7c640131,0x6490023a,0xf04451ae,0xbf34027d}},	//   تابل, mäis, _وعلی, _وراغ, 
   {{0x6490049b,0xdd905d95,0xeb940120,0x7de40150}},	//   läis, بوک_, жиќ_, _ділд, 
   {{0xfe7065fe,0x8cd4012d,0x06ac02dd,0xe7b00116}},	//   _غدا_, _मौको, _ﺳﺎﻻﺩ, _ﻳﯜﺯﻟ, 
   {{0x7d000b6f,0x649002f6,0xfd7593f5,0x00000000}},	//   _uqos, näis, _بداخ, --, 
   {{0xb18400a2,0x00000000,0x00000000,0x00000000}},	//   _ýüňd, --, --, --, 
   {{0x64905951,0x70d41f13,0xf6445751,0xf6503868}},	//   häis, _डब्ल, охан, وئر_, 
   {{0x649193f6,0x9f580022,0x00000000,0x00000000}},	//   käis, _úrõ_, --, --, 
   {{0x659593f7,0x6490005b,0x784401c6,0x6b4c01e1}},	// [2ab50] дату, jäis, _дэнж, _tògú, 
   {{0xf8bc0798,0xb878007b,0xe94401ed,0x649001c7}},	//   nvém_, msío, _آرٹی, däis, 
   {{0x521593f8,0xb87800c6,0x64903110,0x00000000}},	//   здет, lsío, väit, --, 
   {{0x229d93f9,0xb87806ed,0xb5f80798,0xe3b000db}},	//   tíka_, juíz, _amáv, ئرك_, 
   {{0x649193fa,0x3f9d93fb,0xb8780332,0x62240116}},	//   täit, _aztu_, nsío, بىنل, 
   {{0x229c0296,0x98a801a6,0xb878007b,0x00000000}},	//   ríka_, _orač_, isío, --, 
   {{0x229d93fc,0x29047a36,0x1358007b,0x649193fd}},	//   síka_, çmaz_, _الأخ_, räit, 
   {{0xa77c0375,0xb8780077,0x64904562,0x229c02f0}},	//   ירופ, guíz, bäis, píka_, 
   {{0x61e409f3,0xa15855ee,0x3f9c01c4,0x6490005b}},	//   ðile, _дату_, _eztu_, päit, 
   {{0x98a8107d,0x00000000,0x00000000,0x00000000}},	//   _brač_, --, --, --, 
   {{0x260c0c66,0x00000000,0x00000000,0x00000000}},	//   ड्डी_, --, --, --, 
   {{0x98a80063,0x6fcc43d1,0x6fd00154,0x627c0010}},	//   _drač_, _स्तं, _সায়ে, jčol, 
   {{0x9e700150,0x2cbc0165,0x290400e4,0x00000000}},	//   _جۇيت, qqud_, îma_, --, 
   {{0x649033eb,0x85780032,0xccf8033f,0xb87800d8}},	//   häir, ҡсат_, muś_, ssín, 
   {{0x660401e0,0x00000000,0x00000000,0x00000000}},	//   мовҡ, --, --, --, 
   {{0x260c033f,0xdd3800b8,0xb87800e4,0x00000000}},	//   ड्ढी_, _nāśv, lsíl, --, 
   {{0x056593fe,0xb87800d0,0x229c032e,0x00000000}},	// [2ab60] чван, príp, fíkn_, --, 
   {{0xb87993ff,0x649002f6,0x07a406ed,0x00000000}},	//   nsíl, väis, _напн, --, 
   {{0x649004e6,0x00000000,0x00000000,0x00000000}},	//   wäis, --, --, --, 
   {{0x64900664,0xb8781709,0xb5f86b5b,0xdd38002b}},	//   täis, xuíz, _aláf, _cāśv, 
   {{0x1fb8040e,0xdd380055,0xb5f80aab,0xf1c8012d}},	//   оллы_, _dāśv, _bláf, ाड़न, 
   {{0x649193f6,0xc0a88fcb,0x5f940353,0x61e403b2}},	//   räis, حاصل_, милт, ðilb, 
   {{0x6aa40418,0x64919400,0x3e6801c0,0xe28401d3}},	//   _ohif, säis, йшин_, _قطری, 
   {{0x64919401,0x645c01ab,0x1d3400a7,0x91f4008e}},	//   päis, _hlri, дния, _очуч, 
   {{0x645c0085,0xb5f800c7,0x62819402,0x7f84105f}},	//   _klri, _imát, _ijmo, _کلان, 
   {{0x6aa40083,0xfb84d8d1,0xb8780162,0x16380092}},	//   _ahif, зымн, gsíl, _አፈታሪ, 
   {{0xcf8c04fb,0xa2d00490,0x229c00e4,0xcc8402f2}},	//   _پژو_, डीच्, níko_, بۆوه_, 
   {{0x6aa50226,0x3374011a,0xccf80210,0xb87801e7}},	//   _chif, לעים_, buś_, tsío, 
   {{0x3ebc0a40,0x6aa59403,0xce8800cf,0x645c2c13}},	//   _hutt_, _dhif, _بئلم_, _olri, 
   {{0x3ebd9404,0x65640564,0x98a82a53,0x9b58010b}},	//   _kutt_, dzih, _trač_, _милт_, 
   {{0x3ebc00af,0x6aa401ab,0xec20005e,0xab9000d4}},	//   _jutt_, _fhif, _سىيپ, _пиші, 
   {{0x7af99405,0x6aa44c8f,0x3ebd9406,0xeb940375}},	//   mutt, _ghif, _mutt_, _מדור_, 
   {{0x7af82a76,0x645c0076,0x3ebc03b2,0x00000000}},	// [2ab70] lutt, _blri, _lutt_, --, 
   {{0x645c0175,0x765c0240,0xb5f801e1,0x7af803ac}},	//   _clri, shqy, _olág, outt, 
   {{0x7af99407,0x3ebc000d,0xb5f80bcd,0xb87800ae}},	//   nutt, _nutt_, _smáu, nsím, 
   {{0x645d9408,0x62899409,0x75d00451,0x78bc0200}},	//   _elri, _ídol, _ڪيڏا, _kuqv, 
   {{0xa6c8021a,0xb5f80cad,0x7af9940a,0x62800221}},	//   _وویل_, _alág, hutt, _djmo, 
   {{0xe0d1940b,0x7af9940c,0xb5f9940d,0x3ebc1382}},	//   ازن_, kutt, _emát, _butt_, 
   {{0x7af9940e,0x3ebc0076,0x78b401e3,0xa858011a}},	//   jutt, _cutt_, _mixv, היגה_, 
   {{0x7af9940f,0xc0f01540,0xa29400d6,0x3ebd12d0}},	//   dutt, _ፍጹም_, _засі, _dutt_, 
   {{0x3e68034c,0x6aa40368,0x78bc014f,0xc2100375}},	//   تجوی_, _rhif, _nuqv, _בהן_, 
   {{0x7af99410,0x6aa59411,0x3ebcfcf4,0x0ae99412}},	//   futt, _shif, _futt_, одой_, 
   {{0x3ebd9413,0x7af99414,0xb5f80306,0x00000000}},	//   _gutt_, gutt, _klád, --, 
   {{0x6aa40009,0x00000000,0x00000000,0x00000000}},	//   _qhif, --, --, --, 
   {{0x6aa41682,0xb5f804bf,0x9f9802d2,0x7af801f4}},	//   _vhif, _mlád, _háði_, autt, 
   {{0x7af99415,0x6ca40372,0x6aa4045a,0x07a4009d}},	//   butt, _эреж, _whif, дагн, 
   {{0x6aa4020b,0xb8780077,0x7af99416,0x3ebc0135}},	//   _thif, csím, cutt, _xutt_, 
   {{0x6aa400ec,0x96940220,0x9f64003e,0xb6a01b0a}},	//   _uhif, еруш, éwér_, висл, 
   {{0xfaa59417,0xc98400c6,0x26cc0153,0x04480024}},	// [2ab80] _تجوی, _تشغي, ūdo_, опак_, 
   {{0xb5f99418,0xf484144c,0xe5a41955,0x65640023}},	//   _alád, والی, диғи, rzih, 
   {{0x9f982833,0x02040953,0xb5f80162,0x645c003a}},	//   _náði_, дзен, _blád, _vlri, 
   {{0x3ebc0694,0xdb2401ed,0x78bc047e,0x00000000}},	//   _rutt_, ésév, _yuqv, --, 
   {{0x3ebd9419,0x7af8026c,0xb5f801d3,0x00000000}},	//   _sutt_, zutt, _slág, --, 
   {{0x7af9941a,0xb5f80162,0x41cc00dc,0x9f9803b2}},	//   yutt, _plág, _ह्रस, _báði_, 
   {{0x63bc00f3,0x62800066,0x3e781c52,0x3de00183}},	//   _igrn, _tjmo, līti_, _যাবল, 
   {{0x7af802f6,0x3ebc0254,0xa5600092,0x769000a2}},	//   vutt, _vutt_, _ለመንቀ, lçyr, 
   {{0x3e780a30,0xc005941b,0x3ebc00e8,0xd12c004b}},	//   nīti_, _опак, _wutt_, _هڅو_, 
   {{0x3ebd3315,0x61e1941c,0xe92c0135,0x60c00194}},	//   _tutt_, _heml, _སླེབ_, _iumm, 
   {{0x61e1941d,0x3ebc022f,0x8fd40724,0x7af80869}},	//   _keml, _uutt_, _чәчә, uutt, 
   {{0x60c1941e,0x201d941f,0x7af99420,0x61e19421}},	//   _kumm, levi_, rutt, _jeml, 
   {{0x7af99422,0x60c19423,0x61e19424,0x78bc014f}},	//   sutt, _jumm, _meml, _quqv, 
   {{0x60c19425,0x7af99426,0x3e780f40,0x201c0790}},	//   _mumm, putt, dīti_, nevi_, 
   {{0x3ea40652,0x7af820ac,0x7bc99427,0x6a68002d}},	//   _khot_, qutt, _iffu, tűft, 
   {{0x61e000ed,0x201cc9aa,0xb5f8007b,0x0b4401d9}},	//   _neml, hevi_, _amár, _سر٘ێ, 
   {{0x201c19a2,0xd9ac015b,0xb5f8066a,0xd37014d1}},	// [2ab90] kevi_, _ক্রম, _smás, گها_, 
   {{0x201c04b9,0xd3940032,0xb5f802fb,0x00000000}},	//   jevi_, еҙгә_, _slád, --, 
   {{0xd3704030,0xc7d4025f,0x61e00117,0x60c003f9}},	//   دها_, _אותי_, _beml, _aumm, 
   {{0x9f980252,0xb5f802d2,0xc7642309,0x3ea40051}},	//   _ráði_, _bláe, _ساپى, _nhot_, 
   {{0x60c19428,0xb5f803c6,0x61e19429,0x7bc9942a}},	//   _cumm, _vlád, _deml, _offu, 
   {{0x8fa46ca7,0x61e001a4,0xf65c032e,0x201d7f0d}},	//   нале, _eeml, _hlæ_, gevi_, 
   {{0x61e00204,0x3ea5942b,0x60c0062c,0xc604009e}},	//   _feml, _bhot_, _eumm, _লোটা_, 
   {{0x7bc94cad,0x60c1942c,0xb5f800d2,0x3ea4b484}},	//   _affu, _fumm, _hláb, _chot_, 
   {{0x8d743004,0x201d942d,0xb5f846dc,0x21240205}},	//   عابا, bevi_, _ymár, _gsmh_, 
   {{0x201d942e,0x0c2400c2,0x0b44871a,0xada00116}},	//   cevi_, хмон, енон, нақл, 
   {{0x61e1942f,0xdbdc2880,0x60c19430,0x3e7800e2}},	//   _yeml, ráði, _zumm, zīti_, 
   {{0x7bc99431,0x3ea40842,0xc330008d,0x00000000}},	//   _effu, _ghot_, אוט_, --, 
   {{0x60c01db9,0x19b8084c,0x7bdc00fe,0x00000000}},	//   _xumm, дурь_, _মাৰো, --, 
   {{0xcb6800d8,0x00000000,0x00000000,0x00000000}},	//   _нале_, --, --, --, 
   {{0xfb040de2,0xf65c032e,0xc050010f,0xbb501291}},	//   _ñëpp_, _blæ_, נזל_, _منوب, 
   {{0x3e780a2b,0x09d800bd,0x49b8b1bf,0xb5f99432}},	//   tīti_, _থাকা, _عابد_, _aláb, 
   {{0x61e012fb,0x2a6001b9,0xb5f99433,0x201c00ac}},	// [2aba0] _reml, _ilib_, _bláb, yevi_, 
   {{0x60c007e4,0x87240845,0xe96802a9,0x3e781a14}},	//   _rumm, _змож, _нақл_, rīti_, 
   {{0xaca00521,0x60c19434,0x2a617fdb,0x201d9435}},	//   _ahịh, _summ, _klib_, vevi_, 
   {{0x60c0016d,0xb5f801e1,0x61e0047e,0xf65c02d2}},	//   _pumm, _eláb, _qeml, _glæ_, 
   {{0x201cb2cc,0x60c19436,0xc05812fa,0x00000000}},	//   tevi_, _qumm, зій_, --, 
   {{0x61e19437,0x3ea426c2,0x260c02ab,0x60c0c070}},	//   _weml, _shot_, ड्री_, _vumm, 
   {{0x2a60006c,0x44280211,0x201d9438,0x3ea59439}},	//   _olib_, _iab_, revi_, _phot_, 
   {{0x60c1943a,0x4429943b,0xaf31943c,0xdd95943d}},	//   _tumm, _hab_, اروت, кайы, 
   {{0x60c1943e,0x4429943f,0x201c0902,0x80c80154}},	//   _uumm, _kab_, pevi_, _রিক্, 
   {{0x44299440,0x7b644caf,0xbc048c75,0x9b58228c}},	//   _jab_, етме, хчий, диот_, 
   {{0x44299441,0x3ea402d3,0x59f99442,0x00000000}},	//   _mab_, _thot_, меня_, --, 
   {{0x69c077e4,0x2a60007b,0x44299443,0xb5f801ef}},	//   žmen, _clib_, _lab_, _mlác, 
   {{0x442806ed,0x2a600010,0xce3402f2,0x29842af0}},	//   _oab_, _dlib_, _جونک, гырг, 
   {{0x44299444,0x7bc8011c,0x784401c0,0x2a60022e}},	//   _nab_, _uffu, хэмж, _elib_, 
   {{0x7c28d5c3,0xd7940395,0xdb140241,0x00000000}},	//   _iafr, тивъ, _ábàb, --, 
   {{0x44299445,0x2a604e13,0x7c299446,0xff7002d3}},	//   _aab_, _glib_, _hafr, _እንድዩ_, 
   {{0x44299447,0x7c28016b,0x94740214,0x00000000}},	// [2abb0] _bab_, _kafr, نگسا, --, 
   {{0x44299448,0x2a6015f6,0x7c299449,0xf9800022}},	//   _cab_, _zlib_, _jafr, _аҳҭо, 
   {{0x4429944a,0x7c28012c,0x3e7800e2,0xa9240153}},	//   _dab_, _mafr, lītu_, įžei, 
   {{0x7c2870cd,0x4429944b,0xd17400ee,0xd0d402e8}},	//   _lafr, _eab_, кылы, водъ, 
   {{0xa2d4005e,0x3e7800e2,0xf0740131,0x3130035b}},	//   نيەت, nītu_, нидә_, ыҵар, 
   {{0x4429944c,0x7c29944d,0xb5f81ada,0x5f740066}},	//   _gab_, _nafr, _flác, گاهر, 
   {{0xb8780306,0xdc080171,0x764c012d,0x835000e5}},	//   rsíh, _dēļi, _kocy, _پھلا, 
   {{0x7c282337,0x8db412fa,0x00000000,0x00000000}},	//   _aafr, кспі, --, --, 
   {{0x2284152d,0x4428cab7,0x38700254,0x7c29944e}},	//   _сург, _yab_, _omxr_, _bafr, 
   {{0x44280070,0x3e78005f,0xc1a402dd,0x2a61944f}},	//   _xab_, dītu_, _рысқ, _slib_, 
   {{0x764d9450,0x7c299451,0x99880421,0xcb681302}},	//   _oocy, _dafr, _faaū_, фане_, 
   {{0x7c299452,0x16101f5e,0x2a6010f2,0x764c002b}},	//   _eafr, _डॉलर_, _qlib_, _nocy, 
   {{0x260c033f,0x6e2802d0,0xa8240014,0x00000000}},	//   _डॉगी_, _iagb, ۆکھن, --, 
   {{0xc76404a9,0xb5f80bcd,0x6e28007c,0x00000000}},	//   نازى, _smáp, _hagb, --, 
   {{0x44299453,0xc6900050,0x6e2827dd,0x764c0789}},	//   _rab_, لِس_, _kagb, _bocy, 
   {{0x44280190,0x4a759454,0x69bc02ab,0x764d9455}},	//   _sab_, _шылт, _एलटी, _cocy, 
   {{0x44280b89,0x6e28778b,0x764c03cb,0x3e7800de}},	// [2abc0] _pab_, _magb, _docy, cītu_, 
   {{0x44299456,0x6e280cad,0x03799457,0x42d4160b}},	//   _qab_, _lagb, وحات_, віду, 
   {{0x2c100882,0x44299458,0xf8bc04e6,0x229c1427}},	//   त्यं_, _vab_, rwée_, líki_, 
   {{0x6e28ae45,0xd25800d6,0x44299459,0x627c02fb}},	//   _nagb, нці_, _wab_, hčov, 
   {{0x4429945a,0xc7640131,0x6604003b,0x6114009d}},	//   _tab_, _ساھى, mgik, удлу, 
   {{0x44294a96,0x6604c7bf,0x627c012c,0xdbdc0252}},	//   _uab_, lgik, jčov, _náðu, 
   {{0x7c29945b,0x6e29945c,0x6604dac2,0x3e7800e2}},	//   _rafr, _bagb, ogik, zītu_, 
   {{0x6605945d,0xd9ac00cc,0x63b40210,0x00000000}},	//   ngik, কুটম, ęgnę, --, 
   {{0xdbdc08a7,0x7c28fb44,0xfd448e21,0x6605945e}},	//   _báðu, _pafr, тэйн, igik, 
   {{0xf0a5945f,0x7c280548,0x229c0162,0x5ec4022e}},	//   _акул_, _qafr, díki_, _бижғ, 
   {{0x6e282ab7,0xb87825f7,0x7c299460,0xdbdc02d2}},	//   _fagb, príz, _vafr, _dáðu, 
   {{0xb87973cc,0x3e78005f,0x7c291a02,0x58d59461}},	//   nsív, tītu_, _wafr, ломт, 
   {{0x7c299462,0x7e619463,0xe0c0015b,0xfbf0013d}},	//   _tafr, _ilop, _উবুন, _күпь, 
   {{0x7e616e98,0x7c2801f7,0x3e78005f,0x6da0156c}},	//   _hlop, _uafr, rītu_, _тича, 
   {{0x7e619464,0xfaa59465,0x3e799466,0x26cc00df}},	//   _klop, _ишин, sītu_, ŭdon_, 
   {{0x66059467,0x229c00d2,0xaa1400e4,0xb5f80d12}},	//   ggik, bíki_, _hẽng, _bláa, 
   {{0x3e7800e2,0x764c0055,0xddc000c0,0x00000000}},	// [2abd0] līts_, _vocy, limų, --, 
   {{0x7e6000cf,0xe508004b,0xe2c8028e,0xdee401ec}},	//   _llop, ئيلو_, چولو_, _وۋ_, 
   {{0x764c0368,0x3e78005f,0x7e619468,0xe2c800f1}},	//   _tocy, nīts_, _olop, نولو_, 
   {{0xe1f007d6,0x00000000,0x00000000,0x00000000}},	//   قسه_, --, --, --, 
   {{0xa0c41d57,0xe4e40212,0x7af8002f,0x00000000}},	//   لينو, _вісн, hrtt, --, 
   {{0x7e619469,0x6e29946a,0x958400c7,0xaa207039}},	//   _alop, _sagb, _алҭе, _बस्छ_, 
   {{0x6e287004,0xdbdc066a,0x7e603be7,0x627c0030}},	//   _pagb, _ráðu, _blop, včov, 
   {{0x7e61946b,0x3e7800da,0xcd28722e,0xf8bc00d8}},	//   _clop, dīts_, ежие_, nvés_, 
   {{0x9fc402f0,0x6e29946c,0x8cb400db,0x0c7801f4}},	//   sňák_, _vagb, лсоч, есны_, 
   {{0x7e61946d,0x66040161,0x9f0400cf,0xbc600006}},	//   _elop, zgik, _چولو, йвык, 
   {{0x6e29946e,0x627c0306,0xf8bc01d3,0x9f04009a}},	//   _tagb, rčov, kvés_, _نولو, 
   {{0xcd35946f,0x7e619470,0x229c043b,0xdd7400f2}},	//   _مرتب, _glop, tíki_, اپیک, 
   {{0xdc2811fc,0x7af80194,0x7bd80327,0xdd34179e}},	//   رسیه_, artt, bbtu, _پرنظ, 
   {{0x7e602375,0x229c05f7,0xce340244,0x00000000}},	//   _zlop, ríki_, _جوچک, --, 
   {{0xf99c0561,0x46381e76,0x3e7800e2,0xb5f808ce}},	//   ffès_, нчая_, lūta_, _sláa, 
   {{0xa024002f,0x7e600139,0x00000000,0x00000000}},	//   _klöß, _xlop, --, --, 
   {{0x96b81fdf,0x55c43e25,0x850400c6,0xa3c8000d}},	// [2abe0] туру_, рауғ, طوان, _उलद_, 
   {{0xba380165,0xf99c0100,0xe6c81427,0x00000000}},	//   rlïe, rfèt_, ðgóð, --, 
   {{0xf8bc01d3,0x00000000,0x00000000,0x00000000}},	//   svét_, --, --, --, 
   {{0x2c100882,0x6604014b,0xb87800d8,0x00000000}},	//   त्तं_, qgik, usív, --, 
   {{0xb8780120,0x7a3802f6,0x3e7800e2,0xb9e800b7}},	//   rsív, _hätä, jūta_, _ኮድ_, 
   {{0xb8780cfc,0xf99c067c,0x7e619471,0xd9c007f7}},	//   ssív, ngèa_, _slop, _एल्ट, 
   {{0x7e619472,0xb87827b9,0x26d8ca55,0x7a38005b}},	//   _plop, rríx, npro_, _jätä, 
   {{0x7a399473,0x80a404d3,0x9d180276,0xc21001d9}},	//   _mätä, _ڵمان, воит_, _دٔر_, 
   {{0x5274302a,0x81e8045e,0x6fcc0d41,0x7e60033b}},	//   _туру, _মাপ_, _स्कं, _vlop, 
   {{0x3e7800da,0x7118008f,0x5c74020f,0xddc00024}},	//   tīts_, _אומפ, рлот, timų, 
   {{0x7e6001af,0x7bd99474,0xded40023,0xceac00ec}},	//   _tlop, rbtu, ከረኒ_, _ڪڙو_, 
   {{0xfce59475,0xb5f8143c,0x3e799476,0x7e60009f}},	//   _бодо, _alán, _dàtè_, _ulop, 
   {{0x6e919477,0x3e7800e2,0xb5f99478,0x81b400eb}},	//   _النا, sīts_, _blán, চুর_, 
   {{0x7a382776,0xf7701b56,0x81e80154,0x00000000}},	//   _bätä, ماز_, _মাফ_, --, 
   {{0x81e839db,0x395c4ffc,0xab24147e,0x229c02fb}},	//   _মান_, šus_, _боја_, líku_, 
   {{0xf8bc07ea,0xadc0035b,0xb8e803d4,0xb5f813d5}},	//   uvés_, _osẽm, _লব_, _elán, 
   {{0xf8bc0231,0x229c012c,0x00000000,0x00000000}},	// [2abf0] rvés_, níku_, --, --, 
   {{0xf364b711,0xb5f82b76,0x26d80129,0xd9d011dc}},	//   лтен, _glán, bpro_, _دەڭگ, 
   {{0x26d868c8,0xadc000e4,0x3f9c02d2,0x80f0000d}},	//   cpro_, _asẽm, _nytu_, _घिउओ_, 
   {{0x64480699,0xeb9400c8,0x98a8033f,0x00000000}},	//   _òdin, נדאר_, _brać_, --, 
   {{0x3f9ce483,0xd0099479,0xd6e0012d,0x229c01ef}},	//   _aytu_, веле_, गीरथ_, jíku_, 
   {{0x3f9c0232,0xe1f00131,0x229c0306,0xcef400d8}},	//   _bytu_, قسۇ_, díku_, ачињ, 
   {{0x9f4c0548,0x2c780241,0x7a38013d,0x00000000}},	//   _addâ_, _ládè_, _xätä, --, 
   {{0xe374152d,0xfe6c6f33,0x3e7800e2,0x41503ad0}},	//   _улсы, وگن_, tūta_, свәс, 
   {{0x98a8033f,0xfd4400a7,0xe3e800fe,0xf1d000fb}},	//   _grać_, изък_, _পাতব, _көҙө, 
   {{0x26d80051,0xb3e00154,0xb5f80241,0xf1c801ec}},	//   ypro_, _পাঁড়, _oláo, _ﺗﯩﻜﺘ, 
   {{0x5f943b41,0x3e7800e2,0x4aa9947a,0xb80800cc}},	//   _лифт, sūta_, ккон_, শজাত_, 
   {{0x6f01947b,0xb5f80597,0x3e78005f,0x6dc4007b}},	//   munc, _slán, pūta_, _إزال, 
   {{0x6f01947c,0xb5f803c6,0xaca0063f,0x8c45947d}},	//   lunc, _plán, _agụk, _веле, 
   {{0x7a3801b8,0x6d5801d4,0x229c022c,0xb5f80162}},	//   _pätä, myua, líkt_, _bláo, 
   {{0x6f01947e,0x6d580004,0x64900036,0x26d80129}},	//   nunc, lyua, päiz, upro_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
  
   {{0x6d580457,0x75d05cb5,0x26d9947f,0x69c59480}},	// [2ac00] nyua, تيقا, spro_, _igie, 
   {{0x6f019481,0x68e59482,0x81440799,0x69c4031c}},	//   kunc, _iwid, ینان, _hgie, 
   {{0x03259483,0xc3259484,0x6d58020b,0x68e4030a}},	//   рден, рмек, hyua, _hwid, 
   {{0x68e401b3,0x6d580d04,0xb87800dd,0x224001c4}},	//   _kwid, kyua, ssít, ñik_, 
   {{0x6d580218,0x69c46e4a,0xf79400e5,0x04b401f4}},	//   jyua, _mgie, _منیب_, _всвя, 
   {{0x68e59485,0x3f9c0124,0x34900153,0x00000000}},	//   _mwid, _pytu_, _маўр, --, 
   {{0x69c59486,0x6f019487,0x6d5800b5,0xf2e40214}},	//   _ogie, gunc, eyua, _نکنه_, 
   {{0x69c40399,0x68e40428,0xaf3000d1,0x984c00ef}},	//   _ngie, _owid, زرىت, _sēļu_, 
   {{0x6d580cfe,0x68e401ab,0x5c9800a7,0x9a6c0023}},	//   gyua, _nwid, лкия_, ትኽእል_, 
   {{0xb5f80248,0x6f019488,0x69c408c6,0x229c0008}},	//   _alál, bunc, _agie, ríku_, 
   {{0x6f019489,0x68e5948a,0x9b9444e4,0x3f9c0784}},	//   cunc, _awid, синц, _uytu_, 
   {{0x68e40086,0x6d580218,0x01cc02dd,0xfe70009a}},	//   _bwid, byua, _ﺗﯩﯖﻌ, _بدئ_, 
   {{0xb5f800d2,0x6da00022,0x38280023,0x00000000}},	//   _dlál, _дица, _ብምልእ, --, 
   {{0x68e4003e,0xdc08005f,0x69c401c4,0xb5f801d3}},	//   _dwid, _rēķi, _egie, _elál, 
   {{0x683c01e6,0x68e4033f,0x5fb802a0,0x35e40798}},	//   _sådä, _ewid, ेखिल, ицав, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2c100882,0x68e4003d,0x941824fc,0x6f01948b}},	// [2ac10] त्वं_, _gwid, лжат_, zunc, 
   {{0x69c45675,0x9864066d,0x6f01948c,0xea000016}},	//   _zgie, _ایسے_, yunc, _trải_, 
   {{0x68e41682,0x569513cd,0xb879948d,0x69c4035a}},	//   _zwid, _гант, ssís, _ygie, 
   {{0x200c0083,0x2344001f,0xb5f801a8,0x6f000205}},	//   _acdi_, ከርካሪ, _klám, vunc, 
   {{0xe1f8005e,0x200c0230,0x6f01948e,0x658400c7}},	//   ргі_, _bcdi_, wunc, _дырз, 
   {{0x6f01948f,0x6d580218,0x81e800cc,0x00000000}},	//   tunc, vyua, _মাণ_, --, 
   {{0xb5f800eb,0xb8d0031c,0xdcc80051,0x00000000}},	//   _llám, _ྟེ_, _rỉa_, --, 
   {{0x6f019490,0x528400c6,0x00000000,0x00000000}},	//   runc, _الرك, --, --, 
   {{0x6f000986,0x69c4031c,0x00000000,0x00000000}},	//   sunc, _rgie, --, --, 
   {{0x8c499491,0x6d583209,0x68e40223,0x69c407c5}},	//   упов_, ryua, _rwid, _sgie, 
   {{0x68e407a9,0x6d599492,0xb5f80248,0x81e803d4}},	//   _swid, syua, _alám, _মাত_, 
   {{0x68e402d1,0x5f1c15e0,0xe8f81945,0xb5f80d12}},	//   _pwid, _महत्_, аһи_, _blám, 
   {{0x61e40579,0x6d580357,0xdcc801fb,0xad240133}},	//   ðili, qyua, _tỉa_, _خراو, 
   {{0x69d80166,0x00000000,0x00000000,0x00000000}},	//   _şved, --, --, --, 
   {{0x69c40c86,0x8ad400db,0x9b44009f,0x28bc0150}},	//   _tgie, _اتتئ, _ونهو, _ﺤﺎﺼﻠ, 
   {{0x2c10a96d,0x68e4031c,0xdc3c031c,0x69c40327}},	//   त्रं_, _twid, _iġġu, _ugie, 
   {{0x05a80801,0xb5f81427,0x75d01d57,0x68e40210}},	// [2ac20] увай_, _glám, سيلا, _uwid, 
   {{0x48040212,0xecdc01ad,0x00000000,0x00000000}},	//   _упов, पीएफ, --, --, 
   {{0xb5f801ef,0x35e400cc,0x00000000,0x00000000}},	//   _zlám, _ফাৰহ, --, --, 
   {{0x200c0393,0x3fb800fe,0x229c03b2,0xfaf4011a}},	//   _scdi_, ুৰুষ, víks_, מצעי_, 
   {{0xd7280125,0xb958011c,0x18340023,0x00000000}},	//   _ቴክኖሎ, ncìp, _ብምእማ, --, 
   {{0xd2580029,0x9f4c0429,0xb4d8004e,0x00000000}},	//   _viņa_, _addá_, _bràf, --, 
   {{0xb5f801e1,0xb7d8008d,0x82a401d5,0x42543acc}},	//   _amáy, אקצי, _гавж, _лтат, 
   {{0xb5f99493,0x44f4031c,0xefb00133,0xe9540240}},	//   _aláj, _བྷོར_, سینگ, _ዝጸንሔ, 
   {{0xdc3c0003,0x786888c6,0x9d5400f2,0x00000000}},	//   _aġġu, _hüve, زندت, --, 
   {{0x78683361,0x00000000,0x00000000,0x00000000}},	//   _küve, --, --, --, 
   {{0xb4d91e55,0xb5f80118,0x74980115,0x00000000}},	//   _gràf, _slám, רייפ, --, 
   {{0x78699494,0xb5f80332,0xfe700efe,0x00000000}},	//   _müve, _plám, _عدا_, --, 
   {{0xb5f80077,0x2e340375,0x0eb801ee,0x00000000}},	//   _imáx, _לראש_, _туфы_, --, 
   {{0x67d4041b,0x44f4031c,0xf888007b,0xb5f80f91}},	//   зору, _བྷེར_, اضحى_, _vlám, 
   {{0x786804cc,0x45d4063f,0xdcc8004d,0x368801c6}},	//   _nüve, _ọpụ_, _xỉn_, гсан_, 
   {{0xea000016,0x95d806ed,0xa9c400d4,0x64599495}},	//   _trại_, рдат_, _нськ, övin, 
   {{0x54541e28,0xb5f87978,0x3b4802d3,0xa2ac00bc}},	// [2ac30] оват, _hlák, _ንመጀመ, जतन्, 
   {{0x786804cc,0x00000000,0x00000000,0x00000000}},	//   _büve, --, --, --, 
   {{0x3dc40014,0x00000000,0x00000000,0x00000000}},	//   _ogow_, --, --, --, 
   {{0x786803e0,0xb5f800d0,0xd138011c,0x00000000}},	//   _düve, _mlák, изец_, --, 
   {{0xe3e803f4,0x50b5356d,0x0fc4009d,0x00000000}},	//   _পারব, оску, ойлн, --, 
   {{0xb4d801e1,0xb5f801e1,0xe1340661,0x786801d3}},	//   _aràg, _olák, янчы, _füve, 
   {{0x78680ab7,0xb4d800a3,0x567c0023,0x69a00037}},	//   _güve, _bràg, _ባረንቱ_, _गुनी, 
   {{0xbec40046,0x5208009f,0xb5e400fe,0xa77c00d9}},	//   іңіз_, _خيرُ_, _ফাঁচ, טרופ, 
   {{0xb5f80cad,0xb4d800a3,0x00000000,0x00000000}},	//   _alák, _dràg, --, --, 
   {{0xb4d80137,0xb5f8148b,0x3e6801e1,0x00000000}},	//   _tràf, _blák, _rùte_, --, 
   {{0xb4d800cf,0xdef80166,0xf8bc0142,0x00000000}},	//   _fràg, _гыч_, rwél_, --, 
   {{0x6ff800e2,0x64400153,0x00000000,0x00000000}},	//   sācē, _ėmim, --, --, 
   {{0xb5e400cc,0x00000000,0x00000000,0x00000000}},	//   _ফাংচ, --, --, --, 
   {{0x8c44052f,0xb92401f2,0xb5f855c8,0x25dc098a}},	//   _феке, letị_, _flák, गुनी_, 
   {{0x81e800bd,0x8d780092,0xa8a400cf,0x00000000}},	//   _মাস_, ርጋቸው_, _ۉلبۉ, --, 
   {{0xb92405db,0x76d80107,0x7868000d,0xa3dc0073}},	//   netị_, рурӣ_, _rüve, णुन_, 
   {{0x7868162a,0xb5f80306,0x00000000,0x00000000}},	// [2ac40] _süve, _zlák, --, --, 
   {{0x3860045a,0x00000000,0x00000000,0x00000000}},	//   ckjr_, --, --, --, 
   {{0xb92401f2,0xd800010a,0x00000000,0x00000000}},	//   ketị_, _чăх_, --, --, 
   {{0xb92401f2,0x81e80183,0x00000000,0x00000000}},	//   jetị_, _মাহ_, --, --, 
   {{0xb4d800a3,0xdfd41e76,0xbba406e3,0xf65005d0}},	//   _cràd, полы, _ऑर्क, _חצר_, 
   {{0x7868000d,0x00000000,0x00000000,0x00000000}},	//   _tüve, --, --, --, 
   {{0x3e699496,0x42d40826,0xb5f957ba,0x00000000}},	//   ишин_, _фігу, _bláh, --, 
   {{0x2000084c,0xbe88026a,0x3ce40100,0x52b000db}},	//   şii_, јске_, _pwov_, _كەلئ, 
   {{0xd25800da,0x6344001f,0xb4d80e89,0x7c8802e8}},	//   _ziņo_, _የሚጠበ, _gràd, ищов_, 
   {{0xb5f800d7,0x195800fb,0xaff4007b,0x7f180024}},	//   _plák, ҡаны_, _وفقا_, _віду_, 
   {{0x20d00016,0x7f840f47,0xb4d867db,0x31300b82}},	//   _hài_, _بلان, _tràg, _ቻርተር, 
   {{0xb5f802fd,0x3ce405da,0x20d00051,0x00000000}},	//   _vlák, _twov_, _kài_, --, 
   {{0x8c2400cc,0x6c744d66,0x00000000,0x00000000}},	//   বাজন_, صحیح_, --, --, 
   {{0x20d001fb,0xfb84084c,0xd7c91c53,0xec100150}},	//   _mài_, _мыйн, صوره_, _يوند, 
   {{0xdcc801fb,0x20d00208,0xc0f40023,0x69a00118}},	//   _mỉm_, _lài_, ለወሉ_, _गुठी, 
   {{0x20d00208,0xf5240023,0x199400d4,0x00000000}},	//   _oài_, _ሽርክነ, _найя, --, 
   {{0x20d0004d,0x78680205,0x66e001e1,0xa968009b}},	// [2ac50] _nài_, _cüvc, _pàkò, _мића_, 
   {{0x9714e602,0x00000000,0x00000000,0x00000000}},	//   _емоц, --, --, --, 
   {{0x78a401a6,0x97340214,0x00000000,0x00000000}},	//   mljv, _عکسا, --, --, 
   {{0x20d0431d,0x56940323,0x612002e3,0xb8780005}},	//   _bài_, _хамт, _ịlag, spíd, 
   {{0x20d007ae,0xdcc8004d,0x69c00115,0x00000000}},	//   _cài_, _bỉm_, ɾmes, --, 
   {{0x20d007ae,0x44f4031c,0xba381e54,0xf2d8484d}},	//   _dài_, _བྷིར_, loïd, _نظرت_, 
   {{0x81e80154,0xdd000055,0x00000000,0x00000000}},	//   _মার_, _ātān, --, --, 
   {{0xba399497,0x932400aa,0xf53c0158,0xb5f99498}},	//   noïd, _ورځن, _krå_, _blái, 
   {{0xb5f99499,0x87180154,0x20d00208,0x69a00073}},	//   _clái, ডিএফ_, _gài_, _गुढी, 
   {{0x4c680902,0x1d8800d1,0x00000000,0x00000000}},	//   сион_, تئىي_, --, --, 
   {{0xb5f80789,0x25dc190e,0x00000000,0x00000000}},	//   _tláh, गुडी_, --, --, 
   {{0x1c1c0412,0x00000000,0x00000000,0x00000000}},	//   ब्बल_, --, --, --, 
   {{0x20d0001e,0xb0c80882,0xf99c020c,0x00000000}},	//   _xài_, ादिग, ngèh_, --, 
   {{0xfd54011a,0x00000000,0x00000000,0x00000000}},	//   _משני_, --, --, --, 
   {{0xfc14819a,0xf741949a,0x91780208,0x6458000d}},	//   _رقيب_, неро, _lầm_, övim, 
   {{0xd90c4046,0xf53c11ad,0xf8bc020c,0x2c1406b1}},	//   دیی_, _brå_, hwéh_, ब्रू_, 
   {{0xb4d81f40,0x81e80f22,0x00000000,0x00000000}},	// [2ac60] _aràb, _মাল_, --, --, 
   {{0xd7f0004d,0x627c0de2,0xb5f80241,0x6fc4000d}},	//   ữa_, rōom, _oláw, _ललगं, 
   {{0xf8b00302,0x20d00016,0x07a5949b,0xb4d808c2}},	//   _רשת_, _sài_, _ханн, _cràb, 
   {{0xf53c3fae,0xba39949c,0xc0c80414,0xf77008c9}},	//   _frå_, coïd, буке_, _ساپ_, 
   {{0xbfa818ce,0xb5f80ca8,0x7de000d2,0xc0580220}},	//   әтле_, _aláw, _lísâ, йік_, 
   {{0x20d00016,0x321c009a,0x00000000,0x00000000}},	//   _vài_, _ebuy_, --, --, 
   {{0xb5f80597,0xd9b81e61,0xb4d800a3,0x3e7800e2}},	//   _slái, _इण्ट, _gràb, lūti_, 
   {{0x20d001dc,0x786803be,0x99880139,0xb5f800ae}},	//   _tài_, _müva, _nbaş_, _plái, 
   {{0xba380af9,0xdcc80208,0x00000000,0x00000000}},	//   noïe, _tỉm_, --, --, 
   {{0x25dc0490,0xba3806af,0xac800240,0x00000000}},	//   गुती_, zoïd, _ክእረም_, --, 
   {{0x2fd404fb,0x673c1710,0x00000000,0x00000000}},	//   _روند_, jvrj, --, --, 
   {{0xcf240597,0xb5f80306,0x2cb401d9,0x998800c7}},	//   _تركي, _hláv, _ہُند_, жәоз_, 
   {{0xb5f80e96,0xd048013f,0xf8bc01c7,0x64480241}},	//   _kláv, _nteɛ, lwéi_, _òdiw, 
   {{0x2ca40798,0x00000000,0x00000000,0x00000000}},	//   _екчп_, --, --, --, 
   {{0xd048013f,0xc5d8063f,0xec340375,0x78a401a6}},	//   _ateɛ, _ọrụb, _מאגר_, rljv, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xba382e0c,0x3a280010,0x659400f3,0x00000000}},	// [2ac70] roïd, mecp_, еату, --, 
   {{0xb4d8927b,0xf53c2611,0xd2580139,0x734802e8}},	//   _aràc, _vrå_, _soņ_, йчев_, 
   {{0xb4d801c3,0x9f4c036e,0x81e40154,0x27f80419}},	//   _bràc, _dedë_, পণন_, šenú_, 
   {{0xe3b00491,0xf53c143a,0x3e7875e3,0xa2940a4a}},	//   ارك_, _trå_, būti_, нахі, 
   {{0xb4d8004e,0x201c0175,0x91780208,0x00000000}},	//   _dràc, ffvi_, _bấm_, --, 
   {{0x8fa40a83,0x9f4c01e1,0x293808d8,0x91780051}},	//   мале, _kedè_, פאון_, _cấm_, 
   {{0x8e74011c,0x00000000,0x00000000,0x00000000}},	//   дупч, --, --, --, 
   {{0xb4d84f07,0x7bc801ab,0xaca0063f,0x91780208}},	//   _gràc, _agfu, ruọn, _tầm_, 
   {{0x88e02158,0xb5f80120,0x61e409c2,0xefc8001f}},	//   _বিভক, _fláv, ñile, ሠራው_, 
   {{0xada000d1,0x00000000,0x00000000,0x00000000}},	//   мақл, --, --, --, 
   {{0x6ee4d55f,0x6f000175,0xdebc0092,0x00000000}},	//   _رسال, qrnc, _ታሪኩ_, --, 
   {{0xaca00248,0xb8780113,0xdfd001d3,0x00000000}},	//   _ifọk, ypíc, _ليے_, --, 
   {{0x9f64023a,0x7869949d,0x6459949e,0x00000000}},	//   ätön_, _süva, övik, --, 
   {{0xcb680640,0x668400f1,0x7a300064,0x7aecf9d1}},	//   _мале_, ځیدل, ežtė, úntó, 
   {{0xb4c400bc,0x46a401f0,0x07b800ae,0x0664085b}},	//   उदै_, давв, زهرة_, وارپ, 
   {{0xba38017a,0x5a9400c0,0x00000000,0x00000000}},	//   toïe, _прыф, --, --, 
   {{0x6aa54133,0x00000000,0x00000000,0x00000000}},	// [2ac80] _ikif, --, --, --, 
   {{0x26cc74c3,0x786801b8,0xb4d800a3,0xba380ea0}},	//   ídos_, _tüva, _sràc, roïe, 
   {{0xb4d80228,0x98a804a7,0x3e78005f,0xb879949f}},	//   _pràc, _građ_, sūti_, spíc, 
   {{0x41a873ae,0xb5f994a0,0xb87994a1,0x2a8801d3}},	//   овен_, _sláv, mpía, lőbb_, 
   {{0xb5f994a2,0x6aa401f7,0x68380023,0xdef8010c}},	//   _cláu, _mkif, _ብምስት, ለየን_, 
   {{0xa3c852f2,0x1d080022,0x00000000,0x00000000}},	//   _उलट_, ҧҵеи_, --, --, 
   {{0xdebc0201,0x645d94a3,0x656594a4,0xb4d994a5}},	//   _ታሪክ_, _iori, lyih, _tràc, 
   {{0x645d94a6,0x1d3594a7,0x6aa40223,0x6564009a}},	//   _hori, ения, _nkif, oyih, 
   {{0x645c04b9,0x91c0052f,0x65640050,0x628194a8}},	//   _kori, _йәшл, nyih, _immo, 
   {{0x645d94a9,0x62800218,0x6aa594aa,0x394c002e}},	//   _jori, _hmmo, _akif, _àgsi_, 
   {{0x645d94ab,0x2a8801d3,0x443800e4,0xb5f800d7}},	//   _mori, zőbe_, idp_, _klát, 
   {{0xaacd94ac,0x60c80135,0x41b02d6b,0xcf24009f}},	//   _संरक, _hidm, _जरास, _سرمي, 
   {{0x645d94ad,0x5ac803e6,0x4438007f,0x7c3c9162}},	//   _oori, _کاتێ_, kdp_, _ópro, 
   {{0x645d94ae,0xf770acb6,0xb9044c21,0x6aa42f99}},	//   _nori, ناز_, _पऽ_, _ekif, 
   {{0x67d40372,0x6aa40093,0x62800c8c,0xaee00882}},	//   тосу, _fkif, _ommo, riṇa, 
   {{0x645c0851,0x60c994af,0x7c382611,0x9f4c0561}},	//   _aori, _lidm, ldtr, _vedè_, 
   {{0x645c1cf2,0x9f4c0798,0x7c3801f5,0x693401e0}},	// [2ac90] _bori, _dedé_, odtr, _аныу, 
   {{0x628194b0,0xb5f93d26,0x60c8014f,0xd89401d9}},	//   _ammo, _alát, _nidm, _سٔجد, 
   {{0x645d94b1,0xb5f994b2,0x3f8800f3,0x65640009}},	//   _dori, _blát, _žbun_, ayih, 
   {{0x9f4c3386,0x645d02d1,0x60c994b3,0x65656b30}},	//   _gedé_, _eori, _aidm, byih, 
   {{0x645d94b4,0x46280135,0x65640526,0xe5c4020a}},	//   _fori, _སྒྲས_, cyih, _асро, 
   {{0x628194b5,0x60c80009,0xb9c802d3,0x04a40022}},	//   _emmo, _cidm, _ተጋ_, _зусҭ, 
   {{0xb5f824c8,0xb4a81d72,0x7c38369d,0x60c80024}},	//   _coág, खती_, ddtr, _didm, 
   {{0x645c05f5,0x8d54eecc,0x60c802d0,0xf8bc0098}},	//   _zori, еточ, _eidm, rvéy_, 
   {{0x645d94b6,0xb5f80122,0x2c1002ab,0x3e78005f}},	//   _yori, _hlás, _दादू_, jūtu_, 
   {{0x6aa49f65,0x645c77f0,0x70c80f44,0x60c8031c}},	//   _skif, _xori, ादील, _gidm, 
   {{0x62800731,0x2d800165,0x64580108,0x88e000cc}},	//   _ymmo, ńje_, övii, _বিধক, 
   {{0xd1e402d3,0x7c380af9,0x434402d3,0x00000000}},	//   _ዛዕባ_, adtr, _መጋባኣ, --, 
   {{0x6e380921,0x3e7800e2,0x44380175,0x65640009}},	//   mdub, gūtu_, ydp_, xyih, 
   {{0x60c80cc1,0x656594b7,0x6e3994b8,0xba38067c}},	//   _xidm, vyih, ldub, toïc, 
   {{0x645c76db,0xc7645841,0x9f4c02ea,0x8b6801c0}},	//   _rori, راسى, _pedé_, _хийв_, 
   {{0x998c05ce,0x6e3994b9,0x6aa594ba,0x2a8801ed}},	//   žeš_, ndub, _ukif, sőbb_, 
   {{0xeb1c4425,0x645d94bb,0xb5f80ca8,0xb8780077}},	// [2aca0] _बहुत_, _pori, _alás, mpín, 
   {{0x645d94bc,0x44a49fb6,0x656594bd,0xb5f80321}},	//   _qori, رماق, ryih, _blás, 
   {{0x020594be,0x645d94bf,0x4438af97,0x74112914}},	//   езен, _vori, rdp_, اوما, 
   {{0x6e38041a,0x645d94c0,0xd2580212,0x60c8007c}},	//   jdub, _wori, мці_, _sidm, 
   {{0xb5f8dd69,0x44380649,0x6e3994c1,0xba380129}},	//   _elás, pdp_, ddub, noïa, 
   {{0x60c994c2,0x786805d5,0x645d94c3,0xeb1c05f9}},	//   _qidm, _nüvl, _uori, _बहूत_, 
   {{0x60c994c4,0xb5f93908,0xa92c0023,0x628003e0}},	//   _vidm, _ilár, ዳተባህ, _tmmo, 
   {{0xb65804ac,0x60c994c5,0x628194c6,0x81e803d4}},	//   ִדיש, _widm, _ummo, _মাক_, 
   {{0xb5f8041e,0x2dd40597,0x52b00131,0xc1040592}},	//   _klár, ربية_, _ئەنئ, _سواي, 
   {{0x7f740276,0x7c383e1d,0x70f8011a,0xdb200118}},	//   _пуец, udtr, _מהמח, žtík, 
   {{0x9b9594c7,0xa3c00dba,0x00000000,0x00000000}},	//   тинц, ँधि_, --, --, 
   {{0x7b642cc8,0x00000000,0x00000000,0x00000000}},	//   _үтке, --, --, --, 
   {{0x3ea422d0,0xad400137,0xf7b82d40,0xdcf40064}},	//   _ikot_, _مۉيۉ, ﻠﯩﻨﺪ, _įbėg, 
   {{0xd25800da,0xb4d92e49,0x786804cc,0xf99c067c}},	//   _viņi_, _bràn, _güvl, dgèt_, 
   {{0xf64401c6,0x00000000,0x00000000,0x00000000}},	//   нхан, --, --, --, 
   {{0xb5f80cad,0x7af8007c,0x1c1c01ad,0x3e787106}},	//   _alár, mstt, ब्रल_, pūtu_, 
   {{0xe5980220,0x1b740451,0xb5f802d2,0x00000000}},	// [2acb0] екті_, _سگھج, _blár, --, 
   {{0xb5f994c8,0x7bd994c9,0xb4a81533,0xb4d807de}},	//   _plás, nctu, खते_, _fràn, 
   {{0x3ea594ca,0x229c0122,0xb4d994cb,0x7bd80393}},	//   _okot_, líky_, _gràn, ictu, 
   {{0xd9f00c6f,0xb5f8533b,0xf99c0ba1,0x6e380009}},	//   चरित_, _vlás, sgèu_, xdub, 
   {{0x1cdc0135,0x229c02fd,0x865802e4,0xe0d802bf}},	//   ྣམས_, níky_, _חדרי, еві_, 
   {{0x3ea403a2,0x7af85522,0xb87802f0,0xdcc80051}},	//   _akot_, kstt, zpín, _kỉu_, 
   {{0xdebc069c,0x7af80d27,0x7bd8003a,0xab680023}},	//   _ታሪኽ_, jstt, dctu, ትውዓል_, 
   {{0x7bd994cc,0x91800131,0x64580254,0x00000000}},	//   ectu, _پۇتۇ, öviv, --, 
   {{0x6e3994cd,0xa194009d,0x229c0419,0x2c00004e}},	//   rdub, _батч, jíky_, гүлм, 
   {{0x229c02fb,0x3ea42be0,0xbc60023a,0x7af80036}},	//   díky_, _ekot_, ивык, fstt, 
   {{0x7af801f5,0x9c640214,0x3e7800e2,0x00000000}},	//   gstt, اهپو, gūts_, --, 
   {{0x7bd800e4,0x656001c3,0x229c01ef,0xa6e000cc}},	//   actu, _àmhg, fíky_, _বটলট, 
   {{0x2dc407d6,0xb87803b2,0x00000000,0x00000000}},	//   _яқин_, rpín, --, --, 
   {{0x7bd8003a,0xb87802f0,0xdcc80051,0x3e7800ef}},	//   cctu, spín, _bỉu_, būts_, 
   {{0x07a50fb3,0x25080b8a,0xba38004e,0x48ec0118}},	//   тавн, کرزی_, moïn, _अबको_, 
   {{0xf99c068c,0xa9a400db,0x56380120,0x229c0c5e}},	//   tgèt_, _مۅجى, нџур_, bíky_, 
   {{0xb82403d4,0xc4c801c6,0x31c81fe7,0x00000000}},	// [2acc0] ময়ত_, длаж_, िशोध, --, 
   {{0xb4d994ce,0xaca001f2,0xf99c0066,0x10d400d1}},	//   _tràn, krọn, rgèt_, ﻟﻪﺗﻨ, 
   {{0xd048013f,0x9f4d94cf,0x27f80194,0xb4d801ab}},	//   _nteɑ, _cedì_, marn_, _uràn, 
   {{0x27f80489,0xc0e45477,0x00000000,0x00000000}},	//   larn_, водк, --, --, 
   {{0xc05800d6,0x26c00dd9,0xdebc0240,0x00000000}},	//   дій_, mmio_, _ታሪኻ_, --, 
   {{0xdc0800da,0x26c13b77,0x2a6001ab,0x3ea57113}},	//   _mēģi, lmio_, _loib_, _skot_, 
   {{0x229c0122,0xf99d94d0,0x26c179ba,0xdcc8004d}},	//   zíky_, ngèr_, omio_, _xỉu_, 
   {{0x2a60022e,0xd36c00db,0x27f80327,0x00000000}},	//   _noib_, _عۇن_, harn_, --, 
   {{0x27f91d78,0x229c02f0,0x5bbc00cd,0xdc0800ef}},	//   karn_, xíky_, ैश्व, _nēģi, 
   {{0x30240022,0x3e7800e2,0x6ed000c7,0x00000000}},	//   _иоуп_, tūts_, ыцәх, --, 
   {{0x7bd98e21,0x27f88ddb,0x2a6000db,0xbbd000e1}},	//   rctu, darn_, _boib_, _सलीक, 
   {{0x26c194d1,0x7af801a4,0x7d740014,0x27f8cba5}},	//   jmio_, rstt, _لۅبر_, earn_, 
   {{0x2a600076,0xa2d402ab,0x27f80368,0x7af961d4}},	//   _doib_, _बूस्, farn_, sstt, 
   {{0xb5f80ca8,0x26c194d2,0xca6001a9,0x7c2400e5}},	//   _aláp, emio_, stlа, _شيعہ_, 
   {{0xd25800da,0x59a407f7,0x00000000,0x00000000}},	//   _ziņu_, _ऐडवर, --, --, 
   {{0x2a605513,0x88e0015b,0x3b1c0051,0x81e800eb}},	//   _goib_, _বিরক, mttq_, _মাঝ_, 
   {{0xf99ce5ce,0x81c803d4,0x54b80108,0x42800092}},	// [2acd0] rgès_, োৰত_, егая_, ያዊነት_, 
   {{0xf36402de,0x647405f5,0x26c00421,0xb364074d}},	//   ктен, агуу, amio_, къек, 
   {{0x81e800fe,0x00000000,0x00000000,0x00000000}},	//   _মাজ_, --, --, --, 
   {{0x9f4c004e,0xb5f8032e,0x00000000,0x00000000}},	//   _cedí_, _gláp, --, --, 
   {{0xb0300032,0x764d94d3,0x74a400d8,0x27f8013d}},	//   имдә, _incy, _ајве, _öenä_, 
   {{0xaca002e3,0xd478010f,0x64580037,0x00000000}},	//   trọn, _טאָל, övit, --, 
   {{0x8e84004e,0x00000000,0x00000000,0x00000000}},	//   лгке, --, --, --, 
   {{0x27f8030a,0x00000000,0x00000000,0x00000000}},	//   zarn_, --, --, --, 
   {{0x228594d4,0xf1d00184,0x20240413,0x00000000}},	//   _тург, _йөҙө, úrið_, --, 
   {{0xd25800da,0x3e6808c2,0xa0b801c0,0x27f80108}},	//   _viņu_, _lùth_, _агуу_, xarn_, 
   {{0x27f803bd,0xd1e402d3,0xba3994d5,0xcb6994d6}},	//   varn_, _ዛንታ_, roïn, хане_, 
   {{0x3f7804ac,0x955c02d3,0x27f8921c,0x29940023}},	//   _אָדע, ደልትን_, warn_, _ዘሕፍር_, 
   {{0x2c0018ce,0x7e7c0221,0x27f994d7,0x2a60000d}},	//   _күпм, ëppe, tarn_, _voib_, 
   {{0x764d94d8,0xf99c068c,0x27f80489,0x00000000}},	//   _ancy, tgèr_, uarn_, --, 
   {{0x81e8045e,0x3e680e89,0xb4d80e89,0x27f994d9}},	//   _মাঘ_, _bùth_, _dràm, rarn_, 
   {{0x2bdc081e,0x27f994da,0x26c00e3c,0xb4d800a3}},	//   पुरा, sarn_, umio_, _tràl, 
   {{0x26c194db,0x3e6800a3,0xe7a42983,0x27f8007c}},	// [2ace0] rmio_, _dùth_, _खुरप, parn_, 
   {{0x29000093,0x68e416b8,0xb4601b04,0x9f4d94dc}},	//   _ivia_, _itid, бкул, _sedí_, 
   {{0x9f4c00eb,0xf8bc0098,0x42080114,0x00000000}},	//   _pedí_, pwér_, енео_, --, 
   {{0x29000158,0x00000000,0x00000000,0x00000000}},	//   _kvia_, --, --, --, 
   {{0xba04010c,0x5ff594dd,0x601808da,0x6458000d}},	//   _ጉያ_, азлу, воля_, övis, 
   {{0x40941d37,0x03a40798,0x00000000,0x00000000}},	//   ырет, _биго, --, --, 
   {{0xaacd94de,0xbea4009d,0x00000000,0x00000000}},	//   _संगक, лший, --, --, 
   {{0x68e405be,0x2900005b,0x82a40108,0x00000000}},	//   _otid, _ovia_, _сабж, --, 
   {{0x5c7594df,0xdd952129,0x68e48875,0x290402f0}},	//   илит, рапы, _ntid, ámal_, 
   {{0x2bdc084d,0x00000000,0x00000000,0x00000000}},	//   पुला, --, --, --, 
   {{0x29000c95,0x68e594e0,0x00000000,0x00000000}},	//   _avia_, _atid, --, --, 
   {{0xdd0005d1,0x8e1400b8,0x00000000,0x00000000}},	//   ştık, _hṝnt, --, --, 
   {{0x786800af,0xa3e42052,0xf8bc003e,0xcca80137}},	//   _hüvi, नडा_, ntég_, رچۇۇ_, 
   {{0x6d380302,0x68e401ab,0x7e6071e2,0xba3800e4}},	//   _נתונ, _dtid, _hoop, moïm, 
   {{0x68e445b4,0x999800dd,0x00000000,0x00000000}},	//   _etid, reső_, --, --, 
   {{0x58d4156b,0x61e54db1,0x7e6194e1,0x00000000}},	//   _коит, ñill, _joop, --, 
   {{0xb4d800f7,0x7e6194e2,0x6a14030c,0x2b440427}},	// [2acf0] _tràm, _moop, _ابىر, _zrnc_, 
   {{0xe508004b,0x7e608e91,0x241800fb,0x00000000}},	//   ايلو_, _loop, лоуы_, --, 
   {{0x998c0034,0xda080073,0x00000000,0x00000000}},	//   żeń_, _वयात_, --, --, 
   {{0x29000268,0x7e6077d0,0x64580108,0xe2c80472}},	//   _yvia_, _noop, övir, هولو_, 
   {{0xc5f80375,0x00000000,0x00000000,0x00000000}},	//   _בפרט, --, --, --, 
   {{0xa3d407c6,0xa0c416ac,0x21780139,0x00000000}},	//   _горч, مينو, ыйчы_, --, 
   {{0x647594e3,0x7e60002e,0x00000000,0x00000000}},	//   _угру, _boop, --, --, 
   {{0x9f4c0798,0x7ebc0036,0xcd040131,0xfde402e8}},	//   _sedã_, hëpf, апий, адък_, 
   {{0x261800e1,0xa3dc01f9,0x0c78009d,0x00000000}},	//   _फासी_, णुक_, всны_, --, 
   {{0x1ca803e6,0x4c68fe42,0x00000000,0x00000000}},	//   هێنی_, тион_, --, --, 
   {{0x68e594e4,0x9f0594e5,0x7e7c0036,0xba3800e4}},	//   _stid, _هولو, ëppc, moïj, 
   {{0x68e4a0a9,0xdb0c00e4,0x00000000,0x00000000}},	//   _ptid, õhár, --, --, 
   {{0xad600451,0x997594e6,0x46143fe6,0x00000000}},	//   _چاڙه, бурш, یوسر, --, 
   {{0x7e6194e7,0x8b640aaa,0xc79594e8,0x2b440332}},	//   _zoop, _ناعم, арбы, _trnc_, 
   {{0x37845267,0x15b80220,0x09e4f647,0xc6a801d9}},	//   абро_, ғыты_, _койн, ندرٕ_, 
   {{0x7e6062e5,0x2900020c,0x68e40083,0x15e002e5}},	//   _xoop, _tvia_, _ttid, गुलर_, 
   {{0xc48594e9,0x85041a4b,0x00000000,0x00000000}},	// [2ad00] алак, شوان, --, --, 
   {{0x55c40220,0x00000000,0x00000000,0x00000000}},	//   сауғ, --, --, --, 
   {{0x2ba816f0,0xb5f8003a,0x55f400cc,0x00000000}},	//   _घुमा, _ioán, _ছাৰক_, --, 
   {{0x9f4c0232,0x161c1025,0x00000000,0x00000000}},	//   _nedá_, _फायर_, --, --, 
   {{0x7e6194ea,0xb4d80241,0x7868000d,0x00000000}},	//   _roop, _asàf, _süvi, --, 
   {{0x7e6187f4,0x00000000,0x00000000,0x00000000}},	//   _soop, --, --, --, 
   {{0x7e6194eb,0xc21001d9,0x442994ec,0xac800023}},	//   _poop, _ؤس_, _ibb_, _ክብሎም_, 
   {{0xb4d800a3,0xaee00882,0x7e6194ed,0x290c033f}},	//   _bràh, _saṃm, _qoop, ądaj_, 
   {{0xacf40184,0xf8bc004a,0x52740137,0xf2640114}},	//   аныу_, ltée_, _ууру, _титл_, 
   {{0xdd94005e,0x7e6194ee,0x786935c7,0x44280072}},	//   _қалы, _woop, _tüvi, _jbb_, 
   {{0xf8bc4aee,0x7e60947b,0x78a42402,0xdd9004fb}},	//   ntée_, _toop, vojv, توک_, 
   {{0xf8bc004a,0x1958008e,0xeb94041b,0x442994ef}},	//   itée_, гамы_, риџ_, _lbb_, 
   {{0x442994f0,0x984c0171,0x298801f0,0xce3401e2}},	//   _obb_, _nēģu_, асро_, _دونک, 
   {{0x7d0194f1,0x442994f2,0x8c3801f0,0xe61000f1}},	//   _ivos, _nbb_, _бошӣ_, ېشل_, 
   {{0xf65005d9,0x7d003ed8,0x261801f9,0x00000000}},	//   يئر_, _hvos, _फाशी_, --, 
   {{0x80c001ad,0x7d0002d2,0x00000000,0x00000000}},	//   षगुं, _kvos, --, --, 
   {{0xf71c0125,0x6ac4007b,0x00000000,0x00000000}},	// [2ad10] ስቲያን, _بقيم, --, --, 
   {{0x048400d1,0x00000000,0x00000000,0x00000000}},	//   бәси_, --, --, --, 
   {{0xe3b04973,0xb3400327,0x77400244,0x289c00d9}},	//   ورم_, ħħos, _بێزم, _ביזא, 
   {{0xd17594f3,0x442994f4,0x7d008185,0x62240131}},	//   йылы, _ebb_, _ovos, قىمل, 
   {{0x3ce401d4,0xd0088087,0xaad0012c,0x00000000}},	//   _ntov_, геле_, _संघक, --, 
   {{0x4428030a,0x656001c3,0xa3e4012c,0x9f4c01ef}},	//   _gbb_, _àmha, _नभए_, _sedá_, 
   {{0x7d0194f5,0xf8bd94f6,0x4e2801c0,0x00000000}},	//   _avos, ctée_, гойн_, --, 
   {{0xb4d800a3,0x228405f5,0x7c2803fa,0x0eb801e0}},	//   _arài, _дууг, _abfr, ыулы_, 
   {{0x442994f7,0xb4d808c2,0x98a8107d,0xc2100375}},	//   _ybb_, _brài, _apač_, _מהן_, 
   {{0x7d0007f5,0xe0d00b43,0xb4d801c3,0x00000000}},	//   _dvos, _قزل_, _crài, --, 
   {{0x7d000472,0xb4d801c3,0xcac8005b,0x717000ec}},	//   _evos, _drài, лгое_, _اهڃا, 
   {{0x2d7c0034,0x00000000,0x00000000,0x00000000}},	//   _płeć_, --, --, --, 
   {{0x8c4409a5,0x09180022,0x00000000,0x00000000}},	//   _геле, ыцны_, --, --, 
   {{0x6d4828be,0xb4d80e89,0xcc0801d9,0x37e10341}},	//   _irga, _grài, _صٲبن_, зорг, 
   {{0x7d000e8a,0x6d4801a6,0x44280112,0x6684036b}},	//   _zvos, _hrga, _rbb_, قیدل, 
   {{0x442994f8,0xa5e80184,0xaad02e1e,0xfc4802d2}},	//   _sbb_, рлаҡ_, _सूचक, _tríó_, 
   {{0x442846a3,0x3ce4022e,0x6d580208,0xb5f80208}},	// [2ad20] _pbb_, _xtov_, nxua, _toán, 
   {{0xaee006d6,0x98a802d5,0xf8bc06af,0x959402dd}},	//   hiṱa, _ypač_, ttée_, ішті, 
   {{0xf8bd94f9,0x442994fa,0x7498013e,0x00c80ce8}},	//   utée_, _vbb_, устӣ_, ңлек_, 
   {{0x786803be,0xf8bc20ef,0x4428324c,0x9f4c01d3}},	//   _qüvv, rtée_, _wbb_, _ülés_, 
   {{0xf8bc07ea,0xdfd401c0,0x61140212,0xa15994fb}},	//   stée_, оолы, ідку, ралу_, 
   {{0x442994fc,0xf8bc07ea,0x23dc17ee,0x00000000}},	//   _ubb_, ptée_, _बलिद, --, 
   {{0x6d4994fd,0xe82000e1,0x1ce00327,0x7d0001a8}},	//   _arga, _बाना_, _ཧཕང_, _svos, 
   {{0xb4d80e89,0x9f5c0240,0x00000000,0x00000000}},	//   _srài, lavë_, --, --, 
   {{0xb4d801ab,0x80180014,0xd24c0133,0xdce000c0}},	//   _prài, _مزاز_, _جۆن_, kymą, 
   {{0x6d4948ca,0x7e940014,0x9b940063,0x00000000}},	//   _drga, _گۆبر_, жиоц, --, 
   {{0x6d4822a9,0xda340024,0x2fd404fb,0xfb843cc5}},	//   _erga, оены, _اومد_, сыпн, 
   {{0x7e940014,0x6e2801e1,0x9f5c0200,0x986c00de}},	//   _دۆبر_, _gbgb, havë_, džā_, 
   {{0xd04003be,0x6d4801a6,0x6da00022,0xb4d994fe}},	//   _ailə, _grga, _еица, _trài, 
   {{0xd04011a9,0x9f5c0240,0xad180a7c,0x69d8008e}},	//   _bilə, javë_, _עוור, _şvet, 
   {{0x161c02ab,0xd04006be,0x00000000,0x00000000}},	//   _फादर_, _cilə, --, --, 
   {{0xd04000ac,0x95c802dd,0x199594ff,0x6d4800a2}},	//   _dilə, ғуға_, _майя, _yrga, 
   {{0x1ae005ac,0x25e800ab,0x19c4104e,0x00000000}},	// [2ad30] _ভিয়া, जड़ी_, _фәнг, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd1d84727,0xd87801d5,0xd04003e3,0x00000000}},	//   адец_, _ممکت_, _gilə, --, 
   {{0x9f4c0793,0x9f5c0022,0x00000000,0x00000000}},	//   _medä_, pavê_, --, --, 
   {{0xf65c00b5,0xd04003b9,0x00000000,0x00000000}},	//   _diæt_, _zilə, --, --, 
   {{0xcee81064,0x9474036b,0x290401d3,0x00000000}},	//   адке_, _بگرا, ámai_, --, 
   {{0x6d441a5a,0x37d803d4,0xd00801e0,0xda080073}},	//   ājam, _বজাৰ, геһе_, वणात_, 
   {{0x6d5801c6,0x6d4816a3,0x2730007c,0xb5f800e5}},	//   txua, _prga, _hönö_, _aláz, 
   {{0xb5f99500,0x82600150,0x91801e4a,0x27300139}},	//   _bláz, _تۇنن, _تۇشۇ, _könö_, 
   {{0x6d49220c,0x247802d3,0x004400f1,0x09e001f9}},	//   _vrga, _ቡዙሓት_, _ویني_, पड्य, 
   {{0xe8203eaf,0x00000000,0x00000000,0x00000000}},	//   _बाबा_, --, --, --, 
   {{0x6d4824dd,0xe8f80116,0x30740408,0x00000000}},	//   _trga, бһи_, _куçс, --, 
   {{0x6d499501,0x2904773a,0x8238008f,0xf40003d4}},	//   _urga, éma_, בערצ, ৰ্যৰ_, 
   {{0x9f5c033b,0x20c000a3,0xb8780118,0x290400e4}},	//   favè_, ròig_, zpív, ĩma_, 
   {{0xf7411e5d,0x9f4c0139,0x8c4401af,0x47b800cc}},	//   меро, _gedä_, _геһе, _আলহী, 
   {{0x9bb400ec,0xd04006be,0xf40000fe,0xbd9c0023}},	//   _عليڪ, _vilə, ৰ্মৰ_, _ውድቦም_, 
   {{0x44646fbb,0x44899502,0x629800c7,0x00000000}},	// [2ad40] овав, абан_, évom, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc2442ecb,0xf40003d4,0x9f5c0200,0x00000000}},	//   жнек, ৰ্ভৰ_, ravë_, --, 
   {{0x38bd9503,0xb5f80241,0xe820000d,0xcecc02dd}},	//   rîre_, _oláy, _बाडा_, _ﺗﺎﻻﺑ, 
   {{0x9f5d8c80,0x013473ab,0x2ba81bbb,0x78680205}},	//   mavé_, تعاد, _घुसा, _tüvt, 
   {{0xb878012c,0xcb0802ab,0x9f5c58f4,0xf40003d4}},	//   spív, _विंड_, lavé_, ৰ্বৰ_, 
   {{0xb5f80ca8,0xba3800e4,0x00000000,0x00000000}},	//   _aláy, moïv, --, --, 
   {{0x9f5c02fb,0xa02801d3,0x00000000,0x00000000}},	//   navé_, _گزرے_, --, --, 
   {{0xf65c01bf,0xb5f86293,0x86380092,0x00000000}},	//   _kiær_, _pláz, _ቢዝነስ, --, 
   {{0x22440784,0x9f5c0306,0x00000000,0x00000000}},	//   _hamk_, havé_, --, --, 
   {{0x9f5c02fb,0x00000000,0x00000000,0x00000000}},	//   kavé_, --, --, --, 
   {{0x2244002d,0x2c78045f,0x9f4c005b,0xfa8801e0}},	//   _jamk_, _rêde_, _vedä_, рсой_, 
   {{0x9f5c0306,0xba3800e4,0x41c8095f,0xfc640395}},	//   davé_, koïv, िधिस, _мъкн, 
   {{0x201d9504,0x22440113,0x95f41715,0xe82005c0}},	//   ngvi_, _lamk_, ेण्ट_, _बाणा_, 
   {{0x36882152,0x67d59505,0xf53c0267,0x224401f4}},	//   асан_, дору, _nyår_, _oamk_, 
   {{0x9f5c02bd,0x986400dd,0xa3c00f4a,0x6b78011a}},	//   ravè_, _کیسے_, ुधन_, _כרונ, 
   {{0x656001ab,0xd5c402a0,0x00000000,0x00000000}},	// [2ad50] _àmhl, लेंज, --, --, 
   {{0x88e002f5,0x224401c4,0x00000000,0x00000000}},	//   _বিচক, _aamk_, --, --, 
   {{0xe82030fd,0xb3099506,0x00000000,0x00000000}},	//   _बाता_, شغال_, --, --, 
   {{0xb4d80e89,0xd6780150,0x25c40790,0x7e7c0036}},	//   _bràt, _اڭسا_, örlü_, ëppl, 
   {{0xb4d800db,0x8658011a,0x00000000,0x00000000}},	//   _cràt, _הדרי, --, --, 
   {{0xcef406ed,0x2158007b,0x00000000,0x00000000}},	//   пчињ, تجمع_, --, --, 
   {{0xa30801d9,0x00000000,0x00000000,0x00000000}},	//   _ورٲے_, --, --, --, 
   {{0x1ea81129,0x8d642dbf,0x22640030,0xdea43b7a}},	//   يايي_, звие, ľská_, ویلی, 
   {{0xb4d80268,0x22640122,0xa194004e,0x00000000}},	//   _gràt, žská_, _жатч, --, 
   {{0xb4d801ab,0x4fc0005e,0x0c24004e,0x00000000}},	//   _hràs, _كەشە, чмон, --, 
   {{0x4aa80818,0xca6c01d5,0xf11801f9,0x00000000}},	//   йкон_, аkаt, _नमुद_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9f4c0158,0x6ee40139,0x9f5c0306,0xb8780113}},	//   _vedå_, _dıbe, vavé_, ypít, 
   {{0xb87801f1,0xdd940127,0x81c803d4,0x7ebc0200}},	//   dpís, _تجمع, োৰক_, mëpa, 
   {{0x9f5c7247,0x784c0153,0xc050010f,0x7ebc0200}},	//   tavé_, dėvė, עזל_, lëpa, 
   {{0x66d800df,0x6480000d,0xf1180073,0x090400d8}},	//   _aŭkc, _köig, _नमूद_, _епин, 
   {{0x9f5c0122,0x366400f5,0xdb14002f,0x201c0174}},	// [2ad60] ravé_, чато_, ßböd, ygvi_, 
   {{0xf504e2cc,0x22440309,0x9f5c02f0,0xb5c80150}},	//   янул_, _samk_, savé_, _ﻓﻭﻗﻌ, 
   {{0xb4d801e1,0x7ebc0240,0xb7d800d9,0x19e000d1}},	//   _bràs, hëpa, _לקיי, _ﺋﯩﭙﺎ, 
   {{0xf8bd9507,0xb4d80268,0xb8780008,0x7ebc0023}},	//   ntén_, _pràt, spít, këpa, 
   {{0xb4d80192,0x44240198,0x72001eeb,0xb878429f}},	//   _dràs, ƙo_, رووم, mpír, 
   {{0xdfd00451,0x9f34155b,0x6ac807b7,0x00000000}},	//   نڊا_, декі, रगुर, --, 
   {{0x44388c52,0xf8bc0098,0x80ac00eb,0x00000000}},	//   mep_, ktén_, টগল্, --, 
   {{0x44399508,0x6b54063f,0xb4d808c2,0x5d5402e8}},	//   lep_, _ọgb, _gràs, дкит, 
   {{0x201c0369,0x61e40784,0x00000000,0x00000000}},	//   pgvi_, ñilu, --, --, 
   {{0x44399509,0xb1402235,0x986c0064,0x00000000}},	//   nep_, _янул, ožą_, --, 
   {{0x59a469af,0x200d950a,0xb8780419,0x00000000}},	//   _गुजर, _iddi_, zpís, --, 
   {{0x4439950b,0x986c0064,0x00000000,0x00000000}},	//   hep_, ižą_, --, --, 
   {{0xc0c00201,0x4439950c,0x200c037e,0x648000c5}},	//   _ድረስ_, kep_, _kddi_, _köid, 
   {{0x4439950d,0xb4d80ba1,0x634c01e1,0x00000000}},	//   jep_, _oràr, _e̟ni, --, 
   {{0x4439950e,0x6b540241,0x940006be,0xd7c80472}},	//   dep_, _ẹgb, cihə_, زوره_, 
   {{0x986c0153,0x5ac802f2,0x00000000,0x00000000}},	//   džą_, _باتێ_, --, --, 
   {{0x200c00a9,0x443805be,0xe5340212,0xa4d80137}},	// [2ad70] _oddi_, fep_, неть, здуу_, 
   {{0x4439950f,0xb86400f1,0x49100118,0x00000000}},	//   gep_, _راخو, _तितो_, --, 
   {{0x7c3803cd,0xb87803b2,0x00000000,0x00000000}},	//   ietr, spís, --, --, 
   {{0x7c38325f,0x200d9510,0xba3800e4,0x00000000}},	//   hetr, _addi_, moïs, --, 
   {{0x44399511,0x504406ed,0xba380129,0x00000000}},	//   bep_, делб, loïs, --, 
   {{0x940000ac,0x7c38c1af,0xb4b0013d,0x00000000}},	//   yihə_, jetr, _чигә, --, 
   {{0xe820000d,0x00000000,0x00000000,0x00000000}},	//   _बासा_, --, --, --, 
   {{0x200d9512,0x7c380037,0x7ebc036e,0x00000000}},	//   _eddi_, eetr, tëpa, --, 
   {{0xccc43efe,0x7c3803d1,0x200c0165,0x1c180490}},	//   мбий, fetr, _fddi_, _दाखल_, 
   {{0x7c399513,0x20c001ab,0x7ebc036e,0xcc880212}},	//   getr, ròic_, rëpa, ібне_, 
   {{0xdb180356,0x3b8001c0,0xcb6823c5,0x7ebc036e}},	//   _azvâ, влэг, цане_, sëpa, 
   {{0x44399514,0x6ee405d1,0xba380ba1,0x26dc00e4}},	//   zep_, _tıbb, doïs, _évoi_, 
   {{0x7c399515,0x6e399516,0x629807ea,0xf8bd9517}},	//   betr, meub, évoi, rtén_, 
   {{0x7c399518,0xf8bd9519,0x6e380098,0x6480000d}},	//   cetr, stén_, leub, _köie, 
   {{0xf8bc0098,0x44396e25,0xc6900a81,0x942006be}},	//   ptén_, vep_, نِس_, _öpən_, 
   {{0xe8204688,0x6ba0054e,0xf8bc00e5,0x00000000}},	//   _बावा_, ăugă, ltél_, --, 
   {{0x4439951a,0x394000db,0x7e640254,0x00000000}},	// [2ad80] tep_, _аныг, ökpi, --, 
   {{0x2c78006a,0xf8bd951b,0x66d800df,0x9f4c00d0}},	//   _yêda_, ntél_, _eŭka, _vedú_, 
   {{0x4439951c,0xc2081a59,0xb87805f7,0x866802d3}},	//   rep_, ققان_, ppír, _ደገፍቲ_, 
   {{0x4439951d,0x7c39951e,0xd3c40131,0x64800254}},	//   sep_, zetr, رتلى, _söid, 
   {{0x6605951f,0x443871dd,0x64800037,0x7c399520}},	//   maik, pep_, _pöid, yetr, 
   {{0x66059521,0x7c399522,0x03a40c17,0x00000000}},	//   laik, xetr, _жиго, --, 
   {{0xdfd000c6,0xc3741291,0x660401f4,0xb7d800eb}},	//   ديث_, _غُرب, oaik, _বড়ুয়, 
   {{0x6e380c6a,0x7f740124,0x7c380332,0x00000000}},	//   geub, зуҩц, wetr, --, 
   {{0x6480005b,0x9f5c02f0,0x7e98031c,0xa7a80092}},	//   _töid, maví_, nċpi, ቀላጠፈ_, 
   {{0x66059523,0xb908002b,0x7c38017a,0x9f5d9524}},	//   haik, _itiḥ_, uetr, laví_, 
   {{0x34d80316,0xb824009e,0x6e3800d5,0xeb940798}},	//   _बढ्द, য়মত_, beub, диќ_, 
   {{0x66059525,0x6e38003e,0x7dc400db,0x00000000}},	//   jaik, ceub, _ققان, --, 
   {{0x7c399526,0x7c6400d1,0xfd740035,0x00000000}},	//   petr, _ياتل, _تداخ, --, 
   {{0xa3c0412f,0x6c5000db,0xeb8c072d,0x00000000}},	//   ुधा_, _акшу, اظی_, --, 
   {{0xe8219527,0x66059528,0x163400a7,0xfaa401a9}},	//   _बारा_, faik, невя, _ошин, 
   {{0x66059529,0x9f5c0030,0xba380129,0x00000000}},	//   gaik, javí_, roïs, --, 
   {{0xfd500882,0x290401fa,0x9f5c0419,0x00000000}},	// [2ad90] treṇ, šmar_, daví_, --, 
   {{0x66040066,0xcb9401b9,0x03dc0055,0x69c0000d}},	//   aaik, _آچیش_, _kūṭe, ümee, 
   {{0x660485d3,0xf8bc03b7,0x5214a641,0xfe540113}},	//   baik, ntém_, едет, la鯵a_, 
   {{0xe1f0006c,0x6605952a,0xb4d80ffb,0xfd5c001e}},	//   لسه_, caik, _fràp, _quyể, 
   {{0xc614025f,0x50b43c1b,0xb4d800a3,0xfe540784}},	//   _אחרי_, нску, _gràp, na鯵a_, 
   {{0xa0c431b1,0x00000000,0x00000000,0x00000000}},	//   نينو, --, --, --, 
   {{0xfd5c07ae,0x9f5c02fb,0x6e38003e,0xaca00208}},	//   _tuyể, baví_, teub, xuốn, 
   {{0xf40000fe,0x00000000,0x00000000,0x00000000}},	//   ৰ্শৰ_, --, --, --, 
   {{0x0c944855,0xe8211f14,0xf8bce183,0x8c940212}},	//   ешня, _बाला_, ttél_, ерні, 
   {{0x6605952b,0x6ac8bc82,0x6e380098,0xbac00116}},	//   zaik, रग्र, seub, ﺩﯨﺸﺎ, 
   {{0x6605952c,0xaca001f2,0x61e40219,0x00000000}},	//   yaik, _nzụk, žile, --, 
   {{0x3d080024,0x756c0023,0x6f0c00cd,0x9f5808a5}},	//   _žuvų_, _በጺሕዎ_, _ācch, _þrá_, 
   {{0xaca001f2,0x6605952d,0x3d2851ae,0x8274010f}},	//   _azụk, vaik, _فتوی_, גערע_, 
   {{0x6605952e,0x20c001ab,0xa9e402dd,0xe8200073}},	//   waik, hòin_, _ﺍﯞﯨﺴ, _बाळा_, 
   {{0x6605952f,0x9be402bf,0x07b800ae,0xf8bc01ef}},	//   taik, _річк, سهرة_, ctém_, 
   {{0x3dc400cc,0x660401f4,0x00000000,0x00000000}},	//   _ষ্টল, uaik, --, --, 
   {{0x66059530,0x245403e6,0x00000000,0x00000000}},	// [2ada0] raik, پۆزس, --, --, 
   {{0x69c59531,0x55c51c40,0xb4d801e1,0x3ec800b8}},	//   _izie, тауғ, _isàl, _mṛṇm, 
   {{0x66059532,0x9f5c0122,0x69c4031c,0x20c001ab}},	//   paik, taví_, _hzie, fòin_, 
   {{0xb4d8026c,0x4104020f,0x4128004e,0x41c401a9}},	//   _tràp, ездв, зодо_, нёла, 
   {{0x9f5c031d,0x6aa4009f,0x6ee40166,0x15b838be}},	//   raví_, _mjif, _rıba, _жыры_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x645d9533,0xdd0405d1,0x37d8008f,0x65640009}},	//   _inri, _ısır, פֿגע, lxih, 
   {{0x03a4036b,0x1d3400a7,0x6aa4036e,0xb22000ec}},	//   _жиҳо, вния, _njif, _مڙهي, 
   {{0x6280426d,0xdd90034c,0xbc241a59,0x645c0194}},	//   _ilmo, شود_, ىردى, _knri, 
   {{0x6aa401c8,0x3b040241,0x399400c5,0x00000000}},	//   _ajif, _nípá_, _धs_, --, 
   {{0x69c40c04,0x60c803ac,0xb414010f,0x00000000}},	//   _azie, _ihdm, עקטס_, --, 
   {{0x69c4031c,0xb5f801e1,0xfce401c0,0xfe540113}},	//   _bzie, _inág, _зодо, ta鯵a_, 
   {{0xf8bc0e96,0xcfd40011,0x645c01e1,0x76980139}},	//   stém_, _স্পন, _onri, häyä, 
   {{0x69c59534,0xba3806af,0xf770007b,0x6da00063}},	//   _dzie, roïq, هاز_, _љиља, 
   {{0x77916657,0x6280036b,0xf8bc01ed,0xe78400d8}},	//   ایجا, _olmo, lték_, гуто, 
   {{0xba7419bc,0x645d9535,0x7ac4a90c,0xf6500137}},	//   _ساعت, _anri, _ясле, دئس_, 
   {{0x645c01ab,0xf7e800f7,0x00000000,0x00000000}},	// [2adb0] _bnri, _ىردى_, --, --, 
   {{0xe4b802dd,0x27f400d0,0x58d401af,0x00000000}},	//   елуі_, čaní_, _шопт, --, 
   {{0x41ec063f,0x68b8010f,0x7ebc0200,0xe4a47a9c}},	//   _ịsị_, _אלזא_, tëpl, урто, 
   {{0xe29802bf,0xf8bc0c6a,0x00000000,0x00000000}},	//   нає_, kték_, --, --, 
   {{0x20c001c3,0x7ebc0200,0x60e80150,0x00000000}},	//   ròin_, rëpl, емім_, --, 
   {{0x62819536,0xb9f802d3,0xcf58014b,0xa9240306}},	//   _elmo, _መጸ_, дрич_, ýživ, 
   {{0x09ac0073,0x7dc401d5,0x00000000,0x00000000}},	//   _घड्य, lаsh, --, --, 
   {{0x628001ab,0xadc001e0,0x216402dd,0xb8240011}},	//   _glmo, лайһ, _өтуг, য়িত_, 
   {{0x61e409a8,0x645c1368,0xf1bc0241,0x00000000}},	//   žilc, _ynri, _áá_, --, 
   {{0x69c4031c,0xcdc43cc1,0xa1940114,0x0ae800db}},	//   _rzie, наққ, _сауч, мдой_, 
   {{0xb82439db,0x6ee400c6,0x9f5c00d8,0x8ba401d5}},	//   য়াত_, _أسئل, ravã_, тинж, 
   {{0x26f000bd,0x0d98010b,0x8a0402e8,0x62804268}},	//   _ছিলো_, _отлы_, ъзме, _xlmo, 
   {{0xb4d801e1,0x9f5c0122,0x8c4400c7,0xc7640131}},	//   _asàm, mavá_, _аеле, ھاسى, 
   {{0x628802d5,0x1cc00003,0xc7642e51,0x66d800df}},	//   _įdom, _ཁེར_, پاسى, _eŭkl, 
   {{0x69c4012d,0x940403e3,0x7c901291,0x00000000}},	//   _wzie, _ölə_, _خلوص, --, 
   {{0x6aa46a6c,0x69c4005a,0x2b440175,0x20c001ab}},	//   _ujif, _tzie, _isnc_, eòil_, 
   {{0x69c46dde,0x04480276,0xdb0801d3,0x75d04138}},	// [2adc0] _uzie, мпак_, ülöz, ليفا, 
   {{0x814404d3,0xba3800a9,0x68e55275,0x9f5c02f0}},	//   ێنان, mnïa, _iuid, havá_, 
   {{0x43859537,0x68e43441,0x9f5cb830,0x1cc00003}},	//   خلاق, _huid, kavá_, _ཁེལ_, 
   {{0x68e4033d,0xded00020,0x66d80241,0x9f5c0109}},	//   _kuid, ቦችን_, _dúkì, vavà_, 
   {{0x68e59538,0x9f5c0306,0x04b40006,0x40841171}},	//   _juid, davá_, _асвя, кукб, 
   {{0x443d9539,0x68e5953a,0x645d953b,0x3e4c0208}},	//   _út_, _muid, _unri, _ột_, 
   {{0xcfd40729,0x68e5953c,0x3898008f,0x628000d0}},	//   _স্বন, _luid, ויסנ, _tlmo, 
   {{0xf8bd45db,0x2900016b,0x68e46a89,0xb9c8001f}},	//   tték_, _owia_, _ouid, _ሰፋ_, 
   {{0xc0e400d6,0x68e5953d,0x2900013f,0xad200131}},	//   _розк, _nuid, _nwia_, لىيى, 
   {{0x63bd953e,0xf8bc01ed,0x656000a3,0x6ee403e0}},	//   _kyrn, rték_, _àmhu, _kıbl, 
   {{0x2900016b,0x68e43335,0xf8bc01d3,0x79bc00d1}},	//   _awia_, _auid, sték_, ﺠﺘﯩﻤ, 
   {{0x68e40013,0x9f4c29ef,0x63bc062c,0xeaf401ed}},	//   _buid, _medü_, _myrn, کریت_, 
   {{0x68e47ea6,0x3ea40649,0x7dc4036b,0x63bc003a}},	//   _cuid, _ijot_, kаsi, _lyrn, 
   {{0x68e5953f,0xa8a59540,0x63bc03b2,0x9abc025c}},	//   _duid, арск, _oyrn, duċe, 
   {{0xeb44d687,0x68e40381,0xf5e41cb8,0x7dc4022e}},	//   _ачык_, _euid, візм, dаsi, 
   {{0x34d805ba,0x68e49218,0x99845085,0x66e400d8}},	//   बद्द, _fuid, _ملعو, роѓа, 
   {{0x68e59541,0x63bc0363,0x98b8d3a6,0x7dc4022e}},	// [2add0] _guid, _ayrn, _плит_, fаsi, 
   {{0x63bc06a3,0x1cc0031c,0x3ea40fac,0x64800037}},	//   _byrn, _ཁེས_, _ljot_, _pöia, 
   {{0x68e4432f,0x9f4c0793,0x63bd9542,0xa1f0063f}},	//   _zuid, _cedü_, _cyrn, _ịhọt, 
   {{0x63bd6971,0x8778008f,0xe2f80212,0x1b2400fe}},	//   _dyrn, _נארי, теці_, _বনাই_, 
   {{0xf8bc0548,0x9f5c0306,0x63bc01a8,0x00000000}},	//   ttéh_, vavá_, _eyrn, --, 
   {{0x8fa482fa,0x63bd9543,0x3ea40108,0x00000000}},	//   лале, _fyrn, _ajot_, --, 
   {{0x61e41467,0xf65c4e95,0x3dc4010e,0x63bcd17e}},	//   žila, _knæ_, _azow_, _gyrn, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9f5c0122,0x00000000,0x00000000,0x00000000}},	//   ravá_, --, --, --, 
   {{0x68e4cb04,0x6da19544,0x3ea400e2,0xada000d1}},	//   _ruid, лиқа, _ejot_, лақл, 
   {{0x68e59545,0x3b0c0784,0x5f741291,0x00000000}},	//   _suid, _cvfq_, _پالر, --, 
   {{0x68e59546,0xff78010f,0x7dc401a9,0x98b80055}},	//   _puid, _אטעמ, zаsi, _āyād_, 
   {{0x68e59547,0xddc002f0,0x00000000,0x00000000}},	//   _quid, jemň, --, --, 
   {{0xf99c020c,0xb0c02e05,0xba380142,0x00000000}},	//   maèl_, षतिग, rnïa, --, 
   {{0x68e4039a,0x00000000,0x00000000,0x00000000}},	//   _wuid, --, --, --, 
   {{0x8ee42158,0x55f4009d,0x00000000,0x00000000}},	//   _নবাগ, ичуу, --, --, 
   {{0x2a6001d5,0x63bc01bf,0x7dc401a9,0xc4c868eb}},	// [2ade0] _inib_, _syrn, tаsi, елаж_, 
   {{0xded0001f,0x00000000,0x00000000,0x00000000}},	//   ቦችና_, --, --, --, 
   {{0x2a6001bf,0x7dc401d5,0x00000000,0x00000000}},	//   _knib_, rаsi, --, --, 
   {{0x26b40075,0xab6802d3,0x3f800374,0x63bc0076}},	//   _ئەرز, ድልዳል_, _āku_, _vyrn, 
   {{0xdb1801ef,0x00000000,0x00000000,0x00000000}},	//   _vyvé, --, --, --, 
   {{0x26c19548,0x8c180729,0xc30400c6,0x63bc005b}},	//   llio_, ত্তন_, _مبرو, _tyrn, 
   {{0x44298e66,0xb5f800e4,0x9f4c004e,0x2a6001d5}},	//   _icb_, _koáp, _redó_, _onib_, 
   {{0xb5f99549,0x26c033e7,0x9d143dc8,0x9f4c00db}},	//   _inác, nlio_, адич, _sedó_, 
   {{0xd29057be,0x26c0e57d,0xf8bc004a,0x95180327}},	//   _بینظ, ilio_, luée_, ུངགི_, 
   {{0x442800b5,0x9b580cfc,0x2a61954a,0xd40001e1}},	//   _jcb_, виот_, _anib_, _è̟tó_, 
   {{0x26c00006,0x2a60020b,0x9f4c067c,0x3f8800cc}},	//   klio_, _bnib_, _vedó_, _åbu_, 
   {{0x7ebc0200,0x00000000,0x00000000,0x00000000}},	//   këpi, --, --, --, 
   {{0x4429954b,0x9f4c007f,0x29841999,0x26c00064}},	//   _ocb_, _gedò_, бырг, dlio_, 
   {{0x26c01730,0x1bd40314,0x7d000ca8,0x2ca4036e}},	//   elio_, _коля, _iwos, _gjnd_, 
   {{0x7d000433,0xd67c0150,0x7bd000cc,0x00000000}},	//   _hwos, _ﺤﻀﻭﺭ_, _দ্ৰো, --, 
   {{0x26c0156b,0x4429954c,0x7d01954d,0x7cd80055}},	//   glio_, _acb_, _kwos, _dārś, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [2adf0] --, --, --, --, 
   {{0x44280f64,0x7d0004ba,0x52ac00af,0x33844965}},	//   _ccb_, _mwos, टक्स, луев, 
   {{0x26c103c1,0x7c280407,0xf8bc004a,0xd9980451}},	//   blio_, _mcfr, guée_, _سنگت_, 
   {{0x61e449ad,0x7d00009a,0x26c1564d,0x00000000}},	//   žiln, _owos, clio_, --, 
   {{0x3ce4011c,0xe81c012c,0xf0740075,0xa158187f}},	//   _nuov_, _भएमा_, лидә_, лацу_, 
   {{0x8f1535ea,0x9f4c0086,0x764cadd3,0xf8bc004a}},	//   афич, _redò_, _hacy, buée_, 
   {{0x764d6b30,0x7d01954e,0xb5f800c6,0x59d40490}},	//   _kacy, _awos, _gnác, ठेतर, 
   {{0x04182158,0x7d00015c,0x8e547707,0x8db400d4}},	//   ন্দী_, _bwos, рткі, испі, 
   {{0x4c85954f,0xd0400085,0x7d0405f5,0x2a602b52}},	//   илив, _bilɔ, аныг_, _rnib_, 
   {{0x38bc006a,0xf99d9550,0xc0f40023,0x764d9551}},	//   bîri_, raèl_, ገኖም_, _lacy, 
   {{0x7d00013f,0x26c000a9,0x764c0076,0xb4d801e1}},	//   _ewos, ylio_, _oacy, _ipàd, 
   {{0x764d5c49,0xe1040055,0x00000000,0x00000000}},	//   _nacy, _īdṛṅ_, --, --, 
   {{0x7d0002bd,0x69d800df,0x00000000,0x00000000}},	//   _gwos, _ŝveb, --, --, 
   {{0x8ac40046,0x6d499552,0x26c00368,0x7cd800dc}},	//   ыққа_, _isga, wlio_, _pārś, 
   {{0x44299553,0x764c0796,0x6d48003e,0x26c00841}},	//   _rcb_, _bacy, _hsga, tlio_, 
   {{0x44299554,0x7ebc044e,0x26c19555,0x2a6001a9}},	//   _scb_, tëpi, ulio_, _unib_, 
   {{0xf5e48f99,0x764c00b5,0x05659556,0x9a2404b3}},	// [2ae00] рмул_, _dacy, шван, _اعىن, 
   {{0x26c01326,0xf8bc20ef,0xb460cda6,0xb89000e3}},	//   slio_, tuée_, окул, _وليع, 
   {{0x26c004cf,0x764cf3ff,0x44299557,0x4344068e}},	//   plio_, _facy, _vcb_, реев, 
   {{0xd36c2928,0x6d493c2d,0x764d9558,0xd25800d4}},	//   رۇق_, _osga, _gacy, лці_, 
   {{0x61e400f3,0x601835dd,0x00000000,0x00000000}},	//   žilo, голя_, --, --, 
   {{0x764d9559,0x4429955a,0x7d01955b,0x38bc00e4}},	//   _zacy, _ucb_, _rwos, tîri_, 
   {{0x6d49955c,0xf8bc20ef,0x764d955d,0x7dc401d5}},	//   _asga, quée_, _yacy, hаst, 
   {{0x7d000699,0xf3f0031c,0x00000000,0x00000000}},	//   _pwos, _བཅོད_, --, --, 
   {{0x7c280115,0x69c1955e,0xdcb8004e,0x00000000}},	//   _pcfr, ümel, лгич_, --, 
   {{0xf8bc7c70,0xb02400db,0xf53400df,0x00000000}},	//   ntét_, _ەكەم_, סטיר_, --, 
   {{0xe82029c8,0x7ac51518,0xfe440b7e,0x00000000}},	//   _बाजा_, исме, _внео, --, 
   {{0x7d018e3b,0x41a80073,0x00000000,0x00000000}},	//   _twos, _कशास, --, --, 
   {{0x7e6169b6,0x7d0000ca,0xb8b4007b,0x9d19955f}},	//   _inop, _uwos, لإست, _солт_, 
   {{0x764caf78,0xf1d801ec,0x00000000,0x00000000}},	//   _sacy, _ﻁﺭﻴﻘ, --, --, 
   {{0xfa34005e,0x764c1684,0x6ee40166,0x38700139}},	//   _күні_, _pacy, _rıbk, _voxr_, 
   {{0x962006ab,0x6d487999,0xda701e2f,0xaa8800db}},	//   यलेट_, _ysga, _رُخ_, _ۅنۉم_, 
   {{0x648001f4,0x764c00b8,0x00000000,0x00000000}},	// [2ae10] _töil, _vacy, --, --, 
   {{0x764d9560,0x7e600175,0x0418015b,0xd30001ec}},	//   _wacy, _lnop, ন্সী_, уiпс, 
   {{0x7e619561,0xf3659562,0x764c0784,0x00000000}},	//   _onop, штан, _tacy, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x463800c8,0x27ec01f1,0x798c0399,0x7f58008e}},	//   _גערע, ždne_, nzcw, _artq, 
   {{0x7e61556e,0x67540811,0x648001f4,0xd5840133}},	//   _anop, _اخیر, _yöim, _پێڕه_, 
   {{0x660c0598,0xf8bd1d36,0x5fd40395,0x00000000}},	//   _ölkä, ltés_, оцъф, --, 
   {{0x7ebc044e,0xc3300302,0x00000000,0x00000000}},	//   këpu, _מול_, --, --, 
   {{0xf8bd1d36,0x00000000,0x00000000,0x00000000}},	//   ntés_, --, --, --, 
   {{0x4c84ccfb,0xf8bc07ea,0x7e619563,0x00000000}},	//   слов, ités_, _enop, --, 
   {{0x09e59564,0x00000000,0x00000000,0x00000000}},	//   йонн, --, --, --, 
   {{0x46e801a9,0x00000000,0x00000000,0x00000000}},	//   ғдан_, --, --, --, 
   {{0x29042508,0x49980212,0x6d4803ac,0xf8bc01d3}},	//   èma_, утня_, _usga, jtés_, 
   {{0x1cc0031c,0xfd54011a,0xe738035b,0x8b6400f2}},	//   _ཁེག_, _לשני_, аҵо_, _هاعم, 
   {{0x17799565,0xbd5404d3,0xcaf59566,0x7e6002d0}},	//   асть_, _پرۆژ, _استب, _ynop, 
   {{0xf3f02fb5,0x3f78010f,0x6480000d,0x00000000}},	//   _བཅུད_, אָמע, _vöim, --, 
   {{0xf8bc4e82,0x00000000,0x00000000,0x00000000}},	// [2ae20] ttét_, --, --, --, 
   {{0x8c180154,0xceb801ef,0x00000000,0x00000000}},	//   ত্রন_, hoř_, --, --, 
   {{0x48ec0c66,0xdc0c0154,0x00000000,0x00000000}},	//   _इंडो_, _শামস_, --, --, 
   {{0x64800254,0x42080137,0xf7700753,0xf8bc00e5}},	//   _köik, ундо_, _راپ_, stét_, 
   {{0xf8bd9567,0xb6a00116,0x80e00118,0xb110003b}},	//   ctés_, _хиял, खदेख_, зміш, 
   {{0x7e6161a1,0x7af805b1,0x9f5c00d0,0xf8bc8677}},	//   _snop, yptt, mavú_, ltér_, 
   {{0x43840491,0xaee00a28,0xf8bc0008,0x9f3401ec}},	//   _الأق, viṣa, bréf_, цейі, 
   {{0xf8bd9568,0x77601709,0x1cc0031c,0x7dc4022e}},	//   ntér_, _ánxe, _ཁེང_, xаss, 
   {{0xf6500375,0xdb180308,0x8bf800cc,0x9f5c00d7}},	//   לצה_, _vyví, _আয়ন_, navú_, 
   {{0x5b159569,0xf8bc01d3,0xbc4828e8,0xe29802dd}},	//   омот, mrég_, учие_, _сағ_, 
   {{0x9c9400b8,0xf8bc00e5,0xceb8013a,0x00000000}},	//   _cvāṣ, ztés_, boř_, --, 
   {{0x7e600433,0x9c9400b8,0x7ebc036e,0x9f5c00d7}},	//   _unop, _dvāṣ, tëpu, kavú_, 
   {{0x9c940055,0x7b640014,0x298400cf,0x00000000}},	//   _evāṣ, _گاشٕ, пырг, --, 
   {{0xdcb005a9,0xf99c0100,0x9b5801af,0x580400be}},	//   _تىت_, ybèf_, _викт_, توسك, 
   {{0xaf8002d3,0xec34011a,0xe5c40022,0x00000000}},	//   _ጐይታና_, _האור_, ҧсуо, --, 
   {{0xf96806bb,0xb5f800d2,0x648002b5,0xe6940a8f}},	//   _брой_, _enán, _höih, писы, 
   {{0xf8bc0231,0x7ae940e1,0x549802d5,0x962800e2}},	// [2ae30] utés_, _huft, аваў_, _riņķ, 
   {{0xf8bd956a,0xb9f40201,0xf805956b,0x7ae9956c}},	//   rtés_, _ሙሉ_, _учин, _kuft, 
   {{0xf1a46833,0xb9d0044e,0xf8bca4e8,0x7ae801b9}},	//   әрен, _ኹሉ_, stés_, _juft, 
   {{0xb4d801e1,0xf8bd956d,0xd9f800af,0x94440050}},	//   _asàt, ptés_, ंडित_, _ژھان, 
   {{0x7ae9956e,0x94d407b5,0xd00806ed,0x96280171}},	//   _luft, _момц, аеле_, _viņķ, 
   {{0xb7f805d7,0x7bc40034,0x205400a7,0x656001e7}},	//   ्रिम_, ękuj, зтър, _ámha, 
   {{0x287c008f,0xd9f80073,0xceb800bc,0xa87c00df}},	//   רנומ, ंडात_, toř_, ראור, 
   {{0x623513dc,0xe28400d8,0x69c00254,0x00000000}},	//   _несу, _еѓун, ümek, --, 
   {{0xd130021a,0x7ae8fac1,0x320c0209,0xa0c42756}},	//   _زما_, _auft, magy_, _کيلو, 
   {{0xd0106ea9,0x7ae95032,0x0b5805a2,0x320c00ee}},	//   _آلا_, _buft, армы_, lagy_, 
   {{0x7ae80ba7,0x4aa8adc9,0xf8bc00e4,0x3ea801e7}},	//   _cuft, икон_, ytér_, úité_, 
   {{0xcc8878dd,0x320d956f,0x00000000,0x00000000}},	//   انگه_, nagy_, --, --, 
   {{0x6ee4000f,0x6dc42f56,0x4c340153,0x00000000}},	//   _dűbe, _ازال, _дэйт, --, 
   {{0x7ae80ba7,0xf41c015b,0x6480000d,0x9c94002b}},	//   _fuft, ন্তর_, _vöik, _tvāṣ, 
   {{0x7ae80548,0x86999570,0x37e19571,0xf8bc01d3}},	//   _guft, атат_, дорг, ttér_, 
   {{0x84680092,0x4df8010f,0x648001f4,0x320c0432}},	//   _በማመን_, שפּא, _töik, jagy_, 
   {{0xf8bc0450,0x61e42a92,0xb6a0070e,0x320c010b}},	// [2ae40] rtér_, žilk, фитл, dagy_, 
   {{0xf8bd9572,0x03a42f33,0xb5f8307d,0x7ae8011f}},	//   stér_, оизо, _unán, _yuft, 
   {{0xf8bc0518,0xc1e800a7,0x7ae801a9,0x00000000}},	//   ptér_, адеж_, _xuft, --, 
   {{0x09dc015b,0xdb1800e4,0xaabc27c6,0x00000000}},	//   _ভ্যা, _jyvá, ैतिक, --, 
   {{0xf8bc0098,0x7ebc036e,0xfcd00092,0xa158c7b0}},	//   bréd_, këpr, _የወጪ_, салу_, 
   {{0x6b54063f,0x9ed800d1,0x00000000,0x00000000}},	//   _ụgw, әмит_, --, --, 
   {{0xdb180022,0xf8bc003e,0x320c010e,0x00000000}},	//   _oyvá, kuén_, bagy_, --, 
   {{0xf41c00bd,0x7ae99573,0x99980030,0x00000000}},	//   ন্দর_, _ruft, lesť_, --, 
   {{0x69c59574,0xd200004e,0x00000000,0x00000000}},	//   _nyie, _чүчк, --, --, 
   {{0xb5f874c3,0xf8bc06af,0x270806be,0x00000000}},	//   _anál, orée_, kşn_, --, 
   {{0x69c59575,0x2c78002d,0x7e9401d9,0xf8bc0129}},	//   _ayie, _rêdt_, _وۆتر_, nrée_, 
   {{0xf8bc172e,0x69c57ef6,0xfce59576,0x7ebc0036}},	//   guén_, _byie, _додо, rëps, 
   {{0x648002f6,0x200c03ee,0xac7003e6,0xf8bc0129}},	//   _töih, _kedi_, سایش, hrée_, 
   {{0x7ae99577,0x39480142,0x99980419,0x00000000}},	//   _tuft, rwcs_, jesť_, --, 
   {{0x200d9578,0x2b14012c,0x00000000,0x00000000}},	//   _medi_, _थिएँ_, --, --, 
   {{0x200d9579,0xf8bc2a78,0x1cc00327,0x00000000}},	//   _ledi_, drée_, _ཁེཌ_, --, 
   {{0xe535957a,0x200c03cb,0x443803b2,0xd37000f2}},	// [2ae50] меть, _oedi_, ffp_, کها_, 
   {{0x200d957b,0xb5f80241,0x7c380393,0x26cc00cf}},	//   _nedi_, _inám, nftr, ïdor_, 
   {{0xf8bc07ea,0x00000000,0x00000000,0x00000000}},	//   grée_, --, --, --, 
   {{0x1080005e,0x200c003a,0x00000000,0x00000000}},	//   ﯩﺰﺩﯨ, _aedi_, --, --, 
   {{0x200d957c,0xf4840a5b,0xca800023,0xf77001c8}},	//   _bedi_, _дувн, ርኽኩም_, _راھ_, 
   {{0x200d957d,0x37dc015b,0xf8bc7f70,0xc578123b}},	//   _cedi_, _ব্যর, brée_, _הרשת, 
   {{0x200d957e,0xf8bc07ea,0xb4d44e8f,0x00000000}},	//   _dedi_, crée_, ागी_, --, 
   {{0x200c0248,0x7c38002d,0x700800eb,0xdb240241}},	//   _eedi_, eftr, রলেও_, _òsùp, 
   {{0x200d957f,0x6cb00137,0x00000000,0x00000000}},	//   _fedi_, мөкт, --, --, 
   {{0x200d9580,0xdb1800e4,0x50940592,0xf0b80345}},	//   _gedi_, _syvá, _علاء, _ئارش_, 
   {{0x69c4138f,0xb5f801e1,0x7ebc0023,0xf8bc003e}},	//   _syie, _anám, rëpr, tuén_, 
   {{0x200d9581,0x7c3801a4,0xeb340092,0x00000000}},	//   _zedi_, aftr, _እያገለ, --, 
   {{0x200d9582,0xaca00521,0xdb180122,0x20c0068c}},	//   _yedi_, _ahụh, _vyvá, mòir_, 
   {{0x20c000a3,0x00000000,0x00000000,0x00000000}},	//   lòir_, --, --, --, 
   {{0x2aa401ed,0xf8bc0214,0x99980419,0x6d596310}},	//   rűbb_, muél_, vesť_, lvua, 
   {{0x61e41711,0xf8bd9583,0xfb18011a,0x00000000}},	//   žili, quén_, _הוקמ, --, 
   {{0xc4859584,0x6d5801e4,0x00000000,0x00000000}},	// [2ae60] плак, nvua, --, --, 
   {{0xf8bd9585,0x1cc0025c,0x75d00fb4,0x25e80037}},	//   trée_, _ཁེབ_, ريلا, _झलकी_, 
   {{0xb5f803c6,0x200d9586,0xf8bc004a,0x273400cf}},	//   _znám, _redi_, urée_, _تۉزس, 
   {{0x200d9587,0xf8bc07ea,0x44380204,0x7bcc025c}},	//   _sedi_, rrée_, sfp_, żbug, 
   {{0x66059588,0x200d9589,0x6d580218,0xf65c00b5}},	//   mbik, _pedi_, jvua, _skæg_, 
   {{0x6605958a,0x6fb000f1,0x00000000,0x00000000}},	//   lbik, ډمها, --, --, 
   {{0x200c43df,0x764001ed,0xb4d801e1,0x69d800df}},	//   _vedi_, őnye, _isàp, _ŝvel, 
   {{0x200c1649,0x6604f6e6,0xefb001b9,0xfcd00092}},	//   _wedi_, nbik, رینگ, _የወጡ_, 
   {{0xc104d82e,0x200d958b,0xc0e80014,0x1cc00327}},	//   _رواي, _tedi_, _طفان_, _ཁེད_, 
   {{0x7c3803fa,0x6e380083,0x5f780014,0x20c001ab}},	//   uftr, afub, _وۅشس_, ròis_, 
   {{0xb5f800c6,0x00000000,0x00000000,0x00000000}},	//   _snám, --, --, --, 
   {{0x3a3c00ee,0x66040010,0xfa88005b,0xcf24009f}},	//   ýup_, jbik, ссой_, _آرلي, 
   {{0x6298004a,0xc4bc033f,0x3dd00354,0x00000000}},	//   évoy, ्ताओ, _чιаг, --, 
   {{0xb4d801e1,0x66040083,0x00000000,0x00000000}},	//   _apàn, ebik, --, --, 
   {{0x6af00597,0x3dc4039a,0x395c01e4,0x368801d5}},	//   _كثير, _hyow_, ŭus_, бсан_, 
   {{0xb4d80241,0x6605869b,0x6ee405d1,0x00000000}},	//   _asàp, gbik, _kıbr, --, 
   {{0x5454013e,0x42a4069d,0x75800244,0xe695958c}},	// [2ae70] мват, ላዊነት_, ریسم, хиты, 
   {{0xb4d4543b,0xfcd0001f,0x660429f1,0xe5080472}},	//   ागे_, _የወጣ_, abik, سيمو_, 
   {{0x92581de1,0x56941c3e,0x1cc0025c,0x6605958d}},	//   жает_, _жант, _ཁེན_, bbik, 
   {{0x764000e5,0x00000000,0x00000000,0x00000000}},	//   őnyb, --, --, --, 
   {{0xdb180664,0x50d40214,0x50b4bcf8,0x00000000}},	//   _hyvä, وزتر, мску, --, 
   {{0x94d401c0,0x64800108,0x212000e4,0x2ff000db}},	//   _цогц, _söiv, áiha_, رتتڭ, 
   {{0xdb1802f6,0x6e38192e,0x7ebc01c7,0x00000000}},	//   _jyvä, tfub, tëpp, --, 
   {{0xe1f069ef,0x77f80254,0x00000000,0x00000000}},	//   _مسك_, ्रुक_, --, --, 
   {{0x9f5c0122,0x6e380008,0xa194010b,0x7ebc01c7}},	//   mavý_, rfub, _затч, rëpp, 
   {{0x6d59958e,0x3dc40204,0x66040023,0x986c00c0}},	//   rvua, _dyow_, zbik, mžė_, 
   {{0xf8bc03b7,0x6e380230,0x6d580e03,0xdfe8030d}},	//   guém_, pfub, svua, _хьул_, 
   {{0x3dc40204,0x9f5c0306,0x00000000,0x00000000}},	//   _fyow_, navý_, --, --, 
   {{0x64800037,0x00000000,0x00000000,0x00000000}},	//   _köit, --, --, --, 
   {{0xf8bc0077,0xb4d800a3,0x9f5c0306,0x3c60519b}},	//   quél_, _spàn, havý_, _акшг, 
   {{0x6605958f,0xca740276,0x9f5c0306,0x00000000}},	//   tbik, _жупы, kavý_, --, 
   {{0xb66400d1,0x6604000d,0x17c400c7,0x00000000}},	//   мисз_, ubik, хасҭ, --, 
   {{0x9f5c02fb,0x35a001a9,0x00000000,0x00000000}},	// [2ae80] davý_, ватг, --, --, 
   {{0x6604036e,0x00000000,0x00000000,0x00000000}},	//   sbik, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x224009a5,0x81880228,0xf7700375,0x00000000}},	//   ýik_, يناق_, _סקר_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb5f80789,0x74e402bf,0xdfd401c6,0x00000000}},	//   _anáh, _одяг_, нолы, --, 
   {{0xba38000f,0xd24c0014,0x6e4000d1,0x00000000}},	//   diïn, _گۆن_, چنىم, --, 
   {{0xb1400daf,0xf474001f,0x26c10028,0x5d542c08}},	//   хнәл, _በማሰብ_, noio_, екит, 
   {{0xf1c0516c,0xd24c01d9,0x26c000b0,0xe3b00154}},	//   _айтп, _دۆن_, ioio_, _করিব, 
   {{0xd14801d9,0x27f80175,0x00000000,0x00000000}},	//   _عشقن_, jcrn_, --, --, 
   {{0xda34652e,0x9abc031c,0x7f840345,0x00000000}},	//   нены, luċi, _تلان, --, 
   {{0xbd440597,0xf8bc5941,0xba38002d,0x1cc0031c}},	//   _يناي, dréa_, aiïn, _ཁེམ_, 
   {{0x26c002e8,0xdb1802f6,0xceac00ec,0xf770210e}},	//   doio_, _syvä, _دڙو_, ھاس_, 
   {{0xf7719590,0xb5f801e7,0x64800254,0xed4c00f1}},	//   پاس_, _inái, _möis, _خپه_, 
   {{0xdb1805ac,0xd7c8027d,0xe7580212,0x648001f4}},	//   _byvå, سوره_, мирі_, _löis, 
   {{0xf84405f5,0x26c0011c,0x00000000,0x00000000}},	//   чүүд_, goio_, --, --, 
   {{0x9f5c0306,0x3af80055,0x00000000,0x00000000}},	// [2ae90] vavý_, _dīpe_, --, --, 
   {{0xdb1804f3,0xb5f80332,0x9abc025c,0xa4d8004e}},	//   _tyvä, _mnái, duċi, ддуу_, 
   {{0x42a40020,0x26c00077,0xf99c020c,0x9f5c0306}},	//   ላፊነት_, boio_, paès_, tavý_, 
   {{0xe29800d6,0x569401c6,0x64800254,0x9abc0327}},	//   має_, _чамт, _söit, fuċi, 
   {{0x9f5c0122,0xc5f8011a,0x45f8011a,0x00000000}},	//   ravý_, _מפרט, _מהרג, --, 
   {{0xa2d40075,0x94040451,0x9f5c02f0,0x986c0153}},	//   ىيەت, _سوره, savý_, ržė_, 
   {{0xb5f800ae,0x9f5c02f0,0x648001f4,0x00000000}},	//   _anái, pavý_, _vöit, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x648002f6,0xb5f8007b,0xb1440214,0xcc34009d}},	//   _töit, _cnái, _آیتم_, нхны, 
   {{0xcdc42d40,0xe3b01c82,0x98b80139,0x00000000}},	//   маққ, _কৰিব, kxsı_, --, 
   {{0x3b800323,0xcb699591,0xad400137,0x00000000}},	//   глэг, чане_, رىگۉ, --, 
   {{0xb5f8db27,0xee4000c7,0xf1d003ce,0x00000000}},	//   _ináw, _рҭии, _तरान, --, 
   {{0x961400bd,0xd2580165,0xb5f80332,0x6480000d}},	//   িলাম_, _maņ_, _gnái, _möir, 
   {{0x27ec0158,0xf8bc003e,0xdb18072b,0x22b80010}},	//   ødn_, tréa_, _syvå, mčke_, 
   {{0x26c000a7,0xfbc4038e,0x22b809a8,0x66fc01ef}},	//   toio_, _रुपम, lčke_, _očke, 
   {{0xe81c038e,0x2bf806ab,0x69c003e0,0x00000000}},	//   _भएका_, लुरू_, ümes, --, 
   {{0x22b809a8,0x09dc015b,0x26c0030a,0x00000000}},	// [2aea0] nčke_, _ভ্রা, roio_, --, 
   {{0x26c00395,0x29001140,0x321c0098,0x69c0025c}},	//   soio_, _itia_, _aduy_, żmes, 
   {{0x389804ac,0x42250392,0xf8c4387a,0x07a59592}},	//   _זיינ, едев, éées_, _чанн, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd4f40046,0x22b80219,0x8184009d,0x00000000}},	//   _аясы, jčke_, эгдж, --, 
   {{0xd04801e4,0x03a412b9,0x21200306,0x00000000}},	//   _eteɾ, _зиго, šiho_, --, 
   {{0xb5f80491,0x7ee59593,0x673c01e0,0x44f40008}},	//   _snái, нцие, ntrj, _hæ_, 
   {{0x29019594,0x648002f6,0x39700023,0x9f4c013d}},	//   _otia_, _töis, _ብጋህዲ_, _rfdä_, 
   {{0x29019595,0x44f403cd,0xdd944eb1,0xbc2400d1}},	//   _ntia_, _jæ_, тапы, ۈرگى, 
   {{0xb4d801e1,0x61e409a8,0x44f4037f,0x998806be}},	//   _apàj, žils, _mæ_, _adaş_, 
   {{0xab240261,0x44f4365a,0xfba80212,0xdd000205}},	//   ноќа_, _læ_, ятий_, ıtım, 
   {{0x22b80010,0x84e8230e,0x00000000,0x00000000}},	//   bčke_, _झंझट_, --, --, 
   {{0x44f4782c,0xb5f803b2,0x00000000,0x00000000}},	//   _næ_, _knáv, --, --, 
   {{0xeaf41d10,0xfca8072d,0x291c00b8,0x387007a5}},	//   بریت_, _عاشو_, _āvat_, уқот, 
   {{0x29019596,0x69c0e399,0x36899597,0xc0d40023}},	//   _etia_, ümer, псан_, _ርኹስ_, 
   {{0xadc00248,0x44f40008,0x00000000,0x00000000}},	//   _akẹk, _bæ_, --, --, 
   {{0x6594084c,0x44f4003a,0xf4840d5c,0xd25001d3}},	// [2aeb0] гату, _cæ_, нужн, یچر_, 
   {{0x44f4143a,0x69c8002d,0x36d00116,0xf8bc0124}},	//   _dæ_, ędet, тоғр, kuéi_, 
   {{0xdb1800c7,0x78a40240,0xe2c801e2,0x00000000}},	//   _ayvú, mijv, ډولو_, --, 
   {{0xe1f131f7,0x78a59598,0x44f4066a,0xa29401ca}},	//   مسه_, lijv, _fæ_, лахі, 
   {{0x03dc00b8,0x00000000,0x00000000,0x00000000}},	//   _māṃd, --, --, --, 
   {{0x8fa57891,0x7bc803ac,0x22b80427,0xa0c4009a}},	//   кале, _oyfu, včke_, هينو, 
   {{0xa3d44a40,0xf8bd9599,0x7bc8007c,0x00000000}},	//   _борч, guéi_, _nyfu, --, 
   {{0x0e65959a,0x78a40196,0xd5d407f7,0x00000000}},	//   ткин, hijv, _दराज, --, 
   {{0x2d880300,0xc0cc044e,0xba380227,0x7bc802d0}},	//   áce_, ብሎም_, ynïr, _ayfu, 
   {{0x9d4400b2,0x4c8509ea,0xeb0401e0,0x6abd3e05}},	//   ائين, тлов, ндоҙ_, ैत्र, 
   {{0x2901959b,0x7bc80368,0x2d880118,0x78a401a4}},	//   _stia_, _cyfu, šce_, dijv, 
   {{0x8d746794,0x7bc80210,0x00000000,0x00000000}},	//   _لاتا, _dyfu, --, --, 
   {{0x827404ac,0x7e98008f,0x78a40023,0x7bc80857}},	//   דערע_, _קסנו, fijv, _eyfu, 
   {{0x1cb01b4b,0xf99c50b6,0xf8bc003e,0x9abc031c}},	//   _དམར_, mbèl_, srén_, duċu, 
   {{0x7bc80368,0xf8bc0098,0x44f56e62,0x00000000}},	//   _gyfu, ntéy_, _sæ_, --, 
   {{0x2900026c,0xf6200117,0x9bd400c0,0x00000000}},	//   _ttia_, идсо, _сціш, --, 
   {{0x673d2d94,0x6aa461d4,0x29001140,0xf99c007f}},	// [2aec0] strj, _imif, _utia_, nbèl_, 
   {{0x44f4ab17,0x00000000,0x00000000,0x00000000}},	//   _væ_, --, --, --, 
   {{0x86c4004b,0xf99c007f,0x80c800cc,0x00000000}},	//   _ليدن, hbèl_, িগম্, --, 
   {{0x52747e8c,0xdbcc09f3,0x9324036b,0xb5f80174}},	//   лучу, _móði, ارلن, _snáv, 
   {{0x9c7c0427,0xdbcc01a8,0x00000000,0x00000000}},	//   lmče, _lóði, --, --, 
   {{0x3998008d,0x03a40107,0x1d3408ca,0x00000000}},	//   וינד, _ҷиҳо, ҳния, --, 
   {{0x03a40fab,0x645d959c,0x4254a2ff,0xb2200451}},	//   _риво, _iari, _итат, _چڙهي, 
   {{0x645d959d,0xeea42eca,0x01640818,0x00000000}},	//   _hari, ктык_, _икбо, --, 
   {{0x645d87f2,0xdd903ded,0x77a0022e,0x628035ae}},	//   _kari, صود_, _mеxa, _iomo, 
   {{0x6281959e,0x5c742c1d,0x9f9804bf,0x6aa402d0}},	//   _homo, улот, lším_, _amif, 
   {{0x6281959f,0x61480008,0x78a595a0,0x00000000}},	//   _komo, _félö, vijv, --, 
   {{0x645d95a1,0x2fd4034c,0x628195a2,0x9f9802fb}},	//   _lari, _شوند_, _jomo, nším_, 
   {{0x628195a3,0x645d0ab8,0xf65001ed,0x3af8002b}},	//   _momo, _oari, یئر_, _dīpa_, 
   {{0x7d0195a4,0x6aa595a5,0xdb1803b2,0xbaf40124}},	//   _itos, _emif, _oyvø, _иҭоу_, 
   {{0x78a595a6,0xdbcc1f60,0x7bc8011f,0x628195a7}},	//   rijv, _góði, _uyfu, _oomo, 
   {{0x645d95a8,0x628195a9,0x9f980232,0xeb740375}},	//   _aari, _nomo, jším_, _יעוץ_, 
   {{0x645d5cf9,0x2a6400d2,0x9f9802fb,0x00000000}},	// [2aed0] _bari, ômbe_, dším_, --, 
   {{0x645d95aa,0x7d0195ab,0x1cb0025c,0x628004ce}},	//   _cari, _mtos, _དམས_, _aomo, 
   {{0x645d95ac,0x628195ad,0x7d000354,0xe3b006c2}},	//   _dari, _bomo, _ltos, يرم_, 
   {{0x622404a9,0x7d0195ae,0x645d95af,0x81bc02f5}},	//   لىمل, _otos, _eari, ুইন_, 
   {{0x628168ee,0x7d00a1e0,0x62353566,0xdecc0023}},	//   _domo, _ntos, речу, _ኣለካ_, 
   {{0x2ec80a28,0xf8bd95b0,0x00000000,0x00000000}},	//   ात्त, ttéy_, --, --, 
   {{0x7d0195b1,0x628010ba,0xb4bc73ca,0x4df4036b}},	//   _atos, _fomo, ँकी_, ляпт, 
   {{0x628195b2,0x645d95b3,0xb5f995b4,0xdd0002b5}},	//   _gomo, _zari, _gnát, _ōtān, 
   {{0x7d0005b1,0x7bcc0e78,0xc210011a,0xdea4187c}},	//   _ctos, übun, _להן_, جینی, 
   {{0x645d95b5,0x628195b6,0x7d00007b,0xaca002e3}},	//   _xari, _zomo, _dtos, mpịn, 
   {{0x7d0195b7,0x628195b8,0xb5f80083,0x22b80219}},	//   _etos, _yomo, _gaág, lčka_, 
   {{0x18780020,0x6280005a,0x7ebc0240,0x00000000}},	//   _ባሻገር_, _xomo, këpy, --, 
   {{0x8c446833,0x22b8151c,0xa2c401bc,0xdd940064}},	//   _беле, nčka_, िकत्, _кацы, 
   {{0xf8bc0118,0xe8740066,0xe9f40124,0x00000000}},	//   brém_, جنسگ, ыҧҩы, --, 
   {{0x645d95b9,0x7c2c0077,0x27b43d09,0x9f980118}},	//   _rari, óbre, рәпс, yším_, 
   {{0x645d95ba,0x969595bb,0x066595bc,0x6aa4009a}},	//   _sari, аруш, داسپ, _umif, 
   {{0x056445b3,0x628195bd,0x645cb180,0x9f980316}},	// [2aee0] ыван, _romo, _pari, vším_, 
   {{0x645d95be,0x62805599,0x39980375,0xb5f800ae}},	//   _qari, _somo, _נייד, _snát, 
   {{0x22b80030,0x9f9800bc,0x99980153,0x00000000}},	//   ečka_, tším_, besų_, --, 
   {{0x6d4995bf,0x628195c0,0xc6900050,0x99980153}},	//   _opga, _qomo, _چِھ_, cesų_, 
   {{0xd57595c1,0x38c82a60,0x9f980122,0xa15957e4}},	//   _курь, _زایی_, rším_, талу_, 
   {{0x62800944,0xb9d81772,0x645c16b8,0x1cb0025c}},	//   _womo, _አዩ_, _uari, _དམེ_, 
   {{0x7d00006d,0x6d4995c2,0x9f980122,0x628195c3}},	//   _stos, _apga, pším_, _tomo, 
   {{0x6280011c,0x6d48005a,0x6564009f,0x22b80010}},	//   _uomo, _bpga, ovih, bčka_, 
   {{0xb5f80122,0xad200131,0xb4d80e89,0x0db801d3}},	//   _znás, مىيى, _spài, ہئیں_, 
   {{0x6d4802c4,0x20180008,0xf8bc13d5,0x00000000}},	//   _dpga, _þri_, trém_, --, 
   {{0x6d480077,0x1bd595c4,0x7d000254,0x65640821}},	//   _epga, роня, _wtos, hvih, 
   {{0x7f580135,0x7d000083,0x6564003e,0xc0cc0023}},	//   _istq, _ttos, kvih, ብዎም_, 
   {{0x3ea403a1,0x7d000793,0xca6001d5,0x79a42b2e}},	//   _imot_, _utos, rslа, урне, 
   {{0x656578ac,0xf8bc01ed,0x3ea4022a,0x00000000}},	//   dvih, prém_, _hmot_, --, 
   {{0xf64476e9,0x7d040174,0x00000000,0x00000000}},	//   лхан, íksf, --, --, 
   {{0xf5e4177b,0x629801f5,0x00000000,0x00000000}},	//   гізм, ëvol, --, --, 
   {{0x99980024,0xb8e80395,0x00000000,0x00000000}},	// [2aef0] resų_, _пфое_, --, --, 
   {{0xb4bc012c,0xa43801c6,0x22b80427,0x986c0064}},	//   ँके_, лзуу_, včka_, mžį_, 
   {{0x3ea404a7,0x950401ed,0xf36402d5,0x630400d1}},	//   _omot_, _چہرے_, ытан, مولل, 
   {{0x92940798,0x00000000,0x00000000,0x00000000}},	//   јадц, --, --, --, 
   {{0xe1f802d5,0x3af800e8,0x466000db,0x00000000}},	//   угі_, _lëp_, _بۇقق, --, 
   {{0x35740020,0x3ea595c5,0x22b819d6,0x6d480072}},	//   _አመታት_, _amot_, rčka_, _rpga, 
   {{0xf8bc06af,0x0484013d,0x00000000,0x00000000}},	//   lués_, _тәти_, --, --, 
   {{0x8e8595c6,0x1cb00135,0xb5f802f0,0x22b80427}},	//   ргие, _དམུ_, _znár, pčka_, 
   {{0x42a595c7,0x7f593bc1,0xf8bc2ffe,0x202400e8}},	//   _турғ, _estq, nués_, ëriñ_, 
   {{0x3ea404f3,0x1034034c,0x3af80de2,0x0b44013e}},	//   _emot_, _خبرگ, _bëp_, анон, 
   {{0x2bf82017,0x65640810,0x3af800b8,0xecc00137}},	//   लुगू_, zvih, _dīpo_, ишүү, 
   {{0x09e50275,0xcbc400f1,0x00000000,0x00000000}},	//   ионн, هېږو_, --, --, 
   {{0x89d4005e,0xf8bc0098,0x19b8084c,0x88c4007b}},	//   рінш, crék_, гурь_, لتسل, 
   {{0xb4bc012c,0xa3d00118,0x00000000,0x00000000}},	//   ँको_, _růží_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf4847e89,0x77a001b9,0x7d0403b2,0x00000000}},	//   یالی, _tеxn, íksg, --, 
   {{0xf8bd95c8,0xa3e88367,0xd3c40075,0x656405c7}},	// [2af00] gués_, मेन_, ەتنى, uvih, 
   {{0x2a600211,0x656595c9,0xd90c40ec,0x3af80de2}},	//   _haib_, rvih, _سیف_, _yëp_, 
   {{0x0708143e,0x65640f23,0xd4d402d5,0x733008c9}},	//   _جيجي_, svih, сітэ, قىلا, 
   {{0x93580228,0xf8bc004a,0xe2100882,0xa8540032}},	//   ыруу_, bués_, ारेण_, _теүә, 
   {{0xc05802bf,0xf8bc06af,0x8174013e,0x212004e6}},	//   вій_, cués_, ралӣ_, éih_, 
   {{0x2a600211,0x7e0ca4cd,0x1168e1a2,0x03040ee8}},	//   _laib_, सर्ग_, الوی_, _نظرپ, 
   {{0xdc500201,0x00000000,0x00000000,0x00000000}},	//   ዚአብሔ, --, --, --, 
   {{0x2a6195ca,0xdb200098,0xf8bc0098,0xd17802dd}},	//   _naib_, _étén, trék_, _өсуі_, 
   {{0x66fc0122,0xd2b801c0,0x22b80427,0xc0400092}},	//   _očko, _сурч_, lčko_, ነበረው, 
   {{0x2a60070d,0x2ca4004d,0xd9cc0154,0x9b580120}},	//   _aaib_, _cmnd_, রেডম, гиот_, 
   {{0x201d95cb,0xf8bc6479,0x7f58022e,0x22b80219}},	//   mavi_, srék_, _ustq, nčko_, 
   {{0x201d95cc,0x2a6195cd,0x66fc00bc,0xf8bc0098}},	//   lavi_, _caib_, _ačko, prék_, 
   {{0x2a600218,0xf8bc01ed,0x9f5c00e4,0x00000000}},	//   _daib_, nség_, ravõ_, --, 
   {{0x8d8412dd,0x201d95ce,0xb5f80798,0x3af8002e}},	//   _دشمن, navi_, _anáp, _tëp_, 
   {{0x2a600070,0x629800da,0x6bd0005e,0xd7c824e0}},	//   _faib_, īvoj, _وتىر, اوزه_, 
   {{0x201d95cf,0x2a6195d0,0xf8bc61c3,0xeb940375}},	//   havi_, _gaib_, tués_, _כדור_, 
   {{0x201d95d1,0xf8bc0036,0x95d8cd99,0x22b80419}},	// [2af10] kavi_, hréi_, удат_, ečko_, 
   {{0xf36595d2,0x647401c0,0x00000000,0x00000000}},	//   итен, огуу, --, --, 
   {{0x201d95d3,0x24590573,0xdb1c415b,0x00000000}},	//   davi_, рахь_, _özär, --, 
   {{0x2a600457,0x00000000,0x00000000,0x00000000}},	//   _xaib_, --, --, --, 
   {{0xf8bd95d4,0x2ea413f9,0xf99c9c19,0x201c022e}},	//   qués_, یپتی_, nzè_, favi_, 
   {{0x201cfeec,0x600c003a,0x1ea8004b,0xf8bc0036}},	//   gavi_, _rômâ, یايي_, fréi_, 
   {{0xf99c00f2,0x00000000,0x00000000,0x00000000}},	//   sbèh_, --, --, --, 
   {{0x201c0140,0x6234013e,0xf1a41fbe,0x8e5400d4}},	//   aavi_, _месу, _крзн, сткі, 
   {{0x201c04b9,0xa19422e9,0x2a60020b,0xa2c4146b}},	//   bavi_, _датч, _raib_, िकर्, 
   {{0x2a600190,0x201d95d5,0x00000000,0x00000000}},	//   _saib_, cavi_, --, --, 
   {{0x2a600211,0x644804cc,0x0ae995d6,0xdb1800e4}},	//   _paib_, _ödie, лдой_, _tyvý, 
   {{0x2a600070,0xc3300375,0x00000000,0x00000000}},	//   _qaib_, הוט_, --, --, 
   {{0x7d28004b,0xd1d40023,0x00000000,0x00000000}},	//   _مينې_, ርግቲ_, --, --, 
   {{0x1cb008ea,0x7640013f,0xd90c1afc,0x9c6400ec}},	//   _དམག_, ɑnyi, کیی_, _وهنو, 
   {{0x2a602a1f,0xf8bc01ed,0x314c0092,0xe748013d}},	//   _taib_, zség_, _ማጭበር, шүне_, 
   {{0x201d95d7,0x629800da,0x2d9c01c4,0xf8bc01d3}},	//   zavi_, īvok, ozue_, ység_, 
   {{0x044995d8,0x66fc007f,0x3cf800df,0x00000000}},	// [2af20] лпак_, _zčkl, ָלענ, --, 
   {{0xb9780302,0x201c0564,0x2d9c01c4,0x67581968}},	//   _עניי, xavi_, izue_, _پیرس_, 
   {{0xa2c40146,0x43446f65,0x6fa40073,0xd51400d1}},	//   िकल्, сеев, _केलं, مبەغ, 
   {{0xf8bc00dd,0x201cf922,0x22b80010,0xd7c800f1}},	//   tség_, wavi_, rčko_, _خوپه_, 
   {{0x201d95d9,0x7240034c,0xdecc02d3,0x00000000}},	//   tavi_, سپول, _ኣለኻ_, --, 
   {{0x04940aaa,0xf8bc01d3,0x00000000,0x00000000}},	//   _السح, rség_, --, --, 
   {{0x201d95da,0xf8bc00dd,0xf99c011c,0x2d9c005a}},	//   ravi_, sség_, zzè_, ezue_, 
   {{0x1cb00489,0x201d95db,0xa3e800dc,0x3240020f}},	//   _དམང_, savi_, मेण_, _несг, 
   {{0x25a195dc,0x201d3e29,0xf8bc06af,0x439463eb}},	//   nzil_, pavi_, lsée_, _таңс, 
   {{0x201c0a73,0x00000000,0x00000000,0x00000000}},	//   qavi_, --, --, --, 
   {{0xdecc044e,0xf8bceb39,0xfe440798,0x00000000}},	//   _ኣለኹ_, nsée_, _гнео, --, 
   {{0xf8bc004a,0xf99c00db,0x25a00100,0x00000000}},	//   isée_, tzè_, kzil_, --, 
   {{0xa3e84da1,0xa2c000dc,0x9ca400cf,0x4b900023}},	//   मेत_, _वदन्, _وشتۇ, ምልከቶ_, 
   {{0x44380649,0xf99c86ed,0xa8a400f0,0x9ba801d3}},	//   jgp_, rzè_, прск, _پختہ_, 
   {{0x25a0089c,0x2bcc190e,0x7e6195dd,0x21240129}},	//   ezil_, _सुपा, _kaop, _lvmh_, 
   {{0x7c3805e4,0x80d801ad,0x151402e8,0xab80526a}},	//   lgtr, _पीसे, ждая, _хушк, 
   {{0x7e60123c,0x94183529,0x7c3801f5,0x25a0007f}},	// [2af30] _maop, ижат_, ogtr, gzil_, 
   {{0x7c3995de,0x44380117,0xd3c40131,0x7e600254}},	//   ngtr, ggp_, ەتچى, _laop, 
   {{0xd3700491,0x25a00e14,0xb4d800a3,0x798c0142}},	//   بها_, azil_, _spàs, lycw, 
   {{0x7e6195df,0xa3e81788,0x00000000,0x00000000}},	//   _naop, मेध_, --, --, 
   {{0x2bcc19e5,0x61f801f1,0x4638010f,0x00000000}},	//   _सुना, _šalá, _דערע, --, 
   {{0xc0b80092,0x00000000,0x00000000,0x00000000}},	//   _ሲቻል_, --, --, --, 
   {{0x7e6195e0,0xe0d09cc3,0xf99c068c,0xb9e0001f}},	//   _baop, رزه_, mbèu_, _ሩጫ_, 
   {{0x7e6195e1,0xd1082088,0x2d9c01c4,0xcd04005a}},	//   _caop, _نقره_, tzue_, опий, 
   {{0x0c7995e2,0x8d540212,0x7bc4002f,0x00000000}},	//   асны_, ітич, ßkun, --, 
   {{0x4b241bb8,0x7e6000e4,0x7c380efa,0xd09400f1}},	//   омов, _eaop, ggtr, _بدرګ, 
   {{0x7e600421,0xba380548,0xaa640166,0x7bc403e0}},	//   _faop, yiït, пенһ, şkun, 
   {{0x7e60002f,0xf66401bf,0xe98401d5,0x00000000}},	//   _gaop, æælp_, зқин, --, 
   {{0x6e384b2a,0x00000000,0x00000000,0x00000000}},	//   mgub, --, --, --, 
   {{0x64b811bc,0xfd60063f,0xf8bd95e3,0xfc44219b}},	//   _आदेश, _latị, ysée_, čích_, 
   {{0x37840261,0x92181d8a,0x6e38009f,0x6da001e0}},	//   обро_, दराज_, ogub, _фиҙа, 
   {{0x060995e4,0x25a00810,0x7d200139,0x03780244}},	//   рнак_, tzil_, _äxsä, یحات_, 
   {{0x61b800cd,0x00000000,0x00000000,0x00000000}},	// [2af40] _अशेष, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc20995e5,0x6e3800fb,0x2bcc0574,0x9a9002d3}},	//   لقان_, kgub, _सुमा, _ዝከኣል_, 
   {{0xf8bc5725,0x4ac800cd,0x00000000,0x00000000}},	//   rsée_, रविव, --, --, 
   {{0xf8bc20ef,0x7e600109,0xb6a06518,0x6e38058a}},	//   ssée_, _raop, _циял, dgub, 
   {{0x7e60b485,0x2bcc1fc4,0xf99c068c,0x03a400f3}},	//   _saop, _सुभा, mbèt_, _диго, 
   {{0x6878069c,0x7e6195e6,0xd258007f,0x442995e7}},	//   _ኣገዳሲ_, _paop, _djņb_, _idb_, 
   {{0x660595e8,0x6e3995e9,0xf99c0ba1,0x9d180124}},	//   ncik, ggub, ncèc_, боит_, 
   {{0x7c38074d,0x7e600421,0x4428005a,0x2bcc2802}},	//   tgtr, _vaop, _kdb_, _सुबा, 
   {{0xe2980131,0x6e380009,0x7c38002f,0x00000000}},	//   _тағ_, agub, ugtr, --, 
   {{0x66040092,0x442800ac,0x7e618b98,0x2bf8000d}},	//   kcik, _mdb_, _taop, ोड़ू_, 
   {{0x6e380115,0x4428007c,0x00000000,0x00000000}},	//   cgub, _ldb_, --, --, 
   {{0x6ec40a59,0xbda408de,0x7c841513,0x66040139}},	//   ावरु, _بحضو, _муке, dcik, 
   {{0xf8bc003e,0x9f5800e4,0xf77001d9,0x2ec000db}},	//   jrét_, _ýró_, ٘ار_, _нөөм, 
   {{0x9b94074d,0x00000000,0x00000000,0x00000000}},	//   _хийц, --, --, --, 
   {{0x660595ea,0xdea80198,0x7c2800d8,0x0b580137}},	//   gcik, _ƙoƙo, _hdfr, _ырчы_, 
   {{0x442995eb,0xa3e817e6,0xb8840462,0xf41c03d4}},	// [2af50] _bdb_, मेस_, _дунй, _পাবৰ_, 
   {{0x4428030d,0x660400ca,0xfd6001f2,0x6e380010}},	//   _cdb_, acik, _satị, zgub, 
   {{0xe1f004d3,0x52740b38,0x61e400ee,0x6e380009}},	//   ۆسه_, зулу, ýiln, ygub, 
   {{0x66040de2,0x00000000,0x00000000,0x00000000}},	//   ccik, --, --, --, 
   {{0xe1f195ec,0xd00944d4,0x44296120,0xf8bc0098}},	//   نسه_, беле_, _fdb_, brét_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x84200137,0x00000000,0x00000000,0x00000000}},	//   _سۉنن, --, --, --, 
   {{0x0d840131,0x7c2995ed,0xc3300375,0xe37401e0}},	//   злин, _adfr, _רון_, _юлсы, 
   {{0x2d880231,0x8c446128,0xe0d00131,0x7bc40790}},	//   âce_, пепе, رزۇ_, şkul, 
   {{0xa3e8a96d,0xefbc0020,0xd01000c6,0x6e380042}},	//   मेव_, ድሞው_, _ألا_, sgub, 
   {{0x5f745734,0xbb4012c4,0x96bc012c,0x764c033f}},	//   _يامر, неэк, ्काउ, _obcy, 
   {{0x7c2803ac,0x00000000,0x00000000,0x00000000}},	//   _edfr, --, --, --, 
   {{0x660401e4,0x09d40006,0xbb301884,0x00000000}},	//   vcik, яцоў, ﺭﻗﻰ_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x442805da,0x37e0586a,0xb9000d79,0x2f4c0092}},	//   _rdb_, еорг, _फी_, _ሁልጊዜ, 
   {{0x442806af,0xba380042,0xfad00798,0xdb080244}},	//   _sdb_, thïe, _појќ, _بزوه_, 
   {{0xf8bd95ee,0x2bcc0b02,0xcfd0009e,0x39680023}},	// [2af60] grés_, _सुता, াধিন, ታተልቲ_, 
   {{0x660480b6,0xb46195ef,0xf99c067c,0x69c403ac}},	//   scik, нкул, rbèt_, _ixie, 
   {{0x0af8015b,0x3af800b0,0x22b809a8,0xb7f8011a}},	//   _আবুল_, _pīpi_, lčki_, _לפית, 
   {{0xf8bd95f0,0xf65c00b5,0xf41c03d4,0x00000000}},	//   brés_, _skæv_, _পাণৰ_, --, 
   {{0x22b8151c,0xf8bc9d74,0x15b80108,0x00000000}},	//   nčki_, crés_, _дыры_, --, 
   {{0x442995f1,0x3af800b0,0xf990008f,0x69c4031c}},	//   _udb_, _hūpe_, ערג_, _mxie, 
   {{0x6e2800a2,0x749808a8,0xa3e80027,0x3af800b8}},	//   _bdgb, _פילפ, मेश_, _kūpe_, 
   {{0x2bcc28d4,0x3da400d6,0x69c4035a,0xb3b805d0}},	//   _सुधा, зроб, _oxie, _המלכ, 
   {{0xa3e8068f,0x22b809a8,0x7c28005a,0x1cb0031c}},	//   मेर_, jčki_, _pdfr, _དམད_, 
   {{0x6e2801ab,0x61e0110c,0x9b947621,0x80a4007b}},	//   _edgb, _izml, диоц, _عمان, 
   {{0x69c809a5,0xb5f80cad,0x69c4005a,0x7c2800b5}},	//   şdel, _baál, _axie, _vdfr, 
   {{0xcfa8e84d,0x00000000,0x00000000,0x00000000}},	//   _ظالم_, --, --, --, 
   {{0x7d7800f1,0xef1c003d,0x00000000,0x00000000}},	//   _دمشر_, ħżel_, --, --, 
   {{0xf8bc07ea,0x7c2800b5,0xdcb000cf,0xaab40150}},	//   vrés_, _udfr, _جىت_, _үйші, 
   {{0x69c595f2,0x6c4400ec,0x5ac802f2,0x00000000}},	//   _exie, _رليف_, _وابێ_, --, 
   {{0xf8bd95f3,0x784c01d3,0x22b80219,0x66f401ee}},	//   trés_, _bővü, bčki_, епсу, 
   {{0x7ebc00b0,0xf99c067c,0xf8bc0129,0x6aa800e8}},	// [2af70] hīpo, rbès_, urés_, ëjfe, 
   {{0xf8bd95f4,0x98b82bb7,0xc7ac01ed,0x00000000}},	//   rrés_, _флот_, اڑی_, --, 
   {{0x1cb00003,0xa3e820f0,0xd6d000c6,0xe61001ed}},	//   _དམན_, मेल_, _لقد_, ئشہ_, 
   {{0xf8bc381a,0xd1d801af,0x00000000,0x00000000}},	//   prés_, одец_, --, --, 
   {{0x61142f34,0x00000000,0x00000000,0x00000000}},	//   едчу, --, --, --, 
   {{0xe7e41889,0xfe6c07d6,0x00000000,0x00000000}},	//   _गरमा_, یگن_, --, --, 
   {{0xd0080032,0xcee8005b,0x3af800b8,0x00000000}},	//   беһе_, одке_, _yūpe_, --, 
   {{0xbec00055,0x00000000,0x00000000,0x00000000}},	//   _śīra, --, --, --, 
   {{0x62980029,0xc32c04d3,0x4c3402d5,0xb5f80241}},	//   īvot, _مڕۆ_, мэнт, _raál, 
   {{0x66fc02b5,0x321c0098,0x22b809a8,0x2d8000f3}},	//   _hōke, _heuy_, včki_, ćje_, 
   {{0x8fb82885,0x66fc9334,0x60c400c6,0x69c80205}},	//   _بهاء_, _kōke, éime, ğdem, 
   {{0xe7e40412,0x69c803e0,0x00000000,0x00000000}},	//   _गरबा_, şdem, --, --, 
   {{0x66fc0374,0x7aa000d1,0xd6c4015b,0x2bcc02e5}},	//   _mōke, тияз, ্ষায, _सँवा, 
   {{0x1cdc025c,0x22b809a8,0x9c840030,0xa3e807f7}},	//   _ཡེར_, rčki_, točň, मेँ_, 
   {{0xf74195f5,0xa8240014,0x46f44109,0x00000000}},	//   керо, وکھن, дчат, --, 
   {{0xb5f802fb,0xcba400d1,0xf99c067c,0x22b80427}},	//   _znáz, _наһй, rbèr_, pčki_, 
   {{0xf8bc07c5,0x987c001f,0x75d0475d,0x44880114}},	// [2af80] rrér_, ፖሬሽኑ_, نيفا, обан_, 
   {{0xb93400c8,0xfc4c01fb,0x15b995f6,0x9f58010e}},	//   _קריג_, _lửng_, чысы_, _ürç_, 
   {{0xe8142413,0xa3e82007,0x290195f7,0x1cdc031c}},	//   _त्या_, में_, _huia_, _ཡེལ_, 
   {{0x290195f8,0x673c2230,0x00000000,0x00000000}},	//   _kuia_, murj, --, --, 
   {{0x321c025b,0x2054023a,0x00000000,0x00000000}},	//   _deuy_, екля, --, --, 
   {{0x290195f9,0xc648009f,0x57240244,0x00000000}},	//   _muia_, _اجھل_, _تریق, --, 
   {{0x29000270,0x321c007f,0x9f9835dd,0xf8bc003e}},	//   _luia_, _feuy_, явку_, ksén_, 
   {{0x7ebc02b1,0xd29802dd,0x20f00073,0x629800e2}},	//   rīpo, _етуі_, _चळवळ_, īvos, 
   {{0x1ee8066d,0x81444955,0xad200075,0x673d95fa}},	//   _ہوئی_, _زنان, نىيى, hurj, 
   {{0xfca80014,0x2bcc13e0,0x321c030a,0x80b000db}},	//   تابو_, _सुहा, _zeuy_, _جەتش, 
   {{0x29008c04,0xf04505b4,0x673c0427,0x59e000bc}},	//   _auia_, _تعقی, jurj, _नरहर, 
   {{0x29007db6,0x00000000,0x00000000,0x00000000}},	//   _buia_, --, --, --, 
   {{0x290195fb,0x00000000,0x00000000,0x00000000}},	//   _cuia_, --, --, --, 
   {{0x19c40598,0x290000cf,0x2bcc0b6d,0x673c1a33}},	//   _җәмг, _duia_, _सुवा, furj, 
   {{0x67d595fc,0x29000137,0x368816c3,0xeaf8703a}},	//   вору, _euia_, осан_, ثریت_, 
   {{0x29000421,0x20100213,0x80c8033f,0xfc4c0051}},	//   _fuia_, əniş_, ाकुं, _xửng_, 
   {{0x290195fd,0xb86400db,0x22b80219,0x321c6790}},	// [2af90] _guia_, _قادو, nčku_, _reuy_, 
   {{0x1cdc025c,0x673d7864,0x048400ee,0xfcd00092}},	//   _ཡེས_, burj, нәси_, _ከወጣ_, 
   {{0x66fc02b1,0x29012f86,0x80c8015b,0x0874008f}},	//   _pōke, _zuia_, িগঞ্, _װערט_, 
   {{0xe2c96326,0x52c80bae,0xe7f401f9,0x00000000}},	//   وولو_, िकेस, _आणता_, --, 
   {{0xa3b47b05,0x22b995fe,0xd0085336,0x3948003a}},	//   _जेठ_, jčku_, пеле_, ntcs_, 
   {{0xfc4c004d,0x00000000,0x00000000,0x00000000}},	//   _sửng_, --, --, --, 
   {{0x66fc0374,0xcef40261,0x321c030a,0x22b800d0}},	//   _tōke, нчињ, _teuy_, ečku_, 
   {{0x4d640640,0xfccc02d3,0x4d1411f7,0xb5f80241}},	//   екив, _ኣረገ_, ньот, _saáj, 
   {{0x620401d9,0x00000000,0x00000000,0x00000000}},	//   _شولٕ, --, --, --, 
   {{0x29000374,0xa3b400e1,0x1ca803e6,0xcc880133}},	//   _ruia_, _जेड_, وێنی_, سنجه_, 
   {{0x290004c9,0x2bcc0562,0xfc4c0208,0x673c0327}},	//   _suia_, _सुशा, _tửng_, xurj, 
   {{0x290031cf,0xaca00248,0x22b80010,0x9e140064}},	//   _puia_, _iyọk, bčku_, _адці, 
   {{0x2900c51b,0x2bcc1408,0xcc080014,0xf8bc0098}},	//   _quia_, _सुरा, _فٲشن_, rsén_, 
   {{0x8c4595ff,0x29005934,0x00000000,0x00000000}},	//   _чеке, _vuia_, --, --, 
   {{0x61dc0316,0x8698084c,0x35a0059f,0x3ce80118}},	//   _बर्ष, птат_, ҳатг, řivé_, 
   {{0x29019600,0xf65c037e,0x673c0455,0x09e4011c}},	//   _tuia_, _skær_, rurj, _пойн, 
   {{0xf99c0ba1,0xc4e402dd,0x35a001b9,0x59641219}},	// [2afa0] ncèl_, ежай, гатг, _анығ, 
   {{0x03a4ace6,0xf8bc0098,0x673c340f,0xdeec0092}},	//   низо, nsél_, purj, ቆችና_, 
   {{0x3af99601,0x00c82cc8,0x82440408,0xf41c00cc}},	//   _kūpa_, үлек_, нĕнч, _পাশৰ_, 
   {{0xe8140d01,0x41e40024,0x5274004e,0xfbd0011a}},	//   _त्ता_, ніла, кучу, נתא_, 
   {{0x26c148fb,0xaca00cad,0x00000000,0x00000000}},	//   mnio_, _ayọk, --, --, 
   {{0x26c00024,0x3f6400f7,0x15b00131,0x22b80427}},	//   lnio_, етиб, _ئەكس, včku_, 
   {{0x26c19602,0x82a400d6,0x2bcc00e1,0x3f9800bc}},	//   onio_, _завж, _सुला, ápu_, 
   {{0x26c19603,0xdecc02d3,0xc0a84c8b,0x5d543252}},	//   nnio_, _ኣለኒ_, _کارل_, вкит, 
   {{0x26c19604,0xa3b4000d,0x00000000,0x00000000}},	//   inio_, _जेत_, --, --, 
   {{0xb1100521,0x22b80427,0x3f68024c,0x232c0055}},	//   wụgw, rčku_, _низо_, _ṣaḍḍ_, 
   {{0x34b402e4,0xdb1c05d1,0x50b40124,0xbf3404f2}},	//   תפים_, _özür, _рсту, _سراغ, 
   {{0x26c00115,0xbd880c75,0xfbd001d9,0x00000000}},	//   jnio_, _ىنان_, َتھ_, --, 
   {{0xdecc044e,0x26c19605,0x00000000,0x00000000}},	//   _ኣለና_, dnio_, --, --, 
   {{0x7c6400aa,0x26c19606,0x7d000064,0x00000000}},	//   _ساتل, enio_, _iuos, --, 
   {{0xf8bc1e54,0x7d019607,0x26c00142,0xd7c80b24}},	//   sséo_, _huos, fnio_, ذوره_, 
   {{0xac800124,0x7d019608,0x91b005d7,0x9f5800c7}},	//   _агәл, _kuos, _आइलै, _ýrõ_, 
   {{0x7d005067,0xeaf875b0,0x66c8074d,0x00000000}},	// [2afb0] _juos, _ثروت_, хург_, --, 
   {{0x7d001570,0x64a4026a,0x26c000df,0x973400ec}},	//   _muos, гађа, anio_, _لکرا, 
   {{0x7aec0204,0x7d019609,0xd9981f0d,0xb3700092}},	//   omct, _luos, _رنگت_, ኩልዎን_, 
   {{0x37c40154,0x3af8002b,0x00000000,0x00000000}},	//   _এরপর, _yūpa_, --, --, 
   {{0x7d0002d5,0xdd0000bc,0x50440120,0x4638010f}},	//   _nuos, čtěj, велб, _קעשע, 
   {{0x66fc02b1,0xb4b004b4,0x70c8095f,0x00000000}},	//   _hōka, _сигә, िवेल, --, 
   {{0xd6c40729,0x66fc0374,0xb2a800a7,0xf2c40022}},	//   ্ষীপ, _kōka, _етаж_, _зсан, 
   {{0xb8e031d9,0x7d00037e,0xa3d401f4,0x00000000}},	//   _ཏམ_, _buos, _сосч, --, 
   {{0x50f4b590,0x7d001570,0x66fc04fe,0x5ba401e0}},	//   _азат, _cuos, _mōka, ҫлығ, 
   {{0x26c00fcf,0x66fd960a,0x7d01960b,0xa3e89f23}},	//   znio_, _lōka, _duos, मेक_, 
   {{0x26c1960c,0x3af80055,0x765c036e,0x00000000}},	//   ynio_, _sūpa_, keqy, --, 
   {{0x03bc0183,0x7d006ddf,0xe814043e,0x3af80055}},	//   _অৰুণ, _fuos, तुना_, _pūpa_, 
   {{0xb92401f2,0x765c0477,0x3eb8180f,0x7d000064}},	//   matị_, deqy, èpte_, _guos, 
   {{0x48c0015b,0x26c00042,0x00000000,0x00000000}},	//   োগ্র, wnio_, --, --, 
   {{0x26c0068f,0x9f5800c7,0x2d4812e8,0x17c400c7}},	//   tnio_, _ýrô_, løe_, гарҭ, 
   {{0x22b800b0,0x26c00393,0x7ce406ea,0x00000000}},	//   kōka_, unio_, rðre, --, 
   {{0xa2c01533,0x15b801e0,0xf50000a7,0x056402e8}},	// [2afc0] लचस्, ныфы_, изто, ъван, 
   {{0x26c0bdd8,0x66e402dd,0x00000000,0x00000000}},	//   snio_, тоға, --, --, 
   {{0xc7a400d6,0x580400db,0x46e801c6,0x43443b8f}},	//   _ринк, _حوپك, _одон_, теев, 
   {{0xd4f401ec,0xf0700014,0x7d040162,0x00000000}},	//   _ұясы, یُند, íksk, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x656401b2,0x7d01960d,0x22b80100,0x00000000}},	//   mwih, _ruos, tčks_, --, 
   {{0x7d000664,0xdb1405ac,0x82f400c7,0x00000000}},	//   _suos, _åbøb, _ачац, --, 
   {{0x7d01960e,0x65640009,0x46e000bc,0xd2b8009d}},	//   _puos, owih, पतिह, _зууч_, 
   {{0xade000d6,0x7d001730,0x656402c4,0x2d4801bf}},	//   ицьк, _quos, nwih, gøe_, 
   {{0x7d01960f,0xa11401e2,0x00000000,0x00000000}},	//   _vuos, _لوړت, --, --, 
   {{0x765c02d3,0xeb9403b7,0x65640526,0xb9240521}},	//   yeqy, виќ_, hwih, batị_, 
   {{0x6564015c,0x7d00049b,0x7ebc0069,0x98b001fa}},	//   kwih, _tuos, kīpi, _čađu_, 
   {{0xf2d004ac,0xeef4011a,0x6da0010a,0x00000000}},	//   שער_, _סמדר_, _кица, --, 
   {{0xc0d4001f,0x00000000,0x00000000,0x00000000}},	//   ይችሉ_, --, --, --, 
   {{0xb8c88919,0x28f8e2cc,0xf644235c,0x43bc00cd}},	//   _खत_, терь_, кхан, ्थोऽ, 
   {{0x66fc04fe,0xdcb801e4,0x79d0010a,0xf41c00cc}},	//   _pōka, liĉ_, _кιез, _পাইৰ_, 
   {{0x55759610,0xe81400dc,0x5454572e,0x65640327}},	// [2afd0] ыгат, _त्वा_, лват, gwih, 
   {{0x34bc07b7,0xb4bc30a4,0x8e7c0115,0xb864eb01}},	//   ्वेद, ुके_, lmŝt, _شاخو, 
   {{0xd79400a7,0xdef8069d,0x00000000,0x00000000}},	//   _синъ, ገረን_, --, --, 
   {{0xb134044e,0x65640223,0x66fcad26,0x60c400ae}},	//   _ብተወሳ, bwih, _tōka, éimn, 
   {{0xe1640228,0x74f40022,0x753c009a,0x91c40116}},	//   لدوي, _аҵар_, quqz, уәвл, 
   {{0xdcb80115,0xafe000fb,0x00000000,0x00000000}},	//   jiĉ_, һоҙл, --, --, 
   {{0xc4d027af,0xdcb801e4,0x8e3401a9,0x326400f3}},	//   _הגם_, diĉ_, аgаn_, _итав, 
   {{0xa2940024,0x0e640108,0x00000000,0x00000000}},	//   _касі, укин, --, --, 
   {{0xf1b48a4f,0x6d480175,0x00000000,0x00000000}},	//   _अधिन, _qqga, --, --, 
   {{0x4c680323,0x4c844839,0xc0d4001f,0x2d48383d}},	//   хион_, улов, ይችል_, røe_, 
   {{0x65640526,0xdea403e6,0x2d4801bf,0x0f140108}},	//   zwih, دیۆی, søe_, _смею, 
   {{0x8d74f282,0xc9a806ed,0xa3e8547d,0x30740354}},	//   _ماتا, евме_, मेट_, _пуçс, 
   {{0x7bc85a8b,0x46a40107,0x65640009,0x290400e4}},	//   _exfu, ҳавв, xwih, êma_, 
   {{0xb4bc038e,0x34bc07d0,0x00000000,0x00000000}},	//   ुको_, ्वोद, --, --, 
   {{0x613402d3,0xb4bc012c,0x03bc00eb,0x00000000}},	//   _ኣይትኽ, ुकै_, _অর্ণ, --, 
   {{0x65640223,0x00000000,0x00000000,0x00000000}},	//   twih, --, --, --, 
   {{0x6aa59611,0x30e000cd,0x00000000,0x00000000}},	// [2afe0] _ilif, गताः_, --, --, 
   {{0x65640223,0x3b380092,0x3af80055,0x7d0403b2}},	//   rwih, _በተጀመ, _yūpo_, íksi, 
   {{0x656529ef,0x6aa59612,0x00000000,0x00000000}},	//   swih, _klif, --, --, 
   {{0x7ebc02b5,0xd1380092,0x9c7c0118,0x00000000}},	//   pīpi, _አልችል, mlče, --, 
   {{0xa3e81524,0x6aa401f7,0x60c40036,0xd2440124}},	//   मेज_, _mlif, éimo, рмчқ, 
   {{0x66fc02b1,0x6aa40368,0x37b40183,0xb9ec069d}},	//   _kōko, _llif, _আঁতৰ, _ሐዋ_, 
   {{0x6aa59613,0xdcb8010f,0xdfd14ea7,0x5f48013d}},	//   _olif, viĉ_, غيب_, түен_, 
   {{0x1cdc0327,0x3af8002b,0x3ea00162,0xf8bc00e5}},	//   _ཡེང_, _rūpo_, ókt_, tsék_, 
   {{0x62819614,0xdd9178d2,0xc0e401f0,0x00000000}},	//   _inmo, زود_, _боак, --, 
   {{0x6aa59615,0xfc44012c,0x673c0200,0xfb84008e}},	//   _alif, _číst_, krrj, гымн, 
   {{0xf8bc01d3,0x6aa4007c,0xceb801ef,0x7ce402d2}},	//   ssék_, _blif, biř_, gðra, 
   {{0x6aa59616,0x35bc00fe,0x00000000,0x00000000}},	//   _clif, _আৰোহ, --, --, 
   {{0x6aa4037e,0x35bc00cc,0x00000000,0x00000000}},	//   _dlif, _আর্হ, --, --, 
   {{0x6aa59617,0x2bcc0fe6,0x0bb401d5,0x9b58014b}},	//   _elif, _सुका, اجیگ, _аикт_, 
   {{0x628007d5,0xa3b422e3,0x3c90177a,0xe784d266}},	//   _onmo, _जेल_, _نیکز, буто, 
   {{0x6aa406f2,0x0df0001f,0xa3d802ab,0x7bc405d1}},	//   _glif, _ግልፅ_, ाथन_, şkus, 
   {{0x673c002d,0x29040118,0xa3e801f9,0xdef80240}},	// [2aff0] arrj, ímat_, मेघ_, ገረና_, 
   {{0x62819618,0xd138001f,0x7afc0240,0x98b800de}},	//   _anmo, _አልቻል, _hiqt, busā_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x386000b5,0xe29800d4,0x63680022,0x00000000}},	//   lejr_, лає_, ыруг_, --, 
   {{0x7afd9619,0x06640131,0xe1080154,0x00000000}},	//   _miqt, _ئاپپ, রীসহ_, --, 
   {{0xf485961a,0x7afc022e,0x835001d9,0x712400cf}},	//   _сумн, _liqt, _ژھنا, _ەرال, 
   {{0x4fa401c0,0x80b4000d,0x2898011a,0x00000000}},	//   рийв, _अगरइ, רדון_, --, 
   {{0x8d542607,0x7afd961b,0x32c000f1,0x228451cd}},	//   аточ, _niqt, _امرې, _лууг, 
   {{0x776401d4,0xe21400ee,0x710800d4,0x00000000}},	//   hwjx, _ымты, _їхав_, --, 
   {{0x6aa4019b,0xefc8001f,0x0c240107,0xcdc4681b}},	//   _slif, ጠራው_, шмон, лаққ, 
   {{0x2bcc2c82,0x7afc047e,0x6280002d,0x6aa4008f}},	//   _सुखा, _biqt, _ynmo, _plif, 
   {{0x7ebc02b5,0x7ce40d12,0x00000000,0x00000000}},	//   tūpe, rðra, --, --, 
   {{0x7afc03b9,0x6d4c01c3,0x00000000,0x00000000}},	//   _diqt, àcad, --, --, 
   {{0x7ebc198e,0x66fc170b,0x35bc00fe,0xc9800023}},	//   rūpe, _pōko, _আৰ্হ, _ክኸፍል_, 
   {{0x6cc40014,0x6aa40003,0x7afc0200,0x7d0406ea}},	//   _لژھِ_, _tlif, _fiqt, íksv, 
   {{0x6aa40a29,0xd90c1176,0x00000000,0x00000000}},	//   _ulif, بیی_, --, --, 
  
   {{0x6b5801b8,0x386001fa,0xd3980131,0x00000000}},	// [2b000] _fägö, bejr_, қәрә_, --, 
   {{0x66fc00b0,0x29040115,0xc3180154,0x348000d8}},	//   _tōko, ŭmas_, _ডিবি_, огуг, 
   {{0x1458c81b,0xadfc05f9,0x0204329b,0xfde04a01}},	//   ышты_, _उलझन_, азен, _पर्फ, 
   {{0x250842c2,0x7afc0429,0x3ae800e4,0x00000000}},	//   _مرسی_, _xiqt, pùpe_, --, 
   {{0x6160069c,0xf23401ec,0x62800051,0xf1bc02d2}},	//   _ሰውራዊ_, рпіш_, _vnmo, _þál_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x63e400db,0xdb0c03b2,0xf8bc01c7,0x403001e0}},	//   _اۋال, _óhøv, uséi_, беҙс, 
   {{0x6281961c,0xf8bc0036,0x00000000,0x00000000}},	//   _unmo, rséi_, --, --, 
   {{0x7afc5431,0xe05800f1,0x00000000,0x00000000}},	//   _riqt, _میشت_, --, --, 
   {{0x7afc014f,0x00000000,0x00000000,0x00000000}},	//   _siqt, --, --, --, 
   {{0x3860037e,0x61e1961d,0xdd8402dd,0x00000000}},	//   vejr_, _hyml, рықп, --, 
   {{0x4f94a6e6,0x9fa40054,0x79a40124,0x7d78007b}},	//   _уруу, qïña_, арге, _لمصر_, 
   {{0x49a41669,0x3ea4a621,0x1fe80154,0x7afc0139}},	//   бырғ, _ilot_, _পলিস, _viqt, 
   {{0x98b80276,0x3a28014b,0x2c700014,0x61e0007c}},	//   dusă_, sacp_, _وُنس, _myml, 
   {{0x3ea5961e,0x29040ad9,0x7afce689,0x69c0002d}},	//   _klot_, ímar_, _tiqt, ûmer, 
   {{0xaab431ed,0x386000b5,0xabf80375,0x41b400ce}},	//   _وصيت, sejr_, _בהור, _आइंस, 
   {{0x69c800ee,0xe59800d4,0x00000000,0x00000000}},	// [2b010] şder, акті_, --, --, 
   {{0xe11402a6,0xb5f801e1,0xe5c42626,0x929c033f}},	//   _সিংহ_, _baár, істо, _miłe, 
   {{0x3ea400f7,0xe4a40a5b,0x00000000,0x00000000}},	//   _olot_, црто, --, --, 
   {{0x55c5961f,0xe7580150,0x00000000,0x00000000}},	//   _ләзз, _тиюі_, --, --, 
   {{0x21240369,0x61e00142,0x42500244,0xe81400bc}},	//   _cwmh_, _cyml, سنور, तुवा_, 
   {{0x2bcc2db8,0xe0d802bf,0x3ea59620,0x61e400d8}},	//   _सुझा, аві_, _alot_, üila, 
   {{0x3ea43371,0x61e003b2,0x94d40150,0x8c4400fb}},	//   _blot_, _eyml, _نيڭش, ҙене, 
   {{0x3ea59621,0x61e40327,0xf41c00cc,0x00000000}},	//   _clot_, żila, _পাটৰ_, --, 
   {{0x0d200228,0x53a40220,0x2bcc1fd2,0x22680118}},	//   чүлү, _таңб, _सुजा, átků_, 
   {{0xf65c318c,0x93840092,0xdecc0023,0x00000000}},	//   _sjæl_, _አሸንፎ_, _ኣፈኛ_, --, 
   {{0x3ea59622,0x8e759623,0xdb4c01d9,0x00000000}},	//   _flot_, _гулч, نێو_, --, 
   {{0x3ea59624,0x00000000,0x00000000,0x00000000}},	//   _glot_, --, --, --, 
   {{0x89d40220,0x7ebc003a,0x7d0403b2,0x00000000}},	//   сінш, rīpt, íkst, --, 
   {{0x3ea4012d,0xdd9000e5,0x00000000,0x00000000}},	//   _zlot_, _آڈٹ_, --, --, 
   {{0x2bcc205d,0x00000000,0x00000000,0x00000000}},	//   _सुचा, --, --, --, 
   {{0xf740cc30,0x9c7c0419,0x6cc001af,0x00000000}},	//   џето, mlča, _ыйҙа, --, 
   {{0xb11002e3,0xc4c85a6f,0x00000000,0x00000000}},	// [2b020] wụnw, глаж_, --, --, 
   {{0x61e00267,0xb5f801e1,0x98b99625,0x00000000}},	//   _ryml, _obáf, rusă_, --, 
   {{0x61e003cb,0x73300131,0xaabc000d,0x00000000}},	//   _syml, كىلا, _उषाक, --, 
   {{0x98b80276,0x60d80455,0x00000000,0x00000000}},	//   pusă_, wovm, --, --, 
   {{0xc0583334,0x857400db,0x2ca4000d,0x78c401d3}},	//   гій_, _ادجئ, _olnd_, _árví, 
   {{0x3ea464b4,0x61e00c5e,0x00000000,0x00000000}},	//   _slot_, _vyml, --, --, 
   {{0x44299626,0x3ea40c18,0x00000000,0x00000000}},	//   _ieb_, _plot_, --, --, 
   {{0x44299627,0x9d142c68,0x66f846fb,0x60d8016d}},	//   _heb_, одич, ंगिक_, sovm, 
   {{0x44299628,0x3ea42a28,0x645c020c,0xf99c1497}},	//   _keb_, _vlot_, _kbri, ncèt_, 
   {{0x442800da,0xa2c10256,0x21680853,0x00000000}},	//   _jeb_, लचक्, _йиғи_, --, 
   {{0x3ea403a2,0xa3d80316,0x645d9629,0x7ed400c0}},	//   _tlot_, ाथि_, _mbri, _лідч, 
   {{0x442817c5,0x3ea401b9,0xf41c03d4,0xeaf80133}},	//   _leb_, _ulot_, _পাছৰ_, یرێت_, 
   {{0x645c649b,0x81d800bd,0xdc3c0030,0xa3a80037}},	//   _obri, ডের_, láči, खैत_, 
   {{0x4429962a,0x60c40597,0xa3d82658,0x6da0026a}},	//   _neb_, éimh, ाथा_, _хиља, 
   {{0x3cf400ab,0xe7843872,0xdc3c00d0,0x00000000}},	//   ीदीं_, путо, náči, --, 
   {{0x4429962b,0x7c2805c7,0x00000000,0x00000000}},	//   _aeb_, _hefr, --, --, 
   {{0x4429962c,0x7c280156,0xe6940c9e,0x54b8b159}},	// [2b030] _beb_, _kefr, читы, агая_, 
   {{0xf99c0699,0x44280585,0x645c01ab,0xdc3c0419}},	//   myè_, _ceb_, _cbri, káči, 
   {{0x4429962d,0x7c29962e,0xf99c359e,0x1cdc031c}},	//   _deb_, _mefr, rcèu_, _ཡེན_, 
   {{0x645d962f,0x44299630,0x7c299631,0xdc3c0419}},	//   _ebri, _eeb_, _lefr, dáči, 
   {{0x44299632,0x764c035a,0xf0740075,0xf99c02bd}},	//   _feb_, _iccy, йидә_, nyè_, 
   {{0x44299633,0xb5f80241,0x7c299634,0x8f140276}},	//   _geb_, _abág, _nefr, офич, 
   {{0xf8bc06af,0x69c0000d,0x00000000,0x00000000}},	//   lsés_, _लेनी, --, --, 
   {{0x44280457,0xf99d9635,0x645d9636,0x7ebc3b37}},	//   _zeb_, ncès_, _zbri, tūpa, 
   {{0xf8bc37a7,0x44299637,0xf99c0100,0x7d0401c6}},	//   nsés_, _yeb_, jyè_, оныг_, 
   {{0x7ebc0a28,0x7c288351,0x442801d4,0xf8bc004a}},	//   rūpa, _cefr, _xeb_, isés_, 
   {{0x7c280bed,0x7c2c01a8,0x00000000,0x00000000}},	//   _defr, ðbra, --, --, 
   {{0xc33023e4,0xb5f80ca8,0x7c28035a,0xf8bc7cd8}},	//   ווט_, _gbág, _eefr, ksés_, 
   {{0x3d8804f2,0x00000000,0x00000000,0x00000000}},	//   _نحوی_, --, --, --, 
   {{0x764c02d0,0xc31800eb,0x00000000,0x00000000}},	//   _accy, _ডিসি_, --, --, 
   {{0x66fc02b1,0x44299638,0x645c04ce,0x60c4007b}},	//   _hōki, _reb_, _rbri, éimi, 
   {{0x44299639,0x66fc0053,0x7c280a40,0x00000000}},	//   _seb_, _kōki, _zefr, --, 
   {{0x44280e37,0x6e2800dd,0x7c28914f,0x38700f89}},	// [2b040] _peb_, _megb, _yefr, _faxr_, 
   {{0x6e29963a,0xa9a41d56,0x44280070,0x66fc0374}},	//   _legb, _миқд, _qeb_, _mōki, 
   {{0x442871a0,0x645c0219,0x9f4c0162,0x4369963b}},	//   _veb_, _vbri, _íløt_, раен_, 
   {{0x44283c36,0xf99d963c,0xb2801e76,0xdc3c0030}},	//   _web_, ccès_, дышк, váči, 
   {{0x44280b89,0x60182081,0x00000000,0x00000000}},	//   _teb_, боля_, --, --, 
   {{0x44280023,0xdc3c02f0,0x929c012d,0x00000000}},	//   _ueb_, táči, _piłc, --, 
   {{0xf99d963d,0x00000000,0x00000000,0x00000000}},	//   zyè_, --, --, --, 
   {{0xf8bd963e,0xd13c0092,0xdd90007b,0xdc3c0419}},	//   nsér_, ረባቸው, فوب_, ráči, 
   {{0x6e29963f,0x25a0054c,0xb5f80ca8,0x7c280042}},	//   _degb, nyil_, _gbád, _pefr, 
   {{0xf99c0699,0x3a2c01fa,0x6e280241,0x3cf40034}},	//   vyè_, _žgp_, _eegb, ीदें_, 
   {{0xf4100375,0x24980219,0x9c7c0419,0x7c2801a8}},	//   ופת_, _morm_, blčn, _vefr, 
   {{0x6e2801e1,0x7c299640,0xa2c0000d,0xf99c02bd}},	//   _gegb, _wefr, लचट्, tyè_, 
   {{0x1cac0003,0x7c299641,0x38ac0c86,0x79a40220}},	//   ྗིད_, _tefr, _jürg_, ірме, 
   {{0xf99c0699,0xf7704d4e,0x7c28009a,0xf8bc00e4}},	//   ryè_, واز_, _uefr, esér_, 
   {{0xf99c02bd,0x3f8c031c,0xe7a80108,0xdd9401ee}},	//   syè_, nxfu_, овёл_, _фаһы, 
   {{0xf99c0100,0xd91801af,0x00000000,0x00000000}},	//   pyè_, _лоиц_, --, --, 
   {{0xf99c1f40,0x66c80408,0x20bccc41,0x00000000}},	// [2b050] rcès_, цург_, ्चाध, --, 
   {{0x24980076,0xf8bc06af,0x38640332,0x3f8c031c}},	//   _corm_, rsés_, _únr_, kxfu_, 
   {{0xf8bc20ef,0x25fcb213,0x25a000ad,0x2498045a}},	//   ssés_, लेबी_, ayil_, _dorm_, 
   {{0x69c006ab,0xd15c0023,0x27ec0254,0x00000000}},	//   _लेडी, _ሰልፍን_, üdne_, --, 
   {{0x249991e3,0x6e299642,0x659401ec,0xc18000e5}},	//   _form_, _regb, _жаяу, ٹیلٹ, 
   {{0x3cf41533,0xc5f80302,0x25f07e29,0x24999643}},	//   ीदों_, _לפרט, _आरती_, _gorm_, 
   {{0x63540209,0x6474010b,0x00000000,0x00000000}},	//   _овру, _югру, --, --, 
   {{0x66fc0374,0x38ac0036,0xa3b507c7,0xc5f005ac}},	//   _pōki, _hürd_, _जेट_, _ছ্টা_, 
   {{0x22b8012c,0x6e280217,0x38ac0213,0xe1340166}},	//   jčky_, _vegb, _kürd_, _онты, 
   {{0x6e28c991,0xb11001f2,0x00000000,0x00000000}},	//   _wegb, hụkw, --, --, 
   {{0x317c0165,0x22b80030,0xcb6800a7,0x6e2801e1}},	//   _hruz_, ečky_, щане_, _tegb, 
   {{0x9f059644,0xb5f800d2,0x66fc02b1,0x317c6ed2}},	//   _قولو, _mbáb, _tōki, _kruz_, 
   {{0x284402d3,0x6ed0054e,0x5dd4004e,0x0ba800d1}},	//   _ንምክያ, răbd, _оюшу, شاھى_, 
   {{0x48b80154,0x00000000,0x00000000,0x00000000}},	//   ংক্র, --, --, --, 
   {{0x1778169c,0x27180331,0x8ba401c0,0x22b800d7}},	//   ость_, _očne_, _хийж, ačky_, 
   {{0x3a380051,0x06080395,0xe7e001f9,0x46e801a9}},	//   _gdqp_, снак_, _खुणा_, ёдан_, 
   {{0xb5f80077,0x391000be,0x00000000,0x00000000}},	// [2b060] _abáb, _كويز, --, --, 
   {{0x6aac53c7,0xb978011a,0x00000000,0x00000000}},	//   _चतुर, _פניי, --, --, 
   {{0x389813e2,0x24999645,0x99880432,0x317cf4de}},	//   _היינ, _vorm_, _agaň_, _aruz_, 
   {{0x24981590,0x317d21f4,0x3f8002f0,0x9f580241}},	//   _worm_, _bruz_, _čku_, _àré_, 
   {{0x317d9646,0x3f800053,0x24999647,0x3a340375}},	//   _cruz_, _ōku_, _torm_, פרסם_, 
   {{0x317c05c7,0x7ebc00b0,0xf8bc00d5,0xca6001a9}},	//   _druz_, tūpo, nsép_, mplе, 
   {{0x3b7c0020,0xb5f80248,0x38ac002f,0x4eec0055}},	//   _ሥራዎች_, _gbáb, _würg_, _ṣaḍy, 
   {{0x333800d9,0x00000000,0x00000000,0x00000000}},	//   _לתלמ, --, --, --, 
   {{0x41242ed3,0xd12c0137,0xc39002d2,0x317c0210}},	//   _رفاق, _نۅن_, _óíbú, _gruz_, 
   {{0x38ac0790,0x00000000,0x00000000,0x00000000}},	//   _küre_, --, --, --, 
   {{0x4c00004b,0x38ac00a2,0xdb1c06be,0xa2b00950}},	//   پېيل, _jüre_, _üyüd, ंसप्, 
   {{0x66fd9648,0x957402d3,0xbd68009b,0x00000000}},	//   _kōku, _ብርቱዕ_, _грке_, --, 
   {{0x310c00dc,0x298400fd,0x00000000,0x00000000}},	//   ादयः_, нырг, --, --, 
   {{0xb11044fc,0x22b802f0,0x00000000,0x00000000}},	//   wụkw, rčky_, --, --, 
   {{0x1cdc0135,0x7b04012c,0xe7e02122,0xeaf81888}},	//   _རྩར_, ístě, _खुदा_, تریت_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb1100521,0xa5f97720,0x54980006,0x61e40135}},	// [2b070] rụkw, зету_, оваў_, żilj, 
   {{0x647405f5,0x38ac372c,0xbb300131,0x041800b8}},	//   нгуу, _büre_, ﺭﯗﻥ_, _kīṭa, 
   {{0xb11002e3,0x3948004e,0x5274084c,0x98b80356}},	//   pụkw, lucs_, дулу, arsă_, 
   {{0x1cdc08ea,0x38ac03fa,0xddd400bc,0x00000000}},	//   _རྩལ_, _würd_, žařs, --, 
   {{0x555401d9,0xd0080120,0xca3402dd,0x00000000}},	//   _تھزر, оеле_, _ﺗﻪﺯ_, --, 
   {{0x205400a7,0x3cf400e1,0x764800e5,0xd0580150}},	//   етър, ँगों_, ógyf, ірлі_, 
   {{0xa3d401c0,0xcef40261,0xa3440276,0xc4d00375}},	//   _зорч, мчињ, _пэтл, _סגל_, 
   {{0xb8dc31d9,0x317c3132,0x27180219,0x0d84023a}},	//   _གཏ_, _truz_, _učne_, длин, 
   {{0xdb080122,0x905403fb,0x8db40006,0x00000000}},	//   vzdá, _овац, ьскі, --, 
   {{0x4c699649,0x394806af,0x25f00456,0x8ba5964a}},	//   цион_, ducs_, _आरसी_, диож, 
   {{0xca340ef6,0x00000000,0x00000000,0x00000000}},	//   _ﺗﻪﺭ_, --, --, --, 
   {{0x929c068f,0x5f4401b9,0xb80400af,0x00000000}},	//   _miło, _سنهل, _शलजम_, --, 
   {{0x3ea0049f,0x26cc00d7,0x48740066,0x00000000}},	//   ökte_, édom_, ودآس, --, 
   {{0xb6980261,0x50dc078a,0x00000000,0x00000000}},	//   _diâm, यविष, --, --, 
   {{0x869806ed,0x37e18e63,0x00000000,0x00000000}},	//   отат_, ворг, --, --, 
   {{0x26f8007d,0x3948a244,0x2a600175,0xd1d40092}},	//   ंगेर_, bucs_, _ubib_, ክልት_, 
   {{0x38ac0365,0x00000000,0x00000000,0x00000000}},	// [2b080] _süre_, --, --, --, 
   {{0x03a403fb,0x38ac0bbc,0x61e4025c,0x00000000}},	//   мизо, _püre_, żilk, --, 
   {{0x1cdc0327,0xa3a80037,0x8338447e,0x00000000}},	//   _རྩས_, खैं_, ючат_, --, 
   {{0x9c7c6185,0x66fc02b5,0xf77026d4,0x733000d1}},	//   moče, _pōku, _شاپ_, ئىنا, 
   {{0x9c7d964b,0x6018be81,0xddc000c0,0x00000000}},	//   loče, поля_, kemš, --, 
   {{0xaf300131,0x38ad15b8,0x00000000,0x00000000}},	//   ھرىت, _türe_, --, --, 
   {{0x8eb02f7c,0x41dc2122,0xddc00010,0x9c7c0427}},	//   گەنت, _फुरस, demš, noče, 
   {{0x3da5964c,0xf8bc06af,0xdd740114,0x00000000}},	//   дроб, mpée_, егињ, --, 
   {{0x9c7c00bc,0xaf480023,0x60c400ae,0x8eb000f7}},	//   hoče, _ዘይልወ, éims, دەنت, 
   {{0x9c7c5946,0x40951185,0x3f686c00,0x00000000}},	//   koče, _ўрат, _мизо_, --, 
   {{0x9c7c1154,0x00000000,0x00000000,0x00000000}},	//   joče, --, --, --, 
   {{0xbd880050,0xf8bc07ea,0x9c7c9a24,0x00000000}},	//   _ونان_, ipée_, doče, --, 
   {{0x7e61964d,0xac70d87e,0x3e6001a9,0x00000000}},	//   _ibop, رایش, mаt_, --, 
   {{0x1bd5964e,0x394800cf,0x3e6001a9,0x00000000}},	//   _поля, rucs_, lаt_, --, 
   {{0x9c7c0fb7,0x3948067c,0x2ca00267,0xdad000d1}},	//   goče, sucs_, öjde_, _مەدھ, 
   {{0x66f400ee,0x38ac03b9,0x3e6001d5,0x6d4c0118}},	//   впсу, _bürc_, nаt_, škař, 
   {{0x1cdc025c,0x7e61964f,0x929c0034,0xe3b0ba07}},	// [2b090] _རྩོ_, _mbop, _siło, یرم_, 
   {{0x9c7c488c,0xbb2808b0,0x059401d5,0xe4a401f0}},	//   ločb, ﻤﮕﻪ_, راقگ, крхо, 
   {{0x3e60022e,0x7e619650,0xe61001d3,0x622400d1}},	//   kаt_, _obop, اشہ_, چىمل, 
   {{0xddc002fb,0x25fc0073,0x622400d1,0x00000000}},	//   zemš, लेही_, نىمل, --, 
   {{0xe1f00372,0x69081bc5,0x00000000,0x00000000}},	//   ۇسۇ_, _ürdü, --, --, 
   {{0x7e619651,0xe1f000c6,0x7bc40e2d,0x00000000}},	//   _abop, جسم_, şkuy, --, 
   {{0xb4d87220,0x3e60022e,0x409000d1,0xdb1c01e1}},	//   डकी_, fаt_, الىر, _àyèd, 
   {{0x200c00a4,0x9574001f,0x60c40332,0x00000000}},	//   _egdi_, _ያላትን_, éimr, --, 
   {{0x6fdc1fbc,0x0dc800d1,0xf1d000c5,0xd1d40b82}},	//   _पुरं, ялий_, _दखिन, ክልቲ_, 
   {{0xd0100597,0x160016f0,0x7e600921,0xed600118}},	//   _إلا_, लेयर_, _ebop, _nožů_, 
   {{0x27180e04,0x3e60022e,0x61540023,0x4f8401e0}},	//   _očna_, bаt_, _ወልደኣ, _ятаҡ, 
   {{0x9c7c2a92,0xff7800d9,0xad8001d5,0x00000000}},	//   voče, _מטעמ, _ақий, --, 
   {{0x1600012c,0xdd9400c7,0x7e941f70,0x310c00dc}},	//   लेमर_, _иацы, _سنور_, ादिः_, 
   {{0x6d598b72,0x61e40120,0x7eac01ab,0x7d74007b}},	//   mtua, üili, _iùpa, _أمور_, 
   {{0x46f462bd,0x6d599652,0x290c0030,0xfc54011a}},	//   ечат, ltua, _žiaľ_, _נבקש_, 
   {{0x9c7d9653,0x81d800bd,0x6d58009f,0x8e7c01e4}},	//   roče, ডেট_, otua, boŝe, 
   {{0x9c7c0427,0xc48400ee,0x00000000,0x00000000}},	// [2b0a0] soče, нлак, --, --, 
   {{0x6d599654,0xb9d80302,0x00000000,0x00000000}},	//   itua, _מחפש, --, --, 
   {{0x6d599655,0xf8bc06af,0xc2459656,0x826846ee}},	//   htua, upée_, енек, заев_, 
   {{0x6d588155,0xb5f80241,0x6b800051,0x32a40150}},	//   ktua, _laáy, _mrng, нуің, 
   {{0x6d58044e,0x35a029a3,0xf1bc01ef,0x25fc134e}},	//   jtua, _баяг, _žár_, लेशी_, 
   {{0x6d586129,0xf8bd9657,0x6b800477,0xf65c01bf}},	//   dtua, ppée_, _orng, _fjæs_, 
   {{0x25fc03f8,0x166400cf,0x00000000,0x00000000}},	//   लेरी_, _سەەپ_, --, --, 
   {{0xb5f892c3,0x6d5802d3,0x38ac00c5,0x3d2421d7}},	//   _mbán, ftua, _müra_, ньов, 
   {{0x6b8006a3,0x6d599658,0x90e42002,0xf65c365a}},	//   _arng, gtua, رسۇن, _kjær_, 
   {{0x6b80020b,0x93240583,0xb5f801e1,0x6ed0054e}},	//   _brng, _سرہن, _obán, răba, 
   {{0xe7e00d0d,0x6d599659,0x9eb4010b,0x9cc80022}},	//   _खुला_, atua, _ишдә, зыҟа_, 
   {{0x7e600944,0xcf24678e,0xf65c02d2,0x3e6001a9}},	//   _ubop, _شرمي, _ljær_, qаt_, 
   {{0xf2d004ac,0xb5f80248,0x38ac0ba1,0x6b8020ac}},	//   רער_, _abán, _aüra_, _erng, 
   {{0x6b800b4b,0xf88800c6,0x916c0208,0x00000000}},	//   _frng, أضحى_, _hộp_, --, 
   {{0x67d5965a,0x00000000,0x00000000,0x00000000}},	//   гору, --, --, --, 
   {{0x38ad965b,0x3cfc011c,0x0ac40588,0x9c7c013a}},	//   _düra_, lmtv_, _ашьҭ, bočc, 
   {{0x25fc05ba,0x5454192a,0xb90400fe,0x00000000}},	// [2b0b0] लेली_, кват, _বও_, --, 
   {{0x5fb027a6,0xb4d82d6b,0xfafc0200,0x3cfc0051}},	//   जनाल, डके_, lmë_, nmtv_, 
   {{0x925834d8,0x6d5805f5,0xb5f80248,0x7d080135}},	//   дает_, ztua, _gbán, _mifs, 
   {{0x27180219,0x916c0051,0x6d59965c,0x72a0129d}},	//   _učna_, _nộp_, ytua, دەرن, 
   {{0x6d59965d,0xf7711d19,0xf65d965e,0x8634010f}},	//   xtua, _شاھ_, _fjær_, _בארג_, 
   {{0xfafc02d3,0x6d580218,0xf65c08fb,0x7d080327}},	//   hmë_, vtua, _gjær_, _nifs, 
   {{0xe0d0007b,0x8d7400f1,0xceb80075,0x8f741cb8}},	//   حزن_, چاخا, мәд_, тулі, 
   {{0x6d59965f,0xfafc069c,0xf0b80214,0x8d7402f2}},	//   ttua, jmë_, _کارش_, ناخا, 
   {{0xc21006a9,0x7d0801e4,0x6d599660,0x3ea001e3}},	//   _כהן_, _bifs, utua, ökta_, 
   {{0x1cdc0327,0x00000000,0x00000000,0x00000000}},	//   _རྩཱ_, --, --, --, 
   {{0x6d599661,0x00000000,0x00000000,0x00000000}},	//   stua, --, --, --, 
   {{0x6d599662,0xfafc036e,0x752c012d,0x00000000}},	//   ptua, gmë_, _owcz, --, 
   {{0x89d40220,0x00000000,0x00000000,0x00000000}},	//   тінш, --, --, --, 
   {{0x7d089758,0xb4d80316,0x38ac04cc,0x00000000}},	//   _gifs, डको_, _püra_, --, 
   {{0x1cdc0867,0x613800d2,0xcad80276,0x00000000}},	//   _རྩི_, _kúlá, _офич_, --, 
   {{0x36640353,0x9c7c15ad,0x00000000,0x00000000}},	//   касо_, moča, --, --, 
   {{0x9c7d108f,0x6f080b6c,0x88d400c0,0x00000000}},	// [2b0c0] loča, _migc, _аўні, --, 
   {{0x6f099663,0x7d0802b9,0x7ebc4bc0,0xd90c0b28}},	//   _ligc, _xifs, rūpi, _ریف_, 
   {{0x73304da8,0x4ac4007d,0x00000000,0x00000000}},	//   لىلا, _लगाव, --, --, 
   {{0x6f091ca2,0xf8bc003e,0x9f640332,0x00000000}},	//   _nigc, mpéa_, átín_, --, 
   {{0x7540d2f6,0x013c02d3,0x1600000d,0x00000000}},	//   _княз, _ኣይፋሉ, लेदर_, --, 
   {{0x6f08e4d0,0xdfd59664,0xe28400d1,0xfafc0240}},	//   _aigc, лолы, _әһди, zmë_, 
   {{0x6f082b53,0xfafc0023,0x673c002d,0x7d08032e}},	//   _bigc, ymë_, nsrj, _rifs, 
   {{0x6f080007,0x9c7c098d,0xb7d80bd9,0xb5f80122}},	//   _cigc, doča, וקצי, _obál, 
   {{0x410400f3,0x04780055,0x00000000,0x00000000}},	//   _азав, _śuṇv, --, --, 
   {{0x7d080200,0x00000000,0x00000000,0x00000000}},	//   _qifs, --, --, --, 
   {{0xda342ecc,0x9c7c0fb7,0x61380248,0x2ca00267}},	//   лены, goča, _fúlá, öjda_, 
   {{0x2484013f,0x673c045f,0xfafc0200,0x00000000}},	//   _ɔmma_, dsrj, umë_, --, 
   {{0xfafc044e,0x66000af2,0xfce802d3,0x7d080003}},	//   rmë_, _úmkh, _መሪጹ_, _tifs, 
   {{0x77900014,0x6f080912,0x929c068f,0xfafc02d3}},	//   لیخا, _zigc, _piłk, smë_, 
   {{0xd7c826c0,0x6f08e163,0x1cdc025c,0x38ac0e78}},	//   روره_, _yigc, _རྩག_, _fürn_, 
   {{0x79a40022,0xb4d802ab,0x00000000,0x00000000}},	//   _арое, डक्_, --, --, 
   {{0x69c000d2,0xb5f80248,0xa97801e0,0x8e7c01e4}},	// [2b0d0] úmet, _gbál, _айыу_, noŝa, 
   {{0xbec00882,0x7aec009a,0x9734072d,0x00000000}},	//   _śīla, llct, _مکرا, --, 
   {{0x8e7c00df,0x2458074d,0x7ebc01ef,0x00000000}},	//   hoŝa, тахь_, _zápř, --, 
   {{0xe29802bf,0x5694013e,0x92b000fe,0xd1d80395}},	//   кає_, _самт, টচ্_, ндец_, 
   {{0x50442a9d,0x00000000,0x00000000,0x00000000}},	//   гелб, --, --, --, 
   {{0xb4b0052f,0x6f097882,0xdea4036b,0xb4f0004e}},	//   _тигә, _sigc, ییلی, _түзч, 
   {{0x289c00c8,0xdb2000ac,0x6f0800b5,0x50f401ec}},	//   ויגא, ətçi, _pigc, _ұзат, 
   {{0x9c7c09a8,0x228400f7,0x8fd00131,0x8e54187f}},	//   voča, _кууг, _қәлә, уткі, 
   {{0x6468008c,0x1cdc025c,0x4c3401c6,0xa2b02bf1}},	//   _þrið, _རྩང_, лэнт, ंसर्, 
   {{0x9c7c24dd,0x00000000,0x00000000,0x00000000}},	//   toča, --, --, --, 
   {{0x6f08003c,0xcac84623,0x6138f126,0x61e40327}},	//   _tigc, егне_, _túlá, żilt, 
   {{0x9c7c0fb7,0x38ad9665,0x9f580241,0x00000000}},	//   roča, _büro_, _àrá_, --, 
   {{0xc9540aec,0x9c7d9666,0x201015b7,0x00000000}},	//   ытны, močn, şniş_, --, 
   {{0x9c7c6875,0x290d9667,0xc8b40108,0x00000000}},	//   ločn, öda_, усмы, --, 
   {{0x7b841dc8,0xb5f802f0,0xf74001ee,0xdb7800fb}},	//   _مايە, _dbám, йеро, _асыш_, 
   {{0x9c7c0232,0x69c00077,0x673c045f,0x0ae80451}},	//   nočn, úmes, rsrj, _ڪرڻي_, 
   {{0x673c0175,0x00000000,0x00000000,0x00000000}},	// [2b0e0] ssrj, --, --, --, 
   {{0x2718151c,0xa4942354,0xf8bc0098,0x201c003a}},	//   _učno_, جیست, lpén_, xcvi_, 
   {{0x442404ac,0x07a407d5,0xc7a59668,0xc31800fe}},	//   ĝo_, _санн, _синк, _ডিঙি_, 
   {{0x82359669,0x4424010f,0x00000000,0x00000000}},	//   اراا, ŝo_, --, --, 
   {{0xa5080022,0xa19421cb,0x96940064,0x00000000}},	//   _аҵаа_, ралч, _трэш, --, 
   {{0x8e7c00df,0x00000000,0x00000000,0x00000000}},	//   voŝa, --, --, --, 
   {{0x4439966a,0xbf644739,0x7ee40395,0x00000000}},	//   map_, ادتو, лцие, --, 
   {{0x4439966b,0x9c7c0219,0xfb8400fd,0x8e7c0115}},	//   lap_, gočn, ңынн, toŝa, 
   {{0xb5f80241,0x00000000,0x00000000,0x00000000}},	//   _abáj, --, --, --, 
   {{0x4439966c,0x76880139,0x8e7c01e4,0x00000000}},	//   nap_, _köyä, roŝa, --, 
   {{0x8f440212,0x8ca40037,0xeb940798,0x00000000}},	//   _вхід, _चकरो, гиќ_, --, 
   {{0xdb1c01e1,0x00000000,0x00000000,0x00000000}},	//   _àyíd, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xed54025f,0x4439966d,0x9c7c02f0,0x00000000}},	//   _עבור_, jap_, močo, --, 
   {{0x4439966e,0x69c11010,0xb5f80ca8,0x3689966f}},	//   dap_, úmer, _gbáj, нсан_, 
   {{0x7c399670,0x69c00073,0x00000000,0x00000000}},	//   latr, _लेकी, --, --, 
   {{0x44399671,0x34483529,0xf4842377,0x75e000d1}},	// [2b0f0] fap_, ечен_, лужн, сәнҗ, 
   {{0x7c381311,0x44399672,0x9c7c28b5,0x61881772}},	//   natr, gap_, zočn, _ሞራላዊ_, 
   {{0xd3719673,0x7c3800a7,0x521456e2,0x387c0129}},	//   تها_, iatr, адет, œurs_, 
   {{0xf53c0628,0x7c399674,0x94442832,0x44380194}},	//   _två_, hatr, _چھان, aap_, 
   {{0x7c399675,0x44384b41,0x224405b1,0x46380a1e}},	//   katr, bap_, _ddmk_, _בערע, 
   {{0x44387cd8,0x7c38098d,0x8fa59676,0x92d400fe}},	//   cap_, jatr, иале, হতে_, 
   {{0x9c7c0038,0xc4d00302,0x7c399677,0xb1440133}},	//   točn, _וגם_, datr, _ڕیشم_, 
   {{0x321c0548,0x7c380076,0x25fc00bc,0x00000000}},	//   _ufuy_, eatr, लेकी_, --, 
   {{0x9c7c9a4d,0x7c380851,0x9f4c02f0,0x8c9400d3}},	//   ročn, fatr, _vzdá_, арні, 
   {{0xd10000db,0x9c7c00d0,0xccc400cf,0x6d840014}},	//   _بۋتۋ, sočn, рбой, ٖمکہ_, 
   {{0x8d742374,0x9c7c15ad,0x00000000,0x00000000}},	//   _چاتا, močl, --, --, 
   {{0x8a059678,0x443854b5,0x8d759679,0x9c7c0dfe}},	//   изне, zap_, _ناتا, ločl, 
   {{0x4439967a,0x7c39967b,0x8e7c01e4,0x2d880393}},	//   yap_, batr, loŝo, æced_, 
   {{0x6e39967c,0x764801d3,0x9c7c02f0,0xe1680092}},	//   laub, ógyn, nočl, _ሳይቀሩ_, 
   {{0x4438189f,0xf8bc065c,0x00000000,0x00000000}},	//   vap_, mpél_, --, --, 
   {{0x4439967d,0xb5f80248,0x6e39967e,0xbac401d9}},	//   wap_, _gbák, naub, _نژُن_, 
   {{0x80d4b825,0xe2840032,0x580402dd,0x4414399f}},	// [2b100] _बदले, ҙған, _қоюғ, афет, 
   {{0x25fc0034,0x6aa518ec,0x04450cc2,0x6e39967f}},	//   लेगी_, _hoif, режн, haub, 
   {{0x6e399680,0xc2085e87,0xd4f4005b,0x00000000}},	//   kaub, چقان_, сяты, --, 
   {{0x7c399681,0xc2080150,0x97b400db,0x00000000}},	//   zatr, نقان_, _ысыш, --, 
   {{0x7c399682,0x6aa40032,0xd2000166,0x6e399683}},	//   yatr, _moif, зүтк, daub, 
   {{0x44399684,0x0458007b,0x7688013d,0x527401d5}},	//   qap_, _جلسة_, _töyä, _қусу, 
   {{0x7c38325f,0x645d9685,0x03a40798,0x00000000}},	//   vatr, _icri, _тиво, --, 
   {{0x6aa59686,0x6e398646,0x1d340395,0xb7f800cc}},	//   _noif, gaub, бния, _আলমত_, 
   {{0xdd9017ae,0x7c399687,0xe51d9688,0x62819689}},	//   سود_, tatr, _भूमि_, _iamo, 
   {{0x6aa5968a,0x46c40cf1,0x00000000,0x00000000}},	//   _aoif, रोतह, --, --, 
   {{0x7c39968b,0x6aa49dd8,0x6e39968c,0xb414010f}},	//   ratr, _boif, baub, יקיס_, 
   {{0x6281968d,0x7c39968e,0x6aa5968f,0x2904007f}},	//   _jamo, satr, _coif, ïman_, 
   {{0x645c003a,0xed541d39,0x00000000,0x00000000}},	//   _ocri, _воч_, --, --, 
   {{0x628023ee,0x7c380309,0xac14d63e,0x00000000}},	//   _lamo, qatr, _кошу_, --, 
   {{0x6aa59690,0xb6c43ed6,0x569400d8,0x00000000}},	//   _foif, асай, бавт, --, 
   {{0x62819691,0x5a34ca74,0x15f407f7,0x38ac2ca8}},	//   _namo, _унит, _आरआर_, _kürk_, 
   {{0xd1d402d3,0xca28010f,0xdce003b9,0x00000000}},	// [2b110] _ክፉት_, _גופֿ, lxmı, --, 
   {{0x62813bd5,0x645c0ac5,0x6e381196,0x38ac000d}},	//   _aamo, _ccri, zaub, _mürk_, 
   {{0x62800296,0x6e380d04,0x1cdc031c,0xb5f801e7}},	//   _bamo, yaub, _རྩབ_, _mbái, 
   {{0x645d9692,0x92d4009e,0x98b800e2,0x00000000}},	//   _ecri, হত্_, pusē_, --, 
   {{0x62819693,0x645cec36,0x9c7c0cf4,0xb5f80332}},	//   _damo, _fcri, točl, _scáf, 
   {{0x62800428,0x645c00ae,0x8e7c00df,0x16840244}},	//   _eamo, _gcri, toŝo, _ئاگێ, 
   {{0x6e399694,0x9c7c0f03,0x8fa40116,0xa3d400d8}},	//   taub, ročl, сайе, _дорч, 
   {{0x62819695,0x9c7c0219,0x60c802d0,0x8e7c01e4}},	//   _gamo, sočl, _emdm, roŝo, 
   {{0x6e399696,0x9c7c0fb7,0xb69800d2,0xd1300133}},	//   raub, močj, _khâb, _رما_, 
   {{0x62819697,0x6aa4096b,0x1cdc0003,0x6e399698}},	//   _zamo, _soif, _རྩད_, saub, 
   {{0x6aa44d11,0x62819699,0x6e39969a,0xdc982fe5}},	//   _poif, _yamo, paub, ртыш_, 
   {{0xc92805f5,0x70b411a0,0x62800694,0x9c7c0010}},	//   ломж_, _अतुल, _xamo, nočj, 
   {{0x8274008f,0xef18000d,0x00000000,0x00000000}},	//   זערע_, _पूतऽ_, --, --, 
   {{0x78b40393,0x8d7405d9,0xe8c80aac,0x00000000}},	//   _clxv, _ناڪا, рҳол_, --, 
   {{0xabc0052f,0x6aa5969b,0x998800a2,0x6b740116}},	//   _файҙ, _toif, _agań_, _тәпс_, 
   {{0x6aa40270,0x96951318,0x00000000,0x00000000}},	//   _uoif, оруш, --, --, 
   {{0x2bb403be,0xb5f80241,0x00000000,0x00000000}},	// [2b120] dəcə_, _mbáw, --, --, 
   {{0x6281969c,0x388800c0,0xe5a5969d,0x00000000}},	//   _samo, gėrė_, биғи, --, 
   {{0x6281969e,0xb5f80077,0x59240135,0x27180e04}},	//   _pamo, _acád, _འཕོས_, _očni_, 
   {{0xd25800d6,0x6281969f,0xeff002d3,0x1cdc0327}},	//   иці_, _qamo, ልክዕ_, _རྩན_, 
   {{0xc0c80640,0x38880064,0x00000000,0x00000000}},	//   луке_, bėrė_, --, --, 
   {{0x5f94717e,0x00000000,0x00000000,0x00000000}},	//   жикт, --, --, --, 
   {{0x656596a0,0x9c7c0219,0xd09402d5,0xc1e002dd}},	//   ltih, bočj, ўшчы, _ﻋﺒﺩﺍ, 
   {{0x6280545b,0xe2c803e6,0xfeb80736,0xf3ec00cc}},	//   _uamo, _ئاسۆ_, طاعت_, _জলচৰ_, 
   {{0x656596a1,0x7c840b5e,0xe0580133,0x3f6c06be}},	//   ntih, буне, _نیشت_, _səud_, 
   {{0x9c7c0fb7,0x7578008d,0x27180165,0xeff002d3}},	//   močk, נטיפ, _gōng_, ልይዎ_, 
   {{0x95f402ab,0xb4d80109,0x7f84065f,0x9c7c4bee}},	//   _आर्ट_, _ovàn, _دلان, ločk, 
   {{0x38ac3630,0xf7700131,0x00000000,0x00000000}},	//   _türk_, ۋاز_, --, --, 
   {{0x656596a2,0x9c7c0f91,0xfce477e5,0x764801d3}},	//   jtih, nočk, _лодо, ógym, 
   {{0x3ea41590,0xb4d80c86,0x7ac4010a,0x00000000}},	//   _hoot_, _avàn, _ӳспе, --, 
   {{0xf64596a3,0x38ad96a4,0xfb240150,0x3ea596a5}},	//   йхан, _jüri_, _ارتپ, _koot_, 
   {{0xf84405f5,0x3ea4002e,0xb5f800e4,0x9c7cb9b7}},	//   шүүд_, _joot_, _mbáv, kočk, 
   {{0x3ea596a6,0x659596a7,0x65640009,0xa9680472}},	// [2b130] _moot_, пату, gtih, _هميم_, 
   {{0x3ea569ab,0xb5f80122,0x9c7c02fb,0x6ed00356}},	//   _loot_, _obáv, dočk, răbi, 
   {{0xcfac015b,0x38ac0254,0x9c7c0427,0xd7600345}},	//   _কেনন, _nüri_, točj, _تۆزی, 
   {{0x3ea596a8,0xe570066d,0x9c7c0010,0x2b4001d3}},	//   _noot_, بطہ_, fočk, ájci_, 
   {{0x2c48016b,0x9c7c09a8,0x2bb400ac,0x466000d1}},	//   _wɔdɔ_, ročj, rəcə_, _تۇقق, 
   {{0x2418c6cc,0x61e000d5,0x929c012d,0x9c7c0219}},	//   _горы_, _dxml, _piłs, sočj, 
   {{0xf3f056e6,0x3ea4fb81,0x35dc000d,0x985c0171}},	//   _رأس_, _boot_, _नखड़, dāļu_, 
   {{0x9c7c0232,0x0ea996a9,0x3ea40076,0x680001ef}},	//   bočk, ркий_, _coot_, _hájí, 
   {{0x2d880316,0x3ea52e54,0xb7fc015b,0x52b400ce}},	//   íce_, _doot_, ঃখিত_, ंसीस, 
   {{0x271804fe,0x0b44013e,0xdfa80014,0xf65c032e}},	//   _hōne_, онон, _گُمو_, _smæl_, 
   {{0x3ea596aa,0xcb6996ab,0x8d940092,0x00000000}},	//   _foot_, шане_, ግላቸው_, --, 
   {{0x65640ac5,0x6ee400c6,0x3ea40582,0x27180219}},	//   ytih, _اسئل, _goot_, _učni_, 
   {{0x8c4596ac,0x1cdc003d,0x38ac0065,0x0ba80137}},	//   _деле, _རྩམ_, _züri_, _چاعى_, 
   {{0x6c6401ed,0xc6900014,0x00000000,0x00000000}},	//   _طلبہ_, ڈِس_, --, --, 
   {{0x3ea400e8,0x8e7c01e4,0xed5400fb,0xc69001d9}},	//   _yoot_, joŝk, _тоҙ_, وِس_, 
   {{0x2ca427bb,0x656596ad,0x3ea400e8,0x59c40412}},	//   _hond_, ttih, _xoot_, _लेकर, 
   {{0xb5f80005,0xda6400cf,0xcfac0154,0x00000000}},	// [2b140] _acáb, _رايي, _কেমন, --, 
   {{0x39400139,0x9c7c00d7,0x00000000,0x00000000}},	//   _юньг, vočk, --, --, 
   {{0x2ca596ae,0x656436d1,0xa3040116,0xd3980139}},	//   _mond_, stih, зүве, бәтә_, 
   {{0x2ca596af,0x656596b0,0xfbd0011a,0x00000000}},	//   _lond_, ptih, ותב_, --, 
   {{0x656520be,0x2ca40660,0x3ea596b1,0x38ac0432}},	//   qtih, _oond_, _root_, _süri_, 
   {{0x3ea40a40,0x11380006,0x9c7ccd97,0x00000000}},	//   _soot_, сяцы_, ročk, --, 
   {{0x3ea575e4,0x9c7c01fa,0xb5f80332,0xd36c215c}},	//   _poot_, sočk, _gcáb, _مۇل_, 
   {{0xbe898466,0x2a600048,0xbd681abc,0x9c7d96b2}},	//   рске_, _ncib_, арое_, moči, 
   {{0x9c7c0f72,0xeeb400d6,0x2ca48a83,0xdb2001e1}},	//   loči, ільш_, _bond_, _ìwúy, 
   {{0x38ac00c5,0x2a6006be,0x3ea51107,0x7b64020f}},	//   _türi_, _acib_, _woot_, отме, 
   {{0x3ea596b3,0x2ca4f03e,0x9c7c85ab,0xde70002b}},	//   _toot_, _dond_, noči, _ekāṃ_, 
   {{0xb4d8026c,0x66fc003e,0x6d4c00d0,0x7ac40816}},	//   _avàl, _tōky, ácac, існе, 
   {{0xdd9596b4,0x5ed00154,0x298596b5,0xadb400ae}},	//   _халы, হকদে, мырг, _وهما_, 
   {{0x9c7d96b6,0x2ca401ed,0x00000000,0x00000000}},	//   koči, _gond_, --, --, 
   {{0x9c7c151c,0xa81403b7,0x2a60062c,0x999800bc}},	//   joči, ддрш, _fcib_, pasů_, 
   {{0xdae80451,0x2ca50253,0x6ac400ae,0x00000000}},	//   _دفعو_, _zond_, _يقوم, --, 
   {{0x2ca4020c,0x69c801e4,0xd5f400f1,0xd25000e5}},	// [2b150] _yond_, ĝdec, سترګ, ہنا_, 
   {{0xb5f800d8,0x647401c0,0x041800cd,0x00000000}},	//   _acác, мгуу, _kūṭa, --, 
   {{0x9c7c0fb7,0xd25000c6,0x5884035b,0x00000000}},	//   goči, فنا_, _дыҟа, --, 
   {{0x87780bd9,0x6234084c,0xe2c801e2,0x00000000}},	//   _פארי, децу, يولو_, --, 
   {{0xc6901a4c,0x466000cf,0x414401ec,0x00000000}},	//   _נאך_, _سۇلق, здің, --, 
   {{0xd8e40220,0x26dc02d2,0x00000000,0x00000000}},	//   _ﺍﻳﻪﻟ, _ívor_, --, --, 
   {{0x2ca596b7,0x271800b0,0x8e7c00df,0x118800e5}},	//   _rond_, _tōne_, loŝi, _گھاٹ_, 
   {{0x6d440227,0x91b996b8,0x2ca4033f,0x23b400f1}},	//   ņjam, _лгбт_, _sond_, _کمېس, 
   {{0xb5f80241,0x2ca4123b,0x8e7c0115,0xdb0801d3}},	//   _gbát, _pond_, noŝi, gydí, 
   {{0x20540228,0x2a600332,0x00000000,0x00000000}},	//   _окуя, _scib_, --, --, 
   {{0x2ca596b9,0x8b2400c0,0x0ae800db,0xa0c40472}},	//   _vond_, ядне, йдой_, _تيلو, 
   {{0x2ca596ba,0x09e4020a,0x00000000,0x00000000}},	//   _wond_, зомн, --, --, 
   {{0x9c7c63e0,0x2ca49af4,0xb5f801e7,0x427800df}},	//   zoči, _tond_, _mbás, זארג, 
   {{0x6ed0054e,0xcb68009a,0x00000000,0x00000000}},	//   răbu, _همته_, --, --, 
   {{0xc7a406bb,0x07a40116,0x6ed00356,0x00000000}},	//   чивк, чавн, săbu, --, 
   {{0x9c7c0122,0xb6a000b1,0x68440023,0x00000000}},	//   voči, нисл, _ንዝምድ, --, 
   {{0x8e7c0115,0x0448004e,0x00000000,0x00000000}},	// [2b160] goŝi, йпак_, --, --, 
   {{0x59c4033f,0xc5fc00eb,0x00000000,0x00000000}},	//   _लेटर, ংখলা_, --, --, 
   {{0x6ff006be,0x00000000,0x00000000,0x00000000}},	//   _mәcә, --, --, --, 
   {{0x9c7cb515,0x2d8d7a02,0x00000000,0x00000000}},	//   roči, _orge_, --, --, 
   {{0x9c7d96bb,0xd5ac01d3,0x00000000,0x00000000}},	//   soči, _پہل_, --, --, 
   {{0x26c00115,0x99d800fe,0x705000f2,0xdb0c03b2}},	//   lhio_, _সৰুক, فنها, íhús, 
   {{0x2d8d96bc,0xdfd000c6,0x26c003a0,0x00000000}},	//   _arge_, ضية_, ohio_, --, 
   {{0x6e404da8,0x52540114,0x00000000,0x00000000}},	//   ىنىم, _отуђ, --, --, 
   {{0x7c841b2e,0x38acf3aa,0x25a00077,0xf65c00b5}},	//   пуне, _kürt_, nxil_, _smæk_, 
   {{0x31b80302,0x160006ab,0xb6980051,0x00000000}},	//   _הזמנ, लेटर_, _nhân, --, 
   {{0x2d8d96bd,0x59240135,0x1a784f35,0xff5196be}},	//   _erge_, _འཕངས_, обны_, _سخا_, 
   {{0xb698025a,0x7be00421,0x00000000,0x00000000}},	//   _ahân, _ātuā, --, --, 
   {{0x7e60293d,0x26c00214,0xcee88d1a,0x00000000}},	//   _icop, dhio_, _برلن_, --, 
   {{0x7c64021a,0xa3ac000d,0xb698015d,0x00000000}},	//   _راتل, गहा_, _chân, --, 
   {{0x26c01aa1,0x6c800f13,0x77900f01,0xd14c02d3}},	//   fhio_, _سليم, ریحا, _ኣይትፍ, 
   {{0x26c0089c,0x0ccc00bd,0xab8000a7,0x24980356}},	//   ghio_, রকৃত, _чушк, _anrm_, 
   {{0xaab80150,0x00000000,0x00000000,0x00000000}},	// [2b170] _ءدىر_, --, --, --, 
   {{0x7aec003a,0x8e7c0115,0x53340120,0x1ae400eb}},	//   loct, roŝi, дежт, _নওয়া, 
   {{0x7e60014b,0x25a00548,0x38ac00fd,0x8e7c0115}},	//   _ocop, axil_, _dürt_, soŝi, 
   {{0x26c196bf,0x7aed96c0,0x8e7c0115,0xd17400cf}},	//   chio_, noct, poŝi, дыкы, 
   {{0x7aec0393,0x98b800e2,0x9c7c0010,0x929c0210}},	//   ioct, jusī_, loču, _chła, 
   {{0x7e6196c1,0x38ac02b5,0x7aec0208,0x30a4117e}},	//   _acop, _türu_, hoct, ярев, 
   {{0x271806c8,0x2d8c02ea,0xb5f80248,0x9c7c0010}},	//   _kōna_, _srge_, _gbár, noču, 
   {{0x765c0007,0x2d9c01c4,0xcd2827a8,0x00000000}},	//   ngqy, txue_, ожие_, --, 
   {{0x27180053,0xcd0596c2,0x7e600334,0x1600033f}},	//   _mōna_, мпий, _dcop, लेचर_, 
   {{0xaf3596c3,0x7e6196c4,0x38ac07c5,0x26c00156}},	//   _فرصت, _ecop, _mürs_, zhio_, 
   {{0x8d7403e6,0x00000000,0x00000000,0x00000000}},	//   ساکا, --, --, --, 
   {{0x271804fe,0x5f749f01,0xb69800d2,0x25a00548}},	//   _nōna_, _سامر, _shân, yxil_, 
   {{0xb69800d2,0x19b8084c,0x2d8c0d63,0x9e34004e}},	//   _phân, пурь_, _urge_, _чечч, 
   {{0xdc3c0030,0x6d580194,0x26c00374,0x87b800d8}},	//   _záľu, muua, whio_, оубт_, 
   {{0x26c00cfd,0x9c7c0118,0x7e6003ac,0x00000000}},	//   thio_, točv, _ycop, --, 
   {{0x7aed1acb,0x7e6000b5,0x00000000,0x00000000}},	//   coct, _xcop, --, --, 
   {{0xc4840fab,0x05640024,0x6d5800a3,0x26c158d7}},	// [2b180] млак, ьван, nuua, rhio_, 
   {{0x26c196c5,0x9c7cbc56,0x38ad96c6,0x25a0022e}},	//   shio_, boču, _dürs_, rxil_, 
   {{0xb69800d2,0x26c0ad57,0x4344da2d,0x3898011a}},	//   _khâl, phio_, феев, _ויינ, 
   {{0x6d5996c7,0x38ac0730,0x9f580241,0x00000000}},	//   kuua, _fürs_, _áré_, --, 
   {{0x6d591c2f,0x205400a8,0x38ac010e,0xb6a0799e}},	//   juua, еӂер, _gürs_, _риял, 
   {{0x7e6196c8,0x6d58003e,0x7aec067c,0x6b8003ac}},	//   _scop, duua, zoct, _osng, 
   {{0x442996c9,0xf8bcaeae,0x6d4d96ca,0x00000000}},	//   _ifb_, mpét_, ácan, --, 
   {{0xf8b83ead,0x2f1434d8,0xb6b8010f,0x00000000}},	//   _उत्प, мощь_, ַציי, --, 
   {{0x9d1596cb,0x4428003e,0x6d580194,0x6d4c0cf4}},	//   ндич, _kfb_, guua, šcan, 
   {{0x4428007c,0x9b580120,0xa2b401f9,0x00000000}},	//   _jfb_, пиот_, _आवड्, --, 
   {{0x442996cc,0x7aeccbed,0x46dc7c33,0x3ea0007c}},	//   _mfb_, toct, नचाह, ökts_, 
   {{0x6d58113c,0x7e60014b,0xb698004a,0x6e9000c6}},	//   buua, _ucop, _châl, _للما, 
   {{0x6b80047e,0x7aed109d,0xada00022,0x00000000}},	//   _esng, roct, _иацл, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8600007f,0x7c2996cd,0x139001ec,0x7aec0306}},	//   _dakٍ_, _iffr, _ءﻭﻟﺘ, poct, 
   {{0x44297643,0x561c015b,0xab94009f,0x00000000}},	//   _afb_, তর্ক_, _آخور_, --, 
   {{0x38ac0086,0x442996ce,0x8e7c01e4,0x9c7c01ef}},	// [2b190] _dürr_, _bfb_, moŝt, bočt, 
   {{0x9c7c0030,0x8e7c01e4,0x00000000,0x00000000}},	//   poču, loŝt, --, --, 
   {{0x70d805f9,0x44280711,0x271800b0,0x281401d9}},	//   _बदौल, _dfb_, _wōna_, _لوٝس, 
   {{0x27181f4c,0x442996cf,0x3864004e,0x91c4008e}},	//   _tōna_, _efb_, _эзүү_, нәзл, 
   {{0x7c2996d0,0x442996d1,0xe1640128,0xda0005d7}},	//   _offr, _ffb_, ندوي, ोधित_, 
   {{0xf8bd96d2,0x442803e0,0x00000000,0x00000000}},	//   mpés_, _gfb_, --, --, 
   {{0x8e7c01e4,0xf8bcad72,0xe0d0132f,0x3264011c}},	//   koŝt, lpés_, جزن_, _отав, 
   {{0x7c2996d3,0x0d84020f,0x6d5996d4,0x0e640408}},	//   _affr, елин, tuua, хкин, 
   {{0x9f4c02fb,0x8c44010b,0xc0cc0023,0x6900007c}},	//   _vydá_, непе, እሎም_, döen, 
   {{0xf0b88707,0xf8bc004a,0x6d58023a,0x0ccc0154}},	//   _بارش_, ipés_, ruua, রক্ত, 
   {{0x6d58013c,0x20c80150,0xca80022e,0x00000000}},	//   suua, _تٸلٸ_, аtаy, --, 
   {{0x798c074d,0x752c02c4,0x7c2996d5,0x1dd001ad}},	//   fvcw, _otcz, _effr, _तेवत, 
   {{0xb69800d2,0x9c7c022a,0xb5f80332,0x9ac40131}},	//   _châm, točt, _scán, тияҗ, 
   {{0x764c0334,0x38ac0254,0x00000000,0x00000000}},	//   _adcy, _sürr_, --, --, 
   {{0x8e7c01e4,0xe8e00073,0x44286c49,0x37e0001b}},	//   boŝt, _नदीच, _rfb_, горг, 
   {{0x44280223,0x00000000,0x00000000,0x00000000}},	//   _sfb_, --, --, --, 
   {{0x9c7c0232,0x44280ac5,0x9c5802dd,0x561c03d4}},	// [2b1a0] počt, _pfb_, _ءجۇز_, তৰ্ক_, 
   {{0xb46196d6,0x03240cc9,0x00000000,0x00000000}},	//   лкул, еджн, --, --, 
   {{0x0318ad99,0x929c068f,0x44284fc3,0xf8bc003e}},	//   ستات_, _chło, _vfb_, rpét_, 
   {{0xb6a0008e,0xf7d4008f,0x6d485991,0xbb38010f}},	//   _биюл, _טויש_, _ovga, פעני, 
   {{0xe1f80364,0x15b00131,0x6d4c02f0,0x44280139}},	//   фҳа_, _پەلس, ácal, _tfb_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf8b0011a,0x00000000,0x00000000,0x00000000}},	//   רשו_, --, --, --, 
   {{0xc30435e6,0x00000000,0x00000000,0x00000000}},	//   _سبزو, --, --, --, 
   {{0x7eac0ffb,0x00c80166,0x11f801d9,0x00000000}},	//   _dùpp, _елак_, _ہوہک_, --, 
   {{0x95780023,0x7c6445cc,0x9c7c0419,0x00000000}},	//   _ርክብን_, راخل, vočs, --, 
   {{0x6d48a580,0x9c7c0427,0xa3e000dc,0x00000000}},	//   _evga, jnče, दपि_, --, 
   {{0xbe680064,0x7de401ec,0x00000000,0x00000000}},	//   _хадж_, _пілд, --, --, 
   {{0x63680166,0x8e7c00df,0x00000000,0x00000000}},	//   _kοns, roŝt, --, --, 
   {{0xb4acacd2,0x7c2990e1,0x01e00154,0x9f580ca8}},	//   _ओके_, _uffr, _বরাদ, _àró_, 
   {{0x37040064,0x8e7c0115,0x69d800dc,0x00000000}},	//   ечав, poŝt, _śvet, --, 
   {{0xabf80375,0x69000254,0x00000000,0x00000000}},	//   _מהור, löel, --, --, 
   {{0xddc004fe,0xf8bc004a,0xaa54034b,0x00000000}},	// [2b1b0] kamō, upés_, _свыш, --, 
   {{0x57b40124,0x9864066d,0xf4f42832,0xa8a596d7}},	//   _абот, _جیسے_, رواں_, _брюк, 
   {{0xd6d01c67,0x764800dd,0x35800125,0xf09c001e}},	//   _نقد_, ógys, _የካቲት_, _đà_, 
   {{0xf8bc004a,0x3948004e,0xe3b0007b,0x41d000cd}},	//   ppés_, oscs_, حرك_, _देहस, 
   {{0x86580a7c,0xb400010b,0x98b80153,0x00000000}},	//   _קדשי, түңд, nusį_, --, 
   {{0x6d4c0419,0x00000000,0x00000000,0x00000000}},	//   ácam, --, --, --, 
   {{0x7eac0ffb,0x23e40006,0x00000000,0x00000000}},	//   _pùpp, _бітв, --, --, 
   {{0x41d0243c,0x98b80024,0xc3300375,0x61ec0129}},	//   _देवस, kusį_, _כול_, éolé, 
   {{0x321c00e4,0x98b80024,0xa1580124,0x00000000}},	//   _iguy_, jusį_, _пату_, --, 
   {{0xf00000d1,0x9c7c0030,0x98b800c0,0x00000000}},	//   _йүли, ynče, dusį_, --, 
   {{0xb5f8007b,0xf65c01bf,0x00000000,0x00000000}},	//   _scál, _klæd_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9f580248,0xa2b428fe,0x98b800c0,0x9974854b}},	//   _àrò_, _आवस्, gusį_, лурш, 
   {{0x2018004e,0x07180ef6,0xf98000d8,0x00000000}},	//   _úric_, _ﺷﯩﯔ_, јгро, --, 
   {{0x46f400d6,0xf7400261,0x01e000cc,0x00000000}},	//   вчат, иеро, _বৰাদ, --, 
   {{0x321c0016,0xca48004b,0xa03c001f,0xe6b401b9}},	//   _nguy_, _کلکه_, _አዎንታ, دلرگ, 
   {{0xa2940046,0x6a840220,0xd90c10c4,0x090428e5}},	// [2b1c0] ғалі, _алқа, تیی_, _ипин, 
   {{0x321c0588,0xb8b001ec,0xe9d80150,0x8724022e}},	//   _aguy_, _көсі, _окқ_, _имож, 
   {{0x82680408,0x6d4c0419,0x44140798,0x00000000}},	//   даев_, ácaj, тфат, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x38c81056,0x41d01d03,0x690001f4,0x00000000}},	//   _رایی_, _देशस, yöel, --, 
   {{0xbf640133,0x79880042,0x929c012d,0x5d8401f0}},	//   ندبو, _âgwe, _miły, ҳтоҷ, 
   {{0x7ee596d8,0xddc002b5,0x41d001ad,0x5ff42f09}},	//   кцие, ramō, _देरस, ызку, 
   {{0xf65c037e,0x999801f1,0x6adc0037,0x4ee400fb}},	//   _glæd_, lasť_, मचोर, лсыҡ, 
   {{0xd9e000bc,0x00000000,0x00000000,0x00000000}},	//   _पखेट, --, --, --, 
   {{0xb69800d2,0x98b80024,0x443800b5,0x00000000}},	//   _phâk, vusį_, nbp_, --, 
   {{0x34b40302,0x4438010a,0x9bd40212,0x5b1400f0}},	//   דפים_, ibp_, ужні, лмот, 
   {{0xb4ad96d9,0x4fd804ac,0x19580bd6,0xc0cc0023}},	//   _ओक्_, _אַנד, намы_, እዎም_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x972446c9,0xb864e6c4,0xb8d89543,0x7c380175}},	//   افرو, _یادو, _अक_, mbtr, 
   {{0x3e54013f,0x60d8047e,0xe6540212,0x7c38002f}},	//   _bɛtɔ_, hivm, ивсь, lbtr, 
   {{0xe5b447dd,0x60d86525,0x4438045a,0xbbe000bc}},	// [2b1d0] айты, kivm, fbp_, _पशुक, 
   {{0xfafc069c,0xdb08005b,0x60d8014f,0x048400d1}},	//   llë_, sydä, jivm, ләси_, 
   {{0xa2b4433a,0xe9d0004b,0x60d8014f,0x00000000}},	//   _आवश्, _هغی_, divm, --, 
   {{0x3acc0210,0x00000000,0x00000000,0x00000000}},	//   tępy_, --, --, --, 
   {{0x21240007,0x86580375,0xa2b428e0,0xe2900214}},	//   _cumh_, _אדרי, _आवर्, تذل_, 
   {{0xd0080262,0x91040a89,0x674808a5,0x00000000}},	//   неле_, ыпле, _þrjó, --, 
   {{0x3d041533,0x32dc010e,0xa4d40212,0xcef40120}},	//   _सीधे_, _açyň_, _торі, лчињ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4d1596da,0xa184005b,0x00000000,0x00000000}},	//   льот, _выхл, --, --, 
   {{0x60d80998,0x2244009a,0x3d04000d,0x00000000}},	//   civm, _zemk_, _सीदे_, --, 
   {{0x8e7596db,0x8f3400d8,0x00000000,0x00000000}},	//   _булч, _сеец, --, --, 
   {{0xc72423f6,0x00000000,0x00000000,0x00000000}},	//   ғдай, --, --, --, 
   {{0x7c393548,0xd944010b,0x89d401ec,0x00000000}},	//   bbtr, аҗык_, уінш, --, 
   {{0x2efc022f,0x8c4596dc,0xfafc0240,0x6e380334}},	//   lluf_, _секе, alë_, lbub, 
   {{0x869956ff,0x6d5807c5,0x0b4401d5,0x00000000}},	//   нтат_, lrua, _ёнин, --, 
   {{0x6e380c67,0x81a80183,0x60d8007f,0x00000000}},	//   nbub, খনত_, zivm, --, 
   {{0x84580408,0x35a00b01,0xef1800c5,0x00000000}},	// [2b1e0] ерет_, батг, _पूछऽ_, --, 
   {{0x8884dea5,0x03a4024d,0x6d58005a,0x6e3996dd}},	//   _слож, лизо, irua, hbub, 
   {{0x73300075,0x6e38020c,0x6d58f7c7,0x99980419}},	//   مىلا, kbub, hrua, rasť_, 
   {{0x6d58069c,0x46a447c5,0x60d8014f,0x00000000}},	//   krua, _самв, wivm, --, 
   {{0x6e38110c,0x44380204,0xc5b402d5,0x8e7c01e4}},	//   dbub, pbp_, _сёнь, voŝp, 
   {{0xc0e002d3,0x6d5996de,0x7dd80450,0x9574013d}},	//   _ምቛም_, drua, _løsø, _тыюч, 
   {{0x9c7c0427,0x9f3402dd,0xd3780408,0x60d8007c}},	//   jnča, шейі, рчĕ_, rivm, 
   {{0x6e3996df,0x60d996e0,0x5d546b1c,0x6d5996e1}},	//   gbub, sivm, акит, frua, 
   {{0x6d5996e2,0x60d80455,0xdd9000d1,0x00000000}},	//   grua, pivm, تۈش_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x1a6475e5,0x5fa8454f,0x6e3852bf,0x6d5800c5}},	//   لیغی_, _कपिल, bbub, arua, 
   {{0xfaa4bbb8,0xeaf80133,0x00000000,0x00000000}},	//   ушон, ێرێت_, --, --, 
   {{0x6d5996e3,0xfafc0200,0xc8580023,0x00000000}},	//   crua, rlë_, _ንምኽፋ, --, 
   {{0x9b94084c,0x5fa81b61,0xa3c407f7,0x00000000}},	//   _викц, _कपाल, एना_, --, 
   {{0x81a80183,0xb4d8004e,0xd6b402e8,0xab9401f7}},	//   খনি_, _ovàr, айвъ, _مخير_, 
   {{0x963596e4,0x79a414a4,0x99980022,0xf65c01bf}},	//   рнац, _брое, _акит_, _slæb_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [2b1f0] --, --, --, --, 
   {{0xa6156442,0x64a40063,0xe4a40408,0x00000000}},	//   смуч, бађа, йрхо, --, 
   {{0xd2510fca,0x00000000,0x00000000,0x00000000}},	//   قنا_, --, --, --, 
   {{0x0ce00e5b,0x569596e5,0x6d580240,0x92580166}},	//   _पद्म, _тамт, yrua, тадт_, 
   {{0xe2c8021a,0xb5f801e7,0x00000000,0x00000000}},	//   دونو_, _ocái, --, --, 
   {{0x74f000db,0x45a000db,0x92d40154,0xb5f800d7}},	//   _اۋئا, _بەكك, সকে_, _obáz, 
   {{0x2efc0135,0x6e3801e3,0x00000000,0x00000000}},	//   tluf_, tbub, --, --, 
   {{0x6d589789,0x00000000,0x00000000,0x00000000}},	//   trua, --, --, --, 
   {{0xfd4400ee,0x2efc3b97,0x22580108,0x6d5996e6}},	//   азык_, rluf_, _щиты_, urua, 
   {{0x6d5996e7,0x8b9400c7,0x2efc031c,0x6e38007c}},	//   rrua, армч, sluf_, sbub, 
   {{0x4b500133,0x6e38007c,0x00000000,0x00000000}},	//   ڕێژر, pbub, --, --, 
   {{0x6d5996e8,0xddd40841,0x00000000,0x00000000}},	//   prua, šašt, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb5f8007b,0x00000000,0x00000000,0x00000000}},	//   _gcái, --, --, --, 
   {{0x290400da,0x17c40588,0x00000000,0x00000000}},	//   ēma_, барҭ, --, --, 
   {{0x06840261,0x00000000,0x00000000,0x00000000}},	//   јган, --, --, --, 
   {{0xfb10030c,0xbaf8011a,0x93640124,0x00000000}},	// [2b200] _بويج, _בהקש, ҩнуҵ, --, 
   {{0x79880042,0xc3940114,0x00000000,0x00000000}},	//   _âgwa, ијењ, --, --, 
   {{0x436800a7,0x07a596e9,0xc7a42472,0xb5f801e1}},	//   таен_, _танн, _тинк, _mbáy, 
   {{0xd408007b,0x869800d8,0x41d00550,0x00000000}},	//   اتكم_, _ртот_, _देउस, --, 
   {{0x690002f6,0xb2201945,0xa194dd5c,0x008596ea}},	//   töeh, әмәл, салч, илдо, 
   {{0x656596eb,0x26c196ec,0x568401d9,0x23480330}},	//   muih, lkio_, _پگہہ, _مسری_, 
   {{0xd2980046,0x656402f6,0xadc00248,0xfe0c0022}},	//   _өтті_, luih, _ilẹk, rữme_, 
   {{0xb5f995b4,0x23880356,0x43680107,0x26c04f73}},	//   _abáy, _işj_, _паҳн_, nkio_, 
   {{0x656596ed,0x26c00064,0x6da000d8,0x00000000}},	//   nuih, ikio_, жиња, --, 
   {{0x7050007b,0x7fd80798,0x00000000,0x00000000}},	//   _ونقا, _ифет_, --, --, 
   {{0xb69800d2,0x26c0011c,0x65643266,0x00000000}},	//   _khât, kkio_, huih, --, 
   {{0x656596ee,0x00000000,0x00000000,0x00000000}},	//   kuih, --, --, --, 
   {{0xfce41fbd,0xf3e41c82,0xe8b408e9,0xaa940137}},	//   _кодо, _কৰাৰ_, ुसूच, цияч, 
   {{0xf770ae53,0xb5f80248,0x26c00024,0xacf00244}},	//   ياز_, _gbáy, ekio_, _وسوت, 
   {{0xab244a8f,0xf64468f0,0xb8ec07d0,0xcc6400cf}},	//   _која_, ихан, _शत_, _انىۋ, 
   {{0xeb300345,0x00000000,0x00000000,0x00000000}},	//   _بروخ, --, --, --, 
   {{0xa6f40220,0x545400d1,0x65640022,0x00000000}},	// [2b210] ізуш, йват, guih, --, 
   {{0xa43800db,0x00000000,0x00000000,0x00000000}},	//   изуу_, --, --, --, 
   {{0xb36400a7,0xd3740114,0x00000000,0x00000000}},	//   ръзк, слећ, --, --, 
   {{0xb69996ef,0x947401d9,0xb5f002dd,0x65640108}},	//   _chât, _گگرا, _дүбі, buih, 
   {{0x50b44855,0x65640113,0xe188009f,0x00000000}},	//   йску, cuih, لئون_, --, 
   {{0x50b80d17,0x00000000,0x00000000,0x00000000}},	//   دگرد_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9e64aace,0x70540354,0x00000000,0x00000000}},	//   زاين, _кĕпе, --, --, 
   {{0x26c001c0,0x5f747c91,0x61e401e7,0xe7a8000d}},	//   zkio_, _ژانر, úile, _मिलs, 
   {{0x5f957b88,0xb5f800e4,0x26c00024,0x60e801d3}},	//   _мифт, _icáu, ykio_, ármű, 
   {{0x8d740330,0x0f1407e6,0x98b80139,0x00000000}},	//   _هاتا, _умею, dtsı_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xcb6813dc,0x65640108,0x00000000,0x00000000}},	//   _баке_, vuih, --, --, 
   {{0x79880142,0xbc70007b,0x00000000,0x00000000}},	//   _âgwn, _رهيب, --, --, 
   {{0x65640124,0x00000000,0x00000000,0x00000000}},	//   tuih, --, --, --, 
   {{0x6aa4afb1,0x26c196f0,0xb6c800e5,0x00000000}},	// [2b220] _inif, rkio_, ھاہے_, --, 
   {{0x07f8034c,0x15b80220,0x04c8a3a9,0xb3000327}},	//   _مرجع_, шысы_, دوئي_, _མཚུང_, 
   {{0xb698004a,0x6564023a,0x6aa41382,0x00000000}},	//   _châs, suih, _knif, --, 
   {{0x10f801d3,0x65640108,0x412800db,0x9c7c00d7}},	//   یبوں_, puih, годо_, ynčo, 
   {{0x6aa4009f,0x656596f1,0x00000000,0x00000000}},	//   _mnif, quih, --, --, 
   {{0xf990011a,0xa2840133,0xb9ec0092,0x443c00a2}},	//   פרו_, _ژیاو, _ነዋ_, _ýt_, 
   {{0x6aa40241,0x7e280816,0x3f9996f2,0x00000000}},	//   _onif, ліпа_, ípu_, --, 
   {{0x6aa40003,0x00000000,0x00000000,0x00000000}},	//   _nnif, --, --, --, 
   {{0xaacc095f,0xb14001a9,0x00000000,0x00000000}},	//   ासनक, _ннтл, --, --, 
   {{0x6aa400a9,0xb5b40375,0x3ea0045f,0x90700150}},	//   _anif, צליח_, űkt_, _يۇنش, 
   {{0xb4f8008f,0x60c8035a,0x201800e4,0xdb240432}},	//   רליר, _ildm, _àri_, _ösüp, 
   {{0x635c0276,0x200c022e,0x7ac40108,0x00000000}},	//   mănă, _izdi_, ссое, --, 
   {{0xed5400f3,0x768400c7,0x00000000,0x00000000}},	//   _гоч_, ҩыбж, --, --, 
   {{0x6aa596f3,0x58d4009d,0x00000000,0x00000000}},	//   _enif, цогт, --, --, 
   {{0x56948b11,0x5fa80037,0xb8c40220,0x00000000}},	//   оавт, कमिल, _ۇزدى, --, 
   {{0x6aa401a4,0x00000000,0x00000000,0x00000000}},	//   _gnif, --, --, --, 
   {{0x60c84380,0x58d40a83,0xb4241867,0x75ec0139}},	// [2b230] _oldm, _моит, معاو, gеzе, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdce00552,0x00000000,0x00000000,0x00000000}},	//   jumč, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x90c42d30,0xe1f0cf8c,0x00000000,0x00000000}},	//   юбле, رسن_, --, --, 
   {{0xb9ec00b7,0x00000000,0x00000000,0x00000000}},	//   _ነጋ_, --, --, --, 
   {{0x8d54ed5a,0x60c996f4,0xb8f80327,0x00000000}},	//   оточ, _eldm, _རཏ_, --, 
   {{0xb5f800e4,0x200d96f5,0x00000000,0x00000000}},	//   _icás, _ezdi_, --, --, 
   {{0xdce000d7,0x00000000,0x00000000,0x00000000}},	//   bumč, --, --, --, 
   {{0x0ae80108,0x00000000,0x00000000,0x00000000}},	//   идой_, --, --, --, 
   {{0x6d4c0077,0x00000000,0x00000000,0x00000000}},	//   ácas, --, --, --, 
   {{0x3e3027a1,0x8d7405d9,0x78b401e3,0x00000000}},	//   _غفور, _ڇاڪا, _boxv, --, 
   {{0x78b40354,0x0b4400db,0xc4c801ec,0x00000000}},	//   _coxv, _днкн, _ﻓﻀﺎﺌ, --, 
   {{0x2d8c0010,0xb5f8013a,0x00000000,0x00000000}},	//   _hsge_, _ocás, --, --, 
   {{0xb6a0ee8b,0x09e40eff,0x6aa596f6,0xfba4012d}},	//   мисл, _мойн, _unif, गमरम, 
   {{0xb6f40aaf,0x00000000,0x00000000,0x00000000}},	// [2b240] زىكا_, --, --, --, 
   {{0xaca002e3,0xaaa801f9,0x00000000,0x00000000}},	//   knọl, गावक, --, --, 
   {{0x43845734,0xb5f800c6,0x98a8033f,0x291996f7}},	//   تلاق, _scát, _stać_, mmra_, 
   {{0xf1d84d53,0x68fd96f8,0x9c7c14b2,0x02042dbf}},	//   _मेहन, lord, miče, озен, 
   {{0x68fc0196,0x9c7d96f9,0x2918007b,0x05740345}},	//   oord, liče, omra_, _باجد, 
   {{0x257596fa,0xb9e0001f,0x39980a1e,0x5f947f0f}},	//   mäl_, _ያው_, יינד, зикт, 
   {{0x9c7c04b9,0x2574ed6e,0xbfa805a2,0xf8b0011a}},	//   niče, läl_, ртле_, ושג_, 
   {{0x68fd96fb,0xb5f80f33,0xceb400d1,0x03a40107}},	//   hord, _icár, зәш_, _лиҳо, 
   {{0x00e596fc,0x25740793,0x9c7c5049,0x635c054e}},	//   _джан, näl_, hiče, sănă, 
   {{0xf06196fd,0x68fc2d62,0x2b4403cb,0x6144014b}},	//   _окуп, jord, _bwnc_, _меға, 
   {{0x9c7c2d2b,0x6d4c0120,0x2d8c00a2,0x200c20c2}},	//   jiče, ácar, _esge_, _uzdi_, 
   {{0x25740793,0x9c7c670c,0x79a40408,0x6e900150}},	//   käl_, diče, орге, _يللا, 
   {{0x2574049f,0x68fc2278,0x3ea40311,0x78b40139}},	//   jäl_, ford, _inot_, _poxv, 
   {{0x25740793,0xbb28084c,0x9c7c0427,0xfca8678e}},	//   däl_, _кцие_, fiče, _خاصو_, 
   {{0x3ea596fe,0xaf500023,0xaaa8012d,0x00000000}},	//   _knot_, _ከይሓፈ, गाशक, --, 
   {{0x0ccc0183,0x25740267,0x00000000,0x00000000}},	//   ৰকৃত, fäl_, --, --, 
   {{0x25757687,0x2a080220,0xe3b00133,0xaaa811a0}},	// [2b250] gäl_, _وقىپ_, ێرم_, गारक, 
   {{0x68fd96ff,0x3f9d9700,0x9c7ce045,0x82c4031c}},	//   cord, _ortu_, biče, _གཞུའ, 
   {{0xfbc8085c,0xe4e401ca,0x9c7c01ef,0x00000000}},	//   ानिम, фітн, ciče, --, 
   {{0x63b801e3,0x00000000,0x00000000,0x00000000}},	//   ävna, --, --, --, 
   {{0x3f9d281f,0x425028b1,0x2574014a,0x07e80014}},	//   _artu_, رنور, cäl_, _نِیی_, 
   {{0xe0d810f5,0xfbc80a28,0x3ea40006,0x00000000}},	//   ові_, ानाम, _anot_, --, 
   {{0x3f9c07f5,0x3cfc03e5,0xa87c08a8,0xb5f800ae}},	//   _crtu_, रकने_, יאגר, _gcár, 
   {{0x0ea99701,0x68fd9702,0x645801d3,0x80b00166}},	//   ский_, zord, óviv, дбәх, 
   {{0x68fc0ab7,0x3f9c008c,0x9c7c09a8,0x00000000}},	//   yord, _ertu_, ziče, --, 
   {{0x2b4400a9,0x3ea409a8,0x00000000,0x00000000}},	//   _pwnc_, _enot_, --, --, 
   {{0x68fd9703,0x3f9c0135,0xa3c41152,0x99980064}},	//   vord, _grtu_, एनए_, kasų_, 
   {{0x9c7d9704,0x68fc0d63,0x63b8365a,0xff78011a}},	//   viče, word, øvni, _לטעמ, 
   {{0x68fd9705,0x19b80276,0x00000000,0x00000000}},	//   tord, оурь_, --, --, 
   {{0x25759706,0x9c7c0f03,0x68fc0065,0x01dc0150}},	//   väl_, tiče, uord, _ﺃﺒﻴﻨ, 
   {{0x2ca401c3,0x3ea40042,0x00000000,0x00000000}},	//   _innd_, _ynot_, --, --, 
   {{0x68fd9707,0x690001f4,0x00000000,0x00000000}},	//   sord, töes, --, --, 
   {{0x0565650a,0x68fd9708,0xc5640801,0x9c7c8553}},	// [2b260] яван, pord, якак, siče, 
   {{0x9c7c09a8,0x8ca001ad,0xe8540133,0x00000000}},	//   piče, _कोमो, _زۆرد, --, 
   {{0x25741572,0x00000000,0x00000000,0x00000000}},	//   säl_, --, --, --, 
   {{0xaacc00dc,0xded00092,0x00000000,0x00000000}},	//   ासिक, ጦችን_, --, --, 
   {{0x9f5800e5,0xc05800d4,0x00000000,0x00000000}},	//   _árú_, бій_, --, --, 
   {{0x3ea59709,0x65640687,0x00000000,0x00000000}},	//   _snot_, mrih, --, --, 
   {{0x442801e1,0xc305970a,0x00000000,0x00000000}},	//   _igb_, _فبرو, --, --, 
   {{0x82c41b4b,0x4429970b,0x3f9c1109,0xbd696107}},	//   _གཞིའ, _hgb_, _vrtu_, брое_, 
   {{0xb5f80077,0x81440345,0x00000000,0x00000000}},	//   _edáf, _رنان, --, --, 
   {{0x3d04032c,0x65647b49,0x9c7c01ef,0x00000000}},	//   _सीखे_, irih, dičc, --, 
   {{0x28b00f4c,0x44280004,0x0cac045e,0x3f9c01c4}},	//   ञानि, _mgb_, গসূত, _urtu_, 
   {{0x65640023,0x00000000,0x00000000,0x00000000}},	//   krih, --, --, --, 
   {{0x442801c7,0x3154008f,0x65640687,0xf2d00a7c}},	//   _ogb_, ּילן_, jrih, תער_, 
   {{0x645d970c,0x44280005,0x656400ef,0x00000000}},	//   _ndri, _ngb_, drih, --, 
   {{0x62800fb7,0xe784d80a,0x6c780302,0x65640108}},	//   _obmo, нуто, _האופ, erih, 
   {{0x44280639,0x6564e78f,0xb6000030,0x8e7c01e4}},	//   _agb_, frih, úšob, piŝe, 
   {{0x4429970d,0x645d970e,0x55740064,0x99980153}},	// [2b270] _bgb_, _bdri, ьгат, rasų_, 
   {{0xfafc05e4,0x6281970f,0xc950011a,0x00000000}},	//   loë_, _abmo, _שמי_, --, 
   {{0x645d9710,0x65659711,0x44280112,0xe8d8011a}},	//   _ddri, arih, _dgb_, _מוזר_, 
   {{0x645c0066,0x65659712,0xfafc0165,0x3cfd9713}},	//   _edri, brih, noë_, hotv_, 
   {{0x9c7c02d5,0x44299714,0x46600150,0x2240005a}},	//   anči, _fgb_, _جۇقق, ñika_, 
   {{0xb5f801e1,0x6280010a,0xfafc017a,0x6d0803ce}},	//   _adág, _ebmo, hoë_, _सींग_, 
   {{0x3cfc01c7,0x3598069d,0x752c012d,0x3264010a}},	//   dotv_, _ቅርበት_, _hucz, _нтав, 
   {{0x44299715,0x7c2802d0,0x752401a4,0x8d580137}},	//   _zgb_, _agfr, _hijz, ошот_, 
   {{0x3cfc004d,0x645c035a,0x00000000,0x00000000}},	//   fotv_, _ydri, --, --, 
   {{0xb3280003,0xf65c04ce,0xf09c0268,0x764c5cf8}},	//   _སྤོང_, _blæk_, _ßà_, _lecy, 
   {{0x75240d27,0xbb40004e,0x00000000,0x00000000}},	//   _mijz, кеэк, --, --, 
   {{0x7c280ffb,0x764c003a,0x09e4020f,0x3dd0012d}},	//   _egfr, _necy, домн, _żywe_, 
   {{0x6f180ffb,0x00000000,0x00000000,0x00000000}},	//   mmuc, --, --, --, 
   {{0x3870020c,0x2efd9716,0x2f180521,0xf65c01bf}},	//   _ccxr_, louf_, _ụgha_, _flæk_, 
   {{0x44290c25,0x645c02c4,0x752c07c5,0xfd4c0882}},	//   _rgb_, _rdri, _aucz, dhiṣ, 
   {{0x9c7c098d,0x65659717,0x645d6503,0x44299718}},	//   miča, trih, _sdri, _sgb_, 
   {{0x75240936,0x764c068f,0x442801a4,0x65659719}},	// [2b280] _bijz, _decy, _pgb_, urih, 
   {{0x73303955,0x6f19971a,0x2efc0109,0xb46001f0}},	//   چىلا, hmuc, houf_, ккул, 
   {{0x9c7c04b9,0x764c0077,0x73300075,0x44280fac}},	//   niča, _fecy, نىلا, _vgb_, 
   {{0xb4d80241,0x6d480209,0x752c04cc,0xb28008e2}},	//   _atàd, _owga, _fucz, вышк, 
   {{0xdce00276,0x6f18012d,0x64586316,0xfd4c00dc}},	//   numă, dmuc, óvis, bhiṣ, 
   {{0x75240d27,0x6f180ffb,0x44280156,0x9c7c2a53}},	//   _gijz, emuc, _ugb_, kiča, 
   {{0xdfd00597,0x764c0472,0x6d49971b,0xa3c4000d}},	//   طية_, _yecy, _awga, एनओ_, 
   {{0x6d480042,0x752401f5,0x2499971c,0xf770011a}},	//   _bwga, _zijz, _harm_, דקה_, 
   {{0x2499971d,0xb8e8031c,0xf53c005c,0xdce00356}},	//   _karm_, _ྲྭ_, _gråd_, jumă, 
   {{0x9c7c05ce,0x6e280072,0xfafc0af9,0xaee00055}},	//   fiča, _eggb, woë_, _puṃl, 
   {{0x24980077,0x9c7c05ce,0xf53c0158,0x70100022}},	//   _marm_, giča, _tråg_, _иҧшӡ, 
   {{0xb698145e,0x2499971e,0xed4c0451,0xdce00356}},	//   _akân, _larm_, _چپن_, fumă, 
   {{0x24980036,0x49a40032,0xfafc0575,0x5f440066}},	//   _oarm_, нырғ, roë_, _آنچل, 
   {{0x9c7c04b9,0x7b745007,0xfafc017a,0x249801e7}},	//   biča, _قطعا, soë_, _narm_, 
   {{0x752d971f,0x764c0368,0x752401a4,0xed000372}},	//   _sucz, _pecy, _rijz, _جووپ, 
   {{0x24980221,0x929c0034,0xbbc8f3ec,0x95399720}},	//   _aarm_, _okła, ानीक, ззат_, 
   {{0x24999721,0x8e7c0115,0x61e401e7,0x00000000}},	// [2b290] _barm_, niŝa, úill, --, 
   {{0xb32831d9,0x24999722,0x764c014b,0x7924010a}},	//   _སྤུང_, _carm_, _wecy, _юьйж, 
   {{0x24999723,0x752401a4,0xf99c02e2,0x4e040118}},	//   _darm_, _vijz, lvè_, _हुनै_, 
   {{0x75240936,0x752c4aff,0x2498045f,0xb4d800a3}},	//   _wijz, _tucz, _earm_, _stàd, 
   {{0x9c7c0989,0xbbc8454f,0x4638008f,0x24999724}},	//   ziča, ानुक, _מערע, _farm_, 
   {{0x2498030a,0x4f959725,0xe4a4013e,0x94442586}},	//   _garm_, ериу, _ирсо, _سپرن, 
   {{0xf99c3512,0x9c7c02f0,0x63b803b2,0x28b000cd}},	//   hvè_, xiča, øvnt, ञाति, 
   {{0xf53c7c52,0x9c7c08a4,0x249807ab,0x4d499726}},	//   _tråd_, viča, _zarm_, ппин_, 
   {{0xf53c00cc,0x2efc0036,0x22680118,0x39580051}},	//   _uråd_, rouf_, ítků_, _nvqs_, 
   {{0x9c7c04b9,0xc4d004ac,0x6f180072,0xf53c0158}},	//   tiča, ָגט_, smuc, _gråe_, 
   {{0x20ac0f4a,0x5f741ec7,0x5ba401d5,0x00000000}},	//   चारध, _لانر, врўз, --, 
   {{0xb698000f,0x5fd80490,0x7050036b,0xe98401d5}},	//   _skân, _भेटल, _سنچا, вқин, 
   {{0x9c7d9727,0x59742eca,0xf21409bb,0x6d4802d0}},	//   mičn, кыру, _तरफ़_, _uwga, 
   {{0x9c7c041a,0xe7380022,0x00000000,0x00000000}},	//   piča, мҵо_, --, --, 
   {{0x2d9c0327,0x00000000,0x00000000,0x00000000}},	//   lvue_, --, --, --, 
   {{0x7bd8025f,0x4a748dc7,0xca74008e,0x00000000}},	//   _מקצו, _чыкт, _чукы, --, 
   {{0x2499421e,0x00000000,0x00000000,0x00000000}},	// [2b2a0] _parm_, --, --, --, 
   {{0xca48ef89,0x85048d24,0x9c7c09a8,0xf504084c}},	//   _بلکه_, روان, hičn, енул_, 
   {{0x929c068f,0x8264d712,0x00000000,0x00000000}},	//   _skła, فهان, --, --, 
   {{0x24999728,0x9c7c0219,0x8ca0098a,0x64400139}},	//   _warm_, jičn, _कोसो, _şmid, 
   {{0x9c7c0216,0x24987fff,0xa1955164,0xb6a00104}},	//   dičn, _tarm_, талч, _сиял, 
   {{0x6acc0b7c,0x63b803b2,0x00000000,0x00000000}},	//   ासुर, øvns, --, --, 
   {{0x9c7c0219,0x929c0034,0xb4d801ab,0x9f4c3361}},	//   fičn, _wkła, _ftàb, _ölür_, 
   {{0xdd904116,0x44380175,0xb3280327,0x98a80205}},	//   لوب_, lcp_, _སྤིང_, _otağ_, 
   {{0x929c068f,0x25a19729,0x527458e2,0x7f9002dd}},	//   _ukła, nvil_, _шуру, тақх, 
   {{0x2a61972a,0x44380051,0x25a0000d,0x00000000}},	//   _adib_, ncp_, ivil_, --, 
   {{0x9c7c04b9,0xba38025a,0x99840618,0x25a1972b}},	//   bičn, ndïg, ālō_, hvil_, 
   {{0x7aed972c,0x7ec407ea,0x6e900244,0x25a000a2}},	//   unct, _dépê, _ملما, kvil_, 
   {{0x0c951655,0x2985972d,0x25a0030a,0x2d9c0477}},	//   ردیگ, лырг, jvil_, cvue_, 
   {{0x2a600cc1,0x52bc02ab,0xf99c07c5,0x9c7c0419}},	//   _edib_, _ऍक्स, rvè_, mičo, 
   {{0xf53c00cc,0x538c02d3,0xe80400e1,0x9c7c1d55}},	//   _stå_, _ሓልዮት_, _शुदा_, ličo, 
   {{0x24a40020,0x7c380393,0x24800092,0x00000000}},	//   _ለማለት_, lctr, _ከማለት_, --, 
   {{0x25a005ac,0x9c7c0f91,0x66f40137,0x7c380051}},	// [2b2b0] gvil_, ničo, упту, octr, 
   {{0x9c7c341a,0x647405f5,0xb4d800a3,0x00000000}},	//   zičn, лгуу, _stàb, --, 
   {{0x28140014,0x52740276,0x7c3800ae,0x00000000}},	//   _موٝس, вулу, ictr, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9c7d972e,0x74f40022,0x785c0023,0x00000000}},	//   vičn, _зҵар_, _ንምንጻ, --, 
   {{0x4439972f,0x9c7c4be9,0xd0080262,0x910402e8}},	//   ccp_, dičo, меле_, ъпле, 
   {{0x9c7c49ad,0xcef40120,0xb61801ec,0x00000000}},	//   tičn, кчињ, _ﺠﻬ_, --, 
   {{0x0d859730,0x3dd00210,0x00000000,0x00000000}},	//   влин, _żywa_, --, --, 
   {{0x9c7c5946,0xed800116,0x00000000,0x00000000}},	//   ričn, уңли, --, --, 
   {{0x2d9c5eb5,0x245c0085,0xd7d00073,0x99780210}},	//   rvue_, mámí_, सनाच, _dąży_, 
   {{0xb6980022,0x1e8402dd,0x25a00219,0x00000000}},	//   _akâm, _әлім, zvil_, --, 
   {{0x9c7c00d0,0x7c3800a3,0x98a000b8,0x8ca007af}},	//   bičo, actr, _rihā_, _कोरो, 
   {{0x6e399731,0x8e7c01e4,0x9c7c00d7,0x2fc54740}},	//   mcub, liŝo, cičo, lyng_, 
   {{0x9c7c0427,0xcb68004e,0x0ea801f9,0xddc00139}},	//   ničl, _жаке_, काकड, lamş, 
   {{0x869801c6,0x00000000,0x00000000,0x00000000}},	//   мтат_, --, --, --, 
   {{0x6e399732,0x246400da,0xb69800d2,0x44399733}},	//   ncub, zīmē_, _khây, wcp_, 
   {{0x4528e880,0xb5c19734,0x2fc4010e,0x00000000}},	// [2b2c0] джан_, айтл, hyng_, --, 
   {{0x6d599735,0x044417a0,0x8e7c01e4,0x00000000}},	//   isua, тежн, kiŝo, --, 
   {{0x6d599736,0x44380334,0x6e3800f1,0x7c3400a2}},	//   hsua, rcp_, kcub, _şyrk, 
   {{0xd04003be,0x2fc4010e,0xddc00432,0x00000000}},	//   _illə, dyng_, jamş, --, 
   {{0x6d580218,0x55c463eb,0x4438020c,0x6e380327}},	//   jsua, _баяғ, pcp_, dcub, 
   {{0x9c7c2b57,0x8ca01152,0x8e7c01e4,0x80bc02a0}},	//   vičo, _कोलो, fiŝo, ्सें, 
   {{0xdce001fa,0x2fc4010e,0x00000000,0x00000000}},	//   lumć, gyng_, --, --, 
   {{0x6e3859fc,0x9c7c23cc,0x3da560dc,0x41742586}},	//   gcub, tičo, вроб, _لائس, 
   {{0x4e04012c,0x02040124,0x8e7c01e4,0x00f800f7}},	//   _हुदै_, _рзан, miŝl, _قىرع_, 
   {{0xeee401b9,0x2fc400a2,0x9c7c0419,0x00000000}},	//   _یغنی, byng_, ričo, --, 
   {{0x6d580eda,0x6e38003a,0x9c7c0030,0x92d400fe}},	//   asua, bcub, sičo, িচৰ_, 
   {{0x6e38c799,0x200c01a9,0x7c3804cc,0x212d7d86}},	//   ccub, _iydi_, sctr, _hidh_, 
   {{0x200c0175,0x6d5801c3,0x9c7c00d7,0x00000000}},	//   _hydi_, csua, ličm, --, 
   {{0x212c0014,0x9f5801e1,0x00000000,0x00000000}},	//   _jidh_, _áró_, --, --, 
   {{0x6c8000f7,0x212d9737,0xb8c800bc,0xa854010b}},	//   _ئلىم, _midh_, _गफ_, рксч, 
   {{0x212c02d3,0x9c7c01a6,0x66d802d2,0x00000000}},	//   _lidh_, zičl, _líkf, --, 
   {{0x19c40724,0xe6956107,0x7bd8005a,0x929c033f}},	// [2b2d0] _сәнг, шиты, lztu, _skło, 
   {{0x89d818b2,0xca28008f,0xe4a4ecab,0x00000000}},	//   _سوپر_, _אופֿ, ирхо, --, 
   {{0x245c0296,0x35a402d3,0x7bd801c4,0x7e600f91}},	//   wámí_, _ለካቲት_, nztu, _odop, 
   {{0x212c08c2,0x7e619738,0x7bd99739,0x9c7c00d0}},	//   _aidh_, _ndop, iztu, dičm, 
   {{0x212c0013,0x200c6064,0xe2c800f1,0x28a85c8d}},	//   _bidh_, _aydi_, خونو_, _छोडि, 
   {{0x212c2cf4,0x6e3800b5,0xf53c01e3,0x61141cd0}},	//   _cidh_, wcub, _gråa_, адчу, 
   {{0x9374001f,0x212c00a3,0x6e3800b5,0x9c7c0010}},	//   _ያልሆነ_, _didh_, tcub, ričl, 
   {{0x6d59973a,0x200c0368,0x24181e76,0x00000000}},	//   tsua, _dydi_, _росы_, --, 
   {{0x6e39973b,0xa195973c,0x6d5801d4,0x212c009f}},	//   rcub, _катч, usua, _fidh_, 
   {{0x6d5832ff,0x6e380540,0x9c7d973d,0xeb40001f}},	//   rsua, scub, ličj, _የተገለ, 
   {{0x6d59973e,0xd011973f,0x4b24214f,0x7e6c00c6}},	//   ssua, _الا_, лмов, áipé, 
   {{0xe1f00050,0x6d5845a2,0x29f8063f,0x63b80267}},	//   _اسہ_, psua, ọam_, ävni, 
   {{0xc278008f,0x212c0009,0xae1d10af,0x8d640798}},	//   ערשי, _yidh_, मेशन_, _свле, 
   {{0x8b943e07,0x957802d3,0x212c0067,0x61e401e7}},	//   _брич, ኮነትን_, _xidh_, úili, 
   {{0xf1d82645,0x00000000,0x00000000,0x00000000}},	//   _मेघन, --, --, --, 
   {{0xfc4000e5,0x00000000,0x00000000,0x00000000}},	//   _پھیپ, --, --, --, 
   {{0xc4845848,0xdb0804fb,0x399c0419,0x15b80166}},	// [2b2e0] ллак, _جزوه_, _päsť_, кыфы_, 
   {{0xf65d560a,0xd25800ef,0x00000000,0x00000000}},	//   _blæs_, _roņa_, --, --, 
   {{0x543401c6,0x00000000,0x00000000,0x00000000}},	//   рхуу, --, --, --, 
   {{0x20d001c3,0x203c02d3,0xf36400e5,0x00000000}},	//   _càin_, _ኣቀራር, ائلی, --, 
   {{0xb4d8067c,0x20d00e89,0x212c0023,0xa0540212}},	//   _itàn, _dàin_, _pidh_, авлі, 
   {{0x7e619740,0xb69800e4,0x3dd0033f,0x00000000}},	//   _sdop, _akâh, _żywo_, --, 
   {{0x212c0393,0xdfd4329e,0xfeb8072d,0xb518030d}},	//   _vidh_, ройы, فاظت_, _чирĕ_, 
   {{0x212c0067,0x395c0024,0xf65c08a5,0x2ba400cd}},	//   _widh_, šusi_, _hlær_, गिना, 
   {{0x3d2400d6,0xf65ce73f,0x212c01ab,0xae1c0073}},	//   льов, _klær_, _tidh_, मेलन_, 
   {{0x9c7d9741,0xd2200014,0x212c08c2,0x200c03cb}},	//   mičk, _ظہوٝ, _uidh_, _tydi_, 
   {{0x9c7cabea,0x6e9068be,0x69c00724,0x200c0455}},	//   ličk, _گلنا, ämen, _uydi_, 
   {{0xbda42010,0xdc3d1060,0x4e0400af,0x09e40154}},	//   _محتو, mšči, _हुवै_, _নড়া, 
   {{0x9c7c08ad,0x7bd99742,0xb5f80ca8,0xdc3c0219}},	//   ničk, sztu, _adán, lšči, 
   {{0x7ac40046,0x3ae802e2,0x88c40055,0xdc3c00c0}},	//   _әске, _bòpè_, _naśā, ošči, 
   {{0xdc3c0fb7,0x9c7c098d,0xb7b004c5,0x76a80075}},	//   nšči, hičk, ঘন্ট, нтав_, 
   {{0xdc3c0427,0x4918302b,0x00000000,0x00000000}},	//   išči, _मीठो_, --, --, 
   {{0x7468040e,0xb5f80241,0x387c0c09,0x9c7d9743}},	// [2b2f0] ерев_, _edán, ƙur_, jičk, 
   {{0xf53c9c56,0x9c7c03c6,0xdc3c02d5,0xe56800be}},	//   _från_, dičk, kšči, املى_, 
   {{0x9258169c,0x88c400dc,0xdc3c0219,0x2ba403ce}},	//   вает_, _daśā, jšči, गिया, 
   {{0x9c7c0989,0x1dd4215d,0xdc3c0427,0x7b8801ec}},	//   fičk, धनात, dšči, _ﺒﺴﺤﺏ_, 
   {{0x9c7c3858,0x50b4ac62,0xb5f80118,0xd0459744}},	//   gičk, иску, _zdán, لھاي, 
   {{0x92d4009e,0x121801e0,0xf65c032e,0x9c7c310a}},	//   িচে_, нюһы_, _glær_, sičj, 
   {{0x20540046,0xdc3c0024,0x00000000,0x00000000}},	//   стір, gšči, --, --, 
   {{0x8d64a4cb,0x9c7c4ea1,0x42500e26,0x0ea829e4}},	//   авие, bičk, _ۇچۇر, ткий_, 
   {{0x9c7c02fb,0x7054010a,0x88c400b8,0x00000000}},	//   cičk, _йĕпе, _yaśā, --, 
   {{0xdc3c09a8,0x2d80031c,0x5c440092,0x3aec01f4}},	//   bšči, ċje_, _የአገር, yöpä_, 
   {{0x20d008c2,0x656800b8,0x00000000,0x00000000}},	//   _màil_, _ādhm, --, --, 
   {{0x7d7401d5,0x00000000,0x00000000,0x00000000}},	//   دمیر_, --, --, --, 
   {{0x9f059745,0x00000000,0x00000000,0x00000000}},	//   _اونو, --, --, --, 
   {{0xb4d8c1a8,0x66d800e4,0x8c44fff7,0x394401f0}},	//   _stàn, _míke, _теке, рзро_, 
   {{0x9c7c0552,0x00000000,0x00000000,0x00000000}},	//   zičk, --, --, --, 
   {{0x5c14038b,0xf65d39ff,0x7bcc05ac,0x9734084c}},	//   _اظهر, _slær_, øbue, сэрч, 
   {{0xc4e59746,0x66d801e1,0x88c400b8,0x00000000}},	// [2b300] ажай, _níke, _paśā, --, 
   {{0x9c7c1b5c,0x20d00e89,0x20a40490,0x8e7c01e4}},	//   vičk, _càil_, _गोंध, fiŝk, 
   {{0xb4d8af07,0x20d008c2,0xb5f80118,0x245400cf}},	//   _itàl, _dàil_, _udán, _ۇچاس, 
   {{0x9c7c1326,0xdc3c151c,0xcb040d79,0x00000000}},	//   tičk, všči, रविड_, --, 
   {{0x6724003d,0x20d001ab,0x00000000,0x00000000}},	//   mmij, _fàil_, --, --, 
   {{0x273d9747,0x9c7c0bb8,0x3f659748,0x91a801d3}},	//   _kín_, ričk, атиб, انوے_, 
   {{0x273c01e1,0x9c7c54b1,0xe3b92d65,0xd12c0228}},	//   _jín_, sičk, _çı_, رۅم_, 
   {{0x273c1c38,0xbe88026a,0xdc3c25b7,0x9c7d9749}},	//   _mín_, тске_, ršči, miči, 
   {{0xbb44001f,0x6725512c,0xb5f801e7,0xfca800f1}},	//   _የተቋቋ, imij, _ndál, نادو_, 
   {{0x6f08014b,0x273c0077,0x672405be,0xdc3c09a8}},	//   _ekgc, _oín_, hmij, pšči, 
   {{0xbe65974a,0x50b5974b,0x9c7cef6b,0xc02400cf}},	//   _نهاي, _усту, niči, _ئىاي, 
   {{0x6725974c,0xfde800fd,0x66d81427,0x00000000}},	//   jmij, _идек_, _líkb, --, 
   {{0x19c401e0,0x8ca006e3,0x00000000,0x00000000}},	//   сәйг, _कोको, --, --, 
   {{0xade800c5,0x9c7c0064,0xbda400ec,0x00000000}},	//   _जइतन_, kiči, _محڪو, --, 
   {{0x9c7c0960,0xdce000bc,0x672401f5,0x273d363a}},	//   jiči, zumě, fmij, _cín_, 
   {{0x9c7c01f1,0x273d2624,0x963454fa,0x20d001c3}},	//   diči, _dín_, снац, _sàil_, 
   {{0x89d801ed,0x9c7c0064,0xe58c01e1,0x00000000}},	// [2b310] _موٹر_, eiči, _òtìí, --, 
   {{0x67240050,0x273d974d,0x66d802d2,0x9c7c0064}},	//   amij, _fín_, _ríke, fiči, 
   {{0x273c0241,0xded402d3,0x5695974e,0xb5f80118}},	//   _gín_, ርሑን_, _лант, _zdál, 
   {{0x2ba41223,0xf65c032e,0x81e000cc,0x395c0010}},	//   गिता, _glæp_, _নুই_, šusu_, 
   {{0xe1f1974f,0x2178005b,0x5044004e,0x00000000}},	//   وسه_, ийцы_, белб, --, 
   {{0x66d80232,0x273c0cad,0x00000000,0x00000000}},	//   _víke, _yín_, --, --, 
   {{0x8e7c01e4,0x9c7c0419,0x273c0051,0xef90104c}},	//   liŝi, ciči, _xín_, تیاد, 
   {{0x29f80208,0xfe6c01b9,0x00000000,0x00000000}},	//   ọai_, فگه_, --, --, 
   {{0xcc3401c6,0x00000000,0x00000000,0x00000000}},	//   йхны, --, --, --, 
   {{0xb5f80296,0x67241e31,0x238401d9,0x712000db}},	//   _ndám, zmij, _دٔہِ, _بۉتم, 
   {{0xcfe4015b,0x00000000,0x00000000,0x00000000}},	//   _পুরন, --, --, --, 
   {{0x3fc4036b,0xb4d801c3,0xd1ec0092,0x273c0cad}},	//   _уруғ, _stàl, _ቆይቶ_, _rín_, 
   {{0x273d9750,0xd2580139,0xd1400210,0x00000000}},	//   _sín_, _meņ_, _ująć_, --, 
   {{0x290c05da,0x273c0cad,0xf53c007c,0x00000000}},	//   ôda_, _pín_, _vrål_, --, 
   {{0x2d100073,0x00000000,0x00000000,0x00000000}},	//   डतील_, --, --, --, 
   {{0x9c7c0953,0x69c008fb,0xb5f80241,0xf53c03cd}},	//   viči, ømes, _idáj, _trål_, 
   {{0x67240936,0xb5f8012c,0x44899751,0x05a80500}},	// [2b320] rmij, _udál, лбан_, ывай_, 
   {{0x67241f7f,0x273d9752,0x9c7c32fe,0xcc680092}},	//   smij, _tín_, tiči, _ተጠቆመ_, 
   {{0xd90c072d,0x00000000,0x00000000,0x00000000}},	//   _شیف_, --, --, --, 
   {{0x9c7d79ed,0x2d8c017a,0x6724031c,0x22480166}},	//   riči, _opge_, qmij, рҗан_, 
   {{0x15b873b5,0x00000000,0x00000000,0x00000000}},	//   _кыры_, --, --, --, 
   {{0x26c005ce,0x00000000,0x00000000,0x00000000}},	//   ljio_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x26c005ce,0xb3f40375,0x39480076,0x2bc807b6}},	//   njio_, _המלח_, ypcs_, ाहना, 
   {{0xb5f80248,0x2d8c0129,0x40540451,0xcf88009d}},	//   _adáj, _cpge_, _هئاس, гсөд_, 
   {{0xd36c0228,0xa3ac00bc,0xc10431b1,0x00000000}},	//   _سۇۇ_, कटप_, _اوئي, --, 
   {{0xff50009f,0xeb9400d8,0x00000000,0x00000000}},	//   _رخا_, биќ_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd1ec001f,0xdd9000e3,0xdb1001e1,0x14b801f9}},	//   _ቆይታ_, _آوت_, _àfík, _उचलण, 
   {{0x1bd59753,0x3f9c0048,0x9f045c81,0x8e7c01e4}},	//   _моля, _kstu_, _اوچو, viŝi, 
   {{0x36892351,0x7b455745,0x67d59754,0xbc240150}},	//   лсан_, _ائتل, пору, _ارشى, 
   {{0xa3ac00af,0x9f5800c7,0x97140111,0xea000051}},	//   कटन_, _árõ_, імац, _quải_, 
   {{0xdcdc0316,0x67280129,0x00000000,0x00000000}},	// [2b330] यसपछ, ïdja, --, --, 
   {{0x7aed9755,0xade8033d,0x3f9d9756,0x4de40046}},	//   lict, _जइसन_, _ostu_, ﺍﺭﯨﻨ, 
   {{0x163402f6,0x3dcc0183,0xb9e00023,0xe4c4005b}},	//   _меня, িছিল, _ካል_, чётн, 
   {{0x7aed9757,0x521424c3,0x4e18000d,0x00000000}},	//   nict, одет, _परलै_, --, 
   {{0x3f9d9758,0x765c0113,0x637000e4,0x00000000}},	//   _astu_, maqy, _ẽnte, --, 
   {{0x765c0009,0x7aed9759,0x3dbc0154,0xb3d001ee}},	//   laqy, hict, ইনাল, _ейгә, 
   {{0x9c7ca7ab,0xade80037,0x656800cd,0x00000000}},	//   niču, _जइहन_, _ādhi, --, 
   {{0xb5f8043b,0x63b40122,0x66d80248,0xba380142}},	//   _ndák, šený, _kíka, ddïo, 
   {{0x7aed975a,0x3f9d975b,0x8c9402d5,0x0c9402d5}},	//   dict, _estu_, орні, ошня, 
   {{0x4b884631,0xc32c00f7,0xadb400cf,0x40782309}},	//   айон_, _كەە_, _ۇۇعا_, _ەلەڭ_, 
   {{0x66d82242,0xb4d801e1,0x7aeca787,0xf53c6afa}},	//   _líka, _atàk, fict, _bråk_, 
   {{0x7aec037e,0xc9a80261,0x00000000,0x00000000}},	//   gict, авме_, --, --, 
   {{0x6458008c,0xdd940953,0x8a040220,0x4424004d}},	//   ðvik, _нацы, ізге, ̀o_, 
   {{0x3f9c032e,0x00000000,0x00000000,0x00000000}},	//   _ystu_, --, --, --, 
   {{0x7aec011f,0x799c02d0,0x9f5800e4,0x3f9c01a9}},	//   bict, _esqw, _árô_, _xstu_, 
   {{0x6b800455,0x4649975c,0x7aec02d0,0x3dd00210}},	//   _iqng, рзан_, cict, _żywi_, 
   {{0x056410f5,0x9f940162,0x48e40798,0x00000000}},	// [2b340] юван, _lýða_, _моив, --, 
   {{0x6aa5975d,0xdb2002f6,0x00000000,0x00000000}},	//   _haif, ätök, --, --, 
   {{0x6aa5975e,0x765c058a,0x3b281954,0x00000000}},	//   _kaif, baqy, ተፈጸመ, --, 
   {{0x41a809ed,0x6144035b,0x00000000,0x00000000}},	//   ивен_, зҵаа, --, --, 
   {{0x6aa5975f,0x7640012d,0xaa840118,0x59dc00bc}},	//   _maif, śnyc, chýř, नैपर, 
   {{0x6aa43142,0x65640ccb,0x3f9c00d8,0x43759760}},	//   _laif, msih, _pstu_, _мубт, 
   {{0x645d9761,0xd24c0133,0x00000000,0x00000000}},	//   _ieri, _ڕۆن_, --, --, 
   {{0x645d9762,0x6aa40b23,0xade800e1,0x5d543252}},	//   _heri, _naif, _जेहन_, пкит, 
   {{0x645c3957,0x7aed9763,0x65659764,0x00000000}},	//   _keri, vict, nsih, --, 
   {{0x645d9765,0x6aa40099,0x49180037,0x00000000}},	//   _jeri, _aaif, _मीलो_, --, 
   {{0x20199766,0x6aa401ab,0x7aec0857,0x50a000d1}},	//   _ári_, _baif, tict, _سەيل, 
   {{0x645d9767,0x65659768,0x6aa59769,0x9c7c09a8}},	//   _leri, ksih, _caif, viču, 
   {{0x62800618,0x645c0a85,0x6aa50996,0x65640118}},	//   _mcmo, _oeri, _daif, jsih, 
   {{0x645d976a,0x9c7d976b,0x7aec0175,0x66d8041e}},	//   _neri, tiču, sict, _ríka, 
   {{0x6aa46b39,0x7aed976c,0x60c9976d,0xb6c4300e}},	//   _faif, pict, _modm, осай, 
   {{0xb69800c7,0x6aa40368,0x9c7c01a6,0x66d81d0e}},	//   _akâr, _gaif, riču, _píka, 
   {{0x645d976e,0x65649b41,0x27f00134,0x765c1f75}},	// [2b350] _beri, gsih, _ɛnnɛ_, raqy, 
   {{0x645c5101,0x60c94f98,0x66d80321,0x8e7c00df}},	//   _ceri, _nodm, _víka, liŝt, 
   {{0x6aa5976f,0x765c0784,0x3ce000af,0x9c7c0306}},	//   _yaif, paqy, _ओतने_, ličs, 
   {{0x479802e4,0x6304036b,0xe1f001d9,0x66d8032e}},	//   _פירס, وولل, ھسن_, _tíka, 
   {{0x60c80419,0x31300124,0xb5f800e5,0x00000000}},	//   _bodm, дҵар, _odái, --, 
   {{0x645d9770,0xb5f80597,0xcf5800a7,0x8fa443a2}},	//   _geri, _ndái, брич_, заке, 
   {{0x53c401d9,0xb5f801d3,0x00000000,0x00000000}},	//   _عٲرق, _beág, --, --, 
   {{0x645d9771,0x66d80436,0x0e647390,0x00000000}},	//   _zeri, _líkn, чкин, --, 
   {{0x6aa59772,0x645c7c27,0xdea59773,0x60c80363}},	//   _raif, _yeri, بینی, _fodm, 
   {{0x6aa59774,0x645c004e,0x9c7c0122,0x9f940174}},	//   _saif, _xeri, dičs, _týða_, 
   {{0x6aa59775,0x7d340023,0xc7900092,0x1fa401c4}},	//   _paif, _ኣደልዲ, ውነተኛ_, _орцг, 
   {{0x8e7c0115,0x65640108,0x00000000,0x00000000}},	//   giŝt, ysih, --, --, 
   {{0x6aa59776,0x60c8014f,0x9c7c0118,0x00000000}},	//   _vaif, _yodm, tičt, --, 
   {{0x6aa59777,0x6d480356,0x00000000,0x00000000}},	//   _waif, _itga, --, --, 
   {{0x6aa59778,0xab6002dd,0x9c7c0118,0x00000000}},	//   _taif, _تۇجى, ričt, --, 
   {{0x3b040c04,0xaad0069f,0x65659779,0x6aa41132}},	//   _нещо_, _हकिक, tsih, _uaif, 
   {{0x66d80008,0x00000000,0x00000000,0x00000000}},	// [2b360] _fíkn, --, --, --, 
   {{0x656450f9,0x645d977a,0x87f805f5,0x00000000}},	//   rsih, _qeri, _гэмт_, --, 
   {{0x645d977b,0x60c9977c,0x656426bb,0x22a4059f}},	//   _veri, _rodm, ssih, дулҳ, 
   {{0x6d49977d,0x60c9977e,0x59080327,0x00000000}},	//   _otga, _sodm, _གཉོས_, --, 
   {{0x60c80122,0x645d977f,0xa9280006,0x46140214}},	//   _podm, _teri, pažį, _روسر, 
   {{0xb5f80248,0x5f94796c,0x645d9780,0x98780e3c}},	//   _adáw, дикт, _ueri, ršću_, 
   {{0x6d4802d5,0x29180083,0x60c800ad,0xbfa86f61}},	//   _atga, ilra_, _vodm, стле_, 
   {{0xfe7002ef,0x60c80477,0xceb40131,0x00000000}},	//   ردع_, _wodm, дәш_, --, 
   {{0x66d800d2,0x60c8007f,0xb4d80192,0xc15401af}},	//   _líko, _todm, _stài, _хњбњ, 
   {{0x5908031c,0xd25800ef,0x00000000,0x00000000}},	//   _གཉེས_, _roņi_, --, --, 
   {{0x6d499781,0x3f540066,0xeb9400d8,0x00000000}},	//   _etga, _رضاز, пиќ_, --, 
   {{0xee800064,0x00000000,0x00000000,0x00000000}},	//   _зышо, --, --, --, 
   {{0xf2d004ac,0xad4000f7,0x5f7400f1,0xdb1401e1}},	//   גער_, _كۉيۉ, _راڅر, _èbíb, 
   {{0xb69800e4,0x32d4010e,0x291807de,0x2dc802dd}},	//   _akâp, _açyl_, glra_, _دامۋ_, 
   {{0x3ea42244,0x9c7c0122,0xdce00100,0x8e7c01e4}},	//   _kaot_, sičs, nsmč, piŝt, 
   {{0xabf8025f,0x3ea401f4,0x41bc1a47,0xd25800de}},	//   _להור, _jaot_, ्हास, _toņi_, 
   {{0x65959782,0x3ea59783,0x7c3400df,0xddc0002b}},	// [2b370] нату, _maot_, ŝarĝ, damū, 
   {{0x3ea4079b,0x98d0012c,0x66d801ef,0x00000000}},	//   _laot_, _सकिए, _fíko, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3860003d,0xdcc80316,0xe3b000ae,0x00000000}},	//   lajr_, ाउँछ, درك_, --, 
   {{0x10a40c56,0xb18801c0,0x00000000,0x00000000}},	//   дилн, ссеж_, --, --, 
   {{0x66d8008c,0xb4d8004e,0x00000000,0x00000000}},	//   _líkl, _quàd, --, --, 
   {{0xb4f80050,0x6d481570,0x3ea40165,0x7054030d}},	//   ्वीप_, _stga, _baot_, çачĕ, 
   {{0x29180083,0x38600135,0xddc0002b,0x00000000}},	//   zlra_, hajr_, camū, --, 
   {{0xf65c0393,0x9c7c007f,0xcdc400db,0x00000000}},	//   _meæ_, vičr, بۇشۇ_, --, 
   {{0xd1301060,0x612405d5,0xb5f800a2,0x79880142}},	//   _شما_, gòld, _geáe, _âgwy, 
   {{0x3ea405c7,0x00000000,0x00000000,0x00000000}},	//   _faot_, --, --, --, 
   {{0x66d800e4,0xf99c0100,0xcdf4013d,0x4df404b4}},	//   _ríko, fwè_, _очлы, _оялт, 
   {{0x6d499784,0xc95401c6,0x66d800e5,0x00000000}},	//   _utga, ьтны, _síko, --, 
   {{0x2d9c009f,0xde7000dc,0x073402dd,0x35800023}},	//   mwue_, _imāṃ_, _ﺗﯩﯔ_, ኮነትስ_, 
   {{0x66d808a5,0x0b4401d5,0x00000000,0x00000000}},	//   _fíkl, _ўнин, --, --, 
   {{0x612400db,0x4ae011a6,0x00000000,0x00000000}},	//   mòle, _पतिव, --, --, 
   {{0x090511de,0x2ca59785,0x612400cf,0xc4c80395}},	// [2b380] _опин, _kand_, lòle, олаж_, 
   {{0xf53c0589,0x2ca401a9,0x00000000,0x00000000}},	//   _duå_, _jand_, --, --, 
   {{0x2ca4019b,0x612400cf,0x00000000,0x00000000}},	//   _mand_, nòle, --, --, 
   {{0x2ca59786,0x2d9c01f2,0xfe1c000d,0x06b40244}},	//   _land_, kwue_, _परलस_, _تۆرک_, 
   {{0xa15805cc,0x3ea401f4,0xd36c0228,0xec880150}},	//   чалу_, _raot_, _ۇۇل_, _ﺒﺤﺎﺠ_, 
   {{0x2a619787,0x3ea41509,0x25a000e8,0x00000000}},	//   _leib_, _saot_, mwil_, --, 
   {{0x25a05138,0x3ea4030a,0xc3059788,0x3cec0073}},	//   lwil_, _paot_, _قبرو, ेचसे_, 
   {{0x2ca40151,0xbd68023a,0xb5f8013a,0x00000000}},	//   _aand_, орое_, _vdáv, --, 
   {{0x25a19789,0x20d001ab,0x2ca4b9f7,0x3ea4030a}},	//   nwil_, _bàit_, _band_, _vaot_, 
   {{0x2ca40262,0x20d001c3,0x66d86d18,0x00000000}},	//   _cand_, _càit_, _síkl, --, 
   {{0xb5f802fb,0x2ca5978a,0x2a6034c5,0x25a00042}},	//   _udáv, _dand_, _beib_, hwil_, 
   {{0x25a1978b,0xf9e409bd,0x31c000c0,0x00000000}},	//   kwil_, _গুগল_, būzą_, --, 
   {{0x2ca5978c,0xb5f800c6,0xdd95978d,0x29842eca}},	//   _fand_, _meác, _чалы, кырг, 
   {{0x2ca5978e,0x25a1978f,0x00000000,0x00000000}},	//   _gand_, dwil_, --, --, 
   {{0xf53c0589,0x61244d74,0x6c780375,0x56940798}},	//   _suå_, còle, _ואופ, навт, 
   {{0xf53c0589,0x2ca40196,0xf99c007f,0x00000000}},	//   _puå_, _zand_, pwè_, --, 
   {{0x66d80008,0x7d18002d,0x9c7c02e2,0xf4845211}},	// [2b390] _kíkj, olts, chčc, дуен, 
   {{0x59086d7e,0x2ed84d53,0x2ca40327,0x13400023}},	//   _གཉིས_, _बत्त, _xand_, _ንነጻነ, 
   {{0xd34001ed,0x2a600076,0xfafc0240,0x80c0ac66}},	//   اہری, _yeib_, onë_, लाने, 
   {{0xf53c0589,0x66d8148b,0xfafc4113,0x22580108}},	//   _tuå_, _líkj, nnë_, дицы_, 
   {{0xdebc02d3,0x20d001ab,0x00000000,0x00000000}},	//   ቲኤን_, _nàis_, --, --, 
   {{0x6458008c,0x41b045d7,0xba38004e,0x297c00d9}},	//   ðvit, امور, leïd, קטוא, 
   {{0x2ca46040,0x224000f3,0x205401ec,0xfafc0200}},	//   _rand_, žika_, ттір, knë_, 
   {{0xfafc067d,0x20d008c2,0x7d18000f,0xba38004e}},	//   jnë_, _bàis_, elts, neïd, 
   {{0x2ca59790,0x6fe000e8,0xf53c17b8,0x2284009d}},	//   _pand_, _bёcc, _gråt_, _шург, 
   {{0x2ca401d5,0x612400cf,0x66d80162,0xfafc036e}},	//   _qand_, tòle, _ríkm, enë_, 
   {{0x2ca59791,0x66d803b2,0x8e74014b,0x00000000}},	//   _vand_, _díkj, _зулч, --, 
   {{0x2ca59792,0x7d18045f,0x612400db,0xfafc0036}},	//   _wand_, alts, ròle, gnë_, 
   {{0x2ca59793,0x7d2800aa,0x32d400ee,0x634c05d1}},	//   _tand_, _ځينې_, _açyk_, _iğne, 
   {{0x2a600086,0x80c00c6f,0x612400db,0xfafc0240}},	//   _weib_, लाये, pòle, anë_, 
   {{0x25a0025c,0x00000000,0x00000000,0x00000000}},	//   wwil_, --, --, --, 
   {{0x6f199794,0xb6a0641f,0xbb140046,0x2efc022f}},	//   nluc, лисл, ﻳﯩﻦ_, nnuf_, 
   {{0xe6e01533,0xb5f800c6,0x6f180789,0x00000000}},	// [2b3a0] _नतीज, _reác, iluc, --, 
   {{0x6f194576,0x741003e6,0x5908031c,0x20d001c3}},	//   hluc, گوما, _གཉགས_, _làir_, 
   {{0x25a19795,0x6f199796,0x60d80175,0x87d401a9}},	//   swil_, kluc, vkvm, _чўпч, 
   {{0x020447f9,0x7410fda7,0x0164064d,0x20d001ab}},	//   нзен, دوما, екдо, _nàir_, 
   {{0x6f180c09,0x7d1910de,0x66d808ce,0x80bc00bc}},	//   dluc, ylts, _líkk, _एचआइ, 
   {{0x6f180393,0x645805c7,0x601802e8,0x71a00022}},	//   eluc, ñvid, моля_, ықуҵ, 
   {{0x20d000a3,0x66d80008,0x6f199797,0xdfd000c6}},	//   _bàir_, _ríkj, fluc, شية_, 
   {{0x20d000a3,0xaf0073b5,0x00000000,0x00000000}},	//   _càir_, лчык, --, --, 
   {{0xdce000e2,0x5274033a,0x00000000,0x00000000}},	//   esmā, _јусу, --, --, 
   {{0x7d18035a,0x00000000,0x00000000,0x00000000}},	//   ults, --, --, --, 
   {{0x3e7805d1,0x6f18003a,0x7d199798,0x66d80ad9}},	//   gütü_, bluc, rlts, _víkj, 
   {{0x20d000a3,0xfaa41086,0x6f180356,0xfafc036e}},	//   _gàir_, хшон, cluc, unë_, 
   {{0xba380137,0xfafc0240,0x4ae00037,0x00000000}},	//   veïd, rnë_, _पतरव, --, 
   {{0x52dc243c,0xba38017a,0xfafc0200,0x3e7806be}},	//   _मत्स, deïe, snë_, bütü_, 
   {{0x36f80003,0x69c0023a,0x81d40154,0xe5780171}},	//   _དམྱལ_, ämer, াছি_, _āķa_, 
   {{0xf5e41ed2,0xba380af9,0xab8041bd,0x7e600e21}},	//   нізм, feïe, _сушк, _jeop, 
   {{0x7e60fe8c,0xb5f80ca8,0xe59951ee,0x00000000}},	// [2b3b0] _meop, _adár, нкті_, --, 
   {{0x7e619799,0x66d9979a,0xba38004e,0x26c4007f}},	//   _leop, _líkh, reïd, _òmon_, 
   {{0xd2504116,0x53a40023,0x00000000,0x00000000}},	//   لنا_, _ወላዲት_, --, --, 
   {{0x7e601050,0x2374103c,0xba38004e,0xb60000d0}},	//   _neop, االح, peïd, tláč, 
   {{0x6f19979b,0xb4dc0882,0x814000d1,0x00000000}},	//   vluc, _ततॊ_, ۇھەم, --, 
   {{0x20d001ab,0x00000000,0x00000000,0x00000000}},	//   _sàir_, --, --, --, 
   {{0x6f19979c,0x7e600063,0xc4d00375,0x6458030a}},	//   tluc, _beop, _דגם_, ñvie, 
   {{0x6f180268,0xfe6c01b9,0xb60002f0,0x224001e4}},	//   uluc, قگه_, pláč, ɾiko_, 
   {{0x6f19979d,0x7e600276,0x2efc0ea0,0x66d8659a}},	//   rluc, _deop, rnuf_, _síkk, 
   {{0x6f1806d5,0xb4dc0882,0x35800023,0xc0f00023}},	//   sluc, _ततो_, ርሒታት_, ፍጽሞ_, 
   {{0x7e600421,0x8d741a69,0x2c0800dc,0x20d001c3}},	//   _feop, راکا, _सुखं_, _tàir_, 
   {{0x7e60ece2,0xb698002d,0x6f18014f,0x66d808ce}},	//   _geop, _sjân, qluc, _víkk, 
   {{0xc0f00023,0x7da401af,0xc33000d9,0x00000000}},	//   ፍጽም_, _аҙығ_, יוט_, --, 
   {{0x6d9000d7,0x00000000,0x00000000,0x00000000}},	//   gľaš, --, --, --, 
   {{0x6cc00184,0x7d1400e4,0x78600116,0x6da001ee}},	//   _айҙа, _êysa, рксз, _риҙа, 
   {{0xfd6002e3,0x7e61979e,0x3a100521,0x0ae80451}},	//   _netị, _xeop, ụgụ_, _زرعي_, 
   {{0xb69800d2,0xba39979f,0x04440640,0xdb4c0133}},	// [2b3c0] _tjân, teïe, везн, _وێی_, 
   {{0xb97806a9,0x291c00c7,0x66280790,0x00000000}},	//   _קניי, _óva_, _ırkı, --, 
   {{0x66d808a7,0x9358074d,0x94780006,0x00000000}},	//   _líki, ерчу_, эсту_, --, 
   {{0x61240100,0x998800b8,0xf53c007c,0x00000000}},	//   dòla, _nyaś_, _vrår_, --, 
   {{0x7e6197a0,0x20980716,0xb2700220,0x12c80d2f}},	//   _reop, еклы_, рліш, عظمي_, 
   {{0x7e6027be,0x66d80af2,0xf53c33b8,0x705042f4}},	//   _seop, _síkh, _trår_, لنها, 
   {{0x7e6197a1,0x78f8011a,0xd53000e5,0xa284085b}},	//   _peop, ופסו, _اہلخ, _میاو, 
   {{0xb5f800c6,0xd36c01ec,0x50040022,0x4f7800db}},	//   _meán, _ءۇن_, ыҭхо_, رجىگ_, 
   {{0x80c03be6,0x9d14f2f6,0xb5f801d3,0x7e600254}},	//   लादे, лдич, _leán, _veop, 
   {{0x9b580a16,0x66d803b2,0x00000000,0x00000000}},	//   ниот_, _díki, --, --, 
   {{0x61241497,0x00000000,0x00000000,0x00000000}},	//   còla, --, --, --, 
   {{0xb4dc0a28,0xf77197a2,0xf4100375,0x9c7c007f}},	//   _तत्_, یاز_, יפת_, chčn, 
   {{0xba38004e,0x395c180f,0x00000000,0x00000000}},	//   deïc, èus_, --, --, 
   {{0x9ca800f1,0x7c6400d1,0x00000000,0x00000000}},	//   _سختې_, _شاتل, --, --, 
   {{0x3f8cbbab,0xb5f80005,0x9c7c0306,0xdd90004b}},	//   ntfu_, _adáp, lhčo, _خوږ_, 
   {{0xdce002d5,0xb5f801e7,0xec34011a,0xdb2001e1}},	//   tumė, _deán, _באור_, _ìtàn, 
   {{0x66d800d2,0xa5f997a3,0x58d41870,0xe66597a4}},	// [2b3d0] _líkw, вету_, _бопт, ртсо, 
   {{0xfd60063f,0xf53c01e3,0x65949a9a,0x59a8012d}},	//   _setị, _dråp_, рафу, _चैयर, 
   {{0xd76003e6,0x527400f7,0x13a402f2,0xdb2002d2}},	//   _دۆزی, гулу, دۆزی_, _ítón, 
   {{0x98a000b0,0x61240ba1,0x00000000,0x00000000}},	//   _tihē_, vòla, --, --, 
   {{0xb9dc0020,0xe188143e,0x28b41079,0x00000000}},	//   _ሥነ_, نئون_, _صحیح, --, 
   {{0x66d81c38,0x2ed80709,0x6124067c,0x205400a7}},	//   _ríki, बस्त, tòla, атър, 
   {{0x4f9597a5,0x66d821f1,0xd3f003d4,0x00000000}},	//   урлу, _síki, _জুৰি_, --, 
   {{0x63b8037e,0x61244079,0x0d852303,0x8d585e08}},	//   ævne, ròla, глин, ншот_, 
   {{0x623406ed,0xe2f802dd,0xccf8003b,0x00000000}},	//   _вету, _реті_, ехні_, --, 
   {{0x66d81f60,0x6124067c,0xccc40395,0x00000000}},	//   _víki, pòla, убой, --, 
   {{0xbb50030f,0xef900133,0x00000000,0x00000000}},	//   ینیب, _ئیعد, --, --, 
   {{0x66d808ce,0x00000000,0x00000000,0x00000000}},	//   _tíki, --, --, --, 
   {{0x6dc4036b,0xb5f800ae,0x00000000,0x00000000}},	//   _جزال, _seán, --, --, 
   {{0x94080213,0x00000000,0x00000000,0x00000000}},	//   şkən_, --, --, --, 
   {{0x1cb997a6,0x37e197a7,0x6fb00c4c,0xba3800e4}},	//   _جانب_, борг, ंटिं, teïc, 
   {{0xb4d997a8,0x66d803b2,0x798c0175,0x00000000}},	//   _quàn, _líkv, btcw, --, 
   {{0x2bc819e5,0x452997a9,0x2fc401ab,0xeb9401a9}},	// [2b3e0] ाहका, ежан_, hxng_, _чиқ_, 
   {{0xb4600137,0x00000000,0x00000000,0x00000000}},	//   йкул, --, --, --, 
   {{0x2b4c084c,0x42d402bf,0x80c00f4a,0x00000000}},	//   _încă_, ліду, लासे, --, 
   {{0x031841c1,0x3250001f,0x7a4400b0,0xc2080d1f}},	//   رتات_, _ይበልጣ, pūtō, ىقان_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3f8c0083,0xbfa83667,0xf990011a,0x3da408ca}},	//   ttfu_, етие_, צרו_, ҳроб, 
   {{0xb5f801d3,0xdb100de2,0xf424022e,0x00000000}},	//   _leál, ëfën, _борл_, --, 
   {{0x3f8c0204,0x3da40b59,0x00000000,0x00000000}},	//   rtfu_, гроб, --, --, 
   {{0x3f8c0204,0xbfc43d48,0x5bdc00dc,0x5f7800f2}},	//   stfu_, _әбек, मन्व, رمکس_, 
   {{0x41242047,0x90d4001e,0xac74001f,0x2f500166}},	//   _صفاق, _hìn, _በአለም_, штәс, 
   {{0x6124067c,0x9b9495b2,0x8fc400f1,0xf1bc01e1}},	//   lòlo, шинц, _نېول_, _àár_, 
   {{0xb5f800dd,0x66d803b2,0x80c197aa,0x8c1800ec}},	//   _beál, _kíku, लावे, ئيٽر_, 
   {{0x90d4001e,0x2d800165,0xed54014b,0x00000000}},	//   _mìn, ńjer_, _боч_, --, 
   {{0xfca800f1,0x00000000,0x00000000,0x00000000}},	//   _ساتو_, --, --, --, 
   {{0x66d997ab,0x6c8000f7,0xed0003e6,0xa84800f2}},	//   _líku, _الىم, _دووپ, الفم_, 
   {{0xdce0005f,0xf5c401b9,0x00000000,0x00000000}},	//   kumī, лёзм, --, --, 
   {{0x7bd997ac,0xb8d8009e,0x19c48715,0x61e400a3}},	// [2b3f0] lytu, _অক_, _тәнг, ùill, 
   {{0xb4dc05c0,0x00000000,0x00000000,0x00000000}},	//   तसे_, --, --, --, 
   {{0x569597ad,0x65940220,0x90d401fb,0x7bd997ae}},	//   _кант, _қару, _bìn, nytu, 
   {{0x515597af,0x92942401,0x00000000,0x00000000}},	//   атку, радц, --, --, 
   {{0x200c0067,0xd5f8010f,0x7bd80142,0x00000000}},	//   _axdi_, _ספֿר, hytu, --, 
   {{0x7bd8858f,0x84c00139,0xe4e40a4a,0xc578011a}},	//   kytu, _мәхд, _лісн, _ברשת, 
   {{0x93740020,0xcd340214,0x7bd801f4,0x00000000}},	//   _ካልሆነ_, یرخب, jytu, --, 
   {{0x7bd86dd3,0x66d801ef,0x00000000,0x00000000}},	//   dytu, _fíku, --, --, 
   {{0x612400cf,0x00000000,0x00000000,0x00000000}},	//   còlo, --, --, --, 
   {{0xb5f81dee,0x00000000,0x00000000,0x00000000}},	//   _reál, --, --, --, 
   {{0x20c405f5,0x8fd01945,0x66d801a8,0x5f9400d8}},	//   _устг, _фәлә, _kíkt, _гихт, 
   {{0x4e1834d8,0x29d800d7,0x00000000,0x00000000}},	//   _июля_, hľať_, --, --, 
   {{0xb81c009e,0x5ea401e2,0x00000000,0x00000000}},	//   _দলগত_, _دمنل, --, --, 
   {{0xcc892221,0x333c0226,0x1cc40135,0x66d80d12}},	//   _شنبه_, _liux_, _ཌོར_, _líkt, 
   {{0x46f45477,0xc7a405b0,0x25e80dad,0x7bd80034}},	//   ачат, шивк, चैनी_, cytu, 
   {{0x29d801f1,0x6704009d,0x00000000,0x00000000}},	//   eľať_, сүмб, --, --, 
  
   {{0x2b440483,0x4464d456,0x092801c6,0xfb18010f}},	// [2b400] _hunc_, ивав, _ижий_, _בוקמ, 
   {{0xf3900882,0x2b440010,0x66d997b0,0x00000000}},	//   kṣā_, _kunc_, _ríku, --, 
   {{0x66d800d2,0x68fcbd89,0x826997b1,0x00000000}},	//   _síku, mird, ваев_, --, 
   {{0x291997b2,0x68fc4a4a,0xb6a00166,0x3f480248}},	//   lora_, lird, _диюл, _rùu_, 
   {{0x80c03be6,0x15b801e0,0x7bd8033f,0xddc000c0}},	//   लाले, _йыры_, zytu, kamš, 
   {{0x291997b3,0x68fd97b4,0xd6b8009e,0x66d80252}},	//   nora_, nird, ীসৃপ, _víku, 
   {{0x2b4597b5,0x7ee4bdd4,0x90d401fb,0x6d4c056a}},	//   _nunc_, ицие, _tìn, ícan, 
   {{0x68fd97b6,0x44280030,0xe1884990,0xefb001b9}},	//   hird, _izb_, _бөке_, غینگ, 
   {{0x291997b7,0x2b44060a,0x68fc51c8,0x9d180588}},	//   kora_, _aunc_, kird, лоит_, 
   {{0x291997b8,0x14c80404,0x7bd997b9,0x2b44003a}},	//   jora_, रायण, tytu, _bunc_, 
   {{0xb1100058,0x68fce35c,0xba3801f5,0x6ab00154}},	//   _بولغ, dird, geïn, টানো, 
   {{0x2b444a1f,0x9b94005e,0x3f9c0120,0x195997ba}},	//   _dunc_, _ۇلتت, _iptu_, ламы_, 
   {{0x9d5400db,0x66d80162,0x41c4033f,0x14c808df}},	//   _انتت, _líks, लमिस, रामण, 
   {{0x7bd86711,0x68fd97bb,0x2b441528,0x442801a4}},	//   pytu, gird, _func_, _ozb_, 
   {{0x4428ad51,0x67d400f7,0x2b400009,0x36883edd}},	//   _nzb_, оору, _fiic_, ксан_, 
   {{0x68fc01ab,0xb9e401ec,0xb4dc00cd,0x00000000}},	//   aird, _ەسگى, तस्_, --, 
   {{0x2918633d,0x44280332,0x66d808a5,0xe5b4009d}},	// [2b410] bora_, _azb_, _ríkt, ойты, 
   {{0x291997bc,0x1cc40489,0x4428030a,0x04843bf0}},	//   cora_, _ཌོས_, _bzb_, йәси_, 
   {{0x92593c4b,0x18b400d1,0x6124067c,0x96f8022e}},	//   гает_, _кәңр, ròll, _бент_, 
   {{0x635400d4,0x00000000,0x00000000,0x00000000}},	//   івчу, --, --, --, 
   {{0xf1a4716a,0x442997bd,0xb1a40150,0x00000000}},	//   ррен, _ezb_, ршек, --, 
   {{0xd00997be,0x00000000,0x00000000,0x00000000}},	//   леле_, --, --, --, 
   {{0x61240ba1,0x799c02d0,0xc4446676,0xf2c449c4}},	//   còlm, _lpqw, _ایمن_, _ксан, 
   {{0x68fd6957,0x00000000,0x00000000,0x00000000}},	//   zird, --, --, --, 
   {{0xd01197bf,0x68fc00ac,0x291997c0,0x2b440165}},	//   _کلا_, yird, yora_, _sunc_, 
   {{0xba3997c1,0x2b4597c2,0x2918761e,0x00000000}},	//   teïn, _punc_, xora_, --, 
   {{0x291808ad,0x68fd97c3,0x8c8401e0,0x66d8032e}},	//   vora_, vird, аҙҙа_, _míkr, 
   {{0x29180428,0x70b4012c,0x2b400009,0x66d802d2}},	//   wora_, _आफुल, _qiic_, _líkr, 
   {{0x291997c4,0x2b40004e,0xdd940064,0x00000000}},	//   tora_, _viic_, _мацы, --, 
   {{0x2b45209d,0x6d592a3a,0x7d742172,0x291804cc}},	//   _tunc_, mpua, _امور_, uora_, 
   {{0x291997c5,0x68fd97c6,0x26bc025c,0x00000000}},	//   rora_, rird, _པོདཔ, --, 
   {{0x68fd97c7,0x66d808ce,0x8644b154,0x00000000}},	//   sird, _ríks, снаж, --, 
   {{0x70b40316,0x6d58005a,0x6458030a,0x68fd97c8}},	// [2b420] _आफूल, npua, ñvio, pird, 
   {{0xdb192972,0x888415a0,0x68fd97c9,0x6d5800d8}},	//   _arvè, _улож, qird, ipua, 
   {{0x893401d3,0x82440408,0xcf840244,0x00000000}},	//   _پٹھا, йĕнч, _تژ_, --, 
   {{0x6d5802b4,0xa29400d6,0x2bb40051,0x03a401f0}},	//   kpua, іалі, _măc_, _қибо, 
   {{0x672597ca,0x3f9c003e,0x6d4c04d4,0x38c80133}},	//   mlij, _sptu_, ícal, _شایی_, 
   {{0x836824c5,0x2904003e,0x4428022a,0x00000000}},	//   _مصرف_, émah_, _tzb_, --, 
   {{0x6e280175,0x442822cd,0x6724023a,0x5f94030d}},	//   _azgb, _uzb_, olij, цийт, 
   {{0x67240936,0x9ed83596,0xbe8813dc,0x5d5597cb}},	//   nlij, рмит_, уске_, окит, 
   {{0x6d588b14,0x672597cc,0xbb440092,0x40940d1d}},	//   gpua, ilij, _ከተቋቋ, _грет, 
   {{0x23dc041c,0x6724014f,0x9cb4104c,0x00000000}},	//   _यथाद, hlij, آمدت, --, 
   {{0xa3e805b7,0x35180a7c,0x00000000,0x00000000}},	//   यनि_, רוינ, --, --, 
   {{0x6724248d,0xe8940092,0x00000000,0x00000000}},	//   jlij, _ይምረጡ_, --, --, 
   {{0x672405a1,0x6da00cb6,0x42940023,0x00000000}},	//   dlij, _ница, _መዝነት_, --, 
   {{0xa3e80d2c,0x672401a4,0x6ee40139,0xadb40066}},	//   यना_, elij, _iñba, _دهها_, 
   {{0x7d1997cd,0x98a002b5,0x672597ce,0xac940014}},	//   mots, _hihī_, flij, _اۆپا_, 
   {{0x7d1997cf,0x672597d0,0x387c06b9,0x6bd00220}},	//   lots, glij, şur_, _ءتور, 
   {{0xb8ec015b,0x55542c10,0x63bd97d1,0xfafc017a}},	// [2b430] _শত_, زپار, _arrn, mië_, 
   {{0x81cd161d,0xfafc0e29,0x7d1997d2,0x3cfc324c}},	//   শনা_, lië_, nots, nitv_, 
   {{0xb5f800c6,0xdd040024,0x78a40200,0x00000000}},	//   _meái, špėd, mejv, --, 
   {{0x7d1906f1,0xfafc368d,0x7f400eda,0x326800c6}},	//   hots, nië_, _nioq, احاً_, 
   {{0x7d1997d3,0xb07401e0,0x00000000,0x00000000}},	//   kots, йҡау_, --, --, 
   {{0x7d1997d4,0x4f7800a7,0xfafc01f5,0x45a06c68}},	//   jots, ащия_, hië_, _تەكك, 
   {{0x7f4197d5,0x7d1997d6,0x80d800bc,0xe5780171}},	//   _bioq, dots, _बकरइ, _āķi_, 
   {{0xa2940845,0x518401ec,0x00000000,0x00000000}},	//   _насі, _қуға, --, --, 
   {{0xfafc5b5e,0x7d180170,0x6d5997d7,0xb5f801e7}},	//   dië_, fots, upua, _beái, 
   {{0x7d1997d8,0x6d5997d9,0x67240841,0x3cfc26bb}},	//   gots, rpua, zlij, gitv_, 
   {{0x8e740276,0x6d580393,0xcac800d3,0x672597da}},	//   _дулч, spua, агне_, ylij, 
   {{0x6d58023a,0xfafc26be,0x6724031c,0x00000000}},	//   ppua, gië_, xlij, --, 
   {{0x7d1997db,0x6f1997dc,0x672597dd,0x225803b9}},	//   bots, mouc, vlij, _ərk_, 
   {{0x6f1997de,0x6d4997df,0x7d18013e,0xb5f997e0}},	//   louc, _iuga, cots, _geái, 
   {{0x6d4997e1,0x6724f6cf,0xfafc0151,0x6d4197e2}},	//   _huga, tlij, bië_, _iina, 
   {{0x6d4197e3,0x6d487752,0x7c3c278a,0x6f1997e4}},	//   _hina, _kuga, _úpra, nouc, 
   {{0x6d4197e5,0x67240460,0x6d4997e6,0xdbd000a2}},	// [2b440] _kina, rlij, _juga, _eýäm, 
   {{0x6d48c3e6,0x6724c75b,0x6d4197e7,0xc7a428a8}},	//   _muga, slij, _jina, _диок, 
   {{0x6d4197e8,0x672407e4,0x389800c8,0x6f1997e9}},	//   _mina, plij, _דיינ, kouc, 
   {{0x6d4997ea,0xdb1801f1,0x4224209b,0x7d1997eb}},	//   _ouga, _prvé, одев, zots, 
   {{0x6d400323,0x6d4997ec,0x6f180316,0x7d1997ed}},	//   _oina, _nuga, douc, yots, 
   {{0x6d4197ee,0x7f4020ac,0xcbc80316,0x7d180117}},	//   _nina, _sioq, िमाञ, xots, 
   {{0x6d4997ef,0x7d1997f0,0x7f40003a,0x612400db}},	//   _auga, vots, _pioq, nòli, 
   {{0x6d483182,0x6d4197f1,0x7d1997f2,0xb7d80375}},	//   _buga, _aina, wots, יקצי, 
   {{0x7d199005,0x6d4997f3,0x6d4197f4,0xfafc282c}},	//   tots, _cuga, _bina, vië_, 
   {{0x6d4997f5,0x6d4197f6,0x708197f7,0xfafc0ea0}},	//   _duga, _cina, _огуз, wië_, 
   {{0x7d1997f8,0x6d4997f9,0x6f1997fa,0xb5f80789}},	//   rots, _euga, bouc, _veái, 
   {{0x6d4123ba,0x6d48213c,0x7d1997fb,0x6f1997fc}},	//   _eina, _fuga, sots, couc, 
   {{0x7d1997fd,0xfafc2595,0x6d4997fe,0xf77000ec}},	//   pots, rië_, _guga, ڀار_, 
   {{0x6d4197ff,0xfafd9800,0x7d181b11,0x6124068c}},	//   _gina, sië_, qots, fòli, 
   {{0x6d499801,0xfafc1f9e,0x4bc00166,0xbd84009f}},	//   _zuga, pië_, _зөяг, _انڙن_, 
   {{0x6d419802,0x6d499803,0xc5d400cc,0x78a4031c}},	//   _zina, _yuga, _সেইপ, sejv, 
   {{0x34481ea2,0x6d419804,0x6d48025c,0x8e7c01e4}},	// [2b450] ачен_, _yina, _xuga, nkŝa, 
   {{0x6d4007a9,0x612400cf,0x8d9c0150,0xf8dc0037}},	//   _xina, bòli, _ﺃﺴﺴﺕ_, _नकिय, 
   {{0x14180597,0x612400db,0x6f180784,0x00000000}},	//   حياة_, còli, youc, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6f1800bc,0x9c7c02f0,0x00000000,0x00000000}},	//   vouc, lhču, --, --, 
   {{0x46380bd9,0xe4a405f5,0x6f199805,0x00000000}},	//   _לערע, _орсо, wouc, --, 
   {{0x6d499806,0xfd7802d3,0xceb800bc,0xc4d0011a}},	//   _suga, _ተቐማጦ_, hoře_, _אגם_, 
   {{0x6d419807,0x14c80a59,0xf1a400d8,0x0ec40210}},	//   _sina, रावण, _мрзн, वाइड, 
   {{0x6d419808,0xc3300a1e,0x6f199809,0xa15850cb}},	//   _pina, _טול_, rouc, _мату_, 
   {{0x6d49980a,0x6d41980b,0xe8000b98,0x6f600e56}},	//   _vuga, _qina, ोपमा_, _قۇتم, 
   {{0x6d41980c,0x8b24656c,0x6d4800ca,0x8ccc033f}},	//   _vina, здне, _wuga, ताबो, 
   {{0x6d49980d,0x03d408a8,0xdcb80115,0x52d80037}},	//   _tuga, לותם_, voĉe_, _भकोस, 
   {{0x6d41980e,0x6d49980f,0xdc3c00da,0x442401fb}},	//   _tina, _uuga, kšķi, ́o_, 
   {{0x6124bbc6,0x6d40478b,0x1cc4031c,0x00000000}},	//   tòli, _uina, _ཌོག_, --, 
   {{0xf1bc1155,0x00000000,0x00000000,0x00000000}},	//   _šál_, --, --, --, 
   {{0x9c7c031d,0x9518025c,0x6124004e,0xd6c40116}},	//   nkčn, ྱོའི_, ròli, мисқ, 
   {{0x612400cf,0x35a001b9,0x7bcc0254,0x00000000}},	// [2b460] sòli, натг, äbuv, --, 
   {{0x61244b84,0x08883cc5,0xa3e806e3,0x00000000}},	//   pòli, _убой_, यनल_, --, 
   {{0x7d040098,0x00000000,0x00000000,0x00000000}},	//   éksi, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x224000c5,0x41283e08,0x00000000,0x00000000}},	//   äik_, бодо_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdd9000f2,0xf8b0011a,0x00000000,0x00000000}},	//   چوب_, גשו_, --, --, 
   {{0xdd900338,0xe2c80244,0x00000000,0x00000000}},	//   نوب_, _باسۆ_, --, --, 
   {{0x1d345cfa,0x6e5000ec,0xc1e8009d,0x6e2c008e}},	//   мния, رئيء, _удаж_, _ğibä, 
   {{0x0108004b,0xdb08003b,0x7170007b,0xb5f4010f}},	//   _اترو_, lvdø, _أهلا, פציג_, 
   {{0x60c99810,0xf07031f6,0x7aec009a,0x3ea43fe9}},	//   _indm, _سُند, thct, _нижг, 
   {{0x9f043345,0xdc3c00e2,0xceb80118,0x00000000}},	//   _کوچو, zšķi, toře_, --, 
   {{0xa28c001f,0x00000000,0x00000000,0x00000000}},	//   _መኮንን_, --, --, --, 
   {{0x3860002d,0x7aec01c7,0xff240345,0x00000000}},	//   ubjr_, shct, _ببڕی, --, 
   {{0x60c802d0,0x569400d8,0xddd40210,0x00000000}},	//   _mndm, мавт, żańs, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x5a356174,0x00000000,0x00000000,0x00000000}},	// [2b470] _юнит, --, --, --, 
   {{0xa3e800cd,0x00000000,0x00000000,0x00000000}},	//   यनं_, --, --, --, 
   {{0xa7740276,0x929402d5,0x00000000,0x00000000}},	//   _плэч, даец, --, --, 
   {{0x60c8033d,0xb5f99811,0x0ca80882,0xb86404d3}},	//   _andm, _beát, _कस्म, _باکو, 
   {{0xb9f802d3,0xbb2c0116,0x00000000,0x00000000}},	//   _ቅነ_, ﯩﯟﻯ_, --, --, 
   {{0x67480252,0x00000000,0x00000000,0x00000000}},	//   _ósjá, --, --, --, 
   {{0x78b4007c,0x9258014b,0xa87c011a,0x4f940798}},	//   _maxv, _мавт_, זאור, фрлу, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfe6c0517,0x00000000,0x00000000,0x00000000}},	//   شگن_, --, --, --, 
   {{0x20180129,0xa068009b,0x00000000,0x00000000}},	//   éfié_, _нађа_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8274008f,0x201803b2,0x8ac401d5,0x9f5401e1}},	//   וערע_, _ørir_, зққа_, _èfòn_, 
   {{0x6124068c,0xa0300137,0x0ec40073,0x07a4a135}},	//   sòlv, _جۉۉت, वाकड, магн, 
   {{0x86740022,0x17c400c7,0x2be400cc,0x6e4002f2}},	//   дызц, нарҭ, _ওখকৈ_, _تۆکم, 
   {{0xb6a0e6ab,0x00000000,0x00000000,0x00000000}},	//   кисл, --, --, --, 
   {{0x29040129,0x00000000,0x00000000,0x00000000}},	// [2b480] émas_, --, --, --, 
   {{0x893400ae,0x00000000,0x00000000,0x00000000}},	//   _تعبا, --, --, --, 
   {{0xdd3006be,0xd06006be,0x00000000,0x00000000}},	//   _ləşd, _ötəs, --, --, 
   {{0xba00001f,0x00000000,0x00000000,0x00000000}},	//   _ግባ_, --, --, --, 
   {{0x057475e4,0xdb240fac,0x6124033b,0x55c401ee}},	//   _تاجد, _åpåf, kòlt, _заяғ, 
   {{0xd2580100,0x43680139,0x00000000,0x00000000}},	//   _efņ_, _магн_, --, --, 
   {{0x83540014,0x443d9812,0x5f480139,0x00000000}},	//   _آپرا, _àt_, чүен_, --, 
   {{0x13640451,0x7de400d4,0x00000000,0x00000000}},	//   _سافٽ, діод, --, --, 
   {{0xb22001c6,0xfdbc0154,0x7c84011c,0x00000000}},	//   _амтл, েন্ড, муне, --, 
   {{0x634c008e,0xc10416ac,0x60c802d0,0x00000000}},	//   _eşne, _غواي, _undm, --, 
   {{0x63b801bf,0x00000000,0x00000000,0x00000000}},	//   ævnh, --, --, --, 
   {{0xafe001d5,0x00000000,0x00000000,0x00000000}},	//   _шохл, --, --, --, 
   {{0xf2d01a4c,0x1dc40166,0x2f38011a,0x00000000}},	//   דער_, _чөйн, _וגאד, --, 
   {{0x61240ba1,0xb0c4012d,0x7bcc0037,0x00000000}},	//   còlt, लाएग, äbus, --, 
   {{0x7d04003e,0x9f580254,0x00000000,0x00000000}},	//   éksu, _ärä_, --, --, 
   {{0xf5e401ce,0xaba4009f,0x00000000,0x00000000}},	//   мізм, _آهيم_, --, --, 
   {{0xdce120de,0x00000000,0x00000000,0x00000000}},	// [2b490] ltmı, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb5f801e7,0x91700ca8,0x00000000,0x00000000}},	//   _ceár, _ẹ̀k_, --, --, 
   {{0x5214005e,0xb5f80332,0x00000000,0x00000000}},	//   ндет, _deár, --, --, 
   {{0x8658025f,0x741070cb,0x00000000,0x00000000}},	//   _מדרי, روچا, --, --, 
   {{0xca64022e,0x00000000,0x00000000,0x00000000}},	//   hokа, --, --, --, 
   {{0x61259813,0x877c0023,0xc0d000cf,0xb5f800e5}},	//   vòlt, _ንውሳኔ_, ايىب, _teás, 
   {{0xb4d800f7,0xdcb801e4,0x00000000,0x00000000}},	//   _guàr, voĉa_, --, --, 
   {{0x1ae000fe,0x00000000,0x00000000,0x00000000}},	//   মোৱা, --, --, --, 
   {{0x2c00010b,0x00000000,0x00000000,0x00000000}},	//   күлм, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x63b800b5,0xb5f801e1,0x61680023,0x6d900064}},	//   ævni, _ifáf, _ዝተበጽ, ežaš, 
   {{0xaca00521,0xc33006a9,0x19b80276,0x2bdc01f9}},	//   _arụk, טוט_, мурь_, _पॅरा, 
   {{0x7d040098,0x00000000,0x00000000,0x00000000}},	//   ékst, --, --, --, 
   {{0xee780952,0x46a4023b,0xc05000d9,0x00000000}},	//   ﻠﮕﻪﻥ_, навв, רזל_, --, 
   {{0x05750b6a,0x00000000,0x00000000,0x00000000}},	//   فائد, --, --, --, 
   {{0x6aa401b2,0x00000000,0x00000000,0x00000000}},	// [2b4a0] _ibif, --, --, --, 
   {{0x69c40428,0x395c056a,0x4414248c,0xd1e4001f}},	//   _irie, íuse_, нфет, ኛነት_, 
   {{0x82a54691,0x69c40030,0x00000000,0x00000000}},	//   ешле, _hrie, --, --, 
   {{0x69c59814,0xdb1802fb,0x14c807f7,0x00000000}},	//   _krie, _krvá, राउण, --, 
   {{0x6aa40230,0x30100150,0x00000000,0x00000000}},	//   _mbif, ңдір, --, --, 
   {{0x65640851,0x69c59815,0x7d0401e1,0x00000000}},	//   mpih, _mrie, _mérè, --, 
   {{0x65640280,0x6aa40083,0xba38004e,0x80c00046}},	//   lpih, _obif, leït, _ەڭبە, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6280003a,0xba381e7b,0x65640108,0xb1400166}},	//   _idmo, neït, npih, ънәл, 
   {{0x6aa59816,0xfb845ab1,0x9b5803b7,0x7e740b4b}},	//   _abif, нымн, миот_, _šapć, 
   {{0xb5f80332,0x6ca00022,0xb87001ec,0x00000000}},	//   _leáp, урыж, ңғиы, --, 
   {{0x29040699,0x69c59817,0x3f8c0337,0xdce0c6da}},	//   èman_, _brie, mufu_, rtmı, 
   {{0xfce44149,0x69c40c3a,0x645d9818,0xdd959819}},	//   _подо, _crie, _ofri, _ралы, 
   {{0x6aa42252,0x69c43d42,0x7d040129,0x65640010}},	//   _ebif, _drie, _dérè, dpih, 
   {{0x628004b9,0xe784e1ce,0x69c5981a,0xb6c40131}},	//   _odmo, луто, _erie, нсай, 
   {{0x69c49229,0xb06001f1,0x7a0c0055,0xab28009b}},	//   _frie, _zväč, _ṛtun, _поја_, 
   {{0x65642819,0x39e00184,0x4429981b,0xfb94037e}},	// [2b4b0] gpih, _сәнғ, _ayb_, _hオ_, 
   {{0x6281369d,0x3f8d981c,0xd0400085,0x4428bd77}},	//   _admo, kufu_, _kolɔ, _byb_, 
   {{0x1cc4025c,0x798c003c,0xe2c800aa,0xb4d8004e}},	//   _ཌོན_, lucw, کونو_, _quàq, 
   {{0x7c283b3e,0xd0400296,0x3f8d981d,0x8778008d}},	//   _myfr, _molɔ, dufu_, _קארי, 
   {{0x645c0cfd,0x7c280368,0x69c40327,0x442806be}},	//   _ffri, _lyfr, _xrie, _eyb_, 
   {{0x3f8d981e,0x7c2803ac,0x10a5981f,0x3d18012d}},	//   fufu_, _oyfr, тикн, नकों_, 
   {{0x3f8c01aa,0x798c0117,0xe2140220,0x3870022e}},	//   gufu_, hucw, _ұмты, _mexr_, 
   {{0x798c2747,0xdce000e2,0xba38067c,0x8d580024}},	//   kucw, ksmē, neïs, мшот_, 
   {{0x7c2802d0,0x8ccc0950,0x9e6400db,0x00000000}},	//   _ayfr, तालो, داىن, --, 
   {{0x2d80341a,0x6f044c6e,0x3f8c1418,0xba3801a4}},	//   čje_, _bèbè, bufu_, heïs, 
   {{0x7c280f7b,0x69c59820,0x7d04020c,0x65640010}},	//   _cyfr, _srie, èksa, zpih, 
   {{0x69c59821,0x7c280368,0x7d040100,0x6d4c1709}},	//   _prie, _dyfr, _pérè, ícas, 
   {{0x69c40327,0x5ba802dd,0x9f340006,0xc27800d9}},	//   _qrie, _үкім_, _сеці, וררי, 
   {{0x69c59822,0x7954020a,0xba38004e,0xf53c01e3}},	//   _vrie, тиёр_, veït, _spån_, 
   {{0x7c280cfd,0x7cf40311,0x69c59823,0x7d040241}},	//   _gyfr, _bârf, _wrie, _wérè, 
   {{0x6aa40526,0x645c026c,0x798c003c,0xdb199824}},	//   _ubif, _sfri, bucw, _trvá, 
   {{0x69c59825,0x798c0117,0x4428045f,0xf7408f18}},	// [2b4c0] _urie, cucw, _syb_, рето, 
   {{0x65659826,0xb461632f,0x3f8c04ba,0x44280042}},	//   rpih, икул, yufu_, _pyb_, 
   {{0x65659827,0xba38004e,0xbcf80327,0x00000000}},	//   spih, seït, ྒྲིཊ_, --, 
   {{0x65659828,0x3f8c01fa,0x00000000,0x00000000}},	//   ppih, vufu_, --, --, 
   {{0xd6c40046,0x14c85829,0x3f8c0337,0x4824215c}},	//   _сияқ, राखण, wufu_, _سىڭق, 
   {{0xe1359829,0x3f8d982a,0xc04401d3,0x81c000e2}},	//   ынлы, tufu_, پختو, _ķēde, 
   {{0xdfd00597,0xc2980640,0xd5ac0014,0x40a402dd}},	//   صية_, _отац_, _وہہ_, еуқұ, 
   {{0x3f8d982b,0x7c3c0030,0xddc00153,0xbe880063}},	//   rufu_, _úpri, ramž, фске_, 
   {{0x3f8d982c,0xfb9400b5,0x9fc8013e,0x7c2803cb}},	//   sufu_, _sオ_, _ӯҳда_, _syfr, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x798c00d2,0x672401f4,0x9c7c00c0,0x00000000}},	//   wucw, koij, nkči, --, 
   {{0xb698084c,0x3be40228,0x7c2802f0,0x9c7c00c0}},	//   _amân, елүү_, _vyfr, ikči, 
   {{0x49a4052f,0x3ea401b9,0x00000000,0x00000000}},	//   лырғ, _ibot_, --, --, 
   {{0x6f04020c,0x3dc40334,0x7fa803e3,0x4df40395}},	//   _tèbè, _irow_, _vəqf, _щяхт, 
   {{0x644000df,0x2bc001bc,0xba39982d,0x69c033b8}},	//   _ŝmin, षिणा, teïs, åmer, 
   {{0x7cf4054e,0x3dc400a2,0x00000000,0x00000000}},	//   _bârg, _krow_, --, --, 
   {{0x3ea4020c,0x7cf40311,0x953806ed,0x96340276}},	// [2b4d0] _mbot_, _vârf, езат_, унац, 
   {{0x6b54013d,0x00000000,0x00000000,0x00000000}},	//   _яшәр_, --, --, --, 
   {{0xd251982e,0x3ea4003e,0xf99d982f,0x85e801d9}},	//   منا_, _obot_, ltè_, وِہے_, 
   {{0x249802fa,0x2bc00b7c,0xddc00024,0x27ec00b5}},	//   _ecrm_, षिता, namų, ødne_, 
   {{0xf99c0d29,0xe1f114ed,0xa15848a9,0xc69000df}},	//   ntè_, يسه_, вачу_, _פאך_, 
   {{0xe134cced,0x6e280368,0xdb1801bf,0x00000000}},	//   анчы, _rygb, _urvæ, --, 
   {{0x63b8037e,0xf99c033b,0xe3b0009f,0xe0d08863}},	//   ævnt, htè_, _ورف_, غزه_, 
   {{0xf99c0d29,0xddc00024,0x3dc59830,0xa2c400f3}},	//   ktè_, jamų, _brow_, _кљук, 
   {{0x5214023a,0x3dc40f85,0xddc000c0,0x00000000}},	//   _сдат, _crow_, damų, --, 
   {{0x3dc4062c,0x61e402f6,0x7d047dec,0x8b680120}},	//   _drow_, äile, éksp, ниов_, 
   {{0x3dc408e7,0x67243545,0xf99c007f,0x00000000}},	//   _erow_, yoij, etè_, --, 
   {{0xb698054e,0x6e2801e3,0xddc00064,0x00000000}},	//   _smân, _tygb, gamų, --, 
   {{0x3dc40c30,0xdd940024,0x672401f4,0xba7400db}},	//   _grow_, _вачы, voij, داپت, 
   {{0x7cf40356,0x09d4009e,0x3ea40332,0x38680118}},	//   _cârd, হনলা, _zbot_, _čiré_, 
   {{0xcba4036b,0xf99c007f,0x7cf40356,0xaa6401af}},	//   _сайй, atè_, _sârg, _кейһ, 
   {{0xb8e8fa1a,0x4a74a863,0xca7400fd,0x7cf40356}},	//   _रो_, _сыкт, _сукы, _pârg, 
   {{0x2d9d9831,0xd5e43769,0x24980311,0xf99d9832}},	// [2b4e0] ntue_, айтқ, _pcrm_, ctè_, 
   {{0x044400fd,0xf5040108,0x672401f4,0x00000000}},	//   гезн, гнул_, soij, --, 
   {{0x38981a4c,0x9a240543,0x2d9c0200,0x00000000}},	//   _איינ, _معین, htue_, --, 
   {{0x7cf4084c,0x2d9c1c9d,0x9c7c0153,0x00000000}},	//   _târg, ktue_, rkči, --, 
   {{0xc05810f5,0xc0e59833,0xc3780150,0x20540276}},	//   ній_, лодк, _اﺳﺘﺎ, аӂер, 
   {{0x26c00142,0x25a0010e,0x00000000,0x00000000}},	//   ldio_, mtil_, --, --, 
   {{0xa2840214,0xdb1801e3,0x00000000,0x00000000}},	//   _نیاو, _yrvä, --, --, 
   {{0x3dc59834,0xf7700375,0x2d9c036e,0x290402e2}},	//   _prow_, זקה_, ftue_, èmaj_, 
   {{0x7cf40dd4,0x26c00368,0x13c00150,0x5d540e92}},	//   _lâre, idio_, _ءﻧﺎﺭ, јкот, 
   {{0x3dc40798,0x7b6400ee,0xd36c00db,0x232801d5}},	//   _vrow_, лтме, _رۇۇ_, _чоғи_, 
   {{0x7050a04e,0x5b159835,0x2d88004e,0x00000000}},	//   _انما, имот, àcer_, --, 
   {{0x25a19836,0xf99c011c,0x3dc59837,0x19590743}},	//   ktil_, ttè_, _trow_, камы_, 
   {{0x26c00cfd,0xf1c40d01,0x2d9d9838,0xf99c0100}},	//   ddio_, लियन, ctue_, utè_, 
   {{0x25a0019b,0x7fa80cc1,0xac940597,0xf99d9839}},	//   dtil_, _təqd, _منها_, rtè_, 
   {{0xf99d983a,0x26c001e4,0x8cbc012d,0x25a00419}},	//   stè_, fdio_, _वोटो, etil_, 
   {{0xf99c033b,0x26c000e4,0x25a006be,0x00000000}},	//   ptè_, gdio_, ftil_, --, 
   {{0x25a07e54,0xe6645a8e,0x201808a5,0x25ac01ef}},	// [2b4f0] gtil_, стсо, _þrif_, _čilý_, 
   {{0x6474152d,0xb5f80332,0x26c00037,0x7fa80213}},	//   йгуу, _afác, adio_, _məqb, 
   {{0x29d80030,0x399c003a,0x6a140133,0xf2e401f4}},	//   ržať_, lîs_, _نبیر, людо, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb280489,0x25a1983b,0x3f9c0455,0x86780375}},	//   _ལེནཌ_, ctil_, _aqtu_, _שרשו, 
   {{0xa2940046,0xd008ea59,0x00000000,0x00000000}},	//   _қауі, келе_, --, --, 
   {{0x09e008e6,0x6458107d,0x717000ec,0xcef4041b}},	//   _पथ्य, žvic, جهڙا, ичињ, 
   {{0x2d9cabbd,0x684001d3,0x00000000,0x00000000}},	//   ttue_, ládé, --, --, 
   {{0x4df41318,0x00000000,0x00000000,0x00000000}},	//   ряйт, --, --, --, 
   {{0x26c00841,0x2d9d983c,0x00000000,0x00000000}},	//   zdio_, rtue_, --, --, 
   {{0xd0103ded,0x2d9c08cb,0x8ba400ee,0x26c003cb}},	//   _بلا_, stue_, шинж, ydio_, 
   {{0x25a1983d,0x26c00175,0xbb1400d1,0xbf600345}},	//   ytil_, xdio_, ﺳﯩﻲ_, _بگوو, 
   {{0x25a1983e,0xdde92dd7,0x3ae001e1,0x00000000}},	//   xtil_, _مروه_, _ọpá_, --, 
   {{0x8c443cd9,0x6d580de4,0x2ca4001e,0x26c003cb}},	//   _келе, mqua, _ubnd_, wdio_, 
   {{0x6d59983f,0x869921a2,0xc61c0709,0x00000000}},	//   lqua, ктат_, पथ्य_, --, 
   {{0x26c19840,0x09e43339,0x25a19841,0x399c003a}},	//   udio_, _воин, ttil_, bîs_, 
   {{0x6d599842,0x225801ec,0x00000000,0x00000000}},	// [2b500] nqua, қилы_, --, --, 
   {{0x25a19843,0xb9780bd4,0xf4859844,0x6d585a90}},	//   rtil_, _שניי, لامی, iqua, 
   {{0x6d599845,0x25a155c3,0x4ad95463,0x46a40006}},	//   hqua, stil_, _बचाव, _канв, 
   {{0x82a402d5,0x25a19846,0xc32400ee,0x96540395}},	//   радж, ptil_, шмек, _гърч, 
   {{0x41b40efb,0x4424006d,0xf4940014,0xd04003b9}},	//   рсет, ło_, _چھٔت_, _inlə, 
   {{0x6d580d63,0xf990011a,0x00000000,0x00000000}},	//   dqua, קרו_, --, --, 
   {{0x6d5816b8,0x2ff4084c,0x00000000,0x00000000}},	//   equa, иншь_, --, --, 
   {{0xe3b015fa,0x3da40006,0x932401d5,0x00000000}},	//   _ورځ_, ароб, _هرقن, --, 
   {{0xe23401d3,0x6d580051,0xd5c80055,0xaf300116}},	//   _اکاب, gqua, रियज, غرىت, 
   {{0x7cf59847,0xfd1007fc,0x00000000,0x00000000}},	//   _sârb, تجع_, --, --, 
   {{0x6d5816b8,0xecb40037,0x399c0142,0x00000000}},	//   aqua, _असरफ, wîs_, --, 
   {{0x6d580218,0x00000000,0x00000000,0x00000000}},	//   bqua, --, --, --, 
   {{0x6d599848,0x7e619849,0x7cf40311,0x6df0007b}},	//   cqua, _ifop, _cârc, _وكما, 
   {{0xac54020a,0x399c003a,0x5e700244,0x00000000}},	//   _кашф_, rîs_, _بۆکڕ, --, 
   {{0x3704a29c,0x00000000,0x00000000,0x00000000}},	//   ачав, --, --, --, 
   {{0x66f40228,0x27ec0158,0xdb200108,0x00000000}},	//   опсу, ødna_, ötäh, --, 
   {{0x63bc01b9,0x00000000,0x00000000,0x00000000}},	// [2b510] _asrn, --, --, --, 
   {{0x24f825a2,0xda702586,0x98b81422,0x8e7c0115}},	//   ануы_, _بُک_, _слот_, lkŝt, 
   {{0x7e6001ee,0xd6d00597,0xf6500117,0x34481798}},	//   _ofop, _فقد_, _менӯ, тчан_, 
   {{0x63bd984a,0xb2842401,0x6588002d,0x91b4033f}},	//   _dsrn, рыжк, úshâ, _आईआई, 
   {{0x658410e0,0x3f8c0204,0x826000d1,0x00000000}},	//   _мырз, erfu_, سۇلن, --, 
   {{0x675405af,0xf364014b,0x00000000,0x00000000}},	//   _دخیر, _втан, --, --, 
   {{0x4d640032,0x6d58045a,0x248c01f3,0xfdb400cc}},	//   әков, wqua, _ናዝሬት_, জমোড, 
   {{0xcc884bcf,0xd00801e0,0x6d580051,0xdea401b9}},	//   گنده_, кеһе_, tqua, قیمی, 
   {{0x8d740372,0x6d58068c,0x7bc9984b,0x0c7801c6}},	//   حابا, uqua, _arfu, лсны_, 
   {{0x6d59984c,0xcc8823cf,0xb9200092,0x11140066}},	//   rqua, دنده_, ተማሪዎ, _اثرگ, 
   {{0x6d59984d,0x4b25984e,0x8fd029db,0x00000000}},	//   squa, ймов, _хәлә, --, 
   {{0xdce000da,0xc6200183,0x69b4012c,0xd2580166}},	//   rpmā, পেটা_, इबली, _yaņa_, 
   {{0x333c1f21,0x7bc9984f,0x8d653bbc,0x6d580869}},	//   _mhux_, _erfu, _увле, qqua, 
   {{0x7cf40311,0x7fa803b9,0x00000000,0x00000000}},	//   _vârc, _həqa, --, --, 
   {{0x09e4015b,0x99180212,0x46f55d37,0x00000000}},	//   _পেশা, ріях_, бчат, --, 
   {{0xfb842580,0xcaf4c0e3,0x7c3c01c3,0x00000000}},	//   _ادوی, _دستب, _ùpra, --, 
   {{0x7fa80cc1,0xbd0007ea,0x63bd9850,0xc4847c47}},	// [2b520] _məqa, _àécr, _ssrn, йлак, 
   {{0x3f8c0042,0xaaa8000d,0x7ba00244,0x00000000}},	//   yrfu_, _छउँक, _بڵیم, --, 
   {{0x8ca80e5b,0x826811b6,0xf77001ed,0x00000000}},	//   ज्यो, гаев_, _ٹاپ_, --, 
   {{0x7cf4019f,0xb5f801e1,0x7fa806be,0x00000000}},	//   _mâra, _ifán, _nəqa, --, 
   {{0x2b400fa3,0x7cf405c7,0x20540126,0x9c7c0f03}},	//   _mhic_, _lâra, окля, ljče, 
   {{0x2b400076,0x15b0021f,0x00000000,0x00000000}},	//   _lhic_, _تەكس, --, --, 
   {{0x9c7c01a6,0xf8b00375,0x00000000,0x00000000}},	//   njče, פשה_, --, --, 
   {{0x3f8c0135,0x44f800fe,0xf2a00108,0x00000000}},	//   rrfu_, _আদিক_, _нисп, --, 
   {{0xf65c003b,0xc0e40117,0x00000000,0x00000000}},	//   _knær_, _лоак, --, --, 
   {{0x2d885b84,0xc0b400d1,0x00000000,0x00000000}},	//   ácea_, ﺸﻠﻪﺗ, --, --, 
   {{0x09e4000e,0x29180109,0x1ab59851,0x7fa806be}},	//   _পেলা, dnra_, обня, _fəqa, 
   {{0x2b40da1e,0x934000d1,0xd99001ec,0x00000000}},	//   _chic_, ﺭﯨﺪﯗ_, _ﺑﻪﺭﻩ_, --, 
   {{0x13b002a6,0xcf240c8b,0x195864c2,0xfbd001d9}},	//   ছিয়, _برلي, рагы_, زتھ_, 
   {{0x291804cc,0x2b400142,0x00000000,0x00000000}},	//   gnra_, _ehic_, --, --, 
   {{0x6c780677,0x00000000,0x00000000,0x00000000}},	//   _גרוד, --, --, --, 
   {{0xdce000da,0xceb8012c,0x291801e7,0x7fa803b9}},	//   ksmī, toři_, anra_, _xəqa, 
   {{0x7f580455,0x74681214,0x0594036b,0xf65c02d2}},	// [2b530] _lutq, грев_, قالگ, _snæs_, 
   {{0x7f5802d0,0x00000000,0x00000000,0x00000000}},	//   _outq, --, --, --, 
   {{0x7f58fb45,0xdce000e2,0x00000000,0x00000000}},	//   _nutq, esmī, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfcf002d3,0x7fa80213,0x32080066,0x00000000}},	//   _ውሽጡ_, _rəqa, دتاً_, --, 
   {{0x70b00ce0,0x00000000,0x00000000,0x00000000}},	//   ंजेल, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7d0801ab,0x228401c6,0x37b803d4,0xe2f852c4}},	//   _amfs, _нууг, _উপাৰ, _лесі_, 
   {{0x30a58481,0x00000000,0x00000000,0x00000000}},	//   _грев, --, --, --, 
   {{0xfcf0069c,0x202405f7,0xa1f001ec,0x00000000}},	//   _ውሽጢ_, árið_, _سۋىت, --, 
   {{0x7f580548,0x7fa80213,0x00000000,0x00000000}},	//   _gutq, _təqa, --, --, 
   {{0x2b8003be,0x19b8025c,0x2bd80316,0x68401a5e}},	//   rıc_, _བརྡབ, यमबा, _ládí, 
   {{0x7cf4019f,0xabd4066d,0x6f0926cc,0x63800241}},	//   _wâra, _گزشت, _imgc, _káná, 
   {{0xc764568c,0x27ec0158,0x7f5801d5,0xba080408}},	//   قارى, ødno_, _yutq, ăхне_, 
   {{0x3db40327,0x68fc02f0,0x2b400051,0xfcf00023}},	//   _དགོན, rhrd, _thic_, _ውሽጣ_, 
   {{0x3af824ba,0x05753d55,0x39580139,0x68fc01b9}},	//   _pëpe_, قائد, _fuqs_, shrd, 
   {{0x395005d5,0xc4e42b9c,0x35a001b9,0x7cd800e2}},	// [2b540] _fixs_, ожай, матг, sārņ, 
   {{0x612404cc,0x00000000,0x00000000,0x00000000}},	//   sòlz, --, --, --, 
   {{0x6f080472,0x7d041801,0x8ca047b8,0x3cf800df}},	//   _omgc, èksi, _खानो, סלענ, 
   {{0x61e401c7,0x7d0400e5,0x7c2c0112,0x00000000}},	//   äilo, éksz, übri, --, 
   {{0xdc2800d7,0x00000000,0x00000000,0x00000000}},	//   _rôčk, --, --, --, 
   {{0x7f580d04,0x6f080117,0x15b0113e,0x00000000}},	//   _putq, _amgc, _سەمس, --, 
   {{0x4ac9147c,0x7f5801b9,0x7cf40356,0xaff400ae}},	//   ियाव, _qutq, _bârn, يفها_, 
   {{0x9ed80276,0x7cf4054e,0x00000000,0x00000000}},	//   смит_, _cârn, --, --, 
   {{0x52759852,0xf264084c,0x63800332,0xfd440006}},	//   _хусу, _фиул_, _fáná, жэнн, 
   {{0x7f599853,0x6f08009a,0xbc480957,0x7d0802d0}},	//   _tutq, _emgc, ичне_, _qmfs, 
   {{0x3ea40117,0x00000000,0x00000000,0x00000000}},	//   _мижг, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x63800241,0x00000000,0x00000000,0x00000000}},	//   _yáná, --, --, --, 
   {{0x6efc0248,0x9f0402f2,0xbb380150,0x00000000}},	//   _tàbù, _بوچو, _ﻓﺭﻉ_, --, 
   {{0xb9000d0a,0xba380ba1,0xa9340798,0x00000000}},	//   _नच_, neïz, ферш, --, 
   {{0x64580024,0x7d180139,0x00000000,0x00000000}},	//   žvil, lnts, --, --, 
   {{0x55559854,0x7d180170,0x61e402f6,0x8ca017cb}},	// [2b550] سپار, onts, äill, _खामो, 
   {{0x7d199855,0x4a24031c,0x3cfc0051,0x6ab000fe}},	//   nnts, _རྙིལ_, nhtv_, _জোপো, 
   {{0x7d199856,0x7cf40165,0x973405af,0xbb380150}},	//   ints, _lâro, _فکرا, _ﻓﻭﻕ_, 
   {{0x7d180109,0x7f4000d8,0x5fb40073,0xdb180118}},	//   hnts, _nhoq, ंबईल, _osví, 
   {{0x23782928,0x00000000,0x00000000,0x00000000}},	//   ممەد_, --, --, --, 
   {{0x7d1801d4,0xf8c800e1,0x00000000,0x00000000}},	//   jnts, ायिय, --, --, 
   {{0xa3b80736,0x00000000,0x00000000,0x00000000}},	//   _وافر_, --, --, --, 
   {{0x7f419857,0x7d199858,0x2d880005,0x73c00166}},	//   _choq, ents, áceo_, _нәҗе, 
   {{0xfafc044e,0x7f400449,0xdcb801e4,0xf8c807b7}},	//   dhë_, _dhoq, feĉ_, ायाय, 
   {{0xe7ac00bc,0x00000000,0x00000000,0x00000000}},	//   _चहलप, --, --, --, 
   {{0x7cf4054e,0x00000000,0x00000000,0x00000000}},	//   _târn, --, --, --, 
   {{0x7d199859,0x7f40047e,0x6f081cd8,0x7cf40356}},	//   ants, _ghoq, _umgc, _hârl, 
   {{0x7d180218,0x6f180521,0x1dc00022,0x7f38011a}},	//   bnts, mnuc, _аҩын, _פענו, 
   {{0x290c0428,0xfafc0022,0x00000000,0x00000000}},	//   òda_, ahë_, --, --, 
   {{0x7fa803be,0x6d41985a,0xbac40014,0x46f4005b}},	//   _nəql, _ihna, _کژٍن_, пчат, 
   {{0x6f19985b,0xfafc0036,0x00000000,0x00000000}},	//   nnuc, chë_, --, --, 
   {{0x6d400652,0x69c051bb,0x2bc0185d,0x29041497}},	// [2b560] _khna, çmed, षिका, èmas_, 
   {{0x6f181196,0x845821f3,0x61e40108,0x88700133}},	//   hnuc, срат_, äilm, _سێرڤ, 
   {{0x9c7d985c,0x6d401554,0x84580022,0x00000000}},	//   njča, _mhna, арҵт_, --, 
   {{0xb6980421,0x56a002d3,0x00000000,0x00000000}},	//   _alâf, _ውጽኢቱ_, --, --, 
   {{0x7f4000aa,0x2efc208d,0x6d40d5d3,0x7cf40311}},	//   _rhoq, dhuf_, _ohna, _bârl, 
   {{0x7f40069c,0x6604c611,0x3da5985d,0xfafc0023}},	//   _shoq, mzik, җриб, zhë_, 
   {{0x7f41985e,0x7d180218,0x66040109,0xaf300811}},	//   _phoq, vnts, lzik, کروت, 
   {{0x7f4001af,0xe2f800dd,0xbb1408b0,0x6d400245}},	//   _qhoq, _بورڈ_, ﺳﯩﻞ_, _ahna, 
   {{0x3cfc02fa,0x6605985f,0x41040064,0x61c80244}},	//   thtv_, nzik, _езав, _بدزێ_, 
   {{0x7d180c8c,0x6d419860,0x66059861,0xc10416ac}},	//   unts, _chna, izik, _عواي, 
   {{0xfafc069c,0x7d18df4f,0xdcb801e4,0x00000000}},	//   thë_, rnts, reĉ_, --, 
   {{0xf77045fa,0x7d199862,0x2efd9863,0x6d40009d}},	//   ہار_, snts, chuf_, _ehna, 
   {{0x260c000d,0x00000000,0x00000000,0x00000000}},	//   _ठेली_, --, --, --, 
   {{0x66059864,0xfafc044e,0xc2f800bd,0x6d419865}},	//   dzik, shë_, েকটি_, _ghna, 
   {{0x3688152d,0x8ca006ab,0xcce423bb,0x6604009a}},	//   йсан_, _खातो, _تسني, ezik, 
   {{0x9f5800c7,0xec3405d0,0x00000000,0x00000000}},	//   _ãrõ_, _מאור_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [2b570] --, --, --, --, 
   {{0x5ec8009e,0xa5340139,0x00000000,0x00000000}},	//   িউটে, енуч, --, --, 
   {{0x6f199866,0x66040083,0xd25001d3,0xf53c007c}},	//   ynuc, azik, چنا_, _spås_, 
   {{0xaee00a28,0xd2519867,0x95d8014b,0x00000000}},	//   maṇa, ننا_, _ддмт_, --, 
   {{0x066410de,0x7cf40356,0x5ee000dc,0x6f1802f0}},	//   _تاپپ, _pârl, कान्_, vnuc, 
   {{0x7fa803e3,0xdce0013d,0x00000000,0x00000000}},	//   _təql, kumı, --, --, 
   {{0x7cf40356,0xceb80118,0x00000000,0x00000000}},	//   _cârm, teř_, --, --, 
   {{0xdb1801f1,0xfe6c0517,0x6d4000a3,0x00000000}},	//   _prvý, لگه_, _shna, --, 
   {{0xaee00882,0xa1951af5,0x9e6506f6,0x00000000}},	//   haṇa, _патч, راين, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xaca001f2,0x660404ba,0x3cdc033f,0xceb80118}},	//   jiụl, zzik, _कचरे_, peř_, 
   {{0x8d746886,0xc9a806ed,0x00000000,0x00000000}},	//   _قاتا, овме_, --, --, 
   {{0x644802f0,0x00000000,0x00000000,0x00000000}},	//   _údiv, --, --, --, 
   {{0x1cbc025c,0xdb18004e,0x1dbc098a,0x9c7c0010}},	//   _ཅིར_, _esvà, ्टरत, ljčn, 
   {{0xcb6802f2,0x00000000,0x00000000,0x00000000}},	//   _بمبه_, --, --, --, 
   {{0x660401c0,0xf74007d8,0x00000000,0x00000000}},	//   tzik, весо, --, --, 
   {{0x6aa41dc9,0xb97421ec,0x6604009f,0x9aa929f5}},	// [2b580] _icif, _قميص_, uzik, _رديف_, 
   {{0x66059868,0xf53c9596,0x44880212,0x69c44f63}},	//   rzik, _spår_, ібен_, _isie, 
   {{0x69c40135,0x5ee000dc,0x660400e5,0x00000000}},	//   _hsie, काम्_, szik, --, 
   {{0x69c59869,0x7cf40356,0x00000000,0x00000000}},	//   _ksie, _cârj, --, --, 
   {{0x8c10015b,0x41280228,0x69c40327,0x9598084c}},	//   _সুমন_, оодо_, _jsie, _нтру_, 
   {{0x69c5986a,0x22940241,0xf65000cf,0x00000000}},	//   _msie, _búkà_, _جئپ_, --, 
   {{0xb3b0004b,0x69c40135,0xdfd01c43,0x6aa403ac}},	//   _ټینګ, _lsie, ايب_, _ocif, 
   {{0x2565986b,0x69c5986c,0x5ea4009e,0xd158001f}},	//   _köl_, _osie, _খোজে, ገባቸው, 
   {{0x25640793,0x69c4013f,0x5d55986d,0xd1740022}},	//   _jöl_, _nsie, нкит, _зыхы, 
   {{0x6281986e,0xb14000a8,0xaee00882,0x6aa40857}},	//   _hemo, _анул, yaṇa, _acif, 
   {{0x6281986f,0x256401c7,0xaad000af,0x00000000}},	//   _kemo, _löl_, _तोहक, --, 
   {{0x60c99870,0xdb180ba1,0x62802515,0xaee00882}},	//   _hadm, _arvò, _jemo, vaṇa, 
   {{0x645d9871,0xfce400db,0x00000000,0x00000000}},	//   _ogri, _оодо, --, --, 
   {{0x645d9872,0x6aa40c8c,0x60c97c4f,0x62819873}},	//   _ngri, _ecif, _jadm, _lemo, 
   {{0x60c8102c,0x69c59874,0xdb180077,0x62804087}},	//   _madm, _esie, _esvá, _oemo, 
   {{0xaee01161,0x60c99875,0xdb180162,0xe7840640}},	//   raṇa, _ladm, _fsvá, ђусо, 
   {{0x60c800e4,0xdb080036,0xd1d4069d,0x00000000}},	// [2b590] _oadm, htdë, ካቲት_, --, 
   {{0x1cbc0003,0x6280b4b7,0xd76003e6,0x25642ca8}},	//   _ཅིས_, _aemo, _مۆسی, _döl_, 
   {{0x645c0175,0x644000df,0xe4a400a7,0x00000000}},	//   _dgri, _ŝmir, ърто, --, 
   {{0x645d9876,0x60c80014,0x25659877,0xaabc008f}},	//   _egri, _aadm, _föl_, ַזוכ, 
   {{0x62819878,0xe5c416c3,0x645c01c3,0xe2c8004b}},	//   _demo, _исро, _fgri, بونو_, 
   {{0x60c99879,0x6281987a,0x19b80135,0x7afc0113}},	//   _cadm, _eemo, _བརླབ, _llqt, 
   {{0x6281987b,0x60c9987c,0xe455987d,0x25640139}},	//   _femo, _dadm, _акры, _zöl_, 
   {{0x6281987e,0xb69800d2,0x645c0841,0x60c893f6}},	//   _gemo, _hlâb, _zgri, _eadm, 
   {{0xa2dc2ac3,0x00000000,0x00000000,0x00000000}},	//   फार्, --, --, --, 
   {{0x6aa5987f,0x62819880,0x60c80009,0x229401e1}},	//   _scif, _zemo, _gadm, _túkà_, 
   {{0x62819881,0x3b8005f5,0x69c4025c,0xa5b4010e}},	//   _yemo, ллэг, _ssie, _ỳüze_, 
   {{0x8a040209,0x69c47392,0x00000000,0x00000000}},	//   езме, _psie, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x61e4023a,0x6c6401ed,0xa02406be,0x69c400d7}},	//   äili, _غلبہ_, _fgöğ, _vsie, 
   {{0x25640793,0x69c40210,0x00000000,0x00000000}},	//   _söl_, _wsie, --, --, 
   {{0xc4c4304e,0x69c59882,0x645d9883,0x7bc40a26}},	//   کترو, _tsie, _sgri, ākut, 
   {{0x443c38a2,0xb6f40075,0x69c401f7,0x25640139}},	// [2b5a0] _št_, رىكا_, _usie, _qöl_, 
   {{0x75d010fe,0xaaac39de,0x256408a5,0x00000000}},	//   ديكا, ट्रक, _völ_, --, 
   {{0x62819884,0xa40002a6,0x60c99885,0x09e402f5}},	//   _pemo, ্থ্য_, _radm, _পেচা, 
   {{0x8698169c,0x22280502,0x422400f0,0xdb1c01d3}},	//   _этот_, وزشی_, ндев, őzöt, 
   {{0x60c99886,0x645c007f,0x06800220,0x00000000}},	//   _padm, _tgri, _ﺩﻩﻳﯩ, --, 
   {{0x7fa803be,0xba3806a3,0x5f94054a,0x60c8016d}},	//   _həqi, ngïa, викт, _qadm, 
   {{0x443c00dd,0x60c99887,0xb898010f,0x54340108}},	//   _át_, _vadm, לבסש, _ахту, 
   {{0x60c99888,0xfb7004a9,0xfeb812ea,0x62800129}},	//   _wadm, ққия, ساعت_, _uemo, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2904002e,0x00000000,0x00000000,0x00000000}},	//   ëmal_, --, --, --, 
   {{0x20199889,0xeb940798,0xa2d4276a,0x00000000}},	//   _äri_, ниќ_, णयप्, --, 
   {{0xbd6801ec,0x7fa806be,0x8f740064,0x00000000}},	//   _ерке_, _nəqi, _руфі, --, 
   {{0x7cf4030a,0x00000000,0x00000000,0x00000000}},	//   _lâri, --, --, --, 
   {{0xfca9988a,0xa3d028df,0x00000000,0x00000000}},	//   _راتو_, वटा_, --, --, 
   {{0x7fa806be,0xdb1802d2,0x00000000,0x00000000}},	//   _bəqi, _rsvæ, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7fa803be,0x00000000,0x00000000,0x00000000}},	// [2b5b0] _dəqi, --, --, --, 
   {{0xf99c0ffb,0x57f40b2b,0x00000000,0x00000000}},	//   muè_, _апот, --, --, 
   {{0x3ea400d0,0x7fa803e3,0x69d8072d,0x00000000}},	//   _ocot_, _fəqi, _قبیح_, --, 
   {{0x75805dcd,0x00000000,0x00000000,0x00000000}},	//   _میرم, --, --, --, 
   {{0x3dc40134,0x10a47696,0xf99d988b,0x2178013d}},	//   _nsow_, вилн, nuè_, ейчы_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3dc4016b,0x7fa800ac,0x53340121,0x00000000}},	//   _asow_, _yəqi, _аевт, --, 
   {{0x7f48004b,0x0e540395,0x00000000,0x00000000}},	//   وسيې_, къпя, --, --, 
   {{0xf99c0ffb,0x91800131,0x2d88e3f6,0x7bc40210}},	//   juè_, _ئۇتۇ, éce_, łkul, 
   {{0x3ea4003e,0xf99c0ffb,0x7d05988c,0x4fc00150}},	//   _ecot_, duè_, ūksn, _نەتە, 
   {{0x5f9400a7,0x29041bce,0xab6000db,0x00000000}},	//   _бихт, ëmam_, دۇبى, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7fa800ac,0xf99c0ba1,0xdbe401e1,0x8274010f}},	//   _rəqi, guè_, _lèèr, כערע_, 
   {{0x2d9c009f,0x00000000,0x00000000,0x00000000}},	//   muue_, --, --, --, 
   {{0x47580a89,0xe7c00154,0x00000000,0x00000000}},	//   драя_, উম্য, --, --, 
   {{0xd1cc0092,0x00000000,0x00000000,0x00000000}},	//   ጣሁት_, --, --, --, 
   {{0x2a61988d,0xf99c007f,0xc4c801c4,0x00000000}},	// [2b5c0] _igib_, nzèl_, млаж_, --, 
   {{0xdbe40ca8,0x39980677,0x00000000,0x00000000}},	//   _bèèr, _קייד, --, --, 
   {{0x78f8011a,0x7fa80213,0xd25800ef,0x00000000}},	//   _חליפ, _təqi, _maņu_, --, 
   {{0x2919988e,0xdbe401e1,0x2a60031c,0x1f759544}},	//   lira_, _dèèr, _jgib_, қлия, 
   {{0x4aa8069f,0x26c00798,0x00000000,0x00000000}},	//   _कानव, meio_, --, --, 
   {{0x2918f948,0xb14117ea,0x3ea5988f,0x25a19890}},	//   nira_, анчл, _scot_, muil_, 
   {{0x73e19891,0xadc00241,0x29199892,0x00000000}},	//   _корз, _irẹj, iira_, --, 
   {{0x29199893,0x2a619894,0x26c19895,0x02d800db}},	//   hira_, _ngib_, neio_, _تورب_, 
   {{0x1d340801,0x6d440327,0x00000000,0x00000000}},	//   лния, ċjan, --, --, 
   {{0x29199896,0x26c19897,0xf99c026c,0xb5f801e1}},	//   jira_, heio_, vuè_, _ifát, 
   {{0x25a19898,0x26c0014b,0x9c7c0219,0x74980a1e}},	//   huil_, keio_, ljčk, וייפ, 
   {{0x29199899,0x25a1989a,0x27f80042,0x00000000}},	//   eira_, kuil_, dyrn_, --, 
   {{0xdd95989b,0x2919989c,0x26c00798,0x2b4401c0}},	//   _салы, fira_, deio_, рээг, 
   {{0x29180a03,0xf99c0ffb,0x2a6001d5,0x25a001ab}},	//   gira_, ruè_, _egib_, duil_, 
   {{0x5694334e,0x4428004d,0x25a0557b,0xf99cef52}},	//   лавт, _nxb_, euil_, suè_, 
   {{0x25a074bb,0x2a600327,0x2918c2c1,0xb5f907d1}},	//   fuil_, _ggib_, aira_, _ngác, 
   {{0x29189d20,0xf99c26b7,0xadf820f0,0x2d880010}},	// [2b5d0] bira_, què_, एनएन_, šcev_, 
   {{0x2918af7c,0xd17401ec,0xe85401e2,0x00000000}},	//   cira_, ңылы, انېد, --, 
   {{0x44280798,0x4aa807d0,0x26c00393,0x9378010b}},	//   _cxb_, _कामव, beio_, хбет_, 
   {{0x26c00120,0x25a001ab,0xf77c031c,0x327001a9}},	//   ceio_, buil_, ċħdu_, рҳаё, 
   {{0xf1a45882,0x25a0281b,0xf62802bf,0x44293537}},	//   трен, cuil_, _ціни_, _exb_, 
   {{0x4428070d,0x00000000,0x00000000,0x00000000}},	//   _fxb_, --, --, --, 
   {{0xf2c40209,0x46a80316,0xbb4c00b5,0x00000000}},	//   _исан, ङ्कह, _mcmキ_, --, 
   {{0x2918ad5d,0x7fb40597,0x2240003d,0x0dc860a7}},	//   zira_, اهير_, żika_, елий_, 
   {{0x2919989d,0xc0bc0020,0x61e4023a,0xdbf8012d}},	//   yira_, ሱስም_, äilt, kłóc, 
   {{0x2919989e,0x00000000,0x00000000,0x00000000}},	//   xira_, --, --, --, 
   {{0x26c0009a,0x25a001f5,0x00000000,0x00000000}},	//   yeio_, zuil_, --, --, 
   {{0xaca0063f,0x00000000,0x00000000,0x00000000}},	//   _krịk, --, --, --, 
   {{0x29197027,0x26c000d8,0x7c28343a,0x59840022}},	//   tira_, veio_, _exfr, аҩын_, 
   {{0x1cbd989f,0x29180129,0xf1c400d0,0x7c2998a0}},	//   _ཅིག_, uira_, _ináč_, _fxfr, 
   {{0x26c00120,0x7cf4054e,0x00000000,0x00000000}},	//   teio_, _pârv, --, --, 
   {{0x291998a1,0x7fa800ac,0x25a00066,0x00000000}},	//   sira_, _təqv, tuil_, --, 
   {{0x291998a2,0x26c198a3,0x864598a4,0x442801d9}},	// [2b5e0] pira_, reio_, унаж, _sxb_, 
   {{0xb5f80077,0x26c006ed,0xe5a42097,0x25a01a7c}},	//   _afás, seio_, лиғи, ruil_, 
   {{0x46a400d1,0x7fa806be,0x25a001e7,0x3cf8010f}},	//   _йанв, _yəqu, suil_, עלענ, 
   {{0x7cf40276,0xe1880109,0xb28064c2,0x25a008c2}},	//   _hârt, tỳ_, бышк, puil_, 
   {{0x25a198a5,0x7b3400df,0x00000000,0x00000000}},	//   quil_, אָגע_, --, --, 
   {{0x672404b9,0x00000000,0x00000000,0x00000000}},	//   lnij, --, --, --, 
   {{0x6d441f21,0xdfd00597,0xf5005424,0x1cb0031c}},	//   ċjal, زية_, _узро, ྒུལ_, 
   {{0x1cbc038f,0x67241f21,0x42540014,0x7f8400db}},	//   _ཅིང_, nnij, _منزر, _ەلان, 
   {{0x69c0a697,0x422411ed,0x40941a21,0x9c7c46aa}},	//   çmel, _сдав, _брет, ljči, 
   {{0xa2d8102f,0x9d1400f5,0x00000000,0x00000000}},	//   _नोत्, рдоч, --, --, 
   {{0x9c7c01a6,0x3d380023,0x672598a6,0x00000000}},	//   njči, _ከባቢኡ, knij, --, 
   {{0x67241326,0x00000000,0x00000000,0x00000000}},	//   jnij, --, --, --, 
   {{0xb6980311,0x00000000,0x00000000,0x00000000}},	//   _blân, --, --, --, 
   {{0xbd00219b,0x7cf40356,0x672598a7,0x9d1801af}},	//   _šéfr, _cârt, enij, _шолт_, 
   {{0x7d1998a8,0x7e60175b,0xdd9401af,0x00000000}},	//   mits, _kgop, _саһы, --, 
   {{0x7d1998a9,0x7bc80113,0x67241619,0xf5e40111}},	//   lits, _isfu, gnij, лізм, 
   {{0xb5f80ca8,0x7d180770,0x68f00086,0xb698b433}},	// [2b5f0] _afár, oits, ñidò, _flân, 
   {{0x7d1998aa,0xb6994351,0x00000000,0x00000000}},	//   nits, _glân, --, --, 
   {{0x67255f8b,0x7fa80cc1,0x7e6198ab,0x00000000}},	//   bnij, _məqs, _ogop, --, 
   {{0x7e6198ac,0x7d1998ad,0x67240b91,0xfafc0240}},	//   _ngop, hits, cnij, nkë_, 
   {{0x7d1998ae,0x02c000d4,0x00000000,0x00000000}},	//   kits, ійшо, --, --, 
   {{0x7e613f50,0x78a40369,0x4f9421b4,0x8ca800cd}},	//   _agop, ngjv, ариу, ज्ञो, 
   {{0x7d1998af,0x35a805b3,0x00000000,0x00000000}},	//   dits, _चमड़, --, --, 
   {{0x0e653851,0xfafc0200,0x00000000,0x00000000}},	//   шкин, jkë_, --, --, 
   {{0x7d1998b0,0x4d640b3e,0x8d74007b,0xafe001b9}},	//   fits, јков, جابا, роқл, 
   {{0x7d1832ff,0xa3bd98b1,0x69c00790,0x4c8401b9}},	//   gits, _अहम_, çmem, шлов, 
   {{0x8c4598b2,0xfafc0240,0xfd740092,0x00000000}},	//   рене, fkë_, _በዲግሪ_, --, 
   {{0x63a80158,0x7cf4054e,0x7d1998b3,0x00000000}},	//   _ådne, _bârs, aits, --, 
   {{0x7d1998b4,0x67241326,0x7bc8b0eb,0xb698084c}},	//   bits, vnij, _esfu, _plân, 
   {{0x428c069c,0x6f18823f,0x7d1998b5,0x672401f5}},	//   _ናጽነት_, liuc, cits, wnij, 
   {{0x67241326,0xc71403b7,0x7cf40356,0x8ba4010a}},	//   tnij, аќањ, _vârt, _тийж, 
   {{0x672400da,0x6b800477,0xfafc036e,0xca74008e}},	//   unij, _iwng, ckë_, _тукы, 
   {{0x672405ce,0x6b8198b6,0x2fc40369,0xa56800dd}},	// [2b600] rnij, _hwng, hwng_, اشرے_, 
   {{0x67241326,0xb69800d2,0xf504084c,0x6f180200}},	//   snij, _hlâl, анул_, hiuc, 
   {{0x38980bd9,0x845998b7,0x2efc022f,0xd39805a2}},	//   _ביינ, трат_, kkuf_, ләтә_, 
   {{0x7d1998b8,0x6b800207,0x2fc40369,0x3cfc0618}},	//   zits, _mwng, dwng_, zktv_, 
   {{0x7d1998b9,0x6f18026c,0xdcb8010f,0x00000000}},	//   yits, diuc, liĉe_, --, 
   {{0xaca0063f,0x7d1802b9,0x2fc40368,0x6b800857}},	//   _brọk, xits, fwng_, _owng, 
   {{0x7d1998ba,0x21201b24,0x6b800369,0x6f1932ae}},	//   vits, đih_, _nwng, fiuc, 
   {{0x7d1998bb,0xaf303b89,0x3374010f,0xf48400e5}},	//   wits, يريت, _כעלם_, _ماہی, 
   {{0x7d1998bc,0xc0e4412c,0x3f8c0493,0xdfd0221d}},	//   tits, _коак, ssfu_, زيک_, 
   {{0x6208e162,0x6b800369,0x7d180869,0x0db801d3}},	//   ırlı, _bwng, uits, ائيں_, 
   {{0x7d1998bd,0x6b800097,0x2fc40369,0x9b59810e}},	//   rits, _cwng, cwng_, лиот_, 
   {{0x6b800007,0x6f1998be,0x7e600810,0x8f54002b}},	//   _dwng, ciuc, _ugop, _pṛśn, 
   {{0x7d1998bf,0xb5f80241,0xfafc0023,0x7fa800ac}},	//   pits, _agán, rkë_, _təqs, 
   {{0xf770d329,0x7d1998c0,0x7cf4084c,0x6b800399}},	//   قار_, qits, _vârs, _fwng, 
   {{0x9b94f2af,0xa9540220,0x3c940150,0x00000000}},	//   _البت, іксі, _ﻛﯘﺷﻰ_, --, 
   {{0x6b70aaab,0x1ab400cc,0x00000000,0x00000000}},	//   _بطوط, _জোৰা, --, --, 
   {{0xe7580212,0x54b8aec3,0x00000000,0x00000000}},	// [2b610] риті_, лгая_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x52740137,0x00000000,0x00000000,0x00000000}},	//   булу, --, --, --, 
   {{0x39400175,0x7fa806be,0x72a002de,0x00000000}},	//   lljs_, _nəqq, تەرن, --, 
   {{0xb9dc2e1f,0x95e80014,0x31c407b5,0x62240131}},	//   _እነ_, _صبحہ_, рсев, يىمل, 
   {{0x2fc403cb,0x00000000,0x00000000,0x00000000}},	//   twng_, --, --, --, 
   {{0xa2d80574,0x7fb426c0,0x9fbc012d,0x20540395}},	//   _नोव्, مهور_, dłóg_, отър, 
   {{0x0d8598c1,0x69c02ba3,0xf99c02bd,0x228401c6}},	//   блин, çmek, krè_, _мууг, 
   {{0x6f1947dc,0xc33000c8,0x6b800399,0x6b700356}},	//   riuc, _זון_, _swng, _măge, 
   {{0xf99c0395,0x48d00183,0x7d0401c6,0x00000000}},	//   drè_, _সক্ৰ, йныг_, --, 
   {{0x0eb8732a,0x00000000,0x00000000,0x00000000}},	//   _булы_, --, --, --, 
   {{0xb69806af,0x7fa80213,0xf99c0100,0x00000000}},	//   _blâm, _təqr, frè_, --, 
   {{0xf99c02bd,0x870c01e1,0x2be400fe,0x3a200108}},	//   grè_, _nípọ, খনেই_, змяг, 
   {{0x7fa806be,0x00000000,0x00000000,0x00000000}},	//   _zəqq, --, --, --, 
   {{0xf99d98c2,0x00000000,0x00000000,0x00000000}},	//   arè_, --, --, --, 
   {{0xfd341682,0x4aa998c3,0x49c8023a,0xca84009d}},	//   _ipﬁ_, _скин_, _блин_, _угий, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [2b620] --, --, --, --, 
   {{0x88c805b0,0xa6c8e17f,0x1cbc025c,0x291c0267}},	//   _слов_, ылға_, _ཅིབ_, _öva_, 
   {{0x6b700356,0x00000000,0x00000000,0x00000000}},	//   _făge, --, --, --, 
   {{0xb281788f,0x2d9d98c4,0x82a400d3,0x420802e8}},	//   пышк, krue_, садж, лнео_, 
   {{0x41b598c5,0x7fa80213,0x00000000,0x00000000}},	//   ссет, _rəqq, --, --, 
   {{0xd04006be,0xdf78003b,0x00000000,0x00000000}},	//   _halə, абкі_, --, --, 
   {{0x2d9c00b0,0xa3bc4709,0x00000000,0x00000000}},	//   erue_, _अहि_, --, --, 
   {{0x3da4b834,0x00000000,0x00000000,0x00000000}},	//   броб, --, --, --, 
   {{0x25a00184,0x249805b1,0xdcc80209,0x02040f7e}},	//   nril_, _kdrm_, иңде_, _узан, 
   {{0x25a0285e,0x7cf4054e,0xf99c02bd,0xd04003e3}},	//   iril_, _cârp, vrè_, _lalə, 
   {{0xb5f80077,0x25a04c8f,0x249806d9,0xbea801c8}},	//   _agál, hril_, _mdrm_, _مهان_, 
   {{0xfd486215,0x25a00219,0xdb080162,0xf99d98c6}},	//   _өзек_, kril_, ftdá, trè_, 
   {{0x4aa84a01,0x2d9d98c7,0xfe441a71,0x5a3401ca}},	//   _कारव, crue_, _ундо, інгт, 
   {{0x25a198c8,0xf99c011c,0xee340276,0x6b700311}},	//   dril_, rrè_, _унч_, _săge, 
   {{0x25a000d7,0x00000000,0x00000000,0x00000000}},	//   eril_, --, --, --, 
   {{0xf99c02bd,0xa2c40073,0x00000000,0x00000000}},	//   prè_, _रसग्, --, --, 
   {{0x768401ec,0x58d401ec,0x00000000,0x00000000}},	// [2b630] _қынж, _допт, --, --, 
   {{0xf314767b,0x00000000,0x00000000,0x00000000}},	//   әндә_, --, --, --, 
   {{0x1cbc0c99,0x25a000c5,0x3448f18b,0x6d4c0129}},	//   _ཅིན_, aril_, учан_, ïcai, 
   {{0xa29410f5,0x3af802b5,0x317001b9,0xd1d83667}},	//   заці, _tëpu_, зғат, идец_, 
   {{0x51540415,0xddd45043,0xb14400f2,0x00000000}},	//   отку, _ğaşi, میرم_, --, 
   {{0x65a80108,0xc0e001f4,0xddd41ea0,0x00000000}},	//   _утюг_, дошк, _şaşi, --, 
   {{0x4aa8078a,0x26e4030a,0x7bdc022a,0xd010007b}},	//   _कालव, ńsoů_, _špun, بلغ_, 
   {{0x2d9cbea3,0x63a80158,0xdb0801bf,0xd04006be}},	//   true_, _ådna, ltdæ, _xalə, 
   {{0xbf100137,0x2d9c0129,0x00000000,0x00000000}},	//   بويب, urue_, --, --, 
   {{0x2d9d98c9,0x212001c7,0x9f480419,0x00000000}},	//   rrue_, éiht_, _škôd_, --, 
   {{0x25a005b1,0x9f04004b,0xd12c00f7,0x00000000}},	//   zril_, _ډولو, _كۅچ_, --, 
   {{0x25a0022c,0x2d9c0200,0x00000000,0x00000000}},	//   yril_, prue_, --, --, 
   {{0x9ec80014,0xb6980139,0x00000000,0x00000000}},	//   _دِنم_, _ilâh, --, --, 
   {{0xd04006be,0x00000000,0x00000000,0x00000000}},	//   _salə, --, --, --, 
   {{0x46f402bf,0xc1b400cd,0x991828f6,0x00000000}},	//   очат, _आङ्ग, сіях_, --, 
   {{0x25a198ca,0x00000000,0x00000000,0x00000000}},	//   tril_, --, --, --, 
   {{0x2499004c,0x448858e8,0xdcb8008f,0x25a0000d}},	// [2b640] _pdrm_, ибан_, liĉa_, uril_, 
   {{0x25a198cb,0x1cb0031c,0x4aa800c5,0xdee40023}},	//   rril_, ྒུག_, _काँव, ምታና_, 
   {{0x25a00649,0xfb100133,0x00000000,0x00000000}},	//   sril_, _رویج, --, --, 
   {{0x25a198cc,0x3bb8008f,0xc24400f3,0x00000000}},	//   pril_, ימעד, онек, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdfd0301c,0x6ea40316,0x764801d3,0x00000000}},	//   فيت_, _गाउँ, ügye, --, 
   {{0x4aa809bb,0x98b0054e,0x00000000,0x00000000}},	//   _कांव, loză_, --, --, 
   {{0x63b4033f,0x741001d3,0xc0340023,0xb0240e56}},	//   ągnę, _کوہا, _ኣዳለው, تكىم_, 
   {{0x6b7c0020,0xf99c007f,0xaf30a0bc,0x00000000}},	//   _የተሻለ_, nzèt_, بروت, --, 
   {{0xdcb8010f,0x7f9400c7,0x00000000,0x00000000}},	//   fiĉa_, _ҳаҧх, --, --, 
   {{0xb1100131,0x6910013d,0x00000000,0x00000000}},	//   _تولغ, _käef, --, --, 
   {{0xce3401b9,0x00000000,0x00000000,0x00000000}},	//   _کوهک, --, --, --, 
   {{0xfe400214,0x2a640395,0x00000000,0x00000000}},	//   _تکثی, дърг, --, --, 
   {{0x2ae400bc,0x00000000,0x00000000,0x00000000}},	//   गाउँ_, --, --, --, 
   {{0x36886599,0x67d40fbe,0x00000000,0x00000000}},	//   исан_, мору, --, --, 
   {{0x5574694c,0x2d4803cd,0x00000000,0x00000000}},	//   згат, nøen_, --, --, 
   {{0x7468cd11,0x7bd801d3,0xb8642dd0,0x00000000}},	// [2b650] арев_, lvtu, _وادو, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2d482b96,0x52751db3,0x515400d1,0x764800e5}},	//   køen_, пулу, үтлу, ügyb, 
   {{0x2d4813ce,0xca6401a9,0x92580108,0x00000000}},	//   jøen_, nikа, бает_, --, 
   {{0x6b70054e,0x98b00356,0x2d4812e8,0x00000000}},	//   _măga, coză_, døen_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x5ed40154,0xa3b40212,0x00000000,0x00000000}},	//   থানে, _обрі, --, --, 
   {{0x0d8598cd,0xe8a837e3,0x00000000,0x00000000}},	//   плин, _कञ्च, --, --, 
   {{0xfde40137,0x7de4009d,0x3ea00162,0x00000000}},	//   здык_, змыг_, ókta_, --, 
   {{0x2b400010,0xdcb801e4,0x00000000,0x00000000}},	//   _skic_, tiĉa_, --, --, 
   {{0x6b700311,0x2d482d8b,0x78b816a3,0x8c100154}},	//   _băga, bøen_, đuvl, _সুজন_, 
   {{0x7d0998ce,0x691000c5,0xdcb80115,0xdc7000c7}},	//   _elfs, _käeg, riĉa_, нҳәы, 
   {{0xe804a05b,0x3d280133,0x00000000,0x00000000}},	//   रन्थ_, شتیی_, --, --, 
   {{0x8238010f,0xa3bc012d,0x00000000,0x00000000}},	//   מערצ, _अहल_, --, --, 
   {{0x5ea40150,0x7d0400e2,0x37e00830,0x86987fec}},	//   _ءمۇل, īkst, норг, йтат_, 
   {{0x7d041d64,0x00000000,0x00000000,0x00000000}},	//   ūkst, --, --, --, 
   {{0x69100254,0x4da805ac,0x00000000,0x00000000}},	// [2b660] _näeg, _কনুৱ, --, --, 
   {{0x69c598cf,0x3af80036,0x45340212,0x98b0054e}},	//   _ipie, _hëpp_, їхат, roză_, 
   {{0x3af93e03,0x00000000,0x00000000,0x00000000}},	//   _këpp_, --, --, --, 
   {{0x69c4031c,0x9f5c00e4,0xcfe00154,0x00000000}},	//   _kpie, pyvé_, বহান, --, 
   {{0xe804007d,0x2d480217,0x5ed400cc,0xc2140037}},	//   रनका_, vøen_, থামে, _देखब_, 
   {{0x69c598d0,0x3af80de2,0x15b02309,0x00000000}},	//   _mpie, _lëpp_, _جەكس, --, 
   {{0x9f3402dd,0x00000000,0x00000000,0x00000000}},	//   мекі, --, --, --, 
   {{0x3da42678,0x69c598d1,0x69100036,0x0e80004b}},	//   проб, _opie, _fäeg, پیوټ, 
   {{0x5d54192a,0x69c40204,0x23980100,0x6b700356}},	//   мкит, _npie, lčj_, _răga, 
   {{0x2d484c5d,0x80a40220,0x61e0035a,0x3120004e}},	//   søen_, _ءمان, _irml, _здуг, 
   {{0x69c598d2,0x3af8002e,0x92c000fe,0xe1680244}},	//   _apie, _bëpp_, ্ঞৰ_, _اڵڵه_, 
   {{0xb69800d2,0x61e00427,0x00000000,0x00000000}},	//   _hlâv, _krml, --, --, 
   {{0x426c0020,0x3af81bce,0xfce402a9,0xaec40327}},	//   _ትናንት_, _dëpp_, _нодо, _ཁྲིོ, 
   {{0xa3bc0a28,0x52c86c08,0x69100254,0x7bcc025c}},	//   _अहं_, _रस्स, _näed, ħbub, 
   {{0x8c400730,0x69c598d3,0x7ac403fb,0xf99c067c}},	//   ößte, _epie, _еспе, tzès_, 
   {{0x3af800e8,0x61e000a3,0x65b00022,0x00000000}},	//   _gëpp_, _orml, _ẽhag, --, 
   {{0xa63598d4,0x395001c7,0xdb080200,0xfbd001f7}},	// [2b670] енті, _thxs_, hudë, _آتڻ_, 
   {{0x74680c60,0xdb08007c,0x23c806e3,0x00000000}},	//   срав_, stdä, रबंद, --, 
   {{0xe2c800aa,0x47701884,0x3af80de2,0x00000000}},	//   ګونو_, _ақсу, _yëpp_, --, 
   {{0xb1900032,0x3af800e8,0x59b007f7,0x2374072d}},	//   елдә, _xëpp_, _जमार, ءالح, 
   {{0x61e002b9,0xc1700e53,0xe2c800f1,0x73fc0154}},	//   _crml, نگلت, ثونو_, ্পেট_, 
   {{0x7f400869,0xdcb800df,0xb5f801e7,0x69100254}},	//   _akoq, diĉo_, _ngái, _väeg, 
   {{0xdb080120,0xa2d80b98,0x00000000,0x00000000}},	//   rudê, _नोक्, --, --, 
   {{0x0ea8822f,0x61e00175,0xdcb80115,0x00000000}},	//   цкий_, _frml, fiĉo_, --, 
   {{0x61e005ce,0x00000000,0x00000000,0x00000000}},	//   _grml, --, --, --, 
   {{0x2f2001e1,0x7ae0013f,0xdb08067c,0x00000000}},	//   _bègè_, _ɔnte, ludè, --, 
   {{0x69c598d5,0x3ed001b9,0xcac80395,0x00000000}},	//   _spie, رقیر, огне_, --, 
   {{0x69100254,0x00000000,0x00000000,0x00000000}},	//   _mäee, --, --, --, 
   {{0xdb1800b5,0xc62000eb,0x00000000,0x00000000}},	//   _opvæ, _ভুনা_, --, --, 
   {{0x25a42d8b,0xf99c0100,0x258401e1,0x6140010e}},	//   _åmli_, fyèb_, _lélò_, _išlä, 
   {{0x2f200241,0xe7480661,0x69c41430,0x00000000}},	//   _gègè_, зүне_, _wpie, --, 
   {{0x69c00274,0x00000000,0x00000000,0x00000000}},	//   çmes, --, --, --, 
   {{0xf740587f,0x056598d6,0x69c598d7,0x00000000}},	// [2b680] тето, дван, _upie, --, 
   {{0x2398007f,0xc4c4007b,0x3a200064,0x2f2001e1}},	//   tčj_, بترو, _шмыг, _yègè_, 
   {{0x7ae800d2,0x6d4005b1,0x1ab40154,0x5ed400eb}},	//   _úmtá, _mkna, _জোয়া, থাতে, 
   {{0xc208a065,0x4e0c76f8,0x9854104e,0x00000000}},	//   يقان_, िनाई_, _ятыш, --, 
   {{0x6d4198d8,0x856000c7,0xa08400ee,0x00000000}},	//   _okna, _аҽаҧ, еңзе, --, 
   {{0x66040c6a,0x672566fe,0xdcb80115,0x363401c8}},	//   myik, liij, viĉo_, _آرٽس, 
   {{0x660401ed,0x00000000,0x00000000,0x00000000}},	//   lyik, --, --, --, 
   {{0x74100879,0x6d4198d9,0xdb08067c,0xdcb80115}},	//   _شوقا, _akna, cudè, tiĉo_, 
   {{0x660598da,0xdb2401d3,0x6da00114,0x00000000}},	//   nyik, ósít, виња, --, 
   {{0xb69800d2,0x28c02170,0x67240810,0xf0a40276}},	//   _hlât, श्मि, hiij, _окул_, 
   {{0x672404ba,0x660598db,0xeb940798,0x00000000}},	//   kiij, hyik, миќ_, --, 
   {{0x6d4001e4,0x66040083,0x672400b5,0x22400003}},	//   _ekna, kyik, jiij, żiku_, 
   {{0x672598dc,0x6d4003a0,0xdb080129,0x6d440003}},	//   diij, _fkna, nudé, ċjar, 
   {{0x61e402f6,0x660598dd,0x00000000,0x00000000}},	//   äily, dyik, --, --, 
   {{0xb76401c6,0xb8f407f7,0x6ab401e3,0x00000000}},	//   дтай, _सस_, ädfö, --, 
   {{0x660400ca,0x6724013c,0x00000000,0x00000000}},	//   fyik, giij, --, --, 
   {{0x660401d3,0x1a6401d3,0xeab000ae,0x00000000}},	// [2b690] gyik, _سیسی_, _ضعي_, --, 
   {{0xb6980421,0x344807c6,0x00000000,0x00000000}},	//   _alât, очен_, --, --, 
   {{0xb5f800e4,0x2904013f,0x672404ba,0x7cf40356}},	//   _ngáv, ɔma_, biij, _bârz, 
   {{0x660598de,0x3dc400f2,0x9258023a,0x99d00154}},	//   byik, _opow_, пает_, ামীক, 
   {{0xe66522e2,0xb5f800e4,0x90c46ac5,0x66040223}},	//   _атро, _agáv, ебле, cyik, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe37598df,0x6d4003b2,0x258401e1,0x00000000}},	//   _алсы, _rkna, _télò_, --, 
   {{0xd7b4025c,0xfe6c6071,0xe518010f,0x00000000}},	//   _བྱབྱ, مگه_, ĵĵŝŝ, --, 
   {{0x2d880231,0xa2d828d4,0xd134009b,0x4d6400d8}},	//   èce_, _नोट्, _знаћ, нкив, 
   {{0x6725131a,0x7d04017a,0xba9007d2,0x00000000}},	//   ziij, ëksp, _ﻛﯩﻤﮕ, --, 
   {{0x8b250786,0x660403e0,0x00000000,0x00000000}},	//   едне, zyik, --, --, 
   {{0x2d884a31,0x8d745734,0xb9580ffb,0xce9400a7}},	//   âces_, _كاتا, ntìf, _чадъ, 
   {{0xd9b04da8,0xc838001f,0x69100036,0x37e001b9}},	//   لەيد, _የትራን, _näec, қотг, 
   {{0x6724022f,0xb5f80022,0x00000000,0x00000000}},	//   wiij, _ygáv, --, --, 
   {{0x672598e0,0x3dc804ba,0xca742401,0xd24598e1}},	//   tiij, ăbwe_, _пупы, _چچ_, 
   {{0x660598e2,0x68480020,0x317cd814,0xd2440c4f}},	//   tyik, _የኤርት, _otuz_, _نچ_, 
   {{0x05a8166f,0x35a0036b,0xc4e402dd,0x672598e3}},	// [2b6a0] явай_, латг, нжай, riij, 
   {{0x332c0226,0x8458005b,0x0394117e,0x00000000}},	//   engx_, прет_, ердя, --, 
   {{0x660598e4,0xb698004a,0x42c8247f,0x67252355}},	//   syik, _plât, зген_, piij, 
   {{0x67240050,0x66040526,0xeedc0037,0x00000000}},	//   qiij, pyik, _खोलऽ_, --, 
   {{0xd2000139,0x926400f2,0x22480166,0x00000000}},	//   аүтк, ندهم, фҗан_, --, 
   {{0xa5640014,0xdb080ba1,0x26c000df,0x381400fe}},	//   _شۯان, rudé, lfio_, _দুয়ো_, 
   {{0x7cf40276,0xdb0882af,0x63b40124,0x3f64001b}},	//   _târz, sudé, _шәах, нтиб, 
   {{0xb1802195,0x26c198e5,0xb3b800d9,0x00000000}},	//   šťan, nfio_, _ממלכ, --, 
   {{0x26c0015d,0x00000000,0x00000000,0x00000000}},	//   ifio_, --, --, --, 
   {{0xf198011a,0x00000000,0x00000000,0x00000000}},	//   _משמש, --, --, --, 
   {{0xabd002f2,0x00000000,0x00000000,0x00000000}},	//   ۆزێت, --, --, --, 
   {{0xdb1801bf,0x00000000,0x00000000,0x00000000}},	//   _opvå, --, --, --, 
   {{0xdd900131,0xb5f800e4,0x00000000,0x00000000}},	//   _ئوت_, _ygáu, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x26c198e6,0x69c80311,0x56940329,0xf6e4009d}},	//   ffio_, ădea, кавт, нцан, 
   {{0xe78400d8,0x00000000,0x00000000,0x00000000}},	//   ѓусо, --, --, --, 
   {{0xeab001ec,0xb5f801e7,0x3e740092,0x66740066}},	// [2b6b0] _اعى_, _ngát, _በዳሰሳ_, ادفر, 
   {{0xa4d80228,0x77400133,0x00000000,0x00000000}},	//   ндуу_, _ڕێزم, --, --, 
   {{0x92940953,0xb9580ffb,0x317c030a,0xb5f802fb}},	//   ваец, ttìf, _stuz_, _agát, 
   {{0x317c004c,0x7afc0135,0x67d4004e,0x237c00e5}},	//   _ptuz_, _joqt, _союу, ívja_, 
   {{0xb86403e6,0x7afc013d,0x00000000,0x00000000}},	//   _تاکو, _moqt, --, --, 
   {{0x4fa400a7,0x0664198a,0x00000000,0x00000000}},	//   викв, _جاپپ, --, --, 
   {{0xe53400c9,0xe4e401ce,0x24e40006,0x00000000}},	//   _серь, _сіян, _сцяг, --, 
   {{0x69100254,0x7afd98e7,0x98b04632,0x00000000}},	//   _mäea, _noqt, rozę_, --, 
   {{0xfe6c006c,0x8d54004e,0x6234022e,0x00000000}},	//   زگن_, кточ, _бету, --, 
   {{0xd0d802bf,0xfe407e7e,0x00000000,0x00000000}},	//   _ідеї_, рньо, --, --, 
   {{0x7afcdf63,0x09c817ee,0x00000000,0x00000000}},	//   _boqt, िब्य, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb2400d2,0x7afc0139,0x6cb029dc,0x00000000}},	//   ósát, _doqt, _йөнт, --, 
   {{0x8c440046,0x78b40393,0x9c840118,0x288401ec}},	//   _иеле, _ccxv, tečň, ықов, 
   {{0x19c00046,0xcd200014,0x2c0039d2,0x7afc0213}},	//   _құрм, _مژھی, _сүнм, _foqt, 
   {{0x7c2c09c2,0xaa4400d1,0xb6a001f0,0x00000000}},	//   úbre, _مۆجى, иисл, --, 
   {{0x26c000a9,0xb3440003,0xf99c0100,0xc8c80014}},	// [2b6c0] rfio_, _moħħ, lyèn_, _ہوکن_, 
   {{0xc7940022,0xf4841888,0x48050eab,0xa9e805ac}},	//   _ирмы, نامی, _апов, _পথপঞ, 
   {{0xcf8598e8,0x7afc3ae4,0xd3780212,0xf99c0100}},	//   _دژ_, _yoqt, ечі_, nyèn_, 
   {{0x032400a7,0x82640244,0x82a430c7,0x00000000}},	//   ъден, نهان, тадж, --, 
   {{0x41b40261,0x00000000,0x00000000,0x00000000}},	//   тсет, --, --, --, 
   {{0x91e4037e,0xdb0803cd,0x3490014b,0x00000000}},	//   psのa, stdø, _ваёр, --, 
   {{0xa2c49151,0x443c0086,0xf99c02e2,0x3b800092}},	//   _бәлк, _ât_, jyèn_, _የሰዎች_, 
   {{0xf99c02e2,0x717000ec,0x8c840124,0x00000000}},	//   dyèn_, _ڦهلا, қәша_, --, 
   {{0x7c840364,0xfca8004b,0x88a8009e,0xd33402d5}},	//   куне, وادو_, খ্যক, _сэры, 
   {{0x7afc27b3,0xcf8c0014,0xdb0c01e1,0xc0cc0240}},	//   _soqt, _کژو_, _òkún, ቢቦም_, 
   {{0x7afc014f,0x201803cd,0xbda415b4,0x0db800e5}},	//   _poqt, _åri_, رحکو, وئیں_, 
   {{0x69c80311,0x8f74109a,0xdce00205,0x929c0210}},	//   ăden, _суфі, rsmı, _gołd, 
   {{0xf2d01a4c,0x79a400a7,0x7afc014f,0xadb4009f}},	//   בער_, ърне, _voqt, _لهنا_, 
   {{0xa8a42add,0xaca000a2,0x7afc0009,0x00000000}},	//   ирск, _daỳh, _woqt, --, 
   {{0xe89402d5,0x3940005f,0x7afc025c,0x00000000}},	//   рась, rojs_, _toqt, --, 
   {{0x7bc998e9,0x23bc01ed,0xdcb800df,0x929c012d}},	//   _ipfu, díj_, diĉi_, _kołe, 
   {{0xc8dc000d,0x00000000,0x00000000,0x00000000}},	// [2b6d0] _फोकट, --, --, --, 
   {{0x58d409fe,0xb4640451,0xdcb801e4,0x00000000}},	//   _соот, نداه, fiĉi_, --, 
   {{0x58840124,0x69100641,0x644803b2,0xe37400c7}},	//   _иыҟа, _käen, _ødil, алхы, 
   {{0x521438eb,0x7bc807a9,0xef1c033f,0x00000000}},	//   лдет, _mpfu, ężko_, --, 
   {{0x28c01fe5,0x3f9c09a8,0x69101577,0xf99c007f}},	//   श्वि, _avtu_, _mäen, zyèn_, 
   {{0xadc00241,0x7bc890f0,0xc0b400d1,0xe1f0007b}},	//   _gbẹk, _opfu, лғуч_, تسم_, 
   {{0x998c02fb,0x8d7598ea,0x53340798,0x9f9400cf}},	//   šeň_, گابا, _бевт, ашыш, 
   {{0xdea407d6,0x6910005b,0x562c0092,0x00000000}},	//   لیمی, _näen, _ተመድበ, --, 
   {{0x8d748688,0x7bc88293,0x0e641def,0xdb0c0ca8}},	//   دابا, _apfu, ыкин, _òkùn, 
   {{0x4c84ae2e,0xf99c02e2,0x20d400db,0x929c0210}},	//   ылов, tyèn_, _ۅتۅج, _dołe, 
   {{0x1fb80022,0xc0cc0023,0xcc8803e6,0xaa0c012c}},	//   _алхы_, ቢኦም_, ونکه_, हन्छ_, 
   {{0xaca001e1,0x6910013d,0xdb080306,0xf99c0100}},	//   _isọk, _cäen, budí, ryèn_, 
   {{0x7bc80099,0x19b8084c,0xf99c02bd,0x00000000}},	//   _epfu, курь_, syèn_, --, 
   {{0xf99c033b,0x00000000,0x00000000,0x00000000}},	//   myèl_, --, --, --, 
   {{0xf99c0100,0x7aec01e7,0x00000000,0x00000000}},	//   lyèl_, áití, --, --, 
   {{0x0b5805a2,0xc5f402e8,0x00000000,0x00000000}},	//   _ярлы_, лязъ, --, --, 
   {{0xf99c02bd,0x8934007b,0x7aec02f0,0x09e40798}},	// [2b6e0] nyèl_, _معدا, šití, _сопн, 
   {{0x441598eb,0x00000000,0x00000000,0x00000000}},	//   лфет, --, --, --, 
   {{0x291800ae,0x842400db,0x00000000,0x00000000}},	//   mhra_, دىان, --, --, 
   {{0xe28598ec,0x28c00146,0x69100254,0xf99c033b}},	//   рған, श्रि, _käeo, kyèl_, 
   {{0x3d10145e,0xdb080077,0x4128fb0f,0xfdac0154}},	//   _lâwa_, xudí, нодо_, _কন্ড, 
   {{0xdfd002eb,0xf99c033b,0x69100254,0xeb1005dc}},	//   قيت_, dyèl_, _mäeo, ासुत_, 
   {{0xc5e40183,0x6aa40c8c,0x929c012d,0x00000000}},	//   _নথিপ, _odif, _sołe, --, 
   {{0x3ea0334b,0xd36c2544,0x6aa598ed,0x935800cf}},	//   ûkt_, _قۇل_, _ndif, _аруу_, 
   {{0x9d1462d9,0x00c80276,0x9e3400f7,0xc1e801c6}},	//   идич, _плак_, репч, _ядаж_, 
   {{0x6aa598ee,0x6b800175,0xfb8425a2,0xd1d40023}},	//   _adif, _btng, лымн, ረብቲ_, 
   {{0x291998ef,0x9b580cfc,0x61d4454f,0xde7000cd}},	//   dhra_, киот_, _धनुष, _enāṃ_, 
   {{0x7f940588,0x7de41375,0x00000000,0x00000000}},	//   _ааҧх, _مستم, --, --, 
   {{0xf2d004ac,0x6aa400a9,0xdd9598f0,0xb5f800e4}},	//   זער_, _ddif, _талы, _ngáp, 
   {{0x1958807e,0x2db4011a,0x00000000,0x00000000}},	//   тагы_, _עלון_, --, --, 
   {{0x201d98f1,0x7bc998f2,0xb6c439b8,0xfe5400e5}},	//   nzvi_, _upfu, лсай, _جیکب_, 
   {{0xa3e8257b,0x201c006f,0x98486518,0xf99c007f}},	//   बिन_, izvi_, еяға_, lyèm_, 
   {{0x29180597,0xadc000e4,0x7ce0063f,0x6910000d}},	// [2b6f0] bhra_, _osẽj, ọruk, _käel, 
   {{0x291998f3,0x628075fa,0xf99c0100,0x81e800cc}},	//   chra_, _afmo, nyèm_, মহা_, 
   {{0xdb0801c7,0x8e7c01e4,0xf99c0100,0x691026bb}},	//   erdé, ldŝe, lsè_, _mäel, 
   {{0x62800076,0x9c7c007f,0xc76407d2,0x52bc00d1}},	//   _cfmo, ndčb, _پاپى, _ﻧﯚﯞﻩ, 
   {{0xf99c0699,0x201c04cc,0xb60400a7,0xdcb801e4}},	//   nsè_, ezvi_, _сянк, liĉu_, 
   {{0x77742702,0xf39415f8,0x8fe4007b,0x9f5c0108}},	//   _kuxx, _مؤرخ, لأعم, hyvä_, 
   {{0x23e402d5,0x9f5c005b,0x2458009d,0x00000000}},	//   _літв, kyvä_, _барь_, --, 
   {{0x7774102c,0xb5f800e4,0xf99c02bd,0x9f5c0108}},	//   _muxx, _ygáp, ksè_, jyvä_, 
   {{0x6304141b,0x30a40cc9,0xf99c033b,0xe1ec024c}},	//   _اوقل, _брев, uyèl_, _эҳ_, 
   {{0x7d0401c0,0x6910008e,0xf99c02bd,0x8c4406be}},	//   иныг_, _cäel, ryèl_, lağə, 
   {{0xf99c0699,0x2eec0139,0x7bdc00d7,0x00000000}},	//   syèl_, _tngf_, _špur, --, 
   {{0x9c580032,0xdcb801e4,0x2918031c,0x00000000}},	//   ышыу_, diĉu_, whra_, --, 
   {{0x82d405e1,0x00000000,0x00000000,0x00000000}},	//   בורג_, --, --, --, 
   {{0xc85002d3,0x69100037,0xdc40013a,0x00000000}},	//   _መትከላ, _väeo, _zůča, --, 
   {{0xc7640a52,0x86941fbe,0xa804013d,0x291800d7}},	//   لارى, ијач, _ğısy, rhra_, 
   {{0x068598f4,0x291998f5,0x764c037e,0x9510031c}},	//   рган, shra_, _bycy, ཎིའི_, 
   {{0x78b8098d,0x62800472,0x2d9c003a,0x2918003e}},	// [2b700] đuvr, _rfmo, nsue_, phra_, 
   {{0x35d40c58,0x399808a8,0x691000a2,0xb0c400c0}},	//   সমূহ, _שייד, _käem, _апiс, 
   {{0x55c48f62,0x62800175,0x2d48005c,0x7528007f}},	//   _қарғ, _pfmo, løes_, ègza, 
   {{0xf99c0699,0x69100254,0x00000000,0x00000000}},	//   zyèm_, _mäem, --, --, 
   {{0x016401a9,0x00000000,0x00000000,0x00000000}},	//   акдо, --, --, --, 
   {{0x25a047af,0x929c0210,0x00000000,0x00000000}},	//   msil_, _połc, --, --, 
   {{0xdfd00491,0x691025e4,0xb958026c,0xefb001d5}},	//   سية_, _näem, ntìa, قیلگ, 
   {{0xef74044e,0x24980493,0x69c80356,0x00000000}},	//   _ኣቐዲሙ_, _herm_, ădej, --, 
   {{0x24980ea0,0x6b70054e,0x25a01948,0xf99c02bd}},	//   _kerm_, _măgu, nsil_, tyèm_, 
   {{0x25a198f6,0x7e9c02dd,0x31b800d9,0x00000000}},	//   isil_, _ﺍﺩﻩﺕ_, _בזמנ, --, 
   {{0x25a198f7,0x9f5c005b,0x691026bb,0xdb08002f}},	//   hsil_, tyvä_, _väel, ptdü, 
   {{0x25a198f8,0x77740327,0x929c012d,0xf99c007f}},	//   ksil_, _ruxx, _koła, syèm_, 
   {{0x49a46f78,0x7774031c,0xf99c0ba1,0x2d4801bf}},	//   йырғ, _suxx, usè_, tøet_, 
   {{0xee343531,0xf99c07de,0x9f5c005b,0x00000000}},	//   _әнә_, rsè_, syvä_, --, 
   {{0x7774011f,0xf99d98f9,0x69100254,0x25a0002e}},	//   _quxx, ssè_, _käej, esil_, 
   {{0x25a007d6,0x249801c7,0xf99c0066,0x5ed4009e}},	//   fsil_, _aerm_, nyèk_, থাকে, 
   {{0x249998fa,0x69100254,0xbbb407b7,0x00000000}},	// [2b710] _berm_, _mäej, _अमुक, --, 
   {{0x7774102c,0xf48598fb,0x2d480158,0x48c14959}},	//   _tuxx, руан, løer_, _нәса, 
   {{0x249998fc,0x3ea40098,0x25a0602e,0x00000000}},	//   _derm_, _odot_, asil_, --, 
   {{0xfafc069c,0x3ea4036e,0x3cc80150,0x7bcc0327}},	//   një_, _ndot_, _ﺒﻤﺴﻤ, ħbuh, 
   {{0x249998fd,0x91e598fe,0xd25198ff,0x6d440003}},	//   _ferm_, соле, سچر_, ċjaz, 
   {{0xe16400c6,0x6594566d,0x929c033f,0xe13402d5}},	//   يدوي, _фару, _doła, ончы, 
   {{0x835000dd,0x2378031c,0xba380561,0x2d48072b}},	//   _کھلا, _gurj_, laïd, køer_, 
   {{0x3d10019f,0x28380302,0x2d9d9900,0x2d4833b8}},	//   _bâwo_, ינוך_, tsue_, jøer_, 
   {{0xba3805da,0x4d480116,0x52140114,0xf204010a}},	//   naïd, лпин_, _удат, _тяво, 
   {{0x7d18e401,0xeb108153,0xfafc0240,0x2d9d9901}},	//   ghts, ास्त_, ejë_, rsue_, 
   {{0x8c450bd9,0x3ea4007f,0xf99c00f2,0x2d9d9902}},	//   сене, _fdot_, byèk_, ssue_, 
   {{0xa3e81533,0xf1b81533,0xfafc02d3,0x9f0400db}},	//   बित_, _ईमान, gjë_, _وولو, 
   {{0x25a001a9,0x5ec000eb,0x00000000,0x00000000}},	//   xsil_, _শোকে, --, --, 
   {{0x7d199903,0x69100724,0xdc2804d3,0x7c300436}},	//   chts, _täem, اسیه_, ádrá, 
   {{0x6b70054e,0x25a000e8,0xe7380124,0xaee000b8}},	//   _păgu, wsil_, иҵо_, caṣa, 
   {{0x22c002b1,0x25a000c5,0x2498a428,0x691000c5}},	//   _kōkō_, tsil_, _serm_, _käek, 
   {{0x24999904,0xc4c873f6,0xb60002f0,0xdb1401e1}},	// [2b720] _perm_, ллаж_, jháč, _ìbáb, 
   {{0x25a19905,0x04459906,0x69100037,0x00000000}},	//   rsil_, безн, _mäek, --, 
   {{0x25a19907,0x84599908,0x249805d5,0x6f199909}},	//   ssil_, урат_, _verm_, khuc, 
   {{0x0f1000e1,0x9f5800b5,0x6f18014f,0x9358074d}},	//   ़सोस_, _ærø_, jhuc, арчу_, 
   {{0x2499990a,0x20982347,0x69100037,0xc3300014}},	//   _term_, аклы_, _näek, _ہٕس_, 
   {{0x69c005d1,0xc0580826,0xb97808a8,0x00000000}},	//   çmey, лій_, אנסי, --, 
   {{0xf484066d,0x3ea40649,0xba380129,0x929c012d}},	//   _چاہی, _pdot_, maïe, _woła, 
   {{0xdcd028b8,0x31d00131,0xba38017a,0xb0000055}},	//   तज्ञ, تقۇز, laïe, _guḍo, 
   {{0xbdf80dd8,0xb60002fb,0x929c012d,0x6910000d}},	//   ارعا_, cháč, _kołn, _väej, 
   {{0xa3bc0316,0x00000000,0x00000000,0x00000000}},	//   _आमा_, --, --, --, 
   {{0x6f18b7a6,0x79a4728c,0xb4f8011a,0x5ac80116}},	//   bhuc, әрме, אפיי, ңлүм_, 
   {{0x7d180200,0x00000000,0x00000000,0x00000000}},	//   shts, --, --, --, 
   {{0xba380af9,0x69100254,0x2d4801bf,0x00000000}},	//   kaïe, _käeh, røer_, --, 
   {{0xf7713926,0x9b95990b,0x5fdd22aa,0x645c0010}},	//   كار_, _дикц, _मनाल, _ozri, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xec340375,0x00000000,0x00000000,0x00000000}},	//   _לאור_, --, --, --, 
   {{0x645c8d5e,0x8e7c01e4,0x00000000,0x00000000}},	// [2b730] _azri, ndŝa, --, --, 
   {{0xe6c01b24,0xba39990c,0xdb08007b,0x962800ef}},	//   čišć, gaïe, irdí, _raņķ, 
   {{0x5274084c,0x00000000,0x00000000,0x00000000}},	//   оулу, --, --, --, 
   {{0xd1b9990d,0x00000000,0x00000000,0x00000000}},	//   لاتا_, --, --, --, 
   {{0x28c009d9,0xf4841220,0x00000000,0x00000000}},	//   श्कि, _губн, --, --, 
   {{0x6440068f,0xa99c0a1e,0xd0082ded,0xc5f000d9}},	//   _śmie, נבור, иеле_, _קדם_, 
   {{0x6f19990e,0x9fa0020c,0xfe6c0133,0x2938010f}},	//   thuc, nèèh_, ۆگه_, זאגן_, 
   {{0x0d85990f,0x4f08030d,0xecd00154,0x00000000}},	//   олин, рнин_, ়াছড, --, 
   {{0xfe6c908c,0x645c16b8,0x2efc01f5,0xa1940a5b}},	//   نگه_, _zzri, rjuf_, _натч, 
   {{0xd1300014,0x929c033f,0x69100254,0x6f199910}},	//   _غما_, _koło, _väek, shuc, 
   {{0x6f18d059,0xd01001d9,0x320c09a5,0x28c40034}},	//   phuc, _تلا_, lygy_, _लॉगि, 
   {{0xba399911,0x291c0022,0x00000000,0x00000000}},	//   daïb, _ŷva_, --, --, 
   {{0x4a441cd0,0xbf600133,0x00000000,0x00000000}},	//   інгв, _تگوو, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x86999912,0x37e0130f,0x320c010e,0x00000000}},	//   итат_, морг, hygy_, --, 
   {{0x3cb0010b,0xfb840330,0xba380129,0xa3e80bae}},	//   _ейәр, _بدوی, waïe, बिस_, 
   {{0x45299913,0x320c0432,0x00000000,0x00000000}},	// [2b740] ажан_, jygy_, --, --, 
   {{0x69c4031c,0xfafc002e,0x320c00ee,0x00000000}},	//   _iqie, nmën_, dygy_, --, 
   {{0x7b2800bc,0xf7700451,0x00000000,0x00000000}},	//   dřuj, _ڊاٽ_, --, --, 
   {{0xfafc02d3,0x741000c6,0xba380ea0,0x218400d1}},	//   hmën_, بوما, saïe, зғав, 
   {{0x2240eedf,0x69c4025c,0xba381e54,0x320c00a2}},	//   çik_, _jqie, maïc, gygy_, 
   {{0xb5f99914,0xbfa8683a,0x69c40135,0x3e6801e1}},	//   _dzád, атие_, _mqie, _ẹto_, 
   {{0x28340020,0x645c022e,0x03a400f3,0x929c0210}},	//   _አስኪያ, _uzri, _фибо, _goło, 
   {{0x3da402bf,0xddc400d1,0x320c010e,0x00000000}},	//   ороб, _ﻫﻪﺭﺑ, bygy_, --, 
   {{0xaf04e9d0,0x9df8023b,0x69c4031c,0xb1400116}},	//   تقيم_, ёнот_, _nqie, янәл, 
   {{0x61e0036b,0x409486de,0xfafc0200,0x8d040055}},	//   _isml, _фрат, gmën_, _śṛṅk, 
   {{0x7478008f,0x60d8047e,0xd36c00db,0x46b80118}},	//   יניג, mevm, _شۇۇ_, इलाह, 
   {{0x60d807ab,0x3f8c07a9,0x7bd80036,0xe0840244}},	//   levm, mpfu_, rwtu, _بێژو_, 
   {{0x68340201,0x3f8c039a,0xfce59915,0x45440092}},	//   _አስረድ, lpfu_, _модо, ያገኙበ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc05002d3,0x3704d6c0,0x70280023,0xf7280105}},	//   _ምዕባለ, очав, _እንተኸ, ацай_, 
   {{0xab281b88,0xba38557b,0xe83802dd,0x60d80477}},	//   _моја_, raïb, іпті_, hevm, 
   {{0x06c802f5,0x0bf400f7,0x00000000,0x00000000}},	// [2b750] _লোহি, _ويۇڭ, --, --, 
   {{0x929c068f,0xf99c02e2,0xca28010f,0x89d801f7}},	//   _poło, fyèv_, _לופֿ, _اوٿر_, 
   {{0xb4a8068f,0x3d00043e,0x00000000,0x00000000}},	//   _गयी_, _वचने_, --, --, 
   {{0xba380ba1,0xfafc036e,0x00000000,0x00000000}},	//   caïc, zmën_, --, --, 
   {{0xe2c8021a,0x47d0009e,0xfafc0023,0x929c033f}},	//   تونو_, হিণী, ymën_, _woło, 
   {{0x3dc0045e,0x00000000,0x00000000,0x00000000}},	//   ্টাল, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6234030c,0xc330010f,0x0c7801c6,0xca380220}},	//   _жету, _נומ_, йсны_, _ﺒﻬﺎ_, 
   {{0x0c240364,0x69100139,0xf0b866a5,0x00000000}},	//   змон, _täei, _خارش_, --, 
   {{0xfafc02d3,0x6910000d,0x1ae40154,0x00000000}},	//   rmën_, _käev, গানে_, --, 
   {{0x2fc4089c,0xfafc0240,0xca68022e,0x28c406e3}},	//   mtng_, smën_, оnаl, _लॉजि, 
   {{0x9f0419c5,0x69100254,0xcb0801d5,0xfcd800e5}},	//   _تونو, _mäev, ليگن_, _گانڈ_, 
   {{0xdb0805ac,0xfafc0de2,0x00000000,0x00000000}},	//   vudå, lmël_, --, --, 
   {{0xadb405d9,0xba38067c,0xf754001f,0xc1700375}},	//   _اهڙا_, taïc, _ለእያን, תחם_, 
   {{0x691000c5,0x2fc4003e,0x798c0175,0x69c40135}},	//   _näev, itng_, bpcw, _tqie, 
   {{0x7ab80375,0xba398340,0x00000000,0x00000000}},	// [2b760] _הצפו, raïc, --, --, 
   {{0x2a60022e,0xba380ba1,0xa3e8121d,0xd5d40661}},	//   _izib_, saïc, बिल_, ьюсы, 
   {{0x2fc40010,0xdb08007c,0x00000000,0x00000000}},	//   jtng_, rtdö, --, --, 
   {{0x82684110,0x41e41cd0,0x00000000,0x00000000}},	//   баев_, зіка, --, --, 
   {{0x3f8c0204,0xa3dc1684,0xd36c0116,0x00000000}},	//   wpfu_, _तैर_, شۇك_, --, 
   {{0x28c07720,0x03a422f7,0xf53c0267,0x79b800b8}},	//   श्चि, _ниго, _tvåa_, _ṭīkā, 
   {{0xbbd80316,0xf99c007f,0xa2c40139,0x60d86b92}},	//   _बनेक, lyèt_, _жәлк, revm, 
   {{0x671cd3a8,0x2a6001a9,0x60d8014f,0xd01001d3}},	//   नसिक_, _ozib_, sevm, ئلٹ_, 
   {{0x88c4002b,0xf99c033b,0x62840de2,0x00000000}},	//   _keśā, nyèt_, ñiou, --, 
   {{0x21a401e0,0x6910000d,0x00000000,0x00000000}},	//   _ниғм, _käeu, --, --, 
   {{0x69c01e7b,0xbff0010b,0x00000000,0x00000000}},	//   àmen, _чүйш, --, --, 
   {{0x60c4b745,0x7c40005f,0x290c0267,0x88c40055}},	//   đimu, _ātrā, ödan_, _leśā, 
   {{0xcf24027d,0xaa6400d8,0x00000000,0x00000000}},	//   _ترلي, етрк, --, --, 
   {{0xb4a8068f,0xfafc002e,0x00000000,0x00000000}},	//   _गये_, mmëm_, --, --, 
   {{0x2a6001a9,0x3154008f,0xa3dc0210,0x00000000}},	//   _ezib_, פילן_, _तैल_, --, 
   {{0x7d099916,0xf84401c6,0x00000000,0x00000000}},	//   _hofs, жүүд_, --, --, 
   {{0x7d08036e,0x00000000,0x00000000,0x00000000}},	// [2b770] _kofs, --, --, --, 
   {{0x88c40055,0x74699917,0x6440033f,0x00000000}},	//   _ceśā, брев_, _śmia, --, 
   {{0x6910033d,0x1e181524,0x88c400dc,0x65940131}},	//   _päev, धनुष_, _deśā, _җасу, 
   {{0xe3b12d62,0x7d099918,0x00000000,0x00000000}},	//   ارل_, _lofs, --, --, 
   {{0x7d099919,0x69100254,0x42780150,0x00000000}},	//   _oofs, _väev, _ﺠﺯﺌﻲ_, --, 
   {{0xe4e400d6,0x7d08003d,0x929c0210,0x50b800f2}},	//   _пісн, _nofs, _kołk, تگرد_, 
   {{0x205406bb,0xa3d5991a,0x00000000,0x00000000}},	//   нтър, _порч, --, --, 
   {{0x69100036,0xf99c00db,0x6adc3d1d,0xa2c400d8}},	//   _häet, nyès_, _बसेर, _пљук, 
   {{0x7d093759,0x69100037,0xdb0800d0,0xbd8401b9}},	//   _bofs, _käet, budú, وچون_, 
   {{0xb4a80316,0x691000af,0x4c3401c0,0x00000000}},	//   _गयो_, _jäet, дэмт, --, 
   {{0xcb68337e,0x69103496,0x00000000,0x00000000}},	//   жане_, _mäet, --, --, 
   {{0xdce8031c,0x59740022,0x00000000,0x00000000}},	//   ħoġo, ҵысу, --, --, 
   {{0xb5a8002e,0x98b00064,0x00000000,0x00000000}},	//   _d斡kk, nozė_, --, --, 
   {{0x69103110,0xf99c07c2,0x8d0400dc,0x00000000}},	//   _näet, vyèt_, _śṛṅg, --, 
   {{0x6f080b6f,0xc02c1772,0xa3dc13f5,0x00000000}},	//   _kogc, _እንተወ, _तैं_, --, 
   {{0x98b00064,0x929c0210,0x6f0800e5,0x00000000}},	//   kozė_, _dołk, _jogc, --, 
   {{0x35a0036b,0x69100166,0x6f08008e,0x2a6001d5}},	// [2b780] катг, _bäet, _mogc, _uzib_, 
   {{0x6f09991b,0x845800f0,0xa6d000fe,0x00000000}},	//   _logc, орет_, ৱাইট, --, 
   {{0x6f0801a4,0x88c40055,0x00000000,0x00000000}},	//   _oogc, _veśā, --, --, 
   {{0x6f080921,0xdb081600,0xa3dc00dc,0xf99c0100}},	//   _nogc, ardæ, _तैः_, myèr_, 
   {{0xb5f80122,0x602400e4,0x26c18246,0xf99c0100}},	//   _vzác, _oïmé, mgio_, lyèr_, 
   {{0x26c1991c,0x2919991d,0x20180205,0xe2c80137}},	//   lgio_, nkra_, _ürik_, توچو_, 
   {{0xf3e0036b,0x6f080009,0x7d09991e,0xadc001e1}},	//   _ижро, _bogc, _rofs, _ipẹj, 
   {{0x6910007d,0x03a41b74,0x3e60022e,0x29180254}},	//   _käes, _ниҳо, lаti_, hkra_, 
   {{0x2919991f,0x6f08037e,0x7c84001f,0x26c06330}},	//   kkra_, _dogc, _ነበረው_, igio_, 
   {{0x7d0802d3,0x6910165b,0x9b940063,0x3e6001a9}},	//   _qofs, _mäes, ниоц, nаti_, 
   {{0x34b40302,0x6ef401f2,0x3ea401ec,0x00000000}},	//   ופים_, ụbam, _жиег, --, 
   {{0x61e4031c,0x00000000,0x00000000,0x00000000}},	//   ħilf, --, --, --, 
   {{0x2b440323,0x3e60022e,0x7d084087,0x00000000}},	//   тээг, kаti_, _tofs, --, 
   {{0x7e617880,0x6f080472,0x2dc40131,0x26c00064}},	//   _izop, _zogc, _ﻫﻪﻣﻤ, egio_, 
   {{0xba399920,0x6f0801e2,0x6d4c00bc,0xdb0801bf}},	//   caïn, _yogc, ékař, kudø, 
   {{0x26c0156b,0xadc00241,0x69c8084c,0xc4cc0eac}},	//   ggio_, _apẹj, ăder, রযোজ, 
   {{0xc61003f4,0x64580003,0x00000000,0x00000000}},	// [2b790] _সেবা_, żvil, --, --, 
   {{0x2918049f,0x55559921,0xa4d800f7,0x00000000}},	//   ckra_, رپار, мдуу_, --, 
   {{0x317c01f5,0x691000c5,0xe508e25c,0xf99c007f}},	//   _suuz_, _väet, بيلو_, pyès_, 
   {{0x7e617e9f,0x00000000,0x00000000,0x00000000}},	//   _ozop, --, --, --, 
   {{0xf1a49b70,0x3e60022e,0x00000000,0x00000000}},	//   френ, bаti_, --, --, 
   {{0x69100a40,0x7f400eda,0x50a40014,0x98b00153}},	//   _häer, _ajoq, رٕبل, rozė_, 
   {{0x7e604e2b,0x69100221,0xbfc80131,0x64740329}},	//   _azop, _käer, كايە_, _агру, 
   {{0x691001c7,0x876802dd,0x8e0800d8,0x00000000}},	//   _jäer, _ﺳﺎﻟﺖ_, знив_, --, 
   {{0x69100a40,0x51b40451,0x7e600210,0x291803b2}},	//   _mäer, _سماء, _czop, ykra_, 
   {{0x7e600099,0xb6980100,0xe0d00b28,0x271c13f7}},	//   _dzop, _goâv, _نزم_, _नत्र_, 
   {{0x7e619922,0xc4d000c8,0xd010007b,0x26c19923}},	//   _ezop, נגט_, _حلا_, ygio_, 
   {{0x691004e6,0x44180375,0xba385b80,0x7c8c001f}},	//   _näer, פורס, raïn, መስለው_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd1d0044e,0xfce0869e,0x8c4417a2,0x8d642ae3}},	//   _ኩነት_, _бошо, _пеле, _явле, 
   {{0x46f470c9,0x6911487b,0xc050008f,0x29183b7b}},	//   нчат, _bäer, ָזן_, rkra_, 
   {{0x29199924,0x9b3400c7,0xf99c007f,0x64580254}},	//   skra_, _ахьш, ryèr_, üvim, 
   {{0x26c19925,0x69100a40,0xdb0805ac,0xf53c0267}},	// [2b7a0] rgio_, _däer, vudø, _tvål_, 
   {{0x58f83ae9,0xb958026c,0x6910023a,0x26c19926}},	//   _ཕོགས_, guìd, _väes, sgio_, 
   {{0x389804ac,0x69100a40,0x395c0198,0x6b88054e}},	//   _מיינ, _fäer, ɓus_, _îngă, 
   {{0x69119927,0x826812b9,0x9608004b,0xa4f800f1}},	//   _gäer, паев_, _ښکلې_, _ښکار_, 
   {{0x6d40007c,0xa3bc0037,0x00000000,0x00000000}},	//   _ojna, _आमक_, --, --, 
   {{0x67259928,0x69100036,0xd4f41075,0xdb08005c}},	//   lhij, _zäer, _иясы, sudø, 
   {{0x1ccc1b35,0x4ac40574,0x2d8c068c,0x7e60179a}},	//   ྲུལ_, _वाढव, _atge_, _szop, 
   {{0x6d419929,0x672400f3,0x6910008e,0x00000000}},	//   _ajna, nhij, _xäer, --, 
   {{0xa3e80abd,0x61e55296,0xa3dc033f,0xcce400ec}},	//   बिक_, çild, तौर_, چسپي, 
   {{0x6724031c,0x1aa800cd,0x7e6000d7,0x00000000}},	//   hhij, कण्ठ, _vzop, --, 
   {{0x9f4c0306,0x00000000,0x00000000,0x00000000}},	//   _hrdí_, --, --, --, 
   {{0x58f82fb5,0x6d402aad,0x67240369,0x7e281cd0}},	//   _ཕོངས_, _ejna, jhij, _ніла_, 
   {{0x7e611971,0x00000000,0x00000000,0x00000000}},	//   _uzop, --, --, --, 
   {{0x69100139,0x00000000,0x00000000,0x00000000}},	//   _säer, --, --, --, 
   {{0x69100221,0xb765992a,0x64580327,0x00000000}},	//   _päer, етай, żvij, --, 
   {{0x6724047e,0x98b0007f,0xc7940014,0x6b4803e0}},	//   ghij, mizč_, کھیا_, tıge, 
   {{0xf650a554,0x46e00037,0x00000000,0x00000000}},	// [2b7b0] ائز_, _पसरह, --, --, 
   {{0x6910092e,0x7d19992b,0x6b480205,0x00000000}},	//   _wäer, nkts, rıge, --, 
   {{0x67240882,0x78a5992c,0x00000000,0x00000000}},	//   bhij, majv, --, --, 
   {{0x6725992d,0xd69c01e4,0xc5ec00f1,0x00000000}},	//   chij, _eksϲ, _ژړل_, --, 
   {{0x666406bb,0x5f04aa34,0x3f9c2b34,0x691000c5}},	//   _бърз, वान्_, _awtu_, _käep, 
   {{0x1ccc0003,0x78a404a7,0x758001ee,0x00000000}},	//   ྲུས_, najv, _аңҡа, --, 
   {{0xa4d402bf,0x69100254,0x9f2400d1,0x00000000}},	//   _щорі, _mäep, گۈنۈ, --, 
   {{0x63b801f1,0x78a4047e,0x4ac401ad,0x7d180139}},	//   ávne, hajv, _वाधव, ekts, 
   {{0xafe007d6,0x62844beb,0xe2c916e4,0xba380109}},	//   тоқл, žioc, _سولو_, faïm, 
   {{0x61e445e3,0x8d740691,0x20240162,0x00000000}},	//   çile, خابا, írið_, --, 
   {{0x8c45992e,0x8d740ec9,0x78a4047e,0x4ed40ada}},	//   тене, _یاتا, dajv, _لقاء, 
   {{0xdb08004e,0xa3a8033f,0x3e300bce,0x7d180037}},	//   nsdè, _खौफ_, افیر, akts, 
   {{0xb5f801ed,0xd9b00d1f,0x3de40022,0xdd9402d5}},	//   _szán, مەيد, _ақыҭ_, _бачы, 
   {{0x9e65992f,0xaca002e3,0x6f199930,0x7d182305}},	//   _свід, _kpọk, lkuc, ckts, 
   {{0x4b88036b,0x67259931,0xdb0801a8,0x3e68007f}},	//   _ўйин_, thij, ludý, pòté_, 
   {{0x6f180986,0x660405f5,0x6b801730,0x68480092}},	//   nkuc, txik, _iung, _ከኤርት, 
   {{0x6b809769,0x6f180064,0x00000000,0x00000000}},	// [2b7c0] _hung, ikuc, --, --, 
   {{0x67240537,0x6aa59932,0x69100139,0x6f1801c7}},	//   shij, _heif, _gäep, hkuc, 
   {{0x6b819933,0xd00416cb,0x67240227,0x1ae4015b}},	//   _jung, _اڄ_, phij, গারে_, 
   {{0x6b819934,0xf7702732,0x9c7d9935,0xa5e80150}},	//   _mung, _پاپ_, meče, _كوجە_, 
   {{0x9c7c0e96,0xaca0063f,0x6aa59936,0x7d180267}},	//   leče, _apọk, _meif, ykts, 
   {{0x6aa59937,0xe3a40f1c,0xd574109a,0x6b80127b}},	//   _leif, _مشری, _бусь, _oung, 
   {{0x657c00f1,0x9c7ce045,0x6f199938,0x03a4dddf}},	//   _iirh, neče, fkuc, _шиво, 
   {{0x657c02c4,0x3ea00436,0x6aa4bb16,0x793c001f}},	//   _hirh, úkt_, _neif, _ባለቤት, 
   {{0x9f4c0004,0xb5f80085,0x6b819939,0x5d54721f}},	//   _ardã_, _nzál, _aung, лкит, 
   {{0x6b81993a,0x645d993b,0x6f180113,0x626400d1}},	//   _bung, _kyri, akuc, _авға, 
   {{0x6b800207,0x9c7c1f7f,0x657c07a9,0x6aa5993c}},	//   _cung, ječe, _mirh, _beif, 
   {{0x6b81993d,0x657c009a,0x6f180732,0x6aa5993e}},	//   _dung, _lirh, ckuc, _ceif, 
   {{0xdd904bf3,0x6aa5993f,0x645d9940,0x6b819941}},	//   _اوت_, _deif, _lyri, _eung, 
   {{0x645c0162,0x657d6705,0x00000000,0x00000000}},	//   _oyri, _nirh, --, --, 
   {{0xf7701a59,0x6b800d8a,0x6aa40418,0x645d9942}},	//   لار_, _gung, _feif, _nyri, 
   {{0x6aa59943,0x657d9944,0x7c340b45,0x628030b5}},	//   _geif, _airh, _ƙarƙ, _ngmo, 
   {{0x645d9945,0xf968a6e6,0x657d9946,0x00000000}},	// [2b7d0] _ayri, _орой_, _birh, --, 
   {{0x6b800226,0xb864132f,0xe5c4147e,0x645c015d}},	//   _yung, _لاجو, јсто, _byri, 
   {{0x0fbc045e,0x6b819947,0x5ea8015b,0x6f180986}},	//   _আন্ধ, _xung, _গানে, ykuc, 
   {{0x60c802d0,0x645c072b,0x9c7cbbfa,0xa3e807af}},	//   _acdm, _dyri, ceče, बिज_, 
   {{0x645d9948,0x31300588,0x4ac400cd,0x850000d1}},	//   _eyri, аҵар, _वासव, _گۈلن, 
   {{0x645d9949,0x1bf409d9,0xf48428f1,0x8fa4004e}},	//   _fyri, ेमाल_, _шумн, гаке, 
   {{0xb6000306,0x645d994a,0xe534005b,0xe0d002c9}},	//   skáč, _gyri, _терь, تزن_, 
   {{0x6b81994b,0x929c0034,0x657c3c0a,0xe2f80220}},	//   _rung, _połu, _zirh, _иесі_, 
   {{0x6aa5994c,0x6b802c7f,0x657c009a,0xc33005d0}},	//   _reif, _sung, _yirh, _הון_, 
   {{0x6b801060,0xb5f8043b,0x657c06e4,0x6f180036}},	//   _pung, _nzám, _xirh, skuc, 
   {{0xb5f8066d,0x6b81994d,0x6aa401c7,0x3b807a6f}},	//   _szál, _qung, _peif, йлэг, 
   {{0x6b81994e,0x6f180784,0x00000000,0x00000000}},	//   _vung, qkuc, --, --, 
   {{0x6b81994f,0x9c7d9950,0x6aa44699,0x6b480139}},	//   _wung, veče, _veif, gıga, 
   {{0x6b80281c,0xb300025c,0x7afc00d8,0x6aa4ab89}},	//   _tung, _ཚོའང_, _enqt, _weif, 
   {{0x6b819951,0x657c06e4,0x9c7c1a48,0x6aa502e7}},	//   _uung, _rirh, teče, _teif, 
   {{0x657c07a9,0xeccc0db3,0x645c00ca,0xc6e002f5}},	//   _sirh, त्रफ, _ryri, মঞ্চ, 
   {{0x645d9952,0x5f040a28,0xe62800e4,0x657c8a8a}},	// [2b7e0] _syri, वात्_, _thô͘_, _pirh, 
   {{0x9c7c39ae,0x645d9953,0x39980a1e,0x291c00e4}},	//   seče, _pyri, _רייד, _ôva_, 
   {{0xaaa801d9,0x9c7d9954,0x657c049b,0x738801ec}},	//   _कजाक, peče, _virh, ерің_, 
   {{0x645c2aa9,0x60c8003e,0x657c0165,0xdb080036}},	//   _vyri, _scdm, _wirh, tsdé, 
   {{0x657c13a1,0xc61000bd,0x645c015d,0x00000000}},	//   _tirh, _সেরা_, _wyri, --, 
   {{0x645c0953,0x58f8031c,0xa2d406e3,0x929c012d}},	//   _tyri, _ཕོབས_, _यॉर्, _sołt, 
   {{0x443c0086,0x1458672f,0x3ba40092,0x00000000}},	//   _ãt_, _ашты_, _ለሰዎች_, --, 
   {{0x60c83040,0xb220053f,0xfeb8fc15,0x00000000}},	//   _wcdm, рмәл, راعت_, --, 
   {{0xd3340953,0x7aec9e91,0xfafc0036,0xb634010f}},	//   _тэры, vdct, llëg_, ָריס_, 
   {{0x2dd400c6,0x9c7caaf3,0x90e400db,0xc15401af}},	//   ابية_, ječc, _ۅسۅن, _сњбњ, 
   {{0xeb9406ed,0x5f0400dc,0x7f1800d4,0x2fd512cd}},	//   лиќ_, वाद्_, _піду_, _مولد_, 
   {{0xb5f800f8,0xa9280150,0x3e5c0248,0x00000000}},	//   _szám, ңіре_, _ọtun_, --, 
   {{0xa2cc35e0,0x212000b0,0xbc7000cf,0x1dc41de6}},	//   _हान्, ūihu_, _گۇدب, _төйн, 
   {{0x7d08000f,0x3ea4003e,0xdcf8007f,0x81b400cc}},	//   _dêrû, _heot_, _kivč, _জহা_, 
   {{0xd0342295,0x103402d3,0x00000000,0x00000000}},	//   _እንደሆ, _እንተመ, --, --, 
   {{0xe7840b01,0x66c801c6,0x56959955,0xb60402e8}},	//   суро, лууг_, раат, лязк, 
   {{0x3ea40165,0x59a801ad,0xf6280212,0x00000000}},	// [2b7f0] _meot_, _कबिर, хіви_, --, 
   {{0x3ea4003a,0x344807d5,0x58d43a49,0xdb241d0e}},	//   _leot_, нчен_, _тоот, ðsæt, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x62840024,0x60dc0790,0x63b800d0,0x290c000d}},	//   žion, _ırma, ávna, ödav_, 
   {{0x23b41c5c,0xb8640451,0x79580023,0xf77000d1}},	//   لمەس, _جاکو, _ሃብተስ, _پاھ_, 
   {{0xf77d82f3,0x00000000,0x00000000,0x00000000}},	//   _hiç_, --, --, --, 
   {{0xf77c008e,0xb62c0150,0x4ac4190c,0x00000000}},	//   _kiç_, _ﺒﻠ_, _वालव, --, 
   {{0xdcf99956,0xdea401d5,0x00000000,0x00000000}},	//   _divč, میمی, --, --, 
   {{0xd0340201,0x3ea59957,0xb5f801ed,0x72000131}},	//   _እንዲሆ, _deot_, _száj, _دۈشم, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa2cc038e,0x0b440818,0x8b6800d8,0x00000000}},	//   _हाम्, инон, киов_, --, 
   {{0xb5f802fd,0x3ea405c7,0x4ac40490,0x8e759958}},	//   _vzáj, _geot_, _वाळव, _кулч, 
   {{0xfe98025f,0x00000000,0x00000000,0x00000000}},	//   _סיסמ, --, --, --, 
   {{0x827404ac,0xf750044e,0x203c0023,0xc954013d}},	//   יערע_, _መብዛሕ, _ክሕብረ, ртмы, 
   {{0x7d08045f,0x07a42bb6,0xdb080158,0xc7a40212}},	//   _wêrû, рабн, yrdø, рибк, 
   {{0x2ca40489,0x7b2803f9,0x00000000,0x00000000}},	//   _hend_, nƙul, --, --, 
  
   {{0x2ca59959,0xb5f801e1,0x09e56feb,0xfafc0023}},	// [2b800] _kend_, _ayáb, _топн, rmët_, 
   {{0x1ccc76ff,0x2ca5995a,0x9c7c4b16,0x07a40114}},	//   ྲུག_, _jend_, leča, _каон, 
   {{0x2ca5995b,0x33f400b5,0xc3d81a9b,0x00000000}},	//   _mend_, でxl_, ضباط_, --, 
   {{0x48ec0316,0x9c7c0219,0xf77c010b,0xa65403e6}},	//   इएको_, neča, _giç_, _هێزت, 
   {{0x3ea405c7,0xe5d801e1,0x5f041b6e,0xceb8013a}},	//   _reot_, _òtàá, वास्_, chři_, 
   {{0xc05800d6,0x2ca52bbe,0xb140036b,0x45340131}},	//   кій_, _nend_, ончл, _ئىسر, 
   {{0xf8b00302,0x443d995c,0x98b00311,0x3ea40c6a}},	//   קשה_, _ät_, liză_, _peot_, 
   {{0x9c7c0dd1,0x2a60e7f1,0xd36c1d00,0xf77c0139}},	//   ječa, _oyib_, _كۇل_, _xiç_, 
   {{0x2ca43371,0x2a600218,0x6e5402d3,0x2eec06ea}},	//   _bend_, _nyib_, _ምትግባ, _dagf_, 
   {{0x2eec0327,0x2ca40175,0x7fd402bf,0xfafc0240}},	//   _eagf_, _cend_, _віді, ymës_, 
   {{0x2a61995d,0x2ca5995e,0x7b64c897,0x3ea4005b}},	//   _ayib_, _dend_, итме, _teot_, 
   {{0x1ccc1b4b,0x2ca427bb,0xfafc036e,0x9f5c035b}},	//   ྲུང_, _eend_, emër_, tyvõ_, 
   {{0x2ca5991e,0x201c0064,0x00000000,0x00000000}},	//   _fend_, lyvi_, --, --, 
   {{0xf77c044e,0x6ca000a7,0x2ca40166,0xfafc036e}},	//   _siç_, _дръж, _gend_, tmës_, 
   {{0xf77c05d1,0xfafc0240,0x2a6006be,0x98740419}},	//   _piç_, umës_, _eyib_, _týči_, 
   {{0x6c7805e1,0xfafc02d3,0x79a417a0,0xb5f802f0}},	//   _באופ, rmës_, _крое, _uzák, 
   {{0xfafc54f1,0x2ca4009a,0xe3b0004b,0x69c000cf}},	// [2b810] glëe_, _yend_, ېره_, àmet, 
   {{0xe98401d9,0xf77c0661,0x00000000,0x00000000}},	//   _گٔیَ, _wiç_, --, --, 
   {{0x78b403ac,0xf99c007f,0x00000000,0x00000000}},	//   _idxv, jyèz_, --, --, 
   {{0x1fcc00bd,0x61980023,0x61e40327,0x2334003b}},	//   লবাস, _ልኡላዊ_, ħiln, охір, 
   {{0x8e7c01e4,0xb604010a,0x00000000,0x00000000}},	//   keŝa, _тянк, --, --, 
   {{0x824c02d3,0x36dc063f,0x82c40022,0x00000000}},	//   _ንዓመታ, _ịpụọ_, ашәҵ, --, 
   {{0x2ca5995f,0x201c0064,0x64580037,0x00000000}},	//   _rend_, gyvi_, üvit, --, 
   {{0x2ca4b904,0x25b00724,0x4ac407f7,0xe8c408df}},	//   _send_, _ällä_, _वाइव, _वञ्च, 
   {{0x9c7c0fb7,0x2ca4010a,0xd004036b,0xa2cc012c}},	//   veča, _pend_, роққ, _हात्, 
   {{0xd130621e,0x2ca40200,0x26080401,0x00000000}},	//   _عما_, _qend_, समती_, --, 
   {{0x2ca59960,0x9c7c8356,0x357802d3,0x5f9400d8}},	//   _vend_, teča, ባለታት_, _дихт, 
   {{0x62000598,0x2ca59961,0xf53c00cc,0x35941954}},	//   _üzlä, _wend_, _kvås_, ማእታት_, 
   {{0x9c7c0989,0x78b40175,0x2ca59962,0x0a384bec}},	//   reča, _bdxv, _tend_, учны_, 
   {{0x9c7d9963,0x2ca4003a,0x9f4c0139,0x6934bb12}},	//   seča, _uend_, _erdä_, تکبر, 
   {{0x9c7c038e,0x764c009a,0xc7641e4a,0xfafc002e}},	//   lečn, _axcy, مارى, rmër_, 
   {{0x69c001ab,0xfbb4011a,0x06848b1b,0x752400e5}},	//   àmes, _הפקת_, сган, _aljz, 
   {{0x9c7c03c6,0x290c00c5,0xdcf80055,0x05740553}},	// [2b820] nečn, ödas_, _hivā, مائد, 
   {{0x63b801f1,0x98b00311,0x00000000,0x00000000}},	//   ávno, riză_, --, --, 
   {{0x47d003d4,0x8eac00eb,0x00000000,0x00000000}},	//   হিঙী, _গানগ, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9c7cf2df,0x02382f5e,0x00000000,0x00000000}},	//   ječn, دثات_, --, --, 
   {{0x9c7c0122,0x9f999964,0x201c0153,0x64580205}},	//   dečn, авку_, tyvi_, üvis, 
   {{0xdfd00597,0xdd9001d3,0xdcf800dc,0x22e40133}},	//   ذية_, ڈوب_, _nivā, _وترێ, 
   {{0xdb080793,0x94a801d3,0x1ce00327,0xf99c007f}},	//   ludö, _ماہِ_, _ཥིང_, ryèz_, 
   {{0x42240902,0x3c0c06be,0x00000000,0x00000000}},	//   _удав, məvi_, --, --, 
   {{0x1d340a4a,0xaee800cc,0x212402f2,0x3c0c03e3}},	//   іння, কাষণ_, _ببرێ, ləvi_, 
   {{0x69100166,0x39440205,0x00000000,0x00000000}},	//   _fäez, _ıns_, --, --, 
   {{0x9b5805f5,0x3c0c00ac,0xdcf80318,0xf4100375}},	//   римт_, nəvi_, _divā, לפת_, 
   {{0xdef800fb,0x00000000,0x00000000,0x00000000}},	//   _быҙ_, --, --, --, 
   {{0x7e6181fd,0x906400f7,0xe8944990,0xab640210}},	//   _iyop, _اچۇۇ, зарь, ążaj, 
   {{0x7e600165,0x80d800dc,0xdb0802d2,0x00000000}},	//   _hyop, प्ये, dudö, --, 
   {{0x62840024,0x290caa9a,0x00000000,0x00000000}},	//   žioj, ödar_, --, --, 
   {{0x95399965,0x3c0c06be,0x00000000,0x00000000}},	// [2b830] азат_, dəvi_, --, --, 
   {{0x1cb0025c,0xa4d40024,0x00000000,0x00000000}},	//   _ྐབས_, зофі, --, --, 
   {{0x7e601a9f,0xe3b00ada,0x3c0c03b9,0xbbb401f9}},	//   _lyop, فرن_, fəvi_, _आटोक, 
   {{0x7e6001f0,0x1cb8031c,0x81e003d4,0x398c0205}},	//   _oyop, _མཇའ_, ধিন_, _küs_, 
   {{0x398c014a,0x00000000,0x00000000,0x00000000}},	//   _jüs_, --, --, --, 
   {{0x659405f5,0x9c7d9966,0x61e0030a,0xe0d800d4}},	//   _хару, večn, _dpml, йві_, 
   {{0x7e60014b,0x00000000,0x00000000,0x00000000}},	//   _ayop, --, --, --, 
   {{0x9c7c038e,0x3c0c03b9,0x00000000,0x00000000}},	//   tečn, cəvi_, --, --, 
   {{0xdba002dd,0x398c03b9,0x3ff00116,0x00000000}},	//   _ﺃﺨﺭﻯ_, _nüs_, ككۈر, --, 
   {{0x9c7c389e,0x3cec0490,0x2adc012c,0x00000000}},	//   rečn, _असणे_, ग्नु_, --, 
   {{0x9c7c5946,0x7e600921,0x00000000,0x00000000}},	//   sečn, _eyop, --, --, 
   {{0x2fc59967,0x7e600161,0x398d9968,0x9c7c0306}},	//   mung_, _fyop, _büs_, pečn, 
   {{0x2fc59969,0xba39996a,0xa2cc06e3,0xb384044e}},	//   lung_, daïs, _हास्, _ንነዊሕ_, 
   {{0x3afc00b0,0x2fc4020c,0x8e7c0115,0xfce0004e}},	//   _päpä_, oung_, leŝo, _жошо, 
   {{0x3cec05ba,0x4ab800a7,0x398c0254,0xe7c80154}},	//   _असते_, _купя_, _eüs_, শব্য, 
   {{0x2fc40bac,0xb6980042,0x46e82377,0x00000000}},	//   iung_, _wnân, јдан_, --, 
   {{0xf09c01dc,0x391000ec,0x00000000,0x00000000}},	// [2b840] _đàn_, _ڊويز, --, --, 
   {{0x2fc45447,0x61e451b7,0x8504c811,0xf504084c}},	//   kung_, çilm, غوان, онул_, 
   {{0x1cb80867,0x2fc5996b,0x6b85996c,0x818001ec}},	//   _མཇལ_, jung_, _kiig, _ﺨﺎﻨﺔ_, 
   {{0x2fc45df1,0x490000bc,0xc1e002dd,0xdb2003b2}},	//   dung_, शाको_, _ﺍﻴﺭﺍ, átøk, 
   {{0x2fc4fc65,0xe8e8031c,0x6b840067,0x00000000}},	//   eung_, _སྲོག, _miig, --, 
   {{0x2fc5996d,0x6b85996e,0xe1344caf,0x6725996f}},	//   fung_, _liig, янлы, lkij, 
   {{0x7e600055,0x00000000,0x00000000,0x00000000}},	//   _syop, --, --, --, 
   {{0x67259970,0x7e6002b9,0x6b859971,0x3f800008}},	//   nkij, _pyop, _niig, öku_, 
   {{0xf7700302,0x1ee8034c,0x67240024,0x409400f3}},	//   וקה_, لوژی_, ikij, _дрет, 
   {{0x6724000d,0x232801a9,0x00000000,0x00000000}},	//   hkij, _тоғи_, --, --, 
   {{0x67259972,0x2fc59973,0x7fd4dbe2,0xb5f80122}},	//   kkij, cung_, _фізі, _uzáv, 
   {{0x67259974,0x6b84208d,0x2bd800ce,0x398c05d5}},	//   jkij, _ciig, _बहरा, _püs_, 
   {{0x6b84ca75,0x9f4c0597,0xb5f80248,0x7e600107}},	//   _diig, _ordú_, _ayán, _uyop, 
   {{0xefc80092,0x00000000,0x00000000,0x00000000}},	//   በረዉ_, --, --, --, 
   {{0x6b840752,0x76a844b5,0x2018004e,0x6c50004e}},	//   _fiig, итав_, _àrid_, _окшу, 
   {{0x9f4c00c6,0x672401a4,0x6b859975,0xc6e40327}},	//   _ardú_, gkij, _giig, _སྒཱུ, 
   {{0x2fc42155,0x7bdc014a,0x1a64006c,0x2e340240}},	// [2b850] zung_, _äpub, _ریسی_, _ክትዕዘ, 
   {{0x2fc59976,0xf09c07ae,0xf99c05d5,0x672400b5}},	//   yung_, _đào_, mpè_, akij, 
   {{0xba3806af,0xa2cc01ad,0xc1e002dd,0xe1f00133}},	//   maïq, _हाश्, _ﺍﺴﺭﺍ, ێسه_, 
   {{0xd25073c5,0x672401fa,0x2fc40158,0xd1b801d3}},	//   ىنا_, ckij, vung_, ماتا_, 
   {{0x2fc59977,0xf99c5b42,0x00000000,0x00000000}},	//   wung_, npè_, --, --, 
   {{0x2fc59978,0xa99c0a1e,0x2bd84328,0xa4e40153}},	//   tung_, סבור, _बहला, _оўск, 
   {{0x2fc40730,0xc4d002e4,0xa3d400cf,0xdb08005c}},	//   uung_, _רגל_, _оорч, msdæ, 
   {{0x2fc59979,0xc61000bd,0x00000000,0x00000000}},	//   rung_, _সেটা_, --, --, 
   {{0x2fc4046b,0x6b85997a,0xfe6c01d5,0x248c01e1}},	//   sung_, _riig, هگه_, _àimò_, 
   {{0xefc80201,0x2fc40264,0x6b843ede,0xf99c02e2}},	//   በረው_, pung_, _siig, dpè_, 
   {{0x6b8437e7,0xa0c4038b,0x9c7c0427,0xcb0801f7}},	//   _piig, _زينو, lečj, ميدن_, 
   {{0x09e4f631,0x1bec10b7,0xfbd000db,0x00000000}},	//   помн, _जनरल_, رتپ_, --, 
   {{0x6b85997b,0x19b81064,0x98b07502,0xbf100137}},	//   _viig, жусь_, lizę_, _سووب, 
   {{0x9af80882,0x2d9c06af,0x6b840067,0x6724025c}},	//   rmāṇ, mpue_, _wiig, wkij, 
   {{0x4dbc04c5,0x6725997c,0x6b85997d,0x2d9c0789}},	//   _অহিং, tkij, _tiig, lpue_, 
   {{0xfafc044e,0xfbd00375,0xba38b60c,0xae1c0dba}},	//   llën_, _נתח_, raïr, _बथान_, 
   {{0x6725997e,0x9c7c1e31,0xb99000c6,0x3e480023}},	// [2b860] rkij, ječj, _كليب, _ዝትንክ, 
   {{0xe9840150,0x88c81608,0x6b480139,0x00000000}},	//   _تاعۋ, _улов_, dıgi, --, 
   {{0x2ec400e1,0x00000000,0x00000000,0x00000000}},	//   _रफ़्त, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb281997f,0xdd3800b8,0x2574000d,0x00000000}},	//   нышк, _cāśu, jälg_, --, 
   {{0x25a19980,0x9f4c004e,0x1cb8031c,0xdd3800b8}},	//   mpil_, _urdú_, _མཇེ_, _dāśu, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4ac40490,0x25a0007f,0xb5f801d3,0xd36c0116}},	//   _वाजव, npil_, _nyál, _ئۇن_, 
   {{0x6e2c01ab,0xfafc036e,0x00000000,0x00000000}},	//   ùcba, glën_, --, --, 
   {{0xb098008d,0x9c7c00bc,0x25740267,0x00000000}},	//   _היבר, mečk, mäld_, --, 
   {{0x9c7c012c,0x212c01ab,0x25a001f5,0x00000000}},	//   lečk, _hldh_, kpil_, --, 
   {{0xc88000ac,0x6d4801a8,0xfafc036e,0x00000000}},	//   əşə_, ólaá, blën_, --, 
   {{0x3f840165,0x9c7c17ca,0x9948179e,0x61e40327}},	//   _hiou_, nečk, زلزل_, ħilh, 
   {{0xf99d9981,0x25a001f5,0x4ac40490,0x00000000}},	//   spè_, epil_, _वाचव, --, 
   {{0x1ccc0135,0xf09c001e,0xba3839b2,0xf99c0ffb}},	//   ྲུམ_, _đàm_, saïq, ppè_, 
   {{0x24980208,0xe5c4030d,0x2abc011a,0x00000000}},	// [2b870] _bfrm_, есхо, _המחא, --, 
   {{0x9c7d9982,0x3f840165,0xb5f800e5,0x00000000}},	//   ječk, _liou_, _szás, --, 
   {{0xf98400c6,0x25a0409c,0x9c7c0216,0xdb0801bf}},	//   _iiب_, apil_, dečk, rsdæ, 
   {{0x394000da,0x99980034,0x3f840694,0xa29400d4}},	//   lijs_, mysł_, _niou_, еаці, 
   {{0xd1780006,0xdecc0b82,0x00000000,0x00000000}},	//   оскі_, ኣንን_, --, --, 
   {{0x394000da,0x3f840165,0x9c7c09a8,0xd0080026}},	//   nijs_, _aiou_, rečj, жеке_, 
   {{0x3f8405c7,0x7bcc01ab,0x23081d37,0x00000000}},	//   _biou_, àbul, تتەي_, --, 
   {{0x6fcc0574,0x3940d45e,0xdb08007c,0x00000000}},	//   संबं, hijs_, nsdä, --, 
   {{0x3f859983,0x9c7c013a,0x00000000,0x00000000}},	//   _diou_, bečk, --, --, 
   {{0xfe4002bf,0x0c241188,0x9c7c01ef,0x50f40150}},	//   тньо, дмон, cečk, _ізет, 
   {{0x39419984,0xd01061fa,0x3b180327,0x68ec00ac}},	//   dijs_, _جلا_, _boqq_, _öndə, 
   {{0x2d8809ff,0x63b80232,0x3f8407de,0x2574b691}},	//   íces_, ávni, _giou_, mäle_, 
   {{0x3b180327,0xf09c0208,0x394000ef,0x25740166}},	//   _doqq_, _đàj_, fijs_, läle_, 
   {{0x61e45556,0x2d8c003a,0xbf88004d,0x3f84030a}},	//   çili, _iuge_, _đoản_, _ziou_, 
   {{0x25759985,0x2d84006f,0x2d8c565d,0x3f840076}},	//   näle_, _iine_, _huge_, _yiou_, 
   {{0x2d859986,0x25a0017a,0x9c7c0118,0x00000000}},	//   _hine_, tpil_, zečk, --, 
   {{0x2d8d9987,0x2d84138f,0xb5f800dd,0x7b1c01b8}},	// [2b880] _juge_, _kine_, _szár, _vëut, 
   {{0x03a407d6,0xc8c8cf73,0x2d859988,0x2d8c00ca}},	//   дижо, _بودن_, _jine_, _muge_, 
   {{0x2d8547a0,0x25a09573,0x9c7cb964,0x2d8d9989}},	//   _mine_, spil_, večk, _luge_, 
   {{0x2d8c0428,0x25a000e8,0x929c012d,0xb6000327}},	//   _ouge_, ppil_, _koły, ġġru, 
   {{0x3cec0574,0x2d840337,0x04b416ab,0x3f840156}},	//   _असले_, _oine_, _освя, _riou_, 
   {{0x3f840093,0x2d85998a,0x00000000,0x00000000}},	//   _siou_, _nine_, --, --, 
   {{0x2d8cd108,0x9c7c0232,0x2574025a,0x3f8521f4}},	//   _auge_, rečk, gäle_, _piou_, 
   {{0x2d85998b,0x2d8c02a8,0xefb001d3,0x9c7c14b2}},	//   _aine_, _buge_, ئینگ, sečk, 
   {{0x2d85998c,0x88c4045e,0x9c7c39d5,0x2d8c01a6}},	//   _bine_, শ্যক, meči, _cuge_, 
   {{0x2d85998d,0x2b40d435,0x9c7c0fb7,0x2d8c098d}},	//   _cine_, _amic_, leči, _duge_, 
   {{0x2d85998e,0x69c1998f,0x2d8c0381,0x257400fd}},	//   _dine_, ámen, _euge_, cäle_, 
   {{0x2d842d65,0x2d8d9990,0x7e2434d8,0x39400cf9}},	//   _eine_, _fuge_, _одеж, wijs_, 
   {{0xfbd00050,0xedd0a521,0x69c00153,0x39419991}},	//   رتھ_, _ليند, šmen, tijs_, 
   {{0x2d859992,0xc8380092,0x00000000,0x00000000}},	//   _gine_, _ከስምን, --, --, 
   {{0x39419993,0x67d59994,0x3b180194,0x2d8c0e78}},	//   rijs_, кору, _toqq_, _zuge_, 
   {{0x2d859995,0x9c7c1727,0xefbc02d3,0x2d8c00cd}},	//   _zine_, ječi, _ዶባዊ_, _yuge_, 
   {{0xe7859996,0x2d840365,0x7bd8049b,0x5574487f}},	// [2b890] туро, _yine_, lttu, егат, 
   {{0xb8649d69,0x3f9c08e5,0x7bd8026c,0xdb08002f}},	//   _يادو, _ottu_, ottu, ssdä, 
   {{0x7bd99997,0x00000000,0x00000000,0x00000000}},	//   nttu, --, --, --, 
   {{0x7bd831e8,0x2b080034,0xe81c05f9,0x25c4029f}},	//   ittu, षाएँ_, नहरा_, ürlü_, 
   {{0x3f9d9998,0x34f00724,0xa194059f,0x5ef400dc}},	//   _attu_, _иҗат, вачч, ्यन्_, 
   {{0x80d84728,0x7bd803cd,0x6ff003b9,0x00000000}},	//   प्ले, kttu, _həcə, --, 
   {{0x2d8c102c,0x2d859999,0x9c7c0427,0x00000000}},	//   _suge_, _rine_, beči, --, 
   {{0xdea51655,0x2d8c067c,0x7bd805ac,0x00000000}},	//   نیمی, _puge_, dttu, --, 
   {{0x3f9c1418,0x6ff000ac,0xf1a401ce,0x7bd9999a}},	//   _ettu_, _məcə, _іран, ettu, 
   {{0x6e9c02ab,0x3ea01918,0x2b4039b4,0x26000954}},	//   _ग्रु, ıkta_, _smic_, रिती_, 
   {{0x2d85999b,0xcb69999c,0x9f4c0306,0x6ed40073}},	//   _vine_, зане_, _hrdý_, _यापु, 
   {{0x201856eb,0x2d856711,0x81e0015b,0x929c033f}},	//   _ària_, _wine_, ধির_, _poły, 
   {{0x2d85999d,0x6f09999e,0x7bd9999f,0x38a40166}},	//   _tine_, _ingc, attu, _bеr_, 
   {{0x2d8599a0,0x9c7c0010,0x0cdc00cc,0x00000000}},	//   _uine_, zeči, _ভোৰত, --, 
   {{0x37e00137,0x99180816,0x929c0210,0x00000000}},	//   лорг, фіях_, _woły, --, 
   {{0xc8440323,0x63780615,0x2fc4003e,0x46280023}},	//   _үеий, míng, irng_, _ጽርግያ, 
   {{0x6f084b2a,0x9c7d99a1,0x637800d8,0x6ff003b9}},	// [2b8a0] _mngc, veči, líng, _dəcə, 
   {{0xb5f802fb,0x00000000,0x00000000,0x00000000}},	//   _vzáp, --, --, --, 
   {{0x5ef40a28,0x6f0999a2,0x73309498,0x6378013c}},	//   ्यम्_, _ongc, گىنا, níng, 
   {{0xc8c801d5,0x6e9c07f8,0x00000000,0x00000000}},	//   _بوگن_, _ग्लु, --, --, 
   {{0x9c7c5424,0x8eac009e,0x733053f0,0x00000000}},	//   reči, _গাংগ, دىنا, --, 
   {{0xdfd032e8,0x6f090a09,0x7bd809f3,0x7b280b45}},	//   ليت_, _angc, yttu, nƙur, 
   {{0x9c7d99a3,0xde480014,0x00000000,0x00000000}},	//   peči, ڈیاو_, --, --, 
   {{0x80d00406,0xb7d8011a,0x3da401d5,0x37f8010f}},	//   _ठावे, לקצי, нроб, פּוב, 
   {{0x020599a4,0xc0e40120,0x9e340137,0xf06199a5}},	//   _язан, _поак, тепч, ккәп, 
   {{0x6f083058,0x527599a6,0x80a4007b,0xee7000ee}},	//   _engc, _русу, _أمان, ылыь, 
   {{0x7bd80eda,0x29180165,0x6f080356,0x3f9c0254}},	//   uttu, djra_, _fngc, _uttu_, 
   {{0xf09c0016,0x7bd999a7,0x00000000,0x00000000}},	//   _đài_, rttu, --, --, 
   {{0x7bd8143a,0x6da199a8,0x7f40003a,0x63780077}},	//   sttu, _бича, _imoq, mínd, 
   {{0x29892cb4,0xdb080332,0x00000000,0x00000000}},	//   ессо_, nsdú, --, --, 
   {{0x1ce0025c,0x6ed40490,0x370454f9,0x7f40022e}},	//   _སྡར_, _यामु, нчав, _kmoq, 
   {{0x7b2802a8,0x63780077,0x67440276,0x9ab400b8}},	//   rƙus, nínd, гэуз, bhāṃ, 
   {{0x7aed99a9,0xac800116,0x555400d1,0xeaf8009f}},	// [2b8b0] mect, _игәл, پپار, _سريت_, 
   {{0x7f40036b,0x00000000,0x00000000,0x00000000}},	//   _lmoq, --, --, --, 
   {{0x6ff003e3,0x63bc01ef,0x00000000,0x00000000}},	//   _təcə, _cvrn, --, --, 
   {{0xa3b4033f,0xd7600345,0x6b480139,0x00000000}},	//   _फ़िर_, _ئۆری, lıgr, --, 
   {{0x7aed99aa,0x63780005,0xb3d000fd,0xf1a40d1d}},	//   iect, dínd, _әйбә, хрен, 
   {{0x7aec01ee,0x637800d2,0x7f40022e,0x504400db}},	//   hect, yíng, _amoq, келб, 
   {{0x289c00df,0x00000000,0x00000000,0x00000000}},	//   ליגא, --, --, --, 
   {{0xb8d00dd4,0x7aed99ab,0x257401e6,0xcde401b9}},	//   _ཞབ_, ject, mäla_, воий, 
   {{0x25740793,0x7aed99ac,0x63bc0010,0x50f41606}},	//   läla_, dect, _zvrn, _изат, 
   {{0x69c001f1,0xbadc0183,0x5004010a,0xa2640395}},	//   ámem, _বোলছ, _аçис, _съсл, 
   {{0x7aed99ad,0x63780005,0xcc88103f,0x00000000}},	//   fect, bínd, بنده_, --, 
   {{0x6f081cdf,0x6378056a,0x6c0000cf,0x00000000}},	//   _ungc, cínd, _ۅكتۅ, --, 
   {{0xfe98011a,0x5a540139,0x5e2402c9,0xadc001af}},	//   _חינמ, гъру, _معوق, _салһ, 
   {{0x1c440046,0x25740793,0x637999ae,0x9d1801af}},	//   _өнім, käla_, míne, _почт_, 
   {{0x290c12ca,0x637999af,0x6d4199b0,0xc7641066}},	//   ıda_, líne, _imna, نارى, 
   {{0x8a0400c7,0x257401b8,0x4e1437c8,0xb3d40154}},	//   _азие, däla_, _तपाई_, সবাজ, 
   {{0x0684006c,0x6d400083,0xc95408e2,0x5ef40882}},	// [2b8c0] тган, _kmna, _атны, ्यत्_, 
   {{0x5ea8015b,0xf5e401f0,0xc928009d,0x00000000}},	//   _গাছে, ъмул_, _цоож_, --, 
   {{0xc7a599b1,0x6d40007f,0x2c0c00fe,0x00000000}},	//   _шинк, _mmna, ানকৈ_, --, 
   {{0xd3c40075,0x63780005,0x7bcc01ab,0x63840b01}},	//   اتلى, xínd, àbui, уҳба, 
   {{0x6d4199b2,0x7f4001b9,0x9c7c02f0,0x6378013a}},	//   _omna, _rmoq, lečt, jíne, 
   {{0xb5f80241,0x7aed99b3,0xa2b40073,0x7f4001a9}},	//   _ayáw, zect, _उजव्, _smoq, 
   {{0x7aed99b4,0x637999b5,0x63bc05a1,0x7f40022e}},	//   yect, tínd, _uvrn, _pmoq, 
   {{0x7aec6bf8,0x6d4199b6,0x63781aac,0x044402a9}},	//   xect, _amna, fíne, _зеҳн, 
   {{0x7aed99b7,0x1604924b,0x637829d3,0xdb080fac}},	//   vect, रियर_, gíne, msdø, 
   {{0x9d1454ea,0xdb080158,0x7aec009a,0x00000000}},	//   удоч, lsdø, wect, --, 
   {{0x7f4001b9,0x4438009a,0xeb940798,0x00000000}},	//   _tmoq, nzp_, киќ_, --, 
   {{0x6d4199b8,0xbea404ad,0x7aec0393,0xdb0803cd}},	//   _emna, _радк, uect, nsdø, 
   {{0x9c7c09a8,0x6ed407b6,0x63780332,0x00000000}},	//   veču, _यातु, cíne, --, 
   {{0xac90059f,0x8e7c00df,0xbc04009d,0x00000000}},	//   _кашш, teŝv, _ачий, --, 
   {{0x7aed99b9,0xe8240107,0xdb0812e8,0xb7642360}},	//   pect, афто, ksdø, втай, 
   {{0xab840166,0x00000000,0x00000000,0x00000000}},	//   _куык, --, --, --, 
   {{0x65948d20,0x1ce0025c,0xdb081512,0x9c7c0427}},	// [2b8d0] иату, _སྡོ_, dsdø, reču, 
   {{0xa5340724,0xc17c0024,0x5f4405db,0x394401e3}},	//   ануч, žėja_, ịghị_, _öns_, 
   {{0xf484084c,0xe3b000c6,0x7c38002f,0x637801d3}},	//   туан, قرن_, nztr, zíne, 
   {{0xfafd99ba,0xe3b00597,0x92580b32,0xe298003b}},	//   ndë_, ترك_, нает_, ваї_, 
   {{0x320852cb,0xd4c400fd,0x51e400db,0xc4b000cc}},	//   بتاً_, _бөек, اكتك, _চাৰজ, 
   {{0xb958026c,0x1ccc0327,0xf8d0012d,0x463800df}},	//   ssìf, ིུས_, तलिय, _טערע, 
   {{0x1fb599bb,0x44380175,0x00000000,0x00000000}},	//   асыр, czp_, --, --, 
   {{0x9f580022,0x63798475,0x660c010b,0x203c0023}},	//   _ĩrã_, tíne, _ülkä, _ክንምር, 
   {{0xa194721f,0x4d64005b,0xdce800ef,0x00000000}},	//   _вауч, лкив, _šlāp, --, 
   {{0x69c00306,0x63780332,0x00000000,0x00000000}},	//   šmek, ríne, --, --, 
   {{0x0a3c0023,0xe50400dc,0x637801f6,0x9c7c01ef}},	//   _ኣስመራ, रयति_, síne, dečs, 
   {{0xed6000c6,0x7d180218,0x61340ba1,0x63785d85}},	//   гľð_, ajts, _vàle, píne, 
   {{0xa9240122,0x6d4000b5,0xee8406d2,0x00000000}},	//   ážov, _tmna, _рыжо, --, 
   {{0x6f180b91,0x6d4199bc,0x8274008f,0x0c0401d9}},	//   ljuc, _umna, טערע_, _موتُ, 
   {{0x635c0427,0x7c3803ac,0x6e38002f,0x00000000}},	//   lčne, cztr, lzub, --, 
   {{0xe748010b,0x00000000,0x00000000,0x00000000}},	//   түме_, --, --, --, 
   {{0x635c994e,0xfd9c02e3,0x6e3999bd,0xc4e401ec}},	// [2b8e0] nčne, _kụọ_, nzub, лжай, 
   {{0xfd9c0521,0x6f180268,0x850c05d7,0xe7940214}},	//   _jụọ_, hjuc, साइट_, _پادک, 
   {{0x42c82dfa,0xfd9c0521,0x6f180e3c,0x845999be}},	//   еген_, _mụọ_, kjuc, храт_, 
   {{0xb9cc069c,0x59f40867,0xdcf4b745,0x635c00d0}},	//   _ዶብ_, _བརྩེ_, _čači, kčne, 
   {{0x69c00030,0x635c0427,0x6e3802f0,0x614400c7}},	//   ámeh, jčne, jzub, аҵаа, 
   {{0x66040516,0x6e3999bf,0xfd9c01f2,0xe3a42263}},	//   mvik, dzub, _nụọ_, _نشری, 
   {{0x660599c0,0x257401b8,0xdcb801e4,0x635c0419}},	//   lvik, lälo_, vaĉ_, ečne, 
   {{0x6e380e78,0x66040037,0x6e9001a9,0x00000000}},	//   fzub, ovik, биъу, --, 
   {{0x660599c1,0x6134eacd,0x1ce0025c,0x1d3599c2}},	//   nvik, _càlc, _སྡུ_, иния, 
   {{0x7d180218,0xb2200276,0x7c3826bd,0xb5f4010f}},	//   ujts, _умул, tztr, נציג_, 
   {{0xfee4006c,0x6604d62e,0x7d180175,0x7c380165}},	//   _бўлм, hvik, rjts, uztr, 
   {{0x7d1805ac,0x660599c3,0x7c380112,0x00000000}},	//   sjts, kvik, rztr, --, 
   {{0x7c38066d,0xfe70b3cc,0x0eb81688,0xfafc0023}},	//   sztr, _ادا_, _рухы_, rdë_, 
   {{0x660599c4,0xfd9c00b4,0x257401b8,0x6db0010b}},	//   dvik, _gụọ_, dälo_, _уйшу, 
   {{0xf6e45a6f,0x00000000,0x00000000,0x00000000}},	//   лцан, --, --, --, 
   {{0xfd9c02e3,0x8e7c010f,0x660412e8,0x00000000}},	//   _zụọ_, peŝt, fvik, --, 
   {{0x66040d04,0x160401ad,0x645c06be,0x00000000}},	// [2b8f0] gvik, रिधर_, _axri, --, 
   {{0xa4d81c13,0x7afc0477,0xb6980129,0x32cc0205}},	//   лдуу_, _haqt, _saâd, köyü_, 
   {{0x7afc0986,0x6d4c004a,0x29040605,0xfbe0009e}},	//   _kaqt, écai, ɛma_, যিকত, 
   {{0x637999c5,0x66040810,0x7afc0135,0x929c033f}},	//   vínc, bvik, _jaqt, _małg, 
   {{0x66040122,0x28dc01ad,0xb4000116,0x645c00d7}},	//   cvik, _बामि, шүңд, _exri, 
   {{0x2cf005ba,0x635d6185,0x7afd99c6,0xa99c011a}},	//   _असेल_, včne, _laqt, תבגר, 
   {{0xfd9c00b4,0x3e3c02d3,0xdb180174,0x98b000e2}},	//   _rụọ_, _ክትዛረ, _avví, lizē_, 
   {{0x6e38ef32,0xcf2400c6,0x2904005f,0xdcf801e4}},	//   tzub, شرعي, ēmai_, _vivĝ, 
   {{0xfd9c02e3,0x8d5418ac,0x98b000e2,0x6f18002d}},	//   _pụọ_, иточ, nizē_, rjuc, 
   {{0x63790ffb,0x32c801e1,0x6e381298,0xdde85857}},	//   mína, _fòyà_, rzub, اريه_, 
   {{0x660405b8,0x6e3999c7,0x7afd99c8,0x637999c9}},	//   zvik, szub, _baqt, lína, 
   {{0x3164083a,0x3e5c0521,0x660403b2,0x635c00d7}},	//   lonz_, ịta_, yvik, pčne, 
   {{0x61340109,0x7afc0327,0xfd9c01f2,0x257404e6}},	//   _hàla, _daqt, _tụọ_, fäll_, 
   {{0x66041061,0x8b955816,0x23bc08a5,0x07a460a7}},	//   vvik, _крич, _jájá_, иагн, 
   {{0x80d80316,0x2904012c,0x7afc0139,0x23bc0241}},	//   प्टे, ěma_, _faqt, _májá_, 
   {{0x2904448b,0x66041a82,0x0ae832e8,0x613599ca}},	//   śma_, tvik, _شرعي_, _màla, 
   {{0x61340170,0xe61c0055,0xe7b400cf,0x00000000}},	// [2b900] _làla, _rāųņ, _گۅزد, --, 
   {{0x660599cb,0xb344031c,0xfafc01f5,0x291c0022}},	//   rvik, _laħħ, noën_, _õva_, 
   {{0x66041cbd,0x7afc0724,0x00000000,0x00000000}},	//   svik, _yaqt, --, --, 
   {{0x998800a2,0xb344031c,0xba000023,0x7afc00fd}},	//   _araň_, _naħħ, _ልባ_, _xaqt, 
   {{0x66040d04,0x23bc0241,0x63789fab,0x145801ec}},	//   qvik, _bájá_, gína, _ұшты_, 
   {{0xba38006a,0x316405be,0xfafc0023,0x9f640790}},	//   mbït, gonz_, llët_, ştüm_, 
   {{0xb344031c,0xfafc01c7,0x42d40111,0x00000000}},	//   _baħħ, doën_, _візу, --, 
   {{0x61340170,0x637800e4,0xb5f801d3,0xceb40304}},	//   _dàla, bína, _gyás, бәш_, 
   {{0xb5f800dd,0xb3440135,0x7afc102c,0x23bc01e1}},	//   _száz, _daħħ, _raqt, _fájá_, 
   {{0xac7402d3,0x7afc047e,0xfafc01c7,0x7d2400d8}},	//   _ባዕሎም_, _saqt, goën_, рфие, 
   {{0xdd9199cc,0x25740267,0x7afc0986,0xb344025c}},	//   _کوت_, väll_, _paqt, _faħħ, 
   {{0x78b599cd,0x27f800a9,0x79a40228,0x1cb8031c}},	//   _sexv, dwrn_, ирге, _མཇམ_, 
   {{0x7afc006c,0x257401e6,0x998800a2,0x00000000}},	//   _vaqt, täll_, _yraň_, --, 
   {{0x7afc0050,0xb5f801e1,0x00000000,0x00000000}},	//   _waqt, _oyár, --, --, 
   {{0xb5f800dd,0xed540640,0xad180375,0x7afd99ce}},	//   _nyár, _њој_, _בוגר, _taqt, 
   {{0x569431ee,0x257401c7,0x2bc4004e,0x1ab40395}},	//   саат, säll_, _тушо_, _убия, 
   {{0xb5f801e1,0x78b44f74,0x63780005,0x58d40063}},	// [2b910] _ayár, _texv, xína, _лопт, 
   {{0x929c0034,0xb9580268,0xfafc0240,0x00000000}},	//   _małe, ssìb, alët_, --, 
   {{0xdef00092,0x00000000,0x00000000,0x00000000}},	//   ሃንና_, --, --, --, 
   {{0x52140c9e,0xe2c800f1,0x97341d10,0x2c0400cd}},	//   йдет, لومو_, _اکسا, षितं_, 
   {{0x87780d65,0x10a41b10,0xfafc02d3,0xdb080321}},	//   _תארי, билн, llës_, lsdó, 
   {{0xb344038f,0xe0d802bf,0x613401ab,0xfafc0200}},	//   _saħħ, иві_, _pàla, olës_, 
   {{0xb5f800dd,0x24198a81,0xdb0999cf,0x316407c5}},	//   _gyár, _коры_, nsdó, ronz_, 
   {{0x81e403f4,0x63780232,0x9bec0156,0xa344008e}},	//   _বছর_, pína, ལསློ, _дэул, 
   {{0x1ce00003,0xfafc0a40,0x929c068f,0x925919c7}},	//   _སྡང_, toën_, _całe, _саат_, 
   {{0xdb080008,0x28dc2435,0xa0c406b6,0x61340e89}},	//   ksdó, _बाधि, _ويقو, _tàla, 
   {{0xfafc01c7,0x4b880075,0xbb18054e,0xab6400d1}},	//   roën_, лйон_, rmîn, يۇتى, 
   {{0xdb0808ce,0x00000000,0x00000000,0x00000000}},	//   dsdó, --, --, --, 
   {{0x8e840597,0x7c3403e3,0x00000000,0x00000000}},	//   _الشه, _əyri, --, --, 
   {{0x6028013f,0xde7436fe,0xdb0801a8,0x00000000}},	//   sɛme, _بدمع, fsdó, --, 
   {{0x6d4c07ea,0xdb0808a5,0x00000000,0x00000000}},	//   écau, gsdó, --, --, 
   {{0xf7400209,0x00000000,0x00000000,0x00000000}},	//   песо, --, --, --, 
   {{0x96b999d0,0x6aa599d1,0xf53c03cd,0xfad4011a}},	// [2b920] русу_, _ifif, _ståa_, _הופך_, 
   {{0x69c40072,0xdb0801a8,0xfafc0240,0x63b40022}},	//   _ivie, bsdó, blës_, жәах, 
   {{0x69c401a2,0x9f640200,0x048801f7,0x00000000}},	//   _hvie, ëtën_, اخذو_, --, 
   {{0x69c599d2,0x00000000,0x00000000,0x00000000}},	//   _kvie, --, --, --, 
   {{0xb9580268,0x41285378,0x82a40124,0x00000000}},	//   lsìa, лодо_, _ҳабж, --, 
   {{0x35a03528,0x69c40208,0xb64001ec,0x00000000}},	//   _харг, _mvie, _ﻌﺗ_, --, 
   {{0x443d99d3,0x2600a064,0x6aa40241,0x800457c6}},	//   _åt_, रिकी_, _ofif, счле, 
   {{0x6aa4013f,0x63780122,0x835404fb,0x929c0210}},	//   _nfif, míno, _اپرا, _pałe, 
   {{0xc1e404a2,0x69c44f74,0x637802fb,0xe51c00dc}},	//   ﺎﻧﺪﺍ, _nvie, líno, नापि_, 
   {{0x6aa4f9d6,0xb22199d4,0xb5f800df,0x00000000}},	//   _afif, _эмул, נליכ, --, 
   {{0x69c599d5,0x351800c8,0xdb1803b2,0xc0c000d1}},	//   _avie, אוינ, _avvá, _дәқи, 
   {{0xa3e0072a,0x200d99d6,0xdb080162,0x29840124}},	//   _दमन_, _irdi_, vsdó, ҧырг, 
   {{0x4f640597,0xf2d000c8,0x9d18328e,0x201c0393}},	//   _بالف, הער_, _волт_, lxvi_, 
   {{0x69c599d7,0xdd90a822,0x200c84cd,0x20c800dc}},	//   _dvie, _غوث_, _krdi_, रणिध, 
   {{0x69c40c8c,0xe51c0882,0xb6c45d4e,0xc4dc00eb}},	//   _evie, नानि_, йсай, ড়াঙ, 
   {{0xdb085787,0x69c4030d,0x160402ab,0x00000000}},	//   rsdó, _fvie, रिलर_, --, 
   {{0x69c009ff,0x60c999d8,0xd4b80640,0x69c40064}},	// [2b930] ámet, _oddm, илац_, _gvie, 
   {{0x200d99d9,0x63780306,0x635c033b,0xdb0803b2}},	//   _ordi_, fíno, včna, psdó, 
   {{0x80d001d9,0x69c599da,0x69c0005f,0x637802f0}},	//   सलैं, _zvie, šmet, gíno, 
   {{0x60c8030d,0xd250fefb,0x635c033b,0x00000000}},	//   _addm, ونا_, tčna, --, 
   {{0x200d99db,0xfafc0ea0,0xe1f000e5,0x00000000}},	//   _ardi_, voël_, ٹسن_, --, 
   {{0x1c180034,0xa9bc0a1e,0x63787247,0x92b80154}},	//   धमाल_, נזור, bíno, চলে_, 
   {{0x200c8b2e,0x69a00d5f,0xf6e40327,0x28dc012c}},	//   _crdi_, _गंभी, _སྡོང, _बासि, 
   {{0x0dc999dc,0x929c033f,0x00000000,0x00000000}},	//   алий_, _wałb, --, --, 
   {{0x200d99dd,0x61341bce,0x8d580107,0xc0b80023}},	//   _erdi_, _kàll, ишот_, ደመም_, 
   {{0x61341bce,0x7e9c0150,0x25740254,0x00000000}},	//   _jàll, _ﺇﻏﻼﻕ_, välk_, --, 
   {{0x69c44aad,0xc4d00375,0x6aa408d5,0x200c0010}},	//   _svie, וגי_, _pfif, _grdi_, 
   {{0xcb6813d6,0x28dc038e,0x752414b2,0xc6880092}},	//   раме_, _बाहि, _lojz, _ሜዳሊያ_, 
   {{0x20e084b8,0xf6e40327,0xe51c00dc,0x637802f0}},	//   _नामध, _སྡེང, नामि_, zíno, 
   {{0x2d9cc51b,0x273c01e7,0xdcf80171,0x69c401f4}},	//   mque_, _míne_, _divē, _vvie, 
   {{0x273c0491,0x2d9d99de,0x8c4599df,0xb510012d}},	//   _líne_, lque_, _фейе, ठाईय_, 
   {{0x2d9c1730,0x2a600070,0x6aa40421,0xdb1803cd}},	//   oque_, _txib_, _ufif, _avvæ, 
   {{0x69c401f1,0x854901eb,0x25740793,0xa3dc0490}},	// [2b940] _uvie, азав_, läli_, णून_, 
   {{0x29040029,0x2d9d99e0,0x75d00597,0x61340de2}},	//   ēmas_, ique_, بيكا, _càll, 
   {{0x613400e8,0x257599e1,0x2d9c0113,0x273c0162}},	//   _dàll, näli_, hque_, _pínd_, 
   {{0x63780f91,0x73780107,0x42080114,0xd3980139}},	//   ríno, арчӣ_, инео_, сәрә_, 
   {{0x26c199e2,0x61341bce,0xdb2001d3,0x2d9c003a}},	//   maio_, _fàll, áték, jque_, 
   {{0x26c199e3,0x2574049b,0x2d9c1730,0x5f9599e4}},	//   laio_, käli_, dque_, пикт, 
   {{0xdfd006d5,0x2d9c0483,0x82a407d6,0x705050d8}},	//   رية_, eque_, _мавж, ونها, 
   {{0x26c199e5,0x74101aa3,0x257599e6,0x2d9c0393}},	//   naio_, _توفا, däli_, fque_, 
   {{0x61341105,0x26c018a6,0x260025fe,0x635c0427}},	//   _yàll, iaio_, रिटी_, lčno, 
   {{0x200c151c,0x25a00548,0x644000ac,0x613400e8}},	//   _trdi_, iqil_, _əmin, _xàll, 
   {{0x2d9d99e7,0x200d99e8,0x26c199e9,0x635d99ea}},	//   aque_, _urdi_, kaio_, nčno, 
   {{0x2d9d99eb,0x25a0011f,0x6d4c004a,0xdcf8002b}},	//   bque_, kqil_, écar, _dhvā, 
   {{0x2d9d99ec,0x26c0123c,0x28dc02ab,0x81ac00cc}},	//   cque_, daio_, _बाशि, _কিড_, 
   {{0x41d006ab,0x5ef400dc,0x635c0f91,0x6cf4010a}},	//   _सिनस, ्यक्_, kčno, _мечĕ, 
   {{0x7c644a45,0x28dc7f90,0x26c00618,0x69c006ea}},	//   _باشل, _बारि, faio_, ámer, 
   {{0x26c00798,0x6134002e,0x2ce40327,0x00000000}},	//   gaio_, _sàll, _འཁོབ, --, 
   {{0xbba000d1,0x929c012d,0x635c00d7,0x69d80055}},	// [2b950] _ﺍﻟﻠﻪ_, _nała, ečno, _āveg, 
   {{0x26c00093,0x00000000,0x00000000,0x00000000}},	//   aaio_, --, --, --, 
   {{0x96f807d8,0x273c007b,0x2d9c0789,0x1ce00327}},	//   _лент_, _síne_, zque_, _སྡབ_, 
   {{0x61343d27,0x26c0011c,0x2d9c06af,0x929c012d}},	//   _wàll, caio_, yque_, _bała, 
   {{0x2d9c16b8,0x61341bce,0xb864cbbd,0x10a45211}},	//   xque_, _tàll, _داکو, пилн, 
   {{0xe188143e,0x635c0010,0x273c00d0,0x929c012d}},	//   يئون_, bčno, _víne_, _dała, 
   {{0xb454040b,0x3dc40076,0xc85402d3,0x7e60035a}},	//   _بیاض_, _avow_, _ወድሓን, _axop, 
   {{0x2d9c0483,0x25748234,0x83a40022,0x5ef400cd}},	//   tque_, väli_, _хырҵ, ्यग्_, 
   {{0x30a4330e,0x2d9d99ed,0x28dc21b8,0x30e400d4}},	//   _древ, uque_, _बालि, _міжб, 
   {{0x1ce0025c,0xc6140375,0xf99c0ba1,0x26c0009d}},	//   _སྡད_, פחתי_, rvèl_, zaio_, 
   {{0x7e600393,0xc4d000c8,0x2d9d99ee,0x929c0034}},	//   _exop, עגט_, sque_, _zała, 
   {{0x7e600cf9,0x3ea40036,0xf1cc1d15,0x81ac05ac}},	//   _fxop, _gfot_, _हटान, _কিত_, 
   {{0x26c00395,0xedc400f1,0xdcac0228,0x00000000}},	//   vaio_, _بېخي_, دۉۉ_, --, 
   {{0x257401b8,0xdb180267,0x69d8002b,0x00000000}},	//   päli_, _avvä, _āved, --, 
   {{0x26c199ef,0x09e00154,0x00000000,0x00000000}},	//   taio_, যবধা, --, --, 
   {{0x635c0427,0x00000000,0x00000000,0x00000000}},	//   včno, --, --, --, 
   {{0x26c006bb,0x6b840eb4,0x24980109,0x25dc01f9}},	// [2b960] raio_, _ihig, _pgrm_, गंधी_, 
   {{0x26c199f0,0x85781ee3,0xb6a00598,0x00000000}},	//   saio_, ёсат_, _җирл, --, 
   {{0x389804ac,0x6b8402b9,0x26c199f1,0x387c0198}},	//   _ליינ, _khig, paio_, ƙura_, 
   {{0x6378012c,0x929c033f,0x1ce00327,0x635c25d8}},	//   mínk, _pała, _སྡན_, rčno, 
   {{0x6b8401ab,0x8560035b,0x63780216,0x67240135}},	//   _mhig, _зҽаҧ, línk, mjij, 
   {{0x672599f2,0x6b840731,0x36880032,0x635c0010}},	//   ljij, _lhig, _ѳсѳн_, pčno, 
   {{0x9f64025a,0x4abc07b7,0xdb08007c,0x00000000}},	//   ëtïn_, ्णाव, msdö, --, 
   {{0x67259284,0x98a00055,0x644006be,0x00000000}},	//   njij, _mohā_, _əmil, --, 
   {{0xdfd0024e,0x7d6802bf,0x1df840bf,0x40940353}},	//   ريک_, йшов_, تکاب_, _ерет, 
   {{0x6b856b38,0x0164c920,0x628199f3,0xa3e0230e}},	//   _ahig, _экзо, _izmo, _दमा_, 
   {{0x6b84002b,0x6724020c,0x70442309,0x5f480117}},	//   _bhig, kjij, _ىرمە, _мӯин_, 
   {{0x6b8599f4,0xe8b82fb5,0x63b801f1,0x7e60009d}},	//   _chig, _དབུག, ávny, _txop, 
   {{0x6b840d62,0x6e900597,0x3f9d99f5,0x672599f6}},	//   _dhig, _كلما, _hutu_, djij, 
   {{0x3f9d99f7,0x6b8599f8,0x05a80037,0x2a6400e4}},	//   _kutu_, _ehig, _चढ़इब, ûmba_, 
   {{0xbc704acd,0x6b843e79,0x3f9d99f9,0x16f80327}},	//   _سۇحب, _fhig, _jutu_, _ཕྲུམ_, 
   {{0x6b8599fa,0x672599fb,0x418801ec,0x00000000}},	//   _ghig, gjij, _ﺗﻮﮔﯩ, --, 
   {{0x7bd999fc,0x3f9d99fd,0x7bdc03cd,0xaa880137}},	// [2b970] lutu, _lutu_, _åpub, _ىنىم_, 
   {{0x6b8403f9,0x7bd8009f,0x2a580375,0x63780306}},	//   _zhig, outu, _מבחן_, bínk, 
   {{0xb4b00598,0xe5708a91,0x672400ca,0xe2c800f1}},	//   _җибә, اطق_, bjij, ړونو_, 
   {{0xa3440323,0x799c004b,0x527400a8,0x00000000}},	//   нэчл, _kuqw, мулу, --, 
   {{0x3f9d99fe,0x7bd999ff,0x623440c4,0xdb08007c}},	//   _autu_, hutu, нецу, bsdö, 
   {{0x7bd99a00,0x3f9d9a01,0x62800998,0xc6900677}},	//   kutu, _butu_, _dzmo, _שאך_, 
   {{0x7bd805a7,0x799c0472,0x273c0588,0x7994031c}},	//   jutu, _luqw, _hína_, _mixw, 
   {{0x273c1604,0x79940117,0x7bd99a02,0x3f9d9a03}},	//   _kína_, _lixw, dutu, _dutu_, 
   {{0x0d846161,0x273c0113,0x799c0477,0x6b859a04}},	//   млин, _jína_, _nuqw, _rhig, 
   {{0x6b859a05,0x7bd99a06,0x3f9c0b23,0x273c2833}},	//   _shig, futu, _futu_, _mína_, 
   {{0x7bd99a07,0x3f9d9a08,0x257401e6,0x6b84e456}},	//   gutu, _gutu_, mält_, _phig, 
   {{0x09e000bd,0x929c068f,0x2dc400d1,0x37e00154}},	//   যবসা, _mało, _еқин_, মবার, 
   {{0x7bd99a09,0xba2002bf,0x3f9c110c,0x273c032e}},	//   autu, вдяк, _zutu_, _nína_, 
   {{0x799c047e,0x6b840158,0x63780118,0x635c02bd}},	//   _duqw, _whig, tínk, včnm, 
   {{0x6b84f588,0x7bd84552,0x273c00c7,0x3d180316}},	//   _thig, cutu, _aína_, बारे_, 
   {{0x25742155,0x6b8505d9,0x273c0166,0x637813d5}},	//   hält_, _uhig, _bína_, rínk, 
   {{0x09e06569,0xfb842580,0x4528468b,0xc8b40166}},	// [2b980] যবহা, _تدوی, ожан_, _осны, 
   {{0x63799a0a,0x257401e6,0x7bd000e2,0xe8b40c75}},	//   míni, jält_, ūduš, _سەرج, 
   {{0x929c068f,0x63799a0b,0xf9900375,0x24540133}},	//   _cało, líni, _שרת_, رۆرس, 
   {{0x68fd9a0c,0x3f9d9a0d,0x79940117,0x273c0252}},	//   lerd, _rutu_, _zixw, _fína_, 
   {{0x25758b4f,0xe7a402ab,0x7bd80356,0x637800e4}},	//   fält_, _खंडप, zutu, níni, 
   {{0x7bd99a0e,0x68fd9a0f,0x97c40014,0x637801d3}},	//   yutu, nerd, _تتیم, zính, 
   {{0x3f9c094a,0x68fc0221,0x2fc4020b,0x637800c6}},	//   _qutu_, ierd, gsng_, híni, 
   {{0x7bd99a10,0x68fd9a11,0x3f9c19a2,0x4f8401e0}},	//   vutu, herd, _vutu_, нтыҡ, 
   {{0x7bd99a12,0x68fd9a13,0x929c068f,0x3f9c00e8}},	//   wutu, kerd, _zało, _wutu_, 
   {{0x68fd9a14,0x257401e6,0x00000000,0x00000000}},	//   jerd, mäls_, --, --, 
   {{0xdb559a15,0x3f9d48a5,0x799c014f,0x7bd81e70}},	//   евны, _uutu_, _suqw, uutu, 
   {{0x799401f0,0x68fc057b,0x799c016d,0x212c0240}},	//   _sixw, eerd, _puqw, _hodh_, 
   {{0x9de80ed9,0x7bd99a16,0x68fc68b6,0x6d480162}},	//   _འདྲེ, sutu, ferd, ðlaá, 
   {{0xf7719a17,0x00000000,0x00000000,0x00000000}},	//   چار_, --, --, --, 
   {{0x273c1c38,0x3f840dc9,0x212c327f,0x7bd99a18}},	//   _sína_, _khou_, _modh_, qutu, 
   {{0x799c014f,0x212c0240,0x273c0d12,0x637801e1}},	//   _tuqw, _lodh_, _pína_, bíni, 
   {{0xa3dc0574,0x637806ed,0x3f8401ab,0x79940327}},	// [2b990] णूस_, cíni, _mhou_, _tixw, 
   {{0x68fd9a19,0x273c0232,0x212c0200,0x15e002db}},	//   cerd, _vína_, _nodh_, गंबर_, 
   {{0x613400db,0xb8641867,0x53340124,0x00000000}},	//   _gàli, _زادو, нежт, --, 
   {{0x273c0579,0x63bc015d,0x212c00ae,0x8fa40022}},	//   _tína_, _dwrn, _aodh_, ҭале, 
   {{0xb9e402d3,0xa2940845,0xd17558fb,0xe3b80724}},	//   _ክኣ_, ваці, ныкы, _çın_, 
   {{0x2fc401af,0xc0e19a1a,0x00000000,0x00000000}},	//   tsng_, гошк, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3f859a1b,0x273c01e7,0x00000000,0x00000000}},	//   _chou_, _línn_, --, --, 
   {{0x68fd9a1c,0xcc8800aa,0x212c01c3,0x333c0254}},	//   yerd, ګنده_, _fodh_, _ilux_, 
   {{0x0c259a1d,0xc908015b,0xe7f00037,0x68fc0327}},	//   емон, _রক্ত_, _चहला_, xerd, 
   {{0x8fd00b65,0x1fb400c0,0x2b1c0118,0x00000000}},	//   _сәлә, _асір, यालु_, --, 
   {{0x68fd9a1e,0x6e400014,0xf09c004d,0x63780332}},	//   werd, _لۆبم, _đày_, tíni, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x68fc324c,0x63799a1f,0x26c40153,0x7c300162}},	//   uerd, ríni, _žmo_, ídrá, 
   {{0x68fd9a20,0x6028013f,0x273c01e7,0x9988012d}},	//   rerd, yɛmm, _dínn_, _brał_, 
   {{0xb5f99a21,0x28dc367a,0x68fd9a22,0x61340137}},	//   _exám, _बाकि, serd, _vàli, 
   {{0x2b408bbb,0x9a68001f,0xdce800e2,0x273c01a8}},	// [2b9a0] _ilic_, ተካከል_, lodā, _fínn_, 
   {{0x75d16c42,0x59f4081f,0x273c0241,0x04440139}},	//   ايلا, _བརྗེ_, _gínn_, незн, 
   {{0x2b408553,0x635d9a23,0x00000000,0x00000000}},	//   _klic_, lčni, --, --, 
   {{0x442408ad,0xb9b17e94,0xf48505bf,0xb85408a8}},	//   ćo_, _جمیع, رالی, _טייפ_, 
   {{0x2d8409f0,0x635c0fb7,0x30100220,0x2be80eac}},	//   _ohne_, nčni, ғдыр, টিয়ে_, 
   {{0x3f859a24,0x333c0254,0x635c0010,0x63bc015d}},	//   _shou_, _elux_, ični, _twrn, 
   {{0x333d9a25,0x3f8401d4,0x25dc00ab,0x41d0000d}},	//   _flux_, _phou_, गूरी_, _सिवस, 
   {{0x2b400048,0x2d859a26,0xb22005a2,0x8c140011}},	//   _nlic_, _ahne_, тмәл, াহান_, 
   {{0x635c0219,0x59a43042,0x9f5801e1,0xd25800ef}},	//   jčni, _गंधर, _èrí_, _teņa_, 
   {{0x2b40f225,0x72840014,0x635ca0b6,0x2dd00124}},	//   _alic_, _ساقے, dčni, ыжьр, 
   {{0x2b40026a,0x2ef00046,0x3f840f85,0xf1040137}},	//   _blic_, _әзір, _thou_, _سۉيۉ_, 
   {{0x2d8401c4,0x0ae8004b,0xfbd001d9,0x00000000}},	//   _ehne_, ورټي_, پتھ_, --, 
   {{0xedd19a27,0xdd1c00c0,0xcee801f7,0x00000000}},	//   _ميند, _išžu, _آرمن_, --, 
   {{0x2b40067c,0x2d845e7c,0x00000000,0x00000000}},	//   _elic_, _ghne_, --, --, 
   {{0x46ac0521,0x2b404e01,0x3cfc0036,0x286800d4}},	//   _ọtọ_, _flic_, metv_, ерто_, 
   {{0x7d099a28,0xf84405f5,0x2b419a29,0x0ac40124}},	//   _hafs, дүүд_, _glic_, _ишьҭ, 
   {{0x7d099a2a,0x55744f2f,0xa5f873da,0x788402d2}},	// [2b9b0] _kafs, вгат, нету_, _béví, 
   {{0xfafc0660,0x1be42ce1,0x7d08037e,0xb4b807f7}},	//   leë_, _कमाल_, _jafs, घरे_, 
   {{0x344800c7,0x61e400a3,0x7d088eae,0x00000000}},	//   ччан_, àiln, _mafs, --, 
   {{0x925800c9,0x7d080036,0xfafc0af9,0xf5e4187f}},	//   мает_, _lafs, neë_, _пігм, 
   {{0x2364037e,0xd53c0208,0x788402d2,0x23b40116}},	//   _djmj_, _tần, _féví, نمەس, 
   {{0x3cfc05be,0xdcf81a14,0x45a000d1,0x41d003ce}},	//   jetv_, _divī, _ئەلك, _सिरस, 
   {{0xe81406ab,0x20c84072,0xc0cc0f7c,0x683c014a}},	//   डिया_, ربوي_, _ባድመ_, mädö, 
   {{0x683c014a,0xdea40244,0x929c0210,0x00000000}},	//   lädö, هیمی, _małk, --, 
   {{0xfafc0af9,0x395001e3,0x1ea92e20,0x7d080200}},	//   deë_, _omxs_, رايي_, _bafs, 
   {{0x635d9a2b,0x683c29ef,0x6134004e,0x2b400042}},	//   včni, nädö, _sàlv, _slic_, 
   {{0x2b419a2c,0xcb699a2d,0xdde82a60,0xc0e40014}},	//   _plic_, дане_, وریه_, _شکوٕ_, 
   {{0x9f0400db,0x4df429a3,0xcdf464c2,0x9c640451}},	//   _مومو, _аякт, _ачкы, اهٽو, 
   {{0x7d099a2e,0x613400db,0x8fd000d1,0x3d280133}},	//   _fafs, _vàlv, _сәһә, ستیی_, 
   {{0x257401e6,0x6378007b,0x635d9a2f,0x7d0808a5}},	//   jälp_, línt, pōng, _gafs, 
   {{0x07a59a30,0x929c068f,0x6f080472,0x8c459a31}},	//   табн, _całk, _kagc, _шеке, 
   {{0x273c0232,0x2efd9a32,0x41d01df1,0x2b419a33}},	//   _víno_, neuf_, _सिलस, _ulic_, 
   {{0xb6a186a5,0xc4e40150,0x3688010a,0x00000000}},	// [2b9c0] риул, кжай, çсан_, --, 
   {{0x1dd405ba,0x6f0813c4,0x683c0793,0x7d080169}},	//   _दिसत, _lagc, gädö, _xafs, 
   {{0x070800ec,0xd4f402d5,0x929c012d,0x04940006}},	//   _قيدي_, ыяты, _gałk, траў, 
   {{0x490839d7,0x7c2c0158,0x91cc000d,0x00000000}},	//   ायको_, øbri, _सिखै, --, 
   {{0x683c0793,0xe2859a34,0x37bc0327,0x64480327}},	//   bädö, уған, _མཆོད, _żdid, 
   {{0xdfd07427,0x660429ef,0x00000000,0x00000000}},	//   ميت_, mwik, --, --, 
   {{0x6f082747,0x6378215a,0x7d099a35,0x6604002d}},	//   _bagc, fínt, _rafs, lwik, 
   {{0x8318027a,0x35a405f9,0x7d099a36,0xbdc401d3}},	//   _تقرر_, _कूड़, _safs, نگتے_, 
   {{0x66059a37,0x613400db,0x6f0855ad,0x7d08036e}},	//   nwik, _bàlt, _dagc, _pafs, 
   {{0xe28400d1,0xf2640276,0xfafc053d,0x52740022}},	//   _алғи, _риул_, joër_, _сусу, 
   {{0xbd0401e1,0x6f080007,0xff059a38,0x28dc0406}},	//   _abéò, _fagc, _аялн, _बाजि, 
   {{0x66059a39,0x613400db,0x2bd0000d,0x00000000}},	//   kwik, _vàlu, _थिरा, --, 
   {{0x7d099a3a,0x7f400140,0x63780ab9,0x66040113}},	//   _tafs, _iloq, líns, jwik, 
   {{0xf99c0699,0x6f08401f,0x7d0801bf,0x929c0210}},	//   twèb_, _zagc, _uafs, _pałk, 
   {{0x63784c25,0x6f097a81,0x6604003e,0x9f580241}},	//   níns, _yagc, ewik, _éró_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69c00261,0x66041c06,0x683c01b8,0xa63402bf}},	// [2b9d0] âmet, gwik, tädö, анті, 
   {{0xf8b41152,0x7bd80af5,0x7f4003f0,0x8e7c01e4}},	//   _अभिय, ortu, _lloq, ngŝa, 
   {{0x7f40009a,0x2a740f01,0x683c01b8,0x00000000}},	//   _oloq, _مدیح, rädö, --, 
   {{0x660408e7,0x637802f0,0x2458074d,0xdb1c0139}},	//   bwik, díns, ъахь_, _üzär, 
   {{0x6604003e,0x91801e87,0xd17802d5,0x6f080009}},	//   cwik, مۇرۇ, нскі_, _ragc, 
   {{0x7f40006c,0x6f082dee,0xf99c0100,0x64480135}},	//   _aloq, _sagc, lvès_, _żdie, 
   {{0x6f080589,0x2efca573,0x7bd801bf,0x637800d7}},	//   _pagc, teuf_, jrtu, gíns, 
   {{0x7f401e54,0x8e08209b,0x6458033f,0xf99c007f}},	//   _cloq, енив_, ócił, nvès_, 
   {{0xd0101365,0x7bd99a3b,0x63780798,0x2018066a}},	//   _گلا_, ertu, rínt, _árin_, 
   {{0x7f419a3c,0xb698006a,0x63799a3d,0x6f099a3e}},	//   _eloq, _waâw, sínt, _wagc, 
   {{0x6f081c64,0x7f40511a,0x63791a6d,0xd0119a3f}},	//   _tagc, _floq, cíns, _دلا_, 
   {{0x635c0421,0x7e6c01e7,0x00000000,0x00000000}},	//   pōne, éipé, --, --, 
   {{0x7bd832ff,0xe704158f,0x00000000,0x00000000}},	//   artu, یسری, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd5b80003,0x6d40008e,0xfafc0af9,0x6604045a}},	//   _བསྔག, _ilna, roër_, wwik, 
   {{0x290c04b9,0x66059a40,0x6d400083,0x8a0400c7}},	//   žda_, twik, _hlna, _бзие, 
   {{0x06840228,0x056417a1,0xfb8401d5,0x63780306}},	// [2b9e0] уган, гван, _حدوی, zíns, 
   {{0x66040502,0xb9b80375,0xe3b8510c,0xf99c068c}},	//   rwik, _רצית, _çık_, rvèt_, 
   {{0x660406e4,0x41c402ab,0xaaa807f7,0x00000000}},	//   swik, रीनस, _गलाक, --, 
   {{0xb7d825f9,0x63799a41,0x82699a42,0x6d400142}},	//   _אקטי, víns, наев_, _llna, 
   {{0xd3982cc8,0xa3e012eb,0xdcf8013a,0x06c401ec}},	//   тәрә_, _दमक_, _chvě, _ﺩﻩﺳﻪ, 
   {{0x63799478,0x00000000,0x00000000,0x00000000}},	//   tíns, --, --, --, 
   {{0x6134004e,0x9478013e,0xefb001b9,0x09f800eb}},	//   _bàlr, _асту_, میلگ, ইটিং_, 
   {{0x6d400209,0x7bd801a6,0x63780419,0x44380432}},	//   _alna, vrtu, ríns, myp_, 
   {{0x443809a5,0x6da006ed,0xdd909476,0x63790d3f}},	//   lyp_, биња, يوب_, síns, 
   {{0x63799a43,0x7bd80194,0x9bf4f99a,0xf53c0267}},	//   píns, trtu, азоч, _utåt_, 
   {{0x443809a5,0x387c02a8,0x7ee400c6,0x7f4001a9}},	//   nyp_, ƙuri_, _مكان, _tloq, 
   {{0x6d419a44,0x7a2c0139,0xbea40676,0x7f4001b9}},	//   _elna, _bеtе, _садк, _uloq, 
   {{0x7bd80194,0x44380432,0x2f5800df,0x00000000}},	//   srtu, hyp_, _אדאנ, --, 
   {{0x44380209,0xdd903b89,0x273c0051,0x7bd80327}},	//   kyp_, _بوت_, _hính_, prtu, 
   {{0x273c0016,0x7bd80194,0x8e7c01e4,0x67d4010b}},	//   _kính_, qrtu, ngŝn, йору, 
   {{0x44380209,0x7c2c0158,0x6bd00214,0x5fdc00bc}},	//   dyp_, øbru, _اتور, _यिनल, 
   {{0x80c800bd,0x58d48d2f,0x7c399a45,0xd5880408}},	// [2b9f0] _রান্, _копт, lytr, гiай, 
   {{0x273c001e,0xb4dc0b40,0x94d40138,0x00000000}},	//   _lính_, णले_, рожц, --, 
   {{0x7c380270,0x45f4031c,0x635c007f,0x4438010b}},	//   nytr, _པདྨས_, yčnt, gyp_, 
   {{0x5214330e,0xaee0002b,0xd2140063,0xe73803f6}},	//   идет, _maṃj, имећ, _беџ_, 
   {{0x90c402d5,0xd5b8031c,0x49080073,0xb03001e0}},	//   абле, _བསྒག, ायचो_, өмдә, 
   {{0x9f4c025a,0x940405d9,0x7c3803ac,0x00000000}},	//   _fqdë_, _پوره, kytr, --, 
   {{0x273c004d,0x44384d3e,0x00000000,0x00000000}},	//   _bính_, cyp_, --, --, 
   {{0x6d4001ab,0x7c3802d0,0x1db00248,0x00000000}},	//   _slna, dytr, _ẹyẹl, --, 
   {{0x273c001e,0x635c007f,0x00000000,0x00000000}},	//   _dính_, rčnt, --, --, 
   {{0xa3dc0490,0x7c3802d0,0xe3b000e5,0x00000000}},	//   णूक_, fytr, _ذرہ_, --, 
   {{0xaca001f2,0x8b259a46,0x6d4002f0,0x7c3802d0}},	//   _nwụk, адне, _vlna, gytr, 
   {{0xb600025c,0x00000000,0x00000000,0x00000000}},	//   ġġju, --, --, --, 
   {{0x9f04066d,0x443800ee,0x00000000,0x00000000}},	//   _دونو, zyp_, --, --, 
   {{0x6d400393,0x3ddc00fe,0xfce006ed,0x2ec000fb}},	//   _ulna, _বৈকল, _дошо, _төҫм, 
   {{0x97d99a47,0x637800e4,0x644003e3,0x6e380166}},	//   льту_, kínp, _əmis, lyub, 
   {{0x9bb405d9,0x635c02b5,0x273d6dc9,0xb6a000d4}},	//   _اليڪ, kōna, _kíni_, житл, 
   {{0x6aa4015c,0x273c0241,0x3d180073,0x929c0210}},	// [2ba00] _igif, _jíni_, बाचे_, _kału, 
   {{0xf53c1455,0x44399a48,0x273c022c,0x69c40135}},	//   _står_, typ_, _míni_, _iwie, 
   {{0x69c4025c,0x4ad99a49,0x7bd40055,0xdcf400ef}},	//   _hwie, _भयाव, _āyuk, _čaļi, 
   {{0x443809a5,0x69c44812,0xa13c00de,0x46a80037}},	//   ryp_, _kwie, _miķe, _कलिह, 
   {{0x44380209,0x69c4025c,0x80c80154,0x41280137}},	//   syp_, _jwie, _রাব্, кодо_, 
   {{0x443800ee,0x69c40135,0x273c0208,0x22400327}},	//   pyp_, _mwie, _sính_, ġik_, 
   {{0xf5480020,0x7c385e23,0x6aa54eae,0x69c4031c}},	//   _መረጃዎ, xytr, _ogif, _lwie, 
   {{0x6aa45c2e,0x3ea1161c,0xb5f8003a,0x7c3c00c5}},	//   _ngif, økt_, _exáu, _üpri, 
   {{0x6e38089c,0xaee00882,0x5d5400a7,0x69c4031c}},	//   gyub, _saṃj, йкит, _nwie, 
   {{0x6aa43dd4,0x7c395fb5,0x6280036b,0xa13c00de}},	//   _agif, tytr, _iymo, _biķe, 
   {{0x273c01dc,0x69c4013b,0x63a0036b,0x71700592}},	//   _tính_, _awie, _kimn, _بهلا, 
   {{0x69c40428,0x60c99a4a,0x7c399a4b,0x6e380526}},	//   _bwie, _hedm, rytr, byub, 
   {{0x6e380230,0x60c8007f,0x62800076,0xbd689735}},	//   cyub, _kedm, _jymo, _ирке_, 
   {{0x69c59a4c,0x63a012d7,0x6aa41418,0x644000ac}},	//   _dwie, _limn, _egif, _əmir, 
   {{0x69c4545b,0x67d4004e,0xd7c001f9,0x00000000}},	//   _ewie, жосу, षींच, --, 
   {{0x69c40135,0x60c80051,0x63a06a67,0xab280114}},	//   _fwie, _ledm, _nimn, _воћа_, 
   {{0xe85c001f,0x69c59a4d,0x00000000,0x00000000}},	// [2ba10] ደሚገኝ_, _gwie, --, --, 
   {{0x63a01db0,0x60c87dcd,0xb8649a79,0x200c01a9}},	//   _aimn, _nedm, _ناجو, _osdi_, 
   {{0x69c59a4e,0x62819a4f,0x00000000,0x00000000}},	//   _zwie, _aymo, --, --, 
   {{0x63a0022f,0xc7b00375,0x60c8000d,0xdb0c01e3}},	//   _cimn, _מבט_, _aedm, _ökän, 
   {{0x62800cfd,0x63a01a48,0x60c8a359,0x69c4031c}},	//   _cymo, _dimn, _bedm, _xwie, 
   {{0x6e3807a8,0x6ac40882,0x62819a50,0x200c0165}},	//   vyub, _वज्र, _dymo, _bsdi_, 
   {{0x60c962c8,0x273c0579,0x2250013f,0x387c03f9}},	//   _dedm, _síni_, _ɑnkɑ_, ƙuru_, 
   {{0x4f099a51,0x929c033f,0x79480432,0xdd3800de}},	//   унин_, _bałt, _hüwd, _jāņu, 
   {{0x628000a9,0x0d20167e,0x60c80450,0xdb0c0248}},	//   _gymo, зүлү, _fedm, _ìhùw, 
   {{0xfe6c0517,0x6e380223,0x69c4025c,0x273c0d12}},	//   رگن_, ryub, _rwie, _víni_, 
   {{0x69c59a52,0x63a066d4,0x6280045a,0x273c01e1}},	//   _swie, _yimn, _zymo, _wíni_, 
   {{0x63a01709,0x273c0579,0x69c4002d,0x00000000}},	//   _ximn, _tíni_, _pwie, --, 
   {{0x5f740597,0x8ac40ed1,0xbf1003e6,0x80c8015b}},	//   _بالر, аққа_, _رووب, _রাত্, 
   {{0x61e408c2,0xdd940006,0x00000000,0x00000000}},	//   àili, _дачы, --, --, 
   {{0xf99c007f,0x00000000,0x00000000,0x00000000}},	//   mwèl_, --, --, --, 
   {{0x69c59a53,0x6aa59a54,0x657c0cf4,0x00000000}},	//   _twie, _ugif, _skrh, --, 
   {{0x63a00c86,0x69c40034,0x7bcc0006,0xfafc0200}},	// [2ba20] _rimn, _uwie, šbut, onën_, 
   {{0x63a19a55,0x4cd803f4,0xc8440139,0xf99c007f}},	//   _simn, ব্রু, _геой, nwèl_, 
   {{0x60c99a56,0x62819a57,0x63a19a58,0x79480432}},	//   _redm, _symo, _pimn, _düwd, 
   {{0x60c8506e,0xd37800d6,0x6280030a,0x42240b01}},	//   _sedm, ачі_, _pymo, йдев, 
   {{0x88e50d57,0xe4f00882,0x00000000,0x00000000}},	//   _སྐོར, _चापि_, --, --, 
   {{0x55c407d6,0x628002fb,0x60c80455,0x26c04f55}},	//   _фарғ, _vymo, _qedm, lbio_, 
   {{0x63a19a59,0x6280033f,0x60c8bb3c,0x5f94001b}},	//   _timn, _wymo, _vedm, оикт, 
   {{0x628000a9,0x26c0009d,0xfafc0200,0x2b181d34}},	//   _tymo, nbio_, enën_, _बोलु_, 
   {{0x635c0270,0xc2459a5a,0x26c00142,0x00000000}},	//   lōno, _унак, ibio_, --, 
   {{0xf1bc012c,0xb1400276,0x00000000,0x00000000}},	//   ášen_, _енул, --, --, 
   {{0xfe7003e6,0x929c033f,0x8e7c01e4,0x7578010f}},	//   _کدا_, _fałs, ngŝj, רטיפ, 
   {{0x70440c75,0x794800a2,0x749800df,0x5ba8004e}},	//   _اركە, _müwe, טייפ, лкүм_, 
   {{0x635c0374,0xf99c007f,0x00000000,0x00000000}},	//   hōno, bwèl_, --, --, 
   {{0x273c0008,0x635c00b0,0xdd3800ef,0x00000000}},	//   _mínu_, kōno, _sāņu, --, 
   {{0x273c0252,0x00000000,0x00000000,0x00000000}},	//   _línu_, --, --, --, 
   {{0x3dc59a5b,0x91e400b5,0x26c00153,0xf62800d4}},	//   _kwow_, xxはn, gbio_, лізи_, 
   {{0xb6982776,0x9f5800c7,0x273c0cad,0x46a8000d}},	// [2ba30] _mbâg, _érõ_, _nínu_, _कलरह, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x26c00801,0x293800c8,0x96f99a5c,0x00000000}},	//   bbio_, _לאזן_, _кент_, --, 
   {{0x3ea59a5d,0xd9ec05dc,0x273c0241,0x7948010e}},	//   _ngot_, _जमात_, _bínu_, _düwe, 
   {{0xdecc1b49,0x273c02f0,0x6448000d,0xb8650abe}},	//   ጣንን_, _cínu_, _üdin, _خاکو, 
   {{0x2eb00882,0x3ea40332,0x00000000,0x00000000}},	//   ीर्त, _agot_, --, --, 
   {{0x1fb40046,0x3dc40009,0xa93c011a,0x00000000}},	//   псыр, _awow_, רתופ, --, 
   {{0x63b801f1,0x1dd40034,0xfafc0373,0x273c0252}},	//   ívne, _दिखत, liëf_, _fínu_, 
   {{0x77380092,0xf99c02e2,0x925800db,0x59a40210}},	//   _የወሰደ, twèl_, _таат_, _गंगर, 
   {{0x26c00552,0x7d7426c0,0x22642b57,0x3ea4007c}},	//   zbio_, يمير_, šská_, _egot_, 
   {{0xe3b803e0,0x26c00042,0x00000000,0x00000000}},	//   _çıt_, ybio_, --, --, 
   {{0x3ea40c6a,0xf99c0100,0x26c001bf,0x00000000}},	//   _ggot_, swèl_, xbio_, --, 
   {{0x5f749924,0xb9580109,0xa2ac00bc,0x99880055}},	//   _عامر, tsìp, ुँत्, _uraś_, 
   {{0x07a42424,0xba74005e,0x26c023b5,0xc7a40229}},	//   жавн, تاپت, wbio_, живк, 
   {{0x47584600,0x288402dd,0x4e1000bc,0x26c00427}},	//   арая_, яқов, तिकै_, tbio_, 
   {{0x9f5800e4,0x7c3403e0,0xdce8013a,0x00000000}},	//   _érô_, çarş, kodě, --, 
   {{0x80c800bd,0xdbd4032e,0x794800a2,0x768c01e1}},	// [2ba40] _রাস্, _húðv, _süwe, _ròyí, 
   {{0x26c0007c,0xdce8013a,0x00000000,0x00000000}},	//   sbio_, dodě, --, --, 
   {{0x273c008c,0xfb500271,0x00000000,0x00000000}},	//   _sínu_, _رپید, --, --, 
   {{0x032480df,0x273c0321,0x00000000,0x00000000}},	//   юден, _pínu_, --, --, 
   {{0x41b402f6,0xb778008f,0xdbd408a5,0x00000000}},	//   цсет, _כאטש, _lúðv, --, 
   {{0x43080451,0x273c0f91,0x7948010b,0xdee402dd}},	//   _ھيءَ_, _vínu_, _tüwe, _ﺍﻋﺘﺒ, 
   {{0x273c2833,0x443c06ea,0x35a0e362,0x5434010a}},	//   _fínt_, _æt_, _царг, _ехту, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6e940395,0x00d81c43,0x8c8400c7,0x00000000}},	//   овър_, _نبات_, ҟәша_, --, 
   {{0x9c7c00c0,0x00000000,0x00000000,0x00000000}},	//   lgči, --, --, --, 
   {{0x46a80490,0x201801d3,0x704401ec,0x61e401e7}},	//   कशाह, _éri_, _ورمە, áilf, 
   {{0x273c0252,0x9c7c0024,0x26e411d7,0xbe1400ae}},	//   _míns_, ngči, गलोर_, _ووضع, 
   {{0xf2d01775,0x00000000,0x00000000,0x00000000}},	//   וער_, --, --, --, 
   {{0x929c012d,0xb9c40107,0x00000000,0x00000000}},	//   _małp, йёҳи, --, --, 
   {{0xad2000d1,0x00000000,0x00000000,0x00000000}},	//   _زىيى, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe7859a5e,0x195800ee,0x7af80037,0x998401af}},	// [2ba50] фуро, _гапы_, õutu, _нтоһ, 
   {{0x6b5001e1,0x00000000,0x00000000,0x00000000}},	//   _tògù, --, --, --, 
   {{0x273c03b2,0xdecc001f,0x00000000,0x00000000}},	//   _pínt_, ጣንና_, --, --, 
   {{0x80c800bd,0xdce80118,0x1b0800eb,0x00000000}},	//   _রাষ্, todě, ষাকে_, --, 
   {{0x320800d8,0x9f580241,0x05e0000d,0x00000000}},	//   рхен_, _èrù_, _पियब, --, 
   {{0xdce800bc,0x6aa805d7,0x00000000,0x00000000}},	//   rodě, _गल्र, --, --, 
   {{0xba00001f,0x7750001f,0xf1c40118,0x273c02d2}},	//   _ውጣ_, _መለስተ, _řády_, _tínt_, 
   {{0x81a803f4,0x2eec011f,0x6028013f,0x7a40002b}},	//   _খবর_, _qcgf_, rɛmp, _kįtā, 
   {{0x61e400a3,0x0e640395,0xdbd4032e,0xe3b80139}},	//   àilt, якин, _súðv, _çır_, 
   {{0x321c0004,0xc5f002e4,0xfafc0036,0x4d4800f3}},	//   _iruy_, עדי_, hiëd_, спон_, 
   {{0x4c8469a1,0x00000000,0x00000000,0x00000000}},	//   ялов, --, --, --, 
   {{0x8db41ac3,0xcb680902,0x7bd40055,0x00000000}},	//   _ескі, саме_, _āyut, --, 
   {{0xfa651db0,0x1df80064,0x2bdc0303,0x00000000}},	//   заяк_, _мецы_, पूजा, --, 
   {{0x42780115,0x27180248,0x00000000,0x00000000}},	//   מארג, _ọn_, --, --, 
   {{0x99180212,0x8c44010a,0x00000000,0x00000000}},	//   ціях_, _хейе, --, --, 
   {{0xfd4c00b8,0x00000000,0x00000000,0x00000000}},	//   daiṣ, --, --, --, 
   {{0x26e405d7,0x273c066a,0x00000000,0x00000000}},	// [2ba60] गलौर_, _síns_, --, --, 
   {{0xd5e8009f,0x00000000,0x00000000,0x00000000}},	//   تعفن_, --, --, --, 
   {{0x321c02d1,0x29180af9,0x00000000,0x00000000}},	//   _aruy_, mdra_, --, --, 
   {{0x29199a5f,0x321c003e,0x67600023,0x998806be}},	//   ldra_, _bruy_, _ተገዲዱ_, _kraş_, 
   {{0x25741178,0xf4d4074d,0xe8141788,0x00000000}},	//   _قۇرس, емĕш_, डिका_, --, 
   {{0x29199a60,0xdfd04d49,0x273c0162,0x6b2c0327}},	//   ndra_, نيت_, _tíns_, _སོའོ_, 
   {{0xd9d80316,0x9f986880,0x29199a61,0x3d14791c}},	//   _भट्ट, овку_, idra_, _भोगे_, 
   {{0x99880276,0x2918015d,0xe3b80139,0x00000000}},	//   _oraş_, hdra_, _çıq_, --, 
   {{0xdcf800e2,0x00e4009d,0xc244030d,0x00000000}},	//   _akvā, _нжан, _энак, --, 
   {{0xdea0036b,0x2918031c,0x00000000,0x00000000}},	//   _ییغی, jdra_, --, --, 
   {{0x61e40024,0x29189632,0x39a00241,0x3518010f}},	//   šild, ddra_, _lésì_, זוינ, 
   {{0x2918202c,0x998800a2,0xdb1c03b9,0x00000000}},	//   edra_, _braş_, _üzür, --, 
   {{0x7f9400c7,0x7e98007b,0x2b4401c6,0x3e8800cf}},	//   _даҧх, _انشر_, хээг, _уйдо_, 
   {{0xada003b7,0x63bc0109,0x29180af9,0x2de00131}},	//   _зачл, _otrn, gdra_, _ﺋﻪﻣﻤ, 
   {{0x6cf80375,0x97240035,0x74e00154,0x54d40150}},	//   _הפוס, وفسو, ন্ডউ, _ﺘﺩﺨﻼ, 
   {{0x291891ae,0xe75800d4,0x00000000,0x00000000}},	//   adra_, писі_, --, --, 
   {{0xae1c02e5,0x95381086,0x3b080789,0xcce402dd}},	// [2ba70] बियन_, озат_, mecq_, _ءسۇي, 
   {{0x637800d2,0x7bdc003b,0xddd400cd,0x00000000}},	//   míny, _åpus, _śaśi, --, 
   {{0x048400fd,0x2cb806be,0x00000000,0x00000000}},	//   дәти_, _əqd_, --, --, 
   {{0x7aed9a62,0x91800131,0xf6280212,0x00000000}},	//   ngct, چۇرۇ, _ліги_, --, 
   {{0x63bc007f,0x777c01b9,0x64580174,0x00000000}},	//   _etrn, moqx, úvir, --, 
   {{0xf8bc46df,0x777c01a9,0xc1740133,0xca2801ec}},	//   ्रिय, loqx, وڵلا_, _ﺤﺠﺔ_, 
   {{0xe0d19a63,0x3ff025aa,0x647454fe,0x80ac033f}},	//   ازه_, نكور, _згру, ुड़े, 
   {{0x321c0016,0x29199a64,0xe2f802dd,0x00000000}},	//   _truy_, zdra_, _несі_, --, 
   {{0x30a4dab5,0x321c0054,0xf8bc090a,0x29199a65}},	//   _ерев, _uruy_, ्राय, ydra_, 
   {{0x8d7478e3,0x61e59a66,0xc790001f,0x8538008f}},	//   بابا, áile, _ቀጥተኛ_, ַגרי, 
   {{0x8638001f,0x00000000,0x00000000,0x00000000}},	//   _የዘንድ, --, --, --, 
   {{0x6ee40150,0x61e40427,0x29188909,0x00000000}},	//   _ءسال, šile, wdra_, --, 
   {{0x29180af9,0x00000000,0x00000000,0x00000000}},	//   tdra_, --, --, --, 
   {{0x7aec074d,0xaf740240,0x00000000,0x00000000}},	//   agct, _ይህበና_, --, --, 
   {{0x29199a67,0x0b880691,0xa2d001f9,0x00000000}},	//   rdra_, _وضعي_, दरम्, --, 
   {{0x7aec074d,0x291833e6,0x998803e0,0x290c000d}},	//   cgct, sdra_, _traş_, õdab_, 
   {{0x6b840537,0x63bcb820,0xea640014,0x06859a68}},	// [2ba80] _ikig, _strn, _سپدی, фган, 
   {{0xf50400a8,0xdb200241,0x00000000,0x00000000}},	//   мнул_, _òtòl, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8264004b,0x7860022e,0x00000000,0x00000000}},	//   وهان, _sеvg, --, --, 
   {{0x6b84009f,0x00000000,0x00000000,0x00000000}},	//   _mkig, --, --, --, 
   {{0xefb001d5,0x00000000,0x00000000,0x00000000}},	//   چیلگ, --, --, --, 
   {{0x54c00220,0x6b841418,0x6b6401ed,0xefb001b9}},	//   _сұхб, _okig, zőga, نیلگ, 
   {{0x1e14ab8e,0xdfd01129,0x6b8448d8,0x3d1400af}},	//   емия, پيک_, _nkig, _भोजे_, 
   {{0x3ea001e6,0x00000000,0x00000000,0x00000000}},	//   äkt_, --, --, --, 
   {{0x6b859a69,0x00000000,0x00000000,0x00000000}},	//   _akig, --, --, --, 
   {{0xd1759a6a,0x7aec02d0,0x00000000,0x00000000}},	//   _чыты, tgct, --, --, 
   {{0x635c0093,0x00000000,0x00000000,0x00000000}},	//   fōni, --, --, --, 
   {{0x79480432,0xb3d8000d,0x00000000,0x00000000}},	//   _düwn, _पट््, --, --, 
   {{0x6b842f99,0x00000000,0x00000000,0x00000000}},	//   _ekig, --, --, --, 
   {{0x140c00ab,0x777c01b9,0xe818009d,0x00000000}},	//   _सनेह_, toqx, морч_, --, 
   {{0xf6501a90,0x00000000,0x00000000,0x00000000}},	//   پئر_, --, --, --, 
   {{0xa5f8468b,0x777c022e,0x69b001f9,0x00000000}},	// [2ba90] мету_, roqx, ंदणी, --, 
   {{0x7d199a6b,0xb4640271,0x00000000,0x00000000}},	//   ndts, وداه, --, --, 
   {{0xe4f000ab,0xe3b000ec,0xd7f4013d,0x00000000}},	//   _चारि_, لرن_, _язны, --, 
   {{0x16340801,0x6d8c05ac,0x00000000,0x00000000}},	//   _земя, jøan, --, --, 
   {{0x910462cb,0x91e408b7,0x00000000,0x00000000}},	//   епле, холе, --, --, 
   {{0x644003e3,0x41b005af,0x00000000,0x00000000}},	//   _əmiz, دمور, --, --, 
   {{0xf37401b9,0x00000000,0x00000000,0x00000000}},	//   _قطرد, --, --, --, 
   {{0xf99c1801,0x61e400ae,0x0dc800d4,0x00000000}},	//   rvèy_, áilc, плий_, --, 
   {{0x6b8401a9,0x00000000,0x00000000,0x00000000}},	//   _rkig, --, --, --, 
   {{0x6b840dd4,0x61e40219,0xefec0092,0xfbd80037}},	//   _skig, šilc, ቀረው_, _भिखम, 
   {{0x635c00d0,0x5ff401f0,0x00000000,0x00000000}},	//   ečny, _азху, --, --, 
   {{0x09e4e085,0x34c8de9c,0x8e744ae5,0x7e6800e5}},	//   номн, िरुद, _пулч, ámpá, 
   {{0x63780005,0xdf5801b9,0x6f199a6c,0xe4f0000d}},	//   rínx, _تشلش_, mduc, _चालि_, 
   {{0x6f1801e5,0x7c2c007b,0x00000000,0x00000000}},	//   lduc, óirí, --, --, 
   {{0x6f199a6d,0x3da400d4,0x0cbc0456,0x00000000}},	//   oduc, _якшо_, ोरीम, --, 
   {{0x6b85559c,0x6f199a6e,0x635c02b5,0x7c2c03cd}},	//   _ukig, nduc, pōni, åbre, 
   {{0x2b009f23,0x85e800d4,0x00000000,0x00000000}},	// [2baa0] ष्णु_, ядав_, --, --, 
   {{0x63b80030,0x6f199a6f,0x7a7800d9,0x00000000}},	//   ívno, hduc, _מרפס, --, 
   {{0x26b400d1,0x07a40798,0x00000000,0x00000000}},	//   _لەزز, _паон, --, --, 
   {{0x79940175,0x00000000,0x00000000,0x00000000}},	//   _zhxw, --, --, --, 
   {{0xb2819a70,0x6f199a71,0x644006be,0xf374009d}},	//   лышк, dduc, _əmiy, хөрч_, 
   {{0xc0bc0240,0x00000000,0x00000000,0x00000000}},	//   _ሰቦም_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb698025a,0xf99c007f,0x00000000,0x00000000}},	//   _mbân, lwèt_, --, --, 
   {{0xaf30215c,0x9184215c,0x00000000,0x00000000}},	//   ارىت, رجۇم, --, --, 
   {{0x6f199a72,0x3618011a,0x80c80154,0x00000000}},	//   aduc, לופד, _রাক্, --, 
   {{0x6f199a73,0x7948010e,0xfd101f0d,0x00000000}},	//   bduc, _düwl, نجھ_, --, 
   {{0xdb0c0432,0xf090011a,0x00000000,0x00000000}},	//   _ökün, _ענף_, --, --, 
   {{0x45280327,0x00000000,0x00000000,0x00000000}},	//   སྐོར_, --, --, --, 
   {{0x90d4004d,0x7948010e,0xf99c007f,0x00000000}},	//   _lòn, _güwl, jwèt_, --, 
   {{0xf7719a74,0xd04003be,0x9f5801e1,0x00000000}},	//   هار_, _belə, _èró_, --, 
   {{0x7bd89428,0x00000000,0x00000000,0x00000000}},	//   mstu, --, --, --, 
   {{0x799402d0,0x19c4e564,0x929c0210,0x00000000}},	// [2bab0] _thxw, _шәнг, _obła, --, 
   {{0x3b1800ac,0x7bd834c5,0x7c680023,0x19c80014}},	//   _haqq_, ostu, _ትመስል_, _ٹِھپ_, 
   {{0xb698145e,0xd2f80139,0xf8bc2432,0xb8640244}},	//   _gbân, деец_, ्रीप, _سادو, 
   {{0x7bd99a75,0xdb1800bc,0xf6500117,0x00000000}},	//   istu, _otví, _бемӯ, --, 
   {{0x237450a2,0x60280085,0xa29400d6,0x90d4004d}},	//   دالح, mɛmy, гаці, _dòn, 
   {{0x7bd99a76,0xa3cc0c2e,0x212c0407,0xf484064d}},	//   kstu, _शौक_, _cndh_, _зубн, 
   {{0x7bd99a77,0xd04006be,0x61e40327,0x00000000}},	//   jstu, _yelə, ġila, --, 
   {{0xaee00efb,0x61e55569,0xf8bc041c,0x00000000}},	//   اۋشى, šila, ्रुप, --, 
   {{0x6f199a78,0x7bd99a79,0xf99c020c,0x00000000}},	//   rduc, estu, nwès_, --, 
   {{0x7bd80660,0x3b180194,0x333c1e54,0x6f18035a}},	//   fstu, _aaqq_, _houx_, sduc, 
   {{0xd01015f8,0x8fd004a9,0x31640097,0x66e801e1}},	//   _خلا_, _тәлә, minz_, _jèkà, 
   {{0x7948010b,0x333c0129,0x8d7416d0,0x316400a2}},	//   _düwm, _joux_, عاکا, linz_, 
   {{0xe9841b6d,0x3b180135,0x4a7400e4,0x7bd80c2e}},	//   лқин, _daqq_, тынт, astu, 
   {{0x7bd99a7a,0x99150617,0x6d440267,0x316497af}},	//   bstu, льсі, öjad, ninz_, 
   {{0xf8615c6a,0xbb1800c7,0x580400fb,0x00000000}},	//   авро, moîn, лорғ, --, 
   {{0xfafc09b6,0x31640165,0x20200432,0x00000000}},	//   liën_, hinz_, _äriň_, --, 
   {{0x36655d37,0xdb2003b2,0x31640332,0x05a80395}},	// [2bac0] вато_, _ótál, kinz_, двай_, 
   {{0xfafc1190,0x291c0022,0x3b180327,0xf48400e5}},	//   niën_, _ûva_, _zaqq_, ھالی, 
   {{0x333c0207,0x3b18002e,0x00000000,0x00000000}},	//   _boux_, _yaqq_, --, --, 
   {{0x333c0007,0x41e401ce,0x7c3d9a7b,0x8268ef40}},	//   _coux_, віка, _àpre, маев_, 
   {{0x333d9a7c,0x2d840030,0x90d4004d,0xfafc01f5}},	//   _doux_, _okne_, _vòn, kiën_, 
   {{0xb698145e,0x7bd99a7d,0x3f844e1b,0xd0481df2}},	//   _mbâl, ystu, _skou_, ﯨﻠﯩﭗ_, 
   {{0x35180302,0xdfd00597,0x09f80f22,0x929c0034}},	//   _קולנ, حيب_, েটিং_, _mały, 
   {{0x2d840699,0x7bd87e78,0x333c0036,0xfafc0200}},	//   _akne_, vstu, _goux_, nnët_, 
   {{0xa084472d,0x7bd99a7e,0xa13c00de,0xfafc0200}},	//   _өңде, wstu, _liķi, inët_, 
   {{0x7bd99a7f,0xfafc01f5,0x9c3800d8,0x00000000}},	//   tstu, giën_, епот_, --, 
   {{0x333c0007,0x7bd99a80,0x2b400332,0xbff00137}},	//   _youx_, ustu, _boic_, _түйш, 
   {{0x2d8403cd,0x635c00b0,0x57b40aac,0xdce800e2}},	//   _ekne_, pōnu, ғбат, todē, 
   {{0x290456af,0xbe341f0d,0xedd001c8,0x00000000}},	//   đman_, _جراث, _نيند, --, 
   {{0x929c0034,0xfafd4cc1,0x60d80175,0xd91400c7}},	//   _cały, ciën_, navm, ыдгы, 
   {{0x7ac59a81,0xed54026a,0x37a8b132,0x3b18002e}},	//   _испе, _јој_, дтан_, _taqq_, 
   {{0x34c85168,0x00000000,0x00000000,0x00000000}},	//   िर्द, --, --, --, 
   {{0x333d9a82,0x31640007,0x2da400a2,0x80c800fe}},	// [2bad0] _roux_, yinz_, _öweç_, _ৰান্, 
   {{0x2d801674,0xfafc0240,0x69b00073,0x60d80419}},	//   čjeg_, anët_, ंदरी, javm, 
   {{0x333c06af,0x31640e78,0x00000000,0x00000000}},	//   _poux_, vinz_, --, --, 
   {{0x527400a8,0x31640356,0x66e400d8,0xe5f400cf}},	//   лулу, winz_, _коџа, اكەد, 
   {{0x80c800bd,0x61e4151c,0xed680023,0x00000000}},	//   _রাজ্, šiln, _ትገብር_, --, 
   {{0xc5f8008f,0x161807f7,0xfafc0200,0xaee000b8}},	//   _אפשט, _नैयर_, onës_, bhṛn, 
   {{0x333c06af,0x3164002f,0xe4a416a4,0x0d8400d1}},	//   _toux_, rinz_, _врто, һлин, 
   {{0x31649267,0x307000d1,0x0cbc00dc,0x20540150}},	//   sinz_, луқс, ोर्म, штір, 
   {{0x0d8476e9,0xfafc01f5,0x1ea800f1,0x2b4000ae}},	//   ллин, tiën_, پايي_, _roic_, 
   {{0x80c806e3,0xa184010b,0xf8bc193d,0x4a7401e0}},	//   _स्पे, _кыхл, ्रोप, ғымт, 
   {{0xfafc0196,0x09bd1769,0xcb680108,0x9f040137}},	//   riën_, ्ठ्य, еане_, _چومو, 
   {{0x9f04021a,0xaca00521,0xfafc017a,0x92e403d4}},	//   _نومو, _ntụk, siën_, ব্ৰ_, 
   {{0x9f04129e,0xfafc036e,0x8fd001ee,0x00000000}},	//   _خونو, enës_, _тәһә, --, 
   {{0xaca00521,0xa13c00ef,0x00000000,0x00000000}},	//   _atụk, _piķi, --, --, 
   {{0x2b4001ab,0x929c012d,0x37e00150,0x00000000}},	//   _toic_, _obło, йорг, --, 
   {{0x80c8810b,0x60982e1f,0xfafd9a83,0x20d80153}},	//   _स्ने, _ቅንጅት_, niël_, mžių_, 
   {{0x7cec01a9,0x4aa8e096,0xda640214,0xebe002dd}},	// [2bae0] _kеrа, _якин_, _پايي, _соқп, 
   {{0x69c59a84,0x3a340375,0x00000000,0x00000000}},	//   _itie, _ערים_, --, --, 
   {{0x69c58fbd,0xa31400fd,0x78f80375,0xa2d00118}},	//   _htie, иядә, _אליפ, दरल्, 
   {{0x69c59a85,0x02d41291,0x00000000,0x00000000}},	//   _ktie, اتاخ, --, --, 
   {{0x69c40327,0x60d802f0,0x62344130,0x00000000}},	//   _jtie, tavm, релу, --, 
   {{0x80c8015b,0x00000000,0x00000000,0x00000000}},	//   _রাঙ্, --, --, --, 
   {{0x60d96dac,0xa3cc0210,0x0f1c00eb,0x039468eb}},	//   ravm, _शौच_, থানঃ_, _брая, 
   {{0x20d802d5,0x69c59a86,0xdb1801f1,0xfafc0ea0}},	//   džių_, _otie, _otvá, giël_, 
   {{0xbd693cb4,0x69c59a87,0x5d5414a4,0x32d80a1e}},	//   ерне_, _ntie, икит, _רחמנ, 
   {{0xc058084c,0xb5f800df,0x527460a7,0x00000000}},	//   _прец_, עליכ, _тусу, --, 
   {{0x261419e5,0x69c59a88,0x00000000,0x00000000}},	//   नौती_, _atie, --, --, 
   {{0x69c4031c,0xca7c0092,0x00000000,0x00000000}},	//   _btie, ረጉንም_, --, --, 
   {{0x69c401f5,0x693401e0,0x7d4c0023,0xf99c0100}},	//   _ctie, әнсу, _ንፖለቲ, ntèg_, 
   {{0x6e901c43,0x7f40022f,0x69c40036,0x7ac402dd}},	//   _الها, _hooq, _dtie, _өсие, 
   {{0x69c59a89,0x7f400194,0x00000000,0x00000000}},	//   _etie, _kooq, --, --, 
   {{0x69c4025c,0x7f40058a,0x66f4010b,0xfafc036e}},	//   _ftie, _jooq, йпсу, rnës_, 
   {{0xdc9036d7,0x61e4007b,0x7f400009,0x96340798}},	// [2baf0] _ማሕበረ_, áill, _mooq, шнац, 
   {{0x7f40058a,0x61e4025c,0x00000000,0x00000000}},	//   _looq, ġill, --, --, 
   {{0x61e40784,0xdb180118,0x00000000,0x00000000}},	//   šill, _ztvá, --, --, 
   {{0xd2500ada,0x7f419a8a,0x27ec0122,0x2bf4008f}},	//   ينا_, _nooq, ádne_, רמאן_, 
   {{0xe70461f4,0x69c40135,0x98b00139,0x00000000}},	//   _اسپی, _xtie, lizı_, --, 
   {{0x798401ee,0x6938010e,0x20d80153,0x760400de}},	//   nojw, _işeñ, yžių_, rīzā, 
   {{0x7f400050,0x200c0005,0xb490036b,0xb61c0150}},	//   _booq, _cpdi_, _ایاغ, _ﺤﻤ_, 
   {{0x79859a8b,0xcf459a8c,0x8e087e7e,0x3dc000d1}},	//   hojw, рний, внив_, ﺮﻛﯩﺘ, 
   {{0x7984b171,0xfe6c4716,0x7f40058a,0x00000000}},	//   kojw, وگه_, _dooq, --, 
   {{0x6b580086,0xe8e002e3,0x00000000,0x00000000}},	//   _mãge, twọk_, --, --, 
   {{0x69c59a8d,0x7f40300b,0x7984009a,0xdb1800d0}},	//   _stie, _fooq, dojw, _stvá, 
   {{0xcb68554f,0xcd3401ed,0x5f94a99c,0x63b80419}},	//   таме_, ارکب, _лихт, ívni, 
   {{0x7860022e,0x69c4031c,0x00000000,0x00000000}},	//   _bеvo, _qtie, --, --, 
   {{0x79859a8e,0x69c400d7,0x00000000,0x00000000}},	//   gojw, _vtie, --, --, 
   {{0x6d419a8f,0x7f40011f,0x15801df2,0x7860022e}},	//   _iona, _yooq, ﯩﻼﺗﯩ, _dеvo, 
   {{0x6d419a90,0x7f40011f,0x7c3c00d8,0x69c59a91}},	//   _hona, _xooq, _àpra, _ttie, 
   {{0x05659a92,0x6d419a93,0x69c59a94,0xc5640640}},	// [2bb00] аван, _kona, _utie, акак, 
   {{0x75d072ca,0x84e40006,0x00000000,0x00000000}},	//   تيكا, рожж, --, --, 
   {{0xc2c59a95,0x9f5c02fb,0xf9f0031c,0x69380166}},	//   لياي, stvé_, _བཀོན_, _eşeñ, 
   {{0x42259a96,0x00000000,0x00000000,0x00000000}},	//   идев, --, --, --, 
   {{0x6d419a97,0xa4f8ff95,0x26c015c0,0x00000000}},	//   _oona, _مکار_, mcio_, --, 
   {{0x26c19a98,0x7f40581e,0xf990010f,0x00000000}},	//   lcio_, _sooq, ֿרה_, --, 
   {{0x7f40013c,0x73e19a99,0x03a40212,0x70500066}},	//   _pooq, _морз, _виво, ينها, 
   {{0x6d400ea3,0x44299a9a,0x9df86566,0x7f410ffa}},	//   _aona, _irb_, гнит_, _qooq, 
   {{0x6d419a9b,0x26c19a9c,0x44380120,0x2ca800ac}},	//   _bona, icio_, lxp_, əkdə_, 
   {{0x6d419a9d,0x5d5418ec,0x44280306,0xfd4400a8}},	//   _cona, скот, _krb_, рэин, 
   {{0x44399a9e,0x26c0c887,0x34b40302,0x69c19a9f}},	//   nxp_, kcio_, יפים_, ímen, 
   {{0x6d411d3a,0x44286164,0xccf4a8f1,0x80c800dc}},	//   _eona, _mrb_, ақә_, _स्ते, 
   {{0x6d419aa0,0xfe70064c,0x4cd400bd,0x79840526}},	//   _fona, _بدا_, _দারু, tojw, 
   {{0x6d419aa1,0x44299aa2,0x26c00142,0xada0014b}},	//   _gona, _orb_, ecio_, _дачл, 
   {{0xb7659aa3,0x00000000,0x00000000,0x00000000}},	//   атай, --, --, --, 
   {{0xf7709f21,0x7c2804cc,0x79840526,0x9ad40114}},	//   زاز_, _irfr, sojw, _ужич, 
   {{0x6d419aa4,0x61e40f03,0x44299aa5,0x2c44013f}},	// [2bb10] _yona, šilj, _arb_, rɑde_, 
   {{0x6d4007d6,0x44380407,0x170401d3,0x26c00142}},	//   _xona, fxp_, _گہری_, acio_, 
   {{0xdcf80316,0xf1cc0cb3,0x44299aa6,0xf494074d}},	//   _skvě, _सौजन, _crb_, рăнн, 
   {{0x26c19aa7,0x44280ac5,0x925800c9,0x3dc40428}},	//   ccio_, _drb_, лает_, _otow_, 
   {{0x3dc4013f,0x630401b9,0xe2f800d4,0x00000000}},	//   _ntow_, تونل, речі_, --, 
   {{0xdb1805ac,0x00000000,0x00000000,0x00000000}},	//   _utvæ, --, --, --, 
   {{0x442805a1,0x3dc430b5,0x21a800fd,0x00000000}},	//   _grb_, _atow_, рәтү_, --, 
   {{0x6d419aa8,0xc4440ee8,0x00000000,0x00000000}},	//   _sona, _دیمن_, --, --, 
   {{0x7c38007c,0x9558001f,0x2c5403e3,0x00000000}},	//   extr, _ሁለንተ, mədə_, --, 
   {{0x6d4003be,0x2c5400ac,0x00000000,0x00000000}},	//   _qona, lədə_, --, --, 
   {{0x6d419aa9,0x3dc40086,0x6adc00fe,0x509400ec}},	//   _vona, _etow_, _ভাবো, _الاء, 
   {{0x6d419aaa,0x2c540213,0x4b5402e8,0x00000000}},	//   _wona, nədə_, съот, --, 
   {{0x6d419aab,0x5c740184,0x7c299aac,0xc3300375}},	//   _tona, йҙәр_, _erfr, פוך_, 
   {{0x2c5400ac,0xbacc0ae5,0x6d401662,0x6e380472}},	//   hədə_, _ﻛﯩﺘﺎ, _uona, mxub, 
   {{0x2c5403be,0x07b8007b,0x7d7400f1,0x00000000}},	//   kədə_, اهرة_, _دمور_, --, 
   {{0x44287e94,0x16180037,0x00000000,0x00000000}},	//   _rrb_, _नैहर_, --, --, 
   {{0xf74003b7,0x44288841,0xb6a19aad,0x6e38009a}},	// [2bb20] чето, _srb_, зитл, nxub, 
   {{0x26c19aae,0x61e41404,0x12b803d4,0x00000000}},	//   scio_, šilk, ুণোদ, --, 
   {{0x26c19aaf,0x2c540213,0x7f9c0200,0x00000000}},	//   pcio_, fədə_, lëqe, --, 
   {{0x2bb40276,0xe2c891cb,0x41e400ae,0x00000000}},	//   _căci_, рһад_, مستف, --, 
   {{0x67252f1d,0xaefc0f22,0xc62003d4,0xa78400e2}},	//   mdij, ্যাণ_, _নথকা_, ļķīb, 
   {{0x1fc4016c,0x66059ab0,0x00000000,0x00000000}},	//   ориҳ, mtik, --, --, 
   {{0x3dc41713,0x2c540213,0x7c380334,0x00000000}},	//   _stow_, bədə_, xxtr, --, 
   {{0xceb40184,0x2c5403be,0x66059ab1,0x6d440267}},	//   ҙҙә_, cədə_, otik, öjan, 
   {{0x66059ab2,0x6e380921,0xf99c067c,0x00000000}},	//   ntik, gxub, ntèc_, --, 
   {{0x66059ab3,0x67240490,0x387c0311,0x00000000}},	//   itik, hdij, şuri_, --, 
   {{0x6604049b,0x20180ba1,0x6e2803ac,0x672401f5}},	//   htik, _èri_, _ergb, kdij, 
   {{0x672401fa,0xcf2407c0,0xad2000d1,0x00000000}},	//   jdij, _ورني, قىۋى, --, 
   {{0xdc180034,0x64480129,0x67259ab4,0x00000000}},	//   dłąc, _àdif, ddij, --, 
   {{0x7c3ccb63,0x6e40005e,0x69b002ab,0x672401a4}},	//   _àpro, _ءنوم, ंदगी, edij, 
   {{0x6604270c,0x2c5400ac,0x7c2805ac,0x97c401d5}},	//   etik, yədə_, _urfr, تقزو, 
   {{0x261400af,0x27ec0419,0x00000000,0x00000000}},	//   _नईखी_, ádna_, --, --, 
   {{0x66042ecd,0x848c0240,0x00000000,0x00000000}},	// [2bb30] gtik, _ጀሚረን_, --, --, 
   {{0x6724000d,0x00000000,0x00000000,0x00000000}},	//   adij, --, --, --, 
   {{0x66059ab5,0x67259ab6,0x628001d5,0x2c540213}},	//   atik, bdij, _axmo, tədə_, 
   {{0x66059ab7,0xdb18049f,0x80c80c58,0x6fbc01f9}},	//   btik, _utvä, _ৰাষ্, _लंबू, 
   {{0x2c540cc1,0x628005b1,0x66044e0e,0x3cdc03d4}},	//   rədə_, _cxmo, ctik, _মানৱ, 
   {{0x2c5400ac,0xa5040153,0x00000000,0x00000000}},	//   sədə_, _нясл, --, --, 
   {{0x628003ac,0x7f9c0023,0x629c01e4,0x40301d39}},	//   _exmo, zëqe, _ŝrot, дејс, 
   {{0xb8c8025c,0x2c5400ac,0x6e38005a,0x40900131}},	//   _བཻ_, qədə_, txub, بلىر, 
   {{0x9f5c0316,0x80c8193d,0xfe6c01b9,0x6d44000d}},	//   ctví_, _स्वे, پگن_, öjao, 
   {{0x91801b56,0x67240153,0x818400cf,0xdc18012d}},	//   _تۇتۇ, zdij, _وچوق_, złąc, 
   {{0x66059ab8,0x018401d9,0x8c440902,0x00000000}},	//   ztik, _بُلێ, цене, --, 
   {{0x66040962,0x7f9c036e,0x69c00115,0x8a040d1d}},	//   ytik, tëqe, ŭmem, озме, 
   {{0x67252b65,0x6604005a,0x00000000,0x00000000}},	//   vdij, xtik, --, --, 
   {{0x290c0209,0x61e4007b,0x66059ab9,0x7f9c0023}},	//   ýda_, áili, vtik, rëqe, 
   {{0xdb18033b,0x67249b34,0x66059aba,0x61e40327}},	//   _ouvè, tdij, wtik, ġili, 
   {{0x66059abb,0x6724bc36,0x61e4e12e,0x06c99abc}},	//   ttik, udij, šili, ргай_, 
   {{0x66059abd,0x6aa80154,0x2614000d,0xdb0c007c}},	// [2bb40] utik, _ক্রো, _नैखी_, åhår, 
   {{0xdb18180f,0x67247668,0x00000000,0x00000000}},	//   _auvè, sdij, --, --, 
   {{0x66059abe,0x03259abf,0xf99c067c,0x6724047e}},	//   stik, жден, stèc_, pdij, 
   {{0x96b99ac0,0xf99c067c,0x27f80175,0x6724031c}},	//   _гуру_, ptèc_, murn_, qdij, 
   {{0x66040357,0xc1a406ed,0x8184009d,0x00000000}},	//   qtik, ојки, огдж, --, 
   {{0x29199ac1,0xc3c80214,0x6d441b99,0xadf00210}},	//   nera_, _نظرم_, öjal, _आमजन_, 
   {{0x29199ac2,0xdb0c026c,0x9f5c00bc,0xbb180124}},	//   iera_, _biaì, ství_, moîv, 
   {{0x29199ac3,0x9c7c0b9d,0x35dc0034,0x5f940120}},	//   hera_, nače, _पौड़, џиит, 
   {{0x29199ac4,0x63bd9ac5,0x00000000,0x00000000}},	//   kera_, _hurn, --, --, 
   {{0x407000d1,0x9c7cb9b7,0x00000000,0x00000000}},	//   _оғлу, hače, --, --, 
   {{0x63bd9ac6,0x6aa80154,0x113800db,0x00000000}},	//   _jurn, _ক্লো, _уяты_, --, 
   {{0x9c7c1a48,0x29180083,0x7b640d30,0x27f96ba3}},	//   jače, eera_, ітне, durn_, 
   {{0xdb1806af,0x9c7c013a,0x00000000,0x00000000}},	//   _juvé, dače, --, --, 
   {{0x291843c4,0x63bc127b,0x27f80108,0x00000000}},	//   gera_, _ourn, furn_, --, 
   {{0x63bd9ac7,0x6da000f2,0x00000000,0x00000000}},	//   _nurn, _تموم, --, --, 
   {{0x7bc82959,0x9c7c2a57,0x00000000,0x00000000}},	//   _itfu, gače, --, --, 
   {{0x29198e3b,0x63bc005a,0xe69401c0,0x00000000}},	// [2bb50] bera_, _aurn, диты, --, 
   {{0x29199ac8,0x27f99ac9,0xf2dc06a3,0x63bd26d7}},	//   cera_, burn_, _žâ_, _burn, 
   {{0x9c7c0989,0x63bd9aca,0xf99c068c,0x7bc80175}},	//   bače, _curn, ctèa_, _jtfu, 
   {{0x63bcc74a,0xe3b8d8f9,0x00000000,0x00000000}},	//   _durn, ібі_, --, --, 
   {{0xdb1806af,0x9c7c0219,0x1aac03d4,0x00000000}},	//   _cuvé, načb, কুৰা, --, 
   {{0x63bd9acb,0xf4843425,0x21780006,0x00000000}},	//   _furn, _дубн, ойчы_, --, 
   {{0xb4d42274,0x63bd9acc,0x00000000,0x00000000}},	//   सरी_, _gurn, --, --, 
   {{0x63684685,0x29199acd,0xdcec02b1,0x6fc40166}},	//   _друг_, zera_, _īhāi, _nıce, 
   {{0x63bd9ace,0x29199acf,0x7bc8003c,0xb0cc2efd}},	//   _zurn, yera_, _atfu, _स्थग, 
   {{0xe6b801d9,0x9c7c16a3,0x29199ad0,0x80c806ff}},	//   _अल्ज, zače, xera_, सुदे, 
   {{0x29199ad1,0x63bc058a,0x99880210,0x00000000}},	//   vera_, _xurn, _opał_, --, 
   {{0x29199ad2,0xe1640137,0x00000000,0x00000000}},	//   wera_, _ىدەي, --, --, 
   {{0x4520045e,0x7bc82959,0xa9240308,0x4424004d}},	//   নাতক_, _etfu, ížov, ̉o_, 
   {{0x27f99ad3,0x291801c4,0xbea000fb,0x00000000}},	//   turn_, uera_, _яңыһ, --, 
   {{0x4c340323,0x47580962,0x9c7c013a,0x6d8c03b2}},	//   _хэлт, брая_, tače, bøar, 
   {{0x29199ad4,0xb8f04802,0xf7401575,0x63bc014f}},	//   sera_, _ह्_, несо, _rurn, 
   {{0x63bd9ad5,0x9c7c05ce,0xb4d40073,0x00000000}},	// [2bb60] _surn, rače, सरू_, --, 
   {{0x63bd9ad6,0x29180286,0x27f80008,0xc9659ad7}},	//   _purn, qera_, purn_, _хвой, 
   {{0x63bc0561,0x9c7c14b2,0xf9900375,0x78840022}},	//   _qurn, pače, _ארז_, rĩvé, 
   {{0x387c05d1,0xf99c4bb0,0x273400db,0x4424008f}},	//   ğurt_, ntèn_, _تۉرس, ĉo_, 
   {{0x63bc0198,0x399c00d2,0xf99c067c,0xa0b8004e}},	//   _wurn, lîsa_, itèn_, оглу_, 
   {{0x63bd9ad8,0x7860022e,0x00000000,0x00000000}},	//   _turn, _sеvi, --, --, 
   {{0x399c00d2,0xf99c00f2,0x35a002d5,0x63bc0108}},	//   nîsa_, ktèn_, _чарг, _uurn, 
   {{0x3d0c18cc,0x3cdc00fe,0x88e00154,0x00000000}},	//   त्ने_, _মাধৱ, বলিক, --, 
   {{0x9c7c01ef,0x00000000,0x00000000,0x00000000}},	//   kačc, --, --, --, 
   {{0x7c859ad9,0x399c00d2,0xdb18054e,0x00000000}},	//   зуме, kîsa_, _cuvî, --, 
   {{0x9c7d9ada,0x1b1807a2,0x00000000,0x00000000}},	//   dačc, ожны_, --, --, 
   {{0xaca0063f,0x00000000,0x00000000,0x00000000}},	//   _gwọk, --, --, --, 
   {{0x9f5c00d0,0x00000000,0x00000000,0x00000000}},	//   ctvá_, --, --, --, 
   {{0xdc74010b,0xb6980356,0xdce800ef,0x00000000}},	//   _оглы, _obâr, bidā, --, 
   {{0x7d199adb,0x7bc8003c,0xad201066,0xac9021f3}},	//   mets, _utfu, _سىيى, _пашш, 
   {{0x7d199adc,0x95d86575,0x9ba801d9,0x9f5802b5}},	//   lets, ждат_, _بختہ_, _ërä_, 
   {{0xe7840107,0xb8c4021f,0xeab801af,0x00000000}},	// [2bb70] хуро, _ىزدى, _эйњ_, --, 
   {{0x7d199add,0xb4d42274,0x6854044e,0x91ac004d}},	//   nets, सरे_, ሞክራስ, _trẻ_, 
   {{0x3d0c0a94,0xbb1806af,0xf3140139,0x00000000}},	//   त्ये_, boît, знеә_, --, 
   {{0x7d199ade,0xfafc02d3,0xa8a40166,0x99880210}},	//   hets, ngë_, _ярык, _upał_, 
   {{0x7d199adf,0xfafc0036,0x31300022,0x6d4401f4}},	//   kets, liës_, нҵар, öjak, 
   {{0x7d199ae0,0xdb24006a,0x00000000,0x00000000}},	//   jets, ösês, --, --, 
   {{0x7d199ae1,0xf3643460,0x09d800bc,0x00000000}},	//   dets, _етан, _भब्य, --, 
   {{0x0dc99ae2,0x2d801a48,0x752463e4,0xcfa80150}},	//   олий_, čjem_, _hajz, _ﺷﺎﻗﺒ, 
   {{0x7d199149,0x61e40491,0x6adc00bd,0xae18045e}},	//   fets, áilt, _ভালো, তম্ভ_, 
   {{0x7d199ae3,0x00000000,0x00000000,0x00000000}},	//   gets, --, --, --, 
   {{0x5f74004b,0x61e40024,0x9f5c02f0,0x00000000}},	//   _ګالر, šilt, stvá_, --, 
   {{0x7d1801e0,0xfafc00e8,0x09e4022e,0x00000000}},	//   aets, ggë_, момн, --, 
   {{0x7d199ae4,0xf99c0214,0x7aa001a9,0x00000000}},	//   bets, rtèn_, киюз, --, 
   {{0xd040013f,0x6f199ae5,0xb4d40cbf,0x7d180453}},	//   _felɔ, leuc, सरो_, cets, 
   {{0xf99c50b6,0x00000000,0x00000000,0x00000000}},	//   ptèn_, --, --, --, 
   {{0x6f1863b3,0x2efc002e,0x00000000,0x00000000}},	//   neuc, nguf_, --, --, 
   {{0xdbdc01e1,0x58dc00fe,0x00000000,0x00000000}},	// [2bb80] _láìt, _বাৰী, --, --, 
   {{0x9c7c0427,0xfafc01f5,0xa2a4033f,0xf99c5b42}},	//   lača, biës_, _औरब्, ntèl_, 
   {{0xdce80356,0xbb1800c7,0xdb240248,0x00000000}},	//   lidă, moîr, _ẹ̀tọ, --, 
   {{0x9c7c04b9,0x7d199ae6,0x6f18003e,0xfafc0549}},	//   nača, zets, jeuc, liër_, 
   {{0x6f180333,0xf99c007f,0x42182e0b,0x25740136}},	//   deuc, ktèl_, تزاج_, _كۇرس, 
   {{0x15b00075,0xdfd015f2,0xfafc0200,0x00000000}},	//   _مەقس, هيت_, zgë_, --, 
   {{0x6f1848b3,0x9f58025a,0xd5ac00dd,0xf4856658}},	//   feuc, _êrë_, _اہل_, _قافی, 
   {{0x9c7c0bb8,0x7d199ae7,0x7c3ca547,0x75240332}},	//   jača, wets, _àpri, _zajz, 
   {{0xb0cc00a5,0x9c7c2f61,0xdb180ffb,0xd34453b6}},	//   _स्वग, dača, _duvì, _سیوه_, 
   {{0xab640034,0xd9bc0011,0x2240000d,0x28d000cd}},	//   óżni, _অবলম, äiku_, तुमि, 
   {{0xfa1009bd,0xfafc0af9,0xdcf800de,0x00000000}},	//   িয়াল_, diër_, _skvē, --, 
   {{0x7d199ae8,0x9c7c0960,0x6f199ae9,0x6bd0036b}},	//   sets, gača, ceuc, کتیر, 
   {{0xf2d004ac,0x7d199aea,0x5eac00bd,0x25b801ab}},	//   כער_, pets, _ট্রে, _oirl_, 
   {{0x7d180240,0x1958969b,0x00000000,0x00000000}},	//   qets, чагы_, --, --, 
   {{0x7c6405c2,0x9c7c0d0f,0x752401ed,0xe8940166}},	//   _تاشل, bača, _rajz, варь, 
   {{0x25b80048,0xb4d40574,0x7c2c143a,0x9988054e}},	//   _airl_, सर्_, åbru, _braţ_, 
   {{0x25b80204,0xfafc0af9,0xab843d71,0x752401d3}},	// [2bb90] _birl_, biër_, _шушк, _pajz, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7524069c,0x6f193ae5,0x25b80204,0x399c00d2}},	//   _vajz, yeuc, _dirl_, lîso_, 
   {{0x3d0c1684,0x25b80129,0xe4a4033a,0x00000000}},	//   त्ते_, _eirl_, труо, --, 
   {{0xa84803e6,0xe8e00208,0xe2a80014,0x00000000}},	//   _فلیم_, _hiều_, ٘اون_, --, 
   {{0x25b99aeb,0xe8e0001e,0xa2d0033f,0x9c7c0306}},	//   _girl_, _kiều_, डुब्, zača, 
   {{0x6fc415b7,0x00e4030f,0x2b8406be,0x00000000}},	//   _bıca, رتوی, hıca_, --, 
   {{0xe8e00208,0x2b8403e0,0x00000000,0x00000000}},	//   _miều_, kıca_, --, --, 
   {{0xe8e0001e,0x2bd400c5,0x80c807af,0x9c7c01a6}},	//   _liều_, _भौजा, _स्के, vača, 
   {{0x4c699aec,0x611400c7,0x20240108,0xf1340116}},	//   зион_, _идуу, äsiä_, _تةرة, 
   {{0x9c7c00f3,0xf99c0ba1,0xfce400f1,0x6f199aed}},	//   tača, rtèl_, رځوي_, peuc, 
   {{0xf99c180f,0x00000000,0x00000000,0x00000000}},	//   stèl_, --, --, --, 
   {{0xb698054e,0x962800ef,0xf8d800cd,0x00000000}},	//   _scân, _jeņķ, भरूप, --, 
   {{0x2d58006a,0xdb18084c,0x9c7c6075,0xaf740023}},	//   _zêen_, _cuvâ, mačn, _ክህበና_, 
   {{0x9c7d9aee,0xfbc42db6,0xfafc0430,0x962800de}},	//   lačn, _रूपम, riër_, _leņķ, 
   {{0x28d04ead,0xe8e0004d,0x290c02e2,0x65b406be}},	//   _त्रि, _diều_, òdab_, mühə, 
   {{0x9c7c04b9,0x6b859aef,0xdcb80115,0xeaec01f9}},	// [2bba0] načn, _ijig, reĉe_, झणीत_, 
   {{0x6aa40928,0x291c0588,0x00000000,0x00000000}},	//   _izif, _úva_, --, --, 
   {{0x6b8401fa,0xa7a800fb,0x00000000,0x00000000}},	//   _kjig, _ойоҡ_, --, --, 
   {{0x9c7c0232,0x96280171,0x00000000,0x00000000}},	//   kačn, _beņķ, --, --, 
   {{0x9c7c15ad,0xb2e4009f,0x00000000,0x00000000}},	//   jačn, رّون_, --, --, 
   {{0x6fc40365,0x6b842220,0x9c7c0306,0x998801a6}},	//   _sıca, _ljig, dačn, _kraš_, 
   {{0xdfd19af0,0xbec00171,0x3cdc00cc,0xa4440244}},	//   جيب_, _čība, _মালৱ, _جێاو, 
   {{0x6aa4016e,0x6b840337,0x28d011bc,0x3f800254}},	//   _ozif, _njig, तुति, õku_, 
   {{0x9c7c389e,0x6aa4895d,0xd36c215c,0x98a000dc}},	//   gačn, _nzif, _بۇن_, _mahā_, 
   {{0xc0a96265,0x5d549780,0x6b84058a,0xd12c0a81}},	//   _فاضل_, ткот, _ajig, _وۅن_, 
   {{0x6aa4180e,0x00000000,0x00000000,0x00000000}},	//   _azif, --, --, --, 
   {{0xdb0c067c,0x9c7c0dfe,0xfd6001c0,0x00000000}},	//   _miaç, bačn, тнүү, --, 
   {{0xf99c0699,0x6b840de2,0x2484013f,0xceb800bc}},	//   stèm_, _djig, _ɛmma_, teře_, 
   {{0x6aa40084,0x2b844953,0x6b840521,0xbc7000d1}},	//   _dzif, rıca_, _ejig, _مۇخب, 
   {{0x6aa40928,0x9c7c0306,0xf99c0100,0x00000000}},	//   _ezif, mačo, ltèk_, --, 
   {{0x6b8402d3,0x5a340fbe,0x9c7c02fb,0xf99c02e2}},	//   _gjig, _анит, lačo, otèk_, 
   {{0xf99c020c,0xceb80118,0x00000000,0x00000000}},	// [2bbb0] ntèk_, peře_, --, --, 
   {{0xdb0c067c,0x9c7c0122,0x8e7c01e4,0xe8e00208}},	//   _biaç, načo, kaŝn, _tiều_, 
   {{0x9c7c0232,0xf48413d6,0x45202baf,0x69c00115}},	//   začn, хуан, নাংক_, ŭmet, 
   {{0x5275646b,0xe3b19af1,0x786001a9,0x9c7c245b}},	//   кулу, مرن_, _fеvr, hačo, 
   {{0x225809fe,0x9c7c0122,0x80c80c58,0xdbdc0241}},	//   ницы_, xačn, _ৰাজ্, _láàt, 
   {{0x86581203,0x9c7ccc1a,0xdb0c0798,0x0680010a}},	//   _חדשי, vačn, _fiaç, _тӳсн, 
   {{0xe8e007ae,0x9c7c0f91,0x50440137,0x241807e6}},	//   _hiểu_, dačo, тейб, _поры_, 
   {{0x9c7d9af2,0xe8e007ae,0x00000000,0x00000000}},	//   tačn, _kiểu_, --, --, 
   {{0x2c44013f,0x256401ed,0xee719af3,0xc330011a}},	//   mɑdi_, _föld_, ыңды, _דון_, 
   {{0x9c7d9af4,0x7994009a,0xa19401fe,0xe8e00051}},	//   račn, _nkxw, _бауч, _miểu_, 
   {{0x80c80807,0x9c7c01f1,0x4b88010b,0x00000000}},	//   _स्टे, sačn, дйнн_, --, 
   {{0x9c7c15ad,0x628c0034,0x256401ed,0x00000000}},	//   pačn, żnoś, _zöld_, --, 
   {{0x9f5c026c,0x5c7000d1,0x00000000,0x00000000}},	//   duvè_, иһәт, --, --, 
   {{0x1cc049a6,0x88e0009e,0x3ea005d1,0xadb40451}},	//   _ཀུར_, _বাহক, ükte_, _ڪهڙا_, 
   {{0x256403e0,0xe7080014,0xcc880108,0x1ae000fe}},	//   _jöle_, ى۪دن_, _юбке_, _ভাৰা, 
   {{0xe8e007ae,0x6b840165,0x69c02d37,0x24780023}},	//   _biểu_, _ujig, ímes, _ጠላማት_, 
   {{0x6aa46105,0x3d0c00dc,0x2d5800d8,0x4528030c}},	// [2bbc0] _uzif, त्वे_, _lêem_, мжан_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x98a00374,0x2c440134,0x00000000,0x00000000}},	//   _tahā_, fɑdi_, --, --, 
   {{0x69c59af5,0xdb0c0798,0x9c7c39e2,0x00000000}},	//   _kuie, _viaç, začo, --, 
   {{0x69c40998,0xaca002e3,0xd1b80092,0xdb2000e5}},	//   _juie, faịl, _ሲገቡ_, íték, 
   {{0x25659af6,0x69c45934,0x80a40037,0x00000000}},	//   _böle_, _muie, _छरदे, --, 
   {{0xdd94774d,0x69c4d2aa,0x02c412b9,0xb978008d}},	//   ғаны, _luie, _айбо, ונסי, 
   {{0x03a49cff,0x69c40156,0x2d580798,0x1aac0154}},	//   _рибо, _ouie, _dêem_, কুয়া, 
   {{0xf770025f,0x9c7c0232,0xaca001f2,0x69c40356}},	//   יקה_, tačo, baịl, _nuie, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69c59af7,0xfc640801,0x212c00a3,0x409400c7}},	//   _auie, тъпн, _iadh_, _ррат, 
   {{0x69c59af8,0x200c0455,0xa3e41f13,0x212d9af9}},	//   _buie, _iqdi_, पीय_, _hadh_, 
   {{0x7c3c01fa,0x69c4054e,0x9c7c0419,0xf99000ae}},	//   _šprd, _cuie, pačo, لبس_, 
   {{0x69c533c8,0x6d443453,0x3ea003b2,0x00000000}},	//   _duie, öjat, ýktu_, --, 
   {{0x212c069c,0x69c19afa,0x7b6402dd,0xd1b8001f}},	//   _madh_, ímer, _атпе, _ሲገባ_, 
   {{0x3d0c70b0,0x212d3020,0x69c40129,0x00000000}},	//   त्रे_, _ladh_, _fuie, --, 
   {{0x69c59afb,0x15143f6e,0xe5c55c7d,0x69c001e4}},	// [2bbd0] _guie, лдая, асхо, ŭmer, 
   {{0x212d9afc,0x9f5c0ffb,0x1cc0031c,0x200c022e}},	//   _nadh_, suvè_, _ཀུས_, _oqdi_, 
   {{0xe2c801e2,0x00000000,0x00000000,0x00000000}},	//   ږونو_, --, --, --, 
   {{0xe8e007ae,0x256403e0,0x7cc806be,0x00000000}},	//   _tiểu_, _röle_, lәrd, --, 
   {{0x212c2df0,0x61e00042,0x317002dd,0x25640205}},	//   _badh_, _cwml, ағат, _söle_, 
   {{0x3f84033b,0x212c00a3,0x6fc406be,0xa4d400d4}},	//   _ajou_, _cadh_, _qıco, _ворі, 
   {{0x101400c6,0x212c01c3,0x00000000,0x00000000}},	//   ابتد, _dadh_, --, --, 
   {{0x0c241d56,0x212c3e7c,0xd1041bf9,0x2d580798}},	//   ҳмон, _eadh_, _रावण_, _vêem_, 
   {{0x3ea41529,0x200c0455,0x212c0100,0x3f840af9}},	//   _czot_, _eqdi_, _fadh_, _djou_, 
   {{0x22840323,0x212c0067,0x69c401ab,0xcda80271}},	//   _тусг, _gadh_, _ruie, عهده_, 
   {{0x69c59afd,0x9c7c0841,0x8e7c0115,0x4c1401d9}},	//   _suie, lačj, paŝo, اکتھ_, 
   {{0x69c59afe,0x4e340736,0xe8e00051,0x5184014b}},	//   _puie, _معتز, _miễu_, _руға, 
   {{0x69c59aff,0xe8e0001e,0xdcb800df,0x00000000}},	//   _quie, _liễu_, reĉa_, --, 
   {{0xb698019f,0xdb1804ce,0x7c5400aa,0x7c3c107d}},	//   _icâh, _nuvæ, _څلور_, _špre, 
   {{0xdb4c0133,0xa9740023,0x00000000,0x00000000}},	//   سێی_, _ኣብቂዑ_, --, --, 
   {{0xfbd0025f,0x69c59b00,0xc7959b01,0x0f2000ab}},	//   _פתח_, _tuie, ургы, _मसोस_, 
   {{0x36659b02,0x05a80024,0x53b80562,0x00000000}},	// [2bbe0] гато_, евай_, ेदनश, --, 
   {{0x04441e28,0xe8e00051,0x00000000,0x00000000}},	//   лезн, _biễu_, --, --, 
   {{0x212c0e89,0x6fbc00e1,0x00000000,0x00000000}},	//   _radh_, _लंगू, --, --, 
   {{0xb824a39e,0x25e803f3,0x7c3c54fc,0xe8e0004d}},	//   _союз_, _चौथी_, _ápre, _diễu_, 
   {{0x96b80220,0x320c00a2,0x9c7c0419,0xcfcc313e}},	//   _ауру_, gtgy_, vačm, _ﻗﺎﺭﺗ, 
   {{0xb340025c,0x00000000,0x00000000,0x00000000}},	//   ħħar, --, --, --, 
   {{0xfafc044e,0xe8e00208,0x9c7c0419,0x00000000}},	//   dhën_, _giễu_, tačm, --, 
   {{0x9f559b03,0x44280441,0x2d840115,0xe1f80b01}},	//   рвич, _isb_, _ajne_, _аҳд_, 
   {{0x998801f1,0x44299b04,0xdcf400d7,0x00000000}},	//   _hrať_, _hsb_, ďaľu, --, 
   {{0x44280165,0xf288010f,0x00000000,0x00000000}},	//   _ksb_, _אָבֿ, --, --, 
   {{0x9c7c0bb8,0x44280438,0xe7b404af,0x3f840100}},	//   mačk, _jsb_, ंगाप, _tjou_, 
   {{0xda3409fe,0x44294112,0x705065fd,0x290c00a3}},	//   аемы, _msb_, _دنما, òdan_, 
   {{0x442802fa,0x63b80030,0xa3e4e858,0x7f9c0200}},	//   _lsb_, ívny, पीत_, jëqi, 
   {{0x9c7c0bb8,0x44299b05,0x2b406730,0x9f5800e4}},	//   načk, _osb_, _enic_, _êrâ_, 
   {{0x44299b06,0x37a99b07,0x00000000,0x00000000}},	//   _nsb_, етан_, --, --, 
   {{0x7c299b08,0x9c7c245b,0xf84401c6,0x00000000}},	//   _isfr, hačk, вүүд_, --, 
   {{0x44280591,0x55759b09,0x6458dd44,0xa5f84981}},	// [2bbf0] _asb_, агат, øvin, лету_, 
   {{0x9c7c08ad,0x44299b0a,0x998800d0,0x00000000}},	//   jačk, _bsb_, _brať_, --, 
   {{0x9c7c0232,0x44299b0b,0x399c00d2,0x61fc0171}},	//   dačk, _csb_, jîsi_, _ārla, 
   {{0x44299b0c,0x9258023a,0x603c054e,0x91d40006}},	//   _dsb_, кает_, _mămă, ацкі, 
   {{0x44299b0d,0x9c7c00ef,0x00000000,0x00000000}},	//   _esb_, fačk, --, --, 
   {{0x9c7d9b0e,0xfafc0023,0x7c2808a5,0xe8e00051}},	//   gačk, xhën_, _osfr, _tiễu_, 
   {{0xd1e802d3,0x607c0092,0x205402e8,0x10a401a9}},	//   _ሚእቲ_, _እንጨት_, йтър, шикн, 
   {{0xb23400ec,0x00000000,0x00000000,0x00000000}},	//   _مڃتا_, --, --, --, 
   {{0x9c7d354e,0x62359b0f,0xfde4481c,0x91b85c37}},	//   bačk, _лету, адык_, _агат_, 
   {{0x8d543869,0x4428145e,0x399c00d2,0xdce81432}},	//   ртич, _ysb_, bîsi_, ıoğl, 
   {{0xcb68156b,0xe8e007ae,0x1f644d4c,0x9e659b10}},	//   ване_, _hiệu_, ркөм, لاین, 
   {{0xfafc044e,0x88e0045e,0xe8e0004d,0x2564000d}},	//   shën_, _বাইক, _kiệu_, _möla_, 
   {{0xe7e88cce,0x7c2806ed,0x58dc0154,0x5c7401e0}},	//   टीना_, _esfr, _বাড়ী, иҙәр_, 
   {{0x8d180050,0xded4001f,0xdb18000d,0x00000000}},	//   _شٲعر_, _የስነ_, _auvä, --, 
   {{0xe8e007ae,0x7d741ec7,0x9f5800e4,0x87740798}},	//   _liệu_, _خمور_, _êrã_, аѓаш, 
   {{0x2b419b11,0x15b801e0,0x7f9c036e,0xdb1402d2}},	//   _unic_, ғыуы_, tëqi, _óaðs, 
  
   {{0x44299b12,0xc4e40b32,0xe8e001fb,0xebe001ec}},	// [2bc00] _ssb_, ижай, _niệu_, _тоқп, 
   {{0x8458a2e6,0x6e28030d,0x44299b13,0x96b80228}},	//   крет_, _msgb, _psb_, уусу_, 
   {{0x9c7c05ce,0x07a59b14,0xc7a4a401,0x7f9c0200}},	//   vačk, _ванн, _винк, sëqi, 
   {{0x44280098,0x6e2802d0,0x7c2c0388,0x9988013a}},	//   _vsb_, _osgb, æbri, _vrať_, 
   {{0x44299b15,0x9c7c0306,0x67259b16,0x6234228c}},	//   _wsb_, tačk, meij, селу, 
   {{0x44299b17,0x66059b18,0xe8e0001e,0x35a001c0}},	//   _tsb_, muik, _diệu_, _маяг, 
   {{0x442862e8,0x9c7c0bb8,0x66059b19,0xb02418fd}},	//   _usb_, račk, luik, لكوم_, 
   {{0x9c7c3858,0xf99c7d47,0x3dd80183,0x603c054e}},	//   sačk, ltèt_, _দিবল, _rămă, 
   {{0x9c7d9b1a,0xe234004b,0xc0c00075,0x00000000}},	//   mači, _دکاب, _һәқи, --, 
   {{0x9c7d9b1b,0x40940640,0xf99c180f,0x67248ef4}},	//   lači, _крет, ntèt_, heij, 
   {{0x66041e0d,0xe7e8012c,0xdcb800df,0x67240108}},	//   huik, टीमा_, reĉo_, keij, 
   {{0x66059b1c,0x9c7c70f0,0x00000000,0x00000000}},	//   kuik, nači, --, --, 
   {{0x7f400eda,0x67240295,0x66040140,0xf99c007f}},	//   _inoq, deij, juik, ktèt_, 
   {{0xb698145e,0x603c0311,0x9c7c04a7,0x66059b1d}},	//   _gbây, _tămă, hači, duik, 
   {{0x9c7c05a1,0x5bf4121e,0xd7c8034c,0x9c64004b}},	//   kači, _آبا, اوره_, _دهغو, 
   {{0x7bd99b1e,0x9c7c07f5,0xadc00248,0x660403a0}},	//   mptu, jači, _atẹj, fuik, 
   {{0xf99c0ba1,0x9c7c82c7,0x79a406ed,0x66040124}},	// [2bc10] guèc_, dači, _врне, guik, 
   {{0xdce800bc,0x00000000,0x00000000,0x00000000}},	//   vidě, --, --, --, 
   {{0x7f400472,0x00000000,0x00000000,0x00000000}},	//   _onoq, --, --, --, 
   {{0x9c7c1326,0x660401f5,0xf99c0561,0x51f406c2}},	//   gači, buik, rtèu_, مستر, 
   {{0x108404a2,0xefcc02d3,0xf99c068c,0x56e001ec}},	//   ﻪﺭﺩﯨ, _ኣብያ_, stèu_, _мұңғ, 
   {{0x7f4066d4,0xf99c0ba1,0xfafc0240,0x49182e04}},	//   _anoq, ctèt_, dhëm_, म्पो_, 
   {{0x25659b1f,0x7bcc215a,0xf99c35f5,0x9c7c00c0}},	//   _köln_, íbul, ltès_, bači, 
   {{0x9c7c0331,0x6458023a,0xcf445d4e,0x7bd80356}},	//   cači, ävie, сний, dptu, 
   {{0xf99d9b20,0x7bd8003a,0x14400092,0xcdc400cf}},	//   ntès_, eptu, _የሚሠሩ, حۇتۇ_, 
   {{0x1b1402a6,0x7f4001b3,0x7c3c1dd5,0xecc00228}},	//   _তোলে_, _enoq, _špra, өшүү, 
   {{0x6724009f,0x00000000,0x00000000,0x00000000}},	//   yeij, --, --, --, 
   {{0x8e399b21,0x00000000,0x00000000,0x00000000}},	//   _مستر_, --, --, --, 
   {{0x672420e5,0x8e7c01e4,0x90d40248,0xdce803b9}},	//   veij, kaŝi, _nǹk, aldı, 
   {{0x2bcc2c35,0x290d8c43,0x9c7c1b24,0x66059b22}},	//   _संपा, üda_, zači, vuik, 
   {{0x6d419b23,0x8e7c01e4,0x1cc00327,0x672401f5}},	//   _inna, daŝi, _ཀུག_, teij, 
   {{0xc4840184,0x7c3c0077,0x290c0034,0x66059b24}},	//   ҙлек, _ápra, żda_, tuik, 
   {{0xdb180793,0xc4841cd1,0x8e7c01e4,0xf1a40b3c}},	// [2bc20] _ptvö, әлек, faŝi, गतान, 
   {{0x66042595,0x8e7c01e4,0x00000000,0x00000000}},	//   ruik, gaŝi, --, --, 
   {{0x321c1bb7,0x6d419b25,0x66059b26,0x9c7cb972}},	//   _apuy_, _mnna, suik, tači, 
   {{0xaca002e3,0x82687665,0xc2459b27,0xf99c068c}},	//   _atịk, лаев_, йнек, stèt_, 
   {{0x6d419b28,0x9c7c33fc,0xdb0c020c,0xf7700150}},	//   _onna, rači, _dhaè, _ءاپ_, 
   {{0x04440a31,0x29199b29,0xf99c04cc,0x7bd99b2a}},	//   _легн, nfra_, ltèr_, yptu, 
   {{0x291805d5,0x49189417,0x9c7d9b2b,0x32000055}},	//   ifra_, म्यो_, pači, _ājye_, 
   {{0x6d419b2c,0xf99c4c6e,0xc32c00d1,0x29186809}},	//   _anna, ntèr_, _سەت_, hfra_, 
   {{0x1cc00135,0x29181445,0xdd940150,0x00000000}},	//   _ཀུང_, kfra_, жапы, --, 
   {{0x6d4000d8,0xe29801ec,0x71d4011a,0x00000000}},	//   _cnna, _бағ_, _לומד_, --, 
   {{0xfafc069c,0x409400c6,0x291801bf,0x65b001f4}},	//   shëm_, _الضر, dfra_, mähd, 
   {{0x6d419b2d,0x7b6478a7,0x91e400b5,0x7f419b2e}},	//   _enna, стое, _mmのc, _unoq, 
   {{0x7bd8011c,0x29199b2f,0x2b443a49,0x00000000}},	//   sptu, ffra_, чээг, --, 
   {{0x7bd8716e,0x291800b5,0xdd919b30,0x65b001f4}},	//   pptu, gfra_, _توت_, nähd, 
   {{0x8e7c0115,0x90780023,0x00000000,0x00000000}},	//   vaŝi, _እንደሊ_, --, --, 
   {{0x9f5c0268,0xf7719b31,0xc6200011,0x00000000}},	//   nuvà_, ساز_, নিনা_, --, 
   {{0x7bc800ec,0x6d419b32,0x65b00108,0x9ab40055}},	// [2bc30] _hufu, _ynna, kähd, bdāṃ, 
   {{0x7bc99b33,0x65b0023a,0xf99c354d,0xe9d86ea9}},	//   _kufu, jähd, rtès_, _اذيت_, 
   {{0x321c0af9,0xf99d9b34,0x7aec4380,0x00000000}},	//   _spuy_, stès_, oact, --, 
   {{0x7bc99b35,0x2564049f,0x1dc813da,0x9f5c08e5}},	//   _mufu, _höll_, रदात, juvà_, 
   {{0x2bcc375c,0x7bc80084,0xdb0c0022,0x944401d3}},	//   _संभा, _lufu, _chaé, _ڈھان, 
   {{0xdb0c034c,0x7aec010a,0x00000000,0x00000000}},	//   _dhaé, hact, --, --, 
   {{0x7bc8036b,0xdb0c00e4,0x7aec0d27,0x2564000d}},	//   _nufu, _ehaé, kact, _möll_, 
   {{0x9c7c2333,0x0e640395,0x00000000,0x00000000}},	//   naču, жкин, --, --, 
   {{0x7bc99b36,0x8d74c9a4,0x29180142,0x00000000}},	//   _aufu, قادا, yfra_, --, 
   {{0x8d750f5e,0x7bc99b37,0x8d58084c,0x7aec01f5}},	//   تابا, _bufu, ршит_, eact, 
   {{0x8b2424b1,0x7bc96289,0x4b880116,0x6d400051}},	//   одне, _cufu, ийон_, _vnna, 
   {{0x920c1d34,0x7aed9b38,0x7bc80526,0x6d400198}},	//   _समाज_, gact, _dufu, _wnna, 
   {{0x8d7454b4,0x7bc80ffb,0x65b0b6a5,0xc9a80261}},	//   _واتا, _eufu, lähe, ивме_, 
   {{0x7aec074d,0x7bc99b39,0x6d4026de,0x645803cd}},	//   aact, _fufu, _unna, øvik, 
   {{0x7bc99b3a,0x29180ff7,0x65b003fa,0x00000000}},	//   _gufu, rfra_, nähe, --, 
   {{0x7aec074d,0xf7400107,0x49c8337e,0x2918b85b}},	//   cact, месо, _клин_, sfra_, 
   {{0x2564049f,0xf99c04cc,0x7bc80112,0x24c000fe}},	// [2bc40] _föll_, rtèr_, _zufu, েৰাহ, 
   {{0x6aa5814b,0xf99ce74b,0x65b00139,0x00000000}},	//   _iyif, stèr_, kähe, --, 
   {{0x42c898a3,0xf99c068c,0xa3e40243,0x03940276}},	//   аген_, ptèr_, पीं_, ордя, 
   {{0x9f5c012c,0x88e000cc,0xc62000fe,0xc4a8000d}},	//   prvé_, _বাটক, নিবা_, _करीख, 
   {{0x65b0023a,0x9c7c00d0,0x442400d0,0x73300228}},	//   tähd, lačt, ňo_, بىنا, 
   {{0xaca027dd,0x7aec084c,0x6aa40526,0x65b004e6}},	//   _atọk, zact, _myif, fähe, 
   {{0x7aec0014,0xf99c020c,0x9c7c13d5,0x65b0005b}},	//   yact, kuèn_, načt, rähd, 
   {{0x7bc99b3b,0x7aed9b3c,0x6aa41cdf,0x65b0005b}},	//   _rufu, xact, _oyif, sähd, 
   {{0x7bc99b3d,0x6aa59b3e,0x3ea16da4,0x2614000d}},	//   _sufu, _nyif, ækt_, näo_, 
   {{0xdb0c20ef,0x7bc8054e,0x7aec0210,0x00000000}},	//   _chaî, _pufu, wact, --, 
   {{0x7aed9b3f,0x6aa4cf3e,0x1ee80edf,0x7bc80067}},	//   tact, _ayif, _هوای_, _qufu, 
   {{0x6aa40230,0x7bc802b9,0xb098011a,0x00000000}},	//   _byif, _vufu, _דיבר, --, 
   {{0x6aa40230,0x657c009a,0x64480077,0x7bc80014}},	//   _cyif, _omrh, _ádif, _wufu, 
   {{0x7aed9b40,0x7bc99b41,0x7c3c0005,0x9f5800e4}},	//   sact, _tufu, _ápro, _írâ_, 
   {{0x6aa40921,0x7bc80194,0x67d40137,0x63a002d0}},	//   _eyif, _uufu, досу, _okmn, 
   {{0x2bcc04fa,0x657c026c,0x256401c7,0x7d1801a4}},	//   _संता, _amrh, _wöll_, lfts, 
   {{0x7c38072b,0xf99c0100,0xb8c40c75,0x00000000}},	// [2bc50] lvtr, trèd_, _وزدى, --, 
   {{0x78440323,0xdb0c0109,0x7d181a80,0xd3700451}},	//   _дэмж, _khaï, nfts, ڙها_, 
   {{0x95c80046,0xd2a8151e,0x9c7c00d7,0x3448870c}},	//   руға_, әкле_, mačs, шчан_, 
   {{0xe3b19b42,0x65b016ca,0x8898123b,0x77400345}},	//   نرن_, vähe, _לבתי, _تێرم, 
   {{0xd9340023,0x313000c7,0x72280108,0x00000000}},	//   _ብምትሕ, мҵар, рцев_, --, 
   {{0x2d5805e4,0xaca001f2,0x65b00037,0x00000000}},	//   _lêer_, _stọk, tähe, --, 
   {{0xfbc404fa,0x2bcc07d0,0x28d0012d,0x00000000}},	//   _रंगम, _संधा, तुटि, --, 
   {{0x8e7c01e4,0x00000000,0x00000000,0x00000000}},	//   kaŝt, --, --, --, 
   {{0xc3301229,0xafe0036b,0x65b03626,0xdea401b9}},	//   _און_, чоқл, sähe, ویمی, 
   {{0x6aa40223,0xceb8012c,0xbff80183,0x62240131}},	//   _ryif, neři_, _আহৰণ_, _تىكل, 
   {{0x6aa402b4,0x8c459b43,0x9c7c02f0,0x00000000}},	//   _syif, чене, dačs, --, 
   {{0x82600137,0x00000000,0x00000000,0x00000000}},	//   _تۇۇن, --, --, --, 
   {{0xf1c0003d,0x8ac4036b,0x998808a4,0x6f1801f0}},	//   poġġ_, оққа_, _draž_, mfuc, 
   {{0x6aa407a8,0x6e386f4f,0x6f1819f5,0x8274010f}},	//   _vyif, mvub, lfuc, לערע_, 
   {{0x2564049f,0xf99c00f2,0xbd301411,0x8e7c010f}},	//   _följ_, muèl_, _سىيع, raŝu, 
   {{0x6f1961cb,0x06c805f5,0xf1c80b7c,0xf99c0ba1}},	//   nfuc, сгай_, ादान, grèb_, 
   {{0x6aa42939,0x4488506f,0x056400a7,0x6e381418}},	// [2bc60] _uyif, әбен_, пван, nvub, 
   {{0xca74022e,0x9f580022,0xf99c02e2,0x09e00011}},	//   _qayе, _ërö_, nuèl_, _বিপা, 
   {{0xc3259b44,0xdb0c00e4,0x1cc0031c,0xb3d400cc}},	//   змек, _ohaì, _ཀུབ_, _হিউজ, 
   {{0x6448003d,0xd37802bf,0xf99c020c,0x00000000}},	//   _ġdid, очі_, huèl_, --, 
   {{0x9c7c0427,0xdcb80115,0x46380212,0x00000000}},	//   načr, reĉi_, _учня_, --, 
   {{0x66059b45,0x6e380af2,0x657c00f1,0x7d000cad}},	//   mrik, dvub, _umrh, _mírà, 
   {{0xa4880014,0x6f180268,0x66045794,0xf99c007f}},	//   _بێال_, ffuc, lrik, duèl_, 
   {{0x66040fac,0x00000000,0x00000000,0x00000000}},	//   orik, --, --, --, 
   {{0xe8e007ae,0x66059b46,0x40c805d9,0x14400092}},	//   _chịu_, nrik, _هوءَ_, _የሚሰሩ, 
   {{0x64487cfb,0x66040254,0xe05800f1,0x00000000}},	//   _àdis, irik, _ویشت_, --, 
   {{0x66059b47,0x9b9508fc,0x9c7c02f0,0x00000000}},	//   hrik, динц, vačs, --, 
   {{0x66059b48,0xa3e425c9,0x491807f7,0x7c38007c}},	//   krik, पीए_, म्सो_, rvtr, 
   {{0xfaa40107,0x00000000,0x00000000,0x00000000}},	//   яшон, --, --, --, 
   {{0xa9c529dd,0x66059b49,0xdb0d9b4a,0x8e7c01e4}},	//   есск, drik, _ciaò, raŝt, 
   {{0x66059b4b,0x46d80521,0x9c7d7a20,0xe7e80073}},	//   erik, _ọzụz, račs, टीला_, 
   {{0x7ac48da9,0x8e7c0115,0x00000000,0x00000000}},	//   _эске, paŝt, --, --, 
   {{0x66059b4c,0x7d0001e1,0x9f5800e4,0x6458005b}},	// [2bc70] grik, _gírà, _ërõ_, ävin, 
   {{0xdb0c007b,0xefc80092,0x00000000,0x00000000}},	//   _mhaí, ጠረዥ_, --, --, 
   {{0x66059b4d,0xb8640b24,0x491000bc,0x00000000}},	//   arik, _رادو, _तातो_, --, 
   {{0x1cc01efe,0x2bcc071e,0xb698019f,0x3ea40214}},	//   _ཀུན_, _संसा, _ndâg, _oyot_, 
   {{0xe1f8005e,0x3ea4003e,0xceb80118,0xc3c0104e}},	//   згі_, _nyot_, peři_, төрл, 
   {{0x09e009bd,0x6e380083,0x10a46e1f,0xe3b0075e}},	//   _বিমা, vvub, милн, _ەرك_, 
   {{0xdb0c0022,0x234800d1,0x00000000,0x00000000}},	//   _ahaí, غلۇپ_, --, --, 
   {{0x28a4033f,0xe8e00051,0xa0280145,0x00000000}},	//   _खुफि, _phịu_, سسىك_, --, 
   {{0x09e08961,0xf77c0598,0xdb0c0077,0x6448a547}},	//   _বিভা, _mmç_, _chaí, _àdir, 
   {{0x9e6400c6,0x91800137,0x6f18045a,0xa3e40401}},	//   عاين, _جۇتۇ, sfuc, पीक_, 
   {{0x61fc005f,0x65b001f4,0x00000000,0x00000000}},	//   _ārli, näha, --, --, 
   {{0x66059b4e,0xc8e480f3,0xe0d00014,0x00000000}},	//   yrik, कर्म_, _لٲے_, --, 
   {{0x2bcc0412,0x00000000,0x00000000,0x00000000}},	//   _संवा, --, --, --, 
   {{0xdb0c0005,0x66059b4f,0xf99c0ba1,0x98780240}},	//   _diañ, vrik, quèl_, _ከስምዑ_, 
   {{0x07a42c9d,0x29047236,0x47580c9e,0x66059b50}},	//   давн, ğma_, орая_, wrik, 
   {{0x29046654,0xf99c0ba1,0x85e800d4,0x00000000}},	//   şma_, trèc_, ждав_, --, 
   {{0x66059b51,0x63b40124,0x00000000,0x00000000}},	// [2bc80] urik, ҵәах, --, --, 
   {{0x66059b52,0x25659b53,0x2ca40493,0xfafc0240}},	//   rrik, _köli_, _kynd_, nkën_, 
   {{0x66040641,0x00000000,0x00000000,0x00000000}},	//   srik, --, --, --, 
   {{0x2ca59b54,0x491802f8,0xf77c0598,0xfbd00677}},	//   _mynd_, म्रो_, _gmç_, דתא_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x1ae00116,0x00000000,0x00000000,0x00000000}},	//   _ﺋﯩﺠﺮ, --, --, --, 
   {{0xdb0c0332,0xa6b000cc,0xb8740092,0xf0380092}},	//   _shaí, _কলিট, _አድጓል_, _በክረም, 
   {{0xb140728c,0x22e40133,0x8fd40139,0xf8b0011a}},	//   енәл, _سترێ, хәфә, כשו_, 
   {{0xfafc036e,0x230801e2,0x00000000,0x00000000}},	//   fkën_, _وتړي_, --, --, 
   {{0x7c84b6f6,0xdb0c0789,0x3104004e,0x2bcc1223}},	//   думе, _riañ, _онуп_, _संशा, 
   {{0xcfa868cf,0xdb0c030a,0xdce800d7,0x00000000}},	//   _کالم_, _siañ, podľ, --, 
   {{0xdb0c0798,0xc1b000fb,0x1a640345,0x00000000}},	//   _thaí, _яҙһы, فیعی_, --, 
   {{0x1cc00003,0xfafc0023,0xee3401c0,0x7e98007b}},	//   _ཀུམ_, dhët_, _онц_, _بنشر_, 
   {{0xdd90021a,0x2ca40cfd,0xdb0c0077,0xded40023}},	//   _حوت_, _fynd_, _viañ, _ከድኩ_, 
   {{0xb8d405ba,0x6458023a,0x2564010e,0x00000000}},	//   _जर_, ävil, _göli_, --, 
   {{0x65b001f4,0x00000000,0x00000000,0x00000000}},	//   väha, --, --, --, 
   {{0xdcb801e4,0x58d48e3c,0x00000000,0x00000000}},	// [2bc90] reĉu_, _попт, --, --, 
   {{0xaab860ee,0x9998012d,0x65b001f4,0x00000000}},	//   _غدير_, żyło_, täha, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x92940006,0xb90800e5,0x65b00254,0x00000000}},	//   наец, _ازکم_, räha, --, 
   {{0x69d80219,0x65b00108,0xb86402f2,0xfafc036e}},	//   _čvek, säha, _راگو, ykën_, 
   {{0xc620009e,0x00000000,0x00000000,0x00000000}},	//   নিশা_, --, --, --, 
   {{0x45280327,0x8fa400cf,0x4fa42b97,0x00000000}},	//   _ཤྲིར_, наке, никв, --, 
   {{0x2ca40204,0xa3e44142,0x65b00112,0x00000000}},	//   _rynd_, पीओ_, nähn, --, 
   {{0x2eec3371,0x256401b8,0x6fc406be,0x8d640150}},	//   _vegf_, _söli_, _qıcq, евпе, 
   {{0x9c7c12fe,0x65b0002f,0x7520022e,0x00000000}},	//   rbčn, hähn, еnzi, --, 
   {{0xfafc0240,0x00000000,0x00000000,0x00000000}},	//   rkën_, --, --, --, 
   {{0xfafc036e,0x600801ec,0x00000000,0x00000000}},	//   dhës_, _інім_, --, --, 
   {{0x2ca40204,0xe92c025c,0xfc480166,0xe9841870}},	//   _wynd_, _སྲུབ_, _abíı_, ناسۋ, 
   {{0x2ca4037e,0xf99c0ba1,0xad600451,0x00000000}},	//   _tynd_, trèa_, _ڳاڙه, --, 
   {{0x4c6801c0,0xfafc0240,0x429c0092,0x23980010}},	//   _хийн_, thët_, ቃሚነት_, lčje_, 
   {{0x29d4025a,0xc7a56e9e,0x07a4109a,0x6458005b}},	//   _täa_, хибк, хабн, ävim, 
   {{0x290c067c,0x23980427,0x060843c2,0x66e0013a}},	// [2bca0] òdas_, nčje_, янак_, jáků, 
   {{0xba9823e4,0xfafc0023,0x66e001ef,0x00000000}},	//   _מספי, shët_, dáků, --, 
   {{0x76400882,0x9c7c0100,0xfafc00e8,0xe34000e4}},	//   ānya, jbčl, kkël_, _ẽñep, 
   {{0x273400f7,0x00000000,0x00000000,0x00000000}},	//   _جۉرس, --, --, --, 
   {{0x62341142,0x7a380030,0x932401d3,0x00000000}},	//   телу, mätá, ئرمن, --, 
   {{0x61e400a8,0x64580162,0x00000000,0x00000000}},	//   ţilo, øvis, --, --, 
   {{0x443cc187,0x10a8004b,0x00000000,0x00000000}},	//   _ét_, وږمۍ_, --, --, 
   {{0x7c3c00dd,0x27ec0419,0x30100395,0x00000000}},	//   _ápri, ádny_, удър, --, 
   {{0xfafc0023,0xc24402e8,0x43940150,0x7cc803e3}},	//   zhës_, _янак, _жаңс, lәri, 
   {{0xd00c0451,0x3ea800e2,0x65b0002f,0x00000000}},	//   _ڀڄي_, ābt_, zähn, --, 
   {{0x61e19b55,0xfafc0023,0xa3e402ab,0x00000000}},	//   _html, xhës_, पीच_, --, 
   {{0xf99c8a69,0x65b000b0,0x22440254,0xfafc0200}},	//   grèn_, käho, _krmk_, ckël_, 
   {{0x6458005b,0x9d180120,0x00000000,0x00000000}},	//   ävij, _жолт_, --, --, 
   {{0x65b02155,0xfafc036e,0xed5454d9,0x00000000}},	//   wähn, thës_, _поч_, --, 
   {{0x2bac190e,0x49103c71,0xb88c001f,0xe8940166}},	//   _टीका, _तारो_, _የድጋፍ_, гарь, 
   {{0x61e0022e,0xf99c02e2,0x00000000,0x00000000}},	//   _otml, ntèz_, --, --, 
   {{0xfafc044e,0x65b01196,0x9538d440,0xdce80139}},	// [2bcb0] shës_, rähn, мзат_, lodı, 
   {{0xd2512daf,0x66e00118,0x65b0002f,0x00000000}},	//   ینا_, váků, sähn, --, 
   {{0x79840796,0xe92c0135,0x614800e2,0x338402e8}},	//   mijw, _སྲིབ_, _mīlē, нудв, 
   {{0x51f59b56,0x79859b57,0x00000000,0x00000000}},	//   نستر, lijw, --, --, 
   {{0x61e005b1,0xd1b80736,0x645801bf,0x768400cf}},	//   _ctml, واتا_, øvir, _чынж, 
   {{0x7984f320,0xe7e80864,0xe8e00051,0xdce800c0}},	//   nijw, टीका_, _khều_, midė, 
   {{0x6594d42e,0xd3c400c7,0xdce800c0,0x00000000}},	//   _сару, _араҿ, lidė, --, 
   {{0x79840526,0xb4b000c7,0x9f5c02fb,0x2bcc012d}},	//   hijw, _аиҳә, trvá_, सआसा, 
   {{0xe3b07eea,0x7984015c,0x83a400c7,0x0cc801bc}},	//   _طرف_, kijw, _рырҵ, रश्म, 
   {{0x4d659b58,0x79841389,0x4c68d027,0x23980010}},	//   тков, jijw, дион_, rčje_, 
   {{0x22440010,0xc4d00375,0x201c0118,0xf99c007f}},	//   _zrmk_, יגי_, ctvi_, trèn_, 
   {{0x005405e1,0x256402d2,0x6ee4007b,0xdce800c0}},	//   _בשעת_, _hölt_, _أسال, kidė, 
   {{0x3f7800c8,0x7bcc0321,0x5f7401d5,0x9e644ea7}},	//   _קאנס, íbur, _حالر, _ماون, 
   {{0x79848aa7,0xdce80006,0x65b0023a,0x6458005b}},	//   gijw, didė, väho, ävik, 
   {{0xf99c00cf,0x6a7802d2,0x00000000,0x00000000}},	//   prèn_, _búfé, --, --, 
   {{0xfafc036e,0x6cc001af,0x61480171,0x320c00ee}},	//   shër_, _ийҙа, _zīlē, kugy_, 
   {{0x6b859b59,0x79842dab,0x4a74411a,0x00000000}},	// [2bcc0] _imig, bijw, _шыкт, --, 
   {{0xf504005b,0x00000000,0x00000000,0x00000000}},	//   кнул_, --, --, --, 
   {{0x7b9401d3,0x65b001f4,0xc0d00240,0x00000000}},	//   _سپیس_, säho, _ከንሱ_, --, 
   {{0xc2c59b5a,0x660401af,0x00000000,0x00000000}},	//   نياي, _йомҡ, --, --, 
   {{0x2564008c,0x25b801ab,0xf99c007f,0x6b840254}},	//   _sölu_, _thrl_, krèl_, _mmig, 
   {{0x42d0015b,0xf2c4074d,0x1e140107,0xa0b80c31}},	//   ারেশ, ĕсен, ҳмия, нглу_, 
   {{0xf9900375,0x00000000,0x00000000,0x00000000}},	//   ברג_, --, --, --, 
   {{0x91e01c82,0x65b0481f,0x798401f0,0x61e000a2}},	//   _নিৰ্, zähl, zijw, _ttml, 
   {{0x44299b5b,0x7984014b,0x201c0427,0x61480171}},	//   _hpb_, yijw, stvi_, _pīlē, 
   {{0x6b859b5c,0x25659b5d,0xf99c02e2,0x5d54022e}},	//   _amig, _gölt_, grèl_, укот, 
   {{0xd1750fbf,0x806801d5,0x614800ef,0x645801f4}},	//   _сыты, _تماق_, _vīlē, ävih, 
   {{0x65b0481f,0xcdcc00aa,0xf4100302,0x69c00137}},	//   wähl, _کښي_, ספר_, ïmen, 
   {{0x79840526,0x65b0002f,0x00000000,0x00000000}},	//   tijw, tähl, --, --, 
   {{0x6b859b5e,0x442807a8,0x00000000,0x00000000}},	//   _emig, _opb_, --, --, 
   {{0x79840516,0x4428037e,0xaca00432,0x00000000}},	//   rijw, _npb_, _diỳi, --, 
   {{0x24b800bd,0x09e0015b,0x79840117,0xf67400d1}},	//   জশাহ, _বিরা, sijw, پارخ, 
   {{0xa5f884dc,0x00000000,0x00000000,0x00000000}},	// [2bcd0] кету_, --, --, --, 
   {{0xe610007b,0xe8e00051,0x398002f2,0x00000000}},	//   تشف_, _thều_, _ئیسف, --, 
   {{0xdce802d5,0x442801f5,0xe5c59b5f,0xd17401e0}},	//   sidė, _cpb_, рсто, ҫылы, 
   {{0x44299b60,0x31c8726b,0x256402d2,0xd7f00051}},	//   _dpb_, ाद्ध, _sölt_, ẫu_, 
   {{0x442801f5,0x6b7c0a1e,0x00000000,0x00000000}},	//   _epb_, וראנ, --, --, 
   {{0x4428014b,0x7c280582,0x414402dd,0xe4c81411}},	//   _fpb_, _opfr, лдің, ربەن_, 
   {{0x44280998,0x90440035,0x00000000,0x00000000}},	//   _gpb_, انبه, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7c2801ab,0xd7200c58,0x62359b61,0xf99c0100}},	//   _apfr, _পোৱা_, _кету, trèl_, 
   {{0x09e0000e,0x6b859b62,0x00000000,0x00000000}},	//   _বিলা, _smig, --, --, 
   {{0x23980010,0xcf1402da,0x3ea001a9,0xa0c400ae}},	//   lčja_, _مواظ, _қишг, _نيكو, 
   {{0x09e59b63,0x7f9c0023,0x6458023a,0x5f741291}},	//   ломн, këqy, ävii, _پامر, 
   {{0x7c28010a,0x2bcc50ba,0x7c3c02f0,0x23980219}},	//   _epfr, _संका, _šprt, nčja_, 
   {{0x8e80001f,0xfce00e58,0xe984059f,0x00000000}},	//   _ይሆናሉ_, _лошо, рқон, --, 
   {{0x6b840327,0xbd98008f,0x28a42cfd,0x00000000}},	//   _tmig, _אױסט, _खुशि, --, 
   {{0x6b859b64,0x10b802dd,0x00000000,0x00000000}},	//   _umig, _ﺸﺭﺤﻨ, --, --, 
   {{0x8a8801d9,0x23980010,0x00000000,0x00000000}},	// [2bce0] _سپدِ_, jčja_, --, --, 
   {{0x2018b88a,0x98b0012d,0x65b00254,0x00000000}},	//   _årig_, wdzą_, mähk, --, 
   {{0x54d401c0,0x25640166,0x65b00254,0x00000000}},	//   рцуу, _söls_, lähk, --, 
   {{0xd7c800f1,0x00000000,0x00000000,0x00000000}},	//   _ټوټه_, --, --, --, 
   {{0x6724014b,0x44280175,0x85600022,0x016401b9}},	//   mfij, _wpb_, _лҽаҧ, лкдо, 
   {{0xdb0c02d3,0xc4c4007b,0xdb1c0036,0x37e40154}},	//   _thaç, _متزو, rmsé, _ফিতর, 
   {{0x629c006d,0x8024034c,0x44288a8a,0xe7e80073}},	//   _środ, ارتم, _upb_, टीचा_, 
   {{0x1e840831,0xa2c40131,0xf99c067c,0xa1140131}},	//   ғлүм, _кәлк, luèt_, _چۈشت, 
   {{0xc0e4004e,0xf0a40bd6,0x00000000,0x00000000}},	//   _бозк, ккәл_, --, --, 
   {{0x71d40302,0x90d4001e,0xf99c1f3f,0x00000000}},	//   _עובד_, _hàn, nuèt_, --, 
   {{0xb698006a,0xdb5434d8,0xb1400276,0x672401f5}},	//   _ndân, авны, _ынфл, kfij, 
   {{0xad200131,0x6724031c,0x3dd0010a,0x00000000}},	//   لىۋى, jfij, _гιаг, --, 
   {{0x3f84009a,0xb6980276,0xf9919b65,0xfd440139}},	//   _imou_, _adân, مبس_, _бэйн, 
   {{0x3f840270,0xfbdc0004,0x67dc007f,0xf99c24bc}},	//   _hmou_, ãªs_, _sčja, prèm_, 
   {{0xf99c067c,0x67252291,0x00000000,0x00000000}},	//   duèt_, ffij, --, --, 
   {{0x90d4004d,0x69d000c0,0x9af800cd,0x00000000}},	//   _nàn, _žiež, bhāṇ, --, 
   {{0x31b8000f,0x14400092,0x929c0210,0x659400c7}},	// [2bcf0] lêze_, _የሚመሩ, _odła, әаху, 
   {{0xf99c9b4c,0xf4f40a81,0xe5c40b01,0xe0c000cc}},	//   guèt_, اواں_, бсхо, _উভৈন, 
   {{0xd6d00597,0x3f8408f5,0x31b8000f,0xc95002e4}},	//   _وقد_, _omou_, nêze_, _ומי_, 
   {{0x7bd80d04,0x3f840093,0x90d4004d,0xa7740cc9}},	//   iqtu, _nmou_, _càn, _глюч, 
   {{0xdbd00209,0x90d4004d,0xa29400d4,0x51540329}},	//   lýän, _dàn, баці, итку, 
   {{0x3f859b66,0xd008288b,0xa4d402bf,0xa158074d}},	//   _amou_, веке_, _горі, лачу_, 
   {{0x45a00075,0xdbd00209,0xf99c068c,0x93c801ee}},	//   _بەلك, nýän, quèu_, _атаҡ_, 
   {{0x409004a9,0x7bcc0268,0x2c7801e1,0x00000000}},	//   تلىر, ìbul, _ládé_, --, 
   {{0x682c24ba,0x3dcc02e2,0xdce800ef,0x00000000}},	//   _ködö, _bifw_, cidī, --, 
   {{0x0c241b74,0x3f8459ae,0x0d859b67,0x81400014}},	//   амон, _emou_, рлон, _وۆنن, 
   {{0x3f840270,0x682c01b8,0xefc8001f,0x3e7801e1}},	//   _fmou_, _mödö, ጠረው_, _pàté_, 
   {{0x682c29ef,0x8ba4d021,0xdbd0010b,0x51840150}},	//   _lödö, римж, dýän, _суға, 
   {{0x7bd83209,0x333c004a,0x6fc4002d,0xf99c020c}},	//   aqtu, _maux_, _rűch, crèk_, 
   {{0x333c0097,0xdd940166,0x39e40107,0x65b00254}},	//   _laux_, _лачы, рдро_, rähk, 
   {{0x2d84180f,0x2c780248,0x02b00bc0,0x65b0005b}},	//   _imne_, _dádé_, _जर्न, sähk, 
   {{0x65b016ca,0xadb405d9,0x7bf41321,0x00000000}},	//   pähk, _جهڙا_, _өнәр_, --, 
   {{0xefcc067d,0x67240196,0xf99c7172,0x45859b68}},	// [2bd00] _ኣብዚ_, rfij, guès_, агав, 
   {{0x2fcc0c58,0x682c01b8,0x88857103,0x79f806a9}},	//   _ligg_, _cödö, _влож, _שליח, 
   {{0x84540640,0x333c06af,0x959838ab,0xf48400f1}},	//   шњач, _baux_, утту_, ټالی, 
   {{0x68fc7617,0x333c0399,0x2fcc05d5,0x7c3c0129}},	//   lard, _caux_, _nigg_, _âpre, 
   {{0x2d85209d,0x333c0399,0xdb180793,0x3f84007f}},	//   _omne_, _daux_, _tuvö, _rmou_, 
   {{0xefcc044e,0x29199b69,0x2b419b6a,0xcfcc04a2}},	//   _ኣብዛ_, ngra_, _laic_, _ﺗﺎﺭﺗ, 
   {{0x2fcc0204,0x333d9b6b,0xa4440014,0xc2100014}},	//   _bigg_, _faux_, _دێاو, _ژٔر_, 
   {{0x2d859b6c,0x3bd8002e,0x212000bc,0x2fcc0267}},	//   _amne_, _rëq_, řih_, _cigg_, 
   {{0x68fd9b6d,0xb6982776,0x2fcd9b6e,0x3bd8002e}},	//   kard, _ndâl, _digg_, _sëq_, 
   {{0x68fc1050,0x2d840ac5,0x65b003fa,0x2fcc1713}},	//   jard, _cmne_, fähi, _eigg_, 
   {{0x68fd9b6f,0x7bd80357,0x2fcc00e8,0x2b4042f7}},	//   dard, uqtu, _figg_, _baic_, 
   {{0x2d8495a0,0x2b40004e,0x29180789,0x2174036b}},	//   _emne_, _caic_, egra_, _туғр, 
   {{0x68fd9b70,0x2c7801e1,0xdcb000cf,0xba08011c}},	//   fard, _pádé_, تىگ_, ъхне_, 
   {{0x68fcb8b4,0x6e90027d,0x00000000,0x00000000}},	//   gard, _بلها, --, --, 
   {{0x2bd0216a,0x2b400192,0x2fcd9b71,0x37a8da9f}},	//   _संचा, _faic_, _yigg_, втан_, 
   {{0x29199b72,0xf99c067c,0xf84401c0,0x67580214}},	//   agra_, guèr_, гүүд_, لیپس_, 
   {{0xdbd00209,0xd1f0001f,0x5574013d,0x292803b2}},	// [2bd10] rýän, _ግፊት_, бгат, úvað_, 
   {{0x56959b73,0xdb1c00ae,0xe8e00051,0x00000000}},	//   _ҳамт, imsí, _phễu_, --, 
   {{0x236406be,0x79280023,0x00000000,0x00000000}},	//   _bomj_, _ድሌታት, --, --, 
   {{0xa3b410f5,0x527415bf,0x7950009f,0x00000000}},	//   обхі, йулу, _اَڍا, --, 
   {{0x07540302,0x2fcc06f2,0x2bd04e6d,0x333d9b74}},	//   _הסרט_, _rigg_, _संघा, _vaux_, 
   {{0x463804ac,0x9a740092,0xd130007b,0xf124009d}},	//   _געשע, ብርናው_, سمع_, рьдо, 
   {{0x333d9b75,0x2fcd9b76,0xc0cc02d3,0x9c7c0219}},	//   _taux_, _pigg_, _ኣድማ_, obču, 
   {{0x29181050,0x68fd9b77,0x65b026bb,0x00000000}},	//   zgra_, zard, vähi, --, 
   {{0x0d850d14,0x52840597,0xc4440014,0x2b4001e7}},	//   йлин, _الذك, _پیۆن_, _raic_, 
   {{0x8d542082,0xb698006a,0x30a40f1a,0x68fc00ac}},	//   стич, _ndâm, _крев, xard, 
   {{0xcb68d798,0x9e648f52,0x00000000,0x00000000}},	//   гане_, ماین, --, --, 
   {{0x68fcc963,0x62000139,0x8eb801af,0x00000000}},	//   ward, _äzlä, _йылт_, --, 
   {{0x2d84070d,0x68fcb77d,0x2b400076,0x65b00108}},	//   _tmne_, tard, _vaic_, sähi, 
   {{0x2b400165,0x3ea0045f,0x00000000,0x00000000}},	//   _waic_, ûkte_, --, --, 
   {{0x44f402a6,0x2b400876,0x0c040014,0x29180008}},	//   _চালক_, _taic_, _اوبُ, rgra_, 
   {{0x2b400356,0x291801ab,0x00000000,0x00000000}},	//   _uaic_, sgra_, --, --, 
   {{0x8b8412b7,0x68fc0839,0x452804b3,0x3ed8010f}},	// [2bd20] _نەگە_, pard, лжан_, אַבא, 
   {{0x68fd9b78,0x9f5c0268,0x06b800fe,0x33cc00d1}},	//   qard, nuvò_, ংখলি, _ﺑﺎﺭﻣ, 
   {{0x07a59b79,0xc7a40835,0x3cf8010f,0xc2e401a9}},	//   _ганн, _гинк, רלענ, бўли, 
   {{0xf99c067c,0x98a000b8,0x82f800db,0x00000000}},	//   quèr_, _ubhā_, اراز_, --, 
   {{0x87c40014,0xd7b401f9,0x00000000,0x00000000}},	//   _پتھٕ, ंतरच, --, --, 
   {{0xa03476b9,0x645802f6,0x91e4037e,0x75d0038b}},	//   قىتت, ävis, _mlとc, _ريفا, 
   {{0x64584606,0x38c10ac7,0x94040166,0x01cc5f32}},	//   åvid, méré_, _морҗ, _ﺗﻮﻧﻨ, 
   {{0x38c19b7a,0x00000000,0x00000000,0x00000000}},	//   léré_, --, --, --, 
   {{0x0204013d,0x05180154,0x9f580241,0x00000000}},	//   _ызан, ড়ীর_, _ìrí_, --, 
   {{0x38c0004a,0xf99c020c,0x7c6401d5,0xf650123b}},	//   néré_, prèi_, ماجل, פצת_, 
   {{0xba7403e6,0x7c846179,0xfafc002e,0xff2801a9}},	//   ڕاست, супе, kkët_, _бўли_, 
   {{0xbba0012d,0x1a640133,0x00000000,0x00000000}},	//   ओकेक, قیعی_, --, --, 
   {{0x0dbc02d3,0xfe440276,0x65b001f4,0xaa940139}},	//   _ተሪፉ_, _ындо, lähu, зияч, 
   {{0x6cd0742b,0x00000000,0x00000000,0x00000000}},	//   _فقها, --, --, --, 
   {{0xe814069f,0x7f400a73,0x38c05725,0x3cfc01a6}},	//   तूला_, _kaoq, déré_, matv_, 
   {{0x61e41682,0x212c030a,0xe8940006,0x44380327}},	//   ̭ila, _lbdh_, чась, dwp_, 
   {{0x38c04056,0x569401c0,0xcc8403e6,0x00000000}},	// [2bd30] féré_, цаат, _هۆیه_, --, 
   {{0x7d199b7b,0x38c006af,0x98a00055,0x3cfc0171}},	//   ngts, géré_, _jahī_, natv_, 
   {{0x98a000cd,0x97341a4b,0x65b001f4,0x00000000}},	//   _mahī_, _وکرا, jähu, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x38c19b7c,0x7d1801af,0x6458005b,0xa20400d4}},	//   béré_, kgts, ävir, зпід, 
   {{0x3cfc0b4b,0x98a000b8,0x00000000,0x00000000}},	//   jatv_, _nahī_, --, --, 
   {{0x212c0280,0xfafc0023,0x7f40004d,0x3cfc0055}},	//   _dbdh_, nkës_, _baoq, datv_, 
   {{0xb698025a,0x8e081b0a,0x00000000,0x00000000}},	//   _ndâk, анив_, --, --, 
   {{0x7c3806a3,0x212c01ab,0xdde80424,0x63a806ea}},	//   ewtr, _fbdh_, یریه_, _ídna, 
   {{0xb698025a,0x65b00254,0x00000000,0x00000000}},	//   _adâk, sähv, --, --, 
   {{0x65b0005b,0xfafc0200,0x00000000,0x00000000}},	//   mäht, jkës_, --, --, 
   {{0xcac81b10,0x65b01073,0x4fc0185e,0x44180a7c}},	//   игне_, läht, _تەبە, סורס, 
   {{0xa2dc65c5,0x4338008f,0x7d180142,0xb60000d7}},	//   _फलस्, בערב, bgts, ngáč, 
   {{0x6e382dab,0x2efd9b7d,0x65b19b7e,0x3cfc011c}},	//   mwub, lauf_, näht, catv_, 
   {{0x6d40325f,0xb7e00a89,0x00000000,0x00000000}},	//   _iana, джск, --, --, 
   {{0x6f199b7f,0x06e93e87,0x2efc0e78,0xbd880023}},	//   nguc, рмак_, nauf_, _ንእቶም_, 
   {{0x6d419b80,0x056435dd,0x38c18d0c,0x86099b81}},	// [2bd40] _kana, ован, téré_, شقاق_, 
   {{0xfafc0023,0x65b0023a,0xb6a0151e,0x69f40107}},	//   skët_, jäht, фиул, _мӯҳт, 
   {{0x2efc03fa,0xfafc036e,0x00000000,0x00000000}},	//   kauf_, ckës_, --, --, 
   {{0x6e399b82,0x38c006af,0xd9e00490,0x05180154}},	//   kwub, séré_, _गंमत_, ড়ের_, 
   {{0x6d419b83,0x38c19b84,0xc1d00150,0x00000000}},	//   _oana, péré_, _ﺟﻮﺭﺍ, --, 
   {{0x6d419b85,0x66059b86,0x7bcc0122,0x443805b1}},	//   _nana, msik, íbuz, pwp_, 
   {{0xf99c8a69,0xc0585074,0x00000000,0x00000000}},	//   lsèc_, ріл_, --, --, 
   {{0x6d416282,0xc3740014,0x66059b87,0x23bc00d0}},	//   _aana, _بُرب, osik, bíja_, 
   {{0x98a002b1,0xf99c067c,0x3cfc00b5,0xfafc1bce}},	//   _pahī_, nsèc_, tatv_, kkër_, 
   {{0x66059b88,0x6da01f5a,0x7d682e8d,0xc0441867}},	//   isik, миња, ршив_, _وخضو, 
   {{0x66040309,0x7c6400d1,0x00000000,0x00000000}},	//   hsik, زادل, --, --, 
   {{0x6d419b89,0x6e380223,0x3cfc0311,0x9f5801e1}},	//   _eana, bwub, satv_, _ìrà_, 
   {{0x6d419b8a,0xfe7003e6,0x660402d1,0xf99c007f}},	//   _fana, _تدا_, jsik, krèt_, 
   {{0x66045522,0xfafc0200,0xe0f800fe,0x00000000}},	//   dsik, tkës_, _ঘাঁহ_, --, 
   {{0xf7701a57,0x9f58772a,0x66040254,0x00000000}},	//   وار_, _író_, esik, --, 
   {{0x6d401311,0xfafc0240,0x9f5c03b2,0x545400d1}},	//   _zana, rkës_, ksví_, үват, 
   {{0x6d419b8b,0x66059b8c,0xfafc0240,0x9f5800e4}},	// [2bd50] _yana, gsik, skës_, _êrõ_, 
   {{0x6d419b8d,0x3448db74,0xf99c35b2,0x23bc00d0}},	//   _xana, ичен_, grèt_, víja_, 
   {{0x65b00108,0x00000000,0x00000000,0x00000000}},	//   väht, --, --, --, 
   {{0x88380302,0xf99c1497,0x66040171,0x083800df}},	//   _פתרו, rrèu_, bsik, _פערל, 
   {{0x65b0b6a5,0xf99c56ec,0x660401d3,0xbb1800e4}},	//   täht, brèt_, csik, chîe, 
   {{0xf99c180f,0x291c007c,0x2a3c010f,0xd1b07771}},	//   crèt_, _övat_, יעדמ, ریاک, 
   {{0x6d400b45,0x85000131,0x65b0023a,0x211c0073}},	//   _rana, _سۈنن, räht, _नारळ_, 
   {{0x6e380223,0x7d080334,0x65b0023a,0x09e000fe}},	//   twub, _adfs, säht, _বিঘা, 
   {{0x2efc0639,0x8d741075,0xe3b06bc6,0xfde400ee}},	//   rauf_, كادا, _شرف_, пдык_, 
   {{0xd5f4003d,0x2efc0092,0x6e380230,0x611401c0}},	//   _བསླབ_, sauf_, rwub, _одуу, 
   {{0xa3b801ed,0xc1700375,0x291c0022,0x660401d3}},	//   _طاہر_, _רחב_, _ĸva_, zsik, 
   {{0x6d419b8e,0x65b00730,0x6605551f,0x00000000}},	//   _wana, nähr, ysik, --, 
   {{0x6d419b8f,0x94240003,0x64480077,0xabe00150}},	//   _tana, _ཤཱཀྱ_, _ádiv, _ﺍﻟﻬﺎ, 
   {{0xd244105d,0x6d400ccb,0xf99c033b,0xdfd001ec}},	//   _یچ_, _uana, drès_, _كيە_, 
   {{0xebc40032,0x764d9b90,0x00000000,0x00000000}},	//   _оҙон, _arcy, --, --, 
   {{0x66059b91,0x65b003fa,0x9f5800e4,0xc0c01954}},	//   tsik, jähr, _êrô_, ስክሩ_, 
   {{0xfbd0025f,0xf99d9b92,0x66059b93,0xb4d401ad}},	// [2bd60] _אתה_, grès_, usik, ाखू_, 
   {{0x48080124,0x291c3619,0x55c43007,0xf99c0ba1}},	//   _леон_, _øva_, дауғ, urèt_, 
   {{0x65b0cac5,0x764c514c,0xf99c0ba1,0xf8d80375}},	//   fähr, _ercy, ssèc_, _לחימ, 
   {{0xf99c020c,0xc7a403c5,0x07a41606,0x50e0002b}},	//   brès_, _химк, _хамн, _āsāṃ_, 
   {{0x660402d1,0x23980219,0xf99c02e2,0xd20000db}},	//   qsik, nčji_, prèt_, күтк, 
   {{0xbfa801e0,0x61e401e4,0x00000000,0x00000000}},	//   әтке_, ŭilo, --, --, 
   {{0x65b000a2,0x947800d4,0x00000000,0x00000000}},	//   bähr, _дсту_, --, --, 
   {{0x74980a7c,0x7d0801f4,0x53c40150,0x00000000}},	//   _הילפ, _sdfs, _жасұ, --, 
   {{0x80a440bf,0x46bc012c,0xc0c002d3,0x72d02374}},	//   _کمان, ्धिह, ስክሮ_, _كەمچ, 
   {{0x90e401b9,0xdd901a90,0x00000000,0x00000000}},	//   _قسمن, ئود_, --, --, 
   {{0xaa280135,0x6aa402d0,0x714000f7,0x00000000}},	//   _ཧཱུྃ_, _axif, _سۉيۅ, --, 
   {{0xdce805d1,0x38c00248,0xca5001ec,0x00000000}},	//   ğlıy, _lérí_, _ﺎﻗﺽ_, --, 
   {{0xdce81918,0xcf240832,0x657c03cb,0xdb2401e1}},	//   şlıy, _آرمي, _olrh, _àsíp, 
   {{0xdd90a864,0xdfa8009f,0x00000000,0x00000000}},	//   _جوت_, _اُچو_, --, --, 
   {{0xa8a4e2f1,0x6aa59b94,0x77900330,0x00000000}},	//   ертк, _exif, فیدا, --, 
   {{0xf99d9b95,0x77f001e1,0xeb9800f3,0x45f80241}},	//   très_, _ẹsẹẹ, _ниј_, _ọpẹ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [2bd70] --, --, --, --, 
   {{0x65b00730,0x261c05f9,0xf99d532d,0xb4d41025}},	//   währ, मढ़ी_, rrès_, ाखे_, 
   {{0x7afc0240,0xbb1800e4,0x00000000,0x00000000}},	//   _keqt, chîc, --, --, 
   {{0xf99d9b96,0x95c80ed1,0xe3b00451,0x291c0267}},	//   près_, суға_, هرن_, _övar_, 
   {{0x7afc047e,0xabe00220,0x72280108,0x00000000}},	//   _meqt, _ﺍﻟﻤﺎ, сцев_, --, 
   {{0xe1f19b97,0x7afc004e,0xdb0c0055,0xd6f40154}},	//   اسن_, _leqt, _khaó, _ছায়া_, 
   {{0x8fa40120,0x241806a6,0xdb1c007c,0x00000000}},	//   маке, _норы_, omsä, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7e940811,0x78b401e3,0x7dc40174,0x55000037}},	//   وچهر_, _lyxv, iðsf, _लजाए_, 
   {{0x71700137,0xa1942502,0x9e24075e,0x00000000}},	//   _سۇعا, _зауч, رىپو, --, 
   {{0x7afc0477,0x00000000,0x00000000,0x00000000}},	//   _beqt, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x89f41e76,0x00000000,0x00000000,0x00000000}},	//   ьянц, --, --, --, 
   {{0x1cdc2fb5,0x290c025a,0x64480142,0x00000000}},	//   _འུར_, ûda_, _âdig, --, 
   {{0xd6f400bd,0x2564df09,0x2ac401e1,0xcb699b98}},	//   _ছাড়া_, _tölz_, _bèbí_, _маке_, 
   {{0x97b53d8a,0x38c001e1,0x1aac00cc,0x7dc402d2}},	//   есуш, _sérí_, _গণৰা, gðsf, 
   {{0xdb0c035b,0xf99c0ba1,0xcaa4007b,0xd624007b}},	// [2bd80] _ehaó, rrèr_, _تصغي, فعلي, 
   {{0x36c00ed6,0xb3440327,0x00000000,0x00000000}},	//   тбуг, _leħħ, --, --, 
   {{0x53e410f5,0x1cdc031c,0x99880427,0x1b200154}},	//   еціа, _འུལ_, _upaš_, _বসতে_, 
   {{0x44f41c82,0xb3440135,0xf99c007f,0x00000000}},	//   _চাওক_, _neħħ, nsèn_, --, 
   {{0x38c001e1,0xe134008e,0x7af803b2,0x00000000}},	//   _térí_, енлы, ðuti, --, 
   {{0xf914012d,0xdef81ef7,0x00000000,0x00000000}},	//   _ताज़ा_, ለዩን_, --, --, 
   {{0x443c033b,0xf1c802dd,0x00000000,0x00000000}},	//   _èt_, _ﺗﻮﻗﺘ, --, --, 
   {{0x201805ac,0x98b00356,0x00000000,0x00000000}},	//   _årim_, leză_, --, --, 
   {{0x7afc0175,0xc2440111,0x00000000,0x00000000}},	//   _reqt, _юнак, --, --, 
   {{0x64480077,0x98b15d6a,0x7dc40174,0x25640108}},	//   _ádis, neză_, iðsg, _pöly_, 
   {{0x64480042,0x717000e3,0x7dc40162,0x00000000}},	//   _âdid, _جهلا, yðsf, --, 
   {{0x2fd40150,0x201c4f89,0xb920063f,0x7afc047e}},	//   _قولد_, muvi_, barụ_, _qeqt, 
   {{0x201d9b99,0xf9917ea3,0xde58dcc6,0x00000000}},	//   luvi_, نبس_, _халі_, --, 
   {{0x7afc0455,0x00000000,0x00000000,0x00000000}},	//   _weqt, --, --, --, 
   {{0xfca80014,0x201d9b9a,0x61e02a89,0xa3c03885}},	//   _باشو_, nuvi_, _luml, ीषा_, 
   {{0x76400210,0x00000000,0x00000000,0x00000000}},	//   łnym, --, --, --, 
   {{0xe694c23e,0x201d9b9b,0x7dc468f1,0x64585794}},	// [2bd90] виты, huvi_, rðsf, åvin, 
   {{0x201d9b9c,0x98b00356,0x00000000,0x00000000}},	//   kuvi_, geză_, --, --, 
   {{0x61e008a5,0x94740214,0xeab002f2,0x00000000}},	//   _auml, رگسا, _معی_, --, 
   {{0xd2502df0,0x61e001bf,0xdb0c47b1,0xa2f400ec}},	//   ُنا_, _buml, _khañ, پيوڪ, 
   {{0x61e19b9d,0xd9480023,0x00000000,0x00000000}},	//   _cuml, _ብምድጋ, --, --, 
   {{0x4250073e,0xb3440135,0x047800e5,0x00000000}},	//   انور, _seħħ, _کلِک_, --, 
   {{0x61e19b9e,0x7dc40162,0xd25000ec,0x201d9b9f}},	//   _euml, iðsd, ئنڻ_, guvi_, 
   {{0x61e00728,0x00000000,0x00000000,0x00000000}},	//   _fuml, --, --, --, 
   {{0x64480077,0x53a402dd,0x61e04c80,0x26ec000d}},	//   _ádir, _жаңб, _guml, _छ्ोर_, 
   {{0x201c014b,0x00000000,0x00000000,0x00000000}},	//   buvi_, --, --, --, 
   {{0xdb0c00b8,0xab64012d,0x00000000,0x00000000}},	//   _ahañ, óżow, --, --, 
   {{0xdb0c00b8,0xa0c59ba0,0x826000cf,0xdef400c0}},	//   _bhañ, _شينو, _جۇۇن, _апцы, 
   {{0x9f88006a,0xdb0c0489,0xf99c00f2,0x4a7400c7}},	//   kûê_, _chañ, rsèn_, хынт, 
   {{0xf99c4b84,0x00000000,0x00000000,0x00000000}},	//   ssèn_, --, --, --, 
   {{0xf1c801ec,0x00000000,0x00000000,0x00000000}},	//   _ﺗﻮﻟﺘ, --, --, --, 
   {{0xc7640328,0xf7415f0f,0x85e800f5,0x00000000}},	//   رازى, лесо, здав_, --, 
   {{0x98b00276,0xf99c067c,0x9b940451,0xdb0c5db3}},	// [2bda0] teză_, prèp_, _جهيڙ, _ghañ, 
   {{0xfafc0023,0xf99c560d,0x7dc403b2,0x00000000}},	//   njën_, nsèl_, rðsg, --, 
   {{0x61e19ba1,0x7aec00e4,0x98b00356,0xe87800d1}},	//   _suml, _éité, reză_, _غەرب_, 
   {{0x020480df,0x201c00ec,0x61e0047e,0x7ac400ce}},	//   ездн, vuvi_, _puml, रेकअ, 
   {{0x61e1961b,0x654400c7,0xf99c033b,0x96b8004e}},	//   _quml, _иҭаб, ksèl_, _журу_, 
   {{0x201c0286,0x61e0014f,0x00000000,0x00000000}},	//   tuvi_, _vuml, --, --, 
   {{0x61e0014b,0x35a09afe,0xf0e400d1,0x00000000}},	//   _wuml, _сарг, رىيى_, --, 
   {{0x61e19ba2,0x201c9674,0x7bdc07ea,0xaf0400d1}},	//   _tuml, ruvi_, _épui, ىقىم_, 
   {{0x929c0034,0xc6680023,0xf2a000d8,0x61480171}},	//   _pełe, _አመሪካ_, _битп, _pūlē, 
   {{0x7c84005e,0xfafc0240,0x23980427,0x442803b9}},	//   еуме, gjën_, rčju_, _kqb_, 
   {{0xdb0c0113,0x44280076,0x1b1801c6,0x00000000}},	//   _shañ, _jqb_, мжны_, --, 
   {{0xa3c0216a,0x98b00064,0x00000000,0x00000000}},	//   ँति_, nezą_, --, --, 
   {{0x7e9401d9,0x79a4d4b0,0x00000000,0x00000000}},	//   _سۆدر_, ерве, --, --, 
   {{0xdd942758,0x998800d7,0x00000000,0x00000000}},	//   _шалы, _opať_, --, --, 
   {{0x64581f53,0x00000000,0x00000000,0x00000000}},	//   åvil, --, --, --, 
   {{0xdb0c0784,0x9ba801d3,0xab84030d,0xc5fc0241}},	//   _thañ, _تختہ_, _буьк, _ọrẹb, 
   {{0x95d8136b,0x44280175,0x0d3c001f,0x9f5800c7}},	// [2bdb0] ддат_, _aqb_, _ይጻፉል, _írõ_, 
   {{0x200c107d,0x7bcc0076,0x98b000e2,0x00000000}},	//   _ovdi_, lmcu, udzē_, --, 
   {{0x5fb000bc,0xf1c801ec,0x00000000,0x00000000}},	//   ञवाल, _ﺗﻮﻛﺘ, --, --, 
   {{0xfbb00864,0x7e800150,0xdce800c0,0x00000000}},	//   ीतिम, _ﺨﻁﻁﺕ_, rkdę, --, 
   {{0x200d9ba3,0xa2d4012c,0x7dc403b2,0x00000000}},	//   _avdi_, _बृद्, iðsb, --, 
   {{0x442801a9,0xb4b000c7,0xf99c007f,0x00000000}},	//   _fqb_, _бигә, ksèm_, --, 
   {{0x929c0ced,0x00000000,0x00000000,0x00000000}},	//   _bełc, --, --, --, 
   {{0x047800f1,0x00000000,0x00000000,0x00000000}},	//   _کلېک_, --, --, --, 
   {{0x0ea810f5,0xfafc0200,0x00000000,0x00000000}},	//   ький_, tjën_, --, --, 
   {{0x44280208,0xaf5001e0,0x8d540354,0xe5cc02dd}},	//   _yqb_, _әндә, ттич, _ﺒﺎﻟﻜ, 
   {{0xbec00023,0xbc600166,0x9e640244,0x00000000}},	//   çëri, авэк, ناین, --, 
   {{0x09e59ba4,0xf99c0ba1,0x00000000,0x00000000}},	//   комн, ssèl_, --, --, 
   {{0x8d74592e,0x00000000,0x00000000,0x00000000}},	//   _لاثا, --, --, --, 
   {{0xfce19ba5,0x273c0051,0x00000000,0x00000000}},	//   _кошо, _ận_, --, --, 
   {{0x3cc40022,0x670400cf,0x00000000,0x00000000}},	//   _илшо_, лүнб, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc9a80cfc,0x4428f182,0x99880030,0xf740fcc3}},	// [2bdc0] _овие_, _sqb_, _spať_, шето, 
   {{0x31b807a8,0xcfb804c5,0x225809a8,0x00000000}},	//   bêzi_, ুদিন, _črk_, --, 
   {{0x07a40124,0xc7a400c7,0xb978011a,0x00000000}},	//   _аанн, _аинк, _חניי, --, 
   {{0x86c40592,0x00000000,0x00000000,0x00000000}},	//   _ليجن, --, --, --, 
   {{0x6724014b,0x611401c6,0x9324cdcc,0x00000000}},	//   mgij, гдлу, ارمن, --, 
   {{0xd3c401ec,0xabe00220,0xd5d401ee,0x9f580248}},	//   _ەتكى, _ﺍﻟﻁﺎ, _бюсы, _ìrú_, 
   {{0x5f9419c5,0x425001d3,0x7dc40162,0x399800df}},	//   ликт, انڈر, yðsb, ויסד, 
   {{0x67259ba6,0xfafc0023,0x1e8400d1,0x00000000}},	//   ngij, gjël_, лһем, --, 
   {{0x324007d6,0xceb4891e,0x43940220,0xc0e8001f}},	//   _кетг, ләш_, _заңс, መራር_, 
   {{0x67240007,0x40940e22,0xdb1c0158,0x00000000}},	//   hgij, _ирет, lmsø, --, 
   {{0x351800c8,0x7c28030d,0x20199ba7,0x7c8400f5}},	//   ווינ, _qqfr, _íri_, тупе, 
   {{0x2e28005c,0xfb7001f0,0x8e8000c7,0x00000000}},	//   bøf_, рқия, рҳәе, --, 
   {{0x6e280354,0xdcb02160,0xf99c068c,0x7dc4148b}},	//   _gqgb, شىڭ_, ssèm_, rðsb, 
   {{0xf2d01a4c,0x6724020c,0x00000000,0x00000000}},	//   יער_, egij, --, --, 
   {{0x88d40154,0xefd80205,0x00000000,0x00000000}},	//   _ত্বক, _üşüş, --, --, 
   {{0x6724031c,0x290c0174,0xdd9401af,0x00000000}},	//   ggij, ódar_, _шаһы, --, 
   {{0x67d40415,0x7bdc011c,0xdce806be,0x00000000}},	// [2bdd0] роту, _èpub, lndı, --, 
   {{0x67240083,0xaaac0037,0xa2dc0073,0xabe001ec}},	//   agij, _टुटक, _फलज्, _ﺍﻟﻅﺎ, 
   {{0xaba800f2,0x00000000,0x00000000,0x00000000}},	//   _سهیم_, --, --, --, 
   {{0x231400d4,0x00000000,0x00000000,0x00000000}},	//   аєшс, --, --, --, 
   {{0x47180302,0x76840276,0x9f5801e1,0x00000000}},	//   _אורג, _рынж, _ìrù_, --, 
   {{0x10a45b7f,0xa1580354,0xddc800a2,0x00000000}},	//   лилн, качу_, _ýoňk, --, 
   {{0xdbd000a2,0x29380677,0x00000000,0x00000000}},	//   _býüj, דאון_, --, --, 
   {{0xc5f404c5,0x660c023a,0xce480276,0x00000000}},	//   _চিতা_, _älkä, езие_, --, 
   {{0x0d98d54f,0xfafc0200,0x00000000,0x00000000}},	//   етны_, gjëm_, --, --, 
   {{0x4d659ba8,0xa2d0726b,0x00000000,0x00000000}},	//   уков, धधर्, --, --, 
   {{0x3fd402dd,0xa15800d8,0x00000000,0x00000000}},	//   _ﺟﯟﺭﻧ, _јаху_, --, --, 
   {{0xcb687701,0x9e641046,0x00000000,0x00000000}},	//   хаме_, _چاون, --, --, 
   {{0x2d880231,0xe9840058,0x9e6404d3,0xbb180022}},	//   èces_, иқин, _ناون, chîm, 
   {{0xdd941e49,0xfe98008f,0x64584bc1,0x7af81d0e}},	//   _качы, _אינמ, åvik, ðutr, 
   {{0x1cdc025c,0x7aec01e7,0xc5f400cc,0x00000000}},	//   _འུག_, éití, _চিধা_, --, 
   {{0x8a940502,0x76580309,0x67240024,0x7c38011a}},	//   _مشخص, _šuya, ugij, _נתפס, 
   {{0x67259ba9,0x6b859baa,0x14840014,0x00000000}},	// [2bde0] rgij, _ilig, یشمُ, --, 
   {{0x85050689,0x6b8463b3,0x00000000,0x00000000}},	//   اوان, _hlig, --, --, 
   {{0x6fd0012d,0x00000000,0x00000000,0x00000000}},	//   दगां, --, --, --, 
   {{0x42084727,0x6b84007c,0x00000000,0x00000000}},	//   ендо_, _jlig, --, --, 
   {{0x6b8404fb,0xa5640050,0x00000000,0x00000000}},	//   _mlig, _پۯان, --, --, 
   {{0x6b859bab,0x5ff40124,0xfafc036e,0x557401af}},	//   _llig, азку, gjëj_, _кѳст, 
   {{0x15b001ec,0x03a40e58,0x2eec045a,0xd4d400c0}},	//   _بەلس, _биво, _bfgf_, _вітэ, 
   {{0xc32c1b92,0x1e1416c3,0xbfa8013d,0x6b84022e}},	//   _رەت_, амия, этле_, _nlig, 
   {{0x1cdc0489,0xe1c40116,0xd36c0137,0x41a800f3}},	//   _འུང_, _көкй, _تۇن_, _зван_, 
   {{0x6b848c75,0xc044107f,0x996c00de,0x00000000}},	//   _alig, _مخصو, _sēžu_, --, 
   {{0x6b84014a,0x68fc0427,0x75980375,0x3f980129}},	//   _blig, dbrd, תייח, épus_, 
   {{0x44e8015b,0x6b8407ea,0xbb1800d2,0xdb20010e}},	//   গরিক_, _clig, phîm, _ötül, 
   {{0x6b840192,0x7c8402dd,0x996c0171,0x00000000}},	//   _dlig, _әуле, _vēžu_, --, 
   {{0x0ed00014,0x98a00055,0x6da19bac,0x0c9401d5}},	//   _بےٚس, _achā_, _лича, ادیگ, 
   {{0x6b859bad,0x58d4054a,0x00000000,0x00000000}},	//   _flig, ровт, --, --, 
   {{0x98480131,0x00000000,0x00000000,0x00000000}},	//   няға_, --, --, --, 
   {{0x98a412ca,0x7bdc0393,0x273801f4,0x00000000}},	// [2bdf0] ılı_, _iiqu, ызть_, --, 
   {{0x7bdc003a,0x201c01a6,0x6b8401d5,0xc0c00023}},	//   _hiqu, krvi_, _zlig, ስርሕ_, 
   {{0xe5c400c9,0x79a4035b,0x7bdc00d8,0x6b843bfb}},	//   ссто, _арҽе, _kiqu, _ylig, 
   {{0x7bdc0978,0xb4b001e0,0x52740276,0x6b84022e}},	//   _jiqu, _ғибә, иулу, _xlig, 
   {{0x7bdd9bae,0x91049a41,0x201c468a,0x66c99baf}},	//   _miqu, апле, ervi_, _бург_, 
   {{0x6ed800da,0xf1a4013d,0x00000000,0x00000000}},	//   _jābū, ырен, --, --, 
   {{0x629c0882,0x50b40120,0x00000000,0x00000000}},	//   _śrot, јслу, --, --, 
   {{0x7bdd9bb0,0x68fc07f5,0xe6100244,0x00000000}},	//   _niqu, zbrd, _بشێ_, --, 
   {{0x8d741b9e,0x0d84fcd2,0x201c0395,0x6b859bb1}},	//   لادا, илин, arvi_, _rlig, 
   {{0x7bdc08e7,0x6b859bb2,0x00000000,0x00000000}},	//   _aiqu, _slig, --, --, 
   {{0x7bdd9bb3,0x30a461ff,0x6b859bb4,0xd24c04d3}},	//   _biqu, _срав, _plig, _رۆژ_, 
   {{0x7994014b,0x6b859bb5,0x7bdc0077,0x70502b9f}},	//   _amxw, _qlig, _ciqu, _پنچا, 
   {{0x7bdd4406,0xb6040003,0x3f780a1e,0x6b84007c}},	//   _diqu, _jiġġ, _שאנס, _vlig, 
   {{0x7aec074d,0x7bdcf39f,0xb604025c,0x3b080175}},	//   acct, _eiqu, _miġġ, aacq_, 
   {{0x7bdd9bb6,0x8b64152f,0xf1c0031c,0xd90c0133}},	//   _fiqu, _ناظم, miġġ_, ژیی_, 
   {{0x7994014b,0x09e4404e,0xc76400f7,0x00000000}},	//   _emxw, _коин, جاسى, --, 
   {{0x4648039b,0xb604025c,0x49c800ee,0xf4845022}},	// [2be00] ъзан_, _niġġ, _илин_, یامی, 
   {{0x929c068f,0x7bdd9bb7,0xf99c007f,0x394000ef}},	//   _pełn, _épur, krèy_, cejs_, 
   {{0x7bdc047e,0x00000000,0x00000000,0x00000000}},	//   _yiqu, --, --, --, 
   {{0x7bdc00f7,0x236008e7,0x00000000,0x00000000}},	//   _xiqu, ñij_, --, --, 
   {{0x733034b1,0xf20000a7,0x929c033f,0xabe002dd}},	//   تىنا, оящо, _wełn, _ﺍﻟﻔﺎ, 
   {{0xdb0c0166,0x58c800fe,0x00000000,0x00000000}},	//   _tkaç, লশৰী, --, --, 
   {{0x25ec0490,0xf99c0100,0x00c1388e,0xbfa80798}},	//   _अंडी_, trèz_, _ﺯﺍﺗﺘ, ктие_, 
   {{0x3940005f,0x03a433cc,0xd1e80092,0x00000000}},	//   zejs_, _тибо, መቻቸ_, --, 
   {{0xff0804ce,0x8244074d,0x00000000,0x00000000}},	//   _comの, _тĕпч, --, --, 
   {{0x7bdd9bb8,0xbb1800d2,0x201c85a2,0x65b001f4}},	//   _siqu, phîk, prvi_, tähy, 
   {{0x7bdd9bb9,0x4094470e,0x7aec074d,0x212c007f}},	//   _piqu, _трат, tcct, _icdh_, 
   {{0xf99c007f,0x49a401e0,0x6cc00220,0x00000000}},	//   nsèv_, ҡырғ, _ﺭﺍﺌﻴ, --, 
   {{0x7bdd9bba,0x4f6401e2,0x65b001f4,0x00000000}},	//   _viqu, _دالف, sähy, --, 
   {{0x7bdc047e,0x7c640966,0x00000000,0x00000000}},	//   _wiqu, _نابل, --, --, 
   {{0x7bdd9bbb,0x37044dcd,0x3f859bbc,0xac900454}},	//   _tiqu, ичав, _klou_, _машш, 
   {{0xb4640214,0xb8cc5843,0xac7c0092,0x00000000}},	//   یداه, _कश_, _ይመጣሉ_, --, 
   {{0xfafd9bbd,0x95380137,0x6ac402dd,0x394001bf}},	// [2be10] mbë_, лзат_, _وقىم, pejs_, 
   {{0xe5c411ed,0x7994014b,0x00000000,0x00000000}},	//   осхо, _umxw, --, --, 
   {{0xaab85e09,0xb6040003,0x037401e1,0x00000000}},	//   _مدیر_, _siġġ, _àfọd, --, 
   {{0x95c80046,0x00000000,0x00000000,0x00000000}},	//   туға_, --, --, --, 
   {{0x4ec01d4c,0x5fd02d40,0x48900023,0x8fa400c7}},	//   _উল্ল, _ﺗﺎﭘﻘ, ረጋገጽ_, ҩале, 
   {{0x3f840170,0xdb1c0332,0x94d4009d,0x00000000}},	//   _alou_, omsó, _гогц, --, 
   {{0x3f840660,0x99880010,0x00000000,0x00000000}},	//   _blou_, _opaž_, --, --, 
   {{0x3f859bbe,0xb6040135,0xa3e4000d,0x994c0153}},	//   _clou_, _tiġġ, नदर_, ožų_, 
   {{0xd9ac045e,0x506402dd,0x00000000,0x00000000}},	//   _গঠনম, реқұ, --, --, 
   {{0x3f8400a2,0x0d859bbf,0xc6900375,0x37bc03d4}},	//   _elou_, слон, פאי_, ্দিৰ, 
   {{0x3f859bc0,0xf99c067c,0x00000000,0x00000000}},	//   _flou_, nsèu_, --, --, 
   {{0x5185367e,0xfafc006a,0x3f843ec2,0x00000000}},	//   _туға, gbë_, _glou_, --, 
   {{0xb5f808a5,0x25ec0210,0x00000000,0x00000000}},	//   _hráf, _अंधी_, --, --, 
   {{0xbb1800d2,0xdc280344,0x3f8402f0,0x0ba4010b}},	//   khîw, دسیه_, _zlou_, ршүм, 
   {{0x7dc41c38,0x85780046,0xed540032,0x2d84008e}},	//   iðsl, қсат_, _боҙ_, _ilne_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x06c801c0,0x05a99bc1,0x00000000,0x00000000}},	// [2be20] угай_, гвай_, --, --, 
   {{0x46a4013e,0x88840cb6,0x00000000,0x00000000}},	//   _ҳамв, _глож, --, --, 
   {{0x84582692,0x741006b6,0x09b400cd,0x03a401a9}},	//   ырат_, كولا, ृतीय, бижо, 
   {{0x9a5401d3,0x7dc40162,0x162800f7,0x00000000}},	//   _اٹیچ, yðso, ايەۋ_, --, 
   {{0x212c0204,0xd3000354,0x00000000,0x00000000}},	//   _pcdh_, _бiос, --, --, 
   {{0xb5f80162,0x48900023,0xa1599bc2,0x55c401af}},	//   _bráf, ረጋግጽ_, раку_, _маяғ, 
   {{0xdfd19bc3,0x3f8400db,0x78f8010f,0x00000000}},	//   ويت_, _plou_, אפצו, --, 
   {{0x645cb4bb,0xf99c067c,0xc0c00092,0x00000000}},	//   _irri, lsèt_, ድርሻ_, --, 
   {{0x3f840109,0xbdf800db,0x00000000,0x00000000}},	//   _vlou_, درعا_, --, --, 
   {{0xf99c0699,0xb5f8041e,0x1cdc025c,0x9c3806ed}},	//   nsèt_, _fráf, _འུད_, апот_, 
   {{0xb5f81a36,0x3f850932,0xf15003e6,0xf77c03e0}},	//   _gráf, _tlou_, _رکوک, _hiçe_, 
   {{0x2d840139,0xf77c415b,0x645c0200,0x00000000}},	//   _elne_, _kiçe_, _mrri, --, 
   {{0xfafca86a,0x645c0327,0xf770104b,0x6e9001ec}},	//   rbë_, _lrri, ۋار_, _ىلما, 
   {{0x645d9bc4,0xf77c0166,0x00000000,0x00000000}},	//   _orri, _miçe_, --, --, 
   {{0x7c6406b3,0x0dc80e56,0x7d0802d0,0x6bd401b9}},	//   _داشل, _ئبنى_, _iefs, تتیر, 
   {{0x7d080008,0x7dc403b2,0x96f81ca9,0x00000000}},	//   _hefs, iðsm, реат_, --, 
   {{0x557473e6,0x64593927,0x99880327,0xf99c020c}},	// [2be30] огат, ævin, _kpaż_, fsèt_, 
   {{0x994c0006,0xdb1c007b,0x645d9bc5,0xfbb005c0}},	//   ržų_, ilsí, _brri, ीतकम, 
   {{0x58d4ef44,0x7d080200,0x00000000,0x00000000}},	//   _фонт, _mefs, --, --, 
   {{0x7d08ccba,0xd2f804d3,0x1cdc031c,0xd7600345}},	//   _lefs, شکرا_, _འུན_, _تۆری, 
   {{0x645d9bc6,0xf99c067c,0x00000000,0x00000000}},	//   _erri, ssèu_, --, --, 
   {{0x7d099bc7,0xf48417d8,0xf99c0ba1,0x28c02cfd}},	//   _nefs, _лубн, msès_, _एडमि, 
   {{0x7dc40579,0x395001f9,0x9474034c,0x64580267}},	//   rðsl, _maxs_, _بگذا, åvit, 
   {{0x27ec0162,0x00000000,0x00000000,0x00000000}},	//   ídni_, --, --, --, 
   {{0xb5f801ed,0x2d8401f1,0x7d08036e,0xf99c02e2}},	//   _drág, _plne_, _befs, nsès_, 
   {{0xb5f81a36,0x645cc93b,0x3ea003b2,0x00000000}},	//   _tráf, _yrri, úkta_, --, 
   {{0xb5f80f60,0x7d080de2,0x6d4c0327,0x2d8400d0}},	//   _frág, _defs, _ġjaċ, _vlne_, 
   {{0x2c540276,0xb5f99bc8,0x09e000dc,0x1fb40220}},	//   _văd_, _krád, पद्य, _есір, 
   {{0x6ec4280e,0x395001a9,0x00000000,0x00000000}},	//   _اتاق, _baxs_, --, --, 
   {{0x7d0801a8,0x68a00023,0x9f580ca8,0x00000000}},	//   _gefs, _ፍልይቲ_, _ìrò_, --, 
   {{0x764c0393,0xc76403cc,0x929c0210,0x87740798}},	//   _ascy, يارى, _bełk, оѓаш, 
   {{0xfbc00801,0xc050011a,0x00000000,0x00000000}},	//   _общо, וזל_, --, --, 
   {{0x6f0801ed,0xb6f400cf,0x00000000,0x00000000}},	// [2be40] _megc, تىقا_, --, --, 
   {{0x6f099bc9,0x84581e87,0xf99c0ba1,0x291c0588}},	//   _legc, ирет_, usèt_, _ÿva_, 
   {{0xb5f800e4,0xe6ac0724,0xf99c0ba1,0x00000000}},	//   _arád, läüç, rsèt_, --, 
   {{0x893400dd,0x6f099bca,0xb5f806ea,0xf99c180f}},	//   _اٹھا, _negc, _brád, ssèt_, 
   {{0xbb38008f,0xb5f80332,0x00000000,0x00000000}},	//   שעני, _crád, --, --, 
   {{0x645c00ca,0xf77c0139,0x1b2000eb,0x00000000}},	//   _trri, _viçe_, _বসছে_, --, 
   {{0x645d9bcb,0x6f08401f,0x7d09419b,0xb5f8f7b3}},	//   _urri, _begc, _refs, _prág, 
   {{0xfc44031d,0x7d08f7e5,0xb5f8041e,0xfafc0023}},	//   šíku_, _sefs, _frád, njët_, 
   {{0xbd699bcc,0xf0a41cd1,0xb5f99bcd,0xd36c01ec}},	//   арне_, йкәл_, _grád, _حۇن_, 
   {{0xe6ac013d,0x312000f3,0x00000000,0x00000000}},	//   däüç, _одуг, --, --, 
   {{0x7d08008c,0x80a43c5b,0xb5f99bce,0xbb300150}},	//   _vefs, _بمان, _zrád, _ﺯﻴﻭ_, 
   {{0xbe64143e,0xb5f801a8,0x9cf000ef,0x00000000}},	//   _وهاي, _hráe, _šņāk, --, 
   {{0x7d08defa,0x39500077,0xf1c00354,0xaa949d73}},	//   _tefs, _paxs_, _айăп, дияч, 
   {{0x6f08209c,0x15f002ab,0x21f00051,0x00000000}},	//   _zegc, _अंबर_, _màh_, --, 
   {{0x6f08014b,0xdb100174,0x00000000,0x00000000}},	//   _yegc, ófól, --, --, 
   {{0xfafc0200,0x25ec01f9,0x00000000,0x00000000}},	//   gjët_, _अंशी_, --, --, 
   {{0x41c80882,0xa3c0000d,0x21f00051,0x00000000}},	// [2be50] ितास, ुतन_, _nàh_, --, 
   {{0xf99c067c,0x394401e1,0x00000000,0x00000000}},	//   rsès_, _úns_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb5f804bf,0xb60400c9,0x00000000,0x00000000}},	//   _prád, _мягк, --, --, 
   {{0x7dc4022c,0x645808cb,0xd17802d5,0x77b00327}},	//   rðsj, åvir, йскі_, għxe, 
   {{0x6f08014b,0x86780375,0xf65c003a,0xf8dc015b}},	//   _segc, _הרשו, _iræ_, _ব্যথ, 
   {{0xfafc02d3,0x60100aaa,0xc0e12130,0x15f017cb}},	//   njës_, _rómá, ношк, _अंडर_, 
   {{0xb5f80597,0xf65c01bf,0x4f9401c6,0xce5800f2}},	//   _trád, _kræ_, ярлу, مشخص_, 
   {{0x333c003b,0xe21400fd,0xb5f8013a,0x00000000}},	//   _ibux_, _омты, _hráb, --, 
   {{0x6f087dcd,0x00000000,0x00000000,0x00000000}},	//   _wegc, --, --, --, 
   {{0x7dc403b2,0xdb1c0022,0x00000000,0x00000000}},	//   iðsh, mosê, --, --, 
   {{0x09b40882,0xbb18006a,0x92e800cc,0x00000000}},	//   ृत्य, skîn, _য়ু_, --, 
   {{0x333c0327,0x43d000d1,0x00000000,0x00000000}},	//   _mbux_, ﯘﺭﯨﺪ, --, --, 
   {{0x290d0a26,0x803c0241,0x00000000,0x00000000}},	//   úda_, _òṣìk, --, --, 
   {{0xfafc0023,0xe8e00051,0x9bb400ec,0xa3c000cd}},	//   gjës_, _khứu_, _ڪليڪ, ुतम_, 
   {{0x46e8ca3f,0xa6fc00cc,0xc050008f,0xb7e00eed}},	//   сдан_, েল্ম_, עזן_, ежск, 
   {{0xf5e400a8,0xf99c007f,0xb6f41870,0xd6c400c7}},	// [2be60] змул_, rsèr_, سىلا_, дитқ, 
   {{0x2a619bcf,0xb6a001c6,0xdef80023,0x7dc402d2}},	//   _irib_, хиул, _ወድን_, gðsh, 
   {{0xb3e4025c,0x2a6025d8,0xb5f80332,0xb9780375}},	//   _སྤྱུ, _hrib_, _cráb, _הניי, 
   {{0x2a600165,0x48f4012c,0xf65c09e8,0xb5f80c5e}},	//   _krib_, ्रको_, _fræ_, _dráb, 
   {{0xf65c02d2,0x42e80022,0x00000000,0x00000000}},	//   _græ_, амҵо_, --, --, 
   {{0xb5f82242,0x7dc41f60,0x15f00a1c,0x2b400327}},	//   _fráb, rðsk, _अंतर_, _lbic_, 
   {{0xb5f81d0e,0xc05802dd,0x00000000,0x00000000}},	//   _gráb, сіл_, --, --, 
   {{0xb3e41b4b,0x2a601529,0xdb08083c,0x9df80108}},	//   _སྤྲུ, _orib_, ülüy, онит_, 
   {{0xb5f95f69,0x73303ed0,0x9e9401b9,0xc0e80092}},	//   _tráe, _سىلا, باغچ, መራል_, 
   {{0x80dc045e,0xb5f802fb,0x71a00640,0x2dd02309}},	//   নুষ্, _hrác, _зауз, нжыр, 
   {{0x9f582776,0x2a607885,0xed8400a7,0xb5f8013a}},	//   _ïrï_, _arib_, ясък_, _krác, 
   {{0x4f0800db,0x00000000,0x00000000,0x00000000}},	//   _ۇتۇپ_, --, --, --, 
   {{0xf77c1497,0x2a60b57f,0x05bc0a97,0xdb1c036e}},	//   _niça_, _crib_, ्ताब, losë, 
   {{0x2a60007f,0xed540006,0xfafc0200,0x00000000}},	//   _drib_, _ноч_, tjës_, --, 
   {{0xb5f82cd7,0xed54765d,0x2a6001d5,0x9bf401d5}},	//   _orác, _رشوت_, _erib_, _ўзич, 
   {{0x15f009d9,0xf7701de5,0xf65d28ce,0xfafc0200}},	//   _अंदर_, راز_, _præ_, rjës_, 
   {{0x2a619bd0,0x156805d9,0xfafc0200,0xdce80139}},	// [2be70] _grib_, يٽري_, sjës_, lidı, 
   {{0x92e803d4,0xb5f804d4,0xbb1800d2,0xd2500133}},	//   _য়ে_, _arác, phîs, ێنا_, 
   {{0xb5f99bd1,0x5334005b,0x00000000,0x00000000}},	//   _brác, деет, --, --, 
   {{0xf65cebd4,0xb5f80f91,0x398c0112,0xb9c81ef7}},	//   _træ_, _vráb, _düse_, _ሰሌ_, 
   {{0xb5f80789,0xd1b800db,0x68ec00e5,0x00000000}},	//   _drác, ياتا_, _áldá, --, 
   {{0x224400d7,0x00000000,0x00000000,0x00000000}},	//   _dpmk_, --, --, --, 
   {{0xdb1d9bd2,0xfe6c0517,0xe8ec0327,0x00000000}},	//   rosê, یگه_, _ཡུལག, --, 
   {{0xaca001f2,0xa3d4060c,0x0e65957a,0x00000000}},	//   naụl, _सीप_, дкин, --, 
   {{0xe3b19bd3,0x9f4c067c,0x20181427,0x88ac03d4}},	//   _صرف_, _mudè_, _ærin_, _গৰাক, 
   {{0x4c859bd4,0x00000000,0x00000000,0x00000000}},	//   длов, --, --, --, 
   {{0xa13400f2,0x3fd40150,0x00000000,0x00000000}},	//   _سرلش, _ﺟﯟﺍﻧ, --, --, 
   {{0x15ec02ab,0xa2d402ab,0x617000c7,0x4fc08e98}},	//   जदार_, बेक्, _ақәх, _جەبە, 
   {{0x8d7400d1,0x2a60003d,0xd1e40023,0xedd401af}},	//   _ياتا, _qrib_, _ምረት_, _елдә_, 
   {{0xa3d42ce1,0x0c24004e,0x597401ec,0xa80401f0}},	//   _सीन_, _жмкн, нысу, нҷол, 
   {{0x7c90007b,0x00000000,0x00000000,0x00000000}},	//   _للوص, --, --, --, 
   {{0x2b40004e,0xf7e000d1,0xf740004e,0x4a44003b}},	//   _ubic_, _ﺋﺎﻧﺪ, кесо, _жнив, 
   {{0x2a6001b9,0xb6a0a2ae,0x00000000,0x00000000}},	// [2be80] _urib_, витл, --, --, 
   {{0xf1f400b5,0xb5f801d3,0x00000000,0x00000000}},	//   dメ_, _srác, --, --, 
   {{0xb5f80122,0x69dc3bba,0xdb1d9bd5,0x00000000}},	//   _prác, mmre, fosè, --, 
   {{0xdb0c00ee,0x93240811,0xe1f80022,0x77800816}},	//   _okaý, فرهن, зҳа_, _алюз, 
   {{0xd04003be,0xb5f8012c,0x69dc01f5,0x00000000}},	//   _izlə, _vrác, omre, --, 
   {{0xdb1c0200,0x2a6400e4,0x71750086,0x00000000}},	//   tosë, ämby_, мбір_, --, 
   {{0x03a418b6,0xb5f99bd6,0xdb0c00a2,0x69dc01c3}},	//   _живо, _trác, _akaý, imre, 
   {{0xb5f8032e,0xdb1c036e,0x00000000,0x00000000}},	//   _hráa, rosë, --, --, 
   {{0x657d9bd7,0x63a00072,0xb5f80162,0xae2401c6}},	//   _korh, _immn, _kráa, мцэж_, 
   {{0xdd90708e,0x657c04e6,0x5c741789,0x69dc2e22}},	//   اود_, _jorh, елот, jmre, 
   {{0x61e80067,0x69dc0010,0xd04006be,0x00000000}},	//   _iidl, dmre, _ozlə, --, 
   {{0x657d9bd8,0xa3c01df1,0x69dc01f5,0x61e99bd9}},	//   _lorh, ुति_, emre, _hidl, 
   {{0x61e8f00f,0xfe710d74,0x657d9bda,0x9f4ce03d}},	//   _kidl, _جدا_, _oorh, _rudè_, 
   {{0x657d9bdb,0x7e619bdc,0x61e99bdd,0x00000000}},	//   _norh, _irop, _jidl, --, 
   {{0x61e82d75,0x9f4c2b1d,0xa3c06c52,0x7bb00124}},	//   _midl, _pudè_, ुता_, _аҩну, 
   {{0xb8e40597,0x69dc00ad,0xbb1800e4,0xdb1c6479}},	//   _ऋँ_, amre, chîp, kosé, 
   {{0x657d9bde,0x7f419bdf,0x61e801ab,0x60c812ed}},	// [2be90] _borh, _mboq, _oidl, _lydm, 
   {{0x443800b5,0x657c0076,0x7e60009f,0x61e99be0}},	//   ftp_, _corh, _mrop, _nidl, 
   {{0x7c399be1,0x657c3a1c,0xdb1c007f,0x00000000}},	//   nttr, _dorh, tosè, --, 
   {{0x7e619be2,0x61e8a793,0x7c380072,0x63059be3}},	//   _orop, _aidl, ittr, نومل, 
   {{0x657c1455,0x61e8003d,0x9f4c011f,0x60c800a2}},	//   _forh, _bidl, _gudé_, _aydm, 
   {{0x657c0a73,0x7f4000cf,0xdb1c01e6,0x61e99be4}},	//   _gorh, _aboq, llsä, _cidl, 
   {{0x61e8299d,0x7e619be5,0xdb1c068c,0x05bd9274}},	//   _didl, _arop, posè, ्तरब, 
   {{0xa4d410f5,0x61e80036,0x98a00055,0x657c00f1}},	//   _росі, _eidl, _abhī_, _zorh, 
   {{0x7c399be6,0x61e8286e,0x657c00f1,0x78b40381}},	//   ettr, _fidl, _yorh, _lxxv, 
   {{0xb0680532,0x657c02b9,0x7e600d63,0x61e80267}},	//   _وصال_, _xorh, _drop, _gidl, 
   {{0x7e619be7,0x5dbc005e,0x7c38005c,0x14e003d4}},	//   _erop, ﻧﻮﻣﻴ, gttr, খুৰী_, 
   {{0x61e81cdf,0x29c4007c,0x00000000,0x00000000}},	//   _zidl, jöar_, --, --, 
   {{0x7e619be8,0x7c399be9,0x61e95bef,0x24b000cc}},	//   _grop, attr, _yidl, _কৰাহ, 
   {{0xac802c1d,0x61e802b9,0x6e399bea,0xdb1c0112}},	//   _аҳол, _xidl, mtub, elsä, 
   {{0x248003a0,0x6e399beb,0x6d419bec,0x78b40393}},	//   _māmá_, ltub, _ibna, _cxxv, 
   {{0x657d9bed,0x6e380086,0x7e6002d0,0x44380254}},	//   _sorh, otub, _yrop, vtp_, 
   {{0x6e399bee,0x657c00a2,0x056400a7,0x7e600327}},	// [2bea0] ntub, _porh, нван, _xrop, 
   {{0x44380354,0x7ab8011a,0x36c0003b,0x00000000}},	//   ttp_, _מצפו, убуг, --, 
   {{0x0324a29d,0x657c0639,0x399800c8,0xc32400ee}},	//   еден, _vorh, _זייד, емек, 
   {{0x6e399bef,0x61e99bf0,0xb5f800dd,0x657c01e2}},	//   ktub, _sidl, _irán, _worh, 
   {{0x657ccc2e,0x61e99bf1,0xb5f99bf2,0xa1599bf3}},	//   _torh, _pidl, _tráa, далу_, 
   {{0x7c3805f7,0xdb1d9bf4,0xa3dc0490,0x61e80477}},	//   yttr, rosé, _ठळक_, _qidl, 
   {{0x7e600175,0x7dc40162,0xdb1c01e3,0x55c401af}},	//   _srop, iðst, llså, _рарғ, 
   {{0xdb1d9bf5,0x6d419bf6,0x63a00280,0x60c80064}},	//   posé, _abna, _ummn, _vydm, 
   {{0x61e82759,0x6e38d2b2,0x66059bf7,0x3d240248}},	//   _tidl, gtub, npik, _níwà_, 
   {{0x40944a8f,0x721806a9,0x5bc800dc,0x60c8017a}},	//   _прет, _מומח, रत्व, _tydm, 
   {{0x6e38b3a4,0x6604003e,0x9b94468b,0x2d140efc}},	//   atub, hpik, винц, رکوک_, 
   {{0x7c399bf8,0x6e380004,0x60c403ee,0x6d40eded}},	//   rttr, btub, ğimd, _ebna, 
   {{0x7e619bf9,0xb5f85f48,0x66040784,0xce3436ba}},	//   _urop, _arán, jpik, _لونک, 
   {{0xf2d01a4c,0xa0240639,0xb5f82195,0xdcf85946}},	//   טער_, _größ, _brán, _kovč, 
   {{0xda1c10f7,0xb5f99279,0x66040421,0xdcf800f3}},	//   _भटकत_, _crán, epik, _jovč, 
   {{0x7dc401a8,0x00000000,0x00000000,0x00000000}},	//   aðst, --, --, --, 
   {{0xfbdc27be,0x6604c900,0xdcf812fe,0xa3d4012d}},	// [2beb0] mmê_, gpik, _lovč, _सीध_, 
   {{0x57f4a85a,0xb5f99bfa,0x29c4007c,0xf7c400d1}},	//   _ипот, _frán, söar_, ﯩﻜﻠﻪ, 
   {{0xdcf804b9,0xb5f99bfb,0xd9d017de,0x660400b0}},	//   _novč, _grán, _مەڭگ, apik, 
   {{0x6e3972f7,0xe6b40432,0x00000000,0x00000000}},	//   ytub, lüýä, --, --, 
   {{0xe1f80efb,0x6e399bfc,0x4370027d,0xb5f8013a}},	//   егі_, xtub, شهور, _zrán, 
   {{0xb5f8032e,0x6e3801e4,0x7dc40162,0x00000000}},	//   _hráo, vtub, iðss, --, 
   {{0xf77c05d1,0xf33001ed,0x98a006be,0xadc000fb}},	//   _koç_, _مہاج, _kahı_, ғанһ, 
   {{0x6e399bfd,0xdb0c0124,0x1fb46d7d,0xdcf8013a}},	//   ttub, _okañ, лсыр, _dovč, 
   {{0x6e380286,0x7dc40174,0x00000000,0x00000000}},	//   utub, yðst, --, --, 
   {{0x6e399bfe,0x0d841c89,0xc0c0001f,0x918000d1}},	//   rtub, тлон, ድርም_, _خۇتۇ, 
   {{0xdb0c0022,0x660401c6,0xdcf8007f,0xa128007b}},	//   _akañ, zpik, _govč, _أكمل_, 
   {{0x660402d1,0xf77c0139,0x6e399bff,0x00000000}},	//   ypik, _noç_, ptub, --, 
   {{0x0d2015bf,0x2fdc002e,0x9e2419c5,0xdfd40153}},	//   _күпү, mmug_, _مىنو, _соцы, 
   {{0x64491be6,0xdcac0372,0xf77c0205,0x98b00064}},	//   _ädig, تۉۉ_, _aoç_, nezė_, 
   {{0xdb0c08e7,0xc7a42c08,0x7dc40ad9,0x660402d1}},	//   _ekañ, вивк, rðst, wpik, 
   {{0x80dc04c5,0x2fdc0076,0x0b4401d5,0xb5f80118}},	//   নুক্, nmug_, _рнин, _vrán, 
   {{0xf77d9c00,0x3cec0334,0x37e002a9,0x66044bbd}},	// [2bec0] _doç_, _ygfv_, ротг, upik, 
   {{0x66040490,0xb5f80016,0x80a0007d,0x398c0205}},	//   rpik, _trán, _कइले, _hüsn_, 
   {{0x660429ef,0x74100f2b,0xb5f99c01,0x14840014}},	//   spik, لولا, _hrál, ُشمُ, 
   {{0x66059c02,0xb5f80316,0xdcf80cf4,0xf99c0ba1}},	//   ppik, _král, _rovč, mpèa_, 
   {{0x27e19c03,0x66040d04,0x9f4c05d5,0x291897c7}},	//   mmin_, qpik, _dudì_, oara_, 
   {{0xf50002f6,0xf99c067c,0xb1408fa3,0x00000000}},	//   _взро, opèa_, инчл, --, 
   {{0x27e19c04,0x35a18cb1,0x73300131,0x291801c4}},	//   omin_, _тарг, _ھىكا, iara_, 
   {{0x27e19c05,0x9f4c026c,0xb5f81ab0,0x2fdc045a}},	//   nmin_, _gudì_, _orál, gmug_, 
   {{0x27e04ce6,0xd2940014,0x00000000,0x00000000}},	//   imin_, _یُہک, --, --, 
   {{0x29199c06,0x27e19c07,0x7c840153,0x00000000}},	//   jara_, hmin_, вуме, --, 
   {{0x27e19c08,0xdb0c0156,0xefd00092,0xc0e43b8f}},	//   kmin_, _skañ, _ያለዉ_, _рожк, 
   {{0x27e19c09,0xdd900133,0x00000000,0x00000000}},	//   jmin_, _گوت_, --, --, 
   {{0x29199c0a,0x27e19c0b,0xbf0c02ab,0xaa542bb6}},	//   fara_, dmin_, सरीन_, авяш, 
   {{0x7dc4066a,0xb5f80162,0xf77c0076,0x27e0005b}},	//   rðss, _drál, _soç_, emin_, 
   {{0x28f84d15,0xdb1c29d3,0xf77c0139,0x9f4c00d0}},	//   тесь_, losí, _poç_, _ludí_, 
   {{0xf77052c8,0xb5f80436,0x27e19c0c,0xdee4001f}},	//   جاس_, _frál, gmin_, _ማመን_, 
   {{0x95d814a4,0xdb1d9c0d,0x9f4c02f0,0x660400d8}},	// [2bed0] едат_, nosí, _nudí_, ипѓа, 
   {{0x2918f72d,0x27e19c0e,0x995453ab,0x7bcc05ac}},	//   cara_, amin_, _скоц, llcu, 
   {{0x80a005ba,0x9f4c0c86,0x27e19c0f,0x7bdc04cc}},	//   _केले, _pudì_, bmin_, _èpus, 
   {{0x92381049,0xb5f800d0,0x7bcc054e,0x9f4c0c5e}},	//   ечку_, _hrám, nlcu, _budí_, 
   {{0x47700131,0x6234084c,0xb5f80118,0x00000000}},	//   _уқту, иецу, _krám, --, 
   {{0xdb1c00dd,0xe1640145,0x7bcc0306,0x00000000}},	//   dosí, لدىي, hlcu, --, 
   {{0xefd02295,0x4fa48e38,0x73b80014,0x8fa4ccd5}},	//   _ያለው_, ликв, _قطرس_, лаке, 
   {{0xa3c000dc,0xdb1c00ae,0xf204022e,0x00000000}},	//   ुतः_, alsú, _аяжо, --, 
   {{0x29199c10,0xdb1c804d,0x2fdc01f5,0xb5f802f0}},	//   yara_, gosí, rmug_, _orám, 
   {{0xdb0c09cc,0x27e19c11,0x8d54361e,0x30a400f3}},	//   _skað, zmin_, утич, _ирев, 
   {{0x27e19c12,0x00000000,0x00000000,0x00000000}},	//   ymin_, --, --, --, 
   {{0xb5f8ea68,0x27e07885,0x60c405d1,0x0eb8010b}},	//   _arám, xmin_, şimc, _пулы_, 
   {{0xdb1c0077,0x6e640014,0x7dc41427,0x27e00205}},	//   cosí, _شۅدِ_, rðsr, vmin_, 
   {{0x2918013c,0x27e0031c,0x00000000,0x00000000}},	//   uara_, wmin_, --, --, 
   {{0xb5f99c13,0xf99c0d29,0x9c580184,0x27e19c14}},	//   _drám, nsèy_, _ашыу_, tmin_, 
   {{0x29199c15,0x27e19c16,0xb5f803b2,0xe7c40154}},	//   sara_, umin_, _trál, ্দ্য, 
   {{0xb5f99c17,0xf99c0066,0xdcf800dc,0x49c99c18}},	// [2bee0] _frám, mpèn_, _hovā, _плин_, 
   {{0x27e19c19,0x29199c1a,0xb5f986c3,0xf99c020c}},	//   smin_, qara_, _kráj, lpèn_, 
   {{0x7dc403b2,0x9f4c01ef,0x00000000,0x00000000}},	//   iðsp, _sudí_, --, --, 
   {{0x44259c1b,0x27e19c1c,0xdb1c0022,0x00000000}},	//   čo_, qmin_, mosã, --, 
   {{0x93a8027d,0xa18401e0,0xb6a068dc,0x00000000}},	//   خالف_, ғыҙл, _гиял, --, 
   {{0x201c0810,0xe2980166,0x00000000,0x00000000}},	//   tsvi_, наҗ_, --, --, 
   {{0x443c04c4,0xdcf8005f,0xc304136e,0x776c02d0}},	//   _ët_, _novā, _مبذو, _yncx, 
   {{0x2d8002f6,0xdb1d9c1d,0x00000000,0x00000000}},	//   öjen_, tosí, --, --, 
   {{0x01342010,0xefb001b9,0x6448013d,0x05140154}},	//   _معاد, حینگ, _ädib, ালীর_, 
   {{0xdd9000c6,0xdb1d9c1e,0xf650011a,0x00000000}},	//   زوج_, rosí, צצת_, --, 
   {{0xdcf800b8,0x717001f7,0x3f68011c,0x00000000}},	//   _covā, _دهلا, _пижо_, --, 
   {{0xdb1d9c1f,0x00000000,0x00000000,0x00000000}},	//   posí, --, --, --, 
   {{0xfcd4001f,0x00000000,0x00000000,0x00000000}},	//   ኪያጁ_, --, --, --, 
   {{0xbea400c7,0x19d800d1,0x2d540108,0x3ea00174}},	//   _иаҵк, ﯞﺍﻣﻠ, _бишь_, úktu_, 
   {{0xdcf80055,0xf77c0200,0xb5f80419,0x9b94030d}},	//   _govā, _hiçi_, _vrám, _вийц, 
   {{0x7d1854ef,0xf77c00ee,0x9f580022,0xdb1c005c}},	//   lats, _kiçi_, _ïrä_, jlsø, 
   {{0xb5f898c4,0x7010031c,0x67d4004e,0x95381367}},	// [2bef0] _trám, _ྋསྐུ_, соту, кзат_, 
   {{0x7d199c20,0x9f4c07c5,0xfafc0240,0xb5f802d2}},	//   nats, _ludà_, lcë_, _hrák, 
   {{0x5454311c,0xa8a4084c,0xb5f81d0e,0xfafc002e}},	//   рвет, _гряк, _krák, gdëg_, 
   {{0x7d199c21,0xfafc044e,0x9f4c04cc,0x1cb80327}},	//   hats, ncë_, _nudà_, _མཙན_, 
   {{0x7684084c,0x0cd03599,0xa3b802f2,0xb5f801ef}},	//   _сынж, _हर्म, دالر_, _mrák, 
   {{0x7d199c22,0xe1f19c23,0xd4c40166,0x25b80051}},	//   jats, سسه_, _көек, _gjrl_, 
   {{0x7d199c24,0xf77cf812,0x99582b57,0xb7c400fe}},	//   dats, _aiçi_, kážu_, লগীয়, 
   {{0x3e780024,0xfafc036e,0x00000000,0x00000000}},	//   kštą_, jcë_, --, --, 
   {{0x7d1928ff,0xe374052f,0xfcd40020,0xb14404fb}},	//   fats, _улты, ኪያጅ_, _میشم_, 
   {{0x7d199c25,0xb5f80241,0x2158326c,0x398c03b9}},	//   gats, _arák, _مجمع_, _qüsl_, 
   {{0x8c459c26,0x5f740502,0x8f7402d5,0xb5f802d2}},	//   шене, _گالر, _вулі, _brák, 
   {{0x7d1820ac,0x00000000,0x00000000,0x00000000}},	//   aats, --, --, --, 
   {{0x7d199c27,0x5f744667,0x6f199c28,0xf99c020c}},	//   bats, _دالر, mauc, rpèn_, 
   {{0x6f199c29,0x7d18136f,0xf99c00cf,0x00000000}},	//   lauc, cats, spèn_, --, 
   {{0xdb1c08fb,0xf99c4bc7,0xb5f808ce,0x00000000}},	//   ylsø, mpèl_, _frák, --, 
   {{0x6f1819a2,0x00000000,0x00000000,0x00000000}},	//   nauc, --, --, --, 
   {{0x46e89794,0x6b840421,0x3ab00daf,0x9f4c1ada}},	// [2bf00] тдан_, _ioig, _дәрт, _judá_, 
   {{0x75d047ed,0xf50400a8,0x6b859c2a,0x9f4c00d8}},	//   قيقا, инул_, _hoig, _mudá_, 
   {{0x6f180481,0x7af83974,0x2d8402d3,0x6b840037}},	//   kauc, žute, _ዝወሰዶ_, _koig, 
   {{0x43442db9,0x7d199c2b,0x051400bd,0x6b859c2c}},	//   редв, zats, ালের_, _joig, 
   {{0x6f199c2d,0x3f800008,0x42559c2e,0xdb1d9c2f}},	//   dauc, ökum_, ртет, rlsø, 
   {{0x9f4c0ffb,0x7d180117,0x6b859c30,0xdcb800df}},	//   _sudà_, xats, _loig, laĉe_, 
   {{0x7d19354e,0xdb1d19a1,0x6b8400ad,0x754401ed}},	//   vats, őzés, _ooig, észő, 
   {{0x6f180334,0x7c3c29ef,0x645d3077,0xdb1cf7b3}},	//   gauc, _äpri, _isri, kosá, 
   {{0x82a46be1,0xfafc0200,0x00000000,0x00000000}},	//   _тааж, vcë_, --, --, 
   {{0xbd68cf6f,0x6b840e89,0xb5f82b57,0xeb88008f}},	//   трие_, _aoig, _dráh, _אָ_, 
   {{0x1b1809fe,0x6b859c31,0x6f199c32,0x1c3800fd}},	//   лжны_, _boig, bauc, ызны_, 
   {{0x6f199c33,0x7fd40046,0x6b8461a1,0xb5f8148b}},	//   cauc, _тізі, _coig, _fráh, 
   {{0x6b859c34,0x7d199c35,0x6e908b4d,0xfafc02d3}},	//   _doig, pats, _ولما, rcë_, 
   {{0x82f4025c,0x645c014f,0x7d199c36,0x3e780024}},	//   _བུའུ_, _osri, qats, rštą_, 
   {{0x38a4022e,0x6b840e9e,0xdb1c04cc,0x58d46518}},	//   _bеra_, _foig, posà, совт, 
   {{0xd1cc0020,0x6b8435ea,0x398c0254,0x56f40120}},	//   _ብዛት_, _goig, _küsk_, спаѓ, 
   {{0x80a802a6,0x645c034c,0xb5f803b2,0xe75800d4}},	// [2bf10] _চুম্, _asri, _krái, шиті_, 
   {{0xd9559c37,0x00000000,0x00000000,0x00000000}},	//   _اندخ, --, --, --, 
   {{0x6b840407,0xf48406ed,0x6f199c38,0xe4a59c39}},	//   _yoig, јузн, yauc, орцо, 
   {{0xd0080daf,0x28c01fd2,0x00000000,0x00000000}},	//   ңеле_, _शुटि, --, --, 
   {{0x6f199c3a,0x645c00a2,0xb5f8007b,0x00000000}},	//   vauc, _esri, _orái, --, 
   {{0x9f4d9c3b,0xf4843eae,0x00000000,0x00000000}},	//   _judæ_, _кубн, --, --, 
   {{0x6f199c3c,0xbb180af2,0x799402d0,0x3d18012d}},	//   tauc, shîy, _mlxw, _मज़े_, 
   {{0x63682bf6,0x28b80302,0xb5f801e7,0xcf38109a}},	//   _круг_, יפוש_, _arái, учкі_, 
   {{0x0dc99c3d,0x6f199c3e,0x22954115,0x8d740228}},	//   ллий_, rauc, _дитя, مادا, 
   {{0x6b859c3f,0x6f199c40,0x8d58084c,0xd1300150}},	//   _soig, sauc, ушит_, _ءما_, 
   {{0x30a421db,0x6b859c41,0xbdc401c0,0xceb801ef}},	//   _трав, _poig, сгэж_, daře_, 
   {{0x8b943580,0x21f402dd,0xdcf80356,0xdb1c03b2}},	//   сроч, _اكەس, _povă, tosá, 
   {{0x0a3802d5,0xdef802d5,0xceb8013a,0x00000000}},	//   ычны_, _тых_, faře_, --, 
   {{0xb5f8007b,0xdb1c26f6,0xc278008f,0x00000000}},	//   _grái, rosá, ארשי, --, 
   {{0x6b859c42,0x00000000,0x00000000,0x00000000}},	//   _toig, --, --, --, 
   {{0xb5f802f0,0x7c2c0174,0x00000000,0x00000000}},	//   _osád, ábre, --, --, 
   {{0x854801c0,0x44f453b2,0xceb8013a,0x3df800df}},	// [2bf20] лзав_, مساز, baře_, ָלעד, 
   {{0xa31000bc,0x00000000,0x00000000,0x00000000}},	//   ार्ज_, --, --, --, 
   {{0x28c000dc,0x842817a0,0x044401af,0x69c8007f}},	//   _शुचि, ужев_, сеен, čded, 
   {{0x031801e7,0xd1cc0092,0x00000000,0x00000000}},	//   اتات_, _ብዛቱ_, --, --, 
   {{0xd04003b9,0x76d8014b,0x00000000,0x00000000}},	//   _iylə, _бурӣ_, --, --, 
   {{0x23601154,0x00000000,0x00000000,0x00000000}},	//   žij_, --, --, --, 
   {{0xdef80046,0x645d9c43,0x00000000,0x00000000}},	//   қық_, _usri, --, --, 
   {{0xb5f80597,0xf7e00075,0x99140073,0x42b40024}},	//   _srái, _ﺋﺎﻟﺪ, _तज्ञ_, _лёзу, 
   {{0xd1480050,0xb5f8007b,0x9df806ed,0xa3d4134e}},	//   _چشمن_, _prái, јнот_, _सीए_, 
   {{0x7bdc044e,0xb658008f,0x9d1808ca,0xd2b8009d}},	//   _shqu, נדיש, шоот_, _тусч_, 
   {{0x40959c44,0x1cd99c45,0xd6e484b8,0x00000000}},	//   _урат, рдны_, _कण्ठ_, --, 
   {{0x7994035a,0x2ba40118,0x00000000,0x00000000}},	//   _slxw, खोला, --, --, 
   {{0xb5f99c46,0x7ed40a2c,0x7ac40166,0xbdf800ec}},	//   _trái, _ازاا, ссне, _ڌرڻا_, 
   {{0x398c00af,0xf6ec0327,0xb5f80118,0x2e380a7c}},	//   _küsi_, _ཨུཏ྄, _kráv, _עגונ, 
   {{0xa3c810fa,0x7c04007b,0x00000000,0x00000000}},	//   उवा_, _ابتك, --, --, 
   {{0x5a340a0e,0xceb80118,0x6fc800d1,0x00000000}},	//   _днит, saře_, ﺗﻨﺎﺷ, --, 
   {{0xa3cc069f,0x3f8400b0,0x41b800dc,0x00000000}},	// [2bf30] रकन_, _moou_, ेवास, --, 
   {{0xe6100127,0xd0400213,0x00000000,0x00000000}},	//   عشق_, _eylə, --, --, 
   {{0x8cac21f6,0x28080118,0xb0a40037,0xa4d4003b}},	//   ुपयो, ětné_, _केंग, пофі, 
   {{0x3f84002e,0xf99c020c,0x60c40790,0x6ab003d4}},	//   _noou_, kpèk_, ğiml, _ঘৰটো, 
   {{0xb5f800e4,0x60c42fbe,0x7e6401bf,0x461400ec}},	//   _aráv, şiml, ækpl, _ووٽر, 
   {{0xb5f90bdf,0x4adc0073,0xdb1c01f4,0x00000000}},	//   _bráv, नेटव, losä, --, 
   {{0xd0080220,0x93e800c6,0xa3d4000d,0x816400db}},	//   шейе_, _نفسك_, _सीक_, تەلك_, 
   {{0xd9f801f9,0x00000000,0x00000000,0x00000000}},	//   ंदात_, --, --, --, 
   {{0x3f84021c,0xaa7800a2,0xb5f800d7,0xc1d00150}},	//   _doou_, _büýä_, _usád, _ﺘﻬﺩﺍ, 
   {{0xb5f805f7,0x8c487ffd,0x40b40050,0x6fc40037}},	//   _fráv, апов_, _ژھٹھ_, ावहू, 
   {{0xdb1c5f95,0x3f841132,0xb5f806ed,0xaa7800a2}},	//   kosä, _foou_, _gráv, _düýä_, 
   {{0x53c800af,0xb5f802d2,0x00000000,0x00000000}},	//   िकिश, _hráu, --, --, 
   {{0xb698084c,0xdb1c007c,0x6d440254,0x00000000}},	//   _sfân, dosä, õjas, --, 
   {{0x84001710,0x3f84013a,0x00000000,0x00000000}},	//   žđic, _zoou_, --, --, 
   {{0x87f805f5,0x2d859c47,0x3f84002e,0xc17005d0}},	//   рэгт_, _ione_, _yoou_, וחם_, 
   {{0x2d841aa1,0xdc2800f2,0x00000000,0x00000000}},	//   _hone_, _اسوه_, --, --, 
   {{0x2d859c48,0x05a99c49,0x00000000,0x00000000}},	// [2bf40] _kone_, авай_, --, --, 
   {{0x2d859c4a,0x2a61986a,0xdd1c02fb,0xdcb80115}},	//   _jone_, _isib_, záži, laĉa_, 
   {{0x2d859c4b,0xdef002d3,0xb5f801d3,0x00000000}},	//   _mone_, _ግዜን_, _csáb, --, 
   {{0xa3d41533,0xf3f40220,0x9988010b,0x2a60faa7}},	//   _सीख_, ініш_, _ataň_, _ksib_, 
   {{0x2a600135,0xdd1c0306,0x398c0254,0x00000000}},	//   _jsib_, váži, _süsi_, --, 
   {{0xb5f80745,0x2d840375,0x3f859c4c,0xdfd012ea}},	//   _práv, _none_, _soou_, کيب_, 
   {{0xe7cc03d4,0x5f9473b3,0x00000000,0x00000000}},	//   লগীয, зийт, --, --, 
   {{0x2d84b2e9,0x057400db,0x2a6001d5,0x0dc8001f}},	//   _aone_, _ااڭد, _osib_, _አለፈ_, 
   {{0x527400c2,0x2d859c4d,0x3f84021c,0x2a60025c}},	//   _нуфу, _bone_, _voou_, _nsib_, 
   {{0xb5f99c4e,0x23640369,0x9f880086,0x3b1831f7}},	//   _tráv, _hamj_, rûñ_, _seqq_, 
   {{0x2d859c4f,0xdcf8009b,0xb5f986e0,0xf99c033b}},	//   _done_, _lovć, _hrát, spèk_, 
   {{0xb5f803c6,0xfba99c50,0x2d859c51,0x2b400142}},	//   _krát, ртой_, _eone_, _ccic_, 
   {{0x2d859c52,0x290c4952,0x6fc40490,0x3eb0013d}},	//   _fone_, ıdan_, ावरू, _äyt_, 
   {{0x98a000b8,0x2d840375,0xed4c1c93,0x41c807f7}},	//   _adhā_, _gone_, _لپه_, ाकिस, 
   {{0x6d9c2776,0x37a8a92d,0x6ca00801,0x286961bd}},	//   _bêaf, атан_, _оръж, орто_, 
   {{0x5b159c53,0x2d859c54,0x7c640092,0x00000000}},	//   _эмит, _zone_, _ስያሜው_, --, 
   {{0x2d859c55,0xdb1d3c88,0x1a659c56,0x69c00118}},	// [2bf50] _yone_, rosä, _عیسی_, émec, 
   {{0xdb1c0847,0x00000000,0x00000000,0x00000000}},	//   sosä, --, --, --, 
   {{0xc8d051a5,0xf77c03e3,0x64486465,0xe3d400b8}},	//   _दुपट, _qiçs_, _ädil, _ṛcaṃ_, 
   {{0x23640007,0x998802fb,0xb5f99c57,0x00000000}},	//   _camj_, _staň_, _brát, --, 
   {{0xb5f809c2,0xc3c001c6,0x0fd4012d,0xa3d4012d}},	//   _crát, хөрл, _डीगढ, _सीओ_, 
   {{0xb5f99c58,0x00000000,0x00000000,0x00000000}},	//   _drát, --, --, --, 
   {{0xb5f80005,0x8e080032,0xa99c08a8,0xdcf800ef}},	//   _usáb, әнов_, שבור, _elvī, 
   {{0x2d859c59,0x23640007,0xb5f82507,0x00000000}},	//   _sone_, _gamj_, _frát, --, 
   {{0xb5f99c5a,0xa3d408e9,0x72a000d1,0x4dd4187f}},	//   _grát, _सीट_, _تەشن, зінф, 
   {{0xb5f808a5,0x2b400051,0xdce803e0,0x00000000}},	//   _hrás, _scic_, üoğl, --, 
   {{0xb5f8031d,0x2d859c5b,0x2a600003,0xcb68009b}},	//   _krás, _vone_, _ssib_, бане_, 
   {{0x9f059c5c,0x2a60004e,0x2d859c5d,0xdcf400e4}},	//   _قومو, _psib_, _wone_, _ñaĝu, 
   {{0x6e000075,0xa3cc1889,0x4a740139,0x00000000}},	//   _تېخن, रकत_, чынт, --, 
   {{0xaca000b4,0x2d859c5e,0x6abc23e9,0xf1c81fe7}},	//   _ahụi, _uone_, _उशीर, िविन, 
   {{0xab641473,0x7d780375,0xb5c00154,0x00000000}},	//   _قۇدى, _לנסו, ্গাচ, --, 
   {{0x2a600457,0x00000000,0x00000000,0x00000000}},	//   _tsib_, --, --, --, 
   {{0x45297c30,0xf1c8227c,0x44f81370,0x2a60022e}},	// [2bf60] йжан_, िवान, مراج_, _usib_, 
   {{0xfafc02d3,0x5974004e,0x00000000,0x00000000}},	//   ndën_, _жыюу, --, --, 
   {{0xb5f809e8,0x04499c5f,0x00000000,0x00000000}},	//   _brás, спек_, --, --, 
   {{0xb5f99c60,0x7c3c143a,0x644800ee,0x00000000}},	//   _prát, _åpre, _ädim, --, 
   {{0xb5f804d4,0x96b80107,0x00000000,0x00000000}},	//   _drás, _дуру_, --, --, 
   {{0xb5f86b07,0x47340502,0x00000000,0x00000000}},	//   _vrát, _برگز, --, --, 
   {{0xb5f8f50b,0xfafc00e8,0x3e5c0241,0x5fb0134e}},	//   _frás, ddën_, _ẹ̀wà_, _जगदल, 
   {{0x44399c61,0xb5f99c62,0x00000000,0x00000000}},	//   mup_, _trát, --, --, 
   {{0x44399c63,0x398c04e6,0xb5f802d2,0x00000000}},	//   lup_, _küst_, _hrár, --, 
   {{0x398c01c7,0x00000000,0x00000000,0x00000000}},	//   _jüst_, --, --, --, 
   {{0x44399c64,0x2c200724,0x65a00213,0x91a801d3}},	//   nup_, ньяг, _töhf, _بچنے_, 
   {{0x443804fb,0x200c0455,0xbe4804fb,0x34b4011a}},	//   iup_, _itdi_, _هشتم_, לפים_, 
   {{0x44399c65,0xdef40006,0x00000000,0x00000000}},	//   hup_, _ўплы, --, --, 
   {{0x7e619c66,0x9f5800e4,0xf80401d5,0x7dc40162}},	//   _isop, _îrâ_, зчан, yðsy, 
   {{0xa3cc038e,0x7e60003e,0xa3dc0a8a,0x44399c67}},	//   रका_, _hsop, डता_, jup_, 
   {{0x44385589,0x7c399c68,0xdef000b7,0xdcb80115}},	//   dup_, mutr, _ቃሉን_, laĉo_, 
   {{0x7bcc070d,0x9f4c01a2,0xb5f80241,0x7e600175}},	// [2bf70] mocu, _budú_, _arár, _jsop, 
   {{0x7bcd0ef1,0xfd540241,0x7e600334,0x75800133}},	//   locu, _angẹ, _msop, ریزم, 
   {{0x443850f9,0x96f80311,0x5fcc05c0,0xb5f8022a}},	//   gup_, _мент_, ावाल, _prás, 
   {{0x7bcd9c69,0x7e60201d,0x64c401d5,0x7dc40162}},	//   nocu, _osop, رينل, rðsy, 
   {{0xb5f8724e,0xa29402bf,0x7c38004d,0x767001e0}},	//   _vrás, наці, hutr, _яңау, 
   {{0xb90801e1,0x44399c6a,0x398c07de,0xb5f803f2}},	//   _adiẹ_, bup_, _güst_, _frár, 
   {{0x7e600cad,0xb5f802d2,0x41a4012d,0x20540139}},	//   _asop, _grár, कोइस, етыр, 
   {{0x7bcd9c6b,0xf99c0ba1,0x398c002f,0x8e0800f5}},	//   jocu, mpèu_, _küss_, онив_, 
   {{0x200d9c6c,0x7bcc0429,0x7e6000dd,0xcd341ec7}},	//   _etdi_, docu, _csop, وردب, 
   {{0x7c3804cc,0x00000000,0x00000000,0x00000000}},	//   futr, --, --, --, 
   {{0x7e619c6d,0x7bcd9c6e,0xdcf800bc,0x509400ec}},	//   _esop, focu, _hově, _تلاء, 
   {{0x7bcc0077,0x09c40a8a,0x00000000,0x00000000}},	//   gocu, लक्य, --, --, 
   {{0x65a00639,0x44398bab,0x7c380129,0x00000000}},	//   _höhe, zup_, autr, --, 
   {{0x44399c6f,0x7c3802fa,0x6e380083,0x988000ef}},	//   yup_, butr, muub, bīļa_, 
   {{0x44380204,0x6e399c70,0x65a001ed,0x6d40035a}},	//   xup_, luub, _jöhe, _icna, 
   {{0x7e600022,0x4c040014,0x65a00166,0xfafc00e8}},	//   _ysop, _ٹِکل, _möhe, ndël_, 
   {{0x60c40365,0x44399c71,0xdcf800bc,0x6e388442}},	// [2bf80] ğimi, wup_, _nově, nuub, 
   {{0x60c4e03b,0x96b800f7,0xa3b00807,0x9aa4009f}},	//   şimi, чусу_, टोन_, _سمپو, 
   {{0x6e399c72,0x07a59c73,0x44380194,0x4344b9df}},	//   huub, _жанн, uup_, деев, 
   {{0x44399c74,0x398d9c75,0x6e399c76,0x00000000}},	//   rup_, _füss_, kuub, --, 
   {{0x44399c77,0x7c380e78,0x85600022,0x6d4002d0}},	//   sup_, zutr, _иҽаҧ, _ocna, 
   {{0x44399c78,0x6e3801d9,0x7bcd9c79,0x672405b1}},	//   pup_, duub, zocu, laij, 
   {{0x44399c7a,0xf99d03b5,0x7e600327,0x03240798}},	//   qup_, mpèt_, _ssop, _одвн, 
   {{0x672408e7,0x7e60020c,0x6d4002d0,0x6e380337}},	//   naij, _psop, _acna, fuub, 
   {{0x66040107,0x4428007c,0x00000000,0x00000000}},	//   nqik, _hvb_, --, --, 
   {{0x672407dd,0x200c05b1,0x4124211f,0x7c38007c}},	//   haij, _ttdi_, _آفاق, tutr, 
   {{0x7534025f,0x67259c7b,0x7bcd9c7c,0x442803b2}},	//   ואיד_, kaij, tocu, _jvb_, 
   {{0x69c19c7d,0x7c399c7e,0x7e600925,0x6724009f}},	//   émen, rutr, _tsop, jaij, 
   {{0x7e60009a,0x7bcd9c7f,0x6e380067,0xb4c802c3}},	//   _usop, rocu, cuub, _लड्_, 
   {{0x7c399c80,0x7bcc3756,0x6d4000ae,0x65a001f4}},	//   putr, socu, _gcna, _yöhe, 
   {{0x398cf2fa,0xb5f8772a,0xf7706884,0x442801f5}},	//   _süss_, _aráp, پاز_, _nvb_, 
   {{0x398c000d,0x00000000,0x00000000,0x00000000}},	//   _püss_, --, --, --, 
   {{0xfafc5993,0x55759c81,0x66040944,0x6d4002d0}},	// [2bf90] ndëm_, нгат, gqik, _ycna, 
   {{0xb5f99c82,0x44299c83,0x00000000,0x00000000}},	//   _dráp, _bvb_, --, --, 
   {{0x44299c84,0x00000000,0x00000000,0x00000000}},	//   _cvb_, --, --, --, 
   {{0x6e389f02,0x66d801f2,0xdcf800bc,0x00000000}},	//   yuub, ụkas, _sově, --, 
   {{0xdcf8012c,0x7d08f24e,0x35f00124,0x6e38058a}},	//   _pově, _offs, _аҿар, xuub, 
   {{0xdef4044e,0xb69800e4,0x442802d2,0x00000000}},	//   _ጌርካ_, _agâg, _fvb_, --, 
   {{0xdb0c0165,0x442801a4,0x38a4022e,0x6e380a49}},	//   _emaé, _gvb_, _bеri_, wuub, 
   {{0x0e6414b7,0xcf4405f5,0x7d08127b,0x6e380c90}},	//   екин, хний, _affs, tuub, 
   {{0xa3cc13b4,0x44280175,0x7bc401a6,0x35c000cc}},	//   रकर_, _zvb_, čkul, ্গীহ, 
   {{0x4c848372,0xfde40228,0x3f800008,0x6e399c85}},	//   елов, ндык_, ökur_, ruub, 
   {{0x6e382f99,0xcb69708d,0x0f3400c0,0x00000000}},	//   suub, пане_, _зэля, --, 
   {{0x7d0802d0,0xdb1c02e2,0xcb6824fc,0x8c9401ec}},	//   _effs, nnsè, чаме_, _үркі, 
   {{0x67259c86,0xc3300bd4,0xdb1c0267,0x00000000}},	//   vaij, נוך_, ylsö, --, 
   {{0xc210159d,0x6c00016c,0x6724009f,0x7d040022}},	//   רהם_, _иҷоз, waij, _pũrũ, 
   {{0x66040309,0xa92800de,0x9d4402da,0x00000000}},	//   wqik, _režģ, _شئون, --, 
   {{0x66040d04,0x442814ac,0x06080124,0x7c3c03cd}},	//   tqik, _rvb_, знак_, _åpra, 
   {{0xb6a0ccce,0x67259c87,0x44281eff,0x8c54009f}},	// [2bfa0] гитл, raij, _svb_, _آئڪا, 
   {{0x56e4052f,0x65a10563,0xb5f800d2,0x67240083}},	//   тбуғ, _söhb, _tsán, saij, 
   {{0xb5f804d4,0x6fcc0073,0x67258750,0x00000000}},	//   _usán, हकां, paij, --, 
   {{0x741003b6,0xb5f80122,0x77801b04,0x2918036e}},	//   اونا, _tráp, _блюз, lbra_, 
   {{0x660420ac,0xf99c0066,0x69dc0af9,0x1300013e}},	//   qqik, mpèr_, olre, рҷум, 
   {{0x442801fb,0x291834c1,0x720002f2,0x00000000}},	//   _tvb_, nbra_, دووم, --, 
   {{0xdb0c0209,0x69dd9c88,0xf9900375,0x00000000}},	//   _ajaý, ilre, ררו_, --, 
   {{0x69dd9c89,0xbfa88ca3,0x00000000,0x00000000}},	//   hlre, ятле_, --, --, 
   {{0xd3448198,0x63a18f7e,0x99980124,0x77b8013d}},	//   _شیوه_, _ilmn, susũ_, läxä, 
   {{0x6e5005d9,0x69dc3b85,0x00000000,0x00000000}},	//   ائيء, jlre, --, --, 
   {{0xb5f80241,0x63a001e4,0xcfa805d9,0x291801e4}},	//   _asál, _klmn, _ڪالم_, dbra_, 
   {{0x69dd9c8a,0x29183eba,0x2d8001e6,0x6ca00276}},	//   elre, ebra_, öjer_, урьж, 
   {{0x8f5000db,0x6c80516c,0xdb1c0332,0x00000000}},	//   _ئچىش, _ەلىم, nnsé, --, 
   {{0x69dc0158,0x7d08127b,0xdd919c8b,0xa3b00073}},	//   glre, _uffs, _خوت_, टोत_, 
   {{0x58d59c8c,0x383002d3,0xadd40375,0x00000000}},	//   товт, _ክልቲአ, _רווח_, --, 
   {{0x67d59c8d,0xf771692e,0x657c00a9,0x69dc0334}},	//   госу, داس_, _anrh, alre, 
   {{0x29199c8e,0xb18000d7,0x56f40798,0x00000000}},	// [2bfb0] bbra_, úťko, тпаѓ, --, 
   {{0x69dc0334,0xf99c0129,0xa2700023,0xb86400ae}},	//   clre, rpès_, _ባርካን_, _كاجو, 
   {{0xf2dc0652,0x430c01f2,0xc9500375,0xf99c00cf}},	//   _šâ_, _ịpị_, _דמי_, spès_, 
   {{0x657c00b5,0x61e80169,0x32e40cad,0x92940006}},	//   _enrh, _ahdl, _nìyí_, каец, 
   {{0x45a00131,0x00000000,0x00000000,0x00000000}},	//   _ھەمك, --, --, --, 
   {{0x666400a7,0xdb0c0254,0xb5f001ec,0x77b80139}},	//   _съюз, _ajaü, _сүзі, bäxä, 
   {{0xcfe80066,0x00000000,0x00000000,0x00000000}},	//   وفته_, --, --, --, 
   {{0xa3cc00dc,0x99980118,0x00000000,0x00000000}},	//   रकः_, kusů_, --, --, 
   {{0x8d747afb,0x69dc0076,0x00000000,0x00000000}},	//   نادا, ylre, --, --, 
   {{0x30a46bed,0xfe4000d6,0x65a0000d,0x646802d2}},	//   _прев, шньо, _köha, _írið, 
   {{0xbdc401c6,0xcc080014,0xe2340023,0x00000000}},	//   тгэж_, بٲجن_, _ኣርሰና, --, 
   {{0x09d80574,0x81c8009e,0x8b945ff9,0x65a0008e}},	//   णत्य, োষণ_, троч, _möha, 
   {{0x291801e3,0x29f000a2,0x8d640d1d,0x00000000}},	//   tbra_, _ońat_, _авле, --, 
   {{0x7b0c1682,0x29180280,0xcf24004b,0xdb2400bc}},	//   _ṱuts, ubra_, _سرچي, ěpán, 
   {{0xca7400d1,0xe748008e,0x00000000,0x00000000}},	//   راڭغ, нүне_, --, --, 
   {{0x99980118,0xa8a400db,0x2918007c,0x00000000}},	//   busů_, _ەلدۉ, sbra_, --, 
   {{0x49c801a9,0x00000000,0x00000000,0x00000000}},	// [2bfc0] _олин_, --, --, --, 
   {{0x26dc0882,0x44f40e4a,0xf99c0ba1,0x00000000}},	//   āvo_, نساز, spèr_, --, 
   {{0x03259c8f,0x75d000c6,0xb9340375,0x04440139}},	//   вден, جيلا, _בניו_, теен, 
   {{0x78a003be,0x7330104b,0xdcf803b9,0x54d401c6}},	//   _ünva, لىما, _lovğ, уцуу, 
   {{0x63a00175,0xb7b001c6,0xa158117e,0x00000000}},	//   _vlmn, _төрч, еалу_, --, 
   {{0x657c0f7b,0xdb0c0268,0xdcf80166,0x00000000}},	//   _unrh, _amaì, _novğ, --, 
   {{0x443c030a,0x55c48f62,0xb9c80092,0xa6c400eb}},	//   _êt_, _сарғ, _ደዌ_, _শরিয়, 
   {{0xfe40036b,0xdec40166,0x00000000,0x00000000}},	//   لکتی, ләло, --, --, 
   {{0xdb0c0129,0xdcb801e4,0x80a800cc,0x245c0241}},	//   _smaï, maĉi_, _চুখ্, bàmò_, 
   {{0xb5f801e1,0x04ec002b,0x00000000,0x00000000}},	//   _asáj, _sāṃt, --, --, 
   {{0x60c40205,0x00000000,0x00000000,0x00000000}},	//   ğims, --, --, --, 
   {{0x4438679d,0xef1400d8,0x60c403e0,0x00000000}},	//   irp_, _амц_, şims, --, 
   {{0xce3400b2,0x75e0063f,0x00000000,0x00000000}},	//   _مونک, ọzir, --, --, 
   {{0xa9c59c90,0x7c3c143a,0x45cc00d1,0xaec00139}},	//   асск, _åpro, ﻐﺎﻧﻼ, _әбәл, 
   {{0x032005f9,0x77900811,0xed5452d1,0xec653e84}},	//   मराह_, لیدا, _рој_, _арык_, 
   {{0xb8d8c6cd,0x4438054e,0xdb1c0254,0xdb1001e1}},	//   _आइ_, drp_, nosü, _ìfàk, 
   {{0x44399c91,0xe7845e0c,0xb9c4014b,0x00000000}},	// [2bfd0] erp_, шуро, _аёни, --, 
   {{0xfbdc011f,0x7c380af9,0x9f4c013a,0x00000000}},	//   llê_, ortr, _rudý_, --, 
   {{0xd174e17f,0xf7e800c6,0xb5f802f0,0xaee000b8}},	//   ғылы, _يرجى_, _usám, _kiṣk, 
   {{0x9f4c0789,0x7c380158,0xfbdc0af9,0x44440014}},	//   _mudó_, irtr, nlê_, ارٕہ, 
   {{0xdb1c5178,0x4438000f,0x7c38fbba,0xf77cf77f}},	//   losó, arp_, hrtr, _inç_, 
   {{0x65a00086,0xe1f80212,0xdb10032e,0x75e80432}},	//   _höhn, вгі_, _ógæf, düzg, 
   {{0x65a000ac,0x24f87aa6,0xdb1c00c5,0x7c3800b5}},	//   _köhn, _анры_, fosü, jrtr, 
   {{0xaee00882,0x00000000,0x00000000,0x00000000}},	//   _niṣk, --, --, --, 
   {{0x7c38057d,0x65a19c92,0x00000000,0x00000000}},	//   ertr, _möhn, --, --, 
   {{0x0d84013e,0x65a00e78,0xdcf803b9,0x221001e2}},	//   улон, _löhn, _qovğ, _بېوز, 
   {{0xdb0cf0e9,0x75e82fbe,0xdb1c00e4,0x7e6401bf}},	//   _ajañ, müzd, josó, ækpr, 
   {{0x9f4c0407,0xfbdc017a,0x4fc000f7,0x9e240137}},	//   _dudó_, glê_, _دەبە, _چىنو, 
   {{0x6f199c93,0xceb8012c,0x44380810,0xb5f83df9}},	//   mbuc, kaři_, zrp_, _csák, 
   {{0x8c459c94,0x2fdd9c95,0x6e39071e,0x6f188eb5}},	//   _беке, llug_, mrub, lbuc, 
   {{0x58959c96,0xc4bc00bd,0x9f4c19f5,0xdb1c0005}},	//   ашту, _অর্জ, _iudò_, gosó, 
   {{0x6f199c97,0x17c400c7,0x2be00073,0x00000000}},	//   nbuc, аасҭ, नतळा, --, 
   {{0xd624038b,0x7c8402d3,0x2fdc02b5,0x85e8480e}},	// [2bfe0] لعلي, _ንመሰል_, ilug_, едав_, 
   {{0xc96422e9,0xf77c067c,0xdb1c0077,0x2fdc0e78}},	//   _свой, _enç_, bosó, hlug_, 
   {{0x9f4c0c86,0x6e380306,0xdb1c642b,0x74106646}},	//   _pudü_, hrub, mosò, مولا, 
   {{0x42c8113e,0x7c2d9c98,0x2fdc0211,0xdb1c5b80}},	//   нген_, ábri, jlug_, losò, 
   {{0x6e380198,0x84e405f9,0x4438009a,0xdb0c08a5}},	//   jrub, _करवट_, srp_, _mjað, 
   {{0x6e399c99,0xdb1c067c,0x2fdc00e8,0x7c3803cd}},	//   drub, nosò, elug_, yrtr, 
   {{0x27e19c9a,0x2fdd9c9b,0x6e385a25,0xaf300131}},	//   olin_, flug_, erub, ڭرىت, 
   {{0x5f94295e,0x645d9c9c,0x27e19c9d,0xb140760c}},	//   риит, _ipri, nlin_, анәл, 
   {{0x27e19c9e,0x6e399c9f,0xdd9000c6,0xae2401c6}},	//   ilin_, grub, قوة_, лцэж_, 
   {{0x27e19ca0,0xa3b011b1,0x645c05b1,0x64480793}},	//   hlin_, टोर_, _kpri, _ädis, 
   {{0x6f180204,0x2fdd9ca1,0xfe70abd7,0x6e390027}},	//   bbuc, blug_, _گدا_, arub, 
   {{0x645d9ca2,0x6e38003a,0x802c0327,0x1bd40064}},	//   _mpri, brub, _ལྷག༵_, ромя, 
   {{0x27e19ca3,0x645c0472,0xe7f846c7,0xfbdc05e4}},	//   dlin_, _lpri, ंगना_, rlê_, 
   {{0x645d9ca4,0xf2d004ac,0xdb1c0005,0x65a00e78}},	//   _opri, מער_, tosó, _söhn, 
   {{0x27e19ca5,0xdb0c148b,0x52c003ce,0x00000000}},	//   flin_, _fjað, _शख्स, --, 
   {{0x27e19ca6,0xc4bc03d4,0xdb1c012d,0x00000000}},	//   glin_, _অৰ্জ, rosó, --, 
   {{0x779007d6,0xdb1c0077,0xba68007b,0xab2816a4}},	// [2bff0] لیگا, sosó, _أحبك_, _соња_, 
   {{0x27e19ca7,0x6f183cfe,0x645c15eb,0x65a0002f}},	//   alin_, zbuc, _bpri, _wöhn, 
   {{0x645c07ab,0x27e19ca8,0xc8f801d9,0xf4d0009e}},	//   _cpri, blin_, _لوٝچ_, ়ধ্ব, 
   {{0x27e19ca9,0xb7659caa,0x645cabd5,0x65a017da}},	//   clin_, _стой, _dpri, _höhl, 
   {{0x645d9cab,0xfdf40c2e,0x2fdc05e4,0xc7640131}},	//   _epri, ीदास_, vlug_, _ئاپى, 
   {{0x645d9cac,0xf1e002f5,0x505800a7,0x22799cad}},	//   _fpri, মদ্ভ, вшия_, الوگ_, 
   {{0x10a59cae,0x1cb00003,0xefd00020,0x65a00209}},	//   рийн, ྟགས_, _ካለው_, _möhl, 
   {{0xe3b012dd,0x6e39936e,0x65a001f4,0x2fdc01a9}},	//   _فرق_, trub, _yöho, ulug_, 
   {{0x6f199caf,0xddc88bbb,0x2fdc0194,0xcee802e8}},	//   rbuc, _šošk, rlug_, ъдие_, 
   {{0xdcf80029,0x6e38d553,0x27e03445,0x6f199cb0}},	//   _novē, rrub, zlin_, sbuc, 
   {{0x2fdd9cb1,0x27e19cb2,0x6e3801e6,0x752400f3}},	//   plug_, ylin_, srub, _mejz, 
   {{0x6e38ca60,0x75259cb3,0xdb1c0100,0x27e04cd5}},	//   prub, _lejz, wosò, xlin_, 
   {{0x27e195ab,0x65a0002f,0xd0400451,0xb5f80118}},	//   vlin_, _böhl, _اھڙي, _dráz, 
   {{0x27e19cb4,0x7524012c,0x8ac401b9,0xbe1000db}},	//   wlin_, _nejz, лққа_, _بووع, 
   {{0x27e045a2,0x8c44052f,0xb5f80122,0x4c6801c6}},	//   tlin_, _тейе, _fráz, _рийн_, 
   {{0x27e0030a,0xb5f802f0,0x00000000,0x00000000}},	//   ulin_, _gráz, --, --, 
  
   {{0xb698084c,0x068407d6,0x27e0e77d,0xc514221c}},	// [2c000] _sfâr, шган, rlin_, لبات, 
   {{0x645c13be,0x291c0124,0xb5f800d0,0x69c00100}},	//   _ppri, _ýva_, _zráz, èmed, 
   {{0xfa0008ea,0x80d80073,0x04480150,0x00000000}},	//   _མངོན_, _पुढे, тпек_, --, 
   {{0xa3b0068f,0x645c0010,0x74100214,0x27e19cb5}},	//   टों_, _vpri, زوها, qlin_, 
   {{0xd90c0583,0x75240439,0x00000000,0x00000000}},	//   _آیہ_, _fejz, --, --, 
   {{0x645c0334,0x75e800e5,0x00000000,0x00000000}},	//   _tpri, tüze, --, --, 
   {{0x5f9400f7,0x9f3402dd,0x645c0f85,0x00000000}},	//   йикт, бейі, _upri, --, 
   {{0x80d80490,0x00000000,0x00000000,0x00000000}},	//   _पुणे, --, --, --, 
   {{0xb5f80248,0xfafc0023,0x1b240154,0x2ef00395}},	//   _aráy, ndët_, _ভালই_, озър, 
   {{0xdcf800dc,0x3d140490,0xdd900214,0xb5f8013a}},	//   _anvā, पुढे_, سوج_, _sráz, 
   {{0xb5f803c6,0xed8400f7,0xb6980208,0xf1dc0950}},	//   _práz, рсык_, _ngân, _पीटन, 
   {{0xa3cc000b,0x28bc00dc,0x00000000,0x00000000}},	//   रकट_, ोपनि, --, --, 
   {{0xeabc015b,0xdcb0192c,0x6fb000c6,0xdb1c00d8}},	//   вιт_, زىڭ_, _بمنا, ensã, 
   {{0x6b5c04ce,0x65a032e9,0xb5f800ae,0x5bb802dd}},	//   _pågæ, _böhm, _tsái, _әлия_, 
   {{0xada00f14,0x75240427,0xb5f800ae,0x6da01d39}},	//   _фајл, _rejz, _usái, _фија, 
   {{0x6cf8011a,0xcce4009f,0x00000000,0x00000000}},	//   _בפוס, _اسهي, --, --, 
   {{0x75253dc8,0xc0cc0020,0x776c004d,0x929c012d}},	// [2c010] _pejz, _ሥላሴ_, _vacx, _ogła, 
   {{0x82280023,0x00000000,0x00000000,0x00000000}},	//   ትእስሳ, --, --, --, 
   {{0x54559cb6,0x75240841,0xb8640133,0xe3b000e5}},	//   свет, _vejz, _ئاخو, ڈرن_, 
   {{0xb4e417e6,0xe3b19cb7,0x00000000,0x00000000}},	//   _परी_, ورن_, --, --, 
   {{0x75259cb8,0x76840276,0x24680166,0x62240131}},	//   _tejz, _тынж, _eşm_, قىنل, 
   {{0xb4b09e04,0xd9f80034,0x00000000,0x00000000}},	//   _дигә, ूदित_, --, --, 
   {{0xb5f802f0,0xbae002dd,0x6448008e,0x00000000}},	//   _vpád, _ﺍﺭﺑﺎ, _ädip, --, 
   {{0xfafc02d3,0xa3d4094e,0x15e4012d,0x92e400cc}},	//   ndës_, _досч, कतवर_, _নলী_, 
   {{0xe7f80490,0x00000000,0x00000000,0x00000000}},	//   ंगता_, --, --, --, 
   {{0xcda81060,0x63a40022,0x0ca00240,0x00000000}},	//   اهده_, _лыӡҕ, _ዝመርጽ_, --, 
   {{0x1b8c02d3,0x00000000,0x00000000,0x00000000}},	//   _ንረኽቦ_, --, --, --, 
   {{0xe0d19cb9,0x09b00b9c,0x929c033f,0x620401ef}},	//   _غزل_, ुच्य, _zgła, _útlé, 
   {{0xb5f80005,0x00000000,0x00000000,0x00000000}},	//   _fráx, --, --, --, 
   {{0xe6b40166,0x00000000,0x00000000,0x00000000}},	//   lüçä, --, --, --, 
   {{0x4c1400c6,0x5edc0154,0x00000000,0x00000000}},	//   _ابتس, মেদে, --, --, 
   {{0x8320009e,0x07a402e8,0x4b2437ab,0x60e4010b}},	//   _পঞ্চ_, щабн, _умив, _ýumş, 
   {{0x46e80c75,0x6b84cba2,0xe4d003be,0xe80572e1}},	// [2c020] удан_, _inig, _küçə, _शंका_, 
   {{0x6b84032e,0x65a06cba,0xfafc0200,0x75e803e0}},	//   _hnig, _töhm, adës_, vüzc, 
   {{0x2a600175,0x69c006af,0xdcf80356,0xe7f803ce}},	//   _hpib_, émeu, _invă, ंगदा_, 
   {{0x6b840327,0xdb1c0332,0x68e81427,0x43440395}},	//   _jnig, onsá, ýddu, седв, 
   {{0x42540c56,0x6b84009f,0x6234c70f,0x2468010e}},	//   стет, _mnig, целу, _wşm_, 
   {{0x25b809a8,0x65a000ac,0x2098660c,0x1724031c}},	//   _umrl_, _möhk, иклы_, _འབོམ_, 
   {{0xfafc069c,0x6b859cba,0x443c07ae,0x0ed40037}},	//   ndër_, _onig, _ít_, _डँउड, 
   {{0xdb0c0113,0x7c3c03cd,0x835400f1,0xdfd0a5d1}},	//   _imaç, _åpri, _دپرا, بيب_, 
   {{0x2a6001d4,0xf7700375,0x82a40124,0xfbf001c6}},	//   _npib_, לקה_, _уааж, үүль, 
   {{0x6b859cbb,0xdb1c0793,0xc390032e,0x00000000}},	//   _anig, nosö, _áíbú, --, 
   {{0x65a00254,0x70500150,0x7fd4003b,0x00000000}},	//   _pöhj, _ىنكا, _ліді, --, 
   {{0xb5f800d8,0xdb1c02d2,0x00000000,0x00000000}},	//   _usáv, fnsá, --, --, 
   {{0xb5f8056a,0xdb1cc2f8,0xa3b0000d,0x2fd4009f}},	//   _tráx, kosö, _ओतन_, _اوند_, 
   {{0x6b850127,0xdeb00046,0xe804000d,0x00000000}},	//   _enig, _нұқы, _शंखा_, --, 
   {{0xb4e4190c,0xdb1c0793,0xf65c03b2,0x00000000}},	//   _परे_, dosö, _spæ_, --, 
   {{0x98a000ef,0x00000000,0x00000000,0x00000000}},	//   _cehā_, --, --, --, 
   {{0xdb0c0365,0x65a005d5,0xfafc0240,0x98a00055}},	// [2c030] _amaç, _göhk, adër_, _dehā_, 
   {{0x1dc8a06f,0xdd080030,0x00000000,0x00000000}},	//   िचित, _lôžk, --, --, 
   {{0xf2c40724,0xd79400d1,0x931800c6,0xc608009e}},	//   әсен, _динъ, لقاء_, শীলা_, 
   {{0x57481e87,0x6b840327,0xdd080419,0x00000000}},	//   _өзүм_, _xnig, _nôžk, --, 
   {{0x9104094d,0x7994009a,0x00000000,0x00000000}},	//   опле, _koxw, --, --, 
   {{0xe5c401af,0x00000000,0x00000000,0x00000000}},	//   _ессо, --, --, --, 
   {{0x299c0375,0x712400db,0xfe6c02f2,0x00000000}},	//   רסומ, _ۇرال, ێگه_, --, 
   {{0x7bdc021a,0x7994009a,0xa3b0000d,0x53a400ae}},	//   _nkqu, _loxw, _ओतय_, _بمرك, 
   {{0x6b84036b,0xd2512143,0xdb1c067c,0xe0540014}},	//   _rnig, _زنا_, misè, _ہیوت_, 
   {{0x6b859cbc,0x799401e2,0xdb1d9cbd,0x7bdc0112}},	//   _snig, _noxw, lisè, _akqu, 
   {{0x31640bac,0x30a4537c,0xb4e400cd,0x0ed4000d}},	//   menz_, _урав, _परो_, _डँकड, 
   {{0x224038bb,0x9508025c,0xdb1d9cbe,0x31640112}},	//   šike_, _ཇུའི_, nisè, lenz_, 
   {{0x79949b7d,0x6ee42303,0x00000000,0x00000000}},	//   _boxw, _اسال, --, --, 
   {{0x31640d16,0x3ea0168c,0x26c40171,0x00000000}},	//   nenz_, økte_, _ģmo_, --, 
   {{0x929c006d,0x7bcc0129,0x00000000,0x00000000}},	//   _ogło, ébuc, --, --, 
   {{0x6b840cfd,0xdb1d9cbf,0xc1b407b7,0x92e400cc}},	//   _unig, jisè, _अग्ग, _নলৈ_, 
   {{0x3164061c,0xdb1c007f,0xfafc0036,0xdb0c0205}},	// [2c040] kenz_, disè, leën_, _smaç, 
   {{0xdb1c782c,0xba980375,0x04440212,0x65a0000d}},	//   gnsæ, _כספי, жежн, _köhi, 
   {{0x31659cc0,0xb5f802fb,0x65a000a2,0x00000000}},	//   denz_, _spác, _jöhi, --, 
   {{0x65a00724,0x69dd9cc1,0x9f4c0798,0x7994009a}},	//   _möhi, lore, _judô_, _zoxw, 
   {{0xd36c049e,0x79940472,0x84e402e5,0xb5f801d3}},	//   دۇق_, _yoxw, _करकट_, _csás, 
   {{0x31645239,0xddc002b5,0xdb1c2568,0x71f42dd0}},	//   genz_, tumō, tisë, يروس_, 
   {{0xbfa82c71,0x03a59cc2,0x69dd7341,0xfafc0af9}},	//   итие_, _диво, iore, jeën_, 
   {{0x0244f703,0xdfd00491,0xdb1c0023,0xddc000b0}},	//   _وَأَ, عية_, risë, rumō, 
   {{0x69dc633d,0x3164c250,0xb5f800d2,0x80d80490}},	//   kore, benz_, _tsát, _पुरे, 
   {{0x929c006d,0x69dc00bd,0x81f40f31,0xdb1d9cc3}},	//   _zgło, jore, _بہتر_, misé, 
   {{0xdb1d9cc4,0x00000000,0x00000000,0x00000000}},	//   lisé, --, --, --, 
   {{0x79940472,0x212c0023,0x200c003a,0xfd6001c6}},	//   _soxw, _hedh_, _iudi_, чнүү, 
   {{0xdb1d9cc5,0x3f859cc6,0x6d4806ea,0x200c0219}},	//   nisé, _inou_, úlaá, _hudi_, 
   {{0x200d9cc7,0x7e619cc8,0x644002b1,0xdd90691d}},	//   _kudi_, _ipop, _āmin, _سوب_, 
   {{0x200c4694,0xa3bc0574,0x3f859cc9,0xdb1c06af}},	//   _judi_, ेचा_, _knou_, hisé, 
   {{0x31641859,0x200d9cca,0xb8f00b7d,0x7e60037e}},	//   zenz_, _mudi_, _वश_, _kpop, 
   {{0x200cc858,0x3f840122,0x31640399,0x9a58a554}},	// [2c050] _ludi_, _mnou_, yenz_, _الخط_, 
   {{0x7e6001af,0xb5f80241,0x35680261,0x61f801a4}},	//   _mpop, _asár, јран_, jmvl, 
   {{0x3f840069,0x31646bb4,0xe50816ac,0xc950011a}},	//   _onou_, venz_, زينو_, _אמי_, 
   {{0x31640b6f,0x212c03b2,0x52740137,0x7e619ccb}},	//   wenz_, _aedh_, зуку, _opop, 
   {{0x31641a80,0xa2940212,0xdb1c48f9,0x6b7c011a}},	//   tenz_, маці, gisé, יראנ, 
   {{0x3f859ccc,0x1e040d2c,0x212c261c,0xd0095fed}},	//   _anou_, रदोष_, _cedh_, беке_, 
   {{0x7e619ccd,0x31659cce,0xdb1c007c,0xe45401f4}},	//   _apop, renz_, onsä, _окры, 
   {{0x200d9ccf,0x31643f5b,0xc4d0011a,0xdb1c007c}},	//   _dudi_, senz_, _נגן_, nnsä, 
   {{0x7e6007ab,0x3dcc02e2,0x212d3625,0xdb1d9cd0}},	//   _cpop, _bjfw_, _fedh_, cisé, 
   {{0x212c020c,0x200d9cd1,0x3f840204,0x69dc3018}},	//   _gedh_, _fudi_, _enou_, xore, 
   {{0x200d9cd2,0x7e7400c0,0x00000000,0x00000000}},	//   _gudi_, _šypt, --, --, 
   {{0xa0c42085,0x3f84b3a0,0xfafc0ea0,0x69dd9cd3}},	//   _تيمو, _gnou_, reën_, wore, 
   {{0x69dd9cd4,0x200c0165,0xfafc0ea0,0xde5802d5}},	//   tore, _zudi_, seën_, _маці_, 
   {{0x200d9cd5,0xa2ccc454,0xdb1c023a,0x9988002b}},	//   _yudi_, तपत्, ensä, _itaś_, 
   {{0x69dd9cd6,0x2d859cd7,0xe7f80574,0x644002b5}},	//   rore, _inne_, ंगला_, _āmio, 
   {{0xdb1c00dd,0x87f805f5,0x7e6002d0,0x00000000}},	//   yisé, сэгт_, _ypop, --, 
   {{0x7e60030d,0x387c02b5,0xb5f803b2,0x61f8017a}},	// [2c060] _xpop, āura_, _spáa, ymvl, 
   {{0xdb1d9cd8,0x7ab80375,0x7af800ee,0x69dccba2}},	//   visé, _לצפו, ýute, qore, 
   {{0xd1f40020,0x39980bd9,0x59040327,0xdb1c0098}},	//   ገኙት_, _הייד, _ཙུགས_, wisé, 
   {{0xdb1d9cd9,0x212c020c,0xb6a00208,0x60dc03b2}},	//   tisé, _sedh_, _khẩ, _ørmi, 
   {{0xcfd000fe,0x00000000,0x00000000,0x00000000}},	//   াতান, --, --, --, 
   {{0xdb1d9cda,0x67259cdb,0x200cbd88,0xa3b00d79}},	//   risé, lbij, _pudi_, टोज_, 
   {{0x7e619cdc,0x9988002b,0x67240083,0x6ac807d0}},	//   _spop, _ataś_, obij, रपुर, 
   {{0x200d9cdd,0x44280263,0x67259cde,0x2d859cdf}},	//   _vudi_, _iwb_, nbij, _anne_, 
   {{0x7de4005e,0x44299ce0,0x200c013f,0x324013d6}},	//   зінд, _hwb_, _wudi_, _петг, 
   {{0x200c4859,0x9c387c15,0xb8fc0135,0x628026ef}},	//   _tudi_, опот_, _སྙ_, _irmo, 
   {{0x442881be,0x1bd4170a,0x200c208d,0x672401f5}},	//   _jwb_, доня, _uudi_, kbij, 
   {{0x2d859ce1,0xfba8224a,0x6ac8193d,0x69c00129}},	//   _enne_, стой_, रपूर, èmen, 
   {{0x67259ce2,0x2f94011a,0x00000000,0x00000000}},	//   dbij, _מכאן_, --, --, 
   {{0x65a002b1,0xdef402d3,0x628000f3,0xed4c0133}},	//   _köhu, _ጌርና_, _mrmo, _مپه_, 
   {{0x7b640220,0x7c840022,0x00000000,0x00000000}},	//   _етпе, _хуле, --, --, 
   {{0x62819ce3,0x65a000a2,0x67259ce4,0x6c50030d}},	//   _ormo, _möhu, gbij, _чкъу, 
   {{0x44299ce5,0xdb1d9ce6,0xc0500023,0x7c280142}},	// [2c070] _awb_, lisï, _ዘይብለ, _hwfr, 
   {{0x44299ce7,0xdcf800ef,0x00000000,0x00000000}},	//   _bwb_, _novī, --, --, 
   {{0x44294c97,0x67259ce8,0xf77c6f35,0x00000000}},	//   _cwb_, bbij, _akçe_, --, 
   {{0x4428030a,0x6ac401b9,0x00000000,0x00000000}},	//   _dwb_, _آقیم, --, --, 
   {{0x51f4027d,0x666402e8,0x47f001f0,0x00000000}},	//   وستر, _пърз, _рӯёр, --, 
   {{0x442801d4,0xdb1c006a,0x00000000,0x00000000}},	//   _fwb_, kisï, --, --, 
   {{0x62819ce9,0x442803f9,0xe5c802d9,0x45a0030c}},	//   _ermo, _gwb_, _хыял_, _جەلك, 
   {{0x22400960,0xb69800e4,0x62800175,0xedb400dc}},	//   šika_, _agâi, _frmo, ेच्छ, 
   {{0x62800427,0x75e805d2,0xa3bc1025,0x00000000}},	//   _grmo, yüzl, ेचर_, --, 
   {{0x67241326,0x44280218,0xfafc05e4,0x0d84299f}},	//   zbij, _ywb_, reël_, флон, 
   {{0x44280b89,0xfafc0af9,0xcb680262,0x672401f5}},	//   _xwb_, seël_, оане_, ybij, 
   {{0xb6a001fb,0x00000000,0x00000000,0x00000000}},	//   _phẩ, --, --, --, 
   {{0xfd4c02e3,0x8db400d6,0x28e001f9,0x00000000}},	//   _jenụ, _оскі, पॅनि, --, 
   {{0xb5f950c2,0x2d859cea,0x8c44021f,0xdd9402d5}},	//   _spán, _unne_, _жеке, _пачы, 
   {{0x67240cf9,0x65a000ac,0x290c01a6,0xab640150}},	//   tbij, _möht, ždao_, _كۇدى, 
   {{0x75e8137e,0xdd1c0419,0xb6a00208,0x0708009f}},	//   süzl, máši, _thẩ, زيئي_, 
   {{0x67259ceb,0x44280211,0x06e4009e,0xdd1c00d7}},	// [2c080] rbij, _swb_, পেনি, láši, 
   {{0x272c01dc,0xdb1d9cec,0x44280165,0x2fdc08fb}},	//   ến_, hisì, _pwb_, houg_, 
   {{0x7410040d,0x44280218,0x6e280369,0x2fdc05c7}},	//   نولا, _qwb_, _lwgb, koug_, 
   {{0x29199ced,0x274401e1,0x442801f5,0x93a402dd}},	//   lcra_, _dènà_, _vwb_, ншід, 
   {{0x27e19cee,0xb5f800d2,0x442801a4,0x2fdc0072}},	//   moin_, _tsáp, _wwb_, doug_, 
   {{0x44280190,0x6f099cef,0x29199cf0,0x850421ec}},	//   _twb_, _aggc, ncra_, _يوحن, 
   {{0x27e00076,0xf50007a5,0x2f680116,0x00000000}},	//   ooin_, _азро, ﺳﻠﯩﻢ_, --, 
   {{0x27e19cf1,0xdbcc01a8,0x62800010,0x00000000}},	//   noin_, jóðs, _trmo, --, 
   {{0x6ac80d0d,0xb5f82358,0xbd699cf2,0x62819cf3}},	//   रपोर, _opál, орне_, _urmo, 
   {{0x6f09078a,0x81a99cf4,0x27e19cf5,0x00000000}},	//   _eggc, _بطرف_, hoin_, --, 
   {{0x80a40517,0x27e19cf6,0x00000000,0x00000000}},	//   _تمان, koin_, --, --, 
   {{0x27e06af6,0xf0b400c8,0xdbcc0174,0x3f680b01}},	//   join_, _קלאר_, góðs, _фидо_, 
   {{0x27e09e30,0x00000000,0x00000000,0x00000000}},	//   doin_, --, --, --, 
   {{0xfcf40023,0xdd1c00d0,0xdb1c2f5e,0x65a003b9}},	//   _ለዉጢ_, báši, misí, _möhs, 
   {{0x27e19cf7,0xf8059cf8,0xdb1d9cf9,0x561401e1}},	//   foin_, дчан, lisí, _ìfẹ́_, 
   {{0x60dc0174,0xee340ce8,0x64480166,0x00000000}},	//   _ørmu, _энә_, _ädiy, --, 
   {{0x24800092,0x6d60032e,0x00000000,0x00000000}},	// [2c090] _የሚገቡ_, _þvað, --, --, 
   {{0x27e00076,0x34a8007b,0x2fdc0489,0xf4e91ee7}},	//   aoin_, يداً_, zoug_, офей_, 
   {{0x27e0003a,0x24599cfa,0x80bc150d,0xa3bc0073}},	//   boin_, дахь_, _वेले, ेचं_, 
   {{0x27e02a18,0x65a02305,0xdb1c0142,0x5694009d}},	//   coin_, _böhs, lisâ, _замт, 
   {{0x7bcd0b13,0xb19000fb,0x4718011a,0x291000d7}},	//   incu, клдә, _מורג, šlať_, 
   {{0x24800020,0xdb1c01df,0xe50421ef,0x2fdc0100}},	//   _የሚሉት_, disí, ربەي, woug_, 
   {{0x647402f6,0xc0e0584b,0xdc1003e3,0x00000000}},	//   _игру, лошк, _rəğb, --, 
   {{0xb5f8043b,0x80bc0574,0xb4a80cb4,0xe0d09dc7}},	//   _mpám, _वेळे, गनी_, جزه_, 
   {{0x63a4023a,0x2fdc0165,0x4e04033a,0x00000000}},	//   öine, roug_, нзиб, --, 
   {{0x7bcd9cfb,0xb5f800c7,0x30a406ed,0x8c48010a}},	//   encu, _opám, _орев, ппов_, 
   {{0x6ac808ec,0xfaa0006c,0x27e00198,0x644002b5}},	//   रप्र, қаро, yoin_, _āmik, 
   {{0xb5f82195,0x65a004cc,0x27e001c4,0xc4d0010f}},	//   _spál, _jöhr, xoin_, רגט_, 
   {{0x27e002f6,0x65a1928d,0x00000000,0x00000000}},	//   voin_, _möhr, --, --, 
   {{0x8d759cfc,0x20181184,0x7bcc01e4,0x290d1ba3}},	//   _ساتا, _éric_, ancu, øda_, 
   {{0x7bcc0218,0x27e19cfd,0x29180553,0x7d749f9c}},	//   bncu, toin_, rcra_, _سمير_, 
   {{0x29183a93,0x9b340022,0xb900010a,0x00000000}},	//   scra_, _ихьш, узск, --, 
   {{0x27e19cfe,0x36648a6f,0x09e59cff,0x2b4001fa}},	// [2c0a0] roin_, нато_, _поин, _idic_, 
   {{0x27e19d00,0xf5e40276,0xb5f802f0,0xb6f42a8b}},	//   soin_, емул_, _upál, رىلا_, 
   {{0x19c00046,0x321c003e,0x75d000c6,0x65a000ac}},	//   _тұрм, _atuy_, ديلا, _böhr, 
   {{0x80d80316,0xf484f122,0x00000000,0x00000000}},	//   _पुगे, عالی, --, --, 
   {{0x41e404db,0xdb1c0120,0x660400c7,0xb6a00166}},	//   ніка, lisã, _аҿаа, _биял, 
   {{0xdb1cbaac,0xa0341e4a,0x00000000,0x00000000}},	//   visí, نىتت, --, --, 
   {{0x601c00e4,0x65a0002f,0x75d00b24,0x00000000}},	//   _oĩme, _föhr, _صيفا, --, 
   {{0x2b40067c,0xdb1c0122,0xfe24020f,0x65a0002f}},	//   _ndic_, tisí, ньон, _göhr, 
   {{0xefb053e2,0x44383e17,0x9df8005b,0x00000000}},	//   دینگ, lsp_, мнит_, --, 
   {{0x2b4000ca,0x2dd00c75,0x65a19d01,0xdb1c0332}},	//   _adic_, лжыр, _zöhr, risí, 
   {{0x4438010a,0x9988062d,0x7bdc00e4,0x00000000}},	//   nsp_, _ataş_, _êpuk, --, 
   {{0x44380280,0xdb1c31a2,0x7bccc92c,0xd33c030d}},	//   isp_, nnsø, uncu, _гiех, 
   {{0xdb1c0158,0xb5f809e8,0x629c01e1,0x00000000}},	//   insø, _spám, _ńroj, --, 
   {{0xdcf801e4,0xb1480092,0x00000000,0x00000000}},	//   _lavĉ, _ኘሬዚዳ, --, --, 
   {{0x37a84962,0xf77c0724,0x2b40045a,0x00000000}},	//   птан_, _akça_, _fdic_, --, 
   {{0x44380171,0x00000000,0x00000000,0x00000000}},	//   dsp_, --, --, --, 
   {{0x65a003fa,0x75e800ac,0x443800d8,0x79a40798}},	// [2c0b0] _röhr, lüzi, esp_, _зрне, 
   {{0x7c399d02,0xdb1c0ffb,0x65a0399d,0x7d1803ac}},	//   ostr, lisà, _söhr, ncts, 
   {{0xdb1c0261,0x53344727,0xb4a8121d,0xb8c4215c}},	//   cisã, веет, गने_, _سزدى, 
   {{0x7c399d03,0xdb1c05da,0x601c00c7,0x00000000}},	//   istr, nisà, _oĩmb, --, 
   {{0x7c399d04,0x65a0002f,0x00000000,0x00000000}},	//   hstr, _vöhr, --, --, 
   {{0x7c399d05,0x44399c3b,0xdb1c01bf,0x65a0002f}},	//   kstr, bsp_, ansø, _wöhr, 
   {{0xe1ec0491,0x7c384d44,0x65a001f4,0xf36400db}},	//   _ҳҳ_, jstr, _töhr, _птан, 
   {{0xc3c00724,0x0e643b8f,0x00000000,0x00000000}},	//   _көчл, вкин, --, --, 
   {{0x321c0c6a,0x91740276,0x59e017c6,0xf0480240}},	//   _utuy_, _игац, पकार, _ዘይምዝ, 
   {{0x7c399d06,0xb5f801f1,0x61dc1fd2,0xd36c00d1}},	//   fstr, _spáj, मकृष, _دۇچ_, 
   {{0x1f64005e,0xb5f80241,0xb898001f,0x00000000}},	//   _әкім, _apák, ፈላጊው_, --, 
   {{0xdb1c03b7,0xc0640020,0x4e94036b,0x6fcc00fe}},	//   visã, _መርሃግ, _لشتر, _হীৰে, 
   {{0x7c3800a8,0x6f18014b,0xaf5000c7,0xc33002e4}},	//   astr, mcuc, _анҵә, סוך_, 
   {{0x7c399d07,0x6e399d08,0x597402dd,0x7bd000ef}},	//   bstr, msub, лысу, _ēduš, 
   {{0x6e399d09,0x7c380857,0x00000000,0x00000000}},	//   lsub, cstr, --, --, 
   {{0x6f199d0a,0xca8401c6,0xca48007b,0x2b400051}},	//   ncuc, _агий, _قلبه_, _udic_, 
   {{0x46e801b9,0xdb1c03b2,0x00000000,0x00000000}},	// [2c0c0] фдан_, vnsø, --, --, 
   {{0x75d00597,0xdb1d9d0b,0xea240137,0x6e38058a}},	//   ليقا, misá, _ичүү, isub, 
   {{0xdb1c14dd,0x6e399d0c,0x07f8007b,0x00000000}},	//   lisá, hsub, _يرجع_, --, 
   {{0x07a40261,0xdb0c00a2,0x6e380703,0x00000000}},	//   _рамн, _omaý, ksub, --, 
   {{0x7c399d0d,0xe2846f78,0xdce80030,0x42541411}},	//   zstr, ыған, vedč, ттет, 
   {{0x7c399d0e,0x6e380175,0x6f18003a,0x00000000}},	//   ystr, dsub, ecuc, --, 
   {{0x657c01e2,0x5f480032,0xa13c00de,0x00000000}},	//   _iarh, еүен_, _noķe, --, 
   {{0x1f741d56,0x7c380feb,0x245d9d0f,0x00000000}},	//   улия, vstr, mím_, --, 
   {{0x657d9d10,0x6e389b58,0x0204c3cf,0x245c0122}},	//   _karh, gsub, _азан, lím_, 
   {{0x63a19d11,0x5c7412e7,0x00000000,0x00000000}},	//   _homn, глот, --, --, 
   {{0x245c0745,0x63a19d12,0x657d9d13,0x7c399d14}},	//   ním_, _komn, _marh, ustr, 
   {{0xfe440364,0x6f18c7cc,0x6e380175,0x601c00e4}},	//   _андо, ccuc, bsub, _tĩmb, 
   {{0xfe7118a2,0xf770c240,0x7f40025c,0x6e380548}},	//   _خدا_, یار_, _idoq, csub, 
   {{0x63a048b5,0x7c39669f,0xe94401c0,0x657c1617}},	//   _lomn, pstr, ихсо, _narh, 
   {{0x245c0232,0xad853b7b,0xa8a4064e,0xa9343f3a}},	//   jím_, _جانۇ, артк, ресш, 
   {{0x63a19d15,0x657d9d16,0x245c0232,0x7f40025c}},	//   _nomn, _aarh, dím_, _jdoq, 
   {{0x657d9d17,0x645c01d9,0x34a829c7,0xdb1c021c}},	// [2c0d0] _barh, _aqri, चन्द, cisá, 
   {{0x657c0489,0xd7600133,0x2adc0037,0x00000000}},	//   _carh, _گۆری, _गुटु_, --, 
   {{0x63a19d18,0x657d9d19,0x6f180113,0x00000000}},	//   _bomn, _darh, ycuc, --, 
   {{0x657c0857,0xe248001f,0x7f419d1a,0x0a2400fe}},	//   _earh, _አውሮፓ, _ndoq, _বিতং_, 
   {{0x63a19d1b,0x313000c7,0x00000000,0x00000000}},	//   _domn, иҵар, --, --, 
   {{0x245c0122,0x7f403eba,0xb5f8035b,0xb5f002dd}},	//   bím_, _adoq, _opái, _түзі, 
   {{0x245c0e96,0x63a0003a,0x6e380334,0xdb1c3add}},	//   cím_, _fomn, wsub, misæ, 
   {{0x6e399d1c,0x63a003f9,0x35a41ee0,0x657c1617}},	//   tsub, _gomn, _ወረቀት_, _zarh, 
   {{0x6f191410,0x657d9d1d,0xb5f800e4,0x7f40031c}},	//   rcuc, _yarh, _apái, _ddoq, 
   {{0x6f199d1e,0x63a01cdf,0xb5f800c6,0xdb0c07ea}},	//   scuc, _zomn, _bpái, _plaî, 
   {{0x6e399d1f,0x63a06ae5,0xdb0c0254,0x00000000}},	//   ssub, _yomn, _emaü, --, 
   {{0x6e399d20,0x8b94064d,0x00000000,0x00000000}},	//   psub, уроч, --, --, 
   {{0x245c012c,0x38700023,0x99480419,0x00000000}},	//   zím_, _ብውሑዱ_, _kóňu_, --, 
   {{0xdb0c00a2,0xdb1c3add,0x00000000,0x00000000}},	//   _umaý, risá, --, --, 
   {{0x657c0455,0x6d4002d0,0x7f40022e,0xdb1c00e5}},	//   _rarh, _idna, _ydoq, sisá, 
   {{0x245c0316,0x657d9d21,0x0ba800db,0x97b401ec}},	//   vím_, _sarh, _ساعى_, асуш, 
   {{0x657d9d22,0x63a19d23,0x05654acf,0x06851dbc}},	// [2c0e0] _parh, _romn, лван, ыган, 
   {{0x245c0300,0x291c00e4,0x2bc004af,0x44f400f2}},	//   tím_, _üva_, शोरा, هساز, 
   {{0x63a109eb,0x657d9d24,0x601c00c7,0x032406ed}},	//   _pomn, _varh, _oĩma, гден, 
   {{0x245d9d25,0x99980006,0x27b400d1,0x63a00139}},	//   rím_, busų_, _тәгс, _qomn, 
   {{0x245c076f,0x657d9d26,0xa294242f,0xe1347ced}},	//   sím_, _tarh, ралі, анлы, 
   {{0x63a00912,0x245d4555,0x00000000,0x00000000}},	//   _womn, pím_, --, --, 
   {{0x55c444fb,0x645c0113,0x63a028e5,0xd40800db}},	//   _тарғ, _uqri, _tomn, رتۅم_, 
   {{0x3a3c000a,0xdec00020,0x6d40bdb4,0xb2200daf}},	//   šupi_, _ስልክ_, _adna, шмәл, 
   {{0xb5f99d27,0x733000cf,0x06e400eb,0xdb1d9d28}},	//   _spái, _دىقا, পেরি, lisç, 
   {{0xa2e5141c,0xadb051af,0x6d40045a,0xc1b001ee}},	//   _боғд, йбыш, _cdna, _ыҙлы, 
   {{0x2018006a,0x80a40133,0x230800f1,0x9f440200}},	//   _îri_, _حمان, _ستړي_, nomë_, 
   {{0xce359d29,0x6d402cd9,0x00000000,0x00000000}},	//   _چونک, _edna, --, --, 
   {{0xb5f99d2a,0x9e359d2b,0x64480381,0xde58177b}},	//   _ipáv, _телч, _ædif, _ралі_, 
   {{0xdd900214,0xfbd000e5,0x6e4001c8,0x00000000}},	//   _ذوب_, ؤتھ_, _انوم, --, 
   {{0xb7659d2c,0xdcf8242b,0x97c40032,0xd7c80133}},	//   лтай, _kavč, араһ, نوسه_, 
   {{0x2044044e,0xa8980139,0x00000000,0x00000000}},	//   _ከይተረ, ыксу_, --, --, 
   {{0x56959d2d,0xdcf80427,0x6bd400f1,0xe6945184}},	// [2c0f0] шаат, _mavč, _دتور, биты, 
   {{0xdcf8007f,0xdb1c0112,0x9f440200,0x63a40108}},	//   _lavč, hnsü, fomë_, öinn, 
   {{0xdb0c0bc9,0xb5f80124,0x3ce86173,0xdb1c9907}},	//   _imañ, _opáv, _घुमे_, risæ, 
   {{0xb3e80137,0x00000000,0x00000000,0x00000000}},	//   رعال_, --, --, --, 
   {{0xdb1c340f,0x00000000,0x00000000,0x00000000}},	//   misä, --, --, --, 
   {{0xb5f803df,0xdb1c02f6,0xf7700131,0xf77c75d4}},	//   _apáv, lisä, _ئاھ_, _haç_, 
   {{0xdb1c3308,0xf77c0365,0xdcf91bb5,0xd094b73a}},	//   nnsó, _kaç_, _bavč, ршлы, 
   {{0x70740020,0xf77c068c,0xdb1c05ca,0x09d008a3}},	//   _በክልሉ_, _jaç_, nisä, _सद्य, 
   {{0xdcf80fb7,0xf77c03ee,0x12840014,0xdb0c035b}},	//   _davč, _maç_, _خۅشی_, _omañ, 
   {{0xb5f800e4,0xdb1c0008,0xc6900375,0xdb0c00ae}},	//   _epáv, rnsý, קאי_, _claí, 
   {{0xdb1c005b,0x9f44007f,0xa3bc0073,0x01f800df}},	//   kisä, komè_, ेचच_, _ספעל, 
   {{0x999005ce,0xdb0d9d2e,0x6d400036,0xa0a400f7}},	//   _čašu_, _amañ, _wdna, _ушул, 
   {{0xdce80069,0xdb0c01ab,0x00000000,0x00000000}},	//   redā, _smaò, --, --, 
   {{0x6d4000d8,0xdcf802f0,0xdea000e5,0x60d8036e}},	//   _udna, _zavč, _ریپی, _çamç, 
   {{0x52d00574,0x47580801,0x98dc02dd,0xdb1d71ed}},	//   तपुस, края_, естi, fisä, 
   {{0xdb0c0428,0x8724010b,0xdeec01ec,0xc724004e}},	//   _emañ, рмаж, _تۋۋ_, рдай, 
   {{0x59b428fc,0x25f40ebb,0xfaa00c60,0xf77c0200}},	// [2c100] рөөс, ्गली_, _маъо, _daç_, 
   {{0xde7000b8,0xc96402e8,0x36640117,0x9f44036e}},	//   _jyāṃ_, _твой, рафо_, tomë_, 
   {{0x4374009d,0x00000000,0x00000000,0x00000000}},	//   иудт, --, --, --, 
   {{0x82a59d2f,0xf77c20a9,0x9f440200,0xf8d8011a}},	//   ишле, _gaç_, romë_, _יחימ, 
   {{0x0204da2c,0xdb1c0213,0xfafc0af9,0x22400221}},	//   аздн, sisç, leër_, éik_, 
   {{0xb5f81155,0x250800f2,0xde700055,0x00000000}},	//   _spáv, _مرزی_, _nyāṃ_, --, 
   {{0x03959d30,0xdcf80427,0xe13401e0,0xf77c0139}},	//   _края, _pavč, анһы, _yaç_, 
   {{0xbf10052f,0x5f9413d6,0x2a6001b9,0x42240138}},	//   әүҙә, сиит, _oqib_, _вдав, 
   {{0x9f4471d3,0xdcf80010,0x6e9402e8,0x00000000}},	//   nomé_, _vavč, ивър_, --, 
   {{0x6448143a,0x7c8402dd,0x80d400cd,0x00000000}},	//   _ådis, ауме, यपदे, --, 
   {{0xde7000b8,0xdcf80427,0xdb1c005b,0xd64c01ec}},	//   _dyāṃ_, _tavč, yisä, зiле, 
   {{0xceb4052f,0xfba860a1,0x00000000,0x00000000}},	//   рҙә_, ттой_, --, --, 
   {{0x3dd0010a,0xdb1c01f4,0x00000000,0x00000000}},	//   _дιаг, visä, --, --, 
   {{0xf77d9d31,0x9f440306,0xdeb00150,0x00000000}},	//   _saç_, domé_, _мұқы, --, 
   {{0x20040e14,0x95d8013e,0xf77c6aac,0xdbf00118}},	//   ommi_, ҳдат_, _paç_, _hříb, 
   {{0x98b00276,0xeb980063,0x9f6402e2,0xf77c06be}},	//   ează_, _вић_, òtèl_, _qaç_, 
   {{0x20040869,0xb5f86711,0xdb1c0108,0x377401e0}},	// [2c110] immi_, _opát, risä, лыҡс, 
   {{0xdb0c0227,0xdb1c023a,0xf5259d32,0xdce8054e}},	//   _umañ, sisä, рфан, cedă, 
   {{0xf77c05d2,0x6efc00c0,0xdb1c1b99,0x89d808c3}},	//   _taç_, _išbū, pisä, _תחתי, 
   {{0xb5f99d33,0xdec40150,0x00000000,0x00000000}},	//   _apát, _ﺩﺒﺎﺒ, --, --, 
   {{0xb5f82131,0x387c04fe,0xf77c0200,0xf2c400d8}},	//   _bpát, āuru_, _lkçk_, јсен, 
   {{0xc69000c8,0x77a0001f,0x75e80790,0xa50800db}},	//   _זאך_, _ላሊበላ_, rüzs, _چۉكە_, 
   {{0xa4d402bf,0x10a4d9a9,0x290c01e4,0x00000000}},	//   _дорі, сийн, ɾdas_, --, 
   {{0xe8d80375,0x864c0023,0x8c4401e0,0xde70002b}},	//   יוור_, _ንርእስ, ҙеме, _syāṃ_, 
   {{0xe3b00597,0x4f080139,0xc0d41954,0x838800e5}},	//   _غرف_, ынин_, _ሪያል_, _حصّہ_, 
   {{0x20059d34,0xdb0c03b2,0x2a6001b9,0xd9e00b98}},	//   ammi_, _rmað, _rqib_, पकोट, 
   {{0xdb0c0162,0x00000000,0x00000000,0x00000000}},	//   _smað, --, --, --, 
   {{0xb5f8012c,0x00000000,0x00000000,0x00000000}},	//   _zpát, --, --, --, 
   {{0x15f8a4cd,0x00000000,0x00000000,0x00000000}},	//   ्गार_, --, --, --, 
   {{0xb5f80085,0xfda002d3,0xbea01f5a,0x89d402dd}},	//   _mpás, _ዝፈልጦ_, _хашк, сімш, 
   {{0x290d9d35,0xe7e434f8,0x3ce80122,0x64a00153}},	//   äda_, ककला_, čivé_, _kšiš, 
   {{0xdb1c007c,0x00000000,0x00000000,0x00000000}},	//   tiså, --, --, --, 
   {{0xc5140eff,0xfafc0af9,0xdb0c03b2,0x2a6001d5}},	// [2c120] مبات, seër_, _umað, _uqib_, 
   {{0x9f44004a,0xdcf8002b,0xfafc017a,0x764801d3}},	//   romé_, _havā, peër_, ágya, 
   {{0xb5f801e1,0x64a0041a,0x3d38008f,0xdcf800b8}},	//   _apás, _ošiš, רגעס, _kavā, 
   {{0xb5f803b2,0xdcf800b8,0x00000000,0x00000000}},	//   _spát, _javā, --, --, 
   {{0xa248158b,0xdcf80055,0x61142377,0x00000000}},	//   شیال_, _mavā, одлу, --, 
   {{0x7ebc01e1,0xdcf800b8,0x20184e79,0x26c00064}},	//   _làpé, _lavā, _érik_, mzio_, 
   {{0x26c0011c,0x20040194,0x9f980edb,0x4084074d}},	//   lzio_, tmmi_, ивку_, сулб, 
   {{0xdbf00316,0x35a402d3,0x20040869,0xdcf800cd}},	//   _příb, _ወረቐት_, ummi_, _navā, 
   {{0x26c19d36,0xb5f800e4,0xc0500023,0x412800db}},	//   nzio_, _ipár, _ዘይምል, _бозо_, 
   {{0x5be002ab,0x26c01fce,0x00000000,0x00000000}},	//   नव्व, izio_, --, --, 
   {{0xdcf80171,0xca240220,0x22400003,0x00000000}},	//   _bavā, _ﺠﺩﺍ_, ġiku_, --, 
   {{0x26c001c0,0x22402625,0x788001ed,0xdbf0013a}},	//   kzio_, šiku_, hívá, _tříb, 
   {{0x3be40372,0xdcb034b1,0xdcf80055,0x26c000df}},	//   илүү_, سىڭ_, _davā, jzio_, 
   {{0x26c19d37,0x7e6001f0,0x25b80064,0x3ea003b2}},	//   dzio_, _iqop, _nlrl_, øktu_, 
   {{0xbc240a52,0xb5f80124,0x788000bc,0x26c001e4}},	//   _ارتى, _opár, dívá, ezio_, 
   {{0xdcf800dc,0x963432eb,0xbfb40051,0xe4ec000d}},	//   _gavā, жнац, _điễm_, _झड़ि_, 
   {{0x7bcd9d38,0x95399d39,0xdb1c08a7,0x38640023}},	// [2c130] micu, изат_, kisú, _ምፍላጥ, 
   {{0x7bcd9d3a,0xb5f801e1,0x00000000,0x00000000}},	//   licu, _apár, --, --, 
   {{0xb5f99d3b,0x26c001c6,0x7e60022e,0xdec00023}},	//   _spás, azio_, _lqop, _ስውእ_, 
   {{0x7bcd9d3c,0x7e60014b,0x55a00150,0x5694014b}},	//   nicu, _oqop, _ﺍﺷﯩﻼ_, _дамт, 
   {{0x3264a396,0x3ce805f9,0x6b7c008f,0x788001ef}},	//   стев, _घुसे_, טראנ, bívá, 
   {{0x7bcd9d3d,0xc69000df,0xdb1c08a5,0x00000000}},	//   hicu, _קאם_, gisú, --, 
   {{0xe1f0e109,0x7e600117,0x7bcd9d3e,0xe4a40139}},	//   رسه_, _aqop, kicu, _ерто, 
   {{0xce4890ab,0x7bcd9d3f,0xc0500023,0x13a40133}},	//   азие_, jicu, _ዘይመል, _گۆڵی_, 
   {{0x7bcc1e58,0xdb1c000f,0xed5c00d0,0x0d999d40}},	//   dicu, sisû, úžok_, атны_, 
   {{0xdcf84424,0x4c6807dd,0xa15800fd,0x78640240}},	//   _savā, аион_, _гафу_, _ምግንጻ, 
   {{0x26c19d41,0x7e6001f0,0xdcf81c52,0xd104000d}},	//   zzio_, _eqop, _pavā, षेशण_, 
   {{0x7bcd9d42,0xd1c8016c,0xdfd802e8,0x00000000}},	//   gicu, _суғд_, _лъч_, --, 
   {{0x9e64e616,0xdcf800b8,0x00000000,0x00000000}},	//   _فاون, _vavā, --, --, 
   {{0x63b800da,0x00000000,0x00000000,0x00000000}},	//   īvni, --, --, --, 
   {{0x7bcd9d43,0xdcf83a71,0x63a401f4,0x00000000}},	//   bicu, _tavā, öink, --, 
   {{0x7bcc7d90,0x26c0005a,0x9b6000d1,0x2d8800d7}},	//   cicu, tzio_, _كۆپۈ, šieľ_, 
   {{0xb3cc00cc,0x7880294d,0x4518011c,0x00000000}},	// [2c140] িকাজ, tívá, ацея_, --, 
   {{0x6b859d44,0x26c19d45,0xb5f99d46,0x00000000}},	//   _haig, rzio_, _spár, --, 
   {{0x07a4016a,0xc7a4b1c2,0x6b84105c,0xc32833d2}},	//   _данн, _динк, _kaig, لكان_, 
   {{0x7af80034,0x079001ec,0x26c001c6,0x6b85046d}},	//   żute, _تۇرڭ, pzio_, _jaig, 
   {{0x67240010,0xa1947c3f,0x00000000,0x00000000}},	//   mcij, залч, --, --, 
   {{0x7bcd9d47,0x6b847ea1,0x3cf801f9,0xddc000a2}},	//   zicu, _laig, _उरले_, dumş, 
   {{0xdb1c01e6,0x7bcc54da,0x6b840076,0x00000000}},	//   mnsö, yicu, _oaig, --, 
   {{0x44299d48,0x6b859d49,0x3e68016c,0x7bcc4ff3}},	//   _itb_, _naig, ашон_, xicu, 
   {{0x442990e5,0xdb0d9d4a,0x7bcd9d4b,0x3f8001f1}},	//   _htb_, _ilaç, vicu, ľku_, 
   {{0x6b840421,0x3f802195,0x62819d4c,0x4428020b}},	//   _aaig, žku_, _ismo, _ktb_, 
   {{0x7bcd9d4d,0x6b859d4e,0x44299d4f,0xb5f8010f}},	//   ticu, _baig, _jtb_, שליכ, 
   {{0x6b859d50,0xc0c00131,0x7bcc0393,0x69c0036e}},	//   _caig, _нәқи, uicu, ëmen, 
   {{0x6b859d51,0x7e600117,0x67240301,0x2aa8013e}},	//   _daig, _uqop, dcij, отро_, 
   {{0x7bcd279b,0x6b840083,0xdb0c2452,0x442801d5}},	//   sicu, _eaig, _llaç, _otb_, 
   {{0x6b859d52,0x7bcd9d53,0x44299d54,0x8d940014}},	//   _faig, picu, _ntb_, _رٔٹت, 
   {{0x6280254f,0x7c2880f9,0x00000000,0x00000000}},	//   _osmo, _itfr, --, --, 
   {{0x98a003c1,0xf1d80034,0x0bb401ec,0xb5f80332}},	// [2c150] _pehē_, _बदलन, _ءجىگ, _bpáp, 
   {{0x67259d55,0x6b859d56,0xdb0d9d57,0x9f44219b}},	//   acij, _zaig, _alaç, domí_, 
   {{0x442807ab,0x628005f5,0x6b859d58,0x672401f5}},	//   _ctb_, _asmo, _yaig, bcij, 
   {{0xaa888bee,0x4428010e,0x672404ce,0x00000000}},	//   _انیم_, _dtb_, ccij, --, 
   {{0x7c280004,0x442801c0,0xe6642461,0x62800332}},	//   _ltfr, _etb_, _отро, _csmo, 
   {{0x44299d59,0x7c2802d0,0x35a40133,0x940806be}},	//   _ftb_, _otfr, _گۆڕێ_, _əkək_, 
   {{0x62819d5a,0xc5f00302,0xdb0c00db,0x533400d4}},	//   _esmo, _נדל_, _flaç, _невт, 
   {{0xdb0d9d5b,0xb4d4375c,0xcf4401c0,0x241806a6}},	//   _glaç, ापी_, чний, _фоты_, 
   {{0x6b859d5c,0xd250d7ff,0x79940472,0xe1ec00c7}},	//   _raig, _سنا_, _onxw, _аҳ_, 
   {{0x6b859d5d,0xd1300597,0xccc422d7,0x00000000}},	//   _saig, _أما_, збой, --, 
   {{0x6b84007d,0x7ae0013f,0xdb1c01c7,0x7afc03b9}},	//   _paig, _ɛnte, chsë, _azqt, 
   {{0x2d805946,0x799403ac,0x7c280175,0xdb1c1497}},	//   žje_, _anxw, _dtfr, nhsè, 
   {{0x6b859d5e,0x7bdc004e,0x37c0015b,0x7c2802d0}},	//   _vaig, _djqu, ্কার, _etfr, 
   {{0x6b859d5f,0x776c4ed7,0x00000000,0x00000000}},	//   _waig, _abcx, --, --, 
   {{0x6b859d60,0x672401f5,0x050c00fe,0x00000000}},	//   _taig, tcij, াঁৱৰ_, --, 
   {{0x6b859d61,0x44299d62,0xf77c03e0,0x4a4400d8}},	//   _uaig, _rtb_, _okçu_, _енив, 
   {{0x44299d63,0x9f440589,0x25e80037,0xae180b4c}},	// [2c160] _stb_, lomã_, झवली_, नदिन_, 
   {{0x84e4023a,0x62800175,0x00000000,0x00000000}},	//   позж, _rsmo, --, --, 
   {{0xdb0d1c3e,0xdb1c2b96,0xea9401e2,0x00000000}},	//   _plaç, tisø, _راکښ, --, 
   {{0xae1805f9,0x44299d64,0xdce80064,0xf8b0011a}},	//   नदान_, _vtb_, gedę, _נשר_, 
   {{0x4428095c,0x69dd9d65,0xdb1c0162,0x00000000}},	//   _wtb_, onre, risø, --, 
   {{0x69dd9d66,0x9f4402f0,0x74f00055,0x00000000}},	//   nnre, romí_, _ṭaśr, --, 
   {{0x69dceeae,0x60c400df,0x4429208a,0xf990011a}},	//   inre, ĝimo, _utb_, תרו_, 
   {{0xc5bc009e,0x69dc0112,0x60c401e4,0x00000000}},	//   _আদিপ, hnre, ŝimo, --, 
   {{0xc0e8044e,0x6280036b,0xd1f00092,0x00000000}},	//   _ቅዋም_, _usmo, ልሎች_, --, 
   {{0x69dc01a4,0x00000000,0x00000000,0x00000000}},	//   jnre, --, --, --, 
   {{0x601c00c7,0x00000000,0x00000000,0x00000000}},	//   _oĩmi, --, --, --, 
   {{0x4f944276,0x4f640075,0x69dc0171,0xb098025d}},	//   _орчу, _يانف, enre, _ליבר, 
   {{0x61f80af9,0x2cb806be,0xd64c0150,0x00000000}},	//   olvl, _əqdi_, зiне, --, 
   {{0x6da000d1,0x3f840165,0x4268001f,0x00000000}},	//   _пича, _haou_, _ሰውነት_, --, 
   {{0x3f859d67,0x7c2811ad,0xd7f40006,0x00000000}},	//   _kaou_, _utfr, дзвы, --, 
   {{0xdb0c01b8,0x9f4404cc,0x06e4009e,0x69dd9d68}},	//   _plaä, nomà_, পেছি, anre, 
   {{0x3f840270,0xf6280220,0x91780241,0xaa540024}},	// [2c170] _maou_, сіби_, _jẹ̀_, _звыш, 
   {{0x79940472,0x3f8405c7,0xf70c0208,0x00000000}},	//   _unxw, _laou_, _củaa_, --, 
   {{0x3f840093,0xe5c406a6,0xb4d41788,0xa4d4003b}},	//   _oaou_, хсто, ापे_, нофі, 
   {{0x9f440109,0x3f84030a,0x5274e4ae,0xe4501a9b}},	//   jomà_, _naou_, дуку, اضل_, 
   {{0x69d81518,0x39480023,0x00000000,0x00000000}},	//   _ذبیح_, _ንምዕራ, --, --, 
   {{0x3f840418,0xf1a59d69,0xa84802f2,0x00000000}},	//   _aaou_, ярен, _بلێم_, --, 
   {{0x3f841165,0xc0e00b96,0x37e80327,0x00000000}},	//   _baou_, кошк, _རྩོད, --, 
   {{0x91780241,0xd3400014,0x61f8017a,0x4fe801b9}},	//   _bẹ̀_, _شہتی, alvl, ўмин_, 
   {{0x3f8403bd,0xaca0063f,0xa3640014,0xe3742cc8}},	//   _daou_, plịm, _سُلو, _ялты, 
   {{0xe2904fb6,0x333c0399,0x0c259d6a,0x9f4400d8}},	//   _حذف_, _heux_, ммон, tomã_, 
   {{0x3f840156,0x61e59d6b,0x00000000,0x00000000}},	//   _faou_, éile, --, --, 
   {{0x333c2047,0x3f840489,0x91780241,0x9f4400db}},	//   _jeux_, _gaou_, _fẹ̀_, comà_, 
   {{0x37e80489,0xf8c400e8,0x7fb4007b,0x00000000}},	//   _རྩེད, _ňépp_, _زهور_, --, 
   {{0x333c0007,0x8c64107f,0x321c0789,0x201800db}},	//   _leux_, _قطعن, _muuy_, _èric_, 
   {{0x2d840393,0x3f840489,0x6cb00137,0x8c9401ec}},	//   _iane_, _yaou_, _чөпт, _іркі, 
   {{0x7a3402e3,0x248c03b2,0x80e00154,0x91780241}},	//   ụtag, _ádmi_, _ফরম্, _yẹ̀_, 
   {{0x2d859d6c,0x05a802d5,0x69dc005a,0x464806a6}},	// [2c180] _kane_, овай_, pnre, юзан_, 
   {{0x2d84b441,0x2b4016b8,0x00000000,0x00000000}},	//   _jane_, _heic_, --, --, 
   {{0x48041318,0x271801f2,0x00000000,0x00000000}},	//   _опов, _ọnu_, --, --, 
   {{0x333c3a6d,0x321c002e,0x9f440085,0x2d840c18}},	//   _ceux_, _buuy_, komá_, _lane_, 
   {{0x333c2047,0x2d859d6d,0x41e4177b,0x2b419d6e}},	//   _deux_, _oane_, міка, _meic_, 
   {{0x2d859d6f,0x3f859d70,0x2b4001e7,0x9f440306}},	//   _nane_, _saou_, _leic_, domá_, 
   {{0x333c4056,0x3f851924,0x00000000,0x00000000}},	//   _feux_, _paou_, --, --, 
   {{0x31200b65,0x2d859d71,0x917801e1,0x00000000}},	//   ндәг, _aane_, _pẹ̀_, --, 
   {{0x9f4405d5,0x11f801d5,0x5f94010b,0x6b4c0139}},	//   romà_, _کولک_, _җилт, _mögı, 
   {{0x2d8443d6,0x3f840165,0x8144104c,0xfce80092}},	//   _cane_, _waou_, _آنان, _መራጭ_, 
   {{0x333c4aee,0x2d859d72,0x2b4003cb,0x39400810}},	//   _yeux_, _dane_, _beic_, vajs_, 
   {{0x2d8400fb,0x2b400c8e,0x20d801e4,0x917801e1}},	//   _eane_, _ceic_, _iɩi_, _tẹ̀_, 
   {{0x2d859d73,0xed4c2eac,0xdb1d2295,0xbda400c6}},	//   _fane_, _چپه_, misü, _يحتو, 
   {{0x2d859d74,0xdb1c57d9,0x2a64002e,0x00000000}},	//   _gane_, lisü, àmba_, --, 
   {{0x37a80acf,0x9cf402bf,0x2018003e,0x2b419d75}},	//   отан_, _язкі, _éris_, _feic_, 
   {{0x2d859d76,0x2b400048,0x31d800dc,0x601c0022}},	//   _zane_, _geic_, _बद्ध, _kũmb, 
   {{0xde88063f,0x2d859d77,0x333c0369,0xfbdc011f}},	// [2c190] _jị_, _yane_, _reux_, mnê_, 
   {{0xde88004d,0xdb1c0254,0x00000000,0x00000000}},	//   _mị_, hisü, --, --, 
   {{0x333c0231,0xaee000b8,0x58d400cf,0xde880208}},	//   _peux_, _bhṛk, _чонт, _lị_, 
   {{0xdcf800b8,0x2b40004e,0x99880139,0x6b7c010f}},	//   _anvī, _xeic_, _yuaş_, ַרונ, 
   {{0x333c3a6d,0xdb1cbd88,0xde880051,0x00000000}},	//   _veux_, disü, _nị_, --, 
   {{0x2324008e,0x00000000,0x00000000,0x00000000}},	//   нфәг, --, --, --, 
   {{0xf3642071,0xfcdc0023,0xdb1c0210,0x00000000}},	//   _отан, _ሓጋጊ_, nisó, --, 
   {{0xde8801dc,0x2d859d78,0x3ddc0113,0x0ea8234c}},	//   _bị_, _sane_, entw_, зкий_, 
   {{0x2d859d79,0x2b400192,0x00000000,0x00000000}},	//   _pane_, _reic_, --, --, 
   {{0xde883127,0xb0300022,0x2b40679d,0x2d840213}},	//   _dị_, _амжә, _seic_, _qane_, 
   {{0x2d859d7a,0xc5f006a9,0x2b400472,0xdb1c0254}},	//   _vane_, רדי_, _peic_, bisü, 
   {{0x2d859d7b,0xb7c000cc,0x8ba4009d,0xdb1c02d2}},	//   _wane_, ্কুট, химж, disó, 
   {{0x2d859d7c,0xde883127,0x2b40005f,0x39480023}},	//   _tane_, _gị_, _veic_, _ንምዝራ, 
   {{0x8fd09e04,0xbed400c8,0xfbdc0548,0x8c44496b}},	//   _шәһә, _אונז_, anê_, _зеке, 
   {{0x2fdc00e8,0x2b4000e2,0xde880208,0x310c00dc}},	//   onug_, _teic_, _zị_, ाधिः_, 
   {{0xc7b05821,0xdc740588,0x2fdd9d7d,0x7c2d9d7e}},	//   دّر_, _рышь, nnug_, íbre, 
   {{0xde880208,0xa52c0327,0x44a401b9,0x37e001d5}},	// [2c1a0] _xị_, _ཧྥུག_, کماق, уотг, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb1c00d8,0x84595f21,0x00000000,0x00000000}},	//   cisó, ярат_, --, --, 
   {{0x7538009b,0x00000000,0x00000000,0x00000000}},	//   _đuze, --, --, --, 
   {{0x660004e6,0x27e19d7f,0xdcf80064,0xdb1c0254}},	//   _ëmko, mnin_, _davę, visü, 
   {{0x20d801e4,0x27e19d80,0xdb1c0561,0x2fdc002e}},	//   _pɩi_, lnin_, nisò, enug_, 
   {{0x27e19d81,0x645806ed,0xde8800b4,0xd4f499fc}},	//   onin_, ávid, _sị_, _аяты, 
   {{0x27e19d82,0xadc00248,0xdcf80153,0xdfd0007b}},	//   nnin_, _ikẹh, _gavę, ؤية_, 
   {{0x27e19d83,0xdb1d9d84,0xaf3000d1,0x00000000}},	//   inin_, kisò, درىت, --, 
   {{0xde8807ae,0x27e19d81,0x1b2400fe,0x75e803e0}},	//   _vị_, hnin_, পৰাই_, füzy, 
   {{0x40959d85,0xb698006a,0x27e19d86,0x00000000}},	//   _ярат, _nzân, knin_, --, 
   {{0xdb1c06ed,0x27e19d87,0x71a0035b,0xde88004d}},	//   visó, jnin_, _ақәҵ, _tị_, 
   {{0x27e19d88,0xfbdc0120,0xa3b80037,0x00000000}},	//   dnin_, rnê_, _जानs_, --, 
   {{0x27e19d89,0x32c40150,0x00000000,0x00000000}},	//   enin_, _ﯨﺮﮔﻪ, --, --, 
   {{0xf80475b8,0x27e001a8,0x5b0000f1,0x3c44013a}},	//   ечан, fnin_, دېښم, _dívá_, 
   {{0x27e19d8a,0x588414d4,0xdb1c03b2,0x00000000}},	//   gnin_, ныға, risó, --, 
   {{0x7f40003a,0xbe400023,0x00000000,0x00000000}},	// [2c1b0] _meoq, _ጭብጥታ, --, --, 
   {{0x27e19d8b,0xdb1c0034,0xdcf80024,0x66000036}},	//   anin_, pisó, _savę, _ëmkl, 
   {{0x27e10816,0xa3b800e5,0x00000000,0x00000000}},	//   bnin_, کالر_, --, --, 
   {{0x7f4000d8,0xf77c010e,0x27e001ef,0x00000000}},	//   _neoq, _gkçp_, cnin_, --, 
   {{0xa2940d30,0x22940212,0x31700961,0x656c0174}},	//   лаці, лиця, лғат, álhø, 
   {{0xf4bc00cc,0x00000000,0x00000000,0x00000000}},	//   _আশীব, --, --, --, 
   {{0x10a4074d,0xdb1c0113,0xdcf80024,0x94d400f3}},	//   тийн, hisñ, _tavę, _ровц, 
   {{0x645800d0,0x02d04466,0x00000000,0x00000000}},	//   ávie, _देवभ, --, --, 
   {{0x52148205,0x7f406a89,0x59d001ad,0x00000000}},	//   _адат, _deoq, सफार, --, 
   {{0x64580006,0x27e0036e,0x00000000,0x00000000}},	//   švie, znin_, --, --, 
   {{0x27e19d8c,0x765c0357,0x1e8401c0,0x98a0002b}},	//   ynin_, huqy, влөм, _dehī_, 
   {{0xc0dc02d3,0x7f40067c,0xdb1c0332,0xdcf8013a}},	//   _ንኩሉ_, _geoq, bhsí, _havě, 
   {{0x27e0022c,0x2e4401e1,0x8d94007b,0x00000000}},	//   vnin_, _dìfá_, _للإش, --, 
   {{0x27e19d8d,0xfdd805d9,0x5f7400cf,0x00000000}},	//   wnin_, _ٺاهڻ_, _لاۇر, --, 
   {{0x27e19d8e,0xd268001f,0x6d419d8f,0x7d2800e5}},	//   tnin_, ተባባሪ_, _iena, _غزوہ_, 
   {{0x6d419d90,0x27e19d91,0xb7e012c4,0xc0500a1e}},	//   _hena, unin_, ажск, יזל_, 
   {{0x6d419d92,0x27e19d93,0x056406bb,0xc564546a}},	// [2c1c0] _kena, rnin_, кван, ккак, 
   {{0x6d419d94,0x27e19d95,0xdb1c002d,0x29040213}},	//   _jena, snin_, chsâ, əman_, 
   {{0x27e00023,0x43440fbe,0x090400f5,0x00000000}},	//   pnin_, веев, _шпон, --, 
   {{0x6d419d96,0x27e00986,0x00000000,0x00000000}},	//   _lena, qnin_, --, --, 
   {{0x02d0000b,0x217801af,0x00000000,0x00000000}},	//   _देशभ, ейлы_, --, --, 
   {{0xb5f80022,0xefb007d6,0x00000000,0x00000000}},	//   _opáy, ییلگ, --, --, 
   {{0x441400c7,0x04440395,0xb6180150,0x00000000}},	//   _афат, _шевн, _ﺠﺭ_, --, 
   {{0x6d400793,0x661c0ba7,0x00000000,0x00000000}},	//   _aena, _hirk, --, --, 
   {{0x6d414c3c,0x661d9d97,0xb5f800e4,0x2f2402d2}},	//   _bena, _kirk, _apáy, _sígó_, 
   {{0x6d419d98,0x661d9d99,0x00000000,0x00000000}},	//   _cena, _jirk, --, --, 
   {{0x661d9d9a,0x6d419d9b,0xdb1c0113,0xdd903cc4}},	//   _mirk, _dena, wisñ, لوک_, 
   {{0x661c06f2,0x6d40035a,0xdcf800bc,0xfbf00107}},	//   _lirk, _eena, _zavě, ромӯ, 
   {{0x6d419d9c,0x290c0209,0x57b401ec,0x00000000}},	//   _fena, ýdan_, қбат, --, 
   {{0x6d410f34,0x661d9d9d,0x58d43e25,0x00000000}},	//   _gena, _nirk, гогт, --, 
   {{0xdb1c0227,0xe8243129,0xb76400f7,0x28f80108}},	//   sisñ, ифто, ктай, верь_, 
   {{0x6d419d9e,0xf84405f5,0x9f4c0166,0x6ab003b2}},	//   _zena, нүүд_, _älär_, ðifó, 
   {{0x55759d9f,0x356836b1,0x00000000,0x00000000}},	// [2c1d0] лгат, дрен_, --, --, 
   {{0x6d419da0,0x765d93d5,0xa2b800cd,0x00000000}},	//   _xena, ruqy, ्नन्, --, 
   {{0x661d9da1,0x521402dd,0xe3b00451,0x54540116}},	//   _dirk, ңдет, ڊرن_, увет, 
   {{0xe3b005d9,0x765c02d1,0x00000000,0x00000000}},	//   يرن_, puqy, --, --, 
   {{0xd174004e,0x00000000,0x00000000,0x00000000}},	//   гыйы, --, --, --, 
   {{0x661d9da2,0x64580118,0xe53400f5,0xe29000ec}},	//   _girk, ávic, _верь, غذن_, 
   {{0xc5f000d9,0x5eb00154,0x00000000,0x00000000}},	//   _הדם_, _জেলে, --, --, 
   {{0x661d9da3,0x1fb4010b,0x81a001ec,0x00000000}},	//   _zirk, исыр, _ۇڭىل, --, 
   {{0x661d9da4,0xdce80205,0x00000000,0x00000000}},	//   _yirk, tedğ, --, --, 
   {{0xfde47564,0x62240131,0x661d6fd1,0x6d401366}},	//   лдык_, _ئىلل, _xirk, _qena, 
   {{0xcb690a1b,0x00000000,0x00000000,0x00000000}},	//   нане_, --, --, --, 
   {{0x6d419da5,0x4e9441ff,0x7c2c00bc,0x00000000}},	//   _wena, _مشتر, íbra, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d419da6,0x7c2c00df,0xc954008e,0x00000000}},	//   _uena, ŭbra, ытмы, --, 
   {{0x3ab0013d,0xbb180124,0x00000000,0x00000000}},	//   _һәрт, teîc, --, --, 
   {{0xd244c0cc,0x00000000,0x00000000,0x00000000}},	//   _وچ_, --, --, --, 
   {{0x661d9da7,0x46e96036,0x06099da8,0xb6a001d5}},	// [2c1e0] _pirk, хдан_, енак_, битл, 
   {{0x80c82158,0x661c022e,0xd4080014,0x45459da9}},	//   িপত্, _qirk, ۆتنم_, اناق, 
   {{0x661d9daa,0xdb1c0332,0x00000000,0x00000000}},	//   _virk, mhsá, --, --, 
   {{0x661d9dab,0x929c068f,0x43740120,0xc7a59dac}},	//   _wirk, _czło, ѓует, _симк, 
   {{0xbb380a1e,0x61440124,0xe1f80b01,0x00000000}},	//   געני, иҵаа, вҳа_, --, 
   {{0xa19400f7,0x681c007f,0x661c03ac,0x00000000}},	//   ракч, _kōdo, _uirk, --, 
   {{0x1fc40107,0x00000000,0x00000000,0x00000000}},	//   ириҳ, --, --, --, 
   {{0xdfd0099f,0x9f440418,0xa3b835e8,0xdb0c0432}},	//   تيب_, lomú_, _छवि_, _alaý, 
   {{0x2ba808df,0xdb1c000d,0x33d8011a,0x02040117}},	//   गाना, lisö, _נחמד, _бзан, 
   {{0x5c74d282,0xe1640214,0x8cc40118,0x00000000}},	//   алот, _خضری, ानढो, --, 
   {{0xb5f4010f,0x290c03b2,0x00000000,0x00000000}},	//   רציג_, ýdal_, --, --, 
   {{0xdb0c00a2,0x6e900214,0x00000000,0x00000000}},	//   _elaý, _گلها, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb1d9dad,0x6e900066,0x00000000,0x00000000}},	//   ghsá, _دلها, --, --, 
   {{0xf4bc0011,0x601000e4,0x9f4400d7,0xdb1c0205}},	//   _আশ্ব, _ẽmya, domú_, jisö, 
   {{0xc06402d3,0x1a641fb8,0x67d400cf,0x00000000}},	//   _ዘይተገ, _پیسی_, босу, --, 
   {{0xdb1c0597,0xdb0c010b,0x00000000,0x00000000}},	// [2c1f0] bhsá, _ylaý, --, --, 
   {{0x61e4007b,0xaee000b8,0x8cd80118,0x00000000}},	//   éill, _hiṃk, _फेडो, --, 
   {{0xdb0c004e,0xdcf80139,0xaee0002b,0x00000000}},	//   _llaü, _kovı, _kiṃk, --, 
   {{0x645800d0,0xd79402e8,0x8838011a,0x00000000}},	//   ávia, _тимъ, _שגרת, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdce8005f,0x00000000,0x00000000,0x00000000}},	//   nedē, --, --, --, 
   {{0x24980077,0xdb1c00af,0x2ba836c7,0x00000000}},	//   _grrm_, misõ, गामा, --, 
   {{0xdb1c00c5,0x73e000f7,0xdcf8013d,0xdb0c00a2}},	//   lisõ, _ايرۅ, _novı, _slaý, 
   {{0xe3b16265,0x00000000,0x00000000,0x00000000}},	//   _عرف_, --, --, --, 
   {{0x20c40724,0xef9400fd,0x8c940d30,0xdb1c000d}},	//   рсәг, _әйдә_, армі, nisõ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb0c067c,0xdb1c12ce,0x00000000,0x00000000}},	//   _flaü, cksë, --, --, 
   {{0x2ba8190e,0x8a04a401,0xca742123,0xdb1c000d}},	//   गाबा, изме, шуны, kisõ, 
   {{0x8cb4156b,0x9f040472,0xa2b800cd,0x00000000}},	//   _всич, _اوهو, ्नत्, --, 
   {{0xdb1c0037,0xe748013d,0x00000000,0x00000000}},	//   disõ, лүне_, --, --, 
   {{0xfafc0023,0xdb1c000d,0x00000000,0x00000000}},	//   rfër_, visö, --, --, 
   {{0x91c428fe,0x00000000,0x00000000,0x00000000}},	// [2c200] वसाई, --, --, --, 
   {{0xdb1d9dae,0x3ab8011a,0x00000000,0x00000000}},	//   tisö, _סמינ, --, --, 
   {{0x03252f24,0xc484d645,0xfafc0023,0xbb180311}},	//   аден, рлек, ngën_, neîn, 
   {{0x69dd9daf,0xdb1c007c,0xa85401ee,0x71f401fd}},	//   lire, risö, _кеүә, یروس_, 
   {{0x69dd4fa5,0x0cc000e1,0x600c000f,0xdb1c00c5}},	//   oire, शनुम, nûme, bisõ, 
   {{0x69dd9db0,0xdb1d06c9,0x95480633,0x6d440162}},	//   nire, cisõ, _مشفق_, ðjal, 
   {{0xdb1c00d2,0x00000000,0x00000000,0x00000000}},	//   lisô, --, --, --, 
   {{0x69dd9db1,0x44399db2,0xa2b81cba,0x00000000}},	//   hire, mpp_, ्नद्, --, 
   {{0x44380354,0x9df8e2cc,0x2f1001f4,0x00000000}},	//   lpp_, лнит_, одъё, --, 
   {{0x69dd9db3,0xdb0c067c,0xf400031c,0x44380393}},	//   jire, _soaï, _མཚོད_, opp_, 
   {{0xb2f08d8d,0x61f99db4,0x69dd9db5,0x443805b1}},	//   _བཙོང_, movl, dire, npp_, 
   {{0x4438026c,0x6fb000c6,0x69dc3cb2,0x00000000}},	//   ipp_, _وملا, eire, --, 
   {{0x69dd9db6,0xcf241216,0xdd959db7,0xcff40214}},	//   fire, _ارمي, _галы, _اينک, 
   {{0x0ae80451,0xda090404,0xa9c40108,0xae4000e5}},	//   ارٽي_, ايسه_, осск, _بھٹو, 
   {{0xed54a8c9,0xdb1c06ed,0xbe6005d9,0x2d500244}},	//   _тој_, visõ, _اهڙي, _بێپس, 
   {{0x7c399db8,0x69dd9db9,0x61f99dba,0x443800b5}},	//   mptr, aire, hovl, dpp_, 
   {{0x69dd9dbb,0x61f801b4,0xdb1c0037,0x64599dbc}},	// [2c210] bire, kovl, tisõ, ávin, 
   {{0x69dd9dbd,0x7c3801f5,0x00000000,0x00000000}},	//   cire, optr, --, --, 
   {{0xd8940014,0x61f99dbe,0xdb1c0037,0x62840165}},	//   _أجد, dovl, risõ, çion, 
   {{0x88980bd4,0xdb0c05c7,0xdb1c00c5,0x245879ac}},	//   _עברי, _hlañ, sisõ, раць_, 
   {{0x44380334,0xdb0c0156,0xaee000cd,0x600c00e4}},	//   app_, _klañ, _kiṅk, kûmb, 
   {{0x61f807f5,0x3088001f,0xe1f80006,0x00000000}},	//   govl, _በርግጥ_, агі_, --, 
   {{0x7d0802b5,0xb36400a7,0x823c001f,0x6d4403b2}},	//   _nzfs, _възк, _ይደርሳ, ðjam, 
   {{0x69dd9dbf,0xb4b0482a,0x79780150,0x00000000}},	//   zire, टही_, _ﺠﻤﻴﻌ_, --, 
   {{0x69dd1162,0x61f80b3d,0x929c0034,0x7c380072}},	//   yire, bovl, _byłe, eptr, 
   {{0x69dc0005,0x290c00ee,0xbb180022,0x80a00137}},	//   xire, ýdak_, teîn, تۅۅن, 
   {{0x69dd9dc0,0xc8d402ab,0xe0d000db,0x00000000}},	//   vire, _डेंट, _ۉزۅ_, --, 
   {{0x69dc08e7,0xdb0c0054,0x00000000,0x00000000}},	//   wire, _alañ, --, --, 
   {{0x69dd9dc1,0x00000000,0x00000000,0x00000000}},	//   tire, --, --, --, 
   {{0x6e399dc2,0xdfd00150,0x44399dc3,0x69dc83bf}},	//   mpub, _ىيە_, ypp_, uire, 
   {{0x07a41f91,0x6e38009f,0xc7a4c2f3,0x2ba80c6f}},	//   бавн, lpub, бивк, गादा, 
   {{0x0b440517,0x69dd9dc4,0x872400d4,0x00000000}},	//   _унин, sire, смаж, --, 
   {{0xb8fc1f5e,0xbb3804ac,0x6e399dc5,0x443805b1}},	// [2c220] _दे_, _געפי, npub, wpp_, 
   {{0xdb0c05c7,0x6e380793,0x69dd9dc6,0xa2b800dc}},	//   _glañ, ipub, qire, ्नस्, 
   {{0xdb0c01a8,0x61f80306,0x00000000,0x00000000}},	//   _hlað, vovl, --, --, 
   {{0x42c80dd8,0x4438009f,0xdb0c03b2,0x63a400e2}},	//   лген_, rpp_, _klað, ķino, 
   {{0x61f85340,0x02d00d0a,0xdb1c0112,0x00000000}},	//   tovl, _देखभ, chsä, --, 
   {{0x7174005e,0x929c033f,0x00000000,0x00000000}},	//   йбір_, _byłb, --, --, 
   {{0x61f99dc7,0x30a02e70,0x35c4361e,0x00000000}},	//   rovl, зрыв, _угро_, --, 
   {{0x9a28004d,0x61f99dc8,0xb024007b,0x44280171}},	//   _lươn_, sovl, حكيم_, _iub_, 
   {{0x2bcc081e,0x600c025a,0x6e380280,0xfafc0de2}},	//   ासना, tûmb, gpub, ggël_, 
   {{0x44280457,0x849002d3,0x62800455,0x7b6400fd}},	//   _kub_, _ቃልስን_, _ipmo, әтне, 
   {{0x44281574,0xb5f800c8,0x66000036,0xc1040ee8}},	//   _jub_, רליכ, _ëmku, _اواي, 
   {{0xdb0c2242,0x44299dc9,0x09c000bd,0x6e38003b}},	//   _blað, _mub_, _ঈদগা, bpub, 
   {{0x44299dca,0xbf140517,0xdb0c0156,0x2f940375}},	//   _lub_, _اوشب, _plañ, _לכאן_, 
   {{0xf2d004ac,0x7c383402,0x20040113,0xed300050}},	//   לער_, pptr, llmi_, _ٹوٹھ, 
   {{0x44299dcb,0x64580306,0x00000000,0x00000000}},	//   _nub_, ávil, --, --, 
   {{0x67d59dcc,0x62819dcd,0xdb0c02d2,0x00000000}},	//   посу, _opmo, _flað, --, 
   {{0x44299dce,0xdb0c08a7,0x6458c65d,0xac6c02d3}},	// [2c230] _aub_, _glað, švil, _ጸኒሖም_, 
   {{0x9cfc02a6,0xfbdc0120,0x44299dcf,0xf5240107}},	//   ুখীন_, liê_, _bub_, сфан, 
   {{0x7984015c,0x7c299dd0,0x62800006,0x00000000}},	//   mejw, _jufr, _apmo, --, 
   {{0x44299dd1,0x7984342f,0x9239668e,0x3348027a}},	//   _dub_, lejw, ачку_, اجاً_, 
   {{0x7c28030a,0x477000d1,0xdcf800e2,0x5920010b}},	//   _lufr, _юқту, _kavē, _хүңң, 
   {{0x20059dd2,0x8678008d,0x44299dd3,0x798400ca}},	//   elmi_, _דרשו, _fub_, nejw, 
   {{0x44299dd4,0x7c2800db,0x628002d0,0x2bcc085c}},	//   _gub_, _nufr, _epmo, ासमा, 
   {{0x7984016d,0x60c400df,0xdce800c0,0x00000000}},	//   hejw, ĝimp, ledė, --, 
   {{0x7c299dd5,0x0dc99dd6,0x79840230,0x776c003a}},	//   _aufr, илий_, kejw, _mccx, 
   {{0x7984f320,0x7c299dd7,0x6e38005f,0x20040113}},	//   jejw, _bufr, rpub, almi_, 
   {{0x6e398dfc,0x44280457,0x00000000,0x00000000}},	//   spub, _xub_, --, --, 
   {{0xcb691f9c,0x6e380003,0xfbdc0208,0x00000000}},	//   шаме_, ppub, giê_, --, 
   {{0x7c299dd8,0x16085a30,0x8cd802ab,0x37dc00eb}},	//   _eufr, वतार_, _फेरो, ভকার, 
   {{0x8c444170,0x7c2804cc,0x79855e61,0x2a840092}},	//   _деке, _fufr, gejw, ራተኞች_, 
   {{0x290ca249,0x6e280ad9,0x9a2801fb,0x4c68d0f4}},	//   åda_, _hugb, _vươn_, _тийн_, 
   {{0x6e219dd9,0x44299dda,0x6e28006a,0x290534c7}},	//   _hinb, _rub_, _kugb, āma_, 
   {{0x7c299ddb,0x998801f1,0x776c0393,0x6e219ddc}},	// [2c240] _zufr, _stať_, _dccx, _kinb, 
   {{0x44299ddd,0xa6c99dde,0x6e219ddf,0x7c280810}},	//   _pub_, алға_, _jinb, _yufr, 
   {{0x4428dd32,0x6e219de0,0x6e299de1,0x44883756}},	//   _qub_, _minb, _lugb, рбен_, 
   {{0x6e219de2,0x4428e679,0x98040024,0x00000000}},	//   _linb, _vub_, _няўд, --, 
   {{0x27e19de3,0x6e20005a,0xb9dc02d3,0x00000000}},	//   miin_, _oinb, _ጥቓ_, --, 
   {{0x44299de4,0x27e19de5,0xdbe0145e,0x6e219de6}},	//   _tub_, liin_, _zïän, _ninb, 
   {{0x8cd802ab,0x601c00e4,0x4428003e,0x00000000}},	//   _फेलो, _hũmi, _uub_, --, 
   {{0x27e19de7,0x6e299de8,0x6e219de9,0x7984014b}},	//   niin_, _bugb, _ainb, zejw, 
   {{0x7c299dea,0x6e280007,0x26c00109,0x79840117}},	//   _sufr, _cugb, nyio_, yejw, 
   {{0x27e00d62,0x6e200007,0x6e280241,0x200403f9}},	//   hiin_, _cinb, _dugb, slmi_, 
   {{0x27e19deb,0x6e219dec,0xdcf80171,0x9b94003b}},	//   kiin_, _dinb, _ravē, пинц, 
   {{0x6e219ded,0x27e00a55,0x79859dee,0xdcf800e2}},	//   _einb, jiin_, wejw, _savē, 
   {{0x27e19def,0x6e28011f,0x79840526,0x6fb010ef}},	//   diin_, _gugb, tejw, _تمنا, 
   {{0x6e219df0,0xdd94363c,0x7c28008e,0x7cd400ae}},	//   _ginb, _хакы, _tufr, _وتغذ, 
   {{0x7984015c,0x27e19df1,0x71d40375,0xaae00073}},	//   rejw, fiin_, קולד_, _पेठक, 
   {{0x27e19df2,0x6e20005a,0x96344031,0x00000000}},	//   giin_, _zinb, знац, --, 
   {{0xec140014,0x9f443d5a,0x6e20047e,0x2ba828e0}},	// [2c250] _زوٝد, lomó_, _yinb, गारा, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x27e00a55,0x681c007f,0x7ae800e2,0x6ff00356}},	//   biin_, _nōdw, ņotā, lăce, 
   {{0xb9f40201,0x7bcd2a45,0x27e19df3,0xdb0c00e4}},	//   _ዛሬ_, nhcu, ciin_, _ãhóv, 
   {{0x9f4400d2,0x929c0034,0x7524037e,0x2c4400e5}},	//   homó_, _była, _tgjz, ződ_, 
   {{0x6e299df4,0xe65400d4,0x1ad800fe,0x00000000}},	//   _rugb, _івсь, _ধুৱা, --, 
   {{0x6e219df5,0x64740209,0x245800a8,0x6e299df6}},	//   _rinb, _огру, _марь_, _sugb, 
   {{0x6e219df7,0x6e2801e4,0x660001c7,0xb2840124}},	//   _sinb, _pugb, _ëmkr, _мызк, 
   {{0x4fc004da,0x8eb80137,0xe374e564,0x00000000}},	//   _ۋەتە, сыйт_, _юлты, --, 
   {{0x6e20022f,0x27e00ba7,0xdb1c007b,0x273c0118}},	//   _qinb, ziin_, bhsú, mánů_, 
   {{0x27e19df8,0x6e20b9ea,0x69c007ea,0x2ba80404}},	//   yiin_, _vinb, êmem, गाला, 
   {{0x6e299df9,0x27e19dfa,0x00000000,0x00000000}},	//   _tugb, xiin_, --, --, 
   {{0x6e219dfb,0x27e002f6,0x0de8001f,0xbb1800e4}},	//   _tinb, viin_, _መጻፍ_, neîh, 
   {{0xf77c00d8,0x64599dfc,0x8d759dfd,0x27e19dfe}},	//   _abç_, ávik, _راتا, wiin_, 
   {{0x27e19dff,0xc7a473d6,0x4c3401c6,0x2bcc08a3}},	//   tiin_, пивк, _ээлт, ासदा, 
   {{0x25b874b5,0x273c013a,0x00000000,0x00000000}},	//   _sorl_, kánů_, --, --, 
   {{0x27e19e00,0xc07401fb,0x09e401b9,0x00000000}},	// [2c260] riin_, _bướm_, _ноин, --, 
   {{0x27e19e01,0x89640150,0x00000000,0x00000000}},	//   siin_, _экож, --, --, 
   {{0xc3299e02,0x487800a7,0x27e19e03,0x291c00e4}},	//   مكان_, _успя_, piin_, _àva_, 
   {{0x27e08515,0x7c2c06ed,0x32059e04,0x224000e4}},	//   qiin_, íbri, elny_, ãiko_, 
   {{0xb6a04da8,0x273c00bc,0x9f440100,0xa194004e}},	//   _зиял, gánů_, komò_, далч, 
   {{0xf19000c7,0x00000000,0x00000000,0x00000000}},	//   еишь, --, --, --, 
   {{0x99480210,0xf990011a,0x00000000,0x00000000}},	//   _różu_, גרו_, --, --, 
   {{0x04442c1d,0xd24c168d,0x32040034,0x929c033f}},	//   _меҳн, _چۆن_, alny_, _wyła, 
   {{0xd24c01d9,0x31202cc8,0x7f4800cf,0xc0640023}},	//   _نۆن_, мдәг, _ۇلاق_, _ዘይምግ, 
   {{0x9f440789,0x61c80133,0x2dd000c7,0x929c0210}},	//   tomó_, _بدرێ_, ежьр, _człu, 
   {{0xff400020,0x3154008f,0x7c840395,0xff2801a9}},	//   _የጀርመ, _זיבן_, чупе, _лўли_, 
   {{0x7bcc0007,0xdb0c00d8,0x6ff00356,0x00000000}},	//   uhcu, _joaç, tăce, --, 
   {{0x645802f0,0x79a40a5b,0x00000000,0x00000000}},	//   švih, прве, --, --, 
   {{0x98a00055,0x26140037,0x066400d1,0x00000000}},	//   _aghā_, näod_, _ﺷﻪﻫﯩ, --, 
   {{0x2018067c,0x00000000,0x00000000,0x00000000}},	//   _èris_, --, --, --, 
   {{0x1cdc1f21,0x7bcc0113,0x6ff00356,0x00000000}},	//   _ལྟར_, qhcu, păce, --, 
   {{0x66f41142,0xe6646997,0x79a52033,0x67d4014b}},	// [2c270] епту, етхо, _ерне, хоту, 
   {{0x2a64043b,0x00000000,0x00000000,0x00000000}},	//   ámbe_, --, --, --, 
   {{0x320402fb,0x30e400eb,0x00000000,0x00000000}},	//   vlny_, _ফর্স, --, --, 
   {{0xdb0c00d8,0xbb1800c7,0x00000000,0x00000000}},	//   _coaç, teîh, --, --, 
   {{0xdb0c06ed,0x59d02d81,0x00000000,0x00000000}},	//   _doaç, _हतार, --, --, 
   {{0xc6900375,0x00000000,0x00000000,0x00000000}},	//   _שאם_, --, --, --, 
   {{0x79959e05,0x7bdc014b,0x29380a1e,0xddc0054e}},	//   _maxw, _omqu, לאגן_, zumţ, 
   {{0x7994b034,0x00000000,0x00000000,0x00000000}},	//   _laxw, --, --, --, 
   {{0x1ca80327,0xdce800e2,0x00000000,0x00000000}},	//   བཀའ_, bedī, --, --, 
   {{0xf428031c,0xdb0c00d8,0x79940067,0x61e401e7}},	//   _སྤོད_, _zoaç, _naxw, éilt, 
   {{0xaf34106b,0x8f740064,0x00000000,0x00000000}},	//   _فرشت, _жулі, --, --, 
   {{0x952c031c,0x00000000,0x00000000,0x00000000}},	//   _ཧུའི_, --, --, --, 
   {{0x7994379d,0x499800a7,0xaee000db,0x98a00055}},	//   _baxw, отвя_, _سۋدى, _rghā_, 
   {{0x7bdc01f0,0x63a4005f,0x7c2c01e7,0x17c400c7}},	//   _emqu, ķini, úirí, ҭарҭ, 
   {{0xf7880131,0xd7c807af,0x87b80276,0x00000000}},	//   ﺗﻠﯩﻚ_, रसंच, оуат_, --, 
   {{0x6d440de2,0x8d7400ec,0xc76402de,0x00000000}},	//   ñjaf, _راڪا, باسى, --, 
   {{0x8cc46594,0x952c0327,0x00000000,0x00000000}},	// [2c280] ानको, _ཧུཡི_, --, --, 
   {{0x04459e06,0xab645f32,0x333000b8,0x00000000}},	//   дежн, _تۇڭى, _ārāḍ, --, 
   {{0xdce800e2,0x929c033f,0x245400c7,0xdcf800c0}},	//   vedī, _było, _ẽmbe_, _davė, 
   {{0x1cdc0003,0x00000000,0x00000000,0x00000000}},	//   _ལྟས_, --, --, --, 
   {{0x7994014b,0x425402e8,0x71400014,0x05540d1d}},	//   _yaxw, фтет, چھمٕ, _отвя, 
   {{0xc0a99a3f,0xdcf80024,0x00000000,0x00000000}},	//   قابل_, _gavė, --, --, 
   {{0xc1a401ec,0x9f3401ec,0x00000000,0x00000000}},	//   зыққ, нейі, --, --, 
   {{0x3ec465cb,0xd39800d1,0x3c38002b,0x8fd4013d}},	//   дсоб, _нәчә_, _jīve_, нәчә, 
   {{0x733007d2,0xdb1c0162,0xfd880107,0x00000000}},	//   _شىلا, kksá, оёни_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x291c02f0,0xbb1800c7,0x40940408,0x00000000}},	//   _úvah_, neîv, _юрат, --, 
   {{0x2014033f,0x79940009,0xf4540375,0xbea801f7}},	//   ócić_, _saxw, ויטר_, _وهان_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7c64f2af,0x6d4801e4,0x7994058a,0x29840022}},	//   _قابل, _ƭlaŭ, _qaxw, кысг, 
   {{0xd7f40c9e,0x58d4190b,0xdcf800c0,0x00000000}},	//   езвы, ховт, _ravė, --, 
   {{0x79959e07,0x7bdd9e08,0x58840220,0x00000000}},	//   _waxw, _umqu, мыға, --, 
   {{0x7994002e,0xdcf80024,0x2bcc0073,0xc20c00ce}},	// [2c290] _taxw, _pavė, ासरा, िताब_, 
   {{0x1cdc03bd,0xaa88034c,0xf428025c,0x00000000}},	//   _ལྟོ_, _کنیم_, _སྤུད_, --, 
   {{0xe73001d3,0x00000000,0x00000000,0x00000000}},	//   اصہ_, --, --, --, 
   {{0x720000d1,0x52740114,0xddc001ef,0x00000000}},	//   چۈرم, еуку, krmů, --, 
   {{0xa29400d6,0x00000000,0x00000000,0x00000000}},	//   каці, --, --, --, 
   {{0xaad007f7,0x929c033f,0x00000000,0x00000000}},	//   हनतक, _wyło, --, --, 
   {{0xa504010b,0x41b0129d,0x4124004e,0x00000000}},	//   _аятл, امىر, ношо_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x91800075,0x4fa40116,0x0d980139,0x00000000}},	//   _مۇشۇ, _җилв, птны_, --, 
   {{0x4c699e09,0xc6900302,0x8d740131,0xd130007b}},	//   пион_, נאי_, راخا, _إما_, 
   {{0x41bc2435,0xdb1c005c,0x2bcc00bc,0x00000000}},	//   ्सरस, nksæ, ासला, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xaae00034,0x00000000,0x00000000,0x00000000}},	//   _पेशक, --, --, --, 
   {{0x7d0c002f,0x00000000,0x00000000,0x00000000}},	//   übsc, --, --, --, 
   {{0x997c005f,0x52bc012c,0x8b8400cf,0x00000000}},	//   kāņu_, ्नुस, _كەدە_, --, 
   {{0xc5f8694b,0x00000000,0x00000000,0x00000000}},	//   ्त्य_, --, --, --, 
   {{0x6b859e0a,0xd6a800ae,0x00000000,0x00000000}},	// [2c2a0] _ibig, ودكم_, --, --, 
   {{0xbb180124,0x06640150,0x00000000,0x00000000}},	//   teîv, _ﺷﻪﻧﯩ, --, --, 
   {{0x6aa401a8,0x48080798,0x00000000,0x00000000}},	//   _hrif, _неон_, --, --, 
   {{0x6b84025c,0x00000000,0x00000000,0x00000000}},	//   _jbig, --, --, --, 
   {{0xa2941c26,0x3d04007d,0xbb180af2,0x6b859e0b}},	//   талі, _सुने_, mfîc, _mbig, 
   {{0x6aa40142,0x00000000,0x00000000,0x00000000}},	//   _mrif, --, --, --, 
   {{0x6b859e0c,0xfafc0240,0x997c00ef,0x00000000}},	//   _obig, lgët_, bāņu_, --, 
   {{0xdfd00491,0x645c0ac8,0xf8b004ae,0x308007fc}},	//   شيخ_, _ivri, רשה_, اليف, 
   {{0x3ea02833,0xdb1c00ac,0xfafc0023,0xbb1800e4}},	//   íkt_, üyün, ngët_, neît, 
   {{0x6b859e0d,0x998808ad,0x2fcc005a,0xddc001ed}},	//   _abig, _staž_, _elgg_, ttmű, 
   {{0x9f440023,0x9bd402bf,0xee7410e5,0x6ca0004e}},	//   nimë_, вжні, وصیت_, гряж, 
   {{0x6aa59e0e,0x6ff0054e,0xdcf8002b,0x00000000}},	//   _brif, păca, _havī, --, 
   {{0xb698019f,0xdd943697,0xdcf800b8,0x2aa803d0}},	//   _vyâk, _аалы, _kavī, нтро_, 
   {{0x2a659e0f,0x6aa59e10,0x6fc40054,0x6b859e11}},	//   ámba_, _drif, _añch, _ebig, 
   {{0x6a159e12,0x6aa59e13,0x779123dd,0x06dc00eb}},	//   умру, _erif, هیدا, _ভুলি, 
   {{0x6aa43c02,0x6b84110e,0xdcf80171,0x00000000}},	//   _frif, _gbig, _lavī, --, 
   {{0x7d0801e6,0x387001ec,0x00000000,0x00000000}},	// [2c2b0] _hyfs, _әқбт, --, --, 
   {{0x6b84033f,0xdcf800b8,0x00000000,0x00000000}},	//   _zbig, _navī, --, --, 
   {{0xe9d000f1,0x00000000,0x00000000,0x00000000}},	//   _دغي_, --, --, --, 
   {{0xdb1c072b,0xd4900051,0x00000000,0x00000000}},	//   rksæ, _ầm_, --, --, 
   {{0x645c2af2,0x07540375,0x7d08e24a,0x273c004d}},	//   _evri, _בסרט_, _lyfs, _ửng_, 
   {{0x0f38001f,0x26181025,0xc18401d9,0xb5f8032e}},	//   _አቀራረ, _बीपी_, ندى۪, _sváf, 
   {{0xb5f800e4,0xe1f00553,0x997c00e2,0x645800d7}},	//   _avág, حسن_, pāņu_, ávit, 
   {{0xfafc0023,0x0ea80d4b,0x9f44003a,0x00000000}},	//   ngës_, дкий_, nimè_, --, 
   {{0xa3d400d1,0xdb1c002f,0x00000000,0x00000000}},	//   _сотч, nksä, --, --, 
   {{0x7d08002d,0xe53003be,0x6b84026c,0x6aa59e14}},	//   _byfs, _müğə, _sbig, _rrif, 
   {{0xcb699e15,0xf0000116,0xe5300213,0xfafc0240}},	//   мане_, _йүки, _lüğə, zgët_, 
   {{0x6aa59e16,0x5f759e17,0x26180037,0x00000000}},	//   _prif, _ماهر, _बीनी_, --, 
   {{0x21b80014,0xb5f80306,0x6448025c,0xdb1c002f}},	//   _تھۆک_, _kvád, _ħdim, chsü, 
   {{0x19b80108,0x00000000,0x00000000,0x00000000}},	//   нусь_, --, --, --, 
   {{0x2e440241,0x6fc40055,0x6b84e248,0x00000000}},	//   _fífò_, _añci, _tbig, --, 
   {{0x6aa59e18,0x6b840526,0xb5f80124,0xbb1800c7}},	//   _trif, _ubig, _yvág, teît, 
   {{0x3ab001e0,0x645c0327,0x6aa59e19,0x59b40137}},	// [2c2c0] _кәрт, _svri, _urif, төөс, 
   {{0x08c426aa,0xfafc0023,0x9f440240,0xebe40150}},	//   _абон, rgët_, timë_, _шоқп, 
   {{0x55f400f7,0xdb1c01e7,0x00000000,0x00000000}},	//   учту, bhsó, --, --, 
   {{0x3c3800cd,0x6fc4002b,0x9f44036e,0xdcf81619}},	//   _jīva_, _uñch, rimë_, _savī, 
   {{0x49040372,0xdb1c5369,0x15b000cf,0xdcf80171}},	//   _سوڭق, cksä, _گەلس, _pavī, 
   {{0xe2154661,0x3c380171,0x00000000,0x00000000}},	//   ымлы, _līva_, --, --, 
   {{0x645c1711,0xdd940220,0x9f440066,0xb5f80162}},	//   _uvri, қаны, limé_, _svág, 
   {{0x6fe4020c,0x82a40124,0x9988012d,0x3c3800b8}},	//   _rècè, _иабж, _staż_, _nīva_, 
   {{0x422400ee,0x9f440129,0xfd440166,0x42500345}},	//   _адав, nimé_, кэнн, _ئۆتر, 
   {{0x71a01d9d,0xf1840131,0x3da59e1a,0x3c380171}},	//   _кауз, _ийул_, триб, _aīva_, 
   {{0x7f8400c6,0xdb2001e1,0x00340153,0x00000000}},	//   _للان, _ńtàj, _рэзю, --, 
   {{0x395071ed,0x7d080af9,0x9f44003a,0xb5f800d0}},	//   _sexs_, _vyfs, ximè_, _zvád, 
   {{0x20059e1b,0x3f841bce,0x19c59e1c,0x3c380171}},	//   momi_, _ibou_, гәнг, _dīva_, 
   {{0x20059e1d,0x3ea40548,0x00000000,0x00000000}},	//   lomi_, _irot_, --, --, 
   {{0xf80450dd,0x681c007f,0x3ea40306,0x6c90007b}},	//   вчан, _pōdp, _hrot_, _نشيط, 
   {{0x1cdc03bd,0x26187f1a,0x77906a0e,0x309805d0}},	//   _ལྟག_, _बीबी_, جیحا, ושלמ, 
   {{0x9714c029,0x3d059e1e,0x9f4402e2,0xfafc0200}},	// [2c2d0] умац, _सुते_, rimè_, rgës_, 
   {{0x2004019b,0xdb1c007c,0x00000000,0x00000000}},	//   homi_, rksä, --, --, 
   {{0x20059e1f,0x65959e20,0x3f84012c,0xdb1c007c}},	//   komi_, раху, _obou_, sksä, 
   {{0x600c0086,0x3ea40098,0x20059e21,0xb5f80118}},	//   bûmi, _orot_, jomi_, _svád, 
   {{0x20059e22,0xa6f4010a,0x645934a5,0x00000000}},	//   domi_, _взяш, ávir, --, 
   {{0x3f859e23,0xe2159e24,0x6f0801bf,0xdb1c007c}},	//   _abou_, амчы, _rygc, ckså, 
   {{0x20040270,0x91040c75,0xd009394d,0x94d40354}},	//   fomi_, ыпке, неке_, _совц, 
   {{0x3ea59e25,0x20059e26,0xae082e05,0x3e380023}},	//   _brot_, gomi_, _सीजन_, _ከነካይ, 
   {{0x51f81e18,0x3ea43132,0xe3b00cd6,0x4f09943d}},	//   _знаю_, _crot_, _ظرف_, энин_, 
   {{0xb5f80232,0x2bcc11bc,0x3ea59e27,0x3c380171}},	//   _uvád, ास्थ, _drot_, _sīva_, 
   {{0x20059e28,0x0c242c1d,0x3ea59e29,0xc1980a1e}},	//   bomi_, лмон, _erot_, _רשעי, 
   {{0x20059e2a,0x2a640296,0x3ea59e2b,0x8e7428e5}},	//   comi_, ámbo_, _frot_, _букч, 
   {{0xedd4b392,0x3ea59e2c,0x4e78008f,0xcb6801d5}},	//   _илдә_, _grot_, _נאַצ, ومگه_, 
   {{0x5f7400db,0x28848abc,0x00000000,0x00000000}},	//   _ماۇر, ақов, --, --, 
   {{0x2d859e2d,0xdc980cab,0x3c38002b,0xcba48726}},	//   _ibne_, _атыш_, _tīva_, _байй, 
   {{0xc7940588,0x9f4407ea,0x00000000,0x00000000}},	//   ыргы, timé_, --, --, 
   {{0x36640798,0x38c800e5,0x00000000,0x00000000}},	// [2c2e0] лато_, واہی_, --, --, 
   {{0x2bcc2983,0x2004105c,0x9f4407ea,0x86099e2e}},	//   ासका, zomi_, rimé_, رقاق_, 
   {{0x20059e2f,0x9f44020c,0x03a4a2b6,0xe42401e2}},	//   yomi_, simé_, лижо, لکري, 
   {{0x2ca59e30,0x7c3d9e31,0xdb1c007c,0x00000000}},	//   _mrnd_, _épre, skså, --, 
   {{0x41e40953,0x2004036b,0x7980002d,0x2a600064}},	//   ліка, vomi_, _űnwi, _jvib_, 
   {{0x20059e32,0x00000000,0x00000000,0x00000000}},	//   womi_, --, --, --, 
   {{0x20059e33,0x81d42158,0x408401c6,0x94780063}},	//   tomi_, াচল_, уулб, _исту_, 
   {{0x2d840548,0x3ea59e34,0x5ea44630,0xd9e000dc}},	//   _abne_, _prot_, لمعل, _नष्ट, 
   {{0x20059e35,0x661c0280,0xfe2416a8,0x9f9800c7}},	//   romi_, _khrk, льон, _héë_, 
   {{0x20059e36,0x5d5414a4,0x3ea59e37,0xdd90004b}},	//   somi_, шкот, _vrot_, څوک_, 
   {{0x3ea4002d,0xdd90dc96,0x00000000,0x00000000}},	//   _wrot_, موک_, --, --, 
   {{0x3ea59e38,0x77a80724,0x2004fef0,0xfbac033f}},	//   _trot_, _möxä, qomi_, टाइम, 
   {{0xedd000b2,0xcbb402dd,0x408401ee,0x00000000}},	//   _ڏيند, рғыш_, _шуҡб, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x37a99e39,0x6ca00eed,0xf65c02d2,0xed540677}},	//   нтан_, _грыж, _svæ_, _גבור_, 
   {{0x600c0086,0x224401a9,0x69c000d8,0x7cd401d3}},	//   rûmw, _otmk_, êmer, _لوڈز_, 
   {{0xb69800d2,0xf56969e7,0x00000000,0x00000000}},	// [2c2f0] _nyât, ешек_, --, --, 
   {{0x15140953,0xe1a400c5,0x3c3800cd,0x83d40150}},	//   адзя, _गोलघ, _jīvo_, _ﯙﺍﺭﻳ, 
   {{0x420c00dc,0x00000000,0x00000000,0x00000000}},	//   ितैः_, --, --, --, 
   {{0x7bcc021a,0xdb0c4de4,0xe44800d1,0x00000000}},	//   nkcu, _anaé, النى_, --, 
   {{0xfcf40023,0x3264010a,0x2bc8000d,0x00000000}},	//   ፈልጠ_, утев, _लवसा, --, 
   {{0x6a6c008c,0x62240075,0x90c40212,0x2614000d}},	//   _höfð, مىنل, ибле, näol_, 
   {{0xa5f8014b,0x00000000,0x00000000,0x00000000}},	//   _серу_, --, --, --, 
   {{0x0e659e3a,0xca3c0150,0x00000000,0x00000000}},	//   акин, _ﺟﯘﺕ_, --, --, 
   {{0x8db40845,0xe2f80220,0x9f980241,0x00000000}},	//   асні, _беті_, _méè_, --, 
   {{0xfcf402d3,0x9f9801e1,0xde88007b,0x00000000}},	//   ፈልጡ_, _léè_, اضيه_, --, 
   {{0x88d40156,0x00000000,0x00000000,0x00000000}},	//   ུནབར, --, --, --, 
   {{0xa0c400aa,0x8b255e3c,0x32059e3b,0xe7d000cc}},	//   _ديمو, идне, lony_, _িদ্য, 
   {{0x61f4032e,0x00000000,0x00000000,0x00000000}},	//   _áflí, --, --, --, 
   {{0x32040851,0x6e38379d,0xb7b800e4,0x2ca4002f}},	//   nony_, mqub, _oiãs, _trnd_, 
   {{0x7d7475a6,0x883405f5,0x9f980ca8,0xfce00c69}},	//   _ضمير_, рэгц, _béè_, _мошо, 
   {{0x32059e3c,0x7bcc0072,0x661c0009,0x06dc00cc}},	//   hony_, ckcu, _shrk, _ভুগি, 
   {{0x32059e3d,0x1b0c03f4,0x6e380173,0xca7401e0}},	// [2c300] kony_, সেবে_, nqub, _туйы, 
   {{0x3204012d,0x88c80117,0x98b0012d,0xa13c00de}},	//   jony_, _алов_, wczą_, _kaķe, 
   {{0xf55401d5,0x2244002f,0x00000000,0x00000000}},	//   شلنب_, _stmk_, --, --, 
   {{0x6e38021a,0x973401c0,0x07a40063,0xa13c00de}},	//   kqub, _гэрч, _тамн, _maķe, 
   {{0x32059e3e,0x8d2c0023,0x98b0033f,0xb6a08726}},	//   fony_, _ሰዓብቱ, rczą_, _диял, 
   {{0xfcf4044e,0x32059e3f,0x00000000,0x00000000}},	//   ፈልጥ_, gony_, --, --, 
   {{0xd1381cd0,0x9f980248,0x00000000,0x00000000}},	//   ухі_, _yéè_, --, --, 
   {{0x6d440882,0x9f999e40,0xdb1c03b2,0x00000000}},	//   ñjan, _kéé_, rksú, --, 
   {{0x3204325f,0x6e381cdf,0x63a00393,0x9f9985b7}},	//   bony_, gqub, _iamn, _jéé_, 
   {{0x63a19e41,0x6280014f,0x32059e42,0x9f999e43}},	//   _hamn, _iqmo, cony_, _méé_, 
   {{0x63a0488c,0x228002e2,0x00000000,0x00000000}},	//   _kamn, lòk_, --, --, 
   {{0x63a19e44,0x261807f7,0x9e840133,0xbe88004e}},	//   _jamn, _बीसी_, _هاتۆ, _аске_, 
   {{0x63a19e45,0x9f9801c7,0xfeb800db,0x7bcc062c}},	//   _mamn, _néé_, _جاات_, rkcu, 
   {{0x63a00477,0x7e6000b8,0x9d180304,0xeee80037}},	//   _lamn, _ivop, _йолт_, _जइतऽ_, 
   {{0xa8a4fffc,0x29059e46,0x2280007f,0x63a00356}},	//   ортк, şman_, hòk_, _oamn, 
   {{0x63a19e47,0x32041785,0x67d41c13,0x9f9801e1}},	//   _namn, zony_, оосу, _béé_, 
   {{0x7dd40356,0x6a6c02d2,0x00000000,0x00000000}},	// [2c310] _gâsc, _vöfð, --, --, 
   {{0x32040ecf,0x99981b72,0x2280033b,0x35280145}},	//   xony_, _скот_, dòk_, نساپ_, 
   {{0x29d4025a,0x63a00028,0xfcf4044e,0x32040170}},	//   _käan_, _bamn, ፈልጦ_, vony_, 
   {{0x1cdc0156,0x61e8014b,0x63a19e48,0xb3640801}},	//   _ལྟབ_, _amdl, _camn, ръжк, 
   {{0x7cc80cc1,0x32041311,0x63a15f5b,0x2618033f}},	//   lərd, tony_, _damn, _बीवी_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3204a5fc,0x6ff00311,0x63a0cbaf,0x7e60005b}},	//   rony_, lăci, _famn, _avop, 
   {{0x32059e49,0x61e84a7d,0x63a19e4a,0x2280007f}},	//   sony_, _emdl, _gamn, bòk_, 
   {{0xd2514d5a,0x32042f5b,0x7cc800ac,0x8e092416}},	//   _رنا_, pony_, hərd, лнив_, 
   {{0x7e601a48,0x3b8005f5,0x9f440548,0xdb0c37a7}},	//   _dvop, үлэг, gimâ_, _anaï, 
   {{0x1cdc0003,0x62040014,0x63a19e4b,0x7e6000cd}},	//   _ལྟད_, _بولٕ, _yamn, _evop, 
   {{0x63a00694,0x7cc80213,0x929c012d,0xcfe816cc}},	//   _xamn, dərd, _wyłu, _حفصه_, 
   {{0x81c81c82,0x7cd401d3,0x00000000,0x00000000}},	//   _লগত_, لویز_, --, --, 
   {{0x8ac405c2,0x07a40588,0x7cc800ac,0x6ff00311}},	//   иққа_, әаан, fərd, dăci, 
   {{0xa524025c,0x7e60004c,0x7d740150,0x61e401ab}},	//   _འཛེག_, _zvop, _امىر_, èili, 
   {{0x7c3c00d8,0xc0200055,0x228002bd,0x97b41f99}},	//   _épra, _kṛṣi_, yòk_, осуш, 
   {{0x63a19e4c,0x05659e4d,0x6ff00276,0xa5e800fb}},	// [2c320] _ramn, йван, găci, алаҡ_, 
   {{0x63a19e4e,0x7cc803be,0x6280022e,0x2280007f}},	//   _samn, bərd, _rqmo, vòk_, 
   {{0x63a19e4f,0xc4859e50,0x69dc1552,0x9f980036}},	//   _pamn, слек, mhre, _wéé_, 
   {{0x63a19e51,0x53e402bf,0xd37802bf,0x03240334}},	//   _qamn, оціа, ичі_, бден, 
   {{0x63a19e52,0xc1e8d3a6,0x6d413b7d,0x96b80137}},	//   _vamn, льке_, _ofna, _куру_, 
   {{0x63a0e439,0x9f4519f3,0xb5f803b2,0x228002e2}},	//   _wamn, rimí_, _tváa, ròk_, 
   {{0x63a19e53,0xf9900375,0x7e6000b8,0x00000000}},	//   _tamn, פרה_, _svop, --, 
   {{0x91ac06c8,0x6d419e54,0x63a0014b,0x22800100}},	//   _auē_, _afna, _uamn, pòk_, 
   {{0x44259e55,0x7cc803be,0x80a453e2,0x69dd9e56}},	//   mmo_, zərd, _گمان, khre, 
   {{0x61e80912,0x6d40005a,0x7cc80213,0x00000000}},	//   _umdl, _cfna, yərd, --, 
   {{0x69dcd52f,0x9d199e57,0x44259e58,0x5bb80801}},	//   dhre, ронт_, omo_, алня_, 
   {{0x44259e59,0x6d40008c,0x66f80073,0x69dc002f}},	//   nmo_, _efna, ंपाक_, ehre, 
   {{0x44240084,0x69dc007b,0x61f8017a,0x997c00de}},	//   imo_, fhre, onvl, rāžu_, 
   {{0x44240842,0x69dd9e5a,0xb5f800e4,0x7cc800ac}},	//   hmo_, ghre, _aván, tərd, 
   {{0x1cdc0156,0x44259e5b,0x81c80183,0xb7648083}},	//   _ལྟཝ_, kmo_, _লগা_, йтай, 
   {{0x44259e5c,0x6ff00311,0x69dc0076,0x7cc80213}},	//   jmo_, tăci, ahre, rərd, 
   {{0x44259e5d,0x69dd9e5e,0x0b440014,0xa524025c}},	// [2c330] dmo_, bhre, _بر٘ێ, _འཛུག_, 
   {{0x69dd9e5f,0x44259e60,0x6ff00311,0x61f801f5}},	//   chre, emo_, răci, jnvl, 
   {{0x7cc803e3,0x00000000,0x00000000,0x00000000}},	//   lərb, --, --, --, 
   {{0xb9e007db,0x44259e61,0xdb0c030a,0x61f8017a}},	//   _ከም_, gmo_, _hoañ, envl, 
   {{0xc76400cf,0x7cc80213,0x66c8030d,0xa5642374}},	//   _باپى, nərb, _лург_, زدەن, 
   {{0x44259e62,0x737400c7,0xb5f8013a,0x9f9400c7}},	//   amo_, рыҧх, _zván, ҧшыш, 
   {{0xdb0ceb5e,0x6d459e63,0x44240978,0xeee80037}},	//   _moañ, ñjam, bmo_, _जइहऽ_, 
   {{0x44240014,0x69dd9e64,0x7cc803b9,0x00000000}},	//   cmo_, zhre, kərb, --, 
   {{0x72a002dd,0x69dc0200,0x98b00210,0x00000000}},	//   _ءەتن, yhre, rczę_, --, 
   {{0x270807ae,0xcc880108,0x69dc036e,0x00000000}},	//   ởng_, абое_, xhre, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa3cc1098,0x7cc803e3,0x00000000,0x00000000}},	//   शॉप_, fərb, --, --, 
   {{0x69dd9e65,0x9f9801e1,0x00000000,0x00000000}},	//   thre, _méì_, --, --, 
   {{0x442402d5,0xdb0c0077,0x29040790,0xa13c00ef}},	//   zmo_, _coañ, şmam_, _kaķa, 
   {{0x44259e66,0xfb8c0075,0x4758005b,0x00000000}},	//   ymo_, _ﻛﯚﺭﯛ, ирая_, --, 
   {{0xdbe0145e,0x69dce324,0x4424058a,0x00000000}},	//   _sïön, shre, xmo_, --, 
   {{0x9f459e67,0x44240978,0x85e800d4,0xbb38010f}},	// [2c340] nimá_, vmo_, адав_, _דעפי, 
   {{0x683800df,0xdb0c0489,0x056402d5,0xd8d40327}},	//   _aŭde, _goañ, івен, ུགཡི, 
   {{0xb5f80022,0x24940092,0xea1800ec,0x0444013d}},	//   _ivál, _ማውራት_, _پرکڻ_, цеен, 
   {{0x44259e68,0xb5f803b2,0xe2540023,0x7cc803b9}},	//   umo_, _hvál, _ዝሰርሓ, lərc, 
   {{0x325000d4,0x00000000,0x00000000,0x00000000}},	//   двір, --, --, --, 
   {{0x7d04006d,0x00000000,0x00000000,0x00000000}},	//   ększ, --, --, --, 
   {{0x30a011db,0x9f444e9e,0x61f801f5,0xa5240327}},	//   дрыв, timà_, rnvl, _འཛིག_, 
   {{0x44259e69,0xb0245734,0xbfa8199d,0x7cc803e3}},	//   qmo_, يكوم_, ртке_, hərc, 
   {{0xb5f81ab0,0x9f459e6a,0x826400ec,0x4308009f}},	//   _ovál, gimá_, _ذهان, _ئيءَ_, 
   {{0x5c74781e,0x69c82e1b,0x7c8413d6,0xa2e40454}},	//   плот, ödel, оуме, _доғд, 
   {{0xdb0c0022,0x8ff40014,0x9d14005b,0xdcb00372}},	//   _roañ, _کٲنچ, ядоч, رىح_, 
   {{0xb0300058,0x6ff00311,0xd7a800ab,0x11d40150}},	//   _قىلغ, făcu, _चोंच, _وتەد, 
   {{0xfa24003d,0x64499e6b,0x79a40108,0x00000000}},	//   _རྫུན_, _édif, орве, --, 
   {{0x7c3d9e6c,0x3c380171,0x00000000,0x00000000}},	//   _épro, _līvi_, --, --, 
   {{0x068402d3,0xa9340e1d,0x195802dd,0xdc180171}},	//   _ይርከቡ_, дерш, _қаны_, _jāīs, 
   {{0x98483088,0x00000000,0x00000000,0x00000000}},	//   ияға_, --, --, --, 
   {{0x7c740092,0x88801bf4,0x00000000,0x00000000}},	// [2c350] _በተባለ_, ویین, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd3700597,0x00000000,0x00000000,0x00000000}},	//   فها_, --, --, --, 
   {{0xf36402bf,0xfbdc017a,0x9734cdd6,0x00000000}},	//   ітен, nhê_, _رکرا, --, 
   {{0x9f44011f,0x00000000,0x00000000,0x00000000}},	//   ximá_, --, --, --, 
   {{0xe570106b,0x463800df,0x00000000,0x00000000}},	//   _لطف_, _לעשע, --, --, 
   {{0xdd1c01f1,0x3d04000d,0xdddc0210,0x00000000}},	//   yšši, _सँगे_, żyśc, --, 
   {{0x842000f7,0x00000000,0x00000000,0x00000000}},	//   _كۉلن, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb5f80022,0x0d200145,0x0d8401c6,0xa2a80092}},	//   _ovám, нүлү, члон, _ቀልጣፋ_, 
   {{0x9f440270,0xfbdc05e4,0x290403e0,0x00000000}},	//   simá_, fhê_, ğmak_, --, 
   {{0x29041295,0xfbdc017a,0x8ba401c6,0x00000000}},	//   şmak_, ghê_, чимж, --, 
   {{0x2fdcf27a,0x5f740133,0x7f3805d0,0x00000000}},	//   mhug_, _زانر, _התנג, --, 
   {{0x2fdc0589,0xbea0415e,0xfbdc0124,0x06641870}},	//   lhug_, _чашк, ahê_, _ﺷﻪﻛﯩ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfbdc06ed,0x6fd801ad,0x00000000,0x00000000}},	//   chê_, बसिं, --, --, 
   {{0x7cc80213,0x7b8400db,0x75d001e2,0x00000000}},	// [2c360] məra, _رايە, کيلا, --, 
   {{0x80ac06ab,0x7cc800ac,0x290c0c86,0x35a00166}},	//   ंटमे, ləra, üdas_, науг, 
   {{0xfa24031c,0x00000000,0x00000000,0x00000000}},	//   _རྫིན_, --, --, --, 
   {{0xe7b400cf,0xd90c0244,0x00000000,0x00000000}},	//   _تۅرد, _ئیف_, --, --, 
   {{0x27e19e6d,0x7410034c,0x2fdc0066,0x24940092}},	//   mhin_, روها, dhug_, _ማፍራት_, 
   {{0x27e0a7ea,0xfafc00e8,0x00000000,0x00000000}},	//   lhin_, ggëy_, --, --, 
   {{0x7cc806be,0x00000000,0x00000000,0x00000000}},	//   kəra, --, --, --, 
   {{0xdfd00491,0x27e19e6e,0xb4f800d9,0x5f940353}},	//   ئية_, nhin_, _הפלי, фиит, 
   {{0x27e00664,0x26c00077,0x00000000,0x00000000}},	//   ihin_, nxio_, --, --, 
   {{0xf650025d,0x37c403d4,0x27e0000d,0x97440092}},	//   עצת_, ৰোপৰ, hhin_, ያስደስ, 
   {{0x6e2001ab,0x3d04072e,0x4054221c,0x90e400f7}},	//   _dhnb, _सुखे_, _رئاس, _ۉسۅن, 
   {{0xafe055cc,0xcfa802f2,0x27e0031c,0xa13c00ef}},	//   _похл, _وانم_, jhin_, _kaķo, 
   {{0xdcb01a59,0x27e19e6f,0xfbdc017a,0x9f44003a}},	//   رىڭ_, dhin_, rhê_, timæ_, 
   {{0xdedc044e,0x00000000,0x00000000,0x00000000}},	//   _ሕልና_, --, --, --, 
   {{0x27e00730,0x3c3800e2,0x7cc803b9,0xfbdc0208}},	//   fhin_, _būve_, bəra, phê_, 
   {{0x27e19e70,0xacf8011a,0x7cc803e3,0x6cf8011a}},	//   ghin_, _להוכ, cəra, _לפוס, 
   {{0x7bd40227,0xec140014,0x290c05d5,0xba68007b}},	// [2c370] _ŋyuw, _سوٝد, üdar_, _احبك_, 
   {{0x27e001d9,0xbb70247f,0x2fdc05c7,0x59d000bc}},	//   ahin_, _تۇڭع, zhug_, _सकिर, 
   {{0x27e09e4d,0x26c406af,0x0484013d,0x00000000}},	//   bhin_, _àmon_, мәти_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x59d0197c,0x7dd40356,0xa84800e5,0x6a1415b4}},	//   _सकार, _pâsl, _ولیم_, _زبیر, 
   {{0x9f440139,0x00000000,0x00000000,0x00000000}},	//   himä_, --, --, --, 
   {{0x4124013e,0x7dd40356,0xe164007b,0x10a401a9}},	//   мошо_, _vâsl, ردوي, фийн, 
   {{0xd2580100,0xe5340212,0x00000000,0x00000000}},	//   _twņ_, _чесь, --, --, 
   {{0xc91810b7,0xb8cc003d,0x8d759e71,0x5214034b}},	//   _धर्म_, _ནན_, وادا, _ждат, 
   {{0x27e11e8a,0xfe6c0517,0x2fdc009f,0xb5f801d3}},	//   zhin_, شگه_, shug_, _sváj, 
   {{0xa3b800dd,0x2fdc01bf,0x27e0b836,0x00000000}},	//   _ظاہر_, phug_, yhin_, --, 
   {{0x2a64006a,0x27e00240,0xa0a40209,0x00000000}},	//   âmbo_, xhin_, _яшул, --, 
   {{0xc0f002d3,0x291c00d7,0xef1c000d,0x00000000}},	//   ሃደር_, _šva_, üüd_, --, 
   {{0x6838008f,0x00000000,0x00000000,0x00000000}},	//   _aŭda, --, --, --, 
   {{0x27e19e72,0xbe1000cf,0x7cc803b9,0x00000000}},	//   thin_, _جووع, lərn, --, 
   {{0x61440248,0x26c0005a,0x27e19e73,0xf1c0025c}},	//   _kìló, txio_, uhin_, leġġ_, 
   {{0x27e19e74,0x3b800166,0x3c3800ef,0xc9540108}},	// [2c380] rhin_, _рлыг, _dīvu_, _отны, 
   {{0x27e19e75,0x6aa41253,0xfcf4001f,0x26c00077}},	//   shin_, _isif, ፈልጉ_, rxio_, 
   {{0x291c035b,0x00000000,0x00000000,0x00000000}},	//   _áva_, --, --, --, 
   {{0xe6a80118,0xd800030d,0x00000000,0x00000000}},	//   _hříš, _йăх_, --, --, 
   {{0x42080228,0xfbd00a7c,0xb3505074,0x00000000}},	//   ондо_, כתא_, ткіш, --, 
   {{0x6aa401c8,0x6b841713,0x00000000,0x00000000}},	//   _msif, _lcig, --, --, 
   {{0x6b8438bb,0x00000000,0x00000000,0x00000000}},	//   _ocig, --, --, --, 
   {{0x6aa4b0ff,0x645d9e76,0x3e699e77,0x9f44007c}},	//   _osif, _iwri, ошон_, kimå_, 
   {{0x645c0142,0xe6a80118,0x00000000,0x00000000}},	//   _hwri, _oříš, --, --, 
   {{0x6b840077,0xb6b80375,0xb22064cd,0x3f80012d}},	//   _acig, קציי, _амул, żku_, 
   {{0xff400092,0x9f6401d3,0xdd90032f,0x9cb445cc}},	//   _ከጀርመ, ótól_, نوک_, رمحت, 
   {{0x645c0042,0x7cc803e3,0x506400ae,0x00000000}},	//   _mwri, bərn, _أطلق, --, 
   {{0x6b8400a3,0xe6a80118,0x2614000d,0x9f459e78}},	//   _dcig, _bříš, näos_, rimä_, 
   {{0x2014006d,0xfcf40020,0x6db001ec,0x00000000}},	//   ścią_, ፈልግ_, _айшу, --, 
   {{0x6aa59e79,0x37c80120,0x00000000,0x00000000}},	//   _esif, оѓам_, --, --, 
   {{0x6b8401e7,0xf770a6e0,0x00000000,0x00000000}},	//   _gcig, ضار_, --, --, 
   {{0x645d9e7a,0x7bdcfff3,0x00000000,0x00000000}},	// [2c390] _awri, _ilqu, --, --, 
   {{0x645c00a9,0x39440209,0xe3b19e7b,0xdb0c0205}},	//   _bwri, _üns_, یرن_, _anaç, 
   {{0x645c0368,0x00000000,0x00000000,0x00000000}},	//   _cwri, --, --, --, 
   {{0xdedc1e38,0x645c03cb,0x00000000,0x00000000}},	//   _ሕግን_, _dwri, --, --, 
   {{0x645d9e7c,0x7cc806be,0xefcc0240,0x00000000}},	//   _ewri, kəro, ብታዊ_, --, 
   {{0x645c0368,0x00000000,0x00000000,0x00000000}},	//   _fwri, --, --, --, 
   {{0x7bdc02d1,0x645d9e7d,0x261802ab,0x2bd007f7}},	//   _olqu, _gwri, _बीटी_, _हकला, 
   {{0xb3b80150,0xe4d801e2,0x00000000,0x00000000}},	//   _باسء_, _کوېت_, --, --, 
   {{0xcdf40948,0xe2f80220,0x776d9e7e,0x7cc800ac}},	//   ечны, _жеті_, _mdcx, fəro, 
   {{0x7bdd9e7f,0x644814ac,0x6b840332,0x7cc80213}},	//   _alqu, _édic, _scig, gəro, 
   {{0x30a59e80,0xa2700023,0xf1c0031c,0x8fd000fb}},	//   _юрав, _ኣይኹን_, reġġ_, _бәпә, 
   {{0x7cc800ac,0xb7b800b8,0x00000000,0x00000000}},	//   mərl, _bhãm, --, --, 
   {{0x7cc800ac,0x764c00ca,0xe6a8012c,0xce480139}},	//   lərl, _ntcy, _příš, _эзле_, 
   {{0x7bdc5a8b,0xb7b8002b,0x19b80212,0x2ed82c2e}},	//   _elqu, _dhãm, мусь_, यनीत, 
   {{0x26f8000d,0x7cc803e3,0x00000000,0x00000000}},	//   ंप्र_, nərl, --, --, 
   {{0x6b840311,0x26180b7d,0x6aa59e81,0x00000000}},	//   _ucig, _बीजी_, _tsif, --, 
   {{0x6aa51022,0x7cc803be,0x46e8576f,0x06e86565}},	// [2c3a0] _usif, hərl, чдан_, чмак_, 
   {{0x7cc80213,0x00000000,0x00000000,0x00000000}},	//   kərl, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd3a402bf,0x7cc80213,0xf8b005d0,0x00000000}},	//   кріп, dərl, _עשר_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x645c0368,0x7cc800ac,0x278860a1,0xa1944eca}},	//   _twri, fərl, _эрүү_, такч, 
   {{0x7cc800ac,0xc1a402dd,0x03940006,0x00000000}},	//   gərl, дыққ, _прая, --, 
   {{0x0574516c,0x7c3cb4a2,0xbf640133,0x3ec40798}},	//   _تاڭد, _épri, ردبو, есоб, 
   {{0x7dd4019f,0x00000000,0x00000000,0x00000000}},	//   _yâsh, --, --, --, 
   {{0x7cc811a9,0x00000000,0x00000000,0x00000000}},	//   bərl, --, --, --, 
   {{0x2fd400aa,0x7fd402bf,0xdb1c0037,0x7cc803b9}},	//   _ګوند_, _піді, nksö, cərl, 
   {{0x7bdc0153,0x00000000,0x00000000,0x00000000}},	//   _įpus, --, --, --, 
   {{0x683800df,0x7cc806be,0x00000000,0x00000000}},	//   _aŭdo, pəro, --, --, 
   {{0x3ea402f6,0x7cc80213,0x24940092,0x00000000}},	//   _isot_, lərm, _ማግስት_, --, 
   {{0xbc480166,0x00000000,0x00000000,0x00000000}},	//   _эчле_, --, --, --, 
   {{0x7bdc0789,0xdbd80194,0x693422cb,0x00000000}},	//   _ulqu, _sææl, унсу, --, 
   {{0x2498556c,0x644002b5,0x00000000,0x00000000}},	// [2c3b0] _aprm_, _ōmip, --, --, 
   {{0xaa6406bb,0x7cc803be,0xdedc01f3,0x1db000dc}},	//   _стък, yərl, _ሕግና_, जयित, 
   {{0xf1bc07ae,0x249800b5,0xb5f800c7,0xaab851ae}},	//   _đá_, _cprm_, _ováv, _قدیر_, 
   {{0xe5087224,0x2bc400dc,0x7cc80213,0xd2f802e8}},	//   رينو_, षाया, vərl, меец_, 
   {{0xc7d400d9,0x7cc803b9,0x00000000,0x00000000}},	//   _סושי_, dərm, --, --, 
   {{0xb5f800c7,0x3dcc009a,0x43440032,0x7dd40356}},	//   _aváv, _nofw_, нфәғ, _fâsi, 
   {{0xdb1c007c,0x2bc400cd,0x00000000,0x00000000}},	//   cksö, षामा, --, --, 
   {{0x91800131,0x7cc80213,0x00000000,0x00000000}},	//   _چۇشۇ, rərl, --, --, 
   {{0xe61002f2,0xd23407a5,0x00000000,0x00000000}},	//   _خشێ_, _анаъ, --, --, 
   {{0x3f84054e,0x8c480d1d,0x20c40166,0x7cc803b9}},	//   _ecou_, мпов_, тсәг, pərl, 
   {{0x3ea400da,0x2d880034,0x31659e82,0x7bdc00c0}},	//   _esot_, ęce_, manz_, _įpur, 
   {{0x31659e83,0xca740209,0x2d880118,0x7cc803b9}},	//   lanz_, кугы, řce_, cərm, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x31659e84,0x2fcd9e85,0xe7d40014,0xc27800d9}},	//   nanz_, _hogg_, گمرگ, ורשי, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2d840076,0x316401c7,0xfafc0036,0x2fcc007c}},	//   _hcne_, hanz_, maën_, _jogg_, 
   {{0x316404c4,0x36659e86,0x8ca8000b,0x24982a1f}},	// [2c3c0] kanz_, като_, टिको, _sprm_, 
   {{0x7a7825f9,0x2fcc1a82,0x31640165,0x2ca40208}},	//   _קריס, _logg_, janz_, _ksnd_, 
   {{0xc4841945,0x35a001c0,0x31659e87,0xbf1c00bc}},	//   тлек, рахг, danz_, _पर्न_, 
   {{0x69dd9e88,0x7c3d203b,0x5ee40882,0x64ac01e1}},	//   lkre, _èpre, टनम्_, _s̟is, 
   {{0x69dc08a4,0x31659e89,0xa294187f,0x02bc01f9}},	//   okre, fanz_, уалі, ्हेन, 
   {{0x2b400048,0x31659e8a,0xa13c00e2,0xb5f803b2}},	//   _lgic_, ganz_, _kaķi, _sváv, 
   {{0x515400f7,0x2ca40208,0x622400d1,0x5f94009d}},	//   утчу, _nsnd_, نىچل, гийт, 
   {{0x31640d16,0x2fcc01e7,0x2d859e8b,0x2e280fac}},	//   aanz_, _cogg_, _acne_, nøff_, 
   {{0x316400ca,0x31200daf,0x52740b87,0x2fcc0f85}},	//   banz_, лдәг, _буху, _dogg_, 
   {{0x2d840204,0xf77c6648,0x2b419e8c,0x31640036}},	//   _ccne_, _ilçe_, _agic_, canz_, 
   {{0x69dd9e8d,0x6ca0023a,0x1bd4d822,0x06d4015b}},	//   dkre, аряж, гоня, _সেমি, 
   {{0x69dc0373,0x106800c6,0x2b400042,0x20001bce}},	//   ekre, _أحلى_, _cgic_, _ñii_, 
   {{0x2b400042,0x929c033f,0x69dc417b,0x60d80419}},	//   _dgic_, _były, fkre, lyvm, 
   {{0x69dc0066,0xfbd00050,0x2fcc05d5,0x98c401c6}},	//   gkre, اتھ_, _zogg_, гөмж, 
   {{0x7c84f280,0x2dc8005e,0x6cc00014,0xe91800d4}},	//   _руле, _تانۋ_, _نٲوٕ, ворі_, 
   {{0x2b400048,0x69dc06a3,0x31641529,0x2bc40b7c}},	//   _ggic_, akre, zanz_, षाणा, 
   {{0x61f8fa6f,0x02bc033f,0x2a600042,0x66e406ed}},	// [2c3d0] kivl, ्होन, _gwib_, аоѓа, 
   {{0x23640399,0xe694c63f,0x61f80477,0x69c8000d}},	//   _aemj_, рифы, jivl, ödet, 
   {{0xdb1c007d,0x31659e8e,0x2904054e,0x7cc80213}},	//   rksõ, vanz_, şmar_, dərk, 
   {{0x61f804cc,0x24599e8f,0x31642ad7,0x00000000}},	//   eivl, таць_, wanz_, --, 
   {{0x31659e90,0xe3b0034c,0xaca001f2,0x00000000}},	//   tanz_, ترل_, tiịm, --, 
   {{0x2fcc011c,0x461400aa,0xb4b0008e,0xb4f00139}},	//   _sogg_, _موټر, _кигә, _күзч, 
   {{0x2ed9351b,0x31659e91,0x26100574,0xd3943c1a}},	//   यन्त, ranz_, तकरी_, _бәлә_, 
   {{0x23640369,0x316407ab,0x61f99e92,0x2ca40334}},	//   _gemj_, sanz_, aivl, _rsnd_, 
   {{0xb8cc031c,0x3164324c,0x7cc806be,0xa3d40108}},	//   _ྒར_, panz_, bərk, _тотч, 
   {{0x2b400077,0x00000000,0x00000000,0x00000000}},	//   _sgic_, --, --, --, 
   {{0x2fcc0de2,0x9054bc58,0x63a400e4,0x00000000}},	//   _togg_, _свец, õing, --, 
   {{0x69dd9e93,0x799403ac,0xb5f80306,0xfafc0036}},	//   wkre, _abxw, _kvás, raën_, 
   {{0x69dd9e94,0x78b40165,0x6d4400d7,0x00000000}},	//   tkre, _arxv, ľjab, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2e2803cd,0x7ae006be,0x00000000,0x00000000}},	//   tøff_, _ənti, --, --, 
   {{0x61f808ad,0x87f8009d,0x46a40395,0x00000000}},	//   zivl, хэгт_, лабв, --, 
   {{0x857803a6,0xbb18025a,0x23640369,0xc72431ee}},	// [2c3e0] есет_, ngîl, _remj_, удай, 
   {{0x290403be,0x61f99e95,0x9f440200,0x2c540092}},	//   şmaq_, xivl, thmë_, _የተሰጡ, 
   {{0x61f99e96,0x00000000,0x00000000,0x00000000}},	//   vivl, --, --, --, 
   {{0xb5f8012c,0xa4f40490,0x61f8016d,0x00000000}},	//   _svát, _आधीच_, wivl, --, 
   {{0x9f44044e,0x61f99e97,0x00000000,0x00000000}},	//   shmë_, tivl, --, --, 
   {{0x7cc803b9,0x6234081b,0x00000000,0x00000000}},	//   bərh, шелу, --, --, 
   {{0x61f99e98,0x7cc80213,0x3618011a,0x00000000}},	//   rivl, rərk, _נולד, --, 
   {{0x3ec80063,0xdb1c007c,0x63a400e4,0x00000000}},	//   ећом_, ljså, õind, --, 
   {{0x683801e4,0x7cc800ac,0xfd8801b9,0x42080063}},	//   _aŭdk, məri, нёни_, _знао_, 
   {{0x7cc89f20,0x00000000,0x00000000,0x00000000}},	//   ləri, --, --, --, 
   {{0x7c6414ef,0x7f843b93,0x6e3001ef,0x00000000}},	//   داخل, _ملان, _řebí, --, 
   {{0x7dd4054e,0xb6300150,0xfba873f6,0x7cc803b9}},	//   _râsu, _ﯞﯨ_, хтой_, nəri, 
   {{0x7f40014b,0x7e5454d9,0x00000000,0x00000000}},	//   _igoq, _стец, --, --, 
   {{0x7cc803be,0xcee99e99,0x7dd4054e,0xf1c407f8}},	//   həri, _جرمن_, _câst, लायन, 
   {{0xb5f99e9a,0x7e600810,0x6e0001d9,0xc9e800fd}},	//   _ovár, _hwop, _دِون, тыяҗ_, 
   {{0x20059e9b,0x7e60009a,0x69c99e9c,0x3b6402e8}},	//   nnmi_, _kwop, öder, _съкв, 
   {{0x3118726b,0x7cc800ac,0xcac4010a,0xdce803e0}},	// [2c3f0] _पुनः_, dəri, _кӳре_, medı, 
   {{0xb5f800e4,0xdce803e0,0x00000000,0x00000000}},	//   _avár, ledı, --, --, 
   {{0x7cc803be,0x06d4015b,0xf5244411,0xd37000c6}},	//   fəri, _সেদি, уфан, قها_, 
   {{0xded0044e,0x7e619e9d,0x7f419e9e,0x7cc80213}},	//   ብኣና_, _owop, _ngoq, gəri, 
   {{0xd13c0020,0x98b045a5,0x7c3c00ac,0xd2340395}},	//   _ራሳቸው, mazı_, _miqr, андъ, 
   {{0x86780375,0x798405b1,0x7c3c01a9,0x00000000}},	//   _ברשו, ngjw, _liqr, --, 
   {{0x7e600241,0x7cc803be,0x2258151c,0x8fd000fb}},	//   _awop, bəri, _črke_, жәлә, 
   {{0x09d0078a,0x7cc803e3,0x00000000,0x00000000}},	//   _हव्य, cəri, --, --, 
   {{0x2bc40b6d,0xe2c800ec,0x62080162,0x00000000}},	//   षासा, _ٽولو_, íslæ, --, 
   {{0x7f419e9f,0xfafd9ea0,0x4d64206d,0xb5f80030}},	//   _egoq, raël_, шков, _zvár, 
   {{0x7e6002bd,0x705000f7,0xb5f80022,0x98b0c8d8}},	//   _ewop, _اچتا, _yvár, kazı_, 
   {{0x8d780092,0x00000000,0x00000000,0x00000000}},	//   ራሳቸው_, --, --, --, 
   {{0x16144d53,0x00000000,0x00000000,0x00000000}},	//   तकार_, --, --, --, 
   {{0x7cc800ac,0x2bc4298e,0x00000000,0x00000000}},	//   zəri, षाहा, --, --, 
   {{0x6d419ea1,0x7c3cdeb6,0x7cc800ac,0xadc0008e}},	//   _igna, _fiqr, yəri, _ваһһ, 
   {{0x290c038f,0x38a400a9,0xaee00882,0xb7e00c98}},	//   ħda_, _dŵr_, guṇa, ожск, 
  
   {{0x056422e9,0x7c3c011c,0xc56400f3,0x00000000}},	// [2c400] иван, _èpra, икак, --, 
   {{0xb5f863dc,0xa13c00e2,0x2bc41546,0x0554d70a}},	//   _svár, _zaķu, षावा, ртая, 
   {{0xb978025f,0x76600316,0x85059ea2,0x38a40368}},	//   _בניי, _čtyř, جوان, _gŵr_, 
   {{0xf4780023,0xd5b00051,0x00000000,0x00000000}},	//   _ኣግራብ_, _ức_, --, --, 
   {{0x27e19ea3,0x6d419ea4,0xf7719ea5,0x00000000}},	//   mkin_, _ogna, _باپ_, --, 
   {{0x27e19ea6,0x7e600099,0x7cc800ac,0x6d404c86}},	//   lkin_, _rwop, səri, _ngna, 
   {{0x52742097,0x683800c8,0xb5f99ea7,0x7e619ea8}},	//   _қуту, _aŭdi, _kwán, _swop, 
   {{0x27e19ea9,0x7e600699,0x6d419eaa,0x00000000}},	//   nkin_, _pwop, _agna, --, 
   {{0x27e19eab,0xb5f80085,0x64419eac,0x257c01e1}},	//   ikin_, _mwán, _iimi, _gálà_, 
   {{0x27e19ead,0xb5f800d2,0x00000000,0x00000000}},	//   hkin_, _lwán, --, --, 
   {{0x27e19eae,0xdd9402dd,0x98b01432,0xdce803e0}},	//   kkin_, _ғайы, yazı_, tedı, 
   {{0x90e469ef,0x64419eaf,0x7e60033b,0x6d419eb0}},	//   _اسكن, _jimi, _twop, _egna, 
   {{0x64419eb1,0x27e19eb2,0x7e600472,0xfbdc002d}},	//   _mimi, dkin_, _uwop, rkê_, 
   {{0x27e19eb3,0x661c05be,0xada00107,0xaa5800f3}},	//   ekin_, _nkrk, _мачл, риру_, 
   {{0x78440323,0xb7653c1b,0xf77c57bf,0x644002ce}},	//   рэгж, итай, _alça_, _oimi, 
   {{0x6440dc3a,0x27e097a8,0xb5f80022,0xf84405f5}},	//   _nimi, gkin_, _aváp, лүүд_, 
   {{0x7bcc0369,0xaee00882,0x98b03bc1,0x5574004e}},	// [2c410] mjcu, ruṇa, razı_, йгат, 
   {{0x27e19eb4,0x38a4015d,0x00000000,0x00000000}},	//   akin_, _tŵr_, --, --, 
   {{0x64419eb5,0x27e19eb6,0xb7b80055,0x141800c6}},	//   _bimi, bkin_, _bhãt, هيئة_, 
   {{0x27e01c1d,0x98a007ae,0x88b802e4,0x569401c4}},	//   ckin_, _nghĩ_, _עזרי, _ламт, 
   {{0xe2a80014,0xb7b800e4,0x47980375,0x7adc0327}},	//   لاون_, _akãg, _גירס, ྤདྲྣ, 
   {{0x95e40014,0x644002d2,0xef1c0037,0x00000000}},	//   _آسى, _eimi, üüm_, --, 
   {{0x64419eb7,0x50b40108,0xa5f80150,0xd09800ec}},	//   _fimi, сслу, _теру_, ائتا_, 
   {{0x64419eb8,0x6d400554,0x4c8401ec,0x0e640108}},	//   _gimi, _sgna, ұлов, бкин, 
   {{0xf1a400d8,0x14f800fe,0x00000000,0x00000000}},	//   _врен, _অডিঅ_, --, --, 
   {{0x27e00323,0x64414e17,0x4c859eb9,0x0eb80032}},	//   zkin_, _zimi, блов, _ҡулы_, 
   {{0xcb699eba,0xd478008f,0x2bc400bc,0xfaa00124}},	//   лане_, װאָל, षाला, ҟаро, 
   {{0x64419ebb,0x7e940b8a,0x70b001ad,0xd92c0b82}},	//   _ximi, جنیر_, ंटील, _ተስፋሁ, 
   {{0xf1d8072e,0x6d4007de,0x9ad400d4,0x3f800022}},	//   _भवान, _tgna, оюрі, ókue_, 
   {{0x6d408b14,0x27e00204,0x00000000,0x00000000}},	//   _ugna, wkin_, --, --, 
   {{0x27e0049b,0x32040108,0x00000000,0x00000000}},	//   tkin_, inny_, --, --, 
   {{0x27e19ebc,0x32059ebd,0x3d900166,0x00000000}},	//   ukin_, hnny_, _диәр, --, 
   {{0x27e19ebe,0x64419ebf,0x0608010b,0x00000000}},	// [2c420] rkin_, _rimi, гнак_, --, 
   {{0x64419ec0,0xc9a8b2f3,0x6448007f,0x00000000}},	//   _simi, _свое_, _édik, --, 
   {{0x64419ec1,0xc7a41d1c,0xdd04002b,0x00000000}},	//   _pimi, _линк, _āsīt, --, 
   {{0x64419ec2,0x683800df,0x3204033f,0x7cc803b9}},	//   _qimi, _aŭdv, enny_, mərt, 
   {{0x64419ec3,0xe1f99ec4,0xaab807f7,0x82f8009a}},	//   _vimi, аҳа_, इटिक, دراز_, 
   {{0x9f440428,0x64419ec5,0xdcf800de,0x00000000}},	//   jimò_, _wimi, _pavļ, --, 
   {{0x64419ec6,0x63b404b4,0xa11400f2,0x3490014b}},	//   _timi, _мәдх, غوبت, _наёр, 
   {{0x6440170a,0xd018012d,0x44219ec7,0x00000000}},	//   _uimi, goń_, _ók_, --, 
   {{0x88cc015b,0x3c2800e4,0x6458008f,0x00c801ec}},	//   রনিক, jùva_, ŭvid, _әлек_, 
   {{0x5c759ec8,0x9f440407,0xbdc4010b,0x821800d8}},	//   олот, timó_, сщий, _сцбт_, 
   {{0x70501547,0x25f01d15,0x90e400db,0x6440003e}},	//   _فنلا, _इतनी_, _وسمن, _ōmiy, 
   {{0xff28036b,0xbbe8036b,0xdb0c0432,0x00000000}},	//   _йўли_, اردم_, _enaý, --, 
   {{0xa3d004af,0x64480395,0x00000000,0x00000000}},	//   _वचन_, _èdif, --, --, 
   {{0x2d5434d8,0xef1400c7,0x21200118,0xdb1001e1}},	//   _лишь_, _умч_, řihu_, _àfíh, 
   {{0x7c3d4f99,0x21200198,0x06d4015b,0x9b9407d5}},	//   _èpro, ƙihu_, _সেলি, _дийц, 
   {{0xdce80010,0xf0740092,0x00000000,0x00000000}},	//   nadč, _አይቀሬ_, --, --, 
   {{0x61e802d0,0x32059ec9,0x00000000,0x00000000}},	// [2c430] _oldl, ynny_, --, --, 
   {{0xf3f4a262,0x9f440332,0xb8fc0154,0x96ac012d}},	//   әмдә_, dhmí_, _দই_, ुटबॉ, 
   {{0x683801e4,0x5454129c,0xb7b80055,0xdcf8013d}},	//   _aŭdu, цвет, _dhãr, _kavı, 
   {{0x7cc803be,0x61e8000f,0x37a800d8,0xfafc002e}},	//   lərs, _aldl, _стон_, gbëg_, 
   {{0xdcf8008e,0x00000000,0x00000000,0x00000000}},	//   _mavı, --, --, --, 
   {{0xd018033f,0xf77000ec,0x7cc803b9,0x00000000}},	//   woń_, _باھ_, nərs, --, 
   {{0xd018012d,0x6748032e,0x00000000,0x00000000}},	//   toń_, _ásjá, --, --, 
   {{0x403003b7,0x61e99eca,0x92580798,0x7cc803b9}},	//   мејс, _eldl, _ваат_, hərs, 
   {{0x4ec40212,0xd0180210,0x7cc803b9,0x00000000}},	//   ійов, roń_, kərs, --, 
   {{0x0d2015bf,0x8c94109a,0x630400cf,0x2f3c00b8}},	//   мүлү, ормі, _عولل, _rāgī_, 
   {{0xdcf80139,0xfcf40023,0x8f740816,0x7cc803e3}},	//   _bavı, ገልጾ_, _дулі, dərs, 
   {{0xeaa005c7,0xfff80108,0x00000000,0x00000000}},	//   ūṭa_, äätö_, --, --, 
   {{0xdcf8013d,0xf77c0205,0x37cc0154,0x6c0400db}},	//   _davı, _alço_, রসার, _ۉكتۅ, 
   {{0x43380677,0x00000000,0x00000000,0x00000000}},	//   יערב, --, --, --, 
   {{0x02a42e05,0x00000000,0x00000000,0x00000000}},	//   _गन्न, --, --, --, 
   {{0x13b00154,0xc76402de,0x00000000,0x00000000}},	//   ছাড়, تاسى, --, --, 
   {{0xb5f80cad,0x7cc80213,0xc574007b,0x89d40150}},	// [2c440] _iwáj, bərs, قطاع, _дінш, 
   {{0x35a00166,0x00000000,0x00000000,0x00000000}},	//   мауг, --, --, --, 
   {{0xa82423cf,0x44a59ecb,0xa244022e,0xdcf8008e}},	//   _فکرن, تماق, g訴nl, _yavı, 
   {{0x03259ecc,0x74100dc3,0xdc8c010f,0x00000000}},	//   оден, وولا, רװאָ, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3664013e,0x84582082,0x95d0030d,0x00000000}},	//   _фаро_, _врат_, _пăча_, --, 
   {{0x7cc800ac,0xc0c80276,0xb5f801e1,0x47343779}},	//   hərr, руле_, _owáj, _درگز, 
   {{0x301400c6,0x7cc803b9,0x00000000,0x00000000}},	//   يتية_, kərr, --, --, 
   {{0x44259ecd,0x31040bd6,0x3da400d8,0x00000000}},	//   mlo_, йнәп_, орнб, --, 
   {{0x44249ff4,0xbb18019f,0xdcf800fd,0x23c40241}},	//   llo_, pfîz, _savı, bèjà_, 
   {{0x44259ece,0x32540023,0x00000000,0x00000000}},	//   olo_, _ዝተሓባ, --, --, 
   {{0x44259ecf,0x7cc80213,0x2afc0037,0x00000000}},	//   nlo_, fərr, _लेहु_, --, 
   {{0xfcf402d3,0x7cc80213,0x91ac03d4,0x2d800210}},	//   ገልጸ_, tərs, চাৰ্, ójec_, 
   {{0x6ed4012c,0xadb4007b,0x00000000,0x00000000}},	//   यहरु, _وهنا_, --, --, 
   {{0xdcf870f7,0x7cc80213,0x00000000,0x00000000}},	//   _tavı, rərs, --, --, 
   {{0x44259ed0,0x00000000,0x00000000,0x00000000}},	//   jlo_, --, --, --, 
   {{0x44259ed1,0x5f1c0154,0x625c0205,0x7cc803b9}},	// [2c450] dlo_, দেরও_, nçoğ, cərr, 
   {{0xf52402e8,0xd1e001f3,0x00000000,0x00000000}},	//   офен, ናበት_, --, --, 
   {{0x44259ed2,0x9c7c0118,0x00000000,0x00000000}},	//   flo_, byče, --, --, 
   {{0xb5f800d2,0x53356e66,0xca7402f2,0x00000000}},	//   _kwák, пеет, _بڕێت_, --, 
   {{0xb2a8dcd7,0x1dbc0b7c,0x6ed80241,0xa3b805af}},	//   ртеж_, ्ञात, _ḿbè, تالر_, 
   {{0xb360069c,0xe1f99ed3,0x64580005,0x3bf400bc}},	//   ስትያን_, огі_, ívic, ँफुँ_, 
   {{0x44259ed4,0x00000000,0x00000000,0x00000000}},	//   blo_, --, --, --, 
   {{0x44254f40,0x0e6417a0,0x241801ec,0xb4d4482a}},	//   clo_, пкин, _досы_, िही_, 
   {{0x32600014,0x00000000,0x00000000,0x00000000}},	//   _کۆڈہ, --, --, --, 
   {{0x4c8524cf,0x00000000,0x00000000,0x00000000}},	//   плов, --, --, --, 
   {{0x29052828,0x40e40014,0xc5f000d9,0x7cc806be}},	//   şmaz_, _ٹٲنہ, גדי_, fərq, 
   {{0xdb0c00e8,0xc62000fe,0xc2f00eac,0x8e5401ec}},	//   _anañ, _ভূঞা_, _ছুটি_, _еткі, 
   {{0x8d6400ee,0x644800d8,0x9c7c0306,0x00000000}},	//   _евле, _édiv, vyče, --, 
   {{0x9e2400db,0x7f3800df,0x00000000,0x00000000}},	//   _قىنو, _פעסו, --, --, 
   {{0x44259ed5,0x7cc800ac,0x50bc002b,0x00000000}},	//   ylo_, sərr, ्मिष, --, 
   {{0x683801e4,0x44242db1,0x9f6403b2,0xba7400e5}},	//   _aŭdr, xlo_, ðtøl_, _کاٹت, 
   {{0x44259ed6,0x22580427,0x068509df,0xb6a091cb}},	// [2c460] vlo_, _črko_, яган, нитл, 
   {{0x442401d9,0x50bc2a67,0x4b200116,0x00000000}},	//   wlo_, ्माष, _يېگە, --, 
   {{0x44259ed7,0x490400db,0x00000000,0x00000000}},	//   tlo_, _روحق, --, --, 
   {{0x44259ed8,0x42c80eff,0xd4680597,0x00000000}},	//   ulo_, йген_, تحكم_, --, 
   {{0x44259ed9,0xf1c40574,0x68e8022c,0xb36002d3}},	//   rlo_, लांन, øddf, ስትዮን_, 
   {{0x44257973,0x6aa40851,0x7a440129,0x461400f2}},	//   slo_, _mpif, létè, _روزر, 
   {{0x30a0023a,0x997c00e2,0x00000000,0x00000000}},	//   ерыв, nāšu_, --, --, 
   {{0x645d9eda,0x6aa416b8,0x44240014,0xbfa99edb}},	//   _itri, _opif, qlo_, стке_, 
   {{0x63a00066,0x24780100,0x7410007b,0xc0c80139}},	//   _ibmn, lčm_, _أوقا, руһе_, 
   {{0x625c0790,0x36f4011a,0x00000000,0x00000000}},	//   rçoğ, פצים_, --, --, 
   {{0x6aa403c1,0xa3d02144,0x24780100,0x69d0a5b3}},	//   _apif, _वचा_, nčm_, दानी, 
   {{0x5b602440,0xf1c407f7,0x7f48007b,0x997c00ef}},	//   _ገንዘቡ, लाअन, _الإق_, dāšu_, 
   {{0x6aa4010a,0xdd94021f,0x1958010b,0x1ce00327}},	//   _cpif, _жалы, жагы_, སརང_, 
   {{0x645c1574,0xef1405f5,0xb5f800c7,0xdd90007b}},	//   _otri, _эмч_, _itág, _شوب_, 
   {{0xb7b800e4,0x645c0327,0x395c008f,0x00000000}},	//   _akãa, _ntri, ĝus_, --, 
   {{0x67d59edc,0x395c0115,0xcce40b61,0xdce80055}},	//   носу, ŝus_, _تسهي, cadā, 
   {{0x95d9312f,0x00000000,0x00000000,0x00000000}},	// [2c470] одат_, --, --, --, 
   {{0x7aec7975,0x784401c6,0x00000000,0x00000000}},	//   ıntı, _нэмж, --, --, 
   {{0x63a0020b,0xb5f801d3,0x00000000,0x00000000}},	//   _bbmn, _kváz, --, --, 
   {{0x645c007b,0xd2580171,0x13a40133,0x087400df}},	//   _dtri, _arņa_, بۆری_, _קערט_, 
   {{0x645d9edd,0x92390b85,0x2360030a,0x00000000}},	//   _etri, очку_, ñija_, --, 
   {{0xf65c003a,0xf1c59ede,0x46600137,0x69d006b1}},	//   _præf_, लाइन, _شۇمق, दायी, 
   {{0x6d4407f5,0xe1f0009f,0xd7e00210,0x903401c4}},	//   žjak, دسن_, _नवाच, мхич, 
   {{0x764d9edf,0x76459ee0,0x657c0306,0x00000000}},	//   _kucy, _hijy, _zdrh, --, 
   {{0x76440530,0xdce83a71,0x00000000,0x00000000}},	//   _kijy, vadā, --, --, 
   {{0x764d9ee1,0x645c0e38,0x9f98002e,0x776c004e}},	//   _mucy, _ytri, _déñ_, _lecx, 
   {{0x64499ee2,0x764c463d,0x7644e05d,0xb5f800e4}},	//   _édit, _lucy, _mijy, _etág, 
   {{0x273400fc,0x76459ee3,0x72000244,0x00000000}},	//   _júní_, _lijy, _توڕم, --, 
   {{0xdce8198e,0xce3401ed,0x7644062c,0x03740375}},	//   radā, _ہوچک, _oijy, ותרת_, 
   {{0x76440526,0xbea19ee4,0xa2b00490,0x997c00e2}},	//   _nijy, _рашк, _आईस्, tāšu_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x764c0b12,0x5d44008f,0x87f801c4,0x00000000}},	//   _bucy, _אָפּ_, цэгт_, --, 
   {{0x764401aa,0x645d9ee5,0xd5c83042,0x24780100}},	// [2c480] _bijy, _stri, रांज, wčm_, 
   {{0x764c0223,0xa6c80961,0x09e4009d,0x00000000}},	//   _ducy, олға_, _цоон, --, 
   {{0x76440007,0xf1c40bae,0x6134013a,0x00000000}},	//   _dijy, लाईन, _mýlí, --, 
   {{0xd90c00dd,0x53e402bf,0x645c4a8e,0xf50002e8}},	//   _ایف_, нціа, _vtri, ъзхо, 
   {{0x6684e6c4,0x764c0796,0xa2486b5d,0xf7700375}},	//   _سیال, _gucy, سیال_, _בקר_, 
   {{0x76440369,0x645c031c,0xe8040073,0x00000000}},	//   _gijy, _ttri, _रगडा_, --, 
   {{0x645d9ee6,0x92e8192c,0xf65c00b5,0x765800a2}},	//   _utri, يرۇق_, _præg_, _çuyr, 
   {{0xdfd00491,0xd7d00574,0x76440796,0xf1c40316}},	//   اية_, हायच, _zijy, लाउन, 
   {{0x25b8edea,0x7c3c011c,0x76440223,0xf65c00b5}},	//   _karl_, _èpri, _yijy, _græd_, 
   {{0x25b99ee7,0x188002d3,0xb5f80118,0xd12c00db}},	//   _jarl_, _ክፍጠር_, _sváz, جۅۅ_, 
   {{0x64499ee8,0x25b8002f,0xf65c01bf,0x9f98032e}},	//   _édis, _marl_, _træg_, _féð_, 
   {{0xb7b800c7,0x25b800a3,0xfba801c6,0x00000000}},	//   _akãn, _larl_, цтой_, --, 
   {{0x20059ee9,0x2fd47e2c,0x6e913bab,0x00000000}},	//   mimi_, _توند_, _للنا, --, 
   {{0xdd949480,0x764c1423,0xeda0013e,0xf77c010b}},	//   _чакы, _rucy, _ашъо, _ilçi_, 
   {{0x76440526,0xe8940166,0x6da00e92,0x9c7c00d0}},	//   _rijy, карь, _рија, byča, 
   {{0x76440223,0x25b80076,0xb5f8013a,0x00000000}},	//   _sijy, _aarl_, _uváz, --, 
   {{0x645865ff,0x7644047e,0x25b80010,0x9634a30d}},	// [2c490] ívin, _pijy, _barl_, енац, 
   {{0x25b99eea,0x38c80276,0xd5c800ce,0xf48401d5}},	//   _carl_, _думн_, राइज, дудн, 
   {{0x81c4015b,0x6594e1fa,0x1cc4031c,0xf52401c6}},	//   ৎসা_, таху, ཏའི_, ффан, 
   {{0xb5f800c6,0x20059eeb,0x764c0223,0x764400ca}},	//   _stád, jimi_, _tucy, _wijy, 
   {{0x20059eec,0x25b803f9,0x3444010b,0x9f9808a5}},	//   dimi_, _farl_, зүңи_, _réð_, 
   {{0xdcf8007f,0x9f98008c,0x25b80165,0xf65c003a}},	//   _advč, _séð_, _garl_, _itæ_, 
   {{0x6594005e,0x3ea59eed,0xe4540fca,0x10a40408}},	//   _шару, _apot_, _аксы, хийн, 
   {{0x20059eee,0x06d40154,0xf65c005c,0xd33c07d5}},	//   gimi_, _সেটি, _træd_, _дiах, 
   {{0x521402bf,0x0ee802a0,0x4f0856cd,0xd228007b}},	//   _здат, टनेस_, янин_, _فكره_, 
   {{0x62844ca5,0x3ea400d8,0x644800d8,0x00000000}},	//   šioc, _dpot_, _édir, --, 
   {{0x20059eef,0x3ea40086,0x6ab81d8a,0xd0540134}},	//   bimi_, _epot_, इट्र, _ɔbɛt, 
   {{0x20059ef0,0x00000000,0x00000000,0x00000000}},	//   cimi_, --, --, --, 
   {{0x7c880092,0x00000000,0x00000000,0x00000000}},	//   _በደርግ_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x25b8be41,0xfafc0023,0x00000000,0x00000000}},	//   _sarl_, mbën_, --, --, 
   {{0x683c001f,0x25b80356,0x0b442bb7,0x00000000}},	// [2c4a0] _በእርስ, _parl_, _янин, --, 
   {{0x20059ef1,0xe6c807f7,0x25b80139,0x2a60df83}},	//   zimi_, रमौज, _qarl_, _itib_, 
   {{0x20059ef2,0x291c035b,0x64bc01ad,0xdedc0092}},	//   yimi_, _âva_, ोमेश, _ዕውን_, 
   {{0xd5c82068,0x20059ef3,0x25b81c1d,0xf65c01bf}},	//   राउज, ximi_, _warl_, _dræb_, 
   {{0x20059ef4,0xb5f800ae,0xa1940dab,0x00000000}},	//   vimi_, _dtáb, валч, --, 
   {{0x2004021a,0x2a600ac5,0xdb2000d0,0x0ddc0023}},	//   wimi_, _mtib_, ätéh, _ዕጽፊ_, 
   {{0xf990011a,0x9478004e,0x00000000,0x00000000}},	//   ארו_, _осту_, --, --, 
   {{0x2a6001b9,0x20040194,0x9f44023a,0xb7d8010f}},	//   _otib_, uimi_, yhmä_, ִקיי, 
   {{0x26c19ef5,0x7e280d30,0x00000000,0x00000000}},	//   nvio_, зіна_, --, --, 
   {{0xdd9042e2,0xd2019ef6,0x26c000c0,0x00000000}},	//   جود_, _күчк, ivio_, --, 
   {{0x2a60427b,0xd1759ef7,0x26c001f4,0xef1c0254}},	//   _atib_, _шыты, hvio_, üür_, 
   {{0x20041366,0x00000000,0x00000000,0x00000000}},	//   qimi_, --, --, --, 
   {{0xb5f800d2,0x8f7400d4,0x00000000,0x00000000}},	//   _kwát, _рухі, --, --, 
   {{0x26c0107d,0xdb200241,0x00000000,0x00000000}},	//   dvio_, _ìtío, --, --, 
   {{0x2a6007d6,0xd7c803e6,0x26c00393,0xf65c08a5}},	//   _etib_, ووسه_, evio_, _stæ_, 
   {{0x80a803d4,0xf7719ef8,0x00000000,0x00000000}},	//   কিপ্, طار_, --, --, 
   {{0xf650a554,0x7bdc003a,0xfc3d9ef9,0x5a3406bd}},	// [2c4b0] ائر_, _ioqu, mmí_, _инит, 
   {{0x7bdc0137,0xb7b800e4,0xbb701075,0xf9680276}},	//   _hoqu, _ikãm, _جۇڭع, _эрий_, 
   {{0x9c7c02fb,0x26c001f4,0xd3b8c9ab,0x00000000}},	//   zyčn, avio_, дулі_, --, 
   {{0xf8ac01ed,0xa3d000dc,0xe4540006,0x67d400db}},	//   _پکڑ_, _वचः_, укцы, _боюу, 
   {{0x3264026a,0x7bdd9efa,0x6d4c0882,0xfc3c0f33}},	//   хтев, _moqu, ścai, imí_, 
   {{0x7bdd9efb,0x80a802f5,0x3a2000b5,0xb3d004b4}},	//   _loqu, কিন্, nojp_, _өйгә, 
   {{0xe53400fd,0x41b006c7,0x00000000,0x00000000}},	//   _берь, شمير, --, --, 
   {{0x7bdd65ad,0x9c7cf75d,0xc4d005d0,0xfc3c013a}},	//   _noqu, tyčn, _דגל_, jmí_, 
   {{0x0cc8b7b0,0x00000000,0x00000000,0x00000000}},	//   िम्म, --, --, --, 
   {{0x2a6001a9,0xc32c0345,0x00000000,0x00000000}},	//   _rtib_, _بڕم_, --, --, 
   {{0x7bdd9efc,0x3204233e,0x90984f65,0xb7b800c7}},	//   _boqu, miny_, _цвет_, _akãm, 
   {{0x7bdd9efd,0xfafc0023,0x00000000,0x00000000}},	//   _coqu, rbën_, --, --, 
   {{0x4428013f,0x7bdc0166,0x2a6006be,0x09b40154}},	//   _ɔb_, _doqu, _qtib_, ঞাসা, 
   {{0x32045fd3,0x8d7410fe,0x26c002e8,0x7bdc16b8}},	//   niny_, _شاتا, vvio_, _eoqu, 
   {{0x7d7400aa,0x7bdc004e,0xabc401e0,0xfcd007c0}},	//   _شمير_, _foqu, _байҙ, _نيوج, 
   {{0x32041311,0xb6040327,0x26c00eab,0xfc3c00ae}},	//   hiny_, _loġġ, tvio_, cmí_, 
   {{0x3204d831,0xf414015b,0x2a6001a9,0xbab033ae}},	// [2c4c0] kiny_, ়তার_, _utib_, _نميب, 
   {{0x3204d824,0x7bdc04d4,0x26c19efe,0xb6a03ae4}},	//   jiny_, _zoqu, rvio_, рифл, 
   {{0x32059eff,0x26c00120,0x7bdd9f00,0xb8b00150}},	//   diny_, svio_, _yoqu, _көті, 
   {{0x7bdc0724,0xb5f80118,0xf7700451,0x066401e2}},	//   _xoqu, _ptác, _پاٽ_, _لاسپ, 
   {{0x32040851,0x00000000,0x00000000,0x00000000}},	//   finy_, --, --, --, 
   {{0xb5f800d0,0x15b8068e,0x00000000,0x00000000}},	//   _vtác, _пысы_, --, --, 
   {{0xa1940116,0xc61c28f5,0xb63802dd,0x00000000}},	//   ваһч, बकीय_, _ﺘﺼ_, --, 
   {{0x8fd40724,0x9f3402dd,0x00000000,0x00000000}},	//   ләчә, лейі, --, --, 
   {{0xc2440965,0x32059f01,0xef1c00c5,0x9c7c02f0}},	//   _анак, biny_, üüp_, tyčo, 
   {{0x7bdc0eda,0x0c701a02,0xdcf80055,0x320444ef}},	//   _soqu, ڭگود, _advā, ciny_, 
   {{0x7bdd9f02,0x7cc806be,0x00000000,0x00000000}},	//   _poqu, lərz, --, --, 
   {{0xfafc002e,0xbea8009f,0x00000000,0x00000000}},	//   bbël_, _يهان_, --, --, 
   {{0xb4dc033f,0xfc3c004e,0x9c7c007f,0x00000000}},	//   _तथ्_, rmí_, myčm, --, 
   {{0x7e600290,0xfc3c012c,0x9c7c0100,0x00000000}},	//   _itop, smí_, lyčm, --, 
   {{0x7bdd9f03,0x3a2000b5,0xed3001d3,0xfafc036e}},	//   _toqu, rojp_, _پوٹھ, mbëm_, 
   {{0x32042f5b,0x68e806ea,0x00000000,0x00000000}},	//   ziny_, ødda, --, --, 
   {{0x19580962,0x00000000,0x00000000,0x00000000}},	// [2c4d0] _папы_, --, --, --, 
   {{0x7c2c00a3,0x7e601bb6,0xb5f801e1,0xe5c48fa1}},	//   llcr, _mtop, _awár, исхо, 
   {{0x32059f04,0xc9500302,0x69d036c7,0x00000000}},	//   viny_, _למי_, दारी, --, 
   {{0xb6040003,0x3204ae4b,0xd2980006,0x7bc803b2}},	//   _soġġ, winy_, еткі_, _ógud, 
   {{0x32045fd3,0x7e619f05,0xb6040003,0x62840841}},	//   tiny_, _ntop, _poġġ, šion, 
   {{0x06880952,0x7990002d,0x9c7c007f,0x00000000}},	//   _ﺗﻪﻣﯩ, _ôfwę, tyčl, --, 
   {{0x7e600f71,0x32041311,0xa4d40212,0x41259f06}},	//   _atop, riny_, _корі, лошо_, 
   {{0x32040851,0x4f940a42,0xaab800bc,0x2938011a}},	//   siny_, урку, ेटमक, כאון_, 
   {{0xe2c8021a,0x32059f07,0x0d999f08,0x224c0175}},	//   _ټولو_, piny_, нтны_, _fidk_, 
   {{0x4d64656c,0xb06001f4,0x00000000,0x00000000}},	//   ыков, ääsy, --, --, 
   {{0xd1319f09,0x42684be7,0xa6e400eb,0x00000000}},	//   _اما_, ቶዶክስ_, _নোট, --, 
   {{0x7e60010a,0x60dc01c3,0x518400fb,0x00000000}},	//   _ftop, _àrma, _шуға, --, 
   {{0x2fcc0066,0x00000000,0x00000000,0x00000000}},	//   _ingg_, --, --, --, 
   {{0x833408a8,0x9f340212,0x7c2c035a,0x64580162}},	//   טארס_, _течі, alcr, ívik, 
   {{0x6cb005a2,0x6d9001a9,0x7e6001ef,0x00000000}},	//   _төпт, 阻ali, _ztop, --, 
   {{0xcb740f5c,0x7e6002d0,0xc96401c6,0xdcf8002b}},	//   _сукњ, _ytop, _өвий, _udvā, 
   {{0x4614d5bc,0x6b859f0a,0x7e600221,0xcb0800ec}},	// [2c4e0] هورر, _idig, _xtop, _سيدن_, 
   {{0x4994005b,0x9c7c007f,0x997400db,0x597400cf}},	//   _сшит, zyčm, _куюш, _кыюу, 
   {{0x399800c8,0x8504d195,0x453428f6,0x8384035b}},	//   _אייד, دوان, ухат, гыле, 
   {{0x69dc9c2a,0x25f00490,0x2fcc00db,0xe8d00490}},	//   ljre, _इतकी_, _nngg_, हमीच, 
   {{0x6448011c,0x56d401d5,0xa2840133,0x96740153}},	//   _èdim, _кўрф, شیاو, _высі, 
   {{0x2fcd9f0b,0xb7b800c7,0xc5f00014,0x69dc00d5}},	//   _angg_, _akãh, _آس_, njre, 
   {{0xf990011a,0x00000000,0x00000000,0x00000000}},	//   צרה_, --, --, --, 
   {{0x6b859f0c,0x3f80145e,0x3e6821ee,0x00000000}},	//   _ndig, ûku_, ншон_, --, 
   {{0x44259f0d,0x224c0a2e,0x7de40046,0x7ed59f0e}},	//   moo_, _tidk_, гінд, ازعا, 
   {{0x57e005ba,0x6b859f0f,0x442417c7,0x2fcc045a}},	//   _नव्ह, _adig, loo_, _engg_, 
   {{0x8064319b,0x6b843edd,0xfca84fca,0xb5f8008f}},	//   _свеж, _bdig, رادو_, גליכ, 
   {{0x44252901,0xb5f81aac,0xdb1c01ed,0xcfa800f1}},	//   noo_, _ntán, ldsé, _لاهم_, 
   {{0x6b840cfd,0x7e619f10,0xc2e403d4,0x7c2c02d0}},	//   _ddig, _utop, _খেতি_, rlcr, 
   {{0x44247636,0xb5f99f11,0xdb1c7cd6,0xcfa800cc}},	//   hoo_, _atán, ndsé, _খোপন, 
   {{0x44252901,0x7c8477da,0xd7d001ad,0xfd1000ec}},	//   koo_, _суле, हालच, _ھجڻ_, 
   {{0x44259f12,0xf65c005c,0x57b40798,0x00000000}},	//   joo_, _dræn_, јбат, --, 
   {{0x44259f13,0x55743804,0xb5f801e7,0x56940395}},	// [2c4f0] doo_, игат, _dtán, разт, 
   {{0x442400ad,0x21200118,0x98740798,0x00000000}},	//   eoo_, řihy_, _клоц, --, 
   {{0x4424013b,0x62800477,0x62840153,0xf65c01a8}},	//   foo_, _avmo, šiol, _græn_, 
   {{0x44259f14,0x56959f15,0x2e2800ed,0x00000000}},	//   goo_, _камт, løft_, --, 
   {{0x60c99f16,0xdce80153,0x00000000,0x00000000}},	//   _ardm, radę, --, --, 
   {{0x0160004e,0x00000000,0x00000000,0x00000000}},	//   окшо, --, --, --, 
   {{0x4ddc2158,0xe4c40a89,0xc2e400fe,0x944400f2}},	//   যসমূ, _лётн, _খেদি_, _نپسن, 
   {{0x44259f17,0x20c80691,0x8e840117,0x63a40022}},	//   coo_, ابوي_, агие, õint, 
   {{0xa0240e78,0x60c82305,0x6b84002f,0x9e640066}},	//   _stöß, _erdm, _rdig, یاین, 
   {{0x6b840268,0x4e040107,0x7de4009d,0x00000000}},	//   _sdig, рзоб, имыг_, --, 
   {{0xcb68156c,0xa3bc060e,0x19b80327,0x00000000}},	//   кане_, _असम_, _བལྟབ, --, 
   {{0xdce80118,0xf0440153,0x00000000,0x00000000}},	//   ladě, _сэзо, --, --, 
   {{0x6e659f18,0x67f801e1,0x2a64036e,0x00000000}},	//   _стеж, _jíje, ëmb_, --, 
   {{0xb5f99f19,0x9f640008,0x67f801ef,0x00000000}},	//   _stán, ðtöl_, _míje, --, 
   {{0x44259f1a,0xb5f801e1,0xd7d001f9,0x00000000}},	//   yoo_, _atáo, हांच, --, 
   {{0x44259f1b,0x6b840009,0x0ba80150,0x00000000}},	//   xoo_, _udig, _شاعى_, --, 
   {{0xd1f04be7,0x44259f1c,0xdee40023,0x67f80241}},	// [2c500] ግሎት_, voo_, _ምኾነ_, _níje, 
   {{0x44259f1d,0xf65c00b5,0x00000000,0x00000000}},	//   woo_, _træn_, --, --, 
   {{0x65c40046,0xb5f99f1e,0x07a4d25e,0x44259f1f}},	//   _құжа, _itál, _канн, too_, 
   {{0x03a4372a,0xb5f800dd,0xf8ac00f1,0x00000000}},	//   ридо, _után, _ډکې_, --, 
   {{0x44259f20,0xc2442c31,0xaab8146b,0x26c400e4}},	//   roo_, андк, ेटिक, _émo_, 
   {{0x44259f21,0x80a809bd,0xf77c00d8,0x969000e5}},	//   soo_, কিস্, _voçe_, _ریمش, 
   {{0x44259f22,0xdd940032,0xdb1d34a7,0x318401ec}},	//   poo_, ҙаны, rdsé, ртің, 
   {{0x67f80789,0x6280037e,0x44259f23,0x63a4010f}},	//   _fíje, _tvmo, qoo_, ĵins, 
   {{0x9c7c0153,0x41b400f5,0xb5f801ef,0x00000000}},	//   myči, _всет, _otál, --, 
   {{0x7f8401ed,0x9c7c0153,0x00000000,0x00000000}},	//   _چلان, lyči, --, --, 
   {{0xb7b800e4,0x49043d1d,0xbe4802f2,0x00000000}},	//   _ikãv, _हेलो_, _یشتم_, --, 
   {{0xbea40024,0x9c7c0153,0x00000000,0x00000000}},	//   _вадк, nyči, --, --, 
   {{0x19c405a2,0x2e280fac,0x00000000,0x00000000}},	//   бәнг, tøft_, --, --, 
   {{0xf77000ec,0x81c40154,0x00000000,0x00000000}},	//   ڪاس_, ৎসক_, --, --, 
   {{0xf8055f95,0x20199f24,0x9c7c0006,0x6d4c0882}},	//   ачан, _íris_, kyči, ścar, 
   {{0xf7700220,0x3f8400bc,0x59d418cc,0x9c7c0064}},	//   تاس_, _jdou_, दाहर, jyči, 
   {{0x628402d5,0x7e7400a2,0x9c7c0064,0x79a400f3}},	// [2c510] šioj, _çypd, dyči, _крне, 
   {{0xbb180548,0xfafc036e,0x00000000,0x00000000}},	//   taîf, mzë_, --, --, 
   {{0xd370007b,0x24580124,0x00000000,0x00000000}},	//   كها_, аахь_, --, --, 
   {{0x3f85558b,0xb7b80022,0x6ac401d5,0x68e80267}},	//   _ndou_, _akãv, _اقیم, ädde, 
   {{0xd1f001f3,0xfafc0200,0x00000000,0x00000000}},	//   ግሎቱ_, nzë_, --, --, 
   {{0xa20400d4,0x00000000,0x00000000,0x00000000}},	//   опід, --, --, --, 
   {{0xd0099f25,0x344800ee,0x8fd0151e,0x8618014b}},	//   леке_, _ачан_, зәлә, _серӣ_, 
   {{0xa2b00073,0xfafc0de2,0xe0d00066,0x00000000}},	//   _आईच्, ccëg_, بزه_, --, 
   {{0xfafc02d3,0xa3bc0490,0x63a401c3,0x00000000}},	//   jzë_, _असत_, òine, --, 
   {{0x079000bc,0x00000000,0x00000000,0x00000000}},	//   _čímž_, --, --, --, 
   {{0x0c2467d7,0x62240131,0x81400228,0x645801e4}},	//   ймон, _بىلل, _ىچىن, ŭviv, 
   {{0xb5f80e96,0x00000000,0x00000000,0x00000000}},	//   _stál, --, --, --, 
   {{0x0e640022,0x00000000,0x00000000,0x00000000}},	//   _уклн, --, --, --, 
   {{0x2fdcf27a,0x4338008f,0x2884024c,0x7d1000e5}},	//   ljug_, טערב, оқов, ádsá, 
   {{0x2d84003a,0x8c452f12,0xf65c02d2,0x00000000}},	//   _idne_, _леке, _dræm_, --, 
   {{0x2fdc026a,0xf65c0158,0x00000000,0x00000000}},	//   njug_, _træl_, --, --, 
   {{0x06c800db,0x9c7c0153,0xf74000f5,0x85546640}},	// [2c520] ыгай_, vyči, зето, مخاط, 
   {{0x05540006,0xb5f801d3,0x00000000,0x00000000}},	//   стая, _utál, --, --, 
   {{0x9c7c0006,0x39540375,0x448821fa,0xa3bc0950}},	//   tyči, _לשים_, убен_, _असद_, 
   {{0x037896b4,0x2fdc0de2,0x434401af,0xe79400f2}},	//   احات_, jjug_, беев, _بادک, 
   {{0x21793a74,0x9c7c0153,0x27e00174,0x620801a9}},	//   айлы_, ryči, mjin_, аrlа, 
   {{0x27e19f26,0x92640214,0x04f400cc,0x00000000}},	//   ljin_, زدهم, _আশীৰ_, --, 
   {{0x27e00009,0x42500133,0x80041188,0x9c7c0064}},	//   ojin_, _کۆتر, йчие, pyči, 
   {{0x27e19f27,0x5f94192a,0x2fdc0438,0x7520000f}},	//   njin_, циит, gjug_, ûnze, 
   {{0x64400664,0x27e000b5,0x920400e2,0x434400d8}},	//   _ihmi, ijin_, _spāņ, _ѓезв, 
   {{0xf2e4034c,0xf77c06ed,0x644001a6,0x232802a9}},	//   _دکمه_, _moça_, _hhmi, _боғи_, 
   {{0xa3bc05ba,0x644006a3,0x6ca002f6,0x9cf400d4}},	//   _असा_, _khmi, пряж, ізмі, 
   {{0x27e19f28,0xdfd000c6,0x00000000,0x00000000}},	//   jjin_, _زيت_, --, --, 
   {{0x70440150,0x27e01368,0xf0440472,0x00000000}},	//   _ارلە, djin_, _اعلی, --, 
   {{0x27e0020b,0xac701079,0xfafc036e,0xb5f8013a}},	//   ejin_, _کاوش, rzë_, _ptám, 
   {{0x16d089f0,0x37a8e53f,0x28f80276,0x644001f4}},	//   सम्ब, лтан_, берь_, _ohmi, 
   {{0x27e0193f,0xf77c067c,0xcefc0790,0x00000000}},	//   gjin_, _boça_, _öğün_, --, 
   {{0xec140a81,0xf77c00d8,0x356801a9,0xd944010b}},	// [2c530] _روٝد, _coça_, грен_, сеңи, 
   {{0x9b94304e,0xf77c068c,0x64419f29,0x151402d5}},	//   _الکت, _doça_, _ahmi, одзя, 
   {{0xe7c41b76,0x54b80962,0xc2e402f5,0x7aec0175}},	//   _लोकप, ргея_, _খেলি_, lyct, 
   {{0x64403a5b,0xf77c03e0,0x56940107,0x00000000}},	//   _chmi, _foça_, _қаҳт, --, 
   {{0x33848af9,0x777c0e14,0x00000000,0x00000000}},	//   _қувв, maqx, --, --, 
   {{0x644002d0,0x20b46fe9,0x1fb40588,0x00000000}},	//   _ehmi, ंबंध, ҧсыр, --, 
   {{0x13f40024,0x09cc00eb,0x00000000,0x00000000}},	//   _дзвя, _রকমা, --, --, 
   {{0x0e642c2c,0xf1a40354,0x00000000,0x00000000}},	//   окин, _ӳрен, --, --, 
   {{0x8d74516c,0xf1a45a06,0x8db4109a,0x00000000}},	//   يادا, _грен, осні, --, 
   {{0x777c0054,0x8e08bc31,0xb5f80f57,0x201801e1}},	//   haqx, рнов_, _stáj, _ìrin_, 
   {{0xb5f80022,0xf65c00b5,0x814000f7,0x21b800e5}},	//   _aták, _bræk_, _ۉچۉن, _دھنک_, 
   {{0x8e7401d5,0x27e0031c,0x7bd801f4,0x00000000}},	//   _дукч, xjin_, öuup, --, 
   {{0x2d8401ab,0xa87801c6,0x00000000,0x00000000}},	//   _tdne_, өөнт_, --, --, 
   {{0x644802e8,0xf77cff76,0xd7f001fb,0xc864007b}},	//   _èdiv, _roça_, ễn_, قطري, 
   {{0xf65c037e,0x8ba4010b,0x0c0401d9,0x27e19f2a}},	//   _fræk_, _дийж, _ووتُ, tjin_, 
   {{0xbb140ed1,0xf77c00d8,0x8ae0022e,0x27e004ce}},	//   ﻳﻮﻥ_, _poça_, _ma智u, ujin_, 
   {{0x060815ed,0x27e19f2b,0xb6a199c2,0xed4c00e5}},	// [2c540] анак_, rjin_, митл, _تھک_, 
   {{0x64419f2c,0x67f801ed,0x27e0000f,0xc9a91e49}},	//   _shmi, _díja, sjin_, _твое_, 
   {{0x75d00035,0x438400be,0xa81401e2,0x00000000}},	//   ظيما, قلاق, _فېسب, --, 
   {{0x67f80407,0xf4840424,0x42c8e4ae,0xdb9c0023}},	//   _fíja, زامی, иген_, ሃሂዶም_, 
   {{0x2bacd639,0xe1f8039b,0x00000000,0x00000000}},	//   ट्या, бҳа_, --, --, 
   {{0xdbdc01e1,0xfafc0023,0x0578007b,0xbb3808d8}},	//   _dáùs, mbët_, _خمسة_, בעני, 
   {{0x7aec0204,0x657c0036,0x217801e0,0x64400200}},	//   zyct, _ierh, айһы_, _thmi, 
   {{0x657d9f2d,0x645d9f2e,0x00000000,0x00000000}},	//   _herh, _iuri, --, --, 
   {{0x645d9f2f,0x657d9f30,0xa1380023,0x00000000}},	//   _huri, _kerh, _ብዕምቆ, --, 
   {{0x645d9f31,0x6e40edc2,0x2bd00037,0x00000000}},	//   _kuri, ونيم, _तोबा, --, 
   {{0x657d9f32,0x645d9f33,0xb5f80162,0x00000000}},	//   _merh, _juri, _sták, --, 
   {{0x61e99f34,0x657c0472,0xb5f800bc,0x00000000}},	//   _hodl, _lerh, _pták, --, 
   {{0x657d9f35,0x645d9f36,0x61e81258,0x63a00ac5}},	//   _oerh, _luri, _kodl, _mcmn, 
   {{0x645d9f37,0x657d9f38,0xb5f80030,0x7aec0561}},	//   _ouri, _nerh, _vták, ryct, 
   {{0xf65c04ce,0x67f800d2,0xac70005e,0x77914c0b}},	//   _træk_, _síja, _قايش, ویدا, 
   {{0xb7b800c7,0x61e99f39,0xb5f800e4,0x68e80267}},	//   _akãr, _lodl, _kuág, ädda, 
   {{0x657c5088,0x61e99f3a,0xec240150,0x2c540356}},	// [2c550] _berh, _oodl, _تىيپ, _dădu_, 
   {{0x2bac80f3,0x645c2b9d,0x356800ee,0x61e99f3b}},	//   ट्ठा, _buri, рран_, _nodl, 
   {{0x649000e4,0xaee00055,0x00000000,0x00000000}},	//   _ẽire, _kuṣm, --, --, 
   {{0x645d9f3c,0x799802a8,0x657c02d0,0xe4580212}},	//   _duri, ɗuwa, _eerh, іжі_, 
   {{0xa3bc19e5,0x657d9f3d,0x61e99f3e,0xfafc0240}},	//   _असर_, _ferh, _bodl, mbës_, 
   {{0x61e99f3f,0xf77c0240,0x940401b9,0x00000000}},	//   _codl, _koço_, _کوره, --, 
   {{0x645d9f40,0x64a806d6,0xf1a404d3,0x61e801b9}},	//   _guri, _ḓivh, ماژه_, _dodl, 
   {{0xb5f80316,0x657c004b,0xf77c0798,0x68e806ea}},	//   _stáh, _zerh, _moço_, øddi, 
   {{0x645d9f41,0x61e80368,0x657c004b,0xb5f8007b}},	//   _zuri, _fodl, _yerh, _atái, 
   {{0x645d9f42,0x61e99f43,0xc3300bd9,0xa158014b}},	//   _yuri, _godl, _טון_, _дафу_, 
   {{0x645d9f44,0x8fd00116,0xb5f8013a,0x00000000}},	//   _xuri, _зәпә, _vtáh, --, 
   {{0x61e80921,0x75f003ee,0xb5f800c6,0x6448020c}},	//   _zodl, _hızı, _dtái, _èdit, 
   {{0x75f05d6d,0xb5f80022,0x61e8249f,0xf65c02d2}},	//   _kızı, _guág, _yodl, _fræi_, 
   {{0xcefd0b83,0x7c24151c,0x7e7400a2,0xb5f8013a}},	//   ığın_, čkra, _çypa, _utáh, 
   {{0x31ac07c4,0x657c02c4,0xa3bc69de,0x75f02ca8}},	//   mızı_, _rerh, _असल_, _mızı, 
   {{0x657d9f45,0x645d9f46,0x00000000,0x00000000}},	//   _serh, _ruri, --, --, 
   {{0x657d76e1,0xdcf800bc,0xbb1806af,0x00000000}},	// [2c560] _perh, _odvě, raîc, --, 
   {{0x31ac708d,0xfafc0023,0x645d9f47,0x2bd001ad}},	//   nızı_, rbët_, _puri, _तोता, 
   {{0x657c606b,0x645d9f48,0x61e8c375,0xaee000dc}},	//   _verh, _quri, _rodl, _yuṣm, 
   {{0x645c06e4,0x657d9f49,0x61e99f4a,0x2478007f}},	//   _vuri, _werh, _sodl, rōm_, 
   {{0x657d9f4b,0x61e99f4c,0x645c3142,0xfafc0240}},	//   _terh, _podl, _wuri, lbër_, 
   {{0xb5f804d4,0xd2580111,0x75f04e7e,0xcfa800cc}},	//   _cuád, іці_, _cızı, _খোলন, 
   {{0x645c033d,0x61e8016d,0x31ac0205,0x00000000}},	//   _uuri, _vodl, dızı_, --, 
   {{0x61e8014f,0xa4f80073,0xf8b0011a,0x3518011a}},	//   _wodl, ंनीच_, גשה_, _הולנ, 
   {{0xb5f80597,0x61e8047e,0x02040395,0x6ab80709}},	//   _stái, _todl, _езан, ेटोर, 
   {{0x71a12f34,0xd12c0372,0x24680205,0x11e8007b}},	//   _пауз, دۅۅ_, _eğme_, _وعلي_, 
   {{0x64499f4d,0x67f801e1,0x405800ae,0x00000000}},	//   _èdis, _níjo, _الصح_, --, 
   {{0xc0c8001f,0x00000000,0x00000000,0x00000000}},	//   _ጠቅሶ_, --, --, --, 
   {{0xb5f800c7,0xfe445a41,0x68e80267,0xf65c0162}},	//   _itáv, _ендо, äddn, _træi_, 
   {{0xb7b800e4,0xf77c0120,0xf65c01bf,0x75f003b9}},	//   _akãp, _poço_, _kræv_, _xızı, 
   {{0xa3bc05ba,0x28f81c22,0xa41c375c,0xdb0c0022}},	//   _असं_, перь_, पचाप_, _mbaé, 
   {{0xf7700046,0xfaa4014b,0x62440241,0x00000000}},	//   عاز_, _ешон, bòog, --, 
   {{0xfafc0200,0x00000000,0x00000000,0x00000000}},	// [2c570] rbës_, --, --, --, 
   {{0xdcf99f4e,0x63a401ab,0x58d400db,0xa63401ec}},	//   _levč, òinn, _жоот, енуі, 
   {{0xb5f80798,0x75f003e0,0xd75800ae,0x00000000}},	//   _otáv, _rızı, _ولدت_, --, 
   {{0x7c2d9f4f,0x75f02ed0,0x00000000,0x00000000}},	//   nocr, _sızı, --, --, 
   {{0x38c400bc,0xb2a800a7,0xc76424ae,0x16840244}},	//   bírá_, стеж_, _تاپى, _تاجێ, 
   {{0xf77c0cc1,0x75f19f50,0x64980084,0xf65c06ea}},	//   _heç_, _qızı, ḓif, _bræv_, 
   {{0xf77c00ac,0x7c2c004e,0x75f015b7,0x904406c2}},	//   _keç_, kocr, _vızı, ونته, 
   {{0xdcf800f3,0xef3c037e,0x00000000,0x00000000}},	//   _cevč, _ml缶_, --, --, 
   {{0xdcf8107d,0x81b000fe,0xdb1c01bf,0xf77c0200}},	//   _devč, টয়_, ldsæ, _meç_, 
   {{0x6448011c,0xb5f800c7,0xcc88023a,0xd2500214}},	//   _èdir, _etáv, обое_, _شنا_, 
   {{0xdb1d9f51,0x62840024,0x6aa800fe,0x6ab82e04}},	//   ndsæ, šiot, খিছো, ेट्र, 
   {{0xe7d811ba,0x6f84036b,0x00000000,0x00000000}},	//   _সত্য, _хужж, --, --, 
   {{0xdb0c00e8,0x9f580051,0x00000000,0x00000000}},	//   _baañ, đrô_, --, --, 
   {{0x9e244d2d,0xdce8005f,0x59d40254,0xc97408de}},	//   _كىنو, gadē, दागर, باحث, 
   {{0x45080135,0xdb0d2cc9,0xc7a400a7,0x38c400bc}},	//   _གཟེར_, _daañ, мивк, vírá_, 
   {{0xfafc0240,0xc79400c7,0x80cc00cd,0x00000000}},	//   rbër_, ьргы, थिते, --, 
   {{0xf41003f4,0x38c40118,0x67f801e1,0xfafc036e}},	// [2c580] িকার_, tírá_, _wíjo, lcën_, 
   {{0xdb0c0de2,0xf65c0393,0xfa940a1e,0xfcd00150}},	//   _gaañ, _duæ_, _קדיש_, _سيۋج, 
   {{0xc48400a8,0xfafc044e,0x2a6001f5,0x35a001c6}},	//   флек, ncën_, _huib_, тахг, 
   {{0xf77caa4a,0x613800d2,0xd06003e3,0x68e80174}},	//   _geç_, húlú, _ötər, øddu, 
   {{0xc17802bf,0xdcf80010,0xa294109a,0x00000000}},	//   оїй_, _revč, халі, --, 
   {{0xb5f80232,0x00000000,0x00000000,0x00000000}},	//   _stáv, --, --, --, 
   {{0x2a6008c2,0x26c0020c,0x35a19f52,0xfafc0200}},	//   _luib_, lwio_, _шарг, jcën_, 
   {{0xd1c8044e,0x00000000,0x00000000,0x00000000}},	//   _ጠንቂ_, --, --, --, 
   {{0x6d459f53,0xdcf80010,0x7c2c01a6,0x26c00042}},	//   ýjan, _vevč, vocr, nwio_, 
   {{0x201801ed,0x4e140014,0x068800d1,0x00000000}},	//   őri_, ى۪ند_, _ﺗﻪﻟﯩ, --, 
   {{0x2bd0007d,0x00000000,0x00000000,0x00000000}},	//   _तोहा, --, --, --, 
   {{0xfd6001c0,0x5bc401f0,0x00000000,0x00000000}},	//   энүү, хроҷ, --, --, 
   {{0xdd94f1c2,0xb4b88f35,0x2a600311,0x13b00154}},	//   _залы, _अन्_, _cuib_, _ঘোড়, 
   {{0x7f4001f0,0xf77d9f54,0x7c2d0adb,0x61f8017a}},	//   _izoq, _seç_, socr, nkvl, 
   {{0xa9350b85,0xf65c0381,0x2db40375,0xf77c415b}},	//   верш, _suæ_, _חלון_, _peç_, 
   {{0xdb0c0de2,0x60dc00a3,0x00000000,0x00000000}},	//   _waañ, _àrmu, --, --, 
   {{0xf65c1730,0xf77c02d3,0x2a6001ab,0xba3800db}},	// [2c590] _quæ_, _veç_, _guib_, juïg, 
   {{0x61f80d27,0x0c7001d5,0x9f44036e,0x00000000}},	//   jkvl, _جگید, ejmë_, --, 
   {{0x7af80217,0x6a143cc6,0xdb1c01bf,0x5dac00cc}},	//   øutf, _جبير, udsæ, _কোৱঁ, 
   {{0x649806d6,0x7f400117,0xf65d28ce,0x61f80d47}},	//   ḓid, _ozoq, _tuæ_, ekvl, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9f44036e,0xdcf800d7,0x00000000,0x00000000}},	//   ajmë_, _nevď, --, --, 
   {{0x23602ce2,0x7f400117,0x25ac007c,0xdb1c01e3}},	//   žija_, _azoq, _ödla_, ldsä, 
   {{0xe04800c6,0xba38004e,0x00000000,0x00000000}},	//   وشيه_, luïd, --, --, 
   {{0xdb1d482d,0xf65d28ae,0x7e7400a2,0x629c002b}},	//   ndsä, _græt_, _çypl, _ārog, 
   {{0xba38004e,0x00000000,0x00000000,0x00000000}},	//   nuïd, --, --, --, 
   {{0x7f40676c,0xc1e401ed,0xf65c01bf,0xa0c4009a}},	//   _ezoq, _سکول_, _kræs_, _ليلو, 
   {{0xc4d000c8,0x26c000a9,0xfafc0023,0x00000000}},	//   אגט_, ywio_, rcën_, --, 
   {{0x2a600381,0xee400022,0xdde8030f,0x00000000}},	//   _quib_, _иҭии, سریه_, --, 
   {{0xbea19f55,0xd04000ec,0x068800d1,0x00000000}},	//   _сашк, _جھڙي, _ﺗﻪﻛﯩ, --, 
   {{0xba3800f7,0xdb1c00d8,0x00000000,0x00000000}},	//   duïd, nesê, --, --, 
   {{0x6d4004b9,0xdbdc0241,0x00000000,0x00000000}},	//   _izna, _dáós, --, --, 
   {{0x86459f56,0xdcf800e2,0x5ba401e0,0x59b4009d}},	// [2c5a0] енаж, _ievā, _рлығ, хөөс, 
   {{0x2bac08a3,0x290c0077,0x35a000fd,0xa65403e6}},	//   ट्रा, údas_, лауг, ئێست, 
   {{0xddd8007f,0xb5f80194,0xf4840330,0xb978011a}},	//   _divň, _atás, فانی, _מניי, 
   {{0xb5f80316,0x7d04004a,0x82a400f7,0xc3240209}},	//   _stát, _héré, ешке, нмек, 
   {{0xd36c278f,0xba381e7b,0x7d0400e5,0xb5f82b78}},	//   تۇق_, buïd, _kéré, _quác, 
   {{0x6d4c0882,0x7d0461d0,0xb5f801e7,0x615401d3}},	//   ścay, _jéré, _dtás, نچائ, 
   {{0x61f85b5e,0x4508025c,0x7d043980,0x7620033a}},	//   rkvl, _གཟིར_, _méré, _смрз, 
   {{0xf65c037e,0x436805f5,0x7d0401e1,0xdb1c03cd}},	//   _træt_, _хаан_, _léré, ldså, 
   {{0x6d419f57,0xb5f800e4,0x42240111,0xeeb4013d}},	//   _azna, _itár, _здав, елыш_, 
   {{0x3da40bd8,0x7d040c6a,0xc0e401af,0x00000000}},	//   хриб, _néré, _позк, --, 
   {{0x62240131,0x1ac800cd,0x9af800b8,0x00000000}},	//   _كۈچە, िट्ठ, dbāṇ, --, 
   {{0xfba99f58,0x7d040129,0x3518010f,0x00000000}},	//   чтой_, _aéré, לוינ, --, 
   {{0xdcf99f59,0x7d059f5a,0xaee00a28,0x7f40039b}},	//   _devā, _béré, ruṣa, _uzoq, 
   {{0x7d059f5b,0xdb1c0240,0x00000000,0x00000000}},	//   _céré, lesë, --, --, 
   {{0xdd90021a,0x2f50506f,0xb5f80798,0x7e60005b}},	//   _موږ_, _итәс, _otár, _huop, 
   {{0x7e619f5c,0xdb1c0023,0xba3800db,0xf77c0240}},	//   _kuop, nesë, duïe, _koçi_, 
   {{0x64a80943,0x7e60023a,0xba384b84,0xe6946a24}},	// [2c5b0] _ḓiph, _juop, tuïd, литы, 
   {{0x7e60090c,0x7d059f5d,0xdb1cd1ca,0x00000000}},	//   _muop, _géré, hesë, --, 
   {{0xd370b891,0x79840230,0x7e6002f6,0x2004003e}},	//   لها_, majw, _luop, khmi_, 
   {{0x30ac00bd,0xdb1c0023,0x23e40006,0x574400db}},	//   কিৎস, jesë, лічв, _үнүб, 
   {{0x97345226,0x7d0464e7,0xb5f80332,0x20044146}},	//   _شکرا, _yéré, _dtár, dhmi_, 
   {{0xe1f8005e,0xb5f80120,0x337402d3,0xba38004e}},	//   нгі_, _etár, _ሽዱሽተ_, buïe, 
   {{0xf65c02d2,0xe18801f7,0x00000000,0x00000000}},	//   _grær_, رئون_, --, --, 
   {{0xf41c0227,0x79859f5e,0xdb1cd273,0xb4b00022}},	//   _ñä_, hajw, gesë, _ииҳә, 
   {{0x79848aa7,0x7e6004cc,0x6d406dde,0xdcf800b8}},	//   kajw, _cuop, _szna, _revā, 
   {{0x4c699f5f,0x7e6000df,0xfe6cc5f2,0x798400ca}},	//   мион_, _duop, زگه_, jajw, 
   {{0x4e9400dd,0x7d0400d5,0xdb1d9f60,0xe9840116}},	//   رشکر, _réré, lesè, ңқин, 
   {{0x0f1409fe,0x7d059f61,0x7e600418,0x2004af91}},	//   _имею, _séré, _fuop, chmi_, 
   {{0xba399f62,0x7d059f63,0xdce80064,0x6d400210}},	//   duïb, _péré, kadė, _wzna, 
   {{0x0ca8086e,0x79855b88,0x00000000,0x00000000}},	//   _قطعي_, gajw, --, --, 
   {{0x6d402a5c,0xdde802f2,0xf9800117,0x00000000}},	//   _uzna, _سروه_, ргсо, --, 
   {{0x7d040248,0xca3801ec,0x00000000,0x00000000}},	//   _wéré, _ﺒﺭﺩ_, --, --, 
   {{0x79859f64,0x7d059f65,0xf40400eb,0x00000000}},	// [2c5c0] bajw, _téré, লচার_, --, 
   {{0x6b84b183,0xd90c6112,0xb5f80308,0xba38004e}},	//   _heig, _کیف_, _stár, tuïe, 
   {{0x85059f66,0x6b859f67,0xba38004e,0x291c0588}},	//   خوان, _keig, buïb, _ãva_, 
   {{0x6b859f68,0x1b040154,0x340800f1,0xb9bc00fd}},	//   _jeig, রপরে_, ورنۍ_, _çärş, 
   {{0x6b859f69,0x2360151c,0xd36c03cc,0x7024009e}},	//   _meig, žijo_, سۇل_, মতাজ_, 
   {{0xb5f8937c,0xf65c0212,0x80cc0b7d,0xf1900124}},	//   _huán, _trær_, थिले, аишь, 
   {{0xdb1c0023,0xb5f800c7,0x2004d02e,0x7e6032bb}},	//   tesë, _itáp, thmi_, _suop, 
   {{0x7e6003a0,0x6b859f6a,0x3f819f6b,0xb5f800e4}},	//   _puop, _neig, úku_, _juán, 
   {{0xdb1c0023,0x79840223,0x7e600393,0xdef401c6}},	//   resë, yajw, _quop, уппы, 
   {{0x20059f6c,0xdcf80311,0x6b8401e7,0xd24c03e6}},	//   shmi_, _nevă, _aeig, _فۆن_, 
   {{0x6b859f6d,0x62806e25,0xdb1c00e5,0x00000000}},	//   _beig, _hwmo, mesé, --, 
   {{0x6b8401e4,0xdb1c01ed,0x79840117,0x91f4004d}},	//   _ceig, lesé, wajw, _tíc, 
   {{0x6b859f6e,0x79840451,0x25f80490,0x8f74109a}},	//   _deig, tajw, _एवढी_, _сухі, 
   {{0xd7c8135f,0x00000000,0x00000000,0x00000000}},	//   کوره_, --, --, --, 
   {{0x6b859f6f,0x7984337a,0x75f8026c,0xaa587724}},	//   _feig, rajw, _fîzj, тиру_, 
   {{0xf7719f70,0xb5f9801d,0x6b85146a,0x7d1402a8}},	//   شار_, _cuán, _geig, _ƙasƙ, 
   {{0xdb1c5ed5,0x67f800d2,0xe664adf4,0x7bdc5f7a}},	// [2c5d0] kesé, _líjw, атхо, _inqu, 
   {{0x6b840639,0xfc3c00c6,0xe610e42d,0xd1e40023}},	//   _zeig, llí_, يشل_, ሜታት_, 
   {{0x62800204,0xd3b80220,0xfc3c011f,0x6b845acd}},	//   _awmo, еулі_, olí_, _yeig, 
   {{0x7bcd9f71,0xb5f99f72,0x6280003a,0x33700124}},	//   ndcu, _etáp, _bwmo, рҳар, 
   {{0x03b40046,0xe2a84732,0x7bdc009a,0xfc3c007b}},	//   ықты_, ناون_, _mnqu, ilí_, 
   {{0xdb1d9f73,0xfc3d9f74,0x00000000,0x00000000}},	//   gesé, hlí_, --, --, 
   {{0x5f18033f,0x7bdd0659,0xdb1c02e2,0x0d840131}},	//   _बेब्_, _onqu, sesè, ңлин, 
   {{0x816400f7,0xb3840133,0x68e8007c,0xfc3c01ef}},	//   _ۅپكۅ, _شێتم_, äddi, jlí_, 
   {{0xdbdc05a4,0xfc3c012c,0x241812c4,0xdb1c003e}},	//   _ráðs, dlí_, _роты_, besé, 
   {{0x6b84060a,0x7bdc5909,0x03140451,0x7bcc01f5}},	//   _seig, _anqu, _حڪمت_, edcu, 
   {{0x6b859f75,0x60c80204,0xdcf8054e,0x00000000}},	//   _peig, _gsdm, _revă, --, 
   {{0xf77c0205,0x8d740133,0x00000000,0x00000000}},	//   _koçu_, _ڵاتا, --, --, 
   {{0x6b8403b4,0x5f74d839,0x63a400a3,0xd0182c20}},	//   _veig, _ئامر, òini, miń_, 
   {{0x6b851d9a,0xbf3400c8,0x7bdd9f76,0xc330011a}},	//   _weig, _גאנץ_, _enqu, צום_, 
   {{0xfc3c0491,0x6b859f77,0x6ce401ec,0x00000000}},	//   blí_, _teig, _шіде, --, 
   {{0xfc3c00c6,0xd01800ee,0x6b840158,0xb5f99f78}},	//   clí_, niń_, _ueig, _quán, 
   {{0x46480b2b,0xeb98014b,0x00000000,0x00000000}},	// [2c5e0] езан_, _зиқ_, --, --, 
   {{0x8b8400db,0x05cc00c5,0x48e4009d,0x00000000}},	//   _جەڭە_, _होखब, _боов, --, 
   {{0xfff8023a,0x291c00c7,0x5f2400fe,0x5984004e}},	//   ääkö_, _äva_, _পৰাও_, _өлөб, 
   {{0xdb1c003e,0x066400f1,0x00000000,0x00000000}},	//   wesé, _ماسپ, --, --, 
   {{0xdb1d5ce3,0x75d800de,0xd0199f79,0x00000000}},	//   tesé, _bāzē, diń_, --, 
   {{0xb5f802f0,0xfc3c4e6f,0x00000000,0x00000000}},	//   _utáp, zlí_, --, --, 
   {{0xdb1c066d,0xf9900375,0xd01800a2,0x00000000}},	//   resé, זרו_, fiń_, --, 
   {{0xd36c2b62,0xd0199f7a,0x00000000,0x00000000}},	//   _قۇم_, giń_, --, --, 
   {{0xc3240111,0xdb1c003e,0x75d80171,0x03240108}},	//   _смак, pesé, _fāzē, _сдан, 
   {{0x3204038e,0x1e1402f4,0xb5f800c6,0x75d800de}},	//   chny_, рмоя, _nuál, _gāzē, 
   {{0xdb1d9f7b,0xfc3d5286,0x91f40208,0x00000000}},	//   ldsø, tlí_, _kín, --, 
   {{0xdb5434d8,0x81e402f5,0x00000000,0x00000000}},	//   ивны, _পতি_, --, --, 
   {{0x3f84003a,0xdb1c5f03,0x7bdc0393,0x7bcc0072}},	//   _ieou_, ndsø, _vnqu, rdcu, 
   {{0xb5f96355,0xfc3c0122,0x6be40220,0x91f40051}},	//   _cuál, slí_, _ۇكىم, _lín, 
   {{0x81e403d4,0xb5f80518,0xf84800c0,0xd7f40139}},	//   _পতা_, _duál, ечай_, азвы, 
   {{0x7bdd9f7c,0x3f84033b,0x3204007f,0x00000000}},	//   _unqu, _jeou_, zhny_, --, 
   {{0xa3e81533,0xb5f801e7,0x19942bb6,0x16140006}},	// [2c5f0] बान_, _fuál, _капя, адаў, 
   {{0x05946148,0x25b801ab,0xadc000c7,0x3de003d4}},	//   لامگ, _cbrl_, _osẽk, যসকল, 
   {{0x354401ce,0xdce800b8,0x00000000,0x00000000}},	//   ухав, dadī, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x91f40051,0xf77c03b9,0x00000000,0x00000000}},	//   _dín, _qoçu_, --, --, 
   {{0xdce8005f,0xd0187d19,0x00000000,0x00000000}},	//   gadī, wiń_, --, --, 
   {{0x09a80154,0x00000000,0x00000000,0x00000000}},	//   _ওসমা, --, --, --, 
   {{0x13a403e6,0xd018030a,0xc3c0009d,0x5f840116}},	//   _ڕۆڵی_, uiń_, _мөчл, مۇمە, 
   {{0xdba800d1,0x0e6400f0,0x00000000,0x00000000}},	//   _ﺋﯚﺯﻯ_, јкон, --, --, 
   {{0xfe4002bf,0x8d741f70,0x00000000,0x00000000}},	//   жньо, گاکا, --, --, 
   {{0x0c241086,0x61b00137,0x00000000,0x00000000}},	//   имон, _رەيا, --, --, 
   {{0x60dc0008,0x8d74e9cd,0x00000000,0x00000000}},	//   _árma, داکا, --, --, 
   {{0xd64c01ec,0x533400df,0x00000000,0x00000000}},	//   гiме, שאָב_, --, --, 
   {{0x64980084,0x2fcc0204,0x3f840036,0x9e94009f}},	//   ḓin, _hagg_, _zeou_, _اهوڪ, 
   {{0x2d84d7ce,0x3f84003a,0xa2cc1408,0x8b940798}},	//   _iene_, _yeou_, _दैन्, _крпч, 
   {{0x2d859f7d,0x2fcc0216,0x00000000,0x00000000}},	//   _hene_, _jagg_, --, --, 
   {{0x2d859f7e,0x2fcc1bce,0x458400f0,0x81bc00cc}},	// [2c600] _kene_, _magg_, игав, োত_, 
   {{0x2d859f7f,0x2fcccce0,0xe7b59f80,0x7bc808a5}},	//   _jene_, _lagg_, _گۅرد, _ógur, 
   {{0x399800c8,0xdce800da,0xb5f800e4,0xf77c00ac}},	//   _בייד, vadī, _guám, _poçt_, 
   {{0x68fd9f81,0xba3800db,0x3124010c,0x741009a6}},	//   myrd, nuïn, _ድንቁር, يولا, 
   {{0x2d844fa5,0xa3e804fa,0x3f859f82,0x41e0190c}},	//   _oene_, बाब_, _reou_, पालस, 
   {{0xefe01772,0x3f8404e6,0x68fc0076,0xdb0c0129}},	//   ሜናዊ_, _seou_, oyrd, éhér, 
   {{0xf9900302,0xdce80318,0x91f401fb,0xc0c8b7cf}},	//   קרה_, radī, _tín, туле_, 
   {{0x2d840270,0x3f84003a,0xa2340022,0x00000000}},	//   _aene_, _qeou_, шьҵә, --, 
   {{0x6fa40c2e,0x2fcc1bce,0xefb19f83,0xba38004e}},	//   _गारं, _dagg_, تینگ, duïn, 
   {{0x2d859f84,0x68fc06a3,0x3f8401c7,0xf77c010b}},	//   _cene_, kyrd, _weou_, _inçe_, 
   {{0x2d859f85,0xd5d804ac,0x6ca011ed,0x2fcc01f5}},	//   _dene_, אַרש, оряж, _fagg_, 
   {{0x44259f86,0x2d840d27,0xaca00241,0xcfa805af}},	//   nno_, _eene_, _gbọi, _ماهم_, 
   {{0x44259f87,0x2d859f88,0xe3d800cc,0x00000000}},	//   ino_, _fene_, _থকাব, --, 
   {{0xedd016cb,0x68fc03cb,0xfc640408,0x00000000}},	//   _ويند, fyrd, _къин, --, 
   {{0x44259f89,0x37a99f8a,0xb7f8482a,0xaa5c2080}},	//   kno_, ктан_, _एकदम_, терi, 
   {{0x44259f8b,0x2d84e7ab,0x46d017c6,0x69d801a8}},	//   jno_, _zene_, सिंह, _óven, 
   {{0x44250b2c,0x2d859f8c,0xdb20023a,0xdb0c0cad}},	// [2c610] dno_, _yene_, ötäi, _àkàn, 
   {{0x44259f8d,0x2d84056a,0xdb1c1686,0x00000000}},	//   eno_, _xene_, nesí, --, 
   {{0x44247e54,0x93449c3a,0x256c0248,0x00000000}},	//   fno_, әнле, _sòló_, --, 
   {{0x44259f8e,0xf7e800ae,0x00000000,0x00000000}},	//   gno_, _شرجى_, --, --, 
   {{0xf2c4fe20,0xdb1c01ed,0x2bac190c,0x2fcc058a}},	//   рсен, kesí, ट्टा, _ragg_, 
   {{0x07540375,0xca1800d1,0x00000000,0x00000000}},	//   _לסרט_, ﺰﻏﺎ_, --, --, 
   {{0x2fcc0395,0xf77c20a9,0x79940857,0x65941985}},	//   _pagg_, _ençe_, _mdxw, _фасу, 
   {{0x442408ad,0x0ea86c48,0x83500014,0x63a401c3}},	//   cno_, гкий_, _کھما, òint, 
   {{0xd1300f01,0x31c4415e,0xdb1c4e00,0x00000000}},	//   _کما_, _всев, hesâ, --, 
   {{0x2d84044e,0x2fcc00e8,0xdb1c01d3,0xec7400c7}},	//   _qene_, _wagg_, gesí, аҿк_, 
   {{0x2d859f8f,0x2fcc1bce,0x4b8800ee,0xf77c0139}},	//   _vene_, _tagg_, лйнн_, _znçe_, 
   {{0xc0b0001e,0x3dc80134,0x2d859f90,0x00000000}},	//   _lưới_, _ɔhwɛ_, _wene_, --, 
   {{0x2d859f91,0xcb000034,0x79940175,0xba399f92}},	//   _tene_, रैंड_, _bdxw, ruïn, 
   {{0x7f381a4c,0x7e941f84,0xdb1c0005,0x79940334}},	//   _גענו, _انور_, cesí, _cdxw, 
   {{0x44259f93,0x79940334,0xdee40023,0x00000000}},	//   yno_, _ddxw, _ዝኾኖ_, --, 
   {{0x44240067,0x00000000,0x00000000,0x00000000}},	//   xno_, --, --, --, 
   {{0xdee4067d,0x167001a9,0x00000000,0x00000000}},	// [2c620] _ዝኾነ_, мқўр, --, --, 
   {{0x4424068f,0xc0b00016,0x49c81836,0x537c0023}},	//   wno_, _cưới_, _слон_, _ብሂወት_, 
   {{0xc0b007ae,0xdb1c0356,0xe4980133,0x00000000}},	//   _dưới_, cesâ, شحاڵ_, --, 
   {{0x03a400d8,0x338000a7,0x020402dd,0xdb1c16d9}},	//   сидо, пушв, өзен, zesí, 
   {{0xdb1c01d3,0x00000000,0x00000000,0x00000000}},	//   yesí, --, --, --, 
   {{0xdee4069c,0x41e0068f,0x64a40046,0xbb180129}},	//   _ዝኾኑ_, पाइस, _қаға, maît, 
   {{0xa3e8534e,0xdb1cdfd4,0xa0341178,0xb978008f}},	//   बाद_, vesí, يىتت, אנצי, 
   {{0xbfa82bbd,0x44240067,0x00000000,0x00000000}},	//   утке_, qno_, --, --, 
   {{0xdb1c00dd,0x7f840372,0xac88001f,0xbb1806af}},	//   tesí, _ۇلان, _መሰለኝ_, naît, 
   {{0x9e1402bf,0xdb1c0022,0x00000000,0x00000000}},	//   ідні, hesã, --, --, 
   {{0x81449042,0xa2cc07d0,0xdb1c1de4,0x799403ac}},	//   _انان, _दैत्, resí, _rdxw, 
   {{0xdef80184,0xef0c00aa,0xbea40cc9,0x00000000}},	//   _ҡыҙ_, _ګټه_, _гадк, --, 
   {{0xdd95645d,0xdb1c00e5,0x00000000,0x00000000}},	//   _далы, pesí, --, --, 
   {{0x7f4001f0,0x69d8032e,0x00000000,0x00000000}},	//   _iyoq, _óvel, --, --, 
   {{0x19599f94,0x47d002f5,0xc0b00208,0xef340023}},	//   равы_, হানী, _rưới_, _ርትዓው, 
   {{0xdee402d3,0x58846518,0xdb1c0356,0x59ac00cd}},	//   _ዝኾና_, йыға, resâ, ञ्जर, 
   {{0x68e801e6,0xef480023,0xdb1c75ee,0x00000000}},	// [2c630] äddr, _ብትዕግ, ndsü, --, 
   {{0x8c380020,0x00000000,0x00000000,0x00000000}},	//   ደገለፁ, --, --, --, 
   {{0xdb1c00e8,0xa85401d5,0x3cfc0332,0x39440248}},	//   lesà, تکیچ, nytv_, _áns_, 
   {{0x95c80184,0x7f40036b,0x13a40133,0x78a4036e}},	//   ыуға_, _oyoq, تۆری_, mujv, 
   {{0xc0b001fb,0x934401e0,0x00000000,0x00000000}},	//   _tưới_, әнһе, --, --, 
   {{0xf1a41f5a,0xfafc0200,0x00000000,0x00000000}},	//   срдн, lcës_, --, --, 
   {{0xb5f99f95,0x92e809bd,0x7f419f96,0xc32c03e6}},	//   _otáz, মনে_, _ayoq, _یڕه_, 
   {{0xfafc044e,0x94040133,0x5334022e,0x4fa400d8}},	//   ncës_, _بوره, _дебт, циив, 
   {{0xb8e80dd4,0x78a40240,0xcb6801b9,0x8e080815}},	//   _ིར_, hujv, یمده_, инив_, 
   {{0xa1944712,0x78a402d3,0xc0b8001f,0x00000000}},	//   _науч, kujv, ዲህም_, --, 
   {{0x7f400117,0xb5f80332,0x00f80451,0x2b9400d7}},	//   _eyoq, _cuái, _پبلڪ_, júcí_, 
   {{0x80bc00fe,0xb5f801e7,0xcb0800ec,0x28d807af}},	//   ্মশ্, _duái, ليجن_, डिसि, 
   {{0xfc481427,0x9e701d00,0xdb1c00e4,0x81bc00eb}},	//   _smíð_, _كۇيت, vesã, োর_, 
   {{0xb5f80332,0x00000000,0x00000000,0x00000000}},	//   _fuái, --, --, --, 
   {{0xb5f800c7,0xdb1c0120,0x00000000,0x00000000}},	//   _guái, tesã, --, --, 
   {{0xd24400ec,0x37e0466e,0x00000000,0x00000000}},	//   _ڳچ_, мосг, --, --, 
   {{0x46e865c2,0x06e8409a,0x7c540691,0x6d400368}},	// [2c640] шдан_, шмак_, _بلير_, _hyna, 
   {{0xbb184aee,0xd2442ad5,0xdcf8012c,0x7af803fa}},	//   raît, _سچ_, _nevě, äute, 
   {{0x6d40010e,0xf4800023,0x47d000eb,0x00000000}},	//   _jyna, _ይቐርብ_, হাবী, --, 
   {{0x6d401090,0xdb1c0f91,0x46a421f3,0x37e0004e}},	//   _myna, lesá, _қаҳв, _жоюг, 
   {{0xf7719f97,0xeccc02f5,0x6d419f98,0x66848c9e}},	//   _تاپ_, িমিড, _lyna, _ریال, 
   {{0x6d404a98,0xdb0c0165,0xa3e80ebb,0xba380142}},	//   _oyna, _scaë, बाह_, orïa, 
   {{0x6d40005c,0xdcf800bc,0x661c02d0,0xa494411c}},	//   _nyna, _devě, _imrk, _ریشت, 
   {{0x78f8008f,0x0574129d,0x5f941d0f,0xc05801ec}},	//   יפצו, _داڭد, чиит, шіл_, 
   {{0x6d419f99,0x661c00b5,0xb5f801e7,0x2be400bc}},	//   _ayna, _kmrk, _suái, गाईं_, 
   {{0x6d419f9a,0x24680205,0x00000000,0x00000000}},	//   _byna, _eşme_, --, --, 
   {{0x6d40018b,0xdb1c012c,0x1bd41ab7,0x51f00451}},	//   _cyna, desá, поня, _سڳور, 
   {{0xf77d36ed,0x7ee400c6,0x00000000,0x00000000}},	//   _onça_, _وكان, --, --, 
   {{0x7f400c60,0xb4e400bc,0x00000000,0x00000000}},	//   _uyoq, _बप्_, --, --, 
   {{0x1fbc00bd,0x6d40015d,0x78a40240,0xb5f800ae}},	//   _অফিস, _fyna, tujv, _tuái, 
   {{0x6d401090,0xbea405d9,0xf77c00a2,0x7e9401d3}},	//   _gyna, _اهڙن_, _ança_, _انڈر_, 
   {{0x661c0009,0x9d5401d9,0x80a001ad,0x5fbc07f7}},	//   _amrk, _وچھت, _गिने, ्जिल, 
   {{0x35684afa,0xfafc0023,0x6d400432,0xf56801f4}},	// [2c650] арен_, rcës_, _zyna, ашек_, 
   {{0x64419f9b,0x78a40023,0x64580ba1,0xdb1c9965}},	//   _akmi, pujv, ïvin, cesá, 
   {{0xf77c0139,0x5fbc0404,0x78a40477,0xe56833d2}},	//   _ença_, ्जाल, qujv, زمنى_, 
   {{0xdcf80055,0xf65c005c,0x00000000,0x00000000}},	//   _advī, _spæd_, --, --, 
   {{0x63380023,0xdb0c01d3,0x91e400f5,0xa29400d4}},	//   _እናገበ, _abaú, золе, дачі, 
   {{0x64419f9c,0x00000000,0x00000000,0x00000000}},	//   _ekmi, --, --, --, 
   {{0xc5f09b62,0x644003a0,0xf8c807f7,0x10a41ebb}},	//   _אדם_, _fkmi, ाबिय, чийн, 
   {{0x4fe808b7,0xb40801c0,0xdcf80171,0x3cdc2677}},	//   смин_, _тэгж_, _edvī, गिने_, 
   {{0x6d419f9d,0xa3e822e3,0x3dc000d1,0xdb1c005c}},	//   _syna, बार_, ﯩﻴﯩﺘ, lesæ, 
   {{0x6d419f9e,0x200400d7,0x8e080395,0x00000000}},	//   _pyna, akmi_, снов_, --, 
   {{0x8c459f9f,0x5c740184,0xdb1c005c,0xcb6801b9}},	//   зене, үҙәр_, nesæ, یمگه_, 
   {{0x6d40a017,0xb5f800c7,0x9ac40327,0x00000000}},	//   _vyna, _guáv, koċċ, --, 
   {{0x6d40068f,0xdb1c1709,0x7c2c73a0,0x00000000}},	//   _wyna, tesá, ébra, --, 
   {{0xdb1c4c5d,0x2d80030a,0xde5800d4,0xba380142}},	//   kesæ, ñjed_, _дачі_, trïa, 
   {{0xdb1d9fa0,0x6d419fa1,0x957c0023,0x00000000}},	//   resá, _uyna, ሕንትን_, --, 
   {{0xf1c40122,0x661d01dd,0xdb1c005c,0x4b8801d5}},	//   _hráč_, _smrk, desæ, _уйин_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [2c660] --, --, --, --, 
   {{0x55c402dd,0x00000000,0x00000000,0x00000000}},	//   мауғ, --, --, --, 
   {{0xdb1c0b1a,0x83c59fa2,0x454400c6,0x3cdc0037}},	//   gesæ, збеж, أناق, गिये_, 
   {{0x9ac4025c,0x00000000,0x00000000,0x00000000}},	//   boċċ, --, --, --, 
   {{0xe1f808ca,0x00000000,0x00000000,0x00000000}},	//   оҳа_, --, --, --, 
   {{0xdb1c005c,0xd04006be,0xe694014b,0x00000000}},	//   besæ, _islə, _нуҳӯ, --, 
   {{0xc4c8003d,0x054401d5,0x00000000,0x00000000}},	//   _ྋརྒྱ, _رئسپ, --, --, 
   {{0x644002d0,0xde7800d4,0xdc780092,0x00000000}},	//   _ukmi, обич_, _የሰማይ_, --, 
   {{0x2c1000dc,0x52b000db,0x6d44000d,0x00000000}},	//   ासनं_, _لەنئ, üjan, --, 
   {{0xdd919fa3,0xdcf800b8,0x629c0335,0x00000000}},	//   خود_, _udvī, _āroh, --, 
   {{0x61e96f93,0x10f000f1,0x6d44025c,0x00000000}},	//   _indl, _لګيد, żjan, --, 
   {{0x77f80073,0xca3801ec,0x00000000,0x00000000}},	//   _एकेक_, _ﺒﺭﺍ_, --, --, 
   {{0x319c005f,0xa3b401ad,0x3e0402e8,0xcee801f7}},	//   bāzē_, _ञान_, _някв, _ورهن_, 
   {{0xaa646fbd,0xcf24511e,0x18045ca7,0x5fbc07f7}},	//   етск, _ترمي, रस्व_, ्जवल, 
   {{0x87780521,0xf8043acc,0x00000000,0x00000000}},	//   _ọwụw, пчан, --, --, 
   {{0x64981682,0xdb1c00b5,0x7b64717e,0x9b941d10}},	//   ḽiw, vesæ, _этке, _کلکت, 
   {{0x61e99fa4,0x5bc81a22,0xfc3c00e4,0x2bb800ae}},	// [2c670] _ondl, िजीव, moí_, _راية_, 
   {{0x3e702a18,0x1a6403e6,0x35680354,0xe6980131}},	//   _mât_, _زیزی_, сран_, явуш_, 
   {{0x76440014,0x9ac40327,0xa3e8134e,0x00000000}},	//   _ہیرِ_, soċċ, बां_, --, 
   {{0x61e99fa5,0xdb1c00b5,0x4cb0009e,0xdebc0023}},	//   _andl, resæ, _জনমু, ዲእና_, 
   {{0xe3b04111,0xd2a80046,0x249801f5,0xefcc02d3}},	//   ارم_, ікке_, _evrm_, እታዊ_, 
   {{0x74693566,0x0cac0241,0xda0c00bc,0x7ddc0205}},	//   _грав_, _jiṣẹ_, हसित_, nçsı, 
   {{0xdb1c007c,0x00000000,0x00000000,0x00000000}},	//   lesä, --, --, --, 
   {{0x62840311,0x61e99fa6,0x3e7103cf,0xa3d4034b}},	//   ţioa, _endl, _bât_, _посч, 
   {{0x3e7000a8,0x722000cf,0xdb1c3167,0x2ba4000d}},	//   _cât_, _كورۅ, nesä, _खएबा, 
   {{0x3e700036,0x0d20004e,0xa0800150,0x00000000}},	//   _dât_, күлү, _өңше, --, 
   {{0x8ba47125,0x69d802d2,0x00000000,0x00000000}},	//   минж, _óvei, --, --, 
   {{0xdb1c023a,0xba380142,0xdf5890b2,0x00000000}},	//   kesä, frïo, _کشمش_, --, 
   {{0x61e81fcd,0x3e719fa7,0x357c0023,0xddc803e0}},	//   _yndl, _gât_, ብኦታት_, _çoşk, 
   {{0xdb1c01f4,0x00000000,0x00000000,0x00000000}},	//   desä, --, --, --, 
   {{0xdb0c0022,0x00000000,0x00000000,0x00000000}},	//   ĩhár, --, --, --, 
   {{0x7b0401ed,0xc8481cb8,0xcc340b24,0xfbc0014b}},	//   örté, іпаж_, _ترتع, _абъо, 
   {{0xdb1c0d16,0x4b2400d4,0xed4c00e5,0xd90c0d23}},	// [2c680] gesä, _імов, _جھک_, لیی_, 
   {{0xdbdc0ca8,0x24682791,0x35a00139,0x00000000}},	//   _láìs, _aşma_, кауг, --, 
   {{0x61e804fb,0x1b44001f,0xd7c8004b,0xfc159fa8}},	//   _rndl, _ማስተካ, _کوټه_, _رقیب_, 
   {{0x95740724,0x032402dd,0xdb1c007c,0x00000000}},	//   _җырч, мден, besä, --, 
   {{0x066000c7,0x00000000,0x00000000,0x00000000}},	//   _аҵаҟ, --, --, --, 
   {{0x64981682,0x134002d3,0x3e700208,0x00000000}},	//   ḓiv, _ንናጽነ, _rât_, --, 
   {{0x6d4400c5,0xd12c0372,0x00000000,0x00000000}},	//   üjal, مۅك_, --, --, 
   {{0xac7c0020,0xf8b00302,0x00000000,0x00000000}},	//   _የሰላም_, דשה_, --, --, 
   {{0xf65c019b,0xdbdc01e1,0xdd9406d3,0x67005219}},	//   _især_, _dáìs, напы, ोनिक_, 
   {{0x61e80e05,0xdb1c0158,0x6d4c012d,0x3e700051}},	//   _undl, neså, ęcan, _vât_, 
   {{0xb5f800c7,0xdb0c0241,0x00000000,0x00000000}},	//   _kuár, _àkún, --, --, 
   {{0xb5f99fa9,0xefcc044e,0x3e700208,0x0cac01e1}},	//   _juár, እታው_, _tât_, _siṣẹ_, 
   {{0xfc3c00c6,0x2b44009d,0xbf159faa,0x00000000}},	//   roí_, вэрг, _توشب, --, 
   {{0x58d4009d,0xdb1c01e3,0x00000000,0x00000000}},	//   ногт, vesä, --, --, 
   {{0x3a219fab,0xdb1c0036,0x80bc0011,0xcee800f7}},	//   rijp_, wesä, ্মক্, _ورۇن_, 
   {{0x7b6417a2,0xdb1c0108,0x00000000,0x00000000}},	//   _отпе, tesä, --, --, 
   {{0xa3e80b03,0x3a2001f5,0x70d8000d,0xcac4030d}},	// [2c690] बाई_, pijp_, _मछ्ल, _пӳре_, 
   {{0x58d4ee9d,0x19580022,0xdb1c17b8,0x151443a2}},	//   _зоот, _напы_, geså, ндзя, 
   {{0xdb1d9fac,0x5f1403d4,0x7c2c0332,0x00000000}},	//   sesä, াপিও_, oncr, --, 
   {{0x628400da,0xdcf800f3,0xdb1c005b,0x00000000}},	//   ģion, _jevđ, pesä, --, 
   {{0x62840262,0x7c2d9fad,0x8cd40118,0x00000000}},	//   ţion, incr, _बनभो, --, 
   {{0xb9e4044e,0xe1f802dd,0x7c2c002f,0xa564075e}},	//   _ክአ_, мгі_, hncr, ردەن, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4dc4040d,0xdb0c0005,0xb5f88107,0xdb1c0037}},	//   ﯩﺴﯩﻨ, _acaí, _guár, ldsõ, 
   {{0x0e659fae,0xcf4401c0,0x2468013d,0x00000000}},	//   нкин, эний, _uşma_, --, 
   {{0x272c01dc,0x4c8407d6,0xdb0c0248,0xf69801ec}},	//   ếng_, нлов, _àkùn, _ﺟﻪﻟﭙ, 
   {{0x22940241,0x00000000,0x00000000,0x00000000}},	//   _túká_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x1e843981,0x260005c0,0x00000000,0x00000000}},	//   _алім, _शकली_, --, --, 
   {{0xdb4000c7,0x00000000,0x00000000,0x00000000}},	//   рҕьо, --, --, --, 
   {{0xdb1c005c,0x2f1000d1,0x00000000,0x00000000}},	//   veså, _سېھر, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb6a001d5,0xfc54011a,0x00000000,0x00000000}},	// [2c6a0] литл, _אבקש_, --, --, 
   {{0xb5f8e7f0,0x45355de0,0x00000000,0x00000000}},	//   _suár, нхет, --, --, 
   {{0x69dd9faf,0x7af8332c,0x00000000,0x00000000}},	//   mdre, øutv, --, --, 
   {{0x69dd9fb0,0x07a405f5,0x05200023,0xdb1c007c}},	//   ldre, _яамн, _ተኸልኪ, rdsö, 
   {{0xe0bc02f5,0xb38001c0,0x291805d5,0x69dc030a}},	//   _আছেন, улчл, lzra_, odre, 
   {{0x69dd9fb1,0x00000000,0x00000000,0x00000000}},	//   ndre, --, --, --, 
   {{0x69dd9fb2,0x03a59fb3,0x7c2d9fb4,0x30a0023a}},	//   idre, _пиво, yncr, грыв, 
   {{0x69dd9fb5,0xdb0c010e,0x00000000,0x00000000}},	//   hdre, _abaý, --, --, 
   {{0xb5f80124,0x69dc020c,0xdd900131,0xc1e001af}},	//   _kuáp, kdre, لۈش_, _бөйҙ, 
   {{0xba39699e,0xa3e8a432,0x69dc0d27,0x6280014f}},	//   nuït, बाक_, jdre, _itmo, 
   {{0x69dd9fb6,0x44259fb7,0x00000000,0x00000000}},	//   ddre, oio_, --, --, 
   {{0x69dd9fb8,0x8cb00034,0x628000b5,0x69c000e5}},	//   edre, _अमरो, _ktmo, őmel, 
   {{0x69dd77c2,0x2918014b,0xcfa803e6,0x4424003a}},	//   fdre, ezra_, _زانم_, iio_, 
   {{0x19594204,0x64980943,0x69dd9fb9,0x7c2c007f}},	//   дагы_, ṋis, gdre, sncr, 
   {{0x44259fba,0xba380137,0xa9340220,0x63a001ef}},	//   kio_, duït, герш, _odmn, 
   {{0x69dc6d2c,0x67d59fbb,0x7e68003a,0xd7c88863}},	//   adre, лосу, _hifp, بوره_, 
   {{0x7bcd9fbc,0x44242f7f,0xb5a4859f,0x27380108}},	// [2c6b0] mecu, dio_, ерей, езть_, 
   {{0x44240295,0xba3806af,0x00000000,0x00000000}},	//   eio_, guït, --, --, 
   {{0x44259fbd,0xdcf800da,0x64980943,0xe5c45e91}},	//   fio_, _ievē, ḓis, ысто, 
   {{0x7bcd9fbe,0xdb1c00db,0x6280045a,0xeaa00241}},	//   necu, desú, _btmo, _ìṣe_, 
   {{0x60c802d0,0xba3800cf,0x5920010b,0x1dd0095f}},	//   _apdm, buït, _сүңң, तजात, 
   {{0xc69004ac,0x44259fbf,0xb5f800c7,0x10a40e92}},	//   _דאך_, aio_, _guáp, викн, 
   {{0x7bcc015c,0x628007d6,0xc0d01d57,0xba38067c}},	//   kecu, _etmo, ليوب, luïs, 
   {{0x80a00b7d,0x69dc01ef,0xc0c00304,0x00000000}},	//   _गिरे, zdre, рәфи, --, 
   {{0x69dd078a,0x7bcc3247,0x6d4c033f,0x291805d5}},	//   ydre, decu, ęcam, zzra_, 
   {{0xdcf8005f,0xe2c80c4f,0x69dc007c,0x60cc00e4}},	//   _nevē, _سومو_, xdre, ñomí, 
   {{0xa0c44d49,0x7e68003a,0xdb0c0037,0x7bcc164b}},	//   _ميلو, _difp, _ebaü, fecu, 
   {{0x09c84c83,0x7bcc00b0,0x291804cc,0x00000000}},	//   ाज्य, gecu, vzra_, --, 
   {{0x5b34084c,0x7fb4007b,0xb0a4000d,0x00000000}},	//   гэру, _شهور_, _गिडग, --, 
   {{0x44259fc0,0xbea1132c,0x7e68017a,0xba38004e}},	//   zio_, _ташк, _gifp, duïs, 
   {{0x69dd9fc1,0x290d1a6d,0x7bcd9fc2,0xdcf8005f}},	//   rdre, áda_, becu, _devē, 
   {{0x44259fc3,0x38699fc4,0x764400ca,0x69dd9fc5}},	//   xio_, _cicr_, _akjy, sdre, 
   {{0xba399fc6,0x69dc168c,0x291801d3,0x68240b82}},	// [2c6c0] tuït, pdre, szra_, _ተወለድ, 
   {{0x442400a9,0x63a0003e,0xdb1002d2,0x00000000}},	//   wio_, _sdmn, _ófái, --, 
   {{0x442426c2,0x2d64013f,0x07a400c7,0xba3800db}},	//   tio_, nɑe_, _ианн, ruït, 
   {{0x03a41ee3,0x62800334,0xba3800db,0x44240381}},	//   тидо, _ptmo, suït, uio_, 
   {{0xb6a00139,0xc2b40114,0xb37c0023,0x00000000}},	//   _киял, тљењ, ዕትዮን_, --, 
   {{0x44259fc7,0xa15942e5,0xa2499fc8,0x2d64013f}},	//   sio_, налу_, ریال_, kɑe_, 
   {{0x7bcc0b6f,0x31840150,0x0444022e,0x00000000}},	//   yecu, ттің, _аевн, --, 
   {{0x7bcc5f24,0x44240481,0x9ed800d1,0x2d800165}},	//   xecu, qio_, емит_, ñjen_, 
   {{0x62819fc9,0x8ff400db,0x00000000,0x00000000}},	//   _utmo, ازىچ, --, --, 
   {{0xdb2416d9,0xf48400e5,0x00000000,0x00000000}},	//   ásít, _ساہی, --, --, 
   {{0xdb1c2b96,0xdbdc0248,0x9b9450b1,0x00000000}},	//   lesø, _páàs, линц, --, 
   {{0xa3e802f8,0x3ea40588,0xc00468d9,0xa2b800dc}},	//   बाट_, _аидг, _шпек, ोऽप्, 
   {{0x7bcd9fca,0xdb1c1455,0xba38004e,0x00000000}},	//   recu, nesø, duïr, --, 
   {{0x38680368,0xfca84028,0x9e341064,0x0f3000f2}},	//   _sicr_, _قابو_, _щелч, _چکید, 
   {{0xada00e92,0xad2007d2,0xcda8010f,0x6da01d39}},	//   _тајл, _پىيى, _װיפֿ, _тија, 
   {{0x7bcc0113,0x3d0c3996,0xba383ab0,0xdb1c03cd}},	//   qecu, ानीं_, tuïs, kesø, 
   {{0x67d40228,0xdb1c2d8b,0x79a4013d,0x48c00022}},	// [2c6d0] шоту, jesø, _ирне, _қәра, 
   {{0xa2b800dc,0xdb1c0ec3,0x00000000,0x00000000}},	//   ोऽन्, desø, --, --, 
   {{0xd371920b,0xdb0d9fcb,0xe6659fcc,0xd17402dd}},	//   مها_, _ibañ, ртто, қылы, 
   {{0xfbdc145e,0x68e800b5,0x69d81d1d,0x6d44000d}},	//   ndê_, ædde, _óver, üjai, 
   {{0xa3e852be,0xd1c80408,0x768401ec,0x00000000}},	//   बाज_, елле_, _шынж, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb0c0de2,0x74f401ed,0x00000000,0x00000000}},	//   _mbañ, _جہاز_, --, --, 
   {{0xdb1c5b47,0xe5340b87,0xd4980408,0x00000000}},	//   besø, _тесь, ăрĕ_, --, 
   {{0x533400d8,0x00000000,0x00000000,0x00000000}},	//   _сеат, --, --, --, 
   {{0x2d64016b,0xfe6c036b,0xa2cc012d,0x00000000}},	//   tɑe_, سگه_, _दैट्, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf65c022c,0x00000000,0x00000000,0x00000000}},	//   _spæl_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x0c25682a,0x6f180036,0x2fdc0162,0x30c400d1}},	//   _әмин, mzuc, ldug_, ﯩﮕﻪﻧ, 
   {{0x07a42826,0xc7a41a21,0x6f195c9c,0x3e3000f1}},	//   лавн, ливк, lzuc, _دفور, 
   {{0x649806d6,0x2fdd9fcd,0x00000000,0x00000000}},	//   ḓip, ndug_, --, --, 
   {{0x6f181196,0x00000000,0x00000000,0x00000000}},	// [2c6e0] nzuc, --, --, --, 
   {{0xdb1c4606,0x684400d1,0x7d0c01bf,0x84700023}},	//   vesø, унға, øbsg, _ብኣማን_, 
   {{0x75d000c6,0x6f181196,0x00000000,0x00000000}},	//   إيما, hzuc, --, --, 
   {{0xaaa80825,0xdb1c0158,0x6f1801f5,0x06cc00fe}},	//   _कटाक, tesø, kzuc, ৰমবি, 
   {{0x27e19fce,0xdb0c0589,0x2fdc0694,0x00000000}},	//   mdin_, _ybañ, ddug_, --, 
   {{0x27e19fcf,0xa3e40c66,0xdb1c1477,0x26c19fd0}},	//   ldin_, _भोर_, resø, mtio_, 
   {{0x27e19fd1,0x26c19fd2,0xdb1c072b,0xc76400d1}},	//   odin_, ltio_, sesø, _جاھى, 
   {{0x2fdd9fd3,0x6f180112,0x26c0003a,0x14584660}},	//   gdug_, fzuc, otio_, _ашуы_, 
   {{0x26c19fd4,0x27e19fd5,0x1e152043,0x60e002d5}},	//   ntio_, idin_, имия, _žymė, 
   {{0x0c78001f,0x27e002f6,0x7c859fd6,0x26c02bd6}},	//   _አደሮች_, hdin_, луме, itio_, 
   {{0x3d0c0034,0x27e00369,0x05c51f20,0xbf1001e0}},	//   ानें_, kdin_, र्यब, рүҙә, 
   {{0x6f1801f5,0x26c0023a,0x27e0036e,0x3154008f}},	//   bzuc, ktio_, jdin_, _גיבן_, 
   {{0x1dc40598,0x6f180034,0xfbdc00d8,0x26c00115}},	//   _көнн, czuc, rdê_, jtio_, 
   {{0x394448a1,0x27e08200,0x998407d6,0xd9140022}},	//   _ønsk_, edin_, شلرو, адгы, 
   {{0x7d08000f,0x27e00009,0x26c00142,0x00000000}},	//   _dêrú, fdin_, etio_, --, 
   {{0x6c800597,0x27e09b7b,0xf770fb2e,0x26c00042}},	//   _اليم, gdin_, صار_, ftio_, 
   {{0x7bdc011c,0x2b44009d,0xe784490c,0xeb9800f3}},	// [2c6f0] _iaqu, _гээг, сусо, _сињ_, 
   {{0x27e19fd7,0x7bdc0ba7,0x629c00cd,0x00000000}},	//   adin_, _haqu, _ārop, --, 
   {{0x26c19fd8,0x6f18c7cc,0x799402d0,0x7bdce0a3}},	//   atio_, zzuc, _iexw, _kaqu, 
   {{0x7bdd9fd9,0xbd940020,0xe4a401c0,0x6f18002f}},	//   _jaqu, _መጠቀም_, ёрхо, yzuc, 
   {{0x26c19fda,0x0cd00882,0xf6500451,0x00000000}},	//   ctio_, _तन्म, _هئس_, --, 
   {{0x7bdd9fdb,0x91041d0f,0x50d41291,0xf4940472}},	//   _laqu, ипле, لزبر, _مشرد, 
   {{0x3d0c0034,0xe4e402bf,0x0f0c08f2,0xe568014b}},	//   ानों_, _літн, िन्स_, _биёд_, 
   {{0x7bdd9fdc,0xa92802fb,0x6f181196,0x7994002f}},	//   _naqu, loží, tzuc, _lexw, 
   {{0xf1a49f59,0xcdf48fd9,0x24180220,0x2d500ca8}},	//   _брен, ачны, _соты_, _ṣe_, 
   {{0x27e19fdd,0x7bdc011f,0x6f180034,0x799400d8}},	//   zdin_, _aaqu, rzuc, _nexw, 
   {{0x27e19fde,0xd1300597,0x51840139,0x6f1802c1}},	//   ydin_, _بما_, _буҗа, szuc, 
   {{0x27e00014,0xd04000ec,0x00000000,0x00000000}},	//   xdin_, _گھڙي, --, --, 
   {{0x7bdd9fdf,0x63a4007b,0x26c19fe0,0x27e19fe1}},	//   _daqu, óini, xtio_, vdin_, 
   {{0xc3300d65,0x7bdd5694,0x245d9fe2,0xb6040135}},	//   קום_, _eaqu, míme_, _jaġġ, 
   {{0x245c0122,0x27e12da7,0x7bdd9fe3,0x26c00368}},	//   líme_, tdin_, _faqu, wtio_, 
   {{0x7d08002d,0x26c19fe4,0xb604031c,0xf1c0031c}},	//   _wêrú, ttio_, _laġġ, laġġ_, 
   {{0x245c0588,0x27e19fe5,0x26c0003a,0x7c2c0129}},	// [2c700] níme_, rdin_, utio_, èbre, 
   {{0x26c19fe6,0x7bdc0083,0xb604031c,0x45d406ed}},	//   rtio_, _zaqu, _naġġ, јцат, 
   {{0x7bdd9fe7,0xd6c401b9,0xdcf80064,0x0b900240}},	//   _yaqu, _қирқ, _devė, _ጀንዳይ_, 
   {{0x26c19fe8,0x7bdd9fe9,0x27e19fea,0x4de000cc}},	//   ptio_, _xaqu, qdin_, _পকোৱ, 
   {{0x245c0122,0xa2b800dc,0xa3e400dc,0x733000d1}},	//   jíme_, ोऽध्, _भोः_, يىما, 
   {{0x245c2195,0xbbd0c853,0x7af80112,0xf1c00327}},	//   díme_, _तस्क, äuti, jaġġ_, 
   {{0x05c40574,0x03f403e6,0xf990011a,0x00000000}},	//   र्णब, _پژاک_, חרו_, --, 
   {{0x3ec40006,0xb0a411d7,0x92b400fe,0x00000000}},	//   асоб, _गिरग, _জনৰ_, --, 
   {{0x7bdd9feb,0x0f2c02d3,0xa6300092,0x00000000}},	//   _raqu, _እትርከ, _ተረድተ, --, 
   {{0xb604025c,0x6a600112,0x47d00183,0xaf30515c}},	//   _gaġġ, löff, হাটী, ترىت, 
   {{0xf65c01bf,0x00000000,0x00000000,0x00000000}},	//   _spæk_, --, --, --, 
   {{0x799488e0,0x7bdc0eda,0x245c0122,0x6a600112}},	//   _sexw, _qaqu, bíme_, nöff, 
   {{0x7bdd9fec,0x1f5401ec,0x245c0f57,0x7d0c01bf}},	//   _vaqu, _اعاڭ, címe_, øbsb, 
   {{0x7bdd9fed,0x5d8400c6,0x6a60002f,0x95780092}},	//   _waqu, _الغل, höff, ርቦትን_, 
   {{0x9e8403e6,0x6d440037,0x224c0254,0xf770007b}},	//   _ئاڵۆ, üjat, _mkdk_, قاذ_, 
   {{0x20d80016,0xec680153,0x960007af,0x00000000}},	//   _mũi_, _крык_, ोस्ट_, --, 
   {{0xdb1c0309,0x20d80051,0x2bdc0073,0x0b1800ec}},	// [2c710] äyän, _lũi_, _बसता, _ٽريڊ_, 
   {{0x79a40c56,0x06b801d9,0xab6800ef,0x06a802dd}},	//   _трие, انٕک_, _diļļ, _ﺷﻪﺷﻪ, 
   {{0x245c0316,0x3568cb13,0xb604025c,0xdb1c000d}},	//   zíme_, тран_, _raġġ, hesü, 
   {{0xb6040327,0xb3800240,0x00000000,0x00000000}},	//   _saġġ, _ይበዝሕ_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x245c0232,0xdb1c000d,0x00000000,0x00000000}},	//   víme_, desü, --, --, 
   {{0x224c0810,0x601c002e,0x20d8004d,0x8fa400d1}},	//   _dkdk_, _mémf, _cũi_, байе, 
   {{0x29380302,0x245c0122,0xdb1c01b8,0x92b400cc}},	//   יאון_, tíme_, fesü, _জনী_, 
   {{0xb6040135,0xdb1c002f,0xf1c00003,0x638001a9}},	//   _taġġ, gesü, taġġ_, _ўҳша, 
   {{0x245c01f1,0x128800f1,0xfe4000d4,0x00000000}},	//   ríme_, _لمړی_, зньо, --, 
   {{0x4c681d1c,0x245c04bf,0x20d801fb,0xf1c00003}},	//   лион_, síme_, _gũi_, raġġ_, 
   {{0x245c02fb,0xf1c00327,0xdb1ca40b,0x00000000}},	//   píme_, saġġ_, besü, --, 
   {{0x8e859fee,0x4808013e,0xf1c0025c,0x00000000}},	//   _угле, қеан_, paġġ_, --, 
   {{0xf98079a4,0x31480023,0xa9680131,0x7d0c005c}},	//   згро, _ምንታይ, ғиға_, øbsc, 
   {{0xfbdc0261,0x00000000,0x00000000,0x00000000}},	//   glês_, --, --, --, 
   {{0x7b040240,0xc0e80092,0x6d440135,0x00000000}},	//   ërtë, _ሆነህ_, żjas, --, 
   {{0x6b859fef,0x46e90c65,0x3f7800c8,0x1cb40327}},	// [2c720] _ifig, ыдан_, אָבע, _ཝའོ_, 
   {{0xa2b80882,0x49943252,0xba2000db,0x00000000}},	//   ोऽस्, _ушит, _ндык, --, 
   {{0xd1c000b7,0xbb4c001f,0xda64009a,0xe794072d}},	//   ጻናት_, _ማስተላ, _بايي, _واحک, 
   {{0xaee01682,0x6aa403d4,0xbb18025a,0xdb1c179a}},	//   hiṱo, _kvif, mbîr, yesü, 
   {{0x6a600639,0xe2f843e1,0x00000000,0x00000000}},	//   röff, релі_, --, --, 
   {{0x224c03b9,0x6a60002f,0x461406c5,0x00000000}},	//   _qkdk_, söff, _اوسر, --, 
   {{0xdb1c007f,0x00000000,0x00000000,0x00000000}},	//   nesò, --, --, --, 
   {{0x6aa4003a,0xdb1c01ed,0x9ee8007b,0x827400ec}},	//   _ovif, tesü, لفعل_, _هٿرا, 
   {{0x7de40220,0x224c0205,0x00000000,0x00000000}},	//   бінд, _tkdk_, --, --, 
   {{0x6b859ff0,0x6ce083e3,0x733002dd,0xdb1d9ff1}},	//   _afig, गिंग_, _عىلا, resü, 
   {{0x2fd40e53,0x9bd40d30,0xdb1c0ef5,0xe0d80131}},	//   _گوند_, ожні, sesü, _әвҗ_, 
   {{0xf77c0200,0xd0e428d4,0x6ed0228d,0x806400ea}},	//   _kaçe_, किरण_, _बैकु, _увеж, 
   {{0xf77c036e,0x6cc001d9,0x290c0162,0x00000000}},	//   _jaçe_, _ہٲوٕ, ødan_, --, 
   {{0x6b859ff2,0xe0440166,0x00000000,0x00000000}},	//   _efig, _унҗи, --, --, 
   {{0xe9b400fd,0x6b840368,0xddc80122,0xe9180212}},	//   ябрь, _ffig, vodň, борі_, 
   {{0x5694036b,0xfbdc002d,0x00000000,0x00000000}},	//   жаат, rlês_, --, --, 
   {{0x998000b0,0xdb1d9ff3,0xf77c0432,0x768400c7}},	// [2c730] _hohō_, resó, _naçe_, сыбж, 
   {{0x69c800c5,0x58d4004e,0xdcf80171,0xda0c0037}},	//   õdet, _доот, _nevī, _सकित_, 
   {{0x9378554f,0x6aa40433,0x00000000,0x00000000}},	//   абет_, _zvif, --, --, 
   {{0xe3b004d3,0x7c2c0005,0xe3cc015b,0xf77c0200}},	//   فره_, nicr, _রোবব, _baçe_, 
   {{0xf2c4994d,0xe1f012fd,0x00000000,0x00000000}},	//   ссен, کسن_, --, --, 
   {{0x69c0016b,0x7c2c003a,0xc5ec00f1,0x00000000}},	//   ɑmes, hicr, _لړم_, --, 
   {{0xdcf80aed,0x50b4177b,0x6595114e,0xa3e40892}},	//   _devī, іску, _хасу, _भोक_, 
   {{0x8e8531e4,0x63a40124,0x0ea80ce1,0x00000000}},	//   огие, óint, акий_, --, 
   {{0x7c2d9ff4,0xf77c0023,0x6b840327,0x15fc000d}},	//   dicr, _gaçe_, _rfig, _उचार_, 
   {{0x6b84f518,0xd0d40801,0xdce80790,0x4e283a49}},	//   _sfig, _мозъ, çoğl, роон_, 
   {{0x63a411c3,0x6aa59ff5,0x6a60002f,0x30a40354}},	//   ðing, _svif, nöfe, _ырав, 
   {{0x597407dd,0x09b00490,0x8fd00022,0x7c2c02d0}},	//   ҧысу, जल्य, _цәкә, gicr, 
   {{0x6a600112,0x37bc0154,0x9c7c033b,0x245c02f0}},	//   höfe, উজার, nvčj, níma_, 
   {{0xe81c000b,0xba380042,0x3d2802f2,0x6e640395}},	//   नसभा_, tsïa, اتیی_, _утеж, 
   {{0x6b84031c,0x8e84009f,0x00000000,0x00000000}},	//   _tfig, _الڪه, --, --, 
   {{0x245c00e4,0x00000000,0x00000000,0x00000000}},	//   kíma_, --, --, --, 
   {{0xc764278f,0x245c01f1,0xa3e4121d,0xc60401ee}},	// [2c740] زارى, jíma_, _भोग_, озай, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x601d9ff6,0x81e0009e,0xdcf800e2,0x290c007c}},	//   _héme, ধাম_, _revī, ädad_, 
   {{0xe2840220,0x04483740,0x00000000,0x00000000}},	//   зған, шпек_, --, --, 
   {{0x6aa80c2e,0xfc48032e,0xa2940006,0x00000000}},	//   _कटोर, _hlíð_, чалі, --, 
   {{0x601d9ff7,0x7c2c0fac,0xd04003b9,0xf77c036e}},	//   _méme, zicr, _iplə, _vaçe_, 
   {{0x601c002e,0x61140212,0xb114007b,0x63a40332}},	//   _léme, ядку, يقها_, óins, 
   {{0x63a45573,0x42d400c0,0x4614009f,0x00000000}},	//   ðind, _мізу, _اوڳر, --, 
   {{0x601c00dd,0xdb1c0022,0x245c01ef,0x00000000}},	//   _néme, yesñ, címa_, --, 
   {{0x324001ec,0xbd681fdc,0xdce800d7,0x00000000}},	//   _жеуг, ирне_, radľ, --, 
   {{0xdef80046,0x601c003e,0xdd9003e6,0x5d542bbe}},	//   рық_, _pémd, ووک_, якот, 
   {{0x9f440200,0x00000000,0x00000000,0x00000000}},	//   ndmë_, --, --, --, 
   {{0x10680597,0x3f840421,0x60280210,0x00000000}},	//   _احلى_, _ifou_, jśmi, --, 
   {{0x3ea401fa,0x7c2c2e93,0x601c07ea,0x7f400327}},	//   _ivot_, sicr, _déme, _ixoq, 
   {{0x1cb4025c,0xf804cbc7,0x19580006,0x00000000}},	//   _ཝའི_, очан, савы_, --, 
   {{0x601d9914,0x3ea59ff8,0x7790179e,0x7c6406c2}},	//   _hémb, _kvot_, بیحا, _باتل, 
   {{0x601c2056,0x4ab0000d,0x00000000,0x00000000}},	// [2c750] _géme, _जियव, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x601c032b,0x89d8011a,0x00000000,0x00000000}},	//   _mémb, _החתי, --, --, 
   {{0x601d9ff9,0x245c0008,0x527400d8,0x00000000}},	//   _yéme, tíma_, пуку, --, 
   {{0x24599ffa,0x00000000,0x00000000,0x00000000}},	//   цаць_, --, --, --, 
   {{0x3f840607,0x601c0438,0x86780375,0xfec0009e}},	//   _afou_, _némb, _לרשו, ্টাধ, 
   {{0xe4a59ffb,0x3ea40108,0xfbd808ec,0x00000000}},	//   _орто, _avot_, यजाम, --, 
   {{0x20540026,0x00000000,0x00000000,0x00000000}},	//   мтыр, --, --, --, 
   {{0x3b7c0020,0x3ea4003e,0xa3e410fa,0x00000000}},	//   _ቦታዎች_, _cvot_, _भोट_, --, 
   {{0x601c00d2,0x2c0800fe,0xe1f000f1,0x00000000}},	//   _cémb, _লগেই_, _لسم_, --, 
   {{0x62240075,0x601c00e8,0x8c48008e,0x00000000}},	//   _تىلل, _démb, йпов_, --, 
   {{0xbb180356,0x7e9400e5,0x0a440092,0x00000000}},	//   rcîn, _کنور_, _ያብራራ, --, 
   {{0x7aa000d1,0x8e840354,0x00000000,0x00000000}},	//   нияз, _эгле, --, --, 
   {{0x601c0098,0x00000000,0x00000000,0x00000000}},	//   _gémb, --, --, --, 
   {{0x290c025a,0x00000000,0x00000000,0x00000000}},	//   âda_, --, --, --, 
   {{0x06852a29,0x73fc02f5,0x601d8078,0x6d40035a}},	//   зган, ্ফুট_, _téme, _ixna, 
   {{0xde700055,0x1cb80327,0x81e000fe,0x00000000}},	// [2c760] _hrāṃ_, _ངཀོ_, ধাত_, --, 
   {{0x4994006c,0xa3e44c21,0x20b00073,0x857801f4}},	//   _эшит, _भोज_, ींमध, ссат_, 
   {{0xf48002d3,0xb978011a,0x3978011a,0x27040154}},	//   _ክቐርብ_, _לניי, _לטינ, _রেখো_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x217801ec,0x6208022e,0x00000000,0x00000000}},	//   ойлы_, оrlа, --, --, 
   {{0xb6657932,0x672405be,0x6d40045a,0xa4f828c4}},	//   _нияз_, mzij, _oxna, _وکار_, 
   {{0x67259ffc,0x7980045f,0xf77c010e,0x00000000}},	//   lzij, _ûnwe, _haça_, --, 
   {{0x93a99ffd,0x601d9ffe,0xf77c7aa0,0x00000000}},	//   _واقف_, _sémb, _kaça_, --, 
   {{0x601c020c,0x6d40035a,0x7de401ec,0x00000000}},	//   _pémb, _axna, пінд, --, 
   {{0xb8dc025c,0xf77d9fff,0x3da40107,0x7d0c01bf}},	//   _གྀ_, _maça_, чриб, øbso, 
   {{0x656801c3,0x245c00d8,0x3f840129,0xdb1c007c}},	//   _ùdhd, nímo_, _tfou_, nesö, 
   {{0x672401f5,0x3f8400d7,0x671c012d,0x70f8011a}},	//   kzij, _ufou_, फनाक_, _להבח, 
   {{0x6d400a73,0x601d7fa7,0x67251919,0x00000000}},	//   _exna, _témb, jzij, --, 
   {{0x6725a000,0x26000807,0x58d402bf,0x2d800156}},	//   dzij, राफी_, могт, ñjet_, 
   {{0x37a88ba3,0x3d2000f2,0x260000ce,0x672401f5}},	//   йтан_, _déwé_, रानी_, ezij, 
   {{0xdb1c0036,0x6f0801e1,0xa8740150,0x00000000}},	//   ngsë, _ìṣín_, елсі, --, 
   {{0xdce80ba5,0xf77da001,0x67240d86,0x00000000}},	// [2c770] madı, _caça_, gzij, --, 
   {{0xdce81ae6,0xf77c415b,0xdb1c05d1,0x35680484}},	//   ladı, _daça_, fesö, брен_, 
   {{0xb880012c,0x2d8004a7,0xdb1c00a2,0x00000000}},	//   říbr, žjeg_, gesö, --, 
   {{0xf77c03b7,0xd3717250,0xdce80ba5,0x5334034b}},	//   _faça_, نها_, nadı, меет, 
   {{0x91e431df,0x6a6001b8,0xf77c0432,0x00000000}},	//   доле, löfa, _gaça_, --, 
   {{0xdb1c01e6,0xdce83361,0xe3b00137,0x245c0241}},	//   besö, hadı, _ەرل_, bímo_, 
   {{0xa4d400d6,0xdce81432,0x1ac80154,0xc5f0011a}},	//   _порі, kadı, শিয়া, _בדם_, 
   {{0xe1dc012c,0xdb1c0037,0x88300092,0xdce803b9}},	//   _यसअघ, lesõ, _በወታደ, jadı, 
   {{0x0e65a002,0xdce847af,0xf98402d3,0xafe001d5}},	//   мкин, dadı, ዛሕትኡ_, доқл, 
   {{0xdb1c0254,0x00000000,0x00000000,0x00000000}},	//   nesõ, --, --, --, 
   {{0x8c45a003,0x6724003d,0x4d65a004,0x238400fe}},	//   дене, zzij, ьков, _åsjå_, 
   {{0x6a6001b8,0x3eb00342,0xdb1c000d,0x06a80150}},	//   döfa, üntü_, hesõ, _ﺷﻪﺑﻪ, 
   {{0x2600012c,0xdb1c0066,0x00000000,0x00000000}},	//   रामी_, ngsè, --, --, 
   {{0xf77da005,0x9e6402bf,0x672401fa,0x00000000}},	//   _raça_, _звід, vzij, --, 
   {{0x012c044e,0x601c9d74,0xf77c1432,0xdb1c0254}},	//   _እንተዝ, _héma, _saça_, desõ, 
   {{0x601c034c,0x998c1b24,0xc6140882,0x2f200241}},	//   _kéma, đeš_, णस्य_, _gègé_, 
   {{0xb6a004a9,0x14e002dd,0x67240153,0xf77d1a8b}},	// [2c780] китл, _ءﺟﺎﺭ, uzij, _qaça_, 
   {{0x601c0438,0xf65c005c,0xdb1c0254,0x00000000}},	//   _méma, _spær_, gesõ, --, 
   {{0x601da006,0x00000000,0x00000000,0x00000000}},	//   _léma, --, --, --, 
   {{0xf77c06ed,0x778002e8,0xdb1da007,0x00000000}},	//   _taça_, _илюз, resö, --, 
   {{0xe3e0009e,0x741001d5,0xdb1c0254,0x7648007f}},	//   ণালব, خونا, besõ, èlyè, 
   {{0xf7700c75,0x40880114,0x00000000,0x00000000}},	//   _جاپ_, ољим_, --, --, 
   {{0x69dda008,0x601c00e4,0xdce85531,0x3a34025d}},	//   iere, _aéma, yadı, ורסם_, 
   {{0xdc78001f,0x7d0c005c,0xa13c0171,0x00000000}},	//   _ከሰማይ_, øbsm, _neķe, --, 
   {{0x69dc4971,0x52b01e4a,0xdce800ac,0x8e1c02d3}},	//   kere, _مەنئ, vadı, _ስለዝኸ, 
   {{0x63a1a009,0x601ce66a,0x62800998,0x23b40248}},	//   _hemn, _déma, _iumo, _fújà_, 
   {{0x63a000fd,0xdce82573,0xa13c0171,0x71a0014b}},	//   _kemn, tadı, _beķe, _рахз, 
   {{0x61e9a00a,0x6281a00b,0x63a00232,0x69dc01f5}},	//   _hadl, _kumo, _jemn, eere, 
   {{0x63a1a00c,0xdce9a00d,0xb9140248,0xb9c4036b}},	//   _memn, radı, _fifọ_, мёви, 
   {{0x63a1a00e,0x6281a00f,0xdce87bfb,0xdb1c0438}},	//   _lemn, _mumo, sadı, ngsé, 
   {{0x6281a010,0x63a0009a,0xaa58014b,0x069401ec}},	//   _lumo, _oemn, фиру_, _ﺘﺨﻭﺽ_, 
   {{0xb90409d9,0x63a1a011,0x61e99459,0x59b002ab}},	//   _मई_, _nemn, _ladl, _जयवर, 
   {{0x69dda012,0xfc3c038e,0xe7840fbe,0x61e8127b}},	// [2c790] bere, mní_, тусо, _oadl, 
   {{0x69dda013,0xfc3c02f8,0x61e808ad,0x20c8006a}},	//   cere, lní_, _nadl, kûi_, 
   {{0x6281a014,0x63a1a015,0xe5c400a7,0x14e001ec}},	//   _aumo, _bemn, ъсто, _ءﺑﺎﺭ, 
   {{0xfc3da016,0x6281a017,0x56940b3e,0x61e9a018}},	//   nní_, _bumo, _памт, _aadl, 
   {{0x63a1a019,0x6281a01a,0xfc3c007b,0x61e90c12}},	//   _demn, _cumo, iní_, _badl, 
   {{0x6280060a,0x61e80363,0x11d800c6,0x26000f4a}},	//   _dumo, _cadl, سوعة_, राणी_, 
   {{0x601da01b,0x63a1a01c,0x61e9a01d,0x62812dca}},	//   _séma, _femn, _dadl, _eumo, 
   {{0x6281a01e,0xfc3c031d,0x68e80436,0x63a00072}},	//   _fumo, jní_, æddi, _gemn, 
   {{0x69dda01f,0xfc3c02f8,0x61e801d9,0xf77c06ed}},	//   yere, dní_, _fadl, _laço_, 
   {{0x69dda020,0x63a1a021,0x61e83deb,0xa2941cb8}},	//   xere, _zemn, _gadl, _рафі, 
   {{0x260005ba,0x69dda022,0x62800a40,0x63a0192e}},	//   राती_, vere, _zumo, _yemn, 
   {{0x601c0316,0x6281a023,0x69dda024,0x5778001f}},	//   _téma, _yumo, were, _ኤጀንሲ_, 
   {{0x61e9a025,0x81e0015b,0x62808b17,0xca240150}},	//   _yadl, ধার_, _xumo, _ﺼﺒﺢ_, 
   {{0x69dda026,0xfc3da027,0xf77d9551,0x48e5a028}},	//   uere, aní_, _baço_, ногв, 
   {{0xfc3c038e,0xc2100375,0xa13c0171,0x00000000}},	//   bní_, נהל_, _zeķb, --, 
   {{0x69dda029,0xb901a02a,0xb7e00408,0xfc3c00bc}},	//   sere, ызск, лжск, cní_, 
   {{0x69dda02b,0xb904c8bf,0xd90c0753,0x8505a02c}},	// [2c7a0] pere, _मै_, میی_, کوان, 
   {{0x63a1a02d,0xf77c0261,0x6281a02e,0xdb1c002d}},	//   _semn, _faço_, _rumo, resô, 
   {{0x3998159d,0x61e9a02f,0x6281a030,0x6a600793}},	//   _מייד, _radl, _sumo, löfo, 
   {{0x6281a031,0x63a00477,0x61e81c2e,0xc454007b}},	//   _pumo, _qemn, _sadl, رضاع, 
   {{0x6a60014a,0x657c007f,0x6280022e,0x224000e4}},	//   nöfo, _tgrh, _qumo, éiko_, 
   {{0x7d0c04ce,0xfc3c0316,0x63a1a032,0x61e85bf1}},	//   øbsk, zní_, _wemn, _qadl, 
   {{0x63a1a033,0xfc3da034,0x36640364,0x6280014b}},	//   _temn, yní_, _чаро_, _wumo, 
   {{0x61e9a035,0xfc3c012c,0x6a600793,0xff1c04ce}},	//   _wadl, xní_, köfo, _rayや, 
   {{0xfc3c02f8,0xc244115c,0x61e81570,0xb36c0020}},	//   vní_, _знак, _tadl, ባቸውን_, 
   {{0x1fe00154,0x88300092,0xd24c01e2,0x00000000}},	//   ভাইস, _በፈቃደ, _وچو_, --, 
   {{0xfc3c02f8,0x00000000,0x00000000,0x00000000}},	//   tní_, --, --, --, 
   {{0xbe880220,0xce34b5e0,0x69c8007f,0x50a000d1}},	//   _еске_, _یونک, òden, _ئەيل, 
   {{0xfc3c038e,0x601da036,0x290d493a,0xca2800d1}},	//   rní_, _hémo, ädan_, ﻣﯜﺭ_, 
   {{0xfc3c0316,0x601c003e,0xf77d84cc,0x6a6001a8}},	//   sní_, _kémo, _paço_, söfn, 
   {{0xfc3c031d,0x28f8084c,0xdf000003,0x1ee835aa}},	//   pní_, нерь_, _wiċċ_, _روژی_, 
   {{0x601da037,0x0b5001f2,0xbe600451,0x1bd401f0}},	//   _mémo, ọkọl, _جهڙي, _роия, 
   {{0x601c0214,0x32040034,0xdd340092,0x00000000}},	// [2c7b0] _lémo, yjny_, ዮሚሌኒ, --, 
   {{0x63a4008c,0x3568d33a,0x74a400d8,0xf5680166}},	//   ðinn, прен_, ејде, пшек_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6a600112,0x245c00ae,0x00000000,0x00000000}},	//   höfl, nímh_, --, --, 
   {{0xfbd04c5b,0xe3ac02dd,0x00000000,0x00000000}},	//   ध्यम, _құ_, --, --, 
   {{0x601cd8b9,0xc880054e,0x9c7c0100,0x466000db}},	//   _bémo, _fişă_, nvčs, _نۇقق, 
   {{0xfbdc145e,0x6d440327,0x00000000,0x00000000}},	//   keê_, żjaz, --, --, 
   {{0x601da038,0x8f742626,0x00000000,0x00000000}},	//   _démo, купі, --, --, 
   {{0xb8f05078,0xdb0c04d4,0x160402c3,0xde200023}},	//   _ེད_, _ocañ, रापर_, _ስለዝወ, 
   {{0x601c0129,0xadb40137,0x00000000,0x00000000}},	//   _fémo, رۇعا_, --, --, 
   {{0xc5f002e4,0x9e6418fd,0x13d40154,0x00000000}},	//   בדי_, داين, _সোয়, --, 
   {{0xdb0c00b8,0x09c800dc,0x00000000,0x00000000}},	//   _acañ, िभ्य, --, --, 
   {{0x69c8007f,0x00000000,0x00000000,0x00000000}},	//   òdeo, --, --, --, 
   {{0x16046b9b,0x2fdc0165,0x6cc000fb,0x5a540139}},	//   राफर_, leug_, _бикҡ, гъсу, 
   {{0x26005f46,0x8c44030d,0x07a4026b,0x00000000}},	//   रासी_, _иеке, кавн, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4de413f5,0x00000000,0x00000000,0x00000000}},	// [2c7c0] _कसाई_, --, --, --, 
   {{0x55c41669,0x8884036b,0x245c00e4,0x857401c8}},	//   лауғ, _илож, mími_, ندائ, 
   {{0xd4f40006,0x00000000,0x00000000,0x00000000}},	//   ляцы, --, --, --, 
   {{0x2918143a,0x2600276a,0x68e80321,0x2fdd46de}},	//   myra_, राही_, æddu, jeug_, 
   {{0x27e1a039,0x82f85f2e,0x245c012c,0x2fdd157f}},	//   mein_, براز_, ními_, deug_, 
   {{0x27e1a03a,0x32501cb8,0xd6980150,0x00000000}},	//   lein_, авір, _ﺘﺨﻠﻭ_, --, 
   {{0x29192015,0x26c00393,0xc0c80120,0xde880051}},	//   nyra_, luio_, фуле_, _mịe_, 
   {{0x81e02baf,0x27e1a03b,0x601c0005,0x2fdc0c6a}},	//   ধাই_, nein_, _vémo, geug_, 
   {{0x4425a03c,0x2919a03d,0xdd9000d1,0x245c0c5e}},	//   mho_, hyra_, مۈش_, jími_, 
   {{0x4425a03e,0x27e1a03f,0x601da040,0xef1000f7}},	//   lho_, hein_, _témo, рүшө, 
   {{0x27e1a041,0x4425a042,0x291802d3,0x5c74fc32}},	//   kein_, oho_, jyra_, ллот, 
   {{0x4425a043,0x2919a044,0xd64c01ec,0x00000000}},	//   nho_, dyra_, бiле, --, 
   {{0x27e00428,0x34dc1b61,0x4425a045,0x245c0332}},	//   dein_, _नन्द, iho_, rímh_, 
   {{0x4425a046,0xbf0c12eb,0xda0800f1,0x29184cab}},	//   hho_, िहीन_, ريزه_, fyra_, 
   {{0x4424136f,0x2919a047,0xddc80210,0x2a640022}},	//   kho_, gyra_, podł, îmba_, 
   {{0x27e1a048,0x4425a049,0x63a40008,0x245c01ef}},	//   gein_, jho_, ðinl, bími_, 
   {{0x4425a04a,0x26c1a04b,0x245c0122,0x601c0036}},	// [2c7d0] dho_, guio_, cími_, _némm, 
   {{0x2fdc0639,0x442401a2,0x5edc00cc,0x2919a04c}},	//   zeug_, eho_, বিপে, byra_, 
   {{0x27e1a04d,0x44240084,0x2918003a,0x6a14007b}},	//   bein_, fho_, cyra_, _خبير, 
   {{0x4425a04e,0xe3b059d4,0x27e000a3,0x88f4011a}},	//   gho_, قره_, cein_, _עזרו_, 
   {{0xf2c5a04f,0x26002cbb,0xb2a80395,0x00000000}},	//   тсен, राशी_, фтеж_, --, 
   {{0x4425a050,0x65940a89,0x7738001f,0x2fdc003e}},	//   aho_, _вару, _በመሳተ, weug_, 
   {{0x4425a051,0x26002ba2,0x50d40424,0x2fdda052}},	//   bho_, रारी_, ازتر, teug_, 
   {{0x4425a053,0xe3b12702,0xcee80108,0x23600003}},	//   cho_, _ورق_, едие_, żija_, 
   {{0x601c1bce,0x31c40139,0x2fdd80f6,0x8fd000fb}},	//   _gémm, _асев, reug_, _ғәйә, 
   {{0x27e005f5,0x1fe00011,0x0d2000db,0xdb1c08a5}},	//   zein_, ভাগস, йүлү, ggsí, 
   {{0x26c0009f,0xa0c4e1e1,0x6adc2d6b,0x00000000}},	//   zuio_, _نيلو, यब्र, --, 
   {{0x245da054,0x290c01b8,0x00000000,0x00000000}},	//   tími_, ädam_, --, --, 
   {{0x27e01570,0x00000000,0x00000000,0x00000000}},	//   vein_, --, --, --, 
   {{0x442403bd,0x27e1a055,0x2919a056,0xbf9001d9}},	//   zho_, wein_, tyra_, _پۯیڈ, 
   {{0x4425a057,0x245c01a8,0x00000000,0x00000000}},	//   yho_, sími_, --, --, 
   {{0x4424f7b1,0xcb68010b,0x863c0023,0x41d8012d}},	//   xho_, _пайе_, _በረኸት, _मॉनस, 
   {{0x44240dc9,0x26001889,0x38680100,0x27e0be74}},	// [2c7e0] vho_, राली_, _dhcr_, rein_, 
   {{0x26c0003a,0x29180124,0x09e4004e,0x00000000}},	//   ruio_, pyra_, _соон, --, 
   {{0x4425a058,0x27e1a059,0xbb340023,0x00000000}},	//   tho_, pein_, _ኣስተዋ, --, 
   {{0x4424012c,0xc325a05a,0x0324021f,0xe855a05b}},	//   uho_, лмек, лден, _ئۆرد, 
   {{0x442413a1,0x6e20032e,0x76d8014b,0x00000000}},	//   rho_, _olnb, _пурӣ_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4425a05c,0x764801ed,0x50a401e0,0x00000000}},	//   pho_, égye, ауыҡ, --, 
   {{0xb4f8025f,0x44240457,0xdfd0007b,0xa2cc06ff}},	//   _אפלי, qho_, آية_, _समप्, 
   {{0x7410144b,0x6704a1fa,0xc2900ec9,0x5edc00cc}},	//   _اوقا, रमिक_, _ایتب, বিভে, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd00c00ec,0x3a2400ef,0x00000000,0x00000000}},	//   _ڊڄي_, _ķnp_, --, --, 
   {{0xbc2407a7,0x8fc400db,0xef20035b,0xbea40117}},	//   اردى, _ۅزۇن, рҟәҟ, _бадк, 
   {{0x70500150,0xa3bc02ab,0x00000000,0x00000000}},	//   _اننا, _आयन_, --, --, 
   {{0xa2cc1b61,0xdd95a05d,0x81e000cc,0x00000000}},	//   _समन्, _такы, ধাক_, --, 
   {{0x1959a05e,0xd13402d3,0x6e40004b,0x81e400cc}},	//   тавы_, _እንተል, _دنوم, _বচা_, 
   {{0xf77c036e,0xdc180210,0x6f1001e1,0x00000000}},	//   _kaçi_, _błąd, _ìṣéj, --, 
   {{0x9635a05f,0x245c00bc,0x7d18000f,0x28680107}},	// [2c7f0] анац, nímu_, lyts, урро_, 
   {{0xa774020f,0xf77c6f35,0x00000000,0x00000000}},	//   случ, _maçi_, --, --, 
   {{0xb8646e9a,0x7d18002d,0xe66441b9,0xf77c036e}},	//   _ماحو, nyts, стто, _laçi_, 
   {{0xb9ec069c,0xe7840116,0xd2940124,0xd838010e}},	//   _ንሱ_, _гуро, аркь, _öō_, 
   {{0x7d1806d9,0x245c0118,0x2334009d,0x00000000}},	//   hyts, jímu_, йхшр, --, 
   {{0x36200014,0xe1f82a55,0xf77c0200,0x00000000}},	//   _اوسہ, лгі_, _naçi_, --, 
   {{0x2e380241,0x00000000,0x00000000,0x00000000}},	//   _láfè_, --, --, --, 
   {{0x7d180109,0x293808a8,0xdb0c0332,0x765403ac}},	//   dyts, טאון_, _adaí, loxy, 
   {{0x0d9923b3,0x14e002dd,0xf77c0200,0x00000000}},	//   ктны_, _ءﺗﺎﺭ, _baçi_, --, 
   {{0x7d18045f,0x76540129,0x00000000,0x00000000}},	//   fyts, noxy, --, --, 
   {{0xa3ac012d,0x7d1800a2,0x00000000,0x00000000}},	//   _ग़म_, gyts, --, --, 
   {{0x7654959f,0x6a60014a,0x8f740111,0x644800ae}},	//   hoxy, möfi, _кулі, _ídit, 
   {{0x6a6029ef,0x2a6400d2,0x245c00bc,0x765403ac}},	//   löfi, îmbo_, címu_, koxy, 
   {{0x7a294c10,0x11340023,0x00000000,0x00000000}},	//   _lütf, _እንዳሓ, --, --, 
   {{0x6a6029ef,0x6f18022e,0x7d0c005c,0xa2cc00cd}},	//   nöfi, lyuc, øbst, _समभ्, 
   {{0xef340023,0xa5d807f7,0x7a2803b9,0xad6000ec}},	//   _እትደል, न्नौ, _nütf, _پاڙه, 
  
   {{0x6b840280,0x3ab17187,0x46e8013e,0x765402d0}},	// [2c800] _igig, _мәрт, ъдан_, foxy, 
   {{0x6a600793,0x6aa40248,0x415402d3,0xd245a060}},	//   köfi, _iwif, _ልዕሊኦ, _رچ_, 
   {{0xfbd00882,0xf4851192,0x84e400a7,0x9a240fb4}},	//   ध्वम, لانی, роеж, _دعين, 
   {{0x6aa5a061,0x6a600793,0xde880208,0x00000000}},	//   _kwif, döfi, _lịa_, --, 
   {{0xb3800b8d,0x7654035a,0x7d181d01,0x3eb800b8}},	//   әләл, boxy, zyts, _āpto_, 
   {{0x6aa40526,0x6b8401fa,0x6a60014a,0xdb1c438d}},	//   _mwif, _lgig, föfi, ngsá, 
   {{0x03a400d6,0x6b8425e1,0x6a600793,0x601c2dfb}},	//   _вибо, _ogig, göfi, _hémi, 
   {{0x3f800579,0x6b85a062,0x6aa4013f,0x10f801ed}},	//   øku_, _ngig, _owif, ابوں_, 
   {{0xde880521,0x493c001f,0x7e280006,0x7d18002d}},	//   _bịa_, ደሚቀጥ, віна_, wyts, 
   {{0x6b85a063,0x6a6029ef,0xd004036b,0x71a0009b}},	//   _agig, böfi, _қочқ, _мауз, 
   {{0xde880051,0x00000000,0x00000000,0x00000000}},	//   _dịa_, --, --, --, 
   {{0xdfd005d9,0x6aa40526,0x00000000,0x00000000}},	//   _ريت_, _bwif, --, --, 
   {{0x5e940597,0x2fd4004b,0x2aa800e9,0xf77da064}},	//   _التط, _خوند_, итро_, _taçi_, 
   {{0x6b85774f,0x7d0c005c,0x00000000,0x00000000}},	//   _egig, øbss, --, --, 
   {{0x6aa4013f,0x00000000,0x00000000,0x00000000}},	//   _ewif, --, --, --, 
   {{0x6b840083,0x0b4401d9,0xd1340092,0x00000000}},	//   _ggig, _گر٘ێ, _እንቅል, --, 
   {{0xf771a065,0x66f400f7,0x6aa4015d,0x00000000}},	// [2c810] زار_, опту, _gwif, --, 
   {{0x601da066,0xe6640107,0xbbb400cd,0x00000000}},	//   _démi, отхо, _अयुक, --, 
   {{0x6aa40084,0x7655a067,0x601c00d2,0xd4b800d8}},	//   _zwif, roxy, _témh, улец_, 
   {{0x601c83d4,0x4d78008f,0x2d800156,0x92b4d1ee}},	//   _fémi, אָנא, ñjez_, محتا, 
   {{0xdb2000fd,0x601d407e,0xe3b8886f,0x2bf80a7c}},	//   _ütäl, _gémi, рбі_, ימאן_, 
   {{0x6a600793,0xd1c80108,0xbec000ef,0x90d44710}},	//   töfi, улке_, _ķīpa, مآبا, 
   {{0x33a8039b,0xde8801fb,0xe1f0009f,0x00000000}},	//   _аъзо_, _rịa_, بسن_, --, 
   {{0x16040490,0x24181f39,0xb3840244,0xf1c40116}},	//   रावर_, _косы_, _ئێشم_, _چۈشى_, 
   {{0xde8800b4,0xa2940212,0xa3bc1c5d,0x2418a5de}},	//   _pịa_, _маті, _आयत_, _тоты_, 
   {{0x2d8004ce,0x6aa40526,0x7a280432,0x00000000}},	//   øje_, _rwif, _jütd, --, 
   {{0x9099a068,0xdb1c5163,0x6aa55679,0xa0c4007b}},	//   _свет_, ngsæ, _swif, _ويكو, 
   {{0x1dd865c5,0x8c4472db,0x5b440092,0x7a2806be}},	//   ब्बत, семе, _የሕዝቡ, _lütd, 
   {{0xf77c0166,0xada001e0,0x8e740798,0x7d0c005c}},	//   _kaçu_, _һаҙл, _лукч, øbsr, 
   {{0x7051a069,0x601da06a,0x00000000,0x00000000}},	//   _انچا, _rémi, --, --, 
   {{0x601c7027,0x6b8405d5,0xf77c010e,0x61380092}},	//   _sémi, _tgig, _maçu_, _እንደባ, 
   {{0x9ac4038f,0x6aa5a06b,0xde88001e,0x601c0066}},	//   fiċċ, _twif, _mịn_, _pémi, 
   {{0x6aa40526,0x4648010b,0x00000000,0x00000000}},	// [2c820] _uwif, гзан_, --, --, 
   {{0xaca002e3,0x29c80228,0xf400031c,0xd0f89856}},	//   _ndịi, _өтүү_, _ཚོུད_, ्माण_, 
   {{0x04447237,0x291c0158,0x43840101,0xa3bc0037}},	//   бежн, _æva_, ملاق, _आयद_, 
   {{0xdc180034,0x480800a8,0x601c0129,0x125800e5}},	//   _błęd, _семн_, _témi, یثوں_, 
   {{0x26c400e4,0xb890141d,0x00000000,0x00000000}},	//   _êmo_, _ولیع, --, --, 
   {{0x716802d3,0x7a2800a2,0x26c0010f,0xde880051}},	//   _ትንፋስ_, _gütd, mrio_, _bịn_, 
   {{0x26c0011c,0xf0b4104c,0x00000000,0x00000000}},	//   lrio_, مايش_, --, --, 
   {{0xde88063f,0x26009401,0x6018059f,0x26c00115}},	//   _dịn_, राकी_, роия_, orio_, 
   {{0x7a280112,0x2e240023,0x35cc0037,0x00000000}},	//   _hüte, _ስለዝመ, स्क़, --, 
   {{0x9f440240,0x7a29a06c,0x26c003cb,0xfbdc0051}},	//   lemë_, _küte, irio_, gnên_, 
   {{0xa3bc068f,0x7980045f,0x81ac0f22,0x26c001ab}},	//   _आया_, _ûnwi, _কাপ_, hrio_, 
   {{0x7f840491,0x26c0071b,0x7a2805d1,0xb4f8008f}},	//   _الإن, krio_, _müte, אפטי, 
   {{0x249800ca,0x6a6001a8,0x7a28371e,0x00000000}},	//   _ltrm_, höfu, _lüte, --, 
   {{0x26c0705e,0x6c8000f1,0x61381954,0x00000000}},	//   drio_, _کليم, _እንዳባ, --, 
   {{0xde88001e,0x26c0e667,0x52a401ad,0x00000000}},	//   _xịn_, erio_, _ऑब्स, --, 
   {{0x81ac0183,0x26c00042,0x9f440200,0x3ea40210}},	//   কলি_, frio_, jemë_, _kwot_, 
   {{0x5a34170a,0x26c00393,0x81ac0011,0xfc3c022a}},	// [2c830] _мнит, grio_, _কান_, mií_, 
   {{0xfc3c0122,0x7a280432,0x260006b1,0xdb1400a2}},	//   lií_, _büte, रागी_, _ýañs, 
   {{0x26c13316,0x35689ce7,0xbaa41955,0x3f8402e2}},	//   ario_, уран_, _туққ, _ogou_, 
   {{0xb864208f,0x3f8400e8,0xfc3c0216,0xde880051}},	//   _داخو, _ngou_, nií_, _rịn_, 
   {{0x25b80526,0x601c00d2,0x290c0793,0xde880051}},	//   _fdrl_, _yémv, ädav_, _sịn_, 
   {{0xf485a06d,0xf77c0166,0xb4b0013d,0xe6940166}},	//   _гуан, _qaçu_, _нигә, _хиры, 
   {{0x7a2803fa,0x40900228,0x601c0129,0x74680212}},	//   _güte, ولور, _lému, _брав_, 
   {{0xde880208,0x6a6001e3,0x5558022e,0x8fa40022}},	//   _vịn_, löft, _баҳя_, әаҿе, 
   {{0xdb1c893b,0xfc3c02fd,0x63b400bc,0x8e74010b}},	//   ngsä, dií_, řený, жунч, 
   {{0xfe4000d6,0x91802928,0x3f840100,0xe800000d}},	//   дньо, _قۇشۇ, _egou_, _लोना_, 
   {{0xfc3c0232,0x8c49a06e,0x50dc0b02,0x61fc0332}},	//   fií_, ипов_, _महिष, _órla, 
   {{0xfc3c0122,0x00000000,0x00000000,0x00000000}},	//   gií_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa2cc060c,0x601c004a,0x26c14438,0x00000000}},	//   _समस्, _dému, vrio_, --, 
   {{0x81ac0c58,0x2d841730,0x4ccc009e,0xd90c03e6}},	//   _কাম_, _igne_, ়বহু, ۆیی_, 
   {{0x26c1a06f,0xfc3c6b07,0x249800ca,0x601da070}},	//   trio_, cií_, _rtrm_, _fému, 
   {{0xd90c04d3,0xdb1c0267,0x7a29a071,0x24980010}},	// [2c840] نیی_, ggsä, _süte, _strm_, 
   {{0x26c02d7b,0xa3dcabac,0x7a2802b5,0x00000000}},	//   rrio_, त्न_, _püte, --, 
   {{0x25b80010,0x26c000d8,0x9f440200,0x00000000}},	//   _vdrl_, srio_, temë_, --, 
   {{0xf8b00d65,0x26c1a072,0x2eec45a7,0x35680408}},	//   _קשר_, prio_, _osgf_, ăран_, 
   {{0x7a280e78,0xe2f81e32,0xa28402f2,0x9f44036e}},	//   _wüte, селі_, سیاو, remë_, 
   {{0xfc3c02fb,0x7a29a073,0xa194010b,0x00000000}},	//   zií_, _tüte, чакч, --, 
   {{0x3f843d5a,0x7a28002f,0x15b00136,0x00000000}},	//   _pgou_, _hütc, _سەنس, --, 
   {{0xdfd1a074,0x2d85a075,0xdd901056,0x9f440066}},	//   ريخ_, _agne_, کود_, lemé_, 
   {{0x63a42880,0x00000000,0x00000000,0x00000000}},	//   ðinu, --, --, --, 
   {{0xddd80bb8,0xdb1c38aa,0x601c5725,0x2485a076}},	//   _bivš, ngså, _rému, _himm_, 
   {{0x8144066d,0x24840072,0xfc3c02f0,0xb5f800df}},	//   _بنان, _kimm_, tií_, בליכ, 
   {{0x2d84f940,0x2484000f,0x9f44020c,0xefcc001f}},	//   _egne_, _jimm_, hemé_, ጥታው_, 
   {{0xfc3c0232,0x7a281ae4,0x9f440066,0xde700055}},	//   rií_, _rütb, kemé_, _esāṃ_, 
   {{0x248400e8,0xfc3da077,0x2ca40142,0x225c0010}},	//   _limm_, sií_, _fwnd_, novk_, 
   {{0xbb4404a2,0xfc3da078,0x9f4400d7,0x00000000}},	//   ﻘﺎﻥ_, pií_, demé_, --, 
   {{0xa3dc725e,0x248404ef,0xde880208,0x7a28453a}},	//   त्म_, _nimm_, _lịm_, _bütc, 
   {{0xdb1001b8,0x12c400cc,0x22900051,0xa2cc2802}},	// [2c850] äfäl, _এন্দ, _nàk_, _समष्, 
   {{0xaa8801b9,0xdb0c2ca8,0xdb1c01e3,0x00000000}},	//   _گنیم_, _adaç, rgsä, --, 
   {{0x89d800dd,0x6d4c054e,0x260002db,0x290c01e3}},	//   _اوپر_, şcav, राजी_, ädat_, 
   {{0x9378010b,0x48f8010f,0x6a60002f,0x644801e1}},	//   ббет_, _פּיא, söft, _ìdil, 
   {{0x1b1c00bd,0xc5e4015b,0x23380024,0x00000000}},	//   _পেতে_, নাজপ, опцы_, --, 
   {{0x9f4400f2,0x00000000,0x00000000,0x00000000}},	//   cemé_, --, --, --, 
   {{0x24842242,0x2fcc0004,0x2ce4025c,0x00000000}},	//   _fimm_, _pcgg_, _འགེབ, --, 
   {{0xb698019f,0x7afc03b9,0x0ea80108,0x81ac00fe}},	//   _irâb, _orqt, бкий_, _কাণ_, 
   {{0x26016c08,0x7c2c01ab,0xf27001d9,0x00000000}},	//   राची_, dhcr, _ہێچھ, --, 
   {{0x2ca40175,0x00000000,0x00000000,0x00000000}},	//   _pwnd_, --, --, --, 
   {{0x2484020b,0xd5dc3599,0x00000000,0x00000000}},	//   _yimm_, न्यज, --, --, 
   {{0x60dc01e3,0x8fd00139,0xd8d401ec,0x00000000}},	//   _ärma, _чәкә, _ﺘﺴﺘﻐ, --, 
   {{0x5f7469f2,0x41d00da5,0xa13c00ef,0xdef40153}},	//   _قاهر, _सामस, _reķi, _опцы, 
   {{0x6fd40b8f,0x98c40118,0x2d840064,0x00000000}},	//   भ्रं, _útěk_, _ugne_, --, 
   {{0xa3bc75be,0x2bd40316,0x7ba80183,0xc9080154}},	//   _आयल_, _थापा, _কাৰো, রন্ত_, 
   {{0xdb1c002d,0x23600135,0x00000000,0x00000000}},	//   ngsû, żiji_, --, --, 
   {{0x9954012c,0x248404e6,0xc7643769,0x00000000}},	// [2c860] _výši_, _rimm_, سارى, --, 
   {{0x27040034,0x799402d0,0x24840254,0x7bc8032e}},	//   रमौर_, _gfxw, _simm_, _ögur, 
   {{0x69dda079,0x9f440098,0x3a34011a,0xa82802dd}},	//   mfre, remé_, _זרים_, _ۇيگە_, 
   {{0x69dda07a,0x9f44020c,0x42a00023,0x580402dd}},	//   lfre, semé_, _ልኡኻት_, _жоюғ, 
   {{0x24840254,0x96b801ca,0x2bd42d93,0x00000000}},	//   _vimm_, _муру_, _थाना, --, 
   {{0x69dc0385,0x7a29a07b,0x00000000,0x00000000}},	//   nfre, _küta, --, --, 
   {{0x03a4228e,0x7a2801b8,0x248401bf,0x69dc002f}},	//   _ниво, _jüta, _timm_, ifre, 
   {{0x55882ed0,0xb600038f,0x92c00365,0x7a281cce}},	//   ğışı, ġġet, üğün, _müta, 
   {{0x4425a07c,0xdd900131,0xc32401a9,0x00000000}},	//   mko_, نۈش_, _эмак, --, 
   {{0x4425a07d,0x8248a012,0x69dc01a4,0x0164e58b}},	//   lko_, _اشرف_, jfre, _екзо, 
   {{0x69dda07e,0x4425a07f,0x7f84742b,0xdef80220}},	//   dfre, oko_, _فلان, сық_, 
   {{0x61f80af9,0x00000000,0x00000000,0x00000000}},	//   ldvl, --, --, --, 
   {{0x69dda080,0x19c40166,0x79a40798,0x00000000}},	//   ffre, мәнг, зрбе, --, 
   {{0x4424b515,0xa3dc06e3,0x61f82a28,0x69dc4a21}},	//   hko_, त्त_, ndvl, gfre, 
   {{0xa3cc19ec,0x4425a081,0xdb1c01ed,0x18640092}},	//   लला_, kko_, ngsú, ዲፈጠር_, 
   {{0x1dd817ee,0x00000000,0x00000000,0x00000000}},	//   ब्रत, --, --, --, 
   {{0x4425a082,0x6d4c054e,0x290c0267,0x60d803ac}},	// [2c870] dko_, şcat, ädar_, htvm, 
   {{0x6b7400fb,0x00000000,0x00000000,0x00000000}},	//   _ялыу, --, --, --, 
   {{0x4425a083,0x41d801ad,0x00000000,0x00000000}},	//   fko_, _मॉइस, --, --, 
   {{0x7bcc789a,0x4425a084,0xc95006a9,0xf7e80132}},	//   ngcu, gko_, _ימי_, _اردى_, 
   {{0x24580953,0x00000000,0x00000000,0x00000000}},	//   чаць_, --, --, --, 
   {{0x4425a085,0x6235a086,0x00000000,0x00000000}},	//   ako_, нечу, --, --, 
   {{0x44241e5f,0xfbbc1f13,0x00000000,0x00000000}},	//   bko_, ्लाम, --, --, 
   {{0x4425a087,0xb6983a6d,0x940404fb,0x61f8017a}},	//   cko_, _grâc, _توره, advl, 
   {{0x69dc0368,0x00000000,0x00000000,0x00000000}},	//   yfre, --, --, --, 
   {{0x69dd3413,0xb37c0023,0x00000000,0x00000000}},	//   xfre, _ንሱዳን_, --, --, 
   {{0x69dc072b,0x00000000,0x00000000,0x00000000}},	//   vfre, --, --, --, 
   {{0xcb6897d0,0xa2c43507,0x6fd800cc,0x00000000}},	//   жаме_, _रिम्, _মোৰে, --, 
   {{0x7a280205,0x8e380b24,0x00000000,0x00000000}},	//   _süta, _وستر_, --, --, 
   {{0x4424152d,0x68fc9fca,0x601c003e,0xde94007b}},	//   zko_, tvrd, _hémp, _أجنب, 
   {{0x4425a088,0xf1dc00dc,0x080801f7,0x5c3c0023}},	//   yko_, प्यन, يزري_, _ኣህጉር, 
   {{0x7bcc00d2,0x4424bcb1,0x6d4c0205,0x00000000}},	//   cgcu, xko_, şcas, --, 
   {{0xf7406193,0x69dc06f2,0x601c0066,0x0685a089}},	// [2c880] вето, pfre, _mémp, дган, 
   {{0x7a2800af,0x601c7cd8,0x44240034,0xf5e40107}},	//   _tüta, _lémp, wko_, ммул_, 
   {{0x4425a08a,0x850442b5,0x7a28000d,0x92dc03d4}},	//   tko_, بوان, _kütn, তটো_, 
   {{0x601ca507,0x9754002b,0x43446a40,0x5f1000cd}},	//   _némp, _aṇum, меев, तमम्_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc8e00490,0x61b40014,0x81ac00cc,0x6fd800cc}},	//   _पहाट, رٕبا, _কাহ_, _মোলৈ, 
   {{0x4425a08b,0x61f8017a,0xc05801ec,0x00000000}},	//   pko_, rdvl, жіп_, --, 
   {{0x661da08c,0x44fc0153,0x442401a9,0x92ac00cc}},	//   _hork, _iį_, qko_, _কমৰ_, 
   {{0x661da08d,0x67244c99,0x601c0098,0x64401905}},	//   _kork, nyij, _démp, _immi, 
   {{0x661da08e,0x9d141677,0x44fc0064,0x1be02072}},	//   _jork, едоч, _kį_, ग्नल_, 
   {{0x44fc02d5,0x661da08f,0x6289a090,0xdc9800d4}},	//   _jį_, _mork, _iido, явні_, 
   {{0x6289a091,0x717043b1,0x7e7802d0,0x00000000}},	//   _hido, _شهنا, smtp, --, 
   {{0x6289a092,0x661c0660,0x44fc0153,0x00000000}},	//   _kido, _oork, _lį_, --, 
   {{0x6288b364,0x9f4400e4,0x00000000,0x00000000}},	//   _jido, nemí_, --, --, 
   {{0x6289a093,0x6441a094,0xe8000c2e,0x6d4c0276}},	//   _mido, _ommi, _लोहा_, şcar, 
   {{0x6ce000d6,0x9b580323,0x6289a095,0xdd0c012d}},	//   _ріше, _нийт_, _lido, półt, 
   {{0x62880789,0x629c02b5,0x44fc00a2,0x199402d5}},	// [2c890] _oido, _ōron, _aį_, _папя, 
   {{0x6440b265,0x661c0363,0x35681d83,0xd5b0a90e}},	//   _ammi, _cork, орен_, افا_, 
   {{0x661da096,0x3944007c,0x9f440139,0x00000000}},	//   _dork, _äns_, demí_, --, 
   {{0x67240223,0xd3700f84,0x789801f2,0x6289a097}},	//   byij, هها_, _ụkwọ_, _aido, 
   {{0x6289a098,0x661c28b3,0xe785a099,0x601c0098}},	//   _bido, _fork, _ауро, _rémp, 
   {{0x661da09a,0x6289a09b,0x6441a09c,0x9f44004e}},	//   _gork, _cido, _emmi, gemí_, 
   {{0x63a40113,0x601c01e1,0x60dc3bba,0xb4b00139}},	//   ñinc, _pémp, _ärml, _шивә, 
   {{0x6288056a,0x00000000,0x00000000,0x00000000}},	//   _eido, --, --, --, 
   {{0x6289a09d,0x81ac015b,0x00000000,0x00000000}},	//   _fido, _কার_, --, --, 
   {{0xa2c40316,0x6289a09e,0x6f9c0490,0x9c7c0083}},	//   _रित्, _gido, _ग्रू, kwčs, 
   {{0x601c579d,0x6440000f,0x1b1c015b,0x6fd40073}},	//   _témp, _ymmi, _পেলে_, _यापू, 
   {{0xce940c04,0x628808a4,0x7a2806be,0xcd000055}},	//   _задъ, _zido, _büto, _īśā_, 
   {{0x3f800024,0x6289a09f,0x00000000,0x00000000}},	//   žkur_, _yido, --, --, 
   {{0x628802b9,0xc33002e4,0xadf003ce,0x7d0c01e7}},	//   _xido, רוך_, _असिन_, óisí, 
   {{0x6b240135,0x9cf50743,0x8c44074d,0x0d2000db}},	//   ོརངོ_, _ачыш, _пеке, _сүнү, 
   {{0x661c138f,0x9f4400bc,0x7a28000d,0x44fc00c0}},	//   _sork, zemí_, _füto, _rį_, 
   {{0x7a28b6d6,0x661da0a0,0xbd640092,0x44fc00c0}},	// [2c8a0] _kütl, _pork, _ሲስተም_, _sį_, 
   {{0x661d3344,0x85540063,0x49c8d873,0x44fc0064}},	//   _qork, нђељ, _элон_, _pį_, 
   {{0x6289a0a1,0x661da0a2,0x7a2803be,0x28ac01ad}},	//   _rido, _vork, _mütl, टीशि, 
   {{0x6289a0a3,0x661da0a4,0x1e1c1d34,0x41d007d0}},	//   _sido, _work, _पक्ष_, _साहस, 
   {{0xa6843088,0xf48425cb,0x6289a0a5,0x27e00198}},	//   _ағай, رامی, _pido, mfin_, 
   {{0x27e1a0a6,0xb698000f,0xdb1c1347,0x06e400fe}},	//   lfin_, _krân, rgsø, নিদি, 
   {{0x6289a0a7,0xa2cc9401,0xd5ac01ed,0x27e00067}},	//   _vido, _समक्, _ذہن_, ofin_, 
   {{0x27e00c86,0x6441a0a8,0x62893722,0xe73c03b9}},	//   nfin_, _ummi, _wido, güçü, 
   {{0x6289a0a9,0x9cec015b,0x7a2803e3,0x8fd40075}},	//   _tido, _ওপেন_, _bütl, тәхә, 
   {{0x7a2800ac,0xb6980356,0x00000000,0x00000000}},	//   _cütl, _orân, --, --, 
   {{0x5c744727,0xb6340677,0x00000000,0x00000000}},	//   клот, גריס_, --, --, 
   {{0xe800690c,0x27e0e004,0x4ad0000d,0x00000000}},	//   _लोला_, jfin_, _तमशव, --, 
   {{0x27e1a0aa,0x7e28109a,0xdb202ca8,0x00000000}},	//   dfin_, _ніка_, _ütül, --, 
   {{0xb699a0ab,0x27e000d2,0x81ac0183,0xfafc0240}},	//   _brân, efin_, কলক_, rvë_, 
   {{0xb699a0ac,0x6da069f2,0x27e12655,0x00000000}},	//   _crân, _صميم, ffin_, --, 
   {{0x7a2802b5,0x27e000a3,0x7c8400f0,0x00000000}},	//   _tüto, gfin_, _џуке, --, 
   {{0xa2cc6236,0x9f445490,0xbbbc166d,0x00000000}},	// [2c8b0] _समग्, nemà_, ्लीक, --, 
   {{0xb698334b,0x27e1a0ad,0xa6c40075,0x7a280037}},	//   _frân, afin_, اقلى, _kütm, 
   {{0x92ac0f22,0x49ec01e1,0xa3cc0073,0x00000000}},	//   _কমে_, _ǹṣó_, ललं_, --, 
   {{0x245807d5,0xb37c0023,0x27e000de,0x00000000}},	//   нахь_, _ንሱውን_, cfin_, --, 
   {{0x63a5a0ae,0x6a143fb8,0x00000000,0x00000000}},	//   ñina, _شبیر, --, --, 
   {{0x9f440137,0x2efda0af,0x91e55de0,0x39380092}},	//   demà_, vvuf_, токе, ረጋውያ, 
   {{0xe56822f7,0x7a2805d5,0x41d00b02,0x8d4001ee}},	//   _зиёд_, _rütl, _सारस, _иhә_, 
   {{0x2055a0b0,0x20c80131,0x7a2805d1,0x4f087d60}},	//   лтыр, ربىي_, _sütl, днин_, 
   {{0xf1a48656,0x6458004a,0x26c4143a,0x92948675}},	//   _зрен, évie, _åmot_, _разц, 
   {{0xa2940024,0x00000000,0x00000000,0x00000000}},	//   _сафі, --, --, --, 
   {{0xe814012c,0x8ba400ee,0xde880208,0x21a8013d}},	//   डामा_, кинж, _nịu_, _чәчү_, 
   {{0xdb0c2776,0x8c45a0b1,0x5edc02f5,0x2fdc0007}},	//   _âkûn, теме, বিজে, qfug_, 
   {{0xdcf80205,0x89340014,0x0e340108,0xaa8401ef}},	//   _devı, ھٹرا, _индю, htýř, 
   {{0xa2c47f1a,0x27e00204,0xb6980311,0xfaa1a0b2}},	//   _रिस्, wfin_, _prân, раро, 
   {{0x64d009d9,0x7a285c19,0xd9585074,0x00000000}},	//   _हमेश, _kütj, ешті_, --, 
   {{0x2c081533,0xde88001e,0x9f440093,0x27e00e14}},	//   षाओं_, _dịu_, lemá_, ufin_, 
   {{0x27e1a0b3,0x41d06ac3,0x00000000,0x00000000}},	// [2c8c0] rfin_, _सालस, --, --, 
   {{0xb6980261,0x7a28002d,0x27e0581e,0xfbdc0208}},	//   _trân, _lütj, sfin_, niên_, 
   {{0xd499a0b4,0xb69800d8,0x1dd42efd,0x6f840150}},	//   ері_, _urân, _दासत, _ﻗﻭﻴﺎ_, 
   {{0x03247d1a,0xfbdc0016,0x82a402bf,0xc325a0b5}},	//   кден, hiên_, вадж, кмек, 
   {{0x06e404c5,0xde880051,0x00000000,0x00000000}},	//   নিহি, _kịt_, --, --, 
   {{0x79781682,0x00000000,0x00000000,0x00000000}},	//   ṅwed, --, --, --, 
   {{0xa2c40d0a,0xceb441fd,0xde88004d,0xf990011a}},	//   _रिव्, ңәш_, _mịt_, סרה_, 
   {{0x7520c08d,0x274c0020,0x7a280037,0xf8b00375}},	//   änze, _በመስጠ, _rütm, בשה_, 
   {{0x30115972,0xdd940150,0x00000000,0x00000000}},	//   рдыр, лапы, --, --, 
   {{0xde88004d,0xdcf80790,0x9f980419,0x00000000}},	//   _nịt_, _sevı, mšík_, --, 
   {{0x2138005c,0x4175a0b6,0x00000000,0x00000000}},	//   _årh_, _شائس, --, --, 
   {{0xbbbc00e1,0x41d05f46,0xd2c80f4a,0x00000000}},	//   ्लेक, _साँस, _रिमझ, --, 
   {{0x290c01e6,0xde8801fb,0x6fd40073,0x7ac402e8}},	//   ådan_, _bịt_, _यातू, ъсне, 
   {{0x58d44c34,0xa9c401f4,0x00000000,0x00000000}},	//   логт, исск, --, --, 
   {{0x9b940354,0xe9b400d4,0x2dd400ae,0x00000000}},	//   _йийц, рбсь, _شبوة_, --, 
   {{0x7a28000d,0x00000000,0x00000000,0x00000000}},	//   _kütk, --, --, --, 
   {{0x41d00cb4,0xdb1c0e78,0x00000000,0x00000000}},	// [2c8d0] _सांस, ngsü, --, --, 
   {{0x1ce00327,0xf52400d8,0x00000000,0x00000000}},	//   _ཥྱོ_, кфен, --, --, 
   {{0xe980030d,0x2dac0150,0x00000000,0x00000000}},	//   _маьi_, _ﺳﯘﻳﻤ, --, --, 
   {{0xa2c409d9,0x53342077,0x10a40116,0x00000000}},	//   _रिश्, леет, қиин, --, 
   {{0xc5b00154,0xfbd8000d,0x00000000,0x00000000}},	//   _চারপ, _भानम, --, --, 
   {{0x722811ed,0xde8801fb,0x62640212,0xd5f8010f}},	//   ьцев_, _xịt_, авіа, _אפֿר, 
   {{0x9f440270,0xf48402dd,0x274c0092,0xfbdc0051}},	//   vemá_, _ауан, _በመሰጠ, viên_, 
   {{0xb61c0efb,0xbbbc102f,0xddc80118,0x00000000}},	//   _ﻤﻥ_, ्लोक, lidň, --, 
   {{0x0e6596a9,0x9f440093,0xb69800e4,0xd6b003d4}},	//   лкин, temá_, _orâm, _চমুপ, 
   {{0x7c3c0006,0x96d40d0a,0xeff00092,0x00000000}},	//   _įpra, यूयॉ, ግቢያ_, --, 
   {{0x4c8403d0,0x7a2800a2,0x00000000,0x00000000}},	//   ллов, _tütj, --, --, 
   {{0xb69800e4,0x9f440093,0xde880051,0x00000000}},	//   _arâm, semá_, _sịt_, --, 
   {{0xcde400ee,0x52d008f2,0x6f840064,0x00000000}},	//   _болй, _समोस, _ружж, --, 
   {{0x629c00b0,0xb6980356,0x9d4415b4,0x3f800022}},	//   _ōrok, _crâm, ائین, ýkue_, 
   {{0xb6980225,0xde88001e,0x7a2805d1,0x58940261}},	//   _wrâl, _vịt_, _müth, ишту, 
   {{0xb6980022,0x7a2807c5,0xa2c407f7,0xf98400e3}},	//   _erâm, _lüth, _रिल्, انِي_, 
   {{0xde88004d,0xd1c80092,0x060800c7,0xc7640137}},	// [2c8e0] _tịt_, በሉት_, ннак_, اازى, 
   {{0x6aa401f7,0x89a80334,0x7d0c0332,0x778003f6}},	//   _itif, _яков_, _óisé, слуз, 
   {{0x63a40789,0x13a800e5,0x00000000,0x00000000}},	//   ñino, ھنوی_, --, --, 
   {{0xf7700150,0xd90c0133,0x00000000,0x00000000}},	//   _گاپ_, _تیف_, --, --, 
   {{0xbef00882,0xe2f84e19,0xfbdc017a,0x999000c0}},	//   _अनेन_, телі_, onêr_, cizų_, 
   {{0x09c40154,0x7520002f,0x00000000,0x00000000}},	//   শ্রা, änzc, --, --, 
   {{0x7a285c01,0xcf6803b9,0x00000000,0x00000000}},	//   _sütk, _əşşi_, --, --, 
   {{0x9f0400f7,0xdb0c00a2,0xb97808a8,0x6aa40857}},	//   لوعو, _adaý, ענקי, _otif, 
   {{0x6aa40223,0xb1403ad0,0x00000000,0x00000000}},	//   _ntif, инәл, --, --, 
   {{0xf2940302,0xdb2006af,0xc5b0015b,0x00000000}},	//   _עכבר_, _àtél, _চাঁপ, --, 
   {{0x6aa40134,0x290c03cd,0x052000fe,0x00000000}},	//   _atif, ådal_, _মধুৰ_, --, 
   {{0xfbdc0af9,0xb098010f,0x00000000,0x00000000}},	//   enêr_, _נידר, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7a28000d,0x00000000,0x00000000,0x00000000}},	//   _küti, --, --, --, 
   {{0x6aa5a0b7,0x4e10012c,0xa5d800bc,0xa9345ce7}},	//   _etif, तारै_, न्छौ, берш, 
   {{0xfbdc00d8,0xf65c005c,0x09c400cc,0x1dd41428}},	//   rnês_, _kvæg_, শ্লা, _दाँत, 
   {{0xb69809b1,0xb5a428e8,0x6bd41411,0xabd400db}},	// [2c8f0] _trâm, грей, _اتىر, _ازىت, 
   {{0xeb3c010f,0x7c2c02d0,0xaf74010f,0x99900064}},	//   _רעזש, lkcr, רעמס_, rizų_, 
   {{0xfbdc0016,0x7a2805d5,0x683808a5,0xe800043e}},	//   hiêm_, _rüth, _bídd, _लोका_, 
   {{0xf1bc00c6,0xe3b000c6,0xdd0000bc,0x7c2c01a9}},	//   _śá_, كره_, _štěn, nkcr, 
   {{0x64585941,0xf2c40354,0x1dd40412,0x00000000}},	//   évia, усен, _दांत, --, 
   {{0x6595a0b8,0x7a280209,0xabdc01ec,0x6fd401f9}},	//   _гару, _büti, _ﺃﻋﻤﺎ, _याहू, 
   {{0x466001ec,0x10a40354,0x00000000,0x00000000}},	//   _بۇلق, шийн, --, --, 
   {{0x7a2804cc,0xd0244090,0x9f44005b,0xf77c0432}},	//   _wüth, рмий, kemä_, _saçy_, 
   {{0xa0c400db,0x8f7400d4,0x00000000,0x00000000}},	//   _ۇيلو, шукі, --, --, 
   {{0x7d0400e2,0xa344022e,0x00000000,0x00000000}},	//   āksn, _уэсл, --, --, 
   {{0xa0c407c0,0x7a28002f,0x69c80210,0x8ff80117}},	//   _هيلو, _güti, ódem, _ахлу_, 
   {{0x5fdc0490,0xe0d13ecd,0x290c007c,0x00000000}},	//   _यायल, _رزم_, ådam_, --, 
   {{0x6838012c,0x91e400b5,0xe8140073,0x4418011a}},	//   _jíde, niはl, डासा_, דורס, 
   {{0x68380005,0x9f0401d5,0x00000000,0x00000000}},	//   _míde, _دوهو, --, --, 
   {{0x6e200332,0xfce000d4,0x00000000,0x00000000}},	//   _ionb, _дощо, --, --, 
   {{0x6e21a0b9,0x07a5a0ba,0xc5b0009e,0xae000131}},	//   _honb, раан, _চাইপ, _ئۈگى, 
   {{0x6e207550,0x6aa5a0bb,0xde88001e,0x86446219}},	// [2c900] _konb, _utif, _kịp_, анаж, 
   {{0x6e21a0bc,0x09e419bb,0x601c0129,0xc4c4007b}},	//   _jonb, _тоон, _démy, لتصو, 
   {{0x6e21a0bd,0xbef1a0be,0x35a0009d,0x7e3400df}},	//   _monb, _अन्न_, цахг, סטעד_, 
   {{0x7a2804cc,0x683800ae,0x82a5a0bf,0x5ddc02dd}},	//   _rüti, _bíde, ашке, _ﺃﻫﻤﻴ, 
   {{0x41b400c6,0x6e2002d0,0x68380d12,0x42d806a6}},	//   لمشر, _oonb, _vídd, тфея_, 
   {{0x6e21a0c0,0x6839a0c1,0xda1805f9,0x12a85734}},	//   _nonb, _díde, दायत_, ادنى_, 
   {{0x26c1a0c2,0x81740107,0x69c8007f,0x00000000}},	//   lsio_, шакӣ_, òdey, --, 
   {{0xb7b801fb,0x6838003a,0x7c3c0024,0x6e200332}},	//   _loãn, _fíde, _įpro, _aonb, 
   {{0x26c1a0c3,0x24980ac5,0x998002b5,0x25b80e78}},	//   nsio_, _hurm_, _pohū_, _kerl_, 
   {{0x6e201fe1,0x26c00368,0x324002dd,0x24980254}},	//   _conb, isio_, _деуг, _kurm_, 
   {{0xdef8005e,0x6e207cf2,0xdd94052f,0xde88001e}},	//   тық_, _donb, _һалы, _dịp_, 
   {{0x26c1a0c4,0x81ac045e,0x6e2002d0,0xcf2400ec}},	//   ksio_, _কাট_, _eonb, _گرمي, 
   {{0xd6b00729,0x2f0c0008,0x6e20007f,0x7c2c01f5}},	//   _চম্প, rögð_, _fonb, rkcr, 
   {{0xfba53e05,0x6e21a0c5,0x3ea4037e,0xcf241370}},	//   _क्रम, _gonb, _itot_, _درمي, 
   {{0xb6980022,0x9ca4215c,0x24980254,0x00000000}},	//   _irâi, _اشتۇ, _nurm_, --, 
   {{0xa9540046,0x6e21a0c6,0x00000000,0x00000000}},	//   ікті, _zonb, --, --, 
   {{0x25b80139,0x6e20e236,0x00000000,0x00000000}},	// [2c910] _berl_, _yonb, --, --, 
   {{0x2498e7c5,0x1b040107,0x6e20022e,0x3868013a}},	//   _burm_, _кӯҳн, _xonb, _wkcr_, 
   {{0x26c009ad,0x6838022a,0xdb2401e2,0x00000000}},	//   asio_, _síde, _خوښی, --, 
   {{0x68382b76,0xd7f4013d,0xd17400fb,0x5bc493d3}},	//   _píde, _узмы, ҙылы, _वयोव, 
   {{0x81ac2f8b,0x25b8002d,0x27e401b8,0x13a800dd}},	//   _কাজ_, _ferl_, _ömna_, پنڈی_, 
   {{0xb9dca38c,0x6839a0c7,0x25b8002d,0x2499a0c8}},	//   _እና_, _víde, _gerl_, _furm_, 
   {{0x3ea40c6a,0xe4a40261,0xb7b80798,0xd3940ce8}},	//   _atot_, _мрто, _joão, _ләлә_, 
   {{0x6e21a0c9,0xde880208,0x25b8013d,0x00000000}},	//   _sonb, _sịp_, _zerl_, --, 
   {{0x7d0803ac,0x6e21a0ca,0xdd3800ef,0x00000000}},	//   _arfs, _ponb, _jāņt, --, 
   {{0x30e410f5,0x7a2800af,0x9f440421,0x6e20014f}},	//   _відб, _kütu, lemû_, _qonb, 
   {{0xfe6d683d,0x3ea40166,0x6e205d86,0xab00008e}},	//   رگه_, _etot_, _vonb, _küçü_, 
   {{0xb69800e4,0x6e21a0cb,0x00000000,0x00000000}},	//   _erâi, _wonb, --, --, 
   {{0x6e2063d1,0x7d0879cc,0x5fdc0490,0x7a2803e0}},	//   _tonb, _erfs, _यातल, _lütu, 
   {{0xabac1c5c,0x9e642c04,0x00000000,0x00000000}},	//   _ﺳﯩﻨﺎ, _واون, --, --, 
   {{0xe8140073,0x26c003cb,0x00000000,0x00000000}},	//   डाला_, wsio_, --, --, 
   {{0x81ac015b,0x26c00428,0x25b803b2,0x38780092}},	//   _কাছ_, tsio_, _serl_, _በእለቱ_, 
   {{0x25b9a0cc,0x85e9a0cd,0x26c00006,0x249800c5}},	// [2c920] _perl_, лдав_, usio_, _surm_, 
   {{0x26c1a0ce,0x6ecc038e,0x00000000,0x00000000}},	//   rsio_, _दिनु, --, --, 
   {{0x26c1a0cf,0x95980372,0x25b80112,0x645987d6}},	//   ssio_, ртуу_, _verl_, évio, 
   {{0xf484c0da,0x26c095bb,0x25b92aa7,0x00000000}},	//   مانی, psio_, _werl_, --, 
   {{0x2499a0d0,0xb14001c0,0x6f080076,0x49f40327}},	//   _wurm_, үнчл, _nrgc, _བྲོལ_, 
   {{0x24983f5b,0x98a40153,0x7a280205,0xb6a0010a}},	//   _turm_, šlą_, _fütu, _хирл, 
   {{0xa2c402ab,0x3ea5a0d1,0x20dc00f3,0xc29001d5}},	//   _रिक्, _stot_, kšiš_, _کیتب, 
   {{0x7a2817da,0x629c00b0,0x32f000d1,0xa1581de6}},	//   _hütt, _ōrou, تكۇز, лаһу_, 
   {{0x2ca4070d,0x7a2800af,0xde70002b,0x7e28187f}},	//   _atnd_, _kütt, _apāṃ_, гіна_, 
   {{0xb8f8031c,0x5d5402e8,0x7d180175,0x00000000}},	//   _རྀ_, жкот, txts, --, 
   {{0x49f40003,0x7a29a0d2,0xdd902263,0x409400c6}},	//   _བྲེལ_, _mütt, بود_, _الصر, 
   {{0xfba8034b,0x7a280b70,0xb600025c,0x426c0092}},	//   ытой_, _lütt, ġġit, ስገኘት_, 
   {{0x3ea4079b,0x7b6403c5,0xb078010f,0x79a40139}},	//   _utot_, стне, _ענדז, йрве, 
   {{0x60dc343a,0xfbd804e4,0xdb1c0200,0x00000000}},	//   _ärms, _भावम, lasë, --, 
   {{0xa9357f4c,0xb94c0092,0xe8e00208,0x7d0803ac}},	//   перш, _አድራጎ, ườm_, _urfs, 
   {{0x98a591ab,0x2005a0d3,0x6458ad72,0xed5c0118}},	//   çlı_, ndmi_, évil, ážek_, 
   {{0xf771a0d4,0x7a29a0d5,0x00000000,0x00000000}},	// [2c930] سار_, _bütt, --, --, 
   {{0xdb0c00b8,0x200400a2,0x00000000,0x00000000}},	//   _udañ, hdmi_, --, --, 
   {{0x8e7c01e4,0xdb1cc902,0x41d0190e,0x5398011c}},	//   ntŝa, ggsö, _साजस, авея_, 
   {{0x69d80628,0xd3740640,0xbec000e2,0xc888004b}},	//   _över, олећ, _ķīna, _پخپل_, 
   {{0x7bdc0a40,0x7a29a0d6,0x00000000,0x00000000}},	//   _mcqu, _fütt, --, --, 
   {{0x7a29a0d7,0x64480024,0x00000000,0x00000000}},	//   _gütt, _įdie, --, --, 
   {{0x37e40489,0x92d80154,0xb4b001af,0x00000000}},	//   _སྡོད, ়বে_, _хибә, --, 
   {{0xddd4041a,0x7bdc003a,0x7a280254,0xddc80064}},	//   _čaši, _ncqu, _küts, bodū, 
   {{0xb8d86d7e,0xcdf40948,0xb6980022,0xc44403e6}},	//   _ངས_, очны, _erâv, _بینن_, 
   {{0x7bdda0d8,0x79940472,0xccc5a0d9,0x7a295a5b}},	//   _acqu, _ngxw, обой, _müts, 
   {{0x683800d2,0x228401c0,0xdb1c002e,0xd1307640}},	//   _lída, _хутг, basë, _تما_, 
   {{0x249c00d7,0x00000000,0x00000000,0x00000000}},	//   ívmi_, --, --, --, 
   {{0xeea800d8,0xdb1c0066,0x49f40327,0x99800118}},	//   _стек_, nasè, _བྲུལ_, _bohů_, 
   {{0x7bdc16b8,0x00000000,0x00000000,0x00000000}},	//   _ecqu, --, --, --, 
   {{0x290da0da,0x160c0c2e,0x752007c5,0x7a287a78}},	//   ída_, _सफ़र_, änzl, _rütt, 
   {{0x7a29a0db,0x683803b2,0xdb1c0066,0x2bd401f9}},	//   _büts, _bída, kasè, _थाटा, 
   {{0xdb0c06ed,0x4649a0dc,0x7a282d1e,0xb94c001f}},	// [2c940] _reaç, азан_, _pütt, _አድርጎ, 
   {{0x683800cf,0x9f440165,0x200400d7,0x00000000}},	//   _dída, temú_, zdmi_, --, 
   {{0x69dda0dd,0xed9002d3,0x22580790,0x00000000}},	//   mgre, _መቓብር_, _ırk_, --, 
   {{0x69dd4172,0x87d4c56f,0xd90c3293,0x00000000}},	//   lgre, _بغدا, _حیف_, --, 
   {{0xdb1c020c,0x69dc01f5,0xa5640014,0x248000e2}},	//   gasè, ogre, _کۯان, ķim_, 
   {{0x69dcf6ad,0x86740124,0x5eb80154,0x00000000}},	//   ngre, _фымц, _আমলে, --, 
   {{0x69dc00a3,0xabdc0150,0x68fc0142,0x60f80107}},	//   igre, _ﺃﻋﻁﺎ, nwrd, ёния_, 
   {{0x21200bb8,0x3ec4453f,0xf9900375,0x00000000}},	//   ćih_, особ, ורו_, --, 
   {{0x69dc03b2,0xdb1c4d29,0x200400d7,0xc3040244}},	//   kgre, rasë, rdmi_, _ببزو, 
   {{0xfd88016c,0xb698054e,0x69dc01bf,0xfe70007b}},	//   иёни_, _grâu, jgre, بدع_, 
   {{0x69dc4515,0x61f9a0de,0xe6280051,0x9980013a}},	//   dgre, mevl, _đỗ_, _rohů_, 
   {{0x69dc800c,0x161002ab,0x61f9a0df,0x60d8047e}},	//   egre, _डोनर_, levl, muvm, 
   {{0x69dda0e0,0x1be0007d,0xb4d400cd,0x00000000}},	//   fgre, ग्गल_, _ाम्_, --, 
   {{0x61f91ba9,0xdb1c0066,0x68fc03cb,0xea000051}},	//   nevl, nasé, fwrd, đến_, 
   {{0x7a3c0316,0xf848fbc4,0x683806ea,0x61500023}},	//   vště, ачай_, _sída, _ክንበጽ, 
   {{0x220400b0,0x68380789,0x61f8a2c1,0x7a280254}},	//   _hūhē_, _pída, hevl, _püts, 
   {{0x69dc010a,0x2b4400f7,0x60d8014f,0xdb1d671d}},	// [2c950] bgre, _жээг, huvm, kasé, 
   {{0x69dda0e1,0x61f8193c,0x1a6520d4,0x68380413}},	//   cgre, jevl, _ریزی_, _vída, 
   {{0x61f9a0e2,0x60d80455,0x4ddc00bc,0xfde0000d}},	//   devl, juvm, _खासै_, _खानस_, 
   {{0x60d8014f,0x683803b2,0x569401c6,0x7a2803e0}},	//   duvm, _tída, _намт, _tüts, 
   {{0x03b40046,0xdecc001f,0x66c8014b,0x395c0205}},	//   яқты_, _በእኔ_, _мург_, ğusu_, 
   {{0x61f9a0e3,0xdb1da0e4,0x62341503,0x11880139}},	//   gevl, rasè, мечу, бәеп_, 
   {{0x7a0c00c0,0x00000000,0x00000000,0x00000000}},	//   mėtė, --, --, --, 
   {{0xdb1c0022,0x7a0c0153,0xb600031c,0x00000000}},	//   aasé, lėtė, ġġut, --, 
   {{0xf1a40a15,0x69dda0e5,0x0d98e9b5,0xed6000bc}},	//   _дрен, ygre, йтны_, _mužů_, 
   {{0xfe400801,0x60d80455,0x82600ed1,0x6fd400bc}},	//   еньо, buvm, _كۇنن, _याकू, 
   {{0xc44401d9,0x69dd4914,0xfbdc0208,0x00000000}},	//   _بیۆن_, vgre, hiêu_, --, 
   {{0xf19000c7,0x69dc0175,0xfba41a55,0xfbac0150}},	//   _еиҕь, wgre, कुलम, _ﺳﯩﺮﻛ, 
   {{0x69dda0e6,0xc05000c8,0x64b4010b,0x6838013a}},	//   tgre, _אזא_, _işiň, _bídn, 
   {{0xc60805f9,0xfc3c0548,0xed54024c,0x00000000}},	//   _होंठ_, ahí_, _қоқ_, --, 
   {{0x06e403d4,0xfc3c01e7,0xf98000f3,0x00000000}},	//   নিছি, bhí_, егро, --, 
   {{0xfc3da0e7,0x61f804cc,0xb9000a89,0xf18800d1}},	//   chí_, zevl, эзск, ﻗﯘﻏﯘ, 
   {{0x7a280793,0x61f848d3,0xfc540375,0xeb9801a9}},	// [2c960] _vütr, yevl, _מבקש_, _лиқ_, 
   {{0x68fc03cb,0x8ebc00eb,0x00000000,0x00000000}},	//   pwrd, _আমাগ, --, --, 
   {{0x399805e1,0xda65a0e8,0x7a2800c5,0x07a5a0e9}},	//   _לייד, _تايي, _tütr, _нанн, 
   {{0xdb1c020c,0x14580006,0x60d8014f,0x273c0092}},	//   wasé, ошчы_, vuvm, _በጉልበ, 
   {{0x224c020b,0x61f9a0ea,0x60d8014f,0x2bc40073}},	//   _pmdk_, tevl, wuvm, _वजना, 
   {{0x53800131,0x60d80455,0x15b00137,0xe81428fe}},	//   тқуз, tuvm, _لەكس, डाका_, 
   {{0x61f9a0eb,0xdb1c4de4,0x00000000,0x00000000}},	//   revl, rasé, --, --, 
   {{0x61f807f5,0xf99002e4,0x5f9408da,0xdb1c00e4}},	//   sevl, ערה_, мийт, sasé, 
   {{0x683800d2,0xdb1c0098,0xb698054e,0xb8840092}},	//   _lído, pasé, _urât, _በእጥፍ_, 
   {{0x68382b76,0x88c4002b,0x60d8014f,0x00000000}},	//   _oído, _kuśā, puvm, --, 
   {{0xfc3c0597,0x1bd4299f,0x60d8016d,0x00000000}},	//   thí_, моня, quvm, --, 
   {{0x008400db,0x3178010f,0xb4f8011a,0x44fc01ef}},	//   _элео, _פראמ, זלטר, _mů_, 
   {{0x7a2803b9,0x6fb000ae,0x00000000,0x00000000}},	//   _bütp, _أمها, --, --, 
   {{0x7de5a0ec,0x683801ef,0x260c1bbb,0x00000000}},	//   _رستم, _bído, _डोली_, --, 
   {{0xdb1c019f,0xbb442e56,0xae000ef6,0x68380118}},	//   casî, ﺘﺎﻥ_, _سويى, _vídn, 
   {{0x320444ef,0x00000000,0x00000000,0x00000000}},	//   zdny_, --, --, --, 
   {{0x68380162,0x9c7c007f,0x56946d5f,0xd758039e}},	// [2c970] _tídn, ntčm, даат, циац_, 
   {{0x24840280,0x5a341cb8,0xad20215c,0x2c640205}},	//   _ahmm_, _цнот, _زىۋى, rıde_, 
   {{0x2a6404d7,0xa8a400a7,0x629c00b0,0x5fbc20f0}},	//   émbe_, _пряк, _ōrop, ईराल, 
   {{0xdb1c0054,0xfbdc24ba,0x6838012c,0x94189cb8}},	//   nasï, ngê_, _jídl, южет_, 
   {{0xfafc00eb,0xc7d4011a,0xa7140064,0x7a0c0064}},	//   nwë_, _קושי_, _змяі, pėtė, 
   {{0x2485a0ed,0x683801ef,0x916400f2,0x00000000}},	//   _ehmm_, _lídl, وهشه, --, 
   {{0xfafc0036,0x3ff00131,0x6ebc01ad,0x00000000}},	//   hwë_, چكىر, लीनु, --, 
   {{0x6595a0ee,0x3ff01e4a,0x0ea8234c,0x00000000}},	//   _часу, نكىر, окий_, --, 
   {{0x1c2000bc,0x00000000,0x00000000,0x00000000}},	//   यानल_, --, --, --, 
   {{0xf1a40b96,0xabac0131,0x712400cf,0x00000000}},	//   _хран, _ﺳﯩﻴﺎ, _ىرال, --, 
   {{0x63a4008c,0xe0d03be1,0x8e7c01e4,0x00000000}},	//   þing, _مزن_, stŝo, --, 
   {{0x8fd00166,0x00000000,0x00000000,0x00000000}},	//   _рәкә, --, --, --, 
   {{0x40840014,0x20240030,0x1fb40154,0xda1847b8}},	//   _تھوپ_, úsiť_, _টাচস, दांत_, 
   {{0x68380077,0xfc540092,0x6014022e,0x00000000}},	//   _pído, ፈለገው, lоmа, --, 
   {{0x9f6401b8,0x7cd400f7,0x12e00150,0x00000000}},	//   ütöl_, _قووز_, _ﺍﻻﻴﺭ, --, 
   {{0x2fdda0ef,0x00000000,0x00000000,0x00000000}},	//   ngug_, --, --, --, 
   {{0xebe402dd,0xdcf800de,0x88c400b8,0x00000000}},	// [2c980] _жоқп, _izvā, _suśā, --, 
   {{0x7b8400d1,0x44fc01ef,0x290c01e3,0x00000000}},	//   _غايە, _pů_, ådas_, --, 
   {{0x290400da,0x248400a3,0x7a6400db,0x88840395}},	//   āmas_, _phmm_, _تئيە, _олож, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x82f80101,0x27e1a0f0,0x00000000,0x00000000}},	//   تراز_, mgin_, --, --, 
   {{0x27e1a0f1,0x68440248,0x00000000,0x00000000}},	//   lgin_, _fìdù, --, --, 
   {{0x27e003d1,0xf50040c4,0xe1380024,0x1c2009b2}},	//   ogin_, _изро, язкі_, यामल_, 
   {{0xdecc001f,0x2fdc1bce,0xefb001d5,0xe8145c0e}},	//   _በእኛ_, ggug_, نیمگ, डाटा_, 
   {{0x27e092eb,0x06b000cc,0x00000000,0x00000000}},	//   igin_, _চিডি, --, --, 
   {{0x442466dc,0x68380232,0xddc8068f,0x63a40024}},	//   ljo_, _sídl, widł, žind, 
   {{0xb141a0f2,0x4425a0f3,0xdb1c0054,0x9c7c0109}},	//   _инфл, ojo_, tasï, stčm, 
   {{0xbc4802bf,0x7f840345,0x4ebc00cc,0x00000000}},	//   ічне_, _قلان, _আমৰল, --, 
   {{0xf044d902,0x27e1a0f4,0x442406ed,0x28a4033f}},	//   _تعلی, dgin_, ijo_, _खूबि, 
   {{0x27e001d9,0xceac0451,0x6e940064,0x00000000}},	//   egin_, _اڙي_, _жвір_, --, 
   {{0xdb1c1ffb,0x4425a0f5,0x998000b0,0x27e004e6}},	//   masí, kjo_, _tahō_, fgin_, 
   {{0x27e1a0f6,0x44242f99,0x7c65a0f7,0xb8f41223}},	//   ggin_, jjo_, _تاتل, _सि_, 
   {{0x4425a0f8,0x290c049f,0x929c033f,0x00000000}},	// [2c990] djo_, ådar_, _osła, --, 
   {{0x4425a0f9,0x27e00009,0x2c640b97,0x00000000}},	//   ejo_, agin_, mıda_, --, 
   {{0xb69800e4,0x2c65a0fa,0x44240010,0xc0b80092}},	//   _erâp, lıda_, fjo_, ተማሪ_, 
   {{0xe3b0004b,0x4425a0fb,0x00000000,0x00000000}},	//   لره_, gjo_, --, --, 
   {{0xc7d404ae,0x64ac00fd,0x2c640ac1,0xdb1c02f0}},	//   _אורי_, _ağid, nıda_, kasí, 
   {{0x44258ab3,0x45a00136,0x5fdc01f9,0x00000000}},	//   ajo_, _مەكك, _याउल, --, 
   {{0x2efda0fc,0x4425a0fd,0x8fd01945,0xe8140073}},	//   wwuf_, bjo_, гәлә, डाचा_, 
   {{0x2c640cc1,0x20542eca,0x22800109,0xfbd80864}},	//   kıda_, ктыр, ròka_, _भागम, 
   {{0xdb1c04d7,0x8e543981,0x645800cf,0x8fa40124}},	//   fasí, етні, èvie, _ҟале, 
   {{0xdb1c3b7b,0x27e00bbc,0xed5c00d0,0xe1f0027d}},	//   gasí, zgin_, ážok_, _نسم_, 
   {{0x63a45127,0xd1300244,0x05e0134e,0x27e00205}},	//   žine, _حما_, _पासब, ygin_, 
   {{0x691806d6,0xcfe8034c,0xcb69a0fe,0x290c0393}},	//   _ṋea, _رفته_, заме_, ædam_, 
   {{0x683802d2,0x2c6403e0,0x00000000,0x00000000}},	//   _fídj, gıda_, --, --, 
   {{0xdb1c04d4,0x44240010,0x8b8400d1,0x27e0031c}},	//   casí, zjo_, _ۋەدە_, wgin_, 
   {{0x3da410f5,0x4425a0ff,0x00000000,0x00000000}},	//   _якщо_, yjo_, --, --, 
   {{0xdcf8005f,0x27e0030a,0x2c640205,0x00000000}},	//   _uzvā, ugin_, bıda_, --, 
   {{0x27e1a100,0xf74000b1,0x4425a101,0xd6c400d1}},	// [2c9a0] rgin_, гето, vjo_, китқ, 
   {{0x6b85a102,0xdb1c019f,0xf77c00d8,0xfb8400fd}},	//   _izig, basâ, _abçs_, _ябык_, 
   {{0x2b8c01fb,0x75d00b24,0x00000000,0x00000000}},	//   _ếch_, طينا, --, --, 
   {{0x4425a103,0x14d000dc,0x03a4928a,0xdb1da104}},	//   ujo_, _हिरण, хидо, zasí, 
   {{0x4425a105,0xdb0c006a,0x76d80107,0xcfa801ec}},	//   rjo_, _âkôn, _нурӣ_, _ﺴﺘﻘﺒ, 
   {{0x4425a106,0x6b840451,0xfbdc0208,0x6724025c}},	//   sjo_, _mzig, hiêp_, mxij, 
   {{0xc0580046,0x2c6467ab,0x4425a107,0x15b000d1}},	//   зіп_, zıda_, pjo_, _ئەمس, 
   {{0x6b840521,0x2c642fbe,0xdf1806b4,0x00000000}},	//   _ozig, yıda_, джич_, --, 
   {{0x6441a108,0x7de4005e,0x72d02002,0x6b85a109}},	//   _ilmi, нінд, _مەنچ, _nzig, 
   {{0xc0b8001f,0xdd9407e6,0xdb1c00c7,0x2b1400bc}},	//   ተማር_, капы, yasâ, दिनु_, 
   {{0x6b8486ba,0x3f800306,0x6838032e,0x00000000}},	//   _azig, ťku_, _vídj, --, 
   {{0x2c6467ab,0xbea40395,0x00000000,0x00000000}},	//   tıda_, _задк, --, --, 
   {{0x644001ab,0x9f940124,0xe7e4012d,0x00000000}},	//   _mlmi, _рыжә, गलना_, --, 
   {{0x2c6412ca,0x6b84cd2f,0x3f8c031c,0x00000000}},	//   rıda_, _dzig, ħmuġ_, --, 
   {{0x6b85a10a,0x6441a10b,0x2c64123d,0xfc3001f7}},	//   _ezig, _olmi, sıda_, _محظ_, 
   {{0x5b140124,0x6d780375,0x2c642c78,0x2a6400e4}},	//   _амит, _מאוח, pıda_, ĩmba_, 
   {{0xd6d1a10c,0x947404d3,0x6724009a,0x68385d85}},	// [2c9b0] شقا_, ۆگرا, gxij, _mídh, 
   {{0x6441a10d,0xe7840261,0xd68c0150,0x00000000}},	//   _almi, ѓуто, _ﺒﺎﻗﺭ_, --, 
   {{0x947420c1,0xb69800e4,0x6b841418,0xbb440873}},	//   نگرا, _isâm, _zzig, ﺘﺎﻱ_, 
   {{0x644001ab,0xe2c8004b,0x62880108,0x00000000}},	//   _clmi, ځونو_, _ahdo, --, 
   {{0x91e4a046,0x260c2983,0xdb1c05da,0x661c010a}},	//   воле, _डोकी_, nasà, _fnrk, 
   {{0x6441a10e,0x826000d1,0xd17400db,0xa294003b}},	//   _elmi, لۇقن, кыйы, гачі, 
   {{0xfa1003f4,0x691806d6,0xdb1c00e4,0x4ebc00cc}},	//   _সকাল_, _ḽen, hasà, _আমেল, 
   {{0x6288049b,0x6458004a,0xdb1c05da,0x644001ab}},	//   _ehdo, évit, kasà, _glmi, 
   {{0x0e65a10f,0x68380332,0x932400f1,0xafe001d5}},	//   ккин, _dídh, _ګرځن, воқл, 
   {{0xf1a802f2,0x3da40166,0x00000000,0x00000000}},	//   _رائه_, ккьо_, --, --, 
   {{0x6b8400dd,0x8c441c61,0x4c8579c1,0xefb802d3}},	//   _szig, вене, клов, ተላይ_, 
   {{0x69d801d3,0x6288036e,0x06cc0ef6,0x00000000}},	//   _övez, _zhdo, _ﺗﻪﺑﻪ, --, 
   {{0x6724003d,0xdb1c315a,0xbc600a89,0x00000000}},	//   xxij, vasã, рвяк, --, 
   {{0xc330025f,0xbd200356,0x00000000,0x00000000}},	//   סום_, _ţâşn, --, --, 
   {{0x929c033f,0x0d2004da,0x291c0010,0x00000000}},	//   _osło, _түнү, _švab_, --, 
   {{0x6b84da65,0xcc88c019,0xe7c00154,0x3ce802f0}},	//   _tzig, _تنبه_, ইল্য, živí_, 
   {{0xdb1c0798,0x7cf40112,0x00000000,0x00000000}},	// [2c9c0] rasã, _türö, --, --, 
   {{0x68380261,0xc9540166,0x45340408,0x00000000}},	//   _mídi, _атмы, кхет, --, 
   {{0x683931b9,0x6aa4eada,0xdb1c03da,0xb904009e}},	//   _lídi, _huif, masá, _মৈ_, 
   {{0x6aa5a110,0xf48435cd,0xdb1da111,0x07a401ec}},	//   _kuif, نانی, lasá, _шамн, 
   {{0x6aa407ea,0x00000000,0x00000000,0x00000000}},	//   _juif, --, --, --, 
   {{0x6aa40270,0xdb1c659a,0x91c001e0,0xb69800e4}},	//   _muif, nasá, йҙул, _ysâm, 
   {{0x645820ef,0x9c7c0552,0x6aa401a4,0x64400030}},	//   évis, luče, _luif, _tlmi, 
   {{0xdfd00597,0x6aa4030a,0x6440a504,0xdb1c035b}},	//   حية_, _ouif, _ulmi, hasá, 
   {{0x73302928,0x020444e4,0x82a435c7,0xdb1c00e5}},	//   _پىلا, _изан, _разж, kasá, 
   {{0xb22005d9,0x683801e7,0xa6a40154,0x06cc5f32}},	//   _پڙهي, _dídi, _ওবায়, _ﺗﻪﺟﻪ, 
   {{0x7d68003b,0x00000000,0x00000000,0x00000000}},	//   ьшив_, --, --, --, 
   {{0x657d4ea5,0x49a40032,0x6aa40332,0x5ec401ec}},	//   _myrh, ғырғ, _buif, _бидғ, 
   {{0xc5d8045e,0x19c423c9,0x7b64022e,0xfc4401ef}},	//   ঠ্যপ, ләнг, ттне, jmíň_, 
   {{0xaa643523,0x6aa40549,0xdb1da112,0xee3401c4}},	//   атск, _duif, rasà, _инч_, 
   {{0x657c00ee,0xa8a4004e,0x00000000,0x00000000}},	//   _nyrh, иртк, --, --, 
   {{0x6ebc9d6d,0xfaa4006c,0x6aa5a113,0xb8f80316}},	//   लीवु, _ишон, _fuif, _डट_, 
   {{0x7a2848b3,0x6aa40137,0xe8941064,0x765400b5}},	// [2c9d0] _mütz, _guif, рать, tixy, 
   {{0x657c0042,0xcb1008a8,0x7a28002f,0x2cb00118}},	//   _byrh, _פלי_, _lütz, řadů_, 
   {{0x657c0368,0x76440014,0x555401e2,0x00000000}},	//   _cyrh, _ییرِ_, دپار, --, 
   {{0x7a280730,0x6ac401b9,0x9c7c0010,0x06b00154}},	//   _nütz, _حقیم, buče, _চিরি, 
   {{0x64580137,0x3f84006f,0xe1f000ec,0x00000000}},	//   èvia, _nzou_, ڪسن_, --, 
   {{0x6838004e,0x657da114,0x11d8007b,0x91e400d8}},	//   _rídi, _fyrh, روعة_, уоке, 
   {{0x63a425b7,0x3f845dad,0x260c0316,0x657c03cb}},	//   žina, _azou_, _डोटी_, _gyrh, 
   {{0x4f080372,0x4fe80fc0,0x63e41075,0x683801ef}},	//   енин_, хмин_, _ەسەك, _pídi, 
   {{0xdb1c2af5,0xdea4036b,0xcf24007b,0x00000000}},	//   yasá, لینی, ارعي, --, 
   {{0xb2849b81,0x1cdc0327,0x00000000,0x00000000}},	//   _рыбк, _ཤྀང_, --, --, 
   {{0x6aa5a115,0xdb1d19a1,0x00000000,0x00000000}},	//   _suif, vasá, --, --, 
   {{0x69181682,0x25540020,0xdb1c00d2,0x68380174}},	//   _ḓel, _ጋዜጠኞ, wasá, _tídi, 
   {{0x6aa4003a,0x8e74010b,0xdb1c01d3,0x00000000}},	//   _quif, _йукч, tasá, --, 
   {{0x9c7c098d,0x06b004c5,0xfaa02a65,0xc0ec0208}},	//   vuče, _চিলি, саро, _nướu_, 
   {{0x7aec074d,0xdb1da116,0x00000000,0x00000000}},	//   atct, jasæ, --, --, 
   {{0x68380af2,0x9c7c0552,0x6aa420d6,0x7d78008f}},	//   _lídv, tuče, _tuif, _אנצו, 
   {{0x7aec074d,0x3ab00022,0xb8e8791c,0xc0ec004d}},	// [2c9e0] ctct, _гәст, _रौ_, _bướu_, 
   {{0x9c7cabea,0xf5e4084c,0x66e40aac,0x2c18000d}},	//   ruče, лмул_, лоға, _बोतू_, 
   {{0xa8540032,0x74a802dd,0xdb1c02d2,0x00000000}},	//   _ҡеүә, есің_, gasæ, --, 
   {{0x434404b4,0x35a1a117,0x9c7c0841,0x82a44f55}},	//   леев, _ҳарг, puče, гадж, 
   {{0x36d00064,0x580401ee,0x00000000,0x00000000}},	//   _лоўр, _тояғ, --, --, 
   {{0x35a0152d,0x38c82a60,0x2d84009b,0x61880023}},	//   _гарг, _تایی_, _ozne_, _ብሕልፊ_, 
   {{0x704c0023,0x3664014b,0x00000000,0x00000000}},	//   _ንህዝቦ, _саро_, --, --, 
   {{0x7f500023,0x44ec0118,0xdb0c0254,0x7534010f}},	//   _ክትወጽ, mý_, _peaü, _גאלד_, 
   {{0x44ec0308,0xceac0451,0x62240150,0x7dc4010b}},	//   lý_, وڙو_, _پواە, лёнд, 
   {{0x225808a5,0xdb1c03b9,0x00000000,0x00000000}},	//   _örk_, lasç, --, --, 
   {{0x44ec0e96,0x9c7c1b24,0x00000000,0x00000000}},	//   ný_, jučc, --, --, 
   {{0x7aec074d,0x9b9400a8,0x00000000,0x00000000}},	//   ttct, иинц, --, --, 
   {{0x44ec2195,0x00000000,0x00000000,0x00000000}},	//   hý_, --, --, --, 
   {{0xdd95a118,0x44ec1d55,0x84f4012c,0x7aeda119}},	//   _калы, ký_, ीबाट_, rtct, 
   {{0x19947a9f,0x00000000,0x00000000,0x00000000}},	//   равя, --, --, --, 
   {{0x57b41ff0,0x44ec0122,0x00000000,0x00000000}},	//   рбат, dý_, --, --, 
   {{0x3ea40108,0x00000000,0x00000000,0x00000000}},	// [2c9f0] _juot_, --, --, --, 
   {{0x3ea5a11a,0x81c0005f,0xf56802dd,0xb8d800eb}},	//   _muot_, šēja, ншек_, _ঘি_, 
   {{0x3ea5398e,0x35680408,0xdb10005c,0x00000000}},	//   _luot_, хран_, æfæl, --, 
   {{0x611c0356,0x63a402f0,0x48c00166,0x61fc0166}},	//   _mălă, žinn, _фәра, _ırla, 
   {{0x3ea41570,0x7a280790,0x3a3055db,0x61fc01d3}},	//   _nuot_, _süty, _koxp_, _űrla, 
   {{0x44ec0122,0xd5f8008f,0x73c000fb,0x00000000}},	//   bý_, _בפֿר, рҡҡа, --, 
   {{0xdb0c0005,0xdb1c0793,0xf4840139,0x00000000}},	//   _meañ, lasä, _буан, --, 
   {{0x3ea5a11b,0xf77c0240,0x683802d2,0x63a401e4}},	//   _buot_, _kyç_, _fídu, ɾino, 
   {{0xec9c0150,0xdb1c07a3,0x00000000,0x00000000}},	//   _ﺍﻟﺘﺠ_, nasä, --, --, 
   {{0xdb0c0077,0x704801e1,0x611c054e,0xcbe00154}},	//   _neañ, _dájọ, _bălă, _বসেছ, 
   {{0x611c084c,0xdb1c000d,0x622400d1,0x00000000}},	//   _călă, hasä, _دىلل, --, 
   {{0xdb1c340f,0x6c6800e5,0x00000000,0x00000000}},	//   kasä, الحہ_, --, --, 
   {{0x3ea404cc,0xe0d001d9,0xf4140183,0x2c0400fb}},	//   _guot_, _وٲے_, _থকাৰ_, _һүнм, 
   {{0xca75a11c,0x4a740598,0xfc3c03a0,0x00000000}},	//   румы, рымт, akí_, --, 
   {{0x611c0311,0xabc401af,0xab840092,0x00000000}},	//   _gălă, _лайҙ, ሯቸዋል_, --, 
   {{0x44ec0745,0xfc3c0030,0x00000000,0x00000000}},	//   vý_, ckí_, --, --, 
   {{0xdb1c01e6,0x611c0356,0x3a30045a,0x00000000}},	// [2ca00] gasä, _zălă, _foxp_, --, 
   {{0x44ec03c6,0x2ca4df52,0x7621a11d,0x6f080334}},	//   tý_, _kund_, омуз, _msgc, 
   {{0x9c7c0989,0x2ca4002e,0x68380162,0xd44c0241}},	//   luča, _jund_, _sídu, _tẹ̀ǹ, 
   {{0x2ca5a11e,0x44ec0745,0x044415ed,0x2ca00067}},	//   _mund_, rý_, једн, _jiid_, 
   {{0x63a5a11f,0x066000c7,0x2ca0a9b6,0x9c7c0427}},	//   žino, _дҵаҟ, _miid_, nuča, 
   {{0x69181682,0x44ec1705,0xc8d80574,0x325002bf}},	//   _ṋek, pý_, _बटाट, овір, 
   {{0x3ea5a120,0x30a007d8,0xf48401b9,0x00000000}},	//   _suot_, орыв, _چاقی, --, 
   {{0x768805d1,0x683803b2,0x7d091c62,0xdb1c007c}},	//   rüye, _tídu, _rsfs, laså, 
   {{0x3ea5a121,0x9c7c07f5,0x611c0311,0x2a780e78}},	//   _quot_, juča, _sălă, korb_, 
   {{0x2ca5a122,0x9c7c08ad,0x611c054e,0x3ea4004d}},	//   _bund_, duča, _pălă, _vuot_, 
   {{0x2ca00009,0xbff00137,0x5c7400db,0x00000000}},	//   _biid_, _дүйш, йлот, --, 
   {{0x3ea4060a,0x2ca41574,0x2ca1a123,0xfbdc07c5}},	//   _tuot_, _dund_, _ciid_, chêl_, 
   {{0xfb848443,0x2005a124,0xd00c00b2,0x2ca00014}},	//   рынн, memi_, _سڄي_, _diid_, 
   {{0x2005a125,0x225c0270,0x2ca40c30,0xfc3da126}},	//   lemi_, nivk_, _fund_, skí_, 
   {{0x2ca4007f,0xd8a8511e,0x2ca056df,0x6e4000ea}},	//   _gund_, اهرو_, _fiid_, _фејз, 
   {{0x2005a127,0x61b40882,0x9c7c39ae,0x31140882}},	//   nemi_, ुरुष, buča, थितः_, 
   {{0x2ca407c5,0xb5a427a8,0xa87401ec,0x55a401d3}},	// [2ca10] _zund_, арей, ілуі, مجاہ, 
   {{0x2005a128,0x22802558,0x225c0010,0xdb1c01f4}},	//   hemi_, bòki_, jivk_, rasä, 
   {{0x2005a129,0xd04003be,0xdff801ad,0x00000000}},	//   kemi_, _evlə, ्जाद_, --, 
   {{0x2005a12a,0xa4d8005b,0x00000000,0x00000000}},	//   jemi_, рдцу_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x362001d9,0x8e7c01e4,0xa5e4011c,0x00000000}},	//   _بوسہ, kuŝa, _мюсл, --, 
   {{0x64680086,0xc690008f,0xa4d400d4,0x00000000}},	//   òriò, _מאך_, _морі, --, 
   {{0x2ca40639,0xd02447b3,0x2a781529,0x2005a12b}},	//   _rund_, смий, zorb_, gemi_, 
   {{0x2ca5a12c,0x2ca0002d,0x00000000,0x00000000}},	//   _sund_, _riid_, --, --, 
   {{0x2ca5a12d,0x2ca1a12e,0xd250fe86,0xd6a800eb}},	//   _pund_, _siid_, _عنا_, _ওবায, 
   {{0x200400aa,0x63b806ed,0xc5f0123b,0x00000000}},	//   bemi_, _àaná, הדי_, --, 
   {{0x68380122,0x2004012c,0x2ca40036,0xaadc00ab}},	//   _lídr, cemi_, _vund_, _बिदक, 
   {{0x2ca41bce,0x64ac06be,0x0b59a12f,0x2ca0000d}},	//   _wund_, _ağil, урны_, _viid_, 
   {{0x2ca5a130,0x9c7c098d,0x2ca0feeb,0x8c640166}},	//   _tund_, ruča, _wiid_, ртүд, 
   {{0x2ca00225,0x6e204098,0x9c7c0552,0xac680092}},	//   _tiid_, _innb, mučn, ተቻለም_, 
   {{0xbd8401d9,0x7644010b,0x2a79a131,0xe6b401d5}},	//   _دۆپن_, _aljy, sorb_, قلرگ, 
   {{0x64ac05d1,0x86c4007b,0x68380174,0xdbf00154}},	// [2ca20] _eğil, صيان, _síds, _জোকস_, 
   {{0xc928009d,0x4da400cc,0xdb2401e1,0x00000000}},	//   _боож_, _খজুৱ, _ìsáp, --, 
   {{0x200585ac,0x985c0023,0x3a34011a,0x3e58010f}},	//   yemi_, _ተወሲኑ_, _הרים_, נדעס, 
   {{0x032422e9,0xf990008f,0x200401c4,0xc32400ee}},	//   йден, _מרת_, xemi_, ймек, 
   {{0x06b011ba,0x2005a132,0x9c7c02fb,0x291807c5}},	//   _চিকি, vemi_, kučn, lvra_, 
   {{0x9c7c5946,0x200402ce,0x932416ac,0xd6c4023b}},	//   jučn, wemi_, ترمن, _фирқ, 
   {{0xa56401d9,0x60c40e3c,0x9c7c01a6,0x29180af9}},	//   _بۯان, ćimo, dučn, nvra_, 
   {{0x9ed800ee,0x6e2003cd,0x2c180073,0x29180129}},	//   амит_, _annb, _बोलू_, ivra_, 
   {{0x3ca001ec,0x436800db,0xc214000d,0x00000000}},	//   _ﺍﻟﺘﻰ_, _саан_, _धोअब_, --, 
   {{0x200426b8,0x9c7c8185,0x00000000,0x00000000}},	//   semi_, gučn, --, --, 
   {{0x2005a133,0xdef802dd,0x7e680175,0x00000000}},	//   pemi_, уық_, _vjfp, --, 
   {{0x9c7c4b16,0x200596de,0x8fc40137,0x00000000}},	//   krče, qemi_, _ۇزۇن, --, 
   {{0xcf2405d9,0x9c7cabea,0x61f801f5,0x00000000}},	//   _ورهي, bučn, ofvl, --, 
   {{0x9c7c09a8,0xdb1c01ed,0x8e7c0115,0xddc80210}},	//   drče, nbsé, puŝa, hodź, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7e79a134,0x63a41505,0xdd30012d,0x00000000}},	//   lotp, žinj, _męże, --, 
   {{0x9634a20e,0x9c7c02fb,0x98b805d1,0x5bb401f9}},	// [2ca30] онац, lučo, ıyım_, ंडीव, 
   {{0x691806d6,0x7bccf980,0x29180810,0x80dc03d4}},	//   _ṋew, lacu, bvra_, _মহন্, 
   {{0xf36418ce,0x7bcc0789,0xe5c41cd0,0x9258179e}},	//   әтен, oacu, ясто, یشتر_, 
   {{0x7bcda135,0x61f801f5,0x7e78a057,0x44a401ec}},	//   nacu, efvl, hotp, ігің, 
   {{0xd1c8030d,0x569400db,0x1dc801f9,0x00000000}},	//   алле_, _мамт, ळरात, --, 
   {{0x7bcda136,0x87780a7c,0x00000000,0x00000000}},	//   hacu, _כארי, --, --, 
   {{0x7bcda137,0xd6cc03d4,0x9c7c01ef,0x00000000}},	//   kacu, _ৰঙিয, vučn, --, 
   {{0x7bcc08e5,0xd258007f,0x00000000,0x00000000}},	//   jacu, _kwņk_, --, --, 
   {{0xd9e002a6,0x7bcda138,0xb8c80003,0xdb1c01ed}},	//   ম্যম, dacu, _པང_, bbsé, 
   {{0xb6980022,0x6ebc012c,0x7bcc0393,0x291803b2}},	//   _isâs, लीगु, eacu, yvra_, 
   {{0x9c7c0b9d,0x3205a139,0x7bcda13a,0x7144399b}},	//   ručn, meny_, facu, _ухаж, 
   {{0x7bcda13b,0x3204d193,0x00000000,0x00000000}},	//   gacu, leny_, --, --, 
   {{0x25702776,0x7e780728,0x7c38005b,0x4e28005b}},	//   _kôlï_, botp, öura, _волн_, 
   {{0x320471ee,0x7bcc0334,0x29180af9,0x8e7c01e4}},	//   neny_, aacu, tvra_, muŝo, 
   {{0xb88000bc,0x291804cc,0xc7b00592,0x485802d5}},	//   číns, uvra_, ِّر_, араў_, 
   {{0x320405da,0x291805e4,0x78ac0f91,0xf1c00064}},	//   heny_, rvra_, _živí, lošė_, 
   {{0x05b9a13c,0x63a40006,0xf1bc004d,0x32054b6d}},	// [2ca40] لدات_, žink, _đán_, keny_, 
   {{0xf65c1fcd,0x3204219b,0xe8540133,0x3b80013d}},	//   _svær_, jeny_, _کۆرد, _юлыг, 
   {{0x850485d4,0xca480cb8,0x32040308,0xc7a4c064}},	//   توان, _ملکه_, deny_, _минк, 
   {{0x03a4034f,0x3cf8010f,0x00000000,0x00000000}},	//   цидо, ילענ, --, --, 
   {{0xf9a8007f,0x00000000,0x00000000,0x00000000}},	//   _àèò_, --, --, --, 
   {{0x32058781,0x6b840230,0x7bcda13d,0xd90c01d3}},	//   geny_, _myig, zacu, _جیہ_, 
   {{0xf65c26b8,0x7bcc0453,0x06b004c5,0x04440354}},	//   _tvær_, yacu, _চিটি, _девн, 
   {{0x6b85a13e,0xf65c00d4,0x307400c6,0x7bcc0113}},	//   _oyig, _uvær_, يحية_, xacu, 
   {{0x3205a13f,0x6b84e988,0xb69800d2,0x7bcda140}},	//   beny_, _nyig, _tsât, vacu, 
   {{0x32042320,0x7bcc1ab4,0xdb1c0158,0x5d542c2c}},	//   ceny_, wacu, masø, зкот, 
   {{0x7bcda141,0x8e7c01e4,0xc044007b,0xdb1c06ea}},	//   tacu, rtŝp, _وخصو, lasø, 
   {{0x6b840796,0x9c7c0122,0x2e38045f,0x8e7c01e4}},	//   _byig, ručo, _sêft_, buŝo, 
   {{0x6b840230,0x00000000,0x00000000,0x00000000}},	//   _cyig, --, --, --, 
   {{0x7bcda142,0xaca40432,0xded802d3,0xaadc07f7}},	//   sacu, _beỳi, _ዮሃና_, _बिरक, 
   {{0x6b85a143,0x7bcc054e,0xc2f400cc,0x00000000}},	//   _eyig, pacu, চিটি_, --, 
   {{0x320402fd,0xdb1c06ea,0xdb200332,0x9e840345}},	//   zeny_, kasø, ótói, _باڵۆ, 
   {{0xf770bf4e,0x95d800a7,0xdb1c0162,0xddc800e5}},	// [2ca50] ذار_, йдат_, jasø, lidő, 
   {{0xb6982776,0xf1bc0016,0x19940024,0x667407d6}},	//   _asâr, _đáo_, _напя, ودلر, 
   {{0x3204d889,0x26c4036e,0x644800c0,0xd3b812fa}},	//   veny_, _çmon_, _įdir, булі_, 
   {{0x629801f5,0x973401d3,0x00000000,0x00000000}},	//   emvo, _ٹکرا, --, --, 
   {{0x32040875,0xe78400f7,0x00000000,0x00000000}},	//   teny_, _журо, --, --, 
   {{0x22800100,0x10a400d1,0x768803e0,0x00000000}},	//   dòks_, пикн, müyo, --, 
   {{0x3205a144,0x768803ee,0x505800d1,0x00000000}},	//   reny_, lüyo, йшия_, --, 
   {{0x3205a145,0x9754002b,0xaadc03ce,0x8e7c01e4}},	//   seny_, _aṇim, _बिलक, tuŝo, 
   {{0x76880365,0x9c7c0552,0xe1ec0022,0x00000000}},	//   nüyo, ručl, _иҳ_, --, 
   {{0x71240220,0x6b840230,0x8f68023b,0x2e380142}},	//   _ورال, _ryig, _қалб_, _rêfs_, 
   {{0x6ebc32ed,0xb69800e4,0x228401c6,0x7ae0002b}},	//   लीजु, _ysâr, _цутг, _ānta, 
   {{0x768805d1,0x2ca40267,0x8e7c01e4,0xdb24054e}},	//   küyo, ömd_, puŝo, ăpîn, 
   {{0x7d180218,0xaca4010e,0x929c0210,0x00000000}},	//   avts, _seỳi, _wsłu, --, 
   {{0x6b841446,0xc3300375,0x906c01ec,0x00000000}},	//   _vyig, תוך_, _ﮭﻟا_, --, 
   {{0x929c006d,0x8c45a146,0x64ac0432,0x800001e1}},	//   _usłu, _неке, _işig, _àṣèk, 
   {{0x63a42aa9,0x60dc037e,0x00000000,0x00000000}},	//   žini, _ærme, --, --, 
   {{0x6b859090,0x6f180268,0x4428004d,0x7bc80022}},	// [2ca60] _uyig, nvuc, _đb_, _õgua, 
   {{0xa6c857aa,0x9c7c0219,0xa4f80327,0x00000000}},	//   йлға_, jučj, _པྱུག_, --, 
   {{0x768805d1,0x05540395,0x991800d4,0x00000000}},	//   müyl, чтая, _діях_, --, 
   {{0x76880790,0xdb1c0162,0x00000000,0x00000000}},	//   lüyl, tasø, --, --, 
   {{0xd5ac0014,0x00000000,0x00000000,0x00000000}},	//   اہہ_, --, --, --, 
   {{0x26c1a147,0x6f180cf4,0x76880790,0xdb1c03b2}},	//   mpio_, dvuc, nüyl, rasø, 
   {{0xf621a148,0xe7c002f5,0x62982506,0x7de00241}},	//   _ядро, েলীয, rmvo, _lísà, 
   {{0x26c1a149,0x64ac0139,0xdb1c03b2,0x4abc1546}},	//   opio_, _aşig, pasø, ्ठाव, 
   {{0x7de00248,0x76880205,0x00000000,0x00000000}},	//   _nísà, küyl, --, --, 
   {{0x93240502,0x2280007f,0x26c00142,0xd24c00cf}},	//   _ترفن, ròks_, ipio_, _ۅچۉ_, 
   {{0xa3e00d2c,0x768803e0,0x00000000,0x00000000}},	//   _दया_, züyo, --, --, 
   {{0x64ac63b5,0x76880790,0xddc801d3,0x25dc2052}},	//   _eşig, yüyo, ridő, गृती_, 
   {{0x9c7c3ad4,0xb9c40107,0x00000000,0x00000000}},	//   lučk, зёби, --, --, 
   {{0x76880205,0xd9840150,0x00000000,0x00000000}},	//   güyl, _ﺫﻜﺭﻩ_, --, --, 
   {{0xc6d8025c,0x23cc00dc,0x9c7c0419,0x00000000}},	//   ྲེའུ, ाराद, nučk, --, 
   {{0xf1bc0016,0xe8e0001e,0x76880790,0x00000000}},	//   _đám_, _giọt_, tüyo, --, 
   {{0x9c7c0419,0x00000000,0x00000000,0x00000000}},	// [2ca70] hučk, --, --, --, 
   {{0x76887225,0x929c068f,0xddc801fa,0xb4b0035b}},	//   rüyo, _opła, hodž, еижә, 
   {{0x9c7c4d3c,0xddc801fa,0x6f1808a4,0x13f402d5}},	//   jučk, kodž, zvuc, дзея, 
   {{0x9974033f,0xdcf80064,0x6f18022e,0x9c7c0419}},	//   _męża_, _gyvą, yvuc, dučk, 
   {{0xddc81e31,0x3f84002e,0xabfc010f,0xb8100154}},	//   dodž, _nyou_, מפאז, হাদত_, 
   {{0x569401c6,0xe3b000cf,0x00000000,0x00000000}},	//   _цагт, _ۅرك_, --, --, 
   {{0x9c7c05a1,0x3f8400e8,0xe6940022,0xe4e401ca}},	//   ručj, _ayou_, _чиры, _пітн, 
   {{0x1c1c007d,0x76881432,0xe164007b,0x00000000}},	//   _बोलल_, züyl, عدوي, --, 
   {{0x64ad17cf,0xf1a40184,0x64580ea0,0x238c0055}},	//   _eşid, _ерен, ëvie, _ṛjv_, 
   {{0x9c7da14a,0x6f18026c,0xfe400212,0x7de00241}},	//   vrča, rvuc, вньо, _rísà, 
   {{0x6f18110c,0xd13003c7,0x7de001e1,0xddc80153}},	//   svuc, _جما_, _sísà, bodž, 
   {{0x9c7c05ce,0x09c400dc,0x291c0022,0x26c0003a}},	//   trča, वर्य, _ĩva_, ypio_, 
   {{0x3f840007,0x291c00c7,0x768803e0,0x00000000}},	//   _gyou_, _ũva_, tüyl, --, 
   {{0xb6980311,0x2fcc143a,0x9e340064,0x8d640f06}},	//   _spân, _hegg_, _печч, _овле, 
   {{0xfaa1a14b,0x26c00042,0x768803e0,0xe9441291}},	//   таро, wpio_, rüyl, ررسی, 
   {{0xdb1ca39d,0x9c7c0427,0x088801ec,0x768803e0}},	//   lasý, prča, ібай_, süyl, 
   {{0x26c1a14c,0x2d84036e,0x00000000,0x00000000}},	// [2ca80] upio_, _hyne_, --, --, 
   {{0x2fcda14d,0xc8b4005b,0xdb2001d3,0xdb1cdd18}},	//   _legg_, _осмы, _átál, nasý, 
   {{0x291c07dd,0x2d84039a,0x26c00841,0x88e4030d}},	//   _éva_, _jyne_, spio_, _южне, 
   {{0x26c03993,0x2d84b880,0x7bc0013f,0xa5080022}},	//   ppio_, _myne_, _ɑnuo, _ҭҵаа_, 
   {{0x2d8405e4,0x929c033f,0x9c7c0306,0xaca400a2}},	//   _lyne_, _spła, krčn, leỳm, 
   {{0x2d8814cf,0x3f84020b,0x15b00137,0xa2841176}},	//   ęcej_, _ryou_, _مەكس, ریاو, 
   {{0xaca401f2,0xd5ac066d,0x2fcc0de2,0xa6b0015b}},	//   _afọi, _اہم_, _begg_, _ছবিট, 
   {{0x9c7c07f5,0xc624015b,0xb5e0009e,0xf990011a}},	//   ručk, _যতটা_, ন্দচ, כרו_, 
   {{0x2fcc1bce,0x7de40046,0x929c0034,0xddc80024}},	//   _degg_, мінд, _wpła, rodž, 
   {{0x9c7da14e,0xdb1c02d2,0x00000000,0x00000000}},	//   muči, gasý, --, --, 
   {{0x9c7c04b9,0x248405b1,0xd1780024,0x929c0210}},	//   luči, _kkmm_, _есці_, _upła, 
   {{0x2d8408cb,0xdb2002fb,0x201800e2,0x63a40153}},	//   _dyne_, štíh, ēris_, žinu, 
   {{0x9c7c02d5,0x9b44132f,0x99740210,0xab84130f}},	//   nuči, رنسو, _węża_, вурк, 
   {{0x69a00a94,0x2d84002d,0x2fcc07c5,0xdb1c000d}},	//   _गृही, _fyne_, _zegg_, masü, 
   {{0x2fcc0de2,0x2d8408c7,0x26c40200,0xdb1c0254}},	//   _yegg_, _gyne_, _çmoj_, lasü, 
   {{0xdb240276,0x9c7da14f,0xe8940006,0x00000000}},	//   ăpân, kuči, вась, --, 
   {{0x7bdc1730,0xdb1c01b8,0x00000000,0x00000000}},	// [2ca90] _idqu, nasü, --, --, 
   {{0xd054013f,0x9c7c0153,0xad20215c,0x7588011c}},	//   _ɑbɑt, duči, _سىۋى, осев_, 
   {{0xdcf80029,0x07e801d3,0xdb1c000d,0x00000000}},	//   _izvē, _کرپٹ_, hasü, --, 
   {{0xf1a003e6,0x059400db,0x387c03b2,0xdb1c88e9}},	//   ۆڤای, رالگ, _ður_, kasü, 
   {{0xb3082088,0x2fcc002e,0x9c7c00c0,0xdb1d32f5}},	//   تغال_, _regg_, guči, jasü, 
   {{0x7bdda150,0x2fcda151,0xdb0c00d8,0x00000000}},	//   _ldqu, _segg_, _efaç, --, 
   {{0x24840270,0x2fcc896c,0xd1301f3c,0xf48401ec}},	//   _fkmm_, _pegg_, امع_, _жуан, 
   {{0x659428db,0x9c7c0006,0x00000000,0x00000000}},	//   _расу, buči, --, --, 
   {{0x2d844f7f,0x2fcc449c,0xe314475c,0xdb1c1d0e}},	//   _syne_, _vegg_, _لبلب, tasý, 
   {{0x2d85a152,0xc0f802d3,0x71000124,0x77e805d7}},	//   _pyne_, ሊሶም_, _аҧка, टलुक_, 
   {{0x63a402d5,0x62340276,0xdb1d3212,0xf1bc0051}},	//   žint, _шефу, rasý, _đáh_, 
   {{0x9c7c0219,0x8fd000fb,0x2d840064,0xc0b80092}},	//   srčn, _сәкә, _vyne_, ተኛም_, 
   {{0x2d85a153,0xd84000e2,0xdb1c03b2,0x00000000}},	//   _wyne_, _mačā_, pasý, --, 
   {{0x2d85a154,0x8e7c0115,0xbb280014,0x7f3800df}},	//   _tyne_, kuŝi, ستُے_, _מענו, 
   {{0xd1d0044e,0x00000000,0x00000000,0x00000000}},	//   _ኩናት_, --, --, --, 
   {{0xf8a5a155,0x9980010e,0x00000000,0x00000000}},	//   евск_, _wahş_, --, --, 
   {{0x46e89a21,0xc0500bd9,0xc7642544,0xdc740022}},	// [2caa0] ядан_, אזן_, رارى, _шышь, 
   {{0x24842a1f,0x9c7c0306,0x246006be,0x85740116}},	//   _skmm_, vuči, _içmə_, ىدائ, 
   {{0x04443a22,0x248405b1,0xfbdc0120,0x8e7c01e4}},	//   нежн, _pkmm_, chês_, guŝi, 
   {{0x80dc00eb,0x00000000,0x00000000,0x00000000}},	//   _মহল্, --, --, --, 
   {{0xbb3800c8,0x338000a7,0x98540276,0x68fc0010}},	//   ּעצי, лушв, _ртэш, ltrd, 
   {{0x8e7c0115,0xfbdc030a,0xdb1c0254,0x00000000}},	//   buŝi, nhêr_, vasü, --, 
   {{0x68fc00fb,0xdb1c067c,0xeabc0011,0x00000000}},	//   ntrd, nasò, _অটোম, --, 
   {{0xdfd00597,0x9f0400f7,0x9c7c3a4c,0xd12c0137}},	//   جية_, نوعو, puči, تۅم_, 
   {{0x64ac0ab7,0x7bdda150,0x00000000,0x00000000}},	//   _eğit, _rdqu, --, --, 
   {{0x63a5a156,0xf1c00030,0x3f8800e2,0x68fc2bcc}},	//   žins, čší_, ābu_, ktrd, 
   {{0xf52c001f,0x68fc0010,0xaf300132,0x94a800e5}},	//   _በዋናነ, jtrd, _ەرىت, _راہِ_, 
   {{0xf1bc01fb,0x92580150,0xd17401af,0x00000000}},	//   _đái_, _ىشەر_, _рыуы, --, 
   {{0x625401ab,0xdb1c01ed,0xfca80451,0x71a00124}},	//   _càog, vasó, _کاتو_, _иқәҵ, 
   {{0x79a5a157,0xbea400ec,0x00000000,0x00000000}},	//   ербе, _ڪهڙن_, --, --, 
   {{0x2db40302,0xdb1da0e7,0x00000000,0x00000000}},	//   _אלון_, tasó, --, --, 
   {{0x625400a3,0x7bdc06be,0x00000000,0x00000000}},	//   _fàog, _udqu, --, --, 
   {{0xdb1c00c6,0x176802d3,0x968400f1,0xa884215c}},	// [2cab0] rasó, _ተመዲቡ_, نټرن, القى, 
   {{0x7c3c0455,0xaee000cd,0x8e7c0115,0xdcf800ef}},	//   _hoqr, _asṛj, tuŝi, _uzvē, 
   {{0x7aeda158,0xdb1da159,0x929c012d,0x28040118}},	//   luct, casò, _spło, ísní_, 
   {{0xe3b0021a,0x7c3c0327,0xe3480055,0x00000000}},	//   مره_, _joqr, _ṅāst, --, 
   {{0x7c3cdc95,0x7aec05d1,0x27ac010f,0xf5e400d4}},	//   _moqr, nuct, _מסכּ, _півм, 
   {{0x45a02002,0x8e7c0115,0x62340798,0x51980150}},	//   _چەكك, puŝi, лечу, _ﺘﻭﺭﻁ_, 
   {{0x9c7c08a4,0x6594e2da,0x550405f9,0xe3740220}},	//   luču, _бару, _रहिए_, _ұлты, 
   {{0x683800d2,0x7c3c013d,0x241801ee,0xc0b80092}},	//   _sídz, _noqr, _посы_, ሰማራ_, 
   {{0x5ef801c6,0xd2140063,0xc32c0133,0x5215a15a}},	//   нхэр_, _имаћ, _وڕه_, _идат, 
   {{0x7aeda15b,0x00000000,0x00000000,0x00000000}},	//   duct, --, --, --, 
   {{0x7c3da15c,0xa1f00150,0xc690011a,0x00000000}},	//   _boqr, _اۋىت, שאי_, --, 
   {{0xcb695471,0x83d406ba,0x00000000,0x00000000}},	//   даме_, ﻟﻤﺎﻳ, --, --, 
   {{0x7c3c06be,0x8e3800ae,0x00000000,0x00000000}},	//   _doqr, _يستر_, --, --, 
   {{0xc0b8001f,0xdb1c00e4,0x00000000,0x00000000}},	//   ሰማሩ_, tasò, --, --, 
   {{0x7c3c0135,0x00000000,0x00000000,0x00000000}},	//   _foqr, --, --, --, 
   {{0xdb1c007f,0x00000000,0x00000000,0x00000000}},	//   rasò, --, --, --, 
   {{0x0685633a,0x07a4013e,0x9c7c01a6,0xca74013d}},	// [2cac0] вган, таан, guču, _ауны, 
   {{0xba75a15d,0xe8b400d1,0x00000000,0x00000000}},	//   _لاپت, _مەسج, --, --, 
   {{0x75d0237e,0x64ac0205,0x49980395,0x00000000}},	//   شينا, _ağir, _ютия_, --, 
   {{0xc795a15e,0x15b80724,0x4345a15f,0x00000000}},	//   _аргы, _җыры_, кеев, --, 
   {{0x65c402dd,0x4908012c,0x7c380108,0x00000000}},	//   _бұза, ाबको_, öuri, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x44140022,0x64ac03e0,0x380400fe,0x557401af}},	//   _ифат, _eğir, ৱাৰো_, _бѳтт, 
   {{0x661da160,0x5f940408,0x7aec0113,0x00000000}},	//   _hark, лийт, yuct, --, 
   {{0x661da161,0xb0307fb5,0x61fc007c,0x64400064}},	//   _kark, рныш, _örlo, _iomi, 
   {{0x6441a162,0x2f24145e,0xdd9007d6,0x7c3cdaaa}},	//   _homi, _sêgô_, یوک_, _soqr, 
   {{0x661da163,0x1bd418ac,0x7c3c0166,0xbac40150}},	//   _mark, лоня, _poqr, _ﺒﻨﺸﺎ, 
   {{0x661da164,0x6f601c93,0x7aec0548,0x7c3c0477}},	//   _lark, اهیم, tuct, _qoqr, 
   {{0x6441a165,0x661c000f,0x00000000,0x00000000}},	//   _momi, _oark, --, --, 
   {{0x6441a166,0x7aeda167,0x69c806ea,0x00000000}},	//   _lomi, ruct, ðdep, --, 
   {{0x6441a168,0x38701ee3,0xadf40597,0xdb1c0113}},	//   _oomi, иқот, _شروط_, rasñ, 
   {{0x661d20ea,0x64400c46,0x6ca402d5,0xaadc0bae}},	//   _aark, _nomi, _крыж, _बिचक, 
   {{0x661da169,0x00000000,0x00000000,0x00000000}},	// [2cad0] _bark, --, --, --, 
   {{0x9c7da16a,0xfafc02d3,0xdb0c0098,0x64407cab}},	//   ruču, mtë_, _ngaé, _aomi, 
   {{0x6441a16b,0xfafc0023,0x661c0fb2,0xd9d80f22}},	//   _bomi, ltë_, _dark, _তাপম, 
   {{0x661c005a,0x9c7c0219,0x67d400f7,0x8e7c01e4}},	//   _eark, drčk, _коюу, luŝt, 
   {{0x661da16c,0x72a004a9,0xfafc044e,0x6441a16d}},	//   _fark, لەرن, ntë_, _domi, 
   {{0x661da16e,0xd1b9613b,0xfafc0200,0xdb1c007c}},	//   _gark, راتا_, itë_, mbsä, 
   {{0xfafc07db,0x64ac0fb9,0x6441a16f,0x9c7c110c}},	//   htë_, _işin, _fomi, grčk, 
   {{0xae18228d,0xfafc02d3,0x628800df,0xd0947ced}},	//   _भोजन_, ktë_, _ekdo, ышлы, 
   {{0xfafc044e,0x0ea8011b,0xc43024b2,0xfc3c01e7}},	//   jtë_, нкий_, _دکلت, imíd_, 
   {{0x661da170,0x6440e08f,0x00000000,0x00000000}},	//   _xark, _zomi, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfafc044e,0x64400f89,0x00000000,0x00000000}},	//   ftë_, _xomi, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7c2c0597,0x2c041870,0x661c49f0,0x3cfc007f}},	//   áirí, _күнм, _rark, cttv_, 
   {{0x661da171,0x7bb00139,0x8b8401ec,0x64ad85f8}},	//   _sark, _гөру, _مەجە_, _aşin, 
   {{0x6441a172,0x9c7c02fb,0x00000000,0x00000000}},	// [2cae0] _romi, ručt, --, --, 
   {{0x6441a173,0x661da174,0x9aa40050,0x49c8030d}},	//   _somi, _qark, _پمپو, _ялон_, 
   {{0x0ce00c58,0x8578036b,0x682c0139,0x7cf8013d}},	//   _বহুত, хсат_, _födе, _iärç, 
   {{0x661da175,0x95980228,0x64400724,0x64ac03ee}},	//   _wark, ттуу_, _qomi, _eşin, 
   {{0x661da176,0x6441a177,0xd2580100,0x7c280d12}},	//   _tark, _vomi, _pwņp_, _ógre, 
   {{0x6441a178,0x8174016c,0x672401f5,0x661da179}},	//   _womi, лалӣ_, mvij, _uark, 
   {{0x64411db8,0x67256f66,0xe7b805d7,0x049402d5}},	//   _tomi, lvij, _अलाप, _браў, 
   {{0x64400801,0x7cf80139,0x03a474e4,0xdb1cd9f6}},	//   _uomi, _lärç, _бибо, masö, 
   {{0xdb1d77e8,0xd2580100,0xc35400a7,0x7bc80022}},	//   lasö, _twņp_, _съвъ, _õgui, 
   {{0x9c7c16a3,0x67240153,0x00000000,0x00000000}},	//   mrči, ivij, --, --, 
   {{0x5c74a3c3,0xdb1da17a,0x625401ab,0xf48401d3}},	//   илот, nasö, _tàob, _شاہی, 
   {{0x3cfc019b,0xfafc995d,0x5154004e,0x00000000}},	//   rttv_, ttë_, _ттуу, --, 
   {{0x9e349308,0x8e7c0115,0xdb1c000d,0x7b6401f4}},	//   _велч, tuŝt, hasö, утне, 
   {{0xfafc069c,0x6725a17b,0x6f90007b,0x00000000}},	//   rtë_, dvij, _الهض, --, 
   {{0xfafc044e,0x672400da,0xf80421fa,0xf64402dd}},	//   stë_, evij, лчан, қхан, 
   {{0xdb1c0793,0xfafc0240,0x00000000,0x00000000}},	//   dasö, ptë_, --, --, 
   {{0xfafc02d3,0xa8a412c4,0xe894023a,0x3eac0254}},	// [2caf0] qtë_, ёрск, сать, _kift_, 
   {{0xd01c00bd,0x7cf8013d,0xaee000b8,0xdb1da17c}},	//   থায়_, _gärç, _haṃk, rbsä, 
   {{0x19582f6a,0x53900023,0xdb1c08a5,0x00000000}},	//   _раны_, _ዝሓዘት_, gasö, --, 
   {{0x3eac0c18,0x245807d5,0xa4d4003b,0x00000000}},	//   _lift_, лахь_, соці, --, 
   {{0x672400f3,0xdb1c03cd,0x64ada17d,0xe3b80212}},	//   cvij, bbså, _işil, убі_, 
   {{0xaee000b8,0x91c40166,0x004401e2,0x00000000}},	//   _laṃk, рәал, ییلي_, --, 
   {{0xdb1c00c5,0x00000000,0x00000000,0x00000000}},	//   masõ, --, --, --, 
   {{0xdb1c00af,0x9c7c05be,0x20540daf,0x2efc0194}},	//   lasõ, brči, йтыр, ttuf_, 
   {{0x78ac01bf,0x72d000db,0xddc80055,0x00000000}},	//   _micv, _چەچچ, cidū, --, 
   {{0x72d00075,0xdea4429e,0xdb1c00c5,0x3ead5fa5}},	//   _نەچچ, مینی, nasõ, _cift_, 
   {{0x60080150,0x00000000,0x00000000,0x00000000}},	//   _әнім_, --, --, --, 
   {{0xaee0002b,0x8b240006,0xdb1c000d,0x00000000}},	//   _caṃk, адме, hasõ, --, 
   {{0x3eac039a,0xe8e0001e,0xdb1c000d,0x20841532}},	//   _fift_, _kiệt_, kasõ, _النّ, 
   {{0xdb1c0037,0x00000000,0x00000000,0x00000000}},	//   jasõ, --, --, --, 
   {{0x290da17e,0x997c0046,0xe8e0004d,0xdb1c0254}},	//   ïda_, еттi, _miệt_, dasõ, 
   {{0x672411f9,0xe8e00016,0x78ac01fa,0xcc880a0a}},	//   tvij, _liệt_, _cicv, _جنبه_, 
   {{0x09e47696,0x1898023a,0x00000000,0x00000000}},	// [2cb00] _копн, утрь_, --, --, 
   {{0x6725a17f,0x3eac031c,0xe4b8008e,0x00000000}},	//   rvij, _xift_, гъдә_, --, 
   {{0x67248185,0x9f9002d2,0x00000000,0x00000000}},	//   svij, _lúði_, --, --, 
   {{0xc48405a2,0xe70800ec,0x00000000,0x00000000}},	//   шлек, _ٽڪرن_, --, --, 
   {{0xe8e007ae,0x69dc01c0,0x9690036b,0xc4c450d8}},	//   _biệt_, oare, _کیلش, _چترو, 
   {{0x69dda180,0x72d067d1,0x64ac574b,0x38a801e1}},	//   nare, تەكچ, _işim, _tòrì_, 
   {{0xe8e00016,0xddc80006,0x69dda181,0x36640408}},	//   _diệt_, sidū, iare, _таро_, 
   {{0x69dda182,0x3eacdf39,0xb0246886,0x9f9006ea}},	//   hare, _sift_, لكىم_, _búði_, 
   {{0x3eac005c,0x00000000,0x00000000,0x00000000}},	//   _pift_, --, --, --, 
   {{0x69dda183,0xaee00a28,0x73300131,0x3eac0200}},	//   jare, _saṃk, _بىكا, _qift_, 
   {{0x3eac01e3,0xaee000b8,0x7c64007b,0x42a401f3}},	//   _vift_, _paṃk, لاحل, _ሊባኖስ_, 
   {{0xfc6416c3,0xdd940046,0x291800ca,0x69dda184}},	//   ръон, _қайы, dwra_, eare, 
   {{0x69dda185,0x0d38013e,0x3eac0327,0xdd900133}},	//   fare, взӯъ_, _tift_, توگ_, 
   {{0xdb1c00dd,0x61f80549,0x00000000,0x00000000}},	//   ncsé, ngvl, --, --, 
   {{0x98a00055,0xdb1da186,0x764001f4,0x00000000}},	//   _arhā_, vasõ, önym, --, 
   {{0x57b42c1d,0x69dc422c,0x31540115,0xa85400db}},	//   сбат, aare, בילן_, оксч, 
   {{0x6bd40150,0xa7b821cb,0x2b4401c6,0x7bcc0175}},	// [2cb10] _بتىر, рлуу_, _дээг, mbcu, 
   {{0x69dda187,0xf52400d8,0x9a14009f,0x00000000}},	//   care, ифен, _اِدغ, --, 
   {{0x74a410f3,0x64ac05d1,0xe5c47ef2,0xdb1c00c7}},	//   ајде, _eşim, юсто, rasõ, 
   {{0x940c01e4,0x64ac054e,0xaee000b8,0x48c1a188}},	//   _kieɩ_, _uşil, _haṅk, _хәра, 
   {{0xaee000cd,0x3370035b,0x00000000,0x00000000}},	//   _kaṅk, цҳар, --, --, 
   {{0xf2053eb2,0x7aec003a,0xe1f801ec,0x00000000}},	//   рядо, irct, игі_, --, 
   {{0xe8e001dc,0x2a580302,0x64980421,0xaee000b8}},	//   _việt_, שבון_, míin, _maṅk, 
   {{0x69dda189,0x61f80d27,0xaee000cd,0x9f9002d2}},	//   zare, agvl, _laṅk, _púði_, 
   {{0x69dda18a,0x0e640137,0x8db401ce,0xe8e0004d}},	//   yare, йкин, йсні, _tiệt_, 
   {{0x72a00131,0xace001e0,0xe3b0020c,0xdb1c00e5}},	//   _بەتن, обоҙ, _زرق_, ccsé, 
   {{0x4c85a18b,0xc22003e6,0x5194007b,0x71700345}},	//   йлов, _رکوو, _الاذ, _بپاڕ, 
   {{0x69dda18c,0xaf30004b,0x00000000,0x00000000}},	//   ware, _وواژ, --, --, 
   {{0x2918031c,0x6f8401a9,0x00000000,0x00000000}},	//   wwra_, _тужж, --, --, 
   {{0x2918083a,0xe18002d3,0xaee0002b,0x69dc905d}},	//   twra_, _ይሕብሩ_, _caṅk, uare, 
   {{0x69dda18d,0x77e001f9,0x00000000,0x00000000}},	//   rare, गणूक_, --, --, 
   {{0x69dda18e,0x00000000,0x00000000,0x00000000}},	//   sare, --, --, --, 
   {{0xfc54011a,0x7c2800ae,0x7c5400ec,0x00000000}},	// [2cb20] _לבקש_, _ógra, _دلير_, --, 
   {{0x69dda18f,0xdb1c00e4,0x442848e7,0x4534104e}},	//   qare, rasô, _şb_, йхет, 
   {{0x3a200323,0xf1bc07ae,0x79980198,0x929c033f}},	//   _эмэг, _đáp_, ƙuwa, _usły, 
   {{0xe85403e6,0x64ac062d,0xe7480ce8,0x44300124}},	//   _بۆرد, _işik, _күбе_, ñy_, 
   {{0x31cc00bd,0x2338010b,0x00000000,0x00000000}},	//   _রাজশ, рплы_, --, --, 
   {{0x36d00323,0x38c812e1,0x03a40107,0x929c0210}},	//   _хоёр, _جایی_, _ғизо, _opłu, 
   {{0x61f801f5,0x00000000,0x00000000,0x00000000}},	//   rgvl, --, --, --, 
   {{0x2a6400e4,0x00000000,0x00000000,0x00000000}},	//   ĩmby_, --, --, --, 
   {{0x2a640022,0x81c000eb,0x00000000,0x00000000}},	//   ũmby_, ্ণব_, --, --, 
   {{0xf1cc227c,0x39a0020c,0xbbe800f2,0x7de0013d}},	//   _स्पन, nésé_, گردم_, dísí, 
   {{0x1c39165c,0x2ca001ab,0x61e8127b,0x68e803b2}},	//   азны_, _bhid_, _iddl, áddl, 
   {{0x2ca1a190,0xfafc0036,0xaee000dc,0x00000000}},	//   _chid_, nzëg_, _saṅk, --, 
   {{0xba74005e,0xfb8400fd,0x2ca0009f,0x212002b5}},	//   ماست, сынн, _dhid_, āihu_, 
   {{0xaa6400f3,0x195800db,0xd9d800eb,0x00000000}},	//   птск, аагы_, _তাহম, --, 
   {{0xaee000b8,0xb5cc0220,0x00000000,0x00000000}},	//   _vaṅk, _ﺗﯘﻟﻌ, --, --, 
   {{0x2ca1a191,0x6ab8015b,0x00000000,0x00000000}},	//   _ghid_, _অবরো, --, --, 
   {{0x64ac010b,0x3a2000b5,0x3a300051,0x00000000}},	// [2cb30] _eşik, pdjp_, _tnxp_, --, 
   {{0xd9ec000d,0x00000000,0x00000000,0x00000000}},	//   _जयित_, --, --, --, 
   {{0x7c740092,0x00000000,0x00000000,0x00000000}},	//   ከፈለው_, --, --, --, 
   {{0xd370ad2d,0x61e9a192,0x6cf8010f,0x00000000}},	//   وها_, _addl, רפאס, --, 
   {{0x92387a73,0x60c8010a,0x212c0023,0x00000000}},	//   ичку_, _atdm, _ardh_, --, 
   {{0x61ec01ef,0x00000000,0x00000000,0x00000000}},	//   _ďolí, --, --, --, 
   {{0x466000db,0x00000000,0x00000000,0x00000000}},	//   _تۇلق, --, --, --, 
   {{0x76440399,0xdb2001f1,0xdb1c2c95,0x61e803ac}},	//   _hojy, _štýl, bbsø, _eddl, 
   {{0x998000b8,0x212c0240,0x76449cbb,0x929c012d}},	//   _bahū_, _erdh_, _kojy, _spłu, 
   {{0x2ca01a07,0x00000000,0x00000000,0x00000000}},	//   _shid_, --, --, --, 
   {{0xc5f006a9,0x7644037e,0xa0c40d2f,0x09e000eb}},	//   ודי_, _mojy, _فيلو, বলমা, 
   {{0x357002d3,0x99d800cc,0x00000000,0x00000000}},	//   _ጸጋታት_, তলোক, --, --, 
   {{0x229400db,0xcff400f1,0xf3f800cc,0xdb680108}},	//   _بلەس, _هيڅک, _এঘাৰ_, брёл_, 
   {{0x1e840046,0x2fdd0c9b,0xfc3c09c2,0x1fa401c0}},	//   _елім, laug_, rmía_, _эрхг, 
   {{0x8c440dd8,0xc6200729,0x6e200857,0x2ca15d61}},	//   _меке, নামা_, _ianb, _thid_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6e21a193,0x8644dddc,0x86c4035d,0xdbd803b2}},	// [2cb40] _kanb, онаж, زيان, mæði, 
   {{0x6e20033b,0x2fdc168c,0xb6a0084c,0xdbd402d2}},	//   _janb, haug_, диул, _húðu, 
   {{0x6e21a194,0x764400b5,0x39a00098,0xfafc0036}},	//   _manb, _dojy, résé_, tzëg_, 
   {{0x6e21a195,0xc34800fd,0x94a8210e,0x00000000}},	//   _lanb, ияле_, مانِ_, --, 
   {{0x6e200a85,0x27e1a196,0x2fdda197,0x4df8012c}},	//   _oanb, main_, daug_, ंलाई_, 
   {{0x27e1a198,0x7ae804ce,0x6e20037e,0xdbd40d12}},	//   lain_, _ægte, _nanb, _lúðu, 
   {{0x61e8011c,0x41c4102f,0x717000f2,0xf50001d5}},	//   _vddl, रुषस, وهها, _озро, 
   {{0x6e209b80,0x27e1a199,0x301006bb,0x6f18002f}},	//   _aanb, nain_, ддър, fwuc, 
   {{0x6e21a19a,0x4425a19b,0x74106c16,0x99800374}},	//   _banb, mdo_, _زولا, _pahū_, 
   {{0x27e1a19c,0x6e21a19d,0x41dc012c,0x61e83fc1}},	//   hain_, _canb, _नजिस, _uddl, 
   {{0x27e1a19e,0x6e21a19f,0x4425a1a0,0x92380415}},	//   kain_, _danb, odo_, _учту_, 
   {{0x27e1a1a1,0x6e202711,0x7d180142,0xdbd8032e}},	//   jain_, _eanb, rwts, gæði, 
   {{0x4425a1a2,0x6e21a1a3,0x27e1a1a4,0xfbdc0022}},	//   ido_, _fanb, dain_, raê_, 
   {{0x4425a1a5,0x6e21a1a6,0x27e001ab,0xc6200011}},	//   hdo_, _ganb, eain_, নাডা_, 
   {{0x4425a1a7,0x8cc02144,0x27e16ba3,0xaa941078}},	//   kdo_, _रूपो, fain_, фирч, 
   {{0x27e1a1a8,0x4425a1a9,0xa8a4063b,0x76440369}},	//   gain_, jdo_, друк, _sojy, 
   {{0x4425a1aa,0x6e21a1ab,0x00000000,0x00000000}},	// [2cb50] ddo_, _yanb, --, --, 
   {{0x4425a1ac,0x2fdc3dc9,0x6e21a1ad,0x00000000}},	//   edo_, zaug_, _xanb, --, 
   {{0xe3b004d3,0x4425a1ae,0x8e7c01e4,0x7e7851a0}},	//   ۆره_, fdo_, nsŝa, intp, 
   {{0x27e1a1af,0x4425a1b0,0xe3b007d6,0xfc3da1b1}},	//   cain_, gdo_, چره_, zmín_, 
   {{0x0838008f,0x764400e4,0xe3b0cdc2,0x8838025d}},	//   _הערל, _tojy, نره_, _התרו, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4425a1b2,0x6e21a1b3,0x1cd40135,0x2fdc0218}},	//   bdo_, _ranb, ེེས_, taug_, 
   {{0x6e21a1b4,0x44240050,0x7e78127b,0x6b2c031c}},	//   _sanb, cdo_, entp, _སླའོ_, 
   {{0x6e206129,0xdbd8008c,0xdbd408a5,0xf2040006}},	//   _panb, væði, _rúðu, _мяжо, 
   {{0x27e1a1b5,0x2fdc0218,0x6e20014f,0x4d64509d}},	//   zain_, saug_, _qanb, зков, 
   {{0x6e21a1b6,0x27e1a1b7,0xfc3c0232,0xdbd8008c}},	//   _vanb, yain_, rmín_, tæði, 
   {{0x6e21a1b8,0xf1cc1b6e,0x5f740451,0x7e7802d0}},	//   _wanb, _स्तन, _ڪامر, antp, 
   {{0x27e1a1b9,0x6e21a1ba,0xdbd800fc,0x2d88033f}},	//   vain_, _tanb, ræði, łce_, 
   {{0x27e1a1bb,0x19b810f5,0x442402d5,0xd0180034}},	//   wain_, жуть_, zdo_, leń_, 
   {{0x4425a1bc,0x27e1a1bd,0xbd0000e8,0x48580006}},	//   ydo_, tain_, _ñépp, браў_, 
   {{0x442401d9,0xfbdc0af9,0x27e001ab,0x00000000}},	//   xdo_, skêr_, uain_, --, 
   {{0x442407d6,0x05b8dabc,0xe8e00051,0xa13c0171}},	// [2cb60] vdo_, مدات_, _khịt_, _izķe, 
   {{0x1778090b,0xea64034c,0x442401d9,0x6b840548}},	//   ість_, _آپدی, wdo_, _ixig, 
   {{0x27e1a1be,0x4425a1bf,0x291da1c0,0x82a54959}},	//   pain_, tdo_, _èva_, үшле, 
   {{0xb3d40154,0x00000000,0x00000000,0x00000000}},	//   _হাউজ, --, --, --, 
   {{0xd700016c,0x133801d3,0xb3c80210,0xd0180210}},	//   _иҷти, قتوں_, ाड़ख, deń_, 
   {{0x4425a1c1,0xa195a1c2,0xa3cc04aa,0x00000000}},	//   sdo_, малч, _श्र_, --, 
   {{0xb6a0235c,0x4425a1c3,0x00000000,0x00000000}},	//   _чирл, pdo_, --, --, 
   {{0x44240050,0x75780375,0x80f8013e,0x764001ed}},	//   qdo_, _הטלפ, _ҳхдт_, önyv, 
   {{0x09e011ba,0x41b400a7,0x7e28003b,0x00000000}},	//   _বানা, _есет, біна_, --, 
   {{0xdbe40cb4,0xe8e00208,0x7e7801bf,0x5d543866}},	//   कण्ड_, _chịt_, untp, дкот, 
   {{0x6b8402d0,0x57a801f9,0x00000000,0x00000000}},	//   _axig, _कण्ह, --, --, 
   {{0x6299a1c4,0xe7b8012c,0xd018012d,0x00000000}},	//   llvo, _अलगप, ceń_, --, 
   {{0x3ea40124,0x6298017a,0x62540241,0xdb1c06be}},	//   _еидг, olvo, _nàok, _üzüq, 
   {{0xe08801f7,0x00000000,0x00000000,0x00000000}},	//   _اَچو_, --, --, --, 
   {{0xdb0c02d2,0xa93569e7,0x2a640200,0x45d400d1}},	//   _efað, нерш, ëmba_, _ﺟﯘﻏﻼ, 
   {{0x62980112,0x5b1401f4,0x00000000,0x00000000}},	//   hlvo, _жмит, --, --, 
   {{0x5ac80345,0x00000000,0x00000000,0x00000000}},	// [2cb70] _بابێ_, --, --, --, 
   {{0x13d42677,0x62980196,0xd0180034,0xdb0c6565}},	//   दर्भ, jlvo, zeń_, _agaç, 
   {{0x39a001e1,0x7bdc036e,0x81c00154,0x00000000}},	//   _désí_, _kequ, ংরা_, --, 
   {{0x7bdda1c5,0xd1bc02d3,0x629801a4,0xb8643fe6}},	//   _jequ, ሰያት_, elvo, _راجو, 
   {{0xfa282fb5,0x7bdc0428,0xe78401f0,0x86e801f0}},	//   _སྣོན_, _mequ, _зуро, _мурғ_, 
   {{0x7bdda1c6,0xc738011a,0x00000000,0x00000000}},	//   _lequ, _ותשת, --, --, 
   {{0xf49404fb,0x09e0009e,0x733401d3,0xc0c00209}},	//   _فشرد, _বামা, _کرزئ, вәчи, 
   {{0x7bdd55e1,0x6298017a,0xb4b000fd,0x68e803b2}},	//   _nequ, alvo, _чибә, áddi, 
   {{0x62980165,0xd9ec10eb,0xb1c400f1,0x00000000}},	//   blvo, _जयंत_, _فېشن_, --, 
   {{0x7bdc0de4,0xccc5a1c7,0x9f05a1c8,0x6ffc0154}},	//   _aequ, мбой, روپو, ্যেও_, 
   {{0x7bdda1c9,0xd0107092,0x00000000,0x00000000}},	//   _bequ, _للا_, --, --, 
   {{0x7bdc0077,0xd8b00150,0x00000000,0x00000000}},	//   _cequ, _ﺳﺎﻻﻟ, --, --, 
   {{0xe8e00016,0x7bdda1ca,0x09e0015b,0x64ac05d1}},	//   _thịt_, _dequ, _বাবা, _işit, 
   {{0xfe0c004d,0xdb200332,0x00000000,0x00000000}},	//   _hững_, ótái, --, --, 
   {{0x7bdc0393,0xa03401d9,0x00000000,0x00000000}},	//   _fequ, _زى۪ت, --, --, 
   {{0x6b84005a,0xb6040135,0x7bdd1ea3,0xa2a40037}},	//   _txig, _leġġ, _gequ, _चीन्, 
   {{0x46e82de5,0x62980ea0,0x8e7c01e4,0x4648bd83}},	// [2cb80] юдан_, ylvo, nsŝo, озан_, 
   {{0x7bdc01e2,0xfe0c0208,0xd90c0066,0x00000000}},	//   _zequ, _lững_, _گیف_, --, 
   {{0x7bdc4b2a,0x044402d5,0xe8e00051,0x00000000}},	//   _yequ, межн, _khọt_, --, 
   {{0x68fda1cb,0x7bdc00d8,0x5804313e,0xd90c0244}},	//   murd, _xequ, _كوپك, _دیف_, 
   {{0x68fda1cc,0x031833d2,0x00000000,0x00000000}},	//   lurd, تتات_, --, --, 
   {{0xf77002e4,0x764001e3,0x00000000,0x00000000}},	//   _יקר_, önyt, --, --, 
   {{0x68fda1cd,0xe8e0004d,0xd4f42f6a,0x99d80154}},	//   nurd, _kiốt_, _пяты, _তাৎক, 
   {{0xdfd00491,0x2478007f,0xe8e00208,0x3dd800cc}},	//   دية_, fōme_, _nhọt_, _দাইল, 
   {{0x7bdda1ce,0xb604031c,0x30a000a7,0xf1cc012a}},	//   _requ, _feġġ, ършв, _स्वन, 
   {{0x64ac54de,0x7bdcad62,0x00000000,0x00000000}},	//   _eşit, _sequ, --, --, 
   {{0x7bdc74c3,0x68fcee87,0x00000000,0x00000000}},	//   _pequ, jurd, --, --, 
   {{0x68fc0cfd,0x3d1c05b3,0xe8e00208,0x00000000}},	//   durd, _बनीं_, _chọt_, --, 
   {{0xfe441c13,0x7bdc068c,0xfa28031c,0x00000000}},	//   _ондо, _vequ, _སྣུན_, --, 
   {{0x7bdda1cf,0x68fca1bc,0xdb2008a5,0xdb1c00e5}},	//   _wequ, furd, _ótím, gcsá, 
   {{0x7bdda1d0,0x68fda1d1,0x81c002f5,0xadf004af}},	//   _tequ, gurd, _্যা_, _आयतन_, 
   {{0xfe7405f5,0xb7bc00fe,0xfca8020c,0x00000000}},	//   _хүү_, েণ্ট, _باتو_, --, 
   {{0xfaa5a1d2,0xe89400c9,0x18a40116,0x998001ef}},	// [2cb90] _ошон, тать, даңм, _tahů_, 
   {{0x68fda1d3,0x00000000,0x00000000,0x00000000}},	//   burd, --, --, --, 
   {{0x68fc08e5,0xb604031c,0x00000000,0x00000000}},	//   curd, _reġġ, --, --, 
   {{0xd7f40598,0x00000000,0x00000000,0x00000000}},	//   _язмы, --, --, --, 
   {{0x09e02aab,0x00000000,0x00000000,0x00000000}},	//   _বাতা, --, --, --, 
   {{0xfe0c004d,0x00000000,0x00000000,0x00000000}},	//   _sững_, --, --, --, 
   {{0xe5b4ab91,0x387c00b0,0x50b400a8,0x00000000}},	//   _айры, ōuru_, нсиу, --, 
   {{0xb604025c,0x4f25a1d4,0x00000000,0x00000000}},	//   _weġġ, едиб, --, --, 
   {{0xbec40046,0xfe0c001e,0xc62000bd,0xfc3c011f}},	//   еңіз_, _vững_, নারা_, mmíh_, 
   {{0x68fda1d5,0xa2bc033f,0x2478007f,0xdea402f2}},	//   yurd, षआर्, rōme_, نینی, 
   {{0xc6900302,0x68fda1d6,0x7de401c6,0xe8e00208}},	//   ראי_, xurd, эмэг_, _phọt_, 
   {{0x68fc0e38,0xf1bc01fb,0x00000000,0x00000000}},	//   vurd, _đáy_, --, --, 
   {{0x68fda1d7,0xd64c0150,0x00000000,0x00000000}},	//   wurd, мiме, --, --, 
   {{0x68fda1d8,0xe94403e6,0x00000000,0x00000000}},	//   turd, پرسی, --, --, 
   {{0xdb1c01ed,0xfaa0034b,0xa92400bc,0x09e00011}},	//   rcsá, уаро, ěžov, _বাদা, 
   {{0x68fc032d,0x6cb402dd,0xfafc0200,0xfce00117}},	//   rurd, _шөпт, mzën_, _соъо, 
   {{0xdb1c01d3,0xb8901e24,0x00000000,0x00000000}},	// [2cba0] pcsá, القع, --, --, 
   {{0x68fda1d9,0x25bc36e0,0x77c4009d,0xfad400df}},	//   purd, øvl_, _үлэг_, _רויך_, 
   {{0x02880046,0x48e8012c,0xc6200154,0xb60000d7}},	//   үйек_, _छिटो_, নালা_, ášac, 
   {{0x64ac0e2d,0xd90c01d9,0x99740166,0x8494132f}},	//   _aşir, _گیہ_, _шуыш, رجائ, 
   {{0xd25800e2,0x00000000,0x00000000,0x00000000}},	//   _suņa_, --, --, --, 
   {{0xd90c0014,0x15b0104b,0x00000000,0x00000000}},	//   _دیہ_, _چەكس, --, --, 
   {{0x35a1a1da,0xfafc02d3,0x3d1c0034,0xd99800d1}},	//   _барг, jzën_, _बनें_, ﺘﯩﺪﻩ_, 
   {{0x81c0009e,0x64ac010e,0xf425a1db,0x00000000}},	//   ্ণই_, _eşir, _посл_, --, 
   {{0x7e281cd0,0x301001ec,0x787801f4,0x00000000}},	//   піна_, удыр, lävä, --, 
   {{0x11400014,0xceac0451,0x64ac06be,0x9f44036e}},	//   _چێوُ, يڙو_, _işiq, lamë_, 
   {{0x00d82f84,0x00000000,0x00000000,0x00000000}},	//   _ربات_, --, --, --, 
   {{0x786000c5,0x28b40412,0x00000000,0x00000000}},	//   _kõve, ंगफि, --, --, 
   {{0xf77d2ea9,0x6d5c06be,0x63a4031c,0x00000000}},	//   _keçe_, _əqai, żinf, --, 
   {{0xdd940124,0x9f44036e,0x00000000,0x00000000}},	//   _иалы, hamë_, --, --, 
   {{0x29882b39,0x19940801,0xdff4007d,0xf77c036e}},	//   есто_, тавя, _इयाद_, _meçe_, 
   {{0x1ce00135,0xed5c0118,0xf77c0200,0x9f440200}},	//   _སྦར_, ížek_, _leçe_, jamë_, 
   {{0x6c8405e6,0x57b5a1dc,0x26c401c7,0xfcf40023}},	// [2cbb0] _حليم, тбат, _émol_, _ፈሊጠ_, 
   {{0xb8f41d4c,0xf77c03b9,0xc58401d9,0x00000000}},	//   _সি_, _neçe_, چھِم_, --, 
   {{0xd7f40124,0x64ac0213,0x00000000,0x00000000}},	//   _изны, _aşiq, --, --, 
   {{0x937810de,0x425001d5,0x91dc00fe,0x00000000}},	//   мбет_, یچلر, _ঠাইখ, --, 
   {{0x1ce00135,0x200000e8,0xa1980150,0x00000000}},	//   _སྦལ_, _ñiiy_, _ﺘﺼﺭﻑ_, --, 
   {{0x7d08031c,0xfcf40023,0xe3b0007b,0x6d4401f4}},	//   _oqfs, _ፈሊጡ_, حرم_, äjak, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x659410cd,0xb63801ec,0x00000000,0x00000000}},	//   _сасу, _ﺄﻥ_, --, --, 
   {{0x09e000bd,0x0ea80f06,0x00000000,0x00000000}},	//   _বাসা, мкий_, --, --, 
   {{0xf77c0205,0x00000000,0x00000000,0x00000000}},	//   _geçe_, --, --, --, 
   {{0x423400c8,0x7b9c0150,0x00000000,0x00000000}},	//   _שנעל_, _ﺍﺭﺍﺏ_, --, --, 
   {{0x9055a1dd,0x8fd0abba,0x00000000,0x00000000}},	//   _швец, _тәкә, --, --, 
   {{0xd9d8045e,0x00000000,0x00000000,0x00000000}},	//   _তাজম, --, --, --, 
   {{0x2efc0a55,0xeea800cf,0x787801f4,0x00000000}},	//   muuf_, _этек_, yävä, --, 
   {{0x2f080579,0x2efc0a55,0x01e4009e,0xc76400d1}},	//   løg_, luuf_, _নামদ, ھارى, 
   {{0x26141b76,0xaa3c0023,0x787801f4,0x00000000}},	//   न्नी_, _ኣፈላላ, vävä, --, 
   {{0x2bd8dd06,0x2efc198f,0xdb1402d2,0x00000000}},	// [2cbc0] _भ्या, nuuf_, _áaðs, --, 
   {{0x78780664,0x2aa401b8,0xd09800ac,0x7860000d}},	//   tävä, böba_, rçən, _rõve, 
   {{0x2efc0a55,0x2f0812e8,0xf6200107,0x00000000}},	//   huuf_, høg_, рдхо, --, 
   {{0x2efc198f,0x7878023a,0x37e000db,0xd72000cc}},	//   kuuf_, rävä, _коюг, _নপৰা_, 
   {{0x778000a7,0x2efc208d,0x9f44036e,0xf77c0205}},	//   _вляз, juuf_, ramë_, _peçe_, 
   {{0x2efc198f,0x6725a1de,0xd04003e3,0x00000000}},	//   duuf_, mwij, _itlə, --, 
   {{0x6725a1df,0x3fc401d5,0x00000000,0x00000000}},	//   lwij, نگشی_, --, --, 
   {{0x2efc198f,0x7860000d,0xc1a401ec,0x00000000}},	//   fuuf_, _tõve, ныққ, --, 
   {{0x67259598,0x2efc198f,0x96a800af,0xc3c001e0}},	//   nwij, guuf_, _कठमउ, _йөҙл, 
   {{0xdea401d5,0xc1043cc6,0x9c7c00c0,0x00000000}},	//   چیچی, _لوئي, msči, --, 
   {{0x7d080408,0xc0040024,0x9c7c0024,0x6724016d}},	//   _qqfs, _апек, lsči, hwij, 
   {{0x6725a1e0,0x9f440093,0x2efc0a55,0x9c7c0153}},	//   kwij, hamé_, buuf_, osči, 
   {{0xba75a1e1,0xfb85a1e2,0x6725a1e3,0x2ef000d4}},	//   ناست, тынн, jwij, _взір, 
   {{0x6725a1e4,0xee2c00ec,0x9c7c00c0,0x00000000}},	//   dwij, _وٽن_, isči, --, 
   {{0x672401f5,0xf80454f2,0x09e00154,0x8e84030d}},	//   ewij, кчан, _বাশা, _сăрч, 
   {{0x20043209,0x9c7c0006,0x67240d27,0x4bc03ad0}},	//   ngmi_, ksči, fwij, _гөрг, 
   {{0x6725a1e5,0x7c3c6730,0x5d1401d9,0x1880001f}},	// [2cbd0] gwij, _inqr, _شِکا, _የእግር_, 
   {{0x1ce00d46,0x7c2c03ac,0x75240175,0xd69815b4}},	//   _སྦོ_, ldcr, _psjz, رپاؤ_, 
   {{0x98b897d0,0x9c7c0153,0xfafc036e,0x00000000}},	//   _плот_, esči, izëm_, --, 
   {{0x6725a1e6,0x5fb40d2c,0x9f440ffb,0x2efc208d}},	//   bwij, ुशाल, pamè_, yuuf_, 
   {{0x2efc208d,0xb270010b,0x7c280162,0x52748e3c}},	//   xuuf_, аңач, _ógru, луку, 
   {{0xdb74001f,0xdb1c0267,0x00000000,0x00000000}},	//   _አንድም_, bbsö, --, --, 
   {{0xc6909b62,0x8fd01cd1,0x2efc8fea,0xa5f80063}},	//   _האם_, бәлә, wuuf_, _јесу_, 
   {{0x1ce00ad3,0xd0240e46,0x2efc0a55,0x8fa41cd6}},	//   _སྦེ_, умий, tuuf_, лайе, 
   {{0x6f080334,0x4f9476b8,0x00000000,0x00000000}},	//   _qqgc, ырку, --, --, 
   {{0x8350066d,0x7c3c003a,0xfc3c0008,0x2efc0a55}},	//   _دھما, _anqr, nlíf_, ruuf_, 
   {{0xd13054b6,0x09e002a6,0x2f08019b,0x2efc22a9}},	//   _دما_, _বালা, søg_, suuf_, 
   {{0x09bc01bc,0x6724014f,0xa1580114,0x2a78002f}},	//   ्ड्य, ywij, _шаху_, wirb_, 
   {{0x2efc0ba7,0x26140954,0x67240327,0x8db401ec}},	//   quuf_, न्डी_, xwij, _өскі, 
   {{0x7c2da1e7,0x67240477,0x00000000,0x00000000}},	//   adcr, vwij, --, --, 
   {{0x67240003,0x95e8015b,0x00000000,0x00000000}},	//   wwij, খলাম_, --, --, 
   {{0x6724f858,0x9c7c0024,0x26c40098,0x6a740213}},	//   twij, ysči, _émok_, _müfə, 
   {{0xf741a1e8,0x9f4406af,0x672401a4,0xe6b401d5}},	// [2cbe0] бето, tamé_, uwij, للرگ, 
   {{0x67240460,0xcec0033f,0xd1bc0023,0x00000000}},	//   rwij, mięć_, ደራት_, --, 
   {{0x6725a1e9,0xa4941c93,0x45340a89,0x9f440098}},	//   swij, لیست, ыхат, ramé_, 
   {{0xae100cb4,0x9f44002e,0x6724014f,0x00000000}},	//   त्तन_, samé_, pwij, --, 
   {{0xf484315b,0x53c4059f,0x82f4084c,0x69dc2700}},	//   دالی, рҳум_, учец, obre, 
   {{0x6235a1ea,0x9c7c0153,0x96540395,0x5bc009ab}},	//   реку, rsči, _късч, _एल्व, 
   {{0x69dcf8ee,0x969001d5,0x959800db,0x00000000}},	//   ibre, _بیلش, _атту_, --, 
   {{0x786000af,0x69dc0112,0xa3cc00cd,0x9c7c00c0}},	//   _kõva, hbre, _श्च_, psči, 
   {{0x7de53934,0xf1cc00dc,0x2614012c,0xefbc0023}},	//   лінд, _स्कन, न्थी_, ቶርያ_, 
   {{0x1ce0025c,0xbd69a1eb,0xf65c00b5,0x69dc784d}},	//   _སྦུ_, ерме_, _utæt_, jbre, 
   {{0xa3e83eaf,0xf77c0120,0xf6780375,0x78600254}},	//   _मजा_, _meça_, תאימ, _lõva, 
   {{0x2614df24,0xf77c00d8,0xafe0009d,0x00000000}},	//   न्ती_, _leça_, _гоцл, --, 
   {{0x69dda1ec,0x78600254,0x7c2d3c0c,0xa2d80073}},	//   fbre, _nõva, rdcr, नीच्, 
   {{0x69dda1ed,0xcfe802f5,0x1cd4031c,0x00000000}},	//   gbre, _গায়_, ེེད_, --, 
   {{0x64400e29,0xee700022,0x7e780857,0xee0400d8}},	//   _onmi, _ылшь, mitp, _сејл_, 
   {{0x7e798817,0x69dc0204,0xbea40451,0x9a700092}},	//   litp, abre, _جهڙن_, _ባገኘው_, 
   {{0x69dda1ee,0xd6d01b06,0x68fc01ab,0x00000000}},	// [2cbf0] bbre, زقا_, arrd, --, 
   {{0x6441a1ef,0xf9ec03d4,0x69dc0142,0x00000000}},	//   _anmi, ঞ্জল_, cbre, --, 
   {{0x7bcda1f0,0x261447d0,0xb5a5a1f1,0x00000000}},	//   occu, न्धी_, урай, --, 
   {{0x6288a8c4,0x7e7803a2,0x6a7403e3,0xe718215c}},	//   _ajdo, hitp, _rüfə, ئيەت_, 
   {{0x7e782831,0xd1b801d3,0x00000000,0x00000000}},	//   kitp, ھاتا_, --, --, 
   {{0x26140abd,0x6441a1f2,0x877808a8,0x3a2000b5}},	//   न्दी_, _enmi, _יארי, nejp_, 
   {{0x9444c67c,0x2c6c01e1,0x2a64036e,0xcec00210}},	//   _پھان, _jòdù_, ëmbi_, zięć_, 
   {{0x69dc0dfe,0x9404030f,0xfc3c0332,0x00000000}},	//   zbre, _خوره, imís_, --, 
   {{0x0e6404a9,0xf8bc015b,0x69dc0076,0x7ae8005c}},	//   икин, _mié_, ybre, _ægth, 
   {{0x7e79a1f3,0xf8bc07ea,0x2bd80254,0x69dc0036}},	//   gitp, _lié_, भुना, xbre, 
   {{0x4c85a1f4,0x32c800d6,0x6440000f,0xe1f0165e}},	//   илов, _høy_, _ynmi, _رسل_, 
   {{0x69dc0072,0xf8bda1f5,0x5f7400ec,0x00000000}},	//   wbre, _nié_, _ڏاهر, --, 
   {{0x69dda1f6,0x9f44026c,0x929c033f,0x7e78035a}},	//   tbre, namì_, _spły, bitp, 
   {{0x26c414ac,0x7bcc026c,0x32040263,0xde700882}},	//   _émoi_, accu, ngny_, _tvāṃ_, 
   {{0xde94a554,0x32c8003b,0x32040129,0x7aec01e7}},	//   _اجنب, _løy_, igny_, asct, 
   {{0x1ce02eab,0xf8bc026c,0x3d1805f9,0x6d44023a}},	//   _སྦི_, _cié_, _बहते_, äjau, 
  
   {{0xd90cf9e1,0xf77da1f7,0xf8bda1f8,0x26c82be7}},	// [2cc00] ویی_, _peça_, _dié_, اطری_, 
   {{0x45d5a1f9,0x2abc01e1,0xfc3c004e,0xf65c2ab7}},	//   рцат, _dábì_, bmís_, _stær_, 
   {{0x83c56c3e,0x929c033f,0xdb240241,0xe6b800b8}},	//   абеж, _upły, _ìpòg, _ųaųņ, 
   {{0x959800f7,0x32c8143a,0x7410027d,0xb6740092}},	//   утуу_, _bøy_, قوما, _በጨለማ_, 
   {{0xdb0c00a2,0xf77c0139,0xcfe800eb,0x00000000}},	//   _ogaý, _teça_, _গাঢ়_, --, 
   {{0xc75c044e,0x64580034,0x32c800cc,0xb6a1a1fa}},	//   ተኾይኑ_, _ścią, _døy_, _миял, 
   {{0x3618008f,0x8cc002a0,0x05a87dad,0x7bcc0113}},	//   _שולד, _रंगो, _करिब, yccu, 
   {{0x6441a1fb,0xdb0c010b,0x7e780b4f,0x442002f0}},	//   _unmi, _agaý, witp, _úk_, 
   {{0x7e79a1fc,0x32c8168c,0x7e449308,0xed680023}},	//   titp, _gøy_, ахне, ትግበር_, 
   {{0xfc3c0306,0x00000000,0x00000000,0x00000000}},	//   jmír_, --, --, --, 
   {{0x63a1a1fd,0xdd952281,0x7e79a1fe,0x61e803ac}},	//   _hymn, саны, ritp, _iedl, 
   {{0x629914e1,0x61e9a1ff,0x70501216,0x9f45a200}},	//   lovo, _hedl, _ونلا, lamí_, 
   {{0xbe880724,0x60c80455,0x63a0007f,0x61e96120}},	//   _иске_, _hudm, _jymn, _kedl, 
   {{0x61e880fe,0x60c80585,0xdb0c00af,0xaa644d87}},	//   _jedl, _kudm, _igaü, отск, 
   {{0x61e8d95f,0x2bd80a28,0x63a00649,0xadd40302}},	//   _medl, _भ्वा, _lymn, _דווח_, 
   {{0x161851a5,0x1ce00135,0x61e9a201,0xfc3c1e7b}},	//   न्नर_, _སྦག_, _ledl, rmís_, 
   {{0x6299a202,0x395c00da,0xbbe03599,0x919400d1}},	// [2cc10] kovo, ņus_, परीक, ﺗﻘﯘﭼ, 
   {{0x1a6400dd,0x60c85e52,0x32c803cd,0xc8f400fe}},	//   _ایسی_, _oudm, _røy_, _চহৰত_, 
   {{0x60c80477,0x61fc08a5,0x00000000,0x00000000}},	//   _nudm, _örly, --, --, 
   {{0xef1c0365,0x63a003a2,0x61e80254,0x2abc01e1}},	//   çük_, _bymn, _aedl, _tábì_, 
   {{0x28c01533,0x26140da8,0x60c805ac,0xe7855b15}},	//   _शूटि, न्ही_, _audm, _дуро, 
   {{0x60c8d863,0x61e804cc,0xfafc04e6,0x63a04d8c}},	//   _budm, _cedl, irë_, _dymn, 
   {{0x3204050a,0x4fa40092,0x8fd00352,0x00000000}},	//   rgny_, _ዋናዎቹ_, пәлә, --, 
   {{0x60c87a56,0x32c808fb,0x61e8127b,0xed6802d3}},	//   _dudm, _tøy_, _eedl, ትግባር_, 
   {{0x62980122,0x9f4402ea,0x60c800a3,0x63a1a203}},	//   bovo, bamí_, _eudm, _gymn, 
   {{0x1ce0031c,0x00000000,0x00000000,0x00000000}},	//   _སྦང_, --, --, --, 
   {{0xfafc0023,0x00000000,0x00000000,0x00000000}},	//   erë_, --, --, --, 
   {{0xfbdc025a,0x61e80117,0x1e840137,0x00000000}},	//   gbê_, _zedl, йлөм, --, 
   {{0x2fdda204,0x61e8009a,0x945c00a2,0x408401d3}},	//   mbug_, _yedl, _gińe, _دھوپ_, 
   {{0x2bd80882,0xfbdc011f,0x61e8022e,0x7f38011a}},	//   _भ्रा, abê_, _xedl, _תעסו, 
   {{0x09e45f0f,0xfafc036e,0x28b43885,0xa3e801f9}},	//   _қонн, arë_, ंगलि, _मजल_, 
   {{0x6299a205,0xfc3c02fb,0xae1000af,0x2fdc020c}},	//   zovo, smír_, त्रन_, nbug_, 
   {{0x6298014b,0xf740a30d,0x2efc002f,0x00000000}},	// [2cc20] yovo, пето, nruf_, --, 
   {{0x2fdc0175,0x6299a206,0x63a0007c,0x1b0003d4}},	//   hbug_, xovo, _rymn, _লৈকে_, 
   {{0xfb8404d3,0x63a01368,0x96b8bae4,0x969402dd}},	//   _ندیی, _symn, руту_, іруш, 
   {{0xd49800d6,0x61e86075,0x60c80048,0x2efda207}},	//   арі_, _sedl, _rudm, kruf_, 
   {{0x6299a208,0x27e1a209,0x4df80316,0x61e9a20a}},	//   tovo, mbin_, ूलाई_, _pedl, 
   {{0x27e01368,0x25082a60,0x61e8014f,0xcfe401ec}},	//   lbin_, _پرسی_, _qedl, _ﺍﺩﺍﻗ, 
   {{0x61e9a20b,0xe3b01374,0x27e060b7,0x945c00a2}},	//   _vedl, سرچ_, obin_, _sińe, 
   {{0xdbdc025a,0x61e9a20c,0x2fdc089c,0x27e1a20d}},	//   _dâûd, _wedl, gbug_, nbin_, 
   {{0x4425a20e,0x61e807de,0x27e00067,0x00000000}},	//   meo_, _tedl, ibin_, --, 
   {{0x4425a20f,0x27e00327,0xddc803cb,0xd0a8009d}},	//   leo_, hbin_, yndŵ, лтөд_, 
   {{0xd2940014,0x2efc022f,0x2fdd3cec,0x6e9401c6}},	//   _بُلک, aruf_, bbug_, свэр_, 
   {{0xc0e802d3,0x9f4404cc,0xbbe000bc,0x2efc002f}},	//   ዘየለ_, ramâ_, परेक, bruf_, 
   {{0xddc9a210,0x27e00014,0x44240086,0xd25800e2}},	//   midž, dbin_, ieo_, _suņi_, 
   {{0xfafc069c,0x4425a211,0xd1c80201,0x69c801f1}},	//   rrë_, heo_, _አንተ_, žden, 
   {{0x4425a212,0xf77c06ed,0x9f440ffb,0x00000000}},	//   keo_, _peço_, lamà_, --, 
   {{0x4425a213,0x661c107d,0xfafc002e,0x7c65a214}},	//   jeo_, _abrk, prë_, _داتل, 
   {{0x4425a215,0x9f441f40,0x56780500,0x00000000}},	// [2cc30] deo_, namà_, абая_, --, 
   {{0x27e00067,0x64ac2ca8,0xf56801ec,0x998c00ef}},	//   abin_, _işiy, лшек_, _ķoņu_, 
   {{0x4425a216,0x27e1a217,0xddc800f3,0xf40003d4}},	//   feo_, bbin_, kidž, _ৰোগৰ_, 
   {{0x2fdc0369,0xe8e00208,0x00000000,0x00000000}},	//   xbug_, _nhột_, --, --, 
   {{0x9f4408e5,0xddc80153,0xe8e00051,0x337000c7}},	//   jamà_, didž, _phệt_, чҳар, 
   {{0x44240428,0x2fdc0076,0x00000000,0x00000000}},	//   aeo_, wbug_, --, --, 
   {{0x44240381,0xefd0001f,0x737400c7,0x00000000}},	//   beo_, _የቆየ_, шыҧх, --, 
   {{0x661c16a3,0x2efc0112,0xe8e00208,0x00000000}},	//   _zbrk, truf_, _chột_, --, 
   {{0xb8c8003d,0x2fdc0221,0x63548726,0x161800bc}},	//   _བེ_, rbug_, _евту, न्थर_, 
   {{0x2fdda218,0x2efda219,0xdb0c0de2,0xc0e80023}},	//   sbug_, rruf_, _ngañ, ዘየሎ_, 
   {{0x27e01fc2,0x2efc0548,0x4fd4667a,0x64ac0205}},	//   ybin_, sruf_, _джет, _aşiy, 
   {{0x16183fec,0x8c443acc,0xefd00092,0x00000000}},	//   न्तर_, цеме, _የቆዩ_, --, 
   {{0x7af80960,0x9e641ef1,0x9f44026c,0x81c000eb}},	//   šutn, زاین, camà_, ূরণ_, 
   {{0x4425a21a,0x7fb5a21b,0xdfa80451,0x00000000}},	//   zeo_, _ظهور_, _اُهو_, --, 
   {{0x44243743,0xfaa1a21c,0x9f440407,0x64ac1432}},	//   yeo_, фаро, mamá_, _eşiy, 
   {{0x4425a21d,0x9f45a21e,0xdb0c009d,0x27e00175}},	//   xeo_, lamá_, _egañ, ubin_, 
   {{0x27e1a21f,0x2ca01c06,0xfc3c00d7,0x85e80f06}},	// [2cc40] rbin_, _ikid_, slíc_, идав_, 
   {{0x9f446137,0x442480de,0x96b800d3,0x27e0058a}},	//   namá_, weo_, буху_, sbin_, 
   {{0x4425a220,0xfc3c056a,0x052835c7,0x4528011c}},	//   teo_, llía_, роек_, ржен_, 
   {{0x63a4021c,0x7b040174,0x00000000,0x00000000}},	//   üino, _úrtí, --, --, 
   {{0x4424325f,0x00000000,0x00000000,0x00000000}},	//   reo_, --, --, --, 
   {{0x4424b0a0,0x161812eb,0xbb380a1e,0x752c04e6}},	//   seo_, न्दर_, יעני, äizä, 
   {{0x35a03bfd,0xddc80fcf,0x00000000,0x00000000}},	//   _жарг, tidž, --, --, 
   {{0x442400fb,0x9f5402bf,0x00000000,0x00000000}},	//   qeo_, звич, --, --, 
   {{0xf8b00bd4,0xfd60a898,0xddc83e9d,0x82341ec7}},	//   ושה_, _fitọ, ridž, _ورئا, 
   {{0xbbe0243c,0x9f44026c,0xddc80024,0x03d401e1}},	//   पर्क, ramà_, sidž, _èébú_, 
   {{0xddc805be,0x6a700036,0x9f44026c,0xdb0c02d2}},	//   pidž, _käff, samà_, _agað, 
   {{0xb03000d1,0xdce800ef,0x00000000,0x00000000}},	//   _يىلغ, gzdā, --, --, 
   {{0x09e003f4,0x00000000,0x00000000,0x00000000}},	//   _বাজা, --, --, --, 
   {{0x6a7001c7,0x7af84b16,0x195864c2,0x00000000}},	//   _läff, šuto, багы_, --, 
   {{0xed0000f7,0xa9341572,0x2a6400e4,0x261400c5}},	//   _قووپ, мерш, êmba_, _नउजी_, 
   {{0x9b9401c0,0xfc3c02d2,0x00000000,0x00000000}},	//   _нийц, blía_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [2cc50] --, --, --, --, 
   {{0xa3c01414,0xb5a403c5,0x00000000,0x00000000}},	//   ीशन_, орей, --, --, 
   {{0x98c4152d,0x09e00154,0x00000000,0x00000000}},	//   _хөгж, _বাচা, --, --, 
   {{0x2aa401b8,0xb9f801f3,0x24c801ec,0x00000000}},	//   vöbi_, _ቆመ_, ігіп_, --, 
   {{0x33280139,0xfafc036e,0x8838011a,0x00000000}},	//   рцен_, mzës_, _פגשת, --, 
   {{0x999000dd,0x36200014,0xe8e001fb,0xdb1c01d3}},	//   lező_, _توسہ, _nhớt_, lcsó, 
   {{0x7645a221,0x81f4007b,0xf4840150,0x00000000}},	//   _injy, سفير_, _дуан, --, 
   {{0x6a700139,0x09e00154,0xf77c0166,0x1b0003d4}},	//   _gäff, _বাছা, _neçk_, _লৈছে_, 
   {{0xd25800e2,0x9f45a222,0xfd600248,0x925800d8}},	//   _suņu_, tamá_, _titọ, _лаат_, 
   {{0x670c04fa,0x2ca1a223,0xefb80023,0x00000000}},	//   िंतक_, _skid_, ደፋዊ_, --, 
   {{0x999001ed,0x1ce0031c,0x00000000,0x00000000}},	//   kező_, _སྦད_, --, --, 
   {{0xfafc0023,0x00000000,0x00000000,0x00000000}},	//   jzës_, --, --, --, 
   {{0x5b3400a8,0x64ac0139,0x5f2800d4,0x00000000}},	//   мэру, _vşix, _моїм_, --, 
   {{0xd5bc01d9,0x09e000bd,0xe8f80032,0x2ca00175}},	//   ्खाज, _বাঙা, оһо_, _wkid_, 
   {{0x3e301d57,0x00000000,0x00000000,0x00000000}},	//   _سفير, --, --, --, 
   {{0xfc3da224,0x16180b68,0x764544f5,0x7d2401ed}},	//   llín_, न्सर_, _anjy, őrsé, 
   {{0x86c5a225,0x3b8002e8,0x084401d9,0x6a7001e3}},	// [2cc60] سيان, _плъг, _ہندُ, _räff, 
   {{0x6a700267,0x5ba401e0,0x77800395,0x00000000}},	//   _säff, _юлығ, хлуз, --, 
   {{0xfc3c00c6,0x6a7001c7,0x00000000,0x00000000}},	//   ilín_, _päff, --, --, 
   {{0xc20c1533,0x603c0241,0xfb1410e8,0xfc3c00d7}},	//   _साहब_, _ḿmú, _بقیع_, hlín_, 
   {{0x333da226,0x6235a227,0x1ce00327,0x00000000}},	//   _crux_, делу, _སྦན_, --, 
   {{0x291803d1,0x3e800248,0x00000000,0x00000000}},	//   otra_, _métè_, --, --, 
   {{0x3e800248,0xd4f4e738,0x00000000,0x00000000}},	//   _létè_, _ояты, --, --, 
   {{0x9ed9a228,0x291803d1,0x2b4001fa,0xd130003a}},	//   омит_, itra_, _oric_, _ds̅_, 
   {{0x7410fb36,0x2919a229,0xe8e0004d,0x76440432}},	//   _سولا, htra_, _phớt_, _ynjy, 
   {{0x13a80244,0x00000000,0x00000000,0x00000000}},	//   _بچمی_, --, --, --, 
   {{0x2b400048,0xd0180227,0x291801f1,0x999001d3}},	//   _aric_, sińa_, jtra_, yező_, 
   {{0x2b41a22a,0x29180109,0x00000000,0x00000000}},	//   _bric_, dtra_, --, --, 
   {{0xfc3c0005,0xe8e001fb,0x29180109,0xe8e8031c}},	//   blín_, _thớt_, etra_, _འཆུག, 
   {{0x2b40dacc,0x2919a22b,0x00000000,0x00000000}},	//   _dric_, ftra_, --, --, 
   {{0xfd4405f5,0xc7d8063f,0x999001d3,0x2e34011a}},	//   _хэлн, _ọbụr, tező_, _מרגש_, 
   {{0x2b415c73,0xb8e40210,0x00000000,0x00000000}},	//   _fric_, _ों_, --, --, 
   {{0x2919a22c,0x2b41a22d,0xf77c1b0d,0xfafc036e}},	// [2cc70] atra_, _gric_, _keçi_, rzës_, 
   {{0x76840124,0x00000000,0x00000000,0x00000000}},	//   чыбж, --, --, --, 
   {{0xca8002d3,0x78600037,0xf77c0200,0x999000e5}},	//   _ካብኦም_, _lõvi, _meçi_, pező_, 
   {{0x3dbc00cc,0xed5c0419,0x00000000,0x00000000}},	//   _ইভাল, ížik_, --, --, 
   {{0xd1c801af,0x2bf800df,0x84c0008e,0x00000000}},	//   олле_, למאן_, тәрд, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe1f01c93,0x65940fd7,0x90b40640,0x466002dd}},	//   اسه_, _зару, мљиш, _جۇلق, 
   {{0xcf4405f5,0x333da22e,0x00000000,0x00000000}},	//   дний, _trux_, --, --, 
   {{0xb8ec0135,0x5215a22f,0x7af80841,0x6a700112}},	//   _ུང_, _одат, šutj, _häfe, 
   {{0x6a71a230,0x4d64187f,0x8d640120,0x29180072}},	//   _käfe, дков, двое, ytra_, 
   {{0xfc3da231,0x2919a232,0x6a700793,0x31680063}},	//   rlín_, xtra_, _jäfe, _ушао_, 
   {{0x291806d9,0xd9c40154,0x6ed8000d,0x00000000}},	//   vtra_, ্রাম, _मझऊँ, --, 
   {{0x20189f20,0xfc3d5286,0x00000000,0x00000000}},	//   əri_, plín_, --, --, 
   {{0x2919a233,0xc330008d,0x7e64005f,0xfc3c011f}},	//   ttra_, דוך_, ūkpr, llíl_, 
   {{0x2cc4025c,0x29180077,0x6a70070a,0xeff40092}},	//   _གཤིབ, utra_, _näfe, ለጸው_, 
   {{0x2b41a234,0x46e8838f,0x2919a235,0x00000000}},	//   _tric_, ждан_, rtra_, --, 
   {{0xf21000af,0xfc3c0332,0x5e540244,0x00000000}},	// [2cc80] _ठाढ़_, ilíl_, _تئۆر, --, 
   {{0x2919a236,0x46180006,0x00000000,0x00000000}},	//   ptra_, ўцаў_, --, --, 
   {{0xca4800f1,0x00000000,0x00000000,0x00000000}},	//   _هلکه_, --, --, --, 
   {{0x7ea40174,0x00000000,0x00000000,0x00000000}},	//   rðpi, --, --, --, 
   {{0x87b89532,0x932400e5,0x00000000,0x00000000}},	//   _фунт_, ٹرنن, --, --, 
   {{0x38c804fb,0x11f40131,0x3f800bcd,0x00000000}},	//   _دایی_, ىتىگ, úkum_, --, 
   {{0x441402a9,0x11f4030f,0xf77c0200,0x00000000}},	//   _офат, رتوگ, _reçi_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf77c1366,0xceac0451,0xb0300108,0x69c800d7}},	//   _peçi_, ڍڙو_, тныш, ždeh, 
   {{0x5d541f00,0xf2e400f2,0x00000000,0x00000000}},	//   екот, _آکنه_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfc3c0005,0xfd6000f7,0xfe4001c6,0x7f4800db}},	//   rlío_, енүү, хмүү, _ولاق_, 
   {{0x2bc80395,0x39e00116,0x00000000,0x00000000}},	//   дуро_, кәнғ, --, --, 
   {{0x7f40036b,0xdd9400c0,0x19580137,0x00000000}},	//   _iroq, _палы, пагы_, --, 
   {{0xf771a237,0x00000000,0x00000000,0x00000000}},	//   ھار_, --, --, --, 
   {{0xf771a238,0xb8d400af,0xa3c0098a,0x7c64216b}},	//   پار_, _छठ_, ीशा_, _زابل, 
   {{0x945c010e,0x00000000,0x00000000,0x00000000}},	// [2cc90] _dińl, --, --, --, 
   {{0x6a70014a,0x2bb8007b,0x2d8c02f0,0x76a800d4}},	//   _päfe, _غاية_, šleš_, ітав_, 
   {{0x7d1801ee,0x00000000,0x00000000,0x00000000}},	//   ntts, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe3b00372,0x00000000,0x00000000,0x00000000}},	//   ۇرۇ_, --, --, --, 
   {{0xe3b1a239,0xfc3c0216,0x00000000,0x00000000}},	//   جرم_, dlím_, --, --, 
   {{0x10a427cf,0x7f4001d5,0x02c00006,0x00000000}},	//   никн, _aroq, ыйшо, --, 
   {{0x7f4000db,0x998000b8,0xefc80092,0xb4b001af}},	//   _broq, _abhū_, _አድዋ_, _рибә, 
   {{0x92940022,0xe1f000db,0x7c28032e,0x00000000}},	//   _заац, اسۇ_, _ógry, --, 
   {{0x9f44025a,0x7f4003e3,0xa2b4014b,0xa3001de6}},	//   lamû_, _droq, _абуч, _түше, 
   {{0xd011a23a,0x7f4002d0,0x2614012c,0x91dc0055}},	//   _ملا_, _eroq, न्टी_, _gośṛ, 
   {{0xe6380092,0x00000000,0x00000000,0x00000000}},	//   _የፊናን, --, --, --, 
   {{0x261001ad,0x00000000,0x00000000,0x00000000}},	//   _ढाली_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6f180ffb,0x48b4272a,0x799402d0,0x9ac42f8d}},	//   ltuc, ещат, _cxxw, тирҗ, 
   {{0x6d402e95,0x00000000,0x00000000,0x00000000}},	//   _irna, --, --, --, 
   {{0x864400e4,0x6f186bfc,0xdecc0092,0xc690009f}},	// [2cca0] ннаж, ntuc, _አብን_, هِر_, 
   {{0xbb5c00b5,0x6d4001ef,0x00000000,0x00000000}},	//   _faxサ_, _krna, --, --, 
   {{0xeff400b7,0x84042077,0xc4c800bc,0x00000000}},	//   ጋንዳ_, епеж, िदेख, --, 
   {{0x6f180309,0x6d400f85,0x248001c3,0x00000000}},	//   ktuc, _mrna, òim_, --, 
   {{0x3e70004a,0x0664612e,0x00000000,0x00000000}},	//   _hâte_, _كاسپ, --, --, 
   {{0x3e7000e4,0x7d180267,0x6d400d63,0x6f180419}},	//   _kâte_, ytts, _orna, dtuc, 
   {{0xc0c80201,0xf77c0129,0xc5f40154,0x6d400055}},	//   _አቅም_, _deçu_, _চাপা_, _nrna, 
   {{0x7f41a23b,0x6f18011f,0xa8e800e1,0xfc3c00d7}},	//   _proq, ftuc, टीएफ_, tlím_, 
   {{0x6d41a23c,0xdb1c01ed,0xbe840063,0x9f440419}},	//   _arna, lcsö, ећни, lamú_, 
   {{0x6d4160aa,0x64a40131,0x91f40051,0x00000000}},	//   _brna, _чаға, _hón, --, 
   {{0xfc3c0232,0xdd95a23d,0x6d40c75b,0x7d180198}},	//   slím_, таны, _crna, utts, 
   {{0x7f407917,0x7d1992fa,0xe8e0004d,0xd3780354}},	//   _troq, rtts, _nhốt_, _ичĕ_, 
   {{0xfba8b0b9,0x6f185727,0x00000000,0x00000000}},	//   ятой_, ctuc, --, --, 
   {{0xefd0001f,0x6d400334,0x7d180036,0x00000000}},	//   _የቆዳ_, _frna, ptts, --, 
   {{0x3e70084c,0x26140ebb,0x79580166,0x00000000}},	//   _câte_, न्छी_, däwç, --, 
   {{0xe8e001fb,0x91f4004d,0x81e403d4,0x00000000}},	//   _chốt_, _nón, ভণি_, --, 
   {{0x7c2c0228,0xfc3c022a,0xd66800f1,0x00000000}},	// [2ccb0] mecr, hlík_, ومرو_, --, 
   {{0xfc3c02f0,0x00000000,0x00000000,0x00000000}},	//   klík_, --, --, --, 
   {{0xf77c4aee,0x1ad8009e,0x3e700129,0xda700451}},	//   _reçu_, _তিয়া, _gâte_, _مُک_, 
   {{0x6f180034,0xfc3c022a,0x00000000,0x00000000}},	//   ytuc, dlík_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x99c40154,0xfc3c013a,0x00000000,0x00000000}},	//   ্রীক, flík_, --, --, 
   {{0x6a7001b8,0xb60000bc,0x69c8009b,0x7c2da23e}},	//   _jäfa, rtáč, ždev, kecr, 
   {{0x6f19a23f,0x8fa40116,0x00000000,0x00000000}},	//   ttuc, кайе, --, --, 
   {{0xbf100137,0x7c2c01bf,0xb4bc41d8,0xd250d243}},	//   لويب, decr, ीदी_, _پنا_, 
   {{0x6f18aa42,0xfe40f01f,0x6d40020b,0xfc3d3553}},	//   rtuc, аньо, _prna, blík_, 
   {{0x6f19a240,0xfc3c01ef,0x00000000,0x00000000}},	//   stuc, clík_, --, --, 
   {{0xc0c80092,0x00000000,0x00000000,0x00000000}},	//   _አቅሙ_, --, --, --, 
   {{0x9f05a241,0x5120033d,0x9c7c0100,0x00000000}},	//   _مونو, _महुआ_, nsčy, --, 
   {{0x6d41a242,0x3e7007ea,0x8d75a243,0x00000000}},	//   _trna, _pâte_, _لابا, --, 
   {{0x6d400598,0xc21006a9,0x6a700166,0xe8e0004d}},	//   _urna, יהם_, _cäfa, _phốt_, 
   {{0x0c2407dd,0x0b45a244,0x290439e2,0x7c2ccebf}},	//   _рмин, _анин, čma_, cecr, 
   {{0xbc180302,0x06c801c0,0x290400b0,0xe7b000fe}},	// [2ccc0] _חופש, дгай_, ōma_, কশ্য, 
   {{0x3e700129,0x91f40208,0xa3e4482a,0x9f440332}},	//   _tâte_, _són, पुन_, tamú_, 
   {{0xe8e0004d,0x291c00c7,0xd52c01e1,0x00000000}},	//   _thốt_, _ëva_, _rọ́p, --, 
   {{0x69dda245,0x9f440efe,0xfc3c0306,0xdb1c01d3}},	//   lcre, ramú_, vlík_, rcsö, 
   {{0x2248134b,0xf484158b,0xdb1c00e5,0x00000000}},	//   нҗан_, خالی, scsö, --, 
   {{0x69dda246,0xfc3c0306,0x00000000,0x00000000}},	//   ncre, tlík_, --, --, 
   {{0xb0240131,0x00000000,0x00000000,0x00000000}},	//   چكىم_, --, --, --, 
   {{0x753400c8,0xdd940220,0xf9900375,0x69dc0784}},	//   _באלד_, ғамы, ירו_, hcre, 
   {{0x7c2da247,0xfc3c02fb,0x7de402dd,0xc1e001e0}},	//   vecr, slík_, кінд, _көйҙ, 
   {{0x7c2c0083,0x7e4400ee,0x93580166,0x00000000}},	//   wecr, тхие, _ярсу_, --, 
   {{0x7c2c127b,0x5275a248,0x00000000,0x00000000}},	//   tecr, _суту, --, --, 
   {{0x59d40316,0x705004fb,0xc0bc001f,0x80a4009e}},	//   _दलहर, _پنها, ቶችም_, খগহ্, 
   {{0x7c2da249,0x20d80221,0x6f1401d9,0x00000000}},	//   recr, _héi_, _لٲنس_, --, 
   {{0x7c2da24a,0x20d804e6,0xfafc002d,0xcbb40032}},	//   secr, _kéi_, byën_, ығыш_, 
   {{0xed4c7e2c,0x6b8c0213,0x7c2c6b53,0x8d44010a}},	//   _وپه_, _əngə, pecr, _йĕрш, 
   {{0x20d804d1,0x61f9a24b,0x7b6401f0,0x00000000}},	//   _méi_, havl, _атое, --, 
   {{0x20d9119d,0x569401c0,0x61f8003b,0x3c9001ed}},	// [2ccd0] _léi_, гаат, kavl, _میگز, 
   {{0x69dc800c,0x6a7004cc,0x5a340108,0xfc3c0139}},	//   ccre, _häfn, _снот, ldí_, 
   {{0x61f8036b,0x20d9a24c,0x7688012d,0x00000000}},	//   davl, _néi_, eżyc, --, 
   {{0xfc3da24d,0xb4bc0c2e,0xd3b83981,0x7af82672}},	//   ndí_, ीदे_, нулі_, šutu, 
   {{0xfc3c00c6,0xd7c802e9,0x00000000,0x00000000}},	//   idí_, _سوسه_, --, --, 
   {{0x61f9a24e,0x20d804e6,0xd250007b,0x2360000d}},	//   gavl, _béi_, صنع_, äija_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x20d8423a,0x6595a24f,0x00000000,0x00000000}},	//   _déi_, _тасу, --, --, 
   {{0xb4bc1e61,0xcdf5a250,0x8ec801d5,0x4df40153}},	//   ँगी_, лчны, нгиб_, лянт, 
   {{0x7bdc0067,0xcc8800f1,0x00000000,0x00000000}},	//   _afqu, ځنده_, --, --, 
   {{0xccc40228,0x20d804e6,0xcc880063,0x9c7c0306}},	//   лбой, _géi_, ебне_, rpčn, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc9bc0131,0x20d80036,0x99c40154,0xcb14013d}},	//   ﻠﯩﻨﻐ, _zéi_, ্রোক, ыфны, 
   {{0xc7a4016c,0x69dd3024,0x00000000,0x00000000}},	//   ҳибк, ucre, --, --, 
   {{0x69dda251,0x8c440184,0x88a00032,0x00000000}},	//   rcre, _бейе, йғоһ, --, 
   {{0x61f808ad,0x00000000,0x00000000,0x00000000}},	//   zavl, --, --, --, 
   {{0x3de0003e,0x945c010e,0x69dc02d0,0xd01800a2}},	// [2cce0] _érwé_, _gińi, pcre, gińi_, 
   {{0xeb9801a9,0x00000000,0x00000000,0x00000000}},	//   _пиқ_, --, --, --, 
   {{0x0444a441,0x61f9a252,0x88c95d37,0x00000000}},	//   лежн, vavl, _плов_, --, 
   {{0x20d80124,0x15b80032,0x00000000,0x00000000}},	//   _réi_, тыуы_, --, --, 
   {{0xe284c5dc,0x78a00998,0x6a7001b8,0x20d80221}},	//   аған, _ínva, _jäfo, _séi_, 
   {{0xfc3c0308,0x00000000,0x00000000,0x00000000}},	//   zdí_, --, --, --, 
   {{0xfc3d7c70,0x245400e5,0x00000000,0x00000000}},	//   mlív_, _پچاس, --, --, 
   {{0x61f9a253,0x20d9a254,0xf5900aaa,0x42d4003b}},	//   savl, _véi_, _الفج, _біжу, 
   {{0x20d804d1,0xa3e400af,0xbe8831e2,0x996000de}},	//   _wéi_, पुण_, есне_, cīņa_, 
   {{0xd3b83334,0xa544001f,0x20d801c7,0x3e700356}},	//   _русі_, _የሚንቀ, _téi_, _bâta_, 
   {{0xf0900451,0x3e700356,0x16180cf1,0x71a0059f}},	//   _گڏوگ, _câta_, न्टर_, _лафз, 
   {{0xd1740184,0x37a800fe,0x00000000,0x00000000}},	//   _тыуы, _কলঘৰ, --, --, 
   {{0xfc3da255,0xfb844445,0x7bdc003a,0xa1a401e0}},	//   rdí_, уынн, _vfqu, _сыҡһ, 
   {{0x7bdda256,0x25b80010,0xd64c0150,0x00000000}},	//   _wfqu, _ozrl_, лiне, --, 
   {{0xdb1c145e,0xf8480153,0x00000000,0x00000000}},	//   âyân, нчай_, --, --, 
   {{0x6a7005d5,0x7bdc003a,0x00000000,0x00000000}},	//   _häfl, _ufqu, --, --, 
   {{0xa8981531,0x3cfc010a,0x6924013e,0x23c800c0}},	// [2ccf0] укту_, lstv_, _қӯрғ, nįjį_, 
   {{0x6fc80724,0x6b7401ee,0x00000000,0x00000000}},	//   _höcü, _ылыу, --, --, 
   {{0x3cfc194f,0x69c87313,0x6fc806be,0x9e3c013a}},	//   nstv_, žder, _köcü, hoďo, 
   {{0xd3714db7,0x7c3c0135,0xfbdc00d8,0xb4bc02fe}},	//   يها_, _jaqr, ncê_, ँगे_, 
   {{0x7c3c0014,0x6fc800ac,0xfafc995d,0x00000000}},	//   _maqr, _möcü, nsë_, --, 
   {{0x3cfc33b8,0x23c800c0,0x00000000,0x00000000}},	//   kstv_, dįjį_, --, --, 
   {{0xc6900302,0x51540116,0x00000000,0x00000000}},	//   _ואם_, ртлу, --, --, 
   {{0xfafc0023,0x7c3c0135,0x00000000,0x00000000}},	//   ksë_, _naqr, --, --, 
   {{0x8e5402bf,0xd4a400d1,0xfafc0240,0xfbc428fe}},	//   атні, _биңй, jsë_, रेमम, 
   {{0x3e70006a,0xe1f042b5,0x63041884,0x8e840022}},	//   _pâta_, _فسم_, _دوكل, ргое, 
   {{0x7c3da257,0x6fc80205,0x53a401af,0x98b4012d}},	//   _baqr, _böcü, _саҡб, ंताए, 
   {{0xcb6818ec,0xb4d0012d,0x00000000,0x00000000}},	//   ваме_, _हंै_, --, --, 
   {{0xe7b009bd,0xce9400a7,0xfafc00e8,0x8e74588c}},	//   _কল্য, _кадъ, gsë_, _вуйч, 
   {{0x2efc022f,0xfc3c0162,0x00000000,0x00000000}},	//   msuf_, xlív_, --, --, 
   {{0x2efc7c74,0x7c3d1473,0x06c80046,0x00000000}},	//   lsuf_, _faqr, _ﺑﻮﻻﺩ, --, 
   {{0x614001ed,0x2fdc1bce,0xb4bc28f5,0x00000000}},	//   lálá, ncug_, ँगो_, --, 
   {{0xaa50044e,0xdb0c003e,0xb4bc012c,0xe6b4036b}},	// [2cd00] _ኣገልጋ, _nyaè, ँगै_, ملرگ, 
   {{0x614000dd,0xf5e400a8,0x2efc208d,0x7c3c06be}},	//   nálá, имул_, isuf_, _zaqr, 
   {{0xfc3c0174,0xa4940244,0x00000000,0x00000000}},	//   rlív_, میست, --, --, 
   {{0xc7a40212,0xfdd028d4,0x6fc8008e,0xfc3c0413}},	//   _вимк, _सल्फ, _xöcü, slív_, 
   {{0x27e0530b,0xb38001c6,0x614000e5,0xa3040139}},	//   mcin_, олцл, kálá, сүзе, 
   {{0x27e1a258,0x623400a8,0x00000000,0x00000000}},	//   lcin_, секу, --, --, 
   {{0x52740640,0x80a00073,0x31c00395,0x00000000}},	//   ључу, खवले, осъв, --, 
   {{0x27e04437,0x205406bb,0xfbdc011f,0xfafc0240}},	//   ncin_, ския, xcê_, ysë_, 
   {{0x44240605,0x27e04275,0x6a7001b8,0x42c80124}},	//   mfo_, icin_, _päfl, _аган_, 
   {{0x4425a259,0x7c3c02d1,0x0c0c01e1,0x5f9400d1}},	//   lfo_, _saqr, _iyẹẹ_, _қилт, 
   {{0x3cfc02c4,0x7c3c0113,0x27e003f9,0x4425a25a}},	//   ustv_, _paqr, kcin_, ofo_, 
   {{0x4425a25b,0x6441a25c,0xe7e81d8a,0x3cfda25d}},	//   nfo_, _jami, टुमा_, rstv_, 
   {{0x614022ec,0x4425a25e,0x7c3c0455,0xfbdc00d8}},	//   bálá, ifo_, _vaqr, rcê_, 
   {{0xfcf4044e,0x7c3c02d1,0x4f6401b9,0xfafca814}},	//   _ገሊጹ_, _waqr, _دامف, rsë_, 
   {{0x7c3da25f,0x44240093,0x28f8084c,0x644003ac}},	//   _taqr, kfo_, иерь_, _oami, 
   {{0x6441a260,0x9f4429ef,0x44240115,0xa8984b4d}},	//   _nami, kamü_, jfo_, аксу_, 
   {{0xd6d02e51,0x6289a261,0x442403b2,0xb92c0092}},	// [2cd10] سقا_, _omdo, dfo_, _ሥፍራዎ, 
   {{0x6441a262,0xdb0c1dd4,0x44240134,0x3568a20e}},	//   _aami, _nyaé, efo_, крен_, 
   {{0x6441a263,0x4425a264,0x78a00998,0x27e1a265}},	//   _bami, ffo_, _ínvo, bcin_, 
   {{0x62880502,0x9f440793,0x4424003e,0x614001ed}},	//   _amdo, famü_, gfo_, zálá, 
   {{0x6441a266,0x91e4f741,0xfc3c004e,0xc5f400eb}},	//   _dami, боле, llís_, _চারা_, 
   {{0x4424013b,0x64404c3e,0x00000000,0x00000000}},	//   afo_, _eami, --, --, 
   {{0x614001ed,0x00000000,0x00000000,0x00000000}},	//   válá, --, --, --, 
   {{0x6441a267,0xfc3c00c6,0x6289a268,0x00000000}},	//   _gami, ilís_, _emdo, --, 
   {{0x61418707,0x0ea9a269,0xafe001b9,0x777c0477}},	//   tálá, лкий_, боқл, nzqx, 
   {{0x6441a26a,0xf1a5a26b,0x2164008e,0x00000000}},	//   _zami, _крен, стәг, --, 
   {{0x2efda26c,0x3f80041e,0x8c4400b1,0x614001ed}},	//   ssuf_, úkur_, бене, rálá, 
   {{0xf8bc07ae,0x6441a26d,0xcfe8027d,0x00000000}},	//   _nhé_, _xami, _صفته_, --, 
   {{0x9f40008c,0xfc3c0077,0x2d88033f,0x6289a26e}},	//   _þið_, moíl_, ńce_, _ymdo, 
   {{0x7e79a26f,0x44240165,0xfc3c03b2,0xcc880139}},	//   chtp, zfo_, flís_, _әбие_, 
   {{0x48e401a9,0x7e940472,0x00000000,0x00000000}},	//   собв, _دنور_, --, --, 
   {{0xf8bda270,0x27e00b45,0x985400cf,0xbc9010fc}},	//   _ché_, ucin_, отуш, _најј, 
   {{0x27e1a271,0xf8bc3226,0x00000000,0x00000000}},	// [2cd20] rcin_, _dhé_, --, --, 
   {{0x27e003f9,0x77c4160b,0xfc3c068c,0x44240134}},	//   scin_, слуг_, blís_, wfo_, 
   {{0x4424bbab,0x42c802dd,0x00000000,0x00000000}},	//   tfo_, ңген_, --, --, 
   {{0x6441a272,0x74100f1b,0xf8bc001e,0xf2e4004b}},	//   _qami, كوما, _ghé_, څکله_, 
   {{0x6441a273,0xe1f8d74f,0x6a700139,0x133800e5}},	//   _vami, иҳа_, _näfk, لتوں_, 
   {{0x4425a274,0x8b04068f,0xbb380bd9,0x672401f5}},	//   sfo_, częś, טעני, mtij, 
   {{0x6441a275,0x6725a276,0x44242da1,0x9f440268}},	//   _tami, ltij, pfo_, jamò_, 
   {{0x0494911a,0x64401998,0xdb0c0724,0x67240010}},	//   _الرح, _uami, _uzaç, otij, 
   {{0x42183e43,0x25b807af,0x9c7c007f,0x9f5400d4}},	//   _مزاج_, _अरुण, spčk, івоч, 
   {{0xa3e422e3,0x6289a277,0xdbf01b76,0x945c012d}},	//   पुर_, _umdo, चर्ड_, _fińs, 
   {{0x67257765,0x814448c1,0xb65800df,0x00000000}},	//   htij, _دنان, אדיש, --, 
   {{0x6725a278,0x31540115,0x00000000,0x00000000}},	//   ktij, _ליבן_, --, --, 
   {{0x672401a4,0x50a00228,0xbea400c0,0x00000000}},	//   jtij, _تەيل, _ладк, --, 
   {{0xb698084c,0x6299a279,0x50d40132,0x672401a4}},	//   _avân, nnvo, _ازەر, dtij, 
   {{0x67240d27,0xf80400fd,0xed5400f3,0x00000000}},	//   etij, йчан, _гој_, --, 
   {{0x5b1430c4,0x6725a27a,0x998401ed,0x6298002f}},	//   _дмит, ftij, ülő_, hnvo, 
   {{0x672401f5,0x7c6400f1,0x00000000,0x00000000}},	// [2cd30] gtij, _ناکل, --, --, 
   {{0x629801a4,0xba7400e5,0x00000000,0x00000000}},	//   jnvo, _چاھت, --, --, 
   {{0x19580323,0xf8bc07ea,0x67240153,0x394401bf}},	//   _таны_, _thé_, atij, _éns_, 
   {{0x62981a7c,0xf8bc003e,0x6724025c,0x9a2401d3}},	//   envo, _uhé_, btij, _اٹھن, 
   {{0xe785a27b,0x241802bf,0x672401f5,0xeab00133}},	//   _еуро, сією_, ctij, _زعی_, 
   {{0xe2c800aa,0x6a70013d,0xdef80092,0x00000000}},	//   مونو_, _räfk, ጋጅና_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x62980b4f,0x8e7c0115,0xc3d801ec,0x00000000}},	//   anvo, mpŝi, _көшi, --, 
   {{0x929401c6,0x8e580063,0x13a40345,0x00000000}},	//   _даац, ајну_, _بۆشی_, --, 
   {{0xd108b227,0x9f440268,0xd8b80327,0x4094004e}},	//   _نقطه_, tamò_, _དེའི, йрөт, 
   {{0xfbc413f7,0x6724005a,0xe2c831b1,0x519401c8}},	//   रेसम, ztij, _اولو_, _بلاذ, 
   {{0x6a700139,0x00000000,0x00000000,0x00000000}},	//   _täfk, --, --, --, 
   {{0x3b8000d3,0x67240076,0x9f3420c8,0x00000000}},	//   дляг, xtij, _неці, --, 
   {{0x6a71a27c,0x5f800b38,0x60c40003,0x00000000}},	//   _käfi, _سۇپە, ċime, --, 
   {{0x6a7029ef,0x66d00241,0x672401f5,0x00000000}},	//   _jäfi, _lókì, wtij, --, 
   {{0x6725a27d,0x00000000,0x00000000,0x00000000}},	//   ttij, --, --, --, 
   {{0x81b403f9,0x6298017a,0xd7880014,0xa6440092}},	// [2cd40] ɓɓug, ynvo, منٲو_, _የማይተ, 
   {{0x2b400998,0xb6f4104b,0xa2d800cd,0x00000000}},	//   _isic_, تىكا_, मदस्, --, 
   {{0x6725a27e,0x6a70008e,0x00000000,0x00000000}},	//   stij, _näfi, --, --, 
   {{0x29191645,0x67240d27,0x62980158,0xd4980212}},	//   mura_, ptij, wnvo, брі_, 
   {{0x2919a27f,0x67240357,0x7c280274,0x00000000}},	//   lura_, qtij, _ögre, --, 
   {{0x668407d6,0x2918f047,0xaabc07d0,0x9c7c00c0}},	//   _عیال, oura_, ोगिक, rpči, 
   {{0x291820cd,0x845800f3,0x04940006,0x00000000}},	//   nura_, _крат_, _драў, --, 
   {{0x29180295,0x222801d3,0x9fd80154,0xc0c80798}},	//   iura_, _گزری_, সর্গ, шуле_, 
   {{0x7300084c,0x6ce002dd,0x00000000,0x00000000}},	//   _оптз, _ﺍﻟﺨﺴ, --, --, 
   {{0x35ac09fd,0xc1540114,0x00000000,0x00000000}},	//   _जुड़, _мњењ, --, --, 
   {{0x2919a280,0x2b40fe1d,0xc0580212,0x3fe4011c}},	//   jura_, _asic_, _віл_, _джев, 
   {{0x7044030c,0x00000000,0x00000000,0x00000000}},	//   _ورنە, --, --, --, 
   {{0x2b404a29,0x2b44009d,0x00000000,0x00000000}},	//   _csic_, мэрг, --, --, 
   {{0xbd6806ed,0x6d4803b2,0x00000000,0x00000000}},	//   _врие_, úlaæ, --, --, 
   {{0x2919a281,0x79a40220,0x35ac00c5,0x00000000}},	//   gura_, ірге, _जुढ़, --, 
   {{0x1a64a268,0x00000000,0x00000000,0x00000000}},	//   _کیسی_, --, --, --, 
   {{0x2b400334,0x29180356,0x00000000,0x00000000}},	// [2cd50] _gsic_, aura_, --, --, 
   {{0x29180537,0x69c80118,0x00000000,0x00000000}},	//   bura_, ýdec, --, --, 
   {{0x74a40120,0x00000000,0x00000000,0x00000000}},	//   ојде, --, --, --, 
   {{0x6a70008e,0xd9d000d1,0x00000000,0x00000000}},	//   _räfi, _يەڭگ, --, --, 
   {{0x6a700166,0x00000000,0x00000000,0x00000000}},	//   _säfi, --, --, --, 
   {{0x6a700793,0x00000000,0x00000000,0x00000000}},	//   _päfi, --, --, --, 
   {{0xa504036b,0xd00801ec,0x00000000,0x00000000}},	//   _оятл, бейе_, --, --, 
   {{0xa99c0375,0xa3e401ad,0x00000000,0x00000000}},	//   יבור, पुआ_, --, --, 
   {{0x2919a282,0x57b8190c,0x00000000,0x00000000}},	//   zura_, _आरोह, --, --, 
   {{0x2919a283,0x0d841c50,0xc330010f,0xa2d809fa}},	//   yura_, злон, _אומ_, मदर्, 
   {{0x2b400607,0x291801c0,0x8c45a284,0xf044014b}},	//   _ssic_, xura_, пене, _мэдо, 
   {{0x2918602b,0x20d40022,0xc1b805d0,0x93400240}},	//   vura_, _ẽiva_, _המעש, _ባይቶታ, 
   {{0x2919a285,0x92dc03d4,0x9e6401e2,0x00000000}},	//   wura_, থীৰ_, ساین, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfaa1a286,0x4c6805f5,0x3ea0003e,0xf1c800cd}},	//   харо, _гийн_, ékte_, ाधिन, 
   {{0x29182dab,0x2b40007f,0xada001e0,0x47d4007b}},	//   rura_, _tsic_, _наҙл, سيطر, 
   {{0x2ca00c6a,0x0608af8e,0x6ce001ec,0x7c380254}},	// [2cd60] _ijid_, йнак_, _ﺍﻟﺠﺴ, õure, 
   {{0xf1c81d2e,0xcd5802d3,0x00000000,0x00000000}},	//   ाधान, _ንመንፈ, --, --, 
   {{0x2919a287,0xff9c069d,0xbb180356,0xa4f80073}},	//   qura_, _ውድድሩ_, nzîn, ुळेच_, 
   {{0xe8e0004d,0x00000000,0x00000000,0x00000000}},	//   _nhứt_, --, --, --, 
   {{0xa31801ce,0xeaa00055,0x00000000,0x00000000}},	//   іжку_, _goṣv_, --, --, 
   {{0xefc402d3,0x25080405,0xf77c0135,0xc5f400eb}},	//   _ጽልዋ_, _ورزی_, ħħtu_, _চাকা_, 
   {{0x35a06a27,0x00000000,0x00000000,0x00000000}},	//   _зарг, --, --, --, 
   {{0xae2401c0,0x9f5400d8,0x00000000,0x00000000}},	//   үцэж_, двич, --, --, 
   {{0x656801ab,0xb3900092,0x00000000,0x00000000}},	//   _àdhb, ፃቸውን_, --, --, 
   {{0xd0900cc1,0x2ca0003e,0x73301e4a,0x00000000}},	//   _müəl, _ajid_, _سىما, --, 
   {{0x290da288,0x1c380de7,0x00000000,0x00000000}},	//   ádal_, озны_, --, --, 
   {{0xd64c01ec,0xe2c8009f,0x00000000,0x00000000}},	//   кiле, _اوڄو_, --, --, 
   {{0x2ca00334,0x7d0001d3,0x93400023,0xb3800408}},	//   _djid_, _bírá, _ባይታታ, _слăл, 
   {{0x7f4023e0,0xaa642461,0x00000000,0x00000000}},	//   _isoq, нтск, --, --, 
   {{0x7d0001e1,0xed0000cf,0x00000000,0x00000000}},	//   _dírá, _كووپ, --, --, 
   {{0x2db40302,0x6ca42f6a,0x00000000,0x00000000}},	//   _מלון_, _прыж, --, --, 
   {{0x7d19a289,0xbb1800db,0x00000000,0x00000000}},	// [2cd70] luts, _ازعا_, --, --, 
   {{0x3e70004a,0x7d000ca8,0x2f58011a,0x7d1802d0}},	//   _bâti_, _gírá, זדמנ, outs, 
   {{0x7d19a28a,0x9474a4ca,0x8e7c01e4,0x00000000}},	//   nuts, وگرا, mpŝt, --, 
   {{0x61e80ac5,0xe3b0764c,0x7e680af9,0x7d0001ef}},	//   _afdl, گرم_, _lofp, _zírá, 
   {{0x7d19780d,0x7e680857,0x6ce002dd,0x00000000}},	//   huts, _oofp, _ﺍﻟﺤﺴ, --, 
   {{0x7d19a28b,0x972c1e38,0x3e7000d2,0xe3b00214}},	//   kuts, _ስርዓት, _fâti_, درم_, 
   {{0x7d19a28c,0xe534005b,0xd3c40116,0x00000000}},	//   juts, _перь, ستچى, --, 
   {{0x7d181b33,0x6a705df4,0xf8bc5829,0x7645a28d}},	//   duts, _häft, ्षिय, _hajy, 
   {{0x76440526,0xe4c4023a,0x6a700267,0x7d180175}},	//   _kajy, _чёрн, _käft, euts, 
   {{0x7d19a28e,0x20d400c7,0x60c4025c,0x00000000}},	//   futs, _ẽita_, ċima, --, 
   {{0x7d19a28f,0x7645a290,0x2bd0b305,0xf8bc194b}},	//   guts, _majy, सेना, ्षाय, 
   {{0xa0c5a291,0xa13400f1,0x4f9401c6,0x290c00d7}},	//   _كيلو, _سرمش, _орлу, ádam_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7d18e601,0x76440230,0x3ce40150,0x00000000}},	//   buts, _najy, _ﺍﻟﺩﻤ, --, 
   {{0x9e641b31,0x7d184ec2,0xbea12360,0x6f1804e6}},	//   _ساون, cuts, _шашк, luuc, 
   {{0xabc401af,0x00000000,0x00000000,0x00000000}},	//   _пайҙ, --, --, --, 
   {{0x7645a292,0x1abc0c58,0xd1e0001f,0x6f180009}},	// [2cd80] _bajy, _ইংৰা, ሟላት_, nuuc, 
   {{0xb6a001c6,0x9c7c0100,0x00000000,0x00000000}},	//   виул, spčt, --, --, 
   {{0x76440007,0x08c400f7,0xcef82b1b,0x6a70013d}},	//   _dajy, _обон, _আমোদ_, _däft, 
   {{0xf485a293,0x6d40010a,0x752007c5,0x6f18058a}},	//   وانی, _msna, ànza, kuuc, 
   {{0xd0400b45,0x77800276,0x61e80175,0xf7c40ae5}},	//   _hulɗ, _аляз, _pfdl, ﯨﺮﻟﻪ, 
   {{0x7d194b24,0x3984022e,0x6f180009,0x00000000}},	//   yuts, _bеsh_, duuc, --, 
   {{0x26d9a294,0x7d1801f0,0xe3e800e5,0x00000000}},	//   _iiro_, xuts, _فکشن_, --, 
   {{0x7d19a295,0x26d9a296,0x76440526,0x9e3c02f0}},	//   vuts, _hiro_, _zajy, hoďt, 
   {{0x6d41a297,0x7645a298,0x26d9a299,0x7d19a29a}},	//   _asna, _yajy, _kiro_, wuts, 
   {{0x7d19a29b,0x26d9a29c,0x72c0ea23,0x3ce40150}},	//   tuts, _jiro_, _абуз, _ﺍﻟﺭﻤ, 
   {{0x7d180869,0xd12c00f1,0x030c04af,0x00000000}},	//   uuts, _هڅي_, _सिँह_, --, 
   {{0x7d19a29d,0x26d85a22,0x6f180014,0x7050036b}},	//   ruts, _liro_, buuc, _لنما, 
   {{0x2005a29e,0x7d19a29f,0x6d41a2a0,0xfb840724}},	//   mami_, suts, _esna, фынн, 
   {{0x7d19a2a1,0x26d9a2a2,0x3868003a,0x00000000}},	//   puts, _niro_, _socr_, --, 
   {{0xfca83669,0x7d180eda,0x76452e89,0xead40276}},	//   _وابو_, quts, _rajy, торь, 
   {{0x030c4425,0x6a700732,0x7644002b,0x00000000}},	//   _सिंह_, _säft, _sajy, --, 
   {{0x26d9a2a3,0x7644010b,0x3ce40220,0x41dc1fc4}},	// [2cd90] _biro_, _pajy, _ﺍﻟﺠﻤ, मशास, 
   {{0x36343b7a,0x6d40010e,0x80c801f9,0x7c2c15c0}},	//   بررس, _ysna, ागुं, lfcr, 
   {{0x26d9a2a4,0x25b9a2a5,0xe4e40212,0x6f18037e}},	//   _diro_, _cyrl_, вічн, zuuc, 
   {{0x26d9a2a6,0x7645a2a7,0x7c2c003a,0x00000000}},	//   _eiro_, _wajy, nfcr, --, 
   {{0x2005a2a8,0x929416ab,0x76452deb,0x26d802f0}},	//   dami_, надц, _tajy, _firo_, 
   {{0x26d91b54,0x7c2c01ab,0x00000000,0x00000000}},	//   _giro_, hfcr, --, --, 
   {{0x2005a2a9,0x836004b3,0xc5f40154,0x34381291}},	//   fami_, _ەگىل, _চাচা_, _وسرد_, 
   {{0x656800a3,0xcf45a2aa,0x65780b1a,0x00000000}},	//   _àdha, ений, øvhe, --, 
   {{0x64a40261,0x6d41a2ab,0x7688012d,0x0eb80166}},	//   _раѓа, _ssna, używ, зуны_, 
   {{0x6f180050,0x26d9a2ac,0x200400e4,0x2aa00241}},	//   ruuc, _xiro_, aami_, _ḿbí_, 
   {{0x2005a2ad,0x2158007b,0x10140064,0x00000000}},	//   bami_, _يجمع_, _зьля, --, 
   {{0x2005a2ae,0x6a70008e,0xfc3c02d2,0x00000000}},	//   cami_, _näfr, hníf_, --, 
   {{0xa3e406ab,0x9ac4031c,0xa2c400cd,0x00000000}},	//   पुट_, keċċ, िगच्, --, 
   {{0x4078005e,0x6a70007c,0x00000000,0x00000000}},	//   _ولەڭ_, _räfs, --, --, 
   {{0x26d80325,0x19b800d6,0x6d400118,0x6a70007c}},	//   _riro_, дуть_, _usna, _säfs, 
   {{0x26d8a93d,0x06e9a2af,0xe6b4036b,0x4b24003b}},	//   _siro_, змак_, چلرگ, _змив, 
   {{0x26d9a2b0,0x07a40124,0xe6b4036b,0x09e4009b}},	// [2cda0] _piro_, хаан, نلرگ, _попн, 
   {{0x2005a2b1,0x26d8058a,0x76200024,0x00000000}},	//   zami_, _qiro_, лмуз, --, 
   {{0x26d9a2b2,0xa495a2b3,0x2005a2b4,0x291c035b}},	//   _viro_, نیست, yami_, _êva_, 
   {{0xc4852c36,0x44300209,0x26d83743,0x2005a2b5}},	//   элек, ýy_, _wiro_, xami_, 
   {{0x26d9a2b6,0x20041821,0x29180e14,0x47d401f7}},	//   _tiro_, vami_, lrra_, _سيسر, 
   {{0x2004406f,0x2919a2b7,0x6235a2b8,0xa195a2b9}},	//   wami_, orra_, теку, калч, 
   {{0xde700055,0x00000000,0x00000000,0x00000000}},	//   _ntāṃ_, --, --, --, 
   {{0x29182953,0x20040083,0x80c80183,0xf990011a}},	//   irra_, uami_, ৰৱন্, טרו_, 
   {{0x2005a2ba,0x29180023,0x7d0802d0,0x2bac0dba}},	//   rami_, hrra_, _svfs, _टँगा, 
   {{0x2005a2bb,0x29180240,0xd29400c7,0xd24c0050}},	//   sami_, krra_, _ирхь, _وۆن_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00c9a2bc,0x2005a2bd,0x29180023,0x00000000}},	//   _элек_, qami_, drra_, --, 
   {{0x2918198f,0xde7000cd,0x00000000,0x00000000}},	//   erra_, _etāṃ_, --, --, 
   {{0xceb80118,0x00000000,0x00000000,0x00000000}},	//   tuře_, --, --, --, 
   {{0x38c400a7,0x00000000,0x00000000,0x00000000}},	//   ещав, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2919a2be,0x7bdc0944,0x2bd01bbb,0xb4b000d1}},	// [2cdb0] arra_, _igqu, सेदा, қидә, 
   {{0xfc3c1132,0xe8b80327,0xdb0c06be,0x7e79a2bf}},	//   leí_, བཞུག, _ayaç, nktp, 
   {{0xd7c40073,0x29180200,0xb5a5a2c0,0xe5c4009d}},	//   लेजच, crra_, храй, гсцо, 
   {{0xe8e0004d,0x00000000,0x00000000,0x00000000}},	//   _giựt_, --, --, --, 
   {{0x7bdc009a,0x25fc09bb,0x96280171,0x88800244}},	//   _mgqu, _लड़की_, _puņķ, _ئیقن, 
   {{0x3e700129,0x00000000,0x00000000,0x00000000}},	//   _mâts_, --, --, --, 
   {{0x7bdc0b6f,0xfc3c0270,0x00000000,0x00000000}},	//   _ogqu, keí_, --, --, 
   {{0x7bdda2c1,0xb874001f,0xb4b005a2,0x00000000}},	//   _ngqu, _የወጣው_, _сибә, --, 
   {{0xfc3c0122,0x7afc0175,0x0fc43e09,0xde700055}},	//   deí_, _nwqt, ъйин, _stāṃ_, 
   {{0x7bdc0944,0x21640cef,0xd01000dd,0x0e54023b}},	//   _agqu, ттәг, _چلا_, тъия, 
   {{0x3205a2c2,0xfa2409bd,0x7c380115,0xa6e800cc}},	//   many_, য়াল_, ĵurn, _পিছট, 
   {{0x3205a2c3,0x6abccc41,0x6a700139,0x00000000}},	//   lany_, ोग्र, _räfq, --, 
   {{0xc4d004ac,0xe0d010ef,0x32040109,0x7bc0010f}},	//   יגט_, _ازل_, oany_, _ŝnur, 
   {{0x3204325f,0x7bdc0921,0xe8e0004d,0xad800150}},	//   nany_, _egqu, _nhợt_, _ماعۇ, 
   {{0xb7ec01f2,0x29180ba7,0xa3b807f7,0xa2b400dc}},	//   _ụbụb, urra_, _घुन_, ेतत्, 
   {{0x3204325f,0x5894009d,0x00000000,0x00000000}},	//   hany_, гшуу, --, --, 
   {{0x3205a2c4,0xb60401fb,0x37e00063,0x4648d027}},	// [2cdc0] kany_, _thờ, роуг, мзан_, 
   {{0xe8e0001e,0x290401d9,0xfb1800df,0x00000000}},	//   _chợt_, _مژرِ, _קוימ, --, 
   {{0x3205a2c5,0x9a140276,0x64dc041c,0x88c9a2c6}},	//   dany_, _сфыш, यदेश, _олов_, 
   {{0x24805207,0x32040076,0x00000000,0x00000000}},	//   óim_, eany_, --, --, 
   {{0x3205a2c7,0xabe40220,0xdb0c008e,0x00000000}},	//   fany_, _ﺍﯞﻣﺎ, _vyaç, --, 
   {{0x3205a2c8,0xfc3c02fb,0x7d0c02f0,0x80d80a59}},	//   gany_, zeí_, ábsk, _पूजे, 
   {{0x55c5a2c9,0xd3a401ec,0x00000000,0x00000000}},	//   _барғ, _ұлтқ, --, --, 
   {{0x44200ec3,0x35a001c6,0x00000000,0x00000000}},	//   _øk_, _тасг, --, --, 
   {{0x32043270,0xc245a2ca,0xd04001e4,0xfc3c004e}},	//   bany_, _инак, _mulɨ, veí_, 
   {{0x32042f53,0x00000000,0x00000000,0x00000000}},	//   cany_, --, --, --, 
   {{0x7e79a2cb,0x6299a2cc,0xdd940184,0x36180a1e}},	//   rktp, mivo, уаны, וויד, 
   {{0x6299a2cd,0x7c700131,0x98ac025c,0x00000000}},	//   livo, рғич, ċeċ_, --, 
   {{0xfc3c3bd4,0x9e357738,0x00000000,0x00000000}},	//   reí_, _белч, --, --, 
   {{0x6299a2ce,0xddd8010e,0xfc3c00e4,0x00000000}},	//   nivo, _govş, seí_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3204962c,0xf8bc07b7,0x7bdc209c,0xfca9092e}},	//   zany_, ्षेप, _ugqu, _تاتو_, 
   {{0x80d809bb,0xddd803b9,0x17540108,0x00000000}},	// [2cdd0] _पूछे, _yovş, ывая, --, 
   {{0x7d183406,0xda700014,0x04840075,0x00000000}},	//   orts, _چُک_, қәси_, --, 
   {{0x320471ee,0xda700014,0xd5b000e3,0x00000000}},	//   vany_, _نُک_, حفا_, --, 
   {{0x3204006d,0x224c0ac5,0x6298017a,0xb8640753}},	//   wany_, _aadk_, eivo, _شاجو, 
   {{0x3205a2cf,0x7d1803fa,0x224c017a,0x27480107}},	//   tany_, hrts, _badk_, _ичро_, 
   {{0x6299a2d0,0xe2c800aa,0xd468074d,0x81bc00fe}},	//   givo, نونو_, миçе_, ীখন_, 
   {{0x32045fd3,0x224c058a,0x22140816,0xf04033ae}},	//   rany_, _dadk_, рфір, لعظی, 
   {{0x3205a2d1,0xc44401d3,0x629801f4,0x00000000}},	//   sany_, _میمن_, aivo, --, 
   {{0x3205a2d2,0xe3b80276,0x7d19a2d3,0x8e740aac}},	//   pany_, _алтч_, erts, гунч, 
   {{0x7d18010a,0x3204022f,0x9e8002d3,0xddd80213}},	//   frts, qany_, _ንቖልዓ_, _qovş, 
   {{0xb06801af,0x00000000,0x00000000,0x00000000}},	//   _ордж_, --, --, --, 
   {{0xdb0c528b,0x9f0400db,0x00000000,0x00000000}},	//   _azañ, _چونو, --, --, 
   {{0x7d184549,0x9f048ee7,0x00000000,0x00000000}},	//   arts, _نونو, --, --, 
   {{0x1e84063b,0xe3c40724,0xbf980bd9,0x6f1801f5}},	//   _клім, lnıñ_, _אינש, mruc, 
   {{0xed6000d7,0x6f18002f,0x00000000,0x00000000}},	//   _dlží_, lruc, --, --, 
   {{0xe3c41248,0xdb0c0165,0x38c83e66,0xb60002fb}},	//   nnıñ_, _ezañ, فاقی_, hráč, 
   {{0x62980b6f,0x47c40261,0xb60002f0,0xe3c40166}},	// [2cde0] yivo, убав, kráč, inıñ_, 
   {{0x68447601,0x4a4425fc,0x3b8006d3,0xea2401c6}},	//   ынға, _снов, _ылыг, _өчүү, 
   {{0x6299a2d4,0xe3c400fd,0xa8a400db,0xa2b400cd}},	//   vivo, knıñ_, _ۅلگۉ, ेतस्, 
   {{0x6f18924f,0xc4740014,0xe3c40139,0x00000000}},	//   kruc, دیرچ_, jnıñ_, --, 
   {{0x62989ace,0xfc3c0419,0xe3c4008e,0x00000000}},	//   tivo, lníc_, dnıñ_, --, 
   {{0x6f19a2d5,0x62980194,0x3984022e,0x7d1855e3}},	//   druc, uivo, _tеst_, yrts, 
   {{0x09d405ac,0x6f180210,0xe3c4013d,0x00000000}},	//   _ত্তা, eruc, fnıñ_, --, 
   {{0x6f19a2d6,0x04440108,0xe3c4013d,0x00000000}},	//   fruc, _щебн, gnıñ_, --, 
   {{0x44242819,0x7e281fe2,0xa2c40166,0xaab428fe}},	//   mgo_, ніна_, _кәкк, ंकाक, 
   {{0x4425a2d7,0x83501a4d,0x6298013c,0x2f34007b}},	//   lgo_, _پھچا, qivo, اثية_, 
   {{0x4425a2d8,0x5275a2d9,0xcfa80f1c,0xfc3c0419}},	//   ogo_, _туту, _یاهم_, jníc_, 
   {{0x4425a2da,0x6f19a2db,0xa3e401ad,0xfc3c0419}},	//   ngo_, bruc, गशिप_, dníc_, 
   {{0x4425a2dc,0xab84009b,0xceac00ec,0x00000000}},	//   igo_, бурк, _ڪڙي_, --, 
   {{0x44240007,0x82c00327,0x82880248,0x00000000}},	//   hgo_, _ཞེསའ, _yàtọ, --, 
   {{0x4425a2dd,0x00000000,0x00000000,0x00000000}},	//   kgo_, --, --, --, 
   {{0x57f400d6,0x4425a2de,0xf77000ec,0x00000000}},	//   рпат, jgo_, ٽار_, --, 
   {{0x4425a2df,0x785401b9,0x00000000,0x00000000}},	// [2cdf0] dgo_, نیگز_, --, --, 
   {{0x4425a2e0,0xe3c40724,0x26c40036,0x5f1c1a04}},	//   ego_, znıñ_, _ëmol_, _मिन्_, 
   {{0x290d75e0,0xe3c40724,0xfc3da111,0x3ce800c5}},	//   ádat_, ynıñ_, cníc_, _घूमे_, 
   {{0x4425a2e1,0x6f180113,0x00000000,0x00000000}},	//   ggo_, yruc, --, --, 
   {{0xe3c40724,0x00000000,0x00000000,0x00000000}},	//   vnıñ_, --, --, --, 
   {{0x4425a2e2,0x6f19a2e3,0x00000000,0x00000000}},	//   ago_, vruc, --, --, 
   {{0xe3c400fd,0x6f180113,0x4425a2e4,0x00000000}},	//   tnıñ_, wruc, bgo_, --, 
   {{0x69c8068f,0x00000000,0x00000000,0x00000000}},	//   żdeg, --, --, --, 
   {{0xe3c41248,0x8fa5a2e5,0xa858011a,0xfc3c0419}},	//   rnıñ_, рапе, ריחה_, zníc_, 
   {{0x2b5c013a,0x00000000,0x00000000,0x00000000}},	//   _čvc_, --, --, --, 
   {{0x6f18002f,0xf1a401f4,0xa2b42894,0x00000000}},	//   sruc, _сран, ेतर्, --, 
   {{0x6f19a2e6,0xe3c40724,0xfc3c00d0,0x7e1c012d}},	//   pruc, qnıñ_, vníc_, पलॉग_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4425a2e7,0x5f74021a,0x00000000,0x00000000}},	//   zgo_, _دامر, --, --, 
   {{0xaca4063f,0x4425a2e8,0xc89410fc,0xfaa1a2e9}},	//   _agụi, ygo_, арањ, царо, 
   {{0x7d540302,0xfc3c0419,0x00000000,0x00000000}},	//   _כיצד_, rníc_, --, --, 
   {{0xc6040395,0x27b400fb,0xfc3c0419,0x00000000}},	// [2ce00] изай, сәнс, sníc_, --, 
   {{0x3ab00046,0x290c00c6,0x4424031c,0x00000000}},	//   _дәст, ádas_, wgo_, --, 
   {{0x6b140156,0x5a0001c0,0x4424022e,0x291c0588}},	//   ིངམོ_, _хүсв, tgo_, _íva_, 
   {{0x4425a2ea,0x15b800fb,0x00000000,0x00000000}},	//   ugo_, уыуы_, --, --, 
   {{0x03a45f4d,0xc2440276,0x23d0c7f9,0xa2b40073}},	//   шидо, индк, तेंद, ेतल्, 
   {{0x4425a2eb,0xc2b40640,0xe20801e1,0x00000000}},	//   sgo_, шљењ, _gbó̟_, --, 
   {{0x35a1a2ec,0xb698019f,0xf7cc0ed1,0x0444030d}},	//   _дарг, _kwân, ﻛﯩﻠﺪ, _кевн, 
   {{0xc1a40046,0x2548010e,0xbf64007b,0x4424022e}},	//   лыққ, _işl_, لدخو, qgo_, 
   {{0x5f94167e,0x672401f4,0x9e3400cf,0x00000000}},	//   сипт, nuij, бепч, --, 
   {{0xb69800d2,0x00000000,0x00000000,0x00000000}},	//   _lwân, --, --, --, 
   {{0x6725a2ed,0xb0dc43d1,0x00000000,0x00000000}},	//   huij, _पंचग, --, --, 
   {{0xb17804ac,0x6725a2ee,0x00000000,0x00000000}},	//   _שטאר, kuij, --, --, 
   {{0xdef40006,0x9f0400f2,0xdd9000cf,0x00000000}},	//   _уплы, _چوچو, زوڭ_, --, 
   {{0x79a5a2ef,0xdcb80115,0xcc6400f7,0x00000000}},	//   арбе, puĉo_, _ۇنىۋ, --, 
   {{0xf8040e58,0xfc3c09c2,0xa3b8060c,0xb8d42f84}},	//   ичан, anía_, _घुस_, لترش, 
   {{0xba240eac,0xacf002f2,0x00000000,0x00000000}},	//   য়েড_, _بسوت, --, --, 
   {{0x35e5929e,0x290c01e7,0x00000000,0x00000000}},	// [2ce10] ацев, ádar_, --, --, 
   {{0x0af00323,0xaa4400cf,0x00000000,0x00000000}},	//   _хүрэ, _ۇنۋى, --, --, 
   {{0xdce80118,0x00000000,0x00000000,0x00000000}},	//   vydě, --, --, --, 
   {{0xe4a402bf,0x2458a19b,0x00000000,0x00000000}},	//   орчо, иахь_, --, --, 
   {{0xb4c40c2e,0x2548008e,0x083800df,0x00000000}},	//   _उठी_, _eşl_, _גערל, --, 
   {{0xa5f9a2f0,0x00000000,0x00000000,0x00000000}},	//   _веру_, --, --, --, 
   {{0x5155a2f1,0x00000000,0x00000000,0x00000000}},	//   стлу, --, --, --, 
   {{0xfbdda2f2,0x95c86171,0x00000000,0x00000000}},	//   ndês_, _ауға_, --, --, 
   {{0x72280798,0x00000000,0x00000000,0x00000000}},	//   _ацев_, --, --, --, 
   {{0xe1f14cc3,0xc3040014,0x63a4007b,0xc0f802d3}},	//   _قسم_, _دبٲو, úine, ጊሶም_, 
   {{0xc2100302,0xbc800208,0x6ce00150,0x00000000}},	//   _זהב_, ượn, _ﺍﻟﺒﺴ, --, 
   {{0xcb683576,0x8fd004a9,0x7054010a,0x00000000}},	//   гаме_, _нәпә, _тĕме, --, 
   {{0x929c0034,0x8e7400ee,0x5a480023,0x3ed001d5}},	//   _zwła, _гуйч, _ብምምጻ, تقیر, 
   {{0xa9680075,0xff540677,0x99cc01e1,0x00000000}},	//   қиға_, _לבנך_, _ṣálá, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x08c40107,0xfc3c0419,0x00000000,0x00000000}},	//   ёбан, lnín_, --, --, 
   {{0xac980014,0xe8e00051,0x00000000,0x00000000}},	// [2ce20] _مۆھا_, _nhụt_, --, --, 
   {{0x49b9a2f3,0x672401f5,0x2b4089b4,0x07a408ca}},	//   _ماجد_, ruij, _ipic_, _ҳамн, 
   {{0x2b400048,0x09d4015b,0xfc3c00ae,0x00000000}},	//   _hpic_, _ত্রা, inín_, --, 
   {{0x68fc0165,0xace001ec,0x07a4005a,0x75d000ae}},	//   mprd, _ﺍﻟﯟﺷ, _гамн, سينا, 
   {{0xe8e00208,0xbddc01ec,0x00000000,0x00000000}},	//   _chụt_, _ﺘﻌﻤل_, --, --, 
   {{0x461400f8,0xbb38008f,0xfc3c00d7,0x00000000}},	//   _دوسر, רעסי, jnín_, --, 
   {{0xc0580220,0xfbdc63cd,0x969001b9,0x00000000}},	//   гіп_, ndêr_, _تیلش, --, 
   {{0x2b40d301,0x23480214,0x00000000,0x00000000}},	//   _opic_, _پسری_, --, --, 
   {{0x7411a2f4,0x7de40220,0x3f81a2f5,0xd83800a2}},	//   _رولا, йінд, áku_, _öōe_, 
   {{0xec680491,0xe284072d,0x9d1401f4,0x00000000}},	//   _בֿ_, _بطری, одоч, --, 
   {{0xb6b804ac,0x628801c6,0x6d4c0210,0x00000000}},	//   רציי, _ildo, łcan, --, 
   {{0xb698006a,0x62880589,0x66d0010e,0x00000000}},	//   _awâl, _hldo, läkd, --, 
   {{0xaf30085b,0xfc3c00d7,0xab8400d8,0x00000000}},	//   _فروت, bnín_, пурк, --, 
   {{0x79e400e5,0x00000000,0x00000000,0x00000000}},	//   صورہ_, --, --, --, 
   {{0x2b404916,0xdd9401af,0x9f0401f7,0x00000000}},	//   _epic_, _файы, _اوڻو, --, 
   {{0xb4c40c2e,0xe68815bf,0x00000000,0x00000000}},	//   _उठे_, ەنكى_, --, --, 
   {{0x6289a2f6,0xe730bf17,0xa3b800e1,0x4bc00132}},	// [2ce30] _oldo, فصل_, _घुल_, _жөрг, 
   {{0xeef40375,0x79a41fbe,0x1a640244,0x00000000}},	//   צמבר_, _грме, _بیسی_, --, 
   {{0xe610b745,0x2cf8010f,0x59dcb1e3,0x00000000}},	//   عشك_, ָלדא, _मणिर, --, 
   {{0x628804ac,0x3aec0598,0xe8e00208,0x00000000}},	//   _aldo, _küp_, _phụt_, --, 
   {{0xf8bc0241,0x3aec00a2,0x66240118,0x3ce80037}},	//   _iké_, _jüp_, átké, _घूसे_, 
   {{0x9118084c,0xe3b001f7,0x00000000,0x00000000}},	//   ациу_, ررن_, --, --, 
   {{0xf8bc011f,0x1bf807f7,0x00000000,0x00000000}},	//   _kké_, ंडाल_, --, --, 
   {{0x2eb070b0,0x628804ac,0x09d400fe,0xe8e0004d}},	//   ुत्त, _eldo, তুকা, _thụt_, 
   {{0x62880100,0xa4d402bf,0xaca4063f,0x161c00e1}},	//   _fldo, _хоті, nsụl, _पयार_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf8bda2f7,0x2b400077,0x8c45a2f8,0x8d742e3e}},	//   _oké_, _spic_, оене, زادا, 
   {{0x2d88006d,0x8c9402bf,0x66d03f47,0x2d800327}},	//   ące_, ірні, mäke, ġje_, 
   {{0x2d81a2f9,0x66d1a2fa,0x4e940244,0x00000000}},	//   šje_, läke, _وشتر, --, 
   {{0xf8bda2fb,0x3aec29ef,0xefb004fb,0x00000000}},	//   _aké_, _düp_, _ویژگ, --, 
   {{0x66d0005b,0x3ea002e2,0x00000000,0x00000000}},	//   näke, èkte_, --, --, 
   {{0x6da00184,0xfbdc017a,0xcba401d5,0x929c012d}},	//   _миҙа, rdêr_, _майй, _owło, 
   {{0x07a40323,0x68fc01a6,0x3aec00a2,0x66d008a1}},	// [2ce40] цаан, sprd, _güp_, häke, 
   {{0x689401d3,0x00000000,0x00000000,0x00000000}},	//   _کیرئ, --, --, --, 
   {{0x44f40214,0x00000000,0x00000000,0x00000000}},	//   زساز, --, --, --, 
   {{0xd7f80c60,0x6abda2fc,0x83c4005b,0x3aec00a2}},	//   _гуё_, lorf, обеж, _yüp_, 
   {{0x133800dd,0x00000000,0x00000000,0x00000000}},	//   متوں_, --, --, --, 
   {{0x2735a2fd,0xdb200fac,0x00000000,0x00000000}},	//   män_, _åtål, --, --, 
   {{0x2735a2fe,0x00000000,0x00000000,0x00000000}},	//   län_, --, --, --, 
   {{0xb97800c8,0xc0587707,0x1f740108,0x6abc538b}},	//   ינצי, рік_, злия, horf, 
   {{0x2735a2ff,0x6abda300,0x7e4407e6,0x00000000}},	//   nän_, korf, охне, --, 
   {{0xb22000a8,0x628801e4,0x2734023a,0x00000000}},	//   _омул, _uldo, iän_, --, 
   {{0x2734426d,0x929c012d,0x00000000,0x00000000}},	//   hän_, _zwło, --, --, 
   {{0x2735a301,0x656800db,0x3be400f7,0x00000000}},	//   kän_, _àdhu, өлүү_, --, 
   {{0x2734049b,0x6abc28b3,0xf4100375,0x3aec0166}},	//   jän_, forf, ופר_, _qüp_, 
   {{0x2735a302,0xdd942e9a,0xfc3c00bc,0x6abda303}},	//   dän_, _налы, mním_, gorf, 
   {{0xfc3c012c,0x58d5a304,0x9424025c,0x00000000}},	//   lním_, зовт, _ཤྰཀྱ_, --, 
   {{0x5b14147e,0x3aec05d1,0x27340139,0x00000000}},	//   _емит, _tüp_, fän_, --, 
   {{0x27341248,0xfc3c00bc,0x6abda305,0x02c801bc}},	// [2ce50] gän_, nním_, borf, िताभ, 
   {{0xadc001e1,0xfafca87b,0xf1bc0118,0x1bf801f9}},	//   _afẹh, mpë_, íško_, ंडवल_, 
   {{0xea00001e,0xfafc0240,0x398017a5,0x00000000}},	//   _hiếu_, lpë_, _غیرف, --, 
   {{0x27340598,0xf8bc00d5,0xdf000327,0x7f40022e}},	//   bän_, _uké_, _koċċ_, _opoq, 
   {{0xeab026f0,0xb5f00220,0x73484727,0x76440014}},	//   _سعی_, _жүзі, рчев_, _ویرِ_, 
   {{0xfc3c0316,0xea00004d,0x66d0248c,0xf77c0327}},	//   dním_, _miếu_, täke, ħħdu_, 
   {{0x7f400789,0x00000000,0x00000000,0x00000000}},	//   _apoq, --, --, --, 
   {{0x8fd00cef,0x69c000ee,0xa424010b,0x4f0800db}},	//   нәлә, şmeg, _оьул, бнин_, 
   {{0x66d03f64,0xe2f852c4,0x00000000,0x00000000}},	//   säke, _меті_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6abda306,0x7f4006af,0x040c03d4,0x918801e0}},	//   vorf, _epoq, _হাতী_, _ураҡ_, 
   {{0xfc3c012c,0x6abda307,0x2735a308,0x6ab407b7}},	//   bním_, worf, yän_, ंक्र, 
   {{0x6abda309,0xfc3c0118,0x09e4005b,0x3ce401ec}},	//   torf, cním_, зогн, _ﺍﻟﺜﻤ, 
   {{0x2735a30a,0xddc8005f,0xe8e0004d,0x25500240}},	//   vän_, ņoša, _đực_, _ዘጋጥሞ, 
   {{0xa03401d9,0x6abda30b,0x2734007f,0x06840022}},	//   _رى۪ت, rorf, wän_, ҿган, 
   {{0x2735a30c,0x6d4002d0,0x00000000,0x00000000}},	//   tän_, _ipna, --, --, 
   {{0x6abc0261,0xf7400f4d,0x068401b9,0x00000000}},	// [2ce60] porf, нето, пган, --, 
   {{0x6d400175,0xabe401ec,0x45d400d8,0x00000000}},	//   _kpna, _ﺍﯞﻗﺎ, пцет, --, 
   {{0x2735a30d,0xfc3c0118,0x0444008e,0x00000000}},	//   sän_, zním_, зеен, --, 
   {{0x6d400109,0xd49802bf,0x2734005b,0x69c003e0}},	//   _mpna, орі_, pän_, ğmed, 
   {{0x4a28025c,0x833802f6,0x69c03712,0x26b400d1}},	//   _སྐོལ_, счет_, şmed, _قەرز, 
   {{0xfc3c0316,0x67240135,0xbb38008f,0x78b80e3c}},	//   vním_, mrij, מעני, čuve, 
   {{0x67240196,0x55c40220,0x00000000,0x00000000}},	//   lrij, _жарғ, --, --, 
   {{0xfc3c012c,0xa30401ec,0xfafc0200,0x00000000}},	//   tním_, _жүде, ypë_, --, 
   {{0x6d40094a,0x6725a30e,0x838806ed,0x3ce402dd}},	//   _apna, nrij, _убав_, _ﺍﻟﺘﻤ, 
   {{0x46bc0316,0xfc3c012c,0xa5500092,0xb5b801e1}},	//   ्तिह, rním_, _ባልንጀ, _ìṣok, 
   {{0x67240460,0xaf300f00,0xd2940014,0xfc3c00bc}},	//   hrij, وریت, _تُلک, sním_, 
   {{0xfc3c02fb,0x00000000,0x00000000,0x00000000}},	//   mník_, --, --, --, 
   {{0xfc3c0232,0x9e341064,0x46bcd3c3,0x672401f5}},	//   lník_, _желч, ्ताह, jrij, 
   {{0x67240460,0x37a80184,0xfafc0200,0x00000000}},	//   drij, ҡтан_, rpë_, --, 
   {{0xfc3c01f1,0xc7f8063f,0x672400c5,0xfbd043bb}},	//   nník_, _ọsụs, erij, بتھ_, 
   {{0x6725a30f,0x3ebc00dd,0xea0001fb,0xdd9401ee}},	//   frij, lott_, _tiếu_, _наһы, 
   {{0x6725a310,0x3ebc003e,0x6d400010,0x5678005b}},	// [2ce70] grij, oott_, _zpna, обая_, 
   {{0xcb100d65,0x3ebda311,0x6440002f,0x00000000}},	//   _שלי_, nott_, _abmi, --, 
   {{0x67240014,0xfc3c02fb,0xdb0c0055,0x63a413db}},	//   arij, jník_, _iyañ, úinn, 
   {{0x6725a312,0xfc3c674e,0x3ebda313,0x7c2c127b}},	//   brij, dník_, hott_, ngcr, 
   {{0x3ebda314,0x5fb8012d,0x00000000,0x00000000}},	//   kott_, _उँगल, --, --, 
   {{0x3ebda315,0x00000000,0x00000000,0x00000000}},	//   jott_, --, --, --, 
   {{0x3ebda316,0x00000000,0x00000000,0x00000000}},	//   dott_, --, --, --, 
   {{0x661c0010,0x6f0001e1,0x66d001f4,0x00000000}},	//   _zdrk, _níbò, mäka, --, 
   {{0xe2c8021a,0x66d033da,0x00000000,0x00000000}},	//   _کولو_, läka, --, --, 
   {{0x63540323,0xfc3c0122,0x3ebda317,0x78bc014f}},	//   _явуу, bník_, gott_, hoqv, 
   {{0x67241711,0x6f000ca8,0xfc3c02fb,0x66d00108}},	//   zrij, _bíbò, cník_, näka, 
   {{0xdb0c094a,0xc1b800d9,0x00000000,0x00000000}},	//   _ayañ, _ומעש, --, --, 
   {{0x4a28038f,0x3ebda318,0xdb0c0055,0xb9f801ad}},	//   _སྐུལ_, bott_, _byañ, ्रूफ_, 
   {{0x6725845f,0x3ebda319,0x3fd8011a,0x66d001f4}},	//   vrij, cott_, _וקנב, käka, 
   {{0x6d40005a,0x66d00108,0x6725a31a,0x00000000}},	//   _upna, jäka, wrij, --, 
   {{0x38c801d5,0xae000131,0x00000000,0x00000000}},	//   قاقی_, _تۈگى, --, --, 
   {{0x2ca1a31b,0xfc3c0232,0x67240037,0x00000000}},	// [2ce80] _imid_, zník_, urij, --, 
   {{0x6725a31c,0x644000f2,0x24480208,0x00000000}},	//   rrij, _sbmi, _ẻm_, --, 
   {{0x6725a31d,0x200401ab,0xc5ecb825,0x45340022}},	//   srij, ybmi_, _जलीय_, ьхат, 
   {{0x3ebc066d,0xfc3c03c6,0xe1f8e1dd,0x229001e1}},	//   zott_, vník_, ुर्ण_, _màke_, 
   {{0x6724031c,0x27f80210,0x00000000,0x00000000}},	//   qrij, ągną_, --, --, 
   {{0xfc3c0122,0x44300034,0x2ca00175,0x3ebc0327}},	//   tník_, ży_, _lmid_, xott_, 
   {{0x6f0803ac,0x3ebc01d3,0x29184cab,0x453400d1}},	//   _awgc, vott_, nsra_, _تىزر, 
   {{0x9f55227e,0x21201068,0x30a043a7,0xfc3c0122}},	//   евич, čih_, крыв, rník_, 
   {{0x3ebc066d,0xfc3c0216,0x656801e7,0xb3900092}},	//   tott_, sník_, _ádhb, ጃቸውን_, 
   {{0x6f080007,0xfc3c02fb,0x2ca00f85,0x00000000}},	//   _dwgc, pník_, _amid_, --, 
   {{0x3ebda31e,0x02c80a59,0x00000000,0x00000000}},	//   rott_, ितीन, --, --, 
   {{0xc0a89717,0x3ebd8ed8,0xdbf8134e,0x00000000}},	//   _باطل_, sott_, ंडेड_, --, 
   {{0x3ebc00dd,0x7ac4e9cb,0xf3fc054e,0x00000000}},	//   pott_, дсве, âţia_, --, 
   {{0x60c1a31f,0x66d00054,0x2ca15db3,0xcf2401f7}},	//   lomm, yäka, _emid_, _سرهي, 
   {{0xdb0c00dc,0xa9340150,0x00000000,0x00000000}},	//   _vyañ, керш, --, --, 
   {{0x60c1a320,0x81c8015b,0x3154008f,0x66d0005b}},	//   nomm, োশপ_, וילן_, väka, 
   {{0x60c00770,0x57b5a321,0x291801e7,0x00000000}},	// [2ce90] iomm, хбат, asra_, --, 
   {{0x60c1a322,0xfc3da323,0x66d04a84,0x00000000}},	//   homm, lfí_, täka, --, 
   {{0x60c155a3,0xf8e000c7,0x00000000,0x00000000}},	//   komm, _аӡаҿ, --, --, 
   {{0x9474034c,0x66d1a324,0x60c09f88,0x52b800dc}},	//   رگزا, räka, jomm, ेत्स, 
   {{0x66d80521,0x66d0023a,0xfc3c00ae,0x00000000}},	//   ụkar, säka, ifí_, --, 
   {{0x66d1a325,0x51f41046,0xfc3c00ae,0x00000000}},	//   päka, رستر, hfí_, --, 
   {{0xe5c5a326,0x60c0013f,0x46bc0da5,0x3f8006ea}},	//   _асто, fomm, ्तरह, økun_, 
   {{0x2ee4036b,0x00000000,0x00000000,0x00000000}},	//   _sinf_, --, --, --, 
   {{0xc0b80023,0xfc3c01e7,0x00000000,0x00000000}},	//   _ዲኹም_, dfí_, --, --, 
   {{0x2ca1a327,0xa3b800c5,0x7e688f78,0x291803b2}},	//   _smid_, _घुट_, _cnfp, ysra_, 
   {{0x60c1a328,0xe13400c7,0x2ca005d0,0xfc3c032e}},	//   bomm, _анхы, _pmid_, ffí_, 
   {{0x38680589,0xfc3c01e7,0x00000000,0x00000000}},	//   _nncr_, gfí_, --, --, 
   {{0x70c80073,0x5f0400d4,0x12d000eb,0x00000000}},	//   ातील, _азіа, াদীদ, --, 
   {{0xfc3c0418,0x3f78008f,0x69c8033f,0x00000000}},	//   afí_, _מאנס, żdem, --, 
   {{0x290c067c,0x00000000,0x00000000,0x00000000}},	//   èda_, --, --, --, 
   {{0x2ca1a329,0xfc3c01e7,0xa8bc06be,0xa9c00d2e}},	//   _umid_, cfí_, _örüş_, _एडीए, 
   {{0x27b401e0,0xb7b0009d,0x29180135,0x00000000}},	// [2cea0] тәнс, гөрч, ssra_, --, 
   {{0x78b80bb8,0x86c5a32a,0xb7d5a32b,0x60c0d8b7}},	//   čuva, ريان, رولا_, zomm, 
   {{0xf48407d6,0x3a34010f,0xf6200818,0x66d0008e}},	//   کالی, _ארים_, удхо, bäkn, 
   {{0xe8540345,0x00000000,0x00000000,0x00000000}},	//   _جۆرد, --, --, --, 
   {{0x62340276,0x60c1a32c,0xe51c000d,0x82a4011c}},	//   велу, vomm, _पटकि_, надж, 
   {{0xa114215c,0xc97c001f,0x60c0324c,0x66d00108}},	//   نوتت, ከፋፈል_, womm, mäko, 
   {{0x60c0e425,0x66d00958,0x00000000,0x00000000}},	//   tomm, läko, --, --, 
   {{0x74101d0a,0x00000000,0x00000000,0x00000000}},	//   _موفا, --, --, --, 
   {{0x60c1a32d,0x26d8014b,0x5f95a32e,0x2d80037e}},	//   romm, _khro_, типт, øjen_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe3d8037e,0x60c1a32f,0x3214004b,0x66d001f4}},	//   _h話_, pomm, _سيند_, häko, 
   {{0x66d00108,0x00000000,0x00000000,0x00000000}},	//   käko, --, --, --, 
   {{0x9f3400d6,0x66d00108,0xfc3c56fa,0x2b440304}},	//   _релі, jäko, knív_, лэрг, 
   {{0x7e680bc9,0xafe0e360,0x26d80142,0xfc3c0332}},	//   _unfp, _сочл, _nhro_, sfí_, 
   {{0x3ce809fd,0xdd9459fb,0x91f40051,0xa5a0000d}},	//   _घंटे_, _шакы, _hác, _गेलौ, 
   {{0x26d80098,0x00000000,0x00000000,0x00000000}},	//   _ahro_, --, --, --, 
   {{0x66d0049f,0x6e440158,0x7d1800e2,0x00000000}},	// [2ceb0] räkn, _årbø, lsts, --, 
   {{0x26d845c0,0xd37004fb,0xad2000d1,0xe658009d}},	//   _chro_, یها_, _شىۋى, ниуч_, 
   {{0x66d03407,0x7cfc0882,0x19942081,0xe8940092}},	//   mäkl, _dīrg, _раня, _መፈጸም_, 
   {{0xf31421bf,0xe4e44dba,0x66d0013d,0x7d192f20}},	//   ендә_, гічн, läkl, ists, 
   {{0x69d801f1,0xd9f401f9,0x00000000,0x00000000}},	//   _úver, _आलात_, --, --, 
   {{0x7d181455,0x00000000,0x00000000,0x00000000}},	//   ksts, --, --, --, 
   {{0x7d1801f5,0xa2940092,0x00000000,0x00000000}},	//   jsts, ፍሪካን_, --, --, 
   {{0x7d18045f,0x656801e7,0x91f40051,0x6748032e}},	//   dsts, _ádha, _bác, _ísjá, 
   {{0x1ea8021a,0x91f401fb,0x0eb800ee,0xe66c001f}},	//   کايي_, _các, дуны_, _ለማጥፋ, 
   {{0x4d6417d0,0xe3b0a2f2,0x81e40154,0x69c80205}},	//   вков, _ارف_, পড়_, üdek, 
   {{0xc5f00bd4,0x7d1800da,0xfe6c01d5,0x66d00166}},	//   ידי_, gsts, غگه_, däkl, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb03000c7,0xaf340451,0x7d1803ac,0x00000000}},	//   _амҵә, _سرشت, asts, --, 
   {{0x7d1801ee,0xc330008f,0x66d002f6,0x6f180e78}},	//   bsts, בוך_, väko, msuc, 
   {{0x6f1817da,0x78b8107d,0x88c400f2,0x37dc00cc}},	//   lsuc, čuvn, نترل, _ফ্লৰ, 
   {{0x7cfc0055,0x66d00108,0xf77c031c,0x00000000}},	//   _dīrd, täko, ħħnu_, --, 
   {{0x6f180730,0x66d00598,0x46e9a330,0x8a0402e8}},	// [2cec0] nsuc, bäkl, ддан_, _изпе, 
   {{0x66d1a331,0x00000000,0x00000000,0x00000000}},	//   räko, --, --, --, 
   {{0x6f180730,0x98ac03ee,0x2d1c00ab,0x66d0005b}},	//   hsuc, _çoğu_, _मटोल_, säko, 
   {{0x6f18b915,0x66d001f4,0x00000000,0x00000000}},	//   ksuc, päko, --, --, 
   {{0x26d80042,0x00000000,0x00000000,0x00000000}},	//   _thro_, --, --, --, 
   {{0x7cfc02b1,0x3f80022c,0x13a82f30,0x91f40051}},	//   _hīre, økum_, عنوی_, _rác, 
   {{0x7cfc02b1,0x91f4004d,0xb6a0f9cb,0x75e00139}},	//   _kīre, _sác, _тирл, gеzd, 
   {{0x6f180e78,0x3f64b68c,0xc3e000fb,0x00000000}},	//   fsuc, втоб, _көлһ, --, 
   {{0x7e2800d3,0x6f18002f,0x00000000,0x00000000}},	//   міна_, gsuc, --, --, 
   {{0x7d19a332,0x741000e5,0x00000000,0x00000000}},	//   tsts, _موہا, --, --, 
   {{0xf2940375,0x2dd00022,0x00000000,0x00000000}},	//   _שכבר_, ижьр, --, --, 
   {{0x6f18245f,0x7d19a333,0x705000db,0x91f40051}},	//   bsuc, rsts, _ۅنۅا, _tác, 
   {{0x7d1915e5,0xef14035b,0x66d000fd,0xe8e00208}},	//   ssts, _амч_, täkl, _nhựt_, 
   {{0x1958748c,0x64bc01ab,0x69c003e0,0x00000000}},	//   нагы_, lčid, ğmen, --, 
   {{0x66d00724,0x69c13602,0x6e4000cf,0x00000000}},	//   räkl, şmen, _ئنىم, --, 
   {{0xdce80153,0x779000f2,0xfc3c0332,0x00000000}},	//   vydė, لیجا, gnít_, --, 
   {{0xd7d40640,0x38b4025c,0xd7c91147,0x66f4004e}},	// [2ced0] ужањ, għra_, روطه_, ипту, 
   {{0x79a412f6,0xad2c001f,0xe730007b,0x2bd80073}},	//   _арме, _ተሰጥቶ, تصف_, _ठरता, 
   {{0xb698019f,0xc73c001f,0x7cfc00ef,0x00000000}},	//   _bwâr, _አያውቅ, _fīre, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x31cc1870,0x934400ee,0x67e80354,0x47d400ec}},	//   ﺗﺘﯩﻜ, унле, _аьрг_, _ميٽر, 
   {{0x6f18002f,0x12d00154,0x00000000,0x00000000}},	//   vsuc, াদ্দ, --, --, 
   {{0x10a41607,0xed800020,0xc690008f,0x24f80166}},	//   ликн, ሬክተር_, _פאל_, _ансы_, 
   {{0x6f19a334,0xb4b004a9,0x141800ae,0x00000000}},	//   tsuc, _тибә, _سيئة_, --, 
   {{0xd01000db,0xfc3c02d2,0x00000000,0x00000000}},	//   _ۇلا_, hnís_, --, --, 
   {{0x6f1809f0,0xf1a5a335,0xb1a40daf,0x8fd00131}},	//   rsuc, _ирен, _ишек, _қәйә, 
   {{0x2284036b,0xd010e3c1,0x4ce4004e,0x00000000}},	//   _тутг, _هلا_, лжоб, --, 
   {{0xac84013e,0x00000000,0x00000000,0x00000000}},	//   рҳил, --, --, --, 
   {{0xd01923a5,0xf1a4033d,0x9f3402bf,0xe0e401d5}},	//   mań_, _केतन, _вечі, _тўфо, 
   {{0x940c013f,0xc330010f,0x63a40332,0xf77c0135}},	//   _mmeɑ_, זוך_, úini, ħħlu_, 
   {{0x7cfc02b5,0x3e3000cf,0x98f454f2,0xb87801e7}},	//   _pīre, _افىر, иятч, _mhíf, 
   {{0xd01923a5,0x88e41614,0x589400f7,0x3b800092}},	//   nań_, ужбе, ашуу, ከያዎች_, 
   {{0x7cfc07d7,0x0ab4007b,0x00000000,0x00000000}},	// [2cee0] _gīrb, _محدد, --, --, 
   {{0x7cfc02b5,0xd019372f,0x66d1a336,0x00000000}},	//   _wīre, hań_, mäkk, --, 
   {{0x7cfc04fe,0x66d0088b,0xd0180034,0x291c00e4}},	//   _tīre, läkk, kań_, _ìva_, 
   {{0xd0180165,0x00000000,0x00000000,0x00000000}},	//   jań_, --, --, --, 
   {{0xd0180034,0xe2149095,0x240800ee,0x133801d3}},	//   dań_, амлы, енҗи_, نتوں_, 
   {{0xc69000dd,0xb87801e7,0x06740024,0x91dc00b8}},	//   _اِس_, _chíf, _сумя, _saśṛ, 
   {{0xb87801e7,0x66d0005b,0xa194761e,0xc76801a9}},	//   _dhíf, häkk, райч, _ўиҳж_, 
   {{0x65000521,0xd019a337,0xf99002e4,0x00000000}},	//   _ịkwụ, gań_, מרו_, --, 
   {{0xbf640133,0xc328007b,0x00000000,0x00000000}},	//   ادبو, _سكان_, --, --, 
   {{0x64a421f7,0x7520002d,0x66d001f4,0x00000000}},	//   _саға, ânzg, däkk, --, 
   {{0xd0184baa,0x64bc009b,0x00000000,0x00000000}},	//   bań_, pčid, --, --, 
   {{0x69c00790,0x518401af,0x00000000,0x00000000}},	//   ğmel, _туђа, --, --, 
   {{0x69c01295,0xed5403e6,0x7e780334,0x00000000}},	//   şmel, نشێت_, pjtp, --, 
   {{0xdb0c0248,0x00000000,0x00000000,0x00000000}},	//   _èkín, --, --, --, 
   {{0xed541f5a,0x6a400248,0x00000000,0x00000000}},	//   _бој_, _ẹnìk, --, --, 
   {{0xfe7405f5,0xfc3c180f,0x395c00df,0xf1a4000d}},	//   _рүү_, rnís_, ĉus_, _कइसन, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [2cef0] --, --, --, --, 
   {{0xd019a338,0x00000000,0x00000000,0x00000000}},	//   zań_, --, --, --, 
   {{0xf4845211,0x91f40208,0x58d400d8,0x00000000}},	//   лудн, _bán, _вонт, --, 
   {{0x91f40208,0xe508027d,0x00000000,0x00000000}},	//   _cán, اينو_, --, --, 
   {{0xbbd0060c,0xd01805c7,0x91f40208,0xed6000d7}},	//   _सरोक, vań_, _dán, _koží_, 
   {{0xe8e00016,0xd0180034,0x56941f10,0x910400db}},	//   _đức_, wań_, _тагт, апке, 
   {{0xd17519a4,0xd0180034,0x9990033f,0x00000000}},	//   рылы, tań_, lazł_, --, 
   {{0xb87800ae,0x94e800f2,0xfc3c01ef,0x4f24003b}},	//   _dhíg, _شکاف_, fiím_, адиб, 
   {{0xd019a337,0xa344009d,0xfc3c013a,0x00000000}},	//   rań_, _гэхл, giím_, --, 
   {{0x6299a339,0x66d1a33a,0x2074023b,0xd018641a}},	//   chvo, väkk, _ҳушё, sań_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb8780077,0x64bc3bde,0x66d00f23,0x30e401ec}},	//   _xiít, mčic, täkk, _сізб, 
   {{0x94f40489,0xed60219b,0xb87801e7,0x7bc80162}},	//   _བཤའི_, _boží_, _mhíd, _øgul, 
   {{0x66d06c31,0xb699a33b,0x69c005d1,0x3b04013e}},	//   räkk, _stân, şmem, реро_, 
   {{0x2fcc76ad,0x66d0023a,0x2bd80073,0x00000000}},	//   _hygg_, säkk, _ठरवा, --, 
   {{0x66d18b2e,0x48044b53,0x0c2414b3,0x00000000}},	//   mäki, рпав, _тмин, --, 
   {{0xfce80201,0x66d002f6,0x00000000,0x00000000}},	// [2cf00] _መረጃ_, läki, --, --, 
   {{0x7cfc1da6,0x22900109,0x2fcc11ad,0x91f4004d}},	//   _hīra, _ràko_, _mygg_, _sán, 
   {{0x64bc22c1,0x66d1a33c,0xddd80010,0xb8797515}},	//   jčic, näki, _kovš, _bhíd, 
   {{0x0444049d,0xdc74001f,0x7cfc00b8,0x65680332}},	//   редн, _እየታየ_, _jīra, _ádhm, 
   {{0x68e5a33d,0xb8791994,0x3aec031c,0x629805d5}},	//   mmid, _shíg, _mżpn_, thvo, 
   {{0x68e5a33e,0xddd80427,0x46140133,0x76040408}},	//   lmid, _lovš, _خوسر, _верг_, 
   {{0xbbd08a4f,0xddc80034,0x2bb801f2,0x68e4103a}},	//   _सर्क, zedł, ọch_, omid, 
   {{0x2fcc77d4,0x68e5a33f,0xddd80030,0x22400118}},	//   _bygg_, nmid, _novš, řik_, 
   {{0xb87801ed,0x3080007b,0x68e5a340,0x00000000}},	//   _kiír, تليف, imid, --, 
   {{0x68e5a341,0xff0800b5,0x24840165,0x2fcc03b2}},	//   hmid, _comは, _homm_, _dygg_, 
   {{0x2485a342,0xaee00882,0x60c409a8,0xddd80427}},	//   _komm_, _siṃh, čimb, _bovš, 
   {{0x2484002e,0x68e5a343,0x7cfc6991,0x6f1401d9}},	//   _jomm_, jmid, _cīra, _چٲنس_, 
   {{0x24840381,0x68e4017a,0xb0980677,0x00000000}},	//   _momm_, dmid, _ביאר, --, 
   {{0x68e400af,0x24840165,0x66d00139,0x00000000}},	//   emid, _lomm_, bäki, --, 
   {{0xddd80427,0x298885bc,0x2aac01e1,0x64b80073}},	//   _fovš, асто_, _sóbè_, ेकाळ, 
   {{0x68e4bdd0,0x57f43129,0x2e640116,0x24840036}},	//   gmid, спат, _биәп_, _nomm_, 
   {{0x569401c0,0x00000000,0x00000000,0x00000000}},	// [2cf10] баат, --, --, --, 
   {{0x68e5a344,0xddd80419,0x00000000,0x00000000}},	//   amid, _zovš, --, --, 
   {{0x2485a345,0x68e4022e,0x040c0154,0x00000000}},	//   _bomm_, bmid, _হাজী_, --, 
   {{0x54b8040e,0x00000000,0x00000000,0x00000000}},	//   ыгея_, --, --, --, 
   {{0xe3b1a346,0x24840a40,0x0874008f,0x00000000}},	//   وره_, _domm_, _הערט_, --, 
   {{0x2fcc3bb7,0x64bc02f0,0x66d00108,0x00000000}},	//   _rygg_, tčic, yäki, --, 
   {{0x248592c8,0xd1c80c9e,0x00000000,0x00000000}},	//   _fomm_, ылке_, --, --, 
   {{0x64bda347,0x5694016c,0x66d0023a,0xb81403ce}},	//   rčic, _таҳт, väki, तरिम_, 
   {{0x63a400c6,0xd1740032,0x7cfc02b5,0xddd80427}},	//   úint, рыһы, _rīra, _rovš, 
   {{0x66d002f6,0x248491ad,0x64bda348,0x8e09a349}},	//   täki, _zomm_, pčic, ынов_, 
   {{0x7cfc04fe,0xddd82a92,0x64bc0024,0xccc40137}},	//   _pīra, _povš, lčia, йбой, 
   {{0x69c03712,0xb6982326,0xa1f007d2,0x2484002e}},	//   şmek, _stâl, _تۋىت, _xomm_, 
   {{0x64bda11f,0x7cfc0aed,0x66d0023a,0x5f7401f7}},	//   nčia, _vīra, säki, _واهر, 
   {{0x64bc02d5,0x7cfc00b0,0x37bc00fe,0x00000000}},	//   ičia, _wīra, ্ধাৰ, --, 
   {{0x7cfda34a,0xfaa1a34b,0xc894a4e3,0xddd80219}},	//   _tīra, чаро, брањ, _tovš, 
   {{0x64bc0006,0x68e5a34c,0xc7a40166,0x8b94009b}},	//   kčia, umid, бибк, _гроч, 
   {{0x64bc01f1,0xcb680276,0x464801c6,0x37e0665a}},	// [2cf20] jčia, _сапе_, лзан_, зотг, 
   {{0x68e5a34d,0xe7f40d2c,0x64bc00d0,0x69c80254}},	//   smid, _अलका_, dčia, üdes, 
   {{0x64bc02d5,0x452819c3,0xb87800ae,0x24840037}},	//   ečia, ужен_, _dhíb, _pomm_, 
   {{0x68e47708,0xd408007b,0x68940345,0x00000000}},	//   qmid, لتهم_, _بیرئ, --, 
   {{0x818401c6,0x64bc00c0,0x00000000,0x00000000}},	//   өгдж, gčia, --, --, 
   {{0x6d140034,0x36d001a9,0x00000000,0x00000000}},	//   _दबंग_, _ноўр, --, --, 
   {{0x24840489,0x00000000,0x00000000,0x00000000}},	//   _tomm_, --, --, --, 
   {{0x8319a34e,0x63a4007b,0x15b000d1,0xb978011a}},	//   _مقرر_, úins, _تەمس, טנצי, 
   {{0xdfd006d5,0x229000e8,0x4ccc015b,0x93580063}},	//   بية_, _jàkk_, রগাঁ, _врху_, 
   {{0x44fc02b5,0xb878001e,0x229000e8,0xf7700375}},	//   _kï_, _khíc, _màkk_, פקת_, 
   {{0x22901574,0x9cf40153,0x00000000,0x00000000}},	//   _làkk_, юзні, --, --, 
   {{0xb87800c6,0xe7f4007d,0x50640014,0x00e401f4}},	//   _mhíc, _अलगा_, _وانِ, _ужен, 
   {{0x44fc2776,0x22900de2,0x66d001f4,0x72a002f2}},	//   _lï_, _nàkk_, läku, _بڕۆن, 
   {{0xdd95a34f,0x7f40401f,0x44fc0124,0x00000000}},	//   _малы, _iqoq, _oï_, --, 
   {{0x44fc145e,0x66d0049b,0x3689a350,0xb878004d}},	//   _nï_, näku, қсан_, _nhíc, 
   {{0x7cfc0374,0x2290002e,0x64bc0006,0x0a500023}},	//   _hīro, _bàkk_, yčia, _ምዝርራ, 
   {{0x44fc067c,0x69c80e78,0xfca80451,0xb87801e7}},	// [2cf30] _aï_, üder, _لاکو_, _phíb, 
   {{0x44fc145e,0x229000e8,0x66d002d1,0x3f400d12}},	//   _bï_, _dàkk_, käku, iðu_, 
   {{0x356865a7,0xb879a351,0xe5080592,0x66d001f4}},	//   ыран_, _chíc, ميلو_, jäku, 
   {{0xf4b4045e,0x7f41a352,0x44fc0af9,0xb878007b}},	//   জত্ব, _oqoq, _dï_, _dhíc, 
   {{0x44fc0c67,0x22900de2,0x0838008f,0x64bc0024}},	//   _eï_, _gàkk_, _דערל, učia, 
   {{0x64bda353,0xe79c05d1,0x161c033f,0x7cfc00b8}},	//   rčia, lüğü, _फ़िर_, _nīro, 
   {{0x44fc24ba,0x7f4001f0,0x64bd4874,0xe3b00372}},	//   _gï_, _aqoq, sčia, ورۇ_, 
   {{0x3f40008c,0x8fd15aae,0x95c9a354,0x64bda355}},	//   fðu_, мәлә, _буға_, lčin, 
   {{0x44fc025a,0x3f400008,0x8e540111,0x7cfc00ef}},	//   _zï_, gðu_, отні, _bīro, 
   {{0xb8d80135,0x0ea81064,0x64bda356,0x55400150}},	//   _ཆམ_, ркой_, nčin, _ءﯨﺲﻭ, 
   {{0x7f40379d,0x2264012c,0x66d1557b,0xcc89a357}},	//   _eqoq, řská_, mäkt, لنده_, 
   {{0x66d1a358,0x76545e23,0xfafc0240,0x00000000}},	//   läkt, hexy, rvën_, --, 
   {{0xe79c05d1,0x8b8400db,0x00000000,0x00000000}},	//   düğü, زەدە_, --, --, 
   {{0x64bc07f5,0xaea00150,0x00000000,0x00000000}},	//   jčin, _رەجي, --, --, 
   {{0x9e65a359,0x22900694,0x8c4401e0,0x26082d8f}},	//   _راون, _sàkk_, _дейе, ाँसी_, 
   {{0x229000e8,0x64bc00d0,0x66d001e3,0x00000000}},	//   _pàkk_, ečin, häkt, --, 
   {{0x44fc24ba,0x64bc009b,0xd1f4001f,0xc05000d9}},	// [2cf40] _sï_, fčin, ገመት_, וזן_, 
   {{0xb878004d,0x7d14012d,0x45d401af,0x00000000}},	//   _phíc, _łysi, оцет, --, 
   {{0xe0d02b1b,0x00000000,0x00000000,0x00000000}},	//   াগতভ, --, --, --, 
   {{0x3f4006ea,0x22901bce,0x66d0023a,0x00000000}},	//   yðu_, _tàkk_, väku, --, 
   {{0x0a50044e,0x44fc0004,0x64bc25d8,0x02c454a7}},	//   _ምምስራ, _wï_, bčin, ойдо, 
   {{0xb87801dc,0x44fc145e,0x6725a35a,0x7f4001a9}},	//   _thíc, _tï_, msij, _rqoq, 
   {{0x6725a35b,0x7cfc02b5,0x69d800b5,0x00000000}},	//   lsij, _rīro, _øved, --, 
   {{0x661da35c,0x42d804c5,0x66d1a35d,0x67240254}},	//   _herk, দদেশ, räku, osij, 
   {{0x6724b24b,0x661da35e,0x66d00877,0x6d400455}},	//   nsij, _kerk, säku, _aqna, 
   {{0x661c1368,0x3f401c38,0x6725a35f,0x66d1a360}},	//   _jerk, rðu_, isij, päku, 
   {{0x64bc0953,0x62880472,0x67240066,0x66d1a361}},	//   nčio, _iodo, hsij, qäku, 
   {{0x661c6672,0x7cfc02b5,0x64bc0064,0x00000000}},	//   _lerk, _wīro, ičio, --, 
   {{0x6289a362,0x661cd7bd,0x67240552,0x7f40487e}},	//   _kodo, _oerk, jsij, _uqoq, 
   {{0x6288122d,0x672401fa,0x661da363,0x66d001f4}},	//   _jodo, dsij, _nerk, iäks, 
   {{0x2d80019b,0xdd9400ee,0x64bca01b,0x3ba40092}},	//   øjet_, _хайы, včin, ወካዮች_, 
   {{0x6289a364,0x661c0115,0x20041bce,0x67240327}},	//   _lodo, _aerk, ncmi_, fsij, 
   {{0x661da365,0x64bd3437,0x66d0023a,0x62886c98}},	// [2cf50] _berk, tčin, jäks, _oodo, 
   {{0x62880029,0x7bdda366,0x661da367,0xf6500f1b}},	//   _nodo, _izqu, _cerk, بئر_, 
   {{0x661da368,0x54540108,0x76540332,0x66d001e3}},	//   _derk, звет, rexy, väkt, 
   {{0x62880dd4,0x6440010a,0x1834008f,0x9378010b}},	//   _aodo, _ccmi, _צאָל_, йбет_, 
   {{0x661c0385,0x64bda369,0x66d001e6,0x6440003a}},	//   _ferk, mčil, täkt, _dcmi, 
   {{0x6440009a,0x661da36a,0x491000bc,0x64bc0064}},	//   _ecmi, _gerk, धीको_, bčio, 
   {{0x6289a36b,0x66d13c88,0xfbc0009e,0x644001bf}},	//   _dodo, räkt, োধিত, _fcmi, 
   {{0x64bc4ea1,0x62880086,0x66d033f7,0x98bc012c}},	//   nčil, _eodo, säkt, ्किए, 
   {{0x661da36c,0x6289a36d,0x15f43d1d,0xb5a00150}},	//   _yerk, _fodo, ेडकर_, _ﺃﻁﻠﻘ_, 
   {{0x661c005a,0x64bc02f0,0xdea416d0,0x8fd001e0}},	//   _xerk, hčil, وینی, мәһә, 
   {{0xe2c9a36e,0x3f80022c,0xf8bc01e1,0x98bc00bc}},	//   _بولو_, økur_, _ojé_, ्काए, 
   {{0x6289a36f,0xa13401d5,0x64bc02f0,0xf8bc0241}},	//   _zodo, _آرلش, jčil, _njé_, 
   {{0x769005d1,0x64bc6075,0x6289a370,0x8f080137}},	//   _kıyı, dčil, _yodo, _ايتق_, 
   {{0xf8bc0ca8,0x2d80037e,0x64bc0006,0x76900139}},	//   _ajé_, øjes_, yčio, _jıyı, 
   {{0xe7f81dd1,0x2d400113,0x661c0009,0x76900e2d}},	//   ंखला_, qñe_, _rerk, _mıyı, 
   {{0x6725a371,0x661da372,0xfc28012c,0x66d0005b}},	//   tsij, _serk, íští_, yäks, 
   {{0x661da373,0xdd2c0023,0x07a4009d,0x00000000}},	// [2cf60] _perk, _ተተሓሒ, чаан, --, 
   {{0x67244193,0x66d0049b,0x85780395,0x00000000}},	//   rsij, väks, йсет_, --, 
   {{0x6725a374,0x6289a375,0xb87800e4,0x4535a376}},	//   ssij, _rodo, _ihín, яхат, 
   {{0x661d593e,0x66d0adae,0xd1f4001f,0xc4840024}},	//   _werk, täks, ገኘት_, ялек, 
   {{0x661da377,0x6724003d,0x7691a378,0x64bc0153}},	//   _terk, qsij, _bıyı, sčio, 
   {{0x62880050,0x76900598,0x64bc8b04,0x66d1a379}},	//   _qodo, _cıyı, mčim, räks, 
   {{0x6f08074d,0x66d0049b,0xb87800c6,0x00000000}},	//   _atgc, säks, _mhín, --, 
   {{0x62880034,0xc05838a9,0x63e401ec,0xd17400c7}},	//   _wodo, сік_, _قۋال, ьычы, 
   {{0x62881a36,0x29dc0dc9,0x14c816d1,0xf48401d3}},	//   _todo, _ḽa_, िकरण, _عافی, 
   {{0xb698019f,0x7d0802d0,0x76900205,0x5270022e}},	//   _bwây, _ptfs, _gıyı, _ақшф, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb87800c7,0x00e400cf,0x7f8400db,0xd3a40408}},	//   _ahín, _эжен, _ىلان, _ирĕп, 
   {{0x2d8004ce,0xb87801e7,0x64bc0010,0x76900166}},	//   øjer_, _bhín, včil, _yıyı, 
   {{0xb87801dc,0x2ec42314,0x9d180276,0x64bc0010}},	//   _chín, रकृत, _докт_, dčim, 
   {{0xa9c402d5,0xf9900472,0x58d5a37a,0xb87801e7}},	//   естк, ربس_, довт, _dhín, 
   {{0x29dc06d6,0x64bc1668,0xb878035b,0x20cc00dc}},	//   _ḓa_, učil, _ehín, ाविध, 
   {{0xdd901176,0xb87800ae,0x3ba40092,0x00000000}},	// [2cf70] _سوک_, _fhín, ለጫዎች_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x64bc0219,0x7afc0477,0x19580022,0xb5a401a9}},	//   mčij, _huqt, _ьаны_, чрай, 
   {{0xfc3da37b,0x7690ce56,0x7afda37c,0x64bc0010}},	//   ngí_, _sıyı, _kuqt, lčij, 
   {{0xfc3c00ae,0x291c032e,0x8cb4bac8,0x69c00205}},	//   igí_, _ævar_, _उदघो, şmet, 
   {{0x66d0049f,0x7af4003d,0x7afd674e,0x64bc00c0}},	//   säkr, _jixt, _muqt, nčij, 
   {{0x7afc0bc9,0x7af5a37d,0xdee802d3,0x00000000}},	//   _luqt, _mixt, _ዘለካ_, --, 
   {{0x794c02d3,0xb878007b,0x1dd009bb,0x4f09a37e}},	//   _ሕግታት, _mhío, _हड़त, онин_, 
   {{0xa3d5a37f,0x64bcc75b,0x7afc100f,0xe45400fd}},	//   _सुप_, kčij, _nuqt, _якты, 
   {{0x3eac030d,0x7af4003d,0x63a400a3,0xcd041513}},	//   _cmft_, _nixt, ùine, мпой, 
   {{0x64bc0010,0xe8200118,0x62240116,0x00000000}},	//   dčij, बरमा_, _سىنل, --, 
   {{0x7afc014f,0xb87800c6,0xd0540134,0x929c033f}},	//   _buqt, _shín, _ɛbɛt, _bułg, 
   {{0x64bc00f3,0xb8780051,0x00000000,0x00000000}},	//   fčij, _phín, --, --, 
   {{0xb8780597,0x7af5156f,0xfc4800d7,0x09e40108}},	//   _bhío, _cixt, _číž_, догн, 
   {{0xa3d419e5,0xb879a380,0x7af40393,0x00000000}},	//   _सुन_, _chío, _dixt, --, 
   {{0xb8780597,0x78ac007f,0xb4c4012c,0x290c00e2}},	//   _dhío, _cmcv, ईको_, īda_, 
   {{0x7afc0357,0x788000d2,0x4b244077,0x64bc8c2c}},	// [2cf80] _guqt, _sívû, _ўмов, učim, 
   {{0x64b8fe33,0xb878e680,0x442001a6,0x37e000f3}},	//   ेक्श, _fhío, _žk_, тоуг, 
   {{0x69c005d1,0xb8780332,0x38b4031c,0x00000000}},	//   ğmes, _ghío, eħru_, --, 
   {{0x69c02c44,0x95980137,0x7afc6140,0x320400d7}},	//   şmes, чтуу_, _yuqt, ecny_, 
   {{0xf48479f8,0xb878007b,0x82a4085e,0x64bc139f}},	//   بالی, _mhíl, мадж, lčik, 
   {{0x05540395,0xd3c40116,0x00000000,0x00000000}},	//   _отбя, رتنى, --, --, 
   {{0x64bda381,0x55c401a9,0x00000000,0x00000000}},	//   nčik, _зарғ, --, --, 
   {{0xb898010f,0x00000000,0x00000000,0x00000000}},	//   ַביש, --, --, --, 
   {{0xc244147e,0xc3049a73,0x98b00356,0x0f300066}},	//   _онак, _آبرو, luză_, هکود, 
   {{0x7cfc02b1,0xb344025c,0x7afc0477,0x00000000}},	//   _hīri, _duħħ, _ruqt, --, 
   {{0x7afc27b3,0xfe4004fb,0x64bc0010,0x7cfc0055}},	//   _suqt, _یکدی, jčik, _kīri, 
   {{0xb87800e4,0xb344025c,0x6299a382,0x7afcc329}},	//   _chíl, _fuħħ, lkvo, _puqt, 
   {{0x7af40054,0xfc3c0597,0xba741927,0x7cfc02b1}},	//   _pixt, rgí_, واست, _mīri, 
   {{0x781446c7,0xb878007b,0x0cac0248,0x00000000}},	//   तर्क_, _phío, _paṣẹ_, --, 
   {{0x64bc09a8,0x7afc0455,0xea000051,0x6e38011a}},	//   rčij, _wuqt, _giậu_, _ותוד, 
   {{0x7afda383,0xee341de6,0xddc80210,0x00000000}},	//   _tuqt, _енә_, zedś, --, 
   {{0x7af4003d,0x6298143a,0x64bc0010,0x9bf400d4}},	// [2cf90] _tixt, kkvo, pčij, _язич, 
   {{0xb8780597,0x629801a4,0x98b00311,0x7ac402dd}},	//   _thío, jkvo, fuză_, _іспе, 
   {{0x7cfc0171,0xfcd00023,0xd4540395,0x79a400d8}},	//   _bīri, _ረጊጹ_, етль, _црпе, 
   {{0xb6980276,0x64bc0093,0x6298057b,0x7cfc00ef}},	//   _atât, hōif, ekvo, _cīri, 
   {{0xe4a40395,0x241800d4,0x00000000,0x00000000}},	//   ърфо, фією_, --, --, 
   {{0x91e4554c,0xef3c00b5,0x471800d9,0x00000000}},	//   ноле, _kg缶_, _מושג, --, 
   {{0xd1b003e6,0x91c400c7,0x00000000,0x00000000}},	//   دیاک, хәал, --, --, 
   {{0x629827bb,0x2ec400dc,0x7cfc00dc,0x00000000}},	//   akvo, रक्त, _mūrd, --, 
   {{0xe820069f,0xe44800c6,0x19d400d1,0x4fc000db}},	//   बरता_, _تلقى_, ﺘﯩﻤﻠ, دەشە, 
   {{0x6298fbba,0xb878007b,0x0e64059f,0xafe001d5}},	//   ckvo, _shíl, хкон, ноқл, 
   {{0x8c44104e,0x1ea8028e,0x00000000,0x00000000}},	//   нене, بايي_, --, --, 
   {{0x85980302,0xa3d402ab,0xb87801e7,0x00000000}},	//   פשרו, _सुड_, _bhím, --, 
   {{0x9e64011d,0x7520002d,0x00000000,0x00000000}},	//   راین, ânzj, --, --, 
   {{0xb8780332,0x3ebc0051,0x00000000,0x00000000}},	//   _dhím, cntt_, --, --, 
   {{0x39e401f0,0x3e6800f2,0x00000000,0x00000000}},	//   едро_, _رجوی_, --, --, 
   {{0x066469f1,0x0b44022e,0x00000000,0x00000000}},	//   کارپ, _знин, --, --, 
   {{0xb69807a8,0x7cfc0374,0x2ca00142,0x00000000}},	// [2cfa0] _ntâs, _rīri, _ilid_, --, 
   {{0x2ca005c7,0x7cfc00e2,0x98b00356,0x64bc0064}},	//   _hlid_, _sīri, tuză_, pčik, 
   {{0xb6f405a9,0x44f80b24,0x2ca000bc,0x00000000}},	//   رىما_, سراج_, _klid_, --, 
   {{0x94a82b9f,0x00000000,0x00000000,0x00000000}},	//   وانِ_, --, --, --, 
   {{0x7cfc0029,0x9aa83345,0x00000000,0x00000000}},	//   _vīri, _ردیف_, --, --, 
   {{0x7cfc02b5,0x2ca0015d,0xa158a4e9,0x4614009a}},	//   _hūre, _llid_, даку_, _سورر, 
   {{0x2ca0007d,0x6299a384,0x7cfda385,0xa4c801d3}},	//   _olid_, rkvo, _kūre, _قطرے_, 
   {{0xb9c82295,0x62980006,0xb02400d1,0x7cfc0153}},	//   _ሰው_, skvo, ىكىم_, _jūre, 
   {{0x7cfc02b1,0x00000000,0x00000000,0x00000000}},	//   _mūre, --, --, --, 
   {{0x4424c6ee,0xfbdc006a,0xddd80316,0x2ca04264}},	//   lao_, ngêe_, _zavř, _alid_, 
   {{0xb63400c8,0xa3d40243,0x2ca03c02,0x44241132}},	//   ערטס_, _सुत_, _blid_, oao_, 
   {{0x4425a386,0x7cfc02b5,0x00000000,0x00000000}},	//   nao_, _nūre, --, --, 
   {{0x7ac43169,0x00000000,0x00000000,0x00000000}},	//   есве, --, --, --, 
   {{0x4425a387,0x2ca00165,0x1958cced,0x7db001d9}},	//   hao_, _elid_, магы_, _مۅخص, 
   {{0x2ca1a388,0x7cfc0024,0x00000000,0x00000000}},	//   _flid_, _būre, --, --, 
   {{0x44241326,0x2ca05794,0x59640131,0x6d4c0210}},	//   jao_, _glid_, нъға, ńcac, 
   {{0x44241326,0x3d0445bf,0x7e6801e4,0x7cfc07d7}},	// [2cfb0] dao_, _संडे_, _kafp, _dūre, 
   {{0xb698d552,0x44242486,0xa3d405f9,0xe8e001fb}},	//   _atâr, eao_, _सुध_, _đục_, 
   {{0x44240972,0x7cfc00ef,0x55f000eb,0x00000000}},	//   fao_, _fūre, য়র্ক_, --, 
   {{0x44241326,0x2c200183,0x22580205,0x00000000}},	//   gao_, _ভাৱে_, _ırka_, --, 
   {{0x7cfc00b8,0xddd80118,0x00000000,0x00000000}},	//   _gīrv, _vavř, --, --, 
   {{0x4425a389,0x00000000,0x00000000,0x00000000}},	//   aao_, --, --, --, 
   {{0x44253db5,0x23600003,0x10a400d8,0x73740588}},	//   bao_, ħija_, кикн, ьыҧх, 
   {{0x4425a38a,0xe6101973,0x3de4009e,0x00000000}},	//   cao_, _نشہ_, নশাল, --, 
   {{0xa3551ea1,0x7e6800ca,0x8fa406ac,0xa858011a}},	//   _مخلص, _bafp, тапе, תיחה_, 
   {{0xf1a421ca,0x2ca0c00a,0xe3b000c6,0xddd80010}},	//   _прен, _slid_, _طرق_, _dovž, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x1fb40220,0x7cfc0055,0x3d240241,0x8c9420c8}},	//   _өсір, _nīru, _síwá_, троі, 
   {{0x99800270,0x0e64022e,0x00000000,0x00000000}},	//   _fehū_, _аклн, --, --, 
   {{0x7cfc00c0,0x00000000,0x00000000,0x00000000}},	//   _sūre, --, --, --, 
   {{0x4425a38b,0x7cfc04fe,0xba204c6b,0x60dc00b8}},	//   yao_, _pūre, рдск, _ūrmi, 
   {{0x6e21a38c,0x44241fce,0x64bc02f0,0x7cfc00de}},	//   _henb, xao_, lčiv, _cīru, 
   {{0x6e21a38d,0x1a2003d4,0xa2a41bd6,0x00000000}},	// [2cfc0] _kenb, _বাৰু_, कसम्, --, 
   {{0x4425a38e,0xb6980311,0xb6c801ed,0x64bc02f0}},	//   wao_, _stâr, والے_, nčiv, 
   {{0x4425a38f,0x75d002dd,0x7cfcff26,0xf501a390}},	//   tao_, ليكا, _tūre, азхо, 
   {{0x4424123c,0x6e208d29,0xd49800d4,0x00000000}},	//   uao_, _lenb, нрі_, --, 
   {{0xb8b002dd,0x7cfc002b,0x00000000,0x00000000}},	//   _төрі, _kūrc, --, --, 
   {{0x44241326,0xe8e007ae,0x7cfc0882,0x6e2001c4}},	//   sao_, _độc_, _kīrt, _nenb, 
   {{0x7e680004,0xdee802d3,0xd14c001f,0x7cfc00cd}},	//   _rafp, _ዘለኻ_, _ሀይማኖ, _mūrc, 
   {{0xf99002e4,0x30100395,0x00000000,0x00000000}},	//   שרה_, адър, --, --, 
   {{0xf8b0025f,0x78a00276,0x00000000,0x00000000}},	//   ישה_, _înve, --, --, 
   {{0xb6980311,0xb9c80023,0x2f240248,0x93380092}},	//   _luân, _ሰፍ_, _sìgá_, _አልባሳ, 
   {{0x6e21a391,0x71700214,0xc0dc01f3,0x00000000}},	//   _denb, _پهنا, _ዓለሙ_, --, 
   {{0x6e2014dc,0xb698002d,0x75200356,0x24780092}},	//   _eenb, _nuân, ânzi, _በሌሊት_, 
   {{0xdee8044e,0x9f34109a,0x3e89a392,0x00000000}},	//   _ዘለኹ_, _селі, _ойдо_, --, 
   {{0x6e21a393,0x38a4000d,0x6e900212,0x3869a394}},	//   _genb, _kõrg_, _вишу, _sacr_, 
   {{0x69d88784,0xeaf803e6,0x7cfc0055,0x64bc0024}},	//   _øvel, کرێت_, _cīrt, lčiu, 
   {{0x6e21a395,0x28a4013d,0xa8a40064,0x64bc0064}},	//   _zenb, ашуг, арук, očiu, 
   {{0xf7708fcb,0x64bc02d5,0x6e200086,0xfc3c0077}},	// [2cfd0] جاز_, nčiu, _yenb, chía_, 
   {{0x64bc02d5,0xd054013f,0xdd1c02fb,0xd6d800f2}},	//   ičiu, _ɛbɑt, _zášt, رواش_, 
   {{0xa9c448a5,0x950401ed,0x63a401c3,0x527400d1}},	//   _всяк, اہرے_, ùinn, ғулу, 
   {{0x6ba803ee,0xe5340212,0x64bc0153,0x00000000}},	//   _örgü, рець, kčiu, --, 
   {{0x929400d4,0x00000000,0x00000000,0x00000000}},	//   ладц, --, --, --, 
   {{0x98a40124,0x648c00a2,0x00000000,0x00000000}},	//   _риҭе, _ỳiti, --, --, 
   {{0x6e210be4,0x64bc0024,0xa5f8013d,0x51540131}},	//   _renb, ečiu, _аеру_, утлу, 
   {{0xcf4401c0,0x6578005c,0x00000000,0x00000000}},	//   гний, ævhe, --, --, 
   {{0x6e2003cb,0x2608012c,0x00000000,0x00000000}},	//   _penb, ाँची_, --, --, 
   {{0x4d646c48,0xbe1c015b,0x63040244,0x00000000}},	//   гков, _দাউদ_, _ئولل, --, 
   {{0x8fa40022,0xf1500133,0x7f4800f1,0x64bc1155}},	//   _әале, _ئێعد, وسیې_, rčiv, 
   {{0x6e21a396,0xab640131,0x7cfc0055,0x00000000}},	//   _wenb, لۇبى, _sūrc, --, 
   {{0x6e21a397,0x64bc8bdf,0x7c9400cf,0x00000000}},	//   _tenb, mčit, اشپا, --, 
   {{0xcde400d1,0x8c940220,0x7f380677,0x00000000}},	//   _йолй, _әркі, _נעצו, --, 
   {{0xa2a41fbc,0x19b80212,0x48782bcb,0xfc3c00ae}},	//   कसत्, вуть_, нсая_, mhín_, 
   {{0xb6980798,0x64bc3493,0x15ac0150,0x00000000}},	//   _quân, nčit, _ﺴﺒﻘﻬ, --, 
   {{0xe7c409bd,0x46e80b2b,0x870401b9,0x580401e0}},	// [2cfe0] ্ধ্য, едан_, ابرل, роуғ, 
   {{0x7cfd1bb0,0xcc8804fb,0xfb18010f,0x97e801b9}},	//   _hūra, _آنکه_, _רוימ, тлуғ_, 
   {{0x7cfc0374,0x00000000,0x00000000,0x00000000}},	//   _kūra, --, --, --, 
   {{0x2919a398,0x64bc0bb8,0x7cfc1494,0x9478004e}},	//   mpra_, jčit, _jūra, ксчу_, 
   {{0x6685a399,0x7cfc0467,0x291933bf,0x38a40254}},	//   _پیال, _mūra, lpra_, _sõrg_, 
   {{0x6ff80029,0x26d80098,0x929c033f,0x816801a9}},	//   _mācī, _ukro_, _puła, ериб_, 
   {{0xa3d402e5,0x5be00f44,0xa495a39a,0x84590029}},	//   _सुर_, _नर्व, _پیشت, _прат_, 
   {{0xa4f98723,0x38bc0108,0x00000000,0x00000000}},	//   _شکار_, märä_, --, --, 
   {{0x29180023,0x741004fb,0xea000208,0x42c801a9}},	//   hpra_, _طولا, _giầu_, _зган_, 
   {{0x64bc0024,0xd3440133,0x00000000,0x00000000}},	//   rčiu, _ئیوه_, --, --, 
   {{0x64bc0006,0x38a40254,0x794800a2,0x00000000}},	//   sčiu, _hõre_, _möwç, --, 
   {{0x38a4000d,0x64bc0064,0x00000000,0x00000000}},	//   _kõre_, pčiu, --, --, 
   {{0xb7bc015b,0x7cfc3a71,0xfc3c00ae,0x3078010f}},	//   _আর্ট, _dūra, bhín_, _ראדנ, 
   {{0x6c840220,0xfc3da39b,0xd914035b,0x38bc00fd}},	//   _ۇلىم, chín_, идгы, kärä_, 
   {{0xd058013b,0x6e4002dd,0x00000000,0x00000000}},	//   _nhwɛ, _انىم, --, --, 
   {{0x6d4c054e,0x38bc0166,0x00000000,0x00000000}},	//   ăcat, därä_, --, --, 
   {{0xd058016b,0xd75812e3,0xfafc036e,0x00000000}},	// [2cff0] _ahwɛ, ضلات_, rvës_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x66d0023a,0x2614033f,0x38bc008e,0x00000000}},	//   näky, धड़ी_, gärä_, --, 
   {{0x7bdc036e,0x00000000,0x00000000,0x00000000}},	//   _kyqu, --, --, --, 
   {{0x64bc09a8,0x61e806be,0x00000000,0x00000000}},	//   včit, _azdl, --, --, 
   {{0x7bdc020c,0x38bc00fd,0x00000000,0x00000000}},	//   _myqu, bärä_, --, --, 
   {{0x65940276,0x7bdc0051,0x38bc0166,0x00000000}},	//   _лару, _lyqu, cärä_, --, 
   {{0x64bc1883,0x40900075,0x75200311,0x944400f1}},	//   učit, قلىر, ânzu, _خپرن, 
   {{0x4fe8016c,0x64bc0306,0xfc3c007b,0xddd00427}},	//   ъмин_, rčit, thín_, _češp, 
   {{0xcdf41c22,0xd01005d9,0x6ea401d3,0x64bc022a}},	//   ичны, _ڀلا_, اندہ_, sčit, 
   {{0x7bdc0309,0x6f8402dd,0x7cfc2bd1,0x31c400d4}},	//   _ayqu, _әуеж, _sūra, _ссав, 
   {{0x7cfda39c,0x31640007,0x717005d9,0x7fb404fb}},	//   _pūra, mwnz_, _پهچا, اهیر_, 
   {{0xe0d0a012,0x8e840395,0xfc3c0332,0x00000000}},	//   _عزم_, _вгле, mhíl_, --, 
   {{0x69d80158,0xbf1003e6,0xecc401c6,0xb7bc00fe}},	//   _øvek, _بووب, ршүү, _আৰ্ট, 
   {{0x48b448a5,0x00000000,0x00000000,0x00000000}},	//   ащат, --, --, --, 
   {{0x7cfc0053,0x1ce40135,0x2918004e,0xfcd000ae}},	//   _tūra, _ཨེར_, rpra_, _ويوج, 
  
   {{0x31640007,0x2919a39d,0xddd80790,0x61480023}},	// [2d000] hwnz_, spra_, _kavş, _ዘይትኽ, 
   {{0x29180267,0x5ba46518,0xea640214,0x7cfc00de}},	//   ppra_, _ылығ, _اپدی, _jūrn, 
   {{0x0565a39e,0x36640107,0x6abc02d0,0x7cfc00de}},	//   рвен, рахо_, mirf, _mūrn, 
   {{0x1cc00327,0x24800784,0x6a7c01e3,0x00000000}},	//   ཁོར_, ñim_, _fåfä, --, 
   {{0x1ce40d46,0x78a00276,0x4ab8000d,0x6abc0332}},	//   _ཨེལ_, _înva, _उगाव, oirf, 
   {{0xfafc0036,0x38bc005b,0x4eb800cc,0x38a4000d}},	//   hwën_, pärä_, ুতুল, _võre_, 
   {{0x121802d5,0x00000000,0x00000000,0x00000000}},	//   уючы_, --, --, --, 
   {{0xc0580efb,0xea00001e,0xf4940014,0x00000000}},	//   тік_, _giấu_, _پھٔت_, --, 
   {{0x3ec41188,0x4ccc03d4,0x5eb401d5,0xdfd0007b}},	//   исоб, ৰগাঁ, ййит, ثية_, 
   {{0x64a421f7,0x66d001f4,0x00000000,0x00000000}},	//   _таға, täky, --, --, 
   {{0x93380092,0x290c0115,0xb2d0009f,0x6abc1d1d}},	//   _አልተሳ, ŭdaj_, _بيلغ, dirf, 
   {{0xfc3c01e7,0x66d001f4,0x1c38008e,0x00000000}},	//   chíl_, räky, ызмы_, --, 
   {{0xb87801e7,0x66d0005b,0x6abc02d2,0x00000000}},	//   _mhít, säky, firf, --, 
   {{0xddd80a43,0xe43c01ef,0x00000000,0x00000000}},	//   _gavş, dříč, --, --, 
   {{0x1fd8009e,0x00000000,0x00000000,0x00000000}},	//   দেশস, --, --, --, 
   {{0xfe7401c0,0xab680171,0x7d180857,0x00000000}},	//   _сүү_, _baļļ, mpts, --, 
   {{0x28f80664,0x7cfc02b5,0x7bdc01b9,0x7d18000f}},	// [2d010] реть_, _hūro, _uyqu, lpts, 
   {{0x7cfc00e2,0x00000000,0x00000000,0x00000000}},	//   _kūro, --, --, --, 
   {{0x7cfc02d5,0xb87800ae,0x98b00210,0x58d4d450}},	//   _jūro, _bhít, erzą_, _гонт, 
   {{0x1ce40489,0xe43c00bc,0xb879a39f,0x7d18035a}},	//   _ཨེས_, bříč, _chít, ipts, 
   {{0xb87800c6,0x734801ee,0xeab00133,0xb364010b}},	//   _dhít, тчев_, _رعی_, ръек, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd1744f3f,0xf485a3a0,0x626401b9,0x00000000}},	//   сылы, _куан, زاوق, --, 
   {{0x64bc0b23,0xc444030f,0x244800db,0xa4480137}},	//   lōin, _هیمن_, _ەجەي_, _ەشەك_, 
   {{0xa9e40316,0x45440092,0x8e7400cf,0x00000000}},	//   _गर्छ_, _ያልነበ, бунч, --, 
   {{0x64bc0607,0x6d4c012d,0xe3b000e5,0x00000000}},	//   nōin, ńcam, _کرہ_, --, 
   {{0xb60002f0,0x7054074d,0x6abc03b2,0x00000000}},	//   mpáč, _кĕне, virf, --, 
   {{0x30e40220,0x7cfc0055,0xb87801e7,0x50f40063}},	//   _тізб, _dūro, _mhís, _узет, 
   {{0x6abc09f3,0xddd805d1,0x7d180036,0x35800092}},	//   tirf, _tavş, apts, ከርበት_, 
   {{0x6f19a3a1,0x8d7403e6,0x3b04013e,0x24b800fe}},	//   mpuc, _هابا, серо_, _জৱাহ, 
   {{0x6abd9f24,0x09e4ee8b,0x6f1804cc,0x89d800f1}},	//   rirf, совн, lpuc, اوزر_, 
   {{0x6abd5b71,0xabc4052f,0xa9282195,0x480402d5}},	//   sirf, _майҙ, _nižš, спав, 
   {{0x6abc1455,0x31380092,0x00000000,0x00000000}},	// [2d020] pirf, _አጭበር, --, --, 
   {{0xb8780248,0x644401e4,0x26dc00e4,0x00000000}},	//   _akíd, ϲiis, ôvo_, --, 
   {{0xe9741fd6,0x00000000,0x00000000,0x00000000}},	//   _بۇزد, --, --, --, 
   {{0x0444584b,0xc6900050,0xe43c00bc,0xb87800ae}},	//   седн, _کِس_, příč, _dhís, 
   {{0x68e40342,0xb8780174,0xa2940d30,0x82340f1c}},	//   mlid, _skíg, жалі, مرغا, 
   {{0x7d180122,0xb87800ae,0xe2f801ec,0x00000000}},	//   ypts, _fhís, шелі_, --, 
   {{0x55c5a3a2,0x84e400ee,0x68e400c5,0x00000000}},	//   _дарғ, _говж, olid, --, 
   {{0x03a41b74,0xb9f01772,0x5f39a3a3,0x1ce4031c}},	//   _либо, _ሞያ_, апия_, _ཨེེ_, 
   {{0x68e5a3a4,0x7e281fe2,0x657c01c7,0x69c00790}},	//   ilid, ліна_, _hrrh, ğmey, 
   {{0x7cfc0053,0x69c003ee,0x68e5a3a5,0xdc24015b}},	//   _pūro, şmey, hlid, _ভাইস_, 
   {{0x7d180e78,0xb87800ae,0xc0581084,0x00000000}},	//   upts, _mhír, _біл_, --, 
   {{0xb5f800c8,0x7d186548,0xfbd00a81,0x00000000}},	//   טליכ, rpts, ۪تھ_, --, 
   {{0x5f940e58,0x9e35a3a6,0xf77c0240,0x00000000}},	//   _филт, _делч, _kyçe_, --, 
   {{0x7cfc7f11,0xed30121e,0x0db8066d,0xbd680276}},	//   _tūro, _کوٹھ, ائیں_, _брие_, 
   {{0x3ebda3a7,0x38c80022,0x3f9401f2,0xfbd001d9}},	//   mitt_, гуан_, ̣dụ_, تتھ_, 
   {{0x68e5a3a8,0x3a3c41b5,0x7cfda3a9,0xf7700451}},	//   glid, şup_, _dàrì, ٻار_, 
   {{0x7cfc00da,0x9ca800aa,0x7c2d79d7,0xb8780af2}},	// [2d030] _jūrm, _مخکې_, macr, _shís, 
   {{0x7c2da3aa,0x3ebc3e41,0x7d09a3ab,0x7cfc00ef}},	//   lacr, nitt_, _kufs, _mūrm, 
   {{0x68e5a3ac,0xb87800c6,0x3ebc06fd,0x78a00356}},	//   blid, _dhír, iitt_, _învo, 
   {{0x68e5a3ad,0x3ebda3ae,0x7d080009,0x6eec005c}},	//   clid, hitt_, _mufs, møbe, 
   {{0x6eec04ce,0xb87800c6,0x657c02d0,0x78bc0240}},	//   løbe, _fhír, _errh, miqv, 
   {{0x39500208,0x7c2c035a,0x7cfc01e1,0x00000000}},	//   _kqxs_, hacr, _yàrì, --, 
   {{0xd9f8006d,0x7c2c014b,0x3ebcefbc,0x6a9c008f}},	//   ंधित_, kacr, ditt_, רשונ, 
   {{0xa3d40406,0xf41c0432,0x00000000,0x00000000}},	//   _सुक_, _ýä_, --, --, 
   {{0x7d09a3af,0x7c2c0221,0x3ebda3b0,0xb4c40490}},	//   _aufs, dacr, fitt_, ैकी_, 
   {{0x3ebce73f,0x68e5a3b1,0x6eec00b5,0x78bc0477}},	//   gitt_, zlid, købe, hiqv, 
   {{0x6f19a3b2,0xb1a40137,0xa3640014,0xcc880484}},	//   spuc, _ушак, _وُہو, абне_, 
   {{0x6eec01bf,0x7cfc0171,0x7b080171,0x00000000}},	//   døbe, _fūrm, _gļuk, --, 
   {{0x68e5a3b3,0x3ebda3b4,0x7cfc01e1,0x00000000}},	//   vlid, bitt_, _sàrì, --, 
   {{0xe8e00016,0xcdc41884,0x7d080ba7,0x68e5a3b5}},	//   _đốc_, _қаққ, _fufs, wlid, 
   {{0x6f0000aa,0x7d080548,0x7c2c0393,0xc8940120}},	//   _iinc, _gufs, bacr, орањ, 
   {{0x6f01a3b6,0x38c8cef2,0x02b41b61,0xf8a4d5de}},	//   _hinc, لاقی_, _अग्न, овск_, 
   {{0x68e5a3b7,0x6f00bda3,0x37e001c6,0x00000000}},	// [2d040] rlid, _kinc, дотг, --, 
   {{0x68e5a3b8,0x6f01a3b9,0xc9641080,0x613001e1}},	//   slid, _jinc, _двой, _jólá, 
   {{0x6f01a3ba,0x6f083917,0x00000000,0x00000000}},	//   _minc, _lugc, --, --, 
   {{0xf480533f,0x68e42994,0x3ebd561b,0xd408007b}},	//   душн, qlid, zitt_, متهم_, 
   {{0xa3d40cb4,0x6f01a3bb,0xb87800ae,0x98b00210}},	//   _सुख_, _oinc, _thír, jrzę_, 
   {{0x6f01a3bc,0x7c2c02e8,0x00000000,0x00000000}},	//   _ninc, zacr, --, --, 
   {{0x3ebc10ee,0x81e0015b,0x98b0012d,0x7c2c03ac}},	//   vitt_, নেন_, erzę_, yacr, 
   {{0x22409d6a,0x6f083917,0x6f01a3bd,0x5f953ed5}},	//   şik_, _bugc, _ainc, зиит, 
   {{0x6f01a3be,0x61300241,0x7d0805e4,0x3ebda3bf}},	//   _binc, _bólá, _sufs, titt_, 
   {{0x6f002c7f,0xdee80023,0x7de401ec,0x00000000}},	//   _cinc, _ዘለኒ_, жімд, --, 
   {{0x3ebc3e41,0x6f01a3c0,0x7d08022f,0x61300332}},	//   ritt_, _dinc, _qufs, _dólá, 
   {{0x3ebc62a5,0xdef80220,0x6f001f8e,0x7cfc00ef}},	//   sitt_, шық_, _einc, _tūrm, 
   {{0x7c2da3c1,0x60c1a3c2,0x00000000,0x00000000}},	//   racr, mimm, --, --, 
   {{0x60c00af5,0x7c2da3c3,0x6f002281,0xf8e0000d}},	//   limm, sacr, _ginc, _कीड़ा_, 
   {{0xdee8044e,0x5824031c,0x7c2c002d,0xf77c00a2}},	//   _ዘለና_, _འབྱོ_, pacr, _izçi_, 
   {{0x6f01a3c4,0x60c1a3c5,0x6eec00b5,0x7cfc00cd}},	//   _zinc, nimm, røbe, _mūrk, 
   {{0xb87801e7,0xab280114,0xfca85cfc,0x00000000}},	// [2d050] _dhíp, _доња_, _ماکو_, --, 
   {{0x60c1a3c6,0x6f000077,0x2bc80b02,0x35e40cb6}},	//   himm, _xinc, रपरा, оцев, 
   {{0x60c123f1,0x00000000,0x00000000,0x00000000}},	//   kimm, --, --, --, 
   {{0x60c1a3c7,0x7ae40227,0x5824025c,0x00000000}},	//   jimm, lljt, _འབྲོ_, --, 
   {{0x60c1a3c8,0xb4c807f7,0x00000000,0x00000000}},	//   dimm, _लदी_, --, --, 
   {{0x6f080009,0xe6646874,0x00000000,0x00000000}},	//   _rugc, _отсо, --, --, 
   {{0x60c00eda,0x3d04033d,0x61300332,0x10a40408}},	//   fimm, _संगे_, _rólá, зийн, 
   {{0x6f01a3c9,0x60c00eda,0x613000ae,0x98b0012d}},	//   _sinc, gimm, _sólá, trzę_, 
   {{0xea00001e,0xe454008e,0x00000000,0x00000000}},	//   _phẫu_, _юкты, --, --, 
   {{0x0ea8ac58,0xe3b0fc3b,0x6f0002d1,0xfe4002bf}},	//   ской_, _شرق_, _qinc, нньо, 
   {{0x60c027c4,0xa2d8bc82,0xcc89a3ca,0x00000000}},	//   bimm, यवर्, منده_, --, 
   {{0x60c00198,0xa1f00150,0x6f08e0ea,0xbd4000cf}},	//   cimm, _جۋىت, _tugc, رچىي, 
   {{0x6f01a3cb,0x6eec03cd,0x4bd80006,0x613001e1}},	//   _tinc, røbb, сьня_, _tólá, 
   {{0x6f0016b8,0xa3d400bc,0x00000000,0x00000000}},	//   _uinc, _सँघ_, --, --, 
   {{0x2bdc8d42,0xea0007ae,0x290c006a,0xf77c12e4}},	//   _गुरू_, _khẩu_, êda_, _arç_, 
   {{0xb4c40316,0x0c24d31e,0x78cc0208,0x00000000}},	//   ैको_, _эмин, _đểcó_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [2d060] --, --, --, --, 
   {{0x60c1a3cc,0x00000000,0x00000000,0x00000000}},	//   zimm, --, --, --, 
   {{0x60c1a3cd,0x76400af2,0x39400076,0xa3d40ce0}},	//   yimm, ónya, crjs_, _सुज_, 
   {{0x75d040c7,0x941c013f,0x60c00129,0x81e000eb}},	//   رينا, mhwɛ_, ximm, নেড_, 
   {{0x60c1a3ce,0xfc3c00e4,0x00000000,0x00000000}},	//   vimm, nkía_, --, --, 
   {{0x69d80158,0x60c00112,0x00000000,0x00000000}},	//   _øves, wimm, --, --, 
   {{0x941c0134,0xc2440022,0xb3340023,0xc05803de}},	//   nhwɛ_, _ҽнак, _ኣይግደ, біп_, 
   {{0x7cec08e7,0x44200051,0x00000000,0x00000000}},	//   kùra, _ýk_, --, --, 
   {{0x60c1a3cf,0x00000000,0x00000000,0x00000000}},	//   rimm, --, --, --, 
   {{0x60c00664,0x7b0800da,0x72d00137,0x62a80345}},	//   simm, _kļuv, _كەنچ, _بخرێ_, 
   {{0x6289a3d0,0x7cfc02b5,0x60c0013c,0xba740131}},	//   _indo, _hūri, pimm, ۋاست, 
   {{0x7cfc02d5,0x60c1a3d1,0x00000000,0x00000000}},	//   _kūri, qimm, --, --, 
   {{0x7cfc0024,0xfb840006,0x0f7001af,0xab8400d8}},	//   _jūri, чынн, _ағыр, нурк, 
   {{0xdd90030f,0x7cfc0fda,0x1cc00327,0x19c4008e}},	//   _لوت_, _mūri, ཁོང_, дәмг, 
   {{0x628802ce,0x7cfc0171,0x00000000,0x00000000}},	//   _mndo, _lūri, --, --, 
   {{0x25e0068f,0x31380020,0xe8940953,0x38a4000d}},	//   _कड़ी_, _አይቀር, нась, _võro_, 
   {{0x6288152d,0xf1bc00d0,0xd6d06923,0x38a40254}},	// [2d070] _ondo, čšia_, پقا_, _wõro_, 
   {{0x62880810,0xb4c4012d,0xa814009d,0x00000000}},	//   _nndo, ैक्_, _үдэш, --, 
   {{0x290c00bc,0x545415bd,0x00000000,0x00000000}},	//   ídat_, двет, --, --, 
   {{0x7cfc0fda,0x23a8134e,0x00000000,0x00000000}},	//   _būri, कनंद, --, --, 
   {{0x69d814f5,0xc5dc0eac,0x00000000,0x00000000}},	//   _øver, ভেলপ, --, --, 
   {{0x91e43fd9,0xd5dc0943,0xfc3da3d2,0x7cfc4e96}},	//   моле, pﬁ_, chív_, _dūri, 
   {{0x6eec0158,0xea000208,0xb4440064,0x00000000}},	//   jøba, _phẩu_, _нэак, --, 
   {{0x92cc00bd,0x6289a3d3,0xa3b84b99,0x63c800e5}},	//   রতে_, _endo, _کافر_, ásná, 
   {{0xa1840022,0x63a400a3,0x00000000,0x00000000}},	//   _ҿыцл, ùint, --, --, 
   {{0xddc8b700,0xb62c04ce,0xafe001b9,0x00000000}},	//   cedū, _ｓｔ_, моқл, --, 
   {{0xf8bc003e,0xf1a416c0,0xb1a401d5,0x00000000}},	//   _omé_, _эран, _эшак, --, 
   {{0x7cec0428,0x7cfc00b8,0xbb1802dd,0xd47800df}},	//   tùra, _kīry, _ﺷﯘﻱ_, קאָל, 
   {{0x62880b21,0x7cfc002b,0x4e94007b,0x00000000}},	//   _yndo, _jīry, _يشتر, --, 
   {{0xf8bda3d4,0xfc3c0022,0x7d0c2805,0x00000000}},	//   _amé_, rkía_, úisí, --, 
   {{0x0d20004e,0x00000000,0x00000000,0x00000000}},	//   _шүнү, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xaf540205,0x00000000,0x00000000,0x00000000}},	// [2d080] _çığr, --, --, --, 
   {{0x290c74c3,0xf8bc068c,0x7cfc02b5,0xf741a3d5}},	//   ídas_, _emé_, _rūri, тефо, 
   {{0x7cfc0006,0xb8780241,0x75340175,0x00000000}},	//   _sūri, _ikín, gsxz, --, 
   {{0x7cfc3e16,0x448802e8,0x92cc0011,0xa82401d3}},	//   _pūri, юбен_, রতো_, _سکرن, 
   {{0xe285a3d6,0x4ad00cce,0x3d041a04,0x81e00011}},	//   нған, _सदाव, _संघे_, নো_, 
   {{0xdee8001f,0x7cfc00b8,0x00000000,0x00000000}},	//   _ዘፈን_, _dīry, --, --, 
   {{0x3d04000d,0x00000000,0x00000000,0x00000000}},	//   _सूझे_, --, --, --, 
   {{0x7cfc00da,0x63e40150,0x794c0092,0x1f74011c}},	//   _tūri, _كۋال, _ዕውቀት, елия, 
   {{0x7411a3d7,0xb1480023,0x00000000,0x00000000}},	//   _شولا, _ዘይውዳ, --, --, 
   {{0x4425a3d8,0x82600150,0xdd1c0419,0x11f800f1}},	//   lbo_, _شۇعن, _vážt, _کومک_, 
   {{0x4425a3d9,0xdcf8002b,0x7cc8030a,0x38a4000d}},	//   obo_, _arvā, lęri, _sõrm_, 
   {{0x4425a3da,0xb8780ca8,0x38a4000d,0x71a001a9}},	//   nbo_, _akín, _põrm_, _шахз, 
   {{0x78a0084c,0x4425a3db,0x70f8011a,0x00000000}},	//   _învi, ibo_, _והאח, --, 
   {{0x61e805ac,0x4424014f,0x6eec01bf,0x2be000bc}},	//   _kydl, hbo_, løbn, _नडरा, 
   {{0x4425a3dc,0xceac00ec,0x00000000,0x00000000}},	//   kbo_, _دڙي_, --, --, 
   {{0x4425a3dd,0x61e82344,0xdd9005d9,0x7e7801bf}},	//   jbo_, _mydl, _لوڪ_, ldtp, 
   {{0x4425a3de,0x6b740184,0x2ca401e6,0x61e812ed}},	// [2d090] dbo_, _алыу, ömde_, _lydl, 
   {{0x4425a3df,0x7c3809f3,0x61e803ac,0x6d640115}},	//   ebo_, ðurf, _oydl, ŭpaŝ, 
   {{0xb698006a,0x61e82d8b,0x7cfc002b,0x442401a9}},	//   _buâr, _nydl, _dūrv, fbo_, 
   {{0x4425a3e0,0x9aa4009f,0x00000000,0x00000000}},	//   gbo_, _آمھو, --, --, 
   {{0xfc3c068c,0x580433d2,0x00000000,0x00000000}},	//   lhís_, _سوسك, --, --, 
   {{0x61e80e96,0x4425a3e1,0x7cfc0882,0x8fd07f6d}},	//   _bydl, abo_, _vīry, һәлә, 
   {{0x4425a3e2,0x38a400c5,0x61e803cb,0x81e02cc5}},	//   bbo_, _nõrk_, _cydl, নেস_, 
   {{0x8fd11c49,0x7cfc0064,0x2ea400cd,0x4f9400f3}},	//   ләлә, _kūru, गस्त, ероу, 
   {{0xf1dc007d,0xaee000b8,0x8e540a4a,0xb91401e1}},	//   _पुरन, _ghṛh, нтні, _pafọ_, 
   {{0xf1a5a3e3,0x00000000,0x00000000,0x00000000}},	//   _орен, --, --, --, 
   {{0x61e8015d,0x00000000,0x00000000,0x00000000}},	//   _gydl, --, --, --, 
   {{0x81e00729,0xb878148b,0xcb681d0f,0x00000000}},	//   নেহ_, _skín, паме_, --, 
   {{0x3eac04cc,0xf1c03347,0x0ae800ae,0x00000000}},	//   _flft_, _वेतन, كرسي_, --, 
   {{0x44240219,0xbf34010f,0x00000000,0x00000000}},	//   zbo_, _טאנץ_, --, --, 
   {{0x442401d9,0x96140154,0x00000000,0x00000000}},	//   ybo_, িরাম_, --, --, 
   {{0x4425a3e4,0x7cfc00ef,0x61e40205,0x00000000}},	//   xbo_, _būru, şilg, --, 
   {{0x0685068a,0x7cfc1161,0xf7415e42,0x4425a3e5}},	// [2d0a0] нган, _pūrv, лето, vbo_, 
   {{0xfc3c00c6,0x45d413d6,0x00000000,0x00000000}},	//   bhís_, нцет, --, --, 
   {{0x4424007f,0xfc3da3e6,0x6b850d57,0x3ab80375}},	//   tbo_, chís_, _hrig, _זמינ, 
   {{0x1ce40489,0x44240428,0x61e80158,0x06bc00cc}},	//   _ཨེབ_, ubo_, _rydl, _অৱশি, 
   {{0x4425a3e7,0x61e82611,0x00000000,0x00000000}},	//   rbo_, _sydl, --, --, 
   {{0x4425a3e8,0xb7b800e4,0xbb3800df,0xc32000cc}},	//   sbo_, _teãr, לעני, _নিদি_, 
   {{0xf1c0215d,0x044400d6,0xa194515c,0x4424014b}},	//   _वेदन, _певн, тайч, pbo_, 
   {{0xea0001fb,0x61e80306,0x442401a9,0x37440023}},	//   _nhậu_, _vydl, qbo_, _ንርእዮ, 
   {{0x3f818333,0x929c4baa,0x1cdc0135,0x6b85a3e9}},	//   íku_, _pułt, ྡོལ_, _nrig, 
   {{0x61e804f3,0xb87801e1,0x41b40305,0x00000000}},	//   _tydl, _akíl, _псет, --, 
   {{0x6b85a3ea,0x6eec4e9b,0x7e780af9,0xfe7001d3}},	//   _arig, møbl, rdtp, ندھ_, 
   {{0x61e40365,0xea0001fb,0x67240d27,0x38a40037}},	//   ğild, _chậu_, kpij, _võrk_, 
   {{0x69c9a3eb,0x6b8400ad,0xbea402d5,0xb60000d0}},	//   úden, _crig, _падк, čšie, 
   {{0x6b85a3ec,0x7cfc02b1,0x3eac01a4,0x672401f5}},	//   _drig, _rūru, _ulft_, dpij, 
   {{0x81e00d42,0x6b85a3ed,0x6441a3ee,0x7cfc0064}},	//   নের_, _erig, _odmi, _sūru, 
   {{0x6b85a3ef,0x661cfd56,0x7cfc3e16,0x38a4000d}},	//   _frig, _afrk, _pūru, _kõri_, 
   {{0x6b85a3f0,0xf77055de,0x67240d27,0xfc3c067c}},	// [2d0b0] _grig, داز_, gpij, shís_, 
   {{0xe68804a9,0xa775a3f1,0x00000000,0x00000000}},	//   ىنقى_, ылуч, --, --, 
   {{0x7cfc00b0,0x63a403cd,0x00000000,0x00000000}},	//   _wūru, øinn, --, --, 
   {{0x7cfd3f77,0x6b85a3f2,0x00000000,0x00000000}},	//   _tūru, _yrig, --, --, 
   {{0x1ce403bd,0x88981203,0xc88403fa,0x661851bb}},	//   _ཨེན_, _חברי, ößen_, çakç, 
   {{0x03a1a3f3,0x64413a3b,0x00000000,0x00000000}},	//   ришо, _edmi, --, --, 
   {{0xd1740fb5,0xd130fae3,0x00000000,0x00000000}},	//   тылы, جمع_, --, --, 
   {{0x1cdc031c,0x2f2401e1,0x09c400cc,0xd13000ec}},	//   ྡོས_, _nígò_, _এডমা, همڻ_, 
   {{0x9990012c,0x648c0432,0xa344009d,0x13a40345}},	//   kazů_, _ỳigi, _бэхл, _جۆشی_, 
   {{0x7ec44056,0x8fd00032,0x0d85a3f4,0x2ab4010e}},	//   _répè, ләһә, влон, _käbe_, 
   {{0x6b8425a9,0x905400a8,0xa25403b9,0x00000000}},	//   _srig, _авец, lüşə_, --, 
   {{0x63a402b5,0x7ec40129,0x00000000,0x00000000}},	//   äing, _pépè, --, --, 
   {{0xbb50037e,0x2f240241,0x2ab4070a,0xc438011a}},	//   _anaカ_, _dígò_, _läbe_, ותרי, 
   {{0x61e4aa4a,0xc3300302,0x6b84fb0e,0x67240010}},	//   şile, שום_, _vrig, vpij, 
   {{0x09e433e0,0x3b040868,0x672401f5,0x7cfc002b}},	//   товн, теро_, wpij, _pūrt, 
   {{0x7a3c6648,0x9854deeb,0x672401f5,0x00000000}},	//   _açtı, лтуш, tpij, --, 
   {{0x6b8408e5,0x7c3805f7,0x661c010a,0x00000000}},	// [2d0c0] _urig, ðure, _pfrk, --, 
   {{0xe61003be,0x00000000,0x00000000,0x00000000}},	//   _düşə, --, --, --, 
   {{0x6725a3f5,0x623400d1,0x00000000,0x00000000}},	//   spij, қейу, --, --, 
   {{0x6725a3f6,0x3a30014b,0x29180007,0x2ab4010b}},	//   ppij, _zexp_, mqra_, _däbe_, 
   {{0x2bc80574,0x68e5a3f7,0x2901a3f8,0x3a30009a}},	//   रपटा, moid, mmia_, _yexp_, 
   {{0x2900049b,0xf48401b9,0x2ca00254,0x670401ec}},	//   lmia_, _یاقی, _loid_, _сүзб, 
   {{0x2ab40e78,0xefb001b9,0x29180327,0x29001057}},	//   _gäbe_, ییمگ, nqra_, omia_, 
   {{0xb9c8044e,0x2ca00363,0x00000000,0x00000000}},	//   _ደው_, _noid_, --, --, 
   {{0x2900023a,0x00000000,0x00000000,0x00000000}},	//   imia_, --, --, --, 
   {{0x68e5a3f9,0x2900045a,0x1b200154,0x00000000}},	//   hoid, hmia_, _বিলে_, --, 
   {{0xb8780f52,0x68e45184,0x2ca00332,0x2900036e}},	//   _ehíy, koid, _boid_, kmia_, 
   {{0x68e402f6,0x2ca00175,0xbb341d00,0xffe4022e}},	//   joid, _coid_, _ﻗﯘﻡ_, _июлн, 
   {{0x68e401e7,0x999000bc,0x2ca40267,0x38a4000d}},	//   doid, tazů_, ömda_, _kõrv_, 
   {{0x1ce431d9,0x2901a3fa,0x7ac40249,0x7c380321}},	//   _ཨེམ_, emia_, тсме, ðurb, 
   {{0x3f8402fb,0x2ca001ab,0x99900118,0xeef40375}},	//   _hrou_, _foid_, razů_, _שמור_, 
   {{0x3f84030a,0xdc540b3e,0x2ca0952b,0x68e40108}},	//   _krou_, _свињ, _goid_, goid, 
   {{0x57f40d06,0x660c013f,0xa814013e,0x00000000}},	// [2d0d0] упат, ɛnkɛ, рдуш, --, 
   {{0x2ca0a926,0x68e401ab,0x29000108,0x00000000}},	//   _zoid_, aoid, amia_, --, 
   {{0x68e403ac,0x00000000,0x00000000,0x00000000}},	//   boid, --, --, --, 
   {{0x9359a3fb,0x00000000,0x00000000,0x00000000}},	//   ерку_, --, --, --, 
   {{0xe3b0a534,0x00000000,0x00000000,0x00000000}},	//   يره_, --, --, --, 
   {{0x2ab40139,0xaee000b8,0xc32000eb,0x00000000}},	//   _täbe_, _piṭh, _নিশি_, --, 
   {{0x3f840077,0xe5342075,0x00000000,0x00000000}},	//   _arou_, _весь, --, --, 
   {{0x3f85a3fc,0xa5f9a3fd,0xbb3402dd,0x00000000}},	//   _brou_, _ресу_, _ﻗﯘﻥ_, --, 
   {{0xb8780248,0x3f8400ad,0xf1bc012c,0x4fe800fd}},	//   _akík, _crou_, _řád_, эмин_, 
   {{0x63a4049b,0xe3b158e8,0x3f840076,0x72a00131}},	//   äine, _برف_, _drou_, _خەتن, 
   {{0x2ca0e1b9,0x2900009f,0x3f851aa2,0x68e401f7}},	//   _poid_, ymia_, _erou_, yoid, 
   {{0x3f85a3fe,0x814000f1,0x8b24004e,0xc5f000d9}},	//   _frou_, _اچون, лдме, מדי_, 
   {{0x3f85a3ff,0x68e5a400,0x2ca03af1,0x8f680107}},	//   _grou_, void, _void_, _чалб_, 
   {{0x7f3825f9,0x2ca00076,0x38a4000d,0x00000000}},	//   _טענו, _woid_, _mõru_, --, 
   {{0x68e40641,0x2900036e,0xfbdc05c7,0x00000000}},	//   toid, tmia_, ugêr_, --, 
   {{0x2901a401,0x2d85a402,0xfbdc0156,0xd9180108}},	//   umia_, _irne_, rgêr_, тьё_, 
   {{0x38c8034c,0xfafc0de2,0x00000000,0x00000000}},	// [2d0e0] رافی_, rwër_, --, --, 
   {{0x68e5a403,0xb6a1a404,0x2900023a,0x3ab001af}},	//   soid, биул, smia_, _ләст, 
   {{0x2b40003a,0x7cfc0055,0x75d0007b,0x225800a2}},	//   _hvic_, _kūrp, ميكا, _örki_, 
   {{0xe6600342,0x00000000,0x00000000,0x00000000}},	//   ğrış, --, --, --, 
   {{0x82a4386d,0xe5140037,0x00000000,0x00000000}},	//   ладж, _तूरि_, --, --, 
   {{0x2d85a405,0x7b080327,0x37a00116,0x78a0054e}},	//   _orne_, _nżul, _уқуғ, _învr, 
   {{0x35a1a406,0x26d8036b,0x00000000,0x00000000}},	//   _ларг, _ijro_, --, --, 
   {{0x3f8400f7,0x00000000,0x00000000,0x00000000}},	//   _prou_, --, --, --, 
   {{0xdfd00597,0xdfd401c0,0xb1e004a9,0x5eb40075}},	//   تية_, ропы, _қәшқ, ийит, 
   {{0x3f840591,0x2d840306,0xb3c40902,0x00000000}},	//   _vrou_, _brne_, _слуз_, --, 
   {{0x2d840bb8,0x98b0012d,0x00000000,0x00000000}},	//   _crne_, lszą_, --, --, 
   {{0x3f85a407,0x00000000,0x00000000,0x00000000}},	//   _trou_, --, --, --, 
   {{0x2d85a408,0xede007d6,0x9f3410da,0x3b7c0092}},	//   _erne_, _қўшн, _телі, _እጩዎች_, 
   {{0xbda5a409,0x29840588,0x09c400eb,0x00000000}},	//   _محبو, әырг, _এড়া, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf40803d4,0xa8a41a5c,0x00000000,0x00000000}},	//   হঁতৰ_, брук, --, --, 
   {{0x96351fa4,0x98b0012d,0xf77c0200,0x94741888}},	// [2d0f0] инац, jszą_, _kyçi_, یگرا, 
   {{0xda1812eb,0xddd8013a,0x98b00210,0x00000000}},	//   _दलित_, _javů, dszą_, --, 
   {{0x7ae404b9,0x67d40184,0x3d1800e8,0x38a40254}},	//   mojt, _ғору, _jëw_, _sõru_, 
   {{0x52dc000d,0xe4e400d4,0xd25000ec,0x7ae4036e}},	//   यव्स, бічн, ڪچر_, lojt, 
   {{0x3d1800e8,0xfc3c0548,0x0838008f,0x3f8001bf}},	//   _lëw_, rkíh_, _בערל, ækul_, 
   {{0x38a400af,0x630401d5,0x00000000,0x00000000}},	//   _võru_, مونل, --, --, 
   {{0xa5f8005e,0x74685aa6,0x50b40276,0x00000000}},	//   _беру_, _прав_, исиу, --, 
   {{0xcf45a40a,0xe18800b2,0x10a43129,0x004400f1}},	//   аний, ائون_, риин, لیمي_, 
   {{0x6eec00b5,0x7ae40784,0x8eb8084c,0x0eb8010b}},	//   løbi, kojt, вынт_, вуны_, 
   {{0x0ea802f6,0x6b4c01a8,0xcef406ed,0x7cfc002b}},	//   ткой_, _lögð, јчињ, _sūrp, 
   {{0xcc88034c,0x2b4000b8,0x00000000,0x00000000}},	//   ننده_, _svic_, --, --, 
   {{0x2d8409a8,0x61fc0e89,0x7eb40129,0x00000000}},	//   _vrne_, _ùrla, _râpe, --, 
   {{0x7c380bcd,0x00000000,0x00000000,0x00000000}},	//   ðura, --, --, --, 
   {{0x6eec037e,0x00000000,0x00000000,0x00000000}},	//   købi, --, --, --, 
   {{0x6f1802d1,0x29c80116,0x8a0455f3,0x00000000}},	//   lquc, уңни_, рзве, --, 
   {{0x98b0012d,0xcba4030d,0x2b400064,0x81e00154}},	//   yszą_, _ваий, _tvic_, নেক_, 
   {{0x46e9a40b,0x2b4000cf,0x6f1802d1,0x7ae40216}},	// [2d100] вдан_, _uvic_, nquc, bojt, 
   {{0xf484006c,0x064800ae,0x00000000,0x00000000}},	//   یانی, ئلاً_, --, --, 
   {{0x3d18002e,0x98b0012d,0x38c801d3,0x85780395}},	//   _xëw_, wszą_, راہی_, ъсат_, 
   {{0x1cdc031c,0x1a240014,0x88b00133,0x845000db}},	//   ྡོག_, _پریُ, _بیرچ, زىتچ, 
   {{0x437411ed,0xc7940166,0x00000000,0x00000000}},	//   рует, _трны, --, --, 
   {{0xea00004d,0xfafc0036,0x98b0012d,0x00000000}},	//   _chầu_, rtëg_, rszą_, --, 
   {{0x04940024,0x00000000,0x00000000,0x00000000}},	//   _краў, --, --, --, 
   {{0x98b00034,0x3d1800e8,0x75780375,0x3f64014b}},	//   pszą_, _rëw_, _בטלפ, атоб, 
   {{0xd968044e,0x6d440030,0x7e2801ce,0x7ae403f0}},	//   _ህግደፋ, ájan, кіна_, yojt, 
   {{0xdfd40046,0x1be01af8,0xbea401c6,0x6d440135}},	//   _қолы, _गुगल_, рший, ġjan, 
   {{0xdfd00acb,0x7ae4036e,0x00000000,0x00000000}},	//   تيک_, vojt, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7ae40455,0xadc00051,0x00000000,0x00000000}},	//   tojt, _phải, --, --, 
   {{0x6b4c01a8,0x3d18002e,0x19582fe5,0x1cdc0327}},	//   _sögð, _tëw_, лагы_, ྡོང_, 
   {{0x7ae4044e,0x38c402e8,0xcf8c0133,0x00000000}},	//   rojt, ащав, _قژی_, --, 
   {{0xf77000ec,0x0b2400fe,0x00000000,0x00000000}},	//   ٺار_, _বিৰল_, --, --, 
   {{0xf771a40c,0x7ae5a40d,0xb8fc00cd,0xe78401f4}},	// [2d110] غار_, pojt, _तद_, жухо, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xaadc0375,0x29840024,0x00000000,0x00000000}},	//   _בחזר, _дыяг, --, --, 
   {{0x6f180309,0x00000000,0x00000000,0x00000000}},	//   yquc, --, --, --, 
   {{0xfa480023,0x7bdc0051,0x00000000,0x00000000}},	//   _ንምስማ, _jxqu, --, --, 
   {{0x5eac009e,0x787000ec,0xe3b00066,0x63a40108}},	//   টোতে, _اُڏا, برم_, äina, 
   {{0x7f400869,0xc690008f,0x32400032,0xbb7801ec}},	//   _avoq, _צאל_, беҙг, _ﲤﻬﻴﺪ_, 
   {{0x40900131,0x0cc4000d,0x00000000,0x00000000}},	//   كلىر, _लगेम, --, --, 
   {{0xea00001e,0xb4e035e8,0x93b40063,0xd01000e5}},	//   _thầu_, नकी_, _убац, _ہلا_, 
   {{0xe8e007ae,0x7c382833,0x6f1803f0,0xd01001e2}},	//   _đọc_, ðurn, rquc, _ځلا_, 
   {{0xea00001e,0xc3040014,0xd01000c6,0x6040063f}},	//   _khấu_, _آلی, _فلا_, _ịmeb, 
   {{0x6fc80073,0x00000000,0x00000000,0x00000000}},	//   _तेथू, --, --, --, 
   {{0x6f1802d1,0xa0c406c7,0xf77c0200,0xddc800d7}},	//   qquc, _بينو, _kyçu_, redš, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7bdc0d63,0x48b4011c,0x00000000,0x00000000}},	//   _exqu, бщат, --, --, 
   {{0x38680098,0x5018008f,0xf1dc00c5,0x589400cf}},	//   _cbcr_, רוּו, _पुछन, ошуу, 
   {{0x864401b9,0x9ac4031c,0x2d400139,0x00000000}},	// [2d120] йнаж, faċċ, lıe_, --, 
   {{0xfbd00375,0xe63400a2,0xded40092,0x00000000}},	//   _מתח_, _ösüº, _የኪነ_, --, 
   {{0x7a7808a8,0x05641214,0x291c0022,0x38a4000d}},	//   _גריס, свен, _îva_, _võrr_, 
   {{0x38680048,0xb87801e1,0x29040086,0xea00004d}},	//   _gbcr_, _ajíf, _òma_, _chấu_, 
   {{0x9ac40327,0x6e20032e,0xe2140166,0x00000000}},	//   baċċ, _ofnb, омлы, --, 
   {{0x24800b9b,0x6d400857,0xd4540092,0x00000000}},	//   žim_, _ovna, _የዝግጅ, --, 
   {{0x82340137,0x6d440419,0x00000000,0x00000000}},	//   _ۇراا, ájal, --, --, 
   {{0x61e5a40e,0x6ab43f6f,0x2d400139,0x5f78431a}},	//   şilo, ँसुर, dıe_, لمبس_, 
   {{0x6d4002d0,0x408401f0,0x00000000,0x00000000}},	//   _avna, _ҳулб, --, --, 
   {{0x6098040b,0x324073f9,0x22580162,0x00000000}},	//   انکس_, _неуг, _ørk_, --, 
   {{0x7c380579,0xdc9802bf,0x4085a40f,0x1df8005b}},	//   ðuro, авні_, _гулб, рены_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d41a410,0x7ff40a2c,0x92cc0c58,0x00000000}},	//   _evna, _اساا, ৰতৰ_, --, 
   {{0x7c2c0077,0x6abc031c,0x2d400139,0x00000000}},	//   sbcr, ghrf, bıe_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb4b40dba,0x00000000,0x00000000,0x00000000}},	//   _छते_, --, --, --, 
   {{0xfc3da411,0xdd9001ed,0x28f8005b,0xda700014}},	// [2d130] maí_, _روک_, сеть_, _ہُک_, 
   {{0xfc3c0491,0xb87801e1,0xda6400ec,0x00000000}},	//   laí_, _akít, _ڏاڍي, --, 
   {{0x9418023a,0x9ac4031c,0x72a000d1,0x00000000}},	//   ажет_, raċċ, ۋەرن, --, 
   {{0xfc3c06d5,0xb4e01bf9,0x61e40e2d,0x93f50e16}},	//   naí_, नके_, ğill, опец, 
   {{0xb87801e1,0x61e40342,0x00000000,0x00000000}},	//   _ajíg, şill, --, --, 
   {{0xfc3c0491,0x25ac0118,0xbb2c0150,0x2b440419}},	//   haí_, íhlá_, _ﺨﺩﻤ_, ámci_, 
   {{0x91040372,0xfc3c1132,0xea0001fb,0x00000000}},	//   опке, kaí_, _thấu_, --, 
   {{0x7c3809cc,0xfc3c0120,0x6d440030,0xd7dc0073}},	//   ðurl, jaí_, ájam, _यशाच, 
   {{0xfc3c0597,0xb87801e1,0x6eec005c,0x6d440327}},	//   daí_, _ejíg, købt, ġjam, 
   {{0xb8d80327,0x91800131,0x82600150,0x00000000}},	//   _མཾ_, _يۇشۇ, _يۇنن, --, 
   {{0xfc3da412,0x00000000,0x00000000,0x00000000}},	//   faí_, --, --, --, 
   {{0xfc3c00c6,0x00000000,0x00000000,0x00000000}},	//   gaí_, --, --, --, 
   {{0x3b18002e,0x8fa40fbe,0xda600b82,0x6abc0142}},	//   _cuqq_, _фале, _ድምጽና_, thrf, 
   {{0x69c001e4,0xdb1400a2,0x74cc0154,0x00000000}},	//   ŝmem, _çaýs, িকিউ, --, 
   {{0x8a040046,0x0ca40023,0xfc3c00ae,0x8cc40127}},	//   ізбе, _ዚገልጽ_, baí_, _وقته, 
   {{0xb4e002f8,0xfc3c00c6,0xd9280006,0x00000000}},	//   नको_, caí_, сцёл_, --, 
   {{0xb4e000bc,0x00000000,0x00000000,0x00000000}},	// [2d140] नकै_, --, --, --, 
   {{0xb878066a,0x26dc00e4,0xca700244,0x03a80066}},	//   _skít, õvo_, _تۆسک, یدشو_, 
   {{0x6eec819e,0x88e402e8,0x571801d5,0x00000000}},	//   løbs, _мжое, _қўяр_, --, 
   {{0xddd80010,0x6820012d,0x63a401f4,0x00000000}},	//   _javš, _bądź, äino, --, 
   {{0xf484760d,0x61e405d1,0x6d4400d0,0x224800fd}},	//   تالی, ğilm, ájaj, йҗан_, 
   {{0x61e56898,0x41241422,0x00000000,0x00000000}},	//   şilm, офиб, --, --, 
   {{0x15b000cf,0xd25000e5,0x02a807b7,0x00000000}},	//   _كەكس, رنٹ_, _कवीन, --, 
   {{0xddd80232,0x44200724,0x437455da,0xdb1c01ed}},	//   _navš, _ük_, _музт, szsé, 
   {{0xfc3da413,0x7c38041e,0x00000000,0x00000000}},	//   vaí_, ðurm, --, --, 
   {{0x2485a414,0x00000000,0x00000000,0x00000000}},	//   _hamm_, --, --, --, 
   {{0xfc3c06d5,0x2485a415,0xbdc411ed,0xdd91a416}},	//   taí_, _kamm_, ющий, روح_, 
   {{0x2485a417,0xb1100131,0x3f6813b5,0x00000000}},	//   _jamm_, _قولغ, _видо_, --, 
   {{0xfc3c0491,0x24855341,0x11080fb4,0x5f940902}},	//   raí_, _mamm_, _اغلي_, _хилт, 
   {{0xfc3c0491,0x2485a418,0xf9900014,0xb4b41be1}},	//   saí_, _lamm_, ٘بر_, _छत्_, 
   {{0x298911d8,0xfc3c00c6,0x1cdc025c,0x98a000cd}},	//   осто_, paí_, ྡོད_, _athā_, 
   {{0x2485a419,0x23bc07b7,0xd7c8027d,0xe8940024}},	//   _namm_, ्छाद, موزه_, мась, 
   {{0x63a4023a,0x39400113,0xec38011a,0x32d8000d}},	// [2d150] äinl, ssjs_, _ואחר_, _बदलऽ, 
   {{0x24840194,0x75200077,0x96340212,0x5eac0154}},	//   _aamm_, ínzo, їнец, টোরে, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2484002e,0x9878008f,0xc950010f,0x24580006}},	//   _camm_, _פאָט, _אמט_, жаць_, 
   {{0x2485a41a,0x88980302,0x241802bf,0x159c0150}},	//   _damm_, _הברי, цією_, _ءﺳﺎﺑ, 
   {{0x7c3803f2,0x00000000,0x00000000,0x00000000}},	//   ðurj, --, --, --, 
   {{0x2484007f,0x00000000,0x00000000,0x00000000}},	//   _famm_, --, --, --, 
   {{0x248405c7,0x92cc0183,0x00000000,0x00000000}},	//   _gamm_, ৰতে_, --, --, 
   {{0x20c80137,0x2f0001d5,0x00000000,0x00000000}},	//   تبوي_, мжиҳ, --, --, 
   {{0x24850d57,0xddd80010,0x0e6400db,0xc32000cc}},	//   _zamm_, _savš, чкон, _নিচি_, 
   {{0x2a79a41b,0xddd80219,0x00000000,0x00000000}},	//   verb_, _pavš, --, --, 
   {{0x7cfc02d5,0x2a780730,0x01f80375,0x24840327}},	//   _kūry, werb_, _הפעל, _xamm_, 
   {{0x2a780427,0xce9402e8,0x00000000,0x00000000}},	//   terb_, _надъ, --, --, 
   {{0x68500020,0xdd0000da,0x1e8402bf,0x98a000b8}},	//   ንዱስት, ītāj, _олім, _rthā_, 
   {{0xec3401d5,0x98a0002b,0xda780006,0x80ac0154}},	//   _قوغگ, _sthā_, цяў_, টফর্, 
   {{0xb879a41c,0xc8c401ad,0x87240305,0x2a780200}},	//   _ajíb, रोंट, змаж, serb_, 
   {{0x24840327,0xfafc0240,0x464801c6,0x2a780f85}},	// [2d160] _ramm_, mtën_, йзан_, perb_, 
   {{0x2a8c016b,0x2485a41d,0xf1d85096,0xfafc036e}},	//   kɔbɔ_, _samm_, यपान, ltën_, 
   {{0xa494168d,0xc515178c,0x2484020b,0x61e403e0}},	//   ویست, سبات, _pamm_, ğilk, 
   {{0x7cfc0024,0xfafc0240,0x92cc03d4,0xf3f400fe}},	//   _būry, ntën_, ৰতো_, েশনৰ_, 
   {{0x24840489,0xe28478d8,0x66c05f47,0x00000000}},	//   _vamm_, мған, _rökf, --, 
   {{0x66c0049f,0x48f40316,0xd36c1e4a,0xfafc036e}},	//   _sökf, ्षको_, شۇم_, htën_, 
   {{0x248403bd,0x7c382242,0x38680597,0xfafc02d3}},	//   _tamm_, ðurk, _éirí_, ktën_, 
   {{0xfafc044e,0x5f95a41e,0xdcf80055,0x00000000}},	//   jtën_, диит, _osvā, --, 
   {{0x6e4c0092,0x03a800cc,0xc10400e5,0x00000000}},	//   _በአጋጣ, _খেৰণ, _ہوئي, --, 
   {{0x7de40220,0x437401f0,0x00000000,0x00000000}},	//   зімд, _муҷт, --, --, 
   {{0x44253ef8,0xfafc02d3,0xd048016b,0xdcf8002b}},	//   oco_, ftën_, nneɛ, _asvā, 
   {{0x44244219,0x6f000175,0x30e401ec,0xb5f800df}},	//   nco_, _ehnc, _есің, מליכ, 
   {{0xaf040502,0x66c10d98,0x60c00477,0xdd90215c}},	//   تقیم_, _kökd, mhmm, روڭ_, 
   {{0xfafc0200,0x00000000,0x00000000,0x00000000}},	//   atën_, --, --, --, 
   {{0x4425a41f,0x63a401f4,0x00000000,0x00000000}},	//   kco_, äinj, --, --, 
   {{0x44245a54,0xf1bc02fb,0x9b580124,0x224c00de}},	//   jco_, ýšil_, _диит_, _lddk_, 
   {{0x44254bf4,0x571800d4,0x69d802d2,0x00000000}},	// [2d170] dco_, іжжя_, _þven, --, 
   {{0x4425a420,0xb8646646,0x78bc036e,0x569400c7}},	//   eco_, _کادو, shqv, ьазт, 
   {{0x442402ce,0x7cfc0882,0xa2c00303,0x00000000}},	//   fco_, _sūry, वसन्, --, 
   {{0x09c40729,0x7c3c025c,0x7c3801a8,0x7cfc002b}},	//   _শুকা, _jeqr, ðurh, _pūry, 
   {{0x7e780857,0x7c3c025c,0x66c0010b,0x224c03e0}},	//   ketp, _meqr, _bökd, _bddk_, 
   {{0x4425a421,0x66c001e3,0x00000000,0x00000000}},	//   aco_, _rökg, --, --, 
   {{0x10a5a422,0x44242787,0x66c0010e,0xfafc036e}},	//   дийн, bco_, _dökd, ytën_, 
   {{0x4425a423,0x8fd00b8d,0x855401d9,0xff08037e}},	//   cco_, кәлә, _زیٖر_, _rpmの, 
   {{0x5fd4005b,0xfe6c0133,0xb600032e,0x00000000}},	//   ецэф, ڤگه_, _óáby, --, 
   {{0xb8fc0867,0x66c000ee,0xda1829c8,0x7e780254}},	//   _སམ_, _gökd, _दलगत_, getp, 
   {{0x7c3c0477,0x00000000,0x00000000,0x00000000}},	//   _beqr, --, --, --, 
   {{0xa3b800dd,0x00000000,0x00000000,0x00000000}},	//   _باہر_, --, --, --, 
   {{0xfafc02d3,0x7e780784,0xa2d401ec,0x2ab40037}},	//   rtën_, betp, _تيەت, _häbi_, 
   {{0x4425a424,0x66c1a425,0xfafc02d3,0xefbc0020}},	//   zco_, _köke, stën_, ድነው_, 
   {{0x4c6801c6,0x5974fb04,0x00000000,0x00000000}},	//   _дийн_, ныту, --, --, 
   {{0x44240429,0x63a4023a,0x2cb80327,0x66c1a426}},	//   xco_, äink, _བཞིབ, _möke, 
   {{0x2ab4033d,0xf741a427,0x61e403ee,0x66c00fe7}},	// [2d180] _läbi_, кето, ğili, _löke, 
   {{0x6b85a428,0x61e59d31,0xba740c50,0x44246b95}},	//   _isig, şili, _قاپت, wco_, 
   {{0x75d072ca,0xf1c00006,0x090533d4,0x2ab40166}},	//   نيكا, nešė_, _опон, _näbi_, 
   {{0x4424057f,0x6b85a429,0x66c006be,0x00000000}},	//   uco_, _ksig, _sökd, --, 
   {{0x7c381bb0,0x6b84009a,0x7b08025c,0x42e8717e}},	//   ðuri, _jsig, _iżur, омдо_, 
   {{0x4425a42a,0x6b8401f7,0x2ab4013d,0x66c00a43}},	//   sco_, _msig, _bäbi_, _böke, 
   {{0x2724006a,0x4425a42b,0x00000000,0x00000000}},	//   _hön_, pco_, --, --, 
   {{0x6b8404b9,0x27255669,0x7b080135,0x2ab40432}},	//   _osig, _kön_, _jżur, _däbi_, 
   {{0x6b85a42c,0x2725a42d,0x69d80024,0x644000e2}},	//   _nsig, _jön_, _žvel, _iemi, 
   {{0x6441a42e,0x73300131,0x7c3c047e,0xbd680414}},	//   _hemi, _شىما, _seqr, орме_, 
   {{0x6b85a42f,0x7e782b92,0x62880649,0x2724049f}},	//   _asig, retp, _iado, _lön_, 
   {{0x6441a430,0x6289a431,0x7e79a432,0x27240112}},	//   _jemi, _hado, setp, _oön_, 
   {{0x6441a433,0x6289a434,0x6b8401d3,0x63a4005b}},	//   _memi, _kado, _csig, äinh, 
   {{0x644048b5,0xdd91a435,0x6289a436,0x7c3c0455}},	//   _lemi, _موت_, _jado, _weqr, 
   {{0xaf0400c6,0x66c00724,0x7c3c025c,0x67240327}},	//   _تقوم_, _xöke, _teqr, eqij, 
   {{0x27257234,0x6b840175,0x3eac00e2,0xab64025c}},	//   _bön_, _fsig, žotā_, _żżej, 
   {{0x62880156,0x569496da,0x00000000,0x00000000}},	// [2d190] _oado, наат, --, --, 
   {{0x27244953,0x6440bfc1,0x00000000,0x00000000}},	//   _dön_, _aemi, --, --, 
   {{0x54545847,0xb0cc01ad,0x6b8401d3,0xdce803e3}},	//   евет, तोडग, _zsig, lxdı, 
   {{0x6441a437,0x62880248,0x66c001e6,0x6b843c75}},	//   _cemi, _aado, _röke, _ysig, 
   {{0x66c004f3,0xf8bc0570,0x272456f8,0xbefc0073}},	//   _söke, _ilé_, _gön_, _उठून_, 
   {{0x6289a438,0xb7b800e4,0x6441a439,0x661c00b5}},	//   _cado, _agãg, _eemi, _ggrk, 
   {{0x6289a43a,0x50b407dd,0xf8bc03d1,0xfafc036e}},	//   _dado, еспу, _klé_, jtëm_, 
   {{0x6441a43b,0x6289a43c,0x2725a43d,0x66c02e11}},	//   _gemi, _eado, _yön_, _gökb, 
   {{0x6289a43e,0xe3ac01ec,0x00000000,0x00000000}},	//   _fado, _тұ_, --, --, 
   {{0x6441a43f,0x6289a440,0x66c1a441,0x8e600092}},	//   _zemi, _gado, _töke, _ጉዳያቸ, 
   {{0x8d75a442,0x6b841418,0x3f8001a8,0xab6400d1}},	//   رادا, _ssig, ækur_, ھۇدى, 
   {{0x6b8405e4,0x64400077,0xd054013f,0xab640131}},	//   _psig, _xemi, _ɔbɛs, نۇبى, 
   {{0x6289a443,0x6c040107,0x00000000,0x00000000}},	//   _yado, ъҷиз, --, --, 
   {{0xc3306da4,0xf8bc0ca8,0xdbcc0579,0x272401e3}},	//   רום_, _alé_, róðr, _rön_, 
   {{0x2724049f,0xf8bda444,0x89f800e5,0x00000000}},	//   _sön_, _blé_, سٹرز_, --, 
   {{0xf8bda445,0x6b85a446,0x00000000,0x00000000}},	//   _clé_, _tsig, --, --, 
   {{0x6b84337a,0xd244e549,0x64400d7f,0xc7643b5f}},	// [2d1a0] _usig, _پچ_, _remi, عارى, 
   {{0xf8bc9399,0x66c001e3,0x272408a5,0x00000000}},	//   _elé_, _sökb, _vön_, --, 
   {{0x644037bd,0x62888b8c,0x491802ab,0x98a4b811}},	//   _pemi, _rado, _मंटो_, ūlā_, 
   {{0x6289a447,0x44f40dc4,0xf8bc03d5,0x1cb40327}},	//   _sado, رساز, _glé_, ཞིག_, 
   {{0x6289a448,0x64404ee1,0x6724dc95,0xb6040064}},	//   _pado, _vemi, qqij, _alšė, 
   {{0x6289a449,0xf8bc2b57,0x00000000,0x00000000}},	//   _qado, _zlé_, --, --, 
   {{0x6441a44a,0x6289a44b,0x69d80006,0x33f0013d}},	//   _temi, _vado, _žvej, кчәс, 
   {{0x6289a44c,0xd5b80953,0x25080101,0x00000000}},	//   _wado, _ўсё_, _آرسی_, --, 
   {{0xdfd0a5af,0x23b801b9,0x42c801d5,0x66c00205}},	//   شيد_, _تگاب_, _еган_, _gökc, 
   {{0x6288020c,0x00000000,0x00000000,0x00000000}},	//   _uado, --, --, --, 
   {{0x717000e3,0xdb1c00e5,0x00000000,0x00000000}},	//   _مهلا, dzsá, --, --, 
   {{0xb87801e1,0x290d0baf,0x6da001d5,0x50b400d8}},	//   _ajín, ïdal_, چمیم, _исчу, 
   {{0x2ab40037,0x00000000,0x00000000,0x00000000}},	//   _läbu_, --, --, --, 
   {{0xddc80153,0xdb1c00e5,0x00000000,0x00000000}},	//   medž, gzsá, --, --, 
   {{0xf8bc0597,0xddc9a44d,0x00000000,0x00000000}},	//   _plé_, ledž, --, --, 
   {{0xd78800aa,0x3f84007f,0x61e80175,0x779000f2}},	//   ونزو_, _ksou_, _mxdl, هیجا, 
   {{0x3f8402f8,0xddc8ebf6,0xf8bc007f,0x56f40120}},	// [2d1b0] _jsou_, nedž, _vlé_, впаѓ, 
   {{0x35e46c48,0x1a6401ed,0x3f84007f,0x00000000}},	//   нцев, _جیسی_, _msou_, --, 
   {{0x7c3805d1,0x3eac054e,0x00000000,0x00000000}},	//   ıurf, _moft_, --, --, 
   {{0x3f8402f0,0x533424fc,0x7d0c02d0,0xf8bc01e1}},	//   _osou_, ведт, nmcs, _ulé_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x78ac0051,0xddc800ef,0x00000000,0x00000000}},	//   _hocv, dedž, --, --, 
   {{0x3f85a44e,0xa92802f0,0x00000000,0x00000000}},	//   _asou_, maží, --, --, 
   {{0x409004a9,0xa99c0a1e,0xddc80cf4,0xf8b0012d}},	//   للىر, לבור, fedž, ीसिय, 
   {{0x4fe80184,0x2481a44f,0x4f0800db,0x66c001e3}},	//   ьмин_, õime_, мнин_, _höka, 
   {{0x3eac039a,0xa3d4209b,0xa9280419,0x918000d1}},	//   _coft_, _соуч, naží, _نۇتۇ, 
   {{0x3f8404d1,0xfe6c0517,0x3eac42a7,0xc690011a}},	//   _esou_, تگن_, _doft_, באי_, 
   {{0xe984020a,0x66c00166,0x0cc00011,0x826000f7}},	//   ҳқон, _möka, োক্ত, _مۇۇن, 
   {{0x8d75a450,0x66c001e3,0x3b800006,0x601401ee}},	//   راگا, _löka, аляг, _йєшє, 
   {{0x3eac0218,0x37c40183,0x00000000,0x00000000}},	//   _goft_, লপাৰ, --, --, 
   {{0xfaa1a451,0x78ada452,0xdb1c00e5,0x451400fe}},	//   шаро, _bocv, rzsá, াৱিক_, 
   {{0x2d85a453,0xdb1c00e5,0x7c38148b,0x00000000}},	//   _isne_, szsá, ðurt, --, 
   {{0x78ac01f4,0x00000000,0x00000000,0x00000000}},	// [2d1c0] _docv, --, --, --, 
   {{0x36c0008e,0x3ab0728c,0xaca801ed,0x66c0007c}},	//   абуг, _кәст, _آپکے_, _böka, 
   {{0x05643b78,0xdb1c01d3,0x044402e8,0xdb1401bf}},	//   твен, özöt, веен, åbåd, 
   {{0x2b4000ca,0x55f405f5,0xbefc0118,0x74a80150}},	//   _kwic_, учуу, _उठ्न_, мсің_, 
   {{0x37e001b9,0xe37463e1,0x82a40395,0x19c4014b}},	//   _вояг, уллы, кадж, _абӯм, 
   {{0xddc80024,0xaac80073,0x91ac03d4,0xbb340150}},	//   vedž, रफटक, _কেইখ, _ﻗﺘﻴ_, 
   {{0x35a1a454,0x66c00790,0x00000000,0x00000000}},	//   _карг, _göka, --, --, 
   {{0x3eada455,0xddc84a38,0xd3a400d1,0xa52401ee}},	//   _soft_, tedž, тләқ, _аяҡһ, 
   {{0x3eac0393,0x00000000,0x00000000,0x00000000}},	//   _poft_, --, --, --, 
   {{0xb87802d1,0xddc9a456,0x3eac0240,0x30100209}},	//   _ajíl, redž, _qoft_, шдыр, 
   {{0x61e403ee,0xfafc036e,0x1cd81f39,0x00000000}},	//   ğils, stëk_, едны_, --, 
   {{0xdd940184,0x3f840561,0xcb1c0c70,0x00000000}},	//   _ҡалы, _tsou_, पदंड_, --, 
   {{0x3f84d02b,0x2d85a457,0x3eacbc85,0xde580111}},	//   _usou_, _esne_, _toft_, _залі_, 
   {{0x78ac0010,0x6d440327,0xf410011a,0x00000000}},	//   _socv, ġjar, יפר_, --, 
   {{0x7c3819cf,0xddc8033f,0xed8401ee,0x00000000}},	//   ðurs, nedż, _асык_, --, 
   {{0x66c00267,0x7c6400f2,0x629c02d2,0x00000000}},	//   _röka, _شابل, _órof, --, 
   {{0x66c1a458,0x28f8034b,0x00000000,0x00000000}},	// [2d1d0] _söka, теть_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x5f300023,0x94780354,0x58d41d39,0xa9280419}},	//   _ተኣኪቦ, еслу_, _бонт, raží, 
   {{0xbb3c1884,0x00000000,0x00000000,0x00000000}},	//   ﻟﮕﻪ_, --, --, --, 
   {{0xf364fc0f,0xa8a40024,0x81b4010b,0x00000000}},	//   ттен, _трэк, ңңур_, --, 
   {{0x91e5a459,0x54540116,0x26100a59,0x00000000}},	//   лоле, _әват, थेही_, --, 
   {{0x74680120,0xd1746518,0x66c00205,0x00000000}},	//   _орав_, уылы, _kökn, --, 
   {{0x25bc00b5,0xdb1c0112,0x00000000,0x00000000}},	//   øvle_, lzsä, --, --, 
   {{0x8c440032,0x63a402f6,0xc4d00375,0xddc802f0}},	//   һене, äint, _הגן_, ladň, 
   {{0x0d8401c0,0xafe001b9,0xc7b00375,0x14b80073}},	//   глон, лоқл, צבי_, _आवडण, 
   {{0x8c442cd4,0xb8780241,0xddc80118,0x00000000}},	//   лене, _ajím, nadň, --, 
   {{0x61fc1445,0xfafc0036,0x60b8030d,0x69d802d2}},	//   _ørla, huëd_, _иччĕ, _þvei, 
   {{0x20240038,0xfc4409ff,0x00000000,0x00000000}},	//   ásiť_, ñías_, --, --, 
   {{0x3ea001c6,0x7c38041e,0x00000000,0x00000000}},	//   _гишг, ðurr, --, --, 
   {{0x2d84098d,0x7c2c01e7,0x3b046c00,0x00000000}},	//   _usne_, éirí, уеро_, --, 
   {{0x09e4036b,0x61580023,0x00000000,0x00000000}},	//   воҳн, _ከይበጽ, --, --, 
   {{0x480579e7,0x2ca001ab,0x2b400142,0x2d000073}},	// [2d1e0] упав, _inid_, _uwic_, ईतील_, 
   {{0xb6640022,0x00000000,0x00000000,0x00000000}},	//   лиуз_, --, --, --, 
   {{0x82340075,0x37e001d5,0x96f80006,0x00000000}},	//   ۇرغا, _ғорг, тэту_, --, 
   {{0x234804d3,0x66c0496e,0x2f080174,0x00000000}},	//   نستی_, _gökn, løgd_, --, 
   {{0x68e59317,0x29000009,0x00000000,0x00000000}},	//   mnid, mlia_, --, --, 
   {{0x2901a45a,0xe1340124,0x88c4015b,0x37e006ed}},	//   llia_, анкы, _এদিক, _ѓорг, 
   {{0x2901a45b,0x3f980069,0x68e5a45c,0x2ca06f66}},	//   olia_, _ōpu_, onid, _onid_, 
   {{0x1cb40156,0xb87801e1,0x9f543acc,0x2f0805ac}},	//   ཞིབ_, _ajíj, авич, høgd_, 
   {{0x68e400a9,0xaf3004fb,0x63a40158,0x387c00e4}},	//   inid, یریت, åind, _ñure_, 
   {{0x68e40a40,0x2ca00175,0xfbcc03d4,0x00000000}},	//   hnid, _anid_, ৰথমত, --, 
   {{0x2901a45d,0x66c00205,0xc05803de,0x00000000}},	//   klia_, _löko, _зіл_, --, 
   {{0x2ca00334,0x68e40113,0x25dc007d,0x3b640395}},	//   _cnid_, jnid, _गइनी_, лъгв, 
   {{0x290096f1,0x66c00267,0x68e4d6ff,0x00000000}},	//   dlia_, _rökn, dnid, --, 
   {{0xdd95a45e,0x66c004f3,0x290016b8,0x2ca1a45f}},	//   _вакы, _sökn, elia_, _enid_, 
   {{0x68e400a9,0x29000421,0x7b640220,0x7e6802d0}},	//   fnid, flia_, _өтпе, _icfp, 
   {{0x2901a460,0x68e4060a,0x2ca00728,0x3c440064}},	//   glia_, gnid, _gnid_, _сэкв, 
   {{0xe8940b32,0x657c0076,0xbb1800d2,0x96f80261}},	// [2d1f0] щать, _aprh, lwîm, веат_, 
   {{0x2901a461,0x68e5a462,0x7d1c0477,0xa81400ee}},	//   alia_, anid, _hiqs, сдуш, 
   {{0x2901a463,0x68e40067,0x00000000,0x00000000}},	//   blia_, bnid, --, --, 
   {{0x2901a464,0xddc801f1,0x7d1c0009,0xa9c40137}},	//   clia_, radň, _jiqs, _ысык, 
   {{0x03b40046,0x66c16eeb,0xddd802fb,0x53a42002}},	//   ақты_, _kökl, _navž, ралб, 
   {{0x7d1c3cf6,0x20540032,0x66c001a8,0x00000000}},	//   _liqs, ҡтыр, _jökl, --, 
   {{0x63a40108,0x00000000,0x00000000,0x00000000}},	//   äinr, --, --, --, 
   {{0xd39401ee,0x00000000,0x00000000,0x00000000}},	//   _вәкә_, --, --, --, 
   {{0x09d00574,0x4f240cfc,0xb87801e1,0x2f080158}},	//   _सध्य, јдоб, _ajík, høge_, 
   {{0x68e4dea4,0x00000000,0x00000000,0x00000000}},	//   znid, --, --, --, 
   {{0x68e4036b,0x7d1c014f,0x63a400df,0xc6900677}},	//   ynid, _biqs, ĥine, קאט_, 
   {{0x386800ec,0x7645a465,0x7c3803f2,0xddc800e5}},	//   _nccr_, _lejy, ðurp, gedű, 
   {{0x3ce80122,0x7d1c0548,0x66c00139,0x75241315}},	//   _živé_, _diqs, _bökl, _lujz, 
   {{0x7d1c0399,0xfc0002bf,0x7c2c0076,0x5ff4004e}},	//   _eiqs, іпро, accr, _узчу, 
   {{0x386801ee,0x66c04c98,0x38c8036b,0x290001ab}},	//   _bccr_, _söko, چاقی_, tlia_, 
   {{0x29001140,0x68e5a466,0x2ca1a467,0x00000000}},	//   ulia_, unid, _unid_, --, 
   {{0x6d400810,0x4a741142,0x07a5a468,0xca74013d}},	// [2d200] _hwna, _кынт, шаан, _куны, 
   {{0x68e5a469,0xdcf80316,0x66c041b5,0x290000d0}},	//   snid, _osvě, _gökl, slia_, 
   {{0x4584011c,0x00000000,0x00000000,0x00000000}},	//   ргев, --, --, --, 
   {{0x7d1c0548,0xf500013e,0x6d41a46a,0x00000000}},	//   _xiqs, озхо, _mwna, --, 
   {{0x66c1a46b,0x82a40137,0x62354f72,0x22580108}},	//   _hökm, ишке, белу, гилы_, 
   {{0xb8780248,0x6d400c8c,0x75240175,0xf74008da}},	//   _ajíh, _owna, _fujz, _феро, 
   {{0x26d800d7,0xfafc0200,0x00000000,0x00000000}},	//   _imro_, mtët_, --, --, 
   {{0x66c00139,0xfafc0200,0x00000000,0x00000000}},	//   _mökm, ltët_, --, --, 
   {{0x6d400054,0x75240218,0x7d1c0986,0x45d4010b}},	//   _awna, _zujz, _riqs, _соңс, 
   {{0xfafc044e,0x7d1c5431,0x33540137,0x00000000}},	//   ntët_, _siqs, _түшө_, --, 
   {{0xf3f00327,0x9d180107,0x66c036b2,0xfafc0200}},	//   _བཙོད_, лоот_, _rökl, itët_, 
   {{0x7eb400c6,0xddd80010,0xfafc0200,0x00000000}},	//   _câpr, _tavž, htët_, --, 
   {{0x6d4014dc,0xad0801c6,0xfafc036e,0x7c2c0327}},	//   _ewna, рхэж_, ktët_, rccr, 
   {{0xf4680020,0x66c0010e,0x6d400142,0xfafc0240}},	//   ተሳሰብ_, _bökm, _fwna, jtët_, 
   {{0x1fe800bd,0x764402bd,0x6d400368,0x7d1c02d1}},	//   _পরিস, _rejy, _gwna, _tiqs, 
   {{0xa8a49bc9,0x3154008f,0x66c02ba3,0xdbf00118}},	//   орук, יילן_, _dökm, _hříc, 
   {{0x2f08037e,0xfc3da46c,0xa7b9a46d,0x66c05c01}},	// [2d210] søge_, mbí_, алту_, _tökl, 
   {{0x7bcc0007,0x00000000,0x00000000,0x00000000}},	//   mzcu, --, --, --, 
   {{0x66c003e0,0x758002cb,0x4a74009f,0x00000000}},	//   _gökm, غیرم, _اُپر, --, 
   {{0xfc3da46e,0xfafc0023,0x26d8022e,0x03e000cc}},	//   nbí_, atët_, _emro_, _বৰেণ, 
   {{0x76440211,0x7bcc0097,0x72a000d1,0x63a4005b}},	//   _tejy, nzcu, يەرن, äinp, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe2a81ec7,0x1fd400fe,0xfafc036e,0xb1e00022}},	//   شاون_, _হুলস, ltës_, цәақ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x0eb94959,0xfafc0240,0xb2b00166,0xdcf80171}},	//   гуны_, ntës_, _мәкъ, _ervī, 
   {{0x4d64cadc,0x0ea80108,0x00000000,0x00000000}},	//   бков, укой_, --, --, 
   {{0xa29402bf,0x66c0010e,0x02f8010f,0xfafc0200}},	//   _фахі, _bökj, _עלעמ, htës_, 
   {{0xe1f04336,0xfc3c004e,0x66c001e3,0x00000000}},	//   _غسل_, gbí_, _rökm, --, 
   {{0x66c1a46f,0xfafc02d3,0x7c380784,0xc4d0010f}},	//   _sökm, jtës_, ñura, לגט_, 
   {{0x9b0000c7,0xadc001af,0x00000000,0x00000000}},	//   мҷыд, _малһ, --, --, 
   {{0xcd3496e0,0xfc3da470,0x46e8036b,0x00000000}},	//   _ارتب, bbí_, ҳдан_, --, 
   {{0xfafc044e,0x1fe80183,0xb304031c,0x66c0010e}},	//   ftës_, _পৰিস, _ཆེའང_, _gökj, 
   {{0x46e9253e,0x03e000bd,0xfafc0036,0x00000000}},	// [2d220] гдан_, _বর্ণ, drëf_, --, 
   {{0x66c1a471,0x85040133,0x06486640,0x89f81291}},	//   _tökm, ڕوان, الاً_, _معجز_, 
   {{0xfafc0240,0xf3f0031c,0x26d9a472,0x66c1a473}},	//   rtët_, _བཙུད_, _vmro_, _hökk, 
   {{0xfafc044e,0x95980228,0x66c00108,0xb978011a}},	//   stët_, штуу_, _kökk, _גנטי, 
   {{0xb8780241,0x87b80262,0xc794013d,0x14b8085c}},	//   _ajíw, _сунт_, _урны, _आवरण, 
   {{0x26d80bb8,0x66c0023a,0xfafc0023,0xc6d0030d}},	//   _umro_, _mökk, ltër_, _хιок, 
   {{0xd258063b,0xfc3c012c,0x66c0032e,0xf1a001c6}},	//   рці_, ybí_, _lökk, зрын, 
   {{0x03255bc3,0x3998008f,0x58fc0327,0xfafc00e8}},	//   _гдан, ריקד, _དེབས_, ntër_, 
   {{0x5f9430e1,0xd9a406ab,0x60c1a474,0xb87801e1}},	//   ципт, _ऑप्ट, rkmm, _ejíw, 
   {{0x5d542119,0x8cd401ad,0xddd8031c,0x9ed80120}},	//   окот, मोसो, _tavż, рмот_, 
   {{0xfafce64a,0xdcf80055,0x00000000,0x00000000}},	//   ktër_, _urvī, --, --, 
   {{0x7bcc0789,0x66c1a475,0xddd80064,0xfafc0200}},	//   tzcu, _bökk, _savų, ytës_, 
   {{0x06f83b90,0xfc3da476,0xdbf001ef,0x00000000}},	//   ्ताव_, rbí_, _tříc, --, 
   {{0x3da49dc2,0x66c001a8,0x00000000,0x00000000}},	//   _гриб, _dökk, --, --, 
   {{0xf8bc07ea,0x69d80427,0x38c40395,0x00000000}},	//   _liée_, _žver, бщав, --, 
   {{0x52c40b7c,0x6c8400db,0xa92801ec,0x00000000}},	//   _वत्स, _فلىم, сіре_, --, 
   {{0x32c802bf,0x66c00790,0xe7840117,0x2f080162}},	// [2d230] _høye_, _gökk, зухо, løga_, 
   {{0x03e00c58,0xfafc0023,0xb5a40150,0x00000000}},	//   _বৰ্ণ, rtës_, йрей, --, 
   {{0xfafc02d3,0x986400dd,0xf608fe13,0x00000000}},	//   stës_, _ویسے_, ухай_, --, 
   {{0x32c80158,0xe6102c10,0x66c05fa7,0x00000000}},	//   _møye_, رشل_, _yökk, --, 
   {{0x32c805ac,0x69d80008,0x98a0002b,0x81b4009e}},	//   _løye_, _þver, _guhā_, _চেল_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x32c8168c,0x63a401e4,0xc690010f,0x2be02ef1}},	//   _nøye_, ĥina, _קאל_, _पेना, 
   {{0x67540244,0x00000000,0x00000000,0x00000000}},	//   _بخێر, --, --, --, 
   {{0xd3e405d9,0xe81c0037,0xff640023,0x00000000}},	//   _بڻاي, पइया_, _ተቐይሩ_, --, 
   {{0xd2502e2e,0x32c8143a,0xb00000b8,0x66c03720}},	//   _آنا_, _bøye_, _niḥk, _rökk, 
   {{0x31c40640,0x66c03720,0x00000000,0x00000000}},	//   _усав, _sökk, --, --, 
   {{0x236005ce,0x62c40150,0xd01005af,0x66c1a477}},	//   šije_, _وزەك, _قلا_, _pökk, 
   {{0xe7e40eac,0x290c00c0,0x00000000,0x00000000}},	//   _মর্য, _ėda_, --, --, 
   {{0x66c0083c,0x32c803cd,0xc330011a,0x00000000}},	//   _gökh, _føye_, ווך_, --, 
   {{0x316405d5,0xbf1096c6,0x48b4234c,0x00000000}},	//   nunz_, _تووب, ощат, --, 
   {{0x66c1a478,0x00000000,0x00000000,0x00000000}},	//   _tökk, --, --, --, 
   {{0x4649a479,0xfafc02d3,0x316407de,0x00000000}},	// [2d240] изан_, rtër_, hunz_, --, 
   {{0xfafc044e,0x8934007b,0xb4a8032e,0x2be04433}},	//   stër_, _وعجا, _áþjó, _पेया, 
   {{0x290c067c,0xfafc002e,0x8428a90c,0x08f8007b}},	//   ïdas_, ptër_, ажев_, _نرحب_, 
   {{0xc7a5a47a,0x66c0e9b1,0x316404cc,0x07a46de9}},	//   _димк, _möki, dunz_, _дамн, 
   {{0x3f80031c,0x00000000,0x00000000,0x00000000}},	//   ħkuk_, --, --, --, 
   {{0x31640472,0x62340e92,0x4acc0073,0xa19400db}},	//   funz_, чеку, होचव, закч, 
   {{0x66c0032e,0x71a000ea,0x00000000,0x00000000}},	//   _rökh, дајз, --, --, 
   {{0x32c803cd,0x66c0007c,0x00000000,0x00000000}},	//   _røye_, _sökh, --, --, 
   {{0x32c80158,0xbe840114,0x00000000,0x00000000}},	//   _søye_, оћни, --, --, 
   {{0x31640036,0x66c001e3,0x918400cf,0x00000000}},	//   bunz_, _böki, تجۇم, --, 
   {{0x1df80c98,0xdcf80171,0x1d3400d4,0x00000000}},	//   сены_, _apvā, яння, --, 
   {{0xd7240c58,0xff080154,0x1ae40150,0x00000000}},	//   মীয়া_, রদেশ_, _ﺍﻳﺘﻮ, --, 
   {{0xdb1da47b,0x69d80427,0x70500214,0x212c036e}},	//   lysé, _žvep, _آنها, _hudh_, 
   {{0x32c803cd,0xe7e403d4,0xde440092,0xf9901291}},	//   _tøye_, _মৰ্য, _የበኩል, وبز_, 
   {{0xdb1c00dd,0xf849a47c,0x645c00b0,0x66c000a2}},	//   nysé, ичай_, _ērin, _göki, 
   {{0x212c058a,0x00000000,0x00000000,0x00000000}},	//   _mudh_, --, --, --, 
   {{0xe730117d,0x2ec001c6,0x00000000,0x00000000}},	// [2d250] نصل_, _хөөм, --, --, 
   {{0x58fc0489,0xfbdc145e,0xdb1c00e4,0x00000000}},	//   _དེམས_, gbêe_, kysé, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x224c005a,0xb86405af,0x31640007,0x00000000}},	//   _aedk_, _بادو, vunz_, --, 
   {{0x09bc031c,0x2f082ab7,0x10a43ad0,0xd4500055}},	//   _ཁཎྜ_, døgn_, җипн, _āśīr_, 
   {{0x212da47d,0x316404cc,0x00000000,0x00000000}},	//   _budh_, tunz_, --, --, 
   {{0xdb1c01ed,0x00000000,0x00000000,0x00000000}},	//   gysé, --, --, --, 
   {{0x316405d5,0x38780175,0x2f0803b2,0x2ec000cd}},	//   runz_, nfqr_, gøgn_, षस्त, 
   {{0xb4e405ba,0x34c40c2e,0x316405d5,0x842000db}},	//   यची_, लसीद, sunz_, _كۉمن, 
   {{0x4d642d57,0xf1a45211,0x00000000,0x00000000}},	//   пков, _мрен, --, --, 
   {{0xb92401f2,0x00000000,0x00000000,0x00000000}},	//   retọ_, --, --, --, 
   {{0xdb0c01f1,0x51840131,0x00000000,0x00000000}},	//   ľkýc, _муҗа, --, --, 
   {{0x53bc29d9,0xdb0c0216,0x4fa408ca,0x00000000}},	//   ्निश, žkýc, _хилв, --, 
   {{0x8d55a47e,0x25dc007d,0x9f040228,0x09c00154}},	//   _етич, _गइली_, _قونو, োপসা, 
   {{0x59740046,0xfafc2a4e,0xb8780241,0x00000000}},	//   мыту, muël_, _omíd, --, 
   {{0x53bc07b7,0xe3bc00cc,0x00000000,0x00000000}},	//   ्नाश, _আইসব, --, --, 
   {{0xb8780248,0x00000000,0x00000000,0x00000000}},	// [2d260] _ajís, --, --, --, 
   {{0x6b85a47f,0x7bd8011a,0x26dc00e4,0x83840124}},	//   _ipig, _לקפו, òvo_, ҧыле, 
   {{0x3ab802e4,0x7ab80375,0xc48400fd,0xe97407d2}},	//   _המינ, _הציו, злек, _تۇزد, 
   {{0x61fc143a,0x212da480,0x8d900092,0xdb1c0022}},	//   _ørli, _rudh_, _ቆይተው_, vysé, 
   {{0xa294beb0,0x212c020b,0xaab000dc,0x63a40115}},	//   далі, _sudh_, ञापक, ĥino, 
   {{0x6b8504c4,0xdb1c00e4,0xdec80023,0xdb240162}},	//   _mpig, tysé, ሽቱን_, ðsør, 
   {{0xc8fc02f5,0x224c0158,0x46140150,0xa13c00e2}},	//   ংগীত_, _vedk_, _ءوزر, _orķe, 
   {{0xb9f4069c,0x6b84bf3f,0x25580100,0xdb1c00e4}},	//   _ማይ_, _opig, mčl_, rysé, 
   {{0x2558007f,0xb22000d1,0x3f800129,0xc5bc0154}},	//   lčl_, ммәл, ïku_, _আধিপ, 
   {{0x2f080174,0x00000000,0x00000000,0x00000000}},	//   søgn_, --, --, --, 
   {{0xaab00cba,0x6b8400ec,0xc20802dd,0x629801e4}},	//   ञानक, _apig, _اقان_, mdvo, 
   {{0x6299a481,0x63a08256,0x00000000,0x00000000}},	//   ldvo, _krmn, --, --, 
   {{0x66c003be,0xde581ed2,0x5e5801fe,0x00000000}},	//   _höku, _далі_, _диля_, --, 
   {{0x6299a482,0x66c00008,0x63a001a9,0x7e780175}},	//   ndvo, _köku, _mrmn, qftp, 
   {{0x25dc0574,0x66c001a8,0x1cdc0327,0x62980076}},	//   _गेली_, _jöku, ཡོད_, idvo, 
   {{0xb87801e1,0x255802e2,0x63a003ac,0x395c72f2}},	//   _ajír, dčl_, _ormn, čus_, 
   {{0xf771a483,0x5695a484,0xeaf80133,0x81780150}},	// [2d270] عار_, маат, ترێت_, _ﺤﻴﻔﺔ_, 
   {{0xba4401c0,0x629801f5,0x61e403e0,0x00000000}},	//   _эхий, jdvo, şily, --, 
   {{0x32c80158,0x62980427,0x5fc800bc,0x81c00171}},	//   _nøya_, ddvo, ाईँल, _šēnb, 
   {{0xb4e405ba,0x245879ac,0x62995885,0x00000000}},	//   यचे_, заць_, edvo, --, 
   {{0x63a002c4,0x88980302,0xe78401f0,0x66c008a5}},	//   _crmn, _וברי, _пуро, _rökv, 
   {{0x03a1a485,0x32c80158,0x63a0110c,0x629801f5}},	//   тишо, _bøya_, _drmn, gdvo, 
   {{0x2360038f,0x95c4007b,0xf1a47c76,0xddc80210}},	//   ġija_, _غيره, ярдн, hadł, 
   {{0x5fc8038e,0x23600552,0x203402d3,0xb7b800e4}},	//   ाईंल, šija_, _ኣበርክ, _agãi, 
   {{0x66c001a8,0x00000000,0x00000000,0x00000000}},	//   _vökv, --, --, --, 
   {{0x23840014,0xc3c0010b,0x00000000,0x00000000}},	//   _سٔمِ, _шөхл, --, --, 
   {{0x6b85a486,0x693c07f5,0xcc8848a9,0x8ca8012d}},	//   _spig, _ičeg, обне_, टालो, 
   {{0x81b40eac,0x66c001a8,0x418401d5,0x859800d9}},	//   _চেক_, _hökt, _ютуғ, קשרו, 
   {{0x8fd03e25,0x66c00790,0xdd740345,0xc608012d}},	//   _шәкә, _kökt, وپیک, _वर्य_, 
   {{0x7d0420ef,0x645c00b0,0x255802bd,0x66c001f4}},	//   térê, _ērim, yčl_, _yöku, 
   {{0xcce4009f,0x09e4586a,0x00000000,0x00000000}},	//   _يسعي, фовн, --, --, 
   {{0x62981591,0xb4e40490,0x255802e2,0x00000000}},	//   zdvo, यचो_, včl_, --, 
   {{0x6b85a487,0x4ab804a9,0x48040395,0x00000000}},	// [2d280] _upig, _дуня_, фпав, --, 
   {{0x255802e2,0x66c002d2,0x00000000,0x00000000}},	//   tčl_, _nökt, --, --, 
   {{0x7e7c04f3,0x69c801bf,0x00000000,0x00000000}},	//   _öppe, øded, --, --, 
   {{0xf8bc0036,0xf481a488,0x32c803cd,0x845802dd}},	//   _hién_, вушн, _røya_, ірет_, 
   {{0x2900ead8,0x62980e3c,0x68e5a489,0x66c001a8}},	//   moia_, tdvo, miid, _söku, 
   {{0x2900123c,0x68e5a48a,0x6298017a,0x255802e2}},	//   loia_, liid, udvo, pčl_, 
   {{0x6299a48b,0xf6217118,0x66c00790,0x1fb8012c}},	//   rdvo, _адро, _dökt, ेन्ड, 
   {{0x290018a6,0x68e5a48c,0xa6c0015b,0x79800036}},	//   noia_, niid, _এগিয়, _änwe, 
   {{0x29003957,0x63a00548,0xbe8848a9,0x63a401bf}},	//   ioia_, _urmn, осне_, æind, 
   {{0x29002bae,0x68e5a48d,0x2ab401e6,0x66c1a48e}},	//   hoia_, hiid, _täby_, _töku, 
   {{0x2901a48f,0x68e43110,0x01d8007b,0xc05803de}},	//   koia_, kiid, _بوضع_, _діл_, 
   {{0xbfc406bb,0x66c1a490,0x68e4279a,0x802401d5}},	//   _обек, _köks, jiid, _قرشم, 
   {{0x68e5a491,0xf8bc0407,0x2900009d,0x7118008f}},	//   diid, _bién_, doia_, _וואפ, 
   {{0x3f840270,0x66c0340f,0x63a401f4,0xddc80210}},	//   _ipou_, _möks, äiny, radł, 
   {{0xda0826c0,0x81bc04c5,0x29001140,0x68e4022f}},	//   سيره_, ীপক_, foia_, fiid, 
   {{0x7c841fe2,0x3f84007f,0x68e4102c,0x2901a492}},	//   _цуке, _kpou_, giid, goia_, 
   {{0xb87845a7,0x9714084c,0x00000000,0x00000000}},	// [2d290] _amíc, емац, --, --, 
   {{0x66e4026a,0x68e401ab,0xdb0c0248,0xb4e400cd}},	//   вођа, aiid, _ìkàn, यच्_, 
   {{0xe3b00722,0x2900d829,0x66c00267,0x0af001c6}},	//   یره_, boia_, _rökt, _сүрэ, 
   {{0x809c11b1,0x66c1a493,0x68e40014,0x25bc01e3}},	//   _खोले, _sökt, ciid, ävla_, 
   {{0xe825a494,0x68240354,0x00000000,0x00000000}},	//   _афро, _аьрз, --, --, 
   {{0x2bd0ad78,0x00000000,0x00000000,0x00000000}},	//   हनता, --, --, --, 
   {{0x66c001a8,0x10a4009d,0x00000000,0x00000000}},	//   _vökt, еийн, --, --, 
   {{0x855401d9,0x00000000,0x00000000,0x00000000}},	//   _سیٖر_, --, --, --, 
   {{0x8e7425a1,0x66c1a495,0xc1a4035b,0x10a40166}},	//   нунч, _göks, _ҿыцқ, _җилн, 
   {{0x290001c0,0xd004036b,0x68e4022f,0xe2c800cf}},	//   zoia_, моққ, ziid, _قوقو_, 
   {{0x3f84007f,0x8e09a496,0x68e40083,0x00000000}},	//   _epou_, янов_, yiid, --, 
   {{0xe1d8012c,0x66c0005b,0x645c00e2,0x68e40009}},	//   _भेटघ, _yöks, _ērik, xiid, 
   {{0x2be02cce,0x2901a497,0x68e5a498,0x9f98009b}},	//   _पेशा, voia_, viid, _овцу_, 
   {{0x68e46243,0x8a04010b,0x00000000,0x00000000}},	//   wiid, езге, --, --, 
   {{0x68e5a499,0x13bc0316,0x2901a49a,0x4c68009d}},	//   tiid, ्नुभ, toia_, _еийн_, 
   {{0xba21a49b,0x7d7400c6,0xf8bc0036,0x2bd015c0}},	//   удск, _أمير_, _wién_, हनदा, 
   {{0x68e5a49c,0x29007229,0x2d84020c,0xfafc02d3}},	// [2d2a0] riid, roia_, _hpne_, mrën_, 
   {{0x68e5a49d,0x66c0553f,0x2900009d,0x661802f0}},	//   siid, _röks, soia_, ývko, 
   {{0x29009051,0x44880046,0x66c1a49e,0x68e49abd}},	//   poia_, збен_, _bökr, piid, 
   {{0x68e49f02,0x66c00108,0x8494007b,0xb878013a}},	//   qiid, _pöks, عجائ, _vmíc, 
   {{0xeff41e38,0x7c380309,0xb82400db,0x133800e5}},	//   ጉራዊ_, ñuri, _поюз_, وتوں_, 
   {{0x2d8403d4,0x236009a8,0x4f400092,0x00000000}},	//   _opne_, šijo_, _የሐዋር, --, 
   {{0x6ec0038e,0xb87823ec,0xfafc0240,0x693c013a}},	//   ाउनु, _umíc, krën_, _učed, 
   {{0x2b401710,0xdb1c0118,0x66c1a49f,0x00000000}},	//   _otic_, vysí, _töks, --, 
   {{0x2d84879f,0xfafc0240,0x2b400129,0x2480000d}},	//   _apne_, drën_, _ntic_, õimu_, 
   {{0x3011a4a0,0xfafc0023,0x00000000,0x00000000}},	//   ыдыр, erën_, --, --, 
   {{0x2b400077,0xfafc0240,0x00000000,0x00000000}},	//   _atic_, frën_, --, --, 
   {{0x3f840270,0x00000000,0x00000000,0x00000000}},	//   _tpou_, --, --, --, 
   {{0x3f840270,0xdd91a4a1,0x248406be,0x00000000}},	//   _upou_, _چوت_, _mbmm_, --, 
   {{0x2f940302,0xdd902088,0x7ce801e6,0x2b40045a}},	//   _נכון_, _نوت_, förä, _dtic_, 
   {{0x2b41a4a2,0x2d800240,0xdd9402dd,0xfafc036e}},	//   _etic_, çjet_, _райы, brën_, 
   {{0xfafc0240,0xe8940006,0xac580117,0x00000000}},	//   crën_, лась, _заъф_, --, 
   {{0xe81c069f,0x2b400109,0x67d400f7,0x66c0d802}},	// [2d2b0] पेला_, _gtic_, готу, _rökr, 
   {{0x66c0049f,0x69c801bf,0x00000000,0x00000000}},	//   _sökr, ødec, --, --, 
   {{0xeef4008f,0xaa640eed,0x7ae5a4a3,0xdd201165}},	//   עמבר_, _стык, mijt, půńj, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xaac800bc,0x00000000,0x00000000,0x00000000}},	//   _रकमक, --, --, --, 
   {{0x91e4a76a,0xf8bc74bc,0x68400118,0xb6040064}},	//   коле, _hoé_, rádů, _зябк, 
   {{0xf8bda4a4,0x66f40c5c,0x7468020f,0xca4c0150}},	//   _koé_, _спру, _нрав_, _ﺑﯘﻳﯩ_, 
   {{0x10a5a4a5,0xf8bc04e6,0x7ae5a4a6,0x63ac0118}},	//   тиин, _joé_, hijt, álný, 
   {{0xf8bd074c,0x92940022,0xfafc0200,0xe2000055}},	//   _moé_, _иаац, vrën_, _įųer_, 
   {{0xcb0c0016,0xfbd400bd,0x69d801ed,0x8d75a4a7}},	//   _ۣۜÑ_, সপাত, _üveg, پادا, 
   {{0xfafc02d3,0xf1a409a5,0xd094151e,0x8c449509}},	//   trën_, _яран, _ашлы, кене, 
   {{0x2b400219,0x00000000,0x00000000,0x00000000}},	//   _ptic_, --, --, --, 
   {{0x7ae40023,0xfafc0023,0x799403ac,0x00000000}},	//   fijt, rrën_, _asxw, --, 
   {{0xabc40184,0xb6040153,0x10a4030d,0x00000000}},	//   _ҡайҙ, _košė, _пиçн, --, 
   {{0xfafc0023,0x48e41468,0x76540067,0x690800c7}},	//   prën_, вовв, daxy, kÿet, 
   {{0x1cb008ea,0x201800ac,0xd9e00154,0x00000000}},	//   _ནོར_, ərib_, _মুহম, --, 
   {{0xc05000c8,0x7ae400f3,0x7bb00220,0x69d8025c}},	// [2d2c0] יזן_, bijt, _көру, _żved, 
   {{0x7654058a,0x00000000,0x00000000,0x00000000}},	//   gaxy, --, --, --, 
   {{0xb8780022,0x3568010a,0x00000000,0x00000000}},	//   _imín, çрен_, --, --, 
   {{0x7ebc0118,0x43440006,0xc4e40395,0x00000000}},	//   _zápě, ведв, ъжей, --, 
   {{0xe28598ec,0x693c0232,0x1cb00135,0x73302dfc}},	//   лған, _učeb, _ནོལ_, لىنا, 
   {{0x02bc1a22,0xf8bc4738,0x41b41a4e,0x00000000}},	//   ्सेन, _zoé_, _अपदस, --, 
   {{0x32c80158,0xdb1c01ed,0x2484083c,0x00000000}},	//   _gøym_, nysá, _tbmm_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdfd000c6,0xc325a4a8,0x9e340276,0x44200208}},	//   صيد_, _амак, лепч, _àk_, 
   {{0x73300075,0xdedc02d3,0x9104004e,0xf8bc0709}},	//   _ئىلا, _ሒዝካ_, кчөд, _एक्प, 
   {{0xdcb00075,0xe188010b,0x7ae446aa,0xbf645d95}},	//   مىد_, _чөле_, vijt, ردکو, 
   {{0x3fe5a4a9,0xb878032e,0x7ae40784,0x00000000}},	//   _ижев, _amín, wijt, --, 
   {{0xfd1c026c,0x257c0332,0x10f000f1,0x00000000}},	//   rmì_, híl_, _دګود, --, 
   {{0xaa6428a8,0x7f400194,0x3da45a52,0x00000000}},	//   итск, _itoq, _ариб, --, 
   {{0xf8bc3386,0x7ae41b9d,0xdb1c01d3,0xaa640a93}},	//   _poé_, rijt, gysá, штяк, 
   {{0x5c7407d8,0x257da4aa,0x66c0007c,0xd7940395}},	//   _слит, díl_, _sökp, либъ, 
   {{0xe825a4ab,0xe894011b,0x7c380309,0x5718005b}},	// [2d2d0] аффо, шать, ñuru, ежая_, 
   {{0x257c00c6,0x2bd0202e,0x7ae40200,0x00000000}},	//   fíl_, हनरा, qijt, --, 
   {{0xe695a4ac,0x765401d9,0xf8bc0051,0x690800e4}},	//   рихы, raxy, _toé_, tÿet, 
   {{0xb879a4ad,0x1cb0031c,0x7654058a,0x00000000}},	//   _zmín, _ནོས_, saxy, --, 
   {{0x628408a4,0xb87800e4,0x78ac03ac,0x00000000}},	//   đion, _ymín, _incv, --, 
   {{0x257c01a8,0x63c401e0,0x00000000,0x00000000}},	//   bíl_, рашҡ, --, --, 
   {{0xf525a4ae,0x7f41a4af,0x81e4015b,0x257d776a}},	//   _афан, _atoq, _যুব_, cíl_, 
   {{0x409004a9,0x20d80a40,0x67300428,0x8fd00032}},	//   ملىر, _léif_, _òijò, йәлә, 
   {{0x290c016b,0x93f400a8,0x319403b9,0xa92400d7}},	//   _ɔda_, _спац, _məzə_, úžit, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa1940354,0x00000000,0x00000000,0x00000000}},	//   _вахч, --, --, --, 
   {{0x7e7c04f3,0xcb680a89,0x2bd000ce,0xdb1c00d7}},	//   _öppn, наме_, हनला, vysá, 
   {{0x31a003ee,0x3b8002e8,0xdb1c0142,0xd09400fb}},	//   _hız_, бляг, wysá, _ашһы, 
   {{0x31a0a493,0x613c00e4,0xe984216c,0x00000000}},	//   _kız_, _hĩla, ақон, --, 
   {{0x20d80221,0x80880248,0x00000000,0x00000000}},	//   _déif_, _àṣàk, --, --, 
   {{0x68440032,0xddc800bc,0x6d4002d0,0x31a015b7}},	//   рмаҡ, jadř, _itna, _mız_, 
   {{0x068474a1,0xf74000fb,0xb6f400d1,0x00000000}},	// [2d2e0] лган, йето, گىلا_, --, 
   {{0x20d804c4,0xdce80882,0x257c0548,0xb8780022}},	//   _géif_, mudā, tíl_, _umín, 
   {{0xb6f40131,0x31a00205,0x0564009b,0x84640395}},	//   دىلا_, _nız_, увен, гъле, 
   {{0x257da4b0,0x22580e3c,0x20d80036,0x319403b9}},	//   ríl_, _žrk_, _zéif_, _gəzə_, 
   {{0x7520006a,0x20d801c7,0x257c3edd,0x69dc7c8c}},	//   ïnza, _héig_, síl_, lzre, 
   {{0x6d402f05,0x7f4001b9,0x31a01bc5,0x45340131}},	//   _otna, _rtoq, _bız_, _مىسر, 
   {{0xc0580046,0x52747b17,0x69dc8357,0x31a00205}},	//   ніп_, ручу, nzre, _cız_, 
   {{0x98a000b8,0xfba400bc,0x00000000,0x00000000}},	//   _rthī_, खिमम, --, --, 
   {{0x6d41a4b1,0x20d8007b,0x00000000,0x00000000}},	//   _atna, _léig_, --, --, 
   {{0xb87800e4,0x6d400175,0xb778008f,0xfb840150}},	//   _amíl, _btna, עאיש, қымн, 
   {{0x6288208d,0xb8e4031c,0x1df9a4b2,0x4085a4b3}},	//   _ibdo, _ཉྭ_, тены_, _булб, 
   {{0x7c640efc,0xfafc0200,0x69dc0171,0x00000000}},	//   دادل, rrëm_, dzre, --, 
   {{0x7f400eda,0x69c94094,0x6d41a4b4,0x2d88054e}},	//   _utoq, øden, _etna, ăcea_, 
   {{0x945c006d,0x32c808fb,0x6f60009f,0x00000000}},	//   _końc, _røyk_, _اهوم, --, 
   {{0x7c3c00b5,0x00000000,0x00000000,0x00000000}},	//   _tfqr, --, --, --, 
   {{0xdce800b8,0x00000000,0x00000000,0x00000000}},	//   budā, --, --, --, 
   {{0x628823e2,0xfb840598,0x9b9400d8,0x00000000}},	// [2d2f0] _obdo, _сыйн, _типц, --, 
   {{0xb8780022,0x6440058a,0x6d4003ac,0x00000000}},	//   _imím, _afmi, _ytna, --, 
   {{0x64400334,0xb5a4069a,0x319400ac,0xeaf81541}},	//   _bfmi, ырай, _təzə_, _حريت_, 
   {{0xfc3da4b5,0xe69402dd,0xf4f400e5,0x00000000}},	//   ncí_, _қисы, دوؤں_, --, 
   {{0x20d80597,0xe1f80220,0x27f800d0,0xf3640395}},	//   _méid_, ңгі_, čenú_, утен, 
   {{0x644001e4,0x00000000,0x00000000,0x00000000}},	//   _efmi, --, --, --, 
   {{0xfc3c0e96,0x31a0654f,0x00000000,0x00000000}},	//   kcí_, _qız_, --, --, 
   {{0x90c46eac,0x6289a4b6,0x693c01a6,0x20d80332}},	//   рбие, _ebdo, _očen, _néid_, 
   {{0x13a4b4d5,0x98a40024,0xa55402f2,0xfc3c013a}},	//   _خۆشی_, ūlė_, _نکۆڵ, dcí_, 
   {{0x0d8465e1,0xb87806ea,0x22a401d3,0x31a00139}},	//   алон, _smíl, tékű_, _tız_, 
   {{0x50b4330e,0x20d804e6,0x4df401b9,0x945c0210}},	//   _вслу, _béid_, ряпт, _gońc, 
   {{0xe1f0b4dc,0x20d80332,0x00000000,0x00000000}},	//   _عسل_, _céid_, --, --, 
   {{0xdb1c01f4,0x2be0000d,0x00000000,0x00000000}},	//   kysä, _पेखा, --, --, 
   {{0x69dda4b7,0x4a741b15,0x61f800a2,0x69c801bf}},	//   tzre, шымт, _çalç, ødeo, 
   {{0x8c440184,0xb87800e4,0x39e40107,0x69dc05c7}},	//   _кейе, _emím, адро_, uzre, 
   {{0x2360041a,0x69dc2fb3,0x09e401a9,0x00000000}},	//   šiji_, rzre, гоҳн, --, 
   {{0x2ca00652,0xfd6001e1,0x2f0806ea,0x87080798}},	// [2d300] _iaid_, _ootọ, søgu_, веав_, 
   {{0x2ca1a4b8,0x644000b5,0x86940063,0x16c40014}},	//   _haid_, _sfmi, јјач, ٝزمُ, 
   {{0x2480001f,0xae081b51,0x2ca00254,0x00000000}},	//   _የምርት_, _सुमन_, _kaid_, --, 
   {{0x2ca00652,0x44301445,0xfdf4011a,0x395400e4}},	//   _jaid_, øy_, בצעת_, ñesũ_, 
   {{0x2ca041fb,0x55c47c4c,0x39100133,0x69c4023e}},	//   _maid_, _һарғ, _گوێز, रहवी, 
   {{0x809d0204,0x48c00184,0x13a9353b,0x628800b5}},	//   _खोजे, _уҙға, انوی_, _qbdo, 
   {{0x2ca1a4b9,0x55c58437,0xfc3c022a,0x9f6403e0}},	//   _oaid_, _ларғ, ycí_, ştük_, 
   {{0x2ca1a4ba,0xb878013a,0x00000000,0x00000000}},	//   _naid_, _sjíz, --, --, 
   {{0xdea401d5,0x00000000,0x00000000,0x00000000}},	//   ییچی, --, --, --, 
   {{0x2050693c,0x20d80332,0x693c013a,0xd24c00ec}},	//   _መጀመር, _séid_, _rčen, _ٻچو_, 
   {{0x69c811c0,0x2ca0f574,0x2bf40183,0xba743fb8}},	//   ødel, _baid_, _ঘৰলৈ_, یاست, 
   {{0x201811a9,0x2ca0062c,0x9b9531ab,0xfc3c00bc}},	//   ərin_, _caid_, бимц, ucí_, 
   {{0xfb85a4bb,0x704400cf,0x2ca19d75,0x7c3802d1}},	//   шынн, _ئرمە, _daid_, ñurq, 
   {{0xfc3c00c6,0x0eac10eb,0xdd94008e,0x34c000bc}},	//   scí_, _झोपड, _гакы, _शव्द, 
   {{0x2ca1a4bc,0xaa58361e,0x20d801e7,0xfc3c0118}},	//   _faid_, рису_, _téid_, pcí_, 
   {{0x2ca01028,0x2f08037e,0xfafc0036,0x00000000}},	//   _gaid_, søgt_, guër_, --, 
   {{0x693c181f,0xad240228,0xb8780118,0xa5d801d5}},	// [2d310] _učen, _بىيى, _umím, یبمر_, 
   {{0x2be00d01,0xf645a4bd,0x2ca1a4be,0xb5a4001b}},	//   _पेटा, рхан, _zaid_, ирей, 
   {{0xe610505a,0x20d801c7,0xa6340212,0xd1d40092}},	//   وشم_, _zéie_, інці, _ክፋት_, 
   {{0x69c4038e,0x00000000,0x00000000,0x00000000}},	//   रहरी, --, --, --, 
   {{0xdb1c4fc6,0x53a5a4bf,0x505800d1,0x00000000}},	//   pysä, салб, ңшия_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x701009bd,0x00000000,0x00000000,0x00000000}},	//   _হলেও_, --, --, --, 
   {{0x3ddc033f,0x53340064,0xa5f80150,0x00000000}},	//   dztw_, _геат, _тесу_, --, 
   {{0x0d200228,0x00000000,0x00000000,0x00000000}},	//   үүлү, --, --, --, 
   {{0x2ca1a4c0,0x232800f3,0x00000000,0x00000000}},	//   _said_, _вођи_, --, --, 
   {{0x2ca00375,0x32080022,0x2bd000bc,0x63048944}},	//   _paid_, _рхан_, हन्थ, _بولل, 
   {{0xa0c40372,0x2ca005b1,0x7c380113,0xc5f0011a}},	//   _ويلو, _qaid_, ñurp, לדי_, 
   {{0x2ca0033d,0x7bc80003,0x00000000,0x00000000}},	//   _vaid_, _żgur, --, --, 
   {{0xdde804d3,0x2fdc0112,0x5ea4004b,0xe3c40166}},	//   اریه_, mzug_, _ومنل, ldıñ_, 
   {{0x20d80036,0x2fdc0112,0x2ca0015d,0x993801f0}},	//   _wéie_, lzug_, _taid_, ияту_, 
   {{0x1cb0025c,0x271000cd,0x00000000,0x00000000}},	//   _ནོག_, ऽत्र_, --, --, 
   {{0x2fdc03fa,0x693c0841,0x386c007b,0x6ea809ab}},	// [2d320] nzug_, _ičem, ógra_, जयपु, 
   {{0x3bb8011a,0x6d940241,0x00000000,0x00000000}},	//   _עמיד, _ṣay, --, --, 
   {{0x945c010e,0x2fdc0112,0x994800f1,0x00000000}},	//   _sońa, hzug_, _پلټل_, --, 
   {{0x04590096,0x45340022,0xbb18054e,0xe7f84e6d}},	//   اجات_, _ҳхат, ntîn, ंपदा_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf741a4c1,0xf8bc0561,0x7cec033b,0x27e1a4c2}},	//   _херо, _diéu_, _kòrè, mzin_, 
   {{0x27e0d0ab,0xfafc0036,0x0578007b,0x00000000}},	//   lzin_, ssëg_, _حمزة_, --, 
   {{0x2fdc0e78,0x00000000,0x00000000,0x00000000}},	//   fzug_, --, --, --, 
   {{0xa2c49151,0x9ed800a8,0x9e7400d1,0x00000000}},	//   _мәкк, имит_, قۇشت, --, 
   {{0x693c071b,0x27e1a4c3,0x1cb0031c,0x20d801e7}},	//   _pčel, izin_, _ནོང_, _béic_, 
   {{0xeea40372,0xc0e40dbb,0x00000000,0x00000000}},	//   стык_, _ложк, --, --, 
   {{0x693c0122,0x27e0037e,0xff080183,0x2fdc0112}},	//   _včel, kzin_, ৰদেশ_, bzug_, 
   {{0x27e001f5,0x7118011a,0x00000000,0x00000000}},	//   jzin_, _עודפ, --, --, 
   {{0x27e0068f,0x00000000,0x00000000,0x00000000}},	//   dzin_, --, --, --, 
   {{0x27e0039a,0x90740092,0x988001ec,0x00000000}},	//   ezin_, _በቀበሌ_, _ﺩﻋﻭﺓ_, --, 
   {{0x32c802bf,0xf8bc01f5,0xddd80100,0x27e0004d}},	//   _høyt_, _niét_, _revň, fzin_, 
   {{0x2b4405f5,0xe91800d4,0x00000000,0x00000000}},	// [2d330] _нээг, соті_, --, --, 
   {{0xa3ac2aa1,0x38ac0139,0x00000000,0x00000000}},	//   गिन_, _börä_, --, --, 
   {{0x14580184,0xf8bda4c4,0x27e00109,0x65946f81}},	//   ашлы_, _siéu_, azin_, заху, 
   {{0x26d9a4c5,0x27e0014b,0x00000000,0x00000000}},	//   _elro_, bzin_, --, --, 
   {{0xf8bd232e,0x7cec02bd,0x91e400cc,0x00000000}},	//   _diét_, _zòrè, _পুংখ, --, 
   {{0xd1c9a4c6,0xd2a93021,0x27f40419,0x00000000}},	//   илле_, ркке_, šaná_, --, 
   {{0xe5c4d9ec,0x38ac09a5,0x00000000,0x00000000}},	//   _есто, _görä_, --, --, 
   {{0xcf45881b,0x2fdc0b70,0xe164007b,0x63b400e4}},	//   оний, tzug_, أدوي, ñenó, 
   {{0x0eb800fd,0x24180153,0xdc2800d7,0x00000000}},	//   ауны_, _готы_, _bôči, --, 
   {{0x4d6520d1,0x69c939ee,0x7bcc05b1,0x2fdc0e78}},	//   оков, ødek, dycu, rzug_, 
   {{0x27e1a4c7,0x2fdc03fa,0x201800ac,0xb628037e}},	//   zzin_, szug_, ərim_, _ｔｙ_, 
   {{0xe3b00014,0x601000e4,0x00000000,0x00000000}},	//   _ترہ_, _ẽmen, --, --, 
   {{0xf8bc20ef,0x00000000,0x00000000,0x00000000}},	//   _liés_, --, --, --, 
   {{0x538c0092,0x8ca8012d,0x00000000,0x00000000}},	//   _መውደድ_, _जोरो, --, --, 
   {{0x7c3804a7,0x19b802bf,0x66c005d1,0xff2001b9}},	//   žura, буть_, _göky, _юмшо, 
   {{0x27e1a4c8,0x8b945884,0x20d80036,0x7bcc003a}},	//   tzin_, _дроч, _kéia_, bycu, 
   {{0x46e9a4c9,0x06e809a5,0x46380276,0x27e0030a}},	// [2d340] адан_, амак_, ачея_, uzin_, 
   {{0x27e1a4ca,0x38ac00e4,0x66c00108,0x00000000}},	//   rzin_, _pörä_, _yöky, --, 
   {{0xfc3c09ff,0x32c805ac,0x27e0072d,0x00000000}},	//   ldía_, _løys_, szin_, --, 
   {{0x88b02be7,0xf8bceccd,0x00000000,0x00000000}},	//   _تیرچ, _diés_, --, --, 
   {{0x693c0552,0xfc3c29ac,0x741002f2,0xc3041913}},	//   _oček, ndía_, ووما, يبتو, 
   {{0xf6c400aa,0xc69001d9,0x8168036b,0x00000000}},	//   _وژلي_, _تِس_, ариб_, --, 
   {{0xd2584077,0x36640064,0x052800d4,0x69c812e8}},	//   сці_, _фасо_, _вовк_, ødeh, 
   {{0x3f6404f0,0x6b84022e,0x00000000,0x00000000}},	//   отоб, _oqig, --, --, 
   {{0x6e2c0213,0x69d80135,0x00000000,0x00000000}},	//   əkbə, _żvel, --, --, 
   {{0x63a001a9,0x9ed8014b,0x00000000,0x00000000}},	//   _ismn, смот_, --, --, 
   {{0x6299a4cb,0xf8bc0154,0xb87800e4,0xe3b000f1}},	//   mevo, _miér_, _imív, _ترځ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd0f800c8,0x7ff41291,0xcbb40150,0x00000000}},	//   _פּער, _بساا, зғыш_, --, 
   {{0x32c800fe,0xb4e401ad,0x6298b4bb,0x255802e2}},	//   _høyr_, _पष्_, nevo, kōl_, 
   {{0x32c800cc,0x38c41985,0xceb400c7,0x290402e2}},	//   _køyr_, ощав, _хәы_, čman_, 
   {{0x6b840327,0xf8bc067c,0x6298ca5a,0x63a00118}},	//   _fqig, _riés_, hevo, _osmn, 
   {{0xb8e00cb4,0xd7582085,0xf7702dd0,0xe785a4cc}},	// [2d350] _एच_, صلات_, ظار_, духо, 
   {{0x62981883,0xf674009a,0x00000000,0x00000000}},	//   jevo, تارخ, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf8bc0798,0x00000000,0x00000000,0x00000000}},	//   _viés_, --, --, --, 
   {{0x88804bcf,0xf8bcf140,0x6298003b,0x88b8011a}},	//   _سیلن, _chée_, fevo, _הזרי, 
   {{0x6299a4cd,0xe7f82274,0xfafc02d3,0x32c805ac}},	//   gevo, ंपरा_, mrës_, _røys_, 
   {{0x7984003c,0x0418002b,0x00000000,0x00000000}},	//   ntjw, _mūṣa, --, --, 
   {{0x69c801bf,0x00000000,0x00000000,0x00000000}},	//   ødei, --, --, --, 
   {{0x6299a4ce,0x32c800fe,0xb4d4190e,0x20180213}},	//   bevo, _døyr_, िसी_, ərik_, 
   {{0x6299a4cf,0xd2500597,0x20d800d8,0x39a400d7}},	//   cevo, _أنا_, _véia_, _zísť_, 
   {{0x4c34009d,0x00000000,0x00000000,0x00000000}},	//   зэгт, --, --, --, 
   {{0xdb0c01c7,0x32c8143a,0xfafc0240,0x20d9a4d0}},	//   _fraë, _tøys_, krës_, _héin_, 
   {{0x6b84022e,0xdcf800e2,0xb878032e,0x6ea801f9}},	//   _qqig, _apvē, _klíf, जयदु, 
   {{0x798400fb,0xfc3c2b76,0xfafc02d3,0x041800b8}},	//   ftjw, rdía_, drës_, _cūṣa, 
   {{0x20d83a35,0xfafc0023,0x041800dc,0xc330011a}},	//   _méin_, erës_, _dūṣa, תום_, 
   {{0x20d88ec5,0x62994756,0x9cf40166,0xfafc0200}},	//   _léin_, zevo, _очыш, frës_, 
   {{0x6b8401a9,0x255802e2,0xb87802d2,0xfafc0200}},	// [2d360] _uqig, wōl_, _olíf, grës_, 
   {{0xfc3da4d1,0xb6a001c6,0xbd8402f2,0x00000000}},	//   ndín_, ниул, _بچین_, --, 
   {{0x6299a4d2,0xba980375,0x63a00334,0x2d640e04}},	//   vevo, _פסטי, _ssmn, nđe_, 
   {{0xe8b404a9,0xfafc0240,0xe5380240,0x00000000}},	//   _تەرج, brës_, _እነፍቅ, --, 
   {{0x6299a4d3,0x32c800cc,0xfafc0240,0xb87802d2}},	//   tevo, _røyr_, crës_, _blíf, 
   {{0x20d80332,0xe214010b,0xa1940166,0x00000000}},	//   _céin_, ммлы, дакч, --, 
   {{0xd5ac1973,0x20d804e6,0xe7f00490,0xb87801e7}},	//   _پہن_, _déin_, _घेता_, _dlíf, 
   {{0x6299a4d4,0x61e40115,0xf990011a,0xdce80064}},	//   sevo, ŝilo, גרה_, budę, 
   {{0x20d806d5,0x62999e62,0xb87800e4,0x301002e8}},	//   _féin_, pevo, _imít, ндър, 
   {{0xe8040034,0xb8780588,0x00000000,0x00000000}},	//   _रखना_, _umív, --, --, 
   {{0x1cb0025c,0x945c00a2,0xdc980212,0x53800092}},	//   _ནོད_, _alńy, овні_, _የልደት_, 
   {{0xd488001f,0xfafc0240,0x90d40208,0x00000000}},	//   _መዝናኛ_, yrës_, _hùn, --, 
   {{0x22a402b5,0x041800b8,0x69c8007c,0x00000000}},	//   _tūkē_, _pūṣa, äden, --, 
   {{0xb878032e,0xfafc0200,0x7c4000ef,0x00000000}},	//   _klíg, vrës_, _štrā, --, 
   {{0xb8794b4b,0x00000000,0x00000000,0x00000000}},	//   _omít, --, --, --, 
   {{0x6935a4d5,0xfafc0023,0xf7701867,0x90d40051}},	//   енсу, trës_, فاط_, _lùn, 
   {{0xfc3c3a6c,0xddc80064,0x00000000,0x00000000}},	// [2d370] ldío_, ngdž, --, --, 
   {{0xfafc02d3,0x798400fb,0x1a65a4d6,0x79a51ed0}},	//   rrës_, ptjw, _زیری_, _ерме, 
   {{0xfc3c09c2,0x20d80332,0x00000000,0x00000000}},	//   ndío_, _réin_, --, --, 
   {{0xe4e41c26,0xb4d51afa,0x941802f6,0xfafc0023}},	//   нічн, िसे_, ожет_, prës_, 
   {{0x1cb00135,0x20d801ab,0x90d40051,0xdb0c0248}},	//   _ནོན_, _péin_, _bùn, _ìkón, 
   {{0xf2c40724,0xb8780005,0x90d401fb,0x7d0c0332}},	//   ясен, _emít, _cùn, hocs, 
   {{0x65947036,0x7d0c01ed,0x90d401fb,0xc690025d}},	//   _пару, kocs, _dùn, _שאל_, 
   {{0x409004a9,0xc04c004b,0xe1f02824,0x20d801c7}},	//   نلىر, لږه_, دسه_, _wéin_, 
   {{0x7d0da13a,0x20d80221,0x4fe801f0,0x8e7401a9}},	//   docs, _téin_, юмин_, мунч, 
   {{0xe3b11f0c,0xb8780118,0x20d8000c,0xcee800d4}},	//   _حرف_, _hlíd, _héil_, ідне_, 
   {{0xfc3da4d7,0xb878013a,0x8e0801a9,0x00000000}},	//   rdín_, _klíd, юнов_, --, 
   {{0xe3e400bd,0x2d641591,0x945c030a,0xfd5c004d}},	//   _ফুটব, rđe_, _sońj, _huyễ, 
   {{0x2d6401fa,0x40e80244,0x00000000,0x00000000}},	//   sđe_, _بونێ_, --, --, 
   {{0x8d74189c,0x5f74188d,0xae08000d,0x00000000}},	//   _قابا, _ساهر, _सुअन_, --, 
   {{0x1ea87ae6,0x7d0c01d3,0xbf1000f7,0xfbdc030a}},	//   _راوي_, bocs, _جووب, ubêr_, 
   {{0x693c098d,0xfbdc030a,0x00000000,0x00000000}},	//   _očev, rbêr_, --, --, 
   {{0x333c0014,0x06c806a6,0xcb680244,0x00000000}},	// [2d380] _nuux_, огай_, _بمخه_, --, 
   {{0xa3ac2cf5,0xb87801ef,0x26dc0588,0x00000000}},	//   गिस_, _smít, óvo_, --, 
   {{0x2b400483,0x693c009b,0xb87803b2,0x20d800ae}},	//   _huic_, _ačev, _blíd, _béil_, 
   {{0x333c0067,0xfafce5d5,0xd624a9e7,0x00000000}},	//   _buux_, nsën_, رعلي, --, 
   {{0xdb1c0124,0xa29400d4,0x00000000,0x00000000}},	//   hysý, еалі, --, --, 
   {{0x2b41a4d8,0x7bc8004e,0xdb1c00e4,0xe764030d}},	//   _muic_, _àgue, kysý, ăвĕп, 
   {{0x35a000c7,0x20d80332,0xfafc0240,0x90d40208}},	//   _иарг, _féil_, ksën_, _vùn, 
   {{0x20d80798,0xb8780118,0xfafc036e,0x00000000}},	//   _véio_, _umít, jsën_, --, 
   {{0x333c6ed1,0x6d4400d0,0x90d40051,0xdfd000ae}},	//   _guux_, íjan, _tùn, ايخ_, 
   {{0x20189787,0xdb0c0077,0xdce80118,0x5d541d0f}},	//   āri_, _traé, budě, нкот, 
   {{0x69c8f4b5,0x4084004e,0x00000000,0x00000000}},	//   ädel, _жулб, --, --, 
   {{0x20d804e6,0xfc3c09c2,0x333c002e,0x248001c3}},	//   _kéim_, rdío_, _yuux_, òimh_, 
   {{0x2b40067c,0x333c0de2,0xb8780241,0x945c0432}},	//   _cuic_, _xuux_, _omír, _sońk, 
   {{0x1cb0025c,0x2b41a4d9,0x00000000,0x00000000}},	//   _ནོམ_, _duic_, --, --, 
   {{0x20d80597,0xdb0c5725,0x8ca81d8a,0x00000000}},	//   _léim_, _fraî, _जोको, --, 
   {{0x25f469de,0xe89402d5,0x7c9400f2,0x00000000}},	//   ्पनी_, кась, _آشغا, --, 
   {{0xdd900271,0xfc3c022a,0xb87801ef,0xcee80345}},	// [2d390] _شوک_, ndím_, _smís, _برۆن_, 
   {{0x333c0050,0xfc3c012c,0x20d804e6,0xb4d4258d}},	//   _ruux_, zdíl_, _séil_, िस्_, 
   {{0xaaa8772c,0x20d80036,0x333c0de2,0x58d40cc9}},	//   _छोटक, _péil_, _suux_, _зонт, 
   {{0x20d800c6,0x24580953,0xfd5c0208,0x00000000}},	//   _béim_, даць_, _suyễ, --, 
   {{0x20d800c6,0x77300022,0xf365a4da,0xb878013a}},	//   _céim_, _аҭау, фтен, _vlíd, 
   {{0xe804033f,0x20d80036,0x572400f7,0xe16400d1}},	//   _रखता_, _wéil_, _سىزك, ھدىي, 
   {{0xb879a4db,0xfafc002e,0x746800f3,0x00000000}},	//   _umís, ysën_, _мрав_, --, 
   {{0xb8780118,0xa3b800ec,0x00000000,0x00000000}},	//   _zmír, _ڪافر_, --, --, 
   {{0xb63004a9,0x20d801e7,0xfd5c0051,0x00000000}},	//   _ﯞﻩ_, _géim_, _tuyễ, --, 
   {{0x44c00124,0xa3ac012c,0x235801f7,0x00000000}},	//   _аӡәг, गिर_, _آڳنڌ_, --, 
   {{0xc6900bd9,0xd05802dd,0xf1a40166,0xdeec00db}},	//   נאט_, _ерлі_, _юран, تۋو_, 
   {{0xdb1c00c7,0x205400c0,0x69c8f6b3,0x00000000}},	//   rysý, _акця, ädem, --, 
   {{0x2b40003a,0xfafc036e,0xb8780241,0x00000000}},	//   _quic_, rsën_, _olíb, --, 
   {{0xbea1a4dc,0x693c151c,0x3ea0009d,0x00000000}},	//   _башк, _očet, _бишг, --, 
   {{0x09e41639,0xc5f800bd,0xdb0c07ea,0xfafc0200}},	//   ховн, _অর্থ_, _traî, psën_, 
   {{0x799402d0,0xf8bc0165,0x2b40030a,0xb878013a}},	//   _dpxw, _phéa_, _tuic_, _smír, 
   {{0xcb6814a5,0xdb0c02fb,0xc72400a7,0xc5f89856}},	// [2d3a0] _عمده_, žkác, едай, ्थ्य_, 
   {{0x69c804ce,0x20d8007b,0xdedc02d3,0x25484e7e}},	//   ødes, _réim_, _ሒዝና_, _ağla_, 
   {{0x85782136,0xe7f01d8a,0xe97402dd,0xfc3c0216}},	//   ясат_, _घेरा_, _جۇزد, zdím_, 
   {{0xc515a4dd,0x7de40c6a,0x24840051,0x00000000}},	//   ربات, _hésé, _qcmm_, --, 
   {{0x68e5a4de,0x2c0403d4,0x7de5a4df,0x00000000}},	//   mhid, ৰেৰে_, _késé, --, 
   {{0x68e5a4e0,0x2900295f,0xfc3c01d3,0xb879a2f5}},	//   lhid, lnia_, gdíj_, _umír, 
   {{0x2901a4e1,0x7de40098,0x049402d5,0x764000d0}},	//   onia_, _mésé, _праў, žnyc, 
   {{0xb879a4e2,0x71f412e3,0x68e5a4e3,0x7de40129}},	//   _ilíc, عروس_, nhid, _lésé, 
   {{0x2901a4e4,0xfd88013e,0x63a4cb38,0x00000000}},	//   inia_, ӯёни_, çind, --, 
   {{0x61080316,0x68e5a4e5,0xfc3c0306,0x733000db}},	//   děle, hhid, rdím_, _مىقا, 
   {{0x2901a4e6,0x68e5a4e7,0xdd907cf6,0x41b402ac}},	//   knia_, khid, جوج_, _ясат, 
   {{0xd17401e0,0x29000210,0x00000000,0x00000000}},	//   _шыуы, jnia_, --, --, 
   {{0x2900006d,0x693c151c,0x7de4003e,0x68e5a4e8}},	//   dnia_, _očes, _bésé, dhid, 
   {{0x2900006d,0xf8bc01fb,0x1e140139,0x00000000}},	//   enia_, _chén_, _имля, --, 
   {{0x7de5a4e9,0x290006ea,0x6da000ea,0xada000f3}},	//   _désé, fnia_, _бија, _бајл, 
   {{0x2900d6dc,0x68e554b4,0xdb0c56ed,0xc5f80183}},	//   gnia_, ghid, _traï, _অৰ্থ_, 
   {{0x4bc01a59,0xb8781c69,0x81c402f5,0x69c80ef9}},	// [2d3b0] _көрг, _alíc, উনি_, øder, 
   {{0x2901a4ea,0x68e400ec,0xdb1da4eb,0x7de4525e}},	//   ania_, ahid, rysó, _gésé, 
   {{0x68e5a4ec,0x0af005f5,0x629c0174,0x00000000}},	//   bhid, _түрэ, _óroy, --, 
   {{0x693da4ed,0x68e4253c,0x2901a4ee,0xdb1c0124}},	//   _včet, chid, cnia_, pysó, 
   {{0x53a5a4ef,0x67d402dd,0xe4540209,0x01780092}},	//   талб, _бояу, укчы, _አርከበ_, 
   {{0xf8bc001e,0x00000000,0x00000000,0x00000000}},	//   _khéo_, --, --, --, 
   {{0x693da4f0,0xb8780077,0x20d80036,0x10a48b1b}},	//   _kōea, _glíc, _kéih_, вийн, 
   {{0x8fd00184,0x693c0841,0xe53400c0,0x6d4400d7}},	//   иәлә, _kčer, _бесь, íjam, 
   {{0xb2b00131,0x20d804e6,0x159c0150,0xdb0d9bcd}},	//   _бәйъ, _méih_, _ءﺗﺎﺑ, _araí, 
   {{0x2901a4f1,0xf8bc0022,0x4d482b97,0x68e405c7}},	//   znia_, _ohéo_, мпон_, zhid, 
   {{0x2901a4f2,0x68e5a4f3,0x7538009f,0x7de44de4}},	//   ynia_, yhid, _kiuz, _résé, 
   {{0xcb6814a4,0x4f943334,0x7539791b,0x693c009b}},	//   маме_, _арку, _jiuz, _očer, 
   {{0x68e4c72e,0x261807f7,0x753800c0,0x290000d7}},	//   vhid, _बुनी_, _miuz, vnia_, 
   {{0x68e5a4f4,0x75380007,0x9af80882,0x2900068f}},	//   whid, _liuz, trāṇ, wnia_, 
   {{0x68e40e89,0x2901a4f5,0xf8bc01fb,0x5974030c}},	//   thid, tnia_, _chéo_, лыту, 
   {{0x6d41a4f6,0x68e40ac5,0xb901a4f7,0x14dc00ce}},	//   _iuna, uhid, азск, _मतगण, 
   {{0x9af80882,0x0684457e,0xf7400395,0x8b24014b}},	// [2d3c0] srāṇ, кган, ието, _идие, 
   {{0x6d41a4f8,0x68e5a4f9,0xd84864b6,0xb878013a}},	//   _kuna, shid, _җорҗ_, _plíc, 
   {{0xb6a1a4fa,0x0a140014,0x2901a4fb,0x4584010b}},	//   рихл, _شہرک_, pnia_, тгев, 
   {{0x6d41a4fc,0x75380beb,0xc7940124,0x29000200}},	//   _muna, _ciuz, _иргы, qnia_, 
   {{0x6d41a4fd,0x7538092c,0xb38005f5,0x6d4400d0}},	//   _luna, _diuz, илцл, íjaj, 
   {{0xb8785133,0xfafc0240,0x6d41a4fe,0x81c40154}},	//   _ilía, ysëm_, _ouna, উনস_, 
   {{0x6d41a4ff,0x693c2aef,0x4534035b,0x7f400393}},	//   _nuna, _učes, _ахат, _suoq, 
   {{0x7c381505,0x75380097,0x673c0083,0xfc3c02f0}},	//   žuri, _giuz, _hirj, rdík_, 
   {{0x673da500,0x7f41a501,0xb2200daf,0x661c00a2}},	//   _kirj, _quoq, лмәл, _hyrk, 
   {{0xc32c278f,0x6d41a502,0x661da503,0x673c8ebb}},	//   _بەت_, _buna, _kyrk, _jirj, 
   {{0x6d41a504,0xeea40228,0x661c0f23,0x3d0c482a}},	//   _cuna, ттык_, _jyrk, ठवले_, 
   {{0x6d41a505,0x661da506,0xfb70039b,0x9f6401ed}},	//   _duna, _myrk, ақия, ától_, 
   {{0x6d41a507,0x20d80036,0x9f9c08a5,0x6d640055}},	//   _euna, _réih_, _gæða_, _āpaś, 
   {{0x6d41a508,0xdb0c0f71,0xdd9021ec,0x673c00dc}},	//   _funa, _traí, _هوت_, _nirj, 
   {{0xdd9434b1,0xb87804d4,0x69c811c0,0x661c023a}},	//   _сайы, _alía, ødep, _nyrk, 
   {{0x201803be,0x673c037e,0x693c0419,0x8c100154}},	//   ərir_, _airj, _sčer, সেইন_, 
   {{0x6d400fb7,0x673da509,0x75380369,0x3d0c05f9}},	// [2d3d0] _zuna, _birj, _riuz, सवीं_, 
   {{0x64401730,0x661c00fe,0x673c0009,0xfd1da50a}},	//   _agmi, _byrk, _cirj, llì_, 
   {{0x693c23e2,0xb87912fe,0x673da50b,0x64400334}},	//   _včer, _elía, _dirj, _bgmi, 
   {{0x661c00ed,0x628802d0,0x64400175,0x00000000}},	//   _dyrk, _acdo, _cgmi, --, 
   {{0xf8bc01a2,0x673da50c,0x7538011c,0xa774013d}},	//   _iné_, _firj, _viuz, _кляч, 
   {{0x9f9c008c,0x661da50d,0x693c0010,0x673c0432}},	//   _ræða_, _fyrk, _učer, _girj, 
   {{0x753802ce,0x64400175,0x661c0432,0x73c001e0}},	//   _tiuz, _fgmi, _gyrk, ыҡҡа, 
   {{0x6d404375,0x20d801c7,0x63a40790,0xa5e800d1}},	//   _runa, _méiw_, çinc, _جۈمە_, 
   {{0x6d41a50e,0x20d80221,0x673c0076,0xae080118}},	//   _suna, _léiw_, _yirj, _सुजन_, 
   {{0x6d41a50f,0x0dc83da1,0x2d88033f,0x673c025c}},	//   _puna, елой_, ńcem_, _xirj, 
   {{0x6d41a510,0xf8bc2afb,0x00000000,0x00000000}},	//   _quna, _oné_, --, --, 
   {{0x6d4003b4,0x6cb400f7,0xfd1c05d5,0xe7f800bc}},	//   _vuna, рөкт, glì_, ूपमा_, 
   {{0xf8bc001e,0x6d400113,0xdef80327,0x00000000}},	//   _chém_, _wuna, biċ_, --, 
   {{0x6d41a511,0xf8bc1682,0xc0c400c7,0xbb400e92}},	//   _tuna, _ané_, _ашәқ, серк, 
   {{0x6d41a512,0xfd1c05d5,0xf1b001ad,0x261817ee}},	//   _uuna, blì_, ंटिन, _बँधी_, 
   {{0x673da513,0x4c84223a,0x07a5a514,0x6ea80e49}},	//   _sirj, _слив, лабн, जयकु, 
   {{0x673c4b35,0x64400254,0x661da515,0xf8bc0051}},	// [2d3e0] _pirj, _rgmi, _syrk, _ghém_, 
   {{0x661da516,0xf8bc003e,0x673c0240,0x7d1c00cd}},	//   _pyrk, _ené_, _qirj, _īpsi, 
   {{0x673da517,0x20d801c7,0x44201155,0x9aa400cf}},	//   _virj, _géiw_, _šk_, _ئمپو, 
   {{0xf8bc00c6,0x661c0158,0x673da518,0xb8780118}},	//   _gné_, _vyrk, _wirj, _hlín, 
   {{0x667455b2,0xb879a519,0x628800d8,0x673ca94c}},	//   _نگار, _klín, _pcdo, _tirj, 
   {{0x6108012c,0x733015c3,0x273803b9,0x00000000}},	//   děla, مىنا, künə_, --, 
   {{0xd2580212,0xea0001e1,0x33f0013d,0x47e001ee}},	//   тці_, _plẹu_, ичәс, _тәңҡ, 
   {{0xe3a401b9,0xd1f00023,0x81c400fe,0x00000000}},	//   _پشری, _ጁቡቲ_, উনল_, --, 
   {{0xdfd000c6,0x44200051,0x42541867,0xa3040150}},	//   زيد_, _ák_, _منذر, _күде, 
   {{0x81a4004b,0xe28401b9,0xfafc00e8,0xbe88010b}},	//   _محصل, _خطری, rsëk_, хсие_, 
   {{0xdd95a51a,0xa3acaf6c,0x273803b9,0x00000000}},	//   шаны, गिक_, günə_, --, 
   {{0xb87810d8,0xfd1c0ffb,0x3d0c02e5,0xb63400df}},	//   _alín, ulì_, सवें_, טריס_, 
   {{0xfd1da51b,0xdd000205,0x61c400cd,0x00000000}},	//   rlì_, çtık, _वपुष, --, 
   {{0x9e340137,0xf99001d9,0x273806be,0x3da400f3}},	//   _келч, ٝبر_, bünə_, _бриб, 
   {{0xf974044e,0xb87800ae,0xda340108,0x273803e3}},	//   _ክልቲኡ_, _dlín, ревы, cünə_, 
   {{0x3eac056b,0xb879a51c,0x5bb80166,0xa3c4012c}},	//   _haft_, _elín, _алия_, एमा_, 
   {{0xee340184,0x3eada51d,0x79a40220,0xf8bc0098}},	// [2d3f0] _инә_, _kaft_, _өрне, _uhém_, 
   {{0xa3d82232,0x00000000,0x00000000,0x00000000}},	//   ाहन_, --, --, --, 
   {{0x80b805b7,0x7af4022f,0xf8bc00d7,0x00000000}},	//   _शोभे, _imxt, _tné_, --, 
   {{0xb878012c,0x1ccc0327,0xa3e000dc,0x00000000}},	//   _zlín, _ློས_, दनं_, --, 
   {{0xe3d82b1b,0x27380213,0x69c8000d,0x00000000}},	//   _দেবব, zünə_, ädev, --, 
   {{0x3eac002e,0x8778008f,0x63a4cae1,0x00000000}},	//   _naft_, _באשי, çina, --, 
   {{0x91c4035b,0xc0c00092,0x91e4011c,0x00000000}},	//   шәал, _ድሮም_, ройе, --, 
   {{0x4f940588,0x50b442cd,0x00000000,0x00000000}},	//   ароу, рску, --, --, 
   {{0x00c56c3b,0xe45400f7,0x20c80b38,0xf1a40116}},	//   рлык_, _ыкты, ابىي_, _әрзн, 
   {{0xe7f80034,0x273800ac,0x0cdc0b7c,0x0e643999}},	//   ूपता_, tünə_, मस्म, шкон, 
   {{0x3eac1c1d,0xf8bc002e,0xe81c00e1,0x800800e5}},	//   _daft_, _chék_, _भुना_, فریہ_, 
   {{0x78ac0306,0x00000000,0x00000000,0x00000000}},	//   _nacv, --, --, --, 
   {{0xb8790227,0xa13401b9,0x3b800d30,0x29040205}},	//   _plín, _ارلش, оляг, _ıma_, 
   {{0xbec000ef,0x00000000,0x00000000,0x00000000}},	//   _šīva, --, --, --, 
   {{0xb87800ae,0x00000000,0x00000000,0x00000000}},	//   _clío, --, --, --, 
   {{0xb878007b,0xa3d816ae,0x0b4474df,0x00000000}},	//   _dlío, ाहम_, _книн, --, 
  
   {{0x65b000e5,0x00000000,0x00000000,0x00000000}},	// [2d400] kóhá, --, --, --, 
   {{0x290c020c,0x3eac031c,0x36c000f0,0x00000000}},	//   édab_, _xaft_, обуг, --, 
   {{0x7a780bd9,0x610800bc,0x00000000,0x00000000}},	//   _בריס, děln, --, --, 
   {{0x69dc0072,0x33140214,0x945c010b,0x00000000}},	//   myre, یزود_, _sońr, --, 
   {{0x69dda51e,0x00000000,0x00000000,0x00000000}},	//   lyre, --, --, --, 
   {{0x20d80221,0x78ac0ebd,0x0524015b,0xefcc1954}},	//   _léit_, _zacv, যদের_, _ኤርያ_, 
   {{0x69dc2fce,0x2000054e,0x3eac0f85,0x41c401d5}},	//   nyre, _ţii_, _raft_, рёла, 
   {{0x3eac1c1d,0x2111a51f,0x20d80036,0x612c002d}},	//   _saft_, ावेश_, _néit_, kûle, 
   {{0x69dda520,0x693c02b5,0x00000000,0x00000000}},	//   hyre, _nōem, --, --, 
   {{0x69dda521,0x00000000,0x00000000,0x00000000}},	//   kyre, --, --, --, 
   {{0x69dc0c5f,0x00000000,0x00000000,0x00000000}},	//   jyre, --, --, --, 
   {{0x69dc3c02,0x3ead6039,0x00000000,0x00000000}},	//   dyre, _waft_, --, --, 
   {{0x3eada522,0x20d80036,0x09cc0327,0xb8780332}},	//   _taft_, _déit_, ྱའྀ_, _slío, 
   {{0x69dc21e3,0x00000000,0x00000000,0x00000000}},	//   fyre, --, --, --, 
   {{0x5d840491,0x69dcfe92,0x78ac01e4,0x00000000}},	//   _العل, gyre, _pacv, --, 
   {{0xdb0c06ed,0xf7708a61,0xacf4007b,0x3b640354}},	//   _oraç, قاط_, _وسيت, _къов, 
   {{0xfb84151e,0x972450ea,0x9b94007b,0x2b4400db}},	// [2d410] _тыйн, مفرو, _الخت, _мээг, 
   {{0x7c384b16,0x20d804e6,0xab281f5a,0x00000000}},	//   žurs, _kéis_, _коња_, --, 
   {{0xdb0caa4a,0x69c802f6,0xfc3c0077,0x79a407b5}},	//   _araç, ädet, rdíu_, _трпе, 
   {{0xdb0da523,0xb8790b03,0x61080118,0x63a40135}},	//   _braç, _klím, dělo, ħinn, 
   {{0x889823e4,0x20d801c7,0xb9d0001f,0xa3f40212}},	//   _גברי, _léis_, _ድሰ_, опці, 
   {{0xdb0c0213,0x1db817ee,0x00000000,0x00000000}},	//   _draç, ेमात, --, --, 
   {{0xb8780113,0x00000000,0x00000000,0x00000000}},	//   _llím, --, --, --, 
   {{0xfc3da524,0xdb0c0120,0xf8a4033f,0x25bc01bf}},	//   ndís_, _fraç, ख़िय, ævle_, 
   {{0xdb0c0261,0xfc3c007b,0x20d80036,0x9e3c00d7}},	//   _graç, idís_, _réit_, veďa, 
   {{0x0d8464cf,0xa5240135,0x20d804e6,0x80a800cc}},	//   блон, _འཚོག_, _béis_, কাষ্, 
   {{0x69dc9e8d,0x8c44054a,0x00000000,0x00000000}},	//   xyre, йене, --, --, 
   {{0x20d804e6,0x69dc00e4,0x00000000,0x00000000}},	//   _déis_, vyre, --, --, 
   {{0x0eb80184,0x69dc015d,0x00000000,0x00000000}},	//   _буйы_, wyre, --, --, 
   {{0x69dda525,0x20d80036,0xa3d801ad,0x15f805dc}},	//   tyre, _féis_, ाहत_, ्पार_, 
   {{0x20d80798,0x8cc8c019,0x80a8015b,0x69dc00ad}},	//   _géis_, _موثق_, কার্, uyre, 
   {{0x612c145e,0xfc3c01a8,0x85e80116,0xcbf802c9}},	//   pûle, gdís_, ңдав_, _مرخص_, 
   {{0x69dc0ec3,0xb87801a8,0x00000000,0x00000000}},	// [2d420] syre, _glím, --, --, 
   {{0x693c0053,0x69dda526,0x7c5404fb,0x69c83167}},	//   _kōek, pyre, _پلیر_, ädes, 
   {{0x41a40034,0xfad4008f,0x35a097c3,0x69dc0200}},	//   _कैंस, _הויך_, захг, qyre, 
   {{0x20d80491,0xdb0c06ed,0x15b80032,0x610800bc}},	//   _léir_, _praç, шыуы_, vělo, 
   {{0x26181d15,0x7b0403b2,0x00000000,0x00000000}},	//   _बुरी_, _ártí, --, --, 
   {{0xdb0ca75a,0xd3c400db,0x00000000,0x00000000}},	//   _vraç, تتمى, --, --, 
   {{0xdb0c010e,0xe134004e,0x00000000,0x00000000}},	//   _wraç, онкы, --, --, 
   {{0xb9eda527,0xdb0da528,0x9f541bf6,0xf8bc020c}},	//   _ነው_, _traç, ович, _dhéw_, 
   {{0x20d80332,0xcf8c0014,0x00000000,0x00000000}},	//   _béir_, نژو_, --, --, 
   {{0xc3047251,0xc0c002d3,0x20d801e7,0x00000000}},	//   _ابرو, _ድዮም_, _céir_, --, 
   {{0xa13c00de,0xb8781d1d,0xe7f0000d,0x00000000}},	//   _apķe, _slím, _घेघा_, --, 
   {{0x1c38040e,0x62984f99,0x20d80789,0xf1b002e4}},	//   изны_, lfvo, _véis_, _מסע_, 
   {{0x20d9a529,0xa3d83af4,0x79a41945,0x704400db}},	//   _wéis_, ाहि_, әрге, _ارمە, 
   {{0xde584dba,0x00000000,0x00000000,0x00000000}},	//   _такі_, --, --, --, 
   {{0x693c00b0,0x7e68005a,0xab640327,0x6298002f}},	//   _kōeh, _iefp, _ġżej, ifvo, 
   {{0x63a0009a,0xa3d82713,0x00000000,0x00000000}},	//   _opmn, ाहा_, --, --, 
   {{0x69c9a52a,0xfc3da52b,0x5b2400ae,0x00000000}},	// [2d430] äder, rdís_, _وفعل, --, 
   {{0xf645a52c,0x629801f5,0xdb0c007c,0xb87808a5}},	//   схан, jfvo, _braå, _klík, 
   {{0xcd64010c,0x58d485ce,0x00000000,0x00000000}},	//   _መደናገ, _донт, --, --, 
   {{0xa63402bf,0x798400ca,0x629801f5,0x93586885}},	//   їнці, mujw, efvo, арку_, 
   {{0xe78402a9,0x00000000,0x00000000,0x00000000}},	//   _нуро, --, --, --, 
   {{0xe3d802f5,0x63a00240,0x03a001f0,0x00000000}},	//   _দেহব, _dpmn, фишо, --, 
   {{0x20d80491,0x2360005f,0x6efc01e1,0x00000000}},	//   _réir_, ģija_, _lábè, --, 
   {{0xfbdc06ed,0x00000000,0x00000000,0x00000000}},	//   ncês_, --, --, --, 
   {{0x79840526,0xb879a52d,0xe2c801c8,0x8ee80798}},	//   hujw, _alík, _گولو_, имив_, 
   {{0x8d743009,0x79842dee,0x94d8000d,0x00000000}},	//   ياجا, kujw, _भकुआ, --, 
   {{0x7e6804cc,0x79840526,0xe2c99c37,0x00000000}},	//   _defp, jujw, _دولو_, --, 
   {{0x386800d8,0xfafc0240,0x79840455,0x00000000}},	//   _necr_, ksës_, dujw, --, 
   {{0x2548ac4c,0x20d801e7,0x3fc801d3,0xfafc036e}},	//   _işle_, _téir_, _ندوی_, jsës_, 
   {{0x7644044e,0x7e680048,0x79845a6d,0xbea000f7}},	//   _ngjy, _gefp, fujw, _жашк, 
   {{0x7985a52e,0x20d80036,0xdce80153,0x1db000cd}},	//   gujw, _kéip_, judė, _जनयत, 
   {{0xfc3c0407,0x1ccc031c,0x00000000,0x00000000}},	//   seía_, _ློག_, --, --, 
   {{0x2fdc0004,0x3868003a,0x8b644d3f,0x00000000}},	// [2d440] nyug_, _decr_, _باعم, --, 
   {{0x798407a8,0x98b8005f,0x63a0020b,0x1db06173}},	//   bujw, _visā_, _rpmn, _जनमत, 
   {{0x05a83da1,0xd39801e0,0x38680205,0xfafc0200}},	//   рвей_, ҙәтә_, _fecr_, rsët_, 
   {{0x6e214534,0x76440240,0xfafc0200,0x00000000}},	//   _mynb, _egjy, ssët_, --, 
   {{0x29000069,0x68e5a52f,0x6d4401f4,0x22580108}},	//   miia_, mkid, _miia, билы_, 
   {{0x6d44db6d,0x290018a6,0x00000000,0x00000000}},	//   _liia, liia_, --, --, 
   {{0x27e1a530,0x7e69a531,0x84e402bf,0xe3d80eac}},	//   lyin_, _refp, _довж, _দেশব, 
   {{0x26d9a532,0x68e5a533,0x27e00050,0x290018a6}},	//   _horo_, nkid, oyin_, niia_, 
   {{0x26d9a534,0x27e00605,0x68e5a535,0xb87826b8}},	//   _koro_, nyin_, ikid, _slík, 
   {{0x26d9a536,0x2900123c,0x6d4401ab,0x27e00086}},	//   _joro_, hiia_, _aiia, iyin_, 
   {{0x6d45a537,0x29003266,0x68e5a538,0xf6500302}},	//   _biia, kiia_, kkid, וצת_, 
   {{0x26d9a539,0x6d44020c,0x6e200334,0x2bfc0037}},	//   _loro_, _ciia, _dynb, _लेहू_, 
   {{0x29000ffb,0x7984014b,0x26d80241,0xbc2400cf}},	//   diia_, wujw, _ooro_, تردى, 
   {{0x26d9a53a,0x6e21a53b,0x79840223,0x68e40083}},	//   _noro_, _fynb, tujw, ekid, 
   {{0x6d45a53c,0x1959a53d,0xb8680261,0x8fc400db}},	//   _fiia, сабы_, ијае_, _وزۇن, 
   {{0x7984337a,0x68e40280,0x27e00204,0xf8bc01fb}},	//   rujw, gkid, fyin_, _nhét_, 
   {{0x26d9a53e,0xf7707405,0xfbdc00d8,0xb8d004af}},	// [2d450] _boro_, باز_, rcês_, _टस_, 
   {{0x6d440472,0x68e40083,0xfafc83cc,0x3a800014}},	//   _ziia, akid, asër_, _کُھہ, 
   {{0x26d9a53f,0x254807b3,0xe3b0168d,0x27e0090e}},	//   _doro_, _oğlu_, ێره_, ayin_, 
   {{0x27e00585,0xe4e41ed2,0x6d45a540,0x64c0037e}},	//   byin_, мічн, _xiia, 版iph, 
   {{0x26d9a541,0xb9080882,0x27e0020c,0xdce80153}},	//   _foro_, dhiḥ_, cyin_, sudė, 
   {{0xdb0cbaac,0x883800d9,0x00000000,0x00000000}},	//   _araú, _לתרו, --, --, 
   {{0x692c0112,0xb87801ef,0x00000000,0x00000000}},	//   ißen, _plíh, --, --, 
   {{0x26d9a542,0x54544f65,0xf8bc001e,0x00000000}},	//   _zoro_, _хват, _ghét_, --, 
   {{0x26d9a543,0x6d4425e4,0x0eb80139,0x98b8054e}},	//   _yoro_, _riia, буны_, _zisă_, 
   {{0x6e20138f,0x68e401c0,0x6d4400af,0x0d85a544}},	//   _pynb, zkid, _siia, плон, 
   {{0xb9080a28,0xfe6cebe8,0x6d4420ac,0x27e00007}},	//   bhiḥ_, اگه_, _piia, zyin_, 
   {{0x27e1a545,0x692c0730,0x6d44ab03,0x68e4005a}},	//   yyin_, eßen, _qiia, xkid, 
   {{0x29000421,0x6d4425c6,0x6e206e1c,0x95f8000d}},	//   viia_, _viia, _wynb, ्पुट_, 
   {{0x290018a6,0x273400c5,0xa13403e6,0xb11400f7}},	//   wiia_, mäng_, _فرۆش, _اقچا_, 
   {{0x26d9a546,0xc3300302,0x27e00198,0x290002b1}},	//   _roro_, גום_, wyin_, tiia_, 
   {{0x26d9a547,0x27e1a548,0x68e5a549,0x7d78011a}},	//   _soro_, tyin_, ukid, _הנקו, 
   {{0x26d9a54a,0x68e5a54b,0x46e95d50,0xfafc00e8}},	// [2d460] _poro_, rkid, бдан_, rsër_, 
   {{0x26d9a54c,0x27e00493,0x98a80034,0x29000418}},	//   _qoro_, ryin_, ymać_, siia_, 
   {{0x26d9a54d,0x27e1a54e,0x2901a54f,0xf8bc0208}},	//   _voro_, syin_, piia_, _phét_, 
   {{0x26d9a550,0xa3d8000d,0x00000000,0x00000000}},	//   _woro_, ाहल_, --, --, 
   {{0x2ca0002e,0x93540efc,0x273401e3,0x78a80254}},	//   _mbid_, وروچ, jäng_, õgve, 
   {{0x2734007c,0x00000000,0x00000000,0x00000000}},	//   däng_, --, --, --, 
   {{0x2ca1a551,0xf8bc004d,0x35a06b2f,0xf1a00ce8}},	//   _obid_, _thét_, _парг, ерын, 
   {{0x2ca0025c,0x98a801a6,0xa1142f84,0x7578011a}},	//   _nbid_, rmać_, بوبت, _לטלפ, 
   {{0x3aec000d,0xd36c00cf,0x273571ec,0x00000000}},	//   _hüpe_, _نۇن_, gäng_, --, 
   {{0x2ca1a552,0x3aec0790,0x00000000,0x00000000}},	//   _abid_, _küpe_, --, --, 
   {{0xbb180356,0x5fa80b67,0x00000000,0x00000000}},	//   frîn, _कनकल, --, --, 
   {{0xcf480023,0xb8780118,0x00000000,0x00000000}},	//   _ነቐፌታ, _hlív, --, --, 
   {{0xe81c2871,0xb87803b2,0x63a400d8,0x6d4401e4}},	//   _भुला_, _klív, çinh, ŭjap, 
   {{0x610800bc,0xaa58372a,0x692c002f,0x63a40135}},	//   děli, зиру_, ußen, ħinh, 
   {{0x3f500208,0x5d5401d5,0x1db0043e,0x00000000}},	//   _hâu_, _ўкит, _जनित, --, 
   {{0xb879a553,0x6c8400db,0x27340254,0x00000000}},	//   _llív, _كلىم, händ_, --, 
   {{0x5b140276,0x27340267,0xb879a554,0xc62400cc}},	// [2d470] _омит, känd_, _olív, _বলগা_, 
   {{0xdb0c004e,0x3f5001fb,0x66b4009d,0x1db072a2}},	//   _isaï, _mâu_, нбуу, _जनात, 
   {{0x3f5007ae,0x94d4063b,0x00000000,0x00000000}},	//   _lâu_, можц, --, --, 
   {{0xb8780120,0xa3d800dc,0x610801ef,0x00000000}},	//   _alív, ाहं_, běli, --, 
   {{0xb8780579,0x3f50001e,0x00000000,0x00000000}},	//   _blív, _nâu_, --, --, 
   {{0xf8bc06af,0x261807f7,0xd29800d4,0x95c800fb}},	//   _thés_, _बुकी_, ітлі_, _һуға_, 
   {{0xf4840276,0x69d8031c,0x00000000,0x00000000}},	//   _нуан, _żvez, --, --, 
   {{0x27340267,0x10a40276,0xee4c0022,0x3f500051}},	//   täng_, фиин, hẽte_, _bâu_, 
   {{0x3f5007ae,0x2734000d,0xa3d800cd,0x732400e5}},	//   _câu_, bänd_, ाहः_, _فقرہ_, 
   {{0x0ea811ed,0x3f500016,0x0ecc09bb,0x273442a7}},	//   цкой_, _dâu_, ़ाधड, räng_, 
   {{0x693c00b0,0xd130003a,0xdb0c0e78,0xbb18054e}},	//   _kōet, _sp̅u_, _spaß, trîn, 
   {{0x13e02f8b,0x2735a555,0x2ca00135,0x4c3401c6}},	//   _মেয়, mäne_, _qbid_, дэгт, 
   {{0x273519e0,0x4fc000db,0x3f500208,0xe8680419}},	//   läne_, _شەدە, _gâu_, _nášľ, 
   {{0x63a43630,0x99840014,0x00000000,0x00000000}},	//   çini, کلٲو, --, --, 
   {{0xa3b4038e,0xbb4050d3,0x2ca14e8c,0xa3e40073}},	//   _छैन_, терк, _tbid_, _पॅन_, 
   {{0xb8780008,0x2618033f,0x69f401c6,0x9e1c0354}},	//   _olíu, _बुगी_, дүүт, _урчĕ_, 
   {{0x3f50004d,0x4038010f,0xcdc54da1,0x00000000}},	// [2d480] _xâu_, ַגעג, _хаққ, --, 
   {{0x6c68066d,0xddc802fb,0xc9a831af,0xc954005b}},	//   _بلکہ_, ladš, _двое_, _отмы, 
   {{0x2734049f,0x00000000,0x00000000,0x00000000}},	//   vänd_, --, --, --, 
   {{0x2d5003b7,0x1ccc025c,0x610800bc,0x1db012eb}},	//   _mãe_, _ློབ_, pěli, _जनसत, 
   {{0xd5b0004d,0x95f801ad,0x58940166,0x2734007c}},	//   _ấn_, ्पॉट_, _яшэу, tänd_, 
   {{0xdebc069c,0x98b802d5,0x3f51a556,0xddd80790}},	//   ታትን_, _visą_, _râu_, _nevş, 
   {{0x3f500016,0x05641ed2,0xf8bc01fb,0x2735a557}},	//   _sâu_, _іван, _khép_, ränd_, 
   {{0xf9900302,0xdfb40063,0x273401e3,0x03a4014b}},	//   דרה_, ебињ, sänd_, _оибо, 
   {{0xb7d804ac,0x0324b754,0x76400153,0xa3c4012d}},	//   ַקטי, _ждан, žnyt, एमओ_, 
   {{0xb87808a5,0xddd80205,0x2734013d,0x00000000}},	//   _hlít, _cevş, bäne_, --, 
   {{0xdb2001ed,0xab6800e2,0xddd803e0,0x27340166}},	//   _ítél, _leļļ, _devş, cäne_, 
   {{0xf8bc004d,0x3f500208,0x00000000,0x00000000}},	//   _nhép_, _tâu_, --, --, 
   {{0x69c87c1d,0x00000000,0x00000000,0x00000000}},	//   åden, --, --, --, 
   {{0xddd805d1,0xb9c40107,0xaa880014,0x00000000}},	//   _gevş, мёби, ونُم_, --, 
   {{0x986c0419,0xd914005b,0x46d000bc,0x00000000}},	//   _vôľu_, едвы, सानह, --, 
   {{0xdb0da558,0xf8bc001e,0x3994067c,0xc99c0023}},	//   _isaí, _chép_, rçs_, _ምግፋፍ_, 
   {{0xb9040d41,0x4bc000fd,0xa2780240,0x00000000}},	// [2d490] _बक_, _йөрг, _ከጽንዕ_, --, 
   {{0xb8780113,0x1a640424,0xf7280006,0x99980798}},	//   _alít, _سیری_, іцай_, _екот_, 
   {{0xb8780413,0x00000000,0x00000000,0x00000000}},	//   _blít, --, --, --, 
   {{0xf8bc001e,0xb87804d4,0x980c015b,0x2478001f}},	//   _ghép_, _clít, _শরীফ_, ጠቀሱት_, 
   {{0xb87800c6,0x1ccc0327,0x00000000,0x00000000}},	//   _dlít, _ློན_, --, --, 
   {{0xca300131,0x63c401e0,0xe680022e,0xb8782bb4}},	//   ﺭﯛﺵ_, ташҡ, g訴da_, _elít, 
   {{0xbbc88004,0xb0700c60,0xab680171,0xe6940150}},	//   ामुक, вқеъ, _zeļļ, _ширы, 
   {{0x82d4cffe,0x00000000,0x00000000,0x00000000}},	//   ддәс_, --, --, --, 
   {{0xd130003a,0xd02401c0,0xcf451439,0x00000000}},	//   _sp̅s_, эмий, нний, --, 
   {{0x4d642082,0xb8e80327,0xb878032e,0x61080118}},	//   нков, _ྲལ_, _klís, dělu, 
   {{0xdcec00b0,0x82480023,0x00000000,0x00000000}},	//   _ōhāu, _ሓሳባቶ, --, --, 
   {{0x998c068f,0x1c0000af,0xa0c4007b,0x9f04104c}},	//   łeś_, _लेहल_, _ليمو, _یونو, 
   {{0xb878315a,0x8fa400c0,0xa0c416cc,0x8e8400f3}},	//   _moíd, _чале, _جينو, _згле, 
   {{0xb87802d2,0x26181bbb,0x00000000,0x00000000}},	//   _olís, _बुझी_, --, --, 
   {{0xf8bc07ae,0x09cc015b,0x26dc0793,0x4fc002dd}},	//   _phép_, রন্থ, övom_, _شەگە, 
   {{0x1c0017cb,0x00000000,0x00000000,0x00000000}},	//   _लेवल_, --, --, --, 
   {{0x6da03ba6,0x46e805bc,0xca740276,0xb87802d2}},	// [2d4a0] _чиқа, пдан_, _пуны, _alís, 
   {{0xb8780d12,0x37dc03d4,0x00000000,0x00000000}},	//   _slít, _নেহৰ, --, --, 
   {{0xf8bc001e,0x05640395,0x00000000,0x00000000}},	//   _thép_, хвен, --, --, 
   {{0xdebc1e38,0xb878e0ff,0x3e8401e1,0x00000000}},	//   ታትና_, _coíd, _kítà_, --, 
   {{0xa294242f,0xb879a559,0x37e02e36,0x69c801bf}},	//   валі, _elís, _бояг, ædef, 
   {{0xb8797189,0x7bc83822,0xf8bc0129,0x3e840241}},	//   _flís, _águe, _ikéa_, _mítà_, 
   {{0xe3d8015b,0x44f80024,0x00000000,0x00000000}},	//   _দেখব, _ехаў_, --, --, 
   {{0x290c0687,0xa3b4000d,0x6384014b,0xb87801ef}},	//   édah_, _छैथ_, _аҳда, _ulít, 
   {{0x247c02d3,0xff0402d5,0xdb0c0432,0xb2202cc8}},	//   _ኣሽሓት_, еянн, _araý, кмәл, 
   {{0xb031a55a,0xdb0c010e,0x00000000,0x00000000}},	//   ыныш, _braý, --, --, 
   {{0x69c812e8,0xa3d87688,0xa3b4000d,0x4084009d}},	//   ådel, ाहक_, _छैत_, _зулб, 
   {{0xb87800db,0xdb0c010e,0x00000000,0x00000000}},	//   _llír, _draý, --, --, 
   {{0xddd801ed,0xcfa816ac,0xdeb40064,0x5eb4009d}},	//   _vevő, _ياهم_, _аблы, _айлт, 
   {{0x657c3a4a,0x6e900451,0xdb0c0332,0x00000000}},	//   _ovrh, _ملها, _tsaí, --, 
   {{0x693c00b0,0x61f802d0,0x00000000,0x00000000}},	//   _rōer, nzvl, --, --, 
   {{0xbc4800fd,0x537c0023,0x7c9400ae,0x00000000}},	//   _эчке_, _ኣርዑት_, _أشغا, --, 
   {{0x8194069c,0x69d87cfb,0x1bd40276,0x8cbc4c5b}},	// [2d4b0] _ዘይብሉ_, _àven, _ропя, षयरो, 
   {{0xb87800bc,0xaa1400c7,0x2d880135,0xefd40023}},	//   _plís, vẽva, żież_, ርኣዩ_, 
   {{0x6108012c,0xd914d31a,0x5a3400d8,0xba44030d}},	//   něls, _адны, _шнот, _яхий, 
   {{0xd5b00208,0x48c001ec,0xb87800e5,0x00000000}},	//   _ấm_, _кәуа, _elír, --, 
   {{0xd7c800aa,0x394800e4,0x20d801c7,0xf365a55b}},	//   _غوسه_, _iics_, _féiz_, хтен, 
   {{0xb864215c,0x00000000,0x00000000,0x00000000}},	//   _تاگو, --, --, --, 
   {{0x41b0007b,0x00000000,0x00000000,0x00000000}},	//   لمور, --, --, --, 
   {{0xbb1824ba,0xe3d8045e,0x6108012c,0x629c01e6}},	//   frîk, _দেওব, děls, _öron, 
   {{0x273401b8,0x657c1b5c,0x3948045a,0x00000000}},	//   läna_, _zvrh, _mics_, --, 
   {{0x39482503,0x00000000,0x00000000,0x00000000}},	//   _lics_, --, --, --, 
   {{0xcc886df1,0x31c404a9,0x30e402bf,0x4df401b9}},	//   ونده_, _ясав, _підб, тяпт, 
   {{0xdb0c0295,0xe1f00a2c,0xd7d00316,0x69c80194}},	//   _eraü, _اسك_, समाच, ådem, 
   {{0xca740276,0xaa140588,0x3f900139,0x205401af}},	//   кувы, hẽta, _äyup_, _стєр, 
   {{0x2735a55c,0x3948011c,0xefd402d3,0x3aec04cc}},	//   käna_, _aics_, ርኣይ_, _püpa_, 
   {{0x27340bc9,0xdb0d21a6,0xb8780798,0xc92802bf}},	//   jäna_, _araó, _alíq, довж_, 
   {{0x2734014a,0x3948045a,0x3e840248,0xcc8801e2}},	//   däna_, _cics_, _títà_, _ځنګه_, 
   {{0x657c04b9,0xc76404a9,0x39484b84,0x5f1800dc}},	// [2d4c0] _svrh, ئارى, _dics_, _पदम्_, 
   {{0xb8780332,0x16580006,0x00000000,0x00000000}},	//   _coíb, ерць_, --, --, 
   {{0x394800d8,0x2a780477,0x69c8005c,0x00000000}},	//   _fics_, marb_, æded, --, 
   {{0xc7641075,0xd4d40006,0x9f440200,0x00000000}},	//   _لاسى, лічэ, tymë_, --, 
   {{0x6f001cdf,0xc1d816d1,0x00000000,0x00000000}},	//   _omnc, यङ्ग, --, --, 
   {{0xdc180171,0x161c134e,0x74100066,0x00000000}},	//   _jāār, _बुकर_, جوها, --, 
   {{0x657c02f0,0x7f49a55d,0xb8782507,0xaaa45b14}},	//   _uvrh, _rifq, _klíp, ख्यक, 
   {{0x6f01a55e,0x394800cf,0x5f944727,0x00000000}},	//   _amnc, _xics_, гиит, --, 
   {{0x73300075,0xa8e001fb,0xb878007b,0x63780332}},	//   _چىقا, _độn, _hoíc, _dúná, 
   {{0xfc3c04d4,0xf7700375,0x016400cf,0xc2c400ec}},	//   nfíe_, סקת_, _акжо, _جيئي, 
   {{0x80a553b4,0x91c0035b,0x9e3c0118,0x01d8007b}},	//   _لمان, _гәыл, jeďt, _توضع_, 
   {{0x6f009c78,0xc0040166,0xaa1400e4,0x00000000}},	//   _emnc, _ипек, hẽsa, --, 
   {{0x39484b84,0xdb2401ed,0x7f48025c,0xa3d80da3}},	//   _rics_, ősít, _tifq, ाहट_, 
   {{0xdd942eca,0x212400a3,0x00000000,0x00000000}},	//   _бакы, lomh_, --, --, 
   {{0x394807d5,0x28c4146b,0xae0000d1,0x00000000}},	//   _pics_, _लोहि, _پويى, --, 
   {{0xad2401d9,0xaa140022,0x00000000,0x00000000}},	//   _پر٘و, vẽta, --, --, 
   {{0x3949a55f,0x2a79a560,0xa85400a7,0x212400a3}},	// [2d4d0] _vics_, barb_, ркуч, iomh_, 
   {{0xb8785178,0x2a78511b,0x2735a561,0x2124014f}},	//   _elíp, carb_, täna_, homh_, 
   {{0xf645a562,0x29840733,0x00000000,0x00000000}},	//   тхан, _кыяг, --, --, 
   {{0x27340054,0x61080210,0xe944072d,0x00000000}},	//   räna_, yśla, _پرپی, --, 
   {{0xd2a8b392,0x27340054,0xb8780309,0xdb0c0165}},	//   екле_, säna_, _ulíq, _hrañ, 
   {{0xb6e418d9,0xdb0c030a,0x6d481315,0x63780332}},	//   _рюмк, _krañ, íjaz, _súná, 
   {{0x10a5a563,0x35440064,0x00000000,0x00000000}},	//   гийн, _ахав, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x753801b2,0x4f245a52,0x00000000,0x00000000}},	//   _ihuz, лдиб, --, --, 
   {{0xdb0c05c7,0x229400f7,0xa3b802f2,0x00000000}},	//   _orañ, _ەلەس, _جافر_, --, 
   {{0x75380117,0x509400e3,0xaa1400c7,0x2734007c}},	//   _khuz, _ملاء, hẽra, känn_, 
   {{0x0cd00f22,0x2a780112,0x9e3c022a,0x00000000}},	//   াস্ত, warb_, veďt, --, 
   {{0xdb0da564,0x2a780112,0xd01000ec,0xcc880345}},	//   _arañ, tarb_, _ھلڻ_, ونگه_, 
   {{0xdb0da565,0x6f002ffc,0xb87808ce,0x00000000}},	//   _brañ, _umnc, _slíp, --, 
   {{0xbf1004d3,0x753800e4,0x0d200209,0xe6b4036b}},	//   _دووب, _ohuz, _гүнү, یلرگ, 
   {{0x35f8015b,0x9e3c00d7,0x00000000,0x00000000}},	//   ্থাৎ_, reďt, --, --, 
   {{0xdb0c0428,0x3c6000fd,0x06c801c0,0x2a7800db}},	// [2d4e0] _erañ, _укыг, нгай_, parb_, 
   {{0xdb0c03bd,0x75380526,0x7bc806ed,0x28c403e5}},	//   _frañ, _ahuz, _água, _लोरि, 
   {{0x448814a4,0xdb0c29d3,0xf8bc0429,0x09e5a566}},	//   ебен_, _grañ, _kkél_, _сонн, 
   {{0x7539a567,0xdb0c008c,0xc0cc001f,0x00000000}},	//   _chuz, _hrað, ጥቀስ_, --, 
   {{0xf48400dd,0x00000000,0x00000000,0x00000000}},	//   طانی, --, --, --, 
   {{0xff0800b5,0xc64400db,0x00000000,0x00000000}},	//   _odmは, _مئزى, --, --, 
   {{0x81a4007b,0x00000000,0x00000000,0x00000000}},	//   احتل, --, --, --, 
   {{0xdfd026c0,0x205402e8,0x00000000,0x00000000}},	//   قيب_, шкия, --, --, 
   {{0x9e742002,0x21240007,0xdd9000f1,0x00000000}},	//   لۇشت, romh_, ښود_, --, 
   {{0x75380327,0x212401bf,0x00000000,0x00000000}},	//   _zhuz, somh_, --, --, 
   {{0x9e340598,0x2360005f,0x52640014,0x9d140108}},	//   ренч, ģiju_, _خاقٲ, идоч, 
   {{0x98a80030,0x538000c7,0x75380200,0x00000000}},	//   tlač_, _уқәз, _xhuz, --, 
   {{0x75e801d3,0x0f300023,0x2734007c,0x00000000}},	//   _közú, _ብጥምየ, vänn_, --, 
   {{0x27340036,0xdb0c00b8,0xaa1400e4,0x00000000}},	//   wänn_, _prañ, vẽra, --, 
   {{0x7e79a568,0x1959a569,0xdd946f32,0x273404e6}},	//   matp, табы_, _тайы, tänn_, 
   {{0x7e79a56a,0xdb0c0165,0x98a800d7,0x00000000}},	//   latp, _vrañ, plač_, --, 
   {{0x3689a56b,0xd7940801,0x67d47b96,0xa3b400ab}},	// [2d4f0] есен_, ризъ, боту, _छैल_, 
   {{0x7539a56c,0xa7b80228,0xdb0da56d,0xbc7400db}},	//   _shuz, ылуу_, _trañ, _جەڭش_, 
   {{0x5455a56e,0x7539a56f,0xdb0c0309,0xd5b06d69}},	//   авет, _phuz, _urañ, تفا_, 
   {{0x7e79a570,0xe5680131,0x81a800eb,0x00000000}},	//   hatp, امنى_, গটা_, --, 
   {{0x7e780054,0xd6a8210e,0xe45800d4,0x00000000}},	//   katp, _لگام_, ужі_, --, 
   {{0x7e799e63,0x91e421e0,0x00000000,0x00000000}},	//   jatp, иоле, --, --, 
   {{0xf8bc00f2,0x75380036,0x66f4023a,0x7e7801e3}},	//   _kaé_, _thuz, _упру, datp, 
   {{0xf8bc82af,0x75380230,0x2d8000bc,0x00000000}},	//   _jaé_, _uhuz, ájem_, --, 
   {{0x241812c4,0x0ef806a6,0xf8bc0129,0x7e7801d5}},	//   _боты_, вэны_, _maé_, fatp, 
   {{0xb7b800c7,0x21640032,0x2d800219,0xe3b17233}},	//   _hyãs, штәг, šjem_, _عرق_, 
   {{0xe80c22e3,0x90980022,0x00000000,0x00000000}},	//   _सेना_, _авет_, --, --, 
   {{0x8c441b2e,0x6d540332,0x00000000,0x00000000}},	//   иене, _éxam, --, --, 
   {{0x7e79a571,0x4c343163,0x00000000,0x00000000}},	//   batp, рэнт, --, --, 
   {{0xe1640137,0x313000ee,0xb6040064,0x7e780055}},	//   _ئدەي, _теҗр, _kašė, catp, 
   {{0xf8bc1dd4,0x8d740075,0x092801c8,0xbec00171}},	//   _baé_, _ئاتا, نسري_, _šīga, 
   {{0x257c01e1,0x57d041ac,0x00000000,0x00000000}},	//   _lálá_, समूह, --, --, 
   {{0x3324009a,0xdb0c0bcd,0x7e68054e,0x00000000}},	// [2d500] konx_, _trað, _împâ, --, 
   {{0x254856f8,0x00000000,0x00000000,0x00000000}},	//   _işli_, --, --, --, 
   {{0x23646085,0x9aa410ef,0xc30415b4,0x00000000}},	//   _stmj_, _امپو, یبتو, --, 
   {{0x75d1a572,0xf8bc020c,0x83c404c2,0x00000000}},	//   تيما, _gaé_, ибеж, --, 
   {{0xe28598ec,0x741030bf,0xa3b00118,0x00000000}},	//   йған, يوما, टौं_, --, 
   {{0xfc3c2b76,0xe7480598,0x2d880034,0xd5ac01d3}},	//   nfía_, _сүзе_, ącej_, بہہ_, 
   {{0x7e79a573,0x257c01e1,0xd258187f,0x00000000}},	//   vatp, _dálá_, уці_, --, 
   {{0x1f75a574,0xf0340023,0x00000000,0x00000000}},	//   блия, _ብስምም, --, --, 
   {{0xdfd02a14,0x7e79a575,0xc30000f1,0x945c002b}},	//   سيد_, tatp, _وړتی, _sańg, 
   {{0x9ed97898,0x52740212,0xeea4003b,0x7ee401f4}},	//   умот_, _гуцу, атюк_, рцие, 
   {{0x7e79a576,0x23a002e2,0x00000000,0x00000000}},	//   ratp, lòj_, --, --, 
   {{0x62980165,0x00000000,0x00000000,0x00000000}},	//   lgvo, --, --, --, 
   {{0x7e79a577,0x629801f5,0xfc3c09e8,0x00000000}},	//   patp, ogvo, ffía_, --, 
   {{0x62981a4c,0xf8bd06cd,0x4498001f,0x00000000}},	//   ngvo, _saé_, ቀሳቀሰ_, --, 
   {{0xed540a16,0x58d4192a,0x25480724,0x7c8456e2}},	//   _кој_, бовт, _eşli_, _купе, 
   {{0x5c74005b,0x394c007c,0x00000000,0x00000000}},	//   _улит, ögs_, --, --, 
   {{0x0c9400db,0xaef80154,0xad1c011a,0x00000000}},	// [2d510] _ادىگ, ীকরণ_, _שוחר, --, 
   {{0xf8bd24c4,0x6d5001e4,0x00000000,0x00000000}},	//   _waé_, ĝhaŭ, --, --, 
   {{0xdce803b9,0x00000000,0x00000000,0x00000000}},	//   ltdı, --, --, --, 
   {{0xb8c4215c,0xe2c8004b,0xb60400c0,0x00000000}},	//   _ئزدى, یونو_, _rašė, --, 
   {{0xe7841d56,0x7de803e3,0xdce803b9,0xded40240}},	//   _муро, ləsd, ntdı, ርሓን_, 
   {{0xb6040153,0x00000000,0x00000000,0x00000000}},	//   _pašė, --, --, --, 
   {{0x63ac013f,0x256c033b,0x33240c6a,0x69c80419}},	//   _ɛnnɑ, _vòlò_, ronx_, ťdev, 
   {{0x50b43c85,0x4f9400d8,0xdce803e3,0x3ac80153}},	//   сску, броу, ktdı, lėpė_, 
   {{0x257c043b,0xd3700e4a,0x00c400fd,0x68e8017a}},	//   _tálá_, _رها_, слык_, êddi, 
   {{0xb6040064,0x7de401a9,0xf1a40114,0x00000000}},	//   _tašė, 喪sat, _врдн, --, 
   {{0x4d483be4,0x7170021f,0x692c002f,0x00000000}},	//   лпон_, _بۇعا, ißer, --, 
   {{0xf1c002d5,0x46cc05d7,0xcb680354,0xfafc0036}},	//   rašė_, _होनह, ламе_, spël_, 
   {{0xb0000055,0x00000000,0x00000000,0x00000000}},	//   _kuḍm, --, --, --, 
   {{0x9bb8031c,0xda64007b,0x7de803b9,0x00000000}},	//   _བརྫོ, قافي, fəsd, --, 
   {{0xc33006a9,0x17180156,0x8d940411,0xb8780022}},	//   פול_, ྱོནམ_, _العش, _voín, 
   {{0x0d200323,0x692c002f,0x00000000,0x00000000}},	//   _хүмү, eßer, --, --, 
   {{0x0685a578,0xfc3da579,0x00000000,0x00000000}},	// [2d520] йган, lfín_, --, --, 
   {{0x6b85a57a,0x06540953,0x00000000,0x00000000}},	//   _ivig, стаў, --, --, 
   {{0x4638ed4a,0x2734049f,0xfc3da57b,0xcb083695}},	//   учая_, länk_, nfín_, _ليکن_, 
   {{0x6b84fa6f,0x69dc0007,0xd4994012,0x7d54010f}},	//   _kvig, mxre, ирі_, צינד_, 
   {{0x87d801d9,0xdb0c0037,0x00000000,0x00000000}},	//   _صبحس_, _eraõ, --, --, 
   {{0xf8bc04fb,0x04f8015b,0xdb900131,0xf2c002e8}},	//   _akéh_, েকের_, _ﺑﻪﺯﻯ_, зсън, 
   {{0xc058005e,0x41c40c98,0x629801f5,0x835400ec}},	//   ліп_, сёла, rgvo, _ڇپرا, 
   {{0xb97808a8,0xd574068e,0x6b4002d2,0x00000000}},	//   אנקי, _фурь, bögg, --, 
   {{0x98a80165,0x3f81a57c,0xd09401e2,0x00000000}},	//   llaă_, éku_, زديګ, --, 
   {{0x3f880122,0xfc3c032e,0x46cc134e,0x00000000}},	//   čbu_, ffín_, _होमह, --, 
   {{0x628822a9,0x794c0241,0xc0d4001f,0x1cd9a57d}},	//   _iddo, _jòwì, ርሳል_, адны_, 
   {{0x69cc0aa2,0xdb9002dd,0x026002f2,0x00000000}},	//   हिनी, _ﺑﻪﺭﻯ_, _بێژێ, --, 
   {{0x69c800b5,0x9b5801c0,0xa0680166,0xadc000e4}},	//   æden, ригт_, _баҗа_, moẽm, 
   {{0x6b85a57e,0xdce82fbe,0xddc80841,0x290c020c}},	//   _dvig, rtdı, madž, èdan_, 
   {{0xddc80471,0x3ac80153,0x06e002dd,0x00000000}},	//   ladž, vėpė_, _ﺍﻷﻫﺩ, --, 
   {{0x3e4c03be,0x27343672,0x290c020c,0xb878013a}},	//   mət_, bänk_, édap_, _hlíz, 
   {{0xddc80bb8,0x7d0da57f,0x3e4c00ac,0x00000000}},	// [2d530] nadž, mics, lət_, --, 
   {{0x7d0da580,0xdb0c00b8,0x00000000,0x00000000}},	//   lics, _praõ, --, --, 
   {{0x3e4c03be,0xddc80b4b,0x6b840433,0x69c87fff}},	//   nət_, hadž, _zvig, ådet, 
   {{0x7d0da581,0xfc3c09c2,0x00000000,0x00000000}},	//   nics, nfío_, --, --, 
   {{0x889806a9,0xe3b0040b,0xddc80114,0x3e4c03be}},	//   _דברי, ٹرن_, jadž, hət_, 
   {{0xd1b97ea3,0x3e4c00ac,0xe3b005d9,0x7d0c0857}},	//   لابا_, kət_, عرن_, hics, 
   {{0x659462bd,0x6a9c0302,0xded4044e,0x941c013f}},	//   _нару, אשונ, ርናን_, rewɑ_, 
   {{0x62882252,0x3e4c00ac,0xa3b44ca3,0x6b4033fe}},	//   _eddo, dət_, _छैक_, möge, 
   {{0xb87804bf,0x7d0c01ed,0xc04c00f1,0x00000000}},	//   _blíz, dics, نږه_, --, 
   {{0xb8e803bd,0xe4500597,0x3f80025a,0x3e4c03be}},	//   _ིལ_, _أضف_, âkua_, fət_, 
   {{0xc6900302,0x7d0c0c8c,0xa3440166,0x2d80398f}},	//   ואי_, fics, _хэтл, éje_, 
   {{0x7d0da582,0x9bb80135,0x2d88012c,0xf52c02dd}},	//   gics, _བརྡོ, čce_, мкiн_, 
   {{0x28c445bf,0xfd6002e3,0xb8780077,0x6b40007c}},	//   _लोगि, _katọ, _coím, höge, 
   {{0x3e4c03be,0x7d0c01ab,0x5f740066,0x00000000}},	//   bət_, aics, _راهر, --, 
   {{0x7d0da583,0x7958013e,0x39e40107,0x4c68004e}},	//   bics, иятӣ_, одро_, _кийн_, 
   {{0x2735a584,0x7d0da582,0x6e400014,0xdb1c03b2}},	//   mäni_, cics, _وچھم, rvsá, 
   {{0x6b841709,0x2735a585,0x7bd8023a,0x2ca0045a}},	// [2d540] _uvig, läni_, äuut, _icid_, 
   {{0x69c801e6,0x0684155b,0x56200241,0x00000000}},	//   ådes, іген, _ìwọ́_, --, 
   {{0x35a005f5,0x273456da,0xe9740150,0x9f440419}},	//   дахг, näni_, _ءۇرد, nymá_, 
   {{0x69c80030,0xdb200108,0xbb180142,0x00000000}},	//   ťdes, ätöi, nsîn, --, 
   {{0x2ca00334,0x60c40332,0x00000000,0x00000000}},	//   _mcid_, _óimi, --, --, 
   {{0x3e4c0cc1,0x01884bf5,0x6b400112,0x273462cb}},	//   yət_, ащий_, böge, käni_, 
   {{0x2ca00098,0x35b00868,0x273456da,0x00000000}},	//   _ocid_, _обёр, jäni_, --, 
   {{0xf48458c2,0x27340724,0x2ca0051f,0x3e4c00ac}},	//   _واقی, däni_, _ncid_, vət_, 
   {{0x69cc0574,0x7d0da586,0x78f80a7c,0x69d8032e}},	//   हिडी, vics, יפקו, _ávef, 
   {{0x201800a8,0xddc8248d,0x2ca1a587,0x7cfc00e8}},	//   ări_, radž, _acid_, _kërg, 
   {{0x7d0c0c8c,0xb65800c8,0x69c8037e,0x2ee40129}},	//   tics, ידיש, ædel, _donf_, 
   {{0x3e4c0cc1,0x7cfc0023,0xddc80064,0x00000000}},	//   rət_, _mërg, padž, --, 
   {{0x7ac4bda8,0x3e4c03be,0x2ca001ab,0xdfd43c7f}},	//   осве, sət_, _dcid_, _холы, 
   {{0x7d0da588,0x387c0219,0x98a000a2,0xf42400a2}},	//   sics, _žur_, _ruhı_, _ýäň_, 
   {{0x7d0da589,0x0e7401f1,0x2ca00334,0x3e4c00ac}},	//   pics, äčší, _fcid_, qət_, 
   {{0x6e40acdc,0x2ca00334,0x7cfc00e8,0x6b400112}},	//   _غنيم, _gcid_, _sërf, vöge, 
   {{0x31b5a58a,0x7cfc069c,0x69c9a58b,0xad241178}},	// [2d550] _आन्ध, _përf, åder, _تىيى, 
   {{0x7cfc0de2,0x66b4009d,0x6b4000e5,0x00000000}},	//   _bërg, мбуу, töge, --, 
   {{0xecd0012c,0x69cc07f8,0xfbc007b7,0x00000000}},	//   _तोडफ, हिणी, शिकम, --, 
   {{0x2eb40c00,0x7cfc044e,0xfd6001f2,0x5fbc4f71}},	//   _अस्त, _dërg, _satọ, ्टाल, 
   {{0x5334abba,0x7cfc0200,0xded40092,0x00000000}},	//   педт, _tërf, ርናና_, --, 
   {{0xe3b0082e,0x6ed80241,0x2734005b,0x7cfc036e}},	//   ضره_, _ḿbé, yäni_, _fërg, 
   {{0xd174cced,0x7cfc036e,0xf4842e26,0x00000000}},	//   чылы, _kërd, _муан, --, 
   {{0x69cc0574,0x865c02d3,0x2734023a,0x25ac01e3}},	//   हिती, _ቅሳነት, väni_, _ädla_, 
   {{0x3cdc0490,0x2ca00175,0x00000000,0x00000000}},	//   गाने_, _rcid_, --, --, 
   {{0x3f840316,0xb8780077,0x2ca03c36,0x72980014}},	//   _dvou_, _elíx, _scid_, _خضرس_, 
   {{0xbb18019f,0x2ca00334,0x3f8402f0,0x3208074d}},	//   tsîn, _pcid_, _evou_, _тхан_, 
   {{0x80a09543,0x7cfc04e6,0x69c89069,0x645c01d3}},	//   _गाये, _nërd, ædem, _őriz, 
   {{0x27354bd1,0x290c007f,0x3f8003b2,0x00000000}},	//   säni_, èdam_, ákut_, --, 
   {{0xbea02a30,0xc0d40092,0x3ea0022e,0x00000000}},	//   _зашк, ርዳል_, _зишг, --, 
   {{0x7cfc0200,0x78ac0051,0x3f84013a,0x00000000}},	//   _bërd, _bbcv, _zvou_, --, 
   {{0x2ca001d9,0x00000000,0x00000000,0x00000000}},	//   _ucid_, --, --, --, 
   {{0x6d4400ad,0x00000000,0x00000000,0x00000000}},	// [2d560] _ihia, --, --, --, 
   {{0x7cfc067d,0x69cc007d,0x00000000,0x00000000}},	//   _përg, हिदी, --, --, 
   {{0x6d45a58c,0x7e7c007d,0x7cfc0036,0x846402e8}},	//   _khia, _õppe, _fërd, пъле, 
   {{0x7cfc0023,0x74a802dd,0x03a40117,0x00000000}},	//   _gërd, йсің_, зидо, --, 
   {{0x6d4414d0,0xd0180227,0x7cfc00e8,0x68e40162}},	//   _mhia, yańa_, _wërg, mjid, 
   {{0x6d4402a4,0x2d8400b5,0x290000d8,0x27e0025c}},	//   _lhia, _ovne_, lhia_, mxin_, 
   {{0x6d45a58d,0x3f840316,0x290000b0,0xf62054f9}},	//   _ohia, _svou_, ohia_, _здро, 
   {{0x2901a58e,0x36180302,0x6d44090c,0xd0180227}},	//   nhia_, _הולד, _nhia, wańa_, 
   {{0x42540220,0x290002b1,0x43740107,0x752000e5}},	//   _етет, ihia_, _хубт, énze, 
   {{0x644176a7,0x7bc9a58f,0x27e00137,0x68e4026c}},	//   _izmi, _águi, ixin_, hjid, 
   {{0x2901a590,0x6d447ea6,0x7cfc0240,0xba2400fe}},	//   khia_, _bhia, _lëre, _মণ্ড_, 
   {{0x6d44393c,0x68e51213,0xe6c800dc,0x3f840118}},	//   _chia, jjid, रयुज, _tvou_, 
   {{0x2901a591,0x6d45a592,0x7b64081d,0x2d840e38}},	//   dhia_, _dhia, ятне, _evne_, 
   {{0xdd940372,0xd0180227,0x3f800006,0x290002b1}},	//   _жакы, qańa_, škus_, ehia_, 
   {{0x7cfda593,0x6d440fa3,0x69c80fac,0x29000332}},	//   _përd, _fhia, ådep, fhia_, 
   {{0x6d45a594,0x26d80100,0x7cfc00e8,0x2901a595}},	//   _ghia, _anro_, _bëre, ghia_, 
   {{0x7a4406af,0x7cfc036e,0x3e84013a,0xd9d03769}},	// [2d570] fété, _vërd, cítí_, رەڭگ, 
   {{0x29006661,0xf8bc0098,0x6d44020c,0x7a44003e}},	//   ahia_, _ojég_, _zhia, gété, 
   {{0x6441567d,0x2d540311,0x2901a596,0x187412e7}},	//   _azmi, _oţel_, bhia_, _огня, 
   {{0x2901a597,0xf1c400bc,0x00000000,0x00000000}},	//   chia_, žáky_, --, --, 
   {{0x27e0004d,0x69d80129,0x53a40120,0x7cfc0200}},	//   cxin_, _àver, фалб, _kërb, 
   {{0x81c000e2,0x7c2801bf,0x2004a2f1,0x00000000}},	//   _ģērb, _øgru, dzmi_, --, 
   {{0x7cfc0036,0x2bc40073,0xe3b00137,0xfc3c032e}},	//   _zëre, _लईभा, _ۅرل_, ffík_, 
   {{0x7cfc002e,0x3aec0037,0x622400d1,0x00000000}},	//   _yëre, _küps_, رۈنە, --, 
   {{0x6d45a598,0x9f44023a,0xcf4551fa,0x6b40007c}},	//   _rhia, kymä_, мний, höga, 
   {{0x6d440731,0x4d65a599,0x5f4400fb,0x69c801bf}},	//   _shia, мков, ндыҡ, ædek, 
   {{0x6d440457,0x00000000,0x00000000,0x00000000}},	//   _phia, --, --, --, 
   {{0x2901a59a,0x6d4401d4,0x629c01a8,0x27341f65}},	//   xhia_, _qhia, _öror, länt_, 
   {{0x27e0031c,0x00000000,0x00000000,0x00000000}},	//   xxin_, --, --, --, 
   {{0x29000053,0x6d440175,0x0c4000c7,0x5fbc0bae}},	//   whia_, _whia, нҭқо, ्टरल, 
   {{0x6d440e37,0x2901a59b,0xc3300302,0xfe401b74}},	//   _thia, thia_, דום_, _иншо, 
   {{0x29000357,0x6d440093,0x6efc003a,0x27e0009d}},	//   uhia_, _uhia, _dêbe, txin_, 
   {{0x46e9a59c,0x2901a59d,0x06e80e92,0x27340267}},	// [2d580] одан_, rhia_, омак_, känt_, 
   {{0x2901a59e,0x68e5a59f,0x7cfc0240,0x27e00014}},	//   shia_, sjid, _vëre, rxin_, 
   {{0x2901a5a0,0x6abda5a1,0x7cfc002e,0xdbdc0248}},	//   phia_, merf, _wëre, _láìr, 
   {{0x6abda5a2,0x98c00356,0x00000000,0x00000000}},	//   lerf, ăpăm_, --, --, 
   {{0x7a4473a0,0x27e00327,0x25fc0073,0x4b78010f}},	//   pété, qxin_, ऊनही_, קאַו, 
   {{0x6abda5a3,0x7cfc044e,0x4168026a,0x48c00032}},	//   nerf, _kërc, ојим_, _яҙға, 
   {{0xf5540131,0x6abc1052,0x6440012d,0x69c801bf}},	//   سلۇب_, ierf, _wzmi, ædeh, 
   {{0x6abda5a4,0x78f8010f,0x00000000,0x00000000}},	//   herf, ַליפ, --, --, 
   {{0x6abc008c,0x20041674,0xdb0c00a2,0x00000000}},	//   kerf, uzmi_, _asaý, --, 
   {{0x6abc5522,0xe80005d7,0x200401a9,0x2734007c}},	//   jerf, लैया_, rzmi_, mäns_, 
   {{0x273401b8,0xecd009bb,0x84f00037,0x00000000}},	//   läns_, _तोहफ, _अकाट_, --, 
   {{0x7cfc0240,0x6abc0175,0x06e00150,0x00000000}},	//   _sërb, eerf, _ﺍﻷﻴﺩ, --, 
   {{0x7cfc069c,0x6abda5a5,0x273401b8,0x9f44023a}},	//   _përb, ferf, näns_, tymä_, 
   {{0xe6c81a3e,0x6abda5a6,0xc0d41954,0x00000000}},	//   रयोज, gerf, ርዳም_, --, 
   {{0x6dc0010b,0x7e6802d0,0x7cfc036e,0xaa583b9e}},	//   _асыж, _iffp, _vërb, диру_, 
   {{0x69d9a5a7,0x6b40007c,0x00000000,0x00000000}},	//   _švec, röga, --, --, 
   {{0x7cfc0240,0xd75800c6,0x6b4001a8,0x96f80120}},	// [2d590] _tërb, سلات_, mögn, пеат_, 
   {{0x6abc0072,0xfd8000d1,0xc6780092,0x00000000}},	//   cerf, ﻨﺴﺎﻥ_, ይጄሪያ_, --, 
   {{0x2734049f,0x00000000,0x00000000,0x00000000}},	//   vänt_, --, --, --, 
   {{0xf770021a,0x69cc044b,0x00000000,0x00000000}},	//   _لاس_, हिरी, --, --, 
   {{0xdb0c00c5,0x80a00037,0xdebc1ef7,0x087400df}},	//   _osaü, _गा़े, ሳስን_, _רעשט_, 
   {{0x87780bd9,0x9bb80327,0xfafc4113,0xdbdc0248}},	//   _מאשי, _བརློ, mpës_, _náír, 
   {{0x27340267,0x51540798,0x490400bc,0x00000000}},	//   ränt_, нтиу, सोको_, --, 
   {{0x4fe9a5a8,0x0fc40cdd,0xdb0c0055,0x41b000c6}},	//   змин_, ейин, _asaü, امير, 
   {{0x6abc0175,0x3f8002f0,0x386801ef,0x00000000}},	//   yerf, ákup_, _mfcr_, --, 
   {{0x0ea82075,0x72a00131,0x00000000,0x00000000}},	//   чкой_, _شەبن, --, --, 
   {{0xd0d40395,0x00000000,0x00000000,0x00000000}},	//   _пожъ, --, --, --, 
   {{0xfd1c1570,0x6abda5a9,0x776c02d0,0xb87801a8}},	//   gnì_, werf, _otcx, _hníf, 
   {{0x6abda5aa,0x7c38012d,0x6028036e,0x00000000}},	//   terf, żurn, rëmë, --, 
   {{0x7cfc044e,0x6abc17da,0x387c01e4,0xe8e00208}},	//   _përc, uerf, _ĵura_, _trừu_, 
   {{0x6abda5ab,0x443801fb,0x7f380375,0x00000000}},	//   rerf, ́p_, _צעצו, --, 
   {{0x386801ab,0xfe340375,0x00000000,0x00000000}},	//   _cfcr_, _ארצי_, --, --, 
   {{0x657c02b9,0x6abda5ac,0xb8780248,0x00000000}},	// [2d5a0] _swrh, perf, _oníf, --, 
   {{0xb6a1a5ad,0x86c4009a,0x2734007c,0x00000000}},	//   лиул, عيان, väns_, --, 
   {{0x06e000eb,0x00000000,0x00000000,0x00000000}},	//   _যতদি, --, --, --, 
   {{0x7cfc0694,0x74100214,0x24800332,0x00000000}},	//   _këra, گوها, úim_, --, 
   {{0x23481db7,0x7cfc002e,0xf8b0011a,0x00000000}},	//   وستی_, _jëra, _גשר_, --, 
   {{0xf8ac00aa,0xdebc1b49,0x27340267,0x741002da}},	//   _پکې_, ሳትን_, räns_, دوها, 
   {{0x11682a9f,0x00000000,0x00000000,0x00000000}},	//   ولوی_, --, --, --, 
   {{0x59d0078a,0xf990011a,0x00000000,0x00000000}},	//   हितर, ארה_, --, --, 
   {{0x0325099b,0x30100395,0x23480066,0x00000000}},	//   _здан, лдър, _قسطی_, --, 
   {{0xfafc0023,0x80a000c5,0xd0600023,0xbea401a9}},	//   hpër_, _गावे, _ተዳልዩ_, хший, 
   {{0x3204006d,0x7bcc01d4,0x123001d3,0xd498030d}},	//   czny_, wvcu, _پڑوس, _арĕ_, 
   {{0x7cfc00e8,0x00000000,0x00000000,0x00000000}},	//   _bëra, --, --, --, 
   {{0x7cfc00e8,0xfd1c07c5,0xb878032e,0x00000000}},	//   _cëra, rnì_, _hníg, --, 
   {{0xdcb05a05,0xb87803b2,0x7e6802d0,0x3cdc01ad}},	//   دىڭ_, _kníg, _uffp, गाहे_, 
   {{0x6b403b45,0x945c3012,0xda34023a,0x46cc00af}},	//   mögl, _dańj, тевы, _होइह, 
   {{0xadd40375,0x47b800cc,0xdc300118,0x00000000}},	//   _טווח_, উটনী, _hýčk, --, 
   {{0x7ae40bc9,0x7cfc0de2,0x25b8009f,0xda700014}},	// [2d5b0] pjjt, _gëra, _aprl_, _پُج_, 
   {{0x3ebce4bb,0xb8780cad,0x3204012d,0xf4f401d3}},	//   nett_, _oníg, yzny_, کوؤں_, 
   {{0x4adc00af,0xa2a4102f,0x7cfc0023,0x63a40e89}},	//   मारव, च्छ्, _zëra, àinn, 
   {{0x3ebda5ae,0xe4e41fe2,0xdbdc01e1,0x7cfc0de2}},	//   hett_, лічн, _káàr, _yëra, 
   {{0x3ebda5af,0x00000000,0x00000000,0x00000000}},	//   kett_, --, --, --, 
   {{0x3ebc03a1,0xdbdc01e1,0x43700592,0x00000000}},	//   jett_, _máàr, جهور, --, 
   {{0x3ebd6ef6,0xdbdc0cad,0x6f040241,0x073c0116}},	//   dett_, _láàr, _lébù, ﻟﯘﯓ_, 
   {{0xed600308,0x6568020c,0x50b40312,0x3204033f}},	//   _leží_, _édha, тску, rzny_, 
   {{0x3ebda5b0,0x00c46733,0x00e002dd,0x3204033f}},	//   fett_, тлык_, ржын, szny_, 
   {{0x6efc0120,0x3ebda5b1,0x74e00154,0x00000000}},	//   _bêba, gett_, _মতিউ, --, 
   {{0xc1e405d9,0xa1952247,0xb87803b2,0x630400db}},	//   _لکيل_, _бахч, _gníg, _حولل, 
   {{0x7cfc0023,0x8d740133,0x00000000,0x00000000}},	//   _përa, _یابا, --, --, 
   {{0x3ebda5b2,0xdb0c0055,0x09c81fbc,0xed6000d0}},	//   bett_, _asañ, ाट्य, _beží_, 
   {{0xdbdc0241,0xb0a40073,0xfbc01fbe,0x945c012d}},	//   _dáàr, _गाडग, јбро, _bańk, 
   {{0x19b8224f,0x6b4001e6,0x7cfc0de2,0xb8780ca8}},	//   нуть_, sögo, _wëra, _oníd, 
   {{0xdbdc0241,0x7cfc0694,0xe9441bf4,0x00000000}},	//   _fáàr, _tëra, ارسی, --, 
   {{0xdb0c0165,0x7861a5b3,0x0c2410f3,0x6cc40220}},	// [2d5c0] _esañ, ркуз, _шмин, _айқа, 
   {{0xb8781a70,0x6838063f,0x26dc0165,0xfafc0200}},	//   _boís, ụdos, ñvo_, spër_, 
   {{0xc485a5b4,0x78bc0477,0xd5d402d5,0x00000000}},	//   влек, beqv, люцы, --, 
   {{0x3ebc066d,0xddd80010,0xdebc01f3,0x00000000}},	//   zett_, _jevš, ሳትና_, --, 
   {{0xa3b43bb3,0xa2943334,0xdbdc01e1,0x23b400f2}},	//   ублі, галі, _káár, امتس, 
   {{0xa28405af,0x1fc40107,0x00000000,0x00000000}},	//   ایاو, ҳроҳ, --, --, 
   {{0x52740372,0x25b80010,0x3ebcbb1b,0xdb1da5b5}},	//   уучу, _uprl_, vett_, rvsø, 
   {{0x3ebd78af,0xddd81f48,0x3f4001a8,0xdbdc01e1}},	//   wett_, _nevš, gðun_, _láár, 
   {{0x3ebc066d,0xff0400c9,0xcca40131,0x7cfc036e}},	//   tett_, вянн, _ﺋﯚﺯﮔ, _bërn, 
   {{0x24841f21,0x3ebc0036,0x7cfc0200,0xfc3c01e7}},	//   _hemm_, uett_, _cërn, ifít_, 
   {{0x69d80953,0x248408ea,0x5d5406bb,0x3ebda5b6}},	//   _šven, _kemm_, лкот, rett_, 
   {{0x3ebd449a,0x387c0115,0xdbdc0241,0x7de806be}},	//   sett_, _ĵuro_, _páàr, ləsk, 
   {{0x5f95a5b7,0x2485a5b8,0x3ebda5b9,0x945c00b8}},	//   _силт, _memm_, pett_, _sańk, 
   {{0x9b45a5ba,0x60c01bb3,0x2485a5bb,0x00000000}},	//   انسو, lemm, _lemm_, --, 
   {{0x23640226,0xdbdc017a,0xdd900633,0xaa5c01ec}},	//   _lumj_, _dáár, _اوب_, дерi, 
   {{0x60c1a5bc,0x2484002e,0x00000000,0x00000000}},	//   nemm, _nemm_, --, --, 
   {{0x69d80005,0xa9540150,0x00000000,0x00000000}},	// [2d5d0] _áven, ркті, --, --, 
   {{0x60c0f111,0xb878012c,0x00000000,0x00000000}},	//   hemm, _sníd, --, --, 
   {{0x60c1a5bd,0xa470063f,0x24840254,0xdb0c2737}},	//   kemm, _ịdọt, _bemm_, _apaç, 
   {{0x60c17c4f,0xf8a005f5,0xb864e750,0xb4b00131}},	//   jemm, _өгүү, _جادو, ридә, 
   {{0x60c1a5be,0x24584077,0x24840003,0x00000000}},	//   demm, ваць_, _demm_, --, 
   {{0xdebc0023,0x60c00108,0x00000000,0x00000000}},	//   ዳድኣ_, eemm, --, --, 
   {{0x60c1a5bf,0xe18806f6,0x7cfc00e8,0xe5c40064}},	//   femm, نئين_, _nëro, _ксто, 
   {{0x60c1a5c0,0x90c4cea0,0x2485a5c1,0xb87800e4}},	//   gemm, убие, _gemm_, _uníd, 
   {{0x3f40008c,0x7cfda5c2,0xddd80219,0x00000000}},	//   rðun_, _përn, _revš, --, 
   {{0xe8e02982,0x77780327,0xe3b000e5,0x00000000}},	//   _पच्च, _ħuxl, _گرہ_, --, 
   {{0x9bb8025c,0x60c1a5c3,0x00000000,0x00000000}},	//   _བརྔོ, bemm, --, --, 
   {{0x60c01e4f,0x7cfc00e8,0xdbdc0248,0xe3b000e5}},	//   cemm, _wërn, _sáár, _درہ_, 
   {{0x8e54005e,0x6fb46c5a,0x7cfc0240,0xb8780ca8}},	//   _өткі, _अहिं, _tërn, _oníb, 
   {{0x4e280261,0x00000000,0x00000000,0x00000000}},	//   _полн_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd5b0004d,0x997416a4,0xa02403d4,0x6fb40037}},	//   _ấy_, рурш, _পৰিব_, _अहां, 
   {{0xc724405c,0x24859e2b,0x8699a5c4,0xc7640137}},	// [2d5e0] гдай, _remm_, етет_, اارى, 
   {{0x9bb81efe,0x69c8d02e,0xf79401d5,0xe748008e}},	//   _བརྗོ, ædes, انلب_, түге_, 
   {{0xd6c40ae5,0x881801e1,0x23640309,0x7de800ac}},	//   рихқ, _dírẹ, _sumj_, vəsk, 
   {{0x49740166,0xe3a401b9,0xc7642309,0xf4800114}},	//   _илүс, لشتی, _ماسى, бушн, 
   {{0xe28404a9,0x60c07f8d,0xa11401d5,0x00000000}},	//   иған, vemm, یوتت, --, 
   {{0x60c1a5c5,0x45840592,0x25f400e1,0x6b8000e5}},	//   wemm, _مجرّ, ंहदी_, ámgy, 
   {{0x248592c8,0x7cfc0200,0x00000000,0x00000000}},	//   _temm_, _bërl, --, --, 
   {{0xb87803b7,0x7640068f,0xa2d421f6,0x00000000}},	//   _iníc, żnyc, _योर्, --, 
   {{0x60c1a5c6,0x7de803be,0x69d80006,0xe4dc00e2}},	//   remm, məsi, _švel, _mīļā, 
   {{0x60c034d7,0x7de803be,0x61f80175,0x7de401ec}},	//   semm, ləsi, pyvl, гімд, 
   {{0x80a4158f,0x4ee401e0,0x7cfc036e,0xd24c00db}},	//   _ممان, рсыҡ, _qëro, _ۉچۉ_, 
   {{0xf8bc0438,0x7de80213,0xb8780030,0x48e400eb}},	//   _ajén_, nəsi, _mníc, নসুর, 
   {{0x7cfc00e8,0x00000000,0x00000000,0x00000000}},	//   _wëro, --, --, --, 
   {{0x7de803be,0x307001ec,0x32500408,0x00000000}},	//   həsi, _куәс, _евĕр, --, 
   {{0x7de800ac,0x0f34084c,0x69d802d2,0x00000000}},	//   kəsi, _тэця, _ável, --, 
   {{0x3f4005f7,0x7cfc036e,0x1874549f,0x98741fce}},	//   iðum_, _kërm, ргая, рлац, 
   {{0x6c78215e,0x9715a5c7,0x7de800ac,0x7cfc00e8}},	// [2d5f0] _صحيح_, амац, dəsi, _jërm, 
   {{0x1da805f9,0xa3e8610a,0xfc3c067c,0x290c020c}},	//   _कमात, यमन_, sfís_, èdar_, 
   {{0xfe1806ab,0xf645a5c8,0x7de803be,0x394801fb}},	//   _फेमस_, ухан, fəsi, _thcs_, 
   {{0x94740214,0x58d48083,0x9878010f,0x7de806be}},	//   شگرا, _томт, _שאָט, gəsi, 
   {{0x7cfc0de2,0xe508004b,0x246c1954,0xded40092}},	//   _nërm, دينو_, ስቆሮስ_, ይናና_, 
   {{0x3f4001a8,0x91940063,0x00000000,0x00000000}},	//   fðum_, ајиш, --, --, 
   {{0x7de803be,0x7cfc02d3,0x3f400008,0x00000000}},	//   bəsi, _përl, gðum_, --, 
   {{0x7de803be,0x8d7401d3,0x00000000,0x00000000}},	//   cəsi, یاجا, --, --, 
   {{0x7539a5c9,0x7cfc0200,0x91a0000d,0x00000000}},	//   _ikuz, _vërl, _गमकै, --, 
   {{0x9bb8025c,0xcef40261,0x7cfc8a64,0x6ca00150}},	//   _བརྟོ, рчињ, _wërl, _ﺃﻋﻘﺏ_, 
   {{0x2d54054e,0x6cb4004e,0x00000000,0x00000000}},	//   _oţet_, бөпт, --, --, 
   {{0xcb6905c6,0x945c0165,0x7cfc0036,0x6b400793}},	//   каме_, _dańv, _fërm, mögi, 
   {{0x753801f7,0x7cfc0023,0xa3e8610a,0x6b41a5ca}},	//   _mkuz, _gërm, यमय_, lögi, 
   {{0xbea00024,0x7de800ac,0x00000000,0x00000000}},	//   _дашк, zəsi, --, --, 
   {{0xfc3d2b4f,0x753857d2,0x7de800ac,0x59740c75}},	//   rgía_, _okuz, yəsi, йыту, 
   {{0x753800b4,0x1cc4031c,0x7cfc0694,0x08c400d8}},	//   _nkuz, _ཌིར_, _yërm, јбан, 
   {{0x07a506e4,0x0685a5cb,0x7de803be,0xc7a408da}},	// [2d600] разн, иган, vəsi, ризк, 
   {{0x7b840075,0x7bf80a7c,0xee4c00c7,0x3f4006ea}},	//   _ئايە, _ספיצ, hẽme_, yðum_, 
   {{0x7de803be,0x44640120,0xee4c0022,0x7a1801e1}},	//   təsi, авев, kẽme_, _tìbẹ, 
   {{0x6b85a5cc,0xd6c41b6d,0x07a46690,0xe8b40131}},	//   _kwig, _қисқ, _камн, _دەرج, 
   {{0xf86010f5,0x7de803be,0xb60400da,0x290000ec}},	//   _євро, rəsi, ekšē, mkia_, 
   {{0x6b849818,0x75395238,0x2901a5cd,0x7de800ac}},	//   _mwig, _ekuz, lkia_, səsi, 
   {{0xd5d40024,0x69d8013a,0x29000108,0x7de803b9}},	//   _люты, _švej, okia_, pəsi, 
   {{0x7cfc069c,0x3f4031ac,0x2901a5ce,0x7de800ac}},	//   _përm, rðum_, nkia_, qəsi, 
   {{0x2901a5cf,0xb2212e74,0x42c80022,0xd0180165}},	//   ikia_, ймәл, _иган_, zańv_, 
   {{0x65600327,0x3ea80ade,0x6440010e,0x7cfc036e}},	//   _himh, übt_, _iymi, _vërm, 
   {{0x2900049b,0x6b84003e,0x6288005f,0x73300f78}},	//   kkia_, _awig, _iedo, _بىلا, 
   {{0x6b84015c,0x656001c7,0x7cfc0023,0x64400108}},	//   _bwig, _jimh, _tërm, _kymi, 
   {{0x6289a5d0,0x6560006f,0xdfd00220,0xb9080051}},	//   _kedo, _mimh, _ءيت_, _thiế_, 
   {{0x7cfc069c,0x6289a5d1,0xdd90468e,0x6561a5d2}},	//   _kërk, _jedo, _فوت_, _limh, 
   {{0x6b852794,0x6da02424,0xdd9402dd,0x69c801bf}},	//   _ewig, _дија, _уайы, ædep, 
   {{0x7cfc0023,0x6560ae9e,0x19583007,0xae5805d0}},	//   _mërk, _nimh, уабы_, _בכור, 
   {{0xf7702674,0x628800a9,0x6441a5d3,0x6b84030a}},	// [2d610] تاز_, _oedo, _nymi, _gwig, 
   {{0x6561a5d4,0x7538c443,0x29000618,0xe730007b}},	//   _aimh, _skuz, akia_, وصل_, 
   {{0x6b8406d6,0x65600099,0x64400548,0x59f80276}},	//   _zwig, _bimh, _aymi, _сеня_, 
   {{0x6289a5d5,0x64403c02,0x1cc4031c,0x29000108}},	//   _aedo, _bymi, _ཌིས_, ckia_, 
   {{0x62886404,0x7cfc044e,0x64403657,0x00000000}},	//   _bedo, _përj, _cymi, --, 
   {{0x6289a5d6,0x65610568,0x6441a5d7,0xe3b001c8}},	//   _cedo, _eimh, _dymi, ظرن_, 
   {{0x94d43aeb,0x644006be,0x00000000,0x00000000}},	//   _ловц, _eymi, --, --, 
   {{0x753829e5,0x945c0241,0x7cfc002e,0x6289a5d8}},	//   _ukuz, _bańt, _dërk, _eedo, 
   {{0x6289a5d9,0x24580b87,0xf41d1297,0x3d08043e}},	//   _fedo, _вать_, _ää_, ासने_, 
   {{0x6289a5da,0x6b84015c,0x290005f5,0x8ee9a5db}},	//   _gedo, _rwig, zkia_, умов_, 
   {{0x6b85a5dc,0x7d7431d6,0x64400153,0x2900b6f6}},	//   _swig, یمیر_, _zymi, ykia_, 
   {{0x628811ce,0x656002b9,0x00000000,0x00000000}},	//   _zedo, _ximh, --, --, 
   {{0x6288ca38,0xa13401b9,0x4c34009d,0x00000000}},	//   _yedo, _برلش, сэнт, --, 
   {{0xe1640150,0x63a40192,0x3f8000e4,0x00000000}},	//   _ادەي, àini, ãkue_, --, 
   {{0x7bc8025a,0x2900023a,0x2bc40037,0x00000000}},	//   _âgun, tkia_, _लईका, --, 
   {{0x6b85a5dd,0x7d747427,0x2901a5de,0x4c8400ea}},	//   _twig, _امير_, ukia_, _улив, 
   {{0x29005456,0x6561a5df,0x6b840526,0xfc3c004e}},	// [2d620] rkia_, _rimh, _uwig, ngíl_, 
   {{0xb8fc7f1a,0x6561a5e0,0x945c030a,0x25f401ad}},	//   _धो_, _simh, _lańs, ंहली_, 
   {{0xb0a48098,0xb8780332,0x6441a5e1,0x00000000}},	//   _गांग, _inín, _symi, --, 
   {{0x6289a5e2,0x6560047e,0x133801d3,0xf48000c0}},	//   _sedo, _qimh, یتوں_, пушн, 
   {{0x6289a5e3,0xb878d301,0x7de80213,0x067402e8}},	//   _pedo, _unía, ləst, _губя, 
   {{0x7cfc069c,0x6560016b,0x0b04015b,0x64401d55}},	//   _përk, _wimh, _ঈদুল_, _vymi, 
   {{0x6440006d,0x656006e4,0x6289a5e4,0x7e7c007d}},	//   _wymi, _timh, _vedo, _õppi, 
   {{0x1f750862,0x62883418,0x65604ba3,0x60f80801}},	//   олия, _wedo, _uimh, рния_, 
   {{0x628801b8,0x6b40008c,0x64400113,0x00000000}},	//   _tedo, lögu, _uymi, --, 
   {{0x6288014b,0x7e7400a2,0x3ec80114,0x7de803e3}},	//   _uedo, _şypb, ућим_, kəst, 
   {{0xe18802dd,0x00000000,0x00000000,0x00000000}},	//   _төле_, --, --, --, 
   {{0xb87800c7,0x7cfc0de2,0x00000000,0x00000000}},	//   _anín, _këri, --, --, 
   {{0xd0e44540,0x7cfc0de2,0x7520003e,0x98a8025c}},	//   कारण_, _jëri, énzi, lmaħ_, 
   {{0xde584077,0x6e9000c7,0x7cfc0240,0x00000000}},	//   _калі_, _еишу, _mëri, --, 
   {{0x7cfc036e,0x00000000,0x00000000,0x00000000}},	//   _lëri, --, --, --, 
   {{0xa3e8038e,0x6b4001a8,0x00000000,0x00000000}},	//   यमा_, dögu, --, --, 
   {{0x9b443ccf,0x02f80cb4,0x56f40120,0x9d74009f}},	// [2d630] _ونعو, ्साह_, опаѓ, _انڊڪ, 
   {{0x35e4026b,0x6b4002d2,0x6b900205,0x00000000}},	//   йцев, fögu, şigü, --, 
   {{0x7cfda5e5,0xa2dc00cd,0x00000000,0x00000000}},	//   _përh, पयन्, --, --, 
   {{0x7cfc4113,0xb87800c6,0x2e38008f,0xb8c41c3e}},	//   _bëri, _inío, נגאנ, _ازدى, 
   {{0x7cfc00e8,0x7af4005a,0xdebc02d3,0x00000000}},	//   _cëri, _koxt, ዳስን_, --, 
   {{0x69d82602,0xfa24031c,0x945c0165,0xe1f0082a}},	//   _švei, _རྨོན_, _sańs, کسه_, 
   {{0x945c006d,0x7cfc044e,0x3f84007f,0x7af40724}},	//   _pańs, _tërh, _awou_, _moxt, 
   {{0xe8000316,0x7af4017a,0x338416a4,0x4f95a5e6}},	//   लैका_, _loxt, _гужв, ороу, 
   {{0x4f08e77b,0xa3f401ec,0x237400ae,0xa2d400cd}},	//   инин_, _епті, _فالح, _योक्, 
   {{0xb8e8003d,0x918003cc,0xcf24027d,0x13a40133}},	//   _ཊི_, _قۇتۇ, ترعي, _هۆڵی_, 
   {{0x98b80100,0xdeec8337,0x7cfc02d3,0x3f8401c7}},	//   _aksč_, اۋى_, _zëri, _ewou_, 
   {{0xfa24025c,0xdc74005b,0x8c444130,0x69d8032e}},	//   _རྨེན_, зырь, жеме, _ávei, 
   {{0x7af5a5e7,0xb878007b,0xd0180165,0x27340036}},	//   _boxt, _anío, rańs_, ränz_, 
   {{0x15f8000d,0xda64007b,0x00000000,0x00000000}},	//   ंहार_, كافي, --, --, 
   {{0x3f840a40,0xbb40020f,0x1a0400c7,0x00000000}},	//   _zwou_, ферк, порҭ, --, 
   {{0x6568020c,0x8ba40124,0xcba4030d,0x00000000}},	//   _édhi, _дииж, _даий, --, 
   {{0x9aa465dc,0xa9680058,0x2d8401ab,0x7de803e3}},	// [2d640] _کمپو, риға_, _hwne_, bəss, 
   {{0xfb1410fe,0xb8780005,0xdb1402d2,0x7de803e3}},	//   _وقيع_, _unín, _íaðs, cəss, 
   {{0x7cfce49d,0xb8780491,0xa2d406e3,0x3cdc0490}},	//   _sëri, _gnío, _योग्, गाचे_, 
   {{0x7cfc94f5,0x2d840100,0x00000000,0x00000000}},	//   _dërw, _mwne_, --, --, 
   {{0x6b400008,0x7d5408a8,0x7cfc0200,0x3d0800cd}},	//   sögu, קינד_, _qëri, ासते_, 
   {{0xdebc0b82,0xaa1400c7,0x00000000,0x00000000}},	//   ዳትን_, hẽma, --, --, 
   {{0x4ab01533,0x05640212,0xb8780ca8,0xc1e80166}},	//   _जानव, _єван, _oníl, рьле_, 
   {{0xc48465cb,0x2fcc00a2,0x7cfc2568,0xd574009d}},	//   _флак, _bsgg_, _tëri, _хурь, 
   {{0xe2980133,0x44208021,0x4ac805c0,0x00000000}},	//   _هێشت_, _äk_, ाजाव, --, 
   {{0x7de800ac,0xeeb402d5,0x2734005b,0x945c00a2}},	//   xəss, ольш_, täny_, _tańr, 
   {{0x6b4001e6,0xc0d40023,0x63a40332,0x00000000}},	//   högs, ክሳር_, áinf, --, 
   {{0x91a401d9,0x7af401b9,0x3f8402bd,0xc058cea4}},	//   _رحمٔ, _soxt, _twou_, _кіл_, 
   {{0xb87801e7,0xcf2401e2,0x00000000,0x00000000}},	//   _snío, _کرني, --, --, 
   {{0xbd683529,0x60c40165,0x3da400f0,0x00000000}},	//   _крие_, _ñimb, _дриб, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7af42bcc,0x7cfc0200,0x00000000,0x00000000}},	// [2d650] _toxt, _bërv, --, --, 
   {{0x387c01e4,0x7bdda5e8,0x7640033f,0x7cfc036e}},	//   _ĵuru_, _irqu, żnym, _cërv, 
   {{0x7e7c00c5,0xdb1c0036,0x7cfc036e,0x00000000}},	//   _õppu, rwsä, _dërv, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf8bc01e1,0x00000000,0x00000000,0x00000000}},	//   _ibé_, --, --, --, 
   {{0xe9d8cc7b,0x7cfc0240,0xe73802d5,0x7bdc0051}},	//   _اذیت_, _gërv, _меў_, _mrqu, 
   {{0xe5b401c6,0x0e6400d1,0x00000000,0x00000000}},	//   _ойры, үкин, --, --, 
   {{0x409004a9,0x7cfc0de2,0xddc8033f,0xb50400cf}},	//   ىلىر, _këru, łośn, _بىرۅ_, 
   {{0xf8bda5e9,0x63a40192,0x7e74010b,0x00000000}},	//   _mbé_, àint, _şypa, --, 
   {{0xdcf00607,0x777803e3,0xb87801ef,0x00000000}},	//   _āfāi, _çuxu, _sníl, --, 
   {{0x7bdc10d0,0xb8793383,0x315800b8,0x2bc4012c}},	//   _arqu, _aním, _aṃśā, _लैजा, 
   {{0x63a40332,0x00000000,0x00000000,0x00000000}},	//   áing, --, --, --, 
   {{0x1cc40327,0xfba46236,0x0f7800df,0x00000000}},	//   ཌྶེ_, कूलम, _פאַב, --, 
   {{0xf8bc0cad,0x63a5a5ea,0x261c0073,0x00000000}},	//   _abé_, šing, _मधली_, --, 
   {{0x7bdda5eb,0xdce80139,0x5ee801f9,0x00000000}},	//   _erqu, ardı, जार्_, --, 
   {{0x1cc40489,0x2b58030d,0xcc880c56,0x00000000}},	//   _ཌིག_, smrc_, _убие_, --, 
   {{0x7cfda5ec,0xb87800ae,0x9a480014,0x00000000}},	// [2d660] _përv, _gním, مجہِ_, --, 
   {{0x951808ea,0x7cfc00e8,0x7528009a,0xa8080139}},	//   ྱིའི_, _dëru, engz, _anıñ, 
   {{0x88e400ee,0x056463e6,0x36640107,0x7cfc0200}},	//   _ежне, чвен, чахо_, _vërv, 
   {{0xf8bc0570,0x69dc5e52,0xa2d400cd,0xdebc04b2}},	//   _gbé_, mvre, _योज्, ዳትና_, 
   {{0xe7945a51,0xe2f802dd,0xb8780248,0xd408007b}},	//   _تاجک, желі_, _oníj, يتهم_, 
   {{0xd5ac00e5,0x00000000,0x00000000,0x00000000}},	//   _چہل_, --, --, --, 
   {{0x69dda5ed,0x7cfc036e,0x31c00108,0x00000000}},	//   nvre, _kërt, есыв, --, 
   {{0x69dc0175,0xdebc1954,0x417400e5,0x00000000}},	//   ivre, ዳድን_, _ہاؤس, --, 
   {{0x7cfc0200,0x69dc0254,0x00000000,0x00000000}},	//   _mërt, hvre, --, --, 
   {{0x69dda5ee,0x38140375,0x00000000,0x00000000}},	//   kvre, פקים_, --, --, 
   {{0xb878031d,0x69dc1505,0x7cfc022e,0x1df80153}},	//   _sním, jvre, _oërt, цены_, 
   {{0x69dda5ef,0xdce80205,0x00000000,0x00000000}},	//   dvre, trdı, --, --, 
   {{0x7a2001a9,0x69dc75d9,0x7074010f,0xdfd4009d}},	//   _kеtg, evre, _זײדע_, _цолы, 
   {{0xb8780122,0x4ab00574,0xe044010b,0x657c02f0}},	//   _vním, _जाणव, _енҗи, _otrh, 
   {{0x7cfc02d3,0x69dc017a,0x00000000,0x00000000}},	//   _bërt, gvre, --, --, 
   {{0x7cfc0023,0x3178010f,0x98b801a9,0x00000000}},	//   _përu, מאלד, ўлат_, --, 
   {{0x7bdc0bf1,0x28f9a5f0,0x57b4461c,0xdbdc08a5}},	// [2d670] _urqu, четь_, ьбат, _háþr, 
   {{0x6abc00b5,0x69dc02d0,0x9f40013d,0x00000000}},	//   cfrf, bvre, _çiä_, --, 
   {{0x7cfc00e8,0x7bcc0042,0x64c401ef,0x4ab000cd}},	//   _wëru, lwcu, _očič, _जातव, 
   {{0x88e40156,0x00000000,0x00000000,0x00000000}},	//   _ཤོགར, --, --, --, 
   {{0xf365a5f1,0xa7740410,0x88f4011a,0x00000000}},	//   чтен, _пляч, _חזרו_, --, 
   {{0xe3b02651,0x7cfc036e,0xb8780ca8,0x00000000}},	//   طره_, _kërs, _oník, --, 
   {{0x69d8032e,0x00000000,0x00000000,0x00000000}},	//   _ávet, --, --, --, 
   {{0xa4d402bf,0x00000000,0x00000000,0x00000000}},	//   _посі, --, --, --, 
   {{0xb87800c7,0x7bcc0113,0xdb1c000f,0xa3e800dc}},	//   _aník, jwcu, uwsû, यमः_, 
   {{0x63a4007b,0x7a2001a9,0x45080327,0x69dc03b2}},	//   áine, _kеtd, _གཞོར_, yvre, 
   {{0xcc881371,0x290c0153,0x63a40135,0x00000000}},	//   ينده_, ūdai_, ġine, --, 
   {{0x69dda5f2,0x63a40841,0x7e6802d0,0x00000000}},	//   vvre, šine, _egfp, --, 
   {{0xb87801e1,0x8140132f,0x00000000,0x00000000}},	//   _eník, _جھوم, --, --, 
   {{0xb3bc015b,0xeff002d3,0x69dc01a4,0x00000000}},	//   _এছাড়, ልኣይ_, tvre, --, 
   {{0x7cfc02d3,0x69dcad72,0xb8780030,0x7f5402dd}},	//   _përt, uvre, _kníh, _ﺤﺼل_, 
   {{0x69dda5f3,0x45080327,0x69d80118,0x4adc01ad}},	//   rvre, _གཞེར_, _šves, _फोरव, 
   {{0x7cfc069c,0x6d45a5f4,0x657c0122,0x69dc0af9}},	// [2d680] _vërt, _ikia, _strh, svre, 
   {{0x7cfc0200,0xa5c80055,0x09e400cf,0x00000000}},	//   _fërs, _niųå, _жоон, --, 
   {{0x7cfc0240,0xb87801e1,0xf41803d4,0x00000000}},	//   _gërs, _oníh, _ফুলৰ_, --, 
   {{0x7cfc0036,0x100c230e,0x657c0306,0x03a401f0}},	//   _hërr, िनाश_, _vtrh, дидо, 
   {{0x3f4005f7,0x6d449511,0x7cfc036e,0x00000000}},	//   iður_, _mkia, _kërr, --, 
   {{0x69d802d2,0x00000000,0x00000000,0x00000000}},	//   _áves, --, --, --, 
   {{0xaac01025,0x657da5f5,0x76440432,0x7d0c0036}},	//   श्यक, _utrh, _gyjy, ëbsk, 
   {{0x6d4401d4,0x39980302,0x7fb001b9,0x3154007b}},	//   _nkia, קיפד, نلبچ, وجية_, 
   {{0x26d9a5f6,0xb8780d12,0x00000000,0x00000000}},	//   _karo_, _sník, --, --, 
   {{0x26d804ac,0x6d45a5f7,0x7cfc0200,0x00000000}},	//   _jaro_, _akia, _nërr, --, 
   {{0x26d9a5f8,0x3d080892,0x3f4008a5,0x00000000}},	//   _maro_, ासले_, fður_, --, 
   {{0x26d88b14,0xc004274b,0x3f400008,0xc09401d3}},	//   _laro_, _опек, gður_, _آجات, 
   {{0x26d9a5f9,0x7cfc036e,0x6fb0007b,0xd12c00f1}},	//   _oaro_, _bërr, _لمنا, _دڅو_, 
   {{0x7cfc0023,0x29dc1682,0x26d8d6bd,0x6d45a5fa}},	//   _përs, _ḽau_, _naro_, _ekia, 
   {{0x69d81591,0x7cfc0240,0x20040419,0x212403d5}},	//   _šver, _dërr, lymi_, oimh_, 
   {{0x26d9a5fb,0x2125240d,0x6d4401ab,0x7cfc0023}},	//   _aaro_, nimh_, _gkia, _vërs, 
   {{0x20047726,0xe6107811,0x7cfc1bce,0xad240228}},	// [2d690] nymi_, یشم_, _wërs, _جىيى, 
   {{0x45080327,0x7cfc036e,0x21249a14,0xfa340150}},	//   _གཞུར_, _gërr, himh_, _жүгі_, 
   {{0x26d9a5fc,0xaca40022,0xfbdc0798,0x200400d7}},	//   _daro_, _apỹi, lvê_, hymi_, 
   {{0xdb0c00e4,0x2005a5fd,0x25f403e5,0x68f80419}},	//   _ipañ, kymi_, ंहजी_, ľadá, 
   {{0xf3c9a5fe,0x21243e7c,0x69d808a5,0x00000000}},	//   تباه_, dimh_, _áver, --, 
   {{0x26d806a3,0xbcf800d8,0xeaa00055,0x200415c0}},	//   _garo_, lméd, _veṇv_, dymi_, 
   {{0x3f4008a7,0x00000000,0x00000000,0x00000000}},	//   yður_, --, --, --, 
   {{0x26d807d6,0x00000000,0x00000000,0x00000000}},	//   _zaro_, --, --, --, 
   {{0x26d9a5ff,0x200400e4,0x3f400162,0xb37400ec}},	//   _yaro_, gymi_, vður_, _آدرش, 
   {{0x6d45a600,0x00000000,0x00000000,0x00000000}},	//   _skia, --, --, --, 
   {{0x200400e8,0x0e65a601,0xa29400d4,0x00000000}},	//   aymi_, экон, _рахі, --, 
   {{0x8228031c,0x00000000,0x00000000,0x00000000}},	//   _སྨྲི_, --, --, --, 
   {{0x3f4156fa,0xdb0cf806,0x7cfc02d3,0x20040034}},	//   rður_, _apañ, _përr, cymi_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x26d80325,0x39e40107,0x19b802bf,0xc33004ae}},	//   _raro_, ндро_, муть_, אום_, 
   {{0x26d9a602,0x6d45a603,0x00000000,0x00000000}},	//   _saro_, _ukia, --, --, 
   {{0xdb0c00c7,0x87080120,0x7cfc0200,0x00000000}},	// [2d6a0] _epañ, пеав_, _tërr, --, 
   {{0xcc8803e6,0x26d9a604,0xb8780248,0x4aa829c6}},	//   _بنکه_, _qaro_, _oníw, _экон_, 
   {{0x20040034,0x7cfc0240,0x00000000,0x00000000}},	//   zymi_, _kërp, --, --, 
   {{0x4a7401d9,0x26d9a605,0x200401f4,0xca4801e2}},	//   _تُھر, _waro_, yymi_, _ولکه_, 
   {{0x26d9a606,0xa3d406ed,0x00000000,0x00000000}},	//   _taro_, толч, --, --, 
   {{0xbcf9a607,0x200445be,0xd3c412d7,0x249800ef}},	//   mmée, vymi_, ъқул_, _ērmu_, 
   {{0x2004068f,0x95980145,0x453400c7,0x066401ec}},	//   wymi_, _отту_, _зхат, _ساسپ, 
   {{0x45080867,0x81b000bd,0x2ca0009a,0x27e00037}},	//   _གཞིར_, টবল_, _ndid_, ovin_, 
   {{0x9e74049e,0x27e048bb,0x212400c6,0xd048013f}},	//   نۇشت, nvin_, rimh_, mdeɛ, 
   {{0xdcc8194b,0x2005a608,0x2ca1a609,0x27e1a60a}},	//   िज्ञ, rymi_, _adid_, ivin_, 
   {{0xd34413f9,0x9e35a60b,0x6e9401c0,0x27e0023a}},	//   _جیوه_, тенч, эвэр_, hvin_, 
   {{0x7cfc02d3,0x200400c7,0xfb2001e1,0x00000000}},	//   _përq, pymi_, _ẹ̀rù, --, 
   {{0x5ed401c0,0xb8780174,0x69d80064,0x7c64007b}},	//   _ажлу, _knív, _švep, عاجل, 
   {{0x27e0aef5,0x2ca0010a,0x98a80010,0x692c0205}},	//   dvin_, _edid_, rnač_, hşed, 
   {{0x1d34013d,0x00000000,0x00000000,0x00000000}},	//   _инкя, --, --, --, 
   {{0x9c940882,0x2ca00135,0x00000000,0x00000000}},	//   bhāṣ, _gdid_, --, --, 
   {{0xf7703ccf,0x6935a60c,0xbcf8cb63,0x27e0a23e}},	// [2d6b0] اار_, унту, rméd, gvin_, 
   {{0xbcf81155,0xf7a40150,0x7a0c0055,0x66b430ab}},	//   sméd, _ﺷﻪﻧﺪ, _ṛtul, лбуу, 
   {{0xf8bc0de2,0x27e005da,0x24580124,0x00000000}},	//   _amée_, avin_, ҭахь_, --, 
   {{0xf771a60d,0xb87800e4,0xbcf801d3,0x2c180154}},	//   _ماس_, _anív, lméb, _ধুয়ে_, 
   {{0x1cc40135,0xaab9a60e,0xe4a5a60f,0xdee00023}},	//   _ཌིན_, _غدیر_, урхо, ቓስን_, 
   {{0x63a45821,0x00000000,0x00000000,0x00000000}},	//   áina, --, --, --, 
   {{0x06900150,0x63a4003d,0x00000000,0x00000000}},	//   _ﺟﯘﻧﯩ, ġina, --, --, 
   {{0x7410004b,0x3db400cc,0x7ec80150,0x4fe9a610}},	//   _یوځا, জবাল, _ﺒﻤﻨﻁ, дмин_, 
   {{0x4ab008a3,0x00000000,0x00000000,0x00000000}},	//   _जालव, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7cfc069c,0x2ca00175,0x6ae000cc,0x00000000}},	//   _përp, _pdid_, _নকলো, --, 
   {{0x32040209,0x7e2034bb,0xdb0c08ce,0x27e1a611}},	//   myny_, рдюж, _spað, yvin_, 
   {{0x32040209,0x2ca00076,0x4c340105,0x290c0171}},	//   lyny_, _vdid_, тэнт, _ēda_, 
   {{0x3324e0c9,0xbb180356,0x00000000,0x00000000}},	//   ninx_, spîn, --, --, 
   {{0x32040209,0x7cfc0200,0x8d540354,0x00000000}},	//   nyny_, _tërp, _итич, --, 
   {{0x332414e0,0x6a8404a9,0x27e0f7b7,0x2ca1a612}},	//   hinx_, _әһва, tvin_, _udid_, 
   {{0x27e00129,0xcdc401d5,0xb4a8000d,0x320400ee}},	// [2d6c0] uvin_, _чаққ, _खाड़_, hyny_, 
   {{0xbcf9a613,0x3204fd87,0x1d98001f,0x00000000}},	//   rmée, kyny_, _መደቦች_, --, 
   {{0x74100345,0x3204010b,0x00000000,0x00000000}},	//   یوما, jyny_, --, --, 
   {{0x32046b7e,0x290c005f,0xda5802d9,0xb8780030}},	//   dyny_, īdas_, _ярыш_, _snív, 
   {{0x290c005f,0x332435f5,0x58040150,0x00000000}},	//   ūdas_, finx_, _бояғ, --, 
   {{0x06741836,0xa89400e2,0xd3e401d5,0x320400a2}},	//   _шумя, šķīr, اقوی, fyny_, 
   {{0x320409a5,0x7a20022e,0xf41c0432,0x00000000}},	//   gyny_, _kеta, _ýän_, --, 
   {{0xf990025f,0xd01800a2,0x00000000,0x00000000}},	//   ברה_, lańy_, --, --, 
   {{0x7a2001a9,0x7ec80150,0x00000000,0x00000000}},	//   _mеta, _ﺒﻤﻭﻁ, --, --, 
   {{0x9df80261,0xb878004e,0x64a43007,0x320400ee}},	//   енот_, _unív, _шаға, byny_, 
   {{0x6299a614,0xdcf824cb,0xb87803b2,0x3204033f}},	//   mavo, _atvā, _knít, cyny_, 
   {{0x6299a615,0xde4c0092,0x00000000,0x00000000}},	//   lavo, _ማዕከል, --, --, 
   {{0x7c6401d5,0x00000000,0x00000000,0x00000000}},	//   ضاحل, --, --, --, 
   {{0x6299a616,0xbcf801c7,0xcfa8007b,0x00000000}},	//   navo, fméc, _ساهم_, --, 
   {{0x50a00075,0xdb1c0036,0x9f940022,0xb8780ca8}},	//   _ئەۋل, ltsë, _рыҵә, _onít, 
   {{0x6299a617,0xf77c0598,0x693560be,0x2984441e}},	//   havo, _arça_, ансу, рырг, 
   {{0x6299a618,0x32046b7e,0x80bc0f22,0xebd800c7}},	// [2d6d0] kavo, zyny_, ্যপ্, _адыш_, 
   {{0xb8792448,0x00000000,0x00000000,0x00000000}},	//   _anít, --, --, --, 
   {{0x63a40597,0x00000000,0x00000000,0x00000000}},	//   áinn, --, --, --, 
   {{0x33240054,0xf4841363,0x9878010f,0x00000000}},	//   winx_, тужн, _ראָט, --, 
   {{0xad1c1a4c,0xaac0202e,0x00000000,0x00000000}},	//   וואר, श्वक, --, --, 
   {{0x32040209,0x6299a619,0xf77005d9,0x63540815}},	//   tyny_, gavo, _ماڳ_, авчу, 
   {{0xd37005d9,0x3324037e,0xca880023,0x7a20022e}},	//   جهڻ_, rinx_, ሓንኩም_, _yеta, 
   {{0x32040510,0x33240054,0x62980140,0x50b400c0}},	//   ryny_, sinx_, aavo, уску, 
   {{0x320409a5,0x62999384,0xb8780077,0x00c46590}},	//   syny_, bavo, _uníu, улык_, 
   {{0x629960fe,0x33240227,0xdbdc02d2,0xc0dc0023}},	//   cavo, qinx_, _ráðr, ቓቕማ_, 
   {{0xd251a61a,0x4d6587cf,0xcd2848a9,0xb87802d2}},	//   _انا_, лков, ежне_, _kaíd, 
   {{0xb87800d7,0xa3e80073,0x00000000,0x00000000}},	//   _mnís, यमच_, --, --, 
   {{0x4fa42461,0x090401ec,0xb9bc013d,0x00000000}},	//   _силв, қпан, _şäpş, --, 
   {{0x645c01e4,0xe2c80327,0xbcf80036,0xdb1c007f}},	//   _ŝrik, _གིབཀ, tméc, ntsè, 
   {{0x6cc401ec,0xc33005d0,0x00000000,0x00000000}},	//   _ұйқа, צול_, --, --, 
   {{0x6298634d,0x00000000,0x00000000,0x00000000}},	//   zavo, --, --, --, 
   {{0x46e82de0,0xada0044c,0xb879a61b,0x78a8022c}},	// [2d6e0] ндан_, _сақл, _anís, ógva, 
   {{0x62981188,0xb878013a,0x00000000,0x00000000}},	//   xavo, _snít, --, --, 
   {{0x6299a61c,0x6b84031c,0x5eb800cc,0x3ab800d9}},	//   vavo, _htig, _অসমে, _אמינ, 
   {{0xb878f466,0x6299a61d,0x849401ed,0x26dc0010}},	//   _caíd, wavo, اجائ, žvo_, 
   {{0x6299a61e,0x00000000,0x00000000,0x00000000}},	//   tavo, --, --, --, 
   {{0x63a45d74,0xbcf8007b,0x6d10012c,0x00000000}},	//   šino, iméa, ासँग_, --, 
   {{0x9574005b,0xb87802d2,0x6d0401f9,0x660401af}},	//   _выуч, _gnís, _लवंग_, _товҡ, 
   {{0x6299a61f,0xf9900302,0x7de402dd,0xb8780022}},	//   savo, זרה_, ңінд, _vaíg, 
   {{0x6b8533ed,0x6299a620,0x7ff400c6,0x3f80036e}},	//   _ntig, pavo, اسعا, ëku_, 
   {{0x6298013c,0xf42400d8,0x00000000,0x00000000}},	//   qavo, _соул_, --, --, 
   {{0x6b85a621,0x46c4dd06,0x6d10012c,0x98a80165}},	//   _atig, र्यह, ासंग_, nnaă_, 
   {{0x61e802d0,0xdb1c0036,0x00000000,0x00000000}},	//   _irdl, ptsë, --, --, 
   {{0xdb1c00dd,0x5edc02f5,0x61e802fb,0x63a00175}},	//   ltsé, বাবে, _hrdl, _jvmn, 
   {{0x46c41a55,0x6b8400ae,0xdedc0023,0x7da400fb}},	//   र्मह, _dtig, _ንጎኒ_, _йәмғ_, 
   {{0x6b85a622,0x19940276,0x7d0c0036,0xdb1c01d3}},	//   _etig, рабя, ëbss, ntsé, 
   {{0xcdcc00aa,0xf77000ae,0x3cfc0037,0x00000000}},	//   _کښی_, ماط_, _लवटे_, --, 
   {{0xb8780d4e,0x57f40798,0x1bd48a2e,0x63a400ae}},	// [2d6f0] _raíd, шпат, _топя, áinl, 
   {{0xb8787c36,0x6c840214,0x22400118,0x4ab0000d}},	//   _saíd, _پلیم, řiky_, _जाएव, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x01b809bd,0x3db400fe,0x659400c7,0x46c400cd}},	//   ংবাদ, _জনাল, сацу, र्बह, 
   {{0xf8ac021a,0x61e9a623,0x245874e7,0x88980375}},	//   _وکړ_, _ardl, гаць_, _בברי, 
   {{0x6b7c00c8,0x572400d1,0x00000000,0x00000000}},	//   ערונ, _ئىسك, --, --, 
   {{0xdef0044e,0xda042ef1,0x7a2001d5,0x893c0092}},	//   ልናን_, रहित_, _mеto, _የብአዴ, 
   {{0xd131920b,0xb0f011ba,0x910401a9,0x502c0023}},	//   تمع_, জস্ব_, рпие, _እትረኽ, 
   {{0x61e8002f,0x692c0356,0x00000000,0x00000000}},	//   _erdl, nşea, --, --, 
   {{0x4f2407a5,0xcfbc00d1,0xa5d400a2,0x00000000}},	//   рдоб, _ﻣﻪﻧﺒ, lỳaz, --, 
   {{0x2d800240,0xf77c0790,0x10f40064,0x00000000}},	//   ëje_, _orço_, _вяля, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6b840327,0x00000000,0x00000000,0x00000000}},	//   _qtig, --, --, --, 
   {{0xbcf9a624,0x5f74cae0,0x00000000,0x00000000}},	//   rméa, _طاهر, --, --, 
   {{0xc8946997,0x6f01a625,0x2ba83be5,0x00000000}},	//   ирањ, _ionc, _कटवा, --, 
   {{0x6f01a626,0x6b85a627,0xbcf801ed,0x88845d4e}},	//   _honc, _ttig, lmén, рлаж, 
   {{0x6b85a628,0xc7254209,0x316c0327,0x75280165}},	// [2d700] _utig, адай, _migz_, digz, 
   {{0x6f01a629,0x3ab0329e,0x00000000,0x00000000}},	//   _jonc, _мәст, --, --, 
   {{0x80bc0154,0x17c400c7,0x00000000,0x00000000}},	//   ্যত্, _қарҭ, --, --, 
   {{0x452800a7,0x00000000,0x00000000,0x00000000}},	//   ъжен_, --, --, --, 
   {{0xc7640aaf,0xbcf801d3,0x60c42e48,0x4db003d4}},	//   _ناسى, kmén, _ñimi, _জনোৱ, 
   {{0x6f01a62a,0xdb1c00dd,0xba001b49,0xbcf80316}},	//   _nonc, ttsé, _ልቡ_, jmén, 
   {{0x35a1a62b,0xbcf800dd,0xd36c1e87,0x6028005f}},	//   _марг, dmén, رۇم_, zīmī, 
   {{0xbcf8004e,0x6f0036f4,0xf1a4033f,0xdb1c950c}},	//   emén, _aonc, _गिरन, rtsé, 
   {{0x6f01a62c,0xb87800e4,0xbe8873a9,0x00000000}},	//   _bonc, _haíc, ксне_, --, 
   {{0xbcf80098,0x61e802f0,0x4ab001f9,0x00000000}},	//   gmén, _trdl, _जागव, --, 
   {{0x6f011c3e,0x80a41927,0x61e88b98,0xb8780ca8}},	//   _donc, _نمان, _urdl, _oníp, 
   {{0x6f000076,0x3d2400d4,0x00000000,0x00000000}},	//   _eonc, рьов, --, --, 
   {{0x6f01a62d,0xdd904e5c,0xdee801af,0x00000000}},	//   _fonc, _کوب_, _буйһ_, --, 
   {{0x3f84083a,0xbcf8012c,0x79a43412,0x387c0003}},	//   _itou_, cmén, ирбе, _żur_, 
   {{0x39480789,0x7cfc0023,0x5edc0eac,0xb9240a89}},	//   _pkcs_, _mërz, বাদে, афай, 
   {{0x3f840618,0x987581ad,0x6f0000f1,0x7c84010b}},	//   _ktou_, слац, _zonc, _туке, 
   {{0x6f01a62e,0x63a42230,0x3f74012d,0x00000000}},	// [2d710] _yonc, šinj, _dług_, --, 
   {{0xbb5400b5,0x692c0356,0x35e403c5,0xa6f400db}},	//   _dvdレ_, rşea, ицев, озуш, 
   {{0x5fd80d01,0x7a20022e,0x58d4014b,0x00000000}},	//   _बैसल, _kеtm, _лонт, --, 
   {{0xbcf800dd,0x3f85a62f,0x4d78010f,0x692c00a2}},	//   zmén, _otou_, אָסא, lşen, 
   {{0x045400b8,0x7cfc0200,0x00000000,0x00000000}},	//   _kūṣm, _bërz, --, --, 
   {{0x9735a630,0x692c0209,0x63040131,0x00000000}},	//   _اکرا, nşen, يونل, --, 
   {{0x3f85a631,0xf5680022,0x10a4374e,0x356939f6}},	//   _atou_, _ашак_, бийн, _аран_, 
   {{0x6f01a632,0xeb041ab2,0xe1f16dfb,0x00000000}},	//   _sonc, _रक्त_, بسه_, --, 
   {{0x6f01a633,0xbcf800dd,0x692c00ee,0x8e7400cf}},	//   _ponc, tmén, kşen, йунч, 
   {{0x6f000477,0x2e1406be,0x00000000,0x00000000}},	//   _qonc, ləfə_, --, --, 
   {{0x3f840093,0x525401ec,0xbcf84e79,0x6f000055}},	//   _etou_, _اناء, rmén, _vonc, 
   {{0x753804ba,0x6f000472,0x7cfc002e,0x00000000}},	//   _jjuz, _wonc, _këry, --, 
   {{0x6f007d64,0x7539a634,0x8538008f,0x00000000}},	//   _tonc, _mjuz, רגרי, --, 
   {{0x92a80183,0xb8780d12,0xbcf800e5,0x00000000}},	//   গ্ৰ_, _sníp, lmél, --, 
   {{0x753800e4,0x00000000,0x00000000,0x00000000}},	//   _ojuz, --, --, --, 
   {{0xb87809ff,0x7539a635,0x9bb40451,0x2d841f65}},	//   _raíc, _njuz, _ڀليڪ, _itne_, 
   {{0xc6747677,0xf8bcf578,0x6568020c,0x06c8787c}},	// [2d720] مطاب, _imél_, _èdhi, лгай_, 
   {{0x7538009f,0x63a40c53,0x247c0023,0xc0500677}},	//   _ajuz, šink, _ብቓላት_, לזן_, 
   {{0xd2442f4d,0x00000000,0x00000000,0x00000000}},	//   _آچ_, --, --, --, 
   {{0xa6d8015b,0x3eb801e3,0x00000000,0x00000000}},	//   সাইট, _öptv_, --, --, 
   {{0x7cfc02d3,0xc3083334,0x68e403ee,0x290001c8}},	//   _përz, ледж_, mdid, mjia_, 
   {{0x7538063f,0x29000165,0x00000000,0x00000000}},	//   _ejuz, ljia_, --, --, 
   {{0xa4f8dc89,0xe7e00d2c,0x41e400c6,0x68e40037}},	//   _پکار_, निकप, إستف, odid, 
   {{0x2901a636,0x75380200,0xa80800a2,0x00000000}},	//   njia_, _gjuz, _taıı, --, 
   {{0x290097cf,0x3dcc0798,0x68e5a637,0x5edc0eac}},	//   ijia_, _spfw_, idid, বাসে, 
   {{0xb7d80bd9,0x6440020c,0x68e5a638,0x290008e5}},	//   נקיי, _ixmi, hdid, hjia_, 
   {{0xde5800d3,0x00000000,0x00000000,0x00000000}},	//   рані_, --, --, --, 
   {{0x0db801d3,0x42080107,0xfca83fe6,0x00000000}},	//   گئیں_, _инҷо_, دادو_, --, 
   {{0x68e5a639,0xdfd01d48,0x2d8403d4,0x7f440276}},	//   ddid, _آيت_, _etne_, _ледж, 
   {{0xdd90a012,0x37a80032,0xbcf8004a,0xdd9400ee}},	//   _قوت_, ҫтан_, mmém, _дакы, 
   {{0x692c0209,0x6560014f,0xcf240592,0x68e40009}},	//   rşen, _ohmh, _برني, fdid, 
   {{0x99544dba,0x68e5a63a,0x290002d3,0xb878021c}},	//   ікац, gdid, gjia_, _baía, 
   {{0xb87804d4,0x60c40784,0xa77484dc,0x81cc00eb}},	// [2d730] _caía, _ñimu, злуч, ষটি_, 
   {{0x7bdda63b,0x68e5a63c,0x2900005b,0xbcf800e5}},	//   _isqu, adid, ajia_, zmél, 
   {{0x91e4037e,0x68e5a63d,0x7cfc0200,0x19580153}},	//   _auのc, bdid, _bërx, _ваны_, 
   {{0x5455a63e,0x692c0205,0x81cc00eb,0x00000000}},	//   овет, nşel, ষটা_, --, 
   {{0xb86470cb,0xe8240cb6,0xdce806be,0x00000000}},	//   _دادو, _ефро, nsdı, --, 
   {{0x291c0064,0x00000000,0x00000000,0x00000000}},	//   _įvai_, --, --, --, 
   {{0x7bdda63f,0x9118084c,0xfbcc0154,0x692c08a9}},	//   _lsqu, ициу_, িটিত, kşel, 
   {{0x75380451,0x910402dd,0x7bdc03ac,0x7cfc036e}},	//   _ujuz, іппе, _osqu, _gërx, 
   {{0x2f18006a,0x24580166,0x5334005b,0x46c4258d}},	//   _lêge_, _гать_, _деат, र्वह, 
   {{0x673c0175,0x0dc80408,0x68e401d5,0xdb1c02d2}},	//   _xjrj, алой_, zdid, ftsí, 
   {{0x7bdda640,0xf8bc0798,0x68e401a9,0xf1a40408}},	//   _asqu, _amém_, ydid, _ыран, 
   {{0xb5a800fe,0x00000000,0x00000000,0x00000000}},	//   _গঙাচ, --, --, --, 
   {{0x64402ee4,0xe13402d5,0x450403d4,0x69dc000d}},	//   _xxmi, _энцы, লোকক_, _पनही, 
   {{0x63a40491,0x7bdc011c,0x705001e2,0x4ab80395}},	//   áini, _dsqu, _وچکا, шумя_, 
   {{0xb8780587,0x2d85a641,0x80bc015b,0x68e40100}},	//   _saía, _utne_, ্যর্, tdid, 
   {{0x63a51b4e,0x08880c75,0xf8bc0332,0x00000000}},	//   šini, рбай_, _ccé_, --, 
   {{0x2901a642,0x98a80034,0x5edc015b,0x7a20022e}},	// [2d740] rjia_, znać_, বারে, _yеtk, 
   {{0x656001ab,0x98a8033f,0x00000000,0x00000000}},	//   _shmh, ynać_, --, --, 
   {{0x44a406b3,0x68e40332,0x00000000,0x00000000}},	//   قماق, pdid, --, --, 
   {{0xf77c0363,0xf8bc0332,0x68e40009,0xa92801ef}},	//   _orçh_, _gcé_, qdid, _dožá, 
   {{0xc3d42f5e,0x43d42d4b,0x225801a6,0x98a8033f}},	//   تغاث, تزاز, _šrk_, wnać_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb878a749,0xcb00033f,0x00000000,0x00000000}},	//   _maín, रॉएड_, --, --, 
   {{0x60f9a643,0x044402e8,0x46c407f7,0xdcec00d7}},	//   сния_, _дебн, र्रह, _piač, 
   {{0xdfd1a644,0x4ac81b61,0xf0b40214,0xc05802dd}},	//   ريد_, िभाव, زايش_, шік_, 
   {{0x7bdda645,0x657da646,0xbcf807ea,0xdcec0064}},	//   _rsqu, _kurh, rmém, _viač, 
   {{0xe0ac04c5,0x00000000,0x00000000,0x00000000}},	//   ক্ষভ, --, --, --, 
   {{0x657da647,0xdb1c0579,0x69dc0042,0x19c400d1}},	//   _murh, rtsí, dwre, үәнг, 
   {{0x657c009a,0x2f18002d,0x98a8031c,0x00000000}},	//   _lurh, _sêge_, llaħ_, --, 
   {{0xb8780077,0x7bdc0381,0x657c127b,0x00000000}},	//   _caín, _vsqu, _ourh, --, 
   {{0x657c7547,0x7a2001a9,0x00000000,0x00000000}},	//   _nurh, _kеti, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7bdda648,0x0b1800ec,0x00000000,0x00000000}},	// [2d750] _usqu, _گريڊ_, --, --, 
   {{0x3689137a,0xa928012c,0x9b6000d1,0x00000000}},	//   рсан_, _požá, _سۆزۈ, --, 
   {{0x657da649,0x7af4025c,0x3568010b,0xe6780212}},	//   _curh, _inxt, ардн_, ійці_, 
   {{0x657da64a,0xd4900023,0xe57951ee,0x00000000}},	//   _durh, _ዝበጽሑ_, ізі_, --, 
   {{0x657c0113,0xb87800ae,0x00000000,0x00000000}},	//   _eurh, _haío, --, --, 
   {{0x657c02b9,0x98a8025c,0x00000000,0x00000000}},	//   _furh, flaħ_, --, --, 
   {{0x94449105,0x657c00ee,0x10a401c4,0x00000000}},	//   _کھان, _gurh, пийн, --, 
   {{0xb878007b,0xe164007b,0xaa3c011a,0x78a80162}},	//   _maío, وديي, יתוח, ógvh, 
   {{0xb87801e7,0x00000000,0x00000000,0x00000000}},	//   _laío, --, --, --, 
   {{0xa2b5214b,0x237400d0,0x918000d1,0x692c0790}},	//   _обуч, ľajú_, _كۇتۇ, vşem, 
   {{0x657c02b9,0xb879a64b,0x2481a64c,0xd094008e}},	//   _xurh, _raín, žime_, _ешлы, 
   {{0xb878056a,0x7af403ac,0x8c449bd2,0x71700137}},	//   _saín, _anxt, земе, _تۇعا, 
   {{0x8d743c5b,0xb87800e4,0x826000cf,0x692c00a2}},	//   _کاتا, _paín, _قۇۇن, bşej, 
   {{0x692c03ee,0x69dc013f,0xbcf8003e,0xe98401d5}},	//   rşem, twre, hméh, мқон, 
   {{0x69dc01f5,0x7a20022e,0x06900150,0x00000000}},	//   uwre, _yеti, _ﺟﯘﻟﯩ, --, 
   {{0xfd1da64d,0x657c047e,0x0d20010b,0x32cc03e0}},	//   chì_, _rurh, _чүмү, lıyı_, 
   {{0x657da64e,0x69dc0165,0xbcf8013a,0x00000000}},	// [2d760] _surh, swre, dméh, --, 
   {{0x69dc232c,0xa96804a9,0x2e04013f,0x32cc0205}},	//   pwre, сиға_, nɑfo_, nıyı_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x657c07a9,0x75d000ae,0x00000000,0x00000000}},	//   _vurh, عينا, --, --, 
   {{0xf8b01203,0xdb1c01ed,0x234800f1,0x32cc0205}},	//   _אשר_, ltsá, يستی_, kıyı_, 
   {{0x657c049b,0xc6902264,0x3f801f60,0xf8bc003e}},	//   _turh, _سِر_, íkum_, _améh_, 
   {{0xdb1d9914,0x00000000,0x00000000,0x00000000}},	//   ntsá, --, --, --, 
   {{0xbcf8066d,0xc0580220,0x61dc2a67,0x20340023}},	//   rmék, йіп_, _मनीष, _ክትረክ, 
   {{0x442001e6,0xa2c40316,0x78a806ea,0xc32401a9}},	//   _åk_, _राप्, ógvi, _емак, 
   {{0xbcf804e6,0x00000000,0x00000000,0x00000000}},	//   mméi, --, --, --, 
   {{0xbcf80221,0x1cd9a64f,0x63a4031c,0xfd1c0051}},	//   lméi, одны_, ġinu, thì_, 
   {{0x63a40024,0xf99001d3,0xdb1c00e5,0x6918032e}},	//   šinu, ہبر_, dtsá, _síen, 
   {{0x61dc08ec,0xb87801e7,0x32cc236c,0x692c03e0}},	//   _मनुष, _saío, bıyı_, mşeh, 
   {{0xbcf80597,0x32cc0790,0x9e3c007f,0x692c0205}},	//   iméi, cıyı_, raďb, lşeh, 
   {{0xb8780077,0xbcf80036,0x00000000,0x00000000}},	//   _faíl, hméi, --, --, 
   {{0xb8780118,0x692c03e0,0x86440240,0x00000000}},	//   _hníz, nşeh, ራዉነት, --, 
   {{0x67d400f7,0xaba83090,0x628801c7,0x06e400eb}},	// [2d770] ноту, _فهيم_, _ofdo, নানি, 
   {{0x7af40bc9,0xec380375,0x3ebc0051,0x00000000}},	//   _unxt, _מאחר_, ngtt_, --, 
   {{0x692c05d1,0xe5b4010b,0xfc3c01e7,0x00000000}},	//   kşeh, ейхы, saíd_, --, 
   {{0x628928ca,0x32cc05d1,0xdcf80100,0x27fc00bc}},	//   _afdo, zıyı_, _ouvč, ózní_, 
   {{0x88801079,0x48c0008e,0x32cc03e0,0x692c03e0}},	//   _شیلن, _шәра, yıyı_, zşek, 
   {{0xb878032e,0x00000000,0x00000000,0x00000000}},	//   _maím, --, --, --, 
   {{0x32cc0205,0x00000000,0x00000000,0x00000000}},	//   vıyı_, --, --, --, 
   {{0xfbdc145e,0x2d800122,0x78bc0369,0xe2480092}},	//   kwê_, íjem_, ngqv, _ምዕመና, 
   {{0x63a40491,0xc4d00375,0x32cc03e0,0x00c4013d}},	//   áint, _בגן_, tıyı_, флык_, 
   {{0xdb1c01bf,0x59dc0ebb,0x2bdc00bc,0x9e8c0023}},	//   ltsæ, मबार, यबसा, _ዘበልና_, 
   {{0x3d18006a,0x63a40006,0x32cc05d1,0xf77c0139}},	//   _sëwa_, šint, rıyı_, _luç_, 
   {{0xdb1c005c,0x692c03e0,0x5fd809ab,0x00000000}},	//   ntsæ, rşek, _बैकल, --, 
   {{0xa2c4038e,0x32cc05d1,0x78bc0175,0x00000000}},	//   _राम्, pıyı_, dgqv, --, 
   {{0xdb1c00dd,0x6364004e,0xabb400c7,0x00000000}},	//   ttsá, cònd, маҭә, --, 
   {{0x2bdc00bc,0xb878032e,0x20540023,0x00000000}},	//   यबहा, _taíl, _ምስተረ, --, 
   {{0x3d18002e,0x2ee41196,0xdb1c00e5,0x00000000}},	//   _tëwa_, _hanf_, rtsá, --, 
   {{0x2ca00649,0xdb0c0113,0xbd300c75,0x0b4401a9}},	// [2d780] _ieid_, _eqañ, _جىيع, _онин, 
   {{0x2ca04f7f,0x9518031c,0x00000000,0x00000000}},	//   _heid_, ཱིའི_, --, --, 
   {{0x2ca0030a,0x7cf40139,0xdb1c01bf,0x78b40205}},	//   _keid_, _kürе, ftsæ, _şavş, 
   {{0x2ca00076,0x9e3c0306,0x290400e4,0xbcf80036}},	//   _jeid_, naďa, _õma_, tméi, 
   {{0xc3d896e0,0x2ca1a650,0x82e40032,0x692c0790}},	//   تباط_, _meid_, мғаҡ_, vşeh, 
   {{0x2ca1a651,0xbcf804c4,0x27e1a652,0x250810e5}},	//   _leid_, rméi, mwin_, _کرسی_, 
   {{0xbcf804e6,0x00000000,0x00000000,0x00000000}},	//   sméi, --, --, --, 
   {{0x2ca0033d,0x52740408,0xbcf800e5,0x00000000}},	//   _neid_, хучу, lmév, --, 
   {{0x692c0790,0x00000000,0x00000000,0x00000000}},	//   rşeh, --, --, --, 
   {{0x442405d9,0x63a43d72,0x6364067c,0x826801ca}},	//   mzo_, šins, fòne, _дазв_, 
   {{0x1d341ed2,0x4425a653,0x27e00020,0x1df800c9}},	//   ення, lzo_, hwin_, чены_, 
   {{0x2fe00598,0x2ca0015d,0x27e1a654,0x4425a655}},	//   ärgä_, _ceid_, kwin_, ozo_, 
   {{0x4425a656,0x2ca01c1d,0x7ac400d8,0x692c0432}},	//   nzo_, _deid_, мсве, lşew, 
   {{0xb87800e4,0x00000000,0x00000000,0x00000000}},	//   _vaím, --, --, --, 
   {{0x27e0b1e1,0xf77c03ee,0x58d43419,0x2ca09306}},	//   ewin_, _suç_, новт, _feid_, 
   {{0x2ca1a657,0xf77da658,0x28f80a89,0x00000000}},	//   _geid_, _puç_, месь_, --, 
   {{0x9fbd161d,0xa8340063,0x44240200,0x00000000}},	// [2d790] _অনুগ, ветљ, jzo_, --, 
   {{0x4425a659,0x00000000,0x00000000,0x00000000}},	//   dzo_, --, --, --, 
   {{0x44250264,0x27e0300b,0x00000000,0x00000000}},	//   ezo_, awin_, --, --, 
   {{0x27e00428,0x00000000,0x00000000,0x00000000}},	//   bwin_, --, --, --, 
   {{0xdb1c019b,0x78a806ea,0x00000000,0x00000000}},	//   rtsæ, ógvu, --, --, 
   {{0xdb1c037e,0xe3b1a65a,0x934400ee,0x00000000}},	//   stsæ, شره_, энле, --, 
   {{0x24800b91,0x4425a65b,0xbcf8007f,0x2fdc002e}},	//   žima_, azo_, lméu, wwug_, 
   {{0x442400ca,0x00000000,0x00000000,0x00000000}},	//   bzo_, --, --, --, 
   {{0x61f80038,0x2ca01c1d,0xe4554a96,0x4424033f}},	//   _ďalš, _reid_, _акты, czo_, 
   {{0x2ca1a65c,0xc4306f5d,0x80bc009e,0xdb1c088f}},	//   _seid_, _حکمت, ্যগ্, ntsä, 
   {{0x27e1a65d,0xa2c4041c,0x3eac00a3,0x2ee405da}},	//   zwin_, _रात्, _ddft_, _vanf_, 
   {{0xc0f0001f,0x27e00810,0x692c2b93,0xbcf80036}},	//   ውታል_, ywin_, lşev, hléf, 
   {{0x8fd0052f,0xdb1c01e6,0x2ee4007f,0x2ca1a65e}},	//   _сәйә, ktsä, _tanf_, _veid_, 
   {{0x6364026c,0x2ca0c23a,0xfd6400cd,0x692c06be}},	//   pòne, _weid_, _marṣ, nşev, 
   {{0x4424156b,0x2ca1a65f,0x27e0010a,0x8d5410ae}},	//   zzo_, _teid_, wwin_, _птич, 
   {{0x27e1a660,0x4425903b,0x00000000,0x00000000}},	//   twin_, yzo_, --, --, 
   {{0x59743d50,0x6d44009f,0xdb1c26bc,0x00000000}},	// [2d7a0] тыру, _ijia, ftsä, --, 
   {{0xff7800c8,0x4425a661,0x09e5a662,0x00000000}},	//   פטעמ, vzo_, _зоон, --, 
   {{0x27e018f7,0xba98025d,0x272401a8,0x46c40b6d}},	//   swin_, _מסיי, _löng_, र्गह, 
   {{0x27e0030d,0x4425a663,0xe7b400cf,0x4cdc0011}},	//   pwin_, tzo_, _لۅرد, যাকু, 
   {{0x26c80046,0xfd64002b,0x27e00113,0xb7b001c6}},	//   _оған_, _carṣ, qwin_, _бөхч, 
   {{0x4425a664,0x6364004e,0xfd6400b8,0x764800e5}},	//   rzo_, dònc, _darṣ, élyé, 
   {{0x6d4401f2,0x4ad011bc,0x44240c57,0x00000000}},	//   _ojia, द्यव, szo_, --, 
   {{0x6d4400ec,0x60c00175,0x00000000,0x00000000}},	//   _njia, ugmm, --, --, 
   {{0x261c0084,0xbcf9a665,0xdcf800b8,0x2ec800cd}},	//   ḽo_, llég, _nuvā, ऽभूत, 
   {{0x6d45a666,0xf8bc0036,0x7a2001a9,0x4c9c01ec}},	//   _ajia, _gléf_, _mеtr, _ﺃﺩﺍﺀ_, 
   {{0x261c0943,0x20e4014b,0xfe40072d,0x00000000}},	//   ṋo_, _аслҳ, دکشی, --, 
   {{0x27240008,0xd12c01e2,0x00000000,0x00000000}},	//   _hönd_, _وڅي_, --, --, 
   {{0x6d44fa6d,0x4ad000dc,0x21240477,0x272408a5}},	//   _djia, द्भव, mhmh_, _göng_, 
   {{0xdb1c7944,0xdcf80055,0x4cdc00eb,0x00000000}},	//   ktså, _duvā, যাগু, --, 
   {{0xbcf80048,0x7c84026b,0x00000000,0x00000000}},	//   fmét, _пупе, --, --, 
   {{0x261c06d6,0x9e3c02f0,0x1ad00154,0x272401a8}},	//   ḓo_, laďo, াযো, _lönd_, 
   {{0xdb1c5df7,0x6bd4036b,0xdcf800ef,0x00000000}},	// [2d7b0] ttsä, _یتیر, _guvā, --, 
   {{0x29040428,0xdb1c0217,0x671400d4,0xfb2400f2}},	//   _òman_, ftså, льєф, _سرخپ, 
   {{0xdb1c04f3,0xfd64002b,0xa6c41e4a,0x00000000}},	//   rtsä, _sarṣ, اقمى, --, 
   {{0xdb1d37c9,0xfd6400dc,0xdcf800cd,0x00000000}},	//   stsä, _parṣ, _yuvā, --, 
   {{0xdb1c01cf,0x2724032e,0x048400d1,0x00000000}},	//   ptsä, _bönd_, тәси_, --, 
   {{0xfd640882,0x2f1800d8,0x272408a5,0xd37000ec}},	//   _varṣ, _rêgo_, _röng_, گهڻ_, 
   {{0xe2a971c7,0x272401a8,0x00000000,0x00000000}},	//   راون_, _söng_, --, --, 
   {{0x13f40801,0xfd6400b8,0x00000000,0x00000000}},	//   _избя, _tarṣ, --, --, 
   {{0xf8bc00dd,0x8eb8084c,0xc42400f1,0x10640014}},	//   _elég_, мынт_, _لګول_, کُکُ, 
   {{0xbcf8012c,0x69d80793,0x6d440217,0x5f440032}},	//   hléd, _äveg, _sjia, лдыҡ, 
   {{0xbcf8004a,0xdcf8002b,0xc32c0133,0x00000000}},	//   ymét, _suvā, _بڕن_, --, 
   {{0xe8040316,0x692c083c,0x63640ba1,0xdb1c0240}},	//   रममा_, nşet, mòna, busë, 
   {{0x3984000d,0x636401c3,0xa0740354,0x2d440139}},	//   _aõs_, lòna, _йышш, bıen_, 
   {{0x27240ed6,0x692c05d1,0xdb140241,0x00000000}},	//   _köne_, hşet, _óbìn, --, 
   {{0xfaa1a667,0xa2c4228d,0xfc3c04d4,0xc3300375}},	//   расо, _रास्, raía_, בום_, 
   {{0x6d4450f9,0x81cc00bd,0xdcf800da,0x61fc0008}},	//   _ujia, ষয়ক_, _tuvā, _árle, 
   {{0xbcf9a668,0x46e9a669,0xf8bc00db,0xfc3c00c6}},	// [2d7c0] rmét, мдан_, _amés_, laín_, 
   {{0x6364007f,0xdb1c01e3,0x25380241,0x23c80037}},	//   kòna, ttså, _ṣàìs, _रमबद, 
   {{0x37cc015b,0xdb1c04fb,0x6b85a66a,0x2724032e}},	//   রিগর, dusè, _huig, _rönd_, 
   {{0x6b85a66b,0xbcf801ed,0x6364007f,0xdb1c713c}},	//   _kuig, lmér, dòna, rtså, 
   {{0xf8bc067c,0x6b84017a,0xdb1da66c,0xe7ac0406}},	//   _emés_, _juig, fusè, _चिटप, 
   {{0x6b840192,0x6364067c,0xbcf9a66d,0x00000000}},	//   _muig, fòna, plég, --, 
   {{0xbcf9a66e,0x69d829ef,0xa15831d5,0xb1a000ee}},	//   llée, _äved, наку_, ашык, 
   {{0x6b84030a,0x36640c91,0x27240205,0x11f4f9ec}},	//   _ouig, _расо_, _döne_, اتوگ, 
   {{0x7411a66f,0x3f65a670,0x6b85a671,0x42c9a672}},	//   _پولا, ктоб, _nuig, _оган_, 
   {{0x82189780,0xf8bc0241,0x3f74012d,0xdb1c0200}},	//   _оцет_, _ilée_, _tłum_, rusë, 
   {{0x6b840b23,0x42540276,0xbcf80036,0x9e3c00d0}},	//   _auig, _ртат, hlée, raďo, 
   {{0x6b85a673,0xdb1da674,0x8068036b,0x1dc40764}},	//   _buig, musé, _قماق_, लंबत, 
   {{0x6b8403d5,0xa0a40166,0x2bc8014b,0xff2401f0}},	//   _cuig, _ааҗд, куро_, _имдо, 
   {{0x27240afb,0x6b8408c2,0xef1400c7,0xbcf801d3}},	//   _yöne_, _duig, _имч_, gmér, 
   {{0x98a80034,0xaa58026a,0x6b84003a,0x4ad01fe7}},	//   niać_, виру_, _euig, द्धव, 
   {{0xbcf9a675,0x6b85a676,0xf8bc01e1,0x39840037}},	//   rmés, _fuig, _olée_, _võs_, 
   {{0xbcf806af,0xdb1c00e4,0x57f40108,0x692c03e0}},	// [2d7d0] glée, husé, ыпат, vşet, 
   {{0xa2c410fa,0x67d497d0,0x79a40cab,0xdb1c005c}},	//   _राष्, рофу, _ирме, kusé, 
   {{0x6b840196,0xd4b87b7e,0xbcf87cda,0x7bcc0112}},	//   _zuig, елец_, mléb, ltcu, 
   {{0x7af802a8,0xbcf806af,0x6b8400b5,0xdb1c0c6a}},	//   ɓuta, blée, _yuig, dusé, 
   {{0x7bcda677,0x63a00cfd,0xbcf80129,0xe80401ad}},	//   ntcu, _cwmn, clée, रमणा_, 
   {{0xdb1da678,0x6364067c,0xd1c857c6,0x00000000}},	//   fusé, tòna, елке_, --, 
   {{0x05b413f9,0x692c05d2,0x27240139,0x38380092}},	//   _مگنت_, mşer, _qöne_, _በመቀበ, 
   {{0x4fe9a679,0x63651c14,0xbcf800e5,0x9a700092}},	//   емин_, ròna, zmér, _በጤናው_, 
   {{0x63a000a9,0x9418013f,0xf2c5a67a,0xcf380212}},	//   _gwmn, _ɔyɛm_, _асен, ечні_, 
   {{0x6b840013,0x27243411,0x98a8033f,0x113800fb}},	//   _ruig, _töne_, biać_, ьяһы_, 
   {{0x6b8404c9,0xdb1c2d7d,0x814001d3,0xa9480092}},	//   _suig, cusé, _گھوم, _የጥብቅ, 
   {{0x6b85a67b,0x27200a28,0xfc3d2a61,0x1f6400f7}},	//   _puig, _यत्र_, raín_, лкөм, 
   {{0x692c0598,0xdcf800da,0xc32c03e6,0xbcf8002e}},	//   kşer, _atvē, _بڕۆ_, xlée, 
   {{0x6b85a67c,0xd0180432,0x00000000,0x00000000}},	//   _vuig, myń_, --, --, 
   {{0xc3300375,0x6b8400ad,0x636402e2,0xbcf800e5}},	//   מוך_, _wuig, kònn, rmér, 
   {{0x6b85a67d,0xbcf801d3,0x47c800fe,0x589400db}},	//   _tuig, smér, ৰিসী, ишуу, 
   {{0xd0180209,0xbcf80129,0x7bf400cf,0xcdc421f3}},	// [2d7e0] nyń_, ulée, _مىيز_, _раққ, 
   {{0xbcf9a67e,0xea000051,0x692c00a2,0x00000000}},	//   rlée, giải_, gşer, --, 
   {{0x692c0276,0xab6407d2,0x24940023,0x06e40154}},	//   uşes, _مۇڭى, _ዝበለት_, নালি, 
   {{0xbcf9a67f,0x935401d5,0x00000000,0x00000000}},	//   mléc, یروچ, --, --, 
   {{0x98a80034,0xbcf804e6,0x7cf807d9,0xd01800a2}},	//   wiać_, lléc, _härä, jyń_, 
   {{0xd0187d19,0xd054013f,0xdee002d3,0x7cf80822}},	//   dyń_, _ɑbɔs, ሓትን_, _kärä, 
   {{0x26d8c87e,0xbcf804e6,0x36640818,0xdb1c03b2}},	//   _ibro_, nléc, _баро_, ttsú, 
   {{0x60f80801,0xb87800c7,0xdb1da680,0x7cf8248c}},	//   тния_, _vaív, rusé, _märä, 
   {{0x04448271,0xbcf804e6,0xcf8c00f1,0xd018010b}},	//   _сеан, hléc, وژو_, gyń_, 
   {{0x38b801e1,0xbcf80036,0x98a8012d,0xdb1cea62}},	//   _kàrà_, kléc, piać_, stsú, 
   {{0x7cf8248c,0xb878032e,0x26d80200,0x6d88010e}},	//   _närä, _haít, _mbro_, _ỳara, 
   {{0xbcf801c7,0x7bcc0158,0x23c8012c,0x38b801e1}},	//   dléc, ttcu, _रमाद, _màrà_, 
   {{0xbcf83a64,0x26d8036b,0xfc3c0077,0x8c180451}},	//   eléc, _obro_, raío_, نيٽر_, 
   {{0x7bcda681,0xbcf8df44,0x09dc009e,0x7cf800fd}},	//   rtcu, fléc, ডিনা, _bärä, 
   {{0x7cf8008e,0xdd9000c6,0xeec01411,0xbcf80221}},	//   _cärä, _بوب_, _ايىپ, gléc, 
   {{0x7cf80724,0x3f8403c1,0x26d81a06,0xa8a41586}},	//   _därä, _kuou_, _abro_, йрук, 
   {{0xfe740323,0xad240131,0xdb1c3c02,0x2ec0004e}},	// [2d7f0] _шүү_, _دىيى, ktsø, _төөм, 
   {{0xbcf9a682,0x38b80248,0x7ae0000f,0x6364007f}},	//   bléc, _bàrà_, _űntf, wònn, 
   {{0xd0187d19,0x3f840077,0x7cf8008e,0x67d40131}},	//   zyń_, _luou_, _gärä, _қору, 
   {{0x3f8402b5,0xb8780077,0x9b680131,0x2e38010f}},	//   _ouou_, _saíu, _яшқа_, עגאנ, 
   {{0xdb1c2ab7,0xf3140139,0x3c8401ec,0xade80118}},	//   ftsø, лндә_, _ﺭﯞﺣﻰ_, _छैनन_, 
   {{0x38b80241,0x3720004b,0x88380375,0x0838010f}},	//   _fàrà_, _اوسې, _יתרו, _יערל, 
   {{0x7cf80724,0x38b80248,0xb6c0013d,0x8d9c01ec}},	//   _xärä, _gàrà_, _вөҗд, _ﺃﺨﺫﺕ_, 
   {{0xd1740993,0xd0187d19,0xe18808f0,0x00000000}},	//   шылы, tyń_, دئون_, --, 
   {{0xf1c40030,0xb2c41ec7,0x6305a683,0x2724007c}},	//   _snáď_, _مغاو, _گولل, _höna_, 
   {{0xd01800ee,0x764000d2,0x38b801e1,0xfc3c0332}},	//   ryń_, ûnyw, _yàrà_, raíl_, 
   {{0x6304049e,0x3f8009f3,0xfc3c007b,0x00000000}},	//   _دولل, íkur_, saíl_, --, 
   {{0x272400b0,0xa0c4188d,0xaee00055,0xaf240092}},	//   _möna_, _هيمو, _baṃh, _ስለሌለ, 
   {{0x7cf82776,0x8fa52f07,0x272401e3,0xb87808a5}},	//   _särä, _тале, _löna_, _maís, 
   {{0xfaa0c5c4,0xddd400ee,0x7cf80716,0xbcf801c7}},	//   жаро, _ýaşu, _pärä, tléc, 
   {{0xbb409e06,0x09e42235,0xc33002e4,0xa03401d9}},	//   церк, шовн, קול_, _پى۪ت, 
   {{0x2d84166a,0xbd540050,0xbcf80221,0xb87801e7}},	//   _iune_, _پر٘ژ, rléc, _naís, 
  
   {{0x2d85a684,0x7cf8025a,0xada0023b,0xbcf81545}},	// [2d800] _hune_, _wärä, _тақл, sléc, 
   {{0x2d85a685,0x7cf88b82,0x3d1800e8,0x2d80000d}},	//   _kune_, _tärä, _rëwi_, _hiie_, 
   {{0x2d840302,0xc485a686,0x161c07f7,0x2b580010}},	//   _june_, алек, पनगर_, morc_, 
   {{0x2d85a687,0x636400f7,0x4ad0a5b3,0xb87800d8}},	//   _mune_, tòno, द्रव, _caís, 
   {{0x2d85a688,0xdb1d449a,0x2d800036,0x22940cc9}},	//   _lune_, ttsø, _miie_, биля, 
   {{0x68e5a689,0x26d8003e,0x3f84004d,0x636400db}},	//   leid, _ubro_, _ruou_, ròno, 
   {{0x1bed2df6,0x2d85a68a,0x68e40295,0xb87810d8}},	//   _चैनल_, _nune_, oeid, _faís, 
   {{0x68e5a68b,0x2d800036,0xbcf80c6a,0x2b580427}},	//   neid, _niie_, kléa, horc_, 
   {{0x42e8026a,0x2d8403cd,0xff040006,0x00000000}},	//   _имао_, _aune_, аянн, --, 
   {{0x68e5a68c,0x2d8400a8,0x6d4800d2,0xb87808a5}},	//   heid, _bune_, éjan, _kaír, 
   {{0x68e5a68d,0x00c9a68e,0xd3444fe0,0x2d840009}},	//   keid, _алек_, _دیوه_, _cune_, 
   {{0xe0d001d9,0xb87800d8,0x68e46c3f,0xbcf80332}},	//   _رٲت_, _maír, jeid, fléa, 
   {{0x2b5803bd,0x68e40793,0x2d800036,0x92e80183}},	//   forc_, deid, _diie_, যাৰ_, 
   {{0x2d85a68f,0x80d00316,0x2d8000a3,0x2b580427}},	//   _fune_, भ्रे, _eiie_, gorc_, 
   {{0x68e40597,0x2989a690,0x2d855e76,0xf8bc0129}},	//   feid, исто_, _gune_, _aléa_, 
   {{0xdb1c04bf,0x68e5a691,0x7ae0002d,0xbcf801e7}},	//   musí, geid, _űntd, bléa, 
   {{0xbcf9a692,0xb87800d8,0xddc800a2,0x00000000}},	// [2d810] cléa, _raís, _şoňk, --, 
   {{0x30740302,0x68e5a693,0xb87810d8,0x2d85a694}},	//   שתמש_, aeid, _saís, _yune_, 
   {{0xb879a695,0x68e41a84,0x2d84011f,0xdf340051}},	//   _país, beid, _xune_, _đắt_, 
   {{0x27240793,0x2d8006af,0x00000000,0x00000000}},	//   _vöna_, _xiie_, --, --, 
   {{0x6918032e,0x00000000,0x00000000,0x00000000}},	//   _víet, --, --, --, 
   {{0x97240e6b,0x99d804c5,0x2725a696,0xdb1c0118}},	//   _افسو, দটীক, _töna_, kusí, 
   {{0xdbdc02fb,0xb9dc0b82,0x02d40b24,0x2724002f}},	//   dšív, _እኒ_, صويب_, _könn_, 
   {{0xdb1c068c,0x91041892,0xf47401ec,0x5558011c}},	//   dusí, спие, _көлі_, _сабя_, 
   {{0x2d85a697,0x67300086,0x745801d9,0x799402d0}},	//   _sune_, _ôijò, _ششرس_, _ltxw, 
   {{0x2d85a698,0x4f085abb,0x68e59379,0xadc000c7}},	//   _pune_, унон_, zeid, ahẽm, 
   {{0x7bdc0d04,0x79940070,0xdb1c006a,0x68e5a699}},	//   _apqu, _ntxw, kusâ, yeid, 
   {{0x69c8067c,0x00000000,0x00000000,0x00000000}},	//   àdem, --, --, --, 
   {{0x68e40029,0x2d8000af,0x2b580276,0x2d84002e}},	//   veid, _viie_, torc_, _wune_, 
   {{0x2d85a69a,0x68e5a69b,0x2d80013f,0xbcf9a69c}},	//   _tune_, weid, _wiie_, rléa, 
   {{0x68e5a69d,0x7bc006c8,0x2d840009,0x2724032e}},	//   teid, _ānue, _uune_, _bönn_, 
   {{0x6ed02699,0x888410d9,0xbcf9a69e,0x2b5805c7}},	//   ब्रु, слаж, llén, sorc_, 
   {{0x63640699,0xb878617f,0xdcf80024,0x00000000}},	// [2d820] wònm, _saír, _atvė, --, 
   {{0x59a4012c,0xf3fc0154,0x00000000,0x00000000}},	//   गीहर, ্নার_, --, --, 
   {{0xbcf8020c,0x799402d0,0x6fd0009e,0x1778234c}},	//   ilén, _gtxw, তিয়ে, рсть_, 
   {{0xf4940020,0xdcf80006,0xb87800c7,0x2724002f}},	//   _ይበልጥ_, _buvę, _vaír, _gönn_, 
   {{0xbcf80c6a,0x6f0002d0,0x9e3c00d0,0x2bf803d4}},	//   klén, _onnc, raďi, ুনকৈ_, 
   {{0x316c002f,0xf41403d4,0xe2f801ec,0xf0341954}},	//   _ahgz_, _দেহৰ_, рекі_, _እስላም, 
   {{0xb6a1a69f,0xdb1c06ed,0x4614177a,0xb8780022}},	//   _хисл, lusã, _اوزر, _haíp, 
   {{0xa2c407b7,0x36180375,0x7640012d,0x00000000}},	//   _राक्, _גולד, źnyc, --, 
   {{0x9e3c0100,0xd3c40220,0x00000000,0x00000000}},	//   naďv, _وتكى, --, --, 
   {{0xdcec03e0,0xef1000cf,0x00000000,0x00000000}},	//   _ıkın, зүшө, --, --, 
   {{0x80a46dd7,0x82643918,0x63a40356,0x11f80066}},	//   _همان, _اهان, ţind, _پونک_, 
   {{0xf8bc1709,0x7bc00055,0x00000000,0x00000000}},	//   _alén_, _ānub, --, --, 
   {{0x2fd003c7,0xbcf8204f,0x2724007c,0xa0c400f1}},	//   _فتوح, blén, _rönn_, _هيڅو, 
   {{0xaa9406b3,0x7ae0002d,0x272408a5,0x00000000}},	//   зирч, _űntb, _sönn_, --, 
   {{0x98e4007b,0x00000000,0x00000000,0x00000000}},	//   يكسو, --, --, --, 
   {{0x63a45e93,0x7c944a4c,0xdd90040b,0xdb1da6a0}},	//   šiny, _اشغا, _ٹوک_, fusã, 
   {{0x69d8049f,0x0f3001d5,0x97140cb6,0xc03c0240}},	// [2d830] _även, _رکید, омац, _ክትብለ, 
   {{0xab981aa3,0xfaa400f7,0xdb1c00e5,0x00000000}},	//   _اخير_, _ушин, ntsü, --, 
   {{0x7ae4014f,0xdb1c002f,0x272408a5,0x00000000}},	//   mejt, itsü, _tönn_, --, 
   {{0x7ae5a6a1,0x636515a0,0x3d18002e,0x7f58014f}},	//   lejt, lònh, _tëwu_, hotq, 
   {{0xa2c4038e,0xd2a80640,0x356801ec,0x00000000}},	//   _राख्, акле_, _ұран_, --, 
   {{0x7ae5a6a2,0xbcf800d5,0x7f580477,0x9e3c02f0}},	//   nejt, kléo, jotq, laďu, 
   {{0x356806ed,0xf4140183,0x06e400cc,0x45a000d1}},	//   _бран_, _দেশৰ_, নাখি, _يەكك, 
   {{0x7ae4ac3e,0xa4d40111,0xaee00055,0xbcf8002e}},	//   hejt, _носі, _kaṇh, wlén, 
   {{0xcc895a58,0x7ae40122,0x94442586,0x75380064}},	//   ینده_, kejt, _بھان, _imuz, 
   {{0x0ea802f6,0x6364067c,0xf8bc00d8,0xbcf8002e}},	//   шкой_, jònh, _oléo_, ulén, 
   {{0x7ae40316,0x6f00004d,0xbad00150,0x00000000}},	//   dejt, _vnnc, _ﺘﺤﺘﺎ, --, 
   {{0x63a4084c,0xb8780cad,0xdb1c01a8,0x9f0800db}},	//   ţine, _gbíg, rtsý, _ۇزىك_, 
   {{0xbcf9a6a3,0x753804ba,0x61e40311,0x7f580455}},	//   plén, _mmuz, ăile, botq, 
   {{0xb8780332,0x00000000,0x00000000,0x00000000}},	//   _mbíd, --, --, --, 
   {{0x7539a6a4,0xf8bda6a5,0xbcf84ae9,0x2d440139}},	//   _omuz, _cléo_, cléo, dıev_, 
   {{0x8d74afd5,0x8c4401e0,0x07a401c6,0xc9641cb8}},	//   _باتا, _мейе, жаан, івай, 
   {{0x7ae4016d,0xecb00154,0xd2c803ce,0x0cc400bc}},	// [2d840] bejt, _কাপড, _रांझ, वलीम, 
   {{0x7539a6a6,0xd1bc1e38,0x8699646b,0x272401b8}},	//   _amuz, ሰረት_, ртат_, _vöno_, 
   {{0xb87801e1,0x75380083,0xb6f4c947,0x85e8011c}},	//   _abíd, _bmuz, تىلا_, рдев_, 
   {{0x636466ce,0xb87800e4,0x290c0419,0x00000000}},	//   mòni, _taíp, ájač_, --, 
   {{0x63641daa,0xf485a6a7,0xa29401ce,0x229428e8}},	//   lòni, زانی, палі, пиля, 
   {{0x7539a6a8,0xa29400d4,0x00000000,0x00000000}},	//   _emuz, чакі, --, --, 
   {{0x63641e7b,0xdb1c2d7d,0xd12c0372,0x4cc0015b}},	//   nòni, ursé, گۅن_, ষ্যু, 
   {{0x61f8074d,0x315400c6,0xbcf800e8,0x00000000}},	//   rvvl, يجية_, glél, --, 
   {{0x42d4109a,0xd12c0228,0x00000000,0x00000000}},	//   _міжу, دۅن_, --, --, 
   {{0xf8bc003e,0x72c0cc9a,0x00000000,0x00000000}},	//   _alél_, _обуз, --, --, 
   {{0x7ae5a6a9,0x602001e1,0xbd69a6aa,0x412800db}},	//   vejt, _bámú, ирме_, _кожо_, 
   {{0x2fd4021a,0x24800c53,0x636456ed,0xdb1c00c5}},	//   _ژوند_, žimu_, dòni, stsü, 
   {{0x7ae4012c,0xb1111bf8,0x7c6401d5,0x42a00092}},	//   tejt, _تونغ, تادل, _ጌትነት_, 
   {{0x63644d74,0xdd905f2e,0x5ed80154,0xbcf800e4}},	//   fòni, _كوت_, _ভোরে, pléo, 
   {{0x7ae5a6ab,0xdb1c65ff,0x636400db,0x6ecc00cd}},	//   rejt, gusá, gòni, _दातु, 
   {{0x7ae5a6ac,0x00000000,0x00000000,0x00000000}},	//   sejt, --, --, --, 
   {{0x368865e1,0x7ae4044e,0xdb1c026c,0x9e3c00d0}},	// [2d850] асен_, pejt, pusà, raďu, 
   {{0x75380ffb,0xa775a6ad,0x9fa00de2,0xdb1c01ef}},	//   _smuz, длуч, gééy_, busá, 
   {{0xa2c410eb,0xa49801f2,0x1959a6ae,0xf6440124}},	//   _राज्, _ịhụt, _ганы_, цхан, 
   {{0x628803ac,0x4cc00011,0xaee000b8,0xbcf801ef}},	//   _agdo, ষ্ঠু, _taṇh, klém, 
   {{0xb11001f2,0x53a43576,0x62880175,0x79500327}},	//   _hụgh, чалб, _bgdo, għwe, 
   {{0xd1bc1e38,0xe3b005d9,0x00000000,0x00000000}},	//   ሰረቱ_, ئرن_, --, --, 
   {{0xd25000d1,0x354401af,0x00000000,0x00000000}},	//   عنع_, _дхав, --, --, 
   {{0x7539a6af,0x3f9800b0,0x00000000,0x00000000}},	//   _umuz, _ōpua_, --, --, 
   {{0x636400db,0x00000000,0x00000000,0x00000000}},	//   zòni, --, --, --, 
   {{0x60200241,0x23280114,0xe298009b,0x00000000}},	//   _sámú, _дођи_, _мађ_, --, 
   {{0xf8bc0cfc,0xcc884716,0x636435f5,0xf8c88367}},	//   _além_, ینگه_, xòni, िलाय, 
   {{0xbcf9a6b0,0x2d85a6b1,0xc614011a,0x00000000}},	//   blém, öme_, לחתי_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb11000b4,0x63644d74,0xf1cc043e,0xdb1c00e5}},	//   _bụgh, tòni, संपन, tusá, 
   {{0x0d9805a2,0xbd640092,0x39700023,0x00000000}},	//   _утлы_, ደለችም_, _ጸለምቲ_, --, 
   {{0x63640372,0x9e3c0122,0xdb1c06ea,0xf98000d8}},	//   ròni, raďt, rusá, егсо, 
   {{0x8ca0006d,0x98a80306,0x9e3c0306,0x8c440798}},	// [2d860] _क्यो, chač_, saďt, _хепе, 
   {{0x636400f7,0xcb68004b,0x692c0356,0xdb1c00e5}},	//   pòni, _دمخه_, nşez, pusá, 
   {{0xf8bc01ef,0x00000000,0x00000000,0x00000000}},	//   _zlém_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf48000d1,0xfc3c0332,0x07f800ae,0x00000000}},	//   нушн, mbíc_, _ارجع_, --, 
   {{0xbcf800e4,0x00000000,0x00000000,0x00000000}},	//   vlém, --, --, --, 
   {{0x4534023a,0xd76401d5,0x06641176,0x7ec001e1}},	//   _ехат, _آچقی, _راسپ, _lípà, 
   {{0x2508f619,0xbcf80118,0xdfd001c8,0x00000000}},	//   _برسی_, tlém, پيد_, --, 
   {{0x1f74004e,0x00000000,0x00000000,0x00000000}},	//   млия, --, --, --, 
   {{0xf8340375,0x62880153,0x00000000,0x00000000}},	//   פנית_, _ugdo, --, --, 
   {{0x4254ea80,0xc0e41507,0x0084011c,0xf58800a2}},	//   _عنصر, _ножк, _елео, _ỳazỳ, 
   {{0xde48044e,0xbcf9a6b2,0x00000000,0x00000000}},	//   _ብዘየገ, plém, --, --, 
   {{0xbcf800dd,0xb11002e3,0x4ff000c7,0xd1082356}},	//   llék, _sụgh, _аҧыс, वारण_, 
   {{0xb110063f,0x00000000,0x00000000,0x00000000}},	//   _pụgh, --, --, --, 
   {{0x58d4678d,0x6ed80375,0x489801f2,0xe9e40138}},	//   мовт, _החופ, _ọhụh, нцто, 
   {{0x3eada6b3,0x95140055,0x00000000,0x00000000}},	//   _heft_, _iṅgh, --, --, 
   {{0x9724179e,0x5718c583,0xf6e402e8,0x00000000}},	// [2d870] وفرو, ожая_, зцен, --, 
   {{0xb11002e3,0x3689a6b4,0x764001d3,0x2ca403e0}},	//   _tụgh, ссан_, únyo, ımde_, 
   {{0xcb100375,0x7af403ac,0xbcf801d3,0x00000000}},	//   _סלט_, _iaxt, jlék, --, 
   {{0x3eac2403,0x7af40139,0x00000000,0x00000000}},	//   _left_, _haxt, --, --, 
   {{0xfc3c0077,0x00000000,0x00000000,0x00000000}},	//   maís_, --, --, --, 
   {{0x3ead4543,0x7af405c7,0xbcf8003e,0x91e4010b}},	//   _neft_, _jaxt, flék, доке, 
   {{0xdb1c005b,0x92340023,0xc6900115,0x00000000}},	//   musä, _እንመሃ, _יאם_, --, 
   {{0x636400a3,0x7af5a6b5,0x63a40356,0xdb1c340f}},	//   dònu, _laxt, ţina, lusä, 
   {{0x3ead4cc1,0xbcf80789,0x951400b8,0x00000000}},	//   _beft_, pléj, _aṅgh, --, 
   {{0xf8bc0098,0x7af40009,0xa2940111,0xbcf80419}},	//   _blék_, _naxt, _зафі, lléh, 
   {{0xc3300302,0x3eac0076,0x737400c7,0x06b000cc}},	//   _שוב_, _deft_, _дыҧх, _চামি, 
   {{0x8c4535dc,0xe0d18414,0x53d000dc,0x8d75a6b6}},	//   деме, _مزه_, _समाश, باخا, 
   {{0x7af5a6b7,0x24580118,0xde480023,0xdb1c01f4}},	//   _baxt, _týmů_, _ብዘይገ, kusä, 
   {{0x09e43117,0x7af5a6b8,0xbcf80c5e,0xc0dc0240}},	//   могн, _caxt, hléh, ዓዕል_, 
   {{0x658c06be,0xfe98011a,0x8d5403fb,0xde8800ae}},	//   _kşhe, _ויצמ, _отич, _عضوه_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x06b0045e,0x0ba8030c,0xbcf800bc,0x7af45170}},	// [2d880] _চাবি, _باعى_, dléh, _faxt, 
   {{0xe6a80dad,0x7af4005a,0xbcf8002e,0x2b580066}},	//   गरेज, _gaxt, ylék, _ریزد_, 
   {{0xf8bc0c6a,0x3d0001f9,0x00000000,0x00000000}},	//   _oléh_, षाचे_, --, --, 
   {{0x61fc1bd1,0x2725a6b9,0x4808084c,0xbcf80118}},	//   _árli, _möni_, _демн_, vlék, 
   {{0xf8b002e4,0x7af5a6ba,0xd36c00d1,0x4da800fe}},	//   _בשר_, _yaxt, ڭۇل_, _কমোৱ, 
   {{0xdee0693c,0x12b40131,0xda6400db,0x692c0205}},	//   ዓትን_, ىشىڭ, _تاۋي, vşey, 
   {{0x2b94007c,0x3664022e,0x00000000,0x00000000}},	//   _läc_, _жаро_, --, --, 
   {{0xb8780077,0xd2580212,0x5ff40120,0xd25404f2}},	//   _ubíc, чці_, езиу, رینش_, 
   {{0xb461a6bb,0x30900131,0x00000000,0x00000000}},	//   _актл, خشىس, --, --, 
   {{0x692c03ee,0xbcf9a6bc,0x00000000,0x00000000}},	//   rşey, plék, --, --, 
   {{0xbcf9a6bd,0x6ecc29d9,0x00000000,0x00000000}},	//   lléi, _दारु, --, --, 
   {{0x7af5a6be,0xdb1c002f,0x00000000,0x00000000}},	//   _saxt, zusä, --, --, 
   {{0x7b64824c,0x7af407d6,0x3eac03cd,0x71400137}},	//   дтве, _paxt, _teft_, _جۉيۅ, 
   {{0xf044205b,0x2f500184,0xf8bc00e4,0x78ac863c}},	//   _تعمی, _үтәс, _iléi_, _secv, 
   {{0x7af40cc1,0xbcf80a40,0x272400ee,0xf8bc02d2}},	//   _vaxt, hléi, _göni_, _hléi_, 
   {{0x7af41574,0xf8bc0036,0x6e2400b5,0xd9d000eb}},	//   _waxt, _kléi_, øjbe, াবলম, 
   {{0xb8f4551c,0x2984dfe6,0x7af54999,0xdb1c26bb}},	// [2d890] _सा_, тырг, _taxt, tusä, 
   {{0xbcf801e7,0x00000000,0x00000000,0x00000000}},	//   dléi, --, --, --, 
   {{0xbcf8020c,0x78ac03e0,0xdb1c007c,0x2cb801e1}},	//   tléh, _tecv, rusä, _ìddó_, 
   {{0xbcf801c7,0x458800e4,0x00000000,0x00000000}},	//   fléi, _ẽtév_, --, --, 
   {{0xf8bda6bf,0xb110063f,0xb3e8bed4,0xbcf88ec5}},	//   _idé_, _lụch, تعال_, gléi, 
   {{0xbcf80306,0x7bc0002b,0x00000000,0x00000000}},	//   sléh, _ānul, --, --, 
   {{0xbcf80306,0xe6646390,0x00000000,0x00000000}},	//   pléh, _атто, --, --, 
   {{0xe571003b,0xf8bc04e6,0xbcf95db1,0x630401b9}},	//   _نطق_, _bléi_, bléi, _یوقل, 
   {{0x00e0b4c7,0x27240166,0x00c4010b,0xbcf801e7}},	//   ужын, _söni_, хлык_, cléi, 
   {{0x27e40628,0xb11001f2,0x249800bc,0xe3746ef4}},	//   _ämne_, _bụch, čemž_, _алуы, 
   {{0xdb1c0254,0x00000000,0x00000000,0x00000000}},	//   ntsõ, --, --, --, 
   {{0x8d740e5a,0xf8bda6c0,0x71700132,0xdcec00b8}},	//   عادا, _fléi_, _جۇعا, _phaā, 
   {{0xd0080364,0x6364067c,0x00000000,0x00000000}},	//   _хеле_, còns, --, --, 
   {{0xf8bc0cad,0x00000000,0x00000000,0x00000000}},	//   _adé_, --, --, --, 
   {{0xb11002e3,0xdb240162,0x8e7400df,0x00000000}},	//   _gụch, úsár, _אײַנ_, --, 
   {{0xba142764,0xc21008d8,0xe6a807b6,0xdb1c007c}},	//   ريقا_, נהן_, गर्ज, xtsö, 
   {{0xaee006d6,0x00000000,0x00000000,0x00000000}},	// [2d8a0] _hoṱh, --, --, --, 
   {{0xf8bc0248,0xb90401ad,0x00000000,0x00000000}},	//   _edé_, _मॉ_, --, --, 
   {{0xfad41a4c,0x35a0009d,0xdb1c44b3,0x00000000}},	//   _אויך_, гахг, ttsö, --, 
   {{0xb87801e1,0xbcf8000c,0xe70800ec,0x07a400c0}},	//   _ibín, tléi, _ڪڪرن_, _памн, 
   {{0x69dda6c1,0xe2f96689,0xdb1c01e3,0x00000000}},	//   ltre, делі_, rtsö, --, 
   {{0xbcf9a6c2,0x69dc0ea0,0xd36c0131,0x248c0092}},	//   rléi, otre, قۇق_, ንትራት_, 
   {{0x69dda6c3,0xbcf99d6b,0x629801e4,0xa1581606}},	//   ntre, sléi, rcvo, маку_, 
   {{0xb878a0e3,0xbcf801c7,0x00000000,0x00000000}},	//   _raíz, pléi, --, --, 
   {{0x69dc324c,0x9f540aa8,0x00000000,0x00000000}},	//   htre, квич, --, --, 
   {{0x69dc0dd4,0xc32c1e4a,0x3ce0012c,0xb87801e1}},	//   ktre, _دەت_, ट्ने_, _obín, 
   {{0x4424b058,0x2d4400dd,0xb1800306,0x00000000}},	//   lyo_, rűen_, šťal, --, 
   {{0x4425a6c4,0x69dca20f,0x6364004e,0x91c018c7}},	//   oyo_, dtre, pòns, _тәшл, 
   {{0xb8780ca8,0xd1240150,0x00000000,0x00000000}},	//   _abín, _جةلى, --, --, 
   {{0x4425a6c5,0x69dda6c6,0xa3e8951e,0x2ca471e1}},	//   iyo_, ftre, _बहन_, ımda_, 
   {{0x4425a6c7,0x9984012c,0xbcf801ef,0x00000000}},	//   hyo_, álů_, dlév, --, 
   {{0x4425a6c8,0x6d4c00fd,0xd1bc0092,0xf8c808dd}},	//   kyo_, ılaç, ደረባ_, िलेप, 
   {{0x69dda6c9,0x4425a6ca,0xa95402bf,0x8c840022}},	// [2d8b0] atre, jyo_, укті, _аәра_, 
   {{0xaee00084,0x7bcda6cb,0x69dc0016,0xbcf801d3}},	//   _yoṱh, mucu, btre, glév, 
   {{0x69dda6cc,0x4425a6cd,0x7d1c011f,0xb87801e1}},	//   ctre, eyo_, _koqs, _gbín, 
   {{0x81d403d4,0x44240067,0x28a8000d,0x00000000}},	//   িবা_, fyo_, _छ्पि, --, 
   {{0x4425a6ce,0x7bcda6cf,0x61e802d0,0x7e68017a}},	//   gyo_, nucu, _apdl, _lyfp, 
   {{0xe3b094b9,0x02c01fe2,0x81e80f22,0x7d00013f}},	//   صره_, айшо, মিন_, _ɔnsa, 
   {{0x4425a6d0,0x7bcda6d1,0x00000000,0x00000000}},	//   ayo_, hucu, --, --, 
   {{0x4425a6d2,0xaee006d6,0x2724014a,0x7bcc48b5}},	//   byo_, _roṱh, _dönu_, kucu, 
   {{0x4425a6d3,0x7bcda6d4,0xb87800c6,0xe5341064}},	//   cyo_, jucu, _mbío, _сеть, 
   {{0x7bcda6d5,0xe45000c6,0x28a8000d,0x4e28009d}},	//   ducu, _اضف_, _छ्नि, доон_, 
   {{0x6ea4066d,0x7d1c01a9,0xbcf802d2,0x00000000}},	//   ونکہ_, _boqs, hléu, --, 
   {{0x7bcc0117,0x69dc33b8,0xf8c818cc,0xfc3c908e}},	//   fucu, vtre, िलोप, rbín_, 
   {{0x317c0365,0xaee01682,0x7bcc192e,0xf0000075}},	//   mmuz_, _woṱh, gucu, _сүпи, 
   {{0x61f4010e,0x60c400de,0x00000000,0x00000000}},	//   _çelý, _ķimi, --, --, 
   {{0x21fc012c,0x60e8003b,0x4424037e,0x7bc80153}},	//   máhá_, _åsmø, zyo_, _įmuš, 
   {{0x69dda6d6,0x7bcda6d7,0x4424c0dc,0xbcf86085}},	//   rtre, bucu, yyo_, loén, 
   {{0x44256e91,0x7bcda6d8,0x6d44422c,0xbc901155}},	// [2d8c0] xyo_, cucu, _imia, ášťo, 
   {{0x4425a6d9,0x69dda6da,0x06b00f22,0x3ce00034}},	//   vyo_, ptre, _চাহি, ट्ठे_, 
   {{0x4425a6db,0x63a00175,0x7d1c01a9,0xdcf80171}},	//   wyo_, _stmn, _yoqs, _guvē, 
   {{0x4425a6dc,0xe7b401d9,0x81e80154,0xf500305d}},	//   tyo_, _مۅرد, মিম_, изхо, 
   {{0xbcf8114f,0x4425a6dd,0x07a40120,0xdb1c00c7}},	//   mlét, uyo_, _јагн, vusú, 
   {{0x4425a6de,0xe3747e27,0xbcf8ea5b,0xe2c80b6c}},	//   ryo_, ыллы, llét, روعو_, 
   {{0x44247004,0xf74005c5,0x6d45a6df,0x26d801c7}},	//   syo_, _теро, _omia, _icro_, 
   {{0x44247dcc,0x7bcc06b9,0x8ca03874,0xbcf801d3}},	//   pyo_, yucu, _क्लो, nlét, 
   {{0xfdac0729,0xb1109f22,0x44240014,0x7d1c022e}},	//   _কমেড, рмыш, qyo_, _roqs, 
   {{0xbcf85725,0x6d45a6e0,0x81e800cc,0xe2341bf4}},	//   hlét, _amia, মিব_, _مکعب, 
   {{0xb8780241,0x7bcda6e1,0x27240267,0x00000000}},	//   _abíl, wucu, _höns_, --, 
   {{0xdb0c000f,0x7bcda6e2,0x7e68017a,0x7d1c2a89}},	//   _twaë, tucu, _vyfp, _qoqs, 
   {{0x2724007c,0xcfe000cc,0x3134010f,0x2fd47aaf}},	//   _jöns_, বিউন, _בראך_, _لوند_, 
   {{0x6d45a6e3,0xbcf800d8,0xdb1c03b2,0xde580153}},	//   _emia, elét, nusø, _палі_, 
   {{0x7bcda6e4,0xbcf81c9b,0x8f740a4a,0xdef401af}},	//   sucu, flét, _суці, _апһы, 
   {{0x26d8037e,0xa954109a,0xbcf8136e,0x00000000}},	//   _acro_, аксі, glét, --, 
   {{0x26d801ee,0x98741679,0x02d00490,0x7ac40798}},	// [2d8d0] _bcro_, улац, _सांभ, _исне, 
   {{0x6d44006d,0xbcf801c7,0xdb1c0162,0xdcf800de}},	//   _zmia, rléu, jusø, _tuvē, 
   {{0x58d41cd6,0xe7840138,0xbb70021f,0x2724007c}},	//   _йонт, руто, _مۇڭع, _rönt_, 
   {{0x7ae0002d,0x630401b9,0x272402d2,0x00000000}},	//   _űnth, یونل, _böns_, --, 
   {{0xfbdc0120,0xbcf806af,0x06b00154,0x248c0023}},	//   ntê_, llés, _চারি, _ዕዱማት_, 
   {{0xdb1c03b2,0xe37400cf,0x00000000,0x00000000}},	//   gusø, алчы, --, --, 
   {{0xb87801e7,0x83140137,0x16340024,0x00000000}},	//   _mbím, اقىر_, _севя, --, 
   {{0xe1f0036b,0xf8bc0248,0xdb1c00e4,0x999000e5}},	//   تسه_, _ilés_, rusù, nyző_, 
   {{0x545505ec,0x6d4403a2,0x52140220,0xf8bc02d2}},	//   _сват, _rmia, _әдет, _hlés_, 
   {{0x6d4410b3,0xa3e800c5,0xc6b000cc,0xcef400d8}},	//   _smia, _बहत_, _চাৱচ, учињ, 
   {{0x0d85a6e5,0x06b40150,0x00000000,0x00000000}},	//   ллон, _ﺸﺩﻴﺩ, --, --, 
   {{0xb8780241,0xcd34158b,0xa1340ed8,0xc198010f}},	//   _abím, اردب, _پرمش, _טשעי, 
   {{0x0b580b87,0xbcf80c6a,0x1fb800db,0x00000000}},	//   ервы_, poén, _алчы_, --, 
   {{0xbea0020a,0x8cd43c74,0x00000000,0x00000000}},	//   _лашк, _भावो, --, --, 
   {{0xbcf80228,0x69d40574,0x06b009bd,0x30bc08b0}},	//   glés, बंधी, _চালি, ﻠﮕﻪﻧ, 
   {{0x6d45a6e6,0x999000e5,0x00000000,0x00000000}},	//   _umia, gyző_, --, --, 
   {{0x7d7827af,0x07a41fdf,0x2fdda6e7,0x480400c0}},	// [2d8e0] _אנקו, уазн, ntug_, ыпав, 
   {{0xf8bd19aa,0x2fdc0de2,0xdd98008e,0x69d40c22}},	//   _blés_, itug_, _яшә_, बंदी, 
   {{0xf8bda6e8,0x26d8003a,0xbcf8a09e,0x9a940354}},	//   _clés_, _vcro_, clés, _тăхл, 
   {{0x44f852c8,0x7d00013f,0xbcf9a6e9,0x00000000}},	//   عراج_, _ɔnso, llér, --, 
   {{0x68e5a6ea,0x290090d4,0xe3b802dd,0x31141db2}},	//   mfid, mdia_, тұз_, थानः_, 
   {{0x2901a6eb,0x27e1a6ec,0x5ee8015b,0x2ca00139}},	//   ldia_, mtin_, _কোনও_, _lfid_, 
   {{0x27e1a6ed,0x41e40597,0xf1a1a6ee,0x69d803cd}},	//   ltin_, استف, брын, _åved, 
   {{0x27e1a6ef,0x68e5a6f0,0xe37400fb,0xe38c0023}},	//   otin_, nfid, ылһы, _ንደምበ_, 
   {{0x2901a6f1,0x2fdda6f2,0xf8bc020c,0x68e4022f}},	//   idia_, gtug_, _klér_, ifid, 
   {{0x27e1a6f3,0x2ca00175,0x68e4007b,0x398801e1}},	//   itin_, _afid_, hfid, _kòsì_, 
   {{0x27e01368,0x11f80050,0x5d542b44,0xde580a4a}},	//   htin_, _لولک_, икот, тані_, 
   {{0x27e1a6f4,0xa3e805f9,0x2ca00175,0x29004168}},	//   ktin_, _बहा_, _cfid_, jdia_, 
   {{0x27e1a6f5,0x2ca1a6f6,0xcbb457aa,0x2901a6f7}},	//   jtin_, _dfid_, ағыш_, ddia_, 
   {{0x68e5a6f8,0x2901a6f9,0xcfe000fe,0x27e001f4}},	//   efid, edia_, বিখন, dtin_, 
   {{0x68e4a35c,0x13d0b500,0x27e00493,0x3f8c009f}},	//   ffid, _सम्भ, etin_, _iifu_, 
   {{0x27e1a6fa,0x29000228,0x49a40184,0xbcf801ed}},	//   ftin_, gdia_, рырғ, rlés, 
   {{0x3f8c0083,0x4bc005f5,0xb8dc01ad,0x27e00413}},	// [2d8f0] _kifu_, _мөрг, _ीय_, gtin_, 
   {{0xaadc0574,0xde4802d3,0xe785a6fb,0x68e5a6fc}},	//   _बायक, _ብመንግ, бухо, afid, 
   {{0x27e1a6fd,0x7ae0000f,0xadc00022,0x0595a6fe}},	//   atin_, _űntw, _osẽh, لانگ, 
   {{0x3f8c009a,0x68e4007b,0x2fdc002e,0x27e1a6ff}},	//   _lifu_, cfid, ytug_, btin_, 
   {{0x56940510,0x69d800fd,0x1bf4012d,0x00000000}},	//   _вагт, _äver, इबिल_, --, 
   {{0x798c0223,0x7994487e,0x39880241,0x3f8c143a}},	//   _hicw, _kuxw, _fòsì_, _nifu_, 
   {{0x798c0337,0xb2b00116,0xbcf85fe6,0x00000000}},	//   _kicw, _һәйъ, toél, --, 
   {{0x40900131,0x7bdda700,0x2e380241,0xe5340816}},	//   يلىر, _oqqu, _láfé_, _лесь, 
   {{0x79940472,0x3f8c01c8,0xc4240014,0x224001e4}},	//   _luxw, _bifu_, _پِلی, ĝika_, 
   {{0xb8780241,0x798c0921,0x2fdca1e7,0xfc3c011f}},	//   _abík, _licw, rtug_, mbíh_, 
   {{0xd251a701,0x7bdc0af5,0x98a80034,0x50f40801}},	//   _بنا_, _aqqu, chać_, _взет, 
   {{0xd0100491,0x00000000,0x00000000,0x00000000}},	//   _ولا_, --, --, --, 
   {{0xf1d0052f,0x2e380241,0x29000240,0x68e4022e}},	//   _төҙө, _báfé_, vdia_, vfid, 
   {{0xa3e819e5,0x3f8d5b72,0x95140327,0x00000000}},	//   _बहस_, _gifu_, _ཊོའི_, --, 
   {{0xc3300302,0x798c8875,0x7bdc0af5,0xdb140209}},	//   חום_, _bicw, _eqqu, _ýaýr, 
   {{0x27e1a702,0x3f8c04ba,0x68e5a703,0x63a40356}},	//   ttin_, _zifu_, ufid, ţini, 
   {{0x3f8c014b,0x0888223c,0x68e46b41,0xcdc402dd}},	// [2d900] _yifu_, тбай_, rfid, _саққ, 
   {{0x4a45a704,0xbcf801ed,0x00000000,0x00000000}},	//   _внов, llép, --, --, 
   {{0x48e4d7b1,0x68e5a705,0x44a535dd,0x6abda706}},	//   _конв, pfid, لماق, marf, 
   {{0x27e1a707,0xc565a708,0x6abda709,0x84e41ed2}},	//   ptin_, шкек, larf, родж, 
   {{0x27e1a70a,0x39880241,0x257c0413,0x00000000}},	//   qtin_, _wòsì_, víld_, --, 
   {{0x6abda70b,0x12f40075,0x798da70c,0xa1940351}},	//   narf, متىھ, _zicw, бакч, 
   {{0x798c2dab,0x3f8c07a9,0x6ecc00bc,0xa2481291}},	//   _yicw, _rifu_, _दाजु, دیال_, 
   {{0x3f8c0ac5,0x6abda70d,0xbcf8012c,0x96c801d9}},	//   _sifu_, harf, jlép, _لبہِ_, 
   {{0x81d400fe,0xdef80135,0x6fb4004e,0x00000000}},	//   িবই_, loċi_, агыр_, --, 
   {{0x80a40807,0x6abc0008,0x157c0131,0x20040010}},	//   _ट्रे, jarf, ﺭﯨﺠﯩ, rvmi_, 
   {{0x6abda70e,0xdb1c2268,0x00000000,0x00000000}},	//   darf, arsû, --, --, 
   {{0x4085a70f,0x257c013a,0x00000000,0x00000000}},	//   _кулб, bíle_, --, --, 
   {{0x6abc0cfd,0x69c9a710,0x3f8c0327,0x00000000}},	//   farf, áden, _tifu_, --, 
   {{0x6abda711,0x798c2d2f,0x98a84b16,0x248c001f}},	//   garf, _sicw, rkač_, ንስሳት_, 
   {{0x98a80010,0xdb1c0254,0x00000000,0x00000000}},	//   skač_, musü, --, --, 
   {{0x6934eec0,0xdb1da712,0xe8951e13,0x6abc0194}},	//   онсу, issé, жать, aarf, 
   {{0x7bdc0d04,0x6abc0ba7,0x00000000,0x00000000}},	// [2d910] _uqqu, barf, --, --, 
   {{0x798c07a8,0x29f80421,0x6abc0fac,0x3ce007b6}},	//   _wicw, _fōa_, carf, ट्रे_, 
   {{0x3689a713,0xbcf8020c,0x98a8031c,0xa9c8004e}},	//   тсан_, joék, jnaħ_, _кыяз_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfc3c0316,0x98a80135,0xdb1c000d,0xe858014b}},	//   nzí_, enaħ_, kusü, _ваяш_, 
   {{0xf364faf8,0x257c0122,0xfd1c026c,0xa3e8202e}},	//   штен, víle_, hjì_, _बहर_, 
   {{0x7160005e,0xdb1c0254,0xb878013a,0x00000000}},	//   يپتە, dusü, _sbíh, --, 
   {{0x257c00ae,0x6abc0205,0xa4d401ca,0x00000000}},	//   tíle_, zarf, _мосі, --, 
   {{0x0eb9a714,0x6abc06ea,0xc4d002e4,0x835001d9}},	//   луны_, yarf, _מגן_, _کھنا, 
   {{0xfc3da715,0x92e403d4,0xaadc00cd,0xa2940153}},	//   dzí_, _বোৰ_, _बाधक, _дафі, 
   {{0x6abce0e9,0xd36c215c,0x31a00205,0x00000000}},	//   varf, _قۇچ_, _bıze_, --, 
   {{0x3ce0069f,0x6abc002d,0xfaa00107,0x00000000}},	//   ट्ले_, warf, ҷаро, --, 
   {{0x6abda716,0xdb1c1427,0xb87801ef,0xc0d40023}},	//   tarf, jusó, _ubíh, ያኦም_, 
   {{0xfaa1a717,0x81e8015b,0xcd340133,0xc0b80092}},	//   заро, মির_, _گرتب, _ጳጉሜ_, 
   {{0xbb41a6e5,0x6abda718,0x7bcc0072,0x29040174}},	//   черк, rarf, arcu, _ómak_, 
   {{0x6abc0eda,0xa3e86c95,0x00000000,0x00000000}},	//   sarf, _बहल_, --, --, 
   {{0x6abda719,0x2d800521,0x06e82692,0xc695a71a}},	// [2d920] parf, _ihie_, лмак_, مشاع, 
   {{0x6abc0680,0xdb1c004a,0x8b640fb4,0x00000000}},	//   qarf, yssé, _داعم, --, 
   {{0xd0f80cb4,0x23485d35,0x2d80002d,0x8a05a71b}},	//   ्याण_, یستی_, _khie_, _узне, 
   {{0xc4842e91,0xbcf80156,0xdb1c012d,0xdef8031c}},	//   блек, goéh, busó, roċi_, 
   {{0x4430004d,0x98a80327,0x24184130,0xc79401af}},	//   áy_, wnaħ_, ролы_, _ырны, 
   {{0x2d801368,0x1168088e,0x06b0009e,0x00000000}},	//   _lhie_, یلوی_, _চাকি, --, 
   {{0xdb1da71c,0x2bd80882,0xbcf8003e,0x55c50924}},	//   ussé, भूता, boéh, _марғ, 
   {{0xf99006a9,0x2d800051,0x00000000,0x00000000}},	//   הרה_, _nhie_, --, --, 
   {{0x30104f3f,0xa3bc00c5,0x0324004e,0xdb1c0037}},	//   здыр, _आबि_, _лдан, tusü, 
   {{0xbcf8003e,0x31a003e0,0x00000000,0x00000000}},	//   poék, _sıze_, --, --, 
   {{0x69c9a71d,0x00c80835,0xaf3000ec,0xdb1c0254}},	//   ádel, _блек_, ثريت, rusü, 
   {{0x63a4084c,0x2d818cd0,0x28a80037,0xa3bc01f9}},	//   ţinu, _chie_, _छ्लि, _आबा_, 
   {{0x2d81a71e,0xbc48998c,0xbe88013d,0x7bc000ef}},	//   _dhie_, учне_, _өске_, _ānus, 
   {{0xdce803ee,0x59b40032,0xfc3c00bc,0x7bcc00a3}},	//   ılıy, ҙөүс, rzí_, rrcu, 
   {{0x3ebda71f,0x7ae0000f,0xda34023a,0xa3bc000d}},	//   matt_, _űnts, цевы, _आबऽ_, 
   {{0x3ebda720,0x57b43529,0x2d810b3a,0x996c00ef}},	//   latt_, жбат, _ghie_, _bēšs_, 
   {{0x6c840137,0xec6800c0,0x00000000,0x00000000}},	// [2d930] _ىلىم, _грэк_, --, --, 
   {{0xec38025f,0x3ebcf31c,0x1cf000b4,0x613c0008}},	//   _לאחר_, natt_, _ọjọọ_, _héld, 
   {{0x7c2c24c2,0xdcf80055,0x00000000,0x00000000}},	//   lycr, _nuvī, --, --, 
   {{0x3ebc007c,0x43e400d1,0xe4c80014,0x00000000}},	//   hatt_, ﺎﻧﯩﺪ, ٕبون_, --, 
   {{0x3ebda721,0xc0dc00b7,0x5ed0015b,0x7c2c514c}},	//   katt_, ናንስ_, ত্যে, nycr, 
   {{0x1ca80c99,0x56940107,0x97341e4b,0x3ebc03b2}},	//   _བཅའ_, _фавт, _بکرا, jatt_, 
   {{0x3ebda722,0xaadc011a,0x00000000,0x00000000}},	//   datt_, אחור, --, --, 
   {{0x81e809bd,0xdb0c0254,0x00000000,0x00000000}},	//   মিং_, _avaü, --, --, 
   {{0x3ebc0e14,0x2d80003e,0x49200023,0x00000000}},	//   fatt_, _rhie_, _ተጻባእ, --, 
   {{0x3ebda723,0x671c06e3,0x8e74036b,0x78bc0455}},	//   gatt_, नायक_, жумч, haqv, 
   {{0x52544439,0x2d840118,0xba080154,0x00000000}},	//   _بناء, ůjem_, রহুড_, --, 
   {{0x3ebc020c,0x69c80077,0xcc880139,0x85800116}},	//   aatt_, ádem, ибне_, ﺭﯨﺪﺍ_, 
   {{0x3ebc0445,0xae142172,0x78bc0455,0x0c780b83}},	//   batt_, _گذشت, daqv, рсны_, 
   {{0x3ebc23be,0x5ed0015b,0x1f640150,0x00000000}},	//   catt_, ত্বে, _екім, --, 
   {{0x2d8002a4,0x39480204,0x6f01a724,0x9a186f9f}},	//   _thie_, _bmcs_, _ianc, бюту_, 
   {{0x6f01947b,0x1ca8038f,0x6a800241,0x2d8002e3}},	//   _hanc, _བཅར_, _aáfí, _uhie_, 
   {{0x6f01a725,0xa8a400db,0xc724447e,0x872400f3}},	// [2d940] _kanc, _ۉلدۉ, одай, омаж, 
   {{0x6f01a726,0x157c2d40,0x257c00d7,0x00000000}},	//   _janc, ﺭﯨﺸﯩ, díla_, --, 
   {{0x6a800241,0x613da727,0xc8b4007b,0x00000000}},	//   _dáfí, _héle, _وصحب, --, 
   {{0x2c59317b,0x613c585c,0x7a78011a,0x3ebc0327}},	//   ọdu_, _kéle, _כריס, zatt_, 
   {{0x1ca8031c,0x6f000311,0x3ebc003b,0xdcf8002b}},	//   _བཅལ_, _oanc, yatt_, _suvī, 
   {{0x613da728,0x3ebc0bc9,0x6f0191de,0x130001f0}},	//   _méle, xatt_, _nanc, нҷум, 
   {{0xf1f40acb,0x613c1a46,0x0edc000d,0x00000000}},	//   قعيت_, _léle, _मा़ड, --, 
   {{0x11f40075,0x6f01a729,0x8cd4033f,0x257c08a5}},	//   ستىگ, _aanc, _भागो, bíla_, 
   {{0x3ebda72a,0x69c80306,0xbb400116,0x00000000}},	//   tatt_, ádej, ﻛﯜﻡ_, --, 
   {{0x6f00fb7f,0x290c016b,0xbe888cff,0x829000cf}},	//   _canc, _ɔdaa_, исне_, _قۇشچ, 
   {{0x3ebda72b,0x613c00dd,0x1df800c9,0x6f01a72c}},	//   ratt_, _péld, щены_, _danc, 
   {{0x3ebcb59f,0x6f01a72d,0x7c2c0857,0x613c00e5}},	//   satt_, _eanc, tycr, _béle, 
   {{0x60c1a72e,0x3ebda72f,0xdb0c011f,0x6f002517}},	//   mamm, patt_, _awaá, _fanc, 
   {{0x6f01a730,0x60c1a731,0x39480b0e,0x613da732}},	//   _ganc, lamm, _smcs_, _déle, 
   {{0x31a003ee,0xb925a733,0xaadc9725,0x78bc014f}},	//   _kıza_, офай, _बारक, taqv, 
   {{0x60c1a734,0x6f000c09,0x613c01ed,0x7c2c03ac}},	//   namm, _zanc, _féle, pycr, 
   {{0x6f01a735,0xdb1c0784,0x69d8143a,0xfc3c01ef}},	// [2d950] _yanc, susñ, _åven, gbít_, 
   {{0xb8780077,0x6f01a736,0x66f401c6,0xdef80327}},	//   _acíc, _xanc, мпуу, neċ_, 
   {{0x39480175,0x8af8011a,0x00000000,0x00000000}},	//   _tmcs_, _ההתי, --, --, 
   {{0x60c1a737,0x78bc0357,0x7844009d,0x39480210}},	//   jamm, qaqv, _дэгж, _umcs_, 
   {{0x183404ac,0x60c1a738,0xdcec0327,0xb4b84fed}},	//   _זאָל_, damm, _akaċ, _आजी_, 
   {{0x257c01f1,0x316c0010,0x5ed00154,0x00000000}},	//   ríla_, _skgz_, ত্তে, --, 
   {{0x58f80489,0x60c127a1,0x6f01a739,0xdef00f7c}},	//   _ཕྲོས_, famm, _ranc, ፍናን_, 
   {{0x60c1a73a,0x91801e87,0x6f01a73b,0xd024bb65}},	//   gamm, رۇشۇ, _sanc, змий, 
   {{0x6f000e47,0xaadc1276,0xa3e8000d,0x00000000}},	//   _panc, _बालक, _बहए_, --, 
   {{0x6f01a73c,0x6ecc013f,0xb4b8033d,0x60c00140}},	//   _qanc, _kɔbɔ, _आजु_, aamm, 
   {{0x613da73d,0x60c1a73e,0x671c2b3d,0x75389732}},	//   _séle, bamm, नातक_, _kluz, 
   {{0x6f01a73f,0x60c0102c,0xc2780375,0x7f58003a}},	//   _wanc, camm, _הרעי, antq, 
   {{0x6f0145f5,0xdb0c0588,0x753801f7,0x58f80327}},	//   _tanc, _avañ, _mluz, _ཕྲེས_, 
   {{0x613c066d,0x6f0002d0,0x7d1800e2,0xaadc0073}},	//   _véle, _uanc, ķusa, _बाळक, 
   {{0xaca4063f,0x7539a740,0xb4b80406,0xcfbc0eac}},	//   _ahụw, _oluz, _आजू_, _আমিন, 
   {{0xc7b001d9,0x613da741,0x07a5a742,0xb6380092}},	//   فّر_, _téle, заан, _በሚያቀ, 
   {{0xf8bc0005,0xd7f802bf,0x5ed402dd,0xdb0c002b}},	// [2d960] _toén_, жує_, _ءتۇز, _evañ, 
   {{0x7539a743,0x1ca80867,0xb8780241,0x8699a744}},	//   _aluz, _བཅོ_, _abís, стат_, 
   {{0x60c1a745,0x272407c5,0x7539a746,0xdb0c0174}},	//   yamm, _könz_, _bluz, _ivað, 
   {{0xdecc0201,0xdb0c008c,0xaadc0316,0xc0f002d3}},	//   _ቡድን_, _hvað, _बाँक, ፍታሕ_, 
   {{0x60c15bd9,0x31a005d1,0x9f64002e,0xdb0c08a5}},	//   vamm, _rıza_, étël_, _kvað, 
   {{0xf4843737,0xfc3c2b76,0x7538010f,0x77755eed}},	//   سانی, ncía_, _eluz, clxx, 
   {{0x60c1a747,0x290c016b,0x0578007b,0x00000000}},	//   tamm, _ɔdan_, _همسة_, --, 
   {{0xf8bc0098,0x31a00213,0x753954cd,0x8c200154}},	//   _noél_, _qıza_, _gluz, _পেছন_, 
   {{0xe3a401d5,0xaadc0d0d,0xef380023,0x00000000}},	//   _آشری, _बांक, _ስለዝግ, --, 
   {{0x60c1a748,0xdb1da749,0x92c400b5,0x7f58003a}},	//   samm, tssí, syをo, untq, 
   {{0x613c08a5,0xbcf800e5,0x1cd401a9,0x00000000}},	//   _vélb, nnég, монў, --, 
   {{0xf8bc0098,0x60c1a74a,0x613c00bc,0x00000000}},	//   _coél_, qamm, _délc, --, 
   {{0xdd904732,0x272405d5,0xdb1c0194,0xfb840b7e}},	//   _یوت_, _dönz_, vssâ, зывн, 
   {{0x6ff80302,0x7a3401b8,0xdb1c0254,0xb87801ef}},	//   _להדפ, jütö, husö, _obír, 
   {{0x69d84606,0xdb1da74b,0x38c86518,0xaa64004e}},	//   _åvel, kusö, йуан_, еттк, 
   {{0xb4b80ce0,0xed5800ea,0x00000000,0x00000000}},	//   _आजे_, _ној_, --, --, 
   {{0xb87801e1,0xf77c0724,0xfc3c0ba1,0x98744140}},	// [2d970] _abír, _aqça_, rbís_, флац, 
   {{0x6fcc0490,0xaf38001f,0xc5f40011,0x5fd400bc}},	//   _दिसू, _ስለሚገ, ঘটনা_, _दिनल, 
   {{0xdb0c0139,0x75386fca,0xdce803b9,0xdb1c02d2}},	//   _awaç, _pluz, lqdı, fusö, 
   {{0xdcec0384,0xdb1c69a9,0x00000000,0x00000000}},	//   _okač, hrsü, --, --, 
   {{0x6ecc0134,0x7a340790,0x24f82401,0x6d8c010e}},	//   _wɔbɔ, bütö, янцы_, _ỳaka, 
   {{0xe3b1a74c,0x00000000,0x00000000,0x00000000}},	//   ارن_, --, --, --, 
   {{0xd01416f0,0xf675a74d,0xb87801e1,0x3544030d}},	//   तम्भ_, _راسخ, _gbír, _ехав, 
   {{0x3d040034,0xdecc001f,0x7538cbfc,0x257c0332}},	//   षयों_, _ቡድኑ_, _uluz, níll_, 
   {{0xdb1da74e,0xd43400aa,0xf8bc003e,0xa3d41d39}},	//   lusõ, _غبرګ, _roél_, _потч, 
   {{0x1ca80ed9,0x0dc9a74f,0xbcf8020c,0xf8bc01e1}},	//   _བཅུ_, олой_, mléy, _leé_, 
   {{0x3d0c000d,0xdb1c000d,0xc22000ec,0x00000000}},	//   _तोहे_, nusõ, _لکيو, --, 
   {{0xb4b800c5,0xf4800023,0xdb0c08a5,0x00000000}},	//   _आजो_, _ይሓስብ_, _svað, --, 
   {{0xb4b800bc,0x00000000,0x00000000,0x00000000}},	//   _आजै_, --, --, --, 
   {{0x9f8400d6,0x257c00d2,0xdb1c000d,0xbd0000e5}},	//   _згід, yílo_, kusõ, áért, 
   {{0xfc3c9ca8,0x613c4056,0x272405d5,0xf8bc003e}},	//   rcía_, _héla, _tönz_, _toél_, 
   {{0x613da750,0xdb1c00c5,0x0edc0037,0x645c0055}},	//   _kéla, dusõ, _माँड, _śrim, 
   {{0xb878012c,0x8c440a15,0x7a3401b8,0x07a426b1}},	// [2d980] _sbír, _цепе, tütö, фазн, 
   {{0x613da751,0xdb1c00d8,0x7f88010f,0xf7c800d1}},	//   _méla, fusõ, ַנײַ, _ﺗﻪﻗﺪ, 
   {{0x613c8075,0xfc3c215a,0xbcf80077,0xdb1c8949}},	//   _léla, ncín_, poét, tusö, 
   {{0x87b800ee,0xfc3c01e7,0x00000000,0x00000000}},	//   _мугт_, icín_, --, --, 
   {{0x69dda752,0x0edc0574,0x613da753,0x58f8031c}},	//   lure, _मांड, _néla, _ཕྲིས_, 
   {{0x69dc05c7,0xbcf80129,0xfc3c02f0,0x7bd801ab}},	//   oure, mnée, kcín_, àuui, 
   {{0x41e41cb8,0xaadc01f9,0xb878013a,0x20dc01f9}},	//   філа, _बाईक, _ubír, _याआध, 
   {{0x613c3847,0xbcf80118,0x234800f2,0x00000000}},	//   _béla, sléz, _کسری_, --, 
   {{0xbcf82047,0x69dda754,0x613c7dec,0x9ee41e4a}},	//   nnée, hure, _céla, ىزدۇ, 
   {{0x613c20ef,0xc32c0075,0xb381a755,0xb46000c7}},	//   _déla, _خەت_, _алул, _ркул, 
   {{0x63a022a9,0xbf100184,0xc0c80261,0x73300e76}},	//   _humn, еүҙә, _дуле_, _جىلا, 
   {{0x613c00fc,0x63a1a756,0x69dda757,0xa13c0171}},	//   _féla, _kumn, dure, _buķe, 
   {{0x613c06af,0x69dc06af,0xf8bc0241,0x00000000}},	//   _géla, eure, _reé_, --, 
   {{0x69dda758,0x63a00099,0xf8bc0241,0x00000000}},	//   fure, _mumn, _seé_, --, 
   {{0x69dda759,0x63a1a75a,0xbcf80036,0xdb1c1427}},	//   gure, _lumn, enée, gssá, 
   {{0x394c068c,0x00000000,0x00000000,0x00000000}},	//   ògs_, --, --, --, 
   {{0x63a0060a,0xbcf87c92,0x613c00e8,0xf6e408da}},	// [2d990] _numn, gnée, _xéla, дцен, 
   {{0x5ed000bd,0xdb1c00c5,0x67d40815,0x00000000}},	//   ত্রে, tusõ, тофу, --, 
   {{0x69dd2f37,0x63a0022e,0xd4f41d37,0x00000000}},	//   cure, _aumn, еялы, --, 
   {{0x63a00921,0x00000000,0x00000000,0x00000000}},	//   _bumn, --, --, --, 
   {{0x33701086,0x63a03c57,0x69c80005,0x0594feab}},	//   вҳар, _cumn, ádev, رامگ, 
   {{0x63a00262,0x613c8616,0xb878003a,0x290401a8}},	//   _dumn, _réla, _ubíq, _ómar_, 
   {{0x613c00f2,0x10a4bb65,0xee840150,0x00000000}},	//   _séla, нийн, _ﺭﺍﻫﻥ_, --, 
   {{0x613c0129,0xe18801f7,0x00000000,0x00000000}},	//   _péla, وئين_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x613c0008,0x69dda75b,0x00000000,0x00000000}},	//   _véla, yure, --, --, 
   {{0x62040050,0x945c00a2,0x69dda75c,0x63a0022e}},	//   _لولٕ, _deńe, xure, _zumn, 
   {{0x69dda75d,0x4638008f,0xa13c00de,0xdb1c01bf}},	//   vure, פערע, _puķe, nssæ, 
   {{0xbf1003e6,0x69dc05db,0x4c34009d,0x3d0c0073}},	//   _ڕووب, wure, хэнт, _तोळे_, 
   {{0x69dda75e,0x945c00a2,0x69d803cd,0x00000000}},	//   ture, _geńe, _åvek, --, 
   {{0x613c0de2,0xdb1c01bf,0x00000000,0x00000000}},	//   _méln, kssæ, --, --, 
   {{0xeaa001e1,0xdb1c01bf,0x00000000,0x00000000}},	//   _biṣu_, jssæ, --, --, 
   {{0x69dda75e,0xddd800f3,0x6c6400c7,0xdb1c005c}},	// [2d9a0] sure, _izvš, _шеиҕ, dssæ, 
   {{0xbcf9a75f,0x98c4005f,0xeaa00055,0x44200327}},	//   rnée, ētās_, _diṣu_, _ħk_, 
   {{0x63a008ad,0x69dc011f,0x00000000,0x00000000}},	//   _sumn, qure, --, --, 
   {{0x80bc09d9,0x63a1a760,0xeaa00241,0xb87801e7}},	//   _एजें, _pumn, _fiṣu_, _gcío, 
   {{0x81e800cc,0x00000000,0x00000000,0x00000000}},	//   মিছ_, --, --, --, 
   {{0xae1c06b1,0x63a0047e,0xa2780276,0x98a8033f}},	//   यमान_, _vumn, мблу_, tkać_, 
   {{0xe3b09beb,0xf8bc0098,0x63a00117,0xf7740375}},	//   ارچ_, _boéh_, _wumn, _נעלי_, 
   {{0x63a00784,0xd25000e5,0x00000000,0x00000000}},	//   _tumn, ؤنٹ_, --, --, 
   {{0x63a0208d,0xf8bc003e,0x98a8033f,0x613c01d3}},	//   _uumn, _soék_, skać_, _féln, 
   {{0x1ca8025c,0xf8bc00d5,0x7e44b190,0xf4840101}},	//   _བཅང_, _poék_, ехме, _ساقی, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbfa86171,0x81b400eb,0x00000000,0x00000000}},	//   _етке_, _জিপ_, --, --, 
   {{0x613da761,0x7b640f06,0x00000000,0x00000000}},	//   _hélo, етве, --, --, 
   {{0x613c7dec,0x945c0165,0x00000000,0x00000000}},	//   _kélo, _heńc, --, --, 
   {{0xaf0415f2,0x387c03ef,0xeaa00ca8,0x00000000}},	//   _سقيم_, _šur_, _ńṣe_, --, 
   {{0x613da762,0xc0500240,0x945c0210,0x00000000}},	//   _mélo, _ክትሰግ, _jeńc, --, 
   {{0x671c0d5f,0x67d41cb5,0x9c740451,0x1c0401d5}},	// [2d9b0] नांक_, лоту, _ڳنڍڻ, _рўйҳ, 
   {{0x81b4045e,0x613c020c,0x3689a763,0x5a35a764}},	//   _জিন_, _oélo, псен_, _анот, 
   {{0xaee00055,0x00000000,0x00000000,0x00000000}},	//   _asṛk, --, --, --, 
   {{0x613c0098,0xb4c80490,0x7664002b,0x00000000}},	//   _séln, लणे_, _āpyā, --, 
   {{0xfc3c16d9,0xdb1c005c,0x00000000,0x00000000}},	//   kcím_, rssæ, --, --, 
   {{0x613c020c,0xba180113,0xf8bc003e,0xd78801ed}},	//   _bélo, _wa鯵u, _soéh_, _آنسو_, 
   {{0x613c01ed,0xc240399f,0xdb1c002f,0x00000000}},	//   _célo, иншк, mssä, --, 
   {{0x613da765,0x6595a766,0xdb1c007c,0x00000000}},	//   _délo, _басу, lssä, --, 
   {{0x63b40122,0x00bc02dd,0x00000000,0x00000000}},	//   čený, _ﺭﻩﺗﺘ, --, --, 
   {{0xddd802d5,0xdb1d2686,0x21cc0118,0x645400f3}},	//   _gyvū, nssä, běh_, _свуђ, 
   {{0x613ce9f0,0xe2c81e24,0xdb1d653c,0x00000000}},	//   _gélo, _سونو_, issä, --, 
   {{0x613c002e,0x20540220,0xfe6c04da,0x0edc0073}},	//   _jéll, _өтір, ڭگۇ_, _माकड, 
   {{0xd009a767,0xaee000cd,0xdb1c007c,0x00000000}},	//   _целе_, _haṭh, kssä, --, 
   {{0xd5d0069f,0xfc000e92,0xaee000cd,0x0f7800df}},	//   _हिंज, јпро, _kaṭh, _קאַב, 
   {{0xaee0002b,0x2fdca6ec,0xdb1c01e3,0x63800051}},	//   _jaṭh, luug_, dssä, ữngc, 
   {{0xdb1c005b,0xaee00055,0x00000000,0x00000000}},	//   essä, _maṭh, --, --, 
   {{0x2fdc0009,0x2ca003e3,0x63a401e4,0x00000000}},	// [2d9c0] nuug_, _igid_, ƭini, --, 
   {{0x5fd40574,0x69c80077,0x7c28a547,0xdb1c01e3}},	//   _दिसल, ádes, _àgra, gssä, 
   {{0x257c043b,0xa3e40574,0xbcf82a78,0x614801e1}},	//   líli_, पून_, lnéa, _jèlù, 
   {{0xdee01ee0,0x613c01d3,0x75d002da,0x00000000}},	//   ናትና_, _céll, شيها, --, 
   {{0x2901a768,0x613da769,0xbcf8007b,0xfc3c02f0}},	//   meia_, _déll, nnéa, ycím_, 
   {{0x2900eaca,0x27e1a76a,0x68e5a76b,0x613da76c}},	//   leia_, muin_, lgid, _pélo, 
   {{0x27e04725,0x257c10e1,0x5fd4033d,0x72001b06}},	//   luin_, híli_, _दिहल, لووم, 
   {{0x2901a76d,0x613cdf44,0x2ca00066,0x2b58009a}},	//   neia_, _vélo, _ngid_, hirc_, 
   {{0x27e1a76e,0x03a446e0,0x1f748c2b,0x68e40083}},	//   nuin_, _ризо, ллия, igid, 
   {{0x2901a76f,0x2ca08d4a,0x2b58009f,0x613c0129}},	//   heia_, _agid_, jirc_, _télo, 
   {{0x27e1a770,0x2900123c,0x68e4017a,0x5fd40406}},	//   huin_, keia_, kgid, _दिवल, 
   {{0x27e1a771,0x8024036b,0x00000000,0x00000000}},	//   kuin_, _لرتم, --, --, 
   {{0x4425a772,0x2901a773,0x27e0020b,0x2ca0010a}},	//   nxo_, deia_, juin_, _dgid_, 
   {{0x4425a774,0x27e1a775,0x2ca003b2,0x68e5a776}},	//   ixo_, duin_, _egid_, egid, 
   {{0xf991a777,0x2901a778,0x58d4054a,0x629c02fb}},	//   لبر_, feia_, ловт, _úrod, 
   {{0x68e4102c,0x29004f77,0xbae0009e,0x6fbc0073}},	//   ggid, geia_, য়েঞ, लीवू, 
   {{0x27e1a779,0xdb1d3aa7,0xfbdc0120,0xeca800e1}},	// [2d9d0] guin_, tssä, quê_, _गलतफ, 
   {{0xa6cc00bd,0x29000093,0xbb4008b0,0x4424922f}},	//   র্ঘট, aeia_, ﻛﻜﻪ_, dxo_, 
   {{0x44254690,0x613c04cc,0x68e42430,0xaee000b8}},	//   exo_, _péll, bgid, _abṛh, 
   {{0x27e1a77a,0x290000d8,0x4424022e,0x00000000}},	//   buin_, ceia_, fxo_, --, 
   {{0x3eac00b5,0x4425a77b,0x78440139,0x7ae000e5}},	//   _offt_, gxo_, _рэнж, _önts, 
   {{0x8fd00831,0xe3b1a77c,0xaee000dc,0x00000000}},	//   ҡәлә, زره_, _paṭh, --, 
   {{0x442403d9,0x51f5a77d,0x6d880309,0x00000000}},	//   axo_, استر, nñac, --, 
   {{0x825c02d3,0xaca401f2,0x6aa0016b,0x44248186}},	//   _ቆጸራታ, raịj, ɛmfu, bxo_, 
   {{0x4f9400c7,0x00000000,0x00000000,0x00000000}},	//   лроу, --, --, --, 
   {{0x257c04bf,0x4814008f,0x4f24094d,0x6d880113}},	//   víli_, אַטן_, удоб, kñac, 
   {{0x2ca0030d,0x68e5a77e,0x60e801e6,0xa3e402ab}},	//   _pgid_, ygid, ärmö, पंथ_, 
   {{0x27e0079b,0x1015a77f,0x00000000,0x00000000}},	//   yuin_, _مبتد, --, --, 
   {{0x2901a780,0x7e68003a,0x68e5a781,0x2ee00014}},	//   veia_, _exfp, vgid, _نقشہ, 
   {{0x6adc045e,0x290018a6,0x317c005a,0x257ca56b}},	//   ম্নো, weia_, lluz_, ríli_, 
   {{0x2901a782,0x68e5a783,0x2b580332,0x442401a9}},	//   teia_, tgid, rirc_, zxo_, 
   {{0x27e1a784,0x2bdc0c2e,0x6b5406be,0x442401a9}},	//   tuin_, _बिपा, _mügə, yxo_, 
   {{0x6d45a785,0x44240429,0x317c01c4,0x3868045a}},	// [2d9e0] _ilia, xxo_, iluz_, _cxcr_, 
   {{0x27e1a786,0x613c01ed,0x68e5a787,0x2901a788}},	//   ruin_, _célj, sgid, seia_, 
   {{0x6d45a789,0x2901a78a,0x27e00649,0x5eb80154}},	//   _klia, peia_, suin_, _আযমে, 
   {{0x6d4406a3,0x44243bfd,0x27e01c06,0x3a8001d9}},	//   _jlia, txo_, puin_, _دُپہ, 
   {{0x27e1a78b,0x4425a78c,0x6d45a78d,0x6474041b}},	//   quin_, uxo_, _mlia, јглу, 
   {{0x4425a78e,0x69dda78f,0x6d44015d,0x2bdc00ce}},	//   rxo_, orre, _llia, _बिना, 
   {{0x6d45a790,0x69dc0784,0x325001c6,0x442401d5}},	//   _olia, nrre, йвшр, sxo_, 
   {{0x58f80135,0xa3e4000d,0x69dc26de,0x04c800ec}},	//   _ཕིབས_, पंद_, irre, _سوئي_, 
   {{0x69dda791,0x436801c6,0x442401a9,0x4464187f}},	//   hrre, _заан_, qxo_, _свав, 
   {{0x6d45a792,0x6d880309,0x69dc036e,0x00000000}},	//   _alia, yñac, krre, --, 
   {{0x6d443c60,0x3f800029,0x7a3800d7,0x00000000}},	//   _blia, ēku_, _mätú, --, 
   {{0x6d44cdfa,0x628800da,0x69dc0240,0x3eac0142}},	//   _clia, _izdo, drre, _wfft_, 
   {{0x6d4400a3,0x7d0da793,0xf8bc01f5,0x2fd465dc}},	//   _dlia, rdcs, _moét_, _موند_, 
   {{0x3eac05d5,0xf8bc004d,0xcf24d0cc,0x00000000}},	//   _ufft_, _loét_, _پرهي, --, 
   {{0x613c066d,0x6d45a794,0x7f580393,0xee040120}},	//   _nélk, _flia, mitq, _бејл_, 
   {{0xeab000dd,0x7d1c0399,0x62880122,0x7f58876a}},	//   قعہ_, _unqs, _mzdo, litq, 
   {{0x69dda795,0x2bdc2983,0xbcf80129,0x57d4009f}},	// [2d9f0] arre, _बिया, lnéo, شياء, 
   {{0x7f59a796,0x6288489c,0x6d440030,0x69dc0076}},	//   nitq, _ozdo, _zlia, brre, 
   {{0xe784034b,0x7bcd0836,0x6d44023a,0x6d880784}},	//   суто, lscu, _ylia, qñac, 
   {{0x7f580357,0x613c0316,0xf8bc0098,0x2bdc5f46}},	//   hitq, _délk, _coét_, _बिमा, 
   {{0x94240c9e,0x1ca8031c,0x00000000,0x00000000}},	//   рмле, _བཅན_, --, --, 
   {{0x7bcc003a,0x257c00bc,0x613c01d3,0x00000000}},	//   iscu, dílu_, _félk, --, 
   {{0x7f59a797,0x2bdc00bc,0xf77c03b9,0x7774025c}},	//   ditq, _बिभा, _nqçi_, moxx, 
   {{0xbcf80306,0x10a40116,0x7774025c,0x00000000}},	//   liéf, шиин, loxx, --, 
   {{0xcf45a798,0xbcf801ed,0x62888dfa,0x545400d8}},	//   иний, tnén, _ezdo, _тват, 
   {{0x6d45a799,0x7f59a79a,0x7774003d,0x317c0077}},	//   _slia, gitq, noxx, sluz_, 
   {{0x6d45a79b,0x7bcc4ff3,0xfc3c011f,0x201802b5}},	//   _plia, escu, mbíy_, āria_, 
   {{0x8d55a79c,0x717001ec,0x4ea40022,0x00000000}},	//   рточ, _دۇعا, ырҩа, --, 
   {{0x7f59a79d,0x77740429,0x7bcc0158,0x6d4400d7}},	//   bitq, koxx, gscu, _vlia, 
   {{0x7f580381,0x69dda79e,0x2bdc012d,0x8fe001ee}},	//   citq, trre, _बिठा, _ләүҙ, 
   {{0x69dda79f,0x4e7800c8,0x6d4400a3,0xcde401a9}},	//   urre, _באַצ, _tlia, _тойй, 
   {{0x6d45a7a0,0x09e407d6,0x7bcda7a1,0x00000000}},	//   _ulia, лоҳн, bscu, --, 
   {{0x46e89794,0xf99da7a2,0x06e901fc,0x4b8800db}},	// [2da00] кдан_, _diè_, кмак_, _ийин_, 
   {{0x684410c6,0xed5801ec,0xd36400ec,0x00000000}},	//   анға, _шоқ_, _رڇ_, --, 
   {{0x31a0008e,0x86980166,0x613c00e5,0x00000000}},	//   _kızu_, ттат_, _félh, --, 
   {{0x613c032e,0xb9000064,0x00000000,0x00000000}},	//   _vélk, _дзюк, --, --, 
   {{0x613c003e,0x8d7c013f,0x476000c7,0x7f580455}},	//   _wélk, ɑɑtɑ, _дҭаҳ, yitq, 
   {{0xdb0c0589,0x7f5816b8,0xb8780042,0xfc4808a5}},	//   _itaã, xitq, _acíw, _hríð_, 
   {{0x6684ef89,0x613da7a3,0xa2c40cef,0xf1a1a7a4}},	//   _ایال, _héli, _һәйк, орын, 
   {{0xb87801e1,0x613c0066,0x62883831,0x5fd4000d}},	//   _abíy, _kéli, _vzdo, _दिआल, 
   {{0xdb0c00a2,0xa49401b9,0x7f580393,0x7ae40200}},	//   _awaý, _ایشت, titq, ygjt, 
   {{0xd36c0efb,0x613da7a5,0x7f580393,0x3230013d}},	//   _كۇن_, _méli, uitq, схәс, 
   {{0x43940184,0x6288005f,0x2d6807f5,0x7f58e913}},	//   _баҡс, _uzdo, rđen_, ritq, 
   {{0xcf50044e,0x7f580381,0xde280116,0x1f6404da}},	//   _ንጥፈታ, sitq, вжүд_, ркүм, 
   {{0xcb2045bf,0x7bcc16b8,0x613c0077,0x7f580381}},	//   मांड_, uscu, _néli, pitq, 
   {{0x1ca80489,0xdb1cfcf4,0xbcf802fb,0x7bcda7a6}},	//   _བཅམ_, nssø, mném, rscu, 
   {{0xf99da7a7,0x7bcd6e0d,0xbcf802fb,0x38c402e8}},	//   _piè_, sscu, lném, ищав, 
   {{0x613d9197,0xf8bc003e,0x49a414d4,0x7bcc007c}},	//   _béli, _roés_, сырғ, pscu, 
   {{0xf09004ac,0x613da7a8,0x10900131,0xbcf802fb}},	// [2da10] ַנע_, _céli, ﻟﯩﺪﯨ, nném, 
   {{0x613c0231,0x2bdc084a,0x6d880309,0x945c00a2}},	//   _déli, _बिता, nñan, _deńl, 
   {{0xdb1c0b34,0xfc480162,0x98a807f5,0xa3e40073}},	//   dssø, _fríð_, ljač_, पूस_, 
   {{0x0595a7a9,0xfc4802d2,0x947400f2,0x66180162}},	//   مانگ, _gríð_, مگذا, ævka, 
   {{0x98a807f5,0x69d803d4,0xbcf80306,0x613c0129}},	//   njač_, _åver, jném, _géli, 
   {{0xbcf80122,0xdb1c03b2,0x8898011a,0x6a140066}},	//   dném, gssø, _תבשי, _ابیر, 
   {{0x613c00d8,0x91700051,0x00000000,0x00000000}},	//   _zéli, _hở_, --, --, 
   {{0x0ce039db,0xf8bc0098,0x41b000c6,0xe4d4007b}},	//   _বস্ত, _unéd_, أمير, _وتقب, 
   {{0x613c0077,0x5eb80154,0x2bdc00bc,0xbcf9a7aa}},	//   _xéli, _আয়ে, _बिधा, rnél, 
   {{0x98a83421,0x9170004d,0x234800f2,0x31a00139}},	//   djač_, _mở_, _پلمپ_, _sızu_, 
   {{0x71241291,0x00000000,0x00000000,0x00000000}},	//   _پرال, --, --, --, 
   {{0x2bdcdde9,0xbcf80306,0x62a800e2,0x31a0013d}},	//   _बिदा, bném, āsoš, _qızu_, 
   {{0xbcf80306,0xac980023,0x91700051,0xaf340633}},	//   cném, ቀመሎም_, _nở_, _پرشت, 
   {{0xd04800fd,0x613c7dec,0xdde80271,0xdb200241}},	//   ığız_, _réli, دریه_, _àtìm, 
   {{0x2fdc0430,0xc33008c3,0xc98400f1,0x00000000}},	//   lrug_, הום_, مشري, --, 
   {{0xccc40cca,0x798c02d0,0x613ca573,0x26cc01a6}},	//   _убий, _chcw, _péli, _ždo_, 
   {{0x0888e3cd,0x8cbc00dc,0xcdc48f62,0x2fdd13ee}},	// [2da20] убай_, _व्यो, _таққ, nrug_, 
   {{0x613da7ab,0x91700051,0x00000000,0x00000000}},	//   _véli, _dở_, --, --, 
   {{0xb6a001c0,0xbcf80306,0xfb34011a,0xda9400ec}},	//   чихл, zném, _האיש_, _واپڊ, 
   {{0x81b4009e,0x290400c7,0x613c01d3,0x00000000}},	//   _জিল_, _úma_, _téli, --, 
   {{0xbcf806af,0x10900131,0xb9780677,0x00000000}},	//   siég, ﻟﯩﺮﯨ, _תנכי, --, 
   {{0x49f41f21,0x27e1a7ac,0xbcf802fb,0xdce800bc}},	//   _བྱོལ_, mrin_, vném, _čočk, 
   {{0x26d9195c,0xbcf8004a,0xd39805a2,0xdb1c0158}},	//   _idro_, liée, рәтә_, rssø, 
   {{0x27e00726,0xbcf802fb,0x26d89584,0x2fdc017a}},	//   orin_, tném, _hdro_, frug_, 
   {{0x27e1a7ad,0xe8e00016,0x2fdda7ae,0x3ebc01a9}},	//   nrin_, _ngọt_, grug_, tbtt_, 
   {{0x9df803b7,0xbcf802fb,0x27e1a7af,0x00000000}},	//   анот_, rném, irin_, --, 
   {{0xa3e452f2,0xdd9584c9,0x27e1a7b0,0xbcf802fb}},	//   पूर_, жаны, hrin_, sném, 
   {{0x27e1a7b1,0x2fdda7b2,0x2600007d,0xdc9802bf}},	//   krin_, brug_, _रहनी_, ивні_, 
   {{0x409406d5,0x31780a1e,0x613c0036,0x26d8a010}},	//   _الشر, _גראמ, _sélw, _odro_, 
   {{0x27e1a7b3,0x26d9a7b4,0xbcf8004a,0xfbdc00d8}},	//   drin_, _ndro_, diée, rrê_, 
   {{0x27e1a7b5,0x9170004d,0xf9684316,0x00000000}},	//   erin_, _sở_, грай_, --, 
   {{0x26d9a7b6,0xbcf807ea,0xdd904a3b,0x98b9a7b7}},	//   _adro_, fiée, _توب_, рлат_, 
   {{0xe894034b,0xbcf806af,0x76a4007b,0x613c00e5}},	// [2da30] зать, giée, محاك, _félv, 
   {{0x6aa401ec,0x55c40124,0xd7940395,0x00000000}},	//   _ىشپە, жәаз, цизъ, --, 
   {{0x3689a7b8,0x6d680077,0x27e1a7b9,0x2924007b}},	//   усан_, _ásaí, arin_, ásaí_, 
   {{0x27e1a7ba,0x26d80115,0x2fdc01b9,0x1bec0210}},	//   brin_, _edro_, yrug_, _जमाल_, 
   {{0xbcf807ea,0xd34000e5,0x00000000,0x00000000}},	//   ciée, وہری, --, --, 
   {{0x70b000dc,0x613c0129,0xb5a4e4c1,0x2bdc007a}},	//   ीर्ल, _mélu, _грай, _बिसा, 
   {{0x63bc0219,0xbcf8002e,0x37a800cc,0x59e0000d}},	//   _črne, gnék, _ছবিৰ, _फिफर, 
   {{0x2fdc03fa,0xfc3c381a,0x5fd4858c,0x00000000}},	//   trug_, ncís_, _दिखल, --, 
   {{0xe81c534e,0xbcf80232,0x98a801a2,0x6595a7bb}},	//   निया_, mnéh, kiaľ_, _хату, 
   {{0xbcf80232,0xdb0c0428,0x289c00c8,0xb7b80022}},	//   lnéh, _owañ, ניזא, _erãg, 
   {{0x2bdc7db3,0xdcec01f1,0x27e1a7bc,0xcd281b4f}},	//   _बिहा, _diaľ, zrin_, ажне_, 
   {{0xbcf80232,0x2fdc1b24,0x8d7400e5,0xe81c0118}},	//   nnéh, prug_, تاخا, निमा_, 
   {{0x613c2137,0x66e00241,0x98a800e4,0x27e00003}},	//   _célu, _jákà, chaĩ_, xrin_, 
   {{0x27e1a7bd,0x613da7be,0x00000000,0x00000000}},	//   vrin_, _délu, --, --, 
   {{0xfaa05d77,0x8d7424e0,0xbcf80306,0x27e0f28f}},	//   даро, _وابا, knéh, wrin_, 
   {{0x27e1a7bf,0xbcf9a7c0,0xc21000d9,0x2600000d}},	//   trin_, jnéh, והל_, _रहबी_, 
   {{0xbcf86b07,0x2d80020c,0x6d880086,0x613c06af}},	// [2da40] dnéh, _ikie_, nñam, _gélu, 
   {{0xbcf94735,0x49c81d4a,0x7c380112,0xa13c0171}},	//   riée, _клон_, äure, _puķk, 
   {{0xb878007b,0x50c994de,0xbac800d1,0x00000000}},	//   _scít, रराष, _ﺑﯘﺧﺎ, --, 
   {{0x66e001e1,0x27e10db0,0x3df8010f,0x44f400db}},	//   _bákà, prin_, ילעד, تسئز, 
   {{0x27e00369,0x613c01ed,0x39440311,0xd36c0116}},	//   qrin_, _mélt, _însa_, گۇل_, 
   {{0x2d800076,0xb87802f0,0xe214004e,0x46a40454}},	//   _lkie_, _vcít, змкы, _фавв, 
   {{0x2d81a7c1,0xbcf82195,0x461401b9,0x201800e2}},	//   _okie_, bnéh, _بوزر, ārim_, 
   {{0xbcf80122,0x00000000,0x00000000,0x00000000}},	//   cnéh, --, --, --, 
   {{0xf9910b71,0xff04165d,0x9f44004a,0xb8780c5e}},	//   ורה_, оянн, lumé_, _ucít, 
   {{0x35ac00ab,0xbcf80036,0x74100472,0xdb1c032e}},	//   _जूड़, mnéi, _زوما, fssý, 
   {{0x613da7c2,0x41a8460c,0x8f0c002e,0xdb1c032e}},	//   _sélu, _твен_, ёnёl_, gssý, 
   {{0xb1100131,0xbcf80221,0x2bdc00bc,0x923800db}},	//   _يولغ, onéi, _बिशा, _учуу_, 
   {{0x98a801a2,0x4f644a6b,0xbcf9a6c2,0x613c3847}},	//   tiaľ_, _کانف, nnéi, _délt, 
   {{0x2bdc0316,0x23b0004a,0xbcf9a7c3,0x9f44020c}},	//   _बिरा, _màj_, inéi, kumé_, 
   {{0xda3407d8,0x613c01d3,0xbcf9a7c4,0x38c80124}},	//   чевы, _félt, hnéi, иуан_, 
   {{0xed581b88,0x98a80030,0x57b46134,0x156c2d40}},	//   _мој_, siaľ_, збат, ﻳﺎﺗﯩ, 
   {{0xbcf86b07,0x2714015b,0xfc3c4d74,0x613c032e}},	// [2da50] vnéh, ঠানো_, rcís_, _héls, 
   {{0xb8780332,0xbcf801e7,0x00000000,0x00000000}},	//   _scís, dnéi, --, --, 
   {{0xbcf80232,0xab980597,0xdb0c0139,0xbec000e2}},	//   tnéh, _بخير_, _ataç, _ķīln, 
   {{0x49f4025c,0xaba804fb,0x00000000,0x00000000}},	//   _བྱིལ_, _دهیم_, --, --, 
   {{0xbcf9a7c5,0x63bc0010,0x23b00051,0x00000000}},	//   rnéh, _črnc, _càj_, --, 
   {{0xbcf80122,0x24840ac5,0xc88800aa,0x88380375}},	//   snéh, _dymm_, _دخپل_, _התשו, 
   {{0xbcf80122,0x569401c0,0x66e001e1,0x66f001f9}},	//   pnéh, _хавт, _wákà, _चातक_, 
   {{0x2bdc1533,0x26000034,0x65946148,0x2d6801a6}},	//   _बिला, _रहती_, _жасу, rđek_, 
   {{0xb4e47347,0x00c400fd,0xb6000135,0x00000000}},	//   पली_, члык_, ġġus, --, 
   {{0x2d800004,0xe81c6236,0xa3e001ad,0x69dc25c9}},	//   _skie_, निता_, _थित_, _फिली, 
   {{0xd250446a,0x6b500267,0x613c01d3,0x546801af}},	//   _ثنا_, _hägg, _céls, _таҡм_, 
   {{0x39480936,0x40b40014,0x00000000,0x00000000}},	//   _nlcs_, _ٹھٹھ_, --, --, 
   {{0x6b5005d5,0x613c31b7,0x00000000,0x00000000}},	//   _jägg, _vélt, --, --, 
   {{0x39480472,0x613c01d3,0x6b500254,0x00000000}},	//   _alcs_, _féls, _mägg, --, 
   {{0x6b500628,0x2714015b,0x945c0432,0x00000000}},	//   _lägg, ঠামো_, _deńi, --, 
   {{0x39480472,0x2d800175,0xc210008f,0xa13c00ef}},	//   _clcs_, _ukie_, עהן_, _puķi, 
   {{0x3948002f,0x25a400a2,0xbd80013d,0x00000000}},	// [2da60] _dlcs_, _riml_, _ягък, --, 
   {{0xf1042d8f,0xcfbc03d4,0xb87801e1,0x00000000}},	//   वजुद_, _ইটান, _odíf, --, 
   {{0x24840076,0xca48009f,0x00000000,0x00000000}},	//   _symm_, _طلحه_, --, --, 
   {{0x07a4e490,0x6b500267,0xf8bc032e,0xc7a40818}},	//   _намн, _bägg, _hnén_, _нимк, 
   {{0xb8780248,0x9f45a7c6,0x260800e1,0xfc3c00d0}},	//   _adíf, sumé_, _सनकी_, ncíp_, 
   {{0xd36c302a,0xbcf9a7c7,0x32d00372,0xdcec01e4}},	//   لۇق_, rnéi, ىزىس, _vjaĉ, 
   {{0xf10409d9,0xbcf80491,0x15b80064,0x0554022e}},	//   वजूद_, snéi, _мыты_, _етая, 
   {{0xb6a03f36,0x09d8000d,0x00000000,0x00000000}},	//   _числ, _बटैय, --, --, 
   {{0x5f941d0f,0xd3b80153,0x00000000,0x00000000}},	//   миит, _духі_, --, --, 
   {{0x613c01d3,0x823400f7,0x00000000,0x00000000}},	//   _célr, _ىراا, --, --, 
   {{0x7d00032e,0x8cbc01f9,0x00000000,0x00000000}},	//   _níræ, _व्हो, --, --, 
   {{0x613c01a8,0x00000000,0x00000000,0x00000000}},	//   _véls, --, --, --, 
   {{0x613c01ed,0x82e8031c,0x008401a9,0x00000000}},	//   _félr, _རྐོའ, _элдо, --, 
   {{0xd9d002f5,0x61f8017a,0x2dd401d9,0xb09800d9}},	//   ়ংসম, otvl, _کُٹھ_, _הידר, 
   {{0x61f9a7c8,0xe088009f,0x00000000,0x00000000}},	//   ntvl, _اَڇو_, --, --, 
   {{0x61f801f5,0xa9343cc5,0xbdf00154,0x00000000}},	//   itvl, несш, _জনপদ_, --, 
   {{0x945c0165,0x69d80162,0x00000000,0x00000000}},	// [2da70] _heńv, _æven, --, --, 
   {{0x945c030a,0xdb1c03b2,0x00000000,0x00000000}},	//   _keńv, rssó, --, --, 
   {{0xe5c40395,0x8af8011a,0x0af0009d,0x00000000}},	//   есчо, _והתי, _шүрэ, --, 
   {{0xb4e5144d,0xb4b401ad,0x00000000,0x00000000}},	//   पले_, छडे_, --, --, 
   {{0x291c013f,0xa92402f0,0x2bd02ce6,0x00000000}},	//   ɛva_, ážet, तीपा, --, 
   {{0xf6b40003,0x6b50049f,0xb87801e1,0x00000000}},	//   _བཅིང, _vägg, _adíg, --, 
   {{0x91940261,0xdef00023,0x00000000,0x00000000}},	//   мјиш, ግናን_, --, --, 
   {{0xd02401c0,0x10a5a7c9,0x00000000,0x00000000}},	//   дмий, мийн, --, --, 
   {{0x944401ed,0x6b500267,0x6d880113,0x09d80037}},	//   _تھان, _häge, sñak, _बट्य, 
   {{0x75380489,0xaca4063f,0xc32c0133,0x00000000}},	//   _houz, stịm, _پڕه_, --, 
   {{0x7539a7ca,0x6b51a7cb,0x2bd039c5,0x613c032e}},	//   _kouz, _jäge, तीना, _vélr, 
   {{0x945c0165,0x6b5000c5,0xfe6c03e6,0x228400db}},	//   _deńv, _mäge, جگه_, _чууг, 
   {{0x6b5004f3,0x7539a7cc,0xdde000bc,0x2714009e}},	//   _läge, _mouz, ětši, ঠাতো_, 
   {{0x0a58044e,0x7539a7cd,0x317da7ce,0x5f7405d9}},	//   _ፍልልያ, _louz, louz_, _ٻاهر, 
   {{0x6b51a7cf,0xbcf87ce5,0x945c030a,0x00000000}},	//   _näge, mién, _geńv, --, 
   {{0x8d75a7d0,0xbcf80789,0x8d9801d9,0x753800bc}},	//   _تاتا, lién, _بختس_, _nouz, 
   {{0x07a5a7d1,0xbf880016,0xc7a5a7d2,0xd7f80212}},	// [2da80] даан, _đoạn_, диак, зує_, 
   {{0xbcf82760,0x86e8007b,0x28dc00bc,0x00000000}},	//   nién, تعرف_, यणहि, --, 
   {{0x7539a7d3,0x8609a7d4,0x6b50338d,0x317c0165}},	//   _bouz, تقاق_, _vägd, kouz_, 
   {{0x75380369,0x448828e8,0x6b500166,0x75d01bf4}},	//   _couz, обен_, _däge, ئينا, 
   {{0x7539a7d5,0x317c1165,0x00000000,0x00000000}},	//   _douz, douz_, --, --, 
   {{0x629c0122,0xa2940826,0x2bd000dc,0x38c00588}},	//   _úrok, налі, तीया, _térâ_, 
   {{0xbcf8f140,0x7539a7d6,0x6b500139,0x91700051}},	//   dién, _fouz, _kägb, _bờ_, 
   {{0x673c0050,0x753803bd,0x61f80f49,0x317c0007}},	//   _horj, _gouz, rtvl, gouz_, 
   {{0x673cdb6d,0xb110a4c3,0xa91001e4,0x61f801f5}},	//   _korj, тмыш, goɾi, stvl, 
   {{0x673da7d7,0x7539a7d8,0x6561a626,0x3ea800b5}},	//   _jorj, _zouz, _hmmh, øbt_, 
   {{0x673c0fb7,0x75380399,0x317d55e3,0x63a82bd7}},	//   _morj, _youz, bouz_, _iidn, 
   {{0x63a9396d,0x673c01e4,0x6288058a,0xa115a7d9}},	//   _hidn, _lorj, _iydo, _سوتت, 
   {{0x63a9a7da,0xbcf828e2,0xdb0c0798,0x6d400f23}},	//   _kidn, bién, _itaú, ömaa, 
   {{0xbcf9a7db,0x673c02f6,0x00000000,0x00000000}},	//   cién, _norj, --, --, 
   {{0x63a9a7dc,0x6288062c,0x2bd0146c,0x6560025c}},	//   _midn, _jydo, तीबा, _ommh, 
   {{0x6288037e,0x63a9a7dd,0xb74404d3,0x00000000}},	//   _mydo, _lidn, ژئاو, --, 
   {{0x6b500628,0xb8e44802,0x7539a7de,0x62882b96}},	// [2da90] _säge, _उभ_, _rouz, _lydo, 
   {{0x7539a7df,0xd6d043a0,0x6b50014a,0x673c0072}},	//   _souz, اقا_, _päge, _corj, 
   {{0x7538038e,0x58d4a99b,0x317c0399,0x3a800014}},	//   _pouz, _понт, youz_, _شیرِ, 
   {{0x23e0069f,0x6b514f10,0xaa652c36,0x26000037}},	//   _निशद, _väge, _штык, _रहरी_, 
   {{0x673da7e0,0x75393514,0x63a80162,0x6289a7e1}},	//   _forj, _vouz, _bidn, _aydo, 
   {{0x63a801d9,0x6560003e,0xdb0c09c2,0x62880042}},	//   _cidn, _emmh, _ataú, _bydo, 
   {{0x63a80c3a,0x7538e219,0xdb04003e,0x62882bd6}},	//   _didn, _touz, _cihé, _cydo, 
   {{0xdb04003e,0x62880165,0x673c0010,0x90d4bfb2}},	//   _dihé, _dydo, _zorj, رآبا, 
   {{0xbcf997b8,0xf8bc030a,0x205401c0,0x63a89f02}},	//   tién, _boéz_, втэр, _fidn, 
   {{0x62880142,0xdd9001d3,0x662800fd,0x916001e1}},	//   _fydo, یڈٹ_, _üskä, bó̟_, 
   {{0x8d65a7e2,0xbcf8180f,0x6288feaa,0x613c0066}},	//   евне, rién, _gydo, _télp, 
   {{0x63a807f5,0x2d8420ef,0xaca401f2,0xa3e44da4}},	//   _zidn, ôme_, stọm, पंच_, 
   {{0x426c044e,0x66f02cce,0x2ca401e6,0xaf501321}},	//   _ድሕነት_, _चालक_, ämd_, _индә, 
   {{0x6b50006a,0x2600007d,0xee400022,0x00000000}},	//   _sägb, _रहली_, _аҭои, --, 
   {{0xf8bc0066,0xbcf9a7e3,0x2bdc10fa,0x4995a7e4}},	//   _eném_, gnés, _बिका, ешат, 
   {{0x6e2000ca,0xe81cd639,0x00000000,0x00000000}},	//   _irnb, निला_, --, --, 
   {{0xc724f262,0x8c45a7e5,0x6b50049f,0x63bc49ad}},	// [2daa0] ндай, _чепе, _vägb, _črno, 
   {{0x4bbc0156,0xbcf8004e,0x645c03e3,0x00000000}},	//   ཙཚཛཝ, snét, _ərid, --, 
   {{0x63a9a7e6,0x673c03fa,0xd2440137,0xdd7401d3}},	//   _ridn, _vorj, _ئچ_, _سپیک, 
   {{0x63a9a7e7,0xb7b80022,0xbcf84afb,0x628800ad}},	//   _sidn, _irãn, lnér, _rydo, 
   {{0xf4800131,0x673da7e8,0x628801e3,0x83840137}},	//   лушн, _torj, _sydo, ныке, 
   {{0x7c29a7e9,0x6e200857,0x161c0412,0x88540092}},	//   _ágre, _ornb, फिशर_, _ለመታደ, 
   {{0x63a9a7ea,0x29000418,0xdb0c003a,0x2bd001bc}},	//   _vidn, ofia_, _quaé, तीता, 
   {{0x7af81326,0x63a9a7eb,0x2901a7ec,0x250804d3}},	//   đuti, _widn, nfia_, _ترسی_, 
   {{0x63a804f3,0x2901a7ed,0x6e200d12,0xd48400c7}},	//   _tidn, ifia_, _arnb, _актқ, 
   {{0x7de40220,0xbcf9a7ee,0x6d4001e3,0xdcec00e2}},	//   німд, jnér, öman, _vjač, 
   {{0xaf000139,0x00000000,0x00000000,0x00000000}},	//   учык, --, --, --, 
   {{0x9170004d,0xc059a7ef,0x645c00dc,0x00000000}},	//   _tớ_, _ніл_, _śriy, --, 
   {{0xcff42756,0x7a380166,0x00000000,0x00000000}},	//   _لينک, kätç, --, --, 
   {{0x6e200175,0xbcf97e5c,0x00000000,0x00000000}},	//   _frnb, gnér, --, --, 
   {{0x2901a7f0,0xbcf80129,0x58d414d4,0xcf242c37}},	//   ffia_, liém, ковт, _جرني, 
   {{0xf991a7f1,0x23e00412,0xb878007b,0x3f9d39b6}},	//   ابس_, _निंद, _ndíc, lmtu_, 
   {{0x49a43088,0xb7b800e4,0xf6e5a7f2,0x9f4400d8}},	// [2dab0] тырғ, _erãn, ецен, cumã_, 
   {{0xb8780005,0x2901a7f3,0x9b600131,0x9f4405d5}},	//   _adíc, afia_, _ئۆسۈ, numà_, 
   {{0xb8f41c82,0x19582136,0xfaa406dc,0x80d400eb}},	//   _সা_, _жаны_, _яшин, _ধান্, 
   {{0x7d0c009a,0x9f44004e,0x947400f2,0x91700051}},	//   necs, humà_, نگذا, _mỡ_, 
   {{0xe3b80046,0x66f400d1,0x45a01870,0x6ad400fe}},	//   ебі_, _әпсу, شەكك, _তাতো, 
   {{0x0441a7f4,0x2d680cf4,0xb879a7f5,0x6b50008e}},	//   решн, nđer_, _edíc, _käga, 
   {{0x20540184,0x6b515403,0x1fb401ec,0x00000000}},	//   ҫтыр, _jäga, қсыр, --, 
   {{0x6b500724,0x3f9c208d,0x6d880309,0x74cc00d1}},	//   _mäga, emtu_, nñat, ﺗﻤﻪﻳ, 
   {{0x77380020,0x9f440ffb,0x4f9417a0,0x00000000}},	//   _በማስተ, fumà_, кроу, --, 
   {{0x9f44004e,0x257c00bc,0xbcf8002e,0xb87801ef}},	//   gumà_, díly_, siél, _zdíc, 
   {{0xbcf804d4,0x91700051,0x0e540395,0x00000000}},	//   piél, _cỡ_, тъпя, --, 
   {{0x1e9430cb,0x6d880882,0x8c440166,0xe0d042b5}},	//   ырыр, jñat, веме, _هزه_, 
   {{0xdc740724,0x5a300023,0x8b64691d,0x00000000}},	//   гырь, _ኣመለኻ, ناسم, --, 
   {{0x09e40276,0x00540302,0xeab0015b,0x6e200076}},	//   когн, _בשנת_, কর্ম, _trnb, 
   {{0x6e200857,0xc33005d0,0x91700051,0x29000042}},	//   _urnb, סול_, _gỡ_, tfia_, 
   {{0x0c25a7f6,0x09d005f9,0x29000618,0x00000000}},	//   _амин, _तबीय, ufia_, --, 
   {{0x629c03c6,0x290020ac,0x9a480014,0x00000000}},	// [2dac0] _úrov, rfia_, وجہِ_, --, 
   {{0x998c04b9,0xdcec00df,0x0ba80046,0x4a44022e}},	//   ćeš_, _diaĵ, _تاعى_, _анов, 
   {{0xd5b80164,0x44a42c11,0xdb1c0267,0x88e40139}},	//   есі_, چماق, tssö, _ижне, 
   {{0xb7b80120,0xdcec0115,0x44a410cf,0x84640166}},	//   _grão, _fiaĵ, نماق, къле, 
   {{0x69dda7f7,0xbcf80129,0x00000000,0x00000000}},	//   lsre, xiém, --, --, 
   {{0xf8bc00d5,0x630401b9,0xd3c400d1,0xc20400d8}},	//   _anéh_, اوغل, اتنى, вџии, 
   {{0x72d00075,0x835401d5,0xb204033a,0x00000000}},	//   شەنچ, _یپرا, вејз_, --, 
   {{0xdef8003d,0x60f800a7,0xbcf800e4,0x00000000}},	//   miċi_, хния_, tiém, --, 
   {{0xdef8038f,0xefb007d6,0x7d0c00e5,0x00000000}},	//   liċi_, لینگ, vecs, --, 
   {{0xaca401f2,0x00000000,0x00000000,0x00000000}},	//   _chọw, --, --, --, 
   {{0x69dc0552,0x2bd00574,0xdef8003d,0x00000000}},	//   jsre, तीसा, niċi_, --, 
   {{0xbcf801ed,0x9f4404cc,0x63bc0010,0x6b51549b}},	//   gnép, sumà_, _črnj, _räga, 
   {{0x201800da,0xa3b80c2e,0x6b500724,0x46b005d7}},	//   āris_, _घूम_, _säga, जशाह, 
   {{0x6b500309,0xf8bc00e4,0x69dda7f8,0xe0440d31}},	//   _päga, _inéi_, fsre, _инҗи, 
   {{0xead42401,0xdef80327,0xeab000fe,0x4f9400d8}},	//   рось, jiċi_, কৰ্ম, _срцу, 
   {{0x2bdc7ff3,0xdef8003d,0x6b516d21,0x2d6801ed}},	//   _बिचा, diċi_, _väga, lően_, 
   {{0x9b45a7f9,0xdd9000ec,0x2bac01f9,0x00000000}},	// [2dad0] _منظو, _پوک_, _टंचा, --, 
   {{0x5b140664,0xdef8003d,0x6d882b34,0x69dda7fa}},	//   _смот, fiċi_, sñat, bsre, 
   {{0xb7b800e4,0xdef80327,0x2ae800cd,0xbac80150}},	//   _irãm, giċi_, _जयतु_, _ﺑﯘﺗﺎ, 
   {{0xfd1da7fb,0xdcec0115,0xc17c0024,0x6d880784}},	//   ndì_, _tiaĵ, žėjo_, qñat, 
   {{0x2bdc04fa,0xe8e001fb,0xf8bc0241,0xdb0c00ae}},	//   _बिछा, _ngột_, _ifé_, _luaí, 
   {{0x6b500139,0xdef8025c,0xdb1c0254,0x00000000}},	//   _lägn, biċi_, pssõ, --, 
   {{0xb5a5a7fc,0xdb0c0332,0x049000b8,0x2dc80150}},	//   _арай, _nuaí, _mūṣi, _ﺒﺈﻫﻤ, 
   {{0x31400107,0x00000000,0x00000000,0x00000000}},	//   рдиҳ, --, --, --, 
   {{0xa3e0038e,0x4ed40166,0xc4d0011a,0x00000000}},	//   _थिए_, люнт, _לגן_, --, 
   {{0xd06001e4,0x69dc9d07,0x00000000,0x00000000}},	//   _ɨuɨa, ysre, --, --, 
   {{0x7bdda7fd,0xf8d000dc,0x00000000,0x00000000}},	//   _avqu, तराय, --, --, 
   {{0x69dc0627,0xb7b80022,0x6d880789,0xc69002e4}},	//   vsre, _arãm, eñar, מאי_, 
   {{0xd0080262,0x63bc0427,0x00000000,0x00000000}},	//   _челе_, _črnk, --, --, 
   {{0xf8bc0ca8,0xfd1c04cc,0x8fe00032,0x12e403d4}},	//   _afé_, adì_, _кәүҙ, প্ৰদ, 
   {{0xdb0c0798,0x4430004d,0x0490002b,0x69dda7fe}},	//   _guaí, ̣y_, _dūṣi, usre, 
   {{0x69dda7ff,0xb7b800c7,0xdb0c010e,0x6138010e}},	//   rsre, _erãm, _itaý, _iºlä, 
   {{0x69dda800,0x7d74038b,0x3ec000d5,0x00000000}},	// [2dae0] ssre, _حمير_, _érté_, --, 
   {{0xdef8003d,0xb8e82886,0x69dc1f53,0x442876e0}},	//   tiċi_, _र्_, psre, _čb_, 
   {{0x234803e6,0x2bd06847,0x05cc000d,0x6b500166}},	//   ێستی_, तीरा, हींब, _yägn, 
   {{0xaee01682,0x61fc01e6,0x893400c6,0x2d6801d3}},	//   _maṱh, _ärli, _إعدا, zően_, 
   {{0x4344784b,0x24180104,0xd90c6e92,0xdef8031c}},	//   ледв, толы_, _زیل_, siċi_, 
   {{0xdb0c00a2,0xdef80135,0xf48411c5,0x00000000}},	//   _otaý, piċi_, دامی, --, 
   {{0xe81c07af,0xa3e0000d,0xf5e40451,0x00000000}},	//   निका_, _थिक_, _مڙني_, --, 
   {{0x1fc8009e,0x959800cf,0xba98b8b4,0x00000000}},	//   _শিবস, _атуу_, עסקי, --, 
   {{0x2d6800dd,0x9f541b88,0xdb0c010b,0x00000000}},	//   tően_, ивич, _ataý, --, 
   {{0x03a4004e,0x38140375,0x2b5800b5,0x6b50007c}},	//   _сизо, נקים_, jhrc_, _sägn, 
   {{0x1d344dba,0xa2a0298e,0xc0e418bc,0x73300ef6}},	//   ання, गेश्, _боек, _دىلا, 
   {{0xfd1c04cc,0xa3e80073,0xdcfc00ef,0x00000000}},	//   udì_, _मटा_, fosā, --, 
   {{0xdfd4005e,0xfd1c06bb,0x2bd0146c,0x9f340006}},	//   _толы, rdì_, तीला, _велі, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf99005d3,0xdd9406d3,0xda0800f1,0xfca84710}},	//   مبر_, _какы, خيزه_, باگو_, 
   {{0x6b51a801,0x7b64008e,0x3ddc0210,0x00000000}},	//   _fägo, _әтие, mstw_, --, 
   {{0x6b50007c,0x00000000,0x00000000,0x00000000}},	// [2daf0] _kägl, --, --, --, 
   {{0xbcf80036,0x7d1c439e,0x99800118,0x613c01d3}},	//   diéi, _haqs, _trhů_, _célz, 
   {{0x6b500598,0x7d1c0113,0x39e800c7,0xabac01ec}},	//   _mägl, _kaqs, _џьон_, _ﺳﻮﻣﺎ, 
   {{0x7d1c003d,0x6d880113,0xbcf890d4,0x6b50007c}},	//   _jaqs, nñap, fiéi, _lägl, 
   {{0x7d1da802,0xbcf801c7,0xfbdc0af9,0x7c3801f4}},	//   _maqs, giéi, nsê_, äurh, 
   {{0xe3b0021a,0x02c00212,0x00000000,0x00000000}},	//   سره_, ойшо, --, --, 
   {{0xe8e00208,0xd3c42374,0xa2a028fe,0x6d4001f4}},	//   _ngớt_, اتچى, गेल्, ömak, 
   {{0x7d1da803,0xdb0c067c,0xc95000df,0x00000000}},	//   _naqs, _ataü, ַמי_, --, 
   {{0xbcf80036,0xdb0c00a2,0x64a40120,0x09d001f9}},	//   ciéi, _staý, _гаѓа, _तब्य, 
   {{0x613c00dd,0x3385a804,0xdb0401ab,0xdb1c03b2}},	//   _mély, _субв, _nihà, ypsá, 
   {{0x63bc09a8,0x7d1d6137,0x14d80037,0x00000000}},	//   _črni, _baqs, _ढ़ाण, --, 
   {{0xb878007b,0x0c240139,0xa19401f0,0x00000000}},	//   _ndío, аммн, _лахч, --, 
   {{0x7d1c0003,0xfbdc0af9,0x0c9406a6,0x4f9400d8}},	//   _daqs, gsê_, ршня, _крку, 
   {{0xb7b80022,0x00000000,0x00000000,0x00000000}},	//   _erãk, --, --, --, 
   {{0x7d1c0009,0x2fdda805,0x0d740a89,0xbcf80036}},	//   _faqs, lsug_, _выпя, ziéi, 
   {{0x08c5a806,0x3f000156,0x2f100131,0x2b58037e}},	//   рбан, _མཁོའ_, _ئېھر, shrc_, 
   {{0xdb040ca8,0x6d45a807,0x6d880309,0x2fdc003b}},	// [2db00] _fihà, _ioia, qñaq, nsug_, 
   {{0x6d45a808,0xb879a809,0x28b80e5b,0xbcf80036}},	//   _hoia, _idíl, _अलवि, viéi, 
   {{0x5804005e,0x6d441f45,0x7d1c058a,0x1778005b}},	//   _қорғ, _koia, _yaqs, усть_, 
   {{0x6d45a80a,0x6d403110,0x7d1c0a84,0x6b500139}},	//   _joia, ömah, _xaqs, _mägm, 
   {{0x4ad8ec91,0x6d45a80b,0x883405f5,0x52d0012c}},	//   _बजाव, _moia, _тэнц, हरूस, 
   {{0x27e1a80c,0x6d45a80d,0xdb0c0124,0xbcf804e6}},	//   msin_, _loia, _kuaá, riéi, 
   {{0x6d440270,0x241801e0,0xca54010f,0x00000000}},	//   _ooia, тоһы_, ייַז_, --, 
   {{0x6d45a80e,0x26d9a80f,0xdb04ea0f,0x27e1a810}},	//   _noia, _hero_, _mihá, osin_, 
   {{0x26d9a811,0x25b9a812,0x7d1c01b9,0xb87801e7}},	//   _kero_, _hurl_, _raqs, _ndíl, 
   {{0x27e1a813,0x26d9a814,0xdb0400e4,0x25b80413}},	//   isin_, _jero_, _oihá, _kurl_, 
   {{0xb8780241,0x27e007a1,0x11e80ef8,0xb7b80124}},	//   _adíl, hsin_, _معني_, _erãh, 
   {{0x4425a815,0x26d9a816,0xeea429a3,0x2fdc0af9}},	//   ovo_, _lero_, штык_, bsug_, 
   {{0xae403b99,0x4424047e,0x6b500730,0x6d44f5f6}},	//   مپیو, nvo_, _tägl, _doia, 
   {{0x26d9a817,0xdcb01473,0x4425a818,0xfb85a819}},	//   _nero_, تىڭ_, ivo_, рымн, 
   {{0x7d1da81a,0x6d445ab2,0xa3b81e61,0x613c056a}},	//   _taqs, _foia, _घूस_, _bélx, 
   {{0x6d45a81b,0x27e015b7,0x00000000,0x00000000}},	//   _goia, fsin_, --, --, 
   {{0x26d9a81c,0x4424016d,0x76c4007b,0x78bc02d0}},	// [2db10] _bero_, jvo_, لغال, rcqv, 
   {{0x26d839b3,0x4425a81d,0x25b818b0,0x7b6401d9}},	//   _cero_, dvo_, _burl_, _خابٕ, 
   {{0x25b8375a,0x442402e8,0x27e1a81e,0xdb0c00e4}},	//   _curl_, evo_, asin_, _guaá, 
   {{0xdb0c0428,0x27e1a81f,0x6d44056a,0x25b80175}},	//   _itañ, bsin_, _xoia, _durl_, 
   {{0x26d9a820,0x06d0045e,0x27e001f6,0xb7b800e4}},	//   _fero_, ালজি, csin_, _orãi, 
   {{0x26d89383,0xc0b80020,0xa3e802e5,0x25b9a821}},	//   _gero_, ደዚህ_, _मटर_, _furl_, 
   {{0x25b9a822,0x4425a823,0xf99c0208,0x00000000}},	//   _gurl_, avo_, _khè_, --, 
   {{0xc6901a4c,0x4425a824,0xf8bc04d4,0x2fdda825}},	//   _זאל_, bvo_, _inés_, tsug_, 
   {{0x26d9a826,0xe16400c6,0x6d45a827,0x22540010}},	//   _yero_, تدوي, _roia, _čakš_, 
   {{0x26d80014,0xe6040014,0xf2040953,0xdb0c005a}},	//   _xero_, _دِہَ, _вядо, _otañ, 
   {{0xb8780316,0x6d440276,0x27e02a87,0x0d84c939}},	//   _sdíl, _poia, zsin_, йлон, 
   {{0x8d5400e6,0x27e1a828,0xb7b800e4,0xf99c004d}},	//   сточ, ysin_, _erãi, _nhè_, 
   {{0xdb0c0054,0x6d440276,0x27e1a829,0x70b401af}},	//   _atañ, _voia, xsin_, _йѳҙѳ_, 
   {{0xf99c026c,0x7f580d16,0x6d440076,0xcb740063}},	//   _ahè_, chtq, _woia, сумњ, 
   {{0x26d9a82a,0x27e1a82b,0x44241cbd,0xf99c0395}},	//   _rero_, wsin_, zvo_, _bhè_, 
   {{0x27e1a82c,0xf99da82d,0x4425a82e,0x26d9a82f}},	//   tsin_, _chè_, yvo_, _sero_, 
   {{0x26d9a830,0xdb0c0428,0xf8bc4b84,0x25b8010a}},	// [2db20] _pero_, _etañ, _anés_, _surl_, 
   {{0x4424047e,0x25b9a831,0x59e000bc,0xddd80064}},	//   vvo_, _purl_, _फिचर, _gyvų, 
   {{0x26d9a832,0x27e1a833,0x8699a834,0x85e80798}},	//   _vero_, ssin_, утат_, удев_, 
   {{0x4425a835,0x27e00209,0x26d804fe,0xf99c0ffb}},	//   tvo_, psin_, _wero_, _ghè_, 
   {{0x26d9a836,0x25b80036,0x4425a837,0x27e1a838}},	//   _tero_, _wurl_, uvo_, qsin_, 
   {{0x4425a839,0x26d81730,0x25b801ab,0xbcf8003e}},	//   rvo_, _uero_, _turl_, liét, 
   {{0x4425a83a,0x63bc0219,0x25b80175,0xa3b800e1}},	//   svo_, _črnu, _uurl_, _घूर_, 
   {{0x4424014f,0x20540395,0xd25800d4,0xc5a001af}},	//   pvo_, жкия, шці_, _эҫеһ, 
   {{0x35a001c6,0x4424f5a0,0x2ee4045a,0xbfa80108}},	//   _хатг, qvo_, _bdnf_, лтое_, 
   {{0x161c0316,0x8c1c009e,0xc304009a,0x00000000}},	//   फिचर_, দমান_, _دبرو, --, 
   {{0x4255a0dc,0x00000000,0x00000000,0x00000000}},	//   _утат, --, --, --, 
   {{0x271400fe,0x7f580200,0xbcf800e5,0x00000000}},	//   ঠাটো_, shtq, lnéz, --, 
   {{0x2cb80122,0xc0940137,0xff2801b9,0xed5802d5}},	//   _šedá_, _اجات, _бўйи_, соў_, 
   {{0x9f440270,0xf99c007f,0x00000000,0x00000000}},	//   humú_, _shè_, --, --, 
   {{0xf99c0051,0x9e840244,0x00000000,0x00000000}},	//   _phè_, _باشۆ, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x200400d0,0xf7b800f2,0x00000000,0x00000000}},	// [2db30] ntmi_, ادرش_, --, --, 
   {{0x2904007c,0x00000000,0x00000000,0x00000000}},	//   _öman_, --, --, --, 
   {{0xf99da83b,0x3f500311,0xd4b9a83c,0x56141291}},	//   _thè_, _râul_, алец_, تواء, 
   {{0xbcf82047,0xe6a8039b,0x200400d0,0x98b80064}},	//   ciét, съул_, ktmi_, _bosą_, 
   {{0xbcf9a83d,0x9970033f,0xdb1c11ab,0x2cb80327}},	//   liés, _mąż_, ppsä, _དཔལབ, 
   {{0xbcf800dd,0x2d6801d3,0x3f8c0205,0xd1c826b1}},	//   gnéz, tőek_, _nkfu_, алке_, 
   {{0x3544009d,0x00000000,0x00000000,0x00000000}},	//   _лхав, --, --, --, 
   {{0x945c0432,0x0fc401a9,0x00000000,0x00000000}},	//   _meńz, ойин, --, --, 
   {{0xb7b800e4,0xdb0c00d8,0xcf380212,0x73c000fb}},	//   _erãv, _guaç, ачні_, _эҙле, 
   {{0x42500451,0x6b500267,0x0dbc0023,0x13a40345}},	//   _ڪچهر, _vägk, _ተረፍ_, _بۆتی_, 
   {{0xd2500583,0xdb0c00d8,0x6234034f,0x645c03e3}},	//   _تنا_, _zuaç, _нефу, _ərim, 
   {{0xdb0c11c3,0xbcf9a83e,0xd01006b6,0x00000000}},	//   _stað, diés, _يلا_, --, 
   {{0xbcf995f3,0x4fc000d1,0x00000000,0x00000000}},	//   viét, _تەخە, --, --, 
   {{0x78100c2e,0x6ebc0316,0x6b50000d,0xdb040139}},	//   डबैक_, लुखु, _kägi, _nihä, 
   {{0xbcf80129,0x00000000,0x00000000,0x00000000}},	//   tiét, --, --, --, 
   {{0x61fc03d4,0x798c03ac,0x9f5401b8,0x945c0432}},	//   _årle, _ckcw, öfön_, _deńz, 
   {{0xbcf9033c,0x2bd000c5,0x00000000,0x00000000}},	// [2db40] riét, तीखा, --, --, 
   {{0xbcf80789,0xc68c0023,0x00000000,0x00000000}},	//   biés, _ጀሚርካ_, --, --, 
   {{0xbcf9a83f,0x6b51a840,0xaad000dc,0x9f440270}},	//   miér, _nägi, _त्यक, tumú_, 
   {{0x614000d2,0xdb0402f6,0xbcf99938,0x254000cd}},	//   _málû, _eihä, liér, _śiṣṭ, 
   {{0x24819171,0x07a400c2,0x63bc0010,0x00000000}},	//   çim_, _мамн, _črns, --, 
   {{0xbcf9a841,0x17c40022,0x240800ee,0x6b5001f4}},	//   niér, _харҭ, инҗи_, _bägi, 
   {{0x3d180073,0x6b5001e3,0xd3980166,0x00000000}},	//   _बसले_, _vägh, сәтә_, --, 
   {{0x3f8c00d8,0xdb0c0166,0xbcf801d3,0x20040003}},	//   _skfu_, _tuaç, snéz, ttmi_, 
   {{0xc05800d6,0x8cdc02ab,0xbcf801c7,0x00000000}},	//   рій_, परनो, nhée, --, 
   {{0x6b5001b8,0x2005a842,0xf834011a,0xc0e002dd}},	//   _fägi, rtmi_, קנית_, _ﺍﺩﻩﺗ, 
   {{0xb4a8008c,0x200454a8,0xbcf80789,0x6e6000f5}},	//   _íþró, stmi_, diér, дтяж, 
   {{0x61f80455,0x00000000,0x00000000,0x00000000}},	//   muvl, --, --, --, 
   {{0x61f9a843,0x3178010f,0x00000000,0x00000000}},	//   luvl, _דראמ, --, --, 
   {{0x70502cbf,0xef0c00f1,0xef14013d,0x9970012d}},	//   _تنها, _لټه_, _ммч_, _wąż_, 
   {{0xf9688b2d,0xbcf8004a,0x61f8022e,0x620406be}},	//   арай_, théd, nuvl, _çulğ, 
   {{0x98b9a844,0x6d41a845,0x9724008e,0x76400108}},	//   слат_, ömat, _äğzä, änym, 
   {{0xe89411ed,0xbcf9a846,0x61f8022e,0x57f40150}},	// [2db50] дать, siés, huvl, япат, 
   {{0xbcf80789,0xdb0401e3,0xb9c41095,0x7bcc01e3}},	//   ciér, _bihå, _وتجه, mpcu, 
   {{0x1db0033f,0x61f80455,0x5ebc0154,0x199401f0}},	//   ीआपत, juvl, _আজাই, _наоя, 
   {{0x604402b5,0x6a159c56,0x00000000,0x00000000}},	//   _kōmā, _کبیر, --, --, 
   {{0xbcf820ef,0x61f80af9,0x49380375,0xdb0c0174}},	//   chée, euvl, _הגרו, _óhós, 
   {{0xe8e831d9,0x6b50af45,0xe7f00b7d,0xc7d40a7c}},	//   _འཇོག, _pägi, _चिता_, _מושי_, 
   {{0x94d40640,0x00000000,0x00000000,0x00000000}},	//   _новц, --, --, --, 
   {{0x6b5000af,0x950400dd,0x45a01e4a,0xe188143e}},	//   _vägi, _رہتے_, _كەلك, يئين_, 
   {{0x245800c9,0x972c0b82,0xbcf800e5,0x8eb839af}},	//   _дать_, _ሰማዕት, yiér, йынт_, 
   {{0xdd0000b0,0x6b5008a1,0x61f80477,0x0e65a847}},	//   _ātām, _tägi, buvl, зкон, 
   {{0x7bcc0369,0x73c001ee,0xf60c0150,0x00000000}},	//   epcu, _эҙһе, ейiн_, --, 
   {{0xfe6c1550,0x00000000,0x00000000,0x00000000}},	//   دگه_, --, --, --, 
   {{0xbcf9911a,0xfaa000c7,0x00000000,0x00000000}},	//   tiér, ҵаро, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbcf803c6,0xb878015b,0xc3300375,0x32043903}},	//   riér, _leíd, עול_, ntny_, 
   {{0x47c45547,0xbcf80407,0x3ea80419,0x19b00116}},	//   збав, siér, ýbte_, _ﺳﺎﻧﻠ, 
   {{0x46e9a848,0xc6d5a849,0x06e9a84a,0x61f801b9}},	// [2db60] йдан_, كتات, ймак_, zuvl, 
   {{0x2ca1a84b,0xbcf80036,0x61f8014f,0x32040419}},	//   _izid_, rhée, yuvl, ktny_, 
   {{0x7ab80302,0x3ab80375,0x070016ae,0x69a401af}},	//   _לציו, _למינ, र्गव_, _олоҡ, 
   {{0x29e80724,0xbcf8004a,0x48080276,0x61f8014f}},	//   mğa_, phée, _лемн_, vuvl, 
   {{0x29e80724,0xb87800e4,0x6b50008e,0x3204033f}},	//   lğa_, _reíg, _dägv, etny_, 
   {{0x6ab0000e,0x61f9a84c,0xa29401ce,0x2295a84d}},	//   _জ্যো, tuvl, малі, миля, 
   {{0x29e80598,0xb6c801ed,0x46a4010b,0xa3e80406}},	//   nğa_, _چاہے_, _хавв, _मटक_, 
   {{0xf1a13f3c,0x1fc400c2,0xfc3c011f,0xf49401d9}},	//   нрын, мроҳ, yxí_, _کھٔت_, 
   {{0x6b500037,0x7ff4007b,0x61f82a89,0xb600025c}},	//   _hägu, أسعا, suvl, ġġes, 
   {{0x74104cec,0xf48401d5,0x608c0023,0x7c2808a5}},	//   _سوما, _راقی, _ሕድገት_, _ágri, 
   {{0xabac02dd,0x29e80166,0x00000000,0x00000000}},	//   _ﺳﻮﻋﺎ, jğa_, --, --, 
   {{0x80d40eac,0xfc3c00cf,0xa3e017cb,0x5bb45ae4}},	//   _ধাক্, txí_, _दबा_, ंद्व, 
   {{0x2d80007f,0xff500023,0x00000000,0x00000000}},	//   _djie_, _ዝገርመ, --, --, 
   {{0xe8e8025c,0x6d412d5f,0xde580a4a,0x5e582c2c}},	//   _འཇུག, ömar, _малі_, _миля_, 
   {{0x6e91a84e,0xba75a84f,0x6b500037,0xdb0401d3}},	//   _пишу, ساست, _nägu, _kihú, 
   {{0x2d80017a,0x99980212,0x00000000,0x00000000}},	//   _gjie_, ікат_, --, --, 
   {{0x57b5a850,0x29e82d1c,0x97344dc1,0x00000000}},	// [2db70] дбат, ağa_, وکسا, --, 
   {{0xb879a851,0xdcf804fb,0xe784014b,0x555401d9}},	//   _reíd, _افکت_, нухо, ژپار, 
   {{0x04c8063f,0xbcf8400f,0x2ca0031c,0x29e8013d}},	//   _ịpịn, chéc, _zzid_, cğa_, 
   {{0x09d40154,0x00000000,0x00000000,0x00000000}},	//   _তৎকা, --, --, --, 
   {{0x5fb809bb,0x6b500267,0xe45402d5,0x00000000}},	//   _उंगल, _vägv, нкцы, --, 
   {{0x97346727,0x88380375,0xa3b8007b,0x00000000}},	//   _تکرا, _ותשו, ساهر_, --, 
   {{0x225401f1,0x23092707,0xa5f80117,0x56940114}},	//   _čaká_, ستوي_, _неру_, _цавт, 
   {{0x39480228,0x6595a852,0x320400d7,0x00000000}},	//   _jocs_, _засу, rtny_, --, 
   {{0x3948004e,0x32042344,0x96e0033f,0xae9000e4}},	//   _mocs_, stny_, _फ़ाउ, mỹir, 
   {{0x39480998,0x8e740108,0x09a801f9,0x156c00d1}},	//   _locs_, думч, _कळ्य, ﺳﺎﺑﯩ, 
   {{0xe1f078db,0x2be0000d,0xe2c80472,0x00000000}},	//   _مسن_, _कबहू_, _رونو_, --, 
   {{0x3949a853,0x905400d4,0x00000000,0x00000000}},	//   _nocs_, _овец, --, --, 
   {{0x0ba81c3e,0x9a78001f,0x6134022e,0x00000000}},	//   قاسى_, _የትኛው_, mоlа, --, 
   {{0xbcf806af,0x00000000,0x00000000,0x00000000}},	//   théc, --, --, --, 
   {{0x20180311,0x2d80f4e5,0x3949a854,0xe7f0000d}},	//   ărie_, _tjie_, _bocs_, _चिहा_, 
   {{0x29e81248,0xbe5400aa,0x9f440023,0xbcf80036}},	//   rğa_, _ترهګ, ysmë_, rhéc, 
   {{0x3949a855,0x6b500139,0xc725a856,0x37e001a9}},	// [2db80] _docs_, _sägu, мдай, котг, 
   {{0x6b500309,0xbcf800c6,0x46e80220,0x6134022e}},	//   _pägu, mhéa, іден_, hоlа, 
   {{0x3949a857,0x7b840137,0x613401a9,0x96a8012d}},	//   _focs_, _تايە, kоlа, झेलॉ, 
   {{0xe8e81b35,0x6e204b5a,0x387c01a6,0x6b50007c}},	//   _འཇིག, _msnb, _žure_, _vägu, 
   {{0x68e5a858,0xc7640447,0xf8bc0c6a,0x2901a11a}},	//   maid, _قاسى, _kaén_, mgia_, 
   {{0x68e5a859,0xf8bd5e00,0x2901a85a,0x6f00036e}},	//   laid, _jaén_, lgia_, _ncnc, 
   {{0xf8bc00d5,0xf620023b,0x29000037,0xa195a85b}},	//   _maén_, _идро, ogia_, накч, 
   {{0x68e5a85c,0x3948004e,0xb6a02312,0x00000000}},	//   naid, _xocs_, _рисл, --, 
   {{0x290007c5,0xdb1c08fb,0xf9900375,0x00000000}},	//   igia_, ppsø, כרה_, --, 
   {{0x68e43c60,0xbcf800c6,0x290005b1,0xdb0401e1}},	//   haid, dhéa, hgia_, _fihù, 
   {{0x68e5a85d,0x36f40302,0x6b5001e6,0xd2b8009d}},	//   kaid, וצים_, _lägs, _хууч_, 
   {{0x9f4401b8,0xbcf80332,0xbd6800d4,0xbc340139}},	//   lumü_, fhéa, ірне_, дҗич_, 
   {{0x68e5a85e,0x3948004e,0x290007c5,0xbcf80332}},	//   daid, _rocs_, dgia_, ghéa, 
   {{0x2900009d,0x9b5801c6,0x69c0010f,0x00000000}},	//   egia_, чигт_, ĉmen, --, 
   {{0x68e5a85f,0x3949a860,0x00000000,0x00000000}},	//   faid, _pocs_, --, --, 
   {{0x2901a861,0xbcf80491,0x00000000,0x00000000}},	//   ggia_, bhéa, --, --, 
   {{0xbcf91f45,0x39480076,0xb87801e7,0x00000000}},	// [2db90] chéa, _vocs_, _ndít, --, 
   {{0x29000618,0x6134022e,0xdb2401f4,0x00000000}},	//   agia_, zоlа, äsär, --, 
   {{0x68e5a862,0x394852b3,0xb7b80124,0x290007c5}},	//   baid, _tocs_, _erãp, bgia_, 
   {{0x68e5a863,0x29000051,0x00000000,0x00000000}},	//   caid, cgia_, --, --, 
   {{0x947425da,0xe824013e,0x6134022e,0x00000000}},	//   رگرا, _ифро, vоlа, --, 
   {{0xf8bc0005,0x6b5001e3,0x7c28032e,0x00000000}},	//   _xaén_, _hägr, _ágru, --, 
   {{0xb87804d4,0x66b56986,0x3dcc0142,0x00000000}},	//   _edít, _абру, _ntfw_, --, 
   {{0xd025a864,0x21740022,0x00000000,0x00000000}},	//   емий, куыр, --, --, 
   {{0x7538005a,0x6b50008e,0xa491a865,0x6134022e}},	//   _inuz, _mägr, _پیوت, rоlа, 
   {{0x6b50049f,0x29005144,0x68e43f1b,0x00000000}},	//   _lägr, zgia_, zaid, --, 
   {{0x68e4c3d3,0x2900003a,0xa3b80037,0xf1c401d5}},	//   yaid, ygia_, _घूट_, _ўқий_, 
   {{0xbcf800c6,0x8c940845,0x9f440789,0x228401c0}},	//   théa, ергі, fumó_, _рууг, 
   {{0x68e5a866,0x29001570,0x317c0107,0xfaa074f0}},	//   vaid, vgia_, mnuz_, ғато, 
   {{0x68e400b2,0x69c8f874,0xecc4009d,0x00000000}},	//   waid, ídeo, эшүү, --, 
   {{0x68e5a867,0x2901a868,0xed840116,0xb87800d0}},	//   taid, tgia_, _аңни, _odís, 
   {{0xb87801e7,0xb8800c5e,0xa3e00037,0x00000000}},	//   _ndís, klíč, _दबल_, --, 
   {{0x68e43e7c,0x46f40c56,0xd7f802bf,0x88840395}},	// [2dba0] raid, ечет, дує_, хлаж, 
   {{0x68e5a869,0x7538005a,0x290154dc,0x6b500267}},	//   said, _anuz, sgia_, _vägs, 
   {{0x8a040212,0x00000000,0x00000000,0x00000000}},	//   _язне, --, --, --, 
   {{0x75d1a86a,0xc4841cd1,0xb8800118,0x225800a2}},	//   اينا, нлек, flíč, _ürki_, 
   {{0xb87803b7,0x63e400cf,0xe8dc01f9,0x00000000}},	//   _veíc, ئۋئل, बरीच, --, 
   {{0xf4840799,0x81f80156,0x7539a86b,0x73c0009a}},	//   رانی, _དཀྱི_, _enuz, ديوم, 
   {{0xb6a0785a,0xbcf8034c,0x317c0334,0x06a800cc}},	//   _бирл, dhén, fnuz_, খুজি, 
   {{0x04c80451,0xd4c002dd,0xb880013a,0xd5d401f9}},	//   _روئي_, _көшк, blíč, डीओज, 
   {{0x6560007b,0xb11000fb,0x00000000,0x00000000}},	//   _ilmh, умыш, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x81f8025c,0x69c802fb,0x00000000,0x00000000}},	//   _དཀྲི_, ídel, --, --, 
   {{0x61f800f3,0xe8540023,0x00000000,0x00000000}},	//   mrvl, ለልትነ, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbcf80124,0xb87801ef,0x9e140153,0x00000000}},	//   chén, _odír, _адкі, --, 
   {{0xb88000bc,0x39a5a86c,0x656002d0,0xb87800ae}},	//   zlíč, ешав, _olmh, _ndír, 
   {{0x673c02e2,0xdd941c3e,0xa3b8000d,0x00000000}},	//   _anrj, _шайы, _घूघ_, --, 
   {{0xd7f07d5d,0x6b50049f,0x298801f0,0x2ee000cc}},	// [2dbb0] شكا_, _vägr, хсро_, _মাতষ, 
   {{0x7bdc014f,0xb880fc95,0x61f801a6,0x645c03b9}},	//   _iwqu, vlíč, krvl, _ərit, 
   {{0x7ae55c56,0xb7b800e4,0x00000000,0x00000000}},	//   majt, _isãm, --, --, 
   {{0x7ae5a86d,0x63a9a86e,0xdcec00d7,0x1ad800eb}},	//   lajt, _ahdn, _omač, _তায়া, 
   {{0xe7580131,0x2458cb43,0x73340107,0x00000000}},	//   بلەغ_, наць_, нҷар_, --, 
   {{0x7ae5a86f,0x68240a89,0xf364f0be,0x73e000db}},	//   najt, _сьюз, этен, _ۅيرۅ, 
   {{0x7774102c,0x6d600054,0xb88002f0,0x3568030d}},	//   mixx, _ŋqam, slíč, _еран_, 
   {{0x7774003d,0x7ae5a870,0xdcec0cf4,0x958c001f}},	//   lixx, hajt, _ojađ, ጅቶችን_, 
   {{0x7ae4b2b6,0x673c045f,0x317da871,0xbcf8806d}},	//   kajt, _ynrj, rnuz_, thén, 
   {{0x7ae40f03,0x77740003,0x7d180254,0x00000000}},	//   jajt, nixx, õusn, --, 
   {{0xf8bc1dd4,0x7bdc0548,0x03680014,0x20180311}},	//   _ogé_, _awqu, _تٔلی_, ăria_, 
   {{0xf8bda872,0x777400b5,0x2d848b9a,0x69c80419}},	//   _ngé_, hixx, õme_, ídem, 
   {{0xbcf897e9,0x4090004b,0x1ad80154,0x7ae5a873}},	//   phén, _پلور, _তাড়া, fajt, 
   {{0x7ae5a874,0xf8bda875,0x69c801e4,0x8fe000fb}},	//   gajt, _agé_, ŭdem, _йәүҙ, 
   {{0xbcf9a876,0xb8780789,0x4994c9e8,0x7774025c}},	//   chéo, _reía, вшат, dixx, 
   {{0x8d75a877,0xf1b01fbc,0x387c0010,0x6b9c0076}},	//   _جاتا, ुदिन, _žura_, slrg, 
   {{0x8c45a878,0x7ae5a879,0xcc88090f,0xfc4401d3}},	// [2dbc0] _репе, bajt, _زنده_, őírt_, 
   {{0x7bf80302,0x7ae5a87a,0xcb6804fb,0xca740166}},	//   _קפיצ, cajt, _آمده_, _аумы, 
   {{0xb87809c2,0xd245a87b,0xf1b0185d,0x00000000}},	//   _veía, _اچ_, ुदान, --, 
   {{0x96943955,0xdcec031c,0xdbd401e1,0x00000000}},	//   уруш, _kkaġ, _rúút, --, 
   {{0xbcf800f2,0x55c401e0,0x7774031c,0x817001d5}},	//   dhél, _ҡарғ, bixx, ینتچ, 
   {{0xb7b80022,0x387c02d2,0x00000000,0x00000000}},	//   _ysãm, _þura_, --, --, 
   {{0x7640005b,0xb878013a,0x00000000,0x00000000}},	//   änyt, _udír, --, --, 
   {{0x2d5406ed,0xc05802bf,0x7ae40419,0xb7d400e5}},	//   _mães_, діо_, zajt, _سوہا_, 
   {{0x5f9413d6,0x44200669,0x00000000,0x00000000}},	//   лиит, _èk_, --, --, 
   {{0xbcf806af,0x00000000,0x00000000,0x00000000}},	//   théo, --, --, --, 
   {{0x73300131,0x5e5808da,0xdb1c0254,0xde58003b}},	//   _خىلا, хиня_, rpsü, хані_, 
   {{0xdcec01fa,0x7ae40309,0xdb1c000d,0x00000000}},	//   _tmač, wajt, spsü, --, 
   {{0x7ae48b8c,0xdfd1a87c,0x7c84084c,0xb8780332}},	//   tajt, _ايت_, туне, _ndíp, 
   {{0x7774011f,0xab843129,0x00000000,0x00000000}},	//   xixx, ауск, --, --, 
   {{0xa9c59678,0xb8780241,0x2d5406ed,0xae400133}},	//   истк, _adíp, _cães_, _نپوو, 
   {{0x7ae5a87d,0x3f9da87e,0xac7401ec,0x7774031c}},	//   sajt, lltu_, _ھايش, wixx, 
   {{0x7ae5a87f,0x3f9c0268,0x6ca40276,0x97140063}},	// [2dbd0] pajt, oltu_, _врэж, лмац, 
   {{0x2ca4a697,0x7ae40784,0x00000000,0x00000000}},	//   ümde_, qajt, --, --, 
   {{0x77740003,0x3f9c005b,0x00000000,0x00000000}},	//   rixx, iltu_, --, --, 
   {{0x7774011f,0x059402f2,0xe694009d,0x00000000}},	//   sixx, هانگ, шихы, --, 
   {{0x3370941f,0x77740327,0x00000000,0x00000000}},	//   аҳар, pixx, --, --, 
   {{0x56942df7,0x7774022f,0xbcf8020c,0x00000000}},	//   _багт, qixx, dhém, --, 
   {{0xf8bc0438,0xbcf806af,0xeaa00055,0xf48401b9}},	//   _naék_, thél, _ikṣu_, راچی, 
   {{0x10a4356a,0x3f9c031c,0x00000000,0x00000000}},	//   лийн, eltu_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x34905026,0xa300010b,0x00000000,0x00000000}},	//   _бағр, _дүше, --, --, 
   {{0xbcf99914,0x62840356,0x7de4009d,0x800800e5}},	//   phél, şior, лмэг_, وریہ_, 
   {{0xf8bc0438,0x3f9c208d,0xb8780124,0x8c443004}},	//   _daék_, altu_, _reín, геме, 
   {{0xbcf858f4,0x00000000,0x00000000,0x00000000}},	//   chém, --, --, --, 
   {{0x2d540120,0x43d000d1,0x0f78010f,0xbcf800e4}},	//   _pães_, ﻟﺪﯨﺪ, _ראַב, ykég, 
   {{0xe9841086,0xaca40241,0xae0000fb,0x00000000}},	//   иқон, _ikọw, _тойҙ, --, 
   {{0x98a801f1,0x2c040139,0xcd040395,0x00000000}},	//   adač_, _күмм, _спий, --, 
   {{0x8d748c5a,0x19b800a8,0xb6c800e5,0x1b1800eb}},	// [2dbe0] _لاکا, турь_, ڑانے_, দয়ে_, 
   {{0x7bc800d8,0x4a440353,0x00000000,0x00000000}},	//   _égua, _бнов, --, --, 
   {{0x75d000c6,0x682c0023,0x75c80150,0x00000000}},	//   ميلا, ስተራት, етің_, --, 
   {{0x7cec067c,0xb7b800e4,0x7a7808d8,0x00000000}},	//   mòrí, _ysãk, _טריס, --, 
   {{0xab740023,0x3f9c03b2,0xe688215c,0x00000000}},	//   _ኣእዳው_, yltu_, رنچى_, --, 
   {{0xaca400b4,0x26cc06be,0x00000000,0x00000000}},	//   _nkọw, _üdo_, --, --, 
   {{0x81740107,0xd3980139,0x00000000,0x00000000}},	//   лакӣ_, тәтә_, --, --, 
   {{0xb46030cb,0xaca52d9e,0xbcf807ea,0x91a801ed}},	//   ркәл, _akọw, thém, نچنے_, 
   {{0xc24401ec,0x7d18000d,0x00000000,0x00000000}},	//   _әнек, õusm, --, --, 
   {{0x442443d6,0x66e41152,0x301400c6,0x00000000}},	//   mwo_, गरिक_, اتية_, --, 
   {{0x4424d121,0x38a80241,0x00000000,0x00000000}},	//   lwo_, _kòrí_, --, --, 
   {{0xdd94dacb,0x38a80241,0x4424f52d,0xbcf9919a}},	//   рамы, _jòrí_, owo_, kkée, 
   {{0x4424110e,0x5f501954,0x317800df,0x00000000}},	//   nwo_, _ይገልጸ, _אראמ, --, 
   {{0x442437ae,0x38a801e1,0xaed0010a,0x00000000}},	//   iwo_, _lòrí_, _лошш, --, 
   {{0xa3e40034,0x442405b8,0x799c0175,0x6e400114}},	//   भीत_, hwo_, tlqw, _гејз, 
   {{0x260805ba,0x58d5a880,0x4425a881,0xf4bc00cc}},	//   ांनी_, роат, kwo_, _উজ্ব, 
   {{0xbcf80036,0x80dc0154,0x8b64215c,0x00000000}},	// [2dbf0] gkée, নঃপ্, _چاپم, --, 
   {{0x4424013b,0xe87400c6,0x36880408,0xbcf8002e}},	//   dwo_, حافظ, нсен_, khék, 
   {{0x4425a882,0x00000000,0x00000000,0x00000000}},	//   ewo_, --, --, --, 
   {{0x89d8008d,0xbcf80066,0x19582f6a,0x00000000}},	//   _שחרי, dhék, _рамы_, --, 
   {{0x38a801e1,0xbcf806af,0x44242252,0xb4340022}},	//   _dòrí_, ckée, gwo_, ыҟац_, 
   {{0xc88403fa,0x00000000,0x00000000,0x00000000}},	//   üßen_, --, --, --, 
   {{0xb5a422d7,0xf8bc003e,0x44242252,0x661800d0}},	//   _брай, _saéh_, awo_, čaká, 
   {{0x442493e9,0xf8bc00d5,0x569401a9,0x00000000}},	//   bwo_, _paéh_, _баҳт, --, 
   {{0xb7b800e4,0xdb0c0077,0x44240067,0xbfc0005b}},	//   _asãi, _luañ, cwo_, обык, 
   {{0xe454008e,0x98b800ef,0xf1a401ec,0x00000000}},	//   _укуы, _hosē_, _өрен, --, 
   {{0x8d75a883,0x0d8400c2,0xf8bc0c6a,0xb1440214}},	//   لاحا, илон, _waéh_, _میثم_, 
   {{0xed5401e4,0x00000000,0x00000000,0x00000000}},	//   _viɾo_, --, --, --, 
   {{0xe0d001d9,0xd009a884,0x4fd00345,0x00000000}},	//   _رزن_, _реле_, _بڕبڕ, --, 
   {{0xbcf8003e,0xa2d800dc,0x00000000,0x00000000}},	//   gkéb, नुप्, --, --, 
   {{0x09e410f5,0x44240dc9,0x39e4013e,0x00000000}},	//   робн, zwo_, идро_, --, 
   {{0x4424033f,0xdeec0150,0x00000000,0x00000000}},	//   ywo_, _قۋۋ_, --, --, 
  
   {{0xa3e405dc,0x44240009,0xc79441e5,0xabf401f7}},	// [2dc00] _भौं_, xwo_, аржы, _ازبڪ, 
   {{0xb7b800e4,0x0ba80eff,0xc76400d1,0x49c801d5}},	//   _ysãi, _جاعى_, جارى, _илон_, 
   {{0xa6e8045e,0x442404ba,0xa2d400d1,0xbcf812e8}},	//   _পাদট, wwo_, ەيتت, skée, 
   {{0x4425a885,0x61fcec5d,0x75d000f2,0x2ee40790}},	//   two_, _årli, زيها, _lenf_, 
   {{0xd90c0647,0x661c0175,0xe2f802dd,0x35a0009d}},	//   _سیل_, _wprk, гелі_, цацг, 
   {{0x4425a886,0x2ca08e96,0xbcf8020c,0x00000000}},	//   rwo_, _myid_, thék, --, 
   {{0x44240c11,0x661c4beb,0x46a8007d,0x38a801e1}},	//   swo_, _uprk, _करिह, _tòrí_, 
   {{0x9f440770,0xbcf802fb,0x46d00118,0x00000000}},	//   humô_, chéh, दुरह, --, 
   {{0xf4240139,0x44240009,0x00000000,0x00000000}},	//   _котл_, qwo_, --, --, 
   {{0xc305a887,0x38140302,0x46a805f9,0xbcf8007b}},	//   _خبرو, סקים_, _कराह, mhéi, 
   {{0x9f440770,0xdd5844b2,0xb87826b6,0xbcf80036}},	//   dumô_, ганч_, _reím, lhéi, 
   {{0xc0f8001f,0x6ce402dd,0x9f841eec,0x00000000}},	//   ፊትም_, жіре, ргүд, --, 
   {{0x260804fa,0x9f3401ce,0xfd1c026c,0xb7b800e4}},	//   ांडी_, _гелі, gnìa_, _isãv, 
   {{0x2005a888,0x2ee4002f,0x26280139,0xcae00154}},	//   mumi_, _genf_, _oşo_, _বাউফ, 
   {{0x7de4005e,0xda34656c,0xa92400d0,0xaa5406ed}},	//   _тілд, щевы, _žľaz, оврш, 
   {{0x19c400c7,0x00000000,0x00000000,0x00000000}},	//   _ҳәаг, --, --, --, 
   {{0x2005a889,0x00000000,0x00000000,0x00000000}},	// [2dc10] numi_, --, --, --, 
   {{0x200400d2,0xdb0c0108,0x00000000,0x00000000}},	//   iumi_, ähäp, --, --, 
   {{0x2005a88a,0x9b680124,0xac740214,0xda34008e}},	//   humi_, _ашҟа_, _هایش, _уены, 
   {{0x2005a88b,0x940c013f,0xe571a88c,0xf0bc00b5}},	//   kumi_, _gyeɛ_, وطن_, _mm砲_, 
   {{0x200411f9,0x2124007f,0x26dc0156,0xbcf801e7}},	//   jumi_, demh_, ñvoc_, ghéi, 
   {{0x2005a88d,0x88008fda,0x00000000,0x00000000}},	//   dumi_, _رېمو, --, --, 
   {{0x69c801e4,0xe3b002c9,0x00000000,0x00000000}},	//   ŭdev, ذره_, --, --, 
   {{0x2005a88e,0xbcf800c6,0x2ee5a88f,0x00000000}},	//   fumi_, bhéi, _senf_, --, 
   {{0x2005a890,0xbcf9a891,0x00000000,0x00000000}},	//   gumi_, chéi, --, --, 
   {{0x4e2805f5,0xb7b80055,0xa344009d,0x00000000}},	//   гоон_, _prãy, _мэхл, --, 
   {{0xed5400df,0x62340107,0x8db420c8,0x00000000}},	//   _poɾ_, _мефу, йсмі, --, 
   {{0x49c802dd,0x26080073,0x88d40150,0x00000000}},	//   ғлан_, ांती_, _ﺘﻘﺎﻀ, --, 
   {{0x2005a892,0x0c78009d,0xe04801e2,0x00000000}},	//   cumi_, усны_, _نشوه_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbcf804d4,0xb7b800c7,0xdf740214,0xe70401d9}},	//   zhéi, _ysãv, _بدنب, ۪سری, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d45a893,0x068418ce,0x6b500166,0x8b942377}},	// [2dc20] _inia, әген, _mägz, _грнч, 
   {{0x6d440211,0x9724013d,0x00000000,0x00000000}},	//   _hnia, _äğlä, --, --, 
   {{0x2005a894,0x6d440064,0xdd1c013a,0x463800c0}},	//   zumi_, _knia, _báňs, ычая_, 
   {{0x69dd38dd,0xbcf88f8a,0x2005a895,0xc0e8001f}},	//   mpre, théi, yumi_, _መስሎ_, 
   {{0x69dda896,0x82a41945,0xd36c03cc,0x2005a897}},	//   lpre, әшле, چۇق_, xumi_, 
   {{0x2005a898,0xd36c2002,0x260801ad,0xbcf804e6}},	//   vumi_, نۇق_, ांदी_, rhéi, 
   {{0x69dda899,0x6b500139,0xbcf80036,0xc0c8010a}},	//   npre, _bägz, shéi, лупе_, 
   {{0x20041958,0xdfd145d2,0x6d4588ef,0x69dca98b}},	//   tumi_, ويب_, _nnia, ipre, 
   {{0xa49429a4,0x3e4c00ac,0x20040618,0xb87800e4}},	//   _بیشت, məti_, uumi_, _reík, 
   {{0x2005a89a,0x9e740145,0x3e4c0213,0x00000000}},	//   rumi_, يۇشت, ləti_, --, 
   {{0xa3e413b4,0x69dc2e6a,0x2005a89b,0x6d440652}},	//   भीर_, jpre, sumi_, _bnia, 
   {{0x69dda89c,0x03a4016c,0x3e4c0213,0xf650011a}},	//   dpre, _тиҷо, nəti_, לצת_, 
   {{0x69dc0363,0x20040333,0x6d440034,0x2fd400ec}},	//   epre, qumi_, _dnia, _هوند_, 
   {{0x69dda89d,0x6d45a89e,0xfb8420b0,0x03b800fe}},	//   fpre, _enia, сымн, ঁৱৰণ, 
   {{0x69dcab21,0xaf0400cf,0x3e4c0213,0x00000000}},	//   gpre, _اقىم_, kəti_, --, 
   {{0xb9080882,0xa2d80882,0x6d45a89f,0x58d9a8a0}},	//   naiḥ_, नुत्, _gnia, рдая_, 
   {{0x69dc1e0b,0x3e4c03e3,0x00000000,0x00000000}},	// [2dc30] apre, dəti_, --, --, 
   {{0x69dd177b,0xb6c40432,0xac94010a,0x00000000}},	//   bpre, ссай, _хаьш, --, 
   {{0x69dc010f,0xd918b6fc,0xb9080882,0x3e4c00ac}},	//   cpre, _конц_, kaiḥ_, fəti_, 
   {{0x80dc00fe,0x5fc801f9,0x00000000,0x00000000}},	//   নৃত্, रदाल, --, --, 
   {{0xaad000bc,0xa6e80154,0xb90800cd,0x00000000}},	//   तुकक, _পারট, daiḥ_, --, 
   {{0x31b0543b,0x67d4016c,0xdb1c0254,0x00000000}},	//   ुद्ध, _хору, ppsõ, --, 
   {{0x1cb80003,0x3e4c00ac,0x00000000,0x00000000}},	//   _མཛའ_, bəti_, --, --, 
   {{0xd1b801ed,0xf4840120,0x00000000,0x00000000}},	//   جاتا_, _лузн, --, --, 
   {{0x6d440194,0x69dd015d,0xe4540006,0x00000000}},	//   _rnia, zpre, _екты, --, 
   {{0x69dda8a1,0x6d45a8a2,0xb7b80124,0xa3b00073}},	//   ypre, _snia, _isãs, _टीप_, 
   {{0x69dda8a3,0x6b500139,0xdcfc0064,0x00000000}},	//   xpre, _tägz, nosė, --, 
   {{0x69dc151c,0x66d001e1,0x320480c1,0xb908002b}},	//   vpre, _kòkó, muny_, caiḥ_, 
   {{0x320400ee,0x69dc9add,0x00000000,0x00000000}},	//   luny_, wpre, --, --, 
   {{0x95280003,0xf99c0241,0x317c0007,0xdb14033b}},	//   _ལིའི_, _akè_, liuz_, nmzè, 
   {{0x3e4c03be,0x32040209,0x6d4401ab,0xbcf8a491}},	//   yəti_, nuny_, _tnia, skéa, 
   {{0x6d45a8a4,0x2608256a,0x317c634b,0xa3b00027}},	//   _unia, ांसी_, niuz_, _टीन_, 
   {{0x46e80517,0x31180882,0x06e80063,0xdb0408a5}},	// [2dc40] идан_, भ्यः_, имак_, _rihö, 
   {{0xbcf800dd,0xf99c01e1,0x69dda8a5,0x69c80005}},	//   nkén, _ekè_, ppre, ídes, 
   {{0x201800a8,0x81c000cc,0xdbd402d2,0xbcf803df}},	//   ării_, ্ঠত_, _húðt, ikén, 
   {{0x317c009f,0x55f401c6,0x69c801e4,0x320400a2}},	//   jiuz_, ячуу, ŭdes, duny_, 
   {{0x29e9a8a6,0x3e4c00ac,0xbcf801d3,0x00000000}},	//   lşa_, rəti_, kkén, --, 
   {{0x623408bf,0x3e4c00ac,0x1cb80327,0x00000000}},	//   зеку, səti_, _མཛལ_, --, 
   {{0x8168006c,0xb9080882,0x29e83b33,0x3205a8a7}},	//   ириб_, taiḥ_, nşa_, guny_, 
   {{0x15b01e0e,0x6b9da8a8,0xf99c02e8,0xdcec4beb}},	//   _كەلس, horg, _xkè_, _imać, 
   {{0x6b9da8a9,0xb9080882,0x7f4802bf,0x00000000}},	//   korg, raiḥ_, аїна_, --, 
   {{0x6b9da8aa,0xbcf8b0c5,0x730000cf,0x29e88021}},	//   jorg, gkén, _опуз, kşa_, 
   {{0x6b9da8ab,0xf8bc0098,0xe80c1d15,0x51cc0220}},	//   dorg, _jaér_, िंडा_, _ﻗﺎﻳﺸ, 
   {{0x3d240212,0xe1680133,0x5bb4daf5,0x00000000}},	//   цьов, _دڵته_, ूद्व, --, 
   {{0xbcf800dd,0xf8bc7dec,0x44e001b9,0x00000000}},	//   bkén, _laér_, _mа_, --, 
   {{0xa3b0006d,0x44e0022e,0x90b001e0,0x00000000}},	//   _टीम_, _lа_, _яҙыш, --, 
   {{0x8db4036b,0x6ed8011a,0x29e80432,0x00000000}},	//   تشیچ, _דחופ, gşa_, --, 
   {{0xeec00150,0x61e80142,0x9bf402e8,0xaa5c01ec}},	//   _تيىپ, _mwdl, _езич, шесi, 
   {{0x7d180254,0x00000000,0x00000000,0x00000000}},	// [2dc50] õusu, --, --, --, 
   {{0x6b9cc5ec,0x29e800a2,0xe7842cdd,0x00000000}},	//   corg, bşa_, мухо, --, 
   {{0xcb1006a9,0x44e0022e,0x61e8015d,0x29e80356}},	//   _אלי_, _bа_, _nwdl, cşa_, 
   {{0xbcf9a8ac,0x33240007,0x1dbc00dc,0xa2d80303}},	//   chét, wenx_, ोदित, नुस्, 
   {{0x81c0000e,0xf7701411,0x44e001a9,0x61e80042}},	//   ্ঠা_, _قاس_, _dа_, _awdl, 
   {{0x26080490,0x00000000,0x00000000,0x00000000}},	//   ांशी_, --, --, --, 
   {{0xa5f8189b,0x33240036,0x1dbc00cd,0x00000000}},	//   _меру_, renx_, ोदात, --, 
   {{0x6b9da8ad,0x32043a5a,0x645c00ac,0x44e0022e}},	//   zorg, runy_, _əriz, _gа_, 
   {{0x317c0fac,0x78ac0208,0xbcf801d3,0x6aa800bc}},	//   riuz_, _jzcv, tkén, _गर्र, 
   {{0x317c009d,0x61e80142,0x7c2803b2,0x8e081188}},	//   siuz_, _fwdl, _ágry, бнов_, 
   {{0x6b9cf955,0x7d1c02d0,0xbcf801d3,0x00000000}},	//   vorg, _bbqs, rkén, --, 
   {{0xbcf9a8ae,0xf1a80244,0x00000000,0x00000000}},	//   skén, _ئائه_, --, --, 
   {{0x6b9da8af,0x160c06ab,0x00000000,0x00000000}},	//   torg, ांडर_, --, --, 
   {{0xaee0030c,0x2fdc0c6a,0x6b9c01f5,0x0054011a}},	//   _تۋدى, mpug_, uorg, _משנת_, 
   {{0x6b9da8b0,0xbcf820ef,0xae1c032c,0xbea00006}},	//   rorg, thét, _बहिन_, _пашк, 
   {{0xc4e40183,0x61fda8b1,0x6ac00154,0x7d180037}},	//   _পঞ্জ, _ærle, ্রলো, õust, 
   {{0x2bd804fb,0x6fdc01ad,0x44e001a9,0x7b0400e5}},	// [2dc60] _بابک_, पीचं, _rа_, árté, 
   {{0x683802d3,0x6b9c016d,0x29e9a8b2,0x00000000}},	//   _ብክርስ, qorg, pşa_, --, 
   {{0x1cb80003,0xbcf9a8b3,0x250801b9,0x00000000}},	//   _མཛོ_, phét, قرشی_, --, 
   {{0xe80c05d7,0xb8780022,0x7bc800c7,0x61e80042}},	//   िंदा_, _reív, _ũgui, _rwdl, 
   {{0x68e5a8b4,0x44e0036b,0x03a40139,0x00000000}},	//   mbid, _vа_, пидо, --, 
   {{0x27e07cba,0x68e40323,0xe5a400ee,0x00000000}},	//   mpin_, lbid, чиҗи, --, 
   {{0x27e1a8b5,0xa2d80a94,0x44e001b9,0xa195a8b6}},	//   lpin_, नुष्, _tа_, макч, 
   {{0x35a00323,0x68e5a8b7,0x27e1a8b8,0x00000000}},	//   _засг, nbid, opin_, --, 
   {{0x27e1a8b9,0x68e5a8ba,0x1cb8025c,0x23480405}},	//   npin_, ibid, _མཛེ_, _وسطی_, 
   {{0x9df9a8bb,0x94740014,0xdf7802bf,0xc0c001e0}},	//   онот_, _تھٔچ, ібні_, мәҙи, 
   {{0xdd9494f2,0x6441a8bc,0xbcf800f2,0x27e00076}},	//   даны, _hrmi, dhér, hpin_, 
   {{0x64409a4d,0x27e00280,0x160c1098,0x00000000}},	//   _krmi, kpin_, ांतर_, --, 
   {{0x68e4005c,0x69b00ce0,0x7f442bb6,0xd1c00092}},	//   dbid, ंतनी, _недж, _ሻለቃ_, 
   {{0x7ca40201,0xbcf84e01,0x27e00455,0xdb1c00a2}},	//   _ማድረግ_, thés, dpin_, _üzüp, 
   {{0x3f9da8bd,0x27e01c1d,0x798c03ac,0x2ee00165}},	//   motu_, epin_, _pjcw, ñjfe_, 
   {{0x3f9da8be,0x6441a8bf,0x68e5a8c0,0x6da407fa}},	//   lotu_, _ormi, gbid, _пија, 
   {{0xa2bc2366,0x27e00280,0xf8bc1bce,0x4b300345}},	// [2dc70] षेत्, gpin_, _mbég_, رکیس, 
   {{0xbcf9a8c1,0x3f9da8c2,0x68e42f0f,0xefb80023}},	//   chér, notu_, abid, _ሰለዚ_, 
   {{0x68e5a8c3,0x195801e8,0x6d4059c6,0xded402d3}},	//   bbid, _даны_, ômag, _ጨካን_, 
   {{0x3f9da8c4,0x644005b1,0x68e5a8c5,0x6595a8c6}},	//   hotu_, _brmi, cbid, наху, 
   {{0x3f9c0924,0xe4f401d5,0x98a80210,0x00000000}},	//   kotu_, رقوگ, ddać_, --, 
   {{0x644001a6,0x572400db,0xbcf802f0,0x0440117e}},	//   _drmi, _تىسك, dkém, тешн, 
   {{0x6440035a,0x2004011c,0x3f9da8c7,0x669400f3}},	//   _ermi, ermi_, dotu_, _зарђ, 
   {{0x799c0117,0x64400175,0xd17802d5,0xe5340006}},	//   noqw, _frmi, ўскі_, _песь, 
   {{0x1b040183,0xf2c5a8c8,0x3f9c7eb8,0x64400427}},	//   শ্যে_, _есен, fotu_, _grmi, 
   {{0xb87800e4,0x799c014b,0x68e4005a,0x752801d3}},	//   _heís, hoqw, zbid, legz, 
   {{0x5ec00c58,0x2005a8c9,0xa2a40c2e,0x140c146c}},	//   _শ্বে, armi_, _चुप्, _समुह_, 
   {{0x27e1a8ca,0x2fdc0de2,0xf8bca71d,0xc210011a}},	//   ypin_, ppug_, ्शाय, _יהב_, 
   {{0xbcf9a8cb,0xd054016b,0x00000000,0x00000000}},	//   thér, _ɛbɛs, --, --, 
   {{0x8e841b10,0xb8780789,0xe80c6c5a,0x68e4010a}},	//   _огле, _leís, िंसा_, wbid, 
   {{0xfaa1a8cc,0x2fc4138f,0xbcf86428,0x2fcda8cd}},	//   варо, _iing_, rhér, _hugg_, 
   {{0x140c06bc,0x2fc5a8ce,0x6839127d,0x68e5a8cf}},	//   _समूह_, _hing_, júdá, ubid, 
   {{0xbcf807ea,0x2fcc002e,0x2fc40c30,0x68e5a8d0}},	// [2dc80] phér, _jugg_, _king_, rbid, 
   {{0x27e02622,0x2fc40652,0x68e5a8d1,0x2fcd5d41}},	//   rpin_, _jing_, sbid, _mugg_, 
   {{0x2fc5a8d2,0x2d800652,0x2fcc3be7,0x06c400cc}},	//   _ming_, _kmie_, _lugg_, শুনি, 
   {{0xc4840c78,0x2fc5a8d3,0x27e03d25,0x6440020c}},	//   млек, _ling_, ppin_, _prmi, 
   {{0x2fcc002e,0xf48404fb,0x3f9c0694,0xd02400eb}},	//   _nugg_, واهی, yotu_, বিড়_, 
   {{0x2fc5a8d4,0x26d804e6,0x3f9c01c4,0xe214004e}},	//   _ning_, _ufro_, xotu_, емкы, 
   {{0xb8780077,0x2d800af9,0xf8bc01d3,0x00000000}},	//   _feís, _omie_, _ebéd_, --, 
   {{0x2fc43386,0x60f80801,0x2fcc01e3,0xd25001d3}},	//   _aing_, чния_, _bugg_, انٹ_, 
   {{0x2fc4bed5,0x6440a062,0x3f9d9531,0xbcf800f2}},	//   _bing_, _urmi, totu_, dhép, 
   {{0x2d81a8d5,0x2fcc1574,0x608c0020,0x2fc5a8d6}},	//   _amie_, _dugg_, _ዕድገት_, _cing_, 
   {{0x2fc5a8d7,0xbcf802fb,0x799c0784,0x8264007b}},	//   _ding_, ském, yoqw, _تهان, 
   {{0xdcec00df,0x2fc40036,0x3f9da8d8,0x61f80b4f}},	//   _klaĉ, _eing_, sotu_, msvl, 
   {{0xb87800dd,0x2fc5a8d9,0x61f8017a,0x00000000}},	//   _leír, _fing_, lsvl, --, 
   {{0x2fc5a8da,0x25a40175,0xcbb401ec,0x00000000}},	//   _ging_, _lkml_, нғыш_, --, 
   {{0xa2a40118,0x61f80f49,0xdef802dd,0x7c6400d1}},	//   _चुम्, nsvl, _дық_, ساڭل, 
   {{0x2fc5a8db,0x61f8017a,0xa3b000e1,0xd7c8007b}},	//   _zing_, isvl, _टीस_, كوره_, 
   {{0x61f8074d,0x57b4041b,0xdd9000f1,0x00000000}},	// [2dc90] hsvl, ебат, _ټوک_, --, 
   {{0xb8789411,0x7bdc0393,0x61f8017a,0x00000000}},	//   _seís, _itqu, ksvl, --, 
   {{0xfc3d19d6,0x368801c0,0xe450129e,0x00000000}},	//   lví_, цсан_, یضه_, --, 
   {{0x94d4d4de,0x799da8dc,0x61f80af9,0x98a80003}},	//   ходц, qoqw, dsvl, jjaħ_, 
   {{0x75282165,0x3949a8dd,0x61f8017a,0x773000c7}},	//   regz, _incs_, esvl, _иҭау, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdcec00df,0xd250821f,0x2fc593a7,0x61f80549}},	//   _elaĉ, انع_, _ring_, gsvl, 
   {{0x2fc413e1,0x3cf80034,0x7bdc022e,0x7c280142}},	//   _sing_, ्लों_, _otqu, _âgrw, 
   {{0x160c0574,0xdcec00df,0xf8bc0098,0x61f8017a}},	//   ांवर_, _glaĉ, _ubéd_, asvl, 
   {{0x2fc5a8de,0xa3d40d35,0xf8bc0241,0x2d81a8df}},	//   _qing_, _संत_, _gbée_, _smie_, 
   {{0x7bdcc51b,0x2fc531d2,0xfd1c07c5,0xe2500133}},	//   _atqu, _ving_, ffì_, _نێوخ, 
   {{0xc690008d,0x2fc4a458,0xbcf80306,0x2fcc007c}},	//   ראט_, _wing_, nkéh, _tugg_, 
   {{0x2fc55e50,0x6ac835a7,0x00000000,0x00000000}},	//   _ting_, लश्र, --, --, 
   {{0x2fc43386,0xdcec01e4,0x34c800dc,0x70dc012c}},	//   _uing_, _imaĝ, िशुद, _नभुल, 
   {{0xbcf80306,0x00000000,0x00000000,0x00000000}},	//   kkéh, --, --, --, 
   {{0xca8401c0,0xb87919d6,0x2d81a8e0,0x00000000}},	//   _үгий, _reír, _umie_, --, 
   {{0xcc34007b,0xbcf80306,0x00000000,0x00000000}},	// [2dca0] _أربع, dkéh, --, --, 
   {{0x61f8017a,0xa96800d1,0x850400f1,0xbcf80022}},	//   ysvl, чиға_, ځوان, ykék, 
   {{0x8504021a,0x63740208,0xf0cc01ec,0x00000000}},	//   فوان, _hàng, _өзiн_, --, 
   {{0xdcec010f,0xba7400f7,0x637401e1,0x87f8009d}},	//   _plaĉ, _ساپت, _kàng, _нэгт_, 
   {{0xca7c00d6,0xd90cdbb4,0x63741574,0xc76413ef}},	//   _zapа, _ذیل_, _jàng, _كاسى, 
   {{0xf8ac00dd,0x6375a8e1,0xdcec00e2,0x61f80b4f}},	//   _چکے_, _màng, _skaļ, tsvl, 
   {{0x63741bce,0xf41c005b,0xfc3c0118,0xd36c00d1}},	//   _làng, _ään_, zví_, غۇم_, 
   {{0xbcf80e96,0xa4f80014,0x61f80d47,0x6ec06fe9}},	//   ckéh, _آکار_, rsvl, रधनु, 
   {{0x63740de2,0x15b00131,0x91700208,0x00000000}},	//   _nàng, _ئەنس, _sợ_, --, 
   {{0x61f801a6,0x3204033f,0x671028d4,0xfbe0035b}},	//   psvl, brny_, ालिक_, қәиҭ, 
   {{0x00c9a8e2,0xbcf801c7,0xa3d411a6,0xf770011a}},	//   _елек_, lkéi, _सूत_, רקת_, 
   {{0xfc3c02f8,0x91700208,0x00000000,0x00000000}},	//   tví_, _vợ_, --, --, 
   {{0x3949a8e3,0x637542cd,0x00000000,0x00000000}},	//   _rncs_, _càng, --, --, 
   {{0xdcec031c,0x7bdc003a,0xbcf858bb,0x1ee80133}},	//   _klaċ, _vtqu, ikéi, _کوژی_, 
   {{0x3da40126,0xdd940124,0xaaa402a0,0x9e34011c}},	//   _приб, _иакы, _खुदक, _рейч, 
   {{0x637401e1,0x00000000,0x00000000,0x00000000}},	//   _hànd, --, --, --, 
   {{0x7bdc16b8,0x6375a8e4,0xa899a8e5,0x4f0801ec}},	// [2dcb0] _utqu, _gàng, екту_, _ءتۇپ_, 
   {{0xa3b007f7,0x00000000,0x00000000,0x00000000}},	//   _टील_, --, --, --, 
   {{0x63740694,0xbcf80030,0x39480208,0x2608a4cd}},	//   _mànd, tkéh, _tncs_, ांगी_, 
   {{0xd7f44132,0xf3f41cd1,0x320402fb,0xe3b82791}},	//   _измы, емдә_, vrny_, _ahı_, 
   {{0xbcf9a8e6,0x1b3402d3,0xa3d400e1,0xd4740395}},	//   gkéi, _ብምቕራ, _सूद_, ълдъ, 
   {{0xbcf80232,0x637400e8,0x320405da,0x662400db}},	//   skéh, _nànd, trny_, ئرەك, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x10a5a8e7,0x82d40166,0x00000000,0x00000000}},	//   кийн, ндәс_, --, --, 
   {{0xbcf80221,0x637400cf,0xb400d220,0x00000000}},	//   ckéi, _bànd, _сүлд, --, 
   {{0x7539a8e8,0x6375a8e9,0xb4bc66c0,0x00000000}},	//   _hauz, _cànd, ुखी_, --, 
   {{0x622404a9,0x7539a8ea,0xdcec031c,0x6375a8eb}},	//   _مىلل, _kauz, _glaċ, _sàng, 
   {{0x753801c0,0x228496da,0x98b80153,0x00000000}},	//   _jauz, _сууг, _nosį_, --, 
   {{0x7539a8ec,0xe0d01a57,0x4f941611,0xa2d817c6}},	//   _mauz, _ازم_, _ирку, नुक्, 
   {{0x7539a8ed,0x1e840220,0xb87800e4,0x00000000}},	//   _lauz, _өлім, _reíp, --, 
   {{0x0d200228,0x891400c7,0x37b400eb,0xee6c0116}},	//   _күнү, кьац, জদার, ﺷﻜﻪﻥ_, 
   {{0x75388a39,0x8d980014,0x63741bce,0xbcf800e4}},	//   _nauz, _تختس_, _tàng, ykéi, 
   {{0xf861a8ee,0x46f44727,0x4c3402d5,0x07a401c6}},	// [2dcc0] авто, вчет, _рэйт, ваан, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7538002f,0xb4a8032e,0x00000000,0x00000000}},	//   _bauz, _íþjó, --, --, 
   {{0x75380262,0x637400cf,0x29040022,0x4488011c}},	//   _cauz, _màne, _ÿma_, мбен_, 
   {{0x753801c0,0xf485a8ef,0x07f8007b,0x00000000}},	//   _dauz, پانی, _ترجع_, --, 
   {{0xbcf80a40,0xdcec025c,0x49080118,0x00000000}},	//   rkéi, _plaċ, िलको_, --, 
   {{0x75385dff,0x45355139,0x3d10012c,0xbcf80221}},	//   _fauz, _ихат, _थाले_, skéi, 
   {{0x673c246f,0x75380323,0x261c0998,0x00000000}},	//   _harj, _gauz, mío_, --, 
   {{0x34a5a8f0,0x83c40a89,0x65614ffd,0xd3440133}},	//   _авто_, _абаж, _iomh, _ڕیوه_, 
   {{0x673da8f1,0x63750232,0x6560047e,0x00000000}},	//   _jarj, _bàne, _homh, --, 
   {{0x65600928,0x3ea804ce,0x75380369,0x6374004e}},	//   _komh, æbt_, _yauz, _càne, 
   {{0x673da8f2,0x7538022e,0x308051ae,0x00000000}},	//   _larj, _xauz, الیف, --, 
   {{0x261c0077,0x656001ab,0x6375a8f3,0x8e80035b}},	//   hío_, _momh, _tànd, иҳәе, 
   {{0x65602935,0x673da8f4,0xfb85a8f5,0xdd900014}},	//   _lomh, _narj, тымн, _گوب_, 
   {{0x5ec000bd,0xdceda8f6,0x261c0789,0x63740248}},	//   _শ্রে, _hlač, jío_, _kànb, 
   {{0x65601928,0x261da8f7,0xdcec00ef,0xdd9006c2}},	//   _nomh, dío_, _klač, _دوب_, 
   {{0x69d9a8f8,0xa2a42e1e,0xeab000dd,0x75380166}},	// [2dcd0] _éven, _चुस्, معہ_, _rauz, 
   {{0x7539a8f9,0x261c30cf,0xf771a8fa,0x656001ab}},	//   _sauz, fío_, جار_, _aomh, 
   {{0x65601cdf,0x673c001f,0x37740124,0xe78800f1}},	//   _bomh, _darj, ныҧс, خپله_, 
   {{0x65603c76,0x673c000f,0x00000000,0x00000000}},	//   _comh, _earj, --, --, 
   {{0x6561a8fb,0x94243c8f,0xdb047dec,0x673c552a}},	//   _domh, умле, _akhé, _farj, 
   {{0x75384180,0x261c09c2,0x673cdb5f,0x8aa40166}},	//   _wauz, bío_, _garj, _шрөд, 
   {{0x261cb0eb,0x6560007b,0x25d801af,0xc0d00023}},	//   cío_, _fomh, _амсы_, ረጋስ_, 
   {{0xf2dc07ae,0xdcec009b,0x65600327,0x673c0219}},	//   _đâu_, _blač, _gomh, _zarj, 
   {{0x673c23db,0x5ec002f5,0x6374002e,0x658400a8}},	//   _yarj, _শ্লে, _sàne, _тырз, 
   {{0x260805ba,0x65600912,0xf8bc00e4,0x8fa406ed}},	//   ांची_, _zomh, _baéz_, ѓане, 
   {{0x6561a8fc,0x00000000,0x00000000,0x00000000}},	//   _yomh, --, --, --, 
   {{0x6458033f,0x8d54720d,0x2d8435b2,0xdde8030f}},	//   ścił, уточ, òme_, کریه_, 
   {{0xdcec28b5,0x49940fc0,0xbcf80022,0x00000000}},	//   _glač, ҳшат, ykév, --, 
   {{0x09bc0b7c,0x637400e8,0x00000000,0x00000000}},	//   ्द्य, _tàne, --, --, 
   {{0xaaa400e1,0x63740241,0xe5140037,0x00000000}},	//   _खुशक, _yànb, _डालि_, --, 
   {{0x261c0895,0x673da8fd,0xc76400d1,0x00000000}},	//   vío_, _sarj, گارى, --, 
   {{0x0b94f01a,0x65607ea1,0x673da8fe,0xc724247f}},	// [2dce0] _مجدد, _romh, _parj, лдай, 
   {{0xc764278f,0x6561a8ff,0x637405d5,0x9410013f}},	//   دارى, _somh, _mànc, _ɛbɔw_, 
   {{0x673da900,0x7ddc0418,0xc4e401ec,0x25a800ec}},	//   _varj, _tīse, гжей, نگري_, 
   {{0x261c09ff,0xc4d0015b,0x673cf32c,0x44f57ea9}},	//   río_, ার্জ, _warj, اساز, 
   {{0x673da901,0x261c0005,0x248000a3,0x00000000}},	//   _tarj, sío_, àim_, --, 
   {{0x65601cdf,0x261c04d4,0xf8b00ef6,0x1780014b}},	//   _womh, pío_, _دةپ_, _дҳум, 
   {{0xa3d4561f,0x6561a902,0xe7d82802,0xdcec0427}},	//   _सूर_, _tomh, _भूतप, _slač, 
   {{0xdceda903,0x637407c5,0x9f440109,0x98a80342}},	//   _plač, _bànc, mpmé_, ndağ_, 
   {{0x637435fb,0x79480139,0xa2a43b16,0xdef8031c}},	//   _cànc, _höwä, _चुर्, taċ_, 
   {{0x64a4005e,0x7de4005e,0xb46000fd,0xdcec0427}},	//   _баға, лімд, _укул, _vlač, 
   {{0xdeb40166,0xbcf800e8,0xaaa4012d,0x5274009b}},	//   рбны, kkét, _खुलक, _куцу, 
   {{0xdcec0e96,0x7e780112,0xbcf800e4,0x3194054e}},	//   _tlač, rztp, ijég, păza_, 
   {{0x63740de2,0x60187df2,0x9bd4003b,0x00000000}},	//   _gànc, _роля_, ржгі, --, 
   {{0xab846033,0xb07800df,0x00000000,0x00000000}},	//   буск, _אנדז, --, --, 
   {{0xb8780120,0xda3400c9,0xb7640220,0x998401e0}},	//   _ofíc, шевы, қтай, атаһ, 
   {{0x79a5a904,0x8e140244,0x4ea4003b,0x00000000}},	//   урге, _ئسوڵ, _тріа, --, 
   {{0x56f406ed,0x6374002e,0x5bb802e8,0xe80c230e}},	// [2dcf0] ипаѓ, _xànc, _илия_, िंगा_, 
   {{0xb87800e4,0x29040086,0x00000000,0x00000000}},	//   _afíc, _ôman_, --, --, 
   {{0x6dbc006d,0x9634177b,0xf645a905,0xbcf802f0}},	//   _właś, рнец, ыхан, dhéz, 
   {{0x4a58025f,0x57f4025c,0xd8940050,0xdcec01ef}},	//   _סדרו, _བསྭོ_, _نٔجد, _mlaď, 
   {{0xbcf801ed,0x3eada906,0xc4d003d4,0x00000000}},	//   lkés, _lyft_, াৰ্জ, --, 
   {{0x6374004e,0x2bf8011a,0x00000000,0x00000000}},	//   _rànc, נמון_, --, --, 
   {{0x637400db,0x7af4054e,0xe40c0118,0x00000000}},	//   _sànc, _mext, čkář, --, 
   {{0x637400cf,0xc3040154,0x00000000,0x00000000}},	//   _pànc, ল্লি_, --, --, 
   {{0x50b40354,0x00000000,0x00000000,0x00000000}},	//   шску, --, --, --, 
   {{0x7af5a907,0x00c4ea10,0x98a805d1,0xbcf80419}},	//   _next, шлык_, zdağ_, chéz, 
   {{0x113846e5,0x59b44f76,0xbcf800e4,0x00000000}},	//   _аялы_, ंतार, ykét, --, 
   {{0x2abc0248,0x8c4400d8,0x19d00116,0x00000000}},	//   _lábí_, аеме, _ﻛﺎﭘﺎ, --, 
   {{0x31d404c5,0x78ac0477,0x7af42b93,0x00000000}},	//   _সবিশ, _nycv, _bext, --, 
   {{0xdcec0003,0x3f6400d8,0xbcf800c7,0x00000000}},	//   _vjaġ, _вишо_, yjég, --, 
   {{0x7af5a908,0xdcec01e4,0xbcf82cda,0x97400092}},	//   _dext, _akaĵ, hhéy, _የማያስ, 
   {{0x6375a909,0x57f4031c,0x7d740228,0x6c6800e5}},	//   _màna, _བསྡོ_, _ۅمۉر_, _ملبہ_, 
   {{0x8d75a90a,0xd244208f,0x98a805d1,0x637401c3}},	// [2dd00] _ماکا, _کچ_, rdağ_, _làna, 
   {{0x7bf80a1e,0x27100118,0x00000000,0x00000000}},	//   _שפיצ, ालेर_, --, --, 
   {{0xb6f4049e,0x2abc0241,0x63740109,0xcc880244}},	//   شىنا_, _dábí_, _nàna, _سنگه_, 
   {{0x69dc0369,0x75c80220,0xbcf801d3,0x00000000}},	//   mqre, втің_, lkér, --, 
   {{0x7ddc0418,0xed6c00b7,0x00000000,0x00000000}},	//   _mīsa, _ትዊተር_, --, --, 
   {{0x69c5a90b,0x637408c2,0xa3189a41,0x7c2801b8}},	//   lmie, _bàna, ужку_, _ägre, 
   {{0x69dda90c,0x63740013,0x69c5a90d,0xe1e800db}},	//   nqre, _càna, omie, دىعو_, 
   {{0x69c40652,0x35a005f5,0x637401c3,0xb4600032}},	//   nmie, _дасг, _dàna, скәл, 
   {{0x29dc5793,0x69c40108,0xc0580212,0xdcec1155}},	//   _lía_, imie, тій_, _slaď, 
   {{0x69c43bbe,0x3f646897,0x29dc04d4,0x637401c3}},	//   hmie, ртиб, _oía_, _fàna, 
   {{0x637400e8,0xc10486bf,0x9d540214,0xdfd000ec}},	//   _gàna, _نواي, مندت, _کيت_, 
   {{0x7af5a90e,0xdd943c1f,0x69c45f0b,0xbd680108}},	//   _sext, самы, jmie, трое_, 
   {{0x69c40038,0x5f500023,0xfee401d5,0x00000000}},	//   dmie, _ክገልጸ, _кўйм, --, 
   {{0x69c5a90f,0x29dcf483,0xbcf801d3,0x78ac00b5}},	//   emie, _bía_, gkér, _rycv, 
   {{0x29dcf18c,0xddc80006,0x1cb80327,0x7af402d2}},	//   _cía_, mzdž, _མཛམ_, _vext, 
   {{0x29dd3316,0x69c40810,0x7af495e7,0x6da400f1}},	//   _día_, gmie, _wext, _وموم, 
   {{0x98b9a910,0xf770007b,0xbcf800e5,0x00000000}},	// [2dd10] улат_, ياط_, skés, --, 
   {{0x69c5a911,0xf6e5a912,0x29dd709d,0x78ac0306}},	//   amie, рцан, _fía_, _vycv, 
   {{0x0af00323,0x29dc004d,0xddc80024,0x2abc01ef}},	//   _хүсэ, _gía_, izdž, _vábí_, 
   {{0x63752207,0x19580006,0x69c4d75c,0x00000000}},	//   _ràna, _самы_, cmie, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x083800c8,0x65b800d7,0x00000000,0x00000000}},	//   _געשל, ríha, --, --, 
   {{0xa5f80108,0x9444431a,0x9f640419,0x00000000}},	//   _весу_, _گھان, ätým_, --, 
   {{0xd1b80f1b,0xf48418ac,0x00000000,0x00000000}},	//   داتا_, _кузн, --, --, 
   {{0x944401ed,0x2bbc1c15,0xbcf80124,0x00000000}},	//   _دھان, ोगमा, ykér, --, 
   {{0x63740851,0x69c5a913,0x7ddc00b8,0xa3d40401}},	//   _tàna, zmie, _sīsa, सआर_, 
   {{0x69c40598,0x63740248,0x0dc9a914,0xdcec0327}},	//   ymie, _kànn, ллой_, _xjaħ, 
   {{0x29dc172e,0xc6900375,0x6374002e,0x69c40399}},	//   _ría_, לאי_, _jànn, xmie, 
   {{0xd00892ec,0x6374002e,0xddc80024,0xbcf801d3}},	//   _селе_, _mànn, bzdž, tkér, 
   {{0xc0d00020,0x29dc0005,0x69d801ed,0x69c40003}},	//   ረዋል_, _pía_, _évek, wmie, 
   {{0x09e431de,0x3ea80122,0x69c5a915,0xa3d40cb4}},	//   собн, čité_, tmie, _सूई_, 
   {{0x29dc1280,0x69c4202a,0x8d7402f2,0x0ae801c6}},	//   _vía_, umie, _داتا, _өдий_, 
   {{0x6f000166,0xdcfc00ef,0x00000000,0x00000000}},	// [2dd20] _tíbı, ansē, --, --, 
   {{0x29dda916,0x69c5a917,0xbcf801d3,0x00000000}},	//   _tía_, smie, lkép, --, 
   {{0x63741574,0x7d742fc0,0x69c400e2,0x29dc02d2}},	//   _bànn, _ضمیر_, pmie, _uía_, 
   {{0x61fd6450,0x637492a7,0xbcf801ed,0xdcfc00f3}},	//   _ærli, _cànn, nkép, risć, 
   {{0x24583352,0x637401ab,0x69d800e4,0x00000000}},	//   раль_, _dànn, _ũveh, --, 
   {{0x0674d66f,0x37e1a918,0x5f1c1414,0x88bc00cc}},	//   _лубя, _хорг, _माध्_, _অলপক, 
   {{0x63741bce,0xbcf801ed,0x7800033f,0x7a4053ad}},	//   _fànn, kkép, _लि॑क_, mítá, 
   {{0x7a40066d,0x63741574,0x00000000,0x00000000}},	//   lítá, _gànn, --, --, 
   {{0xdec42295,0xb460022e,0x00000000,0x00000000}},	//   ቸውን_, _ектл, --, --, 
   {{0x7a4001ed,0xb698008e,0x00000000,0x00000000}},	//   nítá, _çäçe, --, --, 
   {{0x6375a919,0x98b80171,0x1d3400f5,0x00000000}},	//   _hàno, _masā_, оння, --, 
   {{0x6ce402dd,0x224c0200,0xbcf801d3,0xdb1402d2}},	//   зіре, _irdk_, gkép, _ábúa, 
   {{0xb879a91a,0x395c008f,0x7a4000dd,0x00000000}},	//   _afín, _ĵus_, kítá, --, 
   {{0xab84c43c,0x7a4001ed,0x2ff40276,0x23a807b7}},	//   пуск, jítá, _уншь_, गविद, 
   {{0x7de42303,0x7a4001d3,0xa2bc0a59,0x00000000}},	//   _استم, dítá, षेच्, --, 
   {{0xc0d0001f,0x98741064,0xb4d407f7,0x00000000}},	//   ረጋል_, олбц, _सले_, --, 
   {{0xa3d419e5,0xd7c801d5,0xf8bc00d8,0x69c8017a}},	// [2dd30] _संग_, لوره_, _tbém_, ïdea, 
   {{0x63740694,0x7a4001ed,0x5a3406ed,0x00000000}},	//   _sànn, gítá, _днот, --, 
   {{0x58d413f3,0xdb2401e2,0x00000000,0x00000000}},	//   _монт, _هوښی, --, --, 
   {{0xa3d4000d,0xa5f80063,0x00000000,0x00000000}},	//   _संख_, сецу_, --, --, 
   {{0x8508005e,0x637400cf,0x93580414,0xe87c15b7}},	//   рдің_, _càno, ирку_, müşü, 
   {{0x224c0098,0xe87c3535,0x63740de2,0x00000000}},	//   _brdk_, lüşü, _wànn, --, 
   {{0xbcf80c63,0x63740694,0xe3b007fc,0x2bbc0a59}},	//   ykép, _tànn, رره_, ोगता, 
   {{0x7ae00b21,0xe87c2fbe,0x00000000,0x00000000}},	//   _ûntf, nüşü, --, --, 
   {{0x77640218,0x63740248,0xf09c00cf,0x00000000}},	//   _kojx, _kànl, çà_, --, 
   {{0x69d807de,0xa2a41899,0x4e05a91b,0xa858011a}},	//   _èveg, _चुक्, озоб, מיחה_, 
   {{0x7bc44bc1,0xbcf801d3,0xe87c0205,0x220800ec}},	//   dmju, tkép, küşü, _هيلٿ_, 
   {{0x69d9a91c,0xfbec0118,0x7a4001d3,0x8d7400db}},	//   _évei, ěšné_, zítá, زاجا, 
   {{0x0ba834b1,0xbcf800dd,0x7a4001ed,0xe87c15b7}},	//   لاسى_, rkép, yítá, düşü, 
   {{0xbcf801ed,0xf8a40037,0xca7400c7,0xd1bc0092}},	//   skép, _कुइय, оубы, ቶዎች_, 
   {{0x7a4000dd,0x5a5400a7,0xbe1000db,0x98b807d7}},	//   vítá, пъту, _قووع, _rasā_, 
   {{0x5654001f,0x00000000,0x00000000,0x00000000}},	//   _የሚያጠ, --, --, --, 
   {{0x6d4403a2,0x7764036b,0x7a4001ed,0x41c800dc}},	// [2dd40] _iaia, _bojx, títá, ागतस, 
   {{0x6d45a91d,0x00000000,0x00000000,0x00000000}},	//   _haia, --, --, --, 
   {{0x6d4431ce,0x7a4001ed,0x5f1c0307,0x850400c6}},	//   _kaia, rítá, _मास्_, قوان, 
   {{0x7a40066d,0x6d45a91e,0x00000000,0x00000000}},	//   sítá, _jaia, --, --, 
   {{0x2901a91f,0x6d440323,0xa3d400e1,0x7a4001ed}},	//   maia_, _maia, _सूख_, pítá, 
   {{0x2901a920,0x68e4fdbe,0x6d45a921,0x490000bc}},	//   laia_, lcid, _laia, षणको_, 
   {{0xdec40020,0xf8bc0098,0x26d8151c,0x27e1a922}},	//   ቸውና_, _abéh_, _igro_, lqin_, 
   {{0x29008cae,0x68e58f48,0x6d45a923,0x25089b17}},	//   naia_, ncid, _naia, _درسی_, 
   {{0x7ddc03a0,0x3cf801e2,0x68e40077,0x7ae0000f}},	//   _pīso, _reqv_, icid, _ûntg, 
   {{0x4425a924,0x6441a925,0x2901a926,0x6d45a927}},	//   mto_, _ismi, haia_, _aaia, 
   {{0x4425a928,0x6d45a929,0x29011339,0xb8780085}},	//   lto_, _baia, kaia_, _afíl, 
   {{0x4425a92a,0x2901a92b,0xf1dc01ad,0xc0c9a92c}},	//   oto_, jaia_, _पंतन, _куле_, 
   {{0x2901a92d,0x98b80276,0xc09400e5,0x7f440fac}},	//   daia_, _masă_, _بجات, _медж, 
   {{0x4425a92e,0x6d440270,0x98b8084c,0x68e41d47}},	//   ito_, _eaia, _lasă_, ecid, 
   {{0x6d45a92f,0x4425a930,0x290004c9,0x8a78013e}},	//   _faia, hto_, faia_, бирӣ_, 
   {{0x4425a931,0x6d45a932,0x2901a933,0xa3cc0073}},	//   kto_, _gaia, gaia_, रगड_, 
   {{0x4425a934,0xe87c2c6f,0x6440063f,0x6da4038b}},	// [2dd50] jto_, rüşü, _nsmi, _تميم, 
   {{0x4425a935,0x65b80af2,0x6d44005a,0x68e40115}},	//   dto_, síhl, _zaia, acid, 
   {{0x6441a936,0x290068ba,0x6d4401f7,0xaee00055}},	//   _asmi, baia_, _yaia, _avṛk, 
   {{0x4425a937,0x29004fce,0x98b8084c,0x2004005f}},	//   fto_, caia_, _casă_, ksmi_, 
   {{0x4425a938,0xf99c0248,0x57f40327,0xe8240a0e}},	//   gto_, _ijè_, _བསྲོ_, _офро, 
   {{0x7ae00b21,0xf8bc00e5,0x70880248,0xd78803c7}},	//   _ûntd, _izé_, _ẹjó, _طنزو_, 
   {{0x4425a939,0x6441a93a,0x637401e1,0x65880174}},	//   ato_, _esmi, _gànm, ðshá, 
   {{0x4425a93b,0x637400e8,0x6a9c0a1e,0xe66401a9}},	//   bto_, _jànj, ישונ, _ўтро, 
   {{0x4425a93c,0x6d45a93d,0x998c0f91,0x31940356}},	//   cto_, _raia, čeň_, năzi_, 
   {{0x6d45a93e,0x2901a93f,0xb8801155,0x2de002dd}},	//   _saia, zaia_, mníč, _ﺍﻟﻭﺤ, 
   {{0x6d45a940,0xa3d48098,0xb88019b3,0x5f1c01ef}},	//   _paia, _सूट_, lníč, _मार्_, 
   {{0x27e0c56c,0xa2a4302b,0x68e4002e,0x1e940022}},	//   yqin_, _चुट्, xcid, ьрыр, 
   {{0x6d44096b,0xd7bc0490,0x2901a941,0x3f800270}},	//   _vaia, ्गाच, vaia_, ūkua_, 
   {{0x6d45a942,0xf99c0241,0x2901a943,0x8cc000dc}},	//   _waia, _ajè_, waia_, रेगो, 
   {{0x6d45a944,0x2901a945,0xf8bda946,0x4425a947}},	//   _taia, taia_, _azé_, zto_, 
   {{0x4425a948,0x6d440421,0xb8785cca,0x68e40067}},	//   yto_, _uaia, _efím, ucid, 
   {{0x2901a949,0x98b8054e,0x7d780375,0x2de00150}},	// [2dd60] raia_, _rasă_, _לנקו, _ﺍﻟﻠﺤ, 
   {{0x68e5a94a,0x2901a94b,0x0ba80e26,0x46a40801}},	//   scid, saia_, _داعى_, пазв, 
   {{0x29000751,0xc0e802d3,0x98b8054e,0x644001f4}},	//   paia_, _ዘድሊ_, _pasă_, _ssmi, 
   {{0x44243003,0x05640801,0x6375a94c,0x35a014a8}},	//   tto_, явен, _gànj, нахг, 
   {{0x27e1a94d,0x3e800248,0x37e001f0,0x98b80210}},	//   qqin_, _kété_, _пояг, _आरएए, 
   {{0x644000b5,0x637401e1,0x26d9a94e,0x47b400fe}},	//   _vsmi, _tànm, _ugro_, _অংকী, 
   {{0x7ae0045f,0x3e800100,0xbb3808a8,0xb778010f}},	//   _ûnte, _mété_, מעסי, _פאלש, 
   {{0x6375a8e4,0xf4845022,0xb8800306,0xf77c0135}},	//   _kànk, _کافی, bníč, ħħet_, 
   {{0x44240548,0x387c0209,0x63741bce,0x644109eb}},	//   qto_, _ýurt_, _jànk, _usmi, 
   {{0x43846cb6,0x3e800098,0x637400e8,0xb9580051}},	//   _علاق, _nété_, _mànk, _nhìn, 
   {{0x63740de2,0xf41c000d,0x37e000fe,0x00000000}},	//   _lànk, _äär_, _পিছৰ, --, 
   {{0x8c1805d9,0xdcec0841,0x515434da,0xdd5800c7}},	//   ڊيٽر_, _mlać, _отчу, цамч_, 
   {{0xfbd00014,0x3e800165,0x4f6405d9,0xdb1404e6}},	//   فتس_, _bété_, _ڪانف, llzé, 
   {{0xb9580208,0xdcfc0205,0x00000000,0x00000000}},	//   _chìn, ıyın, --, --, 
   {{0x3f8c0223,0xb8800306,0x98b8012d,0x00000000}},	//   _imfu_, zníč, _masą_, --, 
   {{0x3194084c,0x00000000,0x00000000,0x00000000}},	//   tăzi_, --, --, --, 
   {{0xa3cc4802,0x637400e8,0x3e80007f,0x2bbc1d68}},	// [2dd70] रगा_, _cànk, _fété_, ोगशा, 
   {{0xb88004bf,0xdcec28b5,0x31940311,0x3a300327}},	//   vníč, _blać, răzi_, _tpxp_, 
   {{0x7bdc006c,0xcb1006a9,0x2bbc000d,0x63740241}},	//   _huqu, _בלי_, ोगरा, _tànj, 
   {{0x7bdd23c9,0x7ae0045f,0x317c0369,0xb8800306}},	//   _kuqu, _ûntb, xhuz_, tníč, 
   {{0xf8bc019f,0x7bdda94f,0x5fac024a,0xf77000c6}},	//   _uzé_, _juqu, घकाल, _كاس_, 
   {{0x7bdda950,0xf36400fd,0xb8800122,0xdc3c0306}},	//   _muqu, ятен, rníč, _náčr, 
   {{0x7bdda951,0x7bd5a952,0x69d80120,0x317c009a}},	//   _luqu, _mixu, _évet, thuz_, 
   {{0x7bd4022f,0x7bdc02d0,0x4fe90c8d,0x3f80036e}},	//   _lixu, _ouqu, омин_, ëkun_, 
   {{0x7bdda953,0xbde402dd,0xcf3800d4,0x00000000}},	//   _nuqu, _ﺍﻟﻨﻔ, очні_, --, 
   {{0x8e09a954,0x73c0052f,0x317c0198,0x7bd40393}},	//   онов_, _яҡла, shuz_, _nixu, 
   {{0x63a4092e,0xd24c04d3,0xd1300597,0x7bdda955}},	//   éine, _ڕۆژ_, _لما_, _auqu, 
   {{0xfd1c011c,0x317c0007,0x320404ce,0x8d54005b}},	//   ggì_, qhuz_, msny_, фточ, 
   {{0x7bdda956,0x7bd40077,0x3e8006af,0xb9580208}},	//   _cuqu, _bixu, _pété_, _phìn, 
   {{0x7bd40005,0x6374004e,0x00000000,0x00000000}},	//   _cixu, _rànk, --, --, 
   {{0xfc3c011f,0x7bdc00d8,0x63741bce,0xdb1403b2}},	//   awí_, _euqu, _sànk, _ábýa, 
   {{0x7bd400cf,0x7bdd7cd1,0x8d7400be,0x00000000}},	//   _eixu, _fuqu, _زابا, --, 
   {{0x7bd5679d,0x7bdc4b2a,0xdcec009b,0x798c035a}},	// [2dd80] _fixu, _guqu, _slać, _dmcw, 
   {{0xdcec04b9,0x3204005c,0xca7401ec,0x00000000}},	//   _plać, ksny_, _жумы, --, 
   {{0x98b84632,0x00000000,0x00000000,0x00000000}},	//   _rasą_, --, --, --, 
   {{0x7bd48080,0x63741bce,0x7bdcfb5e,0x9694011c}},	//   _zixu, _tànk, _yuqu, хруш, 
   {{0x7bdda957,0x32e4002e,0xa248004b,0x98b800c0}},	//   _xuqu, _bёy_, ګیال_, _pasą_, 
   {{0x7bd4005a,0x777400b5,0x3dc80208,0x00000000}},	//   _xixu, ckxx, zmcw_, --, 
   {{0x63b802c4,0x69d801ed,0xc8bc0073,0xb3740092}},	//   rlvn, _éves, ्धवट, ሪሽያን_, 
   {{0x071c0c2e,0x637400cf,0x6ea800bc,0x397800df}},	//   _पाँव_, _màni, _घुइँ, ַטינ, 
   {{0x637400cf,0x03247428,0xc32400f3,0x00000000}},	//   _làni, _одан, _омак, --, 
   {{0x64a40046,0x7bdda958,0xdb200fac,0x6fb40137}},	//   _жаға, _ruqu, _åtøm, мгыр_, 
   {{0x7bdda959,0x7bd40309,0xfd1c04cc,0xde5801ca}},	//   _suqu, _rixu, tgì_, чані_, 
   {{0x7bd4f0ba,0x9be80135,0x7bdc0bf1,0x00000000}},	//   _sixu, _འཕྱོ, _puqu, --, 
   {{0x7bdda95a,0x071c05f9,0x7ddc0418,0x7bd4054e}},	//   _ququ, _पांव_, _mīsi, _pixu, 
   {{0x3f8c01f0,0x7bd4022f,0x7bdd47e6,0x32e4002e}},	//   _umfu_, _qixu, _vuqu, _xёy_, 
   {{0x3f9c021a,0x7bdc05b1,0xdd943e1f,0x7e8400bc}},	//   mntu_, _wuqu, _пакы, úspě, 
   {{0x7bdda95b,0x637401e1,0x6d400109,0x3f9c01e2}},	//   _tuqu, _dàni, ômat, lntu_, 
   {{0x9be83ae9,0xe894169c,0xb90444ab,0x3f9c0067}},	// [2dd90] _འཕྲོ, вать, _पल_, ontu_, 
   {{0x236c01f0,0x3f9c9573,0x00000000,0x00000000}},	//   _nodj_, nntu_, --, --, 
   {{0x151407d8,0xb60401fb,0x32e4002e,0x953800ee}},	//   едея, _giớ, _rёy_, ззет_, 
   {{0x798c4ec2,0xcdd8008f,0xb604031c,0x7ddc0171}},	//   _umcw, פֿער, _ruġġ, _cīsi, 
   {{0xb604038f,0xc9140302,0x799c00f1,0xf8c015e0}},	//   _suġġ, _אחרת_, mnqw, _शरिय, 
   {{0xb8780241,0x69d8cd11,0x3205a95c,0x69c80419}},	//   _agíg, _éver, tsny_, čmeň, 
   {{0xd6685dda,0xf5243169,0x00000000,0x00000000}},	//   _عمرو_, _офан, --, --, 
   {{0x3f9da95d,0x7ddc00da,0x32040af9,0x00000000}},	//   entu_, _mūsd, rsny_, --, 
   {{0x4f943f51,0x659501be,0x799c0472,0xf1dc0037}},	//   ерну, _рату, inqw, _पूरन, 
   {{0x0e65a95e,0x00800212,0x3205a95f,0xdb240248}},	//   екон, ульо, psny_, _ìpèd, 
   {{0xa3cc0c2e,0xc7b00302,0x00000000,0x00000000}},	//   रगर_, רבי_, --, --, 
   {{0xf2dc01dc,0x3f9da960,0x00000000,0x00000000}},	//   _đây_, antu_, --, --, 
   {{0x3f9c0083,0xfaa001f0,0x00000000,0x00000000}},	//   bntu_, ҳаро, --, --, 
   {{0xa51c00dc,0x63740137,0x799c0472,0x00000000}},	//   _पञ्च_, _pàni, enqw, --, 
   {{0xfaa1a961,0x57f40003,0x0d2000d1,0xfbc006ed}},	//   гаро, _བསྔོ_, _йүнү, убро, 
   {{0xbd0000d0,0x00000000,0x00000000,0x00000000}},	//   žérs, --, --, --, 
   {{0x2d800276,0x7d180005,0x47c5a962,0x98b8033f}},	// [2dda0] _ilie_, óuse, ебав, _kasę_, 
   {{0xdb0400d2,0x4a4400d6,0x6374004e,0x00000000}},	//   _mkhû, _знов, _tàni, --, 
   {{0xb8780248,0x7ae0002d,0x98b8fea4,0x4a740f15}},	//   _agíd, _ûnta, _masę_, _чыпт, 
   {{0x84e4063b,0x44a41870,0xf484a797,0xf77c0327}},	//   ходж, ىماق, کامی, ħħat_, 
   {{0x2d800093,0xe660723e,0x3f9c0067,0xbde40220}},	//   _mlie_, ırığ, yntu_, _ﺍﻟﻤﻔ, 
   {{0xa2941fe2,0x57bc00dc,0x48c001af,0xd3980166}},	//   калі, ्गृह, _аҙға, мәхә_, 
   {{0xdebc069c,0x2d81a963,0xe6b401d5,0xb87800d7}},	//   ተኾነ_, _olie_, _شلرگ, _egíd, 
   {{0xd1e0069c,0xf8bc0241,0xd6c406dc,0xb1a000ee}},	//   _ናብቲ_, _gbés_, _рисқ, лшык, 
   {{0x30102e5d,0xf77c010e,0x23e80214,0xd12c00f7}},	//   гдыр, _awçy_, _آذری_, تۅن_, 
   {{0x2d81a964,0x3f9c026c,0x1f7401e0,0x637401e1}},	//   _alie_, untu_, тлоя, _rànw, 
   {{0x9d182678,0x2d80007f,0xd50c0085,0x3f9c0194}},	//   монт_, _blie_, lɔ́t, rntu_, 
   {{0xdd95a965,0xdebc0023,0x00000000,0x00000000}},	//   тамы, ተኾኑ_, --, --, 
   {{0xd1e002d3,0x2d800165,0x80240acb,0xe7b0033f}},	//   _ናብታ_, _dlie_, _سرشم, जकाप, 
   {{0x2d81a966,0x5f940228,0x1fb804b4,0x7ddc0153}},	//   _elie_, _шилт, _юллы_, _pūsd, 
   {{0xba75a967,0xf9c5337d,0x2d8006f2,0x7ddc0024}},	//   راست, ещан, _flie_, _būse, 
   {{0xdd903345,0xf7709f6d,0x2d80011c,0xdc54009b}},	//   _خوب_, گار_, _glie_, _авињ, 
   {{0x57b416c3,0x6934084c,0x98b80454,0x00000000}},	// [2ddb0] вбат, ынту, флат_, --, 
   {{0xf771a968,0x69d80395,0x6da42220,0x81e4015b}},	//   دار_, _èven, nđan, _ভবন_, 
   {{0xd91400c7,0xf77c0205,0x00000000,0x00000000}},	//   _идны, _nuçe_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x57f4025c,0xa3cc07b7,0x7cd001ef,0x00000000}},	//   _བསྒོ_, रगं_, běrů, --, 
   {{0x7f480429,0xf6280212,0x39480142,0x41b01bf4}},	//   _nafq, _ніби_, _hacs_, یمور, 
   {{0x6b800036,0x00000000,0x00000000,0x00000000}},	//   ëmgi, --, --, --, 
   {{0x31400107,0xf1c40116,0x00000000,0x00000000}},	//   удиҳ, رۈشى_, --, --, 
   {{0x7ddc0270,0x27440020,0x290c013b,0xbcf80022}},	//   _mīsu, _የማህበ, _ɛda_, ajék, 
   {{0x3949a969,0xdcfc0093,0xbcf8003e,0x2d800076}},	//   _lacs_, kisē, bjék, _slie_, 
   {{0x2d81a96a,0x7f48022f,0x9f0401d3,0x00000000}},	//   _plie_, _dafq, دوپو, --, 
   {{0x50b40798,0x00000000,0x00000000,0x00000000}},	//   _ислу, --, --, --, 
   {{0x2fc400a3,0xecb40022,0x00000000,0x00000000}},	//   _thng_, ыӡкы, --, --, 
   {{0x6a7c0793,0x00000000,0x00000000,0x00000000}},	//   jäfö, --, --, --, 
   {{0x3949a96b,0x09e4036b,0x6f01a96c,0x2d81079d}},	//   _bacs_, тобн, _ienc, _tlie_, 
   {{0x2d819690,0x7ae0000f,0x3cb000b4,0x6f01a96d}},	//   _ulie_, _ûntn, ụzụ_, _henc, 
   {{0x3949a96e,0x637401e1,0xc1700375,0xc724010b}},	// [2ddc0] _dacs_, _kànt, בחן_, кдай, 
   {{0x6f0078e0,0x39480332,0xc7640116,0x00000000}},	//   _jenc, _eacs_, خارى, --, 
   {{0x6f01a96f,0x49c8152d,0xf74005b0,0x39480e9e}},	//   _menc, _олон_, рехо, _facs_, 
   {{0x6f01a970,0x00000000,0x00000000,0x00000000}},	//   _lenc, --, --, --, 
   {{0xd90c10e5,0x6fb00073,0x00000000,0x00000000}},	//   _ریل_, ुतां, --, --, 
   {{0x6f002747,0x07a41a5c,0x94a8210e,0x00000000}},	//   _nenc, _рагн, رانِ_, --, 
   {{0xd6c40131,0xa195a971,0x00000000,0x00000000}},	//   _бирқ, лакч, --, --, 
   {{0x32500801,0xc0c001e0,0x7f48013d,0xd2580006}},	//   рвър, һәҙи, _safq, эці_, 
   {{0xf9906da4,0x7ddc00de,0x72c00139,0x00000000}},	//   ירה_, _līst, лбәз, --, 
   {{0x6f01a972,0x7f4803be,0x80a410c4,0x637400cf}},	//   _cenc, _qafq, _یمان, _cànt, 
   {{0x6f001bce,0x826516af,0x7ddc00ef,0x00000000}},	//   _denc, _جهان, _nīst, --, 
   {{0x6f01a973,0xbba807af,0x00000000,0x00000000}},	//   _eenc, चक्क, --, --, 
   {{0x6f00f49a,0x7f48011f,0x9f3402dc,0x39480142}},	//   _fenc, _tafq, _белі, _racs_, 
   {{0x3949a974,0x7ddda975,0x637400e8,0x707400df}},	//   _sacs_, _sīsu, _gànt, _בײדע_, 
   {{0x9e34f0c0,0x3949a976,0x00000000,0x00000000}},	//   _сейч, _pacs_, --, --, 
   {{0x6f01a977,0x6da401a6,0x51cc01ec,0xae000116}},	//   _zenc, nđal, _ﺗﺎﻟﺸ, _ئويى, 
   {{0x6f01a978,0x77900214,0x37047696,0x7c8403f6}},	// [2ddd0] _yenc, لیحا, вчев, _шуке, 
   {{0x2b20012d,0x00000000,0x00000000,0x00000000}},	//   _बाएँ_, --, --, --, 
   {{0x1995a979,0x3949a97a,0x00000000,0x00000000}},	//   _баня, _tacs_, --, --, 
   {{0xe3b803e0,0x00000000,0x00000000,0x00000000}},	//   _akı_, --, --, --, 
   {{0x7c2da97b,0xf1c4022a,0x00000000,0x00000000}},	//   ntcr, ťáky_, --, --, 
   {{0x98a40124,0x66240137,0x00000000,0x00000000}},	//   _аиҭе, ارەك, --, --, 
   {{0x6f01a97c,0x7c2c01c7,0x637401e1,0xe79401af}},	//   _renc, htcr, _rànt, _тирњ, 
   {{0xdcec00df,0x659c0374,0x63740241,0x836000db}},	//   _plaĝ, tōhe, _sànt, _ۇگىل, 
   {{0x6f002831,0xb87800e4,0x9f9c03b2,0xd25001d3}},	//   _penc, _ifís, _mææn_, _گنا_, 
   {{0x00c438ce,0x205402e8,0x41b4004e,0x62240116}},	//   ылык_, ртър, ксөт, _چىلل, 
   {{0xd2503918,0x00000000,0x00000000,0x00000000}},	//   _دنا_, --, --, --, 
   {{0x22840228,0x7c2cbb91,0x63740694,0x6f01a97d}},	//   _тууг, ftcr, _wànt, _wenc, 
   {{0x6f01a97e,0x6375a97f,0xf8bc0306,0x00000000}},	//   _tenc, _tànt, _scén_, --, 
   {{0x7ae0045f,0x63740241,0x5f94008e,0x6f0003ac}},	//   _ûntl, _hànr, _кичт, _uenc, 
   {{0x637401e1,0xbcf8002e,0x4e0401d5,0x00000000}},	//   _kànr, jjéw, _ёзиб, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x07a40323,0x0c24036b,0x637401c3,0xd7f802bf}},	// [2dde0] гаан, _ёмон, _mànr, вує_, 
   {{0x7ddc00ef,0x27b40166,0x00000000,0x00000000}},	//   _tīst, рәмс, --, --, 
   {{0xd244cc47,0xf1d004af,0x00000000,0x00000000}},	//   _بچ_, दगान, --, --, 
   {{0xc485a980,0x05b86bcc,0x98f400c0,0x00000000}},	//   ллек, ردات_, _вярч, --, 
   {{0x7ddc00de,0x63a400e4,0x1ba800e5,0x15b000db}},	//   _mūsa, éino, _سایٹ_, زەكس, 
   {{0xdcec05d1,0x2bbc01f9,0x389800df,0x00000000}},	//   _olağ, ोगटा, _װילנ, --, 
   {{0xd36c04a9,0x6375a981,0x61e40115,0x00000000}},	//   بۇل_, _bànr, ĉilo, --, 
   {{0x07a4023b,0x34800166,0x00000000,0x00000000}},	//   _раҳн, ргәг, --, --, 
   {{0x656000c6,0xff041d82,0x6da4009b,0x27440092}},	//   _inmh, лянн, rđal, _የማሕበ, 
   {{0x5f954067,0xdcec0166,0x1e340006,0xe3b80166}},	//   риот, _blağ, аноў, _ukı_, 
   {{0x9e340724,0x593002d3,0xf8bc01d3,0xdd906640}},	//   шенч, _ኣማኑኤ, _acél_, قود_, 
   {{0x6375a982,0xffa001c0,0xf77c0240,0xf65400df}},	//   _gànr, рлүү, _muça_, אסטי_, 
   {{0x7ddc0064,0x00000000,0x00000000,0x00000000}},	//   _dūsa, --, --, --, 
   {{0xdfd09f43,0xf77c06ed,0xdcec0139,0x7c2c0072}},	//   _بيت_, _ouça_, _flağ, rtcr, 
   {{0xdd91a983,0x63748024,0x7ae0002d,0x79a4005b}},	//   _ووت_, _jànq, _ûntm, грае, 
   {{0x2e118398,0x81e403d4,0x7c2c0356,0x5c740229}},	//   _ابوح, _ভবা_, ptcr, _влит, 
   {{0xb8780248,0xf9b0016c,0x290c00ef,0x7ac40150}},	// [2ddf0] _afír, _ҳанӯ, _ēdat_, _әспе, 
   {{0x63a404c4,0x6561a984,0x76a81ade,0x5bc40139}},	//   éinl, _anmh, нтев_, _әйүб, 
   {{0xdced031e,0x939400e5,0xb6c401c4,0x00000000}},	//   _hlađ, یجتا, усай, --, 
   {{0x5455954f,0xdcec05ce,0x13dc146b,0x661813d5}},	//   ивет, _klađ, मद्भ, ávka, 
   {{0x5fb407f7,0x637401e1,0x24f8013d,0x00000000}},	//   ँवाल, _rànr, унчы_, --, 
   {{0xdcec04b9,0x63741bce,0xf8bc0241,0xbde40220}},	//   _mlađ, _bànq, _iyé_, _ﺍﻟﻁﻔ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb140023,0x85540014,0xc69005d0,0x50b42f5c}},	//   fozë, _پیٖر_, _ואל_, испу, 
   {{0x61f80660,0xf48401b9,0xe5702ed7,0x10a41436}},	//   apvl, _сувн, _عطف_, рипн, 
   {{0x659c02b5,0x64740137,0xcf585332,0xdcec0205}},	//   mōha, _угуу, трич_, _plağ, 
   {{0x8d65a985,0xf8bc0332,0x00000000,0x00000000}},	//   авне, _scél_, --, --, 
   {{0xf8bc0085,0x7ae00b21,0x909802e8,0x2d8485a0}},	//   _oyé_, _ûntj, _ивет_, óme_, 
   {{0xf8bc0af2,0x659c02b5,0xa928013a,0xbcf800c7}},	//   _nyé_, nōha, _ležá, yjév, 
   {{0x637400e8,0xc330008f,0xa0c40769,0x00000000}},	//   _yànq, ֿון_, _ايهو, --, 
   {{0xf8bc0570,0x49940354,0xa92800bc,0x7e943b98}},	//   _ayé_, ашат, _nežá, _پنير_, 
   {{0x8d740075,0x659c02b5,0x317c005a,0x7a28013d}},	//   _خاتا, kōha, nkuz_, _sötç, 
   {{0x8c444d0b,0xdcec2f61,0x7d7411e6,0x1cdc0327}},	// [2de00] _тепе, _glađ, _خمير_, རྨཱ_, 
   {{0xdcec0327,0xf77c0665,0x46f41553,0xfbdc017a}},	//   _imaġ, _puça_, рчат, svêr_, 
   {{0x6b9c0209,0x1b0001c0,0x69c800db,0xfb18010f}},	//   mirg, _хүсн, ïdes, _בוימ, 
   {{0x2bb409d9,0x63740137,0x6b9c510c,0x39840254}},	//   ंकवा, _rànq, lirg, _põse_, 
   {{0xfa00031c,0x5f1800dc,0x2454007b,0x2480027a}},	//   _མཆོན_, पणम्_, إنتس, áim_, 
   {{0x2480025c,0x00000000,0x00000000,0x00000000}},	//   ġim_, --, --, --, 
   {{0x320401c0,0x6da4009b,0x3664030d,0xb6a0022e}},	//   ахын_, rđaj, _каро_, _дирл, 
   {{0x6b9da986,0x7e7c0e78,0x125800e5,0x15b801af}},	//   hirg, _üppi, اثوں_, _быуы_, 
   {{0x6b9da987,0x3518011a,0x00000000,0x00000000}},	//   kirg, _שומנ, --, --, 
   {{0x1be01b87,0xdb14036e,0x6b9c022e,0x00000000}},	//   _गूगल_, rozë, jirg, --, 
   {{0x63b9a988,0xdcec1674,0x201802b5,0xfa000327}},	//   movn, _slađ, ōri_, _མཆེན_, 
   {{0x63b9a989,0x92c4037e,0xbf643346,0xf1d401ec}},	//   lovn, ptをo, ادکو, _ﺟﺎﻳﻘ, 
   {{0x7ae0045f,0xbfa80c75,0x5ff401b9,0x6b9c022e}},	//   _ûntk, _итке_, _узлу, firg, 
   {{0x61e82747,0xa3cc02ab,0x6b9da98a,0xf0a40116}},	//   _kudl, रगट_, girg, _әкәл_, 
   {{0x224da98b,0x6e90020f,0x00000000,0x00000000}},	//   _jsdk_, _мишу, --, --, 
   {{0x63b85d6c,0x61e9a98c,0xfe7401c0,0xf8bc007f}},	//   hovn, _mudl, _бүү_, _pyé_, 
   {{0x63b849ad,0x6b9da98d,0x3a2000b5,0xe61001e2}},	// [2de10] kovn, birg, sujp_, ېشه_, 
   {{0x63b80122,0xa8a40220,0x61e833d5,0x9f600166}},	//   jovn, іртк, _oudl, _üsär_, 
   {{0x61e9a98e,0x96345172,0xddd80118,0x7ddc00ef}},	//   _nudl, снец, _prvň, _jūso, 
   {{0xdb14007f,0x6e34010f,0x63740241,0x7ddc0171}},	//   wozè, שטאף_, _sànp, _mūso, 
   {{0x61e8003a,0xdcfc0153,0x637401e1,0xe570007b}},	//   _audl, sisė, _pànp, بطل_, 
   {{0x61e9a98f,0x63b8151c,0xf1dc2802,0xe3b81cb8}},	//   _budl, govn, _पूजन, абі_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x61e9a990,0x6b9c07d6,0xf3fc0798,0x659c0374}},	//   _dudl, zirg, _ção_, pōha, 
   {{0x7538337a,0x63b8f61c,0x317c005a,0x113802dd}},	//   _ibuz, bovn, rkuz_, _ұялы_, 
   {{0x63b80745,0x23740491,0x7ae00b21,0x317da991}},	//   covn, _والح, _ûnth, skuz_, 
   {{0x61e803f2,0xa91001e4,0xd05403b9,0xbcf800e4}},	//   _gudl, skɾi, _əbəs, yjét, 
   {{0xf77c0798,0x226400bc,0xb8780332,0x8c440150}},	//   _ouço_, ňská_, _ngío, беме, 
   {{0x75380161,0x6b9da992,0x61b019c5,0x61e801b9}},	//   _mbuz, tirg, _تەيا, _zudl, 
   {{0x61e80455,0x0054025d,0x3f80036e,0x389806be}},	//   _yudl, _לשנת_, ëkut_, _gцrə_, 
   {{0x7538b23d,0x6b9c01a8,0xbea02ff7,0x4df41887}},	//   _obuz, rirg, _нашк, _уялт, 
   {{0xfaa1a993,0x75380083,0x6b9c8f1e,0xf77c00d8}},	//   часо, _nbuz, sirg, _buço_, 
   {{0x8d75a994,0xf1dc2871,0x78ac003a,0x6b9c01b9}},	// [2de20] _ناکا, _पूछन, _cxcv, pirg, 
   {{0x7539a995,0x4b241feb,0x66180122,0x6b9c01d5}},	//   _abuz, _умов, ávko, qirg, 
   {{0x75380083,0x7b8401ec,0x63b80306,0x7bc800e4}},	//   _bbuz, _دايە, vovn, _ëgua, 
   {{0xd5b802bf,0x61e802f0,0x448800a8,0xdb15a996}},	//   асі_, _rudl, лбен_, vozé, 
   {{0x63b9a997,0x69c5a998,0x61e9a999,0x00000000}},	//   tovn, mlie, _sudl, --, 
   {{0x75381cdf,0x29000006,0x53e402bf,0x7ddc01e1}},	//   _ebuz, lbia_, іціа, _kàsì, 
   {{0x63b80745,0xf8bc0c6a,0x69c5a99a,0x2b9803b9}},	//   rovn, _acéh_, olie, _cücə_, 
   {{0x69c5a99b,0x2901a99c,0x659c00b0,0x61e9a99d}},	//   nlie, nbia_, mōho, _vudl, 
   {{0x61e8faba,0x290001f7,0xc48406d3,0x7ddc01e1}},	//   _wudl, ibia_, _улак, _làsì, 
   {{0x69c5a99e,0x61e8234f,0x4425a99f,0xb3800276}},	//   hlie, _tudl, muo_, _елул, 
   {{0xc10545d2,0x4425a9a0,0x69c5a9a1,0x7ae0002d}},	//   _هواي, luo_, klie, _ûnti, 
   {{0x69c5a9a2,0x9c88009d,0x1cd80108,0x00000000}},	//   jlie, ахгv, идны_, --, 
   {{0x69c5a9a3,0x659c02b5,0x00000000,0x00000000}},	//   dlie, hōho, --, --, 
   {{0x69c4017a,0x44240418,0x9b5801c6,0x290000c0}},	//   elie, iuo_, шигт_, ebia_, 
   {{0x4425a9a4,0x69c5a9a5,0x0f340276,0x00000000}},	//   huo_, flie, _фэчя, --, 
   {{0x69c5a9a6,0x4425a9a7,0xf9905019,0x64400221}},	//   glie, kuo_, سبز_, _opmi, 
   {{0x7d0c040b,0x4425a9a8,0xdcfc0024,0xe8049856}},	// [2de30] macs, juo_, nksč, शीला_, 
   {{0x3f9da9a9,0x7538026c,0x69c5a9aa,0x29000037}},	//   nitu_, _sbuz, alie, abia_, 
   {{0x69c5a9ab,0x2901a9ac,0xfa000003,0x6440005f}},	//   blie, bbia_, _མཆིན_, _apmi, 
   {{0x7d0c0a81,0x4425a9ad,0x3f9da9ae,0x94790af1}},	//   nacs, fuo_, hitu_, ислу_, 
   {{0x3f9da9af,0xd4681142,0x92c4015b,0x04b401e1}},	//   kitu_, риле_, _এলে_, _ìèlú_, 
   {{0x3f9c019b,0x799c0472,0x00000000,0x00000000}},	//   jitu_, liqw, --, --, 
   {{0x3f9da9b0,0x4425a9b1,0x1dc80574,0x7ddc0fda}},	//   ditu_, auo_, रतात, _pūsl, 
   {{0x75398e3b,0x4425a9b2,0x3f9c396f,0x7d0d080e}},	//   _ubuz, buo_, eitu_, jacs, 
   {{0x3f9da9b3,0x4425a9b4,0x24f80961,0x4fe800f0}},	//   fitu_, cuo_, _ынты_, јмон_, 
   {{0x3f9da9b5,0x69c40029,0x7ae00a85,0xddc80064}},	//   gitu_, zlie, _ûntw, gydž, 
   {{0x3f80145e,0xb2a8ee66,0x69c5a9b6,0x2900014b}},	//   êkua_, _стаж_, ylie, ybia_, 
   {{0x3f9da9b7,0x69c40007,0xe7d028fe,0x00000000}},	//   aitu_, xlie, _तीनप, --, 
   {{0xd00824ce,0x3f9da9b8,0x69c5a9b9,0x64400334}},	//   _теле_, bitu_, vlie, _xpmi, 
   {{0x3f9da9ba,0x7d0c0175,0x00000000,0x00000000}},	//   citu_, aacs, --, --, 
   {{0x69c5a9bb,0x44240521,0x7d0da9bc,0x499811db}},	//   tlie, zuo_, bacs, атая_, 
   {{0x69c5a9bd,0x44240066,0x0d84300e,0x290095bb}},	//   ulie, yuo_, _флин, ubia_, 
   {{0x92c4015b,0x7cd000b8,0x00000000,0x00000000}},	// [2de40] _এলো_, _cśrī, --, --, 
   {{0x69c5a9be,0x4424c887,0x2901a9bf,0xa8881669}},	//   slie, vuo_, sbia_, айға_, 
   {{0x69c5a9c0,0x7c4007f5,0xf8bc00e8,0x442402e3}},	//   plie, čvrš, _mbéy_, wuo_, 
   {{0x4425a9c1,0x3f9da9c2,0x69c4031c,0xae140118}},	//   tuo_, zitu_, qlie, _थिईन_, 
   {{0x24592a63,0xe2f96715,0x3f9da9c3,0x84800023}},	//   саль_, белі_, yitu_, _ጓይላን_, 
   {{0x44241a83,0xd7c40574,0x3f9c0bfa,0x7d0d7190}},	//   ruo_, वतःच, xitu_, zacs, 
   {{0x3f9da9c4,0x4425a9c5,0x66d00241,0x05840032}},	//   vitu_, suo_, _dókí, _һуҡм, 
   {{0x3f9da9c6,0x442483c6,0x98b80421,0x60f802e8}},	//   witu_, puo_, _gasē_, щния_, 
   {{0x4425a9c7,0x3f9da9c8,0x7d0d5352,0xbfa80108}},	//   quo_, titu_, vacs, итое_, 
   {{0xdfd00597,0xaac00d2b,0x814404d3,0x799c01e2}},	//   عيد_, _शुभक, _ژنان, ziqw, 
   {{0x3f9da9c9,0x7d0c4e82,0xddc80006,0x799c01e2}},	//   ritu_, tacs, rydž, yiqw, 
   {{0xc0580212,0x00000000,0x00000000,0x00000000}},	//   _вік_, --, --, --, 
   {{0x3f9da9ca,0x7d0c28be,0x6ce40220,0x00000000}},	//   pitu_, racs, діре, --, 
   {{0x3f9c0327,0x7d0c01e7,0x00000000,0x00000000}},	//   qitu_, sacs, --, --, 
   {{0xae140316,0x00000000,0x00000000,0x00000000}},	//   _थिएन_, --, --, --, 
   {{0x7cd0002b,0x66d800d7,0x00000000,0x00000000}},	//   _aśrū, _mäkč, --, --, 
   {{0xd7c80b24,0x575c0092,0xf7f400db,0x00000000}},	// [2de50] موره_, _ለማፍራ, تسزد, --, 
   {{0x799c01e2,0xa564004b,0x5a340108,0x00000000}},	//   siqw, ېدون, _енот, --, 
   {{0x6da40989,0x92c400cc,0x98b80171,0x27040154}},	//   rđav, _এল্_, _pasē_, _লাখো_, 
   {{0x7bc43615,0x799da9cb,0x00000000,0x00000000}},	//   llju, qiqw, --, --, 
   {{0x34480598,0xdb14012c,0x7bc403b2,0x00000000}},	//   рчен_, hozí, olju, --, 
   {{0x8ccc2a05,0x7bc491d7,0xb9d80092,0x31d000cd}},	//   _सरसो, nlju, _በሬ_, दग्ध, 
   {{0xb5a44f13,0xbcf800e4,0x00000000,0x00000000}},	//   _драй, yjép, --, --, 
   {{0x7ae0002d,0x0ed0033f,0xca28010f,0x00000000}},	//   _ûntu, _हरबड, צופֿ, --, 
   {{0x8fa43460,0x27600092,0x00000000,0x00000000}},	//   запе, _ለማህበ, --, --, 
   {{0x7bc55690,0xb310009f,0x00000000,0x00000000}},	//   jlju, _آٻاڻ, --, --, 
   {{0x2258005b,0x00000000,0x00000000,0x00000000}},	//   _мифы_, --, --, --, 
   {{0xb0dc00dc,0x00000000,0x00000000,0x00000000}},	//   _पृथग, --, --, --, 
   {{0x0ba80a52,0x7bc405be,0xbde40150,0x00000000}},	//   ماسى_, flju, _ﺍﻟﻜﻔ, --, 
   {{0x7bc401e3,0xcb6801f4,0x00000000,0x00000000}},	//   glju, щаге_, --, --, 
   {{0x629c01a8,0x00000000,0x00000000,0x00000000}},	//   _þrot, --, --, --, 
   {{0xa37c0115,0x7dcc026c,0xda1ccd66,0x00000000}},	//   _niĵn, rùsc, _फिरत_, --, 
   {{0x1dc806ab,0x88c41411,0x6cc801d9,0x00000000}},	// [2de60] रतरत, سترل, _گژھِ_, --, 
   {{0x7af4011c,0x7c2803cd,0x00000000,0x00000000}},	//   _gfxt, _ågra, --, --, 
   {{0xf6200e91,0xf1c8b305,0xaac012eb,0x00000000}},	//   едхо, ातान, _एडिक, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x04fc0154,0xa2d80073,0xc20400d8,0x00000000}},	//   ুলের_, मधल्, пџии, --, 
   {{0x6da401a6,0xe1d80006,0x00000000,0x00000000}},	//   nđas, одкі_, --, --, 
   {{0x7bc42630,0xdb1402f0,0x00000000,0x00000000}},	//   zlju, vozí, --, --, 
   {{0xc484022e,0xa4940244,0x00000000,0x00000000}},	//   _элак, _تیشت, --, --, 
   {{0x741000c6,0x7ddc00de,0x00000000,0x00000000}},	//   _أولا, _tūsk, --, --, 
   {{0x7bc404b9,0x00e4453f,0x63a40036,0xdec40092}},	//   vlju, _ежен, éinu, ሸፍን_, 
   {{0xdb1400d7,0x00000000,0x00000000,0x00000000}},	//   rozí, --, --, --, 
   {{0x9f340046,0x7bc59ff8,0x913000c7,0x7ddc0064}},	//   _желі, tlju, _рҭых, _jūsi, 
   {{0x629c0008,0xdb141f08,0x7bc4045f,0xafe001c6}},	//   _þros, pozí, ulju, _зочл, 
   {{0x7bc40267,0x7ddda9cc,0x00000000,0x00000000}},	//   rlju, _lūsi, --, --, 
   {{0x7bc401e3,0x00000000,0x00000000,0x00000000}},	//   slju, --, --, --, 
   {{0x7bc4098d,0x21000010,0xd7600133,0x00000000}},	// [2de70] plju, mčič_, پۆزی, --, 
   {{0x04fc015b,0xf77c0023,0x21000427,0xea000051}},	//   ুলোর_, _kuçi_, lčič_, _giắt_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x0595a9cd,0x7ddc1d64,0x210009a8,0xf77c0200}},	//   وانگ, _būsi, nčič_, _muçi_, 
   {{0xf99da9ce,0xf77c0200,0x5fac01f9,0x00000000}},	//   _imè_, _luçi_, टचाल, --, 
   {{0x7ae00a85,0x69d800a7,0x98a8107d,0x659403e6}},	//   _ûnts, _èver, ngač_, وجۆر, 
   {{0xc0dc0020,0x656c01a8,0x67d40107,0x66b4187f}},	//   ነዚህ_, ólhý, _чору, _збру, 
   {{0x63740100,0x21000010,0x47d000cc,0x00000000}},	//   _màny, jčič_, _থূপী, --, 
   {{0xe3ac02dd,0x7ddc139f,0x0fd800c7,0x00000000}},	//   _бұ_, _gūsi, жьны_, --, 
   {{0x63a5a9cf,0x4fc00131,0x0ea81507,0x6ce80150}},	//   éint, خەتە, жкой_, _ﺍﻏﺘﻴ, 
   {{0xf99c007f,0x00000000,0x00000000,0x00000000}},	//   _omè_, --, --, --, 
   {{0x8658008f,0xa1940354,0x00000000,0x00000000}},	//   קדרי, _пахч, --, --, 
   {{0x4f9400db,0x00000000,0x00000000,0x00000000}},	//   _орку, --, --, --, 
   {{0xf99c00db,0xf77c036e,0x00000000,0x00000000}},	//   _amè_, _fuçi_, --, --, 
   {{0x28e011b1,0xee8806ba,0x98b80064,0x00000000}},	//   पेनि, ﺗﻜﻪﻥ_, _kasė_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x98b80153,0x08c40150,0x00000000,0x00000000}},	// [2de80] _masė_, фбан, --, --, 
   {{0x7ddda9d0,0x659c04fe,0x788000d2,0xd1e4001f}},	//   _rūsi, mōhi, _sívú, _ማለቴ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x44a41f7a,0xdb1401d3,0x00000000,0x00000000}},	//   وماق, mozá, --, --, 
   {{0x7ae0045f,0x659c02b1,0x47e001e0,0xe2f838a9}},	//   _ûntr, nōhi, _аҙаҡ, пелі_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x133800dd,0xd3b800d4,0x00000000,0x00000000}},	//   ستوں_, чуці_, --, --, 
   {{0x7ddc0607,0x36200014,0x78ac0e3c,0xc85002d3}},	//   _tūsi, _جوٲہ, šivš, _ቅርሕን, 
   {{0xdb1428cb,0x63a5a9d1,0x21000219,0x00000000}},	//   hozá, éins, včič_, --, 
   {{0xdb1400dd,0x4425a9d2,0xf77c0200,0xc0280023}},	//   kozá, mro_, _puçi_, _ተቐቢለ, 
   {{0x78180037,0x00000000,0x00000000,0x00000000}},	//   _फट्क_, --, --, --, 
   {{0x00840276,0xdb1429e8,0xa6b00154,0x00000000}},	//   _олео, dozá, _করাট, --, 
   {{0xcfa804d3,0x21000219,0x6e0001d9,0x637401e1}},	//   _کانم_, rčič_, _یِون, _sàny, 
   {{0x442410b4,0xdb1400d7,0x00000000,0x00000000}},	//   iro_, fozá, --, --, 
   {{0x4425a9d3,0x0c706071,0xaa59a9d4,0x21000010}},	//   hro_, نگید, миру_, pčič_, 
   {{0xea00001e,0x5804007b,0x00000000,0x00000000}},	//   _giật_, فورك, --, --, 
   {{0x4425a9d5,0x68e000d2,0xf2c40154,0x260c1cd2}},	// [2de90] jro_, _úmdl, ষেপণ, डीसी_, 
   {{0x4425a9d6,0xf771a9d7,0xac8401f3,0xdb1400e5}},	//   dro_, خار_, ሮግራም_, bozá, 
   {{0x4425a9d8,0xf7705896,0x5ee0015b,0xb6c4014b}},	//   ero_, _یاس_, পুরে, фсай, 
   {{0x4425a9d9,0xf8bc00d7,0xfe04012d,0x00000000}},	//   fro_, _dcér_, वीएस_, --, 
   {{0x934544dc,0xe7081066,0x98b800c0,0x00000000}},	//   енле, ستەن_, _rasė_, --, 
   {{0xe4a40818,0x00000000,0x00000000,0x00000000}},	//   ърхо, --, --, --, 
   {{0x4425a9da,0x74100345,0x00000000,0x00000000}},	//   aro_, روژا, --, --, 
   {{0x3f8c009f,0x63a40332,0x00000000,0x00000000}},	//   _alfu_, éinr, --, --, 
   {{0x00c400a7,0x38900023,0x7ddc00de,0x93b40114}},	//   нлък_, _መመሊሱ_, _jūsu, _збац, 
   {{0x798c0857,0x64a40063,0xdb1401d3,0x9d000154}},	//   _llcw, _рађа, yozá, ্লোন_, 
   {{0xd13000c6,0x9f053016,0x00000000,0x00000000}},	//   _مما_, خوپو, --, --, 
   {{0x3f8c0451,0x659c02b1,0x8d5401f0,0x28e0190e}},	//   _elfu_, tōhi, хточ, पेडि, 
   {{0xa6b00183,0x00000000,0x00000000,0x00000000}},	//   _কৰাট, --, --, --, 
   {{0xdb1401d3,0x00000000,0x00000000,0x00000000}},	//   tozá, --, --, --, 
   {{0x44243d3c,0x00000000,0x00000000,0x00000000}},	//   zro_, --, --, --, 
   {{0x8d740a52,0x4425a9db,0xdb1428cb,0x48e402e8}},	//   _سابا, yro_, rozá, еобв, 
   {{0xa8b401c0,0x6d459331,0xb9580ca8,0x442400b5}},	// [2dea0] төнц, _ibia, _ikìl, xro_, 
   {{0x4425a9dc,0xdb1401d3,0x4a74004e,0xabcc0116}},	//   vro_, pozá, _зымт, ﯗﺭﻏﺎ, 
   {{0x4425a9dd,0x7ae0000f,0x21f8035b,0x798c03ac}},	//   wro_, _ûntp, _oĩha_, _flcw, 
   {{0x25a00e89,0x00000000,0x00000000,0x00000000}},	//   òil_, --, --, --, 
   {{0x4425a9de,0x5644001f,0x6d447b8f,0x00000000}},	//   uro_, _ከዋክብ, _mbia, --, 
   {{0x46a405f5,0x1300013e,0x00000000,0x00000000}},	//   _загв, иҷум, --, --, 
   {{0x6d440605,0x4425a9df,0x260c0073,0x7ddc00ef}},	//   _obia, sro_, डीशी_, _kūst, 
   {{0xd2580953,0x80040798,0x00000000,0x00000000}},	//   ьці_, нчое, --, --, 
   {{0xf9900302,0x3f8c0270,0x6da400e5,0x00000000}},	//   טרה_, _plfu_, tőan, --, 
   {{0x6d45a9e0,0x661c0b4b,0x389802e4,0x7ddc00ef}},	//   _abia, _kvrk, פיינ, _lūst, 
   {{0xdd943f3e,0xbcf8bc07,0x6d4401fa,0xfe41a9e1}},	//   ваны, ndég, _bbia, اکتی, 
   {{0xa1140150,0x00000000,0x00000000,0x00000000}},	//   _شوتت, --, --, --, 
   {{0x3f680b01,0x00000000,0x00000000,0x00000000}},	//   _нидо_, --, --, --, 
   {{0x6d45a9e2,0xf8d800cd,0x00000000,0x00000000}},	//   _ebia, _मृगय, --, --, 
   {{0x7ddc02d5,0xf8bc003e,0x1c1c007d,0xeef40375}},	//   _būst, _acép_, _भटकल_, _אמור_, 
   {{0x62980bb8,0x6d440076,0x97c4036b,0x00000000}},	//   izvo, _gbia, چقرو, --, 
   {{0xe895a9e3,0x798c035a,0x7ddc00c0,0xb4ac000d}},	// [2deb0] гать, _vlcw, _dūst, _ओखे_, 
   {{0x7c2da9e4,0x7580036b,0x43c800dc,0x00000000}},	//   mucr, گیرم, ितोऽ, --, 
   {{0x7c2da9e5,0x4ca400cc,0xbadc00cc,0x00000000}},	//   lucr, _গুপু, _ব্ৰঞ, --, 
   {{0x24f812c4,0x236c00f3,0x6298004c,0x659c02b1}},	//   енцы_, _andj_, dzvo, kōhu, 
   {{0xf77c05d1,0xdcec00d0,0xa4d40212,0x38c8004e}},	//   _suçu_, _omaľ, гоці, _хунн_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x106806b3,0x7c2c0098,0xe2a8007b,0x00000000}},	//   диий_, kucr, عاون_, --, 
   {{0x6595a9e6,0x661c107d,0xe7b802e5,0x4f941d39}},	//   _сату, _zvrk, _आदमप, врну, 
   {{0x6d45a9e7,0x0e647df9,0xe448007b,0xa354179e}},	//   _sbia, вкон, _سلمى_, _مخمص, 
   {{0x2b5003be,0x6d440076,0x2c1408a3,0x00000000}},	//   _öncə_, _pbia, तीनं_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfe3400b5,0x81400228,0x7ddc00c0,0x00000000}},	//   _eク_, _ئچىن, _rūst, --, 
   {{0x680801e1,0x8fa40a4a,0xfc00117e,0x00000000}},	//   _léjò, _шале, рпро, --, 
   {{0xc3301203,0x9e65a9e8,0x6d4403a2,0x8ccc07f7}},	//   יום_, _ماين, _tbia, _सरको, 
   {{0x7b1c013d,0x00000000,0x00000000,0x00000000}},	//   _açuı, --, --, --, 
   {{0x2bb40a8a,0x00000000,0x00000000,0x00000000}},	// [2dec0] ूकदा, --, --, --, 
   {{0x78a80579,0x2d801368,0xb6040051,0x00000000}},	//   úgva, _hoie_, _thớ, --, 
   {{0x65b400c7,0x00000000,0x00000000,0x00000000}},	//   гӡат, --, --, --, 
   {{0xd6241564,0x2d81a9e9,0xc484a40e,0x00000000}},	//   اعلي, _joie_, клек, --, 
   {{0x87e40131,0x2d8004e6,0x69c5a9ea,0x00000000}},	//   _аһаң_, _moie_, moie, --, 
   {{0x661c0841,0x02691a75,0x2c1400dc,0x69c5a9eb}},	//   _tvrk, дший_, तीयं_, loie, 
   {{0xa6e009bd,0xa2440372,0x2d8005e4,0x46a5a9ec}},	//   _প্রয়, ارتۇ, _ooie_, _равв, 
   {{0x2fc5a9ed,0x69c5a9ee,0xb280034a,0x2d817a02}},	//   _akng_, noie, рышк, _noie_, 
   {{0xbcf9a9ef,0x30100588,0xc058109a,0x00000000}},	//   ndée, адыр, фій_, --, 
   {{0x83684d1c,0x2d8006c8,0x69c4005a,0x3f65208f}},	//   _تصرف_, _aoie_, hoie, ттиб, 
   {{0xf8bda9f0,0x2d8150e6,0x69c4da12,0x00000000}},	//   _idée_, _boie_, koie, --, 
   {{0x398400c5,0xdd940032,0x659c00b0,0x6dc40138}},	//   _tõsi_, уамы, pōhu, исяж, 
   {{0x21f8003e,0x69c497c7,0xfb8001b9,0xada40006}},	//   _héh_, doie, لگدی, раўл, 
   {{0x69c40a73,0x21f8003e,0xbcf80de2,0xcbb402dd}},	//   eoie, _kéh_, ddée, лғыш_, 
   {{0x7c2da9f1,0x57b42c1d,0x2d8037a7,0x28e002ab}},	//   sucr, ҳбат, _foie_, पेसि, 
   {{0x21f9a9f2,0x69c401c0,0x99840efc,0xe9b40212}},	//   _méh_, goie, دلرو, абсь, 
   {{0xb87801e1,0x17ec00af,0x998401d3,0x2db80a7c}},	// [2ded0] _agír, जदेव_, élő_, _שלחן_, 
   {{0xb8d80d62,0xf8bc0022,0xd7581867,0x0af001c6}},	//   _अख_, _ndée_, علات_, _гүрэ, 
   {{0x9b940588,0xfc3d0ca1,0x21f800d8,0x69c404e6}},	//   _аиҿц, ltí_, _néh_, boie, 
   {{0xfc3c0548,0xe50800f1,0x00000000,0x00000000}},	//   otí_, نيمو_, --, --, 
   {{0xfc3da9f3,0x21f800d5,0xe53448bd,0xb4b000d1}},	//   ntí_, _aéh_, речь, шидә, 
   {{0x21f800d5,0xe785a9f4,0x29f80219,0x889802e4}},	//   _béh_, _кусо, _očal_, _טברי, 
   {{0xfc3c011f,0x75800133,0x6b7c0375,0x569490ad}},	//   htí_, _پیشم, ורגנ, _савт, 
   {{0x2fc405b1,0xfc3c013a,0x00000000,0x00000000}},	//   _skng_, ktí_, --, --, 
   {{0x2d800731,0x6ac019cc,0x835001d3,0x4fe9a9f5}},	//   _roie_, _एड्र, _گھنا, нмин_, 
   {{0x2d81a9f6,0x69c5a9f7,0x8e080354,0xfc3c01e7}},	//   _soie_, zoie, ннов_, dtí_, 
   {{0x21f80098,0x69c401f7,0xf2c42095,0x41b02d56}},	//   _géh_, yoie, _рсан, شمیر, 
   {{0xfc3c011f,0x69c4005a,0x4c3401c6,0x00000000}},	//   ftí_, xoie, лэгт, --, 
   {{0x2d81a9f8,0x69c5a9f9,0x2fc4003e,0xfc3c00ae}},	//   _voie_, voie, _tkng_, gtí_, 
   {{0xe0d0d7a1,0x21f8003e,0x2d800076,0x00000000}},	//   _بزم_, _yéh_, _woie_, --, 
   {{0x69c5a9fa,0x2d800076,0xfc3c00d7,0x78a803b2}},	//   toie, _toie_, atí_, úgvn, 
   {{0xfc3c0429,0x80a80037,0x00000000,0x00000000}},	//   btí_, _जइमे, --, --, 
   {{0x69c5a9fb,0xfc3c004e,0x597429a3,0x00000000}},	// [2dee0] roie, ctí_, шыру, --, 
   {{0xd1e40020,0xbcf8529d,0x69c401c4,0x1e30001f}},	//   _ማወቅ_, rdée, soie, _በተጠና, 
   {{0xe3a4f061,0x7d7400aa,0x452898cc,0x80a84721}},	//   یشتی, _شمیر_, ежен_, _जेने, 
   {{0xc5149ce2,0x49b99e99,0x21f80098,0xd5d40006}},	//   ابات, _ساجد_, _réh_, аючы, 
   {{0xa2941e38,0x21f80098,0x233800ee,0x28e0166d}},	//   ውያንን_, _séh_, вплы_, पेशि, 
   {{0xea00001e,0x44b001ec,0x07a41a5c,0x00000000}},	//   _ngẫu_, _құлс, _сагн, --, 
   {{0xbcf80129,0x965402e8,0x3240007b,0xfaf40677}},	//   ndéc, _кътч, منوف, נצקי_, 
   {{0xfc3da9fc,0x71f400c6,0x325002e8,0x00000000}},	//   ytí_, دروس_, свър, --, 
   {{0xbfa93495,0x35180375,0x0108004b,0x21f800d5}},	//   етне_, _רומנ, وتکو_, _wéh_, 
   {{0x21f8ebf1,0x7c2803cd,0x2d843bba,0xe5a401b9}},	//   _téh_, _ågri, ömen_, _сиғи, 
   {{0xbf640066,0x00000000,0x00000000,0x00000000}},	//   ندگو, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdcec025c,0x71d4011a,0xfc3c0118,0x00000000}},	//   _inaċ, _עודד_, utí_, --, 
   {{0xbe841f84,0xfc3da9fd,0x7ac40334,0x00000000}},	//   _مجبو, rtí_, гсбе, --, 
   {{0xfc3d8051,0x0ef802d5,0x973401d3,0xdd9400fb}},	//   stí_, _рэчы_, یکسا, _вайы, 
   {{0x6e0001c8,0x00000000,0x00000000,0x00000000}},	//   _اِين, --, --, --, 
   {{0xee9003e6,0xf728084c,0xd7c80472,0x80a80ce0}},	// [2def0] _نگێک, ецей_, نوره_, _जेमे, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb878ada8,0x7bc5a9fe,0x00000000,0x00000000}},	//   _egíp, moju, --, --, 
   {{0x7bc5a9ff,0x29f807f5,0x00000000,0x00000000}},	//   loju, _očaj_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7bc4a7df,0x81c000e2,0x3984000d,0xd79402e8}},	//   noju, žēlo, _võsu_, _тигъ, 
   {{0x5275aa00,0x00000000,0x00000000,0x00000000}},	//   рулу, --, --, --, 
   {{0xd18405f5,0x940428fa,0xb2b000d1,0xd024074d}},	//   рлий, _نوره, _қәлъ, амий, 
   {{0x7bc4f95a,0x2e30001f,0xa4d40212,0x224c03e0}},	//   koju, _በተያዘ, _готі, _epdk_, 
   {{0x20540801,0xe04821ec,0x4fa406ed,0xe4a401af}},	//   стър, اشيه_, риов, _урсо, 
   {{0x7bc5aa01,0x00000000,0x00000000,0x00000000}},	//   doju, --, --, --, 
   {{0x0ba80372,0xfe6c03e6,0x7de401c6,0x00000000}},	//   چاسى_, بگه_, имэг_, --, 
   {{0x0ba834b1,0x7bc40254,0xd478010f,0x00000000}},	//   ناسى_, foju, דאָל, --, 
   {{0x7bc5aa02,0x8a0400f7,0x00000000,0x00000000}},	//   goju, изге, --, --, 
   {{0xbea1aa03,0xd04801e4,0xadec0037,0xdbd0010e}},	//   _машк, nceɾ, _घंटन_, dýäl, 
   {{0x0904f081,0xdc341d55,0x7e7c00e8,0x00000000}},	//   рпан, _zúčt, _àppa, --, 
   {{0x7bc5aa04,0x46f505ec,0xf860005a,0xd7f800d4}},	// [2df00] boju, ачет, овто, гує_, 
   {{0x753800a8,0x7bc400de,0x00000000,0x00000000}},	//   _acuz, coju, --, --, 
   {{0x850465dc,0x00000000,0x00000000,0x00000000}},	//   لوان, --, --, --, 
   {{0x3ab8011a,0x25080066,0x00000000,0x00000000}},	//   _ימינ, ارضی_, --, --, 
   {{0xbcf94938,0x7410007b,0x00000000,0x00000000}},	//   ndéa, قونا, --, --, 
   {{0x2901aa05,0xbcf80597,0x753802d0,0x00000000}},	//   lcia_, idéa, _ecuz, --, 
   {{0x96b84cef,0x969000e5,0x00000000,0x00000000}},	//   _буту_, _ٹینش, --, --, 
   {{0x07a41ee3,0x7bc5aa06,0x31640022,0xdc340419}},	//   _саҳн, zoju, ашьо_, _súčt, 
   {{0x7bc55d86,0x290009d7,0x15b9aa07,0x67440023}},	//   yoju, icia_, _сыры_, _ከማዕብ, 
   {{0x6561aa08,0x244002bd,0x80a80073,0x00000000}},	//   _hamh, mòm_, _जेणे, --, 
   {{0x2901aa09,0x24400699,0x65611119,0x7bc41039}},	//   kcia_, lòm_, _kamh, voju, 
   {{0x6561aa0a,0x29000030,0xffa001c0,0x00000000}},	//   _jamh, jcia_, слүү, --, 
   {{0x7bc5aa0b,0x6561aa0c,0x24403c51,0x290000d0}},	//   toju, _mamh, nòm_, dcia_, 
   {{0x2901aa0d,0x6561aa0e,0x9f040b8a,0x3e680139}},	//   ecia_, _lamh, _اوغو, _ашин_, 
   {{0xdcec04b9,0x79a5aa0f,0x7bc5aa10,0x69c02625}},	//   _inač, арае, roju, čmen, 
   {{0x6561aa11,0x6da407b5,0x5ef803d4,0xdcec00d0}},	//   _namh, _мија, _আজিও_, _hnač, 
   {{0xd7f1aa12,0x2d8c013b,0x7bc5aa13,0x36e800d1}},	// [2df10] سكا_, ɔde_, poju, چراپ_, 
   {{0x7539aa14,0x3705aa15,0xa775aa16,0x3689aa17}},	//   _scuz, рчав, олуч, ксен_, 
   {{0x65603917,0xbd9802d3,0xcb540375,0x2900012d}},	//   _bamh, _ሂወቶም_, _הסתה_, bcia_, 
   {{0x29004ef6,0x656065e7,0xfbdc0b21,0x244002bd}},	//   ccia_, _camh, stêd_, fòm_, 
   {{0x6561aa18,0x24400086,0x0b2c0092,0x00000000}},	//   _damh, gòm_, _እምብዛ, --, 
   {{0x5724104b,0x65603a77,0xb4c41b87,0x7c2c02d0}},	//   _دىسك, _eamh, _उडी_, ircr, 
   {{0xd6e403f4,0x656001c3,0x63a80175,0xa2c409ab}},	//   _প্রয, _famh, _dmdn, ाअष्, 
   {{0x6561aa19,0x75381ae4,0x5154fc32,0x244002e2}},	//   _gamh, _ucuz, стку, bòm_, 
   {{0x2440180f,0x10a40353,0x91680208,0xe3ac01ec}},	//   còm_, сипн, _cứu_, _жұ_, 
   {{0x65600117,0x00000000,0x00000000,0x00000000}},	//   _zamh, --, --, --, 
   {{0x6561aa1a,0x29000034,0x838801b9,0x17b403d4}},	//   _yamh, ycia_, _ёруғ_, _জীৱি, 
   {{0xdcec0219,0xd6d800eb,0x00000000,0x00000000}},	//   _enač, _তলায, --, --, 
   {{0x7e6823f5,0x00000000,0x00000000,0x00000000}},	//   _erfp, --, --, --, 
   {{0x394800d8,0xdb040142,0x00000000,0x00000000}},	//   _abcs_, _ymhé, --, --, 
   {{0xf8bd0e96,0xb44c02d3,0xbcf801c7,0x244002bd}},	//   _axé_, _ማርሴሉ, mdén, zòm_, 
   {{0x98b80139,0x29000561,0xbcf801c7,0x244002bd}},	//   _ansı_, ucia_, ldén, yòm_, 
   {{0x4ca403f4,0x6561aa1b,0x2e200790,0x06f4007b}},	// [2df20] _গুরু, _ramh, lıf_, مساج, 
   {{0x29004ef6,0x6561aa1c,0xbcf82508,0x86988f8c}},	//   scia_, _samh, ndén, лтет_, 
   {{0x2e200365,0x65600433,0x290056ef,0xbcf8003e}},	//   nıf_, _pamh, pcia_, idén, 
   {{0x631400bd,0xf8bc01ed,0x65600477,0x24401f3f}},	//   _সাইট_, _idén_, _qamh, tòm_, 
   {{0x656144a9,0x260c007d,0x6fc492c2,0x09bc00cc}},	//   _vamh, डीजी_, रकां, _আঠপা, 
   {{0x65605b12,0x2e2005d1,0x3408004b,0x6e20005c}},	//   _wamh, kıf_, ارنۍ_, _ovnb, 
   {{0x80a8007d,0x161001ad,0x24400100,0x00000000}},	//   _जइहे, डीआर_, sòm_, --, 
   {{0x656014d0,0x60f80801,0x317c031c,0x91d400ce}},	//   _uamh, шния_, gjuz_, _डीआई, 
   {{0xdee80092,0x00000000,0x00000000,0x00000000}},	//   ዚያን_, --, --, --, 
   {{0x63a42a28,0x61fc0098,0x45a000db,0x6d4002e2}},	//   ëind, _érlo, _بەچك, òman, 
   {{0x82640fba,0x7de40220,0x260c0073,0x7d1803b2}},	//   _دهان, йімд, डीची_, ðuso, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf8bc0098,0xceb40184,0x7d0c0175,0x00000000}},	//   _adén_, йҙә_, rbcs, --, 
   {{0x51f401ec,0xe9240327,0x00000000,0x00000000}},	//   _اسەر, _འཇུབ_, --, --, 
   {{0x39480334,0x998401e0,0x7e280d30,0xb95801e1}},	//   _pbcs_, отаһ, _сіла_, _okìt, 
   {{0x02b4000d,0x00000000,0x00000000,0x00000000}},	//   _अखैन, --, --, --, 
   {{0xf8bc0407,0xdcec0327,0xbc2411dc,0x6f00010a}},	// [2df30] _edén_, _flaġ, _اربى, _yfnc, 
   {{0x3c90023b,0x317c0327,0x00000000,0x00000000}},	//   _миқё, zjuz_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9b4400dd,0xaee0002b,0xfd1c0109,0x2e38008f}},	//   _انھو, _agṛh, naì_, רגאנ, 
   {{0x5eac0154,0x69b80fe6,0x34a87b8f,0x00000000}},	//   _ঘুমে, ्करी, دداً_, --, 
   {{0x2e2005d1,0x00000000,0x00000000,0x00000000}},	//   yıf_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x1bf802ab,0xe5b401ee,0x00000000,0x00000000}},	//   ंदाल_, _ейсы, --, --, 
   {{0xbcf801c7,0x317c0327,0x00000000,0x00000000}},	//   tdén, rjuz_, --, --, 
   {{0x2e200205,0x00000000,0x00000000,0x00000000}},	//   tıf_, --, --, --, 
   {{0xbcf80a40,0x05dc2ce1,0x0eb806a6,0xa1240014}},	//   rdén, _फीडब, рупы_, _کڈى۪, 
   {{0xe294008f,0xbcf9aa1d,0x00000000,0x00000000}},	//   _צװײ_, sdén, --, --, 
   {{0xdcec0327,0xedb40124,0x7e9c02dd,0x00000000}},	//   _plaġ, _ҕәнџ, _ﺇﻁﻼﻕ_, --, 
   {{0xf8bc0241,0x81c0009e,0x00000000,0x00000000}},	//   _adéo_, ূষণ_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbcf9aa1e,0xdcec01e4,0x6b9c01d5,0x00000000}},	//   ndél, _amaĵ, shrg, --, 
   {{0x8d740424,0x00000000,0x00000000,0x00000000}},	// [2df40] _هاکا, --, --, --, 
   {{0xa96804a9,0xca7400c7,0x5ba401af,0x00000000}},	//   шиға_, _думы, _нлығ, --, 
   {{0xb6f438eb,0x00000000,0x00000000,0x00000000}},	//   زىنا_, --, --, --, 
   {{0xe924031c,0x8935aa1f,0x2b580156,0x63840107}},	//   _འཇིབ_, _بعدا, lerc_, ӯҳба, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x46a401c0,0x2b58030a,0xd50800d1,0x491000bc}},	//   _дагв, nerc_, لغۇن_, तरको_, 
   {{0x5f940116,0x00000000,0x00000000,0x00000000}},	//   җинт, --, --, --, 
   {{0x2b580841,0x764000cf,0x6d40004e,0x00000000}},	//   herc_, ànye, òmal, --, 
   {{0xdcec025c,0x439401e0,0x835401d5,0x7d1803b2}},	//   _ilaħ, _һаҡс, _وپرا, ðusm, 
   {{0x78a80579,0x64a5aa20,0x2b580427,0x00000000}},	//   úgvi, _даға, jerc_, --, 
   {{0xb7d800c8,0x2b5805c7,0x80a801ad,0x41040006}},	//   שקיי, derc_, _जेरे, _дзев, 
   {{0xdcec025c,0xbcf839b4,0x00000000,0x00000000}},	//   _jlaħ, rdéo, --, --, 
   {{0x11e830bf,0xdcec031c,0x2b580165,0xed580006}},	//   _اعلي_, _mlaħ, ferc_, цоў_, 
   {{0x2b580165,0x3a2004ce,0x00000000,0x00000000}},	//   gerc_, tsjp_, --, --, 
   {{0xf990c852,0xdd940137,0x7ae400f1,0x00000000}},	//   وبر_, _накы, زورې_, --, 
   {{0x3a2000b5,0x8cb400db,0x00000000,0x00000000}},	//   rsjp_, تگۉس_, --, --, 
   {{0xbcf9aa21,0x19580184,0xfb8400c7,0x2b58030a}},	// [2df50] ndém, _һаны_, _дынн, berc_, 
   {{0x2b580276,0x69d0031c,0x3f9c0208,0xdb100241}},	//   cerc_, _ġież, nhtu_, _àgàg, 
   {{0xd5749dc2,0xd7f8016c,0x19580064,0x06bc00cc}},	//   зуль, руғ_, _ланы_, _অৰবি, 
   {{0x3f9c031c,0x00000000,0x00000000,0x00000000}},	//   hhtu_, --, --, --, 
   {{0xd469aa22,0x3f9c00e8,0x9878008f,0xea000208}},	//   силе_, khtu_, _האָט, _kiết_, 
   {{0xdb1401d3,0xa3a40014,0xb87800d7,0x83480150}},	//   mozó, وٝن٘, _vzíd, йжің_, 
   {{0xdcec0327,0xe1f801e0,0xea000208,0xdb1401d3}},	//   _flaħ, ҙгө_, _miết_, lozó, 
   {{0xc9e400d1,0x2b580165,0x59bc190c,0x00000000}},	//   _ﺋﺎﻟﻐ, zerc_, ्किर, --, 
   {{0x8fd000ee,0x53340064,0x800800e5,0x00000000}},	//   нәкә, _неат, یریہ_, --, 
   {{0x63040075,0xea000208,0x3f9c7fb6,0x8c440ce8}},	//   _يوقل, _niết_, ghtu_, үене, 
   {{0x59bc11bc,0x2b59aa23,0xbcf80036,0x0dc800cf}},	//   ्कार, verc_, pdél, йлой_, 
   {{0xdb1401ed,0xfbdc007f,0x2b580165,0xc82c0092}},	//   kozó, mwêy_, werc_, _እርሱን, 
   {{0xea0001dc,0x2b59aa24,0x00000000,0x00000000}},	//   _biết_, terc_, --, --, 
   {{0xc0f4001f,0x3f9c3e91,0x3b044773,0xdb1400e5}},	//   ለዋል_, chtu_, зеро_, dozó, 
   {{0x09e438a7,0x64b800c5,0xaee000dc,0x2b9401e3}},	//   зовн, _अश्श, _duṣk, _häck_, 
   {{0x0c2440c5,0x2b94007c,0xf9800107,0x480401ca}},	//   _емин, _käck_, нгсо, зпав, 
   {{0x2b58030a,0x451800cc,0x00000000,0x00000000}},	// [2df60] perc_, _ডালক_, --, --, 
   {{0xea000016,0x4a4400ee,0x00000000,0x00000000}},	//   _giết_, _енов, --, --, 
   {{0xd90c00dd,0xbaf80375,0x2b94007c,0x00000000}},	//   _چیف_, _להיש, _läck_, --, 
   {{0xe9743f7b,0x675801d9,0x00000000,0x00000000}},	//   _تۇرد, _ڈیرس_, --, --, 
   {{0xdb14007f,0x75d00035,0x2b94007c,0x670401ec}},	//   mozò, ريها, _näck_, _жүзб, 
   {{0xea00004d,0xdb1402e2,0x8798009f,0x00000000}},	//   _xiết_, lozò, _اَسر_, --, 
   {{0x7d19aa25,0xdcec025c,0x37e01e35,0x00000000}},	//   ðusk, _tlaħ, _чорг, --, 
   {{0xb6b80375,0x2b9401e3,0x850400ec,0x00000000}},	//   _הצלי, _bäck_, _روئن, --, 
   {{0x3f9c009a,0x9fc801d5,0x00000000,0x00000000}},	//   thtu_, оҳда_, --, --, 
   {{0x4425aa26,0x2b9401e6,0x00000000,0x00000000}},	//   mso_, _däck_, --, --, 
   {{0xea00004d,0x00000000,0x00000000,0x00000000}},	//   _riết_, --, --, --, 
   {{0x3f9c069c,0xea00004d,0xa3a81d3b,0x00000000}},	//   shtu_, _siết_, खोर_, --, 
   {{0x4425aa27,0x1b203fae,0x2b940036,0x6e400330}},	//   nso_, _বাবে_, _gäck_, ونیم, 
   {{0xdeb40efb,0xab840246,0x46bc2c2e,0x00000000}},	//   _облы, нуск, ्थाह, --, 
   {{0xea0001dc,0xbcf9aa28,0x4425aa29,0xdef80220}},	//   _viết_, ndék, hso_, _лық_, 
   {{0x4425aa2a,0x7f58023d,0x29f80064,0x00000000}},	//   kso_, letq, _ačas_, --, 
   {{0xea0007ae,0x20380020,0x4424bd40,0xf1bc0118}},	// [2df70] _tiết_, _በነበረ, jso_, íšil_, 
   {{0x4424058a,0x7f580393,0xdb145955,0x7ddc0153}},	//   dso_, netq, rozó, _rūsy, 
   {{0x4425aa2b,0xcb100375,0x7d1c0200,0xd9141f39}},	//   eso_, _שלט_, _keqs, _одны, 
   {{0x4425aa2c,0xdb1400e5,0x00000000,0x00000000}},	//   fso_, pozó, --, --, 
   {{0x4425aa2d,0xa9240153,0x7d1c03e3,0x7f580166}},	//   gso_, ęžtu, _meqs, ketq, 
   {{0x5724215c,0xe4580212,0x78a806ea,0x00000000}},	//   _زىرك, яжі_, úgvu, --, 
   {{0x4425aa2e,0xd7d802ab,0x7f580393,0x9238109a}},	//   aso_, _बीएच, detq, ічку_, 
   {{0x4425aa2f,0x2b9401c7,0x7d1c025c,0xca28010f}},	//   bso_, _päck_, _neqs, קופֿ, 
   {{0x4425aa30,0x24182f6a,0x290c03b9,0x00000000}},	//   cso_, _ноты_, _əda_, --, 
   {{0x7f58003a,0xa8580375,0x2b9401e3,0xbcf80129}},	//   getq, ליחה_, _väck_, ldéh, 
   {{0x69c002b1,0x00000000,0x00000000,0x00000000}},	//   ōmei, --, --, --, 
   {{0x2b94aa9a,0x77640327,0x40cc00b4,0x50b403fb}},	//   _zäch_, _lajx, ịrị_, _ослу, 
   {{0x7d1c102c,0x7f580393,0x00000000,0x00000000}},	//   _deqs, betq, --, --, 
   {{0xbd0001f5,0x7f580393,0x8fd001e0,0x00000000}},	//   _éénp, cetq, _шәйә, --, 
   {{0xc3200729,0x91e00118,0x00000000,0x00000000}},	//   _নামি_, _पठाई, --, --, 
   {{0x4425aa31,0x78b800d0,0x09e40b3b,0x7bc801e1}},	//   yso_, _žuva, фобн, _ígun, 
   {{0x6d44005a,0x44240548,0x6cb40137,0x1b1c0154}},	// [2df80] _icia, xso_, _чөнт, _তারই_, 
   {{0x4424013c,0x7c540101,0x00000000,0x00000000}},	//   vso_, _کلیر_, --, --, 
   {{0x29f80122,0xd49802dd,0xf74000f3,0x4424a21f}},	//   _včas_, үрі_, техо, wso_, 
   {{0x4425aa32,0xd5b8155b,0x00000000,0x00000000}},	//   tso_, псі_, --, --, 
   {{0x442421df,0x2b940227,0x04580597,0xf8bc003e}},	//   uso_, _päch_, تجات_, _ndéh_, 
   {{0xa3a8068f,0x9a243faa,0xf8b002e4,0x32cc00b8}},	//   खों_, _تعین, _ישר_, _ṣaṇ_, 
   {{0x4425aa33,0xf7402636,0x6d44127b,0xfd1c026c}},	//   sso_, _шеро, _ocia, hjìa_, 
   {{0x325006bb,0x6d45aa34,0x27f80ade,0xbcf800d5}},	//   твър, _ncia, _hirn_, rdék, 
   {{0x27f9aa35,0x7d1c0986,0x44240014,0x00000000}},	//   _kirn_, _reqs, qso_, --, 
   {{0x6d441f2a,0xada40034,0x27f80009,0x741006c2}},	//   _acia, óźni, _jirn_, _شوما, 
   {{0x7f5816b8,0xbcf80036,0x00000000,0x00000000}},	//   retq, ldéi, --, --, 
   {{0x6d440395,0x53800022,0x4ad000e1,0x7f580393}},	//   _ccia, _ақәз, _दुधव, setq, 
   {{0xdb0406d5,0xbcf9aa36,0x27f801c3,0xdbf80d79}},	//   _amhá, ndéi, _oirn_, ंदेड_, 
   {{0x212435b8,0x6d45aa37,0xbcf800c6,0xea00004d}},	//   lamh_, _ecia, idéi, _chắt_, 
   {{0x7d1daa38,0x00000000,0x00000000,0x00000000}},	//   _teqs, --, --, --, 
   {{0x2124be90,0x27f9aa39,0x6d4400ae,0x2d84a6e1}},	//   namh_, _airn_, _gcia, ömet_, 
   {{0x27f8f84a,0x26d80548,0x661c0067,0x48c00022}},	// [2df90] _birn_, _ayro_, _awrk, гәра, 
   {{0x21243e7c,0x00000000,0x00000000,0x00000000}},	//   hamh_, --, --, --, 
   {{0xfbdc06ed,0x26d80393,0x261c0115,0xd94c0023}},	//   ntêm_, _cyro_, gŭo_, _ምጽውዋ, 
   {{0x26d80042,0x65940354,0xca940a7c,0x78a803b2}},	//   _dyro_, каху, _נדרי_, úgvs, 
   {{0x212437a8,0xf99c110e,0xbcf80306,0x261c0115}},	//   damh_, _ilè_, rdéh, aŭo_, 
   {{0x27f80493,0xd7c804fb,0x00000000,0x00000000}},	//   _girn_, _روزه_, --, --, 
   {{0x26d8070d,0xf99c0699,0x212401ab,0xe3b00592}},	//   _gyro_, _klè_, famh_, جرن_, 
   {{0xa5e405f5,0xbcf80036,0x21240e89,0xc6900677}},	//   _аюул, bdéi, gamh_, _גאל_, 
   {{0xe4a4059f,0x00000000,0x00000000,0x00000000}},	//   _ирфо, --, --, --, 
   {{0x6d45aa3a,0xa3000046,0xf99c007f,0x0ea8023a}},	//   _scia, _күше, _llè_, зкой_, 
   {{0xbcf80098,0xf99c0248,0x9ac4025c,0x92581171}},	//   ndéw, _olè_, nuċċ, _хает_, 
   {{0x212400a3,0xf99c0241,0xa29400d4,0xf1a80244}},	//   camh_, _nlè_, _шахі, _بائه_, 
   {{0xea000208,0x00000000,0x00000000,0x00000000}},	//   _phắt_, --, --, --, 
   {{0xf99daa3b,0x1ea8004b,0x12d0015b,0xf7c80131}},	//   _alè_, _ښايي_, াধীদ, ﻐﺎﻧﺪ, 
   {{0x5f7404b3,0x00000000,0x00000000,0x00000000}},	//   _جانر, --, --, --, 
   {{0x6d440857,0x9f9001e1,0x00000000,0x00000000}},	//   _ucia, bàó_, --, --, 
   {{0x27f81f28,0xea00001e,0x26d86947,0x4734114f}},	// [2dfa0] _pirn_, _thắt_, _syro_, فراز, 
   {{0xf99daa3c,0x46a5a4f7,0xea00004d,0xbcf800e4}},	//   _elè_, назв, _ngầu_, teég, 
   {{0xfc3c0122,0xf99c02bd,0xe9c400c7,0x6db403f9}},	//   nzín_, _flè_, _аанҿ, rƙaƙ, 
   {{0x35a005f5,0x26d80006,0xa3a802ab,0xcfe400eb}},	//   лахг, _vyro_, खोई_, নদিন, 
   {{0xbcf80036,0x26d80142,0x2c140073,0x00000000}},	//   udéi, _wyro_, तीचं_, --, 
   {{0x26d9aa3d,0xdb0400b5,0xbcf80221,0x337001ec}},	//   _tyro_, _emhæ, rdéi, лгір, 
   {{0x3af800c8,0xbcf80221,0xd36c1e4a,0x26d8022e}},	//   פּגע, sdéi, تۇل_, _uyro_, 
   {{0xea0001dc,0x212401ab,0x00000000,0x00000000}},	//   _nhật_, uamh_, --, --, 
   {{0x82f8193a,0xdcec3c52,0xd5ac01ed,0x2125aa3e}},	//   _فراز_, _inać, _بہن_, ramh_, 
   {{0x2124379c,0x826800d4,0xbcf80588,0x00000000}},	//   samh_, _назв_, ndév, --, 
   {{0xdd91aa3f,0x00000000,0x00000000,0x00000000}},	//   لود_, --, --, --, 
   {{0xea0001fb,0xcdcc00f1,0xb6b80a7c,0x00000000}},	//   _chật_, يښي_, לציי, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2d8426bc,0xdb140240,0x3078010f,0xf41c0139}},	//   ömer_, mizë, _מאדנ, _çäe_, 
   {{0xdb140023,0xf99c7704,0x00000000,0x00000000}},	//   lizë, _plè_, --, --, 
   {{0x3f8c0451,0x5c74098c,0x7c28003a,0xade8000d}},	//   _hofu_, _алит, _ægro, _टीपन_, 
   {{0x3f8c03a0,0xdb140023,0x742c0092,0x00000000}},	// [2dfb0] _kofu_, nizë, _አልፎአ, --, 
   {{0xab850757,0xfc3c03a0,0xb6c460a7,0x00000000}},	//   _буюк, muí_, нсей, --, 
   {{0x3f8c01e0,0xfc3d3908,0xdb140200,0xb6c4009d}},	//   _mofu_, luí_, hizë, хсай, 
   {{0x3f8c02c4,0xa2c400cd,0x19940153,0x00000000}},	//   _lofu_, िपन्, _рамя, --, 
   {{0x3f8daa40,0xfc3c004e,0x5fd0012c,0x61e4031c}},	//   _oofu_, nuí_, सकाल, ċill, 
   {{0xaab801d5,0xdb140200,0x9ac40327,0x00000000}},	//   _آدیر_, dizë, puċċ, --, 
   {{0x798c0921,0xfc3c00c6,0x60dc00ac,0x43900a5b}},	//   _kocw, huí_, ərmi, рајс, 
   {{0xdb14036e,0x00000000,0x00000000,0x00000000}},	//   fizë, --, --, --, 
   {{0x3f8c006f,0x13f4113e,0x10a43866,0xfc3c00e4}},	//   _bofu_, _азая, типн, juí_, 
   {{0x798daa41,0xdcec041a,0xfc3c00db,0x0eb800c0}},	//   _locw, _znać, duí_, думы_, 
   {{0xa3c00574,0xea00001e,0xd1306728,0x623402a9}},	//   ीवर_, _phật_, _نما_, _беху, 
   {{0x798c2d2f,0x7bd40166,0xdb15aa42,0xe1e8075e}},	//   _nocw, _akxu, lizè, _كىلو_, 
   {{0xb878066d,0xfc3daa43,0x3f8c00e8,0xe1f000db}},	//   _szín, guí_, _fofu_, _اسل_, 
   {{0x3f8c01c8,0x09b80490,0xdb150111,0x33240327}},	//   _gofu_, ईच्य, nizè, nanx_, 
   {{0xea0007ae,0x798c0af2,0x7f54009b,0x00000000}},	//   _thật_, _bocw, _рајс_, --, 
   {{0x7d18008c,0xfc3c17cd,0x798c0142,0xea000051}},	//   ðust, buí_, _cocw, _ngấu_, 
   {{0x33240054,0xa3e40883,0xb9580241,0xfc3c00d8}},	// [2dfc0] kanx_, नतम_, _ejìo, cuí_, 
   {{0xdcec08ad,0x1b0001c6,0x3f8c06be,0x00000000}},	//   _snać, _гүрн, _xofu_, --, 
   {{0x3324003e,0x798c0142,0x46f4005b,0xdb140200}},	//   danx_, _focw, тчат, zizë, 
   {{0x798c0007,0xf8bc0137,0x25a0007b,0x69c00010}},	//   _gocw, _adéu_, óil_, čmes, 
   {{0xdb14007f,0x3e5c00b5,0x245440bb,0x00000000}},	//   fizè, るtv_, انتس, --, 
   {{0x798c01b3,0xdb140023,0x572400c6,0x3490013e}},	//   _zocw, vizë, _مرفق, рашр, 
   {{0x798c0944,0x3f8c0810,0x20241ee0,0x06e400bc}},	//   _yocw, _rofu_, _ሳተላይ, _करिव_, 
   {{0xdb140240,0x3f8c03b2,0x00000000,0x00000000}},	//   tizë, _sofu_, --, --, 
   {{0x032402d5,0x28d828a2,0xbcf9aa44,0x00000000}},	//   _адзн, _भुमि, ndét, --, 
   {{0xc299aa45,0xdb140023,0x24a44674,0x00000000}},	//   _отец_, rizë, ırmı_, --, 
   {{0xdd952aa8,0xdeb41611,0xdb140200,0x00000000}},	//   ганы, убны, sizë, --, 
   {{0x236daa46,0x63b9aa47,0xfc3daa48,0xdb140306}},	//   _hadj_, livn, tuí_, mizé, 
   {{0x3f8daa49,0xdd91aa4a,0xdb15aa4b,0x236c0117}},	//   _tofu_, لوگ_, lizé, _kadj_, 
   {{0x798c009a,0xfc3c0798,0xcf1800ec,0x00000000}},	//   _socw, ruí_, _ٻروچ_, --, 
   {{0x19582b95,0x236c009f,0xdb14126c,0xfc3c0332}},	//   навы_, _madj_, nizé, suí_, 
   {{0xfe7401c6,0x5b140139,0x00000000,0x00000000}},	//   _зүү_, _өмит, --, --, 
   {{0xfc3daa4c,0x63b80158,0x2985aa4d,0xfa600092}},	// [2dfd0] quí_, kivn, шырг, _ቴክኒክ_, 
   {{0x3e380020,0x798c0921,0x63b805be,0xd01800a2}},	//   _በተደረ, _wocw, jivn, gyńy_, 
   {{0xd6d0a37e,0xa3c80316,0x55c400c7,0x95380108}},	//   حقا_, ोकन_, гәаз, езет_, 
   {{0xf4f40014,0x00000000,0x00000000,0x00000000}},	//   نواں_, --, --, --, 
   {{0x236c007f,0x493800d9,0x659400d8,0xdcfc00c0}},	//   _badj_, _אגרו, јачу, rksė, 
   {{0x63b9aa4e,0xbcf800dd,0xdb140221,0x68d40640}},	//   givn, ldés, fizé, _ђорђ, 
   {{0x33240227,0x425000c6,0xdb15aa4f,0x6298541b}},	//   ranx_, منور, rizè, gyvo, 
   {{0xc6900bd9,0x659401ee,0x11480131,0xbcf9aa50}},	//   _פאן_, _касу, хпий_, ndés, 
   {{0xf8bc45a7,0x33240054,0xc1840014,0x00000000}},	//   _idés_, panx_, ادى۪, --, 
   {{0xea00001e,0x629801a4,0x8fa400f2,0x00000000}},	//   _giặt_, byvo, امده, --, 
   {{0xed8400d1,0xa3b8007b,0xd2140114,0x69d802d2}},	//   иңки, _شاكر_, _смећ, _íveg, 
   {{0xea00001e,0x00000000,0x00000000,0x00000000}},	//   _nhạt_, --, --, --, 
   {{0x814000cf,0x00000000,0x00000000,0x00000000}},	//   _اچىن, --, --, --, 
   {{0xfc00f9e0,0xd9e000fe,0x9e65aa51,0xdc8000c7}},	//   спро, _মূলম, _چاين, цқьо, 
   {{0xfaa067bf,0x7e946356,0x15f496e3,0x5a944f13}},	//   баро, _منور_, ेदार_, артф, 
   {{0xa2c406ff,0x82e80135,0x26dc014a,0xdb140036}},	//   िपत्, རྟིའ, üvom_, enzä, 
   {{0x88e46c60,0x19f8084c,0xc8c81374,0x00000000}},	// [2dfe0] ужае, тэрь_, روئن_, --, 
   {{0xf8bc62a3,0xdb140356,0x00000000,0x00000000}},	//   _adés_, lizî, --, --, 
   {{0x2d81aa52,0x65b400c7,0xca7401af,0x00000000}},	//   _knie_, аӡат, _супы, --, 
   {{0x62980306,0x63b8047e,0x091c00cc,0x00000000}},	//   vyvo, wivn, _ফাকু_, --, 
   {{0x69c5aa53,0x63b8506e,0x2d80006d,0x236c00e8}},	//   mnie, tivn, _mnie_, _padj_, 
   {{0x69c5aa54,0x6299aa55,0xdb1402f0,0x3fc002dd}},	//   lnie, tyvo, tizé, _ﺯﻳﺎﻧ, 
   {{0xbcf9aa56,0x63b97de0,0x2d800493,0x46a5aa57}},	//   ndér, rivn, _onie_, _савв, 
   {{0xf1a1aa58,0x6298030a,0xa3a8012d,0xb1a00139}},	//   йрын, ryvo, खोज_, йшык, 
   {{0xf9900302,0x69c5aa59,0xdb1404e6,0x6299242d}},	//   מרה_, inie, sizé, syvo, 
   {{0x69c40399,0x2d801311,0xbcf9aa5a,0x224c0213}},	//   hnie, _anie_, zdés, _tqdk_, 
   {{0x69c5aa5b,0x8145aa5c,0x7bc800e4,0x9d180024}},	//   knie, _منان, _ígui, конт_, 
   {{0x69c5aa5d,0x4ad0012c,0xc0c801f0,0xfc3001d9}},	//   jnie, _दुइव, _пуле_, ٝحس_, 
   {{0x69c5aa5e,0xc0940014,0x2d8049aa,0xfc3c1155}},	//   dnie, _حجات, _dnie_, mzík_, 
   {{0x2d80013f,0x69c5aa5f,0x7f95aa60,0x7868007c}},	//   _enie_, enie, _pâqu, _lövå, 
   {{0xea00001e,0x8e84010a,0x69c415c0,0x00000000}},	//   _phạt_, _кăрч, fnie, --, 
   {{0x69c5aa61,0x588401ec,0xc6bc00cc,0x6b88007c}},	//   gnie, қыға, _অৰ্চ, ödgr, 
   {{0xa3e41715,0xbcf8066d,0x57b5aa62,0x52e00d2e}},	// [2dff0] नता_, rdés, абат, _फर्स, 
   {{0x3f9daa63,0x1a641482,0x2d800030,0x00000000}},	//   nktu_, _پیری_, _znie_, --, 
   {{0x69c5aa64,0x7c2daa65,0x6da43ee6,0xdd2000bc}},	//   bnie, lscr, _ضمیم, _můžo, 
   {{0x7e68030d,0x69c4033f,0x7c2c0334,0x4ec000cc}},	//   _msfp, cnie, oscr, _উৰুল, 
   {{0x3948020c,0x7c2daa66,0xd469aa67,0xb4bc0037}},	//   _iccs_, nscr, тиле_, ँपे_, 
   {{0x3868011c,0x1c1c033f,0x7c2c7ffa,0x883800d9}},	//   _iscr_, बीएल_, iscr, _בתשו, 
   {{0x3868009a,0x5695aa68,0x6b7c0375,0x7c2c00ae}},	//   _hscr_, _тавт, תרונ, hscr, 
   {{0x3f9daa69,0x799c009a,0x7c2c03ac,0x51f426c6}},	//   ektu_, nkqw, kscr, جستر, 
   {{0x4ad000bc,0x00000000,0x00000000,0x00000000}},	//   _दुईव, --, --, --, 
   {{0x69c5aa6a,0x6fa4021a,0x7c2c035a,0x2d80045f}},	//   znie, اندې_, dscr, _snie_, 
   {{0x7c2c1730,0x69c5aa6b,0x630400f1,0x00000000}},	//   escr, ynie, _اومل, --, 
   {{0x9f5c02e2,0x386801ab,0x7c2c0036,0xc61800fe}},	//   _livè_, _oscr_, fscr, _ডিমা_, 
   {{0x69c400da,0xb35c001f,0xddd402d1,0x76f800fe}},	//   vnie, ሰጠውን_, ñašp, ইডিছ_, 
   {{0x69c4006d,0xb928001e,0x0cc40034,0xc4f40375}},	//   wnie, _thuỷ_, _लखीम, יזרי_, 
   {{0x69c5aa6c,0x394801ee,0xc9b4147e,0x7f38008f}},	//   tnie, _bccs_, асањ, _סעקו, 
   {{0x386801ee,0x7c2daa6d,0x69c5aa6e,0x2d81aa6f}},	//   _bscr_, bscr, unie, _unie_, 
  
   {{0x316c020b,0x7c2d395d,0xbcf80022,0xca4c01ec}},	// [2e000] _magz_, cscr, leén, _ﺍﺤﺩ_, 
   {{0x69c5aa70,0x998c0f03,0x61e4003d,0x29f800b0}},	//   snie, češ_, ċili, _mōai_, 
   {{0x69c5aa71,0x9f5c0100,0xbb380375,0x09e4010a}},	//   pnie, _divè_, _בעיי, _вонн, 
   {{0x69c40007,0xa2c401e0,0x00000000,0x00000000}},	//   qnie, ҙҙек, --, --, 
   {{0x2458506f,0xbcf8035b,0xd24c0014,0x3f9c1427}},	//   уаль_, ndép, ہۆل_, yktu_, 
   {{0x9f5c05d5,0x07a401c0,0x6f000427,0x6e200857}},	//   _givè_, _тагн, _ngnc, _ownb, 
   {{0xdd20012c,0x316c00d8,0xf41c0139,0x9f60032e}},	//   _růžo, _bagz_, _çän_, _ásér_, 
   {{0x7c2daa72,0x78b80006,0xdbd001a8,0xfe7c010b}},	//   yscr, _žuvi, _lýðh, _üįin_, 
   {{0xdec4044e,0x438400db,0x00000000,0x00000000}},	//   ኸውን_, _پلاق, --, --, 
   {{0x66000165,0x7c28003a,0x3f9c262b,0xe5a401a9}},	//   _himk, _ægri, uktu_, _тиғи, 
   {{0x6601aa73,0x7c2c010a,0x3f9daa74,0x00000000}},	//   _kimk, wscr, rktu_, --, 
   {{0x7c2daa75,0x66000a73,0xdb0400d2,0x3f9daa76}},	//   tscr, _jimk, _umhú, sktu_, 
   {{0x66017192,0x7c2c02d0,0xceb400fb,0x23bc243c}},	//   _mimk, uscr, иҙә_, ्चपद, 
   {{0x7c2daa77,0x69c80231,0x6601aa78,0xac186a8b}},	//   rscr, éden, _limk, рору_, 
   {{0x7c2c035a,0xdd9400ee,0xfce80023,0x4f6405af}},	//   sscr, _гайы, መርጸ_, _دانف, 
   {{0x6601aa79,0xf99c068c,0x7c2c9cef,0x386804cc}},	//   _nimk, _mièg_, pscr, _pscr_, 
   {{0xbda4ef89,0x3705aa7a,0xd7c826c0,0xa3c821b8}},	// [2e010] _محکو, ачев, هوره_, ोका_, 
   {{0x1b20009e,0xfc3c01e7,0x00000000,0x00000000}},	//   _বাকে_, mrí_, --, --, 
   {{0x41d41533,0x6600009f,0x39480798,0x7bc40cf4}},	//   डकास, _bimk, _tccs_, mnju, 
   {{0xeef406a9,0x7bc409a8,0x660001d3,0xe3b80790}},	//   במבר_, lnju, _cimk, _amı_, 
   {{0x6601aa7b,0x85080046,0x7bc4017a,0x2aac0248}},	//   _dimk, удің_, onju, _tóbé_, 
   {{0xfc3c0491,0xd7940597,0xdb140311,0x316c0175}},	//   irí_, _الآخ, lizâ, _sagz_, 
   {{0x5275aa7c,0xfbdc00d8,0xfc3c00ae,0x00000000}},	//   сулу, ltês_, hrí_, --, 
   {{0xd18405f5,0x7bc416a3,0x60c40010,0xdb140356}},	//   слий, hnju, _žima, nizâ, 
   {{0xfc3c0309,0xeae400e1,0x92c80154,0x8f7428f6}},	//   jrí_, _गर्त_, োধে_, буні, 
   {{0x6601aa7d,0xfc3c0f15,0xdb140356,0x316c00a2}},	//   _zimk, drí_, hizâ, _wagz_, 
   {{0xd17400ee,0x63a40798,0x7bc401a6,0x6f000334}},	//   _гылы, êine, dnju, _vgnc, 
   {{0xfc3c0321,0xea000208,0xa2c400cd,0x2258000d}},	//   frí_, _khất_, िपर्, _ärka_, 
   {{0xfc3c4d74,0xf8bc002e,0x7d180784,0x00000000}},	//   grí_, _seén_, ñusa, --, 
   {{0x7bc4110c,0xa0c400ec,0xbcf806af,0xe0d80212}},	//   gnju, _بيهو, rdép, _тві_, 
   {{0x4ad010f7,0xfaa00209,0xfd1c026c,0xaca4063f}},	//   _दुखव, паро, bbì_, moọk, 
   {{0x0905aa7e,0xfc3c7bb9,0x7c3801fa,0x9f5c007f}},	//   спан, brí_, šura, _rivé_, 
   {{0xea0001dc,0xfc3c5133,0x660000c0,0x07a400c7}},	// [2e020] _nhất_, crí_, _rimk, баан, 
   {{0x6601aa7f,0xf8bc002e,0x46f4c959,0xfa500023}},	//   _simk, _teén_, бчет, _ምግምማ, 
   {{0xa3c801ad,0x00000000,0x00000000,0x00000000}},	//   ोकस_, --, --, --, 
   {{0xc48409a5,0xdb14054e,0x00000000,0x00000000}},	//   йлек, cizâ, --, --, 
   {{0xea0007ae,0x66000254,0xfd4c0248,0x248001e4}},	//   _chất_, _vimk, _panẹ, ĥimo_, 
   {{0x6600002d,0xc0580220,0x59240327,0x4b78010f}},	//   _wimk, ңіп_, _འབོས_, ראַו, 
   {{0xdb140798,0x6601aa80,0x00000000,0x00000000}},	//   lizã, _timk, --, --, 
   {{0xdb040ba1,0xfc3c011f,0xdb140518,0xfbdc0af9}},	//   _elhè, yrí_, vizí, ntêr_, 
   {{0x7bc5aa81,0x58fc0327,0x15b9aa82,0x30100209}},	//   ynju, _ཐུབས_, _тыры_, пдыр, 
   {{0xc32000bd,0xe3a4c8e1,0xdcec0139,0x2b18012c}},	//   _নাকি_, _بشری, _anağ, _ब्लु_, 
   {{0xb7d8010f,0xfc3c01d3,0x00000000,0x00000000}},	//   רקיי, nzív_, --, --, 
   {{0x69c800dd,0xfc3c01a2,0x29f802b5,0xdb040120}},	//   édel, trí_, _kōau_, _ilhé, 
   {{0x9f349e08,0x00000000,0x00000000,0x00000000}},	//   _делі, --, --, --, 
   {{0xfc3daa83,0x63a80175,0x84f400b8,0xdfd0027d}},	//   rrí_, _jldn, _nṛmṇ, _تيت_, 
   {{0x7bc4000f,0xaa5c02dd,0xfc3c01e7,0x00000000}},	//   rnju, лерi, srí_, --, 
   {{0x7bc40219,0xdd200118,0x8e140244,0x00000000}},	//   snju, lůžk, _بسوڵ, --, 
   {{0x7bc40427,0xad1c011a,0xdb140356,0x00000000}},	// [2e030] pnju, _עוזר, rizâ, --, 
   {{0x9b580120,0xe6c42bf1,0x00000000,0x00000000}},	//   _тиот_, वपूज, --, --, 
   {{0x1994010b,0x195864c2,0xaa64010a,0x00000000}},	//   _даня, _каны_, _етяк, --, 
   {{0xea00004d,0x78b80024,0x1b2000cc,0x63a817d1}},	//   _phất_, _žuvu, _বাটে_, _aldn, 
   {{0x5fc83fec,0x687002d3,0x60c40010,0xf83000d7}},	//   िचाल, ስተይቲ_, _žimn, ýšľa_, 
   {{0x3dcc009e,0x00000000,0x00000000,0x00000000}},	//   রতিল, --, --, --, 
   {{0x25600100,0x00000000,0x00000000,0x00000000}},	//   _bčlč_, --, --, --, 
   {{0xea0007ae,0xd1780006,0x90345751,0x63a801e3}},	//   _thất_, рскі_, охоч, _eldn, 
   {{0x8fd00b8d,0x764001d3,0x98b803e0,0xf9940051}},	//   мәкә, ányf, _kası_, _đậm_, 
   {{0xa3e400dc,0x00000000,0x00000000,0x00000000}},	//   नतः_, --, --, --, 
   {{0x8d64ebc9,0x5f00013e,0x59d8352c,0x98b815b7}},	//   овне, нҷша, भकार, _ması_, 
   {{0x82d400c8,0x2360009b,0x8db452c4,0xa194014b}},	//   _וועג_, đije_, існі, _нахч, 
   {{0x69c8004a,0x1b20015b,0xd0100451,0x8b64007b}},	//   édem, _বাজে_, _کلڻ_, ياسم, 
   {{0x5924025c,0x09e00c00,0x63a80129,0xdce80342}},	//   _འབུས_, पत्य, _xldn, şoğl, 
   {{0x49946c00,0x29f800a2,0xbb400120,0xff14011a}},	//   ошат, _oōat_, ќеск, _וקצת_, 
   {{0xeaa00943,0x4fc00150,0xe0540345,0x00000000}},	//   _haṋu_, _ءەگە, _بییت_, --, 
   {{0x98b803e0,0x08c46885,0xdcfc0356,0x00000000}},	// [2e040] _bası_, цбан, ăzăt, --, 
   {{0x3db40156,0x29f802b5,0xfbddaa84,0xe7b400cf}},	//   _བཏོན, _rōau_, stêr_, سۅزد, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x44a41e87,0x63a801ab,0x75d1aa85,0x00000000}},	//   يماق, _sldn, ويلا, --, 
   {{0xdb15790c,0xb87800dd,0x00000000,0x00000000}},	//   lizá, _szív, --, --, 
   {{0xf4843c5b,0x998c0118,0xe7d400f2,0x02a401a9}},	//   تامی, čeť_, _رمزگ, жрим, 
   {{0xdb143b0f,0x320401c6,0x48dc00cd,0x00000000}},	//   nizá, охын_, _कुतो_, --, 
   {{0xba98010f,0x00000000,0x00000000,0x00000000}},	//   יסצי, --, --, --, 
   {{0xd5b802d5,0x1b20009e,0xc35400a7,0xdb14007f}},	//   _усё_, _বাঘে_, _мъжъ, yizà, 
   {{0x6d402833,0x63a801bf,0xb87801e1,0x00000000}},	//   óman, _uldn, _oyín, --, 
   {{0xc2c40fa2,0x9e1401ca,0xc1180150,0x00000000}},	//   _بياي, ядні, _күйi, --, 
   {{0xdcec08a4,0xf8bc002e,0x00000000,0x00000000}},	//   _snađ, _seém_, --, --, 
   {{0xb87801e1,0x00000000,0x00000000,0x00000000}},	//   _ayín, --, --, --, 
   {{0x23bcc6e5,0xab84004e,0x00000000,0x00000000}},	//   ्चिद, муск, --, --, 
   {{0x7e2802bf,0xdb1437b5,0x98b80166,0x00000000}},	//   _тіла_, gizá, _rası_, --, 
   {{0x394c01b8,0x98b80166,0xf96002f2,0x00000000}},	//   ügs_, _sası_, بنرێ, --, 
   {{0x23bc00dc,0x98b80205,0x00000000,0x00000000}},	// [2e050] ्चाद, _pası_, --, --, 
   {{0x2ca400cc,0x00000000,0x00000000,0x00000000}},	//   ømde_, --, --, --, 
   {{0x36880323,0x00000000,0x00000000,0x00000000}},	//   шсан_, --, --, --, 
   {{0x5924031c,0x3e7800de,0xf41ce73c,0x00000000}},	//   _འབིས_, _mīt_, _çäk_, --, 
   {{0x45a010a8,0xea000208,0x746800ee,0x98b80205}},	//   رەكك, _nhẹt_, ррев_, _tası_, 
   {{0xe3b80212,0x00000000,0x00000000,0x00000000}},	//   обі_, --, --, --, 
   {{0x9f5c07c5,0x00000000,0x00000000,0x00000000}},	//   _vivì_, --, --, --, 
   {{0x9f5daa86,0xb9d402d3,0x35a40345,0x00000000}},	//   _diví_, _ሸኽ_, _بنرێ_, --, 
   {{0xea000051,0xefec0092,0x00000000,0x00000000}},	//   _chẹt_, _ቀሪው_, --, --, 
   {{0xddc800d0,0xb284013d,0xf20402e8,0x3e380092}},	//   ludň, _мыек, _дядо, _በተዘረ, 
   {{0xc32002f5,0x92a801e0,0x00000000,0x00000000}},	//   _নাচি_, _усаҡ_, --, --, 
   {{0xdb145923,0x00000000,0x00000000,0x00000000}},	//   vizá, --, --, --, 
   {{0x20b8005b,0x06e00154,0x00000000,0x00000000}},	//   _мышь_, _বলছি, --, --, 
   {{0xdb15aa87,0x96bc05d7,0xfc3c0118,0xdb100241}},	//   tizá, ्पाउ, vzít_, _ògìd, 
   {{0x753804b9,0x7774007c,0x00000000,0x00000000}},	//   _oduz, ddxx, --, --, 
   {{0x7539aa88,0x8d74a847,0xdb15aa89,0x7bc80241}},	//   _nduz, _رابا, rizá, _ìgun, 
   {{0x84f4002b,0x00000000,0x00000000,0x00000000}},	// [2e060] _gṛhṇ, --, --, --, 
   {{0x46f4721f,0x753800d8,0xfc3c1de4,0xcb6800f2}},	//   пчет, _aduz, rzít_, _امده_, 
   {{0x3118012c,0xfc3c01d3,0x0584769e,0xccb00022}},	//   नडाः_, szít_, зулм, _цәҟь, 
   {{0x59240327,0xd5b828f6,0x00000000,0x00000000}},	//   _འབགས_, осі_, --, --, 
   {{0x39780375,0xdb1000e4,0x84580640,0x00000000}},	//   _הטכנ, _ágãg, срет_, --, 
   {{0x7539aa8a,0xeaa0002b,0x78b800a2,0x7ad8000d}},	//   _eduz, _goṣu_, _ýuva, _मुँअ, 
   {{0x48f43c71,0x673c0332,0x21cc0118,0xdef80135}},	//   ्शको_, _idrj, běhl_, peċi_, 
   {{0x2870001f,0x9f5c0407,0x3e78005f,0xe190010e}},	//   _ቅርንጫ, _viví_, _rīt_, _aỳry_, 
   {{0xb87800dd,0x430805d9,0x80a40034,0x656001ab}},	//   _nyíl, _هيءَ_, गनें, _ibmh, 
   {{0xcce40150,0x3e7800ef,0xdb14010e,0x00000000}},	//   _ﺍﺭﺘﻔ, _pīt_, mizç, --, 
   {{0x733020ea,0x1df811ed,0xc1044caa,0xdb140139}},	//   _سىنا, жены_, _فواي, lizç, 
   {{0x661c01a9,0x00000000,0x00000000,0x00000000}},	//   _mtrk, --, --, --, 
   {{0xa2c40b9a,0x673c01a6,0xf1b00375,0xed580006}},	//   िपक्, _odrj, _אסף_, чоў_, 
   {{0x59242fb5,0x9f5c00d8,0x661c00e2,0x3e7800ef}},	//   _འབངས_, _divã_, _otrk, _tīt_, 
   {{0xaf580375,0x263802f0,0xdb040112,0x99854eaa}},	//   _הכוכ, jčo_, _umhü, ولسو, 
   {{0xf7706ff0,0xfe7401c0,0x3a3c0306,0x17e466c0}},	//   کار_, _дүү_, čup_, कत्व_, 
   {{0xa3dc0574,0xdcec0421,0x661c01a6,0x6d3c011a}},	// [2e070] ठवा_, _faaā, _atrk, _התחנ, 
   {{0x6b0c031c,0x3689aa8b,0x97140212,0x00000000}},	//   _ཁུརོ_, йсен_, ємец, --, 
   {{0xb8641680,0x00000000,0x00000000,0x00000000}},	//   _کاجو, --, --, --, 
   {{0x9f5c0268,0x656000a3,0xa5f8f854,0x661c0139}},	//   _livà_, _cbmh, пеху_, _dtrk, 
   {{0xe3b1aa8c,0x6561aa8d,0x764001ed,0x1b4002d3}},	//   گرن_, _dbmh, ányb, _ንምትካ, 
   {{0x44c40165,0x263800d7,0x00000000,0x00000000}},	//   _dɐ_, bčo_, --, --, 
   {{0xe3b1aa8e,0xb7b80022,0x00000000,0x00000000}},	//   درن_, _atãg, --, --, 
   {{0x236053fb,0x75380213,0x7c38031c,0x00000000}},	//   đija_, _uduz, ġurj, --, 
   {{0x50b46afe,0xbcf861d0,0x205474e7,0x9438007b}},	//   ьску, nféd, нтэр, _ذكاء_, 
   {{0x6d480024,0x09b800dc,0x69d80022,0x9f040214}},	//   ėdam, _इष्य, _êvev, کوپو, 
   {{0x64440327,0x00000000,0x00000000,0x00000000}},	//   ġiie, --, --, --, 
   {{0x845c0201,0x00000000,0x00000000,0x00000000}},	//   _ሳይሆን_, --, --, --, 
   {{0xcf240691,0xa1340214,0x34d80c22,0x00000000}},	//   _قرغي, _سرنش, _बडोद, --, 
   {{0xdb0401d3,0x53dc043e,0x00000000,0x00000000}},	//   _elhí, यविश, --, --, 
   {{0x09e41e80,0xea0007ae,0xfc00041b,0x3b046b2a}},	//   довн, _chết_, тпро, деро_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9f5c0418,0x661c39e4,0x88c8460c,0xb87801d3}},	// [2e080] _hivá_, _strk, цлав_, _szír, 
   {{0xc7641a59,0x46a40a8d,0x629c0248,0xdb14008e}},	//   بارى, мазв, _àrog, gizä, 
   {{0x463812c4,0x48dc012c,0x63b400c7,0x00000000}},	//   ючая_, _कुरो_, ҕәах, --, 
   {{0xea0007ae,0x3ce000e1,0x04440120,0x69c8007f}},	//   _đặc_, _टुडे_, дедн, èded, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69c4002f,0x63e46911,0x64a4010b,0x00000000}},	//   liie, رۋال, маҗа, --, 
   {{0x661c1711,0x9f5c07de,0xdb2401d3,0x00000000}},	//   _utrk, _rivà_, ásér, --, 
   {{0xb2800228,0x224001f1,0xb380104e,0x76400419}},	//   тышк, čik_, еләл, šnyc, 
   {{0xc05800d6,0xdee80092,0x567c0092,0x00000000}},	//   цій_, መውን_, _የሚነሱ_, --, 
   {{0xdcec0115,0x69c40036,0xf4840244,0x00000000}},	//   _joaĥ, hiie, _تافی, --, 
   {{0x69c4002d,0xbf1001e0,0xf770011a,0x12d00150}},	//   kiie, нүҙә, דקת_, _ﻚﺒﻳﺭ, 
   {{0xdd949ad7,0x9f5c00d7,0x69c4031c,0x0ba400c7}},	//   хамы, _divá_, jiie, ҭырҭ, 
   {{0x6ce402bf,0x61e1aa8f,0xdb0400d8,0xfb8007d6}},	//   віре, moml, _olhã, نگدی, 
   {{0x61e00c54,0x9f5802f6,0xdcec0115,0xea00004d}},	//   loml, örä_, _noaĥ, _phết_, 
   {{0x69c401ab,0x10f000f1,0xbaf40022,0x00000000}},	//   fiie, _لګید, ьҭоу_, --, 
   {{0x79a400d4,0x00000000,0x00000000,0x00000000}},	//   єрве, --, --, --, 
   {{0x57f400c7,0xbcf9aa90,0x00000000,0x00000000}},	// [2e090] епат, ffée, --, --, 
   {{0x61e1aa91,0x67f00108,0xea000051,0x00000000}},	//   homl, täja, _thết_, --, 
   {{0x0af00323,0x61e05f47,0x41dc08ec,0x2ba40073}},	//   _бүрэ, koml, मवास, _ऐकता, 
   {{0x7d180784,0xd4f4010b,0x61e10614,0x00000000}},	//   ñush, нялы, joml, --, 
   {{0x61e1aa92,0xf8bc00e8,0x23bc0d79,0x6bd402f2}},	//   doml, _reéw_, ्चंद, _ستیر, 
   {{0x362001d9,0x972400f1,0x5724129d,0x67f001f4}},	//   _لوسہ, _سفرو, _سىرك, päja, 
   {{0x6d41aa93,0xb7e83885,0x00000000,0x00000000}},	//   ómak, _जीएम_, --, --, 
   {{0x9a38001f,0x61e003b2,0x80c8000d,0x00000000}},	//   _እውነቱ, goml, ापूं, --, 
   {{0x9f5c00d0,0x7ff400e5,0xe45401af,0x00000000}},	//   _sivá_, کسٹا, _икты, --, 
   {{0xb87801e1,0x69c40112,0x9f5c00d7,0x00000000}},	//   _ayík, ziie, _pivá_, --, 
   {{0x61e1aa94,0xdd040055,0x00000000,0x00000000}},	//   boml, _āsār, --, --, 
   {{0x8d75aa95,0x8c44c45c,0x73300137,0x10d400c0}},	//   راجا, неме, _سىچا, _пілё, 
   {{0x69c40254,0x00000000,0x00000000,0x00000000}},	//   viie, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69c403fa,0x00000000,0x00000000,0x00000000}},	//   tiie, --, --, --, 
   {{0xed640122,0xfbdc0798,0xa9280308,0xbcf800e8}},	//   _drží_, rrêa_, drží, wfée, 
   {{0x69c41cc4,0x00000000,0x00000000,0x00000000}},	// [2e0a0] riie, --, --, --, 
   {{0xf99c020c,0x61e1aa96,0x66180518,0xbcf80022}},	//   _hièl_, zoml, ívko, teév, 
   {{0xb6a0036b,0x61e1aa97,0x00000000,0x00000000}},	//   лифл, yoml, --, --, 
   {{0x7641aa98,0xe97402dd,0x75c802dd,0x00000000}},	//   ánya, _جۇرد, птің_, --, 
   {{0xfb0805f5,0xf99c007f,0x245800c0,0x61e1aa99}},	//   _óëñ_, _mièl_, фаль_, voml, 
   {{0x823413d7,0x61e0014b,0x61400419,0x00000000}},	//   ىرعا, woml, zílč, --, 
   {{0x864402d3,0x366401ee,0x387c031c,0xc20400d8}},	//   _ካልኦት, _паро_, _ġuri_, нџии, 
   {{0x5924025c,0x55f42063,0xe3b001d9,0x00000000}},	//   _འབབས_, _ачуу, درچ_, --, 
   {{0x67f0023a,0xd4080131,0xe7c4009e,0x00000000}},	//   näjo, ستۇم_, ্তীয, --, 
   {{0x74100690,0x7dc801f4,0x00000000,0x00000000}},	//   _صوما, kösä, --, --, 
   {{0x61e001f7,0x67f0005b,0x2ae00037,0x00000000}},	//   poml, häjo, _खुलँ_, --, 
   {{0x7171aa9a,0x61e031c5,0xbcf800e4,0x00000000}},	//   _مهما, qoml, keét, --, 
   {{0x67f00108,0x00000000,0x00000000,0x00000000}},	//   jäjo, --, --, --, 
   {{0xa135120a,0xc0c400b7,0x00000000,0x00000000}},	//   _سرچش, ሽነር_, --, --, 
   {{0xf99c007f,0xbdf80137,0xead40108,0x19588ca3}},	//   _fièl_, _ىرعا_, горь, мавы_, 
   {{0xdd9000f1,0x00000000,0x00000000,0x00000000}},	//   _څوګ_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [2e0b0] --, --, --, --, 
   {{0xacf800fb,0xdb0400e5,0x00000000,0x00000000}},	//   _яныу_, _elhá, --, --, 
   {{0x24840589,0x7bc5aa9b,0xfbd001d9,0xded00023}},	//   _armm_, miju, _لتھ_, _ብርኪ_, 
   {{0x7bc5aa9c,0xf99c02e2,0x00000000,0x00000000}},	//   liju, _kièm_, --, --, 
   {{0x7bc40083,0xdb04007c,0x6d400332,0x00000000}},	//   oiju, _cmhö, ómai, --, 
   {{0x7bc5aa9d,0xf3b00124,0x00000000,0x00000000}},	//   niju, ыҩзы, --, --, 
   {{0x67d5aa9e,0x5275aa9f,0x24840ac5,0x4370007b}},	//   _сору, тулу, _ermm_, شهير, 
   {{0x7bc5aaa0,0xd1b80244,0x00000000,0x00000000}},	//   hiju, باتا_, --, --, 
   {{0x7bc5aaa1,0xf99c007f,0xa4d402bf,0xf1bc00d0}},	//   kiju, _nièm_, _боті, žšom_, 
   {{0x7bc4b8b7,0x0ea8023a,0x273c00bc,0xf99daaa2}},	//   jiju, дкой_, mání_, _sièl_, 
   {{0x273c0316,0x7bc4f5ef,0xb2a8023a,0x226402fb}},	//   lání_, diju, _этаж_, čská_, 
   {{0xf99daaa3,0xfe6c2807,0x7bc40064,0x2174014b}},	//   _noè_, تگه_, eiju, _бушр, 
   {{0x85380302,0x273c0316,0x7bc40200,0x6abc01ef}},	//   וגרי, nání_, fiju, ोप्र, 
   {{0x7bc5aaa4,0x6ca400f7,0x7dc801f4,0x00000000}},	//   giju, _ۅلبۅ, tösä, --, 
   {{0x273c012c,0x8db40111,0x451400fe,0x00000000}},	//   hání_, _аспі, াৰিক_, --, 
   {{0x273daaa5,0x4c8401c0,0x3ea8005c,0x67f001f4}},	//   kání_, _алив, øbte_, täjo, 
   {{0xed580efb,0x7bc5aaa6,0xdb1407c5,0x47580cc9}},	// [2e0c0] _жоқ_, biju, hizù, дрея_, 
   {{0x273c038e,0xcb68004b,0x7bc433fc,0xb7440137}},	//   dání_, _ځمکه_, ciju, кпуз_, 
   {{0x69c85f5e,0xf99c02bd,0xdb0408a5,0x67f001f4}},	//   édes, _zièm_, _alhæ, säjo, 
   {{0x8505aaa7,0x67f0005b,0x935400d1,0x15b800cf}},	//   نوان, päjo, ۇرىچ, нычы_, 
   {{0x74107286,0xbcf801d3,0x53dc0263,0x00000000}},	//   لونا, leér, यवंश, --, 
   {{0xe2f81e32,0x27ec0162,0x00000000,0x00000000}},	//   нелі_, _ódn_, --, --, 
   {{0x133800dd,0xe6a001e1,0x00000000,0x00000000}},	//   رتوں_, _ìlàò, --, --, 
   {{0x7bc5aaa8,0x273c0118,0xf1a03c1a,0xf99c0208}},	//   ziju, bání_, ирын, _xoè_, 
   {{0xb030a166,0x7bc42dab,0x35a001c0,0x26180406}},	//   аныш, yiju, _татг, _बंडी_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4425aaa9,0x9f5ccf77,0x7bc435bd,0xdd58010b}},	//   lpo_, _nivå_, viju, нанч_, 
   {{0x4425aaaa,0x7bc5aaab,0xd00c00ec,0xf1a000f3}},	//   opo_, wiju, _کڄي_, _вршн, 
   {{0x7bc5aaac,0x4425aaad,0xab64033f,0x7f84007b}},	//   tiju, npo_, ężni, _للإن, 
   {{0x44244d41,0x9f340046,0x7bc40140,0xf99c0100}},	//   ipo_, _секі, uiju, _vièm_, 
   {{0xbe880046,0x273c012c,0x7bc5aaae,0x4424022e}},	//   _іске_, zání_, riju, hpo_, 
   {{0x7bc40953,0x44240521,0x5d543849,0xf99c033b}},	//   siju, kpo_, _скит, _tièm_, 
   {{0x7bc402d5,0x44240115,0x7d180309,0x00000000}},	// [2e0d0] piju, jpo_, ñusu, --, 
   {{0x273c02f8,0x764000dd,0x2ca50903,0x7bc40194}},	//   vání_, ányo, ämde_, qiju, 
   {{0x4425315d,0x6d480153,0x53a41219,0x00000000}},	//   epo_, ėdav, ғайб, --, 
   {{0x273c012c,0x00000000,0x00000000,0x00000000}},	//   tání_, --, --, --, 
   {{0x44248fc8,0xf65000ec,0x00000000,0x00000000}},	//   gpo_, _ھئس_, --, --, 
   {{0x273c012c,0xe7080137,0x00000000,0x00000000}},	//   rání_, رتەن_, --, --, 
   {{0x442407dd,0xc5ec021a,0x273c0118,0x527400d8}},	//   apo_, _کړل_, sání_, ѓуку, 
   {{0x273c012c,0x44240455,0x5eb80154,0x51f405af}},	//   pání_, bpo_, ঁপাই, دستر, 
   {{0x798c0117,0xf99c0100,0xdb1404cc,0xe5880137}},	//   _mncw, _pièj_, sizù, _جۅنۉ_, 
   {{0xf2c5aaaf,0xae0c012d,0x00000000,0x00000000}},	//   _исен, _सूजन_, --, --, 
   {{0x798c009a,0xf99c007f,0xd130a6e0,0x5fa40210}},	//   _oncw, _vièj_, _هما_, _ओवरल, 
   {{0x3f8c04ba,0xdec40023,0x00000000,0x00000000}},	//   _enfu_, ጸልካ_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbcf82af5,0x317c72a0,0xc2f4015b,0xca745184}},	//   teér, lduz_, _চলতি_, лубы, 
   {{0xc33004ae,0xbcf80332,0x2618012d,0x9d7400db}},	//   מום_, rféa, _बंधी_, اەۋا_, 
   {{0x317daab0,0x4424f25a,0xbcf8007b,0x7d180113}},	//   nduz_, ypo_, sféa, ñust, 
   {{0x38680048,0x6d44009d,0xb7d40101,0x00000000}},	// [2e0e0] _cpcr_, _idia, گولا_, --, 
   {{0x798c3058,0x317c0399,0x6d440036,0x26181098}},	//   _encw, hduz_, _hdia, _बंदी_, 
   {{0x86c41c4e,0xb7d40220,0x46f43417,0x864400c7}},	//   ديان, دولا_, учат, унеж, 
   {{0x4425aab1,0x25a0041e,0xda0800f1,0x00000000}},	//   tpo_, ðil_, _ټيټه_, --, 
   {{0x4425aab2,0x03a53851,0x95741586,0x2905aab3}},	//   upo_, лидо, рыхч, _àma_, 
   {{0xfc1400d9,0x00000000,0x00000000,0x00000000}},	//   אקסי_, --, --, --, 
   {{0x6d45aab4,0x7af4010a,0x72d003cc,0xae042c06}},	//   _odia, _xzxt, مەكچ, रगान_, 
   {{0x4425aab5,0x6d45aab6,0x395c0784,0x00000000}},	//   ppo_, _ndia, _ñust_, --, 
   {{0xd4c09183,0x4424016d,0x00000000,0x00000000}},	//   _мөшк, qpo_, --, --, 
   {{0x6d45aab7,0xfe244494,0xdb04023a,0x00000000}},	//   _adia, льмн, _ylhä, --, 
   {{0x051400bd,0xdd95aab8,0xdea001d5,0x3f800118}},	//   ারীর_, ааны, تیغی, ěku_, 
   {{0x6d44004e,0x9cb400c6,0x62880009,0x1e84013d}},	//   _cdia, لمجت, _irdo, глүм, 
   {{0xa0340131,0x6d440368,0x628802fb,0x5f940256}},	//   _ئىتت, _ddia, _hrdo, _вилт, 
   {{0x6d440c8c,0x69c807ea,0x63b80051,0x00000000}},	//   _edia, èden, nhvn, --, 
   {{0x38680334,0x00000000,0x00000000,0x00000000}},	//   _spcr_, --, --, --, 
   {{0x62881caa,0x64400162,0x764000e5,0x00000000}},	//   _mrdo, _ovmi, ánym, --, 
   {{0xa3e40118,0xe894026b,0x00000000,0x00000000}},	// [2e0f0] फका_, бать, --, --, 
   {{0x6289aab9,0xfc3c00c6,0xf99c067c,0x317c0007}},	//   _ordo, msí_, _mièi_, zduz_, 
   {{0xb879aaba,0xea0001fb,0x6441aabb,0xfc3c0332}},	//   _oxíg, _nhặt_, _avmi, lsí_, 
   {{0x798c4b2a,0x00000000,0x00000000,0x00000000}},	//   _uncw, --, --, --, 
   {{0xfc3daabc,0x49380302,0x3cf00034,0x81c80eac}},	//   nsí_, _בגרו, _घरों_, লকা_, 
   {{0x62881505,0xfc3d0ca1,0x161c134e,0x00000000}},	//   _brdo, isí_, _बंपर_, --, 
   {{0xea00001e,0x588400c7,0x6b7c010f,0xfc3c01e7}},	//   _chặt_, _сыҟа, גרונ, hsí_, 
   {{0x78b80024,0x628802f0,0x317c030a,0xe3b000f7}},	//   _žuvy, _drdo, uduz_, _ۉرل_, 
   {{0x6288bd81,0x4f940c98,0x317c005a,0x00000000}},	//   _erdo, арну, rduz_, --, 
   {{0xfc3c0332,0x6d4400d7,0x00000000,0x00000000}},	//   dsí_, _sdia, --, --, 
   {{0x6d440652,0xe1f007d6,0x64400109,0x628801a6}},	//   _pdia, _کسل_, _zvmi, _grdo, 
   {{0x261800ab,0x6ea40014,0xbcf80022,0xc2200345}},	//   _बंसी_, ٖنگہ_, teép, _بکوو, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbcf8c756,0xfd1c0ffb,0x61e43831,0x6aa805ac}},	//   mfél, acì_, čile, ødfo, 
   {{0xdb2400dd,0x5f74208f,0xbcf83b7b,0xfaa00120}},	//   ásár, _دانر, lfél, оаро, 
   {{0xfd1c0ffb,0x2360009b,0x6d45aabd,0x00000000}},	//   ccì_, điji_, _udia, --, 
   {{0xfbddaabe,0xbcf800e7,0x47c402d5,0x67f001f4}},	// [2e100] guês_, nfél, абав, läji, 
   {{0x2d81aabf,0x320c0122,0x4aa8b6f6,0xed5001d3}},	//   _haie_, _ligy_, _акон_, _بھگ_, 
   {{0x2fc40a2e,0x2d800037,0xca7404b1,0x4a7400db}},	//   _mmng_, _kaie_, _тупы, _тыпт, 
   {{0xc484008e,0xbcf8655d,0x57440022,0xf62000d4}},	//   илек, kfél, инӡб, ідчо, 
   {{0x6288107d,0x2d800037,0x00000000,0x00000000}},	//   _srdo, _maie_, --, --, 
   {{0x051403f4,0x2fc40280,0x02680ce7,0x55c400fb}},	//   ারের_, _nmng_, вший_, _ғауғ, 
   {{0x668470c8,0x2d801368,0xf99c0561,0xd4400023}},	//   _دیال, _oaie_, _sièi_, _ኣይፍቀ, 
   {{0x2fc4089c,0xb95801e1,0x628828b5,0xbcf80165}},	//   _amng_, _amìj, _vrdo, ffél, 
   {{0xbcf8012b,0x043401c0,0x25a40332,0x00000000}},	//   gfél, _түлш_, _ioml_, --, 
   {{0x81447690,0x2d80062c,0x62880219,0x48dc0037}},	//   _چنان, _aaie_, _trdo, _कुछो_, 
   {{0x2d81aac0,0x6289aac1,0xd3b80212,0x320c00d7}},	//   _baie_, _urdo, _суті_, _figy_, 
   {{0x2fc40263,0x2d800076,0xfc3c19e4,0x00c82519}},	//   _emng_, _caie_, tsí_, _илек_, 
   {{0x2d802a1f,0x7d180bf1,0x00000000,0x00000000}},	//   _daie_, ñusq, --, --, 
   {{0xfc3daac2,0xfd1c6933,0x6d40148b,0x2ca40267}},	//   rsí_, scì_, ómar, ämda_, 
   {{0xf9c406bb,0x199406bb,0xb87801ed,0xfc3daac3}},	//   ащан, бавя, _nyír, ssí_, 
   {{0x2d800129,0x64440327,0x00000000,0x00000000}},	//   _gaie_, ġiij, --, --, 
   {{0xae047a32,0xad2401d9,0x57b58d06,0xda700014}},	// [2e110] _بويى, _بر٘و, ббат, _کُج_, 
   {{0xa7b80e26,0x2d8001c0,0x433c001f,0x57180212}},	//   алуу_, _zaie_, ጠበቅባ, ужжя_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbcf801ed,0x00000000,0x00000000,0x00000000}},	//   yfél, --, --, --, 
   {{0x320c0198,0xfbdc00d8,0xa91001e4,0x00000000}},	//   _rigy_, quês_, teɾe, --, 
   {{0x9f5c011c,0x6a1404fb,0x69d80436,0xde58001f}},	//   _tivù_, _دبیر, _íver, _ጉባኤው, 
   {{0x29240086,0x18b404a9,0x00000000,0x00000000}},	//   _òrañ_, _тәңр, --, --, 
   {{0x23b0002e,0xbcf967dc,0x2a840055,0x00000000}},	//   _jàjj_, tfél, _uṣāḥ_, --, 
   {{0x2d81aac4,0xc0cc0023,0x4fe8030d,0x4254004e}},	//   _raie_, _ብልሂ_, лмин_, атөт, 
   {{0xbcf8008c,0x67f0049b,0x66640014,0x2d81aac5}},	//   rfél, täji, _دُہٕ, _saie_, 
   {{0xbcf8012b,0x2d81aac6,0x76400e33,0x91680051}},	//   sfél, _paie_, ányh, _cựu_, 
   {{0xea00001e,0x67f11e05,0x7d180309,0x61e40427}},	//   _đắc_, räji, ñusp, čilc, 
   {{0xb7b800c7,0x2d8004e2,0x00000000,0x00000000}},	//   _atãm, _vaie_, --, --, 
   {{0xe0d001d5,0x00000000,0x00000000,0x00000000}},	//   _تزم_, --, --, --, 
   {{0x2d800276,0x387c00de,0x00000000,0x00000000}},	//   _taie_, _šurp_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x08887bf7,0xc7680124,0xaba4022e,0x00000000}},	// [2e120] ыбай_, лиаж_, _дунë, --, 
   {{0x2478001f,0x00000000,0x00000000,0x00000000}},	//   _በልማት_, --, --, --, 
   {{0x4b0401d9,0xaca4063f,0x3b8001c0,0x2bd80014}},	//   _دِدٕ, knịk, _элэг, _ماگک_, 
   {{0x84444a3b,0xc2ec00cc,0x00000000,0x00000000}},	//   مختل, টেডি_, --, --, 
   {{0x23380032,0x147801d3,0x00000000,0x00000000}},	//   аплы_, لجوں_, --, --, 
   {{0xf99c0d29,0x9f5803ee,0xc35402e8,0x14000139}},	//   _chèf_, örü_, съдъ, дҗуг, 
   {{0xe81c00cd,0xcfcc00eb,0x00000000,0x00000000}},	//   _भूता_, রকান, --, --, 
   {{0xdb040129,0x00000000,0x00000000,0x00000000}},	//   _bohê, --, --, --, 
   {{0x81c80349,0x7cfc01e1,0xdee80092,0xc2c000f1}},	//   লকল_, _màrí, ዘውን_, تيژي, 
   {{0x7cfc0241,0x398c00a2,0x7e2801ca,0xdecc0092}},	//   _làrí, _kösä_, ліма_, _ጤነኛ_, 
   {{0xbcf80122,0xf0b400f2,0x00000000,0x00000000}},	//   rfém, لایش_, --, --, 
   {{0x020580e2,0x236000f3,0xc0580212,0x71a00107}},	//   _узен, điju_, _бік_, _нахз, 
   {{0x67f001f4,0x00000000,0x00000000,0x00000000}},	//   läju, --, --, --, 
   {{0x3f80005f,0xac182766,0x5f940a5b,0xdb140419}},	//   ēkus_, сору_, _фикт, vizó, 
   {{0x37a80046,0x8fc400f2,0x00000000,0x00000000}},	//   қтан_, _بزنن, --, --, 
   {{0xbcf80c6a,0xdb140113,0x00000000,0x00000000}},	//   nfék, tizó, --, --, 
   {{0xdb04069c,0xa8144303,0xe3b80724,0xe894005b}},	// [2e130] _kohë, здуш, _olı_, пать, 
   {{0x81bc0729,0x161c06ab,0x6fb80210,0x00000000}},	//   ঁচি_, _बंदर_, एसयू, --, 
   {{0x59f8084c,0x3e7800de,0x00000000,0x00000000}},	//   _веня_, _jūt_, --, --, 
   {{0xf99c007f,0xe3b84dd9,0xc0cc0240,0x00000000}},	//   _shèf_, _alı_, _ብግስ_, --, 
   {{0x34487136,0xe610129e,0x00000000,0x00000000}},	//   учен_, رشم_, --, --, 
   {{0xd2a89111,0xdb0401c7,0x3944013f,0xf65000db}},	//   икле_, _nohë, ɔnsa_, _ىئز_, 
   {{0x515418a4,0x77740003,0x00000000,0x00000000}},	//   отпу, mexx, --, --, 
   {{0xe3b80724,0xf99c067c,0xd9f8033f,0x7775aac7}},	//   _elı_, _tièu_, ंतित_, lexx, 
   {{0x994c00d0,0x90c4011c,0x00000000,0x00000000}},	//   _vôňu_, юбие, --, --, 
   {{0x3e780029,0x630452cb,0x75380165,0x61e4110c}},	//   _būt_, _کومل, _heuz, čila, 
   {{0x75380936,0xe4240241,0x28d0033f,0xa29401ca}},	//   _keuz, _iṣọd, _सेनि, _нафі, 
   {{0x7538002d,0x8c9401ce,0x041401ec,0xa0c400f1}},	//   _jeuz, оргі, _اكەڭ, _ډيمو, 
   {{0xccf8063b,0x77740548,0x753805c7,0xa91000b0}},	//   рхні_, kexx, _meuz, keɾa, 
   {{0x77740076,0xe0d80212,0x00000000,0x00000000}},	//   jexx, _уві_, --, --, 
   {{0x3e7800e2,0xdb1c01d3,0x00000000,0x00000000}},	//   _gūt_, ózás, --, --, 
   {{0x7539aac8,0x09288639,0xc0900023,0x00000000}},	//   _neuz, ржай_, ግጋጽን_, --, 
   {{0x628402b1,0x00000000,0x00000000,0x00000000}},	// [2e140] āioi, --, --, --, 
   {{0x46f406bb,0x2c6405d5,0xb4840248,0x3ce02d8f}},	//   очет, möd_, _jẹ́ọ, _टुटे_, 
   {{0x2c64014a,0x75380156,0x86984a03,0x09e400db}},	//   löd_, _beuz, штат_, _моон, 
   {{0x44882cc8,0xdb0c02d2,0x81dc00eb,0x67f00108}},	//   ибен_, _áhát, _দীন_, väju, 
   {{0x75380156,0x15b1aac9,0x3b000066,0xbb480023}},	//   _deuz, رەكس, pépé_, _ንምቅላ, 
   {{0xdb05aaca,0xf48442ad,0xf8b005d0,0x629c0241}},	//   _bohè, غانی, _חשש_, _àrok, 
   {{0x673c01c7,0x96f802d5,0x7538036e,0xdcec00ef}},	//   _ierj, _гэту_, _feuz, _knaģ, 
   {{0x7539aacb,0xb7b800e4,0x236c003e,0x7f8400d1}},	//   _geuz, _atãh, _wbdj_, ﺭﺑﯩﻲ_, 
   {{0x673d910f,0xd58404d3,0x28d017ee,0xbcf83847}},	//   _kerj, _رێوه_, _सेमि, rfék, 
   {{0xbfa8084c,0xe3b80724,0x7538009d,0x2c6401e3}},	//   ртие_, _ulı_, _zeuz, död_, 
   {{0x673daacc,0xe81c00af,0x00000000,0x00000000}},	//   _merj, _भूसा_, --, --, 
   {{0x63a8f057,0x7774208d,0xd36c00cf,0x00000000}},	//   _hodn, zexx, _لۇۇ_, --, 
   {{0x661daacd,0x673c000f,0x777405b1,0x91d8010f}},	//   _lurk, _oerj, yexx, _פֿעפ, 
   {{0x673daace,0x63a800f3,0x7774011f,0xbcf80036}},	//   _nerj, _jodn, xexx, nféi, 
   {{0x63a81109,0x661daacf,0x77758435,0x39a47c4a}},	//   _modn, _nurk, vexx, ошав, 
   {{0xdb0400e4,0x63a84f8a,0xbcf801c7,0x00000000}},	//   _johé, _lodn, hféi, --, 
   {{0x673daad0,0x661c152d,0x7539aad1,0xdb040561}},	// [2e150] _berj, _aurk, _reuz, _mohé, 
   {{0xf7700f84,0xd7f1aad2,0x65600597,0x63a80115}},	//   بار_, ركا_, _acmh, _nodn, 
   {{0x661c7dfd,0x673daad3,0x6dc401d9,0x75380156}},	//   _curk, _derj, _رٲیل, _peuz, 
   {{0x661daad4,0xe61802bf,0xac740220,0xf968005a}},	//   _durk, іді_, _راۋش, _трой_, 
   {{0x673daad5,0xf99c067c,0xb864a32b,0x753805c7}},	//   _ferj, _fièr_, _باجو, _veuz, 
   {{0x673daad6,0x39480472,0x661daad7,0x63a80009}},	//   _gerj, _hdcs_, _furk, _codn, 
   {{0x61e40fb7,0x661daad8,0x63a80122,0x75380156}},	//   čiln, _gurk, _dodn, _teuz, 
   {{0xdb04df44,0x764001d3,0x24780092,0xa3cc01f9}},	//   _cohé, ányu, _በግምት_, शोब_, 
   {{0xb36406bb,0x661c16a3,0xdb0401c7,0xdb0c0008}},	//   _мъжк, _zurk, _dohé, _áhæt, 
   {{0x661c0054,0x00c40228,0x2c64014a,0x63a9aad9}},	//   _yurk, ялык_, vöd_, _godn, 
   {{0x73c00032,0xe7ec01ad,0x8f680c60,0xb4b4009f}},	//   _нәҫе, जकता_, _ғайб_, _اُڃا_, 
   {{0x2c6477b6,0xa91001e4,0x00000000,0x00000000}},	//   töd_, deɾn, --, --, 
   {{0x63a801d5,0x21a4072d,0xd478010f,0x2d8400d7}},	//   _yodn, _تمنّ, זאָל, ľme_, 
   {{0x2c64ccfa,0x2d841155,0xe81c3c71,0x403000f0}},	//   röd_, žme_, _भूषा_, _џејс, 
   {{0x7f38011a,0xc95400c7,0x2c6400e5,0x00000000}},	//   _העצו, зтзы, söd_, --, 
   {{0x673c003d,0x69cc0490,0x661c033f,0x99880432}},	//   _serj, _सगळी, _rurk, nmaň_, 
   {{0x661daada,0x00000000,0x00000000,0x00000000}},	// [2e160] _surk, --, --, --, 
   {{0x661daadb,0xa25c0020,0x7d0000ee,0x89a401d9}},	//   _purk, _ሰሞኑን_, _языж, _کھسہ_, 
   {{0x673daadc,0xcb080acb,0x661c0139,0xe81c012d}},	//   _verj, _ديدن_, _qurk, _भूरा_, 
   {{0x673daadd,0x63a8a34d,0x661c0af9,0xba98011a}},	//   _werj, _sodn, _vurk, _הסטי, 
   {{0x673daade,0x661c0225,0xfbdc0129,0xbcf801c7}},	//   _terj, _wurk, prêt_, tféi, 
   {{0x661daadf,0xdb040098,0x63a80067,0x77b003b9}},	//   _turk, _sohé, _qodn, _cıxı, 
   {{0x63a89a4d,0x661c0014,0x9f5c05d5,0xdb0400e4}},	//   _vodn, _uurk, _vivü_, _pohé, 
   {{0x61e409a8,0x63a80034,0xbcf95db1,0x00000000}},	//   čilo, _wodn, sféi, --, 
   {{0xdb040109,0x63a82acf,0xbcf80036,0x6720302b}},	//   _vohé, _todn, pféi, _बलाक_, 
   {{0xbcf9aae0,0xdfd0b823,0x5f9402e8,0x93a8007b}},	//   ngée, ئيد_, фиот, _والف_, 
   {{0xdd90ab80,0xdb040098,0xdb140205,0x9d55aae1}},	//   نود_, _tohé, lizö, وندت, 
   {{0x9f5c004e,0x02040166,0x80a400cf,0xf650011a}},	//   _pivó_, _эзен, _ىمان, עצר_, 
   {{0x39480083,0x79a5aae2,0xdb040030,0x77b00213}},	//   _rdcs_, үрбе, _dlhý, _yıxı, 
   {{0xdfd01564,0xea0001fb,0xfe5400e8,0xa91001e4}},	//   _جيت_, _đạc_, _sa鯵i_, teɾn, 
   {{0xaa9400cf,0xb9580241,0x998400fb,0x00000000}},	//   нирч, _omìt, мтаһ, --, 
   {{0x9f4c025a,0x6ed8011a,0x81c805ac,0x6a14d227}},	//   kodë_, _לחופ, লকক_, емсу, 
   {{0x2d8c013b,0xdcec031c,0x00000000,0x00000000}},	// [2e170] ɛde_, _mbaċ, --, --, 
   {{0x2c8c0022,0xbcf81574,0x37040354,0x00000000}},	//   _ñohẽ_, ggée, пчев, --, 
   {{0xf99c068c,0x1a6432db,0x394801bf,0xdb0402d2}},	//   _chèc_, _تیزی_, _tdcs_, _ylhý, 
   {{0x42a402d3,0x784405f5,0x45a00131,0x77b00213}},	//   ላውነት_, _нэгж, پەكك, _sıxı, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb7b80124,0x764001d3,0xdb1001e1,0xe784014b}},	//   _atãv, ánys, _ògód, _пусо, 
   {{0xdb040798,0xbcf801d3,0x43900a5b,0xf0f40a8a}},	//   _ilhó, ngéb, тајс, ुध्द_, 
   {{0xe61006d0,0xfc3c00db,0x00000000,0x00000000}},	//   _مشق_, nyís_, --, --, 
   {{0xa3b8004b,0x7af4007c,0x00000000,0x00000000}},	//   _ډالر_, _lyxt, --, --, 
   {{0x24800790,0xefc00023,0xca3000d1,0x00000000}},	//   çime_, ጸምዎ_, ﮬﻪﺭ_, --, 
   {{0xb63c037e,0x8ee9aae3,0x00000000,0x00000000}},	//   _ｂｄ_, юмов_, --, --, 
   {{0x8c45aae4,0x00000000,0x00000000,0x00000000}},	//   меме, --, --, --, 
   {{0xa1580006,0xb26803b2,0x00000000,0x00000000}},	//   _хачу_, óðfó, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xaca40241,0xfbdc017a,0x06b00154,0xdb1001e1}},	//   _inọw, trêr_, _টেনি, _ógìd, 
   {{0x9f582776,0x00000000,0x00000000,0x00000000}},	//   örö_, --, --, --, 
   {{0x9f4c0267,0x00000000,0x00000000,0x00000000}},	// [2e180] rmdö_, --, --, --, 
   {{0xf42802dd,0xeb3400db,0x9f4c036e,0xd7f800d4}},	//   _тиiс_, _سۉرد, vodë_, пує_, 
   {{0xbcf8004a,0x36646fe4,0x058421f3,0x1b00009d}},	//   rgée, дахо_, дулм, _бүрн, 
   {{0x89345263,0x9f4c0023,0xc61403d4,0x00000000}},	//   _تعدا, todë_, াৱনা_, --, 
   {{0x98b8007f,0xe37400fd,0xcb2000ab,0x39780375}},	//   _yesč_, еллы, _मलाड_, _וטכנ, 
   {{0xb3700075,0x34900107,0x00000000,0x00000000}},	//   ندىش, ташр, --, --, 
   {{0xf6204166,0x261803ce,0x4e18000d,0xc2040798}},	//   _адсо, _बंटी_, _नंगई_, мџии, 
   {{0xbbb81810,0x00000000,0x00000000,0x00000000}},	//   _उत्क, --, --, --, 
   {{0x60980592,0x00000000,0x00000000,0x00000000}},	//   سندس_, --, --, --, 
   {{0x733000db,0x00000000,0x00000000,0x00000000}},	//   _لىكا, --, --, --, 
   {{0x05c006bc,0x22ac0134,0x1df80006,0x28d001ad}},	//   _शताब, bɛka_, зены_, _सेसि, 
   {{0xd24c05d9,0xa91001e4,0x00000000,0x00000000}},	//   _اچو_, teɾl, --, --, 
   {{0xfbd001d9,0x00d80133,0x00000000,0x00000000}},	//   نتس_, _ببات_, --, --, 
   {{0xb9580241,0xbf140137,0xb26803b2,0x00000000}},	//   _nmìr, _قوشب, óðgó, --, 
   {{0xdcfc03ee,0xb878021c,0xbdf802dd,0x053c0ca8}},	//   rksı, _exíl, _ورعا_, _èèwò_, 
   {{0x629c0129,0x7de4007b,0x200c2ca8,0xdcfc0205}},	//   _àrou, _تستم, lmdi_, sksı, 
   {{0x28f834d8,0xbc04004e,0x00000000,0x00000000}},	// [2e190] деть_, _очой, --, --, 
   {{0x200c007f,0x00000000,0x00000000,0x00000000}},	//   nmdi_, --, --, --, 
   {{0xd6d133be,0x06b0015b,0x00000000,0x00000000}},	//   دقا_, _টেবি, --, --, 
   {{0x395c0158,0x28d015e0,0x690902a3,0x0af001c6}},	//   _øus_, _सेवि, ördü, _сүсэ, 
   {{0xe824020a,0xf8c400cd,0x00000000,0x00000000}},	//   _афсо, _रेचय, --, --, 
   {{0xe7302606,0xaee000b8,0x42a40023,0x00000000}},	//   _نصف_, _huṅk, ላፍነት_, --, 
   {{0x42500214,0x9f4c0129,0xaee0002b,0xe664030d}},	//   هنور, codé_, _kuṅk, _итто, 
   {{0xbcf80077,0x659400c7,0x26040139,0x6e440023}},	//   nfés, _иасу, _ачуг, _መሰኻኽ, 
   {{0x8fd11de3,0x2485aae5,0x26180dad,0xd374026a}},	//   ләкә, _gsmm_, _बूटी_, _плаћ, 
   {{0xb4a80073,0x00000000,0x00000000,0x00000000}},	//   खही_, --, --, --, 
   {{0xf1a401c6,0x00000000,0x00000000,0x00000000}},	//   _ордн, --, --, --, 
   {{0xdb140036,0xe13400c0,0x00000000,0x00000000}},	//   ckzé, _анцы, --, --, 
   {{0x5ed000eb,0x00000000,0x00000000,0x00000000}},	//   _সুদে, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfc00011c,0x00000000,0x00000000,0x00000000}},	//   упро, --, --, --, 
   {{0xb87800d8,0xdcec0427,0x00000000,0x00000000}},	//   _exím, _zbač, --, --, 
   {{0x3f940055,0x9f4c0139,0x00000000,0x00000000}},	// [2e1a0] _åcuþ_, bldä_, --, --, 
   {{0x9f4c0066,0x00000000,0x00000000,0x00000000}},	//   todé_, --, --, --, 
   {{0x61240b23,0x28d0012c,0xbb3800d9,0x764001d3}},	//   lōlō, _सेरि, _מעיי, ányp, 
   {{0x63e404a9,0x7cd40214,0x9f4c0306,0x61e40219}},	//   ھۋال, _آویز_, rodé_, čilk, 
   {{0xded01b49,0x69c5aae6,0x200c0ad9,0x7ec401d3}},	//   _ብይን_, mhie, ymdi_, _képé, 
   {{0xe2f99ed3,0x69c5aae7,0xbcf80098,0x7c280129}},	//   мелі_, lhie, ngéa, _égre, 
   {{0xbcf820ef,0xdb140221,0x37e18ce1,0x7ec40098}},	//   nfér, chzä, _сорг, _mépé, 
   {{0xb9580113,0x7ec401ed,0x69c5aae8,0x1ae40154}},	//   _ilìc, _lépé, nhie, _গরমে_, 
   {{0xc0580212,0x60c40327,0x75d0007b,0x98b80139}},	//   чій_, _żimb, _إيقا, _ybsı_, 
   {{0x2019aae9,0x74100244,0x4424016d,0x80c002dd}},	//   öri_, _موقا, mqo_, _ەڭدە, 
   {{0x52840124,0x4424f526,0x69c5aaea,0x00000000}},	//   _аӡын_, lqo_, khie, --, 
   {{0xa3cc0cb4,0x69c401f5,0x4425aaeb,0xc0c82bbd}},	//   शोर_, jhie, oqo_, _нуле_, 
   {{0x28d04eae,0x4424daaa,0x69c4025c,0x6ce401ec}},	//   _सेलि, nqo_, dhie, гіре, 
   {{0xf99daaec,0xbcf82047,0x7ec4003e,0xdcec1050}},	//   _chèn_, ffér, _cépé, _ubač, 
   {{0x69c5aaed,0x7ec406af,0x44240978,0xaee000b8}},	//   fhie, _dépé, hqo_, _puṅk, 
   {{0x69c5aaee,0x4424102c,0x98ac08a4,0xdb040022}},	//   ghie, kqo_, _žeđ_, _pohâ, 
   {{0x99806661,0x44240978,0xbcf800d7,0x00000000}},	// [2e1b0] _huhū_, jqo_, afér, --, 
   {{0xa8a5aaef,0x69c40165,0x4424047e,0x69c80129}},	//   ырск, ahie, dqo_, èder, 
   {{0x69c5aaf0,0x00000000,0x00000000,0x00000000}},	//   bhie, --, --, --, 
   {{0xdec402d3,0x94780063,0xe6100c4f,0x00000000}},	//   ጸልና_, дску_, مشن_, --, 
   {{0xd4681a92,0x4424047e,0x161c01ad,0x98a8012d}},	//   филе_, gqo_, _बंकर_, dbać_, 
   {{0xe3b802dd,0x00000000,0x00000000,0x00000000}},	//   нбі_, --, --, --, 
   {{0x44240014,0x02c00212,0xf1cc00cd,0x645c0171}},	//   aqo_, ийшо, तोऽन, _ārie, 
   {{0xa224034c,0x4424047e,0x00000000,0x00000000}},	//   دروه, bqo_, --, --, 
   {{0x224000f3,0x1ae400cc,0xb2680162,0xbcf800e5}},	//   ćika_, _গৰমে_, óðbó, zfér, 
   {{0x69c40489,0xddc805a1,0x4f940120,0x00000000}},	//   zhie, _ćošk, триу, --, 
   {{0xeadc03f4,0x7ec5aaf1,0x69c4a2d1,0xf99c0051}},	//   _ধর্ম, _répé, yhie, _nhèo_, 
   {{0x7ec40332,0x00000000,0x00000000,0x00000000}},	//   _sépé, --, --, --, 
   {{0x8f68036b,0x7ec40c6a,0xf99c004d,0x317c1165}},	//   _жалб_, _pépé, _phèn_, meuz_, 
   {{0x317c05c7,0x69c4031c,0x13b400eb,0x00000000}},	//   leuz_, whie, _ঝগড়, --, 
   {{0xbb407428,0x8cd005f9,0xb92c0521,0xf99c004d}},	//   реск, _ढेरो, _ụtụt, _chèo_, 
   {{0x8cb400a8,0xbcf82dfb,0x317caf7a,0x4424047e}},	//   _асоч, rfér, neuz_, yqo_, 
   {{0x69c5aaf2,0xbcf9aaf3,0xe81c05f9,0xdb040124}},	// [2e1c0] rhie, sfér, _भूखा_, _pohã, 
   {{0x6d45aaf4,0x61e46b48,0x6e218df9,0x7c380311}},	//   _heia, čili, _kunb, ţurc, 
   {{0xbcf852ce,0x6d45aaf5,0x6e21aaf6,0x4424047e}},	//   ngén, _keia, _junb, wqo_, 
   {{0x6d440363,0x6e200455,0x4424047e,0xd5b80a4a}},	//   _jeia, _munb, tqo_, нсі_, 
   {{0x6d45aaf7,0x6e208489,0x03a40b3b,0x44240009}},	//   _meia, _lunb, кидо, uqo_, 
   {{0x6d45aaf8,0xa3cc068f,0xfc3c0077,0x4424016d}},	//   _leia, शों_, nxía_, rqo_, 
   {{0x6e21a871,0xb6a00408,0x4424bf70,0x629c0419}},	//   _nunb, _кирл, sqo_, _šrob, 
   {{0x6d442486,0xdb040077,0x4424016d,0x7d180153}},	//   _neia, _johá, pqo_, žusi, 
   {{0xf4842a77,0x4425aaf9,0x5ff40120,0xdb05aafa}},	//   _لالی, qqo_, лзиу, _mohá, 
   {{0x6d440418,0x6e21aafb,0x9f4c0332,0x10e80133}},	//   _aeia, _bunb, lldú_, رژنی_, 
   {{0x73300075,0x6e200e89,0xbcf800f2,0x50a401e0}},	//   _ئىما, _cunb, ggén, _ҡушҡ, 
   {{0x6e21aafc,0xdb0402fb,0xeadc0183,0x6288172c}},	//   _dunb, _nohá, _ধৰ্ম, _isdo, 
   {{0x6d4405f5,0x20540111,0xbcf806af,0x00000000}},	//   _deia, _скля, agén, --, 
   {{0xbcf80789,0x6e216faf,0x29e80213,0xf99c004d}},	//   bgén, _funb, yğac_, _phèo_, 
   {{0x6e21aafd,0xdd95aafe,0x6d45aaff,0xdb0402fb}},	//   _gunb, _байы, _feia, _bohá, 
   {{0x201c00b2,0x6d45ab00,0x63880153,0x00000000}},	//   _hivi_, _geia, lūnė, --, 
   {{0x201dab01,0x9f4c2b57,0xdb0401ed,0x6e20005a}},	// [2e1d0] _kivi_, hodí_, _dohá, _zunb, 
   {{0x6e21ab02,0x628801a4,0x9f4c022a,0x00000000}},	//   _yunb, _osdo, kodí_, --, 
   {{0xfbd00014,0x6d45ab03,0x7bc43402,0x6e200067}},	//   _متھ_, _yeia, mhju, _xunb, 
   {{0x201dab04,0x7bc44836,0x00000000,0x00000000}},	//   _livi_, lhju, --, --, 
   {{0x62880280,0xf99c007f,0x64400142,0x317c0165}},	//   _asdo, _inè_, _cwmi, veuz_, 
   {{0x201dab05,0x7bc40158,0xbcf806af,0x317c0156}},	//   _nivi_, nhju, ygén, weuz_, 
   {{0x62640137,0x52740228,0x67d5ab06,0x3568d22b}},	//   لايق, уулу, _тору, _оран_, 
   {{0xd1840323,0x201dab07,0xdb040005,0x6e21ab08}},	//   улий, _aivi_, _xohá, _runb, 
   {{0x6d445c10,0x6e21ab09,0xf36477e0,0x62885d43}},	//   _reia, _sunb, _атен, _esdo, 
   {{0x6d45ab0a,0x201dab0b,0xe3b00014,0x23748fdc}},	//   _seia, _civi_, _ورل_, _نامح, 
   {{0x201dab0c,0xd175ab0d,0xf99c033b,0x8aa40220}},	//   _divi_, _былы, _onè_, _ءﻭﻧﯩ, 
   {{0xbcf8180f,0xaee00241,0x6d44003a,0xf1a842b5}},	//   rgén, _aiṣi, _qeia, _تائه_, 
   {{0x6d45ab0e,0x9f5c0798,0xdb0413d5,0xa91001e4}},	//   _veia, _pivô_, _rohá, peɾi, 
   {{0x7bc40c95,0x6e2081d6,0xf99c05d5,0x62880334}},	//   ghju, _tunb, _anè_, _ysdo, 
   {{0xfc3c172e,0xdb041dee,0x2d8407ea,0x6d45ab0f}},	//   rxía_, _pohá, ômes_, _teia, 
   {{0x201c05a1,0x3b0403b7,0xb7b801fb,0x7bc4000d}},	//   _zivi_, ѓето_, _quãn, ahju, 
   {{0x201c02b9,0x161c00e1,0x090454fa,0xed5800d1}},	// [2e1e0] _yivi_, _बंजर_, упан, _зоқ_, 
   {{0x7bc408e5,0x7c285941,0x6fc039bc,0x00000000}},	//   chju, _égra, षसिं, --, 
   {{0xfc3c0077,0x00000000,0x00000000,0x00000000}},	//   nxín_, --, --, --, 
   {{0x9f4c022a,0x00000000,0x00000000,0x00000000}},	//   vodí_, --, --, --, 
   {{0x3e4c033f,0xf990011a,0x00000000,0x00000000}},	//   zęt_, _פרש_, --, --, 
   {{0x64a40661,0x648401ec,0x337000d4,0xf8b0011a}},	//   лаҗа, лқұж, йгір, _השש_, 
   {{0x66844eaf,0x201dab10,0x00000000,0x00000000}},	//   _خیال, _rivi_, --, --, 
   {{0x201dab11,0x9f4dab12,0x2055ab13,0x00000000}},	//   _sivi_, kodã_, акия, --, 
   {{0x201c0f03,0x00000000,0x00000000,0x00000000}},	//   _pivi_, --, --, --, 
   {{0x30740597,0x23b800dc,0x2c0400cd,0x38940092}},	//   احية_, _अविद, _शीलं_, ቅሰቃሴ_, 
   {{0x7410b65a,0x201dab14,0x42500050,0xb7d80375}},	//   _اولا, _vivi_, _اۆبر, תקיי, 
   {{0xceb519ba,0xaee000b8,0x3e4c012d,0x3da40798}},	//   рәш_, _siṣi, ręt_, уроб, 
   {{0x201dab15,0xfcd00020,0x00000000,0x00000000}},	//   _tivi_, _የዋጋ_, --, --, 
   {{0x5a35ab16,0x93b40208,0x00000000,0x00000000}},	//   ингт, _lĩn, --, --, 
   {{0x7bc4795b,0x49300521,0xe51400cd,0xdcfc0064}},	//   rhju, _ọzọk, तेति_, mesč, 
   {{0x3f8dab17,0xf99c001e,0xbdf800ec,0xdd080419}},	//   _hafu_, _thèm_, _ڪرڻا_, môžm, 
   {{0x06b011ba,0x3f8dab18,0x49a40032,0xa3d409bb}},	// [2e1f0] _টেলি, _kafu_, шырғ, हफा_, 
   {{0x0594006c,0x36e81a59,0x3f8c0003,0xe8f800f7}},	//   یانگ, ىراپ_, _jafu_, унуч_, 
   {{0x3f8dab19,0x37055fe1,0x00000000,0x00000000}},	//   _mafu_, учав, --, --, 
   {{0x29e81248,0x3f8c0b23,0xf99c026c,0xf8bc06af}},	//   lğan_, _lafu_, _unè_, _agée_, 
   {{0xdcfc02d5,0x934400ee,0xdb040790,0xd4a409a5}},	//   kesč, анле, _bohç, рилй, 
   {{0x29e80598,0x3f8dab1a,0x798c0142,0x00000000}},	//   nğan_, _nafu_, _hacw, --, 
   {{0x5eb800cc,0x00000000,0x00000000,0x00000000}},	//   ুপুং, --, --, --, 
   {{0x3f8c0421,0xf8bd2bd1,0x00000000,0x00000000}},	//   _aafu_, _egée_, --, --, 
   {{0x798c200c,0x3f8dab1b,0x0fc404a9,0x41a40cc8}},	//   _macw, _bafu_, ийин, рвын_, 
   {{0x798c00d2,0xdb041ba6,0xd0080640,0x73c001af}},	//   _lacw, _kohä, ђене_, _ыҡла, 
   {{0xf99c033b,0x3f8dab1c,0xd5b813e0,0xddc80841}},	//   _chèk_, _dafu_, _आवाज, _šoši, 
   {{0xf99c00f2,0x798c0548,0x77b8003a,0x7054010a}},	//   _dhèk_, _nacw, _dîxi, _йĕме, 
   {{0x3f8c0421,0xa3cc00af,0x705000cf,0x50445f18}},	//   _fafu_, शोक_, _اچبا, _телб, 
   {{0x3f8dab1d,0x9f880184,0x09dc0490,0x798c02d0}},	//   _gafu_, _башҡ_, नच्य, _aacw, 
   {{0x798c00d2,0x393001f2,0x0d2006d3,0x9ac40166}},	//   _bacw, _ụfụ_, _мүнү, бирҗ, 
   {{0x88e40276,0x798c0042,0x00000000,0x00000000}},	//   ажбе, _cacw, --, --, 
   {{0x798c0050,0x4735ab1e,0x4ad400c5,0xbe100116}},	// [2e200] _dacw, لراز, _डेरव, _بويع, 
   {{0x7d180419,0x44a401b9,0x00000000,0x00000000}},	//   ľust, یماق, --, --, 
   {{0x0685ab1f,0x798ccd1e,0x00000000,0x00000000}},	//   рген, _facw, --, --, 
   {{0x798c00ca,0x25a1ab20,0x00000000,0x00000000}},	//   _gacw, ñil_, --, --, 
   {{0x29040022,0x93b40208,0x00000000,0x00000000}},	//   _áma_, _vĩn, --, --, 
   {{0x798c0472,0x00000000,0x00000000,0x00000000}},	//   _zacw, --, --, --, 
   {{0x3f8c01c8,0x798c009a,0x461404d3,0x93b40051}},	//   _rafu_, _yacw, _نوسر, _tĩn, 
   {{0x3f8dab21,0x00000000,0x00000000,0x00000000}},	//   _safu_, --, --, --, 
   {{0x3f8c01e4,0xca3406ba,0x6abc0042,0x00000000}},	//   _pafu_, _ﻗﯩﺰ_, hyrf, --, 
   {{0xe1d00491,0x3f8c011f,0x00000000,0x00000000}},	//   _ṧṃṧ_, _qafu_, --, --, 
   {{0xcd3c3ce1,0xdd95ab22,0x6e605aa2,0xc0cc00b7}},	//   ﯩﻨﯩﯔ_, баны, отяж, _ሥፍራ_, 
   {{0x3f8dab23,0x6abc143a,0x71a008ca,0x00000000}},	//   _wafu_, dyrf, _махз, --, 
   {{0x764000dd,0x9988033f,0xdcfc0024,0x195814d4}},	//   ányz, ymał_, pesč, ғазы_, 
   {{0x3f8d266c,0x98e40032,0x3078025d,0xb098011a}},	//   _uafu_, ҡсаһ, _סאונ, _שיגר, 
   {{0x29e80598,0xe0e800bd,0x1959ab24,0xf969ab25}},	//   rğan_, _পরিভ, лавы_, край_, 
   {{0xbcf800d5,0xdef80150,0x00000000,0x00000000}},	//   ngék, _иық_, --, --, 
   {{0x7c640131,0x00000000,0x00000000,0x00000000}},	// [2e210] _ئابل, --, --, --, 
   {{0x798c014b,0x7bd401e2,0xdb0400e4,0x6abc2b96}},	//   _wacw, _umxu, _pohä, byrf, 
   {{0x36880395,0xca34313e,0x00000000,0x00000000}},	//   ъсан_, _ﻗﯩﺲ_, --, --, 
   {{0x798c02d0,0x06d400eb,0x6c4800e5,0x00000000}},	//   _uacw, _তুহি, _حلیف_, --, 
   {{0x24f80aec,0x66dd56de,0x74685a1c,0x9878008f}},	//   анцы_, _påkø, трев_, _גאָט, 
   {{0x28d00141,0xdb0c02d2,0x00000000,0x00000000}},	//   _सेटि, _áhót, --, --, 
   {{0xb5a43da1,0x00000000,0x00000000,0x00000000}},	//   _край, --, --, --, 
   {{0xb9580268,0x00000000,0x00000000,0x00000000}},	//   _olìm, --, --, --, 
   {{0x99880165,0x3444013d,0xa938011a,0xd09801c8}},	//   mmań_, _түли_, בטחה_, ائبا_, 
   {{0x0e640139,0x0fc40116,0x00000000,0x00000000}},	//   бкон, сйон, --, --, 
   {{0xb4e41d8a,0xa294187f,0x623400f3,0x00000000}},	//   _पशु_, _мафі, _деху, --, 
   {{0x4ea40588,0x0eb801e0,0x9f4c02f0,0xa2c8009d}},	//   арҭа, _ҡуйы_, rodá_, _тууз_, 
   {{0xbcf8003e,0x2fb00166,0x00000000,0x00000000}},	//   ngéh, _дөня, --, --, 
   {{0xbae001ec,0x0b580ce8,0x6abc007c,0x00000000}},	//   _ﺍﺣﺒﺎ, ырмы_, tyrf, --, 
   {{0xdd1003c6,0x4e349f21,0x00000000,0x00000000}},	//   _výšk, _اعتز, --, --, 
   {{0x60cc1ae4,0x6c6400c7,0x6e440023,0xe0e800fe}},	//   _ölmü, _деиҕ, _መሰናኽ, _পৰিভ, 
   {{0x69d80006,0xc4e00154,0x6d400e2d,0xa91001e4}},	// [2e220] _įved, _বর্জ, ımad, veɾs, 
   {{0x2bd801d9,0x5fc003ba,0xcf2400eb,0x00000000}},	//   _خابک_, एसएल, _মজুদ_, --, 
   {{0x61200327,0x3fa000a2,0x00000000,0x00000000}},	//   ཿཨོཾ_, _ösuş_, --, --, 
   {{0xc4c86f34,0x026801a9,0x00000000,0x00000000}},	//   ллеж_, ҳший_, --, --, 
   {{0x98a80205,0x6d5800ef,0x00000000,0x00000000}},	//   mbağ_, _ēval, --, --, 
   {{0x2fc4079b,0x69c8002d,0xf1c40306,0x46a5ab26}},	//   _nlng_, êdef, šály_, _лагв, 
   {{0x43740220,0xa2846e0c,0xb37000db,0x00000000}},	//   _қуат, تیاو, سدوش, --, 
   {{0x2fc41e92,0xf99c0066,0x1b1404c5,0x9f640077}},	//   _alng_, _dhèw_, তুকে_, _átúa_, 
   {{0x2fc4020b,0x25a40789,0x00000000,0x00000000}},	//   _blng_, _inml_, --, --, 
   {{0xaac8000d,0x64a4190b,0x749800df,0xc3e43fe6}},	//   रनाक, _лаға, _גימפ, _اثرو, 
   {{0x733000db,0x52740395,0xceb40124,0x2e280092}},	//   _رىنا, _муцу, жәы_, _ተቃውመ, 
   {{0xbcf812f2,0xceac00ec,0x00000000,0x00000000}},	//   lgéi, ئڙو_, --, --, 
   {{0x25a4002d,0x26e4012c,0x5ed00154,0xbcf80332}},	//   _mnml_, कपुर_, _সুখে, ogéi, 
   {{0xbcf80221,0x8c380107,0x00000000,0x00000000}},	//   ngéi, рорӣ_, --, --, 
   {{0xbcf80332,0x31d002f2,0x00000000,0x00000000}},	//   igéi, _بقۆز, --, --, 
   {{0xf770004b,0xdb0400d0,0x3ebc03cd,0xdd0403e0}},	//   ګار_, _kohú, mytt_, şpın, 
   {{0x06d42158,0xbbe80502,0xa3e80574,0x57b5ab27}},	// [2e230] _তুলি, _مردم_, मचा_, обат, 
   {{0x2a980100,0xb7b800c7,0xf7707660,0xc4e003d4}},	//   _fčb_, _kuãi, ثار_, _বৰ্জ, 
   {{0x3ebcce29,0x6adc015b,0xde680240,0x00000000}},	//   nytt_, _মুঠো, _ተሰኪሙ_, --, 
   {{0x25a4004e,0x82e40327,0x00000000,0x00000000}},	//   _cnml_, _སྨེའ, --, --, 
   {{0x2a98007f,0x13f401f4,0x00000000,0x00000000}},	//   _zčb_, оздя, --, --, 
   {{0x7f480135,0x3ebc0267,0xf36400d8,0xa92800d7}},	//   _nefq, kytt_, стдн, _vyžš, 
   {{0xca3c1df2,0x69c8000f,0x00000000,0x00000000}},	//   ﻟﻤﺎ_, êdeg, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2fc4870e,0x7f48022f,0x394807ea,0xb7d8009e}},	//   _plng_, _befq, _mecs_, বকীয়, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7f4801f5,0xf2c401c0,0xe5bc00ef,0x00000000}},	//   _defq, _усан, _dūņā, --, 
   {{0x2fc40280,0x2bb41a47,0xbcf8003e,0x9e9400cf}},	//   _wlng_, ुस्थ, ngéw, ساپچ, 
   {{0x2fc40a2e,0xa03000db,0x00000000,0x00000000}},	//   _tlng_, _كۉيت, --, --, 
   {{0x8fa48c02,0x24800259,0xcb68026a,0x5f94005b}},	//   _факе, çimi_, јаве_, _ничт, 
   {{0xdde8adb0,0xf99c068c,0x394806af,0xaee0237e}},	//   _گروه_, _lhèu_, _becs_, _رۋحى, 
   {{0x394800db,0x2a98007f,0x2de800f1,0x00000000}},	//   _cecs_, _včb_, _دوبۍ_, --, 
   {{0xf99c068c,0xdb08002d,0xe6e80032,0x2a98007f}},	// [2e240] _nhèu_, _űnôf, әгеҙ_, _wčb_, 
   {{0x8699ab28,0xc7640533,0x3d0c0073,0x6f000432}},	//   итет_, تارى, _ठरते_, _kync, 
   {{0x4528311b,0x6e25ab29,0x00000000,0x00000000}},	//   ажен_, _kiib, --, --, 
   {{0x7e7d696f,0x6f0000ad,0x6e240067,0xd49801ec}},	//   _äppe, _mync, _jiib, өрі_, 
   {{0x69c4038f,0x64c4f14a,0x6e25ab2a,0x6f001da7}},	//   mkie, वनेश, _miib, _lync, 
   {{0x6e25ab2b,0x69c5ab2c,0xa2940212,0x00000000}},	//   _liib, lkie, закі, --, 
   {{0x69c43129,0xbcf95db1,0x71f400ec,0x00000000}},	//   okie, rgéi, ڊريس_, --, 
   {{0x394800db,0x6e240254,0xbcf80036,0xdb2001c7}},	//   _xecs_, _niib, sgéi, étéi, 
   {{0xbfa9ab2d,0x69c46e98,0xdee80092,0x436821f3}},	//   атне_, ikie, ኘውን_, _вазн_, 
   {{0xdd0801a2,0x6e240083,0x6f000368,0xf344084c}},	//   _pôži, _aiib, _bync, _мпул_, 
   {{0x69c5ab2e,0x6e25ab2f,0xdb040241,0xf0b404fb}},	//   kkie, _biib, _fohù, مایش_, 
   {{0x6e25ab30,0x6f00010e,0x3ebc03cd,0x69c4012d}},	//   _ciib, _dync, rytt_, jkie, 
   {{0x6e243a97,0xf8bc0c6a,0x69c40034,0x39480f85}},	//   _diib, _agén_, dkie, _recs_, 
   {{0x60cc2c70,0x69c400da,0x3949ab31,0x63a40198}},	//   ılmı, ekie, _secs_, ɓinc, 
   {{0xaa9405f5,0x69c4bab7,0x6e240254,0xb4e401ad}},	//   мирч, fkie, _fiib, _पश्_, 
   {{0x61e004b9,0x3c2c6047,0x69c5ab32,0x6e24022f}},	//   niml, _tüv_, gkie, _giib, 
   {{0xfb2404fb,0x394800e2,0x60c0005b,0xe9f801ec}},	// [2e250] _وردپ, _vecs_, nymm, інуі_, 
   {{0x6c84b522,0x61e18718,0x6e240472,0x37046ee2}},	//   _کلیم, himl, _ziib, очев, 
   {{0x61e1ab33,0x60c006a3,0x9b9400c7,0xfc3c004e}},	//   kiml, hymm, _диҿц, lpí_, 
   {{0x69c5ab34,0x60c03ff2,0xe6109717,0x6e2417bb}},	//   ckie, kymm, نشن_, _xiib, 
   {{0x183404ac,0x61e1ab35,0xf1c40118,0x53a4004e}},	//   _מאָל_, diml, šáky_, залб, 
   {{0xd7c800aa,0x76440218,0x8881ab36,0xf30001c6}},	//   _اوسه_, _twjy, _سیمن, мжлү, 
   {{0x660002d0,0xf5e40212,0x61e01427,0x00000000}},	//   _fkmk, _діам, fiml, --, 
   {{0xdb040036,0x61e00205,0x00000000,0x00000000}},	//   _anhë, giml, --, --, 
   {{0xa3b800dd,0x60c0007c,0x00000000,0x00000000}},	//   _ڈالر_, gymm, --, --, 
   {{0x69c5ab37,0x6f0000a9,0x6e25ab38,0x00000000}},	//   zkie, _pync, _siib, --, 
   {{0x6e2400c5,0x69c4033f,0xdb0401e1,0x00000000}},	//   _piib, ykie, _tohù, --, 
   {{0x6f000076,0x61e00342,0x00000000,0x00000000}},	//   _vync, ciml, --, --, 
   {{0x41b000b2,0x6e2400af,0x645c02b1,0x6f000042}},	//   _سمور, _viib, _ārik, _wync, 
   {{0xe0d019b6,0x6f841422,0x69c40210,0x00000000}},	//   _جزم_, _фудж, wkie, --, 
   {{0xfaa10844,0xa3ac0574,0x69c5ab39,0x6e25ab3a}},	//   наро, गात_, tkie, _tiib, 
   {{0xba20d6df,0x69c40171,0xd6b000eb,0xb6000419}},	//   едск, ukie, চনায, ýšla, 
   {{0x2d800263,0xdcfc0356,0x46e8010b,0xbc600153}},	// [2e260] _ibie_, resă, әден_, _звык, 
   {{0x69c5ab3b,0x61e1ab3c,0x2ca00003,0x69c8002d}},	//   skie, ziml, _irid_, êdeb, 
   {{0x61e12bb2,0x3bb80302,0x2ca00841,0x69c5ab3d}},	//   yiml, _המיד, _hrid_, pkie, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb04067c,0x61e1ab3e,0x2ca00003,0x44f8e3a3}},	//   _anhè, viml, _jrid_, حراج_, 
   {{0x629c00e5,0x00000000,0x00000000,0x00000000}},	//   _árok, --, --, --, 
   {{0x61e0cddf,0xfc1000bc,0x2d81ab3f,0x29e80790}},	//   timl, _žáků_, _obie_, rşaf_, 
   {{0x32500801,0x60c00649,0x7c380276,0x2ca00076}},	//   хвър, tymm, ţuri, _orid_, 
   {{0x61e1416b,0xbcf9ab40,0x00000000,0x00000000}},	//   riml, ngét, --, --, 
   {{0x30109687,0x61e1ab41,0xbfa93ad0,0xe3a45929}},	//   ндыр, siml, стие_, _تشری, 
   {{0x2bb07922,0x60c00108,0x63a802d0,0x7ee4005b}},	//   ञाना, symm, _indn, яцие, 
   {{0x2ca1ab42,0x61e01ffc,0x00000000,0x00000000}},	//   _brid_, qiml, --, --, 
   {{0x2ca0010a,0xdb0473a0,0xfc3c00bc,0x29e80139}},	//   _crid_, _inhé, upí_, lğaw_, 
   {{0xbcf807ea,0x2ca0062c,0xdb040036,0xfc3c004e}},	//   dgét, _drid_, _unhë, rpí_, 
   {{0xdd942ba5,0xfc3dab43,0x19580150,0x00000000}},	//   _жайы, spí_, жабы_, --, 
   {{0xdd91ab44,0xf99c067c,0x63a8003e,0x2ca001e3}},	//   _شوخ_, _ahèr_, _lndn, _frid_, 
   {{0x2ca1ab45,0xd7f015bf,0x7c38010f,0x00000000}},	// [2e270] _grid_, پكا_, ŭurb, --, 
   {{0xf99c0100,0x7c3801e4,0x00000000,0x00000000}},	//   _chèr_, ƭurb, --, --, 
   {{0x248405b1,0xdb040036,0xd6d000d1,0xac3800e5}},	//   _apmm_, _onhé, خقا_, _وسیط_, 
   {{0xd1c0044e,0x63a9ab46,0x00000000,0x00000000}},	//   ትታት_, _andn, --, --, 
   {{0xa3e80073,0x2ca00327,0xe5704116,0x00000000}},	//   मचं_, _xrid_, اطم_, --, 
   {{0x7bc40579,0xbcf81ada,0x65780030,0x98a400c7}},	//   nkju, lgés, _ľahš, _еиҭе, 
   {{0x994c01a2,0x52740276,0x00000000,0x00000000}},	//   _môžu_, фулу, --, --, 
   {{0x63a8019b,0xbcf800dd,0xc690008d,0x6595ab47}},	//   _endn, ngés, _באל_, _пасу, 
   {{0x16dc2cd1,0x7bc42200,0x50a40133,0x00000000}},	//   _मधुब, kkju, بڕال, --, 
   {{0xcee80a8f,0x2ca0025c,0x2628013d,0x466000db}},	//   ждое_, _rrid_, _iğor_, _سۇۇق, 
   {{0xd1742ba5,0xdf00010b,0xf2c407a5,0x00000000}},	//   _жылы, лүшй, _эсан, --, 
   {{0x2ca1ab48,0xdcfc012d,0x00000000,0x00000000}},	//   _prid_, zesą, --, --, 
   {{0x61fc041e,0xa928013a,0x9988010e,0x00000000}},	//   _írla, _lyžá, mlaň_, --, 
   {{0x2ca01654,0x99880432,0x00000000,0x00000000}},	//   _vrid_, llaň_, --, --, 
   {{0x49940124,0x8a040024,0xca3401ec,0x00000000}},	//   мшат, дзве, _ﻗﯩﺞ_, --, 
   {{0x2ca0038f,0xbcf801d3,0x9988010e,0x00000000}},	//   _trid_, ggés, nlaň_, --, 
   {{0xed5802dd,0xefd40092,0x00000000,0x00000000}},	// [2e280] _доқ_, ርጠው_, --, --, 
   {{0xbcf9ab49,0xc1d8000d,0x28c401ad,0xcb680244}},	//   rgét, _बग्ग, लैगि, _بمده_, 
   {{0x63a8010a,0xeaa00055,0xa3ac4f76,0x9988010b}},	//   _rndn, _kaṭu_, गास_, klaň_, 
   {{0xdb0400e4,0x248400d8,0xba98011a,0x00000000}},	//   _johý, _ppmm_, _וסטי, --, 
   {{0xe0e80154,0x69c80153,0x29e803e0,0x00000000}},	//   _পর্ন, ūdes, rşad_, --, 
   {{0x3cd800fe,0xefbc0023,0x02a454d9,0x00000000}},	//   _যুঁৱ, ትሓዊ_, дрим, --, 
   {{0xbcf8255a,0xb9f80092,0x00000000,0x00000000}},	//   ngér, _መች_, --, --, 
   {{0xa3ac1533,0x3d0c0073,0x45841291,0x9988010e}},	//   गाह_, _ठरले_, _تجسّ, glaň_, 
   {{0xe7e003d4,0x00000000,0x00000000,0x00000000}},	//   বকীয, --, --, --, 
   {{0x9ed803b7,0xdfd1ab4a,0xb460074d,0xbcf800e5}},	//   змот_, ايد_, _шкул, zgés, 
   {{0xdd91ab4b,0x6d400790,0x66e40118,0x00000000}},	//   هود_, ıman, कपटक_, --, 
   {{0x7bc403a2,0xa3ac0490,0x60140ba1,0xdb0401c7}},	//   wkju, गाव_, dàme, _unhé, 
   {{0x50a008c9,0x7de80064,0x00000000,0x00000000}},	//   _مەيل, nęsi, --, --, 
   {{0xab844263,0x00000000,0x00000000,0x00000000}},	//   куск, --, --, --, 
   {{0x7bc426b8,0xbcf953b6,0x8e84010a,0xaa5c01ec}},	//   rkju, ggér, _пăрч, жесi, 
   {{0x7bc5ab4c,0x5c740828,0x7de80064,0x00000000}},	//   skju, _злит, kęsi, --, 
   {{0x76ac013f,0x7de800c0,0xbcf800e5,0x00000000}},	// [2e290] mɔyɛ, jęsi, rgés, --, 
   {{0xa8a400a7,0x69c8e5d5,0x00000000,0x00000000}},	//   ърск, ëder, --, --, 
   {{0x6014004e,0x00000000,0x00000000,0x00000000}},	//   càme, --, --, --, 
   {{0x8e500240,0x00000000,0x00000000,0x00000000}},	//   _መደቀሲ, --, --, --, 
   {{0xa92800bc,0x8ca007c1,0x4938011a,0x00000000}},	//   _vyžá, खियो, _מגרו, --, 
   {{0xbb1808b0,0xb4ac02ab,0xe3b828f6,0xbefc01f9}},	//   ﺴﻪﻡ_, _ओपी_, мбі_, _उडून_, 
   {{0x8fd00184,0x00000000,0x00000000,0x00000000}},	//   ҫәлә, --, --, --, 
   {{0xb7b80022,0xf8bc003e,0x44b00139,0x00000000}},	//   _guãr, _ngék_, тбәс, --, 
   {{0x7538009a,0x00000000,0x00000000,0x00000000}},	//   _ifuz, --, --, --, 
   {{0xf2c42607,0x26280139,0xcd340133,0x29e8013d}},	//   _осен, _uğor_, کردب, lğat_, 
   {{0xdb0400c7,0xc7b0025d,0xeaa0002b,0x00000000}},	//   _pohý, אבי_, _paṭu_, --, 
   {{0xdb0401e1,0x00000000,0x00000000,0x00000000}},	//   _lohó, --, --, --, 
   {{0x1c38005b,0x00000000,0x00000000,0x00000000}},	//   дясь_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7538014b,0x7de8012d,0x1e94045c,0x5a540139}},	//   _ofuz, zęsi, _арыр, къту, 
   {{0x6015ab4d,0x9d0001f2,0x317dab4e,0x0d740209}},	//   ràme, ụsịg, nfuz_, _чыкя, 
   {{0x07a5ab4f,0x629c0419,0xc7a41422,0xdb0400e5}},	// [2e2a0] наан, _árov, ниак, _bohó, 
   {{0x75380117,0x317dab50,0x46f424fc,0x37e0009b}},	//   _afuz, hfuz_, нчет, гоуг, 
   {{0x05643849,0xc56400db,0x26dc00e4,0x00000000}},	//   евен, екек, àvo_, --, 
   {{0x7de80024,0xc64400db,0xcb680244,0xb6f410e0}},	//   tęsi, _ۋئزى, _بمگه_, رىنا_, 
   {{0xa3ac023e,0x07e800e5,0xbcf8ea5b,0x75d000ae}},	//   गाल_, _فرسٹ_, ngép, دينا, 
   {{0x7538014b,0x7e7803cd,0x7de80153,0x00000000}},	//   _efuz, yttp, ręsi, --, 
   {{0x472401d9,0x317c5a67,0x580401af,0x00000000}},	//   _سرسٲ, ffuz_, _рорғ, --, 
   {{0xd25001d3,0x7ae000a2,0xefbc0240,0x00000000}},	//   جنٹ_, _ýnte, ትናዊ_, --, 
   {{0x0444009b,0x69d80064,0x6d407aa0,0x00000000}},	//   _чезн, _įvel, ımal, --, 
   {{0x629c012c,0xb110151e,0x6441ab51,0xd9dc01bc}},	//   _šrou, ымыш, _itmi, _यष्ट, 
   {{0x1df9ab52,0x00000000,0x00000000,0x00000000}},	//   дены_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7af805d1,0x00000000,0x00000000,0x00000000}},	//   ğutm, --, --, --, 
   {{0xd9c83806,0x69c8002d,0xbf1401ec,0x601400e8}},	//   रस्ट, êden, _كوشب, sàmb, 
   {{0x88dc04c5,0x39a4f0c2,0x6bd80014,0x00000000}},	//   _ভুলক, ншав, روِس_, --, 
   {{0x644056af,0xa3ac0037,0x4900000d,0x00000000}},	//   _otmi, गाँ_, _वुहो_, --, 
   {{0xd7c8064c,0xfc3dab53,0xb765ab54,0x00000000}},	// [2e2b0] ووره_, rxís_, етей, --, 
   {{0x6289ab55,0x656000c6,0xa7740408,0x00000000}},	//   _opdo, _admh, ллуч, --, 
   {{0xf65019dd,0x64440262,0x644047c0,0x52e4015b}},	//   ائط_, ţiil, _atmi, _পুনঃ, 
   {{0xcb1006a9,0xa2a4193d,0x00000000,0x00000000}},	//   _כלי_, किन्, --, --, 
   {{0x200c00c6,0x628802d5,0xb4a800cd,0x00000000}},	//   kldi_, _apdo, गमे_, --, 
   {{0x41400020,0x3a28031c,0x645c02b5,0x00000000}},	//   _የሀገሪ, _hicp_, _ārit, --, 
   {{0x644041d5,0x200c0142,0x00000000,0x00000000}},	//   _etmi, dldi_, --, --, 
   {{0x75397e9f,0x29e80724,0x63a40198,0xb4b0013d}},	//   _ufuz, lğar_, ɓinm, _йибә, 
   {{0xc0cc0023,0x317c036e,0x200c02d2,0x00000000}},	//   _ኣካለ_, rfuz_, fldi_, --, 
   {{0xdb040022,0x62880334,0xa3ac00dc,0x200c0d12}},	//   _anhí, _fpdo, गाः_, gldi_, 
   {{0x7e7c01e6,0x2bb021b8,0x00000000,0x00000000}},	//   _äppl, ञासा, --, --, 
   {{0x200c01c0,0xc69000df,0xbcf800e5,0x00000000}},	//   aldi_, באט_, tgép, --, 
   {{0x4b5400a7,0x00000000,0x00000000,0x00000000}},	//   къвт, --, --, --, 
   {{0x998800e8,0x321c002e,0x9f4c002e,0xbcf801d3}},	//   blaŋ_, lmuy_, yndé_, rgép, 
   {{0x229c0085,0x3b044cf6,0x321c011f,0xa6ec0eac}},	//   máká_, веро_, omuy_, _কর্ম_, 
   {{0x229dab56,0xddb8010a,0x84800023,0x99747c3f}},	//   láká_, _зуьш_, _ሓይሊን_, лууш, 
   {{0xd244d712,0x38c40241,0xd1e80092,0x00000000}},	// [2e2c0] _گچ_, _rírú_, _ቅኝት_, --, 
   {{0x46a4b795,0xc2ec00eb,0xe7e000eb,0x00000000}},	//   казв, য়েটি_, বক্য, --, 
   {{0x2b59ab57,0x9f4dab58,0x7c281a44,0xb898001f}},	//   marc_, undé_, _ègra, ፈልገው_, 
   {{0x044534b1,0x96940220,0x9f4c0de2,0x00000000}},	//   ведн, ыруш, rndé_, --, 
   {{0x200c0008,0x9988415b,0x00000000,0x00000000}},	//   yldi_, lmaş_, --, --, 
   {{0xf7403aeb,0x2b5801ab,0xa2780153,0xe3740166}},	//   _веро, narc_, ебку_, улкы, 
   {{0x37e1ab59,0x229c02ea,0x60140ffb,0x859400c7}},	//   _торг, dáká_, jàma, _ишац, 
   {{0xdb04193f,0x2b58379c,0x31c000c9,0x00000000}},	//   _ynhâ, harc_, исыв, --, 
   {{0xf99c007f,0x62880327,0x6440022e,0xc55801af}},	//   _okèn_, _wpdo, _utmi, _ниңє_, 
   {{0xc0cc069c,0x7411ab5a,0x200c030a,0x00000000}},	//   _ኣካል_, _نوقا, uldi_, --, 
   {{0xdcec01e4,0x9ab402dd,0x84800023,0xf770011a}},	//   _maaĥ, _ءﻭﺗﯩ, _ሓይሉን_, בקת_, 
   {{0xdfd005d9,0x53a40124,0x84880023,0x80640395}},	//   _گيت_, _иаӡб, _መልስን_, _авдж, 
   {{0xf9904e10,0x4cc400eb,0x00000000,0x00000000}},	//   یبر_, _লেবু, --, --, 
   {{0x9f4c01b8,0xafe0013d,0x7e98007b,0xc10000ec}},	//   nodü_, _кочл, _ينشر_, _ٽوڙي, 
   {{0x101402d5,0xaa540798,0x00000000,0x00000000}},	//   _сьця, иврш, --, --, 
   {{0x7de40046,0xdddc033f,0xa6ec03d4,0x7de80064}},	//   _шілд, żyła, _কৰ্ম_, gęst, 
   {{0x2b5828e9,0x00000000,0x00000000,0x00000000}},	// [2e2d0] barc_, --, --, --, 
   {{0xb8d8c8bf,0x98b80b23,0x2b580276,0x00000000}},	//   _अप_, _sesē_, carc_, --, 
   {{0x321c0280,0xa3ac257b,0xb4a80882,0x6da43047}},	//   ymuy_, गाई_, गम्_, _صمیم, 
   {{0xb8780005,0xdb04004e,0x9479ab5b,0x4e34010f}},	//   _oxíx, _inhà, еску_, אָסן_, 
   {{0x9f8001e1,0xd468010b,0x00000000,0x00000000}},	//   _jòó_, хиле_, --, --, 
   {{0x9f4c29ef,0xc2ec015b,0x9f8001e1,0x29e80166}},	//   godü_, য়েছি_, _mòó_, lğap_, 
   {{0x848002d3,0x66dc00cc,0x9f800241,0x3f9c031c}},	//   _ሓይልን_, råkå, _lòó_, ddtu_, 
   {{0x9f4d12ba,0x2b58030a,0x29e8496e,0x00000000}},	//   kodó_, zarc_, hşan_, --, 
   {{0x29e800a2,0x00000000,0x00000000,0x00000000}},	//   kşan_, --, --, --, 
   {{0x6ed003be,0x7de8012d,0x00000000,0x00000000}},	//   ləbə, zęst, --, --, 
   {{0xc7d40302,0xed540115,0x8f68013e,0x2b58030a}},	//   רותי_, _peɾ_, _ҷалб_, varc_, 
   {{0x8c44bfc2,0x9f8001e1,0x601401c3,0x04380023}},	//   леме, _bòó_, ràma, _እተጠቕ, 
   {{0x1ae0015b,0x2b59ab5c,0xc0c00092,0x00000000}},	//   _খুলে_, tarc_, ትባል_, --, 
   {{0xa3ac1524,0x2b580165,0x29e800a2,0x00000000}},	//   गाए_, uarc_, gşan_, --, 
   {{0x7de80024,0xbb4000d8,0xc0f40092,0x00000000}},	//   tęst, сеск, ገዋል_, --, 
   {{0xa2a428d4,0x2b58030a,0x848801f3,0x00000000}},	//   कित्, sarc_, _መልሱን_, --, 
   {{0x7de80006,0x6adc015b,0x2b5911b1,0xe8e001fb}},	// [2e2e0] ręst, _মুখো, parc_, _trọt_, 
   {{0x9f8001e1,0xb904e91b,0x69a428d4,0x00000000}},	//   _hòò_, унуз_, _चोरी, --, 
   {{0xbb38010f,0x00000000,0x00000000,0x00000000}},	//   _רעטי, --, --, --, 
   {{0xf1a0068f,0x9f800248,0x00000000,0x00000000}},	//   _खोलन, _yòó_, --, --, 
   {{0xdb04056a,0xefc802d3,0x00000000,0x00000000}},	//   _inhá, _ኣዛዚ_, --, --, 
   {{0xa4f40490,0x9f8001e1,0x00000000,0x00000000}},	//   _अशीच_, _lòò_, --, --, 
   {{0xd09803b9,0x00000000,0x00000000,0x00000000}},	//   _içəc, --, --, --, 
   {{0xc5f02832,0xaca40521,0x80480276,0x5bd000dc}},	//   _آر_, ghịk, нчоб_, _हत्व, 
   {{0xd408167e,0x00000000,0x00000000,0x00000000}},	//   رتۇم_, --, --, --, 
   {{0x74c000aa,0x41d000dc,0x11e800f1,0x00000000}},	//   _دښمن, तसहस, _یعني_, --, 
   {{0x5274013e,0xb7d8008f,0x29e81b0d,0xf770011a}},	//   _вучу, גקיי, vşan_, זקת_, 
   {{0x57c00490,0xfc3c00bc,0x013400c6,0x9f8001e1}},	//   _एव्ह, jvíc_, _إعاد, _pòó_, 
   {{0x00d856a7,0xbd500588,0xf06000db,0x00000000}},	//   _ثبات_, аҭқә, _гкчп, --, 
   {{0xb110004b,0xe8140073,0xb0980677,0x00000000}},	//   _اوهغ, _तीला_, _ניור, --, 
   {{0x6c840150,0x7f59ab5d,0x9f800241,0x19580006}},	//   _ۇليم, matq, _wòó_, кавы_, 
   {{0x6e400a8e,0x9f8001e1,0x7f59ab5e,0x00000000}},	//   _انيم, _tòó_, latq, --, 
   {{0x7c2804cc,0x27f802d2,0x1754005b,0xe9f8003b}},	// [2e2f0] _ègro, _bjrn_, ивая, унті_, 
   {{0x39800133,0x00000000,0x00000000,0x00000000}},	//   _گیرف, --, --, --, 
   {{0xa3d81715,0x0af005f5,0x9f800295,0x5694722e}},	//   ासन_, _дүрэ, _jòñ_, рает, 
   {{0x788400da,0x7f5801a9,0x74540023,0x04480023}},	//   tīvā, hatq, _ምተገብ, _ዝተጸን, 
   {{0xca2402dd,0xef080037,0x00000000,0x00000000}},	//   _ﺠﺯﺀ_, _सुनऽ_, --, --, 
   {{0x69d80006,0x6ed000ac,0x53a4059f,0x00000000}},	//   _įvei, səbə, ракб, --, 
   {{0x7f58003a,0x5fc82e05,0x9f4c007f,0x926400f2}},	//   datq, ाउनल, yodò_, شگام, 
   {{0x201c0254,0xb3840133,0x00000000,0x00000000}},	//   _ahvi_, _ڕێتم_, --, --, 
   {{0xe5b40276,0x27f400e4,0x2d140073,0x7f580139}},	//   _уйты, _ñanã_, _ठरेल_, fatq, 
   {{0x09d00bca,0x0ea8656c,0xf99c033b,0x8e840801}},	//   _सत्य, вкой_, _chèz_, агое, 
   {{0x69c8000f,0xda140073,0x00000000,0x00000000}},	//   êdek, ढतात_, --, --, 
   {{0x8d75ab5f,0x00000000,0x00000000,0x00000000}},	//   جادا, --, --, --, 
   {{0x9f800428,0x7f580381,0x39580135,0x00000000}},	//   _eòñ_, batq, daqs_, --, 
   {{0x4a4400c7,0x7f580393,0x00000000,0x00000000}},	//   ингв, catq, --, --, 
   {{0x8b240f5c,0x39580f85,0x9f800241,0x00000000}},	//   рдве, faqs_, _tòò_, --, 
   {{0x3ea8037e,0x4d6407b5,0xa878009d,0x00000000}},	//   æbte_, _ткив, лөгт_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [2e300] --, --, --, --, 
   {{0xca74040e,0xf8bc0129,0x0768007b,0x68440075}},	//   _кумы, _agés_, ئماً_, инға, 
   {{0xdb0400b5,0x4ab80276,0x00000000,0x00000000}},	//   _anhæ, _рупя_, --, --, 
   {{0xa2a42122,0x090002f5,0xeff402d3,0xfc3dab60}},	//   किस्, লেগু_, _ለኻዊ_, lvía_, 
   {{0x65c40046,0x27f800d8,0x00000000,0x00000000}},	//   _құда, _tjrn_, --, --, 
   {{0xfc3c0cc3,0xe2f838a9,0x62340139,0x00000000}},	//   nvía_, лелі_, беку, --, 
   {{0x4e04eb47,0xddc801ef,0x00000000,0x00000000}},	//   रवाई_, hudš, --, --, 
   {{0xdb2401d3,0x04440408,0x80a001f9,0x00000000}},	//   ísér, _веан, कटले, --, 
   {{0xf99c007f,0xf8bc0036,0x7f59ab61,0x00000000}},	//   _chèy_, _ugét_, tatq, --, 
   {{0xa3ac07f7,0x3fa80114,0x00000000,0x00000000}},	//   गाओ_, тњим_, --, --, 
   {{0x35a82871,0xd3c41075,0xd3b47b0f,0xbb842d40}},	//   _घोड़, _اتقى, _усть, ﻪﺗﻜﻪ_, 
   {{0x7de402bf,0x60140ffb,0x1f64013d,0x00000000}},	//   ріод, màmm, шкүм, --, 
   {{0x9f800295,0xed5802d5,0x7c84010b,0x201c032e}},	//   _wòñ_, шоў_, шуне, _thvi_, 
   {{0xf99c00f2,0x7f580477,0x00000000,0x00000000}},	//   _saè_, qatq, --, --, 
   {{0xf8bc0de2,0xde4401ec,0x00000000,0x00000000}},	//   _ngér_, _ارتۋ, --, --, 
   {{0xf77000b2,0x5d5401b9,0x00000000,0x00000000}},	//   ڪار_, _укит, --, --, 
   {{0xe8380212,0xd1440092,0x00000000,0x00000000}},	// [2e310] ипті_, _ያጠቃል, --, --, 
   {{0xd759ab62,0x7640063f,0x9f60013d,0xfb2400f1}},	//   الات_, ̣nyu, _äsär_, _پرخپ, 
   {{0x7bd4058a,0x048401e0,0x1f440092,0x00000000}},	//   _ilxu, ҙәти_, _የአዕም, --, 
   {{0xf77001d9,0xdb040419,0x03b8010e,0x04840131}},	//   _ڈاس_, _dohô, _tüỳd, әәти_, 
   {{0xdff86bcf,0xf771069e,0x7af805d1,0xf8bc01d3}},	//   ुवाद_, _واس_, ğutu, _egér_, 
   {{0xf6500aa5,0xf674034c,0xa3cc1a22,0x0454007b}},	//   _мегӯ, _پاسخ, _लवण_, حلوة_, 
   {{0x41d007b6,0x62580ce8,0x11380064,0x00000000}},	//   तसंस, арыр_, ляпы_, --, 
   {{0xdb040267,0x00000000,0x00000000,0x00000000}},	//   _inhä, --, --, --, 
   {{0xbcf8003e,0xd13001d3,0xd0e80101,0x00000000}},	//   naéd, _ہما_, دکام_, --, 
   {{0xd13000f1,0x00000000,0x00000000,0x00000000}},	//   _ځما_, --, --, --, 
   {{0x81d400bd,0x60142b1d,0xd13000c6,0x4e2801c0}},	//   _সদর_, càmm, _فما_, лоон_, 
   {{0x7bd40694,0xa2a41d03,0xf1a80345,0x00000000}},	//   _alxu, किर्, _جائه_, --, 
   {{0x9045974a,0x45f8010f,0x0c78013d,0x00000000}},	//   _انته, רהרג, ысны_, --, 
   {{0x5f94013d,0xbb4120d9,0xa5380240,0x00000000}},	//   _мичт, зерк, _ብዓንቀ, --, 
   {{0xc3301203,0xf1d80034,0xada4036b,0xfc3c09c2}},	//   לום_, _बतान, _ҳақл, rvía_, 
   {{0x2ba80316,0xfc3c04d4,0xbd34014b,0x29e82123}},	//   _छोरा, svía_, _гӯру_, mşak_, 
   {{0xdb040730,0xfc3c283a,0x6d4401e1,0x4735ab63}},	// [2e320] _anhä, lvín_, _ifia, مراز, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf99c0066,0x6d440076,0x00000000,0x00000000}},	//   _okèh_, _kfia, --, --, 
   {{0x499813f3,0x25740145,0x7af80205,0x00000000}},	//   _стоя_, تۇرس, ğutt, --, 
   {{0x6d440134,0x290400e4,0xcab80022,0xdb04403a}},	//   _mfia, _âma_, _рыҿц_, _enhä, 
   {{0x25a023e2,0xf99c0502,0xc7955667,0x3f80013f}},	//   žil_, _akèh_, _урмы, ɑkuw_, 
   {{0x6d440034,0x629801f5,0x46140066,0x00000000}},	//   _ofia, uwvo, _هوسر, --, 
   {{0x6d440076,0x00000000,0x00000000,0x00000000}},	//   _nfia, --, --, --, 
   {{0xa3d82413,0x741000aa,0x2e400020,0x271801ad}},	//   ासद_, _کولا, _የተዛመ, _थरुर_, 
   {{0x6d44dc20,0x38980302,0xf8b00375,0x9f4c036e}},	//   _afia, ניינ, פשת_, midë_, 
   {{0x9df9ab64,0x3f80033f,0x9f4c0200,0x00000000}},	//   инот_, ęku_, lidë_, --, 
   {{0x3f800118,0x5bd00055,0x00000000,0x00000000}},	//   řku_, हस्व, --, --, 
   {{0xa2d400dc,0x00000000,0x00000000,0x00000000}},	//   यैर्, --, --, --, 
   {{0x6d4403c1,0x271806ab,0xa3d816d1,0xda34034b}},	//   _efia, _थरूर_, ासि_, жевы, 
   {{0x63a403f9,0x6d44015d,0x00000000,0x00000000}},	//   ɓint, _ffia, --, --, 
   {{0x5c7400c9,0xdb200241,0x29e84dd9,0x00000000}},	//   _длит, _àtíj, nşah_, --, 
   {{0xdc548341,0xa3d81df0,0x00000000,0x00000000}},	// [2e330] _برعک, ासा_, --, --, 
   {{0xdb0401e6,0x9b600131,0x711800df,0x00000000}},	//   _anhå, _زۆرۈ, רומפ, --, 
   {{0xca3401ec,0x29e80205,0x00000000,0x00000000}},	//   _ﺗﯩﺲ_, kşah_, --, --, 
   {{0xfc3c0548,0x986401d3,0x053c01e1,0x15140d1d}},	//   oqí_, _ویزے_, _èèlò_, одея, 
   {{0xe3b04451,0x29e803b9,0x00000000,0x00000000}},	//   کرن_, dşah_, --, --, 
   {{0xdb04072b,0x87700b01,0x00000000,0x00000000}},	//   _enhå, _оғуш, --, --, 
   {{0xdb0404e6,0xf77000ec,0x00000000,0x00000000}},	//   _unhä, _واڳ_, --, --, 
   {{0x75800344,0x9f4c02e2,0xe5bc00ef,0x29e803e0}},	//   _ریتم, lidè_, _tīšā, vşak_, 
   {{0x4f94a6bb,0x10a402e8,0x261c007b,0x00000000}},	//   орну, ципн, síoc_, --, 
   {{0x6d45ab65,0x4fe86b59,0x0e64e55b,0x9988030a}},	//   _sfia, рмон_, окон, llań_, 
   {{0x98b80171,0xf2040153,0x51b8030d,0x00000000}},	//   _besī_, _лядо, _выля_, --, 
   {{0x7c240399,0x601401ab,0xc1e400f1,0xe2c80066}},	//   emjr, hàmh, _وکيل_, _دومو_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x63a40198,0x9f4c02e2,0x29e808a9,0x00000000}},	//   ɓins, jidè_, pşak_, --, 
   {{0x2fc5ab66,0x68300248,0x6d4128c8,0x7aa1ab67}},	//   _iong_, _lódì, ñmas, мирз, 
   {{0x2fc5ab68,0x69d80006,0x6d440618,0x6d402c78}},	//   _hong_, _įves, _ufia, ımas, 
   {{0x2fc5ab69,0x47c4468b,0xcb6803fb,0x00000000}},	// [2e340] _kong_, обав, _капе_, --, 
   {{0x2fc5ab6a,0xc6d40ef6,0xe81405d7,0x9f4c0240}},	//   _jong_, يتات, _तीखा_, vidë_, 
   {{0x2fc5ab6b,0x46e8041b,0x86440120,0x050400eb}},	//   _mong_, јден_, цнеж, _ঋণের_, 
   {{0x2fc4da09,0x291c0213,0x9f4c036e,0x314c01f3}},	//   _long_, əvan_, tidë_, መንበር, 
   {{0x2fc40083,0x053c01e1,0x00000000,0x00000000}},	//   _oong_, _èèmò_, --, --, 
   {{0x2fc5ab6c,0x5edc00dc,0x262806be,0x15b801e0}},	//   _nong_, खनम्_, _aşot_, _һыуы_, 
   {{0x7241ab6d,0x3664016c,0xbb38010f,0x00000000}},	//   وپول, _маро_, בעצי, --, 
   {{0x9f4c02ea,0xa3d80073,0x00000000,0x00000000}},	//   midé_, ासह_, --, --, 
   {{0xdfd00491,0x9f4c07ea,0x601400cf,0xe4c4072d}},	//   فية_, lidé_, làmi, _عصری, 
   {{0x2fc5ab6e,0x2d801730,0x301000c7,0xf48400e5}},	//   _cong_, _acie_, мдыр, _گاہی, 
   {{0x2fc5ab6f,0x2ca1ab70,0x601400f7,0xfd6060a1}},	//   _dong_, _asid_, nàmi, үнүү, 
   {{0x2fc4003e,0x2d80b7be,0xceac00ec,0x26dc0174}},	//   _eong_, _ccie_, اڙو_, úvoy_, 
   {{0x2fc40a40,0xe724031c,0x2ca014b0,0x00000000}},	//   _fong_, _འཛྀན_, _csid_, --, 
   {{0x2fc5436d,0xfc3c6bdf,0x25a40036,0x9f4c0158}},	//   _gong_, svío_, _laml_, kidé_, 
   {{0x69d802d5,0x200dab71,0x100800db,0x9f4c0561}},	//   _įver, modi_, _اتنى_, vidè_, 
   {{0x200dab72,0x25a4025a,0x2fc5ab73,0x2ca00334}},	//   lodi_, _naml_, _zong_, _fsid_, 
   {{0x2fc5ab74,0xdcfc00da,0x2ca0010a,0xae0408b0}},	// [2e350] _yong_, resē, _gsid_, _تويى, 
   {{0x2a79ab75,0x200dab76,0x2fc40016,0xad2401d9}},	//   burb_, nodi_, _xong_, _تر٘و, 
   {{0xfdfc0c66,0x601456eb,0x00000000,0x00000000}},	//   _उदास_, gàmi, --, --, 
   {{0x200dab77,0x4a980375,0xa7140212,0x69c8045f}},	//   hodi_, _פירג, ємці, êdet, 
   {{0x200dab78,0x69c00428,0x798c02d0,0x00000000}},	//   kodi_, _òmea, _ibcw, --, 
   {{0xf1a00034,0x200d67ff,0x88380375,0x798c02d0}},	//   _खोजन, jodi_, _לתשו, _hbcw, 
   {{0x2fc5ab79,0x9f4d9046,0xe665ab7a,0x200dab7b}},	//   _rong_, cidé_, _отто, dodi_, 
   {{0x2fc40302,0x90c54f72,0x929400c7,0x261c007b}},	//   _song_, збие, _ҭаац, líon_, 
   {{0x2fc5ab7c,0x2ed0c6e5,0x45d8010f,0x4fe8bdf4}},	//   _pong_, दन्त, _פֿלא, ймин_, 
   {{0x200dab7d,0xe4a407d6,0x2d81ab7e,0xe3b000aa}},	//   godi_, _ўрто, _scie_, _لرم_, 
   {{0x2fc4001e,0x8e082901,0xa3d83be5,0xf1a41fbe}},	//   _vong_, йнов_, ासर_, _мрдн, 
   {{0x2fc41060,0x798c02d0,0x99880165,0x25a4045a}},	//   _wong_, _nbcw, llaņ_, _xaml_, 
   {{0x2fc5ab7f,0x200dab80,0x8fd00139,0x3eac002f}},	//   _tong_, bodi_, _зәнә, _erft_, 
   {{0x798c035a,0x2fc401fb,0xcd00002b,0x00000000}},	//   _abcw, _uong_, _āśā_, --, 
   {{0x78ac04fb,0xa0340014,0xfc000108,0xb4d42802}},	//   _arcv, _کى۪ت, хпро, ानु_, 
   {{0x9f4c00eb,0xe3b803b9,0x00000000,0x00000000}},	//   vidé_, _ahıl_, --, --, 
   {{0x2ca0014b,0x798c02d0,0x261c0332,0x7d78011a}},	// [2e360] _usid_, _dbcw, fíon_, _הנפו, 
   {{0x004401f2,0x394005f5,0x7b0401ed,0x386c01ed}},	//   _jụụ_, _үнэг, érté, ágra_, 
   {{0x6e25ab81,0xbb38011a,0x00000000,0x00000000}},	//   _khib, _לעיי, --, --, 
   {{0x601400f7,0x200c05ce,0x9f4c00f2,0x00000000}},	//   ràmi, zodi_, ridé_, --, 
   {{0x9f4c5522,0x25a40162,0x200dab82,0x69c5ab83}},	//   sidé_, _vaml_, yodi_, mjie, 
   {{0x69c5ab84,0x68e5ab85,0x261c0407,0xa2940816}},	//   ljie, mzid, cíon_, дакі, 
   {{0x200c0bb8,0x25a4020c,0x6e240857,0x69c5ab86}},	//   vodi_, _taml_, _ohib, ojie, 
   {{0x69c5ab87,0x68e5ab88,0x00000000,0x00000000}},	//   njie, ozid, --, --, 
   {{0x200dab89,0x68e5ab8a,0xfc3c012c,0xa4f8af1c}},	//   todi_, nzid, tvím_, _بکار_, 
   {{0x6e25ab8b,0x68e40165,0x9fb40118,0x69c40108}},	//   _ahib, izid, _tříd_, hjie, 
   {{0x6e25ab8c,0xdfd00633,0x00000000,0x00000000}},	//   _bhib, فيک_, --, --, 
   {{0x6e25ab8d,0x69c4003d,0x67e0049f,0x68e401c7}},	//   _chib, jjie, _höjd, kzid, 
   {{0x6e2414cc,0x200dab8e,0x69c5ab8f,0x160c0da3}},	//   _dhib, podi_, djie, िकतर_, 
   {{0x68e59864,0xfc3c05f7,0x6e240055,0x798c02d0}},	//   dzid, lvík_, _ehib, _sbcw, 
   {{0x68e4ac77,0xe3b80166,0xf968045c,0x9f0400f1}},	//   ezid, _mnı_, йрай_, _توغو, 
   {{0x6e25ab90,0x7e780882,0x69c40023,0x68e4022e}},	//   _ghib, mutp, gjie, fzid, 
   {{0x7e780483,0xe895ab91,0xe3b9ab92,0x00000000}},	// [2e370] lutp, нать, _onı_, --, 
   {{0x7ddc092e,0x67e001e6,0x69c00086,0x69c8000f}},	//   _dëse, _nöjd, _òmen, êder, 
   {{0x9b940124,0xfc3c03b2,0x69c40171,0x095400f7}},	//   _еиҿц, kvík_, bjie, سىەڭ, 
   {{0xe3b80598,0x25e805f9,0x7c3400b5,0x6e240023}},	//   _anı_, चोली_, _hixr, _xhib, 
   {{0xb4d5ab93,0x53a40228,0xa3d800dc,0x7c3c058a}},	//   ाने_, далб, ासं_, _juqr, 
   {{0x7c340135,0x7c3c0139,0xe45001c8,0x7de8012d}},	//   _jixr, _muqr, اضن_, gęsz, 
   {{0x7c340139,0x00000000,0x00000000,0x00000000}},	//   _mixr, --, --, --, 
   {{0xa6c4015b,0x61e00135,0x00000000,0x00000000}},	//   _এইচট, ghml, --, --, 
   {{0x7539ab94,0x8f741ed2,0x7ddc002e,0x70a401f9}},	//   _iguz, муні, _xëse, कटेल, 
   {{0x6e25ab95,0x2628084c,0xa3d80882,0x7c34031c}},	//   _shib, _uşor_, ासः_, _nixr, 
   {{0x7e79ab96,0x6e25ab97,0xe8e001fb,0x68e44067}},	//   gutp, _phib, _trệt_, zzid, 
   {{0x6e2401e0,0x7c3c011f,0x29e8054e,0x4ea40022}},	//   _qhib, _buqr, nşat_, прҭа, 
   {{0x6e240943,0x7c34031c,0x67e001e6,0x69c400e2}},	//   _vhib, _bixr, _höje, vjie, 
   {{0xf99c0100,0x7dddab98,0x6f840117,0x67e000a2}},	//   _okès_, _rëse, _худж, _köje, 
   {{0x160c0d0d,0x6e247318,0x69c5ab99,0x7539ab9a}},	//   िकार_, _thib, tjie, _oguz, 
   {{0x7539ab9b,0x6e2400ca,0xbcf80098,0x68e401c4}},	//   _nguz, _uhib, maén, tzid, 
   {{0xb4d45a17,0x68e40bd7,0xdb040100,0xc7a43129}},	// [2e380] ानो_, uzid, _lahè, миак, 
   {{0x7539ab9c,0x69c470da,0x46f4721f,0x68e5ab9d}},	//   _aguz, sjie, мчет, rzid, 
   {{0x6b9dab9e,0x69c4038f,0x67e00267,0xfc3c022c}},	//   merg, pjie, _nöje, yvík_, 
   {{0x6b9dab9f,0x224c06be,0x00000000,0x00000000}},	//   lerg, _rtdk_, --, --, 
   {{0xbcf8003e,0x24580229,0x00000000,0x00000000}},	//   haén, чаль_, --, --, 
   {{0x7539aba0,0x7ddc0221,0x67e00267,0x00000000}},	//   _eguz, _kësc, _böje, --, 
   {{0xdcec1ae4,0x6b9c01c7,0xdcfc00c0,0x00000000}},	//   _ocağ, ierg, besė, --, 
   {{0x6b9daba1,0x7ddc0221,0x00000000,0x00000000}},	//   herg, _mësc, --, --, 
   {{0x6b9daba2,0x7ddc0a40,0xfc3c1f60,0x60f895be}},	//   kerg, _lësc, rvík_, яния_, 
   {{0x6b9daba3,0x6560014f,0xfc3c0436,0x6440009f}},	//   jerg, _hemh, svík_, _iumi, 
   {{0x65603743,0x7c3c1eca,0x1fd000cc,0xd36c00cf}},	//   _kemh, _suqr, াফলস, _چۇۇ_, 
   {{0x63a9aba4,0x7c3daba5,0x2288002d,0x6561aba6}},	//   _hadn, _puqr, mûk_, _jemh, 
   {{0x6441aba7,0x673c0841,0x2288000f,0x7c3c0139}},	//   _jumi, _ogrj, lûk_, _quqr, 
   {{0x6441aba8,0x63a8071b,0x6b9daba9,0x7ddc0a40}},	//   _mumi, _jadn, gerg, _bësc, 
   {{0x6441abaa,0xdb040c6a,0x19941e76,0x51f40150}},	//   _lumi, _kahé, навя, _تسەر, 
   {{0x6561abab,0x7ddc0221,0xdb05abac,0x6441abad}},	//   _nemh, _dësc, _jahé, _oumi, 
   {{0x7c356fd1,0x57b426f8,0xdb040c6a,0x753801a9}},	// [2e390] _tixr, нбат, _mahé, _rguz, 
   {{0x6b9c2a1f,0xa77403b7,0x7ddc0221,0x63bc01ab}},	//   cerg, клуч, _fësc, _òrnh, 
   {{0xb4d5abae,0x6561abaf,0x7ddc0a40,0x2288000f}},	//   ान्_, _bemh, _gësc, jûk_, 
   {{0x6441abb0,0xd1c01e38,0x63a80014,0xdb05abb1}},	//   _bumi, ስታት_, _aadn, _rahè, 
   {{0x6440421f,0x63a85272,0x7bc4022f,0x39480129}},	//   _cumi, _badn, ojju, _ifcs_, 
   {{0x6441abb2,0x39480327,0x3944013f,0x63a852bb}},	//   _dumi, _hfcs_, ɛnsa_, _cadn, 
   {{0xdb040098,0x63a9abb3,0x6560007c,0xfe0c0037}},	//   _bahé, _dadn, _femh, सवास_, 
   {{0x6441abb4,0x6b9c0724,0x65600099,0x753800ca}},	//   _fumi, zerg, _gemh, _uguz, 
   {{0x6441abb5,0x63a80158,0x6b9dab9d,0x9f4c026c}},	//   _gumi, _fadn, yerg, pidì_, 
   {{0x6b9c315a,0x8ee8234c,0x67e0007c,0x65600205}},	//   xerg, змов_, _töje, _zemh, 
   {{0x6440097d,0x9f4c86c1,0x6561abb6,0xd1740022}},	//   _zumi, cidí_, _yemh, _зылы, 
   {{0x63a90b2c,0x2d85abb7,0x6b9dabb8,0x6440019b}},	//   _zadn, üme_, werg, _yumi, 
   {{0xc22004d3,0x64400014,0x63a9abb9,0xbcf8020c}},	//   _حکوو, _xumi, _yadn, saén, 
   {{0x7bc4044e,0x6b9d281c,0x395c0115,0x3130010b}},	//   gjju, uerg, _ĵusa_, _зеҗр, 
   {{0x6b9c0598,0x8a0403fb,0x6d4001e4,0x00000000}},	//   rerg, езве, ɾman, --, 
   {{0x3948009a,0x4c840212,0x00000000,0x00000000}},	//   _cfcs_, _злив, --, --, 
   {{0xb7d45439,0x6560006f,0x7ddc01c7,0xd36400ec}},	// [2e3a0] کولا_, _remh, _wësc, _پڇ_, 
   {{0x7ddc04c4,0x6561abba,0x29e8010e,0x00000000}},	//   _tësc, _semh, gşar_, --, 
   {{0x63a80bb3,0x6561abbb,0xc76400d1,0x00000000}},	//   _radn, _pemh, _ۋاسى, --, 
   {{0x7ddc069c,0x6441abbc,0x9f4c02fb,0x29dc0166}},	//   _kësa, _pumi, vidí_, _zían_, 
   {{0x6441abbd,0x656092dd,0x00000000,0x00000000}},	//   _qumi, _vemh, --, --, 
   {{0x02a5220f,0x6561abbe,0x6441746a,0xa5200490}},	//   ерим, _wemh, _vumi, _बरीच_, 
   {{0x63a9abbf,0x6561abc0,0xdb04020c,0x6440009a}},	//   _vadn, _temh, _pahé, _wumi, 
   {{0x22880385,0x6441abc1,0x63a9abc2,0xe7ec05dc}},	//   rûk_, _tumi, _wadn, छोरा_, 
   {{0xd584168d,0x6441abc3,0x9f4c004e,0x74e401c6}},	//   _شێوه_, _uumi, sidí_, _здтг_, 
   {{0xddc80034,0x00000000,0x00000000,0x00000000}},	//   łożo, --, --, --, 
   {{0x442c0175,0x77f4011a,0x24dc0055,0xb7d8011a}},	//   mmf_, תמיד_, _āmṛś, פקטי, 
   {{0x6d4008ad,0x7ddc00e8,0xa3d80f4a,0xd24ca397}},	//   žman, _bësa, ासक_, _بچو_, 
   {{0x442dabc4,0xa37c00df,0x00000000,0x00000000}},	//   omf_, _elĵe, --, --, 
   {{0xdd900e56,0x00000000,0x00000000,0x00000000}},	//   دوڭ_, --, --, --, 
   {{0x29dc0005,0x2ec800dc,0x683406be,0x00000000}},	//   _vían_, ाहृत, cüdə, --, 
   {{0x7ddc00e8,0x9f4cb269,0xdcfc00e2,0x298400db}},	//   _fësa, lidà_, nesī, лыуг, 
   {{0xa8983334,0x00000000,0x00000000,0x00000000}},	// [2e3b0] нкту_, --, --, --, 
   {{0x37041d1c,0x2b5400d7,0x00000000,0x00000000}},	//   нчев, čací_, --, --, 
   {{0xa3d400e1,0xbcf801d3,0xe7840c4f,0x00000000}},	//   _हक़_, zaél, المپ, --, 
   {{0xac74215c,0x00000000,0x00000000,0x00000000}},	//   _شاۋش, --, --, --, 
   {{0x95b40032,0x00000000,0x00000000,0x00000000}},	//   ерҙә, --, --, --, 
   {{0x3f9dabc5,0xf30001c0,0x00000000,0x00000000}},	//   jetu_, лжлү, --, --, 
   {{0x3f9c01c0,0xdb0404d4,0x00000000,0x00000000}},	//   detu_, _inhó, --, --, 
   {{0xb1440214,0x80c80011,0x7800014b,0x00000000}},	//   ریتم_, িনন্, _рӯға, --, 
   {{0xb95801e1,0x67e001e3,0x00000000,0x00000000}},	//   _enìg, _höja, --, --, 
   {{0x3f9dabc6,0xbcf9956d,0x442c0077,0x00800395}},	//   getu_, raél, cmf_, шльо, 
   {{0xd1e807db,0xdb0405da,0xdcfc00e2,0xff200395}},	//   _ህዝቢ_, _sahî, besī, имьо, 
   {{0x8c4434b1,0x11f8034c,0xd094008e,0xaee000db}},	//   кеме, _کوچک_, _ашкы, _ەۋدى, 
   {{0xddc80960,0x3f9cd437,0x8fa40120,0x6d4001e4}},	//   budž, betu_, _аале, ɾmal, 
   {{0x9f4dabc7,0x3f9dabc8,0x00000000,0x00000000}},	//   ridã_, cetu_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x601403d1,0xd1e802d3,0x442c0109,0x29e8010e}},	//   làmp, _ህዝባ_, zmf_, gşap_, 
   {{0x0b59abc9,0xa5200574,0x9f4c0077,0x0c2400fd}},	// [2e3c0] _орны_, _बरेच_, lidá_, _имин, 
   {{0xd1e80201,0x291c0a2b,0x4a446145,0xd7f9abca}},	//   _ህዝብ_, āva_, _инов, нує_, 
   {{0x26ddabcb,0x8a0400c7,0x922002ab,0x7ddc00e8}},	//   ávo_, _азне, मताज_, _mësn, 
   {{0x3f9c2a69,0x9f4c06d9,0x29dc0139,0xd1f00092}},	//   zetu_, zidà_, _xíal_, ልቀቅ_, 
   {{0x3f9dabcc,0x7d00013f,0x26dc0427,0x00000000}},	//   yetu_, _ɛnso, švo_, --, 
   {{0x23480cbe,0xdb04004e,0xb58401d9,0x00000000}},	//   رستی_, _inhò, ٹھہٕ_, --, 
   {{0x3f9c098d,0x32602075,0x9f4c07de,0x58043452}},	//   vetu_, атыв, vidà_, _сорғ, 
   {{0x3f9dabcd,0xefb0315b,0x00000000,0x00000000}},	//   wetu_, یینگ, --, --, 
   {{0x3f9c0bb8,0x99980093,0x044428e8,0xdcfc00e2}},	//   tetu_, _sisū_, _резн, resī, 
   {{0xa3cc00c5,0x00000000,0x00000000,0x00000000}},	//   _लवट_, --, --, --, 
   {{0xdef44734,0x3f9dabce,0xddc89ac0,0x73300131}},	//   упны, retu_, rudž, _نىكا, 
   {{0x8f8000c7,0xdef8031c,0xfe40009d,0x799c035a}},	//   ақәл, naċi_, лмүү, xeqw, 
   {{0x5f95abcf,0x9f4c067c,0x80049c49,0x248001c3}},	//   _билт, pidà_, _ичке, àimh_, 
   {{0x799c0921,0xa2b8228a,0xbcf84a16,0x7ae400f1}},	//   weqw, ्मप्, laék, پورې_, 
   {{0xdef8025c,0xeea40064,0x00000000,0x00000000}},	//   kaċi_, _атык_, --, --, 
   {{0x95740f7c,0xbcf80098,0x67e0007c,0xa00400fe}},	//   ረታትን_, naék, _röja, _উঠিব_, 
   {{0x67e00793,0x0c94036b,0xdef8031c,0x28f80108}},	// [2e3d0] _söja, _یدیگ, daċi_, веть_, 
   {{0xb8c8534e,0x799c0472,0x7ddc0200,0x108c0220}},	//   _कई_, seqw, _këso, _ﻛﻪﺯﯨ, 
   {{0xd575abd0,0xfc3c0077,0x368801c0,0x7ac40022}},	//   гуль, rvíu_, ьсан_, _рспе, 
   {{0x9864066d,0x7ddc044e,0xa2b80882,0x960c1b76}},	//   _میرے_, _mëso, ्मन्, िकेट_, 
   {{0xdb040077,0xbcf8003e,0x41b4023e,0x00000000}},	//   _mahí, daék, _अफ़स, --, 
   {{0xfc3d6940,0x67e00267,0x00000000,0x00000000}},	//   lvís_, _höjn, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x569400c7,0x108c1884,0xa83000b8,0x00000000}},	//   _иаҳт, _ﻛﻪﺭﯨ, _ṇḍal, --, 
   {{0xe4a41677,0x9034074d,0x72a00116,0x00000000}},	//   _врхо, лхоч, _چەتن, --, 
   {{0x8d74168d,0xa3b800e3,0xb9f80023,0x00000000}},	//   گادا, _لامر_, _ዘጽ_, --, 
   {{0xdb05abd1,0xe3b05c14,0x8e840a89,0xead003d4}},	//   _bahí, _برق_, ыгне, _ৰশ্ম, 
   {{0x8d75abd2,0x8d540500,0x00000000,0x00000000}},	//   دادا, ыточ, --, --, 
   {{0x7e7801f5,0x00000000,0x00000000,0x00000000}},	//   artp, --, --, --, 
   {{0x321c03f0,0xaee000db,0x00000000,0x00000000}},	//   lluy_, _ەۋگى, --, --, 
   {{0x09e40139,0x67e001e3,0x00000000,0x00000000}},	//   говн, _böjn, --, --, 
   {{0x0d841d5b,0x78b800d7,0xfc3c0174,0x00000000}},	//   _слин, _šuva, gvís_, --, 
   {{0x3ab00075,0xdef8031c,0x00000000,0x00000000}},	// [2e3e0] _һәтт, vaċi_, --, --, 
   {{0x38c95df1,0xfc3c004e,0xdb040139,0x00000000}},	//   راقی_, avís_, _zahí, --, 
   {{0xb8c85654,0xf99c020c,0x86980276,0xdef80327}},	//   _कै_, _ijèn_, этат_, taċi_, 
   {{0xfcf40092,0x15b864c2,0xf7400107,0x998800a2}},	//   _ወላጅ_, кычы_, _ҳеро, mlaş_, 
   {{0x44f48f52,0x3df800df,0x99880a43,0x00000000}},	//   دساز, עלנד, llaş_, --, 
   {{0xe2f802dd,0x50440092,0x06642927,0x6d4003e0}},	//   келі_, _የሁላች, _مارپ, ımay, 
   {{0xbcf80098,0xdef80003,0x998806be,0x00000000}},	//   taék, paċi_, nlaş_, --, 
   {{0xa074188b,0x7ddc1bce,0xf4840133,0x5f4c0092}},	//   агич, _cësl, _ڕامی, _ነበራቸ, 
   {{0x75d1abd3,0xdfd00491,0x7ddc0036,0xbcf8003e}},	//   _ايقا, قية_, _dësl, raék, 
   {{0x749825f9,0x7ddc02d3,0x78780174,0x24940023}},	//   _אימפ, _pëso, _høvð, _መልሓስ_, 
   {{0x381402e4,0xdb04002b,0xdcec00d7,0x00000000}},	//   רקים_, _mahã, _vdač, --, 
   {{0x443c0c30,0x1df8005b,0xb7c00356,0x408400d8}},	//   _hit_, темы_, ăţie, _букб, 
   {{0x6ce40220,0x443dabd4,0x67e001e3,0x00000000}},	//   біре, _kit_, _röjn, --, 
   {{0x9f34005e,0x3a280789,0xdb0400e4,0xcc8403e6}},	//   _келі, _shcp_, _nahã, گۆیه_, 
   {{0x443dabd5,0x6ea8012c,0xdb040166,0x8c380107}},	//   _mit_, _जनयु, _tahí, торӣ_, 
   {{0x443d05f3,0xf99c007f,0x99542503,0x79a40124}},	//   _lit_, _ejèn_, ркац, ырге, 
   {{0x443d82fa,0x57f4403b,0xfc3c068c,0x629c007c}},	// [2e3f0] _oit_, апат, rvís_, _ärof, 
   {{0x443dabd6,0xbbe801d9,0x6ea80ebb,0x6934009d}},	//   _nit_, _سرخم_, _जनमु, снуу, 
   {{0xdb040368,0x5555abd7,0x67e0007c,0x19940f7e}},	//   _wahâ, لپار, _töjn, _каня, 
   {{0x443dabd8,0xdb04000f,0x4a5802e4,0x94780114}},	//   _ait_, _tahâ, _שדרו, вску_, 
   {{0x24d800eb,0xa9280150,0x00000000,0x00000000}},	//   _দেবহ, _біре_, --, --, 
   {{0x443dabd9,0x00000000,0x00000000,0x00000000}},	//   _cit_, --, --, --, 
   {{0x443c2253,0x67e00628,0x69dc3f7e,0x00000000}},	//   _dit_, _möjl, _नवमी, --, 
   {{0x443c3fae,0x67e001e6,0xf1bc0005,0xbcf80c6a}},	//   _eit_, _löjl, ñá_, paéh, 
   {{0xb384d5bc,0x443c0c30,0xc5ec004b,0x321c002e}},	//   _مجاه, _fit_, _تړل_, rluy_, 
   {{0x764401aa,0x99884ba9,0x443dabda,0x9f4c0139}},	//   _kujy, ylaş_, _git_, jidä_, 
   {{0xdb040109,0x77640327,0xa2b800dc,0x9f4c0139}},	//   _nahà, _mejx, ्मण्, didä_, 
   {{0x443c0460,0x764401aa,0x78b8031c,0x00000000}},	//   _zit_, _mujy, _ġuvn, --, 
   {{0x8c44ab8e,0x443dabdb,0x67e0007c,0xc0c00092}},	//   реге, _yit_, _böjl, ስባል_, 
   {{0x8d7521cf,0x443dabdc,0x00000000,0x00000000}},	//   داگا, _xit_, --, --, 
   {{0x7645abdd,0xaca40241,0x80d800cc,0x00000000}},	//   _nujy, _ibọw, _বেপ্, --, 
   {{0xa2b800dc,0x272c0241,0x6fd80073,0x00000000}},	//   ्मत्, _lóní_, _पकडू, --, 
  
   {{0xcd200014,0x81d000eb,0x00000000,0x00000000}},	// [2e400] _گژھی, হোক_, --, --, 
   {{0x76440230,0x67e00139,0x9f4c0166,0x00000000}},	//   _bujy, _göjl, cidä_, --, 
   {{0x443dabde,0x76440007,0x46a460df,0x2a7c0162}},	//   _rit_, _cujy, раев, _ívb_, 
   {{0x443c0d63,0xf620ecab,0xd5b828f6,0x00000000}},	//   _sit_, одхо, лсі_, --, 
   {{0x443c0c3a,0x67e000a2,0x00000000,0x00000000}},	//   _pit_, _höjm, --, --, 
   {{0x443d657f,0xe3b803e0,0x4b7800df,0x00000000}},	//   _qit_, _ahır_, דאַו, --, 
   {{0x443dabdf,0x6d44009d,0xbcf87f70,0xa2b800dc}},	//   _vit_, _ogia, mbée, ्मध्, 
   {{0x6d45abe0,0xdb0400c7,0xf4843c73,0x443c2bab}},	//   _ngia, _jahá, _چالی, _wit_, 
   {{0x443dabe1,0x93ec0134,0x27f801f9,0xdcec0327}},	//   _tit_, _aseε_, _kmrn_, _ibaħ, 
   {{0x443d51e9,0x6d45abe2,0xdfd006f6,0xd7c80490}},	//   _uit_, _agia, سيج_, रायच, 
   {{0x74109067,0xf0b404fb,0xf770011a,0x52740408}},	//   _بولا, هایش_, חקת_, _гучу, 
   {{0xdb0445be,0x6d45abe3,0xdcec031c,0x261c0332}},	//   _nahá, _cgia, _jbaħ, míos_, 
   {{0xd7c836d2,0x998801a6,0x60c40010,0x6054431a}},	//   रामच, jmaš_, _šimf, _انتط, 
   {{0x6d4405f5,0x6fb000c6,0xdb040022,0xfb85abe4}},	//   _egia, _ومنا, _pahà, шымн, 
   {{0x6d4401ab,0xec3402bf,0x75f40521,0xdb0421dd}},	//   _fgia, інсь, ụzia, _bahá, 
   {{0x76440526,0x2f380375,0xfc640408,0x00000000}},	//   _rujy, _בגוד, _къон, --, 
   {{0x776401d4,0x98b800f7,0x5e3401ed,0x7c8401af}},	// [2e410] _pejx, ылат_, _پڑھا, _туйе, 
   {{0x7645abe5,0xbcf80098,0xad1c011a,0x67e0007c}},	//   _pujy, rbéd, _בוחר, _höjj, 
   {{0xdb05abe6,0x56940c9e,0x1ad403d4,0x7ddc0200}},	//   _anhö, сает, _হেৰা, _nësk, 
   {{0x7454044e,0x261c524a,0xbcf8020c,0x758001d5}},	//   _ዝተገብ, díos_, mbéb, تیرم, 
   {{0xe57852c4,0x48fc03ce,0x00000000,0x00000000}},	//   рзі_, _रेपो_, --, --, 
   {{0xe7849786,0x261c2b76,0x76440796,0xdb04012c}},	//   _мусо, fíos_, _tujy, _zahá, 
   {{0xe3b040ab,0xbcf8020c,0xdb0401e3,0x261c01e7}},	//   برن_, nbéb, _enhö, gíos_, 
   {{0xc69004ac,0x201ccb97,0x00000000,0x00000000}},	//   _מאל_, _akvi_, --, --, 
   {{0x272c01e1,0x00000000,0x00000000,0x00000000}},	//   _tóní_, --, --, --, 
   {{0xddc801fa,0x261c0077,0x0ea8034b,0x6d45abe7}},	//   grdž, bíos_, гкой_, _sgia, 
   {{0x7ddc069c,0x69c1abe8,0x261c09c2,0xf8bc01d3}},	//   _kësh, _ómeg, cíos_, _szél_, 
   {{0xaee000cd,0xec7800c7,0x00000000,0x00000000}},	//   _akṣi, аҿи_, --, --, 
   {{0x60c4038f,0x7ddc02d3,0x20c8131e,0x81840228}},	//   _ġimg, _mësh, _نبوي_, _اچىق_, 
   {{0x7ddc02d3,0xdb0401e7,0x00000000,0x00000000}},	//   _lësh, _sahá, --, --, 
   {{0xdb040124,0x29c80131,0x2d840ba1,0x4998005b}},	//   _pahá, аңни_, òmes_, лтая_, 
   {{0x6d44014b,0x46e82d55,0x7f38008f,0x7ddc0200}},	//   _ugia, ңдан_, _געצו, _nësh, 
   {{0xbe0001d9,0xdcec031c,0xcdc4022e,0x00000000}},	// [2e420] _روٝٹ, _rbaħ, _ваққ, --, 
   {{0x0768007b,0x3b9c0092,0x00000000,0x00000000}},	//   اماً_, _ልምዶች_, --, --, 
   {{0x261c0077,0xbcf80129,0x7ddc0200,0xdb040118}},	//   xíos_, rbée, _bësh, _tahá, 
   {{0x261c612f,0xa2b84a18,0x7ddc0023,0xbcf800e4}},	//   víos_, ्मस्, _cësh, raév, 
   {{0x7ddc069c,0xc5144acd,0x44f801ed,0x261c00ae}},	//   _dësh, حبات, دراج_, fíor_, 
   {{0x261c01e7,0x00000000,0x00000000,0x00000000}},	//   tíos_, --, --, --, 
   {{0xf99c033b,0xddc80cf4,0x7cec01e1,0xdcec0135}},	//   _akèy_, vrdž, _kòré, _tbaħ, 
   {{0x261d9279,0x7cec01e1,0x2ca157fb,0x7ddc0240}},	//   ríos_, _jòré, _opid_, _gësh, 
   {{0x5f58001f,0xdb040112,0x03940395,0x00000000}},	//   _የበለጸ, _unhö, _грея, --, 
   {{0xbcf80036,0x7ddc036e,0x00000000,0x00000000}},	//   hbéc, _zësh, --, --, 
   {{0x2ca00098,0x9e3400d8,0x74100244,0x035401ee}},	//   _apid_, женч, _عوما, _күҙә_, 
   {{0xb95801e1,0x1950037e,0x7ddc0240,0x80d800fe}},	//   _anìn, _ｌｅｄ_, _kësi, _বেণ্, 
   {{0x2ca00334,0x69cc0118,0x00d800ae,0x321401f7}},	//   _cpid_, हानी, _حبات_, _ايند_, 
   {{0x7ddc044e,0x2d84004e,0x00000000,0x00000000}},	//   _mësi, òmer_, --, --, 
   {{0xdd943b5f,0x495401f2,0xdb0403e0,0x00000000}},	//   _дайы, _ọtụ_, _mahç, --, 
   {{0x7de4591c,0x2ca00334,0xfe740137,0x00000000}},	//   _دستم, _fpid_, _күү_, --, 
   {{0x6fdc0129,0xa93401ec,0x683000a2,0x00000000}},	// [2e430] _bêch, зетш, kädd, --, 
   {{0xdd30068f,0xe6b40086,0xdb04496e,0x7ddc0200}},	//   _mężc, _òkûñ, _nahç, _sësh, 
   {{0xda7001d9,0xf8bc0158,0x7ddc0023,0x98b80205}},	//   _تُج_, _syéd_, _pësh, ıyık_, 
   {{0xf8bc0248,0xd1c002d3,0x6ea801ad,0xd1f0001f}},	//   _ayée_, ድታት_, _जनसु, ውቀት_, 
   {{0x7ddc044e,0xdb040365,0xc0cc044e,0x798c02d0}},	//   _vësh, _bahç, _እግሪ_, _iccw, 
   {{0x7bd400e8,0xf99c020c,0x6830007c,0xb6e40828}},	//   _joxu, _ojèk_, gädd, _любк, 
   {{0xe3b1abe9,0xc7b00375,0x425001e2,0x52740276}},	//   عره_, _קבל_, ونور, цулу, 
   {{0x6594f5b3,0x00000000,0x00000000,0x00000000}},	//   _насу, --, --, --, 
   {{0x63c4012c,0x7ddc0036,0x4fe9abea,0x798c02d0}},	//   átní, _gësi, имин_, _mccw, 
   {{0xcf3800d6,0x7bd47885,0xa2b817c6,0x68300267}},	//   ичні_, _noxu, ्मश्, rädg, 
   {{0x2ca1abeb,0x63c400bc,0x23740030,0x798c03ac}},	//   _spid_, štní, šajú_, _occw, 
   {{0xcdf40953,0x2481abec,0x221402bf,0xa2b89295}},	//   ічны, šime_, _ефір, ्मर्, 
   {{0x68300715,0xf99c020c,0x71240202,0x2ca00175}},	//   läde, _ijèh_, _ارال, _qpid_, 
   {{0x798c0857,0x7bd5abed,0x9e65abee,0x853805d0}},	//   _accw, _coxu, _کاون, יגרי, 
   {{0x7bd41bce,0x6fdc000f,0x4420013f,0x798c02d0}},	//   _doxu, _rêch, _ɔk_, _bccw, 
   {{0x4c8400d8,0xf40c03d4,0x00000000,0x00000000}},	//   _длив, িতিৰ_, --, --, 
   {{0xba14005e,0x6fdc20ef,0x683003fa,0xdb1400d2}},	// [2e440] زيكا_, _pêch, häde, ndzê, 
   {{0x7bd41bce,0x798c035a,0xbcf80036,0x68300108}},	//   _goxu, _eccw, sbéc, käde, 
   {{0x8544e1fb,0xb95800a3,0xbcf80c6a,0xf1bc00cd}},	//   оэле, _gnìo, mbéa, _शोभन, 
   {{0x798c035a,0x7ddc0200,0x68300166,0x00000000}},	//   _gccw, _pësi, däde, --, 
   {{0x7bd5abef,0x290400e4,0x38ac007c,0xdb200241}},	//   _yoxu, _ãma_, _vörå_, _àtòj, 
   {{0x9f4c067c,0x68303b52,0x00000000,0x00000000}},	//   sidú_, fäde, --, --, 
   {{0x26cc069c,0x683033f7,0x7ddc00e8,0xb9580241}},	//   _çdo_, rädd, _wësi, _onìl, 
   {{0xd5ac00dd,0x290c016b,0xe3b00014,0x00000000}},	//   _مہم_, _ɛdan_, برچ_, --, 
   {{0xc05802bf,0x1c1c00bc,0x00000000,0x00000000}},	//   шій_, पकमल_, --, --, 
   {{0x68300112,0x601000c7,0xf8bc01d3,0x38980677}},	//   bäde, _ẽmbo, _szék_, סיינ, 
   {{0x2450001e,0x6ff000ae,0x00000000,0x00000000}},	//   _hàm_, بسيط, --, --, 
   {{0xc0cc2e1f,0x29dc3eba,0x2450002e,0xffa001c0}},	//   _እግር_, _mías_, _kàm_, члүү, 
   {{0x59e0033f,0xa00400f7,0x00000000,0x00000000}},	//   _नवबर, _ىستۇ, --, --, 
   {{0x245000a3,0xf99c007f,0x7bd40213,0xdfd00066}},	//   _màm_, _tjèk_, _qoxu, _سيب_, 
   {{0x2450431d,0xf96806bb,0x236c00f3,0xcfa84c12}},	//   _làm_, ирай_, _medj_, _دانم_, 
   {{0x5c74094c,0xe6b40086,0x88d403d4,0x5fe00073}},	//   _елит, _òkùñ, _সেইক, _पकडल, 
   {{0x7bd400ac,0xe89400c9,0xbcf8003e,0x24500051}},	// [2e450] _toxu, мать, raés, _nàm_, 
   {{0x4e9401ed,0x00000000,0x00000000,0x00000000}},	//   _بھیج_, --, --, --, 
   {{0xdb041d4b,0xac383592,0xbcf80098,0x6d4800bc}},	//   _bahå, _بسيط_, paés, ědav, 
   {{0x29dd3316,0x683001e6,0x28c801ad,0x00000000}},	//   _días_, väde, रमशि, --, 
   {{0x2451abf0,0x24f8652e,0xf99c0cad,0x8cbc033f}},	//   _càm_, онцы_, _ibè_, शियो, 
   {{0xf8bdabf1,0x49380302,0x68303407,0x63c401e0}},	//   _iré_, _לגרו, täde, дашҡ, 
   {{0xcf4405f5,0x00000000,0x00000000,0x00000000}},	//   үний, --, --, --, 
   {{0x10681b6d,0x6831abf2,0x7ddc0200,0x00000000}},	//   биий_, räde, _kësu, --, 
   {{0x24580c9e,0x00c4ea10,0xf99c01e1,0x65940139}},	//   _мать_, злык_, _mbè_, _юату, 
   {{0x7ddce5c7,0x68301d13,0x00000000,0x00000000}},	//   _mësu, päde, --, --, 
   {{0xa3b846ca,0x23840014,0xf99c01e1,0x00000000}},	//   _باقر_, _زٔنِ, _obè_, --, 
   {{0xcfe8034c,0xf8bc00e4,0xf99c0241,0xa0c400ec}},	//   _گفته_, _oré_, _nbè_, _ڊيمو, 
   {{0x60c45941,0x24500051,0xd17401af,0x00000000}},	//   _àimp, _xàm_, _дыһы, --, 
   {{0xf99c0241,0x00000000,0x00000000,0x00000000}},	//   _abè_, --, --, --, 
   {{0x9e64278f,0xf8bc0ca8,0xbcf8003e,0x9f4c0240}},	//   _قاين, _aré_, rbéa, zhdë_, 
   {{0x29dc1709,0x8b646c9d,0xbcf800f2,0xf8bc0332}},	//   _rías_, _کاظم, mbén, _bré_, 
   {{0xf8bdabf3,0xfbc0190c,0x00000000,0x00000000}},	// [2e460] _cré_, शाखम, --, --, 
   {{0xf99daa3c,0x29dc056a,0xf8bc01f5,0xe3b805d1}},	//   _ebè_, _pías_, _dré_, _akın_, 
   {{0xf8bc110e,0x236c017a,0x2451abf4,0x46f401f0}},	//   _eré_, _redj_, _sàm_, ччат, 
   {{0x29dc09ff,0xf99c110e,0x00000000,0x00000000}},	//   _vías_, _gbè_, --, --, 
   {{0xf8bc004a,0x26dc0793,0x290400c7,0xf1bc06ff}},	//   _gré_, ävob_, _äma_, _शोधन, 
   {{0x29dc3eba,0x14580006,0x24500208,0x7af800df}},	//   _tías_, ішчы_, _vàm_, ŝute, 
   {{0xd36c1e87,0xb3700372,0x7ddc3621,0x78b8031c}},	//   شۇن_, ردوش, _këst, _ġuvi, 
   {{0x2fc5abf5,0x24500208,0x826801a9,0xf74001f4}},	//   _anng_, _tàm_, _ҳажв_, _чесо, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbcf8c00f,0x81454cc3,0xe7e40037,0xe8c800cd}},	//   gbén, _فنان, _गवना_, रमुच, 
   {{0x2fc40083,0x3f800e2d,0x6298002f,0x00000000}},	//   _enng_, şku_, mtvo, --, 
   {{0x62983c02,0x5f9401c6,0x7a3003e0,0x9b58009d}},	//   ltvo, _жилт, nçte, жигт_, 
   {{0xdb04019f,0x63b802c4,0x3078008d,0x7ddc002e}},	//   _gahû, ndvn, _פאונ, _rësu, 
   {{0x7c65abf6,0x6299abf7,0x7dddab98,0x200c05ac}},	//   _کابل, ntvo, _bëst, mndi_, 
   {{0x5e443306,0xf8bca4f7,0x63b802c4,0x6298257d}},	//   _تَعْ, _pré_, hdvn, itvo, 
   {{0x57b40eff,0x7ddc0036,0x6d41abf8,0x62980072}},	// [2e470] мбат, _dëst, žmar, htvo, 
   {{0x200dabf9,0x6298389b,0x29dc013d,0x7b64004e}},	//   nndi_, ktvo, _qíar_, _этие, 
   {{0x5a34052f,0x200dabfa,0xa2c00b27,0x00000000}},	//   _онот, indi_, विफ्, --, 
   {{0xdef8044e,0xa2c01157,0x7dddabfb,0xf8bdabfc}},	//   _ወያነ_, विन्, _gëst, _tré_, 
   {{0x62980d47,0xa91001e4,0x54352ac8,0x00000000}},	//   etvo, gaɾd, ورتر, --, 
   {{0x67380bc9,0xd7c804fb,0x7ddc0036,0x62980e78}},	//   ñajä, _بوسه_, _këss, ftvo, 
   {{0x60c4025c,0x629801bf,0x00000000,0x00000000}},	//   _ġima, gtvo, --, --, 
   {{0x24800989,0x60c5abfd,0x200dabfe,0x683001b8}},	//   šima_, _šima, endi_, mäda, 
   {{0x6b9c0cfd,0x4dd404c5,0x6830014a,0x200c01a8}},	//   yfrg, দসমূ, läda, fndi_, 
   {{0x63b802c4,0xb9580241,0x7e6801bf,0xe3b1abff}},	//   cdvn, _bnìk, _bwfp, _مرم_, 
   {{0x6830f717,0x41b04d20,0x7ddc0036,0x8e280116}},	//   näda, رمیر, _nëss, _тaл_, 
   {{0x200dac00,0xbcf80687,0xf1a80133,0x67e001e3}},	//   andi_, rbén, _دائه_, _höjt, 
   {{0x0ba80372,0xb9580241,0x321c00e8,0x68300037}},	//   ياسى_, _enìk, mouy_, häda, 
   {{0x7ddc04c4,0x6830014a,0x2fc4003b,0x67e001f4}},	//   _bëss, käda, _unng_, _yöju, 
   {{0xef1c03be,0x224001e4,0x00000000,0x00000000}},	//   şüb_, ʈiko_, --, --, 
   {{0x683029ef,0x7ddc04e6,0xe3b8247e,0x26c40010}},	//   däda, _dëss, _akıl_, _čmo_, 
   {{0x6e240537,0xd7c805ba,0x39480327,0x63b802b9}},	// [2e480] _ikib, रांच, _dgcs_, ydvn, 
   {{0x6d6800aa,0x77802082,0x00000000,0x00000000}},	//   _بلکې_, клуз, --, --, 
   {{0x86c40491,0x63b802c4,0x6830014a,0x4e002db8}},	//   بيان, vdvn, gäda, _लगाई_, 
   {{0x45283667,0x85042a60,0x7d78008f,0x00000000}},	//   ожен_, ووان, ַנצו, --, 
   {{0x63b802b9,0x200c2833,0xc76410a8,0x7ddc0036}},	//   tdvn, yndi_, _ياسى, _zëss, 
   {{0x683001b8,0x68e400ca,0x50600092,0x6e2400a2}},	//   bäda, myid, _ለሁላች, _lkib, 
   {{0xf7401bb8,0x68e5ac01,0x6e254d6f,0x200c06ea}},	//   _аеро, lyid, _okib, vndi_, 
   {{0x6e245d23,0x62991ea3,0x63b802c4,0x25b40014}},	//   _nkib, rtvo, sdvn, _سۆتھ_, 
   {{0x62980384,0x68e5ac02,0x66000194,0xdb0401e1}},	//   stvo, nyid, _immk, _dahù, 
   {{0x66000280,0x200dac03,0x6298002f,0x0ec803ce}},	//   _hmmk, undi_, ptvo, िमंड, 
   {{0x6449ac04,0x68e4acdb,0x00000000,0x00000000}},	//   _iidi, hyid, --, --, 
   {{0x80a5ac05,0x00e418b6,0x7330247f,0x6449ac06}},	//   _يمان, _ожен, _شىنا, _hidi, 
   {{0x6449ac07,0xa2b800cd,0x00000000,0x00000000}},	//   _kidi, ्मक्, --, --, 
   {{0x6e240c8a,0x6449ac08,0x68e40433,0x5f9400fd}},	//   _ekib, _jidi, dyid, _чикт, 
   {{0x6449ac09,0x93940023,0xaa95ac0a,0x00000000}},	//   _midi, _ዘኽእሎ_, кирч, --, 
   {{0x6449ac0b,0x8cc404fa,0x00000000,0x00000000}},	//   _lidi, ामखो, --, --, 
   {{0x7ddc04c4,0x7b646582,0x6448007b,0x3f9c208d}},	// [2e490] _wëss, _отне, _oidi, oftu_, 
   {{0x6449ac0c,0x693405f5,0xa9340220,0xd7c8000d}},	//   _nidi, тнуу, теуш, राइच, 
   {{0x68e4022f,0x3f9c022f,0x9f4c0789,0x4bc0013d}},	//   ayid, iftu_, lidó_, _сөяг, 
   {{0x683001e6,0x6d4000ee,0x95d80108,0x00000000}},	//   räda, ýmag, ядет_, --, 
   {{0x6449ac0d,0xd468f112,0x9f4c01b8,0x68300793}},	//   _bidi, чиле_, fidü_, säda, 
   {{0x6831ac0e,0x644801d9,0x569400ee,0x660000d7}},	//   päda, _cidi, _пагт, _emmk, 
   {{0xa2b809fa,0x00000000,0x00000000,0x00000000}},	//   ्मग्, --, --, --, 
   {{0x6449ac0f,0x9185ac10,0x1068084c,0x85180073}},	//   _eidi, رجعم, пиий_, _फुकट_, 
   {{0xd1440020,0x316c0c6a,0xa3b80451,0x504400c7}},	//   _ማናቸው, _vegz_, _ڊالر_, неиб, 
   {{0x6e245f8b,0x63a40e04,0xa3d00c6e,0xb4000150}},	//   _skib, đinc, षाण_, _шүлд, 
   {{0xa2c01fbc,0x00000000,0x00000000,0x00000000}},	//   विण्, --, --, --, 
   {{0x68e5ac11,0x228401c0,0x9e64030f,0x6468000d}},	//   yyid, _шууг, کاین, _äriõ, 
   {{0xc0dc0023,0xabb400c7,0x00000000,0x00000000}},	//   ቕባል_, ҭаҭә, --, --, 
   {{0xe51000af,0x6449ac12,0x67e0007c,0xe0d00133}},	//   ़पति_, _xidi, _löjr, _خزم_, 
   {{0xf1d00b26,0xfaa0bd06,0xa3d175b0,0x8ff800ec}},	//   थापन, ларо, षात_, _ورڪر_, 
   {{0xa2c007b6,0x6e24555f,0x68e40810,0x00000000}},	//   वित्, _ukib, tyid, --, 
   {{0x9f4dac13,0x2d8001c7,0x68e40083,0x00000000}},	// [2e4a0] cidó_, _idie_, uyid, --, 
   {{0xd7f802bf,0x67e0007c,0x7af800df,0x00000000}},	//   мує_, _röjs, ŝuta, --, 
   {{0x6449ac14,0xf8bc01d3,0x00000000,0x00000000}},	//   _ridi, _szét_, --, --, 
   {{0x6449ac15,0x68e40309,0x248000e4,0x00000000}},	//   _sidi, pyid, áimo_, --, 
   {{0x6449ac16,0x00000000,0x00000000,0x00000000}},	//   _pidi, --, --, --, 
   {{0x644900ae,0x2481ac17,0x60c44e86,0x00000000}},	//   _qidi, šimo_, _šimo, --, 
   {{0x2d81ac18,0x6830014a,0xa2c007b7,0x00000000}},	//   _odie_, lädo, विध्, --, 
   {{0x2d807b5d,0x64480429,0x00000000,0x00000000}},	//   _ndie_, _widi, --, --, 
   {{0x6449ac19,0x80040474,0x315400c6,0x68302045}},	//   _tidi, ечне, رجية_, nädo, 
   {{0xa2c05168,0x2d81ac1a,0x9f4cd7b4,0x6449ac1b}},	//   विद्, _adie_, vidó_, _uidi, 
   {{0x1b04015b,0x9f4c0bdf,0x3f9c0008,0x00000000}},	//   _শুনে_, fidò_, rftu_, --, 
   {{0x9f4c0332,0x00000000,0x00000000,0x00000000}},	//   mhdí_, --, --, --, 
   {{0xbcf80066,0xbe480066,0x00000000,0x00000000}},	//   mbék, _کشتم_, --, --, 
   {{0x9f4c00d8,0x00000000,0x00000000,0x00000000}},	//   ridó_, --, --, --, 
   {{0xeab000dd,0x683001e6,0x9f4c00db,0xbdd800db}},	//   یعہ_, tädn, sidó_, tmèd, 
   {{0x42780201,0x7e7801f5,0x68300793,0xdef801ec}},	//   _አይነት_, mstp, fädo, _нық_, 
   {{0x04f0015b,0x683001b8,0xbdd90baf,0x6fb41116}},	// [2e4b0] জপুর_, gädo, rmèd, _असमं, 
   {{0xd7c8221d,0xe944c48f,0xa8840131,0x7e7801a4}},	//   بوطه_, ухсо, اللى, ostp, 
   {{0x5695ac1c,0x6a5c007f,0x60c4107d,0x59f81d5b}},	//   тает, _pčfe, _šiml, _женя_, 
   {{0x68300793,0x7c6c001f,0x7e780165,0xe8800240}},	//   bädo, _ጠቅሰው_, istp, _ኪፍጸም_, 
   {{0x0f4402d3,0xe4580212,0x00000000,0x00000000}},	//   _መዓስከ, ежі_, --, --, 
   {{0x7e7811c0,0x53a40166,0x00000000,0x00000000}},	//   kstp, такб, --, --, 
   {{0xb5a551d7,0x2054005e,0x572417de,0x25a400f3}},	//   _прай, қтыр, _شىرك, _fbml_, 
   {{0x163402f6,0x683003fa,0xa2b800dc,0x63a401fa}},	//   _ребя, hädl, ्मज्, đina, 
   {{0x30cc02f5,0x2d80062c,0xe1640131,0x00000000}},	//   িন্স, _rdie_, ددىي, --, 
   {{0x7e78002f,0x7774025c,0x00000000,0x00000000}},	//   fstp, naxx, --, --, 
   {{0xbcf80005,0x61ec01d3,0x7e7800de,0x8e8402e8}},	//   ncéf, álló, gstp, ъгне, 
   {{0xdbd40248,0x77740327,0x00000000,0x00000000}},	//   _gúús, haxx, --, --, 
   {{0x77740429,0x7e78b266,0x9f4c02e2,0x8ff8030d}},	//   kaxx, astp, ridò_, _охку_, 
   {{0x4fc004a9,0x80d804c5,0x6830014a,0x3ed001d5}},	//   _ئەدە, _বেক্, vädo, _چقور, 
   {{0x49940733,0xefcc0092,0x7774031c,0x4df4022e}},	//   кшат, ባኤው_, daxx, _аяпт, 
   {{0x6830014a,0x98b80139,0xccc400f7,0x00000000}},	//   tädo, _aesı_, _абий, --, 
   {{0x7774025c,0x00000000,0x00000000,0x00000000}},	// [2e4c0] faxx, --, --, --, 
   {{0x68300793,0xbcf80129,0x8c440815,0xca7401af}},	//   rädo, zbék, _шепе, _иумы, 
   {{0x3ab00075,0x00000000,0x00000000,0x00000000}},	//   _кәтт, --, --, --, 
   {{0xa2c07e92,0x683001b8,0xd5d402d5,0x00000000}},	//   विस्, pädo, лючы, --, 
   {{0x77740135,0x00000000,0x00000000,0x00000000}},	//   baxx, --, --, --, 
   {{0x82a4656c,0xd04c0134,0x98b80139,0x7e780fac}},	//   вшие, _ɔkɔt, _gesı_, ystp, 
   {{0x2ba441ac,0x00000000,0x00000000,0x00000000}},	//   ख्या, --, --, --, 
   {{0xbbdcdad1,0xdcec01e4,0xdb040306,0x00000000}},	//   _नक्क, _adaĝ, _nahý, --, 
   {{0x15b042c6,0x00000000,0x00000000,0x00000000}},	//   _دەنس, --, --, --, 
   {{0xef1c03ee,0x9ed80261,0x1da417e6,0xfc440419}},	//   ğün_, емот_, ग्नत, číku_, 
   {{0xef1d2af5,0x7e780158,0x442c0175,0xbcf800e4}},	//   şün_, ustp, mlf_, mbéi, 
   {{0x7e782940,0xbcf80036,0x00846be1,0x91a00118}},	//   rstp, lbéi, _алдо, क्दै, 
   {{0xf0700014,0x00000000,0x00000000,0x00000000}},	//   _نُند, --, --, --, 
   {{0x442c0175,0x77740051,0x00000000,0x00000000}},	//   nlf_, xaxx, --, --, 
   {{0x68300267,0xbcf800ae,0x442c36f4,0x00000000}},	//   rädl, ibéi, ilf_, --, 
   {{0x7af800df,0x98b80205,0x394c01bf,0x00000000}},	//   ŝuto, _sesı_, øgs_, --, 
   {{0xd6d81079,0x7774025c,0x00000000,0x00000000}},	// [2e4d0] کواش_, taxx, --, --, 
   {{0xa37c0115,0x957c02d3,0x68300267,0xdb0402f0}},	//   _loĵb, _ከምዘላ_, lädj, _zahý, 
   {{0x7775ac1d,0x1fe0000d,0x00000000,0x00000000}},	//   raxx, _पकैड, --, --, 
   {{0x442c0048,0x5a040117,0x00000000,0x00000000}},	//   elf_, _сӯгв, --, --, 
   {{0x1da480ee,0x65942369,0xb864027d,0x9b4401d3}},	//   ग्यत, рачу, _جاجو, _جنھو, 
   {{0x59d000e1,0xa8a41b0a,0x7774031c,0x00000000}},	//   हावर, _трюк, qaxx, --, 
   {{0xa2c1ac1e,0xf6440588,0xbcf80109,0x00000000}},	//   विष्, _ахан, lcéd, --, 
   {{0x442c70c7,0x1da4197c,0x00000000,0x00000000}},	//   alf_, ग्मत, --, --, 
   {{0xd0242ef6,0xbcf84ae9,0x00000000,0x00000000}},	//   лмий, ncéd, --, --, 
   {{0xa2c01546,0xa438004e,0x24800022,0x00000000}},	//   विश्, _азуу_, âime_, --, 
   {{0xa3000046,0x69c8013f,0xa3d043d1,0xdb040118}},	//   _мүше, _ɔdeb, षार_, _pahý, 
   {{0xa2c000dc,0x2dc80e46,0x00000000,0x00000000}},	//   विर्, тқин_, --, --, 
   {{0xe0d003e6,0x4fa401d5,0x20101d0e,0x76e400cc}},	//   _وزه_, _билв, ðlið_, _গেমছ_, 
   {{0x32c00139,0x00000000,0x00000000,0x00000000}},	//   _kıy_, --, --, --, 
   {{0xf8bc00dd,0x1898001f,0xdb044b36,0x00000000}},	//   _szép_, ቆጣጠር_, _tahý, --, 
   {{0x4fc004a9,0x32c00166,0x00000000,0x00000000}},	//   _ئەگە, _mıy_, --, --, 
   {{0x07a5ac1f,0xc7a5ac20,0x629c00e4,0x32c00166}},	// [2e4e0] лаан, лиак, _ãrov, _lıy_, 
   {{0x46f43252,0x60c5ac21,0x9988033f,0x8c64008e}},	//   лчет, _šimk, gnał_, _итүд, 
   {{0x0584e8ea,0x32c00166,0x00000000,0x00000000}},	//   гулм, _nıy_, --, --, 
   {{0x05b9ac22,0xd5b9ac23,0x00000000,0x00000000}},	//   عدات_, ксі_, --, --, 
   {{0xf8bc0098,0xbcf9ac24,0xe375ac25,0xa4d40212}},	//   _nyéh_, ccéd, аллы, ролі, 
   {{0x437401c0,0x63a405be,0x32c006be,0x670401e0}},	//   уудт, đino, _bıy_, _күзб, 
   {{0x5805ac26,0x32c00166,0xbcf801c7,0x82a4010b}},	//   _торғ, _cıy_, rbéi, ушле, 
   {{0x442c0014,0x32c00139,0x2ba400e1,0xdcec013d}},	//   slf_, _dıy_, ख्ता, _ndağ, 
   {{0x442c022f,0x5ff40d1d,0x00000000,0x00000000}},	//   plf_, изиу, --, --, 
   {{0x04440598,0xbcf807ea,0xdcec0205,0x00000000}},	//   _сезн, ncée, _adağ, --, 
   {{0x29dc097a,0xe7fc007d,0x9f341ed7,0x32c00139}},	//   _díaz_, _एतना_, рені, _gıy_, 
   {{0x9988033f,0xdd95ac27,0x00000000,0x00000000}},	//   znał_, шамы, --, --, 
   {{0xae04185b,0x1fb9ac28,0xdfd40b7e,0x11e84fca}},	//   शोधन_, _аллы_, _волы, _جعلي_, 
   {{0x6c55ac29,0x308000c6,0xef1401c0,0x00000000}},	//   скру, _الوف, _өмч_, --, 
   {{0x38c80022,0x39a4013e,0x9e34004e,0x00000000}},	//   _oîrô_, лшав, _кекч, --, 
   {{0xfa340f1c,0x00000000,0x00000000,0x00000000}},	//   ارسد, --, --, --, 
   {{0x41a400cd,0x58d401a9,0x00000000,0x00000000}},	// [2e4f0] क्यस, шоат, --, --, 
   {{0x79a402dd,0xdd900345,0xa774004e,0x00000000}},	//   _өрме, _اوک_, йлуч, --, 
   {{0x1a64179e,0xca2c02dd,0xd5740108,0x00000000}},	//   _خیزی_, _ﺩﻭﺩ_, ауль, --, 
   {{0x98640014,0x19580c75,0x32c00139,0x00000000}},	//   _نیرے_, _шамы_, _rıy_, --, 
   {{0xa3d00a28,0x32c00166,0x987800df,0x00000000}},	//   षां_, _sıy_, _באָט, --, 
   {{0x24f850c0,0xcc8c0150,0xfc3c03b2,0x00000000}},	//   ынчы_, _ﺑﻪﺯﮔ, stíf_, --, 
   {{0xf8bc003e,0xbcf801d3,0xe3b00c4f,0xfc3c03b2}},	//   _syéh_, ncéb, ثرن_, mtíd_, 
   {{0x11e5ac2a,0x5f0800bc,0x00000000,0x00000000}},	//   ржим, ाछन्_, --, --, 
   {{0xe5340212,0xef1c0790,0x20548602,0xa5f85ce7}},	//   _геть, ğüm_, йтэр, _сету_, 
   {{0xef1ceab4,0xa3d000dc,0x32c00166,0xa3b8009f}},	//   şüm_, षाः_, _tıy_, _مامر_, 
   {{0xc7b00375,0x9bb8025c,0xa444009f,0x7c240210}},	//   חבי_, _བལྟོ, _اَلو, dojr, 
   {{0xcc8c06ba,0x9988030a,0x720401d3,0xbdc80014}},	//   _ﺑﻪﺭﮔ, nnań_, _حفصہ_, ندُے_, 
   {{0xf8bc003e,0x2d8c05d1,0x69c002d2,0x0b0000fe}},	//   _uyéh_, ğde_, _ómei, _এডেল_, 
   {{0xe4f80882,0x2d8c00ee,0x216401af,0x91a00456}},	//   ्छति_, şde_, _ктәг, क्रै, 
   {{0x3b040364,0xa37c0115,0xe7fc000d,0x24800327}},	//   аеро_, _joĵa, _एतबा_, ġimi_, 
   {{0x60c5ac2b,0xc965ac2c,0x24802753,0xa37c0115}},	//   _šimi, рвай, šimi_, _moĵa, 
   {{0x683029ef,0x629c00e4,0x02d0012c,0x9f58067c}},	// [2e500] lädi, _ärov, _थप्न, òrç_, 
   {{0xbc780375,0x17e40014,0xfef800a2,0x00000000}},	//   _שנית, ٝسمُ, _öçüp_, --, 
   {{0xf99c033b,0x6830014a,0xbcf84056,0xb604004d}},	//   _imèn_, nädi, rcée, _trờ, 
   {{0x99880165,0x00000000,0x00000000,0x00000000}},	//   gnań_, --, --, --, 
   {{0x24800597,0x68300730,0x0665ac2d,0x82340214}},	//   éim_, hädi, _چارپ, یرعا, 
   {{0x6830014a,0xf4840066,0x00000000,0x00000000}},	//   kädi, شاهی, --, --, 
   {{0xa5c4013d,0x51a00150,0x7f740092,0x00000000}},	//   _гөле, _ﺃﺤﺒﻁ_, _በሱማሌ_, --, 
   {{0xc19000f2,0xf1a0013d,0x00000000,0x00000000}},	//   زیتع, орьн, --, --, 
   {{0xdfd00491,0xf0756959,0x55f5ac2e,0xf1bc0419}},	//   كية_, айыш_, _учру, úšam_, 
   {{0x42e800c2,0x6830014a,0x645c0374,0x20180254}},	//   _имзо_, fädi, _ōriw, õri_, 
   {{0x443c003b,0x683029ef,0x9d540b28,0x33f8011a}},	//   _iht_, gädi, ینگت, _שהבנ, 
   {{0xf99c02e2,0x5ea804c5,0x73300131,0x443dac2f}},	//   _amèn_, গিলে, _بىما, _hht_, 
   {{0x443ca653,0x7c240455,0x1244009f,0x00000000}},	//   _kht_, tojr, _ائلٽ, --, 
   {{0x26fc00bd,0x9988068f,0x6830014a,0x443c03b2}},	//   _এখনো_, znań_, bädi, _jht_, 
   {{0x200dac30,0x443c2142,0xaae802bf,0x613001e1}},	//   midi_, _mht_, аєте_, bólú, 
   {{0x443dac31,0x5d8400c6,0xbcf9ac32,0x5a340fc0}},	//   _lht_, _الظل, rcéb, ёнат, 
   {{0x443c00c5,0x200c0010,0x3ea80327,0x00000000}},	// [2e510] _oht_, oidi_, ħbtu_, --, 
   {{0xb7643c7f,0x200dac33,0xb8fc0316,0x41a40a94}},	//   ртай, nidi_, _थप_, क्तस, 
   {{0xa3d0007d,0xb4cc0882,0x555426ba,0x9b6800c7}},	//   षाई_, षम्_, مپار, _ишҟа_, 
   {{0x200c00b2,0x443c4f41,0xbcf80077,0x79a41214}},	//   hidi_, _aht_, bbét, _трое, 
   {{0x200dac34,0x443dac35,0x2ba405f9,0x99880165}},	//   kidi_, _bht_, ख्वा, rnań_, 
   {{0x200c0dd4,0x00000000,0x00000000,0x00000000}},	//   jidi_, --, --, --, 
   {{0x443c02fa,0x200dac36,0xe3b1a3ca,0x1db800cd}},	//   _dht_, didi_, ظره_, ेयात, 
   {{0xef1c03ee,0x6830014a,0x6594735a,0x200c030a}},	//   şük_, vädi, _масу, eidi_, 
   {{0x200dac37,0x2be80073,0x00000000,0x00000000}},	//   fidi_, _ऐकलं_, --, --, 
   {{0x75380bb8,0x443c594a,0x6830014a,0x4100034b}},	//   _izuz, _ght_, tädi, языв, 
   {{0x22940efb,0xbdd8020c,0x21f80332,0xfbc800cd}},	//   _ۇلەس, rmèn, _séhe_, ायनम, 
   {{0xc69004ac,0x6831ac38,0x78ac0129,0xf1bc041c}},	//   האט_, rädi, _opcv, _शोचन, 
   {{0x200dac39,0x8c44054a,0x443d1b34,0xc0dc02d3}},	//   bidi_, йеме, _yht_, ሕባር_, 
   {{0x7539ac3a,0x6831ac3b,0x8c456aa8,0x7ddc0240}},	//   _mzuz, pädi, сеге, _mësy, 
   {{0x8e84007b,0xf1d8023e,0x24940023,0x00000000}},	//   _البه, _मचान, _ዘውሕስ_, --, 
   {{0x753802e3,0x00000000,0x00000000,0x00000000}},	//   _ozuz, --, --, --, 
   {{0x75380521,0xf99c02bd,0x00000000,0x00000000}},	// [2e520] _nzuz, _imèl_, --, --, 
   {{0xe4f800cd,0x00000000,0x00000000,0x00000000}},	//   ्छसि_, --, --, --, 
   {{0x443c0109,0x46a5ac3c,0x63a400e5,0x00000000}},	//   _rht_, саев, őink, --, 
   {{0xbcf9ac3d,0x200dac3e,0x443dac3f,0xd7180358}},	//   mbér, zidi_, _sht_, _दशरथ_, 
   {{0x200cbee3,0x15b82692,0x69c4b571,0x54e800f1}},	//   yidi_, рыхы_, mdie, ټرنټ_, 
   {{0x290005d9,0x443c00ac,0x69c5ac40,0xbcf80332}},	//   mzia_, _qht_, ldie, ncéa, 
   {{0x200dac41,0x75380944,0x998802d1,0x29014ae6}},	//   vidi_, _ezuz, llaš_, lzia_, 
   {{0x200dac42,0x443c0334,0x2900011c,0x69c5ac43}},	//   widi_, _wht_, ozia_, ndie, 
   {{0x2901ac44,0x4060ec6e,0x200dac45,0x443c009f}},	//   nzia_, _bọọl, tidi_, _tht_, 
   {{0x7af800c8,0x69c5ac46,0x200c0156,0x00000000}},	//   ŝuti, hdie, uidi_, --, 
   {{0x200dac47,0x5f3810f5,0xdd91ac48,0x69c4fe3c}},	//   ridi_, рпня_, وود_, kdie, 
   {{0x200dac49,0x60c41710,0x71705712,0x69c5ac4a}},	//   sidi_, _šimu, _فهما, jdie, 
   {{0x69c5ac4b,0x200dac4c,0xa2c01a3e,0x1c395108}},	//   ddie, pidi_, विक्, измы_, 
   {{0x406002e3,0x69c41207,0xf99c007f,0x200c0109}},	//   _gọọl, edie, _emèl_, qidi_, 
   {{0xcfa80e83,0xec34090b,0x69c4cba1,0x82c40327}},	//   _خانم_, їнсь, fdie, _གནསའ, 
   {{0x69c5ac4d,0x5a34177b,0xdb140200,0x00000000}},	//   gdie, інат, lezë, --, 
   {{0x7c94473f,0x998801a6,0x6c840592,0x7a3003e0}},	// [2e530] _اشعا, glaš_, _فليم, nçti, 
   {{0xa8a5698b,0x69c4d65c,0xdb140023,0x9b940fb4}},	//   ярск, adie, nezë, _بلدت, 
   {{0x2901ac4e,0x69c5ac4f,0x1ddc21b8,0xd6d10030}},	//   azia_, bdie, यापत, بقا_, 
   {{0x999802d5,0x69c5ac50,0xdb140036,0x3f88012d}},	//   _visų_, cdie, rdzä, óbuj_, 
   {{0xeaf80133,0x00000000,0x00000000,0x00000000}},	//   _نرێت_, --, --, --, 
   {{0xf8bdac51,0xdb140200,0xdcfc03e0,0x00000000}},	//   _isé_, jezë, nesı, --, 
   {{0x645c0053,0xfa24031c,0xa2c000dc,0xdb140200}},	//   _ōrit, _རྩོན_, विग्, dezë, 
   {{0xa5f8b0b9,0x69c0041e,0x6efc0248,0xca9c0023}},	//   _лесу_, _ómet, _lábé, ልቲኦም_, 
   {{0x2ab0006a,0x7539ac52,0xcfb4005b,0xe6bc01e1}},	//   _köbö_, _uzuz, ощны, _òsòò, 
   {{0x69c401f1,0x0ea80c98,0x8e840395,0x00000000}},	//   zdie, акой_, огое, --, 
   {{0x2901ac53,0x60c40006,0x24800006,0xe44800c6}},	//   zzia_, _šimt, šimt_, _اللى_, 
   {{0xf8bc87aa,0x69c40399,0x3f80013f,0xe3b80139}},	//   _osé_, xdie, ɔkum_, _ukır_, 
   {{0xfa240135,0x69c5ac54,0xdcfc013d,0x00000000}},	//   _རྩེན_, vdie, fesı, --, 
   {{0x69c5ac55,0x92cc03d4,0x317dac56,0xcfe800f2}},	//   wdie, ৱনী_, lauz_, _خفته_, 
   {{0xcdc41ee3,0xf8bdac57,0x1ea80214,0x290007ad}},	//   _ҳаққ, _asé_, _هايي_, wzia_, 
   {{0x29000323,0xbcf9ac58,0x69c5ac59,0x628c2b57}},	//   tzia_, scéa, udie, _úlož, 
   {{0x69c5ac5a,0x2440068c,0x2901ac5b,0x00000000}},	// [2e540] rdie, lòme_, uzia_, --, 
   {{0x69c5ac5c,0x290001a2,0xbcf80022,0x3c3c00e4}},	//   sdie, rzia_, mbép, tîve_, 
   {{0xbcf9ac5d,0xf8bc043b,0x69c4fcbb,0xf40c03d4}},	//   ncén, _esé_, pdie, াকাৰ_, 
   {{0x27f802e2,0x1ddcd0f6,0xdb14036e,0x7c54397a}},	//   _wlrn_, यायत, zezë, _دلیر_, 
   {{0x21f801ed,0xdb140240,0xa3d40798,0x00000000}},	//   _néha_, yezë, золч, --, 
   {{0xe2f802dd,0x68300113,0x15b801ec,0x00000000}},	//   йелі_, tädu, _қысы_, --, 
   {{0xfc3c99d5,0x1ddc1546,0xdb140200,0x7bd8011a}},	//   ntía_, यामत, vezë, יקסו, 
   {{0x317c0007,0x00000000,0x00000000,0x00000000}},	//   gauz_, --, --, --, 
   {{0x41a41a3e,0xdb14036e,0x683001f4,0x00000000}},	//   क्षस, tezë, sädu, --, 
   {{0x434400a8,0x9f4c007b,0x244002bd,0x25f001f9}},	//   _дезв, mhdú_, fòme_, _आवडी_, 
   {{0x9e34008e,0x63b9ac5e,0xdb140240,0xdb040419}},	//   зенч, mevn, rezë, _jahô, 
   {{0x63b9ac5f,0x317c031c,0x6d585043,0xab640327}},	//   levn, cauz_, _şvar, żżlu, 
   {{0xdbd40174,0xfbd0088c,0xdb0400d0,0xdb14c6ca}},	//   _búðs, وتس_, _lahô, pezë, 
   {{0x63b9ac60,0xdb15ac61,0x6abc0142,0x00000000}},	//   nevn, lezé, fwrf, --, 
   {{0xc1ec09d9,0x62980351,0xa2c019cc,0x00000000}},	//   _जवाब_, nuvo, विट्, --, 
   {{0x6298013c,0xded4001f,0xee0810fc,0xed8c0023}},	//   iuvo, ክኒክ_, _мејл_, _ፓስቶር_, 
   {{0x629802b9,0x57f40026,0x7c65ac62,0x63b8f5b8}},	// [2e550] huvo, ппат, _بابل, kevn, 
   {{0x63b9ac63,0x00000000,0x00000000,0x00000000}},	//   jevn, --, --, --, 
   {{0xdb14066d,0x7bd5ac64,0xfc3c0077,0x6299ac65}},	//   kezé, _inxu, ctía_, juvo, 
   {{0x6299ac66,0xdb1401ed,0x7bc5ac67,0xf8bc7d4f}},	//   duvo, jezé, ldju, _tsé_, 
   {{0x9f4c00c6,0x68300e78,0xf8bd38c8,0xf7704b08}},	//   ghdú_, tädt, _usé_, _ياس_, 
   {{0x7bc5ac68,0x63b80037,0x69c008a5,0x00000000}},	//   ndju, gevn, _ómer, --, 
   {{0x7bc40cfe,0x52740228,0x7d0003b9,0x6299ac69}},	//   idju, чулу, _ənsa, guvo, 
   {{0xa2c0cad6,0x21f80098,0xc69008a8,0xd18401c6}},	//   विज्, _péha_, _ראן_, члий, 
   {{0xfbc80882,0x7bd401e2,0xa91001e4,0x7bc4007c}},	//   ायाम, _onxu, taɾi, kdju, 
   {{0xaaac0cb4,0x63b9ac6a,0x7bc4031c,0xe3b8008e}},	//   _चहलक, cevn, jdju, _ukıp_, 
   {{0x62980286,0x7bc47c52,0xdb140036,0xbb3c1884}},	//   cuvo, ddju, bezé, _ﺑﺎﻻ_, 
   {{0xd1300491,0x7bd5ac6b,0x2440067c,0xdb200248}},	//   _كما_, _anxu, ròme_, _ìtùm, 
   {{0xbcf8180f,0x00000000,0x00000000,0x00000000}},	//   scén, --, --, --, 
   {{0x7bc4007c,0xa2c000cd,0x00000000,0x00000000}},	//   gdju, विच्, --, --, 
   {{0x6b9c020b,0x9ac40139,0x00000000,0x00000000}},	//   rgrg, мирҗ, --, --, 
   {{0x7bd5ac6c,0x7bc40d04,0xfc3c2b76,0x63b82625}},	//   _enxu, adju, rtía_, zevn, 
   {{0xfc3c39b3,0x63b9ac6d,0xbcf801d3,0x6298002f}},	// [2e560] stía_, yevn, ncél, zuvo, 
   {{0xfc3c0597,0x6a5c02e2,0xdb14f760,0x629800e4}},	//   ltín_, _lčfi, zezé, yuvo, 
   {{0x99881684,0xdb1401d3,0x63b80162,0x7c2802d2}},	//   nnaś_, yezé, vevn, _ígra, 
   {{0xfc3dac6e,0xf6200e4e,0xa2c000cd,0x00000000}},	//   ntín_, ндхо, विघ्, --, 
   {{0x63b9ac6f,0xdb1401ed,0x6298014b,0xb03802d3}},	//   tevn, vezé, wuvo, _ብጥንቃ, 
   {{0x6299ac70,0xf99c0066,0xfc3c0332,0x6830007c}},	//   tuvo, _amèh_, htín_, räds, 
   {{0x63b80316,0xdb1401d3,0x91dc00b8,0x00000000}},	//   revn, tezé, _suśṛ, --, 
   {{0x6299ac71,0x05640801,0x60f800a7,0xfc3c00d7}},	//   ruvo, _хван, жния_, jtín_, 
   {{0x63b802fb,0xbdd800f2,0x6299544b,0xdb1400e5}},	//   pevn, smèk, suvo, rezé, 
   {{0xf99c020c,0xfc3c0077,0x3b000175,0x00000000}},	//   _emèh_, etín_, yzjq_, --, 
   {{0x4394052f,0x442c0793,0xdb0402fb,0x62980869}},	//   _маҡс, mof_, _obhá, quvo, 
   {{0x442dac72,0xc2441e35,0x00000000,0x00000000}},	//   lof_, _энек, --, --, 
   {{0x7bc40d04,0x00000000,0x00000000,0x00000000}},	//   tdju, --, --, --, 
   {{0x442c014a,0x7bc40d04,0xc5f8015b,0xdb0401e7}},	//   nof_, udju, েকটা_, _abhá, 
   {{0x7e6800d8,0x1ddc3156,0xdcfc0064,0x00000000}},	//   _utfp, यादत, masč, --, 
   {{0x7bc401e6,0x21f8012c,0xdcfc0064,0xef1c236c}},	//   sdju, _mého_, lasč, ğüt_, 
   {{0x442c0793,0x21f8003e,0x79940166,0x683001e3}},	// [2e570] kof_, _lého_, _ğawğ, vädr, 
   {{0x3f9c1dd4,0x7bd41cdf,0x442c03cd,0x7ae000e8}},	//   ngtu_, _unxu, jof_, _ànto, 
   {{0x442c014a,0x1959ac73,0x1a6401d5,0x998800d0}},	//   dof_, _маны_, _آیری_, elať_, 
   {{0x95f802ab,0x7af801e4,0x953800d8,0x1f480023}},	//   ्फेट_, ŝuts, озет_, _መጓዓዝ, 
   {{0x6289ac74,0x442c01b8,0x799c014b,0xfc3c04d4}},	//   _avdo, fof_, mgqw, ntío_, 
   {{0x442d570e,0xc950011a,0xaa880345,0x00000000}},	//   gof_, _שמך_, _بنێم_, --, 
   {{0xea0007ae,0xddcc068f,0xd298b4c7,0xb2b400d1}},	//   _hoạt_, _miał, іткі_, яңжу_, 
   {{0x799c0912,0x628801f5,0x3f9c00e2,0x00000000}},	//   ngqw, _dvdo, egtu_, --, 
   {{0xbb3c08b0,0x442c014a,0xd1b801ed,0x62880166}},	//   _ﺑﺎﻱ_, bof_, ماکا_, _evdo, 
   {{0x442c0223,0xbcf80077,0xc44401d9,0x9988012d}},	//   cof_, rcél, _ہیۆن_, niał_, 
   {{0xea000016,0x9318027a,0x238401d9,0xb8dc031c}},	//   _loạt_, _بقاء_, _سٔنِ, _གག_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfc3c0615,0xddcc068f,0x8fa5ac75,0xe7e000cd}},	//   rtín_, _biał, _жале, नामप, 
   {{0xfc3dac76,0xddcc068f,0x9e6401d5,0x3c3c00c7}},	//   stín_, _ciał, باین, tîva_, 
   {{0x2fc5ac77,0xef1c05d1,0x2440180f,0xcdc400cf}},	//   _iang_, ğüs_, nòma_, _قۇدۇ_, 
   {{0x2fc5ac78,0x09e404c5,0xc9a80006,0x3c3c00e4}},	//   _hang_, নসভা, ўвае_, rîva_, 
   {{0x2fc4ef64,0x2d800421,0xbe100150,0x69c8016b}},	// [2e580] _kang_, _ieie_, _جويع, _ɔdeh, 
   {{0x2fc5ac79,0x442c0408,0x2d81a80e,0x4c940022}},	//   _jang_, xof_, _heie_, _еиҩс, 
   {{0x2fc5ac7a,0x4a45ac7b,0x442dac7c,0xfbc807f7}},	//   _mang_, _онов, vof_, ायरम, 
   {{0x2fc5ac7d,0x2d80000f,0xa3b0012c,0x91f40208}},	//   _lang_, _jeie_, ट्न_, _sún, 
   {{0x442dac7e,0x2d80033d,0x2fc5ac7f,0xbcf806af}},	//   tof_, _meie_, _oang_, ycém, 
   {{0x2fc5ac80,0x2d81ac81,0x99880034,0xbdd80ba1}},	//   _nang_, _leie_, ciał_, rmèi, 
   {{0x998801a2,0x442dac82,0x6234083f,0x26cc8607}},	//   slať_, rof_, неку, _édo_, 
   {{0x2fc5ac83,0x2d800a40,0x80b000bd,0xa084cfb1}},	//   _aang_, _neie_, জিস্, еңде, 
   {{0x2fc5ac84,0x442c017a,0x1ddc1b6e,0xceb40124}},	//   _bang_, pof_, यासत, ҵәы_, 
   {{0x2fc5ac85,0x301000ee,0x442c0003,0x00000000}},	//   _cang_, кдыр, qof_, --, 
   {{0x2fc5ac86,0x2d8008e5,0xbcf807ea,0xb9580241}},	//   _dang_, _beie_, rcém, _enìy, 
   {{0x2fc5ac87,0x99880034,0x44e00165,0x00000000}},	//   _eang_, ział_, _kʰ_, --, 
   {{0x2fc5ac88,0x2d8000ad,0xfc3c011f,0x1958010b}},	//   _fang_, _deie_, btíl_, җазы_, 
   {{0x2fc40e21,0x00000000,0x00000000,0x00000000}},	//   _gang_, --, --, --, 
   {{0xa3b0e858,0xef1c7236,0x2d801368,0xea000051}},	//   ट्य_, şür_, _feie_, _soạt_, 
   {{0x2fc5ac89,0x2d800327,0x20140034,0x9988033f}},	//   _zang_, _geie_, ścić_, wiał_, 
   {{0x2fc571ef,0xfc3c01e7,0x5d540395,0x00000000}},	// [2e590] _yang_, ltím_, _якит, --, 
   {{0x1ddc1fe5,0x3e5c0327,0xb9043e63,0x2d8001c7}},	//   यावत, _aċti_, _मऊ_, _zeie_, 
   {{0x99880034,0xeaa000b8,0x6d4000e4,0xbbc806b1}},	//   riał_, _reṇu_, ýmav, ायीक, 
   {{0x9988033f,0x00000000,0x00000000,0x00000000}},	//   siał_, --, --, --, 
   {{0x798c02d0,0x2e240790,0x99880210,0x00000000}},	//   _idcw, nıfa_, piał_, --, 
   {{0x2440067c,0x9344010b,0x03a00117,0xdb1400e5}},	//   tòma_, ннле, гишо, hezí, 
   {{0x6b7c025f,0xb5a42769,0x8fd00032,0xa3b815eb}},	//   חרונ, _орай, ғәлә, ظاهر_, 
   {{0x90c4005e,0xbbc81db2,0xfc3c00bc,0x2440068c}},	//   ебие, ायुक, dtím_, ròma_, 
   {{0x2fc5ac8a,0xe4a401fc,0x73c00032,0x2d81ac8b}},	//   _pang_, _архо, _аҡла, _reie_, 
   {{0xe3b01060,0x2d800183,0x2fc4016d,0x798c035a}},	//   _نرم_, _seie_, _qang_, _ldcw, 
   {{0x80b0015b,0x2d80062c,0xa3bc1b51,0x00000000}},	//   জিষ্, _peie_, इजर_, --, 
   {{0x3f8c009a,0x6304034c,0x2fc5ac8c,0x798c02d0}},	//   _edfu_, _جومل, _wang_, _ndcw, 
   {{0x2fc4138f,0x537402d3,0x2d801445,0x30a407b5}},	//   _tang_, _ጽንዓት_, _veie_, _црев, 
   {{0x2fc40574,0x798c03ac,0xdb040036,0x2d800036}},	//   _uang_, _adcw, _obhä, _weie_, 
   {{0x2d80007d,0x6d4001b8,0x2d8c013b,0x79cc00d1}},	//   _teie_, ümab, ɔden_, ﻗﻠﯩﻤ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x87b8656c,0xdb040730,0x6e24208d,0x321c011f}},	// [2e5a0] зует_, _abhä, _ijib, inuy_, 
   {{0xfd45ac8d,0x6d440115,0x4aa90029,0x00000000}},	//   _язык_, _izia, _екон_, --, 
   {{0x3ab00131,0x869850ce,0x798c02d0,0xade400ab}},	//   _йәтт, ятат_, _fdcw, गापन_, 
   {{0x9f5c02e2,0x44e00165,0x2bc800bc,0x00000000}},	//   _elvè_, _pʰ_, िएका, --, 
   {{0x6e24009f,0x240800ee,0x00000000,0x00000000}},	//   _mjib, үнҗи_, --, --, 
   {{0x6e24002d,0xfc3c0306,0x82b40327,0x39680023}},	//   _ljib, ytím_, _ྒྱུའ, ዳድርቲ_, 
   {{0xf7401ff0,0x6e2444a1,0x85b40640,0xbdd806af}},	//   _беро, _ojib, _пљач, omèt, 
   {{0xf99c007f,0x6e24020c,0x6d45ac8e,0x68e44087}},	//   _elèf_, _njib, _ozia, oxid, 
   {{0xdfd006d5,0xbdd9ac8f,0x68e4056a,0xbcf8003e}},	//   لية_, llèg, nxid, rcék, 
   {{0x6e25ac90,0x68e400db,0x00000000,0x00000000}},	//   _ajib, ixid, --, --, 
   {{0x6d45ac91,0xbdd80ba1,0x3814011a,0xdcfc002b}},	//   _azia, nlèg, תקים_, dasā, 
   {{0x6d4401e4,0xf1a43af4,0xfc3c02f0,0x5fd00073}},	//   _bzia, _गायन, rtím_, _थोरल, 
   {{0x6e25ac92,0xef1c0afb,0xfc3c0122,0xe29800fd}},	//   _djib, şüp_, stím_, _хаҗ_, 
   {{0x6d4414cf,0xbcf9ac93,0x6e24063f,0x6a5c0100}},	//   _dzia, ncéi, _ejib, _nčfs, 
   {{0xfc3c011f,0xbcf800ae,0x925800a2,0xb6000419}},	//   ltík_, icéi, _üşüg, úška, 
   {{0xa3b0069f,0x6299ac94,0x6e240240,0x2f38011a}},	//   ट्त_, irvo, _gjib, _מגוד, 
   {{0xe8940108,0x47c800eb,0x6fa400eb,0xdef801af}},	// [2e5b0] лать, রানী, _কোয়ে, _хыҙ_, 
   {{0xdb040055,0xbdd80066,0x69344f41,0xdcfc00b8}},	//   _abhå, amèt, унуу, casā, 
   {{0x68e40009,0x4bc00166,0xdb14002f,0xe82401f0}},	//   axid, _төяг, ndzü, уфто, 
   {{0x644802f6,0xd91402d5,0x5554029e,0x653400e5}},	//   _ahdi, _адмы, نپار, گرمذ, 
   {{0x62980196,0x644800a3,0x9988030a,0xa4d40816}},	//   ervo, _bhdi, riań_, лоці, 
   {{0x644800a3,0xf99c0100,0xd79400fd,0x7634030d}},	//   _chdi, _emèt_, _шигъ, ĕлчĕ, 
   {{0x629c00cc,0xbdd80100,0x00000000,0x00000000}},	//   _årol, nmès, --, --, 
   {{0x6448023a,0x00000000,0x00000000,0x00000000}},	//   _ehdi, --, --, --, 
   {{0x644801ab,0x5455ac95,0x6299ac96,0x8f9800a7}},	//   _fhdi, _ават, arvo, мънт_, 
   {{0x7658409c,0x753800ca,0x6e24017a,0x6fd801ad}},	//   _hiuy, _iyuz, _sjib, बाइं, 
   {{0xb8f003bd,0x76580d04,0x6d4400dd,0xdcfc0882}},	//   _ེན_, _kiuy, _szia, vasā, 
   {{0xc3300bd9,0x50b400a8,0xbcf8003e,0x00000000}},	//   _דוב_, _аску, ncéw, --, 
   {{0x6448049b,0x1fb40046,0x0c7801c0,0x00000000}},	//   _yhdi, _әсір, ьсны_, --, 
   {{0x8c44686c,0x7539ac97,0x3e5c025c,0x6d4400d0}},	//   теге, _myuz, _aċtu_, _vzia, 
   {{0x47c8015b,0xdcfc0882,0x6e24002d,0xfd1c0109}},	//   রামী, rasā, _tjib, raìa_, 
   {{0xba2010cd,0x3ea80316,0x6e25ac98,0x75389267}},	//   адск, žití_, _ujib, _oyuz, 
   {{0x75385416,0x07a40124,0x629c01e4,0xbdd8642b}},	// [2e5c0] _nyuz, каан, _ĥrom, rmèt, 
   {{0xf99c007f,0x76580099,0xbdd856ed,0x68e5ac99}},	//   _alèd_, _aiuy, bmès, rxid, 
   {{0x7539ac9a,0xbdd8026c,0x46a5ac9b,0x00000000}},	//   _ayuz, ulèg, таев, --, 
   {{0x75380230,0xfc3c011f,0x644801a9,0x00000000}},	//   _byuz, ytík_, _shdi, --, 
   {{0x75380230,0x76588075,0xc7640075,0xdb0407ea}},	//   _cyuz, _diuy, _لازى, _achè, 
   {{0x6004007f,0x629800f3,0xbdd8004e,0xdb14634d}},	//   _kòme, trvo, plèg, lezá, 
   {{0x62980942,0xbcf804e6,0x6fd80073,0x06540064}},	//   urvo, rcéi, बाईं, _атаў, 
   {{0x7658089c,0xdb040a40,0x75380139,0x62980072}},	//   _giuy, _schë, _fyuz, rrvo, 
   {{0x673c02d3,0xdb04033b,0x644801ab,0x00000000}},	//   _hyrj, _echè, _thdi, --, 
   {{0xb3700020,0x673c02d2,0xfc3c022a,0x1fc401f0}},	//   ከናወን_, _kyrj, rtík_, уриҳ, 
   {{0xdfd000aa,0xfc3c0f91,0x5274072c,0x75380139}},	//   ليک_, stík_, _бучу, _zyuz, 
   {{0x673c0158,0x3df0013e,0xfc3c02f0,0x1ddc0073}},	//   _myrj, рҷис, ptík_, याइत, 
   {{0xf99c0ba1,0x69c8016b,0x600402e2,0x673c036e}},	//   _omèr_, _ɔdet, _pòmd, _lyrj, 
   {{0xac24b9b0,0x00000000,0x00000000,0x00000000}},	//   афск, --, --, --, 
   {{0x19946345,0xaf31ac9c,0x656000a3,0x673c01f4}},	//   лавя, _پروت, _ogmh, _nyrj, 
   {{0x63a8020b,0x6004007f,0x8f4402bf,0x49a40032}},	//   _lcdn, _dòme, _схід, лыуғ, 
   {{0x57b414a4,0x7659ac9d,0xfc3c0429,0x6d48012d}},	// [2e5d0] лбат, _riuy, ytíh_, ędac, 
   {{0x6d6000c6,0x673d23ba,0xb8c80c2e,0x6004007f}},	//   ğyaş, _byrj, _गम_, _fòme, 
   {{0xf21000e1,0x7538022e,0xe3b8008e,0xdb1401ef}},	//   तोड़_, _syuz, _ukıy_, bezá, 
   {{0xa3b00141,0x76580d04,0x63a8035a,0x8af80375}},	//   ट्स_, _qiuy, _acdn, _נהרי, 
   {{0xdb05ac9e,0xe3b00451,0xe5c408ca,0x00000000}},	//   _schè, ڪرن_, рсхо, --, 
   {{0x7539ac9f,0xdb05aca0,0xd2a8f4e3,0x80d4547d}},	//   _vyuz, _aché, екке_, बिने, 
   {{0xe3b1aca1,0x76580099,0xfc3c011f,0x673c00a2}},	//   ترن_, _tiuy, rtíh_, _gyrj, 
   {{0x63a803ac,0x47c80011,0x00000000,0x00000000}},	//   _ecdn, রাণী, --, --, 
   {{0xf99c02e2,0x09c00327,0x75380205,0x90d40c4f}},	//   _klèb_, _གྲྦ_, _uyuz, اآبا, 
   {{0xdb05aca2,0x20540276,0x8ee8360e,0xa3d401f4}},	//   _tchè, итэр, емов_, _коуч, 
   {{0xe2c9aca3,0xd06802d3,0xb37004b2,0xf8dc00cd}},	//   _لولو_, _ተኣሲሩ_, ከናውን_, नमुप, 
   {{0xcf4803ee,0x69c8016b,0x2d840798,0x02f8008f}},	//   _ışık_, _ɔdes, úme_, _אלעמ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x40902ab5,0x6fa4004b,0xcac800f7,0x00000000}},	//   _الور, _شنبې_, нгге_, --, 
   {{0xbdd81497,0x4e94007b,0xf0cc0241,0x00000000}},	//   rmèr, _إشتر, _ìṣẹ́_, --, 
   {{0x38c81079,0xccc4022e,0x00000000,0x00000000}},	//   کافی_, _ббий, --, --, 
   {{0x673daca4,0xcb69aca5,0xdb141315,0x09a800bc}},	// [2e5e0] _syrj, _папе_, rezá, ङ्गठ, 
   {{0x65600175,0x00000000,0x00000000,0x00000000}},	//   _sgmh, --, --, --, 
   {{0xdb1404d4,0xf1c01bd6,0x00000000,0x00000000}},	//   pezá, वजान, --, --, 
   {{0xc9741f7b,0x09e5aca6,0x59742e70,0x02a41086}},	//   _حادث, _сомн, _выру, ҳрим, 
   {{0xbdd8068c,0x63a8045a,0xe7b800e5,0x00000000}},	//   llèc, _pcdn, _لگاؤ_, --, 
   {{0xdb04092e,0x02a43298,0xa3d4039b,0x73d402dd}},	//   _sché, грим, рокч, лдір_, 
   {{0x3d080241,0xd3780212,0x00000000,0x00000000}},	//   _kòwé_, тчі_, --, --, 
   {{0x7dd80598,0x00000000,0x00000000,0x00000000}},	//   _mäsä, --, --, --, 
   {{0x26d80fac,0xbcf9aca7,0xbdd80036,0xbfa8f3a6}},	//   _hrro_, ncét, hlèc, нтне_, 
   {{0x5f940f5c,0x00000000,0x00000000,0x00000000}},	//   јинт, --, --, --, 
   {{0x6d4003ee,0xdb0406af,0x7c280413,0xf834011a}},	//   üman, _tché, _ígri, רנית_, 
   {{0xa3b09e51,0x63a40198,0x7cec0139,0x9e342950}},	//   ट्र_, ɗina, _bеrе, ремч, 
   {{0xa37c0115,0xbdd800db,0xbb3c313e,0x6d41aca8}},	//   _enĵe, elèc, _ﺑﺎﻝ_, ýmap, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfc3c7448,0x7dd80166,0x44e80011,0x00000000}},	//   ktív_, _cäsä, কনিক_, --, 
   {{0x7dd801b8,0x24801155,0x00000000,0x00000000}},	//   _däsä, šimy_, --, --, 
   {{0x26d9aca9,0xbdd80ba1,0xae040150,0x317003b9}},	// [2e5f0] _arro_, alèc, _دويى, _əxz_, 
   {{0x37041e2d,0x7dd80139,0xf72800a8,0x00000000}},	//   лчев, _fäsä, нцей_, --, 
   {{0xea000208,0x00000000,0x00000000,0x00000000}},	//   _loẹt_, --, --, --, 
   {{0xd4f40dd8,0xd1dc1772,0xe3b80205,0x5bc41bd6}},	//   иялы, ዕታት_, _abı_, _लघुव, 
   {{0x26d9acaa,0x00000000,0x00000000,0x00000000}},	//   _erro_, --, --, --, 
   {{0xddd8025c,0xa3b0130b,0xfc3c01ed,0xe94401d3}},	//   _avvż, ट्ल_, atív_, _درپی, 
   {{0x38ac4a4a,0x7dd800fd,0x2bf8011a,0x00000000}},	//   lür_, _xäsä, רמון_, --, 
   {{0x7ae00de2,0xda049e51,0x362001d3,0x00000000}},	//   _àntu, रसित_, _اورہ, --, 
   {{0x38ac47af,0xade406ab,0x847402d3,0x68300030}},	//   nür_, गासन_, ከኣለን_, vädz, 
   {{0x38ac0086,0xa3dc3be5,0x24800124,0x00000000}},	//   iür_, _तोप_, ãime_, --, 
   {{0xb8e4003d,0xdcec0135,0x38ad0d98,0xa364210e}},	//   _ཉར_, _ffaċ, hür_, _اُمو, 
   {{0x38ac0fb9,0x7dd8089d,0x24800276,0x9f59acab}},	//   kür_, _räsä, ţime_, órá_, 
   {{0x8c45acac,0x6d580115,0x3fc80133,0x18900150}},	//   иеме, _ŝvab, ردیی_, _ﺟﻪﯞﻯ_, 
   {{0x38ac418f,0xef640801,0x84740023,0x4c3401c4}},	//   dür_, _съдо, ከኣሉን_, рэмт, 
   {{0x8a140798,0x452400fe,0xe3c40139,0x00000000}},	//   аќач, _বৰাক_, luıñ_, --, 
   {{0x38adacad,0xda641b45,0x7dd8005b,0x00000000}},	//   für_, صافي, _väsä, --, 
   {{0xc9540962,0x21f8003e,0x38ac03ee,0xfb700014}},	// [2e600] ртвы, _géhu_, gür_, _ژھٲگ, 
   {{0x60040d29,0xbcf8020c,0x8b945a41,0x7dd800a2}},	//   _kòma, rcét, _трич, _täsä, 
   {{0x0564d40d,0xdb1408c6,0x47581f39,0x00000000}},	//   авен, gezä, трая_, --, 
   {{0x75c80046,0x38ac29ef,0x21f8020c,0x66fc00de}},	//   ктің_, bür_, _yéhu_, _nākš, 
   {{0xb8c80183,0x3978011a,0x38ac06be,0x65643493}},	//   _কৈ_, _בטכנ, cür_, žiho, 
   {{0x69c5acae,0xdcec031c,0x00000000,0x00000000}},	//   leie, _sfaċ, --, --, 
   {{0xbcf87ca0,0x600402bd,0x2440067c,0xe8740345}},	//   ncér, _nòma, nòmi_, _ئۆڕگ, 
   {{0x69c40a40,0xc4c4221d,0x35a000ee,0xe7ac012c}},	//   neie, _پترو, _масг, _चाडप, 
   {{0x3eac011a,0x43080451,0x69c401c7,0x03a40d1d}},	//   _sqft_, _ڌيءَ_, ieie, _визо, 
   {{0x69c40a40,0x847402d3,0x3f64013e,0xf8b00375}},	//   heie, ከኣልን_, штиб, קשת_, 
   {{0xdcec025c,0x69c5acaf,0x9f34ef2a,0x833800d8}},	//   _tfaċ, keie, сені, _рчат_, 
   {{0x60040428,0x69c4002d,0x38ac0c3c,0xfd6096f0}},	//   _dòma, jeie, yür_, өнүү, 
   {{0xdfd5acb0,0x60040086,0x69c5acb1,0x8ca00034}},	//   _голы, _eòma, deie, कूलो, 
   {{0x60040699,0x69c40fac,0x00000000,0x00000000}},	//   _fòma, eeie, --, --, 
   {{0x69c401cf,0x5e940597,0x38ac0209,0x00000000}},	//   feie, _البط, wür_, --, 
   {{0x69c5acb2,0x38adacb3,0x959802d3,0xbc240c75}},	//   geie, tür_, ለታትን_, ارڭى, 
   {{0x28683e09,0xaa582ff5,0xb7640108,0x00000000}},	// [2e610] архо_, риту_, атей, --, 
   {{0x38ac4a4a,0x154400fb,0x6d3c011a,0x00000000}},	//   rür_, ҙелм, _בתחנ, --, 
   {{0x69c404c4,0xa3bc00af,0xd5746afe,0x38adacb4}},	//   beie, ेजन_, буль, sür_, 
   {{0xe6102468,0xfc3c0077,0x6ed400dc,0x69c401c7}},	//   وشن_, rtíu_, यितु, ceie, 
   {{0xfc3da6b8,0x478400c7,0x00000000,0x00000000}},	//   btít_, рыӡб, --, --, 
   {{0xd4f4052f,0xf8bc020c,0x66fc00de,0x00000000}},	//   ияһы, _ipé_, _sākš, --, 
   {{0x23481e87,0xe2a91147,0xf8bc0036,0xd2b801c6}},	//   ۇلۇپ_, لاين_, _hpé_, уулч_, 
   {{0x600401c3,0xa5f9acb5,0xaad82c2e,0x00000000}},	//   _ròma, _кесу_, डितक, --, 
   {{0xfc3dacb6,0x66fc00de,0xd1b80244,0xb4b001af}},	//   ntís_, _vākš, ناکا_, _физә, 
   {{0x69c5acb7,0xf8bc3d81,0x4fe8013e,0xbcf806af}},	//   zeie, _mpé_, умон_, ycér, 
   {{0x648401e4,0xdb1401e1,0x00000000,0x00000000}},	//   sϲit, _àbèn, --, --, 
   {{0x69c401c7,0xf8bc01e1,0x00000000,0x00000000}},	//   xeie, _opé_, --, --, 
   {{0x69c5acb8,0xf8bc01e1,0xb87808a5,0xa3dc21bd}},	//   veie, _npé_, _hríf, _तोड_, 
   {{0x69c5acb9,0x600408c2,0x09b000dc,0x24400561}},	//   weie, _tòma, ुज्य, tòmi_, 
   {{0x09e40a70,0x69c5acba,0xf8bc01e1,0xdbd40248}},	//   бовн, teie, _apé_, _gúís, 
   {{0xc3300d65,0x89645937,0x0d840075,0xbcf8f85a}},	//   פון_, скаж, _улин, rcér, 
   {{0x69c50d2d,0x39480204,0xbcf806af,0x00000000}},	// [2e620] reie, _czcs_, scér, --, 
   {{0x69c5acbb,0x317c51bf,0x00000000,0x00000000}},	//   seie, hbuz_, --, --, 
   {{0xb8ec0a28,0xf99c00f2,0xf8bc0248,0x69c404e6}},	//   _वै_, _ilèn_, _epé_, peie, 
   {{0x317c0399,0x848002d3,0x261c01e4,0xcb6802f2}},	//   jbuz_, _ይሰርሕ_, aŭon_, _جمگه_, 
   {{0xb8780241,0x04b411db,0x04441b88,0xd9b00131}},	//   _aríf, ссея, бедн, _تەقد, 
   {{0xaca4063f,0xbdd800f2,0xfc3c007b,0xb87802f0}},	//   _adịw, jlèn, ltír_, _bríf, 
   {{0x3ce800b5,0x00000000,0x00000000,0x00000000}},	//   zxcv_, --, --, --, 
   {{0xa0742e3f,0x320401c0,0xb87801a8,0xb6840014}},	//   огич, йхын_, _dríf, _چھۆل_, 
   {{0xc058cea6,0x60281171,0x00000000,0x00000000}},	//   ліо_, ихоҳ_, --, --, 
   {{0x7e78020c,0x2018180f,0x741000f2,0x00000000}},	//   tptp, òri_, _فوقا, --, 
   {{0x443dacbc,0x2bec0882,0xdc180034,0xb878004e}},	//   _ikt_, ञानं_, _głęb, _gríf, 
   {{0x443dacbd,0x918400db,0xdb1401e1,0x00000000}},	//   _hkt_, _ۇجۇم, _àbén, --, 
   {{0x5f9401fe,0x00000000,0x00000000,0x00000000}},	//   _дилт, --, --, --, 
   {{0x443dacbe,0x00000000,0x00000000,0x00000000}},	//   _jkt_, --, --, --, 
   {{0xfc3c09ff,0x443dacbf,0xb878022c,0xf8bdacc0}},	//   guía_, _mkt_, _kríg, _spé_, 
   {{0xdd90f061,0xf99c007f,0x200c014f,0xda0806c2}},	//   _کوک_, _elèn_, lhdi_, جيره_, 
   {{0x443dacc1,0x6004007f,0x1f240014,0x625c0055}},	// [2e630] _okt_, _jòmo, _دِژہ, _aũok, 
   {{0xb764e36d,0xfc3dacc2,0x600402e2,0xf6e40815}},	//   стай, buía_, _mòmo, йцен, 
   {{0xb879acc3,0xfc3dacc4,0x7bc5acc5,0x5ac80244}},	//   _oríg, stís_, meju, _ئاخێ_, 
   {{0x7bc43d99,0x9479acc6,0x317c0369,0x1dc807b6}},	//   leju, аску_, xbuz_, िजित, 
   {{0xf8bc0022,0xbdd80129,0x200c0009,0xd388030d}},	//   _upé_, ylèn, khdi_, айле_, 
   {{0x7bc44b53,0x63e405a9,0x88b8008f,0x443c0051}},	//   neju, كسىك, _דזשי, _ckt_, 
   {{0x443dacc7,0xb8780332,0x1dc8002b,0x00000000}},	//   _dkt_, _bríg, िजात, --, 
   {{0x3861acc8,0x1dd852f2,0x443dacc9,0x7bc5acca}},	//   _hijr_, _बोलत, _ekt_, heju, 
   {{0x7bc5accb,0x60040137,0x7e6803fa,0x443c0841}},	//   keju, _còmo, _aufp, _fkt_, 
   {{0xe4f80014,0x200c0978,0xb87803b2,0x7bc400c7}},	//   _دژمژ_, ghdi_, _tríf, jeju, 
   {{0xb8780579,0xbdd9accc,0x1dd40574,0x7bc400c0}},	//   _fríg, rlèn, धयंत, deju, 
   {{0xc690008d,0xb8780030,0x443c01f5,0xb63800b5}},	//   ואט_, _kríd, _zkt_, _ｇｏ_, 
   {{0xf99c0100,0xbdd9202b,0x65c002d2,0x00000000}},	//   _plèn_, plèn, _háhæ, --, 
   {{0x8c540f1b,0x200cd36a,0xbdd90dcf,0x7bc5accd}},	//   تئجا, chdi_, llèl, geju, 
   {{0xfc3c02d2,0x00000000,0x00000000,0x00000000}},	//   dríd_, --, --, --, 
   {{0x4a440006,0x00000000,0x00000000,0x00000000}},	//   інав, --, --, --, 
   {{0xfc3c0005,0x7bc4037e,0xbe3000cf,0x63bc01e3}},	// [2e640] muín_, beju, _تىيب, _örng, 
   {{0xfc3c068c,0x57680055,0x00000000,0x00000000}},	//   luín_, _kūṭā_, --, --, 
   {{0x86c426c0,0x6d440134,0xfc3c2b76,0xb7d400e3}},	//   تيان, _hyia, quía_, تولا_, 
   {{0x6d4403a2,0xb87801e7,0x200c036e,0x85040338}},	//   _kyia, _bríd, zhdi_, يوان, 
   {{0x443dacce,0xdb0400e4,0xf9800212,0x63b8005a}},	//   _pkt_, _ichá, _ігро, tfvn, 
   {{0x37a06788,0x600401ab,0x74100133,0xf1a400bc}},	//   _оқуғ, _còml, وونا, _गाउन, 
   {{0x443c1132,0xb8780022,0xf7400150,0x00000000}},	//   _vkt_, _eríd, _жеро, --, 
   {{0x443c008b,0x7bc5accf,0x6d440083,0xb879acd0}},	//   _wkt_, zeju, _oyia, _fríd, 
   {{0x6d440b89,0x27f9acd1,0x2901acd2,0x7bc400ec}},	//   _nyia, _korn_, nyia_, yeju, 
   {{0x27f81497,0x443c02d1,0xdfd10565,0x00000000}},	//   _jorn_, _ukt_, ريج_, --, 
   {{0x7411acd3,0x27f9acd4,0xb8780579,0x7bc5acd5}},	//   _تولا, _morn_, _tríg, veju, 
   {{0x200c006c,0xdb1c012c,0x99880311,0xfc3c25e6}},	//   shdi_, ázít, diaş_, guín_, 
   {{0x7bc4000d,0xdcec025c,0x00000000,0x00000000}},	//   teju, _mdaħ, --, --, 
   {{0xdb050053,0xc0441375,0x27f9acd6,0xade400bc}},	//   _achá, _بخصو, _norn_, गाउन_, 
   {{0x7bc5acd7,0x201cad0c,0xbdd80ffb,0x645800f1}},	//   reju, _imvi_, llèm, imvi, 
   {{0x7bc5acd8,0xdcec031c,0xee74007b,0x1874010b}},	//   seju, _ndaħ, _بصوت_, згая, 
   {{0xa3bd12e7,0x27f9acd9,0x2440068c,0x32e801e1}},	// [2e650] ेजा_, _born_, nòms_, _ḿbọ_, 
   {{0xdb040789,0xfc3c04d4,0x27f80e21,0x645801e4}},	//   _echá, fríe_, _corn_, jmvi, 
   {{0x27f9acda,0x201c4264,0xd5740148,0xe7ac0db3}},	//   _dorn_, _mmvi_, пуль, _चारप, 
   {{0xb879acdb,0x645800f1,0x00000000,0x00000000}},	//   _príd, emvi, --, --, 
   {{0x27f9acdc,0xdcec0135,0x628802d0,0xa3dc00e1}},	//   _forn_, _ddaħ, _awdo, _तोह_, 
   {{0x27f9acdd,0x63a40198,0xdb04013a,0x00000000}},	//   _gorn_, ɗink, _zchá, --, 
   {{0x66b5acde,0xa3bc05b3,0x2bec00cd,0x00000000}},	//   _обру, ेज़_, ञातं_, --, 
   {{0x33e800c6,0x27f90b91,0x62880076,0x6458cdc8}},	//   _яєαм_, _zorn_, _dwdo, amvi, 
   {{0x62880327,0xb87800d0,0x99880356,0x00000000}},	//   _ewdo, _hríb, ziaş_, --, 
   {{0x62880334,0x0ea8005b,0x00000000,0x00000000}},	//   _fwdo, бкой_, --, --, 
   {{0x6d4450f9,0x036801d9,0x00000000,0x00000000}},	//   _syia, _أمی_, --, --, 
   {{0xbdd9a62d,0xf99c0109,0x6a5c0618,0x28ac5d4f}},	//   blèm, _blèm_, _tōfi, टूडि, 
   {{0xc0dc0023,0xeb042d93,0x7124032f,0x00000000}},	//   ዕባል_, रन्त_, _برال, --, 
   {{0xdb040216,0x00000000,0x00000000,0x00000000}},	//   _schá, --, --, --, 
   {{0x63bc0365,0x09e400d6,0xa3b00b4e,0x00000000}},	//   _örne, повн, ट्ट_, --, 
   {{0xfc3c097a,0x0d851a47,0x27f8e048,0xbdd8007f}},	//   quín_, _элин, _sorn_, kmèy, 
   {{0x27f9acdf,0xb95801e1,0xdb040306,0x64580174}},	// [2e660] _porn_, _abìb, _vchá, ymvi, 
   {{0x4ab800a8,0xf8bc0129,0xa3bc00e1,0x2b9410e8}},	//   _лумя_, _axés_, ेड़ा_, _زیرس, 
   {{0x27f803fa,0x290005b1,0x7bf8011a,0xaae000bc}},	//   _vorn_, syia_, _הפיצ, _पछिक, 
   {{0xdb0425f7,0x27f82517,0x00000000,0x00000000}},	//   _uchá, _worn_, --, --, 
   {{0x04441318,0x27f8ffe4,0xa3d40354,0x9f580332}},	//   педн, _torn_, долч, órú_, 
   {{0x6459ace0,0xb87808ce,0x46140244,0x21c80150}},	//   umvi, _fríb, _کورر, _ﻓﻤﺘﺭ, 
   {{0x6459ace1,0x6234016c,0xf2c16aaa,0x07681188}},	//   rmvi, меку, есын, _ваҳй_, 
   {{0xa3dc00af,0x850401d3,0xe7ac05dc,0x00000000}},	//   _तोर_, _ٹوئن, _चाँप, --, 
   {{0xbdd8020c,0xb8780162,0x00000000,0x00000000}},	//   blèj, _tríe, --, --, 
   {{0x47c80154,0xe01800d4,0x00000000,0x00000000}},	//   রাকী, іжні_, --, --, 
   {{0x9e35ace2,0xde5800d4,0x00000000,0x00000000}},	//   денч, жані_, --, --, 
   {{0x6004033b,0xff28036b,0x63bc02d2,0x00000000}},	//   _kòmk, _қўли_, _örnb, --, 
   {{0xc05802dc,0x6ce402dd,0xb11400db,0x28e01fd2}},	//   _лік_, ніре, _ىقما_, निफि, 
   {{0x201c009a,0xd12400db,0x00000000,0x00000000}},	//   _umvi_, _تةمى, --, --, 
   {{0x89780521,0x00000000,0x00000000,0x00000000}},	//   _ọgụg, --, --, --, 
   {{0x3f8c02d2,0x6e44399f,0xdb140248,0x00000000}},	//   _hefu_, _пејз, _àbín, --, 
   {{0xd879ace3,0x69354483,0x3f8ceff0,0xfc3c0005}},	// [2e670] زمات_, енту, _kefu_, quío_, 
   {{0xb87801a2,0x3944005f,0xa3dc7f90,0x9bc401ec}},	//   _príb, āns_, _तोल_, _تۇسە_, 
   {{0x59f806bb,0xdb04005c,0xd7580a8e,0xb87800ae}},	//   _деня_, _schæ, آلات_, _bríc, 
   {{0x3f8c052f,0xb87800c6,0x00000000,0x00000000}},	//   _lefu_, _críc, --, --, 
   {{0x7bd478ea,0x798c02d0,0x89d8123b,0x00000000}},	//   _kaxu, _iecw, _וחרי, --, 
   {{0x3f8dace4,0x8880036b,0xbdd8560d,0xb88401fe}},	//   _nefu_, _شیمن, flèk, _муҳй, 
   {{0x7bd5ace5,0x00000000,0x00000000,0x00000000}},	//   _maxu, --, --, --, 
   {{0x7bd4d69a,0xf6500228,0x06b40051,0x00000000}},	//   _laxu, _سئز_, _ôđất_, --, 
   {{0x3f8c004c,0xf365650c,0xbdd8020c,0x24f80276}},	//   _befu_, _етен, alèk, _енты_, 
   {{0x3f8c009a,0x798d9cef,0xf99c007f,0x7bd4fd3d}},	//   _cefu_, _lecw, _blèk_, _naxu, 
   {{0x60c40029,0x3f8c00e8,0xe3b0007b,0xa3bc134e}},	//   _ģime, _defu_, _حرق_, ेजर_, 
   {{0x28e00a94,0x798c009a,0x00000000,0x00000000}},	//   निमि, _necw, --, --, 
   {{0x7bd52339,0x00000000,0x00000000,0x00000000}},	//   _baxu, --, --, --, 
   {{0x798c02d0,0x290c00e2,0x00000000,0x00000000}},	//   _aecw, _āda_, --, --, 
   {{0xbb40ebe9,0x9e64004b,0x798dace6,0x6b94031c}},	//   верк, _ګاون, _becw, _ġegħ, 
   {{0xc3309b62,0x00000000,0x00000000,0x00000000}},	//   דול_, --, --, --, 
   {{0x600401ab,0x3f8c014b,0x7bd40356,0x00000000}},	// [2e680] _bòmh, _yefu_, _faxu, --, 
   {{0x60040013,0x798c0472,0x7bd4005a,0x2c740139}},	//   _còmh, _eecw, _gaxu, _iäd_, 
   {{0xb87801f1,0xf99c04fb,0x60040192,0x3e3097d1}},	//   _príc, _olèh_, _dòmh, _سفیر, 
   {{0x600401ab,0xc604015b,0x1dc000cd,0xdb14010e}},	//   _eòmh, লোনা_, ष्पत, nezý, 
   {{0x7bd5ace7,0xa3bc0037,0x00000000,0x00000000}},	//   _yaxu, ेजल_, --, --, 
   {{0xfc3c0f71,0x77740393,0x2c740139,0x00000000}},	//   oría_, ccxx, _mäd_, --, 
   {{0x2bc0085c,0xb879ace8,0x3f8c0433,0x798d131a}},	//   श्या, _tríc, _refu_, _yecw, 
   {{0x3f8c0cf4,0xfc3c29d3,0x96c80014,0x60f802e8}},	//   _sefu_, iría_, _ڈبہِ_, зния_, 
   {{0x3f8c442c,0xb8781427,0x2c740254,0x5f941eec}},	//   _pefu_, _kría, _näd_, нипт, 
   {{0x6004007f,0xf9540375,0xbdd8020c,0xb4f8011a}},	//   _kòmi, וספת_, plèk, _ולמר, 
   {{0xf8a80950,0x7bd400e8,0x00000000,0x00000000}},	//   _चम्प, _raxu, --, --, 
   {{0xfc3c4e4c,0x600400cf,0x7bd5ace9,0xab6800ef}},	//   dría_, _mòmi, _saxu, _muļļ, 
   {{0x11682580,0x6299acea,0xfc3c0cc3,0x6004007f}},	//   _علوی_, lsvo, ería_, _lòmi, 
   {{0x798daceb,0xfc3c92c4,0x7bd4011f,0x62980010}},	//   _secw, fría_, _qaxu, osvo, 
   {{0xfc3c26ce,0x6004f62f,0x442c004e,0xda341f39}},	//   gría_, _nòmi, inf_, еевы, 
   {{0x7bd48531,0x6299acec,0xb87808a5,0x9df80107}},	//   _waxu, isvo, _aría, _хнит_, 
   {{0xdb0486d4,0xe894088b,0x7bd40694,0xbb2804a2}},	// [2e690] _schä, кать, _taxu, ﻣﺎﻥ_, 
   {{0xfc3c204e,0xb8786bdf,0x62980549,0xab680171}},	//   bría_, _cría, ksvo, _buļļ, 
   {{0x600400f7,0x798d9cef,0x199402d5,0xdb040112}},	//   _còmi, _tecw, _паня, _abhö, 
   {{0x6298eab6,0x6004004e,0x2f580a1e,0x3e780055}},	//   dsvo, _dòmi, קדאנ, _gīte_, 
   {{0x1dc00a28,0xb8799396,0x9878008f,0x47c80154}},	//   ष्यत, _fría, _מאָט, রাজী, 
   {{0x600402bd,0x6299aced,0xdb1400e5,0x00000000}},	//   _fòmi, fsvo, kezü, --, 
   {{0xaad80316,0x22781fd6,0x00000000,0x00000000}},	//   डिएक, ولوگ_, --, --, 
   {{0xd1b81b06,0x1dc0194b,0x95980092,0x00000000}},	//   سابا_, ष्मत, ወታችን_, --, 
   {{0x1fd800fe,0x6594aec3,0x6299acee,0x00000000}},	//   তানস, _шату, asvo, --, 
   {{0x7649acef,0xe4540022,0x0ea8034b,0x6298590e}},	//   llgy, _акуы, пкой_, bsvo, 
   {{0x47c8015b,0xf99c02e2,0xdb140112,0x2c74007c}},	//   রাচী, _odè_, gezü, _säd_, 
   {{0xf99c026c,0x00000000,0x00000000,0x00000000}},	//   _ndè_, --, --, --, 
   {{0x8fa47e79,0x7d740133,0x00000000,0x00000000}},	//   _зале, ژمێر_, --, --, 
   {{0xfc3c09ff,0xdb140112,0xddcc012d,0x3e78002b}},	//   tría_, bezü, _chał, _sīte_, 
   {{0xca54026a,0xde8845d7,0x3e7800b8,0x8c44008e}},	//   етањ, _قضيه_, _pīte_, _җене, 
   {{0xfc3c09ff,0xab6800de,0xa3dc000d,0x998800a2}},	//   rría_, _ruļļ, _तोई_, nkaň_, 
   {{0x59740046,0x60040ba1,0x28e0043e,0xc210010f}},	// [2e6a0] тысу, _sòmi, निधि, אהן_, 
   {{0x1dc00882,0xf99c1ed9,0xa96800d1,0xe3b80205}},	//   ष्ठत, _edè_, зиға_, _amın_, 
   {{0x1cac003d,0x44f4034d,0x3e78002b,0x320c3b5a}},	//   _པའོ_, کساز, _tīte_, _olgy_, 
   {{0x600514d7,0xb87801e1,0x00000000,0x00000000}},	//   _vòmi, _irín, --, --, 
   {{0xc8b41e76,0xa4d43981,0xdb1404d4,0xb879acf0}},	//   _ясны, толі, bezó, _tría, 
   {{0x99880034,0x320c010e,0x7648062c,0xe3b80205}},	//   chał_, _algy_, algy, _emın_, 
   {{0x6abc01e0,0xd36c2928,0xae10033f,0x76480175}},	//   ntrf, زۇن_, ासान_, blgy, 
   {{0x629915e1,0xb6b806a9,0xe0d00014,0xf7400117}},	//   rsvo, _מצלי, لٲب_, _сесо, 
   {{0x6298f985,0x44a402e9,0x1cac031c,0x442d178c}},	//   ssvo, _سماق, _པའེ_, pnf_, 
   {{0x62980b4f,0xb030005b,0xb9580cad,0x4ab00037}},	//   psvo, лныш, _obìn, ुझाव, 
   {{0xb37876e2,0x9f341ac3,0xd2f40451,0x00000000}},	//   ዮጵያን_, тені, _لکيا_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb879acf1,0xf8cc5a30,0xc1d000c7,0x9f5c0200}},	//   _arín, _सैंय, _аҩқә, _kovë_, 
   {{0xed8800c7,0x7b65acf2,0xc05801af,0x00000000}},	//   _ҧсык_, етбе, _эрец_, --, 
   {{0xfc3c0005,0x63a40198,0x6d4005d5,0x19940024}},	//   brín_, ɗint, ümar, кавя, 
   {{0xfc3c0077,0xbd6800db,0x00000000,0x00000000}},	//   crín_, _эрке_, --, --, 
   {{0x9c380801,0x41c0228a,0xb87801e1,0x41ac00bc}},	// [2e6b0] _опит_, व्यस, _erín, _टाईस, 
   {{0xc02c0016,0x00000000,0x00000000,0x00000000}},	//   _điệu_, --, --, --, 
   {{0xb9580248,0xb879acf3,0xda34008e,0x7c240200}},	//   _gbìn, _grín, _аены, mijr, 
   {{0x4a980a7c,0xdb141155,0x00000000,0x00000000}},	//   _קירג, sezó, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2904000d,0x52a800d4,0x00000000,0x00000000}},	//   _ümar_, євим_, --, --, 
   {{0xf99c0d29,0x7c25acf4,0x998801e4,0x47c803d4}},	//   _elèv_, hijr, knaŭ_, ৰাণী, 
   {{0xf99c0100,0x0ee802ab,0xbdd8067c,0x33840108}},	//   _flèv_, टम्स_, nlèu, _зуев, 
   {{0xfc3c04d4,0xa4d801c6,0xe3b02824,0x2d9c00b8}},	//   drío_, _ядуу_, _هرم_, _śve_, 
   {{0xfc3c01a8,0x1cac0327,0xdcfc00e2,0xb8780ca8}},	//   trín_, _པའུ_, kasē, _orío, 
   {{0xfc3c04d4,0x9f5c0100,0xc32c0133,0x80d00137}},	//   frío_, _movè_, _بڕه_, _چۅيچ, 
   {{0xfc3c29d3,0x30a4d646,0xa1840354,0x64580210}},	//   rrín_, _чрев, _сыхл, łcił, 
   {{0xb879acf5,0xddcc00b8,0x63a402a8,0x4fa400d8}},	//   _arío, _ahań, ɗins, _рикв, 
   {{0x9f5c00db,0xb878007b,0x216405a2,0xdcfc00ef}},	//   _novè_, _brío, _итәг, fasē, 
   {{0xb8780597,0xddcc030a,0x24800356,0x8e3802c9}},	//   _crío, _chań, ţimi_, _تستر_, 
   {{0xcc3400c7,0x87b8023a,0x6e4401d9,0xb87801e7}},	// [2e6c0] _ахны, дует_, _لۆگم, _drío, 
   {{0xb879acf6,0x6b6801d3,0x00000000,0x00000000}},	//   _trín, _cégü, --, --, 
   {{0xb8799279,0x28e00303,0x00000000,0x00000000}},	//   _frío, निहि, --, --, 
   {{0xf74170fa,0xbdd80ba1,0xb8798a78,0xa5940133}},	//   шехо, blèu, _grío, اداچ, 
   {{0x3e7800b0,0xbdd80ba1,0x2a600254,0xf4d000ae}},	//   _mīta_, clèu, mmib_, لتوظ, 
   {{0x07a405f5,0x2a6000c5,0xe4542347,0xd48400e5}},	//   _шагн, lmib_, ыклы, اؤنٹ, 
   {{0x6e24043b,0xa5c45aba,0x28e000cd,0x45d40902}},	//   _omib, _бөле, निवि, _ицат, 
   {{0x26d8003e,0xc4c4007b,0xbb380375,0xb878110e}},	//   _isro_, _لتطو, ועצי, _oríl, 
   {{0xdfd006d5,0x7c24022e,0x00000000,0x00000000}},	//   مية_, yijr, --, --, 
   {{0x66000115,0xbdd8004a,0x6e25acf7,0x73e000d8}},	//   _homk, hlèt, _amib, _коуз, 
   {{0x6601acf8,0xb95801e1,0x644800da,0xfc3c37b5}},	//   _komk, _abìl, _ikdi, ptíz_, 
   {{0x9f5c004e,0x6004004e,0xa3bc9418,0x7a300327}},	//   _jové_, _ròmu, ेजक_, għtl, 
   {{0x66002ce2,0xf1b00302,0xc0cc02d3,0x00000000}},	//   _momk, _כסף_, ባቶም_, --, 
   {{0x9f59acf9,0x66001ae8,0x5f95acfa,0x6004068c}},	//   óró_, _lomk, _сикт, _còmt, 
   {{0xb8780491,0x6600009a,0xbdd84056,0x7c2401f5}},	//   _prío, _oomk, flèt, rijr, 
   {{0x9f5c0745,0x66001717,0xb8781d0e,0x3e78002b}},	//   _nové_, _nomk, _fríl, _gīta_, 
   {{0x1cac2b65,0x9955acfb,0xc0dc1772,0x9f5c033b}},	// [2e6d0] _པའི_, укац, ንባሩ_, _sovè_, 
   {{0xf99c02e2,0xd7940691,0xa8144f9b,0xfc3c011f}},	//   _alèt_, الاخ, адуш, ytíy_, 
   {{0x6600209c,0x2a600218,0xd1dc02d3,0x9f5c030a}},	//   _bomk, bmib_, ንሳብ_, _bové_, 
   {{0xe3b80259,0x2b000316,0x6004033b,0x60c400e2}},	//   _acı_, रहरु_, _kòms, _ģimn, 
   {{0x2bc00b26,0x6601acfc,0xbdd800db,0xb878089f}},	//   श्वा, _domk, llès, _krím, 
   {{0x98a40124,0xe45464c2,0x99880165,0xfc3c0174}},	//   _ииҭе, акчы, shań_, krím_, 
   {{0x8cd80210,0x00000000,0x00000000,0x00000000}},	//   _पैनो, --, --, --, 
   {{0xf99cdcc5,0x6449acfd,0x00000000,0x00000000}},	//   _doèg_, _ekdi, --, --, 
   {{0x76580223,0xa37c01e4,0x3e78005f,0xfc3c056a}},	//   _ihuy, _anĵu, _rīta_, luíu_, 
   {{0x66002798,0xa8080139,0xbf0c473c,0x23b410e0}},	//   _zomk, _irıñ, ानून_, _ەمەس, 
   {{0x7659acfe,0x66001449,0xfc3dacff,0x80b00154}},	//   _khuy, _yomk, nuíu_, ড়িগ্, 
   {{0xb87801a2,0xc278010f,0x00000000,0x00000000}},	//   _príl, _טרעי, --, --, 
   {{0x10a40697,0xfb0400e8,0x3e7800b8,0x8fd001ee}},	//   _силн, _ŋëpp_, _vīta_, _ләнә, 
   {{0xb879ad00,0x76580042,0xfc3c0332,0x6f84010a}},	//   _crím, _lhuy, brím_, _рудж, 
   {{0x2fc40280,0xbdd800cf,0xafe000fb,0xca5800d8}},	//   _ibng_, glès, _боҙл, ејач_, 
   {{0x2fc40280,0x6e2422d0,0xb95801e1,0x765801fb}},	//   _hbng_, _umib, _ibìj, _nhuy, 
   {{0x6601ad01,0xf99dad02,0xb8780ad9,0x2a600254}},	// [2e6e0] _romk, _alès_, _frím, rmib_, 
   {{0x7659ad03,0x2ca0011c,0x66002798,0xb878066a}},	//   _ahuy, _ivid_, _somk, _grím, 
   {{0x2ca004ce,0xfc3c0005,0x765800b8,0xe6b401b9}},	//   _hvid_, guíu_, _bhuy, شلشگ, 
   {{0x7659ad04,0x2bc041ac,0x7e7c00dd,0xbdd87ea5}},	//   _chuy, श्रा, _éppe, llèr, 
   {{0x69c401a4,0x76580009,0xdb0412ed,0x00000000}},	//   mfie, _dhuy, _schø, --, 
   {{0x68e53da7,0x66002798,0xfc3c056a,0xf48401d5}},	//   mvid, _womk, buíu_, اانی, 
   {{0x68e5ad05,0x6601ad06,0x2d800134,0x02681808}},	//   lvid, _tomk, _ofie_, нший_, 
   {{0x2fc4089c,0x2ca06a89,0x68e400af,0x07a408ca}},	//   _abng_, _ovid_, ovid, _шаҳн, 
   {{0x68e5ad07,0xb87801e1,0xf200011c,0x00000000}},	//   nvid, _aríj, сящо, --, 
   {{0x2d800134,0x69c5ad08,0x30110cd6,0x68e41a75}},	//   _afie_, hfie, йдыр, ivid, 
   {{0x1cac003d,0x68e47578,0x69c41691,0xbf0c00dc}},	//   _པའང_, hvid, kfie, ानेन_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69c5ad09,0x359402d3,0xb879ad0a,0x68e415ad}},	//   dfie, ቅስቃስ_, _prím, jvid, 
   {{0x68e5ad0b,0x2d800134,0x69c5ad0c,0x2fc4003e}},	//   dvid, _efie_, efie, _gbng_, 
   {{0x2ca00489,0x68e5ad0d,0x35800023,0x00000000}},	//   _evid_, evid, _ይጠቅስ_, --, 
   {{0x5c74f631,0x69c41691,0x1958013d,0x6aa800ae}},	//   _клит, gfie, вабы_, ádfa, 
   {{0x37a9ad0e,0x68e5ad0f,0x2ca00115,0xb9580241}},	// [2e6f0] етен_, gvid, _gvid_, _ibìk, 
   {{0xf99c067c,0x7659ad10,0x69c405d5,0xfc3c056a}},	//   _clèr_, _shuy, afie, tuíu_, 
   {{0xd6d021ef,0x765802d1,0x68e5ad11,0xb87800d0}},	//   تقا_, _phuy, avid, _krík, 
   {{0xe6880075,0x76583d07,0x68e401f5,0x3e7801c7}},	//   اننى_, _qhuy, bvid, _mët_, 
   {{0x76581aa1,0xe57802bf,0x2ca1ad12,0x059403e6}},	//   _vhuy, узі_, _xvid_, شانگ, 
   {{0x3e7800b8,0x00000000,0x00000000,0x00000000}},	//   _nīto_, --, --, --, 
   {{0x3e78092e,0x76580016,0xfc3c067c,0xb8780cad}},	//   _nët_, _thuy, luís_, _orík, 
   {{0x76583c72,0xa490035c,0xfc3cdd18,0x00000000}},	//   _uhuy, _کیوت, frík_, --, 
   {{0xdcfc0153,0x00000000,0x00000000,0x00000000}},	//   masė, --, --, --, 
   {{0xb87801a2,0x3e780694,0x20c800db,0x8fa40261}},	//   _príj, _bët_, ابيي_, јане, 
   {{0x68e40e8a,0x99886b48,0xb8780174,0xe2c831f6}},	//   zvid, znaš_, _brík, _مولو_, 
   {{0x68e40334,0x3e780036,0xfc3c00d0,0x8d640229}},	//   yvid, _dët_, brík_, ивне, 
   {{0x68e420ef,0x2ca0003a,0xdcec00e2,0x00000000}},	//   xvid, _qvid_, _reaģ, --, 
   {{0x68e5ad13,0x69c43b4d,0xfc3c642b,0x99880010}},	//   vvid, wfie, duís_, vnaš_, 
   {{0x69c5ad14,0x3e79ad15,0x4995ad16,0xca742cc8}},	//   tfie, _gët_, ишат, ругы, 
   {{0x317dad17,0xb95801e1,0xd14c02d3,0xbb4017a0}},	//   ncuz_, _gbìk, _ምስትው, цеск, 
   {{0x69c5ad18,0x2ca00b91,0xcdc4aede,0xfc3c068c}},	// [2e700] rfie, _uvid_, _баққ, guís_, 
   {{0x07a5ad19,0xc7a511d8,0x00000000,0x00000000}},	//   ражн, рижк, --, --, 
   {{0x6b9dad1a,0x69c52d78,0x3e781574,0x23ac01e1}},	//   marg, pfie, _xët_, _lójà_, 
   {{0x09e40166,0xfc3c068c,0x6b9dad1b,0x9974010b}},	//   _томн, buís_, larg, _гурш, 
   {{0x48240240,0x00000000,0x00000000,0x00000000}},	//   _ተጨውዮ, --, --, --, 
   {{0x02a5ad1c,0xfc3c056a,0xaee000b8,0x00000000}},	//   арим, luír_, _goṇi, --, 
   {{0x28ac1d8a,0xb6a000db,0x00000000,0x00000000}},	//   _चिडि, _мирл, --, --, 
   {{0xc4848a6f,0xfc3dad1d,0x41e40212,0x7a300327}},	//   _влак, nuír_, ріка, għth, 
   {{0x6b9dad1e,0x3e79ad1f,0xbf0c00dc,0xc058187f}},	//   karg, _sët_, ान्न_, кіо_, 
   {{0x6005ad20,0x80040276,0x3e780200,0x4428d026}},	//   _còmp, рчие, _pët_, _öb_, 
   {{0xb87801f1,0x88cc00fe,0xfd5001e1,0x00000000}},	//   _prík, ৰমিক, bufọ, --, 
   {{0xb8780d12,0x6b9c0042,0x00000000,0x00000000}},	//   _fríh, earg, --, --, 
   {{0x6b9c1dda,0xdd940184,0x6d5801e4,0x99880118}},	//   farg, _һайы, _ŝvar, chař_, 
   {{0x6b9dad21,0xf99c067c,0xab940212,0x63b8833a}},	//   garg, _alèp_, жирі, ngvn, 
   {{0xdd95ad22,0x9f5c0418,0xb8780162,0xdb040200}},	//   _лайы, _koví_, _trík, _idhë, 
   {{0xfc3c068c,0x6e4400f1,0x00000000,0x00000000}},	//   tuís_, _ونوم, --, --, 
   {{0x6b9dad23,0x394c005c,0x7a300135,0x00000000}},	// [2e710] barg, ægs_, nħti, --, 
   {{0x6b9dad24,0xf6e5ad25,0xdd91ad26,0x317c0007}},	//   carg, ицен, _بوک_, zcuz_, 
   {{0xfc3c172e,0xaee80327,0x00000000,0x00000000}},	//   buír_, རའགོ, --, --, 
   {{0x95c445d7,0x9f5c02fb,0xfa3402dd,0x59f80108}},	//   صيته, _noví_, _түбі_, _семя_, 
   {{0xfc3c57ae,0xb8780ca8,0x00000000,0x00000000}},	//   quís_, _oríi, --, --, 
   {{0xb8780077,0xd7c80133,0x92580214,0xe3b852c4}},	//   _asíg, _حوسه_, گشتر_, ибі_, 
   {{0x6004026c,0x9f5c00db,0x2d840428,0x00000000}},	//   _ròmp, _boví_, ñmek_, --, 
   {{0x6b9dad27,0xfba41a3e,0xb8780030,0x00000000}},	//   zarg, कृतम, _príh, --, 
   {{0x7a30003d,0xd1740184,0xdb0405d5,0x6b9dad28}},	//   għti, _һылы, _achü, yarg, 
   {{0x53340108,0x00000000,0x00000000,0x00000000}},	//   _лезт, --, --, --, 
   {{0x6b9dad29,0xdcec0327,0x836000db,0xd17400fb}},	//   varg, _reaġ, _ىگىل, _лылы, 
   {{0x6b9dad2a,0xdb0400f2,0x317c0007,0xf8c402e5}},	//   warg, _idhè, qcuz_, रझाय, 
   {{0x8fa404fb,0xb87809e8,0xdb0400ae,0xe0d0009a}},	//   _همشه, _fríi, _ochó, _يزه_, 
   {{0x1c38023a,0xddcc00b8,0xd1dc0092,0x00000000}},	//   аясь_, _khaś, ንዳች_, --, 
   {{0x6b9dad2b,0xfc3c1709,0xdb040118,0x00000000}},	//   rarg, tuír_, _tchý, --, 
   {{0xb8780216,0xdb0402f0,0x4d140395,0x7bc1ad2c}},	//   _osíd, _uchý, _гьот, _önun, 
   {{0xfc3c056a,0xbb281884,0x00000000,0x00000000}},	// [2e720] ruír_, ﻣﺎﻕ_, --, --, 
   {{0x3cf806a9,0x6b9c036b,0xfc3c056a,0xed5804a9}},	//   _עלינ, qarg, suír_, _йоқ_, 
   {{0xdb040214,0x63bc032e,0x00000000,0x00000000}},	//   _ndhè, _örni, --, --, 
   {{0x056556f3,0xd5b81ac3,0x36640454,0x00000000}},	//   бвен, исі_, бахо_, --, 
   {{0xe37401c0,0xddcc0055,0xe6880b38,0xdb0406af}},	//   оллы, _ahaś, انچى_, _adhè, 
   {{0xb9580241,0xb8780241,0x9f5c004e,0x00000000}},	//   _abìw, _aríw, _soví_, --, 
   {{0xddcc00b8,0x8cd8033f,0x630401d5,0x9f5c01ef}},	//   _chaś, _पैसो, توغل, _poví_, 
   {{0x9f5c0589,0xa3e4000d,0x80a4000d,0x00000000}},	//   _lovã_, _फफक_, _खिआइ, --, 
   {{0xdb05ad2d,0x2638dc02,0xcfe00154,0xeaa000cd}},	//   _schü, nčom_, বানন, _yeṣu_, 
   {{0x9f5c0c67,0xa2081d89,0x210000b0,0xf50400a8}},	//   _novã_, ılış_, _rōiā_, _унул_, 
   {{0x41e40064,0x00000000,0x00000000,0x00000000}},	//   _гіла, --, --, --, 
   {{0x63a8020b,0xdb0401ab,0xefd80092,0x00000000}},	//   _hddn, _ochò, ንጓዴ_, --, 
   {{0xdb04020c,0x00000000,0x00000000,0x00000000}},	//   _idhé, --, --, --, 
   {{0x442dad2e,0xdb04044e,0xfd1c011c,0xdcfc0f40}},	//   nif_, _udhë, rzì_, lasī, 
   {{0x3f9dad2f,0x998800d0,0x00000000,0x00000000}},	//   matu_, hnať_, --, --, 
   {{0x3f9dad30,0x442dad31,0x9f5800c7,0x00000000}},	//   latu_, hif_, órõ_, --, 
   {{0xa3e800dc,0x63a9ad32,0xb8641e24,0x00000000}},	// [2e730] यया_, _oddn, مائو, --, 
   {{0x3f9dad33,0x998801f1,0x628802d0,0x178800c7}},	//   natu_, dnať_, _otdo, рраҿ_, 
   {{0x7ac44712,0x3f9c009d,0x7d0c00e5,0x00000000}},	//   _успе, iatu_, lycs, --, 
   {{0x3f9dad34,0x63a9ad35,0xdb0400f2,0x442c01ab}},	//   hatu_, _addn, _ndhé, eif_, 
   {{0x3f9dad36,0x78911b04,0x442ce1d3,0x9f5c04cc}},	//   katu_, _ریاض, fif_, _lovà_, 
   {{0x3f9dad37,0x56957104,0xdb0420ef,0x442c63ad}},	//   jatu_, _магт, _adhé, gif_, 
   {{0x3f9dad38,0x73e00372,0x1da80073,0xe4501c43}},	//   datu_, _ۉيرۅ, कणात, رضه_, 
   {{0xb87806ea,0x00000000,0x00000000,0x00000000}},	//   _drív, --, --, --, 
   {{0x3f9dad39,0xc880054e,0xb87802f0,0x764801d3}},	//   fatu_, _guşă_, _usíd, mogy, 
   {{0x442dad3a,0x7649ad3b,0x799c014f,0xb8782507}},	//   cif_, logy, haqw, _frív, 
   {{0xc7b00375,0x799c009a,0x00000000,0x00000000}},	//   ובי_, kaqw, --, --, 
   {{0x8ff8150e,0x80b001f9,0x00000000,0x00000000}},	//   ارکر_, _आमचे, --, --, 
   {{0x3f9dad3c,0x3594044e,0x1f34044e,0x41c002ab}},	//   batu_, ቅስቓስ_, _ብዘይም, _वॉटस, 
   {{0x3f9c0c95,0x1c4400c7,0x8f680b01,0x7649ad3d}},	//   catu_, зҟьо_, _калб_, hogy, 
   {{0xcb69ad3e,0x99880030,0x764963c4,0x8cd8033f}},	//   раве_, znať_, kogy, _पैरो, 
   {{0x442dad3f,0x3a2801ab,0x799dad40,0xdcec013d}},	//   zif_, _cmcp_, gaqw, _ufağ, 
   {{0x442dad41,0x6da401ec,0x00000000,0x00000000}},	// [2e740] yif_, _диқа, --, --, 
   {{0x998801a2,0x3b802c68,0x263800d0,0x9f5c01d3}},	//   vnať_, _ольг, rčom_, _hová_, 
   {{0x7649ad42,0x799c009a,0x4e1c00c5,0x00000000}},	//   fogy, baqw, _पताई_, --, 
   {{0x3f9dad43,0x848002d3,0x442c05b1,0x2ce8025c}},	//   zatu_, _ክሰርሕ_, wif_, _སློབ, 
   {{0x628804ce,0x6b6001e1,0xbb280014,0x7a300003}},	//   _stdo, _fágí, _متێے_, għtu, 
   {{0xb87801f1,0x6a780115,0x6288010a,0x3f9d284a}},	//   _prív, _eŭfe, _ptdo, xatu_, 
   {{0x3f9cf996,0x7649289e,0x263800d7,0x00000000}},	//   vatu_, bogy, nčok_, --, 
   {{0x9f5c278a,0x3f9dad44,0xffe0000d,0x00000000}},	//   _nová_, watu_, _कोड़ऽ_, --, 
   {{0xb8781d0e,0x75d0027d,0x442cd033,0xdb20005b}},	//   _fríu, _زيلا, pif_, _ötök, 
   {{0x2019ad45,0x2ce8038f,0xb878022c,0x442dad46}},	//   óri_, _སླེབ, _trív, qif_, 
   {{0x3f9dad47,0x799cd0dd,0xb778010f,0x628803ac}},	//   ratu_, yaqw, יאיש, _utdo, 
   {{0x3f9dad48,0xb87808a5,0x733000d1,0x00000000}},	//   satu_, _krít, _تىما, --, 
   {{0x3f9dad49,0x3e78ff26,0x263800d0,0x6ce44f32}},	//   patu_, _mīti_, ečok_, міре, 
   {{0x799c401f,0x3f9dad4a,0x00000000,0x00000000}},	//   waqw, qatu_, --, --, 
   {{0x799dad4b,0x443c0395,0x7649ad4c,0x3de0015b}},	//   taqw, _mjt_, yogy, যাবল, 
   {{0xb95801e1,0xb8780241,0x3e7800b8,0xeab0007b}},	//   _obìt, _orít, _nīti_, ضعف_, 
   {{0x7c6400aa,0x443c020b,0x799c02d1,0xdd140214}},	// [2e750] _واخل, _ojt_, raqw, _رودخ, 
   {{0xb8d0190e,0xddcd1f9b,0x799c3a76,0x76480142}},	//   _टि_, _miaŭ, saqw, wogy, 
   {{0xb878004e,0x799c0309,0x3a280208,0x70b408a3}},	//   _arít, paqw, _tmcp_, _आम्ल, 
   {{0x443c6591,0xb878565c,0x799c014b,0x94780006}},	//   _ajt_, _brít, qaqw, бску_, 
   {{0x443ca7cc,0x25a00008,0xfc3c0419,0xb87800d7}},	//   _bjt_, ðila_, brít_, _príu, 
   {{0x94244e0c,0x76480b6a,0x443c0356,0xb4b82bf1}},	//   ямле, sogy, _cjt_, _अमी_, 
   {{0xe3b0038b,0x443c0051,0x764800e4,0x35840023}},	//   ئره_, _djt_, pogy, _ዝጠፍኡ_, 
   {{0xb87809cc,0x3e780055,0x91802374,0x569401fe}},	//   _frít, _gīti_, رۇتۇ, _маҳт, 
   {{0xb8780241,0x682001e3,0x00000000,0x00000000}},	//   _irís, _dödf, --, --, 
   {{0x998800c8,0x4f243752,0xb87801a8,0xfc3c0332}},	//   diaŭ_, здоб, _hrís, irís_, 
   {{0x9f980321,0x8e840845,0xc7b0008f,0x1358007b}},	//   ráði_, ягне, עבט_, _الاخ_, 
   {{0x60e00724,0x28ac024a,0x00000000,0x00000000}},	//   äzmä, _चिलि, --, --, 
   {{0x8d540c98,0x9f5c003a,0xc2340a1e,0x908800db}},	//   яточ, _novæ_, _צאנז_, _انتك_, 
   {{0xe04800aa,0xfc3c5133,0x00000000,0x00000000}},	//   _وشوه_, drís_, --, --, 
   {{0xb8780cad,0x00000000,0x00000000,0x00000000}},	//   _orís, --, --, --, 
   {{0xfc3c068c,0x321c0208,0x00000000,0x00000000}},	//   frís_, nhuy_, --, --, 
   {{0x9e644732,0x394007d6,0xfc3dad4d,0x3e7979d2}},	// [2e760] _تاون, ентг, grís_, _rīti_, 
   {{0x6d45ad4e,0xb87801e7,0x3e78002b,0x00000000}},	//   _ixia, _arís, _sīti_, --, 
   {{0x321c0309,0xcb68006c,0xb8797f9e,0x3e7800cd}},	//   khuy_, _دمده_, _brís, _pīti_, 
   {{0xb879ad4f,0xf99c0100,0xfc3c068c,0xbf24030a}},	//   _prít, _joèl_, brís_, qṣūr, 
   {{0xd90c021a,0x443ca8cf,0x1dc01b61,0x6820007c}},	//   _پیل_, _pjt_, ष्टत, _nödg, 
   {{0x2bc0090a,0x443c004e,0x3e780383,0x60c401f4}},	//   श्चा, _qjt_, _wīti_, _äimi, 
   {{0xb879ad50,0x2900056a,0xf741ad51,0xf48401d3}},	//   _frís, lxia_, _зеро, _ہالی, 
   {{0xdd38002b,0xb879ad52,0xfde8012d,0xb4840228}},	//   _cāśr, _grís, _जोंस_, زدۇۇ, 
   {{0xdfd006d5,0x7640066d,0x443c0421,0x36641ee3}},	//   نية_, énye, _tjt_, _хато_, 
   {{0x2900004e,0x03a401b9,0x64a402dd,0x443c0200}},	//   ixia_, _хижо, _наға, _ujt_, 
   {{0x6d44dee2,0x9a9c0092,0x932400cf,0x00000000}},	//   _axia, ንቲንግ_, _ۉرۅن, --, 
   {{0xf278025f,0x321c03f0,0x682002d2,0x00000000}},	//   _הראש, chuy_, _hödd, --, 
   {{0x63bc01e6,0xfc3c2b76,0x7c700853,0x9f400166}},	//   _örns, esía_, нғич, _şiä_, 
   {{0xa37c00df,0xbea4010b,0xb879ad53,0xb95801e1}},	//   _maĵo, _еший, _nsía, _obìr, 
   {{0x6d4402b9,0x6820013d,0xafe000d8,0x00000000}},	//   _exia, _mödd, _чојл, --, 
   {{0x9f500784,0xb8780166,0x682001e3,0x6458002f}},	//   _ñañu_, _asía, _lödd, hlvi, 
   {{0xb9580241,0x28f807d8,0x2c640267,0xa3bc0037}},	// [2e770] _abìr, петь_, född_, अला_, 
   {{0xfc3d12a0,0x6820007c,0xb7643947,0x00000000}},	//   rrís_, _nödd, птей, --, 
   {{0xb8783351,0xf99c00f2,0x7ac5ad54,0x9988033f}},	//   _prís, _yoèl_, _эспе, tkań_, 
   {{0xfc3c1d0e,0x00000000,0x00000000,0x00000000}},	//   prís_, --, --, --, 
   {{0x1fb42baf,0x6d44030a,0x682002d2,0x47c803d4}},	//   জ্যস, _xxia, _bödd, ৰাজী, 
   {{0x7844152d,0xe3b803be,0x764001ed,0x68200267}},	//   _хэмж, _alıb_, ényb, _rödg, 
   {{0xf7715e5e,0xb9580248,0x321c004d,0xb87803b2}},	//   _ساس_, _gbìr, thuy_, _trís, 
   {{0xf99c033b,0x201dad55,0xb000002b,0x00000000}},	//   _alèz_, _alvi_, _voḍh, --, 
   {{0xf99c1ed9,0x6820049f,0x92bc0154,0x2c6401e3}},	//   _blèz_, _född, ইবে_, löde_, 
   {{0xdb040077,0x4de405f9,0xf99c0ca8,0x0ea8005b}},	//   _adhí, _जोड़े_, _leè_, окой_, 
   {{0xa29400d6,0x2c640086,0x47c803d4,0x931400f2}},	//   _захі, nöde_, ৰাচী, _تواش, 
   {{0x201dad56,0x29000072,0xf99c007f,0xc33000d9}},	//   _elvi_, yxia_, _elèz_, _בוב_, 
   {{0x8d7411a4,0x69bc00bc,0xbb440150,0x00000000}},	//   بادا, एलसी, _ﺘﻌﻨ_, --, 
   {{0xddcc084c,0x68200e78,0x1ea8004b,0x9044007b}},	//   _piaţ, _köde, _ځايي_, _تنته, 
   {{0x8ca8012d,0x89d83cc6,0x00000000,0x00000000}},	//   _झटको, يوسر_, --, --, 
   {{0xddcc00a8,0x6d440190,0xfc3c0998,0x290001c0}},	//   _viaţ, _txia, rsía_, txia_, 
   {{0x6458014b,0x6820007c,0x00000000,0x00000000}},	// [2e780] ylvi, _löde, --, --, 
   {{0xb87801a2,0x29001709,0x201c0381,0x6458003a}},	//   _prír, rxia_, _xlvi_, xlvi, 
   {{0xdb0409f0,0x68209632,0x6fcc081e,0xb6a00139}},	//   _schö, _nöde, त्यं, вихл, 
   {{0x6abdad57,0xdb140213,0x00000000,0x00000000}},	//   murf, _əbül, --, --, 
   {{0xfc3c00c6,0x8934007b,0x6820032e,0x1b300092}},	//   isín_, _آعجا, _pödd, _አስተካ, 
   {{0x6820b83f,0x9f9801a8,0x7d08002e,0x959401ec}},	//   _böde, _náðu_, _àgse, _үшті, 
   {{0x682001b8,0xdb080b21,0xa31800f5,0xfbd0011a}},	//   _cöde, _ûnôf, яжку_, דתו_, 
   {{0xdb2401ed,0x682001e6,0x6abc005a,0xb878032e}},	//   ésér, _döde, iurf, _kríp, 
   {{0x83c400a7,0x6abc9ccd,0x9f982507,0xa07415bf}},	//   _обаж, hurf, _báðu_, нгич, 
   {{0xb4600588,0x6820339a,0x6abc0008,0x00000000}},	//   _акул, _föde, kurf, --, 
   {{0x7411ad58,0x6821ad59,0xdfd01129,0x6148002e}},	//   _جولا, _göde, نيک_, fëlë, 
   {{0x6abdad5a,0xf99c007f,0x6148002e,0x00000000}},	//   durf, _poèm_, gëlë, --, 
   {{0xb8784714,0x9f9801a8,0x3e7800de,0x81380066}},	//   _asín, _fáðu_, _rītu_, _بساز_, 
   {{0x3e780093,0x6abc0368,0x9f9802d2,0x201dad5b}},	//   _sītu_, furf, _gáðu_, _ulvi_, 
   {{0xb4b84719,0x6abc08ce,0x00000000,0x00000000}},	//   _अम्_, gurf, --, --, 
   {{0x25a001a8,0x2d84002d,0x6820007c,0xfc3c0332}},	//   ðill_, űmer_, _nödb, csín_, 
   {{0xb87809a9,0x00000000,0x00000000,0x00000000}},	// [2e790] _críp, --, --, --, 
   {{0x7c64598b,0xbdd8067c,0x00000000,0x00000000}},	//   _تابل, coèr, --, --, 
   {{0x6e44121e,0xbdd835f5,0x56940108,0x00000000}},	//   _سنیم, flèx, хает, --, 
   {{0x9478026a,0xb8780252,0x38c000e2,0x68203b52}},	//   пску_, _fríp, tūrā_, _röde, 
   {{0x68200267,0x1cdc025c,0xb87801a8,0x00000000}},	//   _söde, _ཤགས_, _gríp, --, 
   {{0xeddc00bc,0x00000000,0x00000000,0x00000000}},	//   _बस्छ, --, --, --, 
   {{0x3e7800de,0x00000000,0x00000000,0x00000000}},	//   _mīts_, --, --, --, 
   {{0x6820014a,0x69c000fd,0x35f80214,0x666401a9}},	//   _vöde, _ömet, _برسد_, _аъуз, 
   {{0x6d483361,0x8fa40395,0x00000000,0x00000000}},	//   ğdak, напе, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69d029da,0xb8f80327,0x263800d7,0x00000000}},	//   ड्डी, _ྡད_, rčov_, --, 
   {{0x62340032,0x00000000,0x00000000,0x00000000}},	//   _иеху, --, --, --, 
   {{0x8d7400db,0x6abc002f,0x6ea8000d,0xb0440117}},	//   عاجا, wurf, _झिकु, _оҷиз_, 
   {{0x61480240,0xed500014,0xa4b800a2,0xa2b401f9}},	//   sëlë, ُھک_, _çöňň, ईंच्, 
   {{0xdbdc008c,0xbb400137,0xbf10030f,0x9ac40166}},	//   ráðu, герк, _مووب, кирҗ, 
   {{0xb8780038,0x088811dc,0xc33002e4,0xbdd80ba1}},	//   _príp, збай_, אול_, soèr, 
   {{0xba1400c6,0xdb040030,0xcdc402dd,0x68200267}},	// [2e7a0] ريكا_, _schô, _жаққ, _rödb, 
   {{0xe7380214,0xb8780332,0x00000000,0x00000000}},	//   وتاچ_, _tsín, --, --, 
   {{0x28ac1b76,0xb8780118,0x00000000,0x00000000}},	//   _चिकि, _usín, --, --, 
   {{0x25a006d5,0xb879ad5c,0x6fcc07b7,0x00000000}},	//   úil_, _tríp, त्तं, --, 
   {{0xb9780302,0x00000000,0x00000000,0x00000000}},	//   _מרכז, --, --, --, 
   {{0xbdd800db,0x29c800db,0x61940023,0x00000000}},	//   slèx, _этүү_, _ቀቢላዊ_, --, 
   {{0xbdd8067c,0x17c400c7,0x660401f4,0x00000000}},	//   nnèc, _шарҭ, öiks, --, 
   {{0x60f80801,0x7a3801f4,0x00000000,0x00000000}},	//   дния_, mätä, --, --, 
   {{0xc059ad5d,0x7a38adae,0xb9e40023,0x00000000}},	//   зін_, lätä, _ኪዱ_, --, 
   {{0x38b40174,0x00000000,0x00000000,0x00000000}},	//   _hørð_, --, --, --, 
   {{0xdb0402f0,0x3e781ebf,0x7a3801f4,0x00000000}},	//   _odhá, _rīts_, nätä, --, 
   {{0x26d80175,0x3e7800b8,0x38b406ea,0x00000000}},	//   _mpro_, _cūta_, _jørð_, --, 
   {{0xdb140008,0x3e7807d7,0x7a3801f4,0x00000000}},	//   _íbúa, _dūta_, hätä, --, 
   {{0x7a2000af,0x79e401ed,0xa0340137,0x9f9400c7}},	//   _mõte, کورہ_, _جىتت, _рыдә, 
   {{0x4ee40184,0x22ac012c,0xc0c000d1,0x26d80fac}},	//   _асыҡ, něk_, _рәқи, _npro_, 
   {{0x300000c7,0x3ebdad5e,0x5fa00131,0x7a380108}},	//   _азәг, mutt_, _ﺋﯘﭼﯘ, dätä, 
   {{0x26d8d920,0x3ebc4098,0x9f5c01a2,0x6a780115}},	// [2e7b0] _apro_, lutt_, _novú_, _eŭfo, 
   {{0x5b1400c7,0x3e7800ef,0xc91406be,0x00000000}},	//   _амот, _tīts_, nayә, --, 
   {{0xf3fc431d,0x3ebc31a2,0xb87800ae,0xfc3c01e7}},	//   _đã_, nutt_, _tsío, nsím_, 
   {{0x9f5c00d2,0x3a3c0784,0xc17c0153,0x22ac0118}},	//   _bovú_, _ñup_, šėjo_, děk_, 
   {{0x3ebdad5f,0xc91406be,0x00000000,0x00000000}},	//   hutt_, kayә, --, --, 
   {{0x7a38145e,0xf771ad60,0x3ebdad61,0x69c003e0}},	//   bätä, _ماز_, kutt_, _ömer, 
   {{0x3ebc712c,0x7e6c035a,0x00000000,0x00000000}},	//   jutt_, kmcp, --, --, 
   {{0x06640022,0xf650014b,0x00000000,0x00000000}},	//   _ахуҭ, _себӯ, --, --, 
   {{0xe1880451,0x00c4013d,0xfa0c0051,0x00000000}},	//   رئين_, влык_, _đậu_, --, 
   {{0x3e782ba4,0x3ebc0158,0x00000000,0x00000000}},	//   _rūta_, futt_, --, --, 
   {{0x3ebdad62,0x263801fa,0x60c40115,0x0e6433b0}},	//   gutt_, mčor_, _ĥime, ккон, 
   {{0x682119e5,0x23741f3c,0x3e7807d7,0x2c64007c}},	//   _möda, _صالح, _pūta_, döda_, 
   {{0x6820420d,0xaf500daf,0x8fd00304,0x00000000}},	//   _löda, _өндә, _кәнә, --, 
   {{0x320c55b4,0x3ebc0135,0x09b8012c,0xa2d8629c}},	//   _hogy_, butt_, इल्य, _महम्, 
   {{0xfaa000c7,0xfc00b3f0,0x00000000,0x00000000}},	//   иаро, шпро, --, --, 
   {{0x3e7800b0,0x320c0419,0x7a3801f4,0x99880432}},	//   _tūta_, _jogy_, vätä, njaň_, 
   {{0x991400d3,0xb879ad63,0xe3e800cc,0x2018007c}},	// [2e7c0] льфі, _tsíl, পাতব, örig_, 
   {{0xe3b80259,0x81e8015b,0x320c0306,0xa9680131}},	//   _alın_, মায_, _logy_, диға_, 
   {{0x682001b8,0x6fd00034,0xdb040393,0x2ca00165}},	//   _cöda, ब्यू, _adhæ, _hwid_, 
   {{0x6820049f,0x22ac0316,0x7a389226,0x26d8282c}},	//   _döda, věk_, rätä, _vpro_, 
   {{0x69c5ad64,0x7a38adae,0xe4d4aa36,0x00000000}},	//   mgie, sätä, اقتد, --, 
   {{0x682029ef,0x68e40086,0xe3b8008e,0x7a20000d}},	//   _föda, mwid, _elın_, _võte, 
   {{0x2d81ad65,0x68e4030d,0xb6a1abca,0x2020001f}},	//   _ogie_, lwid, _висл, _ስለማይ, 
   {{0x69c5ad66,0xd36c3baf,0x133801d3,0x6fcc00cd}},	//   ngie, سۇن_, عتوں_, त्सं, 
   {{0x68e5ad67,0xde2802d3,0x69c5ad68,0x2055ad69}},	//   nwid, ትኽእል, igie, лкия, 
   {{0xdfd0092f,0x69c40007,0x3ebc0626,0xc1d80150}},	//   حيد_, hgie, tutt_, _ﺃﺤﺩﺍ, 
   {{0x2485ad6a,0x2ca0b238,0x3f640724,0x81e802f5}},	//   _humm_, _awid_, ътиб, মাব_, 
   {{0x68e5ad6b,0x2ca0062c,0x2485ad6c,0xe92c0327}},	//   kwid, _bwid_, _kumm_, སློབ_, 
   {{0xdfd40efb,0x3ebdad6d,0x53c82e1e,0x69c40373}},	//   _болы, sutt_, _रामश, dgie, 
   {{0x61e104ff,0x60c1ad6e,0x3ebc03fa,0xdfd099db}},	//   leml, mumm, putt_, _طيب_, 
   {{0x60c1ad6f,0x2ca00156,0x3078008f,0x2014033f}},	//   lumm, _ewid_, _קאונ, ęcić_, 
   {{0x69c5ad70,0x61e1ad71,0x24840109,0x682001e3}},	//   ggie, neml, _oumm_, _röda, 
   {{0x248404c4,0xaa5800a8,0x68e5ad72,0xb864ba15}},	// [2e7d0] _numm_, титу_, gwid, نائو, 
   {{0x61e1ad73,0x7d0001e1,0x69c40393,0x69d00165}},	//   heml, _ẹrù, agie, _čiež, 
   {{0x60c1ad74,0x61e1ad75,0xcb980375,0x78bc0477}},	//   humm, keml, _אסתט, suqv, 
   {{0xe6102a1a,0x682029ef,0x61e009a8,0x28adad76}},	//   يشن_, _vöda, jeml, _चिचि, 
   {{0x25a5ad77,0x60c1ad78,0xa8a40cfc,0x24840076}},	//   _deml_, jumm, _врск, _cumm_, 
   {{0x60c1ad79,0x248403fa,0x00000000,0x00000000}},	//   dumm, _dumm_, --, --, 
   {{0x2484020b,0x09c802f5,0xe2a801f7,0x880000d1}},	//   _eumm_, _লোটা, ناين_, _دېلو, 
   {{0x60c1ad7a,0x11e43a61,0x61e001d3,0x4de0000d}},	//   fumm, ужим, geml, गड़ाई_, 
   {{0x60c1ad7b,0x2d800010,0xdb04005c,0x00000000}},	//   gumm, _rgie_, _udhæ, --, 
   {{0x69c40007,0x25a4009a,0x4fe904f4,0x4f08020f}},	//   zgie, _zeml_, хмон_, енон_, 
   {{0x61e0379d,0x931417a5,0x798c03ac,0xb28400c7}},	//   beml, _حواش, _ofcw, _рызк, 
   {{0x60c1ad7c,0xe1f09c17,0x69c40007,0x3e7800b8}},	//   bumm, _وسن_, xgie, _dūto_, 
   {{0x60c1ad7d,0x25a00008,0x69c407c5,0xb87801d3}},	//   cumm, ðili_, vgie, _csík, 
   {{0x81e8000e,0x6ef401f2,0x8fa40026,0x4fa4005b}},	//   মাণ_, _ụbo, _саке, _сикв, 
   {{0xb878043b,0x69c5ad7e,0x3e780171,0x00000000}},	//   _esík, tgie, _gūto_, --, 
   {{0x69c40029,0x2ca1ad7f,0x68e5ad80,0xc7240220}},	//   ugie, _twid_, twid, ңдай, 
   {{0x6e25ad81,0x9f5c02e2,0xc9640801,0xdb04002f}},	// [2e7e0] _ilib, _anvè_, увай, _adhä, 
   {{0x68e5ad82,0x2485ad83,0x6e240455,0x2c6401b8}},	//   rwid, _rumm_, _hlib, mödo_, 
   {{0x68e5ad84,0x61e1ad85,0xd2b4010a,0x00000000}},	//   swid, yeml, _цiиэ, --, 
   {{0x60c0c010,0x682001e3,0x00000000,0x00000000}},	//   yumm, _gödn, --, --, 
   {{0x60c00ba7,0x00000000,0x00000000,0x00000000}},	//   xumm, --, --, --, 
   {{0x6e240372,0x60c1ad86,0x2a61ad87,0x3f80016b}},	//   _llib, vumm, llib_, ɛkuw_, 
   {{0x61e1ad88,0x6e25ad89,0x60c1ad8a,0x25a4015d}},	//   teml, _olib, wumm, _teml_, 
   {{0x60c00a4d,0x28c81098,0x2485ad8b,0x00000000}},	//   tumm, िंपि, _tumm_, --, 
   {{0x61e02a57,0x60c0013c,0x3e78002b,0x00000000}},	//   reml, uumm, _sūto_, --, 
   {{0x60c1ad8c,0x61e1ad8d,0x6820014a,0xbdd80268}},	//   rumm, seml, _mödo, gnèn, 
   {{0x60c1ad8e,0x6e2401b8,0x2a60009a,0x00000000}},	//   summ, _blib, klib_, --, 
   {{0x60c1ad8f,0x6e240597,0x6298250a,0xb8780030}},	//   pumm, _clib, mpvo, _psík, 
   {{0x81e8015b,0x4094147e,0xa3e82c35,0x798c03ac}},	//   মাদ_, _срет, _बसा_, _rfcw, 
   {{0x6e25ad90,0x3e780618,0x62980d27,0x5f94586f}},	//   _elib, _tūto_, opvo, _тикт, 
   {{0x6e240072,0xdd9422bf,0x798c035a,0xcfe000fe}},	//   _flib, _кайы, _pfcw, বাখন, 
   {{0x6e25ad91,0x62980af9,0x6d400332,0x00000000}},	//   _glib, ipvo, úmac, --, 
   {{0xe3b98664,0x64480010,0x6abc00ae,0x00000000}},	// [2e7f0] _alım_, _ojdi, arrf, --, 
   {{0x2a61ad92,0x798c02d0,0xda000037,0xa96800ae}},	//   alib_, _wfcw, _लचकत_, امكم_, 
   {{0x2a601c04,0xb878dce6,0x68f8005f,0x19c400fd}},	//   blib_, _kríz, āvda, _вәзг, 
   {{0xb8c80729,0xeef406a9,0x64482a6d,0x7bc409f3}},	//   _গম_, טמבר_, _ajdi, lgju, 
   {{0x62980ea0,0x01a800eb,0x00000000,0x00000000}},	//   epvo, ওলাদ, --, --, 
   {{0xe570038b,0x00000000,0x00000000,0x00000000}},	//   سطن_, --, --, --, 
   {{0x78680790,0x68200112,0x00000000,0x00000000}},	//   güve, _mödl, --, --, 
   {{0x5274104b,0x82800046,0xdb0400c7,0xd18401c6}},	//   шулу, іңіз, _pehê, шлий, 
   {{0x7659ad93,0xdb04d267,0x6298017a,0xd025ad94}},	//   _ikuy, _behë, apvo, имий, 
   {{0x6e25ad95,0x68200267,0x00000000,0x00000000}},	//   _slib, _nödl, --, --, 
   {{0x6e2400c8,0xb879ad96,0x238401d9,0xdb040200}},	//   _plib, _epíg, _أمِ, _dehë, 
   {{0xd1740372,0x6e24fff3,0x59d40d79,0x00000000}},	//   _кылы, _qlib, _डॉलर, --, 
   {{0x10a43500,0x20240086,0x7658009f,0xb2840022}},	//   _тилн, ûriô_, _mkuy, _рыҷк, 
   {{0x7bc41ffb,0x4fc023f6,0xdb0401c7,0x40909eb5}},	//   ggju, _بەدە, _gehë, _بلور, 
   {{0x76591019,0x682001e6,0x6b9c0194,0x6e240135}},	//   _okuy, _dödl, rbrg, _tlib, 
   {{0x7659ad97,0xba20d822,0x321c0309,0x00000000}},	//   _nkuy, одск, nkuy_, --, 
  
   {{0x479452c8,0x2a61ad98,0x0905ad99,0xf1d400cd}},	// [2e800] لجاس, rlib_, шпан, भ्यन, 
   {{0x765838f3,0x7a20007d,0xf99c067c,0x2c7c0241}},	//   _akuy, _võta, _boès_, _dádì_, 
   {{0x3bb80302,0xf99c007f,0x26dc00e4,0x00000000}},	//   _במיד, _poèt_, ïvo_, --, 
   {{0x9f5c0300,0x7a200254,0x80bc0011,0x2a60031c}},	//   _nový_, _tõta, ্বত্, qlib_, 
   {{0x92d40183,0xd9b00150,0x00000000,0x00000000}},	//   িটো_, _رەلد, --, --, 
   {{0x765863f0,0xc76416a0,0x7411ad9a,0xb8780241}},	//   _ekuy, _نازى, يونا, _oríy, 
   {{0xb878318e,0xb7d802e4,0x81e80154,0xe3b8013d}},	//   _asíw, _שקלי, মাস_, _ulım_, 
   {{0xb95801e1,0x321c003e,0x7869ad9b,0x7bc40200}},	//   _abìy, gkuy_, rüve, zgju, 
   {{0xdb0400e4,0xdfd4023a,0x8004188c,0x999800d0}},	//   _pehë, бопы, ачне, _ujsť_, 
   {{0x92d42f8b,0x321c0113,0x7e7c0455,0x833800db}},	//   িয়ে_, akuy_, _siqp, _ичет_, 
   {{0xb87801f1,0x7e7c03f0,0x68200267,0x65600142}},	//   _príz, _piqp, _rödl, _hymh, 
   {{0x63a8f44f,0x81e8009e,0xd1c842ed,0x04f800fe}},	//   _hedn, মাহ_, _مبهم_, ্নীৰ_, 
   {{0x628801f1,0x3e4c033f,0xd36c00cf,0xcfe000cc}},	//   _hudo, jęte_, _قۇۇ_, বাজন, 
   {{0x6289ad9c,0x19580588,0xb9580ca8,0x7118011a}},	//   _kudo, ҳабы_, _gbìy, _בודפ, 
   {{0x6289ad9d,0x63a80f92,0x3ac8013f,0x7bc52c2a}},	//   _judo, _medn, _kɔpɛ_, rgju, 
   {{0x63a9ad9e,0xddcc005f,0x19580cdd,0x49a401e0}},	//   _ledn, _skaņ, габы_, йыуғ, 
   {{0x6289ad9f,0x57b5ada0,0x68200e78,0x65600076}},	// [2e810] _ludo, йбат, _tödl, _nymh, 
   {{0x64599187,0x6289ada1,0x3f9c0327,0x195800fb}},	//   jovi, _oudo, nbtu_, _ҡаны_, 
   {{0xcfe011ba,0x321c1bb7,0x6288b1a3,0x20d001ab}},	//   বাচন, ykuy_, _nudo, hài_, 
   {{0xdb0400dd,0x63a80037,0xb8780332,0x84800023}},	//   _nehé, _aedn, _spíd, _ንሰምዕ_, 
   {{0x6459ada2,0x656000a9,0x00000000,0x00000000}},	//   fovi, _cymh, --, --, 
   {{0x6289ada3,0xb4e409fd,0xbdd835f5,0x6560015d}},	//   _budo, _बनी_, lièd, _dymh, 
   {{0x63a80219,0x6288d8f7,0x00000000,0x00000000}},	//   _dedn, _cudo, --, --, 
   {{0x76588cdb,0x6289ada4,0xa2d84433,0x63a80c8c}},	//   _ukuy, _dudo, _महर्, _eedn, 
   {{0x64581050,0x656000a9,0x2570004a,0x961c0139}},	//   bovi, _gymh, rôlé_, _ciņe, 
   {{0x6459ada5,0x6288019b,0x63a801ab,0x0bd401ec}},	//   covi, _fudo, _gedn, _ﺘﻤﺎﻫ, 
   {{0x6289ada6,0xdb0400dd,0x98a800d0,0xb4e40406}},	//   _gudo, _fehé, dzač_, _बनु_, 
   {{0xdb0404c4,0xb8780077,0x321c0113,0x63a80118}},	//   _gehé, _eríx, qkuy_, _zedn, 
   {{0x3f9c0135,0x00000000,0x00000000,0x00000000}},	//   bbtu_, --, --, --, 
   {{0x6289046f,0xab540092,0x00000000,0x00000000}},	//   _yudo, _መቆየቱ, --, --, 
   {{0x4e95ada7,0x81e803f4,0x6288036b,0x0eb8d8d1}},	//   _اشتر, মার_, _xudo, _сулы_, 
   {{0xbb4080df,0x8f0800c7,0x6fd02802,0x00000000}},	//   ческ, _ахҩа_, ब्रू, --, 
   {{0xa3e8007d,0x00000000,0x00000000,0x00000000}},	// [2e820] _बसल_, --, --, --, 
   {{0x07a4d20e,0x6458023d,0xa2d81a04,0x26381bce}},	//   сажн, xovi, _महल्, rōom_, 
   {{0x63a9ada8,0x645805a1,0x3e68026c,0x4038010f}},	//   _redn, vovi, lùta_, נגעג, 
   {{0x63a9ada9,0x45291d5b,0x7d1801c7,0x645802e2}},	//   _sedn, лжен_, äusg, wovi, 
   {{0x7a20007d,0xbb38001f,0xdb0426b6,0xb878032e}},	//   _mõtl, _አስተላ, _rehé, _asíu, 
   {{0x6289adaa,0x02a53b72,0xbdd80129,0x00000000}},	//   _pudo, брим, pièg, --, 
   {{0x8bf003f4,0x63a80f72,0x645858bb,0x6289adab}},	//   ঞাপন_, _vedn, rovi, _qudo, 
   {{0x80bc0f22,0x63a9adac,0x20d131c7,0x656003cb}},	//   ্বস্, _wedn, tài_, _tymh, 
   {{0x64580bb8,0x63a80fb7,0x81e82aab,0x6288014b}},	//   povi, _tedn, মাল_, _wudo, 
   {{0x6289adad,0x80041b2e,0x3ac80134,0x9ed80120}},	//   _tudo, счие, _wɔpɛ_, амот_, 
   {{0x6d41746b,0x3f9dadae,0xdb0400e5,0x93240472}},	//   úman, rbtu_, _tehé, _ورمن, 
   {{0xde58dbe2,0x5e58084c,0xc0c80114,0x3e7800ef}},	//   рамі_, римя_, _буке_, _kūti_, 
   {{0xef4002d3,0x3e780171,0x00000000,0x00000000}},	//   _ብዘይፍ, _jūti_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9f5c0120,0xbc2401ec,0x00000000,0x00000000}},	//   _vovó_, _ۇردى, --, --, 
   {{0x6e440cfc,0x9999adaf,0xb878013a,0x00000000}},	//   _нејз, ркат_, _opíc, --, 
   {{0xb4e44103,0xf99c0561,0x9cb400ae,0x00000000}},	// [2e830] _बने_, _anèc_, _بمخت, --, 
   {{0x2cb40316,0xdcec16a3,0x370402e8,0x00000000}},	//   řadí_, _ugađ, йчев, --, 
   {{0xb87825e6,0xa05802d3,0x67b8007b,0x60c000a2}},	//   _apíc, _ምእንታ, صالح_, hrmm, 
   {{0xe3b86f30,0x3e780953,0x2f58010f,0x39e8010a}},	//   _adı_, _būti_, נדאנ, _сьон_, 
   {{0x387c068c,0xf3140032,0x2bb000c5,0x6e2800e8}},	//   _èuro_, өндә_, _जजमा, ëjbi, 
   {{0xe895adb0,0xfa60044e,0x1418007b,0xaaa8000d}},	//   _харь, _ሰብኣይ_, شيعة_, _छौँक, 
   {{0xfbd800dc,0x6fcc0073,0x00000000,0x00000000}},	//   म्यम, _दाबू, --, --, 
   {{0x2018d7af,0x00000000,0x00000000,0x00000000}},	//   örin_, --, --, --, 
   {{0xae0801ad,0xf00064b6,0x3e7800de,0x00000000}},	//   षासन_, зүли, _gūti_, --, 
   {{0x6820007c,0xfbd800bc,0x00cc313e,0x00000000}},	//   _rödk, म्मम, _ﻛﻪﺷﺘ, --, 
   {{0xb8f80dd4,0x69c00120,0x3e780055,0xaaa800c5}},	//   _ཡད_, _ômeg, _hīty_, _छौंक, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb4e400e1,0x7bd801fa,0xd009835b,0xe3b80205}},	//   _बनो_, đuun, _веле_, _ydı_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfc3c0561,0x4e29adb1,0x00000000,0x00000000}},	//   esís_, _войн_, --, --, 
   {{0x263800e8,0x80bc00eb,0x00000000,0x00000000}},	//   rōok_, ্বর্, --, --, 
   {{0x64c866c0,0x8174010f,0x00000000,0x00000000}},	// [2e840] _रमेश, ַגעס_, --, --, 
   {{0x7d180730,0x37e00022,0x786800e4,0x3e7800ef}},	//   äuse, моуг, tüva, _rūti_, 
   {{0x06e8b623,0xbb2801d9,0xb879adb2,0x3e7800e2}},	//   рмек_, _نتَے_, _asís, _sūti_, 
   {{0x056428cf,0x68202045,0x090403b7,0x35a001c0}},	//   овен, _mödi, _дпмн, дацг, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x682001e3,0xc0bc0092,0x00000000,0x00000000}},	//   _nödi, _ተብላ_, --, --, 
   {{0x1fb400cc,0x00000000,0x00000000,0x00000000}},	//   জ্ঞস, --, --, --, 
   {{0x03940276,0xddcc00cd,0x764000db,0xa4f800f1}},	//   _дрея, _ekaś, ènye, _دکار_, 
   {{0x64a40046,0x764000e5,0x9548009a,0x00000000}},	//   _маға, ényv, _اشفق_, --, 
   {{0x6ef4063f,0x442c00b5,0xddcc00d0,0x00000000}},	//   _ọbu, mhf_, _viaž, --, 
   {{0xc10400aa,0x682000a2,0x41b001d9,0xd5e80051}},	//   _وواي, _dödi, _کۅکر, _khé, 
   {{0xb4600408,0x00000000,0x00000000,0x00000000}},	//   _акăл, --, --, --, 
   {{0x7a20007d,0xbdd8068c,0x9f3438a9,0x961c00ef}},	//   _võtm, fièc, _нелі, _miņa, 
   {{0x2c78003b,0x00000000,0x00000000,0x00000000}},	//   ійсь_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfbd00807,0xfb840220,0xfc3c067c,0xddcc012d}},	// [2e850] _तापम, _мынн, usís_, _miaż, 
   {{0xb8780241,0xd7c80b24,0x28684ae5,0x00000000}},	//   _asír, صوصه_, орхо_, --, 
   {{0x1994fbc4,0x80c4012c,0xd75800c6,0xfc3c56ed}},	//   _наня, लढुं, حلات_, ssís_, 
   {{0x3e7800b8,0xb87800e5,0x00000000,0x00000000}},	//   _pīty_, _csír, --, --, 
   {{0xd5e8004d,0x1ca80327,0x7a20000d,0xd4a400ee}},	//   _ché, _བཆས_, _lõtk, чилй, 
   {{0xc0bc0201,0x20180254,0x00000000,0x00000000}},	//   _ተብሎ_, öril_, --, --, 
   {{0x3e7802b5,0x3e4c0034,0x7a200254,0xd5e80051}},	//   _hūtu_, zęta_, _nõtk, _thè, 
   {{0xb9f40020,0x682001e3,0x2d8c0118,0x00000000}},	//   _ሚና_, _rödi, ědek_, --, 
   {{0x442c01fa,0x2018036b,0xeaa00055,0x7ae001c7}},	//   bhf_, аri_, _bhṛt_, _äntf, 
   {{0x682001b8,0xb87801ed,0xea00004d,0x7648010e}},	//   _pödi, _zsír, _trầu_, lngy, 
   {{0x961c0029,0x764800a9,0x3a2804cc,0x7a20000d}},	//   _ziņa, ongy, _olcp_, _võtj, 
   {{0x68200793,0x7649adb3,0x8f0800c7,0x00000000}},	//   _vödi, nngy, ахҭа_, --, 
   {{0x9f5c004e,0x0c940024,0x8c9400d3,0x76480363}},	//   _envà_, яшня, ярні, ingy, 
   {{0x7649adb4,0x2d9c372c,0x29dc00b8,0x00000000}},	//   hngy, _şved_, _ṭa_, --, 
   {{0xc0740208,0x9e5c0092,0x3ab00139,0x00000000}},	//   _lườm_, ደለምና_, нәят, --, 
   {{0x3e780029,0xdb040b21,0x7d1804ef,0x99880034}},	//   _būtu_, _behâ, äusc, ciaż_, 
   {{0x2ed860c7,0x9f140014,0xc0740051,0x08c475e1}},	// [2e860] _बहुत, _فےیا_, _nườm_, ябан, 
   {{0x3cf808a8,0xbdd80129,0x76480142,0x00000000}},	//   _פלינ, pièc, engy, --, 
   {{0x8a040166,0xf740009b,0xdb800117,0x00000000}},	//   _езне, нефо, _аҳри, --, 
   {{0x6820049f,0x6a780115,0x97c40e26,0xd5e8004d}},	//   _nödv, _eŭfr, كتۅم, _phé, 
   {{0xc0740208,0x442dadb5,0xa4d4187f,0x3e7800de}},	//   _cườm_, thf_, фолі, _gūtu_, 
   {{0x02a4dea5,0x961c0029,0xf48401d5,0x764802d0}},	//   прим, _viņa, ساهی, angy, 
   {{0xc7641c5c,0xb8780022,0xa37c0115,0xa2784d56}},	//   _راسى, _isíp, _obĵe, обку_, 
   {{0xc1e800d6,0x442c01b9,0xd36c0131,0x764001d3}},	//   ське_, shf_, جۇم_, ényt, 
   {{0x75d1adb6,0x3c2c0254,0x7a20000d,0xb380008e}},	//   _سيلا, _hüve_, _sõtk, мләл, 
   {{0x20182242,0xb03000c9,0x90700131,0x00000000}},	//   ðri_, еньш, نۇنش, --, 
   {{0x443dadb7,0xc1a400f3,0x00000000,0x00000000}},	//   _imt_, _ејли, --, --, 
   {{0xf99c068c,0x443c05ac,0x7a2000c5,0xdd940022}},	//   _anèn_, _hmt_, _võtk, ьамы, 
   {{0xdb041280,0xdfd40046,0x443c01e7,0xe7cc06ff}},	//   _vehí, _жолы, _kmt_, ालाप, 
   {{0x71780375,0x443c5886,0xb7d40154,0x3e7800ef}},	//   _הנדס, _jmt_, _সফ্ট, _rūtu_, 
   {{0x7e8402f8,0xa2b407f7,0x3c2c15b7,0x764846f4}},	//   íspě, ैंट्, _nüve_, yngy, 
   {{0x81e80729,0xb87801e1,0x682001b8,0x3e7802b1}},	//   মাক_, _asíp, _mödu, _pūtu_, 
   {{0x443c4fa5,0xa9549e08,0x98b80137,0xb4b8012d}},	// [2e870] _omt_, екті, юлат_, _आटे_, 
   {{0x443c0098,0xb878559d,0x22400030,0x7a200037}},	//   _nmt_, _epín, čiky_, _mõti, 
   {{0xb95801e1,0x6820007c,0x00000000,0x00000000}},	//   _odìg, _nödu, --, --, 
   {{0x443cdca3,0x1dace613,0x7a4001e1,0xe3b80139}},	//   _amt_, चरित, _dìtè, _olıs_, 
   {{0x443dadb8,0x94749a79,0x682001e6,0x947832b0}},	//   _bmt_, ودتا, _rödv, оску_, 
   {{0x443dadb9,0xb9580241,0x24f8010b,0x3e780171}},	//   _cmt_, _adìg, янчы_, _kūts_, 
   {{0xe3b1adba,0x443c010a,0x764001ed,0x3c2c0205}},	//   اره_, _dmt_, énys, _güve_, 
   {{0x3edc00b4,0x443dadbb,0xea000208,0x961c00ef}},	//   _chọọ_, _emt_, _trấu_, _ziņn, 
   {{0x443dadbc,0x3514036b,0x952401fd,0x00000000}},	//   _fmt_, _عذرس, _تکام, --, 
   {{0xa3d43591,0x38600ac5,0x443dadbd,0x2d9c01ef}},	//   _поуч, _jkjr_, _gmt_, _řve_, 
   {{0x59dc0034,0xc7b00375,0xf2040024,0x82600137}},	//   मभार, כבי_, _нядо, رۇۇن, 
   {{0x3edc01f2,0xbdd8007f,0x00000000,0x00000000}},	//   _ghọọ_, znèv, --, --, 
   {{0xb4b805f9,0x443c00b5,0x61e4002e,0x20101d0e}},	//   _आटो_, _ymt_, _ñila, ýlið_, 
   {{0xb8789559,0x443c022e,0x3e780171,0x572c0092}},	//   _spín, _xmt_, _būts_, ተርፕራ, 
   {{0xaca40248,0xaee000dc,0xef6401f0,0x00000000}},	//   _ifọw, _koṭi, _эъдо, --, 
   {{0xbdd8004e,0xb87800ae,0x00000000,0x00000000}},	//   lièn, _bpío, --, --, 
   {{0xfbe000fe,0x888400d8,0x5fd401f9,0x00000000}},	// [2e880] ময়ত, длаж, _दामल, --, 
   {{0xf99c00f2,0xbdd800cf,0xcb681742,0x00000000}},	//   _unèn_, nièn, _мапе_, --, 
   {{0x443c037e,0x5a940276,0x8ca801ad,0x3e7800ef}},	//   _rmt_, _пряф, जीरो, _gūts_, 
   {{0x81e02f8b,0xb87802fb,0x00000000,0x00000000}},	//   _ফোন_, _upín, --, --, 
   {{0x443c030d,0x00000000,0x00000000,0x00000000}},	//   _pmt_, --, --, --, 
   {{0xe3b80c07,0x4ae00490,0x764001d3,0x3c2c000d}},	//   _alır_, _पहाव, ényr, _tüve_, 
   {{0xbdd80228,0x2509adbe,0x443c000d,0x2be000dc}},	//   dièn, _کرزی_, _vmt_, ख्यं_, 
   {{0xaca40ca8,0x27f9adbf,0x443c022f,0x26d9adc0}},	//   _afọw, _harn_, _wmt_, _iqro_, 
   {{0x961c0029,0xdfd000c6,0xdcec025c,0x27f8030a}},	//   _ziņo, هية_, _ifaħ, _karn_, 
   {{0xf4845311,0xf99c0ba1,0xbdd9adc1,0xdb040122}},	//   _قالی, _anèl_, gièn, _lehá, 
   {{0x27f9adc2,0x6fcc10eb,0x670001ad,0x00000000}},	//   _marn_, _दारू, ोमिक_, --, 
   {{0xdcec031c,0xdb040306,0xe3b803e3,0x3e7800ef}},	//   _jfaħ, _nehá, _ilıq_, _rūts_, 
   {{0x27f800ad,0xdcec0327,0xe0d4010f,0x2c64007c}},	//   _oarn_, _mfaħ, _נײַ_, jöds_, 
   {{0xbdd800f7,0xf99c007f,0xdfd4008e,0x00000000}},	//   cièn, _enèl_, _чокы, --, 
   {{0x201c0381,0xdcec0841,0xb878007b,0x00000000}},	//   _iovi_, _izač, _spío, --, 
   {{0xb87809a9,0x22440194,0x201d12cf,0xbdd859c8}},	//   _epíl, nimk_, _hovi_, gnèt, 
   {{0x201c08f5,0x27f8202b,0x26d9adc3,0x682001e3}},	// [2e890] _kovi_, _barn_, _aqro_, _nöds, 
   {{0x201c0438,0x27f8fcbd,0xb8e402ab,0x6d5800b8}},	//   _jovi_, _carn_, _ईट_, _śvag, 
   {{0x27f88ddb,0x201dadc4,0x6820007c,0x67d55057}},	//   _darn_, _movi_, _rödt, тоху, 
   {{0x54d42e01,0x27f9adc5,0x2a6000a3,0xd57406a6}},	//   ецку, _earn_, coib_, нуль, 
   {{0x27f82ca2,0x5f14009e,0x00000000,0x00000000}},	//   _farn_, ানিও_, --, --, 
   {{0x6820049f,0xd7f409a5,0x00000000,0x00000000}},	//   _döds, _язгы, --, --, 
   {{0x42940131,0x67d400db,0x00000000,0x00000000}},	//   _ﻗﺎﻧﭽ, _шору, --, --, 
   {{0x27f805d5,0x68200267,0x00000000,0x00000000}},	//   _zarn_, _föds, --, --, 
   {{0x201c003a,0x68217234,0xf49401d5,0x27f80746}},	//   _bovi_, _tödt, _آشرد, _yarn_, 
   {{0x201c0a73,0x647405f5,0x3e6800a3,0x00cc2d40}},	//   _covi_, _агуу, lùth_, _ﻛﻪﺗﺘ, 
   {{0xc0f4069c,0xbdd80228,0x201dadc6,0xf99c0066}},	//   _ጉጅለ_, rièn, _dovi_, _anèm_, 
   {{0xb87803b2,0x00000000,0x00000000,0x00000000}},	//   _spíl, --, --, --, 
   {{0x2d840724,0x8fd00032,0x68200267,0xe3b80205}},	//   äme_, _йәнә, _mödr, _klıp_, 
   {{0x09b805ba,0x201dadc7,0x2c640793,0xdb0400e4}},	//   ेल्य, _govi_, vöds_, _sehá, 
   {{0xf99c00f2,0xbdd80ba1,0xdb0400e4,0x3b047995}},	//   _enèm_, gnès, _pehá, неро_, 
   {{0xbdd9adc8,0x6f000472,0x201c07f5,0x9f5c0798}},	//   nièl, _irnc, _zovi_, _vovô_, 
   {{0x6f000122,0xbdd82a4a,0x0d848f47,0x27f9adc9}},	// [2e8a0] _hrnc, rnèt, _ялин, _parn_, 
   {{0x6c3400dd,0x27f8031c,0x629c0129,0x682001e3}},	//   _شہزا, _qarn_, _érog, _röds, 
   {{0xdb0400dd,0x53c821b8,0x27f80489,0x2018023a}},	//   _tehá, _राजश, _varn_, örii_, 
   {{0xe3b9677c,0xdb04005c,0x27f887ba,0x38c800e5}},	//   _alıp_, _behæ, _warn_, تاہی_, 
   {{0x27f9adca,0x98f40598,0x3c2ce523,0xbdd8067c}},	//   _tarn_, _иярч, _hüva_, onèr, 
   {{0x290056ed,0x6f00035a,0xbdd80129,0x3ce000c5}},	//   mvia_, _ornc, nnèr, _ओहसे_, 
   {{0x201c073a,0xdcec031c,0x3e6800a3,0x6d480342}},	//   _rovi_, _tfaħ, bùth_, ğday, 
   {{0x2900011c,0x201dadcb,0x2ca001e3,0xe29800fb}},	//   ovia_, _sovi_, _otid_, паҫ_, 
   {{0x2901adcc,0x201dadcd,0xdd90297d,0x00000000}},	//   nvia_, _povi_, یود_, --, 
   {{0x2900427f,0xd575adce,0xdfd11695,0x557401ee}},	//   ivia_, _русь, جيد_, _рѳст, 
   {{0x6f001674,0x5e5800a8,0x2900023a,0xde5802bf}},	//   _crnc, диня_, hvia_, дані_, 
   {{0x29000357,0xdd2800ef,0x00000000,0x00000000}},	//   kvia_, _vēžv, --, --, 
   {{0x7a20007d,0x2ca0030d,0x201dadcf,0x6f0002d0}},	//   _mõtt, _ctid_, _tovi_, _ernc, 
   {{0x2d94013f,0xb0980375,0xbdd86320,0x6f000175}},	//   _ɔbeɑ_, _ציור, gnèr, _frnc, 
   {{0x940c013f,0x79a45e8b,0x2ca024b4,0x6f00009b}},	//   _ateɛ_, ерзе, _etid_, _grnc, 
   {{0xbdd8067c,0xdb0403e0,0xdb14036e,0x3374011a}},	//   rnès, _lehç, lazë, תעלם_, 
   {{0x5c75add0,0xb4dc01ad,0xf090010f,0x1ad000cc}},	// [2e8b0] _илит, _तहे_, ָנע_, াবো, 
   {{0x6820049f,0xb87800e4,0xbdd806af,0x81d40154}},	//   _södr, _ipík, iièm, াজি_, 
   {{0xdcfc8e8e,0x29000f23,0x6d402ab8,0x1dc40073}},	//   ması, avia_, úmav, _वयात, 
   {{0xdcfc538f,0x39a4036b,0x68200139,0x00000000}},	//   lası, _яшов, _qödr, --, 
   {{0x798c4ec2,0x461004d3,0x98a8033f,0x78680037}},	//   _igcw, شوور, dzać_, hüvi, 
   {{0xdcfc7230,0x998802d1,0xe4480131,0x00000000}},	//   nası, chaš_, ىلنى_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x61e40784,0x6f00003e,0xdcfc029f,0x37c001ee}},	//   _ñill, _rrnc, hası, _шәғб, 
   {{0xdcfc0bfc,0x798c009a,0xbdd80ba1,0x6f0002f0}},	//   kası, _mgcw, rièl, _srnc, 
   {{0x4ae005f9,0xdb140240,0xdb04005b,0x0eb818c7}},	//   _पहलव, gazë, _kehä, мумы_, 
   {{0x2ca02f61,0x798c0944,0x6fa400aa,0xdcfc1b07}},	//   _stid_, _ogcw, ونکې_, dası, 
   {{0x798cb579,0x98a80034,0x2901add1,0xb64000b5}},	//   _ngcw, czać_, yvia_, _ｎｍ_, 
   {{0xa0c5add2,0xdcfc0abc,0x332405da,0x6d58002b}},	//   _مينو, fası, lynx_, _śvab, 
   {{0x798c2747,0x29000395,0x6f00107d,0x3ce00037}},	//   _agcw, vvia_, _trnc, _ओहरे_, 
   {{0x5b3468cc,0xbdd8068c,0xdb04005b,0xae0400fb}},	//   гэту, rnèr, _nehä, _бойҙ, 
   {{0x2901add3,0xbea02c1d,0xc33004ae,0xcd0400cf}},	//   tvia_, _таък, בול_, _апий, 
   {{0xdcfc494d,0x798c03ac,0x290001f4,0x6e4400f1}},	// [2e8c0] bası, _dgcw, uvia_, _لنډم, 
   {{0x2901add4,0x798c1cdf,0xdb054b87,0x07a4487f}},	//   rvia_, _egcw, _behä, тажн, 
   {{0x9998066d,0xbdd8557b,0x290057c6,0x81d40154}},	//   _első_, zièm, svia_, াড়ি_, 
   {{0xfc3c04d4,0xdb04007c,0x00000000,0x00000000}},	//   mpía_, _dehä, --, --, 
   {{0x7a20033d,0xbdd820ef,0x29000357,0xfc3c0005}},	//   _võtt, xièm, qvia_, lpía_, 
   {{0xf99c0214,0x81d4015b,0x07b800c6,0xbdd806af}},	//   _anèh_, াড়া_, _زهرة_, vièm, 
   {{0x7a20007d,0xdb04097d,0x32b4007b,0x00000000}},	//   _tõtt, _gehä, ندية_, --, 
   {{0x60f90275,0xdcfc0bfc,0xbdd8004a,0x9f4c0023}},	//   ения_, zası, tièm, sedë_, 
   {{0xdcfc0cc1,0x5f95add5,0xc485add6,0xfbd03105}},	//   yası, липт, _алак, _तालम, 
   {{0xf99c020c,0xf0d400b5,0xdcfc00ac,0x98a80034}},	//   _enèh_, _dム_, xası, szać_, 
   {{0xdcfc71e1,0x63b800bc,0xdb140240,0xfbd02354}},	//   vası, mavn, razë, یتس_, 
   {{0x6e64170a,0x00000000,0x00000000,0x00000000}},	//   итяж, --, --, --, 
   {{0xdcfc0abc,0xdb148ac6,0xc2e800cc,0x00000000}},	//   tası, mazé, _কপটি_, --, 
   {{0x63b97b86,0x229801ed,0x62800e14,0x6d580055}},	//   navn, _kék_, lmmo, _śvac, 
   {{0xdcfc05f3,0xff340588,0x6280136d,0x6820007c}},	//   rası, _рҟны_, ommo, _rödp, 
   {{0x63b9add7,0xdcfc5531,0x00000000,0x00000000}},	//   havn, sası, --, --, 
   {{0x6281add8,0x2299add9,0xdb04023a,0x63b80219}},	// [2e8d0] immo, _lék_, _sehä, kavn, 
   {{0x63b9adda,0xdcfca090,0x7c6401c8,0x1a640133}},	//   javn, qası, _جابل, _ڕیزی_, 
   {{0x63b80bb8,0xdb04049f,0x22980694,0x00000000}},	//   davn, _behå, _nék_, --, 
   {{0x798c2747,0x7a2000af,0x9f4d30d2,0x6281addb}},	//   _ugcw, _võts, gedé_, jmmo, 
   {{0x63b82142,0xf99c0cad,0xdb140100,0x00000000}},	//   favn, _ifè_, wazè, --, 
   {{0x628031b4,0xd6b4b9ff,0xdb04005b,0x63b80208}},	//   emmo, _مشرک, _tehä, gavn, 
   {{0x88804bcf,0x22983386,0x248c00c0,0x47a40154}},	//   _ایلن, _cék_, _didm_, গৃহী, 
   {{0xd1b839b6,0x9f4c0407,0x2299734e,0x5884035b}},	//   رابا_, cedé_, _dék_, _шыҟа, 
   {{0x00c400ee,0xd39400fb,0x00000000,0x00000000}},	//   глык_, _йәйә_, --, --, 
   {{0x62800ba7,0x0ea80c9e,0x2299addc,0x630400d1}},	//   ammo, нкой_, _fék_, _ھونل, 
   {{0xd37016cb,0xce480724,0x229800d5,0xf3640276}},	//   _اها_, езне_, _gék_, _ртан, 
   {{0xd174125e,0x32f400ac,0x1ea8004b,0xf8bc02f0}},	//   _йылы, _nəyə_, کایي_, _ové_, 
   {{0x22a80241,0x00000000,0x00000000,0x00000000}},	//   _tìkò_, --, --, --, 
   {{0xf99c02bd,0x89f801d3,0x2018005b,0x00000000}},	//   _afè_, کٹرز_, örit_, --, 
   {{0xf8bcba1f,0x5ef9addd,0xbfd00137,0x32f403b9}},	//   _avé_, _ахыр_, _ايىع, _bəyə_, 
   {{0x63b81225,0x6d401d5d,0x69a401e0,0x00000000}},	//   zavn, úmas, рлаҡ, --, 
   {{0xfc3c25e6,0x090412c4,0x2bdc0073,0x7a20000d}},	// [2e8e0] mpín_, ыпан, _बापा, _põtr, 
   {{0xf99c02bd,0xfc3c0332,0x00000000,0x00000000}},	//   _efè_, lpín_, --, --, 
   {{0xc4841945,0x1cd00327,0x6280062c,0xb7d40244}},	//   ңлек, _ུའོ_, ymmo, اوما_, 
   {{0x2299adde,0x00000000,0x00000000,0x00000000}},	//   _rék_, --, --, --, 
   {{0xa928012c,0xa3b402d5,0xb6a001d5,0xfc3c0332}},	//   _držá, аблі, _ҳисл, ipín_, 
   {{0x22998d7f,0x00000000,0x00000000,0x00000000}},	//   _pék_, --, --, --, 
   {{0x248c0427,0x00000000,0x00000000,0x00000000}},	//   _vidm_, --, --, --, 
   {{0x63b80579,0xf7500fba,0x6280022f,0x248c01f5}},	//   savn, _انفج, ummo, _widm_, 
   {{0x43d401d9,0x229800e4,0x741149fc,0x40843246}},	//   _مزاز, _tĩko_, _گولا, луоб, 
   {{0xbdd8067c,0x22980de2,0x42500014,0xb95801e1}},	//   mièi, _ték_, _گۆبر, _odìn, 
   {{0x33900491,0x3c2c29ef,0x7411addf,0x8fd40724}},	//   _المز, _süvo_, _دولا, рәчә, 
   {{0xbd6813d7,0x42500014,0xdd9000c6,0x38b80241}},	//   ерге_, _دۆبر, توح_, _jàrá_, 
   {{0x3d0c01ad,0x32f403b9,0x2ab40055,0x20180254}},	//   ामें_, _rəyə_, _āviṣ_, öris_, 
   {{0x9f5c02d3,0x961c00da,0xf47c0023,0x00000000}},	//   _javë_, _viņi, ትፈልጥ_, --, 
   {{0xf8bc038e,0x9e3400d1,0x00000000,0x00000000}},	//   _své_, _вейч, --, --, 
   {{0xf990007b,0xdd1400f2,0x00000000,0x00000000}},	//   صبر_, _نوبخ, --, --, 
   {{0x57b5214e,0x26181414,0x58d40a42,0x00000000}},	// [2e8f0] ибат, फानी_, розт, --, 
   {{0x3f9c4a1f,0x2bdc0709,0x00000000,0x00000000}},	//   nctu_, _बाया, --, --, 
   {{0xb87800c7,0xdb0401d3,0x00000000,0x00000000}},	//   _opív, _lehú, --, --, 
   {{0x9f5c0124,0xf8bc00bc,0x58d44e73,0x99880419}},	//   _pavê_, _tvé_, _комт, ehať_, 
   {{0xb8781709,0x00000000,0x00000000,0x00000000}},	//   _osíx, --, --, --, 
   {{0xb8780022,0x6595ade0,0xdb0c01e1,0x00000000}},	//   _apív, _ғафу, _àkól, --, 
   {{0x1dc4dc75,0xe858014b,0x00000000,0x00000000}},	//   वणात, _сарш_, --, --, 
   {{0x2308004b,0x3f9c0393,0xdb043df9,0xd2504559}},	//   اتوي_, ectu_, _behú, تنع_, 
   {{0xb4016013,0x758001d5,0x3d0c09bb,0xedb00248}},	//   _гүлд, _ایشم, ामों_, _nẹẹt, 
   {{0x7649ade1,0xe3b0034c,0x09b01d15,0x998801f1}},	//   ligy, _فرم_, _ज़्य, chať_, 
   {{0x2bdc2052,0x1cd00327,0xdddc012d,0x38b80ca8}},	//   _बाबा, _ུའུ_, dosł, _yàrá_, 
   {{0x7648113c,0xb8780005,0xc32c0244,0x00000000}},	//   nigy, _esíx, _تڕه_, --, 
   {{0x9f4c0801,0xdb04002d,0x60c40fac,0x00000000}},	//   ledì_, _tehû, _åimp, --, 
   {{0x4fa423b3,0x7648b57e,0xb87800bc,0x99b400fe}},	//   _тикв, higy, _zpív, টলোক, 
   {{0x7f143ed4,0x9f4c0801,0x7ae0049f,0x40307b00}},	//   _نيوز_, nedì_, _äntl, _фејс, 
   {{0xc33006a9,0x08c400db,0x00000000,0x00000000}},	//   קון_, иббн, --, --, 
   {{0x87b80b32,0x7b9401d9,0x76480009,0x38b80241}},	// [2e900] вует_, _چھِس_, digy, _ràrá_, 
   {{0x6e2400c6,0x76480076,0x00000000,0x00000000}},	//   _hoib, eigy, --, --, 
   {{0xf99c0ba1,0x764801d3,0x00000000,0x00000000}},	//   _anèu_, figy, --, --, 
   {{0x105402d3,0x3f9c004c,0x76481418,0x96c801d3}},	//   _ዝጥቀመ, zctu_, gigy, ابلِ_, 
   {{0xca740131,0x2905ade2,0xb90002d5,0x00000000}},	//   _ماڭغ, _éma_, _дзяк, --, 
   {{0x0ec413b4,0x9f5c02bd,0xdb040789,0x7648062c}},	//   _विंड, _favè_, _rehú, aigy, 
   {{0x76488b14,0xb9dc02d3,0xdee8010c,0xc5d40212}},	//   bigy, _ኣታ_, ዛብን_, _візь, 
   {{0x6e25ade3,0x81b400fe,0x3eb802d2,0x00000000}},	//   _noib, _জাহ_, _æpti_, --, 
   {{0x6600009f,0x442c00b5,0xbfa9ade4,0x9f5c036e}},	//   _iamk, pkf_, ктне_, _tavë_, 
   {{0x6600b502,0x6e2437a8,0xbdd83ae2,0x00000000}},	//   _hamk, _aoib, nièv, --, 
   {{0x6600f71c,0x44e0001e,0x6e240072,0x64480135}},	//   _kamk, _hư_, _boib, _imdi, 
   {{0xc0e5ade5,0x6e25ade6,0x6601ade7,0xf2640276}},	//   _водк, _coib, _jamk, _кихл_, 
   {{0x4094343d,0x6e243e79,0x660002fb,0x3ebc0036}},	//   _трет, _doib, _mamk, sstt_, 
   {{0x6601ade8,0x9f5d0aae,0x7649ade9,0xc1e001ad}},	//   _lamk, _lavé_, zigy, क्रब_, 
   {{0x6e240170,0xdddc0034,0x6448037e,0x76480134}},	//   _foib, rosł, _mmdi, yigy, 
   {{0x6601adea,0x6e25adeb,0x64480327,0x6e4400d8}},	//   _namk, _goib, _lmdi, _мејз, 
   {{0x76480357,0x7e7c014b,0x9f5c026c,0x1cd0031c}},	// [2e910] vigy, _ihqp, _savè_, _ུའི_, 
   {{0xa814afe2,0xf99c068c,0x37051379,0x920400b8}},	//   одуш, _anèt_, ичев, _ihāś, 
   {{0x66002939,0x9f5c0129,0x2bdc0e49,0x76c5adec}},	//   _bamk, _bavé_, _बाता, شغال, 
   {{0x9f4c0801,0x6600020b,0x52a807d6,0x8ccca202}},	//   vedì_, _camk, қвим_, _तिमो, 
   {{0x44e00016,0x6601aded,0xf3f41a98,0x764800e5}},	//   _cư_, _damk, имдә_, rigy, 
   {{0xdb05adee,0x44e0001e,0x660002d0,0x7649adef}},	//   _behø, _dư_, _eamk, sigy, 
   {{0x66000a85,0x9724034c,0xdb15adf0,0x3689adf1}},	//   _famk, _افزو, _âbän, _асан_, 
   {{0xb8780077,0x6601adf2,0xf99c0129,0x64482093}},	//   _epít, _gamk, _inès_, _emdi, 
   {{0xe534034b,0x4f9401c6,0x6e244230,0xad640092}},	//   _деть, йрну, _roib, _ፍላጎቶ, 
   {{0x6601adf3,0xb110063f,0x2bdc0f4c,0x9f4cb269}},	//   _zamk, _kụzi, _बाधा, pedì_, 
   {{0x6e240491,0x6601adf4,0xdb040b1a,0x8e28022e}},	//   _poib, _yamk, _gehø, аkаt_, 
   {{0xdb1440cf,0x9f4c9223,0x660001d5,0xbac801ec}},	//   gazí, cedí_, _xamk, _ﯗﺷﺘﺎ, 
   {{0x8658008f,0x92040055,0x64480142,0xd4900208}},	//   רדרי, _chāś, _ymdi, _kì_, 
   {{0xdd9801f1,0x6e240810,0xd47800df,0x00000000}},	//   ľňa_, _woib, טאָל, --, 
   {{0xbdd84056,0x6e25adf5,0xa4f40e49,0xdd9800d7}},	//   vièv, _toib, _इन्च_, žňa_, 
   {{0x76580337,0xa2d80490,0xb8780030,0x7d240200}},	//   _njuy, नंत्, _opís, ërsë, 
   {{0x19b9adf6,0x66008767,0xe3b80166,0x8c4400f3}},	// [2e920] русь_, _ramk, _elıy_, _гепе, 
   {{0x6601adf7,0x765800b5,0xc17004ae,0x14d00073}},	//   _samk, _ajuy, לחן_, _समजण, 
   {{0x44e00016,0x6601adf8,0x8b840014,0x9f5c529d}},	//   _sư_, _pamk, _دٔدو, _pavé_, 
   {{0x05b9adf9,0x660003f0,0xb8780008,0x3f78008f}},	//   ادات_, _qamk, _spít, אָדע, 
   {{0x9f5c0093,0x66000099,0x9f4c0030,0x7e7dadfa}},	//   _vavé_, _vamk, vedí_, _ëppe, 
   {{0x6601adfb,0x8458593a,0xe748008e,0x3394007b}},	//   _wamk, ырет_, _күзе_, منهج_, 
   {{0x68e5adfc,0x6601adfd,0xb879adfe,0x784c0024}},	//   ltid, _tamk, _epís, _dėvė, 
   {{0x44e001dc,0x6600090c,0x969001b9,0x00000000}},	//   _tư_, _uamk, _قیلش, --, 
   {{0xdcec098d,0x9f4c01f1,0xb111adff,0xf4240166}},	//   _izać, redí_, змыш, _şäex_, 
   {{0x6449ae00,0x68e5ae01,0xd49001fb,0x9f4c02fb}},	//   _umdi, itid, _gì_, sedí_, 
   {{0x68e400af,0xdb140118,0x00000000,0x00000000}},	//   htid, tazí, --, --, 
   {{0x68e42dde,0x73300137,0x5bb001f9,0x00000000}},	//   ktid, _عىنا, झर्व, --, 
   {{0x412810f5,0x6019ae02,0xdb15ae03,0x6459ae04}},	//   _щодо_, _воля_, razí, onvi, 
   {{0x64581278,0x27080248,0x68e45f03,0xe81c5d4f}},	//   nnvi, _e̟ni_, dtid, नाफा_, 
   {{0xa3e011b1,0x998800c8,0xba74eac4,0x6459ae05}},	//   _थान_, rkaŭ_, مارت, invi, 
   {{0x998800c8,0x68e5ae06,0xb110063f,0x81d404c5}},	//   skaŭ_, ftid, _rụzi, াজক_, 
   {{0x68e5ae07,0x23c806ff,0xe91802bf,0xd88800ec}},	// [2e930] gtid, रणाद, боті_, لپرن_, 
   {{0xa7b800f7,0x645801f5,0x00000000,0x00000000}},	//   йлуу_, jnvi, --, --, 
   {{0xb879ae08,0x68e5ae09,0x3c2c002f,0xd758007b}},	//   _spís, atid, _nüvi_, جلات_, 
   {{0x68e40014,0x64580f85,0x588401ec,0x00000000}},	//   btid, envi, сыға, --, 
   {{0x68e5ae0a,0x0594036b,0xdb1406d9,0x9f4c05d5}},	//   ctid, زانگ, lazà, hedà_, 
   {{0x645900fe,0xb87800d7,0x94740066,0x00000000}},	//   gnvi, _vpís, زگذا, --, 
   {{0x08400014,0x1634023a,0xd49001fb,0x923800a8}},	//   _تۆلُ, _девя, _vì_, ичиу_, 
   {{0xd7d803f8,0x41b0005e,0x6458072b,0x961c00ef}},	//   _ढाँच, ومىر, anvi, _viņs, 
   {{0x54540a83,0xdb140109,0x69dc07f7,0xaee00055}},	//   _дват, hazà, _फासी, _kaṇi, 
   {{0x8ee80818,0xb9580241,0xe81c687b,0x23840014}},	//   амов_, _adìk, नाया_, _کٔمِ, 
   {{0xfbd00807,0x68e4009d,0xaee000dc,0xe2c8009f}},	//   _ताजम, ztid, _maṇi, _هولو_, 
   {{0x68e4a784,0xbdd8004e,0x2bdc2c2e,0x00000000}},	//   ytid, diès, _बाहा, --, 
   {{0xe81c038e,0x8d7560bc,0xa3e000e1,0x2fc4014f}},	//   नामा_, تادا, _थाम_, _tdng_, 
   {{0xdb14145e,0xdb0c0122,0x0b58a6d1,0x00000000}},	//   _âbûn, _škál, арбы_, --, 
   {{0x0eb80b65,0x63bc000d,0x8a040d1d,0xfaa0014b}},	//   _тулы_, _õrne, озве, дасо, 
   {{0x2bdc0406,0x89a800d8,0x00000000,0x00000000}},	//   _बावा, ркав_, --, --, 
   {{0xc8c80345,0x7d7401ec,0x68e411d4,0x00000000}},	// [2e940] شوان_, _ومىر_, utid, --, 
   {{0xb879ae0b,0x00000000,0x00000000,0x00000000}},	//   _spír, --, --, --, 
   {{0xbdd9ae0c,0xd1bc001f,0x4038008f,0x4e1c216a}},	//   mièr, ሰሩት_, סגעג, _बचाई_, 
   {{0xbdd9ae0d,0x59e010b7,0xdb0c0248,0x00000000}},	//   lièr, _फायर, _ákál, --, 
   {{0x68e4036b,0xdb15ae0e,0x47e00032,0x3dc4009e}},	//   qtid, mazá, _оҙаҡ, ষ্কল, 
   {{0xbdd8c735,0x02a424b1,0x9f5c04cc,0xaee000cd}},	//   nièr, орим, _bavì_, _gaṇi, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb87802fb,0xdb0402f0,0xd36c03cc,0x7fa400d1}},	//   _upír, _nehý, دۇم_, ﺎﺋﯩﻲ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdcec0327,0xa15802dd,0x3c2c0254,0x5f7800f2}},	//   _ngaġ, _қалу_, _tüvi_, یمکس_, 
   {{0xbdd81497,0xceac0451,0x00000000,0x00000000}},	//   dièr, هڙي_, --, --, 
   {{0xbdd8068c,0xde580006,0xe81c27a6,0xdb1400e5}},	//   nnèx, самі_, नाडा_, jazá, 
   {{0xbb4c001f,0xc044004b,0x00000000,0x00000000}},	//   _አስቸጋ, _وختو, --, --, 
   {{0xbdd8068c,0x99880e04,0x00000000,0x00000000}},	//   gièr, jkaš_, --, --, 
   {{0x2bdc0807,0xd1c002d3,0xaee00055,0x00000000}},	//   _बारा, ጻዕቲ_, _raṇi, --, 
   {{0x9999ae0f,0x7d18324c,0x9f5c0419,0x00000000}},	//   скат_, äuss, _javí_, --, 
   {{0xbdd87d4f,0xaee00055,0x00000000,0x00000000}},	// [2e950] bièr, _paṇi, --, --, 
   {{0xbdd92e05,0x37a84389,0x8f5001d5,0x00000000}},	//   cièr, ртан_, _آچیش, --, 
   {{0x569434d8,0x0af001c0,0xdb140030,0xaee000dc}},	//   чает, _пүрэ, bazá, _vaṇi, 
   {{0xdb140077,0x6af41079,0xcad400d9,0x19580064}},	//   cazá, _کثیر, _צורת_, _гамы_, 
   {{0x9f5c07c5,0xdb040036,0x53a40124,0x268800d1}},	//   _savì_, _ofhë, палб, ڭخەي_, 
   {{0xd7c80330,0x6d580055,0x53a4013d,0x00000000}},	//   _دوسه_, _śvak, чакб, --, 
   {{0x9f5c0122,0xe894026b,0x00000000,0x00000000}},	//   _baví_, _царь, --, --, 
   {{0xbdd8004a,0x2a9800e8,0x00000000,0x00000000}},	//   zièr, _yōbb_, --, --, 
   {{0x2bdc08ec,0x9f4c01f1,0xf7700451,0x646800e8}},	//   _बाला, vedá_, _راڳ_, àriñ, 
   {{0xdb05ae10,0x7ae00a40,0x7ae40175,0xc914011a}},	//   _behü, _äntw, ktjt, פחתת_, 
   {{0xbdd8ff1b,0xe29802bf,0xe81c0b7d,0xf20400c0}},	//   vièr, _дає_, नाता_, _мядо, 
   {{0xe1f12933,0x0734010f,0x00000000,0x00000000}},	//   _لسه_, פארם_, --, --, 
   {{0xbdd8d58d,0xc1980302,0xdb1401ed,0xc1e40451}},	//   tièr, _השני, vazá, _رکيل_, 
   {{0x2bdc0490,0x8e380214,0xc32000fe,0x00000000}},	//   _बाळा, _گستر_, _ভেটি_, --, 
   {{0xbdd9ae11,0xdb1401d3,0xdb040112,0x81e000cc}},	//   rièr, tazá, _gehü, _ফোট_, 
   {{0xbdd839d3,0xba2055c3,0x237803cd,0x629c0022}},	//   sièr, ндск, _ørje_, _ũrok, 
   {{0xbdd84325,0xdb15ae12,0x998805be,0x7e7c0de2}},	// [2e960] pièr, razá, tkaš_, _ëppa, 
   {{0x8d74848c,0xd95802dd,0xade807f7,0x00000000}},	//   _واکا, ішті_, ट्रन_, --, 
   {{0x99880960,0x04a001e1,0x00000000,0x00000000}},	//   rkaš_, _ìtẹs, --, --, 
   {{0x106800d1,0xe56800d1,0x99883493,0x00000000}},	//   ﻴﺎﺭﯨ, ەمچى_, skaš_, --, 
   {{0x961c00ef,0xa4d800d4,0x00000000,0x00000000}},	//   _viņp, ідку_, --, --, 
   {{0xd4985566,0xc0d00092,0xb978011a,0x5dc000d1}},	//   ірі_, _ጨለማ_, _לנכי, _ﻣﯩﻠﻴ, 
   {{0x45d40276,0x3dc400fe,0xd36c15bf,0x9f5c01ef}},	//   _нцат, ষ্টল, لۇك_, _paví_, 
   {{0x96b80868,0x76a4030d,0x00000000,0x00000000}},	//   _фуру_, _хырç, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x73e00640,0x95940150,0x00000000,0x00000000}},	//   _поуз, _ішті, --, --, 
   {{0x2d81ae13,0x8338048a,0x1df812c4,0x22940022}},	//   _azie_, _учат_, оены_, _ẽkua_, 
   {{0xb8780784,0x81b402f5,0x00000000,0x00000000}},	//   _aqíl, _জাক_, --, --, 
   {{0x940403be,0x69d80006,0x00844130,0x7c8400f3}},	//   _ailə_, ėvel, _елдо, зуве, 
   {{0x94040213,0xac2400c0,0x8ccc17c6,0x6e20007c}},	//   _bilə_, нфск, _तिरो, ömbr, 
   {{0x2d8000b4,0xdb040022,0x59e01cd2,0xb2680162}},	//   _ezie_, _rehó, _फादर, úðgó, 
   {{0x94040213,0x00000000,0x00000000,0x00000000}},	//   _dilə_, --, --, --, 
   {{0xdb0400c7,0x9514002b,0xdb14415b,0x00000000}},	// [2e970] _pehó, _iṅgi, kazç, --, 
   {{0xdb04068c,0x648401ab,0xed58011a,0xa87401ec}},	//   _dehò, nòid, _מבחר_, елуі, 
   {{0xf7700532,0xbdd80699,0x940403e3,0x5ac80244}},	//   راط_, chèc, _gilə_, _باخێ_, 
   {{0xb8d18da0,0x55542a9f,0xd5740138,0x6d580055}},	//   _টি_, وپار, муль, _śvai, 
   {{0x9f5cc19a,0xe53400d6,0x3a28007f,0xac740330}},	//   _lavà_, нець, _iocp_, _زایش, 
   {{0x81b4009e,0x673003b2,0xdb1400a2,0x00000000}},	//   _জাগ_, íhjá, gazç, --, 
   {{0xc0f00020,0xdb040332,0xa5240327,0xf644022e}},	//   ግዲህ_, _bfhé, འདུག_, _ехан, 
   {{0xb9f80092,0x8ccc0055,0x00000000,0x00000000}},	//   _ቅን_, _तिलो, --, --, 
   {{0xa4d400d6,0xdb1401b8,0xdb040332,0xc0bc0092}},	//   _поті, lazä, _dfhé, _ሰብል_, 
   {{0x951400cd,0x9f4c0139,0x00000000,0x00000000}},	//   _aṅgi, kedä_, --, --, 
   {{0xfbe009bd,0x63bc0037,0xd8880220,0x00000000}},	//   য়াত, _õrna, _ﺑﻮﻟﯟ, --, 
   {{0x7ec0c00f,0x358002d3,0x2dc801d5,0x51540108}},	//   _sípá, _ይሓትት_, чқин_, _отлу, 
   {{0x9f5c0589,0x7ec08a9a,0x94040213,0x00000000}},	//   _pavã_, _pípá, _silə_, --, 
   {{0xf1e000e1,0x26140037,0x09d40073,0x00000000}},	//   _गाड़_, _नोनी_, धल्य, --, 
   {{0x09e5ae14,0x9f5c0137,0x3b05ae15,0xed5401e4}},	//   мовн, _gavà_, меро_, _teɾo_, 
   {{0x6f840014,0x00000000,0x00000000,0x00000000}},	//   _وچھِ_, --, --, --, 
   {{0x0d84022e,0x9988010e,0x00000000,0x00000000}},	// [2e980] _юлин, ndaň_, --, --, 
   {{0x2ca006ed,0x6f000113,0xb8780139,0x59740124}},	//   _iuid_, _ksnc, _uqíl, хысу, 
   {{0x49b8bd62,0x2ca00cf9,0x7c2000a3,0xbc18010f}},	//   _واحد_, _huid_, _ònra, _וויש, 
   {{0x2ca0033d,0xa3e010fa,0xe81c3f6f,0x00000000}},	//   _kuid_, _थाह_, नाहा_, --, 
   {{0xc514237e,0xe8540131,0x04453da1,0x00000000}},	//   ببات, _كۆرد, медн, --, 
   {{0x69c5ae16,0x2ca1ae17,0x9f5d502c,0x2900009f}},	//   laie, _muid_, _lavá_, mwia_, 
   {{0x4e0c1d72,0x2ca1ae18,0x066402dd,0x2900012d}},	//   ियाई_, _luid_, _قارپ, lwia_, 
   {{0x69c5ae19,0xe81c04fa,0x7410006c,0x00000000}},	//   naie, नावा_, _یوقا, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdfd030d6,0x69c5ae1a,0x290001f2,0x00000000}},	//   ديد_, haie, iwia_, --, 
   {{0x443dae1b,0x69c5ae1c,0x648401ab,0xf7d40677}},	//   _ilt_, kaie, ròid, וויש_, 
   {{0x2ca0039a,0x6f000100,0xffa005f5,0x201801d3}},	//   _buid_, _dsnc, элүү, űri_, 
   {{0x2ca0be47,0x443dae1d,0x69c5ae1e,0x01342073}},	//   _cuid_, _klt_, daie, _تعاد, 
   {{0x2ca0020b,0x443c594a,0xdfd0004b,0x7e6c00cf}},	//   _duid_, _jlt_, _صيب_, socp, 
   {{0x443c4c8f,0xaf00704a,0x69c4515a,0x7e7c1bce}},	//   _mlt_, _ачык, faie, _ëppo, 
   {{0x61e003a2,0x2ca00493,0x9f4c0724,0x69c401c0}},	//   ngml, _fuid_, redä_, gaie, 
   {{0x443dae1f,0x2ca04f7f,0x5c740dbb,0x3eac01ab}},	// [2e990] _olt_, _guid_, _плит, _htft_, 
   {{0xe610444b,0xa50c031c,0x00000000,0x00000000}},	//   یشن_, _གླེག_, --, --, 
   {{0x2ca1ae20,0x69c5ae21,0x3a280175,0x41bc01ad}},	//   _zuid_, baie, _tocp_, _एजंस, 
   {{0x443c0334,0x69c5ae22,0x2900009f,0xeaf8158b}},	//   _alt_, caie, bwia_, _کریت_, 
   {{0x443c8d68,0xa8a4e41f,0x26000037,0x00000000}},	//   _blt_, _арск, _रसरी_, --, 
   {{0x443c5c74,0xb4dc012d,0x00000000,0x00000000}},	//   _clt_, _थमी_, --, --, 
   {{0x23e017c6,0xe81c0fe3,0xa3e00210,0x00000000}},	//   _नारद, नारा_, _थार_, --, 
   {{0x2d8400ee,0x00000000,0x00000000,0x00000000}},	//   ýmek_, --, --, --, 
   {{0x62680118,0x00000000,0x00000000,0x00000000}},	//   děod, --, --, --, 
   {{0x4f2412e7,0x443c01e3,0x69c5ae23,0x998800d7}},	//   едоб, _glt_, zaie, ckať_, 
   {{0x2ca00591,0xddcc00df,0x69c4004a,0x00e4030f}},	//   _suid_, _ekaŭ, yaie, وتیی, 
   {{0x2bb84802,0x2ca000c5,0x6484067c,0x7e7c00e8}},	//   अर्थ, _puid_, ròie, _ëppl, 
   {{0x2ca0c51b,0x443c0354,0x69c5ae24,0xa29402bf}},	//   _quid_, _ylt_, vaie, _раці, 
   {{0x21581375,0x69c5ae25,0x92e00154,0x00000000}},	//   _تجمع_, waie, ধবী_, --, 
   {{0xac5c001f,0x0c84104e,0x606401ee,0x00000000}},	//   ተማማኝ_, дыңм, _шешҡ, --, 
   {{0x2ca006a3,0x2900033f,0x4e280454,0x2bdc0401}},	//   _tuid_, twia_, _хоин_, _बाका, 
   {{0x69c5ae26,0xe81c0490,0x88858b05,0x8c940212}},	// [2e9a0] raie, नाला_, елаж, _проі, 
   {{0x69c5ae27,0x0ae80108,0x37e00022,0x29000210}},	//   saie, _едой_, лоуг, rwia_, 
   {{0x69c5ae28,0x00000000,0x00000000,0x00000000}},	//   paie, --, --, --, 
   {{0x443dae29,0x366508c8,0x058435c9,0xaee000cd}},	//   _slt_, нахо_, нулм, _spṛh, 
   {{0xb958026c,0x65940063,0xb4b4009f,0x7ae001e3}},	//   _veìc, њалу, ُّها_, _äntr, 
   {{0xa2a47e29,0x78b8e090,0xcfd42b1b,0x00000000}},	//   _चंद्, _çuva, ত্তন, --, 
   {{0x443dae2a,0xbdd800f2,0xdcec0139,0x7bd8011a}},	//   _vlt_, dhèn, _ozağ, לקסו, 
   {{0x998801f1,0x2a6000c5,0x443c01f5,0x55f4004e}},	//   skať_, nnib_, _wlt_, _ичуу, 
   {{0x443c30e8,0x0f30001f,0x99880419,0xd09806be}},	//   _tlt_, _ይመለከ, pkať_, lçəl, 
   {{0x443dae2b,0xdcec008e,0x2bdc6620,0x00000000}},	//   _ult_, _azağ, _बागा, --, 
   {{0xd3441046,0x28c000cd,0x00000000,0x00000000}},	//   _لیوه_, शीति, --, --, 
   {{0x11e805d4,0x99880165,0x6da400d8,0xb18000d7}},	//   _يعني_, zhaű_, лиџа, šťam, 
   {{0xc0cc069c,0xe0d400c8,0x7c700116,0x00000000}},	//   ኣቶም_, _סײַ_, лғич, --, 
   {{0xbdd9ae2c,0xdef40f15,0x20540024,0x2a60000d}},	//   chèn, _апкы, _шкля, enib_, 
   {{0xb9580248,0xfa840114,0x6d5800b8,0x00000000}},	//   _ndìr, ећам, _śvat, --, 
   {{0xdd9000f1,0x00000000,0x00000000,0x00000000}},	//   _پوخ_, --, --, --, 
   {{0xa3e00d0a,0x23e01098,0xb4dc00ab,0x28f8005b}},	// [2e9b0] थला_, _नांद, _थमे_, неть_, 
   {{0x2a604469,0x200c0368,0x6d8c0432,0x00000000}},	//   anib_, nddi_, _ỳagn, --, 
   {{0xdcec0989,0x200dae2d,0xaee00241,0xb765ae2e}},	//   _izađ, iddi_, _inṣi, хтай, 
   {{0xdb040628,0x7bc5ae2f,0x200c0083,0x00000000}},	//   _behö, laju, hddi_, --, 
   {{0x81d402a6,0x888001d5,0x00000000,0x00000000}},	//   িভা_, _چیقن, --, --, 
   {{0x7bc5ae30,0x68e005ac,0xf8bc110e,0xd7c81f7e}},	//   naju, _åmda, _iwé_, _زوره_, 
   {{0x7bc40356,0x63780395,0x04400395,0x00000000}},	//   iaju, нсър_, рещн, --, 
   {{0xf8bc025a,0x201c14ed,0x200c03cb,0xdec40023}},	//   _kwé_, _anvi_, eddi_, ጻእን_, 
   {{0xe6641e28,0xdb040639,0xbdd807b0,0x629c00b8}},	//   _стро, _gehö, thèn, _ũrot, 
   {{0x7bc405a1,0x0f30001f,0x0ea8005b,0x200c015d}},	//   jaju, _ይመልከ, мкой_, gddi_, 
   {{0x7bc41326,0x00000000,0x00000000,0x00000000}},	//   daju, --, --, --, 
   {{0x200d638b,0x10f4010b,0x00000000,0x00000000}},	//   addi_, _аякя, --, --, 
   {{0xc690008d,0xbdd80129,0x3e4c0210,0x00000000}},	//   יאט_, phèn, nęty_, --, 
   {{0x7bc5ae31,0xf99c007f,0xd0105220,0x09c8412f}},	//   gaju, _agè_, _ضلع_, िण्य, 
   {{0xf8bdae32,0x629dae33,0x00000000,0x00000000}},	//   _awé_, _érot, --, --, 
   {{0x3b040cfc,0x7bc4013c,0xdcec3361,0x00000000}},	//   њето_, aaju, _uzağ, --, 
   {{0x7bc5ae34,0x3e4c012d,0x07a40006,0xaa640137}},	// [2e9c0] baju, jęty_, вазн, _ۅندۉ, 
   {{0x4795ae35,0x9f4c0419,0x1ab003d4,0x2bdc0118}},	//   نجاس, vedú_, _ছিৰা, _बाटा, 
   {{0xf8bc0ca8,0xfc3c0321,0x2288000f,0x88b001d5}},	//   _ewé_, ppír_, lûke_, _چیرچ, 
   {{0x75d00491,0x741035cf,0xca700345,0x00000000}},	//   ليما, یونا, _ئۆرک, --, 
   {{0x200c0cfd,0xbdd8020c,0xa3d41fce,0x00000000}},	//   yddi_, dhèl, голч, --, 
   {{0x07a46fbd,0x5f1400dc,0xbb3801ec,0x00000000}},	//   _јавн, धिम्_, _ﻓﻠﻥ_, --, 
   {{0xf8bc01c7,0xc69001d9,0x86940798,0xfbd000d9}},	//   _zwé_, _نِس_, _ајач, בתו_, 
   {{0x200c0142,0x91c00166,0x00000000,0x00000000}},	//   wddi_, бәшл, --, --, 
   {{0x7bc5ae36,0xa0742374,0x2288002d,0xb380104e}},	//   yaju, лгич, jûke_, лләл, 
   {{0x2288002d,0x9988002e,0xd5740006,0x00000000}},	//   dûke_, wdaŋ_, _сусь, --, 
   {{0x7bc408ad,0x6459ae37,0x2bdc0d5f,0x74105767}},	//   vaju, mivi, _बाजा, _خولا, 
   {{0xf7700302,0xbdd9ae38,0x7bc432b2,0xcbb40220}},	//   יקת_, chèl, waju, ңғыш_, 
   {{0x9fa401e0,0xdb040419,0x64580051,0x6d5800cd}},	//   _йыйҙ, _lehô, oivi, _śvar, 
   {{0xc5b802f5,0x31980115,0x00000000,0x00000000}},	//   ুলিপ, _חבדנ, --, --, 
   {{0x629d9f61,0xba740150,0xa3e04eae,0xdb040419}},	//   _éros, نارت, _थाई_, _nehô, 
   {{0x7bc400a8,0x6459ae39,0x6e440137,0x00000000}},	//   saju, hivi, _ۅنۉم, --, 
   {{0x57f40484,0x23b400cd,0x00000000,0x00000000}},	// [2e9d0] лпат, ुराद, --, --, 
   {{0xfbb4590f,0x7bc40140,0x7ac52d34,0x00000000}},	//   _अभिम, qaju, _исме, --, 
   {{0xb8780077,0x95d8023a,0xdd9800d0,0x00000000}},	//   _mpíx, едет_, ľňu_, --, 
   {{0x64580024,0x58846518,0x88b00154,0x00000000}},	//   eivi, тыға, _চিরক, --, 
   {{0x89d89b62,0xe5040372,0x9478a9ce,0x64580869}},	//   _אחרי, لبوي, нску_, fivi, 
   {{0x6459ae3a,0x3e4c012d,0xdec40023,0x00000000}},	//   givi, ręty_, ጻእና_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6484067c,0x00000000,0x00000000,0x00000000}},	//   ròia, --, --, --, 
   {{0x6459ae3b,0xd05802bf,0x51f400db,0xe3ac01ec}},	//   bivi, ерні_, _ەستر, _мұ_, 
   {{0x6459ae3c,0x904443f3,0xbbc0037e,0x648401ab}},	//   civi, انده, _ｍで_, lòin, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2288002d,0x00000000,0x00000000,0x00000000}},	//   tûke_, --, --, --, 
   {{0x4638008f,0x00000000,0x00000000,0x00000000}},	//   גערע, --, --, --, 
   {{0x2288002d,0xc0d01913,0x00000000,0x00000000}},	//   rûke_, _ايوب, --, --, 
   {{0x0580002b,0x00000000,0x00000000,0x00000000}},	//   _dūṣy, --, --, --, 
   {{0x6459ae3d,0xbb4000f5,0xda651695,0xd258010e}},	//   zivi, щеск, لاقي, niņ_, 
   {{0x6459ae3e,0x0889ae3f,0x00000000,0x00000000}},	// [2e9e0] yivi, ебай_, --, --, 
   {{0x6459ae40,0xcfd40011,0x00000000,0x00000000}},	//   xivi, ত্রন, --, --, 
   {{0x6459ae41,0x4421ae42,0x1fc8015b,0x98c41c52}},	//   vivi, _đk_, _শামস, ātās_, 
   {{0x442001ed,0x61480421,0x60c40139,0x00000000}},	//   _ők_, lūlū, _çimg, --, 
   {{0x893400c6,0xd25800ef,0x00000000,0x00000000}},	//   _إعجا, diņ_, --, --, 
   {{0x07b800c6,0xbfcc0521,0x43080166,0x64580165}},	//   _سهرة_, ụṅụ_, ехим_, uivi, 
   {{0x7d1801c7,0x00000000,0x00000000,0x00000000}},	//   äusz, --, --, --, 
   {{0x6459ae43,0xc0bc0020,0xb9080882,0x60f80801}},	//   sivi, _ደብረ_, ttiḥ_, вния_, 
   {{0xc4856a4a,0xc5640b3b,0xa2a4146b,0x6459ae44}},	//   _блак, _скак, _चूर्, pivi, 
   {{0x2054030d,0x8004011c,0x8ccc06e3,0x00000000}},	//   ркоя, учие, _तिजो, --, 
   {{0xb7d8008f,0x39880248,0x6d58002b,0xa2c40150}},	//   עקטי, _kòsí_, _śvap, _тәлк, 
   {{0xde5802d5,0x7330129d,0x00000000,0x00000000}},	//   тамі_, _دىما, --, --, 
   {{0xf4240166,0xc05800d4,0x00000000,0x00000000}},	//   _şäix_, _пік_, --, --, 
   {{0x6281ae45,0x5f95ae46,0xd9dc2ac3,0x00000000}},	//   llmo, _килт, यल्ट, --, 
   {{0xc0c000d1,0xfa8800cf,0xda34d9b4,0x00000000}},	//   _тәқи, есай_, аевы, --, 
   {{0xbe880166,0x00000000,0x00000000,0x00000000}},	//   _ясле_, --, --, --, 
   {{0x6280023a,0xdb040332,0xecdc00af,0x6db400fb}},	// [2e9f0] ilmo, _dfhá, _बियफ, _уйыу, 
   {{0x27f80327,0x79a405a2,0xe81c3c71,0x6280002f}},	//   _cbrn_, _әрне, नागा_, hlmo, 
   {{0xa2a40dad,0x7c64004b,0x4c9805d0,0x9c9400b8}},	//   _चूल्, _ټاکل, _שבתו, cvāṣ, 
   {{0xbdd800f2,0x00000000,0x00000000,0x00000000}},	//   dhèk, --, --, --, 
   {{0x741000f1,0xbdb80150,0xa3e007b7,0x00000000}},	//   یوچا, _ﺸﺎﻤل_, थलं_, --, 
   {{0x1be80316,0x6280a46d,0xc8b4010f,0x3f800210}},	//   ञ्चल_, elmo, _כּלה_, ękuj_, 
   {{0x291c0421,0x1db40073,0x56780064,0x81ac00eb}},	//   āvae_, ंडात, _абвя_, করন_, 
   {{0xd5f804ac,0xe2a9ae47,0x6280009b,0x00000000}},	//   _שפּר, داون_, glmo, --, 
   {{0x00c40e26,0xbb380150,0x00000000,0x00000000}},	//   алык_, _ﻓﻠﻴ_, --, --, 
   {{0x628001f5,0x9034447e,0x4f9400f5,0x00000000}},	//   almo, рхич, ирну, --, 
   {{0x0e65ae48,0x00000000,0x00000000,0x00000000}},	//   икон, --, --, --, 
   {{0x9045ae49,0x629c5d69,0x00000000,0x00000000}},	//   انگه, _érop, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf284004b,0x8b64034e,0x0b440b01,0x320c01d3}},	//   _شپږو_, لازم, ангн, _hagy_, 
   {{0x2fc406a3,0x59e0033f,0xfb5400d1,0x0f78010f}},	//   _ieng_, _फाखर, ۇرېھ, _באַב, 
   {{0x2fc5ae4a,0xc3300375,0x0d20004e,0x8a0400d8}},	//   _heng_, חול_, _дүмү, јзае, 
   {{0x2fc5ae4b,0x9e64cb3f,0x47c4871a,0x320dae4c}},	// [2ea00] _keng_, _داون, ибав, _magy_, 
   {{0x2fc5ae4d,0x60c5ae4e,0x320dae4f,0xe3b9ae50}},	//   _jeng_, _çime, _lagy_, _anın_, 
   {{0x2fc5ae51,0xdb0404ce,0x2abc01e1,0x628008fb}},	//   _meng_, _afhæ, _dàbò_, ylmo, 
   {{0x320c066d,0x2fc5ae52,0x21e40220,0x00000000}},	//   _nagy_, _leng_, _ﺍﻋﺎﺭ, --, 
   {{0x24f8010b,0x00000000,0x00000000,0x00000000}},	//   унлы_, --, --, --, 
   {{0x2fc5ae53,0x68e5ae54,0xe74800ee,0xbdd80066}},	//   _neng_, muid, _йүзе_, thèk, 
   {{0x68e5ae55,0x86980228,0x320c010b,0x4de4012c}},	//   luid, _атат_, _bagy_, कलाई_, 
   {{0xd36c1b16,0x2fc40066,0x969405c8,0x628005c7}},	//   رۇن_, _aeng_, _груш, ulmo, 
   {{0x2fc5ae56,0x68e5ae57,0x2d800451,0x320c00ee}},	//   _beng_, nuid, _nyie_, _dagy_, 
   {{0x2fc40007,0x6280022e,0x00000000,0x00000000}},	//   _ceng_, slmo, --, --, 
   {{0x2fc5ae58,0x2d800ac5,0x82a4094e,0x38140375}},	//   _deng_, _ayie_, _таеж, בקים_, 
   {{0x2fc5ae59,0x320c05da,0x9f4c01b8,0x68e5470a}},	//   _eeng_, _gagy_, medü_, kuid, 
   {{0x50300023,0x00000000,0x00000000,0x00000000}},	//   ይምኽኣ, --, --, --, 
   {{0x68e5ae5a,0x2fc5ae5b,0x7b65ae5c,0x72d000c7}},	//   duid, _geng_, атбе, _уӡәӡ, 
   {{0x44fc03d4,0x68e4003a,0x442c01f5,0x320c00a2}},	//   ূমিক_, euid, ijf_, _yagy_, 
   {{0x2fc403b9,0x68e400a3,0xbdf81063,0x00000000}},	//   _zeng_, fuid, _شرعا_, --, 
   {{0x2fc5ae5d,0xd75800e5,0x7c84009b,0x00000000}},	// [2ea10] _yeng_, گلات_, _вуне, --, 
   {{0x8ca01411,0xa7b80137,0x2fc40051,0x00000000}},	//   _رەفو, илуу_, _xeng_, --, 
   {{0x648401ab,0xd758007b,0x99880327,0x53a400fb}},	//   ròil, دلات_, lkaż_, ҙайб, 
   {{0xd04c013f,0x1a64036b,0x6b8805d5,0x00000000}},	//   _ɑkɑt, _ایری_, üdge, --, 
   {{0x395c0221,0x68e5ae5e,0x9a7405d9,0x88803c73}},	//   _äus_, cuid, _ننڍڙ, _کیلن, 
   {{0x320c00a2,0x00000000,0x00000000,0x00000000}},	//   _sagy_, --, --, --, 
   {{0x2fc5ae5f,0xdb1404d4,0x00000000,0x00000000}},	//   _reng_, mazó, --, --, 
   {{0x2fc5ae60,0x00000000,0x00000000,0x00000000}},	//   _seng_, --, --, --, 
   {{0x320c00f8,0x2fc5ae61,0xe81c0490,0xca28008f}},	//   _vagy_, _peng_, नाचा_, רופֿ, 
   {{0x2fc4047e,0xfa04031c,0xd0080063,0x5044009b}},	//   _qeng_, _ཅིའན_, ћене_, сеоб, 
   {{0xa4907ec6,0xa3ac22e3,0x320dae62,0x68e5ae63}},	//   _تیوت, _गलत_, _tagy_, zuid, 
   {{0x7bd4172e,0x2fc406a3,0x68e40d04,0x64840428}},	//   _adxu, _weng_, yuid, jòij, 
   {{0x2fc43c7b,0x30a53b38,0x7bd40175,0xdb14033f}},	//   _teng_, _трев, _bdxu, kazó, 
   {{0x81ac00bd,0xdb0404e6,0x00000000,0x00000000}},	//   করণ_, _ofhä, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbdd8020c,0xe3b80790,0x60d0008e,0x99880210}},	//   dhèw, _anıl_, _ähmä, ddał_, 
   {{0x6e25ae64,0x00000000,0x00000000,0x00000000}},	// [2ea20] _inib, --, --, --, 
   {{0xdb1436ed,0x68e5ae65,0xaee000b8,0x00000000}},	//   gazó, ruid, ciṣm, --, 
   {{0x6e25ae66,0x17780953,0x68e5ae67,0x00000000}},	//   _knib, асць_, suid, --, 
   {{0x68e5ae68,0xe53000b8,0x76480076,0x8a0474df}},	//   puid, _aśāś, ghgy, _узме, 
   {{0xdb0401fb,0x25a40fac,0xd85001e1,0x203c0023}},	//   _nghê, _vgml_, _kọ̀_, _ይገብረ, 
   {{0x66e4005e,0xdb140789,0x00000000,0x00000000}},	//   _қоға, cazó, --, --, 
   {{0x6e25ae69,0x386c01ed,0xd8500248,0xe2c800cf}},	//   _onib, égre_, _mọ̀_, جوعو_, 
   {{0x76480368,0xbdd80ba1,0xe0d8014b,0xd36c00d1}},	//   chgy, lhèv, адич_, خۇم_, 
   {{0x442c0789,0xf0b40244,0x00000000,0x00000000}},	//   pjf_, یایش_, --, --, 
   {{0x6e25ae6a,0x44f0011f,0x97c40ca8,0x340800f1}},	//   _anib, mâ_, _è̟tó, _مرمۍ_, 
   {{0x438436e7,0x6449ae6b,0x38140375,0x44f00548}},	//   _الاق, _ildi, זקים_, lâ_, 
   {{0xf99c020c,0x3f80005f,0x00000000,0x00000000}},	//   _kaèt_, āku_, --, --, 
   {{0xd8500241,0x228800d2,0x44f1ae6c,0xa3ac5d4f}},	//   _bọ̀_, lûko_, nâ_, _गला_, 
   {{0x6e25ae6d,0x47dc04c5,0x3130013e,0xfc6402e8}},	//   _enib, ন্তী, _хешр, съмн, 
   {{0x81ac1c82,0xa3d05c0e,0x9f4c5a8b,0x44f00022}},	//   কৰণ_, _वजन_, redó_, hâ_, 
   {{0x2aa80ce7,0x44f165eb,0x00000000,0x00000000}},	//   стро_, kâ_, --, --, 
   {{0x6449ae6e,0x2dd800c6,0xe3b8453a,0xa3d800cd}},	// [2ea30] _oldi, _طبية_, _anım_, _ऽयं_, 
   {{0x44f00548,0x81ac015b,0x7c640633,0x6d4800df}},	//   dâ_, করি_, _دابل, ĝdat, 
   {{0xdb15ae6f,0x59f80139,0x6d4800df,0x7648015d}},	//   razó, _кеня_, ŝdat, thgy, 
   {{0x64480323,0x7ae5ae70,0x28c417c6,0x00000000}},	//   _aldi, mujt, _लौकि, --, 
   {{0x47dc2158,0x7ae42753,0x44f00618,0x81ac015b}},	//   ন্ধী, lujt, gâ_, করা_, 
   {{0xbdd8026c,0x987800c8,0x61e400ef,0x00000000}},	//   chèv, _כאָט, _ķila, --, 
   {{0xddcc0054,0x74d80a94,0xa3b805f9,0x44f0208d}},	//   _imaņ, _निवृ, चड़_, aâ_, 
   {{0x44f0011f,0x00000000,0x00000000,0x00000000}},	//   bâ_, --, --, --, 
   {{0x44f00429,0x765971bc,0x7ae5ae71,0x73c000fb}},	//   câ_, _imuy, hujt, _еҙле, 
   {{0x7ae5ae72,0x228800d2,0x00000000,0x00000000}},	//   kujt, bûko_, --, --, 
   {{0x920400b8,0x836001ec,0xd85001e1,0x00000000}},	//   _akāś, _يگىل, _rọ̀_, --, 
   {{0x7ae40232,0x8e5402bf,0x623400f3,0x87780375}},	//   dujt, ітні, _неху, יאתי, 
   {{0xd1bc00b7,0x7c340072,0x765804ba,0x64480254}},	//   _ደስታ_, _boxr, _mmuy, _yldi, 
   {{0x951400b8,0x6abc0334,0x4598010f,0x60c4008e}},	//   _aṅki, tprf, יסרע, _çima, 
   {{0x7ae4c2bf,0x76582252,0x44f00109,0x9204002b}},	//   gujt, _omuy, zâ_, _ekāś, 
   {{0x6e25ae73,0xa2cc06ab,0x44f0208d,0xd8500241}},	//   _unib, _सबस्, yâ_, _wọ̀_, 
   {{0x44f00548,0x38c861be,0x00000000,0x00000000}},	// [2ea40] xâ_, لالی_, --, --, 
   {{0x5ee00a28,0x76582e95,0xd48416cb,0x44f14aa0}},	//   _किम्_, _amuy, _سڀ_, vâ_, 
   {{0xdb04001e,0x7ae40306,0x81ac0183,0x8708d29d}},	//   _nghè, cujt, কৰি_, реев_, 
   {{0x454405a9,0x6448062c,0xbdd8068c,0x44f1ae74}},	//   يناق, _sldi, shèv, tâ_, 
   {{0x61400162,0x999802f0,0x8cb0012d,0x00000000}},	//   _málú, _plsť_, _इंफो, --, 
   {{0x76581418,0x2a600009,0xfbbc00dc,0x21e40220}},	//   _emuy, liib_, ्रयम, _ﺍﻋﺘﺭ, 
   {{0x44f00548,0x339001a9,0x00000000,0x00000000}},	//   sâ_, машё, --, --, 
   {{0xb9580ca8,0xb5400248,0x25f400bc,0x44f00022}},	//   _adìy, _kẹ́m, _एउटी_, pâ_, 
   {{0xfbbc1d27,0x7ae4517b,0x44f0011f,0xb1100b7e}},	//   ्रमम, zujt, qâ_, дмыш, 
   {{0xdcec4a4a,0x6449ae75,0x7ae5ae76,0x3fa80063}},	//   _ayağ, _uldi, yujt, шњим_, 
   {{0x2a600067,0x7ae40306,0x00000000,0x00000000}},	//   kiib_, xujt, --, --, 
   {{0x41246e9a,0x7ae57a20,0x2a600014,0xf424031c}},	//   _وفاق, vujt, jiib_, _ཡོོད_, 
   {{0xa0b8c260,0xa1140220,0x2a600009,0x00000000}},	//   _углу_, _ءوتت, diib_, --, 
   {{0x7ae4a355,0x7c340135,0x2bb8007b,0xb59c0150}},	//   tujt, _qoxr, قافة_, _ﻁﺭﻴﻘ_, 
   {{0xe3b8415b,0x7c34007c,0x99880210,0x00000000}},	//   _anık_, _voxr, zdań_, --, 
   {{0x7ae5ae77,0xbda400aa,0x1959ae78,0xcaa80150}},	//   rujt, _بحثو, бабы_, _ﻋﺎﺌﻪ_, 
   {{0x37a9ae79,0x7ae46185,0x00000000,0x00000000}},	// [2ea50] атен_, sujt, --, --, 
   {{0x7ae40306,0x47dc0154,0xb9001fc4,0x6604000d}},	//   pujt, ন্সী, _नट_, õikn, 
   {{0xf99c0066,0xd76004d3,0x2a6003d9,0xac7400cf}},	//   _paès_, رۆری, biib_, _تايش, 
   {{0xbdd806af,0x5ebc0183,0xdb04004d,0x963400d4}},	//   chèt, _আটাই, _nghé, янец, 
   {{0xe5342626,0x298400f7,0x784401c6,0x09b4011a}},	//   мець, _жырг, _дэвж, _מפרט_, 
   {{0x9f5c04cc,0xe45802bf,0x99880165,0x05940244}},	//   _bavü_, ожі_, rdań_, سانگ, 
   {{0x9345ae7a,0x03a06fe4,0xbdd80561,0x64e001f9}},	//   янке, нишо, nhès, _निथळ, 
   {{0x7658a183,0xc5ec00aa,0xa5e400db,0x122801d5}},	//   _umuy, _مړه_, _оюул, соий_, 
   {{0xf4840640,0xc69000df,0x41000108,0x00000000}},	//   _дужн, _טאל_, езыв, --, 
   {{0x8f7400d6,0xbdd80ba1,0xb3dc0037,0xc4d000d9}},	//   зумі, zhèt, _नयिख, _נגב_, 
   {{0x20180109,0x8e840835,0x60c403b9,0x9f6000b8}},	//   ôria_, згне, _çimn, _āsãt_, 
   {{0x2a6001d9,0xbdd80066,0x50b400f3,0x00000000}},	//   xiib_, dhès, _еску, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x58f80003,0xd47800c8,0x00b8011a,0x8c44008e}},	//   _ཕྱེས_, מאָל, _המסמ, чеге, 
   {{0xbdd9ae7b,0x3f64442d,0x2a60000d,0x00000000}},	//   thèt, _нишо_, tiib_, --, 
   {{0x89a86b10,0x2bd80316,0x4fc00137,0x7f38011a}},	//   скав_, _भएका, _تەگە, _לעצו, 
   {{0x2a60058a,0xf8a43d2a,0x88e40108,0x00000000}},	// [2ea60] riib_, звук_, яжае, --, 
   {{0x2a6001d9,0x6f000b4b,0xfbbc0864,0x00000000}},	//   siib_, _kpnc, ्रणम, --, 
   {{0x8cb003f3,0xbdd806af,0x46a43129,0x00000000}},	//   _इंडो, phèt, чаев, --, 
   {{0xbdd8180f,0x648400e4,0x6d580055,0x00000000}},	//   lhèr, nòiv, _śvay, --, 
   {{0x9f5c07c5,0xb7cc00d1,0xc514027d,0x00000000}},	//   _savü_, _ﺗﯘﺭﻏ, ثبات, --, 
   {{0x69c5ae7c,0x68e5ae7d,0xf8bc0008,0xbdd8068c}},	//   lbie, mrid, _bréf_, nhèr, 
   {{0xe2f801ec,0x69c40210,0xfbbc00cd,0x00000000}},	//   цейі_, obie, ्रतम, --, 
   {{0xefb8af5b,0x68e45fd9,0x69c48e0d,0x00000000}},	//   ቲካዊ_, orid, nbie, --, 
   {{0x68e5ae7e,0xdb0c02d2,0x00000000,0x00000000}},	//   nrid, _áköl, --, --, 
   {{0x69c5ae7f,0x68e5ae80,0x9ed8aaba,0x99881a48}},	//   hbie, irid, омот_, njaš_, 
   {{0x68e40e63,0xceb40184,0x6d40383d,0xbdd804fb}},	//   hrid, үҙә_, øman, dhèr, 
   {{0x69c40097,0x68e5ae81,0x00000000,0x00000000}},	//   jbie, krid, --, --, 
   {{0x69c5825f,0x68e4022e,0xed580006,0x00000000}},	//   dbie, jrid, зоў_, --, 
   {{0x69c5ae82,0xbdd807ea,0x9f5c04cc,0x26d801d5}},	//   ebie, thès, _davò_, _ovro_, 
   {{0x68e5ae83,0xa2c00490,0x69c4002f,0x6ff8011a}},	//   erid, ळीच्, fbie, _ההופ, 
   {{0x68e5ae84,0x81dc03f4,0xaa5809f7,0x69c40399}},	//   frid, দ্র_, пису_, gbie, 
   {{0x68e5ae85,0x3eac0263,0x26d9ae86,0xa3cc256a}},	// [2ea70] grid, _huft_, _avro_, लरा_, 
   {{0x37a83f14,0xbdd90dcf,0xa81486de,0x69c4eac5}},	//   стан_, chèr, ндуш, abie, 
   {{0x69c5ae87,0x356824ce,0x68e400af,0x3eac01d5}},	//   bbie, әрен_, arid, _juft_, 
   {{0xfe7c0129,0x68f801e7,0x69c40051,0xf41c372c}},	//   noï_, éadá, cbie, _şä_, 
   {{0x26d9ae88,0xdb0400b5,0x66000175,0x68e5ae89}},	//   _evro_, _afhø, _dbmk, crid, 
   {{0xfbbc1b61,0xdcfc06be,0xeaf803c7,0x00000000}},	//   ्रिम, ncsı, _بریت_, --, 
   {{0xfe7c00e4,0x00000000,0x00000000,0x00000000}},	//   koï_, --, --, --, 
   {{0x78b80139,0xa5f8026b,0x00000000,0x00000000}},	//   _çuvs, _несу_, --, --, 
   {{0xfbbc146b,0x60c40790,0x00000000,0x00000000}},	//   ्राम, _çiml, --, --, 
   {{0x09a82017,0x69c48763,0xf4240327,0x00000000}},	//   _कल्य, zbie, _ཡོིད_, --, 
   {{0x2d8c0034,0xb2c4004b,0x69c5ae8a,0xddcc00d7}},	//   ędem_, _رغاو, ybie, _klaň, 
   {{0x68e40419,0x78a4df61,0x69c40007,0x8cb002ab}},	//   yrid, _lijv, xbie, _इंदो, 
   {{0xcc2400dd,0x68e401b9,0xbdd80129,0x62340133}},	//   ورسٹ, xrid, thèr, _سووڕ, 
   {{0x69c40399,0x68e5ae8b,0x78a509ce,0x37e0015b}},	//   wbie, vrid, _nijv, ন্তর, 
   {{0x69c5ae8c,0x68e4058a,0x78ac0175,0x8d600092}},	//   tbie, wrid, _aucv, ሰራቸው_, 
   {{0x68e5ae8d,0xf99c02e2,0xbdd8067c,0x26dc00d0}},	//   trid, _obèd_, shèr, ávom_, 
   {{0x78a40936,0xda64a5d1,0x68e5ae8e,0xdb0c0030}},	// [2ea80] _bijv, رافي, urid, _škôl, 
   {{0x78a40007,0xddcc0432,0x66000334,0x9f88032e}},	//   _cijv, _alaň, _sbmk, _kóði_, 
   {{0x68e401a9,0x99880219,0x46f400f5,0x00000000}},	//   srid, rjaš_, ьчат, --, 
   {{0xa3d009d9,0xf8bc0165,0x5ee00307,0x69c40327}},	//   _वजह_, _bréd_, _किस्_, qbie, 
   {{0x88a00032,0xf8bc0332,0xddcc02f0,0xa5642c04}},	//   _ағаһ, _créd_, _dlaň, رگرن, 
   {{0x58f8003d,0xf1bc9936,0x78a40369,0xc0f402d3}},	//   _ཕྱིས_, ñán_, _gijv, _ፈለማ_, 
   {{0x161810f7,0xdb04001e,0xf99c0100,0xd49800d4}},	//   _नोकर_, _nghì, _ebèd_, їрі_, 
   {{0x37e000bd,0x41e4063b,0x32600006,0x3eadae8f}},	//   ন্দর, фіка, ктыв, _ruft_, 
   {{0xf40003d4,0x00000000,0x00000000,0x00000000}},	//   লয়ৰ_, --, --, --, 
   {{0x800402e8,0xddcc00d7,0x60c403b9,0x92ac00fe}},	//   фчие, _zlaň, _çimm, _কবৰ_, 
   {{0x4dc408b0,0x61480008,0xd5f000e4,0xfe7c0129}},	//   ﯩﻨﯩﻨ, félö, _ág̃a, toï_, 
   {{0xbdd820ef,0x82340244,0x00000000,0x00000000}},	//   thèq, _ترئا, --, --, 
   {{0x6281ae90,0xfe7c067c,0x00000000,0x00000000}},	//   momo, roï_, --, --, 
   {{0x3eac135e,0x30e401ec,0x00000000,0x00000000}},	//   _tuft_, _ісің, --, --, 
   {{0x200c1917,0x245000e8,0x78a401a4,0x9f88041e}},	//   medi_, _kàmb_, _rijv, _góði_, 
   {{0xdd942ba5,0x200dae91,0xbdd802e2,0xfbbc7239}},	//   _пайы, ledi_, chèp, ्रहम, 
   {{0xf8bc0129,0x386c4de4,0x28f80108,0x00000000}},	// [2ea90] _orée_, égro_, меть_, --, 
   {{0x6281ae92,0x200dae93,0x24500de2,0x78a4014f}},	//   homo, nedi_, _làmb_, _qijv, 
   {{0x78a5ae94,0xdd90034c,0xfd1c07c5,0xe7f0447d}},	//   _vijv, _جوک_, lvì_, _चारा_, 
   {{0x78a52058,0x200cd850,0x6281ae95,0x557402e8}},	//   _wijv, hedi_, jomo, нгет, 
   {{0x6281ae96,0xf65001d5,0xddcdae97,0xac740244}},	//   domo, _یئر_, _vlaň, _سایش, 
   {{0x200c1727,0xf8bdae98,0x58f8025c,0xe8e0004d}},	//   jedi_, _crée_, _ཕྱགས_, _nuột_, 
   {{0x27f80232,0xe785ae99,0x6281ae9a,0x66b454fa}},	//   žený_, _ауто, fomo, _абсу, 
   {{0x6281ae9b,0xdb04004d,0x9f880174,0xe8e00208}},	//   gomo, _nghí, _róði_, _quệt_, 
   {{0xd184152d,0x200dae9c,0xf8bc01c7,0xe8e00208}},	//   элий, fedi_, _frée_, _buột_, 
   {{0x200dae9d,0x00e00124,0x00000000,0x00000000}},	//   gedi_, ыжьн, --, --, 
   {{0xe2f400c7,0x00000000,0x00000000,0x00000000}},	//   _азхь, --, --, --, 
   {{0x628032be,0x35800023,0x6fbc1fad,0x00000000}},	//   como, _ክሓትት_, _श्रं, --, 
   {{0x200c2ee9,0xc690008f,0xdb040142,0xe7f00892}},	//   bedi_, טאט_, _nghâ, _चाला_, 
   {{0x200dae9e,0x26dc0030,0x648400a3,0x00000000}},	//   cedi_, ávok_, lòir, --, 
   {{0xf8bdae9f,0xb9200022,0x3ab04990,0x00000000}},	//   _até_, pyrỹ_, ләят, --, 
   {{0xc3301203,0x629c011c,0x2450002e,0x00000000}},	//   נון_, _èrot, _xàmb_, --, 
   {{0x4c846e4f,0x7bc400e5,0x00000000,0x00000000}},	// [2eaa0] _плив, bbju, --, --, 
   {{0x6281ad6a,0x7d540375,0xf8bc01e7,0x00000000}},	//   zomo, _נייד_, _dté_, --, 
   {{0xf8bdaea0,0x6281aea1,0x00000000,0x00000000}},	//   _eté_, yomo, --, --, 
   {{0x200daea2,0x44200139,0x8ee000fe,0x00000000}},	//   zedi_, _şk_, _বহাগ, --, 
   {{0x628114e1,0x200daea3,0x3a20005b,0x337001ec}},	//   vomo, yedi_, _смяг, ңгір, 
   {{0x7b840046,0x6281aea4,0xe47c010b,0xddcc0210}},	//   _تاۋە, womo, _öwüş, _skaż, 
   {{0x62800839,0xe8e0001e,0xf484104c,0x00000000}},	//   tomo, _ruột_, راهی, --, 
   {{0x200c2d32,0xe3b80790,0x60c400a2,0xb6a0010a}},	//   wedi_, _anıt_, _çimk, _бисл, 
   {{0x200daea5,0xd1d4001f,0x25cc4c5b,0x96900133}},	//   tedi_, _የኤች_, ारीण, _ئینش, 
   {{0x6281aea6,0xdb04032e,0xf8bc0129,0x64840e89}},	//   somo, _afhý, _urée_, ròis, 
   {{0x6281aea7,0x443c07ab,0xe8e00051,0x8fd4008e}},	//   pomo, _iot_, _vuột_, тәчә, 
   {{0x200daea8,0x443c0c3e,0x6280569f,0xddcc012d}},	//   sedi_, _hot_, qomo, _ukaż, 
   {{0x443daea9,0x200daeaa,0xe8e0004d,0xe1040327}},	//   _kot_, pedi_, _tuột_, _མརྒད_, 
   {{0x443c1574,0x315404ac,0xf8bc007b,0x200daeab}},	//   _jot_, _אידן_, _rté_, qedi_, 
   {{0x443c6afa,0x7bc404f3,0xf8bca801,0xe814060e}},	//   _mot_, rbju, _sté_, ड़ना_, 
   {{0x443c8977,0xd1d40020,0xda08088c,0xb8781427}},	//   _lot_, _የቤት_, بيره_, _kvíg, 
   {{0x443c4f7f,0xf8bc004a,0xa979aeac,0x00000000}},	// [2eab0] _oot_, _qté_, ейту_, --, 
   {{0x443daead,0x00000000,0x00000000,0x00000000}},	//   _not_, --, --, --, 
   {{0xbbbdaeae,0x55f4009d,0x00000000,0x00000000}},	//   ्रीक, вчлу, --, --, 
   {{0x443c1028,0xa6c400d1,0xcb340a7c,0x00000000}},	//   _aot_, اقنى, _סארי_, --, 
   {{0x443daeaf,0x98a40724,0x92ac015b,0x94785968}},	//   _bot_, _җиңе, _কবে_, мску_, 
   {{0x9f5c0022,0xdddc033f,0xdef0001f,0x657800d0}},	//   _havõ_, nisł, ቃለን_, _ťahá, 
   {{0x443daeb0,0x86f401ed,0x75e800a2,0x00000000}},	//   _dot_, _لکنس_, gözü, --, 
   {{0x569401f0,0xbbbc08df,0x00000000,0x00000000}},	//   _рабт, ्रुक, --, --, 
   {{0xb401aeb1,0xdddc012d,0x13a40133,0x00000000}},	//   _бүлд, kisł, رۆڵی_, --, 
   {{0x443daeb2,0xe50800aa,0x504400f3,0x00000000}},	//   _got_, _سيمو_, теоб, --, 
   {{0xc7b006a9,0x291c0618,0x630403cc,0xdb04004d}},	//   יבי_, āvai_, _مولل, _nghà, 
   {{0x443daeb3,0x036801d9,0x4fc000d1,0x986c0064}},	//   _zot_, _تٔمی_, _ھەجە, _ožį_, 
   {{0x443daeb4,0xbbbc4709,0x00000000,0x00000000}},	//   _yot_, ्रूक, --, --, 
   {{0xc0e03461,0x2d8c0061,0x1f640220,0x443daeb5}},	//   _тошк, āde_, _өкім, _xot_, 
   {{0xd1d4001f,0x66040161,0xaee000b8,0x99d000fe}},	//   _የቤተ_, ŵiki, _kaṭi, িলৈক, 
   {{0x2288025a,0xbb401a21,0xddcc0166,0xaee0002b}},	//   bûku_, шеск, _imaş, _jaṭi, 
   {{0xaca4063f,0x888413d6,0x00000000,0x00000000}},	// [2eac0] naịk, влаж, --, --, 
   {{0x2288002d,0xdddc0210,0x0c2401af,0x00000000}},	//   lûkt_, cisł, _рмон, --, 
   {{0x443c2af2,0xf8bc06af,0x09e5aeb6,0x26dc0588}},	//   _rot_, _préc_, _ионн, évo_, 
   {{0x443daeb7,0xf620023b,0x26dc00c7,0x00000000}},	//   _sot_, идхо, ĩvo_, --, 
   {{0x443daeb8,0xc9540139,0xdbcc02d2,0x26dceb90}},	//   _pot_, _ртны, _kóðu, ũvo_, 
   {{0x7ebc02b5,0x443c014f,0x1cc80327,0xd4c4007b}},	//   _hīpe, _qot_, ཊྚི_, اغني, 
   {{0xdbcc2833,0x2c0400dc,0xc764215c,0xf7d00150}},	//   _móðu, श्यं_, _شاسى, _ﺟﯘﻧﺪ, 
   {{0x245001ab,0xaee00055,0xf4940131,0xa195aeb9}},	//   _dàma_, _caṭi, ىھەت_, лайч, 
   {{0x2288002d,0xddcc2a9b,0xbdc801ec,0x75e80790}},	//   dûkt_, _amaş, _ﺒﺘﻨﻔ, sözü, 
   {{0x44a401b9,0x443c0208,0x00000000,0x00000000}},	//   _شماق, _uot_, --, --, 
   {{0x1df8467b,0xd34494f1,0x3f8833b8,0x03a400d8}},	//   нены_, _میوه_, æbu_, _рижо, 
   {{0x2288019f,0xc8e006ab,0xb879aeba,0xc2441d5b}},	//   tûku_, _पिंट, _tvíg, _шнек, 
   {{0x3f80033f,0x00000000,0x00000000,0x00000000}},	//   łku_, --, --, --, 
   {{0xbbbc0b9a,0x5f9400d1,0x6d40005b,0xfc6402e8}},	//   ्रेक, _йилт, ämaa, тъмн, 
   {{0x228800d2,0x9b58009d,0x00000000,0x00000000}},	//   sûku_, хивт_, --, --, 
   {{0x201daebb,0xf8bc0e47,0x00000000,0x00000000}},	//   _havi_, _aréa_, --, --, 
   {{0x201daebc,0x27f80175,0xf8bc01e7,0x7ebc00b8}},	// [2ead0] _kavi_, _bcrn_, _bréa_, _dīpe, 
   {{0xdbcc05a4,0x201c041a,0xf8bc004a,0x0f300345}},	//   _góðu, _javi_, _créa_, _ئکید, 
   {{0x201daebd,0x7f580334,0xd5b036ce,0x00000000}},	//   _mavi_, nztq, مفا_, --, 
   {{0x201c9dff,0xb87801ef,0xb6000003,0x00000000}},	//   _lavi_, _svíd, ġġor, --, 
   {{0xe3b8013d,0xaee00055,0x00000000,0x00000000}},	//   _anıq_, _raṭi, --, --, 
   {{0xd7c859c7,0x201daebe,0x00000000,0x00000000}},	//   _سوره_, _navi_, --, --, 
   {{0xaee000b8,0x00000000,0x00000000,0x00000000}},	//   _maṣi, --, --, --, 
   {{0x6b8804cc,0x00000000,0x00000000,0x00000000}},	//   üdgi, --, --, --, 
   {{0x201c0bb8,0xb8780162,0xd4c4008e,0x274c0092}},	//   _bavi_, _tvíd, _сөек, _በሚሰጠ, 
   {{0x201c00a7,0xf3640bd6,0xbbbc0a5a,0x734800f3}},	//   _cavi_, _итен, ्रोक, _очев_, 
   {{0x201daebf,0xbbbc33af,0xdbcc0bcd,0x4814008f}},	//   _davi_, ्रैक, _róðu, אַכן_, 
   {{0x8fa40022,0xd0d43e38,0x00000000,0x00000000}},	//   каҿе, _бодъ, --, --, 
   {{0x7ebc04fe,0x201c003a,0x2288000f,0x09e401a9}},	//   _rīpe, _favi_, rûkt_, ғозн, 
   {{0x2cac9632,0x201c0055,0xa1343346,0xd010007b}},	//   ödd_, _gavi_, _خرمش, _طلع_, 
   {{0x09e5aec0,0x3b040a93,0x7ebc00ef,0xadc401af}},	//   ловн, леро_, _pīpe, _кайһ, 
   {{0x321daec1,0x201c0064,0x69440092,0x00000000}},	//   nduy_, _zavi_, _የመግቢ, --, 
   {{0x9e65aec2,0xca7400fb,0x48040395,0x00000000}},	// [2eae0] _خاون, _ҡумы, лпав, --, 
   {{0x201daec3,0x6ab801ed,0xaac40451,0x6a840075}},	//   _xavi_, _évfo, _نڪرن, улға, 
   {{0x85e9aec4,0x634802ea,0x4ee004c5,0x7bf800c8}},	//   едев_, mɛng, _বহুল, _אפיצ, 
   {{0xf99c007f,0x75d1aec5,0x00000000,0x00000000}},	//   _ibèn_, ميما, --, --, 
   {{0x04442e58,0xa6c42002,0xe5343ad8,0x321c00e8}},	//   ледн, اقچى, рель, dduy_, 
   {{0x2901aec6,0x9989aec7,0xf8bc0098,0x7d78010f}},	//   mtia_, ldaş_, _uréa_, ענסו, 
   {{0x2901aec8,0xc304004b,0xf740013d,0xf2c00166}},	//   ltia_, ابتو, _леро, бсын, 
   {{0x99881cce,0x26dc0306,0xbdd80100,0xf2e401e2}},	//   ndaş_, ávou_, nkèt, اکله_, 
   {{0x2901aec9,0xd584168d,0x6348043b,0x3e68007f}},	//   ntia_, _پێوه_, kɛng, _lòtè_, 
   {{0x29010066,0x93b4004d,0x7a28008e,0xb87808ce}},	//   itia_, _hãn, _kötä, _tvíe, 
   {{0x5f940209,0x290002f6,0xde5800d6,0x201daeca}},	//   ринт, htia_, вані_, _vavi_, 
   {{0x2901aecb,0xbcf80036,0x6458072b,0x321c0051}},	//   ktia_, nzég, lhvi, cduy_, 
   {{0x201c23e0,0x189c0020,0x0234004b,0x290001e4}},	//   _tavi_, _ቁጥጥር_, _لګښت_, jtia_, 
   {{0x6459aecc,0x93b40208,0x5bc401d5,0x00000000}},	//   nhvi, _lãn, شقرل, --, 
   {{0x2901aecd,0x2d843262,0xba7415f2,0xdb14013d}},	//   etia_, ümer_, هارت, _äbün, 
   {{0x290001f4,0x998800a2,0x00000000,0x00000000}},	//   ftia_, gdaş_, --, --, 
   {{0x52d045bf,0x394c0579,0x64580113,0x29000240}},	// [2eaf0] _सब्स, ágs_, khvi, gtia_, 
   {{0x7a280139,0xa9b40154,0x64580419,0xfdf006b1}},	//   _bötä, য়ণগঞ, jhvi, े्रस_, 
   {{0x2901aece,0xb87804d4,0x321c014f,0xfba800d4}},	//   atia_, _avíc, yduy_, _ятий_, 
   {{0x7bd42895,0x588400fb,0xfbbc00cd,0x00000000}},	//   _hexu, уыға, ्रकम, --, 
   {{0x290000a8,0x7bd401c4,0x00000000,0x00000000}},	//   ctia_, _kexu, --, --, 
   {{0x934430cb,0x6348043b,0x7bd4009d,0x6458014f}},	//   инле, kɛnd, _jexu, ghvi, 
   {{0x7bd40077,0x88801680,0xb8780321,0xf77006a0}},	//   _mexu, _بیلن, _tvíb, _طاس_, 
   {{0x7bd5aecf,0x245001e1,0x645c0135,0x00000000}},	//   _lexu, _fàmo_, _ċrie, --, 
   {{0x321c02d1,0x94180166,0x65940024,0x2b9c01ef}},	//   rduy_, _ижат_, _гату, _kácí_, 
   {{0x7bd5aed0,0x3e6c023a,0x673800d0,0xd0080063}},	//   _nexu, yötä_, ňajš, њене_, 
   {{0xd371aed1,0x290005f5,0x798c020c,0xddcc00f3}},	//   _بها_, ztia_, _lycw, _sjaš, 
   {{0xd1300597,0xba38004e,0x3f8c03cb,0x290000d0}},	//   _وما_, _xiït, _dyfu_, ytia_, 
   {{0xe3d802f5,0x7bd4022e,0x4638008f,0x290000b5}},	//   _সাতব, _bexu, דערע, xtia_, 
   {{0xe0d004d3,0x00000000,0x00000000,0x00000000}},	//   _رزه_, --, --, --, 
   {{0x7bd41bce,0xe814000d,0x00000000,0x00000000}},	//   _dexu, ड़सा_, --, --, 
   {{0x290187b7,0x63480296,0x6459aed2,0xddcc0219}},	//   ttia_, sɛng, zhvi, _tjaš, 
   {{0x29000374,0x63480085,0x99898a85,0x00000000}},	// [2eb00] utia_, pɛng, rdaş_, --, 
   {{0x2901aed3,0x7ebc02b5,0xbdd802e2,0xf8bdaed4}},	//   rtia_, _hīpa, skèt, _trén_, 
   {{0x7ebc0069,0xb87800bc,0xa2f401ad,0x7a280139}},	//   _kīpa, _svíc, _इमेज_, _qötä, 
   {{0x2901aed5,0x00000000,0x00000000,0x00000000}},	//   ptia_, --, --, --, 
   {{0x6aa5aed6,0x7bd401d4,0x645802d0,0xbcf84de4}},	//   mmif, _yexu, thvi, rzég, 
   {{0xd90c7878,0x7bd40077,0x7a28010b,0x9914010f}},	//   _سیم_, _xexu, _tötä, _פֿרױ_, 
   {{0x46a4010b,0xf5e405d9,0x386c1e54,0xa30800e5}},	//   _вавв, _چڙهي_, ègre_, ارتے_, 
   {{0x6459aed7,0xe814032c,0x7ebc00b8,0xb6740092}},	//   shvi, ड़वा_, _nīpa, ካከለኛ_, 
   {{0xc05801ce,0xd50800ec,0xc56400d8,0x6d400108}},	//   він_, _مغلن_, _ткак, ämal, 
   {{0x2450002e,0xb878032e,0xf424011c,0x5f9400db}},	//   _kàmm_, _kvía, _коул_, йипт, 
   {{0xf99c204d,0x7bd41709,0x24501574,0xb7d8008f}},	//   _abèl_, _rexu, _jàmm_, כקיי, 
   {{0x6aa402d3,0x245000e8,0xe8e00051,0x79880327}},	//   jmif, _màmm_, _luốt_, żgwi, 
   {{0x7ebc00dc,0x00000000,0x00000000,0x00000000}},	//   _dīpa, --, --, --, 
   {{0x248c0ac5,0xe8e001fb,0x3f8c0368,0x6aa56b96}},	//   _jkdm_, _nuốt_, _tyfu_, emif, 
   {{0x245000e8,0x00000000,0x00000000,0x00000000}},	//   _nàmm_, --, --, --, 
   {{0x7d180140,0x25a00118,0x60c40205,0x2dd40395}},	//   æuss, žily_, _çims, _джър, 
   {{0x9999aed8,0xb8780139,0x7bd4876a,0xe8e0004d}},	// [2eb10] укат_, _avía, _texu, _buốt_, 
   {{0xbb54037e,0x2abc032e,0xd7c800f2,0x6aa58dd1}},	//   _vncサ_, _fíb_, اوضه_, amif, 
   {{0x37a9aed9,0x2450002e,0xbcf801ed,0xf8bc0051}},	//   ттан_, _càmm_, széd, _tréo_, 
   {{0x569400c9,0x00000000,0x00000000,0x00000000}},	//   щает, --, --, --, 
   {{0xf8bc1a09,0xe7f00c2e,0xe570bf4e,0x2c044668}},	//   _krém_, _चाचा_, وطه_, श्वं_, 
   {{0x00d00116,0x00000000,0x00000000,0x00000000}},	//   ﯟﻩﺗﺘ, --, --, --, 
   {{0x764400e5,0x00000000,0x00000000,0x00000000}},	//   _پیشِ_, --, --, --, 
   {{0xeb780302,0x32c008a9,0xc1e40014,0x00000000}},	//   יעוץ_, _nıye_, ٕکول_, --, 
   {{0x0fd98bed,0x7ebc00b0,0x75806646,0x00000000}},	//   льны_, _rīpa, _بیشم, --, 
   {{0x6d40014a,0x6f600131,0xe8e00051,0x00000000}},	//   ämam, يۇشم, _xuốt_, --, 
   {{0x0ea8034b,0x7ebc00b8,0x00000000,0x00000000}},	//   лкой_, _pīpa, --, --, 
   {{0x623440c2,0x62840960,0x00000000,0x00000000}},	//   _меху, čioc, --, --, 
   {{0xd009aeda,0xf080004b,0x32c00790,0x4ea400c7}},	//   _беле_, _ویبپ, _dıye_, ирҭа, 
   {{0xfbc028eb,0x00000000,0x00000000,0x00000000}},	//   збро, --, --, --, 
   {{0x7ebc0053,0x00000000,0x00000000,0x00000000}},	//   _tīpa, --, --, --, 
   {{0xc3300302,0xe8e00016,0x6d4003b2,0x00000000}},	//   הול_, _suốt_, ømas, --, 
   {{0xe8140c2e,0x24500694,0x48086bb6,0xb3600023}},	// [2eb20] ड़ला_, _sàmm_, леан_, ስያዉን_, 
   {{0x6aa4000d,0xf8ac01e2,0x00000000,0x00000000}},	//   smif, ېکې_, --, --, 
   {{0x46e9aedb,0xe8e001fb,0x2b50054e,0x6aa4005a}},	//   уден_, _vuốt_, âncă_, pmif, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd62406d5,0xe8e0004d,0x997403f5,0x00000000}},	//   تعلي, _tuốt_, _дурш, --, 
   {{0x245000e8,0xbcf80036,0x07a401c6,0x00000000}},	//   _tàmm_, lzéc, _гагн, --, 
   {{0xb7d8011a,0xf2c03d5e,0x6d400108,0x00000000}},	//   _תקלי, псын, ämaj, --, 
   {{0xbcf80036,0x2d80007c,0x30100022,0x00000000}},	//   nzéc, _oxie_, ҧдыр, --, 
   {{0xdfd006d5,0xb6a07327,0x625c0129,0x04440024}},	//   وية_, _хитл, _léog, _леан, 
   {{0x73e00276,0x466000db,0x04949cba,0x00000000}},	//   _ноуз, _بۇچق, _الطح, --, 
   {{0xbfa80b32,0x9e140845,0x1e15aedc,0xdeb412c4}},	//   ытие_, одні, омня, юбны, 
   {{0x64a400c7,0x44d4012d,0x13dc00fe,0x00000000}},	//   _уаҕа, oł_, _ঠায়, --, 
   {{0xb36002d3,0xbd68f3a6,0x00000000,0x00000000}},	//   ስያውን_, урне_, --, --, 
   {{0x998849ad,0x20180254,0x30100150,0x3b640395}},	//   tjaž_, õrid_, _ндір, бъбв, 
   {{0xf7cc0150,0x00000000,0x00000000,0x00000000}},	//   _ﺗﯘﻟﻪ, --, --, --, 
   {{0x7ebc02b5,0x9f4c00e8,0x44d4012d,0x58d401d5}},	//   _hīpo, _ñoñi_, kł_, жоат, 
   {{0x7c84457e,0xb8780a87,0xbcf801d3,0x7e6c03ac}},	// [2eb30] _гуне, _dvín, széb, micp, 
   {{0x7e6c0c8c,0x44d40034,0xbdd81497,0x00000000}},	//   licp, dł_, bjèc, --, 
   {{0x625daedd,0xb0980375,0x44d4012d,0x5bc401f9}},	//   _géog, ניבר, eł_, वडीव, 
   {{0x7ebc0618,0x7e6daede,0x79a400f3,0x00000000}},	//   _līpo, nicp, _грге, --, 
   {{0x2d8006af,0x44d4012d,0x00000000,0x00000000}},	//   _xxie_, gł_, --, --, 
   {{0x7e6c6326,0x00000000,0x00000000,0x00000000}},	//   hicp, --, --, --, 
   {{0x44d4006d,0x572419c5,0x67d5aedf,0x00000000}},	//   ał_, _بىزك, _хосу, --, 
   {{0x24500e89,0x90c44727,0x6d400108,0x00000000}},	//   _làmh_, обие, ämak, --, 
   {{0x7e6c02d0,0x00000000,0x00000000,0x00000000}},	//   dicp, --, --, --, 
   {{0xf8bc00d5,0x245001c3,0x4f080107,0x00000000}},	//   _arék_, _nàmh_, анон_, --, 
   {{0xe3b069ef,0x09b00c58,0xf8bc0036,0x2480007b}},	//   _كرم_, টুপা, _brék_, éime_, 
   {{0x7e6c03ac,0x59a81788,0x60e80162,0x00000000}},	//   gicp, कधार, ósmú, --, 
   {{0x0d99aee0,0x625c06af,0x66d00ca8,0xe1f000ae}},	//   ртны_, _déod, _kòkò, _أسم_, 
   {{0xb87805f7,0x66d00241,0x7e6c01e7,0xcae400fb}},	//   _svín, _jòkò, aicp, оғоҙ_, 
   {{0x625daee1,0x0ba80efb,0x3f6400a7,0xaf340330}},	//   _féod, شاسى_, _мишо_, _درشت, 
   {{0x49c9aee2,0x31ac1ae4,0x625ca8d8,0x66e00248}},	//   рлан_, _gözü_, _géod, _láká, 
   {{0x6e2403a2,0xbcf80036,0x8bb4007b,0x00000000}},	// [2eb40] _iaib, rzéc, _وإدا, --, 
   {{0xf99c0ffb,0x60c400d8,0x00000000,0x00000000}},	//   _mbèh_, _éime, --, --, 
   {{0x2bd02d6c,0x6e25aee3,0xb8780162,0x31ac013d}},	//   _त्या, _kaib, _tvín, _yözü_, 
   {{0xb87809f3,0x45282e91,0x00000000,0x00000000}},	//   _hvíl, ижен_, --, --, 
   {{0x6e2410c7,0xed941e38,0x69c43b38,0x29040023}},	//   _maib, _መንበር_, mcie, _ëma_, 
   {{0x68e5aee4,0x6e25aee5,0xc1d053c3,0xd4d84077}},	//   msid, _laib, सर्ग, сьці_, 
   {{0x7ebc0374,0xdddc0030,0x00000000,0x00000000}},	//   _rīpo, losť, --, --, 
   {{0x68e5aee6,0x6e25aee7,0x66d008e7,0x69c5aee8}},	//   osid, _naib, _eòkò, ncie, 
   {{0xdddc01f1,0x69c4fe38,0x15b000d1,0x00000000}},	//   nosť, icie, _كەمس, --, 
   {{0x31ac4a4a,0xf8bc003e,0x6e2401f5,0xbfa8f3a6}},	//   _sözü_, _srék_, _aaib, итне_, 
   {{0x3814025f,0x6e25aee9,0x69c5aeea,0x68e5158a}},	//   חקים_, _baib, kcie, hsid, 
   {{0x6449aeeb,0x6e25aeec,0x69c5aeed,0x99980030}},	//   _hodi, _caib, jcie, _hosť_, 
   {{0x61e1aeee,0x6e25aeef,0x41740228,0x7ebc02b1}},	//   maml, _daib, _بااس, _tīpo, 
   {{0x6449aef0,0xd14856b0,0x68e5aef1,0x61e051c8}},	//   _jodi, _دشمن_, dsid, laml, 
   {{0x6449aef2,0x68e40483,0x6e25aef3,0x31ac0724}},	//   _modi, esid, _faib, _tözü_, 
   {{0x69c40007,0x6e25aef4,0x20c00051,0x00000000}},	//   gcie, _gaib, _kòi_, --, 
   {{0x68e5aef5,0x6f000421,0xf8bc0036,0x245008c2}},	// [2eb50] gsid, _zqnc, _kréi_, _tàmh_, 
   {{0x6449aef6,0xf729aef7,0x61e1aef8,0x1a6437f7}},	//   _nodi, ицей_, haml, _کیری_, 
   {{0xe3d811ba,0x6e25aef9,0x61e1aefa,0x68e58f7e}},	//   _সাংব, _yaib, kaml, asid, 
   {{0x69c5aefb,0x6449aefc,0x61e00209,0xe3b80139}},	//   ccie, _aodi, jaml, _agı_, 
   {{0x61e1aefd,0x26d9aefe,0x68e40067,0x6e200109}},	//   daml, _ewro_, csid, ômbi, 
   {{0x6449aeff,0x6d40005b,0xba1400ec,0x47840022}},	//   _codi, ämai, _ايڏا_, цыӡб, 
   {{0x999801f1,0x62844a52,0x61e001bf,0x00000000}},	//   _dosť_, čion, faml, --, 
   {{0x20c0067c,0x61e1af00,0x6448020b,0xf8bc0124}},	//   _bòi_, gaml, _eodi, _aréi_, 
   {{0x6e2406d5,0x66d00086,0xb4000220,0x51541378}},	//   _raib, _tòkò, _жүлд, ятку, 
   {{0x69c40399,0x6e25af01,0xe0640133,0x20c00208}},	//   zcie, _saib, وێنی, _dòi_, 
   {{0x6e244414,0x69c4068f,0x7658020c,0xf8bc01c7}},	//   _paib, ycie, _kluy, _dréi_, 
   {{0x68e5af02,0x622404a9,0x61e1af03,0x69c40007}},	//   ysid, _يىلل, caml, xcie, 
   {{0x6e25af04,0xf8bc0221,0x64480efc,0x20c00208}},	//   _vaib, _fréi_, _yodi, _gòi_, 
   {{0x644807d6,0x6e25af05,0x68e42f62,0x76580784}},	//   _xodi, _waib, vsid, _lluy, 
   {{0x7659af06,0x6e25af07,0x00000000,0x00000000}},	//   _oluy, _taib, --, --, 
   {{0x68e5af08,0x69c400da,0x08c44942,0xf734001f}},	//   tsid, ucie, збан, _የሚያን, 
   {{0x69c5af09,0x38c9af0a,0x68e4067c,0xc96402e8}},	// [2eb60] rcie, مالی_, usid, чвай, 
   {{0x68e41455,0x7659af0b,0x61e1af0c,0xbdd80066}},	//   rsid, _aluy, zaml, njèn, 
   {{0x3bb80302,0xf99c02e2,0x61e05628,0x87083cc5}},	//   _למיד, _ezè_, yaml, сеев_, 
   {{0x69c40007,0x61e0009a,0xe3d80154,0x00000000}},	//   qcie, xaml, _সাইব, --, 
   {{0x61e01d89,0x68e4022e,0x00000000,0x00000000}},	//   vaml, qsid, --, --, 
   {{0x6448a617,0x26d8016b,0x20c00208,0x32c00166}},	//   _qodi, _twro_, _ròi_, _sıya_, 
   {{0x76580407,0x20c0067c,0x61e1af0d,0x02680c9e}},	//   _fluy, _sòi_, taml, йший_, 
   {{0x7658020c,0x64480134,0x32c00139,0xaf380023}},	//   _gluy, _wodi, _qıya_, _ክመላለ, 
   {{0x6449af0e,0x45d4008e,0xedc400eb,0x00000000}},	//   _todi, _моңс, ্ণাঢ, --, 
   {{0x20c001fb,0xbcf80036,0xf990008f,0xdbf000bc}},	//   _vòi_, fzén, ערז_, tříd, 
   {{0x32c0013d,0xd9a84f3c,0x00000000,0x00000000}},	//   _tıya_, _कण्ट, --, --, 
   {{0x61e1af0f,0x20c1af10,0xab64012d,0x81440137}},	//   qaml, _tòi_, ążli, _ىنان, 
   {{0x20c00561,0xb87803b2,0x2a607bcb,0x8f540023}},	//   _uòi_, _svím, dhib_, ምልከቶ, 
   {{0xa320012c,0x00000000,0x00000000,0x00000000}},	//   _मनाङ_, --, --, --, 
   {{0x625c0129,0xf7d001ec,0xdecc0023,0xfec801c8}},	//   _géoc, _ﺟﯘﻟﺪ, ኣለኒ_, _ابتو_, 
   {{0x58d81ab7,0x2f940375,0xaab402dd,0x2a600455}},	//   ждая_, _מכון_, ейсі, ghib_, 
   {{0x0f500023,0x00000000,0x00000000,0x00000000}},	// [2eb70] _ዝመሰረ, --, --, --, 
   {{0x76580549,0xb8781d1d,0x37a800db,0x00000000}},	//   _sluy, _tvím, бтен_, --, 
   {{0x1a6401b9,0xccb000c7,0x00000000,0x00000000}},	//   _قیسی_, _шәџь, --, --, 
   {{0x2a61af11,0xd0240011,0xdecc0023,0xf9b400ec}},	//   chib_, বায়_, ኣለና_, _رچرڊ_, 
   {{0x298400c7,0x7658002f,0x8d6c0092,0x00000000}},	//   _зырг, _vluy, _አንተው_, --, 
   {{0x6348016b,0x7bc555cb,0x00000000,0x00000000}},	//   rɛnn, ncju, --, --, 
   {{0xf8bc0129,0x7ae403cd,0xc444036b,0x248000c7}},	//   _hué_, nsjt, بیلن_, éima_, 
   {{0xf8bdaf12,0x00000000,0x00000000,0x00000000}},	//   _kué_, --, --, --, 
   {{0x6fa400f1,0x00000000,0x00000000,0x00000000}},	//   ګندې_, --, --, --, 
   {{0xb95801e1,0xa528031c,0x8ee9af13,0x2a600367}},	//   _afìk, _རླིག_, омов_, zhib_, 
   {{0x25c4143a,0x00000000,0x00000000,0x00000000}},	//   _åslå_, --, --, --, 
   {{0x2a61a59a,0x69c80134,0xb63c00b5,0xf8bc06af}},	//   xhib_, _ɑdes, _ａｒ_, _oué_, 
   {{0x2d85af14,0x2fc4020c,0xbcf801d3,0x00000000}},	//   çme_, _tfng_, szén, --, 
   {{0xab78001f,0x4fc004b3,0x81a000db,0x00000000}},	//   _የቆየው_, _جەدە, _جڭىل, --, 
   {{0xf8bc180f,0x92201b76,0x2a600332,0x00000000}},	//   _aué_, _मसाज_, thib_, --, 
   {{0xfaa00dab,0x3ab00166,0x00000000,0x00000000}},	//   васо, кәят, --, --, 
   {{0xf8bd5dc5,0x5fc400bc,0x12e00046,0xc8c80472}},	// [2eb80] _cué_, लुकल, _ﺍﻹﻴﺭ, زوان_, 
   {{0x2a60006c,0x00000000,0x00000000,0x00000000}},	//   shib_, --, --, --, 
   {{0xc60402d5,0xb87801ef,0x00000000,0x00000000}},	//   дзей, _zvík, --, --, 
   {{0xf8bc2760,0x75d086bf,0x00000000,0x00000000}},	//   _fué_, نيما, --, --, 
   {{0xf8bc7c6e,0x32c000a2,0x068001ec,0x00000000}},	//   _gué_, _añy_, _ﯨﺸﻜﯩ, --, 
   {{0x62840024,0x00000000,0x00000000,0x00000000}},	//   čiom, --, --, --, 
   {{0x38c007dd,0x32c00205,0xac3c0023,0x00000000}},	//   _térã_, _dıyo_, _ኣገዳሲ, --, 
   {{0x721400a7,0x00000000,0x00000000,0x00000000}},	//   джър_, --, --, --, 
   {{0xf50006bb,0x8504451a,0x84051d0b,0x00000000}},	//   _изто, _زوان, _опаж, --, 
   {{0xf8bc0129,0x32c00139,0x1dd0012d,0xb87802d2}},	//   _usée_, _kıyl_, थुनत, _rvík, 
   {{0xe8100574,0x9f5805d5,0x6458007c,0xb879af15}},	//   ठ्या_, ürà_, mkvi, _dvíh, 
   {{0x2d8c0205,0x00000000,0x00000000,0x00000000}},	//   ğden_, --, --, --, 
   {{0xa37c0115,0xed580953,0x00000000,0x00000000}},	//   _deĵe, доў_, --, --, 
   {{0x645800c8,0x7ebc00ef,0x00000000,0x00000000}},	//   nkvi, _līpi, --, --, 
   {{0xf8bc0098,0x6ff8011a,0x9f6401e1,0x7bc40210}},	//   _sué_, _והופ, _àtàn_, rcju, 
   {{0x7ae4005c,0xb8782507,0xade400d4,0x00000000}},	//   rsjt, _tvík, _ицьк, --, 
   {{0xf8bdaf16,0x09d402a6,0x2bd00882,0x6459af17}},	// [2eb90] _qué_, তৃভা, _त्वा, kkvi, 
   {{0x7ac5af18,0xb8f4007d,0xdef00092,0x67d40107}},	//   _осме, _सऽ_, _ሁሴን_, вофу, 
   {{0x8bd4025f,0x62840006,0xac740150,0xfde0033f}},	//   _אותו_, čioj, _جايش, _ख़ास_, 
   {{0xf8bc9027,0x645801f5,0x8af8011a,0x068400d1}},	//   _tué_, ekvi, _צהרי, ﻫﺎﻳﯩ, 
   {{0xe4c824e0,0xe50400c6,0x7ebc00cd,0x00000000}},	//   وبون_, نبوي, _dīpi, --, 
   {{0xbf1c01f9,0x2de40220,0x53a400cf,0x00000000}},	//   _बनून_, _ﻋﯩﻠﻤ, налб, --, 
   {{0x32c00166,0xc6040154,0xbdd8007f,0x00000000}},	//   _gıyl_, োয়া_, tjèl, --, 
   {{0xe8100406,0xf8bc01c7,0xe2a800ec,0x00000000}},	//   ठ्ठा_, _frét_, واين_, --, 
   {{0xa37c01e4,0xf8bd306f,0x7ebc00c0,0x00000000}},	//   _reĵe, _irés_, _lūpd, --, 
   {{0x6459af19,0x25380055,0x00000000,0x00000000}},	//   ckvi, _āmṛṣ, --, --, 
   {{0xbcf8066d,0x91b80b8d,0x32c00139,0x4f7802e8}},	//   szél, _егет_, _kıym_, ящия_, 
   {{0x625c0098,0xe1f0015e,0x00000000,0x00000000}},	//   _héon, _نسه_, --, --, 
   {{0x9db9af1a,0x625c003e,0x32c00139,0x12e00150}},	//   дыру_, _kéon, _mıym_, _ﺍﻹﻀﺭ, 
   {{0xc4d00375,0x8b24033a,0x1c380108,0x00000000}},	//   רגם_, ндге, мясь_, --, 
   {{0x625c0c6a,0x6348016b,0x00000000,0x00000000}},	//   _méon, yɛnm, --, --, 
   {{0x2bd03abc,0x625c14a9,0x1e9400c7,0x4fc01c3e}},	//   _त्रा, _léon, _ирыр, _جەگە, 
   {{0x7ebc00b0,0xbd3000db,0xcf24009f,0x00000000}},	// [2eba0] _rīpi, _مىيع, _آرڻي, --, 
   {{0x625c004a,0x4ab8084c,0x4b2412fa,0xad6801f0}},	//   _néon, _нумя_, _змов, _нақз_, 
   {{0x7ebc0383,0x26dc00e4,0xd6d80150,0x00000000}},	//   _pīpi, èvo_, дті_, --, 
   {{0xc695af1b,0xbb60037e,0x00000000,0x00000000}},	//   رشاع, _forウ_, --, --, 
   {{0x0e3c0023,0x00000000,0x00000000,0x00000000}},	//   _ይኹንም, --, --, --, 
   {{0x7ebc02b1,0x78a40ffb,0xf8bc01e1,0x37e000cc}},	//   _hūpe, _ghjv, _erés_, _পাথৰ, 
   {{0xdb0c006a,0x625c004a,0xfbd0011a,0x7ebc00ef}},	//   _âkôl, _déon, נתה_, _kūpe, 
   {{0x6459af1c,0xf8bdaf1d,0xf99c01e1,0xa19400ee}},	//   skvi, _trét_, _gbès_, кайч, 
   {{0xc4843752,0x64582b96,0xb87802d2,0x00000000}},	//   _злак, pkvi, _svíi, --, 
   {{0x64580175,0x00000000,0x00000000,0x00000000}},	//   qkvi, --, --, --, 
   {{0x1df94d30,0x82a401f4,0x00000000,0x00000000}},	//   мены_, _зажж, --, --, 
   {{0x7ebd4345,0xc0b80092,0x00000000,0x00000000}},	//   _nūpe, ተምር_, --, --, 
   {{0x625c003e,0xc0585b97,0xa320813f,0x7cb400d1}},	//   _héoo, _нік_, _मनुज_, нқит_, 
   {{0xb878032e,0x20980139,0x00000000,0x00000000}},	//   _hvív, _юклы_, --, --, 
   {{0xfaa4cef8,0x6280b594,0xb87806ea,0xbdd800f2}},	//   ешан, onmo, _kvív, njèk, 
   {{0x6281af1e,0x5ea401d5,0x1d344fac,0xbcf801d3}},	//   nnmo, _جمعل, _ания, nzék, 
   {{0x6280017a,0xefb802d3,0x999892b0,0x00000000}},	// [2ebb0] inmo, ተልዩ_, фкат_, --, 
   {{0x37a802de,0x628003fa,0x7ebc0064,0x7c64f9dc}},	//   птен_, hnmo, _tūpd, _ساخل, 
   {{0x9b600075,0xf8bdaf1f,0x5ac80244,0x00000000}},	//   _ئۆزۈ, _prés_, _تاخێ_, --, 
   {{0x62800d27,0xb3cc0183,0x1958004e,0x758c0240}},	//   jnmo, _ৰাইজ, _жамы_, _ክሓልፎ_, 
   {{0x3a28011c,0xe5340212,0x3eb8036e,0xa6140124}},	//   _iacp_, лець, _miqt_, ыҷтә, 
   {{0x628001f5,0x2ba81431,0x00000000,0x00000000}},	//   enmo, _गरमा, --, --, 
   {{0xf8bc07ea,0xe784667a,0xf6740131,0x53900023}},	//   _trés_, _буто, _كارخ, _ምዕዋት_, 
   {{0x6b5c01b8,0x628002d2,0x00000000,0x00000000}},	//   lägö, gnmo, --, --, 
   {{0x4ebc03d4,0xc2403e1f,0x00000000,0x00000000}},	//   _আবেল, рнык, --, --, 
   {{0x628107f4,0x05980014,0xb4b0013d,0xf3640108}},	//   anmo, _غمٕک_, _сизә, _птен, 
   {{0x2608038e,0x41d0007a,0x2d8c0790,0x00000000}},	//   _हामी_, _ध्वस, ğdem_, --, 
   {{0x3a28009f,0x00000000,0x00000000,0x00000000}},	//   _nacp_, --, --, --, 
   {{0x7ebd044e,0xd0080640,0xbcf801d3,0xe7e400bc}},	//   _rūpe, _желе_, nzéh, गरमा_, 
   {{0x7ebc002d,0x321c0c6a,0x3f8003e0,0x00000000}},	//   _sūpe, leuy_, ğkur_, --, 
   {{0x09e5af20,0x7ebc00b0,0x3b05af21,0x6ac80022}},	//   ковн, _pūpe, керо_, _ẽmbá, 
   {{0xc3300302,0x24500de2,0x625da875,0x8e74013d}},	//   סון_, _làmp_, _néol, _шулч, 
   {{0x48e40138,0x8da801d5,0xb9b000ae,0x00000000}},	// [2ebc0] тозв, _ювиб_, لمفع, --, 
   {{0x7d540a1e,0x245000e8,0x321c0c6a,0x7860337e}},	//   _סייד_, _nàmp_, heuy_, акуз, 
   {{0x625c030a,0x7ebc02b1,0x6348013f,0x4aa8023a}},	//   _béol, _tūpe, rɛnk, _окон_, 
   {{0xdb0c02d2,0x00000000,0x00000000,0x00000000}},	//   _íhát, --, --, --, 
   {{0xbf1cd9e5,0x321c0098,0x32c00139,0x066401d5}},	//   _बन्न_, deuy_, _fıyk_, _یارپ, 
   {{0x2901af22,0x62806e16,0xb878032e,0x63e4215c}},	//   muia_, wnmo, _svív, اۋال, 
   {{0x9378069c,0x290018a6,0x3a280142,0x00000000}},	//   _እንከሎ_, luia_, _yacp_, --, 
   {{0x625d3669,0x321c00d5,0x96941a5c,0x00000000}},	//   _géol, geuy_, _бруш, --, 
   {{0x2901af23,0x6280049f,0xe2980184,0xbcf801d3}},	//   nuia_, rnmo, маҫ_, rzék, 
   {{0x29001d50,0xadc40241,0xbcf801d3,0x00000000}},	//   iuia_, _ijẹw, szék, --, 
   {{0x29011339,0x443daf24,0x02045e0c,0xb87808ce}},	//   huia_, _int_, _азен, _tvív, 
   {{0xb87805a4,0x290018a6,0x321c0098,0xbcf80036}},	//   _hvít, kuia_, ceuy_, lzéi, 
   {{0xb878013a,0x00000000,0x00000000,0x00000000}},	//   _kvít, --, --, --, 
   {{0x3a29af25,0x442daf26,0xbcf80221,0x443c0072}},	//   _sacp_, ndf_, nzéi, _jnt_, 
   {{0xa320033d,0x443daf27,0x2fe401ec,0x2bb80073}},	//   _मनोज_, _mnt_, _شىيپ_, _आणणा, 
   {{0xb110063f,0x443c005f,0x7ebc00dc,0xbcf80036}},	//   _mụnw, _lnt_, _dīpt, hzéi, 
   {{0x443daf28,0x2901af29,0xbcf80036,0xa9545074}},	// [2ebd0] _ont_, guia_, kzéi, акті, 
   {{0x443daf2a,0x442c0789,0x37e003d4,0x693401c6}},	//   _nnt_, jdf_, _পাহৰ, шнуу, 
   {{0x7ebc0053,0x442c00a9,0x7d0da793,0xcc38008f}},	//   _tīpu, ddf_, ltcs, _װערט, 
   {{0x443daf2b,0x2901af2c,0x2450002e,0x2bb801f9}},	//   _ant_, buia_, _sàmp_, _आणता, 
   {{0x443c0cf9,0x937802d3,0x2900054e,0xbcf80036}},	//   _bnt_, _እንኮሎ_, cuia_, fzéi, 
   {{0x443daf2d,0x26082871,0x67d4220f,0x25a000d8}},	//   _cnt_, _हाथी_, _вору, üila_, 
   {{0x443daf2e,0xddcc0115,0x625c00f2,0x321c00d5}},	//   _dnt_, _amaŭ, _téol, teuy_, 
   {{0xb8780077,0x5694016c,0xe3b00fb4,0x6ba000a2}},	//   _evít, _сабт, آره_, _ýygş, 
   {{0x321c3386,0x625d738d,0x26080490,0x442c0175}},	//   reuy_, _géom, _हाती_, bdf_, 
   {{0x443daf2f,0xc9500375,0x442c0142,0x00000000}},	//   _gnt_, צמי_, cdf_, --, 
   {{0x290005d9,0x8ff8034c,0xdd1c01e1,0xb878032e}},	//   zuia_, ورگر_, _láńr, _hvís, 
   {{0x76480399,0xb879af30,0x23c80241,0x00000000}},	//   njgy, _zvít, _tìjó_, --, 
   {{0x443c05d1,0xc6900a7c,0x00000000,0x00000000}},	//   _ynt_, מאט_, --, --, 
   {{0xd008405c,0x2900030a,0x7ebc0171,0x00000000}},	//   _чеке_, vuia_, _cīps, --, 
   {{0xd1f8001f,0x62840153,0xd1d40092,0x00000000}},	//   _ለቤተ_, čiov, _ከቤተ_, --, 
   {{0x2901af31,0x3ed00150,0x8d747b1d,0x00000000}},	//   tuia_, _اقير, _ماخا, --, 
   {{0x38600a2e,0x888428e8,0x9f5800e4,0x00000000}},	// [2ebe0] _bljr_, глаж, ýrö_, --, 
   {{0x2901af32,0x7ebc00b0,0x63480085,0x2bd02232}},	//   ruia_, _hūpa, sɛni, तुशा, 
   {{0xb879af33,0x7ebc3e16,0x29001140,0x00000000}},	//   _avís, _kūpa, suia_, --, 
   {{0xb878012c,0x76480369,0x443c023a,0x2900eaca}},	//   _svít, gjgy, _snt_, puia_, 
   {{0x2901af34,0x68440a81,0xbcf804e6,0x495401af}},	//   quia_, _پێال, tzéi, _сњнђ, 
   {{0x443daf35,0x7ebc3d4f,0x00000000,0x00000000}},	//   _qnt_, _lūpa, --, --, 
   {{0x442c581e,0xa65404d3,0x443c0006,0xddcc0115}},	//   rdf_, _پێشت, _vnt_, _smaŭ, 
   {{0x82a40b32,0xbcf934a7,0xaab413e0,0x443c0f85}},	//   ышле, széi, ंगिक, _wnt_, 
   {{0x443c5182,0xb87801a8,0xddcc2ac2,0x00000000}},	//   _tnt_, _tvít, _alaş, --, 
   {{0x443daf36,0x351802e4,0xb87813d5,0x1f140006}},	//   _unt_, _אומנ, _uvít, амоў, 
   {{0xd34404d3,0x00000000,0x00000000,0x00000000}},	//   _نیوه_, --, --, --, 
   {{0x5275af37,0xceac05d9,0xdb14012d,0xc0e401f0}},	//   _кучу, وڙي_, zczó, _бодк, 
   {{0x625c003e,0x6e200254,0x00000000,0x00000000}},	//   _léok, õmba, --, --, 
   {{0xdfd4008e,0xddcc0b97,0x2bd004e4,0x03e00051}},	//   _токы, _flaş, तुला, _đuờn, 
   {{0x3098025f,0x7ebc002b,0x00000000,0x00000000}},	//   _רשומ, _vīps, --, --, 
   {{0x945406c8,0x9f5800e4,0x00000000,0x00000000}},	//   _nīn, ýrõ_, --, --, 
   {{0x987475f1,0x28f811ed,0x6e884fca,0x2aa81fbe}},	// [2ebf0] алац, леть_, _حنيف_, утро_, 
   {{0xb764a5de,0xddcc03e0,0x00000000,0x00000000}},	//   лтей, _ylaş, --, --, 
   {{0xeab001d3,0x947400f2,0xdd900633,0x00000000}},	//   زعہ_, یدتا, _دوک_, --, 
   {{0x998800c8,0x625c0c6a,0x5694034b,0x81c000de}},	//   ldaŭ_, _déok, шает, šējo, 
   {{0x1545af38,0xf1bc00bc,0x00000000,0x00000000}},	//   релм, žák_, --, --, 
   {{0x2d840086,0xf99c0248,0xb8c401e0,0x00000000}},	//   ûmei_, _iyè_, _аҫҡа_, --, 
   {{0xa37c010f,0x00000000,0x00000000,0x00000000}},	//   _deĵo, --, --, --, 
   {{0xddcc00a2,0xb8780321,0xe7840798,0x00000000}},	//   _rlaş, _tvís, _ѓуро, --, 
   {{0xe665190c,0xd4b800c7,0x758801ca,0x00000000}},	//   _утро, _алац_, _чсвв_, --, 
   {{0x7ebc0a28,0xf99c007f,0x09b0009e,0xf4100451}},	//   _rūpa, _myè_, টুকা, _دؤر_, 
   {{0x8fa44d6b,0x33840276,0x7ebc002b,0x8e740b24}},	//   ране, _суав, _sūpa, لاحض, 
   {{0x7ebc02b5,0xddcc0356,0x73300145,0xf99c0cad}},	//   _pūpa, _vlaş, _پىچا, _oyè_, 
   {{0xf8bc0066,0xf99c007f,0x62840024,0xef9400fd}},	//   _asém_, _nyè_, čiot, _өйдә_, 
   {{0xdde400e2,0xddcc0166,0x00000000,0x00000000}},	//   āpša, _tlaş, --, --, 
   {{0xddcc0ab7,0xf99c02e2,0x7f5400f3,0x9f5800e4}},	//   _ulaş, _ayè_, _вајс_, ýrô_, 
   {{0x97402295,0x7ebc3b37,0xf99c02e2,0x3b040261}},	//   _የሚያስ, _tūpa, _byè_, јето_, 
  
   {{0x38c80f00,0x1ea8e77c,0x48085ea0,0x00000000}},	// [2ec00] نالی_, _حاوي_, кеан_, --, 
   {{0x26080073,0xb878013a,0x00000000,0x00000000}},	//   _हाही_, _svír, --, --, 
   {{0xc7246f32,0x32c0013d,0xcb680063,0x87b8084c}},	//   рдей, _kıyu_, _ране_, туат_, 
   {{0x625c003e,0xf99c033b,0x25a00798,0xa264001f}},	//   _géoh, _fyè_, üilo_, ቻችንን_, 
   {{0xe5345238,0xa3d40408,0xda1400f2,0xbcf800e5}},	//   сель, болч, _اسپک, szév, 
   {{0x88340323,0x2d78001f,0x60c401e7,0x26082982}},	//   _тэмц, _አንስቶ_, _éimi, _हावी_, 
   {{0xf2c048a0,0x2481354e,0xb66c01e1,0xb878032e}},	//   осын, đim_, _kẹ̀y, _tvír, 
   {{0xddcc110c,0x133801d3,0x160c3885,0xfbb4011a}},	//   _omaš, اتوں_, _हायर_, ספקת_, 
   {{0xb6b8011a,0x00000000,0x00000000,0x00000000}},	//   _יצלי, --, --, --, 
   {{0x2019af39,0xbdd80268,0x818801d5,0x87a807f7}},	//   ýri_, hjèt, _یناق_, _कराऊ, 
   {{0xb80838d2,0xf83402e4,0x2a601bce,0x5e580126}},	//   स्टम_, בנית_, kkib_, гиня_, 
   {{0x32c000fd,0x62840024,0xc0500023,0x6d4001e4}},	//   _cıyu_, čios, _ዝፈላል, ĥman, 
   {{0xd294210e,0x00000000,0x00000000,0x00000000}},	//   _اُنک, --, --, --, 
   {{0xb8780241,0x00000000,0x00000000,0x00000000}},	//   _awín, --, --, --, 
   {{0xf99c007f,0xdb040042,0xfee401d5,0x9f040b24}},	//   _syè_, _nghô, _тўлм, _اوعو, 
   {{0xf99c0699,0x00000000,0x00000000,0x00000000}},	//   _pyè_, --, --, --, 
   {{0x7ebc02b5,0x6935af3a,0xf1b0010f,0x00000000}},	// [2ec10] _hūpo, онту, ַסע_, --, 
   {{0x7ebc166a,0x00000000,0x00000000,0x00000000}},	//   _kūpo, --, --, --, 
   {{0x2904007c,0x00000000,0x00000000,0x00000000}},	//   _åman_, --, --, --, 
   {{0xf99c02e2,0x00000000,0x00000000,0x00000000}},	//   _tyè_, --, --, --, 
   {{0x26080c2e,0xf5240104,0x38ac05d5,0x298400c7}},	//   _हारी_, рфен, jürg_, _дырг, 
   {{0xbcf801ed,0x80d8012d,0x94240150,0x986401f7}},	//   lzés, पीछे, смке, _اُسه, 
   {{0x7ebc005f,0x6348013f,0xb60407e6,0xf6440408}},	//   _rūpn, dɛns, _вязк, _кхан, 
   {{0x942406be,0x787001c8,0x00000000,0x00000000}},	//   _ətər_, _اُڀا, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7538152d,0xb11002e3,0x00000000,0x00000000}},	//   _iruz, _hụkw, --, --, 
   {{0x20540801,0x7539af3b,0xbcf801ed,0x52140d1d}},	//   ютър, _hruz, zzét, _гдет, 
   {{0x6ed00311,0x32c0013d,0x2dc801d5,0x867800df}},	//   _răbd, _qıyu_, шқин_, ָרשו, 
   {{0x2174023b,0x50b40022,0x8fd004b4,0x00000000}},	//   _мушр, _лску, _нәнә, --, 
   {{0xc0b00016,0xc0b8001f,0xc578008f,0x8e8411e6}},	//   _mười_, ዲቻል_, אָלט, _گلبه, 
   {{0xcaa40597,0xf8bc020c,0xc0b001fb,0x260800af}},	//   مصري, _iséh_, _lười_, _हाली_, 
   {{0x75382625,0xbcf801ed,0xd7bc0073,0x00000000}},	//   _oruz, gzés, ्खनच, --, 
   {{0xddcc28b5,0x2a61af3c,0x38ac06be,0x89a8003b}},	// [2ec20] _umaš, rkib_, kürd_, укав_, 
   {{0x69c8013f,0x2a60037e,0x60c4068c,0xca700014}},	//   _ɑdey, skib_, _èime, _کۆرک, 
   {{0xb1100521,0x7539af3d,0xeb3400db,0x6c6801d3}},	//   _bụkw, _aruz, _بۉزد, _ملکہ_, 
   {{0x7539af3e,0x63a40118,0x00000000,0x00000000}},	//   _bruz, řink, --, --, 
   {{0x89340f11,0xc0b007ae,0x6aa40254,0x46a401a9}},	//   _اعجا, _cười_, mlif, _ҳавв, 
   {{0x6aa5af3f,0x00000000,0x00000000,0x00000000}},	//   llif, --, --, --, 
   {{0xf99c00f2,0x7539af40,0xf4840a98,0x7f38001f}},	//   _acèh_, _eruz, حانی, _ሥራዎች, 
   {{0x2901af41,0x7539af42,0x6aa5af43,0xb110063f}},	//   oria_, _fruz, nlif, _gụkw, 
   {{0xc058d2f5,0x7539af44,0x26d805c7,0x6348013f}},	//   гін_, _gruz, _htro_, tɛns, 
   {{0x290179ba,0xb4600276,0x6aa40e78,0x6d400115}},	//   iria_, _екул, hlif, ĥmal, 
   {{0x6aa5a1d5,0x6348013f,0x290001f4,0xdcfc0205}},	//   klif, rɛns, hria_, _ıyıc, 
   {{0x9f4c036e,0x00000000,0x00000000,0x00000000}},	//   ladë_, --, --, --, 
   {{0x6aa5af45,0x2901252a,0x00000000,0x00000000}},	//   dlif, jria_, --, --, 
   {{0x26d9af46,0x2901af47,0x7ebc04fe,0x6aa51b1a}},	//   _otro_, dria_, _tūpo, elif, 
   {{0x201c0810,0x30780375,0x00000000,0x00000000}},	//   _ibvi_, _תאונ, --, --, 
   {{0x6aa5af48,0x2901af49,0xf8bc00c7,0x00000000}},	//   glif, fria_, _iséi_, --, 
   {{0x2901af4a,0xbcf800dd,0xb11001f2,0x26d80393}},	// [2ec30] gria_, rzés, _rụkw, _atro_, 
   {{0x75380240,0x79a400c7,0x9f4c0200,0xc0b00051}},	//   _rruz, арҷе, jadë_, _rười_, 
   {{0xb110063f,0x37a9af4b,0xbcf801ed,0x6aa402f0}},	//   _pụkw, утан_, pzés, blif, 
   {{0x753808a4,0x1a65683d,0x7c2400b5,0x80dc015b}},	//   _pruz, _بیری_, lejr, _মিন্, 
   {{0x2900003a,0x2bd00a94,0x201c00db,0xbcf801d3}},	//   cria_, तुका, _obvi_, lyéb, 
   {{0xf7702088,0xf99c0100,0x629c02b1,0x75380165}},	//   _فاز_, _obèz_, _ūrop, _vruz, 
   {{0xb11002e3,0xbcf801d3,0xfdf837bb,0x76800142}},	//   _tụkw, nyéb, ्लास_, tŵyd, 
   {{0x7538011c,0x6b7c04ae,0x9f4c007f,0x7c2401bf}},	//   _truz, טרונ, madè_, hejr, 
   {{0x7538015c,0xfe7c004e,0x7e88033f,0x26d80010}},	//   _uruz, diï_, tępn, _ztro_, 
   {{0x6aa5af4c,0x78b40175,0x505802e8,0x00000000}},	//   zlif, nmxv, ршия_, --, 
   {{0x6aa5af4d,0x7c25af4e,0xf3640209,0xce480114}},	//   ylif, dejr, _утан, азне_, 
   {{0x6aa4eeb6,0x2901af4f,0x9988009b,0x550c07f7}},	//   xlif, yria_, zdaš_, _समाए_, 
   {{0x7c2401bf,0x00000000,0x00000000,0x00000000}},	//   fejr, --, --, --, 
   {{0x6aa404ce,0x7c247dec,0x2901af50,0x32c00139}},	//   wlif, gejr, vria_, _gıyr_, 
   {{0xbcf801ed,0x68000241,0xf8bc02f0,0x06dc0011}},	//   gyéb, _lájà, _fréz_, _ডিভি, 
   {{0x2901af51,0xfe7c311a,0x37bc0154,0x6aa40332}},	//   tria_, ciï_, ইডার, ulif, 
   {{0x87d9af52,0x6aa5af53,0x2901af54,0xbcf800dd}},	// [2ec40] لباس_, rlif, uria_, szér, 
   {{0x2900152d,0x041c009e,0x88040472,0x00000000}},	//   rria_, _যোনী_, تظرم, --, 
   {{0xa3180c2e,0x46f4e99a,0x6aa5af55,0x998801a6}},	//   _दहेज_, ючат, plif, rdaš_, 
   {{0x2901af56,0x26cc0066,0x00000000,0x00000000}},	//   pria_, _édom_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xcb1c146c,0x9f4c02e2,0x38adaf57,0x00000000}},	//   _पहाड_, badè_, türe_, --, 
   {{0x26d9af58,0x9f4c0240,0x026801b9,0x4e0800bc}},	//   _utro_, radë_, иший_, वलाई_, 
   {{0x41e4063b,0xf99c007f,0x7c25af59,0xc64400cf}},	//   ціка, _abèy_, zejr, _بئسى, 
   {{0x26c401e2,0xf8ac00dd,0x9f4c00db,0xfe7c00cf}},	//   _iimo_, _سکے_, madé_, viï_, 
   {{0x26c5af5a,0x625c06af,0x7e880210,0x2608012d}},	//   _himo_, _réou, tępo, हलवी_, 
   {{0x7c24005c,0x625c0129,0x82a401a9,0x9e340108}},	//   vejr, _séou, _дажж, пенч, 
   {{0x935831ee,0x26c4dcc5,0x8145af5b,0xdd958d7d}},	//   _уруу_, _jimo_, _ونان, замы, 
   {{0x43940588,0x5d840aaa,0xcbe00154,0x00000000}},	//   _уаҧс, سلسل, _বাড়ছ, --, 
   {{0x26c5af5c,0x6281af5d,0xec698971,0x9f4c0c6a}},	//   _limo_, limo, орск_, hadé_, 
   {{0x7c25af5e,0x26c40124,0x9f4c4a16,0xf8bc00e4}},	//   rejr, _oimo_, kadé_, _uséi_, 
   {{0x26c4c267,0x7c2400b5,0x625c2dfb,0xee784fca}},	//   _nimo_, sejr, _géot, _وصيت_, 
   {{0xefb80092,0x00000000,0x00000000,0x00000000}},	// [2ec50] ዲያው_, --, --, --, 
   {{0x6281af5f,0x24d802a6,0x200daf60,0x26c5af61}},	//   himo, _সিংহ, ngdi_, _aimo_, 
   {{0x26c5af62,0x7ebc0171,0x00000000,0x00000000}},	//   _bimo_, _rūpj, --, --, 
   {{0x6281af63,0x26c5af64,0xaee00055,0x9f4c0100}},	//   jimo, _cimo_, _avṛh, radè_, 
   {{0x6281af65,0x26c5af66,0x625c003e,0x9f4c033b}},	//   dimo, _dimo_, _léos, sadè_, 
   {{0x628001f5,0x69c001e7,0x00000000,0x00000000}},	//   eimo, _úmea, --, --, 
   {{0x6281af67,0xe7840114,0x9f4daf68,0x00000000}},	//   fimo, _жуто, badé_, --, 
   {{0x26c5af69,0x82240327,0x00000000,0x00000000}},	//   _gimo_, _རྒྱི_, --, --, 
   {{0x7af40175,0x2ba8012c,0xf8bc0129,0xe3b1af6a}},	//   _lvxt, _गर्थ, _epée_, _یرم_, 
   {{0xe5c5af6b,0x26c5af6c,0x628194f2,0xd0080640}},	//   _істо, _zimo_, aimo, љене_, 
   {{0x6281af6d,0x26c40472,0xefb80023,0x80dc00cc}},	//   bimo, _yimo_, ተልዎ_, _মিণ্, 
   {{0x6281af6e,0x23840050,0x26c5af6f,0x7bd4058a}},	//   cimo, _تٔمِ, _ximo_, _afxu, 
   {{0x0d98d011,0x80dc015b,0x425003e6,0x3ddc0784}},	//   стны_, _মিথ্, _سنور, ñuwa_, 
   {{0xc170025f,0x6ab42356,0x200c05b1,0x00000000}},	//   _אחד_, ंग्र, cgdi_, --, 
   {{0x09e5575d,0xbb40fe1c,0x625c83e7,0xbd8401b9}},	//   зобн, нерк, _géos, قچین_, 
   {{0x49c9af70,0x7f74011a,0x00000000,0x00000000}},	//   слан_, _מעצב_, --, --, 
   {{0x26c40ff8,0x09040024,0x37e000fe,0x00000000}},	// [2ec60] _rimo_, япан, _পাজৰ, --, 
   {{0x26c43389,0x6ed00356,0x00000000,0x00000000}},	//   _simo_, _zăba, --, --, 
   {{0x25a40368,0x6281af71,0x00000000,0x00000000}},	//   _syml_, yimo, --, --, 
   {{0x6281af72,0x0c040014,0x69b403ce,0xd2b4030d}},	//   ximo, _بوگُ, _आरपी, _тiиэ, 
   {{0x6281af73,0xba7401ec,0x26c4009f,0x245812fa}},	//   vimo, _ءاپت, _vimo_, жаль_, 
   {{0x260805f9,0x9f4c020c,0x62800009,0x00000000}},	//   _हाकी_, sadé_, wimo, --, 
   {{0x6281af74,0x26c5af75,0x9f59af76,0x26dc0518}},	//   timo, _timo_, ürü_, ívod_, 
   {{0x38ac000d,0x4abc0303,0x00000000,0x00000000}},	//   müra_, ्दिव, --, --, 
   {{0x6281af77,0x05642e26,0x00000000,0x00000000}},	//   rimo, _эван, --, --, 
   {{0x6281af78,0x03a40022,0x00000000,0x00000000}},	//   simo, _еизо, --, --, 
   {{0x4abc013a,0x38ac04cc,0x25f01bbb,0x32c00139}},	//   ्दाव, nüra_, आरपी_, _tıyp_, 
   {{0xfd9402d3,0x7ebc00e2,0x6281af79,0x37e003d4}},	//   _ዘቕረቦ_, _kūpi, qimo, _পাছৰ, 
   {{0x38ac07c5,0xfd4402d5,0xf1bc0118,0xe778010e}},	//   hüra_, чэнн, žár_, lýäñ, 
   {{0x5de00131,0x625daf7a,0xa3cc000d,0x717000cf}},	//   _ﺋﯩﻨﺴ, _géor, रखि_, _سۇپا, 
   {{0x26cc003e,0xe81005d7,0x7ebc6e98,0xde580064}},	//   _édoh_, ालना_, _lūpi, _макі_, 
   {{0x6448409c,0x38ac07c5,0xc0dc001f,0xda08009a}},	//   _lndi, düra_, _ፕሬስ_, تيره_, 
   {{0xa3cc3daa,0x6449af7b,0x81800023,0x00000000}},	// [2ec70] रखा_, _ondi, _ክትብሉ_, --, 
   {{0x92040055,0xadb4008e,0xb87801ef,0xbda40345}},	//   _imāś, _ябыш, _hvíz, _وحکو, 
   {{0xb8786361,0x7b640014,0x38ac07c5,0x9b9400f3}},	//   _kvíz, _رادٕ, güra_, _цинц, 
   {{0xe778010e,0xfc7001c8,0x00000000,0x00000000}},	//   dýäñ, _آپگھ, --, --, 
   {{0xe611af7c,0x850801ec,0x49a401ec,0x6fc03f7e}},	//   اشم_, ждің_, _жырғ, _रणभू, 
   {{0x38ac0793,0xb87801a8,0x53a40026,0x65942bef}},	//   büra_, _stíf, малб, رجنر, 
   {{0x7c340de2,0x625c529d,0x81dc00eb,0x00000000}},	//   _maxr, _réor, _তয়_, --, 
   {{0x7c340227,0x998800d0,0x00000000,0x00000000}},	//   _laxr, adať_, --, --, 
   {{0xe56c014b,0x00000000,0x00000000,0x00000000}},	//   _сҷ_, --, --, --, 
   {{0x855401d9,0xa9c41df2,0x7c340067,0xa5354194}},	//   _تیٖر_, ﯨﺮﯨﺴ, _naxr, _януч, 
   {{0x7659af7d,0xb87801e1,0x00000000,0x00000000}},	//   _kouy, _etíg, --, --, 
   {{0x76580363,0x00000000,0x00000000,0x00000000}},	//   _jouy, --, --, --, 
   {{0x201800f7,0x6448d39b,0xe8100316,0x9f580295}},	//   òric_, _yndi, ालमा_, ürò_, 
   {{0x4e080c2e,0x60c4d02b,0x63a40198,0x765800ad}},	//   _वाकई_, _éimp, ƙint, _louy, 
   {{0x4a280135,0xd1cc02d3,0x2fcc02b1,0x09c41d03}},	//   _སྒུལ_, _ጥሜት_, āngā_, वश्य, 
   {{0x0dbc1772,0x765802bd,0x1e9402d5,0x4e94007b}},	//   ተርፍ_, _nouy, _прыр, _تشتر, 
   {{0x7c34036b,0x08c5af7e,0xbcf800e5,0x00000000}},	// [2ec80] _faxr, дбан, lyén, --, 
   {{0x625c5f85,0xfa140003,0x7ebc1805,0x38ac0c86}},	//   _léop, ྲུུན_, _rūpi, türa_, 
   {{0x7659af7f,0x7ebc0055,0xbcf800e5,0x26dc0022}},	//   _bouy, _sūpi, nyén, ëvo_, 
   {{0x64483223,0x05a800a8,0x26dd261f,0x76580363}},	//   _sndi, овей_, īvo_, _couy, 
   {{0xb90003f4,0x7658062c,0x38ac07c5,0x290400c7}},	//   _নয়_, _douy, süra_, _íma_, 
   {{0xc76473c5,0x7ebc00cd,0x00000000,0x00000000}},	//   _قازى, _dīpy, --, --, 
   {{0x7659af80,0xb87809f3,0x9f4c0109,0x64487749}},	//   _fouy, _stíg, gadì_, _vndi, 
   {{0x32b40491,0x765802e2,0xc1e80212,0x7ebdaf81}},	//   ودية_, _gouy, цьке_, _tūpi, 
   {{0xc32c1e87,0x4428056a,0x00000000,0x00000000}},	//   _چەت_, _ºb_, --, --, 
   {{0x6449af82,0xf990011a,0xb87801ef,0x00000000}},	//   _undi, כרח_, _svíz, --, 
   {{0x7659af83,0x733007d2,0xbcf800e5,0x00000000}},	//   _youy, _لىلا, gyén, --, 
   {{0x4ad0069f,0x625c004a,0x7c340946,0x932400f1}},	//   _दूधव, _géop, _saxr, _سرمن, 
   {{0xbd680220,0x63a403f9,0x63a8fb72,0x9f4c02f0}},	//   ірме_, ƙins, _hydn, madí_, 
   {{0x9f4c0306,0x7c3401a9,0x5f95af84,0x00000000}},	//   ladí_, _qaxr, _пилт, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7c340009,0x6ed00356,0xb878013a,0x9a5400db}},	//   _waxr, _zăbo, _uvíz, رعزچ, 
   {{0xf99c067c,0x76580363,0x7c34b95a,0x26080412}},	// [2ec90] _acèr_, _rouy, _taxr, _हाजी_, 
   {{0x37a80aa8,0x7659af85,0x63a803b2,0x16b800cd}},	//   отен_, _souy, _oydn, ेद्ब, 
   {{0x7659af86,0xe9d000e5,0x00000000,0x00000000}},	//   _pouy, اغہ_, --, --, 
   {{0x76580113,0x9f4c07c5,0x00000000,0x00000000}},	//   _qouy, vadì_, --, --, 
   {{0x9425af87,0x76580099,0x63a8058a,0x4abc02c3}},	//   емле, _vouy, _aydn, ्दरव, 
   {{0x94740e4a,0x0595af88,0x7659af89,0x34481214}},	//   رگذا, رانگ, _wouy, ючен_, 
   {{0x7659af8a,0x63a80368,0x80dc015b,0x9f4c011f}},	//   _touy, _cydn, _মিষ্, hadâ_, 
   {{0x7ebc166a,0x00000000,0x00000000,0x00000000}},	//   _kūpu, --, --, --, 
   {{0x63a80579,0x101402d5,0xf8bc0129,0x27440092}},	//   _eydn, ньня, _usés_, _የሚሰበ, 
   {{0x80dc02a6,0x9f4c0589,0x8f7402dd,0x34c8276a}},	//   _মিশ্, dadâ_, еумі, ादीद, 
   {{0x20184f07,0x63a80368,0x8e840a0e,0x7ebc00ef}},	//   òria_, _gydn, егне, _lūpu, 
   {{0x80dc015b,0x1b1400cc,0x00000000,0x00000000}},	//   _মির্, াবাই_, --, --, 
   {{0xd24c0014,0x1e94084c,0x7ebc002b,0x8c95af8b}},	//   _نۆژ_, трэр, _nūpu, ерві, 
   {{0xbcf80129,0x00000000,0x00000000,0x00000000}},	//   myél, --, --, --, 
   {{0x8b64009a,0x38ac03e0,0x00000000,0x00000000}},	//   راسم, türn_, --, --, 
   {{0x7c300134,0x06dc015b,0x2ba401f9,0x975c0092}},	//   _ɔfrɛ, _ডিলি, _खुणा, _ለሚያስ, 
   {{0x6e244a73,0x9740001f,0xbcf8ff83,0x00000000}},	// [2eca0] _ibib, _የሚወስ, nyél, --, 
   {{0x6d440428,0x9f4c0308,0x00000000,0x00000000}},	//   _iria, zadí_, --, --, 
   {{0x8d740344,0x6d45af8c,0x00000000,0x00000000}},	//   _زاکا, _hria, --, --, 
   {{0x6d4512f9,0x38ac0ade,0x63a821e3,0x7e88012d}},	//   _kria, büro_, _rydn, tępi, 
   {{0xe5345402,0x6d44022f,0x9f4c0122,0x6e25af8d}},	//   тель, _jria, vadí_, _mbib, 
   {{0x68e41311,0xe6600598,0x63a9af8e,0x80dc2cc5}},	//   mpid, ırış, _pydn, _মিল্, 
   {{0x6e25af8f,0x68e5af90,0xf8bc0124,0xe7e001f9}},	//   _obib, lpid, _upéa_, खुणा_, 
   {{0x6d45af91,0x68e40254,0x00000000,0x00000000}},	//   _oria, opid, --, --, 
   {{0x6d440218,0x85048d1a,0x9f4c2b57,0x68e5af92}},	//   _nria, _سوان, radí_, npid, 
   {{0x6e25af93,0x5f0402c3,0x9f4daf94,0xb9780302}},	//   _abib, _विद्_, sadí_, פניי, 
   {{0x6d45af95,0x442c9279,0x6e240083,0x60c4011c}},	//   _aria, mef_, _bbib, _èimm, 
   {{0x63a40ab7,0x6e240083,0x64585fed,0x00000000}},	//   ğind, _cbib, ljvi, --, 
   {{0x6d45af96,0x63a43630,0x00000000,0x00000000}},	//   _cria, şind, --, --, 
   {{0x6e25af97,0x442c2045,0x68e40254,0x1da400cd}},	//   _ebib, nef_, dpid, _गुणत, 
   {{0x945c0227,0x2ba42871,0x6d45af98,0xba45af99}},	//   _kuńr, _खुदा, _eria, нхай, 
   {{0x442daf9a,0xf8bc00d5,0x7ebc02b5,0x9f4c00db}},	//   hef_, _asép_, _pūpu, madà_, 
   {{0x6d45137d,0xf80480e8,0x442daf9b,0x9f4c00db}},	// [2ecb0] _gria, ечен, kef_, ladà_, 
   {{0x442daf9c,0x693400cf,0xa6c400d1,0xa9c40108}},	//   jef_, ынуу, ۇقلى, усск, 
   {{0x9f4c66ce,0x442daf9d,0x6d4401f1,0x98b80356}},	//   nadà_, def_, _zria, _arsă_, 
   {{0x7ebc0053,0xb87801e1,0x6d45af9e,0x00000000}},	//   _tūpu, _awít, _yria, --, 
   {{0x442daf9f,0xa3cc0490,0x9f4c05d5,0x28d812eb}},	//   fef_, रखं_, hadà_, _भूपि, 
   {{0x2de400d1,0xeaf802f2,0x00000000,0x00000000}},	//   _ﺋﯩﻠﻤ, _تریت_, --, --, 
   {{0x83145756,0x942400fb,0xe894009d,0x00000000}},	//   نقور_, емһе, _сарь, --, 
   {{0x20180428,0x442c0334,0xbdd8007f,0x230800db}},	//   òrin_, aef_, ndèd, رتىي_, 
   {{0x6595afa0,0xd1780006,0x94d400d4,0x00000000}},	//   _бату, ьскі_, _розц, --, 
   {{0x6d440194,0xa4d40212,0x69b40210,0x00000000}},	//   _rria, _софі, _आरसी, --, 
   {{0x68e405f5,0x6d4407f0,0xa490158f,0x8f740024}},	//   zpid, _sria, _دیوت, тупі, 
   {{0x6d440038,0x1fb4eee2,0x71700228,0xe4800241}},	//   _pria, ысыр, _مۇعا, _ìsò̟, 
   {{0x7d0c00f3,0x4278008f,0x2c740139,0x63a40790}},	//   gucs, _קאנג, _läde_, ğine, 
   {{0x6d45afa1,0x63a49736,0x9f4c004e,0x8fa400c7}},	//   _vria, şine, badà_, _иале, 
   {{0x2c74049f,0x6d440165,0x00000000,0x00000000}},	//   _rädd_, _wria, --, --, 
   {{0x442dafa2,0x6d45afa3,0x6e25afa4,0xf99c007f}},	//   zef_, _tria, _ubib, _odèd_, 
   {{0x6d45afa5,0x9f4c0589,0x645c0086,0x68e4ce03}},	// [2ecc0] _uria, padã_, _òrig, upid, 
   {{0x68e405f5,0x9f4c0030,0x442c0135,0x00000000}},	//   rpid, ladá_, xef_, --, 
   {{0xd6d80164,0x8a04334a,0x68e5afa6,0x6348043b}},	//   еті_, _изне, spid, sɛnz, 
   {{0x9f4c5fd9,0x68e4e530,0x0564026a,0x2c740432}},	//   nadá_, ppid, квен, _däde_, 
   {{0x442dafa7,0x6aa405da,0x00000000,0x00000000}},	//   tef_, moif, --, --, 
   {{0xd90c04d3,0x6aa40421,0xa3181220,0x9f4c0548}},	//   _ریم_, loif, ежку_, hadá_, 
   {{0x442dafa8,0x7d0c0175,0x00000000,0x00000000}},	//   ref_, zucs, --, --, 
   {{0x442dafa9,0x32600b32,0x6aa40418,0x81681def}},	//   sef_, итыв, noif, дроб_, 
   {{0x28d835a7,0x37bc49a6,0x442c02e8,0x9f4c1709}},	//   _भूमि, _མཛོད, pef_, dadá_, 
   {{0x9f4c0137,0x6aa40418,0x442c067c,0x00000000}},	//   tadà_, hoif, qef_, --, 
   {{0x6aa40093,0x00000000,0x00000000,0x00000000}},	//   koif, --, --, --, 
   {{0xf8bc003e,0x00000000,0x00000000,0x00000000}},	//   _apél_, --, --, --, 
   {{0x70340b43,0x7c700131,0xa28000f1,0x6aa40332}},	//   رسیس_, иғич, _پیښو, doif, 
   {{0xddcc0010,0x7c8402dd,0xbcf801d3,0x7ebc00c0}},	//   _umaž, туме, lyék, _pūps, 
   {{0x6aa40e39,0xfaa5afaa,0x291c0165,0x61e4000d}},	//   foif, вшан, ńval_, _õils, 
   {{0x6a7801a8,0xbcf801d3,0x19583740,0x63bc00ae}},	//   _líff, nyék, набы_, _úrnu, 
   {{0xd7589fb2,0x2c741057,0xadf8007b,0x98b80120}},	// [2ecd0] کلات_, _säde_, _شريط_, елат_, 
   {{0x2ba4012c,0x2c740108,0x38ac0254,0x00000000}},	//   _खुवा, _päde_, mürk_, --, 
   {{0x37a85790,0xdd900271,0x00000000,0x00000000}},	//   фтан_, _خوک_, --, --, 
   {{0x6aa406af,0x6909afab,0x34c84668,0x15b800ee}},	//   coif, ürdü, ाद्द, нылы_, 
   {{0xfd1dafac,0x661802f0,0xe570007b,0xf67400e5}},	//   ntì_, _žaká, يطه_, _یارخ, 
   {{0x3eb80051,0x00000000,0x00000000,0x00000000}},	//   _lhqt_, --, --, --, 
   {{0xddcc0327,0x10a40131,0xe730c655,0xd2a81fd4}},	//   _amaż, ғинн, _وصف_, нкке_, 
   {{0x326000c7,0x53900023,0x00000000,0x00000000}},	//   реиҳ, _ዝዕወት_, --, --, 
   {{0x90d4114f,0x00000000,0x00000000,0x00000000}},	//   دآبا, --, --, --, 
   {{0x5f0407af,0x6aa401f7,0x59c437c8,0x65640221}},	//   _विश्_, zoif, लेयर, äihe, 
   {{0x6aa401c8,0x63a405d1,0xbcf80098,0x2055a335}},	//   yoif, ğinc, byék, ртыр, 
   {{0x63a41ae4,0x228401b9,0xc7b0011a,0x00000000}},	//   şinc, _кучг, מבי_, --, 
   {{0x910550d6,0xa15800c7,0xd00839c1,0x4fc0075e}},	//   _спле, _иацу_, _зеле_, _گەدە, 
   {{0x21a40046,0x7ae40334,0x6aa40175,0x9f4c00d7}},	//   _тиім, fpjt, woif, sadá_, 
   {{0x9f4c0316,0x6aa41140,0xac80001f,0x7e6c01d3}},	//   padá_, toif, ጨረሻም_, ánpó, 
   {{0xdb04000f,0x00000000,0x00000000,0x00000000}},	//   _byhâ, --, --, --, 
   {{0x2ba4134e,0x6a7808a5,0x6aa412ef,0x05b0000d}},	// [2ece0] _खुरा, _lífg, roif, _जरइब, 
   {{0x6aa5afad,0x3ea0007f,0x38880064,0x00000000}},	//   soif, čkte_, _nėrė_, --, 
   {{0x6aa5afae,0xbc18010f,0x46e8010b,0xe6c400ec}},	//   poif, _אויש, хден_, لڪري, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2418cf10,0x35f1937f,0x38880064,0x02a40131}},	//   волы_, спір, _bėrė_, һрим, 
   {{0x07a40816,0x00000000,0x00000000,0x00000000}},	//   _багн, --, --, --, 
   {{0x629c022c,0x49b80150,0xddcc033f,0x28d800cd}},	//   _írok, _زاڭد_, _smaż, _भूति, 
   {{0xa5c5afaf,0xe7e0012c,0x75d000c6,0x46a40cc9}},	//   _көле, खुरा_, _هيفا, _сабв, 
   {{0xb3800b8d,0xa075713e,0xde4c02d3,0xa1941d0f}},	//   иләл, игич, ንኽእል, рапч, 
   {{0x2019afb0,0x388800c0,0x15b80024,0x00000000}},	//   üri_, _gėrė_, _рысы_, --, 
   {{0x443c08e7,0x2ba410dc,0xf0b46ea9,0x00000000}},	//   _iat_, _खुला, دايش_, --, 
   {{0x443dafb1,0x38ac0365,0xfd1cfef5,0xb879712c}},	//   _hat_, türk_, ttì_, _ntín, 
   {{0x443dafb2,0x00000000,0x00000000,0x00000000}},	//   _kat_, --, --, --, 
   {{0x443cbdf6,0xfd1c42bc,0x6a78032e,0x00000000}},	//   _jat_, rtì_, _lífd, --, 
   {{0x443dafb3,0xfd1d4849,0x7e940014,0x26dc00db}},	//   _mat_, stì_, _مۆدر_, ívol_, 
   {{0x443dafb4,0x5a340261,0x4e880124,0xa3e409b2}},	//   _lat_, јнат, _ашьҭ_, भुत_, 
   {{0x443daf2a,0x7c85afb5,0xddcc00df,0x57f5afb6}},	// [2ecf0] _oat_, _буне, _klaŭ, ипат, 
   {{0x443c0f85,0x6ed00356,0x00000000,0x00000000}},	//   _nat_, _săbi, --, --, 
   {{0x38ac0205,0x00000000,0x00000000,0x00000000}},	//   nüri_, --, --, --, 
   {{0x443dafb7,0x00000000,0x00000000,0x00000000}},	//   _aat_, --, --, --, 
   {{0x75b4052f,0x443c3077,0x2c7400c5,0xe3b800ac}},	//   уғат_, _bat_, _häda_, _azı_, 
   {{0x67d50b4e,0x443c0c30,0x15b80032,0x85000131}},	//   _гору, _cat_, ныһы_, زۈمن, 
   {{0x443dafb8,0x8898011a,0xdc1800ef,0x00000000}},	//   _dat_, _יבשי, dāļu, --, 
   {{0xd26404a9,0xddcc0115,0x443c0c30,0x2c74000d}},	//   ркий, _alaŭ, _eat_, _mäda_, 
   {{0x443c0c30,0x54540006,0x00000000,0x00000000}},	//   _fat_, _кват, --, --, 
   {{0x443c398e,0x7539afb9,0x63a40724,0x4f243334}},	//   _gat_, _isuz, şina, адоб, 
   {{0x6a7800d8,0x62080267,0x00000000,0x00000000}},	//   _hífe, årlö, --, --, 
   {{0x443dafba,0xddcc01e4,0x63bc0e89,0x59c4f894}},	//   _zat_, _elaŭ, _ùrna, वधार, 
   {{0x443c0a28,0xddcc00df,0xeb5416a0,0x50b40305}},	//   _yat_, _flaŭ, ڭىزگ, _кску, 
   {{0x443dafbb,0x7538090c,0xd00856d1,0xddcc01e4}},	//   _xat_, _msuz, _реке_, _glaŭ, 
   {{0x6a780008,0x999801ef,0x09f41436,0x680001ef}},	//   _lífe, _basů_, ичая, hájí, 
   {{0x26dc1f08,0x75380083,0x4e280022,0x8d7428c4}},	//   ívom_, _osuz, _роин_, _ناخا, 
   {{0x753827d7,0x4fc03cd9,0x49c9afbc,0x8885afbd}},	// [2ed00] _nsuz, _دەگە, тлан_, алаж, 
   {{0xb878007b,0x3cf80a7c,0x00000000,0x00000000}},	//   _dtío, _שלינ, --, --, 
   {{0x753848d8,0xb87809a9,0x443c02c2,0xb6f400d1}},	//   _asuz, _etío, _rat_, لىلا_, 
   {{0x46a42b8e,0xfbb4011a,0x00000000,0x00000000}},	//   шаев, _כפית_, --, --, 
   {{0x443dafbe,0xddcc0311,0x041c009e,0xb904665a}},	//   _pat_, _moaş, _যোগী_, _княз_, 
   {{0x443dafbf,0x7ae801e3,0x00000000,0x00000000}},	//   _qat_, _ömtå, --, --, 
   {{0x443dafc0,0xf99c180f,0xdb040022,0xf4840330}},	//   _vat_, _idèa_, _kyhá, جانی, 
   {{0x443d61e5,0x2901afc1,0x27f946d9,0x26d80381}},	//   _wat_, osia_, _hern_, _iuro_, 
   {{0x443dafc2,0xb27010f5,0x1da40574,0x27f80112}},	//   _tat_, ільш, _गुंत, _kern_, 
   {{0x26d9afc3,0x2900049b,0x443c00a3,0x9f4c0724}},	//   _kuro_, isia_, _uat_, yadä_, 
   {{0x1df8467b,0x26d9afc4,0x29000020,0x7d1c010a}},	//   лены_, _juro_, hsia_, _sqqs, 
   {{0x29000664,0x27f89584,0x6d480882,0xb878008e}},	//   ksia_, _lern_, ādan, _atíl, 
   {{0x2901afc5,0xf27804ae,0x26d80789,0x00000000}},	//   jsia_, _בראש, _luro_, --, 
   {{0x26d97481,0xdfd031ed,0xb8780332,0x290000d7}},	//   _ouro_, _عيب_, _rtío, dsia_, 
   {{0x29000254,0xb8780332,0xfa840114,0x999801ef}},	//   esia_, _stío, аћам, _pasů_, 
   {{0xb87801e1,0x2900009f,0x98a8012d,0x5ea400f1}},	//   _etíl, fsia_, ować_, _دمعل, 
   {{0x27f9afc6,0x26d9afc7,0x6b8c0085,0x80b81428}},	// [2ed10] _bern_, _auro_, _ɛngɛ, _उठाइ, 
   {{0x6c85afc8,0x26d9afc9,0x9c39afca,0x81c00154}},	//   _وليم, _buro_, _спот_, ্ডপ_, 
   {{0x27f9afcb,0x26d9afcc,0x6a7801a8,0xbcf800e5}},	//   _dern_, _curo_, _sífe, gyév, 
   {{0x26d9afcd,0x290034e1,0xf4f400e5,0x9574004e}},	//   _duro_, bsia_, لوؤں_, йылч, 
   {{0x15440598,0xf8d8032c,0x2901afce,0x27f86040}},	//   селм, _बढिय, csia_, _fern_, 
   {{0x27f80730,0x26d9afcf,0xeaf801d3,0x656401c7}},	//   _gern_, _furo_, _حریت_, äiha, 
   {{0x26d9afd0,0x3d140882,0x98a8033f,0xdecc0092}},	//   _guro_, भूते_, ewać_, ጣለን_, 
   {{0xeb980302,0xf8d8375c,0x7538037e,0xd39400d1}},	//   ידור_, _बढाय, _tsuz, _қәлә_, 
   {{0x7539afd1,0x26d80810,0x00e40133,0xb4000150}},	//   _usuz, _zuro_, یتیی, _дүлд, 
   {{0x26d9afd2,0x3a280334,0xb6140150,0xc0c400f1}},	//   _yuro_, _lbcp_, _ﹼﻊ_, مېنه_, 
   {{0x645c0086,0x26d80005,0x11d493fb,0x8fa50764}},	//   _òria, _xuro_, _люля, сане, 
   {{0x29002295,0xb879afd3,0x21240014,0x850c012d}},	//   ysia_, _stíl, _ژٹنُ, _सिमट_, 
   {{0x3948017a,0x6ed00356,0xc22000ec,0xf1a40114}},	//   _nrcs_, _răbu, _رکيو, _тржн, 
   {{0x499400fb,0x2cac0042,0xdddc00d7,0x290000d7}},	//   ҡшат, ôdd_, visť, vsia_, 
   {{0x3949852c,0xdb0400e4,0xb87801ef,0x2901afd4}},	//   _arcs_, _pyhá, _ctím, wsia_, 
   {{0x394800fb,0x2d840120,0x97400092,0x29c80116}},	//   _brcs_, úmes_, _ከሚያስ, иңни_, 
   {{0x26d8016b,0x2901afd5,0x27f86035,0xdb040306}},	// [2ed20] _suro_, usia_, _pern_, _vyhá, 
   {{0xbdd80372,0x2901afd6,0x09b800fe,0x38c81077}},	//   ndèn, rsia_, ংখলা, هالی_, 
   {{0x2901afd7,0x27f9afd8,0x06dc03d4,0x6ed00356}},	//   ssia_, _vern_, _ডিঙি, _tăbu, 
   {{0x2901afd9,0x27f9afda,0x98a80034,0xddcc01ef}},	//   psia_, _wern_, ywać_, _hlaš, 
   {{0x26d80198,0x27f83154,0xddcc00e2,0x337001ec}},	//   _wuro_, _tern_, _klaš, үгір, 
   {{0x26d9afdb,0x27f80295,0x2a60022e,0xd50800f2}},	//   _turo_, _uern_, ljib_, شتهٔ_, 
   {{0x317c0165,0x26d80009,0x58f40327,0xbcf98da2}},	//   ezuz_, _uuro_, _བསོས_, lyét, 
   {{0x7ae06479,0x3e780240,0x2a61afdc,0xe81000bc}},	//   _énte, _këte_, njib_, ालका_, 
   {{0xbcf9afdd,0xe29801e0,0x00000000,0x00000000}},	//   nyét, лаҫ_, --, --, 
   {{0xf99c00db,0x98a8033f,0x9f4c0332,0xbf6400f2}},	//   _odèn_, rwać_, madú_, مدجو, 
   {{0x2ba40dba,0x42e80114,0x00000000,0x00000000}},	//   _खँगा, _смео_, --, --, 
   {{0xffa0009d,0x00000000,0x00000000,0x00000000}},	//   жлүү, --, --, --, 
   {{0x2a60020c,0x5f0401ad,0xddcc0064,0x9f4c01e7}},	//   djib_, _विक्_, _blaš, nadú_, 
   {{0x6f000175,0x2ba40037,0x00000000,0x00000000}},	//   _fvnc, _खँखा, --, --, 
   {{0xf8bc0588,0xd8cc0116,0x00000000,0x00000000}},	//   _upéi_, _ﺑﻮﻻﻟ, --, --, 
   {{0xdd95afde,0x8d940014,0xaa640116,0x38ac002f}},	//   _майы, _ژٔٹت, птук, hürt_, 
   {{0xf99c004e,0x38adafdf,0x3ea802fb,0x00000000}},	// [2ed30] _edèn_, kürt_, moct_, --, 
   {{0x787800e4,0xd794011c,0x00000000,0x00000000}},	//   _oîve, оизъ, --, --, 
   {{0x7bd4014b,0x95d807d8,0xfca85285,0x38ac0166}},	//   _igxu, адет_, _لاگو_, dürt_, 
   {{0xded41772,0x3a280334,0x57a800bc,0xe6107b8f}},	//   ራሻና_, _ubcp_, _कडीह, فشه_, 
   {{0x1d880020,0x63a40213,0x3e780200,0xf52435ce}},	//   _አንቀጽ_, şinl, _gëte_, сфен, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69c0810d,0x00000000,0x00000000,0x00000000}},	//   _úmer, --, --, --, 
   {{0xe6940124,0xbcf801ed,0x317c005a,0x81c000eb}},	//   _еисы, nyés, tzuz_, ংশন_, 
   {{0x70200489,0x466000db,0xd0580111,0xc6840133}},	//   _འཁྱུ_, _تۇنق, арні_, _بێنن_, 
   {{0x7bd40b6f,0xd0080063,0x8fd001e0,0xb64002dd}},	//   _ngxu, јене_, мәйә, _ﺃﻴ_, 
   {{0x0eb85a9a,0xd3702e0b,0x6a7802d2,0x00000000}},	//   иумы_, _تها_, _lífa, --, 
   {{0x7bd40117,0xddcc0219,0xd130027d,0xdb0401f4}},	//   _agxu, _slaš, _يما_, _myhä, 
   {{0xddcdafe0,0x00000000,0x00000000,0x00000000}},	//   _plaš, --, --, --, 
   {{0x70200135,0x00000000,0x00000000,0x00000000}},	//   _འཁྲུ_, --, --, --, 
   {{0xbb41afe1,0x58f40135,0x9528031c,0xbf101eeb}},	//   мерк, _བསུས_, _ལཱའི_, _قووب, 
   {{0x7bd4014b,0xbdd8067c,0x3ea9124b,0x629c01d3}},	//   _egxu, ndèl, coct_, _írot, 
   {{0x8c45afe2,0x08890f52,0xfdb00116,0x4c8400d8}},	// [2ed40] _депе, абай_, _жәря, _млив, 
   {{0x1cb8003d,0x38ac04cc,0xb87801e7,0xc0e00023}},	//   _མཚར_, dürs_, _luíf, _ነብሪ_, 
   {{0xbcf80100,0xb7d41291,0x09f400ae,0x00000000}},	//   syét, زونا_, _وأحد, --, 
   {{0x81c000fe,0x00000000,0x00000000,0x00000000}},	//   ্ডত_, --, --, --, 
   {{0x38ac04cc,0xbcf801ed,0x69b42c35,0x63a40790}},	//   gürs_, lyér, _आरटी, ğinm, 
   {{0x92e40011,0x86e8007b,0x25a00327,0x00000000}},	//   _ভয়ে_, _نعرف_, ħil_, --, 
   {{0x1cb8025c,0xbcf801ed,0xe3b806be,0xd5ac0d62}},	//   _མཚལ_, nyér, _abır_, نہہ_, 
   {{0xfbd00302,0x60f802e8,0x38ac0205,0x00000000}},	//   ותו_, бния_, sürt_, --, 
   {{0xb64002dd,0xc0580006,0x38ac002f,0x00000000}},	//   _ﺃﺴ_, аін_, pürt_, --, 
   {{0x39540375,0x42d40212,0x00000000,0x00000000}},	//   קשים_, _діду, --, --, 
   {{0xb7d80bd9,0xa3e400cd,0xf834011a,0x00000000}},	//   יקיי, भुः_, חנית_, --, 
   {{0x412801f4,0x00000000,0x00000000,0x00000000}},	//   _водо_, --, --, --, 
   {{0xb14005f5,0xe018072a,0x00000000,0x00000000}},	//   _онцл, _दाऊद_, --, --, 
   {{0x6a7808a5,0x00000000,0x00000000,0x00000000}},	//   _rífa, --, --, --, 
   {{0x6a78008e,0xfa88009d,0xbcf800e5,0x00000000}},	//   _sífa, асай_, gyér, --, 
   {{0x9df8084c,0x99d8015b,0x59b807f7,0xdb0401f4}},	//   _унит_, তর্ক, _आरआर, _ryhä, 
   {{0xdd904d4e,0xb86405d9,0xbdd800db,0xb8780118}},	// [2ed50] _سود_, يائو, ndèm, _utík, 
   {{0x7bd40921,0xdb04023a,0x1ca40133,0x6db401af}},	//   _ugxu, _pyhä, _رێزی_, _юйыу, 
   {{0x96347ffd,0x37040006,0x00000000,0x00000000}},	//   знец, ючав, --, --, 
   {{0xcb10008f,0xfa4800db,0x58d5afe3,0x6a78032e}},	//   _אלט_, _ئشدى_, _номт, _tífa, 
   {{0x4a580375,0x00000000,0x00000000,0x00000000}},	//   _הדרו, --, --, --, 
   {{0x81c00eac,0xf77049f6,0xb87801e7,0x00000000}},	//   ্ডা_, _قاز_, _suíf, --, 
   {{0x69e80086,0x63c400fb,0x15f41cd2,0x00000000}},	//   _òreñ, машҡ, आरआर_, --, 
   {{0xb8780308,0x5f0408ec,0x1dbc41ac,0xe01804aa}},	//   _stíh, _विज्_, ोधात, _दाउद_, 
   {{0x066801ec,0x7580315b,0x26dc0419,0x65941075}},	//   _القۋ_, _تیشم, ívov_, _жату, 
   {{0x505802e8,0x008000d4,0x66fc0055,0x00000000}},	//   сшия_, ельо, _ṅkit, --, 
   {{0x0ea8005b,0x00000000,0x00000000,0x00000000}},	//   йкой_, --, --, --, 
   {{0xb8780789,0xf28405d9,0x00000000,0x00000000}},	//   _huíd, _گھڻو_, --, --, 
   {{0x78711d8b,0x8d743b44,0x00000000,0x00000000}},	//   _kıvı, ساحا, --, --, 
   {{0x60c40395,0x629c00e5,0x00000000,0x00000000}},	//   _èimp, _íror, --, --, 
   {{0xfbc04140,0xab64033f,0x25a0031c,0x0f7800df}},	//   ебро, ążow, żilx_, _לאַב, 
   {{0x88e4005b,0xfe7c0022,0x5f740244,0xda5800db}},	//   зжае, chï_, _تاهر, оруш_, 
   {{0x7af800f3,0x99d803d4,0x6d402ca8,0x00000000}},	// [2ed60] ćuta, তৰ্ক, çmad, --, 
   {{0xa96800d1,0x07a40a8d,0x6564005b,0x00000000}},	//   биға_, пазн, äihm, --, 
   {{0xc6d5afe4,0x09e46e1e,0xe3b80205,0x9f6403b2}},	//   ستات, _нонн, _acın_, ðtøk_, 
   {{0x1cb81efe,0x3e78044e,0x7ae1afdd,0xb6c81893}},	//   _མཚོ_, _këta_, _énta, مانے_, 
   {{0x58f40003,0xdde000b0,0x1fc83c71,0xddcc012d}},	//   _བསགས_, _ōtūm, _रण्ड, _znał, 
   {{0x06641547,0xb8780407,0x2cb800d2,0x78b4003a}},	//   _کاسپ, _cuíd, nlrd_, clxv, 
   {{0x21e000b0,0xfc14011a,0x378400d8,0x00000000}},	//   hōhō_, לקסי_, _ебро_, --, 
   {{0x8235afe5,0xf2c1ae78,0x6a780139,0x26dc02f0}},	//   سرعا, нсын, _mífo, ívou_, 
   {{0x26c4014f,0xb6a000fd,0x00000000,0x00000000}},	//   _ihmo_, _читл, --, --, 
   {{0x44e05573,0x4345afe6,0x1cb8025c,0xf1bc0419}},	//   _ið_, _незв, _མཚེ_, ášam_, 
   {{0x60c80204,0xd9b81f13,0x6a7801e1,0xdfd00b61}},	//   rmdm, _आर्ट, _nífo, ضيح_, 
   {{0x76b00113,0xdd94113e,0x5e58084c,0x787003e0}},	//   _třyń, дамы, цимя_, _zıvı, 
   {{0xefb802d3,0x2018068c,0x62800455,0xc0c80114}},	//   ደልየ_, òris_, mhmo, _луке_, 
   {{0x787800c7,0x6144010b,0x6281afe7,0x00000000}},	//   _oîva, _неҗа, lhmo, --, 
   {{0x26c4047e,0x1f7401ec,0x00000000,0x00000000}},	//   _ohmo_, _ілия, --, --, 
   {{0xfd4400dd,0x6280004d,0x9f5c0200,0xe7b00210}},	//   _ٹیسٹ_, nhmo, _levë_, _झड़प, 
   {{0xf9900502,0x00000000,0x00000000,0x00000000}},	// [2ed70] ربر_, --, --, --, 
   {{0x26c405be,0x6a7801e1,0x9f5c00d8,0xefb802d3}},	//   _ahmo_, _fífo, _revê_, ደልዩ_, 
   {{0x44e1afe8,0xb0b80156,0xb87810ba,0xdd91afe9}},	//   _að_, _པེལེ, _ruíd, _سوگ_, 
   {{0x19581e76,0x6281afea,0xb8780005,0x787005d1}},	//   _дамы_, jhmo, _suíd, _sıvı, 
   {{0xd469afeb,0xb8780005,0x181802cb,0x23340124}},	//   жиле_, _puíd, _ورسک_, ҵхыр, 
   {{0x6a7801a8,0x00000000,0x00000000,0x00000000}},	//   _lífl, --, --, --, 
   {{0xe72801c0,0x5724215c,0x03a00107,0xfa280327}},	//   _ноёд_, _تىزك, кишо, _སྡོན_, 
   {{0x9f5c00d8,0x62800978,0x9f4c0165,0xddcc013a}},	//   _tevê_, ghmo, wadÿ_, _zlať, 
   {{0xf4f401ed,0xe1946768,0x7ee40150,0xc240013d}},	//   _رواں_, ерээ, _ﺍﻟﻨﻁ, тнык, 
   {{0x4f08013e,0xbdd8020c,0x629c0241,0x00000000}},	//   онон_, bdèk, _ìron, --, 
   {{0x62800218,0x2278035c,0x44440014,0x25a4030a}},	//   bhmo, زلیگ_, _زرٕہ, _zxml_, 
   {{0x1cb8031c,0x62801c2e,0xaf500116,0x00000000}},	//   _མཚུ_, chmo, _үндә, --, 
   {{0xd0084fd5,0xed5000e5,0xdbc400c7,0x00000000}},	//   _деле_, اھب_, ҵарҩ, --, 
   {{0x7af80cf4,0x2c74010e,0xc0f40023,0x00000000}},	//   ćutn, _kädi_, ሉኹም_, --, 
   {{0x09e5afec,0x0ba80075,0x20180030,0x9f5c0100}},	//   добн, زاسى_, órie_, _nevè_, 
   {{0xc330025f,0x321d6d44,0xbdac00b4,0x3e7800c7}},	//   כול_, nguy_, ụpụt, _tëta_, 
   {{0x63a40ab7,0x6e2401b2,0xddcc02f0,0xe3b80205}},	// [2ed80] ğini, _icib, _plať, _acıl_, 
   {{0x6d45afed,0x63a4aa57,0x42680092,0x4794009a}},	//   _isia, şini, ሳሽነት_, وجاس, 
   {{0x78800118,0x00000000,0x00000000,0x00000000}},	//   důvě, --, --, --, 
   {{0x6d45afee,0x97c401d5,0x00000000,0x00000000}},	//   _ksia, رتلم, --, --, 
   {{0x6e24014b,0x62800218,0x321c0356,0x245800c0}},	//   _mcib, vhmo, dguy_, заль_, 
   {{0x6d4401f7,0x55f40116,0xb8780174,0x44e00a87}},	//   _msia, _үчту, _stív, _vð_, 
   {{0x6281afef,0xf741aff0,0x6a7802d2,0x68e401a9}},	//   thmo, _иеро, _lífm, lqid, 
   {{0x6d45aff1,0x6e24009a,0x9694177b,0x321c00e8}},	//   _osia, _ncib, _зруш, gguy_, 
   {{0x68e4a67c,0x6a7801a8,0x44e002d2,0xa56800e5}},	//   nqid, _rífl, _uð_, _عشرے_, 
   {{0x628174f5,0x6e244b1e,0x66000267,0x81c00011}},	//   shmo, _acib, _hemk, ্ডল_, 
   {{0x6d45aff2,0x381406a9,0x644803d1,0x66007af8}},	//   _asia, וקים_, _iadi, _kemk, 
   {{0x6449aff3,0x442d9fb5,0x6601aff4,0xbe880212}},	//   _hadi, lff_, _jemk, існе_, 
   {{0x644817b2,0x442c010a,0x6600010f,0xbdd80561}},	//   _kadi, off_, _memk, ndèi, 
   {{0x6448ae00,0x442daff5,0x6600003c,0x9f5daff6}},	//   _jadi, nff_, _lemk, _levé_, 
   {{0x6d45aff7,0x442c0368,0xba74020e,0xda340312}},	//   _esia, iff_, وارت, невы, 
   {{0x6601aff8,0x6e2400d2,0x60d8047e,0x6449aff9}},	//   _nemk, _gcib, _hivm, _ladi, 
   {{0xcdc00131,0x9f5c033b,0x6448127b,0x00000000}},	// [2ed90] _бәрп, _sevè_, _oadi, --, 
   {{0x3e78069c,0x7ae08075,0x9f5c007f,0x442c2112}},	//   _këto_, _énto, _pevè_, jff_, 
   {{0x66004ec2,0x321c0124,0x60d80455,0x442c0334}},	//   _bemk, yguy_, _mivm, dff_, 
   {{0x6449affa,0xb87801e1,0x60d85629,0x442daffb}},	//   _aadi, _atít, _livm, eff_, 
   {{0x6449affc,0x8508005e,0xe3b82c70,0x6c84168d}},	//   _badi, здің_, _ayı_, _سلێم, 
   {{0x6449affd,0x6600005a,0x60d80455,0x321c0076}},	//   _cadi, _eemk, _nivm, wguy_, 
   {{0x6449affe,0x6601afff,0x91e401a9,0x00000000}},	//   _dadi, _femk, нойе, --, 
   {{0xd5f4021a,0x442c0b4f,0x644883a9,0x94c8004b}},	//   _سترګ, aff_, _eadi, _ځائې_, 
   {{0xe5b43cd9,0x6449b000,0x76580bd7,0x321db001}},	//   _айты, _fadi, _inuy, rguy_, 
   {{0x6e25b002,0x00c4ea10,0x9f4c004e,0x660000e2}},	//   _scib, нлык_, jadó_, _zemk, 
   {{0x6600003c,0x60d893b9,0x6d440129,0xb3080066}},	//   _yemk, _divm, _ssia, _ذغال_, 
   {{0x78780022,0x7648005c,0x6d44012d,0x00000000}},	//   _oîvo, ndgy, _psia, --, 
   {{0x6449b003,0x60d80109,0xb878056a,0x9d00010b}},	//   _yadi, _fivm, _xuíc, аҗык, 
   {{0x6449b004,0xa2d40150,0x9f4c01d3,0x60d8007c}},	//   _xadi, _كيەت, gadó_, _givm, 
   {{0x76581418,0xdd9800d0,0x92c00154,0x6d44012d}},	//   _onuy, ĺňa_, ংদী_, _wsia, 
   {{0x6d45b005,0x42804be7,0x63bc1455,0x6e25b006}},	//   _tsia, ይማኖት_, _ørne, _ucib, 
   {{0x08c5b007,0xfaa1b008,0x6601b009,0x7e980a7c}},	// [2eda0] ебан, уато, _remk, _מסקו, 
   {{0x6600003c,0x76480369,0x765800cd,0x9f4c067c}},	//   _semk, edgy, _anuy, cadó_, 
   {{0x6600ae08,0xbcf80005,0x9f4c007f,0x290c00cd}},	//   _pemk, nxén, ladò_, _ādau_, 
   {{0x6449b00a,0x442c5323,0x00000000,0x00000000}},	//   _sadi, wff_, --, --, 
   {{0x6449b00b,0xb8780ba1,0x442c009f,0x6a7802d2}},	//   _padi, _quíc, tff_, _lífk, 
   {{0x6449b00c,0x442c7c6e,0x6601b00d,0x00000000}},	//   _qadi, uff_, _wemk, --, 
   {{0x442c0cfd,0x6601b00e,0xcb38010f,0x00000000}},	//   rff_, _temk, לײַכ, --, 
   {{0x644881f1,0x9f4c01d3,0xe3b8008e,0x00000000}},	//   _wadi, zadó_, _ucım_, --, 
   {{0x6449b00f,0x60d8047e,0x58f40327,0x442c0175}},	//   _tadi, _pivm, _བསབས_, pff_, 
   {{0x6449b010,0x60d80477,0x59c41152,0x320c50eb}},	//   _uadi, _qivm, लेटर, _edgy_, 
   {{0x7330104b,0x81c0009e,0x93241680,0x60d9b011}},	//   _مىلا, ্ডই_, _لرنن, _vivm, 
   {{0x1cb80135,0x60d8016d,0xceac0451,0x42c8004e}},	//   _མཚང_, _wivm, يڙي_, _эген_, 
   {{0x60d87073,0x02c8002b,0xcd00002b,0x9f4c00e5}},	//   _tivm, _gṛṇa, _niśā_, tadó_, 
   {{0xbcf80005,0x63a40356,0x9f640162,0x00000000}},	//   bxén, şinu, ðtók_, --, 
   {{0x9f4c01d3,0x76480142,0xb87801ef,0xab84011c}},	//   radó_, ydgy, _otír, гутк, 
   {{0xc0e002d3,0x5d5441b9,0x63bc00a3,0x9e340022}},	//   _ነብሰ_, _акит, _ùrnu, _реич, 
   {{0x04040154,0x1a6401d5,0x6a7800ae,0x00000000}},	// [2edb0] _রানী_, _ییسی_, _mífh, --, 
   {{0x1ce00003,0xcd0000b8,0xd6d8033f,0x7d1800cf}},	//   _སྤར_, _diśā_, _sił_, àusu, 
   {{0xd75800c6,0xa8a40137,0xb87802f0,0xd6d80210}},	//   بلات_, уртк, _stís, _pił_, 
   {{0x3a6c00d1,0x15b80150,0x00000000,0x00000000}},	//   _ﯴﭼﯜﻥ_, мылы_, --, --, 
   {{0x15453f3c,0xc0e002d3,0xfd1c05d5,0xe508004b}},	//   телм, _ነብሱ_, nuì_, فينو_, 
   {{0x935800d8,0x00000000,0x00000000,0x00000000}},	//   дриу_, --, --, --, 
   {{0xb87809ff,0x1ce00327,0x00000000,0x00000000}},	//   _guía, _སྤལ_, --, --, 
   {{0x76580784,0x9f4c0100,0x02c800b8,0xe3b1b012}},	//   _unuy, yadò_, _pṛṇa, حره_, 
   {{0x410034d8,0x6a78007b,0x3ae40254,0x00000000}},	//   азыв, _dífh, _lõp_, --, 
   {{0xc0e002d3,0x00000000,0x00000000,0x00000000}},	//   _ነብሲ_, --, --, --, 
   {{0x2019b013,0x8fa4e96e,0x4fa4040e,0xe16400db}},	//   ória_, тане, тинв, _ەدىي, 
   {{0x2c7403fa,0xc7d40375,0xddd40419,0x02c800cd}},	//   _lädt_, כותי_, _šašt, _tṛṇa, 
   {{0xfd1c5bd9,0x3ea1b014,0x1e94084c,0xbea0013d}},	//   guì_, рияг, урэр, раяк, 
   {{0x9f4c749f,0x8c440114,0x00000000,0x00000000}},	//   radò_, њеве, --, --, 
   {{0xaea40220,0xc0e00023,0x9f54074d,0x6a7802d2}},	//   _مەدي, _ነብሳ_, _йĕрк, _hífi, 
   {{0xd0600198,0xfd1d379e,0x0d200137,0x00000000}},	//   _ƙuɗa, buì_, _күмү, --, 
   {{0x9f5c05da,0x290c005f,0xfd445680,0xbcf80005}},	// [2edc0] _levì_, _ādas_, _азык_, nxél, 
   {{0x2b040014,0xb878013a,0x00000000,0x00000000}},	//   _مژرٲ, _stír, --, --, 
   {{0x6a78008c,0xc5fc005f,0x87099298,0x8d741046}},	//   _lífi, ņēma_, феев_, _ساکا, 
   {{0xa3d46b9b,0x00000000,0x00000000,0x00000000}},	//   सेफ_, --, --, --, 
   {{0xa3d407b7,0xb87801ef,0x993800c0,0x00000000}},	//   सेन_, _vtír, _пяру_, --, 
   {{0x02c80b33,0x7774002d,0x1ce0031c,0x00000000}},	//   ाग्न, byxx, _སྤས_, --, 
   {{0x02a43929,0xa2940006,0x2c20012d,0x00000000}},	//   крим, лакі, _बाईं_, --, 
   {{0x6a7804d4,0xb87801ef,0x00000000,0x00000000}},	//   _bífi, _utír, --, --, 
   {{0xbdd8068c,0xb8780332,0x7ee401ec,0x84e40815}},	//   ndèt, _muín, _ﺍﻟﺸﻲ, _розж, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4224084c,0x7af88bbb,0x81c000cc,0x00000000}},	//   _адев, ćutk, ংশই_, --, 
   {{0x6a783d64,0xfd1cb513,0x00000000,0x00000000}},	//   _fífi, tuì_, --, --, 
   {{0x0488002b,0x00000000,0x00000000,0x00000000}},	//   _śaṃt, --, --, --, 
   {{0xfd1d1999,0xb93c0092,0x9f5c032e,0x00000000}},	//   ruì_, _ዓላማዎ, _heví_, --, 
   {{0xdddc002d,0x9f3402dd,0x3f980254,0x00000000}},	//   sisű, _сейі, _äpu_, --, 
   {{0xb878004e,0x9f5c0118,0x00000000,0x00000000}},	//   _atíp, _jeví_, --, --, 
   {{0xf805b015,0xead42d30,0xfd1c05d5,0xee7c0023}},	// [2edd0] вчен, роть, quì_, _ይረኣዩ_, 
   {{0x9f5c02d2,0x2c20012d,0x00000000,0x00000000}},	//   _leví_, _बाएं_, --, --, 
   {{0x58f40003,0x97c40032,0x6bd801d9,0x97140024}},	//   _བསམས_, ураһ, _لوٝس_, умец, 
   {{0x4b78008d,0x9f5c00bc,0xe6100214,0xda1c000d}},	//   _נארו, _neví_, قشه_, _फाटत_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6a7802d2,0x94740066,0x53a400cf,0x00000000}},	//   _rífi, دگرا, лалб, --, 
   {{0x6a780789,0xe0e0015b,0xf6440022,0xe89401c6}},	//   _sífi, _মৌলভ, _ихан, _тарь, 
   {{0x20180d3f,0x6a783756,0xbdd8067c,0x662434b1}},	//   órin_, _pífi, ndès, _ەرەك, 
   {{0xc69008a8,0x910401ec,0x00000000,0x00000000}},	//   _האן_, ыппе, --, --, 
   {{0x75380472,0x1ce0025c,0x25a0007b,0x32600014}},	//   _ipuz, _སྤེ_, úile_, انکہ, 
   {{0xb878007b,0x7ae0020c,0xdb0400e4,0x1ae800cc}},	//   _luío, _énth, _pyhý, টীতে_, 
   {{0xddcc0232,0x65840129,0x63bd4914,0x00000000}},	//   _dlaž, _àthè, _ørna, --, 
   {{0xb878e099,0xdb0402fb,0x5d0400c7,0x20100162}},	//   _ruín, _vyhý, аҭын_, ølið_, 
   {{0x75380537,0xfce0fc32,0xb8780120,0xe3b800fd}},	//   _mpuz, соро, _suín, _abıy_, 
   {{0x09bc543b,0xddcc0010,0x40d8010f,0x92e403d4}},	//   ्ध्य, _glaž, _אַהײ, বীৰ_, 
   {{0xb8780597,0x7538107d,0x6a7801a8,0x1a640244}},	//   _buío, _opuz, _lífv, لیپی_, 
   {{0x4e9452cb,0xb87801e7,0xddcc0010,0x88c8005b}},	// [2ede0] _لشکر, _cuío, _zlaž, елав_, 
   {{0xf6bc1b4b,0xa3d401ad,0x785800de,0x25080133}},	//   _མཚུང, सेड_, _nāvē, ۆرتی_, 
   {{0xb8780118,0x8078010f,0x06740395,0x00000000}},	//   _vtíp, ענעצ, лудя, --, 
   {{0x84e402bf,0x7c3805a1,0xd6d89e08,0xb87800ae}},	//   годж, đure, вті_, _fuío, 
   {{0x6aa5b016,0xf485b017,0xb8780332,0x00000000}},	//   mnif, گانی, _guío, --, 
   {{0xddcc002b,0x37e1b018,0x6aa4003a,0xe37401c6}},	//   _anaś, _горг, lnif, иллы, 
   {{0xf484aeda,0xbdd8180f,0x6aa40037,0x41e40816}},	//   دانی, ndèr, onif, ліпа, 
   {{0xd5ac00aa,0x816822c3,0x611406ed,0x8235b019}},	//   _ښځو_, ероб_, адиу, ارغا, 
   {{0xddcdb01a,0x20180261,0xd04000ac,0x6aa4009f}},	//   _slaž, ório_, lmlə, inif, 
   {{0xddcd82e0,0xbdd800f2,0x63a40213,0x38ac0112}},	//   _plaž, kdèr, şinq, würz_, 
   {{0x6aa45971,0x9f341d31,0x1df82401,0x00000000}},	//   knif, шені, кены_, --, 
   {{0x7ae07dec,0x3e78036e,0xf7d400df,0x00000000}},	//   _énti, _këti_, טויש_, --, 
   {{0x1cb8031c,0xd0400213,0x00000000,0x00000000}},	//   _མཚད_, hmlə, --, --, 
   {{0xd1c80a81,0x673c0a85,0xdfd4db80,0x60980014}},	//   _شبنم_, _oprj, _колы, _جنتس_, 
   {{0xb8780491,0xddcc56c0,0xbdd80066,0x9f5c0055}},	//   _suío, _ulaž, gdèr, _devã_, 
   {{0x98a8110c,0x6aa80154,0x00000000,0x00000000}},	//   rtač_, _কীবো, --, --, 
   {{0x98b8a3c3,0x98a8bc04,0x79a50d8c,0x19c429db}},	// [2edf0] влат_, stač_, урве, рәнг, 
   {{0x37a9b01b,0x6aa4f4dd,0x98a805be,0x673c0175}},	//   нтен_, anif, ptač_, _bprj, 
   {{0x37a9b01c,0x7538f562,0xaa640408,0x785800de}},	//   хтан_, _spuz, птăк, _rāvē, 
   {{0x6aa45d7e,0x3e7800e8,0x635c084c,0x163400a7}},	//   cnif, _bëti_, _mănă, редя, 
   {{0xa9c80022,0x629c03b2,0x00000000,0x00000000}},	//   _бырз_, _íroy, --, --, 
   {{0x7c25b01d,0x53140120,0x78a4002b,0x00000000}},	//   ngjr, афиу, _ujjv, --, 
   {{0x9f5c004e,0xd04003b9,0x00000000,0x00000000}},	//   _nevà_, cmlə, --, --, 
   {{0x6a7808a5,0x00000000,0x00000000,0x00000000}},	//   _fífu, --, --, --, 
   {{0xb4246728,0x3e78002e,0x7539b01e,0x6a7801a8}},	//   _معاو, _gëti_, _upuz, _gífu, 
   {{0x635c054e,0xa3b001ad,0x3948045a,0x6d4003e0}},	//   _bănă, _टुक_, _mscs_, çmam, 
   {{0x2055b01f,0x7878003a,0x00000000,0x00000000}},	//   стыр, _cîvi, --, --, 
   {{0xb64404ce,0x645c01e1,0x00000000,0x00000000}},	//   _ｈｐ_, _òrir, --, --, 
   {{0x3e780694,0xd0400213,0xe1f149fc,0x43c00220}},	//   _xëti_, zmlə, _رسن_, _ﺯﺍﯕﺪ, 
   {{0xdb040077,0x3a280165,0xb878004e,0x6a7808a5}},	//   _exhí, _accp_, _quíl, _líft, 
   {{0x3a28058a,0x3b0401f0,0x00000000,0x00000000}},	//   _bccp_, иеро_, --, --, 
   {{0xbdd83d0a,0x6aa5b020,0xbea0010b,0xddd40784}},	//   rdèr, unif, _мащк, šašp, 
   {{0x6aa52738,0x673c1711,0x3a28005a,0x00000000}},	// [2ee00] rnif, _sprj, _dccp_, --, 
   {{0x1ce0025c,0x6aa42994,0x2ee00009,0x1cc40327}},	//   _སྤི_, snif, _hiif_, _ཏེར_, 
   {{0x2cb85629,0x6a7804d7,0x2ee0002d,0x3e7800e8}},	//   mord_, _sífu, _kiif_, _sëti_, 
   {{0x2cb9b021,0x2ee00067,0x6f00015d,0xb6c801d3}},	//   lord_, _jiif_, _mwnc, نانے_, 
   {{0x65c8010b,0xba980a7c,0x00000000,0x00000000}},	//   уңам_, _יסטי, --, --, 
   {{0x2cb9b022,0x2ee19888,0x7d540a1e,0x9f5db023}},	//   nord_, _liif_, יינד_, _levá_, 
   {{0xd40800c6,0xbae001ec,0x00000000,0x00000000}},	//   اتهم_, _ﻋﺎﺟﺎ, --, --, 
   {{0x2cb80d81,0xddcdb024,0x92a801e0,0x00000000}},	//   hord_, _plaż, лсыҡ_, --, 
   {{0x635c00a8,0x0449b025,0xa1940f15,0x00000000}},	//   _sănă, _ипак_, сапч, --, 
   {{0x2cb800cc,0x741000f7,0x6f000142,0x3e500051}},	//   jord_, _ووقا, _bwnc, _ệt_, 
   {{0x9ed80261,0x03942bbe,0x62f000cc,0xc2440108}},	//   лмот_, _трая, _টিকট_, _внек, 
   {{0x9f4c0548,0x249c003a,0x00000000,0x00000000}},	//   dadô_, livm_, --, --, 
   {{0x6a78008c,0xb8780597,0x2cb9b026,0x2ee0058a}},	//   _lífs, _suím, ford_, _diif_, 
   {{0x705010fe,0x3a280798,0x6f000142,0x249c003a}},	//   _وننا, _sccp_, _fwnc, nivm_, 
   {{0x200db027,0x2ee00a85,0xdcb00131,0x3a280327}},	//   madi_, _fiif_, قىڭ_, _pccp_, 
   {{0x200db028,0x6281b029,0x2ee000e8,0xeaf82c26}},	//   ladi_, nkmo, _giif_, شرفت_, 
   {{0xa978fb04,0x00000000,0x00000000,0x00000000}},	// [2ee10] айту_, --, --, --, 
   {{0x200db02a,0x2cb8ea90,0xf77000c6,0xb81c00eb}},	//   nadi_, cord_, ياض_, ন্নত_, 
   {{0x200c011c,0xb7640228,0x1ce0031c,0xfba8084c}},	//   iadi_, штай, _སྤག_, _штий_, 
   {{0x200db02b,0x4fd800c8,0x2ee01bce,0x30c00116}},	//   hadi_, אַנד, _xiif_, _ﯬﭘﻪﻧ, 
   {{0xe618005e,0x200db02c,0xa3d402db,0x00000000}},	//   рді_, kadi_, सेस_, --, 
   {{0x200db02d,0x1cc40327,0x25a00332,0x00000000}},	//   jadi_, _ཏེས_, úila_, --, 
   {{0x200c5975,0x62800093,0xc8640150,0xe785b02e}},	//   dadi_, fkmo, _دەلو_, _дуто, 
   {{0x3e78044e,0x2cb8382f,0xd2648083,0x7ae004fb}},	//   _këtu_, zord_, ский, _éntu, 
   {{0x200db02f,0x79980432,0x00000000,0x00000000}},	//   fadi_, _ýuwd, --, --, 
   {{0x200db030,0x2ee0198f,0xfd1c04cc,0xe4e4cea6}},	//   gadi_, _siif_, drì_, _фітн, 
   {{0xe8081d68,0x91680051,0x999800c0,0x00000000}},	//   षरता_, _dứt_, _kasų_, --, 
   {{0x2cb9b031,0x0ae80046,0x6a780008,0xfd1c468a}},	//   word_, ғдай_, _lífr, frì_, 
   {{0x0d9805f5,0xfd1c0ffb,0x7af40175,0xbb5000b5}},	//   утны_, grì_, _atxt, janコ_, 
   {{0x200db032,0x2ee0045f,0x00f40375,0x00000000}},	//   cadi_, _wiif_, _המסך_, --, 
   {{0xc0500302,0x2ee00ba7,0x7af40175,0x00000000}},	//   _מזג_, _tiif_, _ctxt, --, 
   {{0x3e780de2,0xfd1c011c,0x7c380331,0xded80022}},	//   _bëtu_, brì_, đura, _кьыш_, 
   {{0x49c9b033,0xfd1c011c,0xe51c5829,0x32dc000d}},	// [2ee20] улан_, crì_, _निधि_, _पूछऽ, 
   {{0x38600223,0x6a780022,0x0c24014b,0x00000000}},	//   _cnjr_, _cífr, _умон, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x200db034,0x1cc40327,0xbb38010f,0x06a000d1}},	//   zadi_, _ཏེོ_, _געטי, ﺋﺎﻣﯩ, 
   {{0x249c003a,0x45347de7,0xc9540139,0x00000000}},	//   tivm_, схет, _утны, --, 
   {{0x200db035,0x6d480210,0x00000000,0x00000000}},	//   xadi_, łdaw, --, --, 
   {{0x33140491,0x3e78002e,0x249c003a,0xe3b80205}},	//   مزيد_, _këtt_, rivm_, _acır_, 
   {{0x200c1cdf,0x96947b00,0x325002e8,0x00000000}},	//   wadi_, _друш, звър, --, 
   {{0x200db036,0x3e78d695,0x717402e8,0x05a83b8f}},	//   tadi_, _mëtt_, йбър_, _свай_, 
   {{0xfd1c05d5,0x26dc0118,0xc68c00f1,0x799800a2}},	//   vrì_, ůvod_, _غېږ_, _ýuwe, 
   {{0x200db037,0xea0001fb,0x3d18012c,0x058401af}},	//   radi_, _ngắt_, _बिहे_, _туңм, 
   {{0x200db038,0xb7d8008f,0xf7700375,0x3e780221}},	//   sadi_, טקיי, לקת_, _nëtt_, 
   {{0x200c94bb,0xc0580212,0xa3d400bc,0x00000000}},	//   padi_, _бій_, सेर_, --, 
   {{0x200c2af6,0xfd1db039,0xab3800d1,0x00000000}},	//   qadi_, rrì_, әпту_, --, 
   {{0x3e7800e8,0xb0242309,0xdb0401e3,0x3098011a}},	//   _bëtt_, _اكىم_, _lyhö, _תשומ, 
   {{0xfd1c4d72,0xd9f80276,0xaa9403c2,0x00000000}},	//   prì_, рнац_, писч, --, 
   {{0x98754b35,0xaa58034b,0xfca84609,0x99980064}},	// [2ee30] олац, щиту_, _مادو_, _rasų_, 
   {{0x3b11b03a,0xb7640150,0x5e3400e5,0x00000000}},	//   _tvxq_, йтей, _اڑھا, --, 
   {{0x999800c0,0x00000000,0x00000000,0x00000000}},	//   _pasų_, --, --, --, 
   {{0x3e78092e,0xfbd00050,0xb4c00b67,0x00000000}},	//   _gëtt_, _وتھ_, ृष्_, --, 
   {{0xfd640055,0x49a4190b,0x00000000,0x00000000}},	//   _purṣ, _дырғ, --, --, 
   {{0x22ac012c,0xdef0001f,0xe3b803b9,0xa8a414b3}},	//   věka_, ፃለን_, _acıq_, _ерск, 
   {{0xa3d40574,0xf38c0051,0x998c01ef,0x00000000}},	//   सेल_, _nợtk_, _žeň_, --, 
   {{0xc7b00302,0x62240131,0x3e7800e8,0x12b80154}},	//   _חבל_, كۈمە, _xëtt_, ুদ্দ, 
   {{0x9f5c01f4,0x00000000,0x00000000,0x00000000}},	//   _levä_, --, --, --, 
   {{0xf6e4025c,0x00000000,0x00000000,0x00000000}},	//   _སྤོང, --, --, --, 
   {{0x0ea8034b,0xdb1406af,0xf40c0183,0x245000d1}},	//   икой_, _ébèn, _সাপৰ_, _سۆيس, 
   {{0x0ce000dc,0x28d005dc,0x00000000,0x00000000}},	//   पद्म, _तीनि, --, --, 
   {{0x2d84d830,0xc0b80023,0xc0d000ec,0x59b40d2e}},	//   áme_, ደምም_, _ڪيوب, _अँगर, 
   {{0x59180327,0xb81c00fe,0x629c0241,0x00000000}},	//   ུངནས_, ন্তত_, _ìror, --, 
   {{0x2d840f91,0x4a980006,0x317c022e,0x00000000}},	//   šme_, атаў_, lyuz_, --, 
   {{0x7fb43229,0x00000000,0x00000000,0x00000000}},	//   _ظهير_, --, --, --, 
   {{0xfc5801ec,0x1ea816ac,0xfaa063dd,0xf3fc0208}},	// [2ee40] _ءﯗﻥ_, _داوي_, фато, _đãn_, 
   {{0xd90c7b02,0x291c01ef,0x00000000,0x00000000}},	//   طیف_, čva_, --, --, 
   {{0x3ce005f9,0x09e45ce4,0x20180030,0x85e800d8}},	//   _टूटे_, _монн, órii_, адев_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x317c0007,0xb81c03d4,0xe3b80205,0x00000000}},	//   jyuz_, ন্ধত_, _acıp_, --, 
   {{0x6354481b,0x7ae00c6a,0x00000000,0x00000000}},	//   звку, _éntr, --, --, 
   {{0xa3d406ab,0xb88c0092,0x2bc0012d,0xe8000c22}},	//   सें_, _መረጃው_, _शुमा, _ल्या_, 
   {{0x0664005e,0x32b400c6,0xf2c00961,0x34800139}},	//   _باسپ, يدية_, мсын, згәг, 
   {{0x25086e92,0x00000000,0x00000000,0x00000000}},	//   _درزی_, --, --, --, 
   {{0x2bc008ec,0x44280fac,0x00000000,0x00000000}},	//   _शुभा, _øb_, --, --, 
   {{0xbfa80220,0x443c0051,0x525000ec,0xde5800d4}},	//   ртпе_, _ibt_, _ڳچيء, бані_, 
   {{0x443db03b,0xdb1406af,0x00000000,0x00000000}},	//   _hbt_, _ébén, --, --, 
   {{0xb95801e1,0x443db03c,0x37a800fe,0x00000000}},	//   _ayìn, _kbt_, _কৰাৰ, --, 
   {{0x443c1505,0x00000000,0x00000000,0x00000000}},	//   _jbt_, --, --, --, 
   {{0x443c0f85,0x20d001c3,0x00000000,0x00000000}},	//   _mbt_, ràid_, --, --, 
   {{0x443db03d,0xa2d007f7,0x00000000,0x00000000}},	//   _lbt_, _डीम्, --, --, 
   {{0xa93412b9,0xc4c8033f,0x25a001e7,0x00000000}},	// [2ee50] метш, िताओ, úill_, --, 
   {{0xd2580022,0x00000000,0x00000000,0x00000000}},	//   moņe_, --, --, --, 
   {{0x2e24072d,0x00000000,0x00000000,0x00000000}},	//   _عفیف, --, --, --, 
   {{0x443c0b84,0x8bd400d9,0xe51c00cd,0x00000000}},	//   _abt_, _מותו_, _निशि_, --, 
   {{0x443db03e,0x94780024,0x4610009a,0x00000000}},	//   _bbt_, йску_, روور, --, 
   {{0xbcf80077,0x00000000,0x00000000,0x00000000}},	//   lxés, --, --, --, 
   {{0xf62800d4,0x81e400eb,0x00000000,0x00000000}},	//   _візи_, _বড়ই_, --, --, 
   {{0x33240227,0x645c03b2,0x6234010a,0x00000000}},	//   runx_, _órin, çеку, --, 
   {{0x317c0399,0xc0d00092,0x925800f2,0x00000000}},	//   uyuz_, _የለሽ_, لشکر_, --, 
   {{0x33240327,0x00000000,0x00000000,0x00000000}},	//   punx_, --, --, --, 
   {{0x317c0ac5,0x04780014,0x845000cf,0x6e2003b2}},	//   syuz_, _دلٕک_, _سۉيچ, ómbo, 
   {{0x326001d9,0x52d8005b,0x00000000,0x00000000}},	//   _زنتہ, _умею_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd0480115,0x229402dd,0x00000000,0x00000000}},	//   lpeɾ, _ىلەس, --, --, 
   {{0x966802dd,0xf1dc190c,0x00000000,0x00000000}},	//   _ﺍﺗﺎﭖ_, _पृतन, --, --, 
   {{0xdc9402d3,0x8e0800f3,0xdce80210,0x00000000}},	//   _ሃገረይ_, _унив_, _śląz, --, 
   {{0x3a20009d,0x7c30036e,0x088807a5,0x00000000}},	// [2ee60] эмтг, çerë, ббай_, --, 
   {{0xbcf8172e,0x6d442b1d,0x9d4405d9,0x5ed0009e}},	//   rxét, _ipia, _آئين, _সংযে, 
   {{0xb8f00d5f,0x443c194f,0xbc780375,0xeb340137}},	//   _ही_, _rbt_, _הנית, _تۉزد, 
   {{0x443c06ed,0xd01006c8,0x63bc0174,0x59b400c5}},	//   _sbt_, hā_, _ørni, _अँचर, 
   {{0x443c0ac5,0xf864515c,0xe534dab7,0x48e473f9}},	//   _pbt_, تمەي_, фель, _хогв, 
   {{0x6d441311,0x2901b03f,0x799800ee,0x00000000}},	//   _mpia, mpia_, _ýuwa, --, 
   {{0x6d480882,0xf8600075,0x96f80153,0x00000000}},	//   āday, _явро, _мэту_, --, 
   {{0x443c0ac5,0x2718033b,0x00000000,0x00000000}},	//   _wbt_, mčn_, --, --, 
   {{0x850433bb,0x6d440218,0x629c0006,0xc0580046}},	//   _روان, _npia, _įrod, бін_, 
   {{0x3edc00b4,0xbdd8756d,0x656001ab,0x2901b040}},	//   _mmụọ_, lfèg, _irmh, ipia_, 
   {{0x6d45b041,0x3d0c0574,0x22400de2,0xdeb4004e}},	//   _apia, तीने_, _ñiko_, дбны, 
   {{0x2900008b,0x1cc4025c,0x27200311,0x6d4400ae}},	//   kpia_, _ཏེང_, mănă_, _bpia, 
   {{0x863c0092,0x00000000,0x00000000,0x00000000}},	//   _በኮንት, --, --, --, 
   {{0x271802e2,0x39a000af,0x32e40208,0x00000000}},	//   kčn_, _कs_, _tđyt_, --, 
   {{0x3edc01f2,0x20180030,0x6459b042,0x97480023}},	//   _amụọ_, óriu_, idvi, _ሓልዮት, 
   {{0xdd9045d7,0x2718007f,0xcfa80214,0xf3fc0051}},	//   _لوب_, dčn_, _باهم_, _đãm_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [2ee70] --, --, --, --, 
   {{0xed600006,0xfca8015e,0xa854004e,0x00000000}},	//   įžti_, _دابو_, нкуч, --, 
   {{0x201c0589,0x6560b7bf,0x442c0175,0x35f8621e}},	//   _mdvi_, _armh, dgf_, مرشد_, 
   {{0xa6c40075,0x1a65b043,0x64580165,0x68a40023}},	//   ىقلى, _تیری_, edvi, _ገዛውቲ_, 
   {{0x656002c4,0x00000000,0x00000000,0x00000000}},	//   _crmh, --, --, --, 
   {{0x58d401c0,0x3d0c0b7c,0xbcf800e5,0x00000000}},	//   _цогт, तीये_, mvéd, --, 
   {{0xe738034b,0x34080c75,0xdcfc0064,0x00000000}},	//   _неё_, _ۇزاپ_, dysč, --, 
   {{0x6458d45e,0x516400d4,0x00000000,0x00000000}},	//   advi, двиб, --, --, 
   {{0x65944f52,0xe880001f,0x7649b044,0xbcf801d3}},	//   _зату, _የረጅም_, megy, nvéd, 
   {{0x00c40d31,0xdcfc00c0,0x00000000,0x00000000}},	//   млык_, gysč, --, --, 
   {{0x6d4564c3,0xce481b4f,0x75280112,0x2900005a}},	//   _spia, озне_, lugz, zpia_, 
   {{0x290040c0,0xb62c00b5,0x7649b045,0xbcf800e5}},	//   ypia_, _ｓｖ_, negy, kvéd, 
   {{0x81f4103c,0x66ec05d1,0xea00004d,0x27180100}},	//   _غفور_, _işke, _ngạt_, zčn_, 
   {{0x20d000a3,0xa3d42ef1,0x27180100,0x764801d3}},	//   ràic_, सेक_, yčn_, hegy, 
   {{0xfce1b046,0xb8780d2a,0x6d440175,0xbcf800e4}},	//   торо, _luís, _wpia, yvég, 
   {{0x764800dd,0x64580122,0x6d402ca8,0x320c01d3}},	//   jegy, zdvi, çmas, _jegy_, 
   {{0x320c00dd,0x2fc40098,0x6d440309,0xbcf801d3}},	// [2ee80] _megy_, _hyng_, _upia, gvéd, 
   {{0x27180100,0x3a28013a,0x00000000,0x00000000}},	//   tčn_, _čipů_, --, --, 
   {{0xbcf800dd,0x764800e5,0x799800a2,0x00000000}},	//   tvég, fegy, _ýuwn, --, 
   {{0x2901b047,0xb87806ed,0x248c0204,0x7649b048}},	//   ppia_, _suít, _sldm_, gegy, 
   {{0x6aa5b049,0x2fc40ac8,0x248c054e,0xbcf88745}},	//   miif, _lyng_, _pldm_, rvég, 
   {{0x6aa564ed,0xb878215a,0x6459903b,0x27f800d8}},	//   liif, _quít, udvi, _ufrn_, 
   {{0x1778169c,0x7649b04a,0x6458aea2,0x2fc406a3}},	//   _есть_, begy, rdvi, _nyng_, 
   {{0x6aa422a9,0x00000000,0x00000000,0x00000000}},	//   niif, --, --, --, 
   {{0xb8780005,0x248c0ac5,0xb978008f,0xb5c00166}},	//   _guís, _tldm_, ַנטי, _айтл, 
   {{0x2fc40158,0x6aa40ba7,0x66ec008e,0x00000000}},	//   _byng_, hiif, _eşke, --, 
   {{0x98a8068f,0x6aa43f11,0x2fc4015d,0xceac0451}},	//   stać_, kiif, _cyng_, ڍڙي_, 
   {{0xbd691152,0x6aa48ebb,0x52740116,0xbcf801d3}},	//   орге_, jiif, _пучу, yvéd, 
   {{0x6aa5362c,0x00000000,0x00000000,0x00000000}},	//   diif, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7649b04b,0x2fc4045f,0x6aa5b04c,0x9f5c5522}},	//   yegy, _gyng_, fiif, _nevø_, 
   {{0xbcf800dd,0x6aa40af5,0x63bc03cd,0xeab1b04d}},	//   tvéd, giif, _ørnu, لعق_, 
   {{0xb83001e1,0x764800e5,0x99980395,0x00000000}},	// [2ee90] _ajúṣ, vegy, чкат_, --, 
   {{0xd7940801,0x76481418,0xbcf81bbf,0x00000000}},	//   низъ, wegy, rvéd, --, 
   {{0x7649b04e,0x6aa40ba7,0xe57001b9,0xd758007b}},	//   tegy, biif, یطه_, ثلات_, 
   {{0x6aa40014,0x00000000,0x00000000,0x00000000}},	//   ciif, --, --, --, 
   {{0x7649b04f,0x320c002d,0xd468b7f6,0xe61000ec}},	//   regy, _regy_, зиле_, ششن_, 
   {{0x76480aaa,0x75280d27,0xd25800de,0x00000000}},	//   segy, rugz, doņa_, --, 
   {{0x26c41132,0x5695b050,0x66f4399f,0x764801d3}},	//   _fkmo_, _завт, _апсу, pegy, 
   {{0x2fc5b051,0xe3b00da4,0x67d401b9,0x00000000}},	//   _ryng_, جره_, _росу, --, 
   {{0x2fc51ba3,0x7690010e,0xe19401c6,0x00000000}},	//   _syng_, _açyg, врээ, --, 
   {{0x8fd00032,0x6aa402d0,0x9cf000fe,0xc950011a}},	//   ләйә, ziif, জীৱন_, נמי_, 
   {{0x2055a4ac,0x444401d9,0x00000000,0x00000000}},	//   ттыр, _سرٕہ, --, --, 
   {{0x201809f3,0x6aa4208d,0xc7b00a7c,0xd25800ef}},	//   órir_, xiif, רבט_, boņa_, 
   {{0xb80c584e,0x611402d5,0xdcfc00ef,0x00000000}},	//   िराम_, _адчу, dzsē, --, 
   {{0x6aa40472,0xdb0800bc,0x2fc40254,0x00000000}},	//   wiif, _žláz, _tyng_, --, 
   {{0x0ba804da,0xbb40a6d1,0x6aa4198f,0x00000000}},	//   ساسى_, лерк, tiif, --, 
   {{0xa3d423ef,0x00000000,0x00000000,0x00000000}},	//   सेट_, --, --, --, 
   {{0x6aa5b052,0x79980432,0x00000000,0x00000000}},	// [2eea0] riif, _ýuwl, --, --, 
   {{0xbcf8004a,0x6aa40a55,0x20d001ab,0x00000000}},	//   uvée, siif, hàin_, --, 
   {{0x8ba48b1f,0xbcf807ea,0x7ce80003,0x6aa420ac}},	//   _чинж, rvée, _iżra, piif, 
   {{0x0c040014,0x6aa40ba7,0x00000000,0x00000000}},	//   _توگُ, qiif, --, --, 
   {{0x2458009d,0xdc2802f2,0x00000000,0x00000000}},	//   даль_, _عسیه_, --, --, 
   {{0x07a403f5,0xaeec000d,0x00000000,0x00000000}},	//   _загн, _घंूघ_, --, --, 
   {{0xaac400bc,0x00000000,0x00000000,0x00000000}},	//   वकपक, --, --, --, 
   {{0xd36c1e4a,0x7d180153,0xb7d400be,0x00000000}},	//   تۇم_, šusi, _سوقا_, --, 
   {{0xa3d4166d,0xf1d80490,0xa19400ee,0xc0580220}},	//   सेज_, मेलन, тапч, пін_, 
   {{0x80c8033f,0x03940395,0xb934010f,0xe5a401a9}},	//   _सीखे, _прея, עניו_, _зиғи, 
   {{0xbfa811ed,0x3f8802fb,0x78a800e5,0x00000000}},	//   ятие_, ábu_, égvi, --, 
   {{0xf3fc001e,0x649408c2,0xdd90866a,0xb87800e4}},	//   _đãi_, _bàig, لوج_, _luíp, 
   {{0xa2800133,0x00000000,0x00000000,0x00000000}},	//   _میژو, --, --, --, 
   {{0x9f59b053,0xe8000406,0x63bc01bf,0x00000000}},	//   úró_, _ल्ला_, _ørns, --, 
   {{0xca7c001f,0x9988010f,0x1ae80022,0x5f9401af}},	//   _የለኝም_, rgaŭ_, дуаҿ_, _шикт, 
   {{0x649401ab,0x9ee8007b,0x00000000,0x00000000}},	//   _fàig, _تفعل_, --, --, 
   {{0x649400a3,0x78245230,0xad6400ec,0x00000000}},	// [2eeb0] _gàig, فعال, _مٿيو, --, 
   {{0xa5300023,0x7998010b,0xd9ec000d,0x00000000}},	//   _ብሰራዊ, _ýuwm, _झलकत_, --, 
   {{0x649400a3,0xf86400f1,0x1ab400c0,0x36e800d1}},	//   _màid, ومړي_, _абня, سراپ_, 
   {{0x64940192,0xbdd8007f,0x76c40472,0x00000000}},	//   _làid, beèt, رغال, --, 
   {{0xe3b800ac,0x6604005a,0x8a14011a,0x00000000}},	//   _axı_, ñika, _בחרו_, --, 
   {{0xb4b82d3b,0xd5d400fb,0x53a40733,0xd66800ec}},	//   घवे_, нюһы, калб, _ڪمرو_, 
   {{0x63c40184,0x1cc4025c,0x67d40ab2,0x65c002dd}},	//   лашҡ, _ཏེན_, _бору, _құша, 
   {{0x59d402ab,0x040403d4,0x00000000,0x00000000}},	//   _दरार, _ৰাণী_, --, --, 
   {{0xb3e81c67,0x649401c3,0x28b805f9,0x20d001c3}},	//   _فعال_, _bàid, _आदमि, ràin_, 
   {{0x7ea80108,0x00000000,0x00000000,0x00000000}},	//   yöpä, --, --, --, 
   {{0x765823db,0x71f80014,0x3d0c0406,0xf364010b}},	//   _kauy, _فرشس_, तीसे_, _ятан, 
   {{0x7ae000f2,0x649408c2,0xb8d0031c,0x00000000}},	//   _ènth, _pàig, _ཝམ_, --, 
   {{0x50b4a230,0xe1f1b054,0x7658004c,0x7e7c0477}},	//   _иску, _اسم_, _mauy, _doqp, 
   {{0x64940571,0x76580c09,0x10a4009d,0x7ea80108}},	//   _gàid, _lauy, _шилн, töpä, 
   {{0x80c8033f,0x66d80118,0x0f340153,0x00000000}},	//   _सीटे, líke, _рэля, --, 
   {{0x7659b055,0xba209c0b,0x20d000a3,0x00000000}},	//   _nauy, идск, hàil_, --, 
   {{0xeff00201,0xea0001fb,0xc2100375,0xbcf806af}},	// [2eec0] _ፍርድ_, _ngất_, יהן_, rvéc, 
   {{0x66ec03be,0x9f5c0118,0x00000000,0x00000000}},	//   _aşka, _levý_, --, --, 
   {{0xb6f40075,0xe3b9b056,0x7e7c014f,0xf59000f2}},	//   نىلا_, _adın_, _yoqp, یلمج, 
   {{0xbae00131,0x769000a2,0x7ae400f1,0x00000000}},	//   _ﺋﺎﺳﺎ, _açyb, _ټوټې_, --, 
   {{0x76580481,0x45340304,0x00000000,0x00000000}},	//   _dauy, тхет, --, --, 
   {{0x54180328,0x66d801ef,0x00000000,0x00000000}},	//   ىرىڭ_, díke, --, --, 
   {{0x07a41631,0x039400a7,0x649401ab,0xf4840fc6}},	//   _равн, ърдя, _ràid, خانی, 
   {{0x357000dd,0x7a4402b5,0x00000000,0x00000000}},	//   _چھوڑ, _tītō, --, --, 
   {{0x273c00ae,0x649400a3,0xb111b057,0xc4e400cf}},	//   lín_, _pàid, амыш, _ажай, 
   {{0x7e7c0477,0x73300145,0xc06401a9,0x00000000}},	//   _soqp, _چىلا, тъий, --, 
   {{0x273d7f9e,0x7659b058,0x7e7c0455,0xdb0806ea}},	//   nín_, _yauy, _poqp, _ónøg, 
   {{0xb281b059,0x3e68020a,0x935801c0,0x7e7c014f}},	//   _вышк, фшон_, _яруу_, _qoqp, 
   {{0x7ae000f2,0x273d0358,0xd5e80241,0x41740137}},	//   _ènti, hín_, _ilẹ, _جااس, 
   {{0x9f340046,0x273ce10d,0xdfd40139,0x00000000}},	//   _бекі, kín_, _йолы, --, 
   {{0x273c01f1,0x30c40e26,0x63a401e4,0xafa000ec}},	//   jín_, _جووپ_, ŝinf, _پٽيو, 
   {{0x273c01a2,0x3e7804e6,0x7e7c0175,0x799800a2}},	//   dín_, _lëtz_, _uoqp, _ýuwk, 
   {{0x76580099,0x58d801f4,0x00000000,0x00000000}},	// [2eed0] _rauy, едая_, --, --, 
   {{0x7659b05a,0x7d19108d,0x273db05b,0xfca842b5}},	//   _sauy, áusu, fín_, _زاخو_, 
   {{0x273db05c,0x76580810,0x59d40073,0x00000000}},	//   gín_, _pauy, _दरवर, --, 
   {{0xb60435dd,0x00000000,0x00000000,0x00000000}},	//   тяжк, --, --, --, 
   {{0x76580433,0x961c005f,0x00000000,0x00000000}},	//   _vauy, _noņe, --, --, 
   {{0x273db05d,0x9f5c29ef,0x394801c8,0x7658004c}},	//   bín_, _bevü_, _ipcs_, _wauy, 
   {{0x7659b05e,0x273db05f,0xf6e40024,0x00000000}},	//   _tauy, cín_, _ацан, --, 
   {{0x8fd00032,0xe8e0004d,0x06a000d1,0x00000000}},	//   ҙәлә, _đỉa_, ﺋﺎﻟﯩ, --, 
   {{0x10145238,0x649408c2,0x2175b060,0x00000000}},	//   льня, _dàib, ауэр, --, 
   {{0xeff0069c,0x4f081188,0xa4d801c0,0x961c0171}},	//   _ፍርዲ_, ннон_, _адуу_, _doņe, 
   {{0x9f6801b9,0xe4ec0037,0x9f580162,0x00000000}},	//   врўз_, _छूटि_, úrð_, --, 
   {{0x2e840fc0,0x00000000,0x00000000,0x00000000}},	//   рғиб, --, --, --, 
   {{0x273c1dee,0x3ea10dc8,0x3d0c012c,0x5045b061}},	//   zín_, сияг, तीले_, _белб, 
   {{0xac9c044e,0xe3b80139,0x00000000,0x00000000}},	//   _ሃገሮም_, _odıl_, --, --, 
   {{0x273cf8bc,0x63a401e4,0x00000000,0x00000000}},	//   xín_, ĝing, --, --, 
   {{0x273c01f1,0x63a4010f,0x00000000,0x00000000}},	//   vín_, ŝing, --, --, 
   {{0x6e25b062,0xc9640312,0xbcf81a74,0x7d1803b2}},	// [2eee0] _idib, ывай, lvén, áust, 
   {{0xc8c84973,0x395c0135,0xb4bc043e,0x7d180003}},	//   روان_, _ġust_, ीतो_, ġust, 
   {{0xbcf9b063,0x998800d7,0x00000000,0x00000000}},	//   nvén, rgaš_, --, --, 
   {{0x273db064,0x3e780221,0xbcf80022,0xe604008e}},	//   rín_, _sëtz_, ivén, рҗан, 
   {{0x273db065,0x99741a92,0x3e7801c7,0x25a008c2}},	//   sín_, _курш, _pëtz_, àil_, 
   {{0x2a60007d,0x273db066,0xe7043267,0x00000000}},	//   ldib_, pín_, _نسری, --, 
   {{0x6e25b067,0x00000000,0x00000000,0x00000000}},	//   _odib, --, --, --, 
   {{0x6e25b068,0x2a600037,0x66ec03e0,0xe884010a}},	//   _ndib, ndib_, _işko, _йӳçп, 
   {{0xfdbc0183,0xdfd000ec,0x00000000,0x00000000}},	//   _ইণ্ড, ڪيد_, --, --, 
   {{0x6e25b069,0x39540302,0x649400a3,0x6f000175}},	//   _adib, נשים_, _dàic, _btnc, 
   {{0xc300004b,0xdfd00a0a,0xdfd40150,0x9ed8004e}},	//   _اړتی, تيد_, роны, кмот_, 
   {{0x7b4400d0,0x63a40115,0x00000000,0x00000000}},	//   nčuš, ĝind, --, --, 
   {{0xa1140058,0x2a6001d9,0x6e2400a9,0xbcf800e4}},	//   _ئوتت, ddib_, _ddib, avén, 
   {{0x6e25b06a,0x313406a9,0xe298013d,0x00000000}},	//   _edib, _ערוך_, _яаҗ_, --, 
   {{0xf1680131,0xba4434ae,0x3948007c,0x200c03b2}},	//   _ﯰﻳﻐﯘ, лхай, _spcs_, mbdi_, 
   {{0xaa58894b,0x00000000,0x00000000,0x00000000}},	//   лису_, --, --, --, 
   {{0xf804e2cc,0x64480122,0xa7e40131,0x66ec0205}},	// [2eef0] гчен, _obdi, ەكلى, _aşko, 
   {{0xe3b80d9c,0x780c2ca5,0xa8140395,0x6e2401ef}},	//   _adım_, िरेक_, йдуш, _zdib, 
   {{0x2a60113c,0x7690010e,0xdec80092,0x00000000}},	//   bdib_, _açya, _በማን_, --, 
   {{0x6449b06b,0xb4bc0a28,0x7af40483,0x00000000}},	//   _abdi, ीत्_, _iuxt, --, 
   {{0xfd1db06c,0x7aec01e2,0xbcf800dd,0x28080118}},	//   nsì_, _iict, zvén, ítné_, 
   {{0x1abc00bd,0x7af400b5,0xe8040034,0x64480009}},	//   _আওয়া, _kuxt, शुदा_, _cbdi, 
   {{0x7af5b06d,0x6b500086,0xd7c81272,0x00000000}},	//   _juxt, mògò, _شوره_, --, 
   {{0x7af5b06e,0x52841171,0x658801e7,0x20181427}},	//   _muxt, ргиб, íshá, ðrin_, 
   {{0xc0d00201,0x7aec090c,0x7af40036,0x7ae00066}},	//   _የለም_, _mict, _luxt, _èntu, 
   {{0xe8e007ae,0x7aec0381,0x10a5b06f,0xbcf801d3}},	//   _địa_, _lict, рион, tvén, 
   {{0xe4e401d9,0x66d993d6,0x6b4c01ed,0x119c0023}},	//   _آلَ, líka, _mögö, _ንድምጺ_, 
   {{0xbcf800dd,0x7aecec0b,0xb644105c,0xe1f00133}},	//   rvén, _nict, _ｋｇ_, _فسه_, 
   {{0x4654010f,0x63a40115,0x4dd40212,0x00000000}},	//   בױרן_, ĝine, рінф, --, 
   {{0x7af5b070,0xc1980375,0x1a140183,0x66ec05d1}},	//   _buxt, _בשני, িলোঁ_, _aşkl, 
   {{0x7aec0429,0x80c0033f,0xfbd00014,0x00000000}},	//   _bict, रकरे, قتٲ_, --, 
   {{0x6e25b071,0x8a05b072,0x7af401a9,0x00000000}},	//   _udib, рзае, _duxt, --, 
   {{0x7aec5f7a,0xfdb00075,0x6b4c6971,0x9f5c03b2}},	// [2ef00] _dict, _дәря, _bögö, _hevð_, 
   {{0xfd1001ed,0x00000000,0x00000000,0x00000000}},	//   _بجٹ_, --, --, --, 
   {{0x6494004e,0x7aedb073,0x6b4c00e5,0x00000000}},	//   _nàia, _fict, _dögö, --, 
   {{0x0564049d,0x22980241,0x940403e3,0x09340137}},	//   ивен, _kéke_, _illə_, _پىسح, 
   {{0xdbd0032e,0x00000000,0x00000000,0x00000000}},	//   _hýði, --, --, --, 
   {{0x33f00952,0xa438023a,0x7af426b6,0x960400d1}},	//   يسىس, узку_, _yuxt, لبۇم, 
   {{0xfdd002ab,0x7aec003a,0x66ec013d,0x00000000}},	//   _सर्फ, _yict, _uşko, --, 
   {{0x3ea801f5,0x1dc806ff,0xbcf8032e,0x00000000}},	//   xict_, रथमत, fvél, --, 
   {{0xbcf801a8,0x91c8012c,0xdbd01d1d,0x769000a2}},	//   gvél, _हुदै, _lýði, _uçya, 
   {{0x6448035a,0x60980014,0xaac80073,0x00000000}},	//   _ubdi, اندس_, लवडक, --, 
   {{0x050c03d4,0x00000000,0x00000000,0x00000000}},	//   _সময়ৰ_, --, --, --, 
   {{0xdfd4005e,0x7af4008e,0x229800e5,0xa03400db}},	//   _қойы, _ruxt, _béke_, جىگت, 
   {{0x7af40bc9,0x7aec0381,0x3ea8f843,0xfd4402d5}},	//   _suxt, _rict, rict_, шэнн, 
   {{0x7af4036b,0x22980036,0xdbd003b2,0x7aec0356}},	//   _puxt, _déke_, _býði, _sict, 
   {{0x3ea87db2,0x7aedb074,0xfaa5b075,0xac185378}},	//   pict_, _pict, ашан, росу_, 
   {{0x19580372,0xef14151e,0x2904025c,0xbae000d1}},	//   лабы_, _өмә_, _ħmar_, _ﺋﺎﺗﺎ, 
   {{0x6b5c4e97,0xdd91b076,0x3f9c005a,0x9e8403e6}},	// [2ef10] _pågå, _رود_, lztu_, _ناکۆ, 
   {{0xf8049737,0x66d80579,0x7af5b077,0x60c80477}},	//   рчан, víka, _tuxt, nodm, 
   {{0x7aedb078,0x6b4c01b8,0x6b5c0158,0xdb20005b}},	//   _tict, _vögö, _vågå, ötäv, 
   {{0x7aec1730,0xb87906c9,0x60c80c8c,0x16341064}},	//   _uict, _juíz, hodm, седя, 
   {{0x60c801e3,0x89d80451,0xd548009a,0x00000000}},	//   kodm, _موٽر_, التو_, --, 
   {{0x60c80010,0xdb0802d2,0x00000000,0x00000000}},	//   jodm, _ónóg, --, --, 
   {{0xd7940491,0x17e40183,0x6d400213,0xd7380092}},	//   _الأخ, _প্ৰি, çmaz, _ያልሆነ, 
   {{0x92380064,0x85540050,0x66d9b079,0x00000000}},	//   учку_, _گیٖر_, líkn, --, 
   {{0x6595b07a,0x3f9c00de,0x00000000,0x00000000}},	//   _дату, eztu_, --, --, 
   {{0x732401ed,0x98a8107d,0xbcf801a8,0x229801e1}},	//   _نقطہ_, krač_, rvél, _réke_, 
   {{0xb4e03d4d,0x8ee807c6,0x00000000,0x00000000}},	//   नगी_, лмов_, --, --, 
   {{0x98a80010,0xe8e00208,0xa3dc0073,0xd05406be}},	//   drač_, _đọa_, _ठरत_, _əbər, 
   {{0x91042bbd,0x998c010e,0x98a800d7,0x00000000}},	//   _упле, _ýeň_, erač_, --, 
   {{0xfc00f4c0,0x649401ab,0xcf580798,0xd2580171}},	//   зпро, _làin, _брич_, doņi_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfaa000f5,0xdfd80395,0xff2402cb,0x00000000}},	//   пасо, _тъч_, _ابوی, --, 
   {{0x7e98011a,0x66d802d2,0x00000000,0x00000000}},	// [2ef20] _תספו, fíkn, --, --, 
   {{0xdbd006ea,0x7d780a1e,0x00000000,0x00000000}},	//   _týði, _עניו, --, --, 
   {{0x41cc0316,0x91c833ee,0x00000000,0x00000000}},	//   _हुनस, _हुसै, --, --, 
   {{0xb8781709,0x649408c2,0xd25800ef,0x00000000}},	//   _xuíz, _càin, boņi_, --, 
   {{0x649401ab,0xa3f40d30,0x60c80419,0x00000000}},	//   _dàin, оплі, yodm, --, 
   {{0x649401ab,0x7ae000f2,0x6d400342,0xd90c5ce9}},	//   _eàin, _èntr, çmay, _شیم_, 
   {{0x02a4448f,0x649408c2,0xa279b07b,0x7ddc0241}},	//   йрим, _fàin, ибку_, _kàsí, 
   {{0x2ee0009f,0xe81c033f,0x66d802f0,0x60c80477}},	//   _nhif_, _पड़ता_, míko, wodm, 
   {{0x66d80122,0x16f4031c,0x60c97f20,0x00000000}},	//   líko, _བཤོམ_, todm, --, 
   {{0xb8781709,0x30a00212,0x201843e9,0x00000000}},	//   _suíz, зрюв, úri_, --, 
   {{0x66d80232,0x443cef54,0x2d85481b,0x60c815b2}},	//   níko, _ict_, ämen_, rodm, 
   {{0x2ee002bd,0xbdd8004e,0x7ddc01e1,0x3f9c3d44}},	//   _chif_, sfèm, _nàsí, rztu_, 
   {{0x60c8b964,0x443c0798,0x2ee0058a,0x3f9cb2fe}},	//   podm, _kct_, _dhif_, sztu_, 
   {{0xc0a8b3cc,0x769009a5,0x5f94225f,0x98a807f5}},	//   _حاصل_, _açyl, _милт, trač_, 
   {{0x443c0cf9,0xd1dc1b49,0xddcc010f,0xdcb01e87}},	//   _mct_, _ዓመተ_, _inaŭ, كىڭ_, 
   {{0x66d82b57,0x7c34008f,0xbdd800f2,0xd25800e2}},	//   díko, _ŝarĝ, nfèk, toņi_, 
   {{0x443db07c,0x64940e89,0xec34036b,0x2c1803d4}},	// [2ef30] _oct_, _ràin, _کوپگ, _তাৰে_, 
   {{0x443c0208,0x66d9b07d,0x3d90014b,0x00000000}},	//   _nct_, fíko, _миқр, --, 
   {{0xdd902421,0xd758011c,0x00000000,0x00000000}},	//   _روگ_, риец_, --, --, 
   {{0xd1dc1ee0,0x443db07e,0x7ddc0248,0xd5b1b07f}},	//   _ዓመቱ_, _act_, _gàsí, وفا_, 
   {{0x9478f46d,0x3edc0521,0xa97c02d3,0x443db080}},	//   иску_, _nnọọ_, _ኣጸቢቑ_, _bct_, 
   {{0x443db081,0xd468e9d4,0xf99c067c,0x66d80306}},	//   _cct_, рике_, _efèc_, bíko, 
   {{0x569401c0,0x64940e89,0x66d800d7,0x00000000}},	//   _давт, _tàin, cíko, --, 
   {{0x3861b082,0x91047e32,0x80a4190e,0x799800a2}},	//   _hajr_, опие, टोसे, _ýuws, 
   {{0x443c0077,0x2ee000a9,0x3860031c,0xf1bc00d8}},	//   _fct_, _rhif_, _kajr_, çá_, 
   {{0x4f2432cf,0x2ee0036e,0x63a400df,0x92040171}},	//   одоб, _shif_, ŝina, diāņ, 
   {{0x56b400c8,0x649401c3,0x68e00036,0x2c1800fe}},	//   ַפֿן_, _màil, _ëmde, _তালৈ_, 
   {{0x25f00dad,0xc0cc02d3,0xbcf802f0,0x00000000}},	//   ुँची_, _ኣየር_, ovéh, --, 
   {{0xe2c9b083,0x66040113,0x66d800d0,0x00000000}},	//   _اونو_, ñiki, zíko, --, 
   {{0xb87800cf,0xd0082309,0x229401ec,0x00000000}},	//   _guíx, _теке_, _ولەس, --, 
   {{0x66d9b084,0x00000000,0x00000000,0x00000000}},	//   xíko, --, --, --, 
   {{0xddcc010e,0x66d802f0,0x00000000,0x00000000}},	//   _obaň, víko, --, --, 
   {{0x649408c2,0x8885b085,0x0a480023,0x00000000}},	// [2ef40] _bàil, олаж, _ምኽልካ, --, 
   {{0x649408c2,0x66ec1ea0,0x66d802f0,0x00000000}},	//   _càil, _işki, tíko, --, 
   {{0x3ae40142,0xca7c0240,0x00000000,0x00000000}},	//   _cŵps_, _ከለኹም_, --, --, 
   {{0x443db086,0x0ec8150d,0xdd1400d7,0x66d9b087}},	//   _sct_, रविड, _húšt, ríko, 
   {{0x3860006a,0xddcc0259,0x64940192,0x20180321}},	//   _fajr_, _maaş, _fàil, ðrik_, 
   {{0x07a473b3,0x66d802f0,0x00000000,0x00000000}},	//   _дагн, píko, --, --, 
   {{0x0ec813e0,0x66d80419,0xd4c4007b,0x00000000}},	//   रवाड, líkm, أغني, --, 
   {{0x09dc2d6c,0x4125392a,0xfa7002d3,0x0cc40b6d}},	//   _मराठ, офоб, _ኣየናይ_, लकुम, 
   {{0x443db088,0x6d440218,0xaee400b8,0xf48401d3}},	//   _tct_, _nqia, _ceṭi, _ڈالی, 
   {{0xf485336e,0x443db089,0xb8780077,0x0458007b}},	//   _والی, _uct_, _quíx, _خلطة_, 
   {{0x6d440d04,0xe3e8034c,0x02040953,0xd36c0451}},	//   _aqia, _اکشن_, _дзен, _مڇي_, 
   {{0xbcf8007b,0x769000a2,0x8fd40166,0x00000000}},	//   lvéi, _açyj, чәчә, --, 
   {{0x64940192,0x3f880254,0xd09401e2,0x408401f0}},	//   _làim, äbub_, زدیګ, _мукб, 
   {{0x645930ee,0x29000263,0xdcec00df,0x11e801f7}},	//   nevi, dqia_, _kraĉ, _طعني_, 
   {{0x7ed401ec,0x6d440869,0x6459b08a,0x649400a3}},	//   _وزعا, _eqia, ievi, _nàim, 
   {{0x64580851,0x201c0bed,0x656001f5,0x649408c2}},	//   hevi, _hevi_, _osmh, _sàil, 
   {{0x6459b08b,0x7c847323,0x201c03d1,0x649400a3}},	// [2ef50] kevi, _дуне, _kevi_, _pàil, 
   {{0x6458801c,0x9cc50d57,0x201c0010,0x2718007f}},	//   jevi, _གཉིས, _jevi_, fōn_, 
   {{0x656001ab,0x386000b8,0x64940051,0x0db800e5}},	//   _asmh, _vajr_, _vàil, _نئیں_, 
   {{0x649408c2,0xeaf80424,0xbcf80216,0x00000000}},	//   _dàim, _گریت_, tvéh, --, 
   {{0x3d0c0574,0x102c001f,0x649408c2,0x3860031c}},	//   तीचे_, _ተጠቅመ, _tàil, _tajr_, 
   {{0x6459b08c,0x201db08d,0x21240998,0x24a40014}},	//   gevi, _nevi_, dsmh_, وٕنِ, 
   {{0xb9d82e1f,0x67d40137,0x00000000,0x00000000}},	//   _በር_, _жору, --, --, 
   {{0x201db08e,0xd1846610,0xbcf800c7,0xe654003b}},	//   _aevi_, злий, avéi, _овсь, 
   {{0x6459b08f,0x201c7903,0xe2a80244,0x00000000}},	//   bevi, _bevi_, تاون_, --, 
   {{0x6459b090,0x201db091,0xf49424b2,0x00000000}},	//   cevi, _cevi_, _بشرد, --, 
   {{0x201db092,0xb59401f7,0x00000000,0x00000000}},	//   _devi_, _اَڃا_, --, --, 
   {{0x3a29b093,0x2299b094,0x201c1b99,0x838801d5}},	//   _ndcp_, _téka_, _eevi_, _уруғ_, 
   {{0x2390005f,0x270805d1,0x7690010b,0xdd1400d0}},	//   _vējš_, _iğne_, _açyk, _púšt, 
   {{0x8fa53aa1,0xe0d802bf,0x201c06ea,0x6ac400cd}},	//   _нале, _дві_, _gevi_, वक्र, 
   {{0x8f7401ce,0xf1ac007d,0x2d440254,0x00000000}},	//   _хулі, _जेतन, söe_, --, 
   {{0x1ea815fa,0x6459b095,0x649400a3,0x2d840158}},	//   _وايي_, zevi, _ràim, ømes_, 
   {{0x64580cc1,0x649401ab,0xfaa011eb,0xbcf800e4}},	// [2ef60] yevi, _sàim, хато, yvéi, 
   {{0x29000023,0xada4013e,0x201c00db,0xd90c6e0c}},	//   rqia_, _нақл, _xevi_, شیف_, 
   {{0x6458ce46,0x2b94179e,0x00000000,0x00000000}},	//   vevi, _غیرس, --, --, 
   {{0x64580472,0xa2880092,0x00000000,0x00000000}},	//   wevi, ማችንን_, --, --, 
   {{0x6459b096,0xbcf828cd,0x19b801f4,0x981400db}},	//   tevi, rwég, _дурь_, سبەا, 
   {{0xa3d5b097,0xbcf801c7,0x76480142,0x00000000}},	//   молч, uvéi, afgy, --, 
   {{0x6459b098,0x201db099,0xbdd80ba1,0xc7640046}},	//   revi, _revi_, rfèi, _عاسى, 
   {{0x6459b09a,0x443009a5,0x201db09b,0x4ecc015b}},	//   sevi, şy_, _sevi_, রগুল, 
   {{0x201c04cc,0x66040309,0x91c00131,0xbcf800e5}},	//   _pevi_, ñiku, кәшл, lvév, 
   {{0xf99c004e,0x81d0036b,0xf4240276,0x64580200}},	//   _ofèn_, моқх, _ноул_, qevi, 
   {{0x9e342fbf,0x201c07c5,0xceac00ec,0x6fcc134e}},	//   менч, _vevi_, ڌڙي_, _सुदं, 
   {{0x3f8007f5,0x201c009f,0xffa001c0,0xb7d8010f}},	//   ćku_, _wevi_, длүү, מקיי, 
   {{0x201db09c,0x41b00014,0xd24c00f7,0x00000000}},	//   _tevi_, _سۅدر, _ئچى_, --, 
   {{0x201c009a,0x66ec0e2d,0x20d000a3,0xe2c800ec}},	//   _uevi_, _işku, ràis_, _اوچو_, 
   {{0x66d8008c,0x2d8405ac,0x00000000,0x00000000}},	//   ríkj, ømer_, --, --, 
   {{0x0cc4012d,0x20140210,0xaa64081b,0x00000000}},	//   लकॉम, łcić_, нтук, --, 
   {{0xa9542080,0x22988a9a,0xd75800ec,0x00000000}},	// [2ef70] нкті, _léko_, ڪلات_, --, 
   {{0x7b642d55,0x6d48054e,0xd79402e8,0x00000000}},	//   _етме, ădat, мизъ, --, 
   {{0x59f8169c,0xf09004ac,0x6e455a4b,0xaf9402d3}},	//   _меня_, ענע_, _غنیم, _ጎይታና_, 
   {{0xe7310dbc,0xddcc151c,0x95d800d8,0x00000000}},	//   اصل_, _znaš, одет_, --, 
   {{0x229800e4,0x27340022,0xbcf80124,0xb4b00116}},	//   _aéko_, _ẽnte_, avév, нидә, 
   {{0xe3b12b47,0xddcc0083,0x69c001a6,0x00000000}},	//   گره_, _abaŋ, _žmeg, --, 
   {{0x2298020c,0x3688010a,0x00000000,0x00000000}},	//   _céko_, _лсан_, --, --, 
   {{0xe3b1665f,0xdcec0327,0x317c01c4,0x00000000}},	//   دره_, _braċ, txuz_, --, 
   {{0x7bd4007c,0xd0580212,0xe5346af7,0xc6840244}},	//   _lyxu, орні_, _петь, _تێنن_, 
   {{0x8fd00032,0xf8bc0b98,0x793c0023,0x00000000}},	//   кәйә, ्विय, ርሒታት, --, 
   {{0xd2500597,0x09b806ab,0x66ec008e,0x20d001ab}},	//   _لنا_, _इश्य, _eşku, tàir_, 
   {{0xddcc05ce,0x630400ae,0x00000000,0x00000000}},	//   _snaš, _أونل, --, --, 
   {{0x50448916,0xf8bc00dc,0xf074013d,0x00000000}},	//   _желб, ्वाय, _нидә_, --, 
   {{0xa0c4005e,0xbcf800c7,0x8b644842,0x00000000}},	//   _كينو, yvév, وازم, --, 
   {{0xbb41b09d,0x3a0805db,0xddcc0219,0xe7ac06e3}},	//   керк, _ụzọ_, _vnaš, _टेंप, 
   {{0x69c8016b,0x3b040261,0x00000000,0x00000000}},	//   _ɛdef, ќето_, --, --, 
   {{0x9e64004b,0x08880024,0x00000000,0x00000000}},	// [2ef80] _ساين, обай_, --, --, 
   {{0xe6b812eb,0xddcc01ef,0x19b80108,0x00000000}},	//   ेक्ज, _unaš, чусь_, --, 
   {{0xbc780375,0x66d80d12,0x8d7435aa,0x00000000}},	//   _ונית, líki, _راکا, --, 
   {{0xbcf803df,0xd90c00e5,0x00000000,0x00000000}},	//   rvév, شیہ_, --, --, 
   {{0x6fcc1a2a,0x6d9401f1,0xe45408e2,0xee48013a}},	//   _सुसं, _fľaš, еклы, chýř_, 
   {{0xbcf804e6,0x66ec0790,0x430848a6,0x00000000}},	//   lwéc, _aşkt, охим_, --, 
   {{0x7305b09e,0xbcf800dd,0x00000000,0x00000000}},	//   وقوف_, lvét, --, --, 
   {{0x37e0bbd5,0xf99c0100,0xf1ac000d,0xd5080116}},	//   _росг, _ofèl_, _जेहन, زغۇن_, 
   {{0x05641cb8,0x00000000,0x00000000,0x00000000}},	//   _юван, --, --, --, 
   {{0x22980098,0xc0a80214,0x7410007b,0x00000000}},	//   _téko_, تابل_, _لوكا, --, 
   {{0xf8340302,0xdeb405cc,0x03680276,0x537000ec}},	//   ונית_, ебны, _фиек_, _مڇيء, 
   {{0xf1ac0406,0xdcec0135,0x66d8032e,0xbcf8013a}},	//   _जेवन, _traċ, fíki, kvét, 
   {{0x41e02072,0x008401c0,0x12c800e3,0x00000000}},	//   _परिस, _олдо, _عظمي_, --, 
   {{0xba14012c,0xd4900051,0x00000000,0x00000000}},	//   तर्फ_, _kìa_, --, --, 
   {{0xdfd0e540,0xf99c007f,0x46cc00e1,0xe4700092}},	//   _حيث_, _efèl_, ़वाह, _በኬንያ_, 
   {{0xdcec0552,0x6d480311,0x41e12877,0xb4d8000d}},	//   _irač, ădar, _परास, _ठठ्_, 
   {{0xdcec03c6,0xdd9400ee,0x187401a9,0xbcf800e5}},	// [2ef90] _hrač, _чапы, нгая, gvét, 
   {{0xdcec0010,0x63a40115,0x00000000,0x00000000}},	//   _krač, ĝinj, --, --, 
   {{0xba38030a,0x29040687,0x96343533,0xea00004d}},	//   _alïe, _éman_, енец, _ngặt_, 
   {{0xdcec1b24,0xe6102b09,0xf77001b9,0x0af001c0}},	//   _mrač, لشه_, _یاز_, _бүсэ, 
   {{0xf5240166,0x66ec0205,0x41cc0037,0x466019c5}},	//   ффен, _aşks, _हुलस, دۇقق, 
   {{0x9344e7bb,0x26040139,0x52b8134e,0x00000000}},	//   енке, нчәг, ॉक्स, --, 
   {{0x6388067c,0xf644074d,0x00000000,0x00000000}},	//   vènç, _охан, --, --, 
   {{0x70c41546,0x00000000,0x00000000,0x00000000}},	//   रक्ल, --, --, --, 
   {{0x50b5b09f,0xe8a4001f,0x63b80213,0xe4d400cf}},	//   есну, _ለረጅም_, _əcnə, رتۇب, 
   {{0xdcec071b,0x66d808a7,0x00000000,0x00000000}},	//   _brač, víki, --, --, 
   {{0xbcf801d3,0xdddc02f0,0xb4d80b67,0x00000000}},	//   kvés, lesň, ठती_, --, 
   {{0x8fd00032,0xdceccc1a,0xbcf800e4,0x00000000}},	//   _ҡәнә, _drač, yvét, --, 
   {{0x7b0001e4,0x8d75b0a0,0x6fcc25c9,0x4638010f}},	//   _dĵum, راحا, _सुरं, הערע, 
   {{0x66d809f3,0xdcec0427,0x00000000,0x00000000}},	//   ríki, _frač, --, --, 
   {{0xdcec0989,0xbcf80a40,0xdb200248,0x8e74009b}},	//   _grač, twéc, _ìtìj, _зупч, 
   {{0x41cc0037,0xbcf800e5,0x07a40124,0x00000000}},	//   _हुँस, tvét, ҽазн, --, 
   {{0xdcec242a,0xbcf801c7,0x89a800d8,0x88e401f4}},	// [2efa0] _zrač, rwéc, чкав_, ежае, 
   {{0xbdd8007f,0x27fc06ea,0xbcf800e5,0x00000000}},	//   rfèt, øvn_, rvét, --, 
   {{0x6f08084c,0xeb340137,0xbcf801d3,0x2b500356}},	//   _încă, _جۉزد, svét, încă_, 
   {{0xc6d4313e,0x7a4402b1,0x63a40115,0xb6a0022e}},	//   رتات, _pūtō, ŝink, лихл, 
   {{0xbcf9b0a1,0x6aa401f7,0x381c03d4,0x00000000}},	//   lvér, mhif, _পাৰো_, --, 
   {{0xdc3c0e04,0xe4c4104c,0x724000d1,0xd24c0014}},	//   ršću, خصصی, ۇپىل, ۪ۆن_, 
   {{0x37e1b0a2,0xbcf9b0a3,0xbdd99b7a,0x46a400d4}},	//   _борг, nvér, nfèr, _завв, 
   {{0xf2c02f89,0x6aa4003b,0xc6180154,0x30105e78}},	//   лсын, nhif, _ডাকা_, ңдыр, 
   {{0x5bbc21b8,0x26c4014f,0xd24c03e6,0xb6a001e0}},	//   _ईश्व, _ijmo_, تۆن_, _ситл, 
   {{0xdcec022a,0x34c80b98,0x00000000,0x00000000}},	//   _prač, िवृद, --, --, 
   {{0x6aa4b7a3,0xceac05d9,0xdfd000c6,0x00000000}},	//   khif, ڪڙو_, شيح_, --, 
   {{0xdcec237d,0xdd94ea10,0x818800db,0xdd380055}},	//   _vrač, вамы, _ىناق_, cāśv, 
   {{0x6aa5b0a4,0xf8bc012c,0x229800e8,0xeff4001f}},	//   dhif, _svém_, _lékk_, _ጊዜው_, 
   {{0xbdd8004a,0xf1bc0419,0x00000000,0x00000000}},	//   ffèr, íšem_, --, --, 
   {{0x6aa40943,0xdcec0552,0x66d8041e,0x22981bce}},	//   fhif, _urač, líku, _nékk_, 
   {{0x6aa4011c,0x39a401e1,0x961c0171,0x00000000}},	//   ghif, _nìsé_, _toņi, --, 
   {{0x19c4210a,0x25a001ab,0x66d800e4,0x58d400d8}},	// [2efb0] тәнг, ùill_, níku, воат, 
   {{0x26c41b24,0xfb84010b,0xf8bc013a,0x00000000}},	//   _ajmo_, _зымн, _tvém_, --, 
   {{0x37a82af0,0x00000000,0x00000000,0x00000000}},	//   чтан_, --, --, --, 
   {{0x6aa5b0a5,0x7c25b0a6,0x229800e8,0x26cc004e}},	//   chif, lajr, _dékk_, _ídol_, 
   {{0xd4680b3e,0x19b4010f,0x00000000,0x00000000}},	//   диле_, _ספֿר_, --, --, 
   {{0x2298008c,0x34c837e3,0xb4d9b0a7,0xdddc00d0}},	//   _fékk_, िवेद, ठते_, resň, 
   {{0xf8bc0a81,0x98a8033f,0x229802d2,0x00000000}},	//   ्वीप, erać_, _gékk_, --, 
   {{0x67d4034b,0x7c248490,0x00000000,0x00000000}},	//   _сосу, hajr, --, --, 
   {{0x7c240113,0x98a8033f,0x66ec0205,0xa928013a}},	//   kajr, grać_, _tşkr, _tužš, 
   {{0x2ebc12cc,0xf99c007f,0x05b4012c,0x2298002e}},	//   ोक्त, _afèk_, _आइतब, _yékk_, 
   {{0xbcf80c63,0x649401ab,0x09dc36c7,0x918000cf}},	//   yvér, _càiu, _मर्य, _چۇبۇ, 
   {{0x98a8068f,0x41b01291,0x515401f0,0x00000000}},	//   brać_, امیر, _атку, --, 
   {{0x7c25a305,0x52dc28fe,0x00000000,0x00000000}},	//   fajr, मतीस, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6aa5b0a8,0x5b340276,0x8fa40137,0x4fa401f0}},	//   thif, лэту, _шаке, _шикв, 
   {{0x6f001730,0xc3300375,0x09e401d5,0x00000000}},	//   _iunc, יול_, вобн, --, 
   {{0x6f01b0a9,0x229800e8,0xbdd9b0aa,0x7c2597dd}},	// [2efc0] _hunc, _sékk_, lgèn, bajr, 
   {{0x38c8d222,0x6e25b0ab,0xbdd8004e,0x39a401e1}},	//   والی_, _heib, ogèn, _sìsé_, 
   {{0x6f01b0ac,0x6e24019b,0x370007dd,0xbdd96ad8}},	//   _junc, _keib, апхг, ngèn, 
   {{0x6f01b0ad,0x63bc28b5,0x64940192,0xe3b80205}},	//   _munc, _žrno, _làit, _deıl_, 
   {{0x3ab17f8c,0x2458013d,0x6e2439ea,0x6f01b0ae}},	//   _тәрт, еаль_, _meib, _lunc, 
   {{0x6e25b0af,0x6f01b0b0,0x66d8008c,0x741005d9}},	//   _leib, _ounc, víku, لوها, 
   {{0x6f00748d,0x6e240428,0xbcf9b0b1,0x00000000}},	//   _nunc, _oeib, kwén, --, 
   {{0x68fdb0b2,0x2a600784,0x2cb801ab,0x48e4012d}},	//   _hird, neib_, hird_, _जीतो_, 
   {{0x9a6c044e,0x6f01b0b3,0x68fdb0b4,0x649400a3}},	//   _ትኽእል_, _aunc, _kird, _bàit, 
   {{0x649408c2,0x68fdb0b5,0x66d80321,0x6f01b0b6}},	//   _càit, _jird, ríku, _bunc, 
   {{0x6e25b0b7,0xc244d4d0,0x6f01b0b8,0x68fdb0b9}},	//   _beib, _анек, _cunc, _mird, 
   {{0x6e25b0ba,0x2ef4084c,0xdb0c01e1,0x00000000}},	//   _ceib, изэр, _ékél, --, 
   {{0x6e240b21,0x6f00003e,0x66d80113,0x7c24125c}},	//   _deib, _eunc, qíku, tajr, 
   {{0x68fdb0bb,0xbdd8004e,0xdd940032,0x2cb82994}},	//   _nird, bgèn, _ҡайы, gird_, 
   {{0x6f01b0bc,0xeb04b9ad,0xdcb06923,0x644801fa}},	//   _gunc, ичто, لىڭ_, _mcdi, 
   {{0x68fdb0bd,0x7c25978f,0x2cb81cf8,0x0e000117}},	//   _aird, sajr, aird_, _гӯро, 
   {{0x2cb9b0be,0x2c140882,0xad6400ec,0x80c4000d}},	// [2efd0] bird_, _त्वं_, _نٿيو, _लदाइ, 
   {{0x68fdb0bf,0x6f000309,0xa8150e16,0xb9e0012d}},	//   _cird, _yunc, идуш, _खरीफ_, 
   {{0xa034001f,0x6f000005,0x170401d3,0x16c4035b}},	//   _በአንዳ, _xunc, اہری_, гӡан, 
   {{0x68fdb0c0,0x00000000,0x00000000,0x00000000}},	//   _eird, --, --, --, 
   {{0x298400f4,0xa5640372,0x64940013,0xd4d83334}},	//   _кырг, لدون, _nàis, нькі_, 
   {{0xbdd839b2,0x68fdb0c1,0xbcf80036,0x6d4001c3}},	//   ygèn, _gird, zwén, àmai, 
   {{0x644800b5,0x649408c2,0xc0d00092,0x00000000}},	//   _dcdi, _ràit, _ከለላ_, --, 
   {{0x6f01b0c2,0xc5ec00aa,0x4918012c,0x649401ab}},	//   _runc, _کړم_, मीको_, _sàit, 
   {{0x6f000552,0x6e25b0c3,0xf8bc00c7,0x649400a3}},	//   _sunc, _reib, _avéi_, _càis, 
   {{0x6f01b0c4,0x6e25b0c5,0xd1740184,0x200003ee}},	//   _punc, _seib, _ҡылы, _şiir_, 
   {{0x6f01b0c6,0x920400cd,0x6e240037,0xbcf804e6}},	//   _qunc, _anāś, _peib, twén, 
   {{0xbdd800f7,0x6f01b0c7,0x649401c3,0x8754011a}},	//   rgèn, _vunc, _fàis, נברג_, 
   {{0x6e25b0c8,0xf8bc0022,0x5ec43452,0x00000000}},	//   _veib, _evéi_, рияғ, --, 
   {{0x6e25b0c9,0x6f01b0ca,0xf8bc483c,0x63a401e4}},	//   _weib, _tunc, ्वोप, ĝinv, 
   {{0x6e25b0cb,0xc0500302,0x08c4016c,0x8c2400fe}},	//   _teib, _הזו_, ҳбан, _বাদন_, 
   {{0x68fdb0cc,0x2cb807ab,0x6e2404cc,0x61b00131}},	//   _sird, sird_, _ueib, _دەۋا, 
   {{0x3ed800c8,0x64940192,0xbdd9b0cd,0x49c81058}},	// [2efe0] _אַזא, _màir, ngèl, хлан_, 
   {{0xbcf800d2,0xa96804a9,0x649400a3,0x2a6000db}},	//   nwél, ниға_, _làir, seib_, 
   {{0x68fdb0ce,0x00000000,0x00000000,0x00000000}},	//   _vird, --, --, --, 
   {{0x68fdb0cf,0xfbd00302,0x649401c3,0xa5c40022}},	//   _wird, _לתת_, _nàir, аҩбе, 
   {{0x68fc00da,0x1fd04c19,0xd4900051,0xe8f801ee}},	//   _tird, _हड्ड, _bò_, _аһа_, 
   {{0xb3ac00cc,0x00000000,0x00000000,0x00000000}},	//   _চুইজ, --, --, --, 
   {{0x64940e89,0x07a4a229,0xd4900208,0xe7b81100}},	//   _bàir, _савн, _dò_, _आधिप, 
   {{0x649408c2,0x66d801a8,0x00000000,0x00000000}},	//   _càir, ríks, --, --, 
   {{0x64940086,0xb270005b,0x84e4009d,0x00000000}},	//   _dàir, слыш, _боаж, --, 
   {{0x2e2401dc,0x649400a3,0x9f5435dd,0x3154007b}},	//   _đườn, _eàir, авоч, اجية_, 
   {{0x649401c3,0x8654001f,0xc31c009e,0x00000000}},	//   _fàir, _ለምንድ, _ধমকি_, --, 
   {{0x3e68016c,0x64940e89,0x80b4007d,0xfd44009d}},	//   хшон_, _gàir, _ऋगवे, лэгн, 
   {{0x29040066,0x00000000,0x00000000,0x00000000}},	//   _émah_, --, --, --, 
   {{0x1fe800ec,0x42500345,0x00000000,0x00000000}},	//   _لکجي_, _ئۆکر, --, --, 
   {{0xdb24014a,0x7098008f,0x2d8426bc,0xab84292c}},	//   _äpüb, _אױגו, ämer_, бутк, 
   {{0xba75b0d0,0xaf3000f2,0x00000000,0x00000000}},	//   داست, _اروت, --, --, 
   {{0xc1e0000d,0x00000000,0x00000000,0x00000000}},	// [2eff0] _परोग, --, --, --, 
   {{0x76900432,0xf9800022,0x1f540092,0xa9c40108}},	//   _açyp, аҳҭо, _ፈቃደኝ, ёстк, 
   {{0xa9240006,0x00000000,0x00000000,0x00000000}},	//   _įžei, --, --, --, 
   {{0x15b9a3a0,0x66040010,0x00000000,0x00000000}},	//   кылы_, žikn, --, --, 
   {{0xe718005e,0x94242401,0xe9a40064,0x66d80419}},	//   نيەت_, амле, _гаўп, tíkr, 
   {{0x656400ee,0xd49001fb,0x22980241,0x52dc00cd}},	//   çiha, _tìm_, _méku_, मत्स, 
   {{0x64940013,0x2299b0d1,0x53a4955d,0x41e0000d}},	//   _pàir, _léku_, райб, _परउस, 
   {{0x5155b0d2,0x6fcc1098,0xb2800032,0x5274167f}},	//   атоу, _सुगं, скиҙ, руку, 
   {{0xf99c007f,0xf8bc01e1,0x758001b9,0xdbd00432}},	//   _efèv_, _ewée_, _دیشم, lýäm, 
   {{0x98a801a6,0xbcf8002d,0x9104004e,0x00000000}},	//   ksač_, uwél, лчүд, --, 
   {{0x8e84d96d,0x649408c2,0xb3600b82,0x00000000}},	//   агне, _tàir, ጻውያን_, --, 
   {{0x63a400c8,0x649401ab,0xdef80006,0xe1f004f2}},	//   ĝint, _uàir, лыў_, _کسم_, 
   {{0xf8bc01c7,0x63a400df,0x2d840124,0x00000000}},	//   _zwée_, ŝint, ãme_, --, 
   {{0x8c24045e,0xa928013a,0x8c440114,0xefcc0023}},	//   _বাহন_, _lužá, јеве, ብሰይ_, 
   {{0x8a046be2,0x00000000,0x00000000,0x00000000}},	//   изве, --, --, --, 
   {{0xfd6002e3,0x3ed00345,0xdbd000a2,0x195404b2}},	//   netị, _وقور, dýäm, _ምርምሮ, 
  
   {{0xfaa0005b,0x00000000,0x00000000,0x00000000}},	// [2f000] цато, --, --, --, 
   {{0x2ac40166,0x00000000,0x00000000,0x00000000}},	//   рәүв, --, --, --, 
   {{0xdde801d5,0xcac80395,0x00000000,0x00000000}},	//   _لریه_, _агне_, --, --, 
   {{0x48e4012d,0x6b9c0200,0x00000000,0x00000000}},	//   _जीरो_, myrg, --, --, 
   {{0x25a074bb,0xfa640fca,0x7c280139,0x00000000}},	//   áil_, _таяк_, _ömrä, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x02a404a9,0x25a04ea1,0xd4900051,0x3324009d}},	//   ирим, šil_, _mìh_, ацын_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x0445b0d3,0xc48497d0,0xfbc400cc,0x6b9c00a2}},	//   _везн, _клак, _এৰাত, hyrg, 
   {{0xdd9401e0,0x86f000ec,0x8bd00037,0xff380092}},	//   ҡаны, _اڻڄا, _दु्अ, _በተለመ, 
   {{0x389800d9,0x45d401af,0xdfd401c4,0x1fb86135}},	//   דיינ, _соҡс, соны, улны_, 
   {{0x9d1801c0,0x6b9c0072,0x63a401e4,0x00000000}},	//   ломт_, dyrg, ŝins, --, 
   {{0x7de4005e,0xfafc017a,0x00000000,0x00000000}},	//   рінд, _rië_, --, --, 
   {{0xfa202f04,0x0f880150,0xf1ac000d,0x2ec4004e}},	//   _ফাইল_, _ﯗﻳﯩﯖ, _जेटन, йөөм, 
   {{0x9ca400db,0x00000000,0x00000000,0x00000000}},	//   _ۇشدۇ, --, --, --, 
   {{0xf99c007f,0xbdd8020c,0xfd4400e5,0x6ff8011a}},	//   _ofèt_, ngèk, _پیسٹ_, _בהופ, 
   {{0xf80416ab,0x6d4001ab,0x00000000,0x00000000}},	// [2f010] ачен, àmat, --, --, 
   {{0x6b9c08a7,0xa9c43334,0x00000000,0x00000000}},	//   byrg, істк, --, --, 
   {{0xded402d3,0x00000000,0x00000000,0x00000000}},	//   _ከረን_, --, --, --, 
   {{0x6d4000e4,0x4dec0118,0x00000000,0x00000000}},	//   ámag, _घरमै_, --, --, 
   {{0x6c780403,0x29880220,0x64940e89,0xe50800f1}},	//   _صحیح_, _ксро_, _pàip, لينو_, 
   {{0xb7142088,0x95b401e0,0x00000000,0x00000000}},	//   _نظرت, ирҙә, --, --, 
   {{0xd7c800c6,0x0fc00154,0x17b400fe,0x00000000}},	//   _صوره_, _উর্ধ, _জুৰি, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7659b0d4,0xd00800c0,0x00000000,0x00000000}},	//   _ibuy, лепе_, --, --, 
   {{0x2ee000cd,0x2bbc00cd,0x00000000,0x00000000}},	//   नत्त, ोपमा, --, --, 
   {{0x5275b0d5,0x4e280108,0x00000000,0x00000000}},	//   _гулу, лонн_, --, --, 
   {{0xe1880451,0xdcec0055,0x00000000,0x00000000}},	//   _چئون_, _āhās, --, --, 
   {{0xe1f0168d,0x7659b0d6,0xe18805d9,0x2010022c}},	//   _قسه_, _mbuy, _نئون_, ælið_, 
   {{0x321c0076,0x14f803d4,0x00000000,0x00000000}},	//   lbuy_, ঁৱৰী_, --, --, 
   {{0x76582f99,0xf99c004e,0x00000000,0x00000000}},	//   _obuy, _ofès_, --, --, 
   {{0x0d840229,0x66d40166,0x0ae815f2,0x81b800cc}},	//   _глин, _kükş, ارسي_, _আঁত_, 
   {{0x8c45b0d7,0x6d402f5e,0xf53c007c,0xef080037}},	// [2f020] _лепе, ámad, _ååh_, _सूतऽ_, 
   {{0x4c68004e,0x00000000,0x00000000,0x00000000}},	//   _сион_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd6d802bf,0x00000000,0x00000000,0x00000000}},	//   аті_, --, --, --, 
   {{0xe5340153,0x05b8007b,0x3e7c005b,0x3ed8010f}},	//   цель, ددات_, _hätä_, אַגא, 
   {{0x76581cdf,0xf99c067c,0x81680c60,0x99892b94}},	//   _ebuy, _efès_, ҳроб_, lbaş_, 
   {{0xf7400d44,0x3e7c02f6,0x76580175,0x17c400c7}},	//   _неро, _jätä_, _fbuy, _дарҭ, 
   {{0x3e7c01f4,0x998808a9,0x0fc000fe,0x00000000}},	//   _mätä_, nbaş_, _উৰ্ধ, --, 
   {{0xddcc9fca,0x22980c6a,0x96b9b0d8,0xba98010f}},	//   _snaž, _séks_, _туру_, טסקי, 
   {{0x7a3c01e1,0x2c180bc0,0xc4c403c7,0xc5f41025}},	//   _kàtà, _ब्लू_, _اترو, ेशीय_, 
   {{0x442db0d9,0x741034f7,0x99887aa0,0x70f001e1}},	//   maf_, _رونا, kbaş_, _ẹfún, 
   {{0xdcec098d,0x412889d2,0x61b800ec,0x00000000}},	//   _krać, _бодо_, _پهتس_, --, 
   {{0x20940023,0xfbd8000d,0x00000000,0x00000000}},	//   _ይገልጹ_, _मँहम, --, --, 
   {{0x442db0da,0x229800d5,0x3ea801c7,0x00000000}},	//   naf_, _téks_, shct_, --, 
   {{0x6d405d7e,0xa9240153,0x442c03cb,0xa114009f}},	//   àmar, _įžai, iaf_, _اوڪت, 
   {{0x3da4228e,0x442db0db,0xdb1001e1,0x00000000}},	//   _гроб, haf_, _àgíd, --, 
   {{0x442c0591,0xbcf804c4,0xf99c007f,0x98b9b0dc}},	// [2f030] kaf_, hwéi, _afèr_, алат_, 
   {{0xf8040962,0x442c03f9,0x37a9abcf,0x00000000}},	//   счан, jaf_, лтен_, --, 
   {{0x442db0dd,0x186801e0,0x68f80118,0xae0400d1}},	//   daf_, лаҡи_, _řadí, _بوۋى, 
   {{0xdcec0bb8,0xf99c0ba1,0xa3cc05dc,0x9aa40131}},	//   _brać, _egèa_, रपन_, _بۆرە_, 
   {{0xe3b80a73,0x442db0de,0xdddc012d,0xd91000ec}},	//   _meıu_, faf_, lesł, _آڌر_, 
   {{0x442d008f,0xf7702832,0x3f9c0153,0x00000000}},	//   gaf_, _ٹاس_, kytu_, --, 
   {{0x321c0332,0x6ec400e5,0xd7380092,0x00000000}},	//   tbuy_, lőbe, _ካልሆነ, --, 
   {{0x7659b0df,0x3f9db0e0,0x60c802d0,0x00000000}},	//   _ubuy, dytu_, endm, --, 
   {{0x442db0e1,0x9f58025a,0x63a400df,0xfbd80b4c}},	//   baf_, ärî_, ŝinp, _मुसम, 
   {{0x442c0368,0xcfb000cc,0x00000000,0x00000000}},	//   caf_, _ঘুগন, --, --, 
   {{0x7ae001c7,0x00000000,0x00000000,0x00000000}},	//   _ëntw, --, --, --, 
   {{0x764843f4,0x60c800af,0x68400241,0x03d4010f}},	//   nggy, andm, _kádà, _וועם_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8fa4651a,0x3f9c132c,0xfbd85325,0x6ec401d3}},	//   _мале, bytu_, _मुहम, dőbe, 
   {{0xfc000203,0x8e7421fa,0x68400241,0xf7640023}},	//   дпро, _дупч, _ládà, _ደጋጊመ_, 
   {{0x442db0e2,0x0cb800fe,0xbe600046,0xaee4002b}},	//   zaf_, ংকেত, _قۇپي, _kuṭh, 
   {{0x442c0cfd,0x99880210,0x6ec400e5,0x00000000}},	// [2f040] yaf_, ecał_, gőbe, --, 
   {{0x3e7c049b,0x7a3c0570,0x3a280048,0x6f04037e}},	//   _tätä_, _pàtà, _eecp_, _hiic, 
   {{0x6f040a40,0x998805d2,0x442db0e3,0xaee400b8}},	//   _kiic, pbaş_, vaf_, _luṭh, 
   {{0xdcec098d,0x7d743cc4,0x6f040009,0x66ec0432}},	//   _prać, _امیر_, _jiic, _yşky, 
   {{0x6f05b0e4,0x241801ee,0x3f9c0210,0x00000000}},	//   _miic, болы_, zytu_, --, 
   {{0xdcec04b9,0xd1cc693c,0x6f0404c4,0x6aa44c8f}},	//   _vrać, ብነት_, _liic, lkif, 
   {{0x37e022cb,0x6458017a,0xbcf80036,0x00000000}},	//   _жорг, rfvi, uwéi, --, 
   {{0x442db0e5,0x6f05b0e6,0x3a34008f,0x76480076}},	//   saf_, _niic, ֿרים_, cggy, 
   {{0x2105b0e7,0xdddc0034,0x442ca059,0x3f9c0210}},	//   रदेश_, zesł, paf_, wytu_, 
   {{0x442c0003,0x2ee1b0e8,0x6f0402d0,0x74100131}},	//   qaf_, _akif_, _aiic, _يوقا, 
   {{0x6aa5b0e9,0x4ad80574,0x6f040036,0x6ec401ed}},	//   kkif, ढवाव, _biic, zőbe, 
   {{0x3f9db0ea,0x52740117,0x00000000,0x00000000}},	//   rytu_, _нучу, --, --, 
   {{0xf99c0066,0x6f05b0eb,0x6aa40607,0x00000000}},	//   _agèn_, _diic, dkif, --, 
   {{0x3f9c035b,0x6f040381,0xd25800e2,0x6ec401d3}},	//   pytu_, _eiic, miņa_, vőbe, 
   {{0x6f05b0ec,0x5a24025c,0xd258005f,0x7648062c}},	//   _fiic, _འབྱེ_, liņa_, yggy, 
   {{0x6f040548,0x6ec401d3,0xb4c5b0ed,0x00000000}},	//   _giic, tőbe, _उद्_, --, 
   {{0xad24049e,0xd25800e2,0x79a4033a,0x6d48012d}},	// [2f050] _قىيى, niņa_, црве, ądac, 
   {{0xfd1c011c,0x6aa40270,0x5e3401ed,0x6f0401c7}},	//   mpì_, akif, _بڑھا, _ziic, 
   {{0xfd1c86ed,0xdb1001e1,0x6ec400e5,0x00000000}},	//   lpì_, _àgàd, sőbe, --, 
   {{0x41c80574,0x95740228,0x5a24025c,0xb8186a60}},	//   ापास, зыкч, _འབྲེ_, _प्रम_, 
   {{0xa52400d4,0xf569710c,0x00000000,0x00000000}},	//   дмід, ршек_, --, --, 
   {{0x693401ce,0xd25800e2,0xb8641291,0xd4680108}},	//   _інсу, diņa_, _باحو, сике_, 
   {{0x950400dd,0x00000000,0x00000000,0x00000000}},	//   _کہتے_, --, --, --, 
   {{0xe3b1b0ee,0x68e001c7,0x98a80003,0x00000000}},	//   خره_, _ëmdr, ftaħ_, --, 
   {{0x6f040a40,0x9538004e,0x00000000,0x00000000}},	//   _riic, _ызат_, --, --, 
   {{0x6f05b0ef,0xe4a5b0f0,0x2ee0415b,0xc95000d9}},	//   _siic, _орхо, _skif_, עמי_, 
   {{0x6f0400b5,0x9258008e,0x6aa403b2,0x00000000}},	//   _piic, _гает_, ykif, --, 
   {{0x6304044c,0xd25800de,0x00000000,0x00000000}},	//   _قولل, biņa_, --, --, 
   {{0xd0098c46,0x6f0490d4,0xd25800e2,0x6aa403e0}},	//   _леле_, _viic, ciņa_, vkif, 
   {{0x230801ec,0x00000000,0x00000000,0x00000000}},	//   _اتەي_, --, --, --, 
   {{0x6f04058a,0x4fa401c6,0x00000000,0x00000000}},	//   _tiic, _хийв, --, --, 
   {{0x6ec401ed,0x9f5805ac,0x00000000,0x00000000}},	//   sőbb, ørå_, --, --, 
   {{0x6aa40ba7,0xa2ac17c6,0x00000000,0x00000000}},	// [2f060] rkif, जसत्, --, --, 
   {{0x6aa452fd,0x2d800099,0x6c3468e7,0x7d180077}},	//   skif, _irie_, _زہرا, íuse, 
   {{0xc5f43be5,0x2d800076,0xd258005f,0x00000000}},	//   ेश्य_, _hrie_, ziņa_, --, 
   {{0x2d8012c6,0xdb100241,0xb0a400bc,0x00000000}},	//   _krie_, _àgád, गसँग, --, 
   {{0xb6000d1d,0xeaf84f76,0x00000000,0x00000000}},	//   няшк, ंगीत_, --, --, 
   {{0xd90c0244,0x00000000,0x00000000,0x00000000}},	//   _ئیل_, --, --, --, 
   {{0xf361b0f1,0x932400e5,0x00000000,0x00000000}},	//   етын, ورٹن, --, --, 
   {{0xfa9404ac,0xd259b0f2,0x32500801,0x2d81b0f3}},	//   ִדיש_, tiņa_, евър, _orie_, 
   {{0x04451567,0xbdd80066,0xb0a4c976,0x00000000}},	//   _неан, ngèt, गसंग, --, 
   {{0xd258005f,0xbfc801a9,0xf53408a8,0xa3cc13e0}},	//   riņa_, _o喪ta, _מרמז_, रपद_, 
   {{0x2d8029ef,0x020400d8,0x00000000,0x00000000}},	//   _arie_, _езен, --, --, 
   {{0xd25800de,0x00000000,0x00000000,0x00000000}},	//   piņa_, --, --, --, 
   {{0x2d8003b7,0xf2780375,0x8e7002dd,0x00000000}},	//   _crie_, _לראש, тқыш, --, 
   {{0x2d80292b,0xac19b0f4,0xc10000ec,0x00000000}},	//   _drie_, зору_, _ڪوڙي, --, 
   {{0xa3cc00dc,0x2d80123b,0xfaa5b0f5,0x00000000}},	//   रपि_, _erie_, пшан, --, 
   {{0x9f0400f7,0x2d802759,0x09bc015b,0xaa940276}},	//   _توعو, _frie_, _আড়া, нисч, 
   {{0x2d801165,0x0c7001d5,0x00000000,0x00000000}},	// [2f070] _grie_, رگید, --, --, 
   {{0xa3cc2e37,0xadf4010b,0x00000000,0x00000000}},	//   रपा_, _япыш, --, --, 
   {{0xa81801d5,0xc61400eb,0x00000000,0x00000000}},	//   ستلر_, ারনা_, --, --, 
   {{0x6f04020c,0x79a5b0f6,0xcb34011a,0x00000000}},	//   lèbè, _ерге, _קארי_, --, 
   {{0xca940375,0x261c00e1,0xd54802dd,0x00000000}},	//   _חדרי_, मड़ी_, іпке_, --, 
   {{0xbdd800db,0x00000000,0x00000000,0x00000000}},	//   lgès, --, --, --, 
   {{0xdee802d3,0x7ae001c7,0x00000000,0x00000000}},	//   _መሊኡ_, _ënts, --, --, 
   {{0xd18405f5,0xbdd80066,0x59d00073,0xe65801c4}},	//   длий, ngès, _सखार, _нисч_, 
   {{0xd04002ea,0x55740139,0x54547579,0x50400023}},	//   kolɔ, _югат, _оват, _ተበለጽ, 
   {{0x7ae000d2,0x4fa403d0,0xc5f00677,0x889800df}},	//   _íntf, диов, _ידן_, ַברי, 
   {{0x452000cc,0x00000000,0x00000000,0x00000000}},	//   _নিযক_, --, --, --, 
   {{0x2d800953,0xfd48063f,0xb63c037e,0xa17401e0}},	//   _prie_, _uloọ, _ｂｅ_, фҡәт_, 
   {{0x1f640046,0x8634008f,0x50b4119e,0x00000000}},	//   _үкім, וארג_, _оску, --, 
   {{0x2d801368,0x00800124,0x00000000,0x00000000}},	//   _vrie_, _алшо, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2d81b0f7,0x66ec0cb4,0x0ae81cd0,0xeaf80073}},	//   _trie_, _छींक_, ідай_, ंगेत_, 
   {{0x9f9400a2,0x2d80036e,0x2b5988d6,0xee3801ec}},	// [2f080] _eýäm_, _urie_, strc_, _днқ_, 
   {{0xbdd800f7,0x07a488d6,0x6f08020c,0x270800a2}},	//   rgèt, мазн, bèbè, _aşna_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xddcdb0f8,0x8c240154,0x00000000,0x00000000}},	//   _haaš, _বাটন_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x63540fbe,0xe5a40116,0x09a80118,0x64340137}},	//   евку, миҗи, छनीय, رىبئ, 
   {{0xbdd8bedb,0x00000000,0x00000000,0x00000000}},	//   ngèr, --, --, --, 
   {{0xf2c0053f,0x066401ec,0x43e800ec,0x00000000}},	//   ксын, _تاسپ, ٽرڪٽ_, --, 
   {{0xc0e8044e,0xdcec00e4,0x63840107,0xb270010b}},	//   _መሪር_, _araĝ, _ӯҳда, тлыш, 
   {{0x20180428,0x649400db,0x99c800eb,0x00000000}},	//   ùri_, _nàix, _শরৎক, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d480034,0xffa019bb,0xf4b402dd,0x00000000}},	//   ądan, елүү, _ىشەگ, --, 
   {{0xc05802bf,0xd24c00cf,0x00000000,0x00000000}},	//   _дій_, _اچى_, --, --, 
   {{0x443db0f9,0xdfd40962,0xceb40139,0x00000000}},	//   _jdt_, _полы, _җәю_, --, 
   {{0xbdd8004a,0x443c045a,0x00000000,0x00000000}},	//   ggèr, _mdt_, --, --, 
   {{0x443c0174,0x1dc4009d,0x00000000,0x00000000}},	//   _ldt_, _зөгн, --, --, 
   {{0xd25800e2,0x05dc0bae,0x00000000,0x00000000}},	// [2f090] ziņo_, _फुलब, --, --, 
   {{0x443db0fa,0x00000000,0x00000000,0x00000000}},	//   _ndt_, --, --, --, 
   {{0x8c2400fe,0xae1cd9e5,0xdb54005b,0x2c14012d}},	//   _বাচন_, भुवन_, _явны, तुओं_, 
   {{0x19946345,0x7bd5229b,0x00000000,0x00000000}},	//   _замя, _ixxu, --, --, 
   {{0x443c0072,0x00000000,0x00000000,0x00000000}},	//   _bdt_, --, --, --, 
   {{0x443c0f85,0x00000000,0x00000000,0x00000000}},	//   _cdt_, --, --, --, 
   {{0x443db0fb,0xded0044e,0x00000000,0x00000000}},	//   _ddt_, ኩምን_, --, --, 
   {{0x443db0fc,0x00000000,0x00000000,0x00000000}},	//   _edt_, --, --, --, 
   {{0x443c011c,0xb3dc05f9,0xc6900677,0x00000000}},	//   _fdt_, _पुरख, _גאן_, --, 
   {{0x443d83ed,0x75380526,0xc614015b,0x25a00108}},	//   _gdt_, _ivuz, ারণা_, äile_, 
   {{0xd2506e25,0x8fa4f835,0x635401c6,0x4fe80107}},	//   _منا_, хане, _авху, ямон_, 
   {{0xa3cce1ff,0x00000000,0x00000000,0x00000000}},	//   रपर_, --, --, --, 
   {{0xe13400db,0xddcc00c0,0xccd40108,0x00000000}},	//   _анчы, _paaš, ецвы, --, 
   {{0x7538337a,0xbdd8068c,0x00000000,0x00000000}},	//   _mvuz, tgèr, --, --, 
   {{0x2498067c,0xaae403e6,0x5b34084c,0x26c00115}},	//   _òrme_, نترۆ, кэту, ϲio_, 
   {{0x8a05b0fd,0x7538014b,0xc33004ae,0xb50c00dc}},	//   езбе, _ovuz, טול_, ादाय_, 
   {{0x753800ca,0x7bd4007c,0x4c340064,0x00000000}},	// [2f0a0] _nvuz, _exxu, _пэнт, --, 
   {{0xbcf8020c,0x00000000,0x00000000,0x00000000}},	//   swér, --, --, --, 
   {{0x753801b2,0x443c07c5,0xfc54010f,0x7c54010f}},	//   _avuz, _rdt_, _אביש_, _איינ_, 
   {{0x443db0fe,0xb7d425ef,0x00000000,0x00000000}},	//   _sdt_, رونا_, --, --, 
   {{0xf485b0ff,0x443db100,0xddcc002b,0xf77c0327}},	//   کانی, _pdt_, _āhūt, ħħas_, 
   {{0x443c0175,0x00000000,0x00000000,0x00000000}},	//   _qdt_, --, --, --, 
   {{0x443db101,0xa9240153,0xddcc06be,0x82a400db}},	//   _vdt_, įžus, _obaş, ешпе, 
   {{0x04c801ed,0x00000000,0x00000000,0x00000000}},	//   _کوئي_, --, --, --, 
   {{0x7ae1b102,0xd5e40046,0x443c5410,0xd5ac040b}},	//   _ínte, _айтқ, _tdt_, _وہم_, 
   {{0xddcc013d,0x98a80960,0x7d0401e1,0x6d48012d}},	//   _abaş, rsać_, _mérì, ądal, 
   {{0xf8b002e4,0xdcec0dde,0xdfd428a4,0xfe0001ad}},	//   רשת_, _arağ, тоны, रेनस_, 
   {{0xa2c40598,0x93247405,0x2bbc00e1,0xc0f40023}},	//   _шәлк, _شرمن, ोपैथ, _ወፈራ_, 
   {{0xbcf873a0,0xf234008f,0x81b800cc,0x8e7400fb}},	//   ntég, _טראץ_, _আঁক_, тҡыс_, 
   {{0x729000c7,0x70502372,0xdcec013a,0x00000000}},	//   _ашәх, _منها, _vsaď, --, 
   {{0xfbd82a8c,0xdd9004fb,0xdcec0139,0x30780a1e}},	//   _मुखम, _چوب_, _erağ, _מאגנ, 
   {{0xcfa83cc6,0x00000000,0x00000000,0x00000000}},	//   _تاهم_, --, --, --, 
   {{0x50480150,0xba380165,0x6a1400f2,0x00000000}},	// [2f0b0] _ءجۇپ_, _roïd, ابفر, --, 
   {{0x5b1447bf,0xc324015b,0xa855b103,0x00000000}},	//   _имот, _যিনি_, лкуч, --, 
   {{0x7bd40548,0xbcf800e4,0x00000000,0x00000000}},	//   _uxxu, etég, --, --, 
   {{0xe6102d74,0xaa94008e,0x00000000,0x00000000}},	//   مشه_, _биюч, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdcec098d,0xd7f464c2,0xdb200248,0x00000000}},	//   _krađ, _азгы, _ìtój, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x645c0267,0x00000000,0x00000000,0x00000000}},	//   _örin, --, --, --, 
   {{0x753801b2,0x673c00f3,0x00000000,0x00000000}},	//   _uvuz, _zvrj, --, --, 
   {{0xe4506ea9,0x6d4004d4,0x00c46733,0x0081b104}},	//   _هضم_, ámam, клык_, альо, 
   {{0x2298012c,0xdcec03b9,0x6d48012d,0x00000000}},	//   _léky_, _srağ, ądam, --, 
   {{0xe3b000c6,0x00000000,0x00000000,0x00000000}},	//   _ارك_, --, --, --, 
   {{0x320c376f,0xf8bc0a40,0x2d8527ab,0xf99c02e2}},	//   _iggy_, _ewéi_, íme_, _efèz_, 
   {{0xcb68005b,0x00000000,0x00000000,0x00000000}},	//   маге_, --, --, --, 
   {{0xfbc031f5,0xefdc001f,0x00000000,0x00000000}},	//   абро, _ናቸዉ_, --, --, 
   {{0xbcf80124,0x00000000,0x00000000,0x00000000}},	//   ytég, --, --, --, 
   {{0xf8bc04e6,0xdcec0139,0x00000000,0x00000000}},	// [2f0c0] _zwéi_, _urağ, --, --, 
   {{0xdd3003be,0xa9680075,0xfdf4011a,0x00000000}},	//   ləşd, миға_, _בצפת_, --, 
   {{0xdcec1326,0x320c0066,0x78a03b22,0x00000000}},	//   _građ, _oggy_, önva, --, 
   {{0xf7400120,0xdd3003e3,0x00000000,0x00000000}},	//   рецо, nəşd, --, --, 
   {{0x3941b105,0x2bbccc41,0xe7f4000d,0x00000000}},	//   _княг, ोपका, _अरवा_, --, 
   {{0xbcf8020c,0x75d000ae,0x00000000,0x00000000}},	//   rtég, جيها, --, --, 
   {{0x673c0841,0x00000000,0x00000000,0x00000000}},	//   _uvrj, --, --, --, 
   {{0xf7741203,0x6d480034,0xfbd00375,0xbcf80de2}},	//   _בעלי_, ądaj, יתו_, mtée, 
   {{0x26c5b106,0xb6a1b107,0xbcf8004a,0x6d40009b}},	//   _immo_, _титл, ltée, šmaj, 
   {{0xf4840344,0x850403e6,0x1f740108,0xfbd8012d}},	//   _لامی, _شوان, глоя, _मुझम, 
   {{0xefdc2295,0xf8340302,0xbcf9b108,0x9e346708}},	//   _ናቸው_, כנית_, ntée, ленч, 
   {{0xbcf82d7d,0x41a807c6,0xdd9430ab,0x00000000}},	//   itée, _овен_, гамы, --, 
   {{0x3944020c,0xaed40107,0x0ba40022,0x00000000}},	//   ąnsk_, рояш, қырҭ, --, 
   {{0x26c401e4,0xb8300248,0xd04006be,0x6b7c0055}},	//   _lmmo_, _olúṣ, knlə, _ṅgah, 
   {{0x9f5964f5,0x60c81529,0x26c4020b,0xac183594}},	//   ärä_, midm, _ommo_, тосу_, 
   {{0x60c983ed,0x3da40107,0xba7404f2,0x00000000}},	//   lidm, _ароб, خاست, --, 
   {{0xf8bc06af,0x6a1401c6,0x00000000,0x00000000}},	// [2f0d0] _ltée_, рмуу, --, --, 
   {{0x26c5b109,0x9b95b10a,0xd79400a7,0xbcf80de2}},	//   _ammo_, _биоц, лизъ, ftée, 
   {{0xdcec4beb,0xf805b10b,0x00000000,0x00000000}},	//   _urađ, тчан, --, --, 
   {{0x60c80201,0x95d80220,0xab840354,0x00000000}},	//   hidm, ндет_, _туьк, --, 
   {{0xaac800bc,0xe61000ec,0x00000000,0x00000000}},	//   _रगतक, زشن_, --, --, 
   {{0x26c5b10c,0xd25800e2,0x78f01367,0x00000000}},	//   _emmo_, miņi_, _түзу, --, 
   {{0xbcf807ea,0xd25800e2,0x233400c7,0x00000000}},	//   ctée, liņi_, ахыр, --, 
   {{0x67d5b10d,0x6d400022,0x00000000,0x00000000}},	//   _тосу, ámak, --, --, 
   {{0xd25800e2,0x00000000,0x00000000,0x00000000}},	//   niņi_, --, --, --, 
   {{0xb401b10e,0x24540228,0x00000000,0x00000000}},	//   _күлд, _ەنەس, --, --, 
   {{0xe3b04e76,0x26c4003a,0x95f400cc,0x2278315b}},	//   _ورم_, _ymmo_, _ছলিম_, رلیگ_, 
   {{0xdb1001e1,0x00000000,0x00000000,0x00000000}},	//   _àgùd, --, --, --, 
   {{0x60c8005a,0x00000000,0x00000000,0x00000000}},	//   bidm, --, --, --, 
   {{0xe1f0bd4c,0x60c9b10f,0xd04000ac,0xbcf8002e}},	//   _بسم_, cidm, ynlə, ytée, 
   {{0x0ba89067,0x29040395,0x442006be,0xc0d006c5}},	//   راسى_, _èmai_, _ək_, _ديوب, 
   {{0xd25800de,0x00000000,0x00000000,0x00000000}},	//   fiņi_, --, --, --, 
   {{0x088880cf,0xbcf81bce,0x00000000,0x00000000}},	// [2f0e0] нбай_, wtée, --, --, 
   {{0xbcf89a67,0x4b240212,0x00000000,0x00000000}},	//   ttée, _ймов, --, --, 
   {{0xc6681cd1,0xbcf839b2,0x4649b110,0xbc1800d9}},	//   ешле_, utée, езен_, _רוטש, 
   {{0xbcf8be41,0xd2580171,0x00000000,0x00000000}},	//   rtée, biņi_, --, --, 
   {{0xbcf9a607,0x2458035b,0x6594fff7,0xd25800e2}},	//   stée, валь_, ралу, ciņi_, 
   {{0xbcf807ea,0x00000000,0x00000000,0x00000000}},	//   ptée, --, --, --, 
   {{0x60c9b111,0x430801c0,0x09e4015b,0x49040725}},	//   vidm, нхим_, পেশা, _لوڭق, 
   {{0x60c81196,0x26c40455,0x00000000,0x00000000}},	//   widm, _ummo_, --, --, 
   {{0xc059b112,0x68fd988d,0x4391b113,0xc4547b8f}},	//   нін_, _khrd, рақс, _مضاع, 
   {{0xbcf801d3,0xbc940092,0x4428010b,0x00000000}},	//   ztéb, ዎችንና_, _ýb_, --, 
   {{0x74107aaf,0x5ff4390e,0xc324020f,0x60c802d0}},	//   _اوما, рзну, _смек, ridm, 
   {{0x60c9b114,0x63600521,0x00000000,0x00000000}},	//   sidm, _ịnwe, --, --, 
   {{0x60c9b115,0x1c18098a,0x9cf403de,0x00000000}},	//   pidm, _दलदल_, измі, --, 
   {{0xb17825f9,0x3154011a,0x00000000,0x00000000}},	//   _נטור, _עיון_, --, --, 
   {{0xdcb01066,0xfa88020f,0x930c00a2,0x00000000}},	//   مىڭ_, нсай_, _üşük, --, 
   {{0xd25800e2,0x62808bab,0x00000000,0x00000000}},	//   tiņi_, ndmo, --, --, 
   {{0xf848fb0a,0xbcf806af,0x7f5421f3,0x62800254}},	// [2f0f0] ечей_, rtéb, _рақс_, idmo, 
   {{0x68fc00df,0x25e805f9,0xd25800e2,0x00000000}},	//   _chrd, _जड़ी_, riņi_, --, 
   {{0xf99c0561,0x7e7c03f0,0x16c40588,0x09e400cc}},	//   _agèt_, _kaqp, аӡан, পেলা, 
   {{0xd5b01564,0xf8bc7dec,0x7c34017a,0x2b4c00bc}},	//   يفا_, _awét_, _hexr, ádce_, 
   {{0xe618005e,0xa5647146,0xe6644ae5,0x00000000}},	//   уді_, مدون, стхо, --, 
   {{0xd4680283,0x62807105,0x2bbc01bc,0x6d405821}},	//   тике_, edmo, ोपचा, ámai, 
   {{0x7c3401a9,0x628001f5,0xe78400f3,0x69d815b7}},	//   _mexr, fdmo, _луто, şvet, 
   {{0xe8e00016,0x6b8808cb,0x57e401a9,0x00000000}},	//   _đứa_, ådgi, _бўғз, --, 
   {{0xd09407d9,0x826000d1,0x61f8013d,0x00000000}},	//   ашны, تۇنن, _ğalä, --, 
   {{0x05dc2cce,0x7c340175,0x90c40fc0,0x00000000}},	//   _फुटब, _nexr, рбое, --, 
   {{0xdddc01e4,0x00000000,0x00000000,0x00000000}},	//   resŝ, --, --, --, 
   {{0xefc80240,0x00000000,0x00000000,0x00000000}},	//   _ኣዚየ_, --, --, --, 
   {{0x59a40574,0x7c34022e,0x273c01e1,0x5ec457aa}},	//   _गॅलर, _bexr, _káná_, сияғ, 
   {{0x321c011f,0xc4d0010f,0x00000000,0x00000000}},	//   lcuy_, ַגן_, --, --, 
   {{0x7e7cbdff,0xc050011a,0x00000000,0x00000000}},	//   _faqp, _וזו_, --, --, 
   {{0x7658019f,0x9ac4010b,0x321c002e,0xbcf801c7}},	//   _ncuy, бисҗ, ncuy_, ttéc, 
   {{0xefc8044e,0x3b04721f,0x08c5b116,0xf98001c0}},	// [2f100] _ኣዚዩ_, рето_, абан, огто, 
   {{0x765807a8,0xd258005f,0xf41c0139,0x00000000}},	//   _acuy, miņu_, _şän_, --, 
   {{0xd25800e2,0xbcf804e6,0xc4c400f2,0x98f401a9}},	//   liņu_, stéc, یتتو, сятч, 
   {{0x7cf80356,0x00000000,0x00000000,0x00000000}},	//   rîre, --, --, --, 
   {{0xba7404a9,0xd25800e2,0x75d0007b,0xbcf80332}},	//   _ئاپت, niņu_, ييما, ltéa, 
   {{0x7658004e,0x24f82cc8,0x00000000,0x00000000}},	//   _ecuy, ынлы_, --, --, 
   {{0x273c01e1,0xbcf802c9,0x684800e2,0xc7a406ed}},	//   _dáná_, ntéa, rīdē, _тивк, 
   {{0xbcf8007b,0x00000000,0x00000000,0x00000000}},	//   itéa, --, --, --, 
   {{0x6281b117,0xb1100b32,0x06bc015b,0xc0f400b7}},	//   rdmo, омыш, েকদি, _ወለል_, 
   {{0x273c01e1,0x25601f3f,0x7e7c0477,0xd25800e2}},	//   _gáná_, mòl_, _saqp, diņu_, 
   {{0x38140bd4,0x7e7c0309,0xa2c400d1,0xd2f400ec}},	//   יקים_, _paqp, _гәпк, _ڏکيا_, 
   {{0x442c0077,0xbcf8007b,0x645801e4,0x3ec4022e}},	//   lbf_, dtéa, lgvi, рсоб, 
   {{0x25606f90,0x7e7c0455,0x645801e4,0xba74927c}},	//   nòl_, _vaqp, ogvi, یارت, 
   {{0xba38fd3a,0x442c00e4,0xdc2800d7,0x00000000}},	//   _coïn, nbf_, pôčk, --, 
   {{0xa3cc05ba,0x7e7c094a,0x7ac444c9,0x00000000}},	//   रपट_, _taqp, асае, --, 
   {{0x25600d29,0xdcec01fa,0x961c00de,0xd25800de}},	//   kòl_, _osać, _kaņe, biņu_, 
   {{0x78248a47,0xf99c068c,0x25607d47,0xd25800e2}},	// [2f110] لعال, _agèr_, jòl_, ciņu_, 
   {{0x37a9b118,0x1a645896,0xba38000f,0x7658062c}},	//   ктен_, _گیری_, _goïn, _scuy, 
   {{0x7ae00048,0x69d80e78,0xb8cc1431,0x2cac0267}},	//   _ínto, ßver, _ओक_, ödde_, 
   {{0x645801a4,0x1a6479af,0x58841219,0x00000000}},	//   egvi, _دیری_, шыға, --, 
   {{0xdcec0115,0x25606f8d,0x69d80342,0x442c0175}},	//   _apaĉ, gòl_, şver, fbf_, 
   {{0x24f8823b,0xe50400f7,0x645801a8,0xa9340798}},	//   анчы_, يبوي, ggvi, _ферш, 
   {{0x67d5b119,0xd258005f,0x53a400cf,0x00000000}},	//   _дору, ziņu_, сайб, --, 
   {{0x7659b11a,0x272c0428,0x2560033b,0x52740798}},	//   _ucuy, _wònò_, bòl_, суку, 
   {{0x442c0333,0xf8bc020c,0x2560068c,0x645801e4}},	//   bbf_, _uwés_, còl_, bgvi, 
   {{0x504407d8,0xd25800e2,0x00000000,0x00000000}},	//   щеоб, viņu_, --, --, 
   {{0x9f58022c,0xba38068c,0x00000000,0x00000000}},	//   ørð_, _roïn, --, --, 
   {{0xd258005f,0xd17400ee,0xbdd8007f,0x638001d3}},	//   tiņu_, _гыкы, kaèd, sáná, 
   {{0xe7f41886,0x38ac013d,0x00000000,0x00000000}},	//   _अर्थ_, _kırı_, --, --, 
   {{0xd25800e2,0x7c2c01ef,0x00000000,0x00000000}},	//   riņu_, _čiré, --, --, 
   {{0xe0d005af,0x00000000,0x00000000,0x00000000}},	//   _غزه_, --, --, --, 
   {{0x25600d29,0xd25800e2,0x442c0477,0xbcf801e7}},	//   yòl_, piņu_, zbf_, rtéa, 
   {{0xbcf800c6,0xfaa080e8,0x6e2401e1,0xfafc036e}},	// [2f120] stéa, чато, _ifib, _dhë_, 
   {{0x6d45b11b,0x256133d0,0x87b80314,0x00000000}},	//   _ivia, vòl_, лует_, --, 
   {{0x25600d29,0x4038008f,0x64580115,0xdde80133}},	//   wòl_, רגעג, vgvi, _مریه_, 
   {{0xbcf9b11c,0x64580369,0xc6140eac,0x442c0334}},	//   ntén, wgvi, ার্থ_, wbf_, 
   {{0xbdd8067c,0x645801e4,0x38ac03e0,0xbcf80022}},	//   caèd, tgvi, _bırı_, itén, 
   {{0x38ac00fd,0x2561b11d,0x1ce40327,0x8364007b}},	//   _cırı_, ròl_, ྨོར_, مدبل, 
   {{0x961c0029,0x2561b11e,0x442c00e4,0xaadc21b8}},	//   _saņe, sòl_, rbf_, _यदाक, 
   {{0x6d440851,0x961c005f,0x256002bd,0x645800df}},	//   _ovia, _paņe, pòl_, sgvi, 
   {{0xc8e803d4,0x76d8014b,0x00000000,0x00000000}},	//   কগীত_, _сурӣ_, --, --, 
   {{0xf9900375,0x38ac0139,0xbcf800c7,0x00000000}},	//   פרת_, _gırı_, etén, --, 
   {{0x6449b11f,0x3898008d,0x6d44c996,0x9ed9b120}},	//   _iddi, איינ, _avia, имот_, 
   {{0xb7d802e4,0xc61400eb,0x00000000,0x00000000}},	//   רקטי, ারকা_, --, --, 
   {{0x7de4005e,0x6d440354,0xc0e5b121,0xfe0009bb}},	//   сінд, _cvia, _лодк, रेंस_, 
   {{0xf8bdb122,0x9f3402bf,0xdcec0327,0x6d4400c0}},	//   _atén_, _декі, _ipaċ, _dvia, 
   {{0x6d45b123,0xdddc01ed,0x6e24015d,0x00000000}},	//   _evia, reső, _ffib, --, 
   {{0x644801c4,0xf41c0139,0x2b4c00d7,0x00000000}},	//   _lddi, _ğäm_, ádca_, --, 
   {{0x195807dd,0x9999b124,0x6448e08f,0xc0e802d3}},	// [2f130] разы_, _iesū_, _oddi, _መሪሕ_, 
   {{0xa3b805d7,0xf804117e,0x00000000,0x00000000}},	//   ङना_, бчен, --, --, 
   {{0xa644044e,0xbdd8067c,0x6d440419,0x00000000}},	//   _ከምዝተ, saèd, _zvia, --, 
   {{0x6449b125,0xdcec02d5,0x199402e8,0x38ac0139}},	//   _addi, _praė, _дамя, _sırı_, 
   {{0x6d44005a,0xc6140183,0x00000000,0x00000000}},	//   _xvia, াৰ্থ_, --, --, 
   {{0xe508035d,0x38ac0166,0x00000000,0x00000000}},	//   مينو_, _qırı_, --, --, 
   {{0x04540597,0x00000000,0x00000000,0x00000000}},	//   زلية_, --, --, --, 
   {{0x52a80395,0xd2a80108,0x292402d2,0x00000000}},	//   рвим_, ркие_, _órað_, --, 
   {{0x64480175,0x38ac0205,0xe8200b26,0x00000000}},	//   _fddi, _tırı_, _बलमा_, --, 
   {{0x6e24011c,0x99880113,0x1ce40327,0x90c400d4}},	//   _sfib, kaaž_, ྨོས_, ібне, 
   {{0xf2e40dce,0x6d45b126,0x78a40219,0x80a8000d}},	//   _людо, _svia, _mojv, _चकरइ, 
   {{0x9324006c,0xaee40055,0x00000000,0x00000000}},	//   _هرچن, daṃm, --, --, 
   {{0xbcf8066d,0x5045b127,0x64480142,0x3ea020c2}},	//   rtén, _делб, _yddi, фияг, 
   {{0xbcf9b128,0xd00834b1,0x7ae000d2,0xb324031c}},	//   stén, _келе_, _íntj, _ལྕོང_, 
   {{0x09e011bc,0x00000000,0x00000000,0x00000000}},	//   पथ्य, --, --, --, 
   {{0x6d41b129,0x5e600131,0xff240244,0xec180bd6}},	//   ámas, _كۆپە, _ببوی, реңә_, 
   {{0x6d45b12a,0xbd3000cf,0x6d48012d,0xf984009f}},	// [2f140] _uvia, _قىيع, ądas, ينِي_, 
   {{0x2d80010a,0xb900010a,0xbcf93a52,0xd9f4000d}},	//   _isie_, дзук, ntél, _आरऐत_, 
   {{0x929c033f,0xedfc0154,0x00000000,0x00000000}},	//   jmło, _ইলিশ_, --, --, 
   {{0x06e800ee,0x00000000,0x00000000,0x00000000}},	//   шмек_, --, --, --, 
   {{0x85757cfb,0x294800c7,0xb6000006,0xc0e80023}},	//   تدائ, _ыҟан_, мяшк, _መሪሑ_, 
   {{0x2d81b12b,0x3490013e,0xbcf801d3,0x44380051}},	//   _msie_, дашр, jtél, úp_, 
   {{0x98141291,0x00000000,0x00000000,0x00000000}},	//   _ربّا, --, --, --, 
   {{0x41680114,0x2d807392,0x00000000,0x00000000}},	//   ајом_, _osie_, --, --, 
   {{0xf8bc7e7d,0x0445b12c,0x78a40455,0x96b80137}},	//   _otél_, _меан, _yojv, _ууру_, 
   {{0x6449b12d,0xc39400f3,0x00000000,0x00000000}},	//   _uddi, _мјењ, --, --, 
   {{0x2d81b12e,0x5f9401c6,0xf484520f,0x00000000}},	//   _asie_, чинт, _باقی, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbfc8022e,0x2d800332,0xe3b80139,0x20940023}},	//   _o喪ga, _csie_, _ofık_, _ክገልጹ_, 
   {{0xc6140154,0x961c00ef,0x00000000,0x00000000}},	//   ারটা_, _maņa, --, --, 
   {{0x2d80013f,0x2cac0267,0xfaa40024,0x6d41b12f}},	//   _esie_, ödda_, ошан, ámar, 
   {{0x6d48006d,0xbcf9b130,0x2d800005,0xf1bc0030}},	//   ądar, mtém, _fsie_, žšej_, 
   {{0x6d404031,0x80fc0210,0x00000000,0x00000000}},	// [2f150] šmar, _उठाओ_, --, --, 
   {{0xa89800db,0x00000000,0x00000000,0x00000000}},	//   окуу_, --, --, --, 
   {{0x78a42220,0x2b580356,0xe6100133,0x00000000}},	//   _vojv, curc_, ۆشه_, --, 
   {{0x4b7804ac,0x98a80114,0xaa9400d1,0x0af001c6}},	//   _פארו, mpač_, _жиюч, _зүсэ, 
   {{0xf770021a,0xe6102094,0xb7e8000d,0x00000000}},	//   _ښار_, نشه_, _जुरम_, --, 
   {{0xdcecdbc1,0x798c6b53,0x00000000,0x00000000}},	//   _opač, _ircw, --, --, 
   {{0x163402d5,0xf6742984,0x798c02d0,0xd7600133}},	//   _невя, _وارخ, _hrcw, _سۆشی, 
   {{0x66c801c0,0xf7d000d1,0xbcf801ef,0x00000000}},	//   _дууг_, ﻛﯜﻣﻪ, dtém, --, 
   {{0xdcec0024,0x38bc0356,0x00000000,0x00000000}},	//   _apač, _vîrf_, --, --, 
   {{0x2d801529,0xe4480150,0x798c02d0,0x00000000}},	//   _rsie_, _ولقى_, _mrcw, --, 
   {{0xbcf80525,0x8ee81611,0x72a00150,0x521401f4}},	//   rtél, ймов_, _يەتن, _едет, 
   {{0xbcf801d3,0xdb140036,0x798c03ac,0x2d803903}},	//   stél, nzzä, _orcw, _psie_, 
   {{0x98a801e4,0x82d4010f,0x00000000,0x00000000}},	//   ltaĵ_, _צונג_, --, --, 
   {{0xc2100375,0x645c02b1,0x25a00108,0xaee400b8}},	//   _נהג_, _örit, äili_, daṅm, 
   {{0xfce11486,0x798c035a,0x00000000,0x00000000}},	//   хоро, _arcw, --, --, 
   {{0x2d8001af,0xfaa1b131,0x6584001f,0x16b40073}},	//   _tsie_, насо, _በግብፅ_, ंसोब, 
   {{0x3e580302,0x6f0401f2,0x798c03ac,0x8c940150}},	// [2f160] _הדפס, _ihic, _crcw, _ерні, 
   {{0x597400c7,0xbf6402f2,0x00000000,0x00000000}},	//   ьысу, _بڵیم_, --, --, 
   {{0x961c0227,0x798c03ac,0x6f05b132,0x00000000}},	//   _saņa, _ercw, _khic, --, 
   {{0xe5e400f2,0x00000000,0x00000000,0x00000000}},	//   وزشی, --, --, --, 
   {{0x6aa406ea,0x6f047ea6,0x00000000,0x00000000}},	//   mjif, _mhic, --, --, 
   {{0x6f04062c,0x99300014,0xbcf800e4,0xa3f4187f}},	//   _lhic, _شہمت, ytém, мплі, 
   {{0x69c5b133,0x7c20045f,0x6aa4009f,0x6f04022e}},	//   lzie, _ûnre, ojif, _ohic, 
   {{0x6aa5b134,0x6f0402e3,0x88bc02f5,0xd04000ac}},	//   njif, _nhic, _আদিক, milə, 
   {{0x69c50f2e,0xdcedb0f8,0xd04000ac,0x441400fb}},	//   nzie, _spač, lilə, _ефет, 
   {{0x6f0451c5,0x69c5b135,0x2019b136,0x00000000}},	//   _ahic, izie, øri_, --, 
   {{0xd0400cc1,0x443db137,0x6f05b138,0x69c40112}},	//   nilə, _iet_, _bhic, hzie, 
   {{0x443db139,0x6f05b13a,0x6aa40198,0x00000000}},	//   _het_, _chic, jjif, --, 
   {{0x443c0ad3,0xbcf803c6,0xf0b40502,0x6f040050}},	//   _ket_, stém, زایش_, _dhic, 
   {{0x69c5b13b,0xbcf80438,0xd04003be,0x6f05b13c}},	//   dzie, ptém, kilə, _ehic, 
   {{0x443db13d,0x6f047ea6,0x69c4005f,0xbcf8f7b3}},	//   _met_, _fhic, ezie, lték, 
   {{0x6f0547c6,0x69c40086,0x443db13e,0xd04003be}},	//   _ghic, fzie, _let_, dilə, 
   {{0xdd901060,0xad24302a,0xbcf9b13f,0x20c00e89}},	// [2f170] _شود_, _كىيى, nték, _còig_, 
   {{0x443c62e8,0xf80447f9,0x38bc0022,0xd04003e3}},	//   _net_, пчен, _oîre_, filə, 
   {{0x69c5b140,0xc5a800fe,0x7b6400cf,0xd04006be}},	//   azie, _খেলপ, _этпе, gilə, 
   {{0x443db141,0xd04c013f,0xbcf8065c,0x69c4a1cd}},	//   _aet_, _ɔkɑs, kték, bzie, 
   {{0x443db142,0xdb140036,0x798c02d0,0x00000000}},	//   _bet_, rzzä, _urcw, --, 
   {{0x443db143,0xc0ec044e,0x6bd401d5,0xd0400213}},	//   _cet_, _ቀጻሊ_, _آتیر, bilə, 
   {{0x443c03d4,0xd04003be,0x68f801ed,0x97240214}},	//   _det_, cilə, őadá, _آفرو, 
   {{0x443db144,0x7468010a,0x00000000,0x00000000}},	//   _eet_, _ӳрев_, --, --, 
   {{0x443db145,0x7d1c56f7,0x6f040142,0x74680120}},	//   _fet_, _nuqs, _rhic, _грев_, 
   {{0x6f05b146,0x7538019f,0x99980118,0x00000000}},	//   _shic, _iwuz, _lesů_, --, 
   {{0x6f05b147,0x69c5b148,0xf8bc003e,0x6aa40477}},	//   _phic, zzie, _aték_, yjif, 
   {{0x443db149,0x6f041bb7,0x7539b14a,0x69c4836b}},	//   _zet_, _qhic, _kwuz, yzie, 
   {{0xd04003be,0x443c0c3e,0x20c001c3,0x2abc0332}},	//   zilə, _yet_, _bòid_, _níba_, 
   {{0x6f05b14b,0xfd5c0016,0x7538556c,0xd04000ac}},	//   _whic, _huyệ, _mwuz, yilə, 
   {{0x7d140175,0x6f04de48,0xd0400213,0x4f941cd0}},	//   _dixs, _thic, xilə, _ірку, 
   {{0x69c5b14c,0xd04000ac,0xdb1c01ed,0x20c001ab}},	//   tzie, vilə, ázás, _pòig_, 
   {{0xda640597,0x7d1401c7,0x69c40156,0x00000000}},	// [2f180] عافي, _fixs, uzie, --, 
   {{0x69c5b14d,0xfd5c0016,0xd0400213,0xcdc40c60}},	//   rzie, _luyệ, tilə, _наққ, 
   {{0x443db14e,0x75381cdf,0x69c41f05,0x00000000}},	//   _ret_, _awuz, szie, --, 
   {{0xd0400cc1,0xd6d8005e,0x443db14f,0x753801b2}},	//   rilə, пті_, _set_, _bwuz, 
   {{0x9974016c,0x7d1c0548,0xd04000ac,0x443c0c30}},	//   _пурш, _xuqs, silə, _pet_, 
   {{0x443c5c7e,0x2a6000c5,0x6ee803b9,0x75380210}},	//   _qet_, lgib_, lıbd, _dwuz, 
   {{0x443db150,0x7538014b,0xf484dd55,0xd90d5be6}},	//   _vet_, _ewuz, بانی, _ایل_, 
   {{0x2919b151,0x2a61b152,0xb9f8001f,0x443c0c18}},	//   _hira_, ngib_, _መቼ_, _wet_, 
   {{0x443db153,0xfd5c0016,0x00000000,0x00000000}},	//   _tet_, _duyệ, --, --, 
   {{0x29196282,0xbcf9b154,0x7d1c0014,0x443c036e}},	//   _jira_, rték, _ruqs, _uet_, 
   {{0x7d1c0d04,0xddcc02fb,0xf8bc0098,0x20c008c2}},	//   _suqs, _zdaň, _sték_, _ròid_, 
   {{0x2919b155,0x7d1405b1,0x00000000,0x00000000}},	//   _lira_, _sixs, --, --, 
   {{0x29180481,0xbcf81545,0x7f580477,0x00000000}},	//   _oira_, ltéi, sutq, --, 
   {{0x2919b156,0x7f580381,0xbcf80036,0x224401ab}},	//   _nira_, putq, otéi, lamk_, 
   {{0xdcb1b157,0xbcf8350d,0xac19b158,0x5f9400a7}},	//   نىڭ_, ntéi, дору_, _чийт, 
   {{0xe18807ae,0x34d80574,0x2918a597,0xbcf9b159}},	//   _kỳ_, _बद्द, _aira_, itéi, 
   {{0x2918c1eb,0x98b9b15a,0x27f81368,0xbcf9b15b}},	// [2f190] _bira_, плат_, _ayrn_, htéi, 
   {{0xbcf80221,0x7538aaa4,0x2919b15c,0x22440b4b}},	//   ktéi, _rwuz, _cira_, hamk_, 
   {{0x2919b15d,0xec140014,0x27f80042,0xe188004d}},	//   _dira_, _لوٝد, _cyrn_, _lỳ_, 
   {{0x2919b15e,0xbcf80036,0x69d001f9,0x00000000}},	//   _eira_, dtéi, _ठेवी, --, 
   {{0x2919b15f,0xa565b160,0xaba88a41,0xbcf9b161}},	//   _fira_, ندون, _فهیم_, etéi, 
   {{0x93b4035b,0x00000000,0x00000000,0x00000000}},	//   _ag̃a, --, --, --, 
   {{0x27f83deb,0xe18800a2,0x98a80327,0x7bc542ed}},	//   _gyrn_, _aỳ_, eraħ_, nzju, 
   {{0x2919b162,0x75380526,0xbcf9b163,0xfd5c004d}},	//   _zira_, _twuz, stéh, _quyệ, 
   {{0x75381446,0x7ae00048,0x5555b164,0xe6644965}},	//   _uwuz, _íntu, _سپار, _штро, 
   {{0x2919b165,0x0201b166,0xf40003d4,0x0f380092}},	//   _xira_, ызын, ৰুষৰ_, _የተረከ, 
   {{0xfd5c0016,0xe18800a2,0x3cf041d8,0xfbcc12eb}},	//   _tuyệ, _eỳ_, ंकने_, _हेलम, 
   {{0x317c0099,0x7bc400e2,0x00000000,0x00000000}},	//   pwuz_, dzju, --, --, 
   {{0xc0e802d3,0xdb0c01e1,0x00000000,0x00000000}},	//   መሮም_, _èkùl, --, --, 
   {{0xb00000b8,0x7fa806be,0xc0dc0023,0x00000000}},	//   _hiḍi, cəqo, ቕበል_, --, 
   {{0x7f48004e,0x29180ca8,0xcef41fbe,0x7fa803e3}},	//   _gvfq, _rira_, _пчињ, nəql, 
   {{0x1ea801e2,0x092801f4,0x00000000,0x00000000}},	//   _يايي_, зжай_, --, --, 
   {{0x2919b167,0x2a6000c5,0x49c84b00,0x17900092}},	// [2f1a0] _pira_, rgib_, члан_, _የሚወጡ_, 
   {{0x29180023,0x99540432,0xbcf800e4,0x00000000}},	//   _qira_, _müňe_, ytéi, --, 
   {{0x2919b168,0xd90c2354,0x6ee806be,0x00000000}},	//   _vira_, زیف_, pıbd, --, 
   {{0x7f38010f,0x00000000,0x00000000,0x00000000}},	//   פענו, --, --, --, 
   {{0x2509b169,0xf99c007f,0x6ee803e0,0x00000000}},	//   ورتی_, _ogèy_, cıbe, --, 
   {{0x7ebc02d3,0x29180374,0xbcf804e6,0x35b00024}},	//   _mëpa, _uira_, ttéi, ыбір, 
   {{0x7ebc002e,0xbcf80036,0x4b78010f,0x00000000}},	//   _lëpa, utéi, לאַו, --, 
   {{0xbcf9b16a,0xf41c0139,0x00000000,0x00000000}},	//   rtéi, _şät_, --, --, 
   {{0xbcf9b16b,0x7bc40003,0x00000000,0x00000000}},	//   stéi, zzju, --, --, 
   {{0xbcf9b16c,0x98a8025c,0x5f9400d8,0x00000000}},	//   ptéi, rraħ_, виот, --, 
   {{0x9e342fe5,0x039400ee,0xde580212,0xbcf80129}},	//   кенч, _ярая, мані_, nuée, 
   {{0xe18801fb,0xb7d808d8,0x81e003d4,0xffa001c6}},	//   _tỳ_, לקיי, _ধৰণ_, влүү, 
   {{0x69c00327,0xbcf80124,0x00000000,0x00000000}},	//   _żmen, itév, --, --, 
   {{0x2abc0248,0x5ff5b16d,0x47a400cc,0x00000000}},	//   _bíbo_, _излу, _গেছী, --, 
   {{0x9a880032,0xa2a4738f,0x3948045a,0xdb208021}},	//   мшаҡ_, काप्, _svcs_, _ütük, 
   {{0xaa643cbb,0x9f040372,0xc1000451,0x7bc40327}},	//   лтук, _جوعو, _جوڙي, rzju, 
   {{0x7cf8019f,0x5a140798,0x00000000,0x00000000}},	// [2f1b0] hîri, тмаѓ, --, --, 
   {{0x7cf8019f,0x81e0015b,0xbcf800c7,0xd878007b}},	//   kîri, _ধরা_, etév, ظمات_, 
   {{0xdcec07f5,0xbcf806af,0x3a2801ab,0xf8bc0129}},	//   _usađ, guée, _tfcp_, _nuée_, 
   {{0x98a80115,0xdbf8012d,0xbcf800e5,0x73e000c7}},	//   draĥ_, _włóc, gtév, қәзҵ, 
   {{0xa2a42e35,0x00000000,0x00000000,0x00000000}},	//   कान्, --, --, --, 
   {{0xbcf806af,0xf8bc0129,0x00000000,0x00000000}},	//   buée, _buée_, --, --, 
   {{0x61fc03be,0x7ae00af2,0x53a4001b,0x2d8c00e2}},	//   ərli, _ínts, тайб, ādei_, 
   {{0x3cf00490,0x363400f2,0x05d1b16e,0x00000000}},	//   ंकडे_, _سررس, _देवब, --, 
   {{0xc69000c8,0xbb300150,0x00000000,0x00000000}},	//   _דאן_, _ﺯﺩﻱ_, --, --, 
   {{0xd2501e2f,0x0fd80108,0x00000000,0x00000000}},	//   _چنا_, дьмы_, --, --, 
   {{0x66280267,0x2abc03b2,0x7ebc0240,0xd25002f2}},	//   _åskå, _bíbl_, _sëpa, _ننا_, 
   {{0xba39b16f,0xbdd8020c,0x00000000,0x00000000}},	//   _moïs, paèl, --, --, 
   {{0xba380ba1,0x202401e7,0x26dc00e4,0x6cb4009d}},	//   _loïs, ísiú_, évoi_, гөнт, 
   {{0x864802d3,0x4f9405f5,0xa2040212,0xc154011a}},	//   _ናጽነት, _ариу, _спід, _ישנו_, 
   {{0x0c84190b,0xbcf80022,0x26dc0022,0xbb4000d8}},	//   ныңм, ytév, ũvoi_, иерк, 
   {{0x81e00c58,0x2fe4054e,0x7ebc036e,0x00000000}},	//   _ধৰি_, ăugă_, _tëpa, --, 
   {{0xb0000a28,0xba2000f7,0x9f580108,0x00000000}},	// [2f1c0] _duḥk, рдук, ärö_, --, 
   {{0xbcf807ea,0x4b240640,0x2ea801ed,0x38c401e1}},	//   tuée, _имов, _آپکی_, _rírù_, 
   {{0x20c00ba1,0xa2a41a2a,0x81e00183,0x00000000}},	//   _jòia_, काम्, _ধৰা_, --, 
   {{0xb6c801ed,0xbfc8022e,0xf8bc0129,0x2c6c01e1}},	//   وانے_, _o喪na, _ruée_, bòdó_, 
   {{0xd90c01ed,0x05d016da,0xcfd400eb,0x00000000}},	//   زیہ_, _देशब, _সুমন, --, 
   {{0xb58401d9,0x7cf800e4,0xf41c013d,0xf814107b}},	//   کھہٕ_, tîri, _şär_, رسەگ, 
   {{0xbcf807ea,0xf740023a,0x83840024,0x5804569f}},	//   quée, _весо, тыле, _борғ, 
   {{0xbcf800dd,0x37e001c6,0x7cf80356,0x6d5800b8}},	//   ltét, _тосг, rîri, _āvan, 
   {{0xc058f9d2,0xd12c0372,0xf1a00006,0xc4847de7}},	//   мін_, كۅن_, арэн, _илак, 
   {{0xb9fc00b7,0xf5040262,0xf8bc06af,0xdef8025c}},	//   _ቀይ_, _анул_, _tuée_, duċa_, 
   {{0xbcf800e4,0xfe7c0588,0x434400d8,0x00000000}},	//   itét, teï_, _реев, --, 
   {{0x776803e3,0x00000000,0x00000000,0x00000000}},	//   _çoxş, --, --, --, 
   {{0x6281b170,0x7de4005e,0x63b9b171,0x00000000}},	//   memo, тінд, lyvn, --, 
   {{0x6281b172,0x636002e3,0x00000000,0x00000000}},	//   lemo, _ịnye, --, --, 
   {{0x7c6401b9,0xdb140306,0x3ec4014b,0x63b800e5}},	//   _یادل, lyzé, _аспб, nyvn, 
   {{0x6281b173,0xbcf800e4,0x00000000,0x00000000}},	//   nemo, etét, --, --, 
   {{0xba38180f,0xbcf80789,0x628003cd,0xdd94a654}},	// [2f1d0] _soïs, ruéb, iemo, _сапы, 
   {{0x6281b174,0xf8bc0c6a,0x63b80fac,0x00000000}},	//   hemo, _suéb_, kyvn, --, 
   {{0x6281b175,0x286802e8,0x6ee80139,0x00000000}},	//   kemo, ърто_, lıba, --, 
   {{0x7ebc0023,0x961c00ef,0x00000000,0x00000000}},	//   _mëpo, _kaņi, --, --, 
   {{0x2988024c,0xe50800f1,0x6ee803e0,0x85000116}},	//   _исро_, چينو_, nıba, ڭۈلن, 
   {{0x7afc0054,0x58d401c0,0xbcf801d3,0x57240725}},	//   llqt, _согт, mtés, _مىسك, 
   {{0xbcf800dd,0x437005e6,0xe785b176,0xdbdc0419}},	//   ltés, مهور, _куто, _ošíp, 
   {{0x20c00ba1,0x796400b0,0x00000000,0x00000000}},	//   _ròia_, pūwā, --, --, 
   {{0xbcf9b177,0xdb1400dd,0x00000000,0x00000000}},	//   ntés, gyzé, --, --, 
   {{0x62800618,0x00801436,0x00000000,0x00000000}},	//   aemo, бльо, --, --, 
   {{0x62801d62,0x52749e04,0xae0c2122,0x1ce40327}},	//   bemo, _булу, _सृजन_, ྨོན_, 
   {{0x62805599,0xa2a4102f,0xbcf801d3,0x89d801e1}},	//   cemo, काण्, ztét, _lípẹ, 
   {{0xbcf95ce3,0x00000000,0x00000000,0x00000000}},	//   jtés, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe0d00bce,0x4a9802d5,0x2c0400d1,0x961c0171}},	//   _بزن_, нтаў_, рүнм, _daņi, 
   {{0x0e6447c7,0xc3300375,0x0d858013,0x00000000}},	//   _скин, מול_, _блин, --, 
   {{0xfe340375,0x6ee81cce,0xa2a400cd,0xbcf800e5}},	// [2f1e0] _גרפי_, cıba, कात्, ttét, 
   {{0x6a844908,0x6281b178,0xbb342e56,0x291c01e6}},	//   ылға, zemo, ﮔﻪﻥ_, öva_, 
   {{0xf8bc068c,0x27fc00b5,0xf8ac004b,0x8d74451a}},	//   _atés_, ævn_, ښکې_, _شاکا, 
   {{0x6280172e,0xbcf9b179,0x86441b2e,0x85e80261}},	//   xemo, stét, ундж, ндев_, 
   {{0x6281b17a,0xbcf80077,0x248c0175,0x09b000eb}},	//   vemo, quéc, _padm_, _ঘেরা, 
   {{0xbcf801ed,0x597400f7,0x81e000eb,0x00000000}},	//   ltér, _тыюу, _ধরল_, --, 
   {{0x6281b17b,0xbcf80008,0x00000000,0x00000000}},	//   temo, bréf, --, --, 
   {{0x96942082,0xf2c1b17c,0x20c001ab,0x7ebc002e}},	//   _круш, йсын, _còin_, _rëpo, 
   {{0x6280302f,0x26c5b17d,0xbcf80022,0xb6a001a9}},	//   remo, _ilmo_, itér, _уитл, 
   {{0x20c00e89,0x55c4054a,0xf484030f,0xbcf800e5}},	//   _eòin_, _тауғ, _مامی, mrég, 
   {{0x201954e4,0x6281b17e,0x20c001ab,0x826405d9}},	//   äri_, pemo, _fòin_, _مهان, 
   {{0x8c080154,0x9e1400d4,0x8fd4013d,0x00000000}},	//   লশান_, идні, шәчә, --, 
   {{0xc21001d9,0xbcf801d3,0x961c00ef,0x00000000}},	//   _أش_, dtér, _paņi, --, 
   {{0xbcf800c7,0x00000000,0x00000000,0x00000000}},	//   etér, --, --, --, 
   {{0xbcf809c2,0x00000000,0x00000000,0x00000000}},	//   guéa, --, --, --, 
   {{0xfeb83629,0xf0a40022,0x442c0175,0xbcf801d3}},	//   _ساعت_, _акәл_, hcf_, gtér, 
   {{0x74a40d2c,0xd95420d4,0x6d4800e2,0x89d801e1}},	// [2f1f0] चामृ, شناخ, ņdar, _pípẹ, 
   {{0xbcf801ed,0xdcec031c,0x05d000c5,0x5c740798}},	//   rtés, _fraġ, _देइब, _тлот, 
   {{0xf80425ec,0xbcf957a0,0x442c0334,0x7fa806be}},	//   учан, stés, dcf_, fəqi, 
   {{0xbcf9b17f,0x7cf8019f,0x8b38011a,0x1a64085b}},	//   ctér, rîru, _שתרצ, _خیری_, 
   {{0xd468dc3f,0x20c001c3,0xbcf9b180,0x442c010a}},	//   виле_, _ròin_, rréf, fcf_, 
   {{0xf6500451,0x26c49721,0x00000000,0x00000000}},	//   _گئس_, _elmo_, --, --, 
   {{0xdee802d3,0x88040014,0x00000000,0x00000000}},	//   ዘሎን_, _نظٲم, --, --, 
   {{0x362001d9,0x00000000,0x00000000,0x00000000}},	//   _طوطہ, --, --, --, 
   {{0x91e5b181,0x764809a5,0x6595b182,0x2abc01e7}},	//   ропе, magy, _лату, _díbh_, 
   {{0x7649b183,0x50b40262,0x4f940024,0x85240244}},	//   lagy, рсиу, арму, _ئولۆ, 
   {{0xf1a4eb12,0xb1a402dd,0xe4a4024c,0xbcf800c7}},	//   _әрен, _әшек, _урто, ytér, 
   {{0x7649b184,0x7c20000f,0xbcf806af,0xdcec0327}},	//   nagy, _ûnrj, xtér, _rraġ, 
   {{0x10a53ae9,0x0ba80131,0x9f940022,0x463800df}},	//   _вилн, ھاسى_, _ҳшыш, כערע, 
   {{0x7649b185,0x0ba81473,0x8f9800d1,0x60c808c2}},	//   hagy, پاسى_, _аъит_, chdm, 
   {{0xbcf9b186,0xe0d07092,0xd010007b,0x7649b187}},	//   ttér, _عزه_, _بلغ_, kagy, 
   {{0x69c000e4,0xbcf800e4,0x764800ee,0xdddc01ef}},	//   _ümek, yrég, jagy, cesů, 
   {{0x2d8c00da,0x6e25b188,0x764800ee,0x6ee80213}},	// [2f200] ādes_, _igib, dagy, lıbo, 
   {{0xbcf9b189,0x76480076,0xdcec025c,0x8c64004e}},	//   stér, eagy, _traġ, _өтүд, 
   {{0x6e2401af,0xbcf9b18a,0x6d440042,0x764801d3}},	//   _kgib, ptér, _hwia, fagy, 
   {{0x6d45b18b,0x6e24031c,0xf54c063f,0xbcf80005}},	//   _kwia, _jgib, pụli_, trég, 
   {{0x6595b18c,0xa2a4de9c,0xc7640131,0x2459b18d}},	//   салу, कास्, _ھاسى, галь_, 
   {{0xbcf9b18e,0xd1e801f3,0xc7641870,0x00000000}},	//   créd, ቅነት_, _پاسى, --, 
   {{0x6e25b18f,0x7649b190,0xbcf9b191,0x8250001f}},	//   _ogib, bagy, kuén, _ማበረታ, 
   {{0x6e25b192,0xbcf9b193,0x2abc01e1,0x26c5b194}},	//   _ngib, prég, _bíbi_, _ulmo_, 
   {{0x60f806bb,0xaca40241,0x20c000a3,0x00000000}},	//   лния_, _arọw, _fòil_, --, 
   {{0x6e242930,0xbcf80129,0x98a80210,0x80b000db}},	//   _agib, orée, rpać_, تەتش, 
   {{0xaf303306,0xf99c007f,0x43843c5b,0x6d45b195}},	//   يرَت, _azèl_, _خلاق, _awia, 
   {{0xaca4063f,0x6449b196,0x6721b197,0xd3c400db}},	//   _drọw, _hedi, _jimj, _اتكى, 
   {{0xa159b198,0x3cf142f0,0x3f800118,0xe13400b1}},	//   _салу_, ंकले_, ňku_, _унлы, 
   {{0x64480b9d,0x6e25b199,0x764800ee,0x99980030}},	//   _jedi, _egib, zagy, _jesť_, 
   {{0x7649b19a,0xf99c007f,0x70500345,0x00000000}},	//   yagy, _ezèl_, _بۆپا, --, 
   {{0x6449b19b,0x1b19b19c,0xbcf9b19d,0x67201ba4}},	//   _ledi, ужбы_, cuén, _nimj, 
   {{0x6d45b19e,0xdcec031c,0x32c000a2,0x7649b19f}},	// [2f210] _gwia, _jqaċ, _oñyn_, vagy, 
   {{0x6449b1a0,0x6e249ae3,0xe3b80139,0x7649b1a1}},	//   _nedi, _zgib, _agım_, wagy, 
   {{0x6d45b1a2,0x7649b1a3,0xbcf8004a,0x61e40115}},	//   _zwia, tagy, grée, _ɾila, 
   {{0x64480483,0x99880219,0x76480076,0xe75800d4}},	//   _aedi, mbaž_, uagy, риці_, 
   {{0x35687157,0xd4d84077,0x7649b1a4,0xdee80023}},	//   трен_, лькі_, ragy, ዘሎና_, 
   {{0x6449b1a5,0x0440055f,0xbcf9b1a6,0x0664035b}},	//   _cedi, пешн, brée, ахәҭ, 
   {{0x7649b1a7,0xbcf8004a,0x660003b2,0x2abc0248}},	//   pagy, crée, _eymk, _síbi_, 
   {{0x6449b1a8,0x66040003,0x00000000,0x00000000}},	//   _eedi, żika, --, --, 
   {{0x64482d32,0xbcf807dd,0xf99c007f,0xc6840133}},	//   _fedi, ytép, _ozèm_, _دێنن_, 
   {{0x6449b1a9,0x6d4403a2,0x60d8056a,0x00c4d687}},	//   _gedi, _rwia, _cmvm, йлык_, 
   {{0x6d45b1aa,0xa2a400cd,0x00000000,0x00000000}},	//   _swia, काश्, --, --, 
   {{0x6449b1ab,0xd490004d,0xadc400c7,0x00000000}},	//   _zedi, _hà_, ahẽk, --, 
   {{0xa2a43711,0x6449b1ac,0x6464054e,0x00000000}},	//   कार्, _yedi, ştiţ, --, 
   {{0x41b0005e,0xc0dc0023,0x644806be,0x69100254}},	//   _ءمور, ሕበር_, _xedi, mäeg, 
   {{0xd490001e,0xbb4000d8,0x45500240,0x6ee803b9}},	//   _mà_, зеск, _ኣይንጠ, lıbm, 
   {{0x6e25b1ad,0x6d4402c4,0xd490001e,0xf8bc056a}},	//   _ugib, _twia, _là_, _quén_, 
   {{0x092880de,0x6d45b1ae,0x67200135,0xd3640451}},	// [2f220] اسري_, _uwia, _rimj, _ڪڇ_, 
   {{0xbcf820ef,0xa9680075,0x6600000f,0x6720d739}},	//   trée, лиға_, _rymk, _simj, 
   {{0x6ee800ac,0x66000165,0x2d040490,0x6284002e}},	//   yıbl, _symk, ळतील_, _ñiog, 
   {{0x6449b1af,0x67203bc8,0xbcf84e01,0x09e40120}},	//   _sedi, _qimj, rrée, _гомн, 
   {{0x64487963,0xd490004d,0x25a001e4,0xa5f80114}},	//   _pedi, _bà_, ĥilo_, јелу_, 
   {{0x6cf802e5,0x23380137,0x66000306,0xbcf8007f}},	//   ंकिग_, апкы_, _vymk, prée, 
   {{0x6448b996,0x67216fea,0xa2a40864,0x9734009d}},	//   _vedi, _timj, काल्, _мэтч, 
   {{0x6449b1b0,0xdd2c0006,0x69100221,0xa5c40166}},	//   _wedi, vėžy, fäeg, _мөле, 
   {{0xb6b80375,0x845800d8,0x00000000,0x00000000}},	//   _עצמי, _брет_, --, --, 
   {{0xe29807dd,0x9f54f300,0xbcf819f5,0xc32c0328}},	//   уаҩ_, овоч, guél, _كەت_, 
   {{0x2d804077,0xc1a40220,0xbcf801c7,0x78f80375}},	//   _apie_, рыққ, hréc, רפיו, 
   {{0xdcec0327,0x3ec41d3e,0x8e20022e,0x00000000}},	//   _tqaċ, ссоб, tikа_, --, 
   {{0x86280092,0x00000000,0x00000000,0x00000000}},	//   _ትናንት, --, --, --, 
   {{0xbcf9b1b1,0x3f88025c,0x00000000,0x00000000}},	//   dréc, ħbub_, --, --, 
   {{0x2d80013f,0x7ebc0240,0xe13400fb,0x00000000}},	//   _epie_, _lëpi, _унһы, --, 
   {{0xbcf80036,0x7cdc0153,0x00000000,0x00000000}},	//   fréc, _sąrė, --, --, 
   {{0x7824386e,0x7c844123,0xb7440133,0x58d8020f}},	// [2f230] معال, _луне, ڵئاو, адая_, 
   {{0x38bc145e,0x77c84a1a,0x00000000,0x00000000}},	//   _kîri_, луев_, --, --, 
   {{0x38bc025a,0x56941de1,0xddcc0034,0x1a644e5c}},	//   _jîri_, жает, _udał, _ویسی_, 
   {{0xdcec0115,0xbcf9b1b2,0xbdd80022,0x00000000}},	//   _draĥ, bréc, baèt, --, 
   {{0x98c40365,0x942461cc,0x61e433e9,0xfafc036e}},	//   ştır_, омле, _žiln, _ikë_, 
   {{0x798c03ac,0xe3b0320a,0xbcf800e4,0x6910000d}},	//   _iscw, کره_, kuém, väeg, 
   {{0xd490001e,0xd2a8796c,0x00000000,0x00000000}},	//   _và_, икке_, --, --, 
   {{0xf99c007f,0xd2981084,0x533401e0,0x515401ee}},	//   _tyèd_, рткі_, беҫт, отоу, 
   {{0xddd40139,0x0f380092,0x00000000,0x00000000}},	//   _ğaşu, _የተላከ, --, --, 
   {{0xf99c0100,0x798c02d0,0xddd40139,0x2d8403e0}},	//   _azèk_, _mscw, _şaşu, çmem_, 
   {{0xd00828cf,0xbef40574,0xfafcb3db,0x2d810f07}},	//   рене_, ीतून_, _okë_, _spie_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x81e000fe,0x00000000,0x00000000,0x00000000}},	//   _ধৰক_, --, --, --, 
   {{0xf0000323,0x798c2fb2,0x81dc00cc,0x00000000}},	//   _хүни, _ascw, _দুপ_, --, 
   {{0xfaa1b1b3,0x798c02d0,0xbcf84e01,0x81640023}},	//   масо, _bscw, tréc, _ተቐበሉ_, 
   {{0x2bc801ad,0xab28820c,0x515800df,0x00000000}},	// [2f240] रनहा, роға_, יכּו, --, 
   {{0xce34004b,0xbcf804e6,0x00000000,0x00000000}},	//   _اوښک, rréc, --, --, 
   {{0x798c03ac,0x56540023,0x00000000,0x00000000}},	//   _escw, _ከምዝጠ, --, --, 
   {{0xbcf9b1b4,0x660401b8,0x91c832ed,0x00000000}},	//   préc, üiko, िनाई, --, 
   {{0xddcc068f,0x0dec0092,0x69d801e4,0xdb140241}},	//   _gdań, _ሀላፊ_, ŝveb, _íbán, 
   {{0xdcec01e4,0x1ce4031c,0x61e402f0,0xa02c0023}},	//   _traĥ, ཨོར_, _žilo, ደትንሳ, 
   {{0xdb141ab0,0x93b40124,0xbcf80332,0x00000000}},	//   lyzá, _og̃u, nréa, --, 
   {{0x973401c6,0x724000d1,0xbcf801e7,0x07a401f0}},	//   _хэрч, وپىل, iréa, _лаҳн, 
   {{0xc4e40139,0x04586728,0xdb1401d3,0xbcf801e7}},	//   _джай, _نجات_, nyzá, hréa, 
   {{0xb461b1b5,0x93b400c7,0x816402d3,0xbcf80687}},	//   _окул, _ag̃u, _ተቐቢሉ_, kréa, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbcf8020c,0x425003e6,0xfe7c0142,0x224000a2}},	//   dréa, _کۆکر, rnïo_, _ýik_, 
   {{0xf6500302,0xdef8031c,0x00000000,0x00000000}},	//   וצר_, nuċi_, --, --, 
   {{0x25a0023a,0xbcf801e7,0x00000000,0x00000000}},	//   äily_, fréa, --, --, 
   {{0xbcf9b1b6,0x798c03ac,0xab940212,0x57b80073}},	//   gréa, _sscw, мирі, _इथेह, 
   {{0x26dc00db,0x6d580055,0x00000000,0x00000000}},	//   èvol_, _āvav, --, --, 
   {{0x1958035b,0x7e78000d,0x00000000,0x00000000}},	// [2f250] сазы_, õupu, --, --, 
   {{0xf805b1b7,0xdef80003,0x00000000,0x00000000}},	//   очен, duċi_, --, --, 
   {{0x37a9b1b8,0x7d0401fa,0xbcf8004a,0xbdd8020c}},	//   штан_, mljs, créa, paès, 
   {{0xfafc036e,0x00000000,0x00000000,0x00000000}},	//   _ukë_, --, --, --, 
   {{0x798c03ac,0x1544010b,0x00000000,0x00000000}},	//   _uscw, челм, --, --, 
   {{0xab98221d,0xf99c0248,0xe57852c4,0x7fa806be}},	//   _اخیر_, _irè_, юзі_, həqq, 
   {{0x0454007b,0x50b400c7,0x00000000,0x00000000}},	//   سلية_, ҧсоу, --, --, 
   {{0xd2a8169c,0x2d84482b,0x7ebc0023,0xf99c0100}},	//   ские_, çmek_, _këpu, _krè_, 
   {{0x1558010f,0x00000000,0x00000000,0x00000000}},	//   _לכּב, --, --, --, 
   {{0x7539b1b9,0x98bc04aa,0x94d41e5a,0x92b400ec}},	//   _ituz, ोसिए, _عياش, تحڪا, 
   {{0x29040134,0x8fa47df1,0xa9100115,0xe1f12766}},	//   _ɔma_, чане, ntɾa, _یسه_, 
   {{0xe29810f5,0xf99c5cee,0x7b11b1ba,0xbdd8067c}},	//   _має_, _orè_, nçud, vaèr, 
   {{0x7ebc0023,0x3ea80306,0x00000000,0x00000000}},	//   _nëpu, _šité_, --, --, 
   {{0x7538009a,0xbcf80005,0xefe8001f,0xc198011a}},	//   _mtuz, tréa, ቅሰው_, _לשני, 
   {{0x63a40053,0xf99cf21a,0x00000000,0x00000000}},	//   āing, _arè_, --, --, 
   {{0x753927bf,0xbcf8004a,0xbdd8020c,0x00000000}},	//   _otuz, rréa, mbèn, --, 
   {{0xf99c020c,0x7539b1bb,0xf8bc0c6a,0xc96400a7}},	// [2f260] _crè_, _ntuz, _kuéh_, явай, 
   {{0x7659797c,0xcc892554,0x00000000,0x00000000}},	//   _aduy, _انده_, --, --, 
   {{0x7539b1bc,0x0685b1bd,0xf99c02bd,0xe6c400ec}},	//   _atuz, зген, _erè_, وڪري, 
   {{0xf99c0d29,0xbcf80066,0xd6d80212,0x00000000}},	//   _frè_, nrén, оті_, --, 
   {{0x765804ba,0xf99c007f,0xd90c01d5,0xba98011a}},	//   _dduy, _grè_, _چیق_, _הסכי, 
   {{0x7af8151c,0x7bd003d4,0x00000000,0x00000000}},	//   čute, _দুয়ো, --, --, 
   {{0x753804ba,0xbcf801ed,0x580402dd,0xddcc00ef}},	//   _etuz, krén, _жорғ, _gdaņ, 
   {{0xd37802bf,0xd76401b9,0x3d200241,0xf53c1155}},	//   ючі_, _آچلی, _kéwì_, šťan_, 
   {{0x7fa800ac,0xbcf9b1be,0x00000000,0x00000000}},	//   vəqq, drén, --, --, 
   {{0x94040213,0x00000000,0x00000000,0x00000000}},	//   _lalə_, --, --, --, 
   {{0x7d0405be,0x3898010f,0xdfd558ff,0x261810eb}},	//   vljs, זיינ, фоны, बेरी_, 
   {{0x6b9c05ce,0xbcf803da,0x940406be,0xc8f800cd}},	//   dvrg, grén, _nalə_, ्तुम_, 
   {{0xb8dc031c,0x7b1006af,0x7fa800ac,0xbcf801c7}},	//   _ཀྭ_, nçue, rəqq, luéi, 
   {{0xaf3007d6,0xb1100212,0xbcf802f0,0x98a80327}},	//   بریت, _зміш, ltéz, msaħ_, 
   {{0xab84481b,0x7ee40276,0xbcf801c7,0x30780375}},	//   нутк, _нцие, brén, _האונ, 
   {{0x3d200248,0xbcf801ed,0xf99c02bd,0xcfd4009e}},	//   _béwì_, ntéz, _prè_, _সুকন, 
   {{0x98b9b1bf,0x6aac1d55,0x61e40010,0x9f58003a}},	// [2f270] олат_, _šofé, _žilj, æræ_, 
   {{0xf99c02bd,0xbcf8e2a5,0xb4c80037,0x00000000}},	//   _vrè_, kuéi, _लते_, --, 
   {{0x7539b1c0,0x5b1403fb,0x00000000,0x00000000}},	//   _stuz, _омот, --, --, 
   {{0xf99db1c1,0xa63400d6,0x32e0007f,0xbc240150}},	//   _trè_, енці, _mèyè_, _ورگى, 
   {{0xf99c04cc,0x7b100200,0x2618190e,0x00000000}},	//   _urè_, rçud, बेली_, --, 
   {{0x39480142,0x00000000,0x00000000,0x00000000}},	//   _iwcs_, --, --, --, 
   {{0xbcf9b1c2,0x32e0007f,0xe45000c6,0x69c00254}},	//   guéi, _nèyè_, اضه_, _ümer, 
   {{0x2480098d,0x81dc015b,0xa2a4084d,0x00000000}},	//   đima_, _দুধ_, काग्, --, 
   {{0xf485b1c3,0x75380230,0xc0cc001f,0x7ebc01c7}},	//   _нужн, _utuz, _ብሎም_, _lëps, 
   {{0xbcf80022,0x656400e4,0x00000000,0x00000000}},	//   buéi, áihe, --, --, 
   {{0x52740137,0xc4d0011a,0xdec80092,0x00000000}},	//   _жулу, _שגב_, _አማኝ_, --, 
   {{0x32e00699,0xbdd804fb,0xc3f8011a,0x00000000}},	//   _dèyè_, rbèn, _ולעש, --, 
   {{0x13a4168d,0xbcf8068c,0x62240131,0x7afc014f}},	//   _رۆکی_, rrén, _كىمل, doqt, 
   {{0xbdd8020c,0xdef80003,0x00000000,0x00000000}},	//   mbèl, duċu_, --, --, 
   {{0xbcf9b1c4,0xf8bc0022,0xfc0000d4,0xcef40798}},	//   prén, _guéi_, впро, _очињ, 
   {{0xb640069d,0x00000000,0x00000000,0x00000000}},	//   _ሪፑብሊ, --, --, --, 
   {{0x673db1c5,0xa3e403f3,0x00000000,0x00000000}},	// [2f280] _strj, _पेन_, --, --, 
   {{0x61e5b1c6,0x02d800bc,0x00000000,0x00000000}},	//   _žilk, _बग्न, --, --, 
   {{0x6d4043e5,0x3ed403e6,0x7afc0455,0x00000000}},	//   ímaf, _رویج_, boqt, --, 
   {{0x7c200332,0x06080108,0x00000000,0x00000000}},	//   _únra, онек_, --, --, 
   {{0x6f04009f,0xbdd8007f,0x00000000,0x00000000}},	//   _mkic, jbèl, --, --, 
   {{0x7b1198c9,0xbcf801c7,0x00000000,0x00000000}},	//   rçue, tuéi, --, --, 
   {{0x6f05b1c7,0x673c0219,0x4ad1b1c8,0xd6bc00cc}},	//   _okic, _utrj, _सताव, _আগৰপ, 
   {{0x6f05b1c9,0x236009a8,0xdddc00d0,0xb7d8011a}},	//   _nkic, čij_, lesť, _וקלי, 
   {{0x69c5b1ca,0xbcf80789,0xaf400092,0x00000000}},	//   nyie, muév, _የተሻለ, --, 
   {{0x6f05b1cb,0x69c40086,0x3eb80327,0xbcf81155}},	//   _akic, iyie, _soqt_, stéz, 
   {{0x69c40399,0x7afc03f0,0xbcf9b1cc,0x98a8025c}},	//   hyie, yoqt, quéi, ssaħ_, 
   {{0x6f040109,0xa3e40bc0,0x74100133,0x41280117}},	//   _ckic, _पेय_, _شونا, _додо_, 
   {{0xf0b403e6,0x20c0026c,0x69c40399,0x7afc014f}},	//   سایش_, _sòiu_, jyie, voqt, 
   {{0x39480004,0x6f0519fb,0x69c40399,0x8c38016c}},	//   _rwcs_, _ekic, dyie, зорӣ_, 
   {{0x2b580334,0xbcf8035b,0x00000000,0x00000000}},	//   gsrc_, kuév, --, --, 
   {{0x69d801e4,0xddcc0419,0x69100254,0xaa6400db}},	//   ĝven, _ibaž, väea, ктук, 
   {{0x69d801e4,0xe5bc01e1,0x00000000,0x00000000}},	// [2f290] ŝven, _àsẹ̀, --, --, 
   {{0x20c0026c,0x00000000,0x00000000,0x00000000}},	//   _tòiu_, --, --, --, 
   {{0x6f040784,0xdcec0419,0xe730009f,0xb90447b8}},	//   _ykic, _kraľ, لصن_, _बग_, 
   {{0x3a2804cc,0x7afc02d1,0xbcf80124,0x5ec000eb}},	//   _ugcp_, qoqt, guév, শোরে, 
   {{0xfbd00050,0xb4b00131,0x69100108,0x7b1003b9}},	//   _ستھ_, кидә, mäen, pçub, 
   {{0xa8a40b3e,0xdc1800e2,0x6d4001e4,0xbcf800e5}},	//   _ирск, _lāčp, ŭmag, krém, 
   {{0xbcf8035b,0x504400c7,0x00000000,0x00000000}},	//   buév, ҭеиб, --, --, 
   {{0xbcf80109,0xe6640107,0x00000000,0x00000000}},	//   drém, _атфо, --, --, 
   {{0xbcf80077,0x20c000a3,0xa3e40073,0xddcc00ef}},	//   trél, _nòis_, _पेठ_, _abaž, 
   {{0xe5714d6b,0x6f049c56,0xbeb80036,0x630407d6}},	//   _خطف_, _skic, hmëd, _یولل, 
   {{0xe374035b,0xbcf9b1cd,0x69c40399,0x2f34054e}},	//   _алхы, rrél, zyie, _băga_, 
   {{0x10800150,0xa34400c0,0x00000000,0x00000000}},	//   _ﯩﺰﺩﯨ, _рэфл, --, --, 
   {{0x2bc80782,0x69c40369,0xbcf8020c,0x2b58010a}},	//   रन्थ, xyie, prél, wsrc_, 
   {{0xbcf80306,0xc0bc0092,0xa3e4121d,0x00000000}},	//   brém, ቶታል_, _पेड_, --, 
   {{0x9f943cbb,0xa2a41fbc,0xbcf8004a,0x69c40368}},	//   _ашыш, काच्, crém, wyie, 
   {{0x61e401a2,0x6f044793,0x69c40369,0xf99c0100}},	//   _žili, _ukic, tyie, _vyèn_, 
   {{0x2b58b516,0x2ecc00cd,0x00000000,0x00000000}},	// [2f2a0] ssrc_, ासीत, --, --, 
   {{0xba140592,0xf99c0100,0x7ebc0036,0x98a801e4}},	//   ريلا_, _iyèl_, _hëpp, kraĵ_, 
   {{0x69c4e622,0x386401f6,0x00000000,0x00000000}},	//   syie, ónra_, --, --, 
   {{0xd0400cc1,0x00000000,0x00000000,0x00000000}},	//   rhlə, --, --, --, 
   {{0x69c40399,0x20c001c3,0xb600e662,0x91c807f7}},	//   qyie, _mòir_, ляшк, िनोइ, 
   {{0x24800e3c,0xf99c033b,0x7ebc0036,0xb9200092}},	//   đimo_, _myèl_, _lëpp, ታወሻዎ, 
   {{0xd36c167e,0xddcc00b8,0xe2f802dd,0xf3600209}},	//   قۇل_, _bdaś, мекі_, гтын, 
   {{0x733000f2,0x00000000,0x00000000,0x00000000}},	//   دروئ, --, --, --, 
   {{0x45340212,0x7b100200,0x00000000,0x00000000}},	//   _їхат, nçua, --, --, 
   {{0xbcf98662,0x20c000a3,0xa2a400cd,0x6d580055}},	//   trém, _ròis_, काङ्, _āvap, 
   {{0x29180327,0x81dc00cc,0x00000000,0x00000000}},	//   _mhra_, _দুশ_, --, --, 
   {{0xf99c0100,0x20c00e89,0xbcf8529d,0x6ee806be}},	//   _byèl_, _còir_, rrém, dıbs, 
   {{0x29180003,0x7ebc1574,0xbcf80022,0x691001f4}},	//   _ohra_, _dëpp, kuét, väen, 
   {{0x6281b1ce,0xddcc0327,0xbcf9b1cf,0x709000fb}},	//   lfmo, _ibaż, prém, _башф, 
   {{0x20c000a3,0xd01001d3,0xfaa45e82,0x929c0210}},	//   _fòir_, _پلٹ_, ншан, sołe, 
   {{0x29180263,0x7ebc1bce,0xf99c02e2,0xaa94010b}},	//   _ahra_, _gëpp, _fyèl_, лисч, 
   {{0xe9f87707,0x00000000,0x00000000,0x00000000}},	// [2f2b0] енті_, --, --, --, 
   {{0x29180810,0xbcf800e4,0x00000000,0x00000000}},	//   _chra_, guét, --, --, 
   {{0x6910b6a5,0xe81c2983,0x7f580334,0x6e4802d2}},	//   mäel, भेला_, nstq, _ísbí, 
   {{0x29180280,0x7bc4014b,0x7ebc002e,0x628001f5}},	//   _ehra_, myju, _xëpp, jfmo, 
   {{0x9f5c0664,0xf99c0100,0xa8740220,0x66744caa}},	//   _hyvä_, _kyèm_, _әлсі, ادمر, 
   {{0x29181368,0xbcf80789,0x628001a4,0xd91801c0}},	//   _ghra_, mués, efmo, _цогц_, 
   {{0xd7c800aa,0xf8bc003e,0xb9d8001f,0x6280002f}},	//   _غوره_, _duét_, _አር_, ffmo, 
   {{0xddcc003d,0x656405be,0xf99c06af,0xd184b42d}},	//   _bbaż, šiha, _uzès_, влий, 
   {{0x25a401c7,0x69100037,0x00000000,0x00000000}},	//   _grml_, käel, --, --, 
   {{0xf99c007f,0xbdd8020c,0x90c401d5,0x02000139}},	//   _nyèm_, mbèh, тбое, рзьн, 
   {{0xf99c0699,0x7ebc0036,0x7bc400e4,0xe2c800f1}},	//   _syèl_, _pëpp, jyju, _ګونو_, 
   {{0x670400a2,0xe57001d3,0xddcc0055,0x00000000}},	//   _iňkä, _خطہ_, _udaś, --, 
   {{0x7bc401a8,0x61e40153,0x624c010e,0x4df4003b}},	//   eyju, _žilv, _ỳogs, тянт, 
   {{0xadc40184,0x06c8009e,0x6910000d,0x00000000}},	//   _ҡайһ, লোপি, väeo, --, 
   {{0x6d40012b,0x7af80219,0x8f140276,0x7ebc01c7}},	//   ímab, čutn, _ифич, _tëpp, 
   {{0xc3301203,0xbff400d8,0x00000000,0x00000000}},	//   שון_, _шејх_, --, --, 
   {{0x3b05b1d0,0x291806a3,0xbcf9b1d1,0x09280153}},	// [2f2c0] тето_, _phra_, gués, джай_, 
   {{0x07a4242f,0xba380129,0x7b100200,0x00000000}},	//   казн, _naïf, rçua, --, 
   {{0xd90db1d2,0xbcf80306,0x7b1006be,0x00000000}},	//   سیف_, dréh, mçun, --, 
   {{0xdd10012c,0xbcf80ffb,0xf99c02e2,0x7b100213}},	//   mýšl, suét, _zyèm_, lçun, 
   {{0xd90d7409,0xe3b80166,0x19f80276,0x291875d3}},	//   _کیل_, _agıp_, _зэрь_, _thra_, 
   {{0x25a402fa,0xf8bc001e,0xbcf800d8,0xc7641411}},	//   _vrml_, _quét_, quét, _لارى, 
   {{0x7e0c1a22,0xfe7c004e,0x00000000,0x00000000}},	//   _सर्ग_, diïn_, --, --, 
   {{0xb7d42df0,0xdcec031c,0xbcf8003e,0x6280002f}},	//   _شوقا_, _msaġ, trék, ufmo, 
   {{0xbcf80122,0x69c00798,0xbdd80066,0x6284002e}},	//   bréh, _àmed, rbèk, _ñiom, 
   {{0xba380204,0xbf180562,0x69100139,0x5f94011c}},	//   _gaïf, नग्न_, käem, гиот, 
   {{0xbcf9b1d3,0x443c2142,0x691000af,0xadc40248}},	//   kuér, _ift_, väel, _ibẹw, 
   {{0xffa001c6,0xbcf80332,0x71a000c7,0xf770011a}},	//   глүү, mréi, уқәҵ, סקר_, 
   {{0x443c00dd,0xbcf9b1d4,0x409400c6,0x9f5c005b}},	//   _kft_, nség, _للشر, _syvä_, 
   {{0x3154008f,0xfe7c004e,0x443c0fac,0x7bc40158}},	//   _יידן_, ciïn_, _jft_, tyju, 
   {{0xf0900375,0xf99c007f,0x03dc0055,0x443c072d}},	//   _כנס_, _vyèm_, _pāṇd, _mft_, 
   {{0xbcf9b1d5,0x443c010a,0x6459b1d6,0x6d400306}},	//   guér, _lft_, havi, ímac, 
   {{0x6459b1d7,0xdcec031c,0x443c48ed,0xbcf9b1d8}},	// [2f2d0] kavi, _esaġ, _oft_, hréi, 
   {{0x64588b8c,0x78253c46,0xbcf80221,0xf1b0010f}},	//   javi, نعال, kréi, ױסע_, 
   {{0xbcf80124,0xe895b1d9,0x069400ec,0xb8d805c0}},	//   buér, рахь, ڏانھ, _आच_, 
   {{0xbcf9b1da,0x443db1db,0xadc40248,0xf8bc0789}},	//   dréi, _aft_, _abẹw, _pués_, 
   {{0xbcf9b1dc,0x443ceada,0x6459b1dd,0x1cc00327}},	//   gség, _bft_, favi, _གྭོ_, 
   {{0x6459b1de,0xf77005d3,0xe7180075,0x443c003a}},	//   gavi, _پاس_, ىيەت_, _cft_, 
   {{0xbcf9b1df,0x443c77ad,0xbdd8020c,0xfe7c004e}},	//   gréi, _dft_, sbèh, viïn_, 
   {{0x443db1e0,0x06c804c5,0x64580140,0xf8bc004a}},	//   _eft_, লোবি, aavi, _tués_, 
   {{0x6595b1e1,0xbcf8004a,0xf99c02e2,0xbdd80129}},	//   _кату, préh, _syèj_, ncèd, 
   {{0x2ecc085c,0x6459b1e2,0xbcf9b1e3,0xf99c033b}},	//   ास्त, cavi, bréi, _pyèj_, 
   {{0xd2500491,0xcee80b2b,0xba39b1e4,0x4f25b1e5}},	//   _هنا_, едне_, _kaïd, лдоб, 
   {{0xc3300d65,0xf99c02e2,0x63bc00a3,0xd174004e}},	//   _הוא_, _vyèj_, _àrna, _быкы, 
   {{0x7af8151c,0xdb0401c7,0xd2580165,0xdb2001e1}},	//   čutl, _erhë, maņ_, _àtùk, 
   {{0xefcc069c,0x4f940022,0x26180bae,0x00000000}},	//   እሰይ_, _бриу, बेटी_, --, 
   {{0xbcf800dd,0x3b5400b7,0x00000000,0x00000000}},	//   zség, _ገብርኤ, --, --, 
   {{0x6459b1e6,0xa3d4230e,0xbcf801ed,0x8b240c54}},	//   zavi, हनत_, ység, удбе, 
   {{0x6459b1e7,0x317c01c0,0x88848685,0xbeb801c7}},	// [2f2e0] yavi, ntuz_, ллаж, smëc, 
   {{0x317c01c0,0x6d45b1e8,0x6459b1e9,0x7b11119a}},	//   ituz_, _itia, xavi, lçul, 
   {{0x443db1ea,0x4650001f,0x799001b9,0x00000000}},	//   _rft_, _ኘሮግራ, _қиёф, --, 
   {{0xbcf9b1eb,0x6459b1ec,0x8ec4015b,0x317c01c4}},	//   tség, wavi, শোরগ, ktuz_, 
   {{0xe454ea10,0xbdd8004a,0xf7440131,0x66fc0010}},	//   аклы, ccèd, نلەي_, jčke, 
   {{0xbcf9b1ed,0x00000000,0x00000000,0x00000000}},	//   tréi, --, --, --, 
   {{0xbcf9b1ee,0xa3e422e3,0x929c068f,0x26181524}},	//   sség, _पेश_, woła, बेजी_, 
   {{0x443c4fa5,0xbcf9b1ef,0x6d4434a2,0xfbd005d0}},	//   _wft_, rréi, _otia, מתו_, 
   {{0x04440598,0x6459b1f0,0x6d45b1f1,0xd5080075}},	//   _безн, pavi, _ntia, رغۇن_, 
   {{0xb9d80020,0xb6000232,0x6459b1f2,0x443db1f3}},	//   _አይ_, ýšen, qavi, _uft_, 
   {{0x6d45b1f4,0xbcf85725,0x317c009d,0xdeb42401}},	//   _atia, nsée, atuz_, абны, 
   {{0xbcf806af,0x7b1003b9,0x00000000,0x00000000}},	//   isée, gçul, --, --, 
   {{0x6d440393,0xdcec0135,0x20980166,0x7de401ec}},	//   _ctia, _jsaħ, _аклы_, уінд, 
   {{0xdcec0135,0x6d4400ae,0xbcf8035b,0x238c0023}},	//   _msaħ, _dtia, guép, _መርድእ_, 
   {{0x6d45b1f5,0xda34023a,0xeb9821f3,0x2d8c054e}},	//   _etia, иевы, лиё_, ădea_, 
   {{0x6d440109,0x63a808a4,0x61e402d2,0x00000000}},	//   _ftia, _mrdn, _þils, --, 
   {{0x1959b1f6,0xba38057b,0xdd940209,0xdcec031c}},	// [2f2f0] тазы_, _naïe, _тапы, _nsaħ, 
   {{0xe6c004b9,0xa3d42366,0xba380129,0x7b1003e3}},	//   _čišć, हना_, _saïd, mçum, 
   {{0x9635b1f7,0x317c01c6,0x7d0551d2,0x7b1003b9}},	//   анец, ztuz_, mojs, lçum, 
   {{0xbcf85725,0xdcec031c,0xba38004a,0x7d040240}},	//   sséd, _bsaħ, _qaïd, lojs, 
   {{0xe78407d6,0x6d4406d9,0x63a9b1f8,0x4a580375}},	//   _қуро, _xtia, _ardn, _בדרו, 
   {{0x58d40323,0x9345b1f9,0x3f800069,0x7d04fb44}},	//   _тогт, анке, ̄kua_, nojs, 
   {{0xdb04e622,0xf99c020c,0xe818010b,0xbdd80561}},	//   _arhé, _syèh_, _борч_, mbèu, 
   {{0x94540069,0xba3806af,0xd2a8034b,0xbcf8114f}},	//   _kōk, _faïe, ткие_, nséb, 
   {{0x50b5b1fa,0xa6c40150,0x317c005a,0x63a84431}},	//   асну, _اققى, utuz_, _erdn, 
   {{0xe18816cb,0x36d1b1fb,0x317db1fc,0x008066c1}},	//   ائين_, _тоғр, rtuz_, ольо, 
   {{0x6d45b1fd,0x63a805a1,0x7af8151c,0x317c009d}},	//   _stia, _grdn, čutj, stuz_, 
   {{0x61f000d2,0x317c0099,0xd1b9606c,0x00000000}},	//   éhlú, ptuz_, _لاتا_, --, 
   {{0x6305b1fe,0x3ea0807e,0x7b117a56,0x60e00153}},	//   _اونل, цияг, rçul, _žymū, 
   {{0xc5f00302,0x63a80109,0x0b44036b,0xbcf806af}},	//   קדם_, _yrdn, ингн, ysée, 
   {{0xfbc01173,0xca540640,0xbcf800c7,0x7b106887}},	//   обро, итањ, yrév, pçul, 
   {{0x6d440076,0x00000000,0x00000000,0x00000000}},	//   _ttia, --, --, --, 
   {{0x88e5b1ff,0x7d042ce2,0x6f2400dd,0x6d45b200}},	// [2f300] ажае, bojs, _پڑھن, _utia, 
   {{0x929c012d,0x9d441e5a,0x00000000,0x00000000}},	//   koło, _ائين, --, --, 
   {{0xdcec0135,0x320c010e,0xbcf80129,0x8b940798}},	//   _ssaħ, _lygy_, usée, _трпч, 
   {{0x4ac82ecf,0xbcf8004a,0x96b83ec7,0xba3806af}},	//   _रविव, rsée, лучу_, _païe, 
   {{0xbcf9b201,0x00000000,0x00000000,0x00000000}},	//   ssée, --, --, --, 
   {{0x07a400c0,0x00000000,0x00000000,0x00000000}},	//   _кагн, --, --, --, 
   {{0xbcf8004a,0x7f440092,0x69100254,0x00000000}},	//   prév, _የሰዎች, väeh, --, 
   {{0xba3803a2,0xdcec01e4,0x63a8009b,0xb460013d}},	//   _taïe, _isaĥ, _vrdn, бкәл, 
   {{0x63a9b202,0x855404d3,0xbcf8004a,0x00000000}},	//   _wrdn, _ئیتر_, nséc, --, 
   {{0x26c5b203,0xf4841272,0x63a8151c,0xbcf81604}},	//   _homo_, _نامی, _trdn, nrét, 
   {{0x26c5b204,0x7d0402d3,0x81dc03d4,0xf8340375}},	//   _komo_, vojs, _দুখ_, ינית_, 
   {{0x7af809a8,0x74100345,0x6910023a,0xdd9402dd}},	//   čutk, _بوما, säeh, бамы, 
   {{0x26c5b205,0xba385a72,0x320c4c15,0xbd6800a7}},	//   _momo_, _laïc, _gygy_, ърне_, 
   {{0x26c5b206,0xf99c007f,0xbcf80036,0xec6834cb}},	//   _lomo_, _kyèv_, dséc, ирск_, 
   {{0xd0f406ab,0x7d040e3c,0x26c40428,0x20180037}},	//   ीकरण_, rojs, _oomo_, ürid_, 
   {{0xfc2c00c6,0x26c5b207,0x5a3464e1,0x5b140aac}},	//   _ऋँخ_, _nomo_, снат, ёмат, 
   {{0x7c840364,0xbcf9b208,0x7b1102a5,0x929c0210}},	// [2f310] _куне, frét, lçuk, zoło, 
   {{0x02d00073,0x5c7401a9,0x00000000,0x00000000}},	//   तसुन, _улот, --, --, 
   {{0x26c5b209,0xb8fc00dc,0x7b1006be,0x00000000}},	//   _bomo_, _तत_, nçuk, --, 
   {{0x3f8c0223,0xbcf80077,0xaa940166,0x95d80137}},	//   _mpfu_, rréu, _диюч, лдет_, 
   {{0xd468c44a,0xf7701acf,0xbcf8003e,0x00000000}},	//   гиле_, _ژار_, brét, --, 
   {{0xf484c97b,0xbcf820ef,0x48c0010b,0x798c035a}},	//   рудн, crét, _нәха, _ipcw, 
   {{0x26c5b20a,0x3c840ed1,0x61e400d7,0xe358004e}},	//   _fomo_, ﻪﺗﺘﻰ_, _žilp, ашыш_, 
   {{0xe3b0177a,0x26c5b20b,0x2bf80375,0x399c04ce}},	//   بره_, _gomo_, ימון_, のss_, 
   {{0x06c8009e,0xbeb801c7,0x818401b9,0xdb1400e5}},	//   লোহি, tmën, مچوق_, lyzó, 
   {{0x26c5b20c,0xf99c0100,0x70e4023b,0x929c0210}},	//   _zomo_, _fyèv_, ргоҳ_, poło, 
   {{0x26c402ea,0xedd00f44,0xe44800cf,0xbeb9b20d}},	//   _yomo_, हन्छ, _ئلمى_, rmën, 
   {{0xbeb80036,0x320c00a2,0x521400db,0xbcf98c4b}},	//   smën, _tygy_, _лдет, krés, 
   {{0xf1a403e6,0x66fc0010,0x00000000,0x00000000}},	//   _ڕاژه_, nčka, --, --, 
   {{0xbcf9b20e,0xdcec01e4,0xbeb8002e,0xe0d800d4}},	//   drés, _oraĵ, lmël, _кві_, 
   {{0x2ee401d9,0xfce1b20f,0x717001f7,0x00000000}},	//   _وقتہ, чоро, _اهڙا, --, 
   {{0x7f3804ac,0x9b440014,0x00000000,0x00000000}},	//   _געקו, تنٲو, --, --, 
   {{0x0888a6e6,0x26c5b210,0x3d880543,0x798c02d0}},	// [2f320] лбай_, _romo_, _یحیی_, _cpcw, 
   {{0x26c5b211,0xbcf9b212,0xbeb801c7,0x00000000}},	//   _somo_, rséc, hmël, --, 
   {{0x26c5b213,0xbcf9b214,0x66fc0030,0x6d58002b}},	//   _pomo_, rrét, ečka, _āvay, 
   {{0xdcec01e4,0xbcf80008,0xd7180212,0xe6480209}},	//   _draĵ, srét, аючі_, рҗай_, 
   {{0x19b80276,0xbcf800d8,0x6aa401e4,0xe7e801ad}},	//   _курь_, crés, mdif, _टेरा_, 
   {{0xd1e80125,0x49040131,0x6aa5b215,0x26c40112}},	//   ህነት_, _چوڭق, ldif, _womo_, 
   {{0x26c5b216,0xbcf9232d,0x6aa40175,0x46a4014b}},	//   _tomo_, nséa, odif, _лавв, 
   {{0x26c406bb,0x6aa5b217,0xbcf8007b,0x673800e5}},	//   _uomo_, ndif, iséa, ívju, 
   {{0xc0582355,0xc5c4015b,0x6aa40254,0x6d401a53}},	//   лін_, _শেরপ, idif, ímal, 
   {{0x7af8151c,0xaf40001f,0x11f40145,0x00000000}},	//   čuti, _የተመለ, تتىگ, --, 
   {{0xd04000ac,0x6d400115,0x82680150,0x00000000}},	//   nklə, ŭmal, _баев_, --, 
   {{0xf044001f,0xbcf801d3,0x3814011a,0x06c800eb}},	//   መስለኝ, yrés, מקים_, লোরি, 
   {{0x6aa5b218,0x41b4004b,0x20180254,0x00000000}},	//   ddif, _دمشر, ürib_, --, 
   {{0xf99c0100,0x6aa40381,0x798c02d0,0xdfd401ec}},	//   _myèt_, edif, _rpcw, _молы, 
   {{0x3f8c0810,0x3438010f,0x80241291,0x00000000}},	//   _upfu_, רײלע, _ارشم, --, 
   {{0x201c1cbd,0xbcf800dd,0x5b140845,0x00000000}},	//   _izvi_, trés, імат, --, 
   {{0x6284002e,0xe1740092,0x00000000,0x00000000}},	// [2f330] _ñiou, _በነበሩ_, --, --, 
   {{0x66fc0010,0x6aa4000d,0x9b5800d8,0xadbc030d}},	//   včka, adif, _киот_, _саьi, 
   {{0xbcf801d3,0x6aa40067,0xda340150,0x37a800c7}},	//   srés, bdif, _мены, ытан_, 
   {{0xbcf80231,0xc32401d9,0x00000000,0x00000000}},	//   prés, _زٕ_, --, --, 
   {{0x3569b219,0xbd24031c,0x79a40120,0xf568005b}},	//   урен_, _རྫོཊ_, _урне, ушек_, 
   {{0xf99db21a,0x201c0306,0x66fc25b4,0x94741888}},	//   _dyèt_, _ozvi_, rčka, تگرا, 
   {{0xf4840046,0xe3b806be,0xd04006be,0x00000000}},	//   _қуан, _azıb_, cklə, --, 
   {{0x1cb8031c,0x66fc0010,0x00000000,0x00000000}},	//   _ཚོའ_, pčka, --, --, 
   {{0xd094005b,0x77740036,0x00000000,0x00000000}},	//   ошны, luxx, --, --, 
   {{0x76580c6a,0x6d40dd18,0x00000000,0x00000000}},	//   _heuy, ímam, --, --, 
   {{0x6910033d,0x6aa41529,0x765800d5,0x753801f7}},	//   päev, ydif, _keuy, _huuz, 
   {{0x75385ff2,0xf99c01e1,0x4e280395,0x6ee806be}},	//   _kuuz, _osè_, ионн_, lıbz, 
   {{0x75381559,0x00000000,0x00000000,0x00000000}},	//   _juuz, --, --, --, 
   {{0x7539b21b,0x7658003e,0x6aa5b21c,0x8fd000d1}},	//   _muuz, _leuy, wdif, _жәмә, 
   {{0xf99daa3c,0x6aa401e4,0xbb40a99d,0xca580a5b}},	//   _asè_, tdif, деск, ијач_, 
   {{0x0a49b21d,0xf99c007f,0x76581368,0xbdd9b21e}},	//   рзай_, _nyès_, _neuy, rbèr, 
   {{0x7538063f,0x08c421c3,0x8ed81d10,0x795c0248}},	// [2f340] _nuuz, обан, _مذکر_, _ràwá, 
   {{0x1cb81efe,0x691000c5,0x6aa41f06,0x795c01e1}},	//   _ཚོར_, jäet, sdif, _sàwá, 
   {{0x76584312,0xf99cf21a,0xbdd952df,0x46a5b21f}},	//   _beuy, _esè_, ncèn, жаев, 
   {{0x75381418,0x76580c6a,0xd04000ac,0xbeb80023}},	//   _buuz, _ceuy, rklə, ymëm, 
   {{0xd0400213,0x2a600332,0x99742360,0x00000000}},	//   sklə, maib_, _нурш, --, 
   {{0xba38067c,0x7774031c,0x69d801e4,0x2a600332}},	//   _jaïn, buxx, ŝves, laib_, 
   {{0xf485b220,0x1cb8025c,0xfd1c0ffb,0x6d4002fb}},	//   تانی, _ཚོལ_, ntìa_, ímaj, 
   {{0x08400014,0xd140033f,0x66fc0010,0x2a600332}},	//   _رۆچُ, knąć_, mčko, naib_, 
   {{0x673c02f6,0x2044001f,0xcd24001f,0x66fc0219}},	//   _hurj, _የአማር, ተከናወ, lčko, 
   {{0x2a600070,0x673db221,0x69108cfa,0x79b40375}},	//   haib_, _kurj, mäes, קליד_, 
   {{0x66fc09a8,0x673db222,0x44280241,0x00000000}},	//   nčko, _jurj, _àb_, --, 
   {{0x733043e8,0xb35401ed,0x7ee40212,0xdd95a965}},	//   _قىلا, _بیٹا_, іцне, памы, 
   {{0x673cc7bf,0x4084010b,0xc0dc0023,0x2a6001e7}},	//   _lurj, _дуйб, ዕበለ_, daib_, 
   {{0xb110bd96,0x673c02d0,0x201803b2,0x00000000}},	//   _قونغ, _ourj, ýris_, --, 
   {{0x66fc1154,0x673c0c48,0xaf341b12,0x7ac4005b}},	//   jčko, _nurj, ثریت, осае, 
   {{0x9884012c,0x644c00ac,0xcfa800f1,0xaf080736}},	//   _vůči_, əniş, _داهم_, _وقوم_, 
   {{0x673c0055,0x765800ad,0x58d4084c,0x66fc00d0}},	// [2f350] _aurj, _reuy, поат, ečko, 
   {{0x37a9ad0e,0x75380ba7,0x76584e6c,0xc5c004c5}},	//   итен_, _ruuz, _seuy, ্ছাপ, 
   {{0x2a603223,0xf99c0699,0x7539b223,0x76580c6a}},	//   baib_, _pyès_, _suuz, _peuy, 
   {{0x41c8690c,0x673db224,0x7538009f,0xa3c04709}},	//   िहास, _durj, _puuz, ुहन_, 
   {{0xac746e0d,0x69d800df,0x7774031c,0x00000000}},	//   _عایش, ŝver, suxx, --, 
   {{0x1cb81f21,0x39480048,0xf99c0100,0x673c0135}},	//   _ཚོས_, _itcs_, _fyèr_, _furj, 
   {{0x673d310f,0xd7c81077,0x39480fac,0xf99c0100}},	//   _gurj, _اوزه_, _htcs_, _tyès_, 
   {{0xc7b00d65,0x753801f2,0xd2980953,0x69100108}},	//   _אבל_, _tuuz, сткі_, säet, 
   {{0xf48401ce,0x691001c7,0xbcf800e4,0x8618014b}},	//   _мужн, mäer, yrép, _гетӣ_, 
   {{0x69100036,0x850000d1,0x00000000,0x00000000}},	//   läer, _كۈنن, --, --, 
   {{0x9f580008,0xd00807d5,0xbcf800d2,0xe508004b}},	//   ærð_, сене_, tsén, _بيلو_, 
   {{0xfafc07db,0xa3e419e5,0x2a600218,0xc7d40375}},	//   _një_, _पेट_, xaib_, פורי_, 
   {{0xc0d40020,0xbdd87c10,0xf1a4d798,0x2d845f15}},	//   ርሱም_, scèn, _френ, îme_, 
   {{0x69100221,0xba380129,0xbcf80561,0x6b9c0142}},	//   häer, _baïo, ssén, twrg, 
   {{0xd140033f,0x69100036,0x8cbc05dc,0x8fd00166}},	//   snąć_, käer, शाबो, _чәпә, 
   {{0x394804e6,0x673c047e,0xee6c0ae5,0x66fc0219}},	//   _btcs_, _rurj, ﻳﻤﻪﻥ_, včko, 
   {{0xfd1c026c,0x00000000,0x00000000,0x00000000}},	// [2f360] stìa_, --, --, --, 
   {{0x673c05a7,0xbcf99519,0x69101577,0x2a600332}},	//   _purj, nsél, väes, saib_, 
   {{0x69100036,0xca7c022e,0xba74015e,0x00000000}},	//   fäer, _supе, _کاپت, --, 
   {{0xfafc044e,0x66fc0dfe,0x63bc00db,0x6910023a}},	//   _gjë_, rčko, _àrni, täes, 
   {{0xa3e416da,0x673c03f9,0x53980023,0x2bd0000d}},	//   _पेज_, _wurj, _መርየት_, _सॅता, 
   {{0x673db225,0x6fc802ab,0x66fc0010,0x589400db}},	//   _turj, ाहां, pčko, _ошсу, 
   {{0x673c058a,0x73c000e3,0x69101572,0x00000000}},	//   _uurj, فيوم, säes, --, 
   {{0x69100a40,0x48f4012c,0xb37000d1,0x00000000}},	//   päes, ्वको_, ردىش, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x03a4adf4,0xa6c801af,0x00000000,0x00000000}},	//   _низо, _улға_, --, --, 
   {{0xf1f424c5,0xa3e42208,0x9f5805d1,0xf8b00375}},	//   قعیت_, _पेच_, _özür_, גשת_, 
   {{0x032409a5,0x33380375,0x7b104b84,0xbcf800e4}},	//   _эден, _התאמ, nçut, quéz, 
   {{0x71400228,0x00000000,0x00000000,0x00000000}},	//   _كۉيۅ, --, --, --, 
   {{0x3f640131,0xc0d40092,0x00000000,0x00000000}},	//   _етиб, ርቱም_, --, --, 
   {{0xfbd00a11,0xa2c00c00,0xbff000d1,0xbcf80129}},	//   رتس_, वाप्, _чүнш, sséo, 
   {{0x6ff80375,0xefc401f0,0x00000000,0x00000000}},	//   _להופ, _хушк_, --, --, 
   {{0x6448002d,0xaf340214,0x6910000d,0xeab000e5}},	// [2f370] _ofdi, _ثروت, väer, ھٹے_, 
   {{0x691004c4,0xa3bc00bc,0x00000000,0x00000000}},	//   wäer, आमा_, --, --, 
   {{0xbcf806af,0x69100221,0x41680150,0x00000000}},	//   nsém, täer, _ﺳﻪﮔﯩ, --, 
   {{0xfafc044e,0x64490e56,0xfe7c025a,0xba38007f}},	//   _ujë_, _afdi, ngï_, _kaïm, 
   {{0xa2c033ff,0x79a40354,0xd4a4010b,0x20dc043e}},	//   वान्, _эрне, дилй, यसाध, 
   {{0xa8a40e92,0xe61000f2,0x69100108,0x00000000}},	//   _прск, دشم_, säer, --, 
   {{0x6910324c,0x43901d39,0x00000000,0x00000000}},	//   päer, вајс, --, --, 
   {{0x78a5b226,0x98b00100,0x7b100213,0x00000000}},	//   _hajv, _mizč_, mçus, --, 
   {{0xc6900bd9,0x201804cc,0x7b100213,0x00000000}},	//   _באן_, ürin_, lçus, --, 
   {{0x78a4047e,0xbdd8004a,0x00000000,0x00000000}},	//   _jajv, rcèl, --, --, 
   {{0x78a40455,0x7b1003e3,0x00000000,0x00000000}},	//   _majv, nçus, --, --, 
   {{0x78a4007c,0x00000000,0x00000000,0x00000000}},	//   _lajv, --, --, --, 
   {{0xba380129,0x69100254,0x00000000,0x00000000}},	//   _caïm, käep, --, --, 
   {{0x78a48b8c,0x7b1006be,0x00000000,0x00000000}},	//   _najv, kçus, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x98b00100,0xe3b800fd,0x00000000,0x00000000}},	//   _dizč_, _ozın_, --, --, 
   {{0x88c82e36,0xde8801f7,0x00000000,0x00000000}},	// [2f380] олав_, _رضيه_, --, --, 
   {{0x87d80150,0xf99c0100,0x78a40356,0xdb0401ef}},	//   يباس_, _vyèp_, _cajv, _vrhá, 
   {{0x28c403f3,0x78a4016d,0xe3b803e3,0xa2c000cd}},	//   लॉगि, _dajv, _azın_, वाम्, 
   {{0xdb040306,0x00000000,0x00000000,0x00000000}},	//   _trhá, --, --, --, 
   {{0x28f40150,0x7d78010f,0xe6040139,0x00000000}},	//   _كۋرس, ַנקו, хҗан, --, 
   {{0xa2c000dc,0x61e4010e,0xbcf800e4,0x15b0215c}},	//   वाभ्, _ýili, ysém, دەكس, 
   {{0x870401b9,0x47d40b24,0x37840107,0xed640064}},	//   _قبرل, _غيرر, _обро_, ležį_, 
   {{0x41680640,0x81680212,0x051c00eb,0x7b100139}},	//   ојом_, ороб_, দদের_, lçur, 
   {{0x602400e4,0x05b8007b,0x320401c0,0xc4840063}},	//   _oïmí, _بدأت_, дхэн_, _олак, 
   {{0x7b11b227,0xba3800db,0xbcf8002e,0x00000000}},	//   nçur, _raïm, tsém, --, 
   {{0xf48404d3,0xfd60063f,0xdef40b7e,0x30a00153}},	//   _تاقی, batị, епны, трыв, 
   {{0x25a5b228,0xfe7c00cf,0xbeb8036e,0xd36c00ec}},	//   _ksml_, viïs_, hmëv, _اڇو_, 
   {{0xbcf8004a,0xc0c89a51,0x2d940108,0x52740354}},	//   ssém, _муке_, крёс, _чуху, 
   {{0xccb00022,0x00000000,0x00000000,0x00000000}},	//   гәџь, --, --, --, 
   {{0x6d3400e6,0x78a40b4b,0x69100037,0x00000000}},	//   терф, _rajv, väep, --, 
   {{0x6280016d,0xba75b229,0xbdd80066,0x41d006ff}},	//   ngmo, باست, ncèk, _तथास, 
   {{0x63bc022c,0xbcf80098,0xba380129,0xf990007b}},	// [2f390] _árnf, nsék, _haïk, خبز_, 
   {{0xa3c009ae,0xba380055,0xa2c00073,0x7c641a4b}},	//   ुहा_, _kaïk, वाड्, _کاکل, 
   {{0x25a401f5,0x6d41b22a,0xd9cc0154,0xcfc01870}},	//   _asml_, ímav, _রেশম, ﺭﻣﺎﻗ, 
   {{0xba380109,0x57242928,0x00000000,0x00000000}},	//   _maïk, رىشك, --, --, 
   {{0x78a5b22b,0x4a740023,0xba3800b8,0xf77000ec}},	//   _tajv, _ኢምባሲ_, _laïk, _ڄار_, 
   {{0xf771b22c,0x628001f5,0x00000000,0x00000000}},	//   _لار_, egmo, --, --, 
   {{0xe7840276,0x20180254,0x2f040139,0x00000000}},	//   _иуто, üril_, hıga_, --, 
   {{0x628001e6,0xbeb80036,0x51540276,0x2f040166}},	//   ggmo, llëf, нтоу, kıga_, 
   {{0xa5f802dd,0x00000000,0x00000000,0x00000000}},	//   _жету_, --, --, --, 
   {{0x4fe8013e,0x628001f5,0x6f600131,0x10a401c6}},	//   змон_, agmo, نۇتم, хион, 
   {{0x52752cd0,0x929c0034,0x5ea80011,0x00000000}},	//   _зулу, wołu, গানে, --, 
   {{0xbcf8003e,0xbeb801c7,0xa2c00b02,0xc7b000df}},	//   bsék, hlëf, वाण्, אבט_, 
   {{0xd0d41064,0x2f040166,0xe2c805af,0x00000000}},	//   _подъ, gıga_, _تونو_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfaa002d5,0x7aa00116,0x929c012d,0xcc88104c}},	//   ласо, лисз, połu, _کنده_, 
   {{0xc3304645,0x8c441685,0x9e6410fe,0xa2c00882}},	// [2f3a0] רון_, _пепе, _شاين, वात्, 
   {{0x6e240928,0x1cb8025c,0x7d54008f,0x00000000}},	//   _izib, _ཚོག_, _רייד_, --, 
   {{0x66fc0010,0xbeb8036e,0x00000000,0x00000000}},	//   lčki, rmëv, --, --, 
   {{0x28c402ab,0xc604010b,0x00000000,0x00000000}},	//   लॉजि, нзей, --, --, 
   {{0x68340b4b,0x66fc0219,0x00000000,0x00000000}},	//   dždž, nčki, --, --, 
   {{0xdb04481f,0x6e24009f,0x2ee003cb,0x00000000}},	//   _erhä, _mzib, _llif_, --, 
   {{0xd90db22d,0x2ee001a6,0x6f0402d0,0x69c4031c}},	//   _بیل_, _olif_, _ojic, lxie, 
   {{0x6e25b22e,0xa2c000dc,0xd1d40092,0x68340064}},	//   _ozib, वाध्, _ይግቡ_, gždž, 
   {{0x6e246466,0xbeb80036,0x40840aac,0x66fc0427}},	//   _nzib, llëg, нунб, jčki, 
   {{0xbcf801ed,0x6f04009f,0x69c4004e,0x94a8007b}},	//   rsék, _ajic, ixie, _يطلق_, 
   {{0xf485617d,0x443db22f,0xa2c0543b,0x20180008}},	//   _سالی, _igt_, वाद्, æri_, 
   {{0x1cb80c99,0x6e240083,0x6ce40220,0xbdd8067c}},	//   _ཚོང_, _bzib, ңіре, mbèz, 
   {{0x443cf526,0x3248004b,0x717004fb,0xed580006}},	//   _kgt_, _رسنۍ_, _مهنا, ноў_, 
   {{0x6e246009,0x3594001f,0x6f040381,0x2ee1b230}},	//   _dzib, _መግባት_, _ejic, _elif_, 
   {{0x6e24a21d,0xbcf9a6c2,0x8c38016c,0x6458004c}},	//   _ezib, nséi, дорӣ_, ibvi, 
   {{0x3da41feb,0x2ee1b231,0x4514009e,0xbeb804e6}},	//   _зроб, _glif_, াষিক_, gmët, 
   {{0x5a35b232,0x6e240010,0x00000000,0x00000000}},	// [2f3b0] тнат, _gzib, --, --, 
   {{0xf805b233,0x394c0029,0x443db234,0x00000000}},	//   нчен, īgs_, _ngt_, --, 
   {{0x6e240083,0xa8840131,0xf804205a,0x6d4000df}},	//   _zzib, المى, хчан, ŭmat, 
   {{0x443db235,0xf650117d,0xbcf801c7,0x00000000}},	//   _agt_, ائض_, dséi, --, 
   {{0x443c0490,0xbcf80129,0x49a401af,0x00000000}},	//   _bgt_, dréz, _иырғ, --, 
   {{0x443db236,0xdb040200,0xbeb80200,0x00000000}},	//   _cgt_, _oshë, llëd, --, 
   {{0x443c04d4,0xdb0401e6,0xbcf802f0,0x00000000}},	//   _dgt_, _erhå, fréz, --, 
   {{0x443c01a4,0xc8800205,0x00000000,0x00000000}},	//   _egt_, ışş_, --, --, 
   {{0x443c0005,0x26dc005f,0x23600e3c,0xf2c42de5}},	//   _fgt_, īvot_, ćija_, _үсен, 
   {{0xe5c40323,0xd534036b,0x290400ae,0x92940124}},	//   _ёсто, _شفاخ, _ímat_, хаҩц, 
   {{0x6f040051,0x00000000,0x00000000,0x00000000}},	//   _pjic, --, --, --, 
   {{0x386000b5,0xca340220,0x00000000,0x00000000}},	//   _lejr_, _ﻗﻮﺱ_, --, --, 
   {{0x69c4003d,0x00000000,0x00000000,0x00000000}},	//   xxie, --, --, --, 
   {{0x8d7401d5,0x66fc0010,0x623400f3,0x00000000}},	//   _یاخا, rčki, _сечу, --, 
   {{0x4fc00131,0x00f4011a,0xdddc0210,0xbc6001f4}},	//   _ئەجە, _במסך_, gasł, рвск, 
   {{0x69c405f5,0x6f04008b,0x6d403e33,0x63bc08a5}},	//   txie, _ujic, ímas, _árne, 
   {{0x6e240912,0xbeb8d267,0x88855092,0x06d801ec}},	// [2f3c0] _uzib, rmët, клаж, _ﺃﺠﻨﺩ, 
   {{0xbeb9b237,0x7d781203,0x69c4025c,0x0b440454}},	//   smët, _קניו, rxie, _инон, 
   {{0x6d4402b5,0x58940372,0x38600327,0x3c7404ae}},	//   _huia, ышту, _dejr_, _בתים_, 
   {{0x6d4400ec,0xd6d978d3,0xba38017a,0x317c01f7}},	//   _kuia, нті_, _naïw, kuuz_, 
   {{0xa2c0060c,0x443db238,0x05b80133,0x85b800cf}},	//   वास्, _pgt_, بدات_, بااس_, 
   {{0xd90c066d,0x6d440dd4,0x00000000,0x00000000}},	//   _ٹیم_, _muia, --, --, 
   {{0xf361989b,0x443c001e,0x6d453f5b,0xbcf80036}},	//   атын, _vgt_, _luia, uséi, 
   {{0xbcf804c4,0xbeb802d3,0xe23002d3,0x6d44030a}},	//   rséi, hmër, _ብስርዓ, _ouia, 
   {{0xbcf804c4,0x7ae00276,0x6d45945e,0x35a002ac}},	//   sséi, _înte, _nuia, _катг, 
   {{0x443db239,0xbeb80240,0xa2c0d024,0xaf5c0092}},	//   _ugt_, jmër, वाह्, _ለተመለ, 
   {{0x6d45af8e,0x237801ed,0x03a401d5,0x7664010e}},	//   _auia, _írj_, _шижо, _öryä, 
   {{0x6d440268,0xddcc054e,0xbeb80200,0xeae40154}},	//   _buia, _ceaş, emër, নচুম, 
   {{0x2919b23a,0x6d45b23b,0xdc300306,0xc0dc069d}},	//   _okra_, _cuia, _výči, ንበረ_, 
   {{0x29180134,0x09d4015b,0x98b00356,0xbeb80036}},	//   _nkra_, _সেভা, _miză_, tmës, 
   {{0xac19b23c,0xdc3000d7,0x9b440066,0x00000000}},	//   вору_, _týči, انرو, --, 
   {{0xd1d40020,0x2919b23d,0x386004ce,0x6d441140}},	//   _ይልቅ_, _akra_, _sejr_, _fuia, 
   {{0x09d4015b,0xaa640334,0xbeb80036,0xe94421b5}},	// [2f3d0] _সেবা, ртск, smës, аххо, 
   {{0xf7708971,0xcf8c03e6,0xcda8010f,0xbcf800e4}},	//   لاص_, _بژی_, _טיפֿ, esév, 
   {{0x3860037e,0x1bd402bf,0xb8d8012c,0xba3806af}},	//   _vejr_, _соня, _अफ_, _naïv, 
   {{0x201c0092,0x1cb80135,0x291801ab,0xe75802bf}},	//   _myvi_, _ཚོཌ_, _ekra_, тиці_, 
   {{0x3568084c,0xf4806824,0x63a803ac,0x65600142}},	//   френ_, لاغی, _asdn, _cwmh, 
   {{0xbcf9aa44,0x98b8054e,0xae0407f7,0xd3880108}},	//   rséw, _dusă_, रपतन_, ейке_, 
   {{0xdb040309,0xa8a4084c,0xe3b803e3,0x00000000}},	//   _ashé, _тряк, _ayıb_, --, 
   {{0xd185b23e,0x63a8abd5,0x66fc00b0,0x61e40327}},	//   глий, _dsdn, tōke, _żila, 
   {{0x63a802d0,0x69c006af,0xddcc0356,0x70140154}},	//   _esdn, _àmet, _reaş, ডোজ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d45b23f,0x5ecc015b,0xa2c0146b,0xba39b240}},	//   _suia, াসনে, वाश्, _taïw, 
   {{0x6d45b241,0x22580022,0x66fc02b1,0x5398001f}},	//   _puia, _аицы_, pōke, _መርዳት_, 
   {{0xa2c01bd6,0x6d440428,0xcdf40948,0x7ed40330}},	//   वार्, _quia, учны, ازپا, 
   {{0x6d4405c7,0xd008466e,0x00000000,0x00000000}},	//   _vuia, _пеле_, --, --, 
   {{0xbeb80240,0xf8f80183,0x201c0153,0x00000000}},	//   rmër, ্তাৱ_, _gyvi_, --, 
   {{0x6d44b452,0xbeb80023,0x00000000,0x00000000}},	//   _tuia, smër, --, --, 
   {{0x0928dcc6,0x00000000,0x00000000,0x00000000}},	// [2f3e0] ежай_, --, --, --, 
   {{0xbd580375,0x98b80311,0x00000000,0x00000000}},	//   _רכיש, _rusă_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x98b80311,0xbeb804e6,0x46e879ea,0x96b87d1e}},	//   _pusă_, mlëc, эден_, кучу_, 
   {{0x63a8003e,0xbcf8004a,0xbeb80036,0x2b580175}},	//   _ssdn, rsév, llëc, lprc_, 
   {{0x2919b242,0xe5341f42,0x98b00356,0x7eb80108}},	//   _ukra_, шель, _viză_, _käpä, 
   {{0xa2c0086b,0xbeb804e6,0x7eb801f4,0xb8240354}},	//   वाल्, nlëc, _jäpä, _борз_, 
   {{0x69c0a37d,0xae04547d,0x05743226,0xf7d4011a}},	//   _àmes, रपान_, _مائد, _גולש_, 
   {{0xbdd800f2,0x7eb8005b,0xbeb80036,0x3afc005b}},	//   ncèt, _läpä, hlëc, läpä_, 
   {{0xe5a5b243,0xd584168d,0xbeb80036,0x63a80139}},	//   _йиғи, _ئێوه_, klëc, _tsdn, 
   {{0xba388a7c,0x0ca00023,0x5f944eb0,0xc1a402dd}},	//   _haït, _ምምራጽ_, шинт, тыққ, 
   {{0xbeb801c7,0x3ec401d5,0xa2c00073,0x00000000}},	//   dlëc, усоб, वाळ्, --, 
   {{0x1cb80c99,0x00000000,0x00000000,0x00000000}},	//   _ཚོད_, --, --, --, 
   {{0xc0a8004b,0x3afc023a,0xba380129,0x6fa000cc}},	//   _ساتل_, käpä_, _maït, _ওপৰে, 
   {{0xe81452f2,0xbbdc3c71,0xbeb804e6,0x3ae4000d}},	//   _तुला_, ननेक, glëc, _lõpe_, 
   {{0x2b440166,0x00000000,0x00000000,0x00000000}},	//   сэрг, --, --, --, 
   {{0x1dc4008e,0xd140012d,0x00000000,0x00000000}},	// [2f3f0] _төнн, ciąć_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe89400c7,0x657c0055,0x3de400fe,0x00000000}},	//   сахь, _ārha, _পখিল, --, 
   {{0x5695b244,0x55580395,0x00000000,0x00000000}},	//   радт, вадя_, --, --, 
   {{0xe3b90356,0x67d400d1,0xe730007b,0x00000000}},	//   _arı_, _һору, أصل_, --, 
   {{0xbcf800e5,0x398c0205,0xe3b001e2,0x00000000}},	//   csét, müs_, ګره_, --, 
   {{0x1cb80003,0x69c00129,0x67d40408,0x398c0205}},	//   _ཚོན_, _àmer, _лору, lüs_, 
   {{0xe3b08b4d,0xbdd9b245,0x00000000,0x00000000}},	//   ثره_, ncès, --, --, 
   {{0x953840b6,0x42c5b246,0x398db247,0xbcf8003e}},	//   _азат_, ргын_, nüs_, nsés, 
   {{0x66fc02b5,0xba380129,0xa5340212,0x00000000}},	//   mōka, _haïs, _гнуч, --, 
   {{0xd009b248,0x00000000,0x00000000,0x00000000}},	//   тене_, --, --, --, 
   {{0x63bc1f60,0xbcf87dec,0x7eb801f4,0x398c0205}},	//   _árna, ksés, _räpä, küs_, 
   {{0xa1583334,0xba3801a4,0x0c8400fb,0xc33000df}},	//   _бачу_, _maïs, һыңм, _ווא_, 
   {{0x7eb80793,0x201005f7,0x398c03e0,0xbeb801c7}},	//   _päpä, álið_, düs_, tlëc, 
   {{0x8e740ab2,0x66fc02b5,0x61400023,0xc0dc0240}},	//   _купч, hōka, _ኣተዓባ, ንጠራ_, 
   {{0x80d82aab,0x66fc02b5,0x8a04b850,0xbeb804e6}},	//   যোদ্, kōka, азбе, rlëc, 
  
   {{0x443001fb,0xbeb80036,0xdb1c01d3,0x398c03e0}},	// [2f400] ̀y_, slëc, ízás, güs_, 
   {{0x3afc005b,0xab29b249,0x7eb80108,0x00000000}},	//   täpä_, тоға_, _täpä, --, 
   {{0x07a4b96a,0x5ea8015b,0xbcf800e5,0xbc78011a}},	//   раен, গারে, rsét, _בנית, 
   {{0x398c03ee,0xa3a805f9,0xbdd80036,0x81bc03d4}},	//   büs_, खौफ_, ccès, ীনত_, 
   {{0x7ce80639,0x60c402a8,0x7ae00311,0x6aa401f7}},	//   _dürf, _ɗimb, _înta, meif, 
   {{0x6aa5b24a,0x82580023,0x04f403d4,0x276800f1}},	//   leif, _ቀቢላታ, েত্ৰ_, _مشری_, 
   {{0xbdd9b24b,0x46a4014b,0xe2f800d4,0x00000000}},	//   ncèr, _кавв, лекі_, --, 
   {{0x6aa5b24c,0xa3101b37,0xbcf8f0bb,0x98b00064}},	//   neif, ावेज_, nsér, _vizą_, 
   {{0xc05820eb,0x74240092,0x00000000,0x00000000}},	//   кін_, _ትዕግሥ, --, --, 
   {{0xba380660,0x66e46148,0xf990011a,0x00000000}},	//   _kaïr, _тоға, קרת_, --, 
   {{0xba39b24d,0x3518011a,0x00000000,0x00000000}},	//   _jaïr, _יומנ, --, --, 
   {{0x7ce80598,0xdb200174,0x6e980064,0xf38c0023}},	//   _kürg, _átøk, авюр_, _ዘርኣዮ_, 
   {{0x5ea8045e,0x7ce9b24e,0x6aa407de,0x00000000}},	//   গালে, _jürg, deif, --, 
   {{0x7ce800c5,0x2d580276,0xd6d8012d,0xbcf800e4}},	//   _mürg, рирь_, _miła_, esér, 
   {{0x798c0175,0x35940092,0x6aa5b24f,0x00000000}},	//   _sqcw, _መፍታት_, feif, --, 
   {{0x1cb80003,0xbcf801ed,0x398c0205,0x00000000}},	//   _ཚོམ_, gsér, tüs_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [2f410] --, --, --, --, 
   {{0x7ce82045,0xdcec1a48,0x398c0274,0xbcf80022}},	//   _sürf, _kvač, rüs_, asér, 
   {{0xba39b250,0xf771b251,0x81d802f5,0xccf00a7c}},	//   _païs, تاذ_, _ডেম_, _זכי_, 
   {{0x7ce9b252,0x66fc02b5,0xbcf801d3,0x6aa40142}},	//   _bürg, tōka, csér, ceif, 
   {{0xb5a44965,0x74f40022,0x00000000,0x00000000}},	//   ррей, аҵар_, --, --, 
   {{0xf7719773,0x7ce83262,0x81bc00eb,0x00000000}},	//   _واز_, _würf, ীনা_, --, 
   {{0xbcf820ef,0x28f80276,0xb6000306,0x7ce8002f}},	//   nséq, _терь_, _skáč, _türf, 
   {{0xc68403e6,0x7ce81196,0x66fc02b5,0xd26803e6}},	//   _هێمن_, _hürd, pōka, اڵان_, 
   {{0x7ce9b253,0xba380129,0x53c401ec,0x00000000}},	//   _kürd, _zaïr, рақұ, --, 
   {{0x6aa5b254,0xc0d4001f,0x7ce8010e,0x00000000}},	//   zeif, _ይችል_, _jürd, --, 
   {{0x7d0401fa,0x948400ee,0x6aa4009f,0x8fa402e8}},	//   dnjs, _выҗд, yeif, щане, 
   {{0xba3806af,0xd1b9b255,0x4fc400c7,0xb6000419}},	//   _laïq, _ماتا_, асҭа, _tkáč, 
   {{0xf99c0241,0x00000000,0x00000000,0x00000000}},	//   _npè_, --, --, --, 
   {{0x6aa41a80,0x317c0165,0x6ae02c2e,0x00000000}},	//   weif, mruz_, नस्र, --, 
   {{0x6aa5b256,0xf99db257,0x4b25b258,0x60dd15d9}},	//   teif, _apè_, معرف, örme, 
   {{0x4a45b259,0x0e6407b5,0xbdd80ba1,0xbeb80240}},	//   снав, _укин, rcèr, llën, 
   {{0x6aa5b25a,0xc33006a9,0xbdd8026c,0x317c0165}},	// [2f420] reif, לול_, scèr, nruz_, 
   {{0xbcf8aee4,0xdb140030,0x7ce803b9,0xfde400db}},	//   ssér, ľbác, _cürd, _ыдык_, 
   {{0xe3b847af,0xf99c02e2,0xdb140122,0x7ce9b25b}},	//   _ayın_, _epè_, žbác, _sürg, 
   {{0x317c005a,0x7ce80037,0xbeb80036,0xd6d8033f}},	//   kruz_, _pürg, hlën, _piła_, 
   {{0x7ce800dd,0xbdd8180f,0x597400c7,0x0ba800d1}},	//   _fürd, ncèp, _мыру, _شاھى_, 
   {{0x0ee00cb4,0xba380165,0xbcf86085,0x1880010b}},	//   _पतझड, _taïr, nsép, _оңун, 
   {{0x7ce80112,0x107c00d1,0x580401af,0x00000000}},	//   _würg, _ﻣﯘﺯﯨ, _дорғ, --, 
   {{0x7ce9b25c,0x317c022e,0xdcecadbd,0x00000000}},	//   _türg, fruz_, _rvač, --, 
   {{0x26c40789,0xddcc2630,0x7ce84dd9,0x7b1006be}},	//   _inmo_, _odaš, _hüre, gçuy, 
   {{0x7ce9677c,0xf484158b,0x26c40051,0xe7dc00cd}},	//   _küre, _هامی, _hnmo_, _यथाप, 
   {{0x7a2c01e1,0x9f345074,0x00000000,0x00000000}},	//   _kòtí, жені, --, --, 
   {{0x7ce805d1,0xdcfc0171,0x00000000,0x00000000}},	//   _müre, dusā, --, --, 
   {{0x317db25d,0xbeb801c7,0x0c8c0023,0x00000000}},	//   cruz_, blën, _ዝቝጸሩ_, --, 
   {{0xa2c028e1,0xa2d40d0a,0xf54c063f,0x66fc02b5}},	//   वाक्, यॉर्, wụkw_, kōko, 
   {{0x2bc80276,0x7ce80022,0x09d400eb,0xaf34085b}},	//   буто_, _nüre, _সেলা, تریت, 
   {{0x7ce8a2d4,0xda0800f1,0x00000000,0x00000000}},	//   _sürd, ليزه_, --, --, 
   {{0xbcf80129,0xdb200241,0x00000000,0x00000000}},	// [2f430] sséq, _àtík, --, --, 
   {{0xfc44012c,0x7ce82123,0x2a600254,0x2bc400cd}},	//   číst_, _büre, abib_, _लॊका, 
   {{0x7ae0084c,0xb9580268,0x317c0007,0x2a600083}},	//   _înto, _orìg, zruz_, bbib_, 
   {{0x7ce9b25e,0x60c40198,0xa3bc00e1,0x00000000}},	//   _würd, _ɗima, इटन_, --, 
   {{0x7afc0023,0x7ce9b25f,0x317c022e,0xd46800d8}},	//   miqt, _türd, xruz_, аиле_, 
   {{0x7afc3209,0x23c43d4d,0x317ccddc,0xe6101e24}},	//   liqt, वमंद, vruz_, رشن_, 
   {{0x317c0209,0x7ce90f9e,0xad1c011a,0xe4a4009d}},	//   wruz_, _güre, אוגר, ярцо, 
   {{0x7afdb260,0x3941b261,0xa2c0d3c3,0x11e401a9}},	//   niqt, _hijs_, वाग्, жжим, 
   {{0x7ce81196,0xe3b8008e,0x80b000eb,0x00000000}},	//   _züre, _uyın_, জান্, --, 
   {{0x7ce9b262,0x394804cc,0x98b80006,0xb9580241}},	//   _yüre, _mucs_, _pusę_, _erìg, 
   {{0x7afc0357,0xb9580ffb,0x394804cc,0x630407d6}},	//   kiqt, _frìg, _lucs_, _کونل, 
   {{0x7ce8d1df,0x3b180194,0x9180104b,0xd6d8033f}},	//   _nürb, joqq_, _قۇبۇ, _miło_, 
   {{0x2f04002d,0x683001e1,0x2a600158,0xbeb804e6}},	//   jűge_, _kódí, vbib_, plën, 
   {{0x39400225,0x4638008f,0x25a02e00,0x0cb800eb}},	//   _nijs_, יערע, çili_, ুস্ত, 
   {{0xbcf8004e,0x00000000,0x00000000,0x00000000}},	//   rsép, --, --, --, 
   {{0x7afc0357,0x0d8434d8,0x3948354d,0xbcf800d8}},	//   giqt, _длин, _bucs_, ssép, 
   {{0x7ce8bd8f,0x48740f1b,0xdb04011f,0x394800db}},	// [2f440] _süre, قداس, _arhó, _cucs_, 
   {{0x6e24a1d3,0x3949b263,0x7ce8850c,0x5fb000c5}},	//   _iyib, _ducs_, _püre, _जनमल, 
   {{0x46480aa8,0x31cc009e,0x7afc0477,0x7ce9b264}},	//   азен_, িনিশ, biqt, _fürb, 
   {{0x7ce80790,0x7b100327,0xb6a00116,0x00000000}},	//   _gürb, għud, җиәл, --, 
   {{0xba7401d9,0x00000000,0x00000000,0x00000000}},	//   _باپت, --, --, --, 
   {{0x394009b6,0xbb3401ec,0x00000000,0x00000000}},	//   _gijs_, _ﯗﻛﻰ_, --, --, 
   {{0x24800ab7,0x7ae8072b,0x80b00154,0x067401f0}},	//   ğim_, _ømtå, জাম্, _муая, 
   {{0x24800ab7,0x6e25b265,0x33144cdb,0xbcf9919a}},	//   şim_, _oyib, يزيد_, mpée, 
   {{0x6e25b266,0xc4c400c6,0x60f800a7,0x00000000}},	//   _nyib, _وتطو, йния_, --, 
   {{0x7afc036b,0xe7cc2b1b,0x03a4013e,0xd11000ab}},	//   ziqt, লনীয, _мизо, ठकगण_, 
   {{0x6449b267,0x7afdb268,0xaf440092,0x42b400c0}},	//   _igdi, yiqt, _ከተመለ, _мёду, 
   {{0x6e2401aa,0x41e43981,0xbcf8004a,0x7afc0548}},	//   _byib, _міла, ipée, xiqt, 
   {{0x6e240230,0x69c05160,0x7e6c01e4,0x7afc045a}},	//   _cyib, _šmen, racp, viqt, 
   {{0x61ec0e98,0x394800db,0xbcf806af,0xb0640395}},	//   ıllı, _rucs_, xpéd, _дръж_, 
   {{0x3edc05db,0x6e25b269,0xdb040784,0x7afc0054}},	//   _abụọ_, _eyib, _ashá, tiqt, 
   {{0x60d9b26a,0x7ce80213,0x6370295a,0x60cc0153}},	//   _hovm, _bürc, _zóná, šimč, 
   {{0xbcf80798,0xf848023a,0x7afdb26b,0x60d92c1f}},	// [2f450] tpéd, ачей_, riqt, _kovm, 
   {{0xe3b80205,0x7afc014f,0xa93401ec,0x6ef001e1}},	//   _ayım_, siqt, деуш, _tòbù, 
   {{0xbeb80221,0x7ce8a2d4,0xa2c00864,0x7afc02d1}},	//   hlëm, _türb, वाञ्, piqt, 
   {{0x7ce841ba,0x6448011f,0x39400d27,0x3948067c}},	//   _fürc, _agdi, _wijs_, _tucs_, 
   {{0x7ce803be,0xfbd00050,0x394001a4,0x929c012d}},	//   _gürc, _رتھ_, _tijs_, niłe, 
   {{0xa8a4f973,0x60d801e4,0xf1bc02fb,0x64480175}},	//   _орск, _novm, ťák_, _cgdi, 
   {{0x0440207d,0xdcec0030,0xb32c02d3,0x7ce9b26c}},	//   нешн, _opaľ, _ብህግደ, _zürc, 
   {{0x6448010b,0x68fc12fe,0x637001e1,0x00000000}},	//   _egdi, _zmrd, _sóná, --, 
   {{0x60d8014f,0xa2c0078a,0xc4440133,0x61e00432}},	//   _bovm, वाज्, زیۆن_, gyml, 
   {{0x6e240526,0x00000000,0x00000000,0x00000000}},	//   _ryib, --, --, --, 
   {{0x60d803e0,0x00000000,0x00000000,0x00000000}},	//   _dovm, --, --, --, 
   {{0x929c012d,0x5154022e,0x00000000,0x00000000}},	//   fiłe, _етку, --, --, 
   {{0x8c44de01,0x00000000,0x00000000,0x00000000}},	//   зеге, --, --, --, 
   {{0xe1f04352,0x60d808cd,0x6e241446,0xe8140490}},	//   _جسم_, _govm, _vyib, _तुझा_, 
   {{0xa2c053b7,0x212000e4,0x929c033f,0x53bc1db2}},	//   वाच्, _êiha_, woły, ्मिश, 
   {{0x0e640372,0x6e24009a,0x929c033f,0xbb4053ab}},	//   _экин, _tyib, biłe, ееск, 
   {{0x6e25b26d,0xbeb80023,0x929c033f,0x00000000}},	// [2f460] _uyib, ymëz, ciłe, --, 
   {{0x60c40198,0x6d4000db,0xa96800d1,0x288800f2}},	//   _ɗimo, ïmad, йиға_, تصری_, 
   {{0x06480f84,0xbcf8004a,0x46a5b26e,0x929c012d}},	//   ملاً_, upée, заев, soły, 
   {{0x7ce8b1e1,0x00000000,0x00000000,0x00000000}},	//   _türc, --, --, --, 
   {{0xe3b80139,0x00000000,0x00000000,0x00000000}},	//   _azıp_, --, --, --, 
   {{0xbcf8004a,0x7ce80205,0x7954010a,0x00000000}},	//   ppée, _küra, _хирĕ, --, 
   {{0x7ce804cc,0xdcb0004d,0x929c033f,0x04340023}},	//   _jüra, ổi_, ziłe, _ቤትጽሕ, 
   {{0x7ce803be,0x60d8047e,0xb5840050,0x8504179e}},	//   _müra, _sovm, تھہٕ_, _کوئن, 
   {{0x60d8014f,0xcd000055,0x85e8005a,0x00000000}},	//   _povm, _kośā_, _удав_, --, 
   {{0x60f810f5,0xdcec0030,0xe4c443fb,0x741000f1}},	//   іння_, _spaľ, _تصری, _ګوما, 
   {{0x929c033f,0x82a406b4,0x00000000,0x00000000}},	//   wiłe, _нажж, --, --, 
   {{0x733041fa,0x25a40158,0x63045c81,0x60d8047e}},	//   _كىلا, _kpml_, _کوچل, _wovm, 
   {{0xbeb80240,0x8024872f,0x60d806be,0xddcc0210}},	//   llëk, _کرشم, _tovm, _sfał, 
   {{0x317810df,0xdfd0007b,0x929c0210,0x00000000}},	//   _פרומ, _ليت_, ciłb, --, 
   {{0x929c033f,0x30980375,0xb098011a,0x00000000}},	//   siłe, _השומ, _היור, --, 
   {{0x7ce81570,0x25a401c6,0xe3b81ea0,0x929c033f}},	//   _düra, _opml_, _ayık_, piłe, 
   {{0xb1400724,0x69c00077,0xc66c001f,0xf990007b}},	// [2f470] _юнәл, _ámel, ጠቀሚያ_, عبر_, 
   {{0x3ea80fa9,0x34d80882,0x5fb0012c,0xa3bc00bc}},	//   lect_, _भवेद, _जनाल, इटा_, 
   {{0x56941de1,0x1cdc031c,0x7ce80205,0x81e00154}},	//   дает, _རྭར_, _güra, নছি_, 
   {{0x7c6400f2,0x00000000,0x00000000,0x00000000}},	//   _باکل, --, --, --, 
   {{0x3ea800a8,0xfafc0200,0x7ce82ca8,0x7f600023}},	//   iect_, _imë_, _züra, ሰብኣዊ_, 
   {{0x94240276,0xab9843fb,0xe96821f3,0x81e000cc}},	//   ммле, _بخیر_, _хаёл_, নছা_, 
   {{0xe7840640,0xefc802d3,0x7ce806be,0x00000000}},	//   _путо, _ኢልዎ_, _xüra, --, 
   {{0x3ea9b26f,0xdcec00e2,0x929c0210,0x00000000}},	//   ject_, _apaļ, wiłb, --, 
   {{0x3140013e,0x00000000,0x00000000,0x00000000}},	//   ндиҳ, --, --, --, 
   {{0x6ea0012c,0xbeb8036e,0x26180051,0x8f74003b}},	//   ग्नु, llëh, ứoc_, мумі, 
   {{0x3ea9b270,0x925800c9,0x43b00124,0x1cdc031c}},	//   fect_, _дает_, _аӡыр, ཡིན_, 
   {{0x441800c8,0xa2e402bf,0x929c0210,0x00000000}},	//   _וועס, _поєд, siłb, --, 
   {{0x25a4030d,0x7ce805d1,0xf1a4023a,0x929c0210}},	//   _xpml_, _süra, _хрен, piłb, 
   {{0xc1700302,0xfafc0240,0x7ce89047,0x00000000}},	//   _יחד_, _amë_, _püra, --, 
   {{0x51840724,0xdd7403e6,0x8f140262,0xe0d096b4}},	//   _хуҗа, وپێک, _офич, _حزن_, 
   {{0x91d002f8,0xca3406ba,0xfaa0a514,0x00000000}},	//   _तपाई, _ﺗﻮﺭ_, касо, --, 
   {{0x3b040aa8,0x7bc00162,0x00000000,0x00000000}},	// [2f480] фето_, _ánun, --, --, 
   {{0x7ce9b271,0xcc889cad,0x66fc00b0,0x613400db}},	//   _türa, _بنده_, mōki, ràlg, 
   {{0x09d400bd,0xbcf80129,0x00000000,0x00000000}},	//   _সেখা, spéc, --, --, 
   {{0x2d5400c5,0x29f800b5,0x7a34063f,0xbcf80098}},	//   _käe_, _ｍah_, ụtab, mpéa, 
   {{0xd5ac121e,0x245818ce,0x6ea0878d,0x00000000}},	//   یہہ_, паль_, ग्यु, --, 
   {{0x2d55b272,0x24f8a4c3,0xe7300133,0x00000000}},	//   _mäe_, янлы_, _ڵڵا_, --, 
   {{0x3ea80789,0xb37001f7,0x86940063,0xa3a800bc}},	//   yect_, نديش, _ојач, खौं_, 
   {{0x7ce9b273,0x66fc02b1,0x41e40212,0xd76401d3}},	//   _nürn, kōki, діоа, _سافٹ, 
   {{0x2d5405a7,0x69c002fb,0xf6200064,0x00000000}},	//   _näe_, _šmej, _адто, --, 
   {{0xe2980022,0x00000000,0x00000000,0x00000000}},	//   цаҩ_, --, --, --, 
   {{0x3ea9b274,0x7ce800a2,0xf8b0011a,0x00000000}},	//   tect_, _bürn, דשת_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x80d81c82,0x3ea991e3,0x7ce80065,0x7ae00276}},	//   যোগ্, rect_, _dürn, _înti, 
   {{0x3ea9b275,0xfafc0200,0x03d40055,0x00000000}},	//   sect_, _smë_, _ūrṇa, --, 
   {{0x3ea8de48,0x613400db,0x929c012d,0xf090011a}},	//   pect_, ràld, liła, _ינס_, 
   {{0x9e340395,0x2b540c5e,0x00000000,0x00000000}},	//   _пейч, _žací_, --, --, 
   {{0x2d5401c7,0x6db401e0,0x9d7400ec,0x929c012d}},	// [2f490] _gäe_, _айыу, _ڪنڌڪ, niła, 
   {{0xf80408da,0x3944c9df,0x00000000,0x00000000}},	//   мчен, öns_, --, --, 
   {{0x613400db,0x16c400c7,0x00000000,0x00000000}},	//   càle, нӡан, --, --, 
   {{0x5ecc015b,0xba39103b,0xdb0c0241,0x00000000}},	//   াসকে, _maïz, _ìkàl, --, 
   {{0xd7c807d6,0x00000000,0x00000000,0x00000000}},	//   _کوزه_, --, --, --, 
   {{0xb110063f,0xdb040036,0x93b40395,0x00000000}},	//   pụis, _ophë, ещич, --, 
   {{0x9fd0045e,0xe824013e,0x07a00014,0xdef40b82}},	//   ানুগ, _афто, _مۅلُ, ጉምን_, 
   {{0xdb040730,0x09d4015b,0xd04800ac,0x929c012d}},	//   _erhö, _সেটা, ənəl, fiła, 
   {{0x6595b276,0xb3400014,0x00000000,0x00000000}},	//   _иату, _یێتى, --, --, 
   {{0xc8d02c35,0xf000010b,0x7ce800a2,0xa5343671}},	//   सायट, күли, _sürn, _ануч, 
   {{0x7ce8067c,0x00000000,0x00000000,0x00000000}},	//   _aüro, --, --, --, 
   {{0xa3bc1e61,0x66fd4dff,0x929c033f,0xa2d40150}},	//   इटर_, tōki, biła, _ۋيەت, 
   {{0xc3300d65,0x76590d18,0xcd3400e5,0x929c012d}},	//   _עוד_, _mfuy, فرآب, ciła, 
   {{0x613400f7,0x7ce804cc,0x8b642c10,0x7aec02d0}},	//   tàle, _düro, فارم, _alct, 
   {{0x1fb5b277,0x765804ba,0x2719b278,0x7ce80254}},	//   _асыр, _ofuy, lčne_, _türn, 
   {{0x7ce805d5,0xfd1c026c,0x6458cc1a,0x2d540139}},	//   _hürl, rrìa_, zcvi, _täe_, 
   {{0x2718994e,0x08c4016c,0xbcf9b279,0x7ce803e0}},	// [2f4a0] nčne_, нбан, mpén, _kürl, 
   {{0x765800d2,0x6458003a,0x27180010,0x7ce800a2}},	//   _afuy, xcvi, ične_, _jürl, 
   {{0x0685b27a,0xc6a5b27b,0xddcc010e,0x929c012d}},	//   еген, ерли, _agaň, ziła, 
   {{0xb9580109,0xc7643818,0x27180419,0xf49000d1}},	//   _irìn, _ۋازى, kčne_, ۇشىد, 
   {{0x27180427,0xdb0c0248,0x00000000,0x00000000}},	//   jčne_, _ìkál, --, --, 
   {{0x76580472,0x27180427,0xa3bc924b,0x00000000}},	//   _efuy, dčne_, इटल_, --, 
   {{0xa3d4a2ed,0x6b9c00fb,0x271800d0,0x929c033f}},	//   тойч, ntrg, ečne_, wiła, 
   {{0xf74019ba,0xdb0c05d1,0xbeb80240,0x066400cf}},	//   _бесо, ıkça, llëv, _سارپ, 
   {{0x2718007f,0x32d000d1,0x00000000,0x00000000}},	//   gčne_, ازىس, --, --, 
   {{0xb110869e,0x04440798,0xdb2008a5,0x6b9c1180}},	//   лмыш, _зезн, _átök, ktrg, 
   {{0x7ce809a5,0x80b00154,0x929c012d,0x271800d7}},	//   _dürl, জাল্, siła, ačne_, 
   {{0x929c033f,0x7ce8bc64,0x00000000,0x00000000}},	//   piła, _püro, --, --, 
   {{0xc0e5b27c,0xb8d03aaf,0xb9580248,0x52741586}},	//   _подк, _དྲ_, _arìn, _руху, 
   {{0x63a80ac5,0x7ce800ee,0x7aec03ac,0x00000000}},	//   _kpdn, _gürl, _slct, --, 
   {{0x6e200037,0x00000000,0x00000000,0x00000000}},	//   ümbr, --, --, --, 
   {{0x3f8801ab,0x00000000,0x00000000,0x00000000}},	//   àbuu_, --, --, --, 
   {{0x61340268,0x7ce80342,0x76880205,0x00000000}},	// [2f4b0] càlc, _hürm, höyü, --, 
   {{0xbcf8003e,0x7ce800fd,0x768803b9,0x00000000}},	//   mpéo, _kürm, köyü, --, 
   {{0x7d0404b9,0x656000a3,0xcc540375,0x7ce800a2}},	//   mijs, _atmh, _בבתי_, _jürm, 
   {{0x7d05b27d,0x3eb80227,0xbeb80240,0xdb0406af}},	//   lijs, _jaqt_, alëv, _ophé, 
   {{0x3eb802d1,0x99980050,0xe730007b,0xb90400fe}},	//   _maqt_, _تھزر_, حصل_, _বগ_, 
   {{0xf771b27e,0x2719b27f,0xdb04004a,0x64980801}},	//   _مار_, včne_, _sphè, етър_, 
   {{0x22040374,0x36884bb6,0x56940022,0x00000000}},	//   hīhī_, _нсан_, _иавт, --, 
   {{0x1cb00dd4,0x7d05b280,0xb8800306,0x69c00024}},	//   _ནིའ_, hijs, stíč, _šmei, 
   {{0x7ae00276,0x9f4c0306,0x7ce80432,0x6b9c0219}},	//   _întu, vzdá_, _pürl, ztrg, 
   {{0x271825d8,0x7ce800a2,0x225800bc,0x42040212}},	//   rčne_, _bürm, ěrka_, тньо_, 
   {{0x8fd14977,0xdcec00f3,0x75204e6c,0xdb0406af}},	//   рәлә, _zvać, monz, _ephé, 
   {{0xb8d00f50,0x7521b281,0x929c012d,0x59d0243c}},	//   _དི_, lonz, miło, समार, 
   {{0x7ce80365,0x7d04b3d2,0x3eb80327,0x1cb0025c}},	//   _türl, fijs, _daqt_, _ནིཡ_, 
   {{0x7521b282,0xbcf9b283,0x81d800cc,0x333c0327}},	//   nonz, spén, _ডেক_, lmux_, 
   {{0xc0e80020,0xbcf9b284,0x7ce856f8,0x00000000}},	//   ሆኑም_, mpél, _gürm, --, 
   {{0x7521b285,0x61340137,0xb95801ab,0x7ce93e41}},	//   honz, màla, _crìo, _jürj, 
   {{0x7521b286,0x7d05b287,0xbb41b288,0x613406d9}},	// [2f4c0] konz, bijs, ретк, làla, 
   {{0x7d0523fa,0xb95801dc,0x752001c8,0x1cb00327}},	//   cijs, _trìn, jonz, _ནིར_, 
   {{0x7521b289,0x00000000,0x00000000,0x00000000}},	//   donz, --, --, --, 
   {{0xe9740372,0x00000000,0x00000000,0x00000000}},	//   _مۇرد, --, --, --, 
   {{0x80b005ba,0x7521b28a,0x6f0400f3,0x333c0327}},	//   _असले, fonz, _mmic, dmux_, 
   {{0x2b41b28b,0x7521b28c,0x3b0401e1,0xbeb80200}},	//   lmic_, gonz, _tìpè_, llët, 
   {{0x6f05b28d,0xbeb80af9,0xdb0406af,0xe3a40214}},	//   _omic, doën, _sphé, اشتی, 
   {{0x613406d9,0xf2c00024,0xb95801e1,0x7b100135}},	//   dàla, асьн, _orìl, jħul, 
   {{0x7521b28e,0x7ce83630,0xed540115,0x3ce00073}},	//   bonz, _sürm, _nuɾ_, _ऐकले_, 
   {{0x752000ca,0x7ce804cc,0x30a002bf,0x2b400f85}},	//   conz, _pürm, арюв, hmic_, 
   {{0x7d0401fa,0x01040014,0x8cc41116,0x00000000}},	//   vijs, ى۪چو_, ायनो, --, 
   {{0x1cb00156,0x7d040196,0x2ee1124b,0x6f0401a6}},	//   _ནིཤ_, wijs, _coif_, _cmic, 
   {{0xf0b40502,0x7d053fcd,0x3eb807d6,0x6d400006}},	//   رایش_, tijs, _vaqt_, įman, 
   {{0x3eb8038f,0x7ce9b28f,0x2b407c8f,0x5f940ce8}},	//   _waqt_, _türm, emic_, _бикт, 
   {{0xd1d4069c,0xa2b95597,0xb95801ab,0x7ce815b7}},	//   _ክልተ_, ्यप्, _prìo, _hürk, 
   {{0x7d053276,0x7ce918fe,0x7521b290,0x41b40c93}},	//   sijs, _kürk, zonz, _अनास, 
   {{0x752039aa,0x291c00f3,0x7ce80254,0xa95402dd}},	// [2f4d0] yonz, čvan_, _jürk, икті, 
   {{0x3f9c19f5,0x7ce80037,0x00000000,0x00000000}},	//   ottu_, _mürk, --, --, 
   {{0x75218f3e,0x3f9c5943,0xbeb804e6,0x00000000}},	//   vonz, nttu_, blët, --, 
   {{0x9598fe03,0x98b8005f,0x3f9db291,0x752004ba}},	//   етку_, _pusē_, ittu_, wonz, 
   {{0xa2b8726e,0xbeb802d3,0x69c4712e,0xe3b9b292}},	//   ्यन्, llës, रिणी, _ası_, 
   {{0xddcc0115,0x1cb0025c,0xf4842fc3,0x7ce82c43}},	//   _neaŭ, _ནིས_, тудн, _sürj, 
   {{0x67d5b293,0x7521b294,0x7d140014,0xbeb80036}},	//   _кору, ronz, _mjxs, nlës, 
   {{0x75208ab8,0x57a40131,0x98b800ef,0x00000000}},	//   sonz, _ишға, _tusē_, --, 
   {{0x3f9db295,0x20180428,0x7521b296,0xbeb804e6}},	//   ettu_, ûrin_, ponz, hlës, 
   {{0x6ff00cc1,0x2ee0004a,0x6f04ac7f,0x7ce8002f}},	//   ləcə, _soif_, _smic, _dürk, 
   {{0xed540115,0x27180219,0x2b40045a,0x7b10031c}},	//   _suɾ_, lčna_, ymic_, tħul, 
   {{0x6ff000ac,0x52140212,0xad8400d1,0x3ae4000d}},	//   nəcə, _йдет, ақий, _kõpu_, 
   {{0x2718151c,0x3f9db297,0xbeb80109,0x6f040165}},	//   nčna_, attu_, moël, _vmic, 
   {{0xddcc01e4,0x3cf0003a,0xbeb80036,0x00000000}},	//   _geaŭ, _clxv_, flës, --, 
   {{0x3ae400c5,0x01340375,0x2b410961,0xbeb801c7}},	//   _lõpu_, _גרסת_, tmic_, glës, 
   {{0x6f05b298,0x8e74084c,0x00000000,0x00000000}},	//   _umic, _сукч, --, --, 
   {{0x6ff000ac,0x27180010,0xbeb8036e,0x00000000}},	// [2f4e0] dəcə, jčna_, alës, --, 
   {{0x2b41b299,0x3ab00116,0x5a340354,0x00000000}},	//   smic_, _қәст, ăнат, --, 
   {{0x60dcb83f,0x6ed8c454,0x7d180077,0x27180419}},	//   örmi, यापु, éuse, ečna_, 
   {{0xeff0044e,0xbeb80694,0x2d8000c0,0x8ed00154}},	//   _ልክዕ_, llër, _kvie_, াসকগ, 
   {{0x597411db,0xe9440214,0x7ce803b9,0x84e40212}},	//   _высу, _نرسی, _bürh, лодж, 
   {{0x7ae00262,0x2fc40a2e,0x69c5b29a,0xd1cc001f}},	//   _într, _orng_, mvie, ጥነት_, 
   {{0xddcc01e4,0xe3b81ea0,0x37e0004e,0x6ff003e3}},	//   _reaŭ, _ayır_, _лорг, bəcə, 
   {{0x291806d9,0x8928025c,0x07a400c7,0x69c5b29b}},	//   _hjra_, _ཨེཌྶ_, _иаҳн, ovie, 
   {{0x69c488c5,0x9a88044e,0x6ed8081e,0xa494168d}},	//   nvie, _ንኽእል_, यानु, _نیشت, 
   {{0x2fc406d1,0xbb24001f,0x4374822f,0x69c5b29c}},	//   _brng_, _ሰጥተዋ, _будт, ivie, 
   {{0xd9d005ba,0x945406c8,0x2d815adc,0x82680261}},	//   _सप्ट, _kān, _avie_, _заев_, 
   {{0x7ce8d9d4,0x69c40953,0x3f9db29d,0xddcc0356}},	//   _türk, kvie, rttu_, _neaţ, 
   {{0x7c854205,0x291816a3,0x69c400e2,0xe3b803b9}},	//   луве, _ojra_, jvie, _azıx_, 
   {{0x69c5b29e,0xbcf9b29f,0x9c6401c8,0x00000000}},	//   dvie, mpék, شهرو, --, 
   {{0x66f41533,0x2d81b2a0,0xac19b2a1,0x6ff003be}},	//   _आतंक_, _evie_, гору_, yəcə, 
   {{0x7ce9b2a2,0xddcc054e,0xbeb801c7,0x6f601541}},	//   _müri, _ceaţ, rlës, _اهيم, 
   {{0x19940801,0x69c5b2a3,0x98749808,0xaa64023a}},	// [2f4f0] разя, gvie, илац, стск, 
   {{0x271809a8,0xa89800f7,0x00000000,0x00000000}},	//   včna_, лкуу_, --, --, 
   {{0xcc740375,0x69c40500,0x7ce8000d,0x57b40150}},	//   _דעתה_, avie, _nüri, рбет, 
   {{0x29180789,0x69c5b2a4,0x19945b97,0x00000000}},	//   _ejra_, bvie, _камя, --, 
   {{0x6ff00cc1,0x201c0393,0x69c5b2a5,0x2d8006af}},	//   rəcə, _lxvi_, cvie, _xvie_, 
   {{0xe3b82b93,0x27180427,0x15440166,0x00000000}},	//   _ayıq_, rčna_, шелм, --, 
   {{0x6ed805ba,0xe3b803b9,0xb95801e1,0x00000000}},	//   यामु, _axıb_, _orìk, --, 
   {{0xd185b2a6,0x59c8521a,0x00000000,0x00000000}},	//   алий, रिपर, --, --, 
   {{0xf4841248,0x69c00077,0x2fc4003e,0x00000000}},	//   _буен, _ámet, _srng_, --, 
   {{0x94540198,0x9104014b,0x00000000,0x00000000}},	//   _zān, рпое, --, --, 
   {{0x69c5b2a7,0x201c003a,0x2d802b96,0x8fa41d73}},	//   zvie, _cxvi_, _svie_, шане, 
   {{0x201c009a,0x61340ffb,0x69c5b2a8,0x50d46e92}},	//   _dxvi_, làll, yvie, ازکر, 
   {{0x7ce9b2a9,0xdb04045f,0x69c4004d,0x6ed82e1e}},	//   _züri, _ophâ, xvie, याबु, 
   {{0x50440372,0x317c03ee,0x60080220,0x8fd000d1}},	//   _келб, msuz_, _өнім_, _дәмә, 
   {{0x8c4421f0,0x317c0c37,0x273d36e8,0x2fc4525e}},	//   реве, lsuz_, líne_, _urng_, 
   {{0x69c40029,0x0dc84ee3,0x91a800c5,0x00000000}},	//   tvie, _алий_, _कहाई, --, 
   {{0x09054588,0x69c5b2aa,0xa2b80a28,0x317c274a}},	// [2f500] апан, uvie, ्यत्, nsuz_, 
   {{0xa2cc0574,0x69c5b2ab,0x7d780375,0x98b800c0}},	//   _दोन्, rvie, _שניו, _musė_, 
   {{0xd90c77c2,0x69c5b2ac,0x201db2ad,0xdb9c001f}},	//   ریف_, svie, _xxvi_, ሌኒየም_, 
   {{0x46a5b2ae,0x69c5b2af,0xbeb80200,0x00000000}},	//   радв, pvie, nlëp, --, 
   {{0x2a600369,0xe3b80790,0xc76400d1,0x7ce9b2b0}},	//   mcib_, _ayıp_, _چارى, _süri, 
   {{0x7ce8260b,0xbeb80036,0xc76400f7,0x273c00d7}},	//   _püri, hlëp, _نارى, díne_, 
   {{0x2d8400d0,0x00000000,0x00000000,0x00000000}},	//   ámej_, --, --, --, 
   {{0x69c00077,0xa2b800dc,0x77b8011a,0x7b10031c}},	//   _ámes, ्यध्, _במלח, għuh, 
   {{0xa63401ed,0x59c80f90,0x27180219,0x04b403c5}},	//   _اکاؤ, रियर, lčno_, _всея, 
   {{0x5f9421e0,0x7ce81d13,0x04c801c8,0x660400e4}},	//   биот, _türi, _جوئي_, úiku, 
   {{0x27180fb7,0xa2b800dc,0xbcf8003e,0x7b100327}},	//   nčno_, ्यद्, spék, bħuh, 
   {{0x2a600369,0x6d5839ae,0xbcf800d8,0x273c00d0}},	//   jcib_, _čvar, mpéi, bíne_, 
   {{0xbcf801c7,0x7ce815b7,0x273c0419,0xf2000064}},	//   lpéi, _mürv, cíne_, _мяшо, 
   {{0x59180135,0xefcc02d3,0x6ac000fe,0x00000000}},	//   ྱོབས_, ባእያ_, _একগো, --, 
   {{0xc1b4255c,0x27180427,0xc22001e2,0x00000000}},	//   _अनुग, jčno_, _دکډو, --, 
   {{0xbcf9b2b1,0x27180010,0x00000000,0x00000000}},	//   ipéi, dčno_, --, --, 
   {{0xed340014,0x69c13b9b,0x00000000,0x00000000}},	// [2f510] _ڈوٹھ, _šmer, --, --, 
   {{0xd879b2b2,0x85400024,0x1cb00327,0x5cb80006}},	//   امات_, žėja, _ནིི_, _слоў_, 
   {{0x21e00374,0xdeac02a8,0x97341046,0x00000000}},	//   _hōhā_, _shaƙ, مکرا, --, 
   {{0x21e000b0,0xa3bc07f7,0x5695b2b3,0x317c2ca8}},	//   _kōhā_, ेटन_, садт, ysuz_, 
   {{0xd1d40020,0xe6100e60,0x929c0034,0x6ed80846}},	//   _ክፍት_, وشه_, siłk, यातु, 
   {{0x98b80064,0x4d78010f,0x273cf02c,0xb6f400db}},	//   _rusė_, אָקא, víne_, دىچا_, 
   {{0x63784640,0x6134026c,0x9f640213,0x00000000}},	//   асыр_, ràll, ətçi_, --, 
   {{0xe6940724,0x98b80006,0x61340ffb,0x317db2b4}},	//   _мисы, _pusė_, sàll, tsuz_, 
   {{0xc690008f,0x80b00011,0xd2500050,0x2d8c012d}},	//   _מאן_, ড়ান্, _ہنا_, ądek_, 
   {{0x317c1ae4,0x2a600007,0x273c9655,0x25a000a3}},	//   rsuz_, zcib_, ríne_, àile_, 
   {{0xd25036fe,0x273c2d95,0x245873b3,0xe3b8013d}},	//   _فنا_, síne_, _тахь_, _uyıp_, 
   {{0xe3b0007b,0x6580013d,0x317c0205,0x00000000}},	//   _ترك_, _äzhä, psuz_, --, 
   {{0x5ec4e17f,0xc0d4001f,0x918000db,0x471805d0}},	//   цияғ, ክሱም_, _عۇدۇ, רורג, 
   {{0xa0c40228,0x1d18b19d,0x9db8031c,0x4638008f}},	//   _وينو, аюсь_, _བརྫེ, טערע, 
   {{0x6ed800cd,0x00000000,0x00000000,0x00000000}},	//   यादु, --, --, --, 
   {{0x823802d3,0x271809a8,0x70b400bc,0x00000000}},	//   _ብድሆታ, včno_, _असुल, --, 
   {{0x49c97eaf,0x44300208,0x00000000,0x00000000}},	// [2f520] ылан_, ́y_, --, --, 
   {{0xc8d01d8a,0x1cb0025c,0xe6d00882,0xa3bc05d7}},	//   साइट, _ནིག_, सञ्ज, ेटम_, 
   {{0x7c3802a8,0x00000000,0x00000000,0x00000000}},	//   ƙura, --, --, --, 
   {{0x9db82fb5,0xf741b2b5,0xfc1401b9,0x27180427}},	//   _བརྩེ, пехо, _چقیب_, rčno_, 
   {{0xa2b80a28,0xd90c00f8,0x7ce805c7,0xfc143765}},	//   ्यस्, ریہ_, _eüru, _نقیب_, 
   {{0x26c010cd,0xe0ac0154,0x2768036b,0x7ce806be}},	//   žio_, _কোনভ, _نشری_, _füru, 
   {{0xbcf801c7,0x7ce9b2b6,0xf36000db,0x00000000}},	//   upéi, _türv, птын, --, 
   {{0xb6a151fa,0xfbd0011a,0x7ce80112,0xbcf801e7}},	//   _нисл, לתו_, _hürt, rpéi, 
   {{0x7ce9b2b7,0x63b80218,0x60f9b2b8,0xbcf80f33}},	//   _kürt, swvn, иния_, spéi, 
   {{0x3ae400af,0xbcf804e6,0xbadc0150,0x00000000}},	//   _lõpp_, ppéi, _ﺇﻗﺤﺎ, --, 
   {{0xdeb42ecc,0x43680724,0x7ce9b2b9,0xf45400ae}},	//   обны, _саен_, _mürt, _المع_, 
   {{0x1cb00003,0x80d445c7,0x21e002b5,0xf8340375}},	//   _ནིང_, बाहे, _pōhā_, מנית_, 
   {{0x823400db,0xdd5801c0,0x63a40356,0x00000000}},	//   _اراا, рагч_, ăinu, --, 
   {{0xa2b81a2a,0xb22001c0,0x7ce8002f,0xdb0c08ce}},	//   ्यव्, _эмчл, _nürt, _íhús, 
   {{0x43d000d1,0xac9401c4,0x00000000,0x00000000}},	//   _ﻛﯧﯖﻪ, яарш, --, --, 
   {{0x7ce8002f,0x7d6800d4,0x00000000,0x00000000}},	//   _rüru, _йшов_, --, --, 
   {{0x7ce80139,0x6e44313e,0x9a280051,0xdbe40200}},	// [2f530] _bürt, _ىنىم, _bươm_, këça, 
   {{0xfe7c0129,0x00000000,0x00000000,0x00000000}},	//   laï_, --, --, --, 
   {{0xc5e409bd,0xaac51afa,0x7ce8fd2a,0x00000000}},	//   _খেলা_, _लोकक, _dürt, --, 
   {{0xfe7db2ba,0xd88801d3,0x96347e7e,0x00000000}},	//   naï_, _چھان_, онец, --, 
   {{0x7ce9b2bb,0xd1f00092,0xb8fc0154,0x758800d8}},	//   _fürt, ውቁት_, _তত_, усев_, 
   {{0x92d403f4,0x7ce9b2bc,0xe858010b,0x9a28004d}},	//   _হতে_, _gürt, _гарш_, _gươm_, 
   {{0x77640054,0x0441a962,0xfe7c0129,0x00000000}},	//   _utjx, мешн, kaï_, --, 
   {{0x7ce80598,0x5918031c,0x86b002dd,0xa2b800cd}},	//   _kürs, ྱོམས_, _жәші, ्यष्, 
   {{0x50b4034b,0x6ed801bc,0x00000000,0x00000000}},	//   осну, यासु, --, --, 
   {{0x1cb00156,0x1fe400bd,0x273db2bd,0x75040640}},	//   _ནིཊ_, _ফেইস, mína_, _уџбе, 
   {{0x945406c8,0x273d86db,0xa2b800dc,0x98b80171}},	//   _lāk, lína_, ्यश्, _ausī_, 
   {{0xdb040113,0x9db8025c,0xd174010b,0xe3b00214}},	//   _oshñ, _བརྡེ, _дыкы, _سرم_, 
   {{0xa2b80882,0x2d85b2be,0x273db2bf,0xe2700150}},	//   ्यर्, éme_, nína_, _ﺴﺘﻠﻡ_, 
   {{0x8b645c3b,0x800801d3,0x6ed807b6,0x25a00327}},	//   قارم, اریہ_, याहु, ħilx_, 
   {{0xfbc001ca,0xfe7c39b4,0x7bc000d0,0x80d400bc}},	//   мбро, baï_, _šnur, बारे, 
   {{0x7ce9b2c0,0x998c0024,0x00000000,0x00000000}},	//   _bürs, _šeš_, --, --, 
   {{0xdb04037e,0x26c801e0,0x88e44684,0xaa6400cf}},	// [2f540] _ophæ, ҙған_, ожае, _ۉندۉ, 
   {{0x92d4015b,0x7ce9b2c1,0x273c0139,0x291c0124}},	//   _হতো_, _dürs, dína_, õva_, 
   {{0x7ce8f2ad,0x8c4448e5,0xe3b803e3,0xc1b41788}},	//   _vürt, _фене, _axın_, _अन्ग, 
   {{0x7ce9b2c2,0x0568041b,0x2cb800a2,0x273c02d2}},	//   _würt, ајки_, lerd_, fína_, 
   {{0x273d99c9,0x7ce9b2c3,0x9a280208,0x00000000}},	//   gína_, _gürs, _tươm_, --, 
   {{0x6b5800df,0x7ce88eb9,0x53c400dc,0x6e200022}},	//   _eŭge, _hürr, विंश, ümby, 
   {{0xbcf9b2c4,0x7ce8010e,0xa2b801bc,0x00000000}},	//   mpét, _kürr, ्यल्, --, 
   {{0x2cb92202,0x613400db,0xf6c4004b,0x273db2c5}},	//   herd_, màli, _وژني_, bína_, 
   {{0x2cb8d2aa,0x273c0122,0xd5e40075,0x613400cf}},	//   kerd_, cína_, _ейтқ, làli, 
   {{0x26c5b2c6,0xdddd360c,0x2cb805ac,0xfe7db2c7}},	//   _hamo_, sasū, jerd_, waï_, 
   {{0xdfd0c903,0x26c5b2c8,0x2cb8d2aa,0x613400db}},	//   ريح_, _kamo_, derd_, nàli, 
   {{0x74100502,0x2cb80d27,0xbd681d37,0x00000000}},	//   _توما, eerd_, ирге_, --, 
   {{0x6281b2c9,0x26c5b2ca,0xdcec0989,0x2cb8b02f}},	//   mamo, _mamo_, _svađ, ferd_, 
   {{0x6281b2cb,0x2cb851c2,0x443c009f,0x26c5b2cc}},	//   lamo, gerd_, _kzt_, _lamo_, 
   {{0x94540198,0x62800421,0xefcc0092,0x273c0306}},	//   _sāk, oamo, ጥተው_, zína_, 
   {{0xba740533,0x26c5b2cd,0x443c009b,0x212c036e}},	//   تاست, _namo_, _mzt_, lodh_, 
   {{0x7ce9b2ce,0x6280021c,0x78b46326,0xca740014}},	// [2f550] _dürr, iamo, texv, سنٕک, 
   {{0x6281b2cf,0x613426b7,0x26c40067,0x2cb8003a}},	//   hamo, fàli, _aamo_, cerd_, 
   {{0x6281b2d0,0x7ce80e78,0x212c01ab,0x443c0205}},	//   kamo, _würs, iodh_, _nzt_, 
   {{0x6281b2d1,0x7ce9b2d2,0x95d800c9,0xdb040393}},	//   jamo, _gürr, йдет_, _sphæ, 
   {{0x443c00f8,0x26c5b2d3,0xd4680d06,0xe6102c10}},	//   _azt_, _damo_, биле_, پشن_, 
   {{0x273db2d4,0x6134004e,0x212c0023,0x7ce806be}},	//   rína_, bàli, jodh_, _kürq, 
   {{0x26c5b2d5,0x613400db,0x59c81fe7,0xad1c0375}},	//   _famo_, càli, रिवर, בוגר, 
   {{0x6281b2d6,0x66b4049b,0x26c400df,0x2cb801a4}},	//   gamo, _обсу, _gamo_, zerd_, 
   {{0x443c066d,0x2cb8083a,0x23080a2c,0x00000000}},	//   _ezt_, yerd_, تتوي_, --, 
   {{0x26c40c09,0x00000000,0x00000000,0x00000000}},	//   _zamo_, --, --, --, 
   {{0x6281b2d7,0x2cb9b2d8,0x26c5b2d9,0xb37400b5}},	//   bamo, verd_, _yamo_, _iでod, 
   {{0xfe7c0054,0xd33c0354,0x00000000,0x00000000}},	//   wkïr_, _тiах, --, --, 
   {{0x2cb8d2aa,0x00000000,0x00000000,0x00000000}},	//   terd_, --, --, --, 
   {{0x95600023,0x7ce9b2da,0x00000000,0x00000000}},	//   _ስኒትን_, _sürr, --, --, 
   {{0x8d74429e,0xdb0404e6,0x7ce800a2,0xc4d000d9}},	//   _کابا, _ophä, _pürr, עגל_, 
   {{0x0d8404a9,0x2cb81529,0x8964d5da,0x6134004e}},	//   _елин, serd_, зкаж, vàli, 
   {{0x26c407dd,0xc3300302,0x2cb8057b,0x7e980375}},	// [2f560] _ramo_, תון_, perd_, _הספו, 
   {{0x8c45b2db,0x6e24011f,0x613400db,0x6a846518}},	//   _непе, _ixib, tàli, ялға, 
   {{0xbcf87cfb,0x271809a8,0x5d480451,0x26c40248}},	//   rpét, lčni_, _بجيٽ_, _pamo_, 
   {{0x6281b2dc,0x613466ce,0xbcf8026c,0x86440353}},	//   xamo, ràli, spét, пнеж, 
   {{0xbcf9a751,0x2718151c,0x443c0034,0x26c52314}},	//   mpér, nčni_, _szt_, _vamo_, 
   {{0x26c401c8,0x6fd80490,0x443c0790,0x6281b2dd}},	//   _wamo_, यमां, _pzt_, wamo, 
   {{0x62805599,0xd5ac01d9,0x00000000,0x00000000}},	//   tamo, ُہہ_, --, --, 
   {{0x6cf8012c,0xbcf800f2,0xa2cc012c,0x9694004e}},	//   ँसँग_, npér, _दोश्, _оруш, 
   {{0xc0580efb,0x6e2401e2,0x27180427,0xc0c80114}},	//   йін_, _nxib, jčni_, буне_, 
   {{0x443c01f5,0xbcf800e4,0x00000000,0x00000000}},	//   _tzt_, hpér, --, --, 
   {{0x6e24003a,0xa3b0007d,0x443c009d,0x212c08c2}},	//   _axib, _ओहि_, _uzt_, rodh_, 
   {{0x82a5b2de,0xbeb80023,0x3814025d,0x00000000}},	//   _хадж, llëz, לקים_, --, 
   {{0xaed40107,0x7e281cd0,0x00000000,0x00000000}},	//   хояш, сіна_, --, --, 
   {{0xb95801e1,0x5f9400db,0x00000000,0x00000000}},	//   _orìr, _жикт, --, --, 
   {{0x6e25b2df,0x28e01100,0xefa00092,0x42500244}},	//   _exib, नानि, ሊኒየሙ_, _تۆکر, 
   {{0x49780241,0x00000000,0x00000000,0x00000000}},	//   _ọtẹ_, --, --, --, 
   {{0x6d4801d9,0xd8e40220,0x00000000,0x00000000}},	// [2f570] زلہِ_, _ﺍﻷﻭﻟ, --, --, 
   {{0x7ce875d4,0xdb041196,0xe3b806be,0xbcf800e4}},	//   _gürp, _sphä, _axım_, apér, 
   {{0xbb4c037e,0x7e7c0023,0xbcf873a0,0x57d401f7}},	//   _comメ_, _keqp, spés, بياء, 
   {{0x63bc01ed,0xf77015bf,0xca2401ec,0x00000000}},	//   _árny, _ۋاز_, _ﺠﻬﺩ_, --, 
   {{0x7e7c0477,0x6e780092,0xca940115,0x00000000}},	//   _meqp, _ጠንቅቆ_, _קדשי_, --, 
   {{0x849002d3,0xe57000c6,0x61e0003e,0x00000000}},	//   _ፍቕርን_, اطن_, dxml, --, 
   {{0x1cb0025c,0xd7c8315b,0x69000254,0xa4840b24}},	//   _ནིན_, _بوزه_, _söeg, رجون, 
   {{0x1ddc193d,0xe3bc00cc,0x00000000,0x00000000}},	//   ममात, _অপশব, --, --, 
   {{0x7659b2e0,0x62641216,0x659595d2,0x7c3401e3}},	//   _iguy, رايق, _пату, _lyxr, 
   {{0x248c02fa,0x271809a8,0x74f00150,0xc4440133}},	//   _gddm_, včni_, _سۋعا, سیۆن_, 
   {{0x7e7c047e,0xbcf80022,0x00000000,0x00000000}},	//   _beqp, ypér, --, --, 
   {{0x7ce80259,0xa3bc353b,0xbcf80129,0x00000000}},	//   _sürp, ेटर_, xpér, --, 
   {{0xb63c0a5c,0x00e404d3,0x28e0102f,0x02d808a3}},	//   _ｃｈ_, ستیی, नामि, भारभ, 
   {{0x8c443d50,0x27180219,0x0ba800be,0x00000000}},	//   деге, rčni_, يازى_, --, 
   {{0xd1f0044e,0x76595b11,0xa3e00254,0x4b540aac}},	//   _ውልቀ_, _oguy, दमय_, дъат, 
   {{0x7659b2e1,0xbb403739,0x6e2401c4,0x28e0102f}},	//   _nguy, веск, _txib, नाभि, 
   {{0x08c4cb13,0x1ea8a521,0x6d8801ed,0xbcf800d8}},	// [2f580] мбан, _رايي_, _عمدہ_, rpér, 
   {{0x7659b2e2,0x17080135,0xbcf89d74,0xc7943740}},	//   _aguy, _གཏུམ_, spér, дрды, 
   {{0xbeb8017a,0x46a5b2e3,0x0b45b2e4,0xdb0c0118}},	//   poët, даев, _онон, řkác, 
   {{0xb95801e1,0xbeb801f5,0x9aa400cf,0x00000000}},	//   _isìn, loër, _كمپو, --, 
   {{0x6b9db2e5,0x36280092,0x02500051,0x60c8007c}},	//   lurg, _እናገኛ, _mởcử, yddm, 
   {{0x76592baf,0xc7640131,0x98480014,0xd6d8012d}},	//   _eguy, _يازى, _کێم̡_, _miły_, 
   {{0x6b9c00c5,0xd36c0131,0xe2f801ec,0x00000000}},	//   nurg, مۇل_, зейі_, --, 
   {{0xdcfc0064,0xb4600304,0x00000000,0x00000000}},	//   busė, нкәл, --, --, 
   {{0x69c42c35,0x6b9db2e6,0xbeb8002e,0x00000000}},	//   रिटी, hurg, nnëe, --, 
   {{0x6b9db2e7,0x7e7c047e,0xbeb80036,0x61e002d0}},	//   kurg, _seqp, joër, rxml, 
   {{0x6561b2e8,0x7e7c0309,0x6b9c0ffb,0x765802d0}},	//   _humh, _peqp, jurg, _yguy, 
   {{0x6561b2e9,0xdd95b2ea,0x6b9db2eb,0x7e7c0455}},	//   _kumh, намы, durg, _qeqp, 
   {{0x656076b7,0xb95801e1,0x6134004e,0x010800db}},	//   _jumh, _asìn, fàlt, _وتتو_, 
   {{0xa2b80b98,0x6561b2ec,0x7e7c014b,0xdfd016a2}},	//   ्यक्, _mumh, _weqp, _ميت_, 
   {{0x6b9db2ed,0x6560047e,0x30980375,0x961c00e2}},	//   gurg, _lumh, _ושומ, _ieņe, 
   {{0xaf0800c6,0x1cb00327,0xf18401af,0x00000000}},	//   _يقوم_, _ནིམ_, _эйәл_, --, 
   {{0x58d41ee3,0x65600005,0xd33c07d5,0x7b00000d}},	// [2f590] ноат, _numh, _тiех, _lõug, 
   {{0x7b64722e,0xbeb80af9,0xf77000ae,0x00000000}},	//   _отме, poës, ناص_, --, 
   {{0x656001ab,0x6b9db2ee,0x7b000254,0x00000000}},	//   _aumh, curg, _nõug, --, 
   {{0x6561b2ef,0x3f880327,0x00000000,0x00000000}},	//   _bumh, ġbuh_, --, --, 
   {{0x6561b2f0,0xe5780953,0xd4681fbe,0x00000000}},	//   _cumh, дзі_, пиле_, --, 
   {{0xd468fc32,0x6561b2f1,0x961c00e2,0x00000000}},	//   чике_, _dumh, _neņe, --, 
   {{0x656005da,0xe4d403e6,0x271800d7,0x00000000}},	//   _eumh, کتۆب, ečnu_, --, 
   {{0x7658b761,0xa2b800dc,0xa3b000c5,0xdb08013d}},	//   _uguy, ्यग्, _ओहर_, _äläz, 
   {{0x61e5b2f2,0x6b9c5dbf,0xa63400d4,0x66c8030d}},	//   _àill, zurg, _анті, _юург_, 
   {{0x6b9c01b9,0x89d80375,0xdb2002d2,0xc24018bc}},	//   yurg, פחתי, _átæk, ынык, 
   {{0xe1f800f7,0xd6d8033f,0xe50800f1,0x28e008df}},	//   згө_, _siły_, _تيلو_, नाति, 
   {{0x7b00007d,0x201800db,0xa91001e4,0xd6d8012d}},	//   _jõud, úria_, mpɾe, _piły_, 
   {{0x4dd40066,0x00000000,0x00000000,0x00000000}},	//   رتحس, --, --, --, 
   {{0xfafc145e,0x00000000,0x00000000,0x00000000}},	//   _alë_, --, --, --, 
   {{0x1c3802bf,0x8fd0446e,0xbeb8017a,0x00000000}},	//   дять_, _сәпә, roër, --, 
   {{0x7b00007d,0x6134004e,0x88c401d5,0x00000000}},	//   _nõud, sàlt, کترل, --, 
   {{0x6b9d1978,0xc8940640,0x3b0400d8,0x00000000}},	// [2f5a0] surg, ерењ, хето_, --, 
   {{0xe4f44ff1,0x6ed811a0,0x28e1b2f3,0x65600112}},	//   _अवधि_, याकु, नाधि, _rumh, 
   {{0x65600007,0x98a00022,0x6b9c022e,0x00000000}},	//   _sumh, nohę_, qurg, --, 
   {{0x6560047e,0x7b0000c5,0xda100073,0x85a40798}},	//   _pumh, _rõug, _ठेवत_, ејкд, 
   {{0xdcec010f,0x28e000dc,0x65600477,0xca800150}},	//   _staĉ, नादि, _qumh, _ﺩﻩﺳﻪ_, 
   {{0x03c42555,0xeb2000dc,0x07a40064,0x00000000}},	//   есим, _यदुत_, _пагн, --, 
   {{0x6560014b,0x52bc00e1,0x17c40022,0xbeb80036}},	//   _wumh, ्यूस, _иарҭ, nnëc, 
   {{0x65600810,0x220402b1,0xb95801e1,0x61d80395}},	//   _tumh, hūhū_, _osìl, дмия_, 
   {{0xc0c80063,0x00000000,0x00000000,0x00000000}},	//   пуне_, --, --, --, 
   {{0xf9900375,0x7b000037,0xb7e400cc,0x71f400ae}},	//   נרת_, _tõug, _গেটত_, عريس_, 
   {{0x7c380198,0xdea001b9,0x00000000,0x00000000}},	//   ƙuri, لیغی, --, --, 
   {{0x6d40019f,0x032402e8,0x7b000254,0x6ed821b8}},	//   îman, _яден, _kõue, यागु, 
   {{0x7b00000d,0x00000000,0x00000000,0x00000000}},	//   _jõue, --, --, --, 
   {{0xba500051,0x00000000,0x00000000,0x00000000}},	//   _nữaa, --, --, --, 
   {{0x3a3c0306,0x7b00000d,0x6fb4030d,0x00000000}},	//   _šup_, _lõue, _пăрç, --, 
   {{0x3f9db2f4,0x6c54ada8,0x9f3401ec,0xdfd000ec}},	//   mutu_, уксу, _шейі, _ميڪ_, 
   {{0x3f9db2f5,0x7b0000af,0x00000000,0x00000000}},	// [2f5b0] lutu_, _nõue, --, --, 
   {{0xa3e0012c,0x7b0000c5,0xefcc01f3,0x1bf40153}},	//   दमा_, _sõud, ባብዌ_, _апоў, 
   {{0x3f9db2f6,0xdb04037e,0x9734158b,0x7b000254}},	//   nutu_, _ophø, نکرا, _põud, 
   {{0x3f9c00b0,0x238c0118,0xfafc036e,0x15b80137}},	//   iutu_, děj_, _ulë_, дыкы_, 
   {{0x3f9db2f7,0x00000000,0x00000000,0x00000000}},	//   hutu_, --, --, --, 
   {{0x799c0309,0x7aec0051,0x00000000,0x00000000}},	//   muqw, _hoct, --, --, 
   {{0x67d41719,0x799c009a,0xefcc02d3,0x3f9db2f8}},	//   _йору, luqw, ባብዕ_, jutu_, 
   {{0x3f9db2f9,0x00000000,0x00000000,0x00000000}},	//   dutu_, --, --, --, 
   {{0x7aedb2fa,0x96340276,0xa2b800dc,0x20180162}},	//   _moct, _рнац, ्यज्, úrin_, 
   {{0x3f9c3495,0xa61423c5,0x00000000,0x00000000}},	//   futu_, _смуч, --, --, 
   {{0x3f9db2fb,0x799c0b6f,0x52b400c6,0xd00802e8}},	//   gutu_, huqw, _لماذ, фене_, 
   {{0x7aedb2fc,0x52140305,0x799db2fd,0x00000000}},	//   _noct, _идет, kuqw, --, 
   {{0x3f9c0607,0xa47c0023,0xdbd408a5,0x929c012d}},	//   autu_, _ጥንቃቐ_, _gúúr, chła, 
   {{0x3f9db2fe,0xaca40521,0x50c400cd,0x25f4202e}},	//   butu_, kwụk, _वसिष, ्नती_, 
   {{0x7aec01e0,0x3f9db2ff,0xfce1b300,0x0ea80b72}},	//   _boct, cutu_, шоро, _कापड, 
   {{0x7aedb301,0x69c0006a,0x2fc40280,0x097812c4}},	//   _coct, _âmek, _isng_, дёжь_, 
   {{0x7aed2446,0xcd2800d8,0xa25c0023,0x00000000}},	// [2f5c0] _doct, _ожие_, ኰንኩን_, --, 
   {{0x273cc476,0x2fc4020c,0x2d800112,0x50d000cd}},	//   míni_, _ksng_, _iwie_, तयिष, 
   {{0x2d80016b,0x176802dd,0x8b2400c0,0x068400f3}},	//   _hwie_, еріп_, _адне, вген, 
   {{0x7aed264c,0x7b000254,0x28e002c3,0x2d80012d}},	//   _goct, _põue, नाहि, _kwie_, 
   {{0x3f9c0230,0x84e40212,0xe4b81cb8,0xb6a00353}},	//   zutu_, кодж, еллі_, ричл, 
   {{0x69c40086,0x3f9db302,0x349014a8,0xd90c0133}},	//   mwie, yutu_, аашр, _فیق_, 
   {{0x37e1b303,0x69c4068f,0x224023cc,0x6aa40083}},	//   _корг, lwie, _šik_, ogif, 
   {{0x6aa5b304,0x28e00c00,0x3f9d8e9b,0x69c4033f}},	//   ngif, नावि, vutu_, owie, 
   {{0x4430006d,0x2d80016b,0x3f9db305,0x00000000}},	//   ły_, _nwie_, wutu_, --, 
   {{0x20180798,0xa2b8102f,0xd36c0372,0x69c4017a}},	//   úrio_, ्यङ्, زۇۇ_, iwie, 
   {{0x2d80016b,0x69c4101d,0x6aa40175,0x2fc400ef}},	//   _awie_, hwie, kgif, _csng_, 
   {{0x3f9db306,0x799c0784,0x30102cfe,0x69c5b307}},	//   rutu_, yuqw, рдюр, kwie, 
   {{0x3f9db308,0x52744f52,0x6aa4037e,0x41041677}},	//   sutu_, _суху, dgif, _издв, 
   {{0x3f9db309,0x2d800034,0xb22004a9,0x7aec0067}},	//   putu_, _dwie_, _әмәл, _soct, 
   {{0x7ce80730,0x6aa4037e,0x2d80039a,0x7aec0122}},	//   _kürz, fgif, _ewie_, _poct, 
   {{0x799c0227,0x69c40732,0x1a6443fb,0x6aa5b30a}},	//   tuqw, fwie, طیسی_, ggif, 
   {{0x69c5b30b,0x7ce83713,0x79a402e8,0x58d86206}},	// [2f5d0] gwie, _mürz, ърве, ндая_, 
   {{0x6aa40083,0x00000000,0x00000000,0x00000000}},	//   agif, --, --, --, 
   {{0xccf0025f,0xfd1000dd,0x69c40428,0x37a8e1fa}},	//   _הכי_, _مجھ_, awie, ьтан_, 
   {{0x7bd40327,0x69c5b30c,0x6aa40175,0x0c7000e5}},	//   _irxu, bwie, cgif, _نگہد, 
   {{0xf7700d28,0xa634160b,0xa3c805f9,0x799c02d1}},	//   _چار_, анці, _लैब_, quqw, 
   {{0xf771b30d,0x271800b0,0x00000000,0x00000000}},	//   _نار_, rōna_, --, --, 
   {{0x660c016b,0x28e05a30,0xb6c400ee,0x6900013d}},	//   _ɑnkɑ, नारि, _исай, _köen, 
   {{0x777402c4,0xd1c96e66,0xdb1c020c,0xca74022e}},	//   mpxx, елие_, èyèl, boyе, 
   {{0xdcec0114,0xd4b83591,0x95d802e8,0xb634eead}},	//   _atač, _плац_, _ядат_, _شعرت, 
   {{0x0ccc00bd,0x9f4c02f0,0x00000000,0x00000000}},	//   _রক্ত, vydá_, --, --, 
   {{0xb4cc0574,0x8fd0053f,0x69c4033f,0x3ce400dc}},	//   षयी_, сәлә, zwie, ञाने_, 
   {{0x2055b30e,0xb8ec0003,0x98b80166,0x7ce82a9b}},	//   штыр, _ྱི_, _mtsı_, _gürz, 
   {{0x6aa41121,0x333db30f,0xc330008d,0xf1b402c3}},	//   vgif, mlux_, _פוד_, _अहिन, 
   {{0x333db310,0x25a000a3,0x00000000,0x00000000}},	//   llux_, àili_, --, --, 
   {{0x6aa54484,0x3a2800ac,0x2d44002f,0xfc003d2a}},	//   tgif, _axcp_, böen_, бпро, 
   {{0x69c5b311,0x2d80017a,0x00000000,0x00000000}},	//   twie, _twie_, --, --, 
   {{0x6f05b312,0x4a44016c,0xbb41b313,0x2d80003e}},	// [2f5e0] _ilic, унав, сетк, _uwie_, 
   {{0x9db8081f,0xcc34121a,0x69c422ef,0x75200175}},	//   _བརྗེ, _مرجع, rwie, jnnz, 
   {{0x6f040d11,0x6aa404f3,0x69c5b314,0x333c0327}},	//   _klic, pgif, swie, klux_, 
   {{0xbc1800c8,0x86248ca3,0x387c16a3,0x69c4017a}},	//   _טויש, льле, _đure_, pwie, 
   {{0x6f044b44,0x73d402dd,0x333c031c,0xaf880b82}},	//   _mlic, ғдыр_, dlux_, _መደብና_, 
   {{0x2b41b315,0x6f040228,0xa4d401ce,0xa3f402bf}},	//   llic_, _llic, рокі, иплі, 
   {{0x6f040c8c,0xd90db316,0x00000000,0x00000000}},	//   _olic, _تیل_, --, --, 
   {{0xa2f448a4,0x7ce800a2,0x6f04002f,0x02a4010b}},	//   рпич, _düry, _nlic, уркм, 
   {{0xdcec278a,0x7b0000af,0xb88001f1,0x36f40375}},	//   _stač, _jõua, bríč, _עצמם_, 
   {{0x7ce9b317,0x6f0458b7,0xa6c801e0,0xdcec0118}},	//   _würz, _alic, _ялға_, _ptač, 
   {{0x6f05b318,0x2b4009a8,0x7b000037,0x929c033f}},	//   _blic, klic_, _lõua, chło, 
   {{0x6f040082,0x9f345566,0x333c01f5,0x2b400841}},	//   _clic, ремі, clux_, jlic_, 
   {{0x6f040589,0x7b00007d,0x443db319,0x2b40013a}},	//   _dlic, _nõua, _hyt_, dlic_, 
   {{0x273c02fb,0x2b407876,0x443d470a,0x690000fd}},	//   mínu_, elic_, _kyt_, _söen, 
   {{0x6f05b31a,0x273c5768,0x443c017a,0x8c3801f0}},	//   _flic, línu_, _jyt_, ворӣ_, 
   {{0x443db31b,0x2ee004cc,0x2b400427,0xda0801e2}},	//   _myt_, _gnif_, glic_, نيزه_, 
   {{0x443db31c,0x0ea801f9,0x00000000,0x00000000}},	// [2f5f0] _lyt_, _कातड, --, --, 
   {{0x6f05b31d,0x644801a9,0xf80448e5,0x5fa86956}},	//   _zlic, _ozdi, лчен, _कमाल, 
   {{0x443db31e,0x333c0a40,0x200c0007,0x6eac05f9}},	//   _nyt_, ylux_, nzdi_, _झामु, 
   {{0x7f5c01a9,0x2b41b31f,0x00000000,0x00000000}},	//   _jiqq, clic_, --, --, 
   {{0xa68410f5,0x443db320,0xd5e42dbf,0x64482791}},	//   слід, _ayt_, ржли, _azdi, 
   {{0x443db321,0x667404a9,0xb4cc0882,0x7f5c01a9}},	//   _byt_, لدۇر, षये_, _liqq, 
   {{0x2bd9b322,0x69000254,0x443c0210,0x00000000}},	//   डिया, _möel, _cyt_, --, 
   {{0xe6108a54,0x200c0810,0x7f5c0165,0x3720004b}},	//   _کشف_, dzdi_, _niqq, _اورې, 
   {{0x443c0139,0xb88000d0,0x6f04002f,0x7d14007c}},	//   _eyt_, príč, _rlic, _omxs, 
   {{0x2ee1b323,0x4fc00075,0x443db324,0x6f04a2ac}},	//   _snif_, قەتە, _fyt_, _slic, 
   {{0x50440224,0x4f240697,0x443c722a,0xa1e81075}},	//   ренб, идоб, _gyt_, _ەرىك_, 
   {{0xbcf804fb,0xe2c80b24,0x273c20ab,0x00000000}},	//   mpéy, _مومو_, bínu_, --, 
   {{0x7f5db325,0xfafc017a,0x273c0306,0x3f880055}},	//   _diqq, _kiëf_, cínu_, _āhuś_, 
   {{0x068804a9,0x4e94034c,0x645c3822,0xc198011a}},	//   _ﻗﯩﻠﯩ, دشگر, _úric, _ישני, 
   {{0xcb680b7e,0x6b6c00e4,0x7b00000d,0x2b400010}},	//   табе_, _ẽmbý, _sõua, tlic_, 
   {{0x2b41b326,0xdd9800d0,0x7b00000d,0x8e740139}},	//   ulic_, šňa_, _põua, _тукч, 
   {{0x49c9b327,0x2b401c2e,0x888474df,0x7a64009d}},	// [2f600] ълан_, rlic_, илаж, риуг_, 
   {{0xaa480132,0xb4cc00cd,0x00000000,0x00000000}},	//   _ەسسە_, षयो_, --, --, 
   {{0x2b4034fe,0x273c02fb,0x7f5c8e61,0x48580006}},	//   plic_, zínu_, _yiqq, траў_, 
   {{0x7f5c0752,0x98545c74,0x443db328,0x7b000254}},	//   _xiqq, стуш, _ryt_, _tõua, 
   {{0xfb3400c8,0x443d3070,0x3d2803e6,0x69000108}},	//   _כאטש_, _syt_, _ستیی_, _yöel, 
   {{0x443db329,0x7b000254,0xa2a001ec,0x23480133}},	//   _pyt_, _jõun, _ﺍﻋﺘﺒ_, گستی_, 
   {{0x2918004e,0xe3b86656,0xf36076d0,0xdddc0419}},	//   _imra_, _axır_, отын, masť, 
   {{0xb6a01e2d,0x7b00007d,0xd1e40020,0x644801f1}},	//   _мисл, _lõun, ምጣት_, _vzdi, 
   {{0x9f58110e,0x443db32a,0x7f5c374a,0x325002e8}},	//   árí_, _wyt_, _riqq, овър, 
   {{0x443c05b1,0x7b0000c5,0x7f5c014f,0x273db32b}},	//   _tyt_, _nõun, _siqq, rínu_, 
   {{0x644805a1,0x2918013b,0x443c01f5,0xe01800d4}},	//   _uzdi, _mmra_, _uyt_, ужні_, 
   {{0xd04000ac,0x273db32c,0x7f5c0175,0x69000139}},	//   ndlə, míns_, _qiqq, _söel, 
   {{0x7e445e3e,0x7e280212,0xa6d803d4,0x999801ef}},	//   рхне, тіна_, _থকাট, _rysů_, 
   {{0xd0400213,0x00000000,0x00000000,0x00000000}},	//   hdlə, --, --, --, 
   {{0x7bc401a4,0x7f5c047e,0x3b18003a,0xfca85295}},	//   uwju, _tiqq, tiqq_, _یادو_, 
   {{0x2919b32d,0x69d80882,0x7bc4045f,0xba7418fd}},	//   _amra_, āven, rwju, شارت, 
   {{0x98b8354f,0x6e4402dd,0xa3c809bb,0xe9f800d4}},	// [2f610] ллат_, _ونىم, _लैस_, анті_, 
   {{0xe94401f0,0xcf8c0345,0x273c00e5,0x00000000}},	//   оххо, _تژی_, zínt_, --, 
   {{0xdd840150,0x00000000,0x00000000,0x00000000}},	//   _тықп, --, --, --, 
   {{0x9db8003d,0x291802d3,0x7c383535,0xfafc0036}},	//   _བརྙེ, _emra_, ğurd, _siëf_, 
   {{0xc68c0014,0x00000000,0x00000000,0x00000000}},	//   رِو_, --, --, --, 
   {{0xa8a4009b,0x00000000,0x00000000,0x00000000}},	//   _мрск, --, --, --, 
   {{0xc9500375,0xf62800db,0x00000000,0x00000000}},	//   _ממך_, رتچۇ_, --, --, 
   {{0x972405c6,0xe784299f,0x2bd8c488,0x32480023}},	//   _افرو, _фуро, डिता, _ብስልጣ, 
   {{0x92381f39,0x00000000,0x00000000,0x00000000}},	//   ычку_, --, --, --, 
   {{0xd1080517,0xb4000220,0xbeb80036,0xe6100014}},	//   اقده_, _мүлд, hiëd, _کشہ_, 
   {{0xb4c0012d,0x00000000,0x00000000,0x00000000}},	//   एजी_, --, --, --, 
   {{0x81c403f4,0x356402d3,0xb900031c,0x69c000e4}},	//   _উপর_, _ኲነታት_, _ྩལ_, _ãmeg, 
   {{0x2d842047,0x3f9c581e,0x7e780309,0x6900013d}},	//   ème_, artu_, ñupa, _söem, 
   {{0x8238010f,0x61e40064,0x00000000,0x00000000}},	//   _גענצ, _šilg, --, --, 
   {{0x3f9c0552,0xd0400213,0x59a4012d,0x00000000}},	//   crtu_, ydlə, गूसर, --, 
   {{0x387c009b,0x213c01a6,0x81a8015b,0xfe74013e}},	//   _đura_, _zkvh_, খবর_, _гӯё_, 
   {{0x61e401ab,0xcdf5045c,0x0a48b27b,0x00000000}},	// [2f620] _àilt, _ычкы, узай_, --, 
   {{0x202801a6,0x0888007b,0x00000000,0x00000000}},	//   štiš_, اناً_, --, --, 
   {{0xaa6401af,0x00000000,0x00000000,0x00000000}},	//   _менһ, --, --, --, 
   {{0x7b00007d,0x273c54fc,0x69000166,0x00000000}},	//   _jõul, víns_, _köek, --, 
   {{0xd04000ac,0x00000000,0x00000000,0x00000000}},	//   rdlə, --, --, --, 
   {{0x273c1709,0x2919b32e,0x00000000,0x00000000}},	//   tíns_, _umra_, --, --, 
   {{0xd49800d4,0x80d01bd6,0x78a003b2,0x00000000}},	//   ррі_, _भोगे, ónve, --, 
   {{0x273c0005,0x929c033f,0x2cb80175,0x0564119e}},	//   ríns_, ykłe, hfrd_, _гван, 
   {{0xc604036b,0xd5740354,0x00000000,0x00000000}},	//   _узай, _духь, --, --, 
   {{0x61e4003d,0x00000000,0x00000000,0x00000000}},	//   _ġild, --, --, --, 
   {{0x61e402d5,0x11f4036b,0x3f9c0067,0xca2402dd}},	//   _šild, متیگ, urtu_, _ﺠﻬﺔ_, 
   {{0xb7d8008d,0x004002d3,0x6900013d,0x00000000}},	//   אקטי, _ማዕከና, _böek, --, 
   {{0xf1cc00bc,0x733800df,0x00000000,0x00000000}},	//   _तैपन, _געאס, --, --, 
   {{0x6280002f,0x00000000,0x00000000,0x00000000}},	//   lbmo, --, --, --, 
   {{0xb4f80bd9,0x237c0175,0x2d840129,0x00000000}},	//   נפלי, npvj_, âmer_, --, 
   {{0xbeb801f5,0x28a40022,0xde7000b8,0x00000000}},	//   fiëe, ҧшхг, bjāṃ_, --, 
   {{0x98e4007b,0x00000000,0x00000000,0x00000000}},	// [2f630] يكرو, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf8495dfe,0x6b5800c8,0x225800bc,0x00000000}},	//   учай_, _aŭgu, ěrky_, --, 
   {{0x19c40075,0x95d8005b,0x3ea80051,0xe6100066}},	//   _мәзг, идет_, ngct_, کشم_, 
   {{0x2d840005,0x7b000254,0x2b4401c4,0x00000000}},	//   ámex_, _jõum, _хээг, --, 
   {{0xd7c800aa,0x01ac00cc,0x45a00c75,0x00000000}},	//   _پوره_, কবাদ, بەكك, --, 
   {{0x05140597,0x43700244,0xd1dc0092,0x00000000}},	//   تيوب_, وهور, ንዲት_, --, 
   {{0x37c0c7e0,0xd5880354,0x00000000,0x00000000}},	//   _мәҗб, _гiай, --, --, 
   {{0x11e400d4,0x00000000,0x00000000,0x00000000}},	//   іжом, --, --, --, 
   {{0x25a000ae,0x3f9000cd,0x21740395,0x00000000}},	//   áile_, _āyur_, чуър, --, 
   {{0xcee87136,0x62800158,0xe2c801d5,0x6901b32f}},	//   адне_, bbmo, _گونو_, _söek, 
   {{0xc7d40375,0x25a00bb3,0xd10801b9,0x24580124}},	//   קורי_, šile_, اقگه_, _уахь_, 
   {{0x551c07f7,0x00000000,0x00000000,0x00000000}},	//   _भगाए_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7b000254,0x00000000,0x00000000,0x00000000}},	//   _tõul, --, --, --, 
   {{0x28acd07f,0x3ea8074d,0x8a0406d4,0x0b44187f}},	//   _चाहि, cgct_, озбе, інан, 
   {{0x3b0464e1,0x00000000,0x00000000,0x00000000}},	// [2f640] цето_, --, --, --, 
   {{0xbeb801f5,0x7b00000d,0x6a840075,0x0ea800bc}},	//   riëe, _jõuj, юлға, _काँड, 
   {{0xca6401a9,0xd90c01d3,0xb7b000db,0x00000000}},	//   _imkо, ھیہ_, мөтч, --, 
   {{0xb6000122,0x09e410e2,0xbeb801f5,0xd90c01d3}},	//   _omáč, _домн, piëe, پیہ_, 
   {{0xdbd40162,0xd5ac0050,0xa81800ec,0x00000000}},	//   _húðr, ێہہ_, _ڏڪار_, --, 
   {{0xb6000030,0xaf700092,0x00000000,0x00000000}},	//   úšan, _ወደሚገ, --, --, 
   {{0x0ea806ab,0xd5ac0014,0x0b980139,0x00000000}},	//   _कांड, َہہ_, _üñış, --, 
   {{0x6cf800bc,0x00000000,0x00000000,0x00000000}},	//   ुसँग_, --, --, --, 
   {{0x61e400f3,0xc0c40063,0xf5e40451,0xdbd41d1d}},	//   _šilb, ољни, _وڙهي_, _lúðr, 
   {{0x43940022,0x00000000,0x00000000,0x00000000}},	//   _ҳаҧс, --, --, --, 
   {{0xd344004b,0x436821fa,0x036801ec,0xf1f44d66}},	//   _ډیوه_, _таен_, _тиек_, معیت_, 
   {{0x1ccc031c,0x9e34013d,0x00000000,0x00000000}},	//   _ླིང_, земч, --, --, 
   {{0xd490004d,0x6cf800bc,0x217801ee,0x00000000}},	//   _hòa_, ुसंग_, _уйлы_, --, 
   {{0x387c041a,0x257008c2,0xc0c00131,0xdd5801c6}},	//   _đuro_, _màl_, ﯩﻴﻪﺗ, сагч_, 
   {{0xb6000118,0x60c81496,0x00000000,0x00000000}},	//   _zmáč, medm, --, --, 
   {{0xdd9000c6,0x60c8035a,0xae1c0037,0x00000000}},	//   _كوب_, ledm, _पेवन_, --, 
   {{0x6b5801e4,0x2c200092,0x00000000,0x00000000}},	// [2f650] _aŭgs, ደሚገኝ, --, --, 
   {{0x60c8127b,0x6ebc2802,0x00000000,0x00000000}},	//   nedm, ष्ठु, --, --, 
   {{0xb8d0acd2,0x7b0000c5,0x28ac185d,0x1fa8072a}},	//   _टा_, _jõuk, _चारि, _कमोड, 
   {{0x2be00c2e,0x60c8014f,0xdddc00e5,0x00000000}},	//   _पछता, hedm, lcső, --, 
   {{0x257001c3,0x7b000254,0x60c8127b,0x6594004e}},	//   _càl_, _lõuk, kedm, дачу, 
   {{0x929c0034,0x98a002b5,0xd794008e,0x961c00ef}},	//   dkła, rohē_, _нигъ, _jeņi, 
   {{0x7b00007d,0xd25800de,0x60c82ef2,0xb60001ef}},	//   _nõuk, meņi_, dedm, _smáč, 
   {{0x257001ab,0xd184010b,0xae1c000d,0x52741892}},	//   _fàl_, плий, _पइलन_, чуку, 
   {{0x2570004e,0x60c802d0,0xe2a800b3,0xdcfc0205}},	//   _gàl_, fedm, زاين_, htsı, 
   {{0x60c90d9d,0xa3b804fb,0x00000000,0x00000000}},	//   gedm, _ژانر_, --, --, 
   {{0x27180419,0x00000000,0x00000000,0x00000000}},	//   ečny_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x28ac1777,0x00000000,0x00000000,0x00000000}},	//   _चालि, --, --, --, 
   {{0x317c020c,0xa15841bd,0x2bd800bc,0x46380a7c}},	//   mpuz_, _дачу_, डिला, מערע, 
   {{0x7b000254,0x961c00ef,0xd2580171,0x00000000}},	//   _kõuh, _deņi, deņi_, --, 
   {{0xaea40150,0x7b000254,0x9988012d,0x00000000}},	//   _تەحي, _jõuh, dzał_, --, 
   {{0x6ebc2e35,0x80cc00bd,0xddf805f5,0x7c383361}},	// [2f660] ष्णु, ়ার্, _дээш_, ğura, 
   {{0x291c180f,0x2c9443fb,0x17180327,0x39400150}},	//   òva_, _زیرآ, ྱིའམ_, енуг, 
   {{0x78a02242,0x929c0034,0x257001c3,0x3cf8011a}},	//   ónva, zkła, _sàl_, _הלינ, 
   {{0x60c8006d,0x257000db,0x248c00bc,0x00000000}},	//   zedm, _pàl_, _sedm_, --, 
   {{0xa4d402bf,0xd25800ef,0x00000000,0x00000000}},	//   долі, beņi_, --, --, 
   {{0xf4900075,0xd90c02f2,0x60c803ac,0x00000000}},	//   ىشىد, _پیم_, xedm, --, 
   {{0x60c84675,0xc76402dd,0x9988012d,0x00000000}},	//   vedm, _ءاسى, czał_, --, 
   {{0x04fc0154,0x3394007b,0x00000000,0x00000000}},	//   ্চের_, أخوة_, --, --, 
   {{0xbeb80240,0x7b000254,0x15b000db,0x60c8127b}},	//   onëv, _sõuk, _لەنس, tedm, 
   {{0x6aa802ab,0xf4845d95,0xd490004d,0x79f8011a}},	//   गलुर, _فامی, _tòa_, צליח, 
   {{0x60c9b330,0x9f341d31,0x201835f5,0xd4900051}},	//   redm, дені, àri_, _kòn_, 
   {{0xdd95b331,0x60c9b332,0x3f8002f0,0xe4e00037}},	//   мамы, sedm, ďku_, _गोति_, 
   {{0xdb0400d2,0x7c841d0f,0x60c802d0,0x80240633}},	//   _mphô, зубе, pedm, ترکم, 
   {{0x7b0000c5,0x9d1801c6,0x00000000,0x00000000}},	//   _tõuk, цогт_, --, --, 
   {{0x6c5404b0,0x6aa801ef,0x00000000,0x00000000}},	//   екру, गलूर, --, --, 
   {{0x82e8031c,0x00000000,0x00000000,0x00000000}},	//   _འོསའ, --, --, --, 
   {{0x58d41ee3,0x2aa8013e,0xdddc01d3,0xd25800e2}},	// [2f670] моат, ятро_, pcső, teņi_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xda1800c5,0xacfc011a,0x00000000,0x00000000}},	//   _धधकत_, _להזכ, --, --, 
   {{0xd49001fb,0xfaa400c2,0x9988012d,0xbeb8036e}},	//   _còn_, _эшон, rzał_, anëv, 
   {{0x1958023a,0xb13c02d3,0xd46853ab,0x9988012d}},	//   _мамы_, _ኣሃዱታ, оиле_, szał_, 
   {{0x63b80208,0xaad401e1,0x00000000,0x00000000}},	//   ftvn, _àmòó_, --, --, 
   {{0x33600075,0xd7d00037,0x00000000,0x00000000}},	//   ىنتې, _सनिच, --, --, 
   {{0x11e4c731,0x61e40024,0xd2a8023a,0xd4900051}},	//   джим, _šila, цкие_, _gòn_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x317c0790,0x212c01ab,0xbb4801ec,0x00000000}},	//   rpuz_, gndh_, _ﻁﺭﻑ_, --, 
   {{0x75200399,0x8fd07b80,0x00000000,0x00000000}},	//   minz, тәлә, --, --, 
   {{0x212c01ab,0x00000000,0x00000000,0x00000000}},	//   andh_, --, --, --, 
   {{0x6900000d,0x8d74277d,0x333c0129,0x1e940276}},	//   _köet, باجا, moux_, эрэр, 
   {{0x7520021a,0xd00800a8,0xcb69b333,0x333db334}},	//   ninz, _меле_, жаве_, loux_, 
   {{0x7054074d,0x00000000,0x00000000,0x00000000}},	//   _хĕве, --, --, --, 
   {{0x7521b335,0x333c004a,0xbeb8257c,0x31642305}},	//   hinz, noux_, liën, _hinz_, 
   {{0x3165b336,0xbb4011dc,0x8d5402bf,0x7e98011a}},	// [2f680] _kinz_, тетк, _оточ, _וספו, 
   {{0x8d7401d9,0x333c0129,0xbeb80200,0x00000000}},	//   _ٹاکا, houx_, unëv, --, 
   {{0x6d5db337,0x3164dfb5,0x7520495a,0xd258005f}},	//   mmra, _minz_, dinz, meņu_, 
   {{0x3165b338,0x333db339,0x46480a83,0xfafc04e6}},	//   _linz_, joux_, озен_, _hiën_, 
   {{0xba749349,0x333db33a,0x7520002d,0x2b41b33b}},	//   _تاپت, doux_, finz, moic_, 
   {{0x31640399,0x2b400332,0x00000000,0x00000000}},	//   _ninz_, loic_, --, --, 
   {{0xbeb80196,0x00000000,0x00000000,0x00000000}},	//   diën, --, --, --, 
   {{0x68fdb33c,0x6d5c0649,0x2b404f1a,0x75200099}},	//   _hord, hmra, noic_, ainz, 
   {{0x68fdb33d,0x7521755a,0x31640b8b,0x452801af}},	//   _kord, binz, _binz_, _джан_, 
   {{0x75200622,0xbeb9b33e,0x6d5c0e3c,0x00000000}},	//   cinz, giën, jmra, --, 
   {{0x65688ebb,0x333c0007,0xd25800de,0x22a401d5}},	//   _iidh, boux_, deņu_, _зулҳ, 
   {{0x6569b33f,0x7410004b,0x6d5db340,0x68fc0e21}},	//   _hidh, _جوما, emra, _lord, 
   {{0x68fdb341,0x31640268,0x65680832,0x64480030}},	//   _oord, _finz_, _kidh, _hydi, 
   {{0x6569b342,0xbeb80196,0x316401e4,0x7b00000d}},	//   _jidh, ciën, _ginz_, _jõuv, 
   {{0x65687361,0xfafc0036,0x00000000,0x00000000}},	//   _midh, _diën_, --, --, 
   {{0x6568069c,0x7520016e,0x6449b343,0x60d9b344}},	//   _lidh, zinz, _mydi, _havm, 
   {{0x68fcb183,0x2dd410e0,0x656865f2,0x75200c8a}},	// [2f690] _bord, _ажыр, _oidh, yinz, 
   {{0x68fdb345,0x6569b346,0x782400db,0x60d8047e}},	//   _cord, _nidh, وعال, _javm, 
   {{0x68fdb347,0x7521b348,0x333c0369,0x00000000}},	//   _dord, vinz, youx_, --, 
   {{0x6569b349,0x75200810,0x68fc035a,0x60d9b34a}},	//   _aidh, winz, _eord, _lavm, 
   {{0x7521b34b,0x6569b34c,0x644821d8,0xf1c0013a}},	//   tinz, _bidh, _aydi, _košů_, 
   {{0x60d9b34d,0x64480158,0x68fc1e56,0x9474cdc2}},	//   _navm, _bydi, _gord, ردتا, 
   {{0x6569b34e,0x64480042,0xd78803e6,0x04405b0f}},	//   _didh, _cydi, _رچاو_, лешн, 
   {{0x68fc23ee,0x75205b70,0x644802d5,0x31640007}},	//   _zord, sinz, _dydi, _sinz_, 
   {{0x333db34f,0x68fdb350,0xbeb9b351,0x7521b352}},	//   roux_, _yord, tiën, pinz, 
   {{0x68fc172e,0x6569b353,0x333c0129,0x2b406a3a}},	//   _xord, _gidh, soux_, zoic_, 
   {{0x31649ec6,0xbeb82e6c,0x6449b354,0x68f80267}},	//   _vinz_, riën, _gydi, övdi, 
   {{0xbeb80660,0xd1780220,0x6568009f,0xd4900208}},	//   siën, _ескі_, _zidh, _hè_, 
   {{0x65680a81,0x72741ee0,0xd25800e2,0x64480064}},	//   _yidh, _ተሳታፊ_, teņu_, _zydi, 
   {{0x65680a81,0x60d82af2,0xfaa00032,0x22540137}},	//   _xidh, _gavm, ҫаро, _شئنح, 
   {{0x6d5c03ac,0x8e7400f3,0x00000000,0x00000000}},	//   rmra, _пупч, --, --, 
   {{0xfafc0036,0xbeb80430,0x6d5c03ac,0xbb405b6d}},	//   _wiën_, niël, smra, геск, 
   {{0x68fdb355,0x637c00e4,0x0e6401b9,0x60d8014f}},	// [2f6a0] _pord, _tĩng, _якин, _yavm, 
   {{0x2d800022,0x68fc0978,0xc79508a4,0xd4900208}},	//   _itie_, _qord, ерды, _nè_, 
   {{0x68fd0744,0xcd00068f,0x690021c6,0x9f3401d3}},	//   _vord, ęść_, _böer, _سویڈ, 
   {{0x68fdb356,0x6569b357,0xb90404fa,0x64481979}},	//   _word, _sidh, _मो_, _rydi, 
   {{0x6569b358,0x99740022,0x2bd80864,0xd6d8033f}},	//   _pidh, _аусш, डिका, _dał_, 
   {{0x9f580491,0x68fc0c86,0x65680455,0xd1e8001f}},	//   árú_, _uord, _qidh, ጅነት_, 
   {{0x65680a28,0x37e00166,0x60d80174,0x27b40022}},	//   _vidh, _йорг, _ravm, _шәас, 
   {{0x2d81240e,0x6569b359,0xfafc0ea0,0x64480030}},	//   _otie_, _widh, _niël_, _vydi, 
   {{0x65694f9f,0x2d80003e,0x60d80477,0x6449b35a}},	//   _tidh, _ntie_, _pavm, _wydi, 
   {{0x644803d4,0x60f80212,0x65680192,0x60d816a5}},	//   _tydi, єння_, _uidh, _qavm, 
   {{0x2d81b35b,0x6fb401c0,0x60d8014f,0x7b000037}},	//   _atie_, нгэр_, _vavm, _kõut, 
   {{0xbeb80cf9,0x7b0000c5,0x00000000,0x00000000}},	//   ciël, _jõut, --, --, 
   {{0x7c38029f,0x00000000,0x00000000,0x00000000}},	//   ğurm, --, --, --, 
   {{0xdfd0352e,0x637c00e4,0xbeb80036,0x32501cd0}},	//   _نيت_, _tĩnd, tnës, _свір, 
   {{0x645c0086,0xf09004ae,0x2bc92a59,0xc0e00092}},	//   _ùrid, _ענק_, нуто_, ዝናል_, 
   {{0x7b0000af,0xfafc0036,0xead4855f,0x00000000}},	//   _nõut, _giël_, лось, --, 
   {{0x204c1e38,0x387c03f9,0x2d44002f,0x25a00332}},	// [2f6b0] _ማሕበረ, _ƙur_, röer_, áill_, 
   {{0xa9a40075,0x273c0122,0xaa640ea7,0xe4e00dba}},	//   املى, míny_, утск, _गोलि_, 
   {{0x569434d8,0x273c02fb,0xcd0000b8,0xf090008f}},	//   вает, líny_, _daśā_, רנע_, 
   {{0x7bd40009,0xb7440133,0x00000000,0x00000000}},	//   _isxu, رئاو, --, --, 
   {{0x273c71f0,0xe5781ac3,0x7c641e4b,0x00000000}},	//   níny_, езі_, _تاکل, --, 
   {{0xfafc0151,0xbeb80036,0xd6d8012d,0x00000000}},	//   _hoë_, wiël, _wał_, --, 
   {{0xdce4151c,0xbeb801a4,0x69000166,0xa93401f0}},	//   _nihč, tiël, _töer, _серш, 
   {{0x23340022,0x00000000,0x00000000,0x00000000}},	//   лхыр, --, --, --, 
   {{0x41b1b35c,0xbeb9b35d,0x3f8c0c3a,0x61e400c6}},	//   لمير, riël, _awfu_, _áill, 
   {{0x4100b5d4,0x798c514c,0xbeb80af9,0x7b000037}},	//   изыв, _mwcw, siël, _kõus, 
   {{0x2d81b35e,0x7b00007d,0x69d80034,0xc9500375}},	//   _stie_, _jõus, _नैनी, שמי_, 
   {{0xe2900491,0x20541b15,0x00000000,0x00000000}},	//   _هذه_, ытыр, --, --, 
   {{0xc3300302,0x273c0122,0x798c0076,0x7b000254}},	//   _דוא_, gíny_, _nwcw, _lõus, 
   {{0x10a40798,0x41b00345,0x00000000,0x00000000}},	//   _рикн, _ئمور, --, --, 
   {{0x7b00007d,0xe0d0105d,0xfafc0af9,0xf0000116}},	//   _nõus, _دزن_, _boë_, _сүни, 
   {{0xfaa0e846,0x273c00d0,0x00000000,0x00000000}},	//   иасо, bíny_, --, --, 
   {{0x273c02fb,0x2d80009f,0x798c0142,0x00000000}},	// [2f6c0] cíny_, _utie_, _cwcw, --, 
   {{0x98b80166,0xcc8800f1,0x99140816,0x00000000}},	//   _busı_, _تنده_, льхі, --, 
   {{0xd944007b,0xcd0000b8,0x2c2000cc,0x00000000}},	//   ائقي, _vaśā_, _মুৰে_, --, 
   {{0xfafc0036,0x86240166,0x00000000,0x00000000}},	//   _goë_, кьле, --, --, 
   {{0xdb0c032e,0x3ce40b26,0x00000000,0x00000000}},	//   _íhás, _छोडे_, --, --, 
   {{0x24582cc8,0xfafc0549,0xbeb801c7,0x03c40107}},	//   наль_, _zoë_, hnëp, всим, 
   {{0x273c02fb,0xbeb80036,0x6b9c0175,0x7b00000d}},	//   zíny_, knëp, nsrg, _tõut, 
   {{0x8ca000cd,0x00000000,0x00000000,0x00000000}},	//   कृतो, --, --, --, 
   {{0x05641dbc,0xc5645822,0x7b000254,0x973401c6}},	//   _аван, _акак, _kõur, _сэрч, 
   {{0xa6c80032,0x273c02f0,0xf990011a,0x00000000}},	//   _юлға_, víny_, סרת_, --, 
   {{0xd140012d,0x4428007c,0xf8b0011a,0x11f4029e}},	//   djąć_, _äb_, בשת_, نتیگ, 
   {{0x7c380790,0x273c00d7,0x00000000,0x00000000}},	//   şurk, tíny_, --, --, 
   {{0xdcec010f,0xe1c400ee,0x6bd40066,0x00000000}},	//   _etaĝ, _сөйй, یتفر, --, 
   {{0xfafc01c7,0xed5802d5,0x273c02fb,0x98a002b5}},	//   _soë_, коў_, ríny_, rohī_, 
   {{0xff3407dd,0x57d0574f,0xbff001c6,0xac95b35f}},	//   _аҟны_, _सनेह, _түнш, расш, 
   {{0xdfd00451,0x273c0306,0x61e4025c,0x798c03ac}},	//   _نيڪ_, píny_, _ġilj, _pwcw, 
   {{0x61e407f5,0x7e780309,0x00000000,0x00000000}},	// [2f6d0] _šilj, ñupu, --, --, 
   {{0xf805b360,0x39440042,0xb86403c7,0x00000000}},	//   кчен, ôns_, نااو, --, 
   {{0xba380142,0x67d400d8,0x00000000,0x00000000}},	//   _ddïa, иофу, --, --, 
   {{0x1a651d33,0x2c000316,0x59f80801,0xaa940139}},	//   _میزی_, रहरू_, _земя_, _киюч, 
   {{0xe61076e1,0x7aec02d0,0x8b54011a,0x95c400ae}},	//   يشه_, _inct, _תירס_, ايته, 
   {{0x7b00007d,0xf99c02e2,0x0a280023,0xe83400d7}},	//   _tõus, _ivè_, _ተመሃራ, ňoší, 
   {{0xb765b361,0x00000000,0x00000000,0x00000000}},	//   _атай, --, --, --, 
   {{0xf1b40c2e,0x88014060,0x00000000,0x00000000}},	//   _आमदन, _دېمو, --, --, 
   {{0x7aec25a9,0x395c04cc,0xdcec0115,0xc6900375}},	//   _mnct, _èuss_, _staĝ, _לאן_, 
   {{0xe4d400cf,0x6604000d,0x00000000,0x00000000}},	//   _ۅتۅب, äike, --, --, 
   {{0x7aec06af,0xe4f009ae,0xb4440006,0xd42000fe}},	//   _onct, चारि_, _рэак, _পুৰি_, 
   {{0x910401ec,0x2dc801d5,0x00000000,0x00000000}},	//   _әпке, вқин_, --, --, 
   {{0xe1f039b1,0x9db8008e,0x00000000,0x00000000}},	//   _وسه_, кыру_, --, --, 
   {{0x40240046,0x7aec127b,0x4f24134b,0x64580210}},	//   _өзің, _anct, _әдиб, ściń, 
   {{0xf99db362,0x8db40150,0x00000000,0x00000000}},	//   _avè_, _өспі, --, --, 
   {{0x33e001b8,0x4c840116,0x7e7802d1,0x00000000}},	//   _mıx_, _өлив, ñupt, --, 
   {{0x08c5b363,0x7bc00793,0x387c467d,0x7f38008f}},	// [2f6e0] лбан, _änun, _şura_, _רעפו, 
   {{0x7aec010a,0x61e40024,0x4a7400c7,0x00000000}},	//   _enct, _šilk, _әынт, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd6d80164,0xa685b364,0xc6940736,0xcc8800f2}},	//   кті_, рғай, اشاع, _تنگه_, 
   {{0x96b80884,0x7b000254,0x00000000,0x00000000}},	//   туху_, _tõur, --, --, 
   {{0x940406be,0x34900107,0xaa1400e4,0xfb840345}},	//   _helə_, башр, sẽso, _جدیی, 
   {{0x61980f7c,0xdce400b8,0x00000000,0x00000000}},	//   _ግብራዊ_, _jihā, --, --, 
   {{0xdcec00ac,0x7b000037,0x00000000,0x00000000}},	//   _otağ, _jõup, --, --, 
   {{0x623454c9,0x6115b365,0xd37800f7,0xc4c800a7}},	//   репу, идиу, нчө_, _плаж_, 
   {{0xe42400aa,0x7dd80267,0x7c38e07a,0xd04003b9}},	//   _پکتي, _läså, şuri, lelə, 
   {{0xdcec62c7,0xdef5797b,0x64a40022,0x00000000}},	//   _atağ, апны, _баҕа, --, 
   {{0x41e41d93,0x23600428,0x439400c7,0x7b000037}},	//   _مستف, _òij_, _ааҧс, _nõup, 
   {{0x5275b366,0xddcc012d,0xa1947c3f,0x00000000}},	//   _туху, _szał, _талч, --, 
   {{0xa28000f1,0xc05800c0,0x00000000,0x00000000}},	//   _ایښو, _пій_, --, --, 
   {{0x94040cc1,0x661c03b9,0x6e2000e4,0x61e4013a}},	//   _belə_, _ərka, úmbr, _šilh, 
   {{0x3f9c041e,0x00000000,0x00000000,0x00000000}},	//   mstu_, --, --, --, 
   {{0x3f9db367,0xbd69b368,0x98b80075,0xab380116}},	// [2f6f0] lstu_, _прое_, клат_, упту_, 
   {{0x7ac400ee,0x3f9c000d,0x00000000,0x00000000}},	//   _өсме, ostu_, --, --, 
   {{0xda700014,0xccf0011a,0xd04003e3,0x00000000}},	//   _وُد_, _וכי_, felə, --, 
   {{0x7aedb369,0x3f9db36a,0x00000000,0x00000000}},	//   _unct, istu_, --, --, 
   {{0x4a98008f,0x298400ee,0x33e00213,0xd4f4004e}},	//   _בירג, _гысг, _sıx_, иякы, 
   {{0x3f9db36b,0xe570ef89,0xf771b36c,0xc79401d9}},	//   kstu_, سطه_, _هار_, _چھنا_, 
   {{0x940406be,0x00000000,0x00000000,0x00000000}},	//   _yelə_, --, --, --, 
   {{0x3f9cfcf4,0xcb10010f,0x13054da1,0x00000000}},	//   dstu_, ַלי_, рзим, --, 
   {{0x3f9db36d,0x7580006c,0xbeb80036,0x00000000}},	//   estu_, _ایتم, liëw, --, 
   {{0xdc18033f,0x1c04012d,0x04b40c75,0x3f9c032e}},	//   _złąc, रहाल_, _ەلەڭ, fstu_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x74c4015b,0x00000000,0x00000000,0x00000000}},	//   _শফিউ, --, --, --, 
   {{0x3f9c026c,0x8e54109a,0xdce400b8,0xb3600023}},	//   astu_, ртні, _sihā, ትከውን_, 
   {{0x22840220,0x940406be,0x00000000,0x00000000}},	//   _куәг, _selə_, --, --, 
   {{0x8b643ee0,0x00000000,0x00000000,0x00000000}},	//   لارم, --, --, --, 
   {{0xca8454f2,0xdce400dc,0x61e40064,0x00000000}},	//   ргай, _vihā, _šili, --, 
   {{0xea00001e,0xba380142,0x00000000,0x00000000}},	// [2f700] _trật_, _ddïo, --, --, 
   {{0x2ee001e4,0x6f05b36e,0xe9740137,0x0c24117e}},	//   _haif_, _hoic, _ۇۇرد, _вмон, 
   {{0x6f05b36f,0xcd340214,0x7b00000d,0x4bd401d5}},	//   _koic, _مرگب, _tõup, _тўпу, 
   {{0x6f04a7a4,0x98a000b0,0xfc540375,0x00000000}},	//   _joic, rihā_, _כביש_, --, 
   {{0x25a00597,0x45d40801,0x6f05b370,0x2ee1b371}},	//   éil_, рцет, _moic, _maif_, 
   {{0x42940020,0x2ee01028,0xdc18068f,0xa4d43981}},	//   ዚዳንት_, _laif_, _włąc, сокі, 
   {{0x7410007b,0x580401af,0x00000000,0x00000000}},	//   يوها, _лорғ, --, --, 
   {{0x2ee1b372,0x6f05b373,0xb7d8011a,0xa2f4011c}},	//   _naif_, _noic, _בקלי, спич, 
   {{0x3c24022e,0x00000000,0x00000000,0x00000000}},	//   _mеva_, --, --, --, 
   {{0x30a000d6,0xdce4054e,0x6f0401e7,0x3f9c03b2}},	//   орюв, _mihă, _aoic, tstu_, 
   {{0x3f9d56b8,0xd4f4f1c4,0x04440798,0x1fb8008e}},	//   ustu_, _уяты, _тежн, ылны_, 
   {{0x3f9db374,0x6f040399,0x9f34d2f5,0x41e4177b}},	//   rstu_, _coic, семі, _віка, 
   {{0x6f05b375,0x4084f9cb,0x2ee1b376,0xe29800fd}},	//   _doic, _куйб, _daif_, _ааҗ_, 
   {{0x3f9db377,0xfd440105,0x802400f1,0x99780210}},	//   pstu_, рэмн, _پرتم, rąży_, 
   {{0x9f59acf9,0xdcb00e8e,0x6f053908,0x212db378}},	//   áró_, يىڭ_, _foic, midh_, 
   {{0x212cabf3,0x3ce400ab,0x6f1c01e1,0x62800200}},	//   lidh_, _छोरे_, _tókọ, ncmo, 
   {{0x212c327f,0x200c00c0,0x00000000,0x00000000}},	// [2f710] oidh_, lydi_, --, --, 
   {{0x628002c4,0x2ee001b9,0xed580e92,0x212c7ea6}},	//   hcmo, _zaif_, _коњ_, nidh_, 
   {{0xaa1400c7,0x00000000,0x00000000,0x00000000}},	//   sẽpo, --, --, --, 
   {{0xb95801e1,0x212c0e89,0xd6380006,0x957400db}},	//   _apìt, hidh_, лялі_, быкч, 
   {{0x443db379,0x6f7c0952,0x7c383535,0x6ebc16d1}},	//   _axt_, ﯩﻘﻘﺎ_, ğuru, ष्टु, 
   {{0xa564175f,0xddcc04ba,0x212c0023,0x66040036}},	//   يدون, _ayaŋ, jidh_, äika, 
   {{0x3edc0241,0xded4044e,0x443c0077,0xe78400c2}},	//   _agọọ_, ርሕን_, _cxt_, _муто, 
   {{0x443c0077,0x27f400d7,0x00000000,0x00000000}},	//   _dxt_, ňaná_, --, --, 
   {{0x212c0597,0x20180086,0x25600ba1,0x443db37a}},	//   fidh_, ùrin_, dòlf_, _ext_, 
   {{0xddcc0083,0x6f0400c6,0x2ee1b37b,0x765800b5}},	//   _eyaŋ, _soic, _saif_, _izuy, 
   {{0x6f040801,0x69c000e4,0x5044d70a,0x00000000}},	//   _poic, _ãmev, сенб, --, 
   {{0x212c7e9f,0x09c0025c,0x0e40001f,0x00000000}},	//   aidh_, _གྱྀ_, _የሕክም, --, 
   {{0x6f04e1b2,0x212db37c,0xd39401af,0x00000000}},	//   _voic, bidh_, _тәһә_, --, 
   {{0xdb140036,0x212c01ab,0x06880873,0x00000000}},	//   htzä, cidh_, _ﺗﯩﻠﯩ, --, 
   {{0xdce40356,0x6f040332,0x2ee00166,0x00f4011a}},	//   _sihă, _toic, _taif_, _למסך_, 
   {{0xa45c001f,0x0d840352,0x8e74004e,0x61ec02d2}},	//   _ቅንጅት, _ллин, _уукч, _þolæ, 
   {{0x4875b37d,0xabe00150,0x00000000,0x00000000}},	// [2f720] مداس, _ﺇﻅﻬﺎ, --, --, 
   {{0x4c3405f5,0x00000000,0x00000000,0x00000000}},	//   _гэмт, --, --, --, 
   {{0xa2d803e5,0x4098008f,0x82440023,0x00000000}},	//   _मसल्, רבעס, _ሕድሕዳ, --, 
   {{0x37a80405,0x443c0129,0x7c380790,0x7cec022e}},	//   ائلی_, _rxt_, ğurt, lеrа, 
   {{0xa5f80b3b,0xb88c0092,0x00000000,0x00000000}},	//   релу_, ርንጫፍ_, --, --, 
   {{0x69c4b700,0x246c013f,0xbeb804e6,0x212c0009}},	//   mtie, tɛm_, chëf, xidh_, 
   {{0x69c5b37e,0x2918009a,0xd90c00dd,0xd4c400e3}},	//   ltie, _ilra_, _جیل_, تغني, 
   {{0x69c5b37f,0x212c0014,0x6b7c0100,0x80c80303}},	//   otie, widh_, _rčgl, त्ने, 
   {{0x246c0605,0x6280fb40,0x212c08c2,0x849401f7}},	//   sɛm_, rcmo, tidh_, _هجائ, 
   {{0x443db380,0x69c49cbb,0x6af8025c,0x3aec0166}},	//   _txt_, itie, _པོའོ_, _köpä_, 
   {{0x212c0ea3,0x69c5b381,0x2918af97,0x443c0005}},	//   ridh_, htie, _mlra_, _uxt_, 
   {{0x69c5b382,0x61e402d5,0x3e0400a7,0x212c08c2}},	//   ktie, _šilu, бягв, sidh_, 
   {{0x3d0c010e,0x212c01c3,0x69c4031c,0x26c001e4}},	//   _hüwi_, pidh_, jtie, ϲion_, 
   {{0x5f95b383,0xa3ac05f9,0xddcc0356,0x00000000}},	//   _дикт, _कटा_, _agaţ, --, 
   {{0xac1873da,0xb7b009bd,0x69c5b384,0xfaa4833b}},	//   бору_, _ঘন্ট, etie, йшан, 
   {{0x69c5b385,0x29180162,0x00000000,0x00000000}},	//   ftie, _alra_, --, --, 
   {{0x69c403ef,0xbeb8036e,0x5a340798,0x00000000}},	// [2f730] gtie, thëf, цнат, --, 
   {{0x291801ab,0x06880116,0x00000000,0x00000000}},	//   _clra_, _ﺗﯩﻤﯩ, --, --, 
   {{0x80c87922,0x69c46cd9,0x9b582077,0xdb14002f}},	//   त्ये, atie, _винт_, ttzä, 
   {{0x69c5b386,0xbeb801f5,0x57c80037,0x7c382ca8}},	//   btie, ciët, _रहीह, şurs, 
   {{0x69c5b387,0xf2c0009e,0x6444054e,0x00000000}},	//   ctie, ্যমণ, şiil, --, 
   {{0xd794013d,0xdb14036e,0x09f4011a,0x00000000}},	//   _мигъ, kuzë, _ומשם_, --, 
   {{0x785401d3,0x3dbc00fe,0xf2e4006c,0xe7e00037}},	//   _ایاز_, ইবিল, یکچه_, _गईया_, 
   {{0x1309b388,0xe78400c2,0xd1841ebb,0x72a00116}},	//   рний_, _хуро, олий, سەتن, 
   {{0xe610b93f,0xf1d4045e,0xdc0405d7,0x7659b389}},	//   _كشك_, তম্ভ, रहुड_, _uzuy, 
   {{0xaca402e3,0x2360025c,0x88c40055,0x00000000}},	//   twọk, ċija_, caśā, --, 
   {{0x69c40323,0x61e5a353,0xfee0009e,0xdb140200}},	//   ztie, _šilt, যানধ, guzë, 
   {{0x69c5b38a,0xc32400ec,0xdcfc0139,0xdb6c0150}},	//   ytie, _وڃين_, dusı, _ﺳﺎﻻﯞ, 
   {{0x69c4038f,0x10a4023b,0x918000d1,0x00000000}},	//   xtie, _дилн, _تۇخۇ, --, 
   {{0x62200131,0x69c400d7,0x00000000,0x00000000}},	//   _سۈپە, vtie, --, --, 
   {{0x7e78107d,0x69c40327,0xc170011a,0x00000000}},	//   župa, wtie, _קחו_, --, 
   {{0x16084ed3,0x0a2c001f,0x69c4b4bb,0x63bc33b8}},	//   वहार_, _በመልካ, ttie, _årne, 
   {{0x09040a83,0xbeb82ad4,0x291800e4,0xcc880271}},	// [2f740] опан, riët, _plra_, _پنجه_, 
   {{0x1a680124,0xdcfc013d,0x00000000,0x00000000}},	//   сзуҩ_, busı, --, --, 
   {{0x97a400d4,0x00000000,0x00000000,0x00000000}},	//   зріл, --, --, --, 
   {{0x69c5b38b,0xdcec0327,0xbeb80b4f,0x85e84db0}},	//   ptie, _iwaġ, liër, идев_, 
   {{0xbeb802d3,0x2ba80073,0x69c4031c,0x00000000}},	//   shëg, गळवा, qtie, --, 
   {{0x83a807d6,0xbeb8057b,0xd5ac01d3,0x00000000}},	//   атиб_, niër, اہل_, --, 
   {{0x961c0139,0x74a802dd,0x00000000,0x00000000}},	//   _meņy, рсің_, --, --, 
   {{0xfafc0036,0xbeb80ea0,0xe7e0000d,0xe738009f}},	//   _hiër_, hiër, _गैया_, _ايرڪ_, 
   {{0xf2e4036b,0xfcd401f3,0x00000000,0x00000000}},	//   تکله_, ይስጥ_, --, --, 
   {{0xfafc00e8,0xded40023,0x22ac0153,0x3d0c010e}},	//   _jiër_, ርዕን_, dėkų_, _tüwi_, 
   {{0x3dcc0729,0xbeb80926,0x7e00095f,0x00000000}},	//   িয়াল, diër, रङ्ग_, --, 
   {{0x63b80455,0x00000000,0x00000000,0x00000000}},	//   muvn, --, --, --, 
   {{0x63b80232,0xbeb81190,0x93580868,0x00000000}},	//   luvn, fiër, _урфу_, --, 
   {{0x9df8016c,0x00000000,0x00000000,0x00000000}},	//   _ҳнит_, --, --, --, 
   {{0x2a7000ac,0x2560068c,0xbeb8036e,0x59dc0037}},	//   ənbə_, còle_, thëd, _नईहर, 
   {{0xbeb801f5,0x00000000,0x00000000,0x00000000}},	//   riës, --, --, --, 
   {{0xbeb805e4,0xfcc8014b,0x00000000,0x00000000}},	// [2f750] biër, _кунй_, --, --, 
   {{0xbeb801a4,0x61bc00cc,0xe8f8004e,0x00000000}},	//   ciër, _অনাআ, онуч_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x80c81408,0x63b850a8,0x5eac00bd,0x6bd4030f}},	//   त्ते, duvn, ট্রে, _کتیر, 
   {{0x8af8011a,0xddd4010e,0xb8b400ae,0x00000000}},	//   _הפרק, _ýańs, _وإست, --, 
   {{0x01c004c5,0x2db80302,0xdb140221,0xf9600133}},	//   ্টাদ, קלון_, duzé, _کۆڕێ, 
   {{0x7bc5b38c,0xc9500375,0x569434cc,0x4cd40154}},	//   ntju, _נמל_, _навт, দাচু, 
   {{0x7bc40d04,0x11d80597,0xc7b00a1e,0x25b005d1}},	//   itju, موعة_, _רבן_, üllü_, 
   {{0xd3700451,0x00000000,0x00000000,0x00000000}},	//   وهڻ_, --, --, --, 
   {{0x95000150,0x7bc5b38d,0x63b80162,0x00000000}},	//   _سۋبۇ, ktju, ðanø, --, 
   {{0x59dc086b,0x00000000,0x00000000,0x00000000}},	//   _नैसर, --, --, --, 
   {{0xba380ea0,0xd250007b,0xbeb80d49,0x7bc4002f}},	//   _geïg, _كنا_, wiër, dtju, 
   {{0x42780375,0xbeb801f5,0x63042969,0x6cb4004e}},	//   _האנג, tiër, _تونل, мөнт, 
   {{0x414402dd,0x27080562,0x4acc0bca,0x1d18117e}},	//   _едің, _वक्र_, ह्नव, оюсь_, 
   {{0xbeb9b38e,0xaee40150,0x7bc4cbaf,0x00000000}},	//   riër, _قۋدى, gtju, --, 
   {{0xbeb805e4,0xaca401e1,0x59dc000d,0xc0f00b82}},	//   siër, _iwọw, _नैहर, ቃድር_, 
   {{0x3b05b38f,0xbeb9b390,0x50300023,0x63b801a9}},	// [2f760] чето_, piër, _ኣዕሩኽ, zuvn, 
   {{0x2cbc143a,0xa3ac0037,0x9f5800e4,0x00000000}},	//   _øvd_, _कटल_, árö_, --, 
   {{0xbc78011a,0x00000000,0x00000000,0x00000000}},	//   _לנית, --, --, --, 
   {{0x637c00c7,0x00000000,0x00000000,0x00000000}},	//   _hũng, --, --, --, 
   {{0x50bc00dc,0x09e400fe,0x00000000,0x00000000}},	//   ्भाष, _নথকা, --, --, 
   {{0x07a404b0,0x63b91eb2,0x00000000,0x00000000}},	//   _нагн, tuvn, --, --, 
   {{0xd58802d3,0x00000000,0x00000000,0x00000000}},	//   _ዝደልዮ_, --, --, --, 
   {{0xcfe002f5,0xf361b391,0x88cc015b,0x63b801d5}},	//   যমান, нтын, _রফিক, ruvn, 
   {{0x63b9b392,0xba380926,0xf7407758,0x26c001e4}},	//   suvn, _geïd, _чето, ϲioj_, 
   {{0x75d04e74,0xdcec0327,0x63b80477,0xf990011a}},	//   _سيما, _iwaħ, puvn, ערת_, 
   {{0x74100b8c,0x03a406ed,0x63b80455,0xd9a805dc}},	//   _كوكا, _ѕидо, quvn, _छट्ट, 
   {{0x3f8811f9,0xf834011a,0xde580006,0x00000000}},	//   ību_, לנית_, жамі_, --, 
   {{0xdcec031c,0x3f88003e,0x00000000,0x00000000}},	//   _jwaħ, ūbu_, --, --, 
   {{0x601806bb,0xe6c8000d,0xdcec025c,0x7bc4b35a}},	//   _моля_, रभुज, _mwaħ, ttju, 
   {{0x7bc40357,0xd24c08cf,0xac1832b0,0xded40023}},	//   utju, _مچی_, пору_, ይንኻ_, 
   {{0xe7f00bae,0x7bc4cc72,0xdb080342,0xbeb8036e}},	//   घटना_, rtju, _ölüy, shëb, 
   {{0x940c013f,0x7bc5059e,0x9f58035b,0x00000000}},	// [2f770] _ɔnɑm_, stju, árõ_, --, 
   {{0x6b8801e4,0xf1a0012d,0x00000000,0x00000000}},	//   ŭdga, _खौफन, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x96540395,0x6da41291,0x00000000,0x00000000}},	//   мълч, _تمیم, --, --, 
   {{0x864c0023,0x00000000,0x00000000,0x00000000}},	//   _ንዓኻት, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x67d5b393,0x572400db,0xb6000419,0x69c0008e}},	//   _пору, _قىسك, _sláč, _ämer, 
   {{0x63a806d1,0x27f80122,0x80c8078a,0xfe7c015d}},	//   _dvdn, šený_, त्से, ddïo_, 
   {{0xe2a8009f,0x00000000,0x00000000,0x00000000}},	//   ساين_, --, --, --, 
   {{0xb60002fb,0xf4842ec5,0x00000000,0x00000000}},	//   _vláč, _хуан, --, --, 
   {{0xe3b02e44,0xd00800f3,0x943800ae,0x00000000}},	//   _مرن_, цене_, _بكاء_, --, 
   {{0x5215b394,0x6fbc0490,0x7f8800e4,0x91f8007b}},	//   _одет, लंबू, _ỹvév, _وفاء_, 
   {{0xce480220,0x00000000,0x00000000,0x00000000}},	//   ізге_, --, --, --, 
   {{0xf8cc17c6,0x9344010a,0x00000000,0x00000000}},	//   स्मय, _енçе, --, --, 
   {{0x80b001ad,0x91a800e5,0x60dc0254,0x00000000}},	//   _आयते, _انڈے_, õrme, --, 
   {{0xc0500302,0x94fc025c,0x043002d3,0x9f580022}},	//   _שזה_, _དོའི_, _ክንጥን, árô_, 
   {{0x80c80882,0xc3300302,0x637c00c7,0xfe4021f3}},	// [2f780] त्वे, דון_, _tũng, _инъо, 
   {{0x38c82304,0x9e2400f7,0x291c0588,0x00000000}},	//   قامی_, _سىپو, óva_, --, 
   {{0x3ce42232,0x46e9b395,0x8c44e2de,0x2d800076}},	//   _छोटे_, жден_, _цене, _huie_, 
   {{0x3a3c2375,0x776802d0,0xe6c8012d,0x00000000}},	//   _župe_, gmgx, रभेज, --, 
   {{0x05680261,0x19b80276,0xdbdc0248,0x6aa5b396}},	//   ојки_, _нурь_, _láìp, maif, 
   {{0x6aa42486,0x2d81b397,0x00000000,0x00000000}},	//   laif, _muie_, --, --, 
   {{0x2d80282c,0x256091ef,0x00000000,0x00000000}},	//   _luie_, gòla_, --, --, 
   {{0x6aa54400,0x2d800156,0xdcec0135,0x34800139}},	//   naif, _ouie_, _twaħ, нгәг, 
   {{0x15b00131,0x81d40eac,0x611401f4,0x00000000}},	//   _مەنس, ায়ন_, едпу, --, 
   {{0x6aa5b398,0xefd4001f,0x2560067c,0x5f941d0f}},	//   haif, _ሬዲዮ_, bòla_, ниот, 
   {{0x20195344,0x2d80068c,0x6aa4c822,0x25602508}},	//   ári_, _auie_, kaif, còla_, 
   {{0x6d41ab58,0x2d800af9,0xa2c40131,0x20180003}},	//   éman, _buie_, _чәкк, ġri_, 
   {{0x6aa407de,0x2d800311,0x00000000,0x00000000}},	//   daif, _cuie_, --, --, 
   {{0x2d802b1d,0x00000000,0x00000000,0x00000000}},	//   _duie_, --, --, --, 
   {{0x69a41715,0x6aa41f4a,0x9f34177b,0x92e003d4}},	//   _चौबी, faif, _пекі, দাৰ_, 
   {{0x80c87922,0x6aa40618,0x00000000,0x00000000}},	//   त्रे, gaif, --, --, 
   {{0x2d800022,0x3f8c0142,0xaa580212,0xf9905285}},	// [2f790] _guie_, _htfu_, диту_, ئبر_, 
   {{0xdb140306,0xd11c0092,0x7860022e,0x00000000}},	//   muzí, _ስለሚኖ, lеvi, --, 
   {{0x6aa400ca,0xdb1402f0,0x9b580798,0xccf0010f}},	//   baif, luzí, _ниот_, _עכט_, 
   {{0x19943c1b,0xf990007b,0x00000000,0x00000000}},	//   _памя, _لبس_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2edc06bc,0x94440131,0x26c401e3,0x00000000}},	//   _बस्त, ىھان, _ecmo_, --, 
   {{0x3f8c00d2,0x3f7c031c,0xef200210,0x00000000}},	//   _ntfu_, _uċuh_, óżki_, --, 
   {{0x2d8400bc,0x25600ba1,0x52d800e1,0x11e479e7}},	//   ímek_, ròla_, ढ़ेस, ежим, 
   {{0xda002e1e,0x91340212,0x2560067c,0xe5c407a5}},	//   ोहित_, ехні, sòla_, _асхо, 
   {{0x2d80017a,0x2560067c,0x6aa58c9f,0xdbdc0248}},	//   _ruie_, pòla_, zaif, _páìp, 
   {{0x798c02d0,0x6aa40438,0x2d800356,0x047400db}},	//   _ltcw, yaif, _suie_, _كئمگ, 
   {{0x798c02d0,0xbeb80200,0x00000000,0x00000000}},	//   _otcw, thëa, --, --, 
   {{0x3f8c003c,0x88e40729,0xe3b003e6,0x2d81b399}},	//   _etfu_, নাতক, _مرۆ_, _quie_, 
   {{0xc0e0a41f,0x5cd43981,0x6aa4004c,0x8fa40798}},	//   _бошк, кісх, waif, _заке, 
   {{0x6aa5b39a,0xddcc0054,0x798c02d0,0x00000000}},	//   taif, _ayań, _atcw, --, 
   {{0x2d80017a,0x52dc000d,0x8c440139,0x00000000}},	//   _tuie_, _मसोस, _җеме, --, 
   {{0x6aa5b39b,0xcda82088,0xdb140356,0xbb418b05}},	// [2f7a0] raif, _عهده_, fuzâ, уетк, 
   {{0x798800d2,0x798c035a,0x00000000,0x00000000}},	//   ígwa, _dtcw, --, --, 
   {{0x798c127b,0x6aa400db,0x7b3401a6,0x1c440137}},	//   _etcw, paif, tćut, _үнөм, 
   {{0x798c03ac,0x6d5c6b41,0x81d403d4,0x00000000}},	//   _ftcw, llra, াটত_, --, 
   {{0xba38180f,0x6d5d45fe,0x26c40208,0x2b41b39c}},	//   _veïc, olra, _vcmo_, mnic_, 
   {{0x2b41b39d,0x2459b39e,0x637c0022,0x07e801ed}},	//   lnic_, маль_, _oĩnt, _ٹرسٹ_, 
   {{0xbeb802d3,0x2b400f85,0x6d5c0857,0x00000000}},	//   dhën, onic_, ilra, --, 
   {{0x2b41b39f,0x1cd80156,0x33f00691,0x6d5c0112}},	//   nnic_, ོབོ_, اسوس, hlra, 
   {{0x2b40df53,0x6720000d,0xa3ac38d2,0xa5e801ee}},	//   inic_, _ilmj, _कटक_, _юлаҡ_, 
   {{0x2b41b3a0,0xddcc0432,0x6d5c01bf,0x31c0011c}},	//   hnic_, _azaş, jlra, усъв, 
   {{0x6d480024,0x301001c4,0x00000000,0x00000000}},	//   čdal, гдэр, --, --, 
   {{0xfafc006a,0x6d5db3a1,0x9f341ac3,0x2b401d33}},	//   _ahën_, elra, темі, jnic_, 
   {{0x6d5c30a2,0x00000000,0x00000000,0x00000000}},	//   flra, --, --, --, 
   {{0x6d5c07c5,0x6ce40220,0xa3e401ad,0x2b41b3a2}},	//   glra, лісе, _फना_, enic_, 
   {{0x7b6411ed,0xd17400c7,0xafe0041b,0xfafc0200}},	//   етае, _рыцы, _бојл, _dhën_, 
   {{0x6d5db3a3,0x68fc0175,0xc1004530,0x00000000}},	//   alra, _anrd, _рүүл, --, 
   {{0x248c022f,0x2560067c,0x4ae00073,0x0e00014b}},	// [2f7b0] _ofdm_, jòlo_, _पसरव, _кӯро, 
   {{0x2b41b3a4,0xb4dc0574,0x693405f5,0x52dc02ab}},	//   anic_, _तसे_, гнуу, _मस्स, 
   {{0x81d40eac,0xe94400c0,0x2b41b3a5,0x69d80356}},	//   াটি_, ухто, bnic_, ăvea, 
   {{0x2b41b3a6,0xdb140e78,0x68fc02d0,0x798c02d0}},	//   cnic_, ntzü, _enrd, _ttcw, 
   {{0x61240100,0x64480014,0xdbdc01e1,0x81d403d4}},	//   _gòlg, _axdi, _háàp, ায়ত_, 
   {{0x81d400bd,0xdbdc01a8,0x246c1954,0x00000000}},	//   াটা_, ráæt, _ቴድሮስ_, --, 
   {{0x66742928,0xd7c801b9,0xdb140036,0xdbdc01a8}},	//   ندۇر, _توزه_, erzé, sáæt, 
   {{0xf99c0d29,0x52743576,0x00000000,0x00000000}},	//   _kwè_, купу, --, --, 
   {{0xf99c0699,0x644800db,0xbeb802d3,0x557419c3}},	//   _jwè_, _exdi, thën, _агат, 
   {{0xf99c007f,0x2b41b3a7,0xe2a80050,0x068802dd}},	//   _mwè_, znic_, ٘این_, _ﺗﯩﻌﯩ, 
   {{0x7658020b,0x94180605,0x6d4043ed,0xbeb80221}},	//   _hyuy, _ɛsɛ_, émam, rhën, 
   {{0xfafc02d3,0x7658037e,0xbeb80240,0xc0cc0023}},	//   _shën_, _kyuy, shën, ኣስረ_, 
   {{0x2b41b3a8,0xf99c02e2,0x0d9801c0,0xa19448f2}},	//   vnic_, _nwè_, ьтны_, _бачч, 
   {{0x6d5c0357,0x7779b3a9,0xaed4031c,0x50d401d9}},	//   ulra, _liux, _ཏིམོ, _شٲعر, 
   {{0xf99db257,0x2b41b3aa,0xc0d000db,0x6e4402f2}},	//   _awè_, tnic_, _ئيىب, _ڕۆحم, 
   {{0xf99c0699,0x3a3c107d,0x765802e3,0xbeb801c7}},	//   _bwè_, _župa_, _oyuy, nhël, 
   {{0xddcc0bc9,0x2b41b3ab,0xc0cc02d3,0xfafc0200}},	// [2f7c0] _ayaņ, rnic_, ኣስሩ_, _thën_, 
   {{0xf99c02e2,0x4875b3ac,0x2b41b3ad,0x612480e1}},	//   _dwè_, نداس, snic_, _gòld, 
   {{0x7659b3ae,0xf99c020c,0x2b4009a8,0x9e64030f}},	//   _ayuy, _ewè_, pnic_, _لاین, 
   {{0xf99c007f,0x98540145,0x76580139,0xe6b401b9}},	//   _fwè_, утуш, _byuy, الشگ, 
   {{0x61240158,0x2a4400c7,0x00000000,0x00000000}},	//   _hòle, _сҭам, --, --, 
   {{0x76581eca,0x63b85e71,0x00000000,0x00000000}},	//   _dyuy, trvn, --, --, 
   {{0xbeb801c7,0xc6080154,0x00000000,0x00000000}},	//   fhël, _শেখা_, --, --, 
   {{0x6b7c0098,0xa5c40220,0x00000000,0x00000000}},	//   _yōga, _бөке, --, --, 
   {{0xb4600352,0xbbcc0118,0xf8cc084d,0x00000000}},	//   лкәл, _हङ्क, स्वय, --, 
   {{0x66040254,0xd378004e,0x00000000,0x00000000}},	//   äiku, мчө_, --, --, 
   {{0xf48459d4,0xceac00ec,0x6098072d,0x00000000}},	//   _شالی, ڳڙي_, ونکس_, --, 
   {{0x61240699,0xdd953283,0xb28059b7,0x7778f3da}},	//   _sòld, ламы, _кышк, _xiux, 
   {{0x7e4400d3,0x7e2801ca,0x00000000,0x00000000}},	//   тхне, фіна_, --, --, 
   {{0xba382595,0xdfd00b24,0xad440064,0xdb14002f}},	//   _beïn, _هيت_, ахск, stzü, 
   {{0x612456eb,0x3f6400d1,0xf99c02e2,0x31780a7c}},	//   _còle, _итиб, _swè_, _קרומ, 
   {{0xc8c45020,0xb4dc0034,0x2bb800c6,0xe25402d3}},	//   र्घट, _तस्_, ضافة_, _ምስሕሓ, 
   {{0x58d49808,0x38c800d8,0x00000000,0x00000000}},	// [2f7d0] лоат, дуен_, --, --, 
   {{0xf99c02e2,0xfca88e33,0x00000000,0x00000000}},	//   _vwè_, _کاکو_, --, --, 
   {{0xba3808f7,0x5694656c,0x395004cc,0x00000000}},	//   _geïn, гает, roxs_, --, 
   {{0xf99c007f,0x99d40451,0x8c18011a,0x00000000}},	//   _twè_, _ٽڪرا, _נורי, --, 
   {{0x29886550,0xe9a400c0,0x00000000,0x00000000}},	//   _ассо_, _каўп, --, --, 
   {{0xd46800a8,0x195850c0,0xe894248c,0x8cd41b76}},	//   ниле_, _чагы_, _варь, म्पो, 
   {{0x88802c26,0x3f8800cf,0xbeb801c7,0xf6e400f3}},	//   _ایمن, íbul_, thël, _ицан, 
   {{0x2240009b,0x00000000,0x00000000,0x00000000}},	//   _žika_, --, --, --, 
   {{0x11399338,0x765805d1,0x446c001f,0xbeb80221}},	//   еяны_, _uyuy, _ትንቢተ_, rhël, 
   {{0xbeb9b3af,0xa4d80022,0x5ed000eb,0x00000000}},	//   shël, _идуу_, _তোলে, --, 
   {{0x63a4009b,0xfafc036e,0x00000000,0x00000000}},	//   ćinc, _onë_, --, --, 
   {{0x51f505dd,0xba38ecfa,0x2018013c,0x929c033f}},	//   _مستر, _reïn, øria_, ykły, 
   {{0x2d85b3b0,0x61244079,0x00000000,0x00000000}},	//   ême_, _sòle, --, --, 
   {{0xfafc02d3,0x8fd00032,0xc634008f,0x00000000}},	//   _anë_, _ләмә, אָלק_, --, 
   {{0x1c38005b,0xcf5802e8,0xdbdc0241,0x810800f1}},	//   вять_, _прич_, _pááp, _سروې_, 
   {{0xba380228,0xb0cc07b7,0x61241f40,0x09e5b3b1}},	//   _veïn, त्रग, _vòle, лобн, 
   {{0x80c80864,0x00000000,0x00000000,0x00000000}},	// [2f7e0] त्के, --, --, --, 
   {{0xfafc0240,0xecc400db,0xdb1400e5,0x00000000}},	//   _enë_, _өшүү, ruzá, --, 
   {{0x59756508,0x00000000,0x00000000,0x00000000}},	//   рыту, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d40020c,0x00000000,0x00000000,0x00000000}},	//   émah, --, --, --, 
   {{0xfafc02d3,0xd4984e19,0x8cd48bb5,0xba380129}},	//   _ynë_, трі_, म्यो, _leïl, 
   {{0x25ec0034,0xbeb80023,0xb9d00092,0x4cac0154}},	//   _आईपी_, thëm, _ትቶ_, ঞ্চু, 
   {{0x636c1446,0x86440640,0xc0c92a26,0x45a00137}},	//   hûng, _снаж, нуне_, _چەچك, 
   {{0x741004d3,0x00000000,0x00000000,0x00000000}},	//   _گوما, --, --, --, 
   {{0x442801bf,0xdb080790,0xbeb80200,0x00000000}},	//   _åb_, _çoçu, shëm, --, 
   {{0x93240956,0x9f84004e,0x00000000,0x00000000}},	//   _پرمن, лгүд, --, --, 
   {{0x83500014,0x8cd400cd,0x00000000,0x00000000}},	//   _پھژا, म्भो, --, --, 
   {{0xefcc02d3,0x103401b9,0x25ec1b57,0xdfec023e}},	//   ኣእያ_, ابیگ, _आईनी_, _जनपद_, 
   {{0xdc200003,0x7fb00244,0x00000000,0x00000000}},	//   _iċċe, _البچ, --, --, 
   {{0x25a00118,0x8cd42802,0x00000000,0x00000000}},	//   šily_, म्बो, --, --, 
   {{0xba38057b,0x3ea8009f,0xbeb80240,0x69c0143a}},	// [2f7f0] _geïl, mact_, rkëd, _åmel, 
   {{0x636db3b2,0x3ea80356,0x00000000,0x00000000}},	//   bûng, lact_, --, --, 
   {{0x1a64034c,0x88e400fe,0x00000000,0x00000000}},	//   _چیزی_, নাংক, --, --, 
   {{0xfafc069c,0x636c002d,0x00000000,0x00000000}},	//   _unë_, nûnd, --, --, 
   {{0x7aec1730,0x7c640066,0x00000000,0x00000000}},	//   _iact, _جاکل, --, --, 
   {{0x7aec1730,0x636c000f,0x00000000,0x00000000}},	//   _hact, hûnd, --, --, 
   {{0x636c002d,0x6d4006af,0x59a80d0d,0xb81c03d4}},	//   kûnd, émai, _चौतर, _দশকত_, 
   {{0xdc20038f,0x60d80083,0x7aed6a9e,0x11d800c6}},	//   _aċċe, _abvm, _jact, نوعة_, 
   {{0x63a41225,0x7aedb3b3,0x3ea80998,0x41a5b3b4}},	//   ćina, _mact, dact_, авын_, 
   {{0x78a40477,0x00000000,0x00000000,0x00000000}},	//   _jejv, --, --, --, 
   {{0x78a439be,0x7aecb942,0x634800bc,0x52b4007b}},	//   _mejv, _oact, měnn, _نماذ, 
   {{0x25a000a8,0xdc20003d,0x7aec16b8,0x67f001ed}},	//   ţile_, _eċċe, _nact, lójá, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x59a84ca3,0x78a4038e,0x7aec0166,0x51f40451}},	//   _चौधर, _nejv, _aact, _مسڪر, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7aec074d,0x684401e0,0x636ccf56,0x00000000}},	//   _cact, ҡмаҡ, rûng, --, 
  
   {{0x7aedb3b5,0x67f00cad,0x78a5b3b6,0x88c819c9}},	// [2f800] _dact, kójá, _bejv, клав_, 
   {{0xba380f49,0x7aec0c8c,0x25ec00e1,0x92e00f22}},	//   _geïm, _eact, _आईबी_, দায়_, 
   {{0xc6a456ff,0x7aedb3b7,0x78a45d39,0x37840107}},	//   арли, _fact, _dejv, абхо_, 
   {{0x7aec102c,0x61240561,0xddcc00b8,0x81cc03d4}},	//   _gact, _mòla, _nyaś, ৱিত_, 
   {{0x25d8010b,0x7c5400e5,0x78a400e5,0x00000000}},	//   умлы_, _ملیر_, _fejv, --, 
   {{0x291c2771,0xddcc00b8,0x3ea800b5,0xbeb9b3b8}},	//   övad_, _ayaś, zact_, thëk, 
   {{0xa285b3b9,0x69c53f1f,0x636c000f,0x29180210}},	//   میاو, luie, hûne, ęgać_, 
   {{0x3ea80048,0x7aec0334,0xb9dc02d3,0x69c4030a}},	//   xact_, _xact, _ኣቲ_, ouie, 
   {{0x69c5b3ba,0x636c000f,0xdb1c01d3,0x733121e7}},	//   nuie, jûne, ézés, تروئ, 
   {{0xe1344b2c,0x636c0b21,0x69c401ab,0x00000000}},	//   ённы, wûnd, iuie, --, 
   {{0x61245c99,0x25ec0c2e,0x636c002d,0x42c9b3bb}},	//   _còla, _आईडी_, tûnd, _аген_, 
   {{0x61251714,0x69c5b3bc,0x634800bc,0x037857c1}},	//   _dòla, kuie, měno, _شحات_, 
   {{0x3ea9b3bd,0x636c045f,0x6fd80793,0x7aec0548}},	//   ract_, rûnd, _päcö, _ract, 
   {{0x636c0225,0x69c4054e,0x30a002e8,0xc0a80066}},	//   sûnd, duie, _дръв, _شاتل_, 
   {{0x7aed1594,0xc0d41b49,0xfaa40261,0x201800c5}},	//   _pact, ካኤል_, ишан, ärid_, 
   {{0xd1c802d3,0x307802e4,0xdd940022,0xaf34027d}},	//   _ጠለብ_, _באונ, _лаиы, _وريت, 
   {{0x69c5b3be,0x7aec0076,0x6da40120,0x00000000}},	// [2f810] guie, _vact, _диња, --, 
   {{0x2560067c,0x78a40477,0x7aec0142,0x60c8007c}},	//   bòli_, _qejv, _wact, ngdm, 
   {{0x78a4037e,0xf805b3bf,0x7aedaa66,0x96642123}},	//   _vejv, шчан, _tact, әкле, 
   {{0x14c80574,0x69c5b3c0,0x78a4047e,0x63480118}},	//   _राहण, buie, _wejv, děno, 
   {{0x69c4084c,0x67f001ed,0xeef808a8,0x35e42bb7}},	//   cuie, tójá, ימאר_, рцев, 
   {{0x64980801,0x60c800b5,0x942401af,0x00000000}},	//   атър_, jgdm, ймле, --, 
   {{0xd7c861be,0xddcc0055,0x6aac0139,0xd3d800be}},	//   _حوزه_, _pyaś, _ölfä, ابتا_, 
   {{0x4fe822f7,0x27fc037e,0x14c80c00,0x612400a3}},	//   ҳмон_, ævne_, _रावण, _ròla, 
   {{0x65940348,0x612408c2,0xddcc002b,0x00000000}},	//   _мату, _sòla, _vyaś, --, 
   {{0x612401c3,0xdff4033f,0x634801ef,0xd7600244}},	//   _pòla, ेमंद_, běno, _بۆڵی, 
   {{0x141847ea,0x636c000f,0x69c5b3c1,0xbe340023}},	//   _حياة_, wûne, zuie, _ኣስገዳ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x63700124,0xd1740139,0x93380092,0x00000000}},	//   _ẽnga, _лыкы, _እቅዶቹ, --, 
   {{0x636c000f,0x25600ba1,0x00000000,0x00000000}},	//   rûne, tòli_, --, --, 
   {{0x8b6402dd,0x00000000,0x00000000,0x00000000}},	//   مارم, --, --, --, 
   {{0x69c5b3c2,0xca8401c6,0x8e381291,0x70a4012d}},	//   tuie, сгай, _مسخر_, _ग़ुल, 
   {{0x9f640241,0x00000000,0x00000000,0x00000000}},	// [2f820] _ìtán_, --, --, --, 
   {{0x69c5b3c3,0xccc40b7e,0x2560068c,0xdb040267}},	//   ruie, _убой, pòli_, _avhä, 
   {{0x6f05b3c4,0x69c4a952,0x00000000,0x00000000}},	//   _knic, suie, --, --, 
   {{0x69c406af,0x6d48009b,0x63480118,0x00000000}},	//   puie, čdau, věno, --, 
   {{0x35b17cc2,0x6f04c932,0x09f40212,0x7d7417a5}},	//   збір, _mnic, _учня, _خمیر_, 
   {{0xd90c004b,0x00000000,0x00000000,0x00000000}},	//   _ټیم_, --, --, --, 
   {{0x6f05b3c5,0x63a4098d,0x00000000,0x00000000}},	//   _onic, ćino, --, --, 
   {{0x645c013c,0xfbd00375,0x03a401b9,0x00000000}},	//   _ørim, פתח_, _ҳижо, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x88e4009e,0x75d001ec,0xa4c801ed,0xf1c40131}},	//   নাকক, _ءيلا, _خطرے_, _ﻫﻪﻗﻘ, 
   {{0x6f040204,0x636c002d,0x00000000,0x00000000}},	//   _bnic, rûnb, --, --, 
   {{0x3cd80316,0x1df806a6,0x00000000,0x00000000}},	//   ख्ने_, аемы_, --, --, 
   {{0x60c8074d,0xa28000f1,0x20180037,0x1f6400db}},	//   pgdm, _کیښو, ärib_, йкүм, 
   {{0x6f048a15,0xdc6c001f,0x717000ae,0x00000000}},	//   _enic, _በስልክ_, _فهنا, --, 
   {{0xbeb8036e,0x00000000,0x00000000,0x00000000}},	//   dhëv, --, --, --, 
   {{0x6f05b3c6,0x6124007f,0x00000000,0x00000000}},	//   _gnic, _kòlo, --, --, 
   {{0xa2d04c83,0x81d404c5,0x59380006,0xdd900244}},	// [2f830] _धान्, াটক_, азаў_, _توخ_, 
   {{0x6d400231,0xa3e806ab,0x6f040609,0xf805b3c7}},	//   émat, यबा_, _znic, йчен, 
   {{0x6124007f,0xdb04007c,0x6f0402d0,0x8ccc00bc}},	//   _lòlo, _avhå, _ynic, _तातो, 
   {{0x7bc5b3c8,0x959942e5,0x5ac87d0b,0x69a4146c}},	//   muju, атку_, _өлүм_, _चौकी, 
   {{0x7bc5b3c9,0x00000000,0x00000000,0x00000000}},	//   luju, --, --, --, 
   {{0xe944014b,0x00000000,0x00000000,0x00000000}},	//   _ехсо, --, --, --, 
   {{0x758057be,0xd4680114,0x3cd800cd,0x5694146a}},	//   _کیتم, шике_, ख्ये_, _мавт, 
   {{0x7d140005,0x7bc40194,0x97240214,0x57242374}},	//   _loxs, iuju, _بفرو, _بىرك, 
   {{0x7bc5b3ca,0x612400db,0xd1746c15,0x21b812ea}},	//   huju, _còlo, жыны, مپيک_, 
   {{0x6f044cab,0x64540129,0x00000000,0x00000000}},	//   _snic, éfié, --, --, 
   {{0x61fc01ab,0x92940153,0x8fd011ca,0x00000000}},	//   ārla, _даец, фәлә, --, 
   {{0x7bc5481c,0x00000000,0x00000000,0x00000000}},	//   duju, --, --, --, 
   {{0x7d15b3cb,0x6f040393,0xdcec0003,0x00000000}},	//   _boxs, _vnic, _staġ, --, 
   {{0x8d740e5a,0x53dc21b8,0x7d14fa9c,0x333c0369}},	//   تاجا, _महाश, _coxs, liux_, 
   {{0x7bc5b3cc,0x7d1403b9,0x0ca8012d,0x00000000}},	//   guju, _doxs, _क़ीम, --, 
   {{0x6f049ff4,0xaca40248,0x333c0381,0x00000000}},	//   _unic, _itọw, niux_, --, 
   {{0x8d745694,0xbeb80023,0xe7ec0037,0x00000000}},	// [2f840] _واخا, thëv, छौना_, --, 
   {{0x7bc5b3cd,0xb90400cf,0x00000000,0x00000000}},	//   buju, онуз_, --, --, 
   {{0xcb680484,0x38c805af,0x00000000,0x00000000}},	//   _ване_, شالی_, --, --, 
   {{0xd6d800d6,0x6d5c49da,0xf740013e,0xbeb80240}},	//   йті_, lora, мехо, shëv, 
   {{0x7d1403be,0x2560007f,0xddcc0139,0x88c4007b}},	//   _yoxs, kòlt_, _myaş, _وتسل, 
   {{0x6d5db3ce,0xddcc0139,0x00000000,0x00000000}},	//   nora, _lyaş, --, --, 
   {{0x29d4006a,0x6d5c32e5,0x17c400c7,0x291801e7}},	//   läa_, iora, _нарҭ, _iora_, 
   {{0x3a3c107d,0x86740022,0x98140736,0x00000000}},	//   _župi_, _дызц, _عبّا, --, 
   {{0x7bc41b24,0xaca40248,0xc108004e,0xfb1800df}},	//   zuju, _atọw, аэне_, שופמ, 
   {{0x6d5db3cf,0x7bc400ca,0x6124068c,0x2919b3d0}},	//   jora, yuju, _vòlo, _jora_, 
   {{0x7d140007,0xe18800a2,0x00000000,0x00000000}},	//   _roxs, _iỳm_, --, --, 
   {{0x2919b3d1,0x7bc40a73,0x6d5c017a,0x95840023}},	//   _lora_, vuju, eora, _ምሃብን_, 
   {{0xee85b3d2,0xbeb80023,0x2918036e,0x2b400009}},	//   дыро, dhët, _oora_, diic_, 
   {{0x6d5db3d3,0x7bc44aa5,0x2919b3d4,0xe0d4010f}},	//   gora, tuju, _nora_, _זײַ_, 
   {{0x2b4001d9,0x7bc40194,0xac1800f7,0xab9401ec}},	//   fiic_, uuju, оору_, дисі, 
   {{0x7bc5b3d5,0x3f9db3d6,0x2919b3d7,0x6d400124}},	//   ruju, mptu_, _aora_, émar, 
   {{0x2919b3d8,0x5a3464e1,0xba75b3d9,0x25600ba1}},	// [2f850] _bora_, чнат, زارت, nòls_, 
   {{0x6d5c3af1,0x8308025c,0x3eb80051,0x00000000}},	//   cora, _ཀོའུ_, _hdqt_, --, 
   {{0x7bc4013c,0x2b40058a,0xa9d80154,0x67d47d60}},	//   quju, biic_, সিগঞ, доху, 
   {{0x29d4006a,0x29180332,0xcc74011a,0x6fbc134e}},	//   bäa_, _eora_, _מעתה_, लूटू, 
   {{0x291933c8,0x25600ba1,0x6124007f,0x2a64004e}},	//   _fora_, jòls_, _pòll, _жърг, 
   {{0x2919080b,0x7d000174,0x6348013a,0x00000000}},	//   _gora_, _ónsd, běnk, --, 
   {{0x67d40372,0x25600100,0x00000000,0x00000000}},	//   _оору, vòlt_, --, --, 
   {{0x1309b3da,0x612400db,0xdcec031c,0x56948e21}},	//   сний_, _dòlm, _ftaħ, _хаат, 
   {{0x6d5db3db,0xb9d002d3,0x51580006,0x3f9c00ef}},	//   yora, _ኻኣ_, йшоў_, eptu_, 
   {{0x6d5db3dc,0x308400f7,0x2918679e,0x799800a2}},	//   xora, өшүү_, _xora_, _çuwu, 
   {{0xb4e4069f,0x6d5db3dd,0xbeb8d267,0x00000000}},	//   यजी_, vora, rkën, --, 
   {{0x6d5db3de,0xbeb98e57,0xa3e80a8a,0xdb1401e1}},	//   wora, dhës, यबर_, _òbèl, 
   {{0x2ce8025c,0x25600ba1,0x10a40022,0xa2d000dc}},	//   _སྲུབ, còls_, _еилн, _धात्, 
   {{0xd1f8001f,0x8b942bbd,0xc27805d0,0x50d40133}},	//   _ገብቶ_, зрач, _פרסי, _رزتر, 
   {{0xfc0017be,0x2919b3df,0x6d40007f,0xed5001d3}},	//   нпро, _rora_, émaq, ٹھک_, 
   {{0x2919b3e0,0x6d5db3e1,0x29d42776,0xc050011a}},	//   _sora_, sora, täa_, _רזה_, 
   {{0x6d5db3e2,0x2919b3e3,0x2b416078,0xbeb800e4}},	// [2f860] pora, _pora_, riic_, ahës, 
   {{0x6d5db3e4,0x29183089,0x9f5c07c5,0xdb140036}},	//   qora, _qora_, _arvè_, erzä, 
   {{0x2919b3e5,0xbeb93e03,0xdcec0327,0x7ae400f1}},	//   _vora_, chës, _staħ, _کوټې_, 
   {{0x2919b3e6,0x645c0194,0xba380ba1,0x9418016b}},	//   _wora_, _ørii, _reïv, _ɛsɔ_, 
   {{0x29180598,0x6aa4198f,0x612401ab,0x28cc01ad}},	//   _tora_, mbif, _sòlm, ालदि, 
   {{0xf99c02e2,0x6348012c,0x3f9c2507,0x69c5b3e7}},	//   _brèf_, měni, yptu_, mrie, 
   {{0x69c5b3e8,0xc764129d,0x33900108,0x46a4014b}},	//   lrie, _فارى, нащё, _навв, 
   {{0x6aa5b3e9,0x77b8011a,0x00000000,0x00000000}},	//   nbif, _למלח, --, --, 
   {{0x69c5b3ea,0x0575b3eb,0x00000000,0x00000000}},	//   nrie, _فائد, --, --, 
   {{0x3a3406a9,0x69c5b3ec,0x2560067c,0x660002d0}},	//   פרים_, irie, ròls_, _irmk, 
   {{0x69c5b3ed,0xbeb802d3,0xf99c007f,0x00000000}},	//   hrie, dhër, _grèf_, --, 
   {{0x69c5b3ee,0x2560067c,0xba380129,0x6d400100}},	//   krie, pòls_, _keït, èman, 
   {{0xfafc036e,0xada402d5,0x69c40135,0x00000000}},	//   _ohër_, наўл, jrie, --, 
   {{0xbeb8044e,0x6d4000e4,0x6348013a,0x7c840150}},	//   thës, émap, děni, яуме, 
   {{0x69c5b3ef,0x38c001e1,0x8ccc033f,0x998800d7}},	//   erie, _lérà_, _तारो, dzaš_, 
   {{0x69c5b3f0,0x7f28040b,0xd1c80092,0x00000000}},	//   frie, _دستِ_, _ጠለቅ_, --, 
   {{0x69c5b3f1,0xbeb80023,0xdce400b8,0xff5c035b}},	// [2f870] grie, shës, _jihī, moî_, 
   {{0x3f8c0e14,0x98b80220,0xbeb80036,0x7c380115}},	//   _kufu_, ілет_, phës, ĝurb, 
   {{0x69c5b3f2,0x6aa40a55,0x2ce8031c,0x2bac01ad}},	//   arie, bbif, _སྲིབ, टीदा, 
   {{0x3f8c0337,0x3a3c107d,0xe69400c7,0x00000000}},	//   _mufu_, _župu_, еицы, --, 
   {{0x3f8c06d6,0x69c5b3f3,0x82e8031c,0xe3b8510c}},	//   _lufu_, crie, _རྒེའ, _avı_, 
   {{0xba38004e,0xdb05b3f4,0x00000000,0x00000000}},	//   _deït, _avhø, --, --, 
   {{0x98a000b0,0xc9500375,0xdcfc2ca8,0xe7081c3e}},	//   hihī_, _סמל_, nssı, تتەن_, 
   {{0xf771b3f5,0x798db3f6,0x61240100,0x98a000b0}},	//   _ساز_, _kucw, _fòlk, kihī_, 
   {{0x2019b3f7,0xff5c025a,0x61240100,0x6738036e}},	//   ärin_, doî_, _gòlk, ëvje, 
   {{0x3f8c31a9,0x70c40490,0xd250030f,0x92bc00eb}},	//   _bufu_, ललेल, _ینا_, ইভে_, 
   {{0x69c401a2,0x798c2959,0xcee9b3f8,0xaca4063f}},	//   zrie, _lucw, одне_, stịk, 
   {{0x69c5b3f9,0xd5d02ce6,0x7984014b,0xcf3800d6}},	//   yrie, _समाज, _lijw, ічні_, 
   {{0xfe7c004e,0x22580022,0xbeb80240,0xc3300375}},	//   beïm_, _еицы_, thër, _בוא_, 
   {{0x69c5b3fa,0x3f8db3fb,0x3d901ee3,0xc15000ec}},	//   vrie, _fufu_, тиёр, _لکپڙ, 
   {{0x69c5b3fc,0x2e3402d2,0x3f8c032e,0x00000000}},	//   wrie, _búfé_, _gufu_, --, 
   {{0x798c6f15,0x69c5b3fd,0xbeb802d3,0xbac40014}},	//   _bucw, trie, shër, وژُن_, 
   {{0x69c40dd4,0x79840cf9,0x63a42f61,0x6aa5b3fe}},	// [2f880] urie, _bijw, ćini, rbif, 
   {{0x8d75b3ff,0x69c5b400,0x6124068c,0x00000000}},	//   _تابا, rrie, _còlh, --, 
   {{0x7984073c,0x636c002d,0xc7e800cf,0x0ca80709}},	//   _dijw, fûnl, تىان_, करीम, 
   {{0x9f5c01f1,0x7c540014,0x96d801ad,0x86440120}},	//   _prvé_, _زلُر_, फ्लॉ, мнеж, 
   {{0xba38017a,0xd90c2099,0x14c80073,0x69d8054e}},	//   _deïs, _گیل_, _राखण, ăves, 
   {{0x61240100,0xc5fc0171,0x98f40024,0x00000000}},	//   _vòlk, _ķēde_, _пясч, --, 
   {{0x82e8025c,0xd90c0b28,0x00000000,0x00000000}},	//   _རྒུའ, _دیل_, --, --, 
   {{0xba380f49,0x3f8c05b8,0x6600020b,0x7985b401}},	//   _geïs, _rufu_, _trmk, _zijw, 
   {{0x3f8db402,0x05640139,0xf74005c5,0x00e800d8}},	//   _sufu_, _жван, _рето, оќни_, 
   {{0x855404fb,0xbeb80240,0x3f8c0356,0xdce4002b}},	//   _تیتر_, rkëm, _pufu_, _vihī, 
   {{0x84700240,0x00000000,0x00000000,0x00000000}},	//   _ብቕሉዕ_, --, --, --, 
   {{0x42244a81,0xbeb80200,0x00000000,0x00000000}},	//   _одев, thëq, --, --, 
   {{0xd2f40451,0x09e4009e,0x2bac0073,0x2e340241}},	//   _سکيا_, নিডা, टीसा, _rúfé_, 
   {{0x3f8db403,0xdb1401ed,0xfba801c6,0x291c007c}},	//   _tufu_, mszé, жтай_, öval_, 
   {{0x79840d27,0xd24c07d6,0x69d80165,0x5f94030d}},	//   _rijw, _نچی_, ńvel, _яийт, 
   {{0x7984b70b,0x69c001e4,0x79a40120,0x00000000}},	//   _sijw, _ĥmer, држе, --, 
   {{0x79840113,0x81cc03d4,0x2ac40241,0xdb1400e5}},	// [2f890] _pijw, ৱিক_, _sèbà_, nszé, 
   {{0x6124004e,0x7984047e,0x7c6400d1,0x00000000}},	//   _bòli, _qijw, _يادل, --, 
   {{0xe6116657,0x6124381a,0x00000000,0x00000000}},	//   یشه_, _còli, --, --, 
   {{0x7984016d,0x69d80356,0x00000000,0x00000000}},	//   _wijw, ăver, --, --, 
   {{0x612400cf,0x7984014f,0x65940faf,0xc0f00023}},	//   _eòli, _tijw, вачу, ሃስስ_, 
   {{0x61249c19,0x7bc40254,0x00000000,0x00000000}},	//   _fòli, orju, --, --, 
   {{0x3b08020c,0xba380373,0x69c0143a,0x2018369a}},	//   _kncq_, _geïr, _åmer, äril_, 
   {{0xfe0c00dc,0x00000000,0x00000000,0x00000000}},	//   ामास_, --, --, --, 
   {{0xa2d012eb,0xdb1400e5,0x1b0000eb,0x00000000}},	//   _धार्, gszé, _একাই_, --, 
   {{0xf8ac05f9,0x4fa40022,0x03bc00cc,0x00000000}},	//   टरिय, ниов, _আহৰণ, --, 
   {{0xd0096974,0xbeb80240,0x6d400ba1,0x7d2c0092}},	//   чене_, thëp, èmam, _ታሪካቸ, 
   {{0xf99c02bd,0x63bc0413,0x00000000,0x00000000}},	//   _otè_, _ærna, --, --, 
   {{0x0d980474,0xf99c01e1,0x7bc4032e,0x00000000}},	//   ятны_, _ntè_, erju, --, 
   {{0xf99c02e2,0xbeb816a6,0x4638010f,0x1de0000d}},	//   _orèb_, shëp, לערע, _फहरत, 
   {{0xf99cf0b6,0x20180140,0x60dc0ba1,0xc2f000eb}},	//   _atè_, ørit_, òrme, ঝারি_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7bc40357,0x61252452,0x49c80137,0xd72003d4}},	// [2f8a0] arju, _sòli, ялан_, পোৱা_, 
   {{0xf99c0100,0x612400cf,0x86c4004b,0x3e58011a}},	//   _dtè_, _pòli, ځيان, _מדפס, 
   {{0x46e83ae0,0xf99c007f,0x8c4400f7,0x9d4435ea}},	//   зден_, _etè_, _чене, _جئين, 
   {{0x61240ffb,0x00000000,0x00000000,0x00000000}},	//   _vòli, --, --, --, 
   {{0xa4d40d30,0x00000000,0x00000000,0x00000000}},	//   волі, --, --, --, 
   {{0xd5d0000d,0x00000000,0x00000000,0x00000000}},	//   _समरज, --, --, --, 
   {{0xf1bc0306,0xe8cc0073,0xe79803b9,0x00000000}},	//   šál_, ालीच, dəçı, --, 
   {{0xdb1401d3,0xb7d80375,0xa28568e3,0x00000000}},	//   tszé, _מקלי, نیاو, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc05922cf,0xd490004d,0x00000000,0x00000000}},	//   зім_, _hàn_, --, --, 
   {{0x41c0878d,0xdb1401d3,0x9f3400d3,0x00000000}},	//   _शिवस, sszé, вені, --, 
   {{0xdd943ae0,0xd04000ac,0xd1b80092,0xf45400d9}},	//   камы, nglə, ዲገቡ_, _איבר_, 
   {{0x3e68013e,0xd490004d,0xc1e001ee,0x52b001af}},	//   яшон_, _màn_, _сөйҙ, _тҡыс, 
   {{0x7bc409a8,0xed8800c7,0xc05802bf,0x71740212}},	//   trju, есск_, _ній_, _збір_, 
   {{0xf99c0ffb,0x2bac0892,0x00000000,0x00000000}},	//   _stè_, टीला, --, --, 
   {{0xbe887288,0x9f5c013a,0x00000000,0x00000000}},	//   _эске_, _krví_, --, --, 
   {{0x58d5471c,0xae04030c,0x38c40108,0x00000000}},	// [2f8b0] коат, _مويى, ещев, --, 
   {{0xcf8c168d,0x00000000,0x00000000,0x00000000}},	//   _دژی_, --, --, --, 
   {{0x6348012c,0xd490004d,0x00000000,0x00000000}},	//   něns, _bàn_, --, --, 
   {{0xfca819bc,0x99880030,0x9b600131,0x00000000}},	//   _باکو_, dzať_, _ئۆرۈ, --, 
   {{0xb5a4c45c,0xd4900051,0x00000000,0x00000000}},	//   хрей, _dàn_, --, --, 
   {{0xd469b404,0xdb1404d4,0xd1b80092,0x00000000}},	//   миле_, puzó, ዲገባ_, --, 
   {{0xa9544c04,0x00000000,0x00000000,0x00000000}},	//   _скрі, --, --, --, 
   {{0xf99c1497,0x21dc01ec,0x2c7c559d,0x00000000}},	//   _grèc_, _ﺃﺴﺒﻭ, ládé_, --, 
   {{0xc690025f,0x998800d0,0x5f1408df,0x80d800eb}},	//   _כאן_, azať_, धान्_, বজন্, 
   {{0x41c00b7c,0x6594586a,0x00000000,0x00000000}},	//   _शिरस, _сафу, --, --, 
   {{0xd4900051,0x23780055,0x00000000,0x00000000}},	//   _hào_, _ūrje_, --, --, 
   {{0x0ca80782,0x00000000,0x00000000,0x00000000}},	//   कर्म, --, --, --, 
   {{0x9f5800bc,0x201806ea,0x0e540395,0x6cb400db}},	//   írá_, ørir_, тъня, лөнт, 
   {{0x23600bb8,0x612402e2,0x8fd001e0,0x1d180108}},	//   čije_, _sòlv, _кәмә, нюсь_, 
   {{0x65b800d2,0x6124004e,0xd4900051,0x9c58292c}},	//   _kúhá, _pòlv, _lào_, ешту_, 
   {{0xd01005d9,0xf3f000cc,0x00000000,0x00000000}},	//   _ملڻ_, _অপাৰ_, --, --, 
   {{0xd49001fb,0x3a20009d,0xe6940150,0x00000000}},	// [2f8c0] _nào_, амтг, қилы, --, 
   {{0x0c25b405,0xd4900208,0x88b000cc,0x00000000}},	//   _амон, _sàn_, _চাহক, --, 
   {{0x8ba5b406,0x2cb9b407,0xfafc0023,0x00000000}},	//   _шинж, mard_, _ikën_, --, 
   {{0xd4900051,0x00000000,0x00000000,0x00000000}},	//   _bào_, --, --, --, 
   {{0x61240100,0x2cb80334,0x2c7c0241,0x00000000}},	//   _kòlt, oard_, bádé_, --, 
   {{0xb904015b,0x234802f2,0x00000000,0x00000000}},	//   _মো_, کستی_, --, --, 
   {{0x743c044e,0x6124004e,0x68fc01e7,0xd4900051}},	//   _ክንገብ, _mòlt, _iard, _tàn_, 
   {{0x9f5c00d0,0x57a80451,0xa2f41422,0x00000000}},	//   _prví_, _سافٽ_, упич, --, 
   {{0x25ec068f,0x0665b408,0xda041fe5,0xc0c9b409}},	//   _आईटी_, _شارپ, रियत_, муне_, 
   {{0x68fdb40a,0x2cb80219,0x6115b40b,0x0f7001e0}},	//   _jard, jard_, удоу, ҙғыр, 
   {{0x68fdb40c,0x63a41326,0x2cb9b40d,0xe3b01374}},	//   _mard, ćins, dard_, _چرچ_, 
   {{0x68fdb40e,0xc244af9e,0x29040134,0x82a47a9c}},	//   _lard, _инек, _ɔmaa_, _радж, 
   {{0x68fdb40f,0x2cb84c15,0x612401ab,0xdbd000a2}},	//   _oard, fard_, _sòlu, _düýg, 
   {{0x68fdb410,0x6720209c,0x7090020a,0xe8cc1a4e}},	//   _nard, _lomj, _кашф, ालोच, 
   {{0xa5cc1533,0xd174b6f6,0x2a987eeb,0x00000000}},	//   _समझौ, _сыцы, _ọba_, --, 
   {{0x68fc4e06,0xc1000323,0x67200921,0x2cb9abf7}},	//   _aard, _сүүл, _nomj, aard_, 
   {{0x68fc86df,0x2cb9b411,0x00000000,0x00000000}},	// [2f8d0] _bard, bard_, --, --, 
   {{0x6934a6e6,0xf99c0ba1,0x25ec012d,0x00000000}},	//   ануу, _crèa_, _आईजी_, --, 
   {{0x68fdb412,0x6721b413,0xdb1401ed,0x00000000}},	//   _dard, _bomj, lszí, --, 
   {{0xa564415f,0x68fdb414,0xdbd0007d,0x65b8063f}},	//   یدون, _eard, _müüg, _ụhar, 
   {{0x2d9c151c,0x6721b415,0xdb1401ed,0x65b800d7}},	//   _čvek_, _domj, nszí, _rúhá, 
   {{0xd490001e,0xf1bc0308,0x04700055,0xe610114f}},	//   _vào_, šák_, _hūṃk, تشم_, 
   {{0x9404009a,0x00000000,0x00000000,0x00000000}},	//   اوبه, --, --, --, 
   {{0x68fdb416,0x2cb9b417,0x25ec0073,0xdb1400e5}},	//   _zard, zard_, _आईची_, kszí, 
   {{0x68fdb418,0xdb1401d3,0xd4900051,0x15b000db}},	//   _yard, jszí, _hàm_, _چەچس, 
   {{0xb9200201,0x68fdb419,0x67200921,0xc18000e5}},	//   _ተማሪዎ, _xard, _zomj, مینٹ, 
   {{0x7779b41a,0x67200921,0x2018013c,0x2054d646}},	//   _khux, _yomj, ørip_, итюр, 
   {{0x2cb8ae23,0x612405d5,0x11d40153,0x00000000}},	//   ward_, _sòlt, _бікр, --, 
   {{0xd490001e,0x77780327,0x2cb83046,0xb284bcf8}},	//   _làm_, _mhux, tard_, _рыжк, 
   {{0x2d8db41b,0x8c440bd6,0xfde400f1,0x00000000}},	//   öde_, геге, اکيو_, --, 
   {{0x2cb80221,0xc0d000cf,0x6124033b,0x68fdb41c}},	//   rard_, _ايىب, _vòlt, _rard, 
   {{0x765803be,0x2cb900f5,0xbb41b41d,0x00000000}},	//   _oxuy, sard_, беск, --, 
   {{0x68fdb41e,0x67216112,0xa9440032,0x27f8123b}},	// [2f8e0] _pard, _romj, адаһ, _ssrn_, 
   {{0x68fdb41f,0x8d74005e,0x67200472,0x6d40a86a}},	//   _qard, _حابا, _somj, ëmad, 
   {{0x8ca8107c,0xddcc0bb8,0x67200558,0x76580548}},	//   _ज्यो, _izaš, _pomj, _axuy, 
   {{0x68fd8d44,0x7779b420,0xbeb80200,0x201801f4}},	//   _ward, _chux, skëv, ärii_, 
   {{0x15d800dd,0x77780014,0xfe0402ab,0xa5f9b421}},	//   ندوں_, _dhux, शियस_, телу_, 
   {{0x67200117,0x68fc0857,0x15b0215c,0x00000000}},	//   _womj, _uard, تەكس, --, 
   {{0x67211428,0xfe7c00db,0x44f40011,0x79540354}},	//   _tomj, leït_, চালক_, _сирĕ, 
   {{0xded002d3,0x00000000,0x00000000,0x00000000}},	//   _ቦትኡ_, --, --, --, 
   {{0x2904013b,0x26c40014,0xfe7c004e,0x00000000}},	//   _ɔman_, _idmo_, neït_, --, 
   {{0xdbd00037,0xdcb00208,0x00000000,0x00000000}},	//   _püüg, ửi_, --, --, 
   {{0xc2e40517,0x9f54023a,0x09dc0327,0xbeb800e8}},	//   _бўли, ивоч, _རཱྀ_, kkët, 
   {{0x77780240,0xdb1400e5,0x00000000,0x00000000}},	//   _xhux, tszí, --, --, 
   {{0xdd945203,0xf99c0066,0xe3b00451,0x15b800d1}},	//   рагы, _arèn_, _اڱڻ_, ﻧﻴﺎﺩ, 
   {{0xdb1401d3,0xfc2c0023,0x00000000,0x00000000}},	//   rszí, _ጽልግል, --, --, 
   {{0xdb1401ed,0x116804fb,0xdfd402dd,0x00000000}},	//   sszí, _جلوی_, _тойы, --, 
   {{0x25a00dc9,0x7b640946,0x00000000,0x00000000}},	//   ̭ila_, утге, --, --, 
   {{0xa8840131,0x00000000,0x00000000,0x00000000}},	// [2f8f0] ەللى, --, --, --, 
   {{0x26c4011f,0xf99c0100,0x77780169,0xfafc0200}},	//   _admo_, _frèn_, _shux, _ikëm_, 
   {{0xba74168d,0xd7f01e4a,0x61e00334,0x57f40108}},	//   _ڕاست, تكا_, html, рпет, 
   {{0xe5680075,0xa2d00490,0x8c1800d9,0x00000000}},	//   ۇمنى_, _धाग्, _סורי, --, 
   {{0xeef800c8,0x00000000,0x00000000,0x00000000}},	//   טמאר_, --, --, --, 
   {{0xe894256e,0x19580026,0x9424013d,0x00000000}},	//   _гарь, _рагы_, имле, --, 
   {{0xdbd00166,0x53a400cf,0xd7c81d0a,0xbeb80200}},	//   _küñg, шайб, _جوزه_, nkës, 
   {{0x1309b422,0x7778014b,0x00000000,0x00000000}},	//   тний_, _uhux, --, --, 
   {{0xded402d3,0x52746963,0x5f081be1,0x77900345}},	//   ክንን_, шуку, ियन्_, _ئیڤا, 
   {{0x23601050,0x2dc801d5,0x00000000,0x00000000}},	//   čija_, ққон_, --, --, 
   {{0xb4c07220,0x3cc803d4,0x00000000,0x00000000}},	//   ्ली_, িভাৱ, --, --, 
   {{0xe4480302,0x9f5c01f1,0x8e852042,0x51f402da}},	//   _حلمى_, _prvá_, игне, _نستر, 
   {{0x8e74084c,0x47180375,0x00000000,0x00000000}},	//   рунч, דורג, --, --, 
   {{0xfafc01c7,0x4f9453ab,0xbeb801c7,0xfe7c004e}},	//   _aaë_, _криу, fkës, veït_, 
   {{0xfe7c0129,0x00000000,0x00000000,0x00000000}},	//   weït_, --, --, --, 
   {{0x9f5c0122,0xb4c0146c,0x88b003d4,0x00000000}},	//   _trvá_, ्लु_, _চাইক, --, 
   {{0xc8940f14,0x636d13e1,0xbeb84113,0x0d740153}},	// [2f900] арењ, mûnt, rkët, _выня, 
   {{0x78b93dd9,0xf99c0066,0xddcc01a6,0x636c000f}},	//   _œuvr, _trèn_, _uzaš, lûnt, 
   {{0x25a4032e,0x00000000,0x00000000,0x00000000}},	//   _stml_, --, --, --, 
   {{0xbeb80023,0x636c002d,0xfe7c004e,0xf4180154}},	//   lkër, nûnt, peït_, তনার_, 
   {{0x6b844ba2,0xb4c008e9,0x2b9c004d,0x4584009d}},	//   mmig, ्लू_, _híc_, агдв, 
   {{0x6b85b423,0x03c53285,0xa4d80024,0x36880408}},	//   lmig, асим, удку_, ĕсен_, 
   {{0xdb1401ed,0xd49802bf,0x6b84000d,0x987400f3}},	//   lszá, урі_, omig, _гутљ, 
   {{0x6b852e21,0x2b9c0051,0xbeb80200,0xdcec00de}},	//   nmig, _míc_, shëz, _staļ, 
   {{0xdb1400dd,0x6b840af9,0xbeb81bce,0x2b9c01ef}},	//   nszá, imig, kkër, _líc_, 
   {{0x6b840730,0x99b0015b,0xf8b0008f,0xded40023}},	//   hmig, _চমৎক, ֿשר_, ክዕን_, 
   {{0x6b8401d5,0x41c060c7,0x2b9c0051,0x00000000}},	//   kmig, _शिकस, _níc_, --, 
   {{0x6b85b424,0xdb1401d3,0x00000000,0x00000000}},	//   jmig, kszá, --, --, 
   {{0x7de40220,0x6b840067,0x7d0003b2,0xdb1401d3}},	//   шінд, dmig, _ónsk, jszá, 
   {{0xc0444028,0x6b8400c5,0x24b403d4,0xdb1400e5}},	//   _پختو, emig, _ঘাঁহ, dszá, 
   {{0x636c00d2,0xf99c007f,0xb178008f,0x6b84017a}},	//   bûnt, _erèl_, _שטור, fmig, 
   {{0x9ed8676b,0x6b841c06,0xbeb80a40,0x2c7c02d2}},	//   _смит_, gmig, rkës, _sádí_, 
   {{0xb9580ffb,0xdb1401ed,0xbeb8995d,0x00000000}},	// [2f910] _avìa, gszá, skës, --, 
   {{0xf804ed5a,0x6b840037,0x39440ba1,0x6d400129}},	//   ичен, amig, òns_, èmat, 
   {{0xf99c004d,0x298807b5,0x28f807d5,0xc2040014}},	//   _trèo_, рсто_, рехь_, _کٔ_, 
   {{0x1a6402f2,0xdb1400e5,0x1ae400cc,0x00000000}},	//   _هیزی_, bszá, _পোৰা, --, 
   {{0xf99c033b,0xe7b40131,0xd4900208,0x00000000}},	//   _krèm_, ممەد, _hài_, --, 
   {{0xb4c005d7,0x85080220,0x291c0267,0xdb140210}},	//   ्ले_, лдің_, övat_, przó, 
   {{0x27fc005c,0x00000000,0x00000000,0x00000000}},	//   ævnt_, --, --, --, 
   {{0x636c002d,0x1634dcc6,0x00000000,0x00000000}},	//   dûns, _лебя, --, --, 
   {{0x1ae40183,0xa5f802dd,0xd5b0009a,0x00000000}},	//   _পোৱা, _кету_, _رفا_, --, 
   {{0xa42446e8,0x64a40640,0x758001d5,0xf8a4000d}},	//   сьәл, _мађа, _بیتم, गडिय, 
   {{0xdb1401ed,0x54740451,0xe1884fde,0xe50801e2}},	//   zszá, _اٿار, جئين_, _خيلو_, 
   {{0x99880960,0xdb1401d3,0x9104010a,0x00000000}},	//   jzaž_, yszá, _ӳпле, --, 
   {{0x52840597,0xf99c007f,0xd7e0025c,0x636c045f}},	//   _الشك, _brèm_, _ཤཱཀྱ, rûnt, 
   {{0x636c002d,0xe0480330,0x6b8479d4,0x2b9db36e}},	//   sûnt, اشیه_, wmig, _píc_, 
   {{0x201802f6,0xd49001fb,0x6b840254,0x00000000}},	//   ärit_, _bài_, tmig, --, 
   {{0x2b9c0316,0xdb1401ed,0xd490004d,0xbeb80240}},	//   _víc_, tszá, _cài_, skër, 
   {{0x3b040801,0xf99c0100,0x08c5b425,0xd490004d}},	// [2f920] щето_, _frèm_, йбан, _dài_, 
   {{0xdb14066d,0xb4c0038e,0x6b85b426,0x2b9c0051}},	//   rszá, ्लो_, smig, _tíc_, 
   {{0xdb1400dd,0x8d74082a,0xb4c000bc,0x00000000}},	//   sszá, _پاکا, ्लै_, --, 
   {{0xd6d94012,0xeb3400cf,0x6b84016d,0xdb1401d3}},	//   иті_, _بۉرد, qmig, pszá, 
   {{0x3ab00daf,0x291c0267,0xdb0c0248,0x00000000}},	//   _хәст, övas_, _àkám, --, 
   {{0xdb0406af,0xba7401ec,0x00000000,0x00000000}},	//   _athè, _داپت, --, --, 
   {{0xa31816ab,0x00000000,0x00000000,0x00000000}},	//   ижку_, --, --, --, 
   {{0x2360151c,0xae1806ab,0xd4900208,0x33f000d1}},	//   čijo_, दमान_, _xài_, سسىس, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdc9000b5,0x7c38010f,0xd37800db,0xc564009f}},	//   _mm色_, ŝuri, лчө_, _اُئي, 
   {{0xd36c0372,0xede40327,0xdef40108,0x42c8014b}},	//   رۇۇ_, _ཧཱུྃ, опны, _бген_, 
   {{0x636c002d,0x00000000,0x00000000,0x00000000}},	//   rûns, --, --, --, 
   {{0x13ac00bd,0x442db427,0xdce40055,0x12a80150}},	//   _গিয়, lyf_, _akhā, _ﺴﺘﻀﺭ, 
   {{0x2018dcd4,0x2d8c0209,0xd4900208,0x51380228}},	//   äris_, ňden_, _sài_, _ۅزۉڭ_, 
   {{0x7b741d93,0x6c3400d8,0x00000000,0x00000000}},	//   مطرا, перѕ, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x98b80075,0xf99c0066,0x442c000f,0xd490004d}},	// [2f930] илат_, _trèm_, hyf_, _vài_, 
   {{0x7f4c003a,0x442c0af9,0x00000000,0x00000000}},	//   licq, kyf_, --, --, 
   {{0xf99c0100,0xd49001fb,0x00000000,0x00000000}},	//   _krèk_, _tài_, --, --, 
   {{0xb4c000af,0x291c0267,0x442c010e,0x00000000}},	//   ्ल्_, övar_, dyf_, --, 
   {{0x9f9409a5,0xf7701973,0x35e400d6,0x69d80165}},	//   lýän_, _ہار_, сцев, ńver, 
   {{0x7f4c0784,0x1ab00154,0x00000000,0x00000000}},	//   hicq, _ছায়া, --, --, 
   {{0x442c0b21,0x63e40137,0xdb05b428,0xf99c0066}},	//   gyf_, كسيك, _athé, _orèk_, 
   {{0x3a3c1155,0x00000000,0x00000000,0x00000000}},	//   _župy_, --, --, --, 
   {{0x42501bf4,0x00000000,0x00000000,0x00000000}},	//   وچهر, --, --, --, 
   {{0x4fe8016c,0x9f940209,0xa5080063,0x00000000}},	//   амон_, kýän_, _леђа_, --, 
   {{0xe73001d3,0x00000000,0x00000000,0x00000000}},	//   _غصہ_, --, --, --, 
   {{0x9f9400ee,0xdb140036,0x00000000,0x00000000}},	//   dýän_, nszä, --, --, 
   {{0xc3300302,0x20190991,0x00000000,0x00000000}},	//   _קוד_, ärir_, --, --, 
   {{0xd009b429,0xe2800184,0xf99c007f,0x13dc00cc}},	//   _веке_, _яғын, _erèk_, _ভৈয়, 
   {{0xfc01b42a,0x4fc12374,0x1ab0015b,0x9f94010e}},	//   мпро, _تەجە, _ছাড়া, gýän_, 
   {{0x4aa9b42b,0xf99c033b,0x4e28319b,0x00000000}},	//   ркан_, _grèk_, _воин_, --, 
   {{0xeb981e37,0x6f0401ab,0x799c009a,0x00000000}},	// [2f940] риғ_, _iaic, gqqw, --, 
   {{0x38c82ab4,0x6f05b42c,0x645c0008,0x00000000}},	//   لامی_, _haic, _þrig, --, 
   {{0x6f05b42d,0xba38015d,0x86c47b1d,0x37e001c6}},	//   _kaic, _ffïo, قيان, дохг, 
   {{0x6f05b42e,0x941000ac,0x614001e1,0x7c2000a3}},	//   _jaic, _üzə_, _kálù, _ànra, 
   {{0x6f05b42f,0x442c0368,0x798002e3,0xd490004d}},	//   _maic, wyf_, ọwar, _màu_, 
   {{0x442c0a85,0x69c5b430,0xd6a8104b,0x3cd0033f}},	//   tyf_, msie, لدۇم_, _ताज़ा, 
   {{0x69c5b431,0xf99c0066,0xd6f40154,0x37e0004e}},	//   lsie, _arèh_, ছাড়া_, _оорг, 
   {{0x442c0591,0x6aa40399,0x6f05b432,0x247c044e}},	//   ryf_, ncif, _naic, _ብዕለት_, 
   {{0x69c5b433,0x442c0b21,0x973400f7,0x3f9c0327}},	//   nsie, syf_, _ээрч, wqtu_, 
   {{0x69c5b434,0x2ee001fa,0x225801ec,0x00000000}},	//   isie, _acif_, _қилы_, --, 
   {{0xc058005e,0x6f05b435,0x09e404c5,0x69c40399}},	//   ріп_, _baic, নিটা, hsie, 
   {{0x69c5b436,0xb8740092,0x00000000,0x00000000}},	//   ksie, ያመጣው_, --, --, 
   {{0x69c5b437,0x6f04019b,0xc2540133,0xada40006}},	//   jsie, _daic, _بخات, маўл, 
   {{0x69c5b438,0x776801f0,0x399c0356,0x63a40115}},	//   dsie, zogx, _rîs_, ĉinf, 
   {{0x69c5b439,0x6f040192,0x7768014b,0xac95b43a}},	//   esie, _faic, yogx, дарш, 
   {{0x6f05b43b,0x7768014b,0x80b401e2,0x00000000}},	//   _gaic, xogx, _انګړ_, --, 
   {{0x9f9409a5,0x69c5b43c,0x00000000,0x00000000}},	// [2f950] rýän_, gsie, --, --, 
   {{0x60dc00a3,0xad2400d1,0x6f0400ef,0x00000000}},	//   òrmh, _يىيى, _zaic, --, 
   {{0x6f05b43d,0x69c4e468,0xc0480023,0x7d1403ac}},	//   _yaic, asie, _ኣሕሊፍ, _inxs, 
   {{0x6aa40072,0x19953a2a,0x6d54012d,0xa0380023}},	//   ccif, _намя, ągał, ብልናታ, 
   {{0x0ae801c8,0x00000000,0x00000000,0x00000000}},	//   _ارپي_, --, --, --, 
   {{0xdb1401c7,0x00000000,0x00000000,0x00000000}},	//   sszä, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4390033a,0x66f4d63e,0x00000000,0x00000000}},	//   најс, _опсу, --, --, 
   {{0x6f04601a,0xd1b800cf,0x15e800d1,0x941806be}},	//   _raic, حابا_, ﺎﻧﺪﻩ, _əsə_, 
   {{0x7aec02c4,0x6f05b43e,0xb7fc05f9,0x645c00d7}},	//   _lbct, _saic, _ईनाम_, _žrie, 
   {{0x69c40399,0x3144044e,0x6f05b43f,0x00000000}},	//   zsie, _ንእግዚ, _paic, --, 
   {{0x630449c6,0x69c5b440,0x63480210,0x00000000}},	//   _يولل, ysie, yśni, --, 
   {{0x6f05b441,0x69c40369,0x00000000,0x00000000}},	//   _vaic, xsie, --, --, 
   {{0xcfe9b442,0x6f05b443,0x320c020c,0x69c40ea0}},	//   _هفته_, _waic, _irgy_, vsie, 
   {{0x6f05b444,0x4cdc0c58,0xd4900208,0x6aa40205}},	//   _taic, য়লু, _tàu_, tcif, 
   {{0x69c5b445,0x3f6406bb,0x7f540798,0x00000000}},	//   tsie, _нищо_, _најс_, --, 
   {{0x6aa5b446,0xcc883e66,0x69c5b447,0xbb402cc8}},	// [2f960] rcif, _گنده_, usie, хетк, 
   {{0x69c5b448,0x7aec0408,0x6aa5b449,0xbeb800e8}},	//   rsie, _ebct, scif, njën, 
   {{0xcc88415f,0x7aec208d,0x660000b5,0xfe0401ad}},	//   _دنده_, _fbct, _ssmk, शिअस_, 
   {{0x320c0354,0xe8f00451,0x69c42bab,0x629c0118}},	//   _orgy_, _ڄڻا_, psie, ěrok, 
   {{0x6d5db44a,0xfafc002e,0xdcec01e4,0x9f5c0030}},	//   onra, _bjëf_, _etaĵ, _prvú_, 
   {{0x6d5db44b,0x7aec0810,0x00000000,0x00000000}},	//   nnra, _zbct, --, --, 
   {{0x6d5db44c,0xd90c1518,0x291806af,0x349034ac}},	//   inra, _خیل_, _inra_, нашр, 
   {{0x320c4ba8,0x6d5c0e78,0xc7641183,0x333c025c}},	//   _brgy_, hnra, _رازى, ghux_, 
   {{0x2fc40048,0xdee402d3,0xb2700395,0x00000000}},	//   _avng_, _ምሳኻ_, нлъш, --, 
   {{0x6d5c429b,0xbeb80200,0x525800db,0x00000000}},	//   jnra, gjën, تسىڭ_, --, 
   {{0xf99c007f,0x6d5c0109,0xd5840133,0xbec000ef}},	//   _frèw_, dnra, _تێوه_, _ģībo, 
   {{0xbb18006a,0x09b00183,0x6d5db44d,0x00000000}},	//   _ahîn, _চিনা, enra, --, 
   {{0xd2580227,0xca840952,0x42500a81,0x291801ab}},	//   paņa_, ﻪﭘﺘﻪ_, _سۆدر, _onra_, 
   {{0xd2580227,0xa3d00316,0x6d5db44e,0x00000000}},	//   qaņa_, _वटा_, gnra, --, 
   {{0x70541b74,0x961c005f,0xd34403e6,0x3178011a}},	//   _нашр_, _izņe, _رییه_, _האגד, 
   {{0x29180784,0x6d5c0332,0x2b4000ae,0xec2400db}},	//   _anra_, anra, ghic_, رىقپ, 
   {{0xba741216,0x6f74013d,0x00000000,0x00000000}},	// [2f970] سارت, _ягъф, --, --, 
   {{0x929c012d,0x684401d5,0x9cf40006,0x00000000}},	//   ydło, کَمل, _ўзні, --, 
   {{0x9735b44f,0xfafc1bce,0x2b4000a3,0xed600153}},	//   وکرا, _njëg_, bhic_, ėžti_, 
   {{0xc5f403d4,0x7c3801e4,0x7bc401e3,0x00000000}},	//   চিনা_, ŝurs, msju, --, 
   {{0x7bc5b450,0xe5b55093,0x05a402f2,0xba08010a}},	//   lsju, ейчы, وشوێ, _ухне_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7bc401e3,0xd388005b,0xf48400d8,0x00000000}},	//   nsju, ойке_, чудн, --, 
   {{0x72a00131,0x7bc42306,0x00000000,0x00000000}},	//   رەتن, isju, --, --, 
   {{0xe78400e4,0x6d5c0652,0x00000000,0x00000000}},	//   _чуро, ynra, --, --, 
   {{0x0594006c,0x7bc4fb94,0x00000000,0x00000000}},	//   _قالگ, ksju, --, --, 
   {{0xf99c033b,0x50440166,0x656404e6,0x6d5c03b2}},	//   _grèv_, фенб, éihe, vnra, 
   {{0xf99c007f,0x6d5c4d25,0x7bc4007c,0x00000000}},	//   _ouè_, wnra, dsju, --, 
   {{0xf99c01e1,0x320c0432,0x00000000,0x00000000}},	//   _nuè_, _urgy_, --, --, 
   {{0x0ba81fd6,0x7bc401e3,0x00000000,0x00000000}},	//   قارى_, fsju, --, --, 
   {{0x6d5c0c8c,0x7bc401e6,0x8b940261,0x3950004e}},	//   rnra, gsju, драч, dixs_, 
   {{0x49b808de,0x291803e0,0x00000000,0x00000000}},	//   قائد_, _snra_, --, --, 
   {{0xe18800a2,0x0928be81,0x7bc4017a,0x2b40054e}},	// [2f980] _aỳy_, ожай_, asju, rhic_, 
   {{0x236008a4,0x39500353,0x2b4004ce,0x49780006}},	//   čiji_, gixs_, shic_, ісаў_, 
   {{0x2b41b451,0xdeac0b45,0x2a98063f,0x97a40220}},	//   phic_, _alaƙ, _ọbu_, еріл, 
   {{0x48f80918,0x1da40073,0x00000000,0x00000000}},	//   _उसको_, _गंमत, --, --, 
   {{0xf99c0ba1,0x2ba40073,0x00000000,0x00000000}},	//   _brèu_, _खंडा, --, --, 
   {{0xf99c02bd,0x200c0162,0x00000000,0x00000000}},	//   _prèv_, yvdi_, --, --, 
   {{0xc7642302,0x91c01cd1,0xa4381fdf,0x21a80150}},	//   _قارى, ңәшл, язку_, _ﺴﻨﺘﺭ, 
   {{0xbeb80023,0x99880784,0x00000000,0x00000000}},	//   gjël, myaš_, --, --, 
   {{0x057422de,0x00000000,0x00000000,0x00000000}},	//   _قائد, --, --, --, 
   {{0x945406c8,0xf99cf04f,0xe13800d4,0x7bc40108}},	//   _kēl, _grèu_, їзні_, ysju, 
   {{0x213c0051,0x2f380055,0x00000000,0x00000000}},	//   _vlvh_, _ṅgam_, --, --, 
   {{0xf99c0100,0xdb1401ed,0x7bc403cd,0x14380271}},	//   _krèt_, sszú, vsju, _عينک_, 
   {{0xc2c00451,0x7e280006,0x00000000,0x00000000}},	//   _ٻيڙي, ціна_, --, --, 
   {{0x7bc5b452,0x961c00da,0xc05802bf,0xe0d00014}},	//   tsju, _uzņe, _мій_, _صٲب_, 
   {{0x9f58066d,0x7bc401f4,0x00000000,0x00000000}},	//   író_, usju, --, --, 
   {{0x7bc4cbaf,0x1ae400eb,0x69c800de,0x00000000}},	//   rsju, _পোড়া, _āder, --, 
   {{0xf99db453,0x7bc5b454,0x9998fed2,0x9e3417a0}},	// [2f990] _què_, ssju, سپار_, _чепч, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf99c0100,0x57b4010b,0x00000000,0x00000000}},	//   _arèt_, хбет, --, --, 
   {{0xda700014,0x00000000,0x00000000,0x00000000}},	//   _مُج_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf99c0100,0x00000000,0x00000000,0x00000000}},	//   _drèt_, --, --, --, 
   {{0x64e00490,0x543401d5,0xfafc0200,0x00000000}},	//   _नारळ, عرتر, _ukës_, --, 
   {{0xf99c033b,0xa26c0092,0x00000000,0x00000000}},	//   _frèt_, _አኳኋን_, --, --, 
   {{0xdef002d3,0x00000000,0x00000000,0x00000000}},	//   ውንን_, --, --, --, 
   {{0x19b80135,0xc240003b,0x00000000,0x00000000}},	//   _བསླབ, уньк, --, --, 
   {{0x15900150,0x00000000,0x00000000,0x00000000}},	//   _ﺟﻮﺳﯩ, --, --, --, 
   {{0x9f05b455,0xc7d40375,0x0838010f,0x00000000}},	//   نوپو, עורי_, פערל, --, 
   {{0x5ee00764,0x64640311,0x44e400cc,0x00000000}},	//   _कार्_, ătiţ, _গোটক_, --, 
   {{0x8fd0506f,0x21642cc8,0x8c94003b,0x00000000}},	//   _йәмә, _үтәг, ербі, --, 
   {{0x2f880032,0x629c012c,0xf99c007f,0x3ea801e7}},	//   _оҙон_, ěrov, _orès_, éití_, 
   {{0xc5f4009e,0xc9a80006,0x00000000,0x00000000}},	//   চিতা_, звае_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [2f9a0] --, --, --, --, 
   {{0xf99c1e54,0x270c0208,0x00000000,0x00000000}},	//   _arès_, _ớn_, --, --, 
   {{0x59740006,0x0c940139,0xaaa800db,0x6b5c0139}},	//   тыту, _яшия, _ۉنگۅ_, bägе, 
   {{0xf99c0699,0x78b8110c,0x02bc012c,0xf7413758}},	//   _prèt_, _đuve, _एजेन, лехо, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf99c007f,0xbeb80240,0x00000000,0x00000000}},	//   _erès_, gjëj, --, --, 
   {{0xd32001e4,0x5ee00037,0x00000000,0x00000000}},	//   _kulʈ, _काल्_, --, --, 
   {{0xf99db456,0xf3609c10,0xfe7c01f5,0xfbd0011a}},	//   _grès_, лтын, lgïe_, אתה_, 
   {{0x0565b457,0xf7400f4d,0xd32001e4,0x00000000}},	//   _зван, _сето, _mulʈ, --, 
   {{0xdecc02d3,0x00000000,0x00000000,0x00000000}},	//   ባዉን_, --, --, --, 
   {{0xb50400db,0x00000000,0x00000000,0x00000000}},	//   _سۉيۅ_, --, --, --, 
   {{0xbb1800d2,0xde580006,0x00000000,0x00000000}},	//   _phîm, дамі_, --, --, 
   {{0x636c00d2,0xdb0c01e1,0x00000000,0x00000000}},	//   kûnz, _àhér, --, --, 
   {{0x23601591,0x5ff400c7,0xf99c007f,0x2cb80175}},	//   čiju_, _азку, _orèr_, gbrd_, 
   {{0x27f80142,0xac18014b,0x6e200254,0x00000000}},	//   _nprn_, нору_, ämbr, --, 
   {{0x79a4034b,0xd64c02dd,0x98a40166,0x1e1401a9}},	//   ерже, шiле, _ılı_, _амия, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [2f9b0] --, --, --, --, 
   {{0xdd94abba,0x3f980200,0x00000000,0x00000000}},	//   _шапы, _hiqu_, --, --, 
   {{0xf99d4c18,0xc8e000ab,0xb8646ea9,0x00000000}},	//   _près_, _पारट, رائو, --, 
   {{0x3f980455,0x00000000,0x00000000,0x00000000}},	//   _jiqu_, --, --, --, 
   {{0x6d80005b,0x7afc0455,0x00000000,0x00000000}},	//   köal, meqt, --, --, 
   {{0xf99c007f,0x659401c6,0x00000000,0x00000000}},	//   _frèr_, гачу, --, --, 
   {{0xf99c2047,0xdef00020,0x6d4001f5,0x27f400d0}},	//   _très_, ውንና_, ëmai, čaná_, 
   {{0x9f5c01a2,0x3b09b458,0xaca401f2,0xc7b0011a}},	//   _prvý_, _jacq_, trịk, _כבל_, 
   {{0xe2a9b459,0xb4b00724,0x0321b45a,0xc320eb13}},	//   راين_, _бизә, рдын, рмык, 
   {{0xe1e800db,0x00000000,0x00000000,0x00000000}},	//   رىپو_, --, --, --, 
   {{0x81800323,0x3f980455,0x008000d4,0xa3d4030d}},	//   ргэж, _biqu_, ильо, _бохч, 
   {{0xbeb8044e,0x3f980a73,0xb8e00327,0xd1b88e98}},	//   njëh, _ciqu_, _ཌབ_, _قاتا_, 
   {{0x91e5b45b,0x9104a2ff,0x83340a7c,0x6f9c0220}},	//   _роле, _апле, _שאנס_, _ﺍﻟﻌﺎ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9ff00154,0x00000000,0x00000000,0x00000000}},	//   টিউব_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc3300bd4,0x8d7448c1,0x0d85b45c,0x1ea800f1}},	// [2f9c0] בון_, _لادا, _илин, _ښایي_, 
   {{0x8d741075,0x3f98401f,0xbb300131,0x291c0156}},	//   _جابا, _ziqu_, ﺪﺍﻕ_, ñva_, 
   {{0x38c80101,0x46e8004e,0x00000000,0x00000000}},	//   باقی_, дден_, --, --, 
   {{0xf99c0066,0xdb0408a5,0xb344025c,0x00000000}},	//   _isèn_, _athæ, neħħ, --, 
   {{0xa4d40a4a,0x24f80166,0x00000000,0x00000000}},	//   голі, енлы_, --, --, 
   {{0x4614130e,0x3fac00d1,0x00000000,0x00000000}},	//   _یوزر, ﺰﻻﺭﻧ, --, --, 
   {{0xc5ac0064,0x00000000,0x00000000,0x00000000}},	//   _žūči, --, --, --, 
   {{0x65c40046,0x72d000d1,0x00000000,0x00000000}},	//   _бұда, لەمچ, --, --, 
   {{0xf4841a4b,0x060932c6,0x6d800108,0x00000000}},	//   _یامی, _юнак_, töal, --, 
   {{0x26c42bae,0xbb1800d2,0x3f99b45d,0xc0580220}},	//   _hemo_, _phîk, _siqu_, дім_, 
   {{0x26c5b45e,0x5f95b45f,0x9f347707,0x25a401ef}},	//   _kemo_, лиот, гені, _huml_, 
   {{0x26c5b460,0xf454011a,0x71a000c7,0xa2c401ee}},	//   _jemo_, _ביבר_, ықәҵ, _сәкк, 
   {{0x88d804c5,0x98b00064,0xc1e001af,0x52b001af}},	//   ঠ্যক, _elzę_, _төйҙ, _уҡыс, 
   {{0x26c5b461,0x5d840736,0x61e1b462,0x59d8000d}},	//   _lemo_, السل, muml, _ढिबर, 
   {{0x60c81730,0x61e034e5,0x7afc014f,0x00000000}},	//   madm, luml, teqt, --, 
   {{0x26c5b463,0x60c9b464,0x05d006ab,0x25a446d5}},	//   _nemo_, ladm, _सिंब, _ouml_, 
   {{0x61e11ec3,0xaa59b465,0x7afdb466,0xab9452c4}},	// [2f9d0] numl, виту_, reqt, риті, 
   {{0x60c9b467,0x26c40428,0x3ad0001e,0x3fc40131}},	//   nadm, _aemo_, ệp_, ﻨﺴﺎﻧ, 
   {{0x26c50a4d,0x61e1b468,0x25a5b469,0xd7d41b88}},	//   _bemo_, huml, _auml_, ужењ, 
   {{0x26c40b91,0x61e1b46a,0x60c9b46b,0x7afc014f}},	//   _cemo_, kuml, hadm, qeqt, 
   {{0x61e041d0,0x5a2401d9,0x26c4ab6a,0xf9900050}},	//   juml, _صبحہ, _demo_, _نبس_, 
   {{0x48c000c7,0x61e003e0,0x00000000,0x00000000}},	//   _гәца, duml, --, --, 
   {{0x26c403a0,0x94540069,0x60c937c6,0xe4e400d6}},	//   _femo_, _kēi, dadm, річн, 
   {{0x26c401e4,0x61e06e0e,0x13040640,0x11e401c6}},	//   _gemo_, fuml, узим, гжим, 
   {{0x61e05185,0xdb1401ed,0x60c801ef,0x00000000}},	//   guml, lszó, fadm, --, 
   {{0x26c5b46c,0xe19409a0,0x929c0210,0x00000000}},	//   _zemo_, ирээ, dełe, --, 
   {{0xd25005d9,0x26c5b46d,0x00000000,0x00000000}},	//   _ڏنا_, _yemo_, --, --, 
   {{0x25a408cd,0xb2b00598,0x61e1a0ea,0xdb1401ed}},	//   _yuml_, _тәкъ, buml, gszü, 
   {{0x60c8004e,0x8e541ed2,0x3d0c0034,0x76480369}},	//   badm, утні, ायूं_, nzgy, 
   {{0xbb1800d2,0x60c801e4,0x09b000fe,0x50a401e0}},	//   _khîw, cadm, _চিলা, _судҡ, 
   {{0xae0000c5,0x8b6405af,0x0fc401d5,0x00000000}},	//   _लईकन_, هارم, _ёйин, --, 
   {{0xf99c1497,0x3b0435dd,0x20180158,0x9f9400c0}},	//   _prèp_, лесо_, ærie_, _кшыш, 
   {{0x26c5b46e,0xc33023e4,0xc965114a,0x00000000}},	// [2f9e0] _remo_, זון_, гвай, --, 
   {{0x26c5b46f,0xcd042218,0x0c24008e,0x25a4013a}},	//   _semo_, _спой, _бмон, _ruml_, 
   {{0x8d7401d9,0x8c240214,0xdb1401d3,0x00000000}},	//   _لاگا, _صفحه, gszó, --, 
   {{0x61e0036b,0xca742ec5,0x60c80200,0x86440395}},	//   yuml, _бугы, zadm, лнеж, 
   {{0x26c429ef,0x60c804ce,0x00000000,0x00000000}},	//   _vemo_, yadm, --, --, 
   {{0x24580cef,0x26c45745,0xdb04023a,0x61e139df}},	//   каль_, _wemo_, _ethä, vuml, 
   {{0x26c5b470,0x60c8d6a8,0x6d8001f4,0x00000000}},	//   _temo_, vadm, töaj, --, 
   {{0xf74016a8,0x00000000,0x00000000,0x00000000}},	//   _лесо, --, --, --, 
   {{0xf2e411ec,0x25a4ffea,0x60c803cd,0x366400f0}},	//   اکمه_, _uuml_, tadm, _бато_, 
   {{0x61e1b471,0xbeb80023,0x21540006,0x929c012d}},	//   ruml, njëv, ркоў, jdłu, 
   {{0x60c9b472,0x61e1b473,0xf59000c6,0xf9740375}},	//   radm, suml, _اللج, רגיש_, 
   {{0xcf8c0fa2,0x61e0047e,0x82a4187f,0x9e1400d4}},	//   وژي_, puml, _садж, адмі, 
   {{0x60c9b474,0x61e1b475,0xb02400db,0x9f4801e1}},	//   padm, quml, _ەكىم_, _òkín_, 
   {{0x3d0c0034,0xdb1401d3,0x60c80455,0xa15992b3}},	//   ायें_, sszü, qadm, _шалу_, 
   {{0x645c05be,0xa2d81cba,0x753400df,0x317800df}},	//   _žrij, नःप्, נאלד_, _ראוד, 
   {{0xc1007c3f,0x1ea800f1,0x00000000,0x00000000}},	//   _түүл, _ګاډي_, --, --, 
   {{0xa3e43cbe,0xdee402d3,0x99540024,0x9f5800c7}},	// [2f9f0] भूत_, _ምሳና_, акац, írõ_, 
   {{0xdb1401ed,0x6d40d6d6,0x84740092,0xbeb80200}},	//   tszó, ëmat, _ካሳሁን_, gjëv, 
   {{0xd6d008c9,0x00000000,0x00000000,0x00000000}},	//   ققا_, --, --, --, 
   {{0xca7400e5,0xdb1400e5,0x00000000,0x00000000}},	//   انےک, rszó, --, --, 
   {{0xdb1400e5,0x75803fe6,0x00000000,0x00000000}},	//   sszó, میرم, --, --, 
   {{0x8cb8020d,0x92040055,0x89d8011a,0x1a740150}},	//   ्रयो, _jyāś, _בחשי, _бұғы_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb040267,0xd5c40354,0x00000000,0x00000000}},	//   _uthä, _гiан, --, --, 
   {{0x77780472,0x8cb9b476,0x6f9c0150,0x00000000}},	//   _ikux, ्रमो, _ﺍﻟﻘﺎ_, --, 
   {{0xc5ec021a,0xd0942ecb,0x3d0c033f,0x92040055}},	//   _زړه_, ишны, ायों_, _nyāś, 
   {{0x5f340023,0x00000000,0x00000000,0x00000000}},	//   _ይከላኸ, --, --, --, 
   {{0xe7d801ad,0xdb04036e,0x00000000,0x00000000}},	//   _डिसप, _duhë, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc0e09785,0x19b80327,0x00000000,0x00000000}},	//   _дошк, _བསྟབ, --, --, 
   {{0x77781cdf,0x8cb8084d,0x00000000,0x00000000}},	//   _okux, ्रबो, --, --, 
   {{0xbb4006ed,0xba380142,0xfaa00108,0x00000000}},	//   оеск, _sgïa, жато, --, 
   {{0x3b044170,0x08c5b477,0x09e501be,0x63b80175}},	// [2fa00] шето_, ибан, розн, zpvn, 
   {{0x77780944,0xbe0001d9,0x8884009d,0x6d8001f4}},	//   _akux, _بوٝٹ, алзж, köai, 
   {{0xc794189c,0x48041214,0xd25800de,0x00000000}},	//   арды, рпев, maņu_, --, 
   {{0x09e5b478,0x00000000,0x00000000,0x00000000}},	//   _комн, --, --, --, 
   {{0x6d5c062c,0xdb1401e1,0x00000000,0x00000000}},	//   oira, _óbál, --, --, 
   {{0x77781cdf,0x2b4001fa,0x00000000,0x00000000}},	//   _ekux, lkic_, --, --, 
   {{0x769801b8,0x4aa805c0,0x6d5c01ab,0xe2f801ec}},	//   _päyü, _कलाव, iira, гейі_, 
   {{0x6d5db479,0xfafc0de2,0x2b400cf4,0xbeb8036e}},	//   hira, _njël_, nkic_, njët, 
   {{0x6d5db47a,0xb4601cd1,0xdb040267,0xdee40023}},	//   kira, йкәл, _uthå, _ምኳኑ_, 
   {{0x6d5db47b,0x845800f7,0x32500006,0x65680200}},	//   jira, _ирет_, івэр, _ujdh, 
   {{0x20180124,0x657818f7,0xb5700014,0x00000000}},	//   íri_, movh, _بُلغ, --, 
   {{0x6d5db47c,0xd490001e,0x6579b47d,0xbdd8020c}},	//   eira, _này_, lovh, nyèg, 
   {{0xceac0451,0x2018010f,0x00000000,0x00000000}},	//   رڙي_, ŭri_, --, --, 
   {{0x6d5db47e,0x6578b6ad,0xdd9450c0,0x00000000}},	//   gira, novh, сагы, --, 
   {{0x92e80c58,0x5f9555f7,0xb0b40375,0xd4900051}},	//   য়ৰ_, _ликт, _דפוס_, _bày_, 
   {{0x657969de,0xb098008d,0x63a80014,0x6d400023}},	//   hovh, _ביור, _mudn, ëmar, 
   {{0x65781682,0x63a8abe8,0x5a3402e8,0xd4900051}},	// [2fa10] kovh, _ludn, щнат, _dày_, 
   {{0x63a8257c,0x00000000,0x00000000,0x00000000}},	//   _oudn, --, --, --, 
   {{0x69c002d3,0x333c0054,0x63a83e8f,0x657800d7}},	//   _çmen, ykux_, _nudn, dovh, 
   {{0x569403c5,0x0af001c4,0x00000000,0x00000000}},	//   бает, _нүсэ, --, --, 
   {{0x63a80217,0x65780099,0xe730007b,0x00000000}},	//   _audn, fovh, بصل_, --, 
   {{0xd469667e,0x65780810,0xe5780a4a,0x19580139}},	//   лиле_, govh, азі_, _сагы_, 
   {{0x63a9b47f,0xbeb802d3,0x67d4022e,0x00000000}},	//   _cudn, njës, _мору, --, 
   {{0x77780928,0x13083929,0x63a80429,0xdb04007b}},	//   _ukux, уний_, _dudn, _athú, 
   {{0xb9dc0201,0x6d5db480,0x00000000,0x00000000}},	//   _እኔ_, yira, --, --, 
   {{0x6d5c200b,0x77b0031c,0xd9a80eac,0x988000de}},	//   xira, _eħxe, _ওবাম, _līča_, 
   {{0xf99c0100,0x63a9b481,0x00000000,0x00000000}},	//   _asèk_, _gudn, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x23740597,0x63a800f3,0x4718123b,0x00000000}},	//   _بالح, _zudn, אורג, --, 
   {{0xfafc002e,0x63a80175,0xa158013d,0x427800df}},	//   _djëm_, _yudn, _качу_, _גאנג, 
   {{0x92e82f04,0xbeb8044e,0xe0d001b9,0x1c380108}},	//   য়ী_, gjës, _آزه_, аять_, 
   {{0xce5814a5,0x6d5c4c28,0x6578004c,0xdb0400e4}},	//   _مشخص_, sira, zovh, _yuhé, 
   {{0x68380092,0xe05405af,0xf3fc00eb,0x00000000}},	// [2fa20] _በሚመስ, _هییت_, ্মির_, --, 
   {{0xc8c9b482,0x6d5db483,0x2b4000f3,0x00000000}},	//   اوان_, qira, skic_, --, 
   {{0x988000ef,0x00000000,0x00000000,0x00000000}},	//   _fīča_, --, --, --, 
   {{0x65780099,0x929c033f,0xf3fc0154,0x00000000}},	//   wovh, zeła, ্মার_, --, 
   {{0x6b85b484,0x63a9b485,0x6579b486,0x09b003d4}},	//   mlig, _sudn, tovh, _চিকা, 
   {{0x38c8168d,0x63a80589,0xbeb80023,0xe9440244}},	//   _مافی_, _pudn, njër, _بچرپ, 
   {{0x6579b487,0xfafc002e,0x6b84f272,0xe70400f2}},	//   rovh, _akëy_, olig, _وسری, 
   {{0x63a80455,0x61d802e8,0x6578d863,0x00000000}},	//   _vudn, амия_, sovh, --, 
   {{0x63a80204,0x6d80023a,0x8644009d,0x00000000}},	//   _wudn, löau, _унаж, --, 
   {{0x3a34025f,0x63a800dd,0x6b85b488,0x00000000}},	//   צרים_, _tudn, hlig, --, 
   {{0x6b85b489,0x5f95b48a,0x249801c3,0xb978025d}},	//   klig, жинт, _àrm_, רניי, 
   {{0x6b85b48b,0x398c03fa,0x88ac015b,0xdb0402f0}},	//   jlig, müse_, গরিক, _tuhé, 
   {{0x6b85769b,0x9f84010b,0xd5c4030d,0x7e4401f4}},	//   dlig, йгүд, _гiен, ёхме, 
   {{0xbeb80023,0xe7d80412,0xe5e402dd,0x2ba4000d}},	//   gjër, _डिंप, _ﺍﻻﻟﻜ, _खंखा, 
   {{0xdbdc02f0,0x09b000fe,0x00000000,0x00000000}},	//   pšít, _চিগা, --, --, 
   {{0x6b84665b,0x201c0165,0xc01c00c5,0x35a40092}},	//   glig, _irvi_, ुबs_, ገባበት_, 
   {{0x9e95b48c,0x6605b48d,0x201c107d,0xdb1400e5}},	// [2fa30] _باغچ, çikl, _hrvi_, kszö, 
   {{0x3945b48e,0x6b8404c9,0xbb1800d2,0x61e0078c}},	//   óns_, alig, _phîs, irml, 
   {{0x6b85b48f,0x68fc0204,0x7c640092,0x00000000}},	//   blig, _dbrd, ተዋላል_, --, 
   {{0x7d04f71c,0x6b8404cc,0x201c0841,0x398c0112}},	//   lejs, clig, _mrvi_, düse_, 
   {{0xbf444e53,0x7aec0e14,0xe3b80ac4,0xd629b490}},	//   únṣe_, _icct, _atı_, роле_, 
   {{0x7d042e31,0x201db491,0xf568005b,0xf2b05347}},	//   nejs, _orvi_, ышек_, ीर्घ, 
   {{0xfafc1bce,0x44cc06be,0x00000000,0x00000000}},	//   _njëk_, _dә_, --, --, 
   {{0xf771b492,0x4390399f,0x00000000,0x00000000}},	//   _راز_, мајс, --, --, 
   {{0x201db493,0x41a409a5,0x7d0409a8,0xdb1401d3}},	//   _arvi_, овын_, kejs, bszö, 
   {{0x6b8465c2,0x201c0010,0x398c0790,0x00000000}},	//   zlig, _brvi_, büse_, --, 
   {{0x6b85b494,0x7d052a3e,0x201c04a7,0x80b8012c}},	//   ylig, dejs, _crvi_, _एभरे, 
   {{0x201c0010,0x27ec03cd,0x00000000,0x00000000}},	//   _drvi_, _ådne_, --, --, 
   {{0x6b84450f,0x80b9b495,0x237801ed,0x7d040010}},	//   vlig, _श्वे, _írja_, fejs, 
   {{0x7aec0204,0x7d04037e,0x6b85b496,0xf2700014}},	//   _acct, gejs, wlig, _وێژھ, 
   {{0x6b85b497,0xf99c007f,0x00000000,0x00000000}},	//   tlig, _frèz_, --, --, 
   {{0xa0340050,0x6b85b498,0x88ac03d4,0x00000000}},	//   _ژى۪ت, ulig, গৰাক, --, 
   {{0x6b85b499,0x2fc40369,0x7c5c0092,0x63a400df}},	// [2fa40] rlig, _hwng_, ደሚለው_, ĉini, 
   {{0x2fc40369,0xf99c007f,0x6d80005b,0x00000000}},	//   _kwng_, _krèy_, töau, --, 
   {{0xc6a4006c,0xcc880502,0x6b85b49a,0x7aec02f6}},	//   орли, _خنده_, plig, äntö, 
   {{0xf99c007f,0x6b85b49b,0x2fc40369,0x61400194}},	//   _apèd_, qlig, _mwng_, _kâlê, 
   {{0x929c033f,0xb6f4cf33,0x19b81f39,0xea18009f}},	//   wełn, تىنا_, _гусь_, _ارجڻ_, 
   {{0x92e80729,0xf99c007f,0x2d980100,0x68fc02d0}},	//   য়ো_, _orèy_, nmre_, _ubrd, 
   {{0xd57401ce,0xb4900640,0x34900672,0x44cc0213}},	//   чуць, мишљ, машр, _vә_, 
   {{0x7d05b49c,0x398c84bf,0x38c801d3,0xdb1400e5}},	//   zejs, rüse_, _ماہی_, sszö, 
   {{0x0564b3ee,0x4168026a,0x00000000,0x00000000}},	//   _дван, ијом_, --, --, 
   {{0x929c068f,0x09b000cc,0x00000000,0x00000000}},	//   pełn, _চিঞা, --, --, 
   {{0x2fc40369,0x7d05b49d,0x84580276,0xf8b004ae}},	//   _cwng_, vejs, _трат_, ושת_, 
   {{0x80b865c5,0x2fc40399,0x201c0219,0x6d8001f4}},	//   _श्रे, _dwng_, _vrvi_, köas, 
   {{0x7d05b49e,0x733011dc,0xd2f40451,0xbe880452}},	//   tejs, _تىنا, _رکيا_, рсне_, 
   {{0x7fa8030d,0x00000000,0x00000000,0x00000000}},	//   _къив_, --, --, --, 
   {{0x7d04dde1,0xf99c0100,0x85a400cd,0x116800f1}},	//   rejs, _trèz_, खदुः, _دلوی_, 
   {{0x7d05b49f,0x7ae401e2,0x00000000,0x00000000}},	//   sejs, تورې_, --, --, 
   {{0x7d040034,0x1a6401d3,0xdea01888,0x00000000}},	// [2fa50] pejs, سیسی_, _سیسی, --, 
   {{0x929c033f,0x00000000,0x00000000,0x00000000}},	//   zeło, --, --, --, 
   {{0xb8d003f3,0xd8781b06,0xe61003e6,0x96b8014b}},	//   _ऑल_, حمات_, ێشه_, булу_, 
   {{0x569435c7,0xe7a80006,0x34b00118,0x00000000}},	//   пает, івіл_, ँड्द, --, 
   {{0xd7c83bd6,0xdb240254,0x00000000,0x00000000}},	//   _گوزه_, öpõl, --, --, 
   {{0x2ea837c8,0x80b8146b,0x00000000,0x00000000}},	//   _गल्त, _श्ले, --, --, 
   {{0xf7708660,0xd7c8315b,0x00000000,0x00000000}},	//   _قار_, _دوزه_, --, --, 
   {{0x92e805ac,0x66c801c4,0x00000000,0x00000000}},	//   য়্_, _мууг_, --, --, 
   {{0x0201076e,0x77680472,0xfafc0200,0xd5880408}},	//   езын, mngx, _mbë_, _дiай, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x77680208,0xd0081436,0x00000000,0x00000000}},	//   ongx, щене_, --, --, 
   {{0x7d0005d2,0x00000000,0x00000000,0x00000000}},	//   _ınsa, --, --, --, 
   {{0x776800f1,0x3ebcfb08,0x8db47a9c,0x00000000}},	//   ingx, ñuta_, ясні, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb95801e1,0x205400a7,0x2d9801e3,0x00000000}},	//   _ewìk, _отър, rmre_, --, 
   {{0x4aa82fe5,0x6d800108,0x00000000,0x00000000}},	//   скан_, töas, --, --, 
   {{0x61e401e4,0x00000000,0x00000000,0x00000000}},	// [2fa60] _ĥilk, --, --, --, 
   {{0xef18005f,0x7769b4a0,0x38c802f2,0x91bc00cc}},	//   ēļu_, engx, مامی_, _ইটাখ, 
   {{0x86c5b4a1,0x8b2582a7,0x6d8001f4,0xb7d43260}},	//   كيان, _едне, söas, كولا_, 
   {{0xfafc006a,0x4420627e,0x00000000,0x00000000}},	//   _gbë_, _čk_, --, --, 
   {{0xe9740aaf,0x02a40116,0x00000000,0x00000000}},	//   _قۇرد, үрим, --, --, 
   {{0x4534177b,0x442c0051,0x00000000,0x00000000}},	//   яхет, txf_, --, --, 
   {{0xfa200020,0x00000000,0x00000000,0x00000000}},	//   _ሰራተኞ, --, --, --, 
   {{0xb7d8011a,0x00000000,0x00000000,0x00000000}},	//   _לקלי, --, --, --, 
   {{0x398c04cc,0xd04003e3,0x00000000,0x00000000}},	//   lüsa_, malə, --, --, 
   {{0xd0400213,0xa3b001ad,0xe7e001f9,0x00000000}},	//   lalə, _टूथ_, _पटाप, --, 
   {{0xc0580046,0xadc40248,0x50a00131,0x65640036}},	//   сіп_, _iyẹw, پەيل, éihu, 
   {{0x23600086,0x8c100154,0x00000000,0x00000000}},	//   _öij_, হমান_, --, --, 
   {{0x398c04cc,0xb281b4a2,0x00000000,0x00000000}},	//   hüsa_, _пышк, --, --, 
   {{0xa2c41cba,0xd04003b9,0x645c01a8,0x00000000}},	//   ररक्, halə, _þris, --, 
   {{0x1dd806ab,0x6d8001f4,0xd04003b9,0x802401af}},	//   _भटकत, töar, kalə, _хєлд, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x90e401ec,0xeab0484d,0xdc3000ef,0x6d8001e3}},	// [2fa70] _ءسۇن, اعف_, _pļēg, röar, 
   {{0xa41c05f9,0x398c05d5,0x6d80007c,0x60dc01e7}},	//   पटाप_, füsa_, söar, órmh, 
   {{0xd04003b9,0xe6940022,0xbb640092,0x00000000}},	//   falə, ҭихы, _ተፈረመ_, --, 
   {{0xf771b4a3,0xf99c020c,0xadc40248,0xd04006be}},	//   راض_, _asèt_, _ayẹw, galə, 
   {{0x959835c7,0x00000000,0x00000000,0x00000000}},	//   отку_, --, --, --, 
   {{0x7d140009,0xb4e4044b,0xe9a40024,0x00000000}},	//   _jaxs, भले_, _паўп, --, 
   {{0x7d15b4a4,0x3cfc07b6,0x00000000,0x00000000}},	//   _maxs, श्ये_, --, --, 
   {{0x5724005e,0x7d14cce0,0x44b000d1,0xd04003b9}},	//   _تىرك, _laxs, нбәс, calə, 
   {{0xd175b4a5,0x5ec4009e,0xe56c014b,0x00000000}},	//   дыны, ্লাই, _бҷ_, --, 
   {{0x48f00316,0x50449b4e,0x7d14350e,0x0ee40027}},	//   ुभयो_, деоб, _naxs, कल्स_, 
   {{0x4b40001f,0x00000000,0x00000000,0x00000000}},	//   _የፈጠረ, --, --, --, 
   {{0x0cc4193d,0x00000000,0x00000000,0x00000000}},	//   वर्म, --, --, --, 
   {{0x7d153334,0xa294063b,0x5155b4a6,0xb62c00b5}},	//   _baxs, _заці, _отку, _ｐｂ_, 
   {{0x248003ee,0xd6d80210,0x65bc1870,0x00000000}},	//   şime_, _hołd_, ﻧﺪﯨﻠ, --, 
   {{0x7d1401a9,0xbb180165,0xb308031c,0x00000000}},	//   _daxs, _skîa, _ཁྲོང_, --, 
   {{0x98b000e2,0x49c8444e,0x00000000,0x00000000}},	//   _rozā_, жлан_, --, --, 
   {{0x7d14022e,0x929c033f,0xf7800003,0x0e6400d3}},	// [2fa80] _faxs, dełk, _moħħ_, _ікон, 
   {{0x26d8033f,0x98b00171,0x00000000,0x00000000}},	//   _śro_, _pozā_, --, --, 
   {{0xf99c02bd,0x00000000,0x00000000,0x00000000}},	//   _rsèt_, --, --, --, 
   {{0xb95801e1,0x0648007b,0xaac400ec,0x00000000}},	//   _atìd, يلاً_, _سڪرن, --, 
   {{0x7d14006c,0xb308025c,0xe8000037,0x00000000}},	//   _yaxs, _ཁྲེང_, _ईहवा_, --, 
   {{0x6704007f,0x00000000,0x00000000,0x00000000}},	//   _sčkč, --, --, --, 
   {{0x2919b4a7,0x7a400248,0x86f400f0,0x929c0210}},	//   _iara_, _títú, _оџач, bełk, 
   {{0x2919b4a8,0xf3600598,0xd04003be,0x2120010e}},	//   _hara_, ктын, qalə, _şih_, 
   {{0x2919b4a9,0xdb055352,0xd36c0137,0x00000000}},	//   _kara_, _juhá, حۇن_, --, 
   {{0x2919b4aa,0x00000000,0x00000000,0x00000000}},	//   _jara_, --, --, --, 
   {{0x2919b4ab,0x7d14022e,0x2d54013d,0x74107245}},	//   _mara_, _raxs, _käef_, _لولا, 
   {{0x2919b4ac,0xdb040022,0x7d15b4ad,0x63a40115}},	//   _lara_, _ouhá, _saxs, ĉins, 
   {{0xec68b8c6,0x7d140054,0xa50c0135,0x29182786}},	//   _פֿ_, _paxs, _གྲོག_, _oara_, 
   {{0x1fb80166,0x59b43337,0x0a2c0092,0x929c0210}},	//   _елкы_, _अंबर, _አመላካ, zełk, 
   {{0x0a2c0020,0xf99c020c,0x7d1401a9,0xac19b4ae}},	//   _አመለካ, _osèr_, _vaxs, мору_, 
   {{0x2919b4af,0x7d14292a,0x60980050,0x3cf800af}},	//   _aara_, _waxs, _وچھس_, _लउके_, 
   {{0x2919b4b0,0x2ef400c7,0x7d1401a9,0x00000000}},	// [2fa90] _bara_, _рзыр, _taxs, --, 
   {{0x2919b4b1,0x78640a2c,0x2cb800b5,0x00000000}},	//   _cara_, وداك, ccrd_, --, 
   {{0x2919b4b2,0x00000000,0x00000000,0x00000000}},	//   _dara_, --, --, --, 
   {{0x29180c86,0xf090010f,0x00000000,0x00000000}},	//   _eara_, דנע_, --, --, 
   {{0x9aa400f1,0xbdd8007f,0x929c012d,0x00000000}},	//   _سمسو, zyèn, rełk, --, 
   {{0x2919b4b3,0x98b0054e,0xe61802dd,0x929c012d}},	//   _gara_, _doză_, ьді_, sełk, 
   {{0x59b44da4,0xad38010f,0x5ed400cc,0x00000000}},	//   _अंडर, ונגס_, _থানে, --, 
   {{0x2919b4b4,0x3cfc0034,0x2610185d,0xe8940006}},	//   _zara_, श्ते_, _दैवी_, _рась, 
   {{0x2919b4b5,0xe3b80724,0xf99c0ba1,0x766401e2}},	//   _yara_, _urın_, _usès_, _کیږې_, 
   {{0x29180784,0x00000000,0x00000000,0x00000000}},	//   _xara_, --, --, --, 
   {{0x13f4003b,0x00000000,0x00000000,0x00000000}},	//   _їздя, --, --, --, 
   {{0x52740209,0x7ff5b4b6,0x00000000,0x00000000}},	//   _пулу, رسپا, --, --, 
   {{0xbdd80100,0xa1c40064,0xd6d80210,0x00000000}},	//   syèn, _абід, _gołe_, --, 
   {{0xdb0400dd,0x2cac022c,0xb0000055,0x0ba80a11}},	//   _ruhá, ødd_, _haḍi, كارى_, 
   {{0x2919b4b7,0x8b94074d,0xdc4400ef,0x00000000}},	//   _rara_, ерач, bīča, --, 
   {{0x2918493b,0x0a2c0092,0x8ec801d5,0xdb0400e5}},	//   _sara_, _አመልካ, _эгиб_, _puhá, 
   {{0x2919b4b8,0x6f042001,0x0d85b4b9,0xf8c800dc}},	// [2faa0] _para_, _ibic, _плин, िरूप, 
   {{0x6e25b4ba,0x2919b4bb,0xb9580241,0x2ee001f5}},	//   _irib, _qara_, _atìb, _hdif_, 
   {{0x2919b4bc,0x6e2409a8,0x870842fd,0x26c0002e}},	//   _vara_, _hrib, зеев_, ñioo_, 
   {{0x2919b4bd,0x98b00276,0xade412eb,0x8cb800cd}},	//   _wara_, _poză_, _कटान_, ्रको, 
   {{0x6f05b4be,0xa50c031c,0x00000000,0x00000000}},	//   _mbic, _གྲུག_, --, --, 
   {{0x59b40d5f,0x291804fe,0xbdd80100,0xd9b000d1}},	//   _अंतर, _uara_, dyèl, _ئەلد, 
   {{0xf8a410dc,0xc764ba84,0x00000000,0x00000000}},	//   _कृपय, _كارى, --, --, 
   {{0x69c5b4bf,0xf5e400ec,0xfafc0200,0x00000000}},	//   opie, _ڳڙهي_, _ujët_, --, 
   {{0x69c427d6,0x6e24004e,0x2d5400c5,0xcfd00248}},	//   npie, _nrib, _käed_, _ijẹẹ, 
   {{0x6f05b4c0,0x2ee1075e,0x69c406af,0x71f401d3}},	//   _abic, _adif_, ipie, ڈریس_, 
   {{0xf65c00fc,0x6e240516,0xf99c0066,0x39540375}},	//   _þær_, _arib, _opèn_, גשים_, 
   {{0x6e25b4c1,0x2d540254,0x00000000,0x00000000}},	//   _brib, _läed_, --, --, 
   {{0x6e25b4c2,0x69c40034,0x59b400af,0x733004b3}},	//   _crib, jpie, _अंधर, _حىنا, 
   {{0x69c5b4c3,0xf99c02e2,0x6f05b4c4,0x2d5400c5}},	//   dpie, _apèn_, _ebic, _näed_, 
   {{0x64580e8a,0x6e25b4c5,0x69c46a95,0xbdd802e2}},	//   nzvi, _erib, epie, myèm, 
   {{0x6e25b4c6,0x59280867,0x31c00014,0xa3e81414}},	//   _frib, _ལོངས_, _جۅیہ, _बिन_, 
   {{0x6e25b4c7,0x6b74119e,0xc06c0023,0x69c5352c}},	// [2fab0] _grib, улту, _ብመጠን_, gpie, 
   {{0xbdd8033b,0x3cf8000d,0x00000000,0x00000000}},	//   nyèm, _लउटे_, --, --, 
   {{0x8bb42d40,0x69c402e8,0x57f4d87d,0xa3b00034}},	//   _ақсу_, apie, тпет, _टूल_, 
   {{0x6459b4c8,0xca3801ec,0xe8e00051,0x5ac80244}},	//   dzvi, _ﺒﻠﺩ_, _đụn_, _تادێ_, 
   {{0x645801f1,0x69c40171,0x00000000,0x00000000}},	//   ezvi, cpie, --, --, 
   {{0xe5680075,0xac740150,0xfafc0200,0xbeb80200}},	//   ىمنى_, _جاۋش, _gjër_, gjëz, 
   {{0xe89405f5,0xb0000055,0x00000000,0x00000000}},	//   _барь, _paḍi, --, --, 
   {{0xbdd802bd,0x122801d5,0x00000000,0x00000000}},	//   tyèl, доий_, --, --, 
   {{0x21f805f5,0x64580099,0xb00000b8,0x00000000}},	//   нхээ_, azvi, _vaḍi, --, 
   {{0x7ae0016b,0x478400c7,0x24800bbc,0x00000000}},	//   ɔnte, _зыӡб, şima_, --, 
   {{0x69c4006d,0x6e24003e,0xa50c0327,0xbdd8033b}},	//   zpie, _srib, _གྲིག_, syèl, 
   {{0xdec4044e,0x59b00709,0x2bf003d4,0x69c40210}},	//   _ጸላኢ_, जदार, _চনলৈ_, ypie, 
   {{0x6f04003a,0x6e246730,0x00000000,0x00000000}},	//   _vbic, _qrib, --, --, 
   {{0x99880210,0x00000000,0x00000000,0x00000000}},	//   hwał_, --, --, --, 
   {{0xc1a400c7,0xaa1c01e1,0x00000000,0x00000000}},	//   _рыцқ, _òtúá_, --, --, 
   {{0x6f05b4c9,0x6e25b4ca,0x9f4c0066,0xb3e00eac}},	//   _ubic, _trib, judè_, _মহাজ, 
   {{0x6e25b4cb,0x64580810,0xd0040131,0xc9a80006}},	// [2fac0] _urib, zzvi, _чоққ, двае_, 
   {{0x69c5b4cc,0x9988012d,0x6d48007c,0x00000000}},	//   rpie, ewał_, ödad, --, 
   {{0x69c5b4cd,0x07a5b4ce,0xe6e80184,0xcac8005b}},	//   spie, важн, егеҙ_, _огне_, 
   {{0x69c5b4cf,0x864406ed,0xbdd802e2,0x00000000}},	//   ppie, кнеж, zyèm, --, 
   {{0x6b85b4d0,0x3cfc00dc,0x940403e3,0x00000000}},	//   moig, श्वे_, _izlə_, --, 
   {{0x290c02fb,0x6458017a,0xd36c00d1,0x6b85b4d1}},	//   ímač_, tzvi, ۋۇل_, loig, 
   {{0x86e800c6,0x7d005fa3,0x1b140154,0xc768009d}},	//   _يعرف_, _önse, ডারে_, _живж_, 
   {{0xb9ec069c,0xf74012c1,0x6b840332,0xfbd0011a}},	//   _ሕቶ_, _кесо, noig, בתה_, 
   {{0x068486f6,0xf7400261,0x6b841140,0x960404fb}},	//   _рган, _тето, ioig, _مبلم, 
   {{0x6b85b4d2,0x2d540254,0xdb04002f,0xba98011a}},	//   hoig, _läeb_, _zuhä, וספי, 
   {{0xf1f404ce,0x6b84c713,0xa3bc000d,0x7c340092}},	//   _eメ_, koig, _अऽट_, _ባካሄዱ, 
   {{0x6b8420ef,0xf99d90dc,0x2d5400af,0xd6d80034}},	//   joig, _apèl_, _näeb_, _koła_, 
   {{0x6b84005a,0x00000000,0x00000000,0x00000000}},	//   doig, --, --, --, 
   {{0xdb0400b8,0x9988012d,0x6ff000f2,0x00000000}},	//   _muhå, zwał_, دسیط, --, 
   {{0xfba805f5,0x9988033f,0x6b840332,0x00000000}},	//   дтай_, ywał_, foig, --, 
   {{0x6b840421,0xbdd80066,0x69c0031c,0xe3b80205}},	//   goig, nyèk, _ħmer, _arık_, 
   {{0x9998026a,0x3f98016d,0x9f4c04fb,0x79a40022}},	// [2fad0] екат_, _ihqu_, judé_, врже, 
   {{0x83100327,0xb8640a7b,0xa9680063,0xdd9000be}},	//   _ཉིའུ_, پائو, виђа_, _دوخ_, 
   {{0x28f8074d,0x3cc801ec,0xdcfc06be,0x00000000}},	//   техь_, _ﺑﯘﺗﺤ, qqsı, --, 
   {{0x7bc5b4d3,0xdb0401a8,0x00000000,0x00000000}},	//   mpju, _athö, --, --, 
   {{0x7af80309,0x9988012d,0x00000000,0x00000000}},	//   _ñutq, rwał_, --, --, 
   {{0x084001d9,0xd7d41bc6,0x00000000,0x00000000}},	//   _گۆمُ, _مصرک, --, --, 
   {{0x774004d3,0xbb1800d2,0xa7b800fd,0x80d400e1}},	//   _پێشم, _shîy, _алсу_, _मज़े, 
   {{0x23b806af,0xade40037,0x92f4003b,0x00000000}},	//   _déj_, _कटलन_, учкі, --, 
   {{0xd185b4d4,0xe50000af,0xe2a800f1,0xf8a400cd}},	//   ллий, ल्हि_, پاين_, _कृतय, 
   {{0x344800fd,0x6b85b4d5,0x00000000,0x00000000}},	//   _очен_, zoig, --, --, 
   {{0x6b84009f,0xf485b4d6,0x4fa401e0,0x818001c6}},	//   yoig, _руан, лиов, сгэж, 
   {{0xd35000aa,0x6304db5b,0x62080254,0x00000000}},	//   _دکتګ, _نومل, ärlõ, --, 
   {{0xcdf42ecc,0x529000d1,0x00000000,0x00000000}},	//   ычны, ﻟﯩﯖﯩ, --, --, 
   {{0x6b840175,0xc0d00092,0x00000000,0x00000000}},	//   woig, _ጫሚሶ_, --, --, 
   {{0x24d80154,0x2018003a,0x2c0400ee,0x0160004e}},	//   _সামহ, ærit_, шүнм, _ыкшо, 
   {{0x13d00316,0x4ed40139,0x00000000,0x00000000}},	//   _सबैभ, _сюкт, --, --, 
   {{0x8d740372,0x0ea810f5,0x0905b4d7,0x6b580174}},	// [2fae0] _مادا, _який_, лпан, _lígg, 
   {{0xe6cc193d,0xdb04005c,0x6b840129,0x00000000}},	//   ार्ज, _ruhå, soig, --, 
   {{0x46e9b4d8,0x3cf80302,0x8c45b4d9,0x06e80209}},	//   еден_, _אלינ, _сене, емек_, 
   {{0xc6d5b4da,0x25ac0b6f,0x291c0960,0xaab80954}},	//   اتات, _sidl_, žva_, _अलिक, 
   {{0x7d00002d,0x8a680092,0x37e001d5,0xe7e00118}},	//   _űnsi, _በመሆኗ_, _қотг, _पटकप, 
   {{0xac3c01ec,0x6b580162,0x00000000,0x00000000}},	//   _ءﯨﻠﯟ_, _bígg, --, --, 
   {{0x97b40261,0x25ac0427,0xd6d80210,0x00000000}},	//   _всуш, _vidl_, _woła_, --, 
   {{0x63a00218,0xdcd008a3,0xa3040139,0x00000000}},	//   ummn, _तज्ञ, рүде, --, 
   {{0x82340228,0x25ac1477,0x23480424,0x2258005b}},	//   ارعا, _tidl_, فسکی_, типы_, 
   {{0x6b581125,0x8458135c,0x5928031c,0x35a0013d}},	//   _fígg, _прет_, _ལོབས_, _гауг, 
   {{0x83c4005b,0x490411a6,0x00000000,0x00000000}},	//   _сбеж, स्यो_, --, --, 
   {{0x60c40ab7,0xa2c40116,0x98b00153,0xf0e40131}},	//   _şimd, _тәкк, _dozę_, نىۋى_, 
   {{0xf99c0100,0x69b01fd2,0x00000000,0x00000000}},	//   _spèm_, _अंगी, --, --, 
   {{0x7c840aa8,0x20181427,0x00000000,0x00000000}},	//   губе, æris_, --, --, 
   {{0x06f40764,0x7b7400f2,0x1bd4011c,0x00000000}},	//   ीभाव_, هطرا, робя, --, 
   {{0x3f98014f,0x7bc4031c,0x99880210,0x00000000}},	//   _uhqu_, rpju, zwań_, --, 
   {{0x5a3464e1,0xdb0400d2,0x13cc0154,0x7bc40327}},	// [2faf0] шнат, _kuhú, রওয়, spju, 
   {{0x7bc400c5,0x79a5b4db,0x1c1c000d,0x00000000}},	//   ppju, урбе, _पनपल_, --, 
   {{0xa3b000bc,0xad2400d1,0x00000000,0x00000000}},	//   _टंग_, _چىۋى, --, --, 
   {{0x79a43e64,0xfaa400db,0xac1800db,0xaa78010e}},	//   _әрме, _مۇزي_, _союу_, lüýä_, 
   {{0x6b581125,0xfca803e6,0x38680023,0x00000000}},	//   _sígg, _تاکو_, _ተኸሲቱ_, --, 
   {{0xd4680cef,0x398c0432,0x00000000,0x00000000}},	//   киле_, küsi_, --, --, 
   {{0xa9540212,0xe4e400d3,0x398c00a2,0x00000000}},	//   _укрі, січн, jüsi_, --, 
   {{0x11e5b4dc,0x39400010,0x588401e0,0x6b581427}},	//   ажим, _hojs_, _быға, _vígg, 
   {{0x7769b4dd,0x91e4014b,0x00000000,0x00000000}},	//   migx, шопе, --, --, 
   {{0xe610bfb2,0x9f59b4de,0xa3b005f9,0x6b58022c}},	//   _عشق_, îrî_, _टूक_, _tígg, 
   {{0x7649b4df,0x6b58067c,0x39400e04,0x00000000}},	//   lygy, _híge, _mojs_, --, 
   {{0x776912d4,0x645c025c,0x00000000,0x00000000}},	//   nigx, _żrig, --, --, 
   {{0x23840014,0x20180252,0x76480a08,0x00000000}},	//   _أنِ, ærir_, nygy, --, 
   {{0x39400354,0x9f4c4e9e,0x1d18234c,0x10a40408}},	//   _nojs_, ludì_, люсь_, _килн, 
   {{0x7054010a,0x398c0139,0x76488b89,0x00000000}},	//   _сĕве, cüsi_, hygy, --, 
   {{0x9514031c,0xd0100451,0x00000000,0x00000000}},	//   _ཊིའི_, _هلڻ_, --, --, 
   {{0x4aa9b4e0,0xc3300bd4,0xc96454fa,0x6b58032e}},	// [2fb00] ткан_, חון_, авай, _níge, 
   {{0x76480209,0x1cb4025c,0x38c840ec,0x31b805c7}},	//   dygy, _ཞུར_, نامی_, _mêz_, 
   {{0x86c40be2,0xb7d428ee,0x00000000,0x00000000}},	//   ليان, لولا_, --, --, 
   {{0x3ab02cc8,0x6b58032e,0x00000000,0x00000000}},	//   _дәфт, _bíge, --, --, 
   {{0x69b001d9,0x75d010fe,0x3b80b159,0x6b588aa2}},	//   _अंटी, قينا, _фляг, _vígd, 
   {{0xe4540166,0x00000000,0x00000000,0x00000000}},	//   йклы, --, --, --, 
   {{0xd5ac2832,0xdb0c0112,0xd6a815bf,0x00000000}},	//   رہم_, nmaß, ندۇم_, --, 
   {{0xc7640075,0x7648010e,0x00000000,0x00000000}},	//   _ئاسى, bygy, --, --, 
   {{0x6b580241,0x76480175,0x490400cd,0x00000000}},	//   _kígb, cygy, स्थो_, --, 
   {{0x6721b4e1,0x60c400fd,0x215402d5,0x5ff40124}},	//   _hamj, _şimb, скоў, бзоу, 
   {{0xc0580046,0x319405f5,0x6720acd3,0x3010084c}},	//   тіп_, рвээ_, _kamj, одэр, 
   {{0x49043fec,0x3f64c251,0x00000000,0x00000000}},	//   स्तो_, ртоб, --, --, 
   {{0x82a4f42e,0x9f840116,0x398d2fa3,0x00000000}},	//   _тадж, игүд, süsi_, --, 
   {{0x6b58110e,0x77680944,0x6720a5c0,0xa28000f2}},	//   _nígb, zigx, _lamj, _ویژو, 
   {{0x7b6402f6,0x39400e04,0x77684b2a,0xfee401d5}},	//   атае, _rojs_, yigx, _кўпм, 
   {{0x6721b4e2,0x60d8014f,0xfafc0200,0xdd9000f1}},	//   _namj, _hevm, _emën_, _ډوب_, 
   {{0x6568020c,0x06700131,0x3ebc002e,0x81880023}},	// [2fb10] _omdh, ﻻﺭﻧﯩ, ñutu_, _ምእታዉ_, 
   {{0x693430af,0x60d9b4e3,0x2d5400b0,0x9d18094e}},	//   онуу, _jevm, _täea_, _соот_, 
   {{0x672003a2,0x60d8014f,0x00000000,0x00000000}},	//   _bamj, _mevm, --, --, 
   {{0x67200007,0x4bc001c6,0x00000000,0x00000000}},	//   _camj, _хөрг, --, --, 
   {{0x7768002e,0x79a40120,0xcb34011a,0x2d540108}},	//   rigx, _врве, _הארי_, _mäen_, 
   {{0x1cb4038f,0x672003ac,0x776800aa,0x356800a7}},	//   _ཞུས_, _eamj, sigx, ърен_, 
   {{0x672075f9,0x37a9b4e4,0xe3b803e3,0xdee4069d}},	//   _famj, _атан_, _asıb_, ማመን_, 
   {{0x67200097,0x2d5425e4,0xdb1c0139,0x00000000}},	//   _gamj, _näen_, _öyän, --, 
   {{0x60d80165,0x48fc0316,0xd1b800cf,0x50b4009d}},	//   _bevm, _लामो_, دابا_, йсну, 
   {{0x67201727,0x60d80010,0xf48479a0,0x645c025c}},	//   _zamj, _cevm, _куен, _żrie, 
   {{0x60d80455,0x6720014b,0x8fd000fd,0x5f340023}},	//   _devm, _yamj, чәлә, _ክከላኸ, 
   {{0x2d54013d,0x9f4c02fb,0x48fcf289,0x00000000}},	//   _cäen_, budí_, _लाभो_, --, 
   {{0xa3b01533,0x877800c8,0xd5b00208,0x00000000}},	//   _टूट_, רארי, _kí_, --, 
   {{0x8c452a74,0x3164014b,0xdb0c0e78,0xd490004d}},	//   беге, _umnz_, tmaß, _kỳ_, 
   {{0x8fa4035b,0x2cac01e6,0x6b5801e1,0xf21c012d}},	//   _лаке, ädd_, _rígb, बिक़_, 
   {{0xdb0c03fa,0x333c0393,0x8d74c1ac,0x6b580248}},	//   rmaß, njux_, _گابا, _sígb, 
   {{0x6720016d,0xbb41b4e5,0xdb0c0e78,0x09e43129}},	// [2fb20] _ramj, четк, smaß, созн, 
   {{0xa3e802ab,0xc7240588,0x6721b4e6,0x1db425c9}},	//   _बिल_, әҭаҷ_, _samj, ंदरत, 
   {{0x6d5c0ea3,0x6720044e,0x4804781e,0xcb684a81}},	//   mhra, _pamj, спев, _бане_, 
   {{0x26c989f5,0x46a5b4e7,0x00000000,0x00000000}},	//   рған_, баев, --, --, 
   {{0x1b0002a6,0xd5b00208,0xe3b8008e,0x00000000}},	//   _লোকে_, _bí_, _suı_, --, 
   {{0x67207c6f,0x2b400b3d,0xd85001e1,0x6d5c0051}},	//   _wamj, ljic_, _kọ́_, nhra, 
   {{0x60d9b4e8,0xd85001e1,0x00000000,0x00000000}},	//   _revm, _jọ́_, --, --, 
   {{0x60d84a4a,0x2b400558,0xb9f0001f,0xd850110e}},	//   _sevm, njic_, _ዝቅ_, _mọ́_, 
   {{0x6d5db4e9,0x2a60083a,0xd85001e1,0xcd0000b8}},	//   khra, nzib_, _lọ́_, _keśā_, 
   {{0x2fc49834,0xd50801d9,0x2d54002f,0x00000000}},	//   _btng_, _نغمن_, _säen_, --, 
   {{0xaab803e5,0x60d80579,0x20991375,0x00000000}},	//   _अलंक, _vevm, ркны_, --, 
   {{0x2fc406d1,0x6d5c0030,0x2a600213,0x6d4811ab}},	//   _dtng_, ehra, kzib_, ödan, 
   {{0x2b405049,0x2d540108,0xceac00ec,0x00000000}},	//   djic_, _väen_, پڙي_, --, 
   {{0x6d5db4ea,0xd85001e1,0xfc640395,0x00000000}},	//   ghra, _bọ́_, бъбн, --, 
   {{0xf99c00e4,0x00000000,0x00000000,0x00000000}},	//   _upèi_, --, --, --, 
   {{0x9f4801e1,0x00000000,0x00000000,0x00000000}},	//   _ókàn_, --, --, --, 
   {{0x6d5c9875,0x3f8805a1,0x6b5800d2,0x398c01c7}},	// [2fb30] bhra, mocu_, _sígc, küst_, 
   {{0x6d5db4eb,0xdd90314e,0x3f8819f5,0xd8500241}},	//   chra, _زوج_, locu_, _fọ́_, 
   {{0xe6880131,0xcd0000b8,0x398c0036,0x2d54000d}},	//   ەننى_, _deśā_, düst_, _mäel_, 
   {{0x2a6001d4,0xa3bc000d,0x6ff800df,0x00000000}},	//   bzib_, _आढ़_, רהאפ, --, 
   {{0xdd2400ef,0x00000000,0x00000000,0x00000000}},	//   _mūžd, --, --, --, 
   {{0xf48002d3,0x195800fd,0x398c04cc,0xd95400f2}},	//   _ይቕረብ_, _тагы_, güst_, _بچرخ, 
   {{0x6b59b4ec,0x3f880cf4,0xd7c812ea,0x48fc000d}},	//   _híga, kocu_, _خوزه_, _लातो_, 
   {{0x6d5c0122,0x3f882b1d,0x988000de,0x60c40166}},	//   zhra, jocu_, _mīļa_, _ğima, 
   {{0x60c403be,0x3f8819f5,0xd5b00208,0x113829c6}},	//   _şima, docu_, _tí_, аяны_, 
   {{0xbeb804cc,0x622400d1,0x6b5802d2,0xa1f000d1}},	//   udën, سىپل, _míga, رۋىت, 
   {{0xd009b4ed,0x3f880268,0x8fa54b35,0xbeb804e6}},	//   шене_, focu_, жане, rdën, 
   {{0x0dd81b49,0xee4400c7,0x37c800eb,0x00000000}},	//   _ዮሴፍ_, зҭии, _লটার, --, 
   {{0x6d5db4ee,0x35d4045e,0xfbc008b0,0x59b40acd}},	//   thra, _সমুহ, _ﻣﺎﺭﻛ, _अंगर, 
   {{0xbb800952,0x2fc4020b,0x2b0c00bc,0x63a40327}},	//   ﯩﻜﻜﻪ_, _ttng_, ड्नु_, ċine, 
   {{0x0ba80a52,0x8b240261,0x6d5db4ef,0x00000000}},	//   لارى_, одве, rhra, --, 
   {{0x6d5db4f0,0xcac82bb6,0x00000000,0x00000000}},	//   shra, ргае_, --, --, 
   {{0x248003ee,0x7e7465ed,0x3ab000d1,0x95940092}},	// [2fb40] ğimi_, _дәрт_, дәрт, ግሥትን_, 
   {{0x35d40c58,0x248003ee,0x6b599279,0xfafc0240}},	//   _সমূহ, şimi_, _díga, _ecë_, 
   {{0x5a0001c0,0x7de000c7,0xd9940133,0x00000000}},	//   _үүсв, pãsý, سۆفت_, --, 
   {{0x6b58617f,0x00000000,0x00000000,0x00000000}},	//   _fíga, --, --, --, 
   {{0xe5340953,0xa3dd10af,0xbdd8007f,0x6b58032e}},	//   зель, तीन_, lyèr, _gíga, 
   {{0x03c5b4f1,0x38c80345,0xa3e80037,0x00000000}},	//   осим, _نافی_, _बिआ_, --, 
   {{0x998401d9,0x398db4f2,0x15b000d1,0x00000000}},	//   _رلٲو, rüst_, رەمس, --, 
   {{0x49040316,0x398c0254,0x00000000,0x00000000}},	//   स्रो_, süst_, --, --, 
   {{0x3f880ffb,0xa5e801af,0x00000000,0x00000000}},	//   vocu_, _ылаҡ_, --, --, 
   {{0x3a340302,0xd0400213,0x6098179e,0xc8c803ce}},	//   קרים_, lblə, ینکس_, िडिट, 
   {{0x5f95b4f3,0xb8b8008f,0x3998008f,0x2d54000d}},	//   зинт, יזיש, שייד, _väel_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9f4c04cc,0x623400d1,0x69c000e4,0x3f880010}},	//   rudà_, _хелу, _ũmen, rocu_, 
   {{0xe3b80724,0x2dc800d1,0x00000000,0x00000000}},	//   _urıs_, ﻫﻪﻣﻤ, --, --, 
   {{0x6b59b4f4,0x3f8804cc,0xd0f801ad,0xdc3c00d0}},	//   _síga, pocu_, ्भरण_, páčt, 
   {{0xa3dc0b26,0x5ed400bd,0x00000000,0x00000000}},	//   तीय_, _থাকে, --, --, 
   {{0xbeb80de2,0xaa940166,0x00000000,0x00000000}},	// [2fb50] ndëm, дитч, --, --, 
   {{0x0af005f5,0x38c9b4f5,0x00000000,0x00000000}},	//   _үүрэ, руан_, --, --, 
   {{0x69c000d8,0xa3dc0a59,0x00000000,0x00000000}},	//   _émen, तीम_, --, --, 
   {{0xf6e4187f,0x00000000,0x00000000,0x00000000}},	//   іцен, --, --, --, 
   {{0xd6281d5e,0x95940092,0xa3e80118,0x00000000}},	//   соле_, ግሥቱን_, _बिउ_, --, 
   {{0x25a9b4f6,0x85080046,0xe3b803b9,0x00000000}},	//   يدوي_, йдің_, _arıq_, --, 
   {{0xa98800cf,0xc79401d3,0xd04006be,0x00000000}},	//   _بۅلۅ_, _کھلا_, bblə, --, 
   {{0x170401ed,0xa89800d4,0x398c0254,0x7ae801e7}},	//   _رہتی_, _єкту_, püss_, ógth, 
   {{0xdef00b82,0xbeb80200,0x44b0013d,0xa3dc0210}},	//   ፍንን_, rdël, мбәс, तीब_, 
   {{0xc69000c8,0xdb0c02d2,0x2018031c,0x00000000}},	//   _טאן_, _áhær, ħrin_, --, 
   {{0x746816ab,0x2b0c000d,0x6d48000d,0x00000000}},	//   _трав_, ड्डु_, ödam, --, 
   {{0x80dc00cc,0x00000000,0x00000000,0x00000000}},	//   _মাণ্, --, --, --, 
   {{0x7c8c001f,0xdb040205,0x96080154,0xd1c8030d}},	//   _መስለው_, _duhü, লিকম_, _улле_, 
   {{0xff5c011f,0xe16400c6,0xca6401a9,0x8c44113e}},	//   ahî_, _يدوي, _xakе, пеге, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbb40a8c9,0x67040374,0xdb040306,0xff5c0022}},	//   неск, _kōkō, _tuhý, chî_, 
   {{0xb180012c,0xdfa5b4f7,0xa9680032,0x4438004d}},	// [2fb60] šťuj, _تحوي, ҡиға_, ̣p_, 
   {{0x6b5802d2,0x00000000,0x00000000,0x00000000}},	//   _gígn, --, --, --, 
   {{0xf99c0241,0x1cb4025c,0xe3b84dd9,0x00000000}},	//   _apès_, _ཞུག_, _asın_, --, 
   {{0x6934021a,0x2d99b4f8,0xeb340228,0x46a5b4f9}},	//   _ښکار, llre_, _تۉرد, паев, 
   {{0xe3b80166,0xca64022e,0x59b40037,0x271c08e9}},	//   _arıp_, _pakе, _अंचर, _नसीर_, 
   {{0xd5b8005e,0x00000000,0x00000000,0x00000000}},	//   ісі_, --, --, --, 
   {{0x2d9800a3,0x38c800e5,0x00000000,0x00000000}},	//   ilre_, _چاہی_, --, --, 
   {{0x3b0000b0,0x22c002b5,0x33f000d1,0x6d480254}},	//   _tūpō_, kōkō_, رسىس, ödaj, 
   {{0xa3dc09d9,0xe3b80166,0xa3e82e05,0x00000000}},	//   _तौर_, _erıp_, _बिक_, --, 
   {{0x73300131,0x2d9801f5,0xbeb80036,0xea000051}},	//   _ۋىلا, jlre_, rdëm, _nvật_, 
   {{0x80dc00bd,0xf2d800bd,0x1aa800dc,0x845800cf}},	//   _মাদ্, _ধারণ, _कण्ठ, _урат_, 
   {{0x389800c8,0xfbd000e5,0xaed4004e,0x00000000}},	//   מיינ, ہتر_, ноюш, --, 
   {{0x7d0004f3,0x1cb40003,0xdce400b8,0x7e9c0150}},	//   _önsk, _ཞུང_, _amhā, _ﺍﺭﺷﺎ_, 
   {{0xfbd10fec,0x00000000,0x00000000,0x00000000}},	//   فتر_, --, --, --, 
   {{0xbeb8002e,0x71200228,0x00000000,0x00000000}},	//   ndëk, _سىيم, --, --, 
   {{0x6b580005,0x30780375,0xda08009a,0x00000000}},	//   _dígo, _לאונ, ييزه_, --, 
   {{0xa3dc0574,0xbdf80137,0x00000000,0x00000000}},	// [2fb70] तीत_, _ارعا_, --, --, 
   {{0x6b58004e,0x01bc015b,0x940403e3,0x00000000}},	//   _fígo, _ইবাদ, _eylə_, --, 
   {{0xaf2000bd,0xa3e802a0,0xa3dc0d2b,0x645c031c}},	//   ধারণ_, _बिग_, _तौल_, _żrin, 
   {{0x60c40356,0x7f64008e,0x0bac5f32,0x00000000}},	//   _şiml, _çuqı, _ﺳﺎﻳﺮ, --, 
   {{0x89d800ec,0xd02400eb,0x00000000,0x00000000}},	//   _ووٽر_, যময়_, --, --, 
   {{0xe61802bf,0x00000000,0x00000000,0x00000000}},	//   яді_, --, --, --, 
   {{0x3f8001a6,0xb764022e,0x00000000,0x00000000}},	//   čkuj_, _етай, --, --, 
   {{0xc0b80b82,0xd1c85cfa,0x00000000,0x00000000}},	//   _ሰመረ_, олие_, --, --, 
   {{0x6d480793,0xe6100c4f,0x10f40006,0x645c0205}},	//   ödak, _مشل_, мяня, _ürin, 
   {{0xd5b1b4fa,0x4fe821f3,0x63a40135,0x00000000}},	//   _شفا_, омон_, ċina, --, 
   {{0x1cb4031c,0x6b5802f0,0xc950011a,0xe3b800fd}},	//   _ཞུཊ_, _bígl, דמי_, _urıp_, 
   {{0x52740276,0xbeb80200,0x00000000,0x00000000}},	//   _оулу, heëf, --, --, 
   {{0xbea00150,0x00000000,0x00000000,0x00000000}},	//   каюк, --, --, --, 
   {{0xf1a4586f,0xb1a400cf,0x00000000,0x00000000}},	//   _эрен, _эшек, --, --, 
   {{0x0fc407d6,0x6b5801ef,0xfc000108,0x00000000}},	//   _ўйин, _fígl, кпро, --, 
   {{0x205400d4,0x998800a2,0x00000000,0x00000000}},	//   _ятір, ltaň_, --, --, 
   {{0x0d84006c,0x6f05b4fb,0xe3b81918,0x48e4f7f2}},	// [2fb80] _олин, _icic, _asıl_, дозв, 
   {{0x6e248cd7,0x8d740424,0x4874ba32,0x00000000}},	//   _isib, _زاخا, وداس, --, 
   {{0xb95801e1,0x6e24031c,0x3f6c01ef,0x00000000}},	//   _buìb, _hsib, dřuj_, --, 
   {{0x75e001f2,0x6e24025c,0x98800171,0x00000000}},	//   _ọzar, _ksib, _līķa_, --, 
   {{0x80dc0eac,0x6e240003,0xe9745f32,0x00000000}},	//   _মাস্, _jsib, _كۇرد, --, 
   {{0x6e24cc82,0x64d80c70,0x00000000,0x00000000}},	//   _msib, डरेश, --, --, 
   {{0xc10c001e,0x69c40003,0x93c800fb,0x00000000}},	//   _bỗng_, lqie, птыҡ_, --, 
   {{0x6e25b4fc,0x29c401e3,0x00000000,0x00000000}},	//   _osib, _köa_, --, --, 
   {{0x6e24cd29,0x69c40200,0x681000b8,0x00000000}},	//   _nsib, nqie, _ṛdhy, --, 
   {{0x6f0407a8,0x961c0227,0xd6d8012d,0x75d000ae}},	//   _acic, _uxņa, _dołu_, _شيما, 
   {{0x6e247456,0x3944005b,0x988000de,0xa3e81b76}},	//   _asib, önsi_, _dīķa_, _बिट_, 
   {{0x2ee001fa,0xeff40240,0x00000000,0x00000000}},	//   _ceif_, ላለያ_, --, --, 
   {{0xeff4044e,0x2ee1b4fd,0x73300131,0x442c005c}},	//   ላለየ_, _deif_, _جىنا, lvf_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6e240028,0xdd940ede,0x2c080276,0xac9401f0}},	//   _esib, _җаны, мэто_, варш, 
   {{0x2ee004c4,0x442c004c,0x69c4031c,0xd378074d}},	//   _geif_, ivf_, fqie, _ячĕ_, 
   {{0x98a00882,0xab94cea4,0x503800db,0x00000000}},	// [2fb90] ddhā_, титі, _ويۇڭ_, --, 
   {{0xeff402d3,0x2ee1a0f0,0x00000000,0x00000000}},	//   ላለዩ_, _zeif_, --, --, 
   {{0xe3b803e0,0x6e2400e5,0x00000000,0x00000000}},	//   _asım_, _zsib, --, --, 
   {{0xb3080135,0xfe7c067c,0xa3e85b82,0xe56800d1}},	//   _གཡེང_, caïc_, _बिज_, ۈمنى_, 
   {{0xc10c004d,0x7aec03ac,0xa3dc7220,0x1cb40327}},	//   _rỗng_, _idct, तीस_, _ཞུཌ_, 
   {{0xd4a400ee,0x00000000,0x00000000,0x00000000}},	//   нилй, --, --, --, 
   {{0xdec40f7c,0xe3b80205,0xa9a401a9,0x98a000dc}},	//   _ጸጋን_, _esım_, _риёд, bdhā_, 
   {{0x439000f0,0x56940818,0x58840150,0x00000000}},	//   лајс, _забт, _жыға, --, 
   {{0x2ee1b4fe,0x490407af,0x00000000,0x00000000}},	//   _reif_, स्को_, --, --, 
   {{0x6f04fff3,0x2ee1b4ff,0xa3e81152,0x69c000e4}},	//   _scic, _seif_, _बिच_, _ũmek, 
   {{0x6e25b500,0x6f0400d8,0x4fc000cf,0xa1c4004e}},	//   _ssib, _pcic, دەبە, нбөд, 
   {{0xe37400c7,0x99880306,0xdbcc01e1,0x929c012d}},	//   _илхы, staň_, _lóót, egłe, 
   {{0x80dc03f4,0x00000000,0x00000000,0x00000000}},	//   _মার্, --, --, --, 
   {{0x9f4c07c5,0x29c40254,0x6b58032e,0x00000000}},	//   ardà_, _röa_, _gígj, --, 
   {{0x4f940251,0x29c4010e,0x69c40327,0x00000000}},	//   _приу, _söa_, wqie, --, 
   {{0x6e25b501,0xd1c802d3,0x69c4003d,0xdb1001e1}},	//   _tsib, _በለት_, tqie, _ìfìw, 
   {{0x6e245936,0x3f78010f,0x00000000,0x00000000}},	// [2fba0] _usib, _מאקס, --, --, 
   {{0xfe7c067c,0x00000000,0x00000000,0x00000000}},	//   saïc_, --, --, --, 
   {{0x38c804fb,0x69c4002e,0x2c9400f2,0x00000000}},	//   سالی_, sqie, _شیرآ, --, 
   {{0x06855a5f,0x00000000,0x00000000,0x00000000}},	//   нген, --, --, --, 
   {{0x6fc000d1,0x69c40135,0x00000000,0x00000000}},	//   ﻨﺪﺍﺷ, qqie, --, --, 
   {{0xb308003d,0x7aec039a,0xc4c40137,0x00000000}},	//   _གཡུང_, _zdct, رتتو, --, 
   {{0x17c40124,0x1cb40327,0x3490974c,0xf9800395}},	//   _аасҭ, _ཞུབ_, лашр, _сгро, 
   {{0xd36c0131,0xdbcc0248,0x3898011a,0xd6f8010a}},	//   يۇل_, _kóòt, _זילנ, _охуш_, 
   {{0x3664828d,0x320401c0,0x442c003e,0xfafc036e}},	//   _зато_, нхэн_, svf_, _imët_, 
   {{0xbeb80023,0xd57400c7,0xfe7c0129,0x00000000}},	//   ndëv, _иухь, jaïa_, --, 
   {{0x7411b502,0xa3dc2aa1,0xdbcc0248,0xc3d826c6}},	//   _مولا, तीश_, _lóòt, _رباط_, 
   {{0xc308011c,0x00000000,0x00000000,0x00000000}},	//   _хедж_, --, --, --, 
   {{0xa3dc000d,0x2bb4012d,0xd1c95097,0x00000000}},	//   तीर_, ंगना, _በለቶ_, --, 
   {{0x1cb40327,0x00000000,0x00000000,0x00000000}},	//   _ཞུད_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7bc0004a,0x5f943edb,0x309802e4,0xb22004b4}},	//   _énum, _шийт, _משומ, _рмәл, 
   {{0x1ab401c6,0x6b5801e7,0xe3b803e0,0x200c6cba}},	// [2fbb0] тбая, _mígh, _asık_, ltdi_, 
   {{0xbeb80af9,0x5fa428fe,0x00000000,0x00000000}},	//   geëe, _गीतल, --, --, 
   {{0x2d54007d,0xd6d1b503,0x7aec0334,0x67d42ec9}},	//   _päev_, لقا_, _tdct, гоху, 
   {{0xf090008f,0x09c400cc,0xe50400d1,0x6d480037}},	//   אנע_, শীধা, ۇبىي, ödav, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4a580d65,0x00000000,0x00000000,0x00000000}},	//   _חדשו, --, --, --, 
   {{0xa3dc2413,0x649806bb,0x9f5800e4,0xd7c80633}},	//   तील_, нтър_, îrû_, _آوره_, 
   {{0x25f001ad,0x11d8007b,0xe89400c0,0x00000000}},	//   ुंशी_, ووعة_, _сась, --, 
   {{0xe785b504,0x9f4c01f1,0xd185b505,0x6b5800ae}},	//   _суро, budú_, клий, _dígh, 
   {{0x5ec41321,0x34480354,0x00000000,0x00000000}},	//   ғирғ, _нчен_, --, --, 
   {{0x2d541572,0x49042ef1,0x931406c2,0x00000000}},	//   _mäet_, स्टो_, _لواش, --, 
   {{0x69c0011c,0x50d00882,0xdb040e78,0xf230104c}},	//   _èmeg, _द्रष, _zuhö, _مبتک, 
   {{0xc7b000c8,0xe3b0009f,0xdcf40064,0x00000000}},	//   יבט_, _ارل_, nozė, --, 
   {{0x2d5402f6,0x62840153,0x91e001af,0xd1c80023}},	//   _näet_, _žiog, _йәүһ, _በለታ_, 
   {{0xabc004a2,0x8b940108,0x00000000,0x00000000}},	//   _ﻣﺎﻗﺎ, врач, --, --, 
   {{0x0b18007b,0x1c4400c7,0xeb54215c,0xdcf40064}},	//   بقرة_, ымсҭ, دىرگ, kozė, 
   {{0x2d540139,0x09e42c25,0x09280137,0x00000000}},	// [2fbc0] _bäet_, тозн, мжай_, --, 
   {{0x1cb40156,0xefc80b82,0x00000000,0x00000000}},	//   _ཞུཝ_, _በረድ_, --, --, 
   {{0x31100b7c,0x6b5800d8,0xcb6801ec,0x98b00064}},	//   त्यः_, _lígi, _жане_, _mozė_, 
   {{0x9b100165,0x58944530,0xbeb80200,0x00000000}},	//   _ḵẖāl, ушуу, rdëv, --, 
   {{0x5f041d15,0x6d5c0108,0x6b582131,0x04b40050}},	//   _वास्_, okra, _nígi, چھاں_, 
   {{0x645c0254,0x200c01b9,0x08f800ae,0x00000000}},	//   _ürik, ytdi_, _ترحب_, --, 
   {{0x6d5db506,0xe6f8006a,0xa3dc6526,0x3824036b}},	//   ikra, _âsïö, तीं_, _ижро_, 
   {{0x2d5400af,0x24800311,0x6d5db507,0xc7a43f72}},	//   _käes_, ăim_, hkra, _рибк, 
   {{0x6d5c0008,0x720000cf,0x88940075,0xbeb80200}},	//   kkra, لويم, _чиңх, ndët, 
   {{0x6d5c3883,0x84e858c5,0x6b5859bd,0xdb0c01b8}},	//   jkra, _آفاق_, _dígi, _äköm, 
   {{0x3954025f,0x201800db,0x98b00153,0x00000000}},	//   דשים_, ïri_, _dozė_, --, 
   {{0x6578db29,0x645806ea,0x6d5db508,0x200db509}},	//   livh, myvi, ekra, rtdi_, 
   {{0x645802d5,0x6d5db50a,0x01640107,0x00000000}},	//   lyvi, fkra, _икдо, --, 
   {{0x6578a79a,0x48fc0ce0,0x72000244,0x1f740150}},	//   nivh, _लागो_, _ئووم, _әлия, 
   {{0x30a00801,0x9f340220,0x9988002e,0x8c380107}},	//   _кръв, _бейі, staŋ_, норӣ_, 
   {{0x65781aa1,0x6d5db50b,0x70b4011a,0xfafc0200}},	//   hivh, akra, _בהוד_, _amër_, 
   {{0x1cb40135,0x6d5c7a84,0x5a3515af,0xeab0007b}},	// [2fbd0] _ཞུམ_, bkra, ынат, قعك_, 
   {{0xd99852c8,0x6d5db50c,0x6459b50d,0x65780477}},	//   رنات_, ckra, kyvi, jivh, 
   {{0x65781682,0xdbcc022c,0x57f403fb,0x63a4031c}},	//   divh, _góðt, упет, ċinj, 
   {{0xfafc02d3,0x2bb40490,0x64580064,0xe8940022}},	//   _emër_, ंगणा, dyvi, шахь, 
   {{0x95742eca,0x2b4401c6,0xb9b401af,0x00000000}},	//   лыкч, _тээг, _аҫау_, --, 
   {{0x6b59b50e,0x2d5401c7,0xdcf40153,0x00000000}},	//   _rígi, _häer_, rozė, --, 
   {{0x2d5404e6,0x6b58148b,0x64592897,0xdc440171}},	//   _käer_, _sígi, gyvi, _vīķe, 
   {{0xbeb8069c,0x15f43d4d,0x1308352d,0x6d5d37cb}},	//   ndës, ुंदर_, хний_, zkra, 
   {{0x2d540221,0x2bb40490,0x00000000,0x00000000}},	//   _mäer_, ंगता, --, --, 
   {{0x6458007f,0x91642f84,0x6b5802d2,0x00000000}},	//   byvi, اهده, _vígi, --, 
   {{0x64580354,0xc4d00302,0xb401ae7a,0x00000000}},	//   cyvi, _הגב_, _түйд, --, 
   {{0x6d5c01f5,0x00000000,0x00000000,0x00000000}},	//   wkra, --, --, --, 
   {{0xdd000374,0x5f040073,0x00000000,0x00000000}},	//   _ōtāk, _वार्_, --, --, 
   {{0x10a41607,0xfe7c026c,0x6d5c01bf,0x93440354}},	//   _йилн, maïl_, ukra, _инçе, 
   {{0x6d5db50f,0x0cbc12eb,0xb00001ee,0x00000000}},	//   rkra, ्डौम, _тойһ, --, 
   {{0x9f540408,0x00000000,0x00000000,0x00000000}},	//   _кĕск, --, --, --, 
   {{0x2d540a40,0x6d5db510,0x65780564,0x260800c5}},	// [2fbe0] _däer_, pkra, yivh, _समधी_, 
   {{0x59640220,0x2d540254,0xc2f80154,0x00000000}},	//   ануғ, _väes_, _আসছি_, --, 
   {{0x9f4c0724,0x07a43d2a,0x4c34084c,0x2bb40073}},	//   brdä_, гажн, _сэпт, ंगदा, 
   {{0x2d540221,0x3a3c16a3,0x311000dc,0x645802f0}},	//   _gäer_, _šupe_, त्तः_, vyvi, 
   {{0x6b8400ae,0x6578006f,0x35f400f2,0xdb1001e1}},	//   mnig, tivh, هرود_, _ìfáw, 
   {{0x645802d5,0x6b85b511,0x99380139,0xb5c4451a}},	//   tyvi, lnig, _иясу_, دووم_, 
   {{0xbeb8069c,0x6578b6ad,0x6b85b512,0xa928005f}},	//   ndër, rivh, onig, režģ, 
   {{0xf361b513,0x6b85b514,0x6459b515,0x3435b516}},	//   йтын, nnig, ryvi, اسود_, 
   {{0x6459b517,0x6b85b518,0xd24c0014,0x628400c0}},	//   syvi, inig, ٘ۆن_, _žiob, 
   {{0x69c0004a,0x36180a1e,0x6b85b519,0x238c00bc}},	//   _émeu, _אומד, hnig, děje_, 
   {{0x291801ab,0xe58800cf,0x00000000,0x00000000}},	//   _mbra_, _كۅچۉ_, --, --, 
   {{0x5f940323,0x6b85b51a,0xde580006,0xdeb40108}},	//   римт, jnig, вамі_, ибны, 
   {{0x6b85b51b,0x3af80241,0x3390007b,0x26c0002e}},	//   dnig, _làpà_, _النز, ñioy_, 
   {{0x6b842619,0x6b580005,0x2d54013d,0x00000000}},	//   enig, _mígu, _säer_, --, 
   {{0x6b580077,0xac1800f7,0x48fc0073,0xfba843a2}},	//   _lígu, лору_, _लाजो_, етай_, 
   {{0x6b85b51c,0x2918dd69,0x6d48369a,0x9ad40354}},	//   gnig, _abra_, ödar, ржач, 
   {{0x9998023b,0xdcf400e2,0x63a00037,0x61e40205}},	// [2fbf0] вкат_, nozī, ilmn, _çild, 
   {{0x6b8401d9,0x2d540221,0x2c14009e,0xbeb801c7}},	//   anig, _wäer_, ায়েই_, sdës, 
   {{0x6b84003a,0x298800d8,0x09c400fe,0x2bf40024}},	//   bnig, усто_, শীলা, _ляўр, 
   {{0x9635b51d,0xdb1ce64a,0x6b85b51e,0x9b04010b}},	//   инец, _misë, cnig, _өзүд, 
   {{0x291805da,0xaaa800a7,0xd6280556,0xe3b80139}},	//   _fbra_, _бърз_, толе_, _urıy_, 
   {{0x7d040097,0x00000000,0x00000000,0x00000000}},	//   ngjs, --, --, --, 
   {{0x67d41c65,0xdb1cce7b,0x9344228c,0x6b580a87}},	//   _госу, _nisë, инке, _vígv, 
   {{0x27fc01f1,0x3f9801e2,0x00000000,0x00000000}},	//   ávne_, _nkqu_, --, --, 
   {{0x248c0204,0x69c0004a,0x6b580248,0xf42401d5}},	//   _exdm_, _émet, _gígu, тоқл_, 
   {{0xe3b00050,0x50b5b51f,0x74680305,0x4204003b}},	//   _ہرن_, исну, _прев_, шньо_, 
   {{0x2d84012c,0x6b84f286,0x931800c6,0x10a4130f}},	//   émem_, ynig, _لقاء_, ринн, 
   {{0xdeec0075,0x799402c4,0x683001ed,0xbeb80023}},	//   ىۋى_, hoxw, lódá, vdër, 
   {{0x91e5b520,0x7994009a,0x2bb401f9,0x00000000}},	//   _толе, koxw, ंगसा, --, 
   {{0x2d540139,0xfce0022e,0x00000000,0x00000000}},	//   _cäep_, жоро, --, --, 
   {{0x8fa4004e,0x799402d0,0x4fa401c4,0x00000000}},	//   _каке, doxw, _кикв, --, 
   {{0x7521b521,0x6b85b522,0xbeb8036e,0x998800d7}},	//   henz, unig, rdër, vvaš_, 
  
   {{0x7521b523,0x88e4023a,0x2fc5b524,0xafe00116}},	// [2fc00] kenz, ижае, _hung_, _тоқл, 
   {{0x2fc40f6f,0xdb1c0502,0x7521b525,0x613401ed}},	//   _kung_, _lisè, jenz, pülő, 
   {{0x75207b34,0x6b581280,0x2fc46040,0x3a29b526}},	//   denz, _sígu, _jung_, _escp_, 
   {{0x2fc5b527,0x6b85b528,0x2d99a02e,0xb6f421ea}},	//   _mung_, qnig, lore_, لىما_, 
   {{0x2fc06ed5,0x2fc4011a,0xbeb80036,0x2d980129}},	//   _miig_, _lung_, ndëp, oore_, 
   {{0x7521b529,0x6db40227,0x29186d1f,0x2fc0adac}},	//   genz, _ińas, _ubra_, _liig_, 
   {{0x2fc5b52a,0xdb1c0100,0x2d98003a,0x69cc0073}},	//   _nung_, _bisè, iore_, _थंडी, 
   {{0x2d981f4c,0x3ebc01a6,0x88380092,0xf4840133}},	//   hore_, žuti_, _የሚታደ, جاهی, 
   {{0x75207ea9,0x2d982661,0xdb1d9230,0x69c000d8}},	//   benz, kore_, _disè, _émes, 
   {{0x2fc5b52b,0x2d99b52c,0xc8a802ab,0x2bb8007f}},	//   _bung_, jore_, _कराट, _wōch_, 
   {{0x2d99b52d,0x2fc5b52e,0xdb1c24bc,0xbeb80942}},	//   dore_, _cung_, _fisè, geën, 
   {{0x2fc5b52f,0xdb1c387a,0x00000000,0x00000000}},	//   _dung_, _gisè, --, --, 
   {{0x2d99b530,0xffa005f5,0x2fc5b531,0xff5c011f}},	//   fore_, йлүү, _eung_, rkî_, 
   {{0x2d98252e,0x2fc40007,0x79940912,0x15d400d1}},	//   gore_, _fung_, xoxw, ﻟﺪﯨﻐ, 
   {{0x2fc5b532,0x6c5411e5,0x1bd40395,0x00000000}},	//   _gung_, окру, собя, --, 
   {{0x7521b533,0x31c00014,0x683001d3,0xdb1c00e5}},	//   zenz, _دۅیہ, zódá, _kisé, 
   {{0x752037ea,0x78e8736a,0xdea020d3,0x311000dc}},	// [2fc10] yenz, вьев_, _ریسی, त्वः_, 
   {{0x2d99b534,0x2fc4357f,0xdb1db535,0xa3a800c5}},	//   core_, _yung_, _misé, _खीस_, 
   {{0x2fc40016,0xd878fe1e,0xdb1c0c6a,0x683000e5}},	//   _xung_, دمات_, _lisé, vódá, 
   {{0x752102b5,0x7bd401c0,0x15f4007b,0xdb1c0332}},	//   wenz, _itxu, مستح, _oisé, 
   {{0xdb1c0066,0x9f4c0407,0x2bb40490,0xaa9400d4}},	//   _risè, ludó_, ंगरा, _миюч, 
   {{0x07040022,0x7520002f,0xd7c802f2,0x8a4401c8}},	//   ацәҭ, uenz, _موسه_, _ائٽم, 
   {{0xdb1db536,0x1d700023,0xc0e80092,0x00000000}},	//   _aisé, _ኣብዚኣ_, _ሆንሁ_, --, 
   {{0x2fc5b537,0x2d99b538,0x69c007ea,0x8fd001e0}},	//   _rung_, zore_, _émer, үәйә, 
   {{0x2fc5b539,0x7521b53a,0x2fc00037,0x2bc0033f}},	//   _sung_, penz, _riig_, _शंघा, 
   {{0x2fc4e3d4,0x0fd9b53b,0xdb1c8616,0x70e4016c}},	//   _pung_, льмы_, _disé, шгоҳ_, 
   {{0x7bd40457,0x2fc0022f,0x2fc4022e,0x6b58032e}},	//   _ntxu, _piig_, _qung_, _mígr, 
   {{0x10a41607,0x2fc4001e,0x6b58004e,0x2d99b53c}},	//   _қийн, _vung_, _lígr, wore_, 
   {{0x2d99b53d,0xdb1c00e8,0x7bd401c6,0x2fc4003e}},	//   tore_, _gisé, _atxu, _wung_, 
   {{0x2fc5b53e,0x76480369,0x2fc1b53f,0x00000000}},	//   _tung_, ixgy, _wiig_, --, 
   {{0x2d99b540,0x645c007d,0x2fc00165,0x2bb47220}},	//   rore_, _ürit, _tiig_, ंगला, 
   {{0x2d99b541,0x3a3c1ebd,0x31100882,0x61f00139}},	//   sore_, _šupa_, त्रः_, _ählä, 
   {{0x7bd4005a,0x4430004d,0x7c3800b0,0xe8e80116}},	// [2fc20] _etxu, ̉y_, āura, игаһ_, 
   {{0xfe34008f,0x8d74036b,0x2d98058a,0xcd0402e8}},	//   _פריי_, _چاگا, qore_, _упой, 
   {{0x6b580077,0x7d54008f,0x86c471fc,0xb7d45d62}},	//   _dígr, _הייד_, ميان, مولا_, 
   {{0x6b591898,0xb8fc5c8e,0x86448abc,0x00000000}},	//   _vígs, _ध्_, йнеж, --, 
   {{0x68f813de,0x36305f2e,0xdcf400da,0x76480369}},	//   _نکاح_, كروس, lizā, gxgy, 
   {{0x24580daf,0xdb1c0129,0xd5ac01d9,0x00000000}},	//   иаль_, _risé, پہم_, --, 
   {{0xdcf400da,0xdb1cf578,0xb978008f,0xdb0c002f}},	//   nizā, _sisé, _ענלי, nlaß, 
   {{0xe3b82ca8,0x00000000,0x00000000,0x00000000}},	//   _asır_, --, --, --, 
   {{0x7a78010f,0x78c400e5,0xa194004e,0x62340798}},	//   ָריס, _árvá, жапч, цепу, 
   {{0xa3a8177c,0xdb1db542,0x00000000,0x00000000}},	//   _खीर_, _visé, --, --, 
   {{0xdb1c020c,0x049400c6,0xc0580220,0x656803ac}},	//   _wisé, _الضح, уіп_, _ildh, 
   {{0xd04003be,0x23600086,0x3f64292c,0x9e1400d4}},	//   nclə, _ôij_, стоб, одмі, 
   {{0xd0b003b9,0x00000000,0x00000000,0x00000000}},	//   _məət, --, --, --, 
   {{0x49f40135,0x41b400a7,0xe0d00014,0x5d841867}},	//   _བྷེལ_, _усет, _غٲب_, زلزل, 
   {{0x31780375,0xa3dc0490,0x6fcc25c9,0xff040a89}},	//   _תרומ, तीच_, _संयं, _ляпн, 
   {{0x6b5802d2,0x00000000,0x00000000,0x00000000}},	//   _sígr, --, --, --, 
   {{0x9955b543,0x6569b544,0x00000000,0x00000000}},	// [2fc30] окац, _oldh, --, --, 
   {{0x9d1805f5,0x7c84f429,0x00000000,0x00000000}},	//   _тоот_, _гуме, --, --, 
   {{0xbd7802d3,0xbd9c0023,0x30e00154,0x00000000}},	//   _ኣብቶም_, _ሃብቶም_, _মাৎস, --, 
   {{0x6568045f,0x27fc0030,0x00000000,0x00000000}},	//   _aldh, ávna_, --, --, 
   {{0x99886a45,0x6b58032e,0x00000000,0x00000000}},	//   evať_, _tígr, --, --, 
   {{0x9988068f,0x850802dd,0x2db401ec,0xe9a40024}},	//   stał_, идің_, _ﺼﺎﻟﺤ, _наўп, 
   {{0x546800cf,0xe858030d,0x37a8014b,0x00000000}},	//   райм_, _ларш_, _бтан_, --, 
   {{0x6fcc1f5e,0x6569b545,0x22400010,0xbeb8017a}},	//   _संबं, _eldh, _šika_, teël, 
   {{0xc79401ed,0x998800d0,0x3cec00fe,0x00000000}},	//   _بھلا_, avať_, _জান্_, --, 
   {{0x7020025c,0xbeb805e4,0x00000000,0x00000000}},	//   _འགྱུ_, reël, --, --, 
   {{0x92f8f3bb,0x23840014,0x00000000,0x00000000}},	//   _نفاذ_, _کٔنِ, --, --, 
   {{0x60dc0c07,0x6db40227,0x25f1b546,0xb8c80327}},	//   ırma, _ańap, ुंची_, _ཕཊ_, 
   {{0xd10879f2,0x63a40327,0x00000000,0x00000000}},	//   _نقشه_, ċint, --, --, 
   {{0xdcf4005f,0x99880156,0x61e400a2,0x2d8c0037}},	//   tizā, ntań_, _çila, õde_, 
   {{0x2cacd821,0x7020031c,0x777801a9,0x8c9401ec}},	//   ådd_, _འགྲུ_, _omux, іргі, 
   {{0x49f4031c,0xdcf400e2,0x4ce003d4,0xbb41b547}},	//   _བྷུལ_, rizā, _বাওঁ, меск, 
   {{0xfaa1b548,0x7fb400aa,0x998800d0,0x00000000}},	// [2fc40] дато, _بهير_, zvať_, --, 
   {{0x291c0588,0x77780548,0xfafc036e,0x00000000}},	//   ýva_, _amux, _ulën_, --, 
   {{0xbae01e4a,0xc795b549,0x6c6801d3,0x17280327}},	//   سكەي, орды, _طلحہ_, _ལིཡམ_, 
   {{0xbd9c1b49,0xb7d402da,0x06d00154,0x00000000}},	//   _ሃብታም_, زوها_, ারভি, --, 
   {{0xd04003be,0xa4d400d3,0xe6040116,0x00000000}},	//   rclə, полі, яҗан, --, 
   {{0xe3b80166,0xdcf40356,0x00000000,0x00000000}},	//   _asıp_, miză, --, --, 
   {{0xdcf4084c,0xd36c00d1,0x580401af,0x00000000}},	//   liză, گۇن_, _норғ, --, 
   {{0x9f8801a8,0xa084010b,0x00000000,0x00000000}},	//   jóðs_, үңде, --, --, 
   {{0xd36c0372,0xdcf40311,0x50640023,0x36640114}},	//   دۇن_, niză, _ዝመረጽ, _дато_, 
   {{0xbc880092,0x00000000,0x00000000,0x00000000}},	//   _መሆኑና_, --, --, --, 
   {{0x4428004e,0x9f3514ab,0xdcf40356,0x00000000}},	//   _èb_, пені, hiză, --, 
   {{0x443db54a,0x9f880162,0x733000d1,0x00000000}},	//   _irt_, góðs_, _يىلا, --, 
   {{0x443c34df,0x0ce00154,0x3ebc0036,0x00000000}},	//   _hrt_, _বাড়ত, äut_, --, 
   {{0x7d18098d,0x443c8500,0x00000000,0x00000000}},	//   đuso, _krt_, --, --, 
   {{0x5bc411bc,0x443c2109,0x99d40150,0x19d40150}},	//   वदेव, _jrt_, _ﺘﻨﺘﻅ, _ﺘﻨﻘﻠ, 
   {{0x443db54b,0xe8e0001e,0xeab00014,0x00000000}},	//   _mrt_, _đền_, ھٹٕ_, --, 
   {{0x443db54c,0x99880210,0x602401e1,0x00000000}},	// [2fc50] _lrt_, ytań_, bìmò, --, 
   {{0x443db54d,0x00000000,0x00000000,0x00000000}},	//   _ort_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe80c367a,0x3f88002e,0x00000000,0x00000000}},	//   _हमरा_, nncu_, --, --, 
   {{0x443c3af1,0x3f8839b2,0xdcf40311,0x1544fb04}},	//   _art_, incu_, ciză, зелм, 
   {{0xe57802bf,0x49f40327,0xdb1c01ef,0x00000000}},	//   озі_, _བྷིལ_, _misí, --, 
   {{0xdb1c0077,0x59d001ad,0x00000000,0x00000000}},	//   _lisí, _थंडर, --, --, 
   {{0xbb18019f,0xf77c0724,0x3f8800f3,0x99880034}},	//   _ijîs, _öç_, jncu_, stań_, 
   {{0x443db54e,0x557402e8,0xf65c02d2,0x42200108}},	//   _ert_, _егат, _ææ_, едыв, 
   {{0xc5f0011a,0x00000000,0x00000000,0x00000000}},	//   _נדב_, --, --, --, 
   {{0x443db54f,0xb4e5b550,0x8fa5b551,0xdb1c007b}},	//   _grt_, परी_, зане, _aisí, 
   {{0xdb1c02ea,0x5274084c,0x2a60a84b,0x00000000}},	//   _bisí, _нулу, yyib_, --, 
   {{0x443c01ed,0xdb1c0022,0xfe7c0142,0x00000000}},	//   _zrt_, _oisâ, ybïe_, --, 
   {{0xe80c09d9,0x3f880268,0x258400b5,0xe81c00ab}},	//   _हमला_, ancu_, はlte_, _नहला_, 
   {{0x1c382db9,0xdb1c0597,0x0ba85734,0x00000000}},	//   оять_, _eisí, مارى_, --, 
   {{0xdcf4054e,0x3070023b,0x99880165,0x00000000}},	//   tiză, _нуқс, ntaņ_, --, 
   {{0xa8940213,0xc9640395,0x00000000,0x00000000}},	// [2fc60] _küçə_, пвай, --, --, 
   {{0xdcf40311,0x00000000,0x00000000,0x00000000}},	//   riză, --, --, --, 
   {{0xc725b552,0xdcf4054e,0xcb68006c,0x872400d3}},	//   здей, siză, _همده_, змеж, 
   {{0x443db553,0x2cac1427,0x4648003b,0x00000000}},	//   _rrt_, ýddu_, йзен_, --, 
   {{0xe53409fe,0x19f80276,0xdb0c0022,0x443c0f85}},	//   дель, _мэрь_, _âhár, _srt_, 
   {{0x6e2406d9,0x2bb40c4c,0x00000000,0x00000000}},	//   _mpib, ंगका, --, --, 
   {{0x3f88015d,0x00000000,0x00000000,0x00000000}},	//   yncu_, --, --, --, 
   {{0x61d8e33b,0x443db554,0x6e2416b8,0x29a40022}},	//   омия_, _vrt_, _opib, _хыҭҳ, 
   {{0xe80400bc,0x443c045a,0x00000000,0x00000000}},	//   शंका_, _wrt_, --, --, 
   {{0x443ceaab,0x26c00006,0x5f0408a3,0x00000000}},	//   _trt_, žios_, _वाङ्_, --, 
   {{0x443c9484,0x6e24d346,0x2d540139,0x30109731}},	//   _urt_, _apib, _fäez_, ндэр, 
   {{0xf48426f0,0xdce40306,0x442c0fac,0x7d0001d3}},	//   _عالی, _vlhč, mwf_, _önsz, 
   {{0x3a380354,0x62346d2a,0x336001c6,0x6ea0000d}},	//   xvqp_, _целу, _явцг, _गुदु, 
   {{0xdb1db555,0x5bc400dc,0x00000000,0x00000000}},	//   _visí, वद्व, --, --, 
   {{0x98a00325,0xaeec03f4,0x9b4400f7,0xbeb80200}},	//   kehā_, _কারণ_, ونسو, ndëz, 
   {{0xdb1c03c6,0xdb0c00d8,0x9998013a,0x2ba40798}},	//   _tisí, imaç, _prsů_, ејув, 
   {{0xfafc0200,0xaf34009f,0x00000000,0x00000000}},	// [2fc70] _ulëm_, _سريت, --, --, 
   {{0x2d8401d3,0xe8e00051,0x38c800c7,0xdb0c010b}},	//   émet_, _đển_, суан_, kmaç, 
   {{0x7bc00395,0x36880724,0xdb1c00d8,0x61c9b0ed}},	//   _ènuo, әсен_, _cisã, रदुष, 
   {{0x1a6401b9,0x442c0142,0x59a8000d,0x00000000}},	//   _قیزی_, dwf_, _कठकर, --, 
   {{0x7aec003a,0x0af001c0,0x00d802dd,0x00000000}},	//   _iect, _шүтэ, _ﺃﺘﺎﺘ, --, 
   {{0xb4e418ea,0xfe7c026c,0xbeb80b4f,0x98a82737}},	//   परे_, laïs_, geëi, şkın_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7aec13fd,0x61c80c5a,0x13088eea,0x00000000}},	//   _ject, रदूष, цний_, --, 
   {{0x7aedb556,0x9634ba4c,0x61e43c7a,0x843400d1}},	//   _mect, _юнац, _çill, ككۈر_, 
   {{0xfafc0036,0x00000000,0x00000000,0x00000000}},	//   _blëk_, --, --, --, 
   {{0xfc54001f,0x00000000,0x00000000,0x00000000}},	//   ፈላጊው, --, --, --, 
   {{0x7aedb557,0x00000000,0x00000000,0x00000000}},	//   _nect, --, --, --, 
   {{0x67cc00ee,0x61c80b02,0x00000000,0x00000000}},	//   _işje, रदृष, --, --, 
   {{0xfe7c004e,0x2ab401e1,0x4124004e,0x00000000}},	//   vaït_, _lúbí_, _жошо_, --, 
   {{0x7aec3c36,0x8b643224,0x00000000,0x00000000}},	//   _bect, وارم, --, --, 
   {{0x2c100183,0x450400cc,0x5ddc03d4,0x0ae850d8}},	//   াবলৈ_, ল্পক_, _বিৰু, ترسي_, 
   {{0xa9440184,0x2d858da2,0x00000000,0x00000000}},	// [2fc80] ндаһ, émes_, --, --, 
   {{0x9b4c001f,0xdb1c00d8,0xfe7c00cf,0x00000000}},	//   _አፈጻጸ, _pisã, raït_, --, 
   {{0x7aec2bd6,0xa3e800cc,0xd7f801ec,0x00000000}},	//   _fect, _গম্য_, зуі_, --, 
   {{0xdb1c0261,0xbeb80af9,0x7aec0790,0xf2c4007b}},	//   _visã, geëw, _gect, _لآ_, 
   {{0xbdd9b558,0x6b85b559,0x442c0b6f,0xcfe0015b}},	//   rvèg, miig, wwf_, _ময়মন, 
   {{0x6b85b55a,0x00000000,0x00000000,0x00000000}},	//   liig, --, --, --, 
   {{0x7aec009a,0x98a002b5,0x33f0007b,0xf9900677}},	//   _yect, pehā_, نسيس, _ירש_, 
   {{0xdb0c0a16,0x6b85b55b,0x48e4012c,0xdb1c01d3}},	//   rmaç, niig, टरको_, _kisá, 
   {{0x3204009d,0x00000000,0x00000000,0x00000000}},	//   мхэн_, --, --, --, 
   {{0xdb1db55c,0x2570002e,0x6b840014,0x442c0175}},	//   _misá, _bàle_, hiig, pwf_, 
   {{0x25bc01c7,0x6b85b55d,0x00000000,0x00000000}},	//   mmvl_, kiig, --, --, 
   {{0x6b840083,0xefe40092,0x00000000,0x00000000}},	//   jiig, ማሪያ_, --, --, 
   {{0x63a1b55e,0x7aec26c2,0xc0440214,0x9f4c04cc}},	//   momn, _rect, سخگو, rsdà_, 
   {{0x63a1b55f,0x7aec3498,0x00000000,0x00000000}},	//   lomn, _sect, --, --, 
   {{0x7aed8967,0x8024107f,0x260805f9,0x645c00db}},	//   _pect, _آرتم, _समझी_, _àrid, 
   {{0xdb1c043b,0x200db560,0x6b85b561,0x212db562}},	//   _bisá, mudi_, giig, ledh_, 
   {{0x200c003d,0x1a65b563,0x7aed0f14,0xdb1c00d0}},	// [2fc90] ludi_, ریسی_, _vect, _cisá, 
   {{0x784c02ea,0x212c03d5,0x63a0022e,0x00000000}},	//   lɔvɛ, nedh_, homn, --, 
   {{0x200c08a4,0x7aedb564,0xbeb801a4,0x6b8400ef}},	//   nudi_, _tect, geëv, biig, 
   {{0xf8dd2877,0xb4e44108,0x6b84008f,0x4de00c58}},	//   _प्रय, पर्_, ciig, _বিতং, 
   {{0xf771b565,0x200db566,0x63a00171,0x8d700023}},	//   _یار_, hudi_, domn, _ጽምብል_, 
   {{0x200c0032,0x212c02d3,0xf77005d9,0x00000000}},	//   kudi_, jedh_, _ڌار_, --, 
   {{0xa8a4748c,0x61e40240,0x212c0332,0x00000000}},	//   _артк, _çilj, dedh_, --, 
   {{0x200db567,0x63a000f1,0xbef807f7,0xc42800db}},	//   dudi_, gomn, ्लोन_, ستىە_, 
   {{0x8ee800fb,0x0320009d,0x00000000,0x00000000}},	//   үмов_, удын, --, --, 
   {{0xd5b1b568,0x200db569,0x6b85b56a,0x212c4230}},	//   _صفا_, fudi_, ziig, gedh_, 
   {{0x200db56b,0x6b841418,0xe50807c0,0xfafc0200}},	//   gudi_, yiig, _زينو_, _odë_, 
   {{0xfafc036e,0x03d40a7c,0xa2840023,0x92580395}},	//   _ndë_, _טועם_, ምላኽን_, _нает_, 
   {{0xa4940240,0x00000000,0x00000000,0x00000000}},	//   _ይሕደጎ_, --, --, --, 
   {{0xfafc006a,0xfe7c004e,0x6aa0003b,0x00000000}},	//   _adë_, taïr_, _ømfi, --, 
   {{0x6ea008dd,0xfafc01c7,0xc4d00375,0xdc440171}},	//   _गुरु, _bdë_, רגל_, _mūķe, 
   {{0x645c00db,0xfe7c00db,0x2018004e,0xdb100241}},	//   _àrie, raïr_, àrie_, _ìgìd, 
   {{0x6b85b56c,0x7b8400db,0x00000000,0x00000000}},	// [2fca0] riig, رافە, --, --, 
   {{0x63a1b56d,0x850c44ab,0x2dc801ec,0x6b85b56e}},	//   zomn, _साइट_, _تاعۋ_, siig, 
   {{0x6b857f64,0xc8940640,0x37e0009d,0x00000000}},	//   piig, храњ, гохг, --, 
   {{0x09e5b56f,0xeb3400f7,0x00000000,0x00000000}},	//   _помн, _جۉرد, --, --, 
   {{0xe80c02e5,0xdb1c005c,0xbeb80af9,0xdd740133}},	//   _हमका_, _bisæ, seëv, _سپێک, 
   {{0x200d0f44,0x63a0004b,0x00000000,0x00000000}},	//   yudi_, womn, --, --, 
   {{0x63a1b570,0x03c43500,0x5ef400dc,0x97c400db}},	//   tomn, нсим, ्णम्_, رتۅم, 
   {{0x6028016b,0xd04c013f,0x200db571,0x97b40153}},	//   _yɛmf, _ɛkɔs, vudi_, _асуш, 
   {{0x200db572,0x238c0118,0xa2b402e8,0x00000000}},	//   wudi_, něji_, ъбич, --, 
   {{0x200db573,0x63a001f1,0xc1b001e0,0xa2cc0073}},	//   tudi_, somn, ыҙлы, _हलक्, 
   {{0x63a1b574,0x212c03d5,0x2019b575,0x59a817ee}},	//   pomn, redh_, îri_, _कठघर, 
   {{0x200d0e3e,0x212c0421,0xa3a802e5,0x2d84007f}},	//   rudi_, sedh_, _खीच_, èmen_, 
   {{0x200db576,0x01d81c82,0xfe4003e6,0x98b0005f}},	//   sudi_, _দিকদ, اکبی, _mazā_, 
   {{0x200c000a,0x238c012c,0x45cc00d1,0x00000000}},	//   pudi_, ději_, _ﻗﻮﻟﻼ, --, 
   {{0x850c7f1a,0x8c380107,0x00000000,0x00000000}},	//   _साईट_, морӣ_, --, --, 
   {{0x9cc801ec,0x6b5800e5,0x00000000,0x00000000}},	//   зыға_, _kígy, --, --, 
   {{0x5f8004a9,0x5a35b577,0xbeb8017a,0x00000000}},	// [2fcb0] _مۇھە, ънат, geët, --, 
   {{0x7f5c03b9,0x7ac4008e,0xdd040153,0x00000000}},	//   _hoqq, _үсме, _įpėd, --, 
   {{0xe9740014,0x00000000,0x00000000,0x00000000}},	//   اچُھ, --, --, --, 
   {{0xdddc068f,0xa8a40137,0x238c01ef,0x00000000}},	//   mysł, урук, běji_, --, 
   {{0x7f5c0455,0x00000000,0x00000000,0x00000000}},	//   _moqq, --, --, --, 
   {{0xa2c4089a,0x7f5c0477,0x00000000,0x00000000}},	//   ाइन्, _loqq, --, --, 
   {{0x97c4052f,0x629c0790,0x01d800cc,0xd7600133}},	//   _араһ, şrol, _দিগদ, _پۆشی, 
   {{0x7f5c0140,0x4de000fe,0x00000000,0x00000000}},	//   _noqq, _বিসং, --, --, 
   {{0xd17411ca,0xe694005b,0x00000000,0x00000000}},	//   выны, _биты, --, --, 
   {{0xa50800f3,0x95380150,0x00000000,0x00000000}},	//   _пеђа_, _ізет_, --, --, 
   {{0x7f5db578,0xdb1c0724,0x00000000,0x00000000}},	//   _boqq, _kisä, --, --, 
   {{0xdddc033f,0x27fc00d7,0x00000000,0x00000000}},	//   dysł, ávni_, --, --, 
   {{0xdb1c4a41,0x7cfc008e,0x7f5cff36,0x4de00154}},	//   _misä, _oçrı, _doqq, _বিহং, 
   {{0xdb1c426d,0xd0080dd8,0xc5e4009e,0x60c401e4}},	//   _lisä, _жеке_, _নিমপ, _ŝime, 
   {{0x7f5c00e8,0x61e40003,0xdb1c0139,0x998800a2}},	//   _foqq, _ħili, _xisç, mraň_, 
   {{0x28b80ebb,0xdb1c005b,0xcf243092,0x224000ef}},	//   _अरबि, _nisä, _شرعي, _šiki_, 
   {{0x7294044e,0x257005da,0x49c801c0,0x00000000}},	// [2fcc0] _ውድባዊ_, _làla_, длан_, --, 
   {{0x67cc00a2,0x00000000,0x00000000,0x00000000}},	//   _aşja, --, --, --, 
   {{0xbb18013c,0x7f5c01b9,0x3f9404f2,0x86c400f1}},	//   _imîn, _yoqq, _سپید_, چيان, 
   {{0x86c5b579,0xbeb8017a,0x7f5c0139,0xeab000cc}},	//   نيان, meër, _xoqq, _কলীম, 
   {{0x9f59b57a,0xdb1c00fd,0xbeb80af9,0xdb0c03b2}},	//   éré_, _disä, leër, ymaú, 
   {{0x61e56d5f,0xe5b44990,0x00000000,0x00000000}},	//   _çili, ыйлы, --, --, 
   {{0x291807b3,0xf7800327,0x02c800bc,0x00000000}},	//   _icra_, _baħħ_, ाख्न, --, 
   {{0xe8e001fb,0x607c0023,0xf3600572,0x00000000}},	//   _độn_, _ብሉጻት_, итын, --, 
   {{0xd624a482,0x325000a7,0xdddc0034,0x7f5c01a9}},	//   _معلي, ивър, zysł, _roqq, 
   {{0x7f5db57b,0x75d000cf,0x00000000,0x00000000}},	//   _soqq, _ئيلا, --, --, 
   {{0x257000a3,0x7f5c014f,0xdb0c0174,0x7410020c}},	//   _gàla_, _poqq, rmaú, _نولا, 
   {{0x82a40510,0x7f5c198f,0xbeb80af9,0xbb18054e}},	//   _ишле, _qoqq, deër, _amîn, 
   {{0x2918011c,0x7f5c0455,0x00000000,0x00000000}},	//   _ocra_, _voqq, --, --, 
   {{0x99880784,0xee1400cc,0x00000000,0x00000000}},	//   kwaš_, িবংশ_, --, --, 
   {{0x7f5c32ff,0xac19b57c,0xbeb80af9,0xfafc00de}},	//   _toqq, кору_, geër, žīmu_, 
   {{0x2919b57d,0xba7420ad,0xd01001d3,0x00000000}},	//   _acra_, پارت, _الٹ_, --, 
   {{0x29180789,0xceb5b57e,0x98b00356,0x2bc800db}},	// [2fcd0] _bcra_, _бәр_, _oază_, туро_, 
   {{0xdb1c426d,0xd6d80034,0xbeb8017a,0xfca9b57f}},	//   _sisä, _małe_, beër, _يادو_, 
   {{0xa9c4063b,0xdb1c0793,0x67d40aac,0x371401d9}},	//   рстк, _pisä, аоху, ٖرتھ_, 
   {{0xdd840220,0x213c022e,0x96b9b580,0xf48001b9}},	//   _шықп, _lavh_, нулу_, یاغی, 
   {{0x98b0084c,0x7c3802b5,0x28b8000d,0x00000000}},	//   _bază_, āuru, _अरथि, --, 
   {{0x6844001f,0x3a2806be,0x049801e1,0x00000000}},	//   _የሚሉት, _ipcp_, _ìmọr, --, 
   {{0x3d180307,0x00000000,0x00000000,0x00000000}},	//   _बाने_, --, --, --, 
   {{0x28b81a04,0xdb0c0166,0x00000000,0x00000000}},	//   _अरति, _äkäm, --, --, 
   {{0x5695b581,0xd6d80034,0x98b00311,0x00000000}},	//   _саат, _całe_, _fază_, --, 
   {{0x74680798,0x00000000,0x00000000,0x00000000}},	//   _орев_, --, --, --, 
   {{0x0fc40131,0x30c00154,0x62840064,0x8538b8b4}},	//   лйон, োর্স, _žiot, _רגעי, 
   {{0x20189022,0x00000000,0x00000000,0x00000000}},	//   ària_, --, --, --, 
   {{0xb19001af,0x00000000,0x00000000,0x00000000}},	//   _клдә, --, --, --, 
   {{0xd13001d9,0x90442bd8,0xc0e000d8,0x00000000}},	//   _طمع_, _منته, _лошк, --, 
   {{0xfce069a4,0xd0100597,0x2cac05f7,0x82c40022}},	//   сосо, _الع_, ædd_, _ишәҵ, 
   {{0x63a5b582,0x333c0003,0x00000000,0x00000000}},	//   čing, ndux_, --, --, 
   {{0x6f0402d0,0x321db583,0x09e40a5b,0x3a280142}},	// [2fce0] _idic, ntuy_, уозн, _cpcp_, 
   {{0xdb1c0158,0xbeb80ea0,0x3d1801ad,0x00000000}},	//   _riså, peër, _बाये_, --, 
   {{0xbdd9b584,0x98b0054e,0x7d1816a3,0xdb1c01e3}},	//   nvèn, _rază_, đust, _siså, 
   {{0x6028013f,0x97a400d4,0x00000000,0x00000000}},	//   _yɛmb, аріл, --, --, 
   {{0x6f0405b1,0x291801f7,0x98b00311,0x333c031c}},	//   _mdic, _tcra_, _pază_, ddux_, 
   {{0x2b41b585,0x660401f1,0xf4840b43,0x6d5c0007}},	//   ldic_, šiko, گاهی, njra, 
   {{0xd90db586,0x6f049f4e,0x635412e6,0x98b00356}},	//   _زین_, _odic, ивку, _vază_, 
   {{0x2b41b587,0x6f05b588,0xfafc02d3,0xb89000c6}},	//   ndic_, _ndic, _ulët_, _الفع, 
   {{0xa2941fe2,0x2b400072,0x229408e2,0x86080150}},	//   рапі, idic_, рипя, _سقاق_, 
   {{0x6f05b589,0x2ee00a2e,0xdb1c002d,0xe8e001fb}},	//   _adic, _afif_, _bisû, _đớn_, 
   {{0x257001ab,0x80d800bc,0xf954011a,0x00000000}},	//   _hàlo_, पुगे, אסית_, --, 
   {{0x9988494d,0x2b4001fa,0x83b41867,0x224001ef}},	//   ktaş_, jdic_, _صحائ, _šiku_, 
   {{0x64480122,0xffa02be5,0x6f04015d,0x64580393}},	//   _hrdi, илүү, _ddic, lxvi, 
   {{0x720000f1,0x00000000,0x00000000,0x00000000}},	//   _اووم, --, --, --, 
   {{0x3f88003a,0x00000000,0x00000000,0x00000000}},	//   ébus_, --, --, --, 
   {{0x6458003a,0x291c067c,0x6ecc00de,0xf4800023}},	//   ixvi, òvan_, _bēbī, _ክንህብ_, 
   {{0x3f89b58a,0x973403e6,0xd8f40114,0x9e3400db}},	// [2fcf0] micu_, یکرا, изањ, _тепч, 
   {{0x64491137,0x3a280051,0x6f04013a,0x81e400fe}},	//   _ordi, _vpcp_, _zdic, _বটা_, 
   {{0xdb1c02ea,0x64480010,0x6604374d,0x96f801f4}},	//   _misú, _nrdi, šikl, веет_, 
   {{0x3f89b58b,0x3be40323,0xdb1c0085,0x3d18007d}},	//   nicu_, _илүү_, _lisú, _बाडे_, 
   {{0x7bcc009a,0xfafc002e,0x8af8011a,0x321c00e8}},	//   _iicu, _flër_, _בהרי, xtuy_, 
   {{0x7bd5b58c,0x3f89b58d,0x154405a2,0x69b80073}},	//   _kuxu, hicu_, рекм, ्गणी, 
   {{0xf99c033b,0x7bcc0230,0x6448002e,0x3f88041a}},	//   _avèg_, _kicu, _crdi, kicu_, 
   {{0x3f8804b9,0x7bd5b58e,0x1228036b,0xbdd8007f}},	//   jicu_, _muxu, воий_, vvèn, 
   {{0x644805f5,0xdb1c0085,0x7bcdb58f,0x7bd5b590}},	//   _erdi, _bisú, _micu, _luxu, 
   {{0x7bcdb591,0x6f05b592,0x25701bce,0x2b400219}},	//   _licu, _sdic, _jàll_, zdic_, 
   {{0x3f8808e5,0x7bd40014,0x7bcc01e4,0x99980055}},	//   ficu_, _nuxu, _oicu, _assū_, 
   {{0x7bcdb593,0x3f8808e5,0xb04400db,0x00000000}},	//   _nicu, gicu_, _ۅكتۅ_, --, 
   {{0x71e42401,0xbeb80036,0x6f040051,0xd2340395}},	//   _сцеж, sfën, _vdic, _ъндъ, 
   {{0x7bd40548,0xe1f07b16,0x427802e4,0x63a42e31}},	//   _buxu, _رسه_, _באנג, čine, 
   {{0x7bcc9bbf,0x0ba866a3,0x00000000,0x00000000}},	//   _bicu, نارى_, --, --, 
   {{0x8a040351,0x6f05b594,0x7bcdb595,0x79840230}},	//   избе, _udic, _cicu, _amjw, 
   {{0x7bcdb596,0xd0040ed1,0xa03401d9,0x7c88001f}},	// [2fd00] _dicu, _соққ, _نى۪ت, _አድርግ_, 
   {{0x13dc03d4,0x998803e0,0x2bb811d7,0xf3e800fe}},	//   ণীয়, rtaş_, _आठवा, _টিনৰ_, 
   {{0x7bcdb597,0x3d180c2e,0x257150c8,0x6458f39f}},	//   _ficu, _बाते_, _dàll_, xxvi, 
   {{0x7bcc2da1,0xcb694a66,0x66041155,0x2b9400f2}},	//   _gicu, _раме_, šikm, _ایرس, 
   {{0x28b83b29,0x64480030,0x999800d0,0xdb0c010b}},	//   _अरवि, _srdi, _srsť_, nmaý, 
   {{0x3f8805ce,0x200c022c,0x6448a9e9,0x7bcc9b06}},	//   zicu_, yrdi_, _prdi, _zicu, 
   {{0x7bcc0526,0x7bd5b598,0x7d78011a,0x00000000}},	//   _yicu, _xuxu, כנסו, --, 
   {{0x200c08a4,0x7bcc02b9,0xb66c0241,0x82a400cf}},	//   vrdi_, _xicu, _kẹ́y, ишпе, 
   {{0x250801ed,0x260000e1,0x98b00064,0x068401d5}},	//   _مرضی_, _रिटी_, _vazą_, _тган, 
   {{0x6448151c,0x200c09a8,0x25700de2,0x229401b9}},	//   _trdi, trdi_, _xàll_, _қиля, 
   {{0x3f89b599,0x64497520,0xb66c0241,0x200c0129}},	//   ticu_, _urdi, _lẹ́y, urdi_, 
   {{0x200c0165,0xe8e00208,0xb80800eb,0x00000000}},	//   rrdi_, _đờn_, _রহমত_, --, 
   {{0xb281b59a,0x7bcc0c95,0x7bd401d9,0xd1bc001f}},	//   _мышк, _ricu, _suxu, ተሮች_, 
   {{0x7bcdb59b,0x3f89b59c,0xd6d80034,0x80480818}},	//   _sicu, sicu_, _mała_, _ачиб_, 
   {{0x70511386,0xfba8d303,0x7bd40009,0x00000000}},	//   _ونها, втай_, _quxu, --, 
   {{0x7bd402c4,0xefc80139,0x3e68014b,0xab740108}},	//   _vuxu, _куык_, _ашон_, огсш, 
   {{0x7bd40d62,0x7bcdb59d,0x3f980477,0xd0480134}},	// [2fd10] _wuxu, _vicu, _ijqu_, ɑnɑm, 
   {{0x7bd53211,0x7bcdb59e,0x5c74f56c,0x9d14005b}},	//   _tuxu, _wicu, _глот, _удоч, 
   {{0x7bcdb59f,0x38c8010a,0x99880210,0x00000000}},	//   _ticu, туан_, tuał_, --, 
   {{0x6e44034c,0x7bcc003a,0x9b580276,0x25701574}},	//   _انیم, _uicu, _симт_, _wàll_, 
   {{0xd6d80034,0x81e40f22,0x257000e8,0x74f400c7}},	//   _cała_, _বয়স_, _tàll_, иҵар_, 
   {{0xd6d8012d,0x33c40208,0xf9600133,0xdb0c000d}},	//   _dała_, _hđxx_, _گۆڕێ, hmaü, 
   {{0xe894d64b,0x62840153,0xdb1c01e1,0xf8c000cd}},	//   _дарь, _žiop, _sisù, वेशय, 
   {{0xc5e4015b,0x1af400cc,0x00000000,0x00000000}},	//   _নিরপ, _ছাঁই_, --, --, 
   {{0xd18405f5,0x00000000,0x00000000,0x00000000}},	//   йлий, --, --, --, 
   {{0x51540276,0xbeb801c7,0x637c0332,0x00000000}},	//   стиу, rfël, _nénf, --, 
   {{0x10a5b5a0,0xbeb801c7,0xe45000ae,0x98a0002b}},	//   синн, sfël, _يضم_, ddhī_, 
   {{0xe3b00fba,0xa3640014,0x00000000,0x00000000}},	//   _قرن_, _وُلو, --, --, 
   {{0x238401d9,0x10082982,0x42d8010f,0x82d4011a}},	//   _بٔنِ, _विवश_, _עקסע, _הונג_, 
   {{0xfce00364,0xe1f0e647,0x8fd163af,0x925805d9}},	//   зоро, _آسن_, _нәмә, _لشڪر_, 
   {{0xbdd8033b,0xb66c0248,0x00000000,0x00000000}},	//   nvèj, _sẹ́y, --, --, 
   {{0x7f901d39,0x4ed400db,0x00000000,0x00000000}},	//   _најх, _уюкт, --, --, 
   {{0x2fc0062c,0x8d740345,0x09040408,0x9f5800e4}},	// [2fd20] _ihig_, _هادا, йпан, ũrã_, 
   {{0x291db5a1,0xfbe40154,0xb7cc00d1,0x00000000}},	//   üva_, _ফিরত, _ﺑﺎﺭﻏ, --, 
   {{0x387c03f9,0x46e84f2f,0x06e8010b,0x8ba4009d}},	//   _ƙura_, гден_, гмек_, _гинж, 
   {{0x26b400d1,0x00000000,0x00000000,0x00000000}},	//   قەزز, --, --, --, 
   {{0x637db5a2,0x24f944dc,0xdb1d82bd,0x2d980113}},	//   _héng, анлы_, _risø, onre_, 
   {{0x637db5a3,0x2fc01368,0x81e400cc,0x00000000}},	//   _kéng, _lhig_, _বটল_, --, 
   {{0x637db5a4,0x2480010f,0x78f80a7c,0x98b00064}},	//   _jéng, ĝimo_, _תפלו, _oazę_, 
   {{0x637db5a5,0xf40c00c6,0x60c401e4,0x7aa400e1}},	//   _méng, رؤى_, _ŝimo, _कुँअ, 
   {{0x637c0438,0x05640276,0xd36c00d1,0xc91800cc}},	//   _léng, _лван, خۇن_, ড়ীত_, 
   {{0xc05856a4,0xb978010f,0xf8ac00e5,0x00000000}},	//   гім_, ָנטי, _آکے_, --, 
   {{0x2fc03e7c,0x98b07502,0x637d9ff6,0xdbf000bc}},	//   _bhig_, _bazę_, _néng, _přín, 
   {{0x443c2d65,0x83c46eec,0x2fc1b5a6,0xbee00764}},	//   _ist_, _убеж, _chig_, कुंभ_, 
   {{0x2fc1b5a7,0xb5a800e8,0x82b5b5a8,0xbe89b5a9}},	//   _dhig_, _m斡nu, _احاط, усне_, 
   {{0xfbd0a482,0x637da7c2,0xe8e00051,0x00000000}},	//   كتر_, _béng, _đởn_, --, 
   {{0x443db5aa,0x637da7c2,0x6280002f,0x98b0bfb6}},	//   _jst_, _céng, lzmo, _fazę_, 
   {{0x637db5ab,0xbdd800f2,0x3d18000d,0x00000000}},	//   _déng, nvèk, _बावे_, --, 
   {{0x62800007,0x443db5ac,0xab843c18,0xaa5876cd}},	// [2fd30] nzmo, _lst_, чурк, биту_, 
   {{0x443c6040,0x637d3dfd,0x00000000,0x00000000}},	//   _ost_, _hénd, --, --, 
   {{0x6028013f,0xdb0c00c6,0x637d9ff6,0x32cc03ee}},	//   _mɛmo, llaí, _géng, _köyü_, 
   {{0xdb0c0597,0x637c0264,0x00000000,0x00000000}},	//   olaí, _jénd, --, --, 
   {{0x637db5ad,0x7afda70a,0x62800427,0x5bb40073}},	//   _ménd, maqt, jzmo, ंतीव, 
   {{0x7afdb5ae,0x637c0de2,0xd4680262,0x443c23bd}},	//   laqt, _yéng, ииле_, _bst_, 
   {{0xdcf400da,0xd7c804d3,0x62800165,0xb76401e0}},	//   lizē, _نوسه_, ezmo, _лтай, 
   {{0x7afc3209,0x637c0098,0x11e51a8f,0x00000000}},	//   naqt, _nénd, ожим, --, 
   {{0x443db5af,0xdcf400da,0x1ca80135,0x39400728}},	//   _est_, nizē, _བཙའ_, _kajs_, 
   {{0x7afc9e39,0x2fc001b9,0xdb0c01e7,0x4cb800cc}},	//   haqt, _shig_, dlaí, _আলসু, 
   {{0x25a00491,0x2904013b,0x39406101,0x7afc03f0}},	//   éile_, _ɛma_, _majs_, kaqt, 
   {{0xe4680372,0x637ca507,0xd6d80034,0x5274084c}},	//   _ушул_, _cénd, _mało_, _мулу, 
   {{0x0eb9b5b0,0x637db5b1,0x7afc0548,0xdb0c007b}},	//   руны_, _séng, daqt, glaí, 
   {{0x637db5b2,0x2fc00158,0x67f00241,0x394001e3}},	//   _péng, _whig_, _jòjò, _najs_, 
   {{0x3d184425,0x2fc05da8,0xbd8403e6,0xdb0c00ae}},	//   _बारे_, _thig_, ڵچین_, alaí, 
   {{0x7afdb5b3,0x2fc00270,0x637c065c,0xe8e0004d}},	//   gaqt, _uhig_, _génd, _đốn_, 
   {{0xc3300bd4,0xc9640251,0xdb0c00c6,0x3165b5b4}},	// [2fd40] וון_, овай, claí, _konz_, 
   {{0x61e40597,0x48740eff,0x637db5b5,0xe3b8013d}},	//   _éile, يداس, _téng, _aqıl_, 
   {{0x2e24014a,0xa4140349,0x19b80212,0x00000000}},	//   löf_, _ান্য_, суть_, --, 
   {{0x394002fa,0xe51c3027,0xddcc0432,0xd6d8033f}},	//   _eajs_, _नाहि_, _araň, _dało_, 
   {{0x2e240793,0xddcc1f98,0xdcf400e2,0x00000000}},	//   nöf_, _braň, cizē, --, 
   {{0x4e1000bc,0xdb0c0d12,0x00000000,0x00000000}},	//   _तिनै_, lmað, --, --, 
   {{0x4759337d,0x68fc0a85,0x443db5b6,0x637c00e8}},	//   _края_, _ierd, _qst_, _léne, 
   {{0x443c579b,0x68fdb5b7,0x1ca80003,0x6e2407d6}},	//   _vst_, _herd, _བཙལ_, _oqib, 
   {{0x68fdb5b8,0x2e240008,0x3164037e,0x62340262}},	//   _kerd, jöf_, _bonz_, чепу, 
   {{0x443db5b9,0x3165b5ba,0x2e240793,0x68fc0363}},	//   _tst_, _conz_, döf_, _jerd, 
   {{0x68fc03bd,0x7afc1364,0x443db5bb,0xdb0c0008}},	//   _merd, yaqt, _ust_, kmað, 
   {{0x637c00e8,0x6569b5bc,0x68fdb5bd,0x7afc0548}},	//   _béne, _hodh, _lerd, xaqt, 
   {{0x6569b5be,0x68fd6f6b,0x637c0615,0x46c8012c}},	//   _kodh, _oerd, _vénd, िधिह, 
   {{0x6569b5bf,0x637db5c0,0x68fdb5c1,0x31640007}},	//   _jodh, _déne, _nerd, _gonz_, 
   {{0x6569b5c2,0x7afdb5c3,0xfafc0036,0x3940821e}},	//   _modh, taqt, _doën_, _rajs_, 
   {{0x6569b5c4,0xdb0c2880,0xdcf4005f,0x929c033f}},	//   _lodh, gmað, tizē, egły, 
   {{0x68fdb5c5,0x7afdb5c6,0x637db5c7,0x6e2401e2}},	// [2fd50] _berd, raqt, _géne, _gqib, 
   {{0x68fdb5c8,0xdcf400da,0xf848084c,0xfafc0221}},	//   _cerd, rizē, ичей_, _goën_, 
   {{0xdb0c0077,0x7afc02d1,0xf80402d5,0x929c012d}},	//   smañ, paqt, ючан, małe, 
   {{0x68fc7890,0x7afc6018,0x65689a14,0x27f80042}},	//   _eerd, qaqt, _aodh, _dwrn_, 
   {{0x68fdb5c9,0x65681161,0x59f42eab,0x637c0f71}},	//   _ferd, _bodh, _བསྲེ_, _xéne, 
   {{0x68fdb5ca,0x656801ab,0x27f80142,0x929c033f}},	//   _gerd, _codh, _fwrn_, nałe, 
   {{0xb324003d,0xe4e4063b,0x6028013f,0x31641529}},	//   _རྡུང_, фічн, _bɛmm, _ronz_, 
   {{0xb4b9b5cb,0xc0e00150,0x00000000,0x00000000}},	//   _घरी_, _ﺍﺯﻭﺗ, --, --, 
   {{0x68fdb5cc,0x77780472,0x65680e89,0xe6640b7e}},	//   _yerd, _ilux, _fodh, _отфо, 
   {{0x6569b5cd,0x637c0036,0x59bc043e,0xe50800db}},	//   _godh, _réne, ्गिर, _ويقو_, 
   {{0x637c04d4,0x940404fb,0x929c033f,0xd4900208}},	//   _séne, _روشه, dałe, _kèm_, 
   {{0xfafc0a40,0x2e240793,0x0874008f,0x00000000}},	//   _soën_, töf_, פערט_, --, 
   {{0xe8b861b8,0x59bcdb71,0xb3440327,0x656800dc}},	//   _अर्च, ्गार, raħħ, _yodh, 
   {{0x77780227,0x637c1c69,0x2d8db5ce,0x41640023}},	//   _llux, _véne, òde_, _ዝፈልጦ, 
   {{0xc1e40d73,0xdbf0012c,0x777800f1,0x6028016b}},	//   _وکیل_, _přán, _olux, _yɛmm, 
   {{0x68fdb5cf,0x637db5d0,0xc0d401f3,0x00000000}},	//   _serd, _téne, ሪያል_, --, 
   {{0x2d840231,0xdb0c05a4,0xfaa04cc1,0x6e240139}},	// [2fd60] èmes_, rmað, еато, _uqib, 
   {{0xdb0c09cc,0xc4d40729,0x7778009a,0xdb1c0429}},	//   smað, _সজ্জ, _alux, _bisó, 
   {{0x6568c116,0x9e64fc20,0x07f8007b,0x00000000}},	//   _rodh, _فاین, صراع_, --, 
   {{0x68fdb5d1,0xfafdb5d2,0xdb1c0077,0xfbbc1944}},	//   _werd, _joël_, _disó, ्षणम, 
   {{0x6569b5d3,0x68fc5589,0x1ca80135,0xa528025c}},	//   _podh, _terd, _བཙོ_, _ལྡུག_, 
   {{0x77786d27,0x68fc0221,0x6569b5d4,0xabb400c7}},	//   _elux, _uerd, _qodh, _хаҭә, 
   {{0x7779b5d5,0xdb1c00e8,0x65680023,0x9988033f}},	//   _flux, _gisó, _vodh, brał_, 
   {{0x63a40f03,0xf741b429,0x65680810,0x929c012d}},	//   čino, _песо, _wodh, załe, 
   {{0x6569b5d6,0x060800cf,0x4abc00cd,0x00000000}},	//   _todh, _ынак_, ्धिव, --, 
   {{0x0444055f,0x637c003e,0xc0c80023,0x660400e4}},	//   _незн, _bénc, _በሺር_, áiku, 
   {{0x1ca80327,0x5ff40108,0xdb980116,0x00000000}},	//   _བཙེ_, ьзну, ﺘﻮﺭﻯ_, --, 
   {{0x929c068f,0x637c00e8,0x660402d1,0x4abc043e}},	//   wałe, _dénc, šiku, ्धाव, 
   {{0x929c033f,0x93a8007b,0x00000000,0x00000000}},	//   tałe, _بالف_, --, --, 
   {{0xf99c180f,0x3d1404fa,0x3b080334,0xf6800150}},	//   _avèn_, तलें_, _sdcq_, _ﯨﺮﮔﻪ_, 
   {{0x6c542f78,0x929c012d,0x3c44013a,0x00000000}},	//   нкру, rałe, dívá_, --, 
   {{0x929c033f,0x2d8400db,0x00000000,0x00000000}},	//   sałe, èmer_, --, --, 
   {{0xaa584c04,0x929c012d,0xd4900051,0xdb0c02d2}},	// [2fd70] питу_, pałe, _rèm_, glaá, 
   {{0x645c01e1,0x00000000,0x00000000,0x00000000}},	//   _àriw, --, --, --, 
   {{0xb4b87aa4,0xd6d01e87,0x00000000,0x00000000}},	//   _घरे_, چقا_, --, --, 
   {{0x56940a8f,0xd6d1b5d7,0xdb1c04d4,0x59bc00bc}},	//   мает, نقا_, _visó, ्गहर, 
   {{0xdcb15a86,0x15443452,0xbeb80142,0x00000000}},	//   _سىڭ_, делм, rfëw, --, 
   {{0xe5040372,0x00000000,0x00000000,0x00000000}},	//   ىبىي, --, --, --, 
   {{0xe504007b,0xe81401ad,0x57f40816,0x53a45e0c}},	//   ربوي, _डिया_, _іпат, макб, 
   {{0x637c8616,0xfbbc3ee1,0x00000000,0x00000000}},	//   _rénc, ्षिम, --, --, 
   {{0xa5f8023a,0x98380150,0x4220005b,0x929c012d}},	//   _нету_, _ءﯗﻧﺠ, вдыв, wałb, 
   {{0xfafc05e4,0x637c1bce,0x62240131,0x3d14033f}},	//   _leë_, _pénc, رىپل, तलों_, 
   {{0xa3b802e1,0x8fa5b5d8,0xfbbc1223,0x66040e04}},	//   _کالر_, дане, ्षाम, šikt, 
   {{0x637c0ba1,0x03680014,0xfafc0200,0x00000000}},	//   _vénc, _ؤلی_, _neë_, --, 
   {{0xfafc05e4,0x1ca8031c,0x8db40212,0x00000000}},	//   _voël_, _བཙུ_, дсві, --, 
   {{0xd1308384,0x246c0085,0x00000000,0x00000000}},	//   _شمع_, lɛma_, --, --, 
   {{0xb4b80cb4,0x2d840024,0x637cad72,0xfce0117e}},	//   _घरो_, ėme_, _héna, тосо, 
   {{0x637c020c,0xca740139,0x8fd000d1,0x6d20000d}},	//   _kéna, музы, _шәпә, _बावग_, 
   {{0x271400cc,0x00000000,0x00000000,0x00000000}},	// [2fd80] ণ্ডো_, --, --, --, 
   {{0x637db5d9,0xf9c40845,0x60c401e4,0xecf400db}},	//   _ména, дгук_, _ŝimi, _سۋرد, 
   {{0xcb687b17,0x98b00139,0x3f8800e8,0x8724003b}},	//   _дане_, _bozı_, ëbug_, дмеж, 
   {{0x7ae0013f,0x08f400fe,0x00000000,0x00000000}},	//   ɛnto, _চাওঁ_, --, --, 
   {{0x9f6401d3,0xdb0c0022,0x00000000,0x00000000}},	//   áték_, _ãhár, --, --, 
   {{0xbda00092,0x9988012d,0x26c0008f,0x63a400d7}},	//   _ወቅትም_, grań_, ĥio_, činm, 
   {{0x9f580036,0x00000000,0x00000000,0x00000000}},	//   èrë_, --, --, --, 
   {{0x637c06af,0xd5e800db,0x00000000,0x00000000}},	//   _béna, زعۇن_, --, --, 
   {{0x637c00d5,0xd5e81e24,0xbdd8033b,0x9988012d}},	//   _céna, _فعلن_, nvèt, brań_, 
   {{0x637db5da,0x929c012d,0x19c801ec,0x850457fb}},	//   _déna, wałc, _ﺒﺎﻟﺠ, _آوان, 
   {{0x45a01e87,0x246c0134,0x645c0024,0xf990011a}},	//   _كەچك, bɛma_, _šrif, כרז_, 
   {{0xf99c0100,0x9de80327,0x22a40107,0x00000000}},	//   _avèl_, _འཕྱེ, _пулҳ, --, 
   {{0xdb0c0372,0x25701bce,0x623400a8,0x637c0129}},	//   llaç, _wàlu_, _челу, _géna, 
   {{0xfafc0af9,0xdd940124,0xb2b800d9,0x00000000}},	//   _seë_, хагы, _ומדר, --, 
   {{0x5f94798c,0x637c06d9,0xfafc00c7,0x9f3401ec}},	//   _пикт, _zéna, _peë_, _зейі, 
   {{0x929c012d,0x00000000,0x00000000,0x00000000}},	//   lała, --, --, --, 
   {{0x9de80003,0xeab1b4a1,0xc0d400b7,0x05dc09ab}},	// [2fd90] _འཕྲེ, لعك_, ሪያም_, _फूलब, 
   {{0xfafc05e4,0x9aa40075,0x929c012d,0x3ce403e0}},	//   _weë_, _җумһ, nała, _ünv_, 
   {{0x63a404b9,0xfafc0ea0,0xdd90179e,0x9cb4007b}},	//   činj, _teë_, _لوک_, _سمحت, 
   {{0x8c1804ac,0xcc74011a,0xeab000e5,0x00000000}},	//   _צורי, _נערה_, اٹے_, --, 
   {{0x929c012d,0x70b800bc,0x00000000,0x00000000}},	//   kała, _उर्ल, --, --, 
   {{0xdb0c06ed,0xe6101ec7,0x637c9d74,0xbdd8033b}},	//   flaç, ششه_, _réna, lvès, 
   {{0x637db5db,0xe824023b,0x929c033f,0x91c40051}},	//   _séna, _ифто, dała, _đùa_, 
   {{0x1309b5dc,0x637c4afb,0x2cbc0217,0xbdd802bd}},	//   чний_, _péna, _øvde_, nvès, 
   {{0x561400b2,0x00000000,0x00000000,0x00000000}},	//   _سواء, --, --, --, 
   {{0xdb0db5dd,0x929c0210,0x00000000,0x00000000}},	//   llaä, gała, --, --, 
   {{0x80d003d4,0x3ea4016b,0x00000000,0x00000000}},	//   _দ্ব্, _ɛnte_, --, --, 
   {{0x92bc00bd,0x8e840022,0xb6d000b5,0x637c0129}},	//   _আলী_, егме, _macﾌ_, _téna, 
   {{0xf99c180f,0x637c0036,0x5e2c0327,0x718001ec}},	//   _avèm_, _kénn, _ཧཱཾཿ_, _ақпе, 
   {{0x8c45b5de,0x637c003e,0xc5f0011a,0x412400d8}},	//   неге, _jénn, רדם_, _зошо_, 
   {{0x4b5416c3,0x00000000,0x00000000,0x00000000}},	//   нъат, --, --, --, 
   {{0x637db5df,0x9f940022,0x7f14030c,0x28c80220}},	//   _lénn, _ашьш, _كيىز_, _ﺩﺍﺨﻠ, 
   {{0x6ea800dd,0x7d0806ea,0xbdd8007f,0xf1dc28fe}},	// [2fda0] _زندہ_, ámsú, uvèt, नदिन, 
   {{0xbdd80ba1,0x645c00c7,0xa2a00f4a,0x00000000}},	//   rvèt, _árig, खपत्, --, 
   {{0x1ca807e4,0xacb414fb,0x7fb405af,0x817400df}},	//   _བཙག_, _شەرب, _زهیر_, עגעס_, 
   {{0x929c033f,0x6d20000d,0xf1dc578b,0x4e78010f}},	//   zała, _बाँग_, नदान, ּאַצ, 
   {{0x637c00e8,0xbdd80ba1,0xfbbc93cb,0x291c180f}},	//   _bénn, lvèr, ्षरम, òvas_, 
   {{0x3ab001e0,0xb6c801d3,0x6b85b5e0,0x78a800e5}},	//   _сәст, سانے_, lhig, élvé, 
   {{0xbdd9b5e1,0x00000000,0x00000000,0x00000000}},	//   nvèr, --, --, --, 
   {{0x6b85b5e2,0x929c0034,0xb8540a7c,0xdce400cd}},	//   nhig, wała, _אשלג_, _mohā, 
   {{0xb6a00598,0xdb0c06ed,0x6d2001ad,0xdce400b8}},	//   _битл, slaç, _बांग_, _lohā, 
   {{0xdb0db5e3,0xdce400b0,0x637c0694,0x6b840254}},	//   plaç, _oohā, _génn, hhig, 
   {{0x387c0b45,0x26c428b5,0x24983f61,0xd12001ad}},	//   _ƙuri_, _hzmo_, _ärm_, _मारण_, 
   {{0x38980bd9,0x27fc0030,0x929c033f,0x00000000}},	//   ליינ, ávny_, sała, --, 
   {{0x1ca80489,0x6b85b5e4,0x637c0066,0xe18801ec}},	//   _བཙང_, dhig, _héno, _жөне_, 
   {{0x637c0098,0x6b8401ab,0x645c0129,0xa195b5e5}},	//   _kéno, ehig, _àris, _шалч, 
   {{0x645c2cd7,0x395c00f3,0x00000000,0x00000000}},	//   _árid, _đus_, --, --, 
   {{0x6b84a08b,0xeb49b5e6,0x26c400f3,0x637c4e01}},	//   ghig, нчук_, _ozmo_, _méno, 
   {{0x63a00332,0x00000000,0x00000000,0x00000000}},	// [2fdb0] inmn, --, --, --, 
   {{0x3d18033d,0x25a0007b,0x6b840009,0xbea400db}},	//   _बाटे_, éill_, ahig, _يۇھن_, 
   {{0x28f80408,0x6b84a8c6,0x00000000,0x00000000}},	//   хехь_, bhig, --, --, 
   {{0x6b85b5e7,0x00000000,0x00000000,0x00000000}},	//   chig, --, --, --, 
   {{0xb6040171,0xbbbc4195,0x00000000,0x00000000}},	//   _olšū, ्षीक, --, --, 
   {{0x7d05b5e8,0x637c0129,0x16b000bc,0x00000000}},	//   najs, _béno, _जडीब, --, 
   {{0x68f805c7,0x00000000,0x00000000,0x00000000}},	//   ñvde, --, --, --, 
   {{0x637c4aee,0x67d438ac,0x00000000,0x00000000}},	//   _déno, _босу, --, --, 
   {{0x0201b5e9,0xf3640cef,0x7d05b5ea,0x32081e54}},	//   азын, _үтен, kajs, écy_, 
   {{0x637c8616,0x79940117,0x7d050c91,0x63a00afe}},	//   _féno, nixw, jajs, anmn, 
   {{0xf99c11c1,0x7d040232,0x10a5b5eb,0x20540251}},	//   _avèk_, dajs, тинн, гтяр, 
   {{0x8fd01945,0x79940472,0x00000000,0x00000000}},	//   шәлә, hixw, --, --, 
   {{0x333c5725,0x7d040023,0x929c033f,0x00000000}},	//   meux_, fajs, mało, --, 
   {{0x333c0097,0xc0e1b5ec,0x752000ca,0x321c0429}},	//   leux_, _кошк, ngnz, muuy_, 
   {{0x5c143b80,0x1c38224f,0x6b85b5ed,0xf99c02e2}},	//   льту, нять_, thig, _evèk_, 
   {{0x333db5ee,0xbeb802d3,0x645c00d8,0x929c033f}},	//   neux_, rfër, _árie, nało, 
   {{0xbb412ebd,0x7d05b5ef,0x4a4416c3,0x48e56ddf}},	// [2fdc0] шетк, bajs, ънав, возв, 
   {{0x6b85b5f0,0x8c94063b,0x6f05b5f1,0x63a4013a}},	//   shig, _армі, _heic, čini, 
   {{0x92bc00bd,0x6f057ee2,0x321c102c,0x6ea80014}},	//   _আলো_, _keic, huuy_, _زنگہ_, 
   {{0x8a0437ed,0x2d99b5f2,0x637c20ef,0x333c07ea}},	//   _изме, lire_, _réno, jeux_, 
   {{0x6f05b5f3,0x637c44a1,0x2d99b5f4,0x333c0129}},	//   _meic, _séno, oire_, deux_, 
   {{0x6f05b5f5,0x2b4000c6,0x321c102c,0x637c0129}},	//   _leic, leic_, duuy_, _péno, 
   {{0x333c5eb5,0x69dc00f1,0xbdd800f2,0x00000000}},	//   feux_, _iire, kwèn, --, 
   {{0x6f05b5f6,0x333c07ea,0x2b41b5f7,0x69ddb5f8}},	//   _neic, geux_, neic_, _hire, 
   {{0x2d99b5f9,0x00000000,0x00000000,0x00000000}},	//   kire_, --, --, --, 
   {{0x69ddb5fa,0x2d99b5fb,0x637c2d59,0x00000000}},	//   _jire, jire_, _téno, --, 
   {{0x2d99b5fc,0x6f05b5fd,0xf9900302,0xbeb8002e}},	//   dire_, _beic, שרת_, ggën, 
   {{0x69ddb5fe,0x6449b5ff,0xf8b00375,0x321c011f}},	//   _lire, _isdi, ישת_, buuy_, 
   {{0x69dd8c7b,0x6f05b600,0x7d04151c,0xdb1c0109}},	//   _oire, _deic, tajs, _misô, 
   {{0x2d988875,0x69ddb601,0xdb1c00d2,0x2ee0010a}},	//   gire_, _nire, _lisô, _egif_, 
   {{0x6f05b602,0x442db603,0xc20c01d9,0x7d05b604}},	//   _feic, ntf_, _أڈ_, rajs, 
   {{0x2d99b605,0xc03c0092,0x9cc801ec,0x7d040205}},	//   aire_, ዲደረግ, дыға_, sajs, 
   {{0x69ddb606,0x00000000,0x00000000,0x00000000}},	// [2fdd0] _bire, --, --, --, 
   {{0x2d98fd1b,0x6449b607,0x69ddb608,0x6f040639}},	//   cire_, _osdi, _cire, _zeic, 
   {{0x333db609,0xd7640133,0xfca801f7,0x4cd800eb}},	//   yeux_, ێنڕی, _زادو_, বুবু, 
   {{0x4aac069f,0x69ddb60a,0x79940107,0xcc5405d0}},	//   _झुकव, _eire, sixw, _עברי_, 
   {{0x333c20ef,0x592448ef,0x637c0077,0x321c011f}},	//   veux_, _مکاف, _vénl, xuuy_, 
   {{0x637c0098,0xdb1c0798,0x929c033f,0x00000000}},	//   _dénm, _visõ, wało, --, 
   {{0x387c03f9,0x333db60b,0xf8b4012c,0x543428c4}},	//   _ƙuru_, teux_, _अडिय, ارتر, 
   {{0x69ddb60c,0xe9d000f1,0xe4740006,0x10a401d5}},	//   _zire, _هغۀ_, рушэ, ғимн, 
   {{0x2d99b60d,0x333db60e,0x6f04537a,0x69ddb60f}},	//   yire_, reux_, _reic, _yire, 
   {{0x6f05b610,0x333c5eb5,0x42c4b590,0x69dc0014}},	//   _seic, seux_, ыгын_, _xire, 
   {{0x2d99b611,0x6f04035b,0x442c039a,0x60c401e4}},	//   vire_, _peic, ctf_, _ŝimr, 
   {{0x2d985ba1,0xbeb80240,0x56b4008f,0x637c0241}},	//   wire_, rgën, ָפֿן_, _lénj, 
   {{0x6f05b612,0x877800c8,0x2d99b613,0x2b40005f}},	//   _veic, גארי, tire_, veic_, 
   {{0x6f05b614,0x637c00d5,0x2d98003a,0xa1940354}},	//   _weic, _nénj, uire_, _качч, 
   {{0x6f05b615,0x69ddb616,0xddcc033f,0x2b41b617}},	//   _teic, _rire, _brał, teic_, 
   {{0x69ddb618,0x6e8801e2,0x00000000,0x00000000}},	//   _sire, _لمبې_, --, --, 
   {{0x49c9b619,0x2d99b61a,0xbeb9b61b,0x2b41b61c}},	// [2fde0] елан_, pire_, ngël, reic_, 
   {{0x69ddb61d,0xba141870,0x2d980200,0x00000000}},	//   _qire, ايلا_, qire_, --, 
   {{0x69ddb61e,0xfaa012d7,0x2b4007de,0x00000000}},	//   _vire, _ғаро, peic_, --, 
   {{0x06840a52,0x38c807d6,0x69ddb61f,0xddcc033f}},	//   лген, رالی_, _wire, _grał, 
   {{0x4a75b620,0x69ddb621,0xd76404fb,0x29480124}},	//   _сынт, _tire, شنوی, _иҟан_, 
   {{0x75d02998,0x69ddb622,0x637c7c70,0x6475a733}},	//   مينا, _uire, _génj, иглу, 
   {{0xf98102b0,0xf99c0100,0x07a43576,0xd9b1b623}},	//   _угро, _avèw_, _бавн, _بەلد, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x442db624,0xbb3800c8,0xa5c40220,0x320401c4}},	//   stf_, געפי, _көке, лхэн_, 
   {{0xdfd00451,0x00000000,0x00000000,0x00000000}},	//   ڪيج_, --, --, --, 
   {{0x75d1b625,0x84597904,0x733401ec,0x00000000}},	//   _ايلا, _ярат_, _әзір_, --, 
   {{0xe81c09d9,0xbb1805bb,0x00000000,0x00000000}},	//   _पटना_, _alîn, --, --, 
   {{0x637c0a40,0xbb180356,0x00000000,0x00000000}},	//   _lénk, _blîn, --, --, 
   {{0x1ca8031c,0x63a402f0,0xdb0c0174,0xa0b826b1}},	//   _བཙད_, činu, llaø, _иглу_, 
   {{0xa00400db,0xddcc0210,0x00000000,0x00000000}},	//   _ئستۇ, _prał, --, --, 
   {{0x9e8403e6,0x162c0092,0xc60800eb,0xdd040205}},	//   _ناخۆ, ተባበሪ, _রমনা_, ıpın, 
   {{0xbda435e6,0x637c00f2,0x2ef400c7,0x00000000}},	// [2fdf0] _محدو, _pénj, _узыр, --, 
   {{0xfbe000c7,0x7d24084c,0x00000000,0x00000000}},	//   _гәаҭ, _сфие, --, --, 
   {{0x6624167e,0x38c44316,0x00000000,0x00000000}},	//   ەرىك, ущав, --, --, 
   {{0x637c0de2,0x55f44727,0xf99c02e2,0xacf401d5}},	//   _dénk, ачку, _swèd_, _پسیت, 
   {{0x9664010b,0x637c0098,0xfbd00050,0x79a400d8}},	//   ркле, _ténj, _پتھ_, _брве, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x64980801,0x5468ee17,0x9988008f,0x2db8010f}},	//   лтър_, тайм_, ntaŭ_, אלגן_, 
   {{0x1ca81efe,0x00000000,0x00000000,0x00000000}},	//   _བཙན_, --, --, --, 
   {{0xd185b626,0xfafc0af9,0x98a002b5,0x569401c6}},	//   илий, _hoës_, kehī_, _таат, 
   {{0x637c00d2,0x41b00fb4,0xbeb8a87b,0x00000000}},	//   _yénk, يمير, rgël, --, 
   {{0xd7a853c3,0x05dc27a6,0x74a40798,0x00000000}},	//   _कदाच, _फूटब, _сјае, --, 
   {{0x20198139,0xa3cc0ebb,0x00000000,0x00000000}},	//   ária_, _शीप_, --, --, 
   {{0x69c000e4,0xbb18054e,0xa2940006,0x59c44f3c}},	//   _êmeg, _plîn, _лаці, वतार, 
   {{0xe2c800d6,0xd1ec0023,0x00000000,0x00000000}},	//   _слід_, _ቀለታ_, --, --, 
   {{0x412400d6,0x8fd00131,0x8b95b627,0x162c001f}},	//   _тощо_, _мәмә, арач, ተባባሪ, 
   {{0xea000208,0x00000000,0x00000000,0x00000000}},	//   _quắt_, --, --, --, 
   {{0xa3c80574,0x090452db,0xfafc0165,0xa1340133}},	// [2fe00] ोगत_, ипан, _roët_, _خرۆش, 
   {{0x6a84a58e,0xbb280014,0x6e201bce,0x00000000}},	//   алға, _یتُے_, àmbu, --, 
   {{0x9ea40014,0x87080798,0x00000000,0x00000000}},	//   _نصیٖ, веев_, --, --, 
   {{0x6028013f,0xfbdc004d,0x00000000,0x00000000}},	//   _mɛmp, _giê_, --, --, 
   {{0xa0300020,0x26c8052f,0xddcc030a,0x637c04e6}},	//   _እያንዳ, уған_, _frań, _wénk, 
   {{0x61e400c6,0x4cd80eac,0xa2440116,0x00000000}},	//   _éili, _ব্যু, ەردۇ, --, 
   {{0xd90cd653,0xe4b80953,0x637c39b4,0xa5040116}},	//   _سین_, ылкі_, _héni, аяқл, 
   {{0xea0007ae,0xfafc0660,0x637c0129,0xc7a40107}},	//   _luật_, _hoër_, _kéni, _тибк, 
   {{0x637c0066,0x98b00024,0x11f4036b,0x00000000}},	//   _jéni, _bazė_, یتیگ, --, 
   {{0xa6c8bbfd,0xfafc0a40,0x637cc0ba,0x3a3405d0}},	//   _алға_, _joër_, _méni, סרים_, 
   {{0x637c7c6e,0x049402d5,0x3954011a,0x20980139}},	//   _léni, _траў, בשים_, укны_, 
   {{0x63a45946,0x443db628,0x1df9001e,0xf8b4011a}},	//   čins, _ipt_, лемы_, שפטי_, 
   {{0x98b000c0,0x637c00e5,0x00000000,0x00000000}},	//   _fazė_, _néni, --, --, 
   {{0x443c05b1,0x637c068c,0x929c033f,0x00000000}},	//   _kpt_, _sénh, załk, --, 
   {{0x443c0254,0xea000051,0x00000000,0x00000000}},	//   _jpt_, _duật_, --, --, 
   {{0x637db629,0x6d580bcd,0xb8643fe6,0x00000000}},	//   _béni, _óvan, یااو, --, 
   {{0x443c23ee,0x637c0005,0xdd9400ee,0x1dc400ee}},	// [2fe10] _lpt_, _céni, _гапы, _гөвн, 
   {{0x637c1060,0x6028016b,0x929c033f,0x443db62a}},	//   _déni, _yɛmp, wałk, _opt_, 
   {{0xa3c802c3,0xf84802e8,0xfbdc0051,0xf1b000df}},	//   ोगा_, ъчай_, _tiê_, קסע_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x443c4a1f,0x637d3f11,0x00000000,0x00000000}},	//   _apt_, _géni, --, --, 
   {{0x99840491,0x58d401ee,0x28f80108,0x00000000}},	//   _السو, _гогт, _верь_, --, 
   {{0x637cecbf,0xad380a1e,0x7764010a,0x929c0210}},	//   _zéni, ינגס_, _къаж, pałk, 
   {{0x443c33cb,0x7bcc037e,0x00000000,0x00000000}},	//   _dpt_, _jhcu, --, --, 
   {{0x645c09cc,0x637d0a26,0xf6500228,0x6ff0054e}},	//   _árin, _xéni, _بئز_, _măce, 
   {{0xaee41aa1,0x443db62b,0x76580113,0xd18427a8}},	//   _miṅw, _fpt_, _iruy, слой, 
   {{0x443c0998,0x00000000,0x00000000,0x00000000}},	//   _gpt_, --, --, --, 
   {{0x4fa400c7,0x765801f5,0x8fa46927,0x0838008f}},	//   симв, _kruy, саме, נערל, 
   {{0xd17400ee,0x443c0010,0xade8000d,0x00000000}},	//   _гыйы, _zpt_, _टूशन_, --, 
   {{0x7d14010a,0xea0001fb,0x443c0098,0x09f400cc}},	//   _cdxs, _quật_, _ypt_, _চিলং_, 
   {{0x637db62c,0x00000000,0x00000000,0x00000000}},	//   _séni, --, --, --, 
   {{0x637c61c3,0x7bcc00a3,0x3f881155,0x00000000}},	//   _péni, _chcu, chcu_, --, 
   {{0xd0040e46,0x321c0784,0x29c8010b,0xc9a800c0}},	// [2fe20] _тоққ, nruy_, иңми_, гвае_, 
   {{0x637ca09e,0x1fcc0154,0x2d9db62d,0xdb0c00ee}},	//   _véni, _রূপস, _öve_, mlaý, 
   {{0x76580986,0x6ff00276,0x321c003e,0x769c0150}},	//   _aruy, _făce, hruy_, _ﺃﺒﻭﺍ_, 
   {{0xcb68d888,0x443c0005,0x7659b62e,0x27e002f6}},	//   _саме_, _rpt_, _bruy, öin_, 
   {{0x443c2831,0xa4f800dd,0xddcc0171,0xdb0c0432}},	//   _spt_, لکار_, _draņ, nlaý, 
   {{0x443c3c36,0x76580393,0x6ff00356,0x9c84013a}},	//   _ppt_, _druy, _zăce, bičč, 
   {{0x29180268,0x76589267,0xddcc00ef,0x00000000}},	//   _idra_, _eruy, _fraņ, --, 
   {{0xdb0c00ee,0x99080050,0xc05802dd,0x443c0064}},	//   klaý, _متہِ_, ңін_, _vpt_, 
   {{0x7659b62f,0x2c58007f,0x0685b630,0xd3440133}},	//   _gruy, _lčd_, _уган, زیوه_, 
   {{0x20180a16,0xdb0c00a2,0x00000000,0x00000000}},	//   ário_, dlaý, --, --, 
   {{0xc3280597,0x443c194f,0x9989b631,0x765800b8}},	//   _مكان_, _upt_, ntaš_, _zruy, 
   {{0x321c002e,0x7e280816,0x9f5803b9,0x0584030d}},	//   bruy_, ліга_, _üzür_, _куçм, 
   {{0xa37c01e4,0x6ff0054e,0x99880010,0x645879e9}},	//   _luĵk, _răce, htaš_, lvvi, 
   {{0x291c00dd,0x9989b632,0x6d5804d4,0x6ff0054e}},	//   óval_, ktaš_, _óval, _săce, 
   {{0x9f34005e,0xfba805f5,0xdb0c00a2,0x00000000}},	//   _дейі, гтай_, alaý, --, 
   {{0x2919b633,0xec3400d6,0xab940212,0x24580208}},	//   _adra_, янсь, писі, _mĩm_, 
   {{0x99990862,0xd1f8001f,0xf1bc00d0,0x7ac4defb}},	// [2fe30] акат_, _ወጥቶ_, ššej_, ссве, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6ff00311,0xdb50009f,0x00000000,0x00000000}},	//   _tăce, _قَد_, --, --, 
   {{0x5fc8fc36,0xb0b40432,0x2f8801e1,0x57240e56}},	//   रतिल, _üýşe, _ṣúpó_, زىتك, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x637c04e6,0xf7700244,0x00000000,0x00000000}},	//   _ménu, _کاس_, --, --, 
   {{0x5fc82ce6,0xf8bd6b62,0x201800d7,0x00000000}},	//   रताल, _्रिय, áril_, --, 
   {{0x765801dc,0x7ae0016b,0x00000000,0x00000000}},	//   _truy, ɛntr, --, --, 
   {{0x6459b634,0x67d5b635,0x7659b636,0x29180286}},	//   avvi, _хоту, _uruy, _ydra_, 
   {{0x7c2400ca,0x10a40276,0x681c0356,0x00000000}},	//   kujr, жион, bădă, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2c5802e2,0x321c003e,0x00000000,0x00000000}},	//   _rčd_, pruy_, --, --, 
   {{0x2c580100,0x321c0309,0x00000000,0x00000000}},	//   _sčd_, qruy_, --, --, 
   {{0x637c4afb,0x99880309,0xe2c81541,0x00000000}},	//   _dénu, ytaš_, _اوهو_, --, 
   {{0x8b6466a3,0x7c25276f,0x29180055,0x00000000}},	//   يارم, gujr, _rdra_, --, 
   {{0xdb0c0209,0x291805b1,0x27f80472,0x207408ca}},	//   plaý, _sdra_, _rtrn_, _хушё, 
   {{0x29181730,0xe8a80184,0x637c84aa,0x89d8484d}},	// [2fe40] _pdra_, әбеҙ_, _génu, لورر_, 
   {{0x637c00e4,0x707c0b82,0x7e780036,0x2d8400de}},	//   _hént, _ይመስሉ_, äupe, īmes_, 
   {{0x46e80f43,0xdb1c007f,0xfa90010c,0x00000000}},	//   аден_, _oksè, _መዘክር_, --, 
   {{0x637c00d5,0x9989b637,0xdb0c00d8,0x00000000}},	//   _jént, rtaš_, voaç, --, 
   {{0x637c0438,0xf99c00f2,0x81c0009e,0x99880010}},	//   _mént, _iwèn_, ্দত_, staš_, 
   {{0xdb1c4ce1,0x637c0098,0x6b85b638,0x00000000}},	//   _aksè, _lént, lkig, --, 
   {{0xc4d0009e,0x99880784,0xbb280150,0x00000000}},	//   াশভঙ, qtaš_, _ﺤﻔﻅ_, --, 
   {{0x2fc001d4,0xc7640dd8,0x6b85b639,0x1c1c05f9}},	//   _nkig_, _باسى, nkig, _फिसल_, 
   {{0xb6a000d6,0xfbd00302,0x6b8401c4,0x6458003a}},	//   _житл, ותה_, ikig, svvi, 
   {{0x637c76cf,0xba98008d,0xc05802d5,0x27e4036e}},	//   _aént, יספי, аім_, _himn_, 
   {{0x6b842ad4,0x637c551a,0xf6b4025c,0xf48403e6}},	//   kkig, _bént, _བཙོང, _وامی, 
   {{0x637db63a,0x8265b63b,0x00000000,0x00000000}},	//   _cént, _وهان, --, --, 
   {{0xb7d80302,0x637c00e4,0x246c016b,0x63a10614}},	//   יקטי, _dént, rɛmu_, mimn, 
   {{0x63a1b63c,0x26c4011c,0x7c844132,0x6b840d47}},	//   limn, _mymo_, оубе, ekig, 
   {{0x27e400a3,0xac18004e,0x00000000,0x00000000}},	//   _oimn_, жосу_, --, --, 
   {{0x63a1b63d,0x6b842819,0x637db63e,0x3e9802d3}},	//   nimn, gkig, _gént, ጀመርታ_, 
   {{0xae0417de,0x69c002b5,0x26c40fac,0x05c82e04}},	// [2fe50] _قويى, _īmer, _nymo_, िताब, 
   {{0x27e401c3,0xaee40882,0xea00001e,0x6b8404ba}},	//   _aimn_, saṃj, _quạt_, akig, 
   {{0x63a1b63f,0x6281b640,0x00000000,0x00000000}},	//   kimn, hymo, --, --, 
   {{0x637c0077,0x6b8555a3,0x62800024,0x63a0ff94}},	//   _méns, ckig, kymo, jimn, 
   {{0x6ff00276,0x637db641,0x645c02f0,0x63a0f13a}},	//   _măca, _léns, _árij, dimn, 
   {{0x6281b642,0x6ff00311,0x26c400d7,0x744c0092}},	//   dymo, _lăca, _dymo_, _በርግጥ, 
   {{0xdb0ccff6,0xdb1c525e,0x26c40455,0x63a0022e}},	//   llañ, _aksé, _eymo_, fimn, 
   {{0x63a07ce9,0x27e40a43,0x67d46bce,0xbdd8007f}},	//   gimn, _gimn_, _жосу, rvèy, 
   {{0x637c0c6a,0xa5f806a7,0x6281070b,0xe2b401c6}},	//   _rént, _мету_, gymo, дсээ, 
   {{0x6b8401c0,0x637db643,0x63a0464c,0xb4640244}},	//   zkig, _béns, aimn, _وداه, 
   {{0x637c00dd,0x63a001a9,0x9358009b,0x00000000}},	//   _pént, bimn, _грлу_, --, 
   {{0x637c0c6a,0xa3c800dc,0x6ff00356,0x998800a2}},	//   _déns, ोगः_, _căca, lsań_, 
   {{0x637c0098,0xcdf40eed,0x62800332,0xa3b8446a}},	//   _vént, ячны, cymo, _بالر_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x637c1709,0x316402b5,0x3ea4016b,0x9c58cd64}},	//   _tént, _innz_, _ɛnti_, ошту_, 
   {{0xddcc012d,0x20180356,0x00000000,0x00000000}},	//   _kraś, ârie_, --, --, 
   {{0x6b85b644,0xdb0c030a,0x47d000c7,0x00000000}},	// [2fe60] rkig, glañ, ҵәаӡ, --, 
   {{0x6b85b645,0x63a1b646,0x224000c5,0x7e98011a}},	//   skig, zimn, _äike_, _לספו, 
   {{0x7d780375,0x6281b647,0x63a01617,0x4cd800eb}},	//   _הניו, zymo, yimn, _ব্রু, 
   {{0xdb0c0dd4,0x99880165,0x09e463d7,0xbeb80200}},	//   blañ, esań_, _номн, rgëv, 
   {{0xf8ac00aa,0xdb0c022c,0xb6e006a6,0xe18002d3}},	//   نکې_, mlað, нюшк, _ይገብሩ_, 
   {{0xdb0c2242,0x6281b648,0xd9f00456,0x20180419}},	//   llað, vymo, _अंतत_, árik_, 
   {{0x46e40184,0x9f580023,0xf99c0100,0x7464005b}},	//   _еңеү_, ërë_, _mwèl_, зрыв_, 
   {{0x201805be,0x26c40064,0x628007f7,0xa3cc012d}},	//   šrik_, _tymo_, tymo, _शीश_, 
   {{0xbeb8044e,0x63a1b649,0x637db64a,0x2258023a}},	//   ngët, rimn, _séns, ципы_, 
   {{0x3080044e,0xb600038e,0xc0c802d3,0x637c056a}},	//   _ዝመጽእ_, ášen, _በጺሑ_, _péns, 
   {{0x6569b64b,0x6ff00276,0x62807999,0x34f80375}},	//   _indh, _păca, symo, _ההבד, 
   {{0xfafc02d3,0x637c0077,0x63a0014f,0x929c012d}},	//   _anën_, _véns, qimn, tałt, 
   {{0xdb0c032e,0x00000000,0x00000000,0x00000000}},	//   dlað, --, --, --, 
   {{0x637c003e,0x30f401d9,0x6e2001d3,0x00000000}},	//   _téns, _ٹوٹھ_, ámba, --, 
   {{0x3154011a,0xdb0c08ce,0x61500092,0x00000000}},	//   _זיון_, flað, ንጮቻች, --, 
   {{0xfafc0200,0xdb0c0aab,0x00000000,0x00000000}},	//   _enën_, glað, --, --, 
   {{0xaab40046,0x656800f2,0x79a40798,0x2b4430ab}},	// [2fe70] ейті, _ondh, прже, ээрг, 
   {{0xdb0d123f,0x9f5800e4,0x00000000,0x00000000}},	//   rlañ, ĩrõ_, --, --, 
   {{0xdb0c05a4,0xa3cc0490,0xfdf001ad,0x00000000}},	//   blað, ळता_, _इंडस_, --, 
   {{0x6569b64c,0x6fe4020c,0x69c000e4,0xa3cc1100}},	//   _andh, lècè, _êmen, _शील_, 
   {{0xe618005e,0xa3c01ab2,0x2efc03b9,0x4bc001af}},	//   зді_, ंकन_, _əvf_, _рөрг, 
   {{0xf99c007f,0x65949d46,0x69d40d2e,0xdb0c00e4}},	//   _kwèm_, начу, _बीपी, joaú, 
   {{0x5fbc069f,0xa63402dd,0x00000000,0x00000000}},	//   ईवाल, _үнсі, --, --, 
   {{0x6569b64d,0x27fc01f1,0xddcc0882,0xbeb80023}},	//   _endh, ívne_, _praś, ngës, 
   {{0x777802d0,0xd54800f1,0x00000000,0x00000000}},	//   _ioux, _ولرو_, --, --, 
   {{0x66140790,0x81400145,0x77900345,0x00000000}},	//   şekü, نچىن, _تیڤا, --, 
   {{0xd2f821fa,0x2938010f,0x68f8030a,0xae20000d}},	//   _деец_, לאזן_, ñvdi, _बिहन_, 
   {{0xa37c01e4,0x77780129,0x00000000,0x00000000}},	//   _buĵu, _joux, --, --, 
   {{0xa3b88bf0,0xf99c0100,0x63bc00e5,0x00000000}},	//   _عامر_, _pwèl_, _írna, --, 
   {{0x8c45b64e,0x637c0c6a,0x77780129,0xd00800f3}},	//   меге, _hénp, _loux, _деке_, 
   {{0xdb0c0008,0x00000000,0x00000000,0x00000000}},	//   tlað, --, --, --, 
   {{0xbb40190b,0x9f5800c7,0x00000000,0x00000000}},	//   кеск, érô_, --, --, 
   {{0xc330025f,0xf99c0100,0x81c0015b,0x4aa80329}},	// [2fe80] כון_, _twèl_, ্দর_, цкан_, 
   {{0x2828206f,0xddcc00df,0xbeb8a814,0x0d200137}},	//   _ዲሞክራ, _kraŝ, rgët, _шүгү, 
   {{0x77780207,0x9e64035c,0x6fe8020c,0xbeb80036}},	//   _boux, _قاین, cècè, sgët, 
   {{0x46a4927f,0x6ff0054e,0x06c8011c,0x201800d7}},	//   маев, _lăco, огей_, árii_, 
   {{0x35f5b64f,0xd1d00092,0x00000000,0x00000000}},	//   ورود_, ረምት_, --, --, 
   {{0x6ff00356,0xa4d4cea6,0x993800c0,0x00000000}},	//   _răcn, нолі, _нясу_, --, 
   {{0x77780369,0xc7a48040,0xd6d80034,0xbeb8036e}},	//   _foux, _живк, _mały_, ngër, 
   {{0x7c3445e3,0x998800d7,0x00000000,0x00000000}},	//   _çarş, rtať_, --, --, 
   {{0x998801f1,0x637c003e,0x00000000,0x00000000}},	//   stať_, _dénp, --, --, 
   {{0x6568034c,0x44280005,0x601403b2,0x00000000}},	//   _undh, _ªb_, _nýmá, --, 
   {{0x2019b650,0x9f342080,0xe57800ef,0x00000000}},	//   éri_, нені, _niķi_, --, 
   {{0xddcc00df,0xdb20022c,0x201800c7,0xdb0c0432}},	//   _draŝ, _ítøk, ĩri_, llaö, 
   {{0x6d401b24,0x00000000,0x00000000,0x00000000}},	//   đman, --, --, --, 
   {{0x5f0039db,0xea0001dc,0xd6d8068f,0xf99c0100}},	//   ্লেখ_, _xuất_, _cały_, _pwèm_, 
   {{0xdecc01f3,0xe0d4010f,0x9fac013a,0x308000f1}},	//   _ቡራኬ_, _אײַ_, _měú_, _ټليف, 
   {{0x69d4bebc,0xeb48003b,0xf454011a,0x00000000}},	//   _बीबी, мчук_, וילר_, --, 
   {{0x1ab405f5,0x7778017a,0xbeb9b651,0xcd6c0023}},	// [2fe90] хбая, _roux, rgës, _ኣለዉና_, 
   {{0xdc54009b,0x00000000,0x00000000,0x00000000}},	//   _звоњ, --, --, --, 
   {{0xef200327,0x00000000,0x00000000,0x00000000}},	//   żżew_, --, --, --, 
   {{0xea000016,0xf89001f0,0x00000000,0x00000000}},	//   _suất_, нгҷӯ, --, --, 
   {{0xe3b8013d,0x00000000,0x00000000,0x00000000}},	//   _uqıy_, --, --, --, 
   {{0xea0001fb,0xf56801f4,0x00000000,0x00000000}},	//   _quất_, юшек_, --, --, 
   {{0x6ff00311,0xa9341b0a,0x00000000,0x00000000}},	//   _răco, _шерш, --, --, 
   {{0x3e840055,0x00000000,0x00000000,0x00000000}},	//   _kįtā_, --, --, --, 
   {{0x11e4084c,0xd2a8023a,0xea00004d,0x69d403ce}},	//   нжим, якие_, _tuất_, _बीडी, 
   {{0x3cf80034,0xddcc01e4,0x6ff00356,0x00000000}},	//   ्रों_, _praŝ, _făcl, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdef802d5,0xa0c400ec,0xa3c013e0,0x00000000}},	//   дыё_, ئيٽو, ंकण_, --, 
   {{0xb190506f,0xe2146c2e,0x8db402bf,0x1b1400fe}},	//   _илдә, _амчы, есві, িলাই_, 
   {{0xc6900bd9,0xddcc01e4,0xd1000150,0x333c031c}},	//   ראך_, _traŝ, _حۋدۋ, lfux_, 
   {{0x2055b652,0x1c3802f6,0xc0e1b060,0x80c40037}},	//   _атыр, мять_, _йошк, _रुपइ, 
   {{0xd6d80210,0x00000000,0x00000000,0x00000000}},	//   _wały_, --, --, --, 
   {{0x3ab1b653,0xa3c0069f,0x4fc000db,0xc96401f0}},	// [2fea0] гәрт, ंकत_, _لەگە, нвай, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d5c51a0,0xd1d00023,0xc7244130,0x8724011c}},	//   mdra, ረምታ_, едей, емеж, 
   {{0x6d5d0a2e,0xddcc0139,0x00000000,0x00000000}},	//   ldra, _kraş, --, --, 
   {{0xe53400d6,0xe81c07f7,0xf7e400f2,0xff14011a}},	//   вель, _पटका_, رآمی, תקנת_, 
   {{0x6d5db654,0xf51404a9,0xc88c0023,0xb6000419}},	//   ndra, ىتىش_, _መጸውዒ_, ášan, 
   {{0x6d5db655,0x2a600254,0x99740117,0x00000000}},	//   idra, lvib_, _руяш, --, 
   {{0xddcdb656,0xf99c0214,0x6d5cc5db,0x37e0b5f5}},	//   _oraş, _awèh_, hdra, _босг, 
   {{0x6d5db657,0xa2940006,0x66740345,0x00000000}},	//   kdra, тапі, _جگار, --, 
   {{0x3a3402e4,0x922001f9,0x00000000,0x00000000}},	//   ערים_, _मिरज_, --, --, 
   {{0xddcc6f30,0x6d5db658,0x5f9400a8,0xf99000d9}},	//   _araş, ddra, винт, ררת_, 
   {{0xddcc084c,0x671005d7,0x81c004c5,0x442c29ef}},	//   _braş, ारिक_, ্দই_, muf_, 
   {{0x6234084c,0x6d5c777e,0x00000000,0x00000000}},	//   _релу, fdra, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x67201e31,0x2b41b659,0x7b641fd4,0x69d40037}},	//   _odmj, ffic_, нтае, _बीधी, 
   {{0xa3c0534e,0xfbd00a81,0x6d5db65a,0x301002e8}},	//   ंकि_, اتس_, adra, _сдър, 
   {{0x442cc52d,0xe8400020,0xddcc054e,0x97340133}},	// [2feb0] huf_, _ነጋዴዎ, _graş, ێکرا, 
   {{0xdd90021a,0x442c8983,0x64483c6a,0xa9340220}},	//   _څوک_, kuf_, _opdi, леуш, 
   {{0xe9d800c6,0xa3c005d7,0x442c00b5,0xe9440006}},	//   ѕкє_, ंका_, juf_, ыхто, 
   {{0x442c0e14,0x27fc0030,0x8c1802e4,0x00000000}},	//   duf_, ívna_, _קורי, --, 
   {{0x442db65b,0x6449b65c,0x9aa401f7,0x4b780a7c}},	//   euf_, _apdi, _شمسو, _חארו, 
   {{0x201c0395,0x6d5801d3,0xa13c00ef,0x00000000}},	//   _ovvi_, _óvat, diķo, --, 
   {{0x442db65d,0xa3cc0073,0x00000000,0x00000000}},	//   guf_, ळतं_, --, --, 
   {{0x22a4fbdc,0x1cdc0327,0xd610010a,0x0454007b}},	//   kīkī_, ལྟར_, _гiаб, ئلية_, 
   {{0x201c031c,0xdce400de,0x333c031c,0x151400c0}},	//   _avvi_, _kohē, rfux_, _адзя, 
   {{0x442c022f,0xd1b815eb,0x6d5c02d0,0x00000000}},	//   buf_, بابا_, xdra, --, 
   {{0x6448003e,0x6d5ccc6e,0x442cddf6,0xdce400ef}},	//   _gpdi, vdra, cuf_, _mohē, 
   {{0x8fa5b65e,0x333c031c,0xae20000d,0x00000000}},	//   таме, qfux_, _बिआन_, --, 
   {{0x6d5cee60,0x0338009f,0x00000000,0x00000000}},	//   tdra, _آتمڪ_, --, --, 
   {{0x6d5db65f,0x7bdc0381,0x90c401af,0x00000000}},	//   udra, emqu, _ибле, --, 
   {{0x7f4c03ac,0x4f94030d,0x645c08a5,0x00000000}},	//   becq, _арпу, _árit, --, 
   {{0x6d5db660,0x0e640124,0xddcc56a3,0xe0d05cfc}},	//   sdra, _акин, _traş, _ازه_, 
   {{0x6d5c0d27,0x2ea801d9,0xdce40171,0x00000000}},	// [2fec0] pdra, _سپدی_, _bohē, --, 
   {{0x4c84016c,0x7bdc16b8,0x66000010,0x2a600254}},	//   _алов, amqu, _rtmk, rvib_, 
   {{0x38c81c05,0xd7f80046,0x2d740166,0x00000000}},	//   وامی_, еуі_, _eşeñ_, --, 
   {{0x98540220,0xbdd80268,0xc6a401d5,0x00000000}},	//   ытуш, ttèg, крли, --, 
   {{0x6935b661,0x442db662,0xa3c0033f,0xe6b401d5}},	//   _مکار, wuf_, ंकस_, دلشگ, 
   {{0xdb0c3a6d,0x442db663,0x644801a6,0x660001f5}},	//   nnaî, tuf_, _ppdi, _vtmk, 
   {{0xbdd80ba1,0x3490013e,0x00000000,0x00000000}},	//   stèg, иашр, --, --, 
   {{0x442db664,0xf481b665,0xc32d2374,0xf360008e}},	//   ruf_, рушн, زەت_, атьн, 
   {{0x442c509f,0xd25000dd,0x76340354,0xe21400c7}},	//   suf_, منٹ_, _илтĕ, ымпы, 
   {{0xdb0c020c,0xea000208,0x55c401af,0x00000000}},	//   rnaé, _quẹt_, _бауғ, --, 
   {{0x442c0a2e,0x15b8004e,0x00000000,0x00000000}},	//   quf_, _чыты_, --, --, 
   {{0x69d41d72,0x73e000c7,0x0edc033f,0x00000000}},	//   _बीसी, _кәыҵ, नइंड, --, 
   {{0xd1bc0020,0xdd9000c6,0x9f98020c,0x42500244}},	//   ደሮች_, موح_, néé_, _ئۆخر, 
   {{0x201801d3,0x00000000,0x00000000,0x00000000}},	//   áris_, --, --, --, 
   {{0xef20031c,0x00000000,0x00000000,0x00000000}},	//   żżaw_, --, --, --, 
   {{0x7bdc16b8,0x00000000,0x00000000,0x00000000}},	//   umqu, --, --, --, 
   {{0x7ac4209b,0x6a14006c,0x00000000,0x00000000}},	// [2fed0] тсве, لبلر, --, --, 
   {{0x5d54ba46,0x81c0009e,0xeaa000b8,0xf9905b7a}},	//   _скот, ্দক_, _saṃs_, جبر_, 
   {{0x7c6400d1,0x1c38013d,0x00000000,0x00000000}},	//   _شادل, _язны_, --, --, 
   {{0x56944945,0xff5c006a,0xb8e800e1,0x6d58066a}},	//   лает, ndî_, _लड_, _óvar, 
   {{0xd54848bc,0xa5f8005b,0xa63400d4,0x05946bcc}},	//   епле_, вечу_, инці, گانگ, 
   {{0xa56404a9,0x00000000,0x00000000,0x00000000}},	//   لدىن, --, --, --, 
   {{0x0595b666,0x89d801d9,0x64980395,0x00000000}},	//   دانگ, _سوٲر_, ктър_, --, 
   {{0xd2503260,0x00000000,0x00000000,0x00000000}},	//   منع_, --, --, --, 
   {{0xff5c011f,0x113801af,0x00000000,0x00000000}},	//   ddî_, няны_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe1f9b667,0x21740022,0x00000000,0x00000000}},	//   нгө_, руыр, --, --, 
   {{0xd2b8010a,0x00000000,0x00000000,0x00000000}},	//   _пулч_, --, --, --, 
   {{0xa3c03eaf,0xe2f802bf,0xa3cc0034,0xdde00724}},	//   ंकर_, _речі_, _शीट_, ätşi, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb200e78,0x6d90013d,0x8b240276,0x2d3c0023}},	//   äuße, _fäan, лдве, _ይዝከረ, 
   {{0x09bc3f55,0xca740276,0x6ff00356,0x9f98002e}},	//   ्त्य, лузы, _răch, yéé_, 
   {{0x69a400fb,0x00000000,0x00000000,0x00000000}},	// [2fee0] алаҡ, --, --, --, 
   {{0x7a440029,0x00000000,0x00000000,0x00000000}},	//   dītā, --, --, --, 
   {{0x6ea80014,0x6ff0054e,0xf9c401d3,0x2d980332}},	//   _سنگہ_, _băci, احقی, mhre_, 
   {{0x4b5406bb,0x6ff0054e,0xc7940022,0x00000000}},	//   _съот, _căci, ырзы, --, 
   {{0x80c809ab,0x81c800fe,0x00000000,0x00000000}},	//   _सुने, লগত_, --, --, 
   {{0x9f98004a,0x00000000,0x00000000,0x00000000}},	//   réé_, --, --, --, 
   {{0x69dc09f0,0x03c404a9,0xf99c007f,0xbdd8067c}},	//   _ihre, лсим, _pwèv_, ltèc, 
   {{0xbdd8180f,0x00000000,0x00000000,0x00000000}},	//   otèc, --, --, --, 
   {{0x69dc0649,0xd1c8001f,0x7a4400e2,0xaab407f7}},	//   _khre, _አለች_, cītā, ंपिक, 
   {{0x2d980419,0x00000000,0x00000000,0x00000000}},	//   jhre_, --, --, --, 
   {{0x1f7402e8,0x69dc015d,0x0324009b,0xb29001b9}},	//   алня, _mhre, _бден, لجیش, 
   {{0x443c0054,0xaab40073,0x9f3402dd,0x42540066}},	//   _iqt_, ंपाक, шемі, _منصر, 
   {{0x69ddb668,0xd6100354,0x00000000,0x00000000}},	//   _ohre, _гiеб, --, --, 
   {{0xf99c0d29,0xf23406a9,0x69dc0368,0x2d99b669}},	//   _jwèt_, _ערוץ_, _nhre, ghre_, 
   {{0xfbd1b66a,0x26140490,0xac95b66b,0x5f940212}},	//   متر_, नीती_, барш, _вийт, 
   {{0xd01001d3,0xea000051,0xc0c4022e,0x00000000}},	//   _بلٹ_, _quết_, _ишққ, --, 
   {{0x69dc1549,0x637c0098,0x7f5c0194,0x91c80c58}},	// [2fef0] _bhre, _bénz, _iaqq, ৰদৰ্, 
   {{0x7f5c0cc1,0x69ddb66c,0x443c0139,0x2d98015d}},	//   _haqq, _chre, _oqt_, chre_, 
   {{0x69dc14d0,0x7f5c011f,0x80c84a76,0xfca805d9}},	//   _dhre, _kaqq, _सुमे, _سادو_, 
   {{0xf99c0066,0x7a444424,0x69dc813e,0x7f5c0455}},	//   _awèt_, tītā, _ehre, _jaqq, 
   {{0x69dc379c,0xf99c007f,0x7f5db66d,0xdb0c007b}},	//   _fhre, _bwèt_, _maqq, nnaí, 
   {{0x69ddb66e,0x443c001e,0x99880034,0x7f5db66f}},	//   _ghre, _bqt_, ntaż_, _laqq, 
   {{0x7a4400da,0xf99c02bd,0xdb0c00c6,0x81c800fe}},	//   sītā, _dwèt_, hnaí, লগা_, 
   {{0x7f5db670,0x637c00dd,0x395005d5,0x443c06be}},	//   _naqq, _kény, lexs_, _dqt_, 
   {{0xf99c02e2,0xdb0c0086,0x2d980fac,0x80c80b26}},	//   _fwèt_, noañ, yhre_, _सुबे, 
   {{0x7f5c0af5,0xf1cc0034,0x395004cc,0xa5f8009b}},	//   _aaqq, _सीखन, nexs_, _сефу_, 
   {{0x7f5db671,0x637c00dd,0x344400d1,0x645c00e4}},	//   _baqq, _lény, _сүйи_, _árip, 
   {{0x800800dd,0xdb0c00e4,0x00000000,0x00000000}},	//   کریہ_, koañ, --, --, 
   {{0x2d980597,0x7f5db672,0x28ac0412,0x0eb89292}},	//   thre_, _daqq, _टेनि, туны_, 
   {{0x072c0075,0x765801c8,0x443c0175,0x00000000}},	//   ﯩﻤﯘ_, _msuy, _yqt_, --, 
   {{0x99880122,0x7f5c025c,0x4030147e,0xf99c02bd}},	//   mpaň_, _faqq, _дејс, _lwès_, 
   {{0x76580117,0x69ddb673,0x2d980076,0x646400a2}},	//   _osuy, _shre, shre_, _äriň, 
   {{0x637c066d,0x69ddb674,0x3950004e,0x3ed00220}},	// [2ff00] _pénz, _phre, fexs_, _وقىر, 
   {{0x7d14102c,0x7f5c4d5e,0x59d8000d,0x00000000}},	//   _gexs, _zaqq, _बीदर, --, 
   {{0x76581e8e,0x7f5db675,0x69dc0076,0x38c803c7}},	//   _asuy, _yaqq, _vhre, پالی_, 
   {{0x637c00dd,0x7f5c7477,0xe3b80205,0x00000000}},	//   _fény, _xaqq, _avın_, --, 
   {{0x69dced1a,0xf99c007f,0xca741de6,0x00000000}},	//   _thre, _pwèt_, _туны, --, 
   {{0x69dd4975,0x25d9b676,0x2c58007f,0xdb1c0108}},	//   _uhre, ымлы_, _kōd_, _eksä, 
   {{0x2918067c,0xbdd8020c,0x629c0115,0x929c0210}},	//   _iera_, ntèa, ĝrom, mały, 
   {{0x0684001b,0x00000000,0x00000000,0x00000000}},	//   _кгбн, --, --, --, 
   {{0x2918d940,0x7f5c0429,0x27f80076,0x2c580100}},	//   _kera_, _raqq, _hurn_, _lōd_, 
   {{0x7f5c32ff,0x2919b677,0x76d8013e,0x27f80254}},	//   _saqq, _jera_, _русӣ_, _kurn_, 
   {{0x2919b678,0x443c0227,0xf48468cf,0x414002d3}},	//   _mera_, _uqt_, _پالی, _ንኻልኦ, 
   {{0x2919b679,0x7f5db67a,0x27f8039a,0xc2e401b9}},	//   _lera_, _qaqq, _murn_, _кўли, 
   {{0x29189466,0x442c068c,0x7f5c7a06,0xc20c01d9}},	//   _oera_, lrf_, _vaqq, _کٔڈ_, 
   {{0x2919b67b,0xdb0db67c,0x637c003e,0x7f5db67d}},	//   _nera_, rnaí, _rény, _waqq, 
   {{0xb0540597,0x7f5db67e,0x637c114f,0xdb0c007b}},	//   _نشيط_, _taqq, _sény, snaí, 
   {{0x9f480093,0x29184ace,0x637c0066,0x24580208}},	//   _kiaí_, _aera_, _pény, _mũm_, 
   {{0x2919b67f,0x3eac0267,0x3b180309,0xdad80063}},	// [2ff10] _bera_, _ägt_, raqq_, умац_, 
   {{0xfafc0023,0x27f9b680,0xdb0c00e4,0x00000000}},	//   _anët_, _burn_, roañ, --, 
   {{0x2919b681,0x6ff000a8,0x27f96039,0x765804ba}},	//   _dera_, _făcu, _curn_, _ssuy, 
   {{0x637c00dd,0x29180a55,0xf99c02e2,0x96b81c56}},	//   _tény, _eera_, _pwès_, лулу_, 
   {{0x442db682,0x96649919,0x00000000,0x00000000}},	//   erf_, скле, --, --, 
   {{0x2919b683,0x27f805d5,0xfafc0240,0x25d800cf}},	//   _gera_, _furn_, _enët_, амчы_, 
   {{0x27f80327,0xa9c40372,0xfbdc01fb,0xf8d8024a}},	//   _gurn_, _بۅلۉ, _khê_, _भरिय, 
   {{0xf771b684,0x2919b685,0x765804ce,0xb4d4202e}},	//   _باس_, _zera_, _tsuy, _सरी_, 
   {{0x2919b686,0x7659b687,0x442c04e6,0xb73000f1}},	//   _yera_, _usuy, arf_, _هېڅک, 
   {{0x48dc0316,0x2919a78c,0xf8d80073,0x00000000}},	//   केको_, _xera_, _भराय, --, 
   {{0x4fe82c1d,0x94d400db,0x93140214,0x81c401c6}},	//   лмон_, _اياش, _هواش, сгэв_, 
   {{0x23840014,0x0874010f,0xfbdc0051,0x929c012d}},	//   _ؤلِ, צערט_, _nhê_, zały, 
   {{0xa13c00e2,0x398c0205,0xd05406be,0xdcec00dc}},	//   ziķi, _kısı_, _əcəb, _āhār, 
   {{0x6ff00356,0xd7c801f9,0x00000000,0x00000000}},	//   _săcu, िकडच, --, --, 
   {{0x8b95b688,0x6ff0054e,0x00000000,0x00000000}},	//   брач, _păcu, --, --, 
   {{0xfbdc001e,0x0b58008e,0x7e840240,0x929c033f}},	//   _chê_, ыргы_, ërpë, wały, 
   {{0x2919b689,0x2d84004a,0xfafc0240,0x27f86931}},	// [2ff20] _pera_, êmes_, _anës_, _surn_, 
   {{0xe3b80598,0x6e24014b,0x27f8020b,0x29180023}},	//   _avıl_, _ivib, _purn_, _qera_, 
   {{0x29180a32,0x6ff0054e,0x9f580200,0x00000000}},	//   _vera_, _tăcu, ërç_, --, 
   {{0x2919b68a,0xbdd9b68b,0xfbdc001e,0x27340145}},	//   _wera_, ntèn, _ghê_, زىتس, 
   {{0x2919b68c,0x6f05b68d,0x27f80204,0xf1c421f6}},	//   _tera_, _mfic, _wurn_, रकान, 
   {{0x27f80c3e,0x29180381,0x00000000,0x00000000}},	//   _turn_, _uera_, --, --, 
   {{0xbdd80066,0x645801f5,0x398c0205,0xd5a405af}},	//   ktèn, uwvi, _dısı_, تلوی, 
   {{0x6e25b68e,0xf741660a,0xbeb80023,0xd5ac0014}},	//   _ovib, _несо, rgëz, _یہن_, 
   {{0xdb0c0413,0x37e0009d,0x26b40345,0xf774011a}},	//   nnaá, _хотг, _بڕاز, _פעמי_, 
   {{0x6f05b68f,0x398c0139,0xd5740354,0x00000000}},	//   _afic, _gısı_, _мухь, --, 
   {{0x6e25b690,0xb9780a7c,0x00000000,0x00000000}},	//   _avib, אריז, --, --, 
   {{0x3cdc00e1,0x00000000,0x00000000,0x00000000}},	//   _गरबे_, --, --, --, 
   {{0x41e400d6,0x3ebc6320,0x6e240055,0x5ed00154}},	//   _ліка, çut_, _cvib, সেনে, 
   {{0xf99cbe6d,0x6e242bd1,0x4394030d,0x3ebc0135}},	//   _atèn_, _dvib, _каçс, ħut_, 
   {{0xfbdc0016,0xd1c80020,0xb4f8010f,0x00000000}},	//   _phê_, _አለቃ_, רפלי, --, 
   {{0x6ab4dc75,0xd9540092,0xfe25b691,0xb034011a}},	//   ंपूर, _የማዘጋ, _льон, _הנהג_, 
   {{0xceb43d09,0x00000000,0x00000000,0x00000000}},	// [2ff30] _дәр_, --, --, --, 
   {{0xf99c007f,0x00000000,0x00000000,0x00000000}},	//   _etèn_, --, --, --, 
   {{0x6e2405b8,0xfbdc01fb,0xb4d417ee,0xed9c0b82}},	//   _zvib, _thê_, _सरे_, _ግምባር_, 
   {{0xae440214,0x00000000,0x00000000,0x00000000}},	//   _بپیو, --, --, --, 
   {{0xb0cc05dc,0x00000000,0x00000000,0x00000000}},	//   _सुनग, --, --, --, 
   {{0xbb1800e4,0x2e3008a5,0x00000000,0x00000000}},	//   _moîm, _höfð_, --, --, 
   {{0x6ff00356,0x00000000,0x00000000,0x00000000}},	//   _lăcr, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x0cd4448b,0x515412c4,0xd17802bf,0x21f801c0}},	//   _धर्म, отну, асні_, йхээ_, 
   {{0xc1e400f1,0xd5b0009f,0xd02401f4,0x00000000}},	//   يکول_, _غفا_, омой, --, 
   {{0x6e25357f,0x798401ee,0x00000000,0x00000000}},	//   _svib, _mojw, --, --, 
   {{0x35ac0c2e,0x7bcc004b,0x79840455,0xcee9ade4}},	//   _झगड़, _nkcu, _lojw, идне_, 
   {{0xbdd9b692,0xa2d002ab,0x3ea10dc8,0xcdf42401}},	//   rtèn, _डुप्, дияг, ючны, 
   {{0xbdd80228,0xf99c07c5,0x7984014f,0x80c80404}},	//   stèn, _stèn_, _nojw, _सुवे, 
   {{0xbdd8020c,0x3cec01f9,0x69c0032e,0x00000000}},	//   ptèn, _आणणे_, _ímei, --, 
   {{0x94f8025c,0x6f05b693,0xfce0068e,0x6e2402d2}},	//   _ཕུའི_, _ufic, фосо, _tvib, 
   {{0x7984b171,0xbe1010e0,0x89a8f3a6,0xc4b40073}},	// [2ff40] _bojw, _قويع, акав_, _अख्ख, 
   {{0xba1452c8,0x9e640150,0x6f2401ed,0xdb0c1d0e}},	//   تيكا_, _ءاين, _بڑھن, rnaá, 
   {{0x79840477,0x02c400bc,0x00000000,0x00000000}},	//   _dojw, _लड्न, --, --, 
   {{0xcb681bc4,0x00000000,0x00000000,0x00000000}},	//   _таме_, --, --, --, 
   {{0xa4f8397a,0xd90c00e5,0x00000000,0x00000000}},	//   مکار_, ئیہ_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9f58145e,0x7d78011a,0x00000000,0x00000000}},	//   êrë_, ינסו, --, --, 
   {{0x248004b9,0x0508015b,0x00000000,0x00000000}},	//   ćim_, রণের_, --, --, 
   {{0xc17802bf,0xf99c5b42,0x9f540264,0xf2c001c0}},	//   аїн_, _otèl_, _éfék_, дсэн, 
   {{0xfcf40092,0x00000000,0x00000000,0x00000000}},	//   _ፈልጎ_, --, --, --, 
   {{0x43440b7e,0x5560030c,0x30a000f5,0x78f8011a}},	//   _межв, _سۇيك, дряв, יפיו, 
   {{0xdb0c1445,0x98b0012d,0x05a4012d,0x00000000}},	//   _åhør, _uczą_, कोरब, --, 
   {{0x35dc1533,0x80c80f4a,0xfcf404b2,0x00000000}},	//   _पीड़, _सुरे, _ፈልግ_, --, 
   {{0xdd94ba3e,0x7bcc007c,0xc0a800ec,0x00000000}},	//   чагы, _skcu, _پاتل_, --, 
   {{0xfba9201c,0x7984b171,0x5f946b63,0x25ac0334}},	//   атай_, _rojw, _никт, _mmdl_, 
   {{0x7984073c,0xbb1800e4,0xa3c00412,0xfcf40092}},	//   _sojw, _toîm, ंकट_, _ፈልጌ_, 
   {{0x5a35b694,0x3f980455,0x7984014f,0xc0d0001f}},	// [2ff50] янат, _ilqu_, _pojw, ረውም_, 
   {{0x35dc1533,0x798401ee,0x2dd80a81,0x2b9c00ae}},	//   _पीढ़, _qojw, _وُٹھ_, _ríce_, 
   {{0x2b9c01f1,0xdb1c0158,0xbdd84ceb,0xe70800f1}},	//   _síce_, _oksø, ntèm, ښتون_, 
   {{0xb8f0007d,0xdce400e4,0x61e8003e,0xf7700efe}},	//   _हँ_, _nohĩ, hmdl, باط_, 
   {{0xdb0c0798,0x4b7802e4,0x6c8403e6,0x7984047e}},	//   enaç, _הארו, _فلیم, _tojw, 
   {{0x2b9c02f8,0x659401df,0x00000000,0x00000000}},	//   _více_, мачу, --, --, 
   {{0xdb0c0120,0x3f980784,0xe824cbbe,0x80c90457}},	//   gnaç, _olqu_, _офто, _सुले, 
   {{0xdb0c0158,0x52840108,0x00000000,0x00000000}},	//   snaæ, згиб, --, --, 
   {{0xe8e80327,0x0ea80073,0x00000000,0x00000000}},	//   _འཛོག, _चेंड, --, --, 
   {{0x10a5b695,0x3f980113,0xa508009b,0x00000000}},	//   зион, _alqu_, _међа_, --, 
   {{0xbdd80129,0xa1880451,0x00000000,0x00000000}},	//   rtèl, تضيٰ_, --, --, 
   {{0x04880116,0x630401b9,0xbdd9aa4f,0xdb0c0254}},	//   _ушуқ_, _قومل, stèl, nnaä, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa15800f3,0x00000000,0x00000000,0x00000000}},	//   _мачу_, --, --, --, 
   {{0xe8e80f50,0x6ab5733a,0x9b4401d9,0x00000000}},	//   _འཛེག, ंप्र, ژنٲو, --, 
   {{0x60ddb696,0x00000000,0x00000000,0x00000000}},	//   ürme, --, --, --, 
   {{0x8d740133,0x00000000,0x00000000,0x00000000}},	// [2ff60] _فادا, --, --, --, 
   {{0x291c0588,0x38c804d3,0x48780816,0xc0d00092}},	//   úva_, ڕانی_, йсея_, ረግም_, 
   {{0x2c940e3f,0x6be400fb,0x00000000,0x00000000}},	//   _غیرآ, _ойоҡ, --, --, 
   {{0x46e8c45c,0x00000000,0x00000000,0x00000000}},	//   бден_, --, --, --, 
   {{0xb8f02e1e,0x28ac0f44,0x6b8403b2,0x00000000}},	//   _हु_, _टेरि, mjig, --, 
   {{0x2fc00640,0xddcc0153,0xa4d400d4,0x6b8400a4}},	//   _ljig_, _įkūn, молі, ljig, 
   {{0x83a8036b,0x7d00002d,0x6aa40419,0xd90c0244}},	//   йтиб_, _ûnse, lzif, _ئیم_, 
   {{0x6b85b697,0xdb0db698,0x202c001f,0x27fc00d0}},	//   njig, rnaç, _ተሰማር, ívnu_, 
   {{0x6b840009,0xb60002f0,0x00000000,0x00000000}},	//   ijig, áštn, --, --, 
   {{0x2fc0003e,0xc05800fa,0x55c402dd,0x3f540208}},	//   _ajig_, бім_, _жауғ, _ầu_, 
   {{0x9f35b699,0x20181497,0x00000000,0x00000000}},	//   мені, èri_, --, --, 
   {{0x2d8db69a,0x6aa4009a,0x00000000,0x00000000}},	//   öden_, kzif, --, --, 
   {{0xbdd94c55,0x4cd40154,0x00000000,0x00000000}},	//   stèm, _দলগু, --, --, 
   {{0x6aa466a0,0xbdd9b69b,0x3274010f,0x00000000}},	//   dzif, ptèm, _מײדל_, --, 
   {{0x28ac2a8e,0x80040166,0x00000000,0x00000000}},	//   _टेलि, _эчле, --, --, 
   {{0x6b8401d9,0x23cc3e8c,0xbf640345,0xdfd02dd0}},	//   gjig, ाविद, _ردبو, _جيب_, 
   {{0xe8e8038f,0xbdd9b69c,0x6d4800a3,0x00000000}},	// [2ff70] _འཛུག, ntèk, òdac, --, 
   {{0x78e80ce6,0xa92802d5,0x00000000,0x00000000}},	//   бьев_, зіце_, --, --, 
   {{0xc70802e3,0x23cc193d,0x998800f3,0xe7e801f9}},	//   _ịrịb, ावाद, graš_, _ओळखा_, 
   {{0x27e401ab,0xbdd80214,0xe7380212,0xa818007b}},	//   _chmn_, ktèk, зеї_, ستمر_, 
   {{0x3a7001e0,0x63a00332,0x660400d4,0x00000000}},	//   _яһар, dhmn, епіа, --, 
   {{0xe611b69d,0x67d40107,0xb9c4009d,0x00000000}},	//   اشن_, _ҷосу, _хёми, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x46f006ba,0x85700166,0x00000000,0x00000000}},	//   رۋەر, еләх, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x799401e2,0x92940022,0x00000000,0x00000000}},	//   nkxw, заҩц, --, --, 
   {{0x6aa4c7cc,0x2b9c00d7,0x10a40166,0x00000000}},	//   zzif, _líca_, финн, --, 
   {{0x26141533,0x68ec00ac,0x38600010,0x2cb006be}},	//   नीकी_, ündə, _msjr_, _ündə_, 
   {{0x752001c8,0xdcf4031c,0x6374022e,0x00000000}},	//   oanz, _ħaġr, mоnа, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7520009f,0x9f5c02bd,0x45200eac,0xeb800023}},	//   ianz, _ouvè_, _নামক_, _ሓሊፍና_, 
   {{0x31640ffb,0x09c4b702,0x98c40118,0xca440150}},	//   _hanz_, वव्य, štět_, _ﺄﻤﺭ_, 
   {{0x7521b69e,0x6aa40165,0x00000000,0x00000000}},	// [2ff80] kanz, uzif, --, --, 
   {{0x7521b69f,0x99880841,0x00000000,0x00000000}},	//   janz, traš_, --, --, 
   {{0x7521b6a0,0x3165b6a1,0x7f9c002e,0x7d780375}},	//   danz, _manz_, _wëqe, _וניו, 
   {{0x6d5db6a2,0x20180327,0x00000000,0x00000000}},	//   lera, ġrix_, --, --, 
   {{0x75214f99,0x9f5c026c,0xe18002d3,0x05e802e8}},	//   fanz, _duvè_, _ክገብሩ_, офки_, 
   {{0x75209390,0x31640097,0x2d9801ed,0xdd3006be}},	//   ganz, _nanz_, nkre_, _məşa, 
   {{0x6d5db6a3,0xe8e80327,0xb5c40133,0x00000000}},	//   iera, _འཛིག, بووم_, --, 
   {{0xca7c0201,0x16180c2e,0x2b41b6a4,0x7520009f}},	//   _የሉንም_, _नौकर_, ngic_, aanz, 
   {{0x7520d384,0xc6440137,0x151c0183,0x69c003b2}},	//   banz, _تئزى, _নাৰী_, _ímes, 
   {{0x752123a0,0x6600014b,0x2d8c260b,0xbdd80066}},	//   canz, _iumk, ödel_, rtèk, 
   {{0x80d400bd,0x3165b6a5,0x032418d9,0x6600009f}},	//   ডেন্, _danz_, _жден, _humk, 
   {{0x6601b6a6,0x6569b6a7,0xfafc01c7,0x67200076}},	//   _kumk, _hadh, _aaën_, _jemj, 
   {{0x6d5c21a3,0x6569b6a8,0x02e01db2,0x67200a2e}},	//   fera, _kadh, _परिभ, _memj, 
   {{0x3165b6a9,0x66000517,0x6d5db6aa,0x6568198f}},	//   _ganz_, _mumk, gera, _jadh, 
   {{0x6569b6ab,0x66004667,0xfbd055b8,0xbdd80005}},	//   _madh, _lumk, نتر_, ntèi, 
   {{0x9f480c67,0x75200451,0x6569b6ac,0x61f8014f}},	//   _biaå_, zanz, _ladh, _hivl, 
   {{0x752062f9,0x61f9b6ad,0xaca4010b,0xc038001f}},	// [2ff90] yanz, _kivl, _boỳu, _በተባለ, 
   {{0x6d5db6ae,0x6569b6af,0x61f80477,0x75215e14}},	//   cera, _nadh, _jivl, xanz, 
   {{0xb9044a04,0x7521b6b0,0x61f8014f,0xa3c0012c}},	//   _पर_, vanz, _mivl, ूका_, 
   {{0x7521b6b1,0x61f84bc1,0x6568198f,0xe63402d3}},	//   wanz, _livl, _aadh, _ኣይኮን, 
   {{0x7521b6b2,0x6569b6b3,0x4bc0b90b,0xe6180212}},	//   tanz, _badh, _сөрг, дді_, 
   {{0x3edc02e3,0x61f9b6b4,0x6569b6b5,0xd4695d25}},	//   _arịọ_, _nivl, _cadh, зике_, 
   {{0x6569b6b6,0x3165b6b7,0x24480086,0x672003b2}},	//   _dadh, _ranz_, gûm_, _femj, 
   {{0x75200537,0x6d5db6b8,0x316466dd,0x65685e3a}},	//   sanz, zera, _sanz_, _eadh, 
   {{0x6569b6b9,0x75200296,0x61f80477,0x316401c7}},	//   _fadh, panz, _bivl, _panz_, 
   {{0x6569b6ba,0x6d5db6bb,0xdd300213,0x67200171}},	//   _gadh, xera, _rəşa, _zemj, 
   {{0x3165b6bc,0x660004cc,0xd17400fd,0xddcc012d}},	//   _vanz_, _zumk, _җылы, _opał, 
   {{0x656992c3,0x660001f7,0x31640036,0x00000000}},	//   _zadh, _yumk, _wanz_, --, 
   {{0x61f80158,0x65687805,0x3165b6bd,0x764801d3}},	//   _fivl, _yadh, _tanz_, ntgy, 
   {{0x6d5db6be,0x409000aa,0x656801d9,0xbeb80393}},	//   uera, _څلور, _xadh, maël, 
   {{0x4fc004a9,0xc4d000c8,0x2d980158,0x2cac00e8}},	//   _مەدە, ָגן_, rkre_, àdd_, 
   {{0x61f80b3d,0xaca4010e,0x2d980254,0x00000000}},	//   _zivl, _soỳu, skre_, --, 
   {{0xfaa1b6bf,0x4aa9b6c0,0x2b41b6c1,0x61f86a37}},	// [2ffa0] гато, чкан_, rgic_, _yivl, 
   {{0x67200a37,0x7778005a,0xca64022e,0x6600590e}},	//   _semj, _anux, _dekа, _rumk, 
   {{0x6569b6c2,0x6601b6c3,0x00000000,0x00000000}},	//   _radh, _sumk, --, --, 
   {{0x6569b6c4,0xd6d8068f,0x6d900036,0x86c40b38}},	//   _sadh, _był_, _gäar, ىيان, 
   {{0x65680502,0x7778020c,0xb7d42f84,0x67200200}},	//   _padh, _dnux, روها_, _vemj, 
   {{0x656993d5,0x0465b6c5,0x2448003a,0x680c06be}},	//   _qadh, етим, tûm_, _ağde, 
   {{0x65680882,0x6448010a,0x6721b6c6,0x6601b6c7}},	//   _vadh, _qqdi, _temj, _wumk, 
   {{0x6569b6c8,0x7bc00998,0xf99c068c,0xff5c004a}},	//   _wadh, _ínut, _puèg_, noît_, 
   {{0x6569b6c9,0x320c0334,0x61f9b6ca,0x22a402b1}},	//   _tadh, _ctgy_, _pivl, kūkū_, 
   {{0xc0c9b6cb,0x65680332,0x00000000,0x00000000}},	//   зуме_, _uadh, --, --, 
   {{0x80c81a2a,0x61f80115,0x6448022e,0xbd6802dd}},	//   _सुखे, _vivl, _uqdi, үрге_, 
   {{0x61f8016d,0x6d48007f,0x3f64003b,0x00000000}},	//   _wivl, òdan, хтоб, --, 
   {{0x24940050,0x61f8047e,0x261401f9,0x73e0117e}},	//   _سۅکھ_, _tivl, नीची_, _соцз, 
   {{0x81dc015b,0xddcc0210,0x00000000,0x00000000}},	//   _দূর_, _spał, --, --, 
   {{0xe0d404ac,0x4adc0037,0x00000000,0x00000000}},	//   _בײַ_, _मरउव, --, --, 
   {{0x9f540276,0xdb0c0162,0xad08009d,0xdfd401ec}},	//   _рвич, nnaø, _үхэж_, _шойы, 
   {{0x998801f1,0x2fd80014,0xaa58009b,0x8e80030d}},	// [2ffb0] hrať_, _سوٝد_, ниту_, _кӳре, 
   {{0x80d402f5,0xbdd800e4,0xce8801d3,0x7c840395}},	//   ডেণ্, etèv, _آئٹم_, _зуме, 
   {{0xbb180231,0xa9c40212,0xcdf4011a,0x00000000}},	//   _boît, устк, _שמתי_, --, 
   {{0x569445c4,0xe785b6cc,0xddcc012d,0x1ab40006}},	//   кает, лучо, _upał, _абмя, 
   {{0x998800d0,0x19c40220,0xa2d028fe,0xaa940395}},	//   erať_, _ﯨﻘﭙﺎ, _डुल्, _бияч, 
   {{0x99680014,0x62f800eb,0x195400df,0x00000000}},	//   _غمزٕ_, ীরায়_, _בבֿל_, --, 
   {{0x7dd807a8,0xdb2001e1,0x53a4004e,0x00000000}},	//   rîsh, _ìtók, какб, --, 
   {{0x77d40597,0xd6d8033f,0x00000000,0x00000000}},	//   _أغسط, _tył_, --, --, 
   {{0xddcc00df,0x422000c9,0x11380153,0x270c0208}},	//   _araŭ, адыв, мяны_, _ớng_, 
   {{0x998801a2,0xbeb8282c,0x77900345,0x00000000}},	//   brať_, raël, _جیڤا, --, 
   {{0x8fa40c04,0x98b00790,0xaee40055,0xaad800cd}},	//   ване, _kazı_, _kuṇi, _भुनक, 
   {{0x4f94487f,0xe1f800cf,0x00000000,0x00000000}},	//   троу, мгө_, --, --, 
   {{0x59d13374,0x98b00205,0xe18800ec,0x00000000}},	//   तकार, _mazı_, _ڳئون_, --, 
   {{0xddcc008f,0x00000000,0x00000000,0x00000000}},	//   _fraŭ, --, --, --, 
   {{0xe188474d,0x41b00345,0x00000000,0x00000000}},	//   _سئون_, _خمور, --, --, 
   {{0x25e809d9,0x98b025a8,0xc9181fc4,0x80c801f9}},	//   _चीनी_, _nazı_, धर्म_, _सुटे, 
   {{0x0dc8b106,0xff5c06af,0x4fc002dd,0x7fb4009f}},	// [2ffc0] _олий_, roît_, _مەگە, _جهير_, 
   {{0x8d540276,0xc89400f0,0x00000000,0x00000000}},	//   _ртич, крењ, --, --, 
   {{0x98b00365,0x9f480790,0x00000000,0x00000000}},	//   _bazı_, ükçe_, --, --, 
   {{0x98b006be,0x00000000,0x00000000,0x00000000}},	//   _cazı_, --, --, --, 
   {{0xe535b6cd,0xbdd8026c,0xe578013e,0x580401e0}},	//   гель, rtèv, нҷа_, _ҡорғ, 
   {{0xddcc0356,0xdd100213,0x99880419,0x00000000}},	//   _iraţ, _müşf, trať_, --, 
   {{0xd90c3837,0x9974014b,0x00000000,0x00000000}},	//   _رین_, _суяш, --, --, 
   {{0x6928002e,0xe3b800fd,0xbdd8067c,0x98b0247e}},	//   _féeñ, _avır_, ltèt, _gazı_, 
   {{0xbdd8067c,0xc5640063,0xb2a401c6,0xdb0c0174}},	//   nuèc, _икак, втэж_, rnaø, 
   {{0xbdd8da98,0x84b40395,0x998800d7,0x60dc0254}},	//   ntèt, _ищец, prať_, ürmo, 
   {{0x98b007c4,0xff5c07dd,0x6d9000b0,0x5f9406d4}},	//   _yazı_, teî_, _räap, гинт, 
   {{0x92e000fe,0x00000000,0x00000000,0x00000000}},	//   _দলৰ_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbb1800c7,0xddcc00df,0x00000000,0x00000000}},	//   _noîr, _traŭ, --, --, 
   {{0xff340124,0xdfd400fd,0x07204707,0x80c81a47}},	//   _иҟны_, _йокы, मराव_, _सुचे, 
   {{0xd970001f,0xddcc0311,0x2ba40798,0x00000000}},	//   _ለማዘጋ, _braţ, ајув, --, 
   {{0x98b047af,0xdd94004e,0xaee40055,0x7dc4022e}},	// [2ffd0] _razı_, _бапы, _ruṇi, _аёнд, 
   {{0xdd902fc0,0x3f8801a6,0x394407c5,0x98b04dd9}},	//   _چوک_, ljcu_, üns_, _sazı_, 
   {{0xdd903345,0x6fc81432,0x98b00205,0x00000000}},	//   _نوک_, lıca, _pazı_, --, 
   {{0xddcc0276,0x59d0012c,0x98b003e3,0xd9e4000d}},	//   _fraţ, तकहर, _qazı_, _कठवत_, 
   {{0xddcc0311,0xe3c8009e,0x6fc80790,0x00000000}},	//   _graţ, শতাব, nıca, --, 
   {{0x5805b6ce,0x7bddb6cf,0x3f88026c,0xbf1c0490}},	//   _موسك, llqu, hjcu_, परुन_, 
   {{0x7f9c0240,0x00000000,0x00000000,0x00000000}},	//   _nëqo, --, --, --, 
   {{0x04540491,0x7a452cf5,0x6fc80790,0x00000000}},	//   الية_, pūtā, kıca, --, 
   {{0xbdd8ff24,0x44b000fd,0xc7b005d0,0x00000000}},	//   ntès, ибәс, _הבן_, --, 
   {{0x6468023a,0x7bdc00e4,0x00000000,0x00000000}},	//   äsiä, hlqu, --, --, 
   {{0xbf1c0490,0x80d400eb,0x00000000,0x00000000}},	//   परून_, ডেস্, --, --, 
   {{0x8c440032,0x707c0023,0x425001e2,0x00000000}},	//   һеге, _ንዘለዉ_, جنیر, --, 
   {{0xd175b6d0,0xdb0c032e,0x00000000,0x00000000}},	//   _быйы, fnaþ, --, --, 
   {{0x8c445a0b,0x50441c3e,0x765800ca,0x21a40046}},	//   леге, _бекб, _mpuy, _киім, 
   {{0x7bdc0175,0x89d402dd,0x499401d5,0x99880210}},	//   flqu, ңізш, қшат, braź_, 
   {{0x765803e0,0x20c400fb,0x00000000,0x00000000}},	//   _opuy, _әсәг, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [2ffe0] --, --, --, --, 
   {{0x8d64729a,0xddcc0227,0x680c00ac,0x4d642218}},	//   _свое, _apaņ, _ağda, _сков, 
   {{0x76581bb7,0xf99c0137,0xbdd80561,0x00000000}},	//   _apuy, _atès_, rtèt, --, 
   {{0x46a448ec,0x87d81f7a,0xddcce126,0xbdd8068c}},	//   лаев, رباس_, _iraš, stèt, 
   {{0x6935a6fe,0xddcc3858,0x00000000,0x00000000}},	//   _نکار, _hraš, --, --, 
   {{0xa4f9b6d1,0xbdd84325,0xddccdbf2,0xe3b80139}},	//   نکار_, ltèr, _kraš, _avıp_, 
   {{0x2b9c0208,0x6fc803e0,0x00000000,0x00000000}},	//   _níck_, zıca, --, --, 
   {{0xbdd8068c,0xc32c0131,0xdce400cd,0x75d01075}},	//   ntèr, سەت_, _jahā, _ۇيقا, 
   {{0xdce41161,0xbdd8067c,0x7f9c00e8,0xb4c80022}},	//   _mahā, itèr, _sëqo, hẽhá, 
   {{0xddcc05ce,0xdb0c01e3,0x00000000,0x00000000}},	//   _oraš, _åhör, --, --, 
   {{0xbdd800f2,0x84e40108,0x00000000,0x00000000}},	//   ktèr, _сожж, --, --, 
   {{0xc2e407d6,0x98a006c8,0xdb0c06ed,0xdfd43119}},	//   _йўли, nahā_, miaç, ромы, 
   {{0xdb0db6d2,0x9b4475dc,0xddcc3831,0x43940124}},	//   liaç, ینسو, _araš, _иаҧс, 
   {{0x6fc8083c,0xe6340023,0x2b9c0208,0xe6500023}},	//   rıca, _ኣይኰን, _hích_, _መግናሕ, 
   {{0x2b9c07ae,0x442db6d3,0xc20c01d9,0x98a1b6d4}},	//   _kích_, nsf_, _بٔڈ_, kahā_, 
   {{0xddcc0960,0xe0e407d6,0xbdd80ffb,0x6fc805d1}},	//   _draš, _йўқо, ttès, pıca, 
   {{0x645c00c5,0xdce40055,0x2b9c0208,0x6a1401d5}},	// [2fff0] _ärif, _dahā, _mích_, مبلر, 
   {{0x5f5c0521,0x2b9c004d,0xddcc245e,0xae1401c8}},	//   _ọnụọ, _lích_, _fraš, _اذيت, 
   {{0xddcc80b6,0x7658020b,0xf99c067c,0x3154008f}},	//   _graš, _spuy, _stès_, ריבן_, 
   {{0xbdd9b6d5,0x442c0998,0xdb0db6d6,0x7b64f0e8}},	//   ctèr, dsf_, diaç, _стое, 
   {{0xddcc0010,0x6ff40051,0x00000000,0x00000000}},	//   _zraš, _văcx, --, --, 
   {{0xbeb80023,0xd1c8001f,0x442c007f,0x46b400bc}},	//   mbëd, ችበት_, fsf_, _आइरह, 
   {{0x2b9c001e,0xe8f80276,0x06d400cc,0x291c0165}},	//   _bích_, _блё_, তেলি, ñvae_, 
   {{0xd90c1a4b,0x569400d8,0x00000000,0x00000000}},	//   _ریچ_, _кабт, --, --, 
   {{0x797802b5,0x02016aa8,0xe610007b,0x00000000}},	//   _tāwē, озын, _فشل_, --, 
   {{0xc0d00092,0x00000000,0x00000000,0x00000000}},	//   _የሉም_, --, --, --, 
   {{0xdb0c0261,0x0fc40116,0xcd342099,0xbdd80129}},	//   ciaç, ийон, یرآب, ytèr, 
   {{0x7d00000f,0x3cdc23ef,0xb4c80022,0x52740117}},	//   _ûnsj, _गरजे_, vẽhá, _вуку, 
   {{0x8b640424,0xd9e40073,0x00000000,0x00000000}},	//   یارم, कतात_, --, --, 
   {{0xddccb3a8,0x2fc40209,0xdce400dc,0xe2f800d4}},	//   _praš, ррүң, _sahā, _сечі_, 
   {{0x1c38230c,0xdce4002b,0x324000fb,0x00000000}},	//   лять_, _pahā, _теҙг, --, 
   {{0x2b9c01fb,0xddcc0427,0xbfd000db,0x00000000}},	//   _xích_, _vraš, _ويوع, --, 
  
   {{0x6f040516,0xbdd8068c,0xdb0c0254,0xdce400b8}},	// [30000] _igic, rtèr, diaä, _vahā, 
   {{0xbdd9b6d7,0xe3b80724,0xdce402b5,0xddccdb57}},	//   stèr, _awıl_, _wahā, _traš, 
   {{0xbdd91954,0x02e0038e,0xdce400b0,0x6e24030a}},	//   ptèr, _पर्न, _tahā, _hwib, 
   {{0x6e25b6d8,0x49141533,0x07a406ed,0xdb0c00d8}},	//   _kwib, _प्रो_, јадн, viaç, 
   {{0xdb801d56,0x2b9c0208,0x9f6400e5,0x00000000}},	//   _эҳти, _rích_, íték_, --, 
   {{0x6e25b6d9,0x442c0810,0xbdd80f87,0x6d58007c}},	//   _mwib, tsf_, crèd, _övad, 
   {{0x98a006c8,0x6f04127b,0xbdd8007f,0x442c058a}},	//   pahā_, _ogic, kuèn, usf_, 
   {{0x6f05b6da,0xf741b6db,0xdb0c0261,0xf99c067c}},	//   _ngic, _месо, riaç, _utèr_, 
   {{0x3664156b,0x6e25b6dc,0x69dc0327,0x442db6dd}},	//   _като_, _nwib, _kkre, ssf_, 
   {{0xef08b8c6,0x6f05b6de,0xdb0c00d8,0x3f700051}},	//   _טּ_, _agic, piaç, _ệu_, 
   {{0x2b9c07ae,0x75d0088c,0x83844b2c,0x9978010f}},	//   _tích_, _بيلا, _выле, אָרפ, 
   {{0x6e240230,0x7498011a,0x00000000,0x00000000}},	//   _bwib, _שיאפ, --, --, 
   {{0x69ddb6df,0x229c0248,0x7d00045f,0xa158206d}},	//   _okre, _dákú_, _ûnsk, _балу_, 
   {{0x6e25b6e0,0x6f04b4b7,0x717000c6,0x236400e2}},	//   _dwib, _egic, _وهنا, lemj_, 
   {{0x212c0013,0x645c000d,0xdd943452,0xcb0006e3}},	//   madh_, _ärid, _ғаны, लखंड_, 
   {{0x212c50c2,0x312001ee,0x00000000,0x00000000}},	//   ladh_, _лдәг, --, --, 
   {{0xafb8180a,0xbdd8004a,0x6e24015d,0x00000000}},	// [30010] _خطوط_, stèq, _gwib, --, 
   {{0x212c50c2,0x2d8c01e6,0xaa589928,0x00000000}},	//   nadh_, ödet_, рифу_, --, 
   {{0x1bd5b6e1,0x6e241682,0x00000000,0x00000000}},	//   _гоня, _zwib, --, --, 
   {{0x212c0876,0xa8040046,0x00000000,0x00000000}},	//   hadh_, ізіл, --, --, 
   {{0x69dc0270,0x75b402dd,0x212c01ab,0xddcc013a}},	//   _fkre, ағат_, kadh_, _spař, 
   {{0x89d800aa,0xdb1c0109,0xf71c02d3,0xd5480556}},	//   _موټر_, _eksô, ስትያን, упке_, 
   {{0x212d1f39,0xdb0c00e8,0xe5701b80,0x6d4801c3}},	//   dadh_, lnañ, بطن_, òdai, 
   {{0xdce40311,0x9f540214,0x67d5b6e2,0x212c00a3}},	//   _zahă, _èfèk_, _досу, eadh_, 
   {{0x212c00c6,0x09dc04c5,0xd175b6e3,0x2ce44eae}},	//   fadh_, _ভূটা, быны, _गर्ल_, 
   {{0x212c50c2,0xdb08008c,0x6e240230,0x6f0400b5}},	//   gadh_, _ánæg, _rwib, _sgic, 
   {{0x6e2406e4,0x2ee005b1,0x15ec00e1,0x77380092}},	//   _swib, _syif_, _चीयर_, _አምስተ, 
   {{0x863c044e,0x09dc04c5,0x06ac0eac,0x95c801ec}},	//   _ኣርእስ, _ভূঞা, _ছুটি, _руға_, 
   {{0x212db6e4,0x0eb801c0,0xbdd8004e,0x99889ae3}},	//   badh_, ууны_, ruèn, draž_, 
   {{0x212c7e9f,0x8d740345,0xd9d000cd,0xd5f800df}},	//   cadh_, حاحا, तकोट, רפֿר, 
   {{0x10146728,0x3cd800af,0x7ae00213,0xdb0c002e}},	//   _ابتد, _खुदे_, ənti, enañ, 
   {{0x6e24015c,0x6f040223,0xbdd8004e,0x645c0037}},	//   _twib, _ugic, quèn, _ärie, 
   {{0x08c418ce,0x0ae9b6e5,0x49c97eaf,0x6e240526}},	// [30020] әбен, удай_, глан_, _uwib, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xaad8069f,0xddcc0055,0x25bc005c,0x7d78010f}},	//   _भुरक, _lpaś, vivl_, _ענטו, 
   {{0x0685b6e6,0xe8b80490,0x15d801d3,0xbeb80022}},	//   йген, _आधीच, یدوں_, raëv, 
   {{0x659409fe,0x212db6e7,0xe944004b,0x3d0c17c6}},	//   жалу, yadh_, _ورسی, तुके_, 
   {{0x69dc151c,0xdb0c0ad9,0x32fc0055,0x00000000}},	//   _ukre, lnað, _māyī_, --, 
   {{0xe6440259,0x9f48026c,0xddcc00dc,0xf4808984}},	//   ğlığ, _miaò_, _apaś, зуын, 
   {{0xe6449d58,0xdb0c1f60,0x212c00b5,0xa2dc0073}},	//   şlığ, nnað, wadh_, _पडद्, 
   {{0x212c0fa3,0x6fc803be,0xbdd80ba1,0xd24c0ccb}},	//   tadh_, rıcl, fuèl, نچو_, 
   {{0xddcc02fb,0xa494004b,0x212c00a3,0x816801b9}},	//   _krať, _ویشت, uadh_, уриб_, 
   {{0x212c50c2,0xdb0c1f60,0x741194e5,0x7d00045f}},	//   radh_, knað, _فولا, _ûnsi, 
   {{0xbb18145e,0x212c1549,0x7f9c0023,0x43d40137}},	//   _anîn, sadh_, _këqi, _ازئز, 
   {{0x212c327f,0xdb0d5bd3,0x27fc0030,0x6ea80395}},	//   padh_, dnað, ívny_, бърг_, 
   {{0xfee4036b,0xbdd8068c,0x491805f9,0x9f4806af}},	//   _қўйм, cuèl, मुमो_, _thaï_, 
   {{0x71b80302,0xdb0c0008,0x31b80302,0xf99c0100}},	//   _תצוג, fnað, _תזונ, _duèl_, 
   {{0xdb0c05a4,0x2d8db6e8,0x7034c35c,0x00000000}},	//   gnað, öder_, _اسوس_, --, 
   {{0x74dc2894,0xd01c00fe,0x00000000,0x00000000}},	// [30030] _पुनः, _থিয়_, --, --, 
   {{0xdb0c0de2,0xd1c00092,0x6da400f3,0xb9380240}},	//   rnañ, _ትችት_, _ниња, _ኣምሲሎ, 
   {{0x9f480489,0x9b95b6e9,0xdb0c002e,0x00000000}},	//   _hiañ_, _динц, snañ, --, 
   {{0x9f49b6ea,0x32fc0055,0x00000000,0x00000000}},	//   _kiañ_, _yāyī_, --, --, 
   {{0xbdd8004e,0xe77801d3,0x00000000,0x00000000}},	//   crèc, صلوں_, --, --, 
   {{0xf77000f1,0x00000000,0x00000000,0x00000000}},	//   _ډار_, --, --, --, 
   {{0x70d4012c,0x5fd821b8,0x97c401af,0xddcc0210}},	//   _डडेल, णकाल, _драһ, _spaś, 
   {{0x1308255b,0xa2d000bc,0x04380240,0x00000000}},	//   шний_, _डुङ्, _ከይጸን, --, 
   {{0xbdd8007f,0x6790072d,0x00000000,0x00000000}},	//   tuèl, _سیوط, --, --, 
   {{0x399c00d2,0xd1980276,0x00000000,0x00000000}},	//   _bîsi_, ртич_, --, --, 
   {{0xe2a80502,0xfbdc00e4,0x257002dd,0xddcc0210}},	//   لاین_, _okê_, _سۇيس, _wpaś, 
   {{0x9f981bce,0xe3b803e0,0x0874010f,0x00000000}},	//   féñ_, _atıf_, קערט_, --, 
   {{0xc8e45843,0xdb0c0579,0xddcc00cd,0x00000000}},	//   _कर्म_, vnað, _upaś, --, 
   {{0x463c0023,0x10a46c49,0x826001f7,0x00000000}},	//   _ኣይጠራ, _милн, _آڇين, --, 
   {{0x8b953abb,0xdb0c09f3,0x8fe4007b,0x6ab466c0}},	//   орач, tnað, _وأعم, ूप्र, 
   {{0xc0500375,0x3b044623,0xe8e00051,0x00000000}},	//   _חזה_, жето_, liệu_, --, 
   {{0xdb0c1f60,0x8b84005e,0xbeb804e6,0x8918007b}},	// [30040] rnað, مەگە_, rbëc, لغاز_, 
   {{0x2b58034c,0xbdd8180f,0x6a84329e,0xdb0c148b}},	//   _گیرد_, rrèc, олға, snað, 
   {{0xc8c8723b,0xd90c028e,0x87040108,0x00000000}},	//   جوان_, ایف_, ояле, --, 
   {{0xddcc0118,0x80d400eb,0x00000000,0x00000000}},	//   _vrať, ডেক্, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xddcc0306,0x7ae8002f,0xdb200108,0x00000000}},	//   _trať, ügte, ätöv, --, 
   {{0x07a41049,0x83a8036b,0xc76401d9,0x0768014b}},	//   _давн, итиб_, _وارى, _кавй_, 
   {{0x33f006f6,0x00000000,0x00000000,0x00000000}},	//   وسيس, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9f480428,0x96b800db,0x00000000,0x00000000}},	//   _riañ_, _уусу_, --, --, 
   {{0x2018044e,0x2610001e,0x9f480165,0xc0c80063}},	//   ëri_, _hào_, _siañ_, рупе_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2018e04b,0x99880210,0xd13c0092,0x00000000}},	//   ūri_, traż_, ራታቸው, --, 
   {{0x261001fb,0x99880010,0x00000000,0x00000000}},	//   _mào_, ksaš_, --, --, 
   {{0x2610001e,0xbdd8068c,0x00000000,0x00000000}},	//   _lào_, quèm, --, --, 
   {{0xe3b8013d,0x00000000,0x00000000,0x00000000}},	//   _avız_, --, --, --, 
   {{0x261001dc,0x291c00ac,0x00000000,0x00000000}},	// [30050] _nào_, ıvan_, --, --, 
   {{0xceb0008f,0x7c849d9f,0x99980210,0x00000000}},	//   _ניי_, _думе, _żyło_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf09025f9,0x2610001e,0x1bd55f28,0xd6d00136}},	//   ונע_, _bào_, _хомя, ىقا_, 
   {{0x261001fb,0x79a41677,0x00000000,0x00000000}},	//   _cào_, _дрве, --, --, 
   {{0x2610004d,0x8af80375,0x4a98011a,0xdb0c032e}},	//   _dào_, _להרי, _הישג, gnaö, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf770ab4c,0xd7c8036b,0x00000000,0x00000000}},	//   _غاز_, _اوره_, --, --, 
   {{0xd17400ee,0x2610004d,0xf6741b2c,0x00000000}},	//   пыны, _gào_, _بازخ, --, 
   {{0x141800c6,0xf484008e,0x00000000,0x00000000}},	//   _هيئة_, _муен, --, --, 
   {{0x3cd849fc,0x00000000,0x00000000,0x00000000}},	//   _खुले_, --, --, --, 
   {{0x645c000d,0x6e2000e4,0x00000000,0x00000000}},	//   _äria, ãmbo, --, --, 
   {{0x32600014,0x261001fb,0xb2c412a4,0xdb0c0037}},	//   _آنتہ, _xào_, _بغاو, nnaõ, 
   {{0x427805e1,0x2019b6eb,0xa2a8012d,0x3f8c01e1}},	//   _לאנג, íric_, टनर्, _ògun_, 
   {{0x0c740020,0x10a40323,0xc0e002bf,0x2bf80490}},	//   _ችግሮች_, _хийн, _пошк, ंगलं_, 
   {{0xbeb80023,0x4f24010b,0xda6400ec,0xfc0000d8}},	//   mbën, _эдиб, ڀالي, епсо, 
   {{0x3fc8004b,0x680c03e0,0x4a440006,0x00000000}},	// [30060] _ددوی_, _iğdi, янав, --, 
   {{0x2610001e,0x00000000,0x00000000,0x00000000}},	//   _rào_, --, --, --, 
   {{0x6d5db6ec,0x47840228,0x2610004d,0x321c003e}},	//   mfra, зылб, _sào_, hpuy_, 
   {{0x6d5db6ed,0x27e00086,0xa2dc0490,0xa2cc013a}},	//   lfra, ôin_, _पडल्, _तखल्, 
   {{0xd90c0d83,0x00000000,0x00000000,0x00000000}},	//   ایہ_, --, --, --, 
   {{0x2610431d,0x6d5db6ee,0xe9a803e6,0x99880205}},	//   _vào_, nfra, _بگرن_, mpaş_, 
   {{0x29180212,0x6d5d199a,0x7d00045f,0x39440077}},	//   _ifra_, ifra, _ûnst, ónse_, 
   {{0x261001fb,0xbdd8020c,0x3434007b,0xc7640137}},	//   _tào_, jrèn, أسود_, _عازى, 
   {{0x6d5db6ef,0x321c089c,0x04fc015b,0xdb0c0158}},	//   kfra, gpuy_, ুরের_, riaø, 
   {{0x361802e4,0x09bc00fe,0x00000000,0x00000000}},	//   _לומד, _অৱতা, --, --, 
   {{0x6d5db6f0,0xf9900375,0x30a00801,0xbdd800db}},	//   dfra, תרת_, еряв, frèn, 
   {{0xbdd8020c,0xbfa8d822,0x6d5c035a,0xd9b90584}},	//   grèn, стое_, efra, _आष्ट, 
   {{0x2919b6f1,0x64585522,0xf0e400d1,0x00000000}},	//   _ofra_, ltvi, يىۋى_, --, 
   {{0x72e830fb,0x291c0489,0x680c0205,0x920400cd}},	//   _פֿאַ, ñval_, _eğdi, _prāś, 
   {{0x408401f0,0xfba8009d,0x00000000,0x00000000}},	//   _хулб, бтай_, --, --, 
   {{0x2918013f,0x64593288,0x6d5c00ae,0x00000000}},	//   _afra_, itvi, afra, --, 
   {{0x6d5db6f2,0xdd94021f,0x9999b6f3,0xdcfc4674}},	// [30070] bfra, _жапы, окат_, ızıs, 
   {{0xff5c026c,0x37a82f89,0x6d5c02d0,0x2ef4013d}},	//   knîk_, өтен_, cfra, _языр, 
   {{0x2918070d,0x661c0427,0xeaa40014,0x00000000}},	//   _dfra_, _črka, وٕہَ, --, 
   {{0xa7e40131,0x09bc03d4,0x29182507,0x6459b6f4}},	//   ىكلى, _অৱদা, _efra_, dtvi, 
   {{0x7bddb6f5,0x4b780375,0x86200014,0x7ae400f1}},	//   moqu, _וארו, نکٕل, _روسې_, 
   {{0x7bdd7539,0x64580175,0x3f9803e3,0xdb0c0254}},	//   loqu, ftvi, _loqu_, rnaõ, 
   {{0x6458049f,0xbdd90b13,0x572401ec,0x00000000}},	//   gtvi, guèi, _يىسك, --, 
   {{0x3f98601a,0x7bdc16b8,0xe3b80213,0xfa280327}},	//   _noqu_, noqu, _atıb_, _སྦོན_, 
   {{0x6d5db6f6,0x0cc80b02,0xd1b9788c,0x645db6f7}},	//   yfra, _रश्म, قادا_, _ärin, 
   {{0x321c0bf1,0xd1b97ea3,0x10a5b6f8,0x29180165}},	//   rpuy_, تابا_, дион, _xfra_, 
   {{0x5455b6f9,0x6d5db6fa,0xbdd89c19,0x6459b6fb}},	//   _цвет, vfra, trèn, ctvi, 
   {{0xf99c0ba1,0xbeb9b651,0x321c002e,0x6d5db6fc}},	//   _duèi_, rbën, ppuy_, wfra, 
   {{0x6d5db6fd,0x7bddb6fe,0xd1740372,0xd1b8064c}},	//   tfra, doqu, _жыйы, _واتا_, 
   {{0x90c42e91,0xdce40030,0x6d5c05c7,0xbeb8036e}},	//   _обле, _dohľ, ufra, mbël, 
   {{0xfce1b6ff,0x7649b700,0x7bdc0a90,0xbdd806af}},	//   воро, hugy, foqu, prèn, 
   {{0x6d5c2d52,0x8ff8034c,0x32040109,0x320c020b}},	//   sfra, _برتر_, _hiny_, _kugy_, 
   {{0x2fc00223,0x32040526,0x6d5db701,0x8d740222}},	// [30080] _imig_, _kiny_, pfra, _قادا, 
   {{0xc0ec044e,0x3205b702,0x320c020c,0x645805ac}},	//   _ቀጺሉ_, _jiny_, _mugy_, ytvi, 
   {{0x3205b703,0x8b242850,0x76480369,0x7bddb704}},	//   _miny_, _одне, eugy, boqu, 
   {{0x46e864e1,0x7bdd2c5b,0x06e8010b,0x86c400f1}},	//   оден_, coqu, омек_, ويان, 
   {{0x2fc0026c,0x764804ba,0x00000000,0x00000000}},	//   _mmig_, gugy, --, --, 
   {{0x6459b705,0x32040109,0x6e2000e4,0x00000000}},	//   ttvi, _niny_, âmby, --, 
   {{0xd90d105c,0x77680b6f,0x6458168c,0xd6a803cc}},	//   _ایم_, begx, utvi, يدۇم_, 
   {{0x32040170,0x76488576,0x6aa4009a,0x46141541}},	//   _ainy_, bugy, oyif, _يوزر, 
   {{0x6aa5b706,0x02680212,0xba98008f,0xc2e400eb}},	//   nyif, іший_, ַסטי, খেনি_, 
   {{0x3f980194,0xf99c1497,0x7bddb707,0x3dc0009a}},	//   _soqu_, _puèi_, zoqu, xijw_, 
   {{0x61e9b708,0x7bdc01fe,0x320401f5,0xd5340014}},	//   rldl, yoqu, _diny_, _سِنگ, 
   {{0xdce401a2,0x338047ce,0xbdd8067c,0x7bdc003a}},	//   _pohľ, _аушв, nuèv, xoqu, 
   {{0x7bdccc04,0x5ea5b709,0x213c0205,0x00000000}},	//   voqu, رمسل, _tdvh_, --, 
   {{0x660801d9,0x3204004e,0xbdd8180f,0x2fc00064}},	//   _jidk, _giny_, ntèx, _emig_, 
   {{0x7bddb70a,0x66080050,0x3f98013c,0x77680117}},	//   toqu, _midk, _toqu_, yegx, 
   {{0xddcc0115,0x6609b70b,0xfa280327,0xd4540023}},	//   _isaŭ, _lidk, _སྦུན_, _ዘይጠቅ, 
   {{0x7bddb70c,0xaa58009b,0x6d480332,0x00000000}},	// [30090] roqu, миту_, ódac, --, 
   {{0x7bdc8f9b,0x5c742a5e,0xf99034f6,0xdb0c5725}},	//   soqu, _злот, خبر_, chaî, 
   {{0x2009b70d,0x7bdc00d8,0xe9e4010b,0xddcc0153}},	//   _kiai_, poqu, тцто, _kraž, 
   {{0x7649b70e,0x6aa40230,0x99880030,0x96f80108}},	//   tugy, byif, dsať_, пеет_, 
   {{0x6aa40223,0xddcc0118,0x00000000,0x00000000}},	//   cyif, _mraž, --, --, 
   {{0x200819a2,0xba400006,0x6609b70f,0xa5641c02}},	//   _liai_, žįst, _cidk, ندىن, 
   {{0x2008123c,0x76482819,0xdb1c0036,0x645c00c5}},	//   _oiai_, sugy, _amsé, _äril, 
   {{0x2009b710,0x320403d1,0xbdd8007f,0x28a4000d}},	//   _niai_, _siny_, rtèy, _खअति, 
   {{0x5154419d,0xe56c0117,0x00000000,0x00000000}},	//   нтну, _кҷ_, --, --, 
   {{0xe5c45882,0x2009b711,0xdb0dab5c,0xbeb804e6}},	//   _исхо, _aiai_, khaï, rbël, 
   {{0x0fc4010b,0x32040306,0xbdd8067c,0x3ea001b9}},	//   ейнн, _viny_, rrèl, қирг, 
   {{0x6aa40ba7,0x3204012d,0x320c010e,0xdb0c000d}},	//   yyif, _winy_, _tugy_, giaü, 
   {{0x32058f5b,0xb6040003,0x7e78007c,0x00000000}},	//   _tiny_, poġġ, åupp, --, 
   {{0x20080a73,0x6aa400ca,0xd10826c6,0x00000000}},	//   _eiai_, vyif, _عقبه_, --, 
   {{0xd054016b,0x00000000,0x00000000,0x00000000}},	//   _ɔbɛp, --, --, --, 
   {{0xddcdb712,0x20080016,0xdb200241,0x00000000}},	//   _graž, _giai_, _ìtìk, --, 
   {{0x661c0427,0x00000000,0x00000000,0x00000000}},	// [300a0] _črko, --, --, --, 
   {{0x2afc00cd,0x00000000,0x00000000,0x00000000}},	//   लेषु_, --, --, --, 
   {{0x6ea801d9,0x7d00000f,0xdb0d71d5,0x07a42bbd}},	//   _رنگہ_, _ûnsp, chaï, нажн, 
   {{0x6609b713,0xf4f00212,0x8a3801c6,0xbc1800df}},	//   _sidk, _якiй_, _нягт_, _מוטש, 
   {{0xd9b00075,0xaa041719,0xb6e00138,0x7aa00150}},	//   _ھەمد, _аҗай, люшк, _бияз, 
   {{0xcb080832,0xfa280327,0x2d980100,0xc5e80073}},	//   _ويگن_, _སྦིན_, njre_, टतेय_, 
   {{0x6609b714,0xbdd8067c,0x00000000,0x00000000}},	//   _vidk, rtèx, --, --, 
   {{0x645c00c5,0xe3b800fd,0x00000000,0x00000000}},	//   _ärim, _awır_, --, --, 
   {{0x6608143a,0x81c402e8,0x200800c0,0xf7400108}},	//   _tidk, ещне, _riai_, _щето, 
   {{0xbdd9b715,0x7ab80375,0x201800d8,0x2009b716}},	//   trèm, פציו, írio_, _siai_, 
   {{0xddcdb717,0x200805b1,0x521400f7,0x7f9c00e8}},	//   _praž, _piai_, ндөт, _sëqq, 
   {{0xd4680597,0xd37802bf,0xbdd806af,0x20180115}},	//   _تحكم_, _очі_, huèt, ŭrio_, 
   {{0xddccabea,0x2009b718,0xbeb80200,0x00000000}},	//   _vraž, _viai_, mbëk, --, 
   {{0xbdd80ba1,0x26180037,0x00000000,0x00000000}},	//   prèm, _पढनी_, --, --, 
   {{0xddcdb719,0x62804e9b,0x20080607,0xfbd0555a}},	//   _traž, lvmo, _tiai_, هتر_, 
   {{0x25dc0254,0xddcc01ef,0x00000000,0x00000000}},	//   मकुण, _uraž, --, --, 
   {{0xef640801,0xfe2400c7,0xc10001c6,0x00000000}},	// [300b0] _също, _џьин, _шүүл, --, 
   {{0xaa4404a9,0xdb0c0597,0x3eb00365,0xddcc031c}},	//   انلى, mhaí, ıntı_, _jraż, 
   {{0x62840064,0x00000000,0x00000000,0x00000000}},	//   _šiol, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe618005e,0x8b980302,0x4bc08715,0x67240086}},	//   еді_, _חברת, _төрг, ñija, 
   {{0x6595849b,0xd5e400a7,0xd469b71a,0x00000000}},	//   лачу, ъжли, дике_, --, 
   {{0xd7fc00c6,0x201800d0,0x298400cf,0x5fe00fe3}},	//   _мσм_, íril_, _сыяг, नवाल, 
   {{0xbeb80023,0xc3206a7c,0xa48400f1,0x00000000}},	//   rbëj, амък, اجون, --, 
   {{0xddcc0003,0x60d803ac,0xbdd8067c,0x39a402d3}},	//   _braż, _axvm, nuès, _ወረስቲ_, 
   {{0x7779b71b,0xdb0c0332,0x76a40055,0x00000000}},	//   _haux, dhaí, _vīyā, --, 
   {{0xddcc012d,0x71601411,0x00000000,0x00000000}},	//   _draż, _ەپتە, --, --, 
   {{0xa5c40055,0x00000000,0x00000000,0x00000000}},	//   _įųis, --, --, --, 
   {{0x77780227,0xddcc0135,0x00000000,0x00000000}},	//   _maux, _fraż, --, --, 
   {{0x77780399,0x918000d1,0xddcc2c20,0x67f84e00}},	//   _laux, _ئۇدۇ, _graż, míje, 
   {{0x4fc0247f,0x680c00a2,0x4b5401d5,0x2cac03b2}},	//   _نەدە, _oşda, къат, ádd_, 
   {{0xf41000bd,0x8e4800c6,0xdb0db71c,0x61f80240}},	//   _সবার_, _قلبك_, fiañ, _zhvl, 
   {{0xc3300d65,0xbdd8180f,0xdb0c48cb,0x09e401f0}},	// [300c0] יון_, guès, chaí, воан, 
   {{0xddcc00b8,0x8d7402f2,0xd64c00c0,0xfe3400df}},	//   _draų, _شاخا, _вiке, _שריי_, 
   {{0xde883886,0x76580309,0xdd040311,0x7779b71d}},	//   _قضیه_, _aquy, ăsăt, _baux, 
   {{0xe3b8029f,0x62840024,0x46a5532e,0x6280007c}},	//   _atın_, _šiom, каев, yvmo, 
   {{0xa684190b,0x00000000,0x00000000,0x00000000}},	//   ығай, --, --, --, 
   {{0x645c00c5,0xbdd81e54,0xa4d400d4,0x00000000}},	//   _ärik, quèt, лолі, --, 
   {{0x02c800dc,0x3978011a,0x5d44010f,0x00000000}},	//   ाप्न, _קטלנ, אָפּ_, --, 
   {{0xbdd8067c,0x87f801c6,0x78a001f4,0x00000000}},	//   nuèr, _цэгт_, änve, --, 
   {{0xc6040533,0xd584168d,0xf99c0ba1,0x166401d9}},	//   _азай, _ڕێوه_, _tuèt_, _مالَ, 
   {{0xe29800c7,0x00000000,0x00000000,0x00000000}},	//   даҩ_, --, --, --, 
   {{0x9f35b71e,0xdb0c0156,0xbdd80022,0x00000000}},	//   лені, ziañ, kuèr, --, 
   {{0xdb0c0597,0x67f8012c,0xddcc0034,0x7778004e}},	//   thaí, bíje, _wraż, _xaux, 
   {{0x443d0aaa,0xddcc0135,0xbdd8007f,0xf770011a}},	//   _hvt_, _traż, nsèg, בקר_, 
   {{0xdcf40171,0x00000000,0x00000000,0x00000000}},	//   edzā, --, --, --, 
   {{0xb6440075,0x443c0109,0x00000000,0x00000000}},	//   _ﺋﯘ_, _jvt_, --, --, 
   {{0xbdd82508,0x2bb8007b,0xdb0c035b,0x00000000}},	//   guèr, ناقة_, tiañ, --, 
   {{0x62840006,0x7779b71f,0x443c0208,0xaa5c01ec}},	// [300d0] _šioj, _raux, _lvt_, метi, 
   {{0x9934fc15,0x443c0175,0x9b600e56,0x00000000}},	//   افات, _ovt_, _گۆرۈ, --, 
   {{0x443c01f5,0x77780393,0x645c0037,0xdb0c00c7}},	//   _nvt_, _paux, _ärih, siañ, 
   {{0xf99c067c,0x2cac08fb,0x9b94084c,0xdb0c005a}},	//   _cuèr_, ødde_, _симц, piañ, 
   {{0xadc401e1,0x1545b720,0x9664010b,0xbdd8fc63}},	//   _arẹw, гелм, укле, quès, 
   {{0xc620045e,0xf480034c,0xbeb80023,0x67f800bc}},	//   _নিশা_, لاعی, rbëh, víje, 
   {{0xf8045ac1,0x69d80490,0x00000000,0x00000000}},	//   _ачан, _मदती, --, --, 
   {{0x86940032,0x443c0051,0xbeb800e8,0xbb2000d1}},	//   ткәс_, _dvt_, ccëg, ﭽﯩﻚ_, 
   {{0x443c11c0,0x11e5b721,0x00000000,0x00000000}},	//   _evt_, лжим, --, --, 
   {{0x443c00fe,0x67f800d0,0xe3b8013d,0xc6d8010f}},	//   _fvt_, ríje, _utın_, _אַבר, 
   {{0x443db722,0x8fa5b723,0x90c41e76,0xb6a00051}},	//   _gvt_, гане, убне, _đâyy, 
   {{0x4f9400c7,0x4fb414af,0x00000000,0x00000000}},	//   уроу, اصدر, --, --, 
   {{0x443c06d9,0x00000000,0x00000000,0x00000000}},	//   _zvt_, --, --, --, 
   {{0xc22005d9,0xc0d00092,0x5dd4004e,0x00000000}},	//   _اکيو, ከልም_, аюсу, --, 
   {{0xbdd8067c,0x00000000,0x00000000,0x00000000}},	//   tuèr, --, --, --, 
   {{0xc050025f,0x3940010a,0xe0d003e6,0x5bb421f3}},	//   _הזה_, _adjs_, _بزه_, асуф, 
   {{0xca85b724,0x67dc0010,0x4fc00137,0x3ab00139}},	// [300e0] ыгай, nčje, _نەگە, бәрт, 
   {{0x6e25b725,0x8d5418a4,0xe3b803e0,0x62840153}},	//   _itib, _стич, _atıl_, _šiok, 
   {{0xddcc0309,0x67240086,0x76480142,0xb9e400d1}},	//   _usaš, ñijo, ergy, اتقۇ, 
   {{0x4735b726,0xfafc0023,0x6e240135,0xbdd81497}},	//   اراز, _ibën_, _ktib, quèr, 
   {{0x443c049f,0xe69401c6,0x3e7c0419,0xdb200248}},	//   _svt_, рилы, mätá_, _ìták, 
   {{0x443c4fb5,0x6e244180,0xbdd8067c,0x00000000}},	//   _pvt_, _mtib, rsèg, --, 
   {{0x59740137,0xbdd80ba1,0x8cc807f7,0x3444009d}},	//   _тыяу, ssèg, _हेमो, гчын_, 
   {{0xbdd80ba1,0xbeb80240,0x6e24022e,0x6704014b}},	//   rrèi, mbëv, _otib, _кӯлб, 
   {{0x6e240537,0x855435e6,0x2a600393,0xd5e80137}},	//   _ntib, _مخاط, ntib_, رعۇن_, 
   {{0x66e5b727,0x00000000,0x00000000,0x00000000}},	//   _боға, --, --, --, 
   {{0x25080b43,0x44a458c5,0xb6002195,0x2a6000af}},	//   _شرطی_, _حماق, íšen, htib_, 
   {{0x2a61b728,0x1fc400c2,0x00000000,0x00000000}},	//   ktib_, рроҳ, --, --, 
   {{0x6234084c,0x44cc00ac,0x21780166,0xa1959753}},	//   _телу, _hə_, _айлы_, _валч, 
   {{0x6e240175,0x44cc03b9,0x00000000,0x00000000}},	//   _dtib, _kə_, --, --, 
   {{0x7b640474,0x6e25b729,0x00000000,0x00000000}},	//   лтае, _etib, --, --, 
   {{0x7649b72a,0x44cc00ac,0x301002e8,0x7eb4022e}},	//   yrgy, _mə_, _удър, _бҳмс_, 
   {{0x44cc00ac,0x9df80107,0xdb1c0174,0x79240124}},	// [300f0] _lə_, _инит_, _umsí, гьеж, 
   {{0x26180c2e,0x6934009d,0x00000000,0x00000000}},	//   _पढ़ी_, йнуу, --, --, 
   {{0x44cc11a9,0xe3b985f8,0x00000000,0x00000000}},	//   _nə_, _atım_, --, --, 
   {{0xbdd8004a,0x656800b8,0xb7e000cc,0x00000000}},	//   ssèd, _abdh, যষ্ট, --, 
   {{0x15b809a5,0x00000000,0x00000000,0x00000000}},	//   кыкы_, --, --, --, 
   {{0x44cc0213,0xdb0c00e4,0x291c05c7,0xded401f3}},	//   _bə_, chaá, ñvat_, ከርና_, 
   {{0x77b00139,0x44cc03e3,0x00000000,0x00000000}},	//   _eçxa, _cə_, --, --, 
   {{0x44cc9f20,0x07a001d9,0xdb0c0241,0x00000000}},	//   _də_, _وۅلُ, _èkóm, --, 
   {{0xc7e800c7,0x919400d8,0x00000000,0x00000000}},	//   _рырҵ_, ајнш, --, --, 
   {{0x44cc06be,0x41a4009d,0x00000000,0x00000000}},	//   _fə_, ивын_, --, --, 
   {{0x6e24261e,0x7aec003a,0x06a8009e,0x44cc06be}},	//   _stib, _lyct, _খেপি, _gə_, 
   {{0x2a60036b,0xc4980a1e,0x4fc019c5,0x00000000}},	//   ytib_, _בשעת, تەبە, --, 
   {{0x44cc06be,0xe2a802f2,0x00000000,0x00000000}},	//   _zə_, _ماون_, --, --, 
   {{0x44cc00ac,0xdc840240,0x00000000,0x00000000}},	//   _yə_, _ሓያሎይ_, --, --, 
   {{0x2d840118,0x3cc40107,0x44cc06be,0xd7b423e9}},	//   ěme_, алро_, _xə_, ंसाच, 
   {{0x8b241086,0x4b245172,0x2a60000d,0x00000000}},	//   рдае, рмав, ttib_, --, 
   {{0x98a004fe,0x645d81d7,0x98b00100,0x6e25b72b}},	// [30100] kahē_, _äriv, _dezč_, _utib, 
   {{0x2a60263e,0x8d643925,0x6720022e,0x67f801d3}},	//   rtib_, _твое, _sfmj, díja, 
   {{0xb60400da,0x97400023,0xdb0c0254,0x85c401d5}},	//   _mašī, _ከምዝስ, diaõ, یغتم, 
   {{0x068473ce,0xc6a4f970,0x2a601529,0xb6c800dd}},	//   иген, ирли, ptib_, ھانے_, 
   {{0x8cc80882,0x291c030a,0x44cc03e3,0xb6c801d3}},	//   _हेतो, ñvas_, _sə_, پانے_, 
   {{0xbeb9b72c,0xa4f8221d,0x23b80ca8,0xdb0c000d}},	//   mbët, هکار_, _méje_, giaõ, 
   {{0x98b0007f,0xbeb8002e,0x44cc03b9,0x00000000}},	//   _yezč_, lbët, _qə_, --, 
   {{0x44cdb72d,0x67f801f1,0xdb0c000d,0x00000000}},	//   _və_, bíja, aiaõ, --, 
   {{0x46e8010b,0x00000000,0x00000000,0x00000000}},	//   _рдан_, --, --, --, 
   {{0x44cdb72e,0x04440064,0x86080066,0x00000000}},	//   _tə_, _вежн, _شقاق_, --, 
   {{0x10880075,0x15b80064,0x00000000,0x00000000}},	//   _ﺑﯧﺮﯨ, _сыты_, --, --, 
   {{0x42c8506f,0x42a40032,0x78a1b72f,0xdfd4aec3}},	//   _иген_, _ҡуҙғ, ønvi, сомы, 
   {{0xbdd80100,0x7b7400f2,0xcdcc00f1,0x394403b2}},	//   krèt, یطرا, کښي_, ónsk_, 
   {{0xdb0c06ed,0x7de40220,0x00000000,0x00000000}},	//   lhaç, рімд, --, --, 
   {{0x61e9b730,0x217801af,0x56400023,0x30a0011c}},	//   modl, _айһы_, _ኣይንብ, _мръв, 
   {{0x5b15b731,0x61e9a205,0xdb0c0120,0xaca402e3}},	//   смат, lodl, nhaç, chọi, 
   {{0xe3b80790,0x3c8800d1,0x00000000,0x00000000}},	// [30110] _atık_, _ﺗﯧﺨﻰ_, --, --, 
   {{0x61e9b732,0x67f80030,0xdb0c0165,0x00000000}},	//   nodl, víja, nkaé, --, 
   {{0x98a003a0,0x4dd80375,0x61e801ab,0xa34c00c0}},	//   vahē_, _תחתו, iodl, dėžė_, 
   {{0x61e803c6,0xbdd8067c,0xf7708d1a,0x2d440023}},	//   hodl, rrèu, تاط_, _ንምነየ, 
   {{0xbeb80023,0x65b400db,0x61e9b733,0xe75800d4}},	//   mbës, _sàha, kodl, ричі_, 
   {{0xbdd839d3,0xbeb80023,0x67f80789,0x569402dd}},	//   crèt, lbës, ríja, _қазт, 
   {{0x61e8036b,0x649802e8,0x00000000,0x00000000}},	//   dodl, итър_, --, --, 
   {{0x955c0020,0x935825ec,0x67f80419,0xf6500117}},	//   _ሰዎችን_, урку_, píja, _мебӯ, 
   {{0x65b400b0,0x11380024,0x1308084c,0x61e803cb}},	//   _wàha, ляны_, ыний_, fodl, 
   {{0x52741d18,0x61e9b734,0x00000000,0x00000000}},	//   _ҳуку, godl, --, --, 
   {{0xbf9800d8,0x00000000,0x00000000,0x00000000}},	//   rmên, --, --, --, 
   {{0xdb0c06ed,0xe1f800f7,0x62840327,0x7f9c036e}},	//   chaç, лгө_, _ġiov, _këqy, 
   {{0x41b40372,0x61e9b735,0xd9f80490,0x00000000}},	//   рсөт, bodl, ्गात_, --, 
   {{0x61e800d2,0x41240a83,0x56400023,0x00000000}},	//   codl, _лошо_, _ኣይነብ, --, 
   {{0x645c00c5,0xc22000f2,0x00000000,0x00000000}},	//   _ärit, _وکیو, --, --, 
   {{0xeb5413ef,0x9f59b736,0x9f54010a,0x2618000d}},	//   تىرگ, êrô_, _мĕск, _पढली_, 
   {{0xdb1c037e,0xbdd850b6,0xc8c800e5,0x0ae801e2}},	// [30120] _omsæ, grès, گوان_, ارزي_, 
   {{0x645cb88a,0xbeb80036,0x00000000,0x00000000}},	//   _årig, rbët, --, --, 
   {{0xc8c82094,0xe46405d1,0xbdd94344,0x2cb0054e}},	//   دوان_, ülüğ, rrèt, ândă_, 
   {{0xfafc1bce,0x61e9b737,0x2ee0025c,0xbeb80240}},	//   _mbëj_, zodl, _kxif_, mbër, 
   {{0xa5100882,0x6b8400ee,0x61e9a8dc,0xbeb80023}},	//   ाश्च_, mdig, yodl, lbër, 
   {{0x689405d9,0x00000000,0x00000000,0x00000000}},	//   _وڌائ, --, --, --, 
   {{0x6b85b738,0x00000000,0x00000000,0x00000000}},	//   odig, --, --, --, 
   {{0x61e9b739,0x61e400df,0xe3a40066,0x00000000}},	//   wodl, _ƭilo, تشتی, --, 
   {{0x6b85b73a,0x61e9b73b,0xc620009e,0x2ee00327}},	//   idig, todl, _নিকা_, _nxif_, 
   {{0x36180302,0x55c40220,0x15a40014,0x6b85b73c}},	//   _עובד, _дауғ, _وصلُ, hdig, 
   {{0x6b840209,0x61e899e5,0x83840022,0x9f98b834}},	//   kdig, rodl, _гыле, авну_, 
   {{0xf8b00302,0x61e9b73d,0x6b840196,0x00000000}},	//   פשר_, sodl, jdig, --, 
   {{0x6b85b73e,0x1df807d8,0x06a80183,0x61e83e8f}},	//   ddig, иемы_, _খেতি, podl, 
   {{0x6b844d7c,0xbdd8067c,0x645c0037,0x61e81ffc}},	//   edig, erèr, _äris, qodl, 
   {{0x6b841af4,0x00000000,0x00000000,0x00000000}},	//   fdig, --, --, --, 
   {{0x69dc4035,0xe3b8013d,0xbdd856ec,0x5a34600f}},	//   _ajre, _awız_, grèr, жнат, 
   {{0x75fc000f,0xbeb80c52,0x6a1409a0,0x7de403de}},	// [30130] lêze, rbës, змуу, _гінд, 
   {{0x6b85b73f,0xbdd8180f,0x3944045f,0xbeb80036}},	//   adig, rrès, ûns_, sbës, 
   {{0x39a402d3,0x7a3c0ca8,0xbdd81f3f,0x674402d3}},	//   _ወከልቲ_, _bàtá, brèr, _ከምዝብ, 
   {{0xbdd85051,0x6b840124,0x81c000de,0x2bf40024}},	//   près, cdig, _žēla, _няўр, 
   {{0x959810f5,0xe73802d5,0x290c0332,0x61400092}},	//   итку_, сеі_, _údan_, ጢአታች, 
   {{0x9f48002b,0x59dc4e8f,0xe91800d4,0x2e3c00df}},	//   _ahaü_, _मदिर, _горі_, נגונ, 
   {{0x6d480efe,0xa8a42f89,0x25640014,0x00000000}},	//   ódai, _ертк, ساوُ, --, 
   {{0x248c15f5,0x924801d5,0x00000000,0x00000000}},	//   _drdm_, азиб_, --, --, 
   {{0x31b80b21,0xf00401c0,0x59dc1c5d,0x00000000}},	//   _lêze_, үүли, _मदार, --, 
   {{0x5044016a,0x6b85b740,0xdb1c01a8,0x7d140857}},	//   оеоб, zdig, _umsæ, _ngxs, 
   {{0xc9509b62,0x6b85b741,0x00e002d5,0xe3b800db}},	//   ומי_, ydig, джэн, рбө_, 
   {{0x95c80220,0x6840013a,0x92940024,0x00000000}},	//   _суға_, _hádá, _маец, --, 
   {{0x333c0231,0x645c00c5,0x6b85a007,0x684000e5}},	//   maux_, _ärir, vdig, _kádá, 
   {{0x333c0097,0xd37005d9,0x6b849055,0x00000000}},	//   laux_, _رهڻ_, wdig, --, 
   {{0x8fa40a16,0xdb1c049f,0x6b84010b,0x321c02d1}},	//   _маке, _omsä, tdig, lquy_, 
   {{0x6b840e29,0x333c20ef,0xbeb802d3,0x53c801ad}},	//   udig, naux_, rbër, िफिश, 
   {{0x49c9b742,0x9f4800e4,0x37cc015b,0xbdd81497}},	// [30140] алан_, _ehaó_, িকার, rrèr, 
   {{0x6b85b743,0x23b8032b,0xf7800327,0x680d282a}},	//   sdig, _méja_, _leħħ_, _işdi, 
   {{0x6d5db744,0x7c3801a6,0x333c002e,0xbeb8036e}},	//   mgra, ćurc, kaux_, qbër, 
   {{0xbdd9b745,0x684001e1,0x6aa0004e,0x6b84058a}},	//   nsèn, _aádá, _àmfo, qdig, 
   {{0x2b41b746,0x2a640694,0x333c0129,0x6594030d}},	//   maic_, _ëmb_, daux_, залу, 
   {{0x6d5db747,0x273807ae,0xf5142928,0xdb1c0036}},	//   ngra, ẩn_, يتىش_, _emsä, 
   {{0x68300241,0x6d5db748,0xbdd80066,0x333c0129}},	//   _dòdò, igra, ksèn, faux_, 
   {{0x23b800d5,0x2b4000c6,0x333c004a,0x273c0092}},	//   _béja_, naic_, gaux_, ጠቀምበ, 
   {{0x43900efb,0x6d5c1a56,0x75fc045f,0xd624007b}},	//   зақс, kgra, wêze, _فعلي, 
   {{0x23b807ea,0x683001e1,0x62840024,0x6d5db749}},	//   _déja_, _gòdò, _šios, jgra, 
   {{0x6d5db74a,0xc485b74b,0x333c06af,0xdfd0007b}},	//   dgra, _флек, baux_, فيد_, 
   {{0x442db74c,0x7410ef76,0x645805b8,0x333c20ef}},	//   mpf_, _قولا, muvi, caux_, 
   {{0x22940801,0x2c7c01e4,0x2b4004cc,0xa295b74d}},	//   _хиля, _aŭd_, daic_, _халі, 
   {{0x6d5db74e,0x65780084,0xdce40882,0x2918036b}},	//   ggra, nevh, _abhā, _ngra_, 
   {{0x6459b74f,0xc0dc044e,0xe0d400c8,0x2b40007b}},	//   nuvi, _ሓፋሽ_, _מײַ_, faic_, 
   {{0x29187cea,0x6d5c0491,0x201c0418,0xdce40055}},	//   _agra_, agra, _iuvi_, _cbhā, 
   {{0x31b8334b,0x2bbc069f,0x6458b3ea,0x6d5c0677}},	// [30150] _wêze_, _ईतरा, huvi, bgra, 
   {{0x6459b750,0x6578003b,0x5d544130,0x6d5db751}},	//   kuvi, jevh, _экот, cgra, 
   {{0x333c07ea,0x6459b752,0x442c009a,0x2b4001ab}},	//   yaux_, juvi, jpf_, baic_, 
   {{0x6459b753,0x2b41b754,0x2cac01e6,0x201c009f}},	//   duvi, caic_, ädde_, _muvi_, 
   {{0x333c0231,0xcb980302,0x64580051,0xe77800e5}},	//   vaux_, _הסרט, euvi, زلوں_, 
   {{0x201c0261,0x65781682,0xf780003d,0x645802d2}},	//   _ouvi_, gevh, _seħħ_, fuvi, 
   {{0x64586018,0x201c11ce,0x333c20ef,0x23b800d8}},	//   guvi, _nuvi_, taux_, _séja_, 
   {{0xf771b755,0xdb1c0e78,0x10a400d1,0xb9f80092}},	//   _تاس_, _umsä, җимн, _ቆም_, 
   {{0x6d5db756,0x333c20ef,0xe43000dd,0xaee5b757}},	//   ygra, raux_, _یہود, _muṣi, 
   {{0x2b400311,0x201db758,0x657805d1,0x321c0309}},	//   zaic_, _buvi_, cevh, rquy_, 
   {{0x645c007d,0x4fe85c9d,0x201c07c5,0x333c5725}},	//   _ärip, ймон_, _cuvi_, paux_, 
   {{0xbeb802d3,0x201c0005,0x6d5db759,0x273c0092}},	//   rcën, _duvi_, wgra, ጠቀሙበ, 
   {{0x6d5db75a,0x5ec4ec80,0x9f480165,0xcae80cb4}},	//   tgra, дияғ, _chañ_, _झुंड_, 
   {{0x6d5db75b,0x201c07c5,0x00000000,0x00000000}},	//   ugra, _fuvi_, --, --, 
   {{0x6d5db75c,0x201c0064,0x2b401a9b,0xd008010a}},	//   rgra, _guvi_, taic_, _леке_, 
   {{0x65780099,0x3a280332,0xdee80092,0x00000000}},	//   zevh, _btcp_, _መላኩ_, --, 
   {{0x6d5d8747,0x3a29b75d,0x2b4007f0,0x64587ce9}},	// [30160] pgra, _ctcp_, raic_, zuvi, 
   {{0xbdd8033b,0x1a04035b,0x48e46e27,0x09c40456}},	//   nsèl, доуҭ, позв, लफेय, 
   {{0xacb40131,0xdc800fc0,0x2b40078c,0x00000000}},	//   _غەرب, _иқро, paic_, --, 
   {{0x87084640,0x6458af5f,0xdce400cd,0x00000000}},	//   беев_, vuvi, _ubhā, --, 
   {{0x657806d6,0x6458e970,0xbdd8020c,0x998806be}},	//   tevh, wuvi, ksèl, qqaş_, 
   {{0x6459b75e,0x2919b75f,0xc0f40092,0x48b800fe}},	//   tuvi, _ugra_, ለግሉ_, _আশীৰ, 
   {{0x213c004c,0x65780433,0x64580194,0xd9b0030c}},	//   _revh_, revh, uuvi, _جەلد, 
   {{0x6459b760,0x65781399,0x7d05b761,0xf8d8011a}},	//   ruvi, sevh, léré, _החלמ, 
   {{0x201db762,0x442c0a73,0x37e0010b,0x98b00356}},	//   _suvi_, spf_, _чотг, _teză_, 
   {{0x7d0407ea,0xf99c067c,0x645801f4,0xb6b8011a}},	//   néré, _suèz_, puvi, _הצמי, 
   {{0xf9900375,0x201c01a9,0x00000000,0x00000000}},	//   גרת_, _quvi_, --, --, 
   {{0x60280316,0x78f8008f,0xdee8001f,0x7d0400f2}},	//   _něme, מפיו, _መላክ_, héré, 
   {{0x23b80438,0xaee400b8,0x9f58007b,0x7d05b763}},	//   _héjo_, _ruṣi, omsú_, kéré, 
   {{0x23b80098,0x7d04003e,0x201db764,0xaee400b8}},	//   _kéjo_, jéré, _tuvi_, _suṣi, 
   {{0x7d05b765,0xac94b34e,0xa3b00073,0x00000000}},	//   déré, нарш, _ऐका_, --, 
   {{0x23b801e1,0x92c00790,0xdb0c0174,0x00000000}},	//   _méjo_, _öğün, skaí, --, 
   {{0x3edc0521,0x2fd80050,0x290c02fb,0x7d04ea27}},	// [30170] _kpọọ_, _روٝد_, _údaj_, féré, 
   {{0x7d05b766,0xceb000c8,0x64480841,0xdce400b8}},	//   géré, _סיי_, _ovdi, _jahī, 
   {{0xd8781b06,0x06a803d4,0xdce40882,0xf1b0008f}},	//   تمات_, _খেলি, _mahī, עסע_, 
   {{0xff5c2776,0x3a29a11a,0x00000000,0x00000000}},	//   ngî_, _ttcp_, --, --, 
   {{0x7d046792,0x6449b767,0x79a42377,0x00000000}},	//   béré, _avdi, _ерве, --, 
   {{0xcb10025f,0x79e400dd,0x93b401fb,0x7d045fe6}},	//   _שלך_, _روزہ_, _cũn, céré, 
   {{0x53a40209,0x93b40051,0x6b90013d,0x24f4011c}},	//   дайб, _dũn, _çigü, нчър, 
   {{0x79840477,0xc2e4015b,0x98a0007f,0xc0e80092}},	//   _hajw, খেছি_, nchč_, _መራራ_, 
   {{0x79853cfa,0xdce40055,0x98a002b1,0x64490db0}},	//   _kajw, _bahī, kahī_, _evdi, 
   {{0x79840455,0xbeb80200,0xb5240408,0x00000000}},	//   _jajw, rcël, _хьак, --, 
   {{0xd3700597,0x7985b768,0x7bcc0944,0x60c402a8}},	//   _لها_, _majw, _omcu, _ƙima, 
   {{0x7985b769,0xbdd8068c,0x4f94011c,0x00000000}},	//   _lajw, ssèl, фроу, --, 
   {{0xa2942626,0x7d04003e,0x3ea01eca,0x00000000}},	//   _паці, yéré, вияг, --, 
   {{0x7984006d,0xd1f4069c,0x00000000,0x00000000}},	//   _najw, ወምቲ_, --, --, 
   {{0x7d0400e5,0x00000000,0x00000000,0x00000000}},	//   véré, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x798401f0,0x7d05b76a,0xb640001f,0x160c01ad}},	// [30180] _bajw, téré, _ሪፐብሊ, िगार_, 
   {{0x7bcce163,0x00000000,0x00000000,0x00000000}},	//   _emcu, --, --, --, 
   {{0x79840455,0x07a4034b,0x7d040438,0xa2d40709}},	//   _dajw, мажн, réré, _बेन्, 
   {{0xdee8044e,0x7d05539d,0x00000000,0x00000000}},	//   _መላእ_, séré, --, --, 
   {{0x7984009a,0x7d04004a,0x3bd4031c,0x00000000}},	//   _fajw, péré, għqu_, --, 
   {{0xa7840171,0x00000000,0x00000000,0x00000000}},	//   _šķīb, --, --, --, 
   {{0xb8f00154,0xdce400ef,0x00000000,0x00000000}},	//   _হু_, _rahī, --, --, 
   {{0xe3b80213,0x00000000,0x00000000,0x00000000}},	//   _atır_, --, --, --, 
   {{0xdce40a26,0x9f540008,0x06840166,0x05649c9d}},	//   _pahī, ófíl_, _юган, _ован, 
   {{0x66e4005e,0x602800bc,0x25098956,0xa2d40037}},	//   _жоға, _němc, _فرضی_, _बइठ्, 
   {{0x3954025f,0xdef8044e,0xdb0c0162,0xdce40055}},	//   ושים_, ለይን_, ikaá, _vahī, 
   {{0x3390007b,0x78a00847,0x00000000,0x00000000}},	//   _للمز, änvi, --, --, 
   {{0x67f800d2,0x98a000b0,0xdb0c0174,0x25ac01ef}},	//   gíji, tahī_, kkaá, _kodl_, 
   {{0xf19000c7,0x25ac0162,0xc0d40023,0x00000000}},	//   _аишь, _jodl_, ርሰር_, --, 
   {{0x79840100,0x703400e3,0xf9600133,0xfba800c0}},	//   _rajw, _قسيس_, ێنرێ, отай_, 
   {{0x2cac01e6,0x7984017a,0x00000000,0x00000000}},	//   ädda_, _sajw, --, --, 
   {{0x3f980309,0xc0f4001f,0x7984033b,0xdd940006}},	// [30190] _inqu_, ለውም_, _pajw, _запы, 
   {{0x79840477,0x6f000790,0x98e400fb,0x00000000}},	//   _qajw, ümce, нсеһ, --, 
   {{0xdb1c03cd,0xf8480024,0x00000000,0x00000000}},	//   _omsø, ючай_, --, --, 
   {{0x7bcc2747,0x79840784,0xaad007d0,0xf09000d9}},	//   _umcu, _wajw, _सेवक, כנע_, 
   {{0xcb34025f,0x7985b76b,0x7bdc1cdf,0x1fc00eac}},	//   _ראשי_, _tajw, mnqu, _উদাস, 
   {{0xd7c85c81,0xd5e405f5,0x65953566,0x00000000}},	//   _کوره_, эжли, качу, --, 
   {{0x6d3c011a,0x3bd4031c,0x00000000,0x00000000}},	//   חתונ, sħqu_, --, --, 
   {{0xd2a8023a,0x528400db,0x52a80395,0x2cac0174}},	//   зкие_, егиб, звим_, øddi_, 
   {{0x758015cf,0x645c1121,0xd1b87d5d,0x66f40075}},	//   _аңла, _årin, كادا_, _апту, 
   {{0x7bdc002f,0x15140024,0x00000000,0x00000000}},	//   hnqu, _здзя, --, --, 
   {{0x628003a2,0x6724245e,0x659400d8,0x00000000}},	//   awmo, žije, _јаху, --, 
   {{0x8fa5b76c,0x291c030a,0xf0fc0037,0x00000000}},	//   хаме, ñvaz_, _उरीद_, --, 
   {{0xfce0013e,0x00000000,0x00000000,0x00000000}},	//   ҳоро, --, --, --, 
   {{0x92c01ae6,0x7bdc0472,0xe3b80166,0x00000000}},	//   ığın, enqu, _utır_, --, 
   {{0xc0d40201,0xfce1b76d,0xddcc084c,0x48b800fe}},	//   ርተር_, горо, _spaţ, _আশ্ৰ, 
   {{0xa2d4069f,0x00000000,0x00000000,0x00000000}},	//   _बेड्, --, --, --, 
   {{0xdbdc08a7,0x2fc08186,0x8a043da1,0xec180166}},	// [301a0] ráðs, _ilig_, езае, зеңә_, 
   {{0x6f040928,0x291db76e,0x65b40109,0x4c84e4c1}},	//   _izic, øva_, _tàhi, _злов, 
   {{0x2fc0af49,0xc1700375,0xe3b80166,0xaad007f7}},	//   _klig_, רחב_, _otıp_, _सेरक, 
   {{0x2fc0003e,0xddcc00ef,0xdb0c010e,0x00000000}},	//   _jlig_, _ipaš, lhaý, --, 
   {{0xdee802d3,0xe3b800fd,0xc76404da,0x25ac02f0}},	//   _መላኺ_, _buın_, _ۋارى, _podl_, 
   {{0xe3b83279,0x2fc000db,0xa4d40845,0xe73800ec}},	//   _atıp_, _llig_, колі, _ڊيسڪ_, 
   {{0xa3cc0d2b,0x6f0401ef,0x00000000,0x00000000}},	//   रफल_, _lzic, --, --, 
   {{0x6f040b6f,0xd36c6073,0x02a40139,0x99880113}},	//   _ozic, قۇم_, ером, mpaš_, 
   {{0xd36c049e,0x6f040223,0x60c40198,0x6aa40077}},	//   تۇن_, _nzic, _ƙimo, nxif, 
   {{0x2fc1b76f,0x00000000,0x00000000,0x00000000}},	//   _alig_, --, --, --, 
   {{0x6f040df9,0x2fc00793,0x9f340220,0x998803f0}},	//   _azic, _blig_, кені, npaš_, 
   {{0x443c009a,0x2fc00076,0xdb1c022c,0xfafc002e}},	//   _iwt_, _clig_, _umsø, _mbër_, 
   {{0xc6680020,0xddcdb770,0xd24400c7,0x443c005c}},	//   _አሜሪካ_, _apaš, _амчқ, _hwt_, 
   {{0x6f0405b8,0x2fc00998,0x99880309,0x443c010e}},	//   _dzic, _elig_, kpaš_, _kwt_, 
   {{0x6f040912,0x2fc0a46e,0xbc040108,0x00000000}},	//   _ezic, _flig_, ечай, --, 
   {{0x7bdc00a7,0x2fc00076,0xa3c032c6,0x3e68014b}},	//   unqu, _glig_, ँसि_, _ешон_, 
   {{0x443c0263,0x20080055,0x00000000,0x00000000}},	// [301b0] _lwt_, _ihai_, --, --, 
   {{0x64580e04,0xe9f802dd,0x00000000,0x00000000}},	//   krvi, енуі_, --, --, 
   {{0x200807ae,0x443c0175,0xa3c0000d,0x69c00153}},	//   _khai_, _nwt_, ँसा_, _įmet, 
   {{0x20080218,0xe3b8013d,0x00000000,0x00000000}},	//   _jhai_, _suın_, --, --, 
   {{0x645804cc,0x38a8180f,0xe6942bbd,0x00000000}},	//   ervi, fòrç_, лицы, --, 
   {{0xb90403f4,0x443db771,0xa2c42802,0x58d40107}},	//   _পর_, _bwt_, िनन्, _ҷоҳт, 
   {{0x443db772,0x2008035b,0x58d401af,0x00000000}},	//   _cwt_, _ohai_, _ровт, --, 
   {{0x2009b773,0xf77025aa,0x443cb594,0x3940dca0}},	//   _nhai_, _حاس_, _dwt_, _hejs_, 
   {{0x645800f5,0xdb0c03b2,0xc24000cf,0x00000000}},	//   arvi, skaæ, анык, --, 
   {{0x200800c7,0x2fc001ab,0x00000000,0x00000000}},	//   _ahai_, _slig_, --, --, 
   {{0x2fc00190,0x443c32a7,0x3168033f,0x2008045a}},	//   _plig_, _gwt_, ęcz_, _bhai_, 
   {{0x2009b774,0x394004cc,0x249800e4,0x00000000}},	//   _chai_, _lejs_, _árma_, --, 
   {{0xddcc22c1,0xaad000e1,0x62340884,0x7648007c}},	//   _spaš, _सेंक, _бечу, nsgy, 
   {{0xfd640943,0xe1e82160,0x2009b775,0x86580375}},	//   _khuṱ, _كىنو_, _ehai_, ודשי, 
   {{0xe1f00014,0x200801ab,0x98b00210,0xc5f005d0}},	//   _اسن_, _fhai_, _tezę_, ידך_, 
   {{0x16200316,0x2fc001bf,0x7d043bed,0x7648007c}},	//   मदार_, _ulig_, _sérí, ksgy, 
   {{0x193804ce,0x99880784,0xbd846103,0xc96421ee}},	// [301c0] _ｔｖｋ_, wpaš_, رچین_, квай, 
   {{0x200803f9,0x0c240fc0,0x64598456,0x7648007c}},	//   _zhai_, _имон, yrvi, dsgy, 
   {{0x6e25b776,0xbf98045f,0x6aa400db,0xdb0c0784}},	//   _huib, blêd, sxif, ykaç, 
   {{0x6e25b777,0x99880784,0x20080200,0x2cac0174}},	//   _kuib, rpaš_, _xhai_, øddu_, 
   {{0x443c2f2b,0x3940041a,0x069824e0,0x46d00f44}},	//   _swt_, _fejs_, بخات_, _देशह, 
   {{0xd90c006c,0xc0c002d3,0x6458b2a7,0x99880784}},	//   _کیم_, _ስርሑ_, trvi, ppaš_, 
   {{0x2cb801ab,0x443c020c,0x645801a4,0x6e2437a8}},	//   nyrd_, _qwt_, urvi, _luib, 
   {{0x6e24003a,0xc764005e,0x6458248f,0x00000000}},	//   _ouib, _جاسى, rrvi, --, 
   {{0x20080cfd,0xfbd0025f,0xbdd82d7d,0xdb0c7aa0}},	//   _rhai_, יתה_, rrèz, rkaç, 
   {{0x68fc138f,0x20080652,0xf8ac0014,0xbf98017a}},	//   _kyrd, _shai_, _اکے_, ilêe, 
   {{0x2009b778,0x443c01c8,0x6e24003a,0x7c3801fa}},	//   _phai_, _uwt_, _auib, ćurk, 
   {{0x68fdb779,0x6e245318,0xde583981,0xe6f4031c}},	//   _myrd, _buib, намі_, _བཪྙན_, 
   {{0x6e2591d0,0xa158bbc1,0x00000000,0x00000000}},	//   _cuib, _залу_, --, --, 
   {{0x20081f4c,0x6e25b77a,0xbf98017a,0xc19002f2}},	//   _whai_, _duib, dlêe, _ئیدع, 
   {{0x3941b77b,0x20082517,0x6e200077,0x2cb803b2}},	//   _rejs_, _thai_, ímbr, gyrd_, 
   {{0x200978c0,0x00000000,0x00000000,0x00000000}},	//   _uhai_, --, --, --, 
   {{0x6e25b77c,0xdb1c05d5,0xfafc0240,0x2cb80076}},	// [301d0] _guib, _imsü, _ecën_, ayrd_, 
   {{0x68fd38b0,0x693401c4,0x00000000,0x00000000}},	//   _byrd, инуу, --, --, 
   {{0xa2d40027,0x68fc0042,0x394000b5,0xd9d015bf}},	//   _बेस्, _cyrd, _vejs_, لەڭگ, 
   {{0x68fd4740,0x764801bf,0x3dcc012d,0x00000000}},	//   _dyrd, tsgy, żową_, --, 
   {{0xe785b77d,0xf0fc00af,0x00000000,0x00000000}},	//   рухо, _उर्द_, --, --, 
   {{0xa935b77e,0xe61802bf,0x68fdb77f,0xe6b40131}},	//   _верш, вді_, _fyrd, شلىگ, 
   {{0xb4c00032,0xbdd8007f,0x68fdb780,0x76484cab}},	//   рийҙ, bsèv, _gyrd, ssgy, 
   {{0xfd641aa1,0xdb0c030a,0x61f80200,0x00000000}},	//   _vhuṱ, lhañ, _akvl, --, 
   {{0xd5c40408,0x9f5c01e1,0x00000000,0x00000000}},	//   _кiан, _òwù_, --, --, 
   {{0x6e25b781,0x7e6c02d0,0x00000000,0x00000000}},	//   _ruib, dtcp, --, --, 
   {{0x6e249a14,0xf1c00153,0xf2e401b9,0x537401ee}},	//   _suib, _ryšį_, رکچه_, _булђ, 
   {{0xc43806a9,0x6e2401e7,0x00000000,0x00000000}},	//   _נתני, _puib, --, --, 
   {{0x6e240de4,0x9f8805bb,0xe18800dd,0xe4100131}},	//   _quib, _kûê_, رئین_, _بېيج, 
   {{0x6e240a73,0x4250380e,0x23b801e1,0x2cb801e3}},	//   _vuib, _انور, _réji_, tyrd_, 
   {{0xc170011a,0x00000000,0x00000000,0x00000000}},	//   _לחג_, --, --, --, 
   {{0x2d8db782,0x6e240a73,0x0ba82f7c,0xdcf4005f}},	//   žde_, _tuib, رازى_, edzē, 
   {{0x7e94a534,0x68fdb783,0x46d000af,0xdcf4054e}},	// [301e0] _منير_, _syrd, _देंह, teză, 
   {{0x68fc03a2,0xd5b001fb,0x2a6001ab,0xdb1c08a5}},	//   _pyrd, _nó_, ruib_, _umsý, 
   {{0x6fd80073,0x645c0139,0x00000000,0x00000000}},	//   _ढगां, _ärix, --, --, 
   {{0x46e9b784,0x68fc05ac,0xc669b785,0x06e800ee}},	//   нден_, _vyrd, ешке_, нмек_, 
   {{0x7f3800c8,0xd1e402d3,0x68fc0368,0xd5b00051}},	//   גענו, _ዛጊት_, _wyrd, _bó_, 
   {{0xdb0db786,0xd5b00016,0xbdd8007f,0x02a401d5}},	//   chañ, _có_, ssèv, ғрим, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7f980724,0xa81805d9,0xd39800fd,0xbdd8007f}},	//   _mäqä, _شڪار_, кәчә_, lsèt, 
   {{0xbeb802d3,0x3f8c00c7,0xa2d40b4c,0x00000000}},	//   ncët, _ógui_, _बेश्, --, 
   {{0xc059b787,0xa074e91f,0xbdd802e2,0x81680107}},	//   нім_, агоч, nsèt, хриб_, 
   {{0xdfd0215e,0xa2d43b16,0x00000000,0x00000000}},	//   قيد_, _बेर्, --, --, 
   {{0x02040220,0xdb0c0165,0xa2c4095f,0x00000000}},	//   _өзен, zhañ, िनद्, --, 
   {{0x8174014b,0x00000000,0x00000000,0x00000000}},	//   _балӣ_, --, --, --, 
   {{0xbb19b788,0xa1583334,0x7c85b789,0x98ac00bc}},	//   _maît, _раку_, лубе, _řeč_, 
   {{0x9f34005e,0x3ebc4b16,0x00000000,0x00000000}},	//   _кейі, šut_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbb18004a,0xaa582bbd,0x0ba400c7,0x00000000}},	// [301f0] _naît, литу_, шырҭ, --, 
   {{0xdcf4005f,0x7f98013d,0x78e80104,0x85400153}},	//   udzē, _fäqä, ньев_, šėja, 
   {{0xdb0c03b2,0x97f800e5,0x00000000,0x00000000}},	//   nkaú, نکرز_, --, --, 
   {{0x9f480093,0x780c0807,0x23b80098,0x973404d3}},	//   _akaú_, िषेक_, _kéju_, شکرا, 
   {{0xdb0c0054,0xa2d5b78a,0x75fc002d,0x657c00e5}},	//   phañ, _बेल्, lêzi, _űrha, 
   {{0xdb0db78b,0xc5ec004b,0xd5b00051,0x00000000}},	//   qhañ, وړل_, _tím_, --, 
   {{0x75fc002d,0xb77402dd,0x53a48e43,0xb4bc12eb}},	//   nêzi, _бөлу_, иакб, ँने_, 
   {{0xdb1c26b8,0xbb18004a,0xb3a000d1,0xe81801c6}},	//   _umsó, _faît, слиһ, _босч_, 
   {{0x290c0597,0xbb180129,0xbdd8007f,0xe694005b}},	//   _údar_, _gaît, nsès, _литы, 
   {{0xd0942123,0x918000cf,0x00000000,0x00000000}},	//   ашмы, زۇبۇ, --, --, 
   {{0x23840014,0x2458030d,0x8fa400cf,0x9104003b}},	//   _گٔنِ, _бахь_, аане, рпне, 
   {{0x52d8034b,0xbdd80066,0xdb1c02d2,0x00000000}},	//   _имею_, ksès, _alsí, --, 
   {{0x8e747390,0x00000000,0x00000000,0x00000000}},	//   шунч, --, --, --, 
   {{0xdce4007f,0x412400f7,0xcdf401c6,0x22400200}},	//   _echč, _кошо_, рчмы, _çika_, 
   {{0x8c45b78c,0x8b2401ee,0x00000000,0x00000000}},	//   ребе, идве, --, --, 
   {{0xc0500302,0xfbc0a68e,0x00000000,0x00000000}},	//   _וזה_, обсо, --, --, 
   {{0x27ec03b2,0xe3b80166,0x88b000cc,0x7f98008e}},	// [30200] _ídni_, _suık_, _টেংক, _wäqä, 
   {{0xc8940b3e,0x00000000,0x00000000,0x00000000}},	//   ирењ, --, --, --, 
   {{0x87249120,0x88840395,0x00000000,0x00000000}},	//   амеж, рлеж, --, --, 
   {{0xbdd8180f,0x5ec80154,0x00000000,0x00000000}},	//   ssèt, রপরে, --, --, 
   {{0x6b85b78d,0xe53432eb,0x672405be,0x7dc80254}},	//   meig, бель, žijo, _düsf, 
   {{0xbdd8067c,0xa2c411bc,0x00000000,0x00000000}},	//   lsèr, िनस्, --, --, 
   {{0x03c5b78e,0x3445b78f,0x8bfc009e,0xbeb8036e}},	//   исим, ачын_, ংগঠন_, ncër, 
   {{0xbdd8ff24,0x998800d0,0xa6c800f1,0x00000000}},	//   nsèr, rpať_, _یوځل_, --, 
   {{0xc1a41677,0x998800d0,0x00000000,0x00000000}},	//   ајни, spať_, --, --, 
   {{0x6b85b790,0x00000000,0x00000000,0x00000000}},	//   heig, --, --, --, 
   {{0x5f940276,0xd4d40953,0x6b840076,0xc0c80114}},	//   бинт, _ліцэ, keig, тупе_, 
   {{0x6b85b791,0x00000000,0x00000000,0x00000000}},	//   jeig, --, --, --, 
   {{0x6b85b792,0x9324182f,0x22580a8f,0x2004005f}},	//   deig, _ارمن, _силы_, ēli_, 
   {{0x01e400ee,0xb2b8011a,0xd5c40354,0x00000000}},	//   _өйҗү, _במדר, _кiен, --, 
   {{0xceb4767b,0x6b85b793,0xdb0c03b2,0x31340677}},	//   _һәр_, feig, lkaø, _דרוך_, 
   {{0x6b85b794,0x2ba40261,0xf454011a,0x00000000}},	//   geig, ојув, יילר_, --, 
   {{0xac1931c6,0xceb41cd1,0x248c0240,0x00000000}},	// [30210] роту_, _ләр_, _lsdm_, --, 
   {{0x3945b795,0x780c00ce,0xbc240014,0x6028013a}},	//   úns_, िष्क_, _پردى, _němk, 
   {{0x6b85b796,0xbdd800cf,0x7c8404c2,0x00000000}},	//   beig, bsèr, _тупе, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7dc80254,0x9474cfad,0x00000000,0x00000000}},	//   _düsg, مدبا, --, --, 
   {{0xbdd806af,0x248c0332,0x69bc0073,0xd79402e8}},	//   nsèq, _csdm_, _शकती, _ливъ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe73022d2,0x248c6368,0x3568030d,0x7dc803b9}},	//   _آصف_, _esdm_, _арен_, _küsd, 
   {{0x6b8409f0,0x00000000,0x00000000,0x00000000}},	//   zeig, --, --, --, 
   {{0x6b84009f,0x9f5800c7,0x00000000,0x00000000}},	//   yeig, mosê_, --, --, 
   {{0xe2a80014,0xed5001d9,0x00000000,0x00000000}},	//   _چاون_, ژھج_, --, --, 
   {{0x6b85b797,0x920400b8,0xe2a801d9,0x333c002e}},	//   veig, _apāś, _ناون_, mbux_, 
   {{0x8c4401e0,0xd258007f,0x333c031c,0xacc8009d}},	//   йеге, ryņd_, lbux_, аггv, 
   {{0x6b85b798,0xdb1c068c,0x777801e2,0x4b54020a}},	//   teig, _alsà, _obux, йъат, 
   {{0xbdd80ba1,0xbeb80240,0x0054011a,0x00000000}},	//   usèr, rcër, _השקת_, --, 
   {{0x6b85b799,0x7f38008f,0xba2000f7,0xbdd80561}},	// [30220] reig, _געפו, здук, rsèr, 
   {{0x6b85b79a,0xbdd8180f,0x49940114,0x00000000}},	//   seig, ssèr, љшат, --, 
   {{0x291db79b,0x6b85b79c,0x00000000,0x00000000}},	//   äva_, peig, --, --, 
   {{0x8d7404d3,0x78a00267,0xe73800c7,0x00000000}},	//   _ئاکا, ånva, рҵа_, --, 
   {{0x2b41b79d,0xf8ac00aa,0x248c05b1,0xe9a80014}},	//   mbic_, وکې_, _ssdm_, _پۯان_, 
   {{0xbdd81f5d,0xa438234c,0xe3b8008e,0x7d78010f}},	//   nsèp, азку_, _utız_, ָנקו, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc32c6923,0x2b407851,0x2a60003a,0x64a802c3}},	//   رەت_, nbic_, orib_, _कपीश, 
   {{0x7dc8418f,0x06e98234,0x46e80108,0x00000000}},	//   _hüse, _смак_, _сдан_, --, 
   {{0x61d8020a,0x0188023a,0x7dc81ea0,0x2054447e}},	//   рмоя_, ущий_, _küse, окоя, 
   {{0x333db79e,0x85040472,0x2a600010,0x95c80798}},	//   bbux_, _اوان, hrib_, _туѓа_, 
   {{0x2a60007f,0x7dc9b79f,0xbfa80108,0x00000000}},	//   krib_, _müse, утое_, --, 
   {{0x2b400010,0x9f580200,0x00000000,0x00000000}},	//   dbic_, losë_, --, --, 
   {{0x7de40220,0x6d340139,0x2b400076,0x00000000}},	//   сімд, зерф, ebic_, --, 
   {{0xc0583334,0x7dc801b8,0x2a6000af,0x61e80472}},	//   _сіл_, _nüse, erib_, mndl, 
   {{0xeb48177b,0xdce400cd,0x7dc800a2,0xafe4009b}},	//   йчук_, _cchā, _süsd, _нојл, 
   {{0x2a61b7a0,0xaa5c02dd,0x59d80006,0xdd940153}},	// [30230] grib_, летi, адаў_, _дапы, 
   {{0x7f4db7a1,0x1958d982,0x8a78013e,0x61e8009a}},	//   lacq, ражы_, рифӣ_, nndl, 
   {{0x61e9b7a2,0x1a649c96,0x2a60058a,0x920400cd}},	//   indl, _ژیری_, arib_, _upāś, 
   {{0x7f4c86ed,0x7dc9b7a3,0xfbf00107,0x00000000}},	//   nacq, _düse, _хомӯ, --, 
   {{0x7bddb7a4,0x96640220,0x65b802dd,0x00000000}},	//   miqu, ікке, әуір_, --, 
   {{0x7bddb7a5,0x35f800f2,0x00000000,0x00000000}},	//   liqu, درصد_, --, --, 
   {{0x996400bc,0x7dc803e0,0x7bdc0051,0x00000000}},	//   _kůži_, _güse, oiqu, --, 
   {{0x7bddb7a6,0x77784b2a,0x61e9b7a7,0xdb0c01e1}},	//   niqu, _ubux, endl, _òkók, 
   {{0xd1b93b7b,0x7dc800ac,0xd1c88954,0x961c005f}},	//   لادا_, _müsb, илие_, _apņe, 
   {{0x7bddb7a8,0x42040212,0x333c0327,0x3cfc00cd}},	//   hiqu, жньо_, sbux_, _शुभे_, 
   {{0x7bdc0986,0x4fe9b7a9,0x680c00a2,0xe57157d5}},	//   kiqu, имон_, _aşdy, _سطل_, 
   {{0x61e80037,0x00000000,0x00000000,0x00000000}},	//   andl, --, --, --, 
   {{0x7bddb7aa,0xda080490,0xeae4015b,0xbf9800d8}},	//   diqu, वतात_, _মর্ম, plên, 
   {{0x98a0003a,0x90c401ee,0x5044014b,0x00000000}},	//   schę_, _мбле, _декб, --, 
   {{0x7bddb7ab,0x7f4c02e8,0xcfa8a55b,0xd10c05b5}},	//   fiqu, bacq, _ناظم_, _हरिण_, 
   {{0x7bddb7ac,0x2a61b7ad,0x7dc8000d,0x34a8002b}},	//   giqu, trib_, _rüse, _kāṇḍ, 
   {{0x4aa89480,0x7dc8013d,0x00000000,0x00000000}},	// [30240] шкан_, _süse, --, --, 
   {{0xdcf42fbe,0x6f05b7ae,0x203c001f,0x2b4000db}},	//   _çağr, _iyic, _የተቀየ, sbic_, 
   {{0x7bdd2d21,0x08882078,0x00000000,0x00000000}},	//   biqu, рбей_, --, --, 
   {{0x7bddb7af,0x86c45a16,0xf74000d8,0x00000000}},	//   ciqu, ييان, децо, --, 
   {{0x363000f1,0xe53484da,0x6f000112,0xdb1c08a5}},	//   وروس, пель, ümch, _alsæ, 
   {{0xfe98008d,0x75d000c6,0x3a2001a4,0xfc48fc95}},	//   יינמ, وينا, _gijp_, říž_, 
   {{0x69dc0597,0x645c01e4,0x602800bc,0x4adc00c5}},	//   _imre, _ĥris, _těmi, _नेतव, 
   {{0x6f040921,0x9f580240,0x61e8062c,0x00000000}},	//   _oyic, rosë_, wndl, --, 
   {{0x6f05b7b0,0x69dc0263,0x34a8002b,0xaabc013a}},	//   _nyic, _kmre, _cāṇḍ, ोनिक, 
   {{0x61e9b7b1,0x7dc804cc,0x7bddb7b2,0x34a80055}},	//   undl, _müsc, ziqu, _dāṇḍ, 
   {{0xc0e8044e,0x6f042939,0x69dc013f,0x7bddb7b3}},	//   _መራሒ_, _ayic, _mmre, yiqu, 
   {{0x93252931,0x6f040230,0x7bdcf2cb,0x64480455}},	//   _فرهن, _byic, xiqu, _iwdi, 
   {{0x69ddb7b4,0x6f040796,0x7f4c19f5,0x64480142}},	//   _omre, _cyic, racq, _hwdi, 
   {{0x71f46f80,0x7bddb7b5,0xeae400fe,0x00000000}},	//   _وروس_, wiqu, _মৰ্ম, --, 
   {{0x7bddb7b6,0x6f04209c,0x3a200d27,0x7f4c014b}},	//   tiqu, _eyic, _rijp_, pacq, 
   {{0x5a3418b6,0x7dc80ccc,0x69ddb7b7,0x3a28c5e5}},	//   знат, _büsc, _amre, _pucp_, 
   {{0x7bddb7b8,0x3a200d27,0x8e800354,0x6fa80210}},	// [30250] riqu, _pijp_, _пӳре, गारं, 
   {{0x7bddb7b9,0x940c013f,0x64480009,0x20180254}},	//   siqu, _ɛnɑm_, _owdi, lmsi_, 
   {{0x7bddb7ba,0x9bc000db,0xed3400e5,0x00000000}},	//   piqu, _كەسۉ, _توپھ, --, 
   {{0x2019132a,0x69ddb7bb,0x48bc0c58,0xbdd80066}},	//   nmsi_, _emre, ্পূৰ, spèd, 
   {{0x6449b7bc,0x53a81d8a,0x36892975,0xe79800c6}},	//   _awdi, कासश, рсен_, تخلص_, 
   {{0x6448015d,0xdcf400e2,0x662400d1,0x00000000}},	//   _bwdi, jdzī, ۋرۈك, --, 
   {{0xddcc1fe6,0x9f58067c,0xfbbc07b6,0xd04006be}},	//   _opaž, posè_, _एकाम, bzlə, 
   {{0x34a80882,0x629c0374,0xdcf40171,0x00000000}},	//   _pāṇḍ, āron, edzī, --, 
   {{0x91e50239,0x64480327,0x3cf00393,0x69dc0b88}},	//   зопе, _ewdi, _lxxv_, _ymre, 
   {{0x6f040223,0x20180ba7,0x9f480055,0xd1c801f4}},	//   _ryic, emsi_, _ekaü_, слое_, 
   {{0x64480042,0x842000f1,0x10a42bb7,0xead00ca8}},	//   _gwdi, _ګډون, чинн, bẹwo_, 
   {{0xbf980129,0x95c80961,0x60280118,0x34a80055}},	//   blêm, _туға_, _němu, _tāṇḍ, 
   {{0x7ec000b8,0xfbdc000d,0x0ec40d2e,0x00000000}},	//   _nįpā, _नग़म, रैंड, --, 
   {{0x2019b7bd,0x6f0400ca,0xa2d400af,0x64600024}},	//   amsi_, _vyic, _बेट्, ūziš, 
   {{0x3cf00393,0x49c801ec,0x00000000,0x00000000}},	//   _cxxv_, ұлан_, --, --, 
   {{0x69dc8c05,0x7dc805d5,0x67240558,0x9f58020c}},	//   _smre, _püsc, žiji, yosé_, 
   {{0x6f043b6a,0x49c8013e,0xbe3000db,0xbb5000ae}},	// [30260] _uyic, блан_, _كىيب, عنكب, 
   {{0x25e05d9c,0x4d6401f4,0x00000000,0x00000000}},	//   _औषधी_, _эков, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2d982d75,0xd90c01b9,0x64480142,0xfd4c002b}},	//   ldre_, شیق_, _rwdi, dakṛ, 
   {{0x6595b7be,0x7dc80205,0x0aa00139,0x7aa001af}},	//   далу, _hüsa, _яңаү, _зияз, 
   {{0x2d99b7bf,0x6448015d,0x9f587c6e,0x7c5402f2}},	//   ndre_, _pwdi, rosé_, _بلێر_, 
   {{0x87b8084c,0xdb1d4e32,0x6fcc08a3,0x00000000}},	//   _луат_, _elsä, ासां, --, 
   {{0x7dc9b7c0,0x9f5820ef,0xc0c00020,0x337002e8}},	//   _müsa, posé_, _ድርሻ_, егър, 
   {{0xbdd8007f,0xd5b00051,0x00000000,0x00000000}},	//   npèc, _pít_, --, --, 
   {{0xdcf4005f,0xe1d802bf,0x00000000,0x00000000}},	//   udzī, ідні_, --, --, 
   {{0xdcf400da,0x0325802b,0x7998010f,0x80a403ce}},	//   rdzī, _еден, זשיס, गमें, 
   {{0x74105734,0x43d4038b,0x6d5800e4,0x2d980171}},	//   _كولا, _عزاز, _ŷvap, edre_, 
   {{0x4425a076,0x7ce00139,0xa2d400bc,0x53a8043e}},	//   _iio_, _kеrg, _बेच्, कारश, 
   {{0x4425b7c1,0x57b81af8,0x7dc806be,0x3a3c0200}},	//   _hio_, _आव्ह, _büsa, _çupi_, 
   {{0x442404ac,0x63a401ab,0x71780375,0x932400db}},	//   _kio_, _òins, _הנוס, _فرۇن, 
   {{0x2d99b7c2,0x4425b7c3,0x4adc02a0,0xf990029c}},	//   adre_, _jio_, _नेहव, کبر_, 
   {{0x4425b7c4,0x3f880e3c,0x00000000,0x00000000}},	// [30270] _mio_, mecu_, --, --, 
   {{0x4425b7c5,0x98e400fb,0x00000000,0x00000000}},	//   _lio_, мсеһ, --, --, 
   {{0x44240093,0x47b402f5,0xd75802c9,0x9d19319e}},	//   _oio_, ংসনী, قلات_, _фонт_, 
   {{0x2cac78d0,0xd78400db,0xe75800d4,0x00000000}},	//   ådde_, بەرۉ_, зиці_, --, 
   {{0xcb980302,0x7ce01eca,0x996400bc,0x00000000}},	//   _וסרט, _bеrg, můžu_, --, 
   {{0x4425b7c6,0x59c00118,0x00000000,0x00000000}},	//   _aio_, _शकिर, --, --, 
   {{0x0595b7c7,0x3f881155,0x00000000,0x00000000}},	//   بانگ, kecu_, --, --, 
   {{0x4424a2ea,0x3f888185,0xd7c88863,0x2d980419}},	//   _cio_, jecu_, _بوره_, zdre_, 
   {{0x3f881050,0x2d983c02,0xf52428a8,0x52a800d4}},	//   decu_, ydre_, _ефен, івом_, 
   {{0xdb0c0054,0x5554034c,0x00000000,0x00000000}},	//   nkañ, _آپار, --, --, 
   {{0x4425b7c8,0xe28002dd,0x00000000,0x00000000}},	//   _fio_, _ұғын, --, --, 
   {{0x3370010a,0x00000000,0x00000000,0x00000000}},	//   _чӳкр, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4425b7c9,0x2d9806af,0x00000000,0x00000000}},	//   _zio_, udre_, --, --, 
   {{0x8b94277c,0xe3b8013d,0x44240cad,0x0ba86c68}},	//   мрач, _kuıp_, _yio_, يارى_, 
   {{0x7dc80213,0x00000000,0x00000000,0x00000000}},	//   _vüsa, --, --, --, 
   {{0x3b0406bb,0xfbdc8109,0x00000000,0x00000000}},	// [30280] дето_, _नगरम, --, --, 
   {{0xc98400c6,0x7dc83535,0x7ce01eca,0x602800bc}},	//   بشري, _hüsn, _bеrd, _těmt, 
   {{0x7dc9b7ca,0x19b802bf,0xbdd81497,0x48bc0183}},	//   _küsn, чуть_, spèc, ্প্ৰ, 
   {{0x2e3401b8,0xad440137,0x00000000,0x00000000}},	//   _käf_, _تىگۉ, --, --, 
   {{0x44256223,0xdb4c0014,0x7dc806be,0x00000000}},	//   _rio_, _دێق_, _müsn, --, 
   {{0x4425b7cb,0x3f880e3c,0x00000000,0x00000000}},	//   _sio_, zecu_, --, --, 
   {{0x4424123c,0xc7640075,0xe3b80166,0x53a8078a}},	//   _pio_, _يارى, _buıp_, कांश, 
   {{0x7aec1ebd,0x44240286,0x2918033f,0xddcc0327}},	//   šitš, _qio_, ągać_, _spaż, 
   {{0xdb0c0436,0x2e3407c5,0x3f88026c,0x00000000}},	//   nkað, _näf_, vecu_, --, 
   {{0xdb1c0158,0x6028002b,0x7ce0022e,0x03900248}},	//   _ulså, _aśma, _yеrd, _ṣọọb, 
   {{0x4425b7cc,0xf9900375,0x3f89b7cd,0xf0d0009d}},	//   _tio_, דרת_, tecu_, вжээ, 
   {{0x443db7ce,0xdb0c1f60,0x4425b7cf,0xbd840092}},	//   _itt_, kkað, _uio_, _ሕዝቡም_, 
   {{0x3f880e3c,0xd2580100,0xf77c0139,0x00000000}},	//   recu_, nyņl_, _öçe_, --, 
   {{0x443db7d0,0x9f5835f5,0x2e340139,0xa03400cf}},	//   _ktt_, mosí_, _däf_, _كىتت, 
   {{0x9f580093,0x443db7d1,0xe3b80166,0x72005874}},	//   losí_, _jtt_, _yuıp_, _جووم, 
   {{0x5f9400a7,0x5bc81c54,0x00000000,0x00000000}},	//   _чиит, रसेव, --, --, 
   {{0xbbbc146c,0xdb0c0227,0xda141677,0x9f5802f0}},	// [30290] _एकीक, tkañ, едањ, nosí_, 
   {{0x443db7d2,0x64588ebc,0x00000000,0x00000000}},	//   _ott_, ksvi, --, --, 
   {{0x443db7d3,0xdb0db7d4,0xa3c0045b,0x645801f5}},	//   _ntt_, rkañ, ुसा_, jsvi, 
   {{0xdb0c0bc9,0x00000000,0x00000000,0x00000000}},	//   skañ, --, --, --, 
   {{0x443db7d5,0x0af0152d,0x958446bf,0x6459b7d6}},	//   _att_, _бүтэ, елле, esvi, 
   {{0xbb18145e,0x443c1c69,0x645808a5,0x00000000}},	//   _gbîa, _btt_, fsvi, --, 
   {{0x64595455,0x6bd404d3,0x46f00075,0x88804d66}},	//   gsvi, _ستێر, نۋېر, _میلن, 
   {{0x443c011c,0xf7700220,0xabcc008f,0xe3b8013d}},	//   _dtt_, _جاس_, ַציִ, _quıp_, 
   {{0x443db7d7,0x64580660,0x41c8043e,0x00000000}},	//   _ett_, asvi, िसंस, --, 
   {{0x76580c10,0x9f4803b2,0xf500013e,0x6458365a}},	//   _ivuy, _skað_, _иҷло, bsvi, 
   {{0x443c0ecf,0x6724012c,0x6458026c,0xd009b7d8}},	//   _gtt_, žijt, csvi, зене_, 
   {{0x0eb80166,0x00000000,0x00000000,0x00000000}},	//   пугы_, --, --, --, 
   {{0x3ea0bae0,0xdea000e5,0x00000000,0x00000000}},	//   гияг, لیٹی, --, --, 
   {{0x7bcdb7d9,0x76580526,0x443c05ac,0xe8940023}},	//   _alcu, _mvuy, _ytt_, _ዘጋጥም_, 
   {{0xbdd8033b,0xc5f0011a,0x00000000,0x00000000}},	//   nsèy, אדם_, --, --, 
   {{0x8b2407b5,0x00000000,0x00000000,0x00000000}},	//   едбе, --, --, --, 
   {{0x49c9b7da,0xbdd84bc7,0x4d380138,0x6459b7db}},	// [302a0] план_, mpèn, _няня_, zsvi, 
   {{0x6459b7dc,0xdb0c31ac,0x7bccf587,0x4dd402f2}},	//   ysvi, rkað, _elcu, _ستخس, 
   {{0x7659a82a,0x7dc99d31,0xdb0c08a7,0x00000000}},	//   _avuy, _müsl, skað, --, 
   {{0x27e1b7dd,0x00000000,0x00000000,0x00000000}},	//   òin_, --, --, --, 
   {{0x443db7de,0x64580f85,0x00000000,0x00000000}},	//   _stt_, wsvi, --, --, 
   {{0x6459b7df,0x443db7e0,0xddcc00de,0x00000000}},	//   tsvi, _ptt_, _evaņ, --, 
   {{0x76580472,0xdb1c0022,0x6714072a,0x6458ac05}},	//   _evuy, _nosê, तेजक_, usvi, 
   {{0x443db7e1,0xd90ca0c8,0x9f59b7e2,0xf7500271}},	//   _vtt_, _بیم_, tosí_, _منفج, 
   {{0x6459b7e3,0x443c004d,0x36640798,0x249c0153}},	//   ssvi, _wtt_, _пато_, _žymė_, 
   {{0x645811ad,0x4544007b,0x9f5800c7,0x00000000}},	//   psvi, _أناق, kosã_, --, 
   {{0x443db7e4,0x7dc9b5a1,0x30a000a7,0xdfd520cb}},	//   _utt_, _süso, гряв, воны, 
   {{0xbbbc041c,0xde580006,0xf4854db6,0x00000000}},	//   _एकेक, мамі_, _سامی, --, 
   {{0xbb18006a,0x28d007f7,0x41e412fa,0xd0600023}},	//   _abîn, थैति, _піка, _ተደልዩ_, 
   {{0x7d006ab9,0x5bc80882,0xf1900139,0x796401e1}},	//   _ønsk, रस्व, _бишь, _méwà, 
   {{0x26ec367a,0x5ff406bb,0xc0bc08b0,0x31340375}},	//   जपुर_, _изку, ﺭﻣﻪﺗ, _ארוך_, 
   {{0x2cac0267,0x00000000,0x00000000,0x00000000}},	//   ådda_, --, --, --, 
   {{0xba7404b3,0xdb0c02d2,0x00000000,0x00000000}},	// [302b0] عارت, fjaá, --, --, 
   {{0x3f980e14,0xcdc00131,0xdb0c03b2,0x7dc84e7e}},	//   _haqu_, _кәсп, gjaá, _küsm, 
   {{0x463402d3,0x00000000,0x00000000,0x00000000}},	//   _ብሃገራ, --, --, --, 
   {{0x7bcdb7e5,0x67d5b7e6,0x1a641bc6,0x01500092}},	//   _ulcu, лоху, _لیری_, _መጠቀም, 
   {{0xa3b41b76,0x3f988da5,0x16bc00bc,0x8bb8011a}},	//   ञान_, _maqu_, ्नेब, _חזרת, 
   {{0xd914035b,0x00000000,0x00000000,0x00000000}},	//   _адгы, --, --, --, 
   {{0x52c8085c,0x00000000,0x00000000,0x00000000}},	//   िन्स, --, --, --, 
   {{0x25ac0005,0x3f98022f,0x7dc803ee,0xdb1c0022}},	//   _endl_, _naqu_, _süsl, _nosë, 
   {{0x67d4ae94,0x7659b089,0x7e6c01a6,0xbbbc00dc}},	//   _соту, _uvuy, jucp, _एकैक, 
   {{0xf77000ec,0x7dc803b9,0x10a4009b,0xdef00240}},	//   _جاڳ_, _qüsl, вион, _ቃልካ_, 
   {{0x3f98013d,0xe3b05285,0xdb1c0200,0x5ec400d1}},	//   _baqu_, _گرل_, _bosë, қирғ, 
   {{0xb4bc069f,0x7dc81f02,0xe4580212,0xd25802e2}},	//   ुनी_, _düsm, _їжі_, nyņk_, 
   {{0x3f98014f,0xbdd800db,0x23e800fb,0x59c000cd}},	//   _daqu_, rpèn, _яффо_, _एवंर, 
   {{0x9db802dd,0x629c012d,0x00000000,0x00000000}},	//   нысу_, łroc, --, --, 
   {{0x8d75b7e7,0xbdd80066,0x30cc2d40,0xfce0024c}},	//   _یادا, mpèl, ﺗﻜﻪﻧ, аоро, 
   {{0xa3b400cd,0x00000000,0x00000000,0x00000000}},	//   ञाय_, --, --, --, 
   {{0xdb1c068c,0x4df40228,0xb4bc00bc,0x4b240166}},	// [302c0] _josè, _аянт, ुनु_, тмав, 
   {{0xdb1c068c,0x2fc000ad,0xccc400c0,0x00000000}},	//   _mosè, _hoig_, _абой, --, 
   {{0x8e389ce2,0x3f980113,0x8c457646,0xdce400d7}},	//   _عسکر_, _yaqu_, _шене, _zahľ, 
   {{0x46e9b7e8,0x81c8015b,0x589400f7,0x3f98058a}},	//   мден_, রোপ_, ышуу, _xaqu_, 
   {{0xc6d406b3,0x32040118,0xdbc401d5,0xd9b00137}},	//   ختات, _okny_, _ёҳуд_, _گەلد, 
   {{0xd64400dd,0x2fc0030a,0xdb1002d2,0x8bd0000d}},	//   ائنٹ, _loig_, _ófáu, _सतुअ, 
   {{0x2fc00363,0x9f5801ed,0x7ce001d5,0xe7f40490}},	//   _ooig_, őzés_, _kеra, ेकदा_, 
   {{0xc0dc0125,0xdb1c020c,0xd04c016b,0xadc400c7}},	//   _ዓላማ_, _bosè, _ɔkɔr, _raẽv, 
   {{0x23489f6d,0xf62800db,0x00000000,0x00000000}},	//   وسکی_, ستۇۇ_, --, --, 
   {{0xdb1c020c,0x2fc000a3,0x75d021e7,0xbbbc3a62}},	//   _dosè, _aoig_, _پيما, _एक्क, 
   {{0x2fc000cf,0x3f9802d1,0xc60c47b8,0x3954123b}},	//   _boig_, _paqu_, ितीय_, כשים_, 
   {{0x2fc008c2,0x90880014,0x00000000,0x00000000}},	//   _coig_, رمُے_, --, --, 
   {{0x2fc0062c,0xdc800023,0x00000000,0x00000000}},	//   _doig_, _ሕልመይ_, --, --, 
   {{0xdd100232,0x7de402dd,0x00000000,0x00000000}},	//   _výži, тімд, --, --, 
   {{0x7ce001d5,0x9f5800db,0x6c5578d0,0xbc0400d4}},	//   _bеra, posà_, икру, вчай, 
   {{0x61e89acc,0xdb1c00f2,0x3ec40953,0x2fc000cf}},	//   lidl, _hosé, _асоб, _goig_, 
   {{0x5b15b7e9,0x200873f4,0xdb1c003e,0x6e980724}},	// [302d0] умат, _ikai_, _kosé, _авыр_, 
   {{0xdb1d1746,0xdd9000aa,0x78e85a12,0x58d875df}},	//   _josé, _اود_, мьев_, ндзя_, 
   {{0x20080093,0xa9280024,0xdb0c010e,0x00000000}},	//   _kkai_, віце_, kjaç, --, 
   {{0x61e9b7ea,0x96f80108,0x00000000,0x00000000}},	//   hidl, неет_, --, --, 
   {{0xfe7c0054,0xddcc00bc,0x62840356,0x61e8be97}},	//   ntï_, _svař, _ţion, kidl, 
   {{0xdb1c00e4,0xca78008f,0xd1e4001f,0xfe7c0022}},	//   _nosé, _אנשט, ምበት_, itï_, 
   {{0x98740020,0xb4bc454f,0x61e9b7eb,0x2009b7ec}},	//   _ያልሆኑ_, ुने_, didl, _okai_, 
   {{0xdce400dc,0x78b4e748,0xe918109a,0x81c80154}},	//   _abhī, mxxv, _росі_, রোম_, 
   {{0x13080323,0x2fc1b7ed,0xb5f00046,0x223c063f}},	//   эний_, _roig_, _күді, _pọịn, 
   {{0x2009b7ee,0x61e9b7ef,0xdb1c00e4,0x2fc00165}},	//   _akai_, gidl, _cosé, _soig_, 
   {{0xdb1db7f0,0xddcc00bc,0xbdd80561,0xf47402dd}},	//   _dosé, _uvař, rpèl, _рөлі_, 
   {{0x5275b7f1,0xbb18004a,0x61e801ab,0x00000000}},	//   _буку, _abîm, aidl, --, 
   {{0x61e9b7f2,0xdb0c0241,0x00000000,0x00000000}},	//   bidl, _òkèk, --, --, 
   {{0x2009b7f3,0xdb1c004e,0xddcc00b8,0x61e800d7}},	//   _ekai_, _gosé, _ivaś, cidl, 
   {{0x8fa5b7f4,0x2fc0062c,0xfe7c00e4,0x7dc82791}},	//   _байе, _toig_, atï_, _müsh, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc3309b62,0xdb1c003e,0xa3b407af,0x00000000}},	// [302e0] מון_, _yosé, ञात_, --, 
   {{0x4d48256e,0x7dc80790,0x00000000,0x00000000}},	//   _япон_, _nüsh, --, --, 
   {{0x07a5b7f5,0xbb800131,0x7d7808a8,0x00000000}},	//   лажн, شلەي, _אריג, --, 
   {{0x61e802fb,0x8b954dac,0x38640553,0xbf98017a}},	//   zidl, _сроч, ánra_, llêr, 
   {{0x61e81cdf,0x0c0401d9,0x6844070e,0xb7d5b7f6}},	//   yidl, _لوگُ, унҗа, دونا_, 
   {{0x09e4005b,0x00000000,0x00000000,0x00000000}},	//   _согн, --, --, --, 
   {{0x61e80e96,0x6aa5b7f7,0xd5640220,0xdb1c0129}},	//   vidl, lvif, ртіп, _rosé, 
   {{0x291803f9,0x7dc81432,0x61e880c1,0x00000000}},	//   _izra_, _püsk, widl, --, 
   {{0x61e81a6b,0xdb1db7f8,0x85757c79,0x6b84f8ee}},	//   tidl, _posé, _مدائ, ifig, 
   {{0x20082b92,0x7a78010f,0xfa9400df,0x00000000}},	//   _skai_, עריס, נדיש_, --, 
   {{0x20082a1f,0x61e9b7f9,0xddcc00b8,0x6aa40254}},	//   _pkai_, ridl, _evaś, hvif, 
   {{0x61e9b7fa,0xddcc0083,0x6b840158,0x7ce00139}},	//   sidl, _twaŋ, jfig, _bеrn, 
   {{0x61e9b7fb,0x20080093,0x6b84002d,0x00000000}},	//   pidl, _vkai_, dfig, --, 
   {{0x7dc8033d,0xbdd80066,0x6b840381,0xbf98002d}},	//   _küsi, mpèk, efig, tlês, 
   {{0x6b8432ff,0xfba9b7fc,0x6280c300,0x20080270}},	//   ffig, нтай_, ltmo, _tkai_, 
   {{0x20080093,0x62808c63,0x6b84fe6d,0xbf98045f}},	//   _ukai_, otmo, gfig, rlês, 
   {{0xf968d4d0,0x2919b7fd,0xceb400b1,0xfa3400db}},	// [302f0] ерей_, _azra_, _кәр_, اررد, 
   {{0x6b84013c,0x628001f5,0xadbc030d,0x00000000}},	//   afig, itmo, _заьi, --, 
   {{0x5ee80882,0x6b840099,0x62800036,0xd75800d8}},	//   _चेत्_, bfig, htmo, виец_, 
   {{0xd6d1b7fe,0xb11002e3,0xfa340214,0x6b840009}},	//   يقا_, nụar, _مرسد, cfig, 
   {{0x7c2c009a,0x248c0ac5,0x47300032,0xb4bc6236}},	//   _iicr, _apdm_, әнәс, ुन्_, 
   {{0x7dc801b8,0x4adc28d4,0x7c2c3bc1,0xd4680414}},	//   _büsi, _नेटव, _hicr, вике_, 
   {{0x7c340694,0x7ce001a9,0xdce40205,0xddcc00cd}},	//   _juxr, _mеro, _kahı, _svaś, 
   {{0xb9dc02d3,0xd265b7ff,0x7c347708,0xdb0c0cad}},	//   _ኦም_, акий, _muxr, _àkój, 
   {{0x7c3401c7,0x628001bf,0xc0d400d1,0xc3200395}},	//   _luxr, gtmo, ﻟﻜﯜﻳ, омък, 
   {{0x7c2c928e,0x98a0b8f1,0x91045378,0x25bc04ce}},	//   _licr, lahı_, иппе, cjvl_, 
   {{0x6281b800,0x6aa40433,0x00000000,0x00000000}},	//   atmo, zvif, --, --, 
   {{0x7c2db801,0xdb1c0194,0x98a00c3c,0xddcc00b8}},	//   _nicr, _rosî, nahı_, _tvaś, 
   {{0x628044b6,0x81c8015b,0xe1f00014,0x961c00ef}},	//   ctmo, রোধ_, _کسن_, _apņi, 
   {{0x10a41d1c,0x7c2c01e7,0xc5f0008f,0x00e40133}},	//   _викн, _aicr, ַדן_, اتیی, 
   {{0x4c340323,0xa3cc47d0,0xc0e0b7bb,0xb11001f2}},	//   рэгт, _रकम_, _мошк, bụar, 
   {{0x0b45b802,0x7c2c0327,0xbf980165,0x291c00d7}},	//   рнан, _cicr, slêr, ývam_, 
   {{0x6b8432ff,0x7c2db803,0x3e7c0276,0xfaa0014b}},	// [30300] rfig, _dicr, cît_, оато, 
   {{0x7c2c00a3,0xdb1c01d3,0x00000000,0x00000000}},	//   _eicr, _alsó, --, --, 
   {{0x6b85b804,0x7c2c0042,0x63a403b2,0x98a04dd9}},	//   pfig, _ficr, _ðing, fahı_, 
   {{0xc60c7e7c,0x248c01e2,0x628001b9,0x7dc80139}},	//   ित्य_, _rpdm_, ytmo, _rüsi, 
   {{0x057401b9,0x7dc800c5,0x6d5c062c,0xfa6402e8}},	//   لاغد, _süsi, oara, _каяк_, 
   {{0x6d5db805,0xc76404a9,0x0465b806,0x7dc8007d}},	//   nara, _ھازى, атим, _püsi, 
   {{0x601c0231,0x6d5db807,0x7c2c014b,0x98a01432}},	//   léme, iara, _yicr, bahı_, 
   {{0xc0dc02d3,0x6281715c,0x7c2c0139,0x2a60000d}},	//   _ሕርሻ_, ttmo, _xicr, osib_, 
   {{0x6d5db808,0x2a6121a9,0x601ca4f2,0x0514015b}},	//   kara, nsib_, néme, াশের_, 
   {{0x6d5ca324,0x7ce00139,0x7dc9b809,0x00000000}},	//   jara, _bеrl, _tüsi, --, 
   {{0xdb100793,0x2b400cf4,0xdfd000c6,0x9f340220}},	//   _äföv, kcic_, كيد_, йені, 
   {{0x41a4069f,0x7c340009,0x6d5c00ad,0xa3dc07f7}},	//   _कोरस, _ruxr, eara, _ॠषि_, 
   {{0x6d5d5cf9,0x7c2cb3cb,0x7c34022e,0x7dc80205}},	//   fara, _ricr, _suxr, _müsv, 
   {{0x6d5db80a,0x7c2db80b,0x601c4ac6,0x3e7db80c}},	//   gara, _sicr, déme, rît_, 
   {{0x98a00213,0x2d5800f5,0x00000000,0x00000000}},	//   yahı_, рись_, --, --, 
   {{0x6028033f,0x6d5db80d,0x00000000,0x00000000}},	//   _ośmi, aara, --, --, 
   {{0x6d5db80e,0x2a600007,0x7c2c00df,0xdea001d9}},	// [30310] bara, gsib_, _vicr, _عیسی, 
   {{0x6d5db80f,0x7ce006be,0xfc10013a,0x7bc844b3}},	//   cara, _yеrl, _řádů_, ögub, 
   {{0xf7702aaf,0x7c2d513a,0xdce40790,0x9b94009b}},	//   قاش_, _ticr, _tahı, _линц, 
   {{0x22c004fe,0x601c7dec,0x2b4000b8,0x00000000}},	//   _kōkā_, lémb, ccic_, --, 
   {{0xdb1c46dc,0xaa64004e,0x8c18011a,0x5f0800eb}},	//   _kosí, _мтрк, _תורי, রেরও_, 
   {{0x601c525e,0xe5780212,0x00000000,0x00000000}},	//   némb, изі_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d5db810,0x601c00d2,0x1bf80950,0x963400c0}},	//   zara, hémb, ्किल_, _гнац, 
   {{0x96f821fa,0x7f380092,0x42c4011c,0x00000000}},	//   _сеат_, _ቦታዎች, йгън_, --, 
   {{0x6d5db811,0xdb1c02fb,0x7dc803e0,0xd198003b}},	//   xara, _nosí, _küsu, утич_, 
   {{0x1bf819e5,0x8fa5b812,0x7ce0022e,0x2ed000dc}},	//   ्काल_, бане, _bеrm, हन्त, 
   {{0x425000e5,0x00000000,0x00000000,0x00000000}},	//   _کنور, --, --, --, 
   {{0x6d5db813,0xfafc0200,0x00000000,0x00000000}},	//   tara, _nxë_, --, --, 
   {{0x4fe83d48,0x6d5d0c73,0x601c0098,0x7ce00139}},	//   _әмин_, uara, gémb, _tеrl, 
   {{0x7dc80793,0x1c3807d8,0x8c45b814,0xcb687a94}},	//   _nüsu, иять_, себе, лаве_, 
   {{0x2a60cca1,0x0ba80328,0xe0d001b9,0x00000000}},	//   tsib_, داسى_, _تزه_, --, 
   {{0x0935b815,0x2b400960,0xdb1c0419,0x7dc803e3}},	// [30320] مراج, rcic_, _fosí, _rüsv, 
   {{0x6d5db816,0x2a619d48,0x601db817,0x9f580589}},	//   qara, rsib_, réme, roså_, 
   {{0x2a61b818,0x888411ed,0x601c5725,0x00000000}},	//   ssib_, слеж, séme, --, 
   {{0xdb1c00d7,0x2a600254,0x00000000,0x00000000}},	//   _zosí, psib_, --, --, 
   {{0xf86406ba,0x00000000,0x00000000,0x00000000}},	//   لمەي_, --, --, --, 
   {{0x7dc84e7e,0xa5f80114,0x0dc80092,0x00000000}},	//   _füsu, јеку_, አቀፉ_, --, 
   {{0x07a4009b,0x00000000,0x00000000,0x00000000}},	//   _лавн, --, --, --, 
   {{0x7dc9b819,0xd25000e5,0x00000000,0x00000000}},	//   _hüst, ڈنٹ_, --, --, 
   {{0x61d94bdf,0x601db81a,0x7dc9b81b,0x60280034}},	//   имия_, yémb, _küst, _uśmi, 
   {{0xdb1c00e4,0xbdd8026c,0x503c0092,0xfafc0200}},	//   _hosã, lpèv, _አደሮች, _odën_, 
   {{0x7dc9b81c,0x601d6b44,0x1fb8b7e2,0x036800fd}},	//   _xüsu, vémb, алны_, _биек_, 
   {{0x64480399,0x601c00d2,0x7dc82305,0xdb1db81d}},	//   _itdi, wémb, _lüst, _sosí, 
   {{0xe18836d0,0xdb1db81e,0xba38004e,0x64480175}},	//   _көне_, _posí, _trïi, _htdi, 
   {{0xdb1007ea,0xe0d40798,0x00000000,0x00000000}},	//   _âgée, _молњ, --, --, 
   {{0x601caeae,0x7ce001a9,0xdb1c01ef,0x00000000}},	//   rémb, _tеrm, _vosí, --, 
   {{0x601db81f,0xdb1c00d8,0x7dc80213,0x3044009f}},	//   sémb, _rosâ, _rüsu, _اليٽ_, 
   {{0x601c0438,0xac18c43c,0xe924025c,0x7dc9b820}},	// [30330] pémb, соту_, _འཛུབ_, _süsu, 
   {{0x644801a9,0x81c80154,0x39a40114,0x0dc80092}},	//   _otdi, রোর_, љшав, አቀፍ_, 
   {{0x7dc9b821,0xdb3400fb,0x64480208,0x00000000}},	//   _düst, _менњ, _ntdi, --, 
   {{0x6568002b,0xdee81954,0x00000000,0x00000000}},	//   _addh, _ዘላን_, --, --, 
   {{0x961c02e2,0x7dc801d3,0x644806be,0x4b780a7c}},	//   _opņt, _füst, _atdi, _דארו, 
   {{0x7dc80c86,0x38580472,0xa2ac27c6,0x00000000}},	//   _güst, _مشرد_, जिन्, --, 
   {{0xe611b822,0x7dc804cc,0xc32c0133,0xa3b400cd}},	//   رشه_, _hüss, ۆڕه_, ञां_, 
   {{0x7dc912c5,0x77d4007b,0x53c8094f,0x79940175}},	//   _küss, _اغسط, ргим_, lexw, 
   {{0x6449b823,0x7dc8000d,0x7ae80332,0x3568014b}},	//   _etdi, _jüss, úgth, _брен_, 
   {{0x7dc809f0,0x91e402bf,0xd76400f1,0x799403ac}},	//   _müss, іоне, _دنړی, nexw, 
   {{0xba380142,0x6594009d,0xddd40205,0x00000000}},	//   _trïw, _хаху, _şaşt, --, 
   {{0xd009b824,0x9218121d,0x81c80154,0xa3b400cd}},	//   реме_, _नीरज_, রোল_, ञाः_, 
   {{0xa2941feb,0xa3b8925c,0x7dc808d5,0x00000000}},	//   _наці, _دالر_, _nüss, --, 
   {{0xa2040212,0x49180037,0x00000000,0x00000000}},	//   _епід, _भरलो_, --, --, 
   {{0x7dc9b825,0x7995b826,0x3cc40107,0x00000000}},	//   _rüst, dexw, олро_, --, 
   {{0x7dc9b827,0x7b840116,0x00000000,0x00000000}},	//   _süst, ياقە, --, --, 
   {{0x7dc9b828,0xcd34331c,0x7bc800e4,0xda6400ae}},	// [30340] _püst, _وردب, ögua, كالي, 
   {{0x7dc8097d,0x26d802b5,0x601c00e4,0x98a00055}},	//   _düss, _āro_, méma, cchī_, 
   {{0x601db829,0x291db82a,0x9a882f0d,0x656800b8}},	//   léma, åva_, _қирғ_, _rddh, 
   {{0x7dc9b82b,0xddcc033f,0x00000000,0x00000000}},	//   _füss, _gwał, --, --, 
   {{0x7dc9b82c,0x601d033c,0x7a200521,0xbb280014}},	//   _güss, néma, ọtar, _پتَے_, 
   {{0x2d99b82d,0x7dc80790,0x32000073,0x00000000}},	//   nere_, _hüsr, रकोळ_, --, 
   {{0x2d99b82e,0xc32c0075,0x601db82f,0x291c0037}},	//   iere_, ھەت_, héma, üvad_, 
   {{0x2d99b830,0xc32c0131,0xdb1c01e1,0x601d6a7a}},	//   here_, پەت_, _hosá, kéma, 
   {{0xdb1db831,0x2d99b832,0x7dc80205,0x00000000}},	//   _kosá, kere_, _müsr, --, 
   {{0xc0cc0020,0x601c004a,0x66e4054a,0xfcd0001f}},	//   _ብሏል_, déma, _доға, _የውጪ_, 
   {{0x2d99b833,0xdb1db834,0x99980618,0xff5c00e4}},	//   dere_, _mosá, _susū_, taî_, 
   {{0x2d9804ba,0xdb1c013d,0x83500014,0x7dc803e3}},	//   eere_, _ilsö, _کھژا, _nüsr, 
   {{0x7994014b,0xfd48002b,0x00000000,0x00000000}},	//   yexw, _kroḍ, --, --, 
   {{0x2d99b835,0x7dc9b836,0xdb1c02f0,0xe1340139}},	//   gere_, _rüss, _nosá, _энкы, 
   {{0xfbd0221c,0xc0580046,0x7dc9b837,0x7994035a}},	//   وتر_, _тіл_, _süss, vexw, 
   {{0xdb1c004e,0x7994014b,0x7dc9b838,0x2d9802b5}},	//   _posà, wexw, _püss, aere_, 
   {{0xdb1c0296,0x7dc803e3,0x799403ac,0x00000000}},	// [30350] _bosá, _qüss, texw, --, 
   {{0x2d99b839,0xdb1c007b,0xbd680902,0xca6c0150}},	//   cere_, _cosá, _трие_, _ﺷﻪﺷﻪ_, 
   {{0x9f48020c,0xdb1c012c,0x7dc80e78,0x41e40327}},	//   _amaé_, _dosá, _wüss, རྣརྟ, 
   {{0x4c9806a9,0x7dc9b83a,0xda340108,0x7994a245}},	//   _פברו, _tüss, _немы, sexw, 
   {{0x461003e6,0x154400ee,0x00000000,0x00000000}},	//   کوور, пелм, --, --, 
   {{0xbdd8068c,0xe628143e,0x1544013d,0x00000000}},	//   mpès, يثون_, чекм, --, 
   {{0xf771b83b,0x636001f2,0x7ce001b9,0x00000000}},	//   _يار_, _ịnab, _bеri, --, 
   {{0x2d99b83c,0xd1cc1772,0x7bdc004d,0x693412fa}},	//   zere_, ብዓት_, nhqu, _інту, 
   {{0xd1b83947,0x2d99b83d,0xdb1c00e5,0x00000000}},	//   مادا_, yere_, _elsö, --, 
   {{0x2d99b83e,0x6d483535,0xb9ec0023,0x00000000}},	//   xere_, ıdak, _ጓና_, --, 
   {{0xf4f40014,0x8fa4303d,0x645c0327,0xe4a4009d}},	//   _بواں_, пане, _ħrig, _орцо, 
   {{0x2d99b83f,0x601c04fb,0x9b34001f,0xe1f800f7}},	//   were_, téma, _ኤጀንሲ, йгө_, 
   {{0x2d99b840,0x7bdc0009,0xd4680354,0x00000000}},	//   tere_, dhqu, _виçе_, --, 
   {{0x7bc80008,0xd1680023,0x2d998902,0x601c4db4}},	//   ögun, _ተጠቒሙ_, uere_, réma, 
   {{0x2d99b841,0xdb1db842,0x00000000,0x00000000}},	//   rere_, _rosá, --, --, 
   {{0x2d99b843,0x4a44daed,0x030800c5,0x7bdc031c}},	//   sere_, знав, _हुँह_, ghqu, 
   {{0xfcd00201,0xdb1d0749,0x0c7400f2,0x00000000}},	// [30360] _የውጭ_, _posá, _کدخد, --, 
   {{0x6f880014,0x4c680835,0x3a200051,0x8d54005b}},	//   _اچھِ_, _лион_, _chjp_, _этич, 
   {{0xdb1c0022,0xbdd800cf,0x7d5400d9,0x00000000}},	//   _vosá, rpèt, _מייד_, --, 
   {{0x7bddb844,0xbdd802e2,0x672400e4,0x00000000}},	//   chqu, spèt, ýijo, --, 
   {{0xbdd9b845,0x7dc80205,0xe67800d4,0x00000000}},	//   mpèr, _küsp, ійкі_, --, 
   {{0xdb1c00b5,0x7ce0022e,0x89d800ec,0x236001ef}},	//   _bosæ, _sеri, _اوسر_, _žij_, 
   {{0x69ddb846,0x7dc80205,0x00000000,0x00000000}},	//   _ilre, _müsp, --, --, 
   {{0xd36c1823,0x6f04035a,0x00000000,0x00000000}},	//   لۇم_, _oxic, --, --, 
   {{0x61ec01a9,0x00000000,0x00000000,0x00000000}},	//   аllа, --, --, --, 
   {{0x67201727,0xc0c80020,0x00000000,0x00000000}},	//   _izmj, _ኢሜል_, --, --, 
   {{0x9f98998c,0xc4540736,0xbf98045f,0x00000000}},	//   овну_, _رضاع, mlêz, --, 
   {{0xbb182776,0x443db847,0x224000c7,0x672002a0}},	//   _mbîr, _iut_, _éiko_, _बराक_, 
   {{0x03180137,0x443db848,0x00000000,0x00000000}},	//   _اتات_, _hut_, --, --, 
   {{0x443db849,0xd04006be,0x00000000,0x00000000}},	//   _kut_, hylə, --, --, 
   {{0x443db84a,0x6f04127b,0x7dc80254,0x00000000}},	//   _jut_, _exic, _düsp, --, 
   {{0x443db84b,0x69dcfc8d,0xec3402bf,0x601c0129}},	//   _mut_, _alre, енсь, mémo, 
   {{0x443db84c,0x5a3464e1,0x601db84d,0x69dc01ab}},	// [30370] _lut_, днат, lémo, _blre, 
   {{0x443c0d65,0x39440c86,0x7bddb84e,0x20192009}},	//   _out_, ùns_, shqu, llsi_, 
   {{0x443db84f,0x7c6402e7,0x69dc00a3,0xbdd80100}},	//   _nut_, _عادل, _dlre, spès, 
   {{0x7f5c014f,0x69ddb850,0x00000000,0x00000000}},	//   _jeqq, _elre, --, --, 
   {{0x443db851,0x7f5db852,0x69dc01ab,0x601c003e}},	//   _aut_, _meqq, _flre, hémo, 
   {{0x443c0052,0x69dc0076,0xa5640131,0x00000000}},	//   _but_, _glre, ىدىن, --, 
   {{0x443c2517,0x601c0789,0xa564dbc3,0x256401d9}},	//   _cut_, jémo, ردون, راوُ, 
   {{0x443c0323,0x601c07e9,0x7f5c013c,0x9998012c}},	//   _dut_, démo, _neqq, _kusů_, 
   {{0xd175b853,0x9f48006a,0x91e5b854,0x443c4afb}},	//   мыны, _amaï_, допе, _eut_, 
   {{0x443db855,0x5ef00316,0x76580248,0x2018002e}},	//   _fut_, ँछन्_, _iwuy, elsi_, 
   {{0x443db856,0x7f5db857,0x601c0129,0x2be000cd}},	//   _gut_, _beqq, gémo, नसमा, 
   {{0xdb1c014a,0x7bc80008,0x430c01f2,0x7dc803e0}},	//   _kosä, ögul, ịpị_, _süsp, 
   {{0x2e240e78,0xd5d000ab,0x7dc801d3,0xc0cc0240}},	//   höfe_, _तकाज, _püsp, ብሃለ_, 
   {{0x443cc520,0x7f5c0194,0x2be0012c,0x601c0077}},	//   _yut_, _eeqq, नसभा, bémo, 
   {{0x601c056a,0x443db858,0x00000000,0x00000000}},	//   cémo, _xut_, --, --, 
   {{0x7af8b972,0x63a40174,0xe0d00345,0x00000000}},	//   _žuta, _óint, _حزه_, --, 
   {{0x69dc007f,0x49c80354,0x00000000,0x00000000}},	// [30380] _plre, олан_, --, --, 
   {{0xbdd9b859,0x00000000,0x00000000,0x00000000}},	//   spèr, --, --, --, 
   {{0x7659b85a,0x0c25b85b,0x7ce0022e,0x32e00248}},	//   _awuy, _омон, _bеru, _yèyé_, 
   {{0x443c0978,0xddcc0432,0xdb1c0267,0x38c81bf4}},	//   _rut_, _ataň, _bosä, غالی_, 
   {{0xd764034c,0xdce40055,0x1b0001c6,0x601c00d7}},	//   رنوی, _idhā, _бүтн, zémo, 
   {{0x443db85c,0xa2ac02ab,0x940403e3,0x00000000}},	//   _put_, जिस्, _iplə_, --, 
   {{0x443c016d,0x601c0005,0xbf98045f,0xa4d80815}},	//   _qut_, xémo, rlêz, ядку_, 
   {{0x443db85d,0xc7640228,0x601c0077,0xd4980212}},	//   _vut_, _زارى, vémo, ярі_, 
   {{0x443c0694,0x2919b85e,0x7f5c0135,0x458400f3}},	//   _wut_, _hyra_, _reqq, _огав, 
   {{0x443db85f,0x291800c7,0x7ab80302,0x601db860}},	//   _tut_, _kyra_, קציו, témo, 
   {{0x7f5c0af5,0x443c007d,0x75d07ae6,0xf1a1b861}},	//   _peqq, _uut_, _جيلا, трын, 
   {{0x29180217,0x7f5c20ac,0x601db862,0xdce40055}},	//   _myra_, _qeqq, rémo, _ndhā, 
   {{0x442458ec,0x2919b863,0xba380054,0xa30801ed}},	//   _iho_, _lyra_, _asïn, _عرصے_, 
   {{0xd24c16cb,0xdce4002b,0xc0cc02d3,0x291806ea}},	//   _اچي_, _adhā, ብሃል_, _oyra_, 
   {{0x4425b864,0xdb1c0158,0xdce40055,0x7f5d68fc}},	//   _kho_, _moså, _bdhā, _teqq, 
   {{0x30040598,0x1fe800ec,0x00000000,0x00000000}},	//   _үзәг, _رکجي_, --, --, 
   {{0x4425b865,0x29180548,0xdfd001e2,0x00000000}},	// [30390] _mho_, _ayra_, _ليګ_, --, 
   {{0x442532a8,0x291800c0,0xadbc030d,0x5d54156e}},	//   _lho_, _byra_, _даьi, _якот, 
   {{0x4425b866,0x291800a2,0xd7590030,0xd64c01ec}},	//   _oho_, _cyra_, كلات_, _бiле, 
   {{0x29182d62,0x4425b867,0x9f480270,0xddcc0122}},	//   _dyra_, _nho_, _omaí_, _staň, 
   {{0xe785b868,0x2919b869,0x00000000,0x00000000}},	//   тухо, _eyra_, --, --, 
   {{0x291804f3,0x00000000,0x00000000,0x00000000}},	//   _fyra_, --, --, --, 
   {{0x44240876,0x28680372,0x2919b86a,0x00000000}},	//   _bho_, _орто_, _gyra_, --, 
   {{0x4425b86b,0xdb0c0054,0x23640369,0x76580810}},	//   _cho_, ljañ, gamj_, _twuy, 
   {{0x4425b86c,0x291802d3,0x7658014b,0x9f48002e}},	//   _dho_, _zyra_, _uwuy, _njañ_, 
   {{0x4424fe84,0x74b000c7,0x0320010b,0xc3205443}},	//   _eho_, _аӡиу, ыдын, ымык, 
   {{0x44240e9e,0xa1e800ae,0x00000000,0x00000000}},	//   _fho_, بريك_, --, --, 
   {{0x4424016d,0xb4d8447d,0x00000000,0x00000000}},	//   _gho_, डनी_, --, --, 
   {{0x213c0ac5,0xbb180356,0xdce40055,0xa3dc482a}},	//   _fgvh_, _scîn, _rdhā, डसर_, 
   {{0x4424020c,0xfbdc00d8,0x7374035b,0x00000000}},	//   _zho_, _alê_, _хыҧх, --, 
   {{0xa3b402e5,0x4424004b,0x96c002ab,0x00000000}},	//   _छोड_, _yho_, लमडॉ, --, 
   {{0xd838010e,0x44252420,0x70c82052,0x00000000}},	//   _niō_, _xho_, ाहील, --, 
   {{0x7ce0022e,0x29185db4,0xfeb000fb,0x00000000}},	// [303a0] _bеrs, _syra_, _йөрь, --, 
   {{0x2918070d,0x9f580296,0x9db8004e,0x48e41318}},	//   _pyra_, bosó_, _жыюу_, нозв, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x37e041e4,0x81c803d4,0x291800c0,0x00000000}},	//   лохг, ৰোপ_, _vyra_, --, 
   {{0x4425b86d,0xe94400f2,0x00000000,0x00000000}},	//   _rho_, _لرزی, --, --, 
   {{0x2919b86e,0x4425b86f,0xa4f8429e,0x65942bba}},	//   _tyra_, _sho_, وکار_, таку, 
   {{0x290c025a,0x23640309,0x9cd40327,0x00000000}},	//   _âda_, tamj_, ུགགས, --, 
   {{0x4425b870,0xa2ac1152,0xd83800a2,0x83640244}},	//   _qho_, जिल्, _giō_, ردبل, 
   {{0x44240dc9,0x37e001b9,0x00000000,0x00000000}},	//   _vho_, _сотг, --, --, 
   {{0x4425b871,0x00000000,0x00000000,0x00000000}},	//   _who_, --, --, --, 
   {{0x4425b872,0x24b00131,0xf99005d0,0xf0d001c6}},	//   _tho_, ﻳﻐﻪﻣ, ארת_, гжээ, 
   {{0x4425b873,0x78f8011a,0x00000000,0x00000000}},	//   _uho_, לפיו, --, --, 
   {{0x29040134,0x7af80419,0x00000000,0x00000000}},	//   _ɛmaa_, _ľuto, --, --, 
   {{0x7af805ce,0xa3b4000d,0x81c80154,0x69c46d65}},	//   _žuto, _छोत_, রোজ_, राफी, 
   {{0x246c0118,0xac94b34e,0x69c4024a,0x37b801e1}},	//   něm_, ларш, रानी, _ṣìṣe_, 
   {{0x6fd80022,0xdb0c148b,0x09d800cc,0x00000000}},	//   _nãch, fjað, _দদগা, --, 
   {{0xdb0db874,0xcd4001d9,0xda140114,0x8bf800cc}},	// [303b0] tjañ, _چھِٹ, вдањ, _আঠখন_, 
   {{0x9f58007b,0xdb0c0165,0x601c0118,0x9e340108}},	//   insí_, ujañ, kémk, _шепч, 
   {{0x7ce0022e,0x00000000,0x00000000,0x00000000}},	//   _vеrs, --, --, --, 
   {{0xdb1c0085,0x96f80108,0x28a40139,0x00000000}},	//   _mosú, меет_, ышуг, --, 
   {{0x7bcc16b8,0xfe7c00db,0x4b78008f,0x00000000}},	//   _iocu, nuï_, _קאשו, --, 
   {{0xe6b57e97,0x7bcc0055,0x888001ed,0x99840f47}},	//   الوگ, _hocu, _چیلن, _جلسو, 
   {{0xb4d80b8f,0x45d0399f,0x660400c7,0x00000000}},	//   डने_, ројс, éika, --, 
   {{0x7bcdb875,0xb1600023,0x1418007b,0xba040240}},	//   _jocu, _ለበዋታ, بيعة_, _ጋሂ_, 
   {{0x130810f5,0x122807d6,0x69d800dd,0x963400c7}},	//   ьний_, моий_, öveg, _анац, 
   {{0x7bcdb876,0x00000000,0x00000000,0x00000000}},	//   _locu, --, --, --, 
   {{0xdb1c0597,0xd370168d,0xd00823c5,0x33b000d1}},	//   _cosú, _نها_, дене_, _مەغر, 
   {{0x7bcc3e7e,0xd29400c7,0x00000000,0x00000000}},	//   _nocu, _аркь, --, --, 
   {{0x69c400ce,0x15e40fc8,0x00000000,0x00000000}},	//   रामी, _कतार_, --, --, 
   {{0x827400c8,0x71f80014,0x98e007f7,0x7bcc0051}},	//   _יענע_, _عرشس_, पनाए, _aocu, 
   {{0x0d202dc3,0x8c452171,0xf16800d1,0xe0fc00b8}},	//   рүнү, тебе, _ﻳﯘﻗﯘ, _tvāḿ_, 
   {{0x7bcdb877,0xc0e80020,0xdb0c06ea,0xddcc033f}},	//   _cocu, ሆነም_, tjað, _kwaś, 
   {{0x7bcdb878,0xdb1c038c,0x00000000,0x00000000}},	// [303c0] _docu, _kosù, --, --, 
   {{0xdb0c09cc,0x38c803e6,0x97c40116,0xc60400eb}},	//   rjað, ژانی_, ққуз_, _লীনা_, 
   {{0x7bcdb879,0x70740023,0xdb0c03b2,0x5cd40153}},	//   _focu, _ተሰሊፉ_, sjað, _біях, 
   {{0x27e000c6,0x7bcc56f8,0x7ce00139,0xdb0c03b2}},	//   óin_, _gocu, _tеrr, pjað, 
   {{0x2470001f,0x00000000,0x00000000,0x00000000}},	//   _አይሁድ_, --, --, --, 
   {{0x6aa40230,0x6b85b87a,0x2be0012d,0x00000000}},	//   mwif, lgig, नसवा, --, 
   {{0x6b8429f1,0x7bcc00e4,0x44280276,0x69c40073}},	//   ogig, _yocu, мцим_, राठी, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x41e402d5,0x6b85945e,0xb6a0010a,0x942400db}},	//   віна, igig, _китл, دويۇ, 
   {{0xdb1db87b,0xbabc0116,0x00000000,0x00000000}},	//   _posú, _ﯬﺳﺴﺎ, --, --, 
   {{0x601db63a,0xb9780302,0x30a000a7,0xdfd5b87c}},	//   lémi, וניי, аряв, гоны, 
   {{0x6aa5b089,0x25ac0009,0xfe7c00cf,0x7e980150}},	//   kwif, _hadl_, tuï_, _ﺘﻔﻭﻕ_, 
   {{0xa195b87d,0xf8bc1d8a,0x7bcc04cc,0x6b84005c}},	//   _балч, _एप्प, _rocu, dgig, 
   {{0x6aa5b87e,0x7bcc0311,0x6281b87f,0x6b840406}},	//   dwif, _socu, mumo, egig, 
   {{0x7bcdb880,0x6281b881,0xd24da357,0xfba801c0}},	//   _pocu, lumo, _وچی_, мтай_, 
   {{0x63a003d4,0x6b85b882,0x6aa40161,0x00000000}},	//   nemn, ggig, fwif, --, 
   {{0x6281b883,0xceb404a9,0x7bcc16b8,0xac180f06}},	// [303d0] numo, _йәр_, _vocu, тоту_, 
   {{0x601c56ef,0x6b85b884,0x7bcc009a,0x63a0047e}},	//   démi, agig, _wocu, hemn, 
   {{0x6281b2c8,0x7bcc6dab,0x63a1b885,0x2be001f9}},	//   humo, _tocu, kemn, नसशा, 
   {{0xf0901a4c,0x6281b886,0x63a09eb3,0x1a65b887}},	//   ינע_, kumo, jemn, _میری_, 
   {{0x628000da,0x7a34035b,0x63a01948,0xdef00240}},	//   jumo, _аҿар_, demn, _ሃልኪ_, 
   {{0x6281b888,0x2e240008,0x69c423c1,0xd7c8004b}},	//   dumo, höfn_, राणी, _ګوره_, 
   {{0xdb1c0036,0x25ac03cb,0x7dc801d3,0xa3b400c5}},	//   _onsë, _dadl_, _büsz, _छोह_, 
   {{0x63a1b889,0x6281b88a,0x52a84c04,0x23d40022}},	//   gemn, fumo, евим_, ицыр, 
   {{0x6281b88b,0x67d5b88c,0x601c5f6f,0x7580036b}},	//   gumo, _тоту, cémi, _نیشم, 
   {{0xdce400e4,0xdb1c0036,0x203c0092,0x2be02435}},	//   _echĩ, _ansë, _ከተማይ, _नत्थ, 
   {{0x5454b9ac,0x69c40574,0x6aa406d6,0x63a00921}},	//   _свет, राती, zwif, bemn, 
   {{0x6281b88d,0x25acaf97,0x92b46bc6,0xe3b001f7}},	//   bumo, _zadl_, _محتا, _ورن_, 
   {{0x6280ed9b,0x25ac014b,0xdb1c03b2,0x6b8401a9}},	//   cumo, _yadl_, _gosø, vgig, 
   {{0xdb1db88e,0xc3300375,0x00000000,0x00000000}},	//   _insè, _הוד_, --, --, 
   {{0xfce1b88f,0x6aa40e14,0xe1f0143e,0xfafc036e}},	//   боро, wwif, _بسن_, _odës_, 
   {{0x6aa400ca,0x60dc08fb,0xd01000c6,0x2498000d}},	//   twif, ørme, _دلع_, _ärme_, 
   {{0x2fc03e79,0x4b2400c0,0x61ec0166,0xc8c802f2}},	// [303e0] _inig_, умав, _ällü, کوان_, 
   {{0x9e6404a9,0x63a1b890,0x6aa40223,0x69c4024a}},	//   _ئاين, zemn, rwif, राधी, 
   {{0x6281b891,0xcb6801ce,0x63a02812,0x25ac002f}},	//   zumo, _пане_, yemn, _radl_, 
   {{0xa65402d3,0xdb1c0100,0x601c0129,0x00000000}},	//   _ዝተወሰ, _onsè, témi, --, 
   {{0x6d5c15ad,0xf8ac00aa,0x25ac013a,0x63a1b892}},	//   obra, يکې_, _padl_, vemn, 
   {{0x6d5db893,0x601ca90d,0x5a9422c3,0x02a41171}},	//   nbra, rémi, _трюф, ҳром, 
   {{0x63a1b894,0xdb1c02bd,0x601db895,0x6280209c}},	//   temn, _ansè, sémi, wumo, 
   {{0x6281b896,0x02a5b897,0x6d5c035a,0xa3d4447e}},	//   tumo, гром, hbra, роич, 
   {{0x06092f07,0x6d5cac32,0xd24c0b6c,0x6280011f}},	//   _знак_, kbra, وچو_, uumo, 
   {{0x6281b898,0x63a1b899,0x2fc001a9,0x6d5c01f5}},	//   rumo, semn, _anig_, jbra, 
   {{0x6281b89a,0x6d5db89b,0x4385b89c,0xb97800c8}},	//   sumo, dbra, _ملاق, ענטי, 
   {{0x628006ee,0x9f5802d3,0x9f3401ec,0x7a28002f}},	//   pumo, misë_, иені, müte, 
   {{0x7a29b89d,0x7411b89e,0x6d5d9bf8,0x9f5802d3}},	//   lüte, _اونا, fbra, lisë_, 
   {{0x2fc1b89f,0x6d5ce6dd,0x2e2401a8,0x6458005c}},	//   _enig_, gbra, söfn_, opvi, 
   {{0x9f58044e,0xfafc044e,0x7201b8a0,0xdb1db8a1}},	//   nisë_, _ndër_, _دووم, _insé, 
   {{0x6d5db8a2,0x2e240793,0xac19b8a3,0x00000000}},	//   abra, böfo_, госу_, --, 
   {{0x6d5db8a4,0x7a280086,0x9f4803ee,0x9f580240}},	// [303f0] bbra, hüte, _amaç_, hisë_, 
   {{0x6d5c01ab,0x9f5802d3,0x7dc80213,0x7a2884cd}},	//   cbra, kisë_, _nüsx, küte, 
   {{0x9f5802d3,0x00000000,0x00000000,0x00000000}},	//   jisë_, --, --, --, 
   {{0x9f580023,0x69c9b8a5,0x2b4401c0,0xa87801d5}},	//   disë_, _òden, _гэрг, احلر_, 
   {{0xdb1c01c7,0x6458017a,0xa764b4c7,0x00000000}},	//   _onsé, epvi, скід, --, 
   {{0xaaa80801,0x9f580023,0xf771b8a6,0x00000000}},	//   _съюз_, fisë_, _گاس_, --, 
   {{0x7a14008e,0x7a280112,0xb7b0013d,0x98740092}},	//   _eştä, güte, _гөлч, _ካልሆኑ_, 
   {{0x7bdc021a,0x6d5db8a7,0xf7700532,0xd3b400c7}},	//   nkqu, zbra, _داس_, рскь, 
   {{0x11e422e9,0x64580354,0x77680944,0x6d5db8a8}},	//   ижим, apvi, magx, ybra, 
   {{0x2fc07545,0x2009b8a9,0x6d5db8aa,0x9f580240}},	//   _snig_, _ajai_, xbra, bisë_, 
   {{0xe5c49786,0x9f58044e,0x53c40882,0x6d5c00b5}},	//   _усто, cisë_, वादश, vbra, 
   {{0x6d5db8ab,0xdb1c0789,0x2e24014a,0x7768009a}},	//   wbra, _ensé, töfo_, nagx, 
   {{0x6d5cc307,0xda140073,0xefcc0023,0x5f180243}},	//   tbra, तकात_, _ኣዝየ_, _युद्_, 
   {{0x200805b1,0x7bdc009a,0x42508b29,0x61e801ab}},	//   _ejai_, ekqu, _بنور, chdl, 
   {{0x7768009a,0x8f740826,0xc0f000b7,0xcb6957e4}},	//   kagx, _купі, ውተር_, каве_, 
   {{0x35c41533,0x2fc00cfd,0x31640399,0x9f580268}},	//   लाड़, _unig_, _henz_, jisè_, 
  
   {{0x31657fdb,0x896407fa,0x9f580023,0x6d5c12e8}},	// [30400] _kenz_, икаж, zisë_, pbra, 
   {{0xefcc069c,0x48b40801,0x27e401ab,0x7a280b97}},	//   _ኣዝዩ_, ищет, _slmn_, yüte, 
   {{0x9f58006a,0x31645d34,0x7d78011a,0x00000000}},	//   rosö_, _menz_, _בניו, --, 
   {{0x3165b8ac,0x7bddb8ad,0x7769b8ae,0x9f580023}},	//   _lenz_, ckqu, gagx, visë_, 
   {{0x76480399,0x46f40120,0xddcc0055,0x3ab001af}},	//   gqgy, јчет, _svaũ, _мәфт, 
   {{0x9f580023,0x75d0007b,0x00000000,0x00000000}},	//   tisë_, يينا, --, --, 
   {{0x77680921,0xfc3c01e1,0x7af800d7,0x00000000}},	//   bagx, _yií_, _ľuti, --, 
   {{0x9f58067d,0x7a2839d8,0x31640369,0x7af80552}},	//   risë_, rüte, _aenz_, _žuti, 
   {{0x9f58044e,0x057400cf,0xfafc0036,0x316463bd}},	//   sisë_, _نااد, _leën_, _benz_, 
   {{0x31640369,0x9f597157,0x6458007c,0xeb0400af}},	//   _cenz_, pisë_, ppvi, _रखैत_, 
   {{0x9f59b8af,0x3165b8b0,0x6721b8b1,0x6619b8b2}},	//   lisé_, _denz_, _hymj, movk, 
   {{0x64480de4,0x6569b8b3,0x6619b8b4,0x31640a40}},	//   _iudi, _hedh, lovk, _eenz_, 
   {{0x6568034c,0x6449b8b5,0x9f59b8b6,0xd4140014}},	//   _kedh, _hudi, nisé_, _آنگ, 
   {{0x6449b8b7,0x65688928,0x31640399,0x6619b8b8}},	//   _kudi, _jedh, _genz_, novk, 
   {{0x31540302,0x7b6434d8,0x6569b8b9,0x6720002d}},	//   _דיון_, итае, _medh, _lymj, 
   {{0x6449b8ba,0x3edc063f,0x66180122,0x601c0194}},	//   _mudi, _apụọ_, hovk, tému, 
   {{0x5e940597,0x6619b8b2,0x6d480014,0x9f58007f}},	// [30410] _الخط, kovk, الہِ_, visè_, 
   {{0x2019b8bb,0x6449b8bc,0x6569b8bd,0x7c85b8be}},	//   losi_, _oudi, _nedh, _куме, 
   {{0x66180232,0x3a3002fa,0x6448512d,0x9f58007f}},	//   dovk, rmxp_, _nudi, tisè_, 
   {{0x672003a2,0x65680083,0xae440014,0xb8fc00dc}},	//   _bymj, _aedh, _دپیو, _तथ_, 
   {{0x64480c46,0x656804fb,0xaac8012c,0x79a406ed}},	//   _audi, _bedh, रमणक, _крве, 
   {{0x656804fb,0x59e40050,0xe61802bf,0x7768009a}},	//   _cedh, _آسم, аді_, sagx, 
   {{0x2019b8bf,0x6449b8c0,0x656800f2,0x37a80798}},	//   kosi_, _cudi, _dedh, _итан_, 
   {{0x6449b8c1,0x3165b8c2,0x65695177,0x61f8062c}},	//   _dudi, _senz_, _eedh, _amvl, 
   {{0x6569b8c3,0x2019b8c4,0x64485b3c,0x661802fb}},	//   _fedh, dosi_, _eudi, bovk, 
   {{0x65680502,0x6449b8c5,0x6618022a,0xa2ac043e}},	//   _gedh, _fudi, covk, जिज्, 
   {{0xd174005e,0x2019b8c6,0x644949c0,0x10a4030d}},	//   _ғылы, fosi_, _gudi, щинн, 
   {{0x2019b8c7,0x6569b8c8,0xff5c006a,0xfafc0660}},	//   gosi_, _zedh, gbî_, _reën_, 
   {{0xfafc0660,0x6568a1b9,0xdb1db8c9,0xc18001d3}},	//   _seën_, _yedh, _mosó, _کیپٹ, 
   {{0x2be1b8ca,0x9f58049b,0x6449b8cb,0xc5f004ac}},	//   नस्थ, ensä_, _yudi, ִדן_, 
   {{0x6449b8cc,0x2019b8cd,0xfce00f4e,0xa0c4143e}},	//   _xudi, bosi_, поро, _ويهو, 
   {{0x2019b8ce,0x66180232,0x2d8c033f,0x0b4401f0}},	//   cosi_, zovk, żde_, снан, 
   {{0xdd1002fb,0xca0801c6,0x00000000,0x00000000}},	// [30420] _výši, гнаж_, --, --, 
   {{0x6720002d,0x9f58004a,0x0d740edf,0x7bc801a8}},	//   _rymj, visé_, _دیسک_, ögur, 
   {{0x6569b8cf,0x672000fe,0xdb1c04d4,0xacb41075}},	//   _redh, _symj, _bosó, _بەزب, 
   {{0x06e80209,0x9f5839b2,0x656804fb,0x46e88ef8}},	//   лмек_, tisé_, _sedh, лден_, 
   {{0x64480552,0x66184e6f,0x656804fb,0xdb0c0268}},	//   _sudi, tovk, _pedh, ndaì, 
   {{0x6449b8d0,0x2019b8d1,0x9f580231,0xda08004b}},	//   _pudi, zosi_, risé_, _نيټه_, 
   {{0x6619b8d2,0x65699c38,0x2019b8d3,0x9f580066}},	//   rovk, _vedh, yosi_, sisé_, 
   {{0x65680502,0x9f58020c,0x6449b8d4,0x00000000}},	//   _wedh, pisé_, _vudi, --, 
   {{0x644803f9,0xaac83105,0x2019b8d5,0x65680214}},	//   _wudi, रमिक, vosi_, _tedh, 
   {{0xc0580efb,0xa07411ed,0x6448f313,0xe298035b}},	//   лім_, огоч, _tudi, гаҩ_, 
   {{0x644983b5,0x59c800dc,0x9f580108,0x00000000}},	//   _uudi, रातर, ynsä_, --, 
   {{0x20180024,0x70380014,0xc04c0092,0xe6ac0241}},	//   uosi_, ٝسُس_, _አደረግ, _òróó, 
   {{0x2d99b8d6,0xff5c003a,0x00000000,0x00000000}},	//   ffre_, rbî_, --, --, 
   {{0x2019b8d7,0x9324d573,0xddcc068f,0x10f800dd}},	//   sosi_, _برمن, _stał, ابیں_, 
   {{0x2019b8d8,0x7a280793,0xdecc0023,0x00000000}},	//   posi_, jüta, _ኣፍካ_, --, 
   {{0x9b58c77a,0xdfd0007b,0x2018022e,0x81600133}},	//   риат_, _آية_, qosi_, _بچکۆ, 
   {{0xdd900597,0xd9f80063,0x8c380107,0x60dc01e3}},	// [30430] _قوة_, анац_, ротӣ_, ärmf, 
   {{0x78e94177,0x628001e7,0x9e1400d4,0x00000000}},	//   льев_, irmo, _єдні, --, 
   {{0xd7585f2e,0xf7700b8c,0xdb1db8d9,0x7af80030}},	//   للات_, كاش_, _insí, _ľutu, 
   {{0x3f89b8da,0x628013d5,0xfba8020f,0x00000000}},	//   ngcu_, krmo, _стой_, --, 
   {{0x59c80b7d,0xdce40219,0x15b800fb,0x00000000}},	//   रादर, _mehč, ғыһы_, --, 
   {{0x79e40014,0xdce400bc,0x628001e7,0xdb0c0332}},	//   _اوسہ_, _lehč, drmo, ndaí, 
   {{0x461004d3,0x6281596e,0x362000dd,0x0594036b}},	//   بوور, ermo, _ہورہ, تانگ, 
   {{0x843400c6,0xe19401c6,0xdb0c0332,0xd5b00051}},	//   يكور_, үрээ, hdaí, _wá_, 
   {{0x96f801ee,0xd5b00051,0x2d980142,0x67e8030d}},	//   _теат_, _tá_, yfre_, _уьрг_, 
   {{0xfafc0660,0x00000000,0x00000000,0x00000000}},	//   _reël_, --, --, --, 
   {{0x628001c3,0xe5c5b8db,0x8fa400a8,0xfafc0ea0}},	//   armo, _эсто, оане, _seël_, 
   {{0xdb1c04d4,0xa3d48c75,0x8ff800c7,0x00000000}},	//   _ansí, _нохч, рхоу_, --, 
   {{0x8db402bf,0x11d40826,0x51f49eb5,0x14840451}},	//   осві, _мікр, _وستر, _اھڙي_, 
   {{0x2cb801a6,0x6d800023,0x00000000,0x00000000}},	//   tvrd_, _ንዝያዳ_, --, --, 
   {{0x2e240793,0x00000000,0x00000000,0x00000000}},	//   nöfi_, --, --, --, 
   {{0xddcc0227,0xdb0c00c6,0xfafc0af9,0x0c24177b}},	//   _atań, adaí, _teël_, іман, 
   {{0xdb1c0ba1,0x2d981ada,0x3ab001e0,0xdde81410}},	// [30440] _sosò, pfre_, мәрт, _گريه_, 
   {{0xa2cc1b61,0x601c0098,0xc984007b,0x7a28000d}},	//   _तपस्, lémp, تشري, tüta, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2e2401b8,0xc72413f3,0x8724e99a,0x00000000}},	//   döfi_, одей, омеж, --, 
   {{0xa3b0000d,0x00000000,0x00000000,0x00000000}},	//   _ओसब_, --, --, --, 
   {{0x78ac02f6,0x649c01e4,0xfa6402a9,0x00000000}},	//   äivä, _aɩia, _фарк_, --, 
   {{0xa6d8015b,0x53c4043e,0x00000000,0x00000000}},	//   _দেশট, वांश, --, --, 
   {{0x6280003a,0xe79800f1,0x9a900023,0x00000000}},	//   trmo, _دمرګ_, _ዝክኣል_, --, 
   {{0x62800156,0xc1a41b88,0x601c4264,0xb6a801ee}},	//   urmo, ојни, démp, _китh, 
   {{0x6281b8dc,0x9a900023,0x00000000,0x00000000}},	//   rrmo, _ዝክእል_, --, --, 
   {{0xa05402bf,0x85040133,0x00000000,0x00000000}},	//   явні, _بوان, --, --, 
   {{0x03a5b8dd,0x6d4804a7,0x35180a7c,0x4298007b}},	//   _фидо, ždal, _דובנ, _ننصح_, 
   {{0xf7700302,0x9f042a9f,0x00000000,0x00000000}},	//   וקר_, سوسو, --, --, 
   {{0x9f59b8de,0x69d9b8df,0x00000000,0x00000000}},	//   misí_, övel, --, --, 
   {{0xdb0c007b,0x9f59b8e0,0xde4800ec,0x9a5001e1}},	//   rdaí, lisí_, _گڌجو_, _ìfẹ́, 
   {{0xabac0020,0xcad400fe,0x2ba400d8,0xddcc0210}},	//   ህአዴግ_, _সেইফ, мјув, _stań, 
   {{0x9f580093,0xfd440415,0x7e280024,0x00000000}},	// [30450] nisí_, _мэнн, _віна_, --, 
   {{0x394402ed,0x80bc00dc,0xb92401f4,0x00000000}},	//   øns_, षिपे, офей, --, 
   {{0x9f5801e7,0xfca80244,0x38c800c7,0x00000000}},	//   hisí_, _ئاخو_, шуан_, --, 
   {{0x59c80316,0x28480220,0x2e2401b8,0x00000000}},	//   राहर, ізіп_, vöfi_, --, 
   {{0xc21800e1,0x76a80484,0x00000000,0x00000000}},	//   नकाब_, ртев_, --, --, 
   {{0x7a2801b8,0x2e2401b8,0x00000000,0x00000000}},	//   müto, töfi_, --, --, 
   {{0x80d801f9,0x00000000,0x00000000,0x00000000}},	//   _पॅले, --, --, --, 
   {{0xf771b8e1,0x59c8078a,0x7f580784,0xa2cc081e}},	//   _زار_, रावर, ñuql, _तपश्, 
   {{0xc7b002e4,0x42c4010b,0x27300419,0x27e00254}},	//   _אבן_, згын_, _vôní_, öine_, 
   {{0x7659b8e2,0x2484063f,0xc5c8030d,0x00000000}},	//   _ituy, _ịmee_, _лкуç_, --, 
   {{0x24585ded,0x601c45a7,0x604001f2,0x9f58011f}},	//   _дахь_, témp, _ịmaa, disâ_, 
   {{0xd009b8e3,0x82a400cf,0x00000000,0x00000000}},	//   семе_, تۇۇق_, --, --, 
   {{0xa3b4007d,0x601c0098,0xa314010a,0x0e380092}},	//   _छोट_, rémp, _оьшш, _በህክም, 
   {{0x24480150,0x2bb80208,0x00000000,0x00000000}},	//   _اجەي_, _ọc_, --, --, 
   {{0x41b01564,0x63a402d1,0x800801ed,0x623403e6}},	//   _سمير, _ñinc, _گروہ_, _تووڕ, 
   {{0x60ddb8e4,0x76581418,0x00000000,0x00000000}},	//   ärme, _otuy, --, --, 
   {{0x7659b8e5,0xca84084c,0x00000000,0x00000000}},	// [30460] _ntuy, ягай, --, --, 
   {{0x14bcaa34,0xba2000d8,0x0d84014b,0x00000000}},	//   ्माण, едук, _элон, --, 
   {{0x76582aed,0x7a2803fa,0x79800113,0x00000000}},	//   _atuy, mütl, ónwa, --, 
   {{0xc5f005d9,0x4a7400ee,0x39100244,0xc9d40014}},	//   ڙڪاڻ, _ныгт, رونز, _کٲسب, 
   {{0x86981ab7,0xb8d02ca5,0x7c540133,0x00000000}},	//   стет_, _जै_, _ولیر_, --, 
   {{0x0465b8e6,0x9f580122,0x777816b8,0x291c04cc}},	//   птим, visí_, _edux, üvas_, 
   {{0x76581418,0x24580022,0x2a60022e,0x00000000}},	//   _etuy, _oĩme_, lpib_, --, 
   {{0x427002d3,0xd49800d4,0x6d480205,0x00000000}},	//   _ሸነኻት_, юрі_, ıday, --, 
   {{0x36647fe3,0xdce4005f,0x066401ec,0x5ee000fe}},	//   _нато_, _mehā, _ءارپ, _পেনে, 
   {{0xfcd00092,0x9f5801e7,0x00000000,0x00000000}},	//   _ከውጪ_, risí_, --, --, 
   {{0xf1adb8e7,0x03a400f3,0x00000000,0x00000000}},	//   اءً_, _нижо, --, --, 
   {{0xf484320a,0xdce400b8,0x9f580332,0x00000000}},	//   _رامی, _nehā, pisí_, --, 
   {{0x41e40d30,0xa19400db,0xe7f4000d,0x60dc007c}},	//   _ніка, _жалч, _आतना_, ärmb, 
   {{0x7a2805d1,0xa2780023,0x00000000,0x00000000}},	//   gütl, _ኩርናዕ_, --, --, 
   {{0x3198011a,0x00000000,0x00000000,0x00000000}},	//   _הבונ, --, --, --, 
   {{0xfbd025f4,0xdce400b8,0xddcc00ef,0xdb1c01ef}},	//   رتز_, _cehā, _dvaš, _ansá, 
   {{0x918401ec,0xdce400cd,0x39a41797,0x7a280a43}},	// [30470] _ءجۇم, _dehā, зшев, bütl, 
   {{0x9f59b8e8,0x20b00243,0xbd680139,0xddcc0171}},	//   lisà_, _जनाध, _урие_, _staņ, 
   {{0xdce403a0,0x98740276,0x00000000,0x00000000}},	//   _fehā, флец, --, --, 
   {{0x2a600218,0x9f580c86,0x7a2804cc,0xdce400b8}},	//   bpib_, nisà_, püto, _gehā, 
   {{0xd9f401f9,0x00000000,0x00000000,0x00000000}},	//   _इतपत_, --, --, --, 
   {{0x9f590cf1,0x79a45954,0xdb1c007c,0x00000000}},	//   hisà_, _эрме, _bosö, --, 
   {{0xe571b8e9,0x5ee00154,0xe01c06b1,0x00000000}},	//   اطه_, _পেমে, नवाद_, --, 
   {{0xdb0c0248,0x00000000,0x00000000,0x00000000}},	//   _ìkóm, --, --, --, 
   {{0x7659b8ea,0x00000000,0x00000000,0x00000000}},	//   _utuy, --, --, --, 
   {{0x3a200140,0x42040212,0x7a29b8eb,0xb9d80092}},	//   _jkjp_, дньо_, kütm, _በኢ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9f5804cc,0x2e24002f,0x00000000,0x00000000}},	//   gisà_, höft_, --, --, 
   {{0xddcc071b,0x23741fa2,0xb8dc0135,0x63a40309}},	//   _svaš, _سانح, _ཁན_, _ñina, 
   {{0xc3300302,0x91050261,0x00000000,0x00000000}},	//   _סוג_, _опле, --, --, 
   {{0x2d840790,0xe8dc07b7,0x00000000,0x00000000}},	//   ğme_, _यथेच, --, --, 
   {{0x2d842c44,0x9f58e8c4,0xbf980798,0xdcf40419}},	//   şme_, cisà_, liên, bezľ, 
   {{0xfcd0001f,0x4df40276,0xfcf4001f,0x9f5801bf}},	// [30480] _ከውጭ_, _жянт, _ለውጭ_, vnsø_, 
   {{0x9f5802ea,0xbf9806ed,0x48e4009b,0x0d740101}},	//   misá_, niên, мозв, _زیرک_, 
   {{0xe4f40316,0x00000000,0x00000000,0x00000000}},	//   ेपछि_, --, --, --, 
   {{0xbf9801fb,0xfbdc01fb,0x00000000,0x00000000}},	//   hiên, _hiên_, --, --, 
   {{0x79781682,0xdb1c04ce,0x9f580085,0xfbdc001e}},	//   _ṅwed, _ansæ, nisá_, _kiên_, 
   {{0xe535b8ec,0xa2cc00dc,0x00000000,0x00000000}},	//   нель, तमस्, --, --, 
   {{0x69ddb8ed,0xbf980261,0xfbdc01fb,0xe9441968}},	//   _iore, diên, _miên_, _سرسی, 
   {{0x69ddb8ee,0xfbdc01dc,0xbf9807ea,0x44200086}},	//   _hore, _liên_, nnêt, ôk_, 
   {{0x69dc9769,0x9f580268,0x85b85285,0x00000000}},	//   _kore, visà_, _وائس_, --, 
   {{0x69ddb8ef,0xfbdc0016,0xbf980120,0x7a28029f}},	//   _jore, _niên_, giên, yütm, 
   {{0x69ddb8f0,0x9f5807c5,0x9f48010e,0xe8dc09fa}},	//   _more, tisà_, _emaý_, _यथोच, 
   {{0x69ddb8f1,0x14bc62be,0x660401e4,0x3360009d}},	//   _lore, ्मरण, ɨika, _авцг, 
   {{0xfbdc0016,0x69ddb8f2,0x9f5807c5,0xaed40276}},	//   _biên_, _oore, risà_, вояш, 
   {{0x69dc0c58,0xbf980261,0xed582910,0xa19400db}},	//   _nore, ciên, доё_, _чакч, 
   {{0xfbddb8f3,0xac94b94b,0x00000000,0x00000000}},	//   _diên_, карш, --, --, 
   {{0xdb0c0261,0x69ddb8f4,0xe8001152,0x7a29b8f5}},	//   ndaç, _aore, लोमा_, rütm, 
   {{0x5a341b10,0x00000000,0x00000000,0x00000000}},	// [30490] енат, --, --, --, 
   {{0xfcf4069c,0x69ddb8f6,0xe0d002f5,0x201806af}},	//   _ለውጢ_, _core, ানীন, érif_, 
   {{0x69ddb8f7,0x69c41116,0xdee80023,0x7a280139}},	//   _dore, राजी, _ዚርአ_, lütk, 
   {{0xdd0c068f,0x69ddb8f8,0x96b800cf,0x00000000}},	//   półp, _eore, зуку_, --, 
   {{0x9b4404fb,0xddcc00bc,0x76c400f1,0x5ee000eb}},	//   _سنسو, _stař, بغال, _পেতে, 
   {{0xd1c8010c,0xfbdc004d,0xd1e40092,0x00000000}},	//   ጽበት_, _xiên_, ኝበት_, --, 
   {{0x41d00864,0x95b40022,0xa8985740,0x24f40395}},	//   तानस, дрқә, _окру_, кчър, 
   {{0x69ddb8f9,0xb4ac000d,0x5588008e,0x00000000}},	//   _zore, _ओनी_, _şığı, --, 
   {{0x69c40cb4,0xfcf40201,0x69ddb8fa,0x13092c80}},	//   राची, _ለውጥ_, _yore, яний_, 
   {{0x69ddb8fb,0xdb1c049f,0x70e4016c,0x35680da9}},	//   _xore, _insä, дгоҳ_, _фран_, 
   {{0xbf9803b7,0x059410e8,0x626401d5,0x00000000}},	//   riên, _سالگ, _یاوق, --, 
   {{0x60dc01e6,0x35c4033f,0xca240150,0x00000000}},	//   ärma, लाक़, _ﺠﺭﺡ_, --, 
   {{0x626402bf,0xbf9800d8,0xc5b0015b,0x56b4010f}},	//   _авіа, piên, চারপ, עפֿן_, 
   {{0xddcc002b,0x99980064,0x80d80073,0xa2cc00cd}},	//   _itaś, _musų_, _पॅके, तमर्, 
   {{0xfbdc01dc,0x69ddb8fc,0x7a280086,0x4124f9e2}},	//   _viên_, _rore, müth, _пошо_, 
   {{0xc4d004ac,0x6724003d,0x2e240793,0x00000000}},	//   נגן_, żiji, töfs_, --, 
   {{0xfbdc07ae,0x9f58011f,0x2d8c180f,0x2bc40073}},	// [304a0] _tiên_, qisá_, òdes_, _लोणा, 
   {{0x0d2043e8,0x69ddb8fd,0x4d65b8fe,0x645c004a}},	//   _бүгү, _qore, _яков, _érig, 
   {{0x69dc07ad,0xc6d458c2,0xdb1c03fa,0x9f640798}},	//   _vore, کتات, _ansä, _étão_, 
   {{0x69ddb8ff,0xdbcc01e1,0xd90c01d5,0x00000000}},	//   _wore, _dóós, زیق_, --, 
   {{0x69ddb900,0xbf980ea0,0x659457f6,0x00000000}},	//   _tore, onêr, валу, --, 
   {{0x69dc127b,0x00000000,0x00000000,0x00000000}},	//   _uore, --, --, --, 
   {{0xddcc002b,0xa3ac0456,0xf480013d,0x58946957}},	//   _ataś, ग़ल_, гуын, _ишту, 
   {{0xc764278f,0x00000000,0x00000000,0x00000000}},	//   _سارى, --, --, --, 
   {{0x7c204a1f,0xdb0db901,0x00000000,0x00000000}},	//   _ínre, rdaç, --, --, 
   {{0x26c401c4,0x1b1c00cc,0x00000000,0x00000000}},	//   _irmo_, পেকে_, --, --, 
   {{0xdb1c01e6,0x670401f9,0xf1a030c2,0x48dc00cc}},	//   _inså, _शेतक_, урын, _মধুৰ, 
   {{0x26c40427,0xbf980af9,0xdbcc01e1,0x00000000}},	//   _krmo_, enêr, _lóòs, --, 
   {{0x4425b902,0x00000000,0x00000000,0x00000000}},	//   _iko_, --, --, --, 
   {{0x44240093,0x00000000,0x00000000,0x00000000}},	//   _hko_, --, --, --, 
   {{0x4425b903,0x23c405d7,0x249c003a,0x31b80375}},	//   _kko_, _वफाद, ntvm_, _מזגנ, 
   {{0x4425b904,0xbf98002d,0x7a280b70,0x2d9d4d01}},	//   _jko_, rnês, müti, _öven_, 
   {{0x4424d155,0xb14018c7,0xab2800d8,0x2d58010a}},	// [304b0] _mko_, _инәл, еоѓа_, _ӗçри_, 
   {{0x442403a2,0x99980006,0xbb64037e,0xd6d1b905}},	//   _lko_, _rusų_, _bmwパ_, یقا_, 
   {{0xef200034,0x26c5b906,0xb4ac00af,0x7a280112}},	//   ążek_, _armo_, _ओने_, nüti, 
   {{0x4425b907,0x782442c6,0xdb1c01e6,0xfbdc01fb}},	//   _nko_, رعال, _anså, _kiêm_, 
   {{0x9f4800ae,0x26c401ef,0x9f5801f4,0x37300124}},	//   _olaí_, _crmo_, misä_, уҕат, 
   {{0x4425b908,0x9f59b909,0x78f0010b,0x7a28000d}},	//   _ako_, lisä_, _йүзу, küti, 
   {{0x6ef800d2,0xfbdc01fb,0x26c5b90a,0xa935b90b}},	//   _kúbé, _liêm_, _ermo_, _берш, 
   {{0x4425b90c,0x69c80086,0xd7c85741,0x59c807d0}},	//   _cko_, _òder, _توره_, राकर, 
   {{0x44249c2f,0xfbdc01fb,0x60dc01e6,0xdb1c002f}},	//   _dko_, _niêm_, ärmn, _unsä, 
   {{0x9f4801e7,0x93140066,0x00000000,0x00000000}},	//   _claí_, _یواش, --, --, 
   {{0x44240093,0xc95006a9,0x249c003a,0x00000000}},	//   _fko_, ימי_, ctvm_, --, 
   {{0x9f4803bd,0x4424005a,0x24580276,0x00000000}},	//   _amañ_, _gko_, _чаць_, --, 
   {{0x20b00ebb,0xc7d4011a,0x5ec40417,0x00000000}},	//   _जनअध, דורי_, гияғ, --, 
   {{0xf294037e,0x4425b90d,0xfbdc004d,0x7a2855ac}},	//   _iモ_, _zko_, _diêm_, büti, 
   {{0x68386428,0x442400e4,0x8b95b90e,0x9f580166}},	//   líde, _yko_, крач, fisä_, 
   {{0x9f4803bd,0x35b000c5,0xfafc0200,0x3ff00137}},	//   _emañ_, ंजड़, _neës_, _ۅكۉر, 
   {{0x2019b90f,0x3b040801,0xbf980375,0x0b4401a9}},	// [304c0] érie_, вето_, _חיפש, тнан, 
   {{0x4ce400db,0x00000000,0x00000000,0x00000000}},	//   _ажоб, --, --, --, 
   {{0x6d5db910,0xc8c802f2,0x48b40395,0x00000000}},	//   mcra, بوان_, ъщат, --, 
   {{0x6d5c127b,0x7ae801ed,0x87080022,0x00000000}},	//   lcra, ölté, меев_, --, 
   {{0xfbdc004d,0x5b3401ee,0x68381427,0x00000000}},	//   _xiêm_, _бэру, vídd, --, 
   {{0x6d5db911,0x4425b912,0x6d480006,0x6839b913}},	//   ncra, _sko_, ždau, díde, 
   {{0x44246a45,0x657800b8,0x98dc0150,0x00000000}},	//   _pko_, _ābhī, _естi, --, 
   {{0x6d5db914,0x26c40010,0x07a4013e,0xdbcc02d2}},	//   hcra, _trmo_, _шабн, _jóðs, 
   {{0xb271b915,0xddcc01e4,0xf7403da1,0x63a40113}},	//   алыш, _ataŝ, _вето, _ñinm, 
   {{0x60dc0267,0x442413ee,0xdbcc02d2,0xf2c0011c}},	//   ärmo, _wko_, _lóðs, рсън, 
   {{0x4425b916,0xdfd02781,0xf9900302,0x6d5c127b}},	//   _tko_, ميد_, ברת_, dcra, 
   {{0x4424633d,0x657806d6,0xb4f800c8,0x6838012c}},	//   _uko_, lavh, _קלאר, bíde, 
   {{0x2458893a,0x68380077,0x246801e1,0xfafc0ea0}},	//   _hém_, cíde, _fìmò_, _leër_, 
   {{0xfbdc0016,0x24580016,0x998002b1,0x6441b917}},	//   _viêm_, _kém_, rohū_, lmmi, 
   {{0x2d5829c3,0x2bc5b918,0x2458002e,0x6440022f}},	//   тись_, _लोहा, _jém_, ommi, 
   {{0x657806d6,0xfbdc001e,0x245800bc,0x998000b0}},	//   havh, _tiêm_, _mém_, pohū_, 
   {{0x6441b919,0xeeb9b91a,0x65780433,0x5ee0015b}},	// [304d0] immi, _алыш_, kavh, _পেরে, 
   {{0x9f480227,0x6d5c3607,0x9f5801f4,0x00000000}},	//   _umañ_, ccra, sisä_, --, 
   {{0xf77004a9,0x3945a458,0x65781682,0x2458001e}},	//   لاش_, äns_, davh, _ném_, 
   {{0xb8d92de2,0xfafc04e6,0xdbcc022c,0x9204002b}},	//   _अन_, _deër_, _góðs, _ivāś, 
   {{0xfafc01c7,0x6d4801a6,0x52d000c5,0x5fa466c0}},	//   _eeër_, ždat, _तपेस, ग्यल, 
   {{0x6839b91b,0x69d800dd,0x6578c01c,0x644075a1}},	//   víde, övet, gavh, emmi, 
   {{0xd174052f,0x53a418bc,0x60dc007c,0x00000000}},	//   һыны, гайб, ärml, --, 
   {{0x2458e645,0xf7700131,0x5c7c0092,0x6578002b}},	//   _dém_, _خاس_, _እውነታ_, _ābhū, 
   {{0xd1742cd0,0x11d80597,0x7bcc014b,0x6d5c0857}},	//   лыны, فوظة_, _mncu, ycra, 
   {{0x2459b834,0x64412683,0x6839919e,0x00000000}},	//   _fém_, ammi, ríde, --, 
   {{0x24580bfa,0x910400c9,0x5ee0015b,0x50440b3b}},	//   _gém_, упне, _পেলে, леоб, 
   {{0x826402d3,0x6838021c,0x6d5c01ab,0x00000000}},	//   _ግጥምታ, píde, wcra, --, 
   {{0x6d5c0c8c,0x246801e1,0x00000000,0x00000000}},	//   tcra, _tìmò_, --, --, 
   {{0x7bcdb91c,0x645c0120,0x6d5c0afa,0x00000000}},	//   _ancu, _éric, ucra, --, 
   {{0x6d5db91d,0x201995e3,0x0d2000f7,0x24580208}},	//   rcra, éric_, сүнү, _xém_, 
   {{0x6d5db91e,0x7f580309,0x8f7400c0,0x00000000}},	//   scra, ñuqt, _сукі, --, 
   {{0xacb40075,0x9204002b,0x4e280107,0x65780455}},	// [304e0] _ھەرب, _evāś, _поин_, yavh, 
   {{0x7bcdb91f,0x7a2800c5,0x65780fac,0x00000000}},	//   _encu, kütu, xavh, --, 
   {{0xfaa01d18,0x6fd82e3b,0x6578006f,0x644000ad}},	//   _қаро, यापू, vavh, ymmi, 
   {{0x27e019cf,0x61e02677,0x38c81bf3,0x00000000}},	//   ðin_, _पक्ष, عالی_, --, 
   {{0x65781682,0x7c200998,0x69d92295,0x980808de}},	//   tavh, _ínra, öves, ختلف_, 
   {{0x24580208,0x00000000,0x00000000,0x00000000}},	//   _pém_, --, --, --, 
   {{0x63a40309,0x6579b920,0x00000000,0x00000000}},	//   _ñink, ravh, --, --, 
   {{0xd90c0502,0x6441b921,0x6579b920,0x070800ec}},	//   _تیم_, ummi, savh, _ٻيئي_, 
   {{0x64400522,0x75d00451,0x24580036,0xd3980116}},	//   rmmi, _گيلا, _wém_, тәхә_, 
   {{0x6838012c,0x2459b922,0x72143740,0x64400327}},	//   bídc, _tém_, лжыр_, smmi, 
   {{0xddcdb923,0xf9900302,0x30a00801,0xf484397d}},	//   _ataş, זרת_, бряв, _مانی, 
   {{0xdb1c006a,0x1e1c1dd1,0xde5802d5,0x7a2805d5}},	//   _dasê, पक्ष_, камі_, lütt, 
   {{0xbb18054e,0x920400cd,0x9e340395,0x00000000}},	//   _adîn, _svāś, иемч, --, 
   {{0x11f400db,0x00000000,0x00000000,0x00000000}},	//   _ۅتۉگ, --, --, --, 
   {{0x40843ffb,0x00000000,0x00000000,0x00000000}},	//   _сулб, --, --, --, 
   {{0x7a28c08d,0x7f5c022e,0x41d017c6,0x00000000}},	//   hütt, _ufqq, तावस, --, 
   {{0x7a2800c5,0x7a5400c6,0x9998059f,0xdb0c0162}},	// [304f0] kütt, اضرا, ккат_, ndaø, 
   {{0xdd901060,0xdb1d4861,0x92040055,0x2ef400db}},	//   _بود_, _hasë, _tvāś, _ызыр, 
   {{0x7a2807c5,0x1a641bc6,0xdb1c036e,0x8d58011a}},	//   dütt, _چیری_, _kasë, _בכתי, 
   {{0x7bcdb924,0x69d9b925,0xdb1c03cd,0x1a64030f}},	//   _uncu, över, _onsø, _نیری_, 
   {{0xdb1c0023,0x7a280e78,0x00000000,0x00000000}},	//   _masë, fütt, --, --, 
   {{0x7bd40006,0x7a29b926,0x00000000,0x00000000}},	//   šbuč, tütu, --, --, 
   {{0xdb1c04ce,0x6fd80a59,0x41c00037,0x00000000}},	//   _ansø, यामू, _वोइस, --, 
   {{0xe4c8bf4e,0x681c0100,0x2bd800cd,0x00000000}},	//   ابون_, tčde, डाया, --, 
   {{0x880000aa,0x7a280ccc,0x91d40212,0x67d4004e}},	//   _بېنو, bütt, ацні, _уоту, 
   {{0x9f580395,0x10a40588,0x6595b927,0x799401e2}},	//   misù_, аион, _гафу, ngxw, 
   {{0xdb1c006a,0x10a422d7,0x76408336,0x92d40154}},	//   _basë, шинн, mmny, সনে_, 
   {{0xd009b928,0x76400073,0x92b400ae,0x00000000}},	//   теме_, lmny, _نحتا, --, 
   {{0x326000dd,0xb8d40135,0x326401da,0x2019b929}},	//   _انتہ, _ཙག_, _стев, éria_, 
   {{0x7f5802d1,0x9db802dd,0xfb8401d5,0x00000000}},	//   ñuqr, лысу_, یدقی, --, 
   {{0xdb1c068c,0xfce001c0,0x7641077b,0x00000000}},	//   _hasè, ооро, imny, --, 
   {{0xdb1c4ccd,0x00000000,0x00000000,0x00000000}},	//   _kasè, --, --, --, 
   {{0x7a2800dd,0xda64152b,0x2bd80bae,0x8a040064}},	// [30500] yütt, مالي, डाबा, азае, 
   {{0x2fc000db,0xdb1cff79,0xba14007b,0x00000000}},	//   _haig_, _masè, ليقا_, --, 
   {{0xdb1c0100,0x2fc00076,0x8ba40d1d,0x00000000}},	//   _lasè, _kaig_, _кинж, --, 
   {{0x2d982178,0x46e80209,0x07a4580f,0xc7a48bc6}},	//   lgre_, кден_, радн, ридк, 
   {{0x2fc00372,0x26c8774d,0x320401e2,0x8645b92a}},	//   _maig_, ыған_, _omny_, андж, 
   {{0x2d98cfb2,0x2fc1b92b,0xa3a80316,0x60dc007c}},	//   ngre_, _laig_, ख्न_, ärmk, 
   {{0x7a29b92c,0x2d980219,0xdecc0023,0x6e2000e4}},	//   rütt, igre_, _ኣፍና_, îmby, 
   {{0xdb1c804e,0x32040109,0x2fc1b92d,0x76416c9f}},	//   _basè, _amny_, _naig_, amny, 
   {{0xdb1c1762,0x9f49b92e,0x46489134,0x78ac07f5}},	//   _casè, _ilaç_, _азан_, čivš, 
   {{0xc059ad5d,0x00000000,0x00000000,0x00000000}},	//   кім_, --, --, --, 
   {{0x2fc1b92f,0x3a340302,0x27e40036,0x395402e4}},	//   _baig_, שרים_, _komn_, ישים_, 
   {{0x2fc00218,0xdb1c068c,0xf4240276,0x00000000}},	//   _caig_, _fasè, _кохл_, --, 
   {{0x2fc1b930,0xdb1c0561,0x7f580113,0xeeb802e8}},	//   _daig_, _gasè, ñuqq, аляш_, 
   {{0x9f482452,0x6280007c,0x3240030d,0xc19002f2}},	//   _llaç_, msmo, _дечг, _بیدع, 
   {{0x62801028,0x2fc00137,0xfbd00597,0x02b47d07}},	//   lsmo, _faig_, يتر_, _अनुन, 
   {{0x62800204,0x2fc0004e,0x1f7407a5,0x7a280205}},	//   osmo, _gaig_, _улия, yüts, 
   {{0xa3a87220,0x2009b931,0xdb1c5d69,0xc0f40092}},	// [30510] ख्य_, _imai_, _kasé, ገውም_, 
   {{0xf990484d,0x68380316,0x9f480432,0x6281b932}},	//   تبر_, vída, _alaç_, ismo, 
   {{0xdb1db933,0x2fc001d4,0x00000000,0x00000000}},	//   _masé, _yaig_, --, --, 
   {{0x27e5b934,0x20080198,0xdd900014,0x96f8005b}},	//   _comn_, _jmai_, _بوگ_, леет_, 
   {{0xf991b935,0x6fd80574,0x27e40311,0xfd480055}},	//   _وبس_, यातू, _domn_, _apoḍ, 
   {{0x764006df,0xdb1c0098,0x7a2804cc,0x962001ad}},	//   umny, _nasé, rüts, यवेट_, 
   {{0x200808f5,0xfc3c07ae,0x76400263,0x62800171}},	//   _omai_, _khí_, rmny, esmo, 
   {{0x27e400ca,0x9f481f40,0x2d9863e0,0xdce400dc}},	//   _gomn_, _glaç_, zgre_, _adhī, 
   {{0xfc3c0597,0x645c00dd,0x6281b936,0xdb1db937}},	//   _mhí_, _érin, gsmo, _basé, 
   {{0x2019b938,0x2009b939,0xdb1c0129,0x5edc009e}},	//   érin_, _amai_, _casé, ডনাই, 
   {{0xdb1c003e,0x628005e4,0xd1740032,0xfbdc0208}},	//   _dasé, asmo, _һыйы, _hiêu_, 
   {{0xfc3c001e,0xfbdc01fb,0x7f580113,0x6280005c}},	//   _nhí_, _kiêu_, ñuqp, bsmo, 
   {{0x2fc00228,0x62800098,0xadc400c7,0x00000000}},	//   _vaig_, csmo, ahẽh, --, 
   {{0xfc3db93a,0x20080ba1,0x3edc02e3,0xfbdc01fb}},	//   _ahí_, _emai_, _gwọọ_, _miêu_, 
   {{0xfc3c06d5,0x2fc001d4,0xfbdc01fb,0x53bc012c}},	//   _bhí_, _taig_, _liêu_, ्यपश, 
   {{0xfc3c07ae,0x7984033b,0x7a0c00c0,0x00000000}},	//   _chí_, _adjw, _lėtė, --, 
   {{0xbb41b93b,0x27e401ab,0xfc3c01e7,0x89a80120}},	// [30520] зетк, _romn_, _dhí_, лкав_, 
   {{0xc330025f,0x27e40276,0xddcc0122,0x5ee000fe}},	//   לון_, _somn_, _zvaž, _পেকে, 
   {{0xc7641a02,0x9f4800db,0x27e40010,0xfc3c0332}},	//   ماشى, _plaç_, _pomn_, _fhí_, 
   {{0x6281b93c,0x60ddb93d,0x8b9402bf,0xa6a001ec}},	//   ysmo, ärmi, _уроч, _ﺍﻻﻭﻝ_, 
   {{0x6838012c,0xdcf400e2,0xe98400c7,0xe5780107}},	//   bídn, mazā, _мқан, иҷа_, 
   {{0xfbdc004d,0x6aa403b2,0xdb0c00e4,0x68380419}},	//   _diêu_, mtif, ndaý, cídn, 
   {{0xdb1d3f02,0x00000000,0x00000000,0x00000000}},	//   _rasé, --, --, --, 
   {{0x6280a667,0xdb1db93e,0xf1a001c6,0x386400e5}},	//   tsmo, _sasé, үрэн, ínre_, 
   {{0x62801730,0x20080ac5,0xdb1db93f,0x2be00bae}},	//   usmo, _rmai_, _pasé, _पचना, 
   {{0x20080652,0xddcc013a,0x00000000,0x00000000}},	//   _smai_, _svaž, --, --, 
   {{0x20180261,0x245800e4,0xe7bc05d7,0x74104d66}},	//   ério_, _oĩmi_, _ईसाप, _کونا, 
   {{0x6aa447d8,0xf5340302,0x628001bf,0x5ee000cc}},	//   ktif, _פנאי_, psmo, _পেগে, 
   {{0xdb1c002e,0xfbdc004d,0x8335618b,0x00000000}},	//   _tasé, _xiêu_, _اراض, --, 
   {{0x32981203,0xdb0c09a5,0x7c700023,0xa2f40210}},	//   _עבוד, gdaý, _ጸብለል_, इनीज_, 
   {{0xfc3c07ae,0xfba9b940,0x20080270,0x4df8000d}},	//   _phí_, лтай_, _tmai_, _उतरै_, 
   {{0xdb1c145e,0x82c4025c,0x200872dc,0x00000000}},	//   _dasî, _ཀློའ, _umai_, --, 
   {{0x63a4002e,0x9d44c893,0x683800d7,0x00000000}},	// [30530] _ñinu, сеңд, tídn, --, 
   {{0xa3a81d8a,0xfbdc0208,0xdb1c0790,0x00000000}},	//   ख्त_, _riêu_, _insü, --, 
   {{0xe8e0431d,0x2bc471a3,0xfbdc01fb,0x6e200438}},	//   ười_, _लोका, _siêu_, émbe, 
   {{0x2019b941,0xfc3c1132,0xeab001d3,0xfbdc0051}},	//   nnsi_, _uhí_, بعہ_, _piêu_, 
   {{0x6aa5b942,0x2019b943,0x36898c46,0x68380419}},	//   ctif, insi_, усен_, pídn, 
   {{0xe6b40131,0x00000000,0x00000000,0x00000000}},	//   سلىگ, --, --, --, 
   {{0x2c58033b,0x6838473a,0x00000000,0x00000000}},	//   _pčdi_, cído, --, --, 
   {{0xfbdc07ae,0x61f801a4,0xd265b944,0x2018003e}},	//   _tiêu_, _alvl, окий, éril_, 
   {{0xdb1db945,0xb5a422c3,0xca3c0131,0x5fdc0a97}},	//   _masï, _грей, ﻟﯘﺵ_, यानल, 
   {{0x2019b946,0x00000000,0x00000000,0x00000000}},	//   ensi_, --, --, --, 
   {{0xe6bc0086,0x8ee4009e,0x00000000,0x00000000}},	//   _òbòñ, _পেংগ, --, --, 
   {{0x777820ef,0x765805b8,0xddcdb947,0x527400e4}},	//   _jeux, _kuuy, _evaż, _дуку, 
   {{0xdb1c006a,0x765800e8,0x2bc40cb4,0xbd00002e}},	//   _sasî, _juuy, _लोगा, _ňépp, 
   {{0x2019b948,0x7658004c,0x8ff801b9,0x6fd80073}},	//   ansi_, _muuy, ارگر_, याहू, 
   {{0x4fc00075,0x76582252,0xb14404fb,0xdb1c000d}},	//   _قەدە, _luuy, _دیدم_, _ensü, 
   {{0x63a4002e,0x00000000,0x00000000,0x00000000}},	//   _ñint, --, --, --, 
   {{0x6aa5b949,0x61f80076,0xc9580395,0x20dc00d7}},	// [30540] utif, _ylvl, ашец_, ršiť_, 
   {{0x245800e4,0x0d2000f7,0x683800d7,0x238c0153}},	//   _hũme_, _жүгү, tído, mėjų_, 
   {{0x20dc01f1,0x6aa5b94a,0xbf98000f,0x69c80162}},	//   pšiť_, stif, miêr, _ódem, 
   {{0x5fdc0574,0x6aa4a09e,0xc6680114,0xe9a80014}},	//   यायल, ptif, ашке_, _گگرن_, 
   {{0x777820ef,0xfbddb94b,0x82b40135,0x238c0153}},	//   _deux, _viêt_, _དགེའ, nėjų_, 
   {{0xdb1c06d9,0x7ae817da,0x04642c25,0x35d00108}},	//   _masì, ägte, отим, дошё, 
   {{0x76580098,0x5fdc0825,0xdb1c01e1,0x2a6001d5}},	//   _euuy, यामल, _lasì, lqib_, 
   {{0x82c40135,0x76581418,0xde700882,0xdb1c00cf}},	//   _ཀླུའ, _fuuy, hyāṃ_, _insò, 
   {{0x76582878,0x36643225,0x04f80154,0x238c0064}},	//   _guuy, _мато_, ইপের_, jėjų_, 
   {{0x238c0006,0x7778003a,0xe29800c7,0x00000000}},	//   dėjų_, _zeux, ааҩ_, --, 
   {{0x03a4036b,0xbf98017a,0x838400c0,0x00000000}},	//   _мижо, diêr, _дыле, --, 
   {{0x7658037e,0xd6d80408,0x238c00c0,0x00000000}},	//   _yuuy, _нтĕ_, fėjų_, --, 
   {{0x238c0024,0x41e402d5,0x5ee000eb,0x00000000}},	//   gėjų_, _міка, _পেজে, --, 
   {{0xceac05d9,0x2018003e,0xa1f801d3,0x1288179e}},	//   اڙي_, snsi_, _چڑھا_, _اموی_, 
   {{0x271c07ae,0x63a40113,0x1bd400a7,0x8024007b}},	//   ỉnh_, _ñins, повя, _وربم, 
   {{0xdfd000c6,0x929c033f,0x60dc75ee,0xc04400f1}},	//   _أية_, szłe, ärmu, _بختو, 
   {{0x34b47b05,0xdb1c0100,0x77780369,0x2a6000f1}},	// [30550] _आन्द, _ansò, _reux, gqib_, 
   {{0x77780165,0x68380306,0x19c40116,0x53d001f9}},	//   _seux, sídl, чәмг, _दोनश, 
   {{0xd7599243,0x76580009,0x245800e4,0x1ee801e2}},	//   ملات_, _suuy, _yũme_, _خوښی_, 
   {{0x9f6400f2,0x76580055,0xdb1c294d,0x00000000}},	//   ètèk_, _puuy, _hasí, --, 
   {{0x2bc44802,0xdb1c1705,0x7658004d,0x2a600175}},	//   _लोटा, _kasí, _quuy, cqib_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x82b40003,0xdb1c13d5,0x76580337,0xa7c000de}},	//   _དགུའ, _masí, _wuuy, _šķūn, 
   {{0x7658022f,0xdb0c3eba,0x00000000,0x00000000}},	//   _tuuy, ldañ, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb0c04d4,0xdb1c013d,0xb9d00023,0x238c0153}},	//   ndañ, _nasí, _ኻአ_, vėjų_, 
   {{0x44440050,0x00000000,0x00000000,0x00000000}},	//   _کرٕہ, --, --, --, 
   {{0xb4d47688,0x1728025c,0xe3b000f1,0x74103fe6}},	//   ामी_, _སྙོམ_, _لره_, _کوچا, 
   {{0x69cc791c,0x4dd400d4,0x00000000,0x00000000}},	//   _सफली, півф, --, --, 
   {{0x238c0024,0xa1c40212,0x00000000,0x00000000}},	//   rėjų_, _обід, --, --, 
   {{0xe6b812eb,0x238c0024,0x19e401ec,0x60dc343a}},	//   _इन्ज, sėjų_, _ﺍﻷﻫﻠ, ärmt, 
   {{0xde700882,0x40300f5c,0x2a60031c,0x238c0064}},	//   syāṃ_, _пејс, tqib_, pėjų_, 
   {{0x64a00153,0xb4d4024a,0x00000000,0x00000000}},	// [30560] mšiš, ामु_, --, --, 
   {{0x2d9c2d75,0x7d2401d3,0x2a6001a9,0x64a00064}},	//   _øve_, érsé, rqib_, lšiš, 
   {{0x53bdb94c,0x9f5800eb,0x00000000,0x00000000}},	//   ्याश, cisó_, --, --, 
   {{0xdb1c012c,0x9f580ffb,0x8d74030f,0x00000000}},	//   _zasí, lisò_, _باکا, --, 
   {{0x5fdc0574,0xdb1c008e,0x00000000,0x00000000}},	//   यातल, _yasí, --, --, 
   {{0xe5355b82,0xdb1c0139,0x29380150,0x6594014b}},	//   мель, _xasí, _ﺗﺎﭖ_, факу, 
   {{0x2019b94d,0xdb0c041e,0xb6a400db,0x64a00064}},	//   érik_, ldað, _ۉشكۉ, kšiš, 
   {{0x46a4014b,0x00000000,0x00000000,0x00000000}},	//   _набв, --, --, --, 
   {{0xdb0c1f60,0x64a001a6,0x00000000,0x00000000}},	//   ndað, dšiš, --, --, 
   {{0x6ed000bc,0x64a00153,0x00000000,0x00000000}},	//   दिनु, ešiš, --, --, 
   {{0x1fb88b88,0x5f95b94e,0xdfd00035,0xbd840240}},	//   олны_, минт, نيد_, _ንምቛም_, 
   {{0x200c0086,0x9f580789,0x03a402a9,0x00000000}},	//   òei_, visó_, _хидо, --, 
   {{0xdb0c0120,0xdb1db94f,0x00000000,0x00000000}},	//   meaç, _pasí, --, --, 
   {{0x61140b7f,0x9f58007b,0x60dc0267,0xe0fc0055}},	//   _одлу, mhsí_, ärms, _etāḿ_, 
   {{0x3130016c,0x6e207cd8,0x513802dd,0xefc00023}},	//   _пешр, émba, _وزىڭ_, _ስዑዲ_, 
   {{0x6c5576ac,0xdb1c0139,0x6e20035b,0x00000000}},	//   ексу, _wasí, ĩmba, --, 
   {{0x645c011c,0xdb0c0162,0x0ba40124,0xe89400c7}},	// [30570] _èrif, gdað, ьырҭ, ҵахь, 
   {{0x6838038e,0xdb1c0165,0x00000000,0x00000000}},	//   bídk, _pasâ, --, --, 
   {{0x49f40156,0x41ac878d,0xd7540023,0x9b58022e}},	//   བྲེལ_, ज्यस, ገዳስነ, _минт_, 
   {{0x2d9c0628,0x6569b950,0x00000000,0x00000000}},	//   _över_, _afdh, --, --, 
   {{0x76a873e6,0x8b649e7c,0x6ed01be1,0x00000000}},	//   стев_, _تاپم, दियु, --, 
   {{0xdb1c0109,0x2a64020c,0x99d40451,0x00000000}},	//   _iasà, _émba_, _تڪرا, --, 
   {{0xb4d409ae,0x7d000432,0x00000000,0x00000000}},	//   ामे_, _ünsd, --, --, 
   {{0xf771b951,0x58840220,0x00000000,0x00000000}},	//   _سار_, _ныға, --, --, 
   {{0xb400009d,0x59d00f4a,0x00000000,0x00000000}},	//   _үүлд, _सफार, --, --, 
   {{0xdb1db952,0x00000000,0x00000000,0x00000000}},	//   _masà, --, --, --, 
   {{0x64a00f8b,0xe2a80014,0x92cc0154,0x00000000}},	//   tšiš, _ہاون_, রহে_, --, 
   {{0x683800bc,0x9f5801e7,0x69d801d3,0x00000000}},	//   vídk, bhsí_, övez, --, 
   {{0xa2e400d4,0x60dc007c,0x00000000,0x00000000}},	//   _поїд, ärmr, --, --, 
   {{0x2d8c002d,0x9424010a,0xdb0c03b2,0x00000000}},	//   ûde_, _емçе, vdað, --, 
   {{0x0d2000f7,0xd2680092,0x00000000,0x00000000}},	//   түнү, _ተባባሪ_, --, --, 
   {{0xdb1c05da,0x00000000,0x00000000,0x00000000}},	//   _basà, --, --, --, 
   {{0xdb1c04cc,0xc22001ed,0xb81003d4,0xcf2401f7}},	// [30580] _casà, _سکیو, িকাত_, _ترغي, 
   {{0x6839b953,0x6d4000ac,0x891458c5,0x00000000}},	//   mídi, əman, وبائ, --, 
   {{0x245800e4,0xb4d43996,0xfbdc0208,0xe98400db}},	//   _oũma_, ामो_, _tiêp_, _ۋاسۋ, 
   {{0xb4d4012c,0x88940124,0xd6d80210,0x00000000}},	//   ामै_, зиҧх, _szła_, --, 
   {{0x6b85b954,0x7a34063f,0xddc40055,0x4e78010f}},	//   maig, ụtac, _nihś, קאַצ, 
   {{0x6b85b955,0x00000000,0x00000000,0x00000000}},	//   laig, --, --, --, 
   {{0x6b840618,0xf860014b,0x00000000,0x00000000}},	//   oaig, _авсо, --, --, 
   {{0x6b85b956,0x82880b32,0xdb1c00e5,0x7d0000a2}},	//   naig, особ_, _hasá, _ünse, 
   {{0xdb1c0306,0xf694007b,0x5fdc024a,0x00000000}},	//   _kasá, _ينفع_, यासल, --, 
   {{0x6b85b957,0x26c5b958,0x1728025c,0x68380077}},	//   haig, _ismo_, _སྙིམ_, dídi, 
   {{0xdb1c0232,0x6b85b959,0xdbcc01e1,0xca3c00d1}},	//   _masá, kaig, _bóìs, ﻟﯘﺏ_, 
   {{0xdb1db95a,0x929c033f,0x00000000,0x00000000}},	//   _insö, szła, --, --, 
   {{0x6b85b95b,0x6d480209,0x41e4007b,0xa19400d8}},	//   daig, ýdan, _يستف, _залч, 
   {{0x61ac00bd,0xdb1c02fb,0x26c40798,0xe0d00014}},	//   _কোরআ, _nasá, _msmo_, _مٲت_, 
   {{0x6b85b95c,0xdb1d18a7,0xcec400c7,0xd17400db}},	//   faig, _sasà, _ҧшьҩ, _чычы, 
   {{0x6b85b95d,0x26c5b95e,0xdb1c05d5,0xb6040171}},	//   gaig, _osmo_, _pasà, _iešū, 
   {{0x683806ed,0xdb1db95f,0x44cc00c0,0x7a280112}},	// [30590] cídi, _basá, _lę_, mütz, 
   {{0xdb1c0142,0xbd840133,0x00000000,0x00000000}},	//   _casá, _زۆرن_, --, --, 
   {{0x6b8402d5,0x26c401c6,0x25bc0076,0x44cc0064}},	//   baig, _asmo_, devl_, _nę_, 
   {{0x6b85b960,0x7a280e78,0x00000000,0x00000000}},	//   caig, nütz, --, --, 
   {{0xb4d41161,0xdb1db961,0xaa64009b,0xed6400c0}},	//   ाम्_, _ansö, _атск, bužį_, 
   {{0x7a28bf5a,0xa5940801,0xa5f80b87,0xdb1c0142}},	//   hütz, връщ, мечу_, _gasá, 
   {{0xa4840b24,0x68380419,0x00000000,0x00000000}},	//   نجين, zídi, --, --, 
   {{0xdb1c00bc,0x44cc0064,0x00000000,0x00000000}},	//   _zasá, _dę_, --, --, 
   {{0x35681eed,0x00000000,0x00000000,0x00000000}},	//   _дрен_, --, --, --, 
   {{0x292403b2,0x6b85b962,0x690400a2,0xddd4010e}},	//   _ærað_, zaig, _öwdü, _ýaňr, 
   {{0x44cc0064,0x6b85b963,0x00000000,0x00000000}},	//   _gę_, yaig, --, --, 
   {{0xc474011a,0x00000000,0x00000000,0x00000000}},	//   _נתנו_, --, --, --, 
   {{0xb8f8025c,0x6e200098,0x00000000,0x00000000}},	//   _ྡན_, émbo, --, --, 
   {{0x11d800c6,0x6b85b964,0x09cc012d,0x00000000}},	//   _روعة_, waig, _होंठ, --, 
   {{0x6b85b965,0xc5f000c8,0x68388607,0xd064016b}},	//   taig, נדל_, sídi, _ɔpɛt, 
   {{0x6838021c,0x6b85b966,0x00000000,0x00000000}},	//   pídi, uaig, --, --, 
   {{0xdb1d071b,0x4a45b2ae,0xda64004b,0x49940276}},	// [305a0] _pasá, енав, نالي, ешет, 
   {{0x6b841549,0x6fd4000d,0x6fd801f9,0x00000000}},	//   saig, _बोतू, याकू, --, 
   {{0x7d780302,0xdb1c00dd,0xf8ac00aa,0x6b85b967}},	//   _מניו, _vasá, یکې_, paig, 
   {{0xc6a5b2b5,0xc724113e,0x69d00118,0x00000000}},	//   ерки, ндей, _डोरी, --, 
   {{0xfa640395,0x00000000,0x00000000,0x00000000}},	//   _паяк_, --, --, --, 
   {{0x8c000183,0x06b000cc,0xc64400db,0x00000000}},	//   _এদিন_, চিলি, رئشى, --, 
   {{0x69ddb968,0x00000000,0x00000000,0x00000000}},	//   _inre, --, --, --, 
   {{0x44200428,0x9f48010e,0x97b41fbe,0xa3d40117}},	//   õk_, _alaý_, _исуш, тоич, 
   {{0x46142aaf,0xf1d80490,0x8504004b,0x042000eb}},	//   _كورر, बांन, _ګوان, মতলী_, 
   {{0x84e4656c,0x2258b625,0x44cc068f,0xdb1c0798}},	//   _позж, örk_, _tę_, _insô, 
   {{0x7a280639,0x6d480209,0x84950325,0xaed4013e}},	//   tütz, ýdal, _سجائ, ҳояш, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69dc22b0,0x00000000,0x00000000,0x00000000}},	//   _onre, --, --, --, 
   {{0x69d0000d,0xb8d00327,0xa1940798,0x9cb80150}},	//   _डोली, _དྱ_, _ракч, _ﺸﻴﻭﻋ, 
   {{0xd24c314c,0x3ea8009a,0x11e8007b,0x00000000}},	//   _بچي_, stct_, _تعني_, --, 
   {{0x69ddb969,0x5ed400c7,0x00000000,0x00000000}},	//   _anre, _ажиу, --, --, 
   {{0x5a3464e1,0xaa940a5b,0x201800d7,0x00000000}},	// [305b0] внат, литч, ériu_, --, 
   {{0xa4fc0327,0x5fa000d1,0xd6d80210,0x00000000}},	//   ྐྱོག_, _ﺋﯚﭼﯘ, _szło_, --, 
   {{0xa9a41183,0xec6802e8,0x2bd801f9,0x68380139}},	//   اممى, _пряк_, डाखा, hídu, 
   {{0x69dc388b,0x9bc402dd,0xb12c0432,0x96b800db}},	//   _enre, _جۇرە_, _üýşm, дуку_, 
   {{0xa3d400bc,0x2b444f73,0xead80064,0x00000000}},	//   िएन_, _бэрг, _змяі_, --, 
   {{0x27e0005f,0xe8f8074d,0xd1d80023,0x5fdc0118}},	//   ķina_, ллĕ_, ዮታት_, याँल, 
   {{0xb95400cf,0xdb1c0205,0xb7b0004e,0x95b400c7}},	//   _سئست, _basç, _бөлч, ерқә, 
   {{0xe7841d0f,0x13bc00cd,0x00000000,0x00000000}},	//   _буфо, ्येभ, --, --, 
   {{0x24801326,0x38600161,0x91801e87,0xd175b96a}},	//   ćima_, _hujr_, لۇشۇ, кыны, 
   {{0x929c0034,0x80c8015b,0xb3d000fd,0xc4c000ec}},	//   szło, িমন্, _әйдә, _چڪيو, 
   {{0xe2a80344,0x78a806be,0x00000000,0x00000000}},	//   واین_, _çovğ, --, --, 
   {{0x8fd018ce,0xdb1c0036,0x00000000,0x00000000}},	//   рәкә, _kasä, --, --, 
   {{0xb8d0025c,0xdb0c0086,0xfbdc0051,0x20fc0051}},	//   _དཱ_, reaû, _phên_, ải_, 
   {{0x645c0395,0x00000000,0x00000000,0x00000000}},	//   _èric, --, --, --, 
   {{0x6e3c08a5,0xdb1c0793,0xbd80b40e,0x645c0c6a}},	//   rlrb, _lasä, ргск, _érit, 
   {{0x20191746,0xe88c02d3,0xe0d00133,0x6fb000fe}},	//   érit_, _ኣፍሊጡ_, _دزه_, _জোৰে, 
   {{0xe0440014,0x3b040241,0x09f8007b,0x89f800e5}},	// [305c0] _حضوٝ, _rìpé_, وفرة_, وٹرز_, 
   {{0xfe9806a9,0x26d80118,0x00000000,0x00000000}},	//   _קיימ, _čro_, --, --, 
   {{0x244800d2,0x69dc0208,0xa3d428fe,0x00000000}},	//   lûme_, _vnre, िएम_, --, 
   {{0xdb1c145e,0x6b68002e,0xd7f802dd,0x7d009016}},	//   _basä, _dégó, нуі_, _ünsa, 
   {{0xca7418ce,0x6595b96b,0xdb1c0139,0x4a7401ec}},	//   _шуны, галу, _rasç, _шынт, 
   {{0x6839b96c,0x69ddb96d,0x071001f2,0xddcc0205}},	//   vídu, _unre, tụbọ, _muaş, 
   {{0xf48021f7,0x2448019f,0x3860020c,0x3b040248}},	//   ауын, hûme_, _gujr_, _tìpé_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfe1007f7,0xfbac00cc,0x00000000,0x00000000}},	//   _डगलस_, _চোঁত, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6839b96e,0xbb180276,0xbf9800d2,0xe01801ce}},	//   sídu, _neîn, bhêl, ежні_, 
   {{0xdb1c0fac,0x661876e0,0xdfd016a2,0x00000000}},	//   _haså, livk, حيح_, --, 
   {{0x4425b96f,0xa29402d5,0x82f80214,0x00000000}},	//   _ijo_, _салі, _تراز_, --, 
   {{0x44241b9c,0x661876e0,0x00000000,0x00000000}},	//   _hjo_, nivk, --, --, 
   {{0x4424067d,0xdfd40efb,0xd0400213,0x00000000}},	//   _kjo_, _бойы, hvlə, --, 
   {{0x9f05b970,0x44240337,0x6b6801d3,0xc10000ec}},	//   _موعو, _jjo_, _régó, _موڙي, 
   {{0xab84a8fc,0x44240a40,0x934c0075,0x66180158}},	// [305d0] руск, _mjo_, ﻟﯩﺪﯗ_, kivk, 
   {{0x66180219,0x2cc800fd,0xaed40408,0x00000000}},	//   jivk, äwdä_, _тоьш, --, 
   {{0x4425b971,0x66180306,0x38c40395,0x15cc0150}},	//   _ojo_, divk, ъщав, _ﻓﺄﻨﻬ, 
   {{0xba75b972,0x4425b973,0xe8941fe2,0x68f803cd}},	//   _لاست, _njo_, раць, øvda, 
   {{0x4b781203,0xdb1c01e3,0xaa940139,0x20180254}},	//   _ראשו, _baså, _кияч, iisi_, 
   {{0x4425b974,0xa2b8095f,0x2019b975,0x00000000}},	//   _ajo_, ्बन्, hisi_, --, 
   {{0x2019b976,0x44247483,0x37a80046,0xd39418c7}},	//   kisi_, _bjo_, _отан_, гәлә_, 
   {{0x2019b977,0x44246bfc,0xdec00092,0x00000000}},	//   jisi_, _cjo_, ስህን_, --, 
   {{0x2019b978,0x44240100,0x55a401ed,0x9f4800a2}},	//   disi_, _djo_, _مجاہ, _olañ_, 
   {{0x4425b979,0x20180064,0x0200009d,0x00000000}},	//   _ejo_, eisi_, йзын, --, 
   {{0xfbdd3cc3,0xaee400b8,0x00000000,0x00000000}},	//   _diêz_, bhṛk, --, --, 
   {{0xfbdc073c,0xbb180276,0x44240240,0x889800d9}},	//   _nnê_, _reîn, _gjo_, עברי, 
   {{0x201856eb,0xfbdc0051,0x19e40150,0x24580064}},	//   èria_, _chêm_, _ﺍﻷﻁﻠ, _раць_, 
   {{0x831800c8,0x2019b97a,0x5fdc0bae,0x24480022}},	//   _אונז, érir_, याउल, rûme_, 
   {{0x2019b97b,0xd8380069,0x8c2000eb,0x00000000}},	//   bisi_, _okō_, _ভীষন_, --, 
   {{0x6618110c,0x683800e4,0x2054004e,0x601c00e4}},	//   zivk, hídr, _ктыр, tũme, 
   {{0xc1e5b97c,0x0b4400c2,0x3b040798,0xbfc80116}},	// [305e0] _شکیل_, унан, гето_, _سايە_, 
   {{0xd838007f,0xe23802d3,0x206800fd,0x00000000}},	//   _akō_, _ርእሰዓ, _яшәп_, --, 
   {{0x9f4802d2,0x00000000,0x00000000,0x00000000}},	//   _hlað_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x44240010,0x26c800d1,0x00000000,0x00000000}},	//   _rjo_, ъған_, --, --, 
   {{0x2019b97d,0x442403cd,0x80c8009e,0x35b00220}},	//   zisi_, _sjo_, িমত্, йбір, 
   {{0x2019b97e,0x442401fa,0x66195402,0x248004a7}},	//   yisi_, _pjo_, rivk, ćimo_, 
   {{0x20180564,0x6fd40d79,0x717402dd,0x661802f0}},	//   xisi_, _बोलू, ңбыр_, sivk, 
   {{0x2019b97f,0xf740084c,0x225c0010,0x87247a9c}},	//   visi_, _гето, _pivk_, _смаж, 
   {{0x2019b980,0x32b40597,0x36643edf,0xa194033a}},	//   wisi_, ادية_, _сафо_, јанч, 
   {{0x44240a40,0x1cb0031c,0x3a340375,0xb4b4132f}},	//   _tjo_, _ནཱེ_, ררים_, _مُلا_, 
   {{0x4425b981,0x9f480ad9,0xd9d0012c,0x71a0035b}},	//   _ujo_, _blað_, _सफ्ट, ақәҵ, 
   {{0x80c82158,0x9f4805c7,0x601c00c7,0x00000000}},	//   িমধ্, _plañ_, tũmb, --, 
   {{0x6441b982,0xf2d00677,0x00000000,0x00000000}},	//   llmi, _לענ_, --, --, 
   {{0x6440017a,0x601c0124,0x00000000,0x00000000}},	//   olmi, rũmb, --, --, 
   {{0xfbdc01dc,0xeaf80424,0x601c00c7,0x2019b983}},	//   _thêm_, گرفت_, sũmb, qisi_, 
   {{0x7c3c074d,0x3f88a33f,0x9f4806ea,0x6440c2f8}},	// [305f0] rlqr, macu_, _glað_, ilmi, 
   {{0x6440ab3b,0xd999b3eb,0x5fdc0316,0x5fd81d8a}},	//   hlmi, ئنات_, याकल, _बोतल, 
   {{0xf771b984,0x394401e3,0x00000000,0x00000000}},	//   ماش_, åns_, --, --, 
   {{0x3f89b985,0xf09000d9,0x00000000,0x00000000}},	//   nacu_, מנע_, --, --, 
   {{0x7bcc0483,0x95840408,0x75b401ec,0xa3a800bc}},	//   _iacu, алле, лғат_, ख्छ_, 
   {{0x6441b986,0x7bcdb987,0x3f89b988,0x58d4005b}},	//   elmi, _hacu, hacu_, _когт, 
   {{0x7bcdb989,0x3f880286,0x3dd400bd,0x4611b98a}},	//   _kacu, kacu_, _সকাল, توور, 
   {{0x7bcdb98b,0x3f89b98c,0xd7c85da7,0x00000000}},	//   _jacu, jacu_, _جوره_, --, 
   {{0x02840228,0xbf9800e4,0xe73801ee,0xd17800d4}},	//   айык_, ahêk, _беѓ_, ксні_, 
   {{0x7bcdb98d,0x7984019f,0x91f4084c,0xf4840f32}},	//   _lacu, _jejw, рчич, _будн, 
   {{0x64400ffb,0x3f880ffb,0xd009b98e,0xdce4002b}},	//   blmi, facu_, вене_, _dehī, 
   {{0x7bcc00ca,0x7984ac5c,0x645c00d2,0x8fa5b98f}},	//   _nacu, _lejw, _érip, шаме, 
   {{0xd1740228,0x60d80076,0x00000000,0x00000000}},	//   _кыйы, _ervm, --, --, 
   {{0x7bcdb990,0x7984047e,0x00000000,0x00000000}},	//   _aacu, _nejw, --, --, 
   {{0x3f89b991,0x10a4210b,0xfafc00e8,0xdb1c00ae}},	//   bacu_, _тийн, _ngëb_, _gasú, 
   {{0x7bcdb992,0x8b24970e,0x3f8800d8,0xfc0000d8}},	//   _cacu, адбе, cacu_, опсо, 
   {{0xc5fc02a6,0x7bcc0c86,0x7984016d,0x2ba8012c}},	// [30600] ্চতা_, _dacu, _bejw, गलबा, 
   {{0x4c8400f0,0x00000000,0x00000000,0x00000000}},	//   _клов, --, --, --, 
   {{0x7bcd35fc,0x798402e2,0x08c44255,0x4d48026b}},	//   _facu, _dejw, рбен, _шпон_, 
   {{0x7bcdb993,0x27e008e7,0x2b5800f2,0x00000000}},	//   _gacu, ñin_, _میزد_, --, 
   {{0x41a402ab,0x05e0095f,0x00000000,0x00000000}},	//   _खालस, पालब, --, --, 
   {{0x3f88deae,0x28882580,0x6aa401b8,0xdb0801e1}},	//   zacu_, _مصری_, muif, _áláy, 
   {{0x7bcdb994,0x245800e4,0x3f880230,0x6aa401f5}},	//   _yacu, _hũmi_, yacu_, luif, 
   {{0x3edc01f2,0x7984014b,0x7bcc0098,0xc69001d9}},	//   _stọọ_, _zejw, _xacu, _وِز_, 
   {{0x7984014b,0x6aa40140,0xddcc01e4,0x41e402d5}},	//   _yejw, nuif, _staŭ, аіна, 
   {{0x3f8801b2,0xe2141e76,0xf5e405d9,0x453407d5}},	//   wacu_, ёмны, _پڙهي_, _кхет, 
   {{0x6aa40196,0xf9900375,0x30a002e8,0xbb180356}},	//   huif, חרת_, оряв, _reîm, 
   {{0x6aa5b995,0xdb1c01ed,0xa2b80782,0xd4f401af}},	//   kuif, _vasú, ्बद्, _уяуы, 
   {{0x3f880cf4,0xbb18026c,0x741073c9,0x42080139}},	//   racu_, _peîm, _بونا, _индо_, 
   {{0x3f880cf4,0xc0640408,0x00000000,0x00000000}},	//   sacu_, _къий, --, --, 
   {{0x7bcdb996,0x3f880a2e,0x4084a5c1,0xfba8cb0f}},	//   _pacu, pacu_, _тулб, ктай_, 
   {{0x79841a83,0xad240075,0x6aa40618,0x41a46c95}},	//   _sejw, زىقى, fuif, _खाँस, 
   {{0x7bcdb997,0x798401f9,0x6aa4b0b3,0x79a400ee}},	// [30610] _vacu, _pejw, guif, ирже, 
   {{0x7bcdb998,0x195807ee,0x00000000,0x00000000}},	//   _wacu, газы_, --, --, 
   {{0x7bcdb999,0x1cb0031c,0x6e200066,0x6934014b}},	//   _tacu, _ནཱི_, èmbe, онфу, 
   {{0x7bcdb99a,0x3ddc0198,0x6e89b99b,0x7984014f}},	//   _uacu, ɓuwa_, _حنیف_, _wejw, 
   {{0xd6d8068f,0xb6c5b99c,0x41a4012d,0x00000000}},	//   _była_, рсей, _खांस, --, 
   {{0x9990012d,0x39b4013a,0x00000000,0x00000000}},	//   żały_, _děsí_, --, --, 
   {{0xe895b99d,0x6b8c0166,0x00000000,0x00000000}},	//   _марь, _ölgä, --, --, 
   {{0x53c80283,0xd2a8023a,0x68f80267,0x00000000}},	//   угим_, гкие_, ävde, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9f58007b,0x244800e4,0x00000000,0x00000000}},	//   bhsú_, rûma_, --, --, 
   {{0x3444008e,0xefc00023,0x00000000,0x00000000}},	//   _күки_, ድሕዱ_, --, --, 
   {{0x7641b99e,0xdb24006a,0xd00800d8,0x00000000}},	//   llny, ûpûl, уеме_, --, 
   {{0xa3d4012c,0xe3b017a5,0xe1f8013e,0x00000000}},	//   िएर_, _آرم_, угӯ_, --, 
   {{0xc278010f,0xace80116,0x601c00e4,0x00000000}},	//   _ערצי, қмға_, rũma, --, 
   {{0x61fdb99f,0xddcc084c,0x76400263,0x00000000}},	//   örle, _staţ, ilny, --, 
   {{0x60dc4e9b,0x68e81574,0x2498005c,0xddcc012d}},	//   ærme, _àddi, _ærme_, _zważ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [30620] --, --, --, --, 
   {{0x0dc80416,0x6aa4017a,0x4a740150,0x00000000}},	//   _слой_, ruif, _қымт, --, 
   {{0x1cb0025c,0x6aa4013c,0x19e40150,0x5fdc2894}},	//   _ནཱག_, suif, _ﺍﻷﻗﻠ, याचल, 
   {{0x8709b9a0,0x6aa40607,0x7640772f,0x38c804f2}},	//   леев_, puif, elny, طامی_, 
   {{0xadecbebc,0x00000000,0x00000000,0x00000000}},	//   ञापन_, --, --, --, 
   {{0x48e40600,0x24f80166,0x00000000,0x00000000}},	//   _логв, инлы_, --, --, 
   {{0x7d78008f,0xd1e80092,0x987400f3,0x00000000}},	//   אנצו, ህናት_, _мутљ, --, 
   {{0xd90c5194,0x7641b9a1,0x02a40828,0x00000000}},	//   _جیم_, alny, бром, --, 
   {{0x645c0395,0xfbd0011a,0x73d4010b,0x25ac0051}},	//   _èrim, לתה_, сдыр_, _tcdl_, 
   {{0xddcc00f3,0xa0b80022,0x25a8179e,0x66e40117}},	//   _otaš, агоу_, _خضری_, _лоға, 
   {{0x4544007b,0x6609b9a2,0x00000000,0x00000000}},	//   _اناق, _ildk, --, --, 
   {{0x82a5b9a3,0x00000000,0x00000000,0x00000000}},	//   _гадж, --, --, --, 
   {{0x60dc005c,0xddcc6e98,0x67080073,0x00000000}},	//   ærmb, _ataš, वनिक_, --, 
   {{0xddcc068f,0xa158008e,0x5fd807f7,0x00000000}},	//   _uważ, _калу_, _बोरल, --, 
   {{0x15cc01ec,0x00000000,0x00000000,0x00000000}},	//   _ﻓﺄﻴﻬ, --, --, --, 
   {{0x27e40280,0xbf9800e4,0xac18cd64,0x92cc03d4}},	//   _nnmn_, ehêv, босу_, ৰহৰ_, 
   {{0xfafc02d3,0x200942db,0x660805ac,0xeab0007b}},	// [30630] _afër_, _ilai_, _oldk, فعل_, 
   {{0xa3d4302b,0x00000000,0x00000000,0x00000000}},	//   िएँ_, --, --, --, 
   {{0x3e6c0036,0x20080064,0x00000000,0x00000000}},	//   _hüt_, _klai_, --, --, 
   {{0xd74002d3,0x8cc40490,0xe858020a,0x5ba80137}},	//   _ንሓርነ, ाबरो, бахш_, _өкүм_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x200800a9,0x3e6c06be,0xd2f801d5,0x1dac00cd}},	//   _llai_, _müt_, یکشا_, ञ्चत, 
   {{0x2009b9a4,0x114402d3,0xfc3c02d2,0x3e6c0213}},	//   _olai_, _ሚስዮና, _kkí_, _lüt_, 
   {{0x5fd8d825,0xdb0db9a5,0x20080162,0x66087e05}},	//   _बोलल, leañ, _nlai_, _eldk, 
   {{0x66f4084c,0x32040306,0x9b1801ec,0x95c4009f}},	//   _епту, _plny_, лтiр, _ويره, 
   {{0x3448eabc,0x50b4329b,0x92940124,0xdb0c00e4}},	//   _өчен_, осму, баҩц, neañ, 
   {{0x32040122,0x20084530,0x00000000,0x00000000}},	//   _vlny_, _blai_, --, --, 
   {{0xf485b9a6,0x2008015d,0xfbdc004d,0x3e6c03b9}},	//   _ناچی, _clai_, _khêu_, _büt_, 
   {{0xce49b9a7,0x44440014,0x3e6c03e3,0x0eb8013d}},	//   изме_, _برٕہ, _cüt_, шуны_, 
   {{0x273807ae,0xfc3db9a8,0x27e0005f,0x2009b9a9}},	//   ứng_, _akí_, ķini_, _elai_, 
   {{0x200808cd,0x3e6c0037,0x4250007b,0x8b841870}},	//   _flai_, _eüt_, _تنور, يەدە_, 
   {{0x3e6c05d5,0xc4d002e4,0x20080042,0x00000000}},	//   _füt_, וגל_, _glai_, --, 
   {{0x2448025a,0xbb40648d,0x0ae801a9,0x00000000}},	// [30640] zûmo_, детк, шдай_, --, 
   {{0x49780006,0xb9e401a9,0x00000000,0x00000000}},	//   рсаў_, омуз_, --, --, 
   {{0x6e3db9aa,0xd6d8006d,0x88c8010a,0x00000000}},	//   morb, _było_, рлев_, --, 
   {{0x8c4400a8,0xdb1c0124,0x00000000,0x00000000}},	//   _феме, _hasý, --, --, 
   {{0x06600022,0x00000000,0x00000000,0x00000000}},	//   дҵаҟ, --, --, --, 
   {{0x2ba8951e,0xdb1c0022,0x35f0cea4,0x41ac00cd}},	//   गलवा, _jasý, мпір, ज्ञस, 
   {{0x25a00ab7,0x746420e5,0xd5ac00dd,0x00000000}},	//   ğil_, орыв_, اہم_, --, 
   {{0x25a003ee,0xe2c800ec,0x6e3c01e7,0x1af00154}},	//   şil_, موعو_, horb, _ঘেটে_, 
   {{0x6e3c1ff8,0xd1f00092,0x707c0092,0x00000000}},	//   korb, _ውሎች_, _የተሻሉ_, --, 
   {{0x6e3db9ab,0xdb1c0419,0x7ab80677,0xca4802dd}},	//   jorb, _nasý, סציו, _ﻀﺭﺏ_, 
   {{0x2009b9ac,0x3e6db9ad,0x6d580122,0xfafc1bce}},	//   _plai_, _süt_, _úvah, _ngën_, 
   {{0xdb200122,0x3e6c05d5,0x7d0000ac,0x68e81574}},	//   _štíh, _püt_, _ünsi, _àddu, 
   {{0x600c0a85,0xdb1c0432,0xfc3c02d2,0x00000000}},	//   _nûme, _basý, _rkí_, --, 
   {{0xf28400dd,0x6e3c01c4,0x00000000,0x00000000}},	//   _بھٹو_, gorb, --, --, 
   {{0x317805d0,0x59d4134e,0x00000000,0x00000000}},	//   _דרומ, _डोगर, --, --, 
   {{0x61f9b9ae,0x23bc3b11,0xbc2400d4,0x00000000}},	//   _hovl, ्जिद, ієви, --, 
   {{0xf968e2cc,0x61f92936,0x6e3c00e5,0x5b140798}},	// [30650] арей_, _kovl, borb, чмат, 
   {{0x600c06af,0x50b40214,0xbf980022,0x91ec228d}},	//   _dûme, _بگید_, ahêt, जायज_, 
   {{0x940403b9,0x61f9b9af,0xdb0c0022,0x00000000}},	//   _evlə_, _movl, reañ, --, 
   {{0x600c026c,0x65680067,0xdb1c00d7,0xd75800d8}},	//   _fûme, _agdh, _zasý, биец_, 
   {{0x76c40a8e,0x2ab40166,0x00000000,0x00000000}},	//   تغال, cäb_, --, --, 
   {{0x79e4040b,0xe61800d6,0xdb1c0c86,0x61f80115}},	//   _بوسہ_, оді_, _masü, _novl, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6e3db9b0,0x13e80aae,0x6d400209,0xfbdc001e}},	//   zorb, смий_, şmag, _thêu_, 
   {{0x61f9b9b1,0x00000000,0x00000000,0x00000000}},	//   _bovl, --, --, --, 
   {{0x10a5b9b2,0x11d400c6,0xdb1c000c,0x61f80076}},	//   пион, ستخد, _absë, _covl, 
   {{0x61f9b9b3,0x6e3c0112,0xdb1c0022,0x61fc0267}},	//   _dovl, vorb, _rasý, örla, 
   {{0x6e3c03fa,0x60dc0b1a,0x68f80162,0x00000000}},	//   worb, ærma, øvdi, --, 
   {{0xdb1c04d4,0xdd0002b1,0x00000000,0x00000000}},	//   _masó, _ātāh, --, --, 
   {{0x2d8c7c36,0x22780ae5,0x226400d0,0xdb1c012d}},	//   úde_, _بلوگ_, ľskú_, _lasó, 
   {{0x6e3c0af9,0x4fc0516c,0xef1c000d,0x22640419}},	//   rorb, _كەدە, _पेरऽ_, žskú_, 
   {{0xc4d01a4c,0xbdf804b3,0xdb1c03e0,0x00000000}},	//   עגן_, _ۇرپا_, _fasü, --, 
   {{0x2fc0357f,0x61f8022e,0x1fb40154,0x6fbc23e9}},	// [30660] _ibig_, _yovl, _জোকস, ष्णू, 
   {{0x61f82f3b,0x6e3c031c,0x88c000fe,0x00000000}},	//   _xovl, qorb, োমসক, --, 
   {{0xdb1db9b4,0x3df8011a,0x00000000,0x00000000}},	//   _basó, _הליד, --, --, 
   {{0xdb1db9b5,0xde6c0016,0x2fc0030a,0x06e809a5}},	//   _obsè, _hươn, _jbig_, ймек_, 
   {{0x6b85b9b6,0x6d4051c8,0x8ad4010b,0x073842f4}},	//   mbig, şmad, _эюнц, حساب_, 
   {{0x6b85b9b7,0x7c382625,0xbf980165,0xe7380139}},	//   lbig, čure, nhêr, беҗ_, 
   {{0xdb1db9b8,0x589400f7,0x61f801b9,0xde6c004d}},	//   _absè, _ошту, _rovl, _mươn, 
   {{0xde6c0016,0x6b854091,0x61f8047e,0x2ee001d5}},	//   _lươn, nbig, _sovl, _orif_, 
   {{0x6b84113c,0x6aa403cb,0x7980002d,0xdb0c0129}},	//   ibig, nrif, űnwe, rfaç, 
   {{0xdb0c0261,0x2fc0003a,0xde6c001e,0x26c40455}},	//   sfaç, _abig_, _nươn, _ipmo_, 
   {{0x6aa5b9b9,0xbef4012c,0xc05802dd,0x54d40408}},	//   hrif, ुन्न_, йім_, _оццу, 
   {{0xfe7c0054,0x2ee000a9,0x00000000,0x00000000}},	//   tpï_, _brif_, --, --, 
   {{0x61f86064,0x2ee024a6,0x64a4010b,0x6b840009}},	//   _tovl, _crif_, _хаҗа, dbig, 
   {{0x2ee1b9ba,0x6aa41a82,0x932400aa,0xde6c001e}},	//   _drif_, drif, _ترمن, _cươn, 
   {{0xde6c07ae,0x6aa40194,0xdfd40220,0xec68004e}},	//   _dươn, erif, _жойы, зрук_, 
   {{0xdfd0215e,0x6aa40cfd,0x6b848b14,0x929c012d}},	//   _شيخ_, frif, gbig, syłe, 
   {{0x6aa5b9bb,0x600c025a,0x2ee1b9bc,0xb0380bd9}},	// [30670] grif, _tûmb, _grif_, _מנהג_, 
   {{0xde6c0016,0xddcc0374,0x6b85b9bd,0x62800ea0}},	//   _gươn, _muaū, abig, ipmo, 
   {{0x6b85b9be,0x6aa5b9bf,0xee782e6b,0x8d800092}},	//   bbig, arif, _وصیت_, ንዳቸው_, 
   {{0x6aa5b9c0,0x6b8401d9,0x6ca401c0,0x45280327}},	//   brif, cbig, _ярьж, _སྨེར_, 
   {{0xdb1c14ac,0x7c3db9c1,0x16a802bf,0x645c003e}},	//   _obsé, moqr, івки_, _ériy, 
   {{0xde6c0016,0x45d00640,0x9475b9c2,0x15440139}},	//   _xươn, вољс, ودبا, мелм, 
   {{0xe6100592,0xf1d40b67,0x00000000,0x00000000}},	//   دشن_, _भोगन, --, --, 
   {{0x67d40aa5,0xdb1c068c,0x13089e78,0x1cb0031c}},	//   _посу, _absé, жний_, _ནཱན_, 
   {{0x60dc005c,0xe2b4009d,0x00000000,0x00000000}},	//   ærmn, нсээ, --, --, 
   {{0x3ea9b9c3,0xfafc0694,0x2ee001a6,0xc5ec004b}},	//   duct_, _ngëm_, _rrif_, _پړه_, 
   {{0x8fa45434,0x6b84b35f,0xde6c01fb,0x4fa400d8}},	//   мане, ybig, _rươn, минв, 
   {{0x2ee00cfd,0xe3b0fe86,0xde6c001e,0x6aa40162}},	//   _prif_, _مره_, _sươn, yrif, 
   {{0x20c401ec,0x2ee006be,0x00000000,0x00000000}},	//   _үйім, _qrif_, --, --, 
   {{0x6b840142,0xb3840244,0x00000000,0x00000000}},	//   wbig, _بێکم_, --, --, 
   {{0xde6c0016,0x2fc001ab,0x3ea80076,0x8c44119e}},	//   _vươn, _tbig_, auct_, деве, 
   {{0x6aa5b9c4,0x6b840e78,0xc8c80050,0x00000000}},	//   trif, ubig, ۪وان_, --, 
   {{0x6b84f496,0xde6c07ae,0x3ab0767b,0xdb1c04cc}},	// [30680] rbig, _tươn, кәрт, _sasò, 
   {{0x6aa5b9c5,0x6b840a81,0x2b8c07ae,0x645c0395}},	//   rrif, sbig, ếc_, _èriv, 
   {{0xc8c83451,0xcb68009b,0x00000000,0x00000000}},	//   توان_, _мане_, --, --, 
   {{0x6aa5b9c6,0xc7241075,0x5fc0190c,0x00000000}},	//   prif, мдей, ष्पल, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x44cc00bc,0xfcd40092,0xd90c00e5,0x00000000}},	//   _př_, _ይሰጥ_, جیہ_, --, 
   {{0x38c80244,0x00000000,0x00000000,0x00000000}},	//   _وافی_, --, --, --, 
   {{0x4aa001ad,0x245400e4,0x27e000e2,0xd6a401ec}},	//   _ओटाव, _ẽmba_, ķins_, _бiрн, 
   {{0x26c40455,0xb9b400a2,0xb2a4009d,0x61fc007c}},	//   _upmo_, _üçça, мтэж_, örlo, 
   {{0x44cc0118,0x60dc005c,0x00000000,0x00000000}},	//   _tř_, ærmo, --, --, 
   {{0x8505b9c7,0x65700882,0x6280045f,0x7c3c0784}},	//   _توان, ādhā, spmo, yoqr, 
   {{0x6281b9c8,0x00000000,0x00000000,0x00000000}},	//   ppmo, --, --, --, 
   {{0x6441b9c9,0x7c3c014f,0x9f05b9ca,0x00000000}},	//   momi, voqr, روسو, --, 
   {{0x3ea9b9cb,0xfd11692e,0x929c0210,0x00000000}},	//   ruct_, نجز_, syłc, --, 
   {{0x7c3c0213,0x6440000d,0x00000000,0x00000000}},	//   toqr, oomi, --, --, 
   {{0xfbd00014,0xa3d407af,0x00000000,0x00000000}},	//   ختس_, िएट_, --, --, 
   {{0x645c0395,0xdb1c02d1,0x7c3c0455,0x00000000}},	// [30690] _èriu, _pasñ, roqr, --, 
   {{0x6441b9cc,0x6d40002f,0x00000000,0x00000000}},	//   homi, ßmac, --, --, 
   {{0x6441b9cd,0xf7700075,0x39454607,0x9b9404c2}},	//   komi, ناش_, æns_, _пинц, 
   {{0x6441b9ce,0x6d4005d1,0xab64025c,0x00000000}},	//   jomi, şmac, _żżew, --, 
   {{0xe79400d8,0x00000000,0x00000000,0x00000000}},	//   тичњ, --, --, --, 
   {{0xd4680354,0x7d0000a2,0xdd480092,0x00000000}},	//   пике_, _ünss, _በሆስፒ, --, 
   {{0x6440014a,0xaa080014,0xe94402e8,0x60dc01bf}},	//   fomi, _غٲفل_, _ахто, ærml, 
   {{0x6441b9cf,0x248d03fa,0xf1d42e35,0x601c0086}},	//   gomi, _dwdm_, _भोजन, bũmi, 
   {{0x96340a31,0xd2643802,0xd64c0354,0x00000000}},	//   _знац, нкий, _дiае, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x65941ed2,0xe6040014,0x6fa800f1,0x06640150}},	//   _раху, _جِلَ, وندې_, _ﺷﻮﻣﯩ, 
   {{0x45280327,0x00000000,0x00000000,0x00000000}},	//   _སྨིར_, --, --, --, 
   {{0xe844044e,0x039400ec,0x00000000,0x00000000}},	//   _ንኣብነ, _سانڍ, --, --, 
   {{0x6fac01f9,0x00000000,0x00000000,0x00000000}},	//   _झाकू, --, --, --, 
   {{0x1b1c00bd,0xd009b9d0,0xbf9800d2,0x9324004b}},	//   _ভুলে_, _неке_, phêp, _ترڅن, 
   {{0xe0d0030f,0x2018004e,0x00000000,0x00000000}},	//   _خزه_, èrit_, --, --, 
   {{0x920400b8,0xd8400153,0x7bc80022,0x4b241291}},	// [306a0] _etāś, _mačą_, õgua, رعرف, 
   {{0x5fc00316,0x7c380063,0x6441b9d1,0xdb240332}},	//   ष्ठल, čura, zomi, úpál, 
   {{0x7ae00a28,0xc7c40209,0x6441b9d2,0xb9b000db}},	//   ānta, если, yomi, اممع, 
   {{0x6441b9d3,0x929c033f,0x78a001d3,0x00000000}},	//   xomi, zyła, ánva, --, 
   {{0x6440006c,0x00000000,0x00000000,0x00000000}},	//   vomi, --, --, --, 
   {{0x2ba80764,0x291c021c,0x6441b9d4,0xe6c000c5}},	//   गलका, úvas_, womi, _एहीज, 
   {{0x39e5b9d5,0x7c2c0597,0xc7a417a0,0xe3780092}},	//   _ядро_, _áirí, _пивк, _አቀረበ_, 
   {{0x98540116,0xd25001d3,0xd3780137,0x30e000dc}},	//   _атуш, ینٹ_, үчө_, गिनः_, 
   {{0x601000c7,0x00000000,0x00000000,0x00000000}},	//   _ẽmom, --, --, --, 
   {{0x6441b9d6,0x00000000,0x00000000,0x00000000}},	//   somi, --, --, --, 
   {{0x6441b9d7,0x600c0b21,0x91f00307,0x00000000}},	//   pomi, _dûmn, _अचरज_, --, 
   {{0x929c0034,0xdfd0f18a,0x64400fc0,0x7cf8013d}},	//   syła, جيح_, qomi, härç, 
   {{0x33f8011a,0xb27000c0,0x00000000,0x00000000}},	//   _מהאנ, _бліш, --, --, 
   {{0xdce400b8,0xdd5801c0,0x00000000,0x00000000}},	//   _aghā, дагч_, --, --, 
   {{0x645c0395,0x71f42c10,0x2018068c,0x6d340256}},	//   _èris, _سروس_, èris_, герф, 
   {{0xdb1c0790,0x8cc05c0e,0x00000000,0x00000000}},	//   _masö, _लहरो, --, --, 
   {{0xab386958,0x39a5b9d8,0x51a80150,0x5fc01bd6}},	// [306b0] епту_, ешев, _ءدۇپ_, ष्णल, 
   {{0x13d81aba,0x1a640b43,0x5c74024c,0x7cf8d84a}},	//   থায়, ئیسی_, _илот, gärç, 
   {{0x777807a9,0x5d5407b5,0xa3e041ac,0xae1c011a}},	//   _pfux, _шкот, दया_, _מוזכ, 
   {{0xfba81c22,0x9f48020c,0xa88415bf,0x00000000}},	//   _этой_, _anaé_, النى, --, 
   {{0x79a41b88,0x7cf80724,0x6d5800e4,0x00000000}},	//   _прве, bärç, _úvar, --, 
   {{0xd548b6fc,0x8b6400cf,0xdb1c007c,0xa5940395}},	//   мпле_, _جاپم, _basö, гръщ, 
   {{0xd86400c7,0x70ac1524,0x7994004b,0x00000000}},	//   _ахаҿ, _झमेल, maxw, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3568054a,0x961c00e2,0x52bc1db2,0x00000000}},	//   _ерен_, _atņe, ्बेस, --, 
   {{0xe73000f1,0x020005a2,0x6d480254,0x6594022e}},	//   _اصف_, изын, üdak, _бафу, 
   {{0x64c40220,0xca480150,0x93b4119e,0x00000000}},	//   _ميلل, _ﺀﻭﺯ_, _абец, --, 
   {{0x7641b9d9,0x15780050,0x91800131,0x7d04033f}},	//   lony, _رٔچھ_, _ھۇجۇ, dyjs, 
   {{0x7641b9da,0x20180023,0xdb1c00e4,0xf32402dd}},	//   oony, ëria_, _kasõ, _سۋدى_, 
   {{0xaae0012c,0xb640037e,0x7640253c,0x201802b5}},	//   निसक, _ｎｏ_, nony, īria_, 
   {{0x79940d62,0x41b0188d,0x7640009f,0x201800b0}},	//   daxw, _ضمير, iony, ūria_, 
   {{0x76418f0e,0x0ba842c6,0x5044004e,0x00000000}},	//   hony, باسى_, _шейб, --, 
   {{0x6ef40306,0x49940395,0x00000000,0x00000000}},	// [306c0] _džbá, вшет, --, --, 
   {{0x7994014b,0x48e40063,0x7d0402f0,0x7640012d}},	//   gaxw, козв, byjs, jony, 
   {{0x76401801,0x00000000,0x00000000,0x00000000}},	//   dony, --, --, --, 
   {{0x2d99b9db,0x7d34011a,0x8b240006,0x00000000}},	//   lare_, _יניב_, _адме, --, 
   {{0x7641b9dc,0x79940117,0x2d98054e,0xb60001ef}},	//   fony, baxw, oare_, _čáry, 
   {{0x2d99b9dd,0xe5359833,0xc8a801ad,0xeb003be5}},	//   nare_, лель, _चटपट, ोनीत_, 
   {{0x2d9800fe,0xc795b9de,0x461401b9,0xd90c00e5}},	//   iare_, _арзы, _یورر, _ٹین_, 
   {{0xd90d2837,0x44200086,0x00000000,0x00000000}},	//   _عین_, òk_, --, --, 
   {{0x2d99b9df,0x69ddb9e0,0x76400a03,0x04f0015b}},	//   kare_, _kare, bony, জনের_, 
   {{0x69ddb9e1,0x7641b9e2,0x00000000,0x00000000}},	//   _jare, cony, --, --, 
   {{0x2d99b9e3,0x5f94009d,0xdcf400de,0x1e380092}},	//   dare_, линт, razī, _የህጻና, 
   {{0x69ddb9e4,0xc1e0000d,0x5c7401a9,0xf4841dd8}},	//   _lare, _कोरब_, ғлат, _شامی, 
   {{0x2d99b9e5,0x69ddb9e6,0xa2c4005e,0xdcf400da}},	//   fare_, _oare, _сәйк, pazī, 
   {{0x2d99b9e3,0xc0a85263,0xa19450d5,0xaed416a4}},	//   gare_, _قابل_, _сакч, јорш, 
   {{0x6d419e46,0x5a341ee3,0xac94020f,0x71a00798}},	//   şman, ҳнат, иарш, _тајз, 
   {{0x7641b9e7,0xec35b9e8,0x2d98aa7c,0x79940921}},	//   zony, ансь, aare_, waxw, 
   {{0x7641b9e9,0x5a3544d6,0x6b7405f5,0x7d040034}},	// [306d0] yony, гнат, рлуу, syjs, 
   {{0x2d99b9ea,0x69dc5ffb,0xc0d41772,0x929c012d}},	//   care_, _care, ራጥር_, zyło, 
   {{0x764000ca,0x79947d85,0x7c6400ae,0x00000000}},	//   vony, raxw, _لاحل, --, 
   {{0x69ddb9eb,0xb8c80d01,0x3a800014,0x9734009d}},	//   _eare, _खि_, _نیرِ, лэлч, 
   {{0x69a000dc,0x00000000,0x00000000,0x00000000}},	//   गृही, --, --, --, 
   {{0x7bdc3f5b,0x7640009f,0xd1f40023,0xf6600137}},	//   ldqu, uony, ሎታት_, шелү, 
   {{0xe8940024,0x7bdc0381,0x24f40395,0xbac802dd}},	//   _вась, odqu, ичър, _ﺗﻴﺠﺎ, 
   {{0x2d99b9ec,0x7641b9ed,0x7bdc07de,0x47f0014b}},	//   zare_, sony, ndqu, _гӯшр, 
   {{0x7641b9ee,0x2d99b9ef,0x81cc03d4,0xd6d80210}},	//   pony, yare_, ৱান_, _pyłu_, 
   {{0x69dc1574,0x2d99b9f0,0x76402beb,0x20180023}},	//   _xare, xare_, qony, ërin_, 
   {{0x2d99b9f1,0xf4f42832,0xa5f82bbd,0x00000000}},	//   vare_, _جواں_, _шефу_, --, 
   {{0x645c011c,0xe51c000d,0x00000000,0x00000000}},	//   _èrip, _भेटि_, --, --, 
   {{0xd174052f,0xd6d8033f,0x2054ede6,0xc7d4011a}},	//   _йыйы, _tyłu_, ртэр, נושי_, 
   {{0xddcc5667,0xe1f802dd,0x2d98003a,0x00000000}},	//   _etaž, _игі_, uare_, --, 
   {{0x41b02309,0x00000000,0x00000000,0x00000000}},	//   _امىر, --, --, --, 
   {{0x69ddb9f2,0x2d99b9f3,0x00000000,0x00000000}},	//   _sare, sare_, --, --, 
   {{0x2d99b9f4,0x69dc2d61,0xdd740014,0xdb1c0241}},	// [306e0] pare_, _pare, _چھِک, _àyìn, 
   {{0x69dc1b3f,0x2d98df62,0x4c8401af,0x1ab800d1}},	//   _qare, qare_, _йлов, _ﻧﻪﺷﺮ, 
   {{0x4c681def,0x61fc01e3,0x30c40220,0x00000000}},	//   _пион_, örli, _ﯨﻠﻪﻧ, --, 
   {{0x69dd3503,0xc79400db,0x60dc168c,0x87d847e7}},	//   _ware, اشاب, ærmi, عباس_, 
   {{0x69ddb9f5,0x86242fc3,0xb6c801d3,0x65944530}},	//   _tare, льке, ٹانے_, аалу, 
   {{0x69dc127b,0x00000000,0x00000000,0x00000000}},	//   _uare, --, --, --, 
   {{0xf4804660,0x00000000,0x00000000,0x00000000}},	//   буын, --, --, --, 
   {{0xbf98000f,0x6e200588,0x00000000,0x00000000}},	//   nkêt, ĩmby, --, --, 
   {{0x46e917ea,0x91a80014,0xe7300345,0x00000000}},	//   _ядан_, ھنَے_, _بڵا_, --, 
   {{0xddcdb9f6,0x3ab800df,0x00000000,0x00000000}},	//   _staž, עמינ, --, --, 
   {{0x5ff4311b,0xddcc0311,0xbc900092,0xe0180212}},	//   азну, _luaţ, ቃቅንና_, вжні_, 
   {{0x6d401cce,0x3ea801f5,0xbeb80036,0x00000000}},	//   ğmal, trct_, nzëg, --, 
   {{0x4425b9f7,0x6d407975,0xa29401ce,0x81cc0183}},	//   _imo_, şmal, _талі, ৱাব_, 
   {{0x44240457,0xbd680276,0x80040139,0x5fb001f9}},	//   _hmo_, ербе_, _әчке, _झाकल, 
   {{0x317825f9,0xdb0c0597,0x44240373,0x9f0400cf}},	//   _ארומ, rgaí, _kmo_, _چوعو, 
   {{0x4425b9f8,0x7bdc003a,0x3cfc00bc,0xddcc0b9b}},	//   _jmo_, udqu, ैनौं_, _utaž, 
   {{0x7bddb9f9,0xab84036b,0x0d280092,0x7ac40006}},	// [306f0] rdqu, суск, ደሚፈል, ысве, 
   {{0x99840032,0x2f38001f,0xdb1c0241,0x00000000}},	//   ртаһ, _የሕፃና, _àyín, --, 
   {{0x4425b9fa,0xe3ac04c5,0x6e200023,0x98b8010a}},	//   _omo_, ক্যব, ëmbe, тлет_, 
   {{0xba75b9fb,0x201800ca,0x442401e1,0x00000000}},	//   _ماست, nhsi_, _nmo_, --, 
   {{0x2d9401a2,0xcb980375,0x6d4800c5,0x00000000}},	//   ždeň_, _בסרט, üdav, --, 
   {{0x4425b9fc,0xa5f81429,0xf954010a,0x00000000}},	//   _amo_, лечу_, _йĕлм, --, 
   {{0x442400fd,0x2019b9fd,0xa9c4177b,0xa3e000dc}},	//   _bmo_, khsi_, _усяк, दयं_, 
   {{0x4424070d,0x091c00fe,0x00000000,0x00000000}},	//   _cmo_, _বুকু_, --, --, 
   {{0xb5a5b9fe,0xc32c04d3,0x95d813d6,0x20180067}},	//   _брей, وڕه_, _идат_, dhsi_, 
   {{0x032002d5,0x90c40b01,0x645c00ef,0x00000000}},	//   ідэн, абое, _īrie, --, 
   {{0x34440116,0x225c002b,0xb400009d,0xca8400d1}},	//   _йүки_, _dhvk_, _гүйд, ﻪﻛﺘﻪ_, 
   {{0xa3b831ed,0x5044b6fc,0xa3e00882,0x80b4000d}},	//   _ماهر_, ремб, दयः_, _अमरइ, 
   {{0xc7d40375,0x6d400c3c,0x65840129,0xb284013d}},	//   בורי_, ğmam, _éthé, _сыек, 
   {{0x623400d1,0x6d4006b9,0xe57800de,0x442400d7}},	//   _лечу, şmam, _kaķa_, _zmo_, 
   {{0x8b94721f,0x442416b8,0x00000000,0x00000000}},	//   ирач, _ymo_, --, --, 
   {{0xe8e00016,0x8fa400d8,0x00000000,0x00000000}},	//   _hiệp_, _таие, --, --, 
   {{0x60dc01bf,0xddd4010e,0x00000000,0x00000000}},	// [30700] ærmv, _ýaşr, --, --, 
   {{0x0d2000d1,0x6a840075,0x00000000,0x00000000}},	//   _дүгү, илға, --, --, 
   {{0xdb0c0122,0xc7b80006,0x601000e4,0x13540092}},	//   čkác, вёл_, _ẽmim, _ወዳጅነ, 
   {{0xbc780302,0x929c0034,0x0b580166,0x87080121}},	//   _שנכת, szły, _аргы_, кеев_, 
   {{0x4424011f,0x81cc0183,0x2c7c0e33,0x00000000}},	//   _rmo_, ৱাত_, _híd_, --, 
   {{0x7ae804ce,0x9f9002d2,0x568800ec,0x00000000}},	//   ægte, _lúðu_, ائنٽ_, --, 
   {{0x4425b9ff,0x2f38063f,0x7bc800fe,0x35f40472}},	//   _pmo_, ọgh_, ৱাৰো, شرود_, 
   {{0xddcc033f,0x2018022e,0x00000000,0x00000000}},	//   _staż, xhsi_, --, --, 
   {{0x20180023,0x00000000,0x00000000,0x00000000}},	//   ërim_, --, --, --, 
   {{0x4425ba00,0x69c80274,0x66e44942,0xc2040798}},	//   _wmo_, _öded, _коға, рџии, 
   {{0x442539c5,0xe8e001fb,0x8024bd4c,0x55f40145}},	//   _tmo_, _diệp_, لرحم, _учту, 
   {{0x4425ba01,0x7c38727d,0xadc40248,0x00000000}},	//   _umo_, čurk, _itẹw, --, 
   {{0xfbdc0022,0xe5780171,0x00000000,0x00000000}},	//   _raê_, _zaķa_, --, --, 
   {{0x9f4800d8,0x2c7c0332,0xf0b404f2,0xe2140304}},	//   _unaí_, _bíd_, دایش_, _ымлы, 
   {{0xdd940220,0x61fc0267,0xdde001d3,0x30a00064}},	//   _қаны, örlu, ítői, _дрыв, 
   {{0xb0680006,0x00000000,0x00000000,0x00000000}},	//   _крыж_, --, --, --, 
   {{0x7b641a21,0x600c0194,0xf9911fe8,0x8c38013e}},	// [30710] ртве, _nûmi, قبض_, уотӣ_, 
   {{0xd999ba02,0x80d80918,0xa3c806ab,0xd7581823}},	//   انات_, _बनाइ, _लॉस_, ۇلات_, 
   {{0xf090008f,0x5378001f,0xddcc4e96,0x6d480037}},	//   ַנס_, _በዳዊት_, _guaš, üdat, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xadc40241,0x1cdc031c,0xfafc0023,0xdb1c0ca8}},	//   _atẹw, _ལནཌ_, _egër_, _àyàn, 
   {{0x929c068f,0x00000000,0x00000000,0x00000000}},	//   syłk, --, --, --, 
   {{0x6498e3e7,0x53a400f7,0x00000000,0x00000000}},	//   атыр_, байб, --, --, 
   {{0xf77c9f19,0x14580b8d,0xa95402bf,0x00000000}},	//   _üç_, ышлы_, _єкті, --, 
   {{0xaae0012c,0xc68403e6,0xa3c800af,0x9f9002d2}},	//   निएक, _هێنن_, _लउर_, _rúðu_, 
   {{0xc0b80092,0x00000000,0x00000000,0x00000000}},	//   ታለሁ_, --, --, --, 
   {{0x5555ba03,0xaee40084,0x91e4013e,0xd00850cb}},	//   _اپار, _maṅw, _ҳоле, гене_, 
   {{0xf74802d3,0x6d415aec,0x257001ec,0x0eb8010b}},	//   _ንሓድሕ, şmak, _تۇىس, лугы_, 
   {{0x91e4529e,0x52840597,0xe3b00014,0xe8e0004d}},	//   _голе, _التك, _زرن_, _tiệp_, 
   {{0x6cc8c7b0,0x00000000,0x00000000,0x00000000}},	//   ақов_, --, --, --, 
   {{0xf004005e,0xc0b8001f,0x60dc005c,0x00000000}},	//   _дүни, ታወሻ_, ærmt, --, 
   {{0xbf988eaf,0x40300798,0x00000000,0x00000000}},	//   skêr, _нејс, --, --, 
   {{0x0ae80eff,0x49c86bb8,0x00000000,0x00000000}},	// [30720] ыдай_, ллан_, --, --, 
   {{0x2c7c06ea,0x66f00241,0x6cb40139,0x00000000}},	//   _tíd_, _ǹka, _мөбт, --, 
   {{0x9e64a957,0xdb1c0e78,0x4784411a,0x2ea800b8}},	//   _باين, _absä, былб, _कटुत, 
   {{0x9f480589,0xa4f8030f,0xe7b40137,0x00000000}},	//   _unaã_, یکار_, تۅرد, --, 
   {{0x5b340276,0x4e78010f,0x662801a9,0x81bc00cc}},	//   _дэру, נאַצ, аrkа, ঁজত_, 
   {{0x27e1ba04,0x998400f1,0x8a14210e,0xdb1c0248}},	//   žin_, _ولټو, _اِست, _àyán, 
   {{0x80b401ad,0xaae0095f,0x48580024,0x15b9ba05}},	//   _अमें, निकक, _браў_, рычы_, 
   {{0xc795ba06,0x6d400205,0x00000000,0x00000000}},	//   _ыргы, ğmah, --, --, 
   {{0xc0b8001f,0x3f8c0022,0x41e412fa,0x7bc80124}},	//   ታወስ_, _õgui_, біна, õgui, 
   {{0x63f8065f,0xdcf4012d,0xc644009f,0x00000000}},	//   افکس_, lczą, _اَئي, --, 
   {{0xa158024d,0x7ae00882,0xf9900375,0xf4842a77}},	//   рану_, ānti, הרת_, _هانی, 
   {{0x39540302,0x71f40150,0xded00023,0xff040395}},	//   משים_, _ۇرىس_, _ብኣኻ_, бягн, 
   {{0xfafc00e8,0x1b0c00fe,0x00c40150,0x00000000}},	//   _ngëp_, _সেনে_, _ﺒﻴﺌﺘ, --, 
   {{0xdb0c0261,0x60dc005c,0xa444009f,0x00000000}},	//   lgaç, ærms, _اَچو, --, 
   {{0x6e21ba07,0xbe9801ec,0x00000000,0x00000000}},	//   ëmba, _әңгi, --, --, 
   {{0x9f340220,0xdb0dba08,0xad2415bf,0xe21400fb}},	//   _мейі, ffað, سىقى, _ымһы, 
   {{0xd9dc1c82,0x9998b6c2,0x9d080154,0x9e840345}},	// [30730] ঠাসম, икат_, রছেন_, _بابۆ, 
   {{0xdd9026c0,0x600c0428,0x19580137,0x00000000}},	//   _تود_, _pûmw, аазы_, --, 
   {{0x3f980481,0x91bc00fe,0x58d80395,0xfec801e2}},	//   _kequ_, _অসমখ, рдея_, _شبکو_, 
   {{0x37140050,0x69d80419,0x00000000,0x00000000}},	//   ٝرتھ_, ôver, --, --, 
   {{0x3f980286,0x6c8400e5,0x09cc0154,0xb9e400d4}},	//   _mequ_, _ولیم, রয়া, _ліви, 
   {{0xd9fc19e5,0x3f980a73,0x00000000,0x00000000}},	//   _उचित_, _lequ_, --, --, 
   {{0x81bc0154,0x06640150,0x00000000,0x00000000}},	//   ঁজা_, _ﺷﻮﻗﯩ, --, --, 
   {{0x52a88ed9,0xf7701ec7,0x52840108,0x39a00ca8}},	//   авим_, _رار_, огиб, bésí_, 
   {{0xdce400d0,0xf1bc00d0,0x00000000,0x00000000}},	//   _nehľ, úšok_, --, --, 
   {{0xa614010a,0xaadc00df,0x00000000,0x00000000}},	//   _емуч, רחזר, --, --, 
   {{0xdbe4002e,0x00000000,0x00000000,0x00000000}},	//   _lëñb, --, --, --, 
   {{0x24587af6,0x8e740798,0x00000000,0x00000000}},	//   _лахь_, жувч, --, --, 
   {{0x3f98067c,0xbb180311,0xb8f8031c,0x6d5800bc}},	//   _dequ_, _sfîn, _འར_, _úvaz, 
   {{0xb7fc04c5,0xdcf4033f,0x00000000,0x00000000}},	//   ংসিত_, zczą, --, --, 
   {{0xc5f00302,0xd5c41cb8,0xe16400db,0x8d6400d4}},	//   ודם_, _мiжн, _ىدىي, івбе, 
   {{0x4b8800ee,0x0b598c19,0x00000000,0x00000000}},	//   рйан_, арзы_, --, --, 
   {{0x8d75ba09,0x3204e332,0x8b64178c,0x22400115}},	// [30740] _وادا, _kony_, زارم, _ŭiki_, 
   {{0x9f050740,0xdb0c0252,0xdb0800a2,0x00000000}},	//   _روپو, rfað, _ýoýs, --, 
   {{0x32044f7f,0x5fc000dc,0x2d440092,0x8c440117}},	//   _mony_, ष्कल, _የትኩረ, _меое, 
   {{0x46e9ba0a,0x38c801b9,0xa6842bcb,0x2cb8915e}},	//   иден_, شامی_, зғай, murd_, 
   {{0x4e0c3d1d,0x2cb804cc,0x81bc0154,0xc6d40116}},	//   _हवाई_, lurd_, ঁড়ি_, تتات, 
   {{0x32040851,0x6aa430f4,0x6b840ffb,0xa3cc37bb}},	//   _nony_, msif, lcig, श्न_, 
   {{0x9f44012c,0xcfb0009e,0x7c540133,0x748000f1}},	//   ělé_, ট্যন, _دلێر_, وټول, 
   {{0x6b85ba0b,0x2fc00457,0x02a5ba0c,0x81bc0154}},	//   ncig, _ncig_, ором, ঁড়া_, 
   {{0x6aa5ba0d,0x2cb8002d,0x00000000,0x00000000}},	//   nsif, hurd_, --, --, 
   {{0x27e439c3,0x3204a78a,0x26c4014f,0x2cb8014b}},	//   _hamn_, _cony_, _iqmo_, kurd_, 
   {{0x27e408cd,0x2ee1ba0e,0xb97806a9,0x32041ef3}},	//   _kamn_, _asif_, יניי, _dony_, 
   {{0x6aa5ba0f,0x27e400cc,0x66080306,0x00000000}},	//   ksif, _jamn_, _hodk, --, 
   {{0x32040851,0x63a1ba10,0x2ee00077,0x6b84058a}},	//   _fony_, mamn, _csif_, dcig, 
   {{0x22800086,0x3205ba11,0x7af85941,0x2cb8000f}},	//   _iòk_, _gony_, _àuti, furd_, 
   {{0x2cb82147,0x64b802ab,0x6609ba12,0xbc055be7}},	//   gurd_, _इमोश, _modk, очай, 
   {{0x27e433f3,0x3204233e,0xe3ac00bd,0x228002bd}},	//   _namn_, _zony_, ক্রব, _kòk_, 
   {{0xa3cc28d4,0x2ee00048,0x6608035a,0xceb4fb04}},	// [30750] श्य_, _gsif_, _oodk, _нәр_, 
   {{0x63a1ba13,0x2009ba14,0x66080117,0x32040175}},	//   hamn, _hoai_, _nodk, _xony_, 
   {{0x63a1ba15,0x2009ba16,0x6aa4013c,0x2280007f}},	//   kamn, _koai_, asif, _lòk_, 
   {{0x6b84b2cc,0xdd900014,0x6aa4022f,0xa3cccc41}},	//   ccig, _توگ_, bsif, श्म_, 
   {{0x20080225,0x63a1ba17,0x6609ba18,0x00000000}},	//   _moai_, damn, _bodk, --, 
   {{0x66080050,0x428002d3,0x200801fb,0xd5b000c6}},	//   _codk, _ረዲኤት_, _loai_, رفع_, 
   {{0x26c40477,0x27e5ba19,0x63a0198f,0x53a400f7}},	//   _eqmo_, _famn_, famn, пайб, 
   {{0x32043c36,0x63a1ba1a,0xd7c853be,0x200803a0}},	//   _sony_, gamn, _دوره_, _noai_, 
   {{0x66087166,0xdb1c032e,0x3205ba1b,0x828002dd}},	//   _fodk, _absú, _pony_, еңіз, 
   {{0x660800d4,0x2ea811b1,0x20080607,0x228002e2}},	//   _godk, _कटौत, _aoai_, _dòk_, 
   {{0x63a1ba1c,0x320406d9,0x7bcc0427,0x2ee00356}},	//   bamn, _vony_, _obcu, _ssif_, 
   {{0x22800d29,0xb4e403f3,0x63a1ba1d,0x00000000}},	//   _fòk_, यटी_, camn, --, 
   {{0x600c000f,0xdbd80008,0x32042517,0x2cb8045f}},	//   _rûmt, væðu, _tony_, wurd_, 
   {{0xfc3c0407,0x2738004d,0x2cb802d1,0x32100208}},	//   _ají_, ẩng_, turd_, _ôxy_, 
   {{0x7aedba1e,0x20081140,0xdbd8008c,0x7bcc01a9}},	//   _arct, _foai_, tæðu, _bbcu, 
   {{0x6aa5ba1f,0x2008002d,0x228002e2,0x046400b8}},	//   tsif, _goai_, _yòk_, _kṛṣa, 
   {{0xdbd8008c,0x6b840050,0x27e40158,0x00000000}},	// [30760] ræðu, rcig, _ramn_, --, 
   {{0x6aa5ba20,0x6b85ba21,0x63a00213,0x2cb83619}},	//   rsif, scig, zamn, purd_, 
   {{0x63a1ba22,0x6aa5ba23,0x7d780375,0x42a000b7}},	//   yamn, ssif, _לניו, _ፍጥነት_, 
   {{0xdcf4068f,0x8c4400ee,0x63a1b4dd,0x7d1800df}},	//   jczę, _хеме, xamn, ĝust, 
   {{0x66083e8f,0x63a00194,0x5fc092c1,0x6aa40175}},	//   _podk, vamn, ष्टल, qsif, 
   {{0x27e40083,0xd90c01ed,0x63a05559,0x8a0400db}},	//   _wamn_, دیہ_, wamn, _эзге, 
   {{0x63a1ba24,0x27e40109,0x80d80034,0x66081bb3}},	//   tamn, _tamn_, _बनें, _vodk, 
   {{0x97b400ee,0xb60000da,0x2280007f,0xe2580023}},	//   _осуш, īšan, _pòk_, _ምብራቓ, 
   {{0x2d5c06d6,0xc76402dd,0x8574179e,0xf2c06816}},	//   _ḽe_, _ءازى, _فدائ, нсэн, 
   {{0x63a1ba25,0xe8e0001e,0x20080618,0x046400b8}},	//   samn, _nhịp_, _soai_, _dṛṣa, 
   {{0x200818a6,0x75200175,0x1e540092,0xfe700014}},	//   _poai_, cznz, _ለህጻና, ہدس_, 
   {{0x81cc0183,0x63a1ba26,0x9f34cea4,0x01c802dd}},	//   ৱাই_, qamn, демі, _ﺒﻤﻌﻨ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf1a00395,0xdd240055,0x00000000,0x00000000}},	//   _зрън, cīśa, --, --, 
   {{0x61f9ba27,0x248c011c,0x2009ba28,0xfba801c0}},	//   _invl, _jtdm_, _toai_, йтай_, 
   {{0x2d5c06d6,0x31540375,0xb1540375,0xc10001c4}},	//   _ḓe_, _מיון_, _מסוג_, _жүүл, 
   {{0x9e6c0023,0x20180200,0x00000000,0x00000000}},	// [30770] በረልና_, ëriu_, --, --, 
   {{0xa3cc0c2e,0xdcf40034,0xf1cc00dc,0x00000000}},	//   श्त_, zczę, त्पन, --, 
   {{0x7e7c0113,0x52d8012c,0x20180024,0x6d400112}},	//   _huqp, _भन्स, ūriu_, ßmat, 
   {{0x69c803ee,0x7bcc02d0,0x2984013d,0x7860000d}},	//   _öden, _ubcu, _җырг, kõve, 
   {{0x2b4405f5,0x55e46b1a,0x61f8017a,0x7c2c02d0}},	//   _зэрг, долб, _onvl, _imcr, 
   {{0xe6b457d7,0x7e740327,0x8af80375,0x957400fd}},	//   رلىگ, _jixp, _והשי, мыйч, 
   {{0x20f017a3,0x7e7402f0,0x8ca400e1,0xf4800efc}},	//   nđić_, _mixp, _छिछो, راغی, 
   {{0x61f944a6,0x0464002b,0x00000000,0x00000000}},	//   _anvl, _pṛṣa, --, --, 
   {{0x9180167e,0x00000000,0x00000000,0x00000000}},	//   نۇشۇ, --, --, --, 
   {{0xbeb802d3,0xed600419,0x046400dc,0x3a300051}},	//   tzën, úžku_, _vṛṣa, nixp_, 
   {{0xa3c806ab,0x50440bad,0x00000000,0x00000000}},	//   _लॉक_, денб, --, --, 
   {{0xe4d49105,0xbeb8036e,0x79340023,0xd314014b}},	//   _ستمب, rzën, _ጸጋታት, _омеъ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7e7c0477,0x7c2c02d0,0x00000000,0x00000000}},	//   _duqp, _amcr, --, --, 
   {{0x42503695,0xd0096454,0x00000000,0x00000000}},	//   _جنور, _меке_, --, --, 
   {{0xc1700302,0x201802d3,0x7778009a,0x09a40073}},	//   _בחו_, ërit_, _ngux, खण्य, 
   {{0xfaa19ad9,0xca09ba29,0x7e75ba2a,0x09e401b9}},	// [30780] като, онаж_, _fixp, моан, 
   {{0x6d40002f,0x00000000,0x00000000,0x00000000}},	//   ßmas, --, --, --, 
   {{0xf1cc0882,0x6d407236,0x3df80375,0x00000000}},	//   त्यन, ğmas, _וליד, --, 
   {{0x6d400ba5,0x00000000,0x00000000,0x00000000}},	//   şmas, --, --, --, 
   {{0xa3c8068f,0xc668223e,0x09e40f22,0xa5f80006}},	//   _लॉग_, ошке_, নাবা, зелу_, 
   {{0xf1cc0882,0x3eac037e,0xd90dba2b,0xe57800e2}},	//   त्मन, _ægte_, _گیم_, _kaķi_, 
   {{0xa5c4033f,0x0464249c,0x07a401b9,0x92cc03d4}},	//   _राठौ, мтим, _оавн, শটো_, 
   {{0xd90dba2c,0x6e20036e,0xaca40051,0x78600254}},	//   _دیم_, ëmbj, _chỉt, tõve, 
   {{0x86c5ba2d,0x00000000,0x00000000,0x00000000}},	//   _زيان, --, --, --, 
   {{0x61e808a5,0xb6c801d9,0xdb1407ea,0x00000000}},	//   uddl, _گاہے_, ébéc, --, 
   {{0x9f440316,0x7e7c0477,0x61e8015d,0x133800e5}},	//   ělí_, _suqp, rddl, قتیں_, 
   {{0x7e7c016d,0x443000fd,0x9f9c08a5,0x00000000}},	//   _puqp, _öy_, gæði_, --, 
   {{0xd6d8068f,0x7e7c014f,0x60c802d0,0x00000000}},	//   _były_, _quqp, stdm, --, 
   {{0x09e40011,0xdce40205,0x00000000,0x00000000}},	//   নাডা, _sehı, --, --, 
   {{0x1bd406bb,0x7c60001f,0x645c005f,0x7e7c0455}},	//   новя, _ተብለው_, _īrij, _wuqp, 
   {{0xec682626,0x20f0009b,0x7e7c014f,0xc044029c}},	//   друк_, rđić_, _tuqp, _تختو, 
   {{0x2a780165,0x20180fda,0x7e74031c,0xbb8001ec}},	// [30790] _birb_, ūris_, _tixp, _ﯨﺴﻜﻪ_, 
   {{0x2f540020,0xc0b80092,0x69c801e3,0x00000000}},	//   _ለሕፃና, ታገል_, _ödel, --, 
   {{0x5c7407d8,0x20180108,0xf1bc0419,0x2a780064}},	//   _плот, oksi_, úšik_, _dirb_, 
   {{0x2019ba2e,0xda08004b,0x80d4012d,0xe894003b}},	//   nksi_, _کيسه_, _बहने, таць, 
   {{0x201802f6,0x973403e6,0x1b0c0154,0x16a8003b}},	//   iksi_, رکرا, _সেরে_, ївки_, 
   {{0x6618003e,0xe57800de,0x00000000,0x00000000}},	//   gkvk, _zaķi_, --, --, 
   {{0xbeb80036,0x20181bce,0xf77002f2,0x00000000}},	//   dzëm, kksi_, راڵ_, --, 
   {{0x1309350a,0xc2f8015b,0x00000000,0x00000000}},	//   зний_, েননি_, --, --, 
   {{0x9f9c008c,0x00000000,0x00000000,0x00000000}},	//   væði_, --, --, --, 
   {{0x2019ba2f,0x00000000,0x00000000,0x00000000}},	//   eksi_, --, --, --, 
   {{0xf8dc000d,0x9378005b,0x00000000,0x00000000}},	//   नबिय, _ебет_, --, --, 
   {{0xa35002e3,0xe3b0028e,0x00000000,0x00000000}},	//   ịkọt, _نره_, --, --, 
   {{0x9f9c1873,0x09e402f5,0x00000000,0x00000000}},	//   ræði_, নাতা, --, --, 
   {{0x20189a89,0xc690008f,0x00000000,0x00000000}},	//   aksi_, ראם_, --, --, 
   {{0xa3cc37f3,0x4638010f,0x00000000,0x00000000}},	//   श्व_, לעשע, --, --, 
   {{0x0ea80276,0xfbdc0af9,0x00000000,0x00000000}},	//   _екий_, _skêr_, --, --, 
   {{0xc0f00092,0xdc740108,0xc9b41d39,0x0b440132}},	// [307a0] ግደል_, тырь, есењ, хнан, 
   {{0x6d407a0e,0x6ea80014,0x00000000,0x00000000}},	//   şmaq, _ٹنگہ_, --, --, 
   {{0x69c80365,0xcd340214,0x8ba47de7,0x00000000}},	//   _ödem, _سردب, _пинж, --, 
   {{0x7af8110c,0xcfb0015b,0xf1cc00cd,0x00000000}},	//   _šute, ট্রন, त्तन, --, 
   {{0x3ab03941,0x8d740133,0xbc680014,0x1780024c}},	//   _бәхт, _تاکا, _ڈجێے_, рҳум, 
   {{0xa3c802ab,0x2d99ba30,0xe5350086,0x00000000}},	//   _लॉज_, nbre_, кель, --, 
   {{0x91bc0f22,0x2018023a,0x2d9801e7,0xfa640f7e}},	//   _অসংখ, yksi_, ibre_, _чарк_, 
   {{0x6a7403e3,0x00000000,0x00000000,0x00000000}},	//   düfə, --, --, --, 
   {{0x3edc02e3,0x857802dd,0x00000000,0x00000000}},	//   _kwụọ_, _есет_, --, --, 
   {{0xd5e8007b,0x1fa83711,0x00000000,0x00000000}},	//   _يعلن_, कण्ड, --, --, 
   {{0x02040598,0x3a340375,0x5f951567,0x555001d9}},	//   _үзен, תרים_, кинт, _پھور, 
   {{0x35180302,0x2d980789,0x1938037e,0x03a41171}},	//   _מובנ, ebre_, _ｔｈｅ_, _чидо, 
   {{0x2019ba31,0x00000000,0x00000000,0x00000000}},	//   rksi_, --, --, --, 
   {{0xa3cc0cb4,0x9324f6d1,0x3edc01f2,0x62340108}},	//   श्र_, _جرمن, _nwụọ_, _шелу, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x644003b2,0x69c8010e,0x78600254,0x00000000}},	//   nnmi, _ödej, kõva, --, 
   {{0x2cb801ab,0x2d99ba32,0x64400108,0xb6000419}},	// [307b0] arrd_, bbre_, inmi, úško, 
   {{0x6440002f,0x00000000,0x00000000,0x00000000}},	//   hnmi, --, --, --, 
   {{0xe57800e2,0x8c2c0092,0xa818036b,0xc99c0241}},	//   _kaķu_, _ተገኝቷ, کتلر_, _ọbẹ̀_, 
   {{0xf7700a8e,0xded00023,0x00000000,0x00000000}},	//   هاش_, _ብኣና_, --, --, 
   {{0x7bddba33,0x7ac40212,0xe7080123,0x7a0c00b8}},	//   mequ, _ясне, فتون_, _ṛtuk, 
   {{0xe619ba34,0x7bddba35,0x64400369,0xcfe8015b}},	//   нді_, lequ, enmi, গায়_, 
   {{0x6e200023,0xc4cc0014,0xd794007b,0x644008a5}},	//   ëmbi, قےٕ_, _للأخ, fnmi, 
   {{0x7bddba36,0x2cac03b2,0x00000000,0x00000000}},	//   nequ, áddi_, --, --, 
   {{0x04540597,0x1db00a1c,0xd1b8158b,0x00000000}},	//   خلية_, _जयंत, وادا_, --, 
   {{0x7bddba37,0x2cb80076,0x00000000,0x00000000}},	//   hequ, yrrd_, --, --, 
   {{0xe61000db,0x6ea400ab,0xc5040451,0xdb1c03e0}},	//   _اشق_, _कबहु, _لڪيل_, _absü, 
   {{0xb63801ec,0x92d400c0,0x85240244,0x00000000}},	//   _ﺇﻁ_, _аўкш, _جومۆ, --, 
   {{0x24a002d3,0x83a400c7,0x90d400f2,0x00000000}},	//   _ግህሰት_, _рыхҵ, رآگا, --, 
   {{0x2c7c01e4,0x3f88026c,0x32c8143a,0x81d00051}},	//   _aŭda_, accu_, møy_, _hồng, 
   {{0x32c813ce,0x9f4400bc,0x7bdc003a,0xdb0c02d2}},	//   løy_, ělá_, fequ, ggaþ, 
   {{0x7bdc0194,0xb6040135,0xf004009d,0x00000000}},	//   gequ, leġġ, _сүми, --, 
   {{0x32c8332c,0x0e640209,0x3b800209,0x98980150}},	// [307c0] nøy_, _икин, рлуг, _ﺇﺨﻭﺓ_, 
   {{0xdb1c0077,0x4c8402f4,0x7bdc16b8,0xba2002d5}},	//   _absó, _илов, aequ, адук, 
   {{0x291dba38,0x7bddba39,0x18880220,0x8c440022}},	//   áva_, bequ, есіп_, _аене, 
   {{0x7bdc98ff,0x32c808fb,0xdb0c0432,0x00000000}},	//   cequ, køy_, lgaý, --, 
   {{0x32c80158,0x48e0033f,0x291ce8a8,0x00000000}},	//   jøy_, _टैरो_, šva_, --, 
   {{0x32c8332c,0x78600022,0xf8643769,0x068801ec}},	//   døy_, rõva, ىمەي_, _ﻗﻮﻧﯩ, 
   {{0xc6900014,0x00000000,0x00000000,0x00000000}},	//   _چِر_, --, --, --, 
   {{0xaca401f2,0x644005d5,0x870400e5,0xf1cc00cd}},	//   _nhọt, unmi, _لڑتے_, त्सन, 
   {{0x7c2000a8,0x6440fcf4,0x32c808fb,0xc32c00d1}},	//   _înre, rnmi, gøy_, غەت_, 
   {{0xaca401f2,0x7ae8037e,0xd5c8000d,0x00000000}},	//   _ahọt, ægti, _रायज, --, 
   {{0x8505ba3a,0x65c400c7,0x7bdc937c,0xa07401c6}},	//   _جوان, _абҕа, yequ, лгоч, 
   {{0xaca40521,0xe7b400af,0x7d0000db,0x32c84606}},	//   _chọt, ुलिप, _ànsi, bøy_, 
   {{0xd5c8007d,0x420839af,0x00000000,0x00000000}},	//   _रामज, _ондо_, --, --, 
   {{0x6e9434d8,0x69c801e3,0x00000000,0x00000000}},	//   риру, _ödeh, --, --, 
   {{0x7bddba3b,0x8048036b,0xfb840006,0xe6a801ef}},	//   tequ, _очиб_, вызн, dříš, 
   {{0xaca40521,0x92d403d4,0x6a1401b9,0x00000000}},	//   _ghọt, হিৰ_, یبلر, --, 
   {{0xdb1c02e2,0x3e6800f7,0xf1cc102f,0xaf343cc6}},	// [307d0] _absò, _ошон_, त्वन, _پريت, 
   {{0x7bddba3c,0x1a640d73,0x00000000,0x00000000}},	//   sequ, ایسی_, --, --, 
   {{0xdd9400c7,0x00000000,0x00000000,0x00000000}},	//   _иаҿы, --, --, --, 
   {{0xd78826c6,0x00000000,0x00000000,0x00000000}},	//   رنتو_, --, --, --, 
   {{0xdb0c00c5,0xb6c40107,0x81d00208,0xe6a8013a}},	//   ngaü, тсей, _rồng, bříš, 
   {{0xd2580227,0x32c803cd,0x00000000,0x00000000}},	//   kuņa_, vøy_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x32c81a82,0xf2dc0798,0x6aac0166,0xb6040135}},	//   tøy_, çâo_, _älfä, weġġ, 
   {{0x81bc009e,0x09e40154,0xb604025c,0x92382ff5}},	//   ুজন_, নারা, teġġ, ечну_, 
   {{0x32c8319f,0x00000000,0x00000000,0x00000000}},	//   røy_, --, --, --, 
   {{0x76400167,0x32c8168c,0xf484013e,0xb604031c}},	//   mnny, søy_, _рузн, reġġ, 
   {{0x7640020b,0x32c80fac,0x4f940022,0x71f8002b}},	//   lnny, pøy_, ыроу, _ṅgān, 
   {{0x80d404c5,0x7641ba3d,0x00000000,0x00000000}},	//   ধিষ্, onny, --, --, 
   {{0x60cc01a8,0x00000000,0x00000000,0x00000000}},	//   ölmö, --, --, --, 
   {{0x03e403f4,0x76405afc,0xcfa8007b,0x4a440107}},	//   কারী_, inny, _كاظم_, ҳнав, 
   {{0x7640005c,0x7af81050,0xeb38001f,0xf1cc11a6}},	//   hnny, _šuta, _በመግለ, त्रन, 
   {{0x76400a2e,0x4f940022,0x4a4415bd,0x98b800b8}},	// [307e0] knny, _ирҿу, гнав, _āyān_, 
   {{0x8fe00032,0x00000000,0x00000000,0x00000000}},	//   _тәүҙ, --, --, --, 
   {{0x6e200240,0x09e40154,0x058400d1,0x00000000}},	//   ëmbu, নালা, қулм, --, 
   {{0x7641ba3e,0xc72520d3,0x87240209,0x2cac03b2}},	//   enny, лдей, лмеж, áddu_, 
   {{0x47340014,0x00000000,0x00000000,0x00000000}},	//   دراز, --, --, --, 
   {{0xcb9403e6,0x00000000,0x00000000,0x00000000}},	//   _شۆڕش_, --, --, --, 
   {{0xc0cc044e,0xd1cc0092,0x3a2001d5,0x00000000}},	//   ጥቃስ_, ጥናት_, _умрг, --, 
   {{0x764015a5,0x442000dd,0x430813dc,0x65640118}},	//   anny, ók_, ехом_, řiho, 
   {{0xa5e801af,0xb2a4009d,0x73d40139,0x00000000}},	//   _илаҡ_, лтэж_, удыр_, --, 
   {{0x1b000183,0x66e40116,0xfa38001f,0x00000000}},	//   লৈকে_, _йоға, _በከተሞ, --, 
   {{0x325001c0,0x00000000,0x00000000,0x00000000}},	//   свэр, --, --, --, 
   {{0x82a40395,0x00000000,0x00000000,0x00000000}},	//   _бадж, --, --, --, 
   {{0x2c7c0115,0xd24c0451,0x00000000,0x00000000}},	//   _aŭdo_, _ڪچي_, --, --, 
   {{0xa19401a9,0xdb0c0254,0x00000000,0x00000000}},	//   _такч, rgaü, --, --, 
   {{0x7240004b,0x23b800af,0x5f94010a,0x00000000}},	//   _دپول, _इयाद, _кийт, --, 
   {{0x9b95ba3f,0x00000000,0x00000000,0x00000000}},	//   риац, --, --, --, 
   {{0x5a35ba40,0x7641ba41,0x44e800cc,0xa88400d1}},	// [307f0] анат, ynny, কমিক_, ەلمى, 
   {{0x6b7401c0,0xdcf400d7,0x19c4013d,0x00000000}},	//   слуу, mazľ, шәмг, --, 
   {{0x6d44001f,0x1bd59442,0x00000000,0x00000000}},	//   _የስፖር, _коня, --, --, 
   {{0x3154010f,0xab841608,0x4c98011a,0x96b85968}},	//   ניאן_, _гурк, _שברו, вуку_, 
   {{0x7640020b,0xd7046c49,0x00000000,0x00000000}},	//   tnny, рзли, --, --, 
   {{0x76403a97,0xddc400e5,0x00000000,0x00000000}},	//   unny, _kihű, --, --, 
   {{0x7640083a,0x5efc0183,0xe8940024,0x00000000}},	//   rnny, ুনিও_, _гась, --, 
   {{0x7640020b,0xb9d000b7,0x00000000,0x00000000}},	//   snny, _ሺሕ_, --, --, 
   {{0xcb1000c8,0x231801c0,0x5678068e,0x645c00b8}},	//   ַלט_, гцээ_, _абая_, _īrit, 
   {{0x645c00b0,0xdb0c76df,0x00000000,0x00000000}},	//   _ūrit, ngañ, --, --, 
   {{0xc5f800c8,0x354402d5,0x387c0254,0x00000000}},	//   _שפעט, _схав, _kiur_, --, 
   {{0x69c805d1,0x0eb800ee,0xb46402da,0xd394104e}},	//   _ödev, кугы_, _صداه, _тәкә_, 
   {{0x387d4f99,0x7af82804,0x205402d5,0xb8e40327}},	//   _miur_, _šutn, стэр, _ཉའ_, 
   {{0x387c207a,0xa36401f7,0x00000000,0x00000000}},	//   _liur_, _اُهو, --, --, 
   {{0xa3cc2ba2,0x00000000,0x00000000,0x00000000}},	//   श्क_, --, --, --, 
   {{0x387c01ab,0x69d82802,0x403003f6,0x00000000}},	//   _niur_, न्नी, _мејс, --, 
  
   {{0x49c9ba42,0xfaa5353b,0xbb18054e,0xfbdc0051}},	// [30800] клан_, لجلی, _sfîr, _tjên_, 
   {{0x3c3c02f6,0x499586f8,0x3c24000d,0x8d75ba43}},	//   tävä_, ршат, _rõve_, _پاخا, 
   {{0x6e3c2791,0x387dba44,0x39e40107,0x48e401f4}},	//   mirb, _biur_, рдхо_, роев, 
   {{0xd7f80220,0x413c02d3,0xd90dba45,0x387c0356}},	//   луі_, _ኣቕሪቦ, ریق_, _ciur_, 
   {{0x66f44294,0x387d6305,0x65940137,0xf76c0050}},	//   сплу, _diur_, балу, ٘او_, 
   {{0x212c00c6,0xfaa1ba46,0xc8940f14,0x7aa00139}},	//   yzdh_, _фаро, _врањ, _фирз, 
   {{0xe50801e2,0x00000000,0x00000000,0x00000000}},	//   ايعو_, --, --, --, 
   {{0x6e3dba47,0x3c240254,0x04c400ec,0x645c0171}},	//   hirb, _tõve_, هوڙي_, _īris, 
   {{0xdb0c09f3,0x42440107,0x6e3c01a9,0x638400c7}},	//   ngað, ихоб, kirb, аҳҵа, 
   {{0x06881c5c,0x387c01c6,0x35a00139,0xe8040073}},	//   _ﻗﻮﻳﯩ, _ziur_, _мауг, ळावा_, 
   {{0x6e3dba48,0x60180006,0xdcb00208,0x06bc00cc}},	//   dirb, гоня_, ởi_, _ইনটি, 
   {{0x7411ba49,0xf48402f2,0x00000000,0x00000000}},	//   _وولا, _ئالی, --, --, 
   {{0x2295ba4a,0x44240924,0xd04003be,0xcf8c2756}},	//   _التس, _ilo_, ntlə, رژي_, 
   {{0x44240070,0x6e3c0076,0x6a7001c7,0xf1a002e8}},	//   _hlo_, girb, läff, _дрън, 
   {{0x4425ba4b,0xda041533,0xc0c84627,0x00000000}},	//   _klo_, रासत_, _руле_, --, 
   {{0x71780302,0xd04000ac,0x317805d0,0xb0280137}},	//   _בנוס, ktlə, _ברומ, _ۅكۉم_, 
   {{0x4425ba4c,0xdb0c041e,0xab280798,0x9a900092}},	// [30810] _mlo_, ggað, аоѓа_, _ሜዲካል_, 
   {{0x4425ba4d,0x6a700221,0x7b340139,0x387dba4e}},	//   _llo_, häff, _ağuç, _siur_, 
   {{0xfb840962,0x98b9ba4f,0xdb0c005a,0x00000000}},	//   _выгн, улет_, rgañ, --, 
   {{0x44240ca8,0x7ae8037e,0xba7400d1,0xd04003e3}},	//   _nlo_, ægts, _چاست, ftlə, 
   {{0xf6e50239,0xba74004b,0x2b4401c0,0x09cc03d4}},	//   рцен, _ناست, _дэрг, ৰয়া, 
   {{0x4425ba50,0xfbd00a81,0x1958121c,0xcb1002e4}},	//   _alo_, _اتھ_, _багы_, _צלם_, 
   {{0x4425ba51,0x387c03cd,0x00000000,0x00000000}},	//   _blo_, _tiur_, --, --, 
   {{0x13e81607,0xd5c802ab,0x869401e0,0xda0423ef}},	//   умий_, _रावज, шкәс_, रावत_, 
   {{0x44240d29,0x00000000,0x00000000,0x00000000}},	//   _dlo_, --, --, --, 
   {{0x4425ba52,0x9f480165,0xaac801ad,0x69c98c3c}},	//   _elo_, _nnañ_, िंतक, _ödet, 
   {{0x4425ba53,0x6d40f9f4,0x323c001f,0x7af80841}},	//   _flo_, şmaz, _ይኖርባ, _šutl, 
   {{0x4425ba54,0x5045ba55,0x9f480139,0x6e3c0e78}},	//   _glo_, семб, _anañ_, wirb, 
   {{0x52740120,0xb9000327,0xcf380212,0x69d80709}},	//   _луку, _ྨད_, учні_, न्डी, 
   {{0xe29c00c8,0x519400c6,0x237400d0,0xdb0c03b2}},	//   _ישׂר, _الغذ, ňajú_, vgað, 
   {{0x1d1810f5,0x6e3c0008,0x44240254,0x5cf407a5}},	//   ають_, rirb, _ylo_, ояту, 
   {{0x9f480165,0x7bd8002e,0x6e3c0165,0x31b407b7}},	//   _enañ_, _ñuul, sirb, _आयुध, 
   {{0xc0500302,0x3b040a83,0x6e3c0ac8,0x752c03e3}},	// [30820] _מזה_, бето_, pirb, _əcza, 
   {{0xdb0c0ad9,0x6e3c022e,0x00000000,0x00000000}},	//   rgað, qirb, --, --, 
   {{0xe8040490,0xbf98000f,0x8c2400f2,0x00000000}},	//   ळाला_, mjêr, _هفده, --, 
   {{0x7b041427,0x00000000,0x00000000,0x00000000}},	//   órtí, --, --, --, 
   {{0x442401a6,0x81bc00eb,0xf74000d8,0x00000000}},	//   _rlo_, ুড়ি_, пецо, --, 
   {{0x4425ba56,0xd04003be,0x9f48208d,0xd704143e}},	//   _slo_, rtlə, _yaaâ_, تظمي, 
   {{0x4424014a,0xd04003be,0x24540150,0x69ddba57}},	//   _plo_, stlə, ينتس, _ibre, 
   {{0x2ee00589,0x3c2400c5,0x69dc005a,0x81bc0154}},	//   _opif_, _kõva_, _hbre, ুড়া_, 
   {{0x6a7001e6,0x69c81355,0x6d403361,0x1ce00327}},	//   räff, _ödes, ğmay, སསོ_, 
   {{0x6d4007c4,0x09e40f22,0xcfd400cc,0x61c400f1}},	//   şmay, নাকা, _তোলন, زښتم, 
   {{0x4425ba58,0x69ddba59,0xc0a87286,0xbeb80200}},	//   _tlo_, _mbre, داخل_, jzër, 
   {{0x4425ba5a,0x43840597,0x69d9258f,0x9f840137}},	//   _ulo_, _الإق, न्ती, өгүд, 
   {{0x69ddba5b,0x3c24000d,0xdd94121c,0x31680210}},	//   _obre, _nõva_, жагы, ęcza_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x904001f2,0x2294009f,0x00000000,0x00000000}},	//   ọmaị, _الڪس, --, --, 
   {{0xa3cc0a28,0x9cc83452,0x00000000,0x00000000}},	//   श्च_, лыға_, --, --, 
   {{0x7b6495be,0x69dc0327,0x7de4de10,0xd24c01d3}},	// [30830] стве, _bbre, _лінд, _سچی_, 
   {{0x69dc01ab,0x9f480165,0x3da428e5,0xd5b00051}},	//   _cbre, _unañ_, _уриб, _móc_, 
   {{0x69dc0036,0x7c200311,0x80d4009e,0xf969ba5c}},	//   _dbre, _înro, ধিক্, урай_, 
   {{0x7c643cc4,0x69ddba5d,0x7d286656,0xf090010f}},	//   _داخل, _ebre, ıqsı, לנע_, 
   {{0x9585ba5e,0xdcf41d89,0x7bcc02d0,0x7c3c03b9}},	//   олле, mazı, _iccu, miqr, 
   {{0x69d81fb2,0xb88401c6,0x7c3c03e3,0x06640124}},	//   न्दी, _гуай, liqr, ҩхәҭ, 
   {{0x2334035b,0x00000000,0x00000000,0x00000000}},	//   ҧхьр, --, --, --, 
   {{0x6b8000d2,0xd7c87380,0x69dc0023,0x8880036b}},	//   _úmgc, _خوره_, _zbre, _قیلن, 
   {{0xf77002dd,0x7af81710,0x00000000,0x00000000}},	//   _ءاز_, _šutj, --, --, 
   {{0xdcf58664,0x7c3c5fda,0xc0b80092,0xd17800d4}},	//   hazı, hiqr, ሳለሁ_, исні_, 
   {{0xf4f40050,0x7bcd021b,0xf524104e,0x20d000e4}},	//   _دواں_, _occu, _уфан, _ỹire_, 
   {{0xe8e0004d,0x00000000,0x00000000,0x00000000}},	//   _chộp_, --, --, --, 
   {{0xe3b02264,0xc1bc1c5c,0x1cc4025c,0xc7d40375}},	//   _سرن_, _ﻣﯘﺭﺍ, ཏྤལ_, חורי_, 
   {{0x7bcdba5f,0xc690008f,0x877808d8,0x10a4030d}},	//   _accu, ואך_, יארי, _дикн, 
   {{0xbf98002d,0xdcf40205,0x00000000,0x00000000}},	//   rjêr, fazı, --, --, 
   {{0x69ddba60,0xfc005788,0x8b25ba61,0x38a403cb}},	//   _sbre, мпсо, одбе, dŵr_, 
   {{0xda043eaf,0x7aec0204,0x6a714c87,0x89a9ba62}},	// [30840] रांत_, _csct, häfe, икав_, 
   {{0x7bcdba63,0x4ce45a31,0xa0340a81,0x49980246}},	//   _eccu, _джоб, _وى۪ت, ртая_, 
   {{0x78a40218,0x81b40f22,0x7aec004e,0x69dd0bdf}},	//   _cwjv, ঙ্ক_, _esct, _vbre, 
   {{0x3d140034,0x614003b2,0x69ddba64,0x00000000}},	//   नहरे_, _hálø, _wbre, --, 
   {{0x668528dc,0x236000e4,0x99800042,0x6595ba65}},	//   سیال, _ĸijo_, dihŵ_, палу, 
   {{0x69dc209c,0xfcf00092,0x00000000,0x00000000}},	//   _ubre, _ውሰጥ_, --, --, 
   {{0xd9b0f2e7,0x2c7c010f,0x291c00af,0x2ed003d4}},	//   _سەند, _aŭdi_, ävad_, িবিষ, 
   {{0xd6a400c0,0x00000000,0x00000000,0x00000000}},	//   _зiрн, --, --, --, 
   {{0xb6c801d3,0xb9e006be,0x249c01f4,0xf2c0009d}},	//   _نالے_, _üçöl, spvm_, мсэн, 
   {{0x7af80841,0x7c3c022e,0x00000000,0x00000000}},	//   _šutk, ziqr, --, --, 
   {{0xf990025f,0xdcf42c78,0x723000c6,0xa15832e1}},	//   ורת_, yazı, بريط, сану_, 
   {{0x25ac0e04,0xd5b00208,0x09e40154,0x00000000}},	//   _hedl_, _tóc_, নাটা, --, 
   {{0x81b411ba,0x7410b32f,0xd5b0004d,0xdcf40205}},	//   ঙ্গ_, _تونا, _hóa_, vazı, 
   {{0x25ac01ef,0x00000000,0x00000000,0x00000000}},	//   _jedl_, --, --, --, 
   {{0xfba8e1d6,0x7c3c2994,0x25ac072b,0x6441ba66}},	//   итай_, tiqr, _medl_, oimi, 
   {{0x60c81c06,0x59dc0882,0x61e90637,0x69d8202e}},	//   mudm, न्नर, ledl, न्सी, 
   {{0xdcf41ae9,0x64400083,0x7c3c0113,0xde380092}},	// [30850] razı, iimi, riqr, ደማይፈ, 
   {{0x61e80cfd,0x19582401,0xd5c807f7,0x7c3c014f}},	//   nedl, базы_, _राइज, siqr, 
   {{0xa5c40034,0x60c80477,0xdcf40205,0x1a6400e5}},	//   _राजौ, nudm, pazı, _ہیری_, 
   {{0xdce407ae,0x6441ba67,0x25ac0005,0x7bcdba68}},	//   _nghĩ, jimi, _aedl_, _uccu, 
   {{0x61e8127b,0xe709ba69,0xe8e0001e,0x69d80b03}},	//   kedl, قتون_, _khớp_, न्ही, 
   {{0x61e81f7f,0x4b78011a,0x00000000,0x00000000}},	//   jedl, _לארו, --, --, 
   {{0xd18405f5,0x61e9ba6a,0x00000000,0x00000000}},	//   үлий, dedl, --, --, 
   {{0x6441ba6b,0xd2a80108,0x00000000,0x00000000}},	//   gimi, бкие_, --, --, 
   {{0xb780036b,0x9344241e,0x6a7001f4,0x00000000}},	//   _ўғли, яние, säfe, --, 
   {{0x61e9ba6c,0x824002d3,0x6441ba6d,0x60c801bf}},	//   gedl, _ክብርታ, aimi, fudm, 
   {{0x6441ba6e,0xfbc80864,0x59dc090a,0x00000000}},	//   bimi, िलाम, न्यर, --, 
   {{0x6440a341,0xfafc044e,0x00000000,0x00000000}},	//   cimi, _orë_, --, --, 
   {{0x61e9ba6f,0x8e7401b9,0x5768002b,0x61f80413}},	//   bedl, зувч, _pūṣā_, ðalý, 
   {{0xfbdc011f,0xe8e001fb,0x61e80076,0x60c8014f}},	//   _abê_, _chớp_, cedl, budm, 
   {{0x32040034,0xd5b00208,0xfafc036e,0x6a70002f}},	//   _inny_, _xóa_, _arë_, häfc, 
   {{0x3ebc2230,0x8c442950,0x00000000,0x00000000}},	//   šuta_, чебе, --, --, 
   {{0x70d8243c,0x3b0400a7,0x00000000,0x00000000}},	// [30860] _बहुल, пето_, --, --, 
   {{0x4fc00eff,0x683c03b9,0x82280092,0x00000000}},	//   _تەڭە, _içdə, _ስለሚታ, --, 
   {{0xfafc0023,0x291c00c7,0x46cc01f9,0x00000000}},	//   _erë_, âva_, हूनह, --, 
   {{0xfbdc145e,0x61e9ba70,0x25ac013a,0x59dc00cd}},	//   _gbê_, zedl, _sedl_, न्बर, 
   {{0x6441ba71,0x61e8401f,0x00000000,0x00000000}},	//   vimi, yedl, --, --, 
   {{0x6441ba72,0x61e9ba73,0x6d580158,0x00000000}},	//   wimi, xedl, _øvas, --, 
   {{0x61e823e2,0x6441ba74,0x09b00011,0x25ac0118}},	//   vedl, timi, _চাপা, _vedl_, 
   {{0x7af9ba75,0x61e9ba76,0x60c8a249,0xcd3c0092}},	//   _šuti, wedl, vudm, ደሚናገ, 
   {{0x61e80c8c,0x6235ba77,0x27340137,0xd7d00073}},	//   tedl, депу, _تۉشس, _हातच, 
   {{0x6441ba78,0x248c0ac5,0xd200004e,0x00000000}},	//   simi, _tudm_, күчк, --, 
   {{0x6609ba79,0x32d012ea,0xf0d001c6,0x00000000}},	//   _indk, وزیس, нжээ, --, 
   {{0x6441ba7a,0x32048106,0xdcb001fb,0x09b000cc}},	//   qimi, _enny_, ẩm_, _চাফা, 
   {{0x82f8bf30,0xd5b00208,0x961c00e2,0x59dc7ef5}},	//   _دراز_, _món_, _suņi, न्डर, 
   {{0xe3b0a55b,0x06882d40,0x2b000118,0x2d8c0419}},	//   _سرچ_, _ﻗﻮﻟﯩ, रिनु_, žden_, 
   {{0xc0cc02d3,0x6ce400d4,0x00000000,0x00000000}},	//   ጥቃም_, ніте, --, --, 
   {{0x29ec1682,0x9bc818fd,0xd5b00051,0x6c14011c}},	//   ḓalo_, تورك_, _nón_, ндсф, 
   {{0x5e443306,0x2009ba7b,0x32040076,0x1f749308}},	// [30870] _يَعْ, _inai_, _ynny_, _юлия, 
   {{0xdd91ba7c,0x7c840262,0x6d4800c6,0x3da4004e}},	//   _جود_, _нуме, údac, _эриб, 
   {{0x2c7c010f,0x5c741b11,0xd5b00051,0x00000000}},	//   _aŭdu_, _олот, _bón_, --, 
   {{0x660800c5,0x3e8001e1,0x99cc015b,0xdc700092}},	//   _andk, _fétì_, রজেক, _በብሉይ_, 
   {{0x200801ab,0xfc3c0241,0xfafc0240,0x00000000}},	//   _mnai_, _imí_, _urë_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2009ba7d,0x649800f7,0x00000000,0x00000000}},	//   _onai_, птыр_, --, --, 
   {{0x5804005e,0x66080112,0xb9f81ef7,0x00000000}},	//   _تورك, _endk, _መሳ_, --, 
   {{0x59dc0b98,0x15f4012d,0x00000000,0x00000000}},	//   न्थर, _इसपर_, --, --, 
   {{0x2009ba7e,0x05940133,0xe7846cf4,0xc2400166}},	//   _anai_, _قامگ, _чусо, кнык, 
   {{0x20080652,0x09b0009e,0x9f4400bc,0xfc3c0248}},	//   _bnai_, _চামা, ělý_, _omí_, 
   {{0x59dc5ceb,0x272000cc,0x00000000,0x00000000}},	//   न्तर, _মইতো_, --, --, 
   {{0x764000ad,0x94dc000d,0x00000000,0x00000000}},	//   oiny, _महुआ, --, --, 
   {{0x200819a2,0x00000000,0x00000000,0x00000000}},	//   _enai_, --, --, --, 
   {{0x75200472,0x41b0004b,0x00000000,0x00000000}},	//   nynz, _شمير, --, --, 
   {{0x7641ba7f,0x0ba8cf33,0x00000000,0x00000000}},	//   hiny, تاسى_, --, --, 
   {{0xbb40716a,0x09b800c6,0xca85ba80,0x00000000}},	// [30880] ветк, قطاع_, дгай, --, 
   {{0x76413cfa,0xda040807,0xb9e4520c,0x00000000}},	//   jiny, रागत_, ммуз_, --, 
   {{0x7641ba81,0xba14143e,0x59dc00dc,0x00000000}},	//   diny, بيلا_, न्धर, --, 
   {{0x27e009a5,0x2d985d7e,0xc6e402dd,0xbb806911}},	//   ýin_, lcre_, дікп, رلەي, 
   {{0x7641ba82,0x9e641547,0x7af80064,0xe6040139}},	//   finy, _زاین, _šutv, нҗан, 
   {{0x2d99ba83,0x59dd1269,0x9d45ba84,0xd10c0db3}},	//   ncre_, न्दर, _آئین, िमाण_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb7f80316,0x76400099,0x00000000,0x00000000}},	//   _एफएम_, ainy, --, --, 
   {{0x20080649,0x00000000,0x00000000,0x00000000}},	//   _rnai_, --, --, --, 
   {{0x7641ba85,0x2009ba86,0x2e340036,0x05740137}},	//   ciny, _snai_, _häff_, _قااد, 
   {{0xdfd5ba87,0x61700023,0x00000000,0x00000000}},	//   ноны, _ባዕላዊ_, --, --, 
   {{0x03244c6b,0xc3244961,0xf5340a7c,0x00000000}},	//   _оден, _омек, _קנאי_, --, 
   {{0x69c00270,0x00000000,0x00000000,0x00000000}},	//   _ēmen, --, --, --, 
   {{0x0f706518,0x20090115,0xfc3c0118,0x00000000}},	//   ығыр, _wnai_, _smí_, --, 
   {{0x30c40137,0xce340014,0x69d8000d,0x00000000}},	//   _قووپ_, روِک, _नउजी, --, 
   {{0x7641ba88,0x2009ba89,0x20d9ba8a,0x61f87008}},	//   ziny, _unai_, méi_, _havl, 
   {{0x7641ba8b,0x2ef5ba8c,0x61f9ba8d,0x65685522}},	// [30890] yiny, _азыр, _kavl, _lydh, 
   {{0x61f81326,0x2d98be27,0x6b7401c6,0xf968005b}},	//   _javl, ccre_, тлуу, орей_, 
   {{0x7641ba8e,0x61f801b9,0xe9d0007b,0x00000000}},	//   viny, _mavl, شغل_, --, 
   {{0xfc3dba8f,0xb178010f,0xd6b40395,0x00000000}},	//   _umí_, קטאר, ейдъ, --, 
   {{0x7641ba90,0x20d9ba91,0x6568058a,0xd5e413d6}},	//   tiny, héi_, _aydh, ежли, 
   {{0xe618005e,0x75200472,0x7640062c,0x20d800c7}},	//   мді_, tynz, uiny, kéi_, 
   {{0x7641ba92,0xd1b804da,0x20d80022,0x25f00037}},	//   riny, ۋادا_, jéi_, _इसरी_, 
   {{0x74000107,0x00000000,0x00000000,0x00000000}},	//   тоиҷ, --, --, --, 
   {{0x7641ba93,0x61f8f2c9,0x961c00de,0x00000000}},	//   piny, _bavl, _suņu, --, 
   {{0xf5240276,0x61f801bf,0x00000000,0x00000000}},	//   _офен, _cavl, --, --, 
   {{0x61f80517,0x904404fb,0xe8040490,0xb91000cd}},	//   _davl, فنده, ळाचा_, _phaṭ_, 
   {{0x14840451,0xd5b00051,0xc950011a,0x533400d8}},	//   _ڪھڙي_, _hé_, רמט_, _пеет, 
   {{0x2aa001e1,0x00000000,0x00000000,0x00000000}},	//   _ḿbà_, --, --, --, 
   {{0x2d8c04ce,0x61f80a7f,0x20d801c7,0x7c2c007c}},	//   øde_, _gavl, béi_, _alcr, 
   {{0x81f5ba94,0x2d994c8d,0x7bdc002f,0xbb4001ec}},	//   _سفير_, rcre_, ffqu, ңеск, 
   {{0x7c2c0204,0x59dc0da5,0x101401d5,0xd25800de}},	//   _clcr, न्सर, _سببد, ruņu_, 
   {{0x61f80139,0x7998010e,0x00000000,0x00000000}},	// [308a0] _yavl, _şuwa, --, --, 
   {{0x6f05ba95,0x00000000,0x00000000,0x00000000}},	//   _iric, --, --, --, 
   {{0x4c844dcd,0xd5c801ad,0x6f0402f0,0x00000000}},	//   _плов, _राजज, _hric, --, 
   {{0x6f05ba96,0x05d000e1,0x00000000,0x00000000}},	//   _kric, _साहब, --, --, 
   {{0xa5f9ba97,0x6568005c,0xd5b0004d,0x00000000}},	//   делу_, _sydh, _bé_, --, 
   {{0x6aa40170,0x6f0400f2,0x7670109a,0xd4900051}},	//   mpif, _mric, гліф, _bù_, 
   {{0xdb1c007f,0xb7d400b2,0x6e200023,0x15b015bf}},	//   _adsè, _ڳولا_, ëmby, شەنس, 
   {{0x6f040262,0x61f9ba98,0xdb1c067c,0xd4900208}},	//   _oric, _savl, _icsò, _dù_, 
   {{0x20d80a40,0x6f042a6e,0x996000e2,0xb7d46ea9}},	//   wéi_, _nric, _cīņa_, _سولا_, 
   {{0x2d8c0313,0x61f8022e,0x20d800c7,0x00000000}},	//   ždej_, _qavl, téi_, --, 
   {{0x6f05ba99,0x3a340302,0x61f8016d,0x02c03f2c}},	//   _aric, גרים_, _vavl, _शिवभ, 
   {{0x29ec0943,0xd4c029db,0x6f040e21,0x61f80455}},	//   ḓaho_, _төшк, _bric, _wavl, 
   {{0x6f05ba9a,0x20d9ba9b,0x6d482b76,0x6a70014a}},	//   _cric, séi_, údan, jäfo, 
   {{0x6f05ba9c,0x2fc0030a,0x20d800c7,0x9a080150}},	//   _dric, _edig_, péi_, лiне_, 
   {{0xf1b0025f,0xd7d06956,0xbc040108,0x00000000}},	//   _עסק_, _हालच, нчай, --, 
   {{0xac180640,0xbbc80316,0x00000000,0x00000000}},	//   носу_, िलेक, --, --, 
   {{0x6c55ba9d,0xf9c4034b,0x15740116,0x00000000}},	// [308b0] укту, ещен, ﻤﯩﺴﯩ, --, 
   {{0x60c801a4,0x20180427,0xa88400d1,0x39e800c7}},	//   ordm, ljsi_, ۇللى, џьан_, 
   {{0x27e4022f,0x3c240037,0x98b8084c,0x78440153}},	//   _bbmn_, _lõvi_, флет_, нэдж, 
   {{0x60c80175,0x20180010,0x7c2c035a,0x6f040857}},	//   irdm, njsi_, _ulcr, _yric, 
   {{0x9aa400fb,0x8c1808c3,0x00000000,0x00000000}},	//   _шунһ, _חורי, --, --, 
   {{0x966400a7,0x195800f7,0x154406ed,0xd5b00051}},	//   ъкле, _жагы_, келм, _tóm_, 
   {{0xaa540e92,0xd4f400ee,0xd5b00051,0x00000000}},	//   _сврш, тялы, _vé_, --, 
   {{0x1309ba9e,0xe5048248,0xe4c80e56,0x00000000}},	//   дний_, ابوي, ربىن_, --, 
   {{0x56940801,0x95d98622,0x7c20054e,0xe2b401c6}},	//   _разт, _одат_, _înru, лсээ, 
   {{0x35dc0c58,0x422007d8,0x2018012d,0xd4900051}},	//   _যোৰহ, идыв, ejsi_, _tù_, 
   {{0x8fa49cf9,0x6a700139,0x00000000,0x00000000}},	//   кане, däfl, --, --, 
   {{0x6f05ba9f,0xe3b153b4,0xbbc8215d,0x5044004e}},	//   _pric, _هره_, िलोक, темб, 
   {{0x60c851a0,0x54c001ec,0xd234011c,0x00000000}},	//   ardm, _сұқб, _индъ, --, 
   {{0xbea001b9,0x2fc00042,0x6f04007c,0x00000000}},	//   рарк, _wdig_, _vric, --, 
   {{0xdb1c025a,0x6f040204,0xb00401af,0xb3840345}},	//   _âyên, _wric, _бойһ, _تێکم_, 
   {{0x6aa40cf9,0x218804ac,0xdc4404fe,0xc5c885cf}},	//   tpif, _אָפּ, tūān, ল্পপ, 
   {{0xa3c405f9,0x6f05baa0,0x35d4000d,0xf3f003d4}},	// [308c0] ौलत_, _uric, _ठाढ़, _আচাৰ_, 
   {{0x8d747092,0x09b003d4,0x00000000,0x00000000}},	//   _لاجا, _চাহা, --, --, 
   {{0x257801ef,0x00000000,0x00000000,0x00000000}},	//   _mýlí_, --, --, --, 
   {{0x6aa5baa1,0x00000000,0x00000000,0x00000000}},	//   ppif, --, --, --, 
   {{0x2a6400c7,0x2ba80118,0x00000000,0x00000000}},	//   _êmbo_, _छ्या, --, --, 
   {{0xaca40521,0xa4d86afe,0x00000000,0x00000000}},	//   _nkịt, едку_, --, --, 
   {{0x7bcc0356,0xb53c0023,0x00000000,0x00000000}},	//   şiuţ, _ክንፈት, --, --, 
   {{0xaca4063f,0xba380548,0x34440166,0x00000000}},	//   _akịt, _itïa, кчын_, --, 
   {{0x0685a4a0,0xc7640aaf,0xa195baa2,0x00000000}},	//   _аган, _شارى, лапч, --, 
   {{0x99540724,0x06740a89,0xa6c906d7,0x1778003b}},	//   _çäçä, _рубя, _يوځل_, _їсть_, 
   {{0x2d1c01ad,0xb2700139,0x00000000,0x00000000}},	//   नहोल_, рлэш, --, --, 
   {{0x741000aa,0x02c5baa3,0x200cc94b,0x20180007}},	//   _پوها, _айдо, ñei_, ujsi_, 
   {{0x71f44667,0x00000000,0x00000000,0x00000000}},	//   رریس_, --, --, --, 
   {{0x3240036b,0x00000000,0x00000000,0x00000000}},	//   _кечг, --, --, --, 
   {{0x69c805d1,0x0f3001d5,0x291c0254,0x00000000}},	//   _ödey, لکید, äval_, --, 
   {{0xdfd0007b,0x8e2001a9,0x09b00154,0x3c7c01ec}},	//   _اية_, stkа_, _চাষা, _ﺣﺎﺗﻰ_, 
   {{0x05d06fe9,0x2b0000cd,0x00000000,0x00000000}},	// [308d0] _सांब, रिषु_, --, --, 
   {{0x3948034c,0x00000000,0x00000000,0x00000000}},	//   وشاپ_, --, --, --, 
   {{0xe8940124,0xa3c412eb,0x6e2801e3,0x00000000}},	//   аахь, ौला_, ödbe, --, 
   {{0xd7581e87,0xdcb00208,0x7c8400d8,0x00000000}},	//   ىلات_, ẩu_, _шупе, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf1c40306,0xf7a401ec,0x00000000,0x00000000}},	//   čáky_, _ﺷﯩﻨﺪ, --, --, 
   {{0xd468bda8,0xa898016c,0x00000000,0x00000000}},	//   нике_, _аксу_, --, --, 
   {{0x20040165,0xb53c0023,0x4730ca0f,0x00000000}},	//   œlij_, _ክንፍት, рнәс, --, 
   {{0xc7b00302,0x17540006,0x27e001c3,0x13a801e2}},	//   _לבן_, _свая, òine_, ونډی_, 
   {{0xc0b8001f,0x00000000,0x00000000,0x00000000}},	//   ዳለሁ_, --, --, --, 
   {{0x69d8132e,0xd5b001fb,0xfbc0012c,0xe2a80050}},	//   न्टी, _nói_, षणाम, _یاون_, 
   {{0xddd40316,0x6d4804d4,0xe3b000db,0x799800a2}},	//   mozř, údam, _ۇرۇ_, _şuwl, 
   {{0x91e44f65,0xc5f40154,0x0c2439b8,0x00000000}},	//   _боле, চারা_, қман, --, 
   {{0xdd0000b0,0xee44035b,0x00000000,0x00000000}},	//   _ōtāh, рҭои, --, --, 
   {{0x09b000bd,0x4250004b,0x8c7800a7,0x00000000}},	//   _চালা, _دنور, ещат_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x09e4084c,0xc9a80395,0xafe4022e,0x00000000}},	// [308e0] лоан, евзе_, _боқл, --, 
   {{0x3b81baa4,0x05d07db3,0x7f3800df,0x00000000}},	//   слуг, _साइब, _נעיו, --, 
   {{0x068425a2,0xc7c401c0,0x08c4c0f6,0xd5b00208}},	//   ңген, гсли, убен, _gói_, 
   {{0xa4f80133,0x00000000,0x00000000,0x00000000}},	//   ێکار_, --, --, --, 
   {{0x8d7405af,0x00000000,0x00000000,0x00000000}},	//   _جاکا, --, --, --, 
   {{0xc0b80092,0x00000000,0x00000000,0x00000000}},	//   ዳለህ_, --, --, --, 
   {{0x0465baa5,0x6fd40073,0x3ebc025c,0xbb6800d1}},	//   лтим, थलां, ġuti_, ﺳﯩﻠﻪ_, 
   {{0x25f0068f,0xaca4063f,0x3ebc0e04,0x00000000}},	//   _इसकी_, _nkọt, šuti_, --, 
   {{0x05d5baa6,0x3f8c0022,0x75400116,0x3324009d}},	//   _مزاج, _ûgui_, инәз, гцэн_, 
   {{0xaca5baa7,0x00000000,0x00000000,0x00000000}},	//   _akọt, --, --, --, 
   {{0xf5900491,0x05546345,0xa158848e,0x09dc015b}},	//   _المج, _стая, тану_, ড়পা, 
   {{0x3f9c01ab,0x3ce8000d,0xc30406c2,0x00000000}},	//   ùuu_, _चहबे_, _مبتو, --, 
   {{0xbf0c2314,0xd3b80153,0x00000000,0x00000000}},	//   ामेन_, _рухі_, --, --, 
   {{0xb809b546,0x6e9435c7,0x00000000,0x00000000}},	//   _सोनम_, сиру, --, --, 
   {{0x16d0ed65,0x6d3404c2,0x05d037cc,0x00000000}},	//   _सम्ब, берф, _साईब, --, 
   {{0xfb8400fd,0x00000000,0x00000000,0x00000000}},	//   гызн, --, --, --, 
   {{0xaf0886bf,0x09dc009e,0x5b15baa8,0x79a466b4}},	// [308f0] _مقيم_, ড়না, шмат, грее, 
   {{0xdfd001ed,0xd04006be,0x00000000,0x00000000}},	//   _ايک_, dulə, --, --, 
   {{0x2c0008e6,0x7e640477,0xaac400d1,0x6a14009f}},	//   _लोकं_, mojp, لتەن, حبقر, 
   {{0x645c00e4,0xac1800db,0x387021f3,0x6d5800c0}},	//   _írih, _боюу_, ёқат, _žvag, 
   {{0x76a8026a,0xf3f00183,0x291d00b0,0x940403e3}},	//   хтев_, _আচলৰ_, øvar_, _gulə_, 
   {{0x7e64014f,0xa5940395,0x00000000,0x00000000}},	//   nojp, бръщ, --, --, 
   {{0x2e3401b8,0xaa583fd7,0x00000000,0x00000000}},	//   _jäfa_, _сиру_, --, --, 
   {{0x1424e9b3,0x7e640477,0xdd1c00d0,0x00000000}},	//   рдим, hojp, ráňt, --, 
   {{0xf7700375,0x08400014,0xd7600345,0x00000000}},	//   _طار_, _بۆنُ, _بۆشی, --, 
   {{0xf650117d,0xbf0c00e1,0xcb1005d0,0x26c001e4}},	//   _ائر_, ामैन_, קלי_, ɩio_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf485baa9,0x00000000,0x00000000,0x00000000}},	//   _сузн, --, --, --, 
   {{0x6cb401c6,0xa244022e,0xe2980024,0x00000000}},	//   өөнт, g訴sh, _баі_, --, 
   {{0x645c00e4,0x00000000,0x00000000,0x00000000}},	//   _êrir, --, --, --, 
   {{0x2e340166,0x8fa41422,0x00000000,0x00000000}},	//   _cäfa_, _кайе, --, --, 
   {{0xc0dc02d3,0xcdc400cf,0x00000000,0x00000000}},	//   ሓኖም_, دۇگۇ_, --, --, 
   {{0x4a45b259,0x2004043b,0xa7a40131,0x49941d0f}},	// [30900] анав, ɛli_, ەشتۈ, ашет, 
   {{0xf9c42fc0,0x00000000,0x00000000,0x00000000}},	//   لحمی, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc6a5baaa,0x3ce8000d,0xe46403e0,0x00000000}},	//   арки, _चहते_, çlüğ, --, 
   {{0x46f5baab,0x7c28e4c3,0x23dc0490,0x182801b9}},	//   рчет, ögre, _याबद, طقوی_, 
   {{0x6a70002f,0x00000000,0x00000000,0x00000000}},	//   käfi, --, --, --, 
   {{0xe5b40032,0x00000000,0x00000000,0x00000000}},	//   айһы, --, --, --, 
   {{0xe5e40583,0x44200162,0x00000000,0x00000000}},	//   _گزری, ðk_, --, --, 
   {{0x7e6403f0,0x05140154,0x54180eff,0x00000000}},	//   yojp, ়নের_, ارىڭ_, --, 
   {{0xdb0c003e,0x2258000d,0x00000000,0x00000000}},	//   ékéa, õrk_, --, --, 
   {{0x2ee0036e,0x5f94baed,0x1fb80139,0x00000000}},	//   _aqif_, йинт, ллны_, --, 
   {{0xa30800e5,0x00000000,0x00000000,0x00000000}},	//   _مرتے_, --, --, --, 
   {{0x69dd8079,0x2004012c,0x705800ee,0x7e64f1f5}},	//   _ocre, ěli_, раяр_, tojp, 
   {{0x2004006d,0x25bc0fac,0x932433ae,0x00000000}},	//   śli_, navl_, _درمن, --, 
   {{0x7e64a39f,0x6d4001e4,0xdb1401e1,0x6e2801e3}},	//   rojp, ŝman, _àbúl, ödba, 
   {{0x69dc18a8,0xec3402bf,0xd5b00208,0x387c00d7}},	//   _acre, онсь, _hót_, _ďuro_, 
   {{0xfb84e2cc,0x68fc036b,0x5a343252,0x7de5baac}},	// [30910] рывн, _asrd, бнат, _кінд, 
   {{0x39a5baad,0x7e64df70,0x37e00154,0x00000000}},	//   ршав, qojp, _নোংর, --, 
   {{0x69dc0334,0x25bc01bf,0x00000000,0x00000000}},	//   _dcre, davl_, --, --, 
   {{0x69dc0c8c,0x25bc0076,0x310400dc,0xb8ecacda}},	//   _ecre, eavl_, षितः_, _शि_, 
   {{0x8c180302,0xe3cc0154,0xd7040116,0xd2e40037}},	//   _עושי, লভাব, сзли, _कहेब_, 
   {{0x59c45cb5,0x69dc007b,0x25bc01bf,0x67240037}},	//   _ديسك, _gcre, gavl_, äija, 
   {{0x95b4035b,0x00000000,0x00000000,0x00000000}},	//   арқә, --, --, --, 
   {{0xed580302,0x6d4800c6,0x67d5baae,0x94780500}},	//   יבור_, údai, _мосу, ыслу_, 
   {{0xd72400cc,0x00000000,0x00000000,0x00000000}},	//   _মেৰা_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x387c0649,0xe4e402bf,0xa224007b,0xf4f400e5}},	//   _khur_, _міцн, تريه, _خواں_, 
   {{0x95c80184,0xc95002e4,0x60dc00a3,0x0d20010b}},	//   _шуға_, למי_, àrma, җүмү, 
   {{0x387c00a3,0x6a70005b,0x8e84004e,0x00000000}},	//   _mhur_, säfi, йгме, --, 
   {{0x8778008f,0x8e5401ca,0xdb1401e1,0x00000000}},	//   טארי, стмі, _àbùl, --, 
   {{0x2d8c0eeb,0x80cc07f7,0xd00800fb,0x00000000}},	//   äde_, _थिये, _бейе_, --, 
   {{0x69dcb557,0x7aec3801,0xc170011a,0x4f940bb1}},	//   _scre, _bpct, _מחו_, _урку, 
   {{0xf3e80327,0x4df401af,0x00000000,0x00000000}},	// [30920] _ཡིནཅ, _лянт, --, --, 
   {{0xbf9803b7,0x46a401e0,0x4994782f,0xb408012d}},	//   ndên, ҡаев, сшат, ążył, 
   {{0x93f80574,0x78a40354,0x48e400c7,0x387c37a8}},	//   ्याच_, _ctjv, соев, _bhur_, 
   {{0x387dbaaf,0x2d8c0153,0x69dc0042,0x00000000}},	//   _chur_, ždes_, _wcre, --, 
   {{0x387dbab0,0x81bc0183,0x00000000,0x00000000}},	//   _dhur_, ইলত_, --, --, 
   {{0xfaa11fc9,0x387c062c,0x69ddbab1,0xc894009b}},	//   _харо, _ehur_, _ucre, _грањ, 
   {{0xc7a4034b,0x68fc01a6,0x25bc01bf,0x23dc012d}},	//   _гибк, _usrd, ravl_, _यादद, 
   {{0x64a40184,0x387c014f,0xd5b00051,0x00000000}},	//   баҫа, _ghur_, _sót_, --, 
   {{0x25bc0589,0x850437f7,0x2b4001a6,0xdd2400e2}},	//   pavl_, _گوان, nzic_, cīņa, 
   {{0x26c40455,0xd62499db,0x387c0200,0x00000000}},	//   _ivmo_, _وعلي, _zhur_, --, 
   {{0x04940491,0xdfd091e8,0x850403e6,0x5ff40b7e}},	//   _الصح, ويد_, _دوان, озну, 
   {{0x2360035b,0x387c003d,0xbfa8005b,0x212c0200}},	//   _ÿijo_, _xhur_, ытое_, rydh_, 
   {{0xdb1c0122,0x442401c7,0xbf9800d8,0xdcec0205}},	//   _odsá, _ioo_, bdên, _ıkım, 
   {{0x4425bab2,0x2b41bab3,0x00000000,0x00000000}},	//   _hoo_, dzic_, --, --, 
   {{0x9f4800e4,0x6d3468eb,0x7d00013a,0x00000000}},	//   _mbaé_, перф, dírá, --, 
   {{0x4425bab4,0xc100dd5c,0x7aec01e7,0x95f407af}},	//   _joo_, _дүүл, _ppct, _इस्ट_, 
   {{0x4425bab5,0x7ed4c9a4,0x30140124,0x00000000}},	// [30930] _moo_, _ازعا, _хдыр, --, 
   {{0x4425bab6,0x387dbab7,0x7d0000e5,0x6d640174}},	//   _loo_, _shur_, gírá, ávað, 
   {{0x4ad802ab,0x9b940276,0xb5a40c50,0x2d8c01a6}},	//   यूबव, _минц, ەپتە_, žder_, 
   {{0x442497b4,0x81bc0154,0x3cc400d1,0x00000000}},	//   _noo_, ইলি_, _ﺩﯛﺷﻤ, --, 
   {{0xe6102580,0x7d007815,0x9f48002e,0xba7404fb}},	//   کشن_, bírá, _kaañ_, _هاست, 
   {{0x44240e39,0x00000000,0x00000000,0x00000000}},	//   _aoo_, --, --, --, 
   {{0x4425bab8,0xdb1c2776,0x7a380311,0x70b40037}},	//   _boo_, _âyân, _cîte, _आबेल, 
   {{0x4424a032,0xa85400a8,0x7a380129,0x00000000}},	//   _coo_, _ексч, _dîte, --, 
   {{0x4425bab9,0xe784055f,0xe2a8030f,0xe8185f0f}},	//   _doo_, _еуфо, یاین_, _уотч_, 
   {{0x44240393,0x9f4800e8,0x90c40117,0x51d40014}},	//   _eoo_, _naañ_, обое, زگتھ_, 
   {{0x4425baba,0x7a3807ea,0x555403e6,0xbf9800d8}},	//   _foo_, _gîte, _بپار, rdên, 
   {{0xfafc0124,0xddd401e4,0xc8d8011a,0x00000000}},	//   _osë_, rozŝ, סקרט, --, 
   {{0x9f48002e,0x0d980108,0x00000000,0x00000000}},	//   _baañ_, итвы_, --, --, 
   {{0x4425babb,0x25fc00ce,0x60e80174,0x00000000}},	//   _zoo_, लजयी_, ósmø, --, 
   {{0x4425babc,0x01600228,0x7d0000bc,0xd04493fe}},	//   _yoo_, _окшо, vírá, _وپتي, 
   {{0x6a7009a4,0x44240218,0x244c0023,0x00000000}},	//   häft, _xoo_, _ንቅድሚ, --, 
   {{0x3b0464e1,0x7d00634d,0xca300050,0x7ec000c7}},	// [30940] оето_, tírá, وٝر_, rãpý, 
   {{0x9f480de2,0xdb0803b2,0x00000000,0x00000000}},	//   _gaañ_, _ínýg, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x290c0162,0x7d0001d3,0xcb6800d8,0x00000000}},	//   _ádam_, sírá, _ваме_, --, 
   {{0x4425babd,0xc6880395,0x00000000,0x00000000}},	//   _roo_, айдж_, --, --, 
   {{0x44247fc5,0xe9440214,0x161400d1,0x93c801e0}},	//   _soo_, _فرزی, كسىڭ, ҡтыҡ_, 
   {{0x4425babe,0xd0b000ac,0xd5b9babf,0xc7a400a7}},	//   _poo_, _təəs, ссі_, _мивк, 
   {{0x44240263,0x070805d9,0x46d007f7,0x00000000}},	//   _qoo_, _پيئي_, _सिपह, --, 
   {{0x4425bac0,0xf36001c4,0x00000000,0x00000000}},	//   _voo_, дтэн, --, --, 
   {{0x81d02f8b,0x4425bac1,0x7a382776,0x23dc0882}},	//   হ্ন_, _woo_, _tîte, _यावद, 
   {{0xf0d00323,0x75d010fe,0x4425bac2,0xb42001ed}},	//   мжээ, _زينا, _too_, سٹیو, 
   {{0x44240270,0x4368008e,0x0368013d,0x00000000}},	//   _uoo_, _каен_, _киек_, --, 
   {{0xdd9420a9,0xf8d406b1,0x00000000,0x00000000}},	//   загы, _डम्प, --, --, 
   {{0xa2f801ad,0x00000000,0x00000000,0x00000000}},	//   ्टीज_, --, --, --, 
   {{0x6ce402bf,0x645c1686,0xbc480006,0xd04006be}},	//   міте, _íris, ачае_, hrlə, 
   {{0xfbd00014,0x9f4800e8,0xd04003e3,0x00000000}},	//   بتس_, _waañ_, krlə, --, 
   {{0x5a35bac3,0x69c000b0,0xbe4800f2,0x00000000}},	// [30950] пнат, _ēmer, _نشدم_, --, 
   {{0x78a001d3,0xd0400213,0x00000000,0x00000000}},	//   ínvo, drlə, --, --, 
   {{0x3945bac4,0x41ec0327,0x068802dd,0x00000000}},	//   àns_, _ཨིནྟ, _ﺗﻮﻋﯩ, --, 
   {{0xfbd00d62,0x99cc00fe,0xd04006be,0x00000000}},	//   _کتھ_, ৰজেক, frlə, --, 
   {{0x8c180302,0x628801b9,0x6d5800c7,0xd5b00051}},	//   _הורי, kmdo, _ÿvar, _bóp_, 
   {{0x06d800fe,0x00000000,0x00000000,0x00000000}},	//   _ধনশি, --, --, --, 
   {{0x6a712341,0x25ec00af,0x09b00154,0x291c000d}},	//   räft, _आउरी_, _চাচা, ävat_, 
   {{0x6288017a,0xdb0803b2,0xdedc0092,0xd04003b9}},	//   emdo, _ínóg, ንህን_, brlə, 
   {{0x24480214,0xb5a43866,0x527400cf,0x69d80174}},	//   تجوي_, _дрей, зуну, óveg, 
   {{0x36340502,0xc2400dbb,0xd5b00208,0x6a700139}},	//   _بررس, еньк, _góp_, läfr, 
   {{0xd008fda6,0xdb1c037e,0x8621bac5,0x19300092}},	//   бене_, _udsæ, _سکول, _በሚሊዮ, 
   {{0x3d0c278e,0x00000000,0x00000000,0x00000000}},	//   डिने_, --, --, --, 
   {{0x7a301ea0,0xb4b81c5d,0x31680210,0x00000000}},	//   _kıtı, _अबु_, łcz_, --, 
   {{0x94280327,0x6cc821f3,0xc1e00037,0x00000000}},	//   ལིམཱ_, оқов_, _खायब_, --, 
   {{0xc6900302,0x00000000,0x00000000,0x00000000}},	//   תאם_, --, --, --, 
   {{0x2055bac6,0x9f4803b2,0x00000000,0x00000000}},	//   _отыр, _taað_, --, --, 
   {{0xe0845706,0x49c805f5,0x00000000,0x00000000}},	// [30960] _تجوي, йлан_, --, --, 
   {{0x499831af,0xd0400213,0xb4b8107c,0xda6473eb}},	//   стая_, vrlə, _अबू_, والي, 
   {{0x8ba4009d,0x00000000,0x00000000,0x00000000}},	//   _нинж, --, --, --, 
   {{0xec140131,0x00000000,0x00000000,0x00000000}},	//   _تۈرد, --, --, --, 
   {{0xfbd0025f,0x7a3003e0,0x7aa01367,0x62880042}},	//   _אתר_, _bıtı, _пияз, ymdo, 
   {{0xd6a804fb,0x291c0267,0x7a300205,0xb8e801d9}},	//   زدهم_, ävas_, _cıtı, شبۅے_, 
   {{0xd90dbac7,0x9f580ea0,0x00000000,0x00000000}},	//   _پین_, gesê_, --, --, 
   {{0x07a40323,0x80a802f5,0xf48020b0,0xd7d4030d}},	//   _хаан, _কিল্, нуын, _оцуь, 
   {{0x7a300790,0xf74000f0,0x00000000,0x00000000}},	//   _fıtı, _зето, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d581462,0x00000000,0x00000000,0x00000000}},	//   _žvan, --, --, --, 
   {{0x39540302,0xf4841bf4,0x00000000,0x00000000}},	//   לשים_, _فانی, --, --, 
   {{0x9f58036e,0x94700066,0x00000000,0x00000000}},	//   mesë_, _جگوا, --, --, 
   {{0x7a3800e4,0x9f580240,0xf0b43267,0x00000000}},	//   _oîta, lesë_, _کاوش_, --, 
   {{0xf27802e4,0x6440037e,0x7200129d,0x00000000}},	//   _הרגש, ohmi, _سويم, --, 
   {{0x9f580023,0x2d5802bf,0xdb0c0109,0x644124e5}},	//   nesë_, чись_, ubaï, nhmi, 
   {{0xdb0c0129,0xa11400e5,0x64400108,0x7bd40139}},	// [30970] rbaï, _روکت, ihmi, _ğauğ, 
   {{0x9f580240,0x9e840345,0x00000000,0x00000000}},	//   hesë_, _تابۆ, --, --, 
   {{0x6ca5bac8,0x644003a2,0xa3bc00af,0x6d580022}},	//   _пряж, khmi, अरा_, _ÿvap, 
   {{0xdb0c04d4,0x9f580023,0x7a300166,0x00000000}},	//   lbaí, jesë_, _sıtı, --, 
   {{0x64400597,0x7bdc0944,0xdb1c0240,0x81d00154}},	//   dhmi, mgqu, _mesë, _হউন_, 
   {{0x7a38025a,0x7a300139,0x00000000,0x00000000}},	//   _fîta, _qıtı, --, --, 
   {{0x7a38006a,0x9f58036e,0x068801ec,0xd3149ea0}},	//   _gîta, fesë_, _ﺗﻮﻗﯩ, तम्ब_, 
   {{0x7bddbac9,0xc950025f,0xdb1dbaca,0x3f98009a}},	//   ngqu, _סמן_, _nesë, _ngqu_, 
   {{0xd1b82dfc,0xe354009d,0x00000000,0x00000000}},	//   يادا_, етээ, --, --, 
   {{0x10a46349,0x645c0248,0x00000000,0x00000000}},	//   мион, _ìrin, --, --, 
   {{0xdb1c3060,0x9f58b89a,0xd5341867,0x00000000}},	//   _besë, lesè_, _تفاخ, --, 
   {{0x6441bacb,0xf414063f,0x00000000,0x00000000}},	//   chmi, ịọrị, --, --, 
   {{0xc0dc0023,0x9f580100,0x5ec41219,0x00000000}},	//   ቓለለ_, nesè_, нияғ, --, 
   {{0xb62c105c,0xa2940212,0x1fb400c7,0x0ca8007b}},	//   _ｐｃ_, _зачі, _ҧсыр, قطري_, 
   {{0xfce17cf8,0x2e3401b8,0x32040170,0x2cadbacc}},	//   коро, _jäfi_, _iany_, ëdd_, 
   {{0x3205bacd,0xdb1dbace,0x81bc0154,0x00000000}},	//   _hany_, _kesè, ইলঃ_, --, 
   {{0xfafc00da,0x0e640334,0x32058e5c,0x00000000}},	// [30980] šīnu_, _окин, _kany_, --, 
   {{0x6f05bacf,0x8d75bad0,0x3205bad1,0x2fc001c7}},	//   _isic, _يادا, _jany_, _heig_, 
   {{0x8c44d43d,0x3205bad2,0x1ea800aa,0x4c85bad3}},	//   _жене, _many_, _وایي_, _олов, 
   {{0x32040851,0x9f580699,0x2fc00731,0x38c83c5b}},	//   _lany_, fesè_, _jeig_, زامی_, 
   {{0x9f580200,0x00000000,0x00000000,0x00000000}},	//   vesë_, --, --, --, 
   {{0x6f040451,0x3204c8b0,0x2fc00192,0x00000000}},	//   _msic, _nany_, _leig_, --, 
   {{0x6441bad4,0x6f04009a,0x9f5802d3,0x9f4801b8}},	//   thmi, _lsic, tesë_, _ükön_, 
   {{0x6f040b6f,0xdb1c020c,0x2fc1bad5,0x3205909c}},	//   _osic, _besè, _neig_, _aany_, 
   {{0x32040137,0x9f5802d3,0x6d580024,0x21c80150}},	//   _bany_, resë_, _žval, _ﻓﻘﺭﺭ, 
   {{0x6441bad6,0xdb1d26bb,0x2fc0004e,0x3cfc00cc}},	//   shmi, _desè, _aeig_, _উপস্_, 
   {{0x3205bad7,0x6f05bad8,0xdb1c0023,0x2fc000ef}},	//   _dany_, _asic, _pesë, _beig_, 
   {{0xf9900302,0x66082cf7,0x9f59bad9,0xdb1c0200}},	//   כרת_, _hadk, lesé_, _qesë, 
   {{0x74111ea1,0x3204213f,0x6608014b,0x27e405b1}},	//   _جونا, _fany_, _kadk, _mcmn_, 
   {{0x6f05bada,0x3205badb,0xee842f6a,0xdb1002f0}},	//   _dsic, _gany_, высо, áfíh, 
   {{0x6f043e6e,0x2bd0033d,0x2fc00086,0x62980472}},	//   _esic, तृभा, _feig_, _iivo, 
   {{0x32041311,0x6299badc,0xdb1c0022,0xac19badd}},	//   _zany_, _hivo, _hesé, мосу_, 
   {{0x20080270,0xdb1c0022,0x62998571,0xae0c03ce}},	// [30990] _iaai_, _kesé, _kivo, िएशन_, 
   {{0x6299190e,0x20080926,0x2fc00e78,0x6608e4e5}},	//   _jivo, _haai_, _zeig_, _nadk, 
   {{0x62980851,0x2009bade,0xdb1c01ed,0x2fc00363}},	//   _mivo, _kaai_, _mesé, _yeig_, 
   {{0x6298bdc1,0x315400c8,0x660801d9,0x3ddc02a8}},	//   _livo, ויבן_, _aadk, ɗuwa_, 
   {{0x6609badf,0x386c0998,0x2aa401b8,0x20080ea0}},	//   _badk, rogr_, _göb_, _maai_, 
   {{0x6299bae0,0x20080660,0xdb1dbae1,0x79a40220}},	//   _nivo, _laai_, _odsú, _ірге, 
   {{0x66080d62,0x3205bae2,0x9f580699,0x53a5bae3}},	//   _dadk, _rany_, sesè_, найб, 
   {{0x320409a5,0x13044c70,0x629802f6,0xdb1c067c}},	//   _sany_, езим, _aivo, _pesè, 
   {{0x6299bae4,0xf771bae5,0xfe0c5b82,0x32049ab7}},	//   _bivo, _شار_, ायास_, _pany_, 
   {{0x6609bae6,0xe784277c,0xba380022,0xdb1c068c}},	//   _gadk, _русо, _itïs, _vesè, 
   {{0xdb1d99b5,0xd009bae7,0x20080942,0x320400bc}},	//   _desé, пене_, _baai_, _vany_, 
   {{0x76400a2e,0x23600122,0xd009bae8,0x6299bae9}},	//   lhny, _žije_, чеме_, _eivo, 
   {{0x3204325f,0x20080151,0x62980851,0x2fc1baea}},	//   _tany_, _daai_, _fivo, _veig_, 
   {{0xfc3c0f71,0x660801d9,0x7bcc0393,0xdb1c0221}},	//   _alí_, _xadk, _adcu, _gesé, 
   {{0x75f02c6f,0x2009baeb,0x6aa401d9,0x2fc1baec}},	//   mızı, _faai_, wqif, _teig_, 
   {{0x2008017a,0xfc3c0332,0x6f0435ae,0x8f68155b}},	//   _gaai_, _clí_, _tsic, _найб_, 
   {{0xfc3c0597,0x6f040c8c,0x76400ac5,0xf1d06611}},	// [309a0] _dlí_, _usic, khny, _दयान, 
   {{0x75f04953,0x629818f7,0x200801f5,0x19b802d5}},	//   nızı, _xivo, _zaai_, дуць_, 
   {{0xba380137,0x7db802e4,0x6d4800a3,0x43600092}},	//   _suïc, _מציצ, ùdad, _ውድድሩ, 
   {{0x4875baed,0x66081008,0x8c44d1d8,0x4c680395}},	//   رداس, _sadk, _чеме, _химн_, 
   {{0x9e65baee,0x6609baef,0x6aa5baf0,0x9f5800f2}},	//   _ساین, _padk, qqif, tesé_, 
   {{0x2579baf1,0x66080067,0x7641baf2,0xfc3c02f0}},	//   мбль_, _qadk, ghny, _zlí_, 
   {{0x6299baf3,0xd9b00075,0xdb1c90d0,0xdb0c0022}},	//   _rivo, _ئەمد, _resé, mbaá, 
   {{0x7641baf4,0x660845b2,0x47d4007b,0x00000000}},	//   ahny, _wadk, _سيطر, --, 
   {{0x200805e4,0xba380022,0xdb1c73a0,0x6608022e}},	//   _raai_, _itïr, _pesé, _tadk, 
   {{0x7641baf5,0x20081af3,0x6298e236,0x61fc022e}},	//   chny, _saai_, _qivo, еrla, 
   {{0x6299baf6,0xa3e84614,0xbb18025a,0x2009baf7}},	//   _vivo, _बाप_, _nzîn, _paai_, 
   {{0x434400a7,0x78a01686,0x6299a1e3,0xd36c00cf}},	//   _пеев, ínvi, _wivo, حۇۇ_, 
   {{0x6299baf8,0x2008096b,0x9f5801bf,0x75f00166}},	//   _tivo, _vaai_, ndsø_, bızı, 
   {{0x20080660,0xfc3c00c6,0x00000000,0x00000000}},	//   _waai_, _slí_, --, --, 
   {{0x2009baf9,0x91c00588,0x00000000,0x00000000}},	//   _taai_, _тәыл, --, --, 
   {{0xb17802e4,0x5ff40022,0x7178011a,0xa3e8d639}},	//   _מטור, _рзиу, _מנוס, _बाफ_, 
   {{0xa3e82ac3,0x00000000,0x00000000,0x00000000}},	// [309b0] _बान_, --, --, --, 
   {{0xbbe83cb9,0x6b7428fc,0xa2d880a0,0x4ab000c7}},	//   _کردم_, улуу, _मिन्, рҩрр, 
   {{0x80a400e1,0x00000000,0x00000000,0x00000000}},	//   _घूमे, --, --, --, 
   {{0x25ac00ca,0xd759bafa,0xfc3dbafb,0xe7ec0037}},	//   _afdl_, ولات_, _ulí_, छ्ला_, 
   {{0x76400a2e,0x00000000,0x00000000,0x00000000}},	//   thny, --, --, --, 
   {{0x4660104b,0x46d0012c,0x3fac0131,0x00000000}},	//   لۇقق, _सिरह, _ﺳﯩﺰﻧ, --, 
   {{0xd468173e,0xdb0c002e,0x855401e1,0x00000000}},	//   мике_, maañ, _pàtẹ, --, 
   {{0x6d584a52,0x7641bafc,0xe8940064,0x21b80150}},	//   _žvak, shny, _бась, _ﺤﺸﺭﻭ, 
   {{0x7c2dbafd,0x2e3401e3,0x85540014,0x00000000}},	//   _mocr, _käft_, _ییٖر_, --, 
   {{0x7c2c65b4,0x00000000,0x00000000,0x00000000}},	//   _locr, --, --, --, 
   {{0xe4d400e5,0x00000000,0x00000000,0x00000000}},	//   _متنب, --, --, --, 
   {{0x7c2d6923,0x75f0456f,0xa3e810eb,0x935800f3}},	//   _nocr, sızı, _बाय_, _орлу_, 
   {{0x44440014,0x28d800bc,0x61f403b2,0x00000000}},	//   _جرٕہ, _डिभि, íflí, --, 
   {{0xda10069f,0x7c2c0076,0x82d4008f,0x2e34013d}},	//   _डोलत_, _aocr, _יונג_, _näft_, 
   {{0xa3e82ba2,0x7c2c013d,0x00000000,0x00000000}},	//   _बाम_, _bocr, --, --, 
   {{0xbc6024b1,0x26181025,0x1fd80154,0xc8c800f1}},	//   авск, _योनी_, ধ্বস, ېوان_, 
   {{0xfaa05fce,0x1600447d,0xfaa401d5,0xdb1001e1}},	// [309c0] иато, लजार_, نجلی, _ńfòs, 
   {{0xadb800db,0xc8c80014,0xfb841c35,0x7bc80413}},	//   _سۇرا_, ِوان_, тбук_, ógur, 
   {{0xfbdc045f,0x99140a4a,0x48e401af,0x00000000}},	//   _blêd_, льці, тоев, --, 
   {{0xbae000db,0x00000000,0x00000000,0x00000000}},	//   اكەي, --, --, --, 
   {{0xc4c8025c,0xa3e80b03,0x00000000,0x00000000}},	//   _ྋསྤྱ, _बाब_, --, --, 
   {{0x76700845,0xe8e00208,0x9f59bafe,0x00000000}},	//   аліф, _chợp_, rdsø_, --, 
   {{0x0465baff,0x00000000,0x00000000,0x00000000}},	//   ктим, --, --, --, 
   {{0xfbdc000f,0xa2c400d1,0x428800d1,0x00000000}},	//   _glêd_, гәкк, ﺮﯨﻨﭽ, --, 
   {{0xdee40023,0x00000000,0x00000000,0x00000000}},	//   ዝቶን_, --, --, --, 
   {{0x762005d9,0x3f8c0022,0x00000000,0x00000000}},	//   _پڙهن, _úgui_, --, --, 
   {{0xb9f81772,0x46c4012c,0x3a340375,0x357000e5}},	//   _ዘዳ_, _रौतह, דרים_, _پھوڑ, 
   {{0xdb0c06ea,0x00000000,0x00000000,0x00000000}},	//   kaað, --, --, --, 
   {{0xdb0c0798,0x613802d2,0xdb1c005c,0xa1a401af}},	//   mbaç, _búlú, _udsø, _йыйһ, 
   {{0x7c2dbb00,0x20540724,0xa3e800c5,0xa1140244}},	//   _socr, _әкия, _बाड_, _موتت, 
   {{0x7c2dbb01,0x9f59bb02,0xbff001ec,0xbc386e92}},	//   _pocr, mesí_, _күнш, وسرا_, 
   {{0x46d0b4ab,0xaf340133,0x00000000,0x00000000}},	//   _सिंह, ارێت, --, --, 
   {{0x5b1428b6,0xdd901a57,0x9f4801e1,0x291c007c}},	// [309d0] ымат, _گود_, _àkàn_, åvan_, 
   {{0x9f5804d4,0x8500012c,0x6e3c123b,0x6d4801ab}},	//   nesí_, लबाट_, ckrb, ùdac, 
   {{0xdd91bb03,0xa3e800e1,0x6d400115,0x51b401ec}},	//   _دود_, _बाढ_, ŝmar, _ﺤﺸﻴﺸ, 
   {{0xdb1c0077,0xd88801d3,0x81bc00eb,0x00000000}},	//   _hesí, رپشن_, ইলট_, --, 
   {{0xf6e5bb04,0x163400a7,0x79a400d8,0xc1e001f9}},	//   тцен, ледя, _арбе, _खांब_, 
   {{0x6d5802d5,0x00000000,0x00000000,0x00000000}},	//   _žvai, --, --, --, 
   {{0xdb1c04d4,0x0a2802d3,0x929c0210,0x00000000}},	//   _mesí, _ተማሃራ, dwła, --, 
   {{0xdb1dbb05,0xbf980af2,0x27e001ab,0xa3e808f2}},	//   _lesí, ndês, òint_, _बाण_, 
   {{0xdb1c00c7,0x81bc015b,0x93240a11,0x35e40798}},	//   _hesâ, েলন_, ارعن, _ацев, 
   {{0xdb1c0af2,0x76840588,0xd838010e,0xa3e828d4}},	//   _nesí, _рыбж, _diōe_, _बाथ_, 
   {{0xa2d880ea,0xe4e402bf,0x23dc0073,0x88800244}},	//   _मिथ्, _вічн, _याचद, _ئیۆن, 
   {{0x24580124,0xa3d40354,0x2f340092,0x00000000}},	//   _иахь_, _воцч, _ይሸፍና, --, 
   {{0xa3e84425,0xba39bb06,0x9aec02a8,0x5274010b}},	//   _बात_, _ruïn, ƙoƙi_, _йуку, 
   {{0xa2d860d3,0xbea0334e,0x14840451,0x7a180171}},	//   _मित्, сарк, _جھڙي_, _jātē, 
   {{0xdb1c012c,0x2720033f,0x8d6400ee,0x7a180171}},	//   _desí, _मप्र_, увве, _mātē, 
   {{0x6e3da2f9,0x2a793fcd,0x80a800eb,0x00000000}},	//   skrb, _skrb_, _কিচ্, --, 
   {{0xc0500375,0x5ba400fb,0xd64c010a,0x38c800e5}},	// [309e0] _לזה_, рлуғ, _кiие, ہانی_, 
   {{0x0d2000db,0x4e2800cf,0x00000000,0x00000000}},	//   _лүгү, _чоон_, --, --, 
   {{0x38c86f43,0x46c402ab,0x08340248,0x00000000}},	//   فانی_, रीनह, _àìkú_, --, 
   {{0xdb1dbb07,0x8174010f,0x46a40006,0x00000000}},	//   _desâ, אגעס_, гадв, --, 
   {{0x929c0210,0x00000000,0x00000000,0x00000000}},	//   zwła, --, --, --, 
   {{0x16140075,0xa5f87a73,0x44f8031c,0x798402d0}},	//   لسىڭ, теку_, _ྒྱུར_, _fzjw, 
   {{0xa3e8fd3e,0xbf99bb08,0x2504010b,0x00000000}},	//   _बाद_, ndêr, рҗев, --, 
   {{0x29180a4d,0x16a40124,0x00000000,0x00000000}},	//   _irra_, ыгәҭ, --, --, 
   {{0xdb0cfd3c,0xc1e80953,0x41c40006,0x9f580270}},	//   rbaç, ньне_, лёна, tesí_, 
   {{0xdb1c00c7,0x69c80037,0xb7d400e5,0x00000000}},	//   _hesã, _õded, _لوہا_, --, 
   {{0xdb1cd02b,0xb9ec0023,0x00000000,0x00000000}},	//   _resí, _ሕድ_, --, --, 
   {{0x71f4066d,0xdb1c0589,0x03a5bb09,0x9f580270}},	//   پریس_, _jesã, _сидо, sesí_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2919bb0a,0xdb1c0120,0x25e85b82,0xa1945cf1}},	//   _orra_, _lesã, च्ची_, _калч, 
   {{0xdb1c0005,0xdd95bb0b,0xe7a4033f,0x24801418}},	//   _vesí, равы, _ओलंप, ŋimu_, 
   {{0x7c8400d8,0x00000000,0x00000000,0x00000000}},	//   ѓуве, --, --, --, 
   {{0x291800dd,0xd24c04d3,0xdb983252,0x46c407b7}},	// [309f0] _arra_, _رچی_, твач_, रीमह, 
   {{0x5d5400d4,0x12c80150,0x00000000,0x00000000}},	//   _вкот, _ﻓﺈﻴﺭ, --, --, 
   {{0x49a40032,0x00000000,0x00000000,0x00000000}},	//   рыуғ, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x29198ac1,0x68fc581e,0x61f809a8,0x7a1800b0}},	//   _erra_, _eprd, _obvl, _pātē, 
   {{0xe618005e,0x54d4084c,0xd00c015b,0xdb1c0124}},	//   лді_, ациу, ষায়_, _tesâ, 
   {{0x3aedbb0c,0xe81002ab,0x154419c9,0xb8840116}},	//   lüp_, _ठोका_, рейм, _буай, 
   {{0xd3f80006,0xfc380092,0x00000000,0x00000000}},	//   тэкі_, _የወጣው, --, --, 
   {{0x3aedbb0d,0x42c5bb0e,0x78a40455,0xa3b40cb4}},	//   nüp_, агын_, _hujv, झड़_, 
   {{0x3e7c025a,0x9960005f,0x950400e5,0xd1bc0092}},	//   bîti_, _mūža_, _نہتے_, _ሱቆች_, 
   {{0xe3d01682,0x41000276,0xd0100014,0x00000000}},	//   _oṱhe_, озэв, ۅلھ_, --, 
   {{0x3aedbb0f,0x00000000,0x00000000,0x00000000}},	//   küp_, --, --, --, 
   {{0xc444008f,0xf00400d1,0x2d9000d1,0x00000000}},	//   _דרײַ_, _һүни, ﻐﯩﻨﻰ_, --, 
   {{0x3aed7d8f,0x91180276,0x8e7470b9,0x00000000}},	//   düp_, _ациу_, румч, --, 
   {{0x78a4014f,0x3b0806af,0x9f5800d8,0x3cc40107}},	//   _nujv, _ascq_, tesã_, илро_, 
   {{0x3aec014a,0x60dc01ed,0xeb5406ba,0x637000e4}},	//   füp_, árme, مىزگ, _ẽnin, 
   {{0x68fc05ce,0xdb1d1375,0x9f5800db,0x29dc01e1}},	// [30a00] _sprd, _cesà, cesà_, _náaà_, 
   {{0xba203f72,0xe3d006d6,0xa2d86f64,0xdb1c004e}},	//   одук, _eṱhe_, _मिस्, _desà, 
   {{0xc7c456ff,0x0904a130,0xa4f40490,0x9f580022}},	//   асли, рпен, _आहेच_, pesã_, 
   {{0x78a4047e,0x9f580030,0xb7d431b1,0x7980002f}},	//   _dujv, lesá_, لوما_, ünwa, 
   {{0x28d800e1,0x81bc00cc,0x00000000,0x00000000}},	//   _डिवि, েলত_, --, --, 
   {{0xa3e800c5,0xc5f402e8,0x00000000,0x00000000}},	//   _बाह_, рядъ, --, --, 
   {{0xdb1dbb10,0x2919bb11,0xd9b0215c,0x68fc02d0}},	//   _tesã, _urra_, _رەند, _uprd, 
   {{0xdb1c00c7,0x37e00108,0x00000000,0x00000000}},	//   _hesá, _мосг, --, --, 
   {{0x233834d8,0xf7401ea2,0x060802ff,0xabe400d1}},	//   уппы_, _дето, _инак_, ﺍﺗﻘﺎ, 
   {{0x26c4014f,0x00000000,0x00000000,0x00000000}},	//   _iwmo_, --, --, --, 
   {{0x8505bb12,0xdb1dbb13,0x747c00d1,0x00000000}},	//   _خوان, _mesá, ﺯﯨﭙﯩ, --, 
   {{0xffa030af,0x7d0000d8,0x9f5800cf,0xdb1c01ef}},	//   өлүү, _ânsi, tesà_, _lesá, 
   {{0xfe7c0137,0xdb0c0268,0xd3b8187f,0x53b401ee}},	//   juïc_, ccaè, _сухі_, _уғыр_, 
   {{0xf7c80131,0x7de40220,0x6440676d,0xdb1d1cb6}},	//   _ﻗﯩﻠﺪ, шімд, lkmi, _nesá, 
   {{0xfda401ad,0xe134084c,0x7c94007b,0xd7e00327}},	//   _खलीफ, _ынкы, لشرا, _ཤྰཀྱ, 
   {{0x6441bb14,0xc05802dd,0x3aec0bbc,0xac24011c}},	//   nkmi, _шіл_, tüp_, офук, 
   {{0xdb1cea68,0x79a40a70,0x6440017a,0x2aa8013e}},	// [30a10] _besá, арее, ikmi, атхо_, 
   {{0x3aedbb15,0xdb1c2cd7,0x5fb40073,0x61e801e3}},	//   rüp_, _cesá, ंडवल, ngdl, 
   {{0x78a4016d,0xdb1c013a,0x6440143a,0x929c012d}},	//   _qujv, _desá, kkmi, zwło, 
   {{0x81bc2baf,0x3be400db,0x00000000,0x00000000}},	//   েলি_, _өлүү_, --, --, 
   {{0xe70814fe,0x370428a8,0xa2d880a0,0x00000000}},	//   لتون_, рчев, _मिष्, --, 
   {{0x64404ddf,0xcb34011a,0x00000000,0x00000000}},	//   ekmi, _הנשק_, --, --, 
   {{0x81bc015b,0x6aa000cf,0x7a300118,0x25882374}},	//   েলা_, _èmfa, _výtě, ۇنۇپ_, 
   {{0xa2d81b57,0xfafc145e,0xc5a80137,0x80d80210}},	//   _मिश्, _kpë_, _ۅپكۅ_, पूछे, 
   {{0xa3e82007,0xac8c001f,0xd9440116,0xc32006a6}},	//   _बार_, _በእጅጉ_, _теңи, змык, 
   {{0xa2d808e9,0xf6740075,0x644001a4,0x2d8c00bc}},	//   _मिर्, _ئارخ, akmi, ýdek_, 
   {{0x8fa4010b,0x9f5800d0,0x867800d9,0x00000000}},	//   йане, vesá_, _ערעו, --, 
   {{0x64401437,0x00000000,0x00000000,0x00000000}},	//   ckmi, --, --, --, 
   {{0x9f58056a,0x8db40212,0x8fa401ec,0xa3b80244}},	//   tesá_, йсві, _қапе, _ئامر_, 
   {{0xdf00031c,0x28d807af,0x7bc8148b,0x00000000}},	//   doċċ_, _डिलि, ðgun, --, 
   {{0x50b451e4,0xfafc006a,0xc2100375,0xdb1c00c7}},	//   _услу, _apë_, _זהו_, _resá, 
   {{0xb6000e96,0x0fc4036b,0xe074004b,0xc0b00051}},	//   _hráč, _уйин, _وپوښ, _lưởi_, 
   {{0x3ed00451,0xb60002fb,0x8e740117,0x92a800fe}},	// [30a20] _فقير, _kráč, _гунч, গীৰ_, 
   {{0xac08c5dc,0x8e08005b,0x8d28009d,0x644015c0}},	//   ынға_, _снов_, _боов_, zkmi, 
   {{0xa3e8023e,0x078c0023,0xb60002f0,0x00000000}},	//   _बाल_, _ዝሓጸረ_, _mráč, --, 
   {{0xa2d8000b,0x8724010b,0xd90c01d3,0x6fc80118}},	//   _मिल्, ймеж, کیہ_, लरिं, 
   {{0x78b8597f,0x46f448ad,0xc0b001fb,0x61e878d0}},	//   _čuve, счет, _bưởi_, ygdl, 
   {{0xdb1c037e,0x2bd0146b,0x3ed800df,0x00000000}},	//   _besæ, तःका, אַהא, --, 
   {{0xd90c03e6,0x64a400c7,0x00000000,0x00000000}},	//   _لیل_, әаҩа, --, --, 
   {{0xe8e00016,0xa2b45cf0,0xa3e80490,0xfbdc03cb}},	//   _chụp_, обич, _बाळ_, _llên_, 
   {{0x6440008c,0x81bc0154,0x00000000,0x00000000}},	//   rkmi, েলস_, --, --, 
   {{0x6440007d,0x46141079,0x00000000,0x00000000}},	//   skmi, _دوطر, --, --, 
   {{0xd0a8016b,0xb6000306,0x766400f1,0x6d4800a3}},	//   _bɑɑb, _dráč, _دیوې_, ùdal, 
   {{0x9f98301d,0xfe7c00db,0x637000c7,0x399808a8}},	//   ивну_, duïa_, _ẽnun, טייד, 
   {{0x7058010b,0x75d80171,0xd04003e3,0x00000000}},	//   саяр_, bāzē, nslə, --, 
   {{0x6d1413b4,0xfbdc0142,0x229500e2,0x81d00154}},	//   डिंग_, _clên_, _بلتس, _হউক_, 
   {{0x60b5bb16,0x6d5800c0,0xd04006be,0x00000000}},	//   _بمبئ, _žvar, hslə, --, 
   {{0xdfd0129e,0xd0400213,0x00000000,0x00000000}},	//   _کيک_, kslə, --, --, 
   {{0xe7cc0034,0xdb1c00a2,0x6fb8013d,0xab945074}},	// [30a30] ारनप, _mesç, _угыр_, зиті, 
   {{0xfe7c004e,0xfbdc0142,0x1a641e4b,0x61fc022e}},	//   buïa_, _glên_, زیزی_, еrli, 
   {{0xa3e81bf9,0x79a40124,0xc0b00051,0x46c41bd6}},	//   बला_, арҵе, _rưởi_, रीसह, 
   {{0xc0b001fb,0xb1780a1e,0x33e402dd,0xdf000327}},	//   _sưởi_, נטאר, _ﺍﻋﺎﻣ, poċċ_, 
   {{0xdf000327,0x21c80150,0x00000000,0x00000000}},	//   qoċċ_, _ﻓﺘﺎﺭ, --, --, 
   {{0xfbd00014,0xaa6400f3,0xb7b8030d,0x00000000}},	//   _بتھ_, _етск, ăнчĕ_, --, 
   {{0x2e3c0375,0x2bd08109,0xdc3c00d7,0x00000000}},	//   רגונ, तृका, háčs, --, 
   {{0xdb1c0413,0xd04003e3,0x00000000,0x00000000}},	//   _vesæ, bslə, --, --, 
   {{0xb6000030,0x387cd556,0xdb1c0798,0xc0b00208}},	//   _práč, _ikur_, _desç, _tưởi_, 
   {{0x5f1c0882,0x70e40107,0x00000000,0x00000000}},	//   मिन्_, бгоҳ_, --, --, 
   {{0x69d803b7,0xdb1c00e4,0x387c0171,0xe8e00051}},	//   óvei, _hesä, _kkur_, _thụp_, 
   {{0xdb1c0664,0x76406ab9,0x60dc1a46,0x9f58023a}},	//   _kesä, lkny, árma, kesä_, 
   {{0xb8e80ad3,0x7640020b,0x047400f7,0x387c00a2}},	//   _ིས_, okny, _بئلگ, _mkur_, 
   {{0x76400263,0xfe7c00db,0x00000000,0x00000000}},	//   nkny, tuïa_, --, --, 
   {{0x2d8c1455,0x387dbb17,0x7640511d,0x00000000}},	//   åde_, _okur_, ikny, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd04003be,0x49c9bb18,0x9f0401d3,0x00000000}},	// [30a40] xslə, илан_, _فوٹو, --, 
   {{0x387dbb19,0x00000000,0x00000000,0x00000000}},	//   _akur_, --, --, --, 
   {{0x291dbb1a,0xba145cb5,0x4904007b,0x8d7402f2}},	//   íva_, تيلا_, تواق, _گاکا, 
   {{0xdb1c0a7d,0xfe7c00db,0x870401b9,0x25b4043e}},	//   _besä, nuïn_, قبتل, ुर्ण, 
   {{0x8d74135f,0xb804027d,0x3e78013a,0x00000000}},	//   _داکا, زيوم_, bátě_, --, 
   {{0xd04000ac,0xc4d80063,0x387c08ce,0x00000000}},	//   rslə, ађи_, _ekur_, --, 
   {{0xdb1c0036,0xd04000ac,0xfaa1bb1b,0x4b540092}},	//   _eesä, sslə, _царо, _ለመጠየ, 
   {{0x7640020b,0xf4800220,0x00000000,0x00000000}},	//   akny, муын, --, --, 
   {{0xdb1c04c4,0x222812e9,0x0bc402dd,0x00000000}},	//   _gesä, مزدی_, _ﺩﻩﻟﻮ, --, 
   {{0x7640410f,0xc6440228,0xdc3c0419,0x00000000}},	//   ckny, _بئرى, váčs, --, 
   {{0x9f480241,0xf21c012d,0x00000000,0x00000000}},	//   _àkún_, बाज़_, --, --, 
   {{0x74104e85,0xcf9000d1,0xa4f800bc,0x96c00210}},	//   _يولا, ﺘﯘﺭﯗ, ूबीच_, रीकॉ, 
   {{0x9f58143a,0x42700c60,0xd9d40154,0x00000000}},	//   keså_, _оҳис, স্টম, --, 
   {{0x4425bb1c,0xfd10072d,0x00000000,0x00000000}},	//   _hno_, وجز_, --, --, 
   {{0x93240372,0xc0c80108,0xc1a40150,0x00000000}},	//   _ورۇن, _туле_, _лыққ, --, 
   {{0x4425077b,0xf0b40244,0x00000000,0x00000000}},	//   _jno_, _باوش_, --, --, 
   {{0xa3e88d42,0x4424ba15,0x76400fac,0x00000000}},	// [30a50] _बाई_, _mno_, ykny, --, 
   {{0xdd95bb1d,0x387dbb1e,0x8d640020,0x9f58037e}},	//   _напы, _skur_, ደሚችል_, geså_, 
   {{0x0af001c0,0x999000bc,0x3e780118,0x7f640150}},	//   _үүсэ, _vozů_, rátě_, _ﻓﻀل_, 
   {{0x4425bb1f,0xf7701a4b,0x670001f2,0x76400007}},	//   _nno_, واش_, _ịkag, wkny, 
   {{0xab8416a4,0x4ae04709,0xdb1001e1,0x00000000}},	//   _журк, _पियव, _àgàb, --, 
   {{0x4425bb20,0x58d402f6,0xcb980375,0xdb0c01e7}},	//   _ano_, _ногт, _לסרט, ncaí, 
   {{0x6a14ca5f,0x7640020b,0x3eb80051,0xaa5c01ec}},	//   _юмру, rkny, _ltqt_, _терi, 
   {{0x387c1dd4,0x4425bb21,0x7640020b,0xdaf80327}},	//   _ukur_, _cno_, skny, _ཕྱོཌ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4425bb22,0xd174113e,0xe6800356,0x314007a5}},	//   _eno_, зымы, ălţă, ддоҳ, 
   {{0x44240334,0xf8c805f9,0xfe7c004e,0x00000000}},	//   _fno_, ाठिय, tuïn_, --, 
   {{0x44240998,0x00000000,0x00000000,0x00000000}},	//   _gno_, --, --, --, 
   {{0x5ec43e64,0xa3e801ad,0x00000000,0x00000000}},	//   мияғ, बलर_, --, --, 
   {{0x4424045a,0x87780a7c,0x60e80162,0x00000000}},	//   _zno_, מארי, ðsmø, --, 
   {{0x4425bb23,0x00000000,0x00000000,0x00000000}},	//   _yno_, --, --, --, 
   {{0x8d64001f,0xfdb00075,0xdb0c01e7,0x2360013a}},	//   ደሚቻል_, _җәря, acaí, _žiji_, 
   {{0x78b80bb8,0xc4c80003,0xe0540014,0xaca401f2}},	// [30a60] _čuva, _ྋསྐྱ, _آیُت_, _nhụt, 
   {{0x6f04014b,0x49b8007b,0x00000000,0x00000000}},	//   _ipic, صائد_, --, --, 
   {{0xaca402e3,0xbe380375,0xda0c033f,0xdb1c01e3}},	//   _ahụt, _העית, _हसरत_, _reså, 
   {{0x464802dd,0xcb680139,0x6eb00210,0xc03c04b2}},	//   өзен_, _гаме_, ंदपु, _ይከተለ, 
   {{0x4425bb24,0xf7400ce4,0x00000000,0x00000000}},	//   _rno_, нецо, --, --, 
   {{0x4425bb25,0x6f04014b,0x4430015d,0x89d8179e}},	//   _sno_, _mpic, _ŵy_, _دوسر_, 
   {{0x69dc1a82,0x290dbb26,0x44240334,0x75c80220}},	//   _idre, _èda_, _pno_, стің_, 
   {{0xb6000029,0x6f04960c,0x69dd9e2b,0x9f4800a2}},	//   ēšan, _opic, _hdre, _abaý_, 
   {{0x44240393,0x96b9ab47,0xff5c0129,0x00000000}},	//   _vno_, _духу_, naît_, --, 
   {{0x60dc0077,0xb6b8011a,0xfce00092,0x00000000}},	//   ármo, _לצמי, ምለጥ_, --, 
   {{0xdb1c002d,0x4425bb27,0xa2d847b8,0x75d000c6}},	//   _besû, _tno_, _मिक्, _سينا, 
   {{0x4425bb28,0x6f0400ae,0x00000000,0x00000000}},	//   _uno_, _bpic, --, --, 
   {{0x69dc1326,0x00000000,0x00000000,0x00000000}},	//   _odre, --, --, --, 
   {{0x69ddbb29,0xdd9438ce,0x00000000,0x00000000}},	//   _ndre, дагы, --, --, 
   {{0x6f05bb2a,0xdb0c00c6,0x9f5800d0,0xc0580064}},	//   _epic, rcaí, nesú_, _гіп_, 
   {{0x69ddbb2b,0x6f040295,0xdb0dbb2c,0x62880d63}},	//   _adre, _fpic, scaí, lldo, 
   {{0xa3e4012c,0x6289bb2d,0x00000000,0x00000000}},	// [30a70] _भएन_, oldo, --, --, 
   {{0xfc3c067c,0xd838010e,0x00000000,0x00000000}},	//   _diía_, _soō_, --, --, 
   {{0x3945bb2e,0x672001e4,0x5eec00e1,0x69dc18b8}},	//   áns_, _armj, _जमुई_, _ddre, 
   {{0xa8840075,0xa3e82c33,0x20180240,0x6289bb2f}},	//   ىللى, _बाग_, ndsi_, hldo, 
   {{0x69dc0295,0x648c0618,0x7bcc0393,0x6f040175}},	//   _fdre, tûin, _iecu, _xpic, 
   {{0x195828b6,0x7bcc0393,0xcb1002e4,0x6d480158}},	//   _дагы_, _hecu, _שלם_, ødag, 
   {{0x7bcc47d8,0xdb1c01f1,0xaa9401b9,0xef1800e2}},	//   _kecu, _nesú, _чирч, āļi_, 
   {{0x62882e22,0x7bcc003a,0xd5b001fb,0xfe7c00db}},	//   eldo, _jecu, _bác_, duïm_, 
   {{0x7bcc1730,0xd5b0001e,0x69dc01bf,0x0454007b}},	//   _mecu, _các_, _ydre, بلية_, 
   {{0x7bcc26cd,0x69dc0254,0x00000000,0x00000000}},	//   _lecu, _xdre, --, --, 
   {{0x6f05bb30,0x7bcc0393,0xd00802e8,0x00000000}},	//   _spic, _oecu, оене_, --, 
   {{0x7bcdbb31,0xdb1c00db,0x62880ffb,0xb7fc012c}},	//   _necu, _desú, aldo, ोजिम_, 
   {{0x35800023,0x4f940022,0x00000000,0x00000000}},	//   _ርሕቀት_, ьроу, --, --, 
   {{0xdb6c001f,0x7bcc003a,0x62344d87,0xfe7c00db}},	//   _በመያዝ_, _aecu, _печу, buïm_, 
   {{0xf408038f,0x7bcdbb32,0xdb0c0209,0x3ea0265b}},	//   _ཁྲོད_, _becu, rbaý, тирг, 
   {{0x69dcc1a8,0x22900109,0x7bcdbb33,0x99dc0154}},	//   _sdre, màka_, _cecu, ডভোক, 
   {{0x7bcdbb34,0x22900109,0xd5b0004d,0x00000000}},	// [30a80] _decu, làka_, _xác_, --, 
   {{0xff5c4aee,0x9f582b1d,0x00000000,0x00000000}},	//   raît_, jesù_, --, --, 
   {{0x26181788,0x7bcdbb35,0xdb1c1709,0x229005da}},	//   _योगी_, _fecu, _xesú, nàka_, 
   {{0x7bcc020c,0xeb340137,0x00000000,0x00000000}},	//   _gecu, _كۉزد, --, --, 
   {{0x2ac40241,0x57a400fb,0x00000000,0x00000000}},	//   _débò_, нышҡ, --, --, 
   {{0x69ddbb36,0x6685bb37,0x7bcc009a,0x22900109}},	//   _udre, ریال, _zecu, kàka_, 
   {{0x7bcc21b5,0x996000ef,0x00000000,0x00000000}},	//   _yecu, _tīša_, --, --, 
   {{0xdb1c2b76,0xe3140261,0x7bcc0356,0x00000000}},	//   _resú, емињ, _xecu, --, 
   {{0x41e41c26,0x07a401c0,0x99080050,0x4dec00bc}},	//   міна, _цаан, _وتہِ_, जलाई_, 
   {{0xf5e4084c,0xfe7c004e,0x00000000,0x00000000}},	//   _омул_, tuïm_, --, --, 
   {{0x62880493,0x4544df9e,0x00000000,0x00000000}},	//   rldo, _تناق, --, --, 
   {{0xa3e8038e,0xc3280597,0xd5b0004d,0xf4841550}},	//   _बाट_, _وكان_, _tác_, _قانی, 
   {{0xa2d80c2e,0x670001ad,0x20180254,0x4aac0037}},	//   _मिट्, ोबिक_, rdsi_, _झूलव, 
   {{0x7bccdad9,0x8e700150,0x00000000,0x00000000}},	//   _secu, лқыш, --, --, 
   {{0x7bcdbb38,0x38b41f21,0xd9cc015b,0xad2400d1}},	//   _pecu, _oħra_, _লালম, پىقى, 
   {{0x28d81414,0x5f95bb39,0x00000000,0x00000000}},	//   _डिजि, _пийт, --, --, 
   {{0x7bcc00da,0x7b6414b7,0x9b580107,0x2f140064}},	// [30a90] _vecu, фтве, чиат_, _адыё, 
   {{0x9f5801bf,0x00000000,0x00000000,0x00000000}},	//   desø_, --, --, --, 
   {{0x1bd44f13,0x7bcdbb3a,0xba380137,0x9cf400d4}},	//   _поня, _tecu, _suïs, _язні, 
   {{0x92a80011,0xbbe8029e,0x28e0012d,0x69d9bb3b}},	//   গীয়_, _بردم_, _पटरि, óver, 
   {{0xa3e82ba2,0x229005da,0xdb1c143a,0x00000000}},	//   _बाज_, zàka_, _nesø, --, 
   {{0xf1c413d5,0xc0dc0023,0x00000000,0x00000000}},	//   ďáky_, ሓወሶ_, --, --, 
   {{0xdb1c04cc,0x9f48002e,0xf4080327,0xdb0c00c7}},	//   _resù, _mbañ_, _ཁྲུད_, mbañ, 
   {{0xdb1c708a,0xf8c80073,0xd39401e0,0x14580ce8}},	//   _besø, ाठीप, нәлә_, яшлы_, 
   {{0xe35401c6,0x00000000,0x00000000,0x00000000}},	//   втээ, --, --, --, 
   {{0x22900109,0x4ae0000d,0xcb1000d9,0x90c5bb3c}},	//   tàka_, _पिसव, נלי_, нбое, 
   {{0x47d00729,0xa5f80815,0xeb0c00cd,0x00000000}},	//   _হাতী, _цеху_, _हन्त_, --, 
   {{0xfbdc24ba,0x229005da,0x00000000,0x00000000}},	//   _ndê_, ràka_, --, --, 
   {{0x22900109,0x91e400d1,0xd1c801ee,0xdb0c0241}},	//   sàka_, _золе, _елле_, _èkèj, 
   {{0xe47801c0,0x00000000,0x00000000,0x00000000}},	//   _нөөц_, --, --, --, 
   {{0xfeb001e0,0x27e001d3,0x3b500092,0x00000000}},	//   _ҡөрь, óink_, _ለመገኘ, --, 
   {{0xddd402f0,0x00000000,0x00000000,0x00000000}},	//   rozš, --, --, --, 
   {{0x3b040c04,0xa3e84c19,0xfc000137,0x6d48005c}},	// [30aa0] нето_, _बाघ_, ыпто, ødab, 
   {{0x3b8000f7,0x2fe80210,0x00000000,0x00000000}},	//   улуг, ługą_, --, --, 
   {{0xef1800e2,0x480801fc,0x9e6413bd,0x69c006be}},	//   āļu_, зеен_, _جاين, _ğmed, 
   {{0x38c8158b,0x00000000,0x00000000,0x00000000}},	//   سامی_, --, --, --, 
   {{0x47d0015b,0x8d7401d9,0x35800092,0xed8c0092}},	//   _হাদী, _زاگا, ርጉበት_, _መስበክ_, 
   {{0x9fc00118,0x9f5836e0,0xdb0c1427,0xb6a001d5}},	//   iďák_, resø_, mbað, гичл, 
   {{0x485800c0,0x00000000,0x00000000,0x00000000}},	//   _ераў_, --, --, --, 
   {{0x58940228,0x973001d3,0x00000000,0x00000000}},	//   _ашуу, _چکوا, --, --, 
   {{0xd36c1e87,0x78a00d27,0xc724010b,0x246c0118}},	//   يۇم_, ïnve, _ядай, němi_, 
   {{0x85b88d1a,0x00000000,0x00000000,0x00000000}},	//   _رائس_, --, --, --, 
   {{0xf0d001c0,0x75d0007b,0xdecc0023,0xd53400f1}},	//   лжээ, _إيما, ባዊን_, _لګيا_, 
   {{0x44f8067d,0x7411bb3d,0x00000000,0x00000000}},	//   më_, _موما, --, --, 
   {{0xf4081b4b,0x44f9bb3e,0xa440168d,0x2d8c2e11}},	//   _ཁྲིད_, lë_, _مێژو, üden_, 
   {{0xdb0c01e1,0xa3e801f9,0x246c01ef,0x00000000}},	//   _èkéj, बलक_, děmi_, --, 
   {{0x44f8067d,0x229006d9,0x6ce40212,0x6e940108}},	//   në_, làko_, літе, уиру, 
   {{0x4ae00073,0xbfa800db,0x00000000,0x00000000}},	//   _पिशव, _этке_, --, --, 
   {{0x44f934a4,0x22900109,0x5b14039b,0xde7802e8}},	// [30ab0] hë_, nàko_, ъмат, _обич_, 
   {{0x44f8044e,0x37140014,0x9e840345,0x00000000}},	//   kë_, ہرتھ_, _جابۆ, --, 
   {{0xdd903d93,0x44f8069c,0xd5b0001e,0xdb0c0077}},	//   _خود_, jë_, _bán_, rbañ, 
   {{0x44f9561d,0xdb0dbb3f,0x7e64df61,0xd5b00051}},	//   dë_, sbañ, lijp, _cán_, 
   {{0x44f80151,0x5fd807f7,0xd5b00051,0x00000000}},	//   eë_, _भजनल, _dán_, --, 
   {{0x7e6401a4,0x44f80240,0x5ee809bb,0x00000000}},	//   nijp, fë_, _जिन्_, --, 
   {{0x44f8044e,0x2bb80950,0x58d4010a,0x00000000}},	//   gë_, _अलमा, _шовт, --, 
   {{0x629807d6,0xed6402fb,0x7e647769,0x142401d5}},	//   _ahvo, loží_, hijp, тдим, 
   {{0x7e640113,0xf77000c6,0x00000000,0x00000000}},	//   kijp, _صار_, --, --, 
   {{0x44f9561d,0xfc3c0093,0x32000209,0x62980f91}},	//   bë_, _loí_, ýjy_, _chvo, 
   {{0x44f80023,0xf3e003d4,0x00000000,0x00000000}},	//   cë_, ক্ষৰ_, --, --, 
   {{0x22900109,0x4ae0000d,0xed6402f0,0xfe7c0142}},	//   bàko_, _पिलव, hoží_, frïo_, 
   {{0xe3b0da98,0x60c409a8,0xfc640023,0x237400d0}},	//   _ارم_, _čime, _ተፈጺሙ_, čajú_, 
   {{0x91e4277c,0x9f6001ed,0xfc3c0332,0x248039ab}},	//   _роке, ását_, _aoí_, čime_, 
   {{0x66d800d2,0xfc3dbb40,0xcfd80154,0x00000000}},	//   _kúká, _boí_, থলবন, --, 
   {{0x4f24020a,0x7ddc71d6,0x073402dd,0x998c013d}},	//   _адиб, _açsı, _ﯗﺭﯞ_, _şeş_, 
   {{0x44f802d3,0x00480023,0x66d801e1,0x00000000}},	// [30ac0] zë_, _ዝረኣና, _múká, --, 
   {{0x79c000ee,0x44f800e8,0x491400c5,0x00000000}},	//   ийуз, yë_, _ननदो_, --, 
   {{0xfe340302,0x22900109,0xd5b00051,0x00000000}},	//   _סרטי_, zàko_, _pán_, --, 
   {{0x8c443d63,0x076846c9,0x44f802d3,0x5ee800e1}},	//   _реме, وماً_, vë_, _जिम्_, 
   {{0x2ca1bb41,0xd5b001fb,0x46f541e6,0xdb1c0432}},	//   mmid_, _cáo_, тчет, _kesý, 
   {{0x44f8067d,0x2ca1bb42,0x22900109,0x00000000}},	//   të_, lmid_, vàko_, --, 
   {{0xbf980af9,0xd5b00051,0x2ca1bb43,0x59740108}},	//   neêr, _tán_, omid_, _быту, 
   {{0x44f8067d,0x2919bb44,0x6298020c,0x229005da}},	//   rë_, _isra_, _shvo, tàko_, 
   {{0x44f8067d,0xdb0c06ed,0x2ca000c6,0x00000000}},	//   së_, rcaç, imid_, --, 
   {{0x2ca1bb45,0x44f802d3,0x60c54e30,0x22900109}},	//   hmid_, pë_, _čimb, ràko_, 
   {{0xb6a1bb46,0x44f80023,0x22900109,0x8174013e}},	//   _тифл, që_, sàko_, танӣ_, 
   {{0x22900109,0x66d801e1,0x7e640113,0xd0f001e1}},	//   pàko_, _gúká, wijp, _siṣẹ, 
   {{0x2ca00009,0x44dc031c,0x00000000,0x00000000}},	//   dmid_, lċ_, --, --, 
   {{0x2ca000af,0x9d1805f5,0x00000000,0x00000000}},	//   emid_, ногт_, --, --, 
   {{0x7e640d27,0xf1900014,0x2ca00175,0x44dc031c}},	//   rijp, _پُٹھ, fmid_, nċ_, 
   {{0x7e640784,0x8c380107,0x30a40006,0x00000000}},	//   sijp, носӣ_, _крыв, --, 
   {{0x29183cf6,0xfc3c0022,0x7e6401a4,0x00000000}},	// [30ad0] _asra_, _voí_, pijp, --, 
   {{0x2ca1bb47,0x24840dd4,0x99d5bb48,0xaa540e92}},	//   amid_, homm_, اقات, авуш, 
   {{0x24847884,0xfc3c0561,0x69c00311,0x79a41d0f}},	//   komm_, _toí_, _şmec, трае, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2919bb49,0x7c2cdb22,0xd5e405f5,0xd7043298}},	//   _esra_, _incr, гжли, узли, 
   {{0xe731bb4a,0xdb1c014a,0xcb100375,0xe9a82ba5}},	//   تصم_, _mesü, _הלך_, ردەن_, 
   {{0xdb1c0036,0x24840356,0x00000000,0x00000000}},	//   _ofsë, fomm_, --, --, 
   {{0x91a80208,0x00000000,0x00000000,0x00000000}},	//   _đà_, --, --, --, 
   {{0x5694a6e6,0xa3e40316,0xd2a8005b,0x5f1400cc}},	//   _баат, _भएर_, нкие_, ামুখ_, 
   {{0xfdbc03ba,0x00000000,0x00000000,0x00000000}},	//   ्रोफ, --, --, --, 
   {{0x10a418b6,0x50441d37,0x7c2c035a,0x2ca000ad}},	//   лион, генб, _oncr, ymid_, 
   {{0x2484051f,0xdd400083,0x6244007f,0xb4dc0073}},	//   comm_, _eŋŋe, _sòot, तळी_, 
   {{0xdb1c04d4,0x00000000,0x00000000,0x00000000}},	//   _mesó, --, --, --, 
   {{0x7c2dbb4b,0x00000000,0x00000000,0x00000000}},	//   _ancr, --, --, --, 
   {{0x2d8c019b,0xfce00032,0xf0040075,0x0ae8004b}},	//   æde_, йоро, _күни, کرزي_, 
   {{0xfe7c0137,0x2ca000c5,0xc1700375,0xdb1c010b}},	//   duïu_, umid_, _לחו_, _wesý, 
   {{0x2ca1bb4c,0x2fc0030a,0xdb1c0e78,0xcfd800fe}},	// [30ae0] rmid_, _ifig_, _gesü, _থাপন, 
   {{0x2ca1bb4d,0x2484a06c,0xc8b401c6,0xe9a80014}},	//   smid_, zomm_, гсды, ٖگرن_, 
   {{0x4995190c,0xdb1c014a,0x68fc0175,0xd5b00208}},	//   ушат, _zesü, _qqrd, _cám_, 
   {{0xd5b00208,0x8e3815b4,0x00000000,0x00000000}},	//   _dám_, _آسکر_, --, --, 
   {{0xdb1c0789,0x6244030a,0x5b3400a8,0x6d5c0112}},	//   _desó, _mòor, _кэру, lzra, 
   {{0x291805da,0xdd24005f,0xfe7c004e,0x2bdc3cbe}},	//   _tsra_, līša, buïu_, यणका, 
   {{0x6d5c0007,0xfbdc045f,0x04a801b9,0x659401f0}},	//   nzra, _glês_, нъий_, шаку, 
   {{0x44dc003d,0xfe7c004e,0x09e40c60,0x74f4011c}},	//   rċ_, luït_, _шоҳн, уеър_, 
   {{0x6718000d,0x91a8004d,0x86e801d3,0x00000000}},	//   _धनिक_, _đá_, _سٹاف_, --, 
   {{0xdb1c0065,0x26c4014f,0xfe7c00db,0x09d0009e}},	//   _resü, _itmo_, nuït_, ালকা, 
   {{0xdfd04b15,0x74103cb9,0x2d8c068f,0x624401ab}},	//   ييد_, _گونا, żdej_, _bòor, 
   {{0xd0e4000b,0x00000000,0x00000000,0x00000000}},	//   _किरण_, --, --, --, 
   {{0x7411490d,0xdd2400da,0x6d5dbb4e,0x9f580789}},	//   _دونا, dīša, ezra, vesó_, 
   {{0xdb1c014a,0xa3e400bc,0x3390007b,0xb3940816}},	//   _vesü, _भएँ_, _الهز, _скіф_, 
   {{0xfe7c00f7,0x61e40198,0x2ce9bb4f,0x6e64005b}},	//   duït_, _ɓill, льто_, стяж, 
   {{0xac182854,0x7c940b38,0x69d806ea,0x00000000}},	//   лосу_, اشسا, ðven, --, 
   {{0xdb1c0077,0x200801c6,0xfbdc3c75,0x9f580407}},	// [30af0] _resó, _ibai_, _blêr_, resó_, 
   {{0xdb1c00cf,0xfbdc0142,0x00000000,0x00000000}},	//   _besò, _clêr_, --, --, 
   {{0x26c5bb50,0x9850068f,0x2fc00165,0xdd2400ef}},	//   _atmo_, nąć_, _yfig_, bīša, 
   {{0xdb1c067c,0x61e406af,0x660806be,0xdd2400e2}},	//   _desò, _œill, _abdk, cīša, 
   {{0x2009bb51,0xfe7c0137,0xf6e40e91,0x2d9c0030}},	//   _mbai_, buït_, уцен, _úver_, 
   {{0x6d4912c5,0xfbdc0142,0x1db400dc,0xd5b00051}},	//   ädag, _glêr_, ःखित, _tám_, 
   {{0x69cc00ee,0x98500034,0x084001d9,0xb4dc0073}},	//   şleý, jąć_, _ڈۆلُ, तळे_, 
   {{0x130810f5,0x084001d9,0x27e40051,0xa8a40153}},	//   вний_, _وۆلُ, _gdmn_, _грук, 
   {{0x7778011f,0x2bb8000d,0x6d5c05d5,0xe2b4009d}},	//   _uxux, _अलसा, zzra, йсээ, 
   {{0x24800bb8,0xdd24005f,0x91e416a4,0x00000000}},	//   čima_, zīša, јоне, --, 
   {{0x27e009cc,0x7af8143a,0x74f00150,0xe5081e5a}},	//   ðing_, _åutf, _اۋعا, _ميلو_, 
   {{0xe3b004d3,0x8fa40395,0x00000000,0x00000000}},	//   _فره_, иане, --, --, 
   {{0xf3f40022,0x0838010f,0x00000000,0x00000000}},	//   _амҵә_, דערל, --, --, 
   {{0x6d5c002f,0x2aac01e1,0x00000000,0x00000000}},	//   tzra, _móbì_, --, --, 
   {{0xdd2400da,0xfafc036e,0x8c44005b,0x00000000}},	//   tīša, _aqë_, аеве, --, 
   {{0xdb1c2561,0x8c441945,0x4fc000db,0x6d5c0112}},	//   _resò, шебе, _گەڭە, rzra, 
   {{0xfe7c00f7,0xdd2400da,0xcb081e95,0xd00401b9}},	// [30b00] tuït_, rīša, ضيان_, _боққ, 
   {{0x2bb8069f,0xdd24005f,0x8d741374,0x00000000}},	//   _अलवा, sīša, _ناجا, --, 
   {{0x32e00131,0xfe7c7172,0xdd2400e2,0xcc8805af}},	//   _ﺋﻪﮔﻪ, ruït_, pīša, _لنده_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2458002e,0x00000000,0x00000000,0x00000000}},	//   _jéme_, --, --, --, 
   {{0x245806af,0x3ab01b15,0xd90c01ed,0x2ab801af}},	//   _méme_, _фәтт, بیہ_, _аңҡы_, 
   {{0x250948ad,0x75c8005e,0xfa6416c3,0xd5b8cea6}},	//   ارتی_, ттің_, _тарк_, усі_, 
   {{0x27e00162,0x00000000,0x00000000,0x00000000}},	//   ðind_, --, --, --, 
   {{0x69c8000d,0x00000000,0x00000000,0x00000000}},	//   _õdes, --, --, --, 
   {{0x200803a2,0x26c0054e,0x00000000,0x00000000}},	//   _sbai_, ţios_, --, --, 
   {{0x91a8001e,0x6d4803cd,0x00000000,0x00000000}},	//   _đã_, ødal, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfe7c00cf,0x91d400fe,0xfbd00050,0x058401ee}},	//   duïr_, _দাৰ্, ۪تس_, _суҡм, 
   {{0x2d840365,0x69d8008c,0x245800e8,0x00000000}},	//   ğmen_, ðvel, _déme_, --, 
   {{0x6289bb52,0xb300031c,0xdd940006,0x00000000}},	//   modo, _མདོང_, савы, --, 
   {{0x6289bb53,0x200805b1,0x1c380137,0x6c54004e}},	//   lodo, _ubai_, ызбы_, оксу, 
   {{0xdb9817d6,0x00000000,0x00000000,0x00000000}},	// [30b10] увач_, --, --, --, 
   {{0x628800a9,0xab85bb54,0xbd687af6,0x00000000}},	//   nodo, цуск, _арме_, --, 
   {{0x15b8005e,0x3945bb55,0xfe7c067c,0x2aa82c12}},	//   қылы_, âns_, buïr_, ртто_, 
   {{0x6289bb56,0xdd9002f2,0xd7580902,0x00000000}},	//   hodo, _ووک_, лиец_, --, 
   {{0x5695bb57,0xdd400083,0xa62c01e1,0x00000000}},	//   бадт, kŋŋa, _ṣágo_, --, 
   {{0xb605068d,0x62885513,0xd5b00051,0xf7c80150}},	//   рядк, jodo, _kái_, _ﺗﯩﻨﺪ, 
   {{0x628803b4,0xd469bb58,0x154401ec,0x19580064}},	//   dodo, лике_, сейм, _савы_, 
   {{0xb73001ed,0xd5b00208,0xe4c800ae,0x00000000}},	//   _وہاب, _mái_, جبون_, --, 
   {{0x628800a9,0xd18405f5,0xe81c0073,0xd5b00208}},	//   fodo, өлий, _नसता_, _lái_, 
   {{0xf6500e26,0x3568213a,0xf5680daf,0xbeb8036e}},	//   _بئر_, _ирен_, _ишек_, rvël, 
   {{0x24580de2,0x00000000,0x00000000,0x00000000}},	//   _démb_, --, --, --, 
   {{0xd1740220,0x35cc0154,0x00000000,0x00000000}},	//   _қылы, _রায়হ, --, --, 
   {{0x6289bb59,0x3168012d,0x00000000,0x00000000}},	//   bodo, ńcz_, --, --, 
   {{0x7410a79f,0xfc340023,0x00000000,0x00000000}},	//   _دوچا, _ኣረገው, --, --, 
   {{0xc6900bd9,0x2bb41428,0xccb800f2,0xeff80023}},	//   פאל_, ंखला, اهرش_, _ገጸይ_, 
   {{0x78a02595,0xd5b001fb,0x2459bb5a,0x9c5800f7}},	//   ïnvl, _cái_, _téme_, ашуу_, 
   {{0x09e4084c,0x4e78007b,0x00000000,0x00000000}},	// [30b20] йоан, _محدد_, --, --, 
   {{0xda644202,0x7ae80f47,0x00000000,0x00000000}},	//   يالي, ágta, --, --, 
   {{0x08f82ed3,0x49980962,0x395c0198,0x0905bb5b}},	//   طراب_, утая_, _ƙusa_, спен, 
   {{0xb8e800dd,0x87d80137,0xd5b0004d,0xc7a4299e}},	//   ابلے_, اباس_, _gái_, биек, 
   {{0xf3fc00bd,0x4ae000e1,0x25d800ee,0x62886394}},	//   ্যার_, _पिटव, амлы_, yodo, 
   {{0x69348150,0x62880561,0x07a421f3,0x17800107}},	//   _وکار, xodo, _ғазн, фҳум, 
   {{0x62888b8c,0xb3000135,0x0464036b,0xddc400d7}},	//   vodo, _མདུང_, йтим, _dohň, 
   {{0x628875ae,0x24801a48,0x24580de2,0x7980045f}},	//   wodo, čimo_, _sémb_, ûnwe, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6289bb5c,0x6d580135,0xe29800c7,0x00000000}},	//   rodo, _żvan, лаҩ_, --, 
   {{0xdfd00979,0x83180035,0xb978011a,0x7d180210}},	//   بيح_, _مقصر_, רנטי, łusk, 
   {{0x6289bb5d,0x2bdc0a8a,0x00000000,0x00000000}},	//   podo, बरना, --, --, 
   {{0xdce401f1,0xdd5801c0,0x62880009,0xf7c9388e}},	//   _vzhľ, аагч_, qodo, _ﺗﯩﻠﺪ, 
   {{0x26004103,0x2d580c9e,0x7c9416ac,0x92647f51}},	//   _रानी_, бирь_, مشرا, _بدنم, 
   {{0xfe740372,0xfb8400fd,0x00000000,0x00000000}},	//   рүү_, бызн, --, --, 
   {{0xbeb8002e,0x00000000,0x00000000,0x00000000}},	// [30b30] ivëk, --, --, --, 
   {{0xf77000d1,0x00000000,0x00000000,0x00000000}},	//   ۋاش_, --, --, --, 
   {{0x6d5800e4,0xf3e003d4,0xd5b00051,0x00000000}},	//   _ývap, ক্টৰ_, _tái_, --, 
   {{0x64400327,0x2b14000d,0x00000000,0x00000000}},	//   jjmi, _नैकु_, --, --, 
   {{0x7bddbb5e,0xe709bb5f,0x572403cc,0x2d8c0254}},	//   maqu, متون_, تىشك, üdev_, 
   {{0xdb1c0628,0x7bddbb60,0x95b4052f,0xd629b51f}},	//   _besö, laqu, әрҙә, роке_, 
   {{0x3eb1bb61,0xd1b803e6,0x00000000,0x00000000}},	//   _mixt_, یادا_, --, --, 
   {{0x7bddbb62,0x94780640,0xdb1c002f,0x00000000}},	//   naqu, јску_, _desö, --, 
   {{0x7bdc003a,0x923806a7,0x4ae0012d,0x3a200064}},	//   iaqu, ачну_, _पिछव, _kajp_, 
   {{0x7bddbb63,0x00000000,0x00000000,0x00000000}},	//   haqu, --, --, --, 
   {{0xf7540201,0xdb1c0036,0x7bdc03f0,0x6aa004e6}},	//   _ገልፀዋ, _gesö, kaqu, _ëmfe, 
   {{0xdb1c08a5,0x148400ec,0x00000000,0x00000000}},	//   _afsí, _گھڙي_, --, --, 
   {{0x7bdc29b1,0x91e47546,0x66280162,0x929c0210}},	//   daqu, _доле, _áskú, atła, 
   {{0xd1742c12,0x2d8403e0,0x00000000,0x00000000}},	//   _мыйы, şmem_, --, --, 
   {{0x7bddbb64,0x25a003f9,0x10640014,0x00000000}},	//   faqu, ƙile_, _وُتُ, --, 
   {{0xdb1c0120,0x7bdc003a,0x4fe81def,0x49440092}},	//   _lesõ, gaqu, _тмин_, _የሸማቾ, 
   {{0x20040cc1,0x245800e8,0x6fa803d4,0x00000000}},	// [30b40] əli_, _jéma_, _ক্ৰে, --, 
   {{0x245802ea,0x6f040113,0x499410f3,0x63a400a3}},	//   _méma_, _iqic, ошет, _ùine, 
   {{0x8c45bb65,0x2f04008c,0x24580066,0xfe340375}},	//   _дене, lög_, _léma_, _ואיך_, 
   {{0x7bddbb66,0x9f5801e6,0x394401e6,0x386c062c}},	//   caqu, resö_, änsa_, gigr_, 
   {{0x60c40427,0xd5b00208,0xc6a4f086,0x9cb000cf}},	//   _čimm, _máu_, орки, _سۅكت, 
   {{0x2bb8063f,0x64400007,0x88c80050,0x25080214}},	//   _ọch_, wjmi, _نظرِ_, مربی_, 
   {{0x69ddbb67,0xd90d2230,0x245800e4,0x26001025}},	//   _iere, _میل_, _aéma_, _राठी_, 
   {{0x4308c97b,0xfd500ca8,0x69ddbb68,0xdb1c000d}},	//   ахом_, _aifọ, _here, _eesõ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69ddbb69,0x3eb80309,0x2f0401d3,0xb604031c}},	//   _jere, _ruqt_, dög_, gaġġ, 
   {{0x69ddbb6a,0x7bddbb6b,0x3eb0000f,0x1fb800fd}},	//   _mere, yaqu, _rixt_, йлны_, 
   {{0x69ddbb6c,0x6619bb6d,0x7bddbb6e,0x2f045d8b}},	//   _lere, levk, xaqu, fög_, 
   {{0xf48427a1,0x69ddbb6f,0xdb1c03d1,0xfd500241}},	//   _بالی, _oere, _jesô, _fifọ, 
   {{0x9f59bb70,0x7bdc094a,0x6a60002f,0xbbd000dc}},	//   desô_, waqu, _höff, तर्क, 
   {{0x7bddbb71,0x2bc802e3,0xed58009d,0x00000000}},	//   taqu, _ọjị_, ооё_, --, 
   {{0x69ddbb72,0x6ca41f99,0x67202804,0x387c0115}},	//   _aere, друж, _osmj, _ĉuro_, 
   {{0x3a20025c,0xd5b00208,0x30840f54,0x6a6002d2}},	// [30b50] _pajp_, _hát_, _تليف, _möff, 
   {{0x7bddbb73,0x69ddbb74,0x66182230,0x6a600e78}},	//   saqu, _cere, jevk, _löff, 
   {{0x7bddbb75,0xdd95a569,0xd7f019c5,0x66180010}},	//   paqu, _ханы, فكا_, devk, 
   {{0xb17800c8,0x69ddbb76,0x96b8026a,0x7bdc03f0}},	//   סטאר, _eere, буку_, qaqu, 
   {{0x69ddbb77,0x27e005a4,0x2018011c,0x3a2001e4}},	//   _fere, ðina_, iesi_, _tajp_, 
   {{0x69ddbb78,0x245806fd,0x26000073,0x5ebc00cc}},	//   _gere, _réma_, _राणी_, _অবাই, 
   {{0x95b400c7,0x2f0400e5,0x00000000,0x00000000}},	//   орқә, zög_, --, --, 
   {{0x2019bb79,0x69ddbb7a,0xd1cc0092,0x84340116}},	//   jesi_, _zere, ቢያት_, ككىر_, 
   {{0x2bdc069f,0xb604031c,0x66180139,0x00000000}},	//   बरता, taġġ, bevk, --, 
   {{0x69ddbb7b,0x245800e4,0x2018005b,0xd5b00051}},	//   _xere, _véma_, eesi_, _sáu_, 
   {{0x2019bb7c,0x387c0113,0x666401d9,0x69d80008}},	//   fesi_, _kjur_, _تُلٕ, ðvei, 
   {{0x245819fd,0x2d844252,0x85980375,0x00000000}},	//   _téma_, şmek_, _השעו, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2f0401ed,0xe29800d3,0x333c0327,0x00000000}},	//   rög_, _даі_, mxux_, --, 
   {{0x2019bb7d,0x69ddbb7e,0x1fac00cc,0xe81c0073}},	//   besi_, _rere, কুলস, _नसला_, 
   {{0x2019bb7f,0x387c04fb,0x3934001f,0xa3e400bc}},	//   cesi_, _njur_, _የሚያካ, _भएछ_, 
   {{0x69d8012d,0x00000000,0x00000000,0x00000000}},	// [30b60] यरली, --, --, --, 
   {{0xba21a2b9,0x387dbb80,0x02b4010f,0x2bb809b2}},	//   ндук, _ajur_, פלעך_, _अलका, 
   {{0x387c01bf,0x6a6001e3,0xc6a5bb81,0x7e740139}},	//   _bjur_, _löfg, үрли, _хәят_, 
   {{0x69ddbb82,0x6c3401d3,0x00000000,0x00000000}},	//   _were, _تہرا, --, --, 
   {{0x387c049f,0x6619bb83,0x44380051,0x00000000}},	//   _djur_, tevk, _đp_, --, 
   {{0x6595bb84,0x2019bb85,0x7af80217,0x69dc16b8}},	//   малу, zesi_, _åuta, _uere, 
   {{0x2019bb86,0xfaa1bb87,0x387c0327,0xf98021c3}},	//   yesi_, _чаро, _fjur_, _згро, 
   {{0x320405f5,0x0664e0d7,0x201800e8,0x66181e34}},	//   үхэн_, _کارپ, xesi_, sevk, 
   {{0x66180038,0x67201f7f,0xd5b00208,0x6a6008a5}},	//   pevk, _usmj, _sát_, _vöff, 
   {{0x2019bb88,0x66e40417,0xd6380064,0x00000000}},	//   wesi_, _ноға, _мяхі_, --, 
   {{0x2019bb89,0x929c012d,0x055401d5,0x6a61bb8a}},	//   tesi_, atło, _этая, _töff, 
   {{0xd36c0372,0x2bb80456,0x20d80022,0x399800df}},	//   دۇۇ_, _अलगा, rũi_, מייד, 
   {{0x4425bb8b,0x6d480267,0xd36c0451,0x6a6002d2}},	//   _iao_, ädan, _پڇي_, _göfg, 
   {{0x4425bb8c,0x8ca00034,0xa1583e0c,0x00000000}},	//   _hao_, _कीबो, _малу_, --, 
   {{0x442404b9,0x2019bb8d,0x64b801e4,0x2d58084c}},	//   _kao_, pesi_, _iĉis, пирь_, 
   {{0x442406d9,0x2019b48d,0x245806af,0xaa4c0092}},	//   _jao_, qesi_, _mémo_, _በማረጋ, 
   {{0x4425bb8e,0x76400034,0x2d8c32e9,0x2ef40022}},	// [30b70] _mao_, yjny, üder_, _ззыр, 
   {{0x4425bb8f,0x27e000fc,0x387c332c,0x7f5439b8}},	//   _lao_, ðinn_, _sjur_, _мақс_, 
   {{0x44240093,0x24580165,0x35cc012d,0x58d800d4}},	//   _oao_, _némo_, सुफ़, іддя_, 
   {{0x4425bb90,0xd7580597,0x7c642984,0x6fdc00cc}},	//   _nao_, يلات_, _راجل, _ভাৱে, 
   {{0xdd9002de,0x999000c0,0xba740127,0x333c025c}},	//   _سوڭ_, _pozų_, _فاست, xxux_, 
   {{0x4425bb91,0x59e0012d,0x00000000,0x00000000}},	//   _aao_, _फ़िर, --, --, 
   {{0x4425bb92,0x6aa004e6,0x387cdc90,0x05dc5219}},	//   _bao_, _ëmfa, _tjur_, _नजरब, 
   {{0x442401dc,0x24589d74,0x387c003e,0xd3940daf}},	//   _cao_, _démo_, _ujur_, мәлә_, 
   {{0x56940372,0x59e002a0,0x00000000,0x00000000}},	//   _жаат, _फ़ार, --, --, 
   {{0x630426c9,0xfbdc0548,0x4425bb93,0x25a000bc}},	//   روپل, _leê_, _eao_, řila_, 
   {{0x4425bb94,0xfe7c0bc9,0x25a002a8,0x74a400d8}},	//   _fao_, yrïr_, ƙila_, _ејде, 
   {{0x9db80022,0x00000000,0x00000000,0x00000000}},	//   ҧысу_, --, --, --, 
   {{0x254c02ea,0x44f8025c,0x23080ef8,0x6a600112}},	//   mɛla_, _དཀོར_, _فتوي_, _höfe, 
   {{0x4425bb95,0x6a600166,0x161c0210,0x00000000}},	//   _zao_, _köfe, फ़िर_, --, 
   {{0x4425bb96,0xc6900a1e,0xd7080154,0x9044007b}},	//   _yao_, דאם_, লিয়া_, _ينته, 
   {{0x4424001e,0xe52000dc,0x00000000,0x00000000}},	//   _xao_, _मनसि_, --, --, 
   {{0x7c280109,0x3b044727,0x09e417d0,0x60c401ef}},	// [30b80] ôgra, мето_, дозн, _čimi, 
   {{0xd8381243,0x248009a8,0x63bc00bc,0x63880240}},	//   _anō_, čimi_, ěrni, lënë, 
   {{0x7af803cd,0x98c402dd,0x00000000,0x00000000}},	//   _åutn, есіл, --, --, 
   {{0x26c82e56,0xdb0c0306,0x245801e1,0x260002db}},	//   зған_, škán, _rémo_, _राही_, 
   {{0x442407ae,0xdb1c037e,0x4735003d,0x00000000}},	//   _rao_, _afsæ, براز, --, 
   {{0x4425bb97,0xdd1c02fd,0xc4c4efb9,0x63880240}},	//   _sao_, lášt, وتبو, hënë, 
   {{0xb89000db,0x00000000,0x00000000,0x00000000}},	//   رلۇع, --, --, --, 
   {{0xfc3c004d,0x44240200,0x00000000,0x00000000}},	//   _khía_, _qao_, --, --, 
   {{0x4425bb98,0x84e822e3,0xc60454a0,0x00000000}},	//   _vao_, _टिकट_, _озай, --, 
   {{0x442400b2,0x75d00150,0xb6a00022,0xdce400d7}},	//   _wao_, _ليكا, _аиул, _vyhĺ, 
   {{0x4425bb99,0xb42001d3,0x6014032e,0x2098035b}},	//   _tao_, رٹیو, _nýmæ, зкны_, 
   {{0x44240421,0xdd940124,0x00000000,0x00000000}},	//   _uao_, ҵагы, --, --, 
   {{0xfe707299,0x50a01411,0x00000000,0x00000000}},	//   ندس_, دەيل, --, --, 
   {{0xf4080327,0x6a60007c,0x00000000,0x00000000}},	//   _གཡོད_, _löfb, --, --, 
   {{0xfbdc00e4,0x6ce401ec,0xbc38007b,0xa15801af}},	//   _peê_, кіте, يسرا_, _хайу_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x5a34305d,0xf0940302,0xfc3c0407,0x1fac0154}},	// [30b90] ннат, _בנק_, _chía_, _ক্রস, 
   {{0x6ac803d4,0x00000000,0x00000000,0x00000000}},	//   _লিখো, --, --, --, 
   {{0xdb0c04d4,0x3da401b9,0x57f41c35,0x00000000}},	//   rcañ, _юриб, епет, --, 
   {{0xdb0c0789,0x00000000,0x00000000,0x00000000}},	//   scañ, --, --, --, 
   {{0x26000fe3,0xfe7c0142,0x00000000,0x00000000}},	//   _राशी_, nsïo_, --, --, 
   {{0xeaf8168d,0x00000000,0x00000000,0x00000000}},	//   _کرێت_, --, --, --, 
   {{0xd5b00051,0x2610000d,0x00000000,0x00000000}},	//   _cáp_, _दउरी_, --, --, 
   {{0xb3080003,0xbf98000f,0x2db80375,0xc950011a}},	//   _ཁྱུང_, nfês, ולון_, _גמל_, 
   {{0xe6102cb0,0x662802f6,0x59b80034,0x99d0009e}},	//   _چشم_, öskä, ेडकर, াণীক, 
   {{0xd3940032,0xe61024b2,0x6388002e,0x01d800eb}},	//   мәһә_, _نشم_, wënë, _দাউদ, 
   {{0x6388025a,0xdd1c0356,0xdc800092,0x00000000}},	//   tënë, _râşc, _የብሄር_, --, 
   {{0xe730066d,0x6d4801b8,0x88f4011a,0x00000000}},	//   _حصہ_, ädam, עזרו_, --, 
   {{0x7d140227,0x63880023,0x00000000,0x00000000}},	//   _apxs, rënë, --, --, 
   {{0xbf98002d,0x60c40219,0x00000000,0x00000000}},	//   efês, _čimv, --, --, 
   {{0xbeb801c7,0x50940114,0x00000000,0x00000000}},	//   twëc, _приђ, --, --, 
   {{0xfc3c0016,0x8fa4657c,0x6aa807d0,0x4fa42143}},	//   _phía_, _пайе, कग्र, _пийв, 
   {{0x260001d9,0xd00402dd,0x4f940108,0x00000000}},	// [30ba0] _राली_, _жоққ, _ярку, --, 
   {{0x29b40c50,0x9044009f,0x00000000,0x00000000}},	//   نجاڭ, _آنکه, --, --, 
   {{0xebc401af,0x00000000,0x00000000,0x00000000}},	//   _аҡби, --, --, --, 
   {{0x27e1bb9a,0xfc3c004d,0x00000000,0x00000000}},	//   úin_, _thía_, --, --, 
   {{0x6aa00036,0x00000000,0x00000000,0x00000000}},	//   _ëmfo, --, --, --, 
   {{0xae041fbc,0x69d80156,0x00000000,0x00000000}},	//   श्चन_, ñved, --, --, 
   {{0xe99401d5,0xfc3c00ae,0xf2c001ec,0x993000e5}},	//   _شهرگ, _mhín_, қсын, _پہنت, 
   {{0xf4806564,0x25a0012c,0x00000000,0x00000000}},	//   луын, řilo_, --, --, 
   {{0x07a4004e,0x0685bb9b,0x05b80066,0x00000000}},	//   _чаан, _зган, _فدات_, --, 
   {{0x1cb80dd4,0xd24c3baf,0x56f022cb,0x00000000}},	//   ངམོ_, قچى_, _түшс, --, 
   {{0xf0e4ab54,0xdfd5bb9c,0x00000000,0x00000000}},	//   ньяк_, коны, --, --, 
   {{0xf1a1bb9d,0x8384023a,0xb1a000ee,0x1768030d}},	//   ырын, _пыле, ышык, _ирĕп_, 
   {{0x3ce00490,0xabc401ec,0x6f8401d5,0x00000000}},	//   टीने_, _ﯨﺴﻘﺎ, гурж, --, 
   {{0xfc3c001e,0x2918025c,0x44dc00e8,0x217801ec}},	//   _chín_, _opra_, oŋ_, _ойлы_, 
   {{0xdd95bb9e,0x00000000,0x00000000,0x00000000}},	//   тавы, --, --, --, 
   {{0xfc3c0248,0xc5e40154,0x00000000,0x00000000}},	//   _ehín_, নলিপ, --, --, 
   {{0x2919bb9f,0xbf98002d,0x00000000,0x00000000}},	// [30bb0] _apra_, rfês, --, --, 
   {{0x1958112a,0x3f980113,0xadbc010a,0x00000000}},	//   мазы_, _iyqu_, _наьi, --, 
   {{0xa3e0130b,0xfe7c004e,0x1a64036b,0x00000000}},	//   थरा_, duïx_, _ییری_, --, 
   {{0x2918020b,0x49a40032,0x69d80321,0x80a4012d}},	//   _dpra_, тыуғ, ðver, _टीमे, 
   {{0x38a400af,0xe75802bf,0xd6285847,0xe77800e5}},	//   võrd_, ниці_, доле_, ٹلوں_, 
   {{0x7afc2b34,0xd91400c7,0x00000000,0x00000000}},	//   muqt, _идгы, --, --, 
   {{0x7afc0d04,0x154457dd,0x00000000,0x00000000}},	//   luqt, тейм, --, --, 
   {{0x32e40241,0xd9e03d1d,0xe58800cf,0x00000000}},	//   _nìyá_, _फ़ुट, رۅنۉ_, --, 
   {{0x7afc0357,0x56e00046,0x14200456,0xe35401c4}},	//   nuqt, _тұлғ, _मसीह_, гтээ, 
   {{0xa7746799,0x326001d3,0x6d480254,0xd378004e}},	//   _случ, اندہ, ädak, зчү_, 
   {{0x78b9366e,0x3208068f,0x7afdbba0,0x10a401af}},	//   _kiuv, ęcy_, huqt, кион, 
   {{0x7afdbba1,0x54545c25,0xfc3c01e7,0x437000f2}},	//   kuqt, _швет, _shín_, اهیر, 
   {{0x7afc0d04,0xc8fc01ad,0x5ec41219,0xb8106c5a}},	//   juqt, _उम्म_, лияғ, ण्यम_, 
   {{0x78b9bba2,0x6588032e,0x7afc0166,0x00000000}},	//   _liuv, _íshú, duqt, --, 
   {{0xfc3c0077,0x3f98014f,0x0c941064,0x5cf40153}},	//   _chío_, _eyqu_, вшая, ляту, 
   {{0x78b9bba3,0x00000000,0x00000000,0x00000000}},	//   _niuv, --, --, --, 
   {{0x7afc0cfe,0xc0500302,0xbf9800d8,0xbeb8036e}},	// [30bc0] guqt, _כזה_, lgên, rvër, 
   {{0x2919bba4,0xda780212,0x6ba8013d,0x00000000}},	//   _ppra_, няє_, _ırgı, --, 
   {{0x78b80a73,0xbf980120,0x9f580793,0x00000000}},	//   _biuv, ngên, äyön_, --, 
   {{0x78b9bba5,0x7afc0455,0xdbd000a2,0xdec400d1}},	//   _ciuv, buqt, _küýd, ﻫﻪﺑﺒ, 
   {{0x2ee00699,0xa3e00034,0xfc3c01e7,0x5c540024}},	//   _jwif_, थरस_, _mhíl_, _стэф, 
   {{0x6a600793,0xbeb80221,0x38a4e523,0x75d093fc}},	//   _föfa, hwën, võre_, ليها, 
   {{0x29180393,0xbeb801c7,0x04a800d1,0x00000000}},	//   _upra_, kwën, мъий_, --, 
   {{0x78b81670,0x245801e1,0x6abdbba6,0xd1e80092}},	//   _giuv, _kémi_, _hirf, _ሙትቻ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x27e405ac,0x6abc031c,0xf41c03d4,0x38a400e4}},	//   _hemn_, _jirf, ভাগৰ_, rõre_, 
   {{0x26c5bba7,0xa5d814df,0x75d00137,0x27e40139}},	//   _humo_, _न्यौ, _ئيما, _kemn_, 
   {{0xf990025f,0x7afdbba8,0x26c5bba9,0x7410004b}},	//   ירת_, yuqt, _kumo_, _نوما, 
   {{0x27e4007f,0x26c40248,0x245801d3,0x6abc00ae}},	//   _memn_, _jumo_, _némi_, _oirf, 
   {{0xdce40038,0x27e400a8,0x26c4c900,0x425407fa}},	//   _vyhľ, _lemn_, _mumo_, _штет, 
   {{0x26c5bbaa,0x7afc014f,0x00000000,0x00000000}},	//   _lumo_, wuqt, --, --, 
   {{0xfbd02b7e,0x61e96491,0x245801e1,0x27e5bbab}},	//   شتر_, ladl, _bémi_, _nemn_, 
   {{0x3f9801d5,0xda1400d8,0x00000000,0x00000000}},	// [30bd0] _uyqu_, лдањ, --, --, 
   {{0x20c8006a,0x7afc1364,0x6a6029ef,0x78b80006}},	//   _kûi_, ruqt, _pöfa, _siuv, 
   {{0x78b808e5,0x6abd8791,0xdbd00037,0x7afc6b88}},	//   _piuv, _dirf, _küüd, suqt, 
   {{0x61e9bbac,0x78b80a73,0x26c40301,0x0d1c02d3}},	//   hadl, _qiuv, _bumo_, _ስልጣኖ, 
   {{0x37047c0c,0xdbd000af,0x61e9bbad,0x6abc0014}},	//   тчев, _müüd, kadl, _firf, 
   {{0x6abc0327,0x26c40009,0x6a6001a8,0xdbd00254}},	//   _girf, _dumo_, _höfn, _lüüd, 
   {{0x61e9bbae,0x27e4007f,0x26c4004e,0x78b801e4}},	//   dadl, _femn_, _eumo_, _tiuv, 
   {{0x26c4fee8,0x629800c8,0x1425bbaf,0xdbd000af}},	//   _fumo_, _akvo, удим, _nüüd, 
   {{0xfc3c004d,0x26c4b16b,0x96f801d3,0x00000000}},	//   _nhím_, _gumo_, _سٹار_, --, 
   {{0x61e8136f,0x6abc01d9,0xfc3c00c6,0xd9e00034}},	//   gadl, _xirf, _shíl_, _फ़ोट, 
   {{0x26c4316a,0xfc3dbbb0,0xd009bbb1,0x2ee002e2}},	//   _zumo_, _oní_, нене_, _swif_, 
   {{0xbf9803b7,0x629800df,0x26c401c8,0xfc3c00ae}},	//   rgên, _ekvo, _yumo_, _bhím_, 
   {{0x27e01125,0x26c401d9,0xfc3c2877,0x09c80154}},	//   ðini_, _xumo_, _chím_, ষরতা, 
   {{0xfc3d7f95,0x61e9bbb2,0x2459bbb3,0x91e4fbc4}},	//   _aní_, cadl, _rémi_, _соке, 
   {{0x10f402d5,0x50380023,0x00000000,0x00000000}},	//   _сяля, እኽኻባ, --, --, 
   {{0x6abc2035,0x8c9401ce,0x2c040116,0xdbd0010b}},	//   _sirf, ургі, шүмм, _tüýd, 
   {{0xfc3c03c6,0xbb40b610,0x4de80150,0x8e74267c}},	// [30be0] _dní_, бетк, _اﻧﺎ_, _бунч, 
   {{0xfc3cf9a8,0x27e40276,0x26c5bbb4,0x80c80490}},	//   _ení_, _semn_, _rumo_, _संमे, 
   {{0x6abdbbb5,0xbeb80036,0xdd2400e2,0x98c40022}},	//   _virf, iwël, pūša, аихҵ, 
   {{0x6abc2300,0x26c40421,0x61e9bbb6,0x24580ca8}},	//   _wirf, _pumo_, zadl, _témi_, 
   {{0x61e83e4c,0x2ca001a4,0xd7f802bf,0xbeb80309}},	//   yadl, mlid_, тує_, kwël, 
   {{0x2ca1bbb7,0xfc3c00bc,0x89d801d5,0x1fc000bc}},	//   llid_, _zní_, _سورر_, _एल्ड, 
   {{0x61e9bbb8,0x2ca000c5,0x26c401f4,0x00000000}},	//   vadl, olid_, _wumo_, --, 
   {{0x26c5bbb9,0x61e851e2,0x629895d8,0x87041291}},	//   _tumo_, wadl, _skvo, _مبطل, 
   {{0x61e91f6a,0x41e4063b,0x2ca1bbba,0x46a401c6}},	//   tadl, ліна, ilid_, _баав, 
   {{0xdbd0007d,0x61148bc5,0x33140214,0x2ca167ab}},	//   _süüd, адоу, ازيد_, hlid_, 
   {{0x61e9bbbb,0x6a6045a7,0x2ca0007d,0xdbd000af}},	//   radl, _löfo, klid_, _püüd, 
   {{0xfc3c0016,0x61e9bbbc,0xc0a847e7,0x00000000}},	//   _phím_, sadl, عادل_, --, 
   {{0x61e84ea1,0x82342688,0x7bcc0036,0x00000000}},	//   padl, _مرغا, _rfcu, --, 
   {{0xc0c00020,0x6a600008,0x61e9168b,0x929c012d}},	//   ሻሻል_, _söfn, qadl, tułe, 
   {{0xdbd0000d,0xf5840023,0xdf000327,0xdfd40150}},	//   _tüüd, _ዕንደራ_, wiċċ_, _койы, 
   {{0x2ca000af,0xfc3c01fb,0x6018014b,0x00000000}},	//   glid_, _thím_, _роия_, --, 
   {{0x2df4016c,0x00000000,0x00000000,0x00000000}},	// [30bf0] шҷӯё, --, --, --, 
   {{0x2ca1bbbd,0x2bb800c6,0x260021f2,0x0e000117}},	//   alid_, طاقة_, _रागी_, _мӯсо, 
   {{0x2ca08fef,0x39a43e4f,0x99b40154,0x57d401c8}},	//   blid_, ушав, য়র্ক, لياء, 
   {{0x2ca02bb1,0xfc3dbbbe,0x6a600e78,0xb178010f}},	//   clid_, _uní_, _höfl, עטאר, 
   {{0x26002cfd,0xc3240014,0xd5e402bf,0x7c2c03ac}},	//   _राखी_, _بٕ_, ажли, _iacr, 
   {{0x7c2c00a3,0x1c1001ad,0x66240131,0x24580118}},	//   _hacr, ड्रल_, مرىك, _mému_, 
   {{0x7c2cf917,0xdb1c005c,0x6a600166,0x00000000}},	//   _kacr, _afsø, _möfl, --, 
   {{0x60c5bbbf,0xb4ac033f,0xe4c80244,0xb600013a}},	//   _čimp, ओगे_, دبون_, _spáč, 
   {{0xd26405f5,0x80c805d7,0xbeb80036,0x6b780205}},	//   икий, _सूबे, twël, _işgö, 
   {{0x81ac00bd,0xdbd0010e,0x11b401f0,0x00000000}},	//   কশন_, _müñd, иёнр, --, 
   {{0x2ca05129,0xbeb804e6,0x42500133,0xe2a8009f}},	//   ylid_, rwël, ڵنێر, داين_, 
   {{0xe3b1bbc0,0x7c2c098d,0xbeb80036,0x00000000}},	//   _کرم_, _nacr, swël, --, 
   {{0x2ca1bbc1,0x929c0210,0x00000000,0x00000000}},	//   vlid_, gułc, --, --, 
   {{0x2ca005b1,0xb644037e,0x00000000,0x00000000}},	//   wlid_, _ｈｒ_, --, --, 
   {{0x7c2c3a73,0xc27800d9,0x77b80166,0x2ca032ba}},	//   _bacr, _שרצי, _yäxü, tlid_, 
   {{0xa3ac5345,0x2ca000c5,0x40900472,0x0c242377}},	//   _गरम_, ulid_, _ولور, јман, 
  
   {{0x7c2c102c,0x2ca1bbc2,0xc0dc01f3,0x0b440022}},	// [30c00] _dacr, rlid_, ናገረ_, шнан, 
   {{0x25a000bc,0xdbd0010e,0x6a60032e,0x00000000}},	//   řili_, _düñd, _göfl, --, 
   {{0x7c2cec36,0x47c40408,0x9e648ee7,0x2ca0000d}},	//   _facr, абев, _داين, plid_, 
   {{0x6d5dbbc3,0x97c400ae,0x00000000,0x00000000}},	//   myra, متهم, --, --, 
   {{0x6d5c14dc,0x7e74010a,0x00000000,0x00000000}},	//   lyra, _ymxp, --, --, 
   {{0x7c2c05ce,0x22900109,0xc0dc001f,0x6d5c0076}},	//   _zacr, bàky_, ናገሩ_, oyra, 
   {{0x394404f3,0x0465bbc4,0x6d5dbbc5,0x85440a89}},	//   änst_, итим, nyra, рэле, 
   {{0x7c2c004e,0x73d400a7,0x00000000,0x00000000}},	//   _xacr, адър_, --, --, 
   {{0x27e0008c,0xd5b0001e,0x6d5dbbc6,0xc76400d1}},	//   ðinu_, _máy_, hyra, _ئازى, 
   {{0x80c85345,0x86040014,0xc0c80104,0x6d5c667b}},	//   _संदे, _خبرٕ, куме_, kyra, 
   {{0x3a34025f,0xd57400d6,0x7af8168c,0x6d5d3dbf}},	//   ברים_, _луць, _åutv, jyra, 
   {{0x6d5dbbc7,0x1b1c0f22,0xd4082073,0x00000000}},	//   dyra, নিতে_, _متهم_, --, 
   {{0xe2f802bf,0xa2d40eff,0x2d8c000f,0x6d5c0009}},	//   _селі_, _ايتت, ûden_, eyra, 
   {{0x7c2d41c0,0x64a40131,0x6d5dbbc8,0xfd10009f}},	//   _sacr, _таҗа, fyra, يجز_, 
   {{0x6d5dbbc9,0xee2802f5,0x998002b5,0x6a6002d2}},	//   gyra, মাংশ_, rehū_, _vöfl, 
   {{0x245801f1,0x2d590cc2,0xec681db6,0x69d8030a}},	//   _tému_, шись_, арук_, ñven, 
   {{0xf9c44f13,0x6a6001a8,0x6d5c0076,0x39e8030d}},	// [30c10] ащен, _töfl, ayra, вьен_, 
   {{0xc0dc0020,0x6d5dbbca,0x6b74009d,0x00000000}},	//   ናገር_, byra, цлуу, --, 
   {{0x7c2c4146,0x6d5c003a,0x26002356,0xed88117e}},	//   _tacr, cyra, _राजी_, _всяк_, 
   {{0xf7700ae5,0x57b400ee,0x28f80212,0x00000000}},	//   ياش_, ббет, рець_, --, 
   {{0xab84010b,0xc044001f,0x8ca00c75,0x00000000}},	//   _дурк, _እየተፈ, _رەكو, --, 
   {{0xc7b40116,0x929c012d,0xa3dc000d,0xe57800ef}},	//   сқуч_, kuła, _त्ब_, _zeķi_, 
   {{0xd76401d3,0x00000000,0x00000000,0x00000000}},	//   ؤنڈی, --, --, --, 
   {{0x130801c0,0x7980002d,0x5edc2cc5,0xe8940006}},	//   гний_, ûnwu, _বিনে, _дась, 
   {{0x6d5c80c1,0x1604000d,0x00000000,0x00000000}},	//   zyra, _राऊर_, --, --, 
   {{0xd264c02c,0x823401d5,0x1fe000cc,0x00000000}},	//   ской, مرپا, _ভাগস, --, 
   {{0xda1807d0,0xa4d40212,0x37740150,0x00000000}},	//   न्यत_, _дохі, _сыңс, --, 
   {{0x6d5cb6f6,0x24580036,0x00000000,0x00000000}},	//   vyra, _déms_, --, --, 
   {{0xe3b0006c,0x6d5c0368,0x4f940114,0x00000000}},	//   _قره_, wyra, срну, --, 
   {{0x6d5dbbcb,0xea0001fb,0xdd000118,0xa3bc01f9}},	//   tyra, _đắn_, _útěk, _आणत_, 
   {{0xe1f001d5,0x3ce0012c,0x91800137,0x6d5c00ad}},	//   _آسه_, टीले_, _رۇحۇ, uyra, 
   {{0x6d5c0c8c,0x00000000,0x00000000,0x00000000}},	//   ryra, --, --, --, 
   {{0x6d5c0f42,0xbb40003b,0xd5b00051,0xcb080472}},	// [30c20] syra, петк, _váy_, طيان_, 
   {{0x6d5c0022,0x4e28004e,0x00000000,0x00000000}},	//   pyra, _соон_, --, --, 
   {{0xcc88009a,0x6d48007c,0x9f5c01e1,0x00000000}},	//   _منده_, ådad, _ùwò_, --, 
   {{0x1604033d,0x00000000,0x00000000,0x00000000}},	//   _राउर_, --, --, --, 
   {{0x1e340023,0x00000000,0x00000000,0x00000000}},	//   _ብምጥሓ, --, --, --, 
   {{0xa4d85884,0x00000000,0x00000000,0x00000000}},	//   адку_, --, --, --, 
   {{0x3ab08595,0xe3e80214,0xa4f86f3f,0xb8200154}},	//   _хәтт, لکشن_, شکار_, ফাজত_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc1e9bbcc,0x7af803cd,0x00000000,0x00000000}},	//   льне_, _åutt, --, --, 
   {{0x929c012d,0xa2780124,0x3014009d,0xdb1c00e5}},	//   tuła, рбоу_, үдэр, özép, 
   {{0x3a340302,0x3d0c0432,0xba980a7c,0x7bdc0334}},	//   זרים_, _möwç_, רסיי, ybqu, 
   {{0x20040006,0xf4f400e5,0x00000000,0x00000000}},	//   ėlio_, _اڈوں_, --, --, 
   {{0xa3bc2d6c,0xa3ac012c,0x058401e0,0xfbe400eb}},	//   _आणि_, _गरि_, _туҡм, _ফালত, 
   {{0x69d80dd4,0x00000000,0x00000000,0x00000000}},	//   ñvel, --, --, --, 
   {{0x941c016b,0x00d9bbcd,0x62880007,0x661c0790}},	//   _nhwɛ_, _صبغت_, mndo, _ırkl, 
   {{0x69d800e5,0xa3bc01f9,0x1dd80118,0x00000000}},	//   űvel, _आणा_, _ब्रत, --, 
   {{0x941c016b,0x6289bbce,0x6d4801e6,0x5ea4007b}},	// [30c30] _ahwɛ_, ondo, ädar, _ومعل, 
   {{0x6289bbcf,0x52c4009e,0x00000000,0x00000000}},	//   nndo, লীকৃ, --, --, 
   {{0xe7081dc8,0x20180ba7,0xaf40001f,0x9cb400ae}},	//   ەتىن_, ofsi_, ታደርገ, _ومخت, 
   {{0xbc2410de,0x7d040200,0x00000000,0x00000000}},	//   _اردى, mujs, --, --, 
   {{0x61f812fe,0xa3cc03ce,0x00000000,0x00000000}},	//   _odvl, लशन_, --, --, 
   {{0xe618005e,0x9f480589,0x34b084b7,0xddc400bc}},	//   йді_, _gdaå_, ुद्द, _pohř, 
   {{0x1958013d,0x60d803e0,0x00000000,0x00000000}},	//   _тавы_, _ntvm, --, --, 
   {{0x61f8003a,0x7af80fac,0xa9780166,0xdd1c00d7}},	//   _advl, _åuts, _уйсу_, kážt, 
   {{0x42c5bbd0,0x00000000,0x00000000,0x00000000}},	//   огын_, --, --, --, 
   {{0xc0dc0020,0x60d8004e,0x7d040240,0x00000000}},	//   ናለሁ_, _btvm, kujs, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6289bbd1,0x504415ed,0xdeac0b45,0x8fa5bbd2}},	//   ando, цемб, _iraƙ, жаме, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6235bbd3,0xfbbc726b,0x20180009,0x3e6c03b9}},	//   _нечу, ्शनम, afsi_, _lütf_, 
   {{0x8c780801,0xdb1c08a5,0x3ea001a9,0x00000000}},	//   ащат_, _ofsó, фирг, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfc3c004d,0x918000db,0x6a60002f,0x00000000}},	// [30c40] _nhíu_, _رۇڭۇ, _höfi, --, 
   {{0x6720003e,0xc8c801c8,0xe5780171,0xba2000cf}},	//   _rpmj, لوئن_, _zeķu_, мдук, 
   {{0x38c86813,0xc7c582a3,0xc92800a7,0x09280108}},	//   لانی_, осли, роеж_, ржей_, 
   {{0x09a80490,0xc5e400cc,0x929c0210,0x00000000}},	//   _करीय, _নাইপ, kuło, --, 
   {{0x6289bbd4,0x6a600793,0xc1a406ab,0xfc3c0051}},	//   yndo, _löfi, _ऑर्ग, _chíu_, 
   {{0xa3dc0490,0x8698030d,0x929c012d,0xc0dc0092}},	//   तुन_, штет_, duło, ናለህ_, 
   {{0xa3ac000d,0x00000000,0x00000000,0x00000000}},	//   _गरह_, --, --, --, 
   {{0xa2c40116,0x00000000,0x00000000,0x00000000}},	//   пәкк, --, --, --, 
   {{0xc32c04a9,0x09a801f9,0x82880454,0x00000000}},	//   ئەت_, _करुय, исоб_, --, 
   {{0x62880798,0x06656eb0,0x66e40032,0x00000000}},	//   undo, _بارپ, _моға, --, 
   {{0xaca401f2,0x5edc009e,0xfc3c004d,0x00000000}},	//   _alọt, _বিধে, _khít_, --, 
   {{0x6a6001a8,0x69d8030a,0x5f9400cf,0x00000000}},	//   _döfi, ñvej, зимт, --, 
   {{0x78a0054e,0xbfa83542,0x9f58005c,0x00000000}},	//   învi, ртне_, ngsø_, --, 
   {{0x6a60014a,0x62880007,0x09a80073,0x7d040200}},	//   _föfi, qndo, _करूय, tujs, 
   {{0x128800f2,0xeda400d4,0xceac00ec,0x00000000}},	//   _دموی_, дшто, دڙي_, --, 
   {{0x5f940323,0xfe7421cb,0x7d040010,0xfc3c0208}},	//   _нийт, сүү_, rujs, _nhít_, 
   {{0xab3800cf,0x00000000,0x00000000,0x00000000}},	// [30c50] опту_, --, --, --, 
   {{0x1b1c00fe,0xea00004d,0x39a5bbd5,0x199402e8}},	//   নিলে_, _đản_, ошев, пазя, 
   {{0xeeb80500,0xd998007b,0x2bfc00eb,0x24d0313e}},	//   _флэш_, حنات_, ুড়েই_, _ﻗﺎﻻﻣ, 
   {{0xb8f1bbd6,0xfc3c01fb,0xa3dc01bc,0x00000000}},	//   _हं_, _chít_, तुम_, --, 
   {{0xf7280276,0x3ab8072d,0x00000000,0x00000000}},	//   рцей_, _ناسخ_, --, --, 
   {{0xd628f3a6,0xbc240137,0x960407f7,0x00000000}},	//   соке_, _ارگى, रलेट_, --, 
   {{0xb8840166,0x00000000,0x00000000,0x00000000}},	//   _дуай, --, --, --, 
   {{0x6aa00a40,0x04240135,0x929c033f,0xfc3c0051}},	//   _ëmfr, _རྒྱམ_, tuło, _thíu_, 
   {{0xeda80316,0x66f5bbd7,0x00000000,0x00000000}},	//   _गर्छ, _опту, --, --, 
   {{0xe664656c,0x6a6001b8,0xcb1023e4,0x2d8403e0}},	//   _отхо, _pöfi, עלי_, ğmez_, 
   {{0x2d8451bb,0x10a43129,0xa3dc00cd,0x00000000}},	//   şmez_, зинн, _त्व_, --, 
   {{0xc4d00302,0x75d001e2,0x00000000,0x00000000}},	//   _נגד_, _ريچا, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6574002d,0x00000000,0x00000000,0x00000000}},	//   _ôfhâ, --, --, --, 
   {{0x661dbbd8,0x311c00cd,0x69d800e5,0x00000000}},	//   _örke, _बहिः_, űvek, --, 
   {{0x4fe80107,0xc0f8010f,0x00000000,0x00000000}},	//   _умин_, _פּוט, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [30c60] --, --, --, --, 
   {{0x6a600267,0x81ac05ac,0x00000000,0x00000000}},	//   _löfv, _কলত_, --, --, 
   {{0x3e58011a,0x00000000,0x00000000,0x00000000}},	//   _הדיס, --, --, --, 
   {{0xa3ac02e5,0xa8000118,0xa878009d,0x00000000}},	//   _गरल_, příč_, цөгт_, --, 
   {{0xb8f052be,0x00000000,0x00000000,0x00000000}},	//   _हू_, --, --, --, 
   {{0xfe1d4556,0xfc3c00ae,0xd70c0037,0x00000000}},	//   म्पस_, _fhís_, _समरथ_, --, 
   {{0xd90cfe81,0x1fb82366,0xfc3c0208,0x00000000}},	//   _نیل_, _इण्ड, _thít_, --, 
   {{0x48e4013e,0x00000000,0x00000000,0x00000000}},	//   _моҳв, --, --, --, 
   {{0x3e6c0112,0xb5c000fb,0xa2b4011c,0x00000000}},	//   _hüte_, мйәл, мбич, --, 
   {{0xa3dc2977,0xb2700b2c,0x3e6c0037,0x3f8c0022}},	//   _त्र_, ельш, _küte_, _ÿgui_, 
   {{0xfc3c00c6,0xa1580276,0x00000000,0x00000000}},	//   _mhír_, цану_, --, --, 
   {{0xbeb801c7,0x38a40037,0x00000000,0x00000000}},	//   hwët, võrk_, --, --, 
   {{0x6a6000fc,0xd04000ac,0x3d0c01f9,0x00000000}},	//   _höfu, nqlə, तूने_, --, 
   {{0x4b10015b,0x6a60032e,0xeb4c0092,0x00000000}},	//   হবাগ_, _köfu, _አመጋገ, --, 
   {{0x6e95bbd9,0x1bd43da1,0xa3a801f7,0x00000000}},	//   хиру, добя, _اُڇل_, --, 
   {{0xea00001e,0xd9d000fe,0x00000000,0x00000000}},	//   _đạn_, িৰাম, --, --, 
   {{0x5a35bbda,0x81ac045e,0x929c012d,0xd6d80210}},	// [30c70] мнат, _কলি_, zułm, _orła_, 
   {{0x3ea40174,0xd9f80006,0xaa4400d1,0x00000000}},	//   _ónt_, інец_, ىنقى, --, 
   {{0x57a80952,0xdd94009d,0x00000000,0x00000000}},	//   ﺴﺘﯩﺮ, _цаны, --, --, 
   {{0x81ac2158,0x38c81291,0x00000000,0x00000000}},	//   _কলা_, لاچی_, --, --, 
   {{0xcc5423e4,0x8c400e78,0x27e0d4bc,0x4c38011a}},	//   _חברי_, ößen, ñina_, _ותרב, 
   {{0xfbd00a81,0x00000000,0x00000000,0x00000000}},	//   _تتھ_, --, --, --, 
   {{0xa9a402f4,0x3e6c0112,0xbeb801c7,0xa84800d1}},	//   _зиёд, _güte_, lwës, غلۇم_, 
   {{0x61e4026a,0xe5041823,0xf67426a8,0xf77005d9}},	//   _đila, ربىي, _کارخ, _ٻار_, 
   {{0x387dbbdb,0x27f800bc,0x91e40f06,0x00000000}},	//   _imur_, řený_, мопе, --, 
   {{0xe61003b9,0x00000000,0x00000000,0x00000000}},	//   müşə, --, --, --, 
   {{0x3569bbdc,0x5edc04c5,0x6aa000d2,0xf5680228}},	//   _уран_, _বিষে, _ímfe, _ушак_, 
   {{0x6a60ee18,0x387c0003,0xbeb80036,0x8598011a}},	//   _höft, _jmur_, kwës, _ושעו, 
   {{0x09c404c5,0x6a6005d1,0x387c025c,0x311c00cd}},	//   শুপা, _köft, _mmur_, _बहवः_, 
   {{0x5edcfebc,0xec3401d5,0xe374013d,0x88dc00eb}},	//   _বিশে, کورگ, _ялчы, _ডিসক, 
   {{0x6ce80073,0x6a6000fd,0x387d2b94,0x00000000}},	//   टींग_, _möft, _omur_, --, 
   {{0x6a6001e6,0x0ae80395,0x5edc00fe,0x00000000}},	//   _löft, ждай_, _বিৰূ, --, 
   {{0xa5a419e5,0x3e6c03e0,0x00000000,0x00000000}},	// [30c80] _चुनौ, _süte_, --, --, 
   {{0x387c0c86,0x00000000,0x00000000,0x00000000}},	//   _amur_, --, --, --, 
   {{0xbeb804e6,0x61fc1d0e,0x00000000,0x00000000}},	//   rwët, órli, --, --, 
   {{0x4e18012c,0x076800ae,0x00000000,0x00000000}},	//   म्रै_, يماً_, --, --, 
   {{0xfc3c007b,0x2ca004ce,0xbf982694,0x929c0210}},	//   _thír_, moid_, lgêr, gułk, 
   {{0x387c003e,0xd04000ac,0x3e6c0112,0x36640117}},	//   _emur_, rqlə, _tüte_, мачо_, 
   {{0xbf98145e,0x689400b2,0xa3d40006,0x00000000}},	//   ngêr, _ٻڌائ, нойч, --, 
   {{0x6a6002d2,0x2240008e,0x00000000,0x00000000}},	//   _vöfu, _şik_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2ca1bbdd,0x6a60032e,0x2ab5bbde,0x5edc00eb}},	//   hoid_, _töfu, bäbe_, _বিলে, 
   {{0x81ac02f5,0xbeb80036,0x4534bc6c,0x00000000}},	//   _কলহ_, zwës, _юхат, --, 
   {{0x246c012d,0xfc3c0208,0xd49801ec,0x00000000}},	//   yśmy_, _nhíp_, _ері_, --, 
   {{0x80c8098b,0x44f81991,0x2004029f,0x6d484bc1}},	//   _संके, lī_, ğli_, ådan, 
   {{0x200430a8,0xa1940305,0xd72c00c0,0x00000000}},	//   şli_, _палч, _вiце, --, 
   {{0x44f80a2b,0xf0b80451,0x6a6001e3,0x38a40254}},	//   nī_, _ڪاوش_, _löfs, mõrv_, 
   {{0x2ca11a00,0xfc3c004d,0x2484fe4a,0xac74007b}},	//   goid_, _chíp_, nimm_, ناقش, 
   {{0x2918003d,0x09c4009e,0x44f83e16,0x1ab402dd}},	// [30c90] _aqra_, শুমা, hī_, ебая, 
   {{0x44f9bbdf,0x2ca001ab,0xbeb804e6,0xdb1c032e}},	//   kī_, aoid_, rwës, _ofsö, 
   {{0x2ca0020c,0xbeb80036,0xadbc0408,0x999001ef}},	//   boid_, swës, _маьi, _vazů_, 
   {{0x9be8038f,0x2ca1bbe0,0x929c0210,0x00000000}},	//   _འབྲོ, coid_, tułk, --, 
   {{0xdb1c01a8,0xcc74025d,0xba741c3e,0x38a40254}},	//   _afsö, _נעשה_, _قاست, kõrv_, 
   {{0xb0cc3806,0xe61000ac,0x2ab554da,0xea000208}},	//   _संलग, rüşə, täbe_, _đần_, 
   {{0x2d9c2f48,0x387c003d,0x3ce00073,0x6934014b}},	//   _øvet_, _tmur_, टीचे_, _инру, 
   {{0x4dc417de,0xa98800db,0x929c0210,0x00000000}},	//   ﯩﺮﯨﻨ, _تۅمۅ_, pułk, --, 
   {{0x569400c7,0xdc800092,0x1b1c0011,0x00000000}},	//   _заат, _ከእስር_, নিকে_, --, 
   {{0x6a6008a5,0x00000000,0x00000000,0x00000000}},	//   _höfr, --, --, --, 
   {{0x8fd0104e,0x44f80a88,0x00000000,0x00000000}},	//   ләпә, cī_, --, --, 
   {{0x494402d3,0x81404ea7,0x8538011a,0xd374009b}},	//   _መጋባእ, اچون, _מגעי, _плећ, 
   {{0x2ca00b1d,0x0eb8010b,0x4814010f,0x00000000}},	//   void_, зувы_, ײַכן_, --, 
   {{0x877804ae,0x333c0267,0x00000000,0x00000000}},	//   לארי, mvux_, --, --, 
   {{0x6fa04d53,0xbeb801c7,0x5ec43d09,0x333c031c}},	//   _गुरू, twër, тирғ, lvux_, 
   {{0x4fe9bbe1,0xbf980165,0x00000000,0x00000000}},	//   _эмин_, rgêr, --, --, 
   {{0x0ba80c75,0xbeb9bacc,0x0fc4010a,0x00000000}},	// [30ca0] سارى_, rwër, _яйин, --, 
   {{0x818407d6,0x2ca1046f,0x00000000,0x00000000}},	//   _آچیق_, soid_, --, --, 
   {{0x2d9c00e4,0xdb0800e4,0x2ca00072,0x499421f3}},	//   _âve_, _ñoîr, poid_, хшат, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfe145096,0x44f802b1,0x0cbc629c,0xf7400120}},	//   _तामस_, wī_, ्दीम, лецо, 
   {{0x44f92d0c,0xcaa0044e,0x3e6c0254,0x2d9c072b}},	//   tī_, _ገሊኦም_, _küta_, _øves_, 
   {{0x69ddbbe2,0xd8380421,0xd68801e4,0x00000000}},	//   _ifre, _faō_, _preϲ, --, 
   {{0x44f83a71,0x07a40120,0x00000000,0x00000000}},	//   rī_, _забн, --, --, 
   {{0x2485b8eb,0xf360009d,0xf41c00cc,0x00000000}},	//   rimm_, гтэн, _মোহৰ_, --, 
   {{0x06e4009e,0x77808f8c,0x75d0007b,0x24840205}},	//   _নিপি, _слуз, _ميكا, simm_, 
   {{0x01889849,0x225c0427,0x331400f2,0x00000000}},	//   ящий_, _vovk_, وزید_, --, 
   {{0xf9900375,0x00000000,0x00000000,0x00000000}},	//   טרת_, --, --, --, 
   {{0x69dc28f2,0xbfa811db,0xefcc0b82,0x35800023}},	//   _ofre, ятое_, በርያ_, _ክሕተት_, 
   {{0x2b400219,0xa3dc07b7,0x9f48002b,0x00000000}},	//   dvic_, तुर_, _idaü_, --, 
   {{0xed58009d,0x00000000,0x00000000,0x00000000}},	//   ноё_, --, --, --, 
   {{0x69ddbbe3,0x9a6800e5,0x00000000,0x00000000}},	//   _afre, ڈمرل_, --, --, 
   {{0xddc401f1,0x5f95bbe4,0x40300124,0x20fc01e4}},	// [30cb0] _dlhš, _шиит, _аеқс, lĉi_, 
   {{0x1dd406b1,0xebd801c6,0x00000000,0x00000000}},	//   _दलित, _үдэш_, --, --, 
   {{0x7ec401e1,0x20fc010f,0x290c01bf,0x6ab01155}},	//   _eépì, nĉi_, _ådal_, _šifó, 
   {{0x8cd400ab,0x99d00154,0x00000000,0x00000000}},	//   _मंतो, িরেক, --, --, 
   {{0x7bcd35c4,0x2d9c2d75,0x69ddbbe5,0xfb858bf4}},	//   _igcu, _øver_, _ffre, _чынн, 
   {{0x6d481cf3,0x79e401ed,0xbeb804e6,0xe68800d1}},	//   ædag, _سورہ_, stëf, ىننى_, 
   {{0x45a021ef,0x661c03e0,0x6a6001a8,0x00000000}},	//   لەكك, _ırkt, _töfr, --, 
   {{0xa3dc150d,0x00000000,0x00000000,0x00000000}},	//   तुल_, --, --, --, 
   {{0x963400c7,0x00000000,0x00000000,0x00000000}},	//   _инац, --, --, --, 
   {{0x38c401e1,0xc2400024,0xbeb8036e,0xd2640395}},	//   _fìrì_, аньк, ntëd, ткой, 
   {{0xd009bbe6,0x2ee0a98d,0x38c40241,0x1b1c0154}},	//   мене_, _stif_, _gìrì_, নিটে_, 
   {{0x7bcdbbe7,0x60dc0005,0xa3d40408,0xa3d80210}},	//   _ngcu, írma, _боцч, _ालय_, 
   {{0xa3a80574,0xe4d800db,0x00000000,0x00000000}},	//   _खुप_, _قوەت_, --, --, 
   {{0x06e44251,0x8cd401ad,0x00000000,0x00000000}},	//   _নিমি, _मंदो, --, --, 
   {{0x0d200228,0x50b40276,0xed840116,0x81f40472}},	//   шүнү, _исиу, уңни, _شفير_, 
   {{0x69dc5bd9,0x0cbc3c71,0x2b400427,0xfc000395}},	//   _sfre, ्देम, tvic_, ипсо, 
   {{0x68fc01a6,0x80c8000d,0xee9410e8,0x00000000}},	// [30cc0] _svrd, _सूटे, _مددک, --, 
   {{0x7bcc0921,0x2b41bbe8,0xbb400b30,0xbea00354}},	//   _egcu, rvic_, шеук, _ваьк, 
   {{0xa3a83eb6,0x00000000,0x00000000,0x00000000}},	//   _खुन_, --, --, --, 
   {{0x38c401e1,0x80c8000d,0x00000000,0x00000000}},	//   _rìrì_, _संछे, --, --, 
   {{0x57a401e0,0x19f000cc,0x00000000,0x00000000}},	//   лышҡ, _চাৰু_, --, --, 
   {{0x69ddbbe9,0x6595bbea,0x38c401e1,0xd90c01d3}},	//   _ufre, лалу, _pìrì_, تیہ_, 
   {{0xd3e8015b,0x69d800e5,0x47d41063,0x97c40116}},	//   _গাড়ি_, űves, _ليزر, نتۇم, 
   {{0xa3dc0882,0x3944037e,0x39102586,0x00000000}},	//   तुं_, ænse_, _خوفز, --, 
   {{0xb7d407d2,0x07a40124,0x38c401e1,0x00000000}},	//   _شولا_, _раан, _wìrì_, --, 
   {{0xd24c67d1,0xf4846aef,0x855461be,0x86c52093}},	//   كچى_, _یانی, _لیتر_, _شيان, 
   {{0x26cc0014,0x60f802d5,0x38c801d3,0x00000000}},	//   _iido_, эння_, _راہی_, --, 
   {{0x20fc00c8,0x30a400a7,0x26cc0009,0x00000000}},	//   rĉi_, иряв, _hido_, --, 
   {{0x4425bbeb,0x26cc02ea,0xa3dc0882,0x23a40055}},	//   _ibo_, _kido_, तुः_, _aṇḍā, 
   {{0x26cc047e,0x24590b13,0x39440267,0x4424123b}},	//   _jido_, _rémy_, ånsk_, _hbo_, 
   {{0x26cdbbec,0x22580008,0x6d58004a,0x3ea0036e}},	//   _mido_, örku_, _àval, rojt_, 
   {{0x44243098,0x20040024,0xdd0c012d,0x026401f3}},	//   _jbo_, ėlis_, _półt, ትዮጽያ_, 
   {{0x4425bbed,0x26cdbbee,0x60cc0784,0x5edc015b}},	// [30cd0] _mbo_, _oido_, _iiam, _বিকে, 
   {{0x6289bbef,0x26cdbbf0,0x60cdbbf1,0x62f4015b}},	//   nido, _nido_, _hiam, _আমায়_, 
   {{0x4425bbf2,0x15840131,0x6288058a,0x00000000}},	//   _obo_, ﻪﺭﺗﯩ, iido, --, 
   {{0x4425bbf3,0x245801a2,0x7bcc0b6f,0x60cc7460}},	//   _nbo_, _témy_, _ugcu, _jiam, 
   {{0x60cdbbf4,0x6289bbf5,0x26cdbbf6,0x9725265f}},	//   _miam, kido, _bido_, افتو, 
   {{0x60cc07e4,0xa3ac0574,0x6289bbf7,0x26cc35f5}},	//   _liam, _गरज_, jido, _cido_, 
   {{0x62881a36,0x26cdbbf8,0x4425bbf9,0xa3a811e1}},	//   dido, _dido_, _bbo_, _खुब_, 
   {{0x60cdbbfa,0x26cc1709,0x6289bbfb,0xd39401e0}},	//   _niam, _eido_, eido, ләлә_, 
   {{0x26cdbbfc,0x6288014a,0xf7700075,0x44240175}},	//   _fido_, fido, _ئاز_, _dbo_, 
   {{0x26cc5144,0x60cc00c5,0x629c00b0,0x38c8004b}},	//   _gido_, _aiam, ōron, _راځی_, 
   {{0x4425bbfd,0x78b91eb0,0x60cc007f,0xd7b8025c}},	//   _fbo_, _khuv, _biam, _བཻཌཱ, 
   {{0x60cdbbfe,0x4424110e,0x9f5800e4,0xfc3c09e8}},	//   _ciam, _gbo_, masê_, _skín_, 
   {{0x6e38044e,0x60cd90a4,0x8e7401b9,0x00000000}},	//   _ብምግባ, _diam, гувч, --, 
   {{0x26cc0077,0xc3300375,0xe3b001fd,0x4424022e}},	//   _xido_, _לוד_, _برم_, _zbo_, 
   {{0x60cdbbff,0x32400184,0x5044247f,0xe8140034}},	//   _fiam, _беҙг, _бейб, _डाला_, 
   {{0x60cc0bed,0x78b802c4,0x44240139,0x00000000}},	//   _giam, _nhuv, _xbo_, --, 
   {{0x3b04192a,0x3fe002d5,0x0b44fb92,0xd8dc0150}},	// [30ce0] лето_, _ужыв, ынан, _ﻁﺎﻭﻟ, 
   {{0x60cc009f,0x00000000,0x00000000,0x00000000}},	//   _ziam, --, --, --, 
   {{0x09046afe,0x26cdbc00,0xba14fd47,0x78b80882}},	//   упен, _rido_, ايما_, _bhuv, 
   {{0x78b9bc01,0x26cdbc02,0x60cd2065,0x6289bc03}},	//   _chuv, _sido_, _xiam, zido, 
   {{0x38c804d3,0x26cdbc04,0xeac80184,0xa684054a}},	//   رامی_, _pido_, _ағай_, ағай, 
   {{0x6288056a,0x4424b918,0x06e40183,0x00000000}},	//   xido, _sbo_, _নিদি, --, 
   {{0x6289bc05,0xe688049e,0x26cdbc06,0xaad808e6}},	//   vido, ىنچى_, _vido_, _भूतक, 
   {{0x02642295,0x6289bc07,0xb990323b,0x4424198f}},	//   ትዮጵያ_, wido, _الفب, _qbo_, 
   {{0xf74072e5,0x60cc1549,0x26cdbc08,0x44240549}},	//   _лето, _riam, _tido_, _vbo_, 
   {{0x60cdbc09,0x4425bc0a,0x60dc0005,0x78b83e17}},	//   _siam, _wbo_, írmo, _zhuv, 
   {{0x75d1bc0b,0x60cdbc0c,0xa05402bf,0x7a780a7c}},	//   _ايما, _piam, авні, גריס, 
   {{0xf534025f,0x62890c34,0x60cdbc0d,0x74100244}},	//   _תנאי_, sido, _qiam, _هوما, 
   {{0x9f580240,0x23a4001f,0x64400334,0x6abc002f}},	//   masë_, ገንዘብ_, mdmi, _ohrf, 
   {{0x6441a17c,0xb5a8002e,0x60cc002e,0x9f580240}},	//   ldmi, _g斡st, _wiam, lasë_, 
   {{0x60cdbc0e,0x2d8c002d,0x5284010a,0x00000000}},	//   _tiam, źden_, _тăру, --, 
   {{0x6441bc0f,0xfe740e26,0xc10000f7,0x9f58036e}},	//   ndmi, түү_, _күүл, nasë_, 
   {{0x63a400e4,0x64400037,0xdb140139,0x9d140154}},	// [30cf0] _ÿind, idmi, _äbül, াবেন_, 
   {{0x78b9bc10,0x25a00118,0x79e401d3,0x9f580200}},	//   _shuv, řily_, اوضہ_, hasë_, 
   {{0x3945bc11,0xd7d40640,0x5be40014,0x78b9b080}},	//   íns_, ажењ, _پتجہ, _phuv, 
   {{0x9f580240,0x6abc002f,0x00000000,0x00000000}},	//   jasë_, _ehrf, --, --, 
   {{0x78b80084,0xe8184028,0x69c800d0,0x37041fbe}},	//   _vhuv, ازمت_, _úden, учев, 
   {{0xd628ea45,0x67d401d5,0x00000000,0x00000000}},	//   токе_, _ғофу, --, --, 
   {{0xfc3c0093,0x3a30020c,0x78b80208,0x74000107}},	//   _kaí_, mexp_, _thuv, бойҷ, 
   {{0x64997ab1,0xc60409bd,0x2db00131,0x13049f27}},	//   лтыр_, ল্লা_, ﺳﯘﻟﻤ, азим, 
   {{0xa3a809d9,0xfc3c0f99,0x290402b5,0x888025da}},	//   _खुद_, _maí_, _āmai_, _بینن, 
   {{0x91801e4a,0xd39401e0,0x52847fec,0x9f58007f}},	//   يۇشۇ, ләһә_, ргоб, masè_, 
   {{0xfba400ab,0x00000000,0x00000000,0x00000000}},	//   _कुसम, --, --, --, 
   {{0x10a5bc12,0xfc3c0332,0x61e4013d,0x00000000}},	//   римн, _naí_, _ğile, --, 
   {{0x3cd800af,0x61e40205,0x00000000,0x00000000}},	//   _खूबे_, _şile, --, --, 
   {{0x91e41c56,0xef5c0240,0x00000000,0x00000000}},	//   _токе, _ንኸይፍ, --, --, 
   {{0xa3dcd04e,0xfc3c0332,0xd1c81954,0x00000000}},	//   तुक_, _baí_, በልቲ_, --, 
   {{0xfc3c1ada,0x9ce402d5,0x00000000,0x00000000}},	//   _caí_, сцёл, --, --, 
   {{0xfc3c06ed,0x9f58026c,0x6388005f,0xca85bc13}},	// [30d00] _daí_, jasè_, cīnī, агай, 
   {{0x7bdc02e8,0x3a300175,0x00000000,0x00000000}},	//   acqu, gexp_, --, --, 
   {{0xfc3c03a0,0x19b80953,0xbeb801c7,0x1ad401d5}},	//   _faí_, гуць_, stëc, _қўяр, 
   {{0x8c45bc14,0x07b8007b,0x87e401e0,0x27e00e89}},	//   _теме, نهضة_, рһаң_, ùin_, 
   {{0xbb4000d6,0x06e40183,0xe58400f7,0x661c0108}},	//   _деяк, _নিহি, өткү, _örkk, 
   {{0xbb400261,0x00000000,0x00000000,0x00000000}},	//   _ќерк, --, --, --, 
   {{0x3af80241,0xb63000cf,0x00000000,0x00000000}},	//   _tàpá_, زعوت, --, --, 
   {{0xd90c0b28,0x386c0175,0x3e6c000d,0xf81400db}},	//   _سیه_, ckgr_, _rütm_, _ەسەگ, 
   {{0x6441bc15,0x06c850c0,0x9f580240,0x23480214}},	//   rdmi, _агай_, rasë_, اسبی_, 
   {{0x09c800bd,0x2721bc16,0x41c401f0,0x00000000}},	//   _ল্যা, mòn_, иёна, --, 
   {{0xdfd446e8,0x272002bd,0x32b401c0,0x9f58020c}},	//   йоны, lòn_, ргээ_, masé_, 
   {{0x2348293c,0x9f585448,0x443001fb,0x9f3401ec}},	//   _مستی_, lasé_, _úy_, бемі, 
   {{0xfc3c00d8,0x00000000,0x00000000,0x00000000}},	//   _raí_, --, --, --, 
   {{0xea0001dc,0xfc3c0120,0x9f580066,0x00000000}},	//   _đến_, _saí_, nasé_, --, 
   {{0xb2b8025f,0xfc3c26b6,0x6e9427a8,0x00000000}},	//   _שמור, _paí_, циру, --, 
   {{0x61f9bc17,0x27200086,0x6e3802d3,0x9f58020c}},	//   _hevl, kòn_, _ብዝግባ, hasé_, 
   {{0xfc3dbc18,0x27200428,0x60d80455,0x9f58020c}},	// [30d10] _vaí_, jòn_, _huvm, kasé_, 
   {{0x195800c7,0x2721bc19,0xba74708e,0x2bb8007b}},	//   лазы_, dòn_, جارت, شاقة_, 
   {{0xdd91bc1a,0xa3a839a1,0xfc3c0798,0x9e840133}},	//   _روح_, _खुस_, _taí_, _ناگۆ, 
   {{0x315404ac,0x20183aad,0x2721030a,0x60d9bc1b}},	//   ייבן_, ngsi_, fòn_, _muvm, 
   {{0x2721bc1c,0x60d9bc1d,0x9f580066,0xaee400cd}},	//   gòn_, _luvm, fasé_, _ikṣv, 
   {{0x9f5800f2,0xe618753d,0x368802e8,0xa68400d4}},	//   gasé_, иді_, ъсен_, олід, 
   {{0xfbd8069f,0x28f84d15,0x38c83159,0xd548314c}},	//   _भलाम, _весь_, _ауан_, البو_, 
   {{0x2721bc1e,0xd7c95dac,0xfbdc0798,0x00000000}},	//   bòn_, _موزه_, _inês_, --, 
   {{0x61f9bc1f,0x9f580066,0xd2a8034b,0x27200051}},	//   _bevl, basé_, лкие_, còn_, 
   {{0x60d83489,0xb5a48fe2,0x9f58020c,0x61f85049}},	//   _buvm, _крей, casé_, _cevl, 
   {{0x61f9bc20,0x987800df,0x88800345,0x00000000}},	//   _devl, ָאָט, _بیۆن, --, 
   {{0xb11002e3,0x20181bce,0x45b4011a,0x00000000}},	//   _kụzu, ggsi_, _הפעל_, --, 
   {{0x88980bd9,0xfba4a1f3,0x00000000,0x00000000}},	//   רברי, _कुलम, --, --, 
   {{0x61f85b5e,0x7641bc21,0xd5b0004d,0x623554df}},	//   _gevl, ndny, _ký_, _мечу, 
   {{0x7640020b,0x27200100,0x00000000,0x00000000}},	//   idny, zòn_, --, --, 
   {{0x2720007f,0xaa1000bc,0x00000000,0x00000000}},	//   yòn_, ाल्छ_, --, --, 
   {{0xf1bc012c,0xd5b001fb,0x61f80213,0x0ba80137}},	// [30d20] řád_, _lý_, _yevl, اازى_, 
   {{0x6f041674,0x60d831c5,0x06e400fe,0x9f58002e}},	//   _ivic, _yuvm, _নিলি, xasé_, 
   {{0xfe34025f,0x27205eb0,0x06c801ec,0x661da473}},	//   _פרטי_, wòn_, ңгей_, _örki, 
   {{0x27200086,0x6f04cc6e,0xe8a801e0,0x9f580214}},	//   tòn_, _kvic, шбеҙ_, wasé_, 
   {{0x9f5800f2,0x8644020f,0x07a4117e,0x00000000}},	//   tasé_, йндж, щадн, --, 
   {{0x27200428,0xe81407f7,0x8f640092,0x9d4401e2}},	//   ròn_, _डाका_, _ልዩነቶ, _ائین, 
   {{0x9f59bc22,0x272002e2,0x6f0401ef,0x00000000}},	//   rasé_, sòn_, _lvic, --, 
   {{0x2a780007,0x7640020b,0x6f049f4e,0x61f8014f}},	//   _hlrb_, adny, _ovic, _sevl, 
   {{0xa3a849fc,0x60d8047e,0xf5a40116,0x02a40f06}},	//   _खुश_, _suvm, _қәшқ_, йром, 
   {{0x60d8047e,0x61f80477,0xcd000055,0x888001d3}},	//   _puvm, _qevl, _kuśā_, _بیچن, 
   {{0x6f05bc23,0x201801ee,0x61f805ac,0x60d8016d}},	//   _avic, tgsi_, _vevl, _quvm, 
   {{0x60d80477,0x00000000,0x00000000,0x00000000}},	//   _vuvm, --, --, --, 
   {{0x27e40109,0x61f9bc24,0x3e9400c6,0x6f041d55}},	//   _mfmn_, _tevl, مؤسس, _cvic, 
   {{0x6f05bc25,0x3e6dbc26,0x00000000,0x00000000}},	//   _dvic, _küti_, --, --, 
   {{0x6f040c8c,0x6d40012d,0x00000000,0x00000000}},	//   _evic, łman, --, --, 
   {{0x7640e475,0xec683f1b,0x3e6c06be,0x9c380798}},	//   zdny, брук_, _müti_, јпат_, 
   {{0x20081509,0xd9f847ce,0x00000000,0x00000000}},	// [30d30] _idai_, инац_, --, --, 
   {{0xacf80034,0xd7584f6f,0xf9c4023a,0x7e7400e5}},	//   _żółt, یلات_, бщен, _چاھئ, 
   {{0x6f05bc27,0x200805b1,0xd99800c6,0x60dc0332}},	//   _zvic, _kdai_, جنات_, írmh, 
   {{0x6d409787,0xd82402bf,0x76400083,0x57b4020f}},	//   āmat, ідли, wdny, обет, 
   {{0xa3a80c2e,0x200801f7,0x7a0800b0,0x8c1800d9}},	//   _खुल_, _mdai_, tētē, _דורי, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7640020b,0x60c00165,0x20080024,0x00000000}},	//   rdny, _alṭṭ_, _odai_, --, 
   {{0x1309bc28,0x7640020b,0x2009bc29,0xae2000c5}},	//   аний_, sdny, _ndai_, _बाभन_, 
   {{0x569405f5,0x3220025c,0xaa302347,0xd3b80006}},	//   _даат, _འཁྱར_, änçä_, шукі_, 
   {{0x20080451,0x6f041529,0x78a80115,0x2f100008}},	//   _adai_, _rvic, logv, _lögð_, 
   {{0x6f0496c0,0x2c7c00ae,0xe5083bd7,0x00000000}},	//   _svic, _híde_, _هيلو_, --, 
   {{0x78a80165,0x00000000,0x00000000,0x00000000}},	//   nogv, --, --, --, 
   {{0xb8d82fb5,0x20080066,0x0838008f,0xaad8000d}},	//   _ངེ_, _ddai_, בערל, _भूंक, 
   {{0x20080481,0xbeb80036,0xa3c80073,0xf2c5bc2a}},	//   _edai_, stën, ोखर_, _усен, 
   {{0x71600020,0x6d5c0007,0xfce008da,0xdeb80023}},	//   ልግሎቶ, uxra, досо, ዲምካ_, 
   {{0xd954001f,0x6f040100,0xf610000d,0x00e40244}},	//   _የሚያጋ, _tvic, _ठाढ़ि_, _بتوی, 
   {{0xfc01bc2b,0x6f0401f0,0x8eb8084c,0x2ab400c5}},	// [30d40] ьпто, _uvic, _вынт_, läbi_, 
   {{0xcc880acb,0x6d480158,0x25a00790,0x4e2801c6}},	//   _چنده_, ådas, şili_, _тоон_, 
   {{0xdde40419,0x4ee000cc,0x00000000,0x00000000}},	//   ásťr, _বিয়ল, --, --, 
   {{0x3e6c05d5,0xae2000af,0x00000000,0x00000000}},	//   _rüti_, _बाडन_, --, --, 
   {{0x3e6c01d3,0x2c7c1d0e,0x2ab4000d,0xf1a8012d}},	//   _süti_, _vídd_, häbi_, _घुसन, 
   {{0x2c7c01e1,0xf1b812eb,0x8a600345,0x00000000}},	//   _díde_, ैधान, _تێئۆ, --, 
   {{0xd838007f,0x7e600241,0x48580064,0x00000000}},	//   _djōb_, _ònpe, _краў_, --, 
   {{0xa408009e,0xe814166d,0x4a74009f,0x00000000}},	//   লভ্য_, _डाटा_, _اُڳر, --, 
   {{0x383005a9,0x00000000,0x00000000,0x00000000}},	//   _زىلز, --, --, --, 
   {{0x026800d6,0x855419b6,0x5fa42ce6,0x3e6c0166}},	//   рший_, _وخاط, _गुगल, _tüti_, 
   {{0x3a3423e4,0x8cd46b9b,0x2c7c0419,0x00000000}},	//   חרים_, _मंगो, _zíde_, --, 
   {{0xc1e001ec,0x00000000,0x00000000,0x00000000}},	//   _ﺍﺯﺩﺍ, --, --, --, 
   {{0xbc3803e6,0x00000000,0x00000000,0x00000000}},	//   یسرا_, --, --, --, 
   {{0x2ab40209,0xf77d85e6,0x2f1001a8,0x8174014b}},	//   bäbi_, _üçe_, _sögð_, _малӣ_, 
   {{0x9f59bc2c,0x53840023,0xb3240327,0x12a8007b}},	//   masí_, _ክትዓት_, _ཡཱོང_, _ادنى_, 
   {{0x69d80006,0x9b8800c6,0x9f59bc2d,0x00000000}},	//   žvel, منزل_, lasí_, --, 
   {{0x6d480267,0x5b15bc2e,0x7e280816,0x00000000}},	// [30d50] ådar, ямат, _кіна_, --, 
   {{0x2eb801d9,0x00000000,0x00000000,0x00000000}},	//   _وَٹھ_, --, --, --, 
   {{0x99840032,0x78a8017a,0xdef802dd,0xf1dc01ad}},	//   чтаһ, togv, _тық_, पुटन, 
   {{0xc0b8001f,0x9b600131,0x6d580306,0xf8040212}},	//   _ተማሪ_, _كۆزۈ, _švag, ічен, 
   {{0xbda4004b,0x78a8a745,0x8cb8687b,0x00000000}},	//   _دحکو, rogv, ्षरो, --, 
   {{0x7c2800df,0x9aa4b823,0x61e40166,0x00000000}},	//   ĵgru, _رمزو, _şiln, --, 
   {{0xe610038b,0x929c0210,0x00000000,0x00000000}},	//   ئشه_, jsła, --, --, 
   {{0xf7700451,0x6a600139,0x00000000,0x00000000}},	//   _ٺار_, _söfx, --, --, 
   {{0xf770e4c4,0x636402b5,0x00000000,0x00000000}},	//   _غار_, _nōnā, --, --, 
   {{0x36a00075,0xf674f6c2,0xbeb80200,0x726400db}},	//   _تەتق, _بارخ, ftëm, تەتق_, 
   {{0x27e05946,0xb44401c4,0x00000000,0x00000000}},	//   žine_, _мэдк, --, --, 
   {{0x504400a8,0xbeb801c7,0x69d805c7,0x1af00011}},	//   чемб, stël, ñvez, _চিনে_, 
   {{0xefcc02d3,0xe80c0490,0x5274611f,0x8c4405a2}},	//   በርዎ_, हणता_, _нуку, үеге, 
   {{0xe2a801d9,0x7c2d2050,0xe374008e,0x13a800e5}},	//   _واون_, _abcr, _юлчы, _پنڈی_, 
   {{0x3ea005f5,0xbea1bc2f,0xddc400d0,0x00000000}},	//   хирг, харк, _jahň, --, 
   {{0x6ac4d013,0x8fa400d4,0x9c5800cf,0x00000000}},	//   वग्र, _найе, ошуу_, --, 
   {{0x3ae800dd,0x7c2c00e4,0x8e540212,0xc6040154}},	// [30d60] مبلی_, _dbcr, _етні, ল্টা_, 
   {{0x2fc0014b,0xbfc00166,0x2bfc00eb,0x00000000}},	//   _izig_, _ябык, ইলেই_, --, 
   {{0xb9e404a9,0x8d744e77,0x7af80327,0x00000000}},	//   ستلۇ, _رادا, _ħute, --, 
   {{0x38c84c12,0x667403e6,0x54e40150,0x00000000}},	//   مانی_, ژگار, _ﺍﺨﺘﻼ, --, 
   {{0x9f5800e4,0x25d80352,0x00000000,0x00000000}},	//   masã_, омлы_, --, --, 
   {{0xd6d800d6,0x6b84f454,0x929c012d,0x98b00210}},	//   іті_, mzig, ysła, _mszę_, 
   {{0x6b849584,0x61e40139,0x00000000,0x00000000}},	//   lzig, _şilo, --, --, 
   {{0x39980302,0xd24cb4d5,0x3e6ce263,0xff5c011f}},	//   _הילד, یۆن_, _hütt_, yxî_, 
   {{0x6b85bc30,0x2fc00083,0xc76402dd,0x3e6c0037}},	//   nzig, _nzig_, _عارى, _kütt_, 
   {{0xd24c3baf,0x6b84c304,0xd4980137,0x00000000}},	//   لچى_, izig, йрө_, --, 
   {{0xd62426c0,0x2b8c01fb,0x06cc01ec,0x00000000}},	//   _تعقي, ếch_, _ﺗﻮﺳﻪ, --, 
   {{0x636402b1,0xbeb8036e,0x5f9401f0,0xcbbc190c}},	//   _pōnā, rtëm, димт, ्धाञ, 
   {{0x6b840936,0xbeb804c4,0x69cc0073,0x9f582e85}},	//   jzig, stëm, थेती, pasí_, 
   {{0x6b85bc31,0x7c2c037e,0x00000000,0x00000000}},	//   dzig, _sbcr, --, --, 
   {{0xeda40212,0xb2b8011a,0x00000000,0x00000000}},	//   ешто, _המגר, --, --, 
   {{0x30a40953,0x5cb80006,0x9b4401e2,0x00000000}},	//   _прыв, ілаў_, ونزو, --, 
   {{0x44f802b5,0x7c2db36e,0x53840023,0x7de5786c}},	// [30d70] hū_, _vbcr, _ክድዓት_, _нінд, 
   {{0x44f8170b,0x00000000,0x00000000,0x00000000}},	//   kū_, --, --, --, 
   {{0x6b8404ba,0x951400b8,0x8cd4012d,0xeab0007b}},	//   azig, _iṅgu, _मंचो, اعق_, 
   {{0x6b840112,0x61e40f77,0x00000000,0x00000000}},	//   bzig, _şill, --, --, 
   {{0x9f580ffb,0xf7280006,0xe57801ec,0x00000000}},	//   nasà_, сцей_, үзі_, --, 
   {{0x67d40408,0x00000000,0x00000000,0x00000000}},	//   хочу, --, --, --, 
   {{0xa93568e2,0x00000000,0x00000000,0x00000000}},	//   _перш, --, --, --, 
   {{0xb4b477d7,0x4730008e,0x00000000,0x00000000}},	//   छते_, хнәс, --, --, 
   {{0xf67400fd,0xc444158b,0x923854d9,0xda000037}},	//   _нәкъ_, بینن_, очну_, _लजात_, 
   {{0xd6d00244,0x3e6c0037,0x00000000,0x00000000}},	//   _شقا_, _müts_, --, --, 
   {{0x10a5bc32,0x6b850416,0x04780014,0x2c7c01ef}},	//   динн, zzig, _ڈلٕک_, _lída_, 
   {{0x39400789,0x951400dc,0x96e000bc,0x674802d2}},	//   _msjs_, _aṅgu, _पढाउ, _ósjú, 
   {{0xddc401ef,0x00000000,0x00000000,0x00000000}},	//   _bohů, --, --, --, 
   {{0xf2c5bc33,0x39804be7,0x6b84003e,0x00000000}},	//   _эсен, ቨርስቲ_, vzig, --, 
   {{0x6d580e3c,0x2c7c0615,0x69d80010,0x504400db}},	//   _švab, _aída_, žvek, _жейб, 
   {{0x6b85bc34,0xf1a43c5b,0x2c7d9bf2,0xae2002e5}},	//   tzig, _واژه_, _bída_, _बावन_, 
   {{0x6b85bc35,0xfc3c01e1,0x9f580ffb,0x3e6c0254}},	// [30d80] uzig, _akís_, casà_, _pütt_, 
   {{0xfbc02c1d,0x3a200161,0x6b85bc36,0x8cbc033f}},	//   тбуо, _ccjp_, rzig, _वीरो, 
   {{0x6e3dbc37,0x2ee1bc38,0xccc4023a,0x6b8401ed}},	//   merb, _ভবিষ, _обой, szig, 
   {{0x1cbc038f,0x2ee00b4f,0x6b840112,0x86b00133}},	//   _ཆེར_, _kuif_, pzig, چیرڤ, 
   {{0x07388fcb,0x2ee1bc39,0x3b800276,0x5b340276}},	//   تساب_, _juif_, _аляг, _пэру, 
   {{0x44f80053,0xea0001fb,0x00000000,0x00000000}},	//   tū_, _đặn_, --, --, 
   {{0x69dc0a62,0x2ee00493,0x6e3c0036,0xb5c40014}},	//   _igre, _luif_, ierb, ٘ووم_, 
   {{0x44f81d86,0x442001d3,0x43080108,0x00000000}},	//   rū_, ük_, охом_, --, 
   {{0x2ee00194,0x2b40020c,0x68fc0142,0x9f5800d7}},	//   _nuif_, nwic_, _hwrd, kasá_, 
   {{0x44f94345,0x6e3c4bdf,0xc0e40220,0x00000000}},	//   pū_, jerb, _ﺍﻟﻭﻗ, --, 
   {{0x01880b32,0xa1591421,0xc88003b9,0xbeb8036e}},	//   ющий_, чану_, _aişə_, stëk, 
   {{0x1c1c12eb,0x68fc015d,0x646002f0,0x00000000}},	//   _फाइल_, _mwrd, ávič, --, 
   {{0x69ddbc3a,0x6e3dbc3b,0x2ee00204,0xf4842263}},	//   _ogre, ferb, _cuif_, _تالی, 
   {{0x69ddbc3c,0x2ee01a7c,0x9f591cdd,0x66c401e1}},	//   _ngre, _duif_, rasà_, bòke, 
   {{0x3e6c04cc,0x71400022,0xaed5992a,0x2c7c56fa}},	//   _süts_, _ахыж, торш, _sída_, 
   {{0x69dcfc8d,0x6e3c0395,0x3e6c04cc,0x2ee001a4}},	//   _agre, aerb, _püts_, _fuif_, 
   {{0x3ec5146e,0x7d041f06,0xab95bc3d,0x2ee0007c}},	// [30d90] _особ, ssjs, ватљ, _guif_, 
   {{0x68fc00a9,0x1a64141d,0x61fc01a9,0x00000000}},	//   _bwrd, ریزی_, аrli, --, 
   {{0x68fc0368,0xdd942519,0x00000000,0x00000000}},	//   _cwrd, _чаны, --, --, 
   {{0x69ddbc3e,0xb8e408e9,0x929c033f,0x4dc400fb}},	//   _egre, _उठ_, ysło, _ярыҡ, 
   {{0x0ba400c7,0x56940111,0x00000000,0x00000000}},	//   _зырҭ, надт, --, --, 
   {{0x68fc0368,0xb4b400dc,0x8af8011a,0xe6880116}},	//   _fwrd, छत्_, _מהשי, وننى_, 
   {{0xf99001d9,0x1cdc025c,0x68fc0368,0xd8880583}},	//   _شبس_, _ཤངས_, _gwrd, _ٹھان_, 
   {{0x93444ced,0x1cbc08ea,0x69dc0219,0xbeb80036}},	//   ение, _ཆེས_, _zgre, luëd, 
   {{0x76400022,0xae2017cb,0x1c1c28a2,0x00000000}},	//   _аҭла, _बालन_, _फाईल_, --, 
   {{0x2ee0039a,0x06e403d4,0x42c401c6,0x6e3c007c}},	//   _ruif_, _নিচি, нгын_, xerb, 
   {{0x387c03a2,0x6e3c1486,0xc0c802d3,0x2ee133ba}},	//   _klur_, verb, በጽሕ_, _suif_, 
   {{0x6e3c09a4,0xd96c00b5,0xc950008f,0xb62001ec}},	//   werb, _mﾌ_, אמט_, _ﯩﻦ_, 
   {{0x24180212,0x48e4000d,0x087400df,0x00000000}},	//   _цією_, _जूनो_, גערט_, --, 
   {{0x6e3dbc3f,0x387c00cf,0x00000000,0x00000000}},	//   uerb, _llur_, --, --, 
   {{0x387c0baf,0x2ee0017a,0x06e400fe,0x7e9401d5}},	//   _olur_, _wuif_, _নিছি, رنفر_, 
   {{0x2d5c1682,0x69ddbc40,0xfc3c02d2,0x00000000}},	//   _ṋee_, _sgre, _skír_, --, 
   {{0xa8240133,0x00000000,0x00000000,0x00000000}},	// [30da0] ێکرن, --, --, --, 
   {{0x387d15ca,0xac09025d,0x2d8c0789,0xba200137}},	//   _alur_, янға_, údes_, лдук, 
   {{0x387dbc41,0x69dc007c,0x61e40139,0x00000000}},	//   _blur_, _vgre, _şilk, --, 
   {{0xe704034d,0x07a454f9,0x00000000,0x00000000}},	//   نستی, наен, --, --, 
   {{0x941c013f,0x387c003e,0x46f402e8,0x00e40220}},	//   _nkwɑ_, _dlur_, хчет, _ﺍﻟﺤﻘ, 
   {{0x387dbc42,0x6595bc43,0x8cb93f6b,0x7af80166}},	//   _elur_, калу, ्षको, _çuta, 
   {{0x2ca1bc44,0x387cf178,0xfaa11fc9,0x7c2c007b}},	//   onid_, _flur_, _саро, _éirí, 
   {{0x2ca1bc45,0xf514167e,0x5ef400dc,0x387c045a}},	//   nnid_, رتىش_, ्ठम्_, _glur_, 
   {{0x46a405f5,0x2ca1bc46,0x04c801d3,0x00000000}},	//   _заав, inid_, _ہوئي_, --, 
   {{0x2c7c2b76,0x2ca0007b,0x684401e0,0x2bb80073}},	//   _oído_, hnid_, _янға, _आडना, 
   {{0xd58404d3,0x940c013f,0xc51416ac,0xbeb8036e}},	//   _لێوه_, nneɛ_, _سبات, otëv, 
   {{0xbeb802d3,0x3998010f,0x00000000,0x00000000}},	//   ntëv, לייד, --, --, 
   {{0x442443d6,0xfeb800c6,0xbeb80200,0x00000000}},	//   _ico_, كاست_, itëv, --, 
   {{0x2ca12d09,0x00000000,0x00000000,0x00000000}},	//   enid_, --, --, --, 
   {{0xc0c80023,0xbeb8036e,0x00000000,0x00000000}},	//   በጽሑ_, ktëv, --, --, 
   {{0x31b805d0,0xbeb80200,0x00000000,0x00000000}},	//   _מזונ, jtëv, --, --, 
   {{0x38701ee3,0x00000000,0x00000000,0x00000000}},	// [30db0] ққат, --, --, --, 
   {{0x2ca1bc47,0xd96c00b5,0x387dbc48,0x442401e7}},	//   anid_, _pﾌ_, _slur_, _lco_, 
   {{0x4425bc49,0x387c4a1f,0xd7f05734,0x00000000}},	//   _oco_, _plur_, لكا_, --, 
   {{0x44240190,0x5bc400cf,0x9774003b,0x362001e1}},	//   _nco_, _үйүб, клеї, _ẹ̀yì, 
   {{0x477000d1,0x03940171,0xc2880240,0x00000000}},	//   ақту, _šūnā_, _ንጥቕሚ_, --, 
   {{0xbeb80240,0x7c3c03e3,0x00000000,0x00000000}},	//   atëv, leqr, --, --, 
   {{0x442401ee,0x06cc02dd,0x546800db,0x199400c0}},	//   _bco_, _ﺗﻮﺗﻪ, дайм_, _равя, 
   {{0x387c02d3,0x225c009d,0xd3940032,0x48c402dd}},	//   _ulur_, _anvk_, кәлә_, _ашуғ, 
   {{0x69c802fb,0x44240129,0x57b40022,0x00000000}},	//   _úder, _dco_, _рбат, --, 
   {{0x4424cc97,0x81c800fe,0x00000000,0x00000000}},	//   _eco_, লখন_, --, --, 
   {{0x2ca00363,0xbe240154,0x00000000,0x00000000}},	//   ynid_, য়াদ_, --, --, 
   {{0x442400ae,0xf54800b8,0x66c4007f,0x7af8025c}},	//   _gco_, _iḥ_, mòka, _ħutn, 
   {{0x2ca1bc4a,0x00000000,0x00000000,0x00000000}},	//   vnid_, --, --, --, 
   {{0xaca40521,0x645c005f,0x63a40006,0xb640037e}},	//   _mmụt, ērie, _žing, _ｏｐ_, 
   {{0x2c0400d1,0x2ca00076,0x00000000,0x00000000}},	//   лүнм, tnid_, --, --, 
   {{0x2ca1bc4b,0x00000000,0x00000000,0x00000000}},	//   unid_, --, --, --, 
   {{0x7c280013,0x2ca1bc4c,0x0ea8084c,0xefe80092}},	// [30dc0] ògra, rnid_, _окий_, ማካይ_, 
   {{0x4ce4036b,0x9c8400ef,0xf5480055,0x00000000}},	//   _ижоб, _ančā, _oḥ_, --, 
   {{0xaca40521,0x2d9c0022,0x480400d4,0x00000000}},	//   _amụt, _ãve_, впев, --, 
   {{0x63a4008c,0xe7d000cd,0x00000000,0x00000000}},	//   _þing, तेऽप, --, --, 
   {{0x27e10675,0xf548002b,0xbeb80023,0xc05000df}},	//   žino_, _aḥ_, rtëv, יזא_, 
   {{0x4425bc4d,0xbeb802d3,0xca75bc4e,0x00000000}},	//   _sco_, stëv, _румы, --, 
   {{0x57b002dd,0xa2442374,0x85440006,0xc0f40023}},	//   _құшт, ۇردۇ, тэле, _ገፊሕ_, 
   {{0x44240175,0x00000000,0x00000000,0x00000000}},	//   _qco_, --, --, --, 
   {{0x225c009d,0x48e4000d,0x00000000,0x00000000}},	//   _pnvk_, _जूतो_, --, --, 
   {{0x85780798,0x2c7c0419,0xf51400db,0x00000000}},	//   _осет_, _sídl_, رتۉش_, --, 
   {{0x63a40024,0x7c3c0477,0x6d580c5e,0x00000000}},	//   _žind, yeqr, _švan, --, 
   {{0x044430ba,0x4425bc4f,0xfd10072d,0x00000000}},	//   _једн, _uco_, یجز_, --, 
   {{0x6441bc50,0x82a55aba,0x9f580267,0xadc401e1}},	//   memi, _ишке, kaså_, _ijẹu, 
   {{0xbeb801c7,0xdd9404f0,0x42500244,0x00000000}},	//   duëc, гагы, _ئۆدر, --, 
   {{0x7c3c0213,0x64400381,0x00000000,0x00000000}},	//   teqr, oemi, --, --, 
   {{0xbb5000b5,0xdd940032,0xf1a805b3,0x06b40150}},	//   _ayaの_, _ҡапы, _घुटन, _ﺸﻬﻴﺩ, 
   {{0x5a34db74,0x6b7401ea,0xbeb802d3,0x6440017a}},	// [30dd0] лнат, алту, ftët, iemi, 
   {{0xf770675b,0x7c3c0194,0xf8c80303,0x00000000}},	//   یاش_, seqr, िष्प, --, 
   {{0x6441bc51,0x3ce40356,0x5dd000fe,0x00000000}},	//   kemi, _înv_, _ত্ৰু, --, 
   {{0x28f800a8,0x6e4400e2,0x9f5800e4,0x1c1c0037}},	//   тець_, ātbū, pasä_, _फाटल_, 
   {{0x3f880007,0xfb840166,0x00e40150,0x96b800db}},	//   nzcu_, _рынн, _ﺍﻟﺴﻘ, нуку_, 
   {{0x64403a2a,0xbeb80200,0x0d480092,0x00000000}},	//   eemi, mtës, _ብልፅግ, --, 
   {{0x94780022,0xbeb80200,0x00000000,0x00000000}},	//   еспу_, ltës, --, --, 
   {{0x6441bc52,0xf1bc00bc,0xbeb80200,0x6498013d}},	//   gemi, řák_, otës, ктыр_, 
   {{0x91e501e4,0xfdbc04c5,0x67d400a8,0xbeb802d3}},	//   лопе, _আলোড, _воту, ntës, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6441bc53,0xbeb802d3,0xb5240022,0x71c001f0}},	//   bemi, htës, _шьак, ранҷ, 
   {{0x2d5c0084,0xd1740184,0xbeb83621,0x658401af}},	//   _ṋea_, _ҡыйы, ktës, _тыуз, 
   {{0xbeb8044e,0x9974033f,0x4f9404b1,0x00000000}},	//   jtës, nęła_, урну, --, 
   {{0xbeb80a40,0xa3c0012d,0x00000000,0x00000000}},	//   hrëf, ंऔर_, --, --, 
   {{0xc690008f,0x00000000,0x00000000,0x00000000}},	//   זאם_, --, --, --, 
   {{0xbeb80023,0x00000000,0x00000000,0x00000000}},	//   ftës, --, --, --, 
   {{0x69180943,0xbeb80036,0x9974012d,0x00000000}},	// [30de0] ḓea, drëf, jęła_, --, 
   {{0xaf400092,0x00000000,0x00000000,0x00000000}},	//   ዳደረገ, --, --, --, 
   {{0x6441bc54,0xbeb894f5,0x6ca400f7,0x8294010f}},	//   yemi, atës, _ۅلگۅ, נדעס_, 
   {{0xbeb80221,0x6440005a,0x6d40054e,0xacb400d1}},	//   grëf, xemi, ămad, _ئەرب, 
   {{0x6441bc55,0xb8e87f1a,0x00000000,0x00000000}},	//   vemi, _री_, --, --, 
   {{0xbeb80240,0x7fd400df,0x09f800ae,0x00000000}},	//   ltër, אונס_, _سفرة_, --, 
   {{0x6441bc56,0xe3e800f2,0x290c0241,0x00000000}},	//   temi, نکشن_, _ìda_, --, 
   {{0x64400270,0xe31406ed,0x647400c7,0x00000000}},	//   uemi, амињ, ргиу, --, 
   {{0x850404d3,0x6d582625,0x07a400db,0x638800c0}},	//   _ڕوان, _šval, _саан, kūnū, 
   {{0x86c400c6,0xbeb8036e,0x85540345,0x00000000}},	//   _صيان, htër, _میتر_, --, 
   {{0x6441bc57,0x00000000,0x00000000,0x00000000}},	//   pemi, --, --, --, 
   {{0xf99006a9,0xdfd5bc58,0x44e80428,0x9f58007b}},	//   מרת_, ионы, _iù_, masú_, 
   {{0x44e9bc59,0xf484066d,0x6f85569a,0xe3d80022}},	//   _hù_, _حالی, бурж, _рыжә_, 
   {{0x44e80cad,0x00000000,0x00000000,0x00000000}},	//   _kù_, --, --, --, 
   {{0x44e80570,0x5a5c001f,0xbeb802d3,0x6d5801a8}},	//   _jù_, _ለማሻሻ, ftër, _ával, 
   {{0x44e8dd87,0x1f742dc1,0x6ce40220,0x3b640395}},	//   _mù_, _влия, сіре, лъзв, 
   {{0x44e80ca8,0x00000000,0x00000000,0x00000000}},	// [30df0] _lù_, --, --, --, 
   {{0x44e9bc5a,0x1959bc5b,0xba75bc5c,0xbeb802d3}},	//   _où_, казы_, دارت, rtës, 
   {{0x60cdbc5d,0x81b400bd,0xbeb9b3af,0x2aa9ab13}},	//   _kham, চের_, stës, утто_, 
   {{0xbeb8a814,0x60cc0055,0x2c7c0332,0x18680114}},	//   ptës, _jham, _nídh_, ђали_, 
   {{0x60cdbc5e,0x44e8026c,0xd6d411dc,0xe75802bf}},	//   _mham, _aù_, ажды, лиці_, 
   {{0x44e8dd87,0x26cc0200,0x98c40e2d,0x00000000}},	//   _bù_, _chdo_, ıtır_, --, 
   {{0x44e80ba3,0x9f59bc5f,0x60cdbc60,0xbf98002d}},	//   _cù_, tasû_, _oham, lbêd, 
   {{0x44e9bc61,0x60cc05b8,0x628802f6,0x00000000}},	//   _dù_, _nham, ehdo, --, 
   {{0x78b9bc62,0xc48000d6,0x32c8003b,0x52a80063}},	//   _ikuv, ільк, høye_, квим_, 
   {{0xa7741de1,0x44e80c95,0x32c80fac,0xd37800db}},	//   _улуч, _fù_, køye_, ечү_, 
   {{0x764025ca,0x60cdbc63,0x42c45ce3,0x44e8c50e}},	//   meny, _bham, ргэн_, _gù_, 
   {{0x7641bc64,0x236005be,0x7521bc65,0x62880009}},	//   leny, _šije_, munz, ahdo, 
   {{0x60cdbc66,0x44e819f5,0x81b4009e,0x7521bc67}},	//   _dham, _zù_, চেল_, lunz, 
   {{0x7641bc68,0x60cc0912,0x26cc0200,0x00000000}},	//   neny, _eham, _xhdo_, --, 
   {{0x7521bc69,0x60cc0084,0x78b80c8a,0x44e801fb}},	//   nunz, _fham, _okuv, _xù_, 
   {{0x60cdbc6a,0x78b80223,0x320406d9,0x3ce802fb}},	//   _gham, _nkuv, _heny_, _živí_, 
   {{0x7641bc6b,0x75214981,0x4e1834d8,0xbeb802d3}},	// [30e00] keny, hunz, _июня_, rtër, 
   {{0x7521bc6c,0x2fc0020c,0xda7802bf,0xff7808a8}},	//   kunz, _iyig_, ляє_, _סטימ, 
   {{0x2bb80c2e,0x9cb80156,0x7641bc6d,0x3204cf77}},	//   _आडवा, _དེཝས, deny, _meny_, 
   {{0x6f05bc6e,0x38c9bc6f,0x60cdbc70,0x6288069c}},	//   _kwic, نانی_, _xham, zhdo, 
   {{0x44e9bc71,0x7641bc72,0x09e40845,0x864412e7}},	//   _sù_, feny, _вогн, индж, 
   {{0x7521bc73,0x7641bc74,0x78b83e6e,0x6f0401b2}},	//   funz, geny, _ekuv, _mwic, 
   {{0x6d59bc75,0x7521bc76,0x00000000,0x00000000}},	//   _švaj, gunz, --, --, 
   {{0x6f040004,0xf9f0031c,0x44e8004d,0x84740092}},	//   _owic, _བཅོན_, _vù_, ራችሁን_, 
   {{0x60cdbc77,0x7641bc78,0x3205bc79,0x38680ba1}},	//   _rham, beny, _beny_, _òcra_, 
   {{0x32049637,0x44e9bc7a,0x7641bc7b,0x7521bc7c}},	//   _ceny_, _tù_, ceny, bunz, 
   {{0x60cd02b5,0x68e1bc7d,0x6f040589,0x2fc0022e}},	//   _pham, _kimd, _awic, _ayig_, 
   {{0x68e1bc7e,0x6f04bf65,0x66080c09,0x60cc0472}},	//   _jimd, _bwic, _hedk, _qham, 
   {{0x60cc0084,0x3204a00c,0x68e0025c,0x2fc00142}},	//   _vham, _feny_, _mimd, _cyig_, 
   {{0x68e1bc7f,0xeea8040e,0x66080010,0xb278030d}},	//   _limd, атск_, _jedk, _илчĕ_, 
   {{0x60cdbc80,0xbc0463e8,0x62980af2,0xa1140fb4}},	//   _tham, ичай, _imvo, _اوبت, 
   {{0x60cd1022,0x7641bc81,0x68e0013b,0x32040f91}},	//   _uham, zeny, _nimd, _zeny_, 
   {{0x75200bd7,0xfbd00b28,0x6f04852a,0x00000000}},	// [30e10] zunz, زتر_, _gwic, --, 
   {{0x764070d0,0x20080421,0x78b86c3c,0x68e00254}},	//   xeny, _heai_, _skuv, _aimd, 
   {{0x6f05bc82,0xbeb8044e,0x20080270,0x27e40263}},	//   _zwic, rrëd, _keai_, _bgmn_, 
   {{0x7641bc83,0x68e1bc84,0x6608005a,0xaf0801d5}},	//   weny, _cimd, _aedk, _حقیم_, 
   {{0x7641bc85,0x62980f49,0x6609bc86,0x752012c5}},	//   teny, _omvo, _bedk, wunz, 
   {{0x7521312c,0x20082f06,0x764000ad,0x7af8031c}},	//   tunz, _leai_, ueny, _ħuth, 
   {{0x3205bc87,0xdeb802d3,0x66093ec2,0x645c00e2}},	//   _reny_, ዲምና_, _dedk, ērin, 
   {{0x7521bc88,0x68e002d5,0xdb1cfb19,0x2008014a}},	//   runz, _gimd, _aysé, _neai_, 
   {{0x75205975,0x76400e8a,0x3205bc89,0x00000000}},	//   sunz, peny, _peny_, --, 
   {{0x7521955b,0x20080418,0x6f040223,0x53a41621}},	//   punz, _aeai_, _rwic, _қалб, 
   {{0x6f05bc8a,0x555400aa,0x200804cc,0xd009bc8b}},	//   _swic, _دپار, _beai_, лене_, 
   {{0x20080276,0x62980dd4,0x10a43500,0xae20000d}},	//   _ceai_, _emvo, симн, _बाङन_, 
   {{0x3204325f,0x20080810,0x236816cc,0x00000000}},	//   _teny_, _deai_, _نحوي_, --, 
   {{0x81b4045e,0x200801ab,0x91e40166,0x65840142}},	//   চেই_, _eeai_, _уоке, _âthî, 
   {{0x2009bc8c,0xbeb8036e,0x00000000,0x00000000}},	//   _feai_, rtëp, --, --, 
   {{0x27e00f03,0xf9f0031c,0x6f040c18,0xbeb91e81}},	//   žini_, _བཅུན_, _twic, stëp, 
   {{0x6f040526,0x68e05063,0xc4d0011a,0x00000000}},	// [30e20] _uwic, _rimd, לגל_, --, 
   {{0x68e1bc8d,0x34d0068f,0xbeb80036,0xab2860c6}},	//   _simd, दगुद, trëe, лоға_, 
   {{0x6608151c,0x68e0014f,0x8c44d29c,0x00000000}},	//   _redk, _pimd, _лене, --, 
   {{0x0ae8cbdb,0x68e00477,0x66089e63,0xbeb80036}},	//   _مرسي_, _qimd, _sedk, huël, 
   {{0xf76c9e24,0xd6d005ac,0x660800c0,0x00000000}},	//   فاو_, াদনয, _pedk, --, 
   {{0x24f8004e,0x00000000,0x00000000,0x00000000}},	//   анкы_, --, --, --, 
   {{0x66080e38,0x0cb8009e,0xdab40132,0x00000000}},	//   _vedk, ংগীত, _بۇلت_, --, 
   {{0x66094b40,0xa2f410d9,0x00000000,0x00000000}},	//   _wedk, опич, --, --, 
   {{0xf3ec00c6,0x660801ef,0x00000000,0x00000000}},	//   رأي_, _tedk, --, --, 
   {{0x20080607,0xcfcc015b,0x3f8c0022,0x6114033a}},	//   _seai_, রখান, _ýgui_, одоу, 
   {{0x3ab80bd9,0x20080270,0x24940050,0x32b4009d}},	//   רמינ, _peai_, _وۅتھ_, сгээ_, 
   {{0x9f480418,0x69a00037,0x00000000,0x00000000}},	//   _afaá_, _गइनी, --, --, 
   {{0x34b401f7,0x00000000,0x00000000,0x00000000}},	//   _اهنج_, --, --, --, 
   {{0x62980472,0xbeb801c7,0x00000000,0x00000000}},	//   _umvo, drëc, --, --, 
   {{0x1cbc1efe,0x20080356,0x6e9401a9,0xf1c00150}},	//   _ཆེད_, _teai_, чиру, _ﺭﺍﻓﻘ, 
   {{0x32c803cd,0x09e40154,0xdbf001ef,0x395c01ef}},	//   møya_, _পড়লা, _třío, _čus_, 
   {{0x32c8143a,0xd9540092,0x00000000,0x00000000}},	// [30e30] løya_, _የሚዘጋ, --, --, 
   {{0x2eb42dde,0x00000000,0x00000000,0x00000000}},	//   ंकृत, --, --, --, 
   {{0x32c82dba,0x00000000,0x00000000,0x00000000}},	//   nøya_, --, --, --, 
   {{0xbeb9bc8e,0xed880228,0xe9d016ac,0x2c7c01ef}},	//   zuël, _ысык_, رغل_, _bídu_, 
   {{0x0ba400c7,0xd5e5bc8f,0x97c401e0,0x38c80330}},	//   _дырҭ, ожли, әйһе, ناچی_, 
   {{0x32c80217,0xfdf807f7,0x6d580153,0x00000000}},	//   køya_, ्रिस_, _švai, --, 
   {{0x20c80574,0x32c80158,0xb7b800eb,0x00000000}},	//   रताध, jøya_, েশেয়, --, 
   {{0x236005be,0x32c82dba,0xf1c000bc,0xf77001d9}},	//   _šija_, døya_, _liší_, _ٹار_, 
   {{0x1cbd6215,0xf77001d9,0x7c2c1590,0x2d8c21fc}},	//   _ཆེན_, _عار_, _mccr, údez_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x63a40008,0x32c80158,0x13f402d5,0x85540014}},	//   _þinn, gøya_, _дзея, _ویٖر_, 
   {{0x61fc7230,0x7c2c0332,0xe3b000f1,0x00000000}},	//   ırla, _nccr, _ګرم_, --, 
   {{0x5274b8d3,0x00000000,0x00000000,0x00000000}},	//   _муку, --, --, --, 
   {{0x0eb9219a,0xb8c80156,0x2eb4a71d,0x69c80b34}},	//   румы_, _པམ_, ंकेत, _ødeg, 
   {{0xe7fc0316,0x00000000,0x00000000,0x00000000}},	//   उँमा_, --, --, --, 
   {{0x951400cd,0x81400014,0x217440f8,0x45d400d1}},	//   _aṅku, _کھیم, _хушр, ﻟﯘﻟﻼ, 
   {{0xe0840150,0x00000000,0x00000000,0x00000000}},	// [30e40] _ءجىي, --, --, --, 
   {{0x768c143a,0xbeb80036,0x00000000,0x00000000}},	//   _høyf, rrëc, --, --, 
   {{0x1cbc0dd4,0x02b4008f,0x2c7c0162,0x00000000}},	//   _ཆེཝ_, קלעך_, _sídu_, --, 
   {{0xbeb801c7,0x281400db,0x00000000,0x00000000}},	//   prëc, سوتس, --, --, 
   {{0xdbe0006a,0x052400bd,0xbf980165,0xc669bc90}},	//   _sïök, _মনের_, laêr, ишке_, 
   {{0x05741074,0x63a40953,0x691806d6,0x2ca0b3cd}},	//   قاعد, _žino, ṋek, liid_, 
   {{0xa3dc0882,0x38c80214,0x2418010b,0x00000000}},	//   णेन_, _چاقی_, бойы_, --, 
   {{0x7d78008f,0x32c800cc,0x2a792aa7,0x2ca0641b}},	//   ינצו, vøya_, _horb_, niid_, 
   {{0x2a78d6d1,0x46a401c0,0xaa500092,0x00000000}},	//   _korb_, _даав, _የማስፋ, --, 
   {{0x2ca001d9,0x7620013e,0x32c82d8b,0x6840032e}},	//   hiid_, _омуз, tøya_, _fádæ, 
   {{0x00e401ec,0xe2980022,0x8024009a,0xc0c80108}},	//   _ﺍﻟﺒﻘ, иаҩ_, يرحم, иуме_, 
   {{0x27e0098d,0x32c84673,0x2ca00067,0xdb2000e5}},	//   žinu_, røya_, jiid_, őtér, 
   {{0x2ca001d9,0x7e7401c4,0x32c808fb,0xfeb800f2}},	//   diid_, _poxp, søya_, لاست_, 
   {{0x32c80158,0x46c800bc,0x6d400356,0x382c0092}},	//   pøya_, ितिह, ăman, ተሳሰብ, 
   {{0x91c00316,0x7e74feba,0x2ca00009,0x0f30015e}},	//   _रुपै, _voxp, fiid_, وکید, 
   {{0x9f600311,0xd1c801c8,0xec68004e,0x00000000}},	//   ăpân_, _ابهم_, орук_, --, 
   {{0x7de4005e,0x2a79bc91,0x291d1966,0x46c818cc}},	// [30e50] _мінд, _borb_, ávan_, िताह, 
   {{0x2a78004e,0x1cbc025c,0xf9c435dd,0x00000000}},	//   _corb_, _ཆེམ_, ощен, --, 
   {{0x2ca0208d,0x768c1445,0x645c00e2,0x00000000}},	//   biid_, _høyg, ērij, --, 
   {{0x2ca00050,0x00000000,0x00000000,0x00000000}},	//   ciid_, --, --, --, 
   {{0x2a781924,0xfc3c0248,0x00000000,0x00000000}},	//   _forb_, _ibí_, --, --, 
   {{0x4624031c,0x00000000,0x00000000,0x00000000}},	//   _རྐྱས_, --, --, --, 
   {{0xe9180212,0x6934014b,0x00000000,0x00000000}},	//   _морі_, _онру, --, --, 
   {{0x13080212,0x1994014b,0xd8a8009f,0x00000000}},	//   бний_, _даҳя, _اهرو_, --, 
   {{0x78a80369,0xfc3c01e7,0x00000000,0x00000000}},	//   mngv, _mbí_, --, --, 
   {{0x2a780003,0x2ca00009,0xdc280051,0x00000000}},	//   _xorb_, ziid_, _môđu, --, 
   {{0xe3b06aef,0x78a80208,0xfc3c0241,0xefe801f3}},	//   _یره_, ongv, _obí_, ማያዊ_, 
   {{0x768c2d8b,0x68e80ffb,0xa52400d3,0x2c7c013a}},	//   _bøyg, _èdde, _імід, _lídr_, 
   {{0xb4b40574,0x78a802d0,0x00e40150,0x2ca00254}},	//   चकी_, ingv, _ﺍﻟﺜﻘ, viid_, 
   {{0xfc3dbc92,0x2ca0002d,0x63800022,0xb4b4009f}},	//   _abí_, wiid_, _рҳьа, _اُچا_, 
   {{0x2ca00a85,0xd7e400ec,0x00000000,0x00000000}},	//   tiid_, _ڄڃ_, --, --, 
   {{0x768ce73f,0x2a79bc93,0xbf9800d8,0x00000000}},	//   _høyd, _sorb_, mbên, --, 
   {{0x2ca1bc94,0x8b240153,0xdb0c01e1,0x0eb80064}},	// [30e60] riid_, ядае, _ìkìj, _гуны_, 
   {{0x39400263,0xfc3c0248,0x2ca1bc95,0x4fc00150}},	//   _bpjs_, _ebí_, siid_, _يەگە, 
   {{0x6adc0073,0xc8c80014,0x7e78011a,0xcc881e4b}},	//   _बळीर, ٕوان_, _האיז, _هنده_, 
   {{0x2d5c1682,0x9f580789,0x6d5c01a4,0xddc4013a}},	//   _ṋei_, casó_, mvra, _nahř, 
   {{0x27e0049b,0x6d5dbc96,0x2a780010,0x38c86646}},	//   äin_, lvra, _torb_, حالی_, 
   {{0x768c2d8b,0xd68801e4,0x78a80051,0x00000000}},	//   _nøyd, _speϲ, angv, --, 
   {{0x35640323,0x6d5dbc97,0x7520019f,0xa4d8187a}},	//   зрын_, nvra, grnz, одку_, 
   {{0x29180158,0x761400d1,0x6d5c0037,0x00000000}},	//   _ivra_, ققۇز_, ivra, --, 
   {{0x768c003b,0xbeb801c7,0x00e402dd,0x00000000}},	//   _bøyd, drën, _ﺍﻟﺘﻘ, --, 
   {{0x4abc1d03,0xb6a00276,0xb6000030,0x6d5c0373}},	//   ्तिव, _зиул, ášto, kvra, 
   {{0x768c0183,0xbf98025a,0x0444470c,0xbeb804e6}},	//   _døyd, gbên, _нежн, frën, 
   {{0xbeb80221,0x84945668,0x00000000,0x00000000}},	//   grën, _عجائ, --, --, 
   {{0x6235bc98,0x768c2d8b,0x6d5c0549,0x9f5801d3}},	//   _желу, _føyd, evra, vasó_, 
   {{0x29181570,0x68fc00da,0xddc400bc,0xd344797d}},	//   _ovra_, _otrd, _zahř, _کییه_, 
   {{0x291c066d,0xdb1c012c,0xbeb80036,0x6d5c0b4f}},	//   ával_, _vysí, brën, gvra, 
   {{0xb4f80a1e,0x00000000,0x00000000,0x00000000}},	//   מפלי, --, --, --, 
   {{0x768c00d6,0x2919bb26,0xd05403b9,0xe810012d}},	// [30e70] _høye, _avra_, _niyə, ारना_, 
   {{0x3f4c031c,0x768c03cd,0x00000000,0x00000000}},	//   _iżu_, _køye, --, --, 
   {{0x37a80b8d,0x3ea00200,0xdef801ec,0x00000000}},	//   әтен_, mijt_, _уық_, --, 
   {{0x3ea001f5,0xbeb80200,0x00000000,0x00000000}},	//   lijt_, jtëz, --, --, 
   {{0x291815ed,0x768c003b,0xd05403e3,0x2d9c02d2}},	//   _evra_, _løye, _ciyə, _þver_, 
   {{0xa81803cc,0xf6280212,0xd05403b9,0x79a40798}},	//   قتۇر_, сіди_, _diyə, _ербе, 
   {{0x7aec0784,0xe611bc99,0x768c143a,0x394000d7}},	//   _huct, اشه_, _nøye, _upjs_, 
   {{0x7ae40477,0x61f80b4f,0xbc5c00b5,0x3ea001a4}},	//   _hijt, _afvl, _ｊａg_, hijt_, 
   {{0x7aec0113,0xe7840276,0x75200477,0x6e3c0142}},	//   _juct, _пуфо, srnz, yfrb, 
   {{0x7ae40455,0x768c08fb,0x7aecb3c9,0x42c4d391}},	//   _jijt, _bøye, _muct, мгын_, 
   {{0x7aedbc9a,0xbeb80023,0x7ae54cc1,0xd05406be}},	//   _luct, trën, _mijt, _ziyə, 
   {{0x67240e3c,0x7ae46687,0xd0540213,0x8fa44f54}},	//   šije, _lijt, _yiyə, даме, 
   {{0x3ea07668,0xa474004b,0xbeb8036e,0x00000000}},	//   fijt_, _سپوږ, rrën, --, 
   {{0x7ae4000f,0x768c143a,0x6d5c9b34,0x00000000}},	//   _nijt, _høyb, tvra, --, 
   {{0x7aedbc9b,0xe810038e,0xdb10025a,0x768c0fac}},	//   _auct, ारमा_, ögîg, _gøye, 
   {{0x291c0030,0x6d580010,0x00000000,0x00000000}},	//   ávam_, _švas, --, --, 
   {{0x7ae5bc9c,0x68fdbc9d,0x6d5dbc9e,0x3ea13238}},	// [30e80] _bijt, _strd, svra, bijt_, 
   {{0x7aedbc9f,0x00000000,0x00000000,0x00000000}},	//   _duct, --, --, --, 
   {{0xbeb802d3,0xdb1c0022,0x7ae5bca0,0xd0540213}},	//   ytëz, _pysã, _dijt, _siyə, 
   {{0x7aec0311,0xcb69bca1,0xb4b40864,0xf3e400ae}},	//   _fuct, _даме_, चको_, _لأ_, 
   {{0xa5f8b96f,0x81e40154,0x00000000,0x00000000}},	//   пелу_, যুপ_, --, --, 
   {{0x4f600020,0x6b8400ca,0x16140131,0xa5f80114}},	//   _ሊያደር, myig, ىسىڭ, чеку_, 
   {{0x68fc0219,0x7aec00d7,0x00000000,0x00000000}},	//   _utrd, _zuct, --, --, 
   {{0x98a00270,0x7ae401a4,0x39980375,0x066400ec}},	//   puhā_, _zijt, _וילד, _ڪارپ, 
   {{0x6b8443c4,0x768c05ac,0x409c0241,0xa2c40352}},	//   nyig, _søye, _laṣọ_, нәкк, 
   {{0xd24c1823,0x6b8404ba,0x06640137,0xdd30012d}},	//   مچى_, iyig, _تارپ, tęże, 
   {{0xaca4063f,0x60f80845,0x6b840230,0x00000000}},	//   _anọt, яння_, hyig, --, 
   {{0x768c0fac,0x42cc0154,0xcb1c0027,0x75d0009a}},	//   _vøye, রদেশ, _पिंड_, _شينا, 
   {{0xff044990,0xbeb801c7,0x291c1155,0x2be00210}},	//   ьянн, brël, ávaj_, पेमा, 
   {{0x768c08fb,0x7aec0393,0x6b840009,0x9325bca2}},	//   _tøye, _ruct, dyig, _سرهن, 
   {{0x7aedbca3,0x7ae40196,0x6d59bca4,0xb308031c}},	//   _suct, _rijt, _švar, _གསོང_, 
   {{0xdfd40220,0x7ae4002d,0x628801b9,0xbff0004e}},	//   _пойы, _sijt, lkdo, _шүмш, 
   {{0x3f4c038f,0x6b84013f,0x3ea00d27,0x7ebc012c}},	// [30e90] _użu_, gyig, pijt_, tápě, 
   {{0x7ae4014f,0x60dc4f8c,0xaab801d5,0x39a40108}},	//   _qijt, lmsm, ودلر_, мшев, 
   {{0x6b841418,0x60dc20a2,0xab280145,0x00000000}},	//   ayig, omsm, كسەل_, --, 
   {{0x7ae5bca5,0x7aedbca6,0x6b840796,0x57b404b3}},	//   _wijt, _tuct, byig, нбет, 
   {{0xb3080003,0x6d59bca7,0xfc3c01ed,0x6b85bca8}},	//   _གསེང_, _ávar, _amíg_, cyig, 
   {{0x62880d27,0xbeb80036,0x8518134e,0xd6180137}},	//   jkdo, krëm, _नटखट_, ستتا_, 
   {{0x4abcf397,0xa9c4014b,0x00000000,0x00000000}},	//   ्तरव, _астк, --, --, 
   {{0x6d5800e4,0xfafc0200,0xbeb80200,0x130800d4}},	//   _âvae, _ktë_, drëm, пний_, 
   {{0x68e80ffb,0x7c38002e,0x25840ca8,0x00000000}},	//   _èdda, _ñuru, _pèlú_, --, 
   {{0xe1f80372,0x3568010a,0x00000000,0x00000000}},	//   үгө_, _мрен_, --, --, 
   {{0x768c003b,0xb00401e0,0x00000000,0x00000000}},	//   _tøyb, конһ, --, --, 
   {{0x6289bca9,0x22800100,0x00000000,0x00000000}},	//   akdo, _bòks_, --, --, 
   {{0xdc1402f5,0x6b84058a,0x258401e1,0xe8101c5d}},	//   িলাস_, xyig, _tèlú_, ारता_, 
   {{0x523804ac,0x6b8407a8,0x6289bcaa,0x60dc0b4f}},	//   _זײַנ, vyig, ckdo, amsm, 
   {{0xfafc069c,0x7bc8097d,0x8c45bcab,0x10a4ac8a}},	//   _atë_, ügun, неве, _пикн, 
   {{0x63a402d5,0x809c012d,0xcdd400f1,0x00000000}},	//   _žini, खोदे, وېښت_, --, 
   {{0xfc3c0241,0xdd3006be,0x7c3800a2,0x00000000}},	// [30ea0] _ajís_, _təşn, _ıurt, --, 
   {{0x6b840223,0x00000000,0x00000000,0x00000000}},	//   ryig, --, --, --, 
   {{0xdb1dbcac,0x4998020f,0x3a2400c7,0x00000000}},	//   _vysá, чтая_, ónpa_, --, 
   {{0x36300131,0x00000000,0x00000000,0x00000000}},	//   ۇرىس, --, --, --, 
   {{0xe7c0000e,0x6289bcad,0x46a4c43d,0x59a4000d}},	//   েশ্য, ykdo, надв, _गेठर, 
   {{0xf64c0131,0x00000000,0x00000000,0x00000000}},	//   مئى_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfc3c00bc,0xa818009f,0x00000000,0x00000000}},	//   _ujít_, _آڪار_, --, --, 
   {{0x82a4716a,0xf5e40131,0x20d801f6,0x00000000}},	//   ешне, ммәл_, léig_, --, 
   {{0xbeb80200,0x00000000,0x00000000,0x00000000}},	//   trëm, --, --, --, 
   {{0xb8100183,0xb3705598,0xdb0c032e,0x00000000}},	//   _হাতত_, ندیش, _óhöp, --, 
   {{0x60dc03ac,0x00000000,0x00000000,0x00000000}},	//   umsm, --, --, --, 
   {{0x768c03d4,0x6d5800f3,0x61e4010f,0x25dc1fd2}},	//   _høya, _švap, _ŝild, गेरी_, 
   {{0x64400af9,0x60dc0857,0x00000000,0x00000000}},	//   lfmi, smsm, --, --, 
   {{0x20d801d3,0xfafc0200,0x69a06956,0x00000000}},	//   jéig_, _stë_, _गेली, --, 
   {{0x6ca43abd,0x93940205,0xeca400d8,0x00000000}},	//   груж, _öğür, гјун, --, 
   {{0xfaf00d28,0x7a481064,0x5a340c56,0xdd9001d5}},	// [30eb0] اثر_, зяев_, кнат, _چوخ_, 
   {{0x1bec000d,0xdea00244,0x929c0210,0x00000000}},	//   _झलकल_, _ئیسی, opła, --, 
   {{0x394400f7,0x768c03a1,0x6d5800e4,0x20d98ed8}},	//   ïns_, _nøya, _ávap, réif_, 
   {{0xe8952b0e,0x260801e4,0xa6c400d1,0x00000000}},	//   лахь, nһof_, ۇقنى, --, 
   {{0x3ce80472,0x20d800c6,0x37045211,0x00000000}},	//   _iicv_, méid_, хчев, --, 
   {{0x945c068f,0x768c05ac,0x20d800c6,0x32c803cd}},	//   końc, _bøya, léid_, røyk_, 
   {{0x25dc0dba,0xd7f400db,0x98e401af,0xb60001ef}},	//   गेली_, _азбы, _асаһ, _rváč, 
   {{0x67244beb,0x768c05ac,0xa564004b,0x20d8007b}},	//   šija, _døya, ادون, néid_, 
   {{0xd76004d3,0x13a403e6,0x660c01d3,0x18a402dd}},	//   _خۆشی, خۆشی_, élkü, _заңм, 
   {{0x387dbcae,0x20d8007b,0x644001a4,0x8784009d}},	//   _hour_, héid_, afmi, _шөхг_, 
   {{0x387c1d59,0x768c03cd,0x00000000,0x00000000}},	//   _kour_, _gøya, --, --, 
   {{0x387c2047,0xdb1c005b,0x88c40210,0x45000051}},	//   _jour_, _kysä, _gość, ữtín_, 
   {{0xa4d410f5,0x087400c8,0xb308031c,0x77ec00c5}},	//   _соці, דערט_, _གསིང_, _छलैक_, 
   {{0x387dbcaf,0x00000000,0x00000000,0x00000000}},	//   _lour_, --, --, --, 
   {{0x2d8d73a0,0x00000000,0x00000000,0x00000000}},	//   áde_, --, --, --, 
   {{0x20d800ae,0x2a6406be,0x00000000,0x00000000}},	//   géid_, _şmb_, --, --, 
   {{0x81e4015b,0x3b8001c0,0xdb1c007c,0x2d9801d3}},	// [30ec0] যুদ_, алтг, _nysä, szre_, 
   {{0x3ce800ca,0x387c0489,0x0d85bcb0,0x0e640124}},	//   _eicv_, _aour_, _алон, _ркон, 
   {{0x291c07dd,0x387c0165,0xdb1c0139,0x20d9b2b1}},	//   éva_, _bour_, _aysä, béid_, 
   {{0x387dbcb1,0x20d8007b,0xdd100432,0xab7800db}},	//   _cour_, céid_, _hüşg, _كۅزا_, 
   {{0x387d5346,0x929c0034,0xf76c02f2,0xdd100432}},	//   _dour_, zpła, قاو_, _küşg, 
   {{0xd764cdc2,0xa6340212,0x20d80036,0x36640305}},	//   انوی, ункі, méie_, качо_, 
   {{0xfaa1bcb2,0x387dbcb3,0xdd102057,0xddc403e0}},	//   _таро, _four_, _müşg, _mahş, 
   {{0xd90c04d3,0x387dbcb4,0x00000000,0x00000000}},	//   _ریه_, _gour_, --, --, 
   {{0x768c0fac,0xa3dc0073,0x0708009f,0x00000000}},	//   _iøyn, णें_, _آيئي_, --, 
   {{0x387cbff2,0x768c143a,0x00000000,0x00000000}},	//   _zour_, _høyn, --, --, 
   {{0x387c3d99,0xe135bcb5,0x20d801c7,0x661802f0}},	//   _your_, ынны, héie_, mavk, 
   {{0x63a40953,0x44304673,0x6618df3f,0x395400e4}},	//   _žinu, _øy_, lavk, _ñesũ_, 
   {{0xf484020e,0xddc49c11,0x00000000,0x00000000}},	//   _جالی, _bahş, --, --, 
   {{0x768c00cc,0x66180427,0x290c0003,0x945c0210}},	//   _løyn, navk, _ħdan_, pońc, 
   {{0xdd10371e,0xbeb801c7,0x80040137,0x929c012d}},	//   _düşg, wuës, _ичпе, jsły, 
   {{0xdb1c5522,0x00000000,0x00000000,0x00000000}},	//   _lyså, --, --, --, 
   {{0x30842781,0xfc3c45a7,0x387c062c,0x20d801e7}},	// [30ed0] _خليف, _amíc_, _rour_, réid_, 
   {{0x0af001c0,0x3ea401d3,0x387cb76c,0x66180427}},	//   сүрэ, _önt_, _sour_, javk, 
   {{0x387dbcb6,0x66180232,0x69c88784,0x20d80597}},	//   _pour_, davk, _ødel, péid_, 
   {{0xdb1c02f6,0x20d801c7,0x05b4012d,0xbbe800ae}},	//   _pysä, béie_, _अख़ब, _يرحم_, 
   {{0xc4b80c58,0x2019bcb7,0x7ac40006,0xddc403e0}},	//   ুষাঙ, iasi_, _асве, _yahş, 
   {{0x20189753,0xda0845d7,0x661800c5,0xe77801d3}},	//   hasi_, _سيره_, gavk, ئلوں_, 
   {{0x2019bcb8,0x387ce1b2,0x768c05ac,0x38c8dcc6}},	//   kasi_, _tour_, _føyn, _жуан_, 
   {{0x2019bcb9,0xe6b802e3,0x9f480332,0x00000000}},	//   jasi_, rịị_, _agaí_, --, 
   {{0x6618597f,0xd468013d,0x00000000,0x00000000}},	//   bavk, _җиле_, --, --, 
   {{0x201800a8,0xd1740cdd,0x66e4009b,0x00000000}},	//   easi_, гымы, _вођа, --, 
   {{0x2019bcba,0xb400247f,0x768c003b,0x225c01bf}},	//   fasi_, _күйд, _høyo, _davk_, 
   {{0x2019bcbb,0xf8b0033f,0xe4a400d8,0x34a8007b}},	//   gasi_, ंचिय, _крчо, _غداً_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf204524d,0xc7d40375,0x00000000,0x00000000}},	//   _рядо, טורי_, --, --, 
   {{0xddc405d1,0x5cf4a5c1,0xf8b00d79,0x333c0327}},	//   _vahş, ияту, ंचाय, ltux_, 
   {{0x2019bcbc,0x66180118,0xddc400a2,0x00000000}},	//   casi_, zavk, _wahş, --, 
   {{0x768c03d4,0xceb458c5,0x0ba81916,0x333c020c}},	// [30ee0] _røyn, _محدث, رارى_, ntux_, 
   {{0x6f05bcbd,0x78b800df,0x2d540133,0xbf980677}},	//   _itic, _ĉuva, _پێرس, _נייש, 
   {{0xe8100073,0x1ea80066,0x49b80efe,0x00000000}},	//   ारला_, _جايي_, رائد_, --, 
   {{0x69c83c02,0x881450d8,0x98c40024,0x00000000}},	//   _ødem, اباط, асіл, --, 
   {{0x7640020b,0x333c031c,0xa6c400d1,0x00000000}},	//   ffny, jtux_, ۇقچى, --, 
   {{0x2019bcbe,0xca7405f5,0xaab86a60,0xbeb80de2}},	//   zasi_, _сумы, _आदिक, rsëg, 
   {{0x2019bcbf,0x20d80998,0x768c0fac,0x2b400e21}},	//   yasi_, néic_, _tøyn, ltic_, 
   {{0x6f053314,0x768c08fb,0x00000000,0x00000000}},	//   _otic, _høyl, --, --, 
   {{0x2018080b,0x6f05bcc0,0xaa6c001f,0x2b41bcc1}},	//   vasi_, _ntic, _ለማስፋ, ntic_, 
   {{0xfafc02d3,0x73d40510,0x86e8007b,0xe7fc00bc}},	//   _orën_, ыдыр_, _أعرف_, उँका_, 
   {{0x2019bcc2,0xdb1c0a85,0x6f05bcc3,0x32600006}},	//   tasi_, _bysû, _atic, стыв, 
   {{0x6f05bcc4,0xf45401b9,0x65680067,0x8364036b}},	//   _btic, _ملمع_, _irdh, _مدتل, 
   {{0x6f040295,0x31640036,0xfafc0200,0xdc5401b9}},	//   _ctic, _ernz_, _arën_, یررک, 
   {{0xcd400075,0x6f040332,0x15e00073,0x00000000}},	//   ﺭﻧﯩﯔ_, _dtic, गेवर_, --, 
   {{0x2019bcc5,0x6f05bcc6,0x2b400f85,0x20d801e7}},	//   pasi_, _etic, etic_, réib_, 
   {{0x2019bcc7,0x2b4001fa,0x7cc400f2,0xa2d800cd}},	//   qasi_, ftic_, ازآم, _नीत्, 
   {{0x768c33b8,0xfafc0240,0xda140063,0x00000000}},	// [30ef0] _bøyl, _erën_, идањ, --, 
   {{0xdb1c00d7,0xbeb8036e,0x00000000,0x00000000}},	//   _kysú, erëv, --, --, 
   {{0x81e4015b,0x2b4024b6,0x32780055,0xbeb8036e}},	//   যুর_, atic_, _jñaṃ_, rsëd, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2b41bcc8,0x6569bcc9,0xfb84d8d1,0x6f04003e}},	//   ctic_, _ardh, _сынн, _xtic, 
   {{0x9585bcca,0xbeb80200,0x00000000,0x00000000}},	//   илле, arëv, --, --, 
   {{0x94941f71,0x291c012c,0x59b929e9,0xd574109a}},	//   ишич, ávat_, _आशिर, руль, 
   {{0x6934084c,0x32c80fac,0x888001d3,0x2c7c01ef}},	//   _ынсу, høyt_, _ویلن, _bídy_, 
   {{0x6568044e,0x67d402bf,0x768c03cd,0xa88411dc}},	//   _erdh, _готу, _høym, _القى, 
   {{0x78a8eda6,0x6f044c45,0x2d9c01d3,0xc2401b0a}},	//   ligv, _rtic, _üveg_, оньк, 
   {{0x6f042517,0x7bcc0381,0x5554004b,0xd0083efd}},	//   _stic, _lycu, _خپار, кене_, 
   {{0xd3703669,0x78a81a7c,0x2b40045a,0x4f9418cd}},	//   _وها_, nigv, ytic_, аргу, 
   {{0x333c0327,0x00000000,0x00000000,0x00000000}},	//   qtux_, --, --, --, 
   {{0x91e5bccb,0x6f04003a,0x2b4000f3,0xd1c805a2}},	//   _коле, _vtic, vtic_, _илле_, 
   {{0xc81001e1,0x00000000,0x00000000,0x00000000}},	//   _éégú, --, --, --, 
   {{0x2b41bccc,0x6f040113,0x768c08fb,0x8b241078}},	//   ttic_, _ttic, _søyl, идбе, 
   {{0x6f041467,0x78a9bccd,0x00000000,0x00000000}},	// [30f00] _utic, digv, --, --, 
   {{0x2b41bcce,0x00000000,0x00000000,0x00000000}},	//   rtic_, --, --, --, 
   {{0x2b41bccf,0x8c449c52,0xba1402dd,0x20d80120}},	//   stic_, _кене, شينا_, léia_, 
   {{0x2b41bcd0,0x7e00063f,0xc84409a5,0x00000000}},	//   ptic_, ọstu, редй, --, 
   {{0xbeb8044e,0xfc3dbcd1,0x768c33b8,0x20d80798}},	//   rrëv, _umía_, _tøyl, néia_, 
   {{0x4548003b,0x00000000,0x00000000,0x00000000}},	//   вчим_, --, --, --, 
   {{0x768c03d4,0x69d804cc,0xbeb80036,0x00000000}},	//   _gøym, üved, lsëc, --, 
   {{0x78a801e4,0x69d800e2,0xd72c01ec,0x00000000}},	//   cigv, ļved, _бiре, --, 
   {{0x07a40372,0x4638084c,0x8838001f,0x389804ae}},	//   _таан, _ачея_, _የምታደ, _סימנ, 
   {{0x20d800d8,0x3f8c00e4,0x602000e4,0x4ac4185d}},	//   déia_, _ügui_, kâmí, वविव, 
   {{0x6568044e,0x601811f4,0x00000000,0x00000000}},	//   _urdh, лоня_, --, --, 
   {{0x75d1bcd2,0xb9780375,0xbeb80221,0xdb1c00d0}},	//   _بيما, דנטי, hrët, _vysú, 
   {{0x4425bcd3,0xeccc04c5,0x32c805ac,0x14b4010f}},	//   _ido_, লগাড, tøyt_, _פּער_, 
   {{0xbeb80036,0x816801fe,0x802400f2,0x7dc400ae}},	//   dsëc, _ариб_, درگم, لتأك, 
   {{0x4424aaca,0x7cb4039b,0xf2780375,0x32c803cd}},	//   _kdo_, иқот_, _ברגש, røyt_, 
   {{0x27e00122,0x1bf402d5,0x32c803cd,0x00000000}},	//   žiny_, спаў, søyt_, --, 
   {{0x442401c8,0x6d4805d1,0x186802dd,0x20d800d8}},	// [30f10] _mdo_, çdar, ғали_, céia_, 
   {{0xd490004d,0x78a8017a,0x7bcc02f0,0x0b380014}},	//   _mùa_, wigv, _vycu, اقٕک_, 
   {{0x4425bcd4,0x60ccf0d6,0xdb1c03cd,0x78a801e4}},	//   _odo_, _kkam, _lysø, tigv, 
   {{0x4425bcd5,0xa3cc05d7,0x649c00c6,0x60cc0327}},	//   _ndo_, _शुभ_, _héif, _jkam, 
   {{0x60cc5416,0xfbd00050,0xcc7405d0,0x39a400d0}},	//   _mkam, _گتھ_, _הערה_, dísť_, 
   {{0x4425bcd6,0x2bb40d2c,0x32c805ac,0x60cc01a9}},	//   _ado_, ंपरा, høyr_, _lkam, 
   {{0x99840491,0x99e43fae,0x44241dda,0xd9e400bd}},	//   _الزو, _প্ৰক, _bdo_, _প্রম, 
   {{0xa8a43bb3,0x4424044e,0xe571092e,0x649db16a}},	//   _друк, _cdo_, بطه_, _léif, 
   {{0x4425bcd7,0xf8b001ad,0x319403b9,0x00000000}},	//   _ddo_, ंचीप, məzə_, --, 
   {{0x4425bcd8,0x81c02f8b,0xe0c800df,0x00000000}},	//   _edo_, ্ধন_, _װײ_, --, 
   {{0xb5a5bcd9,0xbeb80036,0x42c401c6,0x1ab403d4}},	//   _трай, hrës, сгэн_, _জীৱা, 
   {{0x60cc1529,0x78b804ba,0x20d80798,0x4425bcda}},	//   _ckam, _jjuv, téia_, _gdo_, 
   {{0x04740137,0xa3d40354,0x00000000,0x00000000}},	//   _دئلگ, _доцч, --, --, 
   {{0x60cc08e7,0xe3b1bcdb,0x20d80798,0x78b80267}},	//   _ekam, _ترم_, réia_, _ljuv, 
   {{0x60cc1132,0x649c0a40,0xfafc0221,0xbea02b97}},	//   _fkam, _déif, _drëm_, чарк, 
   {{0xfafc04c4,0xa92401f1,0x20d907d4,0xec3401b9}},	//   _erëm_, _úžit, péia_, تورگ, 
   {{0xc9f40597,0xbeb80221,0x8fd0e564,0xcb090323}},	// [30f20] مساع, trët, _хәнә, ايئن_, 
   {{0xe810044b,0x649c04c4,0x81401547,0x2bac0490}},	//   ार्थ_, _géif, _بچین, _घेणा, 
   {{0x78b8007c,0xbeb894f5,0x98b003e0,0x46e9bcdc}},	//   _bjuv, ssëc, _arzı_, ңден_, 
   {{0x38c976d5,0x20d8092e,0xbeb804cc,0x768c4606}},	//   هانی_, héin_, brës, _høyh, 
   {{0x649dbcdd,0x44240010,0x3e2c001f,0x78b9bcde}},	//   _héig, _rdo_, _ኤችአይ, _djuv, 
   {{0x4425bcdf,0x78b802d0,0xd5ac0014,0x697400ec}},	//   _sdo_, _ejuv, ھہن_, _وڏائ, 
   {{0x25a0008f,0x2bac0490,0xeae40abd,0xd6380212}},	//   ĝilo_, _घेता, कगीत_, рячі_, 
   {{0x69ddbce0,0x649c04c4,0x4425bce1,0x78b80158}},	//   _izre, _méig, _qdo_, _gjuv, 
   {{0x44240441,0x649c0597,0x58f4031c,0x60cc01a9}},	//   _vdo_, _léig, _བཤོས_, _rkam, 
   {{0x60cdbce2,0xd24c425b,0xe8100316,0x20d800ae}},	//   _skam, نچى_, ारका_, géin_, 
   {{0x4425bce3,0xa05402bf,0x38c801ed,0x78b800e4}},	//   _tdo_, овні, _شاہی_, _yjuv, 
   {{0x4425bce4,0xf1a1bce5,0x649c0036,0x13a803e6}},	//   _udo_, ярын, _séif, انیی_, 
   {{0x60cc0a73,0x2d8c11c0,0x32c800cc,0x7e2802d5}},	//   _vkam, øden_, røyr_, ліва_, 
   {{0x69dc0e3c,0x768c03a1,0x60dc025a,0x649c0036}},	//   _ozre, _røyk, îrmb, _béig, 
   {{0x58f40867,0xeea80138,0xd5b00051,0x60cc0055}},	//   _བཤེས_, стяк_, _lén_, _tkam, 
   {{0x60cdbce6,0xf1bc00bc,0x649c0036,0xbeb80036}},	//   _ukam, ášek_, _wéif, trës, 
   {{0xd018052f,0xbf980a85,0xfbd00d7a,0x69dc05b1}},	// [30f30] _өфө_, rbês, ستر_, _azre, 
   {{0x95282fb5,0xbeb802d3,0x9f486565,0x649c0332}},	//   _ལྷའི_, rrës, _agaç_, _héid, 
   {{0x649c0a40,0xf9697fe7,0x78b80153,0x00000000}},	//   _géig, ырай_, _pjuv, --, 
   {{0x7cec01e1,0xd7d40640,0xbeb801c7,0x00000000}},	//   _dòrì, ожењ, prës, --, 
   {{0xf1cc0c2e,0x69dc05ea,0x649c007b,0x768c0fac}},	//   _सुनन, _ezre, _méid, _høyi, 
   {{0x57a80490,0x649c01c7,0x00000000,0x00000000}},	//   _कधीह, _léid, --, --, 
   {{0x78b86afa,0xe8100490,0xa2bc3c71,0x20d800ae}},	//   _tjuv, ारखा_, षचन्, véin_, 
   {{0x649c0a40,0x64981945,0x6ee03468,0x13042c28}},	//   _néid, йтыр_, möbe, озим, 
   {{0x20d9bce7,0x667400d1,0x31b000dc,0x00000000}},	//   téin_, غدۇر, ुथ्ध, --, 
   {{0x52a800c9,0x1148084c,0xfc3c0174,0x74a800cd}},	//   рвом_, апой_, _smíl_, _जगवृ, 
   {{0x649c3a35,0x20d800ae,0x00000000,0x00000000}},	//   _béid, réin_, --, --, 
   {{0x6299bce8,0x649c007b,0x20d8003e,0x090c0154}},	//   _elvo, _réig, séin_, _হিমু_, 
   {{0x649dbce9,0x20d80036,0xd5b00208,0x0fd86135}},	//   _déid, méil_, _kéo_, рьны_, 
   {{0xfc3c66e5,0x768c2d8b,0x4d140022,0x00000000}},	//   _ací_, _bøyi, жьат, --, 
   {{0x649c06d5,0x6724003d,0xddc002dd,0x50440137}},	//   _féid, ġiji, еттi_, _дейб, 
   {{0x2fc001d4,0x672405a1,0x20d8007b,0xb324031c}},	//   _txig_, šiji, néil_, _ལྗོང_, 
   {{0x58f403bd,0x4aa8074d,0xbb4045c4,0x8b24023a}},	// [30f40] _བཤུས_, акан_, метк, юдае, 
   {{0x649c0597,0x20d800ae,0x00000000,0x00000000}},	//   _téig, héil_, --, --, 
   {{0x649c0a40,0xf1cc06ff,0x00000000,0x00000000}},	//   _héie, _सुमन, --, --, 
   {{0x649c092e,0x50c9bcea,0xdb1c0022,0x69dc0219}},	//   _kéie, रविष, _hysý, _vzre, 
   {{0xe8e001fb,0x20d8007b,0x38c804fb,0xd5b00051}},	//   hiệt_, déil_, جالی_, _béo_, 
   {{0x6d5c0354,0x81c004c5,0x649c00d8,0x7d140175}},	//   owra, ্ধত_, _méie, _ywxs, 
   {{0x649c0a40,0x69dc005f,0x20d80332,0x6d5c127b}},	//   _léie, _uzre, féil_, nwra, 
   {{0x80dc02f5,0x20d800ae,0x00000000,0x00000000}},	//   _নূন্, géil_, --, --, 
   {{0x68fdbceb,0x649dbcec,0xc76404da,0x39400477}},	//   _hurd, _réid, _بازى, _zqjs_, 
   {{0x649c00ae,0x6d5c03ac,0xfbd0011a,0x61fc022e}},	//   _séid, kwra, ותח_, оrla, 
   {{0x60c401e4,0xbeb801c7,0x0445bced,0x649c0332}},	//   _ĉimb, drëp, _межн, _péid, 
   {{0x6d5dbcee,0x40a816c3,0x649c0221,0x234804fb}},	//   dwra, ръон_, _béie, _هستی_, 
   {{0x68fc016d,0x6d5c127b,0xb5ac00eb,0xfe70691d}},	//   _lurd, ewra, _চুপচ, ودس_, 
   {{0x649c0221,0x68fdbcef,0x809c0034,0x6d5c0042}},	//   _déie, _ourd, खोजे, fwra, 
   {{0xe3b000aa,0xdce400b8,0x649c0332,0x6d5c4891}},	//   _ترڅ_, _arhā, _téid, gwra, 
   {{0x649c0a40,0xd3440133,0x00000000,0x00000000}},	//   _féie, _بییه_, --, --, 
   {{0x29180de2,0x2b4405f5,0x68fdbcf0,0x649c0036}},	// [30f50] _awra_, дэхг, _aurd, _géie, 
   {{0x68fdbcf1,0x29180142,0x768c03cd,0x6d5c0175}},	//   _burd, _bwra_, _høyv, bwra, 
   {{0x68fdbcf2,0xaee40a28,0xe9f802bf,0x20d8007b}},	//   _curd, saṃk, інці_, héim_, 
   {{0xe8f9bcf3,0x68fdbcf4,0xfe4060a1,0x649c01e7}},	//   ілі_, _durd, _эмүү, _léib, 
   {{0x68fc0042,0xf6600137,0x48c0035b,0x00000000}},	//   _eurd, делү, хәра, --, 
   {{0x68fdbcf5,0x768c03d4,0x8af80375,0x20d801e7}},	//   _furd, _løyv, _להשי, déim_, 
   {{0x68fdbcf6,0x00000000,0x00000000,0x00000000}},	//   _gurd, --, --, --, 
   {{0xe8e00051,0x00000000,0x00000000,0x00000000}},	//   việt_, --, --, --, 
   {{0x649c0036,0x68fdbcf7,0x20d801e7,0x00000000}},	//   _béib, _zurd, réil_, --, 
   {{0x68fdb740,0x6d5dbcf8,0x649db2b1,0x69e4010e}},	//   _yurd, ywra, _réie, _üweý, 
   {{0x649c04c4,0x68fc172e,0xc22000aa,0xc69008a8}},	//   _séie, _xurd, رکوو, _ראב_, 
   {{0xfafc0022,0x74f00220,0x6d5c0175,0x2d8c03cd}},	//   _erëi_, _تۋعا, vwra, ødem_, 
   {{0x3f8c003d,0xbf980120,0x768c03cd,0xbeb801c7}},	//   _żgur_, scên, _døyv, rsën, 
   {{0x649dbcf9,0x6d5c62af,0x00000000,0x00000000}},	//   _véie, twra, --, --, 
   {{0x649c0221,0xbeb80200,0x00000000,0x00000000}},	//   _wéie, rrëp, --, --, 
   {{0x6d5dbcfa,0xdd1000a2,0xd5b00051,0xaee4002b}},	//   rwra, _müňg, _ném_, daṅk, 
   {{0x68fdbcfb,0x649c04c4,0x6d5c035a,0x7d1805be}},	// [30f60] _surd, _héic, swra, ćusa, 
   {{0x68fdbcfc,0x6d5c0204,0x00000000,0x00000000}},	//   _purd, pwra, --, --, 
   {{0xfbdc0165,0x68fdbcfd,0x3ddc0198,0xc6c40220}},	//   _ezê_, _qurd, ƙuwa_, үйек, 
   {{0x68fc708a,0x649c0036,0xe85403e6,0x00000000}},	//   _vurd, _méic, بۆرد, --, 
   {{0x68fdbcfe,0x7bc8003d,0x649c7538,0x78a00ea0}},	//   _wurd, żgur, _léic, ënva, 
   {{0x7b140323,0x68fdbcff,0x3b0409ac,0x75d006be}},	//   _хоёр_, _turd, _херо_, _nәzә, 
   {{0x649c01c7,0x68fc058a,0xaee40055,0x00000000}},	//   _néic, _uurd, caṅk, --, 
   {{0x2ca1bd00,0x7de400dd,0x58f40135,0x649c0036}},	//   nhid_, lésé, _བཤགས_, _séib, 
   {{0x2ca01713,0x00000000,0x00000000,0x00000000}},	//   ihid_, --, --, --, 
   {{0x768c05ac,0x649c12f2,0x7de401d3,0xa88801e0}},	//   _bøyu, _béic, nésé, _уйға_, 
   {{0xa3cc069f,0xc51404fb,0x41c407f7,0x22a40064}},	//   _शुर_, _ربات, _रुखस, _rūkė_, 
   {{0x7bc00276,0x649c01c7,0x7de40098,0x42cc03d4}},	//   şnui, _déic, hésé, ৰদেশ, 
   {{0x7de4003e,0x2ca0058a,0x7ee402e8,0xdec40166}},	//   késé, dhid_, зцве, дәно, 
   {{0x7af80798,0xfd110096,0x649c01e7,0xb3240327}},	//   _éuti, فجر_, _féic, _ལྗིང_, 
   {{0x71f4179c,0x7de400dd,0x61080118,0x00000000}},	//   _عروس_, désé, _běle, --, 
   {{0x768c02bf,0x2ca00363,0x15e001ad,0x00000000}},	//   _høyt, ghid_, गेटर_, --, 
   {{0xc62011ba,0x20080407,0x610800bc,0x20d80221}},	// [30f70] _নানা_, _ifai_, _děle, héik_, 
   {{0x7de4fb64,0x58f4031c,0x2ca00067,0x60540248}},	//   gésé, _བཤངས_, ahid_, _ọkọọ, 
   {{0x99800069,0xdd0002b5,0x2ca001ab,0xbbe800f2}},	//   mahū_, ētēt, bhid_, _گردم_, 
   {{0x2ca1bd01,0xd7f1bd02,0x768c022c,0x57b4703b}},	//   chid_, نكا_, _løyt, мбет, 
   {{0x20080421,0x7b640166,0xbbe80066,0x00000000}},	//   _mfai_, _этне, _دردم_, --, 
   {{0x768c168c,0x66240136,0x00000000,0x00000000}},	//   _nøyt, ىرىك, --, --, 
   {{0x200872dc,0x00000000,0x00000000,0x00000000}},	//   _ofai_, --, --, --, 
   {{0x1309bd03,0x9f6401f1,0x7c3c0399,0x649c3a35}},	//   оний_, _štýl_, ngqr, _réic, 
   {{0x9980150c,0xf77c1418,0xddc400dc,0x00000000}},	//   kahū_, _çç_, _bahū, --, 
   {{0x2008096b,0x649c07dd,0x29040421,0x60c40115}},	//   _afai_, _péic, _ōmai_, _ĉima, 
   {{0xe5080592,0xd1bc0023,0x00000000,0x00000000}},	//   _فيلو_, _ሰራቒ_, --, --, 
   {{0x7de400dd,0x6ee00793,0x2ca0036e,0x00000000}},	//   zésé, döba, xhid_, --, 
   {{0xb8fc003d,0x2ca07d06,0x03780451,0x2bac000d}},	//   _ཤེ_, vhid_, _وجهڻ_, _घेंा, 
   {{0x2008a2c6,0xe3b075b0,0x2ca0090c,0x768c0158}},	//   _efai_, _حرم_, whid_, _gøyt, 
   {{0x2ca00013,0x768ce73f,0x649c0036,0x00000000}},	//   thid_, _høys, _héia, --, 
   {{0x2ca00a2e,0x20080270,0xfce000d8,0x0c3800ae}},	//   uhid_, _gfai_, восо, تكرة_, 
   {{0x7de400dd,0xcb08212d,0x2ca0007f,0x0b4426c4}},	// [30f80] tésé, زيان_, rhid_, ьнан, 
   {{0x2ca1bd04,0x768c143a,0x61e40115,0x8d75bd05}},	//   shid_, _møys, _ŝili, _قاجا, 
   {{0x768c0183,0xac94044e,0x6108012c,0x7de4a5b2}},	//   _løys, _ዘገርም_, _těle, résé, 
   {{0x7de400e5,0x00000000,0x00000000,0x00000000}},	//   sésé, --, --, --, 
   {{0xaca401f2,0x768c03cd,0x921c00c5,0xe57801f0}},	//   _laịt, _nøys, फराज_, ӯҷа_, 
   {{0x24580016,0xc9540108,0xbeb8036e,0x00000000}},	//   _ẩm_, _отбы, ysëm, --, 
   {{0xaca401f2,0x3ab058c7,0x65880134,0x768c03cd}},	//   _naịt, _рәтт, rɛho, _røyt, 
   {{0x66fc00b8,0x00000000,0x00000000,0x00000000}},	//   _ṅkur, --, --, --, 
   {{0x7ae800d2,0xddc402b1,0x864401d5,0xb7d401d9}},	//   _úmtú, _pahū, _онаж, _ہوہا_, 
   {{0x61140395,0xdbd802d2,0x26d801e1,0x00000000}},	//   ндоу, _mæði, _óro_, --, 
   {{0x3a350b71,0xdbd808a5,0xa1940408,0x00000000}},	//   ורים_, _læði, ханч, --, 
   {{0x9f340220,0x00000000,0x00000000,0x00000000}},	//   немі, --, --, --, 
   {{0xdbd8032e,0xed6000d7,0x00000000,0x00000000}},	//   _næði, ážnu_, --, --, 
   {{0x768c1a82,0x6440000d,0xabc80150,0x00000000}},	//   _høyr, lgmi, _ﺒﺜﻘﺎ, --, 
   {{0x768c0183,0xd1d0001f,0xfafc0036,0x7c9401e2}},	//   _køyr, _ከመቶ_, _suë_, وشرا, 
   {{0x6441bd06,0xfafc0023,0xdbd80413,0x63a40024}},	//   ngmi, _orët_, _bæði, _žiny, 
   {{0xba282aa5,0x5f94023b,0x4bc098ec,0x998002b1}},	// [30f90] قسام_, _чипт, гөрг, pahū_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdbd80008,0xd0f8008f,0xe894b34e,0x58040137}},	//   _fæði, פּער, кахь, روتك, 
   {{0xe709bd07,0xdbd808a5,0x00000000,0x00000000}},	//   وتون_, _gæði, --, --, 
   {{0x768c03d4,0xd5e459e6,0x6440017a,0xa8180131}},	//   _røys, нжли, egmi, كتۇر_, 
   {{0x7ae40198,0xe944014b,0x00000000,0x00000000}},	//   _ihjt, _ихто, --, --, 
   {{0x6440003b,0xf6740451,0x00000000,0x00000000}},	//   ggmi, _ڪارخ, --, --, 
   {{0xaca400b4,0xaa8801d3,0x00000000,0x00000000}},	//   _saịt, _عنہم_, --, --, 
   {{0xf1bc0030,0x6d5800c7,0xa6341cb8,0xd4900051}},	//   ášok_, _ãvag, _анфі, _mùi_, 
   {{0x527400d1,0x50440026,0x00000000,0x00000000}},	//   _җулу, ненб, --, --, 
   {{0x7ff4350a,0xd6340014,0x20040034,0x768c143a}},	//   کسپا, _زِچھ, ślin_, _tøys, 
   {{0x649c04c4,0x64a80882,0x621000dc,0x3cf002a0}},	//   _kéin, rśit, _द्वौ_, ंगने_, 
   {{0x7c2c0393,0x649c0036,0xdbd80ad9,0xade400c5}},	//   _adcr, _jéin, _ræði, _गरदन_, 
   {{0x649c092e,0xc69025f9,0xfafc0023,0xdbd81d12}},	//   _méin, נאל_, _orës_, _sæði, 
   {{0x649c0597,0xd4900051,0xbd800153,0x00000000}},	//   _léin, _bùi_, ыгск, --, 
   {{0xd4900051,0x945c0210,0x00000000,0x00000000}},	// [30fa0] _cùi_, lońs, --, --, 
   {{0x7c2c02d0,0xdbd80413,0xfafc0200,0xbea00408}},	//   _edcr, _væði, _arës_, _баьк, 
   {{0x291dbd08,0xade400bc,0x00000000,0x00000000}},	//   èva_, _गरिन_, --, --, 
   {{0xaca801ed,0xc8d40026,0x9208031c,0xbf101bf4}},	//   _کھڑے_, رزاع, _གཅྀག_, _جویب, 
   {{0x768c00fe,0xb3ac000d,0x00000000,0x00000000}},	//   _røyr, _जेलख, --, --, 
   {{0xfafc0240,0x649c0332,0x00000000,0x00000000}},	//   _erës_, _céin, --, --, 
   {{0x649dbd09,0x19b80108,0x79540408,0x7bc003e0}},	//   _déin, _жуть_, _пирĕ, şnut, 
   {{0x60c40115,0x27780117,0xe47400d8,0x00000000}},	//   _ĉimo, _орзӯ_, тлињ, --, 
   {{0x6440033d,0x649c00c6,0x8da00ed1,0x73d40801}},	//   rgmi, _féin, ﺎﺭﺍﺕ_, ндър_, 
   {{0x649c04c4,0x20d80332,0x00000000,0x00000000}},	//   _géin, néiv_, --, --, 
   {{0x741003e6,0x3cf002c3,0x610801ef,0x00000000}},	//   _ڕونا, ंगमे_, _běla, --, 
   {{0x768c0fac,0xa62c0327,0x00000000,0x00000000}},	//   _høyp, ċċuż, --, --, 
   {{0x2d8dbd0a,0x61080316,0x733042c6,0x94a8007b}},	//   äden_, _děla, _مىنا, _تطلق_, 
   {{0x623400a8,0xd4900208,0x00000000,0x00000000}},	//   _реку, _rùi_, --, --, 
   {{0x62895ff8,0x7c2c00ca,0x6ee00267,0x32400798}},	//   mjdo, _pdcr, möbl, _сејг, 
   {{0x768c03a1,0x649c003e,0x1f740276,0xacf80c5c}},	//   _løyp, _méio, _алия, енсу_, 
   {{0x6c5400f7,0x6b8479d4,0x00000000,0x00000000}},	// [30fb0] ыкту, gxig, --, --, 
   {{0x66180175,0xbd68010a,0xabe00150,0x00000000}},	//   jbvk, _ерме_, _ﻋﻼﻗﺎ, --, 
   {{0xaa440075,0x649dbd0b,0xd0540134,0x62880369}},	//   انمى, _réin, _nhyɛ, ijdo, 
   {{0x649c01c7,0xd7f800ee,0xfca835b6,0x00000000}},	//   _séin, җуҗ_, _راجو_, --, 
   {{0x649dbd0c,0xd0540134,0x6d580022,0xaea40166}},	//   _péin, _ahyɛ, _âvar, _çıñl, 
   {{0x368800fd,0x41b000dc,0x60dc002f,0xddc401ef}},	//   ясен_, ुपास, hlsm, _jahů, 
   {{0x768c00fe,0xb8e402f5,0x649c01e7,0xf1cc0037}},	//   _døyp, _উঠ_, _véin, _सुंन, 
   {{0x649c04c4,0x60dc4fa5,0x6d5800e4,0xfafc0240}},	//   _wéin, jlsm, _ãvae, _urës_, 
   {{0xc481bd0d,0x0321bd0e,0x649c0221,0x200400bc}},	//   рлык, адын, _téin, ělil_, 
   {{0x649c007b,0xb5a4026b,0x945c0210,0x00000000}},	//   _héil, _прей, tońs, --, 
   {{0x10a5bd0f,0x42c4009d,0x2bd80210,0x00000000}},	//   винн, тгэн_, _भुना, --, 
   {{0x7640020b,0x1ccc025c,0xa3cc02c3,0xefbc02d3}},	//   lgny, ློས_, _शुक_, _ደላይ_, 
   {{0x6b84102c,0x649c0332,0x1cb00327,0x705401d5}},	//   xxig, _méil, ནོན_, نچکا, 
   {{0x76405088,0xfc3c004e,0x649c01c7,0x945c033f}},	//   ngny, _omís_, _léil, pońs, 
   {{0x5a300023,0x1e94010b,0x00000000,0x00000000}},	//   _ኣምላኻ, уряр, --, --, 
   {{0x4f940022,0x6b84009d,0x649c007b,0x4fc000db}},	//   _ароу, txig, _néil, _نەجە, 
   {{0x4a44ab39,0x00000000,0x00000000,0x00000000}},	// [30fc0] кнав, --, --, --, 
   {{0x3a2007a8,0x49948a63,0x610800bc,0x6b847708}},	//   _cejp_, кшет, _měln, rxig, 
   {{0xfc3c03b2,0x649c007b,0x8d7462a9,0xda64007b}},	//   _blíd_, _béil, _شادا, داقي, 
   {{0x6f05284d,0x649c00c6,0x2d98003a,0x261492c1}},	//   _kuic, _céil, myre_, नुनी_, 
   {{0x649c00c6,0x2d9801ed,0x6f05bd10,0x38300845}},	//   _déil, lyre_, _juic, рнір, 
   {{0x6f05bd11,0x2b400165,0x20d801c7,0x3eb00208}},	//   _muic, muic_, léit_, _xmxt_, 
   {{0x649c0597,0x2d99bd12,0xbb60037e,0x6f0401e7}},	//   _féil, nyre_, _topペ_, _luic, 
   {{0x64cc1223,0x62880369,0x649c007b,0xc7940124}},	//   ावेश, wjdo, _géil, _ирзы, 
   {{0x69dc049f,0x6f040099,0x768c0158,0xbeb80023}},	//   _hyre, _nuic, _tøyp, rrëz, 
   {{0x610800bc,0x20d801c7,0xb2700816,0x2d980124}},	//   _děln, héit_, альш, kyre_, 
   {{0x2d980023,0x20d801c7,0x2d8c002f,0x00000000}},	//   jyre_, kéit_, ädel_, --, 
   {{0x6f040597,0x2d98e3bd,0x65680014,0x649c04e6}},	//   _buic, dyre_, _isdh, _kéim, 
   {{0x6f045930,0x69dcfb72,0x2b40004e,0x60dc002d}},	//   _cuic, _lyre, juic_, rlsm, 
   {{0x6f04007f,0x649c0036,0x2d99bd13,0xf770011a}},	//   _duic, _méim, fyre_, בקש_, 
   {{0x2d04036b,0x6f040393,0x649c00ae,0xbeb80200}},	//   иятг, _euic, _léim, ksëv, 
   {{0x69b80316,0xfe7401c0,0xec3402bf,0x6ca4005b}},	//   ्पनी, хүү_, инсь, аруж, 
   {{0x649c00ae,0x69dc0363,0x998000bc,0x00000000}},	// [30fd0] _réil, _ayre, tahů_, --, 
   {{0xdea007d6,0x69ddbd14,0x649c01c7,0x2d980588}},	//   _ایسی, _byre, _séil, byre_, 
   {{0x69ddbd15,0x2d8c2188,0x20d801c7,0x6d580022}},	//   _cyre, ødet_, béit_, _âvap, 
   {{0x20d80221,0x76400007,0x6f0404ce,0x649c2d45}},	//   méis_, wgny, _yuic, _béim, 
   {{0xab85bd16,0x3a21bd17,0x649c00c6,0x5694b0fb}},	//   _курк, _tejp_, _céim, ладт, 
   {{0x69ddbd18,0xd5480e76,0x58f40135,0x0db801ed}},	//   _fyre, епке_, _བཤམས_, _آئیں_, 
   {{0x20d9bd19,0x69dc00c7,0x54d406ed,0xd5b00208}},	//   néis_, _gyre, лциу, _nét_, 
   {{0x2004068f,0x649db16a,0xe8940006,0x1ce0031c}},	//   ślij_, _héij, _кась, _སེས_, 
   {{0x610800bc,0x69dc0240,0x387c0139,0x649c0332}},	//   _bělo, _zyre, _inur_, _géim, 
   {{0x42c405f5,0x690801ed,0x6f0401ab,0xed6013d5}},	//   лгын_, _ördö, _ruic, ážku_, 
   {{0x6f05bd1a,0x20d80789,0x610800bc,0x69dc007f}},	//   _suic, jéis_, _dělo, _xyre, 
   {{0x20d9bd1b,0x6f04d8d4,0x610801ef,0xf8d01be1}},	//   déis_, _puic, _těln, तविय, 
   {{0x6f046b0e,0x69d800e2,0x527400cf,0x8898011a}},	//   _quic, ļvei, _буйу, גברי, 
   {{0x2d98044e,0x6f05bd1c,0x20d8000c,0xb7e8012d}},	//   tyre_, _vuic, wéit_, जेएम_, 
   {{0x09bc03f4,0x20d80221,0x387dbd1d,0x8ff800f2}},	//   _অর্থ, téit_, _onur_, برگر_, 
   {{0x6f0407dd,0x09e0015b,0xfc3c01ef,0x00000000}},	//   _tuic, _বললা, _smír_, --, 
   {{0x09bcc2fc,0x2d982ab7,0x65880134,0x0ae800a7}},	// [30fe0] ्थ्य, syre_, bɛhw, едай_, 
   {{0x69ddbd1e,0x649dbd1f,0x0e65bd20,0x20d9bd21}},	//   _pyre, _réim, _скон, béis_, 
   {{0x20d9bd22,0x649dbd23,0xd5b00208,0x2aa402d2}},	//   céis_, _déij, _xét_, _pöbb_, 
   {{0x20d800c6,0x69dd0be8,0xc7a401ec,0x055001f3}},	//   léir_, _vyre, лиек, _መርማሪ, 
   {{0x69ddbd24,0xbeb80200,0xf76c007b,0x00000000}},	//   _wyre, rsëv, كاو_, --, 
   {{0xe944168d,0x20d800c6,0x387c003e,0x649db161}},	//   _پرسی, néir_, _enur_, _géij, 
   {{0x2aa4066d,0x2bd80a59,0x485800c0,0x00000000}},	//   _több_, _भुता, _праў_, --, 
   {{0xb97805d0,0x649c00ae,0x00000000,0x00000000}},	//   _אנלי, _téim, --, --, 
   {{0x332401c6,0xb89000ae,0x00000000,0x00000000}},	//   лцэн_, _القع, --, --, 
   {{0xd58403e6,0xd5ac00f1,0xd09803b9,0x823c0092}},	//   _چێوه_, _ښځي_, _içən, _በበሽታ, 
   {{0x5bc09543,0xba54008f,0xd58403e6,0x20d801e7}},	//   _एश्व, נסטו_, _نێوه_, déir_, 
   {{0x7d000438,0xf481bd25,0x20d800d8,0x3ea40142}},	//   _énsi, _гушн, véis_, _ŷnt_, 
   {{0x44241497,0x649c00e4,0x610800bc,0x20d8000c}},	//   _ieo_, _léik, _tělo, wéis_, 
   {{0x20d8f505,0x4425bd26,0x61d80166,0x00000000}},	//   téis_, _heo_, _имля_, --, 
   {{0x4425bd27,0x649c0022,0x3ce80120,0xc290029e}},	//   _keo_, _néik, еќам_, _نیکب, 
   {{0x44240fcf,0x20d9bd28,0x09bc0c58,0x5f94084c}},	//   _jeo_, réis_, _অৰ্থ, _виит, 
   {{0x4425bd29,0x2d8c04ce,0x20d9bd2a,0x9e3401e5}},	// [30ff0] _meo_, øder_, séis_, _кепч, 
   {{0x20d9bd2b,0x39a400a8,0x387dbd2c,0xdb1c01e1}},	//   péis_, лшев, _snur_, _èyín, 
   {{0x673c002b,0x4ef8011a,0x00000000,0x00000000}},	//   _ārja, _שהתו, --, --, 
   {{0x44240876,0x78241075,0x649c0036,0x1c44121c}},	//   _neo_, اعال, _déik, _өнүм, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe77801ed,0x00000000,0x00000000,0x00000000}},	//   الوں_, --, --, --, 
   {{0x4425bd2d,0x888000f2,0x00000000,0x00000000}},	//   _beo_, _ژیمن, --, --, 
   {{0x4424123b,0xf1cd2a27,0x387dbd2e,0xd39401e0}},	//   _ceo_, _सुगन, _unur_, иәлә_, 
   {{0x4425bd2f,0x649c0036,0x59d8000d,0x00000000}},	//   _deo_, _méih, _बुतर, --, 
   {{0x4425bd30,0x9f48002e,0x7ea80e78,0x7384010b}},	//   _eeo_, _ngañ_, _hüpf, врүң_, 
   {{0x4425bd31,0x0678008f,0x90c46a27,0x7ea8c361}},	//   _feo_, _שנעל, ибое, _küpf, 
   {{0x2570005e,0x93580dce,0x69b835e0,0x50b401e0}},	//   _ءۇيس, _арку_, ्पती, рсоу, 
   {{0x20d8007b,0x00000000,0x00000000,0x00000000}},	//   téir_, --, --, --, 
   {{0x03a0016c,0x442401e4,0x00000000,0x00000000}},	//   _фишо, _zeo_, --, --, 
   {{0x44247483,0xfbdc145e,0x20d80597,0x21740022}},	//   _yeo_, _ayê_, réir_, _гуыр, 
   {{0x44255857,0xf9f8009e,0x20d80332,0x00000000}},	//   _xeo_, ইডাল_, séir_, --, 
  
   {{0x3b043173,0x20d8007b,0x00000000,0x00000000}},	// [31000] ието_, péir_, --, --, 
   {{0xd1c80020,0x649c00e4,0x3f8c00d8,0x20d80332}},	//   _አሉት_, _péik, _àgua_, léip_, 
   {{0xb4f405d7,0xc9640334,0xbe38011a,0xbeb801c7}},	//   ुदाय_, рвей, _בעית, rsët, 
   {{0x0b580022,0xbeb80036,0x00000000,0x00000000}},	//   _иргы_, ssët, --, --, 
   {{0x44241f4c,0xbc1800df,0x00000000,0x00000000}},	//   _reo_, _בוכש, --, --, 
   {{0x4425bd32,0xca74547c,0x649c01c7,0x2ca1bd33}},	//   _seo_, _тумы, _zéih, lkid_, 
   {{0x4425bd34,0x0584086c,0xfc3c00d0,0x26c00841}},	//   _peo_, рулм, _ulíc_, đio_, 
   {{0x2ca1bd35,0x1ccc0003,0xc7642e51,0x4424ad57}},	//   nkid_, ློག_, _پارى, _qeo_, 
   {{0x4425bd36,0x2ca00280,0xa2b400cf,0x00000000}},	//   _veo_, ikid_, йбич, --, 
   {{0x44240086,0x2ca00076,0xddc400d7,0x0574132f}},	//   _weo_, hkid_, _lahš, _پائد, 
   {{0x4424325f,0x2bd8146c,0x2ca0d27e,0x80d001f9}},	//   _teo_, _भुसा, kkid_, ठवले, 
   {{0xfc3c08a5,0x00000000,0x00000000,0x00000000}},	//   _olía_, --, --, --, 
   {{0x94a8e647,0xfeb819bc,0x2ca004cc,0xb15c013d}},	//   _حالِ_, ناست_, dkid_, _çınğ, 
   {{0x649c0036,0xdd949dc3,0x224c0210,0x00000000}},	//   _séih, багы, ójkę_, --, 
   {{0x3cf00574,0xfc3c0789,0xddc400ef,0x6108013a}},	//   ंगले_, _alía_, _bahš, _mělk, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x5a35bd37,0xb6000122,0x6d5800e4,0x6b7485f2}},	// [31010] йнат, áško, _ãvan, олту, 
   {{0x5e9400d8,0x00000000,0x00000000,0x00000000}},	//   _ѓинѓ, --, --, --, 
   {{0xceb030fb,0xfc3c0789,0xb60000f3,0xbeb801c7}},	//   _זיי_, _elía_, šško, ssës, 
   {{0x2ca1a388,0x7ea800fd,0xbeb8036e,0x973400ae}},	//   ckid_, _qüpf, psës, معتص, 
   {{0x290c065c,0x96b80640,0x610801ef,0xb7644c79}},	//   _édan_, луку_, _bělk, ртей, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd5746ebd,0x7ea8002f,0x00000000,0x00000000}},	//   суль, _tüpf, --, --, 
   {{0x649c01c7,0xe8480150,0xd5b00051,0xd42800ec}},	//   _méiw, _ەجەن_, _dép_, اڻان_, 
   {{0xf770f166,0x649c0a40,0x52740137,0x00000000}},	//   _باز_, _léiw, буну, --, 
   {{0x7778005a,0xe6100214,0x00000000,0x00000000}},	//   _irux, _قشم_, --, --, 
   {{0x87c00166,0x20d801e7,0x00000000,0x00000000}},	//   _мөәз, téip_, --, --, 
   {{0x7778007c,0x00000000,0x00000000,0x00000000}},	//   _krux, --, --, --, 
   {{0x999001d3,0x00000000,0x00000000,0x00000000}},	//   _mező_, --, --, --, 
   {{0xd838007f,0x649c04e6,0xc7d4008d,0xe5040150}},	//   _blōk_, _béiw, מורי_, _ابەي, 
   {{0xf1cc4540,0x7bcc102c,0xc0d002d3,0x333c022e}},	//   _सुचन, _axcu, ረሎም_, lrux_, 
   {{0x649c04e6,0xcb69bd38,0xa17c0408,0x00000000}},	//   _déiw, лабе_, _шучĕ_, --, 
   {{0xbeb8044e,0x2ca1bd39,0x4ed5bd3a,0x00000000}},	// [31020] rsër, rkid_, _гюнт, --, 
   {{0x2ca1bd3b,0x649c01c7,0x3ab01321,0xdfd001c8}},	//   skid_, _féiw, пәст, _آڊٽ_, 
   {{0x649c0036,0x2d9c0158,0x38c820e8,0x7bcdbd3c}},	//   _géiw, _æve_, گالی_, _excu, 
   {{0x0c7805f5,0xfc3c08a5,0x333c0327,0x48e4011c}},	//   _ёсны_, _hlín_, krux_, щоев, 
   {{0xe69407d8,0xddd400bc,0x38c81a4b,0x649c01c7}},	//   жилы, dezř, دالی_, _zéiw, 
   {{0xbb180042,0x2b400072,0x3ff8010f,0x4e78010f}},	//   _brîf, mric_, אפנע, ראַצ, 
   {{0x2b4082b2,0x09e0009e,0x261427f2,0x7ab80677}},	//   lric_, _বলকা, नुषी_, _עצלו, 
   {{0x2b41bd3d,0x649c0036,0xe3140063,0x333c025c}},	//   oric_, _léiv, омињ, frux_, 
   {{0x7ea800c5,0x2b41bd3e,0x07a40124,0x33140066}},	//   _hüpe, nric_, _уаан, یزید_, 
   {{0x7ea97937,0x2d785835,0xc56800f1,0x2b40007b}},	//   _küpe, _oče_, _محصل_, iric_, 
   {{0xf48432de,0x2b4004ba,0xa1586206,0xb15c03e3}},	//   _گالی, hric_, шану_, _çılğ, 
   {{0x333c0327,0x00000000,0x00000000,0x00000000}},	//   brux_, --, --, --, 
   {{0x2bd80c66,0x623414b7,0x333c0158,0xf48568e3}},	//   _भुला, _делу, crux_, _دالی, 
   {{0x2919bd3f,0xae142017,0x00000000,0x00000000}},	//   _otra_, तुलन_, --, --, 
   {{0x2b400a40,0x2919bd40,0xb2b80375,0x7ea9bd41}},	//   eric_, _ntra_, _תמור, _nüpe, 
   {{0xfc3c01a8,0x2b401cf8,0x00000000,0x00000000}},	//   _elín_, fric_, --, --, 
   {{0x60cc0537,0x2919bd42,0x649c01c7,0xdfd0724c}},	// [31030] _ijam, _atra_, _wéiw, _زيد_, 
   {{0xe9dc0597,0x6e0401ec,0x2bb8007b,0x195800c7}},	//   ӣκч_, _ىسپە, حافة_, иазы_, 
   {{0x29183d5a,0x2b400072,0x7e64014f,0x60cd3ec5}},	//   _ctra_, aric_, mejp, _kjam, 
   {{0x60cc04ba,0xfc3c00bc,0x26cc0010,0x2b4098dc}},	//   _jjam, _zlín_, _ajdo_, bric_, 
   {{0x60cc01c8,0x2b4000cf,0x61080118,0x29180108}},	//   _mjam, cric_, _děli, _etra_, 
   {{0x69d402ab,0xe57801ec,0xa8180116,0x00000000}},	//   _बुकी, өзі_, لتۇر_, --, 
   {{0x60cdbd43,0x7ea81ea0,0x00000000,0x00000000}},	//   _ojam, _küpb, --, --, 
   {{0x60cdbd44,0x26cc047e,0x77780784,0x94787e1b}},	//   _njam, _ejdo_, _trux, рску_, 
   {{0x77780bc9,0x52a81363,0x78b9bd45,0xd2a80117}},	//   _urux, ивим_, _imuv, икие_, 
   {{0x60cdbd46,0x26cc0240,0x7ea8010e,0x333dbd47}},	//   _ajam, _gjdo_, _yüpe, rrux_, 
   {{0x80d0009e,0x9f4c0208,0xb5a43efd,0x7e6401ef}},	//   সতন্, _đoái_, _урай, dejp, 
   {{0x2b400204,0x50b401ce,0x333c0098,0xa3b80451}},	//   yric_, існу, prux_, _ڏاهر_, 
   {{0x60cdbd48,0x78b804ba,0x3f1001d5,0x929c0210}},	//   _djam, _mmuv, мдўс, zpły, 
   {{0x60cc2784,0xb8c8031c,0xd1b85285,0x00000000}},	//   _ejam, _བཾ_, _پاتا_, --, 
   {{0xfc3c0077,0x32040109,0x60cdbd49,0x78b912f1}},	//   _clío_, _igny_, _fjam, _omuv, 
   {{0x0c8c0020,0x8b246ac5,0x649c0221,0x2b41bd4a}},	//   _ነገሮች_, ждае, _wéiv, tric_, 
   {{0x7ea9bd4b,0x2b400b6f,0x200400bc,0x7e64014f}},	// [31040] _süpe, uric_, ělit_, bejp, 
   {{0x2b41bd4c,0x78b9bd4d,0x2918003e,0x649c0036}},	//   rric_, _amuv, _ptra_, _héit, 
   {{0x2d780552,0x7ea80139,0x1ea833ae,0x891400ae}},	//   _uče_, _qüpe, _دايي_, زبائ, 
   {{0x2b41bd4e,0x2aa401b8,0x6f0001e1,0x8034008f}},	//   pric_, _töbo_, _fábì, ַנצע_, 
   {{0x649c01e7,0x00000000,0x00000000,0x00000000}},	//   _méit, --, --, --, 
   {{0x78b85c2e,0x649c0597,0x7ea8010b,0x00000000}},	//   _emuv, _léit, _tüpe, --, 
   {{0xf8ac00aa,0x29180393,0xd63802bf,0xc864007b}},	//   رکې_, _utra_, сячі_, _وطري, 
   {{0xd24c04a9,0x3205bd4f,0x649c0036,0x00000000}},	//   ۇچى_, _agny_, _néit, --, 
   {{0x29040067,0xbd680023,0xf62800cf,0x00000000}},	//   _iima_, ስነቶም_, اتۇۇ_, --, 
   {{0x2905bd50,0x00000000,0x00000000,0x00000000}},	//   _hima_, --, --, --, 
   {{0x2905bd51,0x649c007b,0x61140a89,0x61080210}},	//   _kima_, _béit, ядну, _ośle, 
   {{0x2905bd52,0x74109ce2,0x1ccc0156,0x649c0332}},	//   _jima_, _قوما, ློབ_, _céit, 
   {{0x29049bb5,0x78f80a1e,0xcf8c03e6,0x7e640427}},	//   _mima_, יפטו, ۆژی_, tejp, 
   {{0x26dc0552,0xdb1402ea,0x61080055,0xdd941ee1}},	//   novo_, _ébél, _aśle, пагы, 
   {{0x60cc01e0,0x7af8011c,0x6d5801b8,0x3618008f}},	//   _tjam, _èuti, _äval, שולד, 
   {{0x60cdbd53,0x5b146da8,0x2905bd54,0x6299bd55}},	//   _ujam, змат, _nima_, _hovo, 
   {{0x62994874,0x63a1bd56,0x649da7c4,0x60dc00e5}},	// [31050] _kovo, nymn, _héis, mosm, 
   {{0x2905bd57,0x60ddbd58,0x78b8009b,0x649c000c}},	//   _aima_, losm, _smuv, _kéis, 
   {{0x6299bd59,0x26ddbd5a,0x2d8c0267,0x63a1bd5b}},	//   _movo, dovo_, ädet_, hymn, 
   {{0x2905bd5c,0x60ddbd5d,0x6299bd5e,0x4dd80375}},	//   _cima_, nosm, _lovo, _לחתו, 
   {{0x649c0a40,0xf2180034,0x62993d27,0x26dc0010}},	//   _léis, पुड़_, _oovo, fovo_, 
   {{0x2905bd5f,0xaa6434da,0x60dc014f,0xe8680419}},	//   _eima_, _отск, hosm, rášľ, 
   {{0x2905bd60,0x649c04e6,0xa95402bf,0x170401ed}},	//   _fima_, _néis, _окрі, _کہتی_, 
   {{0x20082173,0x78b8015c,0x29040589,0xb3240327}},	//   _ngai_, _umuv, _gima_, _རྦུང_, 
   {{0x60dc0048,0x649c0597,0x6299bd61,0x63a00a7f}},	//   dosm, _réit, _bovo, gymn, 
   {{0xd2a81c22,0xe8e8003d,0x200804c9,0x649dbd62}},	//   ское_, _འཚོག, _agai_, _béis, 
   {{0x62988be0,0x2905bd63,0x649c8ec5,0x60dc037e}},	//   _dovo, _yima_, _péit, fosm, 
   {{0x20080005,0x649db16a,0x8140075e,0x4174075e}},	//   _cgai_, _déis, رچىن, ساپس, 
   {{0x6298062c,0x1ccc025c,0x2458084c,0x649c00e4}},	//   _fovo, ློན_, _фачь_, _véit, 
   {{0x63c83306,0xe3b05533,0x523800c8,0x649c0221}},	//   _بِهِ_, _جرم_, _הײַנ, _féis, 
   {{0x649c2d45,0x10a5bd64,0x60dc2a89,0x00000000}},	//   _géis, _никн, bosm, --, 
   {{0x60ddbd65,0x649c0597,0x62980161,0x6ab405f9}},	//   cosm, _héir, _zovo, ंफ्र, 
   {{0x2905bd66,0x629802ce,0x649c0036,0x0b440026}},	// [31060] _rima_, _yovo, _kéir, янан, 
   {{0x2905bd67,0x8fd000c7,0x629801a9,0x2d8c2bd5}},	//   _sima_, _жәҳә, _xovo, ädes_, 
   {{0x2905bd68,0x7834044e,0xfe9800c8,0x3fc803e6}},	//   _pima_, _ከምዝኾ, _היימ, _ندیی_, 
   {{0x649c0491,0x2905bd69,0x00000000,0x00000000}},	//   _léir, _qima_, --, --, 
   {{0x7ea80037,0x2904014f,0x00000000,0x00000000}},	//   _hüpa, _vima_, --, --, 
   {{0xb6000122,0x2905bd6a,0x649dbd6b,0x36301183}},	//   _otáč, _wima_, _néir, ىرىس, 
   {{0x36300ef6,0x00000000,0x00000000,0x00000000}},	//   رروس, --, --, --, 
   {{0x1ce031d9,0x6299bd6c,0x649c0221,0x2905bd6d}},	//   _སེབ_, _sovo, _réis, _uima_, 
   {{0x6299a087,0x649dbd6e,0x26dc0115,0xf740214f}},	//   _povo, _séis, povo_, _пето, 
   {{0x649c464c,0x629801d5,0x63a06ab6,0xc31c00eb}},	//   _céir, _qovo, rymn, _দিদি_, 
   {{0x6299bd6f,0x649dbd70,0xf1a00cc9,0x81c4005b}},	//   _vovo, _déir, ерян, ящие, 
   {{0x6299bd71,0x75d000c6,0x9f3401ec,0x00000000}},	//   _wovo, _ثيما, мемі, --, 
   {{0x6299bd72,0x60ddbd73,0x649d5db1,0xc0e802d3}},	//   _tovo, rosm, _wéis, _ዘየለ_, 
   {{0xa2d40150,0x649c01e7,0xb6000419,0x00000000}},	//   _تيتت, _géir, _ftáč, --, 
   {{0x60ddbd74,0x71f40137,0x00000000,0x00000000}},	//   posm, _ىرىس_, --, --, 
   {{0xfe7401c0,0x91c000c7,0x60dcdaaa,0x8004013d}},	//   цүү_, _шәыл, qosm, _эчке, 
   {{0x2d8dbd75,0xc55002d3,0xde0800f7,0x9aa4027d}},	// [31070] äder_, _ዘይብሉ, _وردۇ_, ومرو, 
   {{0x3aec014a,0xe8e8031c,0x6d4801d9,0x00000000}},	//   füpa_, _འཚུག, تلہِ_, --, 
   {{0x1df80108,0x00000000,0x00000000,0x00000000}},	//   _фены_, --, --, --, 
   {{0xe9f802bf,0x28f8074d,0xb34015b7,0x00000000}},	//   їнці_, пехь_, şçiy, --, 
   {{0xe7380006,0x00000000,0x00000000,0x00000000}},	//   зеі_, --, --, --, 
   {{0xa6c40131,0x00000000,0x00000000,0x00000000}},	//   ىقنى, --, --, --, 
   {{0x672400da,0x7e75bd76,0x7c2c8616,0x649c00e4}},	//   ģija, _maxp, _kecr, _réir, 
   {{0xc9500302,0x7c2c00ad,0x649c12f2,0x24f400db}},	//   _שמן_, _jecr, _séir, нчыр, 
   {{0x1ce00003,0x649c007b,0x60c401e4,0xb6000306}},	//   _སེན_, _péir, _ĉimp, _stáč, 
   {{0x7c2c037e,0x645c016b,0x99900010,0xb6000118}},	//   _lecr, ɑrim, _zdzš_, _ptáč, 
   {{0x9044034c,0x50440209,0x649c01c7,0xc0e80023}},	//   ونده, менб, _véir, _ዘየሎ_, 
   {{0xb60000d0,0x94441997,0x00000000,0x00000000}},	//   _vtáč, _آپشن, --, --, 
   {{0xe2a92a77,0x649c01e7,0x610801ef,0x00000000}},	//   زاین_, _téir, _běls, --, 
   {{0xb8ec025c,0xc3300a1e,0xfc3c032e,0x00000000}},	//   _ུམ_, _יוד_, _flík_, --, 
   {{0x7c2c009a,0x649c0036,0x68100064,0x00000000}},	//   _becr, _kéip, lėdž, --, 
   {{0x7c2dbd77,0x3aec01b8,0x81f400e3,0x2cf80cb2}},	//   _cecr, vüpa_, _غفير_, ंगेल_, 
   {{0x0c240046,0xfce01b0a,0x27340248,0x2bd80037}},	// [31080] змұн, тото, _múná_, _भुखा, 
   {{0x2aa407de,0x649c0124,0x3aec01b8,0x7ea8000d}},	//   _köbi_, _léip, tüpa_, _hüpn, 
   {{0x7ea8013d,0x7c2c0205,0x291c00c7,0x00000000}},	//   _küpn, _fecr, ëva_, --, 
   {{0x7c2d876e,0x53ac2e1e,0x291c1991,0x8ba401d5}},	//   _gecr, टनाश, īva_, _жимж, 
   {{0xf76dbd78,0x291c05b4,0xa684569f,0x945c0210}},	//   لاو_, ūva_, нғай, zińc, 
   {{0x3aec014a,0x7c2c0083,0xd7f80212,0x2f140139}},	//   püpa_, _zecr, чує_, _mäg_, 
   {{0xc5fc0154,0x00000000,0x00000000,0x00000000}},	//   ুর্থ_, --, --, --, 
   {{0xe8e8025c,0x98540006,0x00000000,0x00000000}},	//   _འཚིག, _птуш, --, --, 
   {{0xfc3c09f3,0xefbc0023,0x629c01f4,0x00000000}},	//   _slík_, _ደጋዊ_, öroo, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7e7400d4,0x72d0014b,0xe1400023,0x68100064}},	//   _raxp, тоэф, _ተደጋጊ, aėdž, 
   {{0x7e74039a,0x2a78020c,0x35a00166,0x61f40166}},	//   _saxp, _larb_, _шахг, _ıelı, 
   {{0x7c2dbd79,0xc8380092,0x77340240,0x00000000}},	//   _recr, _የዮሐን, _ኣይሓደ, --, 
   {{0x7c2dbd7a,0x2a780036,0x00000000,0x00000000}},	//   _secr, _narb_, --, --, 
   {{0x2aa401b8,0x7c2c020c,0x00000000,0x00000000}},	//   _göbi_, _pecr, --, --, 
   {{0x9f5400d6,0x7c2dbd7b,0xec680107,0x00000000}},	//   _звич, _qecr, мрук_, --, 
   {{0x7c2c005f,0x7e74123b,0x2a7850eb,0x00000000}},	// [31090] _vecr, _taxp, _barb_, --, 
   {{0x2a783371,0x1ce0025c,0x7c2c2251,0x48bc015b}},	//   _carb_, _སེམ_, _wecr, ইকোর, 
   {{0x7ea981d7,0x7c2c0365,0x2a79bd7c,0x00000000}},	//   _hüpo, _tecr, _darb_, --, 
   {{0x945c0227,0x2a7801ab,0x201801ed,0xeda40022}},	//   kińa, _earb_, ncsi_, _ршьо, 
   {{0xb8d40c2e,0x9664ea10,0x8c180302,0xfc3dbd7d}},	//   _छत_, екле, _מורי, _idí_, 
   {{0x2a7806f2,0x5a2401d9,0xddd401ed,0x649c007b}},	//   _garb_, _سفرٕ, lező, _séip, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2a79bd7e,0x66d800d2,0xc5fc03d4,0xd9bc00bc}},	//   _zarb_, túkû, ুৰ্থ_, ्पीट, 
   {{0x3aec01b8,0x1304013e,0x9f5c0241,0x00000000}},	//   nüpo_, нзим, _àwè_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2f15557b,0x68100024,0xddd401d3,0xfc3c0241}},	//   _säg_, sėdž, kező, _odí_, 
   {{0xc5ec15fa,0x74f00150,0xddd401d3,0xd3b80064}},	//   _اړه_, _جۋعا, jező, _нулі_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2f1404f3,0xd250007b,0x00000000,0x00000000}},	//   _väg_, _صنع_, --, --, 
   {{0x21744ef9,0x33b00131,0x2bd82435,0x00000000}},	//   _ауыр, _سەھر, _भुजा, --, 
   {{0xe18800b2,0x3aec0793,0xfce06bd7,0x7ea8000d}},	//   _آئون_, füpo_, госо, _hüpl, 
   {{0xbb403f3a,0xcb09bd7f,0x7ea80724,0xca85bd80}},	// [310a0] летк, سيان_, _küpl, нгай, 
   {{0xd9bc00ab,0x00000000,0x00000000,0x00000000}},	//   ्पूट, --, --, --, 
   {{0xc864414e,0x6d480332,0x00000000,0x00000000}},	//   етли, ádad, --, --, 
   {{0x6d5dbd81,0x48bc015b,0x24800241,0xd4900208}},	//   mtra, ইক্র, _ḿmú_, _tùy_, 
   {{0xdb680ce1,0x00000000,0x00000000,0x00000000}},	//   _орёл_, --, --, --, 
   {{0xfc3c0118,0x247c0051,0x44380210,0x00000000}},	//   _zdí_, _ỉm_, _śp_, --, 
   {{0x3ab00220,0xe9a80014,0x35643c7f,0x99382bcb}},	//   _сәтт, _تۯان_, ерын_, _ояту_, 
   {{0x6d5dbd82,0x39440077,0x27e000db,0x00000000}},	//   itra, ánse_, üins_, --, 
   {{0x6d5c5337,0xeac400cc,0x00000000,0x00000000}},	//   htra, ্তীম, --, --, 
   {{0x9f5c0241,0x27e00327,0x05b40024,0x00000000}},	//   _àwé_, żins_, _псеў, --, 
   {{0x6d5c08a4,0x945c0bc9,0xddd400e5,0x32600108}},	//   jtra, sińa, yező, утыв, 
   {{0x6d5dbd83,0x00000000,0x00000000,0x00000000}},	//   dtra, --, --, --, 
   {{0x82a487b7,0x201800e5,0x225801f4,0x00000000}},	//   _падж, rcsi_, _жилы_, --, 
   {{0x6d5dbd84,0xbb180356,0x53ac134e,0x00000000}},	//   ftra, _brîn, टनरश, --, 
   {{0x6d5c1c81,0xddd401d3,0xf278011a,0x00000000}},	//   gtra, tező, _מרגש, --, 
   {{0x7ea9a6b9,0x67200841,0xa3e401ad,0xba75b9c2}},	//   _tüpo, _otmj, पअप_, کارت, 
   {{0x6d5dbd85,0x2d840421,0x59d801ad,0xfc3c00d7}},	// [310b0] atra, āmea_, _बुजर, _olív_, 
   {{0x6d5dbd86,0x6b740228,0x7ea800fd,0xbb180356}},	//   btra, ылуу, _küpm, _frîn, 
   {{0x6d5dbd87,0x6720020c,0x7f4c003a,0xddd401d3}},	//   ctra, _atmj, lucq, pező, 
   {{0xcd940375,0x20e000cd,0x00000000,0x00000000}},	//   _סדרת_, नविध, --, --, 
   {{0x4c9806a9,0xfc3c0174,0x8800620a,0x00000000}},	//   _חברו, _blív_, لېفو, --, 
   {{0xc7a1bd88,0x6d8801d9,0x00000000,0x00000000}},	//   ришк, _تۅہہ_, --, --, 
   {{0x20e0547d,0xd5744d56,0xead401c6,0x8f0406be}},	//   नवाध, туль, _сорь, _çoх_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x67d5bd89,0x6d5d3b9b,0xf60800ae,0x00000000}},	//   _боту, ztra, _فتاه_, --, 
   {{0x386d2972,0x7ea800fd,0xa3a8007b,0x93a40166}},	//   legr_, _qüpl, عطيك_, ешүд, 
   {{0x6d5dbd8a,0x5454035b,0x00000000,0x00000000}},	//   xtra, _авет, --, --, 
   {{0x386c6729,0x8fa40150,0x00000000,0x00000000}},	//   negr_, ваме, --, --, 
   {{0x6d5dbd8b,0x7ea80790,0x8838011a,0x00000000}},	//   wtra, _tüpl, ותרו, --, 
   {{0xbb1861bd,0x00000000,0x00000000,0x00000000}},	//   _prîn, --, --, --, 
   {{0x6d5dbd8c,0xcce401f7,0xc0d00023,0xff0400c7}},	//   utra, نسري, የሎም_, терк_, 
   {{0x6d5dbd8d,0x62940124,0xfc3c01a8,0x00000000}},	//   rtra, _агәӡ, _olíu_, --, 
   {{0x25e8012d,0x26140950,0x00000000,0x00000000}},	// [310c0] _चुनी_, दशमी_, --, --, 
   {{0x6d5dbd8e,0x3b80010b,0xba200022,0x28c43885}},	//   ptra, шлуг, идук, लोनि, 
   {{0x6d5dbd8f,0x6588016b,0xda6400c6,0x00000000}},	//   qtra, bɛhy, طالي, --, 
   {{0x9f440085,0xca64022e,0xf3e40150,0x07a400d8}},	//   ́lí_, _etkа, _نأ_, каен, 
   {{0xfc580023,0x00000000,0x00000000,0x00000000}},	//   _ውሽጣው, --, --, --, 
   {{0xdb4c04d3,0x656805b1,0x00000000,0x00000000}},	//   _رێم_, _ppdh, --, --, 
   {{0xa3b40118,0x00000000,0x00000000,0x00000000}},	//   छैन_, --, --, --, 
   {{0x69e40022,0x00000000,0x00000000,0x00000000}},	//   ĩteĩ, --, --, --, 
   {{0x46e80139,0xa2c42cc8,0x00000000,0x00000000}},	//   _ждан_, ләкк, --, --, 
   {{0x332c0007,0x5f94013e,0x00000000,0x00000000}},	//   _dwgx_, ҳимт, --, --, 
   {{0x3a340375,0x290c0098,0x08bc0241,0x00000000}},	//   כרים_, _édas_, _àìsò_, --, 
   {{0xd36c0e26,0x2d9c0790,0x00000000,0x00000000}},	//   تۇۇ_, _üvey_, --, --, 
   {{0x2d8cef77,0x7d00034c,0xdb0c0205,0x257c01e1}},	//   åden_, _ènsi, mzaç, bálá_, 
   {{0xaf3402f2,0x00000000,0x00000000,0x00000000}},	//   گرێت, --, --, --, 
   {{0xeda4dd46,0x728400e5,0x6e95bd90,0x00000000}},	//   ашто, _جانے, ширу, --, 
   {{0xc0a87e89,0x28c47aec,0x7ea800fd,0xaf340133}},	//   _زابل_, लोमि, _küpk, درێت, 
   {{0x6588016b,0x59d45d4f,0x9bf401d5,0x6d4c0064}},	// [310d0] rɛhy, _दशहर, узач, _įlaš, 
   {{0x6d49bd91,0x19940064,0x386c0142,0x00000000}},	//   ádac, лазя, wegr_, --, 
   {{0xd054013b,0xaf5c0092,0x00000000,0x00000000}},	//   _nkyɛ, ናደርገ, --, --, 
   {{0x57b410de,0x683c0092,0x00000000,0x00000000}},	//   лбет, ጠቀሱት, --, --, 
   {{0xd054016b,0x386c01a6,0x6d5800e4,0x2c0801ee}},	//   _akyɛ, regr_, _ãvar, _аэро_, 
   {{0xd6181e87,0x386c0042,0xa3c82c30,0x00000000}},	//   رتتا_, segr_, ोपन_, --, 
   {{0xfc3c0332,0x941804ce,0xaa59bd92,0xf770656a}},	//   _flít_, yやdv, _ширу_, _ھار_, 
   {{0xf770df81,0xddc400dc,0xe0e4009e,0x865000c7}},	//   _پار_, _abhū, নগুন, акәх, 
   {{0x130821f0,0xdce400da,0xc480008e,0x00000000}},	//   нний_, _arhī, слык, --, 
   {{0xf67402f2,0xe74400fb,0x00000000,0x00000000}},	//   _جارخ, _түше_, --, --, 
   {{0x10a45a5b,0xbeb8036e,0x00000000,0x00000000}},	//   гинн, rpël, --, --, 
   {{0x257c043b,0x5fc400af,0x00000000,0x00000000}},	//   sálá_, _लेहल, --, --, 
   {{0xe508009f,0xb4dc578b,0x00000000,0x00000000}},	//   _شيهو_, णवी_, --, --, 
   {{0x90c400fd,0xc5f400cc,0xfc3c08a5,0xdce80055}},	//   _әбие, _চলতা_, _olís_, _ānād, 
   {{0x8c45bd93,0x7bc81427,0x00000000,0x00000000}},	//   леве, úgun, --, --, 
   {{0xff5c0548,0x4f95bd94,0x657c0042,0x00000000}},	//   btî_, _броу, _ârhe, --, 
   {{0x8b2402d5,0x00000000,0x00000000,0x00000000}},	// [310e0] удзе, --, --, --, 
   {{0x9f042162,0x00000000,0x00000000,0x00000000}},	//   _پوپو, --, --, --, 
   {{0x09f4722e,0xc8480108,0x1d7c0092,0x629c01f4}},	//   учая, епеж_, _ብልቶች_, öroi, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfc3c02d2,0x7d180115,0x3c0401a9,0x00000000}},	//   _elís_, ĉuse, _бўёғ, --, 
   {{0xfc3c08ce,0x6b843bb4,0xc92000cc,0x00000000}},	//   _flís_, mvig, _পটীত_, --, 
   {{0x6b8400df,0xd63802bf,0x9f44a898,0x00000000}},	//   lvig, тячі_, ́là_, --, 
   {{0x6b840037,0xa6540133,0xff5c0022,0xd90c0101}},	//   ovig, _چێشت, ytî_, _قیل_, 
   {{0xb5c000d1,0x0684004e,0x02c80063,0xa3d401c4}},	//   ийәл, _йган, ећни_, ропч, 
   {{0x6b85bd95,0xf3f42e9a,0x22580ac1,0x77c410a7}},	//   ivig, ыныш_, ürk_, _слуг_, 
   {{0x649c01c7,0x6b8400c5,0x2348030f,0x83840022}},	//   _méiz, hvig, رسکی_, _ӡыле, 
   {{0x351808a8,0x6b8400df,0x7ea8010e,0x00000000}},	//   _נודנ, kvig, _tüpk, --, 
   {{0xa294177b,0x6b8401a4,0x7ea8000d,0x2294011c}},	//   _валі, jvig, _hüpi, _виля, 
   {{0x38b40432,0xd36c01f7,0xf3f40064,0x00000000}},	//   _içre_, _آڇي_, _сніш_, --, 
   {{0x291c02fb,0x6b8401f5,0xeea8013d,0x5e700133}},	//   íval_, evig, утяк_, مۆکڕ, 
   {{0x453c0257,0xb22001af,0x00000000,0x00000000}},	//   _አይነበ, _кмәл, --, --, 
   {{0x5a35bd96,0x6bd4007b,0x00000000,0x00000000}},	// [310f0] инат, متكر, --, --, 
   {{0xfc3c032e,0x00000000,0x00000000,0x00000000}},	//   _plís_, --, --, --, 
   {{0xdd95bd97,0x6b840eda,0x649c0036,0x63a59a7b}},	//   _таны, avig, _déiz, _àinf, 
   {{0x7ea803e0,0x00000000,0x00000000,0x00000000}},	//   _süph, --, --, --, 
   {{0xdec80020,0x69dc00db,0x481000fd,0x00000000}},	//   _በምን_, _exre, әмәс, --, 
   {{0x02dc00ab,0x61f802f0,0xfbd80154,0x00000000}},	//   नकोन, _ozvl, _দরপত, --, 
   {{0x7d0c066d,0x39f000cf,0x57240b38,0xc5ec01e2}},	//   _kics, _اۋاز, _چىرك, وړم_, 
   {{0x58d400d6,0x7d15bd98,0xc8640150,0xb4dc084d}},	//   _тобт, _muxs, _نەمو_, णवे_, 
   {{0x7d140309,0x7d0dbd99,0xe7ec0c70,0x569400cf}},	//   _luxs, _mics, _छुपा_, _каат, 
   {{0x52a909ea,0x387dbd9a,0x516440c5,0xd2a8005b}},	//   твом_, _haur_, авоб, ткое_, 
   {{0x387c285e,0x6b840433,0x94780117,0x945c00a2}},	//   _kaur_, zvig, _аслу_, nińk, 
   {{0x7d0dbd9b,0x85980375,0xb8e801ec,0xdc4001ef}},	//   _nics, _בשעו, мкiн, _bůčk, 
   {{0x0874010f,0x889800d9,0x733019c5,0xa3c8141f}},	//   בערט_, דברי, _چىچا, ोपण_, 
   {{0x387dbd9c,0x6b84c5bf,0x7d0c01e7,0x00000000}},	//   _laur_, vvig, _aics, --, 
   {{0xbb18006a,0x7d0c102c,0xd130165e,0x9db8008e}},	//   _frîk, _bics, _بمع_, гыту_, 
   {{0x387dbd9d,0x6b84005c,0x291c0419,0x00000000}},	//   _naur_, tvig, ívam_, --, 
   {{0x7d0c01d3,0x6b85bd9e,0x60dc01d3,0x3b80009d}},	// [31100] _dics, uvig, érme, олтг, 
   {{0x6b85bd9f,0x7d140009,0x20e000bc,0x00000000}},	//   rvig, _fuxs, नवअध, --, 
   {{0x387dbda0,0x7d0c35ab,0x6b84417b,0x02b4008f}},	//   _baur_, _fics, svig, סלעך_, 
   {{0x387dbda1,0x63a401ab,0x6b85bda2,0x00000000}},	//   _caur_, _àing, pvig, --, 
   {{0x387dbda3,0xca7400a8,0xfc3c03b2,0x38c80066}},	//   _daur_, _кувы, _foíb_, خالی_, 
   {{0x2b4001fa,0x00000000,0x00000000,0x00000000}},	//   msic_, --, --, --, 
   {{0x387c1c1d,0xb5a000f7,0x2b400051,0xc894009b}},	//   _faur_, жрый, lsic_, _крањ, 
   {{0x6e3dbda4,0x387c0323,0x29181730,0x3aec0793}},	//   harb, _gaur_, _iura_, vüpi_, 
   {{0x2b41bda5,0x2919bda6,0x649c0077,0x733400db}},	//   nsic_, _hura_, _méix, азыр_, 
   {{0x2919bda7,0x6e3dbda8,0x02a40139,0x3664059f}},	//   _kura_, jarb, ррим, _вафо_, 
   {{0x6e3c1ebf,0x03d00064,0x96b80354,0x00000000}},	//   darb, _šūdą_, _суту_, --, 
   {{0x649c00f7,0x7d1407d6,0x2b402625,0x6e3c002f}},	//   _néix, _ruxs, ksic_, earb, 
   {{0x2919bda9,0xf4842a60,0x6e3dbdaa,0x6d49300d}},	//   _lura_, _خالی, farb, ádan, 
   {{0x8e24151c,0x6e3dbdab,0xa159bdac,0x29180c86}},	//   _ѕoм_, garb, _баку_, _oura_, 
   {{0x2919bdad,0x7d0d070b,0x7d14011f,0xf1a002e8}},	//   _nura_, _pics, _quxs, _мрън, 
   {{0x19580046,0xdea0036b,0x6e3c01c7,0x00000000}},	//   ғады_, _کیسی, aarb, --, 
   {{0x2919bdae,0x649c056a,0x7d0ce6a1,0x63a401ab}},	// [31110] _aura_, _déix, _vics, _àind, 
   {{0x2919bdaf,0x387c3386,0x28c407f7,0x2c1800fe}},	//   _bura_, _saur_, लोसि, তৰলৈ_, 
   {{0x2919bdb0,0x387dbdb1,0x7dc0022e,0x6d580022}},	//   _cura_, _paur_, _kеsm, _ävap, 
   {{0x2919bdb2,0x86240efb,0x00000000,0x00000000}},	//   _dura_, ەبيە, --, --, 
   {{0x29182804,0x2b440323,0xce4c02d3,0xdb20005b}},	//   _eura_, _мэрг, _ንምጥቃ, ötät, 
   {{0x2919bdb3,0xbb18006a,0x1fd8015b,0x387c1c1d}},	//   _fura_, _asîg, _সরাস, _waur_, 
   {{0x387dbdb4,0x00000000,0x00000000,0x00000000}},	//   _taur_, --, --, --, 
   {{0xb7b000d1,0xadd8011a,0x8cc806b1,0x00000000}},	//   _мөлч, יווח_, सोपो, --, 
   {{0x2919bdb5,0x7778014b,0x6e3c03ee,0x92e800db}},	//   _zura_, _usux, yarb, лдиб_, 
   {{0x29180986,0x333c0327,0xd17401ec,0xdbdc00e5}},	//   _yura_, rsux_, бымы, gáér, 
   {{0x29180077,0x91e5bdb6,0x6e3dbdb7,0x333c031c}},	//   _xura_, соне, varb, ssux_, 
   {{0x2b41bdb8,0x6e3c817e,0x657c0042,0x00000000}},	//   ysic_, warb, _ârha, --, 
   {{0x6e3dbdb9,0xfbc405d7,0xd34001ed,0x333c031c}},	//   tarb, _रेलम, _عہدی, qsux_, 
   {{0x7e200f5c,0x6e3c0112,0x00000000,0x00000000}},	//   здрж, uarb, --, --, 
   {{0x62200131,0xdce4002b,0x10a4009d,0x1d1800d4}},	//   _تۈپە, _sphā, _гийн, иють_, 
   {{0x2919bdba,0x00000000,0x00000000,0x00000000}},	//   _rura_, --, --, --, 
   {{0x2918f165,0x4a45bdbb,0x00000000,0x00000000}},	// [31120] _sura_, йнав, --, --, 
   {{0x3f8dbdbc,0x2b41bdbd,0x09e428e8,0x6e3dbdbe}},	//   _água_, rsic_, бозн, qarb, 
   {{0x2919bdbf,0xbc6400d1,0x00000000,0x00000000}},	//   _qura_, شمەن_, --, --, 
   {{0x2919bdc0,0xacb40228,0xe7ec012c,0x98c41cd0}},	//   _vura_, _بەرب, _छँदा_, осіл, 
   {{0x26c8416c,0x291984d7,0x1bf40037,0x00000000}},	//   аған_, _wura_, _आरएल_, --, 
   {{0x29183142,0xe94410e5,0x1614185e,0x2ca000ad}},	//   _tura_, _ورزی, يسىڭ, ljid_, 
   {{0x05858831,0x2918198f,0x2ca00076,0x00000000}},	//   сулм, _uura_, ojid_, --, 
   {{0x2ca0062c,0x066400db,0x28c41cd2,0x00000000}},	//   njid_, _گارپ, लोशि, --, 
   {{0x7ea80724,0x25e80073,0x394000d7,0x00000000}},	//   _küpt, _चुरी_, _zvjs_, --, 
   {{0x28c41b76,0x00000000,0x00000000,0x00000000}},	//   लोरि, --, --, --, 
   {{0x6d480216,0x2099bdc1,0x7ea803e0,0x00000000}},	//   ádal, акны_, _müpt, --, 
   {{0x2ca19f2c,0xa9c42b1b,0xdbdc01d3,0x00000000}},	//   jjid_, ্থপঞ, sáér, --, 
   {{0xfeb843f3,0x2ca1bdc2,0x00000000,0x00000000}},	//   هاست_, djid_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6ca5bdc3,0xdfd40046,0x38b40139,0x2ca0036e}},	//   пруж, _мойы, _oçra_, gjid_, 
   {{0xab940212,0x00000000,0x00000000,0x00000000}},	// [31130] питі, --, --, --, 
   {{0xfc3c00d8,0x20700ca8,0x00000000,0x00000000}},	//   _doía_, _ọnọọ_, --, --, 
   {{0xceb004ae,0x69c804a7,0xeab018fd,0x00000000}},	//   _חיי_, _žder, رعك_, --, 
   {{0x57f41173,0x00000000,0x00000000,0x00000000}},	//   опет, --, --, --, 
   {{0x236400b5,0x7c3c0009,0x881400fe,0xcc840345}},	//   jtmj_, maqr, াৰ্ছ_, _بۆقه_, 
   {{0x7c3c03b9,0x00000000,0x00000000,0x00000000}},	//   laqr, --, --, --, 
   {{0x952401b9,0x00000000,0x00000000,0x00000000}},	//   زکام, --, --, --, 
   {{0x7ea9bdc4,0x7c3c0784,0x00000000,0x00000000}},	//   _küps, naqr, --, --, 
   {{0xd29802bf,0xa89800db,0x94744e5d,0x68e80139}},	//   атні_, _укту_, مدکا, _ídda, 
   {{0xa5d81e87,0x00000000,0x00000000,0x00000000}},	//   جبۇر_, --, --, --, 
   {{0x2bd012eb,0x7c3c0113,0x7ea80037,0x2ca00076}},	//   _सेना, kaqr, _lüps, yjid_, 
   {{0xd009471c,0x629cc9df,0x6d4802f0,0xc0b80092}},	//   иене_, öror, ádam, _ሲችል_, 
   {{0x33280b2c,0x7c3cccb5,0x60dc0c6a,0xf8a4000d}},	//   _сцен_, daqr, érma, _खवईय, 
   {{0xdcb001fb,0x6d480153,0x00000000,0x00000000}},	//   ển_, šdam, --, --, 
   {{0x2d8dbdc5,0x00000000,0x00000000,0x00000000}},	//   íde_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2ca02ab0,0x2d8c00df,0xbfc0014b,0x00000000}},	// [31140] rjid_, ŭde_, _обък, --, 
   {{0x2ca1966d,0x705404f2,0xb05400e5,0x0dc80092}},	//   sjid_, _بچگا, _بھگت, _በግፍ_, 
   {{0xa2dc4a18,0x7c3c6f19,0x00000000,0x00000000}},	//   _पदस्, baqr, --, --, 
   {{0x8c5400db,0x00000000,0x00000000,0x00000000}},	//   _بئدا, --, --, --, 
   {{0x27e1bdc6,0x99a401a6,0x7ea80205,0x00000000}},	//   çin_, ćuše_, _tüpt, --, 
   {{0x27e0003d,0x9f6000dd,0x7dc001a9,0x2bd00037}},	//   ħin_, ését_, _bеsh, _सेया, 
   {{0x7ea80037,0xb6c801d3,0x69346b18,0x00000000}},	//   _küpr, جانے_, _رکار, --, 
   {{0x200403be,0x39440b21,0xe4984eca,0x00000000}},	//   əlif_, ânse_, скич_, --, 
   {{0x6d48219b,0xb404009d,0x00000000,0x00000000}},	//   ádaj, жээж_, --, --, 
   {{0x657c0142,0x82a40150,0x7bc800e4,0x00000000}},	//   _ârho, ішпе, úgui, --, 
   {{0x81c40c9e,0xa1941078,0x00000000,0x00000000}},	//   ющие, чанч, --, --, 
   {{0xf48404d3,0x00000000,0x00000000,0x00000000}},	//   _وانی, --, --, --, 
   {{0x4425bdc7,0x5fc4012c,0x00000000,0x00000000}},	//   _ifo_, _लेखल, --, --, 
   {{0xfbdc0042,0x7c3c0113,0x00000000,0x00000000}},	//   _ddêl_, waqr, --, --, 
   {{0x644000ec,0x4424fa60,0x7dc0022e,0x71f40046}},	//   oami, _kfo_, _kеsi, _ورىس_, 
   {{0xac94234c,0x00000000,0x00000000,0x00000000}},	//   масш, --, --, --, 
   {{0xdfd075a6,0x4425bdc8,0xba2816a0,0x26cc3743}},	// [31150] _سيد_, _mfo_, لسام_, _omdo_, 
   {{0x6441bdc9,0x3168012d,0x00000000,0x00000000}},	//   hami, ńcze_, --, --, 
   {{0xceb01a4c,0x4425bdca,0x60cd7949,0x7c3c0113}},	//   _ניט_, _ofo_, _kmam, paqr, 
   {{0x4425bdcb,0x6d980084,0x26cdbdcc,0x7c3dbdcd}},	//   _nfo_, _ḓad, _amdo_, qaqr, 
   {{0x6441bdce,0x60cdbdcf,0xd6281c58,0x4c98011a}},	//   dami, _mmam, боле_, _הברו, 
   {{0xe7083738,0x60cc52bf,0x7dc0022e,0x6441bdd0}},	//   يتون_, _lmam, _pеsh, eami, 
   {{0x60cdbdd1,0xeaf803e6,0x00000000,0x00000000}},	//   _omam, _گرێت_, --, --, 
   {{0x6441bdd2,0x4424ec8f,0x16180034,0x7af40fac}},	//   gami, _cfo_, दशहर_, llxt, 
   {{0x4425bdd3,0x78b8000d,0xe35401c0,0xeaf803e6}},	//   _dfo_, _iluv, мтээ, _درێت_, 
   {{0x78b807a9,0x4425bdd4,0x64400194,0x6edc01e1}},	//   _hluv, _efo_, aami, _ḿbí, 
   {{0x6441bdd5,0x4424930a,0x78b801e3,0xf4840395}},	//   bami, _ffo_, _kluv, _мудн, 
   {{0x44240770,0xe1f8869e,0x00000000,0x00000000}},	//   _gfo_, өгө_, --, --, 
   {{0x78b80316,0xa3c800dc,0x6934010b,0x929402e8}},	//   _mluv, ोपः_, _işeň, _надц, 
   {{0x60cdbdd6,0x78b8db58,0x7c3800df,0x7ea80790}},	//   _emam, _lluv, _ĵura, _süpr, 
   {{0x78b82f99,0x91a800cc,0x00000000,0x00000000}},	//   _oluv, _ছেৰ্, --, --, 
   {{0x61fc0365,0x8b24656c,0xc5f00375,0x945c012d}},	//   ürle, здае, גדל_, mińs, 
   {{0x945c033f,0x4a740209,0xfc3c0332,0x00000000}},	// [31160] lińs, зыет, _toín_, --, 
   {{0x09e43117,0x00000000,0x00000000,0x00000000}},	//   позн, --, --, --, 
   {{0x78b8b2e4,0x60cd6d10,0x7ea803e0,0x291c035b}},	//   _bluv, _ymam, _tüpr, êva_, 
   {{0x6441bdd7,0x7ea800af,0x78b8003a,0x60cc05b1}},	//   xami, _hüpp, _cluv, _xmam, 
   {{0x6441bdd8,0xe7051cc3,0x4425bdd9,0x7ea8349e}},	//   vami, وستی, _rfo_, _küpp, 
   {{0x6441bdda,0x44257f94,0x78b9bddb,0xbeb80240}},	//   wami, _sfo_, _eluv, lpër, 
   {{0x64406e5e,0xeb0801f9,0xe7ec3f6f,0x00000000}},	//   tami, वगीत_, _छुरा_, --, 
   {{0x78b88bbb,0x985400cf,0xbeb80200,0x00000000}},	//   _gluv, _отуш, npër, --, 
   {{0x44240158,0x7d000036,0xf3604889,0x623401f0}},	//   _vfo_, _ënse, нтэн, мепу, 
   {{0xbeb80023,0x00000000,0x00000000,0x00000000}},	//   hpër, --, --, --, 
   {{0x97600023,0xbeb80200,0xc58801e2,0x00000000}},	//   _ወልደት, kpër, _دپام_, --, 
   {{0x6441bddc,0xdfd402d5,0xbeb80200,0x4430010e}},	//   qami, домы, jpër, _ýy_, 
   {{0x74101e0e,0x2d8c69e8,0xdcb001fb,0x9f480139}},	//   _كوما, æden_, ểm_, _myaç_, 
   {{0x7ea80205,0x945c012d,0x00000000,0x00000000}},	//   _cüpp, bińs, --, --, 
   {{0x290401a6,0x9cf4177b,0x945c033f,0x26000073}},	//   _ohma_, дзві, cińs, षेची_, 
   {{0x62883d32,0x00000000,0x00000000,0x00000000}},	//   lddo, --, --, --, 
   {{0xfbd01416,0xbb18019f,0x5b140364,0x6288058a}},	// [31170] رتر_, _arîr, дмат, oddo, 
   {{0x6289bddd,0xbeb8036e,0x290401f4,0x00000000}},	//   nddo, rpës, _ahma_, --, 
   {{0x78b9bdde,0x62880af9,0xd9f8010b,0x00000000}},	//   _pluv, iddo, цнжц_, --, 
   {{0xcfd00ca8,0x60ddbddf,0x3154008f,0x2905bde0}},	//   _apẹẹ, nnsm, ליבן_, _chma_, 
   {{0x6299bde1,0x2bc9bde2,0x60ddbde3,0x945c012d}},	//   _onvo, _еуро_, insm, zińs, 
   {{0x7d0001c7,0x00000000,0x00000000,0x00000000}},	//   _ënsb, --, --, --, 
   {{0x58d410f5,0x291c012c,0xf77000f1,0xa645bde4}},	//   _жовт, ívat_, _ګاز_, رخون, 
   {{0x6298382f,0x78b9bde5,0x6288e7ae,0x60dc4fa5}},	//   _anvo, _uluv, eddo, jnsm, 
   {{0x6289bde6,0x836144c7,0xc4802347,0xc5ec00cc}},	//   fddo, نگول, тлык, টেলা_, 
   {{0x25e8028a,0xfc3cfe95,0x6289bde7,0x00000000}},	//   _चुकी_, _leí_, gddo, --, 
   {{0x7c38008f,0x7dc0022e,0xe53400c7,0x7ea80254}},	//   _ĵurn, _kеsu, _зехь, _rüpp, 
   {{0x6299bde8,0x7641bde9,0x62889382,0x93b400a7}},	//   _envo, lany, addo, _обец, 
   {{0x945dbdea,0x7ea80b8b,0x00000000,0x00000000}},	//   sińs, _püpp, --, --, 
   {{0x7641bdeb,0xb63c037e,0x945c012d,0x00000000}},	//   nany, _ａｔ_, pińs, --, 
   {{0x764004ba,0xbeb80200,0x00000000,0x00000000}},	//   iany, tpër, --, --, 
   {{0x7641bdec,0xa62c025c,0x00000000,0x00000000}},	//   hany, ċċiż, --, --, 
   {{0xbb41599c,0xbeb88302,0x92c002f5,0x62980076}},	// [31180] кетк, rpër, ্কী_, _ynvo, 
   {{0x764043d6,0x2904036b,0xbeb80240,0xd1dc0023}},	//   jany, _shma_, spër, _ዓሚቕ_, 
   {{0xacb400cf,0x3aec002f,0x2f0401e3,0x7e98011a}},	//   _كەسب, rüpp_, rögd_, _וסיו, 
   {{0xbeb80240,0x764000ad,0x2c7801ed,0x8b24399f}},	//   qpër, eany, _ڈیڑھ_, _одме, 
   {{0x7641bded,0x6d5c0d51,0x62880f7b,0x4e20038e}},	//   fany, lura, yddo, _मलाई_, 
   {{0x7641bdee,0xfbd00375,0xbb400063,0x00000000}},	//   gany, _יתר_, _јерк, --, 
   {{0xf981bdef,0x290406a3,0x60dc383d,0xdc300306}},	//   _игро, _thma_, ynsm, zýčk, 
   {{0x63e41823,0x6d5c0099,0x76400083,0x2d680112}},	//   ىۋال, iura, aany, iße_, 
   {{0xc7640131,0x60dc0174,0x2d9c032e,0x00000000}},	//   _تازى, vnsm, _ávef_, --, 
   {{0x76418e3b,0x234801d3,0x60dc02d0,0x00000000}},	//   cany, _ہستی_, wnsm, --, 
   {{0x62880cfd,0x672001f7,0x60dc01a8,0x0444004e}},	//   rddo, _humj, tnsm, _жеен, 
   {{0x6721bdf0,0x7c3800df,0x60dc0221,0xdc3000d7}},	//   _kumj, _ĵuro, unsm, týčk, 
   {{0xfc3c0789,0x60ddbdf1,0x2d680e78,0x6d5dbdf2}},	//   _reí_, rnsm, eße_, eura, 
   {{0x6d5d284d,0x6299bdf3,0x6720036e,0x3168012d}},	//   fura, _unvo, _mumj, ńcza_, 
   {{0x67200399,0x9f98017a,0x00000000,0x00000000}},	//   _lumj, _dáár_, --, --, 
   {{0x7641bdf4,0xd34404d3,0xfe742063,0xdb0c01e1}},	//   zany, _تییه_, чүү_, _àkúk, 
   {{0x2d8c0627,0xfc3c0137,0x7dc001d5,0x61f801e3}},	// [31190] åder_, _veí_, _rеsu, _hyvl, 
   {{0x6d5c94a7,0xba75bdf5,0x9af40597,0x48c00588}},	//   bura, بارت, ركات, қәса, 
   {{0x7641bdf6,0x00000000,0x00000000,0x00000000}},	//   vany, --, --, --, 
   {{0x2bd06bcf,0x00000000,0x00000000,0x00000000}},	//   _सेवा, --, --, --, 
   {{0x7641bdf7,0xb8d40b7d,0xd6284ea0,0x291dbdf8}},	//   tany, _चक_, поле_, ívar_, 
   {{0x7dc001a9,0xc20401d9,0x76400076,0x67200171}},	//   _fеst, _مٔ_, uany, _dumj, 
   {{0x764001b2,0x6a14a0d5,0xe6b400db,0x00000000}},	//   rany, _амру, ئلىگ, --, 
   {{0x7641bdf9,0x8880036b,0x00000000,0x00000000}},	//   sany, _میمن, --, --, 
   {{0x7641bdfa,0x6d5dbdfb,0x543597a2,0x67200010}},	//   pany, zura, ورکر, _gumj, 
   {{0x6d5c7bc3,0xd5e01682,0x2d9c03b2,0x7641bdfc}},	//   yura, _haḽ, _áveg_, qany, 
   {{0x6d5dbdfd,0xb9f80092,0x74a400d8,0x00000000}},	//   xura, _ሆኜ_, _ојде, --, 
   {{0x6d5dbdfe,0x2ec84103,0x3cf80034,0x92c00eac}},	//   vura, रफ्त, ्षों_, ্কে_, 
   {{0xd5e00943,0xbeb80023,0x8e7401b9,0xe2a8105d}},	//   _maḽ, rqën, нувч, ساین_, 
   {{0x91e40b46,0x6d5dbdff,0xd468010a,0x00000000}},	//   _поле, tura, _миçе_, --, 
   {{0x41b00214,0xc5f0008f,0xd1740137,0xdb0c0248}},	//   _ممور, ָדן_, _чылы, _àkùk, 
   {{0x6d5dbe00,0xd5e00943,0x9f4805c7,0x7dc0022e}},	//   rura, _naḽ, _ezañ_, _rеst, 
   {{0x8b643cd9,0xca541d39,0x00000000,0x00000000}},	// [311a0] عارم, етењ, --, --, 
   {{0x0d8405c5,0xdb0c00c7,0x1a240014,0x59740092}},	//   _злон, byaí, ٖرنُ, _አላችሁ_, 
   {{0x8c442e2c,0x6d5ccbcb,0x6720107d,0x02b4008f}},	//   _пене, qura, _sumj, עלעך_, 
   {{0x67200455,0x657c0142,0xf404009a,0x25b800a2}},	//   _pumj, _ârhi, _مؤ_, _ürli_, 
   {{0xf76dbe01,0xa2b40316,0xbc18011a,0x00000000}},	//   ماو_, ेसम्, _מוכש, --, 
   {{0x65680477,0x6720014f,0x00000000,0x00000000}},	//   _pqdh, _vumj, --, --, 
   {{0x09e40212,0x00000000,0x00000000,0x00000000}},	//   _човн, --, --, --, 
   {{0x6720009f,0x00000000,0x00000000,0x00000000}},	//   _tumj, --, --, --, 
   {{0x5ef40882,0x37e0bb65,0xd5b800db,0x00000000}},	//   ृतम्_, _ботг, зсө_, --, 
   {{0x3f8c0124,0xb3700592,0x94d406be,0xc1e812fa}},	//   _águi_, اديش, _müəl_, зьме_, 
   {{0xba54008f,0xfb14010f,0xd04406be,0x00000000}},	//   עסטו_, ײַזט_, likə, --, 
   {{0x254c012c,0xf481be02,0x61f813d5,0xe3a407d6}},	//   měl_, _бушн, _vyvl, _لشتی, 
   {{0x6d480129,0xceac0451,0xd04403b9,0x2bd00118}},	//   âdan, ڪڙي_, nikə, _सेला, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x254c0118,0x00000000,0x00000000,0x00000000}},	//   něl_, --, --, --, 
   {{0xe0d001d9,0xaf3403e6,0x7dc0022e,0xf1bc0118}},	//   _خٲب_, خرێت, _sеss, íšek_, 
   {{0x7e28109a,0x00000000,0x00000000,0x00000000}},	// [311b0] _ніна_, --, --, --, 
   {{0x9f480139,0x00000000,0x00000000,0x00000000}},	//   _uzañ_, --, --, --, 
   {{0xd9980597,0x02fc000d,0x00000000,0x00000000}},	//   بنات_, _उठै़_, --, --, 
   {{0x254c012c,0x00000000,0x00000000,0x00000000}},	//   děl_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf6512838,0xab846bce,0x8bd4011a,0x00000000}},	//   ائش_, _суюк, _יורו_, --, 
   {{0x6d981682,0xd5e40395,0x00000000,0x00000000}},	//   _ḽan, ъжки, --, --, 
   {{0x69cc0030,0x00000000,0x00000000,0x00000000}},	//   ôlež, --, --, --, 
   {{0x6d981682,0x1309176e,0x57f53684,0x97140022}},	//   _ṋan, мний_, _рпат, _амац, 
   {{0xa30801e0,0x628801e1,0x66e400f3,0x61e400b8}},	//   ндыҡ_, _ìmò, _бођа, _śila, 
   {{0x6ef800d2,0x91e5be03,0x2258033f,0x547400e3}},	//   _lúbî, тоне, órka_, _لهاذ, 
   {{0xe3b06728,0xe50800c6,0x798403ac,0x70dc00af}},	//   _گرم_, _كيلو_, _msjw, मचेल, 
   {{0x96c40118,0x00000000,0x00000000,0x00000000}},	//   _वताउ, --, --, --, 
   {{0x6d9806d6,0xe3b0020c,0x00000000,0x00000000}},	//   _ḓan, _درم_, --, --, 
   {{0xe2a8e647,0xbea007fa,0x3ea001b9,0x420408ca}},	//   _ساون_, шарк, ширг, _иншо_, 
   {{0x6dc400cf,0x00000000,0x00000000,0x00000000}},	//   _ەمدۅ, --, --, --, 
   {{0x8fa45211,0x00000000,0x00000000,0x00000000}},	// [311c0] _рапе, --, --, --, 
   {{0xa2d407f7,0x6d4867ac,0xf4100154,0x00000000}},	//   योप्, ádas, _সভার_, --, 
   {{0xc96425ec,0xbea021fe,0xcc8807d6,0x19b879ac}},	//   твей, _таэк, _قنده_, нуць_, 
   {{0x38c9be04,0x254c0118,0x00000000,0x00000000}},	//   وانی_, věl_, --, --, 
   {{0x23d00034,0xe67810da,0x88c401d5,0x00000000}},	//   _तेंद, ейлі_, _یترل, --, 
   {{0x6b8401b2,0x254c012c,0x645c0153,0x00000000}},	//   mwig, těl_, ėrim, --, 
   {{0x3ab00220,0x05840da1,0x356401c0,0x6b8544d7}},	//   _тәтт, тулм, врын_, lwig, 
   {{0x7c380115,0xa4f8552d,0xa2d4090a,0x00000000}},	//   _ĵurk, رکار_, योन्, --, 
   {{0x6b858e3a,0x0684013d,0xa294109a,0x00000000}},	//   nwig, _иган, гапі, --, 
   {{0x0cdc07f7,0x254c0118,0x08bc01e1,0x00000000}},	//   नचुम, pěl_, _àìbò_, --, 
   {{0xc8b400af,0x6b840009,0xe1d400d4,0x3204009d}},	//   _अकाट, hwig, ужнь, кхюн_, 
   {{0x6b84015c,0x9f340046,0xe43401b9,0xd5d8010f}},	//   kwig, лемі, _صفتد, _אַנש, 
   {{0x6b840223,0x0f31358d,0x2bc42e1e,0x4298007b}},	//   jwig, یکید, लैमा, _ينصح_, 
   {{0x6b85be05,0x00000000,0x00000000,0x00000000}},	//   dwig, --, --, --, 
   {{0x6b840af9,0x2f18084c,0xfd10132f,0x80a00b8f}},	//   ewig, торь_, لجر_, गादे, 
   {{0x2d9c02f0,0x00000000,0x00000000,0x00000000}},	//   _švec_, --, --, --, 
   {{0x9b440214,0x5f940166,0x00000000,0x00000000}},	// [311d0] انطو, _сипт, --, --, 
   {{0x6a340114,0x00000000,0x00000000,0x00000000}},	//   инуђ, --, --, --, 
   {{0xceb006a9,0xdd907153,0x6b840009,0x8dc00327}},	//   _היי_, _اوج_, awig, _ངཎརྣ, 
   {{0x6b85be06,0xe8940022,0x00000000,0x00000000}},	//   bwig, иахь, --, --, 
   {{0xdcb001fb,0xb76402dd,0xa78401b9,0x00000000}},	//   ểu_, ттей, لشوو, --, 
   {{0xfbdc0142,0xc7a00116,0x00000000,0x00000000}},	//   _ddêt_, сишк, --, --, 
   {{0x6d981682,0xd57405f5,0xa565be07,0x00000000}},	//   _ṋal, ууль, لدين, --, 
   {{0x057400c6,0x00000000,0x00000000,0x00000000}},	//   امية_, --, --, --, 
   {{0x38900241,0x94741d0a,0x835000f2,0x80c407b6}},	//   _e̟rú_, ندکا, مپيا, ासने, 
   {{0xc5ec15fa,0x27e000c6,0x758001b9,0x8fa401a9}},	//   _کړه_, úine_, _نیتم, ҳаме, 
   {{0x5044346d,0xc144009d,0x8d7001ec,0x7588010a}},	//   ленб, лзэж_, _ﺸﻴﺎﺕ_, _юсав_, 
   {{0x6d9806d6,0x7dc0036b,0x6b8405e4,0x78a80399}},	//   _ḓal, _rеsp, ywig, njgv, 
   {{0x7ea800e4,0x00000000,0x00000000,0x00000000}},	//   _hüpy, --, --, --, 
   {{0x6da43769,0x7ea80166,0xc5c80011,0x62c400db}},	//   қиға, _küpy, _লুটপ, _ۅزۉك, 
   {{0x6b84017a,0xddc4013a,0xc0d00023,0x00000000}},	//   wwig, _jehň, ከሎም_, --, 
   {{0x32040109,0x77780005,0x6b840230,0x9aa00092}},	//   _izny_, _opux, twig, _ለማከል_, 
   {{0x6b85be08,0x0eb801c0,0x60dcc474,0x00000000}},	// [311e0] uwig, _зуны_, èrme, --, 
   {{0xc330025f,0x7f380302,0xd044013f,0xd1cc02d3}},	//   צוב_, _רעיו, ankɔ, _ብሞት_, 
   {{0xda640fb4,0x4994034b,0x6b84017a,0x00000000}},	//   شالي, ышат, swig, --, 
   {{0xccf80212,0x6d5c02d0,0xb7d40066,0x00000000}},	//   _їхні_, mrra, گوها_, --, 
   {{0x6d5c0e14,0x00000000,0x00000000,0x00000000}},	//   lrra, --, --, --, 
   {{0x6d5dbe09,0x63a40428,0x7c38010f,0xb7d40035}},	//   orra, _àini, _ĵuri, دوها_, 
   {{0xf1a400c6,0x7ae9be0a,0x969001d5,0x80c43541}},	//   _اء_, égte, تیلش, ासमे, 
   {{0x6d980084,0x6d5dbe0b,0x58fc025c,0x08c401f0}},	//   _ṋam, irra, _ཟེགས_, _ёбан, 
   {{0x6d5c0730,0xb0a803ce,0x6d5802d2,0x22580210}},	//   hrra, गानग, _ævaf, órko_, 
   {{0x6d5c036e,0xa88801e0,0x00000000,0x00000000}},	//   krra, _яйға_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d5c0023,0x24800332,0x00000000,0x00000000}},	//   drra, _úim_, --, --, 
   {{0x6d5dbe0c,0x00000000,0x00000000,0x00000000}},	//   erra, --, --, --, 
   {{0x3944334b,0x6234ab37,0x2f040008,0xa1940139}},	//   ânsk_, _теку, sögn_, _вакч, 
   {{0x918801af,0xdb0c03e0,0x6d4800e4,0x00000000}},	//   _арыҡ_, lyaç, ádap, --, 
   {{0xed580030,0x6c680276,0xe7c4206b,0x00000000}},	//   áľa_, лшуг_, वनाप, --, 
   {{0x6d5dbe0d,0x600801a9,0xb034104e,0x7ae401e2}},	// [311f0] arra, kоmi, _уныш, هورې_, 
   {{0x20081529,0xdea004f2,0xed5800d0,0xceb401af}},	//   _izai_, _بیسی, šľa_, _кәс_, 
   {{0xaae80212,0x6d5dbe0e,0x39e8b34e,0xeaf81291}},	//   уєте_, crra, хьан_, ارقت_, 
   {{0xa2d4a782,0x78a80007,0xfb8409a5,0x9f5c01e1}},	//   योत्, ujgv, _йыгн, _àwó_, 
   {{0x38c801d5,0xa848007b,0x8c1800ec,0x00000000}},	//   واچی_, الهم_, _ليٽر_, --, 
   {{0x32d80241,0x998400f1,0x59b400bc,0xdb0c0139}},	//   _máyè_, _پلرو, ंहदर, dyaç, 
   {{0x3eb00327,0x32d80248,0x00000000,0x00000000}},	//   _moxt_, _láyè_, --, --, 
   {{0xed640232,0x94780640,0x142401d5,0x00000000}},	//   leží_, тску_, шдим, --, 
   {{0xe73052d4,0x03200fdc,0xdb0c0cad,0x00000000}},	//   _فصل_, одын, _àkók, --, 
   {{0x91800075,0x7940013f,0x6d5dbe0f,0x6d5802d2}},	//   قۇتۇ, rεwf, yrra, _ævag, 
   {{0x420412e7,0x8698011a,0x00000000,0x00000000}},	//   иньо_, _שיעז, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfc3c1497,0x9db80220,0x13a40133,0x00000000}},	//   _loís_, қыру_, _ڕۆکی_, --, 
   {{0xe1f04fe0,0xa2d400cd,0x59b4072e,0x241800c0}},	//   _کسه_, योद्, ंहार, _сочы_, 
   {{0x6d5dbe10,0x692c013d,0x00000000,0x00000000}},	//   urra, _ağen, --, --, 
   {{0xbb18019f,0xfd1c0268,0x32d80241,0x6e3c0334}},	//   _irîy, _ciì_, _fáyè_, sbrb, 
   {{0x4a45be11,0x2480002e,0x8e75251c,0x4f0800db}},	// [31200] инав, _ñime_, _кунч, _инин_, 
   {{0x8a1801ec,0x49940b96,0xbea00408,0x6d5c036e}},	//   نتاس_, ишет, _даьк, prra, 
   {{0x6008022e,0x9f5c0248,0x00000000,0x00000000}},	//   vоmi, _àwò_, --, --, 
   {{0xc76442c6,0x00000000,0x00000000,0x00000000}},	//   لاتى, --, --, --, 
   {{0xc6a4a63b,0x7af4a2e5,0x597401ec,0x997401d5}},	//   ирки, boxt, _қыру, _қурш, 
   {{0x6d58003b,0x46f402e8,0xb3c80154,0x00000000}},	//   _åvas, шчет, াপাড়, --, 
   {{0xbd780023,0x7c2c01e1,0x00000000,0x00000000}},	//   _ብጾቶም_, _ìirí, --, --, 
   {{0x82280023,0xdb0c01e1,0x00000000,0x00000000}},	//   _ተቓላሳ, _àkòk, --, --, 
   {{0xa65404d3,0x2ef8017a,0x82a4470c,0x00000000}},	//   _هێشت, korf_, ашне, --, 
   {{0xb270a97f,0x23bc0ca8,0xd24c03cc,0x32d80241}},	//   ольш, _aájú_, ىچى_, _ráyè_, 
   {{0x2ef9be12,0x26dc3831,0xfd50063f,0x3ab80a1e}},	//   dorf_, mivo_, _dofọ, דמינ, 
   {{0x26dc1b5c,0xddc4012c,0xf990011a,0x00000000}},	//   livo_, _schů, קרר_, --, 
   {{0x23bc0cad,0xa29402d5,0x63a40010,0x2484000d}},	//   _dájú_, _галі, _šinf, memm_, 
   {{0x26ddbe13,0x2484025c,0x9f480055,0x437401af}},	//   nivo_, lemm_, _iyaü_, _буҫт, 
   {{0xe3e80d42,0x23640399,0xee2001ec,0x00000000}},	//   _পরিব, lumj_, дерi_, --, 
   {{0x6ca4554c,0xc05810f5,0xfc3c0561,0x26ddbe14}},	//   оруж, _рік_, _roís_, hivo_, 
   {{0xfc3c068c,0x26ddbe15,0x6d4c0055,0xb5e400cc}},	// [31210] _soís_, kivo_, _ānaś, _ফৰাচ, 
   {{0x248401c7,0x00000000,0x00000000,0x00000000}},	//   hemm_, --, --, --, 
   {{0x24840867,0x2d8c037e,0x63a40005,0x7af40de2}},	//   kemm_, ædet_, _áinf, roxt, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d5833b8,0x81e803d4,0x00000000,0x00000000}},	//   _åvar, _মৰম_, --, --, 
   {{0x60ddbe16,0xd1dc0023,0x69e40022,0x00000000}},	//   hism, ሕሰብ_, èteé, --, 
   {{0x60ddbe17,0x7854190f,0x9f4800b8,0x00000000}},	//   kism, _نیاز_, _ayaü_, --, 
   {{0x6d9806d6,0x60ddac13,0x24840156,0x73740107}},	//   _ḓah, jism, gemm_, ароӣ_, 
   {{0xe8181188,0x00000000,0x00000000,0x00000000}},	//   _вотч_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x95c40032,0xa17401e0,0xe5340408,0x00000000}},	//   _ураҙ, ҡҡәт_, _дехь, --, 
   {{0x60ddbe18,0x2ef804e6,0x7d0c0051,0x00000000}},	//   gism, worf_, _nhcs, --, 
   {{0x2ef9be19,0x200403be,0x32400184,0x60dc6f8d}},	//   torf_, əlik_, _һеҙг, èrma, 
   {{0xd1b80244,0x23bc0241,0x60dc4f58,0x241800d4}},	//   _مابا_, _wájú_, aism, _тією_, 
   {{0x60ddbe1a,0xe18800b2,0x8c780395,0x00000000}},	//   bism, _نئين_, лщат_, --, 
   {{0x26dc05b8,0xe3e80c58,0x00000000,0x00000000}},	//   zivo_, _পৰিব, --, --, 
   {{0x2d85be1b,0x63a5be1c,0x0ae80137,0xba1400d1}},	// [31220] ňme_, _àint, гдай_, ەيلا_, 
   {{0x8e8400c6,0x9f0401d3,0x2d8c005c,0x00000000}},	//   _الده, _ووٹو, ædes_, --, 
   {{0x4998b0b9,0x26dd78d6,0x00000000,0x00000000}},	//   ытая_, vivo_, --, --, 
   {{0xdc8001b9,0xc7c40395,0x363000d1,0x00000000}},	//   _оқсо, йсли, ۋرىس, --, 
   {{0x2d99be1d,0xc050008f,0xca6000c7,0xbeb8036e}},	//   lvre_, לזא_, _нҵақ, rqëv, 
   {{0x7cf00135,0x07a401ec,0x00000000,0x00000000}},	//   għrf, _қазн, --, --, 
   {{0x26ddbe1e,0x60dc0100,0x2d99be1f,0x2484025c}},	//   rivo_, yism, nvre_, temm_, 
   {{0x60ddbe20,0x2d9807ea,0x0b6c001f,0x39540375}},	//   xism, ivre_, _ድርድር_, _לשלם_, 
   {{0x47c40cfc,0xf7400abe,0x26ddbe21,0x7940016b}},	//   _убав, _нето, pivo_, rεwe, 
   {{0x248408cd,0x60dc8e65,0x684401af,0x00000000}},	//   semm_, wism, _ынға, --, 
   {{0x63a495d8,0x92a801e0,0x96b80d1d,0xff5c0142}},	//   _šind, рсыҡ_, _туту_, wrî_, 
   {{0x60dc2a59,0x224c01ab,0x9f981b0a,0x00000000}},	//   uism, sadk_, авму_, --, 
   {{0xe6c400fc,0x4425be22,0x83380b32,0x00000000}},	//   _þjóð, _igo_, _счет_, --, 
   {{0x60ddbe23,0x00000000,0x00000000,0x00000000}},	//   sism, --, --, --, 
   {{0x4424b171,0xb6b8008f,0x30f801d3,0x00000000}},	//   _kgo_, נצלי, _گوٹھ_, --, 
   {{0x6d980084,0xa2d416d1,0x9c387e7e,0x63a4b4a2}},	//   _ḽaw, योर्, рпат_, _àins, 
   {{0x2d8c019b,0x9f041b06,0x63a40077,0x3f980bf1}},	// [31230] æder_, _ووعو, _áind, _urqu_, 
   {{0x2d984a31,0x6bd4007b,0x00000000,0x00000000}},	//   bvre_, ستقر, --, --, 
   {{0x4425be24,0x6d3412c4,0x27e0fd25,0x00000000}},	//   _ogo_, _неэф, úinn_, --, 
   {{0x442558a1,0xc0d00f7c,0x81e800eb,0x00000000}},	//   _ngo_, _ከፊሉ_, _মরা_, --, 
   {{0xe8141d34,0x00000000,0x00000000,0x00000000}},	//   तेला_, --, --, --, 
   {{0x15340120,0x00000000,0x00000000,0x00000000}},	//   оѕир, --, --, --, 
   {{0x44240280,0xa2ac18cc,0x00000000,0x00000000}},	//   _bgo_, जान्, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x44240789,0x00000000,0x00000000,0x00000000}},	//   _dgo_, --, --, --, 
   {{0x4425be25,0xa7b80228,0xb6040171,0xf6743c5a}},	//   _ego_, _улуу_, _apšū, _دارخ, 
   {{0x39500cf9,0x4424010a,0x63a4031c,0x9044009f}},	//   nsxs_, _fgo_, _ġine, ينده, 
   {{0x2eb4925e,0xc950008d,0x4424d0ab,0x9f480055}},	//   ुस्त, ומט_, _ggo_, _ayañ_, 
   {{0xbeb80240,0x2480002e,0x5274014b,0x00000000}},	//   jqës, _ñima_, _дуйу, --, 
   {{0x44240427,0x00000000,0x00000000,0x00000000}},	//   _zgo_, --, --, --, 
   {{0x6d981682,0x7e200261,0x2d99be26,0x8cb41422}},	//   _ḽav, ддрж, uvre_, осач, 
   {{0xc0d001f3,0x81f401f7,0x3cc400db,0x00000000}},	//   _ከፊል_, _ظفير_, олсо_, --, 
   {{0x8b2400d6,0xcb69be27,0xfce02ec9,0xa2b0012c}},	// [31240] ідже, разе_, фото, _अचम्, 
   {{0xda6400c6,0x60c4025c,0x63a400ae,0x9f5c01e1}},	//   كامي, _ċimi, _áine, _áwá_, 
   {{0x2258033f,0x00000000,0x00000000,0x00000000}},	//   órki_, --, --, --, 
   {{0x53c80c00,0xcb69be28,0x00000000,0x00000000}},	//   िनाश, _каме_, --, --, 
   {{0x7f70044e,0xf76dbe29,0x44240129,0x81e803d4}},	//   _እዋናዊ_, ناو_, _rgo_, _মৰা_, 
   {{0x6595be2a,0xbf98010f,0xd7f80212,0x99480014}},	//   заку, יינש, щує_, _گلٲل_, 
   {{0x4425be2b,0xaa8800f1,0x00000000,0x00000000}},	//   _pgo_, _پنځم_, --, --, 
   {{0x75c802dd,0x6440010a,0x00000000,0x00000000}},	//   штің_, ubmi, --, --, 
   {{0x6440002f,0x133800e5,0x5efc00cd,0x00000000}},	//   rbmi, یتیں_, लकम्_, --, 
   {{0x4425be2c,0x661c08a5,0x00000000,0x00000000}},	//   _wgo_, _úrko, --, --, 
   {{0x2731be2d,0x44240165,0xc4c442f4,0x32b401c4}},	//   _hàn_, _tgo_, _وتصو, цгээ_, 
   {{0x4425be2e,0xbeb802d3,0x2730110e,0x00000000}},	//   _ugo_, yqës, _kàn_, --, 
   {{0x2730007f,0xe7e00cb4,0x394400e5,0x00000000}},	//   _jàn_, _खेमा_, ánsz_, --, 
   {{0x20040029,0x273007ae,0x3f88012d,0x41b4007b}},	//   āli_, _màn_, rwcu_, _ومشر, 
   {{0x2731be2f,0x6289be30,0xc5ec0154,0x2d580108}},	//   _làn_, medo, য়েরা_, жись_, 
   {{0x6289be31,0x61fc000d,0x00000000,0x00000000}},	//   ledo, ürlu, --, --, 
   {{0x273001fb,0x62880042,0x6b74004e,0x00000000}},	// [31250] _nàn_, oedo, млту, --, 
   {{0x6289be32,0xb4c40e5b,0x7d00003a,0x00000000}},	//   nedo, _उत्_, _īnsu, --, 
   {{0x3944067c,0x41c844d0,0x00000000,0x00000000}},	//   èns_, ानिस, --, --, 
   {{0xd7f0425b,0x2731be33,0x6289be34,0xb178008f}},	//   ىكا_, _bàn_, hedo, שטאר, 
   {{0x2731be35,0x7cf0025c,0x00000000,0x00000000}},	//   _càn_, għre, --, --, 
   {{0x2731be36,0x62882804,0x41c807b7,0x2be400cc}},	//   _dàn_, jedo, ानास, _খৰকৈ_, 
   {{0xaa58013d,0x661c02d2,0x00000000,0x00000000}},	//   _фису_, _úrkl, --, --, 
   {{0x28f802bf,0x00000000,0x00000000,0x00000000}},	//   _десь_, --, --, --, 
   {{0xf770ad68,0xf41c049b,0x387c0098,0xe61001b9}},	//   _تاز_, ää_, _ibur_, _یشم_, 
   {{0x6289be37,0x63a40113,0xed600118,0xa3cc000d}},	//   gedo, _šinc, ížku_, _रऔर_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc5e4025c,0x657c00a2,0x27300cad,0x00000000}},	//   _སྨྲི, _ärha, _yàn_, --, 
   {{0x76400218,0x387c002e,0x21b83629,0xd2b8010b}},	//   obny, _mbur_, مپیک_, _гуйч_, 
   {{0x62882b00,0xcd7c0092,0x14a801f9,0x00000000}},	//   cedo, _ሕልውና_, कावण, --, 
   {{0x76400a2e,0xc0f40023,0x692c008e,0x217402dd}},	//   ibny, ለሎም_, _işeg, _жуыр, 
   {{0xd7bc0490,0x00000000,0x00000000,0x00000000}},	//   ्नाच, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [31260] --, --, --, --, 
   {{0x387dbe38,0x27300cad,0x3ab00139,0xbf980115}},	//   _abur_, _ràn_, нәст, _פייש, 
   {{0x2731be39,0x3eb80302,0xa2ac0404,0xca6c022e}},	//   _sàn_, _הציב, जात्, _tibо, 
   {{0x2731be3a,0x6289be3b,0x00000000,0x00000000}},	//   _pàn_, zedo, --, --, 
   {{0xfc3c25e6,0x333c031c,0x00000000,0x00000000}},	//   _unía_, jpux_, --, --, 
   {{0x2b41a4a2,0x628915ab,0x387dbe3c,0x2730004d}},	//   mpic_, xedo, _ebur_, _vàn_, 
   {{0x6289be3d,0xb0cc07af,0x2b40067c,0x85440166}},	//   vedo, ासाग, lpic_, чэле, 
   {{0x62880cfd,0x27310013,0x88c40327,0x00000000}},	//   wedo, _tàn_, _གཞིར, --, 
   {{0x2b400354,0x764001d3,0xfc3c01e1,0xd90c0345}},	//   npic_, bbny, _onín_, _ئین_, 
   {{0x86e800c6,0x62880165,0x26c800f2,0x00000000}},	//   _اعرف_, uedo, _بطری_, --, 
   {{0x26cc01c6,0x325005f5,0x860800db,0x31c00395}},	//   _ildo_, эвэр, _اقاق_, есяв, 
   {{0x6289be3e,0x6d9806d6,0x692dbe3f,0x2b400175}},	//   sedo, _ḽas, _eşeg, kpic_, 
   {{0x6289be40,0x14a828e1,0x00000000,0x00000000}},	//   pedo, कारण, --, --, 
   {{0x6288044e,0x73c00150,0x2b400175,0x00000000}},	//   qedo, _سيىم, dpic_, --, 
   {{0xf29423e4,0x22580210,0x00000000,0x00000000}},	//   _זכור_, órku_, --, --, 
   {{0xdfd00592,0xe0500055,0x00000000,0x00000000}},	//   _ليب_, bhāṣ_, --, --, 
   {{0x2b4000c6,0xba28a47a,0x60cdbe41,0x3168012d}},	// [31270] gpic_, مسام_, _ilam, ącze_, 
   {{0x60cc0c11,0x1a6401b9,0x00000000,0x00000000}},	//   _hlam, بیسی_, --, --, 
   {{0xceb0010f,0x6e98009d,0x9874117e,0x589400d4}},	//   _סיט_, _эвэр_, длец, дшлу, 
   {{0xa3cc38d2,0x7c640f54,0x09b000fe,0x1ca40345}},	//   रना_, _عاجل, _টেঙা, _تێری_, 
   {{0x2b400408,0x60cdbe42,0x69d9be43,0xab840c60}},	//   cpic_, _mlam, úver, _пурк, 
   {{0x60cc4375,0xc7a03baf,0xc614015b,0x07a00408}},	//   _llam, тишк, াশনা_, ташн, 
   {{0x60cdbe44,0xa9c400f7,0xc68c009f,0x00000000}},	//   _olam, _كۅكۉ, شِي_, --, 
   {{0x387d3987,0xe89402d5,0xa56404da,0xb4c400c5}},	//   _ubur_, _пась, ردىن, उसे_, 
   {{0x32080210,0x00000000,0x00000000,0x00000000}},	//   ęcym_, --, --, --, 
   {{0x78b9be45,0xa7b8004e,0x00000000,0x00000000}},	//   _houv, _элуу_, --, --, 
   {{0x78b9be46,0xf788e090,0xd1b9be47,0xd5b196be}},	//   _kouv, şçı_, زادا_, _جفا_, 
   {{0x78b8304b,0xd0080261,0x60ccec5b,0xa4d40212}},	//   _jouv, жеме_, _clam, _похі, 
   {{0x78b9be48,0x60cdbe49,0x92b400c6,0x34081411}},	//   _mouv, _dlam, _يحتا, _ازاپ_, 
   {{0x78b863d1,0x60cdbe4a,0x91e000fd,0x00000000}},	//   _louv, _elam, _җәүһ, --, 
   {{0x60ccc078,0x2b400334,0x00000000,0x00000000}},	//   _flam, wpic_, --, --, 
   {{0x78b9be4b,0x60cdbe4c,0x2b41be4d,0x77681cdf}},	//   _nouv, _glam, tpic_, kugx, 
   {{0xa2d407d0,0x0eb800c7,0x32040042,0x4a7400ee}},	// [31280] योक्, _дуны_, _hyny_, дыет, 
   {{0x60cdbe4e,0xf864004b,0x2b41be4f,0x00000000}},	//   _zlam, ېڅلي_, rpic_, --, 
   {{0x2b41be50,0x2d9cbc07,0xdce803ee,0x60cc01b9}},	//   spic_, _éve_, _çoğu, _ylam, 
   {{0x78b8e365,0x33240369,0x2b400051,0x98c401ca}},	//   _couv, _linx_, ppic_, нсіл, 
   {{0x78b9be51,0x2f0401a8,0x38c800f2,0x00000000}},	//   _douv, sögu_, غامی_, --, 
   {{0xb6a001b9,0xa89400e2,0x320400a2,0xe8140210}},	//   кичл, _šķīr, _oyny_, तेगा_, 
   {{0xfd900075,0x78b80607,0xa2ac00b8,0x3a20022e}},	//   ﻟﻐﺎﻥ_, _fouv, जास्, _амрг, 
   {{0x78b9be52,0x6abc008c,0x3324003e,0xd5b001ed}},	//   _gouv, _horf, _ainx_, افٹ_, 
   {{0x60cc08c2,0x68e003ac,0xa0b800c7,0x00000000}},	//   _rlam, _immd, ҧгоу_, --, 
   {{0x60cdbe53,0xc17802bf,0xf7d4008d,0x6abc00db}},	//   _slam, оїм_, _חומש_, _jorf, 
   {{0xa2d406ff,0xe1380006,0x00000000,0x00000000}},	//   योग्, язні_, --, --, 
   {{0x6728016d,0x6aa0013f,0xb9e40023,0x46bc00bc}},	//   _hidj, _ɔmfa, _ዮው_, ्सवह, 
   {{0x351800c8,0x60cdbe54,0x6728aaee,0x6abcc319}},	//   _וואנ, _vlam, _kidj, _oorf, 
   {{0x6abdbe55,0x320400a9,0xdd95b96a,0x213c01fb}},	//   _norf, _fyny_, нагы, _ttvh_, 
   {{0x6729be56,0x60cc8ad7,0x629803d1,0x941c016b}},	//   _midj, _tlam, _iavo, _wowɔ_, 
   {{0x60cdbe57,0x6608020c,0x672801e4,0x62989a62}},	//   _ulam, _mydk, _lidj, _havo, 
   {{0x6299be58,0x33240399,0x66081477,0x6abdbe59}},	// [31290] _kavo, _yinx_, _lydk, _borf, 
   {{0x78b9be5a,0x6298006c,0x6abc00a9,0x2904cb89}},	//   _souv, _javo, _corf, _akma_, 
   {{0x78b9be5b,0x6299be5c,0x77680b6f,0x2129729c}},	//   _pouv, _mavo, wugx, _kiah_, 
   {{0x6299be5d,0x2009be5e,0x6728003e,0x2128020b}},	//   _lavo, _kyai_, _aidj, _jiah_, 
   {{0x6abc39c2,0x78b85e51,0x672802bd,0x212805b1}},	//   _forf, _vouv, _bidj, _miah_, 
   {{0x6abc0cfd,0x2129be5f,0x78b9561b,0x8d941954}},	//   _gorf, _liah_, _wouv, _ቅልቅል_, 
   {{0x290403a0,0x692c013d,0x78b9be60,0x7bc806ea}},	//   _fkma_, _eşeb, _touv, øguf, 
   {{0x212803a2,0x62980076,0x6abc030a,0x320400a2}},	//   _niah_, _aavo, _zorf, _ryny_, 
   {{0x200828b2,0x3205be61,0x52742a20,0x660803b2}},	//   _nyai_, _syny_, нуну, _eydk, 
   {{0x6299be62,0x6728025c,0xa6c8007b,0x00000000}},	//   _cavo, _gidj, _قوقل_, --, 
   {{0x6299be63,0x21280649,0x63a402d2,0x00000000}},	//   _davo, _biah_, _áinn, --, 
   {{0x20080007,0x21280098,0x4175be64,0x00000000}},	//   _byai_, _ciah_, راپس, --, 
   {{0x6298e4f5,0x21285df1,0x41b00132,0x6fe00d79}},	//   _favo, _diah_, _ەمىر, _पेशं, 
   {{0xe3b0424b,0x6299be65,0x3324003e,0x998000c0}},	//   _خرم_, _gavo, _uinx_, nchų_, 
   {{0x57bc02f8,0xa2ac2e35,0xdb140174,0x00000000}},	//   ्नुह, जार्, ðbýa, --, 
   {{0x8b64484d,0xe7e00037,0x00000000,0x00000000}},	//   فاطم, _खइला_, --, --, 
   {{0xc4d000c8,0x6299be66,0x70cc00bc,0xdc880023}},	// [312a0] אגן_, _yavo, ासील, _ምጽራይ_, 
   {{0x6298036b,0x6e88004b,0x6abdbe67,0x89f40006}},	//   _xavo, _ځمکې_, _qorf, няец, 
   {{0x6abdbe68,0x672805be,0x08881075,0x00000000}},	//   _vorf, _ridj, збей_, --, 
   {{0x6729be69,0x212822d5,0x00000000,0x00000000}},	//   _sidj, _xiah_, --, --, 
   {{0x6609be6a,0x6728007f,0x63a40327,0x60dc0100}},	//   _sydk, _pidj, _ġino, èrmi, 
   {{0x3cfc107d,0x261c01f9,0xb0cc0118,0xed580419}},	//   čuve_, मधली_, ासँग, šľu_, 
   {{0x6729be6b,0x6299be6c,0xf77c025c,0x00000000}},	//   _vidj, _ravo, ħħaq_, --, 
   {{0x6299be6d,0x6729be6e,0x692c0311,0x68e00009}},	//   _savo, _widj, _eşec, _ummd, 
   {{0x629813aa,0x7d000048,0x21280ea0,0x1d900092}},	//   _pavo, _ínse, _riah_, ምነቶች_, 
   {{0x6299be6f,0x21280438,0x229800c0,0x00000000}},	//   _qavo, _siah_, _ožkų_, --, 
   {{0x62980851,0x212805b1,0xfc3c0306,0xb0cc28a2}},	//   _vavo, _piah_, _sním_, ासंग, 
   {{0xdfd05de1,0x6299be70,0xe4b8109a,0x91c1be71}},	//   ليج_, _wavo, _іллі_, рәшл, 
   {{0x6299be72,0xe8140073,0x3168033f,0x00000000}},	//   _tavo, तेचा_, ącza_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa1940395,0xdb0c0241,0xfe18012d,0x00000000}},	//   _райч, _àkék, फेंस_, --, 
   {{0xfd11be73,0xfc3c011f,0x00000000,0x00000000}},	//   اجس_, _iník_, --, --, 
   {{0xe7e02871,0x2008004c,0x2b4401c6,0x9ee8007b}},	// [312b0] _खेला_, _uyai_, гэхг, _يفعل_, 
   {{0x2fd800fd,0x1d34023b,0xdec401ee,0x00000000}},	//   şegä_, _иноя, _рәмо, --, 
   {{0x1df8049b,0x9420013f,0x00000000,0x00000000}},	//   _цены_, _ɔpɑw_, --, --, 
   {{0x28f8074d,0xc0f40023,0x00000000,0x00000000}},	//   нехь_, ለፎም_, --, --, 
   {{0x57bcdd06,0xadfc0034,0x81b400cc,0x7bc80162}},	//   ्नेह, _एडऑन_, ছনি_, øgud, 
   {{0x7e7402d0,0x00000000,0x00000000,0x00000000}},	//   _jcxp, --, --, --, 
   {{0xa8a41075,0x99800064,0x00000000,0x00000000}},	//   _өртк, rchų_, --, --, 
   {{0xdb0ceb90,0x81b40154,0x24f40166,0x59241888}},	//   myañ, ছনা_, лчыр, _شکاف, 
   {{0xdb0c0227,0xe35401c0,0x56940124,0xf1c000d7}},	//   lyañ, лтээ, _иаат, _omší_, 
   {{0x1dd0043e,0x00000000,0x00000000,0x00000000}},	//   सनात, --, --, --, 
   {{0xbb18006a,0x8600034c,0xb5a401e0,0x50440150}},	//   _apîk, _پژوه, _ярай, кенб, 
   {{0x85e80014,0xfc3c00d7,0xe4a400f3,0x00000000}},	//   _تِمے_, _dník_, _брљо, --, 
   {{0x2d8c003d,0xf3640c9e,0x22400790,0xc4380a7c}},	//   ħdem_, _чтен, _şike_, _חתני, 
   {{0xb8d00135,0x03d400df,0x00000000,0x00000000}},	//   _ཟོ_, _בונם_, --, --, 
   {{0xd175be74,0xfc3c0030,0x41b0009f,0x7cf0031c}},	//   _рылы, _kníh_, _نمور, għro, 
   {{0xbc60011c,0x00000000,0x00000000,0x00000000}},	//   ивск, --, --, --, 
   {{0x60dc0023,0xfbc007a5,0x00000000,0x00000000}},	// [312c0] ërme, абто, --, --, 
   {{0x692c054e,0x752800e2,0xc5ec00eb,0x00000000}},	//   _aşea, _ligz, য়েটা_, --, 
   {{0x9f540428,0x00000000,0x00000000,0x00000000}},	//   _ògòg_, --, --, --, 
   {{0x6d5c03ac,0x88e40395,0x00000000,0x00000000}},	//   msra, ъжее, --, --, 
   {{0x6d5dbe75,0xa684678d,0x00000000,0x00000000}},	//   lsra, лғай, --, --, 
   {{0x6d5dbe76,0x00000000,0x00000000,0x00000000}},	//   osra, --, --, --, 
   {{0x6d5d9079,0x7d000998,0x09e495c8,0x692c0e2d}},	//   nsra, _ínsc, _ровн, _eğer, 
   {{0x6d5dbe77,0xbd74001f,0x00000000,0x00000000}},	//   isra, _ይግባኝ_, --, --, 
   {{0xc7643cd9,0x872400c7,0x6234209b,0xa07400d1}},	//   _جازى, _амаж, лепу, ңгоч, 
   {{0x02a54a2a,0x6d5c127b,0x752802d0,0x6028002b}},	//   трим, ksra, _eigz, _jīmū, 
   {{0x6d5dbe78,0xfe70030f,0xf310009d,0x00000000}},	//   jsra, یدس_, рдээ, --, 
   {{0x6d5dbe79,0x04447758,0x844407d6,0xf48400f2}},	//   dsra, _редн, _شخصل, _لاهی, 
   {{0xfbdc017a,0x6d5cf612,0x00000000,0x00000000}},	//   _leêr_, esra, --, --, 
   {{0x7529be7a,0x60dc036e,0x6d5c035a,0xa158011c}},	//   _zigz, ërmb, fsra, _заку_, 
   {{0x3cfd14ee,0x6d5c3fc1,0xe3b000f1,0x752800a2}},	//   लवले_, gsra, _خرڅ_, _ümzü, 
   {{0xd34408dc,0x00000000,0x00000000,0x00000000}},	//   _جییه_, --, --, --, 
   {{0xf0e80150,0x6d5c42f7,0xef980166,0x98a401e0}},	// [312d0] _جىيى_, asra, _акыш_, ғиле, 
   {{0x6d5c01bf,0x00000000,0x00000000,0x00000000}},	//   bsra, --, --, --, 
   {{0xaa95be7b,0x6d5c02d0,0x7bc80162,0x00000000}},	//   рихч, csra, øgub, --, 
   {{0xaca400a2,0x00000000,0x00000000,0x00000000}},	//   _diỳs, --, --, --, 
   {{0x97342c6c,0xf77081a7,0xfc3c01e1,0xf094010f}},	//   اکرا, شاش_, _ifí_, ינף_, 
   {{0x79a400c7,0xfc3c00bc,0x7ac40022,0xab8400db}},	//   _ирбе, _sníh_, _рсме, _туюк, 
   {{0x940c00ac,0xaca4010e,0x692c00a2,0xfc3c02d2}},	//   ənən_, _gaỳt, _işen, _kfí_, 
   {{0xa8a40ebe,0x00000000,0x00000000,0x00000000}},	//   _крук, --, --, --, 
   {{0x27e00597,0x4485be7c,0xa49000f2,0xe4c80137}},	//   úint_, убын_, زیوت, ئبىن_, 
   {{0x6d5c0108,0x00000000,0x00000000,0x00000000}},	//   ysra, --, --, --, 
   {{0x7494013e,0x2d8c025c,0x00000000,0x00000000}},	//   _аслӣ_, ħdek_, --, --, 
   {{0xa4e401d5,0x00000000,0x00000000,0x00000000}},	//   _кўчк, --, --, --, 
   {{0xe3b0168d,0xf3c81cc7,0x39400064,0x6d5c02d0}},	//   _وره_, _تباه_, _ltjs_, wsra, 
   {{0x6d5dbe7d,0xfc3d0610,0x0eb8010b,0x73c000fb}},	//   tsra, _afí_, хумы_, _бәүе, 
   {{0x6d5cd245,0xff2001c6,0x10a4030d,0xd7e400ec}},	//   usra, ёмсо, _бийн, _ڀڃ_, 
   {{0x6d5dbe7e,0xe1f011fc,0xfce1be7f,0x00000000}},	//   rsra, _بسه_, босо, --, 
   {{0x6d5c581c,0xca8405f5,0x88c804c5,0x8fa5be80}},	// [312e0] ssra, лгай, লোডক, _сапе, 
   {{0xda65be81,0xcb082abb,0x3cfc0552,0x6d5c127b}},	//   لامي, ريان_, čuva_, psra, 
   {{0xbb60037e,0xbeb80023,0xc7242b8d,0x38c89cad}},	//   _casカ_, yqëz, ңдей, کالی_, 
   {{0x692c0724,0xddc401ef,0xac9802f2,0x00000000}},	//   _eşen, _nehř, _جۆرا_, --, 
   {{0xc6e40220,0x27e00013,0x00000000,0x00000000}},	//   лікп, àin_, --, --, 
   {{0xb8c923db,0x2ca0007d,0x4e7800c8,0x00000000}},	//   _को_, ldid_, גאַצ, --, 
   {{0x2ca000c5,0x0584009d,0x00000000,0x00000000}},	//   odid_, уулм, --, --, 
   {{0x2ca1be82,0xd24c0131,0x00000000,0x00000000}},	//   ndid_, ۈچى_, --, --, 
   {{0xc674bd1e,0x2ca000af,0x940c0134,0x00000000}},	//   _مطاب, idid_, mdeɛ_, --, 
   {{0x2ca03458,0xd6d801ee,0x00000000,0x00000000}},	//   hdid_, _итє_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2ca00ac5,0xa2b00243,0xdb1002d2,0xee840022}},	//   jdid_, _अचक्, _óföt, ҩыро, 
   {{0x9f347707,0x2ca1be83,0xfc3c0162,0x00000000}},	//   регі, ddid_, _knív_, --, 
   {{0x741000b2,0x2ca0000d,0x00000000,0x00000000}},	//   _اوها, edid_, --, --, 
   {{0xf1a181ad,0xfc3c02d2,0x998c01ef,0x00000000}},	//   _грын, _pfí_, _řež_, --, 
   {{0x88c803d4,0x25ec00c5,0x2ca0031c,0x00000000}},	//   লোতক, _अइनी_, gdid_, --, 
   {{0x5f9557bc,0x2480002e,0xacf87a9c,0x692c0139}},	// [312f0] _типт, _ñimu_, унту_, _pşen, 
   {{0x2ca000af,0x3f98047e,0x00000000,0x00000000}},	//   adid_, _isqu_, --, --, 
   {{0xfc3c032e,0xec1401e2,0xede4022e,0x00000000}},	//   _tfí_, لوېد, _гўян, --, 
   {{0x49a401e0,0x2ca00067,0x58d40798,0x00000000}},	//   шыуғ, cdid_, јодт, --, 
   {{0x692c013d,0xa878007b,0x59b400bc,0x2b44009d}},	//   _işel, احمر_, ूहहर, _гэсг, 
   {{0xff5c011f,0x05b421b8,0x00000000,0x00000000}},	//   isî_, _अपशब, --, --, 
   {{0xa5640597,0xadc4035b,0xe6640107,0x54d40120}},	//   مدين, _osẽv, стчо, ициу, 
   {{0x25a80472,0x00000000,0x00000000,0x00000000}},	//   ادوي_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd1840408,0x067400f7,0xa2ac1bd6,0x66040205}},	//   алой, _ەنەڭ, जाग्, şika, 
   {{0xc200000d,0x2ca0058a,0x00000000,0x00000000}},	//   _रुआब_, ydid_, --, --, 
   {{0x2ca0058a,0x92b403c7,0x67301d1d,0x00000000}},	//   xdid_, احکا, _óhjá, --, 
   {{0x60dc02d3,0x2ca003b2,0x00000000,0x00000000}},	//   ërma, vdid_, --, --, 
   {{0x8e740228,0x2ca03d20,0xaca40023,0xade8009d}},	//   шумч, wdid_, _ወኪሎም_, гагv, 
   {{0x2d8dbe84,0x5044005e,0xe3b000cf,0x00000000}},	//   ïde_, _кейб, _ورۇ_, --, 
   {{0x2ca165fb,0x00000000,0x00000000,0x00000000}},	//   udid_, --, --, --, 
   {{0x2ca1be85,0x66d401e1,0x7e7816a3,0x00000000}},	// [31300] rdid_, _làka, đupr, --, 
   {{0x692c7b47,0x0dc80139,0xc33002e4,0x7bc80162}},	//   _eşel, _алой_, קוב_, øgua, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc7c549af,0x09040220,0x2ca00009,0x2b583413}},	//   исли, шпен, qdid_, _میرد_, 
   {{0x1ac40183,0x00000000,0x00000000,0x00000000}},	//   _এগৰা, --, --, --, 
   {{0x66d401e1,0x31680034,0x692c7aa0,0xa5f84f0c}},	//   _bàka, ńczy_, _işem, лелу_, 
   {{0xf41c09a5,0x9f540086,0x00000000,0x00000000}},	//   ýän_, _ògög_, --, --, 
   {{0x399805e1,0x00000000,0x00000000,0x00000000}},	//   _בילד, --, --, --, 
   {{0xd78c0020,0x823c001f,0xc6900014,0x86940114}},	//   _መግቢያ_, _አበረታ, _وِر_, _вјеч, 
   {{0x555001d9,0x7b080254,0x00000000,0x00000000}},	//   _کھور, lüur, --, --, 
   {{0x3a34025f,0x609805d4,0x217802d5,0x00000000}},	//   ירים_, هندس_, ыйны_, --, 
   {{0xa2d401ec,0xd4f40153,0x00000000,0x00000000}},	//   _گيتت, _лячы, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x66d4002e,0xe3b000ec,0x00000000,0x00000000}},	//   _yàka, _ورڇ_, --, --, 
   {{0xeda5be86,0x00000000,0x00000000,0x00000000}},	//   ошто, --, --, --, 
   {{0x6440e6a1,0xacf9be87,0x00000000,0x00000000}},	//   ncmi, ансу_, --, --, 
   {{0xab38301d,0xdfd07b63,0x00000000,0x00000000}},	// [31310] ипту_, _ريد_, --, --, 
   {{0xba4405f5,0x39a51963,0x6fe001f9,0x00000000}},	//   рхай, ишев, _पेटं, --, 
   {{0xe93801ed,0x692c0166,0x00000000,0x00000000}},	//   لسنت_, _eşem, --, --, 
   {{0x53980023,0xe7080271,0x9e840345,0x00000000}},	//   _ቆልዑት_, یتون_, _ئاکۆ, --, 
   {{0x8c1800ec,0x45a000d1,0x00000000,0x00000000}},	//   _ميٽر_, ۋەكك, --, --, 
   {{0x66f400cf,0xdb0c0241,0x6d48041e,0x00000000}},	//   опчу, _àkàk, ídag, --, 
   {{0xfd1c0051,0x00000000,0x00000000,0x00000000}},	//   _khì_, --, --, --, 
   {{0xbb180998,0x9478177b,0xddc40055,0xf8b00150}},	//   _epît, уску_, _adhū, _بةس_, 
   {{0x130805f5,0x7cf0003d,0x67d5be88,0x98a400fb}},	//   лний_, għri, _доту, _киңе, 
   {{0xa9280118,0xfc3c013a,0x00000000,0x00000000}},	//   požá, _znít_, --, --, 
   {{0x10a40946,0x00000000,0x00000000,0x00000000}},	//   бинн, --, --, --, 
   {{0xfd1c01fb,0xe4740153,0x00000000,0x00000000}},	//   _nhì_, _душэ, --, --, 
   {{0xe4ec00cd,0x00000000,0x00000000,0x00000000}},	//   _जगति_, --, --, --, 
   {{0xc3300375,0xfc3c0ca8,0x00000000,0x00000000}},	//   _זוג_, _onís_, --, --, 
   {{0x7bc8022c,0x290c05f7,0x7af40175,0x7410009f}},	//   øgun, _ídag_, dnxt, _اوڇا, 
   {{0xfd1c3a75,0xcd29be89,0xfce0871a,0xc2100375}},	//   _chì_, ужбе_, посо, _מהו_, 
   {{0xfc3c4e05,0xa2ac0073,0x00000000,0x00000000}},	// [31320] _anís_, जाच्, --, --, 
   {{0x4d6400d8,0xfc3c01ef,0x00000000,0x00000000}},	//   _лков, _snít_, --, --, 
   {{0x63a40077,0xfe980375,0xdbe8015b,0x09e40395}},	//   _áinv, _גיימ, _কুদস_, щожн, 
   {{0xc76407a7,0x692c00fd,0xfd1c0208,0x00000000}},	//   ماتى, _işek, _ghì_, --, 
   {{0x7bb00166,0x6d480115,0x00000000,0x00000000}},	//   _нөфу, ŭdad, --, --, 
   {{0xbb405d72,0xd90c006c,0xd7f80212,0x06740108}},	//   _херк, _ییل_, шує_, судя, 
   {{0x6b85be8a,0xb0c81d94,0x27200051,0x00000000}},	//   ltig, _लवंग, hòng_, --, 
   {{0x1ce40327,0x6b85be8b,0x3944007b,0x98340153}},	//   ྨིར_, otig, ínse_, _дэфі, 
   {{0x6b85be8c,0xdddc033f,0xfc3c01ef,0x64400200}},	//   ntig, _łyże, _knír_, rcmi, 
   {{0x6b85be8d,0x77c46d64,0x00000000,0x00000000}},	//   itig, _улуг_, --, --, 
   {{0x6b85be8e,0x60dc0240,0x974c0023,0xe4480137}},	//   htig, ërmo, _ዝሰደድ, _ەلچى_, 
   {{0x6b84ae44,0x75d0007b,0x00000000,0x00000000}},	//   ktig, _عينا, --, --, 
   {{0x6b8400c8,0x00000000,0x00000000,0x00000000}},	//   jtig, --, --, --, 
   {{0x66d401e1,0x00000000,0x00000000,0x00000000}},	//   _màko, --, --, --, 
   {{0x6b85be8f,0x691809d7,0xfd1c01fb,0x00000000}},	//   etig, víen, _phì_, --, 
   {{0x62880d47,0x9d140212,0xc0580212,0x7bdce22c}},	//   lfdo, ідач, _сік_, tzqu, 
   {{0x6b85be90,0x6c540228,0x692c75d4,0x60dc0332}},	// [31330] gtig, якту, _eşek, mhsm, 
   {{0x25ac03b2,0xfaf00127,0x628801d5,0x00000000}},	//   _ordl_, أثر_, nfdo, --, 
   {{0xfd1c01dc,0x6b8432ff,0xc8540020,0x999822c3}},	//   _thì_, atig, _ሊቀመን, ркет_, 
   {{0xf73402d3,0xa3b8012c,0x394400e2,0xdcec0024}},	//   _እተፈላ, ङमा_, īns_, _įkėl, 
   {{0x66040fb9,0x6b8416b8,0x6d58032e,0x00000000}},	//   şikl, ctig, _ævar, --, 
   {{0xf41c0209,0x26dc047e,0x00000000,0x00000000}},	//   ýäm_, ghvo_, --, --, 
   {{0x58d5017b,0xddd40034,0xfc3c067c,0x15b8e072}},	//   _довт, lazł, _unís_, рылы_, 
   {{0x934578fd,0x628801f5,0xa9c41291,0x00000000}},	//   оние, efdo, _عزّو, --, 
   {{0xf3fc00d8,0xc480013d,0x00000000,0x00000000}},	//   çã_, флык, --, --, 
   {{0x26dc047e,0x27e000a3,0x1dc8090a,0x00000000}},	//   chvo_, ùine_, रहात, --, 
   {{0x42c401c0,0x6b842574,0x00000000,0x00000000}},	//   цгэн_, ztig, --, --, 
   {{0x60dc020c,0x0f00190e,0x6b8401a9,0x00000000}},	//   ghsm, लक्स_, ytig, --, 
   {{0x940404fb,0x7bc8022c,0xd1b800db,0x6b85bde0}},	//   _بوشه, øgul, _چابا_, xtig, 
   {{0x161c141f,0x6b8401bf,0x00000000,0x00000000}},	//   _फरार_, vtig, --, --, 
   {{0x91e5be91,0x333c031c,0xe18800ec,0x226400d7}},	//   _фойе, lqux_, _هئين_, šskú_, 
   {{0xb4c402ab,0x60dc0112,0xfd4c00a2,0x00000000}},	//   _ईको_, chsm, lynỳ, --, 
   {{0x6b85be92,0x63a454fc,0x7c5401d5,0x333c0327}},	// [31340] utig, _áint, زللر_, nqux_, 
   {{0x6b85be93,0xc9d5be94,0x3ab02751,0xaca40241}},	//   rtig, يزاب, мәст, _idọt, 
   {{0x6b85be95,0x88e4005b,0x00000000,0x00000000}},	//   stig, ожже, --, --, 
   {{0x6b85be96,0x66d401e1,0x00000000,0x00000000}},	//   ptig, _pàko, --, --, 
   {{0x6b85be97,0x7cf0003d,0xd90c221d,0x387c0175}},	//   qtig, għru, ایق_, _dcur_, 
   {{0x387c0023,0x09e40229,0xdbc40b01,0x00000000}},	//   _ecur_, _догн, _эҳуд_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x387c00c6,0x2720007f,0x00000000,0x00000000}},	//   _gcur_, dòne_, --, --, 
   {{0xaca401f2,0xa85405a2,0x63a4031c,0x691800e4}},	//   _ndọt, _меңә, _ġins, níem, 
   {{0x63a42151,0x27202561,0x7a20022e,0x00000000}},	//   _šins, fòne_, kеtl, --, 
   {{0xaca402e3,0x60dc0c8c,0x62880076,0xf2840014}},	//   _adọt, thsm, rfdo, تھنو_, 
   {{0x65780433,0x00000000,0x00000000,0x00000000}},	//   muvh, --, --, --, 
   {{0x82a5be98,0x9e340209,0x00000000,0x00000000}},	//   _мадж, зегч, --, --, 
   {{0x7bc80174,0xf770011a,0xdb0c00e5,0x00000000}},	//   øgum, וקש_, ékün, --, 
   {{0x78142d8f,0xddc405d1,0x3ce806ed,0xefe00092}},	//   _तर्क_, _dehş, аќам_, _ነዋይ_, 
   {{0x63a40077,0x20fc01e4,0x692c00ee,0x9c3802e8}},	//   _áins, mĉio_, _işew, спат_, 
   {{0x65780455,0xf8a800dc,0x00000000,0x00000000}},	// [31350] huvh, _घोषय, --, --, 
   {{0x387dbe99,0x65780433,0x9f2000d1,0x6d480118}},	//   _scur_, kuvh, _سۈزۈ, ídac, 
   {{0x0e980375,0x00000000,0x00000000,0x00000000}},	//   _השתל, --, --, --, 
   {{0x65781682,0xdde40032,0x00000000,0x00000000}},	//   duvh, _дәғү, --, --, 
   {{0xba748123,0xe89800e5,0xa7a80023,0x161c000d}},	//   _واست, زموں_, _ቀልጢፈ_, _फरहर_, 
   {{0x60dc02d3,0x6d8801d9,0xdb240108,0x00000000}},	//   ërmj, _دۅہہ_, öpäj, --, 
   {{0x546800f7,0x764000e5,0x00000000,0x00000000}},	//   байм_, rcny, --, --, 
   {{0x2ec9be9a,0xb8b4007b,0x00000000,0x00000000}},	//   _रक्त, _بإست, --, --, 
   {{0x15b80184,0x225c0010,0x00000000,0x00000000}},	//   рыһы_, _bevk_, --, --, 
   {{0x03212e74,0x225c0010,0xf6d40244,0x00000000}},	//   ндын, _cevk_, _بزرد, --, 
   {{0xf98c01ec,0xe6c4032e,0x00000000,0x00000000}},	//   енiн_, _þjáð, --, --, 
   {{0x7d0000d2,0xe6340150,0x10a401a9,0x00000000}},	//   _ínsh, _تۋىت_, чимн, --, 
   {{0x087400c8,0x2d9c0005,0x20540006,0x333c031c}},	//   הערט_, _ávez_, ьтэр, qqux_, 
   {{0x91e5be9b,0x00000000,0x00000000,0x00000000}},	//   _ноле, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd83802b5,0x225c05d1,0x01340375,0x00000000}},	//   _ngō_, _zevk_, _צרפת_, --, 
   {{0xfc002852,0xfce0014b,0x8d7400e5,0xe820000d}},	// [31360] епто, хото, _کاخا, _बरधा_, 
   {{0x9e9419c5,0x25ec00c5,0x2bf00073,0x00000000}},	//   _قاپچ, _अइली_, _घेणं_, --, 
   {{0x8c45be9c,0xbe380375,0xf1c83af4,0x2d9c0129}},	//   _нене, _לעית, ाहिन, _ève_, 
   {{0xacb40075,0xbf6403e6,0x6578014f,0x569400f1}},	//   _تەرب, _بڵێم_, vuvh, ېديځ, 
   {{0x26c801e0,0xf76c0a12,0x00000000,0x00000000}},	//   оған_, هاو_, --, --, 
   {{0x65780810,0xf1c829d7,0x066400cf,0x00000000}},	//   tuvh, ाहान, ساتپ, --, 
   {{0x39e400a7,0x80bc00cd,0x00000000,0x00000000}},	//   _едро_, षामे, --, --, 
   {{0x6578ca52,0x225c05d1,0x692c0205,0x857801f0}},	//   ruvh, _sevk_, _aşev, _ҳсдт_, 
   {{0x66d40694,0x200405d1,0x225c0010,0x69d80ac8}},	//   _jàkk, ğlik_, _pevk_, øvef, 
   {{0x2004fb54,0xfc3c0077,0x66d41bce,0x88bc00eb}},	//   şlik_, _maía_, _màkk, _আতিক, 
   {{0x66d40694,0x32b401c6,0x6578016d,0x00000000}},	//   _làkk, чгээ_, quvh, --, 
   {{0x7bc80174,0x00000000,0x00000000,0x00000000}},	//   øguk, --, --, --, 
   {{0x7d000998,0x66d4002e,0x88ac00cc,0x00000000}},	//   _ínsi, _nàkk, _ককাক, --, 
   {{0xdd94916f,0x00000000,0x00000000,0x00000000}},	//   магы, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x66d41574,0xfc3c617f,0xd4740092,0x00000000}},	//   _bàkk, _baía_, _በቀድሞ_, --, 
   {{0x66d40de2,0xfc3c0a90,0xab940114,0x00000000}},	// [31370] _càkk, _caía_, натљ, --, 
   {{0x66d41bce,0x00000000,0x00000000,0x00000000}},	//   _dàkk, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfc3c067c,0x00000000,0x00000000,0x00000000}},	//   _faía_, --, --, --, 
   {{0x66d400e8,0xcc840244,0x00000000,0x00000000}},	//   _gàkk, _تۆقه_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa9a402a9,0x9954109a,0x38c8009d,0x947800d4}},	//   _пиёд, _ікац, _луан_, оспу_, 
   {{0x65680175,0x66d400e8,0x3688030d,0x00000000}},	//   _dvdh, _yàkk, _ӳсен_, --, 
   {{0x5274405c,0x87e0004b,0xd29800d4,0x7bc80174}},	//   муну, _لګول, отні_, øguh, 
   {{0xc7a40014,0x69c800d8,0x69d8143a,0x00000000}},	//   _زٔمی, _àdec, øveg, --, 
   {{0x91e48c91,0x35680354,0x00000000,0x00000000}},	//   фоне, _ыран_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x692c0724,0x27200109,0x88c8009e,0x00000000}},	//   _işet, lòna_, লোকক, --, 
   {{0x3165be9d,0x66d41bce,0xe8200210,0x00000000}},	//   _tvnz_, _ràkk, _बरसा_, --, 
   {{0xfc3c617f,0x272006d9,0x66d41574,0x8c45be9e}},	//   _saía_, nòna_, _sàkk, дебе, 
   {{0x66d4002e,0x00000000,0x00000000,0x00000000}},	//   _pàkk, --, --, --, 
   {{0x7cf00327,0x00000000,0x00000000,0x00000000}},	// [31380] għrq, --, --, --, 
   {{0xd1e40020,0x89f4007b,0x7bc800e4,0x66040205}},	//   _ምርት_, وثائ, ägua, şiki, 
   {{0xe820069f,0x8885be9f,0x66d400e8,0xdf00010b}},	//   _बरहा_, длеж, _wàkk, _сүрй, 
   {{0x2721bea0,0x66d41bce,0x38c805af,0x00000000}},	//   dòna_, _tàkk, يانی_, --, 
   {{0x60dc0023,0x87280006,0xe69400c7,0x00000000}},	//   ërmi, оўка_, еилы, --, 
   {{0x2720068c,0x201c0165,0x45480108,0x00000000}},	//   fòna_, _ɡwi_, очим_, --, 
   {{0xe820069f,0x69d944cf,0x69740451,0x00000000}},	//   _बरवा_, øved, _سڏائ, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd90c13e1,0xb40405f5,0xb6c801d3,0x06851a6e}},	//   _این_, дээж_, _ڈالے_, _оган, 
   {{0xb6c800f8,0xc32c8337,0x45d413d6,0x00000000}},	//   _والے_, جەت_, _оцет, --, 
   {{0x26cc021c,0xfa740375,0x34a00014,0x7174009d}},	//   _iodo_, ועית_, رمیٲ, мбэр_, 
   {{0x26cc0200,0x00000000,0x00000000,0x00000000}},	//   _hodo_, --, --, --, 
   {{0x26cdbea1,0x9f580570,0x6d48012c,0x02c40137}},	//   _kodo_, ìyàn_, ídan, _ойдо, 
   {{0x7ce0033d,0x26cc0438,0xfc3c04d4,0xeff00023}},	//   _kõrg, _jodo_, _caín_, ጀርያ_, 
   {{0x26cdbea2,0xfd1012a5,0xf1a17b88,0xb1a02eca}},	//   _modo_, نجر_, _арын, _ашык, 
   {{0x26cc0248,0x15f0000d,0x19580022,0x00000000}},	//   _lodo_, _अइसर_, ҧазы_, --, 
   {{0x2720067c,0x1ab401c6,0x26cd99d1,0xa3d401f9}},	// [31390] zòna_, нбая, _oodo_, _सॅम_, 
   {{0x26cdbea3,0x60cdbea4,0x00000000,0x00000000}},	//   _nodo_, _hoam, --, --, 
   {{0x7ce000af,0x27e000a3,0x63a003cb,0x98742d57}},	//   _nõrg, ùinn_, hwmn, елец, 
   {{0x26cc0165,0x2fe403ee,0x28f80408,0x661c02d2}},	//   _aodo_, _örgü_, мехь_, _úrky, 
   {{0x26cdbea5,0x60cdbea6,0x00000000,0x00000000}},	//   _bodo_, _moam, --, --, 
   {{0x26cc09c2,0x60cc00ad,0x272005da,0x3cfc01a6}},	//   _codo_, _loam, tòna_, čuvu_, 
   {{0x26cdbea7,0x60cc009a,0xa5640849,0x546800db}},	//   _dodo_, _ooam, ندين, пайм_, 
   {{0x60ccbf7c,0x2720067c,0x69d80158,0x2e380677}},	//   _noam, ròna_, øvee, ורוש_, 
   {{0xf7700372,0x7d000b60,0x78b8013c,0x92f401ce}},	//   _جاز_, _ínsu, _inuv, ечні, 
   {{0xd174eaae,0x26cdbea8,0x27200100,0xd4f401e0}},	//   нымы, _godo_, lònn_, ьяһы, 
   {{0x60cc014c,0xd1b9bea9,0xcb1002e4,0x673800d0}},	//   _boam, سادا_, רלי_, žajú, 
   {{0x60cc1368,0xfc3c0005,0x6adc102f,0xd00806ed}},	//   _coam, _saín_, _यत्र, земе_, 
   {{0x60cc00a8,0xe3b01698,0x26cc82a2,0x7ce00254}},	//   _doam, _پرن_, _yodo_, _mõrd, 
   {{0x691800d2,0x91f40051,0x00000000,0x00000000}},	//   ríei, hái, --, --, 
   {{0x60cdbeaa,0x71040022,0x7bc81196,0x76900342}},	//   _foam, _аҧна, ägun, mıyı, 
   {{0x661c2d75,0x7690046c,0x60cd2584,0xc06c00bc}},	//   _ørke, lıyı, _goam, íští, 
   {{0x8fd058c7,0xfc3c0077,0x4b249771,0x8b2427a8}},	// [313a0] _сәнә, _taín_, емав, едае, 
   {{0x78b800dc,0x09e42c68,0x76903535,0x60dc036e}},	//   _anuv, нозн, nıyı, ërmv, 
   {{0x26cdbeab,0x93ec016b,0x00000000,0x00000000}},	//   _rodo_, mdeε_, --, --, 
   {{0x26cdbeac,0x89143dca,0x692c0205,0x00000000}},	//   _sodo_, ربائ, _aşer, --, 
   {{0x26cdbead,0xe6a40116,0x69d81347,0x7ce00254}},	//   _podo_, вуйү, øveb, _sõrg, 
   {{0x7ce000c5,0x26cc0067,0x518c0150,0x00000000}},	//   _põrg, _qodo_, _ﺒﺴﺎﻁ_, --, 
   {{0x26cdbeae,0xd9b01473,0xc89400ea,0x769006be}},	//   _vodo_, _پەند, _прањ, dıyı, 
   {{0x6934402b,0x7ce000af,0x7cf8023a,0xe5103711}},	//   _شکار, _võrg, märä, ावधि_, 
   {{0x26cc5599,0x29dc1682,0x2905beaf,0x68e001a9}},	//   _todo_, ḽa_, _ijma_, _ilmd, 
   {{0x60cdbeb0,0x0268049b,0xf7401fbe,0x7ce00037}},	//   _soam, чший_, _сефо, _tõrg, 
   {{0x29dc1682,0x60cd0097,0x857405d9,0x7ce00037}},	//   ṋa_, _poam, _سدائ, _hõre, 
   {{0x7ce00254,0xe1f80137,0xdfd401f4,0x00000000}},	//   _kõre, згү_, вомы, --, 
   {{0x60cc0170,0x4e14134e,0x43740484,0xf8b0011a}},	//   _voam, _दुबई_, _чует, אשר_, 
   {{0x60cc0134,0x7cf8088b,0x76904283,0x00000000}},	//   _woam, kärä, cıyı, --, 
   {{0x60cdbeb1,0x20e4014b,0xd3340064,0x00000000}},	//   _toam, _аспҳ, _рэцы, --, 
   {{0x29dc1aa1,0x7cf80166,0x00000000,0x00000000}},	//   ḓa_, därä, --, --, 
   {{0x7ce00254,0x60dc036e,0x00000000,0x00000000}},	// [313b0] _nõre, ërmu, --, --, 
   {{0x2904022f,0x68e00036,0x78b9059e,0xca740014}},	//   _ajma_, _almd, _snuv, ٖنٕک, 
   {{0x21280649,0x7cf80724,0x7e640784,0xce340014}},	//   _khah_, gärä, majp, _لوٝک, 
   {{0xbcf80003,0x7e64014f,0x76900b97,0x1ca40345}},	//   _དམིཊ_, lajp, zıyı, _جێری_, 
   {{0x7ce0007d,0xf1a4012c,0xefe002d3,0xfc3c0241}},	//   _võrd, _छैनन, _ነጋዶ_, _igí_, 
   {{0x7e64accc,0x21280066,0x68e003e3,0x7cf8008e}},	//   najp, _lhah_, _elmd, bärä, 
   {{0x7af5beb2,0xd91400c0,0x7cf8013d,0x00000000}},	//   mixt, _адвы, cärä, --, 
   {{0x78b800df,0xa9351ed1,0xe6111147,0x21280051}},	//   _unuv, _бесш, حشه_, _nhah_, 
   {{0x7e65beb3,0x7ce000c5,0x142402e8,0x18b000fb}},	//   kajp, _kõrb, ъдим, _бәҙр, 
   {{0x2129beb4,0x7af5beb5,0xd90c01ed,0x1fb8009e}},	//   _ahah_, nixt, _ایچ_, ুনাস, 
   {{0x212806a3,0xd5a40764,0x769067ab,0x03207a6f}},	//   _bhah_, _खनिज, rıyı, рдэн, 
   {{0x21280842,0x76900790,0x25b81d0e,0x00000000}},	//   _chah_, sıyı, _árla_, --, 
   {{0x6f1c074d,0x66044953,0x2128e66c,0x332413eb}},	//   tlrc, şikt, _dhah_, _thnx_, 
   {{0xc7d408a8,0x00000000,0x00000000,0x00000000}},	//   דושי_, --, --, --, 
   {{0x910401af,0x00000000,0x00000000,0x00000000}},	//   _ипке, --, --, --, 
   {{0x212827cc,0x200c0085,0x691800e4,0x00000000}},	//   _ghah_, ékié_, níet, --, 
   {{0xbb4001ec,0x4f24014b,0x4aa800db,0x00000000}},	// [313c0] иетк, _идиб, мкан_, --, 
   {{0xd0f00241,0xcdf4010b,0xaee400b8,0x5ba402dd}},	//   _faṣẹ, _ачмы, _kaṭv, ылуғ, 
   {{0x7ce0000d,0x5e78010f,0x00000000,0x00000000}},	//   _sõre, _אָרד, --, --, 
   {{0x1cc01b4b,0xc76412b7,0x080804fb,0x8c44a861}},	//   _ཁོར_, ناتى, وزشي_, _шеме, 
   {{0x2ca1beb6,0x38c803ff,0x7bc80162,0x00000000}},	//   meid_, بالی_, øgut, --, 
   {{0x2ca1beb7,0x7cf8023a,0xda65155a,0x7ce0000d}},	//   leid_, pärä, _مافي, _võre, 
   {{0x5fa81533,0x39b000f1,0x00000000,0x00000000}},	//   _चैनल, _پینځ, --, --, 
   {{0x2ca1beb8,0x68e00175,0x35b00395,0xd24c00d1}},	//   neid_, _ulmd, рбър, ۋچى_, 
   {{0x1cc00003,0x2ca00363,0x7e640113,0xd6e000cc}},	//   _ཁོལ_, ieid_, yajp, _বদৰপ, 
   {{0x2ca102f8,0x2128138f,0xe51000dc,0x00000000}},	//   heid_, _shah_, ावहि_, --, 
   {{0x60f8bd3e,0xf41c09a5,0x21280652,0x2ca1beb9}},	//   ення_, ýär_, _phah_, keid_, 
   {{0x2ca0d43e,0x00000000,0x00000000,0x00000000}},	//   jeid_, --, --, --, 
   {{0x2ca000af,0x2295beba,0xa2940111,0xfeb81888}},	//   deid_, _биля, _балі, واست_, 
   {{0x4425bebb,0xb9e4044e,0xe3b00344,0x66d40241}},	//   _izo_, _ኮፍ_, _پرچ_, _tàku, 
   {{0x44240109,0x7e646326,0xa1940354,0xc0c8009b}},	//   _hzo_, rajp, _сайч, _жупе_, 
   {{0x2ca1bebc,0x20080218,0x9c8801c6,0x3234011a}},	//   geid_, _txai_, эхгv, _בטון_, 
   {{0x7e640113,0x00000000,0x00000000,0x00000000}},	// [313d0] pajp, --, --, --, 
   {{0x60ddbebd,0x7e640113,0x39400010,0xab940212}},	//   lksm, qajp, _pujs_, рифі, 
   {{0x2ca1bebe,0x60dc02d0,0xa3d4000d,0x00000000}},	//   beid_, oksm, _सॅस_, --, 
   {{0x4425bebf,0x60ddbec0,0x98ac068f,0x2ca0030d}},	//   _ozo_, nksm, _mieć_, ceid_, 
   {{0xd7f40a52,0x44242c36,0x08d80150,0x00000000}},	//   ызды, _nzo_, _ﺃﺠﻬﺯ, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4425bec1,0x29886997,0x998402da,0x00000000}},	//   _azo_, _исто_, _حلزو, --, 
   {{0x60ddbec2,0x1cc00003,0x26dc01e4,0xf8c407f7}},	//   jksm, _ཁོས_, akvo_, _रचिय, 
   {{0xf1c001ef,0x00000000,0x00000000,0x00000000}},	//   _olší_, --, --, --, 
   {{0x44240084,0xfe000490,0x2ca11ded,0xaee400b8}},	//   _dzo_, ळपास_, zeid_, _paṭv, 
   {{0x4425bec3,0xf8c403e5,0x38740092,0x2ca000e5}},	//   _ezo_, _रचाय, _አምስቱ_, yeid_, 
   {{0xf4841614,0x45580375,0x61fc007b,0x44240139}},	//   _јужн, _נכנס, úrla, _fzo_, 
   {{0x8e7407d6,0xe2a9bec4,0x744c001f,0x2ca05886}},	//   лувч, راین_, መንግሥ, veid_, 
   {{0x60dc002d,0x2ca0002d,0x43702732,0x00000000}},	//   aksm, weid_, _اهور, --, 
   {{0x2ca1bec5,0x44240083,0xd175106d,0xe820547d}},	//   teid_, _zzo_, _сылы, _बर्थ_, 
   {{0x2ca0062c,0x6ef406be,0x8ba401d5,0x00000000}},	//   ueid_, _mübə, либж, --, 
   {{0x2ca1bec6,0x0c24074d,0xc4d0011a,0x00000000}},	// [313e0] reid_, уман, זגן_, --, 
   {{0x2ca0033d,0x00000000,0x00000000,0x00000000}},	//   seid_, --, --, --, 
   {{0x2ca1bec7,0x7bc806ea,0x5b340139,0xadc400fb}},	//   peid_, øgur, рэту, _танһ, 
   {{0x7d7805e1,0xfaa00aac,0x48080395,0x00000000}},	//   _אנטו, _қасо, неен_, --, 
   {{0xa2a40073,0x38c800e5,0x00000000,0x00000000}},	//   _कसल्, عامی_, --, --, 
   {{0xbb180075,0x37d000cc,0x00000000,0x00000000}},	//   ﻴﯩﻦ_, _দেহৰ, --, --, 
   {{0xc72402dd,0x44242478,0x60dd137e,0x09e44c92}},	//   _ұдай, _szo_, yksm, _совн, 
   {{0x44240841,0x26dc008f,0x00000000,0x00000000}},	//   _pzo_, skvo_, --, --, 
   {{0xe7b401d9,0x98ac033f,0x4804f3f0,0x80ac000d}},	//   _خۅشد, _sieć_, _спав, _जोगइ, 
   {{0x02a41955,0x3f8c00c7,0x7ce0000d,0x7a20022e}},	//   урим, _ãgui_, _mõra, mеtr, 
   {{0x775402d3,0xf31001c6,0x42c80166,0x00000000}},	//   _ዝተሳተ, сдээ, _үген_, --, 
   {{0x04445938,0x3a340375,0xf4847be0,0x4424005a}},	//   _седн, טרים_, _ماهی, _tzo_, 
   {{0x4425bec8,0x60ddbec9,0xb4f8010f,0x00000000}},	//   _uzo_, rksm, _אלאר, --, 
   {{0x6235beca,0x11f407d6,0x60dc02d0,0x00000000}},	//   _келу, اتیگ, sksm, --, 
   {{0xc0cc206f,0x00000000,0x00000000,0x00000000}},	//   ብሄር_, --, --, --, 
   {{0x9da800d1,0x00000000,0x00000000,0x00000000}},	//   нъға_, --, --, --, 
   {{0x69d80e38,0x3f980477,0x81d403d4,0x3f6401b9}},	// [313f0] øven, _upqu_, _িধি_, _ётиб, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdd9036ba,0xaa9409a5,0x00000000,0x00000000}},	//   _بوج_, сихч, --, --, 
   {{0x3ea0cdf5,0xe82000af,0x57b4004e,0x7d1c0334}},	//   lejt_, _बरखा_, ибет, qlqs, 
   {{0x62984ea1,0xdb0c0227,0x9664df65,0x00000000}},	//   _obvo, sxañ, акле, --, 
   {{0xdb0c2e95,0x4b78008f,0x00000000,0x00000000}},	//   pxañ, _באשו, --, --, 
   {{0x20fc010f,0x2360025c,0x55c400c7,0x37d000cc}},	//   nĉis_, _ħija_, шәаз, _দেশৰ, 
   {{0x6298090c,0xdb0c00e4,0xa56400f1,0x00000000}},	//   _abvo, ivaí, حدون, --, 
   {{0x98a40139,0xdd000118,0xe4c80c75,0x904402f2}},	//   _йиңе, _štěk, ابىن_, ینده, 
   {{0xa3080032,0x00000000,0x00000000,0x00000000}},	//   лдыҡ_, --, --, --, 
   {{0x90c42bbe,0x3ea1becb,0x910400d8,0x00000000}},	//   абне, dejt_, ипое, --, 
   {{0x13940108,0x00000000,0x00000000,0x00000000}},	//   _видю, --, --, --, 
   {{0x24a401d9,0xd0100014,0x00000000,0x00000000}},	//   _دٕنِ, زلس_, --, --, 
   {{0xc8e00034,0x51f401b9,0x00000000,0x00000000}},	//   _खत्म_, _پستر, --, --, 
   {{0x8c44010b,0x7ce0000d,0xf41403d4,0xbb4c02dd}},	//   иеве, _sõra, দেশৰ_, _ﻏﺯﻭ_, 
   {{0x5368044e,0x7ce000af,0xfce001c0,0x00000000}},	//   _ሰነዳት_, _põra, оосо, --, 
  
   {{0x8fa44961,0x20fc01e4,0x3ea0036e,0x7bc80174}},	// [31400] _тапе, aĉis_, bejt_, øgup, 
   {{0x7ce00254,0x69d8383d,0x1c38005b,0x00000000}},	//   _võra, øveo, уясь_, --, 
   {{0xc865becc,0x7e780302,0x888401c6,0x00000000}},	//   атли, _באיז, илжж, --, 
   {{0x27201497,0x256c0241,0x9e2400db,0x7ce0000d}},	//   mòni_, _lólá_, _دىپو, _tõra, 
   {{0x27e006d5,0xc60c07f7,0x00000000,0x00000000}},	//   áin_, िथ्य_, --, --, 
   {{0x6b85becd,0x27e00135,0x4e78010f,0x00000000}},	//   muig, ġin_, דאַצ, --, 
   {{0x6b84008f,0x5f0806ab,0x27e0231e,0xf56400ee}},	//   luig, _सदस्_, šin_, ашык_, 
   {{0x6b8405c7,0xc4c40133,0x00000000,0x00000000}},	//   ouig, شتبو, --, --, 
   {{0x256c0241,0xd36c515c,0x6b85bece,0x86c4785c}},	//   _bólá_, فۇن_, nuig, _پيان, 
   {{0x3f8c0022,0x3ea00327,0x00000000,0x00000000}},	//   _ägui_, xejt_, --, --, 
   {{0x6b8401e7,0x3ea0025c,0x538c00d1,0x00000000}},	//   huig, vejt_, _ﻛﻪﭼﯜ, --, 
   {{0xf4800209,0x6b840099,0x79480023,0x1b1c00cc}},	//   _душн, kuig, _ንነብስ, _ভূঞে_, 
   {{0x200c0798,0x6b84017a,0x9f3401ec,0xf6a00133}},	//   çei_, juig, йемі, _دڵۆپ, 
   {{0x272002bd,0x6b85becf,0x20040356,0x9f3401ec}},	//   fòni_, duig, ăli_, сегі, 
   {{0xcf8caeda,0x69d87eb1,0x3ea002d3,0x8eb800fe}},	//   وژی_, øvel, rejt_, ুসংগ, 
   {{0x3ea142ed,0x2c780212,0x20fc010f,0x6b8400ae}},	//   sejt_, ийсь_, rĉis_, fuig, 
   {{0x6b840588,0x3ea0044e,0x628801f5,0x6c540137}},	// [31410] guig, pejt_, ogdo, юкту, 
   {{0x6289bed0,0xbd680166,0xb90801e1,0x272001e1}},	//   ngdo, _ирме_, bajọ_, bòni_, 
   {{0xaf341002,0x31400023,0xdb1402d2,0x2dd400c0}},	//   _بريت, _ከተቕር, _íbíl, _джэр, 
   {{0x3ebc03f9,0x6b85bed1,0xdef801ec,0x00000000}},	//   ɓuta_, buig, _шық_, --, 
   {{0x6d480122,0xb8fc000d,0x2bc9bed2,0x00000000}},	//   ídav, _णव_, _куро_, --, 
   {{0x154401a9,0x00000000,0x00000000,0x00000000}},	//   бекм, --, --, --, 
   {{0x7ae405b1,0x25ac004d,0x00000000,0x00000000}},	//   _iljt, _csdl_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3689bed3,0x92b000cc,0x00000000,0x00000000}},	//   _асен_, _টকৌ_, --, --, 
   {{0xe9240327,0x62880de2,0x14c405c0,0x00000000}},	//   _འཚོབ_, ggdo, वाहण, --, 
   {{0x6b840196,0xd9f87ebc,0xf1bc00d0,0x9044030f}},	//   zuig, ्पित_, čšom_, ینگه, 
   {{0x62880d47,0x7e740175,0x7ce0000d,0x8fa40150}},	//   agdo, _adxp, _sõrn, баме, 
   {{0x7e74010a,0x5eb00eac,0x7ce0000d,0x00000000}},	//   _bdxp, ঞানে, _põrn, --, 
   {{0x2720180f,0xd9f8230e,0xade8009d,0x00000000}},	//   tòni_, ्पात_, аагv, --, 
   {{0xdef80006,0x0d200137,0x7ce0000d,0x00000000}},	//   рыў_, зүнү, _võrn, --, 
   {{0x6b85bed4,0x2720180f,0x69d8072b,0x00000000}},	//   tuig, ròni_, øvem, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [31420] --, --, --, --, 
   {{0x6b842c88,0x0ea80108,0x00000000,0x00000000}},	//   ruig, _ской_, --, --, 
   {{0xbed400c8,0x6b8417e8,0x00000000,0x00000000}},	//   _הויז_, suig, --, --, 
   {{0x6d5dbed5,0x1cc0081f,0xe89400d6,0x6b841140}},	//   mpra, _ཁོག_, іаль, puig, 
   {{0x6d5c0c8c,0x6288037e,0xbcb40375,0x7c9400db}},	//   lpra, ygdo, _הפכו_, _اشپا, 
   {{0x6ffc00da,0x63a40428,0x6d5c5fcf,0x7e98008f}},	//   mācī, _âini, opra, ָסקו, 
   {{0x6d5dbed6,0xfafc0200,0x00000000,0x00000000}},	//   npra, _evës_, --, --, 
   {{0xdbdc01f1,0x6d5d0f45,0xd4c0004e,0x00000000}},	//   zšír, ipra, дөшк, --, 
   {{0x6d5dbed7,0x25ac045a,0x73d40395,0x00000000}},	//   hpra, _wsdl_, йдър_, --, 
   {{0x6d5dbed8,0xd7640014,0x00000000,0x00000000}},	//   kpra, _گنےی, --, --, 
   {{0xba98008f,0x6d5c44ef,0x00000000,0x00000000}},	//   נסטי, jpra, --, --, 
   {{0x6d5c14dc,0x692c0276,0x7411506c,0x1fb801af}},	//   dpra, _aşez, _کوها, алмы_, 
   {{0x6d5cf842,0x14c41221,0x35180a7c,0x00000000}},	//   epra, वारण, _גואנ, --, 
   {{0x6d5dbed9,0xff0400a8,0x00000000,0x00000000}},	//   fpra, сямн, --, --, 
   {{0xa364009f,0x00000000,0x00000000,0x00000000}},	//   _اُڻو, --, --, --, 
   {{0x657c0ff7,0x2a780204,0xfe740228,0xec69beda}},	//   _århu, _adrb_, шүү_, йрук_, 
   {{0x2a780175,0x6d5c017a,0x00000000,0x00000000}},	// [31430] _bdrb_, apra, --, --, 
   {{0xe9240003,0x39e8fcd0,0x692c03e0,0x7f28210e}},	//   _འཚུབ_, льен_, _işey, _حسبِ_, 
   {{0x2a7803d1,0x6d481a53,0x96f80214,0x6d5dbedb}},	//   _ddrb_, ídat, یعتر_, cpra, 
   {{0xfc3c1709,0x00000000,0x00000000,0x00000000}},	//   _saíu_, --, --, --, 
   {{0xab842852,0x6d4800df,0x17c9bedc,0x00000000}},	//   _нурк, ŭdat, ргли_, --, 
   {{0xfbdc0142,0x7ae400f1,0x69d8007c,0x37d000fe}},	//   _ffêr_, _اوسې_, ävec, _দেউৰ, 
   {{0x3eb00204,0xd5740212,0x00000000,0x00000000}},	//   _maxt_, цуль, --, --, 
   {{0x2804012c,0xe8940153,0x00000000,0x00000000}},	//   ásná_, _нась, --, --, 
   {{0x25a00311,0x7bdc0784,0x00000000,0x00000000}},	//   ăila_, nyqu, --, --, 
   {{0x6d5dbedd,0x9238b834,0x059401d9,0xb7d400ec}},	//   ypra, ичну_, _ژانگ, _پوڄا_, 
   {{0x54540a83,0x6d5c03ac,0x00000000,0x00000000}},	//   _двет, xpra, --, --, 
   {{0x6d5c151c,0x00000000,0x00000000,0x00000000}},	//   vpra, --, --, --, 
   {{0xfc3c36e4,0x3eb0036b,0x00000000,0x00000000}},	//   _maís_, _baxt_, --, --, 
   {{0x6d5dbede,0x69d800ed,0xfc3c0798,0x8838011a}},	//   tpra, øvek, _laís_, יתרו, 
   {{0xc330011a,0x692c0205,0x5238010f,0x6d5dbedf}},	//   _חוג_, _eşey, _דײַנ, upra, 
   {{0x6d5dbee0,0x7688010b,0x00000000,0x00000000}},	//   rpra, _ỳyld, --, --, 
   {{0x6d5dbee1,0x31640007,0x2a78020b,0x00000000}},	// [31440] spra, _hwnz_, _pdrb_, --, 
   {{0x6d5c5e9d,0x3ebc0198,0xdfa801f7,0x00000000}},	//   ppra, ɓuto_, _اُٿو_, --, 
   {{0x8c4400f4,0x6f1dbee2,0x8d75bee3,0x629c00e4}},	//   _мене, morc, _باخا, õroi, 
   {{0xc7c40a8f,0xdb4c04d3,0x08c400a7,0x00000000}},	//   жски, _ڵێم_, юбен, --, 
   {{0x4c35bee4,0x31640007,0x7bc80254,0x00000000}},	//   _фэнт, _lwnz_, ägut, --, 
   {{0x6f1d1ac5,0x3e540118,0xb3bc0154,0xdd740345}},	//   norc, mětí_, ইহাজ, _بپێک, 
   {{0xbb401830,0x2bc81fbc,0x2d689736,0x00000000}},	//   _церк, रमवा, nşe_, --, 
   {{0x97c400db,0x00000000,0x00000000,0x00000000}},	//   تتۅم, --, --, --, 
   {{0x6f1c1b12,0x43080b3b,0x3e540118,0x00000000}},	//   korc, ихом_, nětí_, --, 
   {{0xa314033f,0x2d680790,0x4ecc00fe,0x00000000}},	//   डवेज_, kşe_, ৰফুল, --, 
   {{0x7ce000af,0xf1ac05d9,0x85540214,0x9735bee5}},	//   _sõrm, نءَ_, _بیبر_, _хэтч, 
   {{0x69c806af,0x7ce00037,0x0dc80092,0x3618011a}},	//   _àdeu, _põrm, _አልፋ_, _דובד, 
   {{0x6f1dbee6,0xdbdc00d7,0x00000000,0x00000000}},	//   forc, kšár, --, --, 
   {{0x6f1c0989,0x00000000,0x00000000,0x00000000}},	//   gorc, --, --, --, 
   {{0x3eb003be,0x31640226,0xdb0c0120,0x00000000}},	//   _vaxt_, _gwnz_, lvaç, --, 
   {{0xc0581ac3,0x00000000,0x00000000,0x00000000}},	//   _тік_, --, --, --, 
   {{0x6f1dbee7,0x2d68054e,0x7ce00254,0x3eb0263e}},	// [31450] borc, aşe_, _hõrk, _taxt_, 
   {{0x6f1c01e5,0xf4380302,0x7ce0000d,0x5e6000d1}},	//   corc, שתמש, _kõrk, _سۆرە, 
   {{0xfc3d807f,0x9999bee8,0xdcf40034,0xcec40124}},	//   _país_, скет_, erzą, _хшыҩ, 
   {{0x7ce00254,0x00000000,0x00000000,0x00000000}},	//   _mõrk, --, --, --, 
   {{0x37a9bee9,0x6568058a,0xf7a800ee,0xb3dc00eb}},	//   ртен_, _awdh, ръек_, _বেনজ, 
   {{0x65680042,0x4c3800d9,0x00000000,0x00000000}},	//   _bwdh, _לתרב, --, --, 
   {{0x15b82de5,0x7ce000c5,0xfc3c0798,0x00000000}},	//   сылы_, _nõrk, _taís_, --, 
   {{0x2720068c,0xe91802bf,0x00000000,0x00000000}},	//   fòns_, _досі_, --, --, 
   {{0xd7d401b9,0x6f1dbeea,0xdb0c0139,0xe758003b}},	//   _عصرک, yorc, gvaç, _миті_, 
   {{0x65680142,0x6d5800e4,0x2498013a,0x00000000}},	//   _fwdh, _évag, _čemž_, --, 
   {{0x0dc80020,0x36200014,0x6f1dbeeb,0x42c401c6}},	//   _አልፎ_, _غوصہ, vorc, чгэн_, 
   {{0x05940150,0x8fa41d0f,0x6f1c009a,0x45b40375}},	//   _ءالگ, паме, worc, _מפעל_, 
   {{0xfe54002e,0x7ce000c5,0x00000000,0x00000000}},	//   _li鯵u_, _tõrj, --, --, 
   {{0x69c80162,0xe2980024,0x00000000,0x00000000}},	//   _ádeg, _маі_, --, --, 
   {{0xa9280232,0x6f1c014f,0xdcf4033f,0x1adc03d4}},	//   ližš, rorc, zrzą, ণোৱা, 
   {{0x6f1dbeec,0x4f940276,0x3ce80129,0x2bc80709}},	//   sorc, _ероу, _clcv_, रमला, 
   {{0xfc3c172e,0x00000000,0x00000000,0x00000000}},	// [31460] _saír_, --, --, --, 
   {{0x2fc000f3,0xd5bc0b8f,0xdec80092,0x00000000}},	//   _irig_, ्माज, _አምኖ_, --, 
   {{0x8d751b44,0xc6900014,0xe97400f7,0x00000000}},	//   _عادا, ہِش_, بۇزد, --, 
   {{0x2fc0d88b,0x3e54012c,0xdcf4033f,0x2d99beed}},	//   _krig_, pětí_, trzą, mtre_, 
   {{0x2d99beee,0x00000000,0x00000000,0x00000000}},	//   ltre_, --, --, --, 
   {{0x6b85beef,0x79940218,0x7d1836dd,0x9d18004d}},	//   mrig, btxw, čuse, ệntử_, 
   {{0x2d99bef0,0x6b8494fc,0x6d58a4f1,0x00000000}},	//   ntre_, lrig, _évad, --, 
   {{0x2fc1bef1,0x2d99bef2,0x6b8444db,0x27200ba1}},	//   _orig_, itre_, orig, tòns_, 
   {{0x6b85bef3,0xaee40084,0x2fc00070,0xc764005e}},	//   nrig, hoṱh, _nrig_, _ءارى, 
   {{0xdb0c0261,0x2d99bef4,0xc32c0075,0x6b85bef5}},	//   rvaç, ktre_, دەت_, irig, 
   {{0x6b84aa59,0x2fc0022e,0x6ed03409,0xb9200241}},	//   hrig, _arig_, दानु, _rirẹ_, 
   {{0x6b85bef6,0x2fc1bef7,0x91c0053f,0x7ce000af}},	//   krig, _brig_, тәшл, _võrk, 
   {{0x2fc00363,0x8eb400fe,0x6b84fe07,0xa29428f6}},	//   _crig_, ঞানগ, jrig, _жалі, 
   {{0x4425bef8,0x8338656c,0x43740184,0x2fc00076}},	//   _iyo_, _учет_, _дуҫт, _drig_, 
   {{0x4425bef9,0x2fc00295,0x6b85befa,0x1cc0025c}},	//   _hyo_, _erig_, erig, _ཁོད_, 
   {{0x44242252,0x2fc1befb,0x799401d4,0x7ce00037}},	//   _kyo_, _frig_, vtxw, _kõri, 
   {{0x2d9c9c56,0x6b85befc,0x69d9befd,0x9d440220}},	// [31470] _även_, grig, även, зеңд, 
   {{0x4425befe,0x3f881ab4,0x3e6801ec,0xfd44009d}},	//   _myo_, mucu_, _ушин_, _нэмн, 
   {{0x2d99b845,0x6b85beff,0x44242252,0xd8780137}},	//   ctre_, arig, _lyo_, قمات_, 
   {{0x4425bf00,0x6b98007b,0x52a80da5,0x00000000}},	//   _oyo_, éagá, _कस्स, --, 
   {{0x4425bf01,0x6b8466ce,0x3f880365,0x79940218}},	//   _nyo_, crig, nucu_, stxw, 
   {{0x7d1c571b,0x290c01e1,0x00000000,0x00000000}},	//   loqs, _ìdan_, --, --, 
   {{0x4425bf02,0x3f89bf03,0x326000c7,0x00000000}},	//   _ayo_, hucu_, ҭеиҳ, --, 
   {{0x4425bf04,0x7d1c01a9,0x3f89bf05,0x00000000}},	//   _byo_, noqs, kucu_, --, 
   {{0x44244c99,0x3f89bf06,0x15b80184,0xdb1c29d3}},	//   _cyo_, jucu_, сыһы_, _arsé, 
   {{0x78a9bf07,0x4424aac5,0x3f8970ad,0x6ef11193}},	//   legv, _dyo_, ducu_, _käbe, 
   {{0x4425bf08,0x93a001a9,0x2d9839da,0x00000000}},	//   _eyo_, _bo惣i, xtre_, --, 
   {{0x6b84172c,0x63a40311,0x2fc00076,0x78a8030a}},	//   yrig, _ţine, _prig_, negv, 
   {{0x44240a49,0x7539bf09,0x6b84022e,0x8898011a}},	//   _gyo_, mmuz, xrig, חברי, 
   {{0x2d99bf0a,0xb8dc49a6,0x6b85bf0b,0x7539bf0c}},	//   ttre_, _ཀལ_, vrig, lmuz, 
   {{0x7c3402a8,0xb63c019b,0x753804ba,0x2d980129}},	//   ɓarɓ, _ｂｙ_, omuz, utre_, 
   {{0xd13005c6,0x2fc001b8,0x44241418,0x6b85bf0d}},	//   _جمع_, _trig_, _yyo_, trig, 
   {{0x2d99bf0e,0x0b4400d6,0x44240218,0x3f893d4c}},	// [31480] stre_, днан, _xyo_, cucu_, 
   {{0x2d99bf0f,0x09e5ad1c,0x6ef0010b,0x69d8007c}},	//   ptre_, мозн, _bäbe, äveo, 
   {{0x6b85bf10,0xab90001f,0x6ef0013d,0x753800df}},	//   srig, ኝተዋል_, _cäbe, kmuz, 
   {{0x6b85bf11,0xe854006c,0x7c28031c,0x31ac00fe}},	//   prig, رنتد, żgra, _ছপাশ, 
   {{0x753801a4,0x6b840067,0x286800fb,0x00000000}},	//   dmuz, qrig, орҙо_, --, 
   {{0x44240537,0xdcf40210,0x20380092,0x00000000}},	//   _ryo_, drzę, _በንብረ, --, 
   {{0x7ae0049b,0x44241c06,0xdcf40034,0x81e00eac}},	//   önte, _syo_, erzę, _নেন_, 
   {{0x44244cdf,0x3f88029f,0x7ce0000d,0x00000000}},	//   _pyo_, yucu_, _põri, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x44245975,0x3f89bf12,0x75381418,0xcd7c001f}},	//   _vyo_, vucu_, amuz, _ንግድና_, 
   {{0x3f8800ca,0x75380810,0x6ef00166,0x442401e1}},	//   wucu_, bmuz, _xäbe, _wyo_, 
   {{0xf501bf13,0x3f8805d1,0x93a0022e,0x6ef001e3}},	//   _изхо, tucu_, _qo惣i, _näbb, 
   {{0xf484168d,0x7ce0007d,0x4425bf14,0xbb3400d1}},	//   _زانی, _kõrv, _uyo_, ﻗﯘﻡ_, 
   {{0x3f882fbe,0x9b58013e,0xa2d40592,0x4f34010b}},	//   rucu_, ҷиат_, _سيبت, нҗыр_, 
   {{0x3f8819a2,0x7ce000c5,0x69d8aecc,0x2d580138}},	//   sucu_, _mõrv, ävel, дись_, 
   {{0x6ef1bf15,0x65780194,0xb1780677,0x00000000}},	//   _räbe, isvh, _וטהר, --, 
   {{0x6ef0002f,0x7d1c01d5,0x00000000,0x00000000}},	// [31490] _säbe, roqs, --, --, 
   {{0x1cc00135,0x6ef0014a,0x75380369,0xceb400d1}},	//   _ཁོམ_, _päbe, zmuz, _пәс_, 
   {{0xceb000c8,0x6ef0008e,0x00000000,0x00000000}},	//   _גיי_, _qäbe, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x78a805e4,0x81e00154,0x00000000,0x00000000}},	//   regv, _নেম_, --, --, 
   {{0x6d5807ea,0x6ef00139,0x2aa800db,0x79a401af}},	//   _évac, _täbe, _отсо_, _орбе, 
   {{0x69d81477,0xa954109a,0x00000000,0x00000000}},	//   øvet, _аксі, --, --, 
   {{0x94740345,0x9524277d,0x00000000,0x00000000}},	//   ردبا, رکام, --, --, 
   {{0x069405d9,0x68e402f6,0x387c025c,0x97140064}},	//   _ڳالھ, öide, _idur_, _змац, 
   {{0x7538002d,0xd008010b,0x6ea400c5,0x27e00254}},	//   smuz, җеге_, _चउधु, äine_, 
   {{0x7539bf16,0x91e5b0f4,0x910417a0,0xc0f00092}},	//   pmuz, хоне, епне, _ፍሳሽ_, 
   {{0x387c025c,0xdcf4033f,0x63050db3,0x00000000}},	//   _jdur_, przę, _یونل, --, 
   {{0x06b00154,0xe374004e,0x53a5bf17,0x00000000}},	//   চারি, _алчы, _чалб, --, 
   {{0x387c0254,0x7ce0000d,0x0eb80139,0x00000000}},	//   _ldur_, _mõru, чумы_, --, 
   {{0x387dbf18,0x257c0139,0x10a421d1,0x88d400dc}},	//   _odur_, _gälā_, _зийн, _kṛty, 
   {{0x387c0327,0x00000000,0x00000000,0x00000000}},	//   _ndur_, --, --, --, 
   {{0x88d40882,0x7ce0000d,0xe7c800d1,0x00000000}},	// [314a0] _mṛty, _nõru, _ﯪﻳﺎﻟ, --, 
   {{0x387dbf19,0x3ab00075,0x8c44013d,0x00000000}},	//   _adur_, ләст, _җеге, --, 
   {{0x8884f1f4,0x5a940395,0xdf0001af,0x00000000}},	//   ележ, ъртф, _түрй, --, 
   {{0xacb40150,0x2900067c,0x7ce0000d,0x88d400dc}},	//   _جەرب, òia_, _sõrv, _nṛty, 
   {{0x387caa38,0x3c740375,0x00000000,0x00000000}},	//   _ddur_, _אתכם_, --, --, 
   {{0xa8252221,0x69d81477,0x2ca001b8,0x3f78010f}},	//   _یکشن, øves, lfid_, לאנס, 
   {{0x77780564,0x7d0c01e7,0x04b401d9,0x00000000}},	//   _evux, _áisí, ٹھاں_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7ce000c5,0x2ca000ae,0x2ae40037,0x00000000}},	//   _tõrv, ifid_, _गवाँ_, --, 
   {{0xb9c802d3,0x98340153,0x00000000,0x00000000}},	//   _ደቁ_, _рэсі, --, --, 
   {{0x7ce000c5,0xf5e40798,0x00000000,0x00000000}},	//   _kõrt, _пмфл_, --, --, 
   {{0x26cc025a,0x84880092,0x00000000,0x00000000}},	//   _hndo_, ዚቢሽን_, --, --, 
   {{0xd9ac012c,0x7ce0000d,0x0f706518,0x35800023}},	//   _घन्ट, _mõrt, ағыр, _ከርተት_, 
   {{0x9f34454e,0x8174014b,0x00000000,0x00000000}},	//   тегі, _закӣ_, --, --, 
   {{0xf1a0084c,0x2ca00254,0xceb4035b,0x00000000}},	//   _брын, ffid_, тәы_, --, 
   {{0x3cec0579,0xdfd000ec,0x425002f2,0x00000000}},	//   ógv_, _نيب_, _جۆگر, --, 
   {{0x60cc0537,0x26cdbf1a,0xd10c01ad,0xfa840114}},	// [314b0] _inam, _ondo_, ाचरण_, ећем, 
   {{0x3f98047e,0x60cc0175,0x2ca0000d,0x00000000}},	//   _iqqu_, _hnam, afid_, --, 
   {{0xef140228,0x7b08005f,0xba740131,0x7ce00254}},	//   _сүрө, kļuv, _ۋاست, _sõru, 
   {{0xa95400d6,0x7ce000c5,0x387c022e,0x00000000}},	//   укці, _põru, _qdur_, --, 
   {{0x60cc0451,0x69d92c8e,0xcc74011a,0x7bdc00cc}},	//   _mnam, øver, _שעשה_, _নেৰো, 
   {{0x26cc0117,0x7ce000af,0x68f800e2,0x88d40055}},	//   _cndo_, _võru, īvda, _sṛty, 
   {{0x387c020b,0xa5640691,0x00000000,0x00000000}},	//   _tdur_, هدين, --, --, 
   {{0x60cdbf1b,0x387dbf1c,0x88d40055,0x84580137}},	//   _nnam, _udur_, _dṛsy, үрөт_, 
   {{0xe7842c1d,0x26cc00e4,0x6ef00166,0x36a000d1}},	//   _бухо, _fndo_, _läba, _مەشق, 
   {{0x78b9bf1d,0x22400115,0x7ce00254,0x00000000}},	//   _hauv, _ŝika_, _kõrs, --, 
   {{0x78b9bf1e,0x60cdbf1f,0x05940ccb,0xd5b035b6}},	//   _kauv, _bnam, _لانگ, _خفا_, 
   {{0x60cc30c6,0xd0080261,0x7ce00254,0x00c4030d}},	//   _cnam, деме_, _mõrs, влюк_, 
   {{0x78b8864c,0x26cc045f,0xfd5c0055,0x60cc00d7}},	//   _mauv, _yndo_, _ityṛ, _dnam, 
   {{0x60cdbf20,0x78b9bf21,0xe2c800d4,0x00000000}},	//   _enam, _lauv, _плід_, --, 
   {{0xc690008d,0x3f98014f,0x60cc0334,0x33b00131}},	//   יאם_, _eqqu_, _fnam, _شەھر, 
   {{0x78b9bf22,0xfbe4001e,0xc5f00375,0x0fc4030d}},	//   _nauv, _thể_, בדל_, _айин, 
   {{0x8fd00ce8,0x00000000,0x00000000,0x00000000}},	// [314c0] _тәнә, --, --, --, 
   {{0xd1e802d3,0x00000000,0x00000000,0x00000000}},	//   _ህሞት_, --, --, --, 
   {{0x60cdbf23,0x78b817da,0x2d9c4d29,0x7ae00108}},	//   _ynam, _bauv, _ëve_, önta, 
   {{0x78b9bf24,0x48083252,0xc8b001d5,0x09040395}},	//   _cauv, меен_, شلتک, ъпен, 
   {{0x26c8cacd,0x78b803b4,0x2bc80032,0x38c865dc}},	//   нған_, _dauv, _яһап_, ظامی_, 
   {{0x26cdbf25,0x27341e4a,0x567800d1,0x00000000}},	//   _qndo_, دىتس, ىشىڭ_, --, 
   {{0xd90d534c,0x6abc36f4,0x6ef00139,0x00000000}},	//   _کین_, _iarf, _xäba, --, 
   {{0x78b9bf26,0x6abdbf27,0xe3b801af,0x00000000}},	//   _gauv, _harf, елич_, --, 
   {{0x6abdbf28,0x2904038f,0x7ce0000d,0x68e012ef}},	//   _karf, _imma_, _kõrr, _iomd, 
   {{0x78b807f5,0x60cdbf29,0x68e0047e,0x6abc008f}},	//   _zauv, _snam, _homd, _jarf, 
   {{0x6abdbf2a,0x60cc010a,0x209801c0,0x139802d3}},	//   _marf, _pnam, нкны_, _ገዲፍካ_, 
   {{0x6abc2d42,0x6ef00254,0x00000000,0x00000000}},	//   _larf, _räba, --, --, 
   {{0x6abc0165,0x60cc0010,0xd8d00327,0x6ef00139}},	//   _oarf, _vnam, _ཊོལི, _säba, 
   {{0xa194748c,0xdd94a110,0x28a402ab,0x68e1bf2b}},	//   _бакч, лагы, _गॉसि, _lomd, 
   {{0x5b141ee3,0x2905bf2c,0x2c5827dd,0x60cc01ab}},	//   ҳмат, _omma_, _ọda_, _tnam, 
   {{0x60cdbf2d,0x68e1bf2e,0x6abc9a36,0x00000000}},	//   _unam, _nomd, _aarf, --, 
   {{0xdb0c025a,0x212800d5,0x6d59bf2f,0x78b80158}},	// [314d0] _âkëk, _ikah_, _évan, _rauv, 
   {{0x2905bf30,0x78b9bf31,0x6abdbf32,0x2128011f}},	//   _amma_, _sauv, _carf, _hkah_, 
   {{0x6abdbf33,0x78b9bf34,0x69d828b3,0x00000000}},	//   _darf, _pauv, øvep, --, 
   {{0x68e1bf35,0xfc3c44d5,0x6abc0857,0x7ce00037}},	//   _comd, _maíz_, _earf, _võrs, 
   {{0x6abdbf36,0x78b80664,0x68e0045a,0xe75800d4}},	//   _farf, _vauv, _domd, вичі_, 
   {{0x2905bf37,0x6abdbf38,0x68e003ac,0x7ce00254}},	//   _emma_, _garf, _eomd, _tõrs, 
   {{0x78b9bf39,0x212803f9,0x00000000,0x00000000}},	//   _tauv, _okah_, --, --, 
   {{0x6abdbf3a,0xa564027d,0x2128002b,0x00000000}},	//   _zarf, جدون, _nkah_, --, 
   {{0x6abc0198,0x5274405c,0x7c9c0023,0xd29800d4}},	//   _yarf, луну, _ምጽሓፍ_, нтні_, 
   {{0x61e80cfd,0x68e00944,0x2128102c,0x6abc94f6}},	//   fydl, _zomd, _akah_, _xarf, 
   {{0x68e00944,0xc1e405f5,0xdecc02d3,0x29040142}},	//   _yomd, гдэж_, _ኣሎካ_, _ymma_, 
   {{0xf1e4002e,0xd478010f,0x00000000,0x00000000}},	//   _d斡pp_, _װאַל, --, --, 
   {{0x7bc80267,0x39440419,0xb3e8007b,0xe7f800cd}},	//   ågul, ínsy_, _تعال_, ्छया_, 
   {{0xe8d01fe5,0x8fd00184,0x212800b8,0x61e800bc}},	//   _सच्च, _ғәмә, _ekah_, bydl, 
   {{0x523804ac,0x613c00d8,0x3da401f0,0xa22401c8}},	//   _אײַנ, délf, лкро_, _پروه, 
   {{0x6abdbf3b,0x80c800e1,0x8fd00bd6,0x00000000}},	//   _sarf, _तोपे, _ләгә, --, 
   {{0x68e00098,0x7ce0000d,0x00000000,0x00000000}},	// [314e0] _romd, _põrr, --, --, 
   {{0xa3d4006d,0x6abc0869,0x89f40953,0x68e13264}},	//   हमत_, _qarf, ляец, _somd, 
   {{0x6abdbf3c,0xe70455bd,0x7ce0007d,0x68e003a2}},	//   _varf, یستی, _võrr, _pomd, 
   {{0x4875bf3d,0xbb180952,0x6abc1e15,0x2c94179e}},	//   اداس, ﺷﻘﻰ_, _warf, _خیرآ, 
   {{0x67d5bf3e,0x290401a4,0x0ae800c6,0xb6c801d3}},	//   ролу, _vmma_, _كرسي_, کانے_, 
   {{0x68e00944,0xb820009e,0x00000000,0x00000000}},	//   _womd, _বৃহত_, --, --, 
   {{0x68e1bf3f,0x5ec80154,0x45484965,0x44300064}},	//   _tomd, _রকমে, нчим_, _šy_, 
   {{0x29053870,0xfc3c3c80,0xa53410fc,0xabac0240}},	//   _umma_, _raíz_, јнич, _ህርድግ_, 
   {{0xc694c56f,0xed8802d3,0xa2f400f3,0x3944257c}},	//   _مشاع, _ንግበር_, ипич, ïnse_, 
   {{0x61e8049f,0x3f8801fa,0x21293187,0x00000000}},	//   tydl, vrcu_, _skah_, --, 
   {{0x6234f08e,0x717401c0,0xf1a0822f,0xc48428eb}},	//   рену, лбэр_, брян, _блек, 
   {{0x3618011a,0x61e9bf40,0x00000000,0x00000000}},	//   _אובד, rydl, --, --, 
   {{0x44300208,0x80040a89,0xc880054e,0x8d840014}},	//   _áy_, учне, maşă_, یشٲن, 
   {{0xb3b80375,0xdb1c01ef,0x00000000,0x00000000}},	//   _נמוכ, _orsá, --, --, 
   {{0x6d580231,0x0524015b,0xa194761e,0xca700092}},	//   _éval, মগীর_, _тайч, ችንንም_, 
   {{0xf19001ed,0x6ef001e3,0x9f540353,0x00000000}},	//   _اُٹھ, _fäbo, _квич, --, 
   {{0xaa440075,0xa3e40da0,0x30940150,0xfa88005b}},	// [314f0] ەنلى, नहि_, _اشىس, есей_, 
   {{0xace80131,0xab940212,0xbb1800d1,0x60dc007c}},	//   پرېل_, сифі, ﺴﯩﻢ_, ljsm, 
   {{0x7e743ecf,0xbb180952,0xfc3c0248,0xdb140cad}},	//   _iexp, ﺷﺘﻰ_, _gbín_, _ìbíl, 
   {{0xd7f012a1,0xa3d400bc,0x28f8074d,0x00000000}},	//   يكا_, हमा_, лехь_, --, 
   {{0x960d8e37,0xe6180220,0x00000000,0x00000000}},	//   िप्ट_, ңді_, --, --, 
   {{0xd5e421fa,0xd7c807d6,0x6ef000a2,0x2f5c011a}},	//   ижли, _یوزه_, _näbl, עדונ, 
   {{0x25ac02fa,0xf771bf41,0x7e740407,0x15b80572}},	//   _cpdl_, _گاز_, _mexp, тылы_, 
   {{0x7e740585,0xd90c1b12,0xdb0c000d,0x00000000}},	//   _lexp, _کیچ_, hvaü, --, 
   {{0x28f800c9,0x7c2c0076,0x2e3c01e1,0xe35401c6}},	//   _сеть_, _jycr, _káfí_, йтээ, 
   {{0xc248007f,0x130401f0,0x6d580055,0xd37800cf}},	//   _enfٍ, рзом, _ũvam, нчү_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe2a90db3,0x0fc40212,0xe534030d,0xb11400eb}},	//   پاین_, аймн, _лехь, সত্ব_, 
   {{0x3e800166,0x00000000,0x00000000,0x00000000}},	//   _oçtı_, --, --, --, 
   {{0xfc3c0248,0x3f64013e,0xe7f8ecd9,0x611801e4}},	//   _abío_, риро_, ्छता_, rĉla, 
   {{0x65c000bc,0x5dd400d4,0xd174a5de,0x00000000}},	//   máhá, бюту, _тылы, --, 
   {{0x3e8070f7,0xb4e00574,0xc9d415f6,0x00000000}},	//   _açtı_, _नको_, یزاب, --, 
   {{0x7e740175,0xca540798,0x00000000,0x00000000}},	// [31500] _fexp, атењ, --, --, 
   {{0xff7800c8,0x00000000,0x00000000,0x00000000}},	//   _שטימ, --, --, --, 
   {{0xcc8804b4,0x80c800bc,0x5ea40c4f,0xadc401af}},	//   _ибне_, _तोडे, _امپل, _уанһ, 
   {{0x2c5c068f,0x9e641bf4,0x00000000,0x00000000}},	//   _bądź_, _پاین, --, --, 
   {{0x6d45bf42,0x25ac0158,0x6fb801ad,0xa68400fb}},	//   mmia, _spdl_, ेटिं, йғай, 
   {{0x6d45bf43,0x613c00dd,0xdb1c02f0,0x6d5c03e3}},	//   lmia, méle, _trsá, oqra, 
   {{0x29f000b5,0x6d44067c,0xf5b0007b,0x6d5dbf44}},	//   _ｄay_, omia, قصيد, nqra, 
   {{0x2a79bf45,0x6d45bf46,0x00000000,0x00000000}},	//   _herb_, nmia, --, --, 
   {{0xf4d40ed6,0x6ef001b8,0x27200109,0x69d80158}},	//   рмыш_, _päbl, zòny_, åvef, 
   {{0x6d4483fb,0xa2f400f3,0x00000000,0x00000000}},	//   hmia, споч, --, --, 
   {{0x7e7405b1,0x613c0129,0x20d41359,0xb1e00022}},	//   _rexp, héle, مقدس, жәық, 
   {{0x7e74034c,0x03a4055f,0x2a781529,0xc429bf47}},	//   _sexp, _видо, _lerb_, _июле_, 
   {{0x7bc00b3a,0x7e74003e,0x6d5800e4,0x6d44033f}},	//   ānuk, _pexp, _évaj, dmia, 
   {{0x6d4402e5,0x74100244,0x613c0129,0x60dc0174}},	//   emia, _بوها, déle, sjsm, 
   {{0x6d5c0007,0xdb0c0254,0x00000000,0x00000000}},	//   gqra, rvaü, --, --, 
   {{0x2d5c0998,0x7c2c00e4,0x6d4401ab,0x36180a7c}},	//   _díe_, _pycr, gmia, דולד, 
   {{0xad240075,0xc0300014,0x9c3802e8,0x00000000}},	// [31510] زىكى, _گژھک, упат_, --, 
   {{0xf9c48b16,0x2a787f0a,0xb4e0012d,0xaed40408}},	//   ищен, _cerb_, _नक्_, _доьш, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7c2c0142,0xdb1c010e,0x1ca40133,0x613c00e5}},	//   _tycr, _orsç, _دێری_, béle, 
   {{0x49a40046,0x613c0129,0x7b0800ef,0xab84026b}},	//   _қырғ, céle, bļup, _мурк, 
   {{0x2a780246,0x1b140154,0x00000000,0x00000000}},	//   _gerb_, _তীরে_, --, --, 
   {{0x59e468e7,0xdef00023,0xfc3c01e7,0x69d80108}},	//   _آزم, _ፍናን_, _mbím_, ävet, 
   {{0x2a7807ab,0x54340133,0xe8940024,0x00000000}},	//   _zerb_, یرکر, _мась, --, 
   {{0x57f40261,0xc8e40150,0x95d802dd,0x15b801e0}},	//   _упат, _اققۋ, _әдет_, тыһы_, 
   {{0x81e003f4,0x6d44068f,0xc5a40451,0x00000000}},	//   _নেই_, zmia, _ڇڏين_, --, 
   {{0x6d4400a9,0x613dbf48,0xdb0c0165,0x347001e0}},	//   ymia, zéle, nvañ, _һѳҙѳ, 
   {{0x5f0402f8,0x2d5c0407,0x8634011a,0x72cc00b8}},	//   होस्_, _ríe_, _הרעב_, _ṅgār, 
   {{0x32080034,0xe3b00691,0x00000000,0x00000000}},	//   ńcy_, _يره_, --, --, 
   {{0x613dbf49,0x0838010f,0x61f000e5,0x00000000}},	//   véle, טערל, öklé, --, 
   {{0x519400c6,0x00000000,0x00000000,0x00000000}},	//   _العذ, --, --, --, 
   {{0x4bd800c9,0x2a79bf4a,0x613dbf4b,0x6d44000d}},	//   льзя_, _serb_, téle, umia, 
   {{0x6d45bf4c,0xca8400cf,0xd17401af,0x00000000}},	// [31520] rmia, йгай, _тыһы, --, 
   {{0xeb980364,0x6d45bf4d,0xca540063,0x2a7806be}},	//   лиғ_, smia, стањ, _qerb_, 
   {{0x2a79bf4e,0xda580116,0x00000000,0x00000000}},	//   _verb_, рруш_, --, --, 
   {{0xc0f0044e,0x00000000,0x00000000,0x00000000}},	//   _ፍታሕ_, --, --, --, 
   {{0xbb343769,0x00000000,0x00000000,0x00000000}},	//   ﻗﺘﻪ_, --, --, --, 
   {{0xb8ec534e,0xe3e800dd,0x2a78003a,0x3f4c025c}},	//   _वो_, یکشن_, _uerb_, _nżul_, 
   {{0xa4d835dd,0x69d80158,0x3e580375,0xdb140241}},	//   идку_, åved, נדקס, _ìbál, 
   {{0xdb1c049f,0x6ef00166,0x49b000ee,0x99741b0a}},	//   _ersä, _bäbk, _мәҗу, _фурш, 
   {{0x24182ecc,0xbb3400d1,0x00000000,0x00000000}},	//   ропы_, ﻗﯘﻕ_, --, --, 
   {{0x4acc00ab,0x00000000,0x00000000,0x00000000}},	//   _होमव, --, --, --, 
   {{0x7bc004fe,0xdecc02d3,0xcfe400cc,0x613c01d3}},	//   ānui, _ኣሎኻ_, _পেলন, vélb, 
   {{0x3a34025f,0x00000000,0x00000000,0x00000000}},	//   מרים_, --, --, --, 
   {{0x412400db,0x00000000,0x00000000,0x00000000}},	//   инүү_, --, --, --, 
   {{0xdb1c06ed,0xbb18054e,0x00000000,0x00000000}},	//   _essê, _avîn, --, --, 
   {{0xb8d8031c,0x4dc401e0,0xf27800d9,0x00000000}},	//   _མྲ_, ортҡ, _גרוש, --, 
   {{0xdb9002dd,0x00000000,0x00000000,0x00000000}},	//   _ﺟﻪﺭﻯ_, --, --, --, 
   {{0xdecc044e,0xdcf400e2,0xfc3000c6,0x80cc0154}},	// [31530] _ኣሎኹ_, luzī, سحر_, হউদ্, 
   {{0x09b000bd,0xdb0c0162,0x00000000,0x00000000}},	//   ঘটনা, gvað, --, --, 
   {{0xa2c016d1,0x00000000,0x00000000,0x00000000}},	//   _वसन्, --, --, --, 
   {{0x3198010f,0x5f040118,0x00000000,0x00000000}},	//   רבאנ, होर्_, --, --, 
   {{0x6568044e,0x69d83b22,0x4c980a7c,0x00000000}},	//   _atdh, äver, _דברו, --, 
   {{0xe7b40075,0x3cec0490,0xaa580117,0xe77800e5}},	//   سلىھ, _इकडे_, _гиру_, حلوں_, 
   {{0x13d016d1,0x38c8010b,0xa2cc00cd,0x00000000}},	//   तम्भ, _йуан_, तयन्, --, 
   {{0x499001d9,0x7ae40267,0x5fc800bc,0x00000000}},	//   _زیٖر, _hojt, िटाल, --, 
   {{0x7ae40218,0xf41c0598,0xf770005e,0xd944010b}},	//   _kojt, çä_, _ءار_, _геңи, 
   {{0x130809fe,0xdb1c049f,0xd18401c0,0x6d5800e4}},	//   рной_, _ursä, олой, _èvag, 
   {{0x80c8000d,0xdcf400ef,0x00000000,0x00000000}},	//   _तोहे, guzī, --, --, 
   {{0x7ae402d3,0xc5040451,0x8fa47696,0x61fc00a3}},	//   _lojt, _وڪيل_, оаме, ùrla, 
   {{0x6ef000c5,0x00000000,0x00000000,0x00000000}},	//   _häbi, --, --, --, 
   {{0x6ef00209,0x68f8005f,0x7994401f,0x7ae40455}},	//   _käbi, īvdi, kuxw, _nojt, 
   {{0xbbc4037e,0x10a407d5,0x916402da,0x0d20004e}},	//   _ｉモ_, _дийн, _بهبه, дүнү, 
   {{0x4c68ed3b,0x41b0143e,0xdcf4012d,0x69c8032e}},	//   риан_, _آمير, yszą, _ádei, 
   {{0x7ae5bf4f,0x6ef0007d,0x00000000,0x00000000}},	// [31540] _bojt, _läbi, --, --, 
   {{0x38c887a9,0xc9f410fe,0x2fc001f0,0x00000000}},	//   یانی_, يساع, _isig_, --, 
   {{0x4090034c,0x613c87ef,0x08c403a6,0x6ef1bf50}},	//   _علیر, léla, жбен, _näbi, 
   {{0x7980045f,0xc210011a,0x20dc17ee,0x00000000}},	//   ânwa, והב_, यायध, --, 
   {{0x87b800c9,0x2d99bf51,0xb0ac0a59,0x7ae453ad}},	//   рует_, lure_, ट्यग, _fojt, 
   {{0x6b85bf52,0x7994014b,0x6ef1489e,0xc588023a}},	//   msig, buxw, _bäbi, ащие_, 
   {{0x2d99bf53,0x20dc0574,0x613c0066,0x00000000}},	//   nure_, यामध, héla, --, 
   {{0x6ef0010b,0x613c0098,0x2fc0022e,0xdb1c0129}},	//   _däbi, kéla, _osig_, _assè, 
   {{0x6b855666,0x2d99bf54,0xc7a41f0a,0x1cb80135}},	//   nsig, hure_, _физк, _ཚིལ_, 
   {{0x2d99bf55,0x6b85bf56,0x97e806b3,0x241802dd}},	//   kure_, isig, _улуғ_, _қолы_, 
   {{0x98ac00df,0x2fc00356,0x7ae06c3f,0x6b848186}},	//   _skeĉ_, _asig_, önti, hsig, 
   {{0x613c008c,0x6b85bf57,0xdb1c4d74,0x2d99bf58}},	//   féla, ksig, _essè, dure_, 
   {{0x6b841505,0x79940564,0x2d9806af,0x613c003e}},	//   jsig, zuxw, eure_, géla, 
   {{0x6b85bf59,0x2d9965b1,0x733000cf,0x00000000}},	//   dsig, fure_, _قىنا, --, 
   {{0x7ae5bf5a,0x41e4dbe2,0x2d99bf5b,0x6b840a49}},	//   _rojt, _філа, gure_, esig, 
   {{0x7ae4bff1,0x6b85bf5c,0x613c7dec,0x709401d5}},	//   _sojt, fsig, béla, _жаъф, 
   {{0x6b85bf5d,0x7ae40455,0x71253b7b,0xbf641e24}},	// [31550] gsig, _pojt, _تىيم, _بدبو, 
   {{0x2d99bf5e,0x80a41f13,0xef0800ec,0x00000000}},	//   bure_, ट्रे, _وٺيو_, --, 
   {{0x7ae59d88,0x6b85bf5f,0x00000000,0x00000000}},	//   _vojt, asig, --, --, 
   {{0x6b85bf60,0x2fc0017a,0x7ae5bf61,0x23bc00dc}},	//   bsig, _ysig_, _wojt, ्टाद, 
   {{0x6b840050,0x7ae40477,0x00000000,0x00000000}},	//   csig, _tojt, --, --, 
   {{0x7bcc0c8c,0xd8a80451,0xe7a80154,0x00000000}},	//   _ircu, _گهرو_, ওয়্য, --, 
   {{0xb88402f4,0x2c58063f,0x6ef000fd,0x613c02f0}},	//   _муай, _ọdi_, _qäbi, zéla, 
   {{0x7bcc00f3,0x645c0134,0x1cb8031c,0xf7b80214}},	//   _krcu, ɛrik, _ཚིས_, _پدرش_, 
   {{0x48f800c8,0x1309350a,0xdb1d0e96,0x925804fb}},	//   _פּלא, йний_, _assé, یشگر_, 
   {{0x2d9800aa,0x613dbf62,0x6ef00139,0x7bcdb36e}},	//   yure_, véla, _täbi, _mrcu, 
   {{0x2d9902b9,0x613c003e,0x67680023,0x00000000}},	//   xure_, wéla, _ዝተዓጥ, --, 
   {{0x2d99bf63,0x6b85bf64,0x604001f2,0x7bcc34a2}},	//   vure_, ysig, _ịman, _orcu, 
   {{0xdb1ce0fe,0x2d980214,0x6b840169,0x00000000}},	//   _essé, wure_, xsig, --, 
   {{0x2d9980c5,0x613c00d5,0x6b840fac,0x00000000}},	//   ture_, réla, vsig, --, 
   {{0x613dbf65,0x6b84058a,0xff042bb7,0x50b401af}},	//   méln, wsig, черк_, _еспу, 
   {{0x2d99bf66,0xfce1bf67,0x6b85bf68,0x613ce099}},	//   rure_, носо, tsig, péla, 
   {{0xc0c40020,0x2fc04cd3,0x2d98e1b2,0x6b85bf69}},	// [31560] ችንም_, _usig_, sure_, usig, 
   {{0x6b85bf6a,0x2d99bf6b,0xfd1c0241,0x81e00f22}},	//   rsig, pure_, _ejì_, _নেট_, 
   {{0x14bc67b1,0x7bcdbf6c,0x2d980129,0x00000000}},	//   ्याण, _ercu, qure_, --, 
   {{0xc7c4034b,0x07a400f3,0x00000000,0x00000000}},	//   зски, задн, --, --, 
   {{0x6b840014,0x4c3401c0,0x945c0100,0x7bc803cd}},	//   qsig, _хэнт, edńo, ågut, 
   {{0xf1d80882,0xb8d0000d,0x00000000,0x00000000}},	//   यमान, _जॉ_, --, --, 
   {{0xbb41bf6d,0x7e60002d,0x613c00bc,0x6fa800eb}},	//   _черк, _ûnpe, déln, খিয়ে, 
   {{0xe94401b9,0xe4d8004b,0x589401c4,0x00000000}},	//   _آرسی, زوخت_, _ошуу, --, 
   {{0x73d5bf6e,0x00000000,0x00000000,0x00000000}},	//   здыр_, --, --, --, 
   {{0xd054016b,0x2259449a,0x5908031c,0xc68c00f1}},	//   _woyɛ, ørk_, _གཏོས_, _صېب_, 
   {{0x85741867,0x81e000fe,0x00000000,0x00000000}},	//   _ردائ, _নেজ_, --, --, 
   {{0x63a40276,0xf6f402dd,0x6d482ffe,0x5fb800bc}},	//   _ţinu, _وزەگ, ïdal, इबलल, 
   {{0x6ef00037,0x69c80142,0x00000000,0x00000000}},	//   _läbu, _âdef, --, --, 
   {{0xa19400db,0x00000000,0x00000000,0x00000000}},	//   _жакч, --, --, --, 
   {{0x63ac0153,0xdd90007b,0xd344179e,0xf8cc00cd}},	//   žinč, ضوء_, _تفوی, _सोऽय, 
   {{0x291dbf6f,0xa3c001f9,0xf234011a,0xa14800e5}},	//   éval_, _ंना_, _מרוץ_, _بستے_, 
   {{0xb35c0023,0x00000000,0x00000000,0x00000000}},	// [31570] _ተባዕን_, --, --, --, 
   {{0x1ea805d9,0x2138036e,0x9f64012d,0x00000000}},	//   _ڏاڍي_, llsh_, łtów_, --, 
   {{0x98f4021a,0xed580261,0xdd94013d,0x99d40b24}},	//   وګرا, _ноќ_, _юаны, بقات, 
   {{0xd8380024,0x00000000,0x00000000,0x00000000}},	//   опец_, --, --, --, 
   {{0x37a9bf70,0xdb1c0579,0x7bcc0356,0x263c0208}},	//   стен_, _orsø, _urcu, _ảo_, 
   {{0x7d0c02d0,0x9b452028,0x81e000cc,0x00000000}},	//   _hmcs, _آنسو, _নেছ_, --, 
   {{0x7ae0840d,0xd5480b87,0x959800d3,0x59440014}},	//   öntu, опке_, ітку_, _ہکچہ, 
   {{0xe61078db,0x00000000,0x00000000,0x00000000}},	//   دشه_, --, --, --, 
   {{0x7f5c003d,0x7d0c00b5,0x57240046,0x934400d8}},	//   _nuqq, _mmcs, _قىرك, мние, 
   {{0x7778009a,0xaae00825,0x387c7d9b,0x21cc00bc}},	//   _iwux, नायक, _heur_, _běh_, 
   {{0x387cebf1,0x63a40311,0x613dbf71,0xfdcc0154}},	//   _keur_, _ţint, réln, রহুড, 
   {{0x7f5c198f,0x387c003e,0x98ac02f0,0x613c00e5}},	//   _buqq, _jeur_, _okeč_, séln, 
   {{0x387c03bd,0x7bc800b5,0x613c003e,0x00000000}},	//   _meur_, ægul, péln, --, 
   {{0x387dbf72,0x56b4010f,0x73480798,0x00000000}},	//   _leur_, ופֿן_, _учев_, --, 
   {{0xce480220,0xd108484d,0x00000000,0x00000000}},	//   ізбе_, _وقته_, --, --, 
   {{0x387dbf73,0xe1f00133,0x6ef00254,0x00000000}},	//   _neur_, _حسه_, _räbu, --, 
   {{0x3ce8004e,0x0ae82401,0xbfc000db,0xd1bc0023}},	// [31580] _docv_, одай_, _абык, ሳእቲ_, 
   {{0x3ab07c4c,0x00000000,0x00000000,0x00000000}},	//   кәст, --, --, --, 
   {{0x77780921,0x99640046,0x387ccedb,0xfaa1251c}},	//   _awux, етіл, _beur_, тахо, 
   {{0xbb340952,0xa93400f7,0x1cdc031c,0x88d4002b}},	//   ﻗﻘﻰ_, رباچ, _ཡོར_, _mṛgy, 
   {{0x387c6852,0x2ca0089c,0x38c955a8,0x613c00e5}},	//   _deur_, mgid_, تالی_, déll, 
   {{0x2ca034a6,0x61180115,0x7ae00108,0x00000000}},	//   lgid_, rĉli, öntt, --, 
   {{0xfaa176c3,0x2b58ed74,0x387dbf74,0x6d58004a}},	//   _шаро, _iirc_, _feur_, _évas, 
   {{0x387dbf75,0x2ca1bf76,0x2b58030a,0x3cf800df}},	//   _geur_, ngid_, _hirc_, ַלינ, 
   {{0x2ca0f392,0x22a4013e,0x00000000,0x00000000}},	//   igid_, нунҳ, --, --, 
   {{0x69c80077,0x387c01f5,0x7f5c022e,0x00000000}},	//   _ádes, _zeur_, _ruqq, --, 
   {{0x6114a230,0x2b59bf77,0x7f5c834a,0xf2c03838}},	//   едну, _mirc_, _suqq, тсын, 
   {{0x88d40055,0xc0cc0092,0x00000000,0x00000000}},	//   _dṛgy, _ቤቱም_, --, --, 
   {{0xa2941ed2,0x613c003e,0x24840036,0x90b001e0}},	//   _залі, sélo, mamm_, уҙыш, 
   {{0x44259626,0x2484030a,0x613c0098,0x88d4002b}},	//   _ixo_, lamm_, pélo, _hṛdy, 
   {{0xdce40882,0x5275bf78,0x7f540393,0xfcc40640}},	//   _athā, _чучу, _vixq, мљам, 
   {{0x2b59bf79,0x2ca1bf7a,0x7f5dbf7b,0x248485fa}},	//   _airc_, ggid_, _tuqq, namm_, 
   {{0x2b59bf7c,0x69d800fe,0xff040166,0x88d40055}},	// [31590] _birc_, åven, _жянн, _mṛdy, 
   {{0xab9402bf,0x2ca1bf7d,0x7d0c0175,0x387dbf7e}},	//   тифі, agid_, _wmcs, _seur_, 
   {{0xbb3476b9,0x387dbf7f,0x63a403cd,0xed640306}},	//   ﻗﺘﻰ_, _peur_, _åinf, raží_, 
   {{0x2b58089c,0x4424045a,0x00000000,0x00000000}},	//   _eirc_, _oxo_, --, --, 
   {{0x387c03bd,0x2b580077,0xba75bf80,0x7ae035e9}},	//   _veur_, _firc_, _ياست, önts, 
   {{0x387c0de2,0x973400e5,0x00000000,0x00000000}},	//   _weur_, ءکرا, --, --, 
   {{0x4425bf81,0x613c0599,0x298800fb,0x00000000}},	//   _axo_, téll, _осто_, --, 
   {{0x1cdc0003,0xe3c801fb,0x24840165,0xaae0095f}},	//   _ཡོས_, _bự_, gamm_, नाथक, 
   {{0xe3c801fb,0x77780472,0x6ef00139,0x9474129e}},	//   _cự_, _uwux, _mäbr, ودکا, 
   {{0xe3c807ae,0x4425bf82,0x03200026,0xc320c778}},	//   _dự_, _dxo_, лдын, лмык, 
   {{0x10a40131,0xaae12877,0x5ed80150,0x613c01d3}},	//   нинн, नातक, _ﺀﺗﯘﺭ, mélj, 
   {{0x2484004e,0x1ca8031c,0x27e0332c,0xaa8400a2}},	//   camm_, བཅས_, åing_, meýş, 
   {{0xdb1c1892,0xb4b801ad,0xaa840432,0x00000000}},	//   _assí, आजी_, leýş, --, 
   {{0x7539bf83,0x7d1c0369,0xdce400cd,0x00000000}},	//   lluz, enqs, _rthā, --, 
   {{0xdce40a28,0x2ca000b5,0xd5c407f7,0x80c800bc}},	//   _sthā, tgid_, विटज, _तोके, 
   {{0x2b59bf84,0x6ef00139,0x00000000,0x00000000}},	//   _sirc_, _cäbr, --, --, 
   {{0x2ca1bf85,0x2b59bf86,0x7538005a,0xd838010e}},	// [315a0] rgid_, _pirc_, iluz, _nyō_, 
   {{0x75381cdf,0x7bc00882,0xb0ac0f4a,0x26100037}},	//   hluz, ānup, ट्रग, _थइली_, 
   {{0x7539bf87,0x49986c20,0x7e60002d,0x2b580427}},	//   kluz, ятая_, _ûnpa, _virc_, 
   {{0xc7c8005b,0xdce40055,0x00000000,0x00000000}},	//   зыке_, _tthā, --, --, 
   {{0x7539bf88,0x26c8054a,0x2b5807c5,0xd764006c}},	//   dluz, мған_, _tirc_, نچلی, 
   {{0x659509e0,0x2d999888,0x24842305,0x06642309}},	//   ваку, orre_, wamm_, راتپ, 
   {{0xe3c801dc,0xfc3c0077,0x44240810,0x2485bf89}},	//   _sự_, _icía_, _sxo_, tamm_, 
   {{0x5908025c,0xcfe4015b,0x98ac0003,0x6ef00139}},	//   _གཏགས_, _পেছন, _tieġ_, _xäbr, 
   {{0xd90da39a,0x2485bf8a,0x4658007b,0x69d801bf}},	//   _بین_, ramm_, _فؤاد_, ævef, 
   {{0x24840221,0xdb1c0209,0xdbcc0248,0x02a401fe}},	//   samm_, _orsý, _kóòr, хрим, 
   {{0x75380010,0x00000000,0x00000000,0x00000000}},	//   bluz, --, --, --, 
   {{0xe3c801dc,0x44240070,0x75380276,0x2d98036e}},	//   _tự_, _txo_, cluz, drre_, 
   {{0x66f4069f,0x2d99bf8b,0xf4842814,0xdbcc0ca8}},	//   _अवाक_, erre_, _سانی, _lóòr, 
   {{0xdecc02d3,0x3afc00c7,0x1cb8031c,0xdd9400f7}},	//   _ኣሎኒ_, _oîpa_, _ཚིང_, кагы, 
   {{0x69d80158,0x613c01d3,0x00000000,0x00000000}},	//   åvel, nélk, --, --, 
   {{0xb60002fb,0x7b640150,0x00000000,0x00000000}},	//   ýšil, етже, --, --, 
   {{0x2d980225,0x00000000,0x00000000,0x00000000}},	// [315b0] arre_, --, --, --, 
   {{0xab1802bf,0xdc4400e2,0xfca850d8,0x00000000}},	//   нієї_, mīļo, _کادو_, --, 
   {{0xdecc069c,0x6ef000fd,0xceb005d0,0xeaa001e1}},	//   _ኣሎና_, _täbr, _דיי_, _ńṣa_, 
   {{0x6d58f9d3,0xf094008f,0x1c440131,0x57f40120}},	//   _évap, ָנס_, _үнүм, кпет, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf574022e,0xdbcc01e1,0xaa0000d7,0x00000000}},	//   _yig訴, _wóór, škáš_, --, 
   {{0xb8b00efb,0x67240036,0x613c00e5,0x00000000}},	//   _бөлі, éija, rélj, --, 
   {{0xa564009a,0xda6400ec,0x00000000,0x00000000}},	//   ددون, _ساڀي, --, --, 
   {{0x3f88068f,0x7539bf8c,0x5275bf8d,0x613c00e5}},	//   jscu_, rluz, куну, mélh, 
   {{0x41400092,0x2d980009,0x00000000,0x00000000}},	//   _የሃገሪ, yrre_, --, --, 
   {{0xbb18019f,0x3f89bf8e,0x6594013e,0x7539bf8f}},	//   _kwîb, escu_, _баху, pluz, 
   {{0x1cb80327,0x00000000,0x00000000,0x00000000}},	//   _ཚིཊ_, --, --, --, 
   {{0xc95000c8,0x291c00e4,0x0874010f,0x00000000}},	//   ימט_, évai_, כערט_, --, 
   {{0x645c0882,0x24e4035b,0xa4440a4a,0x66280162}},	//   śrit, _ацәг, _снід, _ískú, 
   {{0x2d8dbf90,0x9db8d8d1,0x98ac0327,0x2d98009d}},	//   éde_, ныту_, _gieħ_, urre_, 
   {{0xdb1c00e5,0x00000000,0x00000000,0x00000000}},	//   _orsó, --, --, --, 
   {{0x66040115,0xdbcc01e1,0x1ba800e5,0x3c600166}},	// [315c0] ĝiki, _sóòr, فالٹ_, ркуг, 
   {{0x1ca80327,0x4d6401ee,0x00000000,0x00000000}},	//   བཅུ_, _иков, --, --, 
   {{0xba14046f,0xc33008a8,0xb6040153,0x00000000}},	//   نيكا_, סוב_, nešė, --, 
   {{0x0d2003cc,0x29000120,0x613c00e5,0xd76400f2}},	//   _түбү, óia_, gélh, گنوی, 
   {{0x3f4c031c,0x3ce802f0,0x80a4086b,0x87d80116}},	//   _iżur_, živá_, ट्टे, بباس_, 
   {{0x613c00e5,0x00000000,0x00000000,0x00000000}},	//   télk, --, --, --, 
   {{0x27e000a8,0x69d8037e,0x00000000,0x00000000}},	//   ţin_, æved, --, --, 
   {{0xa4944144,0x3f4c031c,0xaae0012c,0xe79400e5}},	//   ایشت, _jżur_, नावक, _مائک, 
   {{0x7d00084c,0x46b40a2c,0x07a48eb3,0x855401b9}},	//   _înse, _لحاس, _шаан, _ییتر_, 
   {{0x613c2056,0xb82428eb,0x68443e64,0x983400c0}},	//   méli, _роуз_, _анға, _сэсі, 
   {{0x31c00801,0xe2151ed1,0xb6f400db,0xdbcc08a5}},	//   асяв, умны, _جىلا_, _lóðr, 
   {{0x26cdbf91,0x00000000,0x00000000,0x00000000}},	//   _hado_, --, --, --, 
   {{0x26cc0385,0x613c0129,0x69d801bf,0xbb2c01ec}},	//   _kado_, néli, åvej, _ﺨﻭﻑ_, 
   {{0xdef0044e,0x5f452242,0xb3b4123b,0x00000000}},	//   _ግናኸ_, انسل, _ספוג_, --, 
   {{0x6289bf92,0x613dbf93,0x26cdbf94,0x20dc0073}},	//   mado, héli, _mado_, याआध, 
   {{0x26cc1a36,0x6d58011c,0x00000000,0x00000000}},	//   _lado_, _èval, --, --, 
   {{0x63a16f38,0xbcf83d0a,0xac180640,0x7e60002d}},	// [315d0] numn, _liég, воту_, _ûnpo, 
   {{0x60cdbf95,0x26cdbf96,0x613dbf97,0xae440014}},	//   _haam, _nado_, déli, _چھٲو, 
   {{0x60cdbf98,0xaa64081d,0xf9c40801,0x6289bf99}},	//   _kaam, ртук, ъщан, iado, 
   {{0x60cdbf9a,0x63a1bf9b,0x3871bf9c,0xf1b000c8}},	//   _jaam, kumn, рқат, יסע_, 
   {{0x60cdbf9d,0x26cc00b2,0x6289bf9e,0xb8c80c66}},	//   _maam, _bado_, kado, _खा_, 
   {{0x62881d62,0x26cdbf9f,0x60cdbfa0,0x1cb8025c}},	//   jado, _cado_, _laam, _ཚིཌ_, 
   {{0x26cc1d62,0xc68c143e,0xbb2c0150,0x546800db}},	//   _dado_, سِي_, _ﺨﻭﻓ_, найм_, 
   {{0x60cdbfa1,0x26cc0086,0xbcf9bfa2,0x63a00472}},	//   _naam, _eado_, _diég, fumn, 
   {{0x63a1bfa3,0x613c00d2,0xe918003b,0x00000000}},	//   gumn, lélw, _роті_, --, 
   {{0x26cdbfa4,0xd175bfa5,0x1cdc031c,0xd90c01ed}},	//   _gado_, лымы, _ཡོཀ_, _بیچ_, 
   {{0x60cc6cee,0x0595bfa6,0xd1b9bfa7,0x918000cf}},	//   _baam, _مانگ, رادا_, حۇبۇ, 
   {{0x63a01929,0x60cdbfa8,0xd00806ed,0x00000000}},	//   bumn, _caam, ееме_, --, 
   {{0x8250044e,0x60cdbfa9,0x26cc0334,0x65940133}},	//   _መዓልታ, _daam, _yado_, _مجۆر, 
   {{0x6288a896,0xdbcc0579,0x481400c8,0xf48401b9}},	//   cado, _róðr, אַלן_, _ساچی, 
   {{0x60cc9461,0x8cb45fb7,0x00000000,0x00000000}},	//   _faam, лсач, --, --, 
   {{0x61fc3ad2,0x6e440014,0x00000000,0x00000000}},	//   ørle, ُچھم, --, --, 
   {{0x0ba80046,0xcf580108,0x00000000,0x00000000}},	// [315e0] عارى_, _проч_, --, --, 
   {{0x60cd3878,0x09e4262e,0x613c01a8,0x99900010}},	//   _zaam, лозн, véli, _dzzž_, 
   {{0x60cdbfaa,0x91e400b5,0x00000000,0x00000000}},	//   _yaam, zzのh, --, --, 
   {{0x613c9312,0x9cbc0156,0x60cc0429,0x26cdbfab}},	//   téli, _ཕིགས, _xaam, _sado_, 
   {{0x6289bfac,0x26cdbfad,0xbcf9bfae,0x0134008f}},	//   yado, _pado_, _diéd, אָגט_, 
   {{0x6289138e,0x613dbfaf,0x26cc0429,0xbcf8503f}},	//   xado, réli, _qado_, _piég, 
   {{0x7d0000a8,0x26cdbfb0,0x63a1bfb1,0xbb380375}},	//   _însc, _vado_, wumn, _נעלי, 
   {{0x6289bfb2,0x26cc0050,0x63a1bfb3,0x613c0c6a}},	//   wado, _wado_, tumn, péli, 
   {{0x2905bfb4,0x60cdbfb5,0xf360747c,0x26cdbfb6}},	//   _ilma_, _raam, йтэн, _tado_, 
   {{0x26cc003a,0xb6a00139,0x6288030a,0xc19000f2}},	//   _uado_, _гифл, uado, میتع, 
   {{0x6289bfb7,0x63a007f5,0x2259bfb8,0x60cdbfb9}},	//   rado, sumn, ärk_, _paam, 
   {{0x60cdbfba,0x2904003e,0xa0540212,0x63a00455}},	//   _qaam, _jlma_, ивні, pumn, 
   {{0x6289bfbb,0x60cdbfbc,0xf8bc002e,0xf5340a7c}},	//   pado, _vaam, _ñée_, _גראז_, 
   {{0x1cdc1f21,0x60cdbfbd,0x6289bfbe,0x6db40116}},	//   _ཡོང_, _waam, qado, әйту, 
   {{0x60cdbfbf,0xbcf820ef,0x00000000,0x00000000}},	//   _taam, _liée, --, --, 
   {{0xa3b80490,0x4084013d,0xa11400f2,0x00000000}},	//   _चहा_, _сукб, _خوبت, --, 
   {{0x5b15bfc0,0x21288616,0x307800c6,0xaae043d1}},	// [315f0] амат, _ijah_, _صحية_, नांक, 
   {{0x2905bfc1,0x70240014,0xba280131,0x945c012d}},	//   _alma_, _درٕ٘, ىسام_, leńc, 
   {{0x64b40490,0xbcf80129,0xdb0c4fdf,0xba449de4}},	//   ंभाळ, _piéd, ntaé, ухай, 
   {{0xd7d40261,0x317800df,0x00000000,0x00000000}},	//   ижењ, גראמ, --, --, 
   {{0x212801f5,0x00000000,0x00000000,0x00000000}},	//   _mjah_, --, --, --, 
   {{0x2905bfc2,0x00000000,0x00000000,0x00000000}},	//   _elma_, --, --, --, 
   {{0x21280098,0x613c0129,0x00000000,0x00000000}},	//   _ojah_, lélu, --, --, 
   {{0x6a14010b,0x21294882,0xdd04000d,0x8a400244}},	//   _умсу, _njah_, रसिध_, _بێمن, 
   {{0x67d40276,0x13040131,0x83d0033f,0x76a4007b}},	//   _лоту, изим, तिषआ, _محاك, 
   {{0x2129bfc3,0x66200118,0x395c01f4,0x00000000}},	//   _ajah_, ázká, _hius_, --, 
   {{0x2904010b,0x9f580022,0x6708009d,0x114800db}},	//   _ylma_, pysê_, _сэтг_, кпой_, 
   {{0x10a42097,0xbcf8004e,0x2dc8023b,0x69d803cd}},	//   шимн, _liéb, ҳқон_, åvei, 
   {{0x212805be,0x98c40024,0xfc3c110e,0x52740137}},	//   _djah_, ūtės_, _nyí_, _куйу, 
   {{0x395d0bd5,0x00000000,0x00000000,0x00000000}},	//   _lius_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x395c1028,0xe808012c,0x14bc0073,0x2128036e}},	//   _nius_, वनमा_, ्यटण, _gjah_, 
   {{0x4aa8bd8c,0xca84487f,0xd6840116,0x00000000}},	// [31600] ккан_, игай, _ﯬﮔﻪﺭ_, --, 
   {{0x3165bfc4,0x0d846e27,0xe0540050,0x00000000}},	//   _kunz_, _клон, _دیُت_, --, 
   {{0x395c8a67,0x6f1dbfc5,0xbcf84264,0xfc3c0248}},	//   _bius_, mirc, _diéb, _eyí_, 
   {{0x613c3822,0x6f1c011c,0x395c0393,0xacb40150}},	//   bélu, lirc, _cius_, _دەرب, 
   {{0x67d4cd77,0x395d2f59,0xf76dbfc6,0x613d57a0}},	//   солу, _dius_, واو_, célu, 
   {{0x395cc51b,0x6f1dbfc7,0xdb0c0428,0x68441719}},	//   _eius_, nirc, bwañ, анҗа, 
   {{0x395dbfc8,0x00000000,0x00000000,0x00000000}},	//   _fius_, --, --, --, 
   {{0x395c0656,0x68e0014b,0xdb1c01e3,0x6f1c7aa0}},	//   _gius_, _unmd, _essä, hirc, 
   {{0x6f1dbfc9,0x316407c5,0x46a40354,0xb898123b}},	//   kirc, _aunz_, _вазв, _שבמש, 
   {{0x6f1dbfca,0x2128017a,0x00000000,0x00000000}},	//   jirc, _sjah_, --, --, 
   {{0x31640399,0x31600036,0xf1a00d97,0x05647546}},	//   _cunz_, _biiz_, орян, _твен, 
   {{0x6739bfcb,0x656801c3,0x2099bfcc,0xb5f8010f}},	//   lovj, _iudh, ыкмы_, _שלאכ, 
   {{0x4431bfcd,0x6f1dbfce,0x9f5806af,0xe37401ee}},	//   _ây_, firc, lysé_, _уллы, 
   {{0x6569bfcf,0x3160022e,0x32d00050,0xada800d0}},	//   _kudh, _eiiz_, _وٲنس, zdĺž, 
   {{0xaee40a28,0x656899ba,0x31640051,0x00000000}},	//   _saṃv, _judh, _gunz_, --, 
   {{0x6569bfd0,0x212801f0,0x52e80022,0x6f1c03d5}},	//   _mudh, _ujah_, _агәҭ_, airc, 
   {{0x1868006c,0x2d58b19d,0x395c9972,0x3164019f}},	// [31610] қали_, рить_, _rius_, _zunz_, 
   {{0x6f1dbfd1,0x1cb80135,0x67382804,0x65680430}},	//   circ, _ཚིམ_, jovj, _oudh, 
   {{0x395dbfd2,0x656800f2,0x673966d5,0x613c0c6a}},	//   _pius_, _nudh, dovj, sélu, 
   {{0xbcf87dec,0xfafc002e,0x21380023,0xaee40055}},	//   _diéc, _guën_, nosh_, _taṃv, 
   {{0x395c4d74,0x6568f438,0x37a8516c,0x5d140050}},	//   _vius_, _audh, ттен_, _نِگا, 
   {{0x16a9bfd3,0x673870b1,0x5908025c,0xd3940184}},	//   увки_, govj, _གཏམས_, ҡәлә_, 
   {{0x213802d3,0xdb0dbfd4,0x395cd6a6,0x38c800c7}},	//   kosh_, ltaï, _tius_, _иуан_, 
   {{0x81bc0729,0x6569bfd5,0x6f1c036b,0x21380240}},	//   ীমা_, _dudh, zirc, josh_, 
   {{0x2139bfd6,0x6f1c05d1,0x67380219,0x56956d4a}},	//   dosh_, yirc, bovj, _газт, 
   {{0x65680a4d,0xdb1c03e0,0xaae000bc,0x00000000}},	//   _fudh, _ersö, नाएक, --, 
   {{0x6569bfd7,0x63a408fb,0x21380200,0x1ae800cc}},	//   _gudh, _åinn, fosh_, _গতাই_, 
   {{0x31640207,0x2138feea,0x6f1c01c7,0x61fc03cd}},	//   _vunz_, gosh_, wirc, ørla, 
   {{0x78b88f07,0xe8380023,0x6f1ca6a6,0x613c00e5}},	//   _mbuv, _እናተቐ, tirc, vélt, 
   {{0x6569bfd8,0xe3b153b4,0xfafc01c7,0x3f640107}},	//   _yudh, _زره_, _suën_, сиро_, 
   {{0x6b500628,0x78b9bfd9,0x2139bfda,0x6569bfdb}},	//   lägg, _obuv, bosh_, _xudh, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x09b013b4,0xc0c002d3,0x6f1dbfdc,0x613c01d3}},	// [31620] ीब्य, ትኦም_, pirc, rélt, 
   {{0x78b80453,0xbcf8004a,0x613c00e5,0x00000000}},	//   _abuv, _piéc, sélt, --, 
   {{0x8db400d6,0x613d99eb,0x67381710,0x00000000}},	//   _успі, céls, vovj, --, 
   {{0x48080798,0x6569bfdd,0xa3b8228d,0x00000000}},	//   леен_, _rudh, _चहल_, --, 
   {{0x6569bfde,0x6d45bfdf,0xca74010b,0x67381710}},	//   _sudh, mlia, _губы, tovj, 
   {{0xd1bc069c,0x6d45bfe0,0x78b80a49,0x6568020c}},	//   ዳእታ_, llia, _ebuv, _pudh, 
   {{0x6d440cfd,0x6739bfe1,0x656801d9,0x2138036b}},	//   olia, rovj, _qudh, yosh_, 
   {{0x6d45bfe2,0x21380023,0x673800f3,0x1cdc031c}},	//   nlia, xosh_, sovj, _ཡོབ_, 
   {{0x67381711,0xaee41682,0x6d45bfe3,0x04c42756}},	//   povj, hiṱh, ilia, لوژي_, 
   {{0x6d45bfe4,0xcfbc045e,0x03a40fc0,0x6569bfe5}},	//   hlia, ইটান, _ҳидо, _tudh, 
   {{0x6d4402d5,0x2139bfe6,0x65680a55,0xf674010f}},	//   klia, tosh_, _uudh, _הײבט_, 
   {{0xb9dc044e,0x108c0873,0x69dc0200,0x6b5001e3}},	//   _ኣደ_, _ﻛﯩﺮﯨ, _mrre, lägd, 
   {{0x2139bfe7,0x6d4400a9,0x69dc0076,0x2294ab30}},	//   rosh_, dlia, _lrre, _диля, 
   {{0x6d45bfe8,0x69ddbfe9,0x21380023,0xf19001d9}},	//   elia, _orre, sosh_, _کُٹھ, 
   {{0x1cdc2b65,0x6d45bfea,0x8cd80574,0xde5802bf}},	//   _ཡོད_, flia, _पोहो, раві_, 
   {{0x6d45bfeb,0x00000000,0x00000000,0x00000000}},	//   glia, --, --, --, 
   {{0x82c4025c,0x69d8037e,0x00000000,0x00000000}},	// [31630] _ཀྲོའ, æven, --, --, 
   {{0x69dcaeee,0x78b804cc,0x291c1f3f,0x7c2c002b}},	//   _brre, _sbuv, èvan_, _ākrā, 
   {{0x6d45bfec,0x7d000276,0xd87800c6,0x69dc0240}},	//   blia, _înso, لمات_, _crre, 
   {{0xe89402bf,0x6d45bfed,0x04f80154,0x00000000}},	//   заць, clia, ইফুর_, --, 
   {{0x69ddbfee,0x6299bfef,0x966428a8,0xf7700131}},	//   _erre, _odvo, окле, ساش_, 
   {{0xbb18019f,0x7bcc0c8c,0x629800d2,0xdb0c00c6}},	//   _kwîm, _iscu, _ndvo, otaí, 
   {{0xdb0c00c6,0x82c4031c,0x69d80158,0x00000000}},	//   ntaí, _ཀྲེའ, åvet, --, 
   {{0x78b80796,0x7d1c07d6,0x6abc00f3,0x7bcc0334}},	//   _ubuv, niqs, _zbrf, _kscu, 
   {{0xbb1800d2,0xdb0c00ae,0x00000000,0x00000000}},	//   _lwîm, htaí, --, --, 
   {{0x7d1c0113,0x6d440419,0x0bb4011a,0x00000000}},	//   hiqs, zlia, קלתם_, --, 
   {{0x90c5bff0,0x6d4400a9,0x2d7801a6,0x7d1c0113}},	//   обне, ylia, _ičeg_, kiqs, 
   {{0x7bcdbff1,0x3208068f,0x78a80399,0xaee4002b}},	//   _oscu, ący_, nggv, _kaṇv, 
   {{0x6b51bff2,0x7bcc0113,0x63a00477,0x7539bff3}},	//   läge, _nscu, crmn, mouz, 
   {{0x7539bff4,0x6d4400a9,0x40440212,0x2ed400cd}},	//   louz, wlia, іпро_, दयेत, 
   {{0x7bcdbff5,0x6d45bff6,0x6b51bff7,0x00000000}},	//   _ascu, tlia, näge, --, 
   {{0x6d45bff8,0xfce03c85,0x629802fb,0xfafc0036}},	//   ulia, мосо, _zdvo, _wuël_, 
   {{0x8eb8084c,0x6d45bff9,0x5ea51192,0xa3dc000d}},	// [31640] _кынт_, rlia, _کمپل, डिय_, 
   {{0xac08cacd,0x7bcc0789,0x753802a8,0x98ac0030}},	//   анға_, _dscu, houz, _cieľ_, 
   {{0x49c9bffa,0x798402d0,0x6b503b52,0x7d1c0009}},	//   рлен_, _cwjw, jäge, biqs, 
   {{0x7d1c008e,0x6b50008e,0x00000000,0x00000000}},	//   ciqs, däge, --, --, 
   {{0x765c0cc1,0xbb3406ba,0x6b50007c,0x00000000}},	//   əyyə, ﺗﺘﻪ_, tägd, --, 
   {{0x69d800cc,0x69dc0200,0xf3ec00eb,0x00000000}},	//   åves, _trre, টনার_, --, 
   {{0x69ddbffb,0x3565bffc,0xbcf800e5,0x00000000}},	//   _urre, орын_, _mién, --, 
   {{0x99741086,0x888532ba,0x7538030a,0x1fd0009e}},	//   _хурш, _флаж, gouz, ামতস, 
   {{0x82c40003,0x81bc0154,0x00000000,0x00000000}},	//   _ཀྲུའ, ঁয়া_, --, --, 
   {{0xb2b482ed,0x6b5000fd,0xbcf800e8,0x6ef0007c}},	//   ольф_, bäge, _nién, _täby, 
   {{0x7dc0013f,0x7539bffd,0xa17401ca,0x6b500139}},	//   _kεse, bouz, ягні, cäge, 
   {{0x88d4002b,0x00000000,0x00000000,0x00000000}},	//   _sṛjy, --, --, --, 
   {{0x88d40055,0x68e40108,0x00000000,0x00000000}},	//   _pṛjy, öidy, --, --, 
   {{0x629805ce,0xbcf804d4,0x00000000,0x00000000}},	//   _udvo, _cién, --, --, 
   {{0xf278025f,0xbcf80d51,0x78a80008,0x61fc01e6}},	//   _דרוש, _dién, yggv, ärld, 
   {{0xdb0c007b,0x00000000,0x00000000,0x00000000}},	//   rtaí, --, --, --, 
   {{0xdb0c0597,0x7d1c42b2,0x98a400ee,0x5db801ec}},	// [31650] staí, riqs, җиле, _ﺸﻴﻌﻴ, 
   {{0x1cdc081f,0x7539ab2a,0x7d1c022e,0x39840142}},	//   _ཡོམ_, zouz, siqs, tŵs_, 
   {{0xceb0159d,0xaaac012c,0x753801f7,0x7d1c0113}},	//   _איי_, _चारक, youz, piqs, 
   {{0x6b50049f,0xcdd800c8,0xed5806ed,0x9e840345}},	//   väge, _פֿיר, _моќ_, _باکۆ, 
   {{0x69d945fb,0x3ab00032,0x6b500112,0x7bcc035a}},	//   åver, _оҙат, wäge, _uscu, 
   {{0x753802e2,0x98b00139,0x00000000,0x00000000}},	//   wouz, _vuzı_, --, --, 
   {{0x7538c0b7,0x00000000,0x00000000,0x00000000}},	//   touz, --, --, --, 
   {{0x6b50473b,0xe61001b9,0x49900014,0x25ec000d}},	//   räge, خشه_, _سیٖر, _आऊरी_, 
   {{0x6b514804,0x1424036b,0x7539bffe,0x855401d9}},	//   säge, ядим, rouz, سیٖر_, 
   {{0x130843a7,0x753800bc,0x758001b9,0x00000000}},	//   сной_, souz, _قیتم, --, 
   {{0x753807f5,0xbcf80789,0xcb100375,0xb9e001f3}},	//   pouz, _rién, גלי_, _ከነ_, 
   {{0xbcf80407,0x383c0240,0x00000000,0x00000000}},	//   _sién, _ክሓስብ, --, --, 
   {{0xb4d402ab,0xbcf80789,0xaaac0562,0x862802d3}},	//   ायी_, _pién, _चालक, _ድሕነት, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbcf936b4,0xc27802e4,0x82c40327,0x00000000}},	//   _vién, _פרקי, _ཀྲིའ, --, 
   {{0x61fd0b4e,0x41b000c6,0x88d40882,0xc198011a}},	//   ärle, _أمير, _gṛhy, _השקי, 
   {{0xbcf8067c,0xfbdc0798,0xdbf001ef,0x403000f3}},	// [31660] _tién, _crê_, bříc, _пећс, 
   {{0xa3dc0b26,0xb4d43c71,0x6ea801ed,0x00000000}},	//   डित_, ायु_, _بندہ_, --, 
   {{0x08c40150,0x00000000,0x00000000,0x00000000}},	//   збен, --, --, --, 
   {{0x7ae402d3,0x7fb46e0c,0xb5c0009e,0xfa3015bf}},	//   _enjt, _بهیر_, ্মাচ, رىنج, 
   {{0xbcf9bfff,0x87b8023a,0x4bd835e6,0x4cd00011}},	//   _miél, сует_, _ابجد_, হাদু, 
   {{0x17680046,0x4e78008f,0x46f40108,0x00000000}},	//   іріп_, זאַצ, ячет, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x39980302,0x63a403cd,0x2be000dc,0x00000000}},	//   _לילד, _åink, निपा, --, 
   {{0xd36c46f5,0x07a5c000,0xdce400b8,0x80b0000d}},	//   لۇن_, _хазн, _juhā, _अाबे, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbd9c001f,0xbcf806af,0xa3b807f7,0x672401c7}},	//   ልባትም_, _biél, _चहक_, éiju, 
   {{0x8db80156,0x69c400c5,0xa6c80154,0x00000000}},	//   _བྱེལ, _रहनी, লাওয়, --, 
   {{0xbcf9a76c,0xdbf000bc,0x2be001ad,0xa3d40395}},	//   _diél, tříc, निफा, _цолч, 
   {{0x73305f32,0x2be00b98,0x00000000,0x00000000}},	//   _كىنا, निना, --, --, 
   {{0xb2b80375,0x57b8000d,0x3cf8012d,0xf1a000c0}},	//   _המור, _इह्ह, ैसले_, _зрын, 
   {{0x9f48002f,0x709408ca,0x00000000,0x00000000}},	//   _fraß_, _заъф, --, --, 
   {{0xec34d52c,0xdb9800d4,0x00000000,0x00000000}},	// [31670] енть, ювач_, --, --, 
   {{0x99880022,0x00000000,0x00000000,0x00000000}},	//   жәаз_, --, --, --, 
   {{0x2a78003e,0x5d54329b,0x00000000,0x00000000}},	//   _dfrb_, _окот, --, --, 
   {{0x25e004fa,0x5fb00307,0xfbdc0208,0x00000000}},	//   किनी_, _जमाल, _trê_, --, 
   {{0xbb1807a8,0x1cdc031c,0xdce400cd,0xd9e80037}},	//   _ntîg, _རྣར_, _guhā, _टपकत_, 
   {{0x2b4401c0,0xf9680816,0x2c7c0118,0x55841291}},	//   _зэсг, _грай_, rádů_, وجعف, 
   {{0x75700241,0x00000000,0x00000000,0x00000000}},	//   _ẹgbè, --, --, --, 
   {{0xb4d5c001,0x6b514f42,0xd6cc00eb,0x00000000}},	//   ाये_, mäga, লাইয, --, 
   {{0x2be0242e,0x6b5001e6,0x381800cc,0x00000000}},	//   निया, läga, _ফুৰো_, --, 
   {{0x1cdc0003,0x945c012d,0x00000000,0x00000000}},	//   _རྣལ_, leńk, --, --, 
   {{0x10a4f5cd,0x6b500724,0xfd1c0241,0x862001e2}},	//   минн, näga, _omì_, _ټکول, 
   {{0x2be0193d,0x00000000,0x00000000,0x00000000}},	//   निमा, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbcf8525e,0xdce400b8,0x6b50007c,0x00000000}},	//   _diém, _ruhā, käga, --, 
   {{0x6b5001e3,0x96d4000d,0xc278011a,0x00000000}},	//   jäga, _धसनउ, _ורצי, --, 
   {{0xdb0dc002,0x7bc00311,0x2d8402fb,0x6b5001e3}},	//   traß, ănun, ďme_, däga, 
   {{0x7bb0004e,0x00000000,0x00000000,0x00000000}},	// [31680] көру, --, --, --, 
   {{0xc88003b9,0xdb0c0d12,0x7c3800a2,0x6b50013d}},	//   _iaşə_, ttaá, _ĸurt, fäga, 
   {{0x6b51489f,0x00000000,0x00000000,0x00000000}},	//   gäga, --, --, --, 
   {{0xc7c43e1e,0xb4d41d27,0xdce400b0,0x07a40024}},	//   дски, ायो_, _tuhā, дадн, 
   {{0xb4d40a28,0x4c340953,0x27e1c003,0xa824335b}},	//   ायै_, _цэнт, íin_, رکرن, 
   {{0xeb54192c,0xa3dc07af,0x6b5004ab,0x00000000}},	//   _سىزگ, डिस_, bäga, --, 
   {{0x8a045c81,0x6b5000fd,0xdd1c0306,0x00000000}},	//   _ўзбе, cäga, lášs, --, 
   {{0x25a0389c,0x00000000,0x00000000,0x00000000}},	//   čil_, --, --, --, 
   {{0xa2941cb8,0x00000000,0x00000000,0x00000000}},	//   напі, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x75d0a534,0xbcf87dec,0xbba800bc,0x00000000}},	//   _ليلا, _diéj, _चम्क, --, 
   {{0xbcf89ec6,0x849401ed,0x25082099,0x00000000}},	//   _piém, _آجائ, _عرضی_, --, 
   {{0xdb1c03b2,0x7d000356,0x00000000,0x00000000}},	//   _assý, _însi, --, --, 
   {{0xc0f002d3,0x05c002ab,0x623400d1,0x00000000}},	//   _ግዳም_, _शहाब, _пелу, --, 
   {{0xdb0cfbc0,0x00000000,0x00000000,0x00000000}},	//   ltaç, --, --, --, 
   {{0x6ca5c004,0x6b5001e6,0xa11404fb,0xbcf800c7}},	//   круж, väga, _سوخت, _tiém, 
   {{0xdb0c03b7,0x4bc063f5,0x71240150,0x6ad80154}},	// [31690] ntaç, лөрг, _جىيم, ঠানো, 
   {{0xbcf80085,0xdb0c06ed,0x64bc11bc,0x6b5001e3}},	//   _kiék, itaç, ्जुश, täga, 
   {{0x8c4005d1,0xdb0c0bbc,0x00000000,0x00000000}},	//   öğre, htaç, --, --, 
   {{0xfca801d5,0xdb0c0309,0x6b503400,0x97d800d4}},	//   _بادو_, ktaç, räga, зьку_, 
   {{0x6b500267,0x941c23ef,0x20c000cd,0x00000000}},	//   säga, _बेंच_, ष्यध, --, 
   {{0x6b500267,0x75d006be,0xcbc401e2,0x00000000}},	//   lägn, _həzə, _سېمو_, --, 
   {{0x1cdc0003,0x15441945,0xdb0c00d8,0x00000000}},	//   _རྣོ_, некм, etaç, --, 
   {{0xca6c0023,0x69c400e1,0x6b5001e3,0x91d402c3}},	//   _ስኢኖም_, _रहती, nägn, _बनबै, 
   {{0x75d000ac,0xb2c402dd,0xdb0c0432,0xb4d41bd6}},	//   _məzə, _ﺒﻤﻭﺍ, gtaç, ायौ_, 
   {{0xcb1000c8,0xa2d40490,0x2be06d58,0x6b5001e3}},	//   ָלט_, _बघण्, निता, hägn, 
   {{0x7d0c00dd,0x3f980455,0x032002d5,0x2f14007c}},	//   _olcs, _avqu_, удэн, _hägg_, 
   {{0x75d00cc1,0x46280003,0xbcf80264,0xa3dc0412}},	//   _nəzə, _སྨྲས_, _diék, डिश_, 
   {{0xdb0c0798,0x6e0400f1,0x00000000,0x00000000}},	//   ctaç, ږېدن, --, --, 
   {{0xdb0c01f4,0x00000000,0x00000000,0x00000000}},	//   ntaä, --, --, --, 
   {{0x2f1404f3,0x9db80046,0x2d8dc005,0x75d003be}},	//   _lägg_, мыту_, ède_, _bəzə, 
   {{0xc5f000c8,0x629c0306,0x00000000,0x00000000}},	//   נדן_, órov, --, --, 
   {{0x3eb40200,0x2be000cd,0x00000000,0x00000000}},	// [316a0] çetë_, निधा, --, --, 
   {{0x7fd40375,0x7d0c01d3,0x6d580055,0x00000000}},	//   _טופס_, _elcs, _ūvad, --, 
   {{0xfbdc01fb,0x63a41445,0x00000000,0x00000000}},	//   _uyên_, _åinv, --, --, 
   {{0x61fc022c,0xcb680209,0x75d00213,0x2be01100}},	//   ørli, _наме_, _gəzə, निदा, 
   {{0x67d556ff,0x6ad80183,0xfd640055,0x3910104c}},	//   толу, ঠাবো, _nipṛ, دونز, 
   {{0x6b85c006,0x98c400e2,0x7aec0327,0x00000000}},	//   mpig, ītās_, ċità, --, 
   {{0x6b8521e0,0x00000000,0x00000000,0x00000000}},	//   lpig, --, --, --, 
   {{0x75d003be,0xa3dc951e,0x6b8401f7,0x00000000}},	//   _xəzə, डिल_, opig, --, 
   {{0x676401af,0x6b84007c,0x00000000,0x00000000}},	//   _анаҡ, npig, --, --, 
   {{0xdb0dc007,0x6b84d784,0xd09806be,0x00000000}},	//   rtaç, ipig, mçək, --, 
   {{0xdb0c0261,0xf2c0a9e6,0x2b580161,0x6235c008}},	//   staç, усын, _mhrc_, тену, 
   {{0x6b840357,0xdb0c06ed,0x2b5801f7,0xfafc0221}},	//   kpig, ptaç, _lhrc_, _huët_, 
   {{0xa3e4038e,0xdb0c0309,0x6b5001e3,0x00000000}},	//   _पछि_, qtaç, vägn, --, 
   {{0x26dc13c4,0x7d0c0175,0x6b8401bf,0x00000000}},	//   ndvo_, _slcs, dpig, --, 
   {{0x7201c009,0x7c840640,0xe13400fd,0x6b8436ff}},	//   _مووم, еузе, _инкы, epig, 
   {{0x2b5802fa,0x75d000ac,0x00000000,0x00000000}},	//   _ahrc_, _qəzə, --, --, 
   {{0xfaa5c00a,0x6b8422d0,0xc0f40092,0x6b50002f}},	// [316b0] ешен, gpig, ፎአል_, rägn, 
   {{0xdb1c067c,0x6b50007c,0x00000000,0x00000000}},	//   _assò, sägn, --, --, 
   {{0xf99101c4,0xbb34040d,0x27e4020c,0x6b840607}},	//   ابط_, ﺗﺘﻰ_, _armn_, apig, 
   {{0x60ddc00b,0x2b580142,0x00000000,0x00000000}},	//   ndsm, _ehrc_, --, --, 
   {{0x60dc057b,0xb09c0375,0x477000d1,0xe89801d3}},	//   idsm, ליאר, иқту, رموں_, 
   {{0x2f1401e6,0xf9900244,0x9984007b,0xfca8431a}},	//   _vägg_, _مبر_, _للسو, _باگو_, 
   {{0xda080127,0x00000000,0x00000000,0x00000000}},	//   _غيره_, --, --, --, 
   {{0x60dc04ce,0x13e80139,0x69000118,0xd09806be}},	//   jdsm, дмий_, ězdá, bçək, 
   {{0x7d000276,0x60dc7c1d,0x2f14007c,0x69c80042}},	//   _însu, ddsm, _häge_, _âder, 
   {{0x613c066d,0x60dc0d81,0xb60400ef,0xd174064e}},	//   mély, edsm, _atšū, кымы, 
   {{0xfafc04e6,0x6b8401c6,0x00000000,0x00000000}},	//   _huës_, zpig, --, --, 
   {{0xbcf80120,0xd6cc0154,0x2f142c43,0x00000000}},	//   _fiéi, লাওয, _mäge_, --, 
   {{0x88980302,0x2f14049f,0x62880158,0x35a402e5}},	//   וברי, _läge_, bbdo, _गिड़, 
   {{0x2be05096,0xe2f80212,0x00000000,0x00000000}},	//   निसा, _печі_, --, --, 
   {{0x3f650085,0xfafc0036,0x1e94010b,0x8cb4004e}},	//   тиро_, _luës_, ыряр, ксач, 
   {{0x6d2402d3,0x657c01ed,0x613c01d3,0x00000000}},	//   _ተወፋይ, _érhe, kély, --, 
   {{0xbcf80036,0x6b84009f,0x25880241,0x63a403cd}},	// [316c0] _liéw, upig, _kìlò_, _åint, 
   {{0x6b85c00c,0x613c00dd,0x4e04136b,0x2f140139}},	//   rpig, dély, _азоб, _bäge_, 
   {{0x2be0069f,0x6b85c00d,0xe8a80184,0xdb1c037e}},	//   निहा, spig, ебеҙ_, _opsæ, 
   {{0xbc6404a2,0xfba81889,0x2b9404fb,0x2f14008e}},	//   رمەن_, _चमचम, _میرس, _däge_, 
   {{0x6d45c00e,0x613c01d3,0x00000000,0x00000000}},	//   moia, gély, --, --, 
   {{0x6d45c00f,0xd09800ac,0x00000000,0x00000000}},	//   loia, rçək, --, --, 
   {{0x2be01b6e,0x385000d1,0x60dc005c,0x00000000}},	//   निवा, лъәс, ydsm, --, 
   {{0x7d000311,0xe8ec0327,0x234801b9,0xb6001422}},	//   _înst, _རོིག, کسبی_, ряшк, 
   {{0x6d440421,0xf4d45409,0x00000000,0x00000000}},	//   ioia, тмыш_, --, --, 
   {{0x6d45c010,0x86e800c6,0xbcf80077,0x60dc0204}},	//   hoia, _تعرف_, _viéi, wdsm, 
   {{0xbb1807a8,0x6d44546d,0x6b500267,0x628801a9}},	//   _kwîr, koia, vägl, rbdo, 
   {{0x6d440798,0x5918031c,0x60dc01a4,0x452802e8}},	//   joia, ྱིགས_, udsm, _южен_, 
   {{0x60ddc011,0x6d455d44,0x6b50002f,0x00000000}},	//   rdsm, doia, tägl, --, 
   {{0xdb2401d3,0x01d801f7,0x00000000,0x00000000}},	//   épül, _يوشع_, --, --, 
   {{0x6e95776b,0x6d443495,0x257825d9,0x6b51c012}},	//   рису, foia, _jél_, rägl, 
   {{0x6d45c013,0x1bd400a7,0x2579c014,0x63a41445}},	//   goia, лобя, _mél_, _åins, 
   {{0xdc540a16,0x92d41c82,0x2f140086,0x257802ea}},	// [316d0] увањ, হাৰ_, _säge_, _lél_, 
   {{0x65600978,0xfe24030d,0x321001e1,0xdea00345}},	//   hmmh, _аьмн, _àayè_, _دیسی, 
   {{0x6d44b7c8,0x257801d3,0x00000000,0x00000000}},	//   boia, _nél_, --, --, 
   {{0x6d44004e,0x2f14000d,0x2be09295,0x613c00e5}},	//   coia, _väge_, निशा, tély, 
   {{0x1cdc0135,0x97c40c4f,0x44f80154,0x00000000}},	//   _རྣག_, اقتو, েফাক_, --, 
   {{0x59180003,0x2be0085c,0x00000000,0x00000000}},	//   ྱིངས_, निरा, --, --, 
   {{0xbcf80066,0x257801d3,0x00000000,0x00000000}},	//   _diév, _cél_, --, --, 
   {{0x693c17a3,0xfafc0036,0x4810c66c,0x257801ed}},	//   včeg, _guër_, рмәс, _dél_, 
   {{0x05e800c7,0x9344447e,0xe8e00051,0xa77400d4}},	//   _ҿыцқ_, лние, _ngộp_, _влуч, 
   {{0x257800dd,0x6d44f520,0x00000000,0x00000000}},	//   _fél_, zoia, --, --, 
   {{0x257843ed,0x66f005d7,0x6d4401c8,0xf6440124}},	//   _gél_, चारक_, yoia, _рхан, 
   {{0x6d4401c4,0x92581ea0,0x00000000,0x00000000}},	//   xoia, _ışıg, --, --, 
   {{0x53a4787c,0x6d44fad9,0xcd0402dd,0xf31401ee}},	//   _салб, voia, қпай, _индә_, 
   {{0xb2840124,0x69c400af,0xce493207,0xa22400f2}},	//   _рыдк, _रहली, езге_, اریه, 
   {{0x6d45c015,0xdd1c012c,0x1cdc031c,0x25780de2}},	//   toia, lářs, _རྣང_, _xél_, 
   {{0x8c442cc8,0x4ac4206b,0x00000000,0x00000000}},	//   гебе, र्नव, --, --, 
   {{0x0ae9c016,0x6d45c017,0x6eac068f,0xdd1c012c}},	// [316e0] ндай_, roia, _जयपु, nářs, 
   {{0x387dc018,0x8a380a8f,0x6d45c019,0x945c0034}},	//   _afur_, няет_, soia, leńs, 
   {{0x888406bb,0x6d448fc6,0xfafc0036,0x80d40154}},	//   глеж, poia, _puër_, ধার্, 
   {{0x25780098,0x7ae800e2,0x2bac0ce0,0xdd1dc01a}},	//   _rél_, ēgta, _चिपा, kářs, 
   {{0x25783386,0x66f00263,0xe9840131,0xdd1c013a}},	//   _sél_, चालक_, _چارۋ, jářs, 
   {{0xdd1c012c,0x94000134,0x2578003e,0xe98400db}},	//   dářs, _ɛhɔ_, _pél_, _نارۋ, 
   {{0xbcf80214,0x2d780219,0x291c0ba1,0x00000000}},	//   _dhéf, _očem_, èvas_, --, 
   {{0x257801a8,0x394c0142,0x945c0210,0x00000000}},	//   _vél_, clgs_, jeńs, --, 
   {{0x46b4fc3b,0x25780196,0xb40401c6,0x7ce801f4}},	//   _محاس, _wél_, гээж_, _hörä, 
   {{0x2579c01b,0x7ce80598,0x2bac012c,0xc21800d4}},	//   _tél_, _körä, _चिना, еєм_, 
   {{0x4ac52a27,0x7bc0054e,0xdb0c03b2,0x00000000}},	//   र्यव, ănui, ttaú, --, 
   {{0x7ce80724,0xdd1c00bc,0x38ac03e0,0x2d78013a}},	//   _mörä, bářs, mörü_, _včel_, 
   {{0xc2e4006c,0x38940201,0xdb1c0254,0x00000000}},	//   _бўйи, ቅስቃሴ_, _issö, --, 
   {{0x4ac400cd,0x743028f6,0x00000000,0x00000000}},	//   र्मव, _уніф, --, --, 
   {{0xdd9484dd,0x38ac03e0,0xa3dc09b2,0x00000000}},	//   рабы, nörü_, डिक_, --, 
   {{0xbcf800e8,0x98bc02b1,0x00000000,0x00000000}},	//   _niét, kowā_, --, --, 
   {{0xdfd40220,0x4ac400dc,0x00000000,0x00000000}},	// [316f0] _топы, र्भव, --, --, 
   {{0x301410de,0x7b6401d5,0x00000000,0x00000000}},	//   _ыдыр, утбе, --, --, 
   {{0x7ce80166,0x9875c01c,0x7f44014f,0x3e6801a9}},	//   _cörä, алец, mojq, _яшин_, 
   {{0xaa643624,0x7ce800ee,0xe77800e5,0x4df800df}},	//   стук, _dörä, گلوں_, _ספרא, 
   {{0xbcf9c01d,0x69d83774,0x2bac0892,0xab8426c7}},	//   _diét, æver, _चिया, _гуск, 
   {{0x7ce80628,0xd62844e4,0x945c068f,0x5478001f}},	//   _förä, коле_, zeńs, _በታላቅ_, 
   {{0xbcf8056a,0x140ca4ea,0x7ce8010b,0xaa580166}},	//   _chég, िन्ह_, _görä, _биру_, 
   {{0x1959c01e,0x7f440477,0xdd1c0118,0x53a400c7}},	//   _рабы_, hojq, tářs, ааиб, 
   {{0x92f428f6,0xd1b800d1,0x00000000,0x00000000}},	//   ачні, ھادا_, --, --, 
   {{0x130834d8,0x7ce80724,0xd1b9c01f,0xd7600244}},	//   тной_, _yörä, پادا_, _بۆتی, 
   {{0xdb0c0129,0x05941a90,0xd4f401f4,0x00000000}},	//   huaï, _نانگ, _вялы, --, 
   {{0x62581cd1,0x260400cf,0xd0080139,0x00000000}},	//   ырыр_, _учуг, веме_, --, 
   {{0x33840a70,0x4ac4257b,0xbcf80036,0xdfd8009d}},	//   _суев, र्डव, _liés, лъё_, 
   {{0x91e5c020,0xbb18054e,0x00000000,0x00000000}},	//   _воке, _stîn, --, --, 
   {{0x78b80384,0x693c4b16,0x0c9401d5,0x00000000}},	//   _ocuv, nčec, ишая, --, 
   {{0x4c85c021,0x6b500254,0x00000000,0x00000000}},	//   рлав, mägi, --, --, 
   {{0x998c3d67,0x6b515f4c,0x4b24f0c2,0x7ce80166}},	// [31700] _ćeš_, lägi, амав, _sörä, 
   {{0x8d7425cb,0x00000000,0x00000000,0x00000000}},	//   _پادا, --, --, --, 
   {{0xbcf9c022,0x6b5000c5,0x693c0427,0x7ce80139}},	//   _bhéd, nägi, jčec, _qörä, 
   {{0xbcf9c023,0x7d000311,0x8c4400f3,0x00000000}},	//   _diés, _însp, _веме, --, 
   {{0x26c998ec,0xbcf9c024,0x87b8023a,0xcb681541}},	//   лған_, _shég, тует_, _لمحه_, 
   {{0x38ac05d1,0xc985c025,0x7ce8010b,0xee6c00d1}},	//   törü_, _نشري, _törä, _ﻳﯜﻩﻥ_, 
   {{0xfaa13531,0xbcf9ae76,0x80d40490,0x4ac406ff}},	//   _фасо, _tiét, _बसले, र्णव, 
   {{0xbcf82d59,0xa4d80276,0x38ac0790,0xe3b80cb6}},	//   _hiér, удиу_, rörü_, глич_, 
   {{0x2fc001d4,0x68e00381,0x2905c026,0x4ac400dc}},	//   _nqig_, _iamd, _ioma_, र्थव, 
   {{0x68e1c027,0x2905c028,0x69dc00f3,0xa8080205}},	//   _hamd, _homa_, _ksre, rdıı, 
   {{0x2905c029,0x68e1c02a,0xbcf9c02b,0x6d5800ef}},	//   _koma_, _kamd, _miér, _īvan, 
   {{0x68e00393,0x2905c02c,0x4ac4085c,0xdb0c03b2}},	//   _jamd, _joma_, र्तव, staø, 
   {{0x2f1404f3,0x2905c02d,0xa3dcabac,0x741000db}},	//   _säga_, _moma_, डिओ_, _ووما, 
   {{0x2905c02e,0x68e1c02f,0x69dc151c,0xceb40166}},	//   _loma_, _lamd, _osre, бәю_, 
   {{0x93580063,0x5b1401ec,0x629800c0,0x41d800bc}},	//   _срцу_, ұмат, _ievo, _बनिस, 
   {{0x2905c030,0x2f14033d,0x5c750a1b,0x59180003}},	//   _noma_, _väga_, слат, ྱིབས_, 
   {{0x21281dd4,0x62980793,0x69dc0066,0x645c00ac}},	// [31710] _imah_, _kevo, _asre, əric, 
   {{0x29040810,0x2128020c,0x78b80c86,0x6298031c}},	//   _aoma_, _hmah_, _scuv, _jevo, 
   {{0x29041813,0x68e1c031,0xceb0008f,0x6298d32e}},	//   _boma_, _bamd, _ציט_, _mevo, 
   {{0x2905c032,0x68e1c033,0x3234008f,0x7c8400d8}},	//   _coma_, _camd, סטאן_, _њуне, 
   {{0x68e1c034,0xd7c85fc4,0xdb0dc035,0x69dc00a2}},	//   _damd, اوته_, quaï, _esre, 
   {{0x6299c036,0xc7a1c037,0x68e09207,0x2128003e}},	//   _nevo, чишк, _eamd, _lmah_, 
   {{0x29041140,0x2128034c,0xf969c038,0xaa4401a9}},	//   _foma_, _omah_, _арай_, _деёл, 
   {{0x2905c039,0x68e178df,0x81bc045e,0x69c829ef}},	//   _goma_, _gamd, ুটা_, _ädea, 
   {{0x46f0215c,0x527400cf,0x00000000,0x00000000}},	//   تۋەر, йуну, --, --, 
   {{0x2905c03a,0x2129c03b,0x62988841,0x6b500e78}},	//   _zoma_, _amah_, _cevo, tägi, 
   {{0x7c3800fc,0x395c0218,0x6299c03c,0x68e02aa4}},	//   _þurf, _khus_, _devo, _yamd, 
   {{0x395c0115,0x68e011f2,0x00000000,0x00000000}},	//   _jhus_, _xamd, --, --, 
   {{0x2128004e,0x62980327,0x2a9000b5,0x00000000}},	//   _dmah_, _fevo, _ｄb_, --, 
   {{0x6298400c,0x2129c03d,0xd3a401af,0x00000000}},	//   _gevo, _emah_, _кәүҙ_, --, 
   {{0xdb0c1e0b,0x798400d2,0x395c000d,0x00000000}},	//   guaí, _ntjw, _ohus_, --, 
   {{0x31a00baf,0x62980165,0x225801d3,0x2bac00dc}},	//   mız_, _zevo, ürke_, _चिदा, 
   {{0x68e1c03e,0xbcf80784,0x6299c03f,0x6abc003a}},	// [31720] _ramd, _piér, _yevo, _pcrf, 
   {{0x2905c040,0x68e1c041,0x395c00d4,0x00000000}},	//   _soma_, _samd, _ahus_, --, 
   {{0x31a02917,0x2905c042,0xbcf8020c,0x395c3e7c}},	//   nız_, _poma_, _dhéb, _bhus_, 
   {{0x29040286,0x395c0978,0x61fdc043,0x68e0016d}},	//   _qoma_, _chus_, ärli, _qamd, 
   {{0x68e0cc23,0xc79412c4,0x69dc01ab,0x2904054e}},	//   _vamd, ёрды, _wsre, _voma_, 
   {{0x2905c044,0x68e120e6,0x31a00790,0x69dc0332}},	//   _woma_, _wamd, kız_, _tsre, 
   {{0x69dc071b,0x68e1c045,0x2be008a3,0x316001c4}},	//   _usre, _tamd, निका, _ohiz_, 
   {{0x6298014a,0x395dc046,0x31a00b97,0x00000000}},	//   _sevo, _ghus_, dız_, --, 
   {{0x629801b8,0x81bc0154,0xdce4002b,0x97bc12fa}},	//   _pevo, ুয়া_, _sthī, _архi, 
   {{0xfc3c04d4,0xaad800c5,0x31a00790,0x00000000}},	//   _odín_, ड़िक, fız_, --, 
   {{0x60f9c047,0x62980489,0x2259c048,0x31a00724}},	//   ання_, _vevo, рины_, gız_, 
   {{0x62980b6f,0xbcf80165,0x29e80139,0x0564aa52}},	//   _wevo, _niép, _mğa_, _увен, 
   {{0x6299c049,0x855443fb,0x09b00327,0xaad807f7}},	//   _tevo, _پیکر_, _དའྀ_, ड़ाक, 
   {{0x31a00598,0x98bc033f,0x00000000,0x00000000}},	//   bız_, mową_, --, --, 
   {{0x98bc033f,0x6b500037,0xdb0c010b,0x00000000}},	//   lową_, nägu, gtaý, --, 
   {{0x2129c04a,0x316004cc,0x5d542626,0xbcf801e1}},	//   _umah_, _ghiz_, ікат, _shéb, 
   {{0x2d584834,0x60ccb07e,0x395dc04b,0x29e80add}},	// [31730] сить_, _ibam, _rhus_, _ağa_, 
   {{0x395c0093,0xceb43d48,0xdea01fe4,0x00000000}},	//   _shus_, _мәс_, _زیری, --, 
   {{0x395c0218,0xbcf8003e,0x99d42051,0xc3000154}},	//   _phus_, _chéc, تقات, এসপি_, 
   {{0x26ccc473,0x98bc033f,0x00000000,0x00000000}},	//   _abdo_, kową_, --, --, 
   {{0x60cdc04c,0x26cc0789,0x69c80793,0xdb1c00b5}},	//   _mbam, _bbdo_, _äden, _opsø, 
   {{0x31a00259,0x98bc033f,0x00000000,0x00000000}},	//   yız_, dową_, --, --, 
   {{0xe6c40f1b,0x395dc04d,0xda640451,0x693dc04e}},	//   ستوي, _thus_, _گاڏي, mčen, 
   {{0x693c19d6,0x00000000,0x00000000,0x00000000}},	//   lčen, --, --, --, 
   {{0x4ac4194b,0x98bc012d,0x6378009d,0x00000000}},	//   र्वव, gową_, йсэр_, --, 
   {{0x60cc3182,0x693c4ea1,0xf1c00316,0x316005be}},	//   _abam, nčen, _naší_, _shiz_, 
   {{0x60cc04ba,0x2f140793,0xb5a400f7,0xf0480092}},	//   _bbam, _sägo_, _ырай, _ማስመዝ, 
   {{0x31a06648,0x77780548,0x693c02fb,0xfbdc035b}},	//   rız_, _kuux, hčen, _osê_, 
   {{0x31a04952,0x50581220,0x75280175,0x693c02f0}},	//   sız_, ршня_, _imgz, kčen, 
   {{0xe3b0ab88,0x693c2195,0x77780a55,0x60cdc04f}},	//   _سره_, jčen, _muux, _ebam, 
   {{0x693c0122,0x7778208d,0x2bac302b,0xa2b81bd6}},	//   dčen, _luux, _चिहा, ्भर्, 
   {{0x2d780e3c,0x60cc0241,0xdc980408,0xe81c0118}},	//   _očev_, _gbam, йтуш_, बईमा_, 
   {{0x8e75c050,0x77780014,0xc4d002e4,0xb3700092}},	// [31740] _мунч, _nuux, וגן_, _ከነዓን_, 
   {{0x4a240135,0xfc3c00db,0x00000000,0x00000000}},	//   _རྟུལ_, _idíl_, --, --, 
   {{0xfaa00c60,0x98bc012d,0x00000000,0x00000000}},	//   фахо, zową_, --, --, 
   {{0x7778cd24,0x7c380010,0x92d40154,0x7bc00356}},	//   _buux, _žure, হায়_, ănur, 
   {{0x2ca1c051,0x6b500e78,0x693c7edf,0x00000000}},	//   maid_, wägu, bčen, --, 
   {{0x2ca1c052,0x46f402e8,0x9f5800e4,0x4dfc0037}},	//   laid_, ючет, kysý_, _उपाई_, 
   {{0x98bc012d,0x00000000,0x00000000,0x00000000}},	//   wową_, --, --, --, 
   {{0x2ca131dd,0x4ac4068f,0x6b51c053,0x98bc0034}},	//   naid_, र्रव, rägu, tową_, 
   {{0x2be00490,0x7778292a,0x2ca00142,0x00000000}},	//   निटा, _guux, iaid_, --, 
   {{0xbcf80597,0x2ca00649,0xdb0c0077,0x98bc033f}},	//   _mhéa, haid_, traé, rową_, 
   {{0x2ca1bb42,0x6b505b00,0x98bc033f,0xfeb84e10}},	//   kaid_, lägs, sową_, یاست_, 
   {{0x645c11a9,0x2ca0007d,0x77781bce,0x21380076}},	//   ərin, jaid_, _yuux, unsh_, 
   {{0xc058005e,0x7778208d,0x2ca096b2,0x7ee5b7f5}},	//   рін_, _xuux, daid_, оцве, 
   {{0x741016cb,0xdb0c07dd,0x00000000,0x00000000}},	//   _توها, kuaá, --, --, 
   {{0xf1c0012c,0xdb0c004a,0x693c3883,0x2ca00368}},	//   _vaší_, fraî, včen, faid_, 
   {{0xbcf80597,0xcc8c1c5c,0x2ca1c054,0x00000000}},	//   _bhéa, _ﺑﯩﺮﮔ, gaid_, --, 
   {{0xbcf80491,0x9324105d,0x7c3807f5,0x693c00bc}},	// [31750] _chéa, _برۆن, _žurb, tčen, 
   {{0xbcf806d5,0x777801d9,0x2bad1f14,0x693c0f5f}},	//   _dhéa, _ruux, _चिरा, učen, 
   {{0x77783d3d,0x2ca00e89,0x69c80267,0x00000000}},	//   _suux, baid_, _ädel, --, 
   {{0xbcf80491,0x2ca1c055,0x00000000,0x00000000}},	//   _fhéa, caid_, --, --, 
   {{0xbcf8007b,0x9654001f,0x693c0419,0x00000000}},	//   _ghéa, _ምንጮቻ, pčen, --, 
   {{0xe7086073,0xdcb0005e,0xe76806f6,0xa8a4cffe}},	//   قتىن_, _تىڭ_, يحون_, прәк, 
   {{0x7778058a,0xc8f800cc,0xda0801e2,0x00000000}},	//   _wuux, _আতৰত_, _ايزه_, --, 
   {{0xd4d810f5,0xa4905fc4,0x2e3c008f,0xdb0c02d1}},	//   ські_, پیوت, יגונ, mtañ, 
   {{0x66180cf4,0xdb0c0113,0x00000000,0x00000000}},	//   _čakš, ltañ, --, --, 
   {{0x6b500267,0x00000000,0x00000000,0x00000000}},	//   lägr, --, --, --, 
   {{0xdb0dc056,0x0674008f,0x2ca1bba6,0x00000000}},	//   ntañ, _זײער_, yaid_, --, 
   {{0xdb0c32e2,0x24840077,0xaee0037e,0x2ca004cc}},	//   kraï, ccmm_, _mm幅l, xaid_, 
   {{0x2ca0033d,0xd010aaab,0xa0740124,0x24580024}},	//   vaid_, رلس_, дырш, _даць_, 
   {{0xdb0d4a3d,0x2ca00042,0x693c00d7,0xa8080139}},	//   ktañ, waid_, ečel, ldıñ, 
   {{0xdb0dc057,0xbcf800c6,0x80d40011,0x2ca000e5}},	//   traî, _shéa, ধাজ্, taid_, 
   {{0x75380395,0xbcf8e2dc,0x00000000,0x00000000}},	//   nnuz, _phéa, --, --, 
   {{0xdb0c2024,0x4aa80137,0x2ca1c058,0x0c25c059}},	// [31760] graï, йкан_, raid_, чман, 
   {{0x2ca1c05a,0x6b50049f,0x7c382a4f,0xa7740150}},	//   said_, vägs, _žurc, _ﺸﺎﺫﺓ_, 
   {{0x49c80b96,0x7e78011a,0xdb0c0356,0x00000000}},	//   слен_, _לאיז, praî, --, 
   {{0xbcf9c05b,0xdb0c0129,0x10400092,0xff5c0142}},	//   _théa, braï, _የሕትመ, ntîn_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc5b4081f,0x6b50002f,0x00000000,0x00000000}},	//   _དཀྱི, rägs, --, --, 
   {{0xc1d81533,0x093400db,0x00000000,0x00000000}},	//   _बनेग, _فىسح, --, --, 
   {{0xbcf80113,0x75380ffb,0x363000c6,0xc4c40133}},	//   _lhén, gnuz, عروس, ستبو, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x645c0cc1,0xdb0c09f3,0x98bc0034,0x59e000bc}},	//   əril, ntað, dowę_, फिचर, 
   {{0xc5b40135,0x60980451,0x96740064,0x00000000}},	//   _དཀྲི, يندس_, _жыці, --, 
   {{0xbcf8b519,0x0564040e,0x3a340375,0x7ae800e2}},	//   _ahén, _эвен, לרים_, ēgti, 
   {{0xf484208f,0xdb0cca5d,0x2d780010,0x1e680116}},	//   _رانی, ktað, _očes_, ﺰﺩﻩﺵ_, 
   {{0xbcf80124,0xdb0c02d1,0x61fc007c,0x00000000}},	//   _chén, ytañ, ärls, --, 
   {{0xbcf87245,0x00000000,0x00000000,0x00000000}},	//   _dhén, --, --, --, 
   {{0xdb0c1497,0xb238011a,0x8d1801f0,0xe8581ef7}},	//   traï, _לעוז, онсӣ_, ግስትነ, 
   {{0xdb0dc05c,0x4bc000f7,0x6b50007c,0x00000000}},	// [31770] nuaç, көрг, vägr, --, 
   {{0xdb0dc05d,0x80b010a8,0x1a6401b9,0xde5800d4}},	//   ttañ, _تەڭش, ِیسی_, _мапі_, 
   {{0xceb01a4c,0x99d8027a,0x75383361,0x3ea00240}},	//   _ביי_, تواء_, ynuz, majt_, 
   {{0xdb0c14c8,0xa3ac0490,0x693c0010,0x81d400cc}},	//   rtañ, गळा_, lčej, সিপ_, 
   {{0xdb0dc05e,0xa87800c6,0xe7a80212,0x00000000}},	//   stañ, أحمر_, звіл_, --, 
   {{0x3ea1c05f,0xdb0dc060,0x9aa401ed,0x572400db}},	//   najt_, duaç, _زمرو, بىتك, 
   {{0x2d79c061,0xdb0dc062,0xd05406be,0x154479ea}},	//   _kōea_, nraí, _dayə, мекм, 
   {{0x7ae5c063,0x753804ba,0x70dc00c5,0x84740092}},	//   _hajt, unuz, _बसेल, _የኢራን_, 
   {{0x7ae5c064,0xdb0dc065,0xddc400bc,0x753804cc}},	//   _kajt, hraí, _vyhř, rnuz, 
   {{0x394dc066,0x81d40011,0x3ea010f2,0x27e003e0}},	//   logs_, সিন_, jajt_, çine_, 
   {{0x7ae5c067,0x645c03be,0x6d4006c8,0x6595039b}},	//   _majt, ərim, ōmai, _заху, 
   {{0x7ae5c068,0x8fa5c069,0xdb0c0162,0x00000000}},	//   _lajt, маме, draí, --, 
   {{0xe7f0069f,0xbcf820ef,0xdb0dc06a,0x93600022}},	//   चिया_, _phén, cuaç, _иҽиҵ, 
   {{0x394c01b8,0x3ea0f73a,0xdb0c01e7,0xf36401af}},	//   hogs_, gajt_, fraí, _этен, 
   {{0xdb0c0491,0x9f4801e7,0x394c007c,0x00000000}},	//   graí, _graí_, kogs_, --, 
   {{0x2f1400c5,0x61fc00cc,0x7c39c06b,0xaae403e6}},	//   _mägi_, årle, _žura, کترۆ, 
   {{0x394cbea3,0xdb0dad50,0xbcf8067c,0x904400ec}},	// [31780] dogs_, ttað, _thén, _زنده, 
   {{0x7ae40427,0x3ea00f91,0xdb0c0332,0x00000000}},	//   _cajt, cajt_, braí, --, 
   {{0x7ae439ab,0x2f1400c5,0xdb0dc06c,0x4d643acc}},	//   _dajt, _nägi_, craí, _оков, 
   {{0xdb0c1bb0,0x693c0030,0xd05400ac,0x5dd402dd}},	//   stað, mček, _sayə, _ﺘﺴﻠﻴ, 
   {{0x87d9c06d,0xcb6892ec,0x7ae5c06e,0x693c00d0}},	//   تباس_, _маме_, _fajt, lček, 
   {{0x7ae40200,0xd05403b9,0xc5880395,0x00000000}},	//   _gajt, _qayə, ощие_, --, 
   {{0x6b853136,0x693c0030,0x161401ad,0x36280092}},	//   lqig, nček, तनगर_, _እንገኛ, 
   {{0xdb0c03b7,0x7ae4955b,0x3ea00023,0x00000000}},	//   tuaç, _zajt, zajt_, --, 
   {{0x693c00bc,0xc300015b,0x7ae46b0b,0x00000000}},	//   yčej, এসসি_, _yajt, --, 
   {{0xb4a801a8,0x00000000,0x00000000,0x00000000}},	//   íþró, --, --, --, 
   {{0xe134876e,0x27e40113,0x26dc011c,0x81d4015b}},	//   енны, _hsmn_, mevo_, সিভ_, 
   {{0x26ddc06f,0xbcf80129,0xdb0c0798,0x3ea0031c}},	//   levo_, _chél, puaç, wajt_, 
   {{0xdb0c0120,0xcf8dc070,0x3ea19e14,0x00000000}},	//   quaç, یژی_, tajt_, --, 
   {{0x26ddc071,0xdb0c27b9,0x81d40154,0xd89007d2}},	//   nevo_, traí, সিব_, _ﺟﯩﻠﯟ, 
   {{0x7ae5c072,0x3ea1c073,0x9f480589,0x84f00073}},	//   _rajt, rajt_, _araã_, _अफाट_, 
   {{0x7ae5c074,0x3ea1c075,0xdb0dc076,0x6b84025c}},	//   _sajt, sajt_, rraí, fqig, 
   {{0x3f65c077,0x60dcbc15,0x7ae5c078,0x66e800b0}},	// [31790] _отоб, mesm, _pajt, _kūkē, 
   {{0x60ddc079,0x26dc506e,0xbcf9c07a,0x7ae4036e}},	//   lesm, jevo_, _théo, _qajt, 
   {{0x7ae5c07b,0x26ddc07c,0x6b84013c,0x394c0267}},	//   _vajt, devo_, aqig, togs_, 
   {{0x60ddc07d,0x25f428d4,0x7ae40113,0xaa6400f7}},	//   nesm, ्मनी_, _wajt, ттук, 
   {{0x7ae5c07e,0x394dc07f,0x00000000,0x00000000}},	//   _tajt, rogs_, --, --, 
   {{0x2b001d8a,0x2c840241,0x00000000,0x00000000}},	//   राणु_, _tédó_, --, --, 
   {{0x62880407,0xaa58003b,0x00000000,0x00000000}},	//   dcdo, _жиру_, --, --, 
   {{0x60dc7566,0xfba06f64,0x2f14000d,0x5dd40150}},	//   jesm, _ओबाम, _vägi_, _ﺘﺴﻤﻴ, 
   {{0x6d5800e4,0x60ddc080,0x4ac42a67,0x00000000}},	//   _êvae, desm, र्कव, --, 
   {{0x26ddc081,0x60dc0037,0xe738009b,0x7f680116}},	//   cevo_, eesm, _жеђ_, _ﺳﻮﯞﯦ, 
   {{0xbcf800d2,0x6b84022e,0x00000000,0x00000000}},	//   _phél, zqig, --, --, 
   {{0x60ddc082,0x9f480241,0x63ac0ba1,0x693c0419}},	//   gesm, _araà_, èlnò, vček, 
   {{0x7c39c083,0xbcf80030,0xd388010b,0xb91401e1}},	//   _žurn, _chém, _эйле_, _ńgọ_, 
   {{0xfd1c08e5,0xbcf80066,0xe7f192ae,0x83b4011a}},	//   _alì_, _dhém, चिता_, _נפצע_, 
   {{0x60dc08c8,0x5238008f,0xbcf86ede,0xbf6001c8}},	//   besm, _מײַנ, _thél, دگيو, 
   {{0x693c01a2,0x60dc6548,0xe8e0063f,0x26dc03d1}},	//   rček, cesm, raịt_, zevo_, 
   {{0x5d740064,0xeb5400d1,0x5ed400eb,0x00000000}},	// [317a0] турф, نىرگ, দয়ে, --, 
   {{0x26dc02c4,0x693c00d0,0x6b842ca7,0x00000000}},	//   xevo_, pček, rqig, --, 
   {{0x26dd5350,0x4ac401bc,0x6b840009,0x2bac62a8}},	//   vevo_, र्गव, sqig, _चिका, 
   {{0xc7c4722e,0xb9900101,0xc7a400c7,0xfe340a7c}},	//   ески, النب, еидк, _טריי_, 
   {{0x26ddc084,0x276803e6,0x6b85c085,0x41a4012d}},	//   tevo_, وشتی_, qqig, _कौनस, 
   {{0x8d9c001f,0x6675c086,0x60ddc087,0xc76400f7}},	//   _ገብተው_, نگار, zesm, راشى, 
   {{0x26ddc088,0x60dc01d3,0xd90c01d3,0xbb41c089}},	//   revo_, yesm, _ڈیل_, _серк, 
   {{0xd90c00aa,0x26dc05be,0x3564010e,0x63881086}},	//   _ویل_, sevo_, нрын_, мроҳ_, 
   {{0x26dc00a7,0xbcf800d2,0x60ddc08a,0x66e800b0}},	//   pevo_, _bhéj, vesm, _pūkē, 
   {{0x6d1c0316,0x2f140037,0x60dc0036,0xdee00b82}},	//   नसँग_, _kägu_, wesm, ነታን_, 
   {{0x75d0819a,0x2258019b,0x60ddc08b,0x7d080267}},	//   _ميلا, ærk_, tesm, ögsk, 
   {{0x53800022,0x00000000,0x00000000,0x00000000}},	//   ықәз, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x60ddc08c,0x00000000,0x00000000,0x00000000}},	//   sesm, --, --, --, 
   {{0x2f1400c5,0xba9402dd,0x6d1c0118,0x00000000}},	//   _nägu_, _ﺟﯘﻟﮕ, नसंग_, --, 
   {{0xbcf820ef,0x5ff40124,0x2d8c1dec,0x60dc014f}},	//   _thém, _азиу, ídea_, qesm, 
   {{0x7ff400c6,0x5c75c08d,0x00000000,0x00000000}},	// [317b0] _أسعا, тлат, --, --, 
   {{0x79a55b30,0xdb240133,0x2b1400d4,0x00000000}},	//   ерде, کوڕی, льєр, --, 
   {{0xdd943f6e,0x6ab803b2,0x00000000,0x00000000}},	//   _шаны, óvfa, --, --, 
   {{0xa3e01b76,0x00000000,0x00000000,0x00000000}},	//   दबा_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7d0c0051,0xdb0c0254,0x00000000,0x00000000}},	//   _hocs, ttaõ, --, --, 
   {{0xba7410fe,0x7d0c01ed,0x66180030,0xa6a801d5}},	//   _ساست, _kocs, _čaká, راوق_, 
   {{0x7d0dc08e,0xd7f4005b,0xa3ac0073,0x00000000}},	//   _jocs, _избы, गळं_, --, 
   {{0x25a005ce,0x7d0c01d3,0xe5040228,0xdb0c0254}},	//   ćila_, _mocs, ابىي, staõ, 
   {{0x7d0dc08f,0x00000000,0x00000000,0x00000000}},	//   _locs, --, --, --, 
   {{0xbcf80022,0x6fa400af,0x4ac425c9,0xe69400fb}},	//   _chék, _कबहू, र्टव, _сихы, 
   {{0xbcf800f2,0x61fc0158,0x05940066,0x00000000}},	//   _dhék, årla, _شامگ, --, 
   {{0xde3c001f,0x00000000,0x00000000,0x00000000}},	//   _የትኛው, --, --, --, 
   {{0x387c01a9,0xd1b8516c,0xa3b8e3a3,0x00000000}},	//   _lgur_, _قابا_, _ساهر_, --, 
   {{0x7d0dc090,0x693c28b5,0x387dc091,0x00000000}},	//   _bocs, mčev, _ogur_, --, 
   {{0x693c1a48,0x387cb59b,0x25f40254,0xb9380092}},	//   lčev, _ngur_, ्मती_, ራማሪዎ, 
   {{0x0ae81411,0xfb84141b,0xfce000db,0x3b80009d}},	// [317c0] мдай_, ندلی, шото, илтг, 
   {{0x693c2aac,0x387c01c0,0x27f80219,0x2568002d}},	//   nčev, _agur_, _črn_, mûle_, 
   {{0x7d0dc092,0x99f402bf,0x8d742e0b,0xf9800107}},	//   _focs, ляці, _لاحا, агхо, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x693c00f3,0x00000000,0x00000000,0x00000000}},	//   kčev, --, --, --, 
   {{0x387c009d,0x693c0010,0xf76c00f1,0x00000000}},	//   _egur_, jčev, ياو_, --, 
   {{0x19b802f6,0x75a0010b,0xb5c40244,0x50d0090a}},	//   _путь_, ашыж, نووم_, तभाष, 
   {{0x291c005f,0x2568000f,0xe8740014,0x07080451}},	//   īvas_, kûle_, _منزگ, _ڪيئي_, 
   {{0x684401af,0x00000000,0x00000000,0x00000000}},	//   _смаҡ, --, --, --, 
   {{0x81d40eac,0x387c0135,0x6d58032e,0x00000000}},	//   সিস_, _zgur_, _ívaf, --, 
   {{0xaad4089a,0x7ab8011a,0x00000000,0x00000000}},	//   ठ्यक, וציו, --, --, 
   {{0xf4807de7,0x6738031c,0x00000000,0x00000000}},	//   _кушн, livj, --, --, 
   {{0x69c402ab,0x69c80fac,0x7d0c0356,0x693c0427}},	//   ांडी, _ådef, _rocs, bčev, 
   {{0x7d0c009f,0x72000133,0x00000000,0x00000000}},	//   _socs, _چووم, --, --, 
   {{0x661801d3,0x7d0c00e5,0x00000000,0x00000000}},	//   nyvk, _pocs, --, --, 
   {{0x256800d2,0xdb2003ee,0x5274010b,0x00000000}},	//   bûle_, ştür, _сучу, --, 
   {{0x2d58169c,0x2139c093,0x6738003d,0xdcec0327}},	// [317d0] тить_, mish_, kivj, lmaċ, 
   {{0xdd1000da,0xbcf800c6,0x2b5801f7,0x2139c094}},	//   _kļūd, _mhéi, _ckrc_, lish_, 
   {{0x9f480365,0x98b9c095,0x7d0dc096,0x6d4001a6}},	//   _araç_, елет_, _tocs, čmar, 
   {{0x9f4856ed,0x2139c094,0x00000000,0x00000000}},	//   _braç_, nish_, --, --, 
   {{0x8ca00150,0x37a8014b,0x00000000,0x00000000}},	//   _دەقو, фтен_, --, --, 
   {{0x2139c097,0xdb0c0798,0xbcf80129,0xcc7402e4}},	//   hish_, draç, _shéh, _תעשה_, 
   {{0x2139c098,0x693c1a48,0xaa5c01ec,0x00000000}},	//   kish_, včev, _жерi, --, 
   {{0x13e8170a,0x387c00ee,0xdb0c0120,0xbcf8007b}},	//   емий_, _ugur_, fraç, _bhéi, 
   {{0xbcf80491,0xdb0c0261,0x9f480589,0xb400c4f3}},	//   _chéi, graç, _kraä_, рүлд, 
   {{0x20181672,0x693c5946,0x2139c099,0xe78400db}},	//   dysi_, učev, eish_, _ئللپ, 
   {{0xc69004ac,0x2139c09a,0x10a5c09b,0x693c0f03}},	//   _האב_, fish_, линн, rčev, 
   {{0xbcf80597,0x0d849098,0xdb0c06ed,0x237c0109}},	//   _fhéi, ғлан, braç, _eivj_, 
   {{0xb4dc2ba2,0x693c0427,0x257007d2,0xbcf8007b}},	//   दजी_, pčev, _بۇيس, _ghéi, 
   {{0x2d8c021c,0x213800ad,0xe3b10404,0x00000000}},	//   ídeo_, aish_, _ذره_, --, 
   {{0x2138062c,0x2f1401e6,0x1cdc025c,0x04e40183}},	//   bish_, _sägs_, _ལྒང_, কাৰৰ_, 
   {{0x67381e31,0x693c0b9b,0x90342f84,0x21744990}},	//   zivj, nčet, _مرخص, _куыр, 
   {{0x0b45c09c,0xc0c00023,0x00000000,0x00000000}},	// [317e0] гнан, ድኦም_, --, --, 
   {{0x81d400bd,0xaca40241,0x2f1401e3,0x409004f2}},	//   সির_, _ikọs, _vägs_, _پلیر, 
   {{0x09f48fd9,0x00000000,0x00000000,0x00000000}},	//   ычая, --, --, --, 
   {{0x63a5140d,0x2b9401b9,0x67380477,0x69c00055}},	//   _çing, _نیرس, wivj, _āmed, 
   {{0x6d45c09d,0x693c0427,0x67380455,0x690c00a2}},	//   mnia, dčet, tivj, _ỳesi, 
   {{0x6d452a40,0x21389682,0xfc3c0005,0x28e0012c}},	//   lnia, zish_, _edís_, _नसकि, 
   {{0x25a008ad,0x2139c09e,0x6d45a344,0xfa64d90f}},	//   ćilo_, yish_, onia, _барк_, 
   {{0x6d4432ff,0xbcf89eec,0xdb0c06ed,0x9f4800db}},	//   nnia, _dhéw, traç, _traç_, 
   {{0x2139c09f,0xd90c066d,0x6d45c0a0,0xdb0c0120}},	//   vish_, _تین_, inia, uraç, 
   {{0x6d45c0a1,0x7c39c0a2,0xdb0c06ed,0x254c012c}},	//   hnia, _žurk, rraç, děle_, 
   {{0x2d989358,0xaca40248,0x2139c0a3,0x2d8c0216}},	//   jpre_, _akọs, tish_, ídel_, 
   {{0x6d440070,0x69ddc0a4,0x03a41c89,0xfc3c0407}},	//   jnia, _mpre, _бидо, _leía_, 
   {{0x2139c094,0x6d44489d,0x00000000,0x00000000}},	//   rish_, dnia, --, --, 
   {{0x69ddc0a5,0xa2940953,0x6d45c0a6,0x656000c6}},	//   _opre, _такі, enia, llmh, 
   {{0x693dc0a7,0x2139c0a8,0x6d4400a9,0x656000c6}},	//   nčes, pish_, fnia, olmh, 
   {{0x6d45c0a9,0x213807d6,0xb634010f,0x7c38032e}},	//   gnia, qish_, ארלס_, _þurk, 
   {{0x81c4015b,0x63a400ac,0x6d48065c,0x656000a3}},	// [317f0] _উনি_, _çind, édaa, ilmh, 
   {{0x61f807f5,0x6d45c0aa,0x69dc01e7,0x7a480166}},	//   _krvl, ania, _bpre, няев_, 
   {{0x6d45c0ab,0xdcecb95b,0x13c0194b,0x5a3400d8}},	//   bnia, lmač, _शम्भ, јнет, 
   {{0x6d440034,0x1c38013d,0xdb0c007c,0x690c0432}},	//   cnia, _азмы_, draå, _ỳeri, 
   {{0x69dc0c8c,0xac1802dd,0xdb0c005b,0xe6b400d1}},	//   _epre, _бояу_, traä, ڭلىگ, 
   {{0xbcf8035b,0x69dc0175,0x00000000,0x00000000}},	//   _chév, _fpre, --, --, 
   {{0xbcf8003e,0x693c0cf4,0x00000000,0x00000000}},	//   _dhév, tčet, --, --, 
   {{0x95740137,0xd5740064,0xdcec0064,0x00000000}},	//   шылч, шуль, kmač, --, 
   {{0x7984047e,0x693c00f3,0x5634001f,0x76c42e0b}},	//   _hujw, rčet, _እንዲሠ, _مغال, 
   {{0x6d45c0ac,0x7984da30,0x69ddc0ad,0xdcfc010f}},	//   znia, _kujw, _ypre, _disĉ, 
   {{0x69dc00c6,0x6d440cfd,0xa5240137,0x63a40327}},	//   _xpre, ynia, рмөд, _ħine, 
   {{0x61f80e3c,0x81d400bd,0x545402d5,0x78a95e99}},	//   _drvl, সিং_, _квет, nagv, 
   {{0x53a44154,0x6d45c0ae,0x61f9c0af,0x79840455}},	//   _талб, vnia, _ervl, _lujw, 
   {{0x78a80d04,0x6d45c0b0,0x0874008f,0x7538a850}},	//   hagv, wnia, יערט_, liuz, 
   {{0xfc3c0789,0x79840455,0x3da523a6,0xb1480214}},	//   _reía_, _nujw, икро_, _میدم_, 
   {{0x6d45c0b1,0x2d9900f2,0x7538009f,0x69c407f7}},	//   unia, rpre_, niuz, ांसी, 
  
   {{0x69ddc0b2,0x2d99c0b3,0x6d45c0b4,0x645c00ac}},	// [31800] _spre, spre_, rnia, əris, 
   {{0x950408ea,0x69ddc0b5,0x80a800fe,0x2d9800b5}},	//   _མོའི_, _ppre, _কায্, ppre_, 
   {{0x09e42e3f,0x69dc0998,0xfc3c09d7,0x88849205}},	//   роен, _qpre, _veía_, алеж, 
   {{0x75380451,0x29012e21,0x2abc0241,0x7984047e}},	//   jiuz, ñia_, _bábà_, _dujw, 
   {{0x80a80eac,0x7538022e,0x38c800f2,0x8704004e}},	//   _কাম্, diuz, ضانی_, ияке, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69ddc0b6,0x79841418,0x693c01fa,0x7538056a}},	//   _upre, _gujw, učes, fiuz, 
   {{0x7c3808ad,0x75380369,0x29e803e3,0x00000000}},	//   _žuri, giuz, _işa_, --, 
   {{0x430402bf,0xbcf80129,0xf3f401e1,0x46e801a9}},	//   аїна, _thév, _ọ̀la_, _идан_, 
   {{0xc32c10a8,0xc5d400d4,0x00000000,0x00000000}},	//   بەت_, _відь, --, --, 
   {{0xf1ac05d9,0x31c00395,0xd90c0244,0x00000000}},	//   وءَ_, осяв, _تیۆ_, --, 
   {{0x256800d2,0x00000000,0x00000000,0x00000000}},	//   bûla_, --, --, --, 
   {{0x629c0205,0x00000000,0x00000000,0x00000000}},	//   ırob, --, --, --, 
   {{0xdcec0232,0x6d49a875,0x78a801f5,0x00000000}},	//   rmač, édan, zagv, --, 
   {{0x26cd1746,0xdd94a3f7,0xdb0c0588,0xdcec0010}},	//   _mcdo_, сабы, guaý, smač, 
   {{0xbd681c3e,0xdd940220,0x645c0213,0x00000000}},	//   трге_, _қамы, ərir, --, 
   {{0x29e9c0b7,0x60cdc0b8,0x78a80cfe,0xfa840063}},	// [31810] _aşa_, _icam, vagv, аћем, 
   {{0xd044016b,0x7984047e,0xf8ec0cb4,0x753801f7}},	//   rekɔ, _pujw, _घोड़ा_, ziuz, 
   {{0x79840978,0x693c0010,0x2abc0248,0x78a8002f}},	//   _qujw, včer, _sábà_, tagv, 
   {{0xc30004c5,0xbcf80129,0x59c80073,0xc6e401d9}},	//   এসটি_, _chét, ांबर, ۅتى۪, 
   {{0x60cc0b6f,0x78a8c9d7,0x80cc1a22,0x693c00f3}},	//   _mcam, ragv, _थाने, tčer, 
   {{0x798400fb,0xfbdc0798,0x78a8017a,0xc6e40014}},	//   _tujw, _ipê_, sagv, متى۪, 
   {{0x60cdc0b9,0x75380bd7,0xc68c1b45,0x2d680e78}},	//   _ocam, tiuz, رِي_, ißen_, 
   {{0x60cdc0ba,0x5468001b,0x2abc0241,0x00000000}},	//   _ncam, лайм_, _tábà_, --, 
   {{0xc9501203,0x7c380510,0x75380369,0xbcf801e1}},	//   _זמן_, _ýurd, riuz, _ikéd, 
   {{0x60cdad5c,0xe78413dc,0x2d8c0118,0x00000000}},	//   _acam, _футо, ídek_, --, 
   {{0xd1741885,0x0594030f,0x6594014b,0xd37800cf}},	//   йымы, _هانگ, _даху, кчү_, 
   {{0x2d680639,0x60cc0327,0xd0080139,0xf8a407f7}},	//   eßen_, _ccam, геме_, खरिय, 
   {{0x60cc0204,0x00000000,0x00000000,0x00000000}},	//   _dcam, --, --, --, 
   {{0x80a802a6,0x60cdc0bb,0x254c00bc,0x73c001af}},	//   _কাণ্, _ecam, měla_, _ләүе, 
   {{0xa6380201,0xfbdc0798,0xf1d8d9e5,0x00000000}},	//   _እንደተ, _apê_, _बहिन, --, 
   {{0x4c840b74,0x61fccae2,0x60cc00ae,0xdb0c00e4}},	//   слав, ærle, _gcam, kuaó, 
   {{0xb1480214,0xbcf806af,0x3b80010b,0x00000000}},	// [31820] _میگم_, _rhét, злуг, --, 
   {{0xf1d81df1,0xace863eb,0x3f8c00d8,0x7c2800a3}},	//   _बहान, ымға_, _égua_, ùgra, 
   {{0xddb8014b,0x00000000,0x00000000,0x00000000}},	//   _куяш_, --, --, --, 
   {{0xbcf806c2,0x2bc801ad,0x00000000,0x00000000}},	//   _dhés, िंदा, --, --, 
   {{0xaab82e2e,0x2ca000c5,0xef380023,0xe738035b}},	//   _نگار_, mbid_, _ኣእዳው, аҵа_, 
   {{0x254c012c,0x61e80175,0x2ca0000d,0x36840395}},	//   děla_, ywdl, lbid_, бсън_, 
   {{0xbcf80998,0x29e80311,0x2ca1c0bc,0x41a40210}},	//   _thét, _uşa_, obid_, _कौंस, 
   {{0x2ca005e4,0xfbdc00d8,0x00000000,0x00000000}},	//   nbid_, _ypê_, --, --, 
   {{0x2904d689,0xd36c0075,0xa638001f,0x442001ed}},	//   _inma_, چۇن_, _እንዲተ, ák_, 
   {{0xd36c2dc3,0xaaa84728,0x26c82be7,0xdee402d3}},	//   نۇن_, गरिक, _خطری_, ምትን_, 
   {{0xd5b810f5,0xe7f0f3e4,0x96940114,0x00000000}},	//   _всі_, चिका_, _фруш, --, 
   {{0x59c8bdfc,0xa159c0bd,0xdfd002eb,0x6d480077}},	//   ांतर, раму_, ويج_, édal, 
   {{0x2ca0c6f7,0x00000000,0x00000000,0x00000000}},	//   dbid_, --, --, --, 
   {{0x6e95c0be,0xa638044e,0x2d6803fa,0x5ea401b9}},	//   зиру, _እንዳተ, ußen_, تمسل, 
   {{0x9cf43981,0xddc40118,0xaacc00bc,0xceb400c7}},	//   озві, _vzhů, ालनक, цәы_, 
   {{0x60cc0921,0xbcf9c0bf,0x5c9808e2,0xdedc0023}},	//   _ucam, _ahér, ркая_, _ሕጂኸ_, 
   {{0x672800e5,0x00000000,0x00000000,0x00000000}},	// [31830] _oldj, --, --, --, 
   {{0xbcf9c0c0,0x9f480109,0x2905c0c1,0x2ca1c0c2}},	//   _chér, _isaï_, _anma_, abid_, 
   {{0x81d400bd,0x21280156,0x2ca1c0c3,0x00000000}},	//   সিক_, _klah_, bbid_, --, 
   {{0x2ca00408,0x6728002d,0x7c3800c0,0x00000000}},	//   cbid_, _aldj, _žuru, --, 
   {{0x212813bb,0x693c0e04,0xb17c00df,0x00000000}},	//   _mlah_, rčep, אטאר, --, 
   {{0x2128c2d7,0xbcf806af,0xe6100271,0xf9b001f0}},	//   _llah_, _thés, کشه_, _нагӯ, 
   {{0xdb0c06ea,0x00000000,0x00000000,0x00000000}},	//   draø, --, --, --, 
   {{0x254c012c,0x6728032e,0x1bfc033f,0x00000000}},	//   těla_, _eldj, _उछाल_, --, 
   {{0x395c05f5,0x00000000,0x00000000,0x00000000}},	//   _ikus_, --, --, --, 
   {{0x2129c0c4,0xaacc012c,0x2ca00369,0x00c401ec}},	//   _alah_, ालयक, zbid_, _ﺒﺫﺍﺘ, 
   {{0x9f480730,0x21280f85,0xdcfc00c0,0xe688007b}},	//   _spaß_, _blah_, _aisč, _انمى_, 
   {{0x2ca00334,0x6cc802dd,0x2d180210,0x00000000}},	//   xbid_, _ﺩﻋﺎﻴ, _धकेल_, --, 
   {{0xdb0c0113,0x0fd8035b,0x201c0210,0x00000000}},	//   huañ, шьны_, _żwir_, --, 
   {{0x2129c0c5,0xd5dd30a4,0x27e1c0c6,0x63a44dd9}},	//   _elah_, _महाज, çini_, _çina, 
   {{0x395dc0c7,0x2ca126cc,0x212800ad,0x6a7001e1}},	//   _okus_, tbid_, _flah_, _mófí, 
   {{0x4d641fe2,0xc5f00375,0x8d6402d5,0xbcf806af}},	//   ікав, ודל_, івае, _shér, 
   {{0x2ca1c0c8,0x25a01b24,0xc0e0001f,0x4aa9c0c9}},	// [31840] rbid_, ćili_, ምንም_, икан_, 
   {{0x395d2a08,0x5ec000bd,0x2ca0d540,0x00000000}},	//   _akus_, শ্বে, sbid_, --, 
   {{0xdb0c0784,0x088801af,0x395c0171,0x212800a2}},	//   guañ, абей_, _bkus_, _ylah_, 
   {{0x612c002d,0x61fc0450,0x9e702309,0x2ca00327}},	//   _gûld, årli, _سۇقت, qbid_, 
   {{0xbcf9c0ca,0x00000000,0x00000000,0x00000000}},	//   _thér, --, --, --, 
   {{0x3ff8010f,0x00000000,0x00000000,0x00000000}},	//   יפנע, --, --, --, 
   {{0x80a80154,0x00000000,0x00000000,0x00000000}},	//   _কাস্, --, --, --, 
   {{0xb6000030,0x00000000,0x00000000,0x00000000}},	//   úšal, --, --, --, 
   {{0xd90c0214,0x86940114,0xd7d00456,0x7c3802d2}},	//   _حین_, _дјеч, _समयच, _þurt, 
   {{0x31601529,0x2128194f,0x612c000f,0x395c00bc}},	//   _akiz_, _slah_, _mûle, _zkus_, 
   {{0x21280165,0x2258005b,0x3250009d,0x00000000}},	//   _plah_, сины_, двэр, --, 
   {{0x254c00bc,0xd4f40153,0x00000000,0x00000000}},	//   mělo_, _нячы, --, --, 
   {{0xb97805e1,0x212801fa,0xf8b002e4,0x357001ed}},	//   ינטי, _vlah_, ושר_, _تھوڑ, 
   {{0x69c05ede,0x316045d8,0x547001e0,0x623400d8}},	//   _āmen, _ekiz_, _яңыс, _нелу, 
   {{0x2128511d,0xdb0c032e,0x00000000,0x00000000}},	//   _tlah_, duað, --, --, 
   {{0x21281dd4,0x9b940395,0x00000000,0x00000000}},	//   _ulah_, зиац, --, --, 
   {{0xbcf80066,0xe3d800eb,0xdb0c02d2,0x00000000}},	// [31850] _dhép, তিকব, fuað, --, 
   {{0xdea001ed,0x3f98014f,0x6b7401c0,0x395dc0cb}},	//   _سیری, _itqu_, длуу, _skus_, 
   {{0xdb0c0109,0x2b000073,0x1df8008e,0xba440395}},	//   ssaï, राजु_, _уены_, цхай, 
   {{0x612c000f,0xdb0c00c6,0x254c0118,0x00000000}},	//   _fûle, msaí, dělo_, --, 
   {{0x612c000f,0x395c0306,0xe8380212,0x18680063}},	//   _gûle, _vkus_, опці_, љали_, 
   {{0x3705c0cc,0x00000000,0x00000000,0x00000000}},	//   ючев, --, --, --, 
   {{0xdb0c01e7,0x46100345,0x00000000,0x00000000}},	//   nsaí, فوور, --, --, 
   {{0x395c0989,0xaee40055,0x7c38032e,0x00000000}},	//   _ukus_, _keṣv, _þurs, --, 
   {{0x59c80490,0x85000014,0xdb0c01e7,0x00000000}},	//   ांवर, روٝن, hsaí, --, 
   {{0x254c01ef,0x00000000,0x00000000,0x00000000}},	//   bělo_, --, --, --, 
   {{0x6d480214,0x1adc00dc,0xaacc00bc,0x00000000}},	//   édak, न्यथ, ालतक, --, 
   {{0x61fc00fe,0xded40023,0x00000000,0x00000000}},	//   ærla, _ኪዀኑ_, --, --, 
   {{0xe6c400db,0x4f940006,0xa3f40212,0x00000000}},	//   _رتەي, ярну, _опці, --, 
   {{0xfbb4033f,0x00000000,0x00000000,0x00000000}},	//   ेंईम, --, --, --, 
   {{0x80a80d42,0x78b8098d,0x2d8c045f,0xee50035b}},	//   _কার্, _oduv, êde_, hẽva_, 
   {{0xc5f00a1e,0x00000000,0x00000000,0x00000000}},	//   עדן_, --, --, --, 
   {{0x31d8412f,0xdb0c01e7,0x50444130,0x00000000}},	// [31860] _बहुध, asaí, _хепб, --, 
   {{0x47b800cc,0x00000000,0x00000000,0x00000000}},	//   _ইহলী, --, --, --, 
   {{0x273001dc,0xc764a70b,0xdb0c007b,0xe8e0004d}},	//   _hàng_, ۋاتى, csaí, _ngợp_, 
   {{0xdb0c010e,0x00000000,0x00000000,0x00000000}},	//   mraý, --, --, --, 
   {{0x27301574,0x00000000,0x00000000,0x00000000}},	//   _jàng_, --, --, --, 
   {{0x2731c0cd,0x9f540295,0x254c00bc,0xd04401e4}},	//   _màng_, _ôgôg_, tělo_, rekɨ, 
   {{0x2731c0ce,0x7c380008,0x6abc035a,0x09340064}},	//   _làng_, _þurr, _idrf, _ехаў, 
   {{0x6abc030a,0x6d480066,0xd90c0345,0xaee40055}},	//   _hdrf, édah, _پیه_, _yeṣv, 
   {{0x273007ae,0x81d400cc,0xf49097b5,0x69c428fe}},	//   _nàng_, সিছ_, رشيد, ांकी, 
   {{0xaacc0a78,0xae0c447d,0xe70400f2,0xdcfc00ef}},	//   ालिक, हमान_, _تسری, _misā, 
   {{0xc485c0cf,0x41e400d4,0x27e00003,0x00000000}},	//   _елек, чіпа, ħinu_, --, 
   {{0x273001fb,0xbb1814a9,0x63a51193,0x00000000}},	//   _bàng_, _huît, _çino, --, 
   {{0xc059c0d0,0x273007ae,0xaacc0864,0x39440438}},	//   сін_, _càng_, ालाक, énsi_, 
   {{0x27300016,0x80cc00c5,0x00000000,0x00000000}},	//   _dàng_, _थावे, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x273000e8,0x63740086,0xdcfc00b8,0xfd10210e}},	//   _fàng_, fàng, _bisā, رجز_, 
   {{0xad240075,0x12c401ec,0x273001fb,0x9f54003b}},	// [31870] رىكى, _ءتۇپ, _gàng_, _ович, 
   {{0xcfa80014,0x78b804cc,0x60ddc0d1,0xdb0c010e}},	//   _باٹم_, _sduv, lfsm, braý, 
   {{0x69c8168c,0x69c40401,0x2a98007b,0x00000000}},	//   _ådel, ांगी, سئلة_, --, 
   {{0x6abc02d0,0x6375c0d2,0xaee4002b,0xee5000e4}},	//   _edrf, lànd, _teṣv, tẽva_, 
   {{0x6374004e,0xccf00677,0x00000000,0x00000000}},	//   càng, _סכך_, --, --, 
   {{0xf7701ca1,0xe7083baf,0x2730c477,0x68e002d0}},	//   راش_, كتىن_, _nànd_, _ebmd, 
   {{0xd7c81afc,0x80bc5219,0xee5000c7,0x00000000}},	//   _ژوره_, ्लाइ, sẽva_, --, 
   {{0x6299c0d3,0x60dc0d27,0x26d80267,0x46d0000d}},	//   _afvo, jfsm, _öron_, _साथह, 
   {{0x63a43535,0x6d48004a,0x23d402d5,0x57f401a9}},	//   _çinl, édai, нцэр, _юпат, 
   {{0x2730001e,0x00000000,0x00000000,0x00000000}},	//   _ràng_, --, --, --, 
   {{0x60ddc0d4,0x2731c0d5,0x377400c7,0x00000000}},	//   ffsm, _sàng_, _дыҧс, --, 
   {{0xd7d1c0d6,0x084c063f,0x00000000,0x00000000}},	//   _समाच, mọrị_, --, --, 
   {{0x69c002b5,0x316c00e2,0xee5000e4,0x00000000}},	//   _āmem, ēdz_, hẽta_, --, 
   {{0x273007ae,0xb8cc031c,0x00000000,0x00000000}},	//   _vàng_, _ནབ_, --, --, 
   {{0xc20c01d9,0xdcfc0055,0x3f640117,0x00000000}},	//   _نٔو_, _sisā, фиро_, --, 
   {{0x2731c0d7,0x64500784,0xfce021b4,0x6374002e}},	//   _tàng_, _çhiç, косо, tàng, 
   {{0xcb0800ec,0x0f340064,0x00000000,0x00000000}},	// [31880] ٺيان_, _жэня, --, --, 
   {{0xdcfc00da,0xac09c0d8,0xfaa0f9cc,0x6375c0d9}},	//   _visā, онға_, вафо, cànd, 
   {{0x2005a975,0xcc881e4b,0x00000000,0x00000000}},	//   ālie_, _ونده_, --, --, 
   {{0x69c803cd,0xc86401c6,0xdcfc0055,0x00000000}},	//   _ådem, мтли, _tisā, --, 
   {{0x6d4401c8,0x9f4800db,0x00000000,0x00000000}},	//   miia, _graó_, --, --, 
   {{0x6d45c0da,0xf4100154,0x00000000,0x00000000}},	//   liia, িনার_, --, --, 
   {{0x80cc0316,0xa3b00027,0x60dc017a,0xfa6400db}},	//   _थाले, टीन_, yfsm, _жарк_, 
   {{0x6d440194,0x356401c0,0xb90002e8,0xb60001f4}},	//   niia, мрын_, _изск, тяшк, 
   {{0x8ec403d4,0xbcf800bc,0xf49000d1,0x00000000}},	//   শ্যগ, _okén, خشىد, --, 
   {{0x6d459690,0x6374068c,0x00000000,0x00000000}},	//   hiia, xànd, --, --, 
   {{0x6d44009f,0x637404cc,0x91c00022,0x00000000}},	//   kiia, vànd, гәыл, --, 
   {{0x03a40b3b,0x60dc0e78,0x6374002e,0xee5000e4}},	//   _жидо, ufsm, wànd, hẽsa_, 
   {{0x60dc008c,0x6375c0db,0x44e0022e,0xd68001af}},	//   rfsm, tànd, mа_, _иҫәк, 
   {{0x6561c0dc,0x00000000,0x00000000,0x00000000}},	//   lomh, --, --, --, 
   {{0x200c084c,0x6d440194,0x637492a7,0x6e9498e0}},	//   ţei_, fiia, rànd, тису, 
   {{0x65606004,0x6d4420ac,0x44e001a9,0xee2001ec}},	//   nomh, giia, nа_, шесi_, 
   {{0x31342c1d,0x00000000,0x00000000,0x00000000}},	// [31890] _шеър, --, --, --, 
   {{0x656027cc,0x9f480086,0xda340166,0xba283769}},	//   homh, _eraò_, незы, يسام_, 
   {{0x6561c0dd,0x6d44d29e,0x637400db,0x44e001d5}},	//   komh, biia, càne, kа_, 
   {{0x6d443d62,0x656001ab,0x6e28005c,0x00000000}},	//   ciia, jomh, ødbe, --, 
   {{0x25ac015d,0x6560464c,0x44e001b9,0xee500022}},	//   _awdl_, domh, dа_, sẽta_, 
   {{0x5ec00154,0x00000000,0x00000000,0x00000000}},	//   শ্রে, --, --, --, 
   {{0x05c401ad,0xaa64004e,0x656001e7,0x00000000}},	//   रंगब, _аттк, fomh, --, 
   {{0x1cac0135,0x5508000d,0x44e001b9,0x48102abf}},	//   _ཕབས_, वाइए_, gа_, тмәс, 
   {{0x3f8c0066,0x758001d5,0x56e002dd,0x00000000}},	//   _éguh_, _ییتم, _бұлғ, --, 
   {{0xa77400fd,0xd1c8005b,0x7ae0022e,0x69c401f9}},	//   _алуч, плое_, еnti, ांची, 
   {{0xcb1006a9,0x65601bb6,0x5164004e,0x00000000}},	//   אלי_, bomh, нүкү_, --, 
   {{0xbcf8003e,0x65600332,0x00000000,0x00000000}},	//   _skén, comh, --, --, 
   {{0xb4241de7,0x394dc0de,0x6d440869,0x00000000}},	//   _تعاو, ings_, viia, --, 
   {{0x0838010f,0x00000000,0x00000000,0x00000000}},	//   לערל, --, --, --, 
   {{0x0d2000f7,0x3c680131,0x00000000,0x00000000}},	//   гүнү, ﻳﯩﺘﻰ_, --, --, 
   {{0xe1f00345,0x00000000,0x00000000,0x00000000}},	//   _خسه_, --, --, --, 
   {{0x6d440eda,0x90441541,0x5cf40108,0x00000000}},	// [318a0] riia, _سنده, ъяру, --, 
   {{0x6d440140,0x6561c0df,0x637400db,0x394c0036}},	//   siia, zomh, mànc, engs_, 
   {{0x637466e5,0x3cf80882,0x65610135,0xdb0dc0e0}},	//   lànc, _लोके_, yomh, grañ, 
   {{0x3f8c00c7,0xdcfc054e,0xdde80345,0xaca40022}},	//   _ũgui_, _visă, _کریه_, yrỹi, 
   {{0x637467c1,0x6b8400fb,0xdb0c03b2,0x44e0022e}},	//   nànc, _аҫаб, ssaá, vа_, 
   {{0x65600921,0x254c00bc,0x8c400e78,0x394c0036}},	//   womh, měli_, üßun, angs_, 
   {{0x6561c0e1,0xd90c0133,0xdb0c0413,0x00000000}},	//   tomh, _ژیم_, mrað, --, 
   {{0x273004cc,0x63a40e2d,0x00000000,0x00000000}},	//   _bànc_, _çink, --, --, 
   {{0x63540120,0x44e001a9,0xc7a40108,0x00000000}},	//   квиу, rа_, _чизк, --, 
   {{0x65618ba4,0x3f8c0124,0xb350013d,0x00000000}},	//   somh, _égui_, лкыш, --, 
   {{0x041c00bd,0xa159c0e2,0x32b401c0,0x6560949e}},	//   _বেশী_, дану_, эгээ_, pomh, 
   {{0x63741e7b,0x5f94022e,0xdb0c01a8,0x00000000}},	//   fànc, кимт, hrað, --, 
   {{0xb8003c20,0x2730002e,0xc54001ed,0x3cf800e1}},	//   लियम_, _gànc_, _لڑکی, _लोगे_, 
   {{0x254c012c,0xdb0c0054,0x00000000,0x00000000}},	//   děli_, yrañ, --, --, 
   {{0xdb0dc0e3,0x00000000,0x00000000,0x00000000}},	//   drað, --, --, --, 
   {{0x98bc0053,0x537002d3,0xdb0cfccf,0x00000000}},	//   kiwā_, _ትብዓት_, vrañ, --, 
   {{0xdb0dc0e4,0x6374067c,0x2c259a68,0x1f742d4f}},	// [318b0] nsaç, cànc, льфг, _илия, 
   {{0xdb0dc0e5,0x80b000db,0x00000000,0x00000000}},	//   trañ, _جەڭش, --, --, 
   {{0xa2d82ce6,0xa3b00490,0x5e580276,0x00000000}},	//   _मान्, टीत_, _циня_, --, 
   {{0xa9a423f6,0x26042432,0x6d48a8d8,0x7f44047e}},	//   امنى, विनी_, édat, lijq, 
   {{0xa96816ac,0x00000000,0x00000000,0x00000000}},	//   رمهم_, --, --, --, 
   {{0xdb1c008e,0x6d5800e4,0xab840064,0x3d0c0073}},	//   _aqsö, _êvar, _буск, डावे_, 
   {{0x99840184,0x25680af2,0x00000000,0x00000000}},	//   _атаһ, hûlu_, --, --, 
   {{0x256800d2,0xbcf800e4,0x1c04134e,0x00000000}},	//   kûlu_, _okém, रिपल_, --, 
   {{0x3689c0e6,0x4f080150,0xdb2401e1,0x59c805c0}},	//   _есен_, _ءﺟﺎ_, _òpón, ांकर, 
   {{0x3eb1c0e7,0xc4810260,0xdce40327,0x63744b84}},	//   _next_, шлык, _fuhħ, vànc, 
   {{0xd4f42692,0x10a455da,0x57d013f7,0xbcf80419}},	//   _аялы, кинн, _समुह, _akém, 
   {{0x236d8589,0x637419c6,0xfd1c0ffb,0x7760009a}},	//   aldj_, tànc, _noì_, lonx, 
   {{0x6d5800e4,0x88b80375,0x00000000,0x00000000}},	//   _ívai, וזרי, --, --, 
   {{0x637466e5,0x91e400c7,0x77600472,0x00000000}},	//   rànc, _аоке, nonx, --, 
   {{0xdbc80037,0x63a40003,0xfe40022e,0xdb0c0162}},	//   _mõõg, _ħini, анро, vrað, 
   {{0x06c802a6,0x57d00b26,0x13d40183,0x254c012c}},	//   ল্পি, _समूह, _তৈয়, těli_, 
   {{0x63740b86,0x61e42625,0x77600472,0x4c85c0e8}},	// [318c0] làna, _ćili, konx, тлав, 
   {{0xdb0c002f,0x00000000,0x00000000,0x00000000}},	//   rpaß, --, --, --, 
   {{0x63740170,0x9044765c,0x1a240014,0xdb0c002f}},	//   nàna, _سنگه, ُرمُ, spaß, 
   {{0x07a400c0,0xc7a4054d,0x88a000fb,0x00000000}},	//   вадн, видк, рғаһ, --, 
   {{0xf7f00228,0x2d81c0e9,0xf860023a,0x3cf802e5}},	//   لسود, mmie_, авцо, _लोटे_, 
   {{0xfaa1c0ea,0x98bc02b1,0x2d80033f,0x63a4bd89}},	//   _варо, riwā_, lmie_, _çini, 
   {{0xbb4079c2,0x00000000,0x00000000,0x00000000}},	//   _терк, --, --, --, 
   {{0x29dc26c8,0x2d800263,0x273001c3,0xc4c02b1b}},	//   mía_, nmie_, _dàna_, ্জ্জ, 
   {{0x29ddc0e5,0x1c04228d,0x73d4010b,0xdbd0002f}},	//   lía_, रियल_, вдыр_, _müße, 
   {{0xb9d8001f,0xdb0c0120,0x77600077,0xa450001f}},	//   _አባ_, rsaç, conx, _ዕድገት, 
   {{0x29dc26c8,0x2d800649,0xdb0dc0eb,0xbcf8065c}},	//   nía_, kmie_, ssaç, _ském, 
   {{0x2d800034,0x3eb0f225,0x00000000,0x00000000}},	//   jmie_, _sext_, --, --, 
   {{0x29dc3a6c,0xbcf80129,0xf04401f4,0xf534011a}},	//   hía_, _théz, аэро, _בנאי_, 
   {{0xc4cc01d3,0x2258005b,0xc20400d8,0x2d8015c0}},	//   _اےک_, _пилы_, _аџии, emie_, 
   {{0x29dc09d7,0x3eb00204,0xdbd0002f,0x3d0c0892}},	//   jía_, _vext_, _büße, डाले_, 
   {{0x29dd4692,0x7761c0ec,0x6e280b1a,0xeca40063}},	//   día_, zonx, ødba, ијун, 
   {{0x3eb00fa9,0xbcf80098,0x7761c0ed,0x4bc001e0}},	// [318d0] _text_, _ukém, yonx, йөрг, 
   {{0x29ddc0ee,0x7e45c0ef,0x7a845cb5,0x39940120}},	//   fía_, _ахме, نشام, _pçs_, 
   {{0x29dce5ff,0xab840f32,0xfc3c067c,0xdbd00e78}},	//   gía_, рутк, _peís_, _füße, 
   {{0x273004cc,0x06c8009e,0x6d5800e4,0xdcec0115}},	//   _ràna_, ল্মি, _êvap, klaĉ, 
   {{0xb8d8032c,0x69ddc0f0,0x273004cc,0x63740109}},	//   _आज_, _eqre, _sàna_, zàna, 
   {{0x29dc28f2,0x2abc00bc,0xe7f4000d,0x0db800e5}},	//   bía_, rábí_, _इनरा_, _تئیں_, 
   {{0x29dc26c8,0x74d480f3,0xa3b00490,0x61f80254}},	//   cía_, _यादृ, टीस_, _nsvl, 
   {{0x63740109,0x66240116,0x254c0210,0x00000000}},	//   vàna, شرىك, yśle_, --, 
   {{0x7bddbc9f,0xbcf80030,0x77600005,0x94240276}},	//   ntqu, _akék, ponx, умпе, 
   {{0x273118a7,0x98ac00f3,0x637406d9,0x7bdc0393}},	//   _tàna_, _mleč_, tàna, itqu, 
   {{0x94d4021a,0x27300241,0x7bdc0036,0x2d680112}},	//   _مياش, _kànn_, htqu, ißer_, 
   {{0x8fa5c0f1,0x63740109,0x5f3c001f,0xe508009a}},	//   ламе, ràna, _አቅማቸ, _ليمو_, 
   {{0x273000e8,0x63740109,0x7ae40175,0xf48400ea}},	//   _mànn_, sàna, _objt, _ружн, 
   {{0xdbd003fa,0x63c40032,0x0874008f,0x9ff40327}},	//   _süße, _ташҡ, טערט_, _བརྫང_, 
   {{0xa2d80a78,0x29dc36ed,0x7bdc003a,0x2d8015c0}},	//   _मात्, xía_, etqu, tmie_, 
   {{0x29dc28f2,0xfc3c00eb,0xa3b006ab,0x7bdc324c}},	//   vía_, _reír_, टीव_, ftqu, 
   {{0x2d81c0f2,0xbf9800d8,0x96c0022e,0x00000000}},	// [318e0] rmie_, lvên, _аxир_, --, 
   {{0x29dc09ff,0x2d81c0f3,0xcb6804fb,0x0ea802d5}},	//   tía_, smie_, رماه_, _якой_, 
   {{0x8d740a52,0xbf9806ed,0x7bdc0393,0x5a94023b}},	//   _ماحا, nvên, atqu, рруф, 
   {{0x29dd4692,0x61fc14f5,0xf9c4036b,0x6e540092}},	//   ría_, ærli, احلی, _መሆናች, 
   {{0x29dc26c8,0x7d0400a7,0x27b40bd6,0xa9a40145}},	//   sía_, _сняг_, рәбс, امچى, 
   {{0xa2d994ac,0x29dc0cc3,0xbcf99815,0x645c93ba}},	//   _माध्, pía_, _akéh, şrik, 
   {{0xf41c426d,0x27300694,0x7d0c035a,0x3e740092}},	//   ään_, _fànn_, _yncs, _በትንሹ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x14d4d3c3,0x68e400c5,0xa2d809fa,0xc3480166}},	//   _धारण, õidu, _माद्, еяне_, 
   {{0x778000d4,0x00000000,0x00000000,0x00000000}},	//   _глуз, --, --, --, 
   {{0x6114e0c3,0x2259c0f4,0x06540006,0x27300241}},	//   адну, тины_, _стаў, _yànn_, 
   {{0xdcec01e4,0x85742b9f,0x80a80154,0x00000000}},	//   plaĉ, _صدائ, _কাঙ্, --, 
   {{0x320401c7,0x64a40139,0x5f940068,0xa3b00073}},	//   _erny_, _баҗа, ригт, टीश_, 
   {{0x2fc009a8,0x7c38010b,0x343800df,0x00000000}},	//   _dvig_, _ýuri, _אײדע, --, 
   {{0x2fc02ab7,0xa3b001ad,0x57d03105,0xa15800c7}},	//   _evig_, टीर_, _सम्ह, _иаку_, 
   {{0x660801ef,0x7bdc031c,0x23b8012d,0x00000000}},	//   _mrdk, ttqu, _इबाद, --, 
   {{0x9d441de6,0xfaa400d4,0x00000000,0x00000000}},	// [318f0] геңд, гшен, --, --, 
   {{0x200806af,0x2730002e,0x7bdc003a,0x00000000}},	//   _irai_, _sànn_, rtqu, --, 
   {{0x7bdc0483,0x98b809a5,0x00000000,0x00000000}},	//   stqu, влет_, --, --, 
   {{0x2009c0f5,0x2a780004,0x3f8000e2,0x2fc0007c}},	//   _krai_, _dzrb_, lmju_, _yvig_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2730002e,0xd7040108,0x15f4009f,0x00000000}},	//   _wànn_, рзки, لسبح, --, 
   {{0x27301574,0xdb0c0254,0x00000000,0x00000000}},	//   _tànn_, uraõ, --, --, 
   {{0x200802d5,0x6d5802d2,0x00000000,0x00000000}},	//   _orai_, _ívat, --, --, 
   {{0xa3b16c08,0x66081196,0x637400a3,0xe980010a}},	//   टील_, _erdk, rànn, _хатi_, 
   {{0x9344022e,0x00000000,0x00000000,0x00000000}},	//   рное, --, --, --, 
   {{0x2009c0f6,0x3f800327,0x2fc06a39,0x00000000}},	//   _arai_, dmju_, _svig_, --, 
   {{0x2008004e,0x00000000,0x00000000,0x00000000}},	//   _brai_, --, --, --, 
   {{0x2009c0f7,0x00000000,0x00000000,0x00000000}},	//   _crai_, --, --, --, 
   {{0x2009c0f8,0x56b400c8,0x3204013a,0x00000000}},	//   _drai_, יפֿן_, _trny_, --, 
   {{0x2009c0f9,0x10a401b9,0x7e2016a4,0x00000000}},	//   _erai_, _кийн, одрж, --, 
   {{0x20083987,0xa3b4012c,0x00000000,0x00000000}},	//   _frai_, _छौँ_, --, --, 
   {{0x0b44e093,0xfc000228,0x2009c0fa,0x63a400a2}},	// [31900] анан, опто, _grai_, _çint, 
   {{0x09e40a31,0xb4a80008,0xaca40248,0x00000000}},	//   иозн, íþjó, _ijọs, --, 
   {{0xa2d806ab,0xaca401f2,0x98bc012d,0xfaa00022}},	//   _मास्, _agụt, ziwą_, цахо, 
   {{0x88e41de1,0x0bd40150,0x48e428e8,0x7c380210}},	//   ржде, _پيسح, родв, _żure, 
   {{0xdced839d,0xbcf80ca8,0x2b58009f,0xa3b4012c}},	//   lmağ, _akéw, _tjrc_, _छौं_, 
   {{0x2ca0003a,0x637400cf,0x65942db7,0x00000000}},	//   lcid_, vàno, баку, --, 
   {{0xdcec467d,0x00000000,0x00000000,0x00000000}},	//   nmağ, --, --, --, 
   {{0xe9442f4d,0x2ca0a3d6,0x0584ec1f,0x041c00cc}},	//   _طرزی, ncid_, шулм, _বেগী_, 
   {{0x46f40f06,0x00000000,0x00000000,0x00000000}},	//   _вчет, --, --, --, 
   {{0xc7640075,0x07080451,0x69c80fac,0xdcec03e0}},	//   _ئارى, _جيئي_, _ådes, kmağ, 
   {{0xfa94008d,0x00000000,0x00000000,0x00000000}},	//   ידיש_, --, --, --, 
   {{0x200808cd,0x9d200f22,0xdcec06be,0x00000000}},	//   _prai_, _নগ্ন_, dmağ, --, 
   {{0xc0580efb,0x229402e8,0xdb0c00e5,0x00000000}},	//   тін_, _лиля, őkén, --, 
   {{0x2009c0fb,0xdb0c03b2,0xa6b40154,0x00000000}},	//   _vrai_, ssaú, _ঘাঁট, --, 
   {{0x160803ce,0xac4c0092,0x00000000,0x00000000}},	//   वियर_, _በመፈጸ, --, --, 
   {{0x2009c0fc,0xc0c95d25,0x4904098a,0x63a40139}},	//   _trai_, _руке_, _सोलो_, _çins, 
   {{0x7c8521a2,0xbcf80022,0x2d9c01d3,0x2bb8007b}},	// [31910] руве, _okév, _éven_, لالة_, 
   {{0xfaa4e7ea,0x69c002b5,0xdab80035,0xdcec01a6}},	//   ршан, _āmer, اهات_, mlač, 
   {{0xceb00bd9,0x63a53908,0x00000000,0x00000000}},	//   _מיי_, _éinf, --, --, 
   {{0x68e401e4,0x2ca1c0fd,0x00000000,0x00000000}},	//   ϲide, ccid_, --, --, 
   {{0xcce405d9,0x8d68001f,0x00000000,0x00000000}},	//   _اسپي, _ሰጥቷል_, --, --, 
   {{0xb76488d6,0x9b45050c,0x9585c0fe,0x6d5912fe}},	//   штей, _طنزو, әлие, _ívar, 
   {{0x65b80150,0x0af0009d,0x00000000,0x00000000}},	//   ауыр_, _хүхэ, --, --, 
   {{0xda7800d1,0xdcec02fb,0xf8a8000d,0xaa580452}},	//   _аяғ_, klač, _चभिय, _тису_, 
   {{0xdcec723e,0x63a40115,0x68e400a3,0x69c801e3}},	//   zmağ, _ɩing, òide, _åder, 
   {{0xf5e400d6,0xdcec4674,0x27e000a3,0x52a80108}},	//   _відм, dlač, àine_, ывом_, 
   {{0xa2d82072,0xdcec0213,0x00000000,0x00000000}},	//   _मार्, xmağ, --, --, 
   {{0xdcec02f0,0x00000000,0x00000000,0x00000000}},	//   flač, --, --, --, 
   {{0xdcec0301,0x7539c0ff,0x8d58059f,0x630400e5}},	//   jmađ, mhuz, ҳшат_, _ڈونل, 
   {{0x3ea007d6,0xe3b001d9,0xdcecafeb,0x31940356}},	//   зирг, _آرن_, tmağ, _lăzi_, 
   {{0x28d80456,0x00000000,0x00000000,0x00000000}},	//   _डालि, --, --, --, 
   {{0xdcedc100,0x7538000f,0x8c440166,0xaa8400a2}},	//   rmağ, nhuz, бебе, naýş, 
   {{0x2ca0010a,0x4f582cb0,0x6ad00f22,0x0ae9035c}},	// [31920] rcid_, _مجدد_, স্ফো, лдай_, 
   {{0x8a3834d8,0x6204000f,0x2ca00c3c,0xcfc802dd}},	//   ляет_, _útlâ, scid_, _ﺑﻪﻳﺒ, 
   {{0x7539c101,0x49c9c102,0x5b34084c,0x00000000}},	//   khuz, улен_, цэту, --, 
   {{0x2d841497,0x7538002d,0x888400d8,0x28d801f9}},	//   _òme_, jhuz, блеж, _डाळि, 
   {{0x38c9131c,0xa2d86651,0x75380810,0xaa8400a2}},	//   طانی_, _माल्, dhuz, daýş, 
   {{0x2900c593,0x6ca00150,0x26040073,0x00000000}},	//   žia_, _ﺃﻏﻠﺏ_, विली_, --, 
   {{0xe7f40bb2,0x273000e8,0xdcec0427,0xa82400e5}},	//   _इनका_, _yànj_, zlač, _ڈکشن, 
   {{0x3e8061d0,0xd90d2766,0x9bb80327,0xbb301884}},	//   lété_, _لیم_, _བསྩོ, ﺭﺍﻡ_, 
   {{0x7c3809a5,0x041c00cc,0xd90c12fd,0x389808c3}},	//   _ýurt, _বেজী_, _جین_, _תימנ, 
   {{0xdcec05ce,0x00000000,0x00000000,0x00000000}},	//   vlač, --, --, --, 
   {{0x753853ff,0x27300de2,0xf310009d,0x00000000}},	//   bhuz, _lànk_, чдээ, --, 
   {{0x753805d9,0xdcedc103,0x00000000,0x00000000}},	//   chuz, tlač, --, --, 
   {{0xf5000014,0xd9c4000d,0x27301bce,0x00000000}},	//   _رِوُ, _लट्ट, _nànk_, --, 
   {{0x356c0020,0x62340276,0x2730002e,0xdd94747c}},	//   _ስህተት_, _мелу, _sànj_, жавы, 
   {{0xdcec0552,0x6441c104,0x5648001f,0x00000000}},	//   slač, lzmi, _እንደጠ, --, 
   {{0xdcec0fb7,0x27301bce,0xbd68bdb2,0xf1a400ec}},	//   plač, _bànk_, урге_, _اٿيو_, 
   {{0xac181049,0x64400097,0x63a5c105,0x88cc02f5}},	// [31930] боту_, nzmi, _éind, রভাক, 
   {{0x2730002e,0x6441c106,0xded4038b,0x3e80020c}},	//   _dànk_, izmi, _بيدخ, gété_, 
   {{0xbcf80de2,0x31940356,0x5894419d,0x00000000}},	//   _njég, _păzi_, ошлу, --, 
   {{0x273001dc,0x7c84eb44,0xbb300046,0x7538004b}},	//   _hành_, _гуге, ﺭﺍﻥ_, xhuz, 
   {{0x3f980117,0x186814b7,0x98c40790,0xd6a800e5}},	//   _juqu_, јали_, çtır_, لگام_, 
   {{0x941c016b,0x3f9803f0,0x6441c107,0xb07c010f}},	//   _mewɔ_, _muqu_, dzmi, אנדז, 
   {{0x3f900548,0x7539c108,0x2730004d,0x78902099}},	//   _mixu_, thuz, _mành_, _فیاض, 
   {{0x2730001e,0x53c9c109,0x06c80154,0x41a00046}},	//   _lành_, агим_, ল্লি, _ﺍﻟﺫﻱ_, 
   {{0x56480020,0x3f980a73,0x7539c10a,0xdcec02f0}},	//   _እንዲጠ, _nuqu_, rhuz, hlaď, 
   {{0x7af585f7,0x7538a1d3,0x78b8923a,0x273001fb}},	//   next, shuz, _heuv, _nành_, 
   {{0x75385c2e,0xe78594c7,0x5f1c1944,0x6b800a40}},	//   phuz, _хуто, मान्_, _ëmge, 
   {{0x3f99c10b,0x75380921,0xd0080261,0x394cb571}},	//   _buqu_, qhuz, аеме_, nigs_, 
   {{0x78b80165,0xdb1c03b2,0x2730004d,0x3e80002e}},	//   _meuv, _avsí, _bành_, yété_, 
   {{0x78b9c10c,0x273001fb,0x3f98058a,0x0798010f}},	//   _leuv, _cành_, _duqu_, יסשל, 
   {{0x2731c10d,0x78b820ef,0xd1b80075,0x7bc9c10e}},	//   _dành_, _oeuv, _ئاتا_, águn, 
   {{0x78b99d68,0x33240007,0x3f980003,0xd7c80073}},	//   _neuv, _honx_, _fuqu_, रळाच, 
   {{0x3f90022f,0x8b246ac0,0x4b25c10f,0xa3dc0490}},	// [31940] _fixu_, одае, омав, तंय_, 
   {{0x91ec3be5,0x63a5bd23,0x27300051,0x00000000}},	//   _जहाज_, _éine, _gành_, --, 
   {{0x3e80004a,0x78b806af,0x0c842f89,0x66d00241}},	//   rété_, _beuv, сыңм, _lókà, 
   {{0x27301bce,0x394c002f,0xcab000cc,0x08280798}},	//   _tànk_, gigs_, _চাওফ, ицли_, 
   {{0x26c8c955,0xc7646073,0x3f980e14,0x3e8006af}},	//   йған_, ياتى, _xuqu_, pété_, 
   {{0x2ef801f5,0x63741bce,0x6594e583,0x940c0213}},	//   nerf_, rànk, паку, _önəm_, 
   {{0xa3dc1098,0x612c002d,0xbcf800e4,0x20040421}},	//   तून_, _kûlt, _ikér, ālii_, 
   {{0x63741e7b,0x03c5c110,0x64400e78,0xd5ac0014}},	//   màni, осом, tzmi, اہن_, 
   {{0x29055a7a,0x6abc0008,0x644005ce,0x612c002d}},	//   _iama_, _kerf, uzmi, _mûlt, 
   {{0x2905c111,0x9bb8025c,0x2ef808fb,0x6abc025c}},	//   _hama_, _བསྣོ, jerf_, _jerf, 
   {{0x2905c112,0x6abdc113,0x2ef805e4,0x273001fb}},	//   _kama_, _merf, derf_, _rành_, 
   {{0x29044437,0x6729c114,0x2730001e,0x3f980309}},	//   _jama_, _hodj, _sành_, _puqu_, 
   {{0x6abdc115,0x3324968b,0x644005b1,0xbcf800e4}},	//   _oerf, _fonx_, qzmi, _okér, 
   {{0x2905c116,0x26ddc117,0x6abdc118,0xcf8c04d3}},	//   _lama_, ngvo_, _nerf, ێژی_, 
   {{0x67280a73,0x6e945c97,0x273001fb,0xc0c81d5b}},	//   _modj, диру, _vành_, _купе_, 
   {{0x29042f11,0x5c993521,0x6abdc119,0x6e2801e6}},	//   _nama_, ская_, _aerf, ädba, 
   {{0x6abdc11a,0x23a00100,0x78b801f5,0xbcf8706b}},	// [31950] _berf, _jòj_, _reuv, _njée, 
   {{0x60ddc11b,0x29040140,0x6abdc11c,0x78b9c11d}},	//   lgsm, _aama_, _cerf, _seuv, 
   {{0x6abc0ac7,0x78b80231,0x2905c11e,0x637400f7}},	//   _derf, _peuv, _bama_, gàni, 
   {{0x7af59bfc,0x2905c11f,0x212801c7,0x6abc02d0}},	//   sext, _cama_, _joah_, _eerf, 
   {{0x2905c120,0x6abdc121,0x78b9c122,0x67280363}},	//   _dama_, _ferf, _veuv, _bodj, 
   {{0x6729c123,0x9ff4031c,0x6abd8791,0x637400db}},	//   _codj, _བརླང_, _gerf, bàni, 
   {{0x2905c124,0x67281326,0x63740137,0x78b9c125}},	//   _fama_, _dodj, càni, _teuv, 
   {{0x2905c126,0x466003cc,0x6abc0ade,0xb884010b}},	//   _gama_, رۇنق, _zerf, _дузй, 
   {{0x395c003e,0x67280076,0xd9442f16,0xbcf8035b}},	//   _ijus_, _fodj, _деңи, _ykér, 
   {{0x2905c127,0x387c0327,0x60dc002f,0x00000000}},	//   _zama_, _izur_, egsm, --, 
   {{0x21285cf5,0x2ef9c128,0x395c0fac,0xb80000bc}},	//   _boah_, verf_, _kjus_, लिकम_, 
   {{0x2ef9c129,0x21280789,0x23a0007f,0x60dc143a}},	//   werf_, _coah_, _fòj_, ggsm, 
   {{0x23a002e2,0x24640023,0x2ef86e03,0x7c380327}},	//   _gòj_, rëmë_, terf_, _żurn, 
   {{0x395c049f,0x2d9c01ed,0xa3b002ab,0xbcf8002e}},	//   _ljus_, _évek_, टीओ_, _njéb, 
   {{0x612c002d,0x6b40e4c3,0x2ef8017a,0xa92802f0}},	//   _pûlt, _högg, rerf_, ndžá, 
   {{0x6abdc12a,0x21280c6a,0x0fc400d1,0x63a40798}},	//   _serf, _goah_, _ейин, _éinc, 
   {{0x2905c12b,0x2ef9c12c,0x31940356,0x00000000}},	// [31960] _rama_, perf_, _văzu_, --, 
   {{0x63745c10,0x395c000d,0x4a9802d5,0x6b40032e}},	//   tàni, _ajus_, стаў_, _mögg, 
   {{0x6abdc12d,0x387dc12e,0x4ae005ba,0x2904ad56}},	//   _verf, _azur_, _पाठव, _pama_, 
   {{0x63740137,0x6abc1ec6,0x2905c12f,0x67280363}},	//   ràni, _werf, _qama_, _sodj, 
   {{0x67293b78,0x290404b9,0x6abdc130,0xbcf800e4}},	//   _podj, _vama_, _terf, _ikép, 
   {{0x2905c131,0x395c0483,0x6374068c,0x6abc3c02}},	//   _wama_, _ejus_, pàni, _uerf, 
   {{0x6728e8a2,0x395c031c,0x5f1c00dc,0x316001b9}},	//   _vodj, _fjus_, मात्_, _ojiz_, 
   {{0x6b4008a5,0x4ae001f9,0xf77c010a,0x00000000}},	//   _bögg, _पाडव, _ӗç_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6b4002d2,0x6234234c,0xfa5c0a43,0xb7d401e7}},	//   _dögg, деоу, _çäçe_, _روما_, 
   {{0x7640006d,0x26cc0cfd,0xa3b0547d,0x3250084c}},	//   czny, _iddo_, टीज_, евэр, 
   {{0xf4846f51,0x60dc00e2,0x84e408da,0xa2d821b8}},	//   _کامی, ugsm, _ходж, _माक्, 
   {{0xfc3da809,0x60ddc132,0xdb0c0037,0x26040b02}},	//   _afín_, rgsm, tsaü, विकी_, 
   {{0x3da4dea5,0x2129c133,0x3160010b,0xe374104e}},	//   зраб, _woah_, _ejiz_, _юллы, 
   {{0x21280098,0x00000000,0x00000000,0x00000000}},	//   _toah_, --, --, --, 
   {{0x60dc0477,0x00000000,0x00000000,0x00000000}},	//   qgsm, --, --, --, 
   {{0x60cdc134,0x3e800241,0x9b94c081,0x25ac05b1}},	// [31970] _idam, _bétí_, диац, _ltdl_, 
   {{0x23d4d04e,0x945c0210,0x00000000,0x00000000}},	//   _दिनद, lańc, --, --, 
   {{0xa3dc02ab,0x94fc025c,0x27e008c2,0x2b4401c6}},	//   तूत_, _དྲའི_, àinn_, хэтг, 
   {{0x26cdc135,0xe9d04fb6,0x9f480165,0x81ac0154}},	//   _addo_, اغل_, _isañ_, _ওটা_, 
   {{0x637401ab,0xa8841870,0x00000000,0x00000000}},	//   lànu, ىلمى, --, --, 
   {{0xe7d40075,0xa2d8012c,0xb9e40212,0x6b40032e}},	//   رمىگ, _माग्, _ніби, _rögg, 
   {{0xba7450c9,0x60cc006c,0x945c0034,0xe6c400db}},	//   _راست, _odam, kańc, رتوي, 
   {{0xdb0c0054,0x26cc0083,0x7581c136,0xdb1000d2}},	//   msañ, _eddo_, ریشم, _úfât, 
   {{0x387dc137,0x67d432cf,0x3acc00b0,0x76401f6f}},	//   _uzur_, _поту, pēpē_, szny, 
   {{0x6b4008a5,0x00000000,0x00000000,0x00000000}},	//   _vögg, --, --, --, 
   {{0x61e8089c,0xdb0c0113,0xc05c0023,0xfee000cc}},	//   gtdl, nsañ, _ዘሕለፍ, য়াধ, 
   {{0xdb1c145e,0x798800d2,0xa3b0473c,0xdcfc0171}},	//   âyêk, nmgw, टीङ_, _misē, 
   {{0x6b40049f,0x60cdc138,0xa3dc0073,0x13a40244}},	//   _höge, _ddam, तूद_, _تۆخی_, 
   {{0x60cdc139,0x8368004b,0x6e28007c,0x00000000}},	//   _edam, _وشوې_, ädbo, --, 
   {{0x51f4c5a5,0x6374004e,0xbea0005b,0x437001c8}},	//   _آستر, gànu, таск, _جهور, 
   {{0x6b41c13a,0xd2dc07f7,0x3e800241,0x00000000}},	//   _möge, _माँझ, _sétí_, --, 
   {{0x6b4002d2,0x00000000,0x00000000,0x00000000}},	// [31980] _löge, --, --, --, 
   {{0x27300de2,0x94fc031c,0x7c2801e3,0xca540798}},	//   _jànt_, _དིའི_, ägra, мтењ, 
   {{0x48e5c13b,0x6375c13c,0x0d85c13d,0x752801f5}},	//   доев, mànt, _олон, _oogz, 
   {{0x6375c13e,0xf76dc13f,0x6b4000a2,0x00000000}},	//   lànt, یاو_, _sögd, --, 
   {{0x07f800c1,0xac8400c7,0x81ac0154,0x00000000}},	//   تراع_, _чҳал, _ওয়া_, --, 
   {{0x6b400724,0x6374354d,0xdde80244,0x00000000}},	//   _böge, nànt, _بریه_, --, 
   {{0x75280356,0x00000000,0x00000000,0x00000000}},	//   _bogz, --, --, --, 
   {{0x490405f9,0xdb2401f4,0x00000000,0x00000000}},	//   _सोचो_, äpöm, --, --, 
   {{0x60cc022e,0x75280200,0x00000000,0x00000000}},	//   _rdam, _dogz, --, --, 
   {{0x6b415408,0x2730002e,0x77800276,0xdb0c148b}},	//   _föge, _cànt_, _алуз, nsað, 
   {{0x637407c5,0x60cc0175,0x3f8c00e4,0x6b40010b}},	//   dànt, _pdam, _ègui_, _göge, 
   {{0xc05c0023,0xdfd444a5,0xb518010a,0x7bc800e5}},	//   _ዘሕልፍ, номы, _михĕ_, águk, 
   {{0x6b4003fa,0xf41c023a,0x637407de,0x945c033f}},	//   _zöge, äät_, fànt, rańc, 
   {{0xdb0c0227,0x637405d5,0x6b41c140,0x2d8c01a4}},	//   ysañ, gànt, _lögb, ïden_, 
   {{0x7528090c,0x260403ce,0x00000000,0x00000000}},	//   _yogz, विटी_, --, --, 
   {{0x60cdc141,0x5a340022,0xe37401ee,0x00000000}},	//   _udam, ҭнат, _юлһы, --, 
   {{0xdb0dc142,0x2138020b,0xfd1c01fb,0xbb48037e}},	// [31990] wsañ, mksh_, _chìa_, _nhkホ_, 
   {{0x945c0054,0xdb0c09f3,0x273005d5,0x6374354d}},	//   nańa, gsað, _màns_, cànt, 
   {{0x69c800b5,0x00000000,0x00000000,0x00000000}},	//   _ædel, --, --, --, 
   {{0xa2d82413,0xdcfc0171,0x00000000,0x00000000}},	//   _माझ्, _visē, --, --, 
   {{0x7ac41515,0xf77183e7,0x9bb80327,0x00000000}},	//   _осве, پاش_, _བསྲོ, --, 
   {{0x945c0054,0x254c0118,0xd5e402e8,0xdb1401e1}},	//   jańa, měly_, ежки, _àbàm, 
   {{0x58d54f0b,0xd5b000c6,0x00000000,0x00000000}},	//   _повт, دفع_, --, --, 
   {{0x6b41c143,0x2730002e,0x00000000,0x00000000}},	//   _vöge, _sànt_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc481c144,0x9bb8025c,0x6b400139,0x924808ca}},	//   ылык, _བསློ, _töge, ззоб_, 
   {{0x4ae08a4f,0x63a400c6,0x637407c5,0x42c439d2}},	//   _पासव, _éinn, vànt, эгэн_, 
   {{0xf41c0108,0x2258dd18,0x00000000,0x00000000}},	//   ääs_, úrka_, --, --, 
   {{0x2731c145,0x637407c5,0xa074084c,0x2c6c0118}},	//   _tànt_, tànt, вырш, _kódů_, 
   {{0x82280023,0x2aa00248,0x254c0118,0x7e7801ec}},	//   _ስጉምታ, _ḿbá_, děly_, _ﺤﺭﺒﺎ_, 
   {{0x63748759,0x6d880083,0x3e843fbb,0x3f640117}},	//   rànt, nÿag, ейро_, хиро_, 
   {{0x6375c146,0x00000000,0x00000000,0x00000000}},	//   sànt, --, --, --, 
   {{0x4f9476ac,0x637407c5,0x3e5c0092,0x00000000}},	// [319a0] _проу, pànt, ደሚረዳ_, --, 
   {{0xfaa1c147,0x6d9801e4,0xbf9806af,0xf0b400e5}},	//   гафо, _gŭan, rvêt, _سیڑھ, 
   {{0x6d480066,0x9f480200,0xdb0c0413,0x00000000}},	//   èdas, _spaç_, rsað, --, 
   {{0xdb0c1f60,0xfd1c01fb,0xdb1c0267,0xca7400c7}},	//   ssað, _thìa_, _avsä, _ҷубы, 
   {{0x945c0054,0x4e9404fb,0x6d45c148,0x6b8001c7}},	//   yańa, _تشکر, mhia, _ëmgo, 
   {{0xa5a40034,0x6d45adb4,0x09e41422,0xc8e80133}},	//   _चंदौ, lhia, _погн, توچۆ_, 
   {{0x25a001e4,0x2731a982,0xdb140248,0x00000000}},	//   ĉilo_, _sàns_, _àbám, --, 
   {{0x6d45c149,0x945c0054,0xc4c402f2,0x00000000}},	//   nhia, wańa, رتبو, --, 
   {{0x945c0bc9,0x00000000,0x00000000,0x00000000}},	//   tańa, --, --, --, 
   {{0xfd1c07ae,0xbcf80de2,0xa2940006,0x7bc800c7}},	//   _nhìn_, _njén, капі, águi, 
   {{0x6d45338c,0x945c0227,0xf41c00c5,0x9f5c01e1}},	//   khia, rańa, äär_, _èwé_, 
   {{0xbcf9c14a,0x945c0227,0x84640801,0xdcec05a1}},	//   _ajén, sańa, _пъле, mlać, 
   {{0x6d45c14b,0x945c0054,0x03f80327,0x00000000}},	//   dhia, pańa, _དགྲམ_, --, 
   {{0x945c0054,0x00000000,0x00000000,0x00000000}},	//   qańa, --, --, --, 
   {{0x2730002e,0xe80000e1,0x6d44464c,0xa3dc10eb}},	//   _jànq_, लौता_, fhia, तूर_, 
   {{0x6d45c14c,0x65601cf8,0x01081913,0x00000000}},	//   ghia, nnmh, _رتبو_, --, 
   {{0x65600e9e,0x00000000,0x00000000,0x00000000}},	// [319b0] inmh, --, --, --, 
   {{0x5f94026a,0x6d44b7dc,0x2b4401c0,0x3a28004d}},	//   _шипт, ahia, лэхг, _đểđă, 
   {{0x6d4407f0,0x0e00013e,0x00000000,0x00000000}},	//   bhia, _кӯто, --, --, 
   {{0xdb0c27b9,0x00000000,0x00000000,0x00000000}},	//   mpaí, --, --, --, 
   {{0xdb1c01e3,0xe77800e5,0x00000000,0x00000000}},	//   _avså, کلوں_, --, --, 
   {{0x7bdc0014,0x61f80b4f,0xf72802d5,0xc7a01eec}},	//   muqu, _opvl, яцей_, шишк, 
   {{0xae1409d9,0x7bddc14d,0x2d9c01d3,0x154400db}},	//   डियन_, luqu, _évet_, кекм, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6b4001e6,0xa3dc02ab,0x7bddc14e,0x03e401e2}},	//   _höga, तूल_, nuqu, نډوي_, 
   {{0x6d4403bd,0xa8542077,0x6560952b,0xd75800f2}},	//   zhia, _скуч, anmh, _غلات_, 
   {{0x7998009f,0x7bddc14f,0x00000000,0x00000000}},	//   _kiuw, huqu, --, --, 
   {{0x7bdc0912,0x6d440211,0x6b4000fd,0xbcf802d2}},	//   kuqu, xhia, _möga, _sjén, 
   {{0xa3a805ba,0x6b41c150,0x7538009f,0xfd1c0051}},	//   _खूप_, _löga, mkuz, _phìn_, 
   {{0x7998045f,0x7538009a,0x6d440374,0x00000000}},	//   _liuw, lkuz, whia, --, 
   {{0x6d45c151,0x50b4df4b,0x847c0023,0x7bdc0051}},	//   thia, _испу, _ብድሙቕ_, euqu, 
   {{0x6d440d04,0x3204508d,0x75380223,0x00000000}},	//   uhia, _isny_, nkuz, --, 
   {{0x6d448a67,0x7bdc0928,0xdcec0fcf,0xfd1c004d}},	// [319c0] rhia, guqu, zlać, _thìn_, 
   {{0x6d45c152,0xdb580212,0x6b4001e3,0x7bc800e4}},	//   shia, нює_, _böga, âgua, 
   {{0x6d45c153,0xa3a86225,0x19a80220,0x75380083}},	//   phia, _खून_, етіп_, kkuz, 
   {{0x6d440cfe,0xbb300952,0xdcec01a6,0x7bddc154}},	//   qhia, ﺭﺍﻕ_, vlać, buqu, 
   {{0x799800f2,0x2730002e,0x00000000,0x00000000}},	//   _diuw, _sànq_, --, --, 
   {{0x32046ede,0x75380083,0x2480025c,0x00000000}},	//   _osny_, ekuz, _ġim_, --, 
   {{0x2d9c066d,0x248000da,0x49952e74,0x6b9c04e6}},	//   _éves_, _šim_, _ашат, _iirg, 
   {{0x6b9c01d9,0x602800e8,0x7c380327,0x9974004e}},	//   _hirg, _jëmë, _żuri, _бууш, 
   {{0x07a425fc,0x6b9dc155,0x46e80046,0xdcec3421}},	//   _разн, _kirg, _одан_, slać, 
   {{0xdcec0bb8,0x6b9c23db,0xbcf801e1,0x602800e8}},	//   plać, _jirg, _ajél, _lëmë, 
   {{0xf1ac1d1f,0x6b9c22a9,0x02682d29,0xa1582ff5}},	//   يءَ_, _mirg, ьший_, еану_, 
   {{0x7bdc0d04,0x965402e8,0x68e408c2,0x00000000}},	//   yuqu, _съуч, òidh, --, 
   {{0xa3d40131,0x7bdc0393,0x04c400ec,0x00000000}},	//   _солч, xuqu, _ٻوڙي_, --, 
   {{0x6b9dc156,0x2fc000a2,0xb4603ad0,0xf66c00d1}},	//   _nirg, _dwig_, _әкәл, ﺴﯩﮕﻪ_, 
   {{0x2fc1c157,0x602800e8,0x7bdc0b6f,0xa3a94dc5}},	//   _ewig_, _bëmë, wuqu, _खंड_, 
   {{0x7bdc18df,0x6b9c50c6,0xdb0c067c,0x6da406ed}},	//   tuqu, _airg, rpaí, риѓа, 
   {{0x6b9dc158,0x7999c159,0x18a41870,0xec3402e8}},	// [319d0] _birg, _riuw, қалм, анть, 
   {{0x6b9c008e,0x7bddc15a,0xdf3800ae,0x00000000}},	//   _cirg, ruqu, _أكدت_, --, 
   {{0x6b9dc15b,0x9e340408,0x7bdc0393,0x00000000}},	//   _dirg, _сенч, suqu, --, 
   {{0x7bdc02d1,0x6b9c01e7,0x41d80037,0x00000000}},	//   puqu, _eirg, _भिनस, --, 
   {{0x7bddc15c,0x6b9dc15d,0xb6a0036b,0xd6d800a8}},	//   ququ, _firg, қиқл, еӂе_, 
   {{0x6b9dc15e,0x7998000f,0x6b41c15f,0x2d8c00d0}},	//   _girg, _wiuw, _töga, čmeň_, 
   {{0xa3a80bb2,0xa2b80316,0x55f59a38,0x15f400ae}},	//   _खूब_, ोरन्, учлу, استح, 
   {{0xf3fd216b,0x97c40491,0x6b9dc160,0x20080418}},	//   ção_, _مقرو, _zirg, _osai_, 
   {{0xd174774d,0xc950008d,0x6b9c208d,0xf6e4035b}},	//   ғыны, _המן_, _yirg, _ацен, 
   {{0x75380316,0x2b1c0034,0xe73054ab,0x6b9c1887}},	//   skuz, नाएँ_, _وصل_, _xirg, 
   {{0x41b001b9,0x2fc00ea0,0xfd1c01e1,0x941003b9}},	//   یمیر, _swig_, _onì_, _əbəs_, 
   {{0xfd1c01e1,0x7bcc03b9,0x00000000,0x00000000}},	//   _nnì_, _ovcu, --, --, 
   {{0xb4dc0574,0xfd1c001e,0xe570007b,0x68e400a3}},	//   तली_, _chìm_, _بطل_, òidi, 
   {{0xe8e0726e,0x20080ac5,0x1f180014,0x91e41353}},	//   _पञ्च, _dsai_, نٹُک_, _боке, 
   {{0x16081ab2,0x9bb80135,0x2008603f,0x7bcc0205}},	//   विटर_, _བསྔོ, _esai_, _avcu, 
   {{0x41b00979,0x2fc03d19,0x6b9dc161,0xc2780375}},	//   _امير, _twig_, _sirg, _ארצי, 
   {{0x4c8439c6,0x6b9dc162,0x4b88010b,0xfd1c0051}},	// [319e0] улав, _pirg, ейан_, _ghìm_, 
   {{0xcb08ea80,0xfd1c01e1,0x6b9c01d5,0x8e080212}},	//   عيان_, _enì_, _qirg, _знов_, 
   {{0xaca401f2,0x6b9cda3c,0x4420063f,0x6b4001a8}},	//   _alụs, _virg, ̣k_, _fögn, 
   {{0xfaa0136b,0x6b400008,0xc7c427a8,0x07a40006}},	//   _ҳаро, _gögn, гски, гадн, 
   {{0x6b9dc163,0x2d81c164,0x4c345fd0,0x00000000}},	//   _tirg, mlie_, _сэнт, --, 
   {{0xfaa18504,0x6b9c16b8,0xbf9800d2,0x2d805277}},	//   _гаро, _uirg, jwêl, llie_, 
   {{0x2d81c165,0x2bc0190e,0x6b40007c,0xdb4c0244}},	//   olie_, शीरा, _högo, _تێل_, 
   {{0xa53557d0,0x2d810e2c,0x44282f5c,0x00000000}},	//   рнич, nlie_, ецом_, --, 
   {{0x6fa003e5,0x73d48087,0x75d000db,0xd9500345}},	//   _गंगू, гдыр_, _ۇيلا, _بۆنخ, 
   {{0x6b40014a,0x2d8069f5,0x00dc0150,0xa3a80073}},	//   _mögo, hlie_, _ﺃﻋﺘﻘ, _खूण_, 
   {{0xa5c5c166,0x97341513,0x3370010b,0x65b00345}},	//   _төле, _тэтч, сгэр, _بیبڕ, 
   {{0xa159c167,0x200800d8,0x7410030f,0xa9280171}},	//   таму_, _psai_, _گوها, bežš, 
   {{0x2d81c168,0xf3d401f7,0x6b41c169,0x343400f1}},	//   dlie_, _مونث_, _rögn, _مسود_, 
   {{0xa294242f,0x2d806c2b,0x8c080154,0x22941eca}},	//   _калі, elie_, রমান_, _киля, 
   {{0x23d4012c,0x3d88020f,0x9f5c01e1,0x00000000}},	//   _दिँद, ещан_, _èwí_, --, 
   {{0x2d81c16a,0x20080c09,0x00000000,0x00000000}},	//   glie_, _tsai_, --, --, 
   {{0x2009c16b,0x5c980962,0x50580014,0x3f64059e}},	// [319f0] _usai_, ткая_, _لٔٹس_, _مادّ, 
   {{0x9d540214,0xac9402dd,0x7e280024,0x00000000}},	//   _چندت, сауш, _зіма_, --, 
   {{0x2d81c16c,0x63a40395,0xc6640092,0x00000000}},	//   blie_, _èinf, ትራሊያ_, --, 
   {{0x645c2523,0xfd1ced9b,0x6b4001e6,0x2d8001ab}},	//   şriy, _unì_, _högl, clie_, 
   {{0x9bb80003,0xd825c16d,0x00000000,0x00000000}},	//   _བསྒོ, рдли, --, --, 
   {{0xdcb0005e,0x7d0c367d,0x00000000,0x00000000}},	//   _دىڭ_, _hacs, --, --, 
   {{0x6b4009f0,0x7d0c121e,0xf1d00316,0xdcfc00b8}},	//   _mögl, _kacs, _थिइन, _nisī, 
   {{0xb4dc0be7,0x6b4001a8,0x00000000,0x00000000}},	//   तले_, _lögl, --, --, 
   {{0x9345c16e,0xa3dc069f,0x7d0dc16f,0x6ab40098}},	//   иние, तंग_, _macs, _éffé, 
   {{0x6b41c170,0x81c000ef,0x00000000,0x00000000}},	//   _nögl, _ķēro, --, --, 
   {{0x2d80920e,0x516403c5,0x00000000,0x00000000}},	//   ylie_, ивоб, --, --, 
   {{0x7d0d7cd1,0x661c00e5,0xae1404af,0x6e080022}},	//   _nacs, _árka, डिसन_, ҳҭом_, 
   {{0x8fa5c171,0xfeb4009e,0x221400c7,0x4fa402e8}},	//   раге, _জয়ধ, _ҳфыр, ригв, 
   {{0x9bb8081f,0x8f740a4a,0x2d8001ab,0x90d400f2}},	//   _བསྟོ, румі, wlie_, دآگا, 
   {{0x7d0dc172,0x3cb002e3,0x6b8001c7,0x8d542081}},	//   _bacs, _ụzụ_, _ëmgi, атач, 
   {{0xc1840014,0x00000000,0x00000000,0x00000000}},	//   _پدى۪, --, --, --, 
   {{0x2d81c173,0x6da404a9,0x6b4007c5,0x0ae80440}},	// [31a00] rlie_, риға, _fögl, кдай_, 
   {{0x2d813bd2,0x6b4029ef,0x7d0c01e7,0x34b01116}},	//   slie_, _vögo, _eacs, ीरुद, 
   {{0x2d81c174,0x88c80104,0xf1a809bb,0x7bc803b2}},	//   plie_, влев_, _घूमन, águr, 
   {{0x7d0c102c,0x387c03b2,0xb4dcd5ce,0x8d74178c}},	//   _gacs, _byur_, तलो_, _خاخا, 
   {{0x6b4001e3,0x27f80066,0x00000000,0x00000000}},	//   _högm, افتد_, --, --, 
   {{0x387c0055,0xee500022,0x7d0c00e5,0x00000000}},	//   _dyur_, hẽma_, _zacs, --, 
   {{0x96b80228,0x7d0c011f,0x8624a5de,0x00000000}},	//   уучу_, _yacs, рьле, --, 
   {{0x2b5832a7,0x00000000,0x00000000,0x00000000}},	//   _hmrc_, --, --, --, 
   {{0xc34806bb,0xa41400bd,0x6b400008,0x387c00b8}},	//   вяне_, িহ্য_, _lögm, _gyur_, 
   {{0xa8883e25,0xe2980133,0x7c280254,0x00000000}},	//   _айға_, هێشت_, ägri, --, 
   {{0x6b4001e6,0xdbd00252,0x366401f0,0x7f740092}},	//   _rögl, _lýðv, _кафо_, _በሶማሌ_, 
   {{0x85540608,0x6e3c03cd,0xdcfc0171,0x00000000}},	//   _خیبر_, dyrb, _visī, --, 
   {{0x838400db,0xa3b41cd0,0xe2f8dcc6,0x00000000}},	//   _кыке, _ублі, _белі_, --, 
   {{0x7d0dc175,0xbcf8032e,0x00000000,0x00000000}},	//   _sacs, _tjék, --, --, 
   {{0x5d643306,0x6b400c86,0xdb0d63c1,0xf1d0012c}},	//   مُسْ, _vögl, lpaç, _थिएन, 
   {{0x7c85c176,0x527400cf,0x00000000,0x00000000}},	//   аузе, _уучу, --, --, 
   {{0xdfd1c177,0xfaa40ca4,0x63a40395,0x30341ee3}},	// [31a10] _عيد_, ашен, _èind, _меъё, 
   {{0x7de40220,0xae1401ad,0x00000000,0x00000000}},	//   _кімд, डिशन_, --, --, 
   {{0x3f800bb8,0x7d0dc178,0x387dc179,0x69d80024}},	//   mlju_, _tacs, _syur_, šven, 
   {{0xfca80d17,0x3f813db8,0x97c408de,0x00000000}},	//   _جادو_, llju_, مقصو, --, 
   {{0x3f800162,0x00000000,0x00000000,0x00000000}},	//   olju_, --, --, --, 
   {{0x3f800b21,0xae142099,0x6b4002d2,0x00000000}},	//   nlju_, _اذیت, _lögj, --, 
   {{0xbcf80022,0x00000000,0x00000000,0x00000000}},	//   _ajéi, --, --, --, 
   {{0x9bb80135,0x7bdd1594,0xd7c88863,0x8a78014b}},	//   _བསྙོ, orqu, _موره_, _сисӣ_, 
   {{0x27e001c3,0x387c03e0,0xee5000e4,0x02e00210}},	//   àint_, _uyur_, vẽma_, पलून, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3f800841,0x543400f1,0x00000000,0x00000000}},	//   dlju_, شرکر, --, --, 
   {{0x6458012d,0x51540108,0x00000000,0x00000000}},	//   _ściś, ётну, --, --, 
   {{0x257002dd,0xd0580212,0x6b4000a2,0x00000000}},	//   _تۇيس, урні_, _sögm, --, 
   {{0x9344084c,0x3f800010,0x6e3c143a,0xee500022}},	//   _ынле, glju_, tyrb, sẽma_, 
   {{0x629c01a8,0x00000000,0x00000000,0x00000000}},	//   þrot, --, --, --, 
   {{0x90c414a4,0x2b5801a6,0xa3dc0073,0x4234011a}},	//   _убие, _smrc_, तंच_, _לנצל_, 
   {{0x3f80071b,0x4fe807d6,0x0ba80137,0x6d580024}},	// [31a20] blju_, _ёмон_, اارى_, _įvad, 
   {{0x4f08004e,0x00000000,0x00000000,0x00000000}},	//   _снон_, --, --, --, 
   {{0xda6405d9,0x63a40120,0x6b4001e6,0x7bdcc204}},	//   يامي, _éinv, _högk, arqu, 
   {{0x7ae0068c,0x00000000,0x00000000,0x00000000}},	//   òntr, --, --, --, 
   {{0x26c80058,0xbcf801e1,0x9f5801e3,0xdcec013d}},	//   иған_, _ajéw, rvsö_, llağ, 
   {{0x97a40046,0x07a40022,0xa3a80073,0x273400db}},	//   іріл, _ҳаан, _खूष_, تىتس, 
   {{0xd6d96689,0x68e401c3,0x7ae000c7,0x65940fac}},	//   рті_, òids, ónte, оаку, 
   {{0x248c0023,0x07a4009d,0x16140116,0x00000000}},	//   _ቕትለት_, _гаан, زسىڭ, --, 
   {{0xe6d80133,0x00000000,0x00000000,0x00000000}},	//   _نداڵ_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3f8004b9,0x2e1802e2,0xdb0c00d8,0x623400d8}},	//   vlju_, _nčf_, spaç, цену, 
   {{0x637407de,0x6b40007c,0xdcec0139,0x00000000}},	//   nànz, _bögk, dlağ, --, 
   {{0xc0580220,0x3f80110c,0x049400c6,0x00000000}},	//   уін_, tlju_, _الشح, --, 
   {{0x3f800a85,0x2e1802e2,0xf1f41968,0x60980014}},	//   ulju_, _bčf_, جعیت_, ُنگس_, 
   {{0x3f80045f,0x69d917b7,0x00000000,0x00000000}},	//   rlju_, ável, --, --, 
   {{0xdcb856f6,0x6b400267,0xe0d00014,0x3f800427}},	//   ргач_, _högh, _کٲک_, slju_, 
   {{0xfd4c07ae,0x3f800960,0x637407c5,0xee5000c7}},	// [31a30] _khiế, plju_, dànz, hẽha_, 
   {{0x7bdc0327,0xdcec294f,0x00000000,0x00000000}},	//   rrqu, blağ, --, --, 
   {{0x637404cc,0xd75800e5,0x00000000,0x00000000}},	//   fànz, یجتا_, --, --, 
   {{0xbcf80022,0x6b4008a5,0x2bc405dc,0x00000000}},	//   _ajév, _lögh, _लौका, --, 
   {{0x27300109,0x4ae00073,0x1798005b,0x00000000}},	//   _hàny_, _पाचव, авды_, --, 
   {{0xfd4c001e,0xdcec1710,0x79a40064,0x07140037}},	//   _nhiế, mlađ, _грае, _धोआव_, 
   {{0x39540b82,0x00000000,0x00000000,0x00000000}},	//   ላማውያ, --, --, --, 
   {{0x637407c5,0x00000000,0x00000000,0x00000000}},	//   cànz, --, --, --, 
   {{0x142402bf,0x68e47e9b,0x00000000,0x00000000}},	//   ідом, óide, --, --, 
   {{0xfd4c01dc,0x27e000c6,0xd6d06bcc,0xd29800d4}},	//   _chiế, áine_, _آقا_, итні_, 
   {{0xdcfc01e4,0xdcec1674,0x6d48005f,0xf6442472}},	//   _eksĉ, hlađ, ūdai, _ухан, 
   {{0xdcec39ca,0x64c400ec,0x515401ca,0x00000000}},	//   klađ, _فيمل, ітну, --, 
   {{0xe5081541,0x00000000,0x00000000,0x00000000}},	//   _دينو_, --, --, --, 
   {{0xdea001d3,0xfd4c0051,0xa488009f,0xc7b0011a}},	//   کیپی, _ghiế, _اَهل_, ובך_, 
   {{0x28cc0882,0xbea1c17a,0x8d59c17b,0x3ea04cd0}},	//   ारमि, дарк, ашат_, дирг, 
   {{0x63a4011c,0x1e94010b,0xfe4000d4,0x00000000}},	//   _èinc, яряр, єнто, --, 
   {{0xfd1c001e,0xdcedc17c,0x63a40798,0x637404cc}},	// [31a40] _nhìu_, slağ, _éint, vànz, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2d8dc17d,0x4e29c17e,0x637405d5,0x00000000}},	//   ïdes_, _тонн_, tànz, --, 
   {{0x6b40014a,0x996401ec,0x88840229,0xee5000c7}},	//   _mögi, птіл, олеж, vẽha_, 
   {{0x38c834c9,0xd90c3faa,0x8308025c,0x6b41c17f}},	//   شانی_, دیق_, _ཀྲའུ_, _lögi, 
   {{0xd04c03be,0x6d45c180,0x6374007f,0xdcec0135}},	//   ükəs, lkia, bàny, mmaġ, 
   {{0xfa649931,0x454808da,0xe4f82894,0x00000000}},	//   _дарк_, ичим_, ्जलि_, --, 
   {{0x6d440953,0xd90c397a,0x00000000,0x00000000}},	//   nkia, _میم_, --, --, 
   {{0xfd4c0016,0x6d45c181,0x00000000,0x00000000}},	//   _phiế, ikia, --, --, 
   {{0x85040753,0x6b40007c,0xee5000e4,0xc21800d4}},	//   _ژوان, _bögi, pẽha_, аєм_, 
   {{0x6d45c182,0x26cc0286,0x973000e5,0x00000000}},	//   kkia, _iedo_, _سکوا, --, 
   {{0x273006d9,0x03a4013e,0x166401f7,0x00000000}},	//   _ràny_, _дидо, _عالَ, --, 
   {{0xfd4c01dc,0x26cdc183,0x6560004c,0x6d4401e4}},	//   _thiế, _kedo_, mimh, dkia, 
   {{0x6b4001b8,0x57b80046,0xf4848341,0x26cdc184}},	//   _fögi, ﻧﺪﯨﺮ, _بامی, _jedo_, 
   {{0x26cdc185,0x6441c186,0xee842401,0x6560464c}},	//   _medo_, lymi, дыто, oimh, 
   {{0x26cdc187,0x61e9c188,0x1bb40006,0xa14801d3}},	//   _ledo_, mudl, збаў, _دستے_, 
   {{0x61e9c189,0x63a400d8,0x656000a3,0x00000000}},	// [31a50] ludl, _éins, iimh, --, 
   {{0x60cdc18a,0x6561c18b,0x26cc05be,0xbcf98a05}},	//   _heam, himh, _nedo_, _omég, 
   {{0x61e851e2,0xdcec0552,0x6560009f,0xd9f800d8}},	//   nudl, slađ, kimh, снец_, 
   {{0x60cdc18c,0x6d45c18d,0x6440005b,0x00000000}},	//   _jeam, ckia, kymi, --, 
   {{0x9b600058,0x61e9c18e,0x60cdc18f,0x26cc4a16}},	//   _كۆرۈ, hudl, _meam, _bedo_, 
   {{0x61e82a6c,0x60cc35ab,0x26cdc190,0xdb1c025a}},	//   kudl, _leam, _cedo_, âyäk, 
   {{0x61e9c191,0x64400076,0x65600327,0x3fac1884}},	//   judl, eymi, fimh, ﻳﺪﺍﻧ, 
   {{0x60ccd2bb,0x61e940f2,0xf9900014,0x26cdc192}},	//   _neam, dudl, _آبس_, _eedo_, 
   {{0xb4b82007,0xb4a8375c,0x644001d3,0x00000000}},	//   _अभी_, _खली_, gymi, --, 
   {{0x60cc0421,0x6d4405f5,0x36a00075,0x26cc01d9}},	//   _aeam, zkia, _قەشق, _gedo_, 
   {{0x6d45c193,0x61e9c194,0x1d48001f,0x60cdc195}},	//   ykia, gudl, _መገንዘ, _beam, 
   {{0x64400649,0x26cc1529,0x60cc00c6,0x059400f2}},	//   bymi, _zedo_, _ceam, _فانگ, 
   {{0x60cc45bc,0xcfb4005b,0xb46400f2,0xe1f801f0}},	//   _deam, ящны, _بداه, бгӯ_, 
   {{0x61e80af2,0xb4a80a28,0x6b4001e3,0x00000000}},	//   budl, _खलु_, _högv, --, 
   {{0x60cdc196,0x74102354,0x6d4402fc,0x61e806be}},	//   _feam, _روژا, tkia, cudl, 
   {{0x60cdc197,0x6d440006,0xfeb00166,0x00000000}},	//   _geam, ukia, _җөрь, --, 
   {{0x6d45c198,0x9f480295,0x945dc199,0x00000000}},	// [31a60] rkia, _epañ_, mańs, --, 
   {{0xbcf8ed9b,0x6d45c19a,0x8ee802bf,0x60cdc19b}},	//   _améd, skia, _умов_, _zeam, 
   {{0x6d9801e4,0x6441c19c,0x60cdc19d,0x7ae1c19e}},	//   _dŭar, zymi, _yeam, ónta, 
   {{0x26cd5593,0x4c68b5ff,0x64400108,0x25ac01ef}},	//   _sedo_, _гимн_, yymi, _rudl_, 
   {{0x26cdc19f,0x61e801f0,0x6440037e,0xdc8002dd}},	//   _pedo_, zudl, xymi, _ақто, 
   {{0xdb4c04d3,0x644000d0,0x25ac013a,0xf6d000d1}},	//   _پێم_, vymi, _pudl_, ىزىد, 
   {{0x26cdc1a0,0x64414a52,0x945c0034,0xa9b400f2}},	//   _vedo_, wymi, kańs, _آلرژ, 
   {{0x6441c1a1,0x61e82d62,0x26cc020c,0x945c033f}},	//   tymi, vudl, _wedo_, jańs, 
   {{0x60cdc1a2,0x61e89c78,0x6561c1a3,0x26cdc1a4}},	//   _ream, wudl, rimh, _tedo_, 
   {{0x60cdc1a5,0x6561c1a6,0x61e894da,0x7dec016b}},	//   _seam, simh, tudl, _wɔsɛ, 
   {{0x60cc007d,0x6728003d,0x04c81671,0x644168a2}},	//   _peam, _indj, _هواي_, symi, 
   {{0x6440005b,0x945c012d,0x6560047e,0x00000000}},	//   pymi, gańs, qimh, --, 
   {{0x60cdc1a7,0x61e9c1a8,0x6b4036d5,0xb9780375}},	//   _veam, sudl, _högu, מנטי, 
   {{0x60cc004c,0x6b40032e,0x00000000,0x00000000}},	//   _weam, _kögu, --, --, 
   {{0x60cdc1a9,0x945c012d,0x00000000,0x00000000}},	//   _team, bańs, --, --, 
   {{0x6b40008c,0x2d58e3dd,0xfe7401c4,0x00000000}},	//   _mögu, пись_, жүү_, --, 
   {{0x5b15c1aa,0x6b40008c,0x2128102c,0x67281e31}},	// [31a70] ммат, _lögu, _inah_, _ondj, 
   {{0x8308031c,0xf7a41884,0x39840254,0x3ec400cf}},	//   _ཀིསུ_, ﺷﻪﻧﺪ, põsk_, _эсиб, 
   {{0xaa88007b,0x4ef8011a,0xe8940022,0x00000000}},	//   كنكم_, _והתו, ҭахь, --, 
   {{0xbcf9c1ab,0x6728009b,0x00000000,0x00000000}},	//   _ejér, _andj, --, --, 
   {{0x16a9c1ac,0x68e424b0,0x7c642824,0x7c84010a}},	//   овли_, óida, _راحل, _хуне, 
   {{0x6b4002d2,0x945d8b56,0x00000000,0x00000000}},	//   _bögu, zańs, --, --, 
   {{0x945c0227,0x21280c6a,0xe6b401d5,0x27e00003}},	//   yańs, _onah_, رليگ, ġina_, 
   {{0x6b40008c,0xf9903f0b,0x21280429,0x142402a9}},	//   _dögu, _سبز_, _nnah_, ддим, 
   {{0x395dc1ad,0xc0d402d3,0x56f406ed,0x00000000}},	//   _imus_, _ክሳራ_, _опаѓ, --, 
   {{0x2128b7e6,0x6b4008a5,0x00000000,0x00000000}},	//   _anah_, _fögu, --, --, 
   {{0x7760e74c,0x69d001ad,0x6f0c0213,0x945c012d}},	//   minx, डीपी, _öncə, tańs, 
   {{0x69d9c1ae,0x76400209,0x6b40049f,0x21280c6a}},	//   ávei, myny, _högt, _cnah_, 
   {{0x7641bbc3,0x657c01d3,0xcf24131e,0x945c0210}},	//   lyny, _írha, ورسي, rańs, 
   {{0x21280134,0x15780a81,0xb8dc025c,0x77600077}},	//   _enah_, _أچھ_, _གཅ_, ninx, 
   {{0x76400209,0x945c033f,0xdef802d5,0xcd280451}},	//   nyny, pańs, чыў_, يسرن_, 
   {{0x776000ad,0x6b4002d2,0x00000000,0x00000000}},	//   hinx, _lögt, --, --, 
   {{0x40b40050,0x3160a69d,0x7760022e,0x4c8400f3}},	// [31a80] _تھپھ_, _imiz_, kinx, флав, 
   {{0x7640da8f,0x395c56b5,0xef9412e9,0x00000000}},	//   kyny, _amus_, _سیزد, --, 
   {{0x7760005a,0x90440214,0x987400e2,0x31600139}},	//   dinx, _رنگه, _eļļa_, _kmiz_, 
   {{0x7641c1af,0x395c0005,0xbca00873,0x8c45c1b0}},	//   dyny, _cmus_, رمەي, _жеме, 
   {{0x6b40008c,0x4ba000d1,0x776078aa,0x0ae81e5a}},	//   _sögu, _аһаң, finx, _ورسي_, 
   {{0x395dc1b1,0xbf98017a,0x2d800363,0x76406c26}},	//   _emus_, lwêr, loie_, fyny, 
   {{0x764009a5,0xda6400c6,0xd90c0cbe,0x26c00115}},	//   gyny, _كافي, _گین_, ĝio_, 
   {{0x2d81c1b2,0xbf98017a,0x3ea400c7,0x26c000df}},	//   noie_, nwêr, _únte_, ŝio_, 
   {{0xdc1000ac,0x7640062c,0xa82401e0,0xed5c0051}},	//   _məğl, ayny, _язаһ, _đốt_, 
   {{0x76405452,0x316001d5,0x28cc0c00,0x7760003a}},	//   byny, _amiz_, ारवि, cinx, 
   {{0x6b4004f3,0x21280a2e,0xbf98017a,0x8174013e}},	//   _högs, _pnah_, kwêr, данӣ_, 
   {{0x0565c1b3,0x2d806ede,0x00000000,0x00000000}},	//   _ювен, joie_, --, --, 
   {{0x63a4011c,0xdcfc025c,0x705806d3,0x00000000}},	//   _èino, _nisġ, даяр_, --, 
   {{0xbcf800c7,0x0f703452,0x00000000,0x00000000}},	//   _ajép, лғыр, --, --, 
   {{0x3da40953,0xbf980af9,0x6b4001a8,0x00000000}},	//   драб, fwêr, _lögs, --, 
   {{0x21f83386,0x77600944,0x21280098,0xbf98017a}},	//   méh_, zinx, _unah_, gwêr, 
   {{0x301407dd,0x764000ee,0x7760004b,0x21f80438}},	// [31a90] _адыр, zyny, yinx, léh_, 
   {{0x6ec00490,0xb4b80d2c,0xac9402dd,0x68e401e7}},	//   वडणु, _अभ्_, тауш, óidn, 
   {{0x21f81dd4,0xab844f6d,0x1a6400dd,0x27e00597}},	//   néh_, тутк, ریری_, áinn_, 
   {{0x77600054,0x0e980375,0xea000051,0x7bc800e4}},	//   winx, _משתל, _giập_, âgus, 
   {{0xd7040209,0xbc640014,0x21f80c6a,0x77600381}},	//   езли, _غۅطن_, héh_, tinx, 
   {{0x7641c1b4,0xf77008f4,0xe7e007d0,0x21f8525e}},	//   tyny, خاص_, _निरप, kéh_, 
   {{0x7761c1b5,0x6a14016c,0x6b4004cc,0x21f8003e}},	//   rinx, _имру, _vögt, jéh_, 
   {{0x76400510,0x77600944,0x21f9c1b6,0x395c003a}},	//   ryny, sinx, déh_, _umus_, 
   {{0x76400510,0x998401ed,0x31600100,0x77600393}},	//   syny, _élő_, _rmiz_, pinx, 
   {{0x6b4004f3,0x7640010b,0xf7700736,0x79880042}},	//   _högr, pyny, _شاذ_, llgw, 
   {{0x21f8525e,0x3160022e,0x2d800083,0xbf98017a}},	//   géh_, _pmiz_, yoie_, ywêr, 
   {{0xc6900a7c,0x069402dd,0xab64010b,0x00000000}},	//   _גאב_, _ﺀﻭﻣﯩ, mmüş, --, 
   {{0x2d81c1b7,0xab641ae4,0x6b400139,0x00000000}},	//   voie_, lmüş, _mögr, --, 
   {{0x6b40008c,0x21f83386,0x00000000,0x00000000}},	//   _lögr, béh_, --, --, 
   {{0x78b80607,0x2214035b,0x21f8065c,0x2d817a02}},	//   _ofuv, _афыр, céh_, toie_, 
   {{0x30240124,0x1de01098,0x3da400d8,0x00000000}},	//   _азиҳ, _फिरत, ексо_, --, 
   {{0x8f681fd4,0xbf980ea0,0x2d800363,0x8b2401f0}},	// [31aa0] _наиб_, rwêr, roie_, ндае, 
   {{0x2d80011c,0xaca4063f,0xbf980ea0,0x95180327}},	//   soie_, _nzụt, swêr, _ྱིའི_, 
   {{0x752802d0,0x6b40b743,0x00000000,0x00000000}},	//   _ongz, _bögr, --, --, 
   {{0xaca402e3,0x00000000,0x00000000,0x00000000}},	//   _azụt, --, --, --, 
   {{0x2bd81518,0x7c30022e,0x00000000,0x00000000}},	//   _تاجک_, _беўх, --, --, 
   {{0x27e1c1b8,0x752802d0,0x21f80c6a,0xd5b00051}},	//   šino_, _angz, yéh_, _bú_, 
   {{0x2fc001d5,0x6b4008a5,0xd5b00051,0x36840395}},	//   _ltig_, _fögr, _cú_, нсън_, 
   {{0x69dd3e9b,0xdb1c007f,0x85b801ed,0x03c401af}},	//   _ivre, _atsè, _ہاؤس_, нсом, 
   {{0xb60000da,0x69dc0165,0x21f80264,0xe8cc044b}},	//   āšan, _hvre, wéh_, ारीच, 
   {{0xefc4044e,0x77803667,0x68e00036,0x46a402bf}},	//   ኻየደ_, _блуз, _hdmd, _зазв, 
   {{0x2fc00042,0xd90c0133,0x6b400139,0x22580108}},	//   _atig_, _دیۆ_, _yögr, фины_, 
   {{0xd04400ac,0x21f80438,0x00000000,0x00000000}},	//   lakə, réh_, --, --, 
   {{0x21f8525e,0xe2f802dd,0x133801d3,0x4430010e}},	//   séh_, _желі_, ستیں_, _çy_, 
   {{0x69dc4a1f,0x2fc000ae,0x21f80098,0xd1e40092}},	//   _ovre, _dtig_, péh_, ማለች_, 
   {{0xdcfc025c,0xa2780108,0xefc40023,0x00000000}},	//   _jisħ, _юбку_, ኻየዱ_, --, 
   {{0x3ce800e1,0xdcfc031c,0x00000000,0x00000000}},	//   टलें_, _misħ, --, --, 
   {{0x69ddc1b9,0x31740419,0x00000000,0x00000000}},	// [31ab0] _avre, ťazí_, --, --, 
   {{0x2904000f,0x2009c1ba,0x64c400bc,0x00000000}},	//   _abma_, _ipai_, lčič, --, 
   {{0x78b80564,0xdcfdc1bb,0x69dc0010,0xf2d000df}},	//   _pfuv, _eksā, _cvre, רעע_, 
   {{0x3f81c1bc,0x64c40dfe,0x2139c1bd,0x00000000}},	//   loju_, nčič, njsh_, --, 
   {{0x69dd8649,0x37a9c1be,0xa2b8012c,0x9c6422e0}},	//   _evre, чтен_, ोरञ्, _شهسو, 
   {{0xeff4010c,0x3f8056ce,0xa95803e6,0xc840010b}},	//   _ልባዊ_, noju_, وجۆر_, решй, 
   {{0xda047db3,0x46108688,0xaa95c1bf,0x80b4009e}},	//   _रहित_, لوور, _бирч, _অজন্, 
   {{0xab641ae4,0x200800e4,0x6b4001e3,0xd5b00051}},	//   rmüş, _opai_, _högp, _vú_, 
   {{0x3f81c1c0,0x57f41d5b,0x00000000,0x00000000}},	//   koju_, _шпат, --, --, 
   {{0x3f800024,0xda040073,0x2fc00064,0xd5b00051}},	//   joju_, _रहात_, _rtig_, _tú_, 
   {{0x2fc00a37,0x20081132,0x3f802ba4,0x7bcc03cb}},	//   _stig_, _apai_, doju_, _lwcu, 
   {{0x504415ed,0x7528009a,0x7ae000d2,0x6b4002d2}},	//   вемб, _ungz, óntj, _lögp, 
   {{0x2008070d,0x61e9c1c1,0xc8d8011a,0x65943163}},	//   _cpai_, ardl, וקרט, _сацу, 
   {{0xdf1410f5,0x3f802630,0x66140209,0xe3b000e3}},	//   льсь, goju_, _çeký, _طره_, 
   {{0x20083d81,0xbcf8007b,0xb64000b5,0x64a40022}},	//   _epai_, _sméa, _ｏｓ_, _ишәз, 
   {{0xd0241058,0x00000000,0x00000000,0x00000000}},	//   _амий, --, --, --, 
   {{0xc4d004ac,0xa2b80073,0x6b40007c,0xc0dc0023}},	// [31ac0] יגן_, ोरच्, _bögp, ንኦም_, 
   {{0x4e280137,0x8fa400f3,0xf3f000fe,0x00000000}},	//   _жоон_, _шапе, _অনাৰ_, --, 
   {{0xbcf80124,0x00000000,0x00000000,0x00000000}},	//   _imén, --, --, --, 
   {{0x69dc00d7,0x48640395,0x00000000,0x00000000}},	//   _vvre, кълб, --, --, 
   {{0x8ba40032,0x660801bf,0x00000000,0x00000000}},	//   _аҙаҡ_, _spdk, --, --, 
   {{0xbcf8038e,0x69d80e96,0x8a0429db,0x69dc0165}},	//   _jmén, áves, _изге, _tvre, 
   {{0x69dc2d2b,0x290401ab,0x68e00327,0xf7401fbe}},	//   _uvre, _tbma_, _tdmd, рејо, 
   {{0x6e28007c,0x00000000,0x00000000,0x00000000}},	//   ädby, --, --, --, 
   {{0xbcf800e4,0x64c40427,0x597401f4,0x00000000}},	//   _omén, včič, _сыру, --, 
   {{0xdcfc0003,0x69c80003,0x61e80427,0x00000000}},	//   _tisħ, _ħdej, trdl, --, 
   {{0x3f81c1c2,0xa6d804c5,0x85040066,0x61e80254}},	//   voju_, _সাপট, _لوان, urdl, 
   {{0xbcf9c1c3,0xfd1c01e1,0x04486a27,0x100c00bc}},	//   _amén, _akìn_, _опек_, िबंश_, 
   {{0xc0a88bf0,0x3f81c1c4,0xfd103321,0x3014010b}},	//   بادل_, toju_, یجر_, адяр, 
   {{0x3f800153,0xfe7006c2,0x60c80588,0xc028000d}},	//   uoju_, لدز_, ñemb, _रहs_, 
   {{0x3f81c1c5,0xdbd0010b,0x94700133,0x64c40219}},	//   roju_, _düýe, _نگیا, pčič, 
   {{0x4425c1c6,0xf1a479ac,0x00000000,0x00000000}},	//   _kro_, _крын, --, --, 
   {{0x4424020c,0x27e02230,0x69d002ab,0x6bd4036b}},	// [31ad0] _jro_, šinj_, डीसी, لتلر, 
   {{0x4425c1c7,0x9e34009b,0x1f140153,0x00000000}},	//   _mro_, _беоч, _смоў, --, 
   {{0xfaa5c1c8,0x442401e4,0x4de8000d,0x00000000}},	//   тшан, _lro_, _छियै_, --, 
   {{0x4425c1c9,0xbf980b21,0x2d6805d2,0x00000000}},	//   _oro_, stêd, lşen_, --, 
   {{0x4425c1ca,0x69d9c1cb,0xe7082002,0xd708104e}},	//   _nro_, áver, چتىن_, енле_, 
   {{0xdcec08a4,0xdbd0000d,0x00000000,0x00000000}},	//   inač, _müüe, --, --, 
   {{0x4425c1cc,0x69d80e04,0x39a40166,0xdbd0000d}},	//   _aro_, šver, _ашав, _lüüe, 
   {{0x4425c1cd,0xdb0dc1ce,0xe6100330,0x52bc28d4}},	//   _bro_, mpañ, تشه_, ोर्स, 
   {{0x4425c1cf,0x2d8c0605,0x7d180077,0x79980ca8}},	//   _cro_, _ɔde_, _óusu, _ihuw, 
   {{0xdcec0989,0x4425c1d0,0xe7846c48,0x00000000}},	//   dnač, _dro_, _кухо, --, 
   {{0x7998fbf2,0xdb0dc1d1,0x99b003d4,0x23340022}},	//   _khuw, npañ, _চবুক, рхыр, 
   {{0x4425c1d2,0xdbd0010e,0x00000000,0x00000000}},	//   _fro_, _süýe, --, --, 
   {{0x4425c1d3,0x79980003,0xe7080150,0x437000ec}},	//   _gro_, _mhuw, _ستەن_, _گهور, 
   {{0xd6e4015b,0x224c00e5,0x00000000,0x00000000}},	//   প্রয, ökké_, --, --, 
   {{0x44240489,0x0d2000cf,0x00000000,0x00000000}},	//   _zro_, бүнү, --, --, 
   {{0xe6d01cba,0x7539c1d4,0x44240022,0x799801e1}},	//   _सज्ज, njuz, _yro_, _nhuw, 
   {{0x4424003a,0x0c25c1d5,0x5cd40150,0x00000000}},	// [31ae0] _xro_, ыман, рісх, --, 
   {{0x7999c1d6,0xd1bc001f,0x27e00010,0xe8cc00cd}},	//   _ahuw, _ተረት_, šink_, ार्च, 
   {{0x65bc0124,0x55f403d4,0xda6400f1,0x49c8011c}},	//   _oĩha, চবুক_, ټالي, хлен_, 
   {{0x7999c1d7,0x75380a49,0x00000000,0x00000000}},	//   _chuw, jjuz, --, --, 
   {{0x79980502,0xdb0c00e4,0x75380327,0x499401ec}},	//   _dhuw, apañ, djuz, _ұшат, 
   {{0x4425c1d8,0x79980099,0x03c4020a,0x00000000}},	//   _rro_, _ehuw, қсим, --, 
   {{0xdcecf2c9,0x63a4011c,0x69342418,0xdb0c0d12}},	//   znač, _èini, _پکار, mpað, 
   {{0x4425c1d9,0x79980455,0x7538025c,0x00000000}},	//   _pro_, _ghuw, gjuz, --, 
   {{0x06f5014d,0x44241ada,0xd5b86240,0x324c0092}},	//   _مساج, _qro_, нсө_, _ይመረጣ, 
   {{0x442403bd,0xbcf9c1da,0x79980099,0x07a4026a}},	//   _vro_, _amél, _zhuw, _сазн, 
   {{0xe135c1db,0xa2941fe2,0x22943c85,0x75380083}},	//   анны, рані, риня, bjuz, 
   {{0x25a000a3,0xdcec00d0,0xdbd0000d,0x4425047d}},	//   _òil_, tnač, _püüe, _مرتف, 
   {{0x44240fb7,0x82a46215,0xa3d54e69,0x00000000}},	//   _uro_, _өшке, _толч, --, 
   {{0xf3e00014,0xe5a40116,0x11f401d5,0xdcec0010}},	//   _آوُ, _сиҗи, دتیگ, rnač, 
   {{0x41e5c1dc,0xb2b802e4,0x1b1c0011,0x2d680bbc}},	//   _إستف, _אמור, নামে_, rşen_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x799802b9,0x6b9c0055,0xdb0c353d,0x00000000}},	// [31af0] _rhuw, _bhrg, wpañ, --, 
   {{0x7999c1dd,0x98b805d1,0x00000000,0x00000000}},	//   _shuw, _ısı_, --, --, 
   {{0x9e35c1de,0xda1406ed,0xdd95c1df,0x00000000}},	//   _тенч, рдењ, _ваны, --, 
   {{0x7c84008e,0x6b9c0e78,0x25f80073,0x9f5801e7}},	//   _буге, _ehrg, ईंनी_, itsí_, 
   {{0x5fb401ad,0xdb0d3a9e,0x00c80150,0x9f5c0248}},	//   ंदिल, spañ, _ﺒﺘﺤﻘ, _èwó_, 
   {{0x6d580953,0xfd1c0ffb,0x629814b2,0x67000073}},	//   _įvai, _haì_, _ozvo, ल्लक_, 
   {{0xb8d803f4,0xeef80375,0x2d680139,0x00000000}},	//   _আজ_, אמור_, kşel_, --, 
   {{0x7bddc1e0,0xf1c42097,0x1545c1e1,0x549400d1}},	//   osqu, ққий_, реим, _ﮔﻪﺭﭼ, 
   {{0x7bddc1e2,0xdbd00598,0xfd1c026c,0x6935c1e3}},	//   nsqu, _küñe, _maì_, _унту, 
   {{0x7bddc1e4,0x324c0092,0x00000000,0x00000000}},	//   isqu, _ይመርጣ, --, --, 
   {{0x527435ce,0x00000000,0x00000000,0x00000000}},	//   рупу, --, --, --, 
   {{0x62980099,0x0eec0037,0x00000000,0x00000000}},	//   _dzvo, जल्स_, --, --, 
   {{0xb4c00cf1,0x629884b6,0x7bdc003a,0xc914011a}},	//   ्री_, _ezvo, jsqu, בחרת_, 
   {{0x27e003b2,0x37d400eb,0x00000000,0x00000000}},	//   áini_, _সমার, --, --, 
   {{0x7bdc003a,0xfe40024c,0xbb380092,0x27e00003}},	//   esqu, онро, _በማቋቋ, ġini_, 
   {{0x27e0341a,0xbcf800d2,0xccc441fa,0x16d0012c}},	//   šini_, _umél, рбай, हरुब, 
   {{0x7bdc0112,0x00000000,0x00000000,0x00000000}},	// [31b00] gsqu, --, --, --, 
   {{0xfc3c180f,0xb4c02c2e,0x0e65c1e5,0x3fd80375}},	//   _agís_, ्रु_, _вкон, _שקיב, 
   {{0x7bdc0381,0x9f0400f1,0xdb0c0d12,0x00000000}},	//   asqu, _اوپو, rpað, --, 
   {{0x63a40395,0xc7c41d4a,0x7bdc003a,0x21c801ec}},	//   _èinv, аски, bsqu, _ﺒﺈﺴﺭ, 
   {{0x27e1c1e6,0xdb0c05f7,0x16d0012c,0xc7a40022}},	//   éin_, ppað, हरूब, аидк, 
   {{0x98c400d1,0x00000000,0x00000000,0x00000000}},	//   لغۇن, --, --, --, 
   {{0xb4c02d6b,0xc8800213,0x20040356,0x7b0400e5}},	//   ्रू_, _meşə_, ălii_, éstő, 
   {{0x29d41682,0xa53410f6,0x6d400086,0x945c00a2}},	//   _ḽawe_, снич, _òmad, lańy, 
   {{0x73d5c1e7,0x2c1c0073,0x00000000,0x00000000}},	//   адыр_, निटं_, --, --, 
   {{0xba000020,0x1b1c00fe,0xc88006be,0x00000000}},	//   _ልብ_, নাথে_, _neşə_, --, 
   {{0x26ddc1e8,0xa1a400fb,0x00000000,0x00000000}},	//   mavo_, йымһ, --, --, 
   {{0x26ddc1e9,0xc4841eed,0x6299c1ea,0xea000208}},	//   lavo_, _клек, _vzvo, _giấp_, 
   {{0x15a40014,0x1b1c015b,0xc88006be,0x55300124}},	//   _اصلُ, নাতে_, _beşə_, _хҭыс, 
   {{0x2004003d,0x26ddc1eb,0xbf98045f,0x71f4e9cd}},	//   ċli_, navo_, lwêz, دریس_, 
   {{0x629805a1,0x33040137,0x236c00b5,0x7bdc045a}},	//   _uzvo, _ئيىپ_, midj_, wsqu, 
   {{0x26ddc1ec,0xbf980b21,0x7bdc002f,0x6e28005c}},	//   havo_, nwêz, tsqu, ædba, 
   {{0x26ddc1ed,0x7bdc0483,0x60ddc1ee,0xfd1c0ffb}},	// [31b10] kavo_, usqu, masm, _vaì_, 
   {{0x7bddc1ef,0x26ddc1f0,0xac740efb,0x5dd801d9}},	//   rsqu, javo_, زاقش, _مژرس_, 
   {{0x26ddc1f1,0x5fb40073,0x7bdca1cd,0xaab400d4}},	//   davo_, ंदवल, ssqu, ійці, 
   {{0x60dd4f69,0x7bdc0393,0x225800d0,0x58d800d4}},	//   nasm, psqu, úrky_, уддя_, 
   {{0xdc3430fb,0x26dc0153,0xd82401c6,0x28f8005b}},	//   _האָט_, favo_, сдли, речь_, 
   {{0x60ddc1f2,0x6dbc151c,0x26ddc1f3,0xab84013d}},	//   hasm, _očal, gavo_, _дуск, 
   {{0x60ddc1f4,0x00000000,0x00000000,0x00000000}},	//   kasm, --, --, --, 
   {{0xb4c03f55,0x60dda3b9,0x00000000,0x00000000}},	//   ्रे_, jasm, --, --, 
   {{0x26dca7af,0x60ddc1f5,0x6d400086,0xdcec0171}},	//   bavo_, dasm, _òmae, dmaļ, 
   {{0x26ddc1f6,0xfce0044e,0x00000000,0x00000000}},	//   cavo_, _ምንጪ_, --, --, 
   {{0xd18400cf,0x9f5001e1,0x00000000,0x00000000}},	//   йлой, _òbùn_, --, --, 
   {{0x945c0227,0x69c000b0,0xe50816ac,0x61fc0192}},	//   kańx, _ōmek, _نيمو_, àrla, 
   {{0xc88000ac,0x9878008f,0xf4840063,0x4d4801ec}},	//   _peşə_, ראָט, _тужн, қпан_, 
   {{0x8fa423be,0x6e080022,0x8f7400d4,0x00000000}},	//   саге, аҭом_, сумі, --, 
   {{0x60ddc1f7,0x1ea87224,0x2018002e,0xb4c000cd}},	//   basm, لافي_, awsi_, ्रॊ_, 
   {{0x26ddc1f8,0x60ddc1f9,0x50b401b9,0x2d68510c}},	//   zavo_, casm, _уску, mşek_, 
   {{0x3cec06ea,0x72a00150,0x0ab4007b,0x00000000}},	// [31b20] ógva_, _دەگن, محاد, --, 
   {{0x63a40395,0x7ff400dd,0x5fb401ad,0x00000000}},	//   _èint, _اسٹا, ंदरल, --, 
   {{0x26dc0006,0xb05400aa,0x27680424,0x2b9401e3}},	//   vavo_, _دپښت, یشتی_, läck_, 
   {{0x26dc06e4,0xb4c01c54,0x0d742f4d,0x6e28007c}},	//   wavo_, ्रो_, _ایرک_, ådbu, 
   {{0x66b400db,0xb4c00e57,0x2b9401e3,0x00000000}},	//   облу, ्रै_, näck_, --, 
   {{0x59d400bc,0x60dc02f0,0xcb68014b,0x00000000}},	//   डीहर, zasm, _саге_, --, 
   {{0x60ddc1fa,0xf4000135,0x6dbc0030,0x86240006}},	//   yasm, _མདུད_, _očam, сьле, 
   {{0x7ae401a9,0x70600092,0x00000000,0x00000000}},	//   _zdjt, ገኘታቸ, --, --, 
   {{0xbf98000f,0xd1e40092,0x638401d5,0x60ddc1fb}},	//   rwêz, ማወቅ_, оҳда, vasm, 
   {{0x60ddc1fc,0x2b940267,0x5744007b,0xa9680117}},	//   wasm, däck_, _وخلف, _сиға_, 
   {{0x60ddc1fd,0x60c9c1fe,0x611500fc,0x91c001e0}},	//   tasm, ñemo, одну, үҙәл, 
   {{0x27e0098d,0x823400f7,0xd5840133,0x00000000}},	//   šinu_, _ۇرعا, _وێوه_, --, 
   {{0x60ddc1ff,0x5edc0183,0x849400ec,0x290001e4}},	//   rasm, _বাবে, _اجائ, ϲian_, 
   {{0x60ddc200,0x2018012d,0x2d6800a2,0x00000000}},	//   sasm, rwsi_, bşek_, --, 
   {{0xfe702f84,0xb6b8011a,0x00000000,0x00000000}},	//   سدس_, רצלי, --, --, 
   {{0x2b9558d5,0x60dc016d,0x00000000,0x00000000}},	//   bäck_, qasm, --, --, 
   {{0xfce00020,0x63a4011c,0x7ff44630,0x60180395}},	// [31b30] _ምንጭ_, _èins, _اسعا, _топя_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x98b851a7,0x00000000,0x00000000,0x00000000}},	//   алет_, --, --, --, 
   {{0x6dbc098d,0x2b5800f1,0x00000000,0x00000000}},	//   _očaj, _elrc_, --, --, 
   {{0xf804084c,0x387c031c,0x2b9401c7,0x9e8403e6}},	//   счен, _qxur_, käch_, _داکۆ, 
   {{0x1b1c009e,0x00000000,0x00000000,0x00000000}},	//   নাহে_, --, --, --, 
   {{0x1a6400f2,0xa2dc01f9,0x00000000,0x00000000}},	//   _بیضی_, फरन्, --, --, 
   {{0xd7c9c201,0x58d40166,0x13e801d5,0x2d6803e0}},	//   _نوره_, _фоат, амий_, vşek_, 
   {{0x27e00597,0x7988aaea,0x6934c134,0x6b4001ed}},	//   áint_, mogw, _энту, _rögz, 
   {{0x98ac01f1,0x7989c202,0xa2cc0b98,0x00000000}},	//   _hneď_, logw, _द्द्, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7989c203,0x0b380092,0x00000000,0x00000000}},	//   nogw, _ከየትኛ, --, --, 
   {{0xbf980120,0xf7a40150,0x21e00150,0xdc380139}},	//   rtên, _ﺷﻮﯕﺎ, _ﻋﻨﺼﺭ, kçıg, 
   {{0xa3b9c204,0xbf9803b7,0x79880921,0x2b9401e6}},	//   _طاهر_, stên, hogw, räck_, 
   {{0x7989304e,0x2b9442a7,0xb638037e,0x6cb4009d}},	//   kogw, säck_, _ｇｂ_, зөгт, 
   {{0x2b940ade,0x9db801ec,0xe7fc0118,0x00000000}},	//   päck_, сыру_, उंमा_, --, 
   {{0x0b440364,0x848402d3,0x92bc0154,0xdb1c03b2}},	// [31b40] онан, _ምድሓን_, েণী_, _stsá, 
   {{0x7c288ecc,0x907c0092,0x00000000,0x00000000}},	//   ægra, _የንጹህ_, --, --, 
   {{0xaca40ca8,0xc8c9c205,0xad880117,0x00000000}},	//   _ilọs, لوان_, _ганҷ_, --, 
   {{0x7989c206,0xc278008f,0xf6d000d1,0xf76c01d9}},	//   gogw, ברעי, ۈزىد, ێاو_, 
   {{0xd90c26f0,0x88140a0a,0x6dbc01f1,0x67d40137}},	//   طیل_, تباط, _očak, чолу, 
   {{0x05e9c207,0xe944072d,0xf7400114,0x00000000}},	//   афии_, _کرسی, дељо, --, 
   {{0xd6d9c208,0x798002e3,0xabb400c7,0x46c400bc}},	//   сті_, ọwap, _маҭә, रुषह, 
   {{0x15d801d3,0x97c400db,0x16140116,0x00000000}},	//   حدوں_, زتۇم, سسىڭ, --, 
   {{0x1b1c0154,0x00000000,0x00000000,0x00000000}},	//   নারে_, --, --, --, 
   {{0x46a402d5,0xdcec01e4,0x00000000,0x00000000}},	//   _дазв, riaĉ, --, --, 
   {{0x2b940730,0x84e85ab5,0x96c801d3,0x57200137}},	//   räch_, _نفاق_, _طبلِ_, _سۉيك, 
   {{0x6dbc107d,0xa2700023,0x00000000,0x00000000}},	//   _ečak, _ኣንጭዋ_, --, --, 
   {{0x69c800d8,0x00000000,0x00000000,0x00000000}},	//   _édef, --, --, --, 
   {{0x7c38004e,0x3ddc009e,0x3898010f,0x00000000}},	//   _àuri, বংসল, ייכנ, --, 
   {{0x5edc04c5,0x6d580006,0x2cb000ac,0x7989c209}},	//   _বাদে, _įvar, əndə_, yogw, 
   {{0xdb040036,0x5cb80006,0xa2bc00cc,0x00000000}},	//   mmhé, слаў_, _আজিও, --, 
   {{0x9b580fc0,0x8c380107,0x15e00150,0x00000000}},	// [31b50] биат_, ботӣ_, _ﺍﻹﺤﺩ, --, 
   {{0xdc300171,0x00000000,0x00000000,0x00000000}},	//   _aļģe, --, --, --, 
   {{0xbb4c037e,0x7989c20a,0x1b1c0154,0xdb040332}},	//   _comで_, togw, নালে_, nmhé, 
   {{0x28f8759f,0x9b4404fb,0xdb0401e7,0x00000000}},	//   жець_, _کنسو, imhé, --, 
   {{0x79886456,0x00000000,0x00000000,0x00000000}},	//   rogw, --, --, --, 
   {{0x79887276,0x1fbc0011,0x00000000,0x00000000}},	//   sogw, _অবাস, --, --, 
   {{0x58d401ee,0x00000000,0x00000000,0x00000000}},	//   _новт, --, --, --, 
   {{0xea00001e,0xc5ec00f1,0xdb040332,0x00000000}},	//   _hiếp_, اړل_, dmhé, --, 
   {{0xea0001fb,0x68e40252,0xd468d33a,0xa50800db}},	//   _kiếp_, ðide, сипе_, تۉنە_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbcf80241,0xdb1c013d,0x377400c7,0x0200010b}},	//   _iléf, _itsä, _лыҧс, нзэн, 
   {{0x2ce8025c,0xf8c805d7,0x64c40150,0xea000051}},	//   _འཇེབ, ाडिय, _قيمل, _liếp_, 
   {{0x608c2295,0xa2cc00dc,0xdb040332,0x0d840116}},	//   _መንገድ_, _द्व्, amhé, җлан, 
   {{0xea000051,0x00000000,0x00000000,0x00000000}},	//   _niếp_, --, --, --, 
   {{0xe3b1c20b,0x7d0c294b,0x7c2dc20c,0x4338010f}},	//   _شره_, _bbcs, _arcr, _לעסב, 
   {{0xc6900a1e,0x0d8400d4,0x00000000,0x00000000}},	//   גאל_, їлан, --, --, 
   {{0x0ae9c20d,0x00000000,0x00000000,0x00000000}},	// [31b60] йдай_, --, --, --, 
   {{0x7d0c0354,0x8b2402d5,0x00000000,0x00000000}},	//   _ebcs, ядзе, --, --, 
   {{0x7c2c004e,0x38c804d3,0xbed408a8,0xea000208}},	//   _ercr, ڵانی_, _מויז_, _diếp_, 
   {{0xa6d800bd,0xf98001f0,0x00000000,0x00000000}},	//   _সাইট, нгхо, --, --, 
   {{0x91dc000d,0x00000000,0x00000000,0x00000000}},	//   _कौसड़_, --, --, --, 
   {{0x7bc80cc3,0x6dbc0064,0x1780024c,0xf8ac00e5}},	//   ígue, _ačai, вҳум, اکِ_, 
   {{0xe98402dd,0xd90c02f2,0xdcec0003,0x6d440327}},	//   _قارۋ, _چیم_, llaġ, ojia, 
   {{0x6d44be86,0xdb14025a,0xa8243418,0x00000000}},	//   njia, _nizê, _يکشن, --, 
   {{0x9f5804f3,0x5edc0154,0x290001e4,0x00000000}},	//   ltså_, _বাসে, ϲiaj_, --, 
   {{0xdb1c06ed,0x6d440268,0xd4987c6c,0x00000000}},	//   _ausê, hjia, өрө_, --, 
   {{0xdb2000e5,0x00000000,0x00000000,0x00000000}},	//   ötés, --, --, --, 
   {{0xbcf801e1,0xdb04007b,0xd24c2374,0xdcec025c}},	//   _ilég, rmhé, شچى_, klaġ, 
   {{0x65600842,0xbf980798,0xdb04007b,0x7d0c02d0}},	//   mhmh, stêm, smhé, _rbcs, 
   {{0xbf9807ea,0x6d440076,0xdee00023,0x00000000}},	//   ptêm, ejia, ሓኩኤ_, --, 
   {{0xdd94373e,0x00000000,0x00000000,0x00000000}},	//   давы, --, --, --, 
   {{0x5d980953,0x6d440240,0xf294011a,0x00000000}},	//   ікаў_, gjia, _מכור_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [31b70] --, --, --, --, 
   {{0x6d400428,0x3210033f,0xbcf80129,0xfaa406a7}},	//   _òman, łbyś_, _amét, пшен, 
   {{0xdd902073,0xaa4400d1,0xdcec0419,0x00000000}},	//   _لود_, ىنكى, liač, --, 
   {{0x0db800dd,0x86440023,0x2c1c00fe,0x00000000}},	//   _گئیں_, ራውነት, _নপৰে_, --, 
   {{0xea0001dc,0xbcf80005,0xfca805d9,0x65600afe}},	//   _tiếp_, _alég, _دادو_, dhmh, 
   {{0xdb1c00e8,0xdb140200,0x00000000,0x00000000}},	//   _musë, _mizë, --, --, 
   {{0xe70828b1,0x64400007,0x95840026,0x154401ec}},	//   ستون_, exmi, млке, дейм, 
   {{0xd4d8063b,0x53c9c20e,0x656001e7,0x473004b4}},	//   цькі_, огим_, ghmh, енәс, 
   {{0xbcf9c20f,0x78b8edeb,0xdb1c036e,0x577800c0}},	//   _elég, _iguv, _nusë, _дбаў_, 
   {{0x3f900472,0xdb1c01e6,0xa77402d5,0xdcfc008e}},	//   _nkxu_, _utsä, _злуч, _misı, 
   {{0xbcf8020c,0xe7842678,0x00000000,0x00000000}},	//   _kléd, _чуто, --, --, 
   {{0x65601552,0x059446ee,0x2d681432,0xdcec01e4}},	//   chmh, _قانگ, nşet_, omaĵ, 
   {{0xcfa8fe06,0x00000000,0x00000000,0x00000000}},	//   قاسم_, --, --, --, 
   {{0x93600020,0x2d6805d1,0x78b8022e,0x732401d3}},	//   _ስለሆነ_, hşet_, _lguv, _رقبہ_, 
   {{0x78b80337,0x516400db,0x490c11a6,0x00000000}},	//   _oguv, _жүнү_, ण्डो_, --, 
   {{0x78b9c210,0x50b400db,0x00000000,0x00000000}},	//   _nguv, _оспу, --, --, 
   {{0x8eb80276,0xdcedc211,0x0eb80209,0x6d45c212}},	// [31b80] _мынт_, znać, _муны_, rjia, 
   {{0x78b80083,0xdb1c068c,0x0ae978d3,0x00000000}},	//   _aguv, _jusè, ідей_, --, 
   {{0x33241368,0xdb1c1497,0xdb140100,0x6ed40bae}},	//   _manx_, _musè, _mizè, _ब्यु, 
   {{0x6f1dc213,0x78b807ab,0x1cbc0135,0x2ce8031c}},	//   lerc, _cguv, _ཅུར_, _འཇིབ, 
   {{0x8b65c214,0x2fc00ea0,0xdcec0115,0xbcf801d3}},	//   _قاسم, _juig_, gmaĵ, _emés, 
   {{0xf4081b4b,0x6f1dc215,0xbcf80ca8,0x2fc00254}},	//   _ཁྱེད_, nerc, _eléd, _muig_, 
   {{0x6594035b,0x65615621,0x00000000,0x00000000}},	//   наку, thmh, --, --, 
   {{0x6f1cbc56,0xfaa00364,0xdb1c068c,0xbcf8020c}},	//   herc, _расо, _ausè, _gléd, 
   {{0xea00001e,0x3324003e,0x69dc0e34,0x6f1ca612}},	//   _khắp_, _banx_, _hwre, kerc, 
   {{0xb9e41772,0x68e1c216,0x6f1dc217,0xdb1c0240}},	//   _ክብ_, _hemd, jerc, _rusë, 
   {{0xdb14033b,0x68e1c218,0xf7400e91,0xdb1c0267}},	//   _dizè, _kemd, _шефо, _utså, 
   {{0x68e001fa,0x2fc1c219,0xbcf80036,0x44a407d6}},	//   _jemd, _buig_, _klée, _قماق, 
   {{0x68e00115,0x6f1c514c,0x6728b2a0,0x00000000}},	//   _memd, ferc, _kadj, --, 
   {{0x6f1dc21a,0xdb14036e,0xea000208,0x69dc00ee}},	//   gerc, _vizë, _nhắp_, _owre, 
   {{0x6728044e,0xbf980798,0x9f58020c,0x5f9404a9}},	//   _madj, ntêi, nusé_, _җинт, 
   {{0x6729c21b,0x68e1c21c,0x63b9c21d,0xfe741c13}},	//   _ladj, _nemd, _hivn, зүү_, 
   {{0x6f1dc21e,0x69ddc21f,0xdb1c0098,0x78b8022e}},	// [31b90] berc, _awre, _husé, _rguv, 
   {{0x6f1dc220,0x67293b4d,0x9b95c221,0x9f5802ea}},	//   cerc, _nadj, رلات, kusé_, 
   {{0x68e00489,0x2128102c,0xf2e004c5,0x69c000b0}},	//   _bemd, _kaah_, _মামণ, _ōmer, 
   {{0x67280cfe,0x2905c222,0xdb1dc223,0x63b82630}},	//   _aadj, _ccma_, _musé, _livn, 
   {{0x6729c224,0xdd904ff6,0x2904009f,0x21280014}},	//   _badj, _لوگ_, _dcma_, _maah_, 
   {{0x29040327,0x67281368,0x9f58004a,0x63b8014f}},	//   _ecma_, _cadj, fusé_, _nivn, 
   {{0x68e00cf9,0x69ddc225,0x6728c52a,0xdb0400c6}},	//   _femd, _gwre, _dadj, nmhí, 
   {{0x6f1dc226,0x6935c227,0x9424a4ef,0x1cbc0135}},	//   zerc, _инсу, емие, _ཅུས_, 
   {{0x20080218,0x395c00af,0x6728002e,0x6f1c0334}},	//   _nqai_, _ilus_, _fadj, yerc, 
   {{0x1b1c03f4,0x6729c228,0x62980151,0x13082075}},	//   নাকে_, _gadj, _byvo, чной_, 
   {{0x63b808a4,0x395dc229,0xbcf8020c,0x9f585725}},	//   _divn, _klus_, _mléb, cusé_, 
   {{0x2fc000f7,0x6f1dc22a,0x63b80c86,0xdb1c002e}},	//   _puig_, werc, _eivn, _dusé, 
   {{0x2128b9c2,0x6f1dc22b,0xdb1cc17e,0xd1b904fa}},	//   _daah_, terc, _eusé, _کاتا_, 
   {{0x63b9c22c,0x395d48fb,0xdb1c004a,0x67289420}},	//   _givn, _llus_, _fusé, _xadj, 
   {{0x7bcc003a,0x21280014,0x395c0393,0x62980024}},	//   _atcu, _faah_, _olus_, _gyvo, 
   {{0x6f1dc22d,0x2fc0f3f4,0x8c45c22e,0x2128020c}},	//   serc, _tuig_, небе, _gaah_, 
   {{0x68e1c22f,0xbcf80066,0x31600dd4,0xdb1c002d}},	// [31ba0] _remd, _bléb, _iliz_, _utsû, 
   {{0x395dc230,0x68e0fcfc,0xbcf800d8,0x00000000}},	//   _alus_, _semd, _cléb, --, 
   {{0x6729c231,0x68e1c232,0x2129c233,0x3160009b}},	//   _radj, _pemd, _yaah_, _kliz_, 
   {{0x8c45c234,0x67280fb7,0x02b4008f,0xfaa401d5}},	//   _земе, _sadj, גלעך_, رجلی, 
   {{0x6729c235,0x68e01cee,0xea0001fb,0x2d81c236}},	//   _padj, _vemd, _thắp_, mnie_, 
   {{0x69ddc237,0x2d80006d,0x395dc238,0x68e1c239}},	//   _twre, lnie_, _elus_, _wemd, 
   {{0xfaa0187d,0x395c003d,0x2d8063d0,0x68e1c23a}},	//   _баро, _flus_, onie_, _temd, 
   {{0xa5343849,0x2d81c23b,0x6729c23c,0x63b80477}},	//   тнич, nnie_, _wadj, _sivn, 
   {{0x6729c23d,0x63b999b3,0x3cec06ea,0x2d81c23e}},	//   _tadj, _pivn, ógvi_, inie_, 
   {{0x2d81c23f,0x7c385178,0x63640241,0x00000000}},	//   hnie_, _áure, _mòng, --, 
   {{0x63b9c240,0x6364068c,0x2d5c0789,0x2d81c241}},	//   _vivn, _lòng, _ríen_, knie_, 
   {{0xea0001dc,0x629804bf,0x2d80068f,0x63b8014f}},	//   _nhập_, _vyvo, jnie_, _wivn, 
   {{0x2d80006d,0x63b80455,0x059401b9,0x00000000}},	//   dnie_, _tivn, _قاچگ, --, 
   {{0x4425c242,0x2d80068f,0xf4080156,0x21280548}},	//   _iso_, enie_, _ཁྱིད_, _waah_, 
   {{0x3160011c,0x3da547ba,0x6298014b,0x2129c243}},	//   _fliz_, ераб, _uyvo, _taah_, 
   {{0x2d81c244,0x31600165,0xea0001fb,0xdb04007b}},	//   gnie_, _gliz_, _chập_, rmhí, 
   {{0xbcf9c245,0x6364068c,0x4424009b,0xab6405d1}},	// [31bb0] _aléc, _còng, _jso_, klüğ, 
   {{0x4425c246,0xbcf80a40,0x6b7405f5,0x2d800034}},	//   _mso_, _bléc, глуу, anie_, 
   {{0x395c8aff,0x2d800034,0x5e600131,0x1bec0037}},	//   _plus_, bnie_, _ئۆزە, _छटकल_, 
   {{0x4425c247,0x2d80068f,0xd878034e,0xd9440063}},	//   _oso_, cnie_, ومات_, ђели, 
   {{0x4425c248,0xbcf81280,0x60cdc249,0x7bcc16b8}},	//   _nso_, _eléc, _mfam, _utcu, 
   {{0x7d1c0194,0xbcf93f11,0xd0780240,0x00000000}},	//   leqs, _fléc, _ኣትሪሩ_, --, 
   {{0x44242f06,0xbcf80a40,0x60cc0418,0x76400369}},	//   _aso_, _gléc, _ofam, uxny, 
   {{0xfbdc24ba,0x249002d3,0xdb1c0162,0x395dc24a}},	//   _kwê_, _ምስምስ_, _atsø, _ulus_, 
   {{0x57b5c24b,0x26cc01af,0xdb0c0054,0x8ee004c5}},	//   _абат, _ffdo_, lqañ, _বাসগ, 
   {{0x2d807b8c,0x60cdc24c,0x316002f0,0xdb0401ab}},	//   znie_, _afam, _sliz_, nmhà, 
   {{0x4425c24d,0x3161c24e,0x2d800034,0xdb0c0309}},	//   _eso_, _pliz_, ynie_, nqañ, 
   {{0x6dbc3466,0x442415c0,0x00000000,0x00000000}},	//   _očar, _fso_, --, --, 
   {{0x7d1c0548,0x44240427,0x2f240014,0xa1c001ec}},	//   deqs, _gso_, ۆکھُ, _құяд, 
   {{0x2d813722,0x6364004e,0x60cd4fe6,0x8fa443a2}},	//   wnie_, _cònd, _efam, таге, 
   {{0x2d80006d,0x442400f3,0xfbdc0142,0xea000208}},	//   tnie_, _zso_, _awê_, _phập_, 
   {{0xc5f000c8,0x3160014b,0xab6405d1,0x2b1423c1}},	//   ידל_, _uliz_, zlüğ, न्नु_, 
   {{0x2d81c24f,0x752801d3,0x00000000,0x00000000}},	// [31bc0] rnie_, _magz, --, --, 
   {{0x998c5835,0x2d81c250,0xbcf80036,0xa0a801e0}},	//   _češ_, snie_, _pléc, _ябыҡ_, 
   {{0x6dbc0fb7,0x48e451f2,0xea00001e,0x2d80033f}},	//   _včas, воев, _thập_, pnie_, 
   {{0xb8f0007b,0xe0e000cc,0x00000000,0x00000000}},	//   لكمب, _ভাৱন, --, --, 
   {{0xdcec01e4,0x06e40011,0xe7380022,0x00000000}},	//   nnaĝ, _নাবি, нҵа_, --, 
   {{0xdcfc00df,0x6364033b,0xdde80244,0x00000000}},	//   _disĵ, _kòne, _تریه_, --, 
   {{0xab640365,0x752800f3,0x6dbc0010,0x44252f1b}},	//   rlüğ, _bagz, _učas, _sso_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x752801f5,0x87240276,0xe0e000eb,0xab6403e0}},	//   _dagz, _имаж, _ভালভ, plüğ, 
   {{0x4424151c,0x60cc0395,0xaca4010e,0xdb040332}},	//   _vso_, _sfam, _haỳs, omhá, 
   {{0x60cc006f,0x12e00075,0x3f8c0022,0x225801c6}},	//   _pfam, _ﺋﯘﻻﺭ, _êgui_, хины_, 
   {{0x44240190,0xd5e800c6,0xbcf80129,0x18a40022}},	//   _tso_, _أعلن_, _oléa, _раӡм, 
   {{0xdcec01e4,0xdb040332,0xf1c000d7,0x96040133}},	//   gnaĝ, hmhá, _peší_, _لبۆم, 
   {{0x6364067c,0xdb1c143a,0x54840b82,0xdb0c0113}},	//   _bòne, _utsø, _ይስሃቅ_, yqañ, 
   {{0xbcf8f20f,0x56900092,0x5b1401ec,0x8c840124}},	//   _aléa, _ምንነቱ_, ғмет, ҳәра_, 
   {{0xfc3dc251,0x9f580232,0x60cdc252,0xd7a80073}},	//   _azía_, musí_, _ufam, _चीनच, 
   {{0x6c55c253,0x9f580270,0x5b15c254,0xf1c00030}},	// [31bd0] акту, lusí_, лмат, _teší_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3f8007f5,0xdb040491,0x4ce0015b,0x00000000}},	//   mnju_, gmhá, _ফারু, --, 
   {{0x6dbc02b1,0xbcf806af,0x7d1c009a,0xdb0c0309}},	//   _hōan, _fléa, qeqs, rqañ, 
   {{0x6dbc02b1,0xbcf800c6,0xf8040166,0x63640ba1}},	//   _kōan, _gléa, тчен, _zòne, 
   {{0xdb1c00d2,0x9f59c255,0x6364002e,0x6dbc02f0}},	//   _kusí, lusâ_, _yòne, _učar, 
   {{0x6dbc00b0,0x95c404fb,0xc7940131,0xba74132f}},	//   _mōan, ديبه, اھقا_, _شاست, 
   {{0xdb1c0745,0xb8b00046,0xdb140085,0x3f8001a6}},	//   _musí, _көлі, _mizí, hnju_, 
   {{0x3f802804,0x538c02d3,0xa899be87,0x54340271}},	//   knju_, _ዕብየት_, _акту_, اربر, 
   {{0x3f8008a4,0x1af40154,0x7528010e,0x00000000}},	//   jnju_, ঘ্রই_, _wagz, --, 
   {{0x3f800bb8,0xdb1c006a,0x7529c256,0xc1e401c0}},	//   dnju_, _kusâ, _tagz, лдэж_, 
   {{0xd43435e6,0x6594084c,0x5edc015b,0x22586a12}},	//   _معتب, _каху, _বাগে, ørka_, 
   {{0x06e4045e,0xdb1c067c,0x6364067c,0x00000000}},	//   _নাতি, _ausí, _sòne, --, 
   {{0x63640100,0x3f800841,0x447800df,0x00000000}},	//   _pòne, gnju_, _אננע, --, 
   {{0xdb1400bc,0xbf98045f,0x7c38025c,0xbcf801e7}},	//   _cizí, krêf, _ġura, _sléa, 
   {{0x6ed4146b,0xbcf8007b,0x91040261,0xdb1c02fb}},	//   _ब्रु, _pléa, _спие, _dusí, 
   {{0x9db86564,0x3f802375,0x71740131,0x00000000}},	// [31be0] тыру_, bnju_, _مۇھا, --, 
   {{0xdb1c315a,0x4f24241e,0xe3c80208,0x00000000}},	//   _fusí, _сдоб, _hực_, --, 
   {{0xfaa00798,0x6ea80118,0x00000000,0x00000000}},	//   бафо, _गरिँ, --, --, 
   {{0x88e40a8f,0xbf98000f,0xea00004d,0x0888113e}},	//   ужде, grêf, _chạp_, нбей_, 
   {{0xe3c8001e,0xbcf80221,0x1cbc0327,0xdb040332}},	//   _mực_, _klén, _ཅུག_, smhá, 
   {{0xe3c807ae,0x44380118,0x00000000,0x00000000}},	//   _lực_, _čp_, --, --, 
   {{0xd6d9c257,0xbcf8020c,0x2900067c,0x06e40154}},	//   тті_, _mlén, òias_, _নাদি, 
   {{0x3f801225,0xbf991cb5,0xbcf80789,0xe3c8004d}},	//   znju_, ntêr, _llén, _nực_, 
   {{0xe644956f,0x997405f5,0x8884223e,0x88b007d6}},	//   ılığ, _турш, _слаж, _ایشچ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3f80a068,0xe3c801fb,0x85053ecd,0x27e00356}},	//   vnju_, _bực_, _موان, ţind_, 
   {{0x2b14258d,0xe3c807ae,0xd05403be,0x6dbc0270}},	//   न्तु_, _cực_, _heyə, _sōan, 
   {{0x3f800989,0xf5900486,0x636435f5,0xbcf83b2d}},	//   tnju_, _النج, _cònc, _blén, 
   {{0x9f3402dd,0x212c0010,0x8cb877d7,0x00000000}},	//   шегі, žeh_, ्शनो, --, 
   {{0x3f8005ce,0xd3b800d4,0x00000000,0x00000000}},	//   rnju_, _руці_, --, --, 
   {{0x3f8008ad,0x27e002fb,0x1ca80327,0x60c80427}},	//   snju_, šiny_, _བཛད_, žemb, 
   {{0x3f80b745,0xbcf801c7,0x9c1830bf,0x6dbc02b5}},	// [31bf0] pnju_, _flén, ضياء_, _tōan, 
   {{0xbcf806af,0x7f98003a,0x00000000,0x00000000}},	//   _glén, tîqu, --, --, 
   {{0x2b141dbd,0xceb418c7,0x75c000e5,0x5dcc01ec}},	//   न्धु_, _вәт_, _kőze, _ﻓﺎﻣﻴ, 
   {{0x9f58026c,0xdb1c00d8,0x5edc009e,0x4dd80375}},	//   lusà_, _busã, _বাটে, _שחרו, 
   {{0xd05403b9,0xdb14054e,0x3bf000c7,0x00000000}},	//   _beyə, _vizâ, _ыҟат, --, 
   {{0x2b143174,0xdb14002d,0x00000000,0x00000000}},	//   न्दु_, _wizâ, --, --, 
   {{0xd05403be,0x79a4004e,0x39a4014b,0x00000000}},	//   _deyə, _брае, _бшав, --, 
   {{0x7ae5c258,0xdb1c0120,0xbf98045f,0xdd2000bc}},	//   _hejt, _fusã, brêg, _lůžk, 
   {{0x7999c259,0x7ae48bbb,0xe3c8001e,0xd469b6e9}},	//   _ikuw, _kejt, _rực_, типе_, 
   {{0xa8540598,0xdcec8eb9,0x7ae5c25a,0xdd2000bc}},	//   _укуч, ynağ, _jejt, _nůžk, 
   {{0x7ae58d64,0xdb1405da,0x79980083,0xa5f80114}},	//   _mejt, _mizà, _kkuw, _беху_, 
   {{0x7c38003d,0x27e0084c,0xbcf80066,0xdcec08a4}},	//   _ġurn, ţine_, _slén, knađ, 
   {{0xe3c807ae,0x79980161,0xbcf952b1,0x5edc0f22}},	//   _vực_, _mkuw, _plén, _বাজে, 
   {{0x7ae5c25b,0xd37000ec,0x00000000,0x00000000}},	//   _nejt, _گهڻ_, --, --, 
   {{0x7999c25c,0xbcf806af,0x75c001d3,0xdb04002f}},	//   _okuw, _cléo, _főze, imhä, 
   {{0x7999c25d,0xdb1c00db,0xdde812ea,0x26dc0810}},	//   _nkuw, _ausà, طرفه_, zbvo_, 
  
   {{0x7ae5c25e,0xbcf81e54,0x06e4015b,0x8ad400e3}},	// [31c00] _bejt, _eléo, _নাসি, لتائ, 
   {{0x7999c25f,0x9f594bd7,0xdb5802bf,0xbf99c260}},	//   _akuw, cusà_, лює_, luên, 
   {{0x7ae5c261,0xd1bc02d3,0xdb1c0162,0x00000000}},	//   _dejt, _ሰረት_, _atsó, --, 
   {{0xe3c80016,0x6365c262,0x69c800d8,0x7c0400db}},	//   _lựa_, _mòna, _édem, ايەف_, 
   {{0xdb140109,0x6364068c,0x7e946786,0x7ae401d3}},	//   _fizà, _lòna, _منیر_, _fejt, 
   {{0x9f480004,0x7998849d,0x7ae5c263,0x9ac4010b}},	//   _ivaã_, _ekuw, _gejt, _гирҗ, 
   {{0x9f5807ea,0xa2c5c264,0x00000000,0x00000000}},	//   ursé_, रशस्, --, --, 
   {{0x7ae5c265,0x64e00b7d,0xade805dc,0x245c01e1}},	//   _zejt, नरेश, टीयन_, _námú_, 
   {{0x69c1c266,0xe3c8001e,0x658800bc,0x06f4028e}},	//   _iime, _bựa_, běhn, _نساج, 
   {{0x4aa88fa7,0x69c1c267,0xdb1401ed,0x870407d6}},	//   _कराव, _hime, _kizá, _خبرل, 
   {{0x69c1c268,0xe3c8001e,0xa159c269,0xdcec07f5}},	//   _kime, _dựa_, гану_, znađ, 
   {{0x69c1c26a,0x6364067c,0x7410141b,0x25a000ae}},	//   _jime, _dòna, _ژونا, _óil_, 
   {{0x69c1c26b,0x63640428,0x8ca00dad,0x60dc0112}},	//   _mime, _eòna, _खरगो, rbsm, 
   {{0x636401c3,0x8d9c0092,0x9f5802d2,0x00000000}},	//   _fòna, _ለብቻው_, fusá_, --, 
   {{0x7ae5c26c,0x69c00588,0x41e4753d,0x00000000}},	//   _rejt, _oime, _тіла, --, 
   {{0xb3000ed9,0x7ae5c26d,0xdb1c002e,0xead00248}},	//   _མཐོང_, _sejt, _susà, _kẹwa_, 
   {{0x7ae5c26e,0x6364180f,0x9f580ffb,0xec343129}},	// [31c10] _pejt, _zòna, pusà_, онть, 
   {{0x69c1c26f,0x7ae4014f,0xead00ca8,0xac1835ce}},	//   _aime, _qejt, _mẹwa_, рофу_, 
   {{0x69c1c270,0xdd940209,0x5e589842,0x9e3400fd}},	//   _bime, _ганы, _синя_, _уенч, 
   {{0x98a807f5,0xf41c0598,0x7ae4031c,0xdb1401d3}},	//   žač_, çäk_, _wejt, _dizá, 
   {{0x7ae40038,0xe8f87e3c,0x6a7c0e38,0xdb1c07de}},	//   _tejt, рлі_, _påfø, _tusà, 
   {{0x69c1c271,0x21cc00bc,0xd708009b,0x16c400c7}},	//   _eime, _něho_, унке_, сӡан, 
   {{0x69c1c272,0xd618ef2b,0xbcf800db,0xe3c80051}},	//   _fime, اتتا_, _llém, _rựa_, 
   {{0x99840491,0x69c1c273,0x7998a709,0x636401ab}},	//   _الرو, _gime, _ukuw, _ròna, 
   {{0x06e40154,0x67d5c274,0x00000000,0x00000000}},	//   _নারি, _моту, --, --, 
   {{0x69c1c275,0x636401c3,0xe73000c6,0x06640124}},	//   _zime, _pòna, _يصل_, рхәҭ, 
   {{0x69c1c276,0xcb1002e4,0xf4f40583,0xe3c80208}},	//   _yime, הלי_, _نواں_, _vựa_, 
   {{0x261c29d9,0x0dc84fac,0x00000000,0x00000000}},	//   _महती_, ғлай_, --, --, 
   {{0xe3c8001e,0xbcf9c277,0xc58401d3,0x1b0c00fe}},	//   _tựa_, _clém, _دھوم_, _সঘনে_, 
   {{0xf1cc813f,0xc07002d3,0x6364007f,0x13a40133}},	//   _संपन, _ኣትሒዙ_, _tòna, _دۆخی_, 
   {{0xbcf99b84,0x59b82ca5,0xab64002f,0xea000208}},	//   _elém, ेदार, hlüß, _khấp_, 
   {{0xbf980261,0x2259c278,0xc690008f,0x661c0267}},	//   quên, ärke_, פאן_, _ärke, 
   {{0x636401e1,0x00000000,0x00000000,0x00000000}},	// [31c20] _mònn, --, --, --, 
   {{0x6dbc02b5,0x00000000,0x00000000,0x00000000}},	//   _kōak, --, --, --, 
   {{0xdb04000f,0x06e40154,0xbcf80419,0x3ab00166}},	//   lmhû, _নালি, _zlém, зәтт, 
   {{0x69c11d23,0xc864a9c2,0xea0001fb,0xdb1402fb}},	//   _qime, йтли, _nhấp_, _vizá, 
   {{0x69c1c279,0xc6a404a9,0x07a41d0f,0xc0c00023}},	//   _vime, әрли, бадн, ኻኺሩ_, 
   {{0x69c01517,0xf3fc0154,0x00000000,0x00000000}},	//   _wime, ্বার_, --, --, 
   {{0x658800bc,0x00000000,0x00000000,0x00000000}},	//   běhl, --, --, --, 
   {{0xe944be60,0xea000016,0xbcf80789,0x356401c0}},	//   _برسی, _chấp_, _aléj, йрын_, 
   {{0xbf98002d,0x00000000,0x00000000,0x00000000}},	//   nrêc, --, --, --, 
   {{0xba000092,0xf2e000cc,0x00000000,0x00000000}},	//   _ውብ_, _মাউণ, --, --, 
   {{0xbcf80066,0x2c14015b,0x3f8c00c7,0x75d000ae}},	//   _slém, ঠিয়ে_, _ígui_, _فيلا, 
   {{0xbcf8020c,0x7c380024,0x3ab8011a,0xa0b80114}},	//   _plém, _šurm, טמינ, игну_, 
   {{0x7cfc01e1,0xdde000b0,0xea000208,0xb594009f}},	//   _làrà, ētōt, _đẽo_, _اَنا_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6dbc00b0,0xdbd00724,0x33041d37,0x4524031c}},	//   _kōah, _küçe, _ايىپ_, _རྒོར_, 
   {{0xbcf801e1,0x71f400f2,0x81b00241,0x00000000}},	//   _ilék, _اروس_, béwọ, --, 
   {{0xdbd00432,0xca500023,0x9f34003b,0x00000000}},	// [31c30] _müçe, ዘይብሎ, _депі, --, 
   {{0x7cfc0248,0xdb04007b,0xdbd00139,0x88d00154}},	//   _bàrà, lmhú, _lüçe, ারফক, 
   {{0x9d18084c,0xefd40092,0x00000000,0x00000000}},	//   _конт_, ራዊው_, --, --, 
   {{0xbcf8012c,0xdbd00166,0x9f5800ae,0xdb0401e7}},	//   _mlék, _nüçe, irsí_, nmhú, 
   {{0x28f80108,0xeae800cc,0x98a800d0,0x00000000}},	//   сечь_, _পাৰম, ľaď_, --, 
   {{0x7c2dc27a,0x6d400428,0xdb0400ae,0x84800023}},	//   _iscr, _òmar, hmhú, _ክስራሕ_, 
   {{0x7f540381,0x27e0005f,0xdbd0010e,0xd5480137}},	//   _moxq, ģina_, _büçe, ипке_, 
   {{0xf77168e5,0xf1cc1d27,0x5ba805dc,0x52e00562}},	//   _کار_, _संबन, _कठुव, फर्स, 
   {{0x7c2c030d,0x7c3801a6,0x97244b7c,0xb9d40023}},	//   _jscr, _šurj, _وفرو, _ሽሙ_, 
   {{0x1cbc025c,0x7f54003a,0xd1c00023,0x00000000}},	//   _ཅུན_, _noxq, ጻወት_, --, 
   {{0xea000016,0x273000cf,0x00000000,0x00000000}},	//   _thấp_, _سۉيس, --, --, 
   {{0x09dc04c5,0x3ce8009a,0x61fcd8d3,0x10a4300e}},	//   _ডিমা, _necv_, árla, жимн, 
   {{0xbcf80241,0x7c2c0076,0xead00cad,0xdb140166}},	//   _elék, _nscr, _kẹta_, _kizä, 
   {{0x88b80302,0xb3000135,0xbcf80098,0x91e400db}},	//   יזרי, _མཐིང_, _flék, _доке, 
   {{0x7c2dc27b,0x09dc015b,0x8d543246,0xead00ca8}},	//   _ascr, _ডিভা, отач, _mẹta_, 
   {{0x7c2c010a,0xd0100101,0xead00248,0x00000000}},	//   _bscr, _قلع_, _lẹta_, --, 
   {{0x0ae9c27c,0x4c840153,0x7cfc01e1,0x9f0403c7}},	// [31c40] идай_, цлав, _sàrà, _کوپو, 
   {{0x8a38034b,0x09dc009e,0x7cfc0241,0x00000000}},	//   ияет_, _ডিবা, _pàrà, --, 
   {{0xbcf8020c,0x88c821fa,0x7d0c01e3,0x00000000}},	//   _oléh, алев_, änsö, --, 
   {{0x8c44cb12,0x7c2c0175,0x00000000,0x00000000}},	//   _деме, _fscr, --, --, 
   {{0xdb1400fd,0x2d81c27d,0x5d10004b,0xdbd00166}},	//   _bizä, miie_, _سېلا, _rüçe, 
   {{0xdb1c5d73,0x7cfc0241,0x00000000,0x00000000}},	//   _rusç, _tàrà, --, --, 
   {{0xfaa1c27e,0x6dbc00b0,0x4524031c,0xdbd000a2}},	//   _жаро, _pōah, _རྒུར_, _püçe, 
   {{0xd9b008c9,0x2b580295,0x6364033b,0x2d80002d}},	//   _كەلد, _horc_, _pòno, niie_, 
   {{0x2b580165,0x00000000,0x00000000,0x00000000}},	//   _korc_, --, --, --, 
   {{0xc7640533,0x2d680365,0xdb140139,0x38680205}},	//   _بارى, rşey_, _gizä, _ücra_, 
   {{0x69c80395,0x2d8002c4,0x2b58030a,0x09dc0154}},	//   _èded, kiie_, _morc_, _ডিডা, 
   {{0xdb1c0639,0x2b580156,0x0444004e,0x00000000}},	//   _zusä, _lorc_, _меен, --, 
   {{0x60c800f3,0xdb0401e7,0x00000000,0x00000000}},	//   žemo, rmhú, --, --, 
   {{0x6dbc0374,0xbcf920c2,0x7ddc01e1,0x2b58910e}},	//   _kōaw, _iléi, _fàṣ, _norc_, 
   {{0x72000228,0x7f54003a,0xe3b80ab5,0xbcf80118}},	//   _قووم, _voxq, mmı_, _ulék, 
   {{0xbcf801c7,0x7c85c27f,0xdb040fac,0xf1cc000d}},	//   _kléi, оузе, lmhø, _संतन, 
   {{0x2b580213,0x00000000,0x00000000,0x00000000}},	// [31c50] _borc_, --, --, --, 
   {{0xfaa5c280,0xe3b88eac,0x2b59c281,0x00000000}},	//   ошен, nmı_, _corc_, --, 
   {{0x2d5c056a,0xdb1c0793,0xaee40882,0xf1540133}},	//   _cíes_, _rusä, saṃh, _رکێک, 
   {{0x2d5c00db,0x98b80e58,0xdd94010b,0xdb140166}},	//   _díes_, блет_, _хамы, _sizä, 
   {{0xd41c0020,0x2b59c282,0x7c2c0618,0xb8d002ab}},	//   _ሶፍትዌ, _forc_, _uscr, _ऑर_, 
   {{0x6fdc008d,0xfc3c0241,0x4cb8011a,0x69e40022}},	//   סקוס, _irí_, _לזרו, îteî, 
   {{0xf9916265,0x6a1400ee,0xe77801d3,0x41c401f9}},	//   _قبر_, _омру, تلوں_, _रंगस, 
   {{0xbcf80221,0xea000051,0xd5480798,0x00000000}},	//   _bléi, _nhẹp_, спие_, --, 
   {{0xbcf8007b,0x7989c283,0x200c01ab,0xdb140139}},	//   _cléi, mngw, àeil_, _tizä, 
   {{0x32600364,0xaa880014,0x15b801e0,0x7ddc01e1}},	//   деоҳ, _انہم_, шыһы_, _pàṣ, 
   {{0x79880472,0xfd1c0ca8,0x00000000,0x00000000}},	//   ongw, _obì_, --, --, 
   {{0xfc3c0570,0x7988f456,0xbcf9c284,0x225801e6}},	//   _orí_, nngw, _fléi, ärka_, 
   {{0x69c800d8,0xb4e40959,0xbcf9c285,0xfc3c0241}},	//   _édev, भरी_, _gléi, _nrí_, 
   {{0x798801af,0xbcf8020c,0x0874008f,0x62080162}},	//   hngw, _kléw, לערט_, ðslø, 
   {{0xfc3c0309,0x00000000,0x00000000,0x00000000}},	//   _arí_, --, --, --, 
   {{0x3ea005f5,0x79880369,0x2d5c0789,0xfc3c007b}},	//   хисг, jngw, _ríes_, _brí_, 
   {{0x2b59c286,0xdd10010b,0xadc40051,0x248c0092}},	// [31c60] _porc_, _müňd, _nhất, _ዕድሳት_, 
   {{0x2d80002d,0x0d74006c,0xcfe00011,0x79880142}},	//   siie_, _کیرک_, _বিপন, engw, 
   {{0x2b580165,0xade802ab,0xdcec01e4,0x79880142}},	//   _vorc_, टीशन_, liaĝ, fngw, 
   {{0xfc3c2880,0xc7c41614,0xe3b88eac,0x2258022c}},	//   _frí_, пски, zmı_, ørki_, 
   {{0x07a44712,0xbcf8003e,0x2b59c287,0xdb1c01bf}},	//   падн, _aléw, _torc_, _suså, 
   {{0x7989c288,0x00000000,0x00000000,0x00000000}},	//   angw, --, --, --, 
   {{0xdb1c00d2,0xbcf800c6,0x7c38003d,0x6594b8d3}},	//   _lusû, _sléi, _ġuri, маку, 
   {{0x69dc6b53,0xbcf8007b,0x29f80118,0x24640107}},	//   _itre, _pléi, mča_, дхоҳ, 
   {{0xbcf80241,0x69dc28e9,0xdd1000a2,0x73d409a5}},	//   _eléw, _htre, _düňd, пдыр_, 
   {{0x276836c1,0xbcf80036,0x04fc0154,0x98500244}},	//   _بشری_, _vléi, ্জের_, _جێهش, 
   {{0xe3b84947,0xfbdc045f,0xbcf801c7,0xbf9800d8}},	//   rmı_, _grêf_, _gléw, frên, 
   {{0x6dbc0374,0xe3b86648,0x263c01e4,0xdb1c0267}},	//   _kōau, smı_, _iĉo_, _utsö, 
   {{0x4344470c,0x29f80427,0xafe40006,0x00000000}},	//   _недв, hča_, ноўл, --, 
   {{0x69ddc289,0xd1e4001f,0x9f0400db,0x79880007}},	//   _otre, ኛለች_, بوسو, zngw, 
   {{0x69ddc28a,0x798800a9,0x8cd802e3,0xee2002dd}},	//   _ntre, yngw, _ọbụg, лерi_, 
   {{0xbcf8667d,0xfc3c0419,0x00000000,0x00000000}},	//   _llév, _prí_, --, --, 
   {{0x2d584ec1,0x2d5c00d8,0xa2c407b7,0xbe88030d}},	// [31c70] чить_, _píer_, रशक्, _ӳсме_, 
   {{0x2018bbf3,0xdb1c0109,0x79880042,0x9880010a}},	//   mtsi_, _ntsô, wngw, lачу_, 
   {{0xdea16657,0x69dc0076,0x201800af,0x79880369}},	//   _شیری, _ctre, ltsi_, tngw, 
   {{0xfc3dc28b,0x69dc00c6,0x798801c8,0xbf4c02fb}},	//   _trí_, _dtre, ungw, šíčk, 
   {{0x2019c28c,0x69ddc28d,0xbcf8020c,0x1b1400eb}},	//   ntsi_, _etre, _sléw, ড়বে_, 
   {{0x7bcc1730,0xf09400c8,0x69dc0175,0xbcf80129}},	//   _iucu, ענס_, _ftre, _clév, 
   {{0x7bcdc28e,0x69dc0789,0x7988009a,0x20180254}},	//   _hucu, _gtre, pngw, htsi_, 
   {{0x7bc5c28f,0x201800d2,0x5eac00d1,0xadc40051}},	//   _hiju, ktsi_, ﻳﺘﯘﺭ, _thất, 
   {{0x7bc5c290,0x7bcdc291,0xb6c401ec,0x20180200}},	//   _kiju, _jucu, _есей, jtsi_, 
   {{0x7bcdc292,0x6dbc00b0,0x69c8011c,0x69dc1455}},	//   _mucu, _hōat, _èdec, _ytre, 
   {{0x3f80ce6a,0x7bcdc293,0x2019c294,0x6dbc02b1}},	//   diju_, _lucu, etsi_, _kōat, 
   {{0x5ec4015b,0x7bc5c295,0xf3f400d1,0xd17802bf}},	//   ্রাই, _liju, _еңи_, існі_, 
   {{0xbf980261,0x7bcce989,0x7bc40086,0x201800ca}},	//   rrên, _nucu, _oiju, gtsi_, 
   {{0x3f801326,0x7bc401c8,0x1620a9ec,0xf7c80046}},	//   giju_, _niju, _महार_, _ﻗﻮﻟﺪ, 
   {{0x7bcc2047,0x2018013c,0xbea014a3,0x8d582dbf}},	//   _aucu, atsi_, варк, ошат_, 
   {{0x7bcc0262,0xd1b8b6a9,0x7bc40428,0x20180070}},	//   _bucu, _باتا_, _aiju, btsi_, 
   {{0x3f802220,0x7bc5c296,0x290000d8,0x00000000}},	// [31c80] biju_, _biju, óiam_, --, 
   {{0x09e40138,0x7bcdc297,0x7bc40098,0x29f9c298}},	//   дожн, _ducu, _ciju, tča_, 
   {{0x7bc4a324,0x7bc81427,0x00000000,0x00000000}},	//   _diju, ígur, --, --, 
   {{0x7bcdc299,0x6dbc02b5,0x69dc0010,0xbcf8013a}},	//   _fucu, _pōau, _vtre, _slév, 
   {{0x7bcc015c,0x38c804d3,0x7bc40e3c,0xfc3c01d3}},	//   _gucu, زانی_, _fiju, _szív_, 
   {{0x7bc404ce,0x8a043f6e,0x5b34084c,0x0074011a}},	//   _giju, _озге, _пэсу, ותני_, 
   {{0x69ddc29a,0xe9840131,0x09280451,0xbcf801ef}},	//   _utre, _كارۋ, _وسري_, _vlév, 
   {{0x6364004e,0x7bcc058a,0x7bc5c29b,0xd90c0244}},	//   _iòni, _yucu, _ziju, _هیم_, 
   {{0x248c02d3,0x7bc44a24,0x07a400cf,0x00000000}},	//   _ዕድላት_, _yiju, _жаан, --, 
   {{0x63a80493,0x2019c29c,0x692400d1,0xfc3c0241}},	//   uldn, vtsi_, _юмға, _oyín_, 
   {{0x63a9c29d,0x69c801ed,0x6364004e,0x9f5801ed}},	//   rldn, _édes, _jòni, pusú_, 
   {{0x80f8202e,0x6365c29e,0x06e4009e,0xdcec0139}},	//   ्लेख_, _mòni, _নাটি, diağ, 
   {{0x3f801050,0xbcf8020c,0x2018004c,0x1b140154}},	//   tiju_, _mlét, utsi_, ড়তে_, 
   {{0x4425c29f,0xf4844876,0xa2944077,0x7bcc0526}},	//   _ipo_, _تامی, _палі, _rucu, 
   {{0x44240334,0x2019c2a0,0x00000000,0x00000000}},	//   _hpo_, stsi_, --, --, 
   {{0x7bcdc2a1,0x7bc405d9,0x3cec0579,0x4425c2a2}},	//   _pucu, _siju, úgv_, _kpo_, 
   {{0x60cdc2a3,0xb035c2a4,0xfc3c0248,0x44240327}},	// [31c90] _igam, _аныш, _eyín_, _jpo_, 
   {{0x4425c2a5,0x7bcdc2a6,0x7a85c2a7,0xfba80006}},	//   _mpo_, _vucu, وشام, ітай_, 
   {{0x7bc50693,0x60cdc2a8,0x44240477,0x636400db}},	//   _viju, _kgam, _lpo_, _còni, 
   {{0x4425c2a9,0x7bcdc2aa,0xd7f404b4,0x7bc5c2ab}},	//   _opo_, _tucu, езды, _wiju, 
   {{0x7bc5bae4,0x4425c2ac,0x60cdc2ad,0xb8f428d4}},	//   _tiju, _npo_, _mgam, _सल_, 
   {{0xbcf83fe7,0x636402e2,0x00000000,0x00000000}},	//   _elét, _fòni, --, --, 
   {{0x4425c2ae,0xbcf9c2af,0x661c0254,0x46a00395}},	//   _apo_, _flét, _ärkl, лашв, 
   {{0xbcf80ca8,0x00000000,0x00000000,0x00000000}},	//   _ilés, --, --, --, 
   {{0x4425c2b0,0x6dbc0374,0xb9cc0023,0x880000f1}},	//   _cpo_, _kōar, _ቴማ_, _مېنو, 
   {{0x60cdbdf9,0x4425c2b1,0xf41c0724,0x00000000}},	//   _agam, _dpo_, çäq_, --, 
   {{0x4425c2b2,0x06e404c5,0xdb0400c6,0xdb1c0450}},	//   _epo_, _নাচি, lmhó, _dusø, 
   {{0x44246e24,0xd47402e8,0x00000000,0x00000000}},	//   _fpo_, _плеъ, --, --, 
   {{0xfc3c0142,0x4f9400d4,0xe194009d,0x00000000}},	//   _syín_, ерву, трээ, --, 
   {{0xa3c003f3,0x7538036b,0x99700034,0x0dc800c6}},	//   ंगण_, lduz, nął_, كبرى_, 
   {{0x60cdc2b3,0x44240e78,0x21cc0118,0x00000000}},	//   _fgam, _zpo_, _běhu_, --, 
   {{0x7539c2b4,0x06e40c58,0x60cdc2b5,0xd1080073}},	//   nduz, _নাছি, _ggam, _वाटण_, 
   {{0x4424010a,0x0b451196,0x636400cf,0xf1ac0cbf}},	// [31ca0] _xpo_, ннан, _sòni, _टीएन, 
   {{0x75380007,0x9970033f,0xbcf919aa,0x00000000}},	//   hduz, jął_, _slét, --, 
   {{0x09042488,0xbcf8806d,0xa3c03027,0x5d100131}},	//   епен, _boéd, ंगत_, _ھېكا, 
   {{0xdcec01e4,0x2d8400e4,0x7ae00205,0x753801ef}},	//   flaĵ, _öme_, ınta, jduz, 
   {{0xbcf9c2b6,0xebc401af,0x7d080332,0x00000000}},	//   _elés, _аҙан, ógse, --, 
   {{0xb9054d23,0x4425c2b7,0x636492a7,0xfc3c00bc}},	//   _म्_, _rpo_, _tòni, _vzít_, 
   {{0x4425c2b8,0x8cb80034,0xbcf80241,0xdcec01e4}},	//   _spo_, ्शको, _ilér, alaĵ, 
   {{0x7d180309,0x60c80024,0x44240064,0xdcec010f}},	//   _ñust, žemi, _ppo_, blaĵ, 
   {{0xbcf80066,0x60cc0e14,0xd9b000d1,0x6d480153}},	//   _klér, _rgam, _ئەند, _ėdal, 
   {{0x60cdc2b9,0xbf984aee,0x26d800c5,0x26cc00c0}},	//   _sgam, trêm, _üro_, _ugdo_, 
   {{0xa2941fe2,0xc0c80220,0x02a400f7,0x48d0015b}},	//   тані, зуге_, эрим, ারীর, 
   {{0xdfd5c2ba,0x00000000,0x00000000,0x00000000}},	//   комы, --, --, --, 
   {{0x4425c2bb,0x4ff00588,0x60cc00d8,0xbcf806af}},	//   _upo_, аҧыс, _vgam, _olér, 
   {{0xbf98004a,0x20a46fe9,0x00000000,0x00000000}},	//   prêm, _गुणध, --, --, 
   {{0x60cc0c86,0x2b14012c,0x6440007c,0x6e9401f4}},	//   _tgam, न्छु_, lvmi, гиру, 
   {{0x60cdc2bc,0xfe740228,0x5ba800dc,0x2d58234c}},	//   _ugam, дүү_, कत्व, нись_, 
   {{0xfbd02a60,0x6dbc02b5,0xbcf8020c,0x5b140fc0}},	// [31cb0] اتر_, _pōar, _roéd, кмат, 
   {{0x75380369,0xa3c002c3,0xbcf801ef,0x5e9400ae}},	//   zduz, ंगि_, _plés, _للخط, 
   {{0xdd94035b,0xfbdc0142,0x636401e1,0x21cc013a}},	//   _ааны, _brêc_, _wònw, _těhu_, 
   {{0xbcf8066d,0x00000000,0x00000000,0x00000000}},	//   _elér, --, --, --, 
   {{0xa3c05c0e,0xe3c80208,0xcf780133,0x2bd841ac}},	//   ंगा_, _hựu_, _رشیڤ_, _भूपा, 
   {{0xdb0400c6,0x69c805d5,0x7ae401e2,0x00000000}},	//   rmhó, _èden, _سورې_, --, 
   {{0xab9402bf,0x7af5c2bd,0xa8a40ce8,0xdb0401e7}},	//   _сирі, maxt, крәк, smhó, 
   {{0x7af408aa,0x75380399,0x67243421,0xa3cc107c}},	//   laxt, uduz, đija, _शंख_, 
   {{0xe89400d6,0xd90c00aa,0xf1c002fb,0x629801d5}},	//   _бать, _هیڅ_, ňák_, _axvo, 
   {{0x3de400eb,0x00000000,0x00000000,0x00000000}},	//   _ফিনল, --, --, --, 
   {{0x395d635f,0xcb100a7c,0xf6440354,0x00000000}},	//   _kous_, סלט_, _яхан, --, 
   {{0x395c02e2,0x00000000,0x00000000,0x00000000}},	//   _jous_, --, --, --, 
   {{0xb9e84be7,0x395dc2be,0x61e408a4,0xdecc0023}},	//   _ሕገ_, _mous_, _čile, _ቡሩኽ_, 
   {{0x6364067c,0x395dc2bf,0x00000000,0x00000000}},	//   _bònu, _lous_, --, --, 
   {{0x7af40050,0xe3c8001e,0x27e000e2,0xadc40051}},	//   daxt, _cựu_, ģini_, _chết, 
   {{0x395dc2c0,0x27e00276,0xf00400d1,0x1af00154}},	//   _nous_, ţini_, _йүми, _চাষে_, 
   {{0xccc4c11b,0xbcf80129,0x7af40139,0x00000000}},	// [31cc0] тбай, _plér, faxt, --, 
   {{0x09c81db2,0x0e640588,0x31600097,0x395c01ab}},	//   िद्य, _акон, _hoiz_, _aous_, 
   {{0x395d0311,0xc33006a9,0x2ef80165,0x00000000}},	//   _bous_, שוב_, marf_, --, 
   {{0x395dc2c1,0xfaa07d1d,0x63640ba1,0x316001b9}},	//   _cous_, шахо, _hònt, _joiz_, 
   {{0x395dc2c2,0x261411b1,0x31600399,0x7af5c2c3}},	//   _dous_, नूनी_, _moiz_, baxt, 
   {{0xbf9820ef,0x395c003a,0xdb0401ab,0x2bd800cd}},	//   quêt, _eous_, smhò, _भूया, 
   {{0x2bd87f90,0x395dc2c4,0xa3c0000d,0x00000000}},	//   _भंडा, _fous_, ंगस_, --, 
   {{0x2ef83365,0x316001c0,0x395c007f,0x64400618}},	//   harf_, _noiz_, _gous_, tvmi, 
   {{0x47c402d5,0xdcc4012c,0x2bd82bf1,0x00000000}},	//   _абав, लेपछ, _भूमा, --, 
   {{0x3160005a,0x395c0165,0x00000000,0x00000000}},	//   _aoiz_, _zous_, --, --, 
   {{0x31600369,0x2ef80730,0xe21425a2,0x395c025b}},	//   _boiz_, darf_, ымны, _yous_, 
   {{0x395c004e,0x2bd828fe,0xe3c80051,0xc484d174}},	//   _xous_, _भूभा, _rựu_, _илек, 
   {{0x44300100,0x69d80118,0x7cfc00e5,0x00000000}},	//   _èy_, ívej, _járő, --, 
   {{0x0f703e25,0x63641497,0x6dbc0270,0x20046b92}},	//   йғыр, _cònt, _sōap, čli_, 
   {{0x1af00729,0x3160036b,0x3da40261,0xe3c80051}},	//   _চালে_, _foiz_, враб, _dựt_, 
   {{0x316001c6,0x9f5806af,0x00000000,0x00000000}},	//   _goiz_, issé_, --, --, 
   {{0x5bb811db,0x395dc2c5,0x6364068c,0x64440b4b}},	// [31cd0] елая_, _rous_, _fònt, _šiij, 
   {{0x395dc2c6,0x6b74a6e6,0xbcf87cf3,0xe3c801fb}},	//   _sous_, алуу, _elép, _tựu_, 
   {{0x395c63d2,0x7af5c2c7,0xefd40092,0x00000000}},	//   _pous_, raxt, ያዊው_, --, 
   {{0x69c8011c,0x60dd2300,0x00000000,0x00000000}},	//   _èdel, ncsm, --, --, 
   {{0x395c4e26,0xd825c2c8,0xdb14008e,0x7af5c2c9}},	//   _vous_, удли, _kizü, paxt, 
   {{0x395c0a40,0xdae80014,0x79e401d9,0x7b640354}},	//   _wous_, _سفرو_, _لوسہ_, _ртме, 
   {{0x395c9083,0x2aa8030d,0x53a43452,0xfbac07af}},	//   _tous_, _атто_, ғанб, _जीएम, 
   {{0x395c0ba1,0x19c400d1,0x49a401af,0x00000000}},	//   _uous_, _сәзг, _быуғ, --, 
   {{0x6994005b,0xb7b000db,0x2984004e,0x00000000}},	//   _трёх, _көкч, _тырг, --, 
   {{0xa7b80372,0xef20012d,0x00000000,0x00000000}},	//   _алуу_, ężki_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd1b81c3e,0xd009c2ca,0xdb1c428a,0xfa440092}},	//   عادا_, неме_, _ausü, _ሙያተኞ, 
   {{0x6364068c,0x2ef80008,0x3160022e,0xdb1c00a2}},	//   _còns, tarf_, _voiz_, _susý, 
   {{0xdb1c002e,0xf36403f6,0x00000000,0x00000000}},	//   _musó, _штен, --, --, 
   {{0xdb1c0587,0xa3c05345,0xdb147225,0xa3cc443a}},	//   _lusó, ंगर_, _dizü, _शूट_, 
   {{0x26140574,0xcd34a744,0x2ef80194,0x8b640345}},	//   नंती_, درآب, sarf_, گارم, 
   {{0x00e0010b,0x2ef800d8,0x4b24008e,0x8b25c2cb}},	// [31ce0] _ужын, parf_, лмав, лдае, 
   {{0x8b65c2cc,0xdb140139,0x81e400cc,0xdb1c0790}},	//   دارم, _gizü, _পিত_, _gusü, 
   {{0xd8380607,0x68e40789,0x48e40798,0x00000000}},	//   _asō_, ñido, гоев, --, 
   {{0x25780d27,0x22583110,0xdb0400e4,0xdb1c06d8}},	//   _zélf_, ärki_, nohê, _busó, 
   {{0x69e00219,0x636401e1,0x00000000,0x00000000}},	//   _žveč, _mònr, --, --, 
   {{0xbf98017a,0xd5a401d3,0x00000000,0x00000000}},	//   rsêg, یلوی, --, --, 
   {{0x2bd808f8,0x9f5806af,0x368402e8,0x430800c7}},	//   _भूता, ussé_, лсън_, ҭхом_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa3c02c33,0xbb1801ec,0x00000000,0x00000000}},	//   ंगल_, _ﺴﻴﻥ_, --, --, 
   {{0x33711dbc,0x41e4177b,0x00000000,0x00000000}},	//   йгыр, ліма, --, --, 
   {{0x2d5c4a29,0x28a80037,0xb6a0022e,0x00000000}},	//   _díez_, _छुति, _лифл, --, 
   {{0x844518a2,0x2578017a,0xdb140139,0x00000000}},	//   _مختل, _sélf_, _sizü, --, 
   {{0xdb1401b8,0x133801ed,0xff0400f5,0x00000000}},	//   _pizü, رتیں_, лявн, --, 
   {{0xf485c2cd,0xdcec01e4,0x6dac002f,0xdb0401e3}},	//   _حامی, mkaĉ, ißau, lmhö, 
   {{0x2904098d,0x671c03ce,0x00000000,0x00000000}},	//   _odma_, _नानक_, --, --, 
   {{0x3d0c02ab,0xfbdc015d,0xd1e00023,0x00000000}},	//   िलें_, _drên_, _ቐረባ_, --, 
   {{0x2128011f,0xa0340131,0xdcec0115,0x2bd80764}},	// [31cf0] _ibah_, _ئىخت, nkaĉ, _भूदा, 
   {{0x59d84614,0x02d0134e,0x00000000,0x00000000}},	//   _बंदर, _सलोन, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2128022f,0x9f5819f5,0x2d8c01d3,0x6d440092}},	//   _jbah_, cusò_, édet_, _የሪፖር, 
   {{0xda00069f,0xf80451e4,0x2128a324,0x290401f5}},	//   _लटकत_, учен, _mbah_, _ddma_, 
   {{0x966409a5,0xead5c2ce,0x29040066,0xfc3c01e1}},	//   икле, _горь, _edma_, _nyíi_, 
   {{0x2904003e,0x212906cd,0xf7c802dd,0x00000000}},	//   _fdma_, _obah_, _ﺗﻮﻧﺪ, --, 
   {{0xdb140077,0xdb040240,0x00000000,0x00000000}},	//   _tizó, kohë, --, --, 
   {{0x7989c2cf,0x32080034,0x00000000,0x00000000}},	//   migw, ącym_, --, --, 
   {{0x25a049ad,0x2129c2d0,0x671c04af,0x2bd805f9}},	//   čila_, _abah_, _नायक_, _भंसा, 
   {{0x1db40073,0x18a400fb,0xf1cc012d,0x00000000}},	//   ंतात, _саҡм, _सूखन, --, 
   {{0x69d803b7,0x7989c2d1,0xe6f00248,0x9f48002b}},	//   ívei, nigw, _iṣẹd, _evaü_, 
   {{0x671c35e8,0x6d400332,0xa07401ec,0x1834010f}},	//   _नामक_, _ómai, бырш, באָל_, 
   {{0x7989c2d2,0x2128020c,0xa3c016ae,0x00000000}},	//   higw, _ebah_, ंगः_, --, 
   {{0x798844c8,0x2dc8024c,0x33b002f2,0x75c000e5}},	//   kigw, лқон_, _پڕکر, _főzt, 
   {{0xbcf80c6a,0x798801f7,0x64c400db,0x00000000}},	//   _poéa, jigw, _ئيۇل, --, 
   {{0x7989c2d3,0xaf50044e,0xd7a40073,0x661c000d}},	// [31d00] digw, _ኣገልገ, खकाच, _ärkv, 
   {{0xfbdc431d,0x636401e1,0xcb0856e8,0x00000000}},	//   _trên_, _jònp, ئيان_, --, 
   {{0x27e4003e,0x257801f5,0xca540b3e,0xad88014b}},	//   _stmn_, _héle_, штањ, _банҷ_, 
   {{0xc8c9c2d4,0x79891ad9,0xc8640e46,0xbf980af9}},	//   نوان_, gigw, итли, rsêe, 
   {{0xbcf8003e,0x257800e8,0xb7d410e8,0x38c8158b}},	//   _koén, _jéle_, لونا_, ناهی_, 
   {{0xfe88006a,0x81e40154,0x00000000,0x00000000}},	//   _usïö_, _পিস_, --, --, 
   {{0x7989c2d5,0xbcf8020c,0x29040098,0xd6d80212}},	//   bigw, _moén, _tdma_, уті_, 
   {{0x2905c2d6,0xa4f9c2d7,0x9f480055,0x35642bda}},	//   _udma_, اکار_, _svaü_, ирын_, 
   {{0xf3f52a74,0xf1d06766,0x9974009d,0x00000000}},	//   аныш_, _संजन, _уурш, --, 
   {{0x29c402e3,0xda0c000d,0x00000000,0x00000000}},	//   _ịchụ_, _हिमत_, --, --, 
   {{0x8504dc6f,0x81dc0154,0xdcec0115,0x46a401a9}},	//   _نوان, দীন_, skaĉ, _тажв, 
   {{0xdb040200,0x00000000,0x00000000,0x00000000}},	//   tohë, --, --, --, 
   {{0x25780332,0xc2e401b9,0xa7940208,0x9f48002b}},	//   _céle_, _кўйи, _lằml, _tvaü_, 
   {{0x7989c2d8,0x257800bc,0xdb040200,0xe37401af}},	//   zigw, _déle_, rohë, _ыллы, 
   {{0x63a9c2d9,0xb3b8011a,0x00000000,0x00000000}},	//   modn, _שמוכ, --, --, 
   {{0x21282831,0x63a9c2da,0x7988011f,0x257801ed}},	//   _ubah_, lodn, xigw, _féle_, 
   {{0x257801e1,0x3b34001f,0x7988006f,0xdcb8008e}},	// [31d10] _géle_, _የማግኘ, vigw, угач_, 
   {{0x09dc00bd,0xbcf80066,0x2d8c004a,0x798800ca}},	//   _ডিজা, _goén, éder_, wigw, 
   {{0xcfe003f4,0xdb1c0784,0x79887dcd,0x426c02d3}},	//   _বিএন, _qusñ, tigw, _ስዉኣት_, 
   {{0x63a97969,0x1ca404d3,0x8c2000fe,0x00000000}},	//   hodn, _هێزی_, নিজন_, --, 
   {{0x8d58025f,0xf1d002ab,0x7989c2db,0x2614012d}},	//   _עכשי, _संघन, rigw, नूसी_, 
   {{0xcc3804ac,0xdb1c0784,0x79887294,0x9f60007f}},	//   _געשט, _tusñ, sigw, èsès_, 
   {{0x798805d9,0x63a80286,0xa3c000e1,0xdb0400c7}},	//   pigw, dodn, ंगई_, johé, 
   {{0xddd401d3,0x00000000,0x00000000,0x00000000}},	//   nyző, --, --, --, 
   {{0x79980248,0xd9440075,0xbc700092,0xe818007b}},	//   _ijuw, _кеңи, _የመኪና_, _نزلت_, 
   {{0x63a9c2dc,0x78b80099,0x3688d174,0xb7140ee8}},	//   godn, _izuv, _исен_, _خبرش, 
   {{0x6dac002f,0x56b400ec,0x787001f7,0x00000000}},	//   ißar, _اٽار, _اُڃا, --, 
   {{0xdb0401e6,0xbcf80165,0x7c2d7392,0x25780241}},	//   llhä, _soén, _opcr, _péle_, 
   {{0x63a80b9b,0xbcf98c4b,0x24180006,0x00000000}},	//   bodn, _poén, _вочы_, --, 
   {{0x7998002d,0x75c001d3,0x63a80009,0xdb04035b}},	//   _ljuw, _tőzs, codn, bohé, 
   {{0x7c2c035a,0x22589576,0xdb0406af,0x83141c3e}},	//   _apcr, ärkt_, cohé, _اقىر_, 
   {{0xf1d02052,0x79986922,0xddd401d3,0x1af003d4}},	//   _सूचन, _njuw, gyző, _চাগে_, 
   {{0x9f49c2dd,0x00000000,0x00000000,0x00000000}},	// [31d20] _evañ_, --, --, --, 
   {{0x7999c2de,0xc0a401d9,0xcef41f5a,0x3de40154}},	//   _ajuw, _دجى۪, _учињ, _ফিরল, 
   {{0xd1bc1772,0xead001e1,0x00000000,0x00000000}},	//   _ደረት_, _mẹga_, --, --, 
   {{0x9f480f99,0xcd3404fb,0x08c4084c,0xda6400c6}},	//   _hvað_, _اردب, ббен, غالي, 
   {{0xbf98004a,0x9f4809e8,0x63a851ca,0x00000000}},	//   prêt, _kvað_, yodn, --, 
   {{0x6d440323,0x00000000,0x00000000,0x00000000}},	//   ldia, --, --, --, 
   {{0x78b8004c,0x79980135,0x6d48016b,0x00000000}},	//   _ezuv, _fjuw, _ɔdan, --, 
   {{0x25a04859,0x63a8068f,0xbcf80098,0x00000000}},	//   čilo_, wodn, _noél, --, 
   {{0x69c0049b,0x6d459d75,0x0458036b,0xaadc2d3b}},	//   _ihme, idia, اجعت_, _बलाक, 
   {{0xc1e9c2df,0x824c001f,0x9970033f,0xd5b80137}},	//   льме_, ንግሥታ, kąś_, лсө_, 
   {{0x9f5c4e53,0x69c1c2e0,0xe1349b81,0x86981142}},	//   _ìwé_, _khme, онны, _стат_, 
   {{0x63a9c2e1,0x00000000,0x00000000,0x00000000}},	//   sodn, --, --, --, 
   {{0x6d440f7b,0x63a80bb8,0x2bd8d2c7,0xdb040250}},	//   ddia, podn, _भूला, llhå, 
   {{0x6d45c2e2,0xb4b40451,0x661c0254,0x63a801a9}},	//   edia, _اُها_, _ärks, qodn, 
   {{0x41e42004,0x69c0e4bd,0x37c403d4,0x00000000}},	//   _استف, _ohme, ৰীকৰ, --, 
   {{0x161805ba,0x6d444eca,0xbcf839b4,0xbf98002d}},	//   नंतर_, gdia, _goél, três, 
   {{0xe52039a7,0x00000000,0x00000000,0x00000000}},	// [31d30] _यानि_, --, --, --, 
   {{0x6d4405da,0xa3b800dc,0xac180117,0xa11401e2}},	//   adia, चति_, софу_, _اوکت, 
   {{0x6d45c2e3,0x49d801d3,0x58d8011c,0x00000000}},	//   bdia, لانگ_, адея_, --, 
   {{0x69c002fb,0x866002d3,0x6d44ff7a,0x61e400ef}},	//   _chme, ላውነት, cdia, _čill, 
   {{0x75e4456f,0xe8f8160b,0xa3b82c35,0x79980327}},	//   _kızg, слі_, चता_, _vjuw, 
   {{0xc0600023,0x69c003b9,0xdd9800d7,0x00000000}},	//   _ዝጸሓፍ, _ehme, čňu_, --, 
   {{0xfc3c08a5,0x34b023e9,0xd1bc1954,0x00000000}},	//   _hsí_, ुध्द, _ደረቱ_, --, 
   {{0x7bdc0eda,0x69c00165,0x799801f7,0xfc3c01a8}},	//   oqqu, _ghme, _ujuw, _ksí_, 
   {{0xdcec0cf4,0x935848a9,0xfc3c02d2,0x78b9c2e4}},	//   jkač, арну_, _jsí_, _uzuv, 
   {{0xbcf80165,0x6d44b12f,0x00000000,0x00000000}},	//   _cléz, zdia, --, --, 
   {{0xcb101203,0x644405be,0x6d4403cb,0x09a8031c}},	//   ולי_, _šiit, ydia, _པཉྩ_, 
   {{0xfc3c03a0,0x6d4400db,0x00000000,0x00000000}},	//   _osí_, xdia, --, --, 
   {{0xfc3c022c,0x1b1004c5,0x6748032e,0x00000000}},	//   _nsí_, স্যই_, _ásjú, --, 
   {{0xbcf80241,0x6d440142,0xd9d8000d,0x00000000}},	//   _iléy, wdia, _बंूट, --, 
   {{0xfc3d3316,0x7bdc0869,0xbf98017a,0x62c400db}},	//   _así_, eqqu, trêr, _ىزىك, 
   {{0x6d440860,0x9f5819f5,0x2578003e,0xfc3c032e}},	//   udia, assà_, _kéla_, _bsí_, 
   {{0x4b880334,0x75e40790,0x00000000,0x00000000}},	// [31d40] айан_, _hızd, --, --, 
   {{0x6d45c2e5,0x2578893a,0x75e4247e,0xddd403b9}},	//   sdia, _méla_, _kızd, _çaşq, 
   {{0x7bdc0eda,0x6d4403a2,0xfc3c0ca8,0x3ab00724}},	//   aqqu, pdia, _esí_, дәтт, 
   {{0x671c00af,0x0d744d2f,0xfc3c02d2,0x75e40205}},	//   _नाहक_, _بیرک_, _fsí_, _mızd, 
   {{0xc7c461ac,0xdb1c000d,0xfc3c08a5,0xade00027}},	//   оски, _ausõ, _gsí_, _खंडन_, 
   {{0x69d97ea5,0x6fc003e0,0x25b400cd,0x00000000}},	//   íves, böce, ुष्ण, --, 
   {{0x69c00295,0xc64400db,0x4e7800df,0x00000000}},	//   _thme, تئشى, יאַצ, --, 
   {{0x69dc0381,0x22a4013e,0x2579c2e6,0xdcec02f0}},	//   _iure, ҷумҳ, _béla_, ykač, 
   {{0xf1e002dd,0xdb140205,0x6fbc23e9,0x00000000}},	//   _ﺍﻟﻨﺘ, _vizö, ोगां, --, 
   {{0x69ddc2e7,0xdb1c00d8,0x75e40205,0x00000000}},	//   _kure, _fusõ, _bızd, --, 
   {{0xc4e4272a,0xbcf9c2e8,0x75e406be,0x67380200}},	//   _джей, _eléy, _cızd, mevj, 
   {{0xbcf80139,0x75e4013d,0x00000000,0x00000000}},	//   _poém, _sızg, --, --, 
   {{0x849400dd,0x69dc0f85,0xdee0069d,0x00000000}},	//   _بجائ, _lure, _ፓርክ_, --, 
   {{0x69dc0f71,0x67381e31,0xdcec5160,0x35dc02e5}},	//   _oure, nevj, rkač, _पूड़, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfc3c219b,0x6738014f,0x1b140154,0xc0e40055}},	//   _psí_, hevj, ড়ছে_, _nāḍi_, 
   {{0x69ddc2e9,0x2139c2ea,0xf1c81c5c,0x6739c2eb}},	// [31d50] _aure, mesh_, _بويى_, kevj, 
   {{0x69ddc2ec,0x2019c2ed,0x67382a6d,0x2139c2ee}},	//   _bure, musi_, jevj, lesh_, 
   {{0x20180b0b,0xea000016,0x69dc3498,0xd1bc001f}},	//   lusi_, _đảo_, _cure, _ደረቅ_, 
   {{0x69ddc2ef,0xe9d80953,0x2139c2f0,0xfd1000e5}},	//   _dure, ікі_, nesh_, _کجھ_, 
   {{0x69ddc2f1,0x8d58011a,0x2c08030d,0x00000000}},	//   _eure, _הכרי, _мэро_, --, 
   {{0x2138044e,0x37a8310f,0x2578003e,0x67380037}},	//   hesh_, штен_, _réla_, gevj, 
   {{0x2019c2f2,0x69ddc2f3,0x2139c2f4,0x257800f2}},	//   husi_, _gure, kesh_, _séla_, 
   {{0x2019c2f5,0x21380023,0x6934010b,0x00000000}},	//   kusi_, jesh_, _онсу, --, 
   {{0x2139c2f6,0x2019c2f7,0x69dc223f,0x75e41432}},	//   desh_, jusi_, _zure, _sızd, 
   {{0x2019c2f8,0x69ddc2f9,0x130807d8,0x67380010}},	//   dusi_, _yure, щной_, cevj, 
   {{0xcb101a4c,0x69ddc2fa,0xbf9800d2,0x257800f2}},	//   עלט_, _xure, tsên, _wéla_, 
   {{0x2019c2fb,0xb9200241,0x69c8011c,0x257800f2}},	//   fusi_, _aarẹ_, _èdet, _téla_, 
   {{0x201834d4,0xe52000dc,0x00000000,0x00000000}},	//   gusi_, _याति_, --, --, 
   {{0x04400120,0x9f5c01e1,0x00000000,0x00000000}},	//   _чешн, _ìwì_, --, --, 
   {{0x20180006,0x56b4008f,0x21380200,0x0d200137}},	//   ausi_, לפֿן_, besh_, нүнү, 
   {{0x2019c2fc,0x69ddc2fd,0xfe5400e8,0x2139c2fe}},	//   busi_, _rure, _na鯵u_, cesh_, 
   {{0x20180ffb,0x21cc01ef,0x06b000eb,0x661800d7}},	// [31d60] cusi_, _něhy_, _চলছি, zuvk, 
   {{0x29f80421,0x63a400e4,0x248000e4,0x683c0092}},	//   tōa_, _êint, _üime_, _በልማት, 
   {{0x69dda1ad,0xce48010b,0x50d4004b,0xfbb800cc}},	//   _qure, _узне_, _بزګر, _অংশত, 
   {{0x69ddc2ff,0x845c001f,0x21cc01ef,0xddb8014b}},	//   _vure, ዳይሆን_, _běhy_, _муяш_, 
   {{0xfe54002e,0xfaa00107,0x79800af9,0x6738036e}},	//   _da鯵u_, _ҷаро, ënwa, tevj, 
   {{0x2138036e,0xe5e401d5,0x00000000,0x00000000}},	//   zesh_, وزبی, --, --, 
   {{0xfaa10878,0x6739c300,0x2139c301,0x69ddc302}},	//   _заро, revj, yesh_, _uure, 
   {{0x7ec400dd,0xf64c3e1a,0x2019c303,0x21380472}},	//   lépé, ائو_, yusi_, xesh_, 
   {{0x66180122,0x21380240,0x201800e8,0x00000000}},	//   suvk, vesh_, xusi_, --, 
   {{0x20187478,0xbcf80098,0x00000000,0x00000000}},	//   vusi_, _poék, --, --, 
   {{0x2138044e,0x69c8011c,0x2019c304,0xe1380212}},	//   tesh_, _èdes, wusi_, озні_, 
   {{0x2019c305,0x6364007f,0x00000000,0x00000000}},	//   tusi_, _jònz, --, --, 
   {{0x2139c306,0x2d81c307,0x6aa0016b,0xbbd8012c}},	//   resh_, dhie_, _ɛmfa, _बढेक, 
   {{0x2019c308,0x213802d3,0x382c0092,0x00000000}},	//   rusi_, sesh_, _ሳይቀበ, --, 
   {{0x2019c309,0x2138044e,0xe3b81ae6,0xfe7002f2}},	//   susi_, pesh_, mlı_, ردس_, 
   {{0x2d81c30a,0xe3b89d5d,0xf1a40953,0x21380023}},	//   ghie_, llı_, _прын, qesh_, 
   {{0xea0007ae,0x5c985067,0x2578043b,0x201965ad}},	// [31d70] _đạo_, цкая_, _lélo_, qusi_, 
   {{0xe3b80c07,0x2009c30b,0xdec40022,0x2b580129}},	//   nlı_, _ivai_, _жәбо, _cnrc_, 
   {{0x2d8001ab,0x81dc0154,0x00000000,0x00000000}},	//   bhie_, দীর_, --, --, 
   {{0x2d81c30c,0x4424493b,0xe3b807b3,0x98b9c30d}},	//   chie_, _oqo_, hlı_, олет_, 
   {{0xe3b85d6d,0x442400aa,0xa3ac0316,0xf1e00220}},	//   klı_, _nqo_, कका_, _ﺍﻟﻤﺘ, 
   {{0xe3b85531,0x7ec40098,0x2b44010b,0x00000000}},	//   jlı_, cépé, _пэсг, --, 
   {{0xe3b8afeb,0x442403e3,0xfbdcca55,0x00000000}},	//   dlı_, _aqo_, _huê_, --, 
   {{0xfbdc006a,0x13e9c30e,0x7d1c0007,0xa9c40137}},	//   _kuê_, омий_, ngqs, _كۅلۉ, 
   {{0xe3b807b3,0xb0ac012c,0x6d8c00a2,0x00000000}},	//   flı_, _टुंग, _ỳakm, --, 
   {{0xd38802bf,0xa92800bc,0x8d9c001f,0xe784234c}},	//   ійне_, ražš, _ወጥተው_, _пухо, 
   {{0x2009c30f,0x9f5802f6,0x25780c6a,0xe6104028}},	//   _avai_, issä_, _gélo_, _مشن_, 
   {{0x720400dd,0x25780de2,0xe3b8afeb,0x636401e1}},	//   _ہفتہ_, _jéll_, alı_, _mòny, 
   {{0xd468048a,0x20540816,0x7539c310,0xe3b86656}},	//   _филе_, нтрр, meuz, blı_, 
   {{0xb8fc76ff,0x753805c7,0xe3b8a565,0x00000000}},	//   _ལུ_, leuz, clı_, --, 
   {{0x2d81c311,0x03a000e4,0x20080124,0x00000000}},	//   thie_, _шишо, _evai_, --, 
   {{0x9f5802f6,0x75380247,0x00000000,0x00000000}},	//   essä_, neuz, --, --, 
   {{0x2b58026c,0x61e42230,0x2d8044ee,0x15e002dd}},	// [31d80] _pnrc_, _čili, rhie_, _ﺇﻟﻴﻬ, 
   {{0x2d81c312,0x75382a1f,0x80a400bc,0xeadc0154}},	//   shie_, heuz, _टुटे, ধর্ম, 
   {{0x2d81c313,0x75380196,0x00000000,0x00000000}},	//   phie_, keuz, --, --, 
   {{0xe3b9439a,0x13e404c5,0x7538002d,0x29e80213}},	//   zlı_, পীয়, jeuz, _ağac_, 
   {{0xe3b80c07,0xd90c77c2,0x7ec40098,0x00000000}},	//   ylı_, صیل_, pépé, --, 
   {{0xdcec00e4,0x05e801f0,0x00000000,0x00000000}},	//   ihaĝ, офии_, --, --, 
   {{0x257801a8,0x00000000,0x00000000,0x00000000}},	//   _féll_, --, --, --, 
   {{0x2579c314,0x75380451,0x161403cc,0xfeb80131}},	//   _vélo_, geuz, رسىڭ, ﻠﯩﯟﺍ, 
   {{0xe3b84952,0xa2d0d639,0xdb040306,0x872406ed}},	//   tlı_, डेन्, lohá, _омаж, 
   {{0x57c800dc,0x672400f3,0x75e403b9,0x00000000}},	//   िगृह, đijs, _qızc, --, 
   {{0xe3b84952,0xfbdc0165,0x200803cd,0x44240477}},	//   rlı_, _hrêt_, _svai_, _wqo_, 
   {{0xe3b87b54,0x2578002e,0x00000000,0x00000000}},	//   slı_, _xéll_, --, --, 
   {{0xe3b870f7,0x9f5802f6,0xdb0400e4,0x442403b9}},	//   plı_, yssä_, hohá, _uqo_, 
   {{0xe3b91e7f,0xdb040588,0x75e40205,0x00000000}},	//   qlı_, kohá, _hıza, --, 
   {{0x75e5c315,0x7fd40220,0x6440009a,0x671c0073}},	//   _kıza, зіңі, lwmi, _नाईक_, 
   {{0x27440064,0x00000000,0x00000000,0x00000000}},	//   lūnė_, --, --, --, 
   {{0xfbddc316,0x6ce403de,0x46dc0c22,0x00000000}},	// [31d90] _quê_, тісе, मशाह, --, 
   {{0x31a407c4,0x2578002e,0x7538067c,0x1bd4005b}},	//   mıza_, _séll_, zeuz, хозя, 
   {{0x75382e4b,0x79800af9,0xeadc00fe,0xb9e4003b}},	//   yeuz, ënwo, ধৰ্ম, фізи, 
   {{0x6d60001f,0x28f800d4,0x00000000,0x00000000}},	//   _ለሪፖር, дець_, --, --, 
   {{0x31a407c4,0x63640248,0x9f5c0241,0x27440064}},	//   nıza_, _wòny, _íwó_, kūnė_, 
   {{0x257801c7,0x59ac00bc,0x00000000,0x00000000}},	//   _wéll_, टकहर, --, --, 
   {{0x75398131,0x2bd80cf1,0xdb0400e4,0x46100345}},	//   teuz, _भूटा, cohá, هوور, 
   {{0xab6409a5,0x5eac1df2,0x1d90001f,0x75e406be}},	//   rnüş, ﺳﺘﯘﺭ, _ነጥቦች_, _cıza, 
   {{0xaee406d6,0xfbddc317,0x7539c318,0x947800c0}},	//   _huṅw, _trêu_, reuz, яску_, 
   {{0x2d8c004a,0xc481a8a0,0x7d0c03ac,0x75380356}},	//   édez_, ульк, _ldcs, seuz, 
   {{0x68e40989,0x753800d8,0x032002d5,0xf644074d}},	//   žide, peuz, ыдэн, _юхан, 
   {{0xaee41aa1,0x31a405d1,0x00000000,0x00000000}},	//   _muṅw, fıza_, --, --, 
   {{0xaee41682,0x7bc4005b,0x00000000,0x00000000}},	//   _luṅw, _ohju, --, --, 
   {{0x3f800ba3,0x92ac03d4,0x61e400c0,0x90c000db}},	//   ghju_, _কণী_, _čilv, _ەڭسۅ, 
   {{0xa3ac02a0,0xbea0e07e,0xdb1406ea,0x3ea0b27b}},	//   ककर_, гарк, ðbýn, гирг, 
   {{0x7bc4ec91,0xd0244316,0x3f800254,0x31a40139}},	//   _ahju, _змий, ahju_, bıza_, 
   {{0xc1980375,0x00000000,0x00000000,0x00000000}},	// [31da0] _משקי, --, --, --, 
   {{0x8fa400b2,0x7bc42b1d,0x3f800c95,0x09b800dc}},	//   _سمجه, _chju, chju_, ेष्य, 
   {{0xc3300bd4,0x9f5c0241,0x00000000,0x00000000}},	//   רוב_, _ìwá_, --, --, 
   {{0xfbddc319,0x7d0c0175,0xdb0520c2,0x00000000}},	//   _prêt_, _gdcs, rohá, --, 
   {{0x81e404c5,0x75e4123d,0x7af40175,0xb90401d9}},	//   _পিছ_, _rıza, bbxt, رٲوم_, 
   {{0x38c9c31a,0x7bc40ba3,0xfc3c056a,0x2bd80034}},	//   سانی_, _ghju, _uxía_, _भूचा, 
   {{0x66848fde,0xa2680023,0x00000000,0x00000000}},	//   خیال, ሽውናን_, --, --, 
   {{0x04646ff7,0x75e56918,0xd6d84f32,0xe5540114}},	//   етом, _qıza, фті_, ткињ, 
   {{0xe8e0063f,0x07a401c6,0xc3480395,0x00000000}},	//   niọs_, _заан, пяне_, --, 
   {{0xd36c1823,0x00000000,0x00000000,0x00000000}},	//   يۇن_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf2c1c31b,0xc48400a8,0xbcf807ea,0xd24c2002}},	//   ысын, _плек, _inég, زچى_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x25a00fb7,0xadc40241,0x7588001f,0x00000000}},	//   čilu_, _ikẹt, _ንቅናቄ_, --, 
   {{0x06b000eb,0x7e7400cf,0xbdc403c5,0x00000000}},	//   টেরি, راسئ, ещай, --, 
   {{0xa2d0000d,0x7c840108,0xbb180150,0x62880064}},	//   डेण्, нузе, _ﺴﻴﻘ_, mzdo, 
   {{0x3b500020,0x2fe800cf,0x71d8011a,0x9d440ce8}},	// [31db0] _ለማግኘ, _كىيپ_, _אוהד_, неңд, 
   {{0xfaa4d70a,0x00000000,0x00000000,0x00000000}},	//   ншен, --, --, --, 
   {{0xdd9096e0,0x3f90031c,0x62880007,0xdfd00451}},	//   _نود_, _imxu_, nzdo, _ٽيگ_, 
   {{0x7ec40241,0x75e40166,0x62880156,0x6a14006c}},	//   _eépí, _bızn, izdo, ابلر, 
   {{0x20180472,0xbc480139,0x00000000,0x00000000}},	//   nrsi_, _эчне_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfbdc03b7,0xe708b460,0xadc40241,0x38c40241}},	//   _três_, رتون_, _akẹt, _bìrí_, 
   {{0xd4d40953,0x47300166,0x00000000,0x00000000}},	//   кіпэ, гнәс, --, --, 
   {{0x62880030,0xa56400d1,0xc9500115,0x00000000}},	//   ezdo, ادىن, _דמן_, --, 
   {{0x0595c31c,0x73c00184,0x5274010b,0xbe7000b8}},	//   _یانگ, ыҡла, вуму, _kṣāl, 
   {{0x2019c31d,0xe78495c8,0x38c401e1,0xdb0401f4}},	//   ersi_, _суто, _fìrí_, mohä, 
   {{0xd0080120,0xdb040108,0x6e440022,0x00000000}},	//   меме_, lohä, ҳҵоз, --, 
   {{0x6288012d,0x00000000,0x00000000,0x00000000}},	//   azdo, --, --, --, 
   {{0x8fe00032,0x00000000,0x00000000,0x00000000}},	//   ләүҙ, --, --, --, 
   {{0x2019c31e,0xdcfc1bc5,0xe3b001f7,0xc7b0011a}},	//   arsi_, _aksı, _ارن_, יבך_, 
   {{0x629c0210,0x00000000,0x00000000,0x00000000}},	//   źroc, --, --, --, 
   {{0x78b80117,0x0fc400cf,0xdb0401f4,0x00000000}},	// [31dc0] _nyuv, _ийин, kohä, --, 
   {{0x8ad40597,0x3b80013d,0x00000000,0x00000000}},	//   نتائ, алуг, --, --, 
   {{0xbcf8afe0,0x09280d1d,0xdcfc0205,0x8b643267}},	//   _poét, джей_, _eksı, _یاسم, 
   {{0x81dc02f5,0xe97400d1,0x00000000,0x00000000}},	//   দীক_, دۇرد, --, --, 
   {{0x78b800ca,0x75e4008e,0x39100006,0x00000000}},	//   _cyuv, _qızn, рмір, --, 
   {{0xdd10010e,0x00000000,0x00000000,0x00000000}},	//   _küşd, --, --, --, 
   {{0x863c010c,0x38c40248,0xbf98010f,0x65943893}},	//   _ኮሚኒስ, _pìrí_, ויסש, лаку, 
   {{0x62882753,0xfaa08c21,0x2018003a,0xdd1000ee}},	//   vzdo, _тасо, yrsi_, _müşd, 
   {{0x75e40365,0x6abc1876,0x5f040303,0xc1900066}},	//   _hızl, _hyrf, वरम्_, ییتع, 
   {{0x671c1b57,0x2904123c,0x75e47764,0x201808ad}},	//   _नाटक_, _hema_, _kızl, vrsi_, 
   {{0x2905c31f,0x03540032,0x6289c320,0xb6a0329b}},	//   _kema_, еүҙә_, uzdo, _кифл, 
   {{0x2905c321,0xdb1402e2,0xbcf8020c,0x62887ce9}},	//   _jema_, _ekzè, _loér, rzdo, 
   {{0x2905c322,0x2018058a,0x349000d4,0x62883df9}},	//   _mema_, ursi_, _каїр, szdo, 
   {{0x234800f6,0xf484030f,0x20180200,0x00000000}},	//   _سستی_, _جامی, rrsi_, --, 
   {{0xdcec00f3,0x7db43997,0x6234014b,0x00000000}},	//   nkać, نصرا, _сейу, --, 
   {{0xdd10950d,0x538c02d3,0xed140212,0x720000d1}},	//   _düşd, _ንብዓት_, имсь, _ئويم, 
   {{0x609816cb,0xad24581f,0x2128003e,0x27e405d5}},	// [31dd0] _سندس_, شىلى, _icah_, _numn_, 
   {{0x29040295,0xbcf9c323,0x6abc015d,0x257801d3}},	//   _aema_, _poés, _byrf, _déli_, 
   {{0x2905c324,0xbcf800e8,0x6abc0368,0x75e406be}},	//   _bema_, _anée, _cyrf, _cızl, 
   {{0x27e40073,0xfc3c056a,0x6abd0905,0x225801f4}},	//   _bumn_, _uxío_, _dyrf, ärky_, 
   {{0x2905c325,0xdc34008f,0xdb0408a1,0x7c855785}},	//   _dema_, _גאָט_, tohä, _руне, 
   {{0x2904022f,0xdca40022,0xe8941064,0x6abdc326}},	//   _eema_, _ааҭи, шачь, _fyrf, 
   {{0x6abc00a9,0x66dc05ac,0xbcf80129,0x290475cd}},	//   _gyrf, våkø, _inéb, _fema_, 
   {{0x2905c327,0xbcf8032e,0x76400210,0x00000000}},	//   _gema_, _hnéb, rwny, --, 
   {{0x7790cc47,0x395c735c,0x394c0099,0x49a402dd}},	//   _پیغا, _inus_, mdgs_, _сырғ, 
   {{0x21285103,0x25fc0490,0x395c0306,0x29043e9d}},	//   _acah_, ोळखी_, _hnus_, _zema_, 
   {{0x395c8007,0x2905c328,0x75e40790,0x00000000}},	//   _knus_, _yema_, _kızm, --, 
   {{0x6d48013f,0x2905c329,0xdd1006be,0x00000000}},	//   _ɔdas, _xema_, _rüşd, --, 
   {{0xd094822d,0xdb1402fb,0x75e40205,0x918000cf}},	//   ушны, _ekzé, _mızm, _ۇۇدۇ, 
   {{0x74102e44,0x25e8000d,0x00000000,0x00000000}},	//   _موچا, _चूडी_, --, --, 
   {{0x395dc32a,0x6fc00112,0x00000000,0x00000000}},	//   _onus_, löck, --, --, 
   {{0x0ce000bd,0x225804ce,0x8c45c32b,0x395c0381}},	//   বর্ত, ærke_, лебе, _nnus_, 
   {{0x2905c32c,0x75e40ac4,0x64440b4b,0xbcf8004a}},	// [31de0] _rema_, _sızl, _šiiz, _coéq, 
   {{0x257800e5,0x00000000,0x00000000,0x00000000}},	//   _véli_, --, --, --, 
   {{0x2905c32d,0x75e59f50,0x2d8c06af,0x00000000}},	//   _pema_, _qızl, èdes_, --, 
   {{0x9f480270,0x8885bd80,0x4ea40124,0x257801ed}},	//   _itaá_, ллеж, _арҭа, _téli_, 
   {{0x29040451,0xd90c23cf,0x8ed80214,0xdd740133}},	//   _vema_, بیق_, _تذکر_, _ڕپێک, 
   {{0x6fb41533,0x2904dd9e,0xca30001f,0x6abdc32e}},	//   ंकिं, _wema_, _አዋቂዎ, _tyrf, 
   {{0xbd680092,0x00000000,0x00000000,0x00000000}},	//   _አለብኝ_, --, --, --, 
   {{0x395c0327,0x290401c4,0x5ed000eb,0x00000000}},	//   _gnus_, _uema_, তুকে, --, 
   {{0xb40405f5,0x2128062c,0xd90c0214,0xe8540133}},	//   лээж_, _rcah_, _آیه_, _خۆشد, 
   {{0xbcf80036,0xa778008e,0x316001ef,0xeaa000b8}},	//   _knéc, _шәех_, _aniz_, ciṣu_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6fc05df4,0xe2d801b9,0x00000000,0x00000000}},	//   böck, _یاغچ_, --, --, 
   {{0x9f480093,0x85740022,0x3da401f0,0x3fb40150}},	//   _ataá_, _илҧх, ҳраб, лқия_, 
   {{0x63040075,0x29e815b7,0x6fc0002f,0xe1240022}},	//   _ئوغل, _ağam_, nöch, ымҭи, 
   {{0x3da5c32f,0xa2d0202e,0x9b440633,0xdcec0419}},	//   граб, डेश्, ینرو, rnaľ, 
   {{0x6fc00112,0xe3b000f2,0xfc64011c,0x00000000}},	//   höch, _ارچ_, лъзн, --, 
   {{0xbcf82b76,0xaed40075,0x0ce003d4,0x6fc0002f}},	// [31df0] _anéc, _қоюш, বৰ্ত, köch, 
   {{0x3d1801e1,0x395dc330,0x75e43361,0x3a8400ee}},	//   _bàwà_, _snus_, _sızm, лыев, 
   {{0x60980014,0x91a801d3,0x00000000,0x00000000}},	//   _سنگس_, _سنیے_, --, --, 
   {{0x4df804ac,0xdd980209,0x75e403e3,0x00000000}},	//   _שפרא, _öň_, _qızm, --, 
   {{0x395c0381,0x00000000,0x00000000,0x00000000}},	//   _vnus_, --, --, --, 
   {{0x257800f2,0xc2040014,0xab8420c8,0x00000000}},	//   _mélu_, _ؤ_, _луск, --, 
   {{0x27f8151c,0x00000000,0x00000000,0x00000000}},	//   _črne_, --, --, --, 
   {{0xd1c80201,0x395c0483,0x6fc00112,0x54347701}},	//   _በፊት_, _unus_, töck, ахоу, 
   {{0x27f80232,0xd9440131,0x998000b0,0x75e40790}},	//   čený_, _йеңи, huhū_, _kızk, 
   {{0x6fc0002f,0x56943947,0xa3000166,0x00000000}},	//   röck, _казт, пүше, --, 
   {{0xa2d08497,0x00000000,0x00000000,0x00000000}},	//   डेल्, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x257800e8,0xf2e40064,0x00000000,0x00000000}},	//   _délu_, _сюдо, --, --, 
   {{0xe81c0c2e,0x645c005f,0xff0400a8,0x3f6401f0}},	//   _निभा_, ārie, реск_, широ_, 
   {{0x41b00f1b,0xbea000d4,0x00000000,0x00000000}},	//   _ومور, іатк, --, --, 
   {{0x25780419,0x8fa400f3,0x6cb401c4,0x00000000}},	// [31e00] _gélu_, _вапе, сөнт, --, 
   {{0x2578008c,0x7c38054e,0xfb840395,0x00000000}},	//   _hélt_, _ţurc, абук_, --, 
   {{0x4a441583,0x00000000,0x00000000,0x00000000}},	//   рнев, --, --, --, 
   {{0xdb0405c7,0x6fc0002f,0xf40401e2,0x42340677}},	//   nnhê, wöch, _وؤ_, ינעל_, 
   {{0x6d45c331,0x2578002e,0xa0500023,0x2608000d}},	//   meia, _xélu_, _ንኩነታ, _सबही_, 
   {{0x6d45c332,0x2d81c333,0x9e6404d3,0xca740fdc}},	//   leia, lkie_, _ئاین, _кубы, 
   {{0xfaa08392,0x2d81c334,0xbb38011a,0xfa6400db}},	//   _даро, okie_, _שעלי, _карк_, 
   {{0x2d800591,0x6d45c335,0x26c002b5,0x00000000}},	//   nkie_, neia, āio_, --, 
   {{0x2d81c336,0x00000000,0x00000000,0x00000000}},	//   ikie_, --, --, --, 
   {{0x6d44135e,0x86980408,0xd5b800db,0x00000000}},	//   heia, _итет_, ксө_, --, 
   {{0x2d80f9eb,0x6d440093,0xef2000c5,0x3370009d}},	//   kkie_, keia, _बाजऽ_, цгэр, 
   {{0xd1c80092,0x257800e5,0xb5d401ec,0x00000000}},	//   _በፊቱ_, _célt_, _ﺟﺎﻳﻌ, --, 
   {{0x6d45c337,0xdb040077,0x2d80033f,0x2418013d}},	//   deia, rohú, dkie_, _солы_, 
   {{0xdb05c338,0x2d81c339,0x2d8c0036,0x00000000}},	//   llhö, ekie_, ëden_, --, 
   {{0x6d446bb4,0xbcf806af,0xf4200327,0x75e403e0}},	//   feia, _anéa, _འཀོད_, _rızk, 
   {{0x69c80029,0x6d4401c4,0x00000000,0x00000000}},	//   _ūden, geia, --, --, 
   {{0x5b15c33a,0x6c55c33b,0x301400c7,0xdd0800d7}},	// [31e10] ймат, окту, _ддыр, pôži, 
   {{0x6d440418,0x68e40306,0x00000000,0x00000000}},	//   aeia, židl, --, --, 
   {{0x5a35c33c,0x9f480205,0x00000000,0x00000000}},	//   снет, _ataç_, --, --, 
   {{0x2d81c33d,0x257807c5,0x6d440092,0x00000000}},	//   ckie_, _méls_, _ከሪፖር, --, 
   {{0xbcf800c6,0x00000000,0x00000000,0x00000000}},	//   _gnéa, --, --, --, 
   {{0xd7c83016,0xcc74011a,0xeaf80066,0x00000000}},	//   دوته_, _הגשת_, _نرفت_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3a300204,0x00000000,0x00000000,0x00000000}},	//   ltxp_, --, --, --, 
   {{0x2d8001c0,0x6d45b254,0x8c18011a,0x00000000}},	//   zkie_, zeia, נותי, --, 
   {{0x23780267,0x6d44009f,0x2d80017a,0x18a401e0}},	//   örja_, yeia, ykie_, _таҡм, 
   {{0xfc3c01e1,0x00000000,0x00000000,0x00000000}},	//   _opí_, --, --, --, 
   {{0x732432db,0xdb0401bf,0x00000000,0x00000000}},	//   _نقشہ_, bohø, --, --, 
   {{0x6d4406c8,0x2d80007f,0x00000000,0x00000000}},	//   weia, wkie_, --, --, 
   {{0x51f593a5,0xfc3c03a0,0x6d45c33e,0x2d80012d}},	//   _استر, _apí_, teia, tkie_, 
   {{0x2d8091a1,0xe5780171,0x91a400cc,0x75e400e5}},	//   ukie_, _puķi_, _গীৰ্, _tűzf, 
   {{0x2d812ef7,0x00000000,0x00000000,0x00000000}},	// [31e20] rkie_, --, --, --, 
   {{0x2d81c33f,0x4f2462bd,0xcb081d48,0x06b0009e}},	//   skie_, _удоб, ايان_, টেটি, 
   {{0x6d4418a6,0x2d800210,0x00000000,0x00000000}},	//   peia, pkie_, --, --, 
   {{0x08880228,0xe8f80032,0xbcf802d2,0x00000000}},	//   лбей_, рһа_, _hnén, --, 
   {{0xa40001af,0x00000000,0x00000000,0x00000000}},	//   _эшhө, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x43880150,0xf64c009f,0xf108012d,0x4e7800df}},	//   _ﯗﺭﯨﻦ_, فئي_, _वजूद_, טאַצ, 
   {{0x79880142,0xca280150,0xd95800f3,0x00000000}},	//   chgw, _ﺢﻄﺳ_, _круљ_, --, 
   {{0x88840063,0x25e84709,0xd9940244,0x00000000}},	//   _улаж, _चूरी_, _بۆنت_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x86c5c340,0x85051147,0xb7d58997,0xbb38010f}},	//   _ايان, _هوان, _اولا_, נעטי, 
   {{0x7f8806be,0x00000000,0x00000000,0x00000000}},	//   _müqe, --, --, --, 
   {{0x33a40451,0x01e402dd,0xf1e001ec,0xf990011a}},	//   _گهوٽ_, _ﺍﻟﻌﻨ, _ﺍﻟﻜﺘ, פרש_, 
   {{0x69c800ef,0x22a4014b,0x00000000,0x00000000}},	//   _ūdel, _муйҳ, --, --, 
   {{0xfc3c02fb,0x32d00137,0x25fc0073,0x8d6c0092}},	//   _spí_, _ىزىس, ळीची_, _አለችው_, 
   {{0xbcf80c6a,0x32500801,0x71a41b88,0x98bc02b5}},	//   _enén, _хвър, _најз, hewā_, 
   {{0x2d596719,0xdb980b16,0x75e400e5,0x9c1893fc}},	// [31e30] щить_, авач_, _tűzg, شياء_, 
   {{0x60cc5936,0x5b140046,0xbcf8002e,0x63a80204}},	//   _izam, імет, _gnén, nndn, 
   {{0x27f8151c,0x798802d0,0x2bc800f3,0x5974004e}},	//   _črna_, thgw, суто_, жылу, 
   {{0x6dac0724,0xe1c811a6,0xb2b8010f,0x00000000}},	//   lğan, रतिघ, נמאר, --, 
   {{0x2c3c0023,0x00000000,0x00000000,0x00000000}},	//   _ኣጋጢም, --, --, --, 
   {{0x60cdc341,0xb09c008f,0x7f44014f,0x15ec01ad}},	//   _mzam, ניגר, nejq, _चंदर_, 
   {{0x994c01f1,0xaad81bd6,0x00000000,0x00000000}},	//   môžu_, भेदक, --, --, 
   {{0x60cdc342,0x7f44c329,0xa81800d1,0x0694007b}},	//   _ozam, hejq, شتۇر_, غنية_, 
   {{0xe10003f4,0x60cc2173,0x79987e91,0xf1e002dd}},	//   ্লাহ_, _nzam, _imuw, _ﺍﻟﻘﺘ, 
   {{0x1308034b,0x7f44014f,0x2c3c0023,0x00000000}},	//   шной_, jejq, _ኣጋጣም, --, 
   {{0x76a921c8,0x645c02b5,0x7ae4036e,0x7f44031c}},	//   _став_, āria, _mgjt, dejq, 
   {{0x63a80254,0x00000000,0x00000000,0x00000000}},	//   andn, --, --, --, 
   {{0x79980337,0x60cc0166,0x00000000,0x00000000}},	//   _mmuw, _ğomä, --, --, 
   {{0x60cdc343,0x56b4008f,0xe81c0037,0x00000000}},	//   _dzam, ַפּן_, _निसा_, --, 
   {{0x60cc4005,0x79982f99,0xfbdc0165,0x0d2000f7}},	//   _ezam, _omuw, _frêz_, мүнү, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbcf806af,0x7f44014f,0x51f40451,0x0eb400ce}},	// [31e40] _inél, bejq, _اسڪر, _आँकड, 
   {{0x79980a49,0xa2d006ab,0x7f440113,0xf3f80183}},	//   _amuw, डेक्, cejq, _এটাৰ_, 
   {{0x8a040046,0x75e40166,0xe81c000d,0x7f38010f}},	//   ізде, _kızu, _निहा_, _דעיו, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x79981418,0x26d802fb,0xaf1c015b,0x00000000}},	//   _emuw, _úrok_, দ্রণ_, --, 
   {{0xc6a401b9,0x00000000,0x00000000,0x00000000}},	//   ўрли, --, --, --, 
   {{0x79980083,0xa2c400fb,0x00000000,0x00000000}},	//   _gmuw, үәкк, --, --, 
   {{0x07a5c344,0xc7a4040e,0x75e4002d,0x00000000}},	//   _даан, _диак, _rűze, --, 
   {{0x63a9c345,0xbcf801d3,0x00000000,0x00000000}},	//   undn, _anél, --, --, 
   {{0x60cd6c6a,0xa15835ce,0x00000000,0x00000000}},	//   _szam, бану_, --, --, 
   {{0xe57800e2,0x43740124,0x00000000,0x00000000}},	//   _puķu_, суҩт, --, --, 
   {{0x9f4806ed,0xc0e80020,0x1b100eac,0x128801b9}},	//   _itaú_, _ሆኗል_, ালতে_, لمیی_, 
   {{0xa2941fe2,0x60cc151c,0x00000000,0x00000000}},	//   _налі, _vzam, --, --, 
   {{0x3f802833,0x6dac6b8e,0x69c003e0,0xe50000cd}},	//   rkju_, rğan, _okme, ैरपि_, 
   {{0xf1a4005e,0x3f81c346,0x00000000,0x00000000}},	//   _орын, skju_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [31e50] --, --, --, --, 
   {{0x69c1c347,0x20080a73,0x7a8400db,0x6dac43bc}},	//   _akme, _iwai_, يشام, lğal, 
   {{0xdcec071b,0x2008004c,0x40b40050,0xfc3c004d}},	//   ljač, _hwai_, _دپکھ_, _axít_, 
   {{0x2009c348,0x31a40139,0x00000000,0x00000000}},	//   _kwai_, bızu_, --, --, 
   {{0xf8480276,0xa80402d5,0x00000000,0x00000000}},	//   рчей_, дзіл, --, --, 
   {{0x2009c349,0x69c1c34a,0xbcf80129,0x6e4808a5}},	//   _mwai_, _ekme, _mném, _úrbó, 
   {{0xf969c34b,0x69c00093,0x195858e5,0x00000000}},	//   _край_, _fkme, _лавы_, --, 
   {{0x200818a6,0x7998113c,0xf3fc00d8,0x00000000}},	//   _owai_, _umuw, ãão_, --, 
   {{0xdcec2d2b,0xbb2c4da8,0xe72c0022,0x00000000}},	//   jjač, ﯩﮕﻪ_, _иҵ_, --, 
   {{0xdcec08a4,0x00000000,0x00000000,0x00000000}},	//   djač, --, --, --, 
   {{0x2009c34c,0xbcf8a8d8,0x00000000,0x00000000}},	//   _awai_, _aném, --, --, 
   {{0x92680588,0x75e40139,0x00000000,0x00000000}},	//   арҭа_, _qızu, --, --, 
   {{0x75384b2a,0xe5c402d5,0x00000000,0x00000000}},	//   mfuz, _ўсхо, --, --, 
   {{0x7539c34d,0xc3200154,0x00000000,0x00000000}},	//   lfuz, ব্বি_, --, --, 
   {{0x20080a73,0x00000000,0x00000000,0x00000000}},	//   _ewai_, --, --, --, 
   {{0x7539c34e,0x661c00b5,0xdcec03e0,0x00000000}},	//   nfuz, _ærke, rkağ, --, 
   {{0x2008004c,0x27f8151c,0x69c000ee,0x8b240006}},	// [31e60] _gwai_, _črno_, _rkme, здзе, 
   {{0xcd3404d3,0x7539c34f,0xdb040022,0x9f5408a5}},	//   _کردب, hfuz, pohý, _æfði_, 
   {{0x3f78011a,0xfaa000c0,0x6dac0139,0x00000000}},	//   _האיס, нафо, lğam, --, 
   {{0xdde825da,0xa2d006e3,0x00000000,0x00000000}},	//   _گریه_, डेट्, --, --, 
   {{0x9f40020c,0xdcec010f,0xe81c01f9,0x00000000}},	//   _sihé_, gnaĵ, _निळा_, --, 
   {{0x6b9c01d5,0x00000000,0x00000000,0x00000000}},	//   _umrg, --, --, --, 
   {{0x7538155d,0xb7102162,0x00000000,0x00000000}},	//   ffuz, ربوش, --, --, 
   {{0xe945c214,0x7f8803be,0x69c00006,0x00000000}},	//   _ترسی, _müqa, _ukme, --, 
   {{0xdb042b76,0xbcf80030,0x260817cb,0x25e801ad}},	//   cohó, _poéz, _सबकी_, _चंकी_, 
   {{0x200806a3,0x07700132,0xdcec0427,0x00000000}},	//   _rwai_, _سۇبح, vjač, --, 
   {{0x2009c350,0xf310009d,0x00000000,0x00000000}},	//   _swai_, эдээ, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6aa8024a,0x00000000,0x00000000,0x00000000}},	//   कपुर, --, --, --, 
   {{0xdcec46aa,0x00000000,0x00000000,0x00000000}},	//   rjač, --, --, --, 
   {{0xdcec1505,0x7338011a,0x00000000,0x00000000}},	//   sjač, _העוס, --, --, 
   {{0x5bc400dc,0x75e40139,0xb5d40220,0x00000000}},	//   वत्व, _kızr, _ﺟﺎﻟﻌ, --, 
   {{0x200806c8,0xfc3c0166,0xc05002d3,0x00000000}},	// [31e70] _uwai_, _axír_, ሃደራው, --, 
   {{0x25a00118,0x75e403e0,0x6aa8a786,0x00000000}},	//   čily_, _mızr, कपूर, --, 
   {{0xdd9556cb,0xbef80764,0x6d6801e7,0x00000000}},	//   _жаны, ्रीन_, ásaí, --, 
   {{0x9cf402dd,0x7c840063,0x00000000,0x00000000}},	//   _ізгі, _еуге, --, --, 
   {{0x9f5c0ca8,0x00000000,0x00000000,0x00000000}},	//   _ìwó_, --, --, --, 
   {{0x7d0c0142,0xdcec00df,0x9b4400ae,0x7cd4010a}},	//   _hecs, rnaĵ, _تنسو, ĕмĕр_, 
   {{0x7d0c01ed,0x7f540139,0x00000000,0x00000000}},	//   _kecs, _maxq, --, --, 
   {{0x7f540113,0xdb0400cf,0xaf800023,0x00000000}},	//   _laxq, cohò, _ዓወትና_, --, 
   {{0xbcf8003e,0x75381ee8,0x7d0dc351,0xdcec00d7}},	//   _anék, rfuz, _mecs, kiaľ, 
   {{0x7d0c01ed,0x75e406be,0xa48400ae,0x00000000}},	//   _lecs, _qızs, عجين, --, 
   {{0x75381446,0x2b8404cc,0x368801c0,0xcb100375}},	//   pfuz, _döch_, _усан_, כלי_, 
   {{0x7d0dc352,0x10a449a4,0x659403ea,0x00000000}},	//   _necs, димн, _паху, --, 
   {{0x7f540548,0xbcf801f1,0x00000000,0x00000000}},	//   _baxq, _inéh, --, --, 
   {{0xf8a8004d,0xc0ec0023,0x13a80014,0x00000000}},	//   _đời_, _ቀጸለ_, _گنڈی_, --, 
   {{0x7d0c01ed,0xb63c00b5,0x8d5400db,0x00000000}},	//   _becs, _ａｗ_, мтач, --, 
   {{0x90c400d1,0x7f880213,0xc0f00092,0x00000000}},	//   _обйе, _vüqa, ግቷል_, --, 
   {{0x629c1d55,0x7d0dc20a,0x69d80129,0x00000000}},	// [31e80] úrov, _decs, ïvem, --, 
   {{0x1c380b7e,0xcdf40166,0x00c40139,0x00000000}},	//   яясь_, _очмы, _юлык_, --, 
   {{0xfc54001f,0x29e803e0,0x41b010e8,0x7d0dc353}},	//   ፈልገው, _ağar_, _سمیر, _fecs, 
   {{0xda642c81,0x7d0c00a2,0x9f5c0cad,0xe7200171}},	//   عالي, _gecs, _ìwò_, džšī, 
   {{0xaca4063f,0x02b80118,0x00000000,0x00000000}},	//   _maịs, _उड्न, --, --, 
   {{0xbcf80c6a,0xdb04002d,0xa6340212,0x00000000}},	//   _anéh, anhâ, енкі, --, 
   {{0x9f8c0008,0x2b58009b,0x645c1d77,0xf76c1e4b}},	//   nþá_, _iarc_, ārim, شاو_, 
   {{0xa5341631,0x75e40166,0x2b5800e5,0xdb0c0ca8}},	//   хнич, _sızr, _harc_, _ìkòk, 
   {{0x82e80327,0x56e400d1,0x041c05ac,0x00000000}},	//   _རྔུའ, мбәғ, _বঙহী_, --, 
   {{0xc7647165,0x2b587fc2,0x7c2800cf,0xfc700092}},	//   _تارى, _jarc_, àgri, _ከዘጠኙ_, 
   {{0x2b58664a,0x32b401c0,0xf79401b9,0xa1580114}},	//   _marc_, дгээ_, _تنلب_, пану_, 
   {{0xc48463e8,0x68e401fa,0x69440010,0xd5b801ec}},	//   _олек, židu, _učeč, _есі_, 
   {{0x2b8405d5,0xdcec00d0,0xc6240154,0xf574007b}},	//   _töch_, tiaľ, _মনটা_, _تمنع_, 
   {{0x2b59c354,0x7d0c2b52,0xb38001c6,0xbef8134e}},	//   _narc_, _secs, _илчл, ्रेन_, 
   {{0xf408003d,0x3ce9c355,0x2484030a,0x7d0c01d3}},	//   _གསོད_, _pgcv_, lymm_, _pecs, 
   {{0x7f5401d9,0x7c8400c7,0xbcf804e6,0x8bf400cc}},	//   _waxq, музе, _knéi, _চিজন_, 
   {{0x7d0dc356,0x2b58996f,0x9f480055,0xff04020f}},	// [31e90] _vecs, _barc_, _itaþ_, _оянн, 
   {{0x290001c4,0x2ef80129,0xfaa40150,0x00000000}},	//   ñian_, ccrf_, мшен, --, 
   {{0x2b580165,0x7d0dc357,0x20180ff3,0x7f8806be}},	//   _darc_, _tecs, lssi_, _hüqo, 
   {{0x645c00da,0xbcf80036,0xf8100133,0xdd9400db}},	//   ārij, _onéi, نستگ, _чамы, 
   {{0x2b59c358,0x201802f6,0xf408025c,0xfd1c0241}},	//   _farc_, nssi_, _གསེད_, _idì_, 
   {{0x20180ffb,0x29d400d1,0xb8e41fd2,0x00000000}},	//   issi_, ىيەس, _उड_, --, 
   {{0x19940aec,0xbcf806ed,0x29e8010b,0x9f4800ae}},	//   _завя, _anéi, _işan_, _nuaí_, 
   {{0xb4c001e0,0xead40064,0x00000000,0x00000000}},	//   кийҙ, _рось, --, --, 
   {{0x75e427ac,0x00000000,0x00000000,0x00000000}},	//   _qızq, --, --, --, 
   {{0xd2940139,0xbef812eb,0x00000000,0x00000000}},	//   ермь, ्रोन_, --, --, 
   {{0x20180a55,0x338402d3,0x673c0267,0xfd1c0248}},	//   essi_, _ዝወረደ_, _örja, _odì_, 
   {{0x8658011a,0x00000000,0x00000000,0x00000000}},	//   _מדעי, --, --, --, 
   {{0xbcf80597,0xd468010b,0x00000000,0x00000000}},	//   _gnéi, _хиле_, --, --, 
   {{0xd72003d4,0x5338010f,0x8898011a,0x00000000}},	//   প্ৰা_, _זײַד, לברי, --, 
   {{0x201808e5,0x5ec400d1,0x00000000,0x00000000}},	//   assi_, вирғ, --, --, 
   {{0xbef802ab,0x2b580072,0x29e85397,0x6cb4009d}},	//   ्रॉन_, _sarc_, _aşan_, вөгт, 
   {{0x6aa81b76,0x41b0310b,0x788400dc,0x00000000}},	// [31ea0] कप्र, _حمير, _jīvā, --, 
   {{0xfd1c07c5,0xace800fb,0x6dac0166,0x00000000}},	//   _edì_, змға_, kşag, --, 
   {{0x7b8405a9,0x2b580489,0x788400e2,0x00000000}},	//   راكە, _varc_, _līvā, --, 
   {{0x2b580156,0x00000000,0x00000000,0x00000000}},	//   _warc_, --, --, --, 
   {{0xc7c5c359,0xd90d617d,0x2b59c35a,0x645c0b3a}},	//   нски, زیل_, _tarc_, ārik, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbb40ca5f,0x6e3c01e0,0x6dac0790,0xf8ac00e5}},	//   _щерк, ntrb, rşaf, لکے_, 
   {{0x20180393,0x3a2400e4,0x00000000,0x00000000}},	//   yssi_, ánpe_, --, --, 
   {{0xe3240156,0x97c40075,0x7af0036e,0x6dac010e}},	//   _འཐདཔ_, رتۇم, _çetë, mşad, 
   {{0x73d45409,0x788400e2,0x6dadc35b,0x00000000}},	//   ндыр_, _dīvā, lşad, --, 
   {{0xbcf8004a,0xa1940b3b,0x5ea40154,0x28a41b97}},	//   _inév, ванч, _খুনে, _खेति, 
   {{0xd25000ec,0x00000000,0x00000000,0x00000000}},	//   جنٽ_, --, --, --, 
   {{0x20195a6d,0xa2cc07f7,0x6dac0139,0x00000000}},	//   ussi_, _हरक्, lğaw, --, 
   {{0x20186583,0xf1f412ea,0xdc7c0092,0xdfd40304}},	//   rssi_, بعیت_, _የመማር_, тогы, 
   {{0xf574022e,0x2e482d29,0x7fd40150,0x00000000}},	//   _bag訴, нято_, діңі, --, 
   {{0x99800118,0x00000000,0x00000000,0x00000000}},	//   vrhů_, --, --, --, 
   {{0x5bc4036b,0xe81c01f9,0x00000000,0x00000000}},	// [31eb0] نقرل, _निगा_, --, --, 
   {{0xdb04032e,0x00000000,0x00000000,0x00000000}},	//   fnhá, --, --, --, 
   {{0x5a35c35c,0xfe240022,0x05b0012d,0xdb04032e}},	//   тнет, _џьон, ुकाब, gnhá, 
   {{0x3c40005f,0xfd1c07c5,0xbcf80129,0xb3800023}},	//   tīvā_, _udì_, _anév, _ይወድቕ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3d180241,0xa7640150,0x00000000,0x00000000}},	//   bàwí_, лкід, --, --, 
   {{0xead5c35d,0x788400ef,0x00000000,0x00000000}},	//   _борь, _sīvā, --, --, 
   {{0x96d40022,0x00000000,0x00000000,0x00000000}},	//   нсқә, --, --, --, 
   {{0x160c00af,0x00000000,0x00000000,0x00000000}},	//   _सबकर_, --, --, --, 
   {{0x83601a59,0x394dc35e,0x75e401d3,0x257801d3}},	//   لگىل, legs_, _tűzo, _mély_, 
   {{0x7988073c,0x27f809a8,0xb0040055,0x00000000}},	//   okgw, _črni_, _viḍv, --, 
   {{0x798827be,0x0f080141,0x00000000,0x00000000}},	//   nkgw, वर्स_, --, --, 
   {{0x63bc00a3,0x0f300023,0x00000000,0x00000000}},	//   ōrna, _ይምልከ, --, --, 
   {{0xa3b805d9,0x29e80139,0x53a4a4d0,0x00000000}},	//   _ٻاهر_, _aşal_, _шалб, --, 
   {{0x24e400c7,0x5ea400fe,0x62644677,0x69c4012d}},	//   _ицәг, _খুবে, _مايق, िकमी, 
   {{0xd1b9c35f,0x5ef801c6,0x8c4492fe,0xc6900677}},	//   _تاتا_, _үхэр_, кебе, באל_, 
   {{0xe9857560,0x394dc360,0x00000000,0x00000000}},	// [31ec0] ққан, degs_, --, --, 
   {{0x58240327,0x00000000,0x00000000,0x00000000}},	//   _རཀྟོ_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9974005b,0x996401ec,0xf1b41546,0x29180171}},	//   лучш, лтіл, ीविन, _ēras_, 
   {{0x7bc400c6,0x2578b181,0x2d8c00e2,0xd90c51ae}},	//   _fkju, _gély_, ūdes_, ثیق_, 
   {{0xc66807d8,0x7d0400c7,0x466832b0,0xb7d406c2}},	//   дшие_, _térâ, дрим_, نونا_, 
   {{0x6ae003f4,0x394c0064,0x0928007b,0xdb0402d2}},	//   _প্রো, begs_, _يسري_, fnhæ, 
   {{0x0465145b,0xd5f4004b,0x80d00073,0xd90c158f}},	//   втом, دتوګ, _ठरले, _فیم_, 
   {{0xdc3006be,0x25081291,0x00000000,0x00000000}},	//   _müğe, ورکی_, --, --, 
   {{0x987403e0,0x00000000,0x00000000,0x00000000}},	//   lüğe_, --, --, --, 
   {{0xd62405d9,0xc568007b,0xc5f4011c,0x00000000}},	//   _معني, _يحصل_, _рязъ, --, 
   {{0xfbdc0368,0x74116e8a,0x20980139,0xd24c00f7}},	//   _apêl_, _چونا, екмы_, سچى_, 
   {{0x741006f6,0x00000000,0x00000000,0x00000000}},	//   _نونا, --, --, --, 
   {{0x9e35c361,0x00000000,0x00000000,0x00000000}},	//   легч, --, --, --, 
   {{0x2bec02ab,0x63a9c362,0x394c0793,0xdc30013d}},	//   _अंजू_, midn, yegs_, _büğe, 
   {{0x7bc417c0,0x62895072,0x00000000,0x00000000}},	//   _skju, mydo, --, --, 
   {{0x6288d346,0x394d8ebc,0x61ed7947,0xfafc00e2}},	// [31ed0] lydo, vegs_, _iial, žīms_, 
   {{0x61ec0851,0x394c17da,0x916001e1,0xfec8007b}},	//   _hial, wegs_, _kó̟_, _يبدو_, 
   {{0x61edc363,0xceb40075,0x916001e1,0x60cc002b}},	//   _kial, _бәт_, _jó̟_, _hyam, 
   {{0x60cc8bc8,0xaa65c364,0x61ec0363,0xeea80104}},	//   _kyam, штук, _jial, _штык_, 
   {{0x61edc365,0x394cb25d,0x60cc0223,0x97540055}},	//   _mial, regs_, _jyam, _aṇav, 
   {{0x61edc366,0xab847ffd,0xe7081f7a,0x7bc40784}},	//   _lial, _куск, پتون_, _ukju, 
   {{0x27edc367,0x60cc0a49,0x63a9909c,0x398000f2}},	//   _didn_, _lyam, didn, _پیشف, 
   {{0x61edc368,0x60cdc369,0xbcf8002e,0x473000fd}},	//   _nial, _oyam, _gnét, анәс, 
   {{0x63a80009,0x649801c6,0xbcf8032e,0x00000000}},	//   fidn, втэр_, _hnés, --, 
   {{0x61edc36a,0x3688010b,0xbcf802d2,0x63a801ef}},	//   _aial, _осен_, _knés, gidn, 
   {{0x61ec97d4,0xbcf80098,0xe7847991,0x6288541b}},	//   _bial, _kaéd, _туто, gydo, 
   {{0x60cdc36b,0x3cec00c5,0x7af803e0,0x862000f2}},	//   _byam, _अलगे_, _şutl, _اکول, 
   {{0x60cc0796,0x0d8447b3,0xbcf8020c,0xc9500375}},	//   _cyam, қлан, _maéd, צמך_, 
   {{0x63a80fcf,0x60cdc36c,0x6288bcec,0x61ec01c7}},	//   cidn, _dyam, bydo, _eial, 
   {{0x61edc36d,0x225804ce,0x60cdc36e,0x62880034}},	//   _fial, ærkt_, _eyam, cydo, 
   {{0x61edc36f,0xdb040112,0xc6900677,0x00000000}},	//   _gial, hnhä, זאל_, --, 
   {{0x9f4808e7,0xbcf8004e,0x60cdc370,0x00000000}},	// [31ee0] _etañ_, _anés, _gyam, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x0928023a,0x61ec062c,0xdc300139,0x60cc0055}},	//   ежей_, _yial, _tüğe, _zyam, 
   {{0x8d545a5a,0x975400b8,0xdb0401f4,0x00000000}},	//   _сточ, _rṇav, enhä, --, 
   {{0x63a406a3,0xbcf809c2,0x6288012d,0x98740205}},	//   _ïing, _enés, zydo, rüğe_, 
   {{0x7c280579,0xcb740640,0xf8640b24,0xdb04007c}},	//   ágre, _сумњ, اموي_, gnhä, 
   {{0xb8e8000b,0xbb3800c8,0x78b99fe0,0xbcf80798}},	//   _रु_, _רעלי, _exuv, _inér, 
   {{0x27ec0204,0xdb040e78,0x7ae000e4,0x35f40066}},	//   _widn_, anhä, ýnte, درود_, 
   {{0x61ec06d5,0x63a8049f,0xc508109c,0x80d009bb}},	//   _rial, tidn, وتکل_, _सरें, 
   {{0x60cc8aa7,0xa9a42f0d,0xb890007b,0xc76400db}},	//   _ryam, _сиғд, _الكع, _حارى, 
   {{0x61edc371,0xf361c372,0xa17412fa,0x854400c0}},	//   _pial, стын, агні, _бэле, 
   {{0x6289c373,0xc0c80046,0x61ec013c,0x63a96740}},	//   rydo, еуге_, _qial, sidn, 
   {{0x61edc374,0x1438034c,0x29e8010b,0xbcf806af}},	//   _vial, _لينک_, _aşak_, _onér, 
   {{0x60cdc375,0x2d8c0a85,0x6d440093,0x98a8033f}},	//   _vyam, êden_, efia, żać_, 
   {{0x6d45c376,0x61edc377,0x6e9427a8,0xa194010a}},	//   ffia, _tial, биру, _вайч, 
   {{0x2d5812a2,0x5d540261,0xd24dc378,0xdcec0cf4}},	//   лись_, јкат, _کچی_, njać, 
   {{0x60cc3e6e,0x656000c6,0x6441c379,0x5c74ffec}},	// [31ef0] _uyam, idmh, ntmi, шлат, 
   {{0x6d455ebe,0x9d1400bd,0xd9dc4668,0x6440002f}},	//   afia, িলেন_, यष्ट, itmi, 
   {{0xbcf800f2,0x644000c5,0x1bf00027,0xddb800c0}},	//   _paéd, htmi, _अंकल_, _агні_, 
   {{0xbcf90eb5,0x64403402,0x00000000,0x00000000}},	//   _qaéd, ktmi, --, --, 
   {{0x7c84084c,0xe8f9c37a,0xcc840133,0xb8800139}},	//   _суне, улі_, _پۆله_, _ğísy, 
   {{0xbcf80129,0xd7c8027d,0x17c802e8,0x1638007b}},	//   _inéq, خوته_, ъгли_, نسبة_, 
   {{0xbcf834fe,0x61fc0077,0xdb0426bc,0x6624007b}},	//   _unés, írll, rnhä, مريك, 
   {{0x6440041e,0x6dac00fd,0xd5b096b4,0x69d80129}},	//   ftmi, lğar, تفع_, ïvet, 
   {{0x6440005c,0x49a4329e,0xed600118,0xddcc00d7}},	//   gtmi, _тырғ, ážit_, ľkňa, 
   {{0x395dc37b,0x53a400f3,0x00000000,0x00000000}},	//   _haus_, раоб, --, --, 
   {{0x395dc37c,0xd57506e4,0xdcec00df,0x6d4403cb}},	//   _kaus_, _вуль, miaĵ, yfia, 
   {{0x9f481bb0,0x95e801d9,0x395c00c0,0x00000000}},	//   _stað_, _شباہ_, _jaus_, --, 
   {{0x395dc37d,0xe3b1c37e,0x20b800fd,0xcfa803b6}},	//   _maus_, _کرن_, гырь_, ناسم_, 
   {{0x395c0457,0xc7b0008f,0xdcec0115,0x4fc000d1}},	//   _laus_, ַבן_, niaĵ, تەخە, 
   {{0xeab00d42,0x74d4015b,0x1aa4000d,0x00000000}},	//   _কর্ম, _হলিউ, _गेलथ, --, 
   {{0x395dc37f,0xcd0528a1,0xbcf801a8,0x00000000}},	//   _naus_, рпай, _snér, --, 
   {{0x6d45c380,0x00000000,0x00000000,0x00000000}},	// [31f00] rfia, --, --, --, 
   {{0x3161c381,0x8b2402bf,0x6d45c382,0x06b00154}},	//   _haiz_, рдже, sfia, য়েটি, 
   {{0x29e80274,0x338402d3,0xdcec01e4,0x272c01e1}},	//   _uşak_, _ዝወሰደ_, diaĵ, _lónà_, 
   {{0x6f1dc383,0x395dc384,0xd90c034c,0x9f4001f4}},	//   larc, _caus_, فیف_, _eihä_, 
   {{0x395dc385,0x3161c386,0xdcec0115,0xbcf80129}},	//   _daus_, _maiz_, fiaĵ, _inép, 
   {{0x0eb805f9,0x6f1dc387,0xdcec0115,0x3b05b6cc}},	//   _उखाड, narc, giaĵ, _веро_, 
   {{0x395dc388,0x09e40138,0x00000000,0x00000000}},	//   _faus_, _вовн, --, --, 
   {{0x6f1dc389,0x316005f5,0x64402a5b,0x395dc38a}},	//   harc, _naiz_, ttmi, _gaus_, 
   {{0x64400254,0x00000000,0x00000000,0x00000000}},	//   utmi, --, --, --, 
   {{0x46a406bb,0x395c0457,0x6f1dc38b,0x6441c38c}},	//   _казв, _zaus_, jarc, rtmi, 
   {{0x6441c38d,0x31600007,0x6f1dc38e,0x395c0070}},	//   stmi, _baiz_, darc, _yaus_, 
   {{0x0444db74,0x395c0070,0x6f1c010a,0xd3f0004b}},	//   _ведн, _xaus_, earc, _کړيد, 
   {{0x6f1dc38f,0x31600369,0x7f8806be,0xc61c00cc}},	//   farc, _daiz_, _müqv, _দহটা_, 
   {{0x6f1dc390,0x630407d6,0x1ae00154,0x04c40451}},	//   garc, _اوغل, মুয়া, _ٽوڙي_, 
   {{0x3161c391,0x3da4f1b8,0xf8d0258d,0xfda40063}},	//   _faiz_, араб, _तर्प, ајам, 
   {{0xeab00183,0xdcec00df,0x00000000,0x00000000}},	//   _কৰ্ম, ziaĵ, --, --, 
   {{0x2d5805b0,0x395dc392,0x61f80477,0xdb1400a2}},	// [31f10] шить_, _raus_, _huvl, _ekzý, 
   {{0x6f1dc393,0x6b7419bb,0x00000000,0x00000000}},	//   carc, олуу, --, --, 
   {{0x395dc394,0x61f8014f,0x2bb8e858,0x6dac2093}},	//   _paus_, _juvl, _आदरा, mşan, 
   {{0x395c0218,0x248002b5,0x75e401ed,0x0e000107}},	//   _qaus_, _kōmā_, _tűzi, _хӯро, 
   {{0x395dc395,0x4dd80375,0x61f800b5,0xfc3c013d}},	//   _vaus_, _תחרו, _luvl, _uqí_, 
   {{0x06b000bd,0x395c0198,0x61f8007f,0x37a80395}},	//   য়েছি, _waus_, _ouvl, ътен_, 
   {{0x395dc396,0x1ae41c82,0xdcec010f,0x272c0ca8}},	//   _taus_, _প্ৰা, riaĵ, _sónà_, 
   {{0x6f1dc397,0x056002e8,0x6dac010e,0xe6b40116}},	//   zarc, звън, hşan, تلىگ, 
   {{0x7f880cc1,0x6f1dc398,0x31607499,0x53c8e8f6}},	//   _hüqu, yarc, _raiz_, лгим_, 
   {{0x3160001f,0x61f83733,0x7d00013f,0x18b001e0}},	//   _saiz_, _buvl, ɛnse, _мәҙр, 
   {{0x6f1dc399,0x61f804cc,0x29e80166,0x20cc01a9}},	//   varc, _cuvl, _ağay_, mоiy_, 
   {{0x61f8d863,0x6f1dc39a,0x32400023,0x00000000}},	//   _duvl, warc, _ንካልኣ, --, 
   {{0x31600007,0x76400263,0x8fd000fd,0x6ad400e1}},	//   _vaiz_, ltny, зәнә, _थर्र, 
   {{0x7640020b,0x20cc022e,0x00000000,0x00000000}},	//   otny, nоiy_, --, --, 
   {{0xe3b0004b,0x29dc004e,0xff0400a8,0x7641c39b}},	//   _غره_, níac_, сеск_, ntny, 
   {{0x6f1dc39c,0x76405afc,0xd1b800db,0x2174010a}},	//   sarc, itny, _حاتا_, _дуьр, 
   {{0xcaf4ed6a,0x6f1dc39d,0xbcf8003a,0x4b24187f}},	// [31f20] مساب, parc, _saéc, ймав, 
   {{0x7641c39e,0x6dac0311,0x61f80477,0x6f1dc39f}},	//   ktny, cşan, _yuvl, qarc, 
   {{0x4a44117e,0x00000000,0x00000000,0x00000000}},	//   снев, --, --, --, 
   {{0x38c8130e,0x48e4023b,0x29dc004e,0x8c440354}},	//   گامی_, боев, díac_, _леме, 
   {{0x7640012d,0x1bf000ce,0x00000000,0x00000000}},	//   etny, _अंचल_, --, --, 
   {{0x38c8034c,0xdb04002d,0xd90c01ed,0x5b3400a8}},	//   دامی_, aihâ, فیہ_, _мэсу, 
   {{0xd7f00051,0xd90c02f2,0x36840395,0x00000000}},	//   _dĩ_, _ڤیه_, йсън_, --, 
   {{0x2d81c3a0,0x9aa800db,0x00000000,0x00000000}},	//   njie_, _ئچكە_, --, --, 
   {{0x61f9c3a1,0x7641c3a2,0x7af80139,0x245400db}},	//   _suvl, atny, _şuti, تچاس, 
   {{0x61f8047e,0x66e40116,0x44280010,0x00000000}},	//   _puvl, _ғоҗа, čb_, --, 
   {{0x2179c3a3,0x76400263,0x29dc004e,0x61f831c5}},	//   айны_, ctny, cíac_, _quvl, 
   {{0x920c0165,0x61f8014f,0xe1f800db,0xd2a8030d}},	//   _alẓẓ_, _vuvl, лгү_, ăкне_, 
   {{0x2d800151,0x24180220,0x61f80455,0xdb040162}},	//   djie_, _толы_, _wuvl, rnhú, 
   {{0xdbf00316,0x22940075,0x2ca001fa,0xa29402d5}},	//   _příl, _миля, dzid_, _малі, 
   {{0xe3b800fd,0x6e9407d9,0xe51c00cd,0x00000000}},	//   mnı_, пиру, नरपि_, --, 
   {{0x2d800240,0xe3b800fd,0x00000000,0x00000000}},	//   gjie_, lnı_, --, --, 
   {{0x212831e5,0x7dd02e11,0x75e401d3,0x7f8803e3}},	// [31f30] _idah_, nçsi, _tűzv, _süqu, 
   {{0xe3b80724,0x2009c3a4,0xdb05c3a5,0xdbf00118}},	//   nnı_, _itai_, nnhø, _tříl, 
   {{0x9f480270,0x21280c6a,0xdab800c6,0x2ca00423}},	//   _ouaú_, _kdah_, جهات_, azid_, 
   {{0xe3b800ac,0xd7f0004d,0xfbf0014b,0x00000000}},	//   hnı_, _sĩ_, _номӯ, --, 
   {{0xe3b80724,0x2128003e,0x7d1dc3a6,0x00000000}},	//   knı_, _mdah_, maqs, --, 
   {{0xdb140100,0x97341a69,0x7d1dc3a7,0x7641c3a8}},	//   _ekzò, تکرا, laqs, ttny, 
   {{0x21280c6a,0x19940006,0x29e80166,0x99800098}},	//   _odah_, _давя, _aşau_, nshū_, 
   {{0x7d1dc3a9,0x2009c3aa,0x7641c3ab,0x672802d0}},	//   naqs, _otai_, rtny, _eddj, 
   {{0x76405db4,0x6dac00a2,0xc6980023,0xe3b8013d}},	//   stny, dşal, _ገይርካ_, fnı_, 
   {{0x7d1c0227,0x2128003e,0x7640020b,0x7084013e}},	//   haqs, _adah_, ptny, ҷҳиз, 
   {{0x2009c3ac,0x362001d9,0x33240139,0xabcc010f}},	//   _atai_, _روشہ, _vdnx_, רציִ, 
   {{0xc5a40451,0xf6500107,0xe3b85656,0x59c81100}},	//   _وڏين_, _меҷӯ, anı_, िकिर, 
   {{0x7d1c022f,0x7538030a,0x6f0001e1,0xe3b8013d}},	//   daqs, mguz, _nàbó, bnı_, 
   {{0xaee40084,0x21285103,0x7538009d,0xdcfc0171}},	//   waṱh, _edah_, lguz, _rosā, 
   {{0x59c80cf1,0x2d800591,0x7d1c01d9,0x43700fb4}},	//   िकार, tjie_, faqs, _زهير, 
   {{0x7539c3ad,0x00000000,0x00000000,0x00000000}},	//   nguz, --, --, --, 
   {{0x7538009d,0x2d800af9,0x00000000,0x00000000}},	// [31f40] iguz, rjie_, --, --, 
   {{0x6134022e,0xac08f8fb,0x29e80139,0x09d0041c}},	//   _hоlа, инға_, _lşat_, तत्य, 
   {{0x2905c3ae,0xfaa00f1a,0x9c4801ec,0x7d1c79fa}},	//   _pfma_, мафо, _қорғ_, baqs, 
   {{0xe3b80724,0x7d1c00ac,0xcd35c3af,0x00000000}},	//   znı_, caqs, _بردب, --, 
   {{0xbcf8a507,0xe3b89d5d,0x6dac0356,0xdb040162}},	//   _kaén, ynı_, nşam, ynhø, 
   {{0x61fc008f,0xa5f8014b,0x00000000,0x00000000}},	//   ŭrli, беку_, --, --, 
   {{0xbf981e4f,0x29040109,0xbcf80c6a,0x29000407}},	//   mpêt, _tfma_, _maén, ñias_, 
   {{0xdb04ec21,0x753804ba,0xbf980129,0x6dac0166}},	//   mihá, gguz, lpêt, kşam, 
   {{0xc31c00bd,0xe3b80724,0x399400a2,0x00000000}},	//   _দাবি_, tnı_, _uçsa_, --, 
   {{0x212806df,0x753804ba,0x61b400dc,0xfbbc00cd}},	//   _sdah_, aguz, ृक्ष, ्वयम, 
   {{0x2009c3b0,0xe3b81248,0x225807d8,0x6134022e}},	//   _stai_, rnı_, щины_, _bоlа, 
   {{0xe3b800db,0x00000000,0x00000000,0x00000000}},	//   рбү_, --, --, --, 
   {{0xd5e800c6,0xd3100055,0xded400b7,0x6dac00a2}},	//   _اعلن_, _aṇur_, ሪውን_, gşam, 
   {{0x4425c3b1,0xe3b800fd,0x5f94009d,0x00000000}},	//   _ivo_, qnı_, чигт, --, 
   {{0x4425c3b2,0x7d1c03f0,0x75e400e5,0x6dac00a2}},	//   _hvo_, taqs, _tűzt, mşaj, 
   {{0x212805ba,0x442401e4,0xdb04ea5b,0x00000000}},	//   _udah_, _kvo_, dihá, --, 
   {{0x44240066,0x20080618,0xad240131,0x9c180592}},	// [31f50] _jvo_, _utai_, بىقى, صياء_, 
   {{0x4424679c,0x6134022e,0x7d1ceef1,0x00000000}},	//   _mvo_, _zоlа, saqs, --, 
   {{0xb898001f,0x5975c3b3,0x7d1c0309,0xdd58026b}},	//   _ገልጸው_, зылу, paqs, _ланч_, 
   {{0x44241326,0x7d1dc3b4,0xceb0010f,0x00000000}},	//   _ovo_, qaqs, _טיי_, --, 
   {{0x48e407f7,0x490800ab,0x7af976d0,0xd5e4009d}},	//   जेलो_, ाड़ो_, _şutu, үжли, 
   {{0x29dc0077,0xac1801ee,0xa7b80354,0x59c800bc}},	//   ríaa_, _фору_, олчу_, िकहर, 
   {{0x4425c3b5,0x29dc5793,0x35c0013e,0x377002dd}},	//   _avo_, mían_, макҳ, зықс, 
   {{0xf1c002fb,0x442401f5,0xf77005d9,0x29dc936e}},	//   čák_, _bvo_, _ڪار_, lían_, 
   {{0x7539c3b6,0x7998c562,0x93780597,0x44240b4f}},	//   rguz, _iluw, مصدر_, _cvo_, 
   {{0xf771c3b7,0x29dc204e,0x44241a48,0xf6c80166}},	//   _تار_, nían_, _dvo_, _кыек_, 
   {{0x442404b9,0x7999c3b8,0xbcf8003e,0xe664023a}},	//   _evo_, _kluw, _raén, _отцо, 
   {{0xbcf8034c,0xe61004fb,0x6134022e,0x44240208}},	//   _saén, _ششم_, _qоlа, _fvo_, 
   {{0x764802d5,0x92b40403,0x23840023,0x00000000}},	//   žnyč, تحکا, _ዝገዝእ_, --, 
   {{0x799802d1,0x6dac03ee,0x7d1800df,0xa3cc0073}},	//   _lluw, rşam, _ĵusa, लवण_, 
   {{0x29dc09ff,0x5275c3b9,0xfbc0009e,0x6d9808a5}},	//   dían_, _хулу, ্গাত, _dían, 
   {{0xb880012c,0xbd8000c0,0xdb05c3ba,0x6dac010e}},	//   _klíč, нгск, vihá, mşak, 
   {{0xc31c00cc,0x29ddc3bb,0x00000000,0x00000000}},	// [31f60] _দাতি_, fían_, --, --, 
   {{0x7999c3bc,0x0ba80137,0x29dc3eba,0xdbf00118}},	//   _aluw, حارى_, gían_, _přál, 
   {{0x9f05c3bd,0xc3300302,0xbcf80264,0xfbdc0798}},	//   _توپو, תוב_, _kaél, _apês_, 
   {{0x7998020c,0xdb05c3be,0x29e81ea0,0x00000000}},	//   _cluw, rihá, _aşar_, --, 
   {{0x29dc1280,0x799800f2,0xdcfc00c0,0x00000000}},	//   bían_, _dluw, _alsė, --, 
   {{0x29dc09ff,0x44241529,0x79980083,0xdb0400e4}},	//   cían_, _rvo_, _eluw, pihá, 
   {{0x44240f99,0x7999c3bf,0x4e78008f,0x00000000}},	//   _svo_, _fluw, מאַצ, --, 
   {{0x4425c3c0,0x00000000,0x00000000,0x00000000}},	//   _pvo_, --, --, --, 
   {{0x4425513a,0x69c0047e,0xb7d43fb8,0x86c40633}},	//   _qvo_, _ijme, _کولا_, _کيان, 
   {{0x442401f4,0x389800d9,0xd5b892fe,0x00000000}},	//   _vvo_, _הימנ, йсө_, --, 
   {{0xfbbc63a5,0x869800cf,0xe1340139,0x4abc043e}},	//   ्वतम, _утат_, мнны, ्थिव, 
   {{0x4425c3c1,0xb880013a,0x00000000,0x00000000}},	//   _tvo_, _flíč, --, --, 
   {{0x4425c3c2,0x6d9808a5,0xe81001f9,0x75e400e5}},	//   _uvo_, _pían, ठीचा_, _tűzr, 
   {{0xf4240135,0x29dc0005,0x4abc29d9,0x00000000}},	//   _ལྗིད_, xían_, ्थाव, --, 
   {{0xd3e40b29,0x29dc2b76,0x6d980077,0x00000000}},	//   _تقوی, vían_, _vían, --, 
   {{0xbcf9c3c3,0xb2b8011a,0x6dac03e3,0x00000000}},	//   _gaél, _למור, nşah, --, 
   {{0x6c55c3c4,0x29dc2b76,0xa3d01f14,0x6d980174}},	// [31f70] нкту, tían_, वकप_, _tían, 
   {{0x69c0107d,0x7999c3c5,0xa2a00490,0x00000000}},	//   _ajme, _sluw, खनप्, --, 
   {{0x29dc28f2,0xbcf8020c,0x7999c3c6,0xa9ac00d1}},	//   rían_, _yaél, _pluw, ﻳﻬﯩﺴ, 
   {{0xbcf8003e,0x20e0043e,0x58d801f4,0x00000000}},	//   _kaém, _नराध, одея_, --, 
   {{0xa3cdc3c7,0xe658001f,0x6dac03e3,0x00000000}},	//   लवा_, ጋግጠዋ, dşah, --, 
   {{0xf771c3c8,0x7dd00205,0x00000000,0x00000000}},	//   عاش_, rçsu, --, --, 
   {{0x7999c3c9,0x29dc0077,0xa3d000af,0x00000000}},	//   _tluw, cíao_, वकन_, --, 
   {{0x79980a2e,0x6dac03e0,0x00000000,0x00000000}},	//   _uluw, vşak, --, --, 
   {{0xe5040f1b,0xd4682617,0x93581b4f,0xa9780166}},	//   ربيي, ципе_, орну_, _эйту_, 
   {{0x66740131,0xfbbc00cd,0x00000000,0x00000000}},	//   بدۇر, ्विम, --, --, 
   {{0x7d1801e4,0xdb0401f4,0x00000000,0x00000000}},	//   _ĵusn, mihä, --, --, 
   {{0x6d98013d,0x3d14033f,0xdb04340f,0x00000000}},	//   _cíal, तरों_, lihä, --, 
   {{0xfbbca782,0x6d9802d2,0xa07400c7,0x00000000}},	//   ्वाम, _díal, нырш, --, 
   {{0xf00405f5,0x9574001f,0xc34c01fb,0xdb05c3ca}},	//   _үүни, ያዎችን_, _hổng_, inhó, 
   {{0x29e80166,0xb0040055,0x00000000,0x00000000}},	//   _oşap_, daḥk, --, --, 
   {{0xdb040254,0x00000000,0x00000000,0x00000000}},	//   hihä, --, --, --, 
   {{0x0fc40fc0,0xe8dc0490,0x8b24109a,0xdb040108}},	// [31f80] _ойин, _बरेच, ддзе, kihä, 
   {{0x29e8013d,0xc34c0051,0xa90c00fe,0x6d980139}},	//   _aşap_, _lổng_, _ৱাইড_, _zíal, 
   {{0x7ea0022e,0xd5dc02ab,0x3ab004a9,0x00000000}},	//   _bеpu, मताज, вәтт, --, 
   {{0x6e3dc3cb,0x29dc0005,0x7d00013f,0x2d840124}},	//   murb, ríao_, ɛnso, _õme_, 
   {{0xdcb80664,0xc7c5c3cc,0x7ea0022e,0x22940ca8}},	//   _ещё_, мски, _dеpu, _kúkú_, 
   {{0xe70420d3,0xc1b807b7,0xa5f86dac,0x00000000}},	//   رستی, _उद्ग, пеку_, --, 
   {{0x6e3dc3cd,0xc34c001e,0x29dc0113,0xdb0c00e4}},	//   nurb, _bổng_, líam_, _ãháp, 
   {{0xc34c0016,0x229401e1,0x200c0356,0x69c001ef}},	//   _cổng_, _lúkú_, ţeii_, _ujme, 
   {{0x29e803be,0x28899c56,0x00000000,0x00000000}},	//   _uşaq_, _عصری_, --, --, 
   {{0x6e3dc3ce,0xdb0405d1,0x73d400b1,0x00000000}},	//   kurb, rihç, мдыр_, --, 
   {{0xa2941ed2,0xbcf800d5,0x6d980166,0xd76400db}},	//   хані, _saém, _píal, _سەيى_, 
   {{0x178000c7,0x6e3dc3cf,0xdb04007c,0x9f580254}},	//   _ақәг, durb, mihå, spsü_, 
   {{0x24800790,0xdcec025c,0x00000000,0x00000000}},	//   _çim_, kkaġ, --, --, 
   {{0x32880882,0x234803e6,0x6e3c4219,0x00000000}},	//   ṣaṃ_, _رستی_, furb, --, 
   {{0x6e3dc3d0,0xfbbc012a,0x3d180b4c,0x00000000}},	//   gurb, ्वसम, बरले_, --, 
   {{0xe3c0009e,0xc34c0051,0x00000000,0x00000000}},	//   _উঠিব, _xổng_, --, --, 
   {{0x609801d9,0x7ea00139,0xdb0401f4,0x9c380150}},	// [31f90] _رندس_, _rеpu, yihä, япат_, 
   {{0xa3e44244,0x23a00100,0x9e680092,0x00000000}},	//   _भीम_, _fòje_, _ችግርና_, --, 
   {{0x23a0007f,0xe3c0009e,0x752d2e75,0x00000000}},	//   _gòje_, _উঠাব, óczk, --, 
   {{0xbd9802d3,0xead80212,0x9b881bf4,0x00000000}},	//   _ቀሪቦም_, ємці_, _کنسل_, --, 
   {{0xcdc000d1,0xdb04005b,0x69c402c3,0x00000000}},	//   _сәрп, tihä, िकजी, --, 
   {{0xbcf800e4,0xc34c0051,0xe8f828f6,0x00000000}},	//   _anéx, _sổng_, флі_, --, 
   {{0xbcf80c6a,0xdb040e03,0x55940798,0xab84014b}},	//   _naék, rihä, ејпф, _руяк, 
   {{0xab880092,0x96d400c7,0xeef8011a,0xdb040108}},	//   _በማደግ_, мсқә, ומור_, sihä, 
   {{0x6e3c022e,0x45a0215c,0x00000000,0x00000000}},	//   zurb, دەنك, --, --, 
   {{0xd2a8005b,0x286801d5,0x00000000,0x00000000}},	//   зкое_, _ўрто_, --, --, 
   {{0xc34c07ae,0x6e3c0036,0x26b000d1,0x88300092}},	//   _tổng_, xurb, _پەيز, _አልተደ, 
   {{0xbcf80c6a,0xc34c004d,0x48e4012c,0x0ef81b76}},	//   _daék, _uổng_, जेको_, ्ड्स_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x0d201e87,0xa3cc0073,0x63c401ee,0x00000000}},	//   лүнү, लवर_, _шашҡ, --, 
   {{0x6e3dc3d1,0x8b64029c,0xd9c81157,0x00000000}},	//   rurb, کارم, िकोट, --, 
   {{0x6e3dc3d2,0xabd400aa,0xbcf800d5,0x45d8008f}},	// [31fa0] surb, نمرګ, _maéh, פֿלא, 
   {{0x6e3dc3d3,0x00800212,0x7d04009d,0x8a0401f4}},	//   purb, _сльо, _үнэг_, езже, 
   {{0x6e3c058a,0xdcec00d7,0x00000000,0x00000000}},	//   qurb, chaľ, --, --, 
   {{0x6c34121e,0x99640046,0xc9d40f87,0x08c5845e}},	//   _لہرا, ктіл, رزاب, нбен, 
   {{0xf76c03e6,0xd90c07d6,0x00000000,0x00000000}},	//   ڵاو_, تیق_, --, --, 
   {{0x37500133,0x00000000,0x00000000,0x00000000}},	//   ێپۆس, --, --, --, 
   {{0xfbc0023a,0xf1e01a04,0xc31c00cc,0xfbbc00dc}},	//   _сбро, नतान, _দালি_, ्वरम, 
   {{0xdb040fac,0x00000000,0x00000000,0x00000000}},	//   rihå, --, --, --, 
   {{0x19f800a8,0x274c0092,0x47c40816,0x00000000}},	//   _цэрь_, ነበረበ, _збав, --, 
   {{0xbcf8003e,0x68500023,0x82a43a47,0x00000000}},	//   _paék, _መልሓስ, ешме, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbcf800e4,0xd5ac00f1,0x3ab80677,0x5f1c00cc}},	//   _vaék, _وځي_, למינ, _তাইও_, 
   {{0x7bc002b5,0x25a40175,0xf28401c6,0x00000000}},	//   ōnui, mhml_, дөөд_, --, 
   {{0xbcf8003e,0x7e081f0f,0x6aac04af,0x00000000}},	//   _taék, зхаб_, _टे्र, --, 
   {{0x29dc0113,0xf5540241,0x00000000,0x00000000}},	//   ríaj_, _àṣá_, --, --, 
   {{0x13d400bd,0xa3e40254,0xb46000c7,0x00000000}},	//   _হওয়, _भीत_, _ркәл, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [31fb0] --, --, --, --, 
   {{0x2d8c002d,0xef20031c,0x00000000,0x00000000}},	//   êder_, żżru_, --, --, 
   {{0x60980014,0xdea00345,0x00000000,0x00000000}},	//   _رنگس_, _ئیزی, --, --, 
   {{0x92bdc3d4,0x00000000,0x00000000,0x00000000}},	//   _আৰু_, --, --, --, 
   {{0x6ce40046,0xa3d03c16,0x00000000,0x00000000}},	//   _біре, वका_, --, --, 
   {{0x7c3c01d9,0xe6480023,0x9b44fcbf,0x00000000}},	//   muqr, _ዘይኮን, _جنسو, --, 
   {{0xbbbc4eae,0xaa581188,0x46a0014b,0x00000000}},	//   ्वीक, _пиру_, иашв, --, 
   {{0xbcf80098,0x00000000,0x00000000,0x00000000}},	//   _paéh, --, --, --, 
   {{0x57f5c3d5,0xd7c8023f,0x92bc015b,0x6dac00a2}},	//   _апат, _قوره_, _আরে_, mşat, 
   {{0xe874104c,0xed94001f,0xf771c3d6,0x69d800e4}},	//   _حافظ, _ዘወትር_, _حار_, îvev, 
   {{0x555415fa,0x6fd800d2,0x0cdc197e,0x27e00b45}},	//   _لپار, _lúcî, _मर्म, ɓin_, 
   {{0x7c3c0309,0x6dac054e,0x00000000,0x00000000}},	//   kuqr, nşat, --, --, 
   {{0x059400db,0x00000000,0x00000000,0x00000000}},	//   _جالگ, --, --, --, 
   {{0xdebc0240,0x00000000,0x00000000,0x00000000}},	//   _ታርኽ_, --, --, --, 
   {{0x7e200f14,0xff0400a8,0x645c0356,0x6dac0139}},	//   идрж, теск_, ărie, kşat, 
   {{0xdde8034c,0x9f48030a,0x00000000,0x00000000}},	//   فرقه_, _duañ_, --, --, 
   {{0x69c802d2,0x00000000,0x00000000,0x00000000}},	// [31fc0] _ídei, --, --, --, 
   {{0x4e0461ff,0xcaf5c3d7,0x4f08059f,0xb7e000cc}},	//   _изоб, نساب, _юнон_, মদুট, 
   {{0x4a449cb8,0xbf98011a,0x00000000,0x00000000}},	//   тнев, _חייש, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x92bc03f4,0x6d45c3d8,0x0ba801ec,0x6da400c7}},	//   _আরো_, mgia, _قاسى_, _аиҟа, 
   {{0x6d45c3d9,0xd90c01d3,0x2b580066,0x00000000}},	//   lgia, قیہ_, _سیصد_, --, 
   {{0x25a44f74,0xa3d401d5,0x6d440037,0x00000000}},	//   thml_, ғонч, ogia, --, 
   {{0x6d45c3da,0xa2a00574,0x7ae1c3db,0x97c40131}},	//   ngia, खनस्, ünte, پتۇم, 
   {{0x6d45c3dc,0x35f40633,0x00000000,0x00000000}},	//   igia, خرود_, --, --, 
   {{0x6d45c3dd,0xc764afa0,0xc0f80092,0x92bc00fe}},	//   hgia, _جارى, _ፊርማ_, _আৰে_, 
   {{0xa195c3de,0x326000a7,0xbb380375,0xf56400e5}},	//   ганч, атяв, ועיי, رمیٹ_, 
   {{0xe135c3df,0x7c3c0309,0xc0580212,0x224c01bf}},	//   ынмы, yuqr, міг_, rtdk_, 
   {{0x6d4405d5,0x6560009f,0x9f480165,0x224c01bf}},	//   dgia, memh, _suañ_, stdk_, 
   {{0xf4540375,0x6d45c3e0,0xdca00092,0x6561c3e1}},	//   _סיור_, egia, _ለመማር_, lemh, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d45c3e2,0x6561c3e3,0x7c3c0477,0xb2201de6}},	//   ggia, nemh, tuqr, _өмәл, 
   {{0x5c75c3e4,0x1a640f01,0xdb04002f,0xf15402f2}},	// [31fd0] ылат, گیزی_, inhö, _ڵکێک, 
   {{0xbbbc1025,0x6d440618,0xd24cbf24,0xdb040112}},	//   ्वेक, agia, _بچی_, hnhö, 
   {{0x6441c3e5,0x5a340120,0x6d44f6bf,0xb4cc043e}},	//   humi, унет, bgia, _षड्_, 
   {{0x6d440208,0xb3800023,0x00000000,0x00000000}},	//   cgia, _ክወድቕ_, --, --, 
   {{0x6441c3e6,0x28f8fffd,0x97d81cb5,0x7d0c02d0}},	//   jumi, вець_, ньку_, _ifcs, 
   {{0xdd900131,0xfba4193d,0x00000000,0x00000000}},	//   _ئوڭ_, _गतिम, --, --, 
   {{0x92bc00cc,0x00000000,0x00000000,0x00000000}},	//   _আৰৈ_, --, --, --, 
   {{0x6441c3e7,0x65602251,0x481000fd,0xdb04007c}},	//   fumi, gemh, шмәс, gnhö, 
   {{0x7bc40083,0x00000000,0x00000000,0x00000000}},	//   _kjju, --, --, --, 
   {{0xa7740261,0x6dadc3e8,0x09840022,0x8c18011a}},	//   _клуч, nşar, _аӡәк_, עותי, 
   {{0x6d440368,0x64400421,0x65600117,0xb60400a7}},	//   ygia, aumi, bemh, _рязк, 
   {{0xe570085d,0x6441c3e9,0xf56802dd,0x6dac010b}},	//   _وطن_, bumi, _ішек_, hşar, 
   {{0x7bc40337,0x78a80369,0xa484004b,0x454000f7}},	//   _ojju, nzgv, _نجون, _اچىق, 
   {{0x03640137,0x626405a9,0x00000000,0x00000000}},	//   _бишк_, _چايق, --, --, 
   {{0xe3b0ca18,0x1e94ae0b,0x6d45c3ea,0x8d541180}},	//   _برن_, артр, tgia, лтач, 
   {{0x7bc4d912,0x6d45c3eb,0x42d8010f,0x00000000}},	//   _ajju, ugia, _אקצע, --, 
   {{0x6d441948,0x00000000,0x00000000,0x00000000}},	// [31fe0] rgia, --, --, --, 
   {{0x6d45c3ec,0x5ba401ec,0x6dac010e,0x00000000}},	//   sgia, алуғ, gşar, --, 
   {{0x6441c3ed,0x6561b68d,0x6d440208,0x8e74026b}},	//   zumi, yemh, pgia, _супч, 
   {{0x6441287b,0xba147ee5,0x7bc5c3ee,0x00000000}},	//   yumi, اينا_, _ejju, --, 
   {{0x64410bd7,0x6561c3ef,0xe8f800fb,0x00000000}},	//   xumi, vemh, тһа_, --, 
   {{0x38c82b7e,0x46680bbe,0x6dac5043,0x00000000}},	//   رانی_, ерим_, mşaq, --, 
   {{0x7bc9c3f0,0xaab89f23,0x6560003c,0x6441c3f1}},	//   égue, _आधिक, temh, wumi, 
   {{0x6441c3f2,0xd90c2099,0x997400cf,0x65940124}},	//   tumi, _قیم_, _кууш, раиу, 
   {{0xb9909d9a,0x6561c3f3,0xd9b003cc,0xdb0403cd}},	//   _القب, remh, _بەند, tihø, 
   {{0x65603058,0xaca401f2,0x00000000,0x00000000}},	//   semh, _nsọt, --, --, 
   {{0x64400d90,0x45446640,0x6560006f,0xdb0403cd}},	//   sumi, _مناق, pemh, rihø, 
   {{0xaca40248,0xbcf84a16,0x6441c3f4,0x81680818}},	//   _asọt, _kaét, pumi, хроб_, 
   {{0x75d00046,0x64400eda,0x741026c6,0x00000000}},	//   _اينا, qumi, _هونا, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x98ac0219,0xee840312,0x73c050a3,0x00000000}},	//   _rdeč_, быто, _ديوم, --, 
   {{0x27ec0ac5,0x7c840212,0xdd94dcd2,0x9d1426b1}},	//   _lhdn_, лузе, шабы, рдач, 
   {{0xdfd05706,0x61edc3f5,0x9f340220,0x9d44799d}},	// [31ff0] _ويب_, _ihal, _кепі, леңд, 
   {{0x20199af7,0x6f1800d7,0x00000000,0x00000000}},	//   mpsi_, čací, --, --, 
   {{0x61edc3f6,0xbb4c0150,0x00000000,0x00000000}},	//   _khal, _ﺃﺅﻜ_, --, --, 
   {{0x61edc3f7,0x9874c2f3,0x79a400c7,0x00000000}},	//   _jhal, илец, ырзе, --, 
   {{0x61ec65f2,0xd7f5a349,0xc87c05d1,0x57242374}},	//   _mhal, азды, _öğle_, لىشك, 
   {{0x67d4a577,0x3f90002e,0x60cc0009,0x916001e1}},	//   бочу, _joxu_, _mxam, _kọ́_, 
   {{0x7bd4022e,0x00000000,0x00000000,0x00000000}},	//   moxu, --, --, --, 
   {{0x957400f7,0x63a801ab,0x61edc3f8,0x91600241}},	//   рыкч, ehdn, _nhal, _mọ́_, 
   {{0x60cc00f1,0xbcf8a573,0xd8881a90,0xa3d000cd}},	//   _nxam, _gaét, _جھان_, वकं_, 
   {{0x61edc3f9,0xd4980598,0x7bd4056a,0x92f40212}},	//   _ahal, ерү_, noxu, ичні, 
   {{0xf48402dd,0x836001d5,0x7760201d,0x645c054e}},	//   _әуен, زگول, menx, ăria, 
   {{0x7641c3fa,0x24802375,0x3a2004e6,0xd008021f}},	//   muny, _šime_, _mwjp_, кеме_, 
   {{0x7641c3fb,0x61ecbd6a,0xe240001f,0xbcf9c3fc}},	//   luny, _dhal, _ተደርጓ, _maés, 
   {{0x77600b6f,0x61edc3fd,0x63a801c3,0x3f9006be}},	//   nenx, _ehal, chdn, _coxu_, 
   {{0x3f90002e,0x7641c3fe,0x61edc3ff,0xc7b00375}},	//   _doxu_, nuny, _fhal, קבל_, 
   {{0x61edc400,0xd1b8066d,0x7761c401,0x4d64033a}},	//   _ghal, _جاتا_, henx, јкав, 
  
   {{0x7641c402,0x8c45c403,0x4b243529,0x8b25c404}},	// [32000] huny, резе, имав, идае, 
   {{0x7641c405,0x3f900de2,0x3b8000f7,0x320402f0}},	//   kuny, _goxu_, олуг, _kuny_, 
   {{0x3205c406,0x7640207a,0xbcf80066,0x7f380302}},	//   _juny_, juny, _baés, _בעיו, 
   {{0x7641c407,0x8c45035c,0x32040209,0x61ec0472}},	//   duny, _кеме, _muny_, _xhal, 
   {{0x7bd4011f,0x00000000,0x00000000,0x00000000}},	//   boxu, --, --, --, 
   {{0x7641c408,0x33240369,0x77608a15,0xf7f00b24}},	//   funy, _nenx_, genx, يسود, 
   {{0x76405749,0xd7180212,0xe68800db,0x36840395}},	//   guny, уючі_, انعى_, исън_, 
   {{0x2fd800d4,0x00000000,0x00000000,0x00000000}},	//   horg_, --, --, --, 
   {{0x2fd8049f,0x61ec02b9,0x2904e9e7,0x7761c409}},	//   korg_, _rhal, _igma_, benx, 
   {{0x7641c40a,0xbcf80264,0x3204010e,0xf74400db}},	//   buny, _kaér, _buny_, _ەلەي_, 
   {{0x61edc40b,0x7641c40c,0x68e003cb,0x69c802d2}},	//   _phal, cuny, _hymd, _ídes, 
   {{0x06640272,0x96940853,0x6729c40d,0x61edc40e}},	//   _ماڵپ, _уруш, _hedj, _qhal, 
   {{0x61ec1aa1,0x29dc2b76,0x6729c40f,0xa6e80011}},	//   _vhal, lías_, _kedj, _পলিট, 
   {{0x33240076,0x67280427,0x6608b034,0x2019c410}},	//   _genx_, _jedj, _kudk, rpsi_, 
   {{0x61edb66c,0x6729c411,0x29dcb9f0,0x68e00649}},	//   _thal, _medj, nías_, _lymd, 
   {{0x67281225,0x61ec0451,0xfe741c13,0x60cc01c4}},	//   _ledj, _uhal, гүү_, _txam, 
   {{0x2fd9c412,0x66086f10,0xad241b56,0x60cc009a}},	// [32010] borg_, _ludk, زىلى, _uxam, 
   {{0x67281727,0x77600921,0xbcf87cd8,0x66080b4f}},	//   _nedj, xenx, _saés, _oudk, 
   {{0x20000280,0x20080198,0xe7bc0316,0xbcf8003e}},	//   _iihi_, _huai_, ्चनप, _paés, 
   {{0x764053ff,0x2008123c,0x29dc09ff,0xbcf85d69}},	//   vuny, _kuai_, días_, _daér, 
   {{0xa2d803f3,0x68e00cfd,0x2001c413,0x6729c414}},	//   _नुस्, _cymd, _kihi_, _bedj, 
   {{0x7641c415,0x21281368,0x29dc1280,0x20080b23}},	//   tuny, _leah_, fías_, _muai_, 
   {{0x2001c416,0x29dda366,0x2008166a,0x77600077}},	//   _mihi_, gías_, _luai_, renx, 
   {{0x2001c417,0x2fd80cf9,0x20084056,0x947421e7}},	//   _lihi_, zorg_, _ouai_, مدخا, 
   {{0x7641c418,0x68e000a9,0x6729c419,0xdb140165}},	//   suny, _gymd, _fedj, _amzé, 
   {{0xe784085a,0x764007e2,0x3205c41a,0x29dc2760}},	//   _мухо, puny, _puny_, bías_, 
   {{0x29dc09ff,0x2008096b,0xd57402d5,0x76400944}},	//   cías_, _auai_, _гуль, quny, 
   {{0x20096680,0xdcfc02e2,0x672801fa,0x1ab400cc}},	//   _buai_, _ansč, _zedj, _জুৱা, 
   {{0x2fd80008,0x20080ac5,0x212800a3,0x3324003e}},	//   torg_, _cuai_, _deah_, _tenx_, 
   {{0x20081570,0xaad0033f,0x32040118,0x66080139}},	//   _duai_, _तुझक, _tuny_, _yudk, 
   {{0xbea05afd,0x20080421,0x8d586cf7,0x3ea001b9}},	//   парк, _euai_, лшат_, пирг, 
   {{0x2fd9c41b,0x290002d5,0x20087eb8,0xdcec01f1}},	//   sorg_, žiai_, _fuai_, adač, 
   {{0x2009c41c,0x200003a0,0x7d1801e4,0xdc28027d}},	// [32020] _guai_, _fihi_, _ĵust, لسله_, 
   {{0x68e001e6,0x6d980139,0x8fd0104e,0x00000000}},	//   _rymd, _cíar, _хәмә, --, 
   {{0x29dc172e,0x49040597,0x29041c06,0x67280cf4}},	//   xías_, مواق, _pgma_, _redj, 
   {{0x29dc09c2,0x6d980077,0x672800f2,0x6608005c}},	//   vías_, _vías, _sedj, _rudk, 
   {{0x200006e4,0x6728009b,0xc7b80c98,0x6609c41d}},	//   _yihi_, _pedj, лёк_, _sudk, 
   {{0x8d75c41e,0x29dc9ca8,0x200007a9,0x67280477}},	//   _ئاگا, tías_, _xihi_, _qedj, 
   {{0x09e42f5c,0x26080073,0x00000000,0x00000000}},	//   _говн, ाआधी_, --, --, 
   {{0x29dd3316,0x2904409c,0x672800f2,0xe98401ec}},	//   rías_, _ugma_, _wedj, _باسۋ, 
   {{0x29dc30cf,0x046401b9,0x6729c41f,0x88c8009b}},	//   sías_, ётим, _tedj, _слав_, 
   {{0xca980020,0x2129c420,0x29dc09c2,0xc32c0131}},	//   _ሁሉንም_, _seah_, pías_, رەب_, 
   {{0x2259c421,0x2009c422,0x2001c423,0x2128acd7}},	//   шины_, _suai_, _rihi_, _peah_, 
   {{0x200866ff,0x20000254,0x60f8003b,0x00000000}},	//   _puai_, _sihi_, иння_, --, 
   {{0x20081675,0x20001f45,0x705805f5,0x6ac46a60}},	//   _quai_, _pihi_, баяр_, वपुर, 
   {{0x4425c424,0x212807a8,0x200801c8,0xe2f802dd}},	//   _iwo_, _weah_, _vuai_, _келі_, 
   {{0x3da406c9,0xdcec0fcf,0xee840eed,0x81c00154}},	//   браб, rdač, пыто, ্তব_, 
   {{0x200914c3,0x644020ac,0x200006e4,0x4425c425}},	//   _tuai_, ormi, _wihi_, _kwo_, 
   {{0x200020e6,0xdcfc01fa,0xbcf81bce,0x5bb80006}},	// [32030] _tihi_, _posđ, _mbég, алая_, 
   {{0x6ac41092,0x44241459,0x6441c426,0x2cb85e3d}},	//   वपूर, _mwo_, irmi, حافظ_, 
   {{0xdd95c427,0x4425c428,0x29ddc429,0x1a6401d5}},	//   _даны, _lwo_, víar_, غیری_, 
   {{0x44240570,0x1959bfc0,0x7c841fbe,0x644001ef}},	//   _owo_, рады_, _луге, krmi, 
   {{0x44240ca8,0xd704d43a,0xdd300210,0xa9c400db}},	//   _nwo_, озли, _mężo, سۅكۉ, 
   {{0x645c00a8,0xbcf9c42a,0x01cc00bd,0xa5e801e0}},	//   ăril, _abég, রতিদ, ҙлыҡ_, 
   {{0x4425c42b,0x6440bb30,0x7cec01e1,0x29dc03b2}},	//   _awo_, ermi, _fòrí, ríar_, 
   {{0x44240a03,0x6440010a,0xf1c4022a,0xb8cc03d4}},	//   _bwo_, frmi, _myší_, _ওখ_, 
   {{0x44240263,0x64400841,0xc1d0033f,0x00000000}},	//   _cwo_, grmi, सवैग, --, 
   {{0x4424013f,0x00000000,0x00000000,0x00000000}},	//   _dwo_, --, --, --, 
   {{0x6441c42c,0x4424013b,0xd1b81a71,0x6378010b}},	//   armi, _ewo_, لاحا_, ссыр_, 
   {{0x6594016c,0xbcf80248,0x00000000,0x00000000}},	//   _наху, _gbég, --, --, 
   {{0x4425c42d,0xd00871a4,0x00000000,0x00000000}},	//   _gwo_, реге_, --, --, 
   {{0xbcf80214,0x8e84b9ed,0x0fd8005b,0x86500023}},	//   _mbéd, огге, рьмы_, _ዘርእስ, 
   {{0x44240dc9,0xbcf8003e,0xc1e40014,0xafe40137}},	//   _zwo_, _saép, _ژکُل_, _ۉيبۉ, 
   {{0x51f52203,0x0c240e92,0xf424031c,0xbcf80129}},	//   _بستر, жман, _རྦོད_, _obéd, 
   {{0xfce00d97,0x7529c42e,0x068c0075,0x10e401d9}},	// [32040] дото, _megz, _ﻛﯧﻠﯩ, _گژھی_, 
   {{0x7528e219,0xbfc0173d,0x088801d3,0x4e2800db}},	//   _legz, _обык, یناً_, _коон_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xeff8001f,0xf40416ac,0xba1406c2,0x9f4401f4}},	//   ፋፊያ_, _يؤ_, زيها_, ölö_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x442419f6,0x00000000,0x00000000,0x00000000}},	//   _rwo_, --, --, --, 
   {{0x44240c11,0x75286aac,0xbcf801d3,0x645c0356}},	//   _swo_, _begz, _ebéd, ărim, 
   {{0x6d400086,0x7e9800c8,0xdb04002d,0x44240100}},	//   _ômad, יסצו, chhâ, _pwo_, 
   {{0x752801b8,0xbcf80241,0x2ca00334,0x00000000}},	//   _degz, _gbéd, nyid_, --, 
   {{0xa3e40c2e,0x4424923a,0x2ca00076,0x6440936d}},	//   _भीख_, _vwo_, iyid_, rrmi, 
   {{0xb7d5c42f,0x86c4152b,0x23a0007f,0x6610033f}},	//   _بولا_, _بيان, _jòji_, ójką, 
   {{0x4424025f,0x290002d5,0xc485947d,0xf2c000c7}},	//   _two_, žiau_, _млек, ьсын, 
   {{0x4424633d,0xc0580220,0x00000000,0x00000000}},	//   _uwo_, шін_, --, --, 
   {{0x337000d4,0xdd300210,0x00000000,0x00000000}},	//   _огір, _wężo, --, --, 
   {{0xd7500023,0x98ac0210,0x00000000,0x00000000}},	//   _ዘኽእሎ, _ideą_, --, --, 
   {{0xdb0c00e5,0x00000000,0x00000000,0x00000000}},	//   űkül, --, --, --, 
   {{0x030c2aa1,0xe7bc06ff,0xa1f801ed,0xd9440116}},	// [32050] _सलाह_, ्चाप, _پڑھا_, җели, 
   {{0x9f200131,0xdfd001c8,0x00000000,0x00000000}},	//   _سۈرۈ, _سيج_, --, --, 
   {{0xf0b80214,0xfd4401ed,0x00000000,0x00000000}},	//   _هایش_, _ویسٹ_, --, --, 
   {{0x2ca00408,0x940c013f,0x00000000,0x00000000}},	//   byid_, gyeɛ_, --, --, 
   {{0x7529c430,0xb17c008f,0x00000000,0x00000000}},	//   _regz, יטאר, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x81c02f8b,0x395c0700,0x57b47e81,0x045400c6}},	//   ্তা_, _ibus_, _ебат, كلية_, 
   {{0x82380020,0xbcf80241,0x7529c431,0x00000000}},	//   _በተመሳ, _gbée, _wegz, --, 
   {{0x7528007f,0x8cc001ad,0x91e42901,0x00000000}},	//   _tegz, _रेनो, зоне, --, 
   {{0x2ca1c432,0xbcf9c433,0x76400076,0x28c00709}},	//   yyid_, _mbéb, mrny, _शेडि, 
   {{0xa07400c7,0x395c00ae,0x13f4005b,0x00000000}},	//   мырш, _mbus_, _ездя, --, 
   {{0xe4f000dc,0x2d780051,0x2d5c0055,0x00000000}},	//   _चरति_, _ọe_, _ṭe_, --, 
   {{0x76403223,0x395c6c80,0xdb740092,0x683c0092}},	//   nrny, _obus_, _አሊያም_, _አውስት, 
   {{0x76400a2e,0x2ca00334,0x00000000,0x00000000}},	//   irny, tyid_, --, --, 
   {{0x6ac49d35,0x7640020b,0x3160030a,0x00000000}},	// [32060] वप्र, hrny, _ibiz_, --, 
   {{0x395dc434,0x2ca1c435,0x7af801e4,0x00000000}},	//   _abus_, ryid_, _ŝuta, --, 
   {{0x2ca02ebc,0xc9849f91,0xbf9800d9,0x31600208}},	//   syid_, зули, _הייש, _kbiz_, 
   {{0x9e640050,0x387c0158,0x4c3401c0,0x088800cf}},	//   _کاین, _brur_, _нэгт, йбей_, 
   {{0xbcf802ea,0x0c7805f5,0x395c005a,0x7d780375}},	//   _ebéb, _усны_, _dbus_, _הנכו, 
   {{0x443800df,0xf8ac01ed,0xf86404da,0x00000000}},	//   _ĉp_, چکے_, سمىي_, --, 
   {{0x2d841497,0xbcf80ca8,0x387c01d5,0xf8ac00e5}},	//   _òmes_, _gbéb, _erur_, نکے_, 
   {{0x6b980327,0xa3e4000d,0x00000000,0x00000000}},	//   żagħ, _भीज_, --, --, 
   {{0x76400363,0x387c002f,0x7950009f,0x00000000}},	//   arny, _grur_, _سَلا, --, 
   {{0x3161c436,0x850400aa,0x29000024,0x7640012d}},	//   _abiz_, _ځوان, žias_, brny, 
   {{0xf7400b7e,0x5ec0015b,0xf7700375,0xd24c1913}},	//   _чехо, _শুনে, _רקע_, لچي_, 
   {{0x3160004d,0x00000000,0x00000000,0x00000000}},	//   _cbiz_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2005c437,0x75d00356,0x00000000,0x00000000}},	//   öli_, răze, --, --, 
   {{0x3da40024,0x71f800f2,0x6dac2b93,0x7358011a}},	//   праб, تریس_, lşay, _הכוח, 
   {{0x3618011a,0x00000000,0x00000000,0x00000000}},	//   מולד, --, --, --, 
   {{0x9c1800c6,0xd0241d00,0x5f940137,0x69b015c0}},	// [32070] زياء_, _قويۋ, _жипт, ंसनी, 
   {{0xbcf806af,0x7640062c,0x39340023,0x00000000}},	//   _abéc, yrny, _ከምዘካ, --, 
   {{0x80dc009e,0x671000af,0x5974004e,0x7f600092}},	//   নেশ্, ाशनक_, дылу, _ልምዳች, 
   {{0xfd1005d9,0xf77c0139,0x4ee401af,0x00000000}},	//   _ڪجھ_, _şç_, _юсыҡ, --, 
   {{0x80dc02a6,0xeab000dd,0xf8040354,0x32340023}},	//   _নৃত্, نٹے_, ччен, _ኮይንኩ, 
   {{0x7b640510,0xac19c438,0xfd1001ed,0x00000000}},	//   _этме, _хору_, _تجھ_, --, 
   {{0xe730d52d,0xead401c6,0x37700150,0x00000000}},	//   اصه_, _зорь, дықс, --, 
   {{0x387c0183,0x395c51e2,0xc0e80023,0x45d00798}},	//   _trur_, _ubus_, መርሕ_, којс, 
   {{0x387dc439,0x2d8c013f,0x290001f1,0x23c801ad}},	//   _urur_, _ɑde_, žiar_, िचंद, 
   {{0x79984ffd,0x83600075,0x00000000,0x00000000}},	//   _houw, نگىل, --, --, 
   {{0x799802bd,0xd9400023,0x7ae00254,0x67380419}},	//   _kouw, _ከምድላ, ünth, šajú, 
   {{0x7999c43a,0x5ec009bd,0xfd4c00b8,0x00000000}},	//   _jouw, _শুভে, caiḥ, --, 
   {{0x7998923a,0x31600208,0x00000000,0x00000000}},	//   _mouw, _vbiz_, --, --, 
   {{0x79987ae3,0xa2d8134e,0xdb040254,0x00000000}},	//   _louw, _नुक्, lihõ, --, 
   {{0x79980086,0xdcfc0064,0xd9ec0073,0x883c0023}},	//   _oouw, _kosė, जतात_, _ኣይትሰ, 
   {{0x7998257c,0x00000000,0x00000000,0x00000000}},	//   _nouw, --, --, --, 
   {{0xd7dc07b6,0xdcfc0064,0x00000000,0x00000000}},	// [32080] यवाच, _mosė, --, --, 
   {{0x8b6439b8,0x00000000,0x00000000,0x00000000}},	//   بارم, --, --, --, 
   {{0x81c003f4,0x7999c43b,0x61ec01d3,0x645c0356}},	//   ্তর_, _bouw, _álló, ării, 
   {{0x08c5c43c,0x00000000,0x00000000,0x00000000}},	//   мбен, --, --, --, 
   {{0x7998f8c8,0x068c0075,0xdd00054e,0x38c400e4}},	//   _douw, _ﻛﯧﻴﯩ, ătăt, vêrô_, 
   {{0x79980295,0x00000000,0x00000000,0x00000000}},	//   _eouw, --, --, --, 
   {{0x7998007f,0x6b9dc43d,0xf64c01f7,0xa4f800cd}},	//   _fouw, _iorg, لئي_, ुश्च_, 
   {{0x6b9dc43e,0x799945ab,0x35f40f2b,0x00000000}},	//   _horg, _gouw, وريد_, --, 
   {{0x69c0ee99,0x6b9dc43f,0xbee802ab,0x00000000}},	//   _imme, _korg, _टर्न_, --, 
   {{0x6b9dc440,0x799801c7,0x452403d4,0x00000000}},	//   _jorg, _zouw, _যাওক_, --, 
   {{0xbcf800c6,0x6b9c2d61,0x79980072,0xdb040108}},	//   _mbéa, _morg, _youw, sihö, 
   {{0x6b9dc441,0x00000000,0x00000000,0x00000000}},	//   _lorg, --, --, --, 
   {{0x6b9c0151,0xe7d004c5,0x310c0051,0xb37002f2}},	//   _oorg, িতীয, _ởbên_, ردیش, 
   {{0x6b9dc442,0x883c0023,0x00000000,0x00000000}},	//   _norg, _ኣይተሰ, --, --, 
   {{0x69c1c443,0x87e00327,0x00000000,0x00000000}},	//   _omme, _སེནྡ, --, --, 
   {{0x224c0194,0x200c00d2,0x33040150,0x31c40006}},	//   mudk_, íeis_, _تيىپ_, _асьв, 
   {{0x7999c444,0x2a80001f,0x7dd00327,0x9bf40395}},	// [32090] _rouw, _የሚገባ_, għsa, езач, 
   {{0x799804c4,0x61fdc445,0x6b9dc446,0x00000000}},	//   _souw, lmsl, _corg, --, 
   {{0x6b9c22a9,0x7999c447,0xa2a40073,0x311c00cd}},	//   _dorg, _pouw, _चॅम्, भुवः_, 
   {{0x6b9c127b,0x58d40395,0x4ef8011a,0x00000000}},	//   _eorg, ноет, _מהתו, --, 
   {{0x6b9dc448,0x79980d27,0x61fc0158,0x9bc40150}},	//   _forg, _vouw, imsl, _كۇرە_, 
   {{0x69c1c449,0x799801f5,0x6b9dc44a,0x61fc0112}},	//   _emme, _wouw, _gorg, hmsl, 
   {{0x13080323,0x79985d43,0xdcfc0006,0x00000000}},	//   үний_, _touw, _posė, --, 
   {{0x6b9dc44b,0x28c00210,0x00000000,0x00000000}},	//   _zorg, _शेवि, --, --, 
   {{0x6b9dc44c,0x37740022,0x00000000,0x00000000}},	//   _yorg, _ҽыҧс, --, --, 
   {{0xf771c44d,0x6b9c0139,0x00000000,0x00000000}},	//   _جار_, _xorg, --, --, 
   {{0x6b9807c5,0x69c0035a,0x70c80950,0x69d800e4}},	//   övgi, _ymme, रप्ल, éveg, 
   {{0xc0ec0201,0x527400d1,0xa37c0115,0x55581171}},	//   _ሁሉም_, _җуку, voĵe, _хадя_, 
   {{0x7af801e4,0x00000000,0x00000000,0x00000000}},	//   _ŝutl, --, --, --, 
   {{0x61fc01f5,0xf3240150,0x00000000,0x00000000}},	//   amsl, _تۋدى_, --, --, 
   {{0x6b9c12e8,0x2ebc00cd,0xea000051,0x00000000}},	//   _rorg, ोपेत, cmặt_, --, 
   {{0xdef80023,0x00000000,0x00000000,0x00000000}},	//   ሊልካ_, --, --, --, 
   {{0x6b9d5b90,0x8b240006,0x00000000,0x00000000}},	// [320a0] _porg, едзе, --, --, 
   {{0x69c17d8a,0x6b9c016d,0x81c000eb,0x00000000}},	//   _smme, _qorg, ্তঃ_, --, 
   {{0x6b9c0639,0xfaa002a9,0x620806be,0xc0e80023}},	//   _vorg, лафо, _üslü, መይል_, 
   {{0x6b9c0af9,0x00000000,0x00000000,0x00000000}},	//   _worg, --, --, --, 
   {{0x6b9dc44e,0xfaec004b,0x00000000,0x00000000}},	//   _torg, لګې_, --, --, 
   {{0x6b9c0ac8,0x00000000,0x00000000,0x00000000}},	//   _uorg, --, --, --, 
   {{0x61fc1f60,0x3f8c013f,0xf48002dd,0x7a6400f3}},	//   ymsl, _ɑgu_, ғуын, _пирг_, 
   {{0xbcf81ef4,0x00000000,0x00000000,0x00000000}},	//   _mbén, --, --, --, 
   {{0xddc400b8,0xb6000419,0x00000000,0x00000000}},	//   _sphū, ášal, --, --, 
   {{0xd8b801d9,0x5ec00154,0xdcec0327,0x00000000}},	//   _تھٔچ_, _এডসে, njaġ, --, 
   {{0xf8bc00fc,0x6d9800e4,0xf3609a35,0xdb0417da}},	//   _þér_, _díaz, утын, chhä, 
   {{0x25080517,0x6b100327,0xa5c401ec,0x00000000}},	//   _قرشی_, _ཏུའོ_, _шөле, --, 
   {{0xe37429dc,0xaed4013e,0xf1c1c44f,0x3014010b}},	//   _аллы, ҳорш, शोधन, лдяр, 
   {{0x22940597,0x7af801e4,0xb10000fe,0x00000000}},	//   _للتس, _ŝutm, ূৰ্ব_, --, 
   {{0xaed410cd,0x00000000,0x00000000,0x00000000}},	//   горш, --, --, --, 
   {{0xdcec00f3,0x00000000,0x00000000,0x00000000}},	//   ndać, --, --, --, 
   {{0xbcf80129,0x00000000,0x00000000,0x00000000}},	// [320b0] _ebén, --, --, --, 
   {{0x6d400086,0x9e6802d3,0x1e14022e,0x00000000}},	//   _ôman, _ሽግርና_, _имоя, --, 
   {{0xbcf80248,0x9f4000a2,0xdcfc00ef,0x9df801ee}},	//   _gbén, _mhhü_, _kosī, _онот_, 
   {{0xf2d0010f,0x81dc00fe,0x00000000,0x00000000}},	//   נעף_, _থওঁ_, --, --, 
   {{0xed6000bc,0xcdc00116,0x44e400fe,0xe94401a9}},	//   ížet_, _тәрп, খেতক_, уххо, 
   {{0x7c2dc450,0x09bc0154,0x307c00df,0x00000000}},	//   _iwcr, ইকগা, פאונ, --, 
   {{0xd9140953,0xab8401d5,0x7948010e,0x00000000}},	//   _адбы, _суяк, göwü, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x629c0036,0x672c00e5,0x00000000,0x00000000}},	//   äron, éljü, --, --, 
   {{0xd2a8005b,0x794800a2,0x00000000,0x00000000}},	//   дкое_, böwü, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x10a40853,0xdcec01e4,0x7c2c02d0,0x00000000}},	//   вимн, lkaĵ, _owcr, --, 
   {{0x1cbc025c,0x49380375,0x19d000d1,0x00000000}},	//   ྀགས_, וגרו, ﻛﺎﭘﺎ, --, 
   {{0x03a00f5c,0x645c054e,0xdcec010f,0x04400408}},	//   _вишо, ărit, nkaĵ, _тешн, 
   {{0x683800d2,0xdcec0003,0x8d54ddef,0x00000000}},	//   _kúdá, vjaġ, ктач, --, 
   {{0x661c00dd,0x24800784,0x6838143c,0x41b00228}},	//   _érke, _šimi_, _júdá, _ۅمۉر, 
   {{0xcd0402de,0x00000000,0x00000000,0x00000000}},	// [320c0] тпай, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7c2c035a,0x91c40550,0xba1400ae,0x00000000}},	//   _ewcr, _लगाई, نيلا_, --, 
   {{0x6c342832,0xc8c802f2,0xa9340137,0x00000000}},	//   _مہرا, ووان_, اباچ, --, 
   {{0xaca402e3,0x6e3c009b,0x38c80214,0x5cf40105}},	//   _kpọt, lsrb, واهی_, _бяру, 
   {{0xbcf800f2,0x2c04004e,0xb5c40014,0x00000000}},	//   _mbél, _сүзм, ێووم_, --, 
   {{0x2b59c451,0x7bc8ff09,0x3b040305,0x75d00356}},	//   _icrc_, ègue, _аеро_, răzn, 
   {{0xadf8c707,0x224001e4,0xfa740375,0xdcec0115}},	//   ंगटन_, _ĉik_, _בעלת_, akaĵ, 
   {{0x2b5801e4,0xc3491df5,0x48040006,0xdcfc00de}},	//   _kcrc_, мяне_, _апав, _rosī, 
   {{0x629c0108,0x00000000,0x00000000,0x00000000}},	//   äroo, --, --, --, 
   {{0xbcf80ffb,0xf204012d,0xa159c452,0x00000000}},	//   _abél, रगढ़_, нану_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf06401b9,0x2618004d,0xbf7001ec,0x00000000}},	//   акўп, _héo_, ақпы, --, 
   {{0x26180016,0x67380327,0x00000000,0x00000000}},	//   _kéo_, navj, --, --, 
   {{0x6e3c089c,0xe37401e0,0x7c2c0142,0xc2900345}},	//   gsrb, _алһы, _swcr, _ئیجب, 
   {{0x2618004d,0xb4600022,0x00000000,0x00000000}},	//   _méo_, _скәл, --, --, 
   {{0x2619c453,0xbcf80248,0x9d4401ec,0x00000000}},	// [320d0] _léo_, _gbél, кеңд, --, 
   {{0xdb04002d,0x2139302f,0x2a7808a5,0x39d800e1}},	//   chhû, lash_, _bsrb_, यक्ि, 
   {{0xdea00ec9,0xe0d00014,0x261806af,0x237c022e}},	//   _ایزی, _خٲک_, _néo_, _mavj_, 
   {{0xdd9443a7,0x81c002a6,0x2139c454,0x6838063f}},	//   _самы, ্তক_, nash_, _ụdar, 
   {{0xdc6c0092,0x00000000,0x00000000,0x00000000}},	//   ስተምር_, --, --, --, 
   {{0xfc3c0093,0x21390fba,0x2618001e,0xd6d8084c}},	//   _iví_, hash_, _béo_, нӂе_, 
   {{0x2139c455,0xfc3c0579,0xaa9504f2,0xdcec010f}},	//   kash_, _hví_, _кирч, rkaĵ, 
   {{0x213885d7,0xdcec00df,0xfc3c02d2,0xc8dc01f9}},	//   jash_, skaĵ, _kví_, _फुकट, 
   {{0x58d41b74,0x2139c456,0x67380841,0xd17401ec}},	//   _соат, dash_, bavj, қыны, 
   {{0xdb14002f,0x67380200,0xf644022e,0x00000000}},	//   _umzä, cavj, _ахдн, --, 
   {{0x261839b2,0xd1c9c457,0x21380200,0xfc3c013a}},	//   _géo_, елне_, fash_, _lví_, 
   {{0x2139c458,0xfc3c00db,0x645c0356,0x00000000}},	//   gash_, _oví_, ărir, --, 
   {{0xbb5000b5,0xd469c459,0x73c000fb,0x00000000}},	//   _minコ_, _чиле_, _ҡәүе, --, 
   {{0x2138062c,0x8e745bc6,0xcee8004e,0x00000000}},	//   aash_, лубч, едге_, --, 
   {{0xfc3c004e,0x20180ba7,0x2618004d,0x00000000}},	//   _aví_, aqsi_, _xéo_, --, 
   {{0x6738107d,0x00000000,0x00000000,0x00000000}},	//   zavj, --, --, --, 
   {{0xe1640137,0x4b8800ee,0x8fa400db,0x41b001e2}},	// [320e0] _ئدىي, нйан_, _бапе, _دمير, 
   {{0xbcf80248,0x3ebc0115,0x00000000,0x00000000}},	//   _gbém, ŝuta_, --, --, 
   {{0xa4f01f13,0xdc6c001f,0x41b03fb8,0x00000000}},	//   _चर्च_, ስተማር_, _ضمیر, --, 
   {{0x2b580472,0x0935c45a,0x3ed007d6,0x1ad4102f}},	//   _wcrc_, اراج, _چقیر, _दशरथ, 
   {{0xe895c45b,0x07a44d56,0xc7c40f43,0x77600175}},	//   раль, ладн, лски, ffnx, 
   {{0x2d801caa,0x213964f9,0x26180051,0x00000000}},	//   ldie_, zash_, _péo_, --, 
   {{0x67380f72,0x21380309,0x09bc2cc5,0x9f440129}},	//   ravj, yash_, েকবা, ôlé_, 
   {{0x2d81c45c,0x4428026a,0x6738549d,0xe5840c75}},	//   ndie_, нцом_, savj, рткү, 
   {{0x2d81c45d,0x08880184,0x2138036e,0xe3a401d5}},	//   idie_, _ябай_, vash_, لشدی, 
   {{0x73d495a3,0x7af80115,0x00000000,0x00000000}},	//   лдыр_, _ŝuti, --, --, 
   {{0x2139c45e,0x00000000,0x00000000,0x00000000}},	//   tash_, --, --, --, 
   {{0x2d800311,0x00000000,0x00000000,0x00000000}},	//   jdie_, --, --, --, 
   {{0x2d81c45f,0x2139c460,0x5ff4084c,0x245801af}},	//   ddie_, rash_, изму, _раль_, 
   {{0x21386fff,0x2018011f,0x629c0158,0xef20031c}},	//   sash_, rqsi_, øros, żżnu_, 
   {{0x21380986,0xbcf801e1,0xd1e80092,0x9e340022}},	//   pash_, _gbéj, ሙሮች_, ребч, 
   {{0x21380986,0x81dc00cc,0x00000000,0x00000000}},	//   qash_, _থওক_, --, --, 
   {{0x48b4015b,0xade80214,0x1fb8004e,0xdfd40006}},	// [320f0] জপুর, افقم_, _алпы_, _вопы, 
   {{0x2d81c461,0x00000000,0x00000000,0x00000000}},	//   adie_, --, --, --, 
   {{0xa3cc000d,0x00000000,0x00000000,0x00000000}},	//   _रगन_, --, --, --, 
   {{0x57dc0490,0xfc3d21d0,0x00000000,0x00000000}},	//   यव्ह, _tví_, --, --, 
   {{0xbcf8002e,0xd5b0004d,0xa3d40073,0xdef80023}},	//   _mbék, _lúc_, सचा_, ሊፍካ_, 
   {{0x36400131,0x00000000,0x00000000,0x00000000}},	//   مىتې, --, --, --, 
   {{0x9ae80ef6,0x3a2000ef,0x00000000,0x00000000}},	//   _شىرك_, _utjp_, --, --, 
   {{0x2688027d,0x00000000,0x00000000,0x00000000}},	//   اخوي_, --, --, --, 
   {{0xf84401c6,0x00000000,0x00000000,0x00000000}},	//   _сүлд_, --, --, --, 
   {{0x91e400b5,0x659400d1,0xd2640024,0x998c0419}},	//   _ccのm, _қачу, акой, _sieň_, 
   {{0xd6d09717,0x25b001ed,0x248000c0,0x3688444e}},	//   _بقا_, álló_, _šimt_, _ясан_, 
   {{0x9104008e,0xb07800c7,0x00000000,0x00000000}},	//   ипне, гӡоу_, --, --, 
   {{0x7539c462,0x2d800200,0x3448010a,0x00000000}},	//   mauz, vdie_, _ччен_, --, 
   {{0x7539c463,0xdcfc01e4,0x2d81c464,0x00000000}},	//   lauz, _gasĉ, wdie_, --, 
   {{0x51640228,0x59b428e0,0x2d80017a,0x998c0419}},	//   _күнү_, ंसार, tdie_, _tieň_, 
   {{0x7539c465,0x2d80017a,0x7bc4009f,0xbcf801e1}},	//   nauz, udie_, _amju, _gbék, 
   {{0x2d81c466,0xf2d400eb,0xbd302ba5,0x00000000}},	// [32100] rdie_, _হরিণ, زىلع, --, 
   {{0x75380925,0x2f1c01e1,0x2d80002d,0x21f800e4}},	//   hauz, _dàgó_, sdie_, méha_, 
   {{0x3dd40570,0x7539c467,0x80a80183,0xd5b00208}},	//   úewé_, kauz, _চেপ্, _xúc_, 
   {{0x8885c468,0x2f1c01e1,0x7539b4d5,0x996402dd}},	//   илеж, _fàgó_, jauz, йтіл, 
   {{0x38c816e0,0xe8f800fb,0x00000000,0x00000000}},	//   پانی_, уһа_, --, --, 
   {{0xc6681de1,0xdced161f,0x466801d5,0x00000000}},	//   вшие_, ndaĝ, врим_, --, 
   {{0x8a04005b,0xf654007b,0x00000000,0x00000000}},	//   _взве, لجيش_, --, --, 
   {{0x21f800e4,0xe9440cbb,0x00000000,0x00000000}},	//   kéha_, _درسی, --, --, 
   {{0xd3440133,0x00000000,0x00000000,0x00000000}},	//   ڕیوه_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7538002f,0xe3b80205,0x00000000,0x00000000}},	//   bauz, rhı_, --, --, 
   {{0x75387da7,0xd24c2374,0xdb2003b2,0xe3b80205}},	//   cauz, رچى_, ðtús, shı_, 
   {{0x9f44006a,0xf4843737,0x00000000,0x00000000}},	//   ôlï_, _پانی, --, --, 
   {{0x4425c469,0x2d180014,0xd5b00051,0x00000000}},	//   _ito_, یکُک_, _túc_, --, 
   {{0x93ec013f,0xbdc402e8,0x00000000,0x00000000}},	//   gyeε_, ащай, --, --, 
   {{0x4425c46a,0x7bc4000f,0x6db40137,0x3ebc00df}},	//   _kto_, _smju, ойсу, ŝuto_, 
   {{0x61edc46b,0xac18e4ae,0x30a40006,0x44240064}},	// [32110] _ikal, иоту_, _дрэв, _jto_, 
   {{0x4425c46c,0x69d820ef,0x6440922c,0xfa840063}},	//   _mto_, éven, ismi, ићем, 
   {{0x44240ecf,0x61edc46d,0x753801f7,0xdd9037ba}},	//   _lto_, _kkal, yauz, _فود_, 
   {{0x4425c46e,0x6441348c,0x98b86bcd,0x7538022e}},	//   _oto_, ksmi, ллет_, xauz, 
   {{0x4425c46f,0x61ed1353,0xbcf8004a,0x18680d99}},	//   _nto_, _mkal, _obéi, уали_, 
   {{0x75380bd7,0x67d40228,0x7bc5c470,0x61ec01d5}},	//   wauz, оочу, _umju, _lkal, 
   {{0x61edc471,0x7bd40944,0x753801f7,0x6441c472}},	//   _okal, mnxu, tauz, esmi, 
   {{0x61edc473,0x644001f5,0xf1c00306,0x69c80153}},	//   _nkal, fsmi, ďák_, _įdeg, 
   {{0x44247e54,0x7539c474,0x00000000,0x00000000}},	//   _cto_, rauz, --, --, 
   {{0x4424b74a,0x7538090c,0x270c0134,0xf6e4011c}},	//   _dto_, sauz, bɛn_, _кцен, 
   {{0x4425c475,0xe788021a,0x7bd40e14,0x71740131}},	//   _eto_, _خپله_, inxu, قۇغا, 
   {{0x3f9001a9,0x64401308,0x659436cb,0xd1b800db}},	//   _anxu_, bsmi, _маху, اادا_, 
   {{0x0d8401e0,0x27e001c7,0x21f8009d,0x00000000}},	//   ҙлан, éing_, рхээ_, --, 
   {{0x61edc476,0x0d8402dd,0x00000000,0x00000000}},	//   _ekal, әлан, --, --, 
   {{0x61ec03a0,0x44240010,0xa3cc012c,0xdcfc00b8}},	//   _fkal, _zto_, _रगत_, _āyāc, 
   {{0xdcfcb8ef,0xa2240451,0xc6900a7c,0x23bc0241}},	//   _alsı, _بروه, האל_, _tájù_, 
   {{0x0b440fdc,0x44240789,0x75d00356,0x8f740024}},	// [32120] йнан, _xto_, găzi, _луні, 
   {{0x0ba82ba5,0x270c013b,0x61ec01ef,0x00000000}},	//   دارى_, yɛn_, _zkal, --, 
   {{0x8e85c477,0x0a4802f6,0x00000000,0x00000000}},	//   _الجه, узей_, --, --, 
   {{0x8d542cfe,0x6441c478,0x00000000,0x00000000}},	//   _уточ, ysmi, --, --, 
   {{0x270c013f,0x6440005c,0x69c80153,0x00000000}},	//   wɛn_, xsmi, _įded, --, 
   {{0xbcf80241,0x3200062c,0x6440248f,0xdcec8411}},	//   _abéw, _lhiy_, vsmi, ldağ, 
   {{0x64400066,0x2c1c00cd,0xb99000d1,0x00000000}},	//   wsmi, _भूतं_, غلۇب, --, 
   {{0xdcec0598,0xfad40375,0x270c013f,0xf64c33d2}},	//   ndağ, _הולך_, rɛn_, رئى_, 
   {{0x4425c479,0x6441c47a,0x07a4009d,0x00000000}},	//   _qto_, usmi, _лаан, --, 
   {{0x61ecbdd1,0xc765c47b,0x4424009b,0x270c0134}},	//   _skal, _دارى, _vto_, pɛn_, 
   {{0x4425c47c,0x9f8c012c,0xe2f802bf,0x779001ed}},	//   _wto_, uží_, рені_, _ریٹا, 
   {{0xf2c1c47d,0x4425c47e,0x64403c02,0xbcf801e1}},	//   ясын, _tto_, psmi, _gbéw, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x62344b7d,0xd24c00f7,0x00000000,0x00000000}},	//   _деку, رچۉ_, --, --, 
   {{0xfba80220,0x3f81c47f,0x9f042a9f,0xd5b00051}},	//   қтай_, rdju_, زورو, _mún_, 
   {{0x61edc480,0xbdf800db,0x21f802fb,0x69d80129}},	//   _ukal, ارسا_, mého_, ével, 
   {{0x21f803c6,0xad241c02,0x62880113,0x5c98004e}},	// [32130] lého_, سىلى, lvdo, шкая_, 
   {{0x75d00276,0xefbc0092,0x9b9433d2,0xdcec013d}},	//   răzi, ደቀው_, غلات, adağ, 
   {{0x21f8076f,0x1df812c4,0xfbd00014,0xdd9000e5}},	//   ného_, _вены_, _ہتس_, _ہوگ_, 
   {{0xc0b802d3,0x7258008f,0x00000000,0x00000000}},	//   _ሳልሕ_, רכאפ, --, --, 
   {{0x21f80122,0xd15002d3,0xdcfc02e2,0xf848020f}},	//   hého_, _ቁጠባው, _kasč, учей_, 
   {{0x21f80745,0x6e440244,0xae440345,0x00000000}},	//   kého_, _بنێم, _بپێو, --, 
   {{0x2f5c0a1e,0x39a40117,0x00000000,0x00000000}},	//   אדונ, _лшав, --, --, 
   {{0x9424412c,0x21f802fb,0x14243dab,0xa268010c}},	//   омие, dého_, одим, ጽግናን_, 
   {{0x6f01acf9,0x57d403b7,0xdfe805d7,0x28f800d4}},	//   _kábí, _доаѓ, ओवाद_, _геть_, 
   {{0x387dc481,0x6d4800e2,0x3200022e,0x53c8668b}},	//   _isur_, _ēdam, _shiy_, ргом_, 
   {{0x395c0b4b,0x65bc0098,0x27e000c6,0x170401d3}},	//   _kcus_, _béhd, éine_, _ظہبی_, 
   {{0x387c0003,0x6f000ca8,0x00000000,0x00000000}},	//   _ksur_, _lábí, --, --, 
   {{0xdb040267,0x4ec400cc,0x76404cab,0x212c0124}},	//   lkhä, _এডেল, lsny, ñeha_, 
   {{0x21f802fb,0xf4840066,0x00000000,0x00000000}},	//   bého_, _پاچی, --, --, 
   {{0x7641c482,0x91800b38,0x2bc000ab,0xdb0401f4}},	//   nsny, _قۇدۇ, _एतबा, nkhä, 
   {{0x2000000d,0x8d640006,0xe80093d3,0x56540023}},	//   _ehhi_, ўвае, _लीना_, _ዘይነብ, 
   {{0xdcec2706,0xdc280f1c,0x69d800e4,0x00000000}},	// [32140] rdağ, مسله_, évem, --, 
   {{0x395c0381,0x65bc030a,0x0b4402bf,0x1b1c0154}},	//   _acus_, _iéhe, інен, _পড়বে_, 
   {{0x387dc483,0x6f0001e1,0xdb04002f,0xdcec03b9}},	//   _asur_, _dábí, chhü, pdağ, 
   {{0x2d8400c7,0x08280305,0x764001e3,0x3bcc031c}},	//   _ûme_, ацки_, dsny, rżqa_, 
   {{0x7640017a,0x395c005c,0x6684004b,0x7dd00327}},	//   esny, _dcus_, ګیال, għsu, 
   {{0xf76c02dd,0x395c01ab,0x9e641272,0x06243cc5}},	//   ناى_, _ecus_, _باین, офим, 
   {{0x76401f53,0x00000000,0x00000000,0x00000000}},	//   gsny, --, --, --, 
   {{0x21f88ea8,0x00000000,0x00000000,0x00000000}},	//   vého_, --, --, --, 
   {{0x76400a2e,0x00000000,0x00000000,0x00000000}},	//   asny, --, --, --, 
   {{0x21f804bf,0x83a816c3,0x31601cce,0x63b80051}},	//   tého_, ртиб_, _aciz_, _qlvn, 
   {{0xdcfc4bc9,0x22942f34,0xa2940d30,0xdb04343a}},	//   _rasč, чиня, чані, ckhä, 
   {{0x21f803c6,0xa024025c,0x00000000,0x00000000}},	//   rého_, _འཕྱང_, --, --, 
   {{0x55d8008f,0x21f802f0,0xb0340064,0x00000000}},	//   _פֿענ, sého_, мняш, --, 
   {{0x21f80306,0x00000000,0x00000000,0x00000000}},	//   pého_, --, --, --, 
   {{0x3da47579,0x81f400ae,0x00000000,0x00000000}},	//   ораб, _وأعط, --, --, 
   {{0x9df80fc0,0x6f0001e1,0xa97801e1,0xfd9800db}},	//   ёнат_, _sábí, _àkèé_, جئست_, 
   {{0xa0240135,0xc0580212,0x75d00356,0xffe400c0}},	// [32150] _འཕྲང_, _тій_, căzu, _мюон, 
   {{0xfa89c484,0x26c00115,0x6b74009d,0x00000000}},	//   исей_, ĝioj_, млуу, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbd682b41,0x1959bfc0,0x4e7800c8,0x65bc00f2}},	//   _трое_, сады_, _פארצ, _yéhe, 
   {{0xf1b40302,0x7640020b,0x7c640345,0x6f000241}},	//   וסף_, wsny, _باجل, _tábí, 
   {{0x7641c485,0xb07c010f,0xdb201572,0x00000000}},	//   tsny, ינדז, ätät, --, 
   {{0x9aa410ed,0xf8ac00f1,0x15440150,0x00000000}},	//   _عمرو, رکړ_, пейм, --, 
   {{0x387c0ac5,0xdb043b52,0x00000000,0x00000000}},	//   _tsur_, rkhä, --, --, 
   {{0x76401a87,0x387dc486,0x98b80d6f,0x80a800eb}},	//   ssny, _usur_, _улат_, _চেস্, 
   {{0x75d0084c,0x1b1c015b,0x7641c487,0xe4c800ae}},	//   văzu, _পড়তে_, psny, غبين_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb0401e3,0x00000000,0x00000000,0x00000000}},	//   ckhå, --, --, --, 
   {{0xbcf800f2,0xc0cc001f,0x973002d3,0xd00800fb}},	//   _mbés, _ጥቁር_, _ጽንዓት, йеме_, 
   {{0xc0d00020,0xb2b00131,0x0fd80153,0x0c2401f0}},	//   _የጋራ_, _жәмъ, сьмы_, ҷман, 
   {{0xa3b9c488,0xbcf8004a,0x69d803df,0x00000000}},	//   _ظاهر_, _obés, évek, --, 
   {{0xd1b9c489,0x65bc003e,0x0c25c48a,0xa6a800cc}},	//   _داتا_, _téhe, зман, _কেঁয়, 
   {{0x904400c6,0x00000000,0x00000000,0x00000000}},	// [32160] _عنده, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb0400d2,0x00000000,0x00000000,0x00000000}},	//   mkhû, --, --, --, 
   {{0x7e980375,0xadb800cf,0xcf7801c6,0xf1dc043e}},	//   _הסטו, _بۇرا_, _тбүц_, मचिन, 
   {{0xd90d6e84,0xaf500240,0x00000000,0x00000000}},	//   لیف_, _ክምስገ, --, --, 
   {{0xa37c01e4,0x66f40798,0x00000000,0x00000000}},	//   loĵv, мплу, --, --, 
   {{0x3e8400bc,0x00000000,0x00000000,0x00000000}},	//   mítá_, --, --, --, 
   {{0xbcf9c48b,0x2ca1c48c,0x057400c6,0x00000000}},	//   _ibér, oxid_, ساعد, --, 
   {{0xdcfc0a88,0xdb04007c,0x47c40484,0x00000000}},	//   _kasā, rkhå, _ебав, --, 
   {{0x3ebc00c8,0xd90c0345,0x00000000,0x00000000}},	//   ŝuti_, _ئیه_, --, --, 
   {{0x2179c48d,0xdcfc005f,0x00000000,0x00000000}},	//   ойны_, _masā, --, --, 
   {{0xbcf8002e,0xdcfc00e2,0x00000000,0x00000000}},	//   _mbér, _lasā, --, --, 
   {{0xbcf85f6f,0xd8c0025c,0x00000000,0x00000000}},	//   _océa, _ཀཿབྲ, --, --, 
   {{0xefc8115c,0x93f000c7,0x00000000,0x00000000}},	//   пуск_, _иҿыц, --, --, 
   {{0x6e9435c7,0x33f800d9,0x629c007c,0x00000000}},	//   ниру, _ההגנ, årod, --, 
   {{0x9df801ce,0xb280030d,0x00000000,0x00000000}},	//   інат_, _чышк, --, --, 
   {{0xbcf801e1,0xdcfc0171,0x00000000,0x00000000}},	// [32170] _abér, _basā, --, --, 
   {{0xec6888d6,0xbcf80332,0xd9b42e05,0x61740248}},	//   ярск_, _ccéa, ंस्ट, _ọdọọ, 
   {{0x2ca0058a,0xdb15c48e,0x9d1800d8,0x3cec01f9}},	//   axid_, _umzü, _монт_, _आडवे_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb0400d2,0xdcfc00e2,0x00000000,0x00000000}},	//   nkhú, _fasā, --, --, 
   {{0xab845252,0xbcf80597,0x6d400428,0x75f400d8}},	//   _пуск, _gcéa, _ômar, mãzi, 
   {{0xbcf80ca8,0xcbc400f1,0xaa580117,0x55e4004e}},	//   _gbér, _تېلو_, _ниру_, мокб, 
   {{0xd838007f,0xdb040bcd,0x79a4eacb,0x5c780092}},	//   _twō_, kkhú, _эрге, _የካናዳ_, 
   {{0xed6000bc,0x00000000,0x00000000,0x00000000}},	//   ížit_, --, --, --, 
   {{0x21280429,0x61e401e4,0xa8a4010a,0x00000000}},	//   _afah_, _ĉila, _ярск, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x845000f7,0x00000000,0x00000000,0x00000000}},	//   رۉۉچ, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x21280109,0x98ac0030,0x56a400b8,0x00000000}},	//   _efah_, _oceľ_, _ūrṇā_, --, 
   {{0x3e840118,0xdcfc00dc,0x00000000,0x00000000}},	//   vítá_, _rasā, --, --, 
   {{0xbcf80597,0xdcfc3da0,0xa184010a,0x00000000}},	//   _scéa, _sasā, _пăсĕ_, --, 
   {{0xdcfc0029,0x8fa4004e,0x00000000,0x00000000}},	// [32180] _pasā, _жапе, --, --, 
   {{0x65bc4de4,0x8ad400ec,0x00000000,0x00000000}},	//   _méha, وتائ, --, --, 
   {{0xc985b96b,0xbf98011a,0xfaa01246,0xdcfc00cd}},	//   дули, _וייש, кафо, _vasā, 
   {{0xf9c4187c,0x2bc0000d,0x00000000,0x00000000}},	//   وحنی, _एतवा, --, --, 
   {{0xbeac0055,0xb90c0055,0xdcfc0055,0x7d78011a}},	//   _eṣāh, _kroṃ_, _tasā, _ונכו, 
   {{0x6d45c48f,0x29000115,0x00000000,0x00000000}},	//   laia, ĥia_, --, --, 
   {{0xd90c066d,0x5a5406bb,0xba21c490,0xe784023b}},	//   لیہ_, _пъту, _адск, дуқо, 
   {{0x6d45c491,0xdb1002d2,0x00000000,0x00000000}},	//   naia, _áfát, --, --, 
   {{0xb5c400db,0x00000000,0x00000000,0x00000000}},	//   بويم_, --, --, --, 
   {{0x6d45c492,0x69b40490,0x65bc0129,0x00000000}},	//   haia, _आवडी, _déha, --, 
   {{0x6d45c493,0x45280276,0xe3c40116,0x77ac03b2}},	//   kaia, _джен_, _үрлү, _vøxt, 
   {{0x8505ab62,0xc32c0075,0x6d45c494,0xf590007b}},	//   _قوان, _ھەج_, jaia, _للمج, 
   {{0x6d45c495,0x21f800f2,0xbcf80241,0x03a40117}},	//   daia, néhi_, _nbép, _оидо, 
   {{0x6d440093,0xdb040162,0x00000000,0x00000000}},	//   eaia, rkhú, --, --, 
   {{0x6d45c496,0x05b006ab,0xe3b803e0,0x00000000}},	//   faia, _जवाब, mkı_, --, 
   {{0xe3b870f7,0x6d45c497,0x656012ef,0x41e4007b}},	//   lkı_, gaia, ngmh, _تستف, 
   {{0xdcb025aa,0x5bb80eed,0x9b940395,0x00000000}},	// [32190] دىء_, плая_, ниац, --, 
   {{0xe3b84956,0x00000000,0x00000000,0x00000000}},	//   nkı_, --, --, --, 
   {{0x6d446b9e,0xdfd00206,0x1a640133,0x5a34667a}},	//   baia, _ليک_, عیری_, хнет, 
   {{0x6d45c498,0x629c0579,0x6e2800e4,0xb17c010f}},	//   caia, øroy, _ẽngá, ַטור, 
   {{0xe3b80365,0x00000000,0x00000000,0x00000000}},	//   kkı_, --, --, --, 
   {{0x9665c499,0x65bdc49a,0xdb04143a,0x3ebc010f}},	//   екке, _réha, kkhø, ŝutu_, 
   {{0x7c2c00e4,0x65bc8616,0x00000000,0x00000000}},	//   _htcr, _séha, --, --, 
   {{0xfd1c026c,0x65bc0066,0x00000000,0x00000000}},	//   _maìo_, _péha, --, --, 
   {{0xa9240232,0x79980b45,0xb7800116,0xa81815bf}},	//   _úžas, _inuw, _ағли, ستۇر_, 
   {{0x65600597,0x00000000,0x00000000,0x00000000}},	//   agmh, --, --, --, 
   {{0x95880139,0x69d800e4,0x00000000,0x00000000}},	//   _ciƅä, ĩvev, --, --, 
   {{0x1df802ab,0xcb1002e4,0x43640107,0x00000000}},	//   ंतोष_, טלי_, _ҷашн_, --, 
   {{0x6d45c49b,0xbcf9c49c,0xcf4c02d3,0xdb040112}},	//   vaia, _scén, _ንምፍታ, chhö, 
   {{0xb4c80cb4,0xd9bc194b,0x00000000,0x00000000}},	//   रछी_, ्फुट, --, --, 
   {{0x6d45c49d,0x79980086,0x527405f5,0x00000000}},	//   taia, _onuw, _чулу, --, 
   {{0x1b1c0154,0xc0b80023,0x00000000,0x00000000}},	//   _পড়লে_, _ሳግም_, --, --, 
   {{0x6d45c49e,0x20540166,0xb37c0023,0x00000000}},	// [321a0] raia, _итэр, _ንኪዳን_, --, 
   {{0x7c29c49f,0xaca401f2,0x799801f7,0x9b2c00b8}},	//   ígra, _nrụt, _anuw, _kīṭā, 
   {{0x6d45c4a0,0xdcfc0311,0x8a180244,0x291801e1}},	//   paia, _pasă, ستاس_, _ńra_, 
   {{0xaca401f2,0xc9f5c4a1,0xc8640aa8,0x7c280115}},	//   _arụt, رساع, етки, ŭgra, 
   {{0x65bc003e,0x27e000e4,0x00000000,0x00000000}},	//   _béhn, éino_, --, --, 
   {{0x7999c4a2,0x7c38415b,0x7ae800e5,0x00000000}},	//   _enuw, _çura, élté, --, 
   {{0x21f8525e,0x4e78010f,0x7bc8036e,0x00000000}},	//   séhi_, לאַצ, ëgue, --, 
   {{0x38c8af84,0x998c012d,0x66040327,0x00000000}},	//   _کافی_, _cień_, ċiko, --, 
   {{0x69c1c4a3,0xe3b8247e,0x7dd8008e,0x00000000}},	//   _ilme, tkı_, läsä, --, 
   {{0x2904022e,0xd7ec0451,0x46a40410,0xf740059f}},	//   _izma_, _وڃو_, _пазв, _бефо, 
   {{0xe3b9c4a4,0x7dd80724,0xa159c4a5,0x26d801e3}},	//   rkı_, näsä, ману_, _äro_, 
   {{0xe3b803ee,0xb6b80375,0xdb0401bf,0x00000000}},	//   skı_, _מצבי, rkhø, --, 
   {{0xecd002ab,0xe3b805d1,0x7a4400e5,0x7dd80139}},	//   _सेलफ, pkı_, _kétá, häsä, 
   {{0x09bc0154,0xe3b803b9,0x00000000,0x00000000}},	//   েকটা, qkı_, --, --, 
   {{0x65bc006a,0x69c1c4a6,0x35400014,0x7c2c01f5}},	//   _jého, _olme, _شى۪ہ, _stcr, 
   {{0x290400df,0x7a440118,0x00000000,0x00000000}},	//   _ozma_, _létá, --, --, 
   {{0x98bc33d4,0x21380200,0x6c5400cf,0x9d140108}},	// [321b0] kawā_, mbsh_, лкту, тдач, 
   {{0xdb140077,0x7c2c02c4,0x61fcd457,0xe80008e9}},	//   _alzá, _vtcr, llsl, _लीला_, 
   {{0x2a7800ca,0x290400ec,0x65bc4e79,0x00000000}},	//   _cprb_, _azma_, _réhn, --, 
   {{0x3234008f,0x7f44047e,0xd5b00208,0x9f50036e}},	//   גטאן_, lajq, _túi_, kozë_, 
   {{0x69c030c6,0x5724515c,0x1869845e,0x69340137}},	//   _dlme, نىشك, фали_, унчу, 
   {{0x37a9c4a7,0x69c01de4,0x7f440113,0xfc3c01e1}},	//   ятен_, _elme, najq, _iwí_, 
   {{0x2904022e,0x7bd4009a,0x2f98011a,0xb88000d7}},	//   _ezma_, mixu, תכון_, _sníč, 
   {{0x79980784,0x69c001ab,0x69d80789,0x7bd5c4a8}},	//   _unuw, _glme, évet, lixu, 
   {{0x24d4045e,0x65bc0438,0xb4c800ab,0xb5a402dd}},	//   _হুবহ, _téhn, रछे_, _үрей, 
   {{0x61fc01f5,0x7bd40381,0x00000000,0x00000000}},	//   elsl, nixu, --, --, 
   {{0x13081c22,0xbcf8205e,0xdcec0003,0x00000000}},	//   ьной_, _scél, ffaċ, --, 
   {{0xd4f41411,0x06c8015b,0xdcfc0210,0x00000000}},	//   _иялы, _লুকি, _zasą, --, 
   {{0x7bd4005a,0x35d0004b,0xa0740124,0x316c0210}},	//   kixu, _لښکر, лырш, ędz_, 
   {{0xfd1cb269,0x7dd80724,0x61fc01f5,0x00000000}},	//   _agì_, yäsä, alsl, --, 
   {{0x7bd4005a,0xfe4001b9,0x00000000,0x00000000}},	//   dixu, инро, --, --, 
   {{0xc69025f9,0xd9bc3af4,0x225800d0,0x00000000}},	//   סאן_, ्फोट, árke_, --, 
   {{0x7bd409d3,0x4fe99760,0x7f440477,0x10a40484}},	// [321c0] fixu, _омин_, bajq, _рипн, 
   {{0xdb1402f0,0x69b4000d,0x00000000,0x00000000}},	//   _slzá, _आवही, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7a4401ed,0x57a40032,0xdeec0150,0x7dc00037}},	//   _sétá, ғышҡ, _رۋق_, _põse, 
   {{0x2d8000a8,0x98bc00b0,0xc7a4234c,0xc7c40108}},	//   meie_, tawā_, кидк, кски, 
   {{0x2d81c4a9,0x00000000,0x00000000,0x00000000}},	//   leie_, --, --, --, 
   {{0xfaa1c4aa,0x7aa01321,0x65bc0036,0x42900023}},	//   _каро, _кирз, _féhl, ዝኾነት_, 
   {{0x69c03f17,0x2d800421,0x2fd8022e,0x9f500200}},	//   _ulme, neie_, hirg_, tozë_, 
   {{0x2905c4ab,0x61fc0158,0x7f44014f,0x00000000}},	//   _uzma_, vlsl, yajq, --, 
   {{0x2d800fac,0x73d400ee,0x65bc0118,0x9f500200}},	//   heie_, кдыр_, _tého, rozë_, 
   {{0x2d800151,0xaab405d7,0x61fc0083,0x2fd8022e}},	//   keie_, ूनिक, tlsl, dirg_, 
   {{0x7bd40117,0x0494007b,0xc108013d,0x00000000}},	//   zixu, _للصح, дэге_, --, 
   {{0x2d800158,0x61fc0726,0x7bd40472,0x7f440113}},	//   deie_, rlsl, yixu, tajq, 
   {{0x65bc003e,0xdcec025c,0x00000000,0x00000000}},	//   _méhm, sfaċ, --, --, 
   {{0xa195c4ac,0x2d800fac,0x00000000,0x00000000}},	//   _байч, feie_, --, --, 
   {{0x60b5c4ad,0x33040150,0x2d81c4ae,0x9ed80116}},	//   _ممبئ, _جيىپ_, geie_, _үмит_, 
   {{0x7f4402d1,0x2fd801bf,0x224c005c,0x4084014b}},	// [321d0] pajq, birg_, lsdk_, _руйб, 
   {{0xd5b00208,0x5c780023,0x00000000,0x00000000}},	//   _hút_, _ከካይዶ_, --, --, 
   {{0x2010009a,0xab8406a6,0xaa640166,0x00000000}},	//   mmzi_, шутк, итцк, --, 
   {{0x7bd40107,0x7c380166,0xfd6000db,0xbd840345}},	//   sixu, _çuro, _өнүү, _جۆرن_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69d9c4af,0x00000000,0x00000000,0x00000000}},	//   éver, --, --, --, 
   {{0xf9680046,0xd39401e0,0x65bc0118,0xab841925}},	//   _орай_, ғәлә_, _téhl, _туяк, 
   {{0xb8640a7b,0xd5b00208,0x96d40022,0x00000000}},	//   _لائو, _nút_, ксқә, --, 
   {{0x2868010a,0x2fd8022e,0x00000000,0x00000000}},	//   _архо_, yirg_, --, --, 
   {{0x52a8aa53,0x10a401d5,0x00000000,0x00000000}},	//   евом_, ҳимн, --, --, 
   {{0xd574fd2f,0x7ae0002d,0x95740f15,0xd5b00051}},	//   _буль, ûnth, _былч, _bút_, 
   {{0x10a401b9,0xc0d00092,0x00000000,0x00000000}},	//   гимн, _የኋላ_, --, --, 
   {{0x2d80003b,0x00000000,0x00000000,0x00000000}},	//   veie_, --, --, --, 
   {{0x06c802f5,0xdb0400d2,0x92b46ea9,0xd4f401e0}},	//   _লুটি, nkhó, _محبا, _ияһы, 
   {{0xe2a8e540,0x0d200137,0x2d800356,0x00000000}},	//   _لاين_, йүнү, teie_, --, 
   {{0x6fd403e3,0x753801d5,0x0c38007b,0x50d47b8f}},	//   _mücə, nbuz, فكرة_, _مزخر, 
   {{0x2d81c4b0,0x3ce8003a,0x48bc0154,0x00000000}},	// [321e0] reie_, _cxcv_, _অশ্র, --, 
   {{0x8b2466c1,0x2d802f81,0x7c5407d6,0x2fd8022e}},	//   удже, seie_, اللر_, qirg_, 
   {{0xe945b709,0x7bc80240,0xdb04002f,0x7539c4b1}},	//   لرشی, ëgua, ckhü, kbuz, 
   {{0x38c8e43b,0x08c4084c,0xe6b4006c,0x00000000}},	//   کامی_, лбен, یلشگ, --, 
   {{0x6cb4009d,0x753801ef,0x00000000,0x00000000}},	//   _төвт, dbuz, --, --, 
   {{0xa63400d6,0x2c0450c0,0xfce000d8,0x66b401f4}},	//   анкі, _түзм, _ѓоро, иблу, 
   {{0xf76c03e6,0x6fd403b9,0xd76401b9,0x3f8c00a2}},	//   ساو_, _cücə, شچلی, _önuň_, 
   {{0x19940798,0x00000000,0x00000000,0x00000000}},	//   _кјур, --, --, --, 
   {{0xd5b00208,0xcfe00150,0x48e40108,0x00000000}},	//   _rút_, _ﺍﺳﺎﺗ, _соав, --, 
   {{0xa3d4094e,0x753804ba,0x00000000,0x00000000}},	//   рооч, abuz, --, --, 
   {{0x753815a9,0x00000000,0x00000000,0x00000000}},	//   bbuz, --, --, --, 
   {{0x0444bf66,0x611417a0,0x00000000,0x00000000}},	//   _бедн, идну, --, --, 
   {{0xe7b800dc,0x224c01bf,0x00000000,0x00000000}},	//   _अवाप, ssdk_, --, --, 
   {{0xa3e84309,0x44240093,0x5f9401c6,0xfe700014}},	//   _यदि_, _iuo_, шигт, ٝدر_, 
   {{0x442400b2,0xfeb94db6,0xda1c0037,0x00000000}},	//   _huo_, راست_, _बूझत_, --, 
   {{0x442473f4,0x6298117e,0xa1140133,0x63bc007c}},	//   _kuo_, _irvo, _پوخت, örnf, 
   {{0xa3e80a28,0x6298353f,0x4425c4b2,0x00000000}},	// [321f0] _यदा_, _hrvo, _juo_, --, 
   {{0x69d806af,0x4425c4b3,0x00000000,0x00000000}},	//   èven, _muo_, --, --, 
   {{0x4425c4b4,0x3f80009b,0x9935c4b5,0x75380129}},	//   _luo_, meju_, لفات, ybuz, 
   {{0xdd944c17,0x1959c4b6,0x4425c4b7,0xaf341680}},	//   _тамы, тады_, _ouo_, _پریت, 
   {{0x44244077,0x98a48ba3,0x18a5c4b8,0x47d00451}},	//   _nuo_, риле, ралм, ڪيور, 
   {{0x629800dd,0xbcf80306,0xe89801d3,0x3f81c4b9}},	//   _orvo, _obéz, اموں_, neju_, 
   {{0x4425c4ba,0x47d00137,0xd7c807d6,0x629c03cd}},	//   _auo_, تيور, _یوره_, årol, 
   {{0x4425c4bb,0xf771c4bc,0x75380337,0x59b80b02}},	//   _buo_, _گار_, ubuz, _आविर, 
   {{0x6299c4bd,0x44240b91,0x05a434d8,0xb6a05026}},	//   _arvo, _cuo_, рвый_, риқл, 
   {{0xf7703f0b,0x4424307e,0x7ae0000f,0x795401af}},	//   _دار_, _duo_, ûntw, _шиғр_, 
   {{0x62980fcf,0x59b82ce1,0x442401bf,0xb6304e10}},	//   _crvo, _आवार, _euo_, _اکتش, 
   {{0x629808ad,0x44242139,0x94780276,0xe61004fb}},	//   _drvo, _fuo_, _аску_, _فشن_, 
   {{0x6299c4be,0xd468084c,0x98bc0210,0x3f81c4bf}},	//   _ervo, _риле_, bawą_, feju_, 
   {{0xbcf8007b,0x88b8008f,0xe818166d,0xd0080132}},	//   _gcéi, דזשי, धगया_, теге_, 
   {{0x4425c4c0,0xf230221d,0x7dc0000d,0x80d801f9}},	//   _zuo_, _ابتک, _sõsa, _पेठे, 
   {{0x44240100,0x0d840e92,0x21740354,0x00000000}},	//   _yuo_, јлан, _луьр, --, 
   {{0x0b45c4c1,0x108404a2,0xd7c40490,0x8f7401ca}},	// [32200] инан, ﻪﻧﺪﯨ, वसाच, _куні, 
   {{0x6cc43e25,0x7dc000c5,0x61e4010f,0x1d180138}},	//   айға, _võsa, _ĉili, уюсь_, 
   {{0xbcf8002e,0xca85646a,0x00000000,0x00000000}},	//   _mbéy, ргей, --, --, 
   {{0xbc6408b0,0x26c9c4c2,0xda6400c6,0x98bc0210}},	//   امەن_, ңған_, صامي, zawą_, 
   {{0xe8947927,0x63a40198,0xe75800d4,0x00000000}},	//   саль, _ɗinb, гилі_, --, 
   {{0xd90dc4c3,0x442400b4,0x00000000,0x00000000}},	//   ریل_, _ruo_, --, --, 
   {{0x442458f1,0x998c02fb,0x27e0110c,0x00000000}},	//   _suo_, _oheň_, đin_, --, 
   {{0x44259149,0xbcf80597,0x3f80260c,0xa534011c}},	//   _puo_, _scéi, zeju_, щнич, 
   {{0x4425c4c4,0x98bc033f,0xa4d402d5,0x07a4004e}},	//   _quo_, tawą_, сопі, _каан, 
   {{0xfa0008ea,0x62982aa3,0x92e00c58,0x6600003e}},	//   _མཚོན_, _prvo, _দৰে_, slmk, 
   {{0x3f800006,0x98bc033f,0xa1946b01,0x326002e8}},	//   veju_, rawą_, банч, отяв, 
   {{0x44246ae7,0x76b8011a,0x00000000,0x00000000}},	//   _tuo_, _שמאפ, --, --, 
   {{0x32080323,0x75d000c6,0xc0dc02d3,0x3f805563}},	//   рхэн_, _بينا, _ቓልሲ_, teju_, 
   {{0xbcf80241,0x7c800092,0xc224010a,0x63bc4268}},	//   _gbéy, _ዓላማው_, _кьий, örnd, 
   {{0x3f805d6f,0x7fd402dd,0x629825b9,0x24e80154}},	//   reju_, гіңі, _urvo, _পরিহ, 
   {{0x3f80aa56,0x7c380139,0x00000000,0x00000000}},	//   seju_, _çurk, --, --, 
   {{0x7b64010b,0x7c840075,0x3f81c4c5,0x00000000}},	// [32210] итже, шуве, peju_, --, 
   {{0x35b40248,0x2a880205,0xdfd001c8,0x00000000}},	//   _ḿbẹ_, _bşb_, _ريج_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xaa580414,0x00000000,0x00000000,0x00000000}},	//   рицу_, --, --, --, 
   {{0x9f500316,0x182010dc,0x97d8651a,0xac940150}},	//   hozí_, मदेव_, льку_, _даяш, 
   {{0x49a40032,0xb8dc00dc,0x00000000,0x00000000}},	//   _һыуғ, _ंअ_, --, --, 
   {{0x7bc40135,0xd5b00051,0x957400db,0x00000000}},	//   _ilju, _búp_, быпч, --, 
   {{0x59f834d8,0x65b80022,0x00000000,0x00000000}},	//   _себя_, иуыр_, --, --, 
   {{0x7bc45946,0x0454007b,0xca7400db,0xcda800df}},	//   _klju, ملية_, _نەەت_, ריפֿ, 
   {{0x68e400c6,0xba000092,0xca880023,0x64980395}},	//   úide, _ውሻ_, _ነዚኦም_, ртър_, 
   {{0xa3c80073,0x38780327,0x00000000,0x00000000}},	//   _ईतर_, ħqru_, --, --, 
   {{0x930c05d1,0x91e436ca,0xb0780124,0x00000000}},	//   _ışık, соме, аӡоу_, --, 
   {{0x7bc40579,0x34a800c6,0xe3b000ec,0xa4d4010a}},	//   _olju, _جداً_, _ڪرن_, _мюшш, 
   {{0x6624113e,0x1b1c0154,0x00000000,0x00000000}},	//   _ارەك, _পড়ছে_, --, --, 
   {{0xe3b0fda7,0x6d400086,0x260c02ab,0x63bd3996}},	//   _ترن_, _õmak, _डीडी_, örne, 
   {{0x7bc4e30c,0x24e800fe,0x00000000,0x00000000}},	//   _alju, _পৰিহ, --, --, 
   {{0x69d807ea,0x7bc4041a,0x998c033f,0x00000000}},	// [32220] èvem, _blju, _wieś_, --, 
   {{0x65bc0231,0xa2bc01f9,0x00000000,0x00000000}},	//   _véhi, शनच्, --, --, 
   {{0x387dc4c6,0x09e4e09a,0x24e800fe,0x00000000}},	//   _apur_, божн, _পৰাহ, --, 
   {{0x7bc401d3,0x6e3c0477,0x2d840332,0x466808ca}},	//   _elju, mprb, _úme_, ҳрим_, 
   {{0x7bc4002d,0x00000000,0x00000000,0x00000000}},	//   _flju, --, --, --, 
   {{0x7bc400ef,0xb92800db,0x62880142,0x4669c4c7}},	//   _glju, _ۅزكۅ_, ywdo, грим_, 
   {{0xd90c1550,0xe68801e0,0xfee00220,0xab680171}},	//   _ییم_, рҙек_, _ﺍﺣﯟﺍ, _viļķ, 
   {{0x629c00d0,0x00000000,0x00000000,0x00000000}},	//   ťrok, --, --, --, 
   {{0xc34853d9,0x387c01ab,0xa49401b9,0xe79400ec}},	//   ляне_, _gpur_, تیشت, _وائک, 
   {{0x87e407d6,0x38980a7c,0x00000000,0x00000000}},	//   _اثرل, _גימנ, --, --, 
   {{0xa2a80073,0x628801f5,0xd24dc4c8,0xaad801ec}},	//   टमध्, uwdo, نچي_, лдiр, 
   {{0xc2e407d6,0xba980bd9,0x63bc0267,0x9f5002f0}},	//   _қўли, אסטי, örnb, rozí_, 
   {{0xdef80092,0x9f340150,0x00000000,0x00000000}},	//   ዊውን_, жегі, --, --, 
   {{0x6da80943,0x02a4054d,0x7c380139,0x00000000}},	//   ḓala, _грим, _çuri, --, 
   {{0xdb040267,0x88ac0154,0xdb140205,0x00000000}},	//   lkhö, কনিক, übün, --, 
   {{0x91e400b5,0xe0e401b9,0x7bc800e2,0x00000000}},	//   _ndとm, _қўқо, īgum, --, 
   {{0xcf8dc4c9,0x61edc4ca,0x98bc012d,0xdb05c4cb}},	// [32230] رژی_, _ijal, bawę_, nkhö, 
   {{0x61edc4cc,0x5f800220,0xfaa400cf,0xdfd121e7}},	//   _hjal, _تۇسە, йшен, _آيد_, 
   {{0x387dc4cd,0x61ec05f7,0x7bc409a8,0xbcf85efc}},	//   _spur_, _kjal, _vlju, _acét, 
   {{0x2b58014b,0x387c0589,0x00000000,0x00000000}},	//   _edrc_, _ppur_, --, --, 
   {{0x61edc4ce,0xd7f457aa,0x7e640477,0x00000000}},	//   _mjal, озды, lujp, --, 
   {{0x7bc41505,0x61ec07d6,0x3f90002e,0x7ae0002d}},	//   _ulju, _ljal, _jaxu_, ûnts, 
   {{0x61edc4cf,0xdb140200,0x00000000,0x00000000}},	//   _ojal, _mozë, --, --, 
   {{0x3f90002e,0x3ea41bce,0x959884dc,0xc68c00ec}},	//   _laxu_, _àntu_, ртку_, ئِي_, 
   {{0x53c8466c,0x1cb00327,0xdcfc0139,0xd3880108}},	//   игим_, ྐའི_, _kosı, айпе_, 
   {{0x61edc4d0,0x394dc4d1,0x27e00a40,0x7e640113}},	//   _ajal, lags_, éint_, kujp, 
   {{0x61ec7483,0xb6c48fa3,0x00000000,0x00000000}},	//   _bjal, _усай, --, --, 
   {{0x059400b2,0x00000000,0x00000000,0x00000000}},	//   _وانگ, --, --, --, 
   {{0x61edc4d2,0x3f9001c4,0xd008ab01,0x98bc033f}},	//   _djal, _baxu_, иеме_, tawę_, 
   {{0x61ec0107,0x394c01a8,0x65940133,0x75d00472}},	//   _ejal, hags_, _وجۆر, _بيچا, 
   {{0x61edc4d3,0x98bc0034,0x2b580175,0xdb14036e}},	//   _fjal, rawę_, _rdrc_, _dozë, 
   {{0x61ecd8f6,0xd1b80131,0x81f42ed7,0x00000000}},	//   _gjal, _خاتا_, _وفور_, --, 
   {{0x394dc4d4,0x32000086,0x2b580009,0x3f9002f0}},	// [32240] dags_, _ikiy_, _pdrc_, _faxu_, 
   {{0x8b65c4d5,0x61ec00f3,0xcbb8009e,0xd6e807af}},	//   تارم, _zjal, ৃচ্ছ, टपाथ_, 
   {{0xdb1402bd,0x0928023a,0x00000000,0x00000000}},	//   _jozè, ажей_, --, --, 
   {{0x090400a8,0x7ae000c6,0xe8a80032,0x65bc0214}},	//   опен, únta, йбеҙ_, _yéhu, 
   {{0xdb14004a,0x3f9000e8,0x92c4037e,0x3ed400f2}},	//   _lozè, _yaxu_, niもi, _هویج_, 
   {{0x2c74014a,0xc7641c3e,0x00000000,0x00000000}},	//   mäd_, زاتى, --, --, 
   {{0x394ceec4,0xf64dba69,0x2c74014a,0x77001046}},	//   bags_, نئي_, läd_, وژمن, 
   {{0x35f40214,0x00000000,0x00000000,0x00000000}},	//   يريد_, --, --, --, 
   {{0x2c7429ef,0x61ec025c,0x27e00036,0xdcfc008e}},	//   näd_, _rjal, éins_, _yosı, 
   {{0x61ec1d1d,0x32000309,0x7e640309,0x945c00a2}},	//   _sjal, _akiy_, yujp, dyńd, 
   {{0x27fc05be,0xe2f90617,0x67281e31,0x3f90002e}},	//   movn_, сені_, _igdj, _raxu_, 
   {{0x2c740793,0x3f9000e8,0x27fc332e,0x00000000}},	//   käd_, _saxu_, lovn_, --, 
   {{0x80d807c1,0x4204009d,0xddc8031c,0x00000000}},	//   _पेशे, ймүү_, ħożi, --, 
   {{0x290400e4,0x572000db,0x7e640327,0x00000000}},	//   _myma_, _تۉۉك, tujp, --, 
   {{0x61ec1f60,0x6e95c4d6,0x80d83885,0x00000000}},	//   _tjal, миру, _पेरे, --, 
   {{0x63b9c4d7,0x61edc4d8,0x93f8002e,0x3f90a121}},	//   _hovn, _ujal, _j胃ng, _waxu_, 
   {{0x61fdc4d9,0x7e640218,0x2c74014a,0x3f900de2}},	// [32250] mosl, sujp, gäd_, _taxu_, 
   {{0x61fdc4da,0x7a300327,0x998c0166,0x236c0036}},	//   losl, _aħta, _bieş_, ngdj_, 
   {{0x20000227,0x29040784,0x394dc4db,0xa938063f}},	//   _ikhi_, _ayma_, tags_, _ịmụb, 
   {{0x61fdc4dc,0xbcf801f1,0x2c740793,0xfbdc015d}},	//   nosl, _dcér, bäd_, _gwên_, 
   {{0x2128089c,0x9aa526b1,0x394dc4dd,0x00000000}},	//   _mgah_, _کمزو, rags_, --, 
   {{0x29040cfd,0x61fc0306,0x394dc4de,0x63b9c4df}},	//   _dyma_, hosl, sags_, _novn, 
   {{0x212825a9,0x61fdc4e0,0xaa58f46d,0x290403b2}},	//   _ogah_, kosl, _миру_, _eyma_, 
   {{0x2129c4e1,0xf8ac00ec,0x7dd00064,0x00000000}},	//   _ngah_, _لکت_, _užsė, --, 
   {{0xd9440131,0x580440bb,0x80d80709,0x00000000}},	//   _меңи, _فورك, _पेले, --, 
   {{0x63b80218,0x212803b9,0x32000166,0xe738009b}},	//   _covn, _agah_, _skiy_, _међ_, 
   {{0x63bc0267,0x63b9c4e2,0x61fc06be,0x00000000}},	//   örna, _dovn, fosl, --, 
   {{0x20003223,0xbcf8072b,0x00000000,0x00000000}},	//   _akhi_, _idéf, --, --, 
   {{0xd9bc00bd,0x9344010b,0x00000000,0x00000000}},	//   _আগাম, _енле, --, --, 
   {{0x63b88185,0xb4c41b57,0xdbd80194,0x234800db}},	//   _govn, ईनी_, lææs, _ۇلۇپ_, 
   {{0x61fdc4e3,0xc330008f,0xbea1c4e4,0xc7b0010f}},	//   bosl, _אוו_, нарк, ײבן_, 
   {{0x61fdc4e5,0x63b80558,0x2000005a,0xc690010f}},	//   cosl, _zovn, _ekhi_, עאן_, 
   {{0xd1b80133,0x00000000,0x00000000,0x00000000}},	// [32260] _ناکا_, --, --, --, 
   {{0x2c740267,0x8d740101,0xd1b800ec,0xca7401ec}},	//   räd_, _کادا, _خاڪا_, зуды, 
   {{0x2904a737,0x2c74014a,0x09e5c4e6,0x00000000}},	//   _syma_, säd_, пожн, --, 
   {{0x2c74014a,0xf1cc1fe7,0x00000000,0x00000000}},	//   päd_, ासिन, --, --, 
   {{0x6d45c4e7,0xbcf801e1,0xfaec00aa,0x27fc0174}},	//   mbia, _adéf, نګې_, tovn_, 
   {{0x998c0598,0x6d45c4e8,0xf405c4e9,0x61fc23cc}},	//   _tieş_, lbia, _سؤ_, zosl, 
   {{0x63b9c4ea,0xf1cc0b7c,0xfa647c6c,0x6d440009}},	//   _rovn, ासान, _нарк_, obia, 
   {{0x6d45c4eb,0x63b9c4ec,0x0464e2b0,0xdb04045f}},	//   nbia, _sovn, птом, rkhô, 
   {{0x6d45c4ed,0x2904155d,0x7c380139,0x88c8010a}},	//   ibia, _uyma_, _çurt, _улав_, 
   {{0x6d4401ab,0x7dc0000d,0xdcec031c,0x00000000}},	//   hbia, _põsk, ndaġ, --, 
   {{0x63b80051,0xf1a80073,0x04fc00eb,0x00000000}},	//   _vovn, गांन, ুশের_, --, 
   {{0xc604009e,0x00000000,0x00000000,0x00000000}},	//   _লংকা_, --, --, --, 
   {{0x61fdc4ee,0x63b8009b,0x03a40b01,0x00000000}},	//   rosl, _tovn, _нидо, --, 
   {{0x61fc036b,0x6440017a,0x6fd00139,0x21280332}},	//   sosl, mpmi, _näcd, _wgah_, 
   {{0x644102f8,0xbcf80077,0xa19400db,0x00000000}},	//   lpmi, _acép, _жайч, --, 
   {{0xb8fc0135,0x6d44ef97,0x7c3c0334,0x717400d1}},	//   _སྟ_, gbia, tpqr, _كۇپا, 
   {{0x6ce4109a,0x2ed803d4,0x00000000,0x00000000}},	// [32270] ніфе, _দুআষ, --, --, 
   {{0x7ae00077,0xfbdc0042,0x6d44000d,0xfbd4012d}},	//   únto, _gwêl_, abia, णोंम, 
   {{0x6d45c4ef,0x00000000,0x00000000,0x00000000}},	//   bbia, --, --, --, 
   {{0xbcf800e8,0xd8f400f2,0x00000000,0x00000000}},	//   _ndég, وزشک, --, --, 
   {{0x315800c8,0xa9c40137,0x00000000,0x00000000}},	//   ליאן_, رۅكۉ, --, --, 
   {{0xbcf80248,0x38c000b0,0xa7e40131,0x67d5c4f0}},	//   _adég, _rīrā_, ىكنى, ночу, 
   {{0x7c2c0205,0xc68c0050,0x00000000,0x00000000}},	//   _hucr, لِو_, --, --, 
   {{0x7c2dc4f1,0x6e3801ed,0x34f000fd,0x00000000}},	//   _kucr, _évbe, нҗет, --, 
   {{0x7989c4f2,0xb4c45d9c,0x945c0210,0x00000000}},	//   megw, ईने_, dyńc, --, 
   {{0x7989c4f3,0x7c2c77a9,0xfa28031c,0xbcf803cd}},	//   legw, _mucr, _སྤོན_, _idéd, 
   {{0x7c2dc4f4,0x6d440368,0x644001f5,0x7c240240}},	//   _lucr, ybia, apmi, _mijr, 
   {{0x7c240113,0x79880368,0x38c000de,0x00000000}},	//   _lijr, negw, _tīrā_, --, 
   {{0xf508007b,0xdcfc0171,0xd3b800c0,0x00000000}},	//   _ازاى_, _masē, _мукі_, --, 
   {{0x7988073c,0x6d44015d,0x00000000,0x00000000}},	//   hegw, wbia, --, --, 
   {{0x7989c4f5,0x2ec83ee1,0x6d4404cc,0xa3440166}},	//   kegw, रनेत, tbia, _чэчл, 
   {{0xbcf801e1,0x6fd00166,0x00000000,0x00000000}},	//   _odéd, _säcd, --, --, 
   {{0x6d45c4f6,0xfce02850,0x7989c4f7,0x7c2c001e}},	// [32280] rbia, вото, degw, _cucr, 
   {{0x6d4407d5,0x7c2c06af,0xfb85a3a3,0x9b2c00cd}},	//   sbia, _ducr, мбук_, _kūṭā, 
   {{0xbcf9c4f8,0x7c2cd71f,0x752802d0,0x00000000}},	//   _adéd, _eucr, _oggz, --, 
   {{0xc8c87cbc,0x798800ca,0x7c2c003a,0xfc3c00ae}},	//   يوان_, gegw, _fucr, _bríd_, 
   {{0x89182099,0xb7d400e5,0x00000000,0x00000000}},	//   آغاز_, ڈونا_, --, --, 
   {{0xb7d41ec7,0x7c2400a2,0x945c0210,0x87241291}},	//   وونا_, _gijr, zyńc, وعثم, 
   {{0xc66802dd,0xfc00035b,0x7989c4f9,0x4a441cd0}},	//   ішке_, _рпро, begw, _інав, 
   {{0x7c2401a4,0xf8ac004b,0xfc3c00ae,0x00000000}},	//   _zijr, دکې_, _fríd_, --, 
   {{0x6fd00724,0x86c400ec,0x00000000,0x00000000}},	//   _mäcb, _ڪيان, --, --, 
   {{0xa3d8068f,0xd90c44e7,0x06b4009e,0x77800e92}},	//   ठों_, _ایه_, জনবি, _илуз, 
   {{0xbcf9c4fa,0x86c402dd,0x644002b9,0xb7d40131}},	//   _idée, _تيان, spmi, _تولا_, 
   {{0x7dc0007d,0x04442377,0x85541291,0x00000000}},	//   _tõsi, _жедн, _کیکر_, --, 
   {{0x29f83a4a,0xb5c47092,0x3618010f,0x00000000}},	//   mčad_, _زووم_, _וואד, --, 
   {{0x6601c4fb,0xf1a800bc,0x00000000,0x00000000}},	//   lomk, गाउन, --, --, 
   {{0x7c2401a4,0x82a402dd,0x00000000,0x00000000}},	//   _rijr, _ішке, --, --, 
   {{0x6601c4fc,0x29f807f5,0xb280084c,0x7c2dc4fd}},	//   nomk, nčad_, _рышк, _pucr, 
   {{0xdb0c3361,0xdfd0007b,0xda740092,0xdcfc00de}},	// [32290] şkün, _مية_, _ያውጡና_, _rasē, 
   {{0xfa28081f,0x66000009,0x9b940956,0xdcfc0171}},	//   _སྤུན_, homk, علات, _sasē, 
   {{0x66003e4c,0x7989c4fe,0xdcfc00e2,0x8e80010a}},	//   komk, tegw, _pasē, _йӳте, 
   {{0xfc3c00d0,0x00000000,0x00000000,0x00000000}},	//   _príd_, --, --, --, 
   {{0x7989c4ff,0x7c240309,0xfb8016f5,0x6d880014}},	//   regw, _tijr, _لگای, _زۅلہ_, 
   {{0x9695c500,0x6d400022,0x877000d1,0x6fd00139}},	//   ериш, _õmar, лғуш, _täce, 
   {{0x6b6801ed,0xdb15c501,0x00000000,0x00000000}},	//   ségü, _kozí, --, --, 
   {{0xfc3c0597,0x66000472,0xe98400f3,0x00000000}},	//   _tríd_, gomk, _ићун, --, 
   {{0x395c16b8,0x14241955,0xdcfc0100,0xfc3c0419}},	//   _idus_, ндим, _obsč, _hríb_, 
   {{0x02c80cf1,0xe7780022,0x00000000,0x00000000}},	//   ानून, _ҽаӡә_, --, --, 
   {{0x6600c478,0x13082e70,0xe7acdaf5,0x00000000}},	//   bomk, яной_, चारप, --, 
   {{0x7640020b,0xfc3c0248,0x00000000,0x00000000}},	//   mpny, _otí_, --, --, 
   {{0x2ec82f2e,0xfc3c01e1,0xdb0403b2,0xa4440064}},	//   रन्त, _ntí_, gjhú, _анід, 
   {{0xd0110666,0xe3b01272,0x63a40c09,0x3cf0012d}},	//   الس_, _پره_, _ɗink, ंपने_, 
   {{0xfc3dc502,0x91e4487f,0x395c00ef,0x8ec40066}},	//   _atí_, _поке, _odus_, رآسم, 
   {{0xd17409a5,0xd90400ec,0x00000000,0x00000000}},	//   _чыкы, _نڌ_, --, --, 
   {{0xbcf80ca8,0x8fa453ef,0xfc3c013a,0x00000000}},	// [322a0] _adéb, _запе, _ctí_, --, 
   {{0xfc3c0491,0x395dc503,0x66005d53,0x00000000}},	//   _dtí_, _adus_, zomk, --, 
   {{0x66007f87,0x41b02756,0xfc3c0ca8,0x4a442bb6}},	//   yomk, _شمیر, _etí_, хнев, 
   {{0xfc3c02d2,0xd5b00208,0x0d2000db,0x00000000}},	//   _ftí_, _túy_, _бүбү, --, 
   {{0xe8944834,0x2d800134,0x88d8035b,0x00000000}},	//   таль, mfie_, џьет_, --, 
   {{0x2d81c504,0x6600016b,0xdcac00cf,0x3ce802f0}},	//   lfie_, womk, _بۉك_, šivá_, 
   {{0xd90c00dd,0x66000c5e,0x3685754a,0x04b40014}},	//   میہ_, tomk, есын_, کھاں_, 
   {{0x2d81c505,0x36300f3e,0x3160009a,0x67380841}},	//   nfie_, دروس, _ndiz_, scvj, 
   {{0x2ca0147b,0x29f800f3,0x99740b7e,0xc3e001e0}},	//   nvid_, rčad_, _шурш, лөкһ, 
   {{0x6601c506,0x3160022e,0x2ca000c5,0x395c0010}},	//   somk, _adiz_, ivid_, _zdus_, 
   {{0x2ca000af,0x66014df7,0xf7700a1e,0xe1d40212}},	//   hvid_, pomk, _תקע_, вжнь, 
   {{0xab6403ee,0x6ec4190c,0x00000000,0x00000000}},	//   ldüğ, रहनु, --, --, 
   {{0x2ca00d45,0x7f5c02d3,0x705800ee,0xdb14022a}},	//   jvid_, _ንምፍጣ, наяр_, _rozí, 
   {{0x2ca0049f,0x3161c507,0x200401f1,0xab6403ee}},	//   dvid_, _ediz_, ôli_, ndüğ, 
   {{0x2d81c508,0xdb1456b1,0x2f18084c,0xd3340006}},	//   ffie_, _pozí, еорь_, _рэчы, 
   {{0x32500c04,0xfcec01f3,0x22580419,0x00000000}},	//   _свър, _ቁልጭ_, árku_, --, 
   {{0xdb140232,0xacf9c509,0xd1e40150,0x48d00154}},	// [322b0] _vozí, енту_, _جييۋ, ়পুর, 
   {{0x6b7401c6,0xab74004e,0x7e280064,0x00000000}},	//   ллуу, лгуш, _німа_, --, 
   {{0xba284418,0x2ca0000d,0xef14004e,0x00000000}},	//   سسام_, avid_, _бүрө, --, 
   {{0xaa446788,0x63bc01e3,0x00000000,0x00000000}},	//   اننى, örnj, --, --, 
   {{0x2ca00205,0xd30c03ce,0x7eb8013d,0x00000000}},	//   cvid_, _हर्ब_, bäpç, --, 
   {{0xfbdc000f,0x69d80129,0x7dc0000d,0xac240395}},	//   _stêf_, èver, _võsu, _бфск, 
   {{0xbadc0183,0xe3b80166,0x00000000,0x00000000}},	//   _বুৰঞ, djı_, --, --, 
   {{0x395dc50a,0x00000000,0x00000000,0x00000000}},	//   _udus_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd759c50b,0x7999c50c,0x76406b4e,0xe4c800c6}},	//   _آلات_, _hauw, ppny, عبين_, 
   {{0x7999c50d,0x2d800ea0,0x6fd00139,0x2ca00427}},	//   _kauw, yfie_, _näca, zvid_, 
   {{0xc6900375,0xc6b40677,0x2ca1c50e,0x00000000}},	//   _כאב_, _בלעז_, yvid_, --, 
   {{0x7999c50f,0x7dc00254,0xc9500375,0x2ca00175}},	//   _mauw, _lõss, סמך_, xvid_, 
   {{0x7999c510,0x00000000,0x00000000,0x00000000}},	//   _lauw, --, --, --, 
   {{0x79980086,0x52740276,0xdcfc0064,0xff04ec3f}},	//   _oauw, _рулу, _kasė, верк_, 
   {{0x7999c511,0x2d80017a,0x741000ec,0xc0f40092}},	//   _nauw, ufie_, _جوڙا, _ለጋሽ_, 
   {{0xdcfc0024,0x00000000,0x00000000,0x00000000}},	// [322c0] _masė, --, --, --, 
   {{0x80d81d8a,0x2ca1c512,0x205400a7,0xbf6001d9}},	//   _पेटे, rvid_, _стър, _پۯٲو, 
   {{0x7999c513,0x81f5c514,0x09c800cc,0xab640205}},	//   _bauw, _سفیر_, লোফা, vdüğ, 
   {{0x799801f5,0x2d9c00e2,0x161003ce,0x00000000}},	//   _cauw, ēves_, _डीलर_, --, 
   {{0x7999c515,0x8c4400d8,0x63bc007c,0x00000000}},	//   _dauw, _јеге, örnk, --, 
   {{0x799808e7,0x7a30031c,0xbb4000d8,0x0b580166}},	//   _eauw, _oħth, _верк, _юрмы_, 
   {{0xbcf9c516,0x7dc0007d,0xab6403ee,0xfc3c09c2}},	//   _idéa, _tõst, rdüğ, _iría_, 
   {{0x6b9dc517,0x79980428,0x7538014b,0x2d840166}},	//   _harg, _gauw, gcuz, _ömed_, 
   {{0x6b9dc518,0x69c1c519,0x02c81a3e,0xfc3c02d2}},	//   _karg, _iome, ान्न, _kría_, 
   {{0x6b9dc51a,0x69c1c51b,0x79980034,0x29f800f3}},	//   _jarg, _home, _zauw, bčac_, 
   {{0x6b9dc51c,0xfc3c0083,0xdb141a24,0x7999791b}},	//   _marg, _mría_, _kozá, _yauw, 
   {{0x6b9dc51d,0x80d80011,0x00000000,0x00000000}},	//   _larg, _যুগ্, --, --, 
   {{0xdb1425e6,0x6b9c0b21,0xbcf80109,0xf99000d9}},	//   _mozá, _oarg, _odéa, ברר_, 
   {{0x6b9c0978,0x69c1c51e,0xbcf80597,0x02a4225f}},	//   _narg, _lome, _ndéa, _арим, 
   {{0x69c1c51f,0xc0b802d3,0x3a3c009b,0xdcec0010}},	//   _oome, _ዳግመ_, _čupo_, rgač, 
   {{0x6b9dc520,0x62986785,0xbcf80332,0xfc3c02d2}},	//   _aarg, _isvo, _adéa, _aría_, 
   {{0x7999c521,0x9d14399b,0x6b9c1382,0x7c6401b9}},	// [322d0] _rauw, удач, _barg, ضاءل, 
   {{0x69c00099,0xfc3c2b76,0x69d801a4,0x7dc00254}},	//   _aome, _cría_, ëven, _põss, 
   {{0x6b9dc522,0x7999c523,0xdd5801f0,0x9af00051}},	//   _darg, _pauw, _панч_, _bazơ_, 
   {{0xfbdc0a85,0x6b9dc524,0xceb0010f,0x7dc00254}},	//   _stêd_, _earg, _היט_, _võss, 
   {{0x6b9dc525,0xfc3dc526,0x69c1c527,0x186824db}},	//   _farg, _fría_, _dome, хали_, 
   {{0x6b9dc528,0x799924c8,0x69c0035a,0xf0940a7c}},	//   _garg, _wauw, _eome, שנס_, 
   {{0x69c1c529,0x7999c52a,0x98bc00b0,0xdcfc0024}},	//   _fome, _tauw, tawē_, _pasė, 
   {{0x69c1c52b,0x6b9c3142,0x09c800bd,0xe6c40116}},	//   _gome, _zarg, লোবা, شتىي, 
   {{0x75380395,0x6b9dc52c,0x6298022e,0x29dc01e4}},	//   rcuz, _yarg, _asvo, aŭas_, 
   {{0xf771c52d,0x69c1c52e,0x6b9dc52f,0xf6e40022}},	//   _خار_, _zome, _xarg, _ицен, 
   {{0x69c1c530,0x8fa401a9,0x00000000,0x00000000}},	//   _yome, қаве, --, --, 
   {{0xcb100375,0xc6d8008f,0x504401a9,0x69c00bb9}},	//   מלי_, _אַדר, лемб, _xome, 
   {{0x6299c531,0xe3b80205,0xa4d40153,0x00000000}},	//   _esvo, mmın_, _коці, --, 
   {{0x9f50007f,0x41b00150,0x68e401e7,0xe3b80166}},	//   nnzè_, _ۇمىر, úidi, lmın_, 
   {{0x6b9c0142,0xd0080166,0x00000000,0x00000000}},	//   _rarg, _җене_, --, --, 
   {{0xd1b80a11,0x7bc00112,0x80c801ad,0xb7ac00eb}},	//   _سابا_, önun, हनखे, _কতোট, 
   {{0x69c1c532,0x6b9dc533,0xdb15c534,0x00000000}},	// [322e0] _rome, _parg, _rozá, --, 
   {{0x69c1c535,0x6b9c406c,0x00000000,0x00000000}},	//   _some, _qarg, --, --, 
   {{0x69c054b0,0xc3300302,0x63bcee5c,0x3ab04a92}},	//   _pome, צוא_, örni, бәтт, 
   {{0x6b9dc536,0x69c1c537,0x629c003a,0x00000000}},	//   _warg, _qome, æroi, --, 
   {{0x6b9dc538,0x69c06f89,0xaa44104b,0xdb1402f0}},	//   _targ, _vome, انچى, _vozá, 
   {{0x69c1c539,0x9cb000cf,0x6b9c035a,0x60d800a2}},	//   _wome, _بۅكت, _uarg, _üwme, 
   {{0x22400841,0x00000000,0x00000000,0x00000000}},	//   _čiko_, --, --, --, 
   {{0xa535c53a,0x69c00393,0x00000000,0x00000000}},	//   шнич, _uome, --, --, 
   {{0x08d40006,0x00000000,0x00000000,0x00000000}},	//   _сцвя, --, --, --, 
   {{0xbcf80098,0xfc3c0248,0xe3b82ca8,0x00000000}},	//   _odén, _orín_, amın_, --, 
   {{0x05840348,0x8644c34a,0xbcf81aac,0x21b40a89}},	//   _булм, _снеж, _ndén, айня, 
   {{0xd5b801ec,0x00000000,0x00000000,0x00000000}},	//   _исі_, --, --, --, 
   {{0xbcf9c53b,0xc0a8007b,0x00000000,0x00000000}},	//   _adén, راحل_, --, --, 
   {{0x26dc0810,0x00000000,0x00000000,0x00000000}},	//   ozvo_, --, --, --, 
   {{0x62980bb8,0x442d1111,0x26dc006f,0x99e400a2}},	//   _usvo, _iif_, nzvo_, _hiňň, 
   {{0x26dc0e8a,0x442dc53c,0x69d80ea0,0x724001c8}},	//   izvo_, _hif_, ëvel, _اپيل, 
   {{0x442c1f21,0xfc3c01e1,0xbcf801d3,0x4084004e}},	// [322f0] _kif_, _erín_, _edén, _суйб, 
   {{0x442c2af2,0xdec40022,0xe7a40709,0x00000000}},	//   _jif_, _кәбо, _गोलप, --, 
   {{0xfaa5c53d,0xdea00ec9,0xfd1c0248,0xfc3c01a8}},	//   ышан, _بیزی, _gbìn_, _grín_, 
   {{0x442dc53e,0xd87400cf,0xdd90007b,0x7bd401d5}},	//   _lif_, لاتب, _بوح_, shxu, 
   {{0x442dc53f,0xbcf9c49a,0x32d80ca8,0xdcfc00e2}},	//   _oif_, _idéo, _káyé_, _masī, 
   {{0xdcfc0029,0x7a5440c8,0x442dc540,0x00000000}},	//   _lasī, _مضرا, _nif_, --, 
   {{0x63a40198,0x6e2c01bf,0xa56400d1,0x19940153}},	//   _ɗint, _ålbæ, ڭدىن, _кавя, 
   {{0x442dc541,0xb865c542,0x32d80cad,0x29f80419}},	//   _aif_, _مائو, _láyé_, lčan_, 
   {{0x442dc543,0x1ae40166,0x60dc00e5,0x00000000}},	//   _bif_, _соңм, jzsm, --, 
   {{0x442dc544,0x07a00014,0x7d0c3690,0x60dc01d3}},	//   _cif_, _وۅنُ, _mycs, dzsm, 
   {{0x6b6001ed,0xbcf80129,0x00000000,0x00000000}},	//   lágí, _odéo, --, --, 
   {{0x442c0327,0x6fd001b8,0x10a507e2,0x21f80022}},	//   _eif_, _päco, аимн, tĩha_, 
   {{0x32d80ca8,0x442d2cfa,0x20d4177b,0x746802e8}},	//   _báyé_, _fif_, бірс, _чрев_, 
   {{0x442c8c75,0xbcf80248,0x7bc001b8,0xe45000ec}},	//   _gif_, _adéo, önul, _رضه_, 
   {{0x32d80ca8,0xe2a8ef7f,0xdcec05d1,0x7f5401a9}},	//   _dáyé_, _ماين_, tfağ, _dexq, 
   {{0x442c29ef,0xfc3c0789,0x3f600166,0x20100165}},	//   _zif_, _crío_, _açuı_, alzi_, 
   {{0x32d80248,0x8fd000d1,0x61fc00e5,0xb22400ec}},	// [32300] _fáyé_, _дәвә, érle, _پڙھي, 
   {{0x3cec0579,0xfc3c0332,0x6da400d1,0x442c0139}},	//   úgva_, _trín_, шиға, _xif_, 
   {{0xfc3c09ff,0xfbdc0142,0x00000000,0x00000000}},	//   _frío_, _stêc_, --, --, 
   {{0x6fd00139,0xc83c0023,0x88c800d8,0x19a80150}},	//   _mäcm, _ክሰርሕ, клев_, лтіп_, 
   {{0x26dc0810,0x87e401e0,0x00000000,0x00000000}},	//   wzvo_, аһаң_, --, --, 
   {{0x63a40198,0x6e25c545,0x184801ed,0x2e3c06ea}},	//   _ɗins, lmib, اؤنٹ_, _kíf_, 
   {{0x442dc546,0x6fd0008e,0x00000000,0x00000000}},	//   _rif_, _näcm, --, --, 
   {{0x442dc547,0x6e2401ab,0x00000000,0x00000000}},	//   _sif_, nmib, --, --, 
   {{0x2e3c008c,0x2b580156,0x6e2404ba,0x2338004e}},	//   _líf_, _kerc_, imib, лппы_, 
   {{0x03c5c548,0x2b5800cf,0x442c32aa,0x6e3c0175}},	//   рсим, _jerc_, _qif_, kqrb, 
   {{0xbcf85b7b,0x2b580dd4,0xa159c549,0x29f808a4}},	//   _adél, _merc_, лану_, nčao_, 
   {{0x2b5803bd,0x442dc54a,0x7f543beb,0x32d80248}},	//   _lerc_, _wif_, _sexq, _sáyé_, 
   {{0xf2840323,0xd62414a0,0x40840137,0xdcfc6991}},	//   гөөд_, _اعلي, шунб, _vasī, 
   {{0x442dc54b,0x6e24009a,0xfeb80133,0x65bc0129}},	//   _uif_, emib, پاست_, _réhy, 
   {{0x63bc0008,0xa2440137,0x29f83858,0xdcfc0171}},	//   örnu, _ارتۇ, včan_, _tasī, 
   {{0x32d8110e,0xcf8c01e2,0x00000000,0x00000000}},	//   _wáyé_, وژۍ_, --, --, 
   {{0x2b580156,0xdd940032,0xe0d00014,0xfc3c0332}},	// [32310] _berc_, _һаны, _رٲد_, _gríl_, 
   {{0x3ce80574,0xfaa534b0,0x2b580311,0x2e3c0174}},	//   _घेणे_, ишен, _cerc_, _fíf_, 
   {{0xfc3c2d86,0x2b580489,0xbcf80b1a,0x29f80427}},	//   _trío_, _derc_, _idém, rčan_, 
   {{0xf990034c,0x6ec4012c,0x19580150,0x00000000}},	//   تبط_, रहरु, уады_, --, 
   {{0x18a5c54c,0xaf082ab4,0x2b58030a,0x29f80960}},	//   салм, _مقیم_, _ferc_, pčan_, 
   {{0xba75c54d,0x2b580156,0x7ae0002d,0x9f5001d3}},	//   _پاست, _gerc_, únts, mozó_, 
   {{0xed9002d3,0x6b6001d3,0x3ce80073,0x68f003b9}},	//   _ምኽባር_, ságí, _घेते_, _əjdə, 
   {{0x29f809a8,0x2b580156,0xeef8011a,0x00000000}},	//   nčal_, _zerc_, ימור_, --, 
   {{0x2b580165,0xd1740032,0xb6a001b9,0x00000000}},	//   _yerc_, ҙыны, сиқл, --, 
   {{0x3cfc068f,0xe3b80166,0x00000000,0x00000000}},	//   _रखने_, lmıj_, --, --, 
   {{0x11d40597,0x67440139,0x00000000,0x00000000}},	//   متحد, _фэуз, --, --, 
   {{0xbcf80241,0xf1c804a9,0x249c00fd,0x63041617}},	//   _adém, рқий_, äzmä_, توپل, 
   {{0x53a5c54e,0x544400f7,0xd4695d25,0x2e3c68f1}},	//   _галб, _انتك, _силе_, _síf_, 
   {{0x9f5000e5,0x63bc007c,0x00000000,0x00000000}},	//   dozó_, örnt, --, --, 
   {{0x6fd05df4,0x2b580113,0xc3300677,0x00000000}},	//   _häck, _rerc_, _צוה_, --, 
   {{0x2b59c54f,0x2e3c022c,0x6e241418,0x6fd0007c}},	//   _serc_, _víf_, umib, _käck, 
   {{0x2b59c550,0x4b880209,0x6fd0002f,0x9db80166}},	// [32320] _perc_, лйан_, _jäck, шыру_, 
   {{0xfc3c0413,0x0e6400c7,0x3bcc0139,0x6e2488e9}},	//   _grím_, _лкон, _nıqı_, smib, 
   {{0x4e18bbcc,0x6fd0049f,0x2b580489,0x2e3c03b2}},	//   _متحد_, _läck, _verc_, _uíf_, 
   {{0x29f8110c,0x2b580489,0xe9740136,0xd90c00e5}},	//   rčao_, _werc_, تۇرد, چیف_, 
   {{0xc7c530b0,0xd90c1037,0x2b59c551,0x6fd001e3}},	//   йски, نیف_, _terc_, _näck, 
   {{0xaab4168d,0x29f801fa,0x00000000,0x00000000}},	//   _وڵات, pčao_, --, --, 
   {{0x3bcc06be,0xc6a401d5,0x00000000,0x00000000}},	//   _dıqı_, срли, --, --, 
   {{0x6fd00d11,0xd6d85566,0x9f50007f,0x00000000}},	//   _bäck, шті_, nozò_, --, 
   {{0xbcf801e1,0x70b4012c,0x29f80010,0x00000000}},	//   _adéj, ुहोल, nčam_, --, 
   {{0x6fd001e6,0x73d4969b,0x7bd8010f,0x00000000}},	//   _däck, йдыр_, ָקטו, --, 
   {{0x582800c7,0xc8480023,0x03a800f2,0x00000000}},	//   _тефҭ_, _ዝተሃን, ندگو_, --, 
   {{0x6fd14e78,0x75d00228,0x09c800eb,0x00000000}},	//   _häch, _ىيلا, লোরা, --, 
   {{0xdb14025a,0x63bdc552,0x6fd03bb8,0xc5141fb8}},	//   _bozû, örns, _käch, _ابات, 
   {{0x3fe40f22,0x657401d3,0x00000000,0x00000000}},	//   পক্ষ, _ایکڑ_, --, --, 
   {{0x6fd1c553,0xde580816,0x41e40153,0x00000000}},	//   _mäch, рабі_, _гіпа, --, 
   {{0x6fd01a80,0x3ebc107d,0xa9f400bc,0xaaac09ab}},	//   _läch, ćut_, ेकोछ_, घटनक, 
   {{0x71f9695b,0xbcf8005c,0xdcb801d5,0x32d40133}},	// [32330] _دروس_, _idék, шгач_, _نگێک_, 
   {{0x6fd05651,0x9f5001ed,0x00000000,0x00000000}},	//   _näch, rozó_, --, --, 
   {{0x3ea40036,0xfc3c00d7,0x00000000,0x00000000}},	//   _ént_, _krík_, --, --, 
   {{0xd83806c8,0xaa3802d3,0xaa58009b,0x9f5000e5}},	//   _puō_, _ብኣምላ, сицу_, pozó_, 
   {{0xd838003a,0x6fd00b70,0x00000000,0x00000000}},	//   _quō_, _bäch, --, --, 
   {{0x6fd004f3,0x263c01e4,0xd6a800c6,0xab84ec38}},	//   _räck, _iĉoj_, لدعم_, _нуск, 
   {{0x6fd06ed3,0xfc3c0248,0x8c18011a,0x00000000}},	//   _säck, _orík_, _כושי, --, 
   {{0x59f8049b,0xbcf8f04d,0x1c1c007d,0x6fd00e78}},	//   _тебя_, _ndék, _बीतल_, _päck, 
   {{0x7bc5c554,0x27e00421,0x6fd00ade,0x00000000}},	//   _koju, ūina_, _fäch, --, 
   {{0xd2640cca,0x649806bb,0xbcf80ca8,0x6fd0049f}},	//   окой, стър_, _adék, _väck, 
   {{0x27e023db,0x59dc00af,0x7bc5c555,0x00000000}},	//   ɗin_, _मतार, _moju, --, 
   {{0x7bc5c556,0x6fd0049f,0x25c80118,0x50b401f0}},	//   _loju, _täck, ětlá_, осгу, 
   {{0xc1e401d5,0x419400f2,0x00000000,0x00000000}},	//   تکول_, آشپز, --, --, 
   {{0xbcf81347,0xb4c400af,0x349000d1,0xce4800f7}},	//   _idéh, ैनी_, _маҗр, изге_, 
   {{0x3ea1c557,0x8d581d0f,0xfc3c02d2,0x161c353b}},	//   мирг, ишат_, _frík_, _पठार_, 
   {{0x4d49c558,0x7bc40428,0x6fd0008e,0x28cc00cd}},	//   рпан_, _aoju, _mäci, ऽहमि, 
   {{0x7bc5c559,0x38c000e2,0x22400064,0x00000000}},	// [32340] _boju, _jūrā_, _čiki_, --, 
   {{0x0d7401ed,0xcb69c55a,0x40909c1d,0x7b843769}},	//   _ڈیسک_, раже_, _کلیر, قامە, 
   {{0x7bc40248,0x6fd0fbf7,0x82d4010f,0x00000000}},	//   _doju, _räch, ֿונג_, --, 
   {{0x6fd1c55b,0x29f801a6,0x00000000,0x00000000}},	//   _säch, pčam_, --, --, 
   {{0x7bc40241,0x29001762,0x6fd00112,0x6d443f05}},	//   _foju, çia_, _päch, mcia, 
   {{0x6d45c55c,0x4669c55d,0x3cfc0034,0x7bc4b91a}},	//   lcia, арим_, _रखते_, _goju, 
   {{0xd90c00dd,0x6fd004cc,0x9f9c01e1,0x29f80010}},	//   نیہ_, _cäci, _dìè_, nčak_, 
   {{0x6d458ac1,0x26c00b91,0x7bc40196,0x6fd003fa}},	//   ncia, ćio_, _zoju, _wäch, 
   {{0x6d45c55e,0x00000000,0x00000000,0x00000000}},	//   icia, --, --, --, 
   {{0x6fd00139,0x38c00055,0xdb1402f0,0x00000000}},	//   _fäci, _dūrā_, _rozú, --, 
   {{0x6d446f10,0x29f800f3,0x6fd000fd,0xe214013d}},	//   kcia, jčak_, _gäci, змны, 
   {{0xf1b00451,0x6d45c55f,0xba980677,0x00000000}},	//   نءُ_, jcia, בסטי, --, 
   {{0x65600810,0x44f40214,0x9f3402dd,0x6d447881}},	//   mamh, _بساز, зегі, dcia, 
   {{0x6d45c560,0x6561c561,0x7411c562,0x802400c6}},	//   ecia, lamh, _قونا, ترجم, 
   {{0x7bc43395,0xbcf80261,0x2440004d,0xf8b42ce6}},	//   _roju, _idéi, _hòm_, _आप्प, 
   {{0x24400d29,0x6561c563,0x7bc5c564,0x6d440064}},	//   _kòm_, namh, _soju, gcia, 
   {{0x5c756d4a,0xc33c0023,0x72049fbb,0x00000000}},	// [32350] ялат, _ተሓንጊ, _تويم, --, 
   {{0x65600428,0x6d44012d,0x29f80064,0xbcf800e5}},	//   hamh, acia, bčak_, _leég, 
   {{0xdd918510,0x5a340abe,0xef140372,0x61ec151c}},	//   _كود_, чнет, _жүрө, _kmal, 
   {{0x6d444ef6,0x6fd00139,0x00000000,0x00000000}},	//   ccia, _räci, --, --, 
   {{0x6561c565,0x24406f90,0xfc3c0241,0x3a3c00ef}},	//   damh, _nòm_, _oríi_, _čupu_, 
   {{0xdec8001f,0x67d428e8,0xbcf99bcd,0xc17c00c0}},	//   _አሜን_, мочу, _ndéi, _šėlo_, 
   {{0x61edc566,0x1a6402f2,0x00000000,0x00000000}},	//   _omal, _ریشی_, --, --, 
   {{0x6561c567,0x95990edd,0xe708004b,0x063010f3}},	//   gamh, стку_, غتون_, нејџ, 
   {{0x130805f5,0xbcf8002e,0x24400208,0xaefc00cc}},	//   өний_, _deég, _còm_, _ইৰাণ_, 
   {{0x61edc568,0x6d444baa,0xbcf801e1,0x24400208}},	//   _amal, zcia, _eeég, _dòm_, 
   {{0x656048b5,0xe4c804fb,0x6d443f05,0x56941171}},	//   bamh, مبین_, ycia, _хает, 
   {{0x24400699,0x9f5007c5,0x29f8107d,0x656008c2}},	//   _fòm_, enzà_, včak_, camh, 
   {{0x2440007f,0x6d440030,0xfc3c09e8,0x6ab807f7}},	//   _gòm_, vcia, _fríi_, _इप्र, 
   {{0x61edc569,0xa3a80014,0x60c80037,0x6d4437b0}},	//   _emal, _وُنل_, äema, wcia, 
   {{0xaca402e3,0x9f980008,0x2440007f,0x00000000}},	//   _mpụt, ráðu_, _zòm_, --, 
   {{0x29f80841,0x6d44003a,0x4f8401d9,0xc0dc0023}},	//   rčak_, ucia, _کٔدل, _ሓውሲ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [32360] --, --, --, --, 
   {{0x6d444ef6,0xdee80201,0x65615323,0xdcec00a2}},	//   scia, _መልኩ_, zamh, gdaı, 
   {{0x6d44180f,0x6560209c,0xdb04034c,0xdcec0327}},	//   pcia, yamh, ndhè, reaġ, 
   {{0xaca40521,0x79a05aa2,0x61ec0165,0x8d740046}},	//   _apụt, ерше, _xmal, _عاجا, 
   {{0x6560004c,0x644000b5,0x41800150,0xf98400ae}},	//   vamh, xqmi, _ﯨﺰﮔﯩ, سنوي_, 
   {{0x2441c56a,0xbcf80ca8,0xdb04020c,0x6561c56b}},	//   _ròm_, _adéw, kdhè, wamh, 
   {{0x6560009f,0x244002bd,0xdb4c02f2,0x00000000}},	//   tamh, _sòm_, _ئێم_, --, 
   {{0x66040030,0x244002e2,0x6128022e,0x00000000}},	//   čiko, _pòm_, hоla, --, 
   {{0x61edc56c,0x6561c56d,0x29f80010,0x473404f2}},	//   _rmal, ramh, včah_, _فراز, 
   {{0x46a49702,0x6561c56e,0x61edc56f,0x2440004d}},	//   _назв, samh, _smal, _vòm_, 
   {{0x6560006f,0xdb04020c,0x2440033b,0x32600395}},	//   pamh, gdhè, _wòm_, нтяв, 
   {{0x2441abf0,0x00000000,0x00000000,0x00000000}},	//   _tòm_, --, --, --, 
   {{0xdfd010fe,0xfbdc015d,0xdb040200,0x00000000}},	//   نيح_, _stêm_, tdhë, --, 
   {{0xdee80020,0x7a2000c5,0xe5080451,0x64a40166}},	//   _መልክ_, mõte, _ٿيڻو_, _наҗа, 
   {{0x61edc570,0xdb0402d3,0x9f500023,0xc8800356}},	//   _tmal, rdhë, lizë_, luşă_, 
   {{0x61edc571,0xdb040200,0xdd940022,0x00000000}},	//   _umal, sdhë, ьабы, --, 
   {{0x6289c572,0xac9402dd,0xc880054e,0x61fc007c}},	// [32370] ltdo, натш, nuşă_, mnsl, 
   {{0xad246923,0x1b20015b,0x6288017a,0x23dc00cd}},	//   رىلى, _বলবে_, otdo, यसिद, 
   {{0x61fdc573,0xbcf8035b,0xdcfc0171,0x9f500200}},	//   onsl, _ndév, _basģ, hizë_, 
   {{0x61fd6a26,0x23c80316,0x62880295,0x225802fb}},	//   nnsl, ाउँद, itdo, árky_, 
   {{0x6289c574,0x61fdc575,0x17c80b7e,0x5fd04ed3}},	//   htdo, insl, жгли_, _सकाल, 
   {{0xd7c9c576,0x945c033f,0xdb0400ae,0x62883453}},	//   توته_, zyńs, hdhé, ktdo, 
   {{0xeaa00882,0x7e6403cd,0x47d000db,0x998401ee}},	//   reṣu_, nsjp, ئيىر, _отаһ, 
   {{0x63b8007f,0x27fc0208,0x61fdc577,0x00000000}},	//   _anvn, anvn_, jnsl, --, 
   {{0x395c05d5,0x62880ea0,0xc4800166,0x17a0014b}},	//   _ieus_, etdo, влык, _ақлҳ, 
   {{0x61fdc578,0x395dc579,0xfc3c0093,0x2e3401e1}},	//   ensl, _heus_, _muí_, _kúfì_, 
   {{0x7761c57a,0x395c0196,0xfc3c00c6,0xbcf801bf}},	//   manx, _keus_, _luí_, _idéu, 
   {{0x7761526f,0x76400007,0x61fd419b,0x9f500100}},	//   lanx, mqny, gnsl, lizè_, 
   {{0x395dc57b,0x20b40c98,0x628801b9,0x63a80175}},	//   _meus_, нёрс, atdo, bddn, 
   {{0x395c022f,0x61fc0373,0xe82033af,0x77600472}},	//   _leus_, ansl, यतया_, nanx, 
   {{0x628801a4,0x4390399f,0x741000f2,0x00000000}},	//   ctdo, _рајс, _قوچا, --, 
   {{0x395dc57c,0x9f500ffb,0xfc3c007b,0x9f9c01e1}},	//   _neus_, hizè_, _buí_, _hìì_, 
   {{0x77600bc9,0xfc3c00c6,0xe820197e,0x00000000}},	// [32380] kanx, _cuí_, यतमा_, --, 
   {{0x77600227,0x316035ca,0x0eb82f6a,0x00000000}},	//   janx, _heiz_, _думы_, --, 
   {{0x395dc57d,0x776000db,0xf3fc00fe,0xa8600241}},	//   _beus_, danx, _উঠাৰ_, _ẹ̀kú_, 
   {{0xbcf8004e,0x395c01ab,0xfc3c0407,0x00000000}},	//   _adéu, _ceus_, _fuí_, --, 
   {{0x395dc57e,0x316005c7,0xfc3c00ae,0xe8480092}},	//   _deus_, _meiz_, _guí_, _ሚዲያዎ, 
   {{0x7760b68e,0x7a2000af,0x2d809c45,0x3160030a}},	//   ganx, võte, lgie_, _leiz_, 
   {{0x69d8044e,0x61fdc57f,0x62889b61,0x76400007}},	//   ëves, ynsl, xtdo, gqny, 
   {{0x395d29df,0x2d81c580,0x69d8005f,0x63a80142}},	//   _geus_, ngie_, īves, wddn, 
   {{0x776127b7,0xfc3c1427,0x38c00024,0x211c2356}},	//   banx, _fríu_, gūrą_, _नरेश_, 
   {{0x1b2000bd,0x3cec022c,0x77600077,0x9f500240}},	//   _বলতে_, úgvi_, canx, rizë_, 
   {{0x395c0810,0xdcfc031c,0x2ca0031c,0x0584004e}},	//   _yeus_, _masġ, hwid_, _жулм, 
   {{0xb6f40075,0x31600007,0x628801b9,0x22ac012c}},	//   _تىما_, _ceiz_, rtdo, _věk_, 
   {{0x316007e4,0x2d81c581,0x2ca02948,0x62884d57}},	//   _deiz_, dgie_, jwid_, stdo, 
   {{0x2d80017a,0x2ca00042,0xf4840133,0x41ac000d}},	//   egie_, dwid_, _زاهی, _जोरस, 
   {{0xdb15c582,0x3161c583,0xfc3c007b,0xa19436ca}},	//   _anzî, _feiz_, _suí_, _зайч, 
   {{0x2d81c584,0x31600007,0xdb1401c7,0x00000000}},	//   ggie_, _geiz_, _unzé, --, 
   {{0x395dc585,0xfc3dc586,0x77600117,0xa5480092}},	// [32390] _reus_, _quí_, yanx, _ያጠናቀ, 
   {{0x395dc587,0x77600921,0x316005c7,0x3014035b}},	//   _seus_, xanx, _zeiz_, _идыр, 
   {{0x395dc588,0xbcf80ca8,0x0f54011a,0x9f50033b}},	//   _peus_, _adét, _איתם_, vizè_, 
   {{0x77600b6f,0xfc3dc589,0xdb1400a2,0x9f9c0241}},	//   wanx, _tuí_, _gozý, _mìí_, 
   {{0x7b65c58a,0x395c00f7,0x77600bc9,0xad140022}},	//   _отве, _veus_, tanx, _аҿтә, 
   {{0x2011c58b,0x395c0036,0x69d8017a,0x00000000}},	//   nozi_, _weus_, ëver, --, 
   {{0x395dc58c,0x7760eb64,0x76400007,0x9f9c0248}},	//   _teus_, ranx, uqny, _nìí_, 
   {{0x2011c58d,0xd5b01f3c,0x77600054,0x38c00024}},	//   hozi_, افظ_, sanx, tūrą_, 
   {{0x20109d20,0x77600bc9,0x3161c58e,0xfc3c0ca8}},	//   kozi_, panx, _reiz_, _irís_, 
   {{0x3161c58f,0x9f9c01e1,0x201001fe,0x7761c590}},	//   _seiz_, _bìí_, jozi_, qanx, 
   {{0x2011c591,0xd5740139,0xb8180034,0xd6d0007b}},	//   dozi_, _зуль, _पीएम_, _حقا_, 
   {{0x9f9c0241,0xdcec01e4,0x069400ec,0xfcb80092}},	//   _dìí_, ldaĵ, _سامھ, _ሲሰጡ_, 
   {{0x31600007,0x2011c592,0xc5a400ec,0x00000000}},	//   _veiz_, fozi_, _سڏين_, --, 
   {{0x2011c593,0xdcec008f,0x3160167a,0x2ca0030d}},	//   gozi_, ndaĵ, _weiz_, vwid_, 
   {{0xdb140030,0x3160030a,0xdcec0115,0xfc3c0cad}},	//   _pozý, _teiz_, idaĵ, _orís_, 
   {{0x2ca0079b,0xbcf8020c,0x2d807bbf,0x221400c7}},	//   twid_, _ndés, ugie_, _ифыр, 
   {{0x201093e9,0xfce04294,0x0c25c594,0x9f500129}},	// [323a0] bozi_, гото, еман, zizé_, 
   {{0x9f9c4e53,0xfc3c0597,0xbcf80241,0x7c240ffb}},	//   _yìí_, _arís_, _adés, _chjr, 
   {{0x80a404c5,0xdb1400a2,0xeb980022,0x9670030d}},	//   খমণ্, _tozý, зиҕ_, _цiиэ_, 
   {{0x5a94013e,0xadb838eb,0xe3b80213,0x29f80118}},	//   ъруф, _تۇرا_, nmır_, jčat_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7c240268,0x998c0030,0x7c5400e3,0xc6a5c595}},	//   _ghjr, _vieš_, _سلفر_, ерии, 
   {{0xfc00921a,0x3b0422f7,0x09e400d6,0xdb158ee2}},	//   _спро, _зеро_, _зовн, _dozó, 
   {{0x20101510,0xbcf801bf,0xfcb80092,0xfc3c032e}},	//   zozi_, _idér, _ሲሰጥ_, _grís_, 
   {{0x2011c596,0x9f9c0248,0x00000000,0x00000000}},	//   yozi_, _sìí_, --, --, 
   {{0xa3d40137,0x97d8030d,0x00000000,0x00000000}},	//   тооч, _оьху_, --, --, 
   {{0x1cd80327,0x72d00108,0xd130179e,0x00000000}},	//   འགོ_, гоэф, یمپ_, --, 
   {{0x2011c597,0x044400d8,0xe3b80205,0x00000000}},	//   wozi_, _зедн, tmıs_, --, 
   {{0x2011c598,0xd5e800c6,0x29f9c599,0x9f9c01e1}},	//   tozi_, _تعلن_, lčas_, _wìí_, 
   {{0xbcf801e1,0x9f9c0241,0xe3b803e0,0x00000000}},	//   _odér, _tìí_, rmıs_, --, 
   {{0x2011bc6c,0x6e94722e,0xe3b80205,0x29f85106}},	//   rozi_, лиру, smıs_, nčas_, 
   {{0xb8d16215,0x201044c8,0xfc3dc59a,0x7c6400c6}},	//   _ཟླ_, sozi_, _asía_, فائل, 
   {{0xbcf80248,0x2011c59b,0x9d180b01,0x00000000}},	// [323b0] _adér, pozi_, фоат_, --, 
   {{0x201001f0,0xdea08d3c,0xfbd02a77,0x96a0000d}},	//   qozi_, _پیری, دتر_, _कईलॉ, 
   {{0x6fd00724,0x29f80010,0xfc3c827c,0x00000000}},	//   _täcr, jčas_, _prís_, --, 
   {{0x29f80419,0x69d80200,0x7b0400b8,0x58d41422}},	//   dčas_, ëvep, _āptā, коет, 
   {{0x23b00e49,0x29f813d5,0x64940022,0xfce80092}},	//   जयाद, včat_, _ỹing, _መርጦ_, 
   {{0x62980e29,0x3f800008,0xfc3c08a5,0x6128022e}},	//   _opvo, ngju_, _frír_, vоll, 
   {{0xd70402e8,0xdcec00df,0x20040010,0xa3e400ce}},	//   ъзки, rdaĵ, člih_, नसन_, 
   {{0xf9916c37,0x263c01e4,0xa2c46766,0x00000000}},	//   _حبس_, _aĉos_, िमन्, --, 
   {{0xb6a002f4,0xf8bc0122,0x62980153,0x00000000}},	//   тиқл, _šéf_, _apvo, --, 
   {{0x91a8033f,0x9f9c0241,0xdb0400ae,0x6128022e}},	//   _जोड़े, _nìà_, hdhí, rоll, 
   {{0x91e4016c,0x9474015e,0x64980150,0x00000000}},	//   воне, ردکا, _үтір_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9f9c01e1,0xd131c59c,0x30c00eac,0x682401ab}},	//   _bìà_, شمس_, উন্স, lòda, 
   {{0xb4bc05ba,0x3f802880,0x29f82230,0x4340014b}},	//   ीही_, ggju_, nčar_, _кешв, 
   {{0x924801b9,0xe3b803b9,0x00000000,0x00000000}},	//   _ўзиб_, pmır_, --, --, 
   {{0xdc900125,0xbcf8004a,0x00000000,0x00000000}},	//   _ምርምር_, _adéq, --, --, 
   {{0x68940020,0x00000000,0x00000000,0x00000000}},	// [323c0] _መፍትሄ_, --, --, --, 
   {{0x21f800e4,0x7a2000c7,0x00000000,0x00000000}},	//   mũha_, võta, --, --, 
   {{0xdb04045f,0xc984022e,0x00000000,0x00000000}},	//   edhâ, вули, --, --, 
   {{0xdb0401e7,0x02b4010f,0x00000000,0x00000000}},	//   cdhí, כלעך_, --, --, 
   {{0xe895c59d,0x61fc0d86,0x88e402e8,0x47600022}},	//   уаль, érli, ъжде, иҭаҳ, 
   {{0xbcf8003e,0x7e68005b,0x7a200022,0x8b24b68c}},	//   _keén, _ämpä, rõta, _адге, 
   {{0xdb4c0e53,0xc6a46418,0x00000000,0x00000000}},	//   _رێن_, трли, --, --, 
   {{0xd90c04d3,0x7bd00003,0x00000000,0x00000000}},	//   _کیه_, ġjuż, --, --, 
   {{0x7be80086,0x07a40588,0x00000000,0x00000000}},	//   _ôquò, _иаан, --, --, 
   {{0x85041046,0x682401e1,0x00000000,0x00000000}},	//   _یوان, bòda, --, --, 
   {{0x86c5c59e,0xf740e55b,0xb7d42e0b,0x00000000}},	//   _جيان, _техо, _جولا_, --, 
   {{0xfe7002f2,0x538000c7,0x00000000,0x00000000}},	//   یدز_, ақәз, --, --, 
   {{0xfc3c01e1,0xbcf800c7,0x320801c6,0x00000000}},	//   _asín_, _ndép, тхэн_, --, 
   {{0x200400c5,0x836401b9,0xdb040165,0x00000000}},	//   õli_, _شدتل, ndhã, --, 
   {{0xbcf80248,0x6299c59f,0x00000000,0x00000000}},	//   _adép, _upvo, --, --, 
   {{0x325006bb,0xbdd8180f,0x1b20015b,0x6bd4036b}},	//   _твър, _mièg, _বললে_, یتلر, 
   {{0xbdd807ea,0xdb0400c6,0xc32c04b3,0xd94401b9}},	// [323d0] _lièg, rdhí, _دەگ_, қели, 
   {{0xac94020a,0x9c18007b,0x00000000,0x00000000}},	//   рафш, رياء_, --, --, 
   {{0x29f86b48,0x63bc01ed,0xe7f81b76,0xa8040139}},	//   včar_, örny, ्चना_, _miñğ, 
   {{0xaa580114,0x00000000,0x00000000,0x00000000}},	//   тицу_, --, --, --, 
   {{0x851c02e5,0x77f00022,0x00000000,0x00000000}},	//   _परगट_, аҟац, --, --, 
   {{0x6824067c,0x00000000,0x00000000,0x00000000}},	//   tòda, --, --, --, 
   {{0x53a42d31,0x29f80010,0x2f98011a,0x56380120}},	//   қанб, rčar_, דכון_, нџир_, 
   {{0x06940597,0x68240ba1,0xad580092,0x2d8400fd}},	//   انية_, ròda, _ጉድጓዶ, _ömet_, 
   {{0xb4bc00ab,0x0454007b,0x00000000,0x00000000}},	//   ीहे_, هلية_, --, --, 
   {{0xdb0401ab,0x00000000,0x00000000,0x00000000}},	//   odhà, --, --, --, 
   {{0x88380115,0x00000000,0x00000000,0x00000000}},	//   _נתעו, --, --, --, 
   {{0xa5f801af,0x38540023,0x00000000,0x00000000}},	//   _иеху_, _ዝተሰብ, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x21f800c7,0x00000000,0x00000000,0x00000000}},	//   rũha_, --, --, --, 
   {{0x52751ae1,0xa3b80150,0xa2c408df,0x7a20000d}},	//   _сулу, _جانر_, िमण्, võtn, 
   {{0xfc3c00d0,0x00000000,0x00000000,0x00000000}},	//   _príp_, --, --, --, 
   {{0xe7f800bc,0x00000000,0x00000000,0x00000000}},	// [323e0] ्चमा_, --, --, --, 
   {{0xfc3c0597,0x3254001f,0xfb840107,0x00000000}},	//   _tsín_, _የተሰጣ, лбук_, --, 
   {{0xaaa40032,0x00000000,0x00000000,0x00000000}},	//   ргеҙ, --, --, --, 
   {{0xa2c41fbc,0x48e40818,0xc33000d9,0x00000000}},	//   िमत्, лоев, זוב_, --, 
   {{0xbdd820ef,0xaaa4060c,0x7a200037,0x00000000}},	//   _sièg, _गैरक, mõtl, --, 
   {{0xbdd87ea5,0xa73800aa,0xbb403129,0xf1c80150}},	//   _pièg, نګار_, _герк, _ﺩﻗﻴﻘ, 
   {{0x998c01f1,0xdb0401ab,0x00000000,0x00000000}},	//   _sieť_, cdhà, --, --, 
   {{0x9f40067c,0x9f5000bc,0x00000000,0x00000000}},	//   _elhè_, vizí_, --, --, 
   {{0x69c1c5a0,0x09041dbc,0xdb0400ae,0x00000000}},	//   _inme, _спан, mdhá, --, 
   {{0x27f8dda3,0x00000000,0x00000000,0x00000000}},	//   _örn_, --, --, --, 
   {{0xa159c5a1,0x28ac193d,0xfc14010f,0xa2c42e35}},	//   кану_, चिकि, רקיי_, िमध्, 
   {{0xe135c5a2,0x25a00332,0xdb0400e5,0x00000000}},	//   инны, _úil_, ndhá, --, 
   {{0x69c008cd,0x00000000,0x00000000,0x00000000}},	//   _mnme, --, --, --, 
   {{0x3cfc02d5,0x26d80254,0xdb040332,0x133800e5}},	//   _žuvo_, _üros_, hdhá, عتیں_, 
   {{0x9f3400d6,0x92a80184,0xc0c00131,0xaaa40210}},	//   реві, _асыҡ_, рәқи, _गैलक, 
   {{0x5d542bd4,0xddd401d3,0x2b1800c5,0xf50801e1}},	//   ркат, tsző, _बुधु_, _èṣí_, 
   {{0xaa441456,0x9bf41353,0x47d800cc,0x00000000}},	// [323f0] ەنمى, азач, _ভগনী, --, 
   {{0x69c1c5a3,0xefc807d6,0x21287236,0x00000000}},	//   _anme, _буюк_, _izah_, --, 
   {{0xac9456ff,0xdd94bc59,0x911401d5,0xddd401d3}},	//   _қарш, _каны, _مسیچ, ssző, 
   {{0x199437a4,0x9f5008e5,0xd9f80395,0x00000000}},	//   радя, lizà_, ънец_, --, 
   {{0x7c38180f,0xa3e45444,0xa968007b,0x00000000}},	//   _èuro, नसा_, امهم_, --, 
   {{0x69c1c5a4,0x2d8403ee,0x9f5019f5,0xfd1c0ca8}},	//   _enme, _ömer_, nizà_, _iyì_, 
   {{0xbdd806af,0xdee00023,0x00000000,0x00000000}},	//   _tièd, _ዓርኪ_, --, --, 
   {{0x9f4001f1,0x9f500ffb,0xdb04007b,0x00000000}},	//   _dlhé_, hizà_, cdhá, --, 
   {{0x5838e380,0x00000000,0x00000000,0x00000000}},	//   _азая_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x212805b1,0xf1c8013a,0x00000000,0x00000000}},	//   _azah_, hlář_, --, --, 
   {{0x99600153,0x720800e5,0x00000000,0x00000000}},	//   _lūžo_, افحہ_, --, --, 
   {{0x7a2000af,0x1c142e1e,0xd478008f,0xa07401ec}},	//   võtl, तकाल_, _סאַל, йырш, 
   {{0xdff40006,0xf1c801ef,0x00000000,0x00000000}},	//   бясь, dlář_, --, --, 
   {{0xb644037e,0x6824007f,0xd17400db,0xe7f86a60}},	//   _ｋｚ_, zòdo, _кыпы, ्चता_, 
   {{0x3a3c0c6a,0x00000000,0x00000000,0x00000000}},	//   _niup_, --, --, --, 
  
   {{0x9f500ffb,0xdb043b9d,0x93600023,0x00000000}},	// [32400] bizà_, ndhæ, _ጋንታታ, --, 
   {{0xfbdc0dd4,0x99dc002e,0x4b54020a,0x8b2402d5}},	//   _stêr_, _liňd, ръат, адзе, 
   {{0x682402e2,0xe3b80166,0x00000000,0x00000000}},	//   wòdo, klın_, --, --, 
   {{0x8294008f,0x00000000,0x00000000,0x00000000}},	//   ידעס_, --, --, --, 
   {{0xc7c410f3,0x9f51a467,0x69c1c5a5,0xef1800e2}},	//   иски, lizá_, _vnme, ļļu_, 
   {{0xd0480213,0xc7940022,0xfce80092,0x00000000}},	//   ünəm, ррды, _መርጃ_, --, 
   {{0xa5f8288b,0x3a3c0194,0x9f5000d8,0x6128022e}},	//   леку_, _fiup_, nizá_, rоli, 
   {{0xba54008d,0x3a3c01fb,0x00000000,0x00000000}},	//   _כסלו_, _giup_, --, --, 
   {{0x42941540,0xa4f85896,0x99dc00a2,0x00000000}},	//   ዚደንት_, دکار_, _diňd, --, 
   {{0xdd000841,0x2d04012d,0xe3b82b93,0x00000000}},	//   šuće, _रखैल_, alın_, --, 
   {{0x230800ec,0x00000000,0x00000000,0x00000000}},	//   دڪشي_, --, --, --, 
   {{0x75d0005e,0x9f5000d2,0x99dc00ee,0xbbd00456}},	//   _ويلا, dizá_, _giňd, _दक्क, 
   {{0x2455c5a6,0xbdd80ba1,0x9f5019f5,0xf9900375}},	//   _انتس, _lièc, tizà_, חרר_, 
   {{0x7a2000af,0x24840254,0x42440354,0xfc3c01ef}},	//   võtm, mumm_, _кхиб, _psím_, 
   {{0x6234192a,0x9f5019f5,0xbdd806af,0x442c03b2}},	//   _леку, rizà_, _nièc, _ihf_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x71f80214,0x248401c7,0xfc640395,0x4084b3f0}},	// [32410] _خروس_, numm_, ръбн, _туйб, 
   {{0x3a3c020b,0x4918000d,0x60dc0108,0xf454123b}},	//   _siup_, _बड़ो_, mysm, יימר_, 
   {{0x2485c5a7,0x60dc02d0,0x442c04ce,0x79a41d37}},	//   humm_, lysm, _mhf_, ирде, 
   {{0xd874868d,0x2484000d,0x442c0171,0x4ee401ee}},	//   ماتب, kumm_, _lhf_, _ысыҡ, 
   {{0x61fc006a,0x3a3c0194,0x236c0117,0xe9d001b9}},	//   iisl, _viup_, kadj_, بغل_, 
   {{0xab847df1,0x61fdc5a8,0x236c01a6,0x6824007f}},	//   _муск, hisl, jadj_, bòdm, 
   {{0x61fdc5a9,0x3a3c4694,0x9cc80022,0xb8c400fb}},	//   kisl, _tiup_, _рыҟа_, ыҫҡа_, 
   {{0x61fdc5aa,0xb865c5ab,0x2a6402e8,0x60dc02d0}},	//   jisl, _نائو, _фърг, kysm, 
   {{0x442c05be,0xd6c40075,0x7999c5ac,0x60dc0240}},	//   _bhf_, риққ, _ibuw, jysm, 
   {{0x53c8d979,0x60ddc5ad,0x99dc010e,0xd2a8005b}},	//   угом_, dysm, _diňe, гкое_, 
   {{0x7a20007d,0x442c005c,0x61fc2681,0xc4440133}},	//   võtj, _dhf_, fisl, لیۆن_, 
   {{0xe3b804fb,0x442c008c,0x78b9c5ae,0x248403b2}},	//   llıl_, _ehf_, _kruv, bumm_, 
   {{0x7999c5af,0x442c1e6f,0x99dc0209,0xdb04002f}},	//   _mbuw, _fhf_, _giňe, ldhä, 
   {{0xb4e02208,0x442c0140,0x61fc0332,0xe2a800db}},	//   ननी_, _ghf_, aisl, _چاين_, 
   {{0x7999c5b0,0x61fdc5b1,0xdb0440fc,0x00000000}},	//   _obuw, bisl, ndhä, --, 
   {{0xfbdc0016,0x0ae80220,0xc278010f,0x9f5000d8}},	//   _quên_, ңдай_, _ערפי, rizá_, 
   {{0xbdd820ef,0x442c0477,0x00000000,0x00000000}},	// [32420] _sièc, _yhf_, --, --, 
   {{0xbdd82047,0x7999c5b2,0x00000000,0x00000000}},	//   _pièc, _abuw, --, --, 
   {{0x7d0c009a,0x1c381830,0x78b86695,0xfaa0c4b4}},	//   _excs, рять_, _aruv, захо, 
   {{0x78b9c5b3,0xdb04007c,0x809c0037,0x00000000}},	//   _bruv, ddhä, _ओहमे, --, 
   {{0x6e25c5b4,0x27fc00f3,0x08f8036b,0xc6940023}},	//   mlib, tivn_, دراب_, _መርመራ_, 
   {{0x61fd5b71,0x26dc76b8,0xf40400e3,0x00000000}},	//   zisl, tyvo_, _رؤ_, --, 
   {{0xf76d06ef,0x61fc00ca,0x442dc5b5,0x78b9c5b6}},	//   راو_, yisl, _rhf_, _eruv, 
   {{0x6e25c5b7,0x61fc172e,0xf31c02d3,0x35b000a7}},	//   nlib, xisl, _ሳዕቤና, збър, 
   {{0xb2f0915c,0x61fc03c6,0x78b82ff9,0xdd9800ee}},	//   _བཟུང_, visl, _gruv, _öňe_, 
   {{0x6e25c5b8,0x61fdc5b9,0xaadc00dc,0x2485c5ba}},	//   hlib, wisl, _यथाक, rumm_, 
   {{0x61fc0038,0x6e25c5bb,0x2484ec0a,0xf1c40073}},	//   tisl, klib, summ_, षांन, 
   {{0x61fc01c8,0x60dc023a,0xfc3c13d5,0xe82000bc}},	//   uisl, tysm, _psík_, यतका_, 
   {{0x6e25c5bc,0x442c045a,0x68e401c3,0xa4d400d4}},	//   dlib, _thf_, ùidh, _фолі, 
   {{0x6e25c5bd,0x61fdc5be,0xd9a4033f,0x60dc07a3}},	//   elib, sisl, _ऐस्ट, rysm, 
   {{0x61fc00b5,0xa194702f,0xe3b803e0,0x245401f7}},	//   pisl, _дайч, nlım_, _انڪس, 
   {{0x6e25c5bf,0xbcf800dd,0xdb0493e0,0xdd5801c6}},	//   glib, _idéz, ndhå, раач_, 
   {{0x5ff40022,0x00000000,0x00000000,0x00000000}},	// [32430] _мзиу, --, --, --, 
   {{0x6e25c5c0,0x384002d3,0x1dc400bc,0xe3b803e0}},	//   alib, _ንሰማእ, _लचकत, klım_, 
   {{0xa1146702,0x6e240175,0xfc3c00d7,0x78b800b8}},	//   _دوکت, blib, _kríz_, _sruv, 
   {{0x78b9c5c1,0x685402d3,0x98b9c5c2,0x4a4402dd}},	//   _pruv, _ዝተመስ, илет_, імің, 
   {{0x1278001f,0xeab000dd,0xdb04007c,0xefe00023}},	//   _በደንብ_, وٹے_, ddhå, _ዓጽዩ_, 
   {{0xefc402d3,0xd7c80244,0x00000000,0x00000000}},	//   _ኸምዚ_, شوبه_, --, --, 
   {{0x9985c5c3,0x00000000,0x00000000,0x00000000}},	//   _ولسو, --, --, --, 
   {{0x78b9c5c4,0x79980107,0x91e400b5,0xdb05c5c5}},	//   _truv, _ubuw, _auのl, hehë, 
   {{0xb4e0068f,0x13e9c5c6,0xe3b80724,0x78b9c5c7}},	//   नने_, имий_, lmıy_, _uruv, 
   {{0xa3f40108,0x00000000,0x00000000,0x00000000}},	//   зяюш, --, --, --, 
   {{0xd1c9c5c8,0x6e25c5c9,0xdb140e78,0xd574c8cb}},	//   алне_, ylib, _unzä, _дуль, 
   {{0xac7c0020,0x7988d0c8,0x385402d3,0x656001ab}},	//   _እርሱም_, nggw, _ዝተቐበ, cbmh, 
   {{0x6e240115,0xd46910ad,0x00000000,0x00000000}},	//   vlib, _тиле_, --, --, 
   {{0xfbdc05d5,0xbcf804e6,0xdb040036,0x68e408c2}},	//   _quêl_, _geéi, gehë, ùidi, 
   {{0x7f40ac58,0x6e25c5ca,0x00000000,0x00000000}},	//   держ, tlib, --, --, 
   {{0x6e240337,0xfde40108,0xdb0400e4,0x00000000}},	//   ulib, одск_, pehê, --, 
   {{0x6e25c5cb,0x20540153,0x00000000,0x00000000}},	// [32440] rlib, _нтэр, --, --, 
   {{0xace9c5cc,0xc8c9c5cd,0x6b9c0175,0x61e40135}},	//   амға_, یوان_, _qbrg, _ċili, 
   {{0x4aa81952,0x161829c8,0x6e24a477,0xcb0801e2}},	//   ркен_, दवार_, plib, جيان_, 
   {{0x2bdc0316,0xdb04000f,0x6e246f19,0x00000000}},	//   _मकवा, ldhû, qlib, --, 
   {{0x3ed1c5ce,0x682400db,0xdcfc00d7,0xe3b815b7}},	//   _فقیر, lòdi, _zasľ, rmız_, 
   {{0xbcf8002e,0x798804ba,0xe3b80790,0x3c2c0254}},	//   _ndéy, aggw, tlım_, tüve_, 
   {{0x6abc02d0,0x09e400f3,0x00000000,0x00000000}},	//   _urrf, _довн, --, --, 
   {{0xbcf80248,0x3630004b,0x7ae02f48,0x9958054e}},	//   _adéy, وريس, ønte, râţi_, 
   {{0xdb04007c,0xe3b80205,0x35f40066,0x00000000}},	//   rdhå, slım_, ترود_, --, 
   {{0xe3b870f7,0xa2f400d6,0xc2e81291,0x00000000}},	//   mlık_, зпоч, لعجم_, --, 
   {{0xe3b8a493,0x00000000,0x00000000,0x00000000}},	//   llık_, --, --, --, 
   {{0x81e00f22,0x00000000,0x00000000,0x00000000}},	//   ফোন_, --, --, --, 
   {{0xe3b8a493,0x1b20015b,0x66000113,0xbcf800e4}},	//   nlık_, _বলছে_, mimk, _teéi, 
   {{0xbdd80228,0x6601c5cf,0x998c0432,0x64a4008e}},	//   _cièn, limk, _ejeň_, _маҗа, 
   {{0xbdd800f2,0x63a8922f,0x41b001d9,0xdb04036e}},	//   _dièn, medn, _قۅدر, rehë, 
   {{0x6289c5d0,0x63a9c5d1,0xe3b81918,0x6600ef9b}},	//   mudo, ledn, klık_, nimk, 
   {{0x6289c5d2,0xbc6401d9,0xee2001ec,0xac948c2b}},	// [32450] ludo, زمؔن_, тетi_, матш, 
   {{0x9f34177b,0xdb04003e,0x66000009,0xe3b80139}},	//   _непі, lehé, himk, dlık_, 
   {{0x6289c5d3,0xa2e8009e,0x6601c5d4,0xfc3c00d7}},	//   nudo, _পশুখ, kimk, _osív_, 
   {{0xe3b80baa,0x660000bc,0x63a8047e,0x00000000}},	//   flık_, jimk, hedn, --, 
   {{0x998c01a2,0x6289c5d5,0x63a801ed,0xe3b82737}},	//   _tiež_, hudo, kedn, glık_, 
   {{0x63a81225,0x6289c5d6,0x8ca00150,0x28240014}},	//   jedn, kudo, _سەمو, وژٕہ, 
   {{0xb4e037e3,0x63a9c5d7,0x7bc4bb99,0x66d800c7}},	//   नन्_, dedn, _inju, жьыр_, 
   {{0xd3880032,0x62880066,0x6600007c,0xd5c40456}},	//   әйне_, dudo, gimk, वाइज, 
   {{0x63a9bba6,0xa87401ec,0xe3b80166,0x57f400d4}},	//   fedn, _олті, clık_, _епат, 
   {{0x6289c5d8,0x63a83e3b,0x186800fb,0x00000000}},	//   fudo, gedn, _ваҡи_, --, 
   {{0x6289b986,0x66000010,0xdb0401d3,0x00000000}},	//   gudo, bimk, fehé, --, 
   {{0x10a40853,0xdb0401c7,0x63a8000d,0x11d400ae}},	//   пимн, gehé, aedn, ستجد, 
   {{0x63a80640,0x7bc5c5d9,0xbdd8026c,0xb3d00139}},	//   bedn, _onju, _pièn, _ойдә, 
   {{0x6288489c,0x29f800b0,0x6824004e,0xe50801f7}},	//   budo, rōai_, tòdi, _بيهو_, 
   {{0x62882137,0xe3b81918,0xbdd8067c,0x62640c75}},	//   cudo, zlık_, _vièn, _قايق, 
   {{0x7bc5c5da,0xfe41c5db,0xed6404bf,0xe3b80e51}},	//   _anju, енсо, drží_, ylık_, 
   {{0x68240ba1,0xea000051,0x00000000,0x00000000}},	// [32460] sòdi, nhất_, --, --, 
   {{0x66007d06,0x91780051,0x96bc00bc,0xbd3010e0}},	//   zimk, _hầu_, ्माउ, رىلع, 
   {{0x3fd8011a,0x00000000,0x00000000,0x00000000}},	//   _הקיב, --, --, --, 
   {{0x8c45c5dc,0x63a8068f,0xaca402e3,0x7bc42252}},	//   _неме, zedn, _ahụr, _enju, 
   {{0x6289c5dd,0xbdd80ba1,0x6da40124,0xfc3c01a8}},	//   zudo, _mièl, _еиҟа, _asíu_, 
   {{0xe3b8b753,0x466864b3,0x7bc40841,0x6289c5de}},	//   rlık_, брим_, _gnju, yudo, 
   {{0xcfb400bd,0x2b58014b,0xe3b800fd,0x6601c5df}},	//   ঞাপন, _ifrc_, slık_, timk, 
   {{0xf64d1478,0x6289c5e0,0xbb4008db,0xe3b80790}},	//   دئو_, vudo, _ческ, plık_, 
   {{0x66002ec3,0x63a9c5e1,0x6289c5e2,0x00000000}},	//   rimk, tedn, wudo, --, 
   {{0x6289c5e3,0x6601c5e4,0xbcf80124,0x32540092}},	//   tudo, simk, _teév, _የተመጣ, 
   {{0x63a83883,0x91780208,0x00000000,0x00000000}},	//   redn, _bầu_, --, --, 
   {{0x6289c5e5,0xaca40241,0x63a81d2d,0x917801fb}},	//   rudo, _awọt, sedn, _cầu_, 
   {{0xbdd8020c,0x7a2000af,0xf990008f,0x91780208}},	//   _dièl, mõtt, ערש_, _dầu_, 
   {{0x2d9c01ed,0xf4540375,0x9f3402dd,0x3390005b}},	//   ővel_, _ציור_, дегі, _зашё, 
   {{0xe3b82a15,0x7de40212,0x823411dc,0xf41005d0}},	//   mdı_, піад, _ىرعا, _אפס_, 
   {{0xe3b80bcc,0xdb0401c3,0xfc3c00d7,0x00000000}},	//   ldı_, cdhù, _opíc_, --, 
   {{0x61edc5e6,0xdd9036ba,0x9f400030,0xdb040b1a}},	// [32470] _ilal, _یود_, _dlhá_, ldhø, 
   {{0xe3b80abc,0x61edc5e7,0x3f641a71,0xca340150}},	//   ndı_, _hlal, _этиб, _ﻗﺭﺭ_, 
   {{0xdb0401bf,0x6fb80304,0x00000000,0x00000000}},	//   ndhø, _эгэр_, --, --, 
   {{0xeab00302,0x27ec0048,0xa95402bf,0xe3b806be}},	//   طعم_, _aldn_, екці, hdı_, 
   {{0x61ec88fe,0xd9780032,0xbc740030,0xd78801d5}},	//   _mlal, брҙә_, ýšľa, قنشو_, 
   {{0x61edc5e8,0x7bc472ec,0x3e2402d3,0x7a2000af}},	//   _llal, _unju, _ሰብኣይ, võtu, 
   {{0x61edc5e9,0xe3b927bf,0x00000000,0x00000000}},	//   _olal, ddı_, --, --, 
   {{0x61ec0066,0xdcfc0790,0xdb140200,0x15445f52}},	//   _nlal, _hası, _lazë, мейм, 
   {{0xdcfc494d,0x91780051,0x00000000,0x00000000}},	//   _kası, _nấu_, --, --, 
   {{0x8244044e,0x13080b32,0xb9e41ef7,0x00000000}},	//   _ከተማታ, жной_, _ኮሎ_, --, 
   {{0x61edc5ea,0x7a400241,0xdcfcc24b,0x00000000}},	//   _blal, _gìtì, _ması, --, 
   {{0x61ec0cf9,0x47181a4c,0x2258219b,0xdcfc0205}},	//   _clal, _וועג, írka_, _lası, 
   {{0x61ec2798,0xbdd8180f,0xdb140023,0x91780208}},	//   _dlal, _vièl, _bazë, _cấu_, 
   {{0xdcfc0ab7,0x61edc5eb,0x91780208,0xdcec0115}},	//   _nası, _elal, _dấu_, neaĵ, 
   {{0x3da800d1,0x00000000,0x00000000,0x00000000}},	//   ﺷﻠﯩﻘ, --, --, --, 
   {{0x61ec020c,0x00000000,0x00000000,0x00000000}},	//   _glal, --, --, --, 
   {{0xdcfce162,0xdb140023,0x90340212,0x91780051}},	// [32480] _bası, _fazë, _охоч, _gấu_, 
   {{0xdb15c5ec,0x5c14009d,0x00000000,0x00000000}},	//   _kazè, ньху, --, --, 
   {{0x61ec0209,0x33249e91,0xfc3c09c2,0xbdd8068c}},	//   _ylal, _jynx_, _asís_, _mièj, 
   {{0x79a01b6b,0xe3b81ae6,0x27ec05b1,0xba143e45}},	//   врше, zdı_, _sldn_, ويلا_, 
   {{0x7a20007d,0xe3b84952,0xdcfc0baa,0x8b644706}},	//   võtt, ydı_, _fası, _ياسم, 
   {{0xdcfc0598,0xe3b800ac,0xec340fae,0x99dc010e}},	//   _gası, xdı_, _سوزگ, _hiňl, 
   {{0x7a2000af,0x499400fd,0x76700451,0x00000000}},	//   tõtt, _ошат, نديء, --, 
   {{0xda6400e3,0x00000000,0x00000000,0x00000000}},	//   _سافي, --, --, --, 
   {{0xdcfc43dd,0xe3b800ac,0xb90003d4,0x838400a8}},	//   _yası, tdı_, _ফে_, мыне, 
   {{0x3201c5ed,0xdcfc2b24,0x7a200254,0x00000000}},	//   _amiy_, _xası, sõtt, --, 
   {{0xe3b81b09,0x61edc5ee,0xa19400ee,0xa37c01e4}},	//   rdı_, _plal, нанч, skĵo, 
   {{0xdb040ac8,0x44a400db,0xe7f82c2e,0xb60000d7}},	//   rdhø, _يماق, ्चका_, šáry, 
   {{0xdb140240,0xef08010f,0xe3b803e3,0x00000000}},	//   _pazë, _פּ_, pdı_, --, 
   {{0xe3b80213,0x00000000,0x00000000,0x00000000}},	//   qdı_, --, --, --, 
   {{0x61ecc6ee,0xdb1402e2,0x6e94a3f8,0xdcfc013d}},	//   _tlal, _gazè, киру, _rası, 
   {{0x61edc5ef,0x63b89f65,0xdcfc08a9,0xad2400d1}},	//   _ulal, _havn, _sası, ھىلى, 
   {{0x99dc0209,0x2299c5f0,0x63b80219,0xad240131}},	// [32490] _diňl, lék_, _kavn, پىلى, 
   {{0x2129c5f1,0xfbd00a12,0xdcfc00ac,0xbcf8772a}},	//   _iyah_, ختر_, _qası, _beér, 
   {{0x2249c5f2,0xdcfc6648,0x2299c5f3,0xfbd00244}},	//   _kiak_, _vası, nék_, _یتس_, 
   {{0x63b9c5f4,0x99dc0432,0xdcfc0139,0x00000000}},	//   _lavn, _giňl, _wası, --, 
   {{0x18684834,0x2248009f,0x22987dec,0x63b801a9}},	//   чали_, _miak_, hék_, _oavn, 
   {{0x63b9c5f5,0x76b000ac,0xbcf801e1,0x22983980}},	//   _navn, _həyə, _feér, kék_, 
   {{0xd6d1319d,0x22989194,0x00000000,0x00000000}},	//   اقع_, jék_, --, --, 
   {{0x229800dd,0x22480de2,0x9178004d,0x00000000}},	//   dék_, _niak_, _mẫu_, --, 
   {{0x2129c5f6,0x58040046,0x63b8005c,0xa9c40372}},	//   _nyah_, _كورك, _bavn, _جۅنۉ, 
   {{0xf6e410d9,0x2248005a,0xd264040e,0x63b8054e}},	//   _оцен, _aiak_, нкой, _cavn, 
   {{0x212850f9,0x63b81326,0xdb140232,0x2249c5f7}},	//   _ayah_, _davn, _bazé, _biak_, 
   {{0x21280369,0x224830c7,0xbdd80066,0x16bc610a}},	//   _byah_, _ciak_, _dièk, ्मीब, 
   {{0x63b876f7,0x4dc80183,0x63b0007f,0x00000000}},	//   _favn, ৰসমূ, òknè, --, 
   {{0x22988708,0x21296abd,0x63b8037e,0x6824004e}},	//   bék_, _dyah_, _gavn, lòdr, 
   {{0x76b003be,0x22480194,0xbea1c5f8,0x22983847}},	//   _bəyə, _fiak_, ларк, cék_, 
   {{0x22483e36,0xdb14ba1f,0xdb04002d,0x63b80841}},	//   _giak_, _gazé, kehâ, _zavn, 
   {{0x76b003be,0x21290811,0x1de0007d,0x63b80477}},	// [324a0] _dəyə, _gyah_, _नवरत, _yavn, 
   {{0x8fd0bc08,0x00000000,0x00000000,0x00000000}},	//   _сәмә, --, --, --, 
   {{0xd838007f,0x26e40154,0xc9a8011c,0x00000000}},	//   _epōk_, _কেনো_, звее_, --, 
   {{0x2128011f,0x672805ac,0x00000000,0x00000000}},	//   _yyah_, _rydj, --, --, 
   {{0xbcf80241,0x212805b1,0x229801ed,0x6728005c}},	//   _aféf, _xyah_, zék_, _sydj, 
   {{0x2299a9f2,0xbcf848bf,0xaee40055,0x00000000}},	//   yék_, _teér, _goṣu, --, 
   {{0x63b8341a,0x416800d1,0x29180055,0x00000000}},	//   _ravn, _ﻳﯩﮕﯩ, _śrad_, --, 
   {{0x63b92394,0xbcf80de2,0x046473f9,0xdb04000f}},	//   _savn, _keép, нтом, behâ, 
   {{0x22482948,0xdb1407de,0x63b8007f,0x22980438}},	//   _riak_, _razé, _pavn, wék_, 
   {{0x2298066d,0xd90c39b1,0x672805e4,0x970000d1}},	//   ték_, _بیه_, _tydj, _ھېيى, 
   {{0x0564516e,0x0585c5f9,0x63b8047e,0x06dc0154}},	//   _звен, _зулм, _vavn, _ভেরি, 
   {{0x22999314,0x200001e6,0x682400db,0xd5b852c4}},	//   rék_, _smhi_, còdr, _осі_, 
   {{0x2299c5fa,0x224803cd,0x63b802f0,0x80c801ad}},	//   sék_, _viak_, _tavn, ामें, 
   {{0x22985ef3,0x38380023,0x00000000,0x00000000}},	//   pék_, ትፈልጥ, --, --, 
   {{0x443dc5fb,0x224803a2,0xd1ec0092,0x99dc010e}},	//   mmt_, _tiak_, ጀሎች_, _siňm, 
   {{0xbcf801ed,0x443d0f2e,0xd24c0066,0x00000000}},	//   _beép, lmt_, _گچی_, --, 
   {{0x443cb698,0x21285d69,0x5c9814a3,0x00000000}},	// [324b0] omt_, _uyah_, ькая_, --, 
   {{0x6288011c,0xaa440131,0xdb140030,0xf1c000d0}},	//   ordo, ۇنلى, _enzý, čšej_, 
   {{0x19b80408,0x443cdca5,0x1df8023a,0x1ea80451}},	//   дуль_, imt_, _жены_, _کاڌي_, 
   {{0x443d5892,0x81e0015b,0x00000000,0x00000000}},	//   hmt_, ফোর_, --, --, 
   {{0xdb04002f,0xe3b803e0,0x00000000,0x00000000}},	//   ldhü, nlıs_, --, --, 
   {{0x443c01f5,0x67d5c5fc,0x6288022e,0x00000000}},	//   jmt_, лочу, krdo, --, 
   {{0x443c010a,0x79a40953,0x2011c5fd,0xdb04002f}},	//   dmt_, _прае, inzi_, ndhü, 
   {{0x02a002e3,0x443dc5fe,0x628801b9,0xe70801c8}},	//   _chọọ, emt_, drdo, عتون_, 
   {{0x628809d7,0xd3780228,0x682400db,0xec1400f1}},	//   erdo, үчү_, ròdr, _شوېد, 
   {{0x443c0175,0x614800de,0x00000000,0x00000000}},	//   gmt_, _mīlī, --, --, 
   {{0x88800014,0xf5e40212,0x38b80248,0x00000000}},	//   _میۆن, _підм, bàrá_, --, 
   {{0x443dc5ff,0xd70c1d8a,0x2010949e,0xfed4009e}},	//   amt_, िपीठ_, enzi_, সনাধ, 
   {{0x6289c600,0xdb140086,0xe3b01acf,0x443c0208}},	//   ardo, _anzü, _گرن_, bmt_, 
   {{0x7648fe92,0x443c0175,0xa3c80709,0xdb041427}},	//   _higy, cmt_, _लोप_, ndhó, 
   {{0x7648105c,0xe3b03c4b,0x62c4007b,0x00000000}},	//   _kigy, _درن_, _مزيك, --, 
   {{0x6d4000d2,0x2010026c,0x99dc00a2,0x74b400cd}},	//   _úmak, anzi_, _diňk, ्टपृ, 
   {{0x7648016b,0xbdd80036,0x0c2400d4,0xfe4000f3}},	// [324c0] _migy, _lièw, вман, рнто, 
   {{0x0ba9236f,0x76481418,0x6a4c00a2,0x00000000}},	//   بارى_, _ligy, _aşfa, --, 
   {{0xce584336,0xdb140139,0x9f9c01e1,0x7cf8007c}},	//   _تشخص_, _wazî, _tìò_, tärå, 
   {{0xa3c8c725,0xdb1400d8,0xbcf800c7,0x66e801e1}},	//   _लोन_, _anzó, _teép, _lèkú, 
   {{0x443dc601,0x06d000d1,0xdb0400e4,0xc8940114}},	//   ymt_, _ﻛﯧﺴﻪ, tehã, трењ, 
   {{0x6289c602,0x02a001f2,0x6e245e71,0xc6a41422}},	//   yrdo, _shọọ, loib, врии, 
   {{0x7649c603,0x600808a4,0xbdd8180f,0xd9b01d00}},	//   _bigy, nžma, _sièi, _گەند, 
   {{0x7ae0c6cb,0x764803cb,0x3ea40022,0x85440276}},	//   änte, _cigy, _änte_, кэпе, 
   {{0x7648015d,0xdb040124,0x25082927,0x00000000}},	//   _digy, mehá, عربی_, --, 
   {{0x7648019b,0x03c4bba2,0xadc400e4,0xa88808b0}},	//   _eigy, тсим, _raẽt, _ойға_, 
   {{0x7648066d,0x6e24005a,0x62880129,0x273801ef}},	//   _figy, koib, urdo, _dýní_, 
   {{0x6289c604,0x443c0472,0x76480042,0x00000000}},	//   rrdo, smt_, _gigy, --, 
   {{0xd3a40220,0xb6c000cf,0x00000000,0x00000000}},	//   _әріп, _бөөд, --, --, 
   {{0x764804ba,0x20100099,0xdb0400c7,0x00000000}},	//   _zigy, unzi_, hehá, --, 
   {{0xa2c450e5,0xdb047523,0x20100327,0x00000000}},	//   _сәпк, kehá, rnzi_, --, 
   {{0xb280807e,0x6e2401c0,0xfe742063,0xe3b8afeb}},	//   _тышк, goib, нүү_, mlıq_, 
   {{0xe3b8723e,0x6c546641,0x8d18013e,0xdb0400e4}},	// [324d0] llıq_, икту, ентӣ_, dehá, 
   {{0xbdd9c605,0xdb14026c,0x99dc00a2,0xbff001c6}},	//   _nièv, _fazì, _tiňk, _түгш, 
   {{0x6e25c606,0xe3b8654f,0xd054013f,0xdd9400ee}},	//   boib, nlıq_, ɑbɑr, _йаны, 
   {{0xdb14025a,0xfd1c0248,0x166402a9,0xfb8001b9}},	//   _wazï, _adìe_, қвим, _چگای, 
   {{0xbdd80129,0xe3b803e3,0x00000000,0x00000000}},	//   _bièv, hlıq_, --, --, 
   {{0x7649c607,0xf80402e8,0x1db801f9,0xe3b8a75a}},	//   _sigy, ъчен, _उघडत, klıq_, 
   {{0x9f512b4f,0x24780020,0xdb04007b,0xead4013d}},	//   lizó_, _በሁለት_, rdhó, _корь, 
   {{0xe3b99f50,0x00000000,0x00000000,0x00000000}},	//   dlıq_, --, --, --, 
   {{0x1425c608,0x9f5009d7,0x2ed12fe4,0x764801ed}},	//   лдим, nizó_, _हप्त, _vigy, 
   {{0x387c04cc,0x6e25c609,0x9f4000d0,0x68e54a99}},	//   _ivur_, zoib, _dlhú_, äide, 
   {{0x7648b35f,0x91e43b2e,0x6e2401c8,0x387c02d2}},	//   _tigy, гоне, yoib, _hvur_, 
   {{0xd1b835ea,0x5ef800bc,0xdb1401ef,0x05940066}},	//   راجا_, ैछन्_, _nazí, _ماهگ, 
   {{0xd395c60a,0x53a43763,0xd094008e,0x051400ec}},	//   _йәнә_, _балб, ышны, _ٽيوب_, 
   {{0x99dc010e,0x1834010f,0xe3b803b9,0x00000000}},	//   _diňi, טאָל_, blıq_, --, 
   {{0x6e25c60b,0xdb040450,0x91b00051,0xe3b80166}},	//   toib, lehæ, _thỳ_, clıq_, 
   {{0xd1743a4e,0x387c022e,0x00000000,0x00000000}},	//   _сыкы, _ovur_, --, --, 
   {{0x99dc0209,0xccc593f8,0xa3c80807,0xe3b003e6}},	// [324e0] _giňi, ыбай, _लोड_, _درۆ_, 
   {{0x9f040451,0x6e240332,0x00000000,0x00000000}},	//   _چوٿو, soib, --, --, 
   {{0x7f980302,0x7af80198,0x6e2401f7,0xdb04035b}},	//   _אביז, _ƙuta, poib, tehá, 
   {{0xdb140356,0x4e1800ae,0x00000000,0x00000000}},	//   _bazâ, _ستجد_, --, --, 
   {{0xbdd8026c,0xe3b843bc,0x08280120,0xdb0400c7}},	//   _pièv, zlıq_, нцки_, rehá, 
   {{0xbdd802e2,0x04641955,0x9f500268,0xdcac0137}},	//   _chèf, қтим, lizò_, _تۉك_, 
   {{0x2ca04e97,0xc6a43500,0xf3f8015b,0xdb0400e4}},	//   ltid_, урли, ীকার_, pehá, 
   {{0x26ec0034,0x9f50026c,0x2ca1a540,0x70a4000d}},	//   जनौर_, nizò_, otid_, _ओहूल, 
   {{0x2ca1c60c,0xc7941f3c,0x7dc80166,0xe94401d5}},	//   ntid_, _مشاب, _hösä, _ضرری, 
   {{0xe3b9839d,0x7dc820a9,0x06741436,0x00000000}},	//   tlıq_, _kösä, _будя, --, 
   {{0x2ca1c60d,0x99dc0432,0x00000000,0x00000000}},	//   htid_, _siňi, --, --, 
   {{0xe3b99f50,0x2ca0007d,0x387c0174,0x7dc8013d}},	//   rlıq_, ktid_, _yvur_, _mösä, 
   {{0xa3d4074d,0xe3b89c13,0xdb1419b3,0xfc3c02f0}},	//   _волч, slıq_, _razí, _spím_, 
   {{0xc3540c04,0x9f500789,0x3394007b,0x2004068c}},	//   _съдъ, vizó_, _منهج_, òli_, 
   {{0xe3b8467d,0x1ae8015b,0x3da41171,0xdd240171}},	//   qlıq_, _টেনে_, лраб, dīšo, 
   {{0x9f5009d7,0x2ca0d27e,0x3250011c,0x00000000}},	//   tizó_, ftid_, _увър, --, 
   {{0x9f40044e,0x00000000,0x00000000,0x00000000}},	// [324f0] _kohë_, --, --, --, 
   {{0xbcf80077,0x9f5000eb,0x41c04ff1,0x6b744f41}},	//   _aféc, rizó_, षयवस, йлуу, 
   {{0x9e340f1a,0x2ca091f3,0xceb401af,0x7f840240}},	//   _венч, atid_, _кәт_, _ንምሳሌ_, 
   {{0xba29c60e,0x2ca00067,0x00000000,0x00000000}},	//   رسام_, btid_, --, --, 
   {{0x2ca1c60f,0xbdd80494,0x89d403e6,0x00000000}},	//   ctid_, _dièt, شوور_, --, 
   {{0x966400ee,0xab64002f,0xdd2400ef,0x00000000}},	//   акке, rfüß, cīšo, --, 
   {{0xb4bc0882,0x96b84ccf,0xcbc401e2,0x07b400ae}},	//   ुम्_, тулу_, _خېلو_, شهية_, 
   {{0xa818167e,0x32e4013f,0x395c0393,0x00000000}},	//   پتۇر_, nɑye_, _ufus_, --, 
   {{0xbdd8067c,0x00000000,0x00000000,0x00000000}},	//   _hiès, --, --, --, 
   {{0xdb140109,0x78b80cf4,0x13e8094e,0xdb0401bf}},	//   _kazà, _isuv, тмой_, rehæ, 
   {{0x68440592,0x7dc800fd,0x7ae0005c,0x00000000}},	//   _اَلل, _xösä, ønth, --, 
   {{0xdb1403d1,0x2ca0d032,0xded00023,0xdb04340f}},	//   _mazà, ytid_, _ብኡኡ_, mehä, 
   {{0xdee00b82,0x91340111,0x2ca00175,0xdb04000d}},	//   _ዓይኑ_, рхні, xtid_, lehä, 
   {{0x84340220,0x00000000,0x00000000,0x00000000}},	//   _پكىر_, --, --, --, 
   {{0x5275c610,0x9f5801d3,0xdb042306,0x00000000}},	//   _тулу, ózás_, nehä, --, 
   {{0xa33800c6,0x2ca0cce0,0x14a80490,0x4d653d32}},	//   _сяіѕ_, ttid_, _कहाण, ркав, 
   {{0x51f401ed,0x2ca165fb,0xec3401d5,0x7ff400e5}},	// [32500] _مسکر, utid_, مورگ, _چسپا, 
   {{0xdee0044e,0x7b840075,0xbdd8067c,0xdb04023a}},	//   _ዓይኒ_, لامە, _sièt, kehä, 
   {{0x78b805a7,0xdb140261,0xbdd806af,0x91d80dba}},	//   _asuv, _razã, _pièt, _बचाई, 
   {{0x7ae16d8f,0xc86582a3,0xbdd85d7e,0x2ca1c611}},	//   änta, атки, _diès, ptid_, 
   {{0xbdd8020c,0x99dc002e,0x00000000,0x00000000}},	//   _vièt, _niňu, --, --, 
   {{0x59300023,0x66ec00ef,0x00000000,0x00000000}},	//   ባሚካኤ, _lēkš, --, --, 
   {{0xdb140120,0xdb043262,0x69c40352,0x5b3402d5}},	//   _vazã, gehä, _гөлб, _гэту, 
   {{0x26c00115,0x00000000,0x00000000,0x00000000}},	//   ĉio_, --, --, --, 
   {{0x36300075,0xbdd80036,0x69c0127b,0xdb140241}},	//   غرىس, _kièr, _iame, _ìbòm, 
   {{0x69c1c612,0xdb1401ed,0xdb040e78,0x870401d3}},	//   _hame, _hazá, behä, _پڑتے_, 
   {{0x8699c613,0xdb1401d3,0x2508036b,0xb3740092}},	//   _штат_, _kazá, ضرکی_, ተስፋፋ_, 
   {{0x69c1c614,0x7ae003b2,0xca3401ec,0x00000000}},	//   _jame, ønti, _ﻗﺭﺏ_, --, 
   {{0xdef8001f,0xdb147221,0x00000000,0x00000000}},	//   ጊውን_, _mazá, --, --, 
   {{0x69c1c615,0x7f740184,0x499800b7,0xd7d80490}},	//   _lame, шҡор_, ቀሳቀሱ_, ढायच, 
   {{0x69c00262,0x9f340024,0x00000000,0x00000000}},	//   _oame, севі, --, --, 
   {{0x5d55c616,0xdb040628,0x69c1c617,0x00000000}},	//   скат, nehå, _name, --, 
   {{0x6abc0421,0x9f400270,0xbdd87ea5,0xdb05c618}},	// [32510] _asrf, _mohé_, _bièr, ndhö, 
   {{0x69c1c619,0x7ac4cffb,0x7b645eb4,0x3b640b01}},	//   _aame, исее, ртае, ръав, 
   {{0x69c1c61a,0xdb1401a2,0xbdd8004e,0xcf900375}},	//   _bame, _bazá, _dièr, _צטט_, 
   {{0xa3c807f7,0x3da4119e,0x19942bb7,0x00000000}},	//   _लोस_, _троб, садя, --, 
   {{0xbdd839d3,0xf09400c8,0x6abc009f,0x69c062bc}},	//   _fièr, ַנק_, _esrf, _dame, 
   {{0x69c1c61b,0xe8f802d5,0x78b802f0,0x1a7851ae}},	//   _eame, шлі_, _vsuv, _مشرک_, 
   {{0x69c1c61c,0xdb14006a,0x5ae40014,0xc5ec00aa}},	//   _fame, _anzö, _آزٔ, کړل_, 
   {{0x69c1c61d,0x78b80564,0x95995aa0,0xdb048860}},	//   _game, _tsuv, утку_, gehå, 
   {{0x32f403be,0x9f40020c,0xdb043110,0x0b2c0092}},	//   məyə_, _dohé_, sehä, _ሦስተኛ, 
   {{0x69c1c61e,0x32f400ac,0xdb140118,0xdb04007c}},	//   _zame, ləyə_, _zazá, pehä, 
   {{0x69c1c61f,0x66ec005f,0x53a5c620,0xdb0438aa}},	//   _yame, _pēkš, _ғайб, behå, 
   {{0x69c00694,0xcb1002e4,0xc6e40124,0x541400e5}},	//   _xame, ללי_, _усуҩ, _گڑبڑ_, 
   {{0x68fc00ac,0x00000000,0x00000000,0x00000000}},	//   _ərdo, --, --, --, 
   {{0x51f404fb,0x0eb806a6,0x32f40213,0x06dc00fe}},	//   _گستر, лубы_, həyə_, _ভেটি, 
   {{0x528400c6,0x32f400ac,0x00000000,0x00000000}},	//   _البك, kəyə_, --, --, 
   {{0x51f4bab9,0x6264211f,0xbcf801e7,0x5154004e}},	//   _دستر, _باوق, _sféa, _утку, 
   {{0x7ae001e6,0x32f400ac,0xbdd80066,0xcb080832}},	// [32520] äntn, dəyə_, _pièr, گيان_, 
   {{0x69c1c621,0x00000000,0x00000000,0x00000000}},	//   _same, --, --, --, 
   {{0x69c1c622,0xcb081002,0xc278008f,0x32f40213}},	//   _pame, ديان_, ָרני, fəyə_, 
   {{0x3a3dc623,0x69c0016d,0x888400c6,0x32f406be}},	//   _chup_, _qame, مؤتم, gəyə_, 
   {{0x69c1c624,0x9f400066,0xbdd8180f,0xb3b408a3}},	//   _vame, _rohé_, _tièr, _असंख, 
   {{0x69c016cb,0x9cb000cf,0xe3ac00cc,0xaa9400fb}},	//   _wame, _تۅكت, _কোনব, _мѳбә, 
   {{0x69c1c625,0x32f40213,0xdb040450,0xbc9c0205}},	//   _tame, bəyə_, tehå, ıçeş, 
   {{0x8a04be82,0x69c00607,0x3a3c0477,0x32f400ac}},	//   _узбе, _uame, _ghup_, cəyə_, 
   {{0x98b409bb,0xdb040b21,0xddc400dc,0xb7d4211f}},	//   _आईएए, kehû, _sthū, _گولا_, 
   {{0xaee41682,0x9f400214,0xdb05c626,0x00000000}},	//   hiṱi, _wohé_, jehû, --, 
   {{0xdb0401e6,0xdcec0115,0x46f41f39,0x21b40cc9}},	//   pehå, rbaĉ, _учат, ойня, 
   {{0xa3c800af,0x3a3c0200,0x00000000,0x00000000}},	//   _लोर_, _xhup_, --, --, 
   {{0x9f400030,0x26cc0419,0xb1140006,0x00000000}},	//   _dlhý_, _hrdo_, змяш, --, 
   {{0x26cc00f3,0x32f40213,0x27fc004d,0x00000000}},	//   _krdo_, zəyə_, nhvn_, --, 
   {{0x32f400ac,0x442c02d2,0x00000000,0x00000000}},	//   yəyə_, _ikf_, --, --, 
   {{0x7bc8005f,0x22580118,0x00000000,0x00000000}},	//   ēgum, írku_, --, --, 
   {{0xc4b413b4,0x442c198f,0x00000000,0x00000000}},	// [32530] _अनोख, _kkf_, --, --, 
   {{0x60cca6bf,0x26cdc627,0x7ae03b22,0x8cd80118}},	//   _iram, _ordo_, änto, _नपरो, 
   {{0xbdd835b0,0xdea0006c,0x9e840244,0x00000000}},	//   _chèc, _تیزی, _باخۆ, --, 
   {{0x60cdc628,0xefd4001f,0x442dc629,0xa95800ae}},	//   _kram, ረዳው_, _lkf_, مجهر_, 
   {{0x26cdc62a,0xa3b80882,0x32f400ac,0x442c00ad}},	//   _ardo_, _चसं_, rəyə_, _okf_, 
   {{0x26cc0b91,0x3a3c0204,0x442c0fac,0x32f40213}},	//   _brdo_, _whup_, _nkf_, səyə_, 
   {{0x3a3c0649,0xa3dc05d7,0x32f403b9,0x00000000}},	//   _thup_, डान_, pəyə_, --, 
   {{0x60cdc62b,0xb8640451,0x442c01bf,0x32f40213}},	//   _oram, _هائو, _akf_, qəyə_, 
   {{0xbb3c0ed1,0x61fc01ab,0x60cc74cc,0x94740214}},	//   _ﺟﺎﻥ_, dhsl, _nram, زگشا, 
   {{0x52a86d56,0x5285c62c,0x99dc00a2,0x72a000d1}},	//   авом_, огоб, _giňr, كەتن, 
   {{0x60cdc62d,0x26cc0f03,0x16340276,0x442c01bf}},	//   _aram, _grdo_, _дежя, _dkf_, 
   {{0x60cdc62e,0x628402b5,0xd9f805d7,0x61fc03ac}},	//   _bram, _āiot, ंसित_, ghsl, 
   {{0x60cdc62f,0x46400014,0x1138010b,0x442dc630}},	//   _cram, _تھوِ, ряны_, _fkf_, 
   {{0x6a8001e1,0xdb14154a,0x00000000,0x00000000}},	//   _jáfá, _gazç, --, --, 
   {{0x60cdc631,0xdb04002d,0x91e402e8,0xe4d400db}},	//   _eram, rehû, _моке, _وتۇب, 
   {{0x60cd40ea,0x61fdc632,0x9f400548,0xdb0401e7}},	//   _fram, chsl, _tohî_, cfhé, 
   {{0x60cdc633,0x442c0109,0x00000000,0x00000000}},	// [32540] _gram, _ykf_, --, --, 
   {{0x91a400dd,0xaee40055,0xb86401ec,0xe88c0092}},	//   _اچھے_, _naṇu, _тиiс, መጣጣኝ_, 
   {{0x1c381830,0xda6400c6,0xfaa1c634,0x60cc030a}},	//   сять_, كاني, дахо, _zram, 
   {{0x19a80220,0x26cc0109,0x6aac0183,0x60ccb636}},	//   йтіп_, _rrdo_, ছিলো, _yram, 
   {{0x22ac016b,0x2d800276,0x67d41677,0x8c44b850}},	//   _mɛka_, maie_, золу, _меме, 
   {{0x2d81c635,0x26cc0334,0x00000000,0x00000000}},	//   laie_, _prdo_, --, --, 
   {{0x2d81c636,0x273400ae,0x91c80037,0x7ae001bf}},	//   oaie_, dúnú_, ियाई, øntt, 
   {{0x442c01e3,0x2d81c637,0x1648004b,0xdb140432}},	//   _skf_, naie_, مړنۍ_, _sazç, 
   {{0x04b401d9,0x00000000,0x00000000,0x00000000}},	//   تھاں_, --, --, --, 
   {{0xc3488b82,0x60cdc638,0x26cc0219,0x6a8001e1}},	//   ияне_, _rram, _trdo_, _gáfá, 
   {{0x22ac0134,0x26cc016b,0xe3b800fd,0x0564005b}},	//   _bɛka_, _urdo_, ynıf_, _двен, 
   {{0x60cdc639,0xa5c400fd,0x442c007f,0xe3b80790}},	//   _pram, _хөке, _wkf_, nlız_, 
   {{0xe3740724,0x845806ed,0xc5140133,0x60cc0213}},	//   _еллы, _трет_, _ببات, _qram, 
   {{0xe3a403e6,0x05a4012c,0x442dc63a,0x60cc0200}},	//   _رشتی, क्रब, _ukf_, _vram, 
   {{0x2d800356,0x8234007b,0x7e08014b,0xe2c800ec}},	//   faie_, _ورعا, ахаб_, _چوڻو_, 
   {{0x60cdc63b,0x2d589db1,0x60dc0054,0x2d80a394}},	//   _tram, жить_, pxsm, gaie_, 
   {{0x60cdc63c,0xdb040b1a,0x93840023,0x00000000}},	// [32550] _uram, lehø, ቐስኩዎ_, --, 
   {{0xe8c80135,0xbdd801c3,0x2d800af9,0xab940212}},	//   _གླེག, _dhèa, aaie_, дифі, 
   {{0x2011c63d,0x22ac016b,0x9e354b35,0xdb041347}},	//   mizi_, _yɛka_, _неоч, nehø, 
   {{0x2011c63e,0x2d800356,0x644801a9,0xffa000cf}},	//   lizi_, caie_, hmdi, _элүү, 
   {{0x8dd8011a,0xfd44013d,0x00000000,0x00000000}},	//   _הקרק, _фэнн, --, --, 
   {{0x2011c63f,0xcc7405e1,0x2b580048,0x7ae0037e}},	//   nizi_, _מעשה_, _ggrc_, ønts, 
   {{0xdb040158,0xa9e402dd,0x96740006,0xe7ec000d}},	//   jehø, _ﺍﻗﯩﺴ, чылі, _जकरा_, 
   {{0x2011c640,0x67f40de2,0x64480b4f,0xdb04005c}},	//   hizi_, _jàjj, emdi, dehø, 
   {{0x2011c641,0x248400d2,0xf8bc0037,0x03e80241}},	//   kizi_, gsmm_, _एनिय, _àkọl, 
   {{0xfc3c067c,0x201001f7,0x2d8001c4,0x676400e3}},	//   _ipís_, jizi_, zaie_, _يُقل, 
   {{0x2011c642,0xdb0412e8,0x3f8400ef,0x00000000}},	//   dizi_, gehø, _ķnup_, --, 
   {{0x273400c6,0x13a403e6,0x3f640107,0x00000000}},	//   súnú_, _کۆدی_, ҷиро_, --, 
   {{0x2011c643,0x455806a9,0xb81c9725,0x2d80062c}},	//   fizi_, _הכנס, _बदाम_, vaie_, 
   {{0x201051a9,0x4fc00efb,0x1b000154,0x3f640107}},	//   gizi_, رەجە, _এখনই_, зиро_, 
   {{0x67f400e8,0x2d800276,0xe8b800bc,0x00000000}},	//   _bàjj, taie_, _इन्च, --, 
   {{0xbcf80005,0x515401af,0x00000000,0x00000000}},	//   _efém, _этку, --, --, 
   {{0x2010015c,0x67f4002e,0x2d807925,0x4b8800ee}},	// [32560] bizi_, _dàjj, raie_, ййан_, 
   {{0x2d818318,0x2010054e,0x1d180212,0x00000000}},	//   saie_, cizi_, іють_, --, 
   {{0x4aa9c644,0xd5bc0a94,0x2561024c,0xa3dc0073}},	//   скен_, ्याज, lōlō_, डात_, 
   {{0xa3c800c5,0x8274010f,0x00000000,0x00000000}},	//   _लोई_, פענע_, --, --, 
   {{0xe3b80166,0x00000000,0x00000000,0x00000000}},	//   lnıe_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x36302c6c,0x00000000,0x00000000,0x00000000}},	//   کروس, --, --, --, 
   {{0x2011c645,0x67f40de2,0xe9840150,0xfb180375}},	//   zizi_, _xàjj, _زارۋ, _הולמ, 
   {{0x20119b37,0x070400f1,0x2be01c54,0x00000000}},	//   yizi_, تيژي_, नापा, --, 
   {{0xa2f400d6,0x644801f5,0xdb0403cd,0x00000000}},	//   дпоч, umdi, tehø, --, 
   {{0x644800da,0x2011c646,0xa195c647,0x16c00124}},	//   rmdi, vizi_, манч, _аӡын, 
   {{0x20111a02,0x4648013d,0xdb0401bf,0xe3b80139}},	//   wizi_, _узен_, rehø, dnıe_, 
   {{0x2011c648,0xb5c4105d,0x00000000,0x00000000}},	//   tizi_, _رووم_, --, --, 
   {{0x26d801c3,0xe2f80006,0x2be004af,0x5e58011c}},	//   _àros_, _мелі_, नाफा, живя_, 
   {{0x2011c649,0xbdd80066,0x2be00c00,0x9f400418}},	//   rizi_, _dhèn, नाना, _tohí_, 
   {{0x2011c64a,0x9f4000c7,0x00000000,0x00000000}},	//   sizi_, _pohâ_, --, --, 
   {{0x2718068f,0xfd105085,0x2011c64b,0x00000000}},	// [32570] धपुर_, رجر_, pizi_, --, 
   {{0x201001f0,0xa2d000dc,0x998c0419,0x307c011a}},	//   qizi_, धिप्, _zmeň_, _האזנ, 
   {{0x3f801326,0x00000000,0x00000000,0x00000000}},	//   maju_, --, --, --, 
   {{0x30840ee8,0xdfa801f7,0x00000000,0x00000000}},	//   _تلیف, _اُھو_, --, --, 
   {{0x25e05e58,0x9aa405d9,0x99dc02f0,0x6d580118}},	//   कानी_, _ڪمزو, _chňa, ěvat, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x55e5c64c,0xdb1437b5,0x00000000,0x00000000}},	//   дойб, _lazú, --, --, 
   {{0x3f809bb5,0x7bc5c64d,0x05d802ab,0xdb040332}},	//   haju_, _haju, भाषब, nfhí, 
   {{0x7bc5c64e,0x3f800bb8,0xb11402e3,0xb6a001b9}},	//   _kaju, kaju_, rụkp, фиқл, 
   {{0x3f801326,0x7bc40588,0xa5d4010b,0x2be000dc}},	//   jaju_, _jaju, _aỳdy, नाया, 
   {{0x3f800552,0x7bc51e3d,0x0cb81b6e,0x2eac032c}},	//   daju_, _maju, _उन्म, _चहेत, 
   {{0xeec80055,0x48580132,0xd588030d,0x00000000}},	//   _aṣāḷ, _اكەڭ_, _хiай, --, 
   {{0xa3c81094,0x53a5c64f,0x2be0725a,0xa4d40212}},	//   _लोक_, _жалб, नामा, _поці, 
   {{0x7bc5bf2d,0x3f80811c,0x34480a0e,0x00000000}},	//   _naju, gaju_, _учен_, --, 
   {{0x3ea00372,0xbea1c650,0x00000000,0x00000000}},	//   кирг, карк, --, --, 
   {{0x51545777,0x7bc40869,0x600801fa,0x2be02802}},	//   _отпу, _aaju, džmu, नाभा, 
   {{0x3f801326,0x7de000d2,0x5fa82232,0x9f400124}},	// [32580] baju_, _sísû, _चॉकल, _pohã_, 
   {{0x3f801326,0x00000000,0x00000000,0x00000000}},	//   caju_, --, --, --, 
   {{0x09e41fdf,0x7bc5c651,0x2be0146c,0x50d40133}},	//   можн, _daju, नाबा, _رزکر, 
   {{0xaca40521,0x8c941cb8,0x8d74691d,0x00000000}},	//   _akụr, _оргі, _تادا, --, 
   {{0x7bc5c652,0x8ba40184,0x61fc0023,0xe89524cd}},	//   _faju, _оҙаҡ_, ërli, халь, 
   {{0x7bc5c653,0x38c82688,0x46685cf7,0x8c44003b}},	//   _gaju, غانی_, орим_, _цеге, 
   {{0xa3c84425,0xc6a40120,0xbb3c0150,0x00000000}},	//   _लोग_, фрли, _ﺟﺎﻳ_, --, 
   {{0x3f8005a1,0x7bc400ca,0xbb400139,0xfc3c0306}},	//   zaju_, _zaju, _реск, _upír_, 
   {{0x7bc5c654,0xc7a40022,0xe3ac00cc,0xa3f401ec}},	//   _yaju, _оиак, _কোষব, еппі, 
   {{0x2c6464aa,0x7bc400e8,0x00000000,0x00000000}},	//   _möd_, _xaju, --, --, 
   {{0xa2d40879,0xe2140948,0x2c6401e3,0xf1d00037}},	//   ريحت, емны, _löd_, _तोहन, 
   {{0x3f80110e,0xbdd80100,0x27ec01f1,0xd36c0e26}},	//   waju_, _chèl, _hodn_, لۇۇ_, 
   {{0x3f801326,0x75d0005e,0xbdd8020c,0x2c6401e3}},	//   taju_, _جينا, _dhèl, _nöd_, 
   {{0xe3ac015b,0x3f8000b5,0x00000000,0x00000000}},	//   _কোরব, uaju_, --, --, 
   {{0x3f801326,0x645801e2,0x7bc5c655,0xf2c01411}},	//   raju_, _iivi, _raju, _асын, 
   {{0x3f800b91,0x7bc5c656,0x2c6401b8,0x62881543}},	//   saju_, _saju, _böd_, msdo, 
   {{0x6289c657,0x7bc5c658,0x5c9812c4,0xdb040332}},	// [32590] lsdo, _paju, якая_, rfhí, 
   {{0x61ec123c,0x2c64049f,0x9f445f48,0x6458047e}},	//   _hoal, _död_, óló_, _jivi, 
   {{0x6289c659,0x3a2dc65a,0x6459c65b,0x9f400418}},	//   nsdo, togp_, _mivi, _fohá_, 
   {{0x61ec0831,0x7bc4c534,0xceb000c8,0xd1d4001f}},	//   _joal, _waju, _גיט_, _ርቀት_, 
   {{0x61edc65c,0x7bc5c65d,0x6d580a28,0xfca81973}},	//   _moal, _taju, śvar, _باجو_, 
   {{0x07a18924,0x61edc65e,0xbcf80241,0x6459c65f}},	//   гашн, _loal, _agég, _nivi, 
   {{0x61ec020c,0x6288000f,0xd8b80327,0x199402d5}},	//   _ooal, jsdo, བསཤི, _павя, 
   {{0x6459c660,0xbcf804e6,0x3dcc00fe,0x614800ef}},	//   _aivi, _aféi, ৰসকল, _kūlī, 
   {{0x6459c661,0x69346f65,0x62883c75,0xf8bc0248}},	//   _bivi, _анту, esdo, _èé_, 
   {{0x7ae00a40,0x645826c2,0x130800c9,0xd9f40490}},	//   äntw, _civi, зной_, _आवडत_, 
   {{0x61edc662,0xe7840108,0x5164004e,0x00000000}},	//   _boal, _шуто, нүйү_, --, 
   {{0x61ec34fe,0x645937c2,0x25e00574,0xdb04002f}},	//   _coal, _eivi, काणी_, dehü, 
   {{0x645803d1,0xbdd802e2,0x61ed859c,0xddcc00a2}},	//   _fivi, _chèm, _doal, mmaň, 
   {{0x2c64049f,0x99dc02fb,0x6459c663,0x68e57af6}},	//   _röd_, _ohňo, _givi, äidi, 
   {{0x61ec1368,0xa3dc023e,0x6289c664,0xa3c8230e}},	//   _foal, डार_, csdo, _लोट_, 
   {{0x61edc665,0x00000000,0x00000000,0x00000000}},	//   _goal, --, --, --, 
   {{0xbcf98f0b,0x3200009f,0x908800c6,0x8b95c666}},	// [325a0] _ngéd, _iliy_, _عندك_, ереч, 
   {{0x61ec0460,0x645806e4,0x2c64014a,0xf1ac01ef}},	//   _zoal, _xivi, _vöd_, ट्रन, 
   {{0xdb0400c7,0x62080139,0xddcc00a2,0x00000000}},	//   pehý, _äslü, kmaň, --, 
   {{0x4278010f,0x00000000,0x00000000,0x00000000}},	//   פאנג, --, --, --, 
   {{0x27ec0427,0x2be000cd,0xf98401e2,0x00000000}},	//   _podn_, नादा, رنوي_, --, 
   {{0xc76434b1,0x00000000,0x00000000,0x00000000}},	//   راتى, --, --, --, 
   {{0xbb41c667,0x3200006c,0xd5bc1a22,0x00000000}},	//   _берк, _oliy_, ्यंज, --, 
   {{0x62880158,0x337000fd,0x8a4400db,0x272003ce}},	//   vsdo, ңгыр, _سئزم, _बशीर_, 
   {{0x61edc668,0x6459c669,0x64bc2e04,0xa3dc2ac3}},	//   _roal, _pivi, ्टेश, डाल_, 
   {{0x61edc66a,0xaca40521,0x645820ac,0x320001f7}},	//   _soal, _ahịr, _qivi, _aliy_, 
   {{0xb9c8069c,0x61edc66b,0x3200083a,0x62880165}},	//   _ደቂ_, _poal, _bliy_, usdo, 
   {{0x6289c66c,0x61480618,0x6459c66d,0x25a005ac}},	//   rsdo, _lūlū, _wivi, _øil_, 
   {{0x61ec325f,0x645806e4,0x62893e29,0x50a00145}},	//   _voal, _tivi, ssdo, لەيل, 
   {{0x64580357,0x9f0400aa,0xd4980046,0xbcf80036}},	//   _uivi, پورو, _ірі_, _uféi, 
   {{0x61ec0b23,0x85540101,0x00000000,0x00000000}},	//   _toal, _تیکر_, --, --, 
   {{0xbdd80231,0xbed801e1,0xf3e000c7,0xbcf8002e}},	//   _thèm, _aṣòw, _ажәо, _lgée, 
   {{0x5d548a6f,0xa3e40307,0x2cb40166,0x61fc0200}},	// [325b0] ткат, _पचा_, _ğadí_, ërlu, 
   {{0xb60001a2,0xbcf80694,0xdb0400e4,0x2c8c0022}},	//   čšin, _ngée, pehü, ñohẽ_, 
   {{0x224803a2,0xdd940124,0x62a40306,0x00000000}},	//   _khak_, _ианы, _úroč, --, 
   {{0x6148005f,0xbcf806af,0x00000000,0x00000000}},	//   _tūlī, _agée, --, --, 
   {{0x28f802bf,0x998c00a2,0x00000000,0x00000000}},	//   нець_, _ejeş_, --, --, 
   {{0xdd9000db,0x7bc800e2,0xcd28009f,0x00000000}},	//   _حوڭ_, ēgus, _آسٽن_, --, 
   {{0x98c0ae47,0x200001ab,0x224801a9,0x1a64036b}},	//   ısız_, _mlhi_, _ohak_, _شیشی_, 
   {{0x7ae0005b,0x3ea40254,0x22480208,0x00000000}},	//   äntu, _äntu_, _nhak_, --, 
   {{0xc480969c,0x395dc66e,0x2d8c013b,0x1cc8031c}},	//   алык, _igus_, _ɛde_, _ྲགས_, 
   {{0x22480548,0x6efc01b8,0xdcfc013a,0xaf940240}},	//   _ahak_, näbö, _nesč, ልታትና_, 
   {{0x9c4c0220,0x00000000,0x00000000,0x00000000}},	//   _ﺑﻮﻟﯟ_, --, --, --, 
   {{0x224811c1,0xbdd80066,0x1cdc031c,0x00000000}},	//   _chak_, _dhèk, ྡྷོ_, --, 
   {{0x2248020c,0x42200395,0x00000000,0x00000000}},	//   _dhak_, рдяв, --, --, 
   {{0x63c49e7e,0x35a41533,0x395c0c67,0x2248009d}},	//   _башҡ, _गाड़, _lgus_, _ehak_, 
   {{0xbcf80c6a,0x2be046df,0xc7b0010f,0x4390033a}},	//   _ngéb, नासा, ױבן_, _тајс, 
   {{0x395c01ab,0x00000000,0x00000000,0x00000000}},	//   _ngus_, --, --, --, 
   {{0x82bc0135,0x3dc900d7,0x00c4004e,0xc5f0011a}},	// [325c0] _མགོའ, _dacw_, _алык_, בדן_, 
   {{0x395dc66f,0x0e64892e,0x8fd00daf,0xca74010b}},	//   _agus_, _икон, _тәмә, вуды, 
   {{0x395c3223,0x387c0d51,0xaca4063f,0xad88016c}},	//   _bgus_, _awur_, _ihọr, _панҷ_, 
   {{0x2be0190c,0x00000000,0x00000000,0x00000000}},	//   नाहा, --, --, --, 
   {{0x8b641f84,0x25e00cf1,0xdb040332,0xe3b80139}},	//   _لازم, कासी_, rfhá, dnın_, 
   {{0xf1e40c2e,0x2ca1c670,0xdb4c4732,0x276802f2}},	//   गाड़_, muid_, _کێم_, رشتی_, 
   {{0x2ca00ae3,0x3160022e,0xdb1400a2,0x66d400db}},	//   luid_, _ogiz_, _kazý, ايبئ, 
   {{0xbdd8007f,0xdb140306,0x3160485b,0xa2d000cd}},	//   _chèh, _jazý, _ngiz_, धिस्, 
   {{0x2ca1c671,0x2ed8009e,0xbb3c02dd,0x2abc01e1}},	//   nuid_, সহিষ, _ﺟﺎﻕ_, bàbò_, 
   {{0xaca400b4,0x31602eb7,0x2249c672,0x25e0482a}},	//   _nhọr, _agiz_, _shak_, काही_, 
   {{0x2ca1c673,0x06840124,0xdcfc0100,0xf2c08675}},	//   huid_, _рген, _resč, асян, 
   {{0xaca402e3,0x2ca1c674,0xdb140122,0x00000000}},	//   _ahọr, kuid_, _nazý, --, 
   {{0xdd9402dd,0xdcfc0064,0x00000000,0x00000000}},	//   ғазы, _pesč, --, --, 
   {{0xaca405db,0x3490039b,0x2ca00d27,0x59c830fd}},	//   _chọr, _ташр, duid_, _रसभर, 
   {{0xdd95c675,0x88b8009e,0x443c0036,0x3da40064}},	//   лавы, ূমিক, mlt_, краб, 
   {{0x443dc676,0xe3b02ad5,0xdbd000ee,0xbcf87cd8}},	//   llt_, _خرچ_, _düýb, _ngéc, 
   {{0x2ca1c677,0x443dc678,0x61e8000d,0xadb40798}},	// [325d0] guid_, olt_, öelu, јбуш, 
   {{0xaca402e3,0x61fdc679,0x6b7401c0,0x443c0363}},	//   _ghọr, lksl, илуу, nlt_, 
   {{0x443dc67a,0x999834b1,0xbdd8068c,0x2ca01368}},	//   ilt_, екет_, _lhèi, auid_, 
   {{0x443dc67b,0xa50c0156,0xdb14010b,0xdbd0000d}},	//   hlt_, གློག_, _gazý, _hüüb, 
   {{0x6ce40220,0x2be074c8,0x3f840798,0xe9d000c6}},	//   _кіре, नाशा, _ônus_, تغل_, 
   {{0x02a00cad,0x16a872e5,0x15e40073,0x443dc67c}},	//   _akọọ, евки_, काभर_, jlt_, 
   {{0x2be01a76,0x61fdc67d,0xa3dc2c30,0xdb1400a2}},	//   नारा, kksl, डाई_, _yazý, 
   {{0x1544476d,0xe5140243,0x61fc01f5,0x00000000}},	//   лейм, _तेहि_, jksl, --, 
   {{0xbdd800e4,0x26d801ed,0x387c06fd,0x443dc67e}},	//   _chèi, _áron_, _uwur_, flt_, 
   {{0x53a4069c,0xbdd801ab,0x78b8e702,0x527556ff}},	//   _ጉዳያት_, _dhèi, _ipuv, луму, 
   {{0xa2d00882,0xbdd80ba1,0x2ca001f5,0x69c40254}},	//   धिष्, _ehèi, zuid_, õieg, 
   {{0x443dc67f,0x673c08fb,0x27300137,0x00000000}},	//   alt_, _ørja, _گۉۉس, --, 
   {{0x25e00b26,0x443c0175,0x8fd005a2,0x05b000ae}},	//   कारी_, blt_, бәнә, _طموح, 
   {{0x443c02fa,0x0490399c,0xdb040036,0x00000000}},	//   clt_, _الوح, ofhä, --, 
   {{0x0c2402a9,0x8fd0013d,0x00000000,0x00000000}},	//   ҳман, _һәвә, --, --, 
   {{0x3f90009a,0x2ca1c680,0x78b800e4,0xa2d000dc}},	//   _edxu_, tuid_, _opuv, धिर्, 
   {{0x0c2412b9,0x2be0012c,0x8c4800d8,0x00000000}},	// [325e0] гман, नाला, епав_, --, 
   {{0xdb140077,0xf0040131,0x3b80004e,0x00000000}},	//   _nazó, _түги, йлуг, --, 
   {{0xdb140166,0xda6443b9,0x78b8005b,0x1c380212}},	//   _gazü, لاني, _apuv, тять_, 
   {{0xa8280131,0x76480142,0x094801b9,0x2ca00037}},	//   ھۋال_, _nhgy, нчли_, puid_, 
   {{0x443dc681,0x2ca1c682,0x6e240381,0x2bac28f0}},	//   ylt_, quid_, mnib, _चापा, 
   {{0x67d5c683,0xaee41682,0xdb140100,0xbcf800d8}},	//   року, _haṱu, _obzè, _efés, 
   {{0x6e241730,0x25e00fc8,0xfc0055ee,0x443c037e}},	//   onib, काली_, _упро, vlt_, 
   {{0xbdd8034c,0x00000000,0x00000000,0x00000000}},	//   _dhèw, --, --, --, 
   {{0xaee406d6,0x7ea80209,0x6e2400a3,0xdcfc00b8}},	//   _maṱu, _köpç, inib, _kesā, 
   {{0x443dc684,0xa2b5c685,0x6abc0139,0x491801ad}},	//   ult_, абоч, _kprf, _मेयो_, 
   {{0xba0804c7,0x443dc686,0xdb140109,0x6e242507}},	//   _ፊት_, rlt_, _hazò, knib, 
   {{0x25e00490,0xc0c80220,0x443dc687,0xd24c4fca}},	//   काळी_, нуге_, slt_, وچي_, 
   {{0x61fdc688,0x6e2401ab,0x491801ad,0x26e41025}},	//   rksl, dnib, _मेमो_, _कपुर_, 
   {{0xbcf9c689,0x6e240dd9,0xdcfc00e2,0x6abc03ac}},	//   _ofér, enib, _nesā, _oprf, 
   {{0x629c02fb,0x6abc03b2,0xb7d8008f,0x8d700241}},	//   árod, _nprf, עקלי, _ọlọd, 
   {{0x05d800e1,0x6e25c68a,0x00000000,0x00000000}},	//   _मोमब, gnib, --, --, 
   {{0xbcf88ef6,0xdbd000c5,0x80240edf,0x9c380261}},	// [325f0] _afér, _tüüb, _مردم, впат_, 
   {{0x26e4652f,0x6e25c68b,0xddc400b8,0x92c803d4}},	//   _कपूर_, anib, _kuhū, োহৰ_, 
   {{0xdb15c68c,0xd7f0004d,0xddc40055,0xdcfc00ef}},	//   _razó, _rõ_, _juhū, _desā, 
   {{0x69dc013f,0xdb15c68d,0x3ea00240,0xddc400dc}},	//   _ɔreg, _sazó, mujt_, _muhū, 
   {{0xdcfc0421,0x225800bc,0x99880118,0x299000b8}},	//   _fesā, írky_, škům_, _ṇicā_, 
   {{0x9695c68e,0xbdd833a2,0xe8f802d5,0x00000000}},	//   ариш, _chèv, ылі_, --, 
   {{0xf96c02d3,0xd7f00208,0xa9c40137,0xdb04002f}},	//   _ብዓቢኡ_, _võ_, _گۅنۉ, ufhä, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xccf004ac,0xdb040730,0x78b80421,0xdb140407}},	//   ַכט_, gehö, _upuv, _tazó, 
   {{0x3ea0044e,0x2f0c00e8,0xe7840395,0x066400c7}},	//   kujt_, _jógé_, _гуцо, ыхәҭ, 
   {{0xfbcc00bd,0x4cb8010e,0x46101bf4,0x00000000}},	//   রাপত, _ỳüzü, صویر, --, 
   {{0xdb05c68f,0x7989c690,0x79580432,0x63e40150}},	//   behö, nagw, _gäwü, _ۇسىك, 
   {{0xd13001d9,0x00000000,0x00000000,0x00000000}},	//   زمس_, --, --, --, 
   {{0x8fa40cfc,0x7988e64b,0xcee8211f,0xa534010a}},	//   јаве, hagw, پرسن_, _унчч, 
   {{0xa225c691,0x7989c692,0x6e240010,0x00000000}},	//   _گروه, kagw, tnib, --, 
   {{0x6e240333,0xbcf80332,0xd17400cf,0x00000000}},	//   unib, _sgéa, _тыкы, --, 
   {{0x6e25c693,0x7989c694,0xbdd80ba1,0x69dc016b}},	// [32600] rnib, dagw, _nhèu, _ɔred, 
   {{0x4f94bb47,0x60c8a697,0xa5d400a2,0x9b84b74b}},	//   _триу, çeme, _aỳly, مؤمن, 
   {{0x4aa8afa0,0xbf9805e1,0xc965c490,0xc9842377}},	//   ткен_, _בייש, авей, аули, 
   {{0xbcf800dd,0x7989c695,0x02b4010f,0x00000000}},	//   _igén, gagw, ילעך_, --, 
   {{0x7c340175,0x7ea8008e,0xdcfc0055,0x5cf4010a}},	//   boxr, _töpç, _tesā, _ляру, 
   {{0x9b88136e,0xf7f000d1,0xcb6800ea,0x00000000}},	//   _مخفف_, قسىد, _јаве_, --, 
   {{0x2901c696,0x7989bc83,0x66e8016b,0xf2c4009a}},	//   šia_, bagw, yɛku, _بآ_, 
   {{0xf64c05d9,0x5928025c,0xe3b803e0,0x00000000}},	//   وئي_, _སྙམས_, rnım_, --, 
   {{0x07a5c697,0x479436fe,0x38c81e7c,0x79540408}},	//   _вазн, _نجاس, _لالی_, _витĕ, 
   {{0x69088e8e,0xbcf80098,0x38c80345,0x00000000}},	//   ırdı, _ogén, _جافی_, --, 
   {{0x86c41d57,0xbcf9c698,0xb7d41176,0xe1f8022e}},	//   _خيان, _ngén, _خولا_, генч_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbcf9c699,0xba540a1e,0x6474d02c,0xa3d45dbe}},	//   _agén, יסטו_, _углу, _голч, 
   {{0x2005c69a,0x331404fb,0x7989c69b,0xfe70bd62}},	//   óli_, ازید_, zagw, قدر_, 
   {{0x7989c69c,0x543800c8,0x2295c69d,0xbfa80014}},	//   yagw, _געװא, _البس, _یادٕ_, 
   {{0x7d24004b,0xdcfc054e,0xe3b80205,0x00000000}},	//   ليزې_, _nesă, knık_, --, 
   {{0x7c853c2f,0x26cc01e4,0x798835ba,0xcf880131}},	// [32610] рубе, _lsdo_, vagw, _ﺑﯘﺭﯗ, 
   {{0x60cdc69e,0x79892854,0x3ea00023,0xbe88014b}},	//   _isam, wagw, pujt_, _исме_, 
   {{0x59746431,0xdb140784,0x7989c69f,0x3a24003e}},	//   былу, _pazñ, tagw, énpo_, 
   {{0xdb040c6a,0x60cdc6a0,0x00000000,0x00000000}},	//   nghé, _ksam, --, --, 
   {{0x26cc0077,0xdcfc0311,0xdb040332,0xba75663c}},	//   _asdo_, _desă, ighé, _چارت, 
   {{0x60cd1353,0x7989c6a1,0xcce405d9,0x8d580375}},	//   _msam, sagw, _اسٽي, _תכשי, 
   {{0x7988079b,0xac19c6a2,0xae440014,0x60cc01a9}},	//   pagw, _тору_, _دپێو, _lsam, 
   {{0x60cdc6a3,0x1959c6a4,0xfbd000f1,0x95c801a9}},	//   _osam, _бабы_, _اتڼ_, улиб_, 
   {{0xa5e8052f,0x60cdc6a5,0x37a8004e,0x06a00150}},	//   рлыҡ_, _nsam, _атен_, _ﺍﻛﻜﯩ, 
   {{0x13e8300e,0xdb04000d,0x00000000,0x00000000}},	//   умой_, sehõ, --, --, 
   {{0x15b80024,0x00000000,0x00000000,0x00000000}},	//   _былы_, --, --, --, 
   {{0x60cc05b1,0xd9f80118,0x00000000,0x00000000}},	//   _bsam, ूसित_, --, --, 
   {{0x60cd89c7,0x92c803d4,0x89d8011a,0x00000000}},	//   _csam, োহে_, אחרי, --, 
   {{0x183400c8,0x15e40490,0xe2a80424,0x629c00d0}},	//   מאָל_, कावर_, داین_, ároc, 
   {{0x69dc0134,0x527400f7,0xb9000327,0xdb2401e1}},	//   _ɔreb, _уулу, _ྨན_, _àsèy, 
   {{0x4d65c6a6,0x629c00e2,0xe2a80244,0x00000000}},	//   скав, šroc, _ئاون_, --, 
   {{0x1b1400bd,0x4d48026a,0xbc60011b,0xfce061ac}},	// [32620] _তুলে_, упан_, звук, пото, 
   {{0x7ff4004b,0xb130001f,0xd1c00023,0x7b841183}},	//   _هسپا, ተያየታ, _ትኳቦ_, مامە, 
   {{0x7c28cb71,0x00000000,0x00000000,0x00000000}},	//   égra, --, --, --, 
   {{0xbdd8034c,0x26cdc6a7,0xc3300375,0x7e7c01ec}},	//   _dhès, _rsdo_, הוב_, _ﺩﺨﻠﺕ_, 
   {{0x60cdc6a8,0xfaec004b,0x093402e9,0x00000000}},	//   _xsam, وګې_, حراج, --, 
   {{0x2934040d,0x9e6411fc,0xdcac0137,0x2d80045a}},	//   ﺮﯨﭗ_, _داین, _جۉك_, lbie_, 
   {{0x6675c6a9,0xc6a40108,0xc04c013a,0x00000000}},	//   زگار, ёрки, _žáků, --, 
   {{0x2be005f9,0xca3406ba,0xa9c400db,0xdb140ca8}},	//   नाका, ﻗﯩﺖ_, _گۅچۉ, _ìbám, 
   {{0xbcf9c6aa,0x2d80003e,0x2ca1c6ab,0x090400f3}},	//   _ngél, ibie_, nrid_, _упан, 
   {{0x2ca1c6ac,0x60cc01ab,0xb6000327,0xe41400d4}},	//   irid_, _rsam, _ġġer, іднь, 
   {{0x60ccc35a,0x2ca00076,0x00000000,0x00000000}},	//   _ssam, hrid_, --, --, 
   {{0x2ca0700a,0x60cc7392,0x00000000,0x00000000}},	//   krid_, _psam, --, --, 
   {{0x44f80f84,0x2ca005b1,0x60cc031c,0x7638010f}},	//   _حراج_, jrid_, _qsam, _געאג, 
   {{0x2ca00f85,0xdb0401e7,0x235801af,0x00000000}},	//   drid_, sghé, _килњ_, --, 
   {{0x2ca1c6ad,0x32b4007b,0x1cb00327,0x133800e5}},	//   erid_, _هدية_, _དདང_, _پتوں_, 
   {{0x60cdc6ae,0xb8d8003d,0xbdd8068c,0x932404fb}},	//   _tsam, _མྱ_, _ahèr, _برهن, 
   {{0x7178104e,0x9bf428e8,0xa2a400cd,0xdfd40153}},	// [32630] _убыр_, озач, चूर्, _допы, 
   {{0x7b650d15,0xbdd96a0e,0xdcfc0024,0x3014004e}},	//   стае, _chèr, _nesą, _ндыр, 
   {{0x2d81c6af,0x2ca0007d,0xbdd800f2,0x00000000}},	//   bbie_, arid_, _dhèr, --, 
   {{0x58d8004e,0x00000000,0x00000000,0x00000000}},	//   идея_, --, --, --, 
   {{0xe3b80790,0xdcfc00c0,0x2ca003e3,0x00000000}},	//   kfı_, _besą, crid_, --, 
   {{0xbdd86953,0x4cb8008f,0x5fac18cc,0x00000000}},	//   _thès, _דזשו, ञ्चल, --, 
   {{0x6e49c6b0,0x05d802a0,0xa3ac000d,0x00000000}},	//   _árbó, _मोहब, गलन_, --, 
   {{0xe6c46c68,0x00000000,0x00000000,0x00000000}},	//   ستىي, --, --, --, 
   {{0xa9780354,0x00000000,0x00000000,0x00000000}},	//   _ыйту_, --, --, --, 
   {{0xbcf80c6a,0x00000000,0x00000000,0x00000000}},	//   _ngém, --, --, --, 
   {{0x2d81bd24,0x370401f4,0x00000000,0x00000000}},	//   ybie_, _учав, --, --, 
   {{0xcad40302,0xdb1404cc,0x2ca00363,0x68f801e7}},	//   קורת_, _fazö, yrid_, _éadá, 
   {{0x2ca00003,0x00000000,0x00000000,0x00000000}},	//   xrid_, --, --, --, 
   {{0x2d81c6b1,0xdcec00c8,0x6b5040dc,0x2ca13c8a}},	//   wbie_, ngaĵ, _jógí, vrid_, 
   {{0xb8d80003,0x2d80067c,0x9e050457,0x33400014}},	//   _མཱ_, tbie_, रसंघ_, _ڈۆکِ, 
   {{0x2bac012c,0x6b5002d2,0x10a4010a,0x00000000}},	//   _चाहा, _lógí, _диин, --, 
   {{0xbdd9c6b2,0x2ca1c6b3,0x2d81c6b4,0x00000000}},	// [32640] _chèq, urid_, rbie_, --, 
   {{0x2ca01368,0x3a3c002e,0x2d8001b8,0xf1a803e6}},	//   rrid_, _akup_, sbie_, _ئاژه_, 
   {{0x3ab039c7,0x2ca00204,0x00000000,0x00000000}},	//   мәтт, srid_, --, --, 
   {{0x3a3dc6b5,0x752c068f,0x2ca1c6b6,0x291803b9}},	//   _ckup_, żczy, prid_, _əraf_, 
   {{0xcb6800f3,0x7c4403b2,0x00000000,0x00000000}},	//   _ваге_, ørrí, --, --, 
   {{0xec35c6b7,0x00000000,0x00000000,0x00000000}},	//   _روزگ, --, --, --, 
   {{0x4918038e,0xbcf8065c,0xdb040ffb,0xeb540150}},	//   _मेरो_, _ngéj, nghì, _ءىزگ, 
   {{0xf2cc2158,0xda580f06,0x00000000,0x00000000}},	//   িমাণ, _груш_, --, --, 
   {{0x147801ed,0x614001a8,0x44280640,0xdb2007c5}},	//   یجیں_, _málþ, ицом_, ütös, 
   {{0x05d8000d,0x4adc000d,0x2418009d,0x00000000}},	//   _मोरब, _नछाव, ёоны_, --, 
   {{0x2a6401f7,0x9f640098,0x601001e1,0xe3b803e0}},	//   _kimb_, _étém_, _lómù, rfı_, 
   {{0xe3b80205,0x00000000,0x00000000,0x00000000}},	//   sfı_, --, --, --, 
   {{0xf99004ae,0xddcc033f,0x00000000,0x00000000}},	//   ורר_, ymał, --, --, 
   {{0x2a65c6b8,0x02a40798,0xdb200419,0x00000000}},	//   _limb_, _дрим, štét, --, 
   {{0x442dc6b9,0x00000000,0x00000000,0x00000000}},	//   _ijf_, --, --, --, 
   {{0x5c7434f0,0x2a6401bf,0x00000000,0x00000000}},	//   злат, _nimb_, --, --, 
   {{0x7c280077,0x6d4801d9,0x00000000,0x00000000}},	// [32650] égro, ۅلہِ_, --, --, 
   {{0x5f801c5c,0x225801bf,0x2bb8007b,0x00000000}},	//   _سۇرە, lmsk_, قامة_, --, 
   {{0x442c00d4,0x2a6481a9,0x6d480014,0x3f800003}},	//   _mjf_, _bimb_, ملہِ_, mbju_, 
   {{0x2a648581,0xbdd80129,0x442c00ef,0x00000000}},	//   _cimb_, _thèq, _ljf_, --, 
   {{0xdb1406ed,0x3a3c0010,0xe9d802d5,0x442c036e}},	//   _razõ, _vkup_, ўкі_, _ojf_, 
   {{0x59d80316,0x442c0175,0x00000000,0x00000000}},	//   णयहर, _njf_, --, --, 
   {{0xdcec01e4,0x00000000,0x00000000,0x00000000}},	//   rgaĵ, --, --, --, 
   {{0xf9901365,0x3a3c0113,0xbcf80098,0x442c054e}},	//   _زبر_, _ukup_, _ngék, _ajf_, 
   {{0x1cc80d46,0x629c172e,0x799808e7,0x442c00f3}},	//   _ིགས_, áron, _iduw, _bjf_, 
   {{0x442c0175,0xdb0401e7,0x7bd406be,0x00000000}},	//   _cjf_, hghí, ndxu, --, 
   {{0x09bc015b,0x442c009f,0x6268002b,0xc8b401e2}},	//   _ইফতা, _djf_, _aśob, _ولېک, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7999c6ba,0x82e0025c,0x0ef402ab,0xdb04000f}},	//   _mduw, ེའུའ, ीन्स_, nghâ, 
   {{0x2258000f,0xe00000c7,0xf1c801ef,0x00000000}},	//   amsk_, вҟьо, diář_, --, 
   {{0x79980428,0x434000c2,0x25e00073,0x24800092}},	//   _oduw, _пешв, काची_, _የሐሰት_, 
   {{0x79980502,0xae940241,0xd184009d,0x00000000}},	//   _nduw, _lẹgb, _элий, --, 
   {{0x3f800327,0x26d800d7,0xfaa00124,0x00000000}},	// [32660] bbju_, _árov_, ҵахо, --, 
   {{0x7999c6bb,0x2a642a1f,0x6fa800f1,0xef9404f2}},	//   _aduw, _simb_, _بندې_, _زیرد, 
   {{0x59dc000d,0x00000000,0x00000000,0x00000000}},	//   _नोहर, --, --, --, 
   {{0xa7fc0166,0xfe7401c6,0x00000000,0x00000000}},	//   _ciın, _хөрш_, --, --, 
   {{0xbcf8003e,0x7998015d,0x67d4de98,0xdcec0790}},	//   _ngéh, _dduw, долу, mbağ, 
   {{0x79980428,0xb600031c,0x7d180432,0xdcec06be}},	//   _eduw, _ġġar, _ýusa, lbağ, 
   {{0x2a65c6bc,0x87b802dd,0x0b5801af,0x00000000}},	//   _timb_, _қуат_, _ырмы_, --, 
   {{0x7c5404d3,0x35b000a7,0x43c00131,0xdceca565}},	//   _ولێر_, ебър, ﯩﺴﯩﺪ, nbağ, 
   {{0x84700023,0xa5340212,0x07a438ad,0x00000000}},	//   _ኣደራዕ_, ьнич, _наан, --, 
   {{0x3fd4000e,0xae9401e1,0x3cf800df,0x00000000}},	//   _সক্ষ, _gẹgb, צלינ, --, 
   {{0x442c025a,0x69dc0134,0x05644623,0x6235c6bd}},	//   _vjf_, _ɔren, _евен, дену, 
   {{0x626800b8,0xe7e0098a,0x442c0334,0xa52401ee}},	//   _aśoc, _गोता_, _wjf_, _оялһ, 
   {{0x6b9c0427,0xe13802dd,0x6ac80709,0x00000000}},	//   _odrg, ізгі_, रबुर, --, 
   {{0xf4841129,0xe3a401d5,0x68e0022e,0xa2cc3337}},	//   _راهی, _آششی, _mrmd, तबद्, 
   {{0x69c001a2,0x7bc000c5,0xb3b80375,0x3f81c6be}},	//   _obme, õnum, _המוכ, rbju_, 
   {{0xfbd042c0,0x6298025c,0x9f400ca8,0x15e400bc}},	//   کتر_, _ivvo, _sohó_, काएर_, 
   {{0x443dc6bf,0x2d580c9e,0x644800ad,0xb4600166}},	// [32670] oot_, зить_, oldi, _юкәл, 
   {{0x69c003fa,0xed500075,0xa3ac00c5,0xc92400cc}},	//   _abme, ھپە_, गलि_, _বৰ্ত_, 
   {{0x6449c6c0,0x443c0086,0x69c00175,0x60dc0ac8}},	//   ildi, iot_, _bbme, lvsm, 
   {{0x443dc6c1,0xa2a429ea,0x8de40156,0x64480086}},	//   hot_, _किन्, _ཤོགལ, hldi, 
   {{0xa3ac0574,0x91780208,0xddcc0210,0x00000000}},	//   गला_, _hậu_, rmań, --, 
   {{0x443c0029,0x69c0014f,0x68e000b5,0xe7e00764}},	//   jot_, _ebme, _drmd, _गोदा_, 
   {{0x443dc6c2,0x629c01ed,0x00000000,0x00000000}},	//   dot_, árol, --, --, 
   {{0x6448057b,0xbcf801c7,0x68e00175,0x6b9c0010}},	//   eldi, _agéi, _frmd, _zdrg, 
   {{0x443dc6c3,0x62980801,0x73c00184,0x26d80010}},	//   fot_, _avvo, еҙле, _šrot_, 
   {{0x443dc6c4,0x4a080135,0x0454007b,0x92b400e5}},	//   got_, _གཞོལ_, ولية_, وحجا, 
   {{0x81d400bd,0xd1c9c6c5,0x78a801a8,0x2c8401e1}},	//   সান_, олне_, lugv, _kédò_, 
   {{0x644805f5,0x443c1509,0x7ae002f6,0xddcc00e2}},	//   aldi, aot_, änty, lmaņ, 
   {{0xe19405f5,0x7658011f,0x00000000,0x00000000}},	//   эрээ, mmuy, --, --, 
   {{0x7658b4df,0xe7f0033f,0xdb040332,0x4558011a}},	//   lmuy, चाया_, nfhó, _וכנס, 
   {{0x7f4009fe,0xf3240150,0x9178004d,0x3f640107}},	//   верж, _رۋحى_, _cậu_, диро_, 
   {{0x7659c6c6,0x2a9802e2,0x00000000,0x00000000}},	//   nmuy, včb_, --, --, 
   {{0xdcec3535,0x7d0001e1,0x00000000,0x00000000}},	// [32680] rbağ, _rírú, --, --, 
   {{0x0ba80dd8,0xa7fc0166,0xa2a41221,0xace86518}},	//   تارى_, _ciıl, _किम्, омға_, 
   {{0x765803e0,0x4a680241,0xddcc0171,0xbff00117}},	//   kmuy, _ṣubú_, dmaņ, _рӯяш, 
   {{0x443c71dd,0xbcf80214,0x00000000,0x00000000}},	//   zot_, _ngéw, --, --, 
   {{0x443dc6c7,0x6448795b,0x69c0030d,0x6e25c6c8}},	//   yot_, yldi, _vbme, miib, 
   {{0x6e2533fd,0x443dc6c9,0x24800205,0xddcc00ef}},	//   liib, xot_, _çimi_, gmaņ, 
   {{0x443c0118,0x248c00b7,0x9f8802d2,0x00000000}},	//   vot_, _መሐመድ_, _móðu_, --, 
   {{0x443dc6ca,0xb6e018ac,0xfb100150,0xdb0c00e4}},	//   wot_, тюшк, _شوقج, _ëháp, 
   {{0x29000254,0x00000000,0x00000000,0x00000000}},	//   äiad_, --, --, --, 
   {{0x03c40440,0x76580083,0x644802d2,0x6e2515f7}},	//   фсим, amuy, uldi, hiib, 
   {{0x443dc6cb,0x6e25c6cc,0x271c015b,0xbb8801ec}},	//   rot_, kiib, _পুরো_, _ﺗﯘﻳﻪ_, 
   {{0x443dc6cd,0x84e846c6,0xdb05c6ce,0x6e243ede}},	//   sot_, _وفاق_, nghá, jiib, 
   {{0x6e2401d9,0xe8e001f2,0x9f880174,0x00000000}},	//   diib, daịs_, _bóðu_, --, 
   {{0x60dcb626,0x443cff51,0xa295992f,0xe454008e}},	//   rvsm, qot_, _закі, _яклы, 
   {{0x81d4015b,0x6e246732,0x6298022e,0x00000000}},	//   সাব_, fiib, _uvvo, --, 
   {{0x6e25c6cf,0x7c840063,0xdddc0210,0xc0c8014b}},	//   giib, дуже, _żyła, _дуое_, 
   {{0xac740150,0xdc5407b5,0xa2a40d0b,0x00000000}},	// [32690] نالش, евањ, _किड्, --, 
   {{0x9f882833,0xdb200306,0x76580205,0x00000000}},	//   _góðu_, štít, zmuy, --, 
   {{0xbcf8020c,0x6e25c6d0,0x76586b6d,0xdd940064}},	//   _ngév, biib, ymuy, _паны, 
   {{0xd9f81d5a,0xdddc033f,0xb600025c,0x6b9803b2}},	//   янец_, _wisł, _ġġor, óvgr, 
   {{0x97c5c6d1,0x98a47738,0x28f801ce,0x4e14011a}},	//   ейле, хиле, мець_, _נחשב_, 
   {{0x78a82595,0xdd900e56,0xf804a4c9,0xd7740e56}},	//   rugv, _جوڭ_, ьчен, راتع, 
   {{0x76580790,0x7d0801bf,0xdb040332,0xdb240241}},	//   tmuy, øgsf, rfhó, _àsày, 
   {{0x9b34010a,0x00000000,0x00000000,0x00000000}},	//   ăхăш, --, --, --, 
   {{0xe7e010eb,0x765805d1,0xa898004e,0x69d801f9}},	//   _गोवा_, rmuy, _окту_, _नोटी, 
   {{0x69dc013f,0x387c0381,0xa934084c,0x6e241418}},	//   _ɔrem, _itur_, _реуш, ziib, 
   {{0x53a4013e,0xc7d40375,0x0ecc033f,0x6e241418}},	//   _ҷалб, _רועי_, _हैंड, yiib, 
   {{0x10a405c2,0x6e240050,0x9f880162,0x2451c6d2}},	//   нимн, xiib, _sóðu_, ràma_, 
   {{0x05941370,0xe8e0063f,0x6e2404ba,0x53a401c6}},	//   _سانگ, vaịs_, viib, _залб, 
   {{0x386806af,0xb4a80ebb,0x20540138,0x00000000}},	//   _écru_, गढी_, втср, --, 
   {{0x6e242f99,0x9f8803b2,0xddcc0118,0x63b80419}},	//   tiib, _vóðu_, lmař, žaný, 
   {{0x387dc6d3,0xa2a493cb,0x00000000,0x00000000}},	//   _otur_, _कित्, --, --, 
   {{0x6e25c6d4,0x62a400e2,0x6ac8146b,0x8d7400cf}},	// [326a0] riib, ītoš, रब्र, _ۋاحا, 
   {{0x6e25a6cd,0x00000000,0x00000000,0x00000000}},	//   siib, --, --, --, 
   {{0x387dc6d5,0x6e2492fa,0x06780116,0xc0000024}},	//   _atur_, piib, _ﻧﺎﻫﯩ, _спэк, 
   {{0xaca401f2,0x387c003e,0x2bac01bc,0x6e240009}},	//   _ajụr, _btur_, _चाका, qiib, 
   {{0xdb14002f,0x29000356,0xdb05c6d6,0xe3c0010e}},	//   _abzä, âia_, rghá, lkıň_, 
   {{0x8c45c6d7,0x629c01d3,0x00000000,0x00000000}},	//   _чеге, árok, --, --, 
   {{0x387dc6d8,0x00000000,0x00000000,0x00000000}},	//   _etur_, --, --, --, 
   {{0xe7e006ab,0xd90c01ed,0x629c00e2,0xbb404eab}},	//   _गोरा_, _ڈیم_, šrok, _сеск, 
   {{0xd90c030f,0xf77c0139,0x00000000,0x00000000}},	//   _ویم_, _şçe_, --, --, 
   {{0xf8a40451,0x4cc800eb,0x00000000,0x00000000}},	//   _سگهه_, রিপু, --, --, 
   {{0x46a473e6,0x32b401c6,0x27ec00a2,0xb0040055}},	//   _чаев, нгээ_, _indn_, _saḿv, 
   {{0x75d00a2c,0xdb2001d3,0x00000000,0x00000000}},	//   _ميما, ütés, --, --, 
   {{0xf2c0005e,0x7ff40075,0xc05800d6,0xc5140ee8}},	//   _ұсын, ىسسا, зів_, _ثبات, 
   {{0xf1c40306,0x84580139,0x02b0014b,0x00000000}},	//   _prší_, _эрет_, _бикӯ, --, 
   {{0xdd9402d5,0xe0d0009e,0x00000000,0x00000000}},	//   кавы, ামেন, --, --, 
   {{0x3ebc0327,0x00000000,0x00000000,0x00000000}},	//   ċut_, --, --, --, 
   {{0xbcf80e47,0xae4400db,0x00000000,0x00000000}},	// [326b0] _ngét, اپقو, --, --, 
   {{0x61ec1a53,0xe7e00d2e,0x00000000,0x00000000}},	//   _hnal, _गोला_, --, --, 
   {{0x387dc6d9,0x3a2c0175,0x00000000,0x00000000}},	//   _stur_, tngp_, --, --, 
   {{0xaed4004e,0x00000000,0x00000000,0x00000000}},	//   _союш, --, --, --, 
   {{0x61ecafe6,0x3f90009d,0x645800c5,0x387c022e}},	//   _mnal, _kexu_, _ohvi, _qtur_, 
   {{0x07a001c4,0x00000000,0x00000000,0x00000000}},	//   аашн, --, --, --, 
   {{0x61ecaa24,0xe7e00490,0x00000000,0x00000000}},	//   _onal, _गोळा_, --, --, 
   {{0x69dc0134,0x61ec2252,0x387d88ec,0x3f91c6da}},	//   _ɔrek, _nnal, _ttur_, _lexu_, 
   {{0xa3ac08e6,0x4f280092,0x1c040073,0x00000000}},	//   गलं_, ደሚደር, _शकाल_, --, 
   {{0x61edc6db,0x130834d8,0x2b9c0316,0x6459c6dc}},	//   _anal, дной_, mácí_, _chvi, 
   {{0x15b80dd8,0x38b9c6dd,0xd5d40166,0x67b802f2}},	//   _жылы_, lêr_, _аюлы, _سالح_, 
   {{0x52d0000d,0x00000000,0x00000000,0x00000000}},	//   _तनीस, --, --, --, 
   {{0x38b863cd,0x7f9c00fd,0x00000000,0x00000000}},	//   nêr_, _oçqı, --, --, 
   {{0x61edc6de,0x93443c1a,0xddcc010e,0xe7c407b7}},	//   _enal, _инле, llaň, ल्पप, 
   {{0xb9005078,0x3f900de2,0xdb042bd5,0xb8e00327}},	//   _ཨན_, _dexu_, nghä, _ཏད_, 
   {{0x6458069c,0xbcf80c6a,0x7f9c0166,0x61ec0010}},	//   _zhvi, _ngés, _açqı, _gnal, 
   {{0x38b8002d,0x8d640410,0x4cc80154,0x4d640006}},	// [326c0] jêr_, твае, রিভু, ткав, 
   {{0x61eda26a,0x38b8002d,0xc0e0030d,0x00000000}},	//   _znal, dêr_, _тоьк, --, 
   {{0x66e8013f,0xaee400cd,0x61ec01d5,0xbf980a7c}},	//   bɛky, _kaṭu, _ynal, _קיטש, 
   {{0x8d74eac4,0x79a0023a,0xfaa002d5,0x38b80142}},	//   _جادا, арше, рацо, fêr_, 
   {{0x69dc016b,0x38b8030a,0xa2d8012d,0x00000000}},	//   _ɔreh, gêr_, _फैन्, --, 
   {{0xbcf8066d,0xdb200030,0x60c805d1,0xc7640c50}},	//   _egés, štát, çemi, پاتى, 
   {{0x48ec006d,0x59dc34f8,0x5b340276,0x69c400cf}},	//   _आपको_, _नोकर, _бэту, _бөлб, 
   {{0x998c00fd,0xe0c800cc,0x80a001f9,0x7f38011a}},	//   _imeş_, শিতভ, _कटले, ועצו, 
   {{0x61ec1529,0xbdd80100,0x27ec004d,0x00000000}},	//   _rnal, _chèy, _tndn_, --, 
   {{0x61ec1b24,0x27f80037,0x62840153,0x00000000}},	//   _snal, _õrn_, _čiob, --, 
   {{0xa1956325,0x06780952,0xaee400b8,0x867400c7}},	//   ланч, _ﻧﺎﻣﯩ, _baṭu, _рызц, 
   {{0x3f91c6df,0xaee40055,0xba9802e4,0x00000000}},	//   _sexu_, _caṭu, וסטי, --, 
   {{0x61ec04cc,0x50a00116,0x00000000,0x00000000}},	//   _vnal, مەيل, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbcf80694,0x7fd40220,0x22a4013e,0x5f4402c9}},	//   _ngér, ніңі, _сулҳ, انزل, 
   {{0x61edc6e0,0x81d40154,0x00000000,0x00000000}},	//   _unal, সাহ_, --, --, 
   {{0x5d541d1c,0xbcf801e1,0xe39001fb,0x66e80605}},	// [326d0] укат, _agér, _điề, rɛky, 
   {{0x9b95c6e1,0x78b801d5,0xdfd0ef10,0x38b8017a}},	//   الات, _rquv, _ايد_, vêr_, 
   {{0x20000652,0x3b640107,0x7d0801bf,0x00000000}},	//   _iohi_, тъав, øgsb, --, 
   {{0x200000b0,0x38b9c6e2,0x00000000,0x00000000}},	//   _hohi_, têr_, --, --, 
   {{0x2001c6e3,0xbcf801d3,0x17c8bf77,0x00000000}},	//   _kohi_, _egér, егли_, --, 
   {{0x2000b866,0x38b93b12,0x2b9c00bc,0x00000000}},	//   _johi_, rêr_, rácí_, --, 
   {{0x20000053,0xa2a41a55,0xf1a4000d,0x00000000}},	//   _mohi_, _किष्, _खएलन, --, 
   {{0x2001c6e4,0xdb04007c,0x34a00107,0xfbb02c2e}},	//   _lohi_, gghå, агиҳ, ुभवम, 
   {{0x78b801a9,0x2ee000c5,0x95240066,0x00000000}},	//   _uquv, _पछ्त, دکام, --, 
   {{0x2249c6e5,0xa2a406ab,0x20000ba7,0x00000000}},	//   _akak_, _किश्, _nohi_, --, 
   {{0x7f540175,0xe7f002db,0x63bc0192,0xaee400cd}},	//   _nzxq, चारा_, òrna, _paṭu, 
   {{0xa2a40954,0xb9fc0092,0x00000000,0x00000000}},	//   _किर्, _ሁኑ_, --, --, 
   {{0x20000564,0x7bc55c83,0x0ccc0154,0x96b001af}},	//   _bohi_, _obju, _রপ্ত, _төҙє, 
   {{0xdb1406af,0x00000000,0x00000000,0x00000000}},	//   _eczé, --, --, --, 
   {{0x045447ea,0x200001c7,0x3ea0004e,0x00000000}},	//   _حلوة_, _dohi_, йирг, --, 
   {{0x7bc4198f,0x2248020c,0x918000db,0xd72003d4}},	//   _abju, _gkak_, _دۇحۇ, _পুৱা_, 
   {{0x20000418,0x629c2b57,0x229800bc,0x7ae003b2}},	// [326e0] _fohi_, árov, _týká_, æntn, 
   {{0x200001a9,0x00f4123b,0x00000000,0x00000000}},	//   _gohi_, _עזים_, --, --, 
   {{0x81d400bd,0x09e41ea2,0xbdd800f2,0xaca40241}},	//   সার_, ложн, _okèh, _ikọr, 
   {{0xe984af86,0x02b4008f,0x4ea4035b,0x2abc0332}},	//   рқан, טלעך_, _ирҭа, ríb_, 
   {{0xfaa016c3,0xba14007b,0x00000000,0x00000000}},	//   _қато, دينا_, --, --, 
   {{0xa2a40574,0xbdd80214,0x8b645a05,0xc794e7b1}},	//   _किल्, _akèh, _مازم, урды, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfa65c6e6,0xddcc01e4,0xca3400d1,0x00000000}},	//   _баск_, kmaŝ, ﺗﯩﺶ_, --, 
   {{0x625c0129,0xdb04002f,0x0ca000bc,0x00000000}},	//   léog, ufhö, _ओटोम, --, 
   {{0xd90c04d3,0x2248005c,0xb90001a9,0x00000000}},	//   _تیه_, _skak_, _узук, --, 
   {{0xc3044bcf,0x2001c6e7,0x06840b7e,0x625c003e}},	//   ابخو, _rohi_, _сген, néog, 
   {{0xaca4ba77,0xdb043262,0xddcc01e4,0x6f1c01ef}},	//   _akọr, pfhö, fmaŝ, dzrc, 
   {{0xbcf80098,0x75d0e137,0xddcc0115,0x81d400eb}},	//   _ngép, _دينا, gmaŝ, সাল_, 
   {{0xefc0044e,0x437400fb,0x00000000,0x00000000}},	//   _ስቓይ_, _судт, --, --, 
   {{0x20000109,0x7bc4007c,0x00000000,0x00000000}},	//   _vohi_, _rbju, --, --, 
   {{0x62880395,0x2001c6e8,0xddcc01e4,0x00000000}},	//   mpdo, _wohi_, bmaŝ, --, 
   {{0x2001c6e9,0xfba8412c,0x628801e4,0x27fc0175}},	// [326f0] _tohi_, етей_, lpdo, kjvn_, 
   {{0x60cdc6ea,0x26cc0ba7,0x629c0118,0x62880254}},	//   _ipam, _opdo_, šrou, opdo, 
   {{0x625c003e,0xc10000f1,0x00000000,0x00000000}},	//   géog, _خوښي, --, --, 
   {{0x60cdc6eb,0x00000000,0x00000000,0x00000000}},	//   _kpam, --, --, --, 
   {{0x26cc0280,0x60cc00b5,0xdb0406ea,0x626800cd}},	//   _apdo_, _jpam, nghú, _aśok, 
   {{0x60cdc6ec,0xd7043085,0x7bc402d0,0x00000000}},	//   _mpam, изли, _ubju, --, 
   {{0x60cc0055,0x00000000,0x00000000,0x00000000}},	//   _lpam, --, --, --, 
   {{0x60cdc6ed,0x46e40395,0x44d40210,0x00000000}},	//   _opam, рдън_, _bł_, --, 
   {{0x62886c2b,0x7e6c0115,0x7e7401c7,0xdcfc00de}},	//   epdo, _micp, _luxp, _iesē, 
   {{0x72a00131,0x942411eb,0xe4c81b80,0x245000a3}},	//   مەتن, рмое, ابين_, nàmh_, 
   {{0x60cdc6ee,0xd2a80395,0x00000000,0x00000000}},	//   _apam, ъкне_, --, --, 
   {{0x7e6c01c3,0x8620004b,0xddcc0115,0x6594009d}},	//   _nicp, _وکيل, tmaŝ, _гацу, 
   {{0xaca4063f,0x5154f7c9,0x44d4012d,0xdb04032e}},	//   _kwụt, ртну, _gł_, gghú, 
   {{0xddcc00df,0xd1e40014,0x8e840108,0x09d000cd}},	//   rmaŝ, اکژٔ_, игге, _सस्य, 
   {{0x44d414cf,0x60cdc6ef,0x2c6c0248,0xddcc00df}},	//   _zł_, _epam, _lódì_, smaŝ, 
   {{0x7e6c0407,0xdcfc00e2,0xd180002b,0x00000000}},	//   _cicp, _nesē, _nāḍī_, --, 
   {{0xfce00323,0x629c02f0,0x00000000,0x00000000}},	// [32700] оото, šrot, --, --, 
   {{0x625c0129,0x81d40154,0x4f240108,0x4f084109}},	//   téog, সাঃ_, _вдоб, _анон_, 
   {{0x76480007,0xdef84077,0xe7e001ad,0xbb880150}},	//   _okgy, _быў_, _गोगा_, _ﺗﯘﻛﻪ_, 
   {{0xda643092,0x4a45234c,0xe0c80154,0x39e401f0}},	//   ماني, шнев, শিরভ, идхо_, 
   {{0x093404fb,0x6edc033f,0x3150010c,0xae9401e1}},	//   جراج, _पनडु, _መንበር, _mẹmb, 
   {{0x7648010e,0xc6a5c6f0,0x67d47734,0xa7b9234c}},	//   _akgy, арии, соку, улку_, 
   {{0xfaa066b5,0x7aa09fcc,0xd90cc67c,0x2ca1c6f1}},	//   _маро, _мирз, ویہ_, lsid_, 
   {{0x2d80d193,0x88845569,0x2ca06931,0x00000000}},	//   ncie_, _влаж, osid_, --, 
   {{0x2ca1c6f2,0x63bc01ab,0x2d800210,0x00000000}},	//   nsid_, òrno, icie_, --, 
   {{0xe3b9c6f3,0x2a7800c5,0x2ca1c6f4,0x4ab89ea0}},	//   lnız_, _kurb_, isid_, _उमाव, 
   {{0x2d80bdcd,0xae9401e1,0xe3d8009e,0x26cc017a}},	//   kcie_, _bẹmb, তালব, _updo_, 
   {{0x2ca0033d,0x2d800034,0x2a791546,0x60cc04ba}},	//   ksid_, jcie_, _murb_, _ppam, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2d80068f,0x2ca000af,0x629c01ed,0xd58403e6}},	//   ecie_, dsid_, áros, _پێیه_, 
   {{0x2ca0000d,0x2d800210,0xddcc00a2,0x00000000}},	//   esid_, fcie_, gmaş, --, 
   {{0x6449c6f5,0xfe7430af,0xe3b8456f,0x00000000}},	//   lodi, лүү_, lgı_, --, 
   {{0x60cdc6f6,0x69dc0134,0x7e6c010f,0xc32c0145}},	// [32710] _upam, _ɔret, _vicp, _رەڭ_, 
   {{0x6449c6f7,0x80ac02f5,0x2a780477,0xe3b800fd}},	//   nodi, য়বদ্, _burb_, ngı_, 
   {{0x2a787785,0x2ca1c6f8,0x245001ab,0x2c6c0248}},	//   _curb_, asid_, ràmh_, _sódì_, 
   {{0x6449c6f9,0x2d81c6fa,0x2ca00585,0x625ca8d8}},	//   hodi, ccie_, bsid_, léob, 
   {{0x2ca1c6fb,0x00000000,0x00000000,0x00000000}},	//   csid_, --, --, --, 
   {{0x96940e92,0xac954da4,0x6449c6fc,0xcc74011a}},	//   бриш, _фарш, jodi, _לגשת_, 
   {{0x2a7806b6,0xd6280b7e,0x00000000,0x00000000}},	//   _gurb_, локе_, --, --, 
   {{0xe7083955,0x987400d8,0x00000000,0x00000000}},	//   شتىن_, _глац, --, --, 
   {{0x6449c6fd,0x14243946,0x942411ca,0xc480010b}},	//   fodi, йдим, ймие, плык, 
   {{0x2d80012d,0x7d1800ee,0x00000000,0x00000000}},	//   zcie_, _ýusu, --, --, 
   {{0x8c180302,0x2d800034,0x625c0129,0x91e4014b}},	//   רותי, ycie_, déob, боне, 
   {{0x2ca0273f,0x76480007,0x659400db,0x00000000}},	//   ysid_, _ukgy, _ۇجۇر, --, 
   {{0xd131c6fe,0x200401d5,0x00000000,0x00000000}},	//   سمس_, аli_, --, --, 
   {{0x6449c6ff,0x2d80012d,0x46ac00bc,0x00000000}},	//   codi, wcie_, _टिमह, --, 
   {{0x2ca07e04,0xe3b80166,0x2d800210,0x00000000}},	//   wsid_, jnıy_, tcie_, --, 
   {{0x2ca1c700,0x69dc016b,0xddcc6887,0xe3b80166}},	//   tsid_, _ɔres, rmaş, dnıy_, 
   {{0x2d81c701,0x09d4015b,0x2ca00037,0x00000000}},	// [32720] rcie_, _সচলা, usid_, --, 
   {{0x2ca1c702,0xcb68013d,0x2d81c703,0x00000000}},	//   rsid_, газе_, scie_, --, 
   {{0x2ca1c704,0x4e286135,0x2d808763,0xc9852a73}},	//   ssid_, _бонн_, pcie_, були, 
   {{0x6449c705,0xe3b800fd,0x2ca1c706,0x00000000}},	//   zodi, zgı_, psid_, --, 
   {{0x28f85976,0x6449c707,0xe3b81918,0xe8f801e0}},	//   рель_, yodi, ygı_, шһа_, 
   {{0xe73003e6,0x64481eca,0xe3b80139,0x00000000}},	//   وڵا_, xodi, bnıy_, --, 
   {{0x09e4892e,0x07a400c7,0x368401c4,0x00000000}},	//   _ловн, _ҳазн, бсын_, --, 
   {{0x6449c708,0xe3b80166,0x00000000,0x00000000}},	//   wodi, lnıx_, --, --, 
   {{0x38c98fbc,0x07a53c42,0x693447e5,0x7d18010e}},	//   _مالی_, _газн, _بکار, _ýust, 
   {{0xb904004b,0x00000000,0x00000000,0x00000000}},	//   _دښمن_, --, --, --, 
   {{0x6449c709,0xe3b8247e,0xf51401b9,0x26d9c70a}},	//   rodi, rgı_, لتیش_, _èro_, 
   {{0x6449c70b,0xb7c00311,0x625c0129,0xbb38010f}},	//   sodi, ăţea, déoc, רעטי, 
   {{0x6449c70c,0x04441a21,0xa2a407f7,0xb6c0004e}},	//   podi, _ледн, _किक्, _дөөд, 
   {{0xdddc010f,0xeff402d3,0x60180268,0x200405f7}},	//   _disŝ, _ልበይ_, _sìmb, ðli_, 
   {{0x3da40026,0xe3b80139,0x00000000,0x00000000}},	//   йраб, dnıx_, --, --, 
   {{0x7d0801bf,0x00000000,0x00000000,0x00000000}},	//   øgso, --, --, --, 
   {{0xdddc01e4,0xdb983e0c,0x7c641867,0x7c94007b}},	// [32730] _gisŝ, ивач_, مائل, إشرا, 
   {{0x5ed5114a,0x00000000,0x00000000,0x00000000}},	//   _джоу, --, --, --, 
   {{0x02b419cc,0x00000000,0x00000000,0x00000000}},	//   _अमोन, --, --, --, 
   {{0xb2b8010f,0x9cf40024,0x00000000,0x00000000}},	//   רמאר, _дзмі, --, --, 
   {{0xbdd801e1,0xb23c00df,0x00000000,0x00000000}},	//   _ajèg, נעדז, --, --, 
   {{0x18692bcc,0x572475de,0xba74085b,0x315800df}},	//   шали_, يىشك, _هارت, ציגן_, 
   {{0xa2a4134e,0xd6a80066,0xc0e80092,0x00000000}},	//   _किग्, شگام_, _ሄደህ_, --, 
   {{0x7bd5c70d,0x82c4031c,0x0694007b,0x4810013d}},	//   lexu, _ཀྱེའ, آنية_, змәс, 
   {{0x79980b21,0xa5e80032,0x70a8000d,0x37a80117}},	//   _ieuw, слыҡ_, _कटेल, _бтен_, 
   {{0x7bd5c70e,0x799805e4,0x942402dd,0x67640014}},	//   nexu, _heuw, імне, _کُمل, 
   {{0xe6180228,0x76840724,0xd6d80345,0x00000000}},	//   рдө_, _sıyf, _خواش_, --, 
   {{0xa37c01e4,0x90c4117e,0xd1b800f7,0xd5dc0210}},	//   rdĵa, обме, جادا_, _मसिज, 
   {{0x79980098,0x461003e6,0xdb140112,0x53a5c70f}},	//   _meuw, _زوور, _abzü, _далб, 
   {{0x7998ebf1,0x7684013d,0x00000000,0x00000000}},	//   _leuw, _cıyg, --, --, 
   {{0x7bd5c710,0xb8d80327,0x2bd80037,0x00000000}},	//   dexu, _ཇཀ_, ड़सा, --, 
   {{0xf7280020,0x7999c711,0xd5f8010f,0x00000000}},	//   _እንድን, _neuw, ספּר, --, 
   {{0x8f743334,0x00000000,0x00000000,0x00000000}},	// [32740] _муні, --, --, --, 
   {{0x80d40034,0xd13c001f,0x29187106,0x3f80025c}},	//   यबरे, _ያስታው, _āra_, ccju_, 
   {{0x79980184,0x41b001d3,0xe6b81cd2,0x00000000}},	//   _beuw, _عمیر, _इमेज, --, 
   {{0xdcfc0006,0x76840790,0x2bd800e1,0x98a80790}},	//   _nesė, _mıyd, ड़हा, çağ_, 
   {{0x92d4015b,0x49a40032,0xc7b802d5,0x7999c712}},	//   সময়_, быҙғ, аёй_, _deuw, 
   {{0x79980cf9,0xdb4c04d3,0x7d0801e6,0x13e0015b}},	//   _eeuw, _ڵێن_, ägse, বাড়, 
   {{0x6b9c04c4,0xa71400d4,0x00000000,0x00000000}},	//   _ierg, ямкі, --, --, 
   {{0x6b9dc713,0x799800d5,0x2bd805f9,0xdcec3535}},	//   _herg, _geuw, ड़वा, ncağ, 
   {{0x07a4b258,0x6b9dc714,0x69c0496e,0x87d400ec}},	//   _маан, _kerg, _icme, _وٺرا, 
   {{0x6b9c7e82,0x2fd8037e,0x82c4025c,0x68e0022e}},	//   _jerg, jerg_, _ཀྱུའ, _ismd, 
   {{0x6b9dc715,0xb4e002a0,0x04f8015b,0x7684008e}},	//   _merg, कटॉप_, ইনের_, _cıyd, 
   {{0x6b9cc289,0x76840139,0x00000000,0x00000000}},	//   _lerg, _sıyg, --, --, 
   {{0x6b9dc716,0x69dc013f,0x30e401ec,0x00000000}},	//   _oerg, _ɔrep, мірб, --, 
   {{0x6b9dc717,0x7d089069,0x2fd80083,0x00000000}},	//   _nerg, øgsm, gerg_, --, 
   {{0x2d8802e3,0x69c00334,0xdd94f265,0x24bc009e}},	//   _ọlị_, _ocme, забы, _অনিহ, 
   {{0xbdd801e1,0x6b9dc718,0x9f40525e,0x7bd40472}},	//   _akèr, _aerg, _jahé_, wexu, 
   {{0xc05810f5,0x79980438,0x9f41c719,0x7bd40393}},	// [32750] _він_, _reuw, _mahé_, texu, 
   {{0x6b9dc71a,0xa2a40882,0x69c1c71b,0x79980098}},	//   _cerg, _किञ्, _acme, _seuw, 
   {{0x6b9dc71c,0x79980810,0x34b4012c,0xbcf800e5}},	//   _derg, _peuw, _आम्द, _széd, 
   {{0x6b9dc71d,0x9f4002fb,0x00000000,0x00000000}},	//   _eerg, _nahé_, --, --, 
   {{0x6b9dc71e,0xe0c800fe,0xd94452d1,0x00000000}},	//   _ferg, শিকভ, џели, --, 
   {{0x3ab81060,0x6b9dc71f,0x79980069,0x5a240014}},	//   _پاسخ_, _gerg, _weuw, _کفرٕ, 
   {{0x1995c720,0x9f400098,0x09c0015b,0x7998003e}},	//   _навя, _bahé_, োয়া, _teuw, 
   {{0x6b9dc721,0xbcf8114f,0x186800d1,0x00000000}},	//   _zerg, _izéb, шаһи_, --, 
   {{0x6b9c036b,0xf7280092,0x7684013d,0x00000000}},	//   _yerg, _እንዲን, _sıyd, --, 
   {{0x6b9c0077,0x270c013f,0x452401e0,0xdcec03e0}},	//   _xerg, wɛne_, яжын_, zcağ, 
   {{0xd759c722,0x557418ce,0xef20068f,0xd1740fca}},	//   _الات_, _егет, ążki_, зыгы, 
   {{0x76840166,0xf4f40014,0xcb10010f,0x2fd83ce6}},	//   _cıye, _وواں_, גלט_, werg_, 
   {{0x2fd8e187,0x768403e0,0x217421f3,0x926800c7}},	//   terg_, _dıye, дурр, ирҭа_, 
   {{0xf72800b7,0xb4d4924b,0x65343695,0x7684013d}},	//   _እንዳን, ाबी_, _ترمذ, _tıyd, 
   {{0x625c0ffb,0x6b9c0139,0x00000000,0x00000000}},	//   méon, _rerg, --, --, 
   {{0x6b9dc723,0xbdd9aa3c,0x32640014,0x82c40327}},	//   _serg, _ajèb, _تنبہ, _ཀྱིའ, 
   {{0x1fd0009e,0x19e40150,0xfc3c08a5,0xd0280092}},	// [32760] ায়স, _ﺍﻵﻫﻠ, _svía_, ደማይሆ, 
   {{0x69c004cc,0x26182dfb,0x2a98007f,0x00000000}},	//   _scme, _néon_, tōb_, --, 
   {{0x6b9c3d42,0xf4d400cc,0x76840205,0xb4d40118}},	//   _verg, _তপোব, _yıye, ाबु_, 
   {{0x6b9dc724,0x2d840022,0x7d08007c,0xc278011a}},	//   _werg, _üme_, ägsc, צרני, 
   {{0x6b9dc725,0x3a3c39c3,0x9f400066,0x99e80f11}},	//   _terg, _djup_, _rahé_, تعلق_, 
   {{0xbcf8020c,0x25a13542,0x8c1806f6,0x6b9d16f6}},	//   _ngéy, _žil_, _ايسر_, _uerg, 
   {{0xbb4002f6,0x3684112a,0x443808a9,0x00000000}},	//   _зерк, псын_, _ıp_, --, 
   {{0xbb3806a9,0x3160022e,0x3a3c0051,0xb4d40c70}},	//   _העלי, _oziz_, _gjup_, ाबू_, 
   {{0x9f400270,0xa2a40303,0x00000000,0x00000000}},	//   _vahé_, _किङ्, --, --, 
   {{0xfd1c01e1,0x00000000,0x00000000,0x00000000}},	//   _ofìn_, --, --, --, 
   {{0xe1d810f5,0x3161c726,0xae1c0a17,0x047401d5}},	//   одні_, _aziz_, नसान_, _کلتک_, 
   {{0x7d0808fb,0xa15800c0,0x00000000,0x00000000}},	//   øgsk, жаму_, --, --, 
   {{0xd6250cd1,0xf1a49383,0x60dc5613,0x625c003e}},	//   _تعلي, эрэн, uwsm, béon, 
   {{0x02a40440,0xd49800d4,0xe454008e,0x00000000}},	//   _ерим, _єрі_, _юклы, --, 
   {{0x442dc727,0x316000ee,0x00000000,0x00000000}},	//   _imf_, _eziz_, --, --, 
   {{0xc1b00184,0xdb04002f,0x00000000,0x00000000}},	//   _яҙмы, rghü, --, --, 
   {{0x5d55c728,0x442c05da,0xdcfc00ef,0x30a40153}},	// [32770] фкат, _kmf_, _iesī, _прэв, 
   {{0xefbc0201,0x442c5794,0x00000000,0x00000000}},	//   ታቸው_, _jmf_, --, --, 
   {{0x442c0960,0xf41000df,0x9e840244,0x00000000}},	//   _mmf_, עפע_, _تاخۆ, --, 
   {{0x442c0175,0x99340244,0xeab0007b,0xfe2423be}},	//   _lmf_, وفات, اعل_, _хьон, 
   {{0xcdc00116,0x3cfc0166,0x00000000,0x00000000}},	//   _шәрп, _çuv_, --, --, 
   {{0x442c03cd,0x76840139,0xf8040815,0x00000000}},	//   _nmf_, _rıyb, ячен, --, 
   {{0xb86400e5,0x00000000,0x00000000,0x00000000}},	//   _ہائو, --, --, --, 
   {{0xdcfc00de,0x00000000,0x00000000,0x00000000}},	//   _nesī, --, --, --, 
   {{0x442c6144,0x395c00df,0xb4d400e1,0x76840166}},	//   _bmf_, _uzus_, ाबे_, _qıyb, 
   {{0x52a95dc7,0xd3780137,0xd2a9c729,0xaf780023}},	//   овом_, өчү_, окое_, ጭታትና_, 
   {{0x3990006a,0x387dc72a,0xfbcc0b9a,0x442c03e3}},	//   _gûsâ_, _huur_, स्यम, _dmf_, 
   {{0x387dc72b,0x15141e28,0x76840139,0x10a401d5}},	//   _kuur_, _одея, _tıyb, мимн, 
   {{0x442dc72c,0x95b40184,0x625c003e,0x387dc72d}},	//   _fmf_, _ерҙә, péon, _juur_, 
   {{0x387ca6d8,0xd838007f,0xa2d81d15,0x2258002d}},	//   _muur_, _dwōg_, _फैक्, alsk_, 
   {{0xb8dc025c,0x387c25d9,0x9344ae2e,0x04400166}},	//   _ཀའ_, _luur_, _юнке, _шешн, 
   {{0x625c020c,0x00000000,0x00000000,0x00000000}},	//   néol, --, --, --, 
   {{0x387dc72e,0x4f953fe1,0x316001a9,0x00e06391}},	// [32780] _nuur_, _орну, _uziz_, _ажын, 
   {{0xa7fc06be,0xbcf801d3,0x00000000,0x00000000}},	//   _ahın, _széc, --, --, 
   {{0x0e6483c0,0x625c0264,0x9a8402dd,0xfaa0bbb8}},	//   _окон, kéol, еуіл, вахо, 
   {{0x387c1574,0xfc3c0a87,0x2004007c,0x00000000}},	//   _buur_, _hvíl_, öliv_, --, 
   {{0x02d800ce,0xb4d400e1,0x625c0129,0x00000000}},	//   _बन्न, ाबो_, déol, --, 
   {{0x387dc72f,0xc6140a28,0x1acc0154,0x5b980150}},	//   _duur_, तस्य_, রয়ো, _ﺘﺩﻓﻊ_, 
   {{0xd73402d3,0x7a34063f,0xddcc0165,0x442c012d}},	//   _እንከሎ, ụtaa, blań, _rmf_, 
   {{0x387c0de2,0x81d0015b,0x625c7dec,0xd6d80212}},	//   _fuur_, _হোন_, géol, яті_, 
   {{0x47c415ed,0x442dc730,0x387dc731,0xdcfc00ef}},	//   _обав, _pmf_, _guur_, _resī, 
   {{0x936002d3,0x786000a8,0x3cf808a8,0x4ad00a59}},	//   _ቋንቋታ, _акуз, קלינ, _सहाव, 
   {{0x442dc732,0x2259c733,0x387c0d27,0xe2f802bf}},	//   _vmf_, зины_, _zuur_, чені_, 
   {{0x442dc734,0x2618003e,0x387c00e8,0xa5c40139}},	//   _wmf_, _kéom_, _yuur_, _чөке, 
   {{0x7ff402f2,0xa3b40024,0xc5140244,0x00000000}},	//   وسسا, _зблі, _تبات, --, 
   {{0x442dc735,0x8ca0033f,0x768403e0,0x00000000}},	//   _umf_, गठनो, _hıya, --, 
   {{0x443dc736,0x768504ff,0xe6ddc737,0x42500014}},	//   mnt_, _kıya, _मनोज, _لۆدر, 
   {{0xf1d00016,0x273801e4,0x00000000,0x00000000}},	//   _hạng_, _mɩn_, --, --, 
   {{0x443dc738,0x2d587724,0x5cb80953,0x3cfc01f9}},	// [32790] ont_, дить_, ялаў_, रमधे_, 
   {{0x443dc739,0x387c00e8,0x00000000,0x00000000}},	//   nnt_, _ruur_, --, --, 
   {{0x443dc73a,0xf1d007ae,0x387c007d,0x00000000}},	//   int_, _mạng_, _suur_, --, 
   {{0x443c0639,0x387dc73b,0xf1d001fb,0xed5001d3}},	//   hnt_, _puur_, _lạng_, اپے_, 
   {{0x387c003a,0x625c06af,0x443dc73c,0xd7340023}},	//   _quur_, véol, knt_, _እንኮሎ, 
   {{0xb904534e,0x387c2595,0x81d000bd,0x443c0cf9}},	//   _बन_, _vuur_, _হোম_, jnt_, 
   {{0x2aa9c73d,0x443c3c3f,0x00000000,0x00000000}},	//   _отто_, dnt_, --, --, 
   {{0x443dc73e,0x387dc73f,0x7684008e,0x9f4000d7}},	//   ent_, _tuur_, _cıya, _nahí_, 
   {{0xa9545566,0x443c0008,0x625c06af,0x57d40120}},	//   _акті, fnt_, réol, _поаѓ, 
   {{0x443dc740,0x9f40003e,0x625c0129,0xe7b8014b}},	//   gnt_, _mahâ_, séol, _огуш_, 
   {{0xf1d00016,0x42c401c0,0x2c0000e1,0x768403e0}},	//   _dạng_, нгэн_, रातू_, _fıya, 
   {{0xfbcc0882,0x4ad000ab,0x76847aa0,0x00000000}},	//   स्तम, _सहसव, _gıya, --, 
   {{0xa1540c04,0x443c03d5,0x76580790,0x00000000}},	//   върш, bnt_, mluy, --, 
   {{0x7659c741,0x443ca8cf,0x76840724,0x62842230}},	//   lluy, cnt_, _zıya, _čiov, 
   {{0x7d0801e3,0x00000000,0x00000000,0x00000000}},	//   ägsn, --, --, --, 
   {{0xe6c80724,0xa7fc03b9,0x768400fd,0x90c40798}},	//   şuçı, _ahıl, _xıya, _збие, 
   {{0x3ab05b87,0x2b58020c,0xfe401b30,0xe6dc7ef5}},	// [327a0] һәтт, _syrc_, унто, _मन्ज, 
   {{0x32c40220,0x8b2400c0,0x904401c8,0x00000000}},	//   _ﯨﻠﮕﻪ, ндзе, _سنجه, --, 
   {{0x3ab13298,0xdef80006,0x76582ca8,0xe054085b}},	//   ләтт, _жыў_, kluy, _شیفت_, 
   {{0xda645713,0xe8ec0327,0x00000000,0x00000000}},	//   ناني, _རླུག, --, --, 
   {{0xda7802d3,0x443dc742,0x4784008e,0x629c01d3}},	//   єяє_, ynt_, ныйб, ároz, 
   {{0x6e24089c,0xd90c01b9,0x768408a9,0x8d740116}},	//   lhib, غیل_, _sıya, _ياڭا, 
   {{0x443dc743,0x7659c744,0xf1d0001e,0x7684c8d8}},	//   vnt_, fluy, _rạng_, _pıya, 
   {{0x443dc745,0x2bd800e1,0xb90001e0,0xfaf40375}},	//   wnt_, ड़का, тзәк, _אצלי_, 
   {{0xa4f801d9,0x443dc746,0x5fb00412,0x00000000}},	//   بکار_, tnt_, _जयलल, --, 
   {{0x9f40011f,0x3af404ce,0x25a40165,0x77c4011c}},	//   _sahí_, でpc_, saml_, _плуг_, 
   {{0xa195c747,0x6e25c748,0xf31005f5,0x443c2238}},	//   канч, khib, гдээ, rnt_, 
   {{0x76584e4c,0x443c3c3f,0x7684013d,0x623401f0}},	//   cluy, snt_, _kıyn, тему, 
   {{0x6e25c749,0xf1d001fb,0xb9c802d3,0x00000000}},	//   dhib, _tạng_, _ሳዕ_, --, 
   {{0xb80035d7,0x00000000,0x00000000,0x00000000}},	//   लायम_, --, --, --, 
   {{0x9f400093,0x6e240332,0x7fd40150,0x00000000}},	//   _tahí_, fhib, міңі, --, 
   {{0xb8d0003d,0xd9d403d4,0x00000000,0x00000000}},	//   _དྷ_, _সোনম, --, --, 
   {{0x2004014a,0xdb0426bc,0xdc5400d8,0x00000000}},	// [327b0] ölis_, nghö, ввањ, --, 
   {{0x2bd80034,0x5ff40022,0x0f30036b,0xdb04002f}},	//   ड़गा, _рзоу, اکید, ighö, 
   {{0x9f200075,0x765803e0,0x6e2400dc,0x00000000}},	//   _ئۈزۈ, yluy, bhib, --, 
   {{0x6e25c74a,0x9f400548,0x625c003e,0x5a340395}},	//   chib, _tahâ_, déok, ънет, 
   {{0x260404af,0x2bd805f9,0x7684008e,0x41d000dc}},	//   वानी_, ड़खा, _cıyn, ध्यस, 
   {{0x7c8000fb,0x00000000,0x00000000,0x00000000}},	//   _аҫҡа, --, --, --, 
   {{0xddcc0054,0x765805d1,0x625c003e,0x9984007b}},	//   rlaņ, tluy, géok, _للزو, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9874035b,0x76840724,0x76580342,0xdb04007c}},	//   _алац, _gıyn, rluy, gghö, 
   {{0xa9340261,0x6e2409a8,0x00000000,0x00000000}},	//   _сеуш, zhib, --, --, 
   {{0x86e0021a,0x76580342,0xe4c80244,0x00000000}},	//   _نړيو, pluy, وبین_, --, 
   {{0x6e25c74b,0x80c80f22,0x9fd00154,0x00000000}},	//   xhib, িবন্, াযোগ, --, 
   {{0xc240716a,0xbcf801ed,0x00000000,0x00000000}},	//   рняк, _szén, --, --, 
   {{0xd2b8014d,0xc0e01f5a,0xef3c0092,0x00000000}},	//   _قابض_, јорк, _የቆየው, --, 
   {{0x6e25c74c,0x63bd100c,0x645c0327,0x00000000}},	//   thib, órne, ċrit, --, 
   {{0xfe408354,0x82d4011a,0x7e740166,0x00000000}},	//   ансо, _יוצג_, кәят_, --, 
   {{0x6e25c74d,0xdb04020c,0xc210011a,0xb6040064}},	// [327c0] rhib, lahè, _כהה_, mušė, 
   {{0x6e25c74e,0x00000000,0x00000000,0x00000000}},	//   shib, --, --, --, 
   {{0x26042ecf,0x76840724,0x09e400d4,0x49c8011c}},	//   वामी_, _sıyn, кожн, длен_, 
   {{0xaca402e3,0x6e24014b,0x24d800cc,0x00000000}},	//   _amụr, qhib, তিতহ, --, 
   {{0x92cc00bd,0x7d082d8b,0x7684008e,0xb72000f2}},	//   রিয়_, øgst, _qıyn, یکمه, 
   {{0xf86000d4,0x00000000,0x00000000,0x00000000}},	//   авчо, --, --, --, 
   {{0x29000262,0xfaa04773,0x6f080e78,0x76840790}},	//   ţia_, _васо, ädch, _dıyo, 
   {{0xbb41c74f,0xf64c05d9,0xdb0c00e4,0x9f40032e}},	//   _теск, يئي_, _íháp, _jahá_, 
   {{0x70dc05ba,0xbcf80085,0x046400f7,0xfbcc00dc}},	//   यबोल, _nzél, ктом, स्वम, 
   {{0xd7c802ab,0x1c044721,0xfc3c02d2,0x00000000}},	//   _रायच, रायल_, _rvík_, --, 
   {{0x2bd408e6,0x46a5c750,0x7bc001ab,0x00000000}},	//   ठ्या, _раев, ònui, --, 
   {{0x75d026c0,0x9f4002fb,0x27ec123b,0x00000000}},	//   _نيما, _nahá_, _hadn_, --, 
   {{0xc05810f5,0xa3d5c751,0x00000000,0x00000000}},	//   дів_, _болч, --, --, 
   {{0xb60400c0,0x00000000,0x00000000,0x00000000}},	//   aušė, --, --, --, 
   {{0x9f41c752,0x645800da,0xdb040240,0xfe70f85d}},	//   _bahá_, _ikvi, rahë, لدر_, 
   {{0x33740302,0x41b4000d,0xf1c00419,0x3cfc28fe}},	//   _בתוך_, _अयिस, úšti_, रमले_, 
   {{0x61ec1c06,0xdb040098,0xceb400fb,0x00000000}},	// [327d0] _iaal, mahé, _ҙәр_, --, 
   {{0x61edc753,0x76840139,0x60cdc754,0x26051487}},	//   _haal, _bıyl, _iqam, वाडी_, 
   {{0x76840139,0x7c340175,0x6458045a,0x9e34011c}},	//   _cıyl, rixr, _mkvi, _бенч, 
   {{0x61ec423f,0x63a9c755,0xbcf8003e,0x27ec0009}},	//   _jaal, hadn, _nyég, _aadn_, 
   {{0x61edc756,0x63a9c757,0x2288000f,0xa95402bf}},	//   _maal, kadn, _lûk_, акці, 
   {{0xab95c758,0x61ec947b,0x60cc014b,0xbcf80241}},	//   _вирі, _laal, _mqam, _ayég, 
   {{0xadc40241,0x22880194,0x63a802d1,0x79a4010b}},	//   _ajẹs, _nûk_, dadn, _арзе, 
   {{0x61ec32ff,0x60cdc759,0xdb0400c7,0xfbcc00cd}},	//   _naal, _oqam, jahé, स्रम, 
   {{0x69cc0232,0x60cc0b6f,0xa5e80184,0x64580010}},	//   ílež, _nqam, тлыҡ_, _bkvi, 
   {{0x2288002d,0x63a80827,0xa88400db,0x1308034b}},	//   _bûk_, gadn, _ئللى, еной_, 
   {{0x61edc75a,0x768470f7,0x60cdc75b,0xbcf800dd}},	//   _baal, _kıym, _aqam, _szél, 
   {{0x61ece637,0x64590a95,0x260423ef,0x2288000f}},	//   _caal, _ekvi, वाणी_, _dûk_, 
   {{0x61edc75c,0x63a9c75d,0x62880009,0x00000000}},	//   _daal, badn, aqdo, --, 
   {{0x63a80014,0x2bd8033f,0xd0100014,0xc950011a}},	//   cadn, ड़छा, حلس_, צמם_, 
   {{0x61edc75e,0x60cc0117,0xdb040098,0xee440124}},	//   _faal, _eqam, bahé, иҭои, 
   {{0xc69004ac,0x61ecbb45,0x625c06af,0x4fc000db}},	//   מאל_, _gaal, déow, جەگە, 
   {{0x320002d1,0xaca4063f,0x2605c75f,0xbcf80066}},	// [327e0] _iniy_, _otụt, वाती_, _nyéd, 
   {{0x61ec2252,0xaca401f2,0x24800ba1,0xfce80092}},	//   _zaal, _ntụt, _èime_, _ጅጅጋ_, 
   {{0x61ed1000,0xbcf80ca8,0x9f401132,0x76840139}},	//   _yaal, _ayéd, _tahá_, _qıyl, 
   {{0x61edc760,0x63a8151c,0x76840139,0xf9180014}},	//   _xaal, zadn, _cıym, کرٔژ_, 
   {{0x6018026c,0x0934007b,0x63a8058a,0x00000000}},	//   _sìmi, دراج, yadn, --, 
   {{0x8a04005e,0xcaa42ab5,0x63a81232,0x60d800a2}},	//   _өзге, _مصري, xadn, _äwme, 
   {{0x63a8389e,0xb80431f0,0x320001d5,0x05840075}},	//   vadn, ايىم_, _oniy_, лупм, 
   {{0xa615c761,0x27ec0204,0x2288002d,0x7684013d}},	//   рмич, _wadn_, _rûk_, _gıym, 
   {{0xe3940020,0x61ec0050,0x2ba84540,0x63a9c762}},	//   _የበለጠ_, _raal, गरपा, tadn, 
   {{0x61edc763,0x60cc01d5,0x00000000,0x00000000}},	//   _saal, _rqam, --, --, 
   {{0x61edc764,0x26041ab2,0x82a401ec,0x335400db}},	//   _paal, वादी_, ышпе, лүшө_, 
   {{0x63a88dd4,0x61edc765,0xa17400d4,0x7d08007c}},	//   sadn, _qaal, игні, ägsk, 
   {{0x61edc766,0x645800d7,0xdb040588,0x3664030d}},	//   _vaal, _tkvi, rahé, _сацо_, 
   {{0x61edc767,0x2288000f,0xdb04003e,0x3ee4011c}},	//   _waal, _tûk_, sahé, любв, 
   {{0x61edc768,0xa1950d85,0x73c00372,0xdb04020c}},	//   _taal, _кайч, _ايىم, pahé, 
   {{0x320000e8,0xee8404b4,0x00000000,0x00000000}},	//   _gniy_, сыро, --, --, 
   {{0x60cc0921,0xc0442ad5,0x9cb4aaab,0x00000000}},	// [327f0] _uqam, _مخدو, شمات, --, 
   {{0xb7bc015b,0x7684013d,0x00000000,0x00000000}},	//   _ইস্ট, _sıym, --, --, 
   {{0x22480579,0x20000003,0x316c0210,0x00000000}},	//   _kjak_, _inhi_, ędze_, --, 
   {{0xaab8036b,0x76840dde,0xd8f400d8,0x00000000}},	//   ادلر_, _qıym, изењ, --, 
   {{0x98e40032,0x0524015b,0x28f80212,0x00000000}},	//   рсеһ, মপুর_, лець_, --, 
   {{0x998c0139,0xcc8402f2,0x00000000,0x00000000}},	//   _fleş_, _ئۆله_, --, --, 
   {{0xbdd8007f,0x7ce801e3,0x2248010e,0x76840139}},	//   _skèy, _förå, _ojak_, _tıym, 
   {{0x2249c769,0x067800d1,0x00000000,0x00000000}},	//   _njak_, _ﺧﺎﻧﯩ, --, --, 
   {{0x97340020,0x1425c76a,0x200002c4,0x6b8c143a}},	//   _እንዲስ, идим, _onhi_, _ålgå, 
   {{0x395c0098,0x81d000eb,0x00000000,0x00000000}},	//   _iyus_, _হোল_, --, --, 
   {{0x69cc038e,0x63bc008c,0xe784f7d0,0x00000000}},	//   _हामी, órna, _المپ, --, 
   {{0xd575c76b,0x2000089c,0xdcec0115,0x95740137}},	//   _куль, _anhi_, laaĵ, _кылч, 
   {{0xab640205,0x00000000,0x00000000,0x00000000}},	//   mbüş, --, --, --, 
   {{0x97340020,0x6cb40184,0x00000000,0x00000000}},	//   _እንዳስ, ҙөмт, --, --, 
   {{0xbcf87dec,0x1cc0031c,0x00000000,0x00000000}},	//   _nyéb, _གའུ_, --, --, 
   {{0x224802d3,0x320001a9,0x00000000,0x00000000}},	//   _gjak_, _uniy_, --, --, 
  
   {{0x395c08cd,0xcd0400f7,0x7d08005c,0xc0c00092}},	// [32800] _nyus_, шпай, øgsp, ስቧል_, 
   {{0xdb04019f,0xbb8010a8,0x7ce801e3,0x8b940b01}},	//   rahî, ەلەي, _sörå, ррач, 
   {{0x395dc76c,0xca740220,0xe6d413f5,0xaca40248}},	//   _ayus_, ауды, _दहेज, _ijọr, 
   {{0xe9840046,0x6f1c00ad,0xa37c0115,0x38540214}},	//   сқан, myrc, neĵa, یشود_, 
   {{0x26041092,0xbcf80085,0x76840139,0xda640ada}},	//   वासी_, _eyéb, _fıyk, حالي, 
   {{0x395c03f0,0x8b640244,0x00000000,0x00000000}},	//   _dyus_, _نازم, --, --, 
   {{0xbb40010b,0x09e4f69e,0x7b1400db,0x6f1c03cb}},	//   _дерк, _ковн, _коёр_, nyrc, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x87d8012f,0x6f1c0368,0x36300633,0x00000000}},	//   _لباس_, hyrc, تروس, --, 
   {{0xbcf800dd,0x7d0801e3,0x00000000,0x00000000}},	//   _szék, ägsi, --, --, 
   {{0x23380953,0x05e80276,0xb6c801ed,0xdb140b1a}},	//   упны_, _афли_, _لانے_, åbøn, 
   {{0x6f1c062c,0xfc3c0aab,0x46c40b02,0x00000000}},	//   dyrc, _hvít_, रूणह, --, 
   {{0x03ec045e,0x625c06af,0xd7800023,0x00000000}},	//   জাবী_, déot, _ሓሳብካ_, --, 
   {{0x26040490,0xb4516e8a,0x00000000,0x00000000}},	//   वावी_, _وخوش, --, --, 
   {{0x6f1c0cfd,0xfda4026a,0x224803b2,0x3da42852}},	//   gyrc, ијам, _tjak_, ираб, 
   {{0x224808a4,0xd34403e6,0x1608012d,0x00000000}},	//   _ujak_, _چییه_, वायर_, --, 
   {{0xd344168d,0xbcf8020c,0x76840139,0x6f880a81}},	// [32810] _نییه_, _syéb, _pıyk, انہِ_, 
   {{0x2258030a,0x2bb8007b,0x5a340116,0x00000000}},	//   losk_, لامة_, әндт, --, 
   {{0x19b83119,0x395c00b8,0x00000000,0x00000000}},	//   гуль_, _syus_, --, --, 
   {{0x894c0ca8,0x68e4031c,0x00000000,0x00000000}},	//   _ìfọ̀, ħidn, --, --, 
   {{0x1cc00003,0x26180c6a,0x625c003e,0xdb0400e4}},	//   _གའི_, _léos_, léos, mahí, 
   {{0x7ae4021a,0x945c0054,0xb8fc28fe,0x07a0196c}},	//   _پورې_, kuńa, _तह_, пашн, 
   {{0xdb0c01f4,0x00000000,0x00000000,0x00000000}},	//   äkäl, --, --, --, 
   {{0x1c0413f5,0xd4a401b9,0xd8a8a3a9,0x00000000}},	//   रावल_, биий, _مهرو_, --, 
   {{0xf1c80118,0x22580254,0x00000000,0x00000000}},	//   nkář_, dosk_, --, --, 
   {{0xded40023,0x00000000,0x00000000,0x00000000}},	//   ርሖን_, --, --, --, 
   {{0x26180098,0x7c2400ef,0x260401f9,0x00000000}},	//   _péot_, _mljr, वाशी_, --, 
   {{0xd1b896cb,0xa4440228,0x625c06af,0xa0c40451}},	//   دادا_, йнөд, déos, ڊيٽو, 
   {{0x2605c76d,0x5154eb7f,0x6f1c0368,0xf484008e}},	//   वारी_, стну, wyrc, _туен, 
   {{0xe3b870f7,0x7c240175,0xf1c801ef,0x00000000}},	//   lkın_, _nljr, dkář_, --, 
   {{0xe3b00517,0x2258045f,0xd7f0004d,0x630400f1}},	//   _آره_, bosk_, _mã_, _ووهل, 
   {{0xa8300882,0xe3b80c3c,0xdcfc1cce,0x8b6802a9}},	//   ṇḍal, nkın_, _adsı, қиев_, 
   {{0x270c013f,0x0c25a954,0x82340451,0x0b442cc8}},	// [32820] rɛni_, бман, _درٻا, әнен, 
   {{0x270c0085,0xd6f800cd,0x00000000,0x00000000}},	//   sɛni_, ्माथ_, --, --, 
   {{0xfc3c4f07,0x998c8e70,0xe3b80790,0x8d74ecfe}},	//   _avís_, _smeš_, kkın_, _گادا, 
   {{0x80c803f4,0xddcc0fb9,0x26180098,0xafe40137}},	//   িবর্, mlaş, _léor_, _ايگۉ, 
   {{0x8d75c76e,0xddcdc76f,0xf1c801ef,0x00000000}},	//   _دادا, llaş, ckář_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xddcdc770,0x2604924b,0xd7f00051,0xdee40023}},	//   nlaş, वाली_, _dã_, _ዝኰነ_, 
   {{0x46a4036b,0x88840108,0x00000000,0x00000000}},	//   _ҳажв, _глаж, --, --, 
   {{0x2618020c,0x998c00f3,0xddcd73ff,0x00000000}},	//   _béor_, _umeš_, lmaţ, --, 
   {{0xddcdc771,0x26180113,0xe82401ed,0xa2b435f2}},	//   klaş, _péos_, _بذری, обоч, 
   {{0x04f8015b,0xddcc05d1,0x00000000,0x00000000}},	//   েনের_, jlaş, --, --, 
   {{0x26040574,0xc0c9c772,0xddcc00ac,0x22580104}},	//   वाळी_, луге_, dlaş, римы_, 
   {{0x945c0227,0x5f9401c6,0xe2a001ec,0xd9d400fe}},	//   suńa, жигт, _ﺃﻨﻬﻡ_, _সোঁম, 
   {{0xa2c00882,0xbcf80098,0xd7f0004d,0x133801d3}},	//   _विप्, _nyéa, _xã_, اتیں_, 
   {{0x443dc773,0xdcfc025c,0x644800f1,0x1cc00327}},	//   mit_, _kesħ, mndi, _གའང_, 
   {{0x63b80208,0xf2d000df,0x00000000,0x00000000}},	//   _hdvn, _זעק_, --, --, 
   {{0x6449c774,0x443c1368,0x68e400ac,0x9c3873ad}},	// [32830] ondi, oit_, çidl, апат_, 
   {{0x6449c775,0xddcc0213,0x92cc03d4,0xdb0400e4}},	//   nndi, blaş, ৰিৰ_, sahí, 
   {{0x6449c776,0x443dc777,0x9999c778,0xdb040042}},	//   indi, iit_, لپار_, wahâ, 
   {{0x443dc779,0x1df8049b,0xc1b40406,0xa2c01b61}},	//   hit_, _темы_, _अयोग, _विन्, 
   {{0x443dc77a,0x64480369,0x9f4000d7,0x00000000}},	//   kit_, kndi, _nahú_, --, 
   {{0x443dc77b,0x62982aa3,0x9695c77c,0x64480007}},	//   jit_, _otvo, ориш, jndi, 
   {{0x443dc77d,0xa37c01e4,0xa7fc2ca8,0xe3b8236c}},	//   dit_, deĵo, _ahıs, tkın_, 
   {{0x6448d37e,0x443dc77e,0x63b80334,0xdb040109}},	//   endi, eit_, _advn, mahà, 
   {{0x6449c77f,0xddcdc780,0xb40003cc,0x6299c781}},	//   fndi, zlaş, зүлд, _atvo, 
   {{0x443dc782,0xddcc708d,0x2bcc08e6,0x0454007b}},	//   git_, ylaş, ालया, يلية_, 
   {{0xe3b80790,0x0cc4000d,0x00000000,0x00000000}},	//   pkın_, _लम्म, --, --, 
   {{0x6449c783,0x443dc784,0xd7c80307,0x68e003ac}},	//   andi, ait_, _राँच, _ypmd, 
   {{0x443dc785,0x625c61d0,0x6298022e,0x7658030a}},	//   bit_, téor, _etvo, mouy, 
   {{0x443dc786,0xddcdc787,0xdb1401ed,0x9878008f}},	//   cit_, tlaş, _edzé, יאָט, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xddcd6210,0x0e643981,0x76580433,0x33b00131}},	//   rlaş, ікан, nouy, _بەھر, 
   {{0x81d000bd,0xd7c806e3,0xddcc9c13,0x625c004a}},	// [32840] _হোক_, _रांच, slaş, méop, 
   {{0xddcdc788,0x68e00175,0x625c06af,0x7658062c}},	//   plaş, _rpmd, léop, houy, 
   {{0x68e000f1,0x0ae8516c,0xddcc887f,0x765804ce}},	//   _spmd, рдей_, qlaş, kouy, 
   {{0x443dc789,0xddcc00a8,0x00000000,0x00000000}},	//   zit_, rmaţ, --, --, 
   {{0x443dc78a,0x644883ed,0x28f80ea7,0x7658033b}},	//   yit_, yndi, сель_, douy, 
   {{0x443c0de4,0x6448ec9d,0xa7fc0bbc,0x00000000}},	//   xit_, xndi, _ahır, --, 
   {{0x64481125,0x36848b2d,0xddcc1710,0xdb040798}},	//   vndi, осын_, lmaš, rahã, 
   {{0x270c013f,0x64484019,0x59d001ad,0x7658033b}},	//   dɛnt_, wndi, _हायर, gouy, 
   {{0x62981326,0x625c004a,0x6e242252,0x38c81f70}},	//   _stvo, déop, ikib, _نالی_, 
   {{0x6449c78b,0x443dc78c,0x00000000,0x00000000}},	//   undi, uit_, --, --, 
   {{0x443c2b9d,0xbcf9c78d,0x6e240337,0xfbcc0d0b}},	//   rit_, _nyén, kkib, स्टम, 
   {{0xa2c00490,0x7684008e,0x76580076,0x644801ab}},	//   _विठ्, _cıyu, couy, sndi, 
   {{0xbcf80098,0x644805da,0xdb040109,0x6e240083}},	//   _ayén, pndi, zahà, dkib, 
   {{0x443dc78e,0xc058eeec,0xddcc5d6f,0x6e241418}},	//   qit_, рім_, dmaš, ekib, 
   {{0xdb05c78f,0x629802f0,0xc23401d9,0x855401d3}},	//   kahá, _utvo, _وقتچ_, _دیکر_, 
   {{0x6e241c06,0xdb05c790,0x290001e4,0x00000000}},	//   gkib, vahà, ĥiaj_, --, 
   {{0xacf928c3,0xc05c0092,0xdb0402cc,0x00000000}},	// [32850] онту_, ደረግን_, dahá, --, 
   {{0x1c040c2e,0xdb040109,0x6e241418,0x76580433}},	//   राइल_, tahà, akib, zouy, 
   {{0x2c00069f,0xdd95418f,0x6e380162,0xaa4001e1}},	//   राजू_, _наны, ðabá, _ṣáà_, 
   {{0xdddc01e4,0x6e240fac,0x7d08007c,0x00000000}},	//   _kisŭ, ckib, ägss, --, 
   {{0x8cc006bc,0x98a42692,0x76580481,0x78e991aa}},	//   _लियो, чиле, vouy, рьев_, 
   {{0xf80462bd,0x2bc8023b,0xdb0400c7,0xba740451}},	//   ючен, _мусо_, aahá, _ڀارت, 
   {{0xdb04ec21,0x5ed8015b,0x7659c791,0x00000000}},	//   bahá, ডিকে, touy, --, 
   {{0x199401c6,0xe7309dc7,0xdb040208,0x0f801870}},	//   _хаая, خصه_, cahá, ﯩﺮﯨﯖ, 
   {{0xb6a02f0d,0x76581165,0xa9945837,0x978400fb}},	//   чиқл, rouy, _آشفت, _етеҙ, 
   {{0x6e24009d,0x73f80154,0x00000000,0x00000000}},	//   zkib, েস্ট_, --, --, 
   {{0x625c004a,0x35f8004b,0x28f8084c,0x76591924}},	//   téop, _پرضد_, _леӂь_, pouy, 
   {{0xbcf80098,0x76840166,0x3864002f,0x5ed000eb}},	//   _nyéo, _qıyu, llnr_, াবাই, 
   {{0x85e80014,0x48fc060c,0x461019e2,0xa2c000dc}},	//   _دِنے_, लियो_, _سوور, _विथ्, 
   {{0xd010cb3a,0x16080073,0xdb040f91,0x00000000}},	//   رلز_, वावर_, zahá, --, 
   {{0x0e680597,0xf1d401ad,0x1c0400c5,0x7684008e}},	//   مصري_, _थापन, राईल_, _tıyu, 
   {{0xa2c0216a,0xddcc01fa,0x6e2404ba,0xd174004e}},	//   _वित्, tmaš, ukib, _ныпы, 
   {{0x6e25c792,0x76840166,0x0c244fac,0xdb0400c7}},	// [32860] rkib, _kıys, пман, vahá, 
   {{0x6e25c793,0x80dc045e,0xddcc0b4b,0x3c600120}},	//   skib, মিশ্, rmaš, екуг, 
   {{0xbcf801ed,0xdb04035b,0x00000000,0x00000000}},	//   _szét, tahá, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb05c794,0x88d800ee,0x2bcc01f9,0x00000000}},	//   rahá, сьет_, ालदा, --, 
   {{0x59d00034,0xbcf80129,0x2ca00072,0xdb04fb29}},	//   _हाथर, _myél, mpid_, sahá, 
   {{0xa2c0012a,0x8b65c795,0xa7fc0790,0xfc0001d5}},	//   _विध्, _راسم, _akıc, _япро, 
   {{0xe3b803e0,0x00000000,0x00000000,0x00000000}},	//   rkım_, --, --, --, 
   {{0xbcf9c796,0xdcec0419,0xdb0408a5,0x00000000}},	//   _nyél, zbaľ, gahæ, --, 
   {{0xa2c06352,0x76840166,0x00000000,0x00000000}},	//   _विद्, _cıys, --, --, 
   {{0xbcf80248,0x76840139,0xe3b80205,0x00000000}},	//   _ayél, _qıyt, lkık_, --, 
   {{0x2c740267,0x00000000,0x00000000,0x00000000}},	//   lädd_, --, --, --, 
   {{0xa3d56d3d,0xb3700092,0x00000000,0x00000000}},	//   _жолч, _የዓይን_, --, --, 
   {{0xbdd8020c,0x80dc015b,0x76840166,0x68e40135}},	//   _njèr, মিল্, _gıys, ħidh, 
   {{0x629c0e96,0x33d80375,0xdd95c797,0x00000000}},	//   írod, _החוד, дабы, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbcf8066d,0x629c01e4,0xc0d40257,0xc0580150}},	// [32870] _azér, ŭrod, ርቶም_, _гін_, 
   {{0xdea01888,0x00000000,0x00000000,0x00000000}},	//   _لیسی, --, --, --, 
   {{0x9988012c,0x59d001f9,0x6a9400d4,0x00000000}},	//   íkům_, _हादर, еріє, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbcf800dd,0x80c800cc,0xaa580114,0x00000000}},	//   _ezér, িবক্, чицу_, --, 
   {{0xaab80228,0x00000000,0x00000000,0x00000000}},	//   زدۅر_, --, --, --, 
   {{0x41bc09fa,0x00000000,0x00000000,0x00000000}},	//   ्लास, --, --, --, 
   {{0xe6c43baf,0x63a401fa,0x19580eed,0x00000000}},	//   رتىي, _đina, _дабы_, --, 
   {{0x2808012c,0x94e82fc0,0x5ed80154,0x2c7401e3}},	//   átní_, تکاف_, ডিটে, bädd_, 
   {{0xbcf80098,0xdb240241,0xa4900633,0x00000000}},	//   _nyém, _àpón, دیوت, --, 
   {{0x2808012c,0x42c401c6,0x00000000,0x00000000}},	//   štní_, мгэн_, --, --, 
   {{0xd174765f,0x923802bf,0xcb10010f,0xdb04000d}},	//   дыгы, ічну_, דלט_, mahä, 
   {{0x2c7400fd,0xdb05c798,0x863408a8,0x54340354}},	//   läde_, lahä, _קאנג_, _охку, 
   {{0x68e40213,0x76840166,0x9f5000d7,0x417400cf}},	//   çidi, _gıyr, adzí_, باپس, 
   {{0x2ca00142,0xdb040641,0x68e40135,0x2bcc21f2}},	//   wpid_, nahä, ħidi, ालसा, 
   {{0x7bc00321,0x00000000,0x00000000,0x00000000}},	//   ónun, --, --, --, 
   {{0xbcf801d3,0x2ca00334,0xdb04000d,0xd05800c0}},	// [32880] _szér, upid_, hahä, _мроі_, 
   {{0x2ca0010a,0xdb05c799,0xbcf801d3,0x00000000}},	//   rpid_, kahä, _gyém, --, 
   {{0x63bdc79a,0x2ca0921c,0x3ab04701,0x9c0000c7}},	//   órni, spid_, кәтт, ыҧре, 
   {{0xdb040793,0x2ca1c79b,0xb9e00212,0x2c74013d}},	//   dahä, ppid_, віши, däde_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x0ee0084a,0xf8700451,0xe3b803e0,0x4784008e}},	//   _पहाड, نهنج, rkık_, мыйб, 
   {{0x2c7401e3,0x98a8031c,0x00000000,0x00000000}},	//   rädd_, ħaġ_, --, --, 
   {{0x26c1c79c,0x9f400306,0xb3a40154,0x76840342}},	//   čio_, _nahý_, _খাগড়, _sıyr, 
   {{0x26c000b0,0xcfc400fe,0x00000000,0x00000000}},	//   ōio_, শ্যন, --, --, 
   {{0x24540022,0x77c4008e,0x00000000,0x00000000}},	//   _ẽmbo_, _олуг_, --, --, 
   {{0x26d800e4,0x4308003b,0x00000000,0x00000000}},	//   _ëro_, іхом_, --, --, 
   {{0xe134013d,0x00000000,0x00000000,0x00000000}},	//   енмы, --, --, --, 
   {{0x2a640175,0x17800124,0xa2c0043e,0x00000000}},	//   _mkmb_, _иқәг, _विव्, --, 
   {{0xdb240118,0xa3d4004e,0x00000000,0x00000000}},	//   _špín, _чокч, --, --, 
   {{0x442dc79d,0x76840139,0x629c01e4,0xceb4013d}},	//   _ilf_, _kıyp, ŭrob, нәя_, 
   {{0x41e41c26,0x5c980962,0x2a640010,0x00000000}},	//   _ціка, зкая_, _nkmb_, --, 
   {{0x5c75c79e,0xee85c79f,0xc0580064,0x00000000}},	// [32890] елат, тыро, _міо_, --, 
   {{0xefbc0020,0x442c0076,0xaad00cb4,0x9ed80120}},	//   ሳቸው_, _jlf_, _हमशक, _емот_, 
   {{0xc0d40b82,0x7b6401f0,0x00000000,0x00000000}},	//   ርዶም_, фтае, --, --, 
   {{0x2cc4029f,0x5a340137,0xdb0401f4,0x59744660}},	//   ürdü_, энет, vahä, нылу, 
   {{0x5d840933,0x442c0449,0x323800df,0x00000000}},	//   _سلسل, _olf_, וטאן_, --, 
   {{0x442c03cd,0xdb0401f4,0x00000000,0x00000000}},	//   _nlf_, tahä, --, --, 
   {{0xa2c041ac,0xbcf801e1,0x2bcc0950,0x2d8c0205}},	//   _विष्, _oyék, ालरा, şkeş_, 
   {{0x442cb499,0xbcf88708,0x3a3c0066,0x2c75c7a0}},	//   _alf_, _nyék, _umup_, räde_, 
   {{0x26042274,0x9424d3a6,0x442c0174,0xa7fc00a2}},	//   वाजी_, емпе, _blf_, _ikın, 
   {{0xa2c037f3,0x78b80481,0x442c017a,0x2c740112}},	//   _विश्, _ivuv, _clf_, päde_, 
   {{0x032001c0,0x00000000,0x00000000,0x00000000}},	//   гдэн, --, --, --, 
   {{0x442c02c2,0xa2c02c2e,0x00000000,0x00000000}},	//   _elf_, _विर्, --, --, 
   {{0x799818f7,0x6594026a,0x442dc7a1,0x422002e8}},	//   _mfuw, _рачу, _flf_, удяв, 
   {{0x7bc00008,0x78b801f7,0x71480092,0x00000000}},	//   ónul, _mvuv, _የኦርቶ, --, 
   {{0xbcf800dd,0x26040574,0x16dc0034,0x03d40115}},	//   _szép, वाची_, _महोब, _נוקם_, 
   {{0xcfa806fe,0xcf4401c0,0x43380375,0xae0002ab}},	//   _کاظم_, _үний, _מעצב, _लोशन_, 
   {{0x2a64022e,0x2bcc00bc,0xd1840354,0xfaa000c7}},	// [328a0] _rkmb_, ालला, _ялий, ҳахо, 
   {{0x79980b45,0xa7fc05d1,0x7d0801e3,0x00000000}},	//   _afuw, _akın, ågsa, --, 
   {{0x7fd404ac,0x78b8014b,0xfaa085a1,0xdb04002d}},	//   _אויס_, _avuv, гахо, mahû, 
   {{0x6ad00034,0x00000000,0x00000000,0x00000000}},	//   _हमीर, --, --, --, 
   {{0xe984183c,0x67d42eb4,0xbcf8020c,0x2a6404cc}},	//   тқан, волу, _nyéh, _vkmb_, 
   {{0xa2c05b99,0x76840166,0x00000000,0x00000000}},	//   _विल्, _sıyp, --, --, 
   {{0x78b802c4,0x442c01ee,0x79980083,0xf7b40228}},	//   _evuv, _rlf_, _ffuw, ردوش_, 
   {{0x442c03cd,0x3cfc00ef,0x00000000,0x00000000}},	//   _slf_, _šuvi_, --, --, 
   {{0x442c002d,0x69c0014f,0x1c04012d,0x00000000}},	//   _plf_, _idme, राचल_, --, 
   {{0xbcf8003e,0x69c00051,0x59740153,0x00000000}},	//   _syék, _hdme, _рысу, --, 
   {{0x2258656c,0x69b403ba,0xdeec0023,0x442c02d2}},	//   дины_, आरपी, ህብን_, _vlf_, 
   {{0x29040010,0x625c003e,0x442dc7a2,0x00000000}},	//   _krma_, léoz, _wlf_, --, 
   {{0xa4d59ed3,0x3e740205,0xa3f400d4,0x98a80327}},	//   _ролі, nçte_, _аплі, ħaħ_, 
   {{0x442c17c0,0x7a3005d1,0xe1f80024,0x27fc0051}},	//   _ulf_, _içte, žų_, ndvn_, 
   {{0xc0a8797e,0x69c1c7a3,0x4250105d,0xdb0c000d}},	//   _کابل_, _odme, _مۆدر, äkül, 
   {{0x2905c7a4,0x63a8a270,0x00000000,0x00000000}},	//   _orma_, lbdn, --, --, 
   {{0x68341574,0x61fc0158,0x2d58005b,0x00000000}},	// [328b0] _kàdd, mdsl, еить_, --, 
   {{0x69c1c7a5,0x61fdc7a6,0x68340de2,0xdb0401e7}},	//   _adme, ldsl, _jàdd, lbhé, 
   {{0x6834002e,0xdb041427,0x9f3401ec,0xfc3c1a85}},	//   _màdd, lahú, _рені, _kvíz_, 
   {{0xdb040332,0xdd98010e,0xab3c00a2,0x57c80c22}},	//   nbhé, _üň_, dýäñ_, रल्ह, 
   {{0x60ddc7a7,0x61fdc7a8,0xdb04007b,0x69e40432}},	//   ntsm, idsl, ibhé, _şweý, 
   {{0xfc3c022c,0x60dc260b,0x290407f5,0x78b80083}},	//   _stíf_, itsm, _drma_, _vvuv, 
   {{0x6c54188c,0x316c033f,0x60dc0076,0x00000000}},	//   _скру, ędzi_, htsm, --, 
   {{0x61fc04ce,0x60ddc7a9,0xda08004b,0x2c74014a}},	//   jdsl, ktsm, _تيره_, mäda_, 
   {{0x2905c7aa,0x57f400c7,0x78b800ec,0x91a01a22}},	//   _grma_, _ипат, _uvuv, _क्षै, 
   {{0x61fc62f1,0x60dc01bf,0x5554105d,0xdb0408a5}},	//   edsl, dtsm, _یپار, dahú, 
   {{0x26dc0313,0x2c7401b8,0x7a300139,0x60dc77d0}},	//   ctvo_, näda_, _eçte, etsm, 
   {{0x659400d8,0x00000000,0x00000000,0x00000000}},	//   _бацу, --, --, --, 
   {{0x463804ac,0x68341bce,0x60dc037e,0x54e400e1}},	//   _קענע, _fàdd, gtsm, _कहिए_, 
   {{0x6a785e94,0x68340694,0x61fc0b4f,0x16081b51}},	//   mífe, _gàdd, adsl, वाकर_, 
   {{0x60ddc7ab,0x1f5828cf,0x6a781a70,0x3f640107}},	//   atsm, ешть_, lífe, виро_, 
   {{0xa7fc1918,0x2c7429ef,0xc690008f,0x54e40037}},	//   _akıl, däda_, שאן_, _कहाए_, 
   {{0x0d85c7ac,0x6a79c7ad,0x60dc0175,0x22581de4}},	// [328c0] тлан, nífe, ctsm, érke_, 
   {{0x683400e8,0x4f2400c0,0xdb240419,0x27fc0051}},	//   _xàdd, _адоб, _špán, xdvn_, 
   {{0x2c7401b8,0xcb082161,0x4a7400c7,0xfba00118}},	//   gäda_, بيان_, ҭыҵт, _ओभरम, 
   {{0x831800c8,0xbcf8525e,0x6a8438b4,0x60c8009b}},	//   וועז, _nyéw, уғбе, šeme, 
   {{0xfe74014b,0x00000000,0x00000000,0x00000000}},	//   _рӯё_, --, --, --, 
   {{0x26dc0882,0x6b9c0798,0x7d180129,0x69b40073}},	//   ttvo_, _ufrg, _àusa, _उजवी, 
   {{0xddcc084c,0x69c0010a,0xfc3c08ce,0x703c0023}},	//   noaş, _tdme, _stíg_, _ካብዚኦ, 
   {{0x69c0037e,0x26dc0ba7,0x29040427,0x60dc002d}},	//   _udme, rtvo_, _trma_, ytsm, 
   {{0x29040262,0x60dc010a,0x16141473,0xb4b181e8}},	//   _urma_, xtsm, اسىڭ, айыш, 
   {{0x61fc0076,0xdb0400e4,0x00000000,0x00000000}},	//   wdsl, vahú, --, --, 
   {{0x04f000eb,0x00000000,0x00000000,0x00000000}},	//   জমের_, --, --, --, 
   {{0x60dc0250,0x990801d9,0xbdd8004a,0x81c80154}},	//   ttsm, _تتہِ_, _amèn, র্ন_, 
   {{0x61fdc7ae,0xbcf800e4,0x6a780077,0xdb04007b}},	//   rdsl, _hyév, cífe, rbhé, 
   {{0xdb05c7af,0x69b406ab,0x998c0432,0x60dc4a5a}},	//   rahú, आरडी, _eneň_, rtsm, 
   {{0x60ddc7b0,0xf48447f7,0x6f2400d4,0xe3b80205}},	//   stsm, _شاهی, аєте, maı_, 
   {{0x60dc02d0,0x9e242a8b,0x00000000,0x00000000}},	//   ptsm, دىرو, --, --, 
   {{0x628c0093,0x6b8c0085,0xa7fc05d1,0x64480072}},	// [328d0] _iiao, ɛngɛ, _akım, oidi, 
   {{0x628c0109,0x2c74007c,0x00000000,0x00000000}},	//   _hiao, täda_, --, --, 
   {{0xef140228,0xeab00451,0xd1dc0023,0xe3b803e0}},	//   _күрө, قعن_, _ሕሳብ_, lkıs_, 
   {{0x628c16b7,0x2c740267,0xeab018fd,0x00000000}},	//   _jiao, räda_, تعك_, --, 
   {{0xd7e830cb,0x6448014a,0x7c3803a2,0x628da362}},	//   емле_, kidi, _ïuro, _miao, 
   {{0x628dc7b1,0x2c740793,0x6449c7b2,0xdb0403b2}},	//   _liao, päda_, jidi, kahø, 
   {{0x6449c7b3,0x81c800bd,0x80d000dc,0x7d0801bf}},	//   didi, র্য_, भूते, ægsf, 
   {{0x6a793b5a,0x628c01e4,0xd5b0007b,0x99840ca5}},	//   tífe, _niao, حفظ_, _ملزو, 
   {{0x64481311,0xf4c0045e,0x629c1709,0xf89800f2}},	//   fidi, ্ব্ব, íron, _آخرش_, 
   {{0x628c01ab,0x81c8015b,0x683400cf,0x6a780077}},	//   _aiao, র্ম_, _pàde, rífe, 
   {{0x628c8f24,0xdddc0030,0x8c180375,0x36200a81}},	//   _biao, _zisť, תותי, _پوشہ, 
   {{0x628d069f,0x10a5be7b,0x6834068c,0x6449c7b4}},	//   _ciao, лимн, _vàde, aidi, 
   {{0x628dc7b5,0x03ec00cc,0xbe0803d4,0x81c80154}},	//   _diao, জাজী_, ৰসাদ_, র্ভ_, 
   {{0x75382747,0x00000000,0x00000000,0x00000000}},	//   mzuz, --, --, --, 
   {{0x628c05da,0x75800133,0xe3b80205,0x00000000}},	//   _fiao, _حیکم, rkıt_, --, 
   {{0x81c800bd,0x628dbe35,0xed8400d1,0x8e846d64}},	//   র্ব_, _giao, иңни, угбе, 
   {{0x75384ec2,0xab640790,0x00000000,0x00000000}},	// [328e0] nzuz, zcüğ, --, --, 
   {{0x628c0165,0x945c0210,0x00000000,0x00000000}},	//   _ziao, muńs, --, --, 
   {{0x49c9c7b6,0xfce001b9,0xae1c00ab,0xbf98010f}},	//   елен_, _қоро, _पचपन_, _ריטש, 
   {{0xe0f40135,0xdd980b01,0x00000000,0x00000000}},	//   _བརྩད_, _ашё_, --, --, 
   {{0x28f8e99a,0x6449c7b7,0x7e600998,0xd8380100}},	//   тель_, yidi, _ínpa, _pwōp_, 
   {{0x8c45c7b8,0x00000000,0x00000000,0x00000000}},	//   _сеге, --, --, --, 
   {{0xfaa00b3e,0x75380165,0xa7fc0166,0xfbb40a7c}},	//   _гасо, ezuz, _ukım, _תפלת_, 
   {{0x64480cfd,0x1b700014,0x7d0800b5,0x75380112}},	//   widi, _بۯمج, ægsg, fzuz, 
   {{0x81c803f4,0x049c063f,0x2c740793,0xd838007f}},	//   র্ড_, _bọọd_, nädo_, _twōp_, 
   {{0x64480dd4,0x628c5a53,0xbdd8004e,0x74300724}},	//   uidi, _siao, _amèl, йныф, 
   {{0xe215c7b9,0x32b405f5,0xa5c439fb,0x628c030a}},	//   амны, лгээ_, _көпе, _piao, 
   {{0xdb0403b2,0x63a4010b,0x00000000,0x00000000}},	//   rahø, _şind, --, --, 
   {{0x64481bb7,0xa2c09e3f,0x628c01e4,0xdb040174}},	//   pidi, _विक्, _viao, sahø, 
   {{0x6449c7ba,0x00000000,0x00000000,0x00000000}},	//   qidi, --, --, --, 
   {{0x628c01e4,0x00000000,0x00000000,0x00000000}},	//   _tiao, --, --, --, 
   {{0xa11428b1,0x3ce8004e,0x7a300139,0x00000000}},	//   _نوبت, _ppcv_, _oçta, --, 
   {{0x2c740793,0xbcf88616,0x7c94007b,0xfd10007b}},	// [328f0] gädo_, _nyét, اشرا, حجز_, 
   {{0x9f500240,0xdfd03592,0x2bcc3507,0x00000000}},	//   nezë_, _بيد_, ालगा, --, 
   {{0x81c800bd,0x1a65c7bb,0xbcf80ca8,0x7a300139}},	//   র্ণ_, لیسی_, _ayét, _açta, 
   {{0x3eb00054,0x98a82220,0x00000000,0x00000000}},	//   _iwxt_, šač_, --, --, 
   {{0x30859008,0x81c80eac,0x38c4ba46,0x6d580112}},	//   _خلیف, র্থ_, ущев, ßvat, 
   {{0xdb04007b,0x9f40032e,0x15f80073,0x195800c7}},	//   lbhí, _lbhí_, ्यभर_, наҵы_, 
   {{0xac58016c,0xa2c00146,0xdcec0115,0x9f500200}},	//   _сарф_, _विग्, rbaĵ, dezë_, 
   {{0xe70843f3,0x81c8015b,0x753801c4,0x00000000}},	//   اتون_, র্ত_, tzuz, --, 
   {{0xa5e80184,0x25a80131,0x6a1400f7,0xde580092}},	//   улыҡ_, ددىي_, _умту, _የእድገ, 
   {{0x130809fe,0x7bd4e26a,0xa2c007d0,0x9f400332}},	//   вной_, ngxu, _विख्, _abhí_, 
   {{0x59b800c5,0x75380112,0x95d800d8,0x5274004e}},	//   _उजार, szuz, _адет_, иуму, 
   {{0x6458c0fa,0xcad4011a,0x00000000,0x00000000}},	//   _ejvi, סורת_, --, --, 
   {{0xae00367a,0x22581d55,0x63a400a2,0x00000000}},	//   _लोगन_, érka_, _şine, --, 
   {{0x53a57ccd,0x831401b9,0x945c012d,0x00000000}},	//   _такб, _چقور_, ruńs, --, 
   {{0xe3b80724,0x9f50007f,0x43400117,0x00000000}},	//   pkır_, nezè_, _мешв, --, 
   {{0xe3b80baa,0xbcf80c6a,0xdcfc0139,0x26d80fac}},	//   lkıp_, _nyés, _aesı, _åroe_, 
   {{0x4c69495f,0x683401ab,0x8b940329,0xfde41d39}},	// [32900] виан_, _làda, ареч, јдук_, 
   {{0x40904d2f,0x00000000,0x00000000,0x00000000}},	//   _گلیر, --, --, --, 
   {{0xbcf8003e,0x68340192,0x9c580137,0x0b4400d8}},	//   _syét, _nàda, ушту_, јнен, 
   {{0x4090cb3a,0x9f51c5ec,0xfeb00139,0xdb140200}},	//   _دلیر, dezè_, _фөрь, _zezë, 
   {{0xaca4063f,0x2abc0248,0x9f500240,0xd90c01d3}},	//   _mmịr, _bábá_, yezë_, ٹیل_, 
   {{0xd90c20bf,0xec3401b9,0x7684008e,0xdb040162}},	//   عیل_, _اوسگ, _gıyz, lahý, 
   {{0x7af40175,0x2ef80142,0x9f500200,0x25740116}},	//   cwxt, nwrf_, vezë_, ڭۇشس, 
   {{0xddcc16a3,0xfc3c00e4,0xa6141ce0,0x7bc001a8}},	//   zmaž, _itía_, смич, ónuv, 
   {{0x27e00c09,0x08880046,0xbcf80022,0xe3b8001f}},	//   ƙin_, _абай_, _hyér, _ለበለጠ_, 
   {{0xaca401f2,0x683401ab,0x629c01e4,0x00000000}},	//   _amịr, _fàda, ŭrom, --, 
   {{0x9f500240,0x48fc6a60,0x00000000,0x00000000}},	//   rezë_, लिको_, --, --, 
   {{0x0585c7bc,0xdb140100,0xbdd8007f,0x056400d8}},	//   _кулм, _dezè, _emèj, _квен, 
   {{0xdb14036e,0x23d40bae,0x00000000,0x00000000}},	//   _pezë, _दाऊद, --, --, 
   {{0x41a40e49,0x65b00345,0x00000000,0x00000000}},	//   _क्रस, _بیکڕ, --, --, 
   {{0x3e681b74,0xbcf800d5,0x7e44023a,0xdb140240}},	//   вшан_, _nyér, ахае, _vezë, 
   {{0x6298013c,0x63b9c7bd,0xddcc02f0,0xdcfc0205}},	//   _iuvo, _hevn, smaž, _sesı, 
   {{0xdb040491,0x63b9c7be,0x629807a9,0xbcf801e1}},	// [32910] rbhí, _kevn, _huvo, _ayér, 
   {{0x6299c7bf,0x63b802bf,0xdd100135,0xad240131}},	//   _kuvo, _jevn, _iżże, غىلى, 
   {{0x7e6045a7,0x20000270,0x63b80477,0xdb1401ed}},	//   _ínpo, _iahi_, _mevn, _kezé, 
   {{0x629807d6,0x20001e27,0x63b80316,0xdfd00451}},	//   _muvo, _hahi_, _levn, _بيگ_, 
   {{0x20000751,0x6298014f,0x7c8400d1,0x76840166}},	//   _kahi_, _luvo, _вуве, _gıyy, 
   {{0x63b9472a,0x6298017a,0x2248022e,0xdd900014}},	//   _nevn, _ouvo, _lmak_, _ووگ_, 
   {{0x20001243,0x6299c7c0,0x7bc40098,0xab0400c5}},	//   _mahi_, _nuvo, _idju, _ööpä, 
   {{0xa2c18e2f,0x2001c7c1,0xdb1402bd,0x2248022e}},	//   _विज्, _lahi_, _rezè, _nmak_, 
   {{0x6299c7c2,0x2ba4012c,0x00000000,0x00000000}},	//   _auvo, खुवा, --, --, 
   {{0x2000152d,0x395dc7c3,0x224801c6,0x6299c7c4}},	//   _nahi_, _ixus_, _amak_, _buvo, 
   {{0x63b802e2,0xdb140221,0xe74402dd,0x63a4054e}},	//   _devn, _bezé, _мүше_, _şinc, 
   {{0x200053a3,0x81c800bd,0x6299c7c5,0xdb041427}},	//   _aahi_, র্স_, _duvo, lahó, 
   {{0x2001c7c6,0x63b8022c,0xdb140306,0x662401ec}},	//   _bahi_, _fevn, _dezé, _گرەك, 
   {{0x22488be1,0x20000113,0x63b8030a,0xa2c0227c}},	//   _emak_, _cahi_, _gevn, _विच्, 
   {{0x20001432,0x6298036b,0xdcec0055,0x00000000}},	//   _dahi_, _guvo, _ākāl, --, 
   {{0x32c00724,0x7bc52df7,0xdb1401c7,0x395c022e}},	//   mıy_, _adju, _gezé, _oxus_, 
   {{0x200051ce,0x62980730,0x32c00724,0x59d000e1}},	// [32920] _fahi_, _zuvo, lıy_, _हाजर, 
   {{0x20000418,0xddcc033f,0x62984b5e,0x00000000}},	//   _gahi_, gnał, _yuvo, --, 
   {{0x32c00724,0xaca40cad,0x1b000116,0x15f84f76}},	//   nıy_, _imọr, мүрн, ्यार_, 
   {{0xa2c01cba,0x00000000,0x00000000,0x00000000}},	//   _विघ्, --, --, --, 
   {{0xe919c7c7,0x2000020c,0x9d580117,0xdb0402d2}},	//   ролі_, _yahi_, _кӯфӣ_, fahó, 
   {{0x6fb801f9,0x32c000fd,0xdb04032e,0xd90c0066}},	//   अरिं, kıy_, gahó, ضیم_, 
   {{0x63b9c7c8,0x9f5007a8,0xdb0400a3,0x9c4801ee}},	//   _revn, tezé_, cbhà, _торғ_, 
   {{0x32c00724,0x63b9c7c9,0xa53428eb,0x6299c7ca}},	//   dıy_, _sevn, жнич, _ruvo, 
   {{0x63b8278a,0x62984031,0xdb043535,0x00000000}},	//   _pevn, _suvo, zahü, --, 
   {{0x224811ad,0x6298013a,0xdb0401e7,0x69c40d12}},	//   _smak_, _puvo, lbhá, ðief, 
   {{0x20000053,0x6298036b,0x32c00724,0x63b9c7cb}},	//   _rahi_, _quvo, gıy_, _vevn, 
   {{0x629802c4,0x20000548,0xddcc033f,0x27e00841}},	//   _vuvo, _sahi_, znał, đinu_, 
   {{0x200073be,0x85744028,0xdb1401ed,0xc5748d1a}},	//   _pahi_, _ادائ, _vezé, _اطاع, 
   {{0x629863fa,0x2348034c,0xa0540212,0x41d8043e}},	//   _tuvo, _پستی_, івві, _भावस, 
   {{0x2001c7cc,0x02a001f2,0x81c8015b,0x2c1c043e}},	//   _vahi_, _klọọ, র্ষ_, नानं_, 
   {{0x2001c7cd,0x22482375,0x6a783eba,0x00000000}},	//   _wahi_, _umak_, dífo, --, 
   {{0x2001524d,0x61edc7ce,0xfba8023a,0x5d5413d6}},	// [32930] _tahi_, _ibal, гтей_, цкат, 
   {{0x44e005a4,0x81c800bd,0x20000069,0xefbc001f}},	//   ið_, র্শ_, _uahi_, ዳቸው_, 
   {{0x99980228,0xdea013f9,0xdd940209,0xc0d402d3}},	//   акет_, _آیری, _маны, ይዶም_, 
   {{0x27ec9374,0x998dc7cf,0x3c2c05d1,0xc6840a81}},	//   _abdn_, _aleš_, _sıvı_, _زِ_, 
   {{0x61edc7d0,0x7bc000fc,0x19582e9a,0xd825c7d1}},	//   _mbal, ónus, шады_, ждли, 
   {{0x16a80719,0xbcf84aee,0xfc3c00e4,0x7bc40687}},	//   авки_, _exéc, _itío_, _udju, 
   {{0x02a002e3,0xd3a001ec,0xd8a800ec,0xed4c00b8}},	//   _blọọ, _ﺍﺯﯨﻖ_, _چهرو_, _įųiþ_, 
   {{0x79e400dd,0x395cb7c8,0xfa3400db,0x61ec01a9}},	//   _دورہ_, _txus_, _ارسد, _nbal, 
   {{0x998c1aff,0x44e001a8,0x63a4c8d8,0x00000000}},	//   _fleš_, gð_, _şina, --, 
   {{0x61edc7d2,0x7c240455,0xe9440c60,0xa6c800eb}},	//   _abal, _jojr, _эхсо, _শহরট, 
   {{0x61ec0a49,0x7c2400f3,0xe69400c7,0x44e002d2}},	//   _bbal, _mojr, _еихы, að_, 
   {{0x02a0063f,0x7c24f1c6,0x32c00724,0x22580158}},	//   _glọọ, _lojr, rıy_, gnsk_, 
   {{0xd39400d1,0x8fd03c1a,0xe7e11586,0x00000000}},	//   _мәнә_, мәнә, _नामप, --, 
   {{0x2259c7d3,0xd0084c17,0xfc3c0118,0x24f80166}},	//   ansk_, шеге_, _stín_, _ынчы_, 
   {{0xbea000c0,0x3ea001a9,0x6a7802d2,0x00000000}},	//   даск, дисг, fífl, --, 
   {{0x61ecec6e,0x956c02d3,0x2c7464d4,0x33b00345}},	//   _gbal, _ኣሓትን_, mädi_, _بڕکر, 
   {{0x2c740793,0x7c240200,0x8c4800d8,0x00000000}},	// [32940] lädi_, _bojr, апав_, --, 
   {{0x61edc7d4,0x7d080194,0x7ea001f2,0x83bc1870}},	//   _zbal, ægsa, ọpat, ﻠﻤﺎﻳ, 
   {{0x2c740793,0x7c24033f,0xed5401e4,0x00000000}},	//   nädi_, _dojr, paɾo_, --, 
   {{0x6834067c,0x8ca006e3,0x44e006ea,0x7bc0041e}},	//   _pàdo, _कंपो, yð_, ónur, 
   {{0x4c3401c0,0xdb04007b,0x7de000e4,0xe3b80166}},	//   _дэвт, rbhá, sãsó, djın_, 
   {{0x76480cfd,0x2c7401b8,0xc6a46134,0x38c80271}},	//   _amgy, kädi_, ории, شاهی_, 
   {{0xfd60063f,0x61300241,0x2258002d,0x7d080158}},	//   kstọ, _kólú, ynsk_, ågsv, 
   {{0x7ae007de,0xa7fc0790,0x787c00e4,0x00000000}},	//   ànte, _akıt, vêve, --, 
   {{0x2ca0298d,0xbdd801e1,0x44e00008,0x61ec004e}},	//   nqid_, _emèw, uð_, _rbal, 
   {{0x44e019cf,0x61ec95d4,0x787c002d,0x61300241}},	//   rð_, _sbal, têve, _lólú, 
   {{0x2c740793,0xe2f802bf,0x7880012c,0xb9e40092}},	//   gädi_, щені_, _důvě, _ሪት_, 
   {{0x9f44022a,0xda1c07f7,0x22580108,0xdb0408a5}},	//   ýlí_, फायत_, симы_, bbhæ, 
   {{0x855404fb,0x44f81374,0x8004020f,0x00000000}},	//   _بخاط, _خراج_, очве, --, 
   {{0x9f60006a,0xddcc2bc9,0x00000000,0x00000000}},	//   _äpëe_, znań, --, --, 
   {{0x76480cfd,0x6235c7d5,0x61300ca8,0x61ec01ab}},	//   _ymgy, _неку, _bólú, _tbal, 
   {{0x443c0b11,0xe18800ee,0xc8b801ad,0x7c240334}},	//   lht_, _гөге_, _उबंट, _sojr, 
   {{0xfe7400f7,0x9f500118,0x443c0254,0x00000000}},	// [32950] йүү_, mezí_, oht_, --, 
   {{0xfba80323,0x6834004e,0xae1405d7,0x7c24014f}},	//   ртай_, _bàdm, डाउन_, _qojr, 
   {{0x443dc7d6,0x61300241,0x7c2401e4,0x1df806a6}},	//   iht_, _fólú, _vojr, _лены_, 
   {{0xf9c410f5,0x18680022,0x00000000,0x00000000}},	//   іщен, әаки_, --, --, 
   {{0x7c24014f,0x8e80030d,0x00000000,0x00000000}},	//   _tojr, _чӳре, --, --, 
   {{0x2e3c0022,0xddcc0356,0x63a40166,0x88f400db}},	//   _vífe_, blaţ, _şinn, سىىر_, 
   {{0x443dc7d7,0xeaf8072d,0xac94030d,0x00000000}},	//   dht_, _ورفت_, _царш, --, 
   {{0x443c0730,0xbdd8007f,0x2c7401b8,0xdb1400bc}},	//   eht_, _emèv, vädi_, _jezí, 
   {{0xde58001f,0x60c81710,0xf8dc000d,0xf1c000d7}},	//   _የእንግ, šemj, _नमिय, úšmi_, 
   {{0x443dc7d8,0xc480ea10,0x68e408c2,0x28a401ec}},	//   ght_, нлык, àide, _ішуг, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfc3d3d87,0xf8cc0034,0xdb1402fb,0x53dc0073}},	//   _stíl_, _हटाय, _nezí, _मावश, 
   {{0xd131c7d9,0x443dc7da,0xfbc80882,0x00000000}},	//   رمس_, bht_, ाणाम, --, 
   {{0xa7fc0598,0x32040030,0x6fdc0073,0x06bc00eb}},	//   _ukıt, žmy_, _बाळं, _ইমতি, 
   {{0x7d0dc7db,0x7d08005c,0x5338010f,0x620401e3}},	//   _arcs, ægsn, _לײַד, ötlä, 
   {{0xe2a9c7dc,0x765919fe,0xd1e40092,0x00000000}},	//   _باون_, nnuy, ዝቦች_, --, 
   {{0x629c02fb,0x8238010f,0x00000000,0x00000000}},	// [32960] írov, _לעקצ, --, --, 
   {{0xc86002e3,0x9cd40327,0xd8e402dd,0x95f828fe}},	//   kọọd, ུངཿས, _ﺍﺴﺘﻐ, ्युट_, 
   {{0x1c380212,0xbf98011a,0x613001e1,0x00000000}},	//   цять_, _לייש, _tólú, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6e2400ec,0xddcc0276,0x7d0c02d0,0xbf10036b}},	//   mjib, slaţ, _grcs, _قویب, 
   {{0x6e24fa60,0xa7fc0139,0x6d440156,0x443c01a9}},	//   ljib, _akır, mzia, xht_, 
   {{0xddcc02d1,0x8ca002a0,0x95f80f4a,0x7658032e}},	//   llaš, _कंडो, ्यूट_, fnuy, 
   {{0x6e2412c5,0x3ea40124,0x067000db,0x00000000}},	//   njib, _énte_, رچاڭ, --, 
   {{0x6d45c7dd,0x6e24009f,0xa4f851a4,0xdde000b0}},	//   nzia, ijib, تکار_, _ōtūi, 
   {{0x6d44030a,0xe3b80205,0x00000000,0x00000000}},	//   izia, lkız_, --, --, 
   {{0xddcc0316,0x26d800e4,0x85840150,0x00000000}},	//   hlaš, _êro_, _ﻗﺼﺩﺍ_, --, 
   {{0x443dc7de,0x6d45c7df,0x26f80574,0xbdd801e1}},	//   sht_, kzia, ंबीर_, _ilèg, 
   {{0x6d440211,0x6e24020c,0xf68800cf,0xa7fc0166}},	//   jzia, djib, _احلۇ_, _ukıs, 
   {{0x6d44006d,0xc059b787,0x00000000,0x00000000}},	//   dzia, сім_, --, --, 
   {{0x82a4053f,0x6d44e2ac,0x41d801f9,0x00000000}},	//   _эшле, ezia, _भाऊस, --, 
   {{0x3374025f,0x45080327,0xddcc0427,0x20040118}},	//   _מתוך_, _ཀློར_, flaš, žli_, 
   {{0x787c00e4,0x3e7403e0,0xdb1401ef,0x00000000}},	// [32970] hêva, nçti_, _vezí, --, 
   {{0x7a30083c,0x3c3c0022,0x00000000,0x00000000}},	//   _içti, _oîve_, --, --, 
   {{0x6d44549e,0x63bc012d,0x5ed401f4,0x00000000}},	//   azia, órny, _южну, --, 
   {{0xddcdc7e0,0x63a403b9,0x597401ec,0x7d08007c}},	//   blaš, _şinl, мылу, ågss, 
   {{0x7d0c009a,0x6d4404cc,0xe8c801ec,0x41d80b27}},	//   _urcs, czia, згіл_, _भाईस, 
   {{0xe8f802d5,0xdb0402d2,0x00000000,0x00000000}},	//   ялі_, dahö, --, --, 
   {{0xa7fc0139,0x2e3c032e,0x9aa400e5,0x00000000}},	//   _pkır, _hífa_, _آمرو, --, 
   {{0xbdd8007f,0x80b00eac,0x4810151e,0xdb0402d2}},	//   _imès, _জিন্, емәс, fahö, 
   {{0x7998089c,0xb3e40003,0x76580113,0xc68c01c8}},	//   _iguw, _འཁྱུ, rnuy, جِي_, 
   {{0x78b8014b,0x76580113,0x00000000,0x00000000}},	//   _iwuv, snuy, --, --, 
   {{0x6d45c7e1,0x7a300205,0xddcccf17,0x00000000}},	//   zzia, _açti, zlaš, --, 
   {{0x9f4000d8,0xa7fc00fd,0x468400b8,0x151801f0}},	//   _tchê_, _ukır, _tṛṇa_, _моеъ_, 
   {{0xd0106e9a,0x320c0118,0x7d0801bf,0x27f400a2}},	//   پلز_, ědy_, ægsl, _ýanç_, 
   {{0xb3e408ea,0xddcc56af,0x6d4400d0,0x00000000}},	//   _འཁྲུ, vlaš, vzia, --, 
   {{0x79980a49,0x00000000,0x00000000,0x00000000}},	//   _oguw, --, --, --, 
   {{0x79991a06,0x6d4405f5,0x645c02b1,0x6a7800ae}},	//   _nguw, tzia, ōrit, cífh, 
   {{0x6e24020b,0x6d4405c7,0x629c01e4,0x00000000}},	// [32980] rjib, uzia, ŭrot, --, 
   {{0x6d45c7e2,0x79980a1d,0x683400a3,0xd04400f2}},	//   rzia, _aguw, _gàdh, _آپدي, 
   {{0x78b80944,0x6a798393,0xdb048a7c,0xddcc0010}},	//   _awuv, lífi, nchè, slaš, 
   {{0xbdd8067c,0xddcc005f,0x6d45c7e3,0x7ae1c7e4}},	//   _clèd, plaš, pzia, ànta, 
   {{0x81c800bd,0xbdd8020c,0xdb1400d8,0x44f8031c}},	//   র্ক_, _dlèd, _pezã, _དགེར_, 
   {{0x60140432,0xddcc01ef,0x00000000,0x00000000}},	//   _iýmä, dnař, --, --, 
   {{0x78b8014b,0x6fdc0073,0x6a780332,0x920c0d2e}},	//   _ewuv, _बाईं, hífi, ियाज_, 
   {{0x60c807f5,0x0a140150,0xdb04007f,0xa3b13a43}},	//   šemi, _تورح, dchè, टुन_, 
   {{0x998c0232,0x69c1c7e5,0x7d185b80,0x00000000}},	//   _pleť_, _ieme, _àust, --, 
   {{0x69c1c7e6,0xd90dc7e7,0x2905c7e8,0x87b8104e}},	//   _heme, _دیه_, _isma_, _фуат_, 
   {{0x69c1c7e9,0xbbd40bd9,0x2c74014a,0x27fc004d}},	//   _keme, וויץ_, läds_, mevn_, 
   {{0x29040280,0xe90c0327,0x6fdc012d,0x27fc0051}},	//   _ksma_, _གློབ_, _बाउं, levn_, 
   {{0x69c1c7ea,0x9f400113,0xbdd8067c,0x2c74014a}},	//   _meme, _iché_, _omèr, näds_, 
   {{0x69c1c7eb,0x2904014b,0x9f500109,0xdb1401ed}},	//   _leme, _msma_, tezà_, _lezá, 
   {{0xfe71393e,0x9f400395,0x290405d5,0xdb040268}},	//   ندر_, _xchè_, _lsma_, cchè, 
   {{0x69c1c7ec,0xdb140232,0xbdd9c7ed,0xe5080016}},	//   _neme, _nezá, _amèr, _kỷ_, 
   {{0x61fdc7ee,0x26dc18f7,0x82a40032,0xc0a80123}},	// [32990] mesl, huvo_, _эшһе, _بابل_, 
   {{0x69c01b08,0x60ddc7ef,0x78b80810,0x244002bd}},	//   _aeme, musm, _rwuv, _fòme_, 
   {{0x69c136ff,0x2905c7f0,0xdb1429c5,0x60dca1bc}},	//   _beme, _asma_, _bezá, lusm, 
   {{0x61fdc7f1,0x29040048,0xdb05c7f2,0xbdd800db}},	//   nesl, _bsma_, nché, _emèr, 
   {{0x69c1c7f3,0x290402fa,0x60ddc7f4,0x2c75c7f5}},	//   _deme, _csma_, nusm, gäds_, 
   {{0x97c40f1b,0x9f400022,0x69c1c7f6,0x61fd1bc6}},	//   رقبو, _aché_, _eeme, hesl, 
   {{0x69c1c7f7,0x44f8025c,0x26dc0810,0x290403e0}},	//   _feme, _དགུར_, guvo_, _esma_, 
   {{0x61fd6a75,0x60dd2169,0x79980009,0x00000000}},	//   jesl, kusm, _uguw, --, 
   {{0x78b8209c,0x2904004e,0x60ddc7f8,0xdb0400ae}},	//   _uwuv, _gsma_, jusm, dché, 
   {{0x69c1c7f9,0x26dc02d5,0x60ddc7fa,0x9f400789}},	//   _zeme, buvo_, dusm, _eché_, 
   {{0x3a3c0a85,0x91e42766,0x69cc00bc,0x61fc0e2d}},	//   _klup_, ноне, ůlež, fesl, 
   {{0x61fdc7fb,0xcb1004ac,0x68341daa,0x6a782cd7}},	//   gesl, אלט_, _ràdi, tífi, 
   {{0xfc3c01e1,0x6834004e,0xdb0404cc,0xb60402f0}},	//   _etíi_, _sàdi, schè, _exšé, 
   {{0x0f400020,0x4f95c7fc,0x3a3c02d1,0x15f80073}},	//   _ማመልከ, ербу, _llup_, ्यकर_, 
   {{0x3a3c4514,0x61fdc7fd,0x6a780113,0x60dc0064}},	//   _olup_, besl, sífi, ausm, 
   {{0xdb04026c,0x60dc014f,0xff04084c,0x1228030d}},	//   cché, busm, эеск_, _хоий_, 
   {{0xc69013e2,0x69c1c7fe,0x7af84dfc,0x26dc0564}},	// [329a0] ראן_, _reme, _ćuta, zuvo_, 
   {{0x69c1c7ff,0x2440067c,0x271c0208,0x00000000}},	//   _seme, _tòme_, _ủng_, --, 
   {{0x69c07807,0x27fc0051,0x00000000,0x00000000}},	//   _peme, vevn_, --, --, 
   {{0x3a3dc800,0x3ea400d2,0xc985c801,0x09b800fe}},	//   _clup_, _énta_, нули, ুলভা, 
   {{0x8d746fb7,0x69c00023,0x26101b51,0x20100162}},	//   _ساحا, _veme, _दोषी_, _ølið_, 
   {{0x26ddc802,0x69c0015c,0xbcf8003e,0x9f400036}},	//   tuvo_, _weme, _nyéy, _sché_, 
   {{0x81c803f4,0x316c068f,0x1cdc025c,0xdb040129}},	//   র্ট_, ędzy_, _རའོ_, yché, 
   {{0xa615c803,0x3a3c1b24,0xddd00024,0x4a740139}},	//   тмич, _glup_, _įgūd, _чыгт, 
   {{0x61fd4c03,0x26dc0793,0x29040129,0x00000000}},	//   vesl, suvo_, _usma_, --, 
   {{0x60dc696f,0x80d417ee,0x00000000,0x00000000}},	//   vusm, _बिबे, --, --, 
   {{0x1de051a5,0xc6d5c804,0x60ddc805,0xdb040129}},	//   _फालत, _ستات, wusm, tché, 
   {{0x60dc1059,0xe50807ae,0x27e00198,0x61fc017a}},	//   tusm, _tỷ_, ɗina_, uesl, 
   {{0x61fc55ca,0xdb05c806,0xe50801fb,0x1cdc031c}},	//   resl, rché, _uỷ_, _རའེ_, 
   {{0x61fdc807,0xdb040a40,0x60ddc808,0x3c3c0588}},	//   sesl, sché, rusm, _oîva_, 
   {{0x60ddc809,0x442dc80a,0x61fdc80b,0x00000000}},	//   susm, _iof_, pesl, --, 
   {{0x442cfb35,0x82341d8f,0x61140022,0x81c8015b}},	//   _hof_, _سرعا, _адиу, র্জ_, 
   {{0x5c7480e2,0x442dc80c,0x5c9811db,0x3d180034}},	// [329b0] влат, _kof_, дкая_, नमें_, 
   {{0x60cc59fc,0xbdd80036,0x2e3c0241,0x442c0076}},	//   _ivam, _blèc, _fífo_, _jof_, 
   {{0x442dc80d,0x6d4000b0,0x80d401ad,0x60cc01a8}},	//   _mof_, _üman, _बिडे, _hvam, 
   {{0x442dc80e,0x60cc0623,0x00000000,0x00000000}},	//   _lof_, _kvam, --, --, 
   {{0xbdd800f7,0x26cc05be,0x442c0a40,0x4c8007d6}},	//   _elèc, _avdo_, _oof_, _چیقق, 
   {{0x81c803f4,0xbdd9c80f,0x60cc1446,0xe3b80139}},	//   র্চ_, _flèc, _mvam, jbı_, 
   {{0x68340e89,0xddcc033f,0x81c80183,0x00000000}},	//   _nàdu, miał, ৰ্য_, --, 
   {{0x60cdc810,0x442dc811,0xdb04015d,0x00000000}},	//   _ovam, _aof_, lchï, --, 
   {{0x26cc0263,0x154404b4,0x00000000,0x00000000}},	//   _evdo_, тепм, --, --, 
   {{0x442dc812,0xddcc0034,0x00000000,0x00000000}},	//   _cof_, niał, --, --, 
   {{0x442dc813,0x60cdc814,0xe4e80133,0x0394002b}},	//   _dof_, _avam, وعیه_, _śūrā_, 
   {{0x442c030d,0x10a454a0,0x81c8015b,0x00000000}},	//   _eof_, кимн, র্ঘ_, --, 
   {{0xdb040054,0x442dc815,0xdd0000bc,0x410002e8}},	//   kchï, _fof_, čtět, азяв, 
   {{0x03a0016c,0xd47800c8,0x60cc0841,0x65940640}},	//   _кишо, _קאַל, _dvam, _сачу, 
   {{0x60cdc816,0xbfc002c6,0x2e3c08a5,0x1cdc0327}},	//   _evam, рбск, _fífl_, _རའུ_, 
   {{0x81c803d4,0x63a40166,0x00000000,0x00000000}},	//   ৰ্ব_, _ğini, --, --, 
   {{0x60cc01e4,0x6e640137,0x336001e2,0xddcc0210}},	// [329c0] _gvam, _ۅندۅ, _جنګې, fiał, 
   {{0xbdd8068c,0x442c5feb,0xdd94009f,0x80d400bc}},	//   _plèc, _xof_, اجِع, _बिते, 
   {{0x60cc05b8,0xbf200032,0x8b943e2e,0x4038025d}},	//   _zvam, _күрҙ, трач, _חגיג, 
   {{0x60cc00e4,0x00000000,0x00000000,0x00000000}},	//   _yvam, --, --, --, 
   {{0xdb04026c,0xe3b8247e,0x67d40137,0xe98402dd}},	//   lchì, ybı_, голу, уқан, 
   {{0xddcc068f,0x7e6045a7,0xdb140432,0xfc3c03b2}},	//   ciał, _ínpr, _bezä, _stív_, 
   {{0x442dc817,0xb6c0008e,0x00000000,0x00000000}},	//   _rof_, асый, --, --, 
   {{0x442dc818,0xddcc0306,0x00000000,0x00000000}},	//   _sof_, plať, --, --, 
   {{0x81c80183,0x4de80406,0x2e3c02d2,0x00000000}},	//   ৰ্ড_, _छानै_, _rífl_, --, 
   {{0x442c0a81,0x6a781a06,0x6834004e,0x60cc000d}},	//   _qof_, rífu, _pàdu, _rvam, 
   {{0x60cdc819,0x442c01a4,0xdb14791a,0x225801f4}},	//   _svam, _vof_, _gezä, еины_, 
   {{0xddcc0034,0xa2442002,0x80d4d9e5,0x34a000c7}},	//   ział, اردۇ, _बिदे, ыҳәҳ, 
   {{0x442cb55f,0x660001c8,0x6a7801a8,0xa4d40212}},	//   _tof_, memk, lífs, _солі, 
   {{0x6601c81a,0x2440033b,0x385c0023,0x208401f7}},	//   lemk, _fòma_, ንፈልጥ, السّ, 
   {{0x673801ed,0x1df82401,0x2c1c00e1,0x7de400d4}},	//   nyvj, невы_, नाईं_, кіад, 
   {{0x6601c81b,0xddcc0034,0xabe00150,0x60cc00dc}},	//   nemk, wiał, _ﺇﺫﺍﻋ, _tvam, 
   {{0x2d591c38,0x22582d75,0x6e95c81c,0x60cdc81d}},	// [329d0] вить_, misk_, риту, _uvam, 
   {{0x66001662,0x6bd40035,0x2139c81e,0x00000000}},	//   hemk, لتمر, mysh_, --, 
   {{0xddcc068f,0x9f340046,0x66000161,0x81c80183}},	//   riał, _сені, kemk, ৰ্ণ_, 
   {{0x22581477,0x660009a8,0xddcc0034,0x6738002d}},	//   nisk_, jemk, siał, dyvj, 
   {{0x4dd8025f,0x1cddc81f,0xbd680640,0xa9040691}},	//   _אחרו, _རའི_, _црне_, لبون, 
   {{0xd7c81d0a,0xfc3c01ef,0xb8c83f6f,0x00000000}},	//   روبه_, _ctít_, _गढ_, --, 
   {{0x22584cab,0xf094008f,0xa81803e6,0xdcec0115}},	//   kisk_, בנס_, کتۆر_, rcaĵ, 
   {{0x660095ca,0x3eb10ae4,0x81c800fe,0x21386c09}},	//   gemk, _mtxt_, ৰ্ত_, kysh_, 
   {{0x73c00032,0xa9780220,0xdb04007b,0x14580153}},	//   аҡла, _айту_, ichí, ешны_, 
   {{0x2c1c0034,0x66e00118,0x1424003b,0x00000000}},	//   नाएं_, ušká, удом, --, 
   {{0x225828b3,0x66000921,0x42c4e9b5,0x00000000}},	//   fisk_, bemk, лгэн_, --, 
   {{0x22581477,0x3c3c00e4,0x62240131,0xe61000e3}},	//   gisk_, _oîvo_, لىپل, _وشن_, 
   {{0x3eb0010a,0x515401c0,0xbb50037e,0x8234020e}},	//   _atxt_, утну, _janコ_, ارپا, 
   {{0x3eb00175,0x3d14012c,0x47840124,0x6a7806ea}},	//   _btxt_, निने_, _рыӡб, nífr, 
   {{0x22580ac8,0x3eb0010a,0x21380363,0x7f4000f3}},	//   bisk_, _ctxt_, aysh_, берж, 
   {{0xfc3c0ba1,0x22580034,0x9e6402ef,0x11e4005b}},	//   _otís_, cisk_, لاقن, _сжим, 
   {{0x858c00d1,0xddcc0210,0x00000000,0x00000000}},	// [329e0] ﻟﯩﺪﺍ_, diań, --, --, 
   {{0x660003c6,0x1614033d,0xfce0204b,0xdb040332}},	//   zemk, _दोसर_, софо, achí, 
   {{0xbdd800f2,0x3ab1c820,0x66007ab0,0x6e6400cf}},	//   _ilèn, йәтт, yemk, _ۅنگۅ, 
   {{0xdb040129,0xae7400d1,0xd5c4010a,0x00000000}},	//   fchâ, _ئۇرغ, _цiин, --, 
   {{0xbdd9c821,0x6600354a,0x00000000,0x00000000}},	//   _klèn, vemk, --, --, 
   {{0xdcfc00da,0xbdd8020c,0x6d4800ac,0xe89401ce}},	//   _uzsā, _jlèn, _ədal, шаль, 
   {{0x6601c822,0x249c01a4,0x22580158,0x2508036b}},	//   temk, _rivm_, yisk_, چرخی_, 
   {{0xfb1802e4,0xb7e00588,0xdb0801e1,0x2258007c}},	//   _אולמ, ажәк, _ànáb, xisk_, 
   {{0x22581347,0x8884516a,0x3d140dad,0xfc3c0789}},	//   visk_, _блаж, निये_, _huía_, 
   {{0x66002747,0x2259c823,0xa2f41a5c,0x80b00154}},	//   semk, wisk_, апоч, _জিল্, 
   {{0x22582d75,0xb8900597,0x80d400bc,0x7bd8010f}},	//   tisk_, _اللع, _बिहे, עקטו, 
   {{0xdb0406ed,0xbb38008f,0xf3600166,0x2139c824}},	//   lchã, געטי, стьн, tysh_, 
   {{0x22582d75,0xbdd80066,0x3eb0010a,0x63a40139}},	//   risk_, _blèn, _stxt_, _şinu, 
   {{0x22582d75,0xbdd80066,0x84800023,0xddcc0165}},	//   sisk_, _clèn, ነቶምን_, ziań, 
   {{0x225839c2,0x3315c825,0x213802d3,0x84c00131}},	//   pisk_, _مزيد_, sysh_, _тәқд, 
   {{0x443dc826,0xa3b00037,0x00000000,0x00000000}},	//   lkt_, टुर_, --, --, 
   {{0xdc540b7f,0x628c05da,0x443c5613,0xdfd554e1}},	// [329f0] авањ, _ihao, okt_, _копы, 
   {{0x443dc827,0xe7e013b4,0x26dc00f3,0x6448004d}},	//   nkt_, _नागप, krvo_, nhdi, 
   {{0x443dc828,0x628c0184,0x99dc010e,0x3e500055}},	//   ikt_, _khao, _alňa, _ṛtum_, 
   {{0xd9980220,0x443c037e,0x00000000,0x00000000}},	//   ننات_, hkt_, --, --, 
   {{0x628c65f2,0x443dc829,0x644801d9,0xfc3c00c6}},	//   _mhao, kkt_, khdi, _dtír_, 
   {{0x443c0460,0x20107d59,0x7ea0063f,0xccf00375}},	//   jkt_, ndzi_, ọput, _וכך_, 
   {{0xfc3c1280,0x628c0374,0x443c01f0,0x20100099}},	//   _guía_, _ohao, dkt_, idzi_, 
   {{0x443dc82a,0x7bc40516,0xb8d8015b,0x00000000}},	//   ekt_, _heju, _আট_, --, 
   {{0x7bc407e1,0xfc3c180f,0x20100810,0x99542e01}},	//   _keju, _utís_, kdzi_, _ткац, 
   {{0x7bc5c82b,0x628c18a6,0x6449c82c,0xddcc5775}},	//   _jeju, _ahao, ghdi, ynaş, 
   {{0x38a87eb1,0x7bc402e3,0x60ddc82d,0xb765c82e}},	//   _hør_, _meju, ersm, _стай, 
   {{0x628dc82f,0x7bc55236,0x443c0cf9,0x38a869e8}},	//   _chao, _leju, akt_, _kør_, 
   {{0x628c0ea3,0x76580cfe,0x1cb00135,0xbdd81f3f}},	//   _dhao, miuy, ྟམས_, _plèn, 
   {{0x443db6a9,0xddcdc830,0x6449c831,0x76580d04}},	//   ckt_, tnaş, chdi, liuy, 
   {{0xb8e40dd4,0x38a817c1,0x628c0013,0x60ddc832}},	//   _ཉས_, _lør_, _fhao, arsm, 
   {{0x628c0fa3,0x76580d04,0x9f400004,0x6b5c0158}},	//   _ghao, niuy, _schã_, _lågø, 
   {{0x7538015c,0x38a803b2,0x7bc41042,0x00000000}},	// [32a00] nyuz, _nør_, _beju, --, 
   {{0x628dc833,0x7659c834,0x7bc40789,0xbdd8020c}},	//   _zhao, hiuy, _ceju, _ulèn, 
   {{0x2e3c008c,0x7bc5c835,0x49c9c836,0x1fb40139}},	//   _lífi_, _deju, влен_, _усыр, 
   {{0x38a86ab9,0x6448044e,0x7658037e,0xc95801d5}},	//   _bør_, zhdi, jiuy, кўл_, 
   {{0x443c9f65,0x9f400113,0x7658090c,0x6448023a}},	//   ykt_, _ichá_, diuy, yhdi, 
   {{0x38a84c2e,0x8c45c837,0x26ddc838,0x7bc5c839}},	//   _dør_, _теге, trvo_, _geju, 
   {{0x49980597,0x78a8010a,0x76580113,0x46682e36}},	//   _ѕтαя_, aqgv, fiuy, крим_, 
   {{0x38a8708a,0x7bc4014b,0xfaa1c83a,0x20100210}},	//   _før_, _zeju, _фато, zdzi_, 
   {{0x38a8105c,0x6aa1c83b,0xb8d800bd,0x7bc42251}},	//   _gør_, _iimf, _আয়_, _yeju, 
   {{0x628c1549,0x7bc402b9,0x443c005f,0x7d540375}},	//   _shao, _xeju, ukt_, ייפד_, 
   {{0x6aa0009f,0x628dc83c,0xf51401b9,0xdb0401e7}},	//   _kimf, _phao, هتیش_, ochá, 
   {{0x443dc83d,0x6448badf,0x60dc030d,0x753800ca}},	//   skt_, shdi, trsm, byuz, 
   {{0xc05800d6,0x68e40876,0x6aa007a9,0x941c013f}},	//   вів_, àidh, _mimf, _etwɑ_, 
   {{0xc058fc53,0x74100a2c,0x9f340220,0x628c0374}},	//   тім_, _وونا, бегі, _whao, 
   {{0x7bc51f29,0x628c0ea3,0x6458ca38,0x20100400}},	//   _reju, _thao, _imvi, rdzi_, 
   {{0x7bc415a5,0x00000000,0x00000000,0x00000000}},	//   _seju, --, --, --, 
   {{0x7bc59884,0x61ec0028,0xdb046b07,0xd9dc00cc}},	// [32a10] _peju, _ical, dchá, ণ্ডম, 
   {{0x38a812ed,0x6aa001ab,0x61ec0175,0x81c80183}},	//   _rør_, _aimf, _hcal, ৰ্শ_, 
   {{0x38a83b4c,0x76580357,0x7bc5c83e,0x6458067c}},	//   _sør_, yiuy, _veju, _mmvi, 
   {{0xceb030fb,0x7bc4f3bc,0xbdd8033b,0x38a806ea}},	//   _מיט_, _weju, _klèm, _pør_, 
   {{0xe9d8c6e4,0x6459c83f,0x78e8f3e5,0xdb0404cc}},	//   ркі_, _omvi, тьев_, schà, 
   {{0xdb0400c6,0x6aa001c7,0x48b82586,0x81e00154}},	//   achá, _eimf, ائنگ_, নজট_, 
   {{0x61edc840,0x76580d04,0x6b5c0158,0xb9e402bf}},	//   _ocal, tiuy, _vågø, _візи, 
   {{0x6459c841,0x38a8eda6,0xbdd8007f,0x61ec0117}},	//   _amvi, _tør_, _amèz, _ncal, 
   {{0xf80400d6,0xaa5c01ec,0x2c1c01f9,0x00000000}},	//   _вчен, _ретi, नाचं_, --, 
   {{0x61edc842,0x6aa1c843,0xddcc09a8,0x00000000}},	//   _acal, _zimf, jlaž, --, 
   {{0x61ec009a,0xc7a40014,0x6aa1c844,0x53a400d1}},	//   _bcal, _أمی, _yimf, _һалб, 
   {{0x61ec02ea,0x6458014b,0xbdd80109,0x6aa007a9}},	//   _ccal, _emvi, _blèm, _ximf, 
   {{0xd174b6d7,0xfc3c0077,0x461002f2,0x00000000}},	//   сыны, _ruín_, _روور, --, 
   {{0x61ec6442,0x68e400a3,0xdb040306,0xaad80b4c}},	//   _ecal, àidi, zchá, _डिलक, 
   {{0x61edc845,0xfbc800bc,0x92b4007b,0x7f400395}},	//   _fcal, िरनम, _احتا, перж, 
   {{0x61edc846,0xfa7c01e1,0x00000000,0x00000000}},	//   _gcal, _ṣonṣ, --, --, 
   {{0x92599008,0xbdd80100,0xddcc0e04,0x00000000}},	// [32a20] _لشکر_, _klèj, blaž, --, 
   {{0x8b9402e8,0xcf442077,0x3c1c0171,0x4de8000d}},	//   бреч, _гной, _nāvē_, _छावै_, 
   {{0x7d08037e,0x00000000,0x00000000,0x00000000}},	//   ægsr, --, --, --, 
   {{0x0db8007b,0x61ec0327,0xdb040118,0x09e401d5}},	//   _حادث_, _xcal, uchá, содн, 
   {{0xda1c0cb4,0xdb0401f6,0x61f800a2,0x00000000}},	//   फाजत_, rchá, _öwle, --, 
   {{0x629c00e5,0x19740116,0x00000000,0x00000000}},	//   íroz, ڭپۇڭ, --, --, 
   {{0x6aa1c847,0xdb0400d0,0xcba41188,0x00000000}},	//   _timf, pchá, _ваҳй, --, 
   {{0xbdd9aa3c,0xbb3800c8,0xddcc08a4,0x629c01e4}},	//   _alèj, _געלי, zlaž, ŭroz, 
   {{0x7af82625,0x998c0166,0x3ebc0e04,0x42a0005e}},	//   _ćuti, _ineş_, ćuti_, _ﺍﻟﺘﻲ_, 
   {{0x61edc848,0xe3c8015b,0x00000000,0x00000000}},	//   _scal, _শাহব, --, --, 
   {{0xe2f978d3,0xddcc2e31,0x61ec0175,0x787000c6}},	//   шені_, vlaž, _pcal, _عُما, 
   {{0x2b0000bc,0x84e40395,0xaf4c0092,0x00000000}},	//   _रहनु_, _годж, _ማመላለ, --, 
   {{0xe5349509,0xa3d4074d,0xb51400f1,0x28e00037}},	//   _фель, _долч, _هغوئ_, _निफि, 
   {{0x6459c849,0x61ec0034,0x1fe00349,0x940406be}},	//   _umvi, _wcal, ম্নস, kmlə_, 
   {{0x62340aa5,0x2e3c00d2,0xb3f4011a,0x41e40816}},	//   _меку, _lífu_, _המוח_, _ліпа, 
   {{0x61edc84a,0x4ca809bd,0xbdd8020c,0xa14801ed}},	//   _ucal, _চৌধু, _ilèk, _نسخے_, 
   {{0x9cb40228,0xc0580816,0xc18000e5,0x00000000}},	// [32a30] زمات, _бін_, _ریسٹ, --, 
   {{0x261001f9,0xbc380066,0x00000000,0x00000000}},	//   _दोघी_, دسرا_, --, --, 
   {{0x224808cd,0x5f9406ed,0xceb42a9d,0x9e34011c}},	//   _klak_, _финт, _мәт_, _денч, 
   {{0x59f80395,0x00000000,0x00000000,0x00000000}},	//   редя_, --, --, --, 
   {{0xbcf810ba,0x9a90044e,0x7c840262,0x5894004e}},	//   _exér, _ዝኣክል_, _гуве, ошку, 
   {{0xdd30068f,0x7d0c03ac,0x224802d1,0xbc2400f7}},	//   zęśc, _iscs, _llak_, _ارحى, 
   {{0xa6b400bd,0x7d0c0098,0x22484cb3,0xb07c00df}},	//   _টিউট, _hscs, _olak_, אנגז, 
   {{0x2e3c02d2,0xe72c0022,0x292801e7,0x00000000}},	//   _fífu_, _ҧҵ_, ótaí_, --, 
   {{0xbdd802e2,0x69346349,0x00000000,0x00000000}},	//   _alèk, _енту, --, --, 
   {{0x2249c84b,0x7d0c010a,0x3688010b,0xc4800661}},	//   _alak_, _mscs, _өсен_, млык, 
   {{0x35f9b815,0x00000000,0x00000000,0x00000000}},	//   _مرشد_, --, --, --, 
   {{0x28e03f55,0x7d0c0354,0x22480c6a,0x00000000}},	//   _निमि, _oscs, _clak_, --, 
   {{0xbdd8033b,0x224809a8,0x00000000,0x00000000}},	//   _elèk, _dlak_, --, --, 
   {{0x2249c84c,0xc9cc0075,0xbdd80066,0x00000000}},	//   _elak_, _ﻗﯩﻠﻐ, _flèk, --, 
   {{0xdb040054,0x52740133,0xa8080139,0x00000000}},	//   nchä, _وابز, luıñ, --, 
   {{0x1ea831ed,0x22480165,0xb63800b5,0x00000000}},	//   صافي_, _glak_, _ｇｃ_, --, 
   {{0x0d9839b0,0x92b40451,0x7d08005c,0x4d640798}},	// [32a40] ртвы_, _احڪا, ægsp, цкав, 
   {{0x244000a3,0x00000000,0x00000000,0x00000000}},	//   _còmh_, --, --, --, 
   {{0xbdd8034c,0x244001ab,0xe8e0004d,0x7050001f}},	//   _olèh, _dòmh_, _đốm_, _ማለታቸ, 
   {{0x66fc00e2,0x00000000,0x00000000,0x00000000}},	//   nākš, --, --, --, 
   {{0x082800f0,0x00000000,0x00000000,0x00000000}},	//   ицки_, --, --, --, 
   {{0xd90c0101,0x0ae801f7,0x00000000,0x00000000}},	//   طیم_, _پرسي_, --, --, 
   {{0x27e00ab7,0xe3c804c5,0x00000000,0x00000000}},	//   ğin_, _শালব, --, --, 
   {{0xa535c84d,0x91e416f0,0x27e04947,0x67f4032e}},	//   знич, _कागज_, şin_, fþjó, 
   {{0xdb1001e1,0x67f4032e,0x00000000,0x00000000}},	//   _àfòs, gþjó, --, --, 
   {{0xb6c801d9,0x27200356,0x4cb000cc,0x00000000}},	//   _چانے_, _pănă_, _চিঞঁ, --, 
   {{0x2249c84e,0x68e4007b,0xabcc1df2,0x3370009d}},	//   _plak_, áidf, _ﺗﯘﻣﺎ, дгэр, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2249c84f,0x241800ee,0xea00001e,0x244001e1}},	//   _vlak_, _голы_, _ngập_, _lòmi_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x24400561,0x80d405d7,0xf68400d1,0x69dd3357}},	//   _nòmi_, _बिके, ﺯﯨﮕﻪ_, _ēren, 
   {{0x22480098,0x81a4036b,0x5d680092,0x6d4803b9}},	//   _ulak_, _بحثل, _ተመርቆ_, _ədav, 
   {{0x5d5418ec,0xfba93eb2,0xcfcc0150,0x00000000}},	// [32a50] чкат, атей_, _ﺑﯘﺭﻗ, --, 
   {{0xfbe02158,0xdb040bc9,0xac940220,0xefbc0092}},	//   ন্নত, ychä, дауш, ኳቸው_, 
   {{0x1cdc0327,0x7d0c02d0,0x19b800c0,0x00000000}},	//   _རའམ_, _wscs, буль_, --, 
   {{0x5a342564,0x244002bd,0xc68400e3,0xdb140432}},	//   янет, _dòmi_, _سِ_, _gezý, 
   {{0x28f80108,0x2b00000d,0x00000000,0x00000000}},	//   жечь_, _रहथु_, --, --, 
   {{0xfd1c01e1,0x7ae005d5,0xdb1401d3,0x00000000}},	//   _irì_, ànts, _kezü, --, 
   {{0xe6b412b7,0xbdd8068c,0xc7a1c850,0x07a1c851}},	//   ولوگ, _alèi, нишк, нашн, 
   {{0xb0dc10f7,0x66d001e1,0x00000000,0x00000000}},	//   _बिलग, _sóká, --, --, 
   {{0xdb048505,0xc5ec00aa,0xbdd801ab,0x66fc005f}},	//   schä, اړم_, _clèi, vākš, 
   {{0x78b9c852,0x28e09ed5,0x67f401a8,0x00000000}},	//   _ituv, _निति, rþjó, --, 
   {{0xbdd8068c,0x67f40008,0x00000000,0x00000000}},	//   _elèi, sþjó, --, --, 
   {{0x80b000bd,0x74f001ec,0xfd1c01e1,0x80d4012d}},	//   _জিজ্, _قۋعا, _orì_, _बिखे, 
   {{0xbdd81497,0x271c01fb,0xfbc82e35,0x00000000}},	//   _glèi, _ảnh_, िराम, --, 
   {{0xdb1403fa,0xbdd8007f,0xded4001f,0x1ae00183}},	//   _bezü, _klèw, ርገን_, _গৈছে_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7c240e4f,0x78b801a9,0x8b6801e0,0x00000000}},	//   _anjr, _otuv, ҙиев_, --, 
   {{0x78b81446,0xfd1c04cc,0x24400ba1,0x28e0258d}},	// [32a60] _ntuv, _crì_, _sòmi_, _निधि, 
   {{0x8b941cc9,0x00000000,0x00000000,0x00000000}},	//   преч, --, --, --, 
   {{0x78b9c853,0xaee40055,0xdb141196,0x00000000}},	//   _atuv, _duṣv, _gezü, --, 
   {{0x094800ee,0x00000000,0x00000000,0x00000000}},	//   йчли_, --, --, --, 
   {{0xbdd80241,0x3200020c,0x9f500407,0x81c80183}},	//   _alèw, _mbiy_, bezó_, ৰ্ক_, 
   {{0x76489ab0,0x7d740133,0x00000000,0x00000000}},	//   _algy, _ژمێر_, --, --, 
   {{0x78b9c854,0x649400a3,0x159000d1,0x00000000}},	//   _etuv, làig, ﻟﯩﺸﯩ, --, 
   {{0xbdd8020c,0xb0dc01ad,0x68e400a3,0x7ae07523}},	//   _dlèw, _बिंग, àids, ánte, 
   {{0x649401ab,0x00000000,0x00000000,0x00000000}},	//   nàig, --, --, --, 
   {{0x7649c855,0xaae02e1e,0x2b0000af,0x47340137}},	//   _elgy, _पटाक, _ईहाँ_, _ىراز, 
   {{0x290401c7,0x973000ec,0x77b8011a,0x86780153}},	//   _hpma_, _لکيا, _המבח, _лёду_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbdd8007f,0x66e464b6,0xba54010f,0x00000000}},	//   _klèv, _хоҗа, לסטו_, --, 
   {{0x29040109,0x6d4806be,0x34900064,0x00000000}},	//   _mpma_, _ədat, _заір, --, 
   {{0xdb140100,0x81c803d4,0x33f8011a,0x00000000}},	//   _lezò, ৰ্গ_, _להגנ, --, 
   {{0xfd1c05d5,0xf310007b,0xaee400b8,0x00000000}},	//   _prì_, _أبوظ, _suṣv, --, 
   {{0x41c074c8,0x6abc0194,0x9c386a0a,0x6d40031c}},	// [32a70] _व्यस, _atrf, опат_, _żmar, 
   {{0xfba9201c,0xdb0400c6,0x61fc01f5,0x7af40175}},	//   стай_, mchú, lfsl, ttxt, 
   {{0x78b9c856,0x15902d40,0xdb0401e7,0x2bb800ae}},	//   _stuv, ﻟﯩﺴﯩ, lchú, سالة_, 
   {{0xdb140232,0xa3dc12eb,0xfd1c0016,0xdb0400ae}},	//   _sezó, तृत_, _trì_, ochú, 
   {{0x9f5004cf,0xdb140789,0xdb04007b,0x22580306}},	//   pezó_, _pezó, nchú, érky_, 
   {{0xdb1402bd,0x2b2800db,0x00000000,0x00000000}},	//   _dezò, تكۅپ_, --, --, 
   {{0xac94b9bf,0xdb140036,0x6d4000c5,0xdb04007b}},	//   _чарш, _ofzé, _ümar, hchú, 
   {{0xe708049e,0x61fc0196,0x29040170,0x9a480014}},	//   ستىن_, jfsl, _fpma_, _بٔرم_, 
   {{0x14dc0574,0x78b854bb,0x57f5116b,0xde58001f}},	//   _मिळण, _utuv, _опат, _ከእንግ, 
   {{0x68e406d5,0xba00044e,0xdc68001f,0x93444ea0}},	//   áide, _ጌሩ_, _ተከበረ_, дное, 
   {{0xc7b00302,0x91e43ab4,0x00000000,0x00000000}},	//   _סבא_, моне, --, --, 
   {{0x200000cd,0x2904002d,0x68e402fb,0x2b0000c5}},	//   _abhi_, _ypma_, šide, _रहसु_, 
   {{0x7e7c0784,0xd43400c6,0x6d4806be,0x00c484dc}},	//   doqp, _يعتب, _ədas, мляк_, 
   {{0xe8000b68,0x42940020,0xfbe0009e,0x649401ab}},	//   ल्पा_, መለከት_, ন্তত, gàid, 
   {{0xdb040332,0x00000000,0x00000000,0x00000000}},	//   achú, --, --, --, 
   {{0x33b004a9,0x1fb4009d,0xc3300677,0x2bf000cd}},	//   _تەھر, _үсэр, _יוו_, _चाहं_, 
   {{0x6abc0334,0x0d840f96,0x4bd801f7,0x8598010f}},	// [32a80] _strf, флан, قباد_, ַשעו, 
   {{0x8b680801,0xdb140100,0x649408c2,0x00000000}},	//   оизв_, _rezò, ràig, --, 
   {{0x6a5c1132,0x28e00ad7,0xf41403d4,0x00000000}},	//   lōfi, _निहि, তাপৰ_, --, 
   {{0xfd1c01e1,0xc98424c3,0x00000000,0x00000000}},	//   _iyìn_, мули, --, --, 
   {{0xba14bd0e,0xcca00124,0xddcc0356,0x00000000}},	//   بينا_, _аҳақ, liaş, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2bc42052,0x68e4007b,0x81c80183,0x28e0efff}},	//   _ल्या, áidb, ৰ্ট_, _निवि, 
   {{0x36840166,0x00000000,0x00000000,0x00000000}},	//   мсын_, --, --, --, 
   {{0x6d4485dc,0x87b836ca,0x68e401a6,0x961c00ef}},	//   nyia, _дует_, šidb, doņd, 
   {{0x1d08010f,0x00000000,0x00000000,0x00000000}},	//   פּפּ, --, --, --, 
   {{0xbdd80100,0x6d44016b,0xd4f403e6,0x7e7c02d1}},	//   _klèt, hyia, وتیژ, yoqp, 
   {{0x61fc0112,0x850400f1,0xddcc0356,0xd37000ec}},	//   ufsl, _يوان, diaş, اهٽ_, 
   {{0xbdd8020c,0x6a5c0607,0x61fc01a8,0x00000000}},	//   _mlèt, gōfi, rfsl, --, 
   {{0x99a4031c,0xdb0400ae,0x2bc008ec,0x00000000}},	//   _ġuże_, rchú, शुमा, --, 
   {{0xe8002d6c,0xdb1001ed,0xe3b8083c,0x37d00183}},	//   ल्या_, égüg, mcı_, _সামৰ, 
   {{0xa19400d1,0xe3b80790,0x6d5801e4,0x81c800fe}},	//   _пайч, lcı_, ĝvan, ৰ্জ_, 
   {{0xfd1c01e1,0x28e007d0,0xd5c40408,0x00000000}},	// [32a90] _eyìn_, _निषि, _цiен, --, 
   {{0xe3b84953,0xbdd8007f,0x6448928f,0x60cdc857}},	//   ncı_, _alèt, nkdi, _iwam, 
   {{0x60cc05b8,0x629ca2ec,0x3078007b,0xa8040166}},	//   _hwam, omso, _تحية_, _moñğ, 
   {{0x6d4402c4,0x28e0d013,0x629c007f,0x64480254}},	//   byia, _निशि, nmso, hkdi, 
   {{0x60cc0770,0x388c02d3,0x6448143a,0xb9080efe}},	//   _jwam, _ዝቃለሱ_, kkdi, تزام_, 
   {{0x60cdc858,0x81c80c58,0x28e023c1,0x644801f5}},	//   _mwam, ৰ্চ_, _निरि, jkdi, 
   {{0xba742dfc,0x3d14c4dd,0xbbc8070f,0x00000000}},	//   _قارت, निके_, िरीक, --, 
   {{0x60ccbf45,0xfc3c007b,0x6449c859,0x00000000}},	//   _owam, _cuív_, ekdi, --, 
   {{0x60cdc85a,0x2440067c,0xd4683a47,0xddcc0356}},	//   _nwam, _nòms_, зипе_, ziaş, 
   {{0x20cdc85b,0x769400e4,0xe70800cf,0x00000000}},	//   dži_, kãyg, ستۉن_, --, 
   {{0x60cdc85c,0x71c4013e,0x20cdc85d,0x81c800fe}},	//   _awam, канҷ, eži_, ৰ্ছ_, 
   {{0x60cda42c,0xbdd8020c,0x6d44003e,0xeff80023}},	//   _bwam, _mlès, yyia, ገዳድ_, 
   {{0x8fd029db,0xf41400fe,0x863400df,0x00000000}},	//   ләнә, তাবৰ_, _ראנג_, --, 
   {{0xdb040c86,0x60cc0100,0x85380375,0xf0580023}},	//   schù, _dwam, _מגני, _ሃገሮም, 
   {{0x60ccf1fe,0x63a40115,0x00000000,0x00000000}},	//   _ewam, _ĝing, --, --, 
   {{0xddcc0311,0x00000000,0x00000000,0x00000000}},	//   riaş, --, --, --, 
   {{0xfce1c85e,0x60cc4437,0xbdd887ef,0x0c255421}},	// [32aa0] лото, _gwam, _alès, нман, 
   {{0x7d18003d,0x7e780552,0x6d44067c,0x00000000}},	//   _ġust, čupa, ryia, --, 
   {{0x6d45c85f,0x60cd94f2,0x7d181a5c,0x4aa80bb1}},	//   syia, _zwam, _šust, чкен_, 
   {{0x7ae073ab,0xf7f000d1,0xe3b80205,0x00000000}},	//   ánta, ۇسىد, zcı_, --, 
   {{0xd588030d,0xfaa4552d,0xe3b80790,0x00000000}},	//   _тiий, رجمی, ycı_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x09e410f5,0x3b041eed,0xe3b80790,0x649400e4}},	//   _повн, _перо_, vcı_, hàic, 
   {{0xa8040724,0xfaa02401,0x8d680092,0x00000000}},	//   _soñğ, _басо, _በመስኖ_, --, 
   {{0xc8c80acb,0xbdd80066,0x3edc063f,0x7d180798}},	//   _روان_, _klèr, mmụọ_, _áust, 
   {{0x60cdc860,0xa2b4069f,0x07a4160b,0x2440067c}},	//   _rwam, _ईंद्, _зазн, _ròms_, 
   {{0xcf1000bd,0xb7d47405,0x6449c861,0xe3b805d1}},	//   হমুদ_, _سونا_, rkdi, rcı_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x629c0175,0xbdd800cf,0x63a401e4,0x25a001ab}},	//   rmso, _olèr, _ŝind, _àil_, 
   {{0x7694035b,0x00000000,0x00000000,0x00000000}},	//   tãyg, --, --, --, 
   {{0xa804010b,0x00000000,0x00000000,0x00000000}},	//   _goñş, --, --, --, 
   {{0x6d1c06ab,0x60cd27d1,0xbdd8180f,0xf49c0020}},	//   निंग_, _twam, _alèr, _ግለሰብ_, 
   {{0x60cc0796,0x22ac012c,0x00000000,0x00000000}},	// [32ab0] _uwam, _věku_, --, --, 
   {{0xbdd85051,0xad240075,0xbbc80a94,0x3158010f}},	//   _clèr, دىكى, िरेक, _ריזן_, 
   {{0xcfb40302,0x248c0204,0x99f402d5,0x6d480014}},	//   _בלתי_, ildm_, вялі, ولہِ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf770105d,0x00000000,0x00000000,0x00000000}},	//   گاش_, --, --, --, 
   {{0x6bd5c862,0x00000000,0x00000000,0x00000000}},	//   _متفر, --, --, --, 
   {{0xf770a387,0x7bd4014b,0xcc74011a,0x47d00137}},	//   داش_, maxu, _יעשה_, جيىر, 
   {{0x7bd5c863,0xa9540150,0x65840241,0x00000000}},	//   laxu, _өксі, _ẹlọ̀, --, 
   {{0x3d140490,0x37a800ee,0x00000000,0x00000000}},	//   निटे_, _етен_, --, --, 
   {{0xe5043ccf,0x7bd40354,0xe800012c,0x3a3c010e}},	//   ابيي, naxu, ल्दा_, _houp_, 
   {{0x3a3dc864,0x95d8023a,0x00000000,0x00000000}},	//   _koup_, _ждет_, --, --, 
   {{0x32040122,0x3a3c0036,0xcb1005d0,0xd174008e}},	//   ýmy_, _joup_, בלט_, выгы, 
   {{0xd1759ef7,0x60980092,0x89d8011a,0x00000000}},	//   тыны, መረጡት_, וחרי, --, 
   {{0x3a3dc865,0xf4e00131,0x649401ab,0x05945ce9}},	//   _loup_, _ﺋﻪﺳﻜ, ràic, _شانگ, 
   {{0xfc3dc866,0x7bd5c867,0x649401ab,0x61b000db}},	//   _luís_, daxu, sàic, جەۋا, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbea1c868,0x3ea001b9,0x4c840c60,0x82480240}},	// [32ac0] ратк, ритг, влав, _ዝረኣኹ, 
   {{0x3ea800ca,0x7bd4014b,0x7de801ad,0x7b8400d1}},	//   _eict_, gaxu, टलॉग_, ھالە, 
   {{0x3a3c0100,0x3ab00184,0x7b840131,0x8fa406ed}},	//   _boup_, иәтт, پالە, _јане, 
   {{0x3a3dc869,0xc33002e4,0x2fd9c86a,0x09e4009b}},	//   _coup_, יוב_, larg_, тодн, 
   {{0x99dc007f,0x3a3c0204,0x7bd4addf,0xea000051}},	//   _alňs, _doup_, baxu, _ngấp_, 
   {{0x7bd4011f,0xfbc0228c,0x2fd93b91,0xfc3c0208}},	//   caxu, _вбро, narg_, _quít_, 
   {{0xe7045ec2,0x229800e5,0x00000000,0x00000000}},	//   استی, léke_, --, --, 
   {{0x3a3c0048,0x2fd801ab,0x65940166,0x00000000}},	//   _goup_, harg_, лайу, --, 
   {{0x99dc0432,0xf4f400e5,0x00000000,0x00000000}},	//   _doňd, نڈوں_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3a3c01a4,0x2fd801a9,0xc03c0023,0x07a4119e}},	//   _youp_, darg_, _ዓለማው, _ражн, 
   {{0x2fd801ab,0xc1080209,0x855401d3,0x229800e4}},	//   earg_, мэге_, _لیبر_, kéke_, 
   {{0x3ea80118,0x26dc00c0,0x00000000,0x00000000}},	//   _rict_, lsvo_, --, --, 
   {{0x2005c86b,0xdec42cc8,0xa3d41d0f,0x229800e5}},	//   ýli_, ләмо, _сокч, déke_, 
   {{0x3ea80354,0x5c74013e,0xceb40166,0x00000000}},	//   _pict_, ҳлат, ләя_, --, 
   {{0xbdd8020c,0x442c045a,0x6dc40108,0x7e7800d7}},	//   _clèp, _hnf_, исуж, čupo, 
   {{0x3a3c039a,0x3ea800ca,0x5c75c86c,0xdbd0010b}},	// [32ad0] _roup_, _vict_, глат, _eýýu, 
   {{0x7ae1c86d,0x3a3dc86e,0xdd0c012d,0x00000000}},	//   ánto, _soup_, _półr, --, 
   {{0xfc3c00cf,0x3a3c007f,0x7bd4bf47,0x1fd800eb}},	//   _suís_, _poup_, raxu, _তাপস, 
   {{0x2011c86f,0x442c0158,0x7bd40077,0x961c00e2}},	//   lezi_, _lnf_, saxu, koņa, 
   {{0xdb0407c5,0x3a3c0100,0x442c0129,0x60dc003b}},	//   lchü, _voup_, _onf_, nssm, 
   {{0x2011c870,0xbbe8742b,0xf8100214,0x3a3c031c}},	//   nezi_, _ترحم_, شستگ, _woup_, 
   {{0x2a640109,0xead59833,0xfaa46c9a,0xdb040c86}},	//   _fmmb_, _вось, _ашан, nchü, 
   {{0x2011c871,0x442c0522,0x1fd8015b,0x57b40022}},	//   hezi_, _anf_, _তাফস, _ӡбат, 
   {{0x2a6406bb,0x442dc872,0xe80010e3,0xfba40882}},	//   _търг, _bnf_, ल्हा_, _कृतम, 
   {{0x442c00ca,0x2011c873,0xd1740220,0x60dc0175}},	//   _cnf_, jezi_, ғымы, dssm, 
   {{0x2011c874,0x60dc02d0,0x29140210,0x00000000}},	//   dezi_, essm, ęcał_, --, 
   {{0x442c0100,0xdb05c875,0x229801ed,0xb7d401ed}},	//   _enf_, lchó, yéke_, _سوچا_, 
   {{0x2011c876,0x2fd8033f,0x649401c3,0xdb0401e7}},	//   fezi_, targ_, màin, ochó, 
   {{0x2011c877,0x442c009f,0xdb05c878,0x17e40183}},	//   gezi_, _gnf_, nchó, প্ৰি, 
   {{0xdfa4188d,0x2fd8020c,0x00000000,0x00000000}},	//   لحفي, rarg_, --, --, 
   {{0x442c070d,0xdb0400c6,0x2298ea0f,0x42c4010b}},	//   _znf_, hchó, téke_, _ёгын_, 
   {{0x2011c879,0x9db80220,0xdbd00162,0x10a4010a}},	// [32ae0] bezi_, тысу_, týði, _йиин, 
   {{0xa7fc05d1,0x22981315,0x26dc0208,0x00000000}},	//   _amın, réke_, ysvo_, --, 
   {{0xdb040332,0x8b9400f3,0x00000000,0x00000000}},	//   dchó, урач, --, --, 
   {{0xfaa0e92d,0x9f403eba,0x80c80406,0x00000000}},	//   бахо, _echó_, तीके, --, 
   {{0xf3e80183,0xc7b80024,0xaae00118,0x00000000}},	//   জ্যৰ_, нёй_, _पटकक, --, 
   {{0xddcc0034,0x26dd23c3,0x68e4e5ea,0xa7fc0205}},	//   chał, tsvo_, šido, _emın, 
   {{0x870419b6,0x44300208,0x0ba800db,0x1dc03c71}},	//   ابتل, _đy_, _ساسى_, षुवत, 
   {{0x2011c87a,0x2bc006b1,0x442c0009,0xdb0401e7}},	//   zezi_, शुरा, _snf_, achó, 
   {{0x2011c87b,0x61f8010e,0x7d040055,0x00000000}},	//   yezi_, _öwli, cīrā, --, 
   {{0xe6447230,0xa3d400f7,0x2011c87c,0x3cf800df}},	//   ılış, шооч, xezi_, עלינ, 
   {{0x2259c87d,0x442c036e,0xdef8001f,0x077400c0}},	//   вины_, _vnf_, ገባን_, _суаў, 
   {{0x2011c87e,0xa5c44445,0x670002e3,0x442c01f5}},	//   wezi_, _төке, _ịkwe, _wnf_, 
   {{0x2011c87f,0x9f400066,0x442c62bc,0x60dc01c7}},	//   tezi_, _idhé_, _tnf_, ussm, 
   {{0xf59000c6,0x9f400240,0x2010030a,0x2bc402c3}},	//   _الهج, _udhë_, uezi_, _ल्ला, 
   {{0x20100bd5,0xc300004b,0xc2e401b9,0x69c1c880}},	//   rezi_, _اړخی, _сўли, _ofme, 
   {{0x2011c881,0xdb0405d5,0xd0180107,0x00000000}},	//   sezi_, rchü, нфӣ_, --, 
   {{0x2011c882,0xdb05c883,0x6e9400f0,0x16d000dc}},	// [32af0] pezi_, schü, ситу, _सब्ब, 
   {{0x69c05d94,0x212804fb,0x20100023,0xdb0404cc}},	//   _afme, _irah_, qezi_, pchü, 
   {{0x5b148a63,0x9f340212,0x68e40c5e,0x00000000}},	//   рмет, _тені, šidl, --, 
   {{0x28e0185d,0x212802d3,0xead4003b,0x00000000}},	//   _निखि, _krah_, соць, --, 
   {{0xa90439b6,0x67281368,0x6e040150,0x66880023}},	//   مبون, _ardj, _اسپە, _ምህላዋ_, 
   {{0xe80010fa,0x67280cf4,0x98a422bf,0x18a41eec}},	//   ल्ला_, _brdj, шиле, шалм, 
   {{0x21280ffb,0x67280076,0xdb04007b,0xa3e802ab}},	//   _lrah_, _crdj, rchó, यणन_, 
   {{0x21280331,0xdb4c0014,0xddcc00df,0x9aa8210e}},	//   _orah_, _ٹێچ_, knaŭ, _شگاف_, 
   {{0xf1c8012c,0x54340edb,0xddcc01e4,0xaee4002b}},	//   ndář_, ахну, jnaŭ, _kiṃt, 
   {{0x249c04cc,0xb6a0036b,0x63a401e4,0xfe640092}},	//   _chvm_, шиқл, _ŝina, _ተፈፃሚ_, 
   {{0x2128080b,0x3e500882,0xd1dc00b7,0x8c180375}},	//   _arah_, ṛtya_, ዓመቱ_, דותי, 
   {{0x2129c884,0x5155c885,0x543420e8,0x69ac00ab}},	//   _brah_, атгу, ارکر, ुँची, 
   {{0x21280066,0x7ae004d7,0x94784c87,0x00000000}},	//   _crah_, ántj, _иску_, --, 
   {{0x53a40b20,0xd469c886,0x1cc4031c,0x6728062c}},	//   _калб, _шиле_, ཏེན_, _yrdj, 
   {{0xefdc044e,0x212806fd,0xcdd40063,0x3f6401f0}},	//   _ንናይ_, _erah_, ицањ, аиро_, 
   {{0x212805da,0xe3b8eb46,0x2258000f,0x9e6400d1}},	//   _frah_, ndın_, chsk_, ماقن, 
   {{0x21281883,0xa3dc2e1e,0xa3bc0037,0x00e000c0}},	// [32b00] _grah_, तृक_, _अलम_, _джын, 
   {{0x78a0010a,0xddd400e2,0x25a001ab,0xac6400db}},	//   jmnv, ābša, _ùile_, حئرۇ, 
   {{0x22982cda,0x671400e1,0x8d9c0150,0x00000000}},	//   léka_, _थैंक_, _ﺃﺭﺩﺕ_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x672817a3,0x22987c9e,0xbf440055,0x8274010f}},	//   _srdj, néka_, _eṣāp, סענע_, 
   {{0x8cd4033f,0xdb04067c,0x649401ab,0x5eac0154}},	//   मीणो, rchò, gàil, য়ীদে, 
   {{0x245c0241,0x475802e8,0x159000d1,0x00000000}},	//   _lámù_, ърдя_, ﻟﯩﺘﯩ, --, 
   {{0xddcc0311,0x7ae00311,0x00000000,0x00000000}},	//   mnaţ, ânte, --, --, 
   {{0xe944221d,0x9908007b,0xf4d47a71,0xc96400c0}},	//   _ارزی, _مغلق_, амыш_, _твай, 
   {{0xddcc0311,0xc34800a7,0x2128036e,0xf860020f}},	//   onaţ, вяме_, _rrah_, _двуо, 
   {{0x212800f2,0xd53801d5,0x4df400bc,0x00000000}},	//   _srah_, نغیچ_, इलाई_, --, 
   {{0x21281a48,0x99dc0306,0xdbd008a5,0x00000000}},	//   _prah_, _koňa, _lýðu, --, 
   {{0x3168016c,0x00000000,0x00000000,0x00000000}},	//   ашро_, --, --, --, 
   {{0x2129c887,0x8cd8033f,0xab6800de,0x7ee43efd}},	//   _vrah_, _पौधो, _kaļķ, ицбе, 
   {{0x5f940224,0xdfd40220,0x27f8032e,0xaf340066}},	//   сивт, _қоны, _örnu_, يرفت, 
   {{0x2129c888,0xefdc044e,0x229804d7,0x443c01e6}},	//   _trah_, _ንዓይ_, béka_, ljt_, 
   {{0x2128151c,0xdbd00008,0x628dc889,0x5d9802d5}},	// [32b10] _urah_, _býðu, _ikao, укаў_, 
   {{0x443c0023,0xe3b985f8,0x00000000,0x00000000}},	//   njt_, zdın_, --, --, 
   {{0xfba9c88a,0xe3b8029f,0xf2d0008f,0x44fc0011}},	//   ттай_, ydın_, ַעס_, ্টিক_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x628c3545,0xaa580556,0xd8b8020e,0x00000000}},	//   _mkao, шицу_, اگرا_, --, 
   {{0x99dc010e,0xab6800de,0x3158010f,0x00000000}},	//   _doňa, _baļķ, סיגן_, --, 
   {{0x628dc88b,0x7d0c1bf4,0x9b44129e,0xdb20005b}},	//   _okao, _hpcs, _انزو, ötär, 
   {{0x68ec083c,0xfc5c0023,0x00000000,0x00000000}},	//   üldü, ጋገጸል, --, --, 
   {{0x9f44006a,0xd5480a8f,0xe3b9b056,0x00000000}},	//   ûlê_, уппе_, rdın_, --, 
   {{0x628dc88c,0x79980b45,0x443c0200,0x00000000}},	//   _akao, _izuw, gjt_, --, 
   {{0xd7940491,0xe51c0037,0xd2a80108,0xe3b806be}},	//   _الاخ, _बैठि_, лкое_, pdın_, 
   {{0x22981a09,0x443c036e,0x00000000,0x00000000}},	//   téka_, ajt_, --, --, 
   {{0x10a42f0d,0x64680129,0x76580051,0xd588030d}},	//   йимн, êpiè, mhuy, _тiай, 
   {{0x10a400a8,0x2299c88d,0x628c0295,0x00000000}},	//   сигн, réka_, _ekao, --, 
   {{0x628c03a0,0xb674001f,0x9344084c,0x326401d9}},	//   _fkao, _ይህንኑ_, _ынке, _ونتہ, 
   {{0x7658fcbb,0xdbd002d2,0x00000000,0x00000000}},	//   nhuy, _sýðu, --, --, 
   {{0x7999c88e,0x10148fd9,0x48d000fe,0x76580051}},	// [32b20] _nzuw, _льня, _সম্ৰ, ihuy, 
   {{0x8f7401ca,0x00000000,0x00000000,0x00000000}},	//   _гумі, --, --, --, 
   {{0x7659c88f,0x49c9c890,0xaca4063f,0xcb680214}},	//   khuy, глен_, _nnụr, دماه_, 
   {{0xddcc084c,0xfaa065cb,0x7c64001f,0x99dc0419}},	//   rnaţ, пахо, ሻሻለው_, _poňa, 
   {{0x2d85c891,0xaca40521,0x443c094a,0x6e25c892}},	//   _âme_, _anụr, yjt_, mdib, 
   {{0x79980bd7,0x6e259739,0x99dc02fb,0x00000000}},	//   _dzuw, ldib, _voňa, --, 
   {{0x7bd80375,0x63a401e4,0xf74006ed,0x00000000}},	//   _תקלו, _ĝino, зејо, --, 
   {{0x6e25c893,0xddcc00f3,0x84880023,0x00000000}},	//   ndib, onaš, _ምብላዕ_, --, 
   {{0xfaa0136b,0x6e25c894,0xa534187f,0x394001a9}},	//   _хато, idib, іноч, _ентг, 
   {{0x86c405d9,0x27f87dfa,0x628c05c7,0x6e2401ab}},	//   _هيئن, _ørn_, _skao, hdib, 
   {{0xe214c134,0x9f440259,0x32b401c0,0x6e2444a1}},	//   омны, ülü_, йгээ_, kdib, 
   {{0x76580986,0xf36080f4,0x7ae0307d,0x973004fb}},	//   chuy, ятын, ánti, _آکوا, 
   {{0xe3b80d9c,0xc05802bf,0x6e25c895,0x68e401e7}},	//   ldım_, гів_, ddib, áidh, 
   {{0x6e24003a,0xa3bc012c,0xa37c01e4,0xc05801ec}},	//   edib, _अलि_, vaĵf, уім_, 
   {{0x64580357,0xe3b8494d,0x6e240175,0xdb0401c7}},	//   _ilvi, ndım_, fdib, lchö, 
   {{0x628c8223,0x6e25969a,0x22c402e3,0x33740375}},	//   _ukao, gdib, _ịkwa_, _לתוך_, 
   {{0x66040113,0x71f80046,0x40842716,0x229800e8}},	// [32b30] _ñiku, _ارىس_, _гунб, léko_, 
   {{0xe3b80205,0xff04010a,0x00000000,0x00000000}},	//   kdım_, _лямн, --, --, 
   {{0x6e25c896,0x6d41c897,0x11f40137,0x76580051}},	//   bdib, _àman, _اتۉگ, yhuy, 
   {{0xefdc044e,0xac180220,0x5a3511d8,0x63a401e4}},	//   _ንሓደ_, _қосу_, юнет, _ĝinl, 
   {{0x6459c898,0xe9d84077,0x765806d6,0x998000bc}},	//   _olvi, скі_, vhuy, ěhů_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7659c899,0xc7a000db,0xcc840345,0x00000000}},	//   thuy, мишк, _بۆله_, --, 
   {{0x2f200158,0x753801c4,0x54c40139,0x00000000}},	//   _hågå_, txuz, обиб, --, 
   {{0x7658017a,0x81bc0154,0x00000000,0x00000000}},	//   rhuy, ইরা_, --, --, 
   {{0x76584539,0xddcc0054,0x6458003a,0x1308d44e}},	//   shuy, qhaņ, _clvi, аной_, 
   {{0x81c80183,0x7659c89a,0xddcc0010,0x7af44a43}},	//   _লয়_, phuy, znaš, nuxt, 
   {{0xbdd80ba1,0x78b92f90,0x1da80882,0x64587963}},	//   _boèm, _kuuv, कधात, _elvi, 
   {{0xe820038e,0xfd1c0241,0xe80049be,0x98bc012d}},	//   _यसमा_, _nsì_, ल्का_, tywę_, 
   {{0x2298043b,0xdb040120,0x68e4007b,0xddcc0cf4}},	//   béko_, lchõ, áidi, vnaš, 
   {{0xfd1c01e1,0x0eb8506f,0x78b80254,0xa37c00df}},	//   _asì_, ругы_, _luuv, vaĵg, 
   {{0x6e25531e,0x0dc9c89b,0x4e040006,0x10a401a9}},	//   udib, рлай_, ўзаб, сиҳн, 
   {{0x0eb41533,0x78b80421,0xe3b85531,0x6458143a}},	// [32b40] _आंकड, _nuuv, zdım_, _ylvi, 
   {{0x8b94272a,0x6459c89c,0xe3b85531,0x6e240c8e}},	//   ореч, _xlvi, ydım_, sdib, 
   {{0x8fa4e0c3,0xfd1dc89d,0xd1c8001f,0x6fa8004b}},	//   _фане, _esì_, _ጠላት_, _دندې_, 
   {{0x7ae00276,0x2ef801f5,0x5aa80451,0x37d003d4}},	//   ânta, murf_, مانَ_, _সাগৰ, 
   {{0xb9900fb4,0x9f9402d2,0x961c007f,0x39840023}},	//   ولمب, _hýði_, vlņp, _ንቓልሲ_, 
   {{0x2298002e,0x00000000,0x00000000,0x00000000}},	//   yéko_, --, --, --, 
   {{0xf8bc0936,0xe80001ad,0x287800fb,0x00000000}},	//   _één_, ल्गा_, аҡҡы_, --, 
   {{0xe3b84ba9,0xfaa0ae94,0x7c80001f,0x9f4406af}},	//   rdım_, _жасо, ናገረው_, ûlé_, 
   {{0xdb20023a,0xbdd80100,0xd9b01df2,0x6abdc89e}},	//   ätös, _plèz, _كەمد, _hurf, 
   {{0x6abdc89f,0x4735ab5a,0xdb0404cc,0xe8000c4c}},	//   _kurf, _وراز, rchö, ल्खा_, 
   {{0xe3b8a85c,0xdb05c8a0,0xf360023a,0x998c0139}},	//   ldık_, schö, дтян, _kaeş_, 
   {{0xbdd9ac8f,0x6abdc8a1,0x2ef80af9,0xe928031c}},	//   _poèm, _murf, durf_, _རློབ_, 
   {{0x2f1c010f,0xdb1402bd,0xddcc012c,0xe3b80e51}},	//   _aŭg_, _egzè, chař, ndık_, 
   {{0x6abc0c8c,0x6459c8a2,0x27fc004d,0xfdd05d9c}},	//   _ourf, _ulvi, ngvn_, तर्फ, 
   {{0x3e6800ee,0x6abdc8a3,0x7af40327,0x7fd40150}},	//   ашан_, _nurf, xuxt, йіңі, 
   {{0x7ea40131,0xe3b803e0,0x00000000,0x00000000}},	//   _ﺋﺎﺗﺎ_, kdık_, --, --, 
   {{0x9cb4562d,0x2f200250,0xdcfc0171,0x00000000}},	// [32b50] سمات, _pågå_, _izsī, --, 
   {{0x78b8023a,0x61fc072b,0x6abc007c,0xe3b80205}},	//   _ruuv, lgsl, _burf, ddık_, 
   {{0x2001c8a4,0xe0bc04c5,0x6abc00ae,0xdef002d3}},	//   _ichi_, _অবিভ, _curf, ልወካ_, 
   {{0x78b805a7,0x6abdc8a5,0x22488d29,0xd9580006}},	//   _puuv, _durf, _joak_, йшлі_, 
   {{0x61fdc8a6,0x6700063f,0x224800e4,0x6abc115d}},	//   igsl, _ịkpe, _moak_, _eurf, 
   {{0x6abdc8a7,0x6e20067c,0x2249c8a8,0x00000000}},	//   _furf, _ómbr, _loak_, --, 
   {{0x6abc0c09,0xd17c0020,0x2000009f,0x62780115}},	//   _gurf, _የዕትሙ_, _mchi_, rĉoj, 
   {{0x78b80618,0x200001d5,0xda08131e,0x99dc0c5e}},	//   _tuuv, _lchi_, _ديره_, _koňm, 
   {{0x3e74038f,0x6abc0c09,0x2001c8a9,0xaee400b8}},	//   għti_, _zurf, _ochi_, _keṣu, 
   {{0x200016cb,0xc7a40014,0xa37c01e4,0x00000000}},	//   _nchi_, _کٔمی, zaĵe, --, 
   {{0xe73801ee,0x00000000,0x00000000,0x00000000}},	//   _меѕ_, --, --, --, 
   {{0x2001c8aa,0xe6101550,0x61fcee21,0xc2400815}},	//   _achi_, _لشه_, ggsl, енюк, 
   {{0x20000175,0x2ef80e78,0xa37c00df,0x00000000}},	//   _bchi_, wurf_, vaĵe, --, 
   {{0x2ef9c8ab,0x99dc010b,0xd0080063,0xc9cc0116}},	//   turf_, _soňl, љеве_, _ﺗﯩﻠﻐ, 
   {{0x7ae40334,0x200400db,0x8c443c1a,0xa37c01e4}},	//   _nvjt, òlia_, үебе, taĵe, 
   {{0x2001c8ac,0x22480098,0x7bc40009,0xe3b82737}},	//   _echi_, _goak_, _afju, ydık_, 
   {{0x2ef9c8ad,0x6abdc8ae,0x0d980006,0xd1b00214}},	// [32b60] surf_, _surf, ствы_, _سیسک, 
   {{0x8fa4855f,0x6abdc8af,0x99dc00a2,0x290401a9}},	//   _напе, _purf, _doňm, _rqma_, 
   {{0x6f0c054e,0x1b003ad0,0x00000000,0x00000000}},	//   încă, күрн, --, --, 
   {{0xfc3c1709,0xda64680d,0x63a40115,0x2000022e}},	//   _xuíz_, واني, _ŝink, _zchi_, 
   {{0x3154044e,0x6abc0e78,0x2000022e,0x00000000}},	//   _ዝኸበር, _wurf, _ychi_, --, 
   {{0x6abcd7de,0xd90c3e66,0xe3b80e51,0xc198010f}},	//   _turf, شیم_, rdık_, זשני, 
   {{0x6abc022f,0xc668034b,0x26f80118,0x00000000}},	//   _uurf, йшие_, ्झेर_, --, 
   {{0xa5340283,0x97e80131,0x627801e4,0xd71800d4}},	//   днич, бләғ_, rĉok, юючі_, 
   {{0xfc3dc8b0,0x31c400cc,0x27fc0051,0x00000000}},	//   _ruíz_, ্ণাশ, pgvn_, --, 
   {{0x838402dd,0x2248045a,0xa37c01e4,0xee9001ec}},	//   зыме, _soak_, vaĵb, _ﺒﻌﻴﻥ_, 
   {{0x04fc00bd,0x22480109,0x200001a9,0x337000ee}},	//   ্টের_, _poak_, _rchi_, егэр, 
   {{0x20001570,0x76b80375,0x00000000,0x00000000}},	//   _schi_, _המאפ, --, --, 
   {{0x9f5001a8,0x26f403d4,0x855400f2,0x00000000}},	//   _íbúa_, _আনটো_, _ریدر_, --, 
   {{0x2000022e,0xddcc002b,0x00000000,0x00000000}},	//   _qchi_, bhaś, --, --, 
   {{0xff500345,0x00000000,0x00000000,0x00000000}},	//   رخس_, --, --, --, 
   {{0x8cbc07f7,0xee2001ec,0x00000000,0x00000000}},	//   _वंशो, лесi_, --, --, 
   {{0x61edc8b1,0x2000026c,0xefdc0023,0xee8400c7}},	// [32b70] _idal, _tchi_, _ንዓዲ_, хыро, 
   {{0x2001c8b2,0x7ae00356,0x00000000,0x00000000}},	//   _uchi_, ânto, --, --, 
   {{0x60cc022e,0x7b6429be,0x19b80166,0x00000000}},	//   _htam, чтае, оуль_, --, 
   {{0x60cc01d5,0x00000000,0x00000000,0x00000000}},	//   _ktam, --, --, --, 
   {{0xa95400d6,0x61ece439,0x0e00016c,0xedd40592}},	//   нкці, _mdal, _шӯро, _سيّد, 
   {{0x60cdc8b3,0xd1c8001f,0x75c40241,0x7c840353}},	//   _mtam, _ጠዋት_, _oṣéá, _хуме, 
   {{0x16a80126,0x61edc8b4,0x60cc007f,0xf9b401af}},	//   овки_, _odal, _ltam, _еңеш_, 
   {{0x61edc8b5,0x7c25c8b6,0x60cdc8b7,0x2f5c0a7c}},	//   _ndal, _hajr, _otam, מדונ, 
   {{0x60cdc8b8,0x68e40597,0x7c240240,0x99dc00a2}},	//   _ntam, áidt, _kajr, _loňk, 
   {{0x61edc8b9,0x629c019f,0x7c24014f,0x62840115}},	//   _adal, îron, _jajr, _ĉioa, 
   {{0x7c25c8ba,0xe66c00d0,0xd49800db,0x00000000}},	//   _majr, štáľ, йрү_, --, 
   {{0x60cc010a,0x9b1801ec,0x00000000,0x00000000}},	//   _btam, стiр, --, --, 
   {{0x61edc8bb,0x8fd01de6,0x00000000,0x00000000}},	//   _ddal, кәнә, --, --, 
   {{0x7c25c8bc,0x7648066d,0x60cdc8bd,0x8fa4021f}},	//   _najr, _hogy, _dtam, даге, 
   {{0x7649c8be,0x835000aa,0x61ec0135,0xe2a80344}},	//   _kogy, _ټپيا, _fdal, تاین_, 
   {{0x76490a4d,0xbea194e6,0x1e940276,0x00000000}},	//   _jogy, васк, ерур, --, 
   {{0xfce009fe,0x7c25c8bf,0x7649c8c0,0x5ab8031c}},	// [32b80] кото, _bajr, _mogy, _བཤུམ, 
   {{0xcd280020,0x6da40058,0x7648045f,0x61ec8dd4}},	//   _ትክክለ, диға, _logy, _zdal, 
   {{0x6fd42e05,0x8b943f72,0x7c240200,0x42d800df}},	//   _ब्यू, фрач, _dajr, ַקסע, 
   {{0x7c2401c6,0xa37c0115,0x649401ab,0x00000000}},	//   _eajr, naĵa, làit, --, 
   {{0x7c2400c8,0x3e74003d,0xbb1406ba,0x60cc01b9}},	//   _fajr, għtu_, ﻳﻠﻰ_, _xtam, 
   {{0x0ae876e1,0x649400a3,0x7c253f35,0xcb68010a}},	//   _ورزي_, nàit, _gajr, _даге_, 
   {{0xa37c01e4,0x764800e5,0xe69400c7,0x00000000}},	//   kaĵa, _bogy, никы, --, 
   {{0x2cb80204,0x7c240034,0x7648015d,0xa7fc0166}},	//   _hird_, _zajr, _cogy, _olıg, 
   {{0x04fc00bd,0x7648010e,0xa37c01e4,0x480417a0}},	//   ্ট্র_, _dogy, daĵa, _опав, 
   {{0x60cc01a9,0x627801e4,0x961c00ef,0x00000000}},	//   _rtam, nĉov, doņu, --, 
   {{0x764800dd,0x2cb80204,0x37000022,0xa7fc008e}},	//   _fogy, _mird_, _апхг, _alıg, 
   {{0x7648015d,0xa37c01e4,0x00000000,0x00000000}},	//   _gogy, gaĵa, --, --, 
   {{0x99ddc8c1,0x2cb801e7,0x8444007b,0x61ec5752}},	//   _soňk, _oird_, _يختل, _vdal, 
   {{0x741036ac,0xd4c400c6,0x00000000,0x00000000}},	//   _لوها, _أغني, --, --, 
   {{0x7649c8c2,0x7c240113,0x94240b38,0xe58000e2}},	//   _yogy, _rajr, _سويۇ, šķā_, 
   {{0x61edc8c3,0x7c25c8c4,0x2cb81552,0x60cdc8c5}},	//   _udal, _sajr, _aird_, _ttam, 
   {{0x60ccbe86,0x2cb8771c,0xddcc033f,0x3e740327}},	// [32b90] _utam, _bird_, tkał, xħtu_, 
   {{0x229801ed,0xdfd000e3,0x00000000,0x00000000}},	//   déki_, _حيد_, --, --, 
   {{0x7c240882,0x2ef40276,0x6494642b,0x7d1c0175}},	//   _vajr, _изэр, làis, swqs, 
   {{0xdd91c8c6,0x2cb80204,0x69dc013f,0x7c240113}},	//   _موج_, _eird_, _ɑreg, _wajr, 
   {{0x7c2407d6,0x2cb80036,0xcdf40a1e,0x38000107}},	//   _tajr, _fird_, _אמרי_, волҳ, 
   {{0x2cb80477,0x764800a2,0x26c001e4,0x00000000}},	//   _gird_, _sogy, ĉion_, --, 
   {{0x0af005f5,0x628401e4,0xf7700101,0xc0cc0023}},	//   _бүхэ, _ĉion, خاش_, ኣየሉ_, 
   {{0x19940006,0x00000000,0x00000000,0x00000000}},	//   _забя, --, --, --, 
   {{0xeab047e7,0x2cb81c1d,0x22c40521,0x56940032}},	//   _ضعف_, _yird_, _ịkpa_, маҫт, 
   {{0x76480134,0x98ac00f3,0x2258002d,0xddcc008f}},	//   _wogy, _kreč_, eksk_, diaŭ, 
   {{0xa37c00df,0x7648010e,0x00000000,0x00000000}},	//   taĵa, _togy, --, --, 
   {{0xddcdc8c7,0x6764009f,0x76480064,0x622400d1}},	//   nkań, _جُمل, _uogy, نىپل, 
   {{0xa37c0115,0x0fd80108,0x00000000,0x00000000}},	//   raĵa, зьбы_, --, --, 
   {{0x6d41c8c8,0xa52401ca,0x3204012d,0x00000000}},	//   _àmai, _шмід, żmy_, --, 
   {{0xcfe000cc,0x649401c3,0x93240ed8,0x229800e5}},	//   _বাদন, ràit, _سرغن, zéki_, 
   {{0x82e80327,0x9e6433d2,0x229800e5,0xa4f00064}},	//   _རྗིའ, ناقن, yéki_, lėšų_, 
   {{0x0d85c8c9,0x64940e89,0x7c5401d5,0xc278011a}},	// [32ba0] хлан, màir, کللر_, _מרקי, 
   {{0x4f24675f,0x41a40166,0x7c240395,0x00000000}},	//   _здоб, _явын_, ноуг_, --, 
   {{0x2cb80162,0xca7401ec,0xef94029e,0x00000000}},	//   _vird_, нуды, _شیرد, --, 
   {{0x2cb9c8ca,0x88e42f33,0x0a481064,0x00000000}},	//   _wird_, ежде, язей_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69d05325,0x649400a3,0x00000000,0x00000000}},	//   _ड्री, hàir, --, --, 
   {{0x6d440077,0x2258045f,0x38c801d3,0x00000000}},	//   lxia, yksk_, _ہالی_, --, 
   {{0xd90c03e6,0xf8c80372,0x627801e4,0xddcc054e}},	//   _ژین_, زدۇۇ_, nĉot, miaţ, 
   {{0xa82400d1,0xddcc054e,0x4b380092,0x38c80244}},	//   _изаһ, liaţ, _የሚጠየ, _فالی_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd04c013f,0x06d800cc,0xe1f800ee,0x00000000}},	//   _ɛkɔp, _ধমকি, менч_, --, 
   {{0xbdd8007f,0x05840408,0xddcc01e4,0x2c6408a5}},	//   _inèg, _пулм, tiaŭ, _hödd_, 
   {{0x22580a85,0xb9e40023,0xc0b401d5,0xdb10032e}},	//   rksk_, _ኪድ_, нғич_, _áfös, 
   {{0x2005c8cb,0x649401c3,0x00000000,0x00000000}},	//   üli_, ràis, --, --, 
   {{0x5f95c8cc,0xbea40b7e,0xa37c008f,0xddcc012d}},	//   тивт, ешай, maĵo, ykań, 
   {{0xa37c00c8,0xddcc0311,0x644816a3,0x82a4008e}},	//   laĵo, diaţ, ljdi, _яшле, 
   {{0xdfd005d9,0xd5c4030d,0x00000000,0x00000000}},	// [32bb0] _پيج_, _чiен, --, --, 
   {{0x629dc8cd,0xa37c00c8,0x64480007,0x98ac0030}},	//   llso, naĵo, njdi, _preč_, 
   {{0xddcc054e,0x6d4582a6,0x00000000,0x00000000}},	//   giaţ, axia, --, --, 
   {{0x59740372,0x58d4fff2,0x98ac0427,0x82b40327}},	//   кылу, водт, _vreč_, དམིའ, 
   {{0xa37c008f,0xa3c0000d,0xe89800e5,0x00000000}},	//   kaĵo, ंखा_, کموں_, --, 
   {{0xa3bc4103,0x629c0423,0xe9d00131,0xa7fc0213}},	//   _अलग_, hlso, لغۇ_, _alıb, 
   {{0xba75c8ce,0xddcc084c,0xab8489af,0x81e40f22}},	//   _كارت, ciaţ, _бутк, _পান_, 
   {{0x9f400022,0x00000000,0x00000000,0x00000000}},	//   _pehê_, --, --, --, 
   {{0x12bc5d2d,0x2c64049f,0xbdd9b8a5,0xe8e001fb}},	//   _আবেদ, _född_, _inèd, _đệm_, 
   {{0x629c05e4,0x79996fee,0xb9d402d3,0xa37c008f}},	//   elso, _iyuw, _ጾር_, gaĵo, 
   {{0x67540014,0x0834010f,0x00000000,0x00000000}},	//   _میوس_, _שװער_, --, --, 
   {{0x7998020b,0x63a401e4,0xa7fc008e,0x00000000}},	//   _kyuw, _ĝint, _umır, --, 
   {{0x320c0034,0x7658009f,0x63a40115,0xa37c010f}},	//   ędy_, mkuy, _ŝint, baĵo, 
   {{0x10a52b64,0xddcc0227,0xcfe004c5,0xa37c0115}},	//   тигн, nkaņ, _বাহন, caĵo, 
   {{0xddcc0356,0x00000000,0x00000000,0x00000000}},	//   xiaţ, --, --, --, 
   {{0x6d4405f5,0x7659c8cf,0xdbc800af,0x1ea87500}},	//   txia, nkuy, _mõõd, فاقي_, 
   {{0x79980502,0x6d440327,0x00000000,0x00000000}},	// [32bc0] _nyuw, uxia, --, --, 
   {{0xe3b807b3,0x2d9c0882,0x6d44056a,0xddcc0356}},	//   mdır_, āve_, rxia, tiaţ, 
   {{0xbdd9c8d0,0xe3b8046c,0x76580548,0x8e85a7f2}},	//   _poèt, ldır_, kkuy, _агне, 
   {{0xa37c00c8,0xddcc0276,0x8c20009e,0x2c64032e}},	//   zaĵo, riaţ, নাইন_, _södd_, 
   {{0xe3b83bc2,0x81e404c5,0x28f9c8d1,0xc864004e}},	//   ndır_, _পাম_, хель_, ктки, 
   {{0xddcc0311,0x62840115,0x00000000,0x00000000}},	//   piaţ, _ĉiom, --, --, 
   {{0x8a040b16,0xa37c00c8,0xa7fc4953,0x614800e8}},	//   _изве, vaĵo, _alıc, _këlë, 
   {{0x76582819,0x61480de2,0x2c6401e3,0x09e400ea}},	//   gkuy, _jëlë, _döde_, _јоан, 
   {{0xa37c00c8,0x09041614,0x629c00b5,0x69c002d0}},	//   taĵo, _шпан, vlso, _igme, 
   {{0x6b9dc8d2,0x765918c9,0x99dc010b,0x22980036}},	//   _kyrg, akuy, _doňu, hékt_, 
   {{0x81e42158,0xa37c00c8,0x2c1406ab,0xa2b400a7}},	//   _পাব_, raĵo, न्यू_, лбоч, 
   {{0x4428151c,0x7ae17e82,0x6b9c1368,0xfba413f7}},	//   žb_, ânti, _myrg, केटम, 
   {{0x69c00327,0x99dc010b,0xa37c00df,0x25a000ae}},	//   _mgme, _goňu, paĵo, _áil_, 
   {{0xdd940588,0x00000000,0x00000000,0x00000000}},	//   ҳабы, --, --, --, 
   {{0x9f401132,0x02a455da,0x69c00036,0x828801b9}},	//   _kehé_, _ирим, _ogme, _осиб_, 
   {{0x229802fb,0xdd94cced,0xe3b80213,0xc0a800ec}},	//   téku_, габы, bdır_, _ڪابل_, 
   {{0xf1c402fb,0x1d34190b,0xe3b803b9,0xddcc00c0}},	// [32bd0] ášť_, ыная, cdır_, giaš, 
   {{0x69c1c8d3,0x799800ca,0x2129c8d4,0x6b9dc8d5}},	//   _agme, _ryuw, _isah_, _byrg, 
   {{0x69c00175,0xd9f9c8d6,0xd0100137,0xa37c0115}},	//   _bgme, енец_, _الپ_, kaĵm, 
   {{0x614800e8,0x6b9c89b7,0x229800e8,0xa37c00df}},	//   _gëlë, _dyrg, péku_, vaĵl, 
   {{0xe9d80953,0x68e00042,0x22980c6a,0xddcc0153}},	//   ткі_, _cwmd, léks_, onaž, 
   {{0xfa2000bd,0x69c1c8d7,0xd709c8d8,0xb8e801bc}},	//   ফাইল_, _egme, енке_, _रं_, 
   {{0x12bc09bd,0xe3b80259,0x6b9c00ee,0x614800e8}},	//   _আব্দ, zdır_, _gyrg, _yëlë, 
   {{0xddcc0029,0xe3b87975,0xa37c01e4,0x9774035b}},	//   skaņ, ydır_, raĵl, ктқә, 
   {{0x76586b84,0x3a3c7bad,0x79985745,0xf8046f9f}},	//   rkuy, _inup_, _uyuw, _ачен, 
   {{0x7659c8d9,0x229801c7,0xe3b803e0,0x00000000}},	//   skuy, zékt_, vdır_, --, 
   {{0x91e411ac,0x2129bb19,0x7d1804e6,0x00000000}},	//   лоне, _asah_, _äusf, --, 
   {{0xe3b800ac,0x22980098,0x76580113,0xd1751499}},	//   tdır_, déks_, qkuy, гыгы, 
   {{0xd17420f3,0x26b0568c,0xc6900a7c,0x4a58011a}},	//   уыны, _بەيز, _פאד_, גדרו, 
   {{0xe3b80baf,0x95b40032,0x99dc0118,0x81e400fe}},	//   rdır_, _ирҙә, _koňs, _পাণ_, 
   {{0x212805b1,0xbdd8068c,0x9974033f,0x4c8402a9}},	//   _esah_, _roèr, nęło_, ҳлав, 
   {{0x6fd40882,0x53440022,0xddcc00d7,0x00000000}},	//   _ब्रू, _ахҩа, tiaš, --, 
   {{0x4c848a6b,0xe3b803be,0x6b9dba08,0xbea004f0}},	// [32be0] глав, qdır_, _syrg, сатк, 
   {{0x6b9dc8da,0x2cbc007c,0x00000000,0x00000000}},	//   _pyrg, övd_, --, --, 
   {{0x81e40183,0x4e840014,0x00280023,0x9974012d}},	//   _পাত_, _مٔدٕ, _ብምዃኖ, jęło_, 
   {{0xc9840aa8,0x628401e4,0x2cb00024,0x627801e4}},	//   лули, _ĉiok, _žodį_, nĉop, 
   {{0xc278010f,0x7be003d4,0x00000000,0x00000000}},	//   ערני, _পাৰো, --, --, 
   {{0xa92802f0,0x00000000,0x00000000,0x00000000}},	//   južš, --, --, --, 
   {{0xb8e80acd,0xcb680e92,0x3ea80051,0x3c60117e}},	//   _रू_, _џабе_, _yhct_, _укрг, 
   {{0x36850bf3,0xca740598,0x09dc015b,0xe820012c}},	//   лсын_, _сугы, _ডাকা, _यसका_, 
   {{0x3e7c088b,0x6ab001ad,0x00000000,0x00000000}},	//   lätä_, जगीर, --, --, 
   {{0x7cf806ea,0x64740276,0x6fd403ce,0x00000000}},	//   _hørð, ргоу, _ब्लू, --, 
   {{0x4df4012c,0x3e7c01f4,0x07a40064,0x00000000}},	//   ेलाई_, nätä_, _сажн, --, 
   {{0xa294063b,0x21b400d6,0x7d180a40,0x7cf8022c}},	//   рамі, ийня, _äusg, _jørð, 
   {{0xe3b86656,0x3ea80042,0x3e7c0108,0x00000000}},	//   rdıq_, _rhct_, hätä_, --, 
   {{0xb17402d3,0x3e6400af,0xa3d5c8db,0x2298003e}},	//   _ብኸምዚ_, _mõte_, _токч, téks_, 
   {{0x442c049f,0x748000aa,0x2f1800a8,0xe3b803e3}},	//   _iaf_, _دټول, лорь_, pdıq_, 
   {{0x442dc8dc,0xddcc5797,0x3f9c0421,0x8284036b}},	//   _haf_, snaž, āuu_, _حجتل, 
   {{0x5c75c8dd,0x2129c8de,0xbdd800cf,0xddcc0210}},	// [32bf0] алат, _usah_, _anèc, mnaż, 
   {{0x442dc8df,0x3a3c037e,0xdfd000ec,0x00000000}},	//   _jaf_, _snup_, _ڏيک_, --, 
   {{0x442dc8e0,0xb09c010f,0x2cb40118,0x39481074}},	//   _maf_, _איזר, _řadí_, کشاپ_, 
   {{0x442dc8e1,0x69c4a2ef,0x5e6000d1,0x00000000}},	//   _laf_, žien, _بۆرە, --, 
   {{0xd945c8e2,0x442c0270,0x99dc010e,0x00000000}},	//   рели, _oaf_, _soňs, --, 
   {{0x442dc8e3,0x2c14d054,0xe894005b,0x35680092}},	//   _naf_, न्दू_, бачь, ታይበት_, 
   {{0x66d4083c,0x6d40a547,0x7cf80162,0xead40024}},	//   yükş, _àmar, _førð, _гось, 
   {{0x442dc8e4,0x7ae0084c,0x7cf80162,0x6b7401c0}},	//   _aaf_, ântu, _gørð, _улсу, 
   {{0x81e809bd,0x98b9c8e5,0xb8046ea9,0x7d1804e6}},	//   মলা_, _алат_, _مباه, _äusd, 
   {{0x9404038b,0x99dc010e,0x6fb000eb,0x00000000}},	//   جوده, _goňr, জুয়ে, --, 
   {{0x442dc8e6,0xa5640799,0x53a5c8e7,0x52a80063}},	//   _daf_, لدین, ранб, квом_, 
   {{0x67b84c1c,0x442c5109,0xcb100375,0x2c6401e3}},	//   _صالح_, _eaf_, חלט_, _möda_, 
   {{0x442dc8e8,0x940438b7,0x99e400a2,0x83502a77}},	//   _faf_, _نوشه, _gaňň, مپیا, 
   {{0x442dc8e9,0x00000000,0x00000000,0x00000000}},	//   _gaf_, --, --, --, 
   {{0xa7fc0166,0x99e4010b,0x00000000,0x00000000}},	//   _olın, _zaňň, --, --, 
   {{0x442c7831,0x3e7c0108,0xddcc0432,0x00000000}},	//   _zaf_, vätä_, njaň, --, 
  
   {{0x3b340020,0x645d65e1,0x7cf803b2,0xcc8869f2}},	// [32c00] _የሚገኘ, örig, _rørð, پناه_, 
   {{0xa7fc3e67,0x628401e4,0x442d6078,0x2c64007c}},	//   _alın, _ĉioi, _xaf_, _böda_, 
   {{0xa37c01e4,0x00000000,0x00000000,0x00000000}},	//   vaĵk, --, --, --, 
   {{0x3e7c6c31,0xcda88a41,0x2c64049f,0x99dc0209}},	//   rätä_, _لهجه_, _döda_, _soňr, 
   {{0x6e241a90,0x3e7c5d8a,0x67d5c8ea,0xa3e9b546}},	//   meib, sätä_, болу, बरम_, 
   {{0x2c6401e6,0xa7fc00fd,0xfce001a9,0x3e7c005b}},	//   _föda_, _elın, _форо, pätä_, 
   {{0x81e4015b,0x2c64007c,0x99e4010e,0x00000000}},	//   _পাস_, _göda_, _saňň, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x442dc8eb,0x69348b25,0x960800f1,0x00000000}},	//   _paf_, _دکار, اکمې_, --, 
   {{0x6e25c8ec,0x442dc8ed,0x7d180036,0xc4b00cb2}},	//   heib, _qaf_, _äuse, ीदेख, 
   {{0x442dc8ee,0x82a4858e,0x6e2400b5,0x2259c8ef}},	//   _vaf_, ишме, keib, гины_, 
   {{0x442d9ee3,0x99e400a2,0x81e400cc,0x00000000}},	//   _waf_, _taňň, _পাহ_, --, 
   {{0x442dc8f0,0xe4d46e9a,0x6e25c8f1,0xc17002d3}},	//   _taf_, _اقتد, deib, _ኣድላዪ_, 
   {{0x645c0037,0xcfe000eb,0x00000000,0x00000000}},	//   örid, _বাউন, --, --, 
   {{0xf0b400d6,0xc2e407d6,0x1df812c4,0x7d0c0175}},	//   ійсь, _тўли, левы_, _sqcs, 
   {{0x2c64049f,0xded40020,0x00000000,0x00000000}},	//   _röda_, ክለኛ_, --, --, 
   {{0xb320025c,0xa1140472,0x00000000,0x00000000}},	// [32c10] _འགོང_, _اوخت, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x5b144db0,0xa7fc0205,0x00000000,0x00000000}},	//   смет, _alıo, --, --, 
   {{0x2c640793,0x3d0402ab,0xbe6000cf,0xc6842a93}},	//   _vöda_, िंदे_, _بۇري, _رِ_, 
   {{0xb924ba46,0xb7c000d8,0x00000000,0x00000000}},	//   рфей, çãoz, --, --, 
   {{0xad4400f7,0x068400d1,0xaf34179e,0x00000000}},	//   _بۉكۉ, ﺭﻟﯜﻙ_, _اریت, --, 
   {{0xda342b41,0x428c0020,0xb320031c,0x0de8001f}},	//   _левы, _ነፃነት_, _འགེང_, _ህንፃ_, 
   {{0xba746ad1,0xa7fc008e,0xaa94030d,0x562854d9}},	//   _ئاست, _ulın, _дисч, ужим_, 
   {{0x95980c98,0x9554007b,0xaa5811eb,0x00000000}},	//   ытку_, إخبا, _титу_, --, 
   {{0x986400dd,0x81bc015b,0x6e245380,0x00000000}},	//   _دیتے_, েরা_, zeib, --, 
   {{0x6e24431a,0x8c1808c3,0x00000000,0x00000000}},	//   yeib, אותי, --, --, 
   {{0xf1c800d1,0xa90400f1,0x53a40150,0x00000000}},	//   шқий_, _دبېن, _қайб, --, 
   {{0x6e2419a2,0x81e4015b,0xa7fc008e,0x84600092}},	//   veib, _পাশ_, _olıl, ዴሬሽን_, 
   {{0xe6c40132,0x7bc00306,0xa7fc25a8,0xa3e800bc}},	//   _اتەي, žnuj, _nlıl, बरण_, 
   {{0x81e4015b,0x62840115,0x645c023a,0x8fa5c8f2}},	//   _পার_, _ĉiov, örie, саве, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6e25c8f3,0x41b004b3,0x00000000,0x00000000}},	// [32c20] reib, _ىمىر, --, --, 
   {{0xcfe000cc,0x00000000,0x00000000,0x00000000}},	//   _বাকন, --, --, --, 
   {{0xddcc010f,0xadc401af,0x00000000,0x00000000}},	//   lkaŝ, _манһ, --, --, 
   {{0x7c3803f9,0x00000000,0x00000000,0x00000000}},	//   _ɗuri, --, --, --, 
   {{0x2eb5c8f4,0xddcc00df,0xfc4000db,0x200403b2}},	//   ंगीत, nkaŝ, تپەپ, ólig_, 
   {{0xd90c10e5,0xb600025c,0x00000000,0x00000000}},	//   ئیل_, _ħġar, --, --, 
   {{0xd7f80220,0xf1c813e0,0xcb680640,0x998801e4}},	//   руі_, रखान, _саве_, ɾaŭ_, 
   {{0xf4000c99,0x5694004b,0xa7fc0205,0xfa640f06}},	//   _མཐུད_, يديځ, _ilım, _ласк_, 
   {{0x89658637,0xc965c8f5,0xd1dc0092,0x00000000}},	//   _укаж, _увай, ናኘት_, --, 
   {{0x2c640793,0xa2f461ac,0x00000000,0x00000000}},	//   _mödo_, опоч, --, --, 
   {{0xdef002d3,0xf7415de0,0x2f38033b,0x81bc00fe}},	//   ልወና_, _нефо, _nčg_, েৰা_, 
   {{0xbdd80066,0xc1080139,0x645c01f4,0x00000000}},	//   _anèn, лэге_, örib, --, 
   {{0x9f40004e,0x1c1828fe,0x09d00154,0x3de400cc}},	//   _vehí_, न्डल_, ারপা, _ফালল, 
   {{0x2348fc20,0x00000000,0x00000000,0x00000000}},	//   _نسبی_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa7fc1918,0xdc54026a,0x628d2a2c,0x00000000}},	// [32c30] _alım, овањ, _ijao, --, 
   {{0x60dc0072,0x12d80150,0xaffc030d,0x2e240051}},	//   mpsm, _ﺃﻨﻅﺭ, _йоьi, đườn, 
   {{0xfba85225,0x60dc020c,0x99d8007b,0x6bd400be}},	//   утай_, lpsm, لواء_, ستلر, 
   {{0x60dc0ea0,0x00000000,0x00000000,0x00000000}},	//   opsm, --, --, --, 
   {{0x7e7c0113,0x97c40719,0xa3e8447d,0x8ca82144}},	//   miqp, ойле, बरा_, _जीवो, 
   {{0x7e7c0cfe,0x69351499,0x9b441fb8,0x00000000}},	//   liqp, янчу, _وچاو, --, 
   {{0xa9cc0150,0x00000000,0x00000000,0x00000000}},	//   _ﯗﻛﯩﺴ, --, --, --, 
   {{0x7e7c3209,0xda082e67,0x195800db,0xaa6401a9}},	//   niqp, _خيره_, _кабы_, _етук, 
   {{0x81e4009e,0x72a400d1,0x00000000,0x00000000}},	//   _পাং_, ۋەتن, --, --, 
   {{0x7e7c03f0,0x00000000,0x00000000,0x00000000}},	//   hiqp, --, --, --, 
   {{0x60dc01f5,0xb7640395,0x661c00e5,0x00000000}},	//   epsm, _утай, őrka, --, 
   {{0x2f3802e2,0xa1f000d1,0x15b804f0,0x00000000}},	//   _rčg_, ىۋىت, _кылы_, --, 
   {{0xe71801ec,0x00000000,0x00000000,0x00000000}},	//   _نيەت_, --, --, --, 
   {{0x7bc577f4,0x316c2634,0xd0080063,0xa9280118}},	//   _ngju, ądz_, јеве_, lužá, 
   {{0x1fb4e58b,0x00000000,0x00000000,0x00000000}},	//   зстр, --, --, --, 
   {{0xaaa800c5,0xc0540092,0x00000000,0x00000000}},	//   _छींक, _ያገለግ, --, --, 
   {{0x4d4802dd,0xe18800ec,0x00000000,0x00000000}},	// [32c40] шпан_, _ٿئين_, --, --, 
   {{0x3e6400af,0x00000000,0x00000000,0x00000000}},	//   _võta_, --, --, --, 
   {{0x49c8db74,0x7b840ae5,0x846c0092,0x00000000}},	//   ален_, يامە, _ብዙሀን_, --, 
   {{0xcfe00154,0x09d00154,0x00000000,0x00000000}},	//   _বাটন, ারভা, --, --, 
   {{0x67d41318,0x2d840124,0xb8d0007b,0x00000000}},	//   полу, _ãme_, وتوش, --, 
   {{0x786c01bf,0xd9b00137,0x00000000,0x00000000}},	//   _løvf, رەلد, --, --, 
   {{0x4669c8f6,0xa7fc0166,0x09d00154,0x00000000}},	//   ирим_, _ulım, ারবা, --, 
   {{0x7bc402d3,0xba2000f3,0x84880023,0x60dc03b2}},	//   _zgju, _одск, _ዝብላዕ_, ypsm, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbdd80ba1,0xc86400c6,0x7ae40175,0xddcc0205}},	//   _anèl, _بطري, _ywjt, kkaş, 
   {{0xe3b8825f,0x787001d9,0xfbd00375,0x00000000}},	//   ldız_, _تُلا, ותת_, --, 
   {{0x75d002dd,0x628400df,0x62340108,0x00000000}},	//   _قيما, _ĉios, чему, --, 
   {{0x26cdc8f7,0x60dc0113,0xd4240154,0xd24c00f7}},	//   _hudo_, upsm, বাড়ি_, اچى_, 
   {{0x3de41c82,0x7410501f,0x26cdc8f8,0x60dc5f87}},	//   _ফাইল, _يونا, _kudo_, rpsm, 
   {{0x64581730,0x628c020c,0xa7fc62c7,0x7e7c03f0}},	//   _iovi, _tjao, _alık, tiqp, 
   {{0x26cc01d9,0x6459c8f9,0xa1942626,0x60dc0250}},	//   _mudo_, _hovi, _найч, ppsm, 
   {{0x26cc04ac,0x6459c8fa,0x7e7c03f0,0x65605deb}},	// [32c50] _ludo_, _kovi, riqp, nymh, 
   {{0x7e7cdaaa,0x00000000,0x00000000,0x00000000}},	//   siqp, --, --, --, 
   {{0x6458c337,0x60cc957e,0x61edc8fb,0x7e7dc8fc}},	//   _movi, _huam, _keal, piqp, 
   {{0x60cdc8fd,0x3f90011f,0x629dc8fe,0x7e7c0309}},	//   _kuam, _ixxu_, noso, qiqp, 
   {{0x26cc0295,0x645801e2,0x60cdc8ff,0x1ca403e6}},	//   _audo_, _oovi, _juam, _فێری_, 
   {{0x60cdc900,0x61edc901,0x629dc902,0x26cdc903}},	//   _muam, _leal, hoso, _budo_, 
   {{0x60cc0084,0x26cc0fcf,0xab85c904,0x02c41b87}},	//   _luam, _cudo_, _жутк, _रंगभ, 
   {{0x629d1f29,0x26cc0407,0x60cd9690,0x60c4014f}},	//   joso, _dudo_, _ouam, _lihm, 
   {{0x65600368,0x60cc0356,0x786c005c,0x05c80210}},	//   gymh, _nuam, _røvf, ाख़ब, 
   {{0x61ec0618,0x26cdc905,0x60c4014f,0x1308023a}},	//   _aeal, _fudo_, _nihm, бной_, 
   {{0x61edc906,0x629c06ee,0x60cc166a,0xbdd800db}},	//   _beal, foso, _auam, _anèm, 
   {{0x61ed8026,0xe3b80598,0xd0100014,0x60cc0127}},	//   _ceal, ndıy_, کلس_, _buam, 
   {{0x6459c907,0x61ec8627,0x60c4014f,0x60cc01ab}},	//   _fovi, _deal, _bihm, _cuam, 
   {{0x6459c908,0x26cdc909,0x7539c90a,0xc950011a}},	//   _govi, _yudo_, mvuz, עמם_, 
   {{0x61edc90b,0x26cc036b,0x3f640117,0x7f400117}},	//   _feal, _xudo_, пиро_, нерж, 
   {{0x61ec0fa3,0x6459c90c,0x786c1125,0x60cdc90d}},	//   _geal, _zovi, _høvd, _fuam, 
   {{0x645800f1,0x60ccc3e7,0x786c03b2,0xba18002e}},	// [32c60] _yovi, _guam, _køvd, nu鯵u, 
   {{0x60c40399,0xed580b01,0x00000000,0x00000000}},	//   _gihm, боғ_, --, --, 
   {{0x60cc0998,0x61ec4e6c,0x8b2402bf,0x7d180036}},	//   _zuam, _yeal, ядже, _äusn, 
   {{0x26cc05b8,0x60cc0218,0x786c0fac,0x5f740014}},	//   _rudo_, _yuam, _løvd, _کۅہس_, 
   {{0x26cdc90e,0x60c4014f,0x2d8400c7,0x28f800c0}},	//   _sudo_, _yihm, _äme_, цель_, 
   {{0xf7f004a9,0x26cc204e,0x629dc90f,0x00000000}},	//   ىسىد, _pudo_, zoso, --, 
   {{0x629dc910,0x79cc005e,0xf7f00116,0x6eb0121d}},	//   yoso, _ﯗﻛﯩﻤ, رسود, ंतपु, 
   {{0xfaa1c911,0x629c0005,0x88c85716,0x99880010}},	//   _засо, xoso, _глав_, žaš_, 
   {{0x629dc912,0xf64d003d,0x26cc020c,0x27ec0427}},	//   voso, ائى_, _wudo_, _tedn_, 
   {{0x26cc0cfc,0x60cc00b0,0x629dc913,0x61edc914}},	//   _tudo_, _ruam, woso, _seal, 
   {{0x61ec367a,0x60cdc915,0x22946ac5,0x60c5c916}},	//   _peal, _suam, диня, _rihm, 
   {{0xbdd802bd,0x645801e2,0x60c4014f,0x00000000}},	//   _enèj, _wovi, _sihm, --, 
   {{0x60cc0de4,0xf484168d,0xe5342607,0x60c4014f}},	//   _quam, _کانی, _цель, _pihm, 
   {{0x60cc02c4,0x60c4014f,0x61ec0c18,0xdde002b5}},	//   _vuam, _qihm, _weal, ātōt, 
   {{0x60c5c917,0xda0c09d9,0x61edc918,0x81bc015b}},	//   _vihm, _हालत_, _teal, েরই_, 
   {{0x60cdc919,0x629c03b4,0x816828a8,0x61ec02d0}},	//   _tuam, qoso, _гроб_, _ueal, 
   {{0x224801a2,0x786c13ce,0x60c4014f,0x7c84010b}},	// [32c70] _inak_, _høve, _tihm, пуже, 
   {{0xdfd000c6,0x7c840eba,0x00000000,0x00000000}},	//   _جيد_, чубе, --, --, 
   {{0xde5802bf,0x2248b737,0x7538004c,0x5f940276}},	//   _дані_, _knak_, zvuz, _цинт, 
   {{0xddcc0153,0x00000000,0x00000000,0x00000000}},	//   liaž, --, --, --, 
   {{0x786c2188,0x17c86c48,0xe8f80024,0x00000000}},	//   _løve, огли_, злі_, --, 
   {{0xbdd8020c,0xa8840131,0xddcc00d0,0x00000000}},	//   _onèk, ىلنى, niaž, --, 
   {{0x2249c91a,0x00000000,0x00000000,0x00000000}},	//   _onak_, --, --, --, 
   {{0x645dc91b,0x79a4010b,0x00000000,0x00000000}},	//   örin, _ерзе, --, --, 
   {{0xbdd80100,0xddcc0006,0x628400df,0xa9c40137}},	//   _anèk, kiaž, _ĉiop, _كۅمۉ, 
   {{0x224983d4,0xc4800d31,0x786c03cd,0x9f40005b}},	//   _anak_, клык, _bøve, _kehä_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x1fc400bd,0xe61003e6,0x786c072b,0x00000000}},	//   ্রাস, _مشه_, _døve, --, 
   {{0xb148028e,0x75806646,0x461002f2,0x9f500200}},	//   سیدم_, _سیدم, _شوور, bazë_, 
   {{0x2249c91c,0x00000000,0x00000000,0x00000000}},	//   _enak_, --, --, --, 
   {{0x99dc00a2,0x261409ab,0x00000000,0x00000000}},	//   _doňz, _धामी_, --, --, 
   {{0x0ea80024,0x00000000,0x00000000,0x00000000}},	//   ікай_, --, --, --, 
   {{0x32d007ae,0x7d1801c7,0x50b400fb,0x3ea03dad}},	// [32c80] _hãy_, _äusl, _осоу, титг, 
   {{0x786c5522,0x8fd0104e,0x1d1800f5,0x0081c91d}},	//   _løvb, _шәмә, яюсь_, _альо, 
   {{0x7c5401d5,0xca7402dd,0x202800d7,0xded00150}},	//   بللر_, муды, ätiť_, _ﻛﺎﺳﺒ, 
   {{0xaca4063f,0x2c640793,0x22480ac5,0x00000000}},	//   _inọr, _mödi_, _xnak_, --, 
   {{0xbdf9c91e,0x309c00b8,0x26140210,0x00000000}},	//   _برپا_, _ṛṣit, _धाबी_, --, 
   {{0xbdd8020c,0x00000000,0x00000000,0x00000000}},	//   _anèh, --, --, --, 
   {{0x1b0005f5,0xfbc1c91f,0x32d001fb,0xf7900953}},	//   _бүхн, _абро, _nãy_, кашэ, 
   {{0xa53421fa,0x786ca3ba,0x27e000df,0x7bc000d7}},	//   енич, _røve, ŝin_, ľnut, 
   {{0x786c5522,0x3ea400e4,0x224801d5,0x6d4002f0}},	//   _døvb, _ênte_, _rnak_, _šmaj, 
   {{0x22481a31,0x83840220,0x635409ac,0xa7fc0205}},	//   _snak_, дыме, евоу, _alıv, 
   {{0x2248020c,0x9f500200,0xddcc0419,0x00000000}},	//   _pnak_, razë_, viaž, --, 
   {{0x05640262,0x32d001fb,0x57240acb,0x63b40139}},	//   _овен, _dãy_, _سرمق, _ıenı, 
   {{0xaca401f2,0xddcc00d0,0x76b8011a,0x00000000}},	//   _anọr, tiaž, _ומאפ, --, 
   {{0x961c005f,0x786c1600,0x9f3553cd,0x00000000}},	//   miņa, _tøve, негі, --, 
   {{0x32d001fb,0xbdd8020c,0x961c00e2,0x43b001af}},	//   _gãy_, _unèk, liņa, _шҡор, 
   {{0x22496638,0x60f8005b,0x00000000,0x00000000}},	//   _unak_, _ения_, --, --, 
   {{0xdfd473c7,0xc0580220,0x961c00e2,0xaee4002b}},	// [32c90] _попы, _дін_, niņa, _puṃv, 
   {{0xefe00201,0x7d180036,0xa1f801ed,0x81e40011}},	//   ናቸው_, _äusm, _بڑھا_, _পাট_, 
   {{0xb6340790,0x9f40007c,0x32d00051,0x00000000}},	//   çükç, _behå_, _xãy_, --, 
   {{0x9de81b35,0x961c0227,0x22980122,0xefd40023}},	//   _འབྲེ, kiņa, téky_, ራዋይ_, 
   {{0xd8240ce4,0x8dd80375,0x3e640254,0x961c00e2}},	//   едли, _מקרק, _lõtk_, jiņa, 
   {{0x9f40005b,0x645c005b,0xf848005b,0x961c00e2}},	//   _tehä_, öril, ючей_, diņa, 
   {{0x07a024ca,0xc7a1c920,0x20340023,0x00000000}},	//   лашн, лишк, _ብዝተረ, --, 
   {{0x1cdc0489,0xa37c0115,0x776003ac,0x00000000}},	//   _ལྕོ_, vaĵp, rynx, --, 
   {{0x79a42424,0xa7fc0139,0xaee400dc,0x9988033f}},	//   _црве, _alıu, _bhṛt, żał_, 
   {{0x1308005b,0x6d4001ef,0x00000000,0x00000000}},	//   пной_, _šmak, --, --, 
   {{0xfe0c46c7,0xaee40882,0x69c40024,0x99dc00a2}},	//   िलास_, _dhṛt, žiet, _soňy, 
   {{0x2c64014a,0xa37c01e4,0x961c00e2,0x2004148b}},	//   _vödi_, raĵp, biņa, ólin_, 
   {{0x7649c921,0xf4740046,0x961c00e2,0x5bbc00bc}},	//   _ingy, _жөні_, ciņa, ्खुव, 
   {{0x1cdc003d,0x2c6405d5,0xaee400dc,0x4558011a}},	//   _ལྕེ_, _tödi_, _ghṛt, _מכנס, 
   {{0x2335c922,0xfc4c001f,0x7580179e,0xd7f00051}},	//   _ахыр, _አረጋግ, _سیگم, _mẽ_, 
   {{0xbea1c923,0xddcc012d,0xd7f00208,0x718401ec}},	//   гаск, ciaż, _lẽ_, _ақме, 
   {{0x3d040406,0x4c680022,0x8cc800ae,0xbe3000cf}},	// [32ca0] िंगे_, пиан_, سواق_, دىقب, 
   {{0x98ac01e4,0x846c02d3,0xc19802e4,0xaff801d3}},	//   _preĝ_, _ብዙሓን_, _משפי, _زہرا_, 
   {{0x961c00da,0x09b805cd,0x00000000,0x00000000}},	//   ziņa, ेश्य, --, --, 
   {{0x649c05d2,0xe1a401f9,0x00000000,0x00000000}},	//   _içiş, _गुडघ, --, --, 
   {{0xaca402e3,0x9e700131,0xbb1400d1,0x00000000}},	//   _arụs, _ئۇقت, ﺳﻠﻰ_, --, 
   {{0x7649c924,0x961c00e2,0x81e400fe,0xf98416ac}},	//   _angy, viņa, _পাছ_, عنوي_, 
   {{0x6f1c01e0,0x645c023a,0x3200022e,0x6d4002f0}},	//   ntrc, örim, _odiy_, _šmah, 
   {{0x961dc925,0x3200009a,0x00000000,0x00000000}},	//   tiņa, _ndiy_, --, --, 
   {{0xba14046f,0x00000000,0x00000000,0x00000000}},	//   _سيلا_, --, --, --, 
   {{0x961dc925,0x7649c926,0x3200022e,0x7d78011a}},	//   riņa, _engy, _adiy_, פניו, 
   {{0xe1f80372,0x998800d0,0x00000000,0x00000000}},	//   үгү_, ľať_, --, --, 
   {{0x998801f1,0x961c00e2,0x00000000,0x00000000}},	//   žať_, piņa, --, --, 
   {{0x24180046,0x5fd40e49,0x6ef0002b,0x00000000}},	//   _жолы_, _दलदल, _āviṣ, --, 
   {{0x7410034c,0xf47c0023,0x786c03b2,0xa7fc0205}},	//   _موها, _ትፈልጥ_, _køva, _ilıs, 
   {{0x2f2800a7,0x7649c927,0x00000000,0x00000000}},	//   нюто_, _yngy, --, --, 
   {{0x04c400b2,0x7d180036,0xa2c401af,0x00000000}},	//   _توڙي_, _äusk, _шәпк, --, 
   {{0xbbe800c6,0x786c332e,0x9c38004e,0x1bd4be81}},	// [32cb0] كرام_, _løva, мпат_, возя, 
   {{0x212800d5,0xed046f04,0x22580166,0x00000000}},	//   _ipah_, اولپ, ljsk_, --, 
   {{0x200001d9,0x81bc0154,0xddcc01e4,0x749805d0}},	//   _idhi_, েরও_, lhaŭ, לימפ, 
   {{0x2128001e,0x3e8401e1,0xd7f0001e,0xa7fc013d}},	//   _kpah_, _dìtè_, _sẽ_, _olıs, 
   {{0x98ac0618,0x5fd417ee,0xddcc0115,0xa90401e2}},	//   _aseā_, _दलाल, nhaŭ, هبون, 
   {{0x684800ef,0x00000000,0x00000000,0x00000000}},	//   _nīdē, --, --, --, 
   {{0xdcb01b56,0xdb1402e2,0xac94013e,0xa7fc03e0}},	//   _مىڭ_, _egzò, _сарш, _alıs, 
   {{0x21284c8f,0xbdd80100,0x6edc09a8,0x33240175}},	//   _opah_, _enèv, _učbe, _rpnx_, 
   {{0x58d400d6,0x69c463e5,0xb4001d37,0x00000000}},	//   _розт, žier, гүлд, --, 
   {{0x2bb8032c,0x20000066,0x94a800e5,0x00000000}},	//   _अरमा, _ndhi_, باعِ_, --, 
   {{0x2129c928,0x91e43ad8,0xe6b401b9,0x99880210}},	//   _apah_, коне, ضلیگ, żań_, 
   {{0x2001c929,0x796400b0,0xddcdc92a,0x78a001f4}},	//   _adhi_, _tīwā, fhaŭ, lonv, 
   {{0xa5640597,0x0fd8023a,0x21f801c6,0x8678011a}},	//   _مدون, дьбы_, эхээ_, _קרנו, 
   {{0xe8042144,0x00000000,0x00000000,0x00000000}},	//   रणया_, --, --, --, 
   {{0x8fa4af8b,0xddcc0227,0x00000000,0x00000000}},	//   таве, kjań, --, --, 
   {{0xe3b02b09,0x2bb802ab,0xb640037e,0x20000055}},	//   _اره_, _अरबा, _ｎａ_, _edhi_, 
   {{0xc5f0159d,0x61e800fd,0x6f1c02f0,0xd0940166}},	// [32cc0] ידן_, ñele, strc, _ашны, 
   {{0xa2d8012c,0x504400d8,0x00000000,0x00000000}},	//   _नंम्, _реоб, --, --, 
   {{0x78a1c92b,0xbdd8068c,0xa7fc0166,0x00000000}},	//   donv, _anèu, _olır, --, 
   {{0x786c3619,0x7f7802dd,0xe3b80205,0x961c00de}},	//   _røva, _ﺃﺠل_, kfın_, diņo, 
   {{0x786c01bf,0x645c0821,0x00000000,0x00000000}},	//   _søva, örik, --, --, 
   {{0xa7fc0abc,0x1cdc0003,0x78a01418,0x672805b1}},	//   _alır, _ལྕི_, gonv, _ppdj, 
   {{0xdd100139,0xd1d40092,0x00000000,0x00000000}},	//   _küşe, ራራት_, --, --, 
   {{0xc6a400a7,0x58e003d4,0xddcc0210,0x00000000}},	//   ърли, _নিৰী, cjań, --, 
   {{0x08c53b11,0x78a05a22,0x6fc0015b,0xdd100205}},	//   _абан, bonv, ্রয়ে, _müşe, 
   {{0x78a1c92c,0xc32c04a9,0x3e6400c5,0xb82400c7}},	//   conv, قەت_, _võti_, _иоуз_, 
   {{0x21280652,0xd7a8375c,0x961c0171,0x00000000}},	//   _spah_, _चुपच, ciņo, --, 
   {{0x786c06ea,0x224c6131,0x21780108,0x995403e0}},	//   _jøvn, ñek_, еймы_, nüşe_, 
   {{0xe3c400f7,0xaf340214,0x34340214,0x00000000}},	//   _өркү, یرفت, رسید_, --, 
   {{0x8cd40c2e,0x2c6405d5,0x2584005f,0x50a401e0}},	//   _बढ़ो, _möds_, rīlī_, гусҡ, 
   {{0xbdd80100,0x2f180276,0x00000000,0x00000000}},	//   _onèt, корь_, --, --, 
   {{0x443c2188,0x786c06ea,0x78a003ac,0xf2c401ee}},	//   ldt_, _nøvn, zonv, _ксын, 
   {{0xdd1045e3,0x212856e4,0x961c00da,0x443dc92d}},	// [32cd0] _düşe, _upah_, ziņo, odt_, 
   {{0xbdd8067c,0x1a6436bd,0xad241c02,0x4dc401e0}},	//   _anèt, گیری_, شىمى, урсҡ, 
   {{0x78a1c92e,0x443dc92f,0xddcc0227,0x1c180ce0}},	//   vonv, idt_, tjań, न्गल_, 
   {{0x3ebdc930,0x1a641809,0xbdd800f2,0xaca40432}},	//   _òut_, دیری_, _pnèu, _baỳr, 
   {{0x78a1c931,0x00000000,0x00000000,0x00000000}},	//   tonv, --, --, --, 
   {{0x443c0cf9,0x1cdc0135,0x2c640267,0x1c382347}},	//   jdt_, _ལྕག_, _döds_, _язгы_, 
   {{0x443c0099,0x786c03b2,0x9f500306,0x7ac401af}},	//   ddt_, _føvn, kazí_, _асае, 
   {{0x443dc932,0xbdd8007f,0xc1e01b87,0x2c640267}},	//   edt_, _inès, _क्लब_, _föds_, 
   {{0x443c009a,0xb8b002dd,0x26141bbb,0x864000c7}},	//   fdt_, _көкі, _धारी_, сныж, 
   {{0xdb10032e,0xe3b80205,0xe7080137,0xa8a4009b}},	//   _ífót, rfın_, رتۉن_, _крхк, 
   {{0x67d459e6,0x6628007c,0x00000000,0x00000000}},	//   _тоху, äskå, --, --, 
   {{0xe0c800c8,0x443dc933,0x76c4007b,0x00000000}},	//   _זײ_, adt_, _شغال, --, 
   {{0x443c0077,0xfbc00316,0x79980254,0xb4000139}},	//   bdt_, वेतम, _jxuw, _күпд, 
   {{0xbdd8067c,0x7659c934,0x2eac00cd,0x00000000}},	//   _onès, ljuy, चत्त, --, 
   {{0x786c03cd,0xec3401b9,0x0c240131,0x99540790}},	//   _løvo, یورگ, һман, yüşe_, 
   {{0x76580a1d,0xdcfc5043,0xd7f00051,0x9e740063}},	//   njuy, _azsı, _dõi_, аћуј, 
   {{0xf27400f1,0xa3e80073,0xa80400fd,0xfce0020f}},	// [32ce0] _مخکښ, बरच_, _yañğ, йото, 
   {{0xf54c01f2,0x786c0450,0x290000d0,0x961c00e2}},	//   _bụzi_, _søvn, šiak_, diņm, 
   {{0x645c00af,0x8e8400a7,0x629c2dfb,0xdd100139}},	//   örii, _бгне, érog, _tüşe, 
   {{0x998c068f,0xc9f40150,0x765802a8,0x09d00eac}},	//   _oceń_, اساع, jjuy, ার্থ, 
   {{0x443c00b5,0xbdd800cf,0x2884020a,0xb0380023}},	//   ydt_, _enès, ақав, _ብምንቃ, 
   {{0x2c6429ef,0x6e25c935,0x6d44067c,0x00000000}},	//   _vöds_, lfib, mvia, --, 
   {{0xbdd83813,0x00000000,0x00000000,0x00000000}},	//   _inèr, --, --, --, 
   {{0x7ae1c936,0x786c12ed,0xa8040139,0xd5ac0014}},	//   ínte, _høvl, _sañğ, ڈہم_, 
   {{0x6d440228,0x6595c937,0x3ea400c7,0x443c0175}},	//   nvia, рапу, _ínte_, tdt_, 
   {{0x6d45c938,0x19b8188c,0x443c257d,0xa8040139}},	//   ivia, _русь_, udt_, _qañğ, 
   {{0x443dc939,0x6d448500,0x784800e2,0x3e64000d}},	//   rdt_, hvia, _dēvē, _kõtt_, 
   {{0x6d440357,0x786c143a,0x443c5c00,0x09d00154}},	//   kvia, _løvl, sdt_, ারকা, 
   {{0x6d4401a2,0x9f500122,0x443c04cc,0xd5a400f1}},	//   jvia, razí_, pdt_, _پلوی, 
   {{0x6d440030,0x836400c6,0xe81c302b,0xc0580153}},	//   dvia, _مدبل, _नाफा_, хім_, 
   {{0x5ea5c93a,0xe81ca064,0x8c180154,0x6d456c26}},	//   لمسل, _नाना_, ড়ান_, evia, 
   {{0xbdd80ba1,0x38b89eaa,0x33b000db,0x00000000}},	//   _anèr, mêre_, _دەپر, --, 
   {{0x6d440cfe,0x38b8af58,0x5d540a83,0x9bf5c93b}},	// [32cf0] gvia, lêre_, шкат, изач, 
   {{0x9ed8721f,0x00000000,0x00000000,0x00000000}},	//   _имот_, --, --, --, 
   {{0xa9a40952,0x6d4558a8,0x81b402f5,0x38b89eaa}},	//   ەمنى, avia, _জলি_, nêre_, 
   {{0xfccc0201,0xbdd800db,0x81f0015b,0x99dc010e}},	//   _እጅግ_, _enèr, _ঝাঁপ_, _maňg, 
   {{0x09d01c82,0x199400ee,0x9f5005da,0x3870013e}},	//   াৰ্থ, шадя, lazà_, бқат, 
   {{0x41c4e698,0xddcc02d1,0xdcfc0166,0xfbd800cd}},	//   रेयस, chaš, _uzsı, मुखम, 
   {{0x1a64397a,0x8ca000cf,0x4af40214,0x39e4022e}},	//   _پیشی_, _بەلو, _نکند_, _бўзб, 
   {{0x38b9c93c,0x9664010b,0x00000000,0x00000000}},	//   dêre_, ркие, --, --, 
   {{0xd45402bf,0x41c42e04,0x6d4002d2,0x00000000}},	//   атнь, रेमस, _ámat, --, 
   {{0x38b80af9,0x08400014,0xe81c0037,0x00000000}},	//   fêre_, _وۆنُ, _नाया_, --, 
   {{0x3a3dc93d,0x965400a7,0x0e5c0023,0x6d440419}},	//   _kaup_, _вълч, _ተጻብኦ_, zvia, 
   {{0x5884052f,0x3a3c039a,0x6d440006,0x1dc400cd}},	//   _сыға, _jaup_, yvia, वधात, 
   {{0x61e80077,0xe508216b,0xe81c0b02,0x00000000}},	//   ñela, _مينو_, _नामा_, --, 
   {{0x6d45c93e,0x38b9c93f,0x320c0209,0xe5c402d5}},	//   vvia, bêre_, şdy_, _усхо, 
   {{0xb8d4025c,0x38b8003a,0x787c0064,0x00000000}},	//   _ཛེ_, cêre_, _išvė, --, 
   {{0xcce426c0,0xddc88f81,0x29000006,0x645c023a}},	//   لسطي, _šošt, šiai_, öriv, 
   {{0x629c0407,0x0dc9c940,0x7f88001f,0x41b00220}},	// [32d00] éroe, тлай_, _አድርጌ_, _ومىر, 
   {{0x6d443209,0x00000000,0x00000000,0x00000000}},	//   rvia, --, --, --, 
   {{0x6d45c941,0x2abc0154,0xdddc00dd,0x3a3c06af}},	//   svia, híbe_, _első, _baup_, 
   {{0x3a3dc942,0x6e240175,0x00000000,0x00000000}},	//   _caup_, qfib, --, --, 
   {{0x29000261,0x3a3c020c,0xed040022,0xc88006be}},	//   éia_, _daup_, _ыҟан, _huşə_, 
   {{0x1cb4025c,0x692400d1,0x32c800a2,0x00000000}},	//   _ཝེར_, имҗа, _ỳyla_, --, 
   {{0x3e64000d,0x98680419,0x00000000,0x00000000}},	//   _tõtt_, búľ_, --, --, 
   {{0x3a3c03cd,0xca74008e,0xbb38025d,0x38b9564d}},	//   _gaup_, _тугы, _בעלי, vêre_, 
   {{0x99dc010b,0x9f4401e7,0x00000000,0x00000000}},	//   _daňd, úlú_, --, --, 
   {{0x38b9c943,0x0465c944,0x65940220,0xc8c80133}},	//   têre_, ртим, _қалу, _شوان_, 
   {{0x2a65c945,0x1cb4031c,0xf7400a42,0x07a406ed}},	//   _komb_, _ཝེལ_, _мефо, _тажн, 
   {{0x38b8ed06,0x2a640de2,0x27fd56de,0xe81c01ad}},	//   rêre_, _jomb_, lavn_, _नाडा_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x27fd2394,0x2a64089f,0x38b8002d,0x629c4de4}},	//   navn_, _lomb_, pêre_, érob, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf4200c99,0x27fcd136,0x2a6407ab,0x739400fb}},	//   _འཁོད_, havn_, _nomb_, _әтәс_, 
   {{0x61fd26fc,0x6d4009a8,0xcd50001f,0x26c4022f}},	// [32d10] masl, _šmar, _መካከለ, immo_, 
   {{0x3a3dc946,0x6c5400cf,0x00000000,0x00000000}},	//   _saup_, окуу, --, --, 
   {{0x3a3c007f,0x4cb4009e,0x9e3454e7,0x61fc0076}},	//   _paup_, _অংশু, _ленч, oasl, 
   {{0x61fdc947,0x2a65c948,0xde58063b,0x5974113e}},	//   nasl, _comb_, _самі_, йылу, 
   {{0x2d04084c,0x00000000,0x00000000,0x00000000}},	//   _мярг, --, --, --, 
   {{0x61fdc949,0x961c00e2,0x00000000,0x00000000}},	//   hasl, miņi, --, --, 
   {{0x61fc0323,0x3a3c00b0,0xd138001f,0x27380208}},	//   kasl, _taup_, _ዲያስፖ, _cũn_, 
   {{0x7d181021,0x2f980375,0x61fc005f,0x319801f2}},	//   _äuss, יכון_, jasl, ọzi_, 
   {{0x61fc03ee,0x9984007b,0x9998020f,0xb80401c8}},	//   dasl, _الذو, _скат_, _نباه, 
   {{0x26c4011c,0x2abc007b,0x1cb4031c,0xd6c401a9}},	//   ammo_, ríbe_, _ཝེས_, шиққ, 
   {{0xe81c7b05,0x72a40131,0x2a640694,0x61fc6f85}},	//   _नाता_, يەتن, _yomb_, fasl, 
   {{0x15b80184,0x61fdc94a,0x69000139,0x00000000}},	//   _йылы_, gasl, _äzdä, --, 
   {{0x248c0204,0x65c000e4,0xe60c00df,0x00000000}},	//   bidm_, râhé, _יפאָ, --, 
   {{0x645c6935,0x0d2000f7,0x6f080419,0x961c0171}},	//   örit, үүнү, ádco, diņi, 
   {{0xa524031c,0x61fd282a,0xd1c80572,0x629c0419}},	//   _འདོག_, basl, _өлке_, éroc, 
   {{0x61fc0063,0xca140150,0x59b800cd,0x00000000}},	//   casl, _ﺳﻴﺎ_, ेधार, --, 
   {{0x2a641bce,0xd1b01079,0x3b340092,0x00000000}},	// [32d20] _romb_, _ریسک, _ከሚገኘ, --, 
   {{0x4f94041b,0xe81c000d,0x70540345,0x00000000}},	//   _грму, _नाधा_, _بۆسا, --, 
   {{0x4b240261,0xfbc04ed3,0x7fd40115,0x00000000}},	//   смев, वेलम, _לויס_, --, 
   {{0x2a64014f,0x82d4008f,0x601c01e1,0x20dc0248}},	//   _qomb_, צונג_, _làm̀, _yìi_, 
   {{0x67d4499d,0x6c3401d9,0x961c00de,0x00000000}},	//   оолу, _وہرا, ciņi, --, 
   {{0xfce1c94b,0x2d8001f7,0x2a640afa,0xcc3401f4}},	//   _хоро, mzie_, _womb_, _ухмы, 
   {{0x6d40006a,0x61fc083c,0x2a640f85,0x2d800419}},	//   _âmab, yasl, _tomb_, lzie_, 
   {{0x27fc0579,0x9b440014,0x00000000,0x00000000}},	//   savn_, _بنٲو, --, --, 
   {{0x2d81c94c,0x61fc01ed,0xe94404fb,0x00000000}},	//   nzie_, vasl, _برزی, --, 
   {{0x61fc020b,0x7cfc01e1,0x27380051,0x00000000}},	//   wasl, _hàrá, _tũn_, --, 
   {{0x0744004b,0x61e80077,0x66d00588,0x22580022}},	//   _دناټ, ñelo, _ẽkua, аины_, 
   {{0x27240521,0x7cfc0241,0x29000024,0x93c801e0}},	//   _ịnwe_, _jàrá, šiau_, штыҡ_, 
   {{0x193c019b,0x645d73f2,0x00000000,0x00000000}},	//   _ｐｓｐ_, öris, --, --, 
   {{0x2d8014cf,0x61fdc94d,0x601c01e1,0x00000000}},	//   dzie_, sasl, _gàm̀, --, 
   {{0x61fdc94e,0x3390005b,0xb7d800d9,0x00000000}},	//   pasl, _нашё, רקלי, --, 
   {{0xa194a4cb,0x00000000,0x00000000,0x00000000}},	//   _майч, --, --, --, 
   {{0x2d586880,0x417400f1,0x811400f2,0x00000000}},	// [32d30] бить_, _داغس, _اذعا, --, 
   {{0x69ac0037,0x717801af,0x00000000,0x00000000}},	//   _जड़ी, _ыбыр_, --, --, 
   {{0x9f200075,0x26d80098,0x00000000,0x00000000}},	//   _تۈزۈ, _éroh_, --, --, 
   {{0x397401d9,0x00000000,0x00000000,0x00000000}},	//   ٝشتھ_, --, --, --, 
   {{0x786d449a,0x00000000,0x00000000,0x00000000}},	//   _høvi, --, --, --, 
   {{0x786c03b2,0xddcc012d,0x9e34009f,0x00000000}},	//   _køvi, zjaś, _اوڏڙ, --, 
   {{0xa5243ae9,0x7ae40227,0x7c3402d0,0xac980c4f}},	//   _འདུག_, _utjt, mexr, _انّا_, 
   {{0x7c6404a9,0x61e80724,0x786c05ac,0x96640220}},	//   _ئاڭل, ñell, _møvi, ікпе, 
   {{0x786dc94f,0x5ba8000d,0x54340cc9,0x00000000}},	//   _løvi, _कडुव, охну, --, 
   {{0x38b807a8,0x13042826,0x00000000,0x00000000}},	//   bêra_, озом, --, --, 
   {{0xd79456a7,0x786c005c,0x8c1800d9,0x27f80037}},	//   _بلاخ, _røvh, בותי, _õrna_, 
   {{0xd575c950,0x55541176,0x163401af,0xd1c839be}},	//   _муль, _وپار, _федя, илне_, 
   {{0x2174013e,0x51b80024,0x00000000,0x00000000}},	//   пурр, рыня_, --, --, 
   {{0x753800ca,0xe0d000f1,0xd011b516,0xcee800db}},	//   mwuz, ېزې_, بلس_, идге_, 
   {{0xe81c121d,0x7c34007c,0x3f640107,0x00000000}},	//   _नासा_, dexr, оиро_, --, 
   {{0x2d81c951,0x786c03cd,0x00000000,0x00000000}},	//   tzie_, _døvi, --, --, 
   {{0xac080184,0x2d80009f,0xd008004e,0x00000000}},	// [32d40] ймаҡ_, uzie_, _кепе_, --, 
   {{0x2d81c952,0xace80131,0x00000000,0x00000000}},	//   rzie_, имға_, --, --, 
   {{0x4a45c953,0xdddc033f,0x8b2585fb,0x961c00e2}},	//   жнев, _dosł, юдже, liņu, 
   {{0x1cdc0003,0x4aa838eb,0x753807a8,0x2bdc07d0}},	//   _ལྕམ_, шкен_, kwuz, _बलवा, 
   {{0xbdd8020c,0xe9840075,0x59a40073,0x09344677}},	//   _kaèn, чқан, गॅलर, تراج, 
   {{0xd90c30cd,0xc1700302,0x00000000,0x00000000}},	//   ایل_, וחד_, --, --, 
   {{0xf3fc00bd,0x09e5c954,0xd7f802dd,0x00000000}},	//   ংলার_, _мовн, суі_, --, 
   {{0x066400db,0x858001ec,0xeaf801f9,0x00000000}},	//   تاتپ, _ﺨﻁﺭﺍ_, ुळीत_, --, 
   {{0xd90dc955,0xda6402eb,0xece800eb,0x00000000}},	//   _مین_, _عافي, _পিঁড, --, 
   {{0xdcec010f,0x29000153,0x961c0171,0x00000000}},	//   jzaĝ, šias_, diņu, --, 
   {{0x4e18012c,0xf31000db,0x00000000,0x00000000}},	//   धलाई_, мдээ, --, --, 
   {{0xdb20ae6f,0x786c072b,0x00000000,0x00000000}},	//   étét, _røvi, --, --, 
   {{0x6601c956,0x044452f5,0x786c0623,0x81b000eb}},	//   mamk, _медн, _søvi, ঝেন_, 
   {{0x66000050,0x99dc00a2,0x00000000,0x00000000}},	//   lamk, _maňa, --, --, 
   {{0x442dc957,0xf485c958,0xe8d00150,0xdddc012d}},	//   _ibf_, _بانی, _ﯗﻋﯟﻋ, _rosł, 
   {{0x6601c959,0x442dc95a,0x961c00ef,0x00000000}},	//   namk, _hbf_, biņu, --, 
   {{0xdddc0034,0x628dc95b,0xa19400a7,0x442dc95c}},	// [32d50] _posł, _imao, _хапч, _kbf_, 
   {{0x6601c95d,0xfc3000c6,0x786c0162,0x00000000}},	//   hamk, بحر_, _tøvi, --, 
   {{0x6601a4be,0x442dc95e,0x5a35c95f,0x2bdc2356}},	//   kamk, _mbf_, знет, _बलरा, 
   {{0x6601c960,0xaf340424,0x00000000,0x00000000}},	//   jamk, _کریت, --, --, 
   {{0x628d22f5,0x2d9c03ee,0x6f6400f2,0x00000000}},	//   _mmao, şver_, _فهیم, --, 
   {{0x628c007f,0x99dcf32f,0x442c03cd,0xddcc01e4}},	//   _lmao, _daňa, _nbf_, nkaŭ, 
   {{0x628dc961,0xe81c3f6f,0x6600000f,0x3f80025c}},	//   _omao, _नारा_, famk, nzju_, 
   {{0x6601c962,0x753800ca,0x00000000,0x00000000}},	//   gamk, twuz, --, --, 
   {{0x442c3098,0x99900210,0x00000000,0x00000000}},	//   _bbf_, łały_, --, --, 
   {{0x629dc963,0xc480276f,0x628dc964,0xa8141f5a}},	//   éron, ельк, _amao, _одуш, 
   {{0x66000944,0x03207757,0x11d40212,0x00000000}},	//   bamk, ндэн, зігр, --, 
   {{0x442c0334,0xbdd80066,0x99dc00a2,0x00000000}},	//   _ebf_, _saèn, _yaňa, --, 
   {{0x2bb83af4,0xa7fc6648,0x950401ed,0x24940023}},	//   _अर्थ, _alıy, _عہدے_, _ዝጥምት_, 
   {{0x442c0998,0x628dc965,0x22580153,0xe5200037}},	//   _gbf_, _emao, _čekų_, _ममति_, 
   {{0x1fb464cd,0xefcc0023,0x00000000,0x00000000}},	//   дстр, ቢልዎ_, --, --, 
   {{0x63bc004e,0xc7b00375,0x00000000,0x00000000}},	//   ürne, גבל_, --, --, 
   {{0xd1bc069c,0x786c0579,0x0d85c966,0xa7fc0139}},	// [32d60] ሰርቲ_, _høvu, члан, _elıy, 
   {{0x660001e2,0x99dc01f1,0x00000000,0x00000000}},	//   zamk, _raňa, --, --, 
   {{0x8ad405d9,0xbdd80066,0x6601c967,0xca1400d1}},	//   ستائ, _kaèl, yamk, _ﻳﻪﺭ_, 
   {{0xfaa1c968,0x6edc007f,0x49c9b2b8,0x920400cd}},	//   нахо, _nčbi, блен_, bhāś, 
   {{0xbdd8020c,0x786c0162,0x920400b8,0x00000000}},	//   _maèl, _løvu, chāś, --, 
   {{0x6600004b,0xe3b80205,0x24cc00d1,0x00000000}},	//   wamk, ngıc_, ﺑﺪﯗﻟ, --, 
   {{0x6601c969,0x442c0139,0x311c00cd,0x00000000}},	//   tamk, _rbf_, भूतः_, --, 
   {{0x09e410e4,0xb6c000db,0x00000000,0x00000000}},	//   _хоан, нсый, --, --, 
   {{0x0cac00fe,0xfaa001a9,0x3f800003,0xf64c009a}},	//   কগীত, _чато, zzju_, طئي_, 
   {{0x628c0ea3,0x6601c96a,0xd5b80137,0x00000000}},	//   _smao, samk, өсө_, --, 
   {{0xe21407d8,0x442c0158,0x66000810,0x00000000}},	//   ммны, _vbf_, pamk, --, 
   {{0xa195c96b,0xd62406f6,0x6601c96c,0xe80400bc}},	//   дамч, _يعني, qamk, रणका_, 
   {{0x05b8282b,0xc05800d6,0x41c40034,0x442dc96d}},	//   _ادات_, бів_, रेंस, _tbf_, 
   {{0x9f340220,0x00000000,0x00000000,0x00000000}},	//   мегі, --, --, --, 
   {{0x645996c8,0xddcc00c8,0xfeb9c96e,0x644803cb}},	//   _invi, rkaŭ, مارت_, mddi, 
   {{0x628c02ce,0xbdd800db,0x6449c96f,0xe188013d}},	//   _umao, _gaèl, lddi, _дөге_, 
   {{0x2d580775,0xb1140166,0x64480067,0x00000000}},	// [32d70] пить_, _змыш, oddi, --, 
   {{0x6448cda1,0xcf8c0133,0x9f4400e5,0x00000000}},	//   nddi, اژی_, úló_, --, 
   {{0x644800a9,0x629dc970,0x6d400142,0x69c1c971}},	//   iddi, onso, _âman, _azme, 
   {{0x2ea805ba,0x629c1700,0x9cc8054a,0x786c072b}},	//   ककृत, nnso, сыға_, _løvt, 
   {{0x18695e34,0x64580857,0x888001b9,0x00000000}},	//   жали_, _onvi, چیقن, --, 
   {{0x629dc972,0x91c0012d,0xfe7000e5,0xa9c40137}},	//   hnso, रेटै, _آدھ_, رۅلۉ, 
   {{0xe9d00131,0x07a07701,0x69c00bbc,0x98ac01ef}},	//   نغۇ_, кашн, _ezme, _upeč_, 
   {{0x629dc973,0x6449c974,0x6459c975,0x00000000}},	//   érol, eddi, _anvi, --, 
   {{0x64480368,0x98e0012c,0x690401e4,0xe6d41870}},	//   fddi, _पढिए, nϲel, _ﺟﺎﮬﺎ, 
   {{0x629dc976,0xd90c00dd,0x64487891,0x99dc0306}},	//   enso, _میچ_, gddi, _kaňo, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6449c977,0x629c8ecc,0x00000000,0x00000000}},	//   addi, gnso, --, --, 
   {{0xd1b81c3e,0x00000000,0x00000000,0x00000000}},	//   تادا_, --, --, --, 
   {{0xc0e80020,0x629dc978,0x1cb4031c,0x63a400b8}},	//   _ሆኖም_, anso, _ཝེཊ_, _śine, 
   {{0xff20039b,0x99dc00e8,0x00000000,0x00000000}},	//   кмро, _naňo, --, --, 
   {{0xdcfc013d,0xf4840244,0x8d741291,0x00000000}},	//   _aysı, _باچی, واءا, --, 
   {{0x6458002d,0x00000000,0x00000000,0x00000000}},	// [32d80] _ynvi, --, --, --, 
   {{0x3200062c,0x7bd80790,0x00000000,0x00000000}},	//   _heiy_, _şuur, --, --, 
   {{0x8d740020,0xaca4063f,0x786c9069,0x32000076}},	//   ኩላቸው_, _haịr, _løvs, _keiy_, 
   {{0x99dc0232,0x6f1cb354,0x00000000,0x00000000}},	//   _daňo, murc, --, --, 
   {{0x64481649,0xaca400b4,0x6f1c02d1,0x28f8010a}},	//   yddi, _asụs, lurc, чель_, 
   {{0x69c009a8,0x32000076,0x6f1c0334,0x60c402d0}},	//   _vzme, _leiy_, ourc, _xhhm, 
   {{0x8a041422,0xc7640137,0x00000000,0x00000000}},	//   _озве, باشى, --, --, 
   {{0xc9540664,0x32000086,0x786c01bf,0x99dc0432}},	//   _отзы, _neiy_, _bøvs, _jaňl, 
   {{0x99dc010b,0x629db33a,0xd5ac0050,0x00000000}},	//   _maňl, érom, ٕہن_, --, 
   {{0x6449c979,0x786c0fac,0xddcc0309,0x629c0784}},	//   uddi, _døvs, nkaš, wnso, 
   {{0x64491612,0x6f1c00f3,0x629c1d0e,0x64580051}},	//   rddi, jurc, tnso, _vnvi, 
   {{0x6f1c2ba9,0x629c0036,0x7d0803b2,0x00000000}},	//   durc, unso, ágsk, --, 
   {{0x3200062c,0x786c037e,0x6f1c0175,0x60c401bf}},	//   _deiy_, _iøvr, eurc, _phhm, 
   {{0x6f1dc97a,0xddcc597f,0x64580c86,0x68e0006f}},	//   furc, jkaš, _unvi, _mumd, 
   {{0x6f1c0198,0x68e1c97b,0xf41004ae,0x32000363}},	//   gurc, _lumd, _ספק_, _feiy_, 
   {{0x32000076,0x00000000,0x00000000,0x00000000}},	//   _geiy_, --, --, --, 
   {{0x68e1c97c,0x2728000f,0x99dc00a2,0x91c00166}},	// [32d90] _numd, hûn_, _daňl, _бәрл, 
   {{0x9cb5c97d,0x6f1dc97e,0x22480429,0x60c40280}},	//   رمات, burc, _haak_, _uhhm, 
   {{0x27280a85,0x2248102c,0x6f1c414c,0xda1406ed}},	//   jûn_, _kaak_, curc, едењ, 
   {{0x2000166a,0x68e0009a,0x88e40183,0x2249c97f}},	//   _hehi_, _bumd, _নিজক, _jaak_, 
   {{0x2249c980,0x200000b0,0x68e006be,0xeab0007b}},	//   _maak_, _kehi_, _cumd, جعل_, 
   {{0x68e1c981,0x3eb8094a,0x22480429,0x2728045f}},	//   _dumd, llqt_, _laak_, fûn_, 
   {{0x27280a85,0x68e00381,0x2001c982,0x66dc00c7}},	//   gûn_, _eumd, _mehi_, _oĩku, 
   {{0x2001c983,0x22480eda,0x796402b5,0x6edc0de2}},	//   _lehi_, _naak_, _pūwā, _yōbb, 
   {{0x32000295,0x68e1b86a,0xa9b483f3,0xaa9406bd}},	//   _reiy_, _gumd, _айтч, _ритч, 
   {{0x2728045f,0x2000269e,0x32000363,0x2db80375}},	//   bûn_, _nehi_, _seiy_, ולחן_, 
   {{0x2249c984,0x3200007f,0x95d8005b,0x68e001d5}},	//   _baak_, _peiy_, _едет_, _zumd, 
   {{0xe6107f1b,0x81b4045e,0x2248002e,0x25a01a48}},	//   _نشه_, _জলজ_, _caak_, _žile_, 
   {{0x2248002e,0x2000d021,0x4520015b,0x6f1c002d}},	//   _daak_, _behi_, _বৈঠক_, wurc, 
   {{0xfe7c145e,0x6f1dc985,0x26d80098,0x20000356}},	//   _alï_, turc, _éror_, _cehi_, 
   {{0xc7b01a4c,0x22480a85,0xe3b805d1,0x320000ad}},	//   ָבן_, _faak_, lgın_, _teiy_, 
   {{0x23782d8b,0xd3700451,0x6f1c047e,0x00000000}},	//   ørje_, _لهڻ_, rurc, --, 
   {{0xe3b82706,0x20001132,0xf8ac04fa,0x3b2c001f}},	// [32da0] ngın_, _fehi_, टवाय, _አላገኘ, 
   {{0x22480cf9,0x6f1c579b,0xaca4063f,0x2001c986}},	//   _zaak_, purc, _obụr, _gehi_, 
   {{0xddcc2d2b,0x2248020b,0x68e00477,0x99dc00a2}},	//   rkaš, _yaak_, _sumd, _taňl, 
   {{0x09e5c987,0x3f9401d9,0x68e0047e,0xddcc0784}},	//   ходн, _سپُد_, _pumd, skaš, 
   {{0xaca40521,0x68e1c988,0x2728045f,0x786c01bf}},	//   _abụr, _qumd, wûn_, _røvr, 
   {{0xd90c0426,0x074548c3,0x68e00455,0x2728015d}},	//   زیم_, ехим, _vumd, tûn_, 
   {{0x68e00117,0x5bb400a8,0x61bc08ec,0x00000000}},	//   _wumd, _астф, _ईर्ष, --, 
   {{0x2729c989,0x940400ac,0xc6a5c98a,0xa535c98b}},	//   rûn_, milə_, эрли, внич, 
   {{0x22480591,0x940403b9,0x00000000,0x00000000}},	//   _raak_, lilə_, --, --, 
   {{0x1cb40489,0x2249c98c,0xa3d42996,0xb6c80014}},	//   _ཝེབ_, _saak_, копч, _ہانے_, 
   {{0x2249c98d,0x200000b0,0x067401af,0x940403e3}},	//   _paak_, _rehi_, _пудя, nilə_, 
   {{0xa2940845,0x97000131,0x84e401c6,0x200000a2}},	//   тамі, _ئېيى, _зодж, _sehi_, 
   {{0x22480936,0x2001c98e,0xc05802bf,0x320801c6}},	//   _vaak_, _pehi_, пів_, эхэн_, 
   {{0x22480429,0x940403e3,0x00000000,0x00000000}},	//   _waak_, kilə_, --, --, 
   {{0x22482ad4,0x270c012c,0x2001ac8e,0x7d1801c7}},	//   _taak_, něn_, _vehi_, _äusz, 
   {{0x20000053,0xb460035b,0x229800e4,0x940403e3}},	//   _wehi_, _акәл, tĩku_, dilə_, 
   {{0x61edc98f,0x648408c2,0x20007bc9,0x5ff400a7}},	// [32db0] _ifal, _còig, _tehi_, _изпу, 
   {{0x64840013,0x319c0375,0xe81c3517,0x24d800d1}},	//   _dòig, _מבחנ, _नागा_, ﯜﺯﯛﻟ, 
   {{0x443c91fa,0xe3b80790,0xd9440276,0xdb200139}},	//   iet_, zgın_, ӂели, _ütüw, 
   {{0x443dc990,0xd9980597,0xe3b805d1,0x61ec031c}},	//   het_, ونات_, ygın_, _jfal, 
   {{0xd945c991,0x61ec0451,0x27ec05b1,0xdd9800a2}},	//   тели, _mfal, _bfdn_, _äň_, 
   {{0x443dc992,0x7d1c0054,0x7c84010b,0x99dc01ef}},	//   jet_, muqs, _чуме, _kaňk, 
   {{0x443c08d7,0x61edc993,0x1ab40006,0x81d40154}},	//   det_, _ofal, _абвя, িডি_, 
   {{0x443c023a,0xaee400dc,0x2f5c008f,0x76400107}},	//   eet_, _akṛt, לדונ, умиҷ, 
   {{0x443dc994,0xe9840014,0x7d1c01d5,0x2e38011a}},	//   fet_, _یٔہَ, nuqs, תרחש_, 
   {{0xa7fc010e,0x7e6c0051,0xe3b8236c,0x270c013a}},	//   _boıu, _locp, rgın_, běn_, 
   {{0xa56423cf,0x612c025c,0x1cb4025c,0x00000000}},	//   ندین, _ཧཱུཾ_, _ཝེན_, --, 
   {{0x443c05c7,0xa6c800db,0xc6c800b8,0x200403b2}},	//   aet_, _كولل_, _tṛṇe, ðlin_, 
   {{0x64840e89,0x6ffc031c,0x7d1c03ac,0x6d00012d}},	//   _bòid, _དབྱུ_, juqs, _लौंग_, 
   {{0x443dc995,0x7648066d,0x61ec0cfd,0xb9e8001f}},	//   cet_, _hagy, _efal, _ሕጉ_, 
   {{0x7649c996,0x61ec638c,0x94040213,0xc00000ea}},	//   _kagy, _ffal, xilə_, рпск, 
   {{0x940400ac,0x99dc01ef,0x00000000,0x00000000}},	//   vilə_, _daňk, --, --, 
   {{0x76488d60,0x0c243e1f,0xf1c40306,0xd1c800a8}},	// [32dc0] _magy, кман, _duší_, _юлие_, 
   {{0x7649c997,0x940400ac,0x4f940a42,0x61ec01ef}},	//   _lagy, tilə_, _арму, _zfal, 
   {{0x09c8726b,0xca2401d5,0x00000000,0x00000000}},	//   िध्य, вфли, --, --, 
   {{0x443dc998,0x764800f8,0x940400ac,0x270c0118}},	//   zet_, _nagy, rilə_, věn_, 
   {{0x443dc999,0x940403be,0x6e240921,0x629c4de4}},	//   yet_, silə_, mgib, éroi, 
   {{0x443dc99a,0x6e25c99b,0x270c0118,0x3cf809bb}},	//   xet_, lgib, těn_, _लौटे_, 
   {{0x7649c99c,0x4aa800db,0x4de4012d,0x7d080174}},	//   _bagy, _قارپ_, _कलाई_, ágsv, 
   {{0x443dc99d,0x6e25c99e,0x76480432,0x99dc00d0}},	//   wet_, ngib, _cagy, _naňh, 
   {{0x443c2b9d,0x48e410f5,0x764800ee,0x6d440165}},	//   tet_, _розв, _dagy, nwia, 
   {{0x443dc99f,0x61ec3eb9,0xe1e80248,0xbb3802dd}},	//   uet_, _sfal, _ṣàng, _ﻓﻤﻥ_, 
   {{0x61edc9a0,0x764801ed,0x648401c3,0x6d442315}},	//   _pfal, _fagy, _ròid, hwia, 
   {{0x443dc9a1,0x7d1c0309,0xc6d414fb,0x6d454895}},	//   set_, yuqs, _شتات, kwia, 
   {{0xf1c402fb,0xc0940345,0xf2c4009d,0x00000000}},	//   _ruší_, نجست, рсэн, --, 
   {{0x443c069c,0x7e6dc9a2,0xf1c402f0,0x7d1c022e}},	//   qet_, _socp, _suší_, vuqs, 
   {{0x7649c9a3,0x61ec031c,0x6e240112,0x4ab00073}},	//   _yagy, _tfal, fgib, जवाव, 
   {{0x6e25c9a4,0x61ec0451,0x82341a73,0x7d1c0113}},	//   ggib, _ufal, _شرعا, tuqs, 
   {{0x5d551229,0x9b940014,0xaed400d4,0x6d440210}},	// [32dd0] ыкат, گلات, ротш, gwia, 
   {{0x6e2404ba,0x7d1c022f,0x99dd19ff,0xfdc003ce}},	//   agib, ruqs, _taňk, _शरीफ, 
   {{0xdfd1c9a5,0xc618015b,0x908801d9,0xf1c40c5e}},	//   _ديد_, থ্যা_, _سمَے_, _tuší_, 
   {{0xdea00517,0x6e240204,0x6d4400d7,0x00000000}},	//   _ایری, cgib, bwia, --, 
   {{0x7d1dc9a6,0x7649c9a7,0x28c4000d,0x00000000}},	//   quqs, _ragy, _लीहि, --, 
   {{0xfaf09717,0x17c8036b,0xdcb003cc,0x76480432}},	//   _نثر_, нгли_, _چىڭ_, _sagy, 
   {{0xdcb0345f,0xe7082928,0x7649c9a8,0x9f5001d3}},	//   _نىڭ_, پتىن_, _pagy, mazó_, 
   {{0x9f506428,0x7bc400de,0xa7fc0205,0x53a48abc}},	//   lazó_, _izju, _anıd, ғамб, 
   {{0x7649c9a9,0x95540597,0xe81c02ab,0x00000000}},	//   _vagy, اخبا, _नाचा_, --, 
   {{0x7649c9aa,0xc480d687,0x6e24231e,0x9f500407}},	//   _wagy, йлык, zgib, nazó_, 
   {{0x6d44033f,0x7649c9ab,0xa4900345,0xf1c000eb}},	//   zwia, _tagy, تیوت, _ইলেভ, 
   {{0x2378022c,0x6d44377c,0x25640014,0x00000000}},	//   ørja_, ywia, _چاوُ, --, 
   {{0x648401ab,0x79880007,0x256401d9,0xa564a054}},	//   _dòib, nzgw, _ناوُ, _ندون, 
   {{0x066407dd,0x3204012d,0xc0e001f4,0x00000000}},	//   _ахәҭ, źmy_, сорк, --, 
   {{0x78a0143a,0x00000000,0x00000000,0x00000000}},	//   innv, --, --, --, 
   {{0xd90405d9,0x6d44033f,0x81b00154,0x00000000}},	//   _وڌ_, twia, ঝেই_, --, 
   {{0x6d440295,0xe7f8012c,0x3cfc00bc,0x637801e1}},	// [32de0] uwia, ुरमा_, शीले_, _túnú, 
   {{0x629c0232,0x0ef80276,0x6e2423ac,0x6d44012d}},	//   érov, _пэмы_, sgib, rwia, 
   {{0xca743c1f,0x61e9c9ac,0x6d44012d,0x49041be1}},	//   луды, žele, swia, सीनो_, 
   {{0xaca4063f,0x6e24009a,0x00000000,0x00000000}},	//   _krịs, qgib, --, --, 
   {{0x2900068c,0x9f400208,0x46c000dc,0x75d800ef}},	//   èia_, _nghê_, शतसह, _jāzī, 
   {{0x656401ab,0x00000000,0x00000000,0x00000000}},	//   _àihi, --, --, --, 
   {{0xc79548c8,0x9cb000db,0xd7f802dd,0xf86400d1}},	//   ырды, _بۅلت, туі_, امىي_, 
   {{0x05680798,0xe51809ab,0x00000000,0x00000000}},	//   ејои_, _दिदि_, --, --, 
   {{0x49c8026a,0x00000000,0x00000000,0x00000000}},	//   _члан_, --, --, --, 
   {{0xc32c1b56,0x2b580175,0xeb8c0241,0x00000000}},	//   كەت_, _krrc_, _òòsà_, --, 
   {{0xc30406a0,0x00000000,0x00000000,0x00000000}},	//   دبخو, --, --, --, 
   {{0xe1d400d4,0x00000000,0x00000000,0x00000000}},	//   ижнь, --, --, --, 
   {{0xfdac00cc,0x83840022,0x857408de,0xdb1401ef}},	//   _কণ্ড, _әыле, _حدائ, _ryzí, 
   {{0x2005c9ad,0x224da6a9,0xa3d5c9ae,0x00000000}},	//   úli_, žek_, _колч, --, 
   {{0xdfd5c9af,0xe80c46c7,0x27f80254,0x3ec80063}},	//   ровы, _सजना_, _õrnu_, ећам_, 
   {{0xf3101d93,0x04c40451,0x2004033f,0xdd2c0153}},	//   _ابوظ, _جوڙي_, źli_, _vėžy, 
   {{0x629c0165,0x6f1c0332,0x75d800ef,0x9a0801ec}},	// [32df0] érou, arrc, _gāzī, сiне_, 
   {{0x7af40334,0xfba80354,0xdf780064,0xe0600244}},	//   tpxt, нтей_, _абоі_, _بێسی, 
   {{0x2b580048,0x9f500789,0xfba801c0,0x9e344cef}},	//   _crrc_, razó_, хтай_, _кенч, 
   {{0x9f940022,0x2de4011c,0x00000000,0x00000000}},	//   _быҭә, _гюрг, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfc640801,0x00000000,0x00000000,0x00000000}},	//   _съмн, --, --, --, 
   {{0x7c2000a3,0x7bc400ef,0x9664004e,0x00000000}},	//   ònru, _uzju, икке, --, 
   {{0x7be005d1,0xb8e8015b,0x2004022e,0x00000000}},	//   ştuğ, _রং_, аlik_, --, 
   {{0x78248a61,0x2aa8022e,0x69c400e4,0x00000000}},	//   _معال, _стро_, ýiet, --, 
   {{0x7ae4044e,0x61fc0112,0x00000000,0x00000000}},	//   _kujt, ebsl, --, --, 
   {{0xb9cc044e,0x7ae40309,0xc4c401c0,0xb4b00139}},	//   _ኵሉ_, _jujt, рлэж_, _һидә, 
   {{0x7ae5c9b0,0x00000000,0x00000000,0x00000000}},	//   _mujt, --, --, --, 
   {{0x38b8006a,0x7ae4998f,0x02a001e1,0xe2b4009d}},	//   bêrt_, _lujt, _gbọọ, ссээ, 
   {{0xe3b09cad,0x6ecc002f,0x00000000,0x00000000}},	//   _کره_, ißbe, --, --, 
   {{0xb4c00f4a,0x7ae401d4,0x4418008f,0xd2a80139}},	//   ्षी_, _nujt, _סוקס, _икке_, 
   {{0xb0040882,0x629cd5e7,0x648401ab,0x6b500332}},	//   duḥk, érot, _tòic, hógá, 
   {{0x4d65c9b1,0xfde400f7,0x2b580067,0xdde80214}},	// [32e00] шкав, рдук_, _srrc_, ارفه_, 
   {{0x7ae42fce,0xe518000d,0x4090009f,0x3c60004e}},	//   _bujt, _दिसि_, _ولير, окуг, 
   {{0x0b4433b6,0x1c380724,0x66cc045f,0x99dc0419}},	//   рнен, ыять_, lûke, _maňu, 
   {{0x99dc00e8,0xb4c00bca,0x00000000,0x00000000}},	//   _laňu, ्षु_, --, --, 
   {{0xfa301e4a,0xc8640353,0x00000000,0x00000000}},	//   تىنج, итки, --, --, 
   {{0x2b580048,0xaca4063f,0x99dc002e,0x25a02e31}},	//   _trrc_, _krọs, _naňu, _žilo_, 
   {{0xa7b80948,0x8a040108,0x00000000,0x00000000}},	//   ылку_, _взбе, --, --, 
   {{0x3b040798,0x00000000,0x00000000,0x00000000}},	//   _њето_, --, --, --, 
   {{0x66cc000f,0xb4c0078a,0x00000000,0x00000000}},	//   jûke, ्षू_, --, --, 
   {{0x66cc002d,0x69c00432,0xa3e0000d,0x00000000}},	//   dûke, _iyme, _देखs_, --, 
   {{0x69c0e63d,0x99dc0de2,0x2288045f,0x0eb402e5}},	//   _hyme, _daňu, _lûke_, ंवाड, 
   {{0x9f60004a,0x69c0005b,0x4428012d,0x62340108}},	//   _épée_, _kyme, żb_, щему, 
   {{0x61fc0112,0x05d000bc,0x00000000,0x00000000}},	//   rbsl, देशब, --, --, 
   {{0x69c1c9b2,0x272402e3,0x3e380023,0x00000000}},	//   _myme, _ịnye_, _ኣማኸር, --, 
   {{0x257c01e7,0x629ca8d8,0xfeb80244,0x00000000}},	//   _fálú_, éros, نارت_, --, 
   {{0x6d580882,0x33d80375,0x29040083,0xdd95b915}},	//   āvan, _בחוד, _owma_, бабы, 
   {{0x629dc9b3,0x00000000,0x00000000,0x00000000}},	// [32e10] miso, --, --, --, 
   {{0x2288002d,0xbdd800f2,0x00000000,0x00000000}},	//   _dûke_, _saès, --, --, 
   {{0x69c00c8c,0x29040de2,0x609800dd,0xbdd8020c}},	//   _ayme, _awma_, _لنکس_, _paès, 
   {{0xbdd800f2,0x69c00660,0x2288002d,0x7d24004b}},	//   _daèr, _byme, _fûke_, _پيسې_, 
   {{0x69c000a9,0x00000000,0x00000000,0x00000000}},	//   _cyme, --, --, --, 
   {{0x629c052f,0x7ae4014f,0x5c3400f1,0x69c0bcce}},	//   hiso, _tujt, _دکرز, _dyme, 
   {{0x2904003e,0x14240032,0xab94010a,0x00000000}},	//   _ewma_, ҡдим, _мăшк, --, 
   {{0x9aa40502,0x629c7851,0xe51912d8,0x977400c7}},	//   _امرو, jiso, _दिशि_, итқә, 
   {{0x629dc9b4,0x69c000a9,0x6d400142,0x00000000}},	//   diso, _gyme, _âmat, --, 
   {{0xb4c093cb,0xe874007b,0x00000000,0x00000000}},	//   ्षे_, _والظ, --, --, 
   {{0xf1d00e49,0x69c13f52,0x00000000,0x00000000}},	//   _सृजन, _zyme, --, --, 
   {{0x629dc9b5,0x588460c6,0xd17419b0,0xe5081913}},	//   giso, _тыға, быгы, _چينو_, 
   {{0xe5080b24,0x742401e2,0x00000000,0x00000000}},	//   _نينو_, _نقشې_, --, --, 
   {{0x051475a6,0xaca401f2,0x629d2b42,0x2288000f}},	//   _ايوب_, _prọs, aiso, _rûke_, 
   {{0x03a0085a,0x61e93ec2,0x00000000,0x00000000}},	//   _нишо, žela, --, --, 
   {{0x1ea82266,0x673c01f4,0x00000000,0x00000000}},	//   لاقي_, _ärje, --, --, 
   {{0x8e741e51,0x648408c2,0x05e4031c,0x0dc9c9b6}},	// [32e20] _ғунч, _mòin, _ལྔསྋ, улай_, 
   {{0xcb68026a,0x648400a3,0xbcf801e1,0xd04414af}},	//   лазе_, _lòin, _oréf, _اپدي, 
   {{0x69c1c9b7,0x00000000,0x00000000,0x00000000}},	//   _syme, --, --, --, 
   {{0x69c004cf,0x7f3800c8,0xdcfc0882,0x2288045f}},	//   _pyme, _געטו, śyām, _tûke_, 
   {{0xbcf801e1,0x391000d6,0x0d2001c0,0x7af80427}},	//   _aréf, змір, _хүзү, _čute, 
   {{0x69c06b07,0xbcf80008,0xb4c029ea,0xa8240133}},	//   _vyme, _bréf, ्षो_, تکرن, 
   {{0xeb542e51,0x629c9716,0x69c1c9b8,0x0f7800df}},	//   _بىزگ, yiso, _wyme, טאַב, 
   {{0x6d40006a,0x629dc9b9,0x3684e244,0x69c1c9ba}},	//   _âmas, xiso, йсын_, _tyme, 
   {{0x648401ab,0xbcf80248,0xc9a802d5,0x69c0014f}},	//   _dòin, _eréf, _свае_, _uyme, 
   {{0x629dc9bb,0x07a53aa1,0x00000000,0x00000000}},	//   wiso, _лазн, --, --, 
   {{0x629dc9bc,0x00000000,0x00000000,0x00000000}},	//   tiso, --, --, --, 
   {{0x4eb802f5,0x629c0140,0xe7f80406,0x69dc06be}},	//   ংগুল, uiso, ुरवा_, _şrey, 
   {{0xc50800c6,0x00000000,0x00000000,0x00000000}},	//   _إتصل_, --, --, --, 
   {{0x629d2f9e,0x7d1c0334,0x26c4007c,0x836400f3}},	//   siso, vrqs, llmo_, _гњид, 
   {{0xe7f002a0,0x6304276c,0x00000000,0x00000000}},	//   _चलना_, _بوعل, --, --, 
   {{0x629c20ac,0x6e944c04,0x9e241fd6,0x00000000}},	//   qiso, пису, تىرو, --, 
   {{0xa0c43ccf,0x5c743151,0xbb4800b5,0x5c9806a6}},	// [32e30] _ويعو, олат, _ookペ_, акая_, 
   {{0x442c27c4,0x7c9400ae,0x00000000,0x00000000}},	//   _jcf_, حشرا, --, --, 
   {{0xe80c0c2e,0xc0a800aa,0xbcf81a06,0x442c045a}},	//   _सज़ा_, _ټاکل_, _orég, _mcf_, 
   {{0x442c27c4,0x00000000,0x00000000,0x00000000}},	//   _lcf_, --, --, --, 
   {{0x648401c3,0x998c00d0,0x442c0108,0x39a40114}},	//   _ròin, _obeť_, _ocf_, љшев, 
   {{0xbcf87580,0xaf348b33,0x26c4f518,0x442c04cc}},	//   _préf, _بریت, elmo_, _ncf_, 
   {{0x6d40145e,0x2bd80b7c,0xbcf80129,0x00000000}},	//   _âmar, भेदा, _brég, --, 
   {{0xe709c9bd,0xa3bc00e1,0x442dc9be,0x79e401d9}},	//   حتون_, _आड़_, _acf_, _طوطہ_, 
   {{0x442dc9bf,0x94244fdb,0xdc3806be,0x00000000}},	//   _bcf_, омпе, lçıd, --, 
   {{0x442dc9c0,0x93580131,0xbcf9c9c1,0x00000000}},	//   _ccf_, арму_, _tréf, --, 
   {{0x291804fe,0x52a9c9c2,0x37a9c9c3,0xbcf8387a}},	//   _ārai_, ивом_, _стан_, _frég, 
   {{0x442c200c,0x629dc9c4,0xbcf9c9c5,0x61e833e9}},	//   _ecf_, érop, _grég, želn, 
   {{0x442c859f,0xd4680114,0x00000000,0x00000000}},	//   _fcf_, _виле_, --, --, 
   {{0xbcf8020c,0x70b40406,0xddd40139,0xcfa9053e}},	//   _mréd, ंकेल, _şaşq, لازم_, 
   {{0x6ecc0112,0xa7fc0139,0x00000000,0x00000000}},	//   eßba, _onın, --, --, 
   {{0xd1302d4b,0xbdd8007f,0xd5f8008f,0x00000000}},	//   _قمع_, _obèd, שפּר, --, 
   {{0x3ce00cf9,0xe2a8ad99,0x9f4801f1,0x00000000}},	// [32e40] _bijv_, _داون_, _škôl_, --, 
   {{0xa7fc2fbe,0x10a401af,0x31a400f1,0x63a400b8}},	//   _anın, _фион, _ولګې, _śini, 
   {{0xbdd81f5d,0x6e8800aa,0xbcf80c6a,0x2a65c9c6}},	//   _abèd, _همدې_, _aréd, _pnmb_, 
   {{0xfaa1c9c7,0x0ddc0092,0x0d3c0023,0x904401f7}},	//   махо, ዕራፍ_, ይተፈል, _انگه, 
   {{0xbcf9c9c8,0x82d4008f,0xcc2400e5,0x00000000}},	//   _créd, קונג_, _ورسٹ, --, 
   {{0xb4b01533,0xc7642e51,0x100805b3,0x00000000}},	//   झको_, قابى, वरिश_, --, 
   {{0x2288006a,0xbcf814ac,0x2d800204,0x00000000}},	//   _lûka_, _prég, lyie_, --, 
   {{0xbcf9c9c9,0x00000000,0x00000000,0x00000000}},	//   _fréd, --, --, --, 
   {{0x2d803666,0x442dc9ca,0x648401ab,0xbdd801e1}},	//   nyie_, _pcf_, _fòil, _gbèd, 
   {{0x6fc00574,0x99dc00ee,0xd7780014,0x00000000}},	//   _शुभं, _taňr, _گٔمژ_, --, 
   {{0xbcf9c9cb,0x442c0112,0x2259c9cc,0x00000000}},	//   _trég, _vcf_, бины_, --, 
   {{0x442c0327,0x81ac015b,0x2d80013f,0x00000000}},	//   _wcf_, _করব_, kyie_, --, 
   {{0xbcf8226d,0xe3a4036b,0x61e93b9b,0x7684013d}},	//   _krée, تشکی, želo, _uñya, 
   {{0x442c0048,0x2d80007f,0x00000000,0x00000000}},	//   _ucf_, dyie_, --, --, 
   {{0x3eb80054,0x60e00131,0x00000000,0x00000000}},	//   toqt_, _ﺋﻮﺧﺸ, --, --, 
   {{0x61140798,0xdd943947,0x00000000,0x00000000}},	//   _едиу, пабы, --, --, 
   {{0xcbe4015b,0x2d58023a,0x644800db,0xa114007b}},	// [32e50] _পড়েছ, оить_, oedi, _عودت, 
   {{0xdc382ca8,0x00000000,0x00000000,0x00000000}},	//   tçıd, --, --, --, 
   {{0x92ac00fe,0x00000000,0x00000000,0x00000000}},	//   কতৰ_, --, --, --, 
   {{0x64495b67,0xbcf9c9cd,0x7684010e,0x648401ab}},	//   hedi, _préd, _añyn, _sòil, 
   {{0x6449c9ce,0xbcf801c7,0x2900054e,0x9aa401d9}},	//   kedi, _brée, ţian_, _ہمسو, 
   {{0x64481326,0xbcf82047,0x2011c9cf,0xad4400cf}},	//   jedi, _crée, nazi_, _تۉكۉ, 
   {{0xf770552d,0x81ac00cc,0xfaa4014b,0x00000000}},	//   باش_, _কৰম_, _дшан, --, 
   {{0xbcf8007b,0x64480254,0xa7fc008e,0x00000000}},	//   _tréd, eedi, _unın, --, 
   {{0x6449c9d0,0x648401ab,0xbcf80221,0x00000000}},	//   fedi, _eòim, _frée, --, 
   {{0x2011c9d1,0xbcf8806d,0x395dc9d2,0x648401ab}},	//   jazi_, _kréb, _irus_, _fòim, 
   {{0x395c25a9,0x2011c9d3,0xe7f00034,0xddcc012d}},	//   _hrus_, dazi_, _चलता_, ndał, 
   {{0x395dc9d4,0xbdd8020c,0x64480077,0x23788504}},	//   _krus_, _mbèb, aedi, ärja_, 
   {{0x64480831,0x2010d059,0x6d580882,0x64640276}},	//   bedi, fazi_, āvak, _ştiţ, 
   {{0xe0d001d9,0x4558011a,0x00000000,0x00000000}},	//   ٖزِ_, _לכנס, --, --, 
   {{0x3a3c0427,0x13a40133,0x81ac0154,0x00000000}},	//   _obup_, _رۆحی_, _করণ_, --, 
   {{0xa7fc2fbe,0x395c51bc,0x25a002fb,0x92644028}},	//   _anıl, _orus_, _žili_, _ردعم, 
   {{0x395c0218,0xbcf80241,0x7af80427,0x3ea80118}},	// [32e60] _nrus_, _aréb, _čuta, _šití_, 
   {{0x2011c9d5,0x3a3c00d8,0x2d80007f,0x00000000}},	//   cazi_, _abup_, ryie_, --, 
   {{0xddcc033f,0x92ac00fe,0x8078011a,0x4a44003b}},	//   gdał, কতী_, _הניצ, знев, 
   {{0x395c1a56,0x316047a0,0x6449c9d6,0x2378022c}},	//   _brus_, _kriz_, zedi, ørji_, 
   {{0x395dc9d7,0xb9e002bf,0xbcf806af,0xe3b803e0}},	//   _crus_, ніши, _prée, ngır_, 
   {{0x64481709,0xf78008b0,0xcb6801ee,0x00000000}},	//   xedi, ﯨﻠﯩﻚ_, _лаге_, --, 
   {{0xbb40bdd4,0x99dc007f,0x395c0393,0x291802b5}},	//   _перк, _abňd, _erus_, _ārau_, 
   {{0x2011c9d8,0x6449c9d9,0x395cc289,0x3161c9da}},	//   zazi_, wedi, _frus_, _oriz_, 
   {{0x6449c9db,0x20100928,0xd90c10c4,0x00000000}},	//   tedi, yazi_, _نین_, --, 
   {{0xa2f5c9dc,0x648401c3,0xb7d401d3,0x28883267}},	//   мпоч, _tòim, _کوما_, _بصری_, 
   {{0x2011c9dd,0x6449c9de,0x3160fe1d,0xbcf93e03}},	//   vazi_, redi, _ariz_, _kréc, 
   {{0x6449c9df,0x2011c9e0,0x3161c9e1,0x828807a5}},	//   sedi, wazi_, _briz_, ссоб_, 
   {{0x6449c9e2,0x241809a5,0x395c003a,0x00000000}},	//   pedi, _долы_, _xrus_, --, 
   {{0x6449c9e3,0x44f003cb,0x316000ef,0xf990011a}},	//   qedi, _iâ_, _driz_, גרש_, 
   {{0x3161c9e4,0xa2f401b9,0xf438011a,0x00000000}},	//   _eriz_, _ўпич, _התוש, --, 
   {{0x44f1c9e5,0x3160af7a,0x998c00e8,0x81ac03d4}},	//   _kâ_, _friz_, _feeň_, _কৰণ_, 
   {{0x20116f94,0x628cbe13,0xa7fc05d1,0x00000000}},	// [32e70] pazi_, _ilao, _anım, --, 
   {{0x628dc9e6,0x44f1c9e7,0x22583a52,0x6c5401c6}},	//   _hlao, _mâ_, ldsk_, нкуу, 
   {{0x81ac03f4,0x44f0145e,0x1a6461f4,0xbcf80a40}},	//   _করি_, _lâ_, ویسی_, _bréc, 
   {{0x395dc9e8,0xbcf9c9e9,0x68fc01ab,0x44f00042}},	//   _prus_, _créc, _ōrda, _oâ_, 
   {{0xbcf80a40,0x81dc00bd,0x21388a29,0xe9d0004b}},	//   _dréc, দুর_, ntsh_, هغه_, 
   {{0x81ac0d42,0xbcf9c9ea,0xccf00375,0xba753ecd}},	//   _করা_, _tréb, _בכך_, _کاست, 
   {{0x44f0d9df,0x628dc9eb,0xbcf9c9ec,0x75800345}},	//   _aâ_, _olao, _fréc, کیشم, 
   {{0x44f153ad,0x61e8041a,0x395dc9ed,0xbcf801f1}},	//   _bâ_, želj, _trus_, _gréc, 
   {{0x395dc9ee,0x44f01459,0x7bc4010b,0x00000000}},	//   _urus_, _câ_, _hyju, --, 
   {{0xbcf804c4,0x228800d2,0x22580b21,0x628dc9ef}},	//   _zréc, _bûko_, edsk_, _alao, 
   {{0x628c0851,0x78a1c9f0,0x44f00393,0x8c18011a}},	//   _blao, minv, _eâ_, חותי, 
   {{0x3161c9f1,0x628c1552,0xd29802bf,0x78a1c9f2}},	//   _priz_, _clao, ітні_, linv, 
   {{0x628c0332,0x3f8002d2,0x00000000,0x00000000}},	//   _dlao, eyju_, --, --, 
   {{0x628c0270,0x92ac09bd,0x7af80427,0xc0e00212}},	//   _elao, কতে_, _čutn, кояк, 
   {{0x628c08cd,0x09a83b29,0x44f0019f,0x81dc00bd}},	//   _flao, _कश्य, _zâ_, দুল_, 
   {{0x44f005bb,0x628dc9f3,0x92b400c6,0x78a001f5}},	//   _yâ_, _glao, _تحتا, hinv, 
   {{0x78a1c9f4,0x4ce4a0f5,0x00000000,0x00000000}},	// [32e80] kinv, джаб, --, --, 
   {{0x78a00660,0x00000000,0x00000000,0x00000000}},	//   jinv, --, --, --, 
   {{0xbcf82047,0x78a00165,0x768400a2,0xa0c400ec}},	//   _préc, dinv, _añym, _سيٽو, 
   {{0x81ac3fae,0x49c8f4f2,0xe7f82a67,0x00000000}},	//   _কৰি_, олен_, ुर्थ_, --, 
   {{0x7bc401a8,0x67380455,0x7d0002e8,0x00000000}},	//   _eyju, wtvj, _изяж, --, 
   {{0x78a1c9f5,0x44f000e4,0x67d5c9f6,0x00000000}},	//   ginv, _râ_, нолу, --, 
   {{0x44f1c9f7,0x81ac3fae,0x225801bf,0x59701d37}},	//   _sâ_, _কৰা_, ydsk_, _ەگىز, 
   {{0xdcec70f7,0x44f00455,0x39402cc8,0xe55400d8}},	//   nyağ, _pâ_, хнәг, екињ, 
   {{0xbcf97106,0xfaa00640,0xf64c00e3,0x61e803ca}},	//   _kréa, _рато, شئي_, želk, 
   {{0xc32c43e8,0x628c08c2,0x92ac0011,0x45d001d5}},	//   لەت_, _slao, কতো_, ноқс, 
   {{0x44f1c9f8,0x225807d8,0x628dc9f9,0x68e8058a}},	//   _wâ_, пины_, _plao, _iidd, 
   {{0x68e8b183,0xa7fc008e,0xddcc0356,0xe7f800bc}},	//   _hidd, _onık, njaţ, ुरका_, 
   {{0x68e9c9fa,0x755000c7,0x628c01a6,0x2258000f}},	//   _kidd, _аҭыӡ, _vlao, rdsk_, 
   {{0x68e83aaa,0x21380042,0xdb1400d7,0x00000000}},	//   _jidd, rtsh_, _vyzú, --, 
   {{0x628c0770,0x64580109,0xa7fc0166,0x27ec00a3}},	//   _tlao, _iavi, _anık, _mgdn_, 
   {{0x443dc9fb,0x68e9c9fc,0xbcf86085,0x6459c9fd}},	//   lft_, _lidd, _aréa, _havi, 
   {{0x6459c9fe,0x61edc9ff,0xbcf800c6,0x68e88119}},	// [32e90] _kavi, _igal, _bréa, _oidd, 
   {{0xbcf82047,0x443c09a4,0x68e9ca00,0x6ef801f2}},	//   _créa, nft_, _nidd, ụbat, 
   {{0x6459ca01,0x443dca02,0x61ec18d6,0x78a002f6}},	//   _mavi, ift_, _kgal, vinv, 
   {{0x6459ca03,0x41d00c22,0x68e80213,0x00000000}},	//   _lavi, _सरास, _aidd, --, 
   {{0x1868316e,0x61edca04,0x78a1ca05,0xbcf8007b}},	//   зали_, _mgal, tinv, _fréa, 
   {{0x6459ca06,0x68e9ca07,0xbcf80491,0x443c0936}},	//   _navi, _cidd, _gréa, jft_, 
   {{0x68e9ca08,0xf09402e4,0x61edca09,0x443c00d8}},	//   _didd, כנס_, _ogal, dft_, 
   {{0x78a1ca0a,0x443dca0b,0x6459ca0c,0x68e800a9}},	//   sinv, eft_, _aavi, _eidd, 
   {{0x443dca0d,0x68e83a2e,0x00000000,0x00000000}},	//   fft_, _fidd, --, --, 
   {{0x61edca0e,0x68e9ca0f,0x443c010a,0x13040117}},	//   _agal, _gidd, gft_, нзом, 
   {{0x53c800d6,0x00000000,0x00000000,0x00000000}},	//   ягом_, --, --, --, 
   {{0x64581496,0x60c40e02,0x443dca10,0x68e9ca11}},	//   _eavi, _akhm, aft_, _zidd, 
   {{0x6459ca12,0x61ec0022,0x68e8e6a6,0x50b4009b}},	//   _favi, _dgal, _yidd, есву, 
   {{0x68e80014,0xd01001d5,0x76582ca8,0x00000000}},	//   _xidd, طلر_, lduy, --, 
   {{0xb4c856e9,0x3f64013e,0xdb1401e1,0x00000000}},	//   लती_, ниро_, _ìbèj, --, 
   {{0x76580db8,0x64588b8c,0x61ec0337,0xdcfc06be}},	//   nduy, _zavi, _ggal, _axsı, 
   {{0x7539ca13,0xbcf9ca14,0x6459ca15,0xeff80023}},	// [32ea0] ntuz, _préa, _yavi, ላላይ_, 
   {{0x6459ca16,0x6ab806bc,0x61ec01b9,0x8f740212}},	//   _xavi, इक्र, _zgal, _зумі, 
   {{0x629c017a,0x61ec0432,0x8fa43e38,0x00000000}},	//   ërog, _ygal, _чане, --, 
   {{0x68e9ca17,0xc3300302,0x7538005a,0x00000000}},	//   _sidd, רוא_, ktuz, --, 
   {{0x68e808e5,0x443dca18,0x7658011f,0xbcf8007b}},	//   _pidd, yft_, dduy, _tréa, 
   {{0x68e8102c,0x48bc00eb,0x00000000,0x00000000}},	//   _qidd, ইগ্র, --, --, 
   {{0x68e9ca19,0x0cbc34a5,0x00000000,0x00000000}},	//   _vidd, ्तीम, --, --, 
   {{0x6459ca1a,0x68e9ca1b,0xddcc1591,0x7659279f}},	//   _savi, _widd, ljaš, gduy, 
   {{0x68e82087,0x7ae023f5,0x1fdc5162,0xb4c82ce1}},	//   _tidd, ïnte, _मण्ड, लतू_, 
   {{0x443c2155,0x81ac015b,0xf8a475a2,0xddcc05be}},	//   uft_, _করল_, _звук_, njaš, 
   {{0x443dca1c,0x64589cde,0x22942564,0x61ec05b1}},	//   rft_, _vavi, виня, _pgal, 
   {{0x6459ca1d,0x0cbc1a3e,0x00000000,0x00000000}},	//   _wavi, ्तुम, --, --, 
   {{0xe53488d6,0x443dca1e,0xbcf86361,0xe4543e1f}},	//   _рель, pft_, _arén, _аклы, 
   {{0xe3dc74bb,0xbcf80a40,0x64580472,0xb4f8011a}},	//   _ҳ̸ҳ̸, _brén, _uavi, _צפוי, 
   {{0xf4848a54,0x61ec05d5,0xbcf90b13,0x234807d6}},	//   _ثانی, _tgal, _crén, _آستی_, 
   {{0x61edca1f,0xbcf80221,0x6b6c01e1,0xdb140241}},	//   _ugal, _drén, _o̟gb, _ìbéj, 
   {{0xf1a5ca20,0xbcf800e5,0x5d540395,0x7c84011c}},	// [32eb0] _брэн, _erén, ъкат, нуже, 
   {{0x60c40227,0xbcf806af,0x00000000,0x00000000}},	//   _ukhm, _frén, --, --, 
   {{0xbcf80a40,0x6d40006a,0xb09c008f,0xbdd80241}},	//   _grén, _äman, _מיזר, _gbèn, 
   {{0xe9f87a9c,0x00000000,0x00000000,0x00000000}},	//   енці_, --, --, --, 
   {{0xe8f82355,0xddcc08a4,0x76a4020c,0x00000000}},	//   елі_, bjaš, _lèyè, --, 
   {{0x6d580882,0x7d0c0076,0x6ce40a4a,0x00000000}},	//   āvat, _iwcs, _бісе, --, 
   {{0x6b6c0241,0xa9c400d1,0xe77800e5,0x2d840139}},	//   _e̟gb, ксәк, فلوں_, _ümer_, 
   {{0xdddc00da,0x16640063,0x7538005a,0x99dc010e}},	//   _nosū, твим, ttuz, _maňz, 
   {{0x7659ca21,0xa2c408df,0x00000000,0x00000000}},	//   rduy, रवन्, --, --, 
   {{0xb4c80d35,0x9418013f,0xb360001f,0x00000000}},	//   लते_, ɑsɛ_, _ስራውን_, --, 
   {{0xb9dc2295,0x7d0c0042,0xb7640212,0x00000000}},	//   _ሥራ_, _lwcs, _ятай, --, 
   {{0xddcc07f5,0x61f80030,0x753801c4,0x23d400c7}},	//   zjaš, _čalú, ptuz, ыцыр, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbcf9ca22,0x93940066,0x00000000,0x00000000}},	//   _prén, _لجبا, --, --, 
   {{0xd7f00208,0x00000000,0x00000000,0x00000000}},	//   _lão_, --, --, --, 
   {{0xbcf94ef6,0xe3e800c8,0xf3f00183,0x00000000}},	//   _créo, _אַפֿ, _আজিৰ_, --, 
   {{0x1ea80fba,0xbb4c00b5,0xddcc0010,0xd7f00051}},	// [32ec0] رافي_, _rpmで_, tjaš, _não_, 
   {{0x0cbc09d9,0xbcf81dee,0x76a4007f,0x00000000}},	//   ्तेम, _trén, _yèyè, --, 
   {{0x91f41533,0x61f000d2,0xddcc4b16,0x8f7401ca}},	//   _इलाज_, _éhlú, rjaš, _рупі, 
   {{0x7a2801b8,0xd7f00208,0x7f400166,0x00000000}},	//   vötü, _bão_, _änqa, --, 
   {{0x6d580882,0xc02c01fb,0xb88000d7,0x00000000}},	//   āvas, _điếu_, _číry, --, 
   {{0xd90dca23,0xfc0056ac,0xb4c81fbc,0x311400dc}},	//   سیم_, _впро, लतो_, तीयः_, 
   {{0x6f1c00b5,0x99dc00a2,0xfd6400e4,0xca54009b}},	//   nsrc, _maňy, kyrỹ, _итањ, 
   {{0xbdd8004e,0x2b59ca24,0x00000000,0x00000000}},	//   _obèl, _isrc_, --, --, 
   {{0x2b5969d1,0xdb0801b8,0xd9440137,0x855400f2}},	//   _hsrc_, änöf, _مئلي, ئیتر_, 
   {{0x9f442776,0x0465ca25,0x00000000,0x00000000}},	//   älë_, ттим, --, --, 
   {{0xbdd8020c,0xbcf80098,0x15380b28,0xdddc0024}},	//   _abèl, _arél, وزیک_, _posū, 
   {{0xbcf80165,0xf2c4022e,0x00000000,0x00000000}},	//   _brél, исян, --, --, 
   {{0x26c5ca26,0x6484026c,0x8574059e,0x2b580175}},	//   momo_, _bòit, _جدائ, _lsrc_, 
   {{0x9f3505a1,0x2b580354,0x76a4020c,0x26d8002e}},	//   легі, _osrc_, _tèyè, _ërob_, 
   {{0xbcf85725,0x14b09a2c,0x99dc010b,0x00000000}},	//   _préo, ीकरण, _daňy, --, 
   {{0x7d0c02d0,0x5f940137,0x00000000,0x00000000}},	//   _pwcs, _ەلدئ, --, --, 
   {{0xadf46206,0x5d340956,0x00000000,0x00000000}},	// [32ed0] рпуш, طفائ, --, --, 
   {{0x26c4014c,0x99dc00a2,0xac940022,0x00000000}},	//   homo_, _gaňy, аауш, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d580882,0x26c40428,0xdb14010e,0x00000000}},	//   āvar, jomo_, _gyzý, --, 
   {{0x26c5ca27,0xbcf819fd,0x2b580142,0xd82401c0}},	//   domo_, _krém, _esrc_, гдли, 
   {{0x2b58010a,0x7c844140,0x02dc121d,0xac8400fb}},	//   _fsrc_, _руме, नगुन, _кѳсл, 
   {{0x26c5ca28,0xc7a003cc,0x2bc82826,0x940403b9}},	//   fomo_, йишк, _ауто_, chlə_, 
   {{0x26c5ca29,0x195806a6,0x00000000,0x00000000}},	//   gomo_, _пабы_, --, --, 
   {{0xd4140948,0xbcf8003a,0x648401ab,0xb8e80183}},	//   льны, _orém, _nòis, _ৰং_, 
   {{0x1308169c,0x34a000c2,0x00000000,0x00000000}},	//   нной_, ргоҳ, --, --, 
   {{0x26c5ca2a,0xd2a88211,0xa5648863,0x00000000}},	//   bomo_, екне_, هدین, --, 
   {{0x26c407ad,0xbcf9ca2b,0x7760045a,0xe6100137}},	//   como_, _prél, mvnx, _ۇشۇ_, 
   {{0x648401c3,0xd7f00051,0x00000000,0x00000000}},	//   _còis, _lãm_, --, --, 
   {{0x63480605,0x248c0204,0xbcf82d7d,0xdb1400a2}},	//   _sɛne, ckdm_, _crém, _syzý, 
   {{0xca140150,0xc4d0011a,0x00000000,0x00000000}},	//   _ﺳﻪﺱ_, _הגג_, --, --, 
   {{0xe3b09a79,0xbea050fc,0xbcf801e1,0xc33008a8}},	//   _بره_, баск, _erém, _הוה_, 
   {{0x8d64100e,0xdb1402fb,0xd7f000e4,0xbcf806af}},	// [32ee0] ывае, _vyzý, _og̃_, _frém, 
   {{0x26c553dd,0x2b58009f,0x00000000,0x00000000}},	//   zomo_, _psrc_, --, --, 
   {{0x26c51353,0x4b25c20e,0xef940244,0x1c3801f4}},	//   yomo_, умев, _ئیزد, ъять_, 
   {{0xd7f000e4,0x8c440139,0x00000000,0x00000000}},	//   _ag̃_, _өеме, --, --, 
   {{0xa7fc0724,0x26c40af2,0x648400a3,0x5d745b0f}},	//   _onıt, vomo_, _mòir, _курф, 
   {{0xbdd8007f,0xbfc80150,0xa3e407af,0x00000000}},	//   _obèj, _تاۋە_, पेड_, --, 
   {{0x26c5ca2c,0x38c80214,0x37a400a7,0x00000000}},	//   tomo_, راهی_, лтън_, --, 
   {{0x7f3800c8,0xa7fc0790,0xac84030d,0xf7440472}},	//   געקו, _anıt, _йӳçл, اليي_, 
   {{0x26c5ca2d,0xbdd801e1,0x7af8151c,0x787001d9}},	//   romo_, _abèj, _čuti, _گُلا, 
   {{0x26c49dc0,0xb9900597,0x3200011f,0x48e4005b}},	//   somo_, _الكب, _afiy_, _созв, 
   {{0x64840e89,0xa3d40006,0xa2b5ca2e,0x26c5ca2f}},	//   _sòis, ронч, ибоч, pomo_, 
   {{0x26c401ee,0x64840e89,0xb6000815,0xd5a4030f}},	//   qomo_, _còir, _ляшк, الیی, 
   {{0xbdd80100,0x648400a3,0xf2c43163,0x64740108}},	//   _ebèj, _dòir, ссэн, _вглу, 
   {{0xe3a4bc3d,0xbcf86c80,0x3d1801e1,0x00000000}},	//   _پشتی, _fréj, _làwá_, --, 
   {{0xbcf9ca30,0x648401c3,0xbdd801e1,0x24940014}},	//   _gréj, _fòir, _gbèj, _مۅکھ_, 
   {{0x7de40046,0xa3e400dc,0x64840192,0x00000000}},	//   гізд, पेण_, _tòis, --, 
   {{0x2249ca31,0x00000000,0x00000000,0x00000000}},	// [32ef0] _ibak_, --, --, --, 
   {{0x61e809a8,0x75e8010e,0x00000000,0x00000000}},	//   žels, _hözü, --, --, 
   {{0x75e800dd,0x3d1801e1,0xbfa80050,0x2905ca32}},	//   _közü, _bàwá_, _سادٕ_, _atma_, 
   {{0xeb0800d1,0x00000000,0x00000000,0x00000000}},	//   اقنى_, --, --, --, 
   {{0x224932a8,0xd1e8044e,0xa3e407b6,0xbd8401ee}},	//   _mbak_, _መኸተ_, पेत_, _сѳнк, 
   {{0x224803a2,0xd70402e8,0x00000000,0x00000000}},	//   _lbak_, азки, --, --, 
   {{0x9695ca33,0xa7fc62c7,0x3d1801e1,0xbcf80022}},	//   ириш, _anıs, _fàwá_, _orék, 
   {{0x290403d1,0xe768143e,0x00000000,0x00000000}},	//   _ftma_, احون_, --, --, 
   {{0x9874292c,0xf84401c6,0x00000000,0x00000000}},	//   _клац, _бүлд_, --, --, 
   {{0xbcf9ca34,0x2248102c,0x7988015d,0x8cb800cd}},	//   _arék, _abak_, mygw, ्वयो, 
   {{0x798800a9,0x29000276,0xe6b401d5,0x96740024}},	//   lygw, ţiat_, شلیگ, _вылі, 
   {{0x83600aaf,0x75e80bbc,0x9474072d,0x00000000}},	//   زگىل, _cözü, ادکا, --, 
   {{0x75e8106e,0x51b9b4a2,0x00000000,0x00000000}},	//   _dözü, тыня_, --, --, 
   {{0x22480086,0xbcf80248,0x8598011a,0xd0100b24}},	//   _ebak_, _erék, _בשנו, تلس_, 
   {{0xbcf80438,0x648400a3,0x03a0533f,0x33940354}},	//   _frék, _tòir, _мишо, _сăвв, 
   {{0x75e83559,0x2288145e,0xbcf800d0,0x60c00100}},	//   _gözü, _bûku_, _grék, člma, 
   {{0xc1b00022,0x7e800150,0x00000000,0x00000000}},	// [32f00] _дәры, _ﺭﺠﻌﺕ_, --, --, 
   {{0x81ac3fae,0xcb68295d,0x2904022e,0x62640150}},	//   _কৰক_, казе_, _rtma_, _ناۋق, 
   {{0x75e80166,0x8cb800cd,0x00000000,0x00000000}},	//   _yözü, ्वबो, --, --, 
   {{0x7d1c0548,0x79880142,0xc964490c,0x00000000}},	//   bsqs, fygw, ивей, --, 
   {{0x8d740131,0x88e43c55,0xd05c03b9,0x00000000}},	//   _ئاجا, ажде, _sipə, --, 
   {{0x991402d5,0xa7fc15b7,0x00000000,0x00000000}},	//   сьці, _anır, --, --, 
   {{0xc1d00882,0x7c4401d3,0xc7c400f0,0x00000000}},	//   _सर्ग, ésrő, јсли, --, 
   {{0xbcf80129,0x38c808dc,0x00000000,0x00000000}},	//   _bréh, _یالی_, --, --, 
   {{0x2904892f,0xa2c4085c,0xa6140022,0x56780137}},	//   _utma_, रवस्, азқә, اشىڭ_, 
   {{0x75e85556,0x07a5ca35,0x224803a2,0x2288045f}},	//   _sözü, _казн, _sbak_, _lûkt_, 
   {{0xbcf80098,0xd34400f2,0x00000000,0x00000000}},	//   _prék, میوه_, --, --, 
   {{0x02a428e5,0x00000000,0x00000000,0x00000000}},	//   рром, --, --, --, 
   {{0xbcf800e4,0xa7fc0166,0x00000000,0x00000000}},	//   _iség, _unıs, --, --, 
   {{0x74640395,0x00000000,0x00000000,0x00000000}},	//   _връв_, --, --, --, 
   {{0xd4c40597,0xdfd5ca36,0x75e800fd,0x11840131}},	//   _اغني, совы, _tözü, _һәрп_, 
   {{0x9418013f,0x6f880014,0x00000000,0x00000000}},	//   ɑsɑ_, گنہِ_, --, --, 
   {{0xbcf804c4,0x2288000f,0x6e9400f3,0xd1f80092}},	// [32f10] _kréi, _dûkt_, циту, ላካች_, 
   {{0xad243ee0,0xdea0006c,0xa7fc0166,0xbc041887}},	//   زىمى, _کیری, _onıq, рчай, 
   {{0x6348016b,0x79880042,0x00000000,0x00000000}},	//   _yɛna, wygw, --, --, 
   {{0x2288025a,0x99d800c6,0x00000000,0x00000000}},	//   _tûku_, هواء_, --, --, 
   {{0x7af80960,0xa7fc0166,0xbcf800e4,0x00000000}},	//   _čutu, _anıq, _oréi, --, 
   {{0xfc640801,0x972400c6,0x3158008f,0x78440006}},	//   _тъмн, مفتو, יידן_, рэдж, 
   {{0xbd7c0023,0xdbe403d4,0x9b94007b,0xdb140248}},	//   _ረኺቦም_, _প্ৰফ, _الأت, _ìbàj, 
   {{0xbcf9ca37,0x7684010b,0xd7f00208,0xe70801f7}},	//   _préh, _añyr, _mãi_, جتون_, 
   {{0xbcf9a6c2,0xa3e406e3,0xd7f00051,0x94743fe6}},	//   _bréi, पेस_, _lãi_, مددا, 
   {{0xbcf84d74,0xa5e80184,0x37a9ca38,0x629cd6ae}},	//   _créi, шлыҡ_, _итен_, ëron, 
   {{0xbcf9a891,0x06940451,0x8cb80bca,0x6d400022}},	//   _dréi, _ڏانھ, ्वतो, _ãmav, 
   {{0xbcf9ca39,0xc7b00375,0x629c0153,0x72a400cf}},	//   _eréi, _צבא_, ūron, تەبن, 
   {{0xbcf804c4,0x2288000f,0x00000000,0x00000000}},	//   _fréi, _rûkt_, --, --, 
   {{0xbcf9ca3a,0x836000cf,0x00000000,0x00000000}},	//   _gréi, زگۉل, --, --, 
   {{0xddcc0115,0xd7f00051,0x00000000,0x00000000}},	//   rdaŝ, _bãi_, --, --, 
   {{0x6ecc002f,0xd7f00051,0xbea001f4,0x00000000}},	//   eßbr, _cãi_, паск, --, 
   {{0x0c2411cf,0xa2c4243c,0x10a44873,0x00000000}},	// [32f20] йман, रवर्, _гипн, --, 
   {{0xdc28004b,0x6ea800e5,0x00000000,0x00000000}},	//   لسمه_, _چندہ_, --, --, 
   {{0x0b4453ef,0x00000000,0x00000000,0x00000000}},	//   снен, --, --, --, 
   {{0xc33002e4,0x98b800de,0x92040055,0x00000000}},	//   לוב_, _īsā_, bjāś, --, 
   {{0xeb082928,0xda641622,0x8238008f,0xe9440101}},	//   اقچى_, تالي, רענצ, ترضی, 
   {{0xddcdca3b,0x6d456bff,0xaee40248,0x00000000}},	//   ldaş, mtia, baṣi, --, 
   {{0x6d45ca3c,0xb8fc1a04,0xbcf800e4,0xc6a40c60}},	//   ltia, _धी_, _rréi, йрии, 
   {{0xddcc93ba,0x6d456b40,0x00000000,0x00000000}},	//   ndaş, otia, --, --, 
   {{0x6d45ca3d,0xbcf9ca3e,0x00000000,0x00000000}},	//   ntia, _préi, --, --, 
   {{0x3e6dca3f,0x6d45ca40,0x6a8401b9,0xddcc03e3}},	//   _kötä_, itia, _улға, hdaş, 
   {{0x6d45ca41,0xddcd4c76,0xfee000d1,0xa2c4081e}},	//   htia, kdaş, _ﺋﺎﯞﺍ, रवल्, 
   {{0x6d45ca42,0xbdd801e1,0x00000000,0x00000000}},	//   ktia, _gbèw, --, --, 
   {{0xbcf88f8a,0x6d440218,0x768400c7,0xddcc00ac}},	//   _tréi, jtia, _iñyp, ddaş, 
   {{0xbcf800d8,0xa6c400f7,0x00000000,0x00000000}},	//   _uréi, _اقچى, --, --, 
   {{0x6d45ca43,0xfeb86762,0xc30400db,0xddcc00ac}},	//   etia, هارت_, _ابتو, fdaş, 
   {{0x6348016b,0x64480b4f,0x9d14487f,0x6d456f7c}},	//   _yɛnn, lfdi, ждач, ftia, 
   {{0x6d4401d4,0xead00248,0x64480549,0xa3e400bc}},	// [32f30] gtia, _jẹun_, ofdi, पेर_, 
   {{0xe0d001d9,0xbcf800c7,0x3e6c0139,0x1728031c}},	//   _زٲج_, _orév, _bötä_, _ལྷའམ_, 
   {{0x69c00a81,0xd9f821fa,0x6d44e6a6,0x00000000}},	//   _axme, анец_, atia, --, 
   {{0x6d45ca44,0x629c0208,0x9cc800fb,0x00000000}},	//   btia, nhso, уыға_, --, 
   {{0xa92400d6,0xbcf9ca45,0x00000000,0x00000000}},	//   зділ, _arév, --, --, 
   {{0x1869ca46,0xd709ca47,0xbcf806af,0xd77400be}},	//   раки_, анке_, _brév, قابع, 
   {{0xbcf8020c,0xfbd001d9,0x64480175,0x8ca000db}},	//   _préw, _رتس_, dfdi, _تەلو, 
   {{0x644801f5,0xdd0800d0,0x00000000,0x00000000}},	//   efdi, _môžt, --, --, 
   {{0x6449ca48,0x3a3c004e,0x94784c04,0x61300139}},	//   ffdi, _icup_, асну_, _jılğ, 
   {{0xbcf80165,0x3e6c023a,0x00000000,0x00000000}},	//   _frév, _yötä_, --, --, 
   {{0x6d440323,0xddcce978,0xbdd801e1,0xbcf839b4}},	//   ztia, ydaş, _ibèu, _grév, 
   {{0x6d45ca49,0x629c04cc,0x3ea80051,0x2bd037cc}},	//   ytia, ghso, _nmct_, _तुफा, 
   {{0x6d459af7,0xc690010f,0x00000000,0x00000000}},	//   xtia, _קאד_, --, --, 
   {{0x8f54001f,0xe6940150,0x4f94004e,0xc5f0011a}},	//   _ምልክቶ, _ولەد, орбу, _חדד_, 
   {{0xddcc09a5,0x3a3c054e,0x6d44015d,0x00000000}},	//   tdaş, _ocup_, wtia, --, 
   {{0x6d45ca4a,0x629c0112,0x8e080798,0x00000000}},	//   ttia, chso, рнав_, --, 
   {{0xddcceedf,0x4c84a283,0x6d44003a,0x10a4004e}},	// [32f40] rdaş, олав, utia, _миин, 
   {{0x3a3c004e,0x6d4538dd,0x61e80209,0x0b9400db}},	//   _acup_, rtia, ýele, يجاد, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d45ca4b,0x3a3c0076,0x00000000,0x00000000}},	//   ptia, _ccup_, --, --, 
   {{0x39100212,0x7a2c01e1,0xc9580395,0x3ea000db}},	//   дмір, _sòtà, ршец_, _цияг, 
   {{0xbcf9ca4c,0xaa4400db,0x00000000,0x00000000}},	//   _prév, تنچى, --, --, 
   {{0x395c003a,0xc7640137,0x00000000,0x00000000}},	//   _esus_, تاشى, --, --, 
   {{0x61300724,0x4548c134,0x3a3c00b5,0xc6680556}},	//   _yılğ, ачом_, _gcup_, ршке_, 
   {{0x7e980bd9,0x395c0076,0x26d800e2,0x00000000}},	//   יסקו, _gsus_, ēro_, --, 
   {{0x2a640472,0xbcf806af,0x00000000,0x00000000}},	//   _hamb_, _usée, --, --, 
   {{0x629dca4d,0x31600bc2,0xc6040953,0xa3e402a0}},	//   thso, _asiz_, _дзей, पें_, 
   {{0x67380455,0x96b8030d,0x00000000,0x00000000}},	//   muvj, _лучу_, --, --, 
   {{0x2a6407ab,0x64480112,0xf8dc00cd,0x00000000}},	//   _mamb_, pfdi, _पीडय, --, 
   {{0x2a65ca4e,0xc0c9ca4f,0x629c037e,0x00000000}},	//   _lamb_, руме_, shso, --, 
   {{0x316066d4,0xa29402d5,0x00000000,0x00000000}},	//   _esiz_, _накі, --, --, 
   {{0x9df8721f,0x9ed8039b,0x25a00306,0x32c40139}},	//   снат_, ёмат_, _žily_, gıyd_, 
   {{0x4084013e,0x6130008e,0x5c98005b,0x225800c0}},	// [32f50] _дунб, _qılğ, бкая_, mesk_, 
   {{0x2139ca50,0x290001e4,0x00000000,0x00000000}},	//   mush_, ƭiaj_, --, --, 
   {{0xbcf800e4,0x673801a6,0x316001d5,0x00000000}},	//   _arét, juvj, _zsiz_, --, 
   {{0xbcf9ca51,0x67381e31,0x19c400d1,0xbd68004e}},	//   _brét, duvj, пәзг, _крге_, 
   {{0xa905ca52,0x2a642508,0xbcf89e33,0xddcc0841}},	//   وبون, _damb_, _crét, ljaž, 
   {{0xbcf8003e,0xe9d80953,0x629c0023,0x395c0393}},	//   _drét, цкі_, ëroj, _vsus_, 
   {{0xbcf8cd11,0x2139ca53,0x8cb800cd,0x9b884363}},	//   _erét, hush_, ्वरो, _انزل_, 
   {{0xba75ca54,0xbcf80f99,0x2139ca55,0x395c0218}},	//   _باست, _frét, kush_, _tsus_, 
   {{0x2259ca56,0x395d2c3a,0x66cc025a,0x6d40014a}},	//   desk_, _usus_, rûkp, _ämat, 
   {{0x3160022e,0x855401d9,0x21380200,0x53a400ea}},	//   _rsiz_, ثیٖر_, dush_, заоб, 
   {{0x61f000ac,0x2a6400e8,0xdef00b82,0x00000000}},	//   ədlə, _yamb_, ግለን_, --, 
   {{0x21380263,0x2a64002e,0x3160022e,0xe7c400bc}},	//   fush_, _xamb_, _psiz_, _लुटप, 
   {{0xd1740fca,0x10141cd0,0x059400e5,0x2138010e}},	//   чыны, зьбя, _ٹانگ, gush_, 
   {{0xa0740220,0x2ec41fe7,0x74100133,0xe4c800cf}},	//   мысш, वक्त, _کوژا, _وبون_, 
   {{0xbdd806af,0x22580790,0x00000000,0x00000000}},	//   _obès, besk_, --, --, 
   {{0x2139ca57,0x9044021a,0xf7d40150,0x00000000}},	//   bush_, _کنده, _ﺀﻭﻟﺪ, --, 
   {{0x67381e31,0x8cb800dc,0x316001a9,0x00000000}},	// [32f60] zuvj, ्वलो, _usiz_, --, 
   {{0xc170008d,0x2a65ca58,0x71a40107,0x7ff400db}},	//   _נחת_, _samb_, _нақз, _ىسپا, 
   {{0xbcf87c92,0xef940271,0x00000000,0x00000000}},	//   _brés, _غیرد, --, --, 
   {{0xae740075,0xbcf9ca59,0x1728031c,0x09e40395}},	//   _تۇرغ, _prét, _ལྷེམ_, поен, 
   {{0xbcf800d5,0x2bac01ad,0x9db817b4,0x00000000}},	//   _drés, _टेरा, _дыру_, --, 
   {{0xc7642002,0x67d5ca5a,0x225805c7,0x6739ca5b}},	//   كابى, молу, zesk_, tuvj, 
   {{0x2a65ca5c,0xfbc0063b,0xfce00137,0xbcf802d2}},	//   _tamb_, _збро, _чоро, _frés, 
   {{0xbdd9ca5d,0x213803a2,0xbcf80129,0x629c02b1}},	//   _ibèr, yush_, _grés, īrok, 
   {{0xbcf80687,0xc984007b,0x213801d5,0x98b80064}},	//   _urét, _عشري, xush_, _ūsą_, 
   {{0x3ebc09a8,0x213801b9,0xb8240276,0xc8c8009f}},	//   čuti_, vush_, _ноуз_, _اوئن_, 
   {{0xd05c016b,0x6234764a,0x6d580882,0x6738014f}},	//   _nipɑ, мену, āvay, quvj, 
   {{0xe1f80372,0x21394065,0x00000000,0x00000000}},	//   өгү_, tush_, --, --, 
   {{0x5bb80037,0xcfa800bd,0xbcf87dec,0x2138003e}},	//   _आश्व, _খুলন, _oséa, uush_, 
   {{0x212c0316,0xa3b400d6,0xbdd80ba1,0xddcc0219}},	//   šeho_, _облі, _obèr, tjaž, 
   {{0x9e940244,0x00000000,0x00000000,0x00000000}},	//   وارچ, --, --, --, 
   {{0x443dca5e,0x9ed801ce,0x9d1801d5,0x00000000}},	//   lgt_, імат_, жоат_, --, 
   {{0x2139ca5f,0xbcf9ca60,0x443c0196,0xc0c800ee}},	// [32f70] qush_, _arér, ogt_, _гуне_, 
   {{0x6728036f,0xa2c51269,0x32c40205,0x00000000}},	//   _ovdj, रवक्, rıye_, --, 
   {{0xbcf82047,0x443ca8a4,0x9e1400d6,0xdc1c033f}},	//   _prés, igt_, _одні, _फ़ीड_, 
   {{0xdd95ca61,0x443c0270,0x629c0023,0xd99800c6}},	//   _жамы, hgt_, ëroh, ينات_, 
   {{0x6348013f,0xbdd802e2,0xbcf80022,0x042000cc}},	//   _bɛnk, _ebèr, _erér, _মানী_, 
   {{0x443c0936,0xbcf8557b,0xddcc012d,0x00000000}},	//   jgt_, _frér, reań, --, 
   {{0xbcf9ca62,0xbdd80241,0xe80c02e5,0x6d40000d}},	//   _trés, _gbèr, हड़ा_, _ämar, 
   {{0x443dca63,0x67280010,0xead400c0,0x00000000}},	//   egt_, _dvdj, _зось, --, 
   {{0xdddc068f,0xc50400ec,0x00000000,0x00000000}},	//   _hasł, وڪول_, --, --, 
   {{0x443dca64,0x27e0012c,0x00000000,0x00000000}},	//   ggt_, řina_, --, --, 
   {{0x128402d3,0xdddc012d,0x555400ec,0x00000000}},	//   _ክረክብ_, _jasł, _ڊپار, --, 
   {{0x443c0936,0xdddc033f,0x168403e6,0x2d800129}},	//   agt_, _masł, _تائێ, yxie_, 
   {{0xd00935dc,0x6348016b,0x2d800051,0xd1c801ec}},	//   жеге_, _yɛnk, xxie_, ілге_, 
   {{0x443c074d,0x7538055a,0x765800d5,0x24c80150}},	//   cgt_, muuz, leuy, _егіп_, 
   {{0x130407d6,0x96e00316,0x233400c7,0x753804ba}},	//   _ўзим, _पठाउ, _зхыр, luuz, 
   {{0xb63c019b,0x2d8001c4,0x0dc801e0,0x00000000}},	//   _ａｖ_, txie_, ҡуҡи_, --, 
   {{0x62640137,0xa7fc00a2,0x753804ba,0x90c400c7}},	// [32f80] _سايق, _baıl, nuuz, _обие, 
   {{0xbcf806af,0x76580c6a,0x6ab80709,0x00000000}},	//   _prér, heuy, ेक्र, --, 
   {{0x4a443e4f,0x7538009f,0x76580098,0x04200154}},	//   днев, huuz, keuy, _মামী_, 
   {{0x6348013f,0x75380bd7,0x00000000,0x00000000}},	//   _sɛnk, kuuz, --, --, 
   {{0xbcf9ca65,0x6e25bd9b,0x7658ebad,0xacb41411}},	//   _fréq, maib, deuy, _كەرب, 
   {{0x6e24b8c5,0x7658003e,0x070801f0,0x00000000}},	//   laib, eeuy, охии_, --, 
   {{0xbdd8067c,0x00000000,0x00000000,0x00000000}},	//   _ubèr, --, --, --, 
   {{0x6e25ca66,0xbcf80098,0x753804ba,0x765800d5}},	//   naib, _krép, fuuz, geuy, 
   {{0xdddc0034,0xd90c1550,0x7ae0098c,0x443c0051}},	//   _zasł, _هین_, înte, tgt_, 
   {{0x6e25ca67,0x443dca68,0x63480134,0xbcf800e4}},	//   haib, ugt_, _yɛnh, _osén, 
   {{0x443dca69,0x6e25ca6a,0x21280306,0x00000000}},	//   rgt_, kaib, _svah_, --, 
   {{0x6e2402b4,0x75382f99,0x443dca6b,0xdddc0030}},	//   jaib, buuz, sgt_, _hosť, 
   {{0x05b804d3,0x6e25ca6c,0xbcf80005,0x2bd001ad}},	//   _بدات_, daib, _asén, _तुसा, 
   {{0x443c0175,0xdc3000d7,0x00000000,0x00000000}},	//   qgt_, týči, --, --, 
   {{0xf361bfa5,0xbdd801e1,0xf484006c,0x442c06af}},	//   _атын, _abèp, _تانی, _idf_, 
   {{0x6e25ca6d,0x212805b1,0x05e03c71,0xab6800ef}},	//   gaib, _tvah_, _पराब, _meļķ, 
   {{0x7c8407d8,0xbcf82d7d,0x0a2c001f,0xa19414fb}},	// [32f90] муже, _crép, _አምላካ, _чапч, 
   {{0x628c0069,0x442ccaca,0xd1d0001f,0x32c40213}},	//   _hoao, _jdf_, ረኞች_, mıya_, 
   {{0x9f440891,0x5a3410ea,0x5b15ca6e,0x6e25ca6f}},	//   älä_, енет, хмет, baib, 
   {{0x6e25ca70,0x442dca71,0x628caaa8,0x753804ba}},	//   caib, _ldf_, _joao, yuuz, 
   {{0x273c00d7,0x32c4453a,0x00000000,0x00000000}},	//   yšná_, nıya_, --, --, 
   {{0x442ca928,0xdb040036,0x7658bb92,0x00000000}},	//   _ndf_, nzhë, weuy, --, 
   {{0x753804ba,0x76580098,0x5a340138,0x3f80025c}},	//   wuuz, teuy, _пнвт, nxju_, 
   {{0x32c47236,0x628c0334,0xbcf80022,0x75382252}},	//   kıya_, _noao, _yrép, tuuz, 
   {{0x76580438,0x442c0334,0x959825ec,0xe944014b}},	//   reuy, _bdf_, ятку_, _аххо, 
   {{0x442c0230,0x628dc476,0x6ba40432,0x32c40205}},	//   _cdf_, _aoao, _öwgü, dıya_, 
   {{0x6e25ca72,0x442c0334,0x03215d44,0x88980375}},	//   yaib, _ddf_, лдэн, _צבעי, 
   {{0x75380451,0x442dca73,0x00000000,0x00000000}},	//   puuz, _edf_, --, --, 
   {{0xbdd9ca74,0xe2800046,0x6e25ca75,0x442dca76}},	//   _scèn, рғын, vaib, _fdf_, 
   {{0x92c003f4,0x442dca77,0x6e24d155,0x3ea0010b}},	//   ্গে_, _gdf_, waib, ңирг, 
   {{0x6e25ca78,0x628c030a,0x1fb5ca79,0x8fa43d89}},	//   taib, _foao, встр, хаве, 
   {{0xbcf80231,0x442dca7a,0x63bc0030,0x2bd0530e}},	//   _prép, _zdf_, úrne, _तुषा, 
   {{0x32c403ee,0x7bc8ea10,0xbac00150,0x5eb800fe}},	// [32fa0] cıya_, şgul, _ﯨﺸﺘﺎ, _আঠখে, 
   {{0x6e25ca7b,0xbcf800d2,0x602800e4,0x629c036e}},	//   saib, _tsén, rëmí, ërov, 
   {{0x6e2492e1,0xdddc01ef,0x00000000,0x00000000}},	//   paib, _rosť, --, --, 
   {{0x629c0006,0xfaa1ca7c,0xbcf9ca7d,0x2ea801ed}},	//   ūrov, лахо, _trép, _کھڑی_, 
   {{0x7bc49223,0xdddc0419,0x00000000,0x00000000}},	//   _exju, _posť, --, --, 
   {{0x78a002d0,0xff2400f2,0xab680171,0x00000000}},	//   ghnv, _تبیی, _peļķ, --, 
   {{0x442dca7e,0x32c406b9,0x15dc0150,0x00000000}},	//   _rdf_, zıya_, _ﺇﺭﺍﺩ, --, 
   {{0x2b580407,0x0ddc001f,0x32c41432,0x8cb807b7}},	//   _iprc_, ንጫፍ_, yıya_, ्वको, 
   {{0x6aa0127b,0x7d0c0175,0xfaa05a06,0x7eb81611}},	//   _ilmf, _xtcs, _сато, läpä, 
   {{0xc32c192c,0x628c08cd,0x32c40205,0x00000000}},	//   مەت_, _soao, vıya_, --, 
   {{0x628c0069,0x846c02d3,0xd34403e6,0x7eb8005b}},	//   _poao, እምማን_, نیوه_, näpä, 
   {{0x46e809a5,0x442c017a,0x32c40342,0xa194008e}},	//   _эден_, _wdf_, tıya_, вамч, 
   {{0x442dca7f,0x628c0170,0xa3e405d7,0x7eb8005b}},	//   _tdf_, _voao, पेज_, häpä, 
   {{0x442c055a,0x32c4029f,0x7eb801f4,0x00000000}},	//   _udf_, rıya_, käpä, --, 
   {{0x7ea0007d,0xdfd45a19,0x628c0607,0xbcf801ed}},	//   _lõpe, товы, _toao, _esél, 
   {{0x32c4029f,0xdb0c002e,0x33d8011a,0xe2c80345}},	//   pıya_, ŋkën, _מחוד, _تاتۆ_, 
   {{0x2d581c22,0x00000000,0x00000000,0x00000000}},	// [32fb0] нить_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfba9ca80,0xa3e40709,0x00000000,0x00000000}},	//   чтай_, पेच_, --, --, 
   {{0x3ebc0784,0xc5fc00e2,0xd02400cc,0x00000000}},	//   _ñut_, šējo_, _বায়_, --, 
   {{0x2b580048,0xbd68030d,0xe9b800e5,0x00000000}},	//   _eprc_, _эрне_, ٹنوں_, --, 
   {{0x6aa0009a,0xa3c1b546,0xd7c80133,0xfd1c0ca8}},	//   _elmf, ंपा_, ووشه_, _iwì_, 
   {{0x2bb80491,0x1b04016c,0xa9ac00d1,0x00000000}},	//   _كافة_, _рӯзн, ﻳﮭﯩﺴ, --, 
   {{0xca6401a9,0x00000000,0x00000000,0x00000000}},	//   еmеn, --, --, --, 
   {{0xa8740046,0x0681ca81,0xc68c06f6,0x63a84d9a}},	//   _өлті, ргын, تِي_, ezdn, 
   {{0xd90c6ae0,0x7af80793,0x13082075,0xdb040ba1}},	//   _هیچ_, _hiut, мной_, tzhè, 
   {{0x7af9ca82,0x850401e0,0x00000000,0x00000000}},	//   _kiut, ндөң_, --, --, 
   {{0x7af8768c,0xfd1c01e1,0x5fd4012d,0x00000000}},	//   _jiut, _owì_, _धड़ल, --, 
   {{0x7af801ed,0x672400f3,0xb3d0008e,0x57e00037}},	//   _miut, ćije, _өйдә, _फरुह, 
   {{0x7af9ca83,0xd0100517,0xe7e8012c,0x01601fbe}},	//   _liut, شلر_, टेका_, јкро, 
   {{0x03a002bf,0x43900a5b,0x00000000,0x00000000}},	//   _вищо, _вајс, --, --, 
   {{0x7af9ca84,0x32c40790,0xf4840244,0x00000000}},	//   _niut, mıyo_, _تاچی, --, 
   {{0x8d6400a7,0x32c40790,0x00000000,0x00000000}},	// [32fc0] ъвае, lıyo_, --, --, 
   {{0x7af940f1,0x7c3803f9,0x3b000200,0x7ce8002f}},	//   _aiut, _ɓurg, _bujq_, hürf, 
   {{0x8fa4a97f,0x7af803b4,0xfd1c0cad,0x0b4413f3}},	//   _ране, _biut, _ewì_, тнен, 
   {{0x7af92347,0xba1430bf,0x7eb8081d,0xfa3000d1}},	//   _ciut, نيما_, räpä, لىمج, 
   {{0x7ce80730,0xa954109a,0x7eb8005b,0x7ae00356}},	//   dürf, уклі, säpä, înta, 
   {{0xaca4063f,0x7ae00d27,0x32c40790,0x00000000}},	//   _kpọs, ïntr, kıyo_, --, 
   {{0x7af9ca85,0x7d0400c7,0x8a055de0,0x20cc0139}},	//   _fiut, _térã, _азбе, _uñiş_, 
   {{0x7af9ca86,0x32001bce,0x3ab000d1,0xe6cc1dd1}},	//   _giut, _ngiy_, _кәчт, ावेज, 
   {{0x5ddc0150,0x00000000,0x00000000,0x00000000}},	//   _ﺃﺭﻟﻴ, --, --, --, 
   {{0x3ae40254,0x00000000,0x00000000,0x00000000}},	//   rõpe_, --, --, --, 
   {{0xa2950ee8,0x2905ca87,0xf480026f,0x24540150}},	//   гані, _huma_, руын, _ەنتس, 
   {{0x2905ca88,0x26c002d5,0x325506e4,0x973000f2}},	//   _kuma_, čios_, авюр, _اکوا, 
   {{0x2905ca89,0xe5348fd9,0xaca4acc3,0x9534004b}},	//   _juma_, _сель, _apọs, _مونږ, 
   {{0x2905ca8a,0x7ce88b91,0x21380200,0xdef00023}},	//   _muma_, mürg, rrsh_, ግፈና_, 
   {{0x2904096b,0x7ed401d9,0xb4f80375,0x9f040966}},	//   _luma_, نزرا, _קלור, اورو, 
   {{0x2905ca8b,0xd200014b,0x00000000,0x00000000}},	//   _ouma_, _гӯрк, --, --, 
   {{0x290403b7,0x7af9ca8c,0x00000000,0x00000000}},	// [32fd0] _numa_, _riut, --, --, 
   {{0x7af9ca8d,0xef20025c,0x00000000,0x00000000}},	//   _siut, żżat_, --, --, 
   {{0x7af9ca8e,0x29040b23,0xbcf800e4,0x6d4003cd}},	//   _piut, _auma_, _usém, _åman, 
   {{0x29048c7d,0x673c01f4,0x7ce80166,0x00000000}},	//   _buma_, _ärjy, kürg, --, 
   {{0x7af80268,0x629dca8f,0x32c403e0,0x00000000}},	//   _viut, ikso, zıyo_, --, 
   {{0x2905ca90,0x98e40597,0x6348013f,0xe8f802bf}},	//   _duma_, دكتو, _yɛnt, влі_, 
   {{0x7af9ca91,0x22480365,0x2904003e,0x629c089f}},	//   _tiut, _ocak_, _euma_, kkso, 
   {{0x290407a9,0x629c0d27,0x8a400133,0x26d80055}},	//   _fuma_, jkso, _هێمن, _ūror_, 
   {{0xdcec01a6,0x00000000,0x00000000,0x00000000}},	//   hvač, --, --, --, 
   {{0x2249ca92,0x20000016,0x7ce80793,0x629c01a4}},	//   _acak_, _nghi_, sürf, ekso, 
   {{0x94740502,0xbcf8003e,0x394c05d5,0xdcec00d7}},	//   ندگا, _asék, ltgs_, jvač, 
   {{0x2905ca93,0x20005bd9,0x7ce9ca94,0x32c403e0}},	//   _yuma_, _aghi_, bürg, rıyo_, 
   {{0x2905ca95,0x394c07de,0x8e7401b9,0xdcec00d7}},	//   _xuma_, ntgs_, қувч, evač, 
   {{0x629c5060,0x394c07c5,0x7ce80c3c,0x32c403e0}},	//   ëror, itgs_, nürd, pıyo_, 
   {{0xdb2001e1,0x00000000,0x00000000,0x00000000}},	//   _àtèw, --, --, --, 
   {{0xa3c001ad,0xc7b0011a,0x00000000,0x00000000}},	//   ंपर_, צבן_, --, --, 
   {{0x0d48038b,0x7b10031c,0xc69008a8,0x329401d9}},	// [32fe0] عشري_, _jħuf, זאן_, _مٔژر, 
   {{0x2905ca96,0x753801c4,0x00000000,0x00000000}},	//   _ruma_, iruz, --, --, 
   {{0x2905ca97,0x7ce8574b,0x7538022e,0x5cf400d4}},	//   _suma_, dürd, hruz, ряту, 
   {{0x09483d6c,0xbdd8020c,0x753805a1,0x4fc400c7}},	//   ечки_, _ocèh, kruz, _асҭа, 
   {{0xe985ca98,0x6348016b,0x82d4008f,0x75380cf4}},	//   шқан, _yɛns, נונג_, jruz, 
   {{0x4b242073,0x29043e6e,0x2ee09169,0x7ce80205}},	//   _معرف, _vuma_, llif_, gürd, 
   {{0x2904013f,0x7ce9ca99,0x394c07de,0x629c03b2}},	//   _wuma_, würg, atgs_, ykso, 
   {{0xa5343169,0x2905ca9a,0xb190044e,0xfd64002b}},	//   анич, _tuma_, _ዝጸንሐ_, _aspṛ, 
   {{0x7539ca9b,0x29058df1,0x8834084c,0x9b6400db}},	//   gruz, _uuma_, _бэец, _مەەم_, 
   {{0x63542bbd,0xa3c00c4c,0x04647651,0xdcec00d7}},	//   авоу, ंपल_, утим, yvač, 
   {{0x2ee1ca9c,0x00000000,0x00000000,0x00000000}},	//   klif_, --, --, --, 
   {{0x7538db10,0x7ce902dc,0x60d4012d,0x85440064}},	//   bruz, pürg, wozm, _бэке, 
   {{0x629dca9d,0xc05810f5,0xc5f00050,0x2000003e}},	//   rkso, нів_, _آش_, _pghi_, 
   {{0xdcec07f5,0x40e40133,0x629c007c,0x7d080162}},	//   tvač, اوسێ_, skso, ígsm, 
   {{0x64580099,0x60d43e8f,0x00000000,0x00000000}},	//   _ibvi, rozm, --, --, 
   {{0x1e149ce7,0x6e2000c5,0xdcec02fb,0x2ee1ca9e}},	//   рмая, _õmbl, rvač, glif_, 
   {{0xa3b80574,0x9df813d6,0x7ce80e78,0x6d400fac}},	// [32ff0] _घेत_, тнат_, hüre, _åmal, 
   {{0x7ce8236c,0xac9401ec,0x9ed80150,0x00000000}},	//   küre, бауш, хмұт_, --, 
   {{0x7ae0054e,0x03e00208,0x7ce800a2,0x00000000}},	//   înto, _đuốn, jüre, --, 
   {{0x7ce9ca9f,0xdea00517,0x19b9caa0,0xb3b8010f}},	//   würd, _بیری, куль_, עמאכ, 
   {{0xd825caa1,0x7ce81ae4,0xceb4abba,0x3eb8036e}},	//   адли, türd, _тәр_, miqt_, 
   {{0x7c85caa2,0xbcf9c880,0x75380213,0x2bd00490}},	//   _суме, _oséi, vruz, _तुका, 
   {{0xbcf800e4,0x7ce9caa3,0x394c0c86,0x7e6c012d}},	//   _apég, güre, stgs_, _kacp, 
   {{0x7539caa4,0x6458006f,0xe7080e4a,0x7c2401bf}},	//   truz, _abvi, دتون_, _hejr, 
   {{0x7e6dcaa5,0x784468cf,0xaee400dc,0x67240cf4}},	//   _macp, _مضام, _amṛt, ćija, 
   {{0x7539caa6,0xa5e80184,0x85000014,0x142401f0}},	//   rruz, ылыҡ_, توٝن, шдом, 
   {{0x61e00cc1,0xb9f002d3,0x7c243098,0x91b000cc}},	//   əlli, _ሜላ_, _mejr, _টুংখ, 
   {{0x753808ad,0x7c24037e,0x7e6c0118,0x2ee00327}},	//   pruz, _lejr, _nacp, xlif_, 
   {{0xcad40302,0xbcf800e4,0x00000000,0x00000000}},	//   שורת_, _eséi, --, --, 
   {{0x7c24012c,0x7e6c02d0,0x0440074d,0x2ee00142}},	//   _nejr, _aacp, _дешн, wlif_, 
   {{0xbcf80122,0x60c8002e,0x7ce803b9,0x00000000}},	//   _fréz, éema, kürb, --, 
   {{0x0e64033a,0x00000000,0x00000000,0x00000000}},	//   јкан, --, --, --, 
  
   {{0xcbe00d42,0x4c15c4a1,0xbea006a6,0x272c01e1}},	// [33000] _বলেছ, لباس, цатк, _kóná_, 
   {{0xc0c4021a,0xbcf8007f,0x272c0248,0xf4800023}},	//   _نېټه_, _kréy, _jóná_, _ክወሃብ_, 
   {{0x7c240477,0xef9417a5,0x2ee00356,0x7ce803e0}},	//   _dejr, _ایزد, plif_, fürb, 
   {{0x7ce8014a,0x4354010f,0x09280472,0x32c40139}},	//   vüre, יסעל_, نستي_, dıyk_, 
   {{0x7c2404ce,0xfe3405d0,0x00000000,0x00000000}},	//   _fejr, _דרכי_, --, --, 
   {{0x7c240098,0xddcc0311,0x7ce9b92c,0x6d45caa7}},	//   _gejr, leaş, türe, muia, 
   {{0x47840228,0x6d45274e,0x46a5caa8,0xf7240006}},	//   рылб, luia, ишиб, ацый_, 
   {{0x6d45caa9,0xddcc0356,0xc6240154,0x7f3800df}},	//   ouia, neaş, _যাহা_, דעקו, 
   {{0x6d44096b,0xaee40a28,0xf8ac01ed,0x26c403cd}},	//   nuia, _smṛt, سکے_, rnmo_, 
   {{0x6d440421,0x7ce9caaa,0x7d540a1e,0x63bc00d0}},	//   iuia, püre, סייד_, úrno, 
   {{0x7b10031c,0xbcf96059,0x6d44b26d,0x64640427}},	//   _għud, _préz, huia, _črič, 
   {{0x48dc012c,0x77b8011a,0xf798011a,0x00000000}},	//   गतको_, _במבח, _שבאמ, --, 
   {{0xbcf8035b,0x6d440194,0x2459caab,0x00000000}},	//   _isév, juia, _баль_, --, 
   {{0x61ec04fb,0x64580099,0xbdd801e1,0x6d44054e}},	//   _ıllı, _ubvi, _gbèy, duia, 
   {{0x7e6c0115,0x64480175,0x79340240,0x00000000}},	//   _pacp, mgdi, _ኣይትድ, --, 
   {{0x7c25caac,0x6d45caad,0x00000000,0x00000000}},	//   _sejr, fuia, --, --, 
   {{0x7c240477,0xbc042d29,0xd7f00051,0x61e80254}},	// [33010] _pejr, ачей, _dãy_, üeld, 
   {{0x6449caae,0xad2404da,0x00000000,0x00000000}},	//   ngdi, تىكى, --, --, 
   {{0x7c2404ce,0x64488b14,0xbcf800e4,0x38a803b2}},	//   _vejr, igdi, _osév, _hørg_, 
   {{0xdd9022f3,0x6d45caaf,0x7ce803fa,0x645c022e}},	//   _فوج_, buia, fürc, еrik, 
   {{0x7c240209,0x6d440276,0x7ce80790,0x00000000}},	//   _tejr, cuia, gürc, --, 
   {{0xbcf800e4,0x7b15cab0,0xdbf001ef,0x00000000}},	//   _asév, _نظرئ, _hřím, --, 
   {{0xf771cab1,0xccf00375,0x94740116,0x00000000}},	//   تاش_, _מכך_, ەدجا, --, 
   {{0xead4cadc,0x9ff8015b,0x6d580165,0x00000000}},	//   _дось, _অভাব_, ńvae, --, 
   {{0xf8480276,0x00000000,0x00000000,0x00000000}},	//   _ачей_, --, --, --, 
   {{0xbcf800c7,0x79880369,0x4d78008f,0xd4680063}},	//   _esév, mxgw, אָטא, ћине_, 
   {{0x4ddc02f8,0xc62403f4,0x6d45cab2,0xdee40b82}},	//   _कुनै_, _যারা_, zuia, ማምን_, 
   {{0x7c3803f9,0x644827bb,0x00000000,0x00000000}},	//   _ɓura, agdi, --, --, 
   {{0xc68c01d9,0x6d440165,0x490800cd,0x00000000}},	//   _سِو_, xuia, ादयो_, --, 
   {{0x395c020c,0x6d44030a,0x8fd00139,0x1bf80118}},	//   _mpus_, vuia, зәмә, ्खाल_, 
   {{0x127c0023,0x3cbc03d4,0x00000000,0x00000000}},	//   እኽኻብ_, ্তাৱ, --, --, 
   {{0x395dcab3,0x6d45cab4,0xa3cc0037,0x00000000}},	//   _opus_, tuia, _रखत_, --, 
   {{0x395c0218,0x504400ee,0xddcc0356,0xdbf001ef}},	// [33020] _npus_, _лепб, reaş, _dřím, 
   {{0xbcf801e1,0x6d45cab5,0x38a803b2,0x00000000}},	//   _apéb, ruia, _jørd_, --, 
   {{0x395dcab6,0x6d45cab7,0xdb200248,0x00000000}},	//   _apus_, suia, _àtìw, --, 
   {{0x6d4554d2,0xc5f0015b,0x28bc00cd,0x7ce80205}},	//   puia, ছুটা_, ्चभि, türc, 
   {{0x6d45cab8,0x644938fb,0x395dcab9,0xa8180451}},	//   quia, ygdi, _cpus_, لڪار_, 
   {{0x28f9caba,0x7ea000af,0x38a800b5,0xf76c00f1}},	//   шель_, _lõpl, _nørd_, ځاي_, 
   {{0x644800b5,0xbb40010a,0xf76c06c2,0x00000000}},	//   vgdi, _нерк, فاي_, --, 
   {{0x2d8406af,0xf1c80da5,0x7ce9cabb,0xe698011c}},	//   _àmes_, रपान, müra, рвиш_, 
   {{0xf514932b,0x00000000,0x00000000,0x00000000}},	//   یتیش_, --, --, --, 
   {{0xa7fc0205,0x00000000,0x00000000,0x00000000}},	//   _daır, --, --, --, 
   {{0x38a820e4,0x6449cabc,0x8574132f,0x00000000}},	//   _sørg_, rgdi, _گدائ, --, 
   {{0x217801e0,0xbcf80022,0x96b9cabd,0x75d005af}},	//   аймы_, _usév, _кучу_, _کيها, 
   {{0x6594085f,0x38a852fd,0x7ce967e5,0xa3b81414}},	//   _фалу, _førd_, hüra, _घेर_, 
   {{0x224dcabe,0x27e000bc,0x998c013a,0xf534011a}},	//   żek_, řinu_, _jdeš_, _פנוי_, 
   {{0xdbf00316,0xa2941ae2,0x2294010b,0x733000ec}},	//   _přím, _макі, _микя, _فريئ, 
   {{0x7ce805d5,0xdc202ca5,0x00000000,0x00000000}},	//   düra, यर्ड_, --, --, 
   {{0x38a817c1,0xdcb88e9e,0x998c05ce,0x6e940261}},	// [33030] _høre_, агач_, _odeš_, читу, 
   {{0x61edcabf,0x38a8019b,0xa3cc068f,0xad241b56}},	//   _izal, _køre_, _रखा_, سىمى, 
   {{0x395c00a8,0x7ce9479c,0x31600219,0x7b100003}},	//   _spus_, güra, _zpiz_, _sħub, 
   {{0x38a83b4c,0xbcf80c6a,0xba280eff,0xddcc010f}},	//   _møre_, _asét, اسام_, ldaŭ, 
   {{0x79880369,0xafc40150,0x1988010b,0x00000000}},	//   uxgw, _ويۋى, рбли_, --, 
   {{0x61edcac0,0xddcc01e4,0x00000000,0x00000000}},	//   _mzal, ndaŭ, --, --, 
   {{0xb8c40032,0x38a803b2,0x7ea00037,0x782400db}},	//   аҫҡа_, _rørd_, _lõpm, _ۇعال, 
   {{0x61edcac1,0x2bc80120,0x04200154,0x9aa400ae}},	//   _ozal, _ѓуро_, _মাগী_, _بمرو, 
   {{0x61ecd735,0xf9900597,0x2aa97103,0x18a401e0}},	//   _nzal, _عبر_, _утро_, _һаҡм, 
   {{0x499001d9,0xb72801ee,0x00000000,0x00000000}},	//   _تیٖر, _бюдж_, --, --, 
   {{0x61edcac2,0x00000000,0x00000000,0x00000000}},	//   _azal, --, --, --, 
   {{0x61ec02ea,0x38a8037e,0x38640fac,0xe730007b}},	//   _bzal, _døre_, lenr_, _أصل_, 
   {{0xe4c80236,0x00000000,0x00000000,0x00000000}},	//   شبین_, --, --, --, 
   {{0x61edcac3,0x38a82759,0x386400fe,0x683401d3}},	//   _dzal, _føre_, nenr_, _tüdő, 
   {{0x38a8105c,0x61ed323b,0xa92800d7,0x09c400cd}},	//   _gøre_, _ezal, _kožú, _वश्य, 
   {{0x6f1c05be,0x91800e56,0x741002f2,0x00000000}},	//   rprc, _قۇجۇ, _بوژا, --, 
   {{0x85f400c8,0x61ec0166,0xbe3000db,0x00000000}},	// [33040] ַמעס_, _gzal, بىقب, --, 
   {{0x7ce864aa,0x9aa800d1,0x904450d8,0x00000000}},	//   türa, ەچكە_, _بنده, --, 
   {{0xbcf9cac4,0x8b69cac5,0x7ff5cac6,0x00000000}},	//   _spéc, риев_, _وسپا, --, 
   {{0x61ec00a2,0x00000000,0x00000000,0x00000000}},	//   _yzal, --, --, --, 
   {{0x7ce9cac7,0xdcac00db,0xbcf800e5,0x00000000}},	//   süra, _ڭۉل_, _csés, --, 
   {{0x2d54007d,0x48b80183,0xdb4c0133,0x7ce80254}},	//   mäe_, েত্ৰ, _ڕێم_, püra, 
   {{0x2d540139,0x00000000,0x00000000,0x00000000}},	//   läe_, --, --, --, 
   {{0x38a82d75,0x00000000,0x00000000,0x00000000}},	//   _røre_, --, --, --, 
   {{0x38a82dba,0xbcf8e3f6,0xdddc013d,0x2d54000d}},	//   _søre_, _isér, _masş, näe_, 
   {{0xc32c3baf,0x61edcac8,0xddcc0311,0x7f440113}},	//   نەت_, _rzal, ldaţ, yujq, 
   {{0x61ec1b7a,0xddcc00df,0x09d400eb,0x00000000}},	//   _szal, vdaŭ, তেখা, --, 
   {{0xddcc0276,0x2d55549f,0xe3b80205,0x00000000}},	//   ndaţ, käe_, bbın_, --, 
   {{0x2258000f,0xddcc01e4,0x7ae00356,0x7ce800a2}},	//   rfsk_, tdaŭ, înti, dürn, 
   {{0x61ec0122,0x00000000,0x00000000,0x00000000}},	//   _vzal, --, --, --, 
   {{0x33240369,0xddcc0115,0x91c0013d,0xe2f80024}},	//   _gwnx_, rdaŭ, _җәял, _лекі_, 
   {{0xf2c4005e,0x9d15cac9,0x61ec0036,0xd01801f0}},	//   _осын, здач, _tzal, ифӣ_, 
   {{0x71240228,0x7f440477,0xc0584f32,0xe86c0092}},	// [33050] _قىيم, sujq, _кін_, ሰበሰቡ_, 
   {{0x21280098,0xbcf80332,0x00000000,0x00000000}},	//   _iwah_, _bpéa, --, --, 
   {{0x9b581c3c,0x7f44014f,0x00000000,0x00000000}},	//   сиет_, qujq, --, --, 
   {{0x21280652,0xe3b80205,0x00000000,0x00000000}},	//   _kwah_, ybın_, --, --, 
   {{0xa92400d6,0xbdd8020c,0x67280003,0xf96801b9}},	//   дділ, _ecèr, _awdj, ррей_, 
   {{0x2129caca,0x7ce800a2,0x00000000,0x00000000}},	//   _mwah_, müro, --, --, 
   {{0x38644e9b,0xe9d00131,0xdb200241,0x00000000}},	//   renr_, ىغۇ_, _àtàw, --, 
   {{0x2128034c,0x00000000,0x00000000,0x00000000}},	//   _owah_, --, --, --, 
   {{0x386405ac,0x65f8009d,0x00000000,0x00000000}},	//   penr_, жээр_, --, --, 
   {{0x7ce80086,0x344400b8,0x00000000,0x00000000}},	//   zürn, _śaṇḍ, --, --, 
   {{0x64980801,0x00000000,0x00000000,0x00000000}},	//   ютър_, --, --, --, 
   {{0x93880124,0xe3b80205,0x7ce80bb9,0x6fbc00cd}},	//   асҭа_, mbıl_, küro, ोपसं, 
   {{0x76582747,0xdddc0139,0x83500244,0x942401ec}},	//   mfuy, _rasş, وپیا, _емле, 
   {{0x2d5400af,0xce4802dd,0xfba81c15,0xdb04002f}},	//   väe_, өзге_, चनाम, lzhä, 
   {{0x21293c64,0xa3b80490,0x53a401fe,0x00000000}},	//   _ewah_, _घेऊ_, _хайб, --, 
   {{0x5275cacb,0x32c4013d,0x8e080798,0x00000000}},	//   _хуку, gıyt_, снав_, --, 
   {{0xdb0c0030,0xbcf800ae,0xc0d40023,0xa2c000bc}},	// [33060] ľkým, _spéa, ሪሮም_, _लगत्, 
   {{0x3ea8009f,0xd6d02b1b,0xdb0c0306,0x6d4800cd}},	//   _elct_, াতিয, žkým, _ādad, 
   {{0xeb3400f7,0x2d5401f4,0x7ce8bd89,0x00000000}},	//   بۉزد, säe_, mürl, --, 
   {{0x7ce9cacc,0x691c0790,0x00000000,0x00000000}},	//   büro, hçeş, --, --, 
   {{0x6e242252,0x48e425f2,0x5aa80451,0xddcc054e}},	//   mbib, подв, غامَ_, rdaţ, 
   {{0x6e25cacd,0x7ce8029f,0xa3cc00af,0xec340214}},	//   lbib, nürl, _रखल_, _زورگ, 
   {{0x38c82172,0xeb5412b7,0xbcf80124,0xd5ac01d3}},	//   حانی_, _تىزگ, _upéa, یہم_, 
   {{0x6e25cace,0x6d45cacf,0x7ce8274a,0xbb38011a}},	//   nbib, oria, hürl, _לעלי, 
   {{0x6d44e799,0xbcf80085,0x7ce9cad0,0x00000000}},	//   nria, _mpén, kürl, --, 
   {{0x6d45cad1,0x691c03ee,0xa7fc0166,0xa3b80490}},	//   iria, rçeğ, _abıe, _घेउ_, 
   {{0x7ce845e3,0x6d45cad2,0xe2f94012,0x03c40116}},	//   dürl, hria, жені_, ясим, 
   {{0x6d45cad3,0x21280c6a,0x28bc00dc,0x65b00133}},	//   kria, _pwah_, ्चवि, _لیبڕ, 
   {{0xc5080597,0x38a80158,0x27e00311,0x6e2412e8}},	//   _اتصل_, _høra_, şind_, dbib, 
   {{0x6d45cad4,0x7ce803ee,0xbcf8ee9c,0x6e25cad5}},	//   dria, gürl, _apén, ebib, 
   {{0x6d45cad6,0x442d09c3,0xbea400db,0x00000000}},	//   eria, _ief_, пшай, --, 
   {{0x442c00fc,0x6e25cad7,0x21294572,0x99e4010e}},	//   _hef_, gbib, _twah_, _heňň, 
   {{0xa11402af,0x5c9811db,0x6d45cad8,0x2128020c}},	// [33070] _توخت, окая_, gria, _uwah_, 
   {{0xddcc0841,0x99e4010e,0xa2c400cd,0xff0400c0}},	//   gdaš, _jeňň, ाचक्, _нямн, 
   {{0xdcec071b,0x6d45cad9,0x6e240a49,0x442c0334}},	//   hvać, aria, bbib, _mef_, 
   {{0x442dcada,0x1a6404d3,0x3f5400ac,0x6e240009}},	//   _lef_, بیری_, mçu_, cbib, 
   {{0x6d45cadb,0x442dcadc,0x3f5400ac,0x323808d8}},	//   cria, _oef_, lçu_, לטאן_, 
   {{0x38a80158,0xf810036b,0xe9d80006,0xac940240}},	//   _børa_, رستگ, чкі_, _መሊሶም_, 
   {{0x3f55cadd,0x220402b5,0x7d0c0076,0x7ce82791}},	//   nçu_, _hīhī_, _hucs, nürm, 
   {{0x442cd9df,0xaa5815ed,0x7d05cade,0x38a8168c}},	//   _aef_, _нису_, _hijs, _døra_, 
   {{0x442dcadf,0x7ce8b1e1,0x7ae0054e,0x19580eed}},	//   _bef_, hürm, întu, _фазы_, 
   {{0x38a943ae,0x6e24110c,0x3f54e2ff,0x935873da}},	//   _føra_, zbib, kçu_, орму_, 
   {{0x442c1105,0x7658252e,0x7d0ce048,0xe3b8294f}},	//   _def_, pfuy, _lucs, bbım_, 
   {{0x7ce9cae0,0x7d05cae1,0x442c0a55,0x6d45cae2}},	//   dürm, _lijs, _eef_, yria, 
   {{0x7ce9cae3,0x442dcae4,0x27e00365,0x7d0c054e}},	//   türl, _fef_, ğine_, _nucs, 
   {{0x7d040a85,0x27e1cae5,0x442dcae6,0x6d45cae7}},	//   _nijs, şine_, _gef_, vria, 
   {{0x6e25cae8,0x7ce806b9,0x6d440368,0x7b10025c}},	//   tbib, rürl, wria, _sħun, 
   {{0x6d45cae9,0x7d0c2198,0x442dcaea,0x99e4010b}},	//   tria, _bucs, _zef_, _zeňň, 
   {{0x6d45caeb,0x7d040cf9,0x6e243a52,0x3f55caec}},	// [33080] uria, _bijs, rbib, açu_, 
   {{0x6e25caed,0x10a400a8,0x6d45807b,0x442c00cf}},	//   sbib, _цион, rria, _xef_, 
   {{0xbdd80066,0xddcc65c4,0x7d05caee,0xdcec009b}},	//   _adèd, rdaš, _dijs, zvać, 
   {{0x7d0dcaef,0x38a9caf0,0x7d04282c,0xb3b40327}},	//   _fucs, _røra_, _eijs, _བཟླུ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7d05caf1,0x00000000,0x00000000,0x00000000}},	//   _gijs, --, --, --, 
   {{0xfc01caf2,0x7f540076,0x00000000,0x00000000}},	//   _апро, _xqxq, --, --, 
   {{0x442dcaf3,0x7d0409b6,0x38a80174,0x99e4010e}},	//   _sef_, _zijs, _vøra_, _seňň, 
   {{0x809c0073,0x26d800e5,0x7ce80432,0x00000000}},	//   _ऐकले, _írom_, dürj, --, 
   {{0x442dcaf4,0xdcec01a6,0x32c40139,0x00000000}},	//   _qef_, rvać, dıyq_, --, 
   {{0x442dcaf5,0xbdd80ba1,0x6348016b,0x867800c0}},	//   _vef_, _idèe, _yɛny, _мёду_, 
   {{0x442c07c5,0xd6d802dd,0xf62800db,0xdebc069d}},	//   _wef_, _еті_, _ۇتۇۇ_, ተቱን_, 
   {{0xa30800f8,0x26c5caf6,0x442dcaf7,0x99e4010b}},	//   _کرتے_, mimo_, _tef_, _teňň, 
   {{0x26c5caf8,0x7ce9caf9,0x25b00ba5,0x7d0c0276}},	//   limo_, türm, ıllı_, _rucs, 
   {{0x7d05cafa,0x6d580165,0xf7d407d2,0x00000000}},	//   _rijs, ńval, _ﭘﺎﻟﻪ, --, 
   {{0x26c5cafb,0x3f55cafc,0x816814a4,0x7d040007}},	//   nimo_, rçu_, _дроб_, _sijs, 
   {{0x9b94182f,0xb3080135,0x2d591f12,0x7d040240}},	// [33090] کلات, _གཤོང_, мить_, _pijs, 
   {{0x26c4c267,0x22940ec9,0x3f540342,0x7ce9cafd}},	//   himo_, _آلکس, pçu_, mürk, 
   {{0x38a9cafe,0x26c402d5,0x7d040218,0x67381710}},	//   _børn_, kimo_, _vijs, jsvj, 
   {{0x26c5caff,0x7d0dcb00,0xdd940323,0x7d05cb01}},	//   jimo_, _tucs, _замы, _wijs, 
   {{0x26c499df,0x7d05cb02,0x7ce80790,0xd944014b}},	//   dimo_, _tijs, nürk, хели, 
   {{0x7b6406bf,0xec6804b4,0x7d0402d0,0xa3c05843}},	//   _отбе, _орск_, _uijs, ूपा_, 
   {{0x26c40393,0x6d40143a,0x2bc8009b,0x32c40166}},	//   fimo_, _åmar, _жуто_, kıyp_, 
   {{0xbcf800d2,0x26c40006,0x38a803b2,0x559400f0}},	//   _mpém, gimo_, _gørn_, ејоф, 
   {{0x3a3c3223,0x7ce80254,0x61e803e0,0x00000000}},	//   _idup_, jürk, üell, --, 
   {{0x3a3c0a2e,0x34a0013e,0x00000000,0x00000000}},	//   _hdup_, тгоҳ, --, --, 
   {{0x26c5cb03,0x3a3c0649,0x13e802f6,0x53a46ecf}},	//   bimo_, _kdup_, ямой_, ханб, 
   {{0xbcf806af,0x7b10025c,0x7ea00254,0x358001f0}},	//   _spél, _rħul, _kõpu, _ақиб, 
   {{0xd0080046,0xfd1c0248,0xdcec025c,0x7ae80332}},	//   зеге_, _ntì_, gwaċ, ilgt, 
   {{0x9f5c0241,0x00000000,0x00000000,0x00000000}},	//   _ńwá_, --, --, --, 
   {{0x645dcb04,0x7ea0033d,0xb4c80574,0x3ae40037}},	//   òrie, _lõpu, रची_, lõpu_, 
   {{0x0d2000f7,0xc001cb05,0x3264035b,0x00000000}},	//   лүмү, упск, _реиҳ, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [330a0] --, --, --, --, 
   {{0x26c40117,0x00000000,0x00000000,0x00000000}},	//   zimo_, --, --, --, 
   {{0x26c406e4,0x4a441b0a,0x1fb4373e,0x205401af}},	//   yimo_, енев, _асяр, _ртыр, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x26c5cb06,0x00000000,0x00000000,0x00000000}},	//   vimo_, --, --, --, 
   {{0x5d1004a9,0x7ae00311,0x26c5cb07,0xe8bc0073}},	//   _ئېلا, într, wimo_, ्चेच, 
   {{0x3a3c0166,0x38a80162,0x26d801d3,0xc6a401f4}},	//   _fdup_, _tørn_, _írok_, ерпи, 
   {{0x2d80011c,0x3870016b,0x38a80162,0xc8c80101}},	//   ovie_, _ɔbrɛ_, _føro_, _کوئن_, 
   {{0x26c5cb08,0xd5100116,0x00000000,0x00000000}},	//   rimo_, لېند, --, --, 
   {{0x2d8006af,0x35f001ec,0x00000000,0x00000000}},	//   ivie_, ыпыр, --, --, 
   {{0xa3d4117e,0xf740059f,0x2d8000d7,0x00000000}},	//   тонч, _бехо, hvie_, --, 
   {{0x7ce8d95c,0x2d81cb09,0x00000000,0x00000000}},	//   türk, kvie_, --, --, 
   {{0x24591e3c,0x2a6405b1,0x64746135,0x2d8001a4}},	//   _жаль_, _mbmb_, _аглу, jvie_, 
   {{0x7ce80790,0x2d81cb0a,0x35f00111,0x0a140154}},	//   rürk, dvie_, _спір, ারিং_, 
   {{0x2005cb0b,0x30a40801,0x00000000,0x00000000}},	//   äli_, уряв, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfd11cb0c,0x628c05d9,0xa3e4146c,0x3a3c0139}},	// [330b0] اجر_, _inao, _भुत_, _rdup_, 
   {{0x3a3c0618,0x6c540228,0x00000000,0x00000000}},	//   _sdup_, лкуу, --, --, 
   {{0xbfa801d9,0xd954037e,0xbcf80124,0xe3b80205}},	//   _رادٕ_, _sが_, _upém, nzı_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x628dcb0d,0x2d8001ab,0xa3b8000d,0x7ce9cb0e}},	//   _mnao, cvie_, _घेघ_, hüri, 
   {{0xddcc00b0,0x7ce87bbc,0x00000000,0x00000000}},	//   ngaō, küri, --, --, 
   {{0x628c166a,0xdb0400e4,0x00000000,0x00000000}},	//   _onao, nyhë, --, --, 
   {{0x7ce80209,0xa784315b,0xaa94030d,0xbcf8013a}},	//   düri, اشوو, _йисч, _opék, 
   {{0x38a803b2,0x00000000,0x00000000,0x00000000}},	//   _hørm_, --, --, --, 
   {{0x27e04ad0,0xb4c80490,0xbb6400b5,0x536c010c}},	//   şina_, रचे_, _getツ_, _ሶቭየት_, 
   {{0x394cf985,0x2d800419,0x7ce800a2,0x8c1808c3}},	//   lugs_, zvie_, güri, וותי, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x645d1e55,0x3568005b,0x11d40395,0xc240117e}},	//   òric, _хрен_, тюня, шняк, 
   {{0x628d1e03,0x2d81cb0f,0x7539b302,0x7ce8000d}},	//   _enao, vvie_, msuz, büri, 
   {{0xb3080156,0x628c0109,0x20cc05be,0x7539cb10}},	//   _གཤིང_, _fnao, džid_, lsuz, 
   {{0xfe41cb11,0xd184a229,0x628c01e7,0x2d800419}},	//   инсо, _алий, _gnao, tvie_, 
   {{0x75384890,0x7c340175,0x00000000,0x00000000}},	// [330c0] nsuz, faxr, --, --, 
   {{0x2d81cb12,0x60c800e8,0xa9c40150,0x0134011a}},	//   rvie_, éemt, _ﯨﺮﯨﺴ, _שרית_, 
   {{0xa7fc0139,0x75380205,0x00000000,0x00000000}},	//   _abın, hsuz, --, --, 
   {{0xbb41cb13,0x49c828e8,0x00000000,0x00000000}},	//   рецк, млен_, --, --, 
   {{0xfaa00120,0xe7300133,0xe3b80205,0x00000000}},	//   јачо, ڵڵا_, zzı_, --, 
   {{0x8c4402dd,0x67d5cb14,0x0ba81e4a,0xf86000d4}},	//   _шеге, лолу, _قازى_, ивчо, 
   {{0xf76c0447,0xbdd8180f,0x394c03ef,0x00000000}},	//   قاي_, _idèa, augs_, --, 
   {{0xfaa1cb15,0x394c04cc,0x7d18056a,0x7ce80e78}},	//   _касо, bugs_, _éusc, fürw, 
   {{0x0905cb16,0x628d0d90,0xfaa0e9fa,0xba146ea9}},	//   _апан, _rnao, _тато, _شيلا_, 
   {{0x6aa1cb17,0x07a400c7,0x7ce9b926,0x628c4230}},	//   _homf, _иазн, türi, _snao, 
   {{0x290d74f3,0x6234f258,0xbcf800d5,0x753804ba}},	//   _iida_, лену, _spék, asuz, 
   {{0x290c0455,0xe3b805d1,0xbb38008f,0x490800bc}},	//   _hida_, rzı_, ועטי, ादको_, 
   {{0x290dcb18,0x6aa0016b,0xc05802bf,0x7ce9cb19}},	//   _kida_, _momf, мів_, süri, 
   {{0x290dcb1a,0x6aa02747,0x628c009f,0x00000000}},	//   _jida_, _lomf, _wnao, --, 
   {{0x290dcb1b,0xf484571d,0x394c0112,0x6aa002d0}},	//   _mida_, _جانی, zugs_, _oomf, 
   {{0x290dcb1c,0x628c00b2,0x6aa00912,0x6f1801ef}},	//   _lida_, _unao, _nomf, _žací, 
   {{0x290c0998,0x63a8007c,0x00000000,0x00000000}},	// [330d0] _oida_, lydn, --, --, 
   {{0x290dcb1d,0x61edcb1e,0x207402d5,0x00000000}},	//   _nida_, _iyal, _слоў, --, 
   {{0x6aa00fec,0x1084013d,0x00000000,0x00000000}},	//   _bomf, _сөяк_, --, --, 
   {{0x290c05b8,0x61edcb1f,0x60c4014f,0x5a35cb20}},	//   _aida_, _kyal, _hmhm, ундт, 
   {{0x290dcb21,0x3c90030f,0x6aa003cd,0x64580427}},	//   _bida_, _پیاز, _domf, _ocvi, 
   {{0x61ec4005,0x290c01d9,0x63a800b5,0xdeb002dd}},	//   _myal, _cida_, kydn, _тұғы, 
   {{0xf09405e1,0x290c7dcc,0x60c40fec,0x61edcb22}},	//   ינס_, _dida_, _mmhm, _lyal, 
   {{0x7539cb23,0x61edcb24,0x290c05d5,0x79a40124}},	//   tsuz, _oyal, _eida_, _ирзе, 
   {{0x290dcb25,0x7af9cb26,0x60c40455,0x52740075}},	//   _fida_, _ihut, _omhm, қуну, 
   {{0x290dcb27,0x6458003a,0x6aa04b2a,0xa3c000dc}},	//   _gida_, _ccvi, _zomf, ूपं_, 
   {{0x61ec6f88,0x6aa01cdf,0x645c7b0c,0x753815b7}},	//   _ayal, _yomf, òria, ssuz, 
   {{0x290dcb28,0x61edcb29,0xf77004d3,0x92b4007b}},	//   _zida_, _byal, _ماڵ_, احدا, 
   {{0x61ec0223,0x20cc0b4b,0x7af9cb2a,0x290c358d}},	//   _cyal, džib_, _mhut, _yida_, 
   {{0xdddc068f,0x61ec5079,0x8f741cb8,0xd01007d6}},	//   _obsł, _dyal, лубі, صلر_, 
   {{0x61edcb2b,0x7af9cb2c,0x2b1803e5,0x637800ee}},	//   _eyal, _ohut, _बंधु_, _асыр_, 
   {{0x7ea0007d,0x7af9cb2d,0x9e700023,0x00000000}},	//   _sõpr, _nhut, _ብጽሞና_, --, 
   {{0x61edcb2e,0x0d84c8af,0x6aa0168c,0xde340006}},	// [330e0] _gyal, ылан, _romf, рэсь, 
   {{0x6aa1cb2f,0x7af9cb30,0x6459cb31,0x25a001c3}},	//   _somf, _ahut, _xcvi, _àile_, 
   {{0x290dcb32,0x0a690934,0x8fa5cb33,0x0b440212}},	//   _rida_, ерли_, _сане, унен, 
   {{0x290dcb34,0xbdd800cf,0xfd1c0241,0x8e740063}},	//   _sida_, _idèn, _irìn_, _суоч, 
   {{0x290dcb35,0x7af934ba,0x7ea00254,0x920400b8}},	//   _pida_, _dhut, _tõpr, bdāś, 
   {{0x7af8b2e6,0x290cffd4,0xf9841b4d,0x6aa1cb36}},	//   _ehut, _qida_, انوي_, _womf, 
   {{0x69dc068f,0x7ce806be,0x00000000,0x00000000}},	//   _śred, güru, --, --, 
   {{0x7af81552,0x29180374,0x290c0477,0xa614222a}},	//   _ghut, _ōrau_, _wida_, шмич, 
   {{0x290c0183,0xbcf9bd1f,0x27ec0142,0x19c0008e}},	//   _tida_, _spéi, _wydn_, _мәшг, 
   {{0x63a895a0,0x7ea0007d,0x61edcb37,0xf4d40228}},	//   tydn, _lõpp, _ryal, лмыш_, 
   {{0x61ec0a2e,0xf48002dd,0x8724005b,0xfd1c01e1}},	//   _syal, суын, _смеж, _nrìn_, 
   {{0x63a800b5,0x61ec0055,0x00000000,0x00000000}},	//   rydn, _pyal, --, --, 
   {{0xbcf80022,0x61ec0083,0x63a9cb38,0xe53400f5}},	//   _ipév, _qyal, sydn, _тель, 
   {{0x35400014,0xdee4010c,0x82a401ec,0x61edcb39}},	//   _انوٲ, ዛዝን_, _әшке, _vyal, 
   {{0xbcf80124,0x9f340212,0x656001e7,0x00000000}},	//   _upéi, ребі, ltmh, --, 
   {{0x61ec00f1,0x3f84032e,0x00000000,0x00000000}},	//   _tyal, _ánum_, --, --, 
   {{0x99dc0f91,0xdef80083,0x7af9cb3a,0x7ce82093}},	// [330f0] _odňa, ŋŋo_, _rhut, kürt, 
   {{0x80d000bd,0x27e0012c,0x629c01e3,0x00000000}},	//   _দীর্, řiny_, ljso, --, 
   {{0x7af88f71,0x5f958cb1,0xda1406ed,0x38bc0022}},	//   _phut, _тинт, адењ, hãrõ_, 
   {{0x8f9825f9,0x7af8014b,0x629c0369,0x1dc4070e}},	//   _סירי, _qhut, njso, _көзн, 
   {{0x7af81aa1,0xdddc0055,0x3d1c00cc,0x00000000}},	//   _vhut, _masū, _পিক্_, --, 
   {{0x7af8d588,0xe8f80006,0x7ce80112,0x1868003b}},	//   _whut, глі_, gürt, таки_, 
   {{0x7af86bf9,0x65c800b0,0xab8448a9,0xa7fc0139}},	//   _thut, hīhī, _лутк, _ubıl, 
   {{0x7af800ca,0xdddc00b8,0x00000000,0x00000000}},	//   _uhut, _nasū, --, --, 
   {{0xfe7ca573,0x7ce80112,0x3444010b,0x00000000}},	//   _maï_, bürt, гүли_, --, 
   {{0x54c407a5,0xd4680063,0x7ce85c19,0xf3f40241}},	//   рбоб, њине_, mürs, _ẹ̀ka_, 
   {{0xc5e404c5,0x7ce81432,0xd3949735,0x6d480171}},	//   খেলা_, lürs, рәлә_, _ādam, 
   {{0xe61002f2,0x00000000,0x00000000,0x00000000}},	//   _فشه_, --, --, --, 
   {{0x7ce83535,0x74040154,0xf5e80248,0x00000000}},	//   nürs, োরেট_, bẹẹ_, --, 
   {{0xe700002b,0x60c80129,0x412401f0,0xfde0000d}},	//   _iṣṭi_, éemp, роро_, _कुइस_, 
   {{0x2d84035b,0xefbc0240,0x00000000,0x00000000}},	//   _ũme_, _ሰልዲ_, --, --, 
   {{0x38a80158,0x69dc016b,0x0b9401d5,0x7ce82791}},	//   _døri_, _ɛreb, یجاد, kürs, 
   {{0x395c0211,0xccc4e2b0,0x8e0800d8,0xbe3019c5}},	// [33100] _nqus_, абай, тнав_, زىلب, 
   {{0x8c45cb3b,0x38a8022c,0xddcc0356,0x7ce94398}},	//   реже, _føri_, sfaş, dürs, 
   {{0x395c0113,0xca7401c0,0x8f741cb8,0x5cf4010a}},	//   _aqus_, иуды, _тупі, сяту, 
   {{0x1fb4593a,0x7ce8002f,0x00000000,0x00000000}},	//   _ысыр, fürs, --, --, 
   {{0x6f040a55,0x2d8439b2,0x82d404ae,0x7ce803e0}},	//   mmic, _éme_, סונג_, gürs, 
   {{0x6f05cb3c,0x613c03b2,0x0744022e,0x32c4013d}},	//   lmic, _hælá, ахим, gıyz_, 
   {{0xd90c26f0,0x2769cb3d,0xd76400f2,0x9f5c01e1}},	//   ریم_, اشتی_, منوی, _ńwú_, 
   {{0x6f05cb3e,0x2f1c00dd,0xa53402bf,0x7ce80e78}},	//   nmic, _míg_, бнич, bürs, 
   {{0xbdd80066,0x6f04078c,0x2f1c0419,0x7ce885e1}},	//   _ndèl, imic, _líg_, pürt, 
   {{0x6f0402d0,0x65603e79,0xdddc07d7,0x38bc035b}},	//   hmic, rtmh, _sasū, rãrõ_, 
   {{0x6f0404b9,0xdddc00da,0xbdd82a78,0x589489d2}},	//   kmic, _pasū, _adèl, _ушту, 
   {{0x20cc02d5,0x6f041050,0xbcf80588,0x058400f3}},	//   džia_, jmic, _upév, _вукм, 
   {{0x6f040384,0x8574e5e7,0x6f880131,0xfe7c0129}},	//   dmic, _خدائ, _ﺗﯧﻤﺎ_, _raï_, 
   {{0x75d00451,0x9f3401ec,0x7ce8002f,0xf1a400d4}},	//   _بيها, йегі, hürr, ірян, 
   {{0x3ec5cb3f,0x13a804fb,0xadc401e1,0xdb040112}},	//   асаб, _منوی_, _idẹs, tzhü, 
   {{0x6f040cf4,0x808c0055,0x00000000,0x00000000}},	//   gmic, _ṛtān, --, --, 
   {{0x22580175,0x7ce84dd9,0xf1a40024,0xe3b803e3}},	// [33110] mgsk_, dürr, _дрэн, mbıq_, 
   {{0xfba9cb40,0x2f1c03b2,0x6f0401ab,0x9f40005b}},	//   ктей_, _fíg_, amic, _pyhä_, 
   {{0xdb7c0020,0x2f1c02d2,0x6f04045a,0x3d14012d}},	//   _ከዚያም_, _gíg_, bmic, _भूरे_, 
   {{0xbcf800e4,0x2258037e,0x00000000,0x00000000}},	//   _apét, ngsk_, --, --, 
   {{0xdcec08ad,0x22580175,0x99680014,0xaa580114}},	//   svađ, igsk_, امتٕ_, ричу_, 
   {{0x7ce81ae4,0xa9040fb4,0x31e40011,0x9e840345}},	//   rürs, يبون, নেকশ, _ئاگۆ, 
   {{0xddcc0010,0x3d1c00cc,0xdb2400e5,0x00000000}},	//   ndaž, _পিট্_, _چوڑی, --, 
   {{0xe7d40131,0xd6780451,0x06800395,0x00000000}},	//   تمىگ, احثا_, згън, --, 
   {{0x9344c66c,0xcaa40150,0x758001b9,0x00000000}},	//   әнме, _القۋ, تیشم, --, 
   {{0x6f040419,0x00000000,0x00000000,0x00000000}},	//   zmic, --, --, --, 
   {{0x6f05cb41,0x13080a8f,0x7404015b,0x64981de6}},	//   ymic, лной_, োর্ট_, ртыр_, 
   {{0x622400d1,0x00000000,0x00000000,0x00000000}},	//   يىپل, --, --, --, 
   {{0xd469cb42,0xf8d80034,0xb9dc02d3,0x316001b9}},	//   _биле_, _बदाय, _እካ_, _qqiz_, 
   {{0xd7f0004d,0x8fa4004e,0x00000000,0x00000000}},	//   _kỹ_, баге, --, --, 
   {{0x047400db,0x00000000,0x00000000,0x00000000}},	//   _دئنگ, --, --, --, 
   {{0xe3b02c1f,0xd7f0004d,0x1e940276,0x6f040129}},	//   _تره_, _mỹ_, орур, umic, 
   {{0xbea14671,0x4c6800e4,0x4c14005e,0xe3b81432}},	// [33120] чатк, лиан_, مباس, ncın_, 
   {{0x6da40046,0xc5f00bd9,0x20cc0427,0x645c022e}},	//   биға, לדן_, lžin_, еriy, 
   {{0x7ce803e0,0x00000000,0x00000000,0x00000000}},	//   türr, --, --, --, 
   {{0x7e780aab,0x814002f2,0x00000000,0x00000000}},	//   _óupp, _بچێن, --, --, 
   {{0xe8c801f0,0xe83800d4,0x00000000,0x00000000}},	//   аҳал_, аплі_, --, --, 
   {{0x3ea400a8,0xc7640372,0x2c04010b,0x3cf0003a}},	//   _într_, مابى, _дүзм, clxv_, 
   {{0x22580175,0x37a4011c,0x00000000,0x00000000}},	//   ygsk_, йтън_, --, --, 
   {{0xccec0327,0x661c0118,0x00000000,0x00000000}},	//   _ཨེཌྶ, ěrko, --, --, 
   {{0x20cc00f3,0xc84400ee,0x7e980375,0x00000000}},	//   džin_, _гезй, רספו, --, 
   {{0x38a803b2,0x356401c0,0x6ab807b6,0x7ccc00c0}},	//   _børu_, ёрын_, _आतुर, _gėrė, 
   {{0xaca402e3,0x2cb922d4,0x068401e0,0xe3e800e5}},	//   _adịr, _mlrd_, _гѳлн, جکشن_, 
   {{0xddcdcb43,0x22580175,0x7bd8011a,0x00000000}},	//   neaţ, ugsk_, רקטו, --, 
   {{0x22580158,0x84e400f5,0xb61401ec,0xe3b80205}},	//   rgsk_, _лодж, _ﹼﺎ_, ccın_, 
   {{0xb9dc069c,0x1fb80372,0x2cb8009a,0x9a2801fb}},	//   _እያ_, алгы_, _nlrd_, _mươi_, 
   {{0xaab8534e,0xbcf80231,0x38a8022c,0x3e687216}},	//   _आतंक, _opér, _tørv_, лшан_, 
   {{0x38a817c1,0xff040826,0x22580175,0xef1000f1}},	//   _hørt_, сягн, qgsk_, ېټې_, 
   {{0x38a804ce,0x443dcb44,0x2249cb45,0x9c390081}},	// [33130] _kørt_, oat_, _idak_, ипат_, 
   {{0x443dcb46,0xbcf9cb47,0xcf8c004b,0xd9981893}},	//   nat_, _apér, رژۍ_, ینات_, 
   {{0x443dcb48,0x38a80ac8,0xbcf8551a,0x20cc0064}},	//   iat_, _mørt_, _spés, lžio_, 
   {{0xdd94005e,0x212806a3,0xdb040022,0xda6400d4}},	//   _дамы, _ktah_, pyhí, івли, 
   {{0x443dcb49,0xd944eeaa,0x98a400ee,0xddcc012d}},	//   kat_, цели, жиле, ndaż, 
   {{0xac19cb4a,0xdcb00208,0x9a280051,0x00000000}},	//   _гору_, _ổ_, _dươi_, --, 
   {{0x443dcb4b,0x09a802f5,0x7d1c0334,0x224803e0}},	//   dat_, _খেদা, lqqs, _odak_, 
   {{0x2249cb4c,0xbdd80066,0x443c09d3,0x96a80aac}},	//   _ndak_, _ndèk, eat_, ркиб_, 
   {{0x21294687,0x7ae80158,0xa7fc1432,0xb6a001a9}},	//   _ntah_, mogt, _acıd, жиқл, 
   {{0x7ae9cb4d,0x20cc02d5,0x224803e0,0xe3b80205}},	//   logt, džio_, _adak_, rcın_, 
   {{0x21280438,0x224805b1,0xe6b4036b,0x20cc00c0}},	//   _atah_, _bdak_, زلیگ, ežio_, 
   {{0x443dcb4e,0x2248a0f0,0x7ae82bac,0x38a806ea}},	//   aat_, _cdak_, nogt, _vøru_, 
   {{0x443dcb4f,0x388c00de,0x00000000,0x00000000}},	//   bat_, _tērē_, --, --, 
   {{0x443dcb50,0x53a4007b,0x76580205,0x00000000}},	//   cat_, _ومشك, lguy, --, 
   {{0x212800d5,0x2248031c,0xbdd8007f,0xd00813dc}},	//   _etah_, _fdak_, _jeèf, реве_, 
   {{0x41e8063f,0x13a801ed,0x20cc0010,0x4370009f}},	//   ụsọ_, _منڈی_, lžil_, _آهير, 
   {{0x27e00ab7,0x7ae80ea0,0x00000000,0x00000000}},	// [33140] ğini_, dogt, --, --, 
   {{0x7ea0063f,0xbcf9cb51,0xb4c40cb4,0x5ac40327}},	//   _ọpti, _spér, _ईगो_, _གཏུམ, 
   {{0xddcc054e,0x7ae801d3,0x71fc00fe,0x00000000}},	//   teaţ, fogt, _ইলিচ_, --, 
   {{0x443dcb52,0x224805b1,0xbf600050,0x00000000}},	//   zat_, _xdak_, _تۯٲو, --, 
   {{0x443dcb53,0x88e41301,0xe8945159,0x6e24b2f1}},	//   yat_, ожде, заль, mcib, 
   {{0x6d45cb54,0x6e240381,0xc8640212,0x993806a6}},	//   msia, lcib, ітли, сяцу_, 
   {{0x443dcb55,0x6d45cb56,0x9948068f,0x38c83a25}},	//   vat_, lsia, góły_, جانی_, 
   {{0x9a280016,0x38a9cb57,0x81c003d4,0xbcf8035b}},	//   _tươi_, _børs_, ্থত_, _upér, 
   {{0x443dcb58,0x224801a9,0x487801f4,0x00000000}},	//   tat_, _rdak_, _всея_, --, 
   {{0x6e240007,0x76581418,0x38a82142,0x6d440fb2}},	//   hcib, aguy, _dørs_, isia, 
   {{0x6729cb59,0x6d440092,0xaca40521,0x2248005a}},	//   _utdj, hsia, _ndọr, _pdak_, 
   {{0x443dcb5a,0xe1240489,0x69dc0134,0x00000000}},	//   sat_, _འཕྱད_, _ɛren, --, 
   {{0x443dcb5b,0xc4c43ccf,0xaca4063f,0x659405f5}},	//   pat_, _وتتو, _adọr, _халу, 
   {{0x443dcb5c,0x6d440030,0xc0580220,0xe3b82ca8}},	//   qat_, dsia, шім_, lcım_, 
   {{0xbdd8067c,0x224806df,0x6d445bf7,0xdb0400e4}},	//   _idèi, _tdak_, esia, hyhá, 
   {{0xbcf800e4,0x6e240af2,0x2249cb5d,0x7d1c0334}},	//   _apép, gcib, _udak_, tqqs, 
   {{0xe124003d,0x6d45cb5e,0x5d543ac0,0x7ae9cb5f}},	// [33150] _འཕྲད_, gsia, якат, vogt, 
   {{0x660400c7,0x00000000,0x00000000,0x00000000}},	//   _úiku, --, --, --, 
   {{0x6d440eda,0x7ae86d77,0x7d1c0175,0x7659298d}},	//   asia, togt, sqqs, yguy, 
   {{0x0f7804ac,0x1a642be7,0x6d440218,0xd04c013f}},	//   _פארב, ثیری_, bsia, sobɔ, 
   {{0xdb0401ed,0x6d45cb60,0x7ae81dca,0x00000000}},	//   gyhá, csia, rogt, --, 
   {{0x31580375,0x7ae80ea0,0x00000000,0x00000000}},	//   קיון_, sogt, --, --, 
   {{0xda342b41,0xa7fc0790,0xba7408f4,0x7b00000d}},	//   _невы, _acıb, _وارت, jõug, 
   {{0x1a640133,0x00000000,0x00000000,0x00000000}},	//   _ریتی_, --, --, --, 
   {{0xe8ec4eac,0x25a001c3,0x765803e0,0x29880d1d}},	//   _аһ_, _àill_, rguy, _мсфо_, 
   {{0x81c0000e,0xa855cb61,0x20cc19b3,0x555821f3}},	//   ্থা_, _окуч, užil_, _ҳадя_, 
   {{0x6d45cb62,0x38a803cd,0xe3b80213,0x00000000}},	//   zsia, _førr_, qcıl_, --, 
   {{0x6d45cb63,0x38a803cd,0xe0c8010f,0x00000000}},	//   ysia, _gørr_, _גײ_, --, 
   {{0xa5f8026a,0x6e2400f3,0xc6900a7c,0x00000000}},	//   _децу_, vcib, _ראד_, --, 
   {{0x7e6c01a6,0x8fa402dd,0x00000000,0x00000000}},	//   _abcp, паге, --, --, 
   {{0xb9f01540,0x7e6c010a,0xdff400d4,0xc0e00064}},	//   _ዜጋ_, _bbcp, дять, хорк, 
   {{0x7b0000af,0xbea1cb64,0x27f801bf,0x00000000}},	//   nõud, наск, _ørne_, --, 
   {{0x6d45cb65,0x6e2409ff,0x3d2801b9,0x00000000}},	// [33160] usia, rcib, متلی_, --, 
   {{0x7e6c074d,0x6e25cb66,0x6d441905,0x0200013d}},	//   _ebcp, scib, rsia, _язын, 
   {{0x6d45cb67,0x8b699dcc,0x764802d0,0xaca400a2}},	//   ssia, сиев_, _odgy, _seỳr, 
   {{0x7b0000c5,0x6d45cb68,0xc9846fe4,0xdb04035b}},	//   jõud, psia, зуки, tyhá, 
   {{0x4c340323,0x5ec400fb,0x00000000,0x00000000}},	//   _нэвт, _цияғ, --, --, 
   {{0x76480142,0xbcf80588,0xdb0400e4,0x00000000}},	//   _adgy, _upép, ryhá, --, 
   {{0xc794405c,0xdb0400e4,0x00000000,0x00000000}},	//   ярды, syhá, --, --, 
   {{0xfa640276,0x3200022e,0xa7fc0205,0xdb0400c7}},	//   _наск_, _oziy_, _acıc, pyhá, 
   {{0x7ae1cb69,0x08c4020f,0xdb040b70,0x38a803b2}},	//   énte, _ебан, tzhö, _vørr_, 
   {{0x764802d0,0x25a001ab,0x7b00000d,0xd6d8004e}},	//   _edgy, _àilm_, tõug, йтө_, 
   {{0x38a8168c,0xe3b80205,0xa278361e,0x00000000}},	//   _tørr_, mcık_, обну_, --, 
   {{0x7b00000d,0xe3b803e0,0x00000000,0x00000000}},	//   rõug, lcık_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf1b005d9,0x220400b0,0x20cc0118,0xe3b80790}},	//   اءَ_, _rūhī_, mžik_, ncık_, 
   {{0x3f840135,0xb4f8011a,0x34f805d0,0x00000000}},	//   _ġnus_, _הפגי, _ההגד, --, 
   {{0x756401d9,0x33d80375,0xdd95cb6a,0x9f5c01e1}},	//   _بییہ_, _לחוד, мабы, _ńwó_, 
   {{0x3d1405f9,0x9d1470b7,0x7b0000c5,0x7690012d}},	// [33170] _भूखे_, ддач, nõue, _użył, 
   {{0xa41c033f,0x6d48002b,0xe0600244,0x00000000}},	//   नशिप_, _ādat, _جێسی, --, 
   {{0x09a803f4,0x00000000,0x00000000,0x00000000}},	//   _খেলা, --, --, --, 
   {{0x99d4c578,0xd9f806a6,0xfd4401c0,0xcfc40154}},	//   وقات, онец_, _нэгн, _শুকন, 
   {{0x6935cb6b,0x99dc010e,0x7b000037,0x00000000}},	//   енчу, _meňg, jõue, --, 
   {{0x20cc009b,0x32d40ca8,0x00000000,0x00000000}},	//   džik_, _kúyè_, --, --, 
   {{0x238c0316,0xd70835a2,0x00000000,0x00000000}},	//   _něj_, онке_, --, --, 
   {{0xa7fc013d,0x00000000,0x00000000,0x00000000}},	//   _abıs, --, --, --, 
   {{0x3a3c01c4,0x3ea80306,0x65f801c6,0x947832b0}},	//   _ieup_, _moct_, зээр_, осну_, 
   {{0x3a3dcb6c,0x7b000254,0x00000000,0x00000000}},	//   _heup_, sõud, --, --, 
   {{0x3a3c04c4,0x20000943,0x68e5a6c2,0xfd1c0268}},	//   _keup_, _nzhi_, éide, _luì_, 
   {{0x3ea8003a,0x238c0118,0xc7b0011a,0xd1740166}},	//   _noct_, _děj_, _שבא_, мыгы, 
   {{0xe50800aa,0x10740150,0x65940153,0x00000000}},	//   _ځينو_, _ﺸﻤﻭﻻ_, _пацу, --, 
   {{0x3a3c003e,0x00000000,0x00000000,0x00000000}},	//   _leup_, --, --, --, 
   {{0x9f5c0248,0x00000000,0x00000000,0x00000000}},	//   _ńwò_, --, --, --, 
   {{0x01ec0521,0xe3b80790,0x09e000cc,0x00000000}},	//   ụrụn, zcık_, _বৰফা, --, 
   {{0x3ea96f7c,0x320001a9,0x99dc00a2,0x6d480055}},	// [33180] _doct_, _uziy_, _jeňd, _ādas, 
   {{0xfd1c05d5,0x00000000,0x00000000,0x00000000}},	//   _duì_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa3d402e5,0xddc80205,0x00000000,0x00000000}},	//   _सेफ_, _çoşt, --, --, 
   {{0xa3d407af,0x5d7401f0,0x00000000,0x00000000}},	//   _सेन_, _пурф, --, --, 
   {{0x2d81cb6d,0xec3401b9,0x9d7400db,0x23b5cb6e}},	//   mwie_, _سورگ, _سەما_, _jújú_, 
   {{0xe3b805d1,0xa7fc03b9,0xbc6000d8,0x00000000}},	//   rcık_, _abır, _шврк, --, 
   {{0x2d80d0a9,0x99bc00cc,0x00000000,0x00000000}},	//   owie_, _আখৰক, --, --, 
   {{0x2d80002f,0x26d80051,0x00000000,0x00000000}},	//   nwie_, đro_, --, --, 
   {{0x99dc0432,0xe3b80205,0x00000000,0x00000000}},	//   _deňd, mbız_, --, --, 
   {{0xf4800046,0x3a3c0de2,0xe2f9cb6f,0xac9c02dd}},	//   туын, _yeup_, зені_, рзiм, 
   {{0xb7d40a2c,0x63c401a6,0x7b00000d,0x2d800210}},	//   _توما_, _đunđ, põue, kwie_, 
   {{0x99dc00a2,0x3a34011a,0x25a00205,0xd24c00cf}},	//   _geňd, ורכם_, _çil_, حچى_, 
   {{0xfd4c01fb,0x2d80033f,0x133800e5,0x00000000}},	//   _triế, dwie_, _کتوں_, --, 
   {{0x46b03885,0x2d800210,0x77440023,0x09e000cc}},	//   _जवाह, ewie_, _ከይሓተ, _বৰমা, 
   {{0x6d4800cd,0xe3b8013d,0x00000000,0x00000000}},	//   _ādar, kbız_, --, --, 
   {{0xfd1c0c95,0x3a3c00d5,0xa5d412eb,0x99d800eb}},	// [33190] _quì_, _reup_, _बेमौ, _তর্ক, 
   {{0x2a64070d,0xdfd031b1,0x1ca40133,0x3d1c000d}},	//   _acmb_, _ميخ_, رێزی_, _बढीं_, 
   {{0x3a3c007f,0x4bc001c0,0x99dc00a2,0x0dbc0092}},	//   _peup_, гөтг, _meňe, _ሰይፍ_, 
   {{0x3ea8004b,0xd1e00023,0xe3b80205,0x11680244}},	//   _uoct_, ነይቲ_, rcıh_, _بلیی_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d480014,0x7ce80e78,0x00000000,0x00000000}},	//   _زلفِ_, hürz, --, --, 
   {{0x7ce9cb70,0x3a3c0098,0x20cc16a3,0x00000000}},	//   kürz, _teup_, ržih_, --, 
   {{0x966400c7,0xba740a52,0xb86405d9,0x9585cb71}},	//   хкие, _تاست, _ڊائو, елие, 
   {{0xa3d4032c,0x69dc016b,0x09e00183,0x195800c7}},	//   _सेब_, _ɛrek, _বৰঠা, _хазы_, 
   {{0xa2cc1c5d,0x53c826b1,0x00000000,0x00000000}},	//   दोस्, згом_, --, --, 
   {{0xccf00302,0x99dc00ee,0x2d80033f,0xdb040108}},	//   רכי_, _deňe, zwie_, pyhä, 
   {{0x87b400c8,0x27f805ac,0x60d5cb72,0x2d80012d}},	//   _אלעס_, _ørna_, eizm, ywie_, 
   {{0x46381a4c,0xa3d4007d,0xa48404fb,0x60d5cb73}},	//   _זענע, _सेठ_, رجین, fizm, 
   {{0x99dc0209,0x645c007f,0xb5180d79,0x00000000}},	//   _geňe, òrit, नदीप_, --, 
   {{0xdb1c020c,0x70e0202e,0xfd1c0241,0x00000000}},	//   _èyèl, _नदील, _orìs_, --, 
   {{0x2d807c54,0xbdd8020c,0x99dc010e,0xdea0104c}},	//   twie_, _ndès, _meňb, لیپی, 
   {{0x8274008f,0x645c00c7,0x00000000,0x00000000}},	// [331a0] _טעקע_, órig, --, --, 
   {{0x2d80012d,0x6cac0150,0x99d800fe,0x3c603756}},	//   rwie_, _ﺴﻠﺒﻴ, _তৰ্ক, лкуг, 
   {{0x7d0402d0,0xa7fc3535,0x225c013a,0xc33000df}},	//   _dhjs, _acın, _úzký_, ָוד_, 
   {{0x7c38107d,0x3ea00166,0xca080353,0x00000000}},	//   _đure, _биюг, пнеж_, --, 
   {{0x7ae00687,0xda640597,0x504c0023,0xac8400c7}},	//   énta, ضاني, _ንምንባ, _иҳал, 
   {{0x67d41142,0x9944030d,0xdb0c0419,0x00000000}},	//   колу, _гiой_, ľkám, --, 
   {{0xd76400f2,0xbec400ef,0x2a6403e0,0x36300116}},	//   ننوی, _flīģ, _tcmb_, گرىس, 
   {{0x7d19cb74,0x60d51310,0x7ce800a2,0x00000000}},	//   _èusc, zizm, düry, --, 
   {{0x36300131,0xf64c00db,0xdb2000e5,0x00000000}},	//   درىس, حئى_, ótör, --, 
   {{0x04643500,0x7ce80e78,0x6a84a705,0x07a402d5}},	//   хтим, würz, _ялға, _пазн, 
   {{0x5388044e,0x2259c0f4,0x7af000e4,0x7ce80112}},	//   _ዝካየድ_, мины_, _ÿeté, türz, 
   {{0xf770011a,0x60d40210,0x00000000,0x00000000}},	//   _תקף_, wizm, --, --, 
   {{0xa5c4760c,0xefbc0023,0x7b00000d,0x09e000fe}},	//   _шөке, _ደልየ_, nõua, _বৰতা, 
   {{0x96040050,0x2ee0022f,0x645c0798,0xe374cced}},	//   _شبنم, enif_, órid, _алкы, 
   {{0x81c0045e,0xbdd8020c,0x00000000,0x00000000}},	//   ্থই_, _ndèr, --, --, 
   {{0x60d5cb75,0x2ee0e9bc,0x00000000,0x00000000}},	//   sizm, gnif_, --, --, 
   {{0x7c3805be,0x1e143298,0xdcfc0055,0x60d4036e}},	// [331b0] _đurb, тмая, _assā, pizm, 
   {{0x2ee0208d,0xefbc0023,0xacf800db,0x00000000}},	//   anif_, _ደልዩ_, енуу_, --, 
   {{0x9f3401ec,0x00000000,0x00000000,0x00000000}},	//   _шені, --, --, --, 
   {{0x19598d9d,0x99dc00a2,0x249c00ef,0x00000000}},	//   дады_, _reňb, _lnvm_, --, 
   {{0x41b0024a,0xd8f404fb,0x26c4058a,0x38707d9d}},	//   ुनिस, پزشک, dhmo_, лқат, 
   {{0x0fd4000d,0x00000000,0x00000000,0x00000000}},	//   _डेडढ, --, --, --, 
   {{0xe84831ed,0xf09427af,0x1bd40395,0x00000000}},	//   رجون_, טנס_, _ровя, --, 
   {{0x26c4016d,0x41b000dc,0x00000000,0x00000000}},	//   ghmo_, ुनास, --, --, 
   {{0x99dc00e8,0x145800c7,0x00000000,0x00000000}},	//   _deňc, мшны_, --, --, 
   {{0xb390001f,0x249c0356,0x66e80118,0x00000000}},	//   _ሌላውን_, _cnvm_, věke, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x26c4016d,0x16340395,0x69dc00b8,0x00000000}},	//   chmo_, _редя, _śrei, --, 
   {{0xcb1004ac,0x11389331,0x00000000,0x00000000}},	//   ילט_, ьяны_, --, --, 
   {{0x09b4011a,0xd00801ec,0x00000000,0x00000000}},	//   דפשט_, деге_, --, --, 
   {{0x3f64013e,0xa5c400b8,0x00000000,0x00000000}},	//   киро_, _įųip, --, --, 
   {{0x20cc0006,0xdb0400e4,0x00000000,0x00000000}},	//   džiu_, ayhú, --, --, 
   {{0xa7fc029f,0x20cc0064,0xadb800db,0x0d840166}},	// [331c0] _acıl, ežiu_, رۇسا_, ълан, 
   {{0xbf6001d3,0x2ee1cb76,0x00000000,0x00000000}},	//   دگیو, snif_, --, --, 
   {{0x4f0814a8,0x2055cb77,0x4a441b54,0x00000000}},	//   _онон_, _стыр, внев, --, 
   {{0x9418013f,0xdb2001d3,0x9ac40166,0x00000000}},	//   ɔsɔ_, átás, лихҗ, --, 
   {{0x3ea80122,0x20cc0e3c,0x7e980375,0xfe340677}},	//   žitá_, rživ_, _חסכו, _ברכי_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x26c5cb78,0x7d18011c,0x47840137,0xbb411df5}},	//   thmo_, _èusa, тылб, _веск, 
   {{0x7b000037,0xd90c01d3,0x00000000,0x00000000}},	//   lõun, _ہین_, --, --, 
   {{0xc96522d4,0xb5a00006,0x7be4054e,0x092800ec}},	//   _швай, арэй, ăruţ, _آسري_, 
   {{0xd90dcb79,0xbcf801c7,0x26c4e20a,0x7b000037}},	//   _فین_, _spéz, shmo_, nõun, 
   {{0x645c0137,0x38300075,0xddcc010e,0x00000000}},	//   òriq, _ئىمز, kgaş, --, 
   {{0x41e4242f,0xa158f0c2,0x645c03b2,0x00000000}},	//   віга, наму_, órib, --, 
   {{0x2458009d,0x41e40150,0x00000000,0x00000000}},	//   _заль_, тіна, --, --, 
   {{0xf49802d3,0x65600433,0xdfd4010b,0x7b00000d}},	//   _ንፈልጥ_, mumh, гогы, jõun, 
   {{0x442d29b1,0xbdd8e0fd,0x6561cb7a,0x63bc08fb}},	//   _iff_, _adèp, lumh, ørnd, 
   {{0xaf34034c,0xff040212,0x442c007c,0xc0480023}},	//   شرفت, тягн, _hff_, _ንዝምል, 
   {{0x5c741d56,0x6db43787,0x442c007c,0x260801ad}},	// [331d0] ллат, айту, _kff_, ाइटी_, 
   {{0x3e5007ae,0x628c004c,0x6449cb7b,0xa7fc05d1}},	//   ệt_, _haao, nadi, _acım, 
   {{0x442dcb7c,0x5a341d83,0x64480137,0x628dcb7d}},	//   _mff_, гнет, iadi, _kaao, 
   {{0x941400c8,0x65600099,0xeab07b81,0x442c56ce}},	//   אַנד_, kumh, يعن_, _lff_, 
   {{0x6449cb7e,0x442dcb7f,0x81c0045e,0x79a40801}},	//   kadi, _off_, ্থক_, ърже, 
   {{0x65600280,0x442dcb80,0x628c0363,0xdcec01e4}},	//   dumh, _nff_, _laao, ktaĉ, 
   {{0x6449cb81,0xab840228,0x628c0093,0xccf00375}},	//   dadi, _кутк, _oaao, _לכך_, 
   {{0x442c0c3a,0x628c0093,0x5588004e,0xf9b001f0}},	//   _aff_, _naao, ебим_, _кабӯ, 
   {{0x6449cb82,0x65601cdf,0xf1c408b0,0xca6c022e}},	//   fadi, gumh, ﺮﺍﻗﺘ, _yubо, 
   {{0x442c0334,0xd17402dd,0xefe40b82,0x03e80241}},	//   _cff_, қымы, _ሞያዊ_, _ìkọl, 
   {{0x442dcb83,0xb764022e,0x967400c0,0x00000000}},	//   _dff_, _штай, _былі, --, 
   {{0x442dcb84,0x628c062c,0x65600810,0xf480036b}},	//   _eff_, _caao, bumh, _چاغی, 
   {{0x645c9ace,0x644899ec,0x67540133,0xe3b80205}},	//   óric, badi, _مخۆر, ayı_, 
   {{0x442c0998,0xd6d80034,0xa3d423ff,0x20cc0153}},	//   _gff_, lił_, _सेव_, džis_, 
   {{0x1fb444e4,0x628c096b,0xdb0401bf,0xf00400d1}},	//   астр, _faao, byhø, рүни, 
   {{0x63bc2759,0x7c382625,0xd6d80034,0x442c01a6}},	//   ørne, _đura, nił_, _zff_, 
   {{0xd17430e1,0x7b000254,0xddcdcb85,0x00000000}},	// [331e0] _сыйы, tõun, rgaş, --, 
   {{0x28b8ed65,0x20cc00bc,0x4fa4014b,0xdb080133}},	//   _अवधि, užit_, _биов, ۆزنه_, 
   {{0xdddc00d0,0xdcfc0171,0x8b94064e,0x00000000}},	//   _rasť, _arsē, ырач, --, 
   {{0x65600004,0x1dd40490,0xb9e00055,0xbb400153}},	//   yumh, _ठेवत, _hūṁ_, сецк, 
   {{0x2d85cb86,0x6449cb87,0x99dc01f1,0x6560022e}},	//   _ème_, yadi, _peňa, xumh, 
   {{0x6448058a,0x478879ea,0xd1f40092,0x65600174}},	//   xadi, есим_, ለኞቹ_, vumh, 
   {{0x6449cb88,0x442dcb89,0x656001f0,0xf64c05d9}},	//   vadi, _rff_, wumh, ڳئي_, 
   {{0x6449cb8a,0x442c2625,0x65600810,0x786000c7}},	//   wadi, _sff_, tumh, акәз, 
   {{0xbdd8007f,0x628c0076,0xd5ac0014,0xf52001c4}},	//   _neèl, _raao, ٘ہن_, йфэн, 
   {{0x24180474,0x25a0025c,0xd90c01d9,0x00000000}},	//   копы_, _ġild_, _ہیۆ_, --, 
   {{0x442dcb8b,0xd6d80034,0x99dc010e,0xe7a80243}},	//   _vff_, bił_, _jeňn, _कपिप, 
   {{0xd6d80034,0xe214005b,0xdcec01e4,0x65607d58}},	//   cił_, имны, rtaĉ, pumh, 
   {{0x6449cb8c,0x442dcb8d,0xa3d400af,0x20cc01fa}},	//   padi, _tff_, _सेर_, džir_, 
   {{0x6449b49b,0x93f40213,0x0488004b,0x9f340150}},	//   qadi, çəcə, _سختو_, иегі, 
   {{0x628d8300,0x62340150,0x00000000,0x00000000}},	//   _taao, _кейу, --, --, 
   {{0x290c01af,0x93440131,0x6aa00175,0xa7fc05d1}},	//   _lhda_, _ئىيۇ, _nnmf, _acık, 
   {{0x2d589d0e,0xbeb80036,0x3d1c012d,0x00000000}},	// [331f0] лить_, _riëd, बदें_, --, 
   {{0xd6d80034,0x68e400ae,0x00000000,0x00000000}},	//   ził_, éidl, --, --, 
   {{0xbc042e3f,0x81c002f5,0x10840166,0x00000000}},	//   учай, ্থও_, _төяк_, --, 
   {{0x4fd40302,0xfd4400e5,0xc2e400eb,0x00000000}},	//   _כותב_, _میرٹ_, _গীতি_, --, 
   {{0xd91400cf,0x00000000,0x00000000,0x00000000}},	//   адды, --, --, --, 
   {{0xd6d80034,0xbeb8bab7,0x60c40076,0x28d00cf1}},	//   wił_, _diëe, _jlhm, थोलि, 
   {{0xa3d4134e,0x00000000,0x00000000,0x00000000}},	//   _सेल_, --, --, --, 
   {{0x2b5c00bc,0xba740244,0x00000000,0x00000000}},	//   ávce_, _حاست, --, --, 
   {{0x61ec01e2,0xb864009a,0x54c4004e,0x00000000}},	//   _nxal, _مااو, ибиб, --, 
   {{0xed78044e,0xd6d8033f,0x961c00e2,0x00000000}},	//   _ኣጋጣሚ_, sił_, teņb, --, 
   {{0x645c06ed,0x7af804ba,0xd6d8033f,0x61ec06be}},	//   ória, _kkut, pił_, _axal, 
   {{0x60c43a97,0x95d877c6,0x8c180375,0x25a00064}},	//   _alhm, _идет_, כותי, _šile_, 
   {{0x7af805d9,0xd174c93a,0x77600054,0x98d805d7}},	//   _mkut, шыны, lunx, _भगाए, 
   {{0xaca40521,0xf4e800d1,0x99dc0419,0x00000000}},	//   _kwụs, _яфей_, _leňo, --, 
   {{0x7af9cb8e,0xd010006c,0x7b000254,0x00000000}},	//   _okut, زلر_, tõul, --, 
   {{0x7af9cb8f,0x00000000,0x00000000,0x00000000}},	//   _nkut, --, --, --, 
   {{0x77600564,0x4c6821b5,0xfe400212,0x00000000}},	// [33200] hunx, киан_, інфо, --, 
   {{0x7af81813,0x77600912,0x32000295,0x8b9400d4}},	//   _akut, kunx, _iyiy_, иреч, 
   {{0x3b1c0007,0x7760003a,0x99dc0419,0x8b69cb90}},	//   _biuq_, junx, _beňo, тиев_, 
   {{0x95040156,0x3b1c0399,0xd1c8001f,0x290c01a9}},	//   _ངེའི_, _ciuq_, _አላት_, _shda_, 
   {{0x3b1c0007,0x3a20151e,0xba20010b,0x8274010f}},	//   _diuq_, әмәг, әдәк, שענע_, 
   {{0x7af853ff,0xd90d49f6,0x776001e2,0xdb0c0118}},	//   _ekut, فیق_, funx, čkán, 
   {{0x7af80093,0x77600b6f,0x99dc010e,0xa3d447b8}},	//   _fkut, gunx, _heňl, _सें_, 
   {{0x7af8037e,0x7e00063f,0x77940395,0x00000000}},	//   _gkut, ọses, ркър_, --, 
   {{0x25a00114,0x3200002e,0xa3c80037,0x00000000}},	//   _šilb_, _nyiy_, लैन_, --, 
   {{0x77600107,0x99dc0432,0xf86404b3,0x00000000}},	//   bunx, _meňl, _ەمەي_, --, 
   {{0x33200009,0xf3600cc9,0xc6a40063,0x68f9cb91}},	//   _biix_, отян, _врли, movd, 
   {{0x81c0005f,0xb6a001d5,0x73d42be9,0x68f8be97}},	//   ņēmi, _михл, рдюр_, lovd, 
   {{0xc05c044e,0xe53521a8,0x84e4a90c,0xc1e8008e}},	//   _ንምርግ, _уель, _кодж, тьне_, 
   {{0x7c3817a3,0x68f82631,0x332401f5,0xf5e4a705}},	//   _đuro, novd, _funx_, _әмәл_, 
   {{0x67280010,0x7e440fbe,0xdcec031c,0xde5820c8}},	//   _judj, ихае, staċ, лаві_, 
   {{0x61ec01c0,0x6728020c,0x68f9cb92,0x443c434f}},	//   _txal, _mudj, hovd, lbt_, 
   {{0x67280d02,0x257001c3,0x5d980006,0x2f180229}},	// [33210] _ludj, nàl_, ыкаў_, роть_, 
   {{0x7af82320,0x2248000f,0x672801a4,0x33240098}},	//   _skut, _heak_, _oudj, _yunx_, 
   {{0x443c0639,0x68f9cb93,0x6728020c,0x2248005a}},	//   ibt_, dovd, _nudj, _keak_, 
   {{0x212802b4,0x1ccc0135,0x66e8012c,0x8f980375}},	//   _kuah_, ླིང_, děko, _עירי, 
   {{0xe9f802bf,0x7760014b,0x224977d0,0xdcec02fb}},	//   анці_, wunx, _meak_, ltač, 
   {{0xe8f83bb3,0x6729cb94,0x6b8c0085,0x22481a7b}},	//   алі_, _budj, ́ngɛ, _leak_, 
   {{0xdcec0122,0x21282b10,0x67280076,0x2cbc01e6}},	//   ntač, _luah_, _cudj, övde_, 
   {{0x7af9cb95,0x2129cb96,0x6728030a,0x443dcb97}},	//   _ukut, _ouah_, _dudj, ebt_, 
   {{0x332001d9,0xa934008e,0x68f806be,0x00000000}},	//   _riix_, _метш, bovd, --, 
   {{0x799808e7,0x212006df,0x55e402dd,0xdcec0306}},	//   _iruw, _nihh_, _қолб, ktač, 
   {{0x80a867a7,0x6729cb98,0xdcec009b,0x22481b2a}},	//   ञाने, _gudj, jtač, _beak_, 
   {{0x21288590,0x7998a4e6,0x63bc4098,0x443c0036}},	//   _buah_, _kruw, ørna, abt_, 
   {{0x443c04f3,0x2128020c,0x2249cb99,0x67280165}},	//   bbt_, _cuah_, _deak_, _zudj, 
   {{0xa7fc8411,0x7539cb9a,0x41240c60,0x42040107}},	//   _abıy, mpuz, соро_, ёнро_, 
   {{0x9f94013e,0x00000000,0x00000000,0x00000000}},	//   оштш, --, --, --, 
   {{0x79980295,0x92e400cc,0x00000000,0x00000000}},	//   _oruw, _বীৰ_, --, --, 
   {{0xbcf80066,0xc69008a8,0x75380115,0x28b80a59}},	// [33220] _aqéq, האן_, npuz, _अवलि, 
   {{0x0ff800c6,0x00000000,0x00000000,0x00000000}},	//   _معجب_, --, --, --, 
   {{0xf9f01b4b,0x7999cb9b,0x20280030,0x99dc0432}},	//   _བཙུན_, _aruw, átiť_, _deňm, 
   {{0x7999cb9c,0xc3300375,0x49c806b4,0x87e401e0}},	//   _bruw, פוד_, ллен_, ҡһаң_, 
   {{0x67291f18,0x6f05cb9d,0x38c83cb9,0xbca004da}},	//   _sudj, mlic, گانی_, تمەي, 
   {{0x79980066,0x6728020b,0x5f7401d9,0xddcc0356}},	//   _druw, _pudj, _دۅہس_, sfaţ, 
   {{0x38c87811,0x68f8038f,0x6f04fd00,0x79980428}},	//   دانی_, rovd, olic, _eruw, 
   {{0x6f040639,0x25700137,0xc6680414,0x6728030a}},	//   nlic, tàl_, ушке_, _vudj, 
   {{0x645c03b7,0x6f05cb9e,0x79981af3,0x6b9c020c}},	//   ório, ilic, _gruw, _hrrg, 
   {{0x6728066d,0x21283223,0x6f040639,0x05842c1d}},	//   _tudj, _ruah_, hlic, _ҳукм, 
   {{0x2249cb9f,0x6f05cba0,0x443dcba1,0x7538026c}},	//   _peak_, klic, rbt_, apuz, 
   {{0x21200263,0x2129cba2,0xbc18008f,0xe2f80212}},	//   _sihh_, _puah_, טויש, ремі_, 
   {{0x6f05cba3,0xc05800d6,0x7ae1cba4,0x91a80014}},	//   dlic, лів_, énti, لنَے_, 
   {{0x6f049d8f,0xf6140302,0x241971fb,0x2249cba5}},	//   elic, _החדש_, _колы_, _weak_, 
   {{0xf484c26e,0x6f05cba6,0x2129cba7,0x64580055}},	//   _دانی, flic, _wuah_, _idvi, 
   {{0x6f05cba3,0x21282f2b,0x645801fb,0xa9b801ec}},	//   glic, _tuah_, _hdvi, _әзiр, 
   {{0xdcec4e86,0xd04c00ac,0x6d400200,0x63bc01e3}},	// [33230] stač, hibə, _çmal, ärnf, 
   {{0x20003199,0xdcec02f0,0xb60000d7,0x00000000}},	//   _tyhi_, ptač, ášim, --, 
   {{0x79980066,0x2d9c0421,0x00000000,0x00000000}},	//   _sruw, āvea_, --, --, 
   {{0x6f05cba8,0x9999cba9,0x79981bb7,0xdea08efb}},	//   clic, икет_, _pruw, _تیری, 
   {{0xd8240517,0x64584d3c,0x00000000,0x00000000}},	//   одли, _odvi, --, --, 
   {{0x99dc010e,0x09e000eb,0xd04c03b9,0x00000000}},	//   _heňk, _বরখা, fibə, --, 
   {{0x16a9cbaa,0x2c080064,0x7bc003b2,0x00000000}},	//   ивки_, _гэто_, ønud, --, 
   {{0x6459cbab,0x79988e92,0xb9e40212,0x00000000}},	//   _advi, _truw, _лізи, --, 
   {{0xb88001f1,0x7858005f,0x7999cbac,0x99dc0432}},	//   _príč, tāvē, _uruw, _meňk, 
   {{0x7539cbad,0x1338001f,0x09e000fe,0x00000000}},	//   rpuz, _የተገነ, _বৰকা, --, 
   {{0x64980598,0x6f05cbae,0x6459cbaf,0xd04c03b9}},	//   стыр_, ylic, _ddvi, cibə, 
   {{0x65600055,0x00000000,0x00000000,0x00000000}},	//   brmh, --, --, --, 
   {{0x64580427,0x6f0401ef,0x00000000,0x00000000}},	//   _fdvi, vlic, --, --, 
   {{0x764801ed,0x6f0475cc,0x92580066,0x00000000}},	//   _hegy, wlic, دشگر_, --, 
   {{0x6f05cbb0,0xb4000323,0x68e40597,0x7521cbb1}},	//   tlic, _хүнд, éidi, _iinz, 
   {{0xb8c81e81,0xbea1cbb2,0x7521cbb3,0x764800dd}},	//   _བོ_, маск, _hinz, _jegy, 
   {{0x6f05cbb4,0x7648066d,0xd04c0213,0x00000000}},	// [33240] rlic, _megy, zibə, --, 
   {{0x6f05cbb5,0x7648066d,0x7521cbb6,0x65c00162}},	//   slic, _legy, _jinz, _háhú, 
   {{0x7521cbb7,0xca24300e,0x00000000,0x00000000}},	//   _minz, офли, --, --, 
   {{0x7521cbb8,0x7649cbb9,0xbeb80ea0,0x00000000}},	//   _linz, _negy, _hiën, --, 
   {{0x8d744130,0x9e701a59,0x2ee00ba7,0x961c00ef}},	//   _باجا, _سۇلت, miif_, deņo, 
   {{0x76495465,0x2ee07361,0x7521cbba,0xb81000fe}},	//   _aegy, liif_, _ninz, িখনত_, 
   {{0x7649cbbb,0x93f40213,0x00000000,0x00000000}},	//   _begy, çələ, --, --, 
   {{0x75282adc,0x2ee022a9,0x75200433,0xd04c00ac}},	//   _bugz, niif_, _ainz, ribə, 
   {{0xd04c0cc1,0x2cb9cbbc,0x76480793,0x7521cbbd}},	//   sibə, _kord_, _degy, _binz, 
   {{0x7521cbbe,0x7c382625,0x76480009,0x2ee001c7}},	//   _cinz, _đurk, _eegy, hiif_, 
   {{0x2cb955be,0x764801ed,0x2ee00e14,0xa2940111}},	//   _mord_, _fegy, kiif_, пані, 
   {{0x752009f0,0x050800bd,0x2ee00449,0x2cb9cbbf}},	//   _einz, রদের_, jiif_, _lord_, 
   {{0x7521cbc0,0x2ee036c6,0x2cb80926,0xbeb80549}},	//   _finz, diif_, _oord_, _biën, 
   {{0x6458105c,0x2cb9cbc1,0x7521cbc2,0x99dc0432}},	//   _udvi, _nord_, _ginz, _deňh, 
   {{0x7649cbc3,0x2ee1cbc4,0x63bc01e3,0x00000000}},	//   _yegy, fiif_, ärnd, --, 
   {{0x7521cbc5,0x2ee00194,0x1d3402e8,0x00000000}},	//   _zinz, giif_, зная, --, 
   {{0x2cb9cbc6,0x7521cbc7,0x6fdc00cc,0x00000000}},	// [33250] _bord_, _yinz, _মুদৈ, --, 
   {{0x7521cbc8,0x00000000,0x00000000,0x00000000}},	//   _xinz, --, --, --, 
   {{0xfba9cbc9,0x2ee0208d,0x2cb9cbca,0x92dc03d4}},	//   штай_, biif_, _dord_, তকৰ_, 
   {{0x99dc010e,0x2ee00067,0x3f540327,0x7c3803e0}},	//   _heňi, ciif_, mħu_, _şurd, 
   {{0x76489abb,0x2cb8029d,0x98a400f7,0xd945cbcb}},	//   _regy, _ford_, зиле, чели, 
   {{0x75280d27,0x99dc00a2,0x79880042,0x6e2002d2}},	//   _rugz, _jeňi, rwgw, _úmba, 
   {{0x9b44168d,0x75218a36,0x76480042,0xd7f000d1}},	//   _رچاو, _rinz, _pegy, عكع_, 
   {{0x7520f213,0xa7fc029f,0xaa6400d8,0x00000000}},	//   _sinz, _acıs, _отук, --, 
   {{0x7521cbcc,0x95540491,0xfe7c24ba,0x764800dd}},	//   _pinz, أخبا, _mbï_, _vegy, 
   {{0xd4680063,0xb40000db,0x00000000,0x00000000}},	//   љине_, мүлд, --, --, 
   {{0x7521cbcd,0x764800dd,0xe6b407d6,0x7ae801fb}},	//   _vinz, _tegy, سلیگ, ongt, 
   {{0x7520e6c8,0x7ae80194,0x83601b56,0x3f540327}},	//   _winz, nngt, رگىل, dħu_, 
   {{0x7521cbce,0x59bc2e35,0xfbc0045e,0x7ae800c6}},	//   _tinz, ्निर, ্পিত, ingt, 
   {{0x85980375,0x2ee0002d,0x3f54031c,0x2bdc0037}},	//   _לשנו, wiif_, fħu_, _गइलू_, 
   {{0x3f541f21,0x7ae80280,0x99dc0209,0x2ee022a9}},	//   għu_, kngt, _deňi, tiif_, 
   {{0x63bc0598,0xa3d402ab,0xe3b01ec7,0x2cb91e03}},	//   ärne, _सेट_, _جره_, _sord_, 
   {{0x2ee14ca5,0x2cb801e4,0x4d640006,0x00000000}},	// [33260] riif_, _pord_, якав, --, 
   {{0x2ee05bce,0xcce400c6,0x99dc0432,0x7ae80334}},	//   siif_, أسري, _geňi, engt, 
   {{0x8a443306,0x60c00008,0x9abc002e,0x2cb80156}},	//   كَان, ölme, _siŋa, _vord_, 
   {{0xfe7c025a,0x2cb9cbcf,0xa7fc0139,0x2ee16bf9}},	//   _gbï_, _word_, _ocır, qiif_, 
   {{0x0d98013d,0x99dc010e,0x7c38010e,0x7e98011a}},	//   _утны_, _yeňi, _şure, _הסכו, 
   {{0x7ae9cbd0,0xd5d83be5,0x25a00064,0x00000000}},	//   angt, _बेइज, _šilo_, --, 
   {{0x27380022,0xa7fc0205,0x00000000,0x00000000}},	//   _oĩne_, _acır, --, --, 
   {{0x7c3856c0,0x2d84004a,0x7f380677,0x00000000}},	//   _đuri, _âmes_, זעקו, --, 
   {{0x49c9cbd1,0xa3d42793,0x0dbc02d3,0x3870036e}},	//   _улан_, _सेज_, _ደርፊ_, çarë_, 
   {{0xa4d80212,0x2919cbd2,0x00000000,0x00000000}},	//   ідну_, _òra_, --, --, 
   {{0x337001c0,0xa3d448e5,0xc32c0116,0xf41c00cc}},	//   нгэр, фонч, دەب_, _ম্বৰ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2459cbd3,0x63bc01e3,0x00000000,0x00000000}},	//   _даль_, ärnb, --, --, 
   {{0x760804ac,0xc8bc7382,0x343401d9,0xd5840133}},	//   _פּאַ, ्सिट, _ٹٲٹھ_, _کێیه_, 
   {{0x20041f60,0x5ea4129e,0x7478011a,0xa3c81be1}},	//   æli_, ومسل, _הנוג, लैश_, 
   {{0x7b00000d,0x3f540135,0x133800e5,0x00000000}},	//   nõut, rħu_, _بتوں_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [33270] --, --, --, --, 
   {{0x7f54037e,0xbeb80036,0x804801b9,0xac9401ec}},	//   _tvxq, _ziël, _учиб_, науш, 
   {{0xad24a70b,0x316c0034,0x00000000,0x00000000}},	//   رىمى, ądze_, --, --, 
   {{0x5d880116,0x7ae8030a,0x00000000,0x00000000}},	//   _мәзг_, ungt, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa7fc03e3,0x28f80108,0x52b800bc,0x00000000}},	//   _acıq, печь_, _उक्स, --, 
   {{0x59bc00bc,0x00000000,0x00000000,0x00000000}},	//   ्नहर, --, --, --, 
   {{0xaa940104,0xed580244,0x00000000,0x00000000}},	//   _писч, _بشێت_, --, --, 
   {{0x78240d6d,0xd4f47edd,0x5bdc024a,0xa9240064}},	//   _فعال, дяны, _मधुव, _ūžes, 
   {{0xbeb8017a,0x28a4cc41,0x00000000,0x00000000}},	//   _siël, _गोपि, --, --, 
   {{0x56200051,0xb74402f2,0x96740153,0x00000000}},	//   _bọcạ, _رئاو, _жылі, --, 
   {{0x91e56c3e,0x00000000,0x00000000,0x00000000}},	//   доме, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbeb80036,0x92dc0eac,0x63bc007c,0x83600137}},	//   _wiël, তকে_, ärnc, رگۉل, 
   {{0x7b0000c5,0xd01001d3,0x8fd00116,0xdff4005b}},	//   nõus, ئلز_, тәпә, еять, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb8102158,0x00000000,0x00000000,0x00000000}},	// [33280] িখিত_, --, --, --, 
   {{0xc3440020,0x3c60004e,0x00000000,0x00000000}},	//   _የተጠቀ, ккуг, --, --, 
   {{0x7b0000c5,0x7ff402dd,0x00000000,0x00000000}},	//   jõus, _يسپا, --, --, 
   {{0xc9840139,0x00000000,0x00000000,0x00000000}},	//   дуки, --, --, --, 
   {{0xf98dcbd4,0x80a0012c,0x7ae004fb,0xa7fc0205}},	//   لبو_, _छोडे, ènta, _acıp, 
   {{0x18541b56,0x7ae1cbd5,0x63bc01bf,0x00000000}},	//   ىرىڭ, éntr, ørnk, --, 
   {{0xf76dcbd6,0xd90c01d3,0x2c1c00cc,0x00000000}},	//   لاي_, حیل_, _প্ৰে_, --, 
   {{0x4aa801ec,0x28ac00bc,0x00000000,0x00000000}},	//   _باسپ_, चाहि, --, --, 
   {{0x68e401c7,0x99dc00d7,0x3ab00139,0x846402e8}},	//   éids, _beňu, _шәфт, мъне, 
   {{0x2005cbd7,0x00000000,0x00000000,0x00000000}},	//   ülik_, --, --, --, 
   {{0x92dc0c58,0x00000000,0x00000000,0x00000000}},	//   তকৈ_, --, --, --, 
   {{0xe3c400f7,0xa7fcc031,0x02a42b2e,0x00000000}},	//   _үркү, _adıg, фром, --, 
   {{0xf4913e06,0xbdd801e1,0xdb14003e,0x29c001e4}},	//   رشید, _leèr, ébén, nϲa_, 
   {{0x5f94009d,0x34a40798,0x00000000,0x00000000}},	//   нигт, _овчо_, --, --, 
   {{0xdfd407a2,0xc2f0035b,0xef840a89,0x54180137}},	//   ховы, _аҟны, клёп, _ىرىڭ_, 
   {{0xa3c800dc,0x33800395,0x00000000,0x00000000}},	//   लैः_, _рушв, --, --, 
   {{0x9d142a5e,0xdcfc00de,0x00000000,0x00000000}},	// [33290] едач, _apsā, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x63bc383d,0x00000000,0x00000000,0x00000000}},	//   ørnh, --, --, --, 
   {{0x28a41b97,0x00000000,0x00000000,0x00000000}},	//   _गोबि, --, --, --, 
   {{0x66e800bc,0x00000000,0x00000000,0x00000000}},	//   něku, --, --, --, 
   {{0x7b0000af,0x3f840798,0x00000000,0x00000000}},	//   tõus, _ânus_, --, --, 
   {{0x961c00e2,0x989400c7,0xc05c0023,0x00000000}},	//   meņi, дуқә, _ንዝተገ, --, 
   {{0x99bc009e,0x28a4000d,0x19940153,0x00000000}},	//   _অধীক, _गोठि, _пабя, --, 
   {{0x65f801c0,0xa7fc0b97,0x06800209,0x779006be}},	//   дээр_, _adıd, угын, _məxə, 
   {{0x39740023,0x947400e5,0x66e8013a,0x00000000}},	//   በኣርሲ_, ردخا, děku, --, 
   {{0x236c43ed,0xc4c4009d,0x00000000,0x00000000}},	//   gudj_, хлэж_, --, --, 
   {{0x63bc049f,0x00000000,0x00000000,0x00000000}},	//   ärna, --, --, --, 
   {{0xcb100a7c,0x2174022e,0x5ef400cd,0x00000000}},	//   טלט_, курр, ूवन्_, --, 
   {{0x273800e4,0xd478010f,0x00000000,0x00000000}},	//   _hĩna_, _זאַל, --, --, 
   {{0x60c001a8,0xe4c8140f,0x8e840798,0x99dc01ef}},	//   ölma, _زبون_, нгве, _keňs, 
   {{0x5275cbd8,0x2200063f,0x924801d5,0x645c00c7}},	//   _чуку, ụsịl, _эзиб_, óriv, 
   {{0x7c399f50,0x2bec015b,0x7bc003b2,0x00000000}},	// [332a0] _şura, _করেই_, ønun, --, 
   {{0xe18805d9,0xdcf80116,0x00000000,0x00000000}},	//   _آئين_, ۋرەش_, --, --, 
   {{0x0b440801,0xd4680023,0x8c44013d,0xd008030d}},	//   хнен, _ተበጺሑ_, _җебе, _хене_, 
   {{0x63bcc300,0x81a800fe,0x00000000,0x00000000}},	//   ørni, কৈও_, --, --, 
   {{0x28ac19e5,0xbea000f7,0x07380150,0x00000000}},	//   चालि, _саяк, _ﻓﯩﯔ_, --, 
   {{0x6d44dda0,0xd90c60b3,0x291c0161,0x0d201e4a}},	//   mpia, قیق_, umva_, _сүзү, 
   {{0x69dc013f,0x00000000,0x00000000,0x00000000}},	//   _ɛrey, --, --, --, 
   {{0xba50cb3a,0x00000000,0x00000000,0x00000000}},	//   _منفع, --, --, --, 
   {{0x888423b3,0x6d448440,0x99dc0432,0x00000000}},	//   _плаж, npia, _deňs, --, 
   {{0x6d440024,0x00000000,0x00000000,0x00000000}},	//   ipia, --, --, --, 
   {{0xe2f94012,0x248c00d7,0x46a4014b,0x00000000}},	//   дені_, redm_, _пажв, --, 
   {{0x6d440d04,0x99dc00a2,0x28a400af,0x7b00000d}},	//   kpia, _geňs, _गोति, nõup, 
   {{0x248c020b,0x5bdc00cd,0x00000000,0x00000000}},	//   pedm_, _मध्व, --, --, 
   {{0x6d440393,0x349001af,0x00000000,0x00000000}},	//   dpia, _башр, --, --, 
   {{0x6d44003a,0x316c012d,0xbea401ec,0x8288009b}},	//   epia, ądza_, ншай, _еспб_, 
   {{0x6e9428c7,0xc304004b,0x645c01d5,0x00000000}},	//   лису, _ثبتو, аrig, --, 
   {{0x6d44951a,0x5c7404a9,0x442c0798,0x60f802e8}},	// [332b0] gpia, клат, _kgf_, _ония_, 
   {{0x629dcbd9,0x64480327,0x2bec00cc,0x00000000}},	//   ldso, nbdi, _কৰেই_, --, 
   {{0x6d440ffb,0x7ae000f2,0x779003e3,0x00000000}},	//   apia, ènto, _təxə, --, 
   {{0x3e681086,0xbcf800e4,0x629dcbda,0x8f680014}},	//   _эшон_, _ovég, ndso, _کلێے_, 
   {{0x802437f4,0x629dcbdb,0x00000000,0x00000000}},	//   _ترکم, idso, --, --, 
   {{0x442dcbdc,0x4640001f,0x629c0009,0x28a40037}},	//   _ngf_, _የሀገራ, hdso, _गोदि, 
   {{0x7bc0000d,0xe70833ae,0x00000000,0x00000000}},	//   änud, کتون_, --, --, 
   {{0x442c1cf3,0x629dcbdd,0x958400a7,0x00000000}},	//   _agf_, jdso, влие, --, 
   {{0x629c00a9,0x4810535f,0x7581cbde,0xf99c0ca8}},	//   ddso, лмәс, уңла, _éè_, 
   {{0x98a40100,0x43bc0116,0x00000000,0x00000000}},	//   _kilč_, ﺭﻣﯩﺪ, --, --, 
   {{0x629c01f5,0x6d44009d,0xc0d00092,0xd3940bd6}},	//   fdso, zpia, _የሌላ_, тәлә_, 
   {{0x6d44f928,0x644801fa,0x629c002d,0x442c045a}},	//   ypia, abdi, gdso, _egf_, 
   {{0x442dcbdf,0x64487c1d,0x6d443113,0x645c01d5}},	//   _fgf_, bbdi, xpia, аrid, 
   {{0x442c0730,0x2ebc00dc,0x41000395,0x00000000}},	//   _ggf_, ैस्त, изяв, --, 
   {{0x6d4400a9,0xb4bc228d,0x4125cbe0,0x00000000}},	//   wpia, ीसी_, торо_, --, 
   {{0x91a00118,0x00000000,0x00000000,0x00000000}},	//   खिदै, --, --, --, 
   {{0xbeb804e6,0x63bc03cd,0x00000000,0x00000000}},	// [332c0] _liëw, ørnv, --, --, 
   {{0x6d440eda,0xa3c80c2e,0x8c444e8b,0x10a4010a}},	//   rpia, लैक_, теже, _рион, 
   {{0x6d45cbe1,0xbeb801c7,0xce4800f3,0x00000000}},	//   spia, _niëw, _озне_, --, 
   {{0x6d45cbe2,0xfaa000c7,0x00000000,0x00000000}},	//   ppia, иахо, --, --, 
   {{0xda6431ed,0x6d440357,0x64480014,0x7e740131}},	//   طاني, qpia, ybdi, _шәрт_, 
   {{0x7d04020c,0x8b65cbe3,0xdcec01a6,0x6f041554}},	//   _gkjs, _لارم, vtać, loic, 
   {{0xfce1cbe4,0x629c6394,0xd76400f2,0x00000000}},	//   _торо, ydso, هنوی, --, 
   {{0x6f05cbe5,0x2c7c0248,0x00000000,0x00000000}},	//   noic, bàdó_, --, --, 
   {{0x442c045a,0x35b00395,0x00000000,0x00000000}},	//   _pgf_, ибър, --, --, 
   {{0x63bc0621,0xe4d401d5,0x00000000,0x00000000}},	//   ärno, اقدد, --, --, 
   {{0xdcec1050,0x6d4000d2,0xd76401d9,0xe37400fd}},	//   stać, _émaf, _مانٹ, ылны, 
   {{0x6f05cbe6,0x629c01f5,0xa3c8012d,0x96b801f0}},	//   joic, udso, लैग_, _пучу_, 
   {{0x6e200af2,0x2739cbe7,0x442c0f85,0xf574007b}},	//   _úmbh, _hén_, _tgf_, _لمنع_, 
   {{0x2739cbe8,0xdee00023,0x4439cbe9,0x133800e5}},	//   _kén_, ናዮን_, _üp_, بتیں_, 
   {{0x273800e5,0x00000000,0x00000000,0x00000000}},	//   _jén_, --, --, --, 
   {{0xdd94c331,0x273801bf,0x6d40025c,0x63bcb5a4}},	//   лабы, _mén_, _ħmar, ørnu, 
   {{0x2739c0d7,0x9df9cbea,0xe1c4010b,0x6e9400a8}},	// [332d0] _lén_, хнат_, _сөнй, шиту, 
   {{0xbbe800e3,0x2258fb94,0xfa3401b9,0x00000000}},	//   ورام_, lask_, چرشد, --, 
   {{0x6f05cbeb,0x2738001e,0xdb04002d,0x1fe0015b}},	//   boic, _nén_, cxhû, _মুরস, 
   {{0xa0341c3e,0xbcf801d3,0xa9045297,0xbd68010a}},	//   _جىگت, _svéd, یبون, _орге_, 
   {{0x99846aff,0xaa580063,0x12f8010f,0x00000000}},	//   التو, тичу_, עהױב, --, 
   {{0x27397f60,0x00000000,0x00000000,0x00000000}},	//   _bén_, --, --, --, 
   {{0x27380491,0x1bd4010b,0x22580254,0xe77800e5}},	//   _cén_, _совя, kask_, نلوں_, 
   {{0xba740efb,0x2739cbec,0x22580010,0xac18009b}},	//   _جاست, _dén_, jask_, _росу_, 
   {{0x27380196,0x28a49506,0x3a3c004e,0x00000000}},	//   _eén_, _गोवि, _ifup_, --, 
   {{0x6f05cbed,0xb4bc00af,0x2738e4dc,0x395c003a}},	//   zoic, ीसे_, _fén_, _ivus_, 
   {{0x2739cbee,0x9cf00c58,0x6f0401f7,0x395c0174}},	//   _gén_, _জীৱন_, yoic, _hvus_, 
   {{0xd174481c,0x6d4000e4,0x163402e8,0x645c565c}},	//   лыгы, _émag, _седя, órir, 
   {{0x6f05cbef,0xb638001f,0xd46800a8,0xca78008f}},	//   voic, _ተሳታፊ, _зиле_, ענשט, 
   {{0x27381dd4,0x04400b16,0xb4440006,0xe6100214}},	//   _yén_, _лешн, _рэдк, _بشم_, 
   {{0x22580489,0x27380208,0x00000000,0x00000000}},	//   bask_, _xén_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6f05cbf0,0x4c85cbf1,0x0d20004e,0x00000000}},	// [332e0] roic, ллав, йүмү, --, 
   {{0x6ea4c4dd,0x00000000,0x00000000,0x00000000}},	//   _चोरु, --, --, --, 
   {{0x395ce34f,0x4a4400ee,0x6f04009f,0x00000000}},	//   _avus_, гнев, poic, --, 
   {{0xa3c80c2e,0x2739cbf2,0xaa4400c7,0x00000000}},	//   लैट_, _rén_, рҵал, --, 
   {{0xaca401f2,0x27380de2,0x8274010f,0x00000000}},	//   _atụs, _sén_, רענע_, --, 
   {{0x2d81cbf3,0x273801d3,0x22580210,0x00000000}},	//   mtie_, _pén_, zask_, --, 
   {{0x2d81cbf4,0x00000000,0x00000000,0x00000000}},	//   ltie_, --, --, --, 
   {{0x2739cbf5,0x28a4256a,0x00000000,0x00000000}},	//   _vén_, _गोरि, --, --, 
   {{0x2d81cbf6,0x225828b3,0x273801c7,0x00000000}},	//   ntie_, vask_, _wén_, --, 
   {{0x27380005,0xd90c03e6,0x2d800ea0,0x249c01d5}},	//   _tén_, _قین_, itie_, _qavm_, 
   {{0x22587dcd,0x2d800204,0x3161cbf7,0x00000000}},	//   task_, htie_, _aviz_, --, 
   {{0x2d81cbf8,0x00000000,0x00000000,0x00000000}},	//   ktie_, --, --, --, 
   {{0x7ea8014a,0x22580024,0x611401f0,0x00000000}},	//   _löpä, rask_, идму, --, 
   {{0x31600100,0x63bc0b34,0x98a400b8,0x2258000d}},	//   _dviz_, ørns, _kilā_, sask_, 
   {{0x2d81cbf9,0x9f054308,0xde5802bf,0xddcc00df}},	//   etie_, لوسو, каві_, rgaŭ, 
   {{0x2d81cbfa,0xea000051,0x49140210,0x00000000}},	//   ftie_, _arập_, _पीसो_, --, 
   {{0xdc547b00,0xa1945080,0xab840092,0xc058b3eb}},	// [332f0] ивањ, _тапч, _ነጋዴው_, _пін_, 
   {{0x443dcbfb,0xbdd80ba1,0x28a4033f,0xbcf8013a}},	//   nct_, _afèc, _गोलि, _svéb, 
   {{0x5a35cbfc,0x2d81cbfd,0x316005be,0x443c00a3}},	//   анет, atie_, _zviz_, ict_, 
   {{0x443c324c,0x2d8001ab,0x00000000,0x00000000}},	//   hct_, btie_, --, --, 
   {{0x2d81cbfe,0xbeb827bb,0xa2dc00cd,0x00000000}},	//   ctie_, _diët, _पतन्, --, 
   {{0xb4c0539d,0xbdd81497,0x18a40982,0x98a54cd7}},	//   _एके_, _efèc, ракм, рике, 
   {{0xd83001e4,0xac19bd92,0xe9d000d1,0x5434082a}},	//   _ha̍k_, _бору_, يغۇ_, یردر, 
   {{0x16a81301,0x443c0d6f,0xead40229,0x69c401c7}},	//   твии_, ect_, _лось, äiec, 
   {{0x05740597,0xc5ec00aa,0x27e001e4,0x7ae9cbff}},	//   لمية_, وړه_, ĝina_, migt, 
   {{0xc480876e,0x7ae9cc00,0x31601529,0x7999cc01}},	//   ольк, ligt, _rviz_, _isuw, 
   {{0x3161cc02,0x2d80005a,0x37a800ee,0x25a03493}},	//   _sviz_, ztie_, _ятан_, _šilt_, 
   {{0xd5b09717,0x7ae8fc8e,0x443d7b99,0x2d800030}},	//   _وفا_, nigt, act_, ytie_, 
   {{0xbeb801c7,0x443c8753,0xabdc0150,0x98a400de}},	//   _liës, bct_, _ﺃﻁﻤﺎ, _zilā_, 
   {{0x7ae9cc03,0xa7fc083c,0x10a401c6,0x00000000}},	//   higt, _acıy, шигн, --, 
   {{0x7ae82819,0x2d81cc04,0x8fa40e92,0xd0080063}},	//   kigt, wtie_, јабе, теве_, 
   {{0x7999cc05,0x7659cc06,0x59c41408,0x2d800e21}},	//   _osuw, nauy, वहार, ttie_, 
   {{0x7ae9cc07,0xd17480cf,0x79981418,0x7538014b}},	// [33300] digt, _тыйы, _nsuw, nquz, 
   {{0x2d81cc08,0x7ea80793,0x7659cc09,0xb4c063d3}},	//   rtie_, _pöpä, hauy, _एको_, 
   {{0xa7fc6f30,0x7999cc0a,0xb4c0012c,0x7659cc0b}},	//   _adın, _asuw, _एकै_, kauy, 
   {{0x2d81cc0c,0x49c99c26,0x7b841df2,0xe800302b}},	//   ptie_, клен_, شامە, _लुगा_, 
   {{0xdb15cc0d,0xaca402e3,0x4994d307,0xbeb80ea0}},	//   ébán, _agụr, ршет, _viët, 
   {{0xa81800ec,0x63bc007c,0x00000000,0x00000000}},	//   هڪار_, ärnk, --, --, 
   {{0x38c870c8,0xdcec008f,0x7ae9cc0e,0xca7400fb}},	//   خانی_, ntaĝ, bigt, _вузы, 
   {{0x76580357,0x79b400dd,0xbeb80b4f,0x00000000}},	//   gauy, _چھوڑ_, _hiër, --, 
   {{0x01c800bd,0x6aa001e4,0x75380173,0x443dcc0f}},	//   _লেনদ, _iamf, gquz, tct_, 
   {{0x6aa1cc10,0x04a8036b,0xdb0c01b8,0x98a400b8}},	//   _hamf, тъий_, üköm, _tilā_, 
   {{0x6aa1cc11,0x9f4403ee,0x443db261,0x2259cc12}},	//   _kamf, çlü_, rct_, лины_, 
   {{0x6aa1cc13,0x443c0129,0x85e800d8,0xd6d80210}},	//   _jamf, sct_, _идев_, chł_, 
   {{0xc058090b,0x75d010fe,0x6aa0013f,0xdcec0115}},	//   ків_, _ويما, _mamf, etaĝ, 
   {{0x6aa08967,0x68e401c3,0xdcec0306,0x14ac01f9}},	//   _lamf, èidh, tuač, _झोपण, 
   {{0x64580029,0x6b9c02d0,0x6aa003ac,0xf4846c71}},	//   _ievi, _nsrg, _oamf, _خانی, 
   {{0x6458325f,0x6aa1cc14,0x7ae80009,0x00000000}},	//   _hevi, _namf, xigt, --, 
   {{0x6459cc15,0x6b9c01d5,0x7ae80388,0x290c00a2}},	// [33310] _kevi, _asrg, vigt, _okda_, 
   {{0x6459cc16,0xa115cc17,0x98a40311,0x7ae80ea0}},	//   _jevi, _دوخت, _milă_, wigt, 
   {{0x6aa00921,0x60c403a2,0x76583209,0x6459cc18}},	//   _bamf, _iohm, yauy, _mevi, 
   {{0x6aa0200c,0x290c8b14,0x68e800a9,0x60c4047e}},	//   _camf, _akda_, _amdd, _hohm, 
   {{0x6aa1cc19,0x7ae9cc1a,0x76580357,0x19880032}},	//   _damf, rigt, vauy, убли_, 
   {{0x6459cc1b,0x7ae9cc1c,0xe9d89d2c,0x60c4014f}},	//   _nevi, sigt, шкі_, _johm, 
   {{0x76583209,0x6aa003f9,0x60c4016d,0x7ae83380}},	//   tauy, _famf, _mohm, pigt, 
   {{0x6459cc1d,0x60c491a5,0x7999cc1e,0x6d4000d8}},	//   _aevi, _lohm, _tsuw, _émac, 
   {{0x64583f75,0x76580357,0x27380016,0x7999cc1f}},	//   _bevi, rauy, _lĩnh_, _usuw, 
   {{0x6459cb23,0x6aa1cc20,0x49c40014,0x60c4014f}},	//   _cevi, _zamf, _اغٲف, _nohm, 
   {{0x76580d04,0x6aa172ae,0x65600e9e,0xb9f00092}},	//   pauy, _yamf, asmh, _ዞር_, 
   {{0x7af80083,0x6aa0004e,0x645803ac,0x72c8023b}},	//   _jjut, _xamf, _eevi, рғиб_, 
   {{0x68e80cfd,0x60c40db4,0xb60416ab,0x753803e3}},	//   _ymdd, _bohm, _тяжк, qquz, 
   {{0x6459cc21,0x7af807f5,0x6ac4fad5,0xdddc0034}},	//   _gevi, _ljut, _वक्र, _odsł, 
   {{0xd010036b,0x60c5cc22,0x3d0800e1,0x7af9c4a2}},	//   سلر_, _dohm, ़कने_, _ojut, 
   {{0x645804c4,0x7af9cc23,0x2738004d,0x00000000}},	//   _zevi, _njut, _dĩnh_, --, 
   {{0x64580921,0xa7fc0139,0xdcec01e4,0x0a6801d5}},	// [33320] _yevi, _adıl, staĝ, ҳрли_, 
   {{0x7af9cc24,0xdcec0135,0x00000000,0x00000000}},	//   _ajut, twaġ, --, --, 
   {{0x2fd00311,0xddcc00d7,0x00000000,0x00000000}},	//   ângă_, rgaš, --, --, 
   {{0x3b1c016d,0x63bc0267,0xbeb80036,0x00000000}},	//   _chuq_, ärni, _wiër, --, 
   {{0x6aa00810,0x33200003,0x60c4014f,0xa7fc0205}},	//   _vamf, _mhix_, _yohm, _edıl, 
   {{0x6aa09614,0xaca40521,0x6b9c0142,0xdc7400c0}},	//   _wamf, ftụw, _tsrg, _мысь, 
   {{0x6459cc25,0x60c0008c,0x645c01b9,0x98a40356}},	//   _revi, ölmi, аrin, _silă_, 
   {{0x6459cc26,0x3b1c0477,0x7af801e6,0xda641d57}},	//   _sevi, _ghuq_, _gjut, _واقي, 
   {{0x7ae1c72a,0x6459cc27,0x290c0455,0xa8e400f1}},	//   ënte, _pevi, _tkda_, _وړتي, 
   {{0x7af8151c,0x98a40311,0x27380208,0xdcec01e4}},	//   _zjut, _vilă_, _nũng_, traĉ, 
   {{0x60c4da19,0x24195089,0x6459cc28,0x473458c5}},	//   _rohm, роны_, _vevi, _طراز, 
   {{0x64580921,0x60c4047e,0xdcec0139,0x940406be}},	//   _wevi, _sohm, ktağ, nelə_, 
   {{0x6459cc29,0x60c5cc2a,0x97000116,0x00000000}},	//   _tevi, _pohm, _تېيى, --, 
   {{0x273801dc,0xa3d48046,0x60c4014f,0x9f340212}},	//   _cũng_, _молч, _qohm, жеві, 
   {{0x2738001e,0xdfd41e76,0x00000000,0x00000000}},	//   _dũng_, цовы, --, --, 
   {{0x2bac3806,0xfbdc00bd,0x27380016,0x5d5400a7}},	//   घटना, _বুঝত, _vĩnh_, жкат, 
   {{0x628d6c60,0x60c5cc2b,0xae440214,0x3f800427}},	// [33330] _ibao, _tohm, سپلو, stju_, 
   {{0x2738001e,0xbcf9cc2c,0xa7fd91ab,0x7af9cc2d}},	//   _tĩnh_, _evén, _adım, _sjut, 
   {{0x9e353716,0x5f802033,0x7af9cc2e,0x09c400cc}},	//   _менч, _تۇزە, _pjut, _শেলা, 
   {{0x99d51f23,0xdcec0139,0x5a1400d8,0x00000000}},	//   يقات, btağ, омеѓ, --, 
   {{0x5d78008f,0x628c26d3,0x00000000,0x00000000}},	//   _דאָק, _mbao, --, --, 
   {{0x17c9cc2f,0xe8f80845,0x6e2001ab,0x00000000}},	//   игли_, блі_, _ùmba, --, 
   {{0x628dcc30,0x940400ac,0x316c012d,0x7af801e3}},	//   _obao, belə_, ądzi_, _tjut, 
   {{0x7af80bb8,0x2b440323,0x645c08a7,0x99dc0209}},	//   _ujut, _хэрг, ðrin, _meňz, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x628c03bd,0x5fc842e3,0xd4680063,0x00000000}},	//   _abao, रहाल, јине_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x27380208,0x00000000,0x00000000,0x00000000}},	//   _sũng_, --, --, --, 
   {{0x6b500428,0x628c01ab,0x6594d307,0xb4b0013d}},	//   _kògò, _dbao, _нацу, _нидә, 
   {{0x628c0037,0x00000000,0x00000000,0x00000000}},	//   _ebao, --, --, --, 
   {{0x2738001e,0x33218428,0x1fb40a5b,0x7bc0000d}},	//   _vũng_, _thix_, пстр, änul, 
   {{0x99dc00ee,0x2c1803d4,0x00000000,0x00000000}},	//   _deňz, _তললৈ_, --, --, 
   {{0xc69002e4,0x63bc007c,0xccc44130,0x3da400db}},	// [33340] ואן_, ärnv, обай, окто_, 
   {{0xdde80633,0x00000000,0x00000000,0x00000000}},	//   حرفه_, --, --, --, 
   {{0x99dc00a2,0x80a00073,0x04d8010f,0x00000000}},	//   _geňz, _छोटे, סקעל, --, 
   {{0x66ddcc31,0x09483169,0xc9a99190,0x00000000}},	//   _kéke, ачки_, ивее_, --, 
   {{0x2d840124,0x60d800e4,0x88a000fb,0x5d7401af}},	//   _ëme_, _ñamý, мғаһ, _нурф, 
   {{0xb50011b1,0x8b65a865,0x00000000,0x00000000}},	//   रकोप_, _وازم, --, --, 
   {{0xf40401d3,0x66dc2fda,0x00000000,0x00000000}},	//   _آؤ_, _léke, --, --, 
   {{0xe5540063,0xdcec025c,0x3b04011c,0x00000000}},	//   пкињ, twaħ, _десо_, --, 
   {{0x6b60007b,0xddcc0055,0x00000000,0x00000000}},	//   _fágá, daaś, --, --, 
   {{0x6b5008e7,0x00000000,0x00000000,0x00000000}},	//   _gògò, --, --, --, 
   {{0xbdd80ba1,0xc7a40262,0x3370009d,0x00000000}},	//   _afèl, _фиек, мгэр, --, 
   {{0xefe80023,0x66ddcc32,0xe2f801ec,0x98a400c0}},	//   _ማርያ_, _béke, семі_, _vilą_, 
   {{0x16100406,0xd704143e,0x228c01a9,0x6b5001e1}},	//   _डुपर_, _عظمي, rоk_, _yògò, 
   {{0x85b800ec,0x15440408,0x00000000,0x00000000}},	//   _ماڻس_, _хĕрр, --, --, 
   {{0x234801b9,0xadc40248,0x628c01ab,0xba14012c}},	//   _استی_, _ifẹs, _tbao, _तर्फ_, 
   {{0x7308bed4,0x628c01f7,0x66dc01d3,0x33d8011a}},	//   _وقوف_, _ubao, _féke, _כחוד, 
   {{0xd3440133,0x00000000,0x00000000,0x00000000}},	// [33350] _وییه_, --, --, --, 
   {{0x20000218,0xfba80276,0xc4d00150,0xac9401ec}},	//   _txhi_, итей_, _ﺘﺠﺯﺌ, мауш, 
   {{0x6d40d1f4,0x66dc01f5,0x81c000eb,0x00000000}},	//   _éman, _zéke, _এইট_, --, 
   {{0xdcec39e2,0x00000000,0x00000000,0x00000000}},	//   mrač, --, --, --, 
   {{0x7c3856a3,0x6b6000ae,0x2b5801ef,0x00000000}},	//   _şuru, _págá, _ewrc_, --, 
   {{0x465c0092,0x645c022e,0x8c380117,0x7bc00162}},	//   _ለሀገራ, аrim, _горӣ_, ønus, 
   {{0xfb800133,0x6b6001d3,0x00000000,0x00000000}},	//   _زگای, _vágá, --, --, 
   {{0xadc40248,0xe708007b,0x00000000,0x00000000}},	//   _afẹs, يتين_, --, --, 
   {{0x8e80044e,0xaee400cd,0xdcec02f0,0x1dbc00cd}},	//   _ይኽእሉ_, _anṛt, hrač, ोहित, 
   {{0xdcec03c6,0x66dc04fb,0x00000000,0x00000000}},	//   krač, _réke, --, --, 
   {{0x130831af,0x00000000,0x00000000,0x00000000}},	//   йной_, --, --, --, 
   {{0xbdd802e2,0xdcec151c,0xc0dc0023,0x8bd4011a}},	//   _afèm, drač, _ሐምለ_, פורו_, 
   {{0xb5a41318,0x1544010b,0xdcedcc33,0x463800df}},	//   _фрей, _эелм, lvaĵ, _הענע, 
   {{0x66dc003e,0xdcec02fb,0x95040014,0x00000000}},	//   _gékb, frač, _ژکھہ_, --, 
   {{0x63bc0267,0x320c012d,0x3c24022e,0x00000000}},	//   ärnt, łdy_, yеva_, --, 
   {{0x66dc003e,0x00000000,0x00000000,0x00000000}},	//   _téke, --, --, --, 
   {{0x752002c4,0xbcf800c7,0x28a40037,0x00000000}},	// [33360] _khnz, _evém, _गोझि, --, 
   {{0xc0c80020,0xdcedcc34,0x81c00eac,0x00000000}},	//   በታል_, brač, _এইচ_, --, 
   {{0x316c0210,0x00000000,0x00000000,0x00000000}},	//   ądzu_, --, --, --, 
   {{0xdb58003b,0x00000000,0x00000000,0x00000000}},	//   іює_, --, --, --, 
   {{0x7ae00f49,0xe838187f,0xa97800d4,0x00000000}},	//   ënta, оплі_, ійку_, --, 
   {{0x2b580120,0x7ae152df,0x98a400c0,0x00000000}},	//   _twrc_, èntr, _kilę_, --, 
   {{0xd90c8235,0x81c000cc,0x00000000,0x00000000}},	//   جیل_, _এইছ_, --, --, 
   {{0xb8d00c4c,0xfaa1cc35,0x00000000,0x00000000}},	//   _जो_, _пасо, --, --, 
   {{0xba15cc36,0x69a401af,0x00000000,0x00000000}},	//   _فيفا_, _юлаҡ, --, --, 
   {{0x07a412b4,0xc7a4b19d,0xa3d400f7,0x00000000}},	//   _назн, _низк, дооч, --, 
   {{0xa954069c,0x66dc0098,0x224dcc37,0x7b348bbb}},	//   _ዝተባህ, _cékc, ñeko_, _ućut, 
   {{0xdcec09a8,0xc724010b,0x77b8011a,0x00000000}},	//   vrač, _эдей, _למבח, --, 
   {{0xaca40241,0xbcf8012c,0x061800db,0x2ee01210}},	//   _awọs, _svém, _ازاب_, dhif_, 
   {{0x63bc01e6,0x7bc00254,0x00000000,0x00000000}},	//   ärns, änuk, --, --, 
   {{0xbeb8069c,0xdcec02fb,0x00000000,0x00000000}},	//   _dhën, urač, --, --, 
   {{0xc0dc0020,0xdcec276e,0x00000000,0x00000000}},	//   _ሐምሌ_, rrač, --, --, 
   {{0x9df80120,0x98a40153,0xdd9000ae,0x00000000}},	// [33370] цнат_, _eilę_, ضوا_, --, 
   {{0x2ee00270,0xdcec01fa,0xa11400c6,0xbcf8219b}},	//   ahif_, prač, _زوجت, _tvém, 
   {{0x6ce402bf,0x98a40064,0x00000000,0x00000000}},	//   хіте, _gilę_, --, --, 
   {{0x2ee00368,0xdea048ef,0x644403e0,0x00000000}},	//   chif_, _جیری, _şiil, --, 
   {{0x98a409a5,0x18a401ec,0xdb140ca8,0x00000000}},	//   диле, далм, _àbík, --, 
   {{0xe8f800d3,0x00000000,0x00000000,0x00000000}},	//   плі_, --, --, --, 
   {{0x9178004d,0xfaf0007b,0xab9400d4,0x00000000}},	//   _mất_, _كثر_, _пирі, --, 
   {{0x7ac40209,0xd5483da1,0xdcec00df,0x8a780117}},	//   _эсге, опие_, rvaĵ, _мисӣ_, 
   {{0xb6a001d5,0x00000000,0x00000000,0x00000000}},	//   диқл, --, --, --, 
   {{0xbdd8007f,0x2249cc38,0x998c00a2,0x6724031c}},	//   _afèk, _afak_, _ageŧ_, ċija, 
   {{0xdcec02f0,0x00000000,0x00000000,0x00000000}},	//   hraď, --, --, --, 
   {{0xbeb8069c,0x00000000,0x00000000,0x00000000}},	//   _shën, --, --, --, 
   {{0x917801fb,0xd4680117,0x546800f3,0x00000000}},	//   _bất_, _диле_, _далм_, --, 
   {{0xbdd8007f,0x2248004e,0xf485c968,0x45a00ef6}},	//   _efèk, _efak_, _худн, _شەپك, 
   {{0xdc6c0023,0xf01801d3,0xd54801f7,0x00000000}},	//   _ኣምላክ_, سٹرڈ_, _الڪو_, --, 
   {{0x63bc0ac8,0x63b80419,0x00000000,0x00000000}},	//   årne, šaný, --, --, 
   {{0xbeb8044e,0x63480118,0x910400d8,0x00000000}},	// [33380] _thën, _věne, _опие, --, 
   {{0x2ee1cc39,0x66ddcc3a,0x705404d3,0x62640150}},	//   shif_, _méka, _سۆرا, _قاۋق, 
   {{0x4f2403a6,0x66dc0316,0x7e740205,0xf8a8000d}},	//   _одоб, _léka, _şapş, _टोइय, 
   {{0xaca40ca8,0x00000000,0x00000000,0x00000000}},	//   _ifọr, --, --, --, 
   {{0xe895b050,0x66ddcc3b,0x645c0252,0x00000000}},	//   еаль, _néka, ðrik, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x66dc00e4,0x09c4015b,0x456001d9,0x0bd456e8}},	//   _aéka, _শেখা, چھتہ, _غيرح, 
   {{0x2d440166,0xe60400d1,0x00000000,0x00000000}},	//   _köe_, нҗен, --, --, 
   {{0x66dc06fd,0xa53477c1,0x8884457e,0x38c801d3}},	//   _céka, ннич, _олаж, _ڈالی_, 
   {{0x38c8d902,0x291800dd,0x2d4400b0,0x66dc0264}},	//   _والی_, _óra_, _möe_, _déka, 
   {{0xc1c4c6e5,0x66dc0241,0x917801fb,0xa7fc2791}},	//   रङ्ग, _eéka, _rất_, _adıv, 
   {{0xaf840092,0x7bc1cc3c,0x00000000,0x00000000}},	//   ኝነትና_, änui, --, --, 
   {{0xaca40241,0x6d440211,0x41e40111,0x65941ee1}},	//   _afọr, jqia, фіна, _чалу, 
   {{0xa0c4027d,0x00000000,0x00000000,0x00000000}},	//   ريزو, --, --, --, 
   {{0x7e7c074d,0xee4c00b4,0x3135cc3d,0x7ed400c6}},	//   tgqp, _ọdịn, терр, وزرا, 
   {{0x224803ee,0xaf041db6,0x66dc002e,0x6e94084c}},	//   _ufak_, вчук, _yéka, кису, 
   {{0x629dcc3e,0x2d440139,0x9178004d,0xc0c808ca}},	// [33390] meso, _cöe_, _tất_, _дуне_, 
   {{0x629c72a1,0xad2400d1,0xdd1401e2,0x644803b9}},	//   leso, پىمى, رواخ, ncdi, 
   {{0x7ae0017a,0x6448058a,0xc96c0092,0x00000000}},	//   ënto, icdi, _አልፈው_, --, 
   {{0xaa580063,0x63bc0fac,0x8c84013d,0x00000000}},	//   дицу_, ørny, _җәфа_, --, 
   {{0x991401ce,0xeda4014b,0x00000000,0x00000000}},	//   нькі, _ишро, --, --, 
   {{0x66ddcc3f,0x629dcc40,0x8d580bd4,0xd824036b}},	//   _réka, heso, _מכשי, ндли, 
   {{0x629dcc41,0x66dc020c,0xba75cc42,0xac180132}},	//   keso, _séka, _يارت, _жору_, 
   {{0x629dcc43,0xbcf80316,0x00000000,0x00000000}},	//   jeso, _svéh, --, --, 
   {{0xe70811e6,0x91ec06ab,0xbcf800e4,0x68f400c0}},	//   بتون_, _चेंज_, _avéi, _šedž, 
   {{0x629c020c,0xbeb8036e,0x88800066,0x00000000}},	//   eeso, _shël, _میهن, --, 
   {{0x947404fb,0xdb1402d2,0x00000000,0x00000000}},	//   ودگا, _ábók, --, --, 
   {{0x629dcc44,0xbdd8180f,0x66dc0d51,0x00000000}},	//   geso, _efèi, _téka, --, 
   {{0xbcf90240,0x94d4020f,0xa6c80811,0x00000000}},	//   _evéi, _подц, _تونل_, --, 
   {{0x8fa476b8,0xbeb802d3,0x3cf8033f,0x850802dd}},	//   наге, _dhëm, ्वों_, _едің_, 
   {{0x2d440254,0xd0101291,0xbeb80200,0x63480118}},	//   _söe_, الز_, _thël, _věnc, 
   {{0x629dcc45,0x6d440d04,0xbea1cc46,0x6d4000d2}},	//   ceso, tqia, ласк, _émak, 
   {{0x55880598,0x626402dd,0xbdd8020c,0x7cd4072d}},	// [333a0] _çığı, _شايق, _ngèd, کولز_, 
   {{0x6d4405b1,0xd1e4010c,0xc3440092,0x6da400d1}},	//   rqia, _ማልታ_, _ከተጠቀ, ниға, 
   {{0xdcfc00e2,0x00000000,0x00000000,0x00000000}},	//   _apsē, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d45cc47,0xf98cd03d,0x00000000,0x00000000}},	//   qqia, مبو_, --, --, 
   {{0x629cd3b2,0x66dc003e,0xd6d8012d,0x00000000}},	//   zeso, _cékn, ekł_, --, 
   {{0xf76c1e0e,0x629dcc48,0x00000000,0x00000000}},	//   ماي_, yeso, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x629dcc49,0xdb1401e1,0x3b0403c5,0x00000000}},	//   veso, _àbák, _чето_, --, 
   {{0x629c3910,0xd90c0451,0x9a6c0092,0x759000ec}},	//   weso, _وڌو_, _አምነው_, اجيء, 
   {{0xb7d4a47a,0x629dcc4a,0xbeb80023,0x6449cc4b}},	//   _كوكا_, teso, _shëm, rcdi, 
   {{0x291d7b38,0xb7d8011a,0x00000000,0x00000000}},	//   llva_, _מקבי, --, --, 
   {{0x25a00e5f,0xbcf80124,0xd1b000e5,0x00000000}},	//   _èil_, _ivév, لیٹک, --, 
   {{0x7e6c030d,0x00000000,0x00000000,0x00000000}},	//   _sdcp, --, --, --, 
   {{0x66dc0098,0x1ed80451,0xe46c010e,0x00000000}},	//   _jéko, وارڊ_, _ýeñş, --, 
   {{0xdd95cc4c,0x629c0023,0x66dc0129,0x671028a2}},	//   кабы, qeso, _méko, ाविक_, 
   {{0xb2740b32,0x66ddcc4d,0x91c06566,0x9d1400d4}},	// [333b0] _слыш, _léko, _кәрл, вдач, 
   {{0xd130012f,0x7b640209,0xeb500092,0x00000000}},	//   _پمپ_, етде, _ይነጋገ, --, 
   {{0x66dc0de2,0x00000000,0x00000000,0x00000000}},	//   _néko, --, --, --, 
   {{0xf41000c8,0xbcf80264,0x291c143a,0xd6100150}},	//   אפע_, _swéd, elva_, _тiзб, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa9b411ec,0x3f44000d,0x9ce800e5,0x00000000}},	//   الوژ, _kõu_, _کوڑے_, --, 
   {{0x3f440037,0x2d84013d,0x9b8801e7,0x9a8801af}},	//   _jõu_, _ämer_, _تنزل_, _ошаҡ_, 
   {{0x66ddcc4e,0x9aa5cc4f,0x00000000,0x00000000}},	//   _déko, _جمرو, --, --, 
   {{0x05600cef,0x66dc0438,0xe6c40145,0x00000000}},	//   авын, _tékn, اتىي, --, 
   {{0xbcf800c7,0x3ea8003a,0xb864c303,0x00000000}},	//   _evév, _lact_, _سائو, --, 
   {{0x3f4400af,0xe7f40073,0x2a080419,0x00000000}},	//   _nõu_, ेपणा_, _vňať_, --, 
   {{0x846002d3,0xd1740139,0x95d80108,0x00000000}},	//   _ጻዕርን_, кыгы, _одет_, --, 
   {{0xe7311b58,0xbcf801c7,0xdb08002e,0x63c400fb}},	//   _اصل_, _zwée, ёnée, _ҡашҡ, 
   {{0xe3b1cc50,0xcfa87a1f,0x6d41cc51,0x66dc02ea}},	//   _گره_, وازم_, _émai, _yéko, 
   {{0x53a4004e,0x92e9cc52,0x00000000,0x00000000}},	//   _райб, _одкб_, --, --, 
   {{0xe3b0eb7e,0x3a3c014f,0x52744a46,0xb28401ee}},	//   _دره_, _ngup_, _руку, _скиҙ, 
   {{0x8c44855f,0xbea06f9f,0xe2a8009f,0x00000000}},	// [333c0] везе, шатк, _ساين_, --, 
   {{0x2728000f,0x0080156e,0x8fd000fb,0x00000000}},	//   mûne_, _кльо, _кәбә, --, 
   {{0x3ea88977,0xd009cc53,0x66dc3847,0x8b69a85b}},	//   _fact_, _цене_, _békl, фиев_, 
   {{0x66ddcc54,0x5b340276,0x961c007f,0xce4801ec}},	//   _réko, гэчу, nfņs, _ізге_, 
   {{0x66ddcc55,0x092800aa,0x66e801e1,0xbea064c2}},	//   _dékl, وستي_, _lèkù, _таяк, 
   {{0x0d2043e8,0xbcf81a5e,0x3865356b,0x00000000}},	//   _түзү, _ewéb, ganr_, --, 
   {{0x2d800311,0xb7600139,0xe7b402f2,0x7bc0000d}},	//   luie_, атый, امبد, änut, 
   {{0x66dc01ed,0x57a400fb,0x00000000,0x00000000}},	//   _véko, уышҡ, --, --, 
   {{0x2d81cc56,0xaf70001f,0x2728002d,0x9974010a}},	//   nuie_, _እውቅና_, jûne_, _бухш, 
   {{0x2a6405c7,0x386401f7,0x00000000,0x00000000}},	//   _hemb_, canr_, --, --, 
   {{0x3160003e,0xc6a47a22,0xa3f43334,0xbcf800e4}},	//   _awiz_, _арли, упні, _ivét, 
   {{0x2a64002e,0xbcf800c7,0x490800bc,0x00000000}},	//   _jemb_, _uvév, िवको_, --, 
   {{0xdb20066d,0x2a640175,0x3f440254,0xc1e001e0}},	//   ítés, _memb_, _sõu_, рөйҙ, 
   {{0x2d811afb,0x73c000ec,0x33f0072d,0x00000000}},	//   duie_, _چيوم, اسیس, --, 
   {{0x5f4401d5,0x3ea8045a,0xe4a4059f,0x645c03b2}},	//   انرل, _pact_, _арқо, ðriu, 
   {{0x2d800607,0x2a64020c,0x38640198,0x68f8014f}},	//   fuie_, _nemb_, zanr_, hivd, 
   {{0x31600165,0x68f805ac,0x2d808934,0xdcb86140}},	// [333d0] _gwiz_, kivd, guie_, нгач_, 
   {{0x09bc00e1,0x802401d5,0x3f44000d,0xac740271}},	//   ्हैय, _لرجم, _tõu_, لامش, 
   {{0xdfd4005e,0x63480118,0x00000000,0x00000000}},	//   _соны, _měno, --, --, 
   {{0x2d801142,0xb4bc00dc,0x48d00154,0xf9180210}},	//   buie_, _ंच्_, ়ফোর, _पीड़ा_, 
   {{0xadf005ba,0x2a640de2,0xeab06bd8,0xddcc033f}},	//   _घेऊन_, _demb_, تعل_, ngaż, 
   {{0x9b45cc57,0x6c5400f5,0x18680a42,0x7bc00037}},	//   _منسو, _вкру, хаки_, änus, 
   {{0xfaa5be74,0x386403b2,0x00000000,0x00000000}},	//   _ишан, ranr_, --, --, 
   {{0xead42bb6,0xe6b400d1,0x00000000,0x00000000}},	//   _кось, للىگ, --, --, 
   {{0x68f8014f,0xd4680408,0xc99400f1,0x00000000}},	//   bivd, нипе_, _مالګ, --, 
   {{0x83602002,0x53c85716,0x66e801e1,0x00000000}},	//   ڭگول, егом_, _pèkù, --, 
   {{0x31600007,0x2d8001f7,0xc0f4001f,0x2728002d}},	//   _swiz_, zuie_, _ለሌላ_, wûne_, 
   {{0x3160083a,0x7998063f,0xc0d00092,0xbcf801ef}},	//   _pwiz_, _kpuw, _ከሌለ_, _kvés, 
   {{0x7659b5f9,0xd0302e56,0xcb100a1e,0xc6d800df}},	//   mbuy, ﻳﺘﯩﭗ_, מלט_, _אַגר, 
   {{0x27280a85,0x26181cd2,0x76580166,0x00000000}},	//   rûne_, _पडती_, lbuy, --, 
   {{0x765804ba,0x01c401d3,0xcd040107,0x00000000}},	//   obuy, نڈیٹ_, ҳпай, --, 
   {{0x2d81cc58,0xadf00490,0x7998017a,0x51f442ed}},	//   tuie_, _घेउन_, _opuw, _مسخر, 
   {{0xdcfc1432,0x8c7801f4,0x00000000,0x00000000}},	// [333e0] _arsı, ещет_, --, --, 
   {{0x2a65cc59,0x2d81cc5a,0x68f8263e,0x3c60004e}},	//   _semb_, ruie_, xivd, йкуг, 
   {{0x2d81cc5b,0x09bc043e,0x8ff814af,0x00000000}},	//   suie_, ्ह्य, _سردر_, --, 
   {{0xfe54002e,0x2d81cc5c,0x4b500023,0x904400f2}},	//   _bu鯵u_, puie_, _ዝነግረ, _جنگه, 
   {{0x2d809ec6,0xda640be2,0x2ba405d7,0x2a6401bf}},	//   quie_, شاني, _गैरा, _vemb_, 
   {{0x6f050b2c,0xbdd8067c,0xfe54002e,0x8b65ac62}},	//   lnic, _efès, _du鯵u_, _مارم, 
   {{0x6f057e11,0x5d1000aa,0x2a640694,0xdcfc00c0}},	//   onic, _بېلا, _temb_, _apsė, 
   {{0x6f05cc5d,0x00000000,0x00000000,0x00000000}},	//   nnic, --, --, --, 
   {{0x6f05cc5e,0xbcf800e4,0x634800bc,0x1fd40154}},	//   inic, _ivér, _pěno, _হোস, 
   {{0x6f05cc5f,0x76580083,0xa9a40853,0x6d400129}},	//   hnic, abuy, _йиғд, _émau, 
   {{0x6f040841,0x6348012c,0x66dc00e8,0x7658010a}},	//   knic, _věno, _jékk, bbuy, 
   {{0x1fd00d2e,0x00000000,0x00000000,0x00000000}},	//   _हथौड, --, --, --, 
   {{0x6f04506e,0x7ae00d27,0x66dc002e,0x2710230e}},	//   dnic, ënti, _lékk, ावीर_, 
   {{0x6f05cc60,0xbdd8068c,0x00000000,0x00000000}},	//   enic, _ofèr, --, --, 
   {{0x6f05cc61,0xf5000014,0x66dc0de2,0xbcf800e4}},	//   fnic, _دِوُ, _nékk, _ovér, 
   {{0xc1012aaa,0x6f05cc62,0x2f180212,0x00000000}},	//   рүүл, gnic, гось_, --, 
   {{0xad240617,0xbdd801e1,0xb8180bae,0x00000000}},	// [333f0] ڭىلى, _afèr, _पुनम_, --, 
   {{0x6f05cc63,0x3e780ca8,0xbcf8004a,0xfc301867}},	//   anic, _bàtà_, _avér, محض_, 
   {{0x7998ad71,0xdc20025c,0x5b1401c0,0xbcf801ef}},	//   _spuw, _iċċa, амжт, _svés, 
   {{0x3f8004fb,0xdcec0989,0x1e841ff5,0x66dc1bce}},	//   muju_, krać, _өлүм, _dékk, 
   {{0xeff8001f,0x38702bcb,0xdb240cad,0xaa680066}},	//   ጊዜው_, йқат, _ìpín, امهٔ_, 
   {{0x26183bca,0xe9b8066d,0x66ddcc64,0xbcf80022}},	//   _पड़ी_, انوں_, _fékk, _evér, 
   {{0x3f80ae00,0x81c803d4,0x7658010a,0x69c40036}},	//   nuju_, লনি_, tbuy, äier, 
   {{0x7c640150,0xac1800f3,0x00000000,0x00000000}},	//   _جاڭل, _сосу_, --, --, 
   {{0xdcec009b,0xbcf800bc,0x06c4008e,0x00000000}},	//   grać, _uvés, ргый_, --, 
   {{0x3f8008ad,0x81c811ba,0x63b815b2,0x66dc1bce}},	//   kuju_, লনা_, _brvn, _yékk, 
   {{0x3f8004b9,0x78a1cc65,0x7658030d,0x13040107}},	//   juju_, menv, pbuy, изом, 
   {{0xdcecb485,0x3f800b91,0x63b8041a,0x66dc002e}},	//   brać, duju_, _drvn, _nékh, 
   {{0x41a5cc66,0x78a0257c,0x00000000,0x00000000}},	//   авян_, oenv, --, --, 
   {{0x6f04006d,0x78a1cc67,0x99dc01ef,0x00000000}},	//   wnic, nenv, _ufňu, --, 
   {{0x527408a0,0x3f801591,0xdb1404e6,0x8fa4013e}},	//   _купу, guju_, _erzé, шаве, 
   {{0x78a1cc68,0x66dc0de2,0x6f05cc69,0x00000000}},	//   henv, _rékk, unic, --, 
  
   {{0x78a03544,0x3f8000c0,0x833400df,0x00000000}},	// [33400] kenv, auju_, _דאקס_, --, 
   {{0x6f040b9d,0x78a05784,0xa7fc00a2,0x3f800c5e}},	//   snic, jenv, _beıl, buju_, 
   {{0x3f800b91,0x20540598,0x6f048256,0x66dc91f8}},	//   cuju_, _утыр, pnic, _fékh, 
   {{0x41b0c0e3,0x6f040784,0xa7fc0205,0x00000000}},	//   _امیر, qnic, _deıl, --, 
   {{0x66dc002e,0x78a03ce6,0x00000000,0x00000000}},	//   _wékk, fenv, --, --, 
   {{0x78a1cc6a,0xdcec0989,0x66ddcc6b,0x00000000}},	//   genv, vrać, _tékk, --, 
   {{0xbcf8f9fd,0x7a3801b8,0xc7c4267c,0x98a400de}},	//   _kwén, _pätü, рсли, _ailē_, 
   {{0xdcec0960,0x3f78008f,0xc0f00023,0x00000000}},	//   trać, דאקס, _ግዱስ_, --, 
   {{0x3f801326,0x6d4000d2,0x78a05380,0x7ae000d8}},	//   zuju_, _émas, benv, ênte, 
   {{0x63b8038e,0x3f8000b5,0x7ae001f5,0xd6c401d5}},	//   _prvn, yuju_, ëntv, _қичқ, 
   {{0xbdd800f2,0x66dc002e,0x00000000,0x00000000}},	//   _ngèn, _léki, --, --, 
   {{0xdcec08ad,0x3f803421,0xa159cc6c,0x27280086}},	//   prać, vuju_, ламу_, bûna_, 
   {{0xd4980046,0xbdd9082e,0x66ddb094,0x3f80020c}},	//   _әрі_, _agèn, _néki, wuju_, 
   {{0x3f80e11c,0xdfd4054a,0x555000e5,0x85300244}},	//   tuju_, богы, _ڈھیر, _بوتچ, 
   {{0x9f05cc6d,0xf4540375,0x48ec0037,0x63bc01bf}},	//   موسو, _דיור_, _अतनो_, ærnd, 
   {{0x78a1cc6e,0x00000000,0x00000000,0x00000000}},	//   zenv, --, --, --, 
   {{0xf3f0081f,0x3f800b91,0xaee40882,0x5c9807d8}},	// [33410] _བཟོད_, suju_, _saṃt, лкая_, 
   {{0x3f800989,0xad240075,0x66dc0129,0x00000000}},	//   puju_, قىقى, _déki, --, 
   {{0x78a1cc6f,0xfb84471f,0x00000000,0x00000000}},	//   venv, рызн, --, --, 
   {{0xdd9439f6,0xbcf800e4,0x5a340798,0x00000000}},	//   _ламы, _evép, бнет, --, 
   {{0xe9a80720,0x78a1a26f,0x39a400f3,0x6dc80137}},	//   لدون_, tenv, ршев, _кырг_, 
   {{0x31580302,0xff1001ec,0xbcf801c7,0xaee40055}},	//   סיון_, _ءﺗﯘﭖ_, _zwén, _taṃt, 
   {{0x3a842ecc,0xf3f031d9,0x78a1cc70,0x628c0a73}},	//   _вызв, _བཟེད_, renv, _ocao, 
   {{0x78a1c587,0x6d4000d8,0xc5ec00f1,0x00000000}},	//   senv, _émar, کړم_, --, 
   {{0x78a04ff4,0x00000000,0x00000000,0x00000000}},	//   penv, --, --, --, 
   {{0x644403ee,0x00000000,0x00000000,0x00000000}},	//   _şiir, --, --, --, 
   {{0x569400fd,0xd3880276,0xdcfc0171,0xb92000e4}},	//   _гает, ыйне_, _apsī, kurẽ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x65941a5c,0x66e00162,0x2ee00205,0x00000000}},	//   _мацу, sákæ, vkif_, --, 
   {{0x270c012c,0x2ee00882,0x1bf8000d,0xd468010a}},	//   měna_, नस्त, ्पाल_, _сике_, 
   {{0x1fb4dcc4,0x6edc2efd,0xd3f403d4,0x00000000}},	//   остр, _नवदु, _ঘুৰি_, --, 
   {{0x63bc1455,0x628c00c6,0x66dc004a,0xbcf80118}},	//   ærne, _gcao, _péki, _svép, 
   {{0x270c00bc,0x0d480451,0x00000000,0x00000000}},	// [33420] něna_, اشري_, --, --, 
   {{0xbeb80023,0x874800a2,0x00000000,0x00000000}},	//   _shët, _öỳüń_, --, --, 
   {{0x0b580022,0x00000000,0x00000000,0x00000000}},	//   урзы_, --, --, --, 
   {{0x26180490,0x00000000,0x00000000,0x00000000}},	//   _पडली_, --, --, --, 
   {{0xbcf800d2,0xe8f80184,0x2d84035b,0x499402e8}},	//   _kwél, аһа_, _ême_, сшет, 
   {{0x2d81cc71,0xbeb800b0,0x270c0118,0x00000000}},	//   mrie_, _whët, děna_, --, 
   {{0x6ecc38db,0x7f54022e,0x00000000,0x00000000}},	//   हापु, _xtxq, --, --, 
   {{0x2d81a26f,0x69b01d15,0x2b58009a,0xf1b800bc}},	//   orie_, _आईपी, _itrc_, इटान, 
   {{0x2d802165,0xf64c05d9,0xbdd80214,0xc6a40022}},	//   nrie_, رئي_, _ngèl, арҿи, 
   {{0x2d81cc72,0x628c0597,0xbcf800d2,0xa53402d5}},	//   irie_, _scao, _nwél, ўноч, 
   {{0x2d81cc73,0x68e8005c,0x00000000,0x00000000}},	//   hrie_, _ildd, --, --, 
   {{0x2d809877,0xb7d54dea,0x270c013a,0x00000000}},	//   krie_, _دوما_, běna_, --, 
   {{0x6348012c,0x9730028e,0xf5280092,0xf2c401c6}},	//   _měni, _تکوا, _ጥገኝነ, чсэн, 
   {{0x23b02314,0x00000000,0x00000000,0x00000000}},	//   _जनपद, --, --, --, 
   {{0x2d81cc74,0xf36001af,0x00000000,0x00000000}},	//   erie_, _етын, --, --, 
   {{0x3f7008ad,0x25ec05f9,0x2d800e38,0xfeb800f2}},	//   rću_, आईपी_, frie_, داست_, 
   {{0x2d800ffb,0x816801d5,0x00000000,0x00000000}},	// [33430] grie_, _ёриб_, --, --, 
   {{0x5c740046,0x61140212,0xdb040450,0x00000000}},	//   ілет, _єдну, lvhø, --, 
   {{0x2d81cc75,0xbeb80023,0x60c403ac,0xc8f0000d}},	//   arie_, _dhër, _inhm, _अगड़म_, 
   {{0x2d8000a8,0x68e8000f,0x6d40011c,0x290dcc76}},	//   brie_, _aldd, _èman, _ajda_, 
   {{0x2d80054e,0x00000000,0x00000000,0x00000000}},	//   crie_, --, --, --, 
   {{0xfe7000dd,0xba74fe17,0x6b7c0356,0xe9180212}},	//   _بدھ_, _گاست, făgă, бочі_, 
   {{0x2aa0007f,0xca680e26,0x66dc032e,0x00000000}},	//   _bčbč_, الۇۇ_, _léku, --, 
   {{0xba75cc77,0x290c00f3,0x96b80640,0x270c0118}},	//   _داست, _ejda_, руку_, těna_, 
   {{0x7af9cc78,0x66dc0de2,0x1c1c000d,0x00000000}},	//   _imut, _néku, _बुतल_, --, 
   {{0xbdd80066,0xdcec28b5,0x00000000,0x00000000}},	//   _ngèm, ksač, --, --, 
   {{0x130834d8,0x2d800419,0x00000000,0x00000000}},	//   иной_, zrie_, --, --, 
   {{0x7af8025c,0x92f40212,0x60c40208,0x65b001e0}},	//   _jmut, ічні, _anhm, фҡәт, 
   {{0x7af96447,0x00000000,0x00000000,0x00000000}},	//   _mmut, --, --, --, 
   {{0x66dc01e1,0x158c08b0,0x2d8000d7,0xc950011a}},	//   _déku, _ﻛﻪﺳﯩ, vrie_, ומך_, 
   {{0x7af80c8a,0x2d801c1d,0xd6a4074d,0x00000000}},	//   _omut, wrie_, _хiун, --, 
   {{0xbeb8069c,0xac0801e0,0x00000000,0x00000000}},	//   _shër, ҡмаҡ_, --, --, 
   {{0x2d80caca,0x0dc8506f,0x0c740a2c,0x00000000}},	// [33440] urie_, шлай_, قداد, --, 
   {{0x3b1c0309,0x66dc0098,0x69b00034,0x23b00cb4}},	//   _akuq_, _hékt, _आईबी, _जनमद, 
   {{0xdb14145e,0x0a6810cf,0x2d80002d,0xddcc01e4}},	//   _âbûk, арли_, srie_, mbaŝ, 
   {{0x2d81cc79,0x272800d2,0x9528031c,0xaca40cad}},	//   prie_, vûno_, _ཤེའི_, _itọs, 
   {{0xdb2000dd,0xd90c0ec9,0xbeb802d3,0xbb8000d1}},	//   ítás, گیل_, _thër, كلەي, 
   {{0x7af9cc7a,0x0af80f22,0x00000000,0x00000000}},	//   _emut, ইকেল_, --, --, 
   {{0xf76c3e52,0xd90dcc7b,0xfaec00aa,0x00000000}},	//   ناي_, دیل_, رګې_, --, 
   {{0x6b7c054e,0x00000000,0x00000000,0x00000000}},	//   răgă, --, --, --, 
   {{0x290006ed,0xc8940640,0x88c80cd7,0xa7fc00a2}},	//   éias_, _мржњ, _клав_, _meıi, 
   {{0x07a48f79,0x7b940014,0x25ec07f7,0x00000000}},	//   _мазн, _دپہس_, आईबी_, --, 
   {{0x94702084,0x66dc0264,0x2419cc7c,0x00000000}},	//   رگوا, _séku, соны_, --, 
   {{0xb7f000cc,0x00000000,0x00000000,0x00000000}},	//   _চুকত_, --, --, --, 
   {{0xb6f400d1,0x91a80014,0x461400be,0xbb38010f}},	//   _بىنا_, ٕنُے_, _بوشر, יעטי, 
   {{0xbcf80241,0x6354ea23,0xf5140244,0x00000000}},	//   _ewéj, _евку, _وتوش_, --, 
   {{0x291c084c,0xa7fc010e,0x270c00bc,0x3e69cc7d}},	//   iova_, _beıi, něno_, ишан_, 
   {{0x9f0400c6,0x5d540395,0x98a40153,0xa2d4cdcc}},	//   أورو, зкат, _filė_, _ريخت, 
   {{0x66dc0c6a,0x98a40064,0x00000000,0x00000000}},	// [33450] _héks, _gilė_, --, --, 
   {{0x291dcc7e,0x3b1c0200,0x00000000,0x00000000}},	//   jova_, _skuq_, --, --, 
   {{0x2248020b,0x1fb86135,0x9c18007b,0x25ec012d}},	//   _kgak_, _улны_, حياء_, आईडी_, 
   {{0x22480ac5,0x66dc0098,0xae1c9f23,0xdb140118}},	//   _jgak_, _méks, _भुवन_, _trzí, 
   {{0xe9f800d4,0x00000000,0x00000000,0x00000000}},	//   онці_, --, --, --, 
   {{0xe8f8160b,0x4dd80375,0x00000000,0x00000000}},	//   олі_, _החשו, --, --, 
   {{0x2248020c,0xc1a40cb4,0x7af80327,0x24d000cc}},	//   _ogak_, गबुग, _tmut, িসাহ, 
   {{0x7af8633d,0x22484a95,0xbdd800f2,0x41c811bc}},	//   _umut, _ngak_, _ngèk, ामास, 
   {{0xc0dc044e,0x442c0561,0x2b4405f5,0x66dc0098}},	//   _ሓጎስ_, _azf_, _цэрг, _rékt, 
   {{0x291c03b4,0x224815a5,0x66dc525e,0x66240131}},	//   cova_, _agak_, _sékt, برىك, 
   {{0x66dc003e,0xe61053b6,0x14240006,0x96b81b94}},	//   _pékt, _یشه_, ядом, _гулу_, 
   {{0x2120020b,0x66dc003e,0x00000000,0x00000000}},	//   _akhh_, _déks, --, --, 
   {{0x66dc0c6a,0x27340124,0x5154aec3,0x00000000}},	//   _vékt, _ẽnga_, ятну, --, 
   {{0xd47800c8,0x2248005a,0xa7fc083c,0x2c140073}},	//   _האַל, _egak_, _adıy, _तुझं_, 
   {{0xa3cc2068,0x66dc525e,0x224c01a6,0x24980ba1}},	//   रमण_, _tékt, žeka_, òrme_, 
   {{0x291dcc7f,0x20040137,0xc7b000c8,0x00000000}},	//   zova_, úlia_, עבן_, --, 
   {{0x0d85cc80,0xbcf80af2,0x3f800427,0x00000000}},	// [33460] ялан, _kwéh, arju_, --, 
   {{0xd7bc0aa2,0x291dcc81,0xa7fc0790,0x41b8011a}},	//   ्माच, xova_, _edıy, _פציע, 
   {{0x6ecc0316,0x9c580137,0x0b44117e,0x00000000}},	//   हादु, юшту_, чнен, --, 
   {{0x49c8010b,0x291c02bd,0x00000000,0x00000000}},	//   йлен_, wova_, --, --, 
   {{0xddcc3361,0x00000000,0x00000000,0x00000000}},	//   mbaş, --, --, --, 
   {{0xddcdcc82,0xd90d48ad,0x66dc003e,0x291c0175}},	//   lbaş, لیق_, _nékr, uova_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x291dcc83,0xddcc09a5,0x8a044640,0x6f080036}},	//   sova_, nbaş, _езбе, édch, 
   {{0x291dcc84,0xa53473f9,0x66dc0098,0xdcec0135}},	//   pova_, мнич, _séks, ltaġ, 
   {{0x69c1cc85,0x291ca46b,0x66dc00e5,0x00000000}},	//   _irme, qova_, _péks, --, 
   {{0x66dc003e,0xf8b0008d,0x6aa0030a,0x69c00175}},	//   _dékr, _רשע_, _kbmf, _hrme, 
   {{0x69c00b9b,0x07a4ad85,0xc29000e5,0x809c00bc}},	//   _krme, _маҷн, ریخب, ख्ने, 
   {{0x52b001e0,0x00000000,0x00000000,0x00000000}},	//   тҡыс, --, --, --, 
   {{0xbcf800e4,0x66dc7dec,0x3f800010,0xe4240066}},	//   _itég, _téks, trju_, _يکدي, 
   {{0x7498011a,0x6f880014,0xe3a40066,0x00000000}},	//   _היופ, ۪نہِ_, _آشتی, --, 
   {{0x69c00c8c,0xdb14056a,0x224806be,0xdcec0139}},	//   _orme, _orzá, _ugak_, frağ, 
   {{0x634800bc,0x00000000,0x00000000,0x00000000}},	// [33470] _věnu, --, --, --, 
   {{0x629c178a,0x23b02efd,0x6f8801d9,0x69c401e4}},	//   lfso, _जनाद, تنہِ_, ĥiel, 
   {{0x5f8002dd,0x00000000,0x00000000,0x00000000}},	//   _جۇزە, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x645801a8,0x329c00df,0x00000000,0x00000000}},	//   _ofvi, מבאד, --, --, 
   {{0xa3cc02f8,0xf8c4375c,0xbcf8020c,0x69c00010}},	//   रमा_, लाइय, _stéf, _drme, 
   {{0x809c0a94,0xbcf80241,0x66dc4a16,0xab8400a7}},	//   ख्ये, _atég, _rékr, _путк, 
   {{0x6458019b,0x629c0d27,0x66dc0098,0xeaf896d3}},	//   _afvi, jfso, _sékr, _فرقت_, 
   {{0xa2d01c15,0x69c0deee,0xd6c47577,0x00000000}},	//   धान्, _grme, зиққ, --, 
   {{0xddcdcc86,0x7989cc87,0x5efc00dc,0x00000000}},	//   zbaş, mugw, रोत्_, --, 
   {{0xbcf80022,0x79880083,0x629c0036,0xd2a8ca08}},	//   _etég, lugw, ffso, окне_, 
   {{0xdcec45a5,0x7e6c02f0,0x00000000,0x00000000}},	//   yrağ, _necp, --, --, 
   {{0x2360098d,0x20040579,0xbcf801c7,0x764802d0}},	//   _čije_, úlin_, _ewéi, _iggy, 
   {{0x8fa5cc88,0x69b06495,0x00000000,0x00000000}},	//   маге, _आईसी, --, --, 
   {{0x7988014b,0xdcec01a6,0x00000000,0x00000000}},	//   hugw, jrađ, --, --, 
   {{0x7989cc89,0xbfc000a7,0xdcec01a6,0xbea00cb6}},	//   kugw, ъбск, drađ, каск, 
   {{0xddcdcc8a,0x7988063f,0xbcf804e6,0x00000000}},	// [33480] rbaş, jugw, _zwéi, --, 
   {{0x6da40075,0x6aa00334,0xdcedcc8b,0xf004009d}},	//   миға, _sbmf, rrağ, _зүги, 
   {{0xdcec04b9,0x7649cc8c,0x10a40124,0x00000000}},	//   građ, _oggy, _еиҿн, --, 
   {{0x798801f7,0xdcece1d3,0x69c00477,0xf645cc8d}},	//   fugw, prağ, _prme, _لئ_, 
   {{0x7989cc8e,0x8d746abd,0x75200083,0x2d84a5ae}},	//   gugw, _تاجا, _oknz, _íme_, 
   {{0x6f0404d1,0x7520009a,0x7649cc8f,0xdcec08a4}},	//   liic, _nknz, _aggy, brađ, 
   {{0xbcf83386,0x69b005d7,0x2cb8015d,0x6f040165}},	//   _awéw, _आईवी, _iard_, oiic, 
   {{0x2cb8eaa1,0x75200810,0x6f04098e,0x5a940117}},	//   _hard_, _aknz, niic, _пруф, 
   {{0x2cb9cc90,0x9f45cc91,0x69c000a8,0xdb140077}},	//   _kard_, álé_, _urme, _urzá, 
   {{0x76482252,0x2cb800f3,0x6f05cc92,0x82340131}},	//   _eggy, _jard_, hiic, ېرسا, 
   {{0x2cb9cc93,0x9f4402fb,0xa2940d30,0x47f00116}},	//   _mard_, šlé_, нані, _шүкр, 
   {{0x2cb8a573,0x38c000c7,0x629c0112,0x00000000}},	//   _lard_, _térä_, ufso, --, 
   {{0xdcec07f5,0x6f0481f1,0x2cb8062c,0xc0e80023}},	//   zrađ, diic, _oard_, _መሮር_, 
   {{0x2cb8998f,0x6f0401ab,0x672000e5,0x00000000}},	//   _nard_, eiic, lomj, --, 
   {{0x6f0401d9,0x25ec012d,0x5ff403c5,0x00000000}},	//   fiic, आईवी_, хзву, --, 
   {{0x2cb82253,0x7de40046,0x6f04c7e9,0x98a400e2}},	//   _aard_, мізд, giic, _pilī_, 
   {{0x2cb81590,0x9df83529,0x91c004a9,0x7e6dcc94}},	// [33490] _bard_, чнат_, _йәрл, _vecp, 
   {{0x7988e19c,0xbbe807a7,0x2cb9cc95,0x9cb400db}},	//   vugw, يرام_, _card_, عمات, 
   {{0x67201e31,0x2cb8051a,0x6f05cc96,0x7989cc97}},	//   komj, _dard_, biic, wugw, 
   {{0xdbd000c5,0x7988767d,0xd9b8004e,0xeb3401e2}},	//   müüg, tugw, зыкч_, پرمخ, 
   {{0xca7520c7,0x6721cc98,0xcf2400ec,0x00000000}},	//   رموش_, domj, _سرٽي, --, 
   {{0x2cb9cc99,0x7989cc9a,0x9c65cc9b,0x96a00c4c}},	//   _gard_, rugw, _سهرو, क्नॉ, 
   {{0xac9457aa,0x07a002e8,0xad2400d1,0xdbd00254}},	//   _шарш, гащн, _شىفى, nüüg, 
   {{0xba740244,0xdcec025c,0xf99000f1,0x00000000}},	//   _زارت, ftaħ, _ټبر_, --, 
   {{0x752000b5,0x05a4034b,0x2cb9c6b4,0x15440022}},	//   _pknz, евый_, _yard_, неим, 
   {{0x395c919d,0x6f040036,0x949400d1,0x69347c3f}},	//   _itus_, ziic, хшич, _ануу, 
   {{0x67200455,0x24980ba1,0xe6b4006c,0x25640050}},	//   bomj, òrma_, رلیگ, _یاوُ, 
   {{0xbeb802d3,0x764802d0,0x57bc00bc,0x00000000}},	//   _skën, _uggy, ्मीह, --, 
   {{0x88b00154,0x35f80214,0x00000000,0x00000000}},	//   চারক, _برضد_, --, --, 
   {{0xd131cc9c,0xa3cc6b9b,0x8fd029db,0x6f040221}},	//   امس_, रमश_, гәмә, wiic, 
   {{0x6f040356,0x00000000,0x00000000,0x00000000}},	//   tiic, --, --, --, 
   {{0x660491aa,0x2cb9a540,0xe3b080c2,0x395c0108}},	//   _žiki, _sard_, _خره_, _otus_, 
   {{0x6f05cc9d,0xccc5aafe,0x395c0211,0xa2ac012d}},	// [334a0] riic, нбай, _ntus_, ज़र्, 
   {{0x6f05cc9e,0x3b0c0207,0xbeb804e6,0xbcf80129}},	//   siic, engq_, _ukën, _atéb, 
   {{0x395dcc9f,0x2cb9cca0,0xaca401f2,0x6f040268}},	//   _atus_, _vard_, _nzụr, piic, 
   {{0x395cbabe,0x6f04022f,0x2cb8029d,0x202800d7}},	//   _btus_, qiic, _ward_, ítiť_, 
   {{0x2cb9cca1,0xe895cca2,0xaca402e3,0x88a00184}},	//   _tard_, валь, _azụr, лғаһ, 
   {{0x9d500131,0x9574001f,0x395c0332,0xb9c018fd}},	//   _ئۆلت, _በሁዋላ_, _dtus_, اقوي, 
   {{0x672002d3,0x074401c0,0x37a5cca3,0x00000000}},	//   tomj, нхим, етын_, --, 
   {{0xbb4047c7,0x00000000,0x00000000,0x00000000}},	//   _беск, --, --, --, 
   {{0xc5d40183,0xe9840046,0x6721cca4,0x270c0118}},	//   _তেজপ, _جازۋ, romj, něni_, 
   {{0x8384005e,0xdb14481f,0xa3cc000d,0x00000000}},	//   ныме, _erzä, रमल_, --, 
   {{0x33700323,0x316005c7,0x6720009f,0xdcec031c}},	//   лгэр, _atiz_, pomj, staħ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbcf80af2,0x84e4034b,0xd2b402dd,0x00000000}},	//   _kwét, _подж, тқыш_, --, 
   {{0xdef80092,0xdbd00254,0x270c01ef,0x00000000}},	//   ለጠነ_, tüüg, děni_, --, 
   {{0x3ec402f4,0xf454011a,0x00000000,0x00000000}},	//   нсаб, _איור_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbdd8020c,0x4390020a,0xc0580150,0x00000000}},	// [334b0] _ngèt, _рақс, _нін_, --, 
   {{0xac940220,0xdbd000c5,0xf238010b,0xab6403e0}},	//   лауш, püüg, _япыш_, ktüğ, 
   {{0xdef80092,0x3f8402d2,0x00000000,0x00000000}},	//   ለጠኑ_, _ínu_, --, --, 
   {{0x9f200075,0x0f78010f,0x00000000,0x00000000}},	//   _ئۈرۈ, _קארב, --, --, 
   {{0xaca400e4,0x00000000,0x00000000,0x00000000}},	//   haỹv, --, --, --, 
   {{0x98a4b32d,0x09e0af08,0x31580375,0xa9c400db}},	//   тике, рошн, עיון_, دۅكۉ, 
   {{0xac1865f5,0x42800092,0xfaa40153,0x00000000}},	//   _зору_, ያቂነት_, _пшан, --, 
   {{0x543403e6,0xdcfc08a9,0xa88400cf,0x9984007b}},	//   ێردر, _issı, _ەللى, _للرو, 
   {{0x23602d2b,0x395c0066,0xa2c46b26,0x0574007b}},	//   _čija_, _utus_, ियन्, نمية_, 
   {{0xdff002ab,0x399800d8,0xa3cc00cd,0x00000000}},	//   घनाद_, mês_, रमं_, --, 
   {{0x4ac403f3,0x3998cca2,0x00000000,0x00000000}},	//   _रोडव, lês_, --, --, 
   {{0xbcf9cca5,0x7ae00051,0x00000000,0x00000000}},	//   _kwés, ênth, --, --, 
   {{0x39980261,0x95e800dd,0xcad4011a,0x76580205}},	//   nês_, _تباہ_, דורת_, mcuy, 
   {{0x7659cca6,0x016002e8,0x63380092,0x9424009b}},	//   lcuy, ркро, _የኃጢአ, _имле, 
   {{0xa3cc00dc,0x00000000,0x00000000,0x00000000}},	//   रमः_, --, --, --, 
   {{0xb8d00003,0xbdd80066,0x51540022,0x76580790}},	//   _ཟི_, _ngès, _итоу, ncuy, 
   {{0xdcfc00fd,0x00000000,0x00000000,0x00000000}},	// [334c0] _assı, --, --, --, 
   {{0xbdd8067c,0xbc600114,0x00000000,0x00000000}},	//   _agès, ивук, --, --, 
   {{0xbcf80a40,0x57bc07d0,0x00000000,0x00000000}},	//   _stéc, ्मोह, --, --, 
   {{0x09e47676,0xca080120,0x00000000,0x00000000}},	//   коен, мнеж_, --, --, 
   {{0x9e7000cf,0xc330011a,0x00000000,0x00000000}},	//   _دۇقت, בוא_, --, --, 
   {{0xab640790,0x50c000cd,0x00000000,0x00000000}},	//   ttüğ, शयिष, --, --, 
   {{0x8b25cca7,0xca740220,0x799802d0,0x7d08067c}},	//   _адве, _аузы, _equw, ègse, 
   {{0x399806ed,0xf6e1cca8,0x88b0009e,0x00000000}},	//   bês_, ицын, চাইক, --, 
   {{0x399803b7,0xa2d0043e,0x15e800bc,0x2b9c0419}},	//   cês_, धास्, टनगर_, líc_, 
   {{0xddcc0064,0x00000000,0x00000000,0x00000000}},	//   naaš, --, --, --, 
   {{0xf41c0724,0x2b9c0030,0x973000ec,0x3514009d}},	//   şän_, níc_, _ڏکيا, тжээ_, 
   {{0x05100154,0x85e80120,0x00000000,0x00000000}},	//   হতের_, _одев_, --, --, 
   {{0x9f45cca9,0x7ae00120,0xddcc0113,0xf2040139}},	//   álí_, ênti, kaaš, аяро, 
   {{0x241807e6,0x00000000,0x00000000,0x00000000}},	//   _полы_, --, --, --, 
   {{0xbdd80066,0xa3cc05f9,0x9f44022a,0x2b9c022a}},	//   _ngèr, _रपट_, šlí_, jíc_, 
   {{0xbd680640,0x332800c7,0xdb04007c,0x2b9c0419}},	//   држе_, _ицын_, lvhö, díc_, 
   {{0x4bc001e0,0x645c0165,0x00000000,0x00000000}},	// [334d0] ҙөрг, ñriw, --, --, 
   {{0xb5dc015b,0x2c7c012c,0x270c00bc,0x399800d8}},	//   _বেঁচ, vádí_, měnu_, vês_, 
   {{0xad241c02,0x66f400e1,0xab640205,0x00000000}},	//   جىلى, ेफाक_, ytüş, --, 
   {{0xbcf800c6,0x39980798,0xdea06813,0x5b1402dc}},	//   _dtéa, tês_, _دیری, ымет, 
   {{0x38706788,0x00000000,0x00000000,0x00000000}},	//   иқат, --, --, --, 
   {{0x6935ccaa,0xa924155b,0x2b9c0419,0x6ce45e82}},	//   анчу, аділ, bíc_, _кісе, 
   {{0xbdd804cc,0x2728002d,0x6b9c02d0,0x399800d8}},	//   _tgès, jûns_, _gqrg, sês_, 
   {{0x7bc4031c,0x2728002d,0x00000000,0x00000000}},	//   _irju, dûns_, --, --, 
   {{0x79980784,0x65f801c0,0x765803e0,0xab6434e5}},	//   _uquw, вээр_, rcuy, rtüş, 
   {{0x993423bb,0x2728000f,0x7bc40254,0x00000000}},	//   _صفات, fûns_, _krju, --, 
   {{0x934400ea,0x95b40022,0x00000000,0x00000000}},	//   лное, трқә, --, --, 
   {{0x58840efb,0xdb14056a,0x4ebc00cc,0x00000000}},	//   _шыға, _arzú, _ইক্ল, --, 
   {{0xd4a409a5,0x00000000,0x00000000,0x00000000}},	//   _билй, --, --, --, 
   {{0x63b80175,0x13040116,0x7bc5ccab,0x00000000}},	//   _fsvn, _әзим, _orju, --, 
   {{0x049000db,0xa2d0193d,0xbf1c0073,0xdb1400e5}},	//   _الىح, धाश्, पवून_, _eszé, 
   {{0x2b9c0316,0x27f80139,0xd06003e3,0x11d400d4}},	//   víc_, _ürne_, _ətəy, _біор, 
   {{0x7bc40fb0,0x9f50e8c4,0x831446c1,0xbcf8205e}},	// [334e0] _arju, azzà_, _حقير_, _stéa, 
   {{0x8c440724,0x01f8011a,0x2b9c0419,0x00000000}},	//   гезе, _נפיל, tíc_, --, 
   {{0x409800c8,0x5c547dfe,0x00000000,0x00000000}},	//   _אביס, ртуф, --, --, 
   {{0x9b240d30,0xfb84036b,0x79880042,0xda6401f7}},	//   афіл, ادلی, frgw, لاهي, 
   {{0x38c8d36d,0x2b9c031d,0xbcf80309,0x7bc5ccac}},	//   کانی_, síc_, _itén, _erju, 
   {{0xc5f000cc,0x1c1c000d,0x00000000,0x00000000}},	//   _জখলা_, _बँचल_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf1d407b7,0x77940395,0x00000000,0x00000000}},	//   दमान, укър_, --, --, 
   {{0xc32c0058,0x49c809a5,0x00000000,0x00000000}},	//   ۋەت_, _ялан_, --, --, 
   {{0xdcec00f3,0x00000000,0x00000000,0x00000000}},	//   rsać, --, --, --, 
   {{0xbcf8003e,0x24180d33,0xc6a400d8,0xe2f800d4}},	//   _otén, тоны_, _брли, вені_, 
   {{0xa159ccad,0xa2c44cf3,0x940403b9,0x00000000}},	//   каму_, рәкк, nglə_, --, 
   {{0x870401ed,0xe7ec00bc,0xa4d400d4,0x00000000}},	//   _لڑکے_, जनका_, _волі, --, 
   {{0xbcf9ccae,0x14f40228,0x1c1c0037,0x00000000}},	//   _atén, _ۅزۉڭ, _बुझल_, --, 
   {{0x96a001ad,0xb1e40075,0x83840153,0x00000000}},	//   क्वॉ, _һәрқ, _сыле, --, 
   {{0x636001f2,0x00000000,0x00000000,0x00000000}},	//   _ịnwa, --, --, --, 
   {{0x5c75ccaf,0xdd95ccb0,0x442c0142,0xa3cc000d}},	// [334f0] илат, разы, _hyf_, रमक_, 
   {{0xbcf80296,0x99e4010e,0x99d40efc,0x68f802d0}},	//   _etén, _jyňň, یقات, jhvd, 
   {{0x442c0649,0x9f340816,0xdfd56aa7,0x00000000}},	//   _jyf_, _вені, _тоны, --, 
   {{0xdd95ccb1,0x00000000,0x00000000,0x00000000}},	//   _камы, --, --, --, 
   {{0x442dccb2,0x81e4015b,0x7de4443f,0x13ac0154}},	//   _lyf_, _যেত_, _сінд, গিয়, 
   {{0xd945ccb3,0x7f4c003a,0x68f80175,0x00000000}},	//   шели, _hicq, ghvd, --, 
   {{0xe3e403f4,0x442c05da,0xbeb80200,0xa98800db}},	//   _ফেসব, _nyf_, _akëi, _ۅۅنۅ_, 
   {{0xe6b400d1,0x69e800ae,0x00000000,0x00000000}},	//   ملىگ, íseá, --, --, 
   {{0x1959ccb4,0x7f54003a,0xadc40022,0x98b800ee}},	//   _разы_, _luxq, _osẽt, _илат_, 
   {{0x9f44145e,0xb4bc000d,0x61fc00ef,0x00000000}},	//   âlê_, ँये_, dzsl, --, 
   {{0x53a483f9,0x442c03cb,0xd76002f2,0x00000000}},	//   шанб, _cyf_, _بۆبی, --, 
   {{0x442c0142,0xdcec00c0,0x00000000,0x00000000}},	//   _dyf_, praė, --, --, 
   {{0x7f5407ea,0xd9e407f7,0x00000000,0x00000000}},	//   _auxq, कहित_, --, --, 
   {{0x67241591,0xbcf9ccb5,0x96a002ab,0xd39400fb}},	//   čije, _stén, क्रॉ, _кәмә_, 
   {{0x6ef9ccb6,0x442c0042,0x00000000,0x00000000}},	//   _líbe, _gyf_, --, --, 
   {{0x7f54003a,0x37b400fe,0xda143b16,0x00000000}},	//   _duxq, _অপাৰ, तपात_, --, 
   {{0x9f45ccb7,0x98a40100,0xd13000c6,0xc0f80023}},	// [33500] álá_, _aklč_, _ومع_, ፊሮም_, 
   {{0x4fe9ccb8,0x00000000,0x00000000,0x00000000}},	//   _амон_, --, --, --, 
   {{0x1d1810f5,0x8b2402bf,0x9f441d55,0x4b4401e2}},	//   ують_, адже, šlá_, لګرۍ_, 
   {{0x7f4c030a,0x00000000,0x00000000,0x00000000}},	//   _gicq, --, --, --, 
   {{0xc3300375,0x6ef801e7,0xc9b40063,0xbd4000db}},	//   קוד_, _cíbe, рсењ, حنەي, 
   {{0x2d81ccb9,0x6ef801e7,0x98a40051,0xc234011a}},	//   msie_, _díbe, _bhlđ_, ברנו_, 
   {{0x2d804604,0xc60c00dc,0xc7b801f4,0x00000000}},	//   lsie_, ाप्य_, тёл_, --, 
   {{0x3ab00139,0x09e41fbe,0x896400d4,0x00000000}},	//   _мәчт, _кобн, _вкаж, --, 
   {{0x2d81ccba,0x1dc81944,0x7d040286,0x69b0033f}},	//   nsie_, रियत, _ymjs, _आईटी, 
   {{0x2d81ccbb,0x442c0175,0x38c80133,0xdb2401e1}},	//   isie_, _pyf_, _لامی_, _ìpòn, 
   {{0x2d800f91,0xfc54010f,0x15d800e5,0xc30400ae}},	//   hsie_, יביש_, ندیں_, لبحو, 
   {{0x2d800591,0x442c0151,0x06080032,0x3444010b}},	//   ksie_, _vyf_, _инек_, шчын_, 
   {{0x2d8001f1,0x442c00a9,0xfe7c06af,0xf3180107}},	//   jsie_, _wyf_, _loïc_, рояш_, 
   {{0x2d81ccbc,0x7f4c16b8,0x442c0042,0x34905d4e}},	//   dsie_, _sicq, _tyf_, _дашр, 
   {{0x2d800134,0x7f4c030a,0x343401d9,0x6348012d}},	//   esie_, _picq, _پٲٹھ_, _lśni, 
   {{0xfeb90220,0xc10001c6,0x33d808c3,0xddcc00b8}},	//   خاست_, сүүл, _יחוד, ccaś, 
   {{0x7c640137,0x2d800083,0x25ec033f,0x00000000}},	// [33510] لاال, gsie_, आईटी_, --, 
   {{0xacf80228,0x6ef800d0,0x69b012eb,0xfc64010b}},	//   ануу_, _ríbe, _आईजी, ръан, 
   {{0xba75aa12,0x2d81a1f5,0x6ef8032e,0x00000000}},	//   لاشت, asie_, _síbe, --, 
   {{0x2b59ccbd,0x19590917,0x2d8000d7,0x59b4012d}},	//   _durc_, гады_, bsie_, _आईआर, 
   {{0x0ba407dd,0x2d8000d0,0x6ef802d2,0x5df8010f}},	//   _қырҭ, csie_, _fíbb, _עפֿנ, 
   {{0x7c3801e4,0xbd3402dd,0x00000000,0x00000000}},	//   _ŝuru, _түзу_, --, --, 
   {{0xd7c81176,0x372000d1,0x37b400cc,0x8c38014b}},	//   اوبه_, يوتې, _অপহৰ, _борӣ_, 
   {{0xb2f449a6,0x6ef80d12,0xba745e75,0x7018011a}},	//   _བཞེང_, _tíbe, _خاست, יחוד_, 
   {{0x7cf80356,0xe3e40154,0x4ed8010f,0x5504004e}},	//   _vîrf, _ফেলব, אַינ, йпиб, 
   {{0x25ec05d7,0xf84401af,0x00000000,0x00000000}},	//   आईजी_, _күлд_, --, --, 
   {{0xf8b005f9,0x2d8000d0,0x00000000,0x00000000}},	//   ंजीप, zsie_, --, --, 
   {{0x26f8004b,0xbcf91308,0x15f0012d,0x2d81ab3d}},	//   _پرمخ_, _stél, आईआर_, ysie_, 
   {{0xbcf8003e,0x636000b4,0xd7c400cd,0x0654011a}},	//   _atém, _ịnta, विवच, _הינך_, 
   {{0x2d81ccbe,0xd00804b3,0x00000000,0x00000000}},	//   vsie_, геге_, --, --, 
   {{0x2d81136d,0x1f58084c,0x4478010f,0x00000000}},	//   wsie_, ишть_, _ענקע, --, 
   {{0x2d81ccbf,0x00000000,0x00000000,0x00000000}},	//   tsie_, --, --, --, 
   {{0x0dc95a8e,0x82940302,0xbcf80022,0x4c85ccc0}},	// [33520] ылай_, _הדפס_, _etém, йлав, 
   {{0x2d81ccc1,0xbeb88a64,0x00000000,0x00000000}},	//   rsie_, _njëf, --, --, 
   {{0x2d81ccc2,0x00000000,0x00000000,0x00000000}},	//   ssie_, --, --, --, 
   {{0x2d81ccc3,0x4a4553d2,0xefe80092,0x00000000}},	//   psie_, бнев, ኘነው_, --, 
   {{0x98a40135,0xdcec010f,0x690801d5,0x34b407b7}},	//   _silġ_, lsaĝ, аrdа, _असूद, 
   {{0x2b59ccc4,0x00000000,0x00000000,0x00000000}},	//   _turc_, --, --, --, 
   {{0xdcec01e4,0xfd4c00cd,0xd90c2d56,0xb760004e}},	//   nsaĝ, _nikṛ, خیل_, птый, 
   {{0xc79400c7,0xd90daf6a,0xd7f801ec,0x00000000}},	//   арҩы, _یین_, шуі_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x161413bd,0x00000000,0x00000000,0x00000000}},	//   تسىڭ, --, --, --, 
   {{0x46a401ee,0xa2c40a8a,0xa8240066,0x00000000}},	//   _гаев, ियल्, _بکشن, --, 
   {{0x41e402bf,0x6fcc6bf2,0x7cf8054e,0xbc180115}},	//   біга, हिनू, _tîrg, רוטש, 
   {{0xa1587a94,0x774400db,0xbb38008f,0xe1384f32}},	//   рагу_, _اعلە, טעטי, измі_, 
   {{0x26c40158,0x00000000,0x00000000,0x00000000}},	//   ldmo_, --, --, --, 
   {{0x2004026c,0xf044084c,0x00000000,0x00000000}},	//   àli_, зэто, --, --, 
   {{0x26c403cd,0x00000000,0x00000000,0x00000000}},	//   ndmo_, --, --, --, 
   {{0x9344215c,0x00000000,0x00000000,0x00000000}},	// [33530] _بىيۇ, --, --, --, 
   {{0x2294221d,0x7cf800e4,0xfd1000ae,0x00000000}},	//   _الکس, _oîre, أجر_, --, 
   {{0x25a5ccc5,0xbeb81bce,0x79842d40,0xfb840166}},	//   html_, _njëg, ﻗﺴﯩﺰ_, сызн, 
   {{0xf2d400c8,0xac58020a,0x09b000fe,0x9f34187f}},	//   ּעס_, _ҳарф_, চিনা, _фемі, 
   {{0xb2bc00c8,0x79a418d9,0x7e7c3959,0x98a400ef}},	//   טמאר, срее, maqp, _aklā_, 
   {{0x7e7c0784,0x69c401e4,0x00000000,0x00000000}},	//   laqp, ĥiep, --, --, 
   {{0x2bc80798,0x673c00b8,0x00000000,0x00000000}},	//   _луто_, _ūrja, --, --, 
   {{0x7e7cc624,0xbeb80200,0x00000000,0x00000000}},	//   naqp, _ikës, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7e7c1364,0x6ef8043b,0x672400f3,0xd8f402f2}},	//   haqp, _míba, čija, _بزرک, 
   {{0x7e7c0986,0x00000000,0x00000000,0x00000000}},	//   kaqp, --, --, --, 
   {{0xfd4c00dc,0x00000000,0x00000000,0x00000000}},	//   _vikṛ, --, --, --, 
   {{0x02000d30,0x7e7c047e,0x55e40b01,0x00000000}},	//   дзян, daqp, _фолб, --, 
   {{0xd46800cf,0xfd4c0055,0x00000000,0x00000000}},	//   _тике_, _tikṛ, --, --, 
   {{0xbcf80022,0x634800cd,0x13a40244,0x00000000}},	//   _eték, _aśnu, _بۆجی_, --, 
   {{0x9f5801ed,0xbeb883cc,0xdcec01e4,0x00000000}},	//   ázás_, _njëd, rsaĝ, --, 
   {{0x23601326,0x3f800037,0x6e6400f7,0x4bd800ec}},	// [33540] _čiji_, asju_, _ۉندۅ, ڌباد_, 
   {{0xdb140086,0xbeb80200,0x00000000,0x00000000}},	//   _erzü, _skët, --, --, 
   {{0x31a50fe1,0x00000000,0x00000000,0x00000000}},	//   löz_, --, --, --, 
   {{0x49c809a5,0xa6f4009e,0x00000000,0x00000000}},	//   илен_, _ছদ্ম_, --, --, 
   {{0x31a5ccc6,0x09b000cc,0x273400d1,0x00000000}},	//   nöz_, চিভা, ۋىتس, --, 
   {{0x4789ccc7,0xdcec2ca8,0x00000000,0x00000000}},	//   асим_, msağ, --, --, 
   {{0x31a401ed,0xdcec0166,0x00000000,0x00000000}},	//   höz_, lsağ, --, --, 
   {{0x27e00989,0x31a401d3,0x00000000,0x00000000}},	//   ćin_, köz_, --, --, 
   {{0xf98001c6,0x46a42894,0xdcec03b9,0x00000000}},	//   _огто, क्षह, nsağ, --, 
   {{0x69c0066d,0x363000d1,0x00000000,0x00000000}},	//   _isme, برىس, --, --, 
   {{0x68e80158,0x290c2d74,0x7e7c03f0,0x4adc00c5}},	//   _iodd, _imda_, yaqp, _नचाव, 
   {{0x4308f46d,0x00000000,0x00000000,0x00000000}},	//   рхом_, --, --, --, 
   {{0x68e82776,0x31a41934,0xbeb80022,0xc7940451}},	//   _kodd, göz_, _okër, _اھڙا_, 
   {{0x68e80fac,0x456001d9,0x7e7c0113,0xf99005d0}},	//   _jodd, _ٹھکہ, waqp, ורש_, 
   {{0x68e9ccc8,0x290dccc9,0x9f44145e,0x6ef800d2}},	//   _modd, _mmda_, âlï_, _síba, 
   {{0x69c1ccca,0x83440014,0x25600100,0xbcf800c7}},	//   _osme, _بختٕ, _kòl_, _kuég, 
   {{0x7e7c1bb7,0xfd1c0268,0x290c0109,0x68e80067}},	// [33550] raqp, _avìa_, _omda_, _oodd, 
   {{0x68e9cccb,0x256056ec,0x629c0627,0x7e7db26b}},	//   _nodd, _mòl_, lgso, saqp, 
   {{0x69c1cccc,0x7e7c0986,0xab8400d8,0x00000000}},	//   _asme, paqp, дучк, --, 
   {{0x7e7c3209,0x6ef800d2,0x60c402f6,0xae0c65d9}},	//   qaqp, _tíba, _hahm, _सेवन_, 
   {{0x69c00998,0x1869cccd,0x7cf80356,0x60c401f4}},	//   _csme, бали_, _cîrc, _kahm, 
   {{0x68e9ccce,0x60c5cccf,0xd7f000e4,0xdb14033f}},	//   _codd, _jahm, _ag̃a_, _przó, 
   {{0x69c1ccd0,0xac180117,0x31a40205,0x00000000}},	//   _esme, _дору_, zöz_, --, 
   {{0x60c4016d,0x2560033b,0x290c07de,0x7c640131}},	//   _lahm, _bòl_, _emda_, _داڭل, 
   {{0x68e802a4,0xbcf800f2,0x7af9ccd1,0x25600ba1}},	//   _fodd, _atéi, _ilut, _còl_, 
   {{0x7af800fc,0x60c4de34,0x25600ba1,0x629c178a}},	//   _hlut, _nahm, _dòl_, egso, 
   {{0x256000a3,0x00000000,0x00000000,0x00000000}},	//   _eòl_, --, --, --, 
   {{0x256056ec,0x629c143a,0x883804ae,0x92b400c6}},	//   _fòl_, ggso, _התעו, أحدا, 
   {{0x60c5ccd2,0x7cf05d6d,0x256002bd,0xbcf80129}},	//   _bahm, _kırı, _gòl_, _guég, 
   {{0x7af9ccd3,0x63540092,0x61e80254,0x31a40205}},	//   _llut, _ለኃጢአ, äela, röz_, 
   {{0x60c40399,0xd01007d6,0x31a40790,0x7cf02ca8}},	//   _dahm, رلر_, söz_, _mırı, 
   {{0xff040276,0x3a3c00a2,0x8d640153,0xdcec08a9}},	//   песк_, _ozup_, звае, tsağ, 
   {{0x60c5ccd4,0xae0c06ab,0x00000000,0x00000000}},	// [33560] _fahm, _सेशन_, --, --, 
   {{0x38ac05d1,0x91c401af,0xdcec6b5f,0x00000000}},	//   nırı_, _дљүл, rsağ, --, 
   {{0x68e9ccd5,0x7af9ccd6,0xdb05ccd7,0x96bc0316}},	//   _rodd, _blut, othè, ्याउ, 
   {{0xdb05ccd8,0x60c40fe1,0x69c00175,0x62000c44}},	//   nthè, _zahm, _psme, _özlü, 
   {{0x38ac03ee,0x68e9ccd9,0x7af808c2,0x60c4014f}},	//   kırı_, _podd, _dlut, _yahm, 
   {{0x7af9ccda,0x68e93d3c,0xbdd80066,0x69c0019b}},	//   _elut, _qodd, _ngèy, _vsme, 
   {{0x7af831d8,0x2561185f,0xf76c034c,0x68e81a19}},	//   _flut, _sòl_, هاي_, _vodd, 
   {{0x67241505,0x290c0098,0x2561ccdb,0x69c00219}},	//   čijo, _wmda_, _pòl_, _tsme, 
   {{0xbcf804c4,0x69c1ccdc,0x7cf00259,0x68e81e15}},	//   _stéi, _usme, _fırı, _todd, 
   {{0x4904212d,0x290dccdd,0x25603c51,0x9f45ccde}},	//   _عواق, _umda_, _vòl_, álú_, 
   {{0xa294063b,0x25600699,0x22940276,0x6ef80241}},	//   мані, _wòl_, миня, _níbo, 
   {{0x60c5ccdf,0x25600100,0x9f440419,0x998c0210}},	//   _sahm, _tòl_, šlú_, _rzeź_, 
   {{0x236008ad,0x60c400b8,0x7cf00139,0x4a980023}},	//   _čiju_, _pahm, _yırı, ቀሳቓሲ_, 
   {{0x60c4047e,0x7cf80022,0x291c0162,0x7cf006be}},	//   _qahm, _oîra, nnva_, _xırı, 
   {{0x443807ae,0xbcf800d8,0x60c5cce0,0x7a4001e1}},	//   _áp_, _utéi, _vahm, _kìtí, 
   {{0xf41c0724,0x60c4020c,0x2349cce1,0x961c00e2}},	//   ğät_, _wahm, _بستی_, saņe, 
   {{0x60c50b9a,0x5d55b0d7,0x628dcce2,0xddddcce3}},	// [33570] _tahm, дкат, _idao, _iesū, 
   {{0x7af86afa,0x81400131,0x00000000,0x00000000}},	//   _slut, _سۆزن, --, --, 
   {{0x628c03d1,0xede40327,0x00000000,0x00000000}},	//   _kdao, ཧཱུྃ, --, --, 
   {{0xdb05cce4,0x88a803d4,0xbcf8004a,0x7cf15d27}},	//   othé, _গোলক, _suéd, _sırı, 
   {{0xa2a5cce5,0x998801a2,0xdb044afb,0xfe7400ee}},	//   _कान्, ťaž_, nthé, _мүң_, 
   {{0x7cf1839d,0xbcf825e6,0x291c0115,0x80c007f7}},	//   _qırı, _quéd, gnva_, िएटे, 
   {{0x7af9cce6,0xdb040129,0x5b04009f,0x00000000}},	//   _tlut, ythè, _قِسم, --, 
   {{0x7af9cce7,0x628dcce8,0xdddc00de,0x6d6802d2}},	//   _ulut, _ndao, _nesū, _órað, 
   {{0x7cf00724,0x38ac0baa,0x9178004d,0x00000000}},	//   _tırı, tırı_, _mật_, --, 
   {{0x628dcce9,0xbcf80124,0xb8649924,0xdb040332}},	//   _adao, _etév, _رائو, dthé, 
   {{0x6ef9ccea,0xccf005e1,0x7a4001e1,0xd7c000c5}},	//   _bíbl, דכי_, _fìtí, _शनिच, 
   {{0x395c00af,0x00000000,0x00000000,0x00000000}},	//   _kuus_, --, --, --, 
   {{0xdee802d3,0xd174010b,0x395d7e3e,0x2af0000d}},	//   _ዘሎካ_, ьыны, _juus_, _आवसु_, 
   {{0x395c291e,0x6ef8067c,0xdb040214,0xe7e4012c}},	//   _muus_, _píbo, sthè, _कपमा_, 
   {{0xfe7c017a,0x91780208,0x3f6400d8,0x00000000}},	//   _beï_, _bật_, дисо_, --, 
   {{0x6ef80789,0x00000000,0x00000000,0x00000000}},	//   _víbo, --, --, --, 
   {{0x395c9546,0xe2a801c8,0x00000000,0x00000000}},	// [33580] _nuus_, _راين_, --, --, 
   {{0x4c141afc,0xdb080327,0xfcf40023,0x66d4022e}},	//   وباس, _གཏུཌ_, _ዉሽጢ_, hоkа, 
   {{0x395c0393,0xa2a40a5a,0xcf4400db,0x00000000}},	//   _auus_, _काम्, _оной, --, 
   {{0x31602829,0xfe7c017a,0x8d64010b,0x94100213}},	//   _kuiz_, _geï_, _овме, üzə_, 
   {{0x31616223,0x09482678,0x0928004b,0x09b8007b}},	//   _juiz_, очки_, يستي_, تطاع_, 
   {{0x8b640058,0xa2a40316,0x395c226d,0x316005b1}},	//   _يازم, _काभ्, _duus_, _muiz_, 
   {{0x3161cceb,0xfbc01ee3,0x00000000,0x00000000}},	//   _luiz_, _ибро, --, --, 
   {{0x395c0036,0x4c8001b9,0xf76c1a4b,0x00000000}},	//   _fuus_, _سیچق, جاو_, --, 
   {{0x395dccec,0xfcf402d3,0x7cf80356,0xddcc054e}},	//   _guus_, _ዉሽጥ_, _mîrn, mbaţ, 
   {{0x628c01ab,0xbcf806af,0x838402dd,0x87d80345}},	//   _sdao, _tuée, мыме, _وباس_, 
   {{0x38c83821,0x6ef801e7,0x00000000,0x00000000}},	//   _باقی_, _píbl, --, --, 
   {{0xa19459e6,0x395c3012,0x7d0801d3,0x6ef80166}},	//   намч, _yuus_, égsz, _qíbl, 
   {{0xa7fc0724,0xe7e54d39,0x395c0de2,0xbeb80240}},	//   _ofık, _कपडा_, _xuus_, _njëa, 
   {{0xdb05cced,0x6d4002b1,0x02a00241,0x00000000}},	//   rthé, _ūman, _iyọọ, --, 
   {{0x961dc925,0xe1f80006,0xdb047f70,0x74980375}},	//   maņa, šų_, sthé, _ויופ, 
   {{0x628c090c,0x673c0055,0x00000000,0x00000000}},	//   _udao, _ūrjj, --, --, 
   {{0x9178004d,0xe3e403d4,0xc059184a,0xc0ec0092}},	// [33590] _vật_, _ফেচব, _мін_, ቀሳል_, 
   {{0xac741da8,0x395c602e,0xa2a40073,0x5d3400e5}},	//   نامش, _ruus_, _काड्, رفائ, 
   {{0x395dccee,0xbcf800e4,0x91780051,0x3f840241}},	//   _suus_, _puéb, _tật_, _ìnu_, 
   {{0xbcf820ef,0xdcec0063,0x395c0de2,0x2ef40166}},	//   _québ, mpač, _puus_, _азюр, 
   {{0x31600077,0x18683dab,0x395c0067,0x496402dd}},	//   _xuiz_, пали_, _quus_, енің, 
   {{0x961c0bc9,0xe3e402f5,0x270c00bc,0x636001f2}},	//   jaņa, _ফেছব, měny_, ịnye, 
   {{0xfaa40166,0x6c540006,0x00000000,0x00000000}},	//   _ошан, _акру, --, --, 
   {{0x7cf8019f,0x395dccef,0xbcf800e4,0xe6b40131}},	//   _kîro, _tuus_, _etét, نلىگ, 
   {{0x270c00bc,0x941800ac,0x61e8005b,0x00000000}},	//   něny_, əsə_, äell, --, 
   {{0xa8980372,0x95980092,0x4dd8011a,0x00000000}},	//   _окуу_, ፊነቱን_, פחתו, --, 
   {{0x68380332,0xdee00092,0x00000000,0x00000000}},	//   rúdú, ነሱን_, --, --, 
   {{0xa2a433af,0xa6c80116,0x00000000,0x00000000}},	//   _काण्, _يولل_, --, --, 
   {{0x31605f5c,0xdcec793e,0xa23401c6,0x65c401af}},	//   _quiz_, ltaĵ, вэрш, _аңым_, 
   {{0xa2a401f9,0x270c013a,0x00000000,0x00000000}},	//   _काथ्, děny_, --, --, 
   {{0x41241b74,0xdcec008f,0xb400004e,0x40440108}},	//   хоро_, ntaĵ, _рүнд, епро_, 
   {{0x2334035b,0xdcec00df,0x1e94084c,0x00000000}},	//   _ихыр, itaĵ, крур, --, 
   {{0xe1943bfd,0xa2a46236,0x8e0806ed,0x00000000}},	// [335a0] _ирээ, _कात्, чнав_, --, 
   {{0xdcec008f,0x96d0000d,0x00000000,0x00000000}},	//   ktaĵ, _दोसउ, --, --, 
   {{0xbcf80120,0xdcec01e4,0x24ac00cc,0x00000000}},	//   _suéc, jtaĵ, _কোঁহ, --, 
   {{0xbcf80008,0xf645ccf0,0x270c0118,0x0ae801f4}},	//   _stét, _مئ_, běny_, ядей_, 
   {{0xddcc084c,0x961c0054,0xdcec01e4,0x6f0401c3}},	//   rbaţ, yaņa, etaĵ, mhic, 
   {{0xd9b008b0,0x6f05ccf1,0xdcec01e4,0xc7c40484}},	//   شەمد, lhic, ftaĵ, есии, 
   {{0xd2680020,0xddcc0552,0x00000000,0x00000000}},	//   ዱስትሪ_, mbaš, --, --, 
   {{0x6f05ccf2,0x52c800bc,0xddcc0432,0x00000000}},	//   nhic, ियोस, lbaš, --, 
   {{0xbcf8753e,0x6f0401ab,0xdcec02f0,0x3a2001d5}},	//   _itér, ihic, zpač, _бмтг, 
   {{0xc429ccf3,0x2b38063f,0xbeb81bce,0x6f0508b4}},	//   зюме_, _ọgụụ_, _njën, hhic, 
   {{0x961c0bc9,0x6f041cea,0x37ac0154,0x451003d4}},	//   raņa, khic, কিউর, সকলক_, 
   {{0xc64400cf,0x00000000,0x00000000,0x00000000}},	//   _كئشى, --, --, --, 
   {{0x6f05ccf4,0x21300489,0xf740030d,0x00000000}},	//   dhic, tozh_, _сецо, --, 
   {{0x961c0bc9,0xdcec0327,0x80c8012d,0xdb040142}},	//   qaņa, kraġ, ायें, ythï, 
   {{0xbeb8002e,0xddcc01fa,0x6f040332,0x7534010f}},	//   _djën, dbaš, fhic, _ראוד_, 
   {{0x6f05ccf5,0xc1002063,0x4cc8015b,0x270c0118}},	//   ghic, түүл, রাফু, těny_, 
   {{0xad24425b,0x6ef800ae,0x40840117,0x00000000}},	// [335b0] گىلى, _míbh, _пунб, --, 
   {{0x6ef82959,0xbcf801e1,0x5ff40124,0xbeb80023}},	//   _líbh, _atér, _азоу, _gjën, 
   {{0x99bc0729,0xad244da8,0x6f05ccf6,0x3dc801ec}},	//   _আপেক, دىلى, bhic, _ﻗﺴﯩﺘ, 
   {{0x9e141feb,0xec2800be,0x00000000,0x00000000}},	//   _адмі, ركنى_, --, --, 
   {{0xab640034,0xcdc00131,0x18a40116,0x00000000}},	//   ężar, _вәхп, валм, --, 
   {{0xbcf83822,0x7ae400f1,0x00000000,0x00000000}},	//   _etér, _ګورې_, --, --, 
   {{0x1cc0031c,0xbcf80129,0xd52c01e1,0x279400ee}},	//   _ཁྲར_, _guéa, _lọ́y, гшыр, 
   {{0xdb140036,0xdcec010f,0x7bc5ccf7,0xd7f80124}},	//   _opzé, rtaĵ, _isju, зуҩ_, 
   {{0xdcec008f,0x7bc40158,0x6ef800ae,0xd548084c}},	//   staĵ, _hsju, _díbh, мпие_, 
   {{0xd9540cd2,0xf8040261,0xdcec00df,0xdb0401e7}},	//   _شناخ, _пчен, ptaĵ, ithí, 
   {{0x9eb40004,0xdb0401e7,0x00000000,0x00000000}},	//   _dåº_, hthí, --, --, 
   {{0x46102c26,0x2ee000cd,0x00000000,0x00000000}},	//   اویر, _पचेत, --, --, 
   {{0x71840220,0x687c001f,0x7c20002d,0x9f4400bc}},	//   ықпе, _ጥንቃቄ_, ûnrj, álý_, 
   {{0xf4841679,0x6f05ccf8,0x00000000,0x00000000}},	//   _чудн, whic, --, --, 
   {{0x6f05ccf9,0x0080a229,0x9f440306,0xc0e002e8}},	//   thic, рлсо, šlý_, шорк, 
   {{0xedf400ec,0xff20004e,0x00000000,0x00000000}},	//   هيزگ, амсо, --, --, 
   {{0x910480b2,0x7bc400c5,0x833408a8,0x7d1403ac}},	// [335c0] _аппе, _asju, _באקס_, fixs, 
   {{0x67243ad4,0x6f05ccfa,0xbcf8859d,0x7d14058a}},	//   čiji, shic, _stér, gixs, 
   {{0x26181d8a,0x6ef9ccfb,0x6f05ccfc,0xbcf8003e}},	//   _बेनी_, _líbi, phic, _ptér, 
   {{0xea2401c0,0x6f040455,0x0d8401d5,0xdcec025c}},	//   лчлү, qhic, _илмн, rraġ, 
   {{0xe89518cd,0xa2a4dadd,0xfaa1ccfd,0x7bc408a5}},	//   галь, _कास्, рачо, _esju, 
   {{0x6ef819e4,0x1cc00327,0x00000000,0x00000000}},	//   _síbh, _ཁིར_, --, --, 
   {{0x6d5dccfe,0x38c85022,0xbcf800e4,0x00000000}},	//   _iira, بانی_, _kuén, --, 
   {{0xbeb9ccff,0xbcf8004a,0x6ef806ea,0xda64007b}},	//   _njël, _utér, _bíbi, _ماكي, 
   {{0xa534311b,0x00000000,0x00000000,0x00000000}},	//   лнич, --, --, --, 
   {{0x6d5dcd00,0xc795cd01,0x6ef801e7,0x261800af}},	//   _jira, _арды, _díbi, _बइठी_, 
   {{0xc32c24a7,0xa31832b0,0x00000000,0x00000000}},	//   يەت_, ежну_, --, --, 
   {{0x6d5dcd02,0xd79800ec,0x00000000,0x00000000}},	//   _lira, _سمهڻ_, --, --, 
   {{0x6595cd03,0xdee802d3,0x97000131,0x6d5dcd04}},	//   _салу, _ዘሎኻ_, _دېيى, _oira, 
   {{0xa2a402db,0x6d5dcd05,0xe1340276,0x00000000}},	//   _काव्, _nira, унгы, --, 
   {{0xa43800d6,0xf558b8b4,0x00000000,0x00000000}},	//   _язку_, _קדומ, --, --, 
   {{0x6d5dcd06,0xd05c043b,0xbcf81891,0x79880368}},	//   _aira, _kopɛ, _cuén, ysgw, 
   {{0x6d5dcd07,0x5f8000d1,0xc1080150,0x00000000}},	// [335d0] _bira, _گۇزە, _жэне_, --, 
   {{0x6d5dcd08,0xad243955,0xd05c0085,0x636001f2}},	//   _cira, لىقى, _mopɛ, _ịnya, 
   {{0x6d5dcd09,0xbff005f5,0x9f445f48,0xdee802d3}},	//   _dira, _түвш, áló_, _ዘሎኹ_, 
   {{0x6d5dcd0a,0xbcf9cd0b,0x9f50026c,0xbdd8020c}},	//   _eira, _guén, azzò_, _nyèg, 
   {{0x6d5dcd0c,0x78a0074d,0xe9a87ffb,0x99141ed2}},	//   _fira, tgnv, ندون_, лькі, 
   {{0x6d5dcd0d,0x7bc5cd0e,0xd824b5f5,0xe0d4010f}},	//   _gira, _tsju, лдли, רײַ_, 
   {{0x261810b7,0x7ac5cd0f,0x00000000,0x00000000}},	//   _बेबी_, _исае, --, --, 
   {{0x6d5c9390,0xa2a41fe7,0xdb04000f,0x66040327}},	//   _zira, _काष्, sthâ, _żika, 
   {{0x1cc0003d,0x6d5db17d,0x999801d9,0x98b822c3}},	//   _ཁྲོ_, _yira, _سپار_, _плат_, 
   {{0x2ed01533,0x6d5c9d26,0x4644de69,0x13e80b32}},	//   _हफ्त, _xira, ызын_, емой_, 
   {{0xa2a4f1a6,0x5694008e,0x00000000,0x00000000}},	//   _काश्, _бает, --, --, 
   {{0x91e5cd10,0x6ef83756,0x00000000,0x00000000}},	//   гоме, _tíbi, --, --, 
   {{0xa2a40cf1,0xe4c82172,0x00000000,0x00000000}},	//   _कार्, ربین_, --, --, 
   {{0x8fa5aed8,0x22145b0f,0x01602028,0x7cd800e2}},	//   лаге, рфюр, скро, _jārē, 
   {{0x6d5cf213,0x1cc00135,0xbb3000d1,0x00000000}},	//   _rira, _ཁྲེ_, ﺯﻩﻝ_, --, 
   {{0xbcf9cd11,0xbdd80248,0x00000000,0x00000000}},	//   _stép, _oyèd, --, --, 
   {{0x6d5dcd12,0xbeb80240,0x4d49cd13,0x00000000}},	// [335e0] _pira, _gjëm, епан_, --, 
   {{0x6d5dcd14,0x6da404a9,0x02000209,0x90c40108}},	//   _qira, лиға, _ызын, _сбое, 
   {{0x6d5dcd15,0x2f200139,0x00000000,0x00000000}},	//   _vira, bägе_, --, --, 
   {{0x6d5dcd16,0xbf98010f,0x61f800e5,0x00000000}},	//   _wira, _איטש, _öblí, --, 
   {{0x427800c8,0xbcf80309,0x49940902,0x2618000d}},	//   גאנג, _kuél, ушет, _बेढी_, 
   {{0xbeb8044e,0x6d5c03ac,0xba140127,0x00000000}},	//   _njëj, _uira, ديها_, --, 
   {{0xa2a4e5ed,0x1c380166,0x6d4000b8,0x00000000}},	//   _काल्, _аять_, _īmah, --, 
   {{0xa6f54066,0xc6a5cb15,0xdb0401ab,0x28c000bc}},	//   рзиш, урки, cthà, _एसकि, 
   {{0xfaf40375,0x3b040261,0xdb040165,0x00000000}},	//   _עצמי_, _сето_, sthã, --, 
   {{0x2919cd17,0xdcec031c,0x387400d7,0x00000000}},	//   _öra_, rraħ, čerí_, --, 
   {{0x795001f7,0x351401c4,0x00000000,0x00000000}},	//   _اَلا, ужээ_, --, --, 
   {{0xa2a40490,0xdb0401e7,0xab6403e0,0x00000000}},	//   _काळ्, othá, mrüğ, --, 
   {{0xc9240154,0x00000000,0x00000000,0x00000000}},	//   যতীত_, --, --, --, 
   {{0xbcf8568e,0xbeb80023,0x74100451,0x75d001f7}},	//   _cuél, _gjëj, _ڏوها, _ديها, 
   {{0x6ef800d2,0x9f648021,0x2054117e,0x00000000}},	//   _líbu, _ütük_, рквя, --, 
   {{0x2bc80574,0x9f04072d,0x7de40150,0xeea800db}},	//   रबना, جورو, лізд, лтук_, 
   {{0x1cc00135,0x9d150ac0,0x12b400cf,0x8ee4009e}},	// [335f0] _ཁྲུ_, адач, _ئشىڭ, নসংগ, 
   {{0xbcf80165,0x22480ea0,0xfd10007b,0x44cc03b9}},	//   _guél, _izak_, حجر_, nә_, 
   {{0x5158011a,0x00000000,0x00000000,0x00000000}},	//   _שכתו, --, --, --, 
   {{0xdcec01e4,0xdb0402d2,0x00000000,0x00000000}},	//   draĥ, fthá, --, --, 
   {{0xdd0153ba,0x7cd800da,0xbb280075,0xdb0401e7}},	//   ştır, _pārē, ﺧﺸﻰ_, gthá, 
   {{0x6b180dd4,0x2d0400c0,0x00000000,0x00000000}},	//   ྱལཔོ_, _лясг, --, --, 
   {{0xbeb9cd18,0xdb04007b,0x6fd8033f,0x7cd80171}},	//   _njëk, athá, डियं, _vārē, 
   {{0x6ef80077,0x224800fd,0x1a640133,0x00000000}},	//   _fíbu, _ozak_, _ئیشی_, --, 
   {{0x65f8152d,0x46e40e26,0x26181bf9,0x0560010b}},	//   гээр_, рдын_, _बेदी_, овын, 
   {{0x3ea80ac5,0xa56401e2,0xb40000cf,0xd794011c}},	//   _lcct_, حدين, йүлд, _вижъ, 
   {{0xe81c00af,0x00000000,0x00000000,0x00000000}},	//   _भइया_, --, --, --, 
   {{0xa6c800ec,0x00000000,0x00000000,0x00000000}},	//   _مومل_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x961c0227,0x224800f3,0xbdd80241,0x8598011a}},	//   yaņj, _dzak_, _oyèb, _ישנו, 
   {{0xbdd8020c,0x2248009d,0x53a5cd19,0xbeb80200}},	//   _nyèb, _ezak_, _тайб, _gjëk, 
   {{0x527400f7,0x00000000,0x00000000,0x00000000}},	//   _туку, --, --, --, 
   {{0x8d75cd1a,0x0c75cd1b,0x43380302,0x3ea80051}},	// [33600] شاءا, لداد, _בעקב, _dcct_, 
   {{0xc0e0030d,0x00000000,0x00000000,0x00000000}},	//   _доьк, --, --, --, 
   {{0x6ef800d2,0xd0080262,0xbcf8a573,0xea648f52}},	//   _síbu, _рене_, _guém, مپای, 
   {{0xbeb802d3,0x00000000,0x00000000,0x00000000}},	//   _njëh, --, --, --, 
   {{0x5d7401f0,0x00000000,0x00000000,0x00000000}},	//   _гусф, --, --, --, 
   {{0x89d861f4,0xdb04007b,0x1ce4031c,0x39100212}},	//   _یوزر_, rthá, _ཨོར_, омір, 
   {{0x87e46c31,0x98f4004d,0x3a3dcd1c,0xf8a400f2}},	//   рюле, _tỉn, _eyup_, شگله_, 
   {{0xfaa1cd1d,0x00000000,0x00000000,0x00000000}},	//   _масо, --, --, --, 
   {{0x48e40798,0xdb04032e,0x00000000,0x00000000}},	//   _коав, fthæ, --, --, 
   {{0x0465cd1e,0xe5a4035b,0xb7d400e5,0x00000000}},	//   штим, аиҩи, _ھونا_, --, 
   {{0x291dcd1f,0x1ce4025c,0xe2f89e08,0x9cd8008f}},	//   miva_, _ཨོལ_, гені_, אַרז, 
   {{0xa2c40032,0xc32c00cf,0x00000000,0x00000000}},	//   сәкк, بەب_, --, --, 
   {{0x26c5cd20,0xa4d42626,0x8544010b,0x00000000}},	//   memo_, _голі, _кэке, --, 
   {{0x291cd34f,0x26c5cd21,0x2bf800dc,0x00000000}},	//   niva_, lemo_, ूनां_, --, 
   {{0x25a4009a,0xbcf87d9b,0x99dc010e,0x248c0205}},	//   luml_, _quém, _zyňd, madm_, 
   {{0x2248009d,0xb3701e24,0x00000000,0x00000000}},	//   _tzak_, _بدوش, --, --, 
   {{0x224845e3,0xdcb8bf15,0x291dcd22,0x10880220}},	// [33610] _uzak_, лгач_, kiva_, _ﺑﯘﺭﯨ, 
   {{0x61fdcd23,0x26c5cd24,0xdde000e5,0x00000000}},	//   mysl, hemo_, ítőv, --, 
   {{0x291dcd25,0x9f34fb4f,0x2618007d,0x26c5cd26}},	//   diva_, _гені, _बेसी_, kemo_, 
   {{0xf21c1533,0x2a640356,0x442c0254,0x57e806dc}},	//   _पेड़_, _cgmb_, _mxf_, ғдим_, 
   {{0x291dcd27,0x98a40139,0x7de401ec,0x00000000}},	//   fiva_, _silı_, _тінд, --, 
   {{0x291dcd28,0xbdd8007f,0x00000000,0x00000000}},	//   giva_, _tyèb, --, --, 
   {{0x1cc0003d,0x26c5cd29,0x2bc8004e,0x61fc010e}},	//   _ཁྲག_, femo_, _куто_, hysl, 
   {{0x26c467c5,0x291dcd2a,0xab8401fe,0x61fc1155}},	//   gemo_, aiva_, _фурк, kysl, 
   {{0x291dcd2b,0x3a3c4870,0xd468927f,0x9944030d}},	//   biva_, _uyup_, липе_, _дiай_, 
   {{0x291dcd2c,0x61fdcd2d,0x19580150,0x9944009f}},	//   civa_, dysl, _сазы_, _اَطه, 
   {{0x26c400ca,0x96b80724,0x1ce4031c,0x00000000}},	//   bemo_, _булу_, _ྨོན_, --, 
   {{0x442c02fa,0x26c4597f,0x6ef804d4,0x337c0092}},	//   _dxf_, cemo_, _líbr, _የደረሰ_, 
   {{0x442c0165,0x61fc6e53,0x273000db,0x00000000}},	//   _exf_, gysl, _تۉيس, --, 
   {{0x4638008f,0xdb04000d,0x537400f3,0x00000000}},	//   _גענע, lthä, _луиђ, --, 
   {{0x63a402b5,0x61fc0076,0x2cac02d2,0x447400df}},	//   _āing, aysl, _öddi_, _פעקל_, 
   {{0x291dcd2e,0x52a8026a,0x0c2401e0,0xd9f80a59}},	//   ziva_, _свим_, ҡман, ्नात_, 
   {{0xc2780302,0x10a400d6,0x1cc00135,0x0c253ddf}},	// [33620] _גרפי, _липн, _ཁྲང_, әмен, 
   {{0x26c5cd2f,0x1ce40135,0x291dcd30,0xdb040254}},	//   zemo_, _ཨོཾ_, xiva_, hthä, 
   {{0xcfe81060,0x26c42da1,0x291dcd31,0x6ef801e7}},	//   _صفحه_, yemo_, viva_, _díbr, 
   {{0x291c009f,0x7e980165,0x41b000f2,0xca0802e8}},	//   wiva_, tłpł, _بمیر, лнеж_, 
   {{0x26c5cd32,0xda64007b,0x6d400064,0x60e402d2}},	//   vemo_, زاني, _ūmau, _útmá, 
   {{0x26c5cd33,0x9db800f7,0x6ef8032e,0x996401ec}},	//   wemo_, _тыюу_, _gíbr, ітіл, 
   {{0x26c5cd34,0x76480432,0x7cf80356,0x00000000}},	//   temo_, _azgy, _pîrv, --, 
   {{0x291dcd35,0x26c40418,0x3f78010f,0x61fc0108}},	//   siva_, uemo_, אָזע, yysl, 
   {{0x26c5cd36,0x291dcd37,0x248c0204,0xf98006dc}},	//   remo_, piva_, tadm_, _нгто, 
   {{0x26c5cd38,0x38c81547,0x69c1cd39,0x442c0175}},	//   semo_, _مامی_, _ipme, _pxf_, 
   {{0x26182017,0x3d380a7c,0x26c5cd3a,0x61fdbf40}},	//   _बेरी_, רגיס, pemo_, wysl, 
   {{0x61fc023a,0x8bf8009e,0x7cf80356,0x00000000}},	//   tysl, _আধান_, _hîrt, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x442c0165,0x61fdcd3b,0x06380092,0x00000000}},	//   _txf_, rysl, _አሳታሚ, --, 
   {{0x61fc02ed,0x98a40208,0x78f80a7c,0x00000000}},	//   sysl, _xklđ_, נפלו, --, 
   {{0x69c08e0d,0x1cc0031c,0x84680092,0x7648010e}},	//   _opme, _ཁིང_, _በዓሉን_, _yzgy, 
   {{0x7c6400db,0xdb04072b,0x00000000,0x00000000}},	// [33630] ماال, nthå, --, --, 
   {{0xbeb8036e,0x69c40327,0x46d8000d,0x00000000}},	//   _njëv, ħiel, _मोसह, --, 
   {{0x69c00029,0xbc482075,0xba740228,0x5b1401c6}},	//   _apme, учае_, ماشت, омжт, 
   {{0xdb047fff,0x19f803cf,0x00000000,0x00000000}},	//   kthå, иэль_, --, --, 
   {{0xa8040220,0x26183d1d,0x6ef802d2,0x00000000}},	//   үзіл, _बेली_, _tíbr, --, 
   {{0x2010011c,0x60d402c4,0x48e0234c,0xdb049f5c}},	//   ozzi_, ndzm, дошв, dthå, 
   {{0xdee8044e,0xdb059342,0x80b8043e,0xfb800133}},	//   _ዘሎን_, tthä, श्ये, _رگای, 
   {{0xa2a444eb,0xdb04007c,0x00000000,0x00000000}},	//   _काग्, fthå, --, --, 
   {{0xd628dfb2,0x737c00d1,0xdb04007c,0x00000000}},	//   ропе_, ﯩﺘﯩﺶ_, rthä, --, 
   {{0xbcf800e4,0x1424034b,0xdb04fc23,0x00000000}},	//   _buéi, ждом, sthä, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x846801f3,0x00000000,0x00000000,0x00000000}},	//   _በዓልን_, --, --, --, 
   {{0x32040122,0x257001ec,0x51b802d5,0xdb0400e4}},	//   ámy_, _كۇيس, шыня_, tuhê, 
   {{0x320c033f,0x00000000,0x00000000,0x00000000}},	//   ądy_, --, --, --, 
   {{0xbcf800e4,0x00000000,0x00000000,0x00000000}},	//   _guéi, --, --, --, 
   {{0x0d8407d6,0x00000000,0x00000000,0x00000000}},	//   жлан, --, --, --, 
   {{0x2010011c,0xa7fca75a,0x00000000,0x00000000}},	// [33640] azzi_, _agıl, --, --, 
   {{0x13ac00fe,0x61e803cd,0x00000000,0x00000000}},	//   _ছৈয়, åele, --, --, 
   {{0x0b5956cb,0x00000000,0x00000000,0x00000000}},	//   арды_, --, --, --, 
   {{0x69c000ca,0x7b84129d,0x00000000,0x00000000}},	//   _ppme, تاكە, --, --, 
   {{0xa7fc013d,0x7cf8054e,0xbdd80129,0x2bc800bc}},	//   _egıl, _cîrs, _hyèn, रबहा, 
   {{0x6f040034,0x200408fb,0x00000000,0x00000000}},	//   lkic, ølig_, --, --, 
   {{0x0709cd3c,0xc6a417a2,0x4a9400d8,0x00000000}},	//   ихии_, орпи, _мјау, --, 
   {{0x6f05cd3d,0xdb043bdc,0x00000000,0x00000000}},	//   nkic, tthå, --, --, 
   {{0xe81c000d,0x00000000,0x00000000,0x00000000}},	//   _भइवा_, --, --, --, 
   {{0xdb041654,0xbdd80241,0xbeb8036e,0xf4800092}},	//   rthå, _oyèn, _ujëv, _የአረብ_, 
   {{0x6f05cd3e,0xbcf80005,0xbdd80066,0xdb040267}},	//   kkic, _quéi, _nyèn, sthå, 
   {{0x6f040427,0xc1c00150,0x00000000,0x00000000}},	//   jkic, _ﺩﻴﺭﺍ, --, --, 
   {{0xe8c80ed9,0x6f04012d,0x00000000,0x00000000}},	//   _གྲོག, dkic, --, --, 
   {{0x6f04014b,0x6720a4a5,0xa30800e5,0x00000000}},	//   ekic, limj, _گرتے_, --, 
   {{0xbcf800c7,0x2010026c,0xf3ec007b,0x6600007c}},	//   _kuév, uzzi_, _لأي_, lymk, 
   {{0x3eac03fa,0xbbe813f9,0x63a809a8,0xa2a4e1dd}},	//   ügt_, یرام_, mudn, _काट्, 
   {{0x2005bfef,0x63a8181f,0xbcf80789,0x5c98858f}},	// [33650] šli_, ludn, _muév, йкая_, 
   {{0xa7fc0724,0x628c00c5,0x672001a9,0xdddc0419}},	//   _agım, _heao, himj, _nesť, 
   {{0x7cf8025a,0x63a8151c,0xa2a400dc,0x67201ba4}},	//   _bîrr, nudn, _काञ्, kimj, 
   {{0xddcdcd3f,0xbcf800e4,0x961c007f,0x1ab00154}},	//   mbaž, _nuév, nbņc, _ঘোড়া, 
   {{0xdee8069c,0x628c1140,0x63a86a45,0xdb040332}},	//   _ዘሎና_, _meao, hudn, othú, 
   {{0x628c0b23,0xb17c06a9,0x7cf8054e,0x6dc400db}},	//   _leao, סטור, _vîrs, _تۅكۅ, 
   {{0xf6c449a6,0x628c0086,0xbcf80022,0x42a40092}},	//   _ཁྲུང, _oeao, _buév, ላቂነት_, 
   {{0x63a9cd40,0x80b805b3,0xeaf807f7,0x628c0356}},	//   dudn, श्ते, ्घृत_, _neao, 
   {{0xefc00023,0xae000ebb,0xdddc01ef,0xdb24000d}},	//   _ስዒድ_, ोनयन_, _fesť, öpõh, 
   {{0x628c00b0,0x99dc010e,0xdb040022,0x6f040210}},	//   _aeao, _gyňa, duhé, zkic, 
   {{0x628c01ab,0x1cc0025c,0x6f040986,0x39440175}},	//   _beao, _ཁྲབ_, ykic, mlns_, 
   {{0x99dc010e,0x64700022,0x65881427,0x00000000}},	//   _zyňa, нҳәу, ðshú, --, 
   {{0x55e4152d,0x3568f69e,0x41a402c3,0xd46800f0}},	//   _холб, _трен_, कूलस, _лиле_, 
   {{0x63a88d6f,0x6f040113,0x00000000,0x00000000}},	//   budn, wkic, --, --, 
   {{0x6f05c2da,0x628c0618,0x04400364,0xbeb802d3}},	//   tkic, _feao, _пешн, _njës, 
   {{0x72a4516c,0xdb045002,0xda6400ec,0x00000000}},	//   _تەحن, rthû, _لڏ_, --, 
   {{0x6f0405a1,0xdb04000f,0x3b0c0477,0xcd047afb}},	// [33660] rkic, sthû, dhgq_, ппай, 
   {{0x7cf8025a,0x6f05cd41,0xe81c00af,0x00000000}},	//   _sîrr, skic, _भइला_, --, 
   {{0xdc4400ef,0x00000000,0x00000000,0x00000000}},	//   _fīča, --, --, --, 
   {{0xc7640ae5,0x200403cd,0x00000000,0x00000000}},	//   ۋابى, ølie_, --, --, 
   {{0x7cf001d3,0xf76c0014,0x672006ea,0x63a800e5}},	//   _sűrű, ۯاو_, vimj, zudn, 
   {{0x2d81cd42,0xfe6c9105,0x1ce4025c,0xf76c4ea7}},	//   mpie_, _لگے_, _ཨོག_, گاو_, 
   {{0x2d81cd43,0xab6403fa,0x6721cd44,0xbeb8036e}},	//   lpie_, grüß, timj, _gjës, 
   {{0xb5c004a2,0xf76c4a91,0x63a9cd45,0x2d540036}},	//   ﯩﻤﯩﺰ, داو_, vudn, fäeg_, 
   {{0xbdd80066,0xca0801c0,0x67209ca2,0xdb4c0133}},	//   _nyèl, _унаж_, rimj, _ئێن_, 
   {{0x63a80003,0x070805d9,0x32b801c0,0xa2a416d1}},	//   tudn, _ڏيئي_, үгээ_, _काङ्, 
   {{0x68e8037e,0x628c0037,0xf5b007d6,0x2d540037}},	//   _indd, _peao, وصید, mäed_, 
   {{0x1cc0003d,0x63a8bd8d,0xddcc054e,0x67211eb2}},	//   _ཁྲན_, rudn, ncaţ, qimj, 
   {{0xd4f4030f,0xbb38010f,0xc568007b,0x864401c4}},	//   ستیژ, מעטי, _احصل_, _эндж, 
   {{0xd6249245,0xbeb8044e,0x63a8aaef,0x7634010a}},	//   _تعمي, _njër, pudn, _элчĕ, 
   {{0x628dcd46,0x2d809e8b,0xdb049e9b,0xd6d80210}},	//   _teao, epie_, rthú, sołe_, 
   {{0xdb0405f7,0x1ce4031c,0x22940214,0x00000000}},	//   sthú, _ཨོང_, _کلکس, --, 
   {{0xe3b871e1,0x290dcd47,0x68e801c6,0xf2d4010f}},	// [33670] ltı_, _olda_, _ondd, _נעץ_, 
   {{0xa3b001ad,0xe29800c7,0xadb4084c,0x39440334}},	//   टंप_, _уаҩ_, эбуш, xlns_, 
   {{0xe3b82ed0,0x9f5402bf,0xbdd80241,0xe81c012c}},	//   ntı_, _овоч, _iyèm, _भेला_, 
   {{0x290dcd48,0xa3d405d7,0x68e8032e,0xdb04072b}},	//   _alda_, _हनन_, _andd, nthø, 
   {{0xeab000c6,0xe3b803e0,0x1be8000d,0x00000000}},	//   اعم_, htı_, _टपकल_, --, 
   {{0xe3b85d6d,0x68e807a8,0xbeb8044e,0x09e018d9}},	//   ktı_, _cndd, _gjër, тошн, 
   {{0xb09c008f,0xbeb80240,0x76a00ca8,0x00000000}},	//   מיגר, _ujës, _nìyà, --, 
   {{0x290dcd49,0x68e804ce,0xadc401e1,0xd5e402e8}},	//   _elda_, _endd, _ayẹs, джии, 
   {{0x63a4166a,0x3b1c0113,0x27e1cd4a,0xdb0401bf}},	//   _āina, _imuq_, āina_, dthø, 
   {{0x7af9cd4b,0xbcf8026c,0xe3b808a9,0x00000000}},	//   _hout, _guét, ftı_, --, 
   {{0x7af9cd4c,0xbcf809d7,0x1cc0025c,0x00000000}},	//   _kout, _hués, _ཁིན_, --, 
   {{0x7af8049b,0xbdd80100,0x6fac03d4,0x237800e5}},	//   _jout, _pyèl, _চনলৈ, írja_, 
   {{0x68e800a9,0x7af9cd4d,0xe3b83bc1,0xbeb80240}},	//   _yndd, _mout, atı_, _njëq, 
   {{0xbcf80789,0xd0104d2f,0x00000000,0x00000000}},	//   _mués, پلر_, --, --, 
   {{0xdcec01e4,0x016000f0,0xd0080452,0xe3b80205}},	//   nuaĵ, ткро, цеве_, ctı_, 
   {{0x7af9cd4e,0xefd802d3,0xddcc025c,0x2d800210}},	//   _nout, _ርኡይ_, bbaż, tpie_, 
   {{0xdcfc0139,0xd1c0001f,0x4d640006,0x515400fb}},	// [33680] _aqsı, ስቶች_, дкав, _отоу, 
   {{0x2d81cd4f,0x72a40150,0x7af80129,0x00000000}},	//   rpie_, _تەڭن, _aout, --, 
   {{0xaaa40184,0x8e840416,0x3eb0023a,0x68e80100}},	//   егеҙ, _огне, äntö_, _rndd, 
   {{0x7af9cd50,0xbcf81a06,0x20544caf,0x2d802bab}},	//   _cout, _suét, _ятыр, ppie_, 
   {{0x7af9631c,0x1cc00d46,0xddcc0311,0x80b8193d}},	//   _dout, _ཁྲམ_, rcaţ, श्वे, 
   {{0xbcf9cd51,0xe3b8467d,0xbeb80023,0xddcc054e}},	//   _dués, ytı_, _ujër, scaţ, 
   {{0x7af9cd52,0xe3b803be,0x33200005,0xdcec0115}},	//   _fout, xtı_, _omix_, npaĝ, 
   {{0xa5d40a5b,0x8cac1be1,0x0ae801f7,0x00000000}},	//   ежиш, ुभवो, _برسي_, --, 
   {{0xa3b07e29,0x88c4007b,0x00000000,0x00000000}},	//   टून_, _يتطل, --, --, 
   {{0x7af863d1,0xe3b87764,0xbcf83d57,0xdcec00df}},	//   _zout, ttı_, _huér, buaĵ, 
   {{0x7af9c61d,0xbcf807dd,0xdb0403cd,0x00000000}},	//   _yout, _kuér, tthø, --, 
   {{0xe3b80bcc,0x386000dd,0xbcf9cd53,0xbeb80240}},	//   rtı_, _újra_, _juér, _njëp, 
   {{0xe3b87bfb,0x33200066,0x461401d5,0xb6f400db}},	//   stı_, _dmix_, _توشر, _تىنا_, 
   {{0xdcec00c8,0xe3b81918,0xdb04005c,0x76a00241}},	//   fpaĝ, ptı_, sthø, _tìyà, 
   {{0xe3b80724,0xdcedcd54,0x00000000,0x00000000}},	//   qtı_, jsaġ, --, --, 
   {{0x80bc02ab,0x00000000,0x00000000,0x00000000}},	//   _लॉरे, --, --, --, 
   {{0x5d55cd55,0x7af835c6,0xbdd80248,0xfe7c0142}},	// [33690] екат, _rout, _iyèk, _wnïo_, 
   {{0x224822d0,0xbc48399b,0xdcec00df,0x00000000}},	//   _iyak_, очее_, bpaĝ, --, 
   {{0x7af9cd56,0x2368010f,0x00000000,0x00000000}},	//   _pout, _kiaj_, --, --, 
   {{0x3f80003d,0x5a34e9a8,0xd6d80034,0x224844ce}},	//   mpju_, ннет, koła_, _kyak_, 
   {{0x7af9cd57,0x236800c8,0x4cc80154,0x23b800e5}},	//   _vout, _miaj_, রাজু, héj_, 
   {{0xe8f81c26,0xe9d9af6b,0x2369cd58,0xd8740137}},	//   млі_, ькі_, _liaj_, راتب, 
   {{0x7af9cd59,0x2b440109,0xbcf80789,0xe77801ed}},	//   _tout, _fkmc_, _fuér, ولوں_, 
   {{0xbcf9cd5a,0x2369cd5b,0x2b440048,0x2249cd5c}},	//   _guér, _niaj_, _gkmc_, _oyak_, 
   {{0x2249cd5d,0xd1c002d3,0x7b100166,0x3a040244}},	//   _nyak_, ስቶት_, _açug, _تکای_, 
   {{0xf804169c,0x3630004b,0xdb4c0345,0x00000000}},	//   _очен, _یواځ, _ئێچ_, --, 
   {{0x2249cd5e,0xe894b32d,0xdb0400e4,0xe6100133}},	//   _ayak_, _рахь, huhí, _ێشه_, 
   {{0x23680457,0x2570035b,0x00000000,0x00000000}},	//   _ciaj_, ықәс, --, --, 
   {{0x1ce40156,0x236800df,0x00000000,0x00000000}},	//   _ཨོཕ_, _diaj_, --, --, 
   {{0x261809d9,0x799806d6,0x80b81025,0x22488d29}},	//   _बेटी_, _mvuw, श्ले, _dyak_, 
   {{0x22480113,0x236801e4,0x00000000,0x00000000}},	//   _eyak_, _fiaj_, --, --, 
   {{0x2120003e,0xdcec01e4,0xd0840124,0x00000000}},	//   _emhh_, rpaĝ, ьыҭи, --, 
   {{0x9db81e76,0x7bc5cd5f,0xd2640212,0x4cc80154}},	// [336a0] дыху_, _apju, _який, রাঘু, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8b687ffa,0xbcf807ea,0xfb100133,0xcee800d8}},	//   чиев_, _puér, گونج, _едне_, 
   {{0xbcf9c3f0,0xaca40241,0xb88001ef,0x00000000}},	//   _quér, _iyọr, _lvíč, --, 
   {{0xdcec038f,0xbb800131,0x2fe8012d,0x6a840139}},	//   ssaġ, نلەي, ługę_, елҗа, 
   {{0x7b10222a,0xb0040055,0x6b580162,0x00000000}},	//   _açud, _laḍu, kígg, --, 
   {{0x24d8009e,0x38c8136e,0xd90c01d5,0xd6d80210}},	//   তামহ, ثانی_, غیم_, woła_, 
   {{0x37c08e58,0x99dc00a2,0xf7400120,0x00000000}},	//   اييف, _zyňm, лејо, --, 
   {{0xbcf800e4,0xc52406ed,0xa53400d8,0xdb1001e1}},	//   _kuép, еќни, книч, _ògán, 
   {{0x236800c8,0x6b58022c,0x6b9c2630,0x3a204d56}},	//   _siaj_, fígg, _kvrg, _смуг, 
   {{0x22482948,0x2419cd60,0xf8b004ae,0x236801e4}},	//   _syak_, фоны_, _תשע_, _piaj_, 
   {{0xb9f8044e,0xb9c802d3,0x6b9c01f5,0x00000000}},	//   _ዘተ_, _ደቃ_, _mvrg, --, 
   {{0x236800c8,0xaca40241,0x3f54004a,0x2618924b}},	//   _viaj_, _ayọr, nçue_, _बेची_, 
   {{0x6b9c0010,0x00000000,0x00000000,0x00000000}},	//   _ovrg, --, --, --, 
   {{0x2369cd61,0x4ab0043e,0x260800bc,0x00000000}},	//   _tiaj_, ीभाव, िनकी_, --, 
   {{0x22481c06,0xb00400b8,0xdd040790,0x00000000}},	//   _tyak_, _gaḍu, _ısıy, --, 
   {{0x2248020c,0x7bc5cd62,0xfbb4009e,0xdd9471c1}},	// [336b0] _uyak_, _spju, ীয়াত, тазы, 
   {{0x3f800135,0xa3b003ce,0x00000000,0x00000000}},	//   ppju_, टूथ_, --, --, 
   {{0xfba9cd63,0x30a4005b,0x6ef80419,0xdb0400e4}},	//   ятай_, _срыв, _líby, suhí, 
   {{0xdd9400c7,0xbe6031f0,0x7b440116,0x00000000}},	//   _иамы, _مۇزي, رئال, --, 
   {{0x63a802f0,0xceb40bd6,0x00000000,0x00000000}},	//   hrdn, _шәр_, --, --, 
   {{0x7bc80276,0xbcf80129,0xe9180212,0x6a140022}},	//   ăgub, _guép, ночі_, ымчу, 
   {{0x47d05734,0x6d352515,0x7bc40432,0x00000000}},	//   ليور, _серф, _upju, --, 
   {{0xb88000bc,0xa3e406b1,0xdb0404cc,0x99dc00a2}},	//   _svíč, निन_, nthü, _jyňk, 
   {{0x6b6c51bb,0x63a804e6,0xd4981e4a,0x98b8b039}},	//   _işga, erdn, үрү_, _олат_, 
   {{0x58d802bf,0x6b580174,0x00000000,0x00000000}},	//   _ідея_, tígg, --, --, 
   {{0x63a805a1,0x1ce4031c,0x3dd400eb,0x00000000}},	//   grdn, _ཨོན_, সমিল, --, 
   {{0x1cc00135,0x6b580174,0x00000000,0x00000000}},	//   _གཡའ_, rígg, --, --, 
   {{0x13a403e6,0x63a9cd64,0x200403b2,0x95740092}},	//   رۆکی_, ardn, ølin_, ረቶችን_, 
   {{0x8fa400ee,0x691400a3,0x20d49e08,0x28c400dc}},	//   каге, _gàed, лісс, ल्पि, 
   {{0x764800a9,0xb401cd65,0xa1c002dd,0xe66400c7}},	//   _hygy, _сүнд, _құрд, _итәо, 
   {{0xb4f000cf,0x00000000,0x00000000,0x00000000}},	//   _рүүч, --, --, --, 
   {{0x0e6568e7,0xefd8044e,0x6b9c0552,0x76480432}},	// [336c0] ткан, ርእዮ_, _svrg, _jygy, 
   {{0x6b6c09a5,0x7768209c,0xdcec00ac,0x6aa000b5}},	//   _aşga, _ligx, rpağ, _sdmf, 
   {{0x7d00049f,0xa3e4012c,0x76485127,0xbdd80241}},	//   önsa, निय_, _lygy, _oyèw, 
   {{0x77680117,0xc0d4001f,0xf64403c7,0xefd80240}},	//   _nigx, ርድር_, _نئ_, ርእይ_, 
   {{0x827400c8,0x00000000,0x00000000,0x00000000}},	//   דענע_, --, --, --, 
   {{0x6b59cd66,0x92cc09bd,0x9f44025a,0x3f54004a}},	//   díge, রায়_, âlö_, rçue_, 
   {{0x3fd40075,0x7648010e,0xd64c01ec,0x00000000}},	//   ﻟﻐﺎﻧ, _aygy, _тiке, --, 
   {{0x940403be,0x63a816a3,0x764803cb,0xe99400f2}},	//   qalə_, vrdn, _bygy, _مهرگ, 
   {{0x8965cd67,0x5b340276,0xc96401d5,0x87f000cc}},	//   _акаж, _сэру, _авай, জনেছ_, 
   {{0x764873b0,0xdb040022,0x63a801a9,0xa3d4009d}},	//   _dygy, muhá, trdn, гооч, 
   {{0xb7d5cd68,0xa2940d30,0x1cc00327,0x86c4027d}},	//   _لولا_, лані, _གཡལ_, _ليان, 
   {{0x764803cb,0xb6a0030d,0xf59005af,0x161c19cc}},	//   _fygy, _вицл, _چلنج, _बेकर_, 
   {{0x2cb80048,0x76485443,0xa7fc0205,0x00000000}},	//   _ocrd_, _gygy, _egıt, --, 
   {{0x77680944,0xdb04004a,0x2cb80175,0x00000000}},	//   _zigx, rrhé, _ncrd_, --, 
   {{0xdb0532f5,0x00000000,0x00000000,0x00000000}},	//   huhá, --, --, --, 
   {{0xb7d80bd9,0x7de40220,0x9f0451ae,0x77680009}},	//   וקלי, кізд, دورو, _xigx, 
   {{0x1d34010b,0xdb05cd69,0x00000000,0x00000000}},	// [336d0] гная, juhá, --, --, 
   {{0x7c651d63,0xdb0512fe,0x00000000,0x00000000}},	//   ناال, duhá, --, --, 
   {{0x1fb80139,0x6b7460a9,0x00000000,0x00000000}},	//   _ялны_, алху, --, --, 
   {{0x1ce40489,0xee846cea,0x7e6c04cc,0x6d4181ff}},	//   _ཨོམ_, _выро, _ugcp, _íman, 
   {{0x98a55d51,0x7b100120,0x8c38016c,0x2d54023a}},	//   гиле, _açuc, _ҷорӣ_, mäen_, 
   {{0x77680944,0xe194037e,0x2d540112,0x00000000}},	//   _sigx, _m女_, läen_, --, 
   {{0x2795cd6a,0x7b6400ee,0x3158008f,0x7648010b}},	//   ашыр, _атае, דיגן_, _sygy, 
   {{0xdb040597,0x6b581ada,0x2d5402c1,0x7648010e}},	//   rthó, tíge, näen_, _pygy, 
   {{0x645c2833,0x3ebc0113,0x5a3400d8,0xd6d8012d}},	//   ýrin, _ñutu_, _снат, soło_, 
   {{0x1cc0081f,0x6b595e0d,0xdb0408c2,0x00000000}},	//   _གཡས_, ríge, cthò, --, 
   {{0xa8840137,0x94243cc5,0x67d4974c,0x9f5000e5}},	//   _ئلمى, умне, _воху, nyzó_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe35401c0,0x00000000,0x00000000,0x00000000}},	//   ртээ, --, --, --, 
   {{0x7520009a,0x33600092,0x00000000,0x00000000}},	//   _umnz, ተለመደ_, --, --, 
   {{0x37c003f4,0x06640022,0x82380092,0xdb0400e4}},	//   ্মকর, _ихәҭ, _የዕርዳ, zuhá, 
   {{0x261001f9,0x00000000,0x00000000,0x00000000}},	//   दैवी_, --, --, --, 
   {{0xccc53acc,0x91e4023a,0x28c410b7,0x00000000}},	// [336e0] лбай, _сопе, ल्डि, --, 
   {{0xdcec01e4,0x00000000,0x00000000,0x00000000}},	//   kraĵ, --, --, --, 
   {{0x4aa8074d,0xdcec01e4,0xed5401e4,0x00000000}},	//   екен_, jraĵ, stɾo_, --, 
   {{0xa3e438d2,0xdcec01e4,0xdb040124,0xa3d4012d}},	//   नित_, draĵ, tuhá, हबत_, 
   {{0xe81c0034,0x294c0023,0xdb0403b2,0x00000000}},	//   _भेजा_, _ንሃይማ, kuhæ, --, 
   {{0xdb0487bc,0x9cec0489,0x8c4400ee,0x9d7400d1}},	//   ruhá, _ལོགས, _беге, _ئەلا_, 
   {{0x6d5dcd6b,0x37a41f10,0xc7c43ab4,0xdcec01e4}},	//   _ihra, гтын_, усли, graĵ, 
   {{0x1cc0003d,0x2ee00135,0x00000000,0x00000000}},	//   _གཡོ_, ndif_, --, --, 
   {{0x6d5c0652,0xf9c401d5,0x88c803f6,0xc8b4007b}},	//   _khra, _محلی, _плав_, _مصاب, 
   {{0x83840220,0xdcec01e4,0x00000000,0x00000000}},	//   лыме, braĵ, --, --, 
   {{0x6d5c08c2,0xe4540fca,0x7b1003e0,0xa3e4012d}},	//   _mhra, ркны, _uçuc, निध_, 
   {{0x6d5c04ba,0x00000000,0x00000000,0x00000000}},	//   _lhra, --, --, --, 
   {{0x1b0039db,0x6d5d4e51,0x659401c0,0x2d540108}},	//   লোকে_, _ohra, _талу, väen_, 
   {{0xa159cd6c,0x1cc00327,0x6d5c015d,0xfeb88f52}},	//   тагу_, _གཡེ_, _nhra, کاست_, 
   {{0x20042776,0x2d54023a,0x7cf8054e,0xaab407f7}},	//   âli_, täen_, _tîrz, ँलाक, 
   {{0x6459cd6d,0xfe71b251,0x93440014,0xf3ec007b}},	//   _izvi, صدر_, _پر٘ۆ, _رأى_, 
   {{0x6d5dcd6e,0x4391cd6f,0xa3b001ad,0x26c00de2}},	// [336f0] _bhra, _тақс, टूर_, _ñiou_, 
   {{0x6d5c3084,0xad240116,0x00000000,0x00000000}},	//   _chra, مىقى, --, --, 
   {{0x2d5400c5,0x6d5dcd70,0xaa4406ba,0x00000000}},	//   mäel_, _dhra, ەننى, --, 
   {{0x98a8098d,0x6d5dcd71,0xdcec00df,0x00000000}},	//   đač_, _ehra, vraĵ, --, 
   {{0x6d5c7ea1,0x39a4f7f2,0x00000000,0x00000000}},	//   _fhra, ушев, --, --, 
   {{0x6d5db66e,0x64580d7b,0xbeb80023,0x28f8023a}},	//   _ghra, _ozvi, _njëz, лечь_, 
   {{0x64580e8a,0xac580107,0x94743451,0xdb0403b2}},	//   _nzvi, _барф_, یددا, vuhæ, 
   {{0xbdd8033b,0x382802d3,0x6d5c00d7,0x33600023}},	//   _fyèt, _እንርእ, _zhra, ተወሓደ_, 
   {{0x64580433,0xd4f400ee,0x6d5c010e,0x00000000}},	//   _azvi, аяны, _yhra, --, 
   {{0xb5a80131,0xdcec010f,0xa81800d1,0x28c40118}},	//   _ﺳﻪﻧﺌ, praĵ, ختۇر_, ल्दि, 
   {{0x394429ef,0x6b5803b2,0xdb0403b2,0x00000000}},	//   mons_, líga, ruhæ, --, 
   {{0x3945cd72,0x6458004c,0x6d4000e4,0x87780677}},	//   lons_, _dzvi, _êmav, _סאני, 
   {{0x80dc11ba,0x645805b8,0x00000000,0x00000000}},	//   মান্, _ezvi, --, --, 
   {{0x3944420d,0x63bc01ab,0xbeb80200,0xdb0426bb}},	//   nons_, àrnc, _gjëz, luhä, 
   {{0x8f7410da,0xddd40166,0x00000000,0x00000000}},	//   ругі, _ƅaşq, --, --, 
   {{0x1cc01b4b,0x3945cd73,0x6d5dcd74,0x8e85cd75}},	//   _གཡུ_, hons_, _shra, ргае, 
   {{0x394429ef,0x2ee006af,0x113860a1,0x10a40395}},	// [33700] kons_, rdif_, _аяны_, _кипн, 
   {{0x3945cd76,0xfe7c0129,0xdb040254,0xb7e800cc}},	//   jons_, _naïf_, huhä, _কথনত_, 
   {{0x39442045,0x0c240120,0x161c0412,0x6d400139}},	//   dons_, јмен, _बेघर_, _ímam, 
   {{0xca0806ed,0x2d980133,0x00000000,0x00000000}},	//   кнеж_, _مێرد_, --, --, 
   {{0x6d5dcd77,0x3945cd78,0xd90c7935,0x2df80014}},	//   _thra, fons_, کیل_, _صبحک_, 
   {{0x6d5dcd79,0x0ba80150,0x3945cd7a,0x42800023}},	//   _uhra, _لارى_, gons_, ሪሕነት_, 
   {{0x5ed8015b,0x2bf40490,0xf8000006,0x00000000}},	//   ডারে, ूहळू_, жчын, --, 
   {{0xbb400262,0xa3e47220,0x7bd80375,0xc6e401ec}},	//   _деск, निस_, _בקלו, рікп, 
   {{0x39442045,0xbdd806af,0x058400d1,0x7a6400db}},	//   bons_, _hyèr, шуйм, _نئكە, 
   {{0x1cb049a6,0x69c0014f,0xdb040042,0x3630215c}},	//   དཔར_, _iqme, crhâ, ترىس, 
   {{0x3c7402e4,0x7d54008f,0xa2c400b1,0x2d54000d}},	//   יתים_, שייד_, бәпк, väel_, 
   {{0x86443169,0xb9e002d3,0x64580427,0xd1d40092}},	//   _кнеж, _ሩባ_, _vzvi, ርጅት_, 
   {{0x41c40117,0x35f40066,0x00000000,0x00000000}},	//   шёна, _نرود_, --, --, 
   {{0xd5a410e8,0x00000000,0x00000000,0x00000000}},	//   _الوی, --, --, --, 
   {{0x6459cd7b,0xbdd8020c,0x1cb0031c,0x48ec00bc}},	//   _uzvi, _nyèr, དཔལ_, _आफनो_, 
   {{0x7b10013d,0x6464025c,0x416c0150,0x33f800d9}},	//   _açun, ħtiġ, _ﺴﺎﺩﺱ_, _יהונ, 
   {{0x629dcd7c,0x39444aee,0xdcfc005f,0x00000000}},	// [33710] maso, yons_, _atsā, --, 
   {{0x629dcd7d,0x0af001c0,0xdb04002f,0x6b5803b2}},	//   laso, үүрэ, zuhä, víga, 
   {{0x3945cd7e,0x60d5cd7f,0xbdd8007f,0xdb04002f}},	//   vons_, mezm, _pyès, ithö, 
   {{0x629dcd80,0x28c46b9b,0x60d466c5,0x00000000}},	//   naso, ल्सि, lezm, --, 
   {{0x3945cd81,0xdb04007c,0x00000000,0x00000000}},	//   tons_, kthö, --, --, 
   {{0x629dcd82,0x69347bb3,0x1cc0031c,0xa92402bf}},	//   haso, ончу, _གཡི_, оділ, 
   {{0x629dcd83,0x3945cd84,0xb8fc561f,0xab842f23}},	//   kaso, rons_, _तस_, _мутк, 
   {{0x3945cd85,0x6b5800d7,0xb03800df,0x00000000}},	//   sons_, lígn, ינוג_, --, 
   {{0x629dcd86,0x46e405f5,0x3945cd87,0x1a6407d6}},	//   daso, сдын_, pons_, _ایشی_, 
   {{0x8cc80db3,0xdb040254,0x6b5800d7,0xa968009b}},	//   स्पो, suhä, nígn, _виђа_, 
   {{0x629dcd88,0x60d40789,0x68fc0e89,0x00000000}},	//   faso, dezm, _òrda, --, 
   {{0xc82c001f,0x63bc0192,0x859000f1,0xdb0402d2}},	//   _እንኩዋ, àrna, _کټوا, athö, 
   {{0x3c0000af,0x28c41788,0x95840408,0x00000000}},	//   लहुँ_, ल्वि, _улле, --, 
   {{0x0fd8652e,0x629c0869,0xc5f00375,0xa3e44707}},	//   льбы_, aaso, _מדד_, निश_, 
   {{0x8cc80307,0xb4b00574,0xb4d001ad,0x00000000}},	//   स्फो, टली_, हजी_, --, 
   {{0xd1d40020,0x629c2b76,0x7bc80356,0x2e880022}},	//   ርጅቱ_, caso, ăgul, риаҿ_, 
   {{0x0c75cd89,0x60d50de6,0xd0580150,0xdb1001e1}},	// [33720] مداد, bezm, _әрпі_, _ògùn, 
   {{0x8c440353,0x00000000,0x00000000,0x00000000}},	//   безе, --, --, --, 
   {{0xd0080408,0x00000000,0x00000000,0x00000000}},	//   _сене_, --, --, --, 
   {{0x9b24160b,0xfe7c0129,0x693400f1,0xaa440145}},	//   офіл, _caïd_, ښکار, ەنچى, 
   {{0xc3300375,0xc0f401f3,0x00000000,0x00000000}},	//   הוא_, ፈፀመ_, --, --, 
   {{0x629dcd8a,0x00000000,0x00000000,0x00000000}},	//   zaso, --, --, --, 
   {{0x629dcd8b,0xdcfc00cd,0x00000000,0x00000000}},	//   yaso, _utsā, --, --, 
   {{0x629dcd8c,0xc82c0092,0x00000000,0x00000000}},	//   xaso, _እንክዋ, --, --, 
   {{0x6b59cd8d,0x629c09e6,0x69c00455,0x60d5cd8e}},	//   lígo, vaso, _uqme, yezm, 
   {{0x629dcd8f,0x28c406ab,0xbcf800e4,0xfe7c05da}},	//   waso, ल्शि, _buéy, _zaïd_, 
   {{0x2459cd90,0x8cc83bec,0xb6300acb,0x60d402fb}},	//   рань_, स्यो, قعیت, vezm, 
   {{0x629c0421,0xdb05cd91,0xb28400db,0x00000000}},	//   uaso, sthö, зырк, --, 
   {{0x7d00e4c3,0x27e000b0,0x00000000,0x00000000}},	//   önsk, āinu_, --, --, 
   {{0x629dcd92,0x8cc807f7,0xe7dc0490,0x7b10013d}},	//   saso, स्मो, _मनाप, _açul, 
   {{0xaac819ec,0x629dcd93,0x60d5cd94,0x291c0007}},	//   रभाक, paso, rezm, ihva_, 
   {{0x629dcd95,0x80dc015b,0x9f540212,0xaf046f9f}},	//   qaso, মাধ্, івач, пчук, 
   {{0xb8d8031c,0x9df80798,0x673c01d3,0x447000f1}},	// [33730] _མྰ_, шнат_, _írju, _بنګړ, 
   {{0x61edcd96,0xfe7c0129,0xdb0401ef,0x00000000}},	//   _iral, _saïd_, drhá, --, 
   {{0xf2dc015b,0x61ec0030,0x92cc0183,0xdb040d12}},	//   ধারণ, _hral, ৰাৰ_, muhú, 
   {{0x6b585efb,0x99d40150,0xb3b8008f,0xbd6801e0}},	//   sígn, قتتا, רמאכ, _әрме_, 
   {{0x210c0490,0xa2c0193d,0x00000000,0x00000000}},	//   _सकाळ_, _वान्, --, --, 
   {{0x27ec01ab,0x61ec0066,0x28c46c5a,0xdb040413}},	//   _brdn_, _mral, ल्लि, nuhú, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7d040007,0xd70888d6,0x3ce001a9,0x6d4000e4}},	//   _hojs, рние_, _hajv_, _êmar, 
   {{0x5bc8007d,0x562c02d3,0x7d04036e,0xa2cc0118}},	//   _रहुव, _እትኽእ, _kojs, तभन्, 
   {{0xb4b07971,0x53c9cd97,0xdb04035b,0xa3e400cd}},	//   टले_, агом_, juhú, निं_, 
   {{0x61edcd98,0x7d05cd99,0x99dc00a2,0xb9dc0023}},	//   _aral, _mojs, _gyňr, _ጥረ_, 
   {{0x61ec0dfe,0x3ce11c8c,0xa07400c7,0xd7600244}},	//   _bral, _lajv_, ҧысш, _تۆبی, 
   {{0x61ec01ab,0x20040108,0xdb04032e,0x00000000}},	//   _cral, älin_, fuhú, --, 
   {{0x61edcd9a,0xd4688b10,0x69ac01f9,0xdb041d1d}},	//   _dral, _киле_, ुंती, guhú, 
   {{0xe7ec1094,0x61edcd9b,0xa3e400dc,0x00000000}},	//   झिया_, _eral, निः_, --, 
   {{0x61edcd9c,0xb7e803d4,0xf0780116,0x00000000}},	//   _fral, _কথাত_, риңә_, --, 
   {{0x61edcd9d,0xcd280006,0x00000000,0x00000000}},	// [33740] _gral, ажае_, --, --, 
   {{0xe18800b2,0x7d040cf4,0xdb0402fb,0x4c1400f7}},	//   _ائين_, _cojs, vrhá, يباس, 
   {{0x8b2400d6,0x5ba40212,0x61ec00bc,0x7d05cd9e}},	//   одже, зріз, _zral, _dojs, 
   {{0x6b58004e,0xdb040306,0x9f4002f0,0x7b1006be}},	//   rígo, trhá, _trhá_, _uçul, 
   {{0x20040158,0x2f1c0162,0xe7ac000d,0x00000000}},	//   øliv_, _vígd_, _घटहप, --, 
   {{0xda64d82e,0x7d040369,0x691400a3,0x6b5800db}},	//   ساني, _gojs, _gàel, pígo, 
   {{0xfbc01c83,0xc7641e87,0x291c009a,0x00000000}},	//   _обро, يابى, rhva_, --, 
   {{0xd6d8012d,0x00000000,0x00000000,0x00000000}},	//   kołu_, --, --, --, 
   {{0x50c8a73d,0x9f6000e5,0xf76c02f2,0x7e98011a}},	//   िभाष, épén_, خاو_, בספו, 
   {{0x61ec044e,0x38c8a485,0xdb2000dd,0xd7640014}},	//   _rral, _نامی_, ütör, _ہانٹ, 
   {{0x61fc0175,0xd7ec0451,0x7d000108,0xdb0403b2}},	//   wxsl, _مڃي_, önsi, vuhú, 
   {{0x61edcd9f,0x8cc8262c,0xa7fc008e,0x00000000}},	//   _pral, स्तो, _azıg, --, 
   {{0xfe7c1e54,0x00000000,0x00000000,0x00000000}},	//   _laïc_, --, --, --, 
   {{0xe6940014,0x61ec0165,0x00000000,0x00000000}},	//   _بۅکژ_, _vral, --, --, 
   {{0x7d040fb7,0x61ec000f,0x844401d5,0xdb0403f2}},	//   _rojs, _wral, _بخشل, ruhú, 
   {{0x61e817f9,0xefd80023,0x00000000,0x00000000}},	//   åels, ርብዎ_, --, --, 
   {{0x61edcda0,0xe3b80724,0x3f5405d1,0xdb040162}},	// [33750] _ural, luı_, lçuk_, muhø, 
   {{0xacf80228,0xa2c010eb,0x2f1c0332,0xdb040162}},	//   онуу_, _वाड्, _ríge_, luhø, 
   {{0x7d04181f,0xa3b0e60e,0x9ad40108,0x00000000}},	//   _vojs, टंट_, зжеч, --, 
   {{0x7d040034,0x6128b0e8,0xf6c4025c,0x213005c7}},	//   _wojs, džli, _གཡེང, lizh_, 
   {{0x7d0401d4,0x1958021f,0xd8880014,0x6d4c0174}},	//   _tojs, бады_, ٕپتن_, úlaø, 
   {{0x5b2401d5,0x213005c7,0x4d780115,0x00000000}},	//   _کفرل, nizh_, _לרשע, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6568017a,0xab640112,0x1a64179e,0x00000000}},	//   emdh, rsüß, _فیضی_, --, 
   {{0xaac82052,0x00000000,0x00000000,0x00000000}},	//   रभरक, --, --, --, 
   {{0x6e20007d,0x42c4009d,0xe3b80205,0x00000000}},	//   _ümbe, үгэн_, rzın_, --, 
   {{0x249c003a,0xdb04003a,0x52741eec,0xe3b8013d}},	//   _devm_, rrhæ, зугу, guı_, 
   {{0x62800034,0x00000000,0x00000000,0x00000000}},	//   ślon, --, --, --, 
   {{0x21300a2e,0x958400ee,0xb9dc0092,0x54340345}},	//   fizh_, _элле, _ጥከ_, ترکر, 
   {{0xeb180d2c,0xeb087f90,0x60400521,0xd0081367}},	//   _दत्त_, _वक्त_, _ịmal, беге_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x0d85cda1,0x13040116,0x645c04cc,0x0454007b}},	//   злан, _хзим, ürie, _علية_, 
   {{0xfe4007d8,0xa2c00825,0xc33004ae,0x00000000}},	// [33760] енто, _वात्, _רוח_, --, 
   {{0x8f741cd0,0xbec000b8,0x00000000,0x00000000}},	//   _нумі, _śīti, --, --, 
   {{0xa3e444ab,0xc04401fb,0x0c2407b5,0x2d540139}},	//   निए_, _mượn_, џмен, käev_, 
   {{0xc04401fb,0x61f400a2,0x00000000,0x00000000}},	//   _lượn_, _üflä, --, --, 
   {{0x80dc015b,0xd6d8012d,0x00000000,0x00000000}},	//   মার্, deł_, --, --, 
   {{0x7d44001f,0x6e24d739,0xa8180451,0x67d435ce}},	//   ኒቨርሲ, mzib, يڪار_, доку, 
   {{0x48fc00ab,0x00000000,0x00000000,0x00000000}},	//   लाबो_, --, --, --, 
   {{0xb761c675,0x8cc000bc,0xa2c000bc,0x7d00007c}},	//   нтый, _लाडो, _वाध्, önsv, 
   {{0xbb41cda2,0x6e25cda3,0xbeb80200,0xdb0403b2}},	//   _четк, nzib, _imët, vuhø, 
   {{0x1cc00135,0x6e240083,0xc76400b8,0x1a240014}},	//   _གཡབ_, izib, _dṛṣt, _کرہُ, 
   {{0xa2c00825,0x21300165,0xd6d8012d,0x2d540166}},	//   _वाद्, vizh_, beł_, bäev_, 
   {{0x2259cda4,0x6f040ba7,0x9f581cce,0x6e2403b9}},	//   жимы_, jjic, üyüm_, kzib, 
   {{0x6f045797,0xf51401d5,0x00000000,0x00000000}},	//   djic, زتیش_, --, --, 
   {{0x6f04208d,0x6e25cda5,0x6ad000fe,0xba8c02dd}},	//   ejic, dzib, _সোমো, _ﺗﯩﻠﮕ, 
   {{0xa7fc0166,0x21300489,0xf558011a,0x00000000}},	//   _agız, rizh_, _הדגמ, --, 
   {{0x8cc8033f,0xb6a00051,0xf438011a,0x00000000}},	//   स्सो, _nhầ, _לתוש, --, 
   {{0xa3e46b9b,0x93440137,0xa3d80456,0xf1a40064}},	// [33770] निक_, _تىيۇ, ठौर_, _прэн, 
   {{0x6f04009f,0xbeb80200,0xd6d8012d,0xe45c0023}},	//   ajic, _amët, zeł_, _ደሓንካ_, 
   {{0x6e241418,0x6f040381,0x7b100bbc,0xdb04007c}},	//   azib, bjic, _uçuk, yrhä, 
   {{0xdb0402d3,0x5b150781,0x5a3413d6,0x1ea80451}},	//   mshë, ьмет, мнет, _ڏاڏي_, 
   {{0x67200023,0xdb040240,0xfe7c0129,0x00000000}},	//   dhmj, lshë, _gaïa_, --, 
   {{0xe9d80826,0xd6d80034,0xfd4401c0,0x6ce4d5d9}},	//   які_, weł_, _хэмн, _пісе, 
   {{0xdb0402d3,0xd954105c,0x7d006eeb,0x8c38013e}},	//   nshë, _uがm_, önsu, _дорӣ_, 
   {{0xdc4400de,0x2ac40114,0x00000000,0x00000000}},	//   _mīļa, _пљув, --, --, 
   {{0x6808013f,0xe9d02c10,0xdb053e07,0xa7fc013d}},	//   bɛdo, _مغل_, hshë, _mgıy, 
   {{0xe6c4248d,0xdb0402d3,0x7d14009a,0x79980ca8}},	//   češć, kshë, nkxs, _iwuw, 
   {{0x78a1cda6,0x2d55cda7,0xdb0402d3,0xd6d011e6}},	//   manv, päev_, jshë, _لقا_, 
   {{0x799801f2,0x78a03b22,0x11d4187f,0xdb040200}},	//   _kwuw, lanv, мігр, dshë, 
   {{0xdb0402d3,0x2f1c03b2,0x28c417ee,0x00000000}},	//   eshë, _níga_, ल्कि, --, 
   {{0x78a1cda8,0xdb0402d3,0xa7fc0139,0x6ed0012c}},	//   nanv, fshë, _agıy, ड्नु, 
   {{0x882c044e,0x2ab40ca8,0x00000000,0x00000000}},	//   _እንተደ, _júbà_, --, --, 
   {{0xdbd803b7,0x7999555f,0x78a1cda9,0x9f540640}},	//   nçõe, _owuw, hanv, ењуј, 
   {{0xdbd8d02b,0xbeb91e81,0x6e25cdaa,0x78a001f4}},	// [33780] içõe, _amës, uzib, kanv, 
   {{0x78a1cdab,0xcc3401ec,0xdb040200,0x63b8031c}},	//   janv, وراع, bshë, żanż, 
   {{0x7998401f,0x0ae8170a,0x78a1cdac,0xb6a001fb}},	//   _awuw, ждей_, danv, _phầ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa2c006ab,0xfe7c002d,0x2f1c0ca8,0xdb04068c}},	//   _वास्, _kaïn_, _gíga_, ishè, 
   {{0x78a1cdad,0x47880b7e,0x8c440eff,0x7d0001e6}},	//   ganv, осим_, _жеге, önst, 
   {{0x38c8f619,0x79980a49,0xb6a0004d,0x6ad003d4}},	//   تانی_, _ewuw, _thầ, _সোণো, 
   {{0x8cc86236,0x78a0257d,0xa7fc0790,0xcba401fe}},	//   स्रो, aanv, _azıc, _наҳй, 
   {{0xd9b01a59,0x08c40107,0x7b100139,0x05f400b8}},	//   _مەند, _обан, _açuw, _bhīḥ_, 
   {{0xdbd806ed,0x78a1cdae,0x20040793,0x6aa1cdaf}},	//   açõe, canv, älik_, _hemf, 
   {{0x290c02fa,0x44280086,0x05f4002b,0x00000000}},	//   _ioda_, àb_, _dhīḥ_, --, 
   {{0x68e9cdb0,0x290c098d,0xdbd806ed,0x6aa1cdb1}},	//   _hadd, _hoda_, cçõe, _jemf, 
   {{0x68e9cdb2,0x290dcdb3,0x3884002e,0xc2180212}},	//   _kadd, _koda_, _yёr_, ієм_, 
   {{0x6aa0021a,0x290dcdb4,0x68e9cdb5,0xdb04044e}},	//   _lemf, _joda_, _jadd, tshë, 
   {{0x68e9cdb6,0x2f1c08ce,0x00000000,0x00000000}},	//   _madd, _síga_, --, --, 
   {{0x6aa02747,0xdb04044e,0x290dcdb7,0x68e9cdb8}},	//   _nemf, rshë, _loda_, _ladd, 
   {{0x64580664,0xdb040023,0x68e80076,0xc108010b}},	// [33790] _hyvi, sshë, _oadd, _дэне_, 
   {{0x290c493b,0x68e9cdb9,0x64580158,0x6578047e}},	//   _noda_, _nadd, _kyvi, _jivh, 
   {{0x6579cdba,0x6aa05b36,0x60c5cdbb,0x691401c3}},	//   _mivh, _bemf, _ichm, _gàei, 
   {{0x65780084,0x68e974f0,0xbeb802d3,0x290c01ab}},	//   _livh, _aadd, _emër, _aoda_, 
   {{0x68e9cdbc,0x78a1cdbd,0x59b1617c,0x38840200}},	//   _badd, tanv, ुंधर, _pёr_, 
   {{0x290dcdbe,0x6aa001e2,0xdeb00220,0x68e9ac15}},	//   _coda_, _eemf, _шұғы, _cadd, 
   {{0x6aa0d2a4,0x6b9c0165,0x78a1cdbf,0x6458143a}},	//   _femf, _gwrg, ranv, _nyvi, 
   {{0x78a1cdc0,0x65780099,0x59b004fa,0x68e87ae4}},	//   sanv, _aivh, ुंदर, _eadd, 
   {{0x7af9cdc1,0x65781aa1,0x290dcdc2,0x60c4358d}},	//   _inut, _bivh, _foda_, _ochm, 
   {{0x1cdcb444,0x68e9cdc3,0x290d4154,0x657800ca}},	//   _ཡིས_, _gadd, _goda_, _civh, 
   {{0x657806d6,0x7af811ad,0x6aa0136f,0xdbd80120}},	//   _divh, _knut, _yemf, pçõe, 
   {{0x8c180302,0xe6940022,0x68e895b6,0x645803cd}},	//   פורי, _аицы, _zadd, _dyvi, 
   {{0xa2c06b9b,0x68e9cdc4,0x645802d2,0xdb04000d}},	//   _वार्, _yadd, _eyvi, duhü, 
   {{0x65782b92,0x3b1c02d1,0x68e80014,0x2d540036}},	//   _givh, _lluq_, _xadd, häer_, 
   {{0xb4a80490,0x28c44a01,0xcef410fc,0xd0084b4d}},	//   गणी_, ल्टि, нчањ, чеве_, 
   {{0x8cc13e7e,0x7af9cdc5,0x60c49da5,0x23340124}},	//   _लाहो, _nnut, _echm, _ахьр, 
   {{0xc69000c8,0x6aa1cdc6,0x8d654dac,0x8cb44623}},	// [337a0] טאן_, _remf, евае, есеч, 
   {{0x7af80882,0x6aa1cdc7,0xefc0001f,0x2d5400c5}},	//   _anut, _semf, ትለው_, väes_, 
   {{0x68e9cdc8,0x6aa0f169,0x68fc026c,0x00000000}},	//   _radd, _pemf, _òrdi, --, 
   {{0x68e9cdc9,0x290c0e21,0x4a4400c0,0xdb0402d2}},	//   _sadd, _soda_, ннев, duhó, 
   {{0x68e8074d,0xbdd801e1,0x6ae003ce,0x00000000}},	//   _padd, _oyèy, _नसीर, --, 
   {{0x68e9cdca,0x7af80393,0x6aa0541c,0xbdd806af}},	//   _qadd, _enut, _wemf, _xxèm, 
   {{0x68e9cdcb,0xa2c0de66,0x6aa0003c,0x65780810}},	//   _vadd, _वाल्, _temf, _rivh, 
   {{0x8b64b888,0x290dcdcc,0x28c5b78a,0x60c80134}},	//   _سازم, _woda_, ल्जि, ɑemu, 
   {{0x290c9ace,0x68e9cdcd,0x6578014f,0xc8940063}},	//   _toda_, _tadd, _pivh, _зрењ, 
   {{0x3321cdce,0x68e802d0,0x00000000,0x00000000}},	//   _alix_, _uadd, --, --, 
   {{0x3321cdcf,0x657801e4,0xa29401ce,0x3514009d}},	//   _blix_, _vivh, кані, хжээ_, 
   {{0x60c5cdd0,0x332002fa,0x46a405f5,0x64580122}},	//   _schm, _clix_, _чадв, _vyvi, 
   {{0x6579cdd1,0x64580204,0xa3e40118,0x00000000}},	//   _tivh, _wyvi, निङ_, --, 
   {{0x83a807d6,0xd5b80220,0xb4f00014,0x6b580022}},	//   _етиб_, _ісі_, _مےٚک, mígu, 
   {{0x332000db,0x6b580077,0xadc40241,0xb4e400cf}},	//   _flix_, lígu, _ikẹr, _سىيم_, 
   {{0x33200798,0x60980451,0x234800f2,0x00000000}},	//   _glix_, _ڪندس_, _تستی_, --, 
   {{0x5d55cdd2,0x238c00bc,0x8cc0012d,0x6b5800c7}},	// [337b0] вкат, _děje_, _लाशो, nígu, 
   {{0x60c40c8c,0xbeb804e6,0x7af8a2ec,0x00000000}},	//   _uchm, _blëc, _snut, --, 
   {{0x23680218,0xe3b806b9,0x7af802f0,0x2d540036}},	//   _khaj_, nrı_, _pnut, täer_, 
   {{0x332031c1,0x1cb4031c,0x199402e8,0xa3b82802}},	//   _xlix_, ཞུང_, вадя, _चिन_, 
   {{0x8ec80729,0x7af813d5,0xe3b80205,0x00000000}},	//   _লোকগ, _vnut, hrı_, --, 
   {{0xbeb80036,0xb4ac01ad,0x2d5401e3,0x00000000}},	//   _flëc, _ओये_, säer_, --, 
   {{0x2d540d16,0x628c0421,0xbeb804e6,0x3b1c0135}},	//   päer_, _ofao, _glëc, _tluq_, 
   {{0xadc40241,0x6b880789,0xdcf4007f,0x282c0023}},	//   _akẹr, _édga, _mizč, _ኤትኒካ, 
   {{0x2b440323,0x645dcdd3,0x6b5802d2,0x00000000}},	//   _сэрг, ürin, gígu, --, 
   {{0xb4a8041c,0x8f300092,0x00000000,0x00000000}},	//   गणे_, _በወንዶ, --, --, 
   {{0x3f54004a,0x2f1c02f0,0x33200254,0xe8946990}},	//   nçus_, _bígl_, _plix_, _сахь, 
   {{0x2369cdd4,0x27f80252,0xe7841d5e,0xd1300092}},	//   _chaj_, _árna_, _суфо, _ባለመኖ, 
   {{0xdcec01e4,0xe3b87b47,0x65944572,0x00000000}},	//   lsaĵ, arı_, _бачу, --, 
   {{0xf5680cdd,0x3569cdd5,0xf8b0012d,0xe3b82ca8}},	//   _эшек_, _эрен_, ीलिय, brı_, 
   {{0xdcec00df,0x1fb4011c,0x26b000d1,0x93440354}},	//   nsaĵ, лстр, _ئەۋز, _инке, 
   {{0xdcf40100,0x23680978,0xa7fc00fd,0x24980205}},	//   _dizč, _ghaj_, _ozın, ırme_, 
   {{0x0354011a,0xad840228,0x6cb4009d,0x50b401f0}},	// [337c0] _ביקש_, اارۇ, лөвт, _исну, 
   {{0x0c741c3e,0x72a402dd,0xdcec008f,0x25a003e0}},	//   نداد, _جەڭن, ksaĵ, _çile_, 
   {{0xa7fc0259,0x80dc00fe,0x00000000,0x00000000}},	//   _azın, মাখ্, --, --, 
   {{0xdcb00208,0xad8400db,0x3ea001ec,0xdc4400ef}},	//   _ổn_, _ماسۇ, _киюг, _līķa, 
   {{0xe8f83d09,0x3f540129,0xc33000d9,0x00000000}},	//   нһа_, rçut_, סוד_, --, 
   {{0x2ee01d0e,0xe3b80790,0xa2d80d79,0x2d54013d}},	//   leif_, yrı_, _फॉन्, cäep_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe3b80790,0xdbcc01e1,0x6b59abac,0x1b00014b}},	//   vrı_, _tóòp, tígu, _гӯшн, 
   {{0xdb1000ae,0x00000000,0x00000000,0x00000000}},	//   _ógán, --, --, --, 
   {{0x2369cdd6,0x3f54500d,0xe3b82523,0xfe7c0137}},	//   _shaj_, nçur_, trı_, _raïm_, 
   {{0x23680211,0x9180001e,0xfe7c004e,0x38c80133}},	//   _phaj_, yện_, _saïm_, _تاقی_, 
   {{0xa195cdd7,0xe3b805d1,0x6b5800c7,0x00000000}},	//   ламч, rrı_, pígu, --, 
   {{0xdb040158,0xba980375,0xa4d452c4,0xf3640e3b}},	//   rrhø, וסכי, _болі, ртэн, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x23680457,0x443800af,0x68fc0e89,0xaab41fad}},	//   _thaj_, _äp_, _òrdu, ुलाक, 
   {{0x26c5cdd8,0xfeb80214,0x291c0037,0x6aa41427}},	//   ngmo_, باست_, hkva_, ðifl, 
   {{0xdd940220,0x00000000,0x00000000,0x00000000}},	// [337d0] уазы, --, --, --, 
   {{0x99dc00a2,0xc0a80244,0xdcfc00c0,0x6d4001e1}},	//   _gyňy, _کاکل_, _tusč, _ìmal, 
   {{0x98a40131,0x9f3401ca,0x30a40006,0x00000000}},	//   қийе, _бені, _трыв, --, 
   {{0xeab0006c,0x3f54004a,0xec69cdd9,0x99dc0432}},	//   قعه_, rçus_, трук_, _zyňy, 
   {{0xfe7c0165,0xef1400cf,0x62800210,0x00000000}},	//   _laïk_, _түтө, ślow, --, 
   {{0x1869cdda,0xac94ae50,0x7c85b5d8,0x00000000}},	//   нали_, _варш, _шуме, --, 
   {{0xa9040345,0xb8d81a75,0x00000000,0x00000000}},	//   شبون, _अय_, --, --, 
   {{0x307c0a1e,0xdcec010f,0xaac40150,0x62e400eb}},	//   ואונ, rsaĵ, _ەتەن, গাঁয়_, 
   {{0x8cc83806,0xf990007b,0x00000000,0x00000000}},	//   स्को, _خبز_, --, --, 
   {{0x34a0016c,0xa6e004c5,0x00000000,0x00000000}},	//   шгоҳ, ভাগট, --, --, 
   {{0x80dc0eac,0xb86408f0,0x00000000,0x00000000}},	//   মাঞ্, _شائو, --, --, 
   {{0x6b585e45,0x81bc0154,0x00000000,0x00000000}},	//   lígr, ীবন_, --, --, 
   {{0xa3b800cd,0x00000000,0x00000000,0x00000000}},	//   _चिथ_, --, --, --, 
   {{0xf04415b4,0x988000e2,0xd9c40154,0xc8300023}},	//   لعزی, rīķi_, _এনাম, _ክንሃን, 
   {{0xb400cf33,0x439000f0,0x00000000,0x00000000}},	//   _түнд, _лајс, --, --, 
   {{0xa3b84f3c,0x32040108,0x00000000,0x00000000}},	//   _चित_, ämys_, --, --, 
   {{0x2ee1cddb,0xdd0000b0,0x0e65cddc,0xa7fc0205}},	// [337e0] reif_, _ōtāw, укан, _azıl, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x628000bc,0x4b4400f1,0x200401f4,0x00000000}},	//   ělov, هګرۍ_, älit_, --, 
   {{0x0a4800a8,0xc9a8010b,0xf64401f7,0x0b440006}},	//   нзей_, евде_, _هئ_, ынен, 
   {{0x2c780b4b,0xbeb801c7,0x291c00f3,0x80a801ad}},	//   dždž_, _klën, tkva_, _जजमे, 
   {{0x1cdc2b65,0x200401e3,0x98f400d1,0x49880092}},	//   _ཡིག_, ålig_, لغىچ, _ኢነርጂ_, 
   {{0xd90c30cd,0xf404004b,0xa6840116,0x291dcddd}},	//   بیل_, _اؤ_, аһед, rkva_, 
   {{0x3a2020e2,0xba2064b6,0xc764568c,0x00000000}},	//   рмәг, рдәк, داتى, --, 
   {{0x499007d6,0x26c40fac,0x09bc0154,0x4a440064}},	//   _ایتر, rgmo_, _ইনকা, _снав, 
   {{0x7b100fcd,0x7f5c010a,0x3f540205,0x00000000}},	//   _uçur, zlqq, hçup_, --, 
   {{0x38c834c9,0xb7d4e94b,0x7d54008d,0xd04c016b}},	//   _سالی_, _مولا_, רייד_, rebɛ, 
   {{0xdcfc002b,0x27e0054e,0xdcf400ef,0xc32400db}},	//   _musā, ăind_, _mizā, اعدى, 
   {{0x503c0020,0xbeb801c7,0xa2d801ad,0x00000000}},	//   _አስከባ, _blën, _फॉण्, --, 
   {{0xa2c001bc,0xf0e8e2db,0x107c00d1,0xf18400d1}},	//   _वाक्, льск_, ﻣﯘﺭﯨ, _ﻫﻮﻗﯘ, 
   {{0x6808013f,0xdcfc0055,0x18340092,0xa2940064}},	//   rɛdw, _nusā, _እንደሞ, _кайі, 
   {{0x3e040801,0x1cdc031c,0x6f8400d4,0x00000000}},	//   лязв, _ཡིང_, сурж, --, 
   {{0xbeb80036,0x1d346950,0x00000000,0x00000000}},	// [337f0] _flën, аная, --, --, 
   {{0xbeb80036,0xa7fc03e0,0x80dc0154,0x00000000}},	//   _glën, _azım, মাঙ্, --, 
   {{0x20040158,0x2bc0190c,0xdfd093fc,0x00000000}},	//   ålid_, शूला, _بيج_, --, 
   {{0x8f980302,0x58fc025c,0x3dcc03d4,0x00000000}},	//   _שירי, _དོངས_, ৰিবল, --, 
   {{0x98a400d8,0x00000000,0x00000000,0x00000000}},	//   аиле, --, --, --, 
   {{0xe8f9cdde,0xdcec0327,0x97b40117,0x00000000}},	//   ллі_, bpaġ, асиш, --, 
   {{0xd7042564,0x27940209,0x25a00003,0xa7fc0166}},	//   изки, бшыр, _ħila_, _uzıl, 
   {{0xa2c016d1,0x18680116,0x243c0092,0x00000000}},	//   _वाग्, наһи_, _ኢትዮሚ, --, 
   {{0xe7081dc8,0x05a4023a,0xa7fca565,0x5a340353}},	//   اتىن_, авый_, _ayıd, _тнат, 
   {{0xb76402dd,0x248c013a,0x8a400345,0xdb0402d2}},	//   _өтей, _čhmú_, _بێهن, guhö, 
   {{0x8cc907c7,0xb9e0887f,0xa88400db,0x00000000}},	//   स्टो, şçıl, _المى, --, 
   {{0x24984ba9,0x68fc1497,0x398801bf,0xd2500050}},	//   ırma_, _òrdr, _køs_, ٲنس_, 
   {{0x79880007,0xbeb804e6,0x00000000,0x00000000}},	//   nqgw, _plën, --, --, 
   {{0x629c1c06,0x79880369,0x543400f2,0x00000000}},	//   abso, iqgw, _پرتر, --, 
   {{0x68fc95fc,0x39880ff7,0x629c007c,0x00000000}},	//   _órde, _løs_, bbso, --, 
   {{0x63bc20be,0x0ca00023,0xff202360,0x00000000}},	//   árne, _ምቑራጽ_, омсо, --, 
  
   {{0x8e7407d6,0x91e40c56,0x62c40137,0x39880feb}},	// [33800] рувч, _топе, _ازىك, _nøs_, 
   {{0x61e89155,0x1704025c,0x0c94010b,0x41000006}},	//   çele, _མོའམ_, ршая, _дзьв, 
   {{0x61e8025c,0x00000000,0x00000000,0x00000000}},	//   ħele, --, --, --, 
   {{0xdb040112,0x50d01788,0x01580023,0xdcf40171}},	//   zuhö, द्रष, _ሃብታም, _vizā, 
   {{0xe895cddf,0xf98dcde0,0x0d740a89,0x2f1dcde1}},	//   баль, وبو_, _вывя, _rígh_, 
   {{0x8b942c0b,0x27685598,0x391001c8,0x645c000d}},	//   _врач, گشتی_, يونز, ürik, 
   {{0x6d5dcde2,0x37a5cde3,0x3988168c,0x87e40032}},	//   _ikra, атын_, _eøs_, рһең_, 
   {{0x6d5c151c,0x7b1000a2,0xf76c5230,0x683c0240}},	//   _hkra, _uçup, واي_, _ክንርስ, 
   {{0xa534084c,0xc8b40956,0x19b8010a,0xa3a80073}},	//   йнич, _نصاب, _бухь_, खीन_, 
   {{0x6b800332,0xb5c40066,0x00000000,0x00000000}},	//   _himg, گویم_, --, --, 
   {{0x6b80036b,0x87040006,0xd90c0451,0x58940137}},	//   _kimg, _вяле, _سڌو_, _ышту, 
   {{0xd6d8068f,0x48fc0316,0x6b8001a9,0x7bc001c3}},	//   koły_, लाको_, _jimg, ànui, 
   {{0x224c825f,0x6b80089c,0xdb05cde4,0x629c00f3}},	//   çek_, _mimg, nshá, rbso, 
   {{0x6d5c013b,0x6b81cde5,0x366402e8,0x3618011a}},	//   _nkra, _limg, _тачо_, _בודד, 
   {{0x746400a7,0xd34403e6,0x00000000,0x00000000}},	//   _кръв_, شییه_, --, --, 
   {{0x6d5d4927,0xa2c00490,0x629c0e14,0xa7fc013d}},	//   _akra, _वाट्, qbso, _azık, 
   {{0x8cc031a0,0x9df800f7,0x91c00150,0x00000000}},	// [33810] _लाखो, ынат_, _нәрл, --, 
   {{0x61edcde6,0x27ec0334,0xfbd00a11,0xbfa80354}},	//   _isal, _osdn_, قتص_, _итме_, 
   {{0xfe7c04cc,0xa11403e6,0x39883c38,0xa2c01a55}},	//   _naïv_, _نوکت, _søs_, _वाञ्, 
   {{0xbeb80221,0xa3a802ab,0xdb04032e,0xab8400d8}},	//   _klëm, खीय_, fshá, цуфк, 
   {{0x6b8000c6,0x6d5c0418,0x38c4be04,0x61ec025c}},	//   _dimg, _fkra, لاغی_, _jsal, 
   {{0x61edcde7,0xa2d802ab,0xd824d021,0x2f1c01e1}},	//   _msal, _फॉस्, йдли, _rígi_, 
   {{0x61ec01b9,0xa7fc1cce,0xf41805ac,0x00000000}},	//   _lsal, _ayıb, _ফেনৰ_, --, 
   {{0x61edcde8,0x6d5c012c,0x6b800135,0x3989cde9}},	//   _osal, _zkra, _gimg, _tøs_, 
   {{0x61edcdea,0x6d5c00ee,0x88800133,0x2c6c02d2}},	//   _nsal, _ykra, زیۆن, _tódí_, 
   {{0x6b8001b9,0xa93402dd,0x2f1c032e,0x09bc00eb}},	//   _zimg, _деуш, _vígi_, _ইনচা, 
   {{0x61edcdeb,0xd05c013f,0x6b80022e,0xd6d80210}},	//   _asal, _dapɛ, _yimg, zoły_, 
   {{0x61ec0175,0xa3b81100,0x6b800166,0x00000000}},	//   _bsal, _चिर_, _ximg, --, 
   {{0x61ec066d,0x92387b17,0xe73000c6,0xc2401f09}},	//   _csal, учну_, _تصل_, зняк, 
   {{0xd7080354,0x413c0023,0x00000000,0x00000000}},	//   _инçе_, _ናብርኦ, --, --, 
   {{0x61edcdec,0xa2c000dc,0xe7ec00c5,0xdff40108}},	//   _esal, _वाच्, ढ़िया_, оять, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6b8069a1,0x15ec000d,0x69cc00c5,0x3f641149}},	// [33820] _rimg, जिटर_, _समधी, сито_, 
   {{0x6b81cded,0xcc88005b,0x06bc0154,0xdb0403b2}},	//   _simg, убже_, _আসছি, vshá, 
   {{0x6b80014f,0x6d5c0010,0xdcfc0171,0xd6d80210}},	//   _pimg, _vkra, _atsē, soły_, 
   {{0x61ec022e,0xc98440f8,0x6d5c012d,0x00000000}},	//   _ysal, буки, _wkra, --, 
   {{0x61ec05b1,0xc86404a9,0x00000000,0x00000000}},	//   _xsal, әтли, --, --, 
   {{0x27ec0334,0x00000000,0x00000000,0x00000000}},	//   _psdn_, --, --, --, 
   {{0xb8d00137,0x6b80004e,0xdb0401bf,0x00000000}},	//   ستوش, _timg, dshæ, --, 
   {{0x81dc02a6,0xbc180302,0xa7140826,0xa7fc03e0}},	//   ণিত_, _גולש, імпі, _ayıc, 
   {{0x249002d3,0xdb0408a5,0x00000000,0x00000000}},	//   _ነበረት_, fshæ, --, --, 
   {{0x1cdc025c,0xa2c04e6d,0x2d840798,0x61ec022e}},	//   _ཡིབ_, _वाङ्, _émeu_, _rsal, 
   {{0x61ec6934,0x00000000,0x00000000,0x00000000}},	//   _ssal, --, --, --, 
   {{0x250869f1,0x61ed3417,0x430826b1,0x00000000}},	//   ارکی_, _psal, ухом_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa2d813b4,0x330801ec,0xaee40055,0x24900092}},	//   _फॉर्, _ۇيىپ_, _tdṛt, _ነበሩት_, 
   {{0x61ec05b1,0x00000000,0x00000000,0x00000000}},	//   _wsal, --, --, --, 
   {{0x61edcdee,0x7de401ec,0x00000000,0x00000000}},	//   _tsal, йізд, --, --, 
   {{0x1cdc08ea,0x61edcdef,0x0c8c02d3,0x9d1497d0}},	// [33830] _ཡིད_, _usal, _ዝቑጸሩ_, одач, 
   {{0x25e0033d,0xa2c000cd,0x00000000,0x00000000}},	//   _कहनी_, वलक्, --, --, 
   {{0x99c40183,0x2bc0134e,0x00000000,0x00000000}},	//   _এনেক, शंगा, --, --, 
   {{0xd9f99190,0xde580024,0x00000000,0x00000000}},	//   инец_, _вамі_, --, --, 
   {{0xbdd800f7,0xa2b008ec,0x00000000,0x00000000}},	//   _exèr, _अजन्, --, --, 
   {{0x7f60069c,0xada4039b,0xd7c8004b,0xa3b801f9}},	//   _ሰብኣዊ_, _хаёл, لوته_, _चिं_, 
   {{0x2795cdf0,0xd709cdf1,0x18680107,0xac180354}},	//   пшыр, инке_, шаки_, _лору_, 
   {{0xead40024,0x00000000,0x00000000,0x00000000}},	//   _нось, --, --, --, 
   {{0x2d8406af,0x3ea80356,0xed580133,0x00000000}},	//   _émet_, _mect_, _خشێت_, --, 
   {{0x3ea83657,0x94780452,0x00000000,0x00000000}},	//   _lect_, исну_, --, --, 
   {{0x1cdc3aaf,0xd469cdf2,0xdb05cdf3,0x69c4004e}},	//   _ཡིན_, рине_, rshæ, àiev, 
   {{0x795c025a,0x63bc429f,0x00000000,0x00000000}},	//   rêwu, árna, --, --, 
   {{0xfe7dcdf4,0x10f400a7,0xdb04007c,0x00000000}},	//   _maïs_, оявя, mshä, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x60c003b2,0x00000000,0x00000000,0x00000000}},	//   ólma, --, --, --, 
   {{0x45280020,0xdb0401e3,0x00000000,0x00000000}},	//   _ስለነበ, nshä, --, --, 
   {{0x645c0254,0x00000000,0x00000000,0x00000000}},	// [33840] üriv, --, --, --, 
   {{0xf1540133,0x00000000,0x00000000,0x00000000}},	//   _رێزد, --, --, --, 
   {{0xc6142db8,0x8f74177b,0x8a8800d1,0x0bb435c7}},	//   _तथ्य_, _мумі, айев_, ющая, 
   {{0x27f809f3,0xbdd800db,0x3ea80327,0x6b6c0432}},	//   _árni_, _exèq, _gect_, _yşgy, 
   {{0xc330008d,0x98a40e2d,0xdb04007c,0x00000000}},	//   ווא_, _aklı_, dshä, --, 
   {{0xa91c00d7,0x50a800cd,0x00000000,0x00000000}},	//   _biľa, करिष, --, --, 
   {{0xc1d400bc,0x61280064,0x00000000,0x00000000}},	//   _ढङ्ग, gžly, --, --, 
   {{0xca7400c7,0xdb045df7,0xb7600137,0xa61401df}},	//   _дузы, gshä, мтый, змич, 
   {{0x45480414,0xfe7c0129,0x250810e8,0x59d009ab}},	//   ичом_, _haïr_, مردی_, _समयर, 
   {{0xa91c0419,0xbb340220,0x00000000,0x00000000}},	//   _fiľa, _ﯗﻟﻰ_, --, --, 
   {{0x351401c6,0x61300248,0xe2f801ec,0x99740408}},	//   цжээ_, _lólù, бені_, _хутш, 
   {{0x9f640174,0x00000000,0x00000000,0x00000000}},	//   _átøk_, --, --, --, 
   {{0x3ea9cdf5,0xb284035b,0x00000000,0x00000000}},	//   _rect_, дырк, --, --, 
   {{0x3ea9cdf6,0xa7fc00a2,0xd6d8012d,0x00000000}},	//   _sect_, _zyıa, miła_, --, 
   {{0xd6d8033f,0x00000000,0x00000000,0x00000000}},	//   liła_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x408400d1,0xdcb85b7f,0x3ea9cdf7,0xd6d8012d}},	// [33850] _мунб, йгач_, _vect_, niła_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfe7c068c,0xea980521,0x9f4400e5,0xdb040108}},	//   _païs_, _ịhụn, íló_, yshä, 
   {{0x5b15cdf8,0xdb040fac,0x00000000,0x00000000}},	//   ямет, kshå, --, --, 
   {{0xbdd8004e,0x79a40220,0x554c0023,0x2f1c08ce}},	//   _txèq, ірде, _ንጴጥሮ, _vígt_, 
   {{0xdb04332e,0xa7fc00a2,0x5d78010f,0xed580006}},	//   dshå, _syıa, _לאָק, _моў_, 
   {{0x1a645c81,0xdb04343a,0x91f40327,0x00000000}},	//   _کیشی_, tshä, _བླླག_, --, 
   {{0xdb041196,0xd6d8012d,0x00000000,0x00000000}},	//   ushä, fiła_, --, --, 
   {{0x7bd4005a,0xdb04007c,0x00000000,0x00000000}},	//   ltxu, gshå, --, --, 
   {{0x7999cdf9,0xdb0402c1,0x00000000,0x00000000}},	//   _ituw, sshä, --, --, 
   {{0x7bd401c6,0x00000000,0x00000000,0x00000000}},	//   ntxu, --, --, --, 
   {{0x95940046,0x91e41b88,0x7bd4005a,0xd6d8033f}},	//   _ешкі, поме, itxu, biła_, 
   {{0xd6d8033f,0x7d0402d0,0x422002e8,0xa9000154}},	//   ciła_, _onjs, едяв, ্সরড_, 
   {{0x8678025f,0x7999cdfa,0x25e01d15,0x63c803b2}},	//   _פרסו, _mtuw, _कहती_, ðsnø, 
   {{0x645c00c5,0x91800131,0xb454009f,0x00000000}},	//   ürit, _ۋۇجۇ, _بخشش, --, 
   {{0x79983eda,0x52740131,0x00000000,0x00000000}},	//   _otuw, _нупу, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [33860] --, --, --, --, 
   {{0x7d04067c,0xa3a80073,0x2de002dd,0x00000000}},	//   _cnjs, खीव_, _ﺇﺴﻼﻤ, --, 
   {{0xa7fc7b54,0x79980a49,0x5ba402bf,0x2a640175}},	//   _ayın, _atuw, дріз, _symb_, 
   {{0x32005138,0xdb04002d,0x81dc00eb,0x00000000}},	//   _kriy_, mshû, ণির_, --, 
   {{0x9e940014,0xdb04002d,0xc3300375,0x8b6400e5}},	//   _تاپچ, lshû, עוד_, _ہارم, 
   {{0xbb440116,0x00000000,0x00000000,0x00000000}},	//   يلەن_, --, --, --, 
   {{0x8b64e5e7,0x79981418,0xd6d80034,0x0c780137}},	//   _فارم, _etuw, wiła_, _ысмы_, 
   {{0x9f4803ee,0x3200022e,0x00000000,0x00000000}},	//   ıkça_, _oriy_, --, --, 
   {{0x9a140a93,0x00000000,0x00000000,0x00000000}},	//   _оффш, --, --, --, 
   {{0x63bc02fb,0x38c94d83,0xdb04007c,0x00000000}},	//   árno, _هامی_, rshå, --, 
   {{0x3200f1de,0xc6a5cdfb,0xd6d8033f,0xdb041654}},	//   _ariy_, _ерли, siła_, sshå, 
   {{0xdb04002d,0xd6d8012d,0x940403e3,0x00000000}},	//   dshû, piła_, nclə_, --, 
   {{0x32000076,0xd70802e5,0x9ebc0150,0x00000000}},	//   _criy_, वारथ_, _ﻛﻪرە, --, 
   {{0x6b9c05a1,0xf67804ae,0x85780395,0x645c2349}},	//   _otrg, _האדמ, _усет_, üris, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x656801e6,0x00000000,0x00000000,0x00000000}},	//   lldh, --, --, --, 
   {{0x788000dd,0x796c013f,0x32000100,0xb1e40075}},	// [33870] _kívü, _wɔwɑ, _griy_, _пәрқ, 
   {{0x80a001d9,0xfd440006,0x7bd4031c,0x00000000}},	//   _سۅرن, чэбн, ttxu, --, 
   {{0x7998257d,0x80b000cc,0x656801ab,0x9b4400f2}},	//   _stuw, _জাপ্, ildh, ونطو, 
   {{0xac742d74,0x7bd401c6,0xdb041427,0xf8dc0118}},	//   رالش, rtxu, lshú, प्नय, 
   {{0x7f5c01b9,0x6b9c0427,0xa7fc0139,0x4ef8011a}},	//   moqq, _etrg, _qyın, _והרו, 
   {{0x5d859c56,0x7f5dcdfc,0xa92402dd,0xdb0403f2}},	//   _زلزل, loqq, нділ, nshú, 
   {{0x81e000bd,0x6e2000af,0x47d005d9,0x1cdc025c}},	//   নটি_, _ümbr, نيور, _རྡར_, 
   {{0x66057a1e,0x6569cdfd,0x7f5c013c,0xe6b4ba84}},	//   _šika, eldh, noqq, ىلىگ, 
   {{0x7998556c,0xed50004b,0x80b0015b,0xa7fc00fd}},	//   _utuw, _شپې_, _জান্, _uyın, 
   {{0xb3e44933,0x7ae9cdfe,0x81e0015b,0x057400c6}},	//   _འགྱུ, legt, নটা_, ومية_, 
   {{0xa3a80574,0x7f5c0869,0x96b8004e,0x00000000}},	//   खील_, koqq, _дулу_, --, 
   {{0x3200083a,0x7f5c0af5,0x1cdc0003,0x527400f7}},	//   _priy_, joqq, _རྡལ_, дугу, 
   {{0xbeb8017a,0xe73000c6,0x7f5c014f,0xe2b401c6}},	//   _koëf, _حصل_, doqq, эсээ, 
   {{0x7ae979d3,0xdb04d381,0x53c417c6,0x649802e8}},	//   hegt, tshû, _विपश, _етър_, 
   {{0xefe8001f,0x35d000e1,0xa2d802a0,0x7f5c01a9}},	//   _ሚዲያ_, _दमड़, _फॉक्, foqq, 
   {{0x7f5c0869,0xdb04000f,0xeb0c060c,0xff04084c}},	//   goqq, rshû, _सचेत_, меск_, 
   {{0x6b9c549d,0x257005da,0x0d84327b,0x7ae9cdff}},	// [33880] _strg, làla_, длан, degt, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x257005da,0x0b59ce00,0x7f5c014f,0x904401f7}},	//   nàla_, орды_, boqq, _آنجه, 
   {{0x4a45ce01,0x6b9c0010,0x17f800dc,0x53c400dc}},	//   мнев, _vtrg, ्मैव_, _विनश, 
   {{0xa2b00825,0x2be0000d,0x00000000,0x00000000}},	//   _अजस्, _नहवा, --, --, 
   {{0xbeb801f5,0x7bc030de,0x187802d3,0x67d4033a}},	//   _coëf, ánuc, _ብሕጽር_, еоку, 
   {{0xa7fc0166,0x6b9c0427,0x06640131,0x00000000}},	//   _azır, _utrg, ﺷﯩﻨﯩ, --, 
   {{0x68f8011c,0x25700109,0x7a3401f2,0xb900013d}},	//   sdvd, dàla_, ụtan, езәк, 
   {{0x6e25ce02,0xbb41ce03,0x00000000,0x00000000}},	//   nyib, _ретк, --, --, 
   {{0x6e240083,0xd6d8012d,0x7f5c022e,0x487442f4}},	//   iyib, biło_, zoqq, _قداس, 
   {{0xa3a8033d,0xe2f9cb6f,0xd6d8012d,0x7f5dce04}},	//   खीं_, пені_, ciło_, yoqq, 
   {{0xb6a0035b,0xfbb4011a,0xf8340677,0x00000000}},	//   _аицл, ופטת_, _קנאת_, --, 
   {{0x6e2400ca,0x62240131,0xbeb8017a,0x91a8033f}},	//   jyib, رىسل, _hoëg, जीलै, 
   {{0x61fcebd4,0x6e240280,0x7ae97638,0x25700083}},	//   rvsl, dyib, zegt, bàla_, 
   {{0x7f5c0eda,0xa3b80b67,0x116800e5,0xe28400e5}},	//   toqq, _चिट_, سلفی_, بطگی, 
   {{0x33180f13,0xe3b82d1c,0xc10001c6,0x3eac0162}},	//   _يزيد_, msı_, хүүл, úgt_, 
   {{0x6e246ce7,0xbf1c0c2e,0x7ae805e4,0x7f5dce05}},	// [33890] gyib, _यकीन_, vegt, roqq, 
   {{0x7f5c0140,0x7ae80ade,0xa7fc0205,0x00000000}},	//   soqq, wegt, _ayım, --, 
   {{0xe3b9c6f3,0xbeb8092e,0x628c8ad8,0x20000c67}},	//   nsı_, _blët, _kgao, _urhi_, 
   {{0x6e240796,0x2bd00cb4,0x7f5c0140,0x00000000}},	//   byib, _हमरा, qoqq, --, 
   {{0x7ae9ce06,0x6e257de6,0xdddc068f,0xd6d8033f}},	//   regt, cyib, _wysł, wiło_, 
   {{0xe3b8456f,0x7c3803f9,0xa7fc0139,0x7ae82964}},	//   ksı_, _ƙurd, _azıq, segt, 
   {{0x628dce07,0x10780075,0xbeb8003a,0x9f6403b2}},	//   _ogao, ﻠﯩﺪﯨ, _coëg, _átók_, 
   {{0x628dce08,0xbeb80036,0xa3b8629c,0x00000000}},	//   _ngao, _glët, _चिज_, --, 
   {{0xdb040450,0xd6d8012d,0x77789323,0x5f2000cc}},	//   dshø, siło_, rmux, _নগাও_, 
   {{0x628dce09,0xbeb8017a,0x53a40117,0x25e0000d}},	//   _agao, _hoëd, наоб, _कहरी_, 
   {{0x9345ce0a,0xd6d02bef,0xe3b80166,0x00000000}},	//   енне, _مقا_, gsı_, --, 
   {{0xf4801f7e,0xdb043a26,0x8c18011a,0x96340064}},	//   _یاغی, gshø, לותי, _пнец, 
   {{0xa2b00050,0x362001d9,0x537c001f,0xe5b40006}},	//   _अजर्, _جوشہ, _የኒውስ_, _айчы, 
   {{0xe6104d1c,0x6e24019f,0x2bd01d8a,0x628dce0b}},	//   _خشم_, vyib, _हमला, _egao, 
   {{0x1cdc025c,0x1fb4ff3c,0x63a5ce0c,0x00000000}},	//   _རྡེ_, кстр, _čing, --, 
   {{0x6e247aaf,0x63bc054e,0x00000000,0x00000000}},	//   tyib, ârne, --, --, 
   {{0x0dc800cb,0x227800db,0x00000000,0x00000000}},	// [338a0] ялай_, _ۉلۉگ_, --, --, 
   {{0x6e2400ca,0x101402d5,0xe7f000c5,0x00000000}},	//   ryib, _зьмя, _अईला_, --, 
   {{0x8b249a30,0x0ae81d37,0xe3b80205,0x00000000}},	//   ндже, здей_, yyım_, --, 
   {{0x25e0007d,0xbf980a1e,0x00000000,0x00000000}},	//   _कहली_, _מיטש, --, --, 
   {{0x28f9ce0d,0xfb841550,0x7b841870,0x00000000}},	//   дель_, ردمی, رامە, --, 
   {{0x66040122,0xbeb804e6,0xe3b800fd,0x8c440395}},	//   _šiko, _flës, ysı_, _зеге, 
   {{0xfce00212,0x00000000,0x00000000,0x00000000}},	//   _щоро, --, --, --, 
   {{0xbeb80023,0x668402f2,0xd9b00e56,0x00000000}},	//   _ulët, نیال, _چەند, --, 
   {{0xa495ce0e,0xd9b001ec,0x88c8010a,0x00000000}},	//   نیشت, _نەند, _нлав_, --, 
   {{0x628c0192,0xe3b82737,0x00000000,0x00000000}},	//   _sgao, tsı_, --, --, 
   {{0x290dce0f,0x10780075,0xdb04366f,0x46a400d8}},	//   _inda_, ﻠﯩﺮﯨ, tshø, _заев, 
   {{0xe3b8456f,0xded002d3,0xdce402fb,0xbeb80200}},	//   rsı_, ኦትን_, vlhč, _llër, 
   {{0xc0380020,0xe3b80724,0xa5f80063,0xdb04365a}},	//   _አስመል, ssı_, _целу_, rshø, 
   {{0xd24c104b,0xdb0403cd,0x62f000cc,0xe3b808a9}},	//   تچى_, sshø, টাইট_, psı_, 
   {{0xf2b000bd,0x2ee0031c,0xb4f8011a,0x00000000}},	//   _কারণ, ffif_, _מפגי, --, 
   {{0x628c3421,0xc68c001f,0x383c0023,0xa7fc0790}},	//   _ugao, _መሳሪያ_, _ክንቅበ, _ayık, 
   {{0x1cdc025c,0x34800022,0xdcfc0055,0x00000000}},	// [338b0] _རྡུ_, _игәг, _utsī, --, 
   {{0x290c1682,0x2ee0020c,0xbeb801c7,0x80dc0154}},	//   _nnda_, afif_, _plës, _ফোর্, 
   {{0x5f800150,0x660401ef,0x00000000,0x00000000}},	//   _نۇسە, _šikl, --, --, 
   {{0x290dce10,0xffa001c0,0x80d405dc,0xdb1c03e3}},	//   _anda_, _илүү, _बाडे, _özüy, 
   {{0x290c0ac5,0xbeb8002e,0x64580381,0xceb4011a}},	//   _bnda_, _flër, _lxvi, _בפרק_, 
   {{0x290c020b,0x645802d0,0xfc6402e8,0x00000000}},	//   _cnda_, _oxvi, _зъбн, --, 
   {{0x9c6404fb,0xbeb8036e,0xac58014b,0x00000000}},	//   _شهرو, _ulës, _зарф_, --, 
   {{0x3f907638,0x9a840116,0x00000000,0x00000000}},	//   _muxu_, _җуғл, --, --, 
   {{0x3f89ce11,0x3f91631a,0x1995aedc,0x7af9ce12}},	//   _micu_, _luxu_, _разя, _iaut, 
   {{0x7af9b40a,0x3f88098d,0x290c0280,0x00000000}},	//   _haut, _licu_, _gnda_, --, 
   {{0x7af9ce13,0x64580393,0xf77003e6,0xe0f40327}},	//   _kaut, _cxvi, _یاڵ_, _བལྟད_, 
   {{0x3945ce14,0x7af9ce15,0x1878044e,0x3f880276}},	//   lins_, _jaut, _ብንጹር_, _nicu_, 
   {{0x7af9ce16,0x290c0652,0x32041155,0x00000000}},	//   _maut, _ynda_, ímy_, --, 
   {{0x7af9ce17,0x3945ce18,0x3f900327,0xc0dc02d3}},	//   _laut, nins_, _buxu_, _ንበል_, 
   {{0x3f89ce19,0x43901fbe,0x95c800fd,0x00000000}},	//   _bicu_, _кајс, _хуҗа_, --, 
   {{0x7af9ce1a,0x3945ce1b,0x3f88107d,0x9f4002d2}},	//   _naut, hins_, _cicu_, _fphí_, 
   {{0x3945ce1c,0x3f882b1d,0x3f64c1ef,0x4d6400a7}},	// [338c0] kins_, _dicu_, тито_, вкав, 
   {{0x7af80607,0x3945ce1d,0x1cdc0327,0x910400c7}},	//   _aaut, jins_, _རྡཱ_, _рпое, 
   {{0xc0e80020,0x6458daf0,0x80d4068f,0x68fc45a7}},	//   ሆንም_, _xxvi, _बाते, _órdi, 
   {{0x3f89ce1e,0x41b053e2,0x7af974fe,0x290c003e}},	//   _gicu_, _حمیر, _caut, _snda_, 
   {{0x7af9ce1f,0x33200007,0x8c943334,0x3945ce20}},	//   _daut, _moix_, _арбі, fins_, 
   {{0x3945ce21,0x332001c7,0x7af8127b,0x61e851bb}},	//   gins_, _loix_, _eaut, çeli, 
   {{0x7af9ce22,0x8c45ce23,0x3b1c0007,0xdb4ca04e}},	//   _faut, _реве, _fouq_, _کێن_, 
   {{0x3321ce24,0x8a041920,0x3b1c0097,0x3945ce25}},	//   _noix_, _избе, _gouq_, ains_, 
   {{0x3945ce26,0x35b00124,0xf48001d5,0x80b00154}},	//   bins_, абыр, یاپی, _জাস্, 
   {{0x290dce27,0x7af9ce28,0x3945ce29,0xf64c00d1}},	//   _unda_, _zaut, cins_, تئى_, 
   {{0x7af80a73,0x3b1c0207,0x332000cf,0x16140eff}},	//   _yaut, _youq_, _boix_, _ەسىڭ, 
   {{0x46a40801,0x332000db,0xf364de2f,0xa3d40d79}},	//   _радв, _coix_, итян, िंब_, 
   {{0x3f880113,0xf40c03d4,0x84f40107,0x7ed40133}},	//   _ricu_, ানগৰ_, _адлӣ_, ێزرا, 
   {{0x3f88003c,0xdfd55e7e,0x683c02d3,0x80b000fe}},	//   _sicu_, логы, _ክንሓስ, _জাহ্, 
   {{0x33210baf,0xd24c07d6,0xadc40248,0x69cc00af}},	//   _foix_, قچی_, _ijẹr, _समझी, 
   {{0x3945ce2a,0x61d802e8,0xd24c0137,0x00000000}},	//   zins_, _змия_, تچۉ_, --, 
   {{0x7af9ce2b,0x3f900050,0x88c804c5,0x3f8819f5}},	// [338d0] _raut, _wuxu_, ল্যক, _vicu_, 
   {{0x3945ce2c,0x3b1dce2d,0x3f901bce,0x629c01d3}},	//   xins_, _souq_, _tuxu_, lcso, 
   {{0x7af9ce2e,0x3f88192e,0xbeb80036,0x3158008f}},	//   _paut, _ticu_, _flëp, _ביזן_, 
   {{0x3945ce2f,0x5a3414a4,0x95e802f5,0x629c01ed}},	//   wins_, лнет, কটতম_, ncso, 
   {{0x3945ce30,0x7af81e54,0x21200280,0xa3d402ab}},	//   tins_, _vaut, _kohh_, िंड_, 
   {{0x7af9ce31,0xe8f90617,0x60d40097,0x1cdc031c}},	//   _waut, клі_, ngzm, _རཡི_, 
   {{0x7af9ce32,0x3945ce33,0x236801e4,0x2b440175}},	//   _taut, rins_, _okaj_, _fmmc_, 
   {{0x3945ce34,0x236801d4,0xadc401e1,0x2120020b}},	//   sins_, _nkaj_, _ajẹr, _lohh_, 
   {{0x2121ce35,0x46e40323,0x2b4405f5,0x33200399}},	//   _oohh_, удын_, _тэрг, _roix_, 
   {{0x21200254,0x1614012d,0x00000000,0x00000000}},	//   _nohh_, तमबर_, --, --, 
   {{0xb2dc01ec,0xe8943de2,0x00000000,0x00000000}},	//   _ﺃﻋﻭﺍ, _тахь, --, --, 
   {{0x11d41fe2,0xf8dc0c00,0x80b0009e,0xdb0c005b}},	//   лігр, प्रय, _জাষ্, _äkäi, 
   {{0x33218156,0xe610168d,0xca940150,0x53c41157}},	//   _voix_, _وشه_, _ﺘﺯﻴﺩ_, _विवश, 
   {{0x934400fd,0xcfa84c3a,0x3d14012d,0x00000000}},	//   _әние, فارم_, नाफे_, --, 
   {{0x3d142232,0xdb0403b2,0x4f780108,0x7bc1ce36}},	//   नाने_, nshó, ещая_, ánul, 
   {{0x69c41533,0x383c0023,0x00000000,0x00000000}},	//   _रिली, _ክንሕብ, --, --, 
   {{0x80b000bd,0xc69000c8,0x1cdc025c,0x00000000}},	// [338e0] _জার্, מאן_, _རྡང_, --, 
   {{0xc8d0c881,0xe6d01944,0xc0e00354,0xf00401af}},	//   _साइट, _सञ्ज, _лоьк, _күги, 
   {{0x7ee01b92,0x7c3803f9,0x80d8011a,0xfce0005a}},	//   شكەن, _ƙura, _אחיז, сохо, 
   {{0x8ec004d3,0x4fc400c7,0x00000000,0x00000000}},	//   _دڵسۆ, _исҭа, --, --, 
   {{0x82d404ac,0x2120020c,0x6d8801d3,0xff040117}},	//   רונג_, _yohh_, _لمحہ_, _сеяк_, 
   {{0x6ea007b7,0x27383b2d,0xd76404fb,0xf76c2374}},	//   गुरु, _kéng_, ینوی, ۋاي_, 
   {{0xd90c2f0c,0x273906f7,0x98c401ec,0x683c0240}},	//   ظیم_, _jéng_, рсіл, _ክንመስ, 
   {{0xb8c807ba,0x27380a40,0x248001e4,0x637c01c7}},	//   _क्_, _méng_, _ŝimo_, méng, 
   {{0xa53428e8,0x27380036,0xf64c0451,0x637dce37}},	//   инич, _léng_, ٻئي_, léng, 
   {{0x2369ce38,0x69c003e0,0x3d140950,0x9f6401a8}},	//   _skaj_, _ivme, नाये_, _átök_, 
   {{0xb89006d5,0x86e4006c,0x245800d6,0x291c0369}},	//   _المع, _бўлд, тань_, mjva_, 
   {{0x80d4dad1,0x27ec4405,0xe3b800db,0x00000000}},	//   _बाहे, _ipdn_, нбү_, --, 
   {{0x96b9ce39,0x637dce3a,0xa19443b6,0x6d040034}},	//   _руху_, héng, рагч, रयाग_, 
   {{0x69c00066,0xa3d403e5,0x637c003e,0x27380051}},	//   _mvme, िंद_, kéng, _béng_, 
   {{0x629c00f8,0x27380098,0xc8d02765,0x637c0c6a}},	//   pcso, _céng_, _साईट, jéng, 
   {{0x637dce3b,0x27380a40,0x212002ea,0x69c0014f}},	//   déng, _déng_, _wohh_, _ovme, 
   {{0x1e143298,0x9df9ce3c,0x69c000d7,0x00000000}},	// [338f0] шмая, ънат_, _nvme, --, 
   {{0x61edce3d,0xdb040129,0x2bd00073,0x768803e0}},	//   _ipal, mphé, _हमखा, _höyü, 
   {{0xbc0402d5,0x69c12f98,0x768803ee,0x27380221}},	//   ычай, _avme, _köyü, _géng_, 
   {{0x61edce3e,0x99d42309,0xdb0403b2,0x00000000}},	//   _kpal, لتتا, vshó, --, 
   {{0xf9c43417,0x637dce3f,0x273804e6,0xda640120}},	//   ущен, ménd, _zéng_, јвли, 
   {{0x637c00d5,0xd8242097,0x61edcd26,0xac940510}},	//   lénd, идли, _mpal, _гарш, 
   {{0x637c0098,0xdb8801ee,0xa9040472,0x00000000}},	//   céng, _араһ_, صبون, --, 
   {{0x637d069d,0xd708034b,0x29180192,0x00000000}},	//   nénd, тние_, _òran_, --, 
   {{0x18b800ee,0x61ec01e1,0x00000000,0x00000000}},	//   _агзы_, _npal, --, --, 
   {{0x60c4004d,0x543401b9,0x00000000,0x00000000}},	//   _ndhm, لرجر, --, --, 
   {{0x76880cc1,0x61edce40,0x5724313e,0x00000000}},	//   _böyü, _apal, _پىشك, --, 
   {{0x60c400c6,0x273801c7,0x61ec01e7,0xdb040129}},	//   _adhm, _réng_, _bpal, uphè, 
   {{0x7bc13694,0x768803be,0x2739ce41,0x52742a20}},	//   ánuj, _döyü, _séng_, руну, 
   {{0xdb0459c6,0x273801c7,0x63a80175,0x4638010f}},	//   sphè, _péng_, bpdn, _בענע, 
   {{0x61edce42,0x80d400ce,0x637dce43,0xeccc0154}},	//   _epal, _बारे, fénd, র্ডড, 
   {{0x564002d3,0x7521ce44,0x6604107d,0x637c8616}},	//   _ክትነብ, _honz, _šiki, génd, 
   {{0xd1740276,0x637c893a,0x00000000,0x00000000}},	// [33900] _выны, wéng, --, --, 
   {{0x752001a9,0x27380098,0x637dce45,0x25a001e7}},	//   _jonz, _téng_, téng, _éile_, 
   {{0xc5f1ce46,0x7521ce47,0x637c0077,0x14dc0073}},	//   _अन्य_, _monz, bénd, _मानण, 
   {{0x637dce48,0x7521ce49,0x2739ce4a,0xadb8005e}},	//   réng, _lonz, _kéne_, _مۇرا_, 
   {{0x680001d3,0x637c003e,0x9f0400f1,0x00000000}},	//   kájá, séng, _اوټو, --, 
   {{0x637dce4b,0x53c400dc,0x8274010f,0xa7fc0166}},	//   méne, _विंश, בענע_, _oyıt, 
   {{0x2cb8002d,0x27381bce,0x4ab80276,0x637c01d3}},	//   _ierd_, _léne_, _аузя_, léne, 
   {{0xe66802d3,0x2cb80e21,0x3a2000b1,0x00000000}},	//   _ምስግጋ, _herd_, смәг, --, 
   {{0x752037b6,0x2738002e,0xa6140415,0x99e84b7c}},	//   _bonz, _néne_, ёмоч, _معلق_, 
   {{0x7521ce4c,0x5918025c,0xbeb80036,0x7689ce4d}},	//   _conz, _ྱོགས_, _noën, _söyü, 
   {{0x61edce4e,0x7521ce4f,0x2cb9ce50,0x637c3eba}},	//   _spal, _donz, _merd_, yénd, 
   {{0x27381bce,0x61edce51,0x637c01d3,0xc669ce52}},	//   _béne_, _ppal, kéne, _ишле_, 
   {{0x7521ce53,0x2cb8002d,0x9abc1bce,0x6d400006}},	//   _fonz, _oerd_, _joŋa, _įman, 
   {{0x273801c7,0x59c825fe,0x2004003a,0xfe7c0142}},	//   _déne_, _रिसर, ælio_, _sbïo_, 
   {{0x637c1709,0x75780a1e,0xe3a42ab4,0xdb04004a}},	//   ténd, _שטופ, _اشتی, sphé, 
   {{0x7521ce54,0x2cb80036,0x3f8c0008,0x65698b72}},	//   _zonz, _aerd_, ögu_, lodh, 
   {{0x637dce55,0x2738002e,0x75206c35,0x2cb9ce56}},	// [33910] rénd, _géne_, _yonz, _berd_, 
   {{0x60c4009f,0x6569ce57,0x20040158,0x637c003e}},	//   _udhm, nodh, ålis_, sénd, 
   {{0x443dce58,0x637c0c6a,0x656801ab,0x2cb803b9}},	//   nzt_, pénd, iodh, _derd_, 
   {{0x6569ce59,0xdcfc00e2,0x273800e8,0x443c2305}},	//   hodh, _pusē, _yéne_, izt_, 
   {{0x6569ce5a,0x2cb9161c,0x18a404b4,0xbeb8022e}},	//   kodh, _ferd_, балм, _yoën, 
   {{0x63a403c6,0x6569ce5b,0xa9c400db,0x00000000}},	//   _činn, jodh, زۅمۉ, --, 
   {{0x75200395,0x59c805f9,0xac19ce5c,0x65680200}},	//   _ronz, _रिवर, _кору_, dodh, 
   {{0x752006ee,0x443dce5d,0x9a8801d9,0xead406a6}},	//   _sonz, dzt_, _منزٕ_, _мось, 
   {{0x75200395,0x443c00e2,0xa7fc0213,0x5a34030d}},	//   _ponz, ezt_, _axıd, _унат, 
   {{0x6569ce5e,0x752006be,0x00000000,0x00000000}},	//   godh, _qonz, --, --, 
   {{0xa8a56c5d,0x1cdc031c,0x7521ce5f,0x27381bce}},	//   _фрук, _རྡབ_, _vonz, _séne_, 
   {{0x7521ce60,0xe784020a,0xdcec00df,0x637c01d3}},	//   _wonz, _дучо, mpaĵ, yéne, 
   {{0xd250b23e,0x65680a28,0x7520aba9,0x637c056a}},	//   سنس_, bodh, _tonz, xéne, 
   {{0xa56470bc,0x256401d9,0xdcec010f,0xa7fc0205}},	//   _ودون, _واوُ, opaĵ, _azıy, 
   {{0xaad809bb,0x637c0066,0x8fa4c502,0x443c0332}},	//   _डालक, wéne, сабе, czt_, 
   {{0x637d92f1,0x00000000,0x00000000,0x00000000}},	//   téne, --, --, --, 
   {{0x2cb9ce61,0xd6e40183,0xccc457c2,0x8e7401a9}},	// [33920] _perd_, _খোৱা_, йбай, сувч, 
   {{0x9abc002e,0x2cb8031c,0x637dce62,0xfce1251c}},	//   _roŋa, _qerd_, réne, зофо, 
   {{0x637c00dd,0x00000000,0x00000000,0x00000000}},	//   séne, --, --, --, 
   {{0x2cb9ce63,0xbeb801c7,0x6569ce64,0xc0f00023}},	//   _werd_, _joël, zodh, ልድል_, 
   {{0x656890d7,0x637c180f,0x0948209b,0x6f040393}},	//   yodh, lénc, лчки_, mdic, 
   {{0x8b95174b,0x69340116,0x00000000,0x00000000}},	//   _грач, юнлу, --, --, 
   {{0xa7fc9d58,0xf76d4e9f,0x6d5c02d1,0x637c180f}},	//   _ayır, کاو_, _ijra, nénc, 
   {{0x6f04ffe4,0xbeb80109,0x65680810,0xcb6802d5}},	//   ndic, _noël, wodh, _сабе_, 
   {{0x6f05ce65,0x2d8406af,0x6569ce66,0xd5b001d3}},	//   idic, _èmes_, todh, وفٹ_, 
   {{0x443cb044,0x637c003e,0x6f04047e,0xaad80118}},	//   tzt_, kénc, hdic, _डाँक, 
   {{0x65680a28,0xbeb8022e,0x83840220,0x6f04007f}},	//   rodh, _boël, йыме, kdic, 
   {{0x6569ce67,0x443c097d,0x637c1497,0x6604245e}},	//   sodh, rzt_, dénc, _šiku, 
   {{0x443ca3e2,0x6f05ce68,0x6569ce69,0xb7c0005f}},	//   szt_, ddic, podh, _ēģip, 
   {{0x6f040483,0x6d5c020c,0x6568022f,0xb5c401e2}},	//   edic, _njra, qodh, _اووم_, 
   {{0xdbf00316,0x7c3803f9,0x637c180f,0x69c40030}},	//   _příj, _ƙurm, génc, šieh, 
   {{0x6d5c006c,0xbeb8017a,0xdb04553f,0xd3f0004b}},	//   _ajra, _goël, lshö, _کړید, 
   {{0xdcb8130f,0x8234009a,0x00000000,0x00000000}},	// [33930] игач_, _درغا, --, --, 
   {{0xdb053e4b,0xa2b00da5,0x00000000,0x00000000}},	//   nshö, ंरक्, --, --, 
   {{0x6f05ce6a,0x637c2508,0xe3b80213,0x00000000}},	//   bdic, cénc, lxıb_, --, 
   {{0x6f04003a,0xa7fc0139,0xd1f00240,0x00000000}},	//   cdic, _uzıy, _ውሁብ_, --, 
   {{0x7cc8005f,0x38c401b9,0xaa58009b,0x9cb400ae}},	//   tērē, ماغی_, бицу_, _ومحت, 
   {{0xa7fc06be,0x00000000,0x00000000,0x00000000}},	//   _ayıq, --, --, --, 
   {{0x6d58007f,0xdb04007c,0x3158010f,0x00000000}},	//   čvat, dshö, זיגן_, --, 
   {{0x3d14561f,0x95c8036b,0x7ae4004b,0x00000000}},	//   नावे_, алиб_, _دورې_, --, 
   {{0x7bd570ad,0xdcec01e4,0xaa5c01ec,0xdb2000a2}},	//   luxu, spaĵ, _бетi, _çuñd, 
   {{0x28e02068,0x79980280,0x888003e6,0x27381bce}},	//   _नायि, _iuuw, سیۆن, _pénc_, 
   {{0x09bc015b,0x15e4033f,0xe6680023,0x3f54031c}},	//   _উৎপা, _कहकर_, _ምድግጋ, għuk_, 
   {{0x799800ec,0x637c0ba1,0x6f040036,0x91e400c7}},	//   _kuuw, vénc, xdic, ооме, 
   {{0x4adc073d,0xbeb80660,0x7bd4014b,0xc2400d97}},	//   फ्टव, _voël, huxu, дняк, 
   {{0x7999ce6b,0x7bd5ce6c,0x637c1497,0x00000000}},	//   _muuw, kuxu, ténc, --, 
   {{0x2738020c,0x7bd4014b,0x6f042963,0x7998002e}},	//   _héna_, juxu, tdic, _luuw, 
   {{0x637c2508,0x6f05a1ca,0x27380098,0x28e000e0}},	//   rénc, udic, _kéna_, _नाभि, 
   {{0x79980a49,0x6f044a5a,0x4d48094d,0x637c1497}},	// [33940] _nuuw, rdic, апан_, sénc, 
   {{0x637dce6d,0xcc3405d9,0xbd800845,0x273800c7}},	//   ména, يراع, дгук, _ména_, 
   {{0x27380066,0xeff402d3,0x637c06fd,0xb3740092}},	//   _léna_, ልጥዎ_, léna, ረገውን_, 
   {{0x799801e0,0x2fd8022e,0x4cb000fe,0x00000000}},	//   _buuw, murg_, _চাওঁ, --, 
   {{0x2a6000ac,0x2739ce6e,0xa7fc0790,0x637db094}},	//   çib_, _néna_, _ayıp, néna, 
   {{0x8c44189c,0x0ba80aa0,0x7998022f,0x6d5c547b}},	//   _деге, _نارى_, _duuw, _ujra, 
   {{0x3d141533,0x7bd406be,0x00000000,0x00000000}},	//   नारे_, cuxu, --, --, 
   {{0x799800b5,0x6b9c16b8,0x637c3847,0x320001a9}},	//   _fuuw, _iurg, kéna, _osiy_, 
   {{0x6b9c016d,0x5b200f31,0x99881a48,0xdb04a180}},	//   _hurg, _سہول, šaš_, tshö, 
   {{0x6b9dce6f,0x637dce70,0x7c4401a8,0xda64007b}},	//   _kurg, déna, _úrræ, _راقي, 
   {{0x320002d1,0x6b9dce71,0x2fd800f3,0x13a803e6}},	//   _asiy_, _jurg, jurg_, ینیی_, 
   {{0x6b9dce72,0x2fd8014b,0xbeb8003a,0x7998037e}},	//   _murg, durg_, _poëm, _yuuw, 
   {{0x637dce73,0x6b9caa66,0xd78800f1,0xf2040006}},	//   géna, _lurg, _اخلم_, мяро, 
   {{0x6b9ca16d,0x3ebc16a3,0x722800d4,0x68f803b2}},	//   _ourg, _žut_, іцяв_, nevd, 
   {{0x32000472,0x6b9dce74,0x998c00d7,0x00000000}},	//   _esiy_, _nurg, _dreň_, --, 
   {{0x637c0066,0xb5c001e0,0x00000000,0x00000000}},	//   béna, _эйәл, --, --, 
   {{0x3d140316,0x68f801d4,0x6edc04fa,0xbeb8017a}},	// [33950] नाले_, kevd, _फारु, _hoëk, 
   {{0x2fd9ce75,0x63a41326,0x918001fb,0x7999ce76}},	//   burg_, _činj, yển_, _ruuw, 
   {{0x6b9dce77,0x78a0013f,0xad2416a0,0x2fd8054e}},	//   _curg, vcnv, بىلى, curg_, 
   {{0x6b9dce78,0x799818a6,0x2001ce79,0x00000000}},	//   _durg, _puuw, _ishi_, --, 
   {{0x98a504e8,0xcee80014,0x6d582804,0xe9d83334}},	//   пиле, _ارپن_, čvar, жкі_, 
   {{0xcc840272,0x68f800c5,0xa9240220,0x9b4401b9}},	//   _کۆمه_, gevd, мділ, _کنرو, 
   {{0x6b9dce7a,0x27380098,0xad4400cf,0xdcfc00c0}},	//   _gurg, _séna_, _تۉلۉ, _susė, 
   {{0xc4c400c6,0xdcfc0006,0x00000000,0x00000000}},	//   _כْ_, _pusė, --, --, 
   {{0x6b9dce7b,0xc0bc02d3,0xb0dc2677,0x77a406be}},	//   _zurg, ሴሉስ_, _बालग, _sıxd, 
   {{0x80d413b4,0x6b9c036b,0x27380c6a,0x2001ce7c}},	//   _बागे, _yurg, _véna_, _oshi_, 
   {{0xd46806d3,0x28e01fe7,0x6b9dce7d,0x21e002b5}},	//   сине_, _नाति, _xurg, hōhā_, 
   {{0x637c00d5,0xdb0401ab,0x2fd801a9,0x00000000}},	//   téna, nphà, vurg_, --, 
   {{0xfe7c006a,0x273800e8,0x2001ce7e,0x2fd80af9}},	//   _nzï_, _kénn_, _ashi_, wurg_, 
   {{0x2fd9ce7f,0xd39563af,0x637c2dfb,0xbeb80af9}},	//   turg_, _нәмә_, réna, _hoëh, 
   {{0xb4d40490,0x637dc2e6,0x6ea80037,0x00000000}},	//   िली_, séna, _छ्उँ, --, 
   {{0x2738002e,0x6b9c0455,0x637dab40,0xec8401ec}},	//   _lénn_, _rurg, péna, _ﺩﺍﺨﻠ_, 
   {{0xe4d401ec,0x68f90609,0x2fd87c87,0x7bc000e4}},	// [33960] _ءتۇب, yevd, surg_, ânun, 
   {{0xa91c01f1,0x3ea000fd,0x637c0098,0x20000240}},	//   _ohľa, _җирг, nénn, _fshi_, 
   {{0x63a402fb,0x6b9c1ffc,0x00000000,0x00000000}},	//   _čink, _qurg, --, --, 
   {{0x6b9dce80,0x63bc0311,0x69340133,0x2f1400d1}},	//   _vurg, ârni, ژکار, _تېرر, 
   {{0x27380de2,0x28e01788,0x00000000,0x00000000}},	//   _bénn_, _नादि, --, --, 
   {{0x6b9dce81,0x637c3386,0xe7f80073,0x26c00064}},	//   _turg, jénn, ंबला_, _žio_, 
   {{0x6b9c0ea0,0x37a400f7,0x68f80790,0xdb04002d}},	//   _uurg, птын_, revd, tshô, 
   {{0xa61400a7,0xdb0408c2,0xaae000af,0x68f80205}},	//   дмич, cphà, _पञिक, sevd, 
   {{0xb0dc0c66,0x0cdc0154,0x00000000,0x00000000}},	//   _बांग, ড়ীত, --, --, 
   {{0x27380694,0x637dce82,0x59a0000d,0x00000000}},	//   _génn_, génn, _ओंतर, --, 
   {{0xa4381fe2,0x14dc1fbc,0x351401c0,0xdb0401e7}},	//   ізму_, _मारण, чжээ_, lphá, 
   {{0xc6d40046,0xf7414253,0x00000000,0x00000000}},	//   _ءتات, _пехо, --, --, 
   {{0x20000263,0x61fc5282,0x2738002e,0x574437ba}},	//   _sshi_, uwsl, _yénn_, _تخلف, 
   {{0xf6140375,0x03c400d1,0xa3d400db,0x00000000}},	//   _מחדש_, _есим, _жокч, --, 
   {{0xdb0400ae,0x73c000ae,0x00000000,0x00000000}},	//   hphá, _كيوم, --, --, 
   {{0x62240075,0x30a401c0,0x273806c6,0x637dce83}},	//   _يىغل, _үрэв, _méno_, méno, 
   {{0xa3d407af,0x00000000,0x00000000,0x00000000}},	// [33970] िंक_, --, --, --, 
   {{0x200053ed,0xb7b80241,0x00000000,0x00000000}},	//   _tshi_, _ẹ̀gb, --, --, 
   {{0x20000784,0xdea000f2,0x00000000,0x00000000}},	//   _ushi_, _لیزی, --, --, 
   {{0x7d24004b,0x9e34023a,0x61380241,0xdcfc002b}},	//   _کيسې_, _жемч, _kìlo, _kusī, 
   {{0x273800e8,0xdd90cfad,0x637c73a0,0xaa580b3b}},	//   _pénn_, _لوح_, héno, пицу_, 
   {{0x80c804c5,0x00000000,0x00000000,0x00000000}},	//   িভক্, --, --, --, 
   {{0x59c812eb,0x00000000,0x00000000,0x00000000}},	//   _रिकर, --, --, --, 
   {{0x7d0401d3,0xa91c00d7,0x6d400153,0x00000000}},	//   _hajs, _vhľa, _įmai, --, 
   {{0xab852bca,0x637c0cde,0x69c400e4,0x00000000}},	//   _чурк, ténn, áiet, --, 
   {{0xb4d43a62,0xd4980372,0x98a4007f,0x53c8aa52}},	//   िले_, өрү_, _kolč_, огом_, 
   {{0xa3d40d5f,0x7d048b8c,0x637dce84,0xdcfc00de}},	//   िंग_, _majs, rénn, _ausī, 
   {{0x7d040960,0x637c003e,0xdcf40171,0x00000000}},	//   _lajs, sénn, _bizī, --, 
   {{0x1278007b,0xd6d80210,0x00000000,0x00000000}},	//   تحدث_, chła_, --, --, 
   {{0xe280416c,0x659410f3,0xe514000d,0x00000000}},	//   ығын, _зачу, _थोपि_, --, 
   {{0x28e01b6e,0xdff49849,0x7bc08416,0x637c00e4}},	//   _नासि, нять, ânul, céno, 
   {{0x15e0000d,0x00000000,0x00000000,0x00000000}},	//   _खमार_, --, --, --, 
   {{0x63a40bb8,0x7d046b4e,0xb63c00b5,0xcd041845}},	// [33980] _čini, _bajs, _ｃｌ_, мпай, 
   {{0x7d0401e3,0x81f40244,0x00000000,0x00000000}},	//   _cajs, _کفیر_, --, --, 
   {{0x7d040007,0xa7fc0213,0x00000000,0x00000000}},	//   _dajs, _axın, --, --, 
   {{0x28e03027,0xd4900051,0x00000000,0x00000000}},	//   _नाहि, hèo_, --, --, 
   {{0x637c0122,0x9e040b7e,0x7d042fce,0x00000000}},	//   zéno, _пчёл, _fajs, --, 
   {{0xda65ce85,0xb4d4038e,0x7d05ce86,0xbb806911}},	//   راني, िलो_, _gajs, ىلەي, 
   {{0x8b640372,0xfc000022,0xb4d40316,0xfce001c0}},	//   _قارم, _ипро, िलै_, _шоро, 
   {{0x85a403b7,0x28e01408,0x2d99ce87,0x2ee00549}},	//   мјод, _नावि, _hire_, ngif_, 
   {{0x248c044e,0x2d980724,0x00000000,0x00000000}},	//   _መሓመድ_, _kire_, --, --, 
   {{0x057452c8,0x637d87e7,0x2d999737,0x17ac00fe}},	//   باعد, téno, _jire_, _গিৰি, 
   {{0x2d99ce88,0x61380268,0x070800b2,0x63540fbe}},	//   _mire_, _dìll, _ويئي_, евну, 
   {{0x2d99ce89,0xbeb80ea0,0xd1d4010c,0x637c0419}},	//   _lire_, _hoëv, ራረቡ_, réno, 
   {{0xe8ec0156,0x99880030,0x2d99ce8a,0x35b00024}},	//   _ལྡོག, šať_, _oire_, _абір, 
   {{0x26c5ce8b,0x2d980323,0xdcf4005f,0x2ee0017a}},	//   lamo_, _nire_, _vizī, egif_, 
   {{0xf19402bf,0x7d05ce8c,0x00000000,0x00000000}},	//   тирь, _rajs, --, --, 
   {{0x7d040113,0x2f180212,0x00000000,0x00000000}},	//   _sajs, мось_, --, --, 
   {{0x2d99ce8d,0x26c402e8,0x7d040135,0x09bc015b}},	// [33990] _bire_, iamo_, _pajs, _উৎসা, 
   {{0x2d99ce8e,0xceb401e0,0xdd940124,0x325401f4}},	//   _cire_, _үәт_, хазы, _швыр, 
   {{0x26c5ce8f,0x7d0478e0,0x5f940124,0x9f3428f6}},	//   kamo_, _vajs, _пиот, _зені, 
   {{0x26c5ce90,0x2d99ce91,0x98a4007f,0x9aa401e2}},	//   jamo_, _eire_, _volč_, رمتو, 
   {{0x9db8081f,0xe9a800f7,0x7d042b5d,0x2d99acd9}},	//   _བསྲེ, ودون_, _tajs, _fire_, 
   {{0xd1204d53,0x98a40051,0xfbd000ae,0x00000000}},	//   मायण_, _pllđ_, _لتر_, --, 
   {{0xb904fa1a,0x7c3803f9,0x28e01bbb,0x00000000}},	//   _भा_, _ƙuru, _नारि, --, 
   {{0x26c5ce92,0x7f5c003e,0x9f58020c,0x77a403b9}},	//   gamo_, nnqq, èyèl_, _cıxa, 
   {{0x2d99ce93,0x59c852be,0x00000000,0x00000000}},	//   _yire_, _रिटर, --, --, 
   {{0x0680cced,0x9db80003,0x26c40022,0xdb2401e1}},	//   ыгын, _བསླེ, aamo_, _ńpèm, 
   {{0x26c5ce94,0x00000000,0x00000000,0x00000000}},	//   bamo_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbeb80036,0xdb04041e,0xe6100014,0xd75001d3}},	//   _knëf, pphæ, _پشن_, _لڑکھ, 
   {{0x6e200228,0x637c3847,0x0654011a,0x77780200}},	//   _àmbi, nénj, _אינך_, llux, 
   {{0x2d980588,0x77a403b9,0x59c801f9,0x00000000}},	//   _rire_, _yıxa, _रिझर, --, 
   {{0x62040598,0x645c004e,0x5ef80107,0x3f54031c}},	//   ätlä, úrie, мхур_, xħut_, 
   {{0x2d99ce95,0x0d852134,0x0e640354,0x10a40a0e}},	// [339a0] _pire_, елан, хкан, _пипн, 
   {{0x59c80c2e,0x2d9800fd,0xf76403e6,0x61e801ab}},	//   _रिजर, _qire_, _ڕا_, àele, 
   {{0x2d99ce96,0xb8080064,0x637c00d7,0x00000000}},	//   _vire_, _глiн, zénm, --, 
   {{0x2055ce97,0x2d99bee6,0x26c400f1,0x77780306}},	//   _штыр, _wire_, xamo_, jlux, 
   {{0xbeb8003a,0x2d99ce98,0xed04035b,0xacf400ec}},	//   _coëu, _tire_, _иҟан, _لڳات, 
   {{0x26c5ce99,0x67d45aa2,0x7778003a,0x2d9800a3}},	//   wamo_, воку, elux, _uire_, 
   {{0x26c5ce9a,0x7779ce9b,0x6e240998,0xd90c12e1}},	//   tamo_, flux, lxib, تیل_, 
   {{0x3a207e27,0x3b040166,0x14dc012c,0x59c81b76}},	//   тмәг, _песо_, _माउण, _रिचर, 
   {{0x26c5ce9c,0xbb400aec,0x6e2400aa,0x637c0098}},	//   ramo_, _сетк, nxib, bénj, 
   {{0xd90d97a2,0xbeb8017a,0x9a4801d9,0x00000000}},	//   _وین_, _hoët, _کجہِ_, --, 
   {{0x47f1ce9d,0x2bd801ad,0x38c80214,0x98a40171}},	//   _сүйр, _डिफा, _رالی_, _ellē_, 
   {{0x225807d8,0xf4800032,0x6edc3105,0x637c0118}},	//   димы_, ыуын, _फागु, ménk, 
   {{0x29180ba1,0x27380221,0x45f8031c,0x75d0724c}},	//   _òras_, _lénk_, _དགྲས_, _مينا, 
   {{0xa4d410f5,0x98a40607,0xdb04007c,0x00000000}},	//   _рокі, _kolā_, mphå, --, 
   {{0xf0440276,0x00000000,0x00000000,0x00000000}},	//   гэто, --, --, --, 
   {{0x64480153,0xc2e401d5,0x98a400ef,0x00000000}},	//   mzdi, _чўки, _molā_, --, 
   {{0x6e240921,0x9d543bdb,0x637c0036,0x6448002f}},	// [339b0] gxib, نچست, hénk, lzdi, 
   {{0xc32c04a9,0xa7fc03b9,0xee74010b,0xe78c0150}},	//   _ئەڭ_, _axım, улуь, _ﺗﺎﺑﯟ, 
   {{0x6449ce9e,0x9c1802eb,0x7c64027d,0x00000000}},	//   nzdi, بياء_, رائل, --, 
   {{0x27380694,0xbeb80165,0x5a340021,0x63bc29c5}},	//   _dénk_, _coët, кнет, árny, 
   {{0x637c00d5,0x6ac400f2,0x00000000,0x00000000}},	//   ténj, اقهم, --, --, 
   {{0xfb8003e6,0x80d00154,0x00000000,0x00000000}},	//   _ڵگای, দ্র্, --, --, 
   {{0x637c0098,0x3f540327,0x00000000,0x00000000}},	//   rénj, lħuq_, --, --, 
   {{0x98a40055,0x7c2001f4,0x64480171,0x00000000}},	//   _dolā_, änru, dzdi, --, 
   {{0x644801a2,0x918001fb,0xbeb80af9,0x777801c4}},	//   ezdi, yền_, _hoës, rlux, 
   {{0x2bd845bf,0xdb0404ef,0x00000000,0x00000000}},	//   _डिमा, sphä, --, --, 
   {{0x67d407d5,0xdb04369a,0xc481ce9f,0x6624113e}},	//   _боху, pphä, ильк, _ەرىك, 
   {{0x98f0012c,0x00000000,0x00000000,0x00000000}},	//   _आउँछ_, --, --, --, 
   {{0xbeb805d5,0x6e2495bd,0x98a400ef,0x55e4011c}},	//   _loës, xxib, _zolā_, _ролб, 
   {{0xa68402bf,0x645c04d4,0x41d03599,0xe00c01ad}},	//   _слід, úric, _तिरस, हिंद_, 
   {{0x8fa40148,0xda640451,0x8f990156,0x06881884}},	//   табе, _ڇڏ_, дъат_, ﻗﯩﻠﯩ, 
   {{0x6e2401c0,0xda6400ec,0x00000000,0x00000000}},	//   txib, _هڏ_, --, --, 
   {{0x200408a7,0x8e74036b,0xd1840116,0xabc00131}},	// [339c0] ælir_, тувч, _илий, _ﺯﯨﻴﺎ, 
   {{0xc234008f,0xd17400fb,0x6d400064,0x00000000}},	//   _סאיז_, _шыйы, _įmas, --, 
   {{0xbeb9cea0,0x8ae400d4,0x1c380006,0x60d8010f}},	//   _poët, вілл, няць_, _אַרג, 
   {{0x7c3803f9,0xfb841056,0x2d440254,0x8e84007b}},	//   _ƙurr, ندنی, _söed_, _للجه, 
   {{0x637c01c7,0x98a400ef,0x00000000,0x00000000}},	//   wénk, _solā_, --, --, 
   {{0x14dc0490,0xf98c1c4e,0x637dcea1,0x00000000}},	//   _मागण, يبو_, ténk, --, 
   {{0x27380098,0x8b94d0fd,0xd6d8012d,0x00000000}},	//   _héni_, _арач, liły_, --, 
   {{0xf76dcea2,0xbeb80660,0x637c0098,0x41d03c71}},	//   ياي_, _hoër, rénk, _तिलस, 
   {{0x25f40316,0x9abc002e,0x81b404c5,0x3d140490}},	//   ्बधी_, _coŋu, _চয়ন_, नाचे_, 
   {{0x6a84fd2d,0x637d9f61,0x69c0014f,0xbeb804e6}},	//   _алға, méni, _iwme, _joër, 
   {{0x637dcea3,0x290dcea4,0xe3540419,0x2bf003d4}},	//   léni, _iada_, šníč, ছিকৈ_, 
   {{0x290d7d68,0x69c00208,0x77a406be,0xdb0401e3}},	//   _hada_, _kwme, _mıxl, pphå, 
   {{0xa5f80640,0x273800e5,0x00000000,0x00000000}},	//   _челу_, _néni_, --, --, 
   {{0x290dcea5,0xf99c01e1,0x00000000,0x00000000}},	//   _jada_, _èèe_, --, --, 
   {{0x290dcea6,0x637dcea7,0xa50400d1,0x00000000}},	//   _mada_, héni, _аяқл, --, 
   {{0x290c138f,0x2739cea8,0x637c003e,0x69c1cea9}},	//   _lada_, _béni_, kéni, _owme, 
   {{0x9d18136b,0x3f44000d,0xeda40408,0x7204027d}},	// [339d0] ноат_, _lõug_, ашхо, _نويم, 
   {{0x290c748d,0x61edceaa,0xbeb9ceab,0x637c5f72}},	//   _nada_, _iqal, _poës, déni, 
   {{0x637d550b,0x69c00327,0xbeb8022e,0xbc0402e8}},	//   ténh, _awme, _qoës, ъчай, 
   {{0x290dceac,0x60c4014f,0x273801e1,0x637c003e}},	//   _aada_, _hehm, _féni_, féni, 
   {{0x290dcead,0x637dceae,0x1959ceaf,0x61ec0327}},	//   _bada_, géni, нады_, _jqal, 
   {{0x60c4031c,0x61ec031c,0x99840035,0xd7e84c87}},	//   _jehm, _mqal, دلتو, емке_, 
   {{0x60c5ceb0,0x69c002d0,0x00000000,0x00000000}},	//   _mehm, _ewme, --, --, 
   {{0x60c5ceb1,0x61ec32ff,0x290d965b,0x637c004e}},	//   _lehm, _oqal, _eada_, béni, 
   {{0x290dceb2,0x637ca92b,0xba7438eb,0x99d8d55f}},	//   _fada_, céni, _شارت, _سواء_, 
   {{0x290c11f9,0x60c5ceb3,0xf8c400e1,0x2a600332}},	//   _gada_, _nehm, _रजिय, úibe_, 
   {{0xd6d8012d,0x00000000,0x00000000,0x00000000}},	//   ziły_, --, --, --, 
   {{0x290c00ee,0x3f4400c5,0xc5b401c6,0x00000000}},	//   _zada_, _jõud_, _өршө, --, 
   {{0x60c40649,0x00000000,0x00000000,0x00000000}},	//   _behm, --, --, --, 
   {{0xd0080228,0xd46905ec,0x290c0009,0x2738585c}},	//   неге_, _пиле_, _xada_, _réni_, 
   {{0x2739356e,0xd6d8033f,0xb4ccdc75,0x2d8400ef}},	//   _séni_, wiły_, षणी_, _ūmeo_, 
   {{0xff040276,0x61ec003a,0x3f440037,0x3f89ceb4}},	//   леск_, _fqal, _nõud_, _chcu_, 
   {{0x60c5ceb5,0x61ec014b,0x637c1709,0x3320031c}},	// [339e0] _fehm, _gqal, xéni, _inix_, 
   {{0x646402d5,0x91040120,0x60c40112,0x637da06a}},	//   štiš, _спое, _gehm, véni, 
   {{0x637c020c,0x28b407f7,0xd6d8012d,0x10140006}},	//   wéni, ुरसि, siły_, _сьпя, 
   {{0x290c0bb8,0x61ec022e,0x77a406be,0x12e000fe}},	//   _sada_, _yqal, _cıxm, _বসুদ, 
   {{0x290d71ef,0x00000000,0x00000000,0x00000000}},	//   _pada_, --, --, --, 
   {{0x290dceb6,0x637c004a,0xbeb80ea0,0xd90cafbd}},	//   _qada_, réni, _hoëp, ویق_, 
   {{0x8c45ceb7,0x637c25e6,0x37ac00cc,0x00000000}},	//   _севе, séni, _টিউৰ, --, 
   {{0x290c0a81,0xbb4024b1,0xd1b802d3,0xd6d8033f}},	//   _wada_, _леск, ታማት_, ykłe_, 
   {{0xfa64004e,0x00000000,0x00000000,0x00000000}},	//   _батк_, --, --, --, 
   {{0x9abc00e8,0x290dceb8,0x61ec01a9,0x3f44000d}},	//   _foŋs, _uada_, _rqal, _tõug_, 
   {{0x60c5ceb9,0x2498049f,0xb99000c6,0x61ec0135}},	//   _rehm, ärm_, _اللب, _sqal, 
   {{0x60c4dd07,0x9180004d,0x3f440254,0x41e40111}},	//   _sehm, yễn_, _kõue_, ліга, 
   {{0x60c5ceba,0x61ec010a,0x2bf00154,0x00000000}},	//   _pehm, _qqal, ছিয়ে_, --, 
   {{0x60c4047e,0x630400d1,0x00000000,0x00000000}},	//   _qehm, _چوغل, --, --, 
   {{0x855401ed,0x60c5cebb,0x00000000,0x00000000}},	//   _لیکر_, _vehm, --, --, 
   {{0x774801e1,0x61ec0135,0xe3b82737,0x60c40112}},	//   _kábọ, _tqal, mpı_, _wehm, 
   {{0x5d54e6cb,0x61ec0912,0x3f4400c5,0x60c4047e}},	// [339f0] акат, _uqal, _nõue_, _tehm, 
   {{0x60c402d0,0x28e028d4,0x77a403b9,0x3e4c0240}},	//   _uehm, _नागि, _sıxm, _መዘከር, 
   {{0x81b4015b,0x3f44000d,0x81c400cc,0x00000000}},	//   _চটি_, _põud_, _উমি_, --, 
   {{0x681c0276,0x1a6419d4,0x00000000,0x00000000}},	//   _mădă, لیزی_, --, --, 
   {{0x9504031c,0x00000000,0x00000000,0x00000000}},	//   _མྲའི_, --, --, --, 
   {{0xd7c8004b,0x273801e1,0x00000000,0x00000000}},	//   نوته_, _ménu_, --, --, 
   {{0xae440014,0x27380241,0x681c0356,0x3f44000d}},	//   _نپێو, _lénu_, _nădă, _tõud_, 
   {{0xadc40cad,0x1948037e,0x6c544c87,0x23680200}},	//   _amẹr, _ｆｏｒ_, _уксу, _njaj_, 
   {{0xaee400dc,0xf8e401e2,0x00000000,0x00000000}},	//   _hiṃs, _مساپ, --, --, 
   {{0xb4cc0a94,0x681c0356,0x2368007c,0xaee4002b}},	//   षणे_, _bădă, _ajaj_, _kiṃs, 
   {{0xd469cebc,0x36202832,0x00000000,0x00000000}},	//   тине_, _گوشہ, --, --, 
   {{0xe89400c7,0x5fa8000d,0x00000000,0x00000000}},	//   _уахь, _कढ़ल, --, --, 
   {{0x43640209,0x23680200,0x00000000,0x00000000}},	//   раян_, _djaj_, --, --, 
   {{0x9db81b4b,0xd175cebd,0x00000000,0x00000000}},	//   _བསྟེ, рымы, --, --, 
   {{0x1fb4063b,0xd47800c8,0x923400db,0x00000000}},	//   йстр, _באַל, _چىعش, --, 
   {{0x950000db,0x33203046,0x273802d2,0xbea000cf}},	//   _اۋگۇ, _unix_, _fénu_, жатк, 
   {{0xdcf40100,0x681c0356,0x2bd801ad,0xd1dc0092}},	// [33a00] _ekzč, _zădă, _डिहा, ንቶች_, 
   {{0x8cb498a3,0x00000000,0x00000000,0x00000000}},	//   рсач, --, --, --, 
   {{0x273800e5,0x00000000,0x00000000,0x00000000}},	//   _ként_, --, --, --, 
   {{0xea000051,0x0dc8014b,0x00000000,0x00000000}},	//   _quắp_, _илмй_, --, --, 
   {{0xe8f8052f,0x637dcebe,0x6f04009f,0x2bd82e05}},	//   лһа_, mént, meic, _डिवा, 
   {{0x6f05cebf,0x637c065c,0xb9500212,0x30d803d4}},	//   leic, lént, овіщ, দ্ৰস, 
   {{0xe75802bf,0xec34006c,0xb804007b,0x0744014b}},	//   ликі_, _اوزگ, ليوم_, ихим, 
   {{0x681c0276,0x637c00e4,0x0ae83bd7,0x98a40210}},	//   _rădă, nént, _جرسي_, _rolą_, 
   {{0x48e51d5b,0x15b00131,0xdb080112,0x98a4012d}},	//   _возв, كەنس, _hieß, _solą_, 
   {{0x23681591,0x637c0c63,0x4990035c,0x6f042380}},	//   _sjaj_, hént, _بیتر, heic, 
   {{0x0709cacb,0x46e8010b,0x613801ab,0x637d5ce3}},	//   _ахли_, _аден_, _mìlt, ként, 
   {{0x637c0c6a,0x45240014,0x00000000,0x00000000}},	//   jént, ارکِ, --, --, 
   {{0x6f05cec0,0xdb0803fa,0xe5b40724,0x058400fd}},	//   deic, _ließ, _уйлы, _кукм, 
   {{0x3179cec1,0xa19401c0,0x30a41d39,0x00000000}},	//   gorz_, сагч, жртв, --, 
   {{0x6f05cec2,0xadc401e1,0xdb0403cd,0x3ec4992f}},	//   feic, _itẹt, pphø, исаб, 
   {{0x27380de2,0x637ca4e5,0x6f0400a3,0xa0a40417}},	//   _gént_, ténu, geic, раңд, 
   {{0x2120001e,0x31780210,0x00000000,0x00000000}},	// [33a10] _tnhh_, borz_, --, --, 
   {{0xfa34036b,0xacf4014d,0x00000000,0x00000000}},	//   یرشد, قسمت, --, --, 
   {{0x637dcec3,0x28e000e1,0x6f05cec4,0x19e00150}},	//   bént, _नाजि, beic, _ﺍﻻﭘﺎ, 
   {{0x637dcec5,0xe73801e4,0x59d400c6,0xdb08002f}},	//   cént, _fuĵi_, مغتر, _dieß, 
   {{0x637c0098,0xc68400ec,0x3a24013d,0x00000000}},	//   léns, _ءِ_, релү_, --, 
   {{0xe77801ed,0xe9b801ed,0xadc401e1,0x6ce400c0}},	//   یلوں_, جنوں_, _ntẹt, _місе, 
   {{0xdb0803fa,0x637c003e,0x2d440166,0xd6d80210}},	//   _gieß, néns, _köen_, ekła_, 
   {{0x9db8081f,0xd7085a60,0x7ae400f1,0x00000000}},	//   _བསྙེ, уние_, _خورې_, --, 
   {{0x7af9cec6,0x637c003e,0xf1dc0037,0x28e0190c}},	//   _ibut, héns, _बिधन, _नाचि, 
   {{0x6f040639,0x27380137,0x998400c6,0xa3c81d8a}},	//   zeic, _béns_, _الطو, _लौह_, 
   {{0x7af8009a,0x6f04009f,0x00000000,0x00000000}},	//   _kbut, yeic, --, --, 
   {{0x6f040005,0x637db93e,0xdcfc0139,0xc0c00023}},	//   xeic, déns, _mtsı, ኻኸሪ_, 
   {{0xb5a5cec7,0x6f040097,0x5275cec8,0x31781529}},	//   _трей, veic, суну, torz_, 
   {{0x6f0403fa,0x2bd85360,0x637c0e47,0x659400c0}},	//   weic, _डिला, wént, _дачу, 
   {{0x7af9cec9,0x637cdbd1,0x6f0400da,0x2d440112}},	//   _obut, tént, teic, _böen_, 
   {{0xdb08002f,0x81c40154,0x03d4011a,0x8e7400db}},	//   _rieß, _উমর_, _הוקם_, бузч, 
   {{0x6f0491e1,0x637dad2a,0xa23405f5,0xb7fc009e}},	// [33a20] reic, rént, _дээш, ্মিত_, 
   {{0x637dceca,0x6f040e89,0x50444130,0x00000000}},	//   sént, seic, _геоб, --, 
   {{0x6f05cecb,0x7af80083,0xd1dc001f,0x637dcecc}},	//   peic, _bbut, ንዶች_, pént, 
   {{0x15f85373,0xd6d8033f,0xadb800db,0xcac80063}},	//   ्बार_, ykła_, _نۇرا_, угде_, 
   {{0xdcfc0205,0x00000000,0x00000000,0x00000000}},	//   _etsı, --, --, --, 
   {{0x7af9cecd,0xa7b9cece,0xe91801ce,0x00000000}},	//   _ebut, алку_, рокі_, --, 
   {{0x0aa0052f,0xcb680063,0x00000000,0x00000000}},	//   _еңеү, _баве_, --, --, 
   {{0xe739c904,0x00000000,0x00000000,0x00000000}},	//   рпич_, --, --, --, 
   {{0x3f4400c5,0xa7fc03b9,0x88d8005b,0x2739cecf}},	//   _jõua_, _axıt, _бьет_, _séns_, 
   {{0x7af80023,0x79b4011a,0x39400150,0x00000000}},	//   _zbut, _ללמד_, _енуг, --, 
   {{0x320007ab,0x537c044e,0x3f44000d,0x7d78011a}},	//   _apiy_, የገድስ_, _lõua_, רניו, 
   {{0x2be06c95,0x2738004e,0xc1e85016,0x0684004e}},	//   _पटना, _véns_, льге_, _лген, 
   {{0x3f440037,0xa4d400d4,0x00000000,0x00000000}},	//   _nõua_, _долі, --, --, 
   {{0x637c00d5,0x00000000,0x00000000,0x00000000}},	//   téns, --, --, --, 
   {{0x637c003e,0x20980006,0x28d000c5,0xe5b400fb}},	//   uéns, рквы_, _सजनि, _уйһы, 
   {{0x3ce9ced0,0x443dced1,0x6568020c,0x637c00d5}},	//   _चाहे_, myt_, lndh, réns, 
   {{0x443d13c0,0x9e9404fb,0x637c00d5,0x3f8400e2}},	// [33a30] lyt_, زارچ, séns, ēnu_, 
   {{0x628dced2,0x7af80ffb,0x443c062c,0xf8c40037}},	//   _izao, _sbut, oyt_, _रजइय, 
   {{0x443dced3,0x68f845a7,0xdb20145e,0x5b1400fb}},	//   nyt_, dfvd, ëtïs, жмет, 
   {{0x20000921,0x443c062c,0xf0b80214,0x9f2000d1}},	//   _iphi_, iyt_, _پایش_, _تۈرۈ, 
   {{0xdd940046,0x443dced4,0x65680066,0x7f5c022e}},	//   _мамы, hyt_, kndh, miqq, 
   {{0xa3d80490,0x6e21ced5,0x443dced6,0xe8f81d31}},	//   ाळा_, _ámba, kyt_, йлі_, 
   {{0x443c023a,0x69c4054e,0xdcfc0166,0x00000000}},	//   jyt_, âier, _utsı, --, 
   {{0x7af80537,0x7f5c0357,0x443dced7,0x5fe0257b}},	//   _ubut, niqq, dyt_, _फिनल, 
   {{0x05a405cc,0xae1c05d7,0x798002d0,0x2b44004e}},	//   овый_, नियन_, plnw, _ээрг, 
   {{0x95540128,0x2000014b,0x63b8004e,0x057400c6}},	//   تخبا, _ophi_, _btvn, يمية_, 
   {{0x628c0165,0x443c70bd,0x09cc0154,0xf1dc00c5}},	//   _azao, gyt_, _রমযা, _बिहन, 
   {{0x65686243,0x98a4033f,0x7ae80098,0xf1c00419}},	//   andh, _rolę_, nggt, úšov_, 
   {{0x20000b6f,0x7f5c208d,0x153804fb,0x77780561}},	//   _aphi_, diqq, _پزشک_, moux, 
   {{0x443c3e91,0x628c0099,0x8fa406ed,0x00000000}},	//   byt_, _dzao, жаве, --, 
   {{0x628c02bd,0x7f5c3fb4,0xd008a30d,0x443c4a75}},	//   _ezao, fiqq, шеве_, cyt_, 
   {{0x320000ca,0x3f44000d,0x408401e0,0x2c00000d}},	//   _tpiy_, _põua_, өҙөм_, _रहबू_, 
   {{0x0e6415bd,0x98a4033f,0xf8bc0051,0x00000000}},	// [33a40] цкан, _wolę_, _đén_, --, 
   {{0x998c02f0,0xcce400ae,0x00000000,0x00000000}},	//   _useň_, تسري, --, --, 
   {{0x4aa800f3,0x0c080108,0xbd3038eb,0xe3b803e3}},	//   акен_, реей_, بىلع, lxır_, 
   {{0x60c00205,0x00000000,0x00000000,0x00000000}},	//   ılme, --, --, --, 
   {{0x6568014b,0x443c8674,0x00000000,0x00000000}},	//   yndh, zyt_, --, --, 
   {{0x645c00d7,0x5cf40024,0x00000000,0x00000000}},	//   úrik, _нясу, --, --, 
   {{0x6d5dced8,0xa7fd839d,0xdcfc00ef,0x37a5ced9}},	//   _imra, _axır, _atsķ, отын_, 
   {{0x443c02f6,0x63b801a4,0xbb880014,0xcb680006}},	//   vyt_, _rtvn, _نحقے_, _табе_, 
   {{0xc964166f,0xa3cc0254,0x443dceda,0x00000000}},	//   _двай, शीन_, wyt_, --, 
   {{0x443dcedb,0x65680477,0xb6000030,0x64540640}},	//   tyt_, undh, úšaj, звођ, 
   {{0x6d5c016b,0x77792851,0x7f5c01a9,0x00000000}},	//   _mmra, boux, yiqq, --, 
   {{0x7f5c0290,0x69dc00ef,0x3dac00eb,0x00000000}},	//   xiqq, _ārej, _চৌফল, --, 
   {{0x6d5cb7c5,0x443dcedc,0xe3a41bf3,0x00000000}},	//   _omra, syt_, _کشتی, --, 
   {{0x443dcedd,0x63b8001e,0xb7fc0154,0x3f54031c}},	//   pyt_, _ttvn, ্মরত_, lħux_, 
   {{0x7f5c0cfe,0xd34403e6,0x7ae8007c,0x5f940150}},	//   tiqq, زییه_, yggt, зивт, 
   {{0xb9ec0020,0x6d5dcede,0x23486112,0xceb40d52}},	//   _ነፃ_, _amra, _دستی_, зәр_, 
   {{0x7f5c9ff3,0x32540395,0xa15801f0,0x00000000}},	// [33a50] riqq, _овър, _гапу_, --, 
   {{0xf8bc004d,0x7f5c31c5,0x26f800bc,0xbac89c97}},	//   _đéo_, siqq, ्जुर_, _ﻗﯩﺴﺎ, 
   {{0x20000944,0xd7a80034,0x00000000,0x00000000}},	//   _uphi_, _चूंच, --, --, 
   {{0x6d5c2829,0xa3cc8bb7,0xfb2400d1,0x00000000}},	//   _emra, शीय_, غراپ, --, 
   {{0x6b800009,0xee8400c0,0x00000000,0x00000000}},	//   _dkmg, _жыро, --, --, 
   {{0x71bc00df,0x00000000,0x00000000,0x00000000}},	//   סצוג, --, --, --, 
   {{0x6b800009,0xa3cc01f9,0xb8d0924b,0x00000000}},	//   _fkmg, शीम_, _टल_, --, 
   {{0x3f54003d,0x6d5c02fb,0xbeb80036,0x00000000}},	//   għux_, _zmra, _onëm, --, 
   {{0x7778021c,0x6d5c0042,0x995400c0,0xcb10011a}},	//   roux, _ymra, _екац, _אלן_, 
   {{0x782400c6,0xe5780023,0x00000000,0x00000000}},	//   _وعال, _ኣቃውማ_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xaacc013a,0xa5f800f3,0x00000000,0x00000000}},	//   ारतक, _мецу_, --, --, 
   {{0xd13000dd,0x00000000,0x00000000,0x00000000}},	//   رمز_, --, --, --, 
   {{0x3d0c0034,0x6754f7d0,0x68fd7b27,0xdff40108}},	//   ड़ने_, _رییس_, _örde, мять, 
   {{0x0ea84077,0x00000000,0x00000000,0x00000000}},	//   скай_, --, --, --, 
   {{0x6d5c05b1,0xee500124,0x84940023,0xf7c40210}},	// [33a60] _pmra, hẽvo_, _መዓሙቕ_, ężył_, 
   {{0xf47c0023,0x2ce800f2,0x00000000,0x00000000}},	//   _ሓንሳእ_, تظری_, --, --, 
   {{0xdd1000a2,0xed600153,0x00000000,0x00000000}},	//   _müňb, ūžos_, --, --, 
   {{0x6e20056a,0xea649010,0x3f440037,0x2d44013d}},	//   _ámbo, وپای, _jõul_, _köek_, 
   {{0xda6521e7,0x00000000,0x00000000,0x00000000}},	//   واهي, --, --, --, 
   {{0x6d5dcedf,0xb8d00075,0x994800d0,0x19a801ec}},	//   _umra, ىتىش, túš_, ітіп_, 
   {{0xaf900092,0xb8d000db,0x00000000,0x00000000}},	//   _ሁኔታና_, رتوش, --, --, 
   {{0x86f02756,0x3f440254,0x07080022,0x00000000}},	//   ريخچ, _nõul_, схки_, --, 
   {{0xbeb8f8c8,0x6aa81fc4,0xd5ac00e5,0x00000000}},	//   _poëz, गशीर, لہن_, --, 
   {{0x2c00007d,0x176800cf,0x00000000,0x00000000}},	//   _ईहां_, йрөп_, --, --, 
   {{0x0465cee0,0xf50801e1,0x00000000,0x00000000}},	//   ятим, _ńṣí_, --, --, 
   {{0xc0e0044e,0x2d440724,0xaacc193d,0x00000000}},	//   _ዝሓሸ_, _böek_, ारिक, --, 
   {{0x35f400f2,0x00000000,0x00000000,0x00000000}},	//   _فرود_, --, --, --, 
   {{0xf1a4026b,0x00000000,0x00000000,0x00000000}},	//   ерсн, --, --, --, 
   {{0x34f80375,0xaacc3599,0x635402e8,0xf51400f2}},	//   _ההוד, ाराक, _овку, _رتوش_, 
   {{0x9f05cee1,0x00000000,0x00000000,0x00000000}},	//   بورو, --, --, --, 
   {{0x2cb80175,0x02c01fe7,0x00000000,0x00000000}},	// [33a70] _bfrd_, _व्यभ, --, --, 
   {{0x6154009f,0x00000000,0x00000000,0x00000000}},	//   _آندئ, --, --, --, 
   {{0xff6402d3,0x6bb400d4,0x00000000,0x00000000}},	//   _ተገይሩ_, есіє, --, --, 
   {{0xd5dc0cb4,0x7e2800d3,0x00000000,0x00000000}},	//   _मिलज, _ліга_, --, --, 
   {{0xe9d802d5,0xa3cc0073,0x00000000,0x00000000}},	//   зкі_, शीत_, --, --, 
   {{0xf9900736,0xada40006,0xdd94009d,0x00000000}},	//   ربش_, _паўл, _цагы, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf0940bd9,0x22a402b1,0xeab000c6,0xec340212}},	//   ענק_, _kīkī_, _معك_, _янсь, 
   {{0x957400f7,0x2928007b,0xd0640092,0x80bc07f7}},	//   дынч, átaí_, ደሚሰሩ_, ्राइ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8c180302,0x93580212,0xf1dc000d,0x00000000}},	//   קורי, ірну_, _बिआन, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe53458e5,0x00000000,0x00000000,0x00000000}},	//   _печь, --, --, --, 
   {{0xa3cc0412,0x00000000,0x00000000,0x00000000}},	//   शीद_, --, --, --, 
   {{0x60c045a5,0x63bc0419,0x00000000,0x00000000}},	//   ılma, írne, --, --, 
   {{0xd1b9cee2,0x7bc000e4,0x00000000,0x00000000}},	// [33a80] _بابا_, ãnun, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf1a00116,0x00000000,0x00000000,0x00000000}},	//   _ﺋﻮﻳﯘ, --, --, --, 
   {{0x0b45cee3,0x09e40212,0x00000000,0x00000000}},	//   ьнен, додн, --, --, 
   {{0x3c44006a,0x3dc80142,0x2be00401,0x00000000}},	//   têvö_, _gwcw_, _पटवा, --, 
   {{0xe8941f09,0x31b40166,0x98a40205,0x3cb007a5}},	//   наль, _mäz_, _amlı_, _айёр, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa61570fa,0x8a0422bf,0x5fe0033f,0xb760013d}},	//   емич, _озбе, _फिसल, ктый, 
   {{0x69dc00b0,0x092801f7,0x31b4010e,0x00000000}},	//   _ārew, _وسطي_, _näz_, --, 
   {{0xb8d0015b,0x00000000,0x00000000,0x00000000}},	//   _ঝড়_, --, --, --, 
   {{0x3d0c05b3,0xa40c0154,0x00000000,0x00000000}},	//   ड़ते_, ষম্য_, --, --, 
   {{0x31b4013d,0x00000000,0x00000000,0x00000000}},	//   _bäz_, --, --, --, 
   {{0x2bd80490,0xf798011a,0x00000000,0x00000000}},	//   _डिझा, _ובאמ, --, --, 
   {{0xb6240150,0x00000000,0x00000000,0x00000000}},	//   _ﺯﺕ_, --, --, --, 
   {{0xd24c07d6,0x2004067c,0x00000000,0x00000000}},	//   لچی_, ïli_, --, --, 
   {{0x2bd806bc,0x7ee4ea13,0x812400b8,0x00000000}},	//   _डिजा, ьцге, _ṛtāv, --, 
   {{0xd25000dd,0x20040316,0x1b0c015b,0x00000000}},	// [33a90] _منٹ_, ůli_, _সচলে_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x994801f1,0xfafc002e,0x3f440254,0x60d46887}},	//   núť_, _ñëk_, _jõuk_, mazm, 
   {{0x60d5cee4,0xdea001d5,0x00000000,0x00000000}},	//   lazm, _میزی, --, --, 
   {{0x69c40311,0x343c0092,0x31b40139,0x00000000}},	//   ţien, ሬክቶሬ, _xäz_, --, 
   {{0x60d4083a,0xdce400b0,0x00000000,0x00000000}},	//   nazm, rohē, --, --, 
   {{0xad4400db,0x3f440254,0x068800d1,0x7b746640}},	//   _جۉلۉ, _nõuk_, ﻗﯩﻘﯩ, _قطرا, 
   {{0xac95cee5,0x2d840036,0xbbc80073,0x00000000}},	//   _расш, _ëmer_, ाठीक, --, 
   {{0xd4f40a89,0x60d5cee6,0xa3cc0b4c,0x2678009d}},	//   няны, kazm, शीस_, дсээ_, 
   {{0x31b405d5,0x7d00022e,0xbb440150,0x00000000}},	//   _räz_, еnsi, _ﺘﻁﻠ_, --, 
   {{0xd1d4001f,0xb2c80150,0x00000000,0x00000000}},	//   ያየት_, _ﺒﻘﻭﺍ, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd62891e4,0x00000000,0x00000000,0x00000000}},	//   _холе_, --, --, --, 
   {{0x4638008f,0x31b40419,0x168c0023,0x2c0000c5}},	//   _מענע, _väz_, _ቅድሜኻ_, _रहलू_, 
   {{0xf1dc06bc,0x02000220,0x4508031c,0xc4f4011a}},	//   _बिकन, _ұзын, _ཀྲིར_, _נזקי_, 
   {{0xa3c82aa1,0xddcc033f,0x5fe0482a,0x6280002f}},	//   _लौट_, dzał, _फिरल, ßloc, 
   {{0x61e801ab,0x8e600092,0x00000000,0x00000000}},	// [33aa0] àelt, _ጊዜያቸ, --, --, 
   {{0x98a40100,0x60d467ca,0x660400c5,0xc0e0030d}},	//   _anlč_, cazm, _äike, _йоьк, 
   {{0xc1700302,0x1c380006,0x00000000,0x00000000}},	//   _תחת_, мяць_, --, --, 
   {{0xc444010f,0x27f80166,0xfe08012d,0x00000000}},	//   ערײַ_, _ärni_, _सैकस_, --, 
   {{0xda65cee7,0x7a44002b,0x00000000,0x00000000}},	//   پاني, _nītā, --, --, 
   {{0x271c0208,0x1db43d1d,0x00000000,0x00000000}},	//   _ỉn_, _अंतत, --, --, 
   {{0x2d9809f0,0xddcc033f,0x00000000,0x00000000}},	//   _ihre_, czał, --, --, 
   {{0x7bf8011a,0x00000000,0x00000000,0x00000000}},	//   _מפלצ, --, --, --, 
   {{0x60d4d51a,0x0cd00011,0x69a401ee,0x00000000}},	//   yazm, ালীত, _алаҡ, --, 
   {{0x69c0dd9d,0x998c0139,0x7a4400ef,0xd7ec00ec}},	//   _itme, _ireş_, _dītā, _ڀڃي_, 
   {{0x35f40214,0xec3c01ec,0x00000000,0x00000000}},	//   ورید_, йбiр_, --, --, 
   {{0x998c0790,0x291c00e5,0x00000000,0x00000000}},	//   _kreş_, ldva_, --, --, 
   {{0xf204652e,0x60d401fa,0x6cf002ab,0x7a44002b}},	//   ляро, tazm, _चांग_, _gītā, 
   {{0x291dcee8,0x2d980042,0xc3e001ee,0x00000000}},	//   ndva_, _nhre_, _йөмһ, --, 
   {{0x60d5cee9,0x746400a7,0x972001d3,0xf62800db}},	//   razm, _пръв_, _صہیو, _وتۇۇ_, 
   {{0x69c00cf4,0x00000000,0x00000000,0x00000000}},	//   _otme, --, --, --, 
   {{0x62347327,0x2d98003e,0x9d18039b,0xdea007d6}},	// [33ab0] _репу, _bhre_, моат_, شیسی, 
   {{0x2d98013f,0x6d9001f4,0x60d403b9,0x00000000}},	//   _chre_, säan, qazm, --, 
   {{0x41b41533,0x69c1ceea,0x61fdceeb,0x9bf40276}},	//   _इंडस, _atme, ltsl, тзеч, 
   {{0xeab1ceec,0x4bc00032,0x2d980e78,0xddcc0034}},	//   معه_, рөрг, _ehre_, rzał, 
   {{0x19583c43,0x61fdceed,0xddcc033f,0x00000000}},	//   мады_, ntsl, szał, --, 
   {{0x61fdceee,0x2d9801ab,0x69dc02b5,0xa92402dd}},	//   itsl, _ghre_, _āret, лділ, 
   {{0x69c10a1d,0xac95ceef,0x61fc0857,0xf1a000d1}},	//   _etme, _барш, htsl, _ﺋﻮﻏﯘ, 
   {{0x61fca2ec,0x69c00175,0xbeb80240,0x7a4400cd}},	//   ktsl, _ftme, _enëv, _pītā, 
   {{0x65f80323,0x637c003e,0x693400d1,0x998c0356}},	//   нээр_, bénz, _әнху, _greş_, 
   {{0x637c066d,0x7a440055,0x00000000,0x00000000}},	//   mény, _vītā, --, --, 
   {{0xe90c0003,0x28f010de,0x61fc382c,0x2cbc0165}},	//   _གྲིབ_, _اۋىس, etsl, ñvdi_, 
   {{0x61fc449c,0x63bc3b7b,0x7981cef0,0x2d44007c}},	//   ftsl, írna, lonw, _höet_, 
   {{0x52741823,0xa644004b,0xddcc0100,0x61fc005c}},	//   туну, _مخون, nzań, gtsl, 
   {{0x6e21cef1,0xd008e093,0xdb08017a,0x79807752}},	//   _ámbi, меге_, _bieë, nonw, 
   {{0x61fdcef2,0xfafc1574,0xbad400fe,0x00000000}},	//   atsl, _ñëw_, _হানছ, --, 
   {{0xb8f00489,0xdb08017a,0xc32002e8,0x7981cef3}},	//   _ེབ_, _dieë, _вмък, honw, 
   {{0x7981cef4,0xfe4041bd,0x273801ed,0x61fc01a4}},	// [33ac0] konw, анто, _pénz_, ctsl, 
   {{0x41740ee8,0xaf501954,0xe4580150,0x80a00116}},	//   _لاپس, _መፈላለ, _іжө_, امېن, 
   {{0x69c0031c,0x7981cef5,0x00000000,0x00000000}},	//   _stme, donw, --, --, 
   {{0x273826f6,0x637c01d3,0x996401ec,0x2004025c}},	//   _fény_, fény, қтіл, ħlit_, 
   {{0x637c01ed,0x798000a9,0x2d99cef6,0x273800d7}},	//   gény, fonw, _thre_, _gény_, 
   {{0x2d9801bf,0x7981cef7,0x2d8c0241,0x00000000}},	//   _uhre_, gonw, _óde_, --, 
   {{0x06881c5c,0xb8840023,0xf1dc01f9,0x00000000}},	//   ﺗﯩﻨﯩ, _ምዕጻው_, _बिझन, --, 
   {{0xd05400ac,0x27fc0051,0x00000000,0x00000000}},	//   übəs, rtvn_, --, --, 
   {{0x7980124c,0x69c0df7a,0xbb407843,0xfaa003fb}},	//   bonw, _utme, _тетк, _вато, 
   {{0xf1dc44ab,0x7980014b,0x7e9800d9,0xdb240248}},	//   _बिजन, conw, וספו, _òpòl, 
   {{0xe2f84e19,0xa3cc1408,0x47f00150,0xd72000cc}},	//   нені_, शीं_, _түйр, _ফকৰা_, 
   {{0x61fc77d4,0x7bd80302,0x6fdc0cb4,0x75d000f1}},	//   ttsl, וקטו, _फिजू, _چينا, 
   {{0xf5146071,0x61fc02d0,0x8ca01be1,0xd25000ec}},	//   رتیش_, utsl, केतो, منٽ_, 
   {{0xa2c439db,0x80bcc725,0xb9dc0092,0xc568007b}},	//   ্লেখ, ्रें, _ብየ_, _تحصل_, 
   {{0x224c8be0,0x61fc12ed,0xf1a00075,0xded40240}},	//   šek_, stsl, _ﺋﻮﻗﯘ, ርጉእ_, 
   {{0x6569cef8,0x6449cef9,0x3eadcefa,0x7981cefb}},	//   lidh, mydi, øgt_, zonw, 
   {{0xe3b9839d,0x63ac0472,0x644800c0,0x798001e2}},	// [33ad0] lqı_, _iian, lydi, yonw, 
   {{0xbeb8069c,0x63ac1311,0x637c00dd,0x6569cefc}},	//   _anët, _hian, vény, nidh, 
   {{0x63adcefd,0x644807ab,0x798002b9,0x637c00d2}},	//   _kian, nydi, vonw, wény, 
   {{0x6569cefe,0x9f345cd9,0xaed40228,0x7980013b}},	//   hidh, _семі, _коюш, wonw, 
   {{0x63adceff,0x644800a9,0x656800ec,0x7980127b}},	//   _mian, hydi, kidh, tonw, 
   {{0x63adcf00,0x6568044e,0x64480036,0x637c01d3}},	//   _lian, jidh, kydi, rény, 
   {{0xccf0025f,0x6569cf01,0x63adcf02,0xdb0806af}},	//   _לכם_, didh, _oian, _lieé, 
   {{0x63adcf03,0x7981cf04,0x65680d27,0x4a501914}},	//   _nian, sonw, eidh, ркәс, 
   {{0x6569cf05,0x628dcf06,0xd5480139,0x9584010b}},	//   fidh, _nyao, еппе_, ллие, 
   {{0x28ac038e,0x63adcf07,0x6569cf08,0xd1e402d3}},	//   _चलचि, _aian, gidh, _ዝኣቱ_, 
   {{0x63adcf09,0x628dcf0a,0x2d440267,0x644932eb}},	//   _bian, _ayao, _köer_, gydi, 
   {{0xc7b00302,0x63adcf0b,0x246c016b,0x65681554}},	//   _הבא_, _cian, _dɛm_, aidh, 
   {{0x63acae08,0x656805d9,0x7d040334,0x64480009}},	//   _dian, bidh, _objs, aydi, 
   {{0xd6d8033f,0x00000000,0x00000000,0x00000000}},	//   lał_, --, --, --, 
   {{0x1fb5cf0c,0x63adcf0d,0x06881c5c,0x6449c907}},	//   истр, _fian, ﺗﯩﻠﯩ, cydi, 
   {{0x63adcf0e,0xd6d80034,0xc2b0010b,0x9f540640}},	//   _gian, nał_, _гөрш, ањуј, 
   {{0x76580230,0xbeb8e5c8,0x4b100154,0x7e740352}},	// [33ae0] nzuy, _anës, _সচলগ_, гәрт_, 
   {{0x63adcf0f,0x246c013f,0xbea002dd,0x00000000}},	//   _zian, _yɛm_, саук, --, 
   {{0x50440220,0x0ae8d90c,0x2d440139,0xd6d8033f}},	//   _сенб, едей_, _böer_, kał_, 
   {{0x65685553,0xc0e40014,0xd6d8033f,0x637c00e4}},	//   zidh, _لکہٕ_, jał_, rĩng, 
   {{0xd6d8068f,0x6f05cf10,0x28f8a644,0x6569cf11}},	//   dał_, mfic, вель_, yidh, 
   {{0xc27800c8,0x65680014,0x00000000,0x00000000}},	//   ערסי, xidh, --, --, 
   {{0x65680a28,0x6e240395,0x8b941fbe,0xd6d8033f}},	//   vidh, lvib, _брач, fał_, 
   {{0x6f05cf12,0x6a840220,0x6568a069,0x7bc000db}},	//   nfic, _ұлға, widh, ínue, 
   {{0x63adcf13,0x64484db1,0x6e240660,0x246c013f}},	//   _rian, wydi, nvib, _sɛm_, 
   {{0xe3b8afeb,0x6e2000e4,0x6f04002f,0x6e240254}},	//   tqı_, _ámbu, hfic, ivib, 
   {{0x6569cf14,0x63adc848,0x628c00b5,0xd6d8012d}},	//   ridh, _pian, _syao, bał_, 
   {{0x6569cf15,0x63ac013c,0xd6d8012d,0x00000000}},	//   sidh, _qian, cał_, --, 
   {{0x63adcf16,0xe5340953,0x64480af9,0x058401d5}},	//   _vian, _вель, sydi, _йукм, 
   {{0x6f042be3,0x628c01f7,0xa0c44cdb,0x63ad164a}},	//   efic, _vyao, شيرو, _wian, 
   {{0x63adcf17,0x6f058ad1,0xdfd40276,0xe3b800ac}},	//   _tian, ffic, робы, qqı_, 
   {{0x2f184ec1,0x63ac02b5,0x628c037e,0x00000000}},	//   лось_, _uian, _tyao, --, 
   {{0x7db51ea1,0x628c009f,0x00000000,0x00000000}},	// [33af0] اصرا, _uyao, --, --, 
   {{0xd6d80034,0xeea8094e,0x6f05cf18,0x69dc02b5}},	//   zał_, утск_, afic, _ārep, 
   {{0x5f9422e9,0x06881df2,0xa0340131,0xe8140cbf}},	//   _винт, ﺗﯩﻤﯩ, _ئىجت, _थैला_, 
   {{0xc2e40154,0x00000000,0x00000000,0x00000000}},	//   গ্রি_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x1869cf19,0xd6d8006d,0x76580213,0x9f50036e}},	//   кали_, wał_, vzuy, kuzë_, 
   {{0xd6d80034,0x2d440139,0x00000000,0x00000000}},	//   tał_, _töer_, --, --, 
   {{0x1a64006c,0xdb140200,0x00000000,0x00000000}},	//   _پیتی_, _muzë, --, --, 
   {{0x7af9cf1a,0xd6d8033f,0x1c1c01ad,0x2d440166}},	//   _icut, rał_, फिकल_, _köep_, 
   {{0xd6d8068f,0x3b1c0097,0x8544defb,0xe6081e5a}},	//   sał_, _hauq_, изыв_, ازيو_, 
   {{0x6e2405b8,0x3f44000d,0xd6d8012d,0x6f040210}},	//   zvib, _jõus_, pał_, yfic, 
   {{0xdcfc0205,0x64980304,0x00000000,0x00000000}},	//   _musı, ытыр_, --, --, 
   {{0x56800014,0xf1d00073,0x26c401af,0x00000000}},	//   _گۯکہ, तींन, _уғын_, --, 
   {{0xdb1402d3,0x6e240327,0x00000000,0x00000000}},	//   _buzë, vvib, --, --, 
   {{0x7af80b6f,0x3f4400af,0xd010006c,0x10a43d03}},	//   _ocut, _nõus_, غلر_, ривн, 
   {{0x7af84539,0xcc34066d,0x3b1c0097,0x6f04009f}},	//   _ncut, یراع, _nauq_, ufic, 
   {{0x6f05cf1b,0x8d64c134,0x4d6512b8,0x0ea80006}},	// [33b00] rfic, авае, акав, ткай_, 
   {{0x6f048c35,0x6e24002b,0xdcfc0166,0x2ba80205}},	//   sfic, rvib, _busı, _işci_, 
   {{0x1d8805d9,0x6e240433,0x6f04004e,0x4ac400ae}},	//   ائقي_, svib, pfic, لياق, 
   {{0xc5fc04c5,0xdcfc0166,0x41b000f1,0x0a6801d5}},	//   ্টতা_, _dusı, _دمیر, крли_, 
   {{0x3b1c0226,0x2b9c013a,0x00000000,0x00000000}},	//   _dauq_, jíce_, --, --, 
   {{0x07e48eb4,0x7af8037e,0x7e7400d1,0x00000000}},	//   ацим, _ecut, _тәст_, --, 
   {{0xbeb801c7,0x8c44442d,0xbc5c0023,0x00000000}},	//   _knëp, _теве, ተርኢና_, --, 
   {{0xab74d4cd,0x8b65cf1c,0x332000db,0x3e200023}},	//   _انرژ, _ئاسم, _naix_, _ትርእይ, 
   {{0x0a8800db,0x00000000,0x00000000,0x00000000}},	//   _شئرى_, --, --, --, 
   {{0xdcfc0166,0xb2e00150,0x00000000,0x00000000}},	//   _yusı, _ﻋﺸﻭﺍ, --, --, 
   {{0x33200228,0x7e00190c,0x473405af,0x00000000}},	//   _baix_, _रङ्ग_, _پراز, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x39982776,0x00000000,0x00000000,0x00000000}},	//   sêse_, --, --, --, 
   {{0xdce402b5,0x5eac0011,0xcfac0150,0x00000000}},	//   rohī, টুডে, _ﺳﺎﺭﺗ, --, 
   {{0xff3407dd,0xc2e4036b,0x3f64f1c4,0x85541079}},	//   аҟны_, _кўпи, атаб, _میکر_, 
   {{0xdcf4008e,0x2d440166,0xa6e800fe,0xefd00092}},	//   _rizı, _söep_, ক্ৰম_, ሥሪያ_, 
   {{0x23680699,0x5d54084c,0x63b80455,0xdcfc013d}},	// [33b10] _imaj_, бкат, _huvn, _susı, 
   {{0x7af9cf1d,0x9abc002e,0xf1940050,0xa11401e2}},	//   _scut, _maŋe, _وُٹھ, _اودت, 
   {{0xad2416a0,0x63b800ca,0xaac400aa,0xc10000f1}},	//   تىلى, _juvn, ښتون, _هوښي, 
   {{0x5a3465f1,0x09cc015b,0x63b80477,0x1a6547c8}},	//   йнет, _রমজা, _muvn, میزی_, 
   {{0xe9f80212,0x21200254,0xda0815eb,0x00000000}},	//   инці_, _kahh_, ايته_, --, 
   {{0xe8f84e19,0x3f4400c5,0x2121cf1e,0xdb14008e}},	//   илі_, _tõus_, _jahh_, _muzé, 
   {{0xfba9cf1f,0x2120003e,0x31580375,0x63b8014f}},	//   _атай_, _mahh_, שיון_, _nuvn, 
   {{0x7bc40d04,0x7af8026c,0xe6b441fa,0x4500025c}},	//   _itju, _ucut, يلىگ, _མཁུར_, 
   {{0xd4d81feb,0x55881955,0x0af001c0,0x33200254}},	//   льні_, лбим_, _хүчэ, _raix_, 
   {{0x6e20025a,0x236801e4,0x2120020b,0x6d90005b}},	//   _âmbe, _amaj_, _nahh_, täai, 
   {{0x2b9c0316,0x3321cf20,0xa56402f2,0x00000000}},	//   síce_, _paix_, ڵدین, --, 
   {{0x2121cf21,0x63b816a3,0x00000000,0x00000000}},	//   _aahh_, _duvn, --, --, 
   {{0x0f30001f,0x6d90023a,0x212000a2,0xa56401d5}},	//   _አለማየ, säai, _bahh_, صدین, 
   {{0x236801e4,0xd175cebd,0x846802dd,0x7bc400a2}},	//   _emaj_, сымы, _өзің_, _otju, 
   {{0x21200a2e,0x63b8031c,0xd008010b,0xbb4801ec}},	//   _dahh_, _guvn, ыеве_, _ﻀﻐﻁ_, 
   {{0x2499cf22,0x0490132f,0x00000000,0x00000000}},	//   ürme_, _عليح, --, --, 
   {{0x7bc40024,0xbea000cf,0x8d9401d5,0x42c40139}},	// [33b20] _atju, затк, ملرش, _угын_, 
   {{0x236808a4,0x63b8014f,0x7bc4045a,0x8cb4a68e}},	//   _zmaj_, _yuvn, _btju, ссач, 
   {{0x33e00bb9,0x00000000,0x00000000,0x00000000}},	//   nıx_, --, --, --, 
   {{0x7bc01c69,0xa3cc2ba2,0xeac863eb,0x00000000}},	//   ínua, शीट_, рғай_, --, 
   {{0x212001f9,0x08e401a9,0x9f0401e2,0x00000000}},	//   _yahh_, йҳақ_, _بوټو, --, 
   {{0x3fc80244,0x00000000,0x00000000,0x00000000}},	//   _جدیی_, --, --, --, 
   {{0x9abc002e,0x2b440010,0xdcf400de,0xe858024c}},	//   _saŋe, _tomc_, _aizķ, райш_, 
   {{0xeb5407a7,0xb8ec23ef,0x63b80477,0x3c6006a6}},	//   _بىرگ, _व्_, _ruvn, _эксг, 
   {{0x63b816a5,0x38c80133,0x4acc00cd,0x00000000}},	//   _suvn, _ڕانی_, _ह्यव, --, 
   {{0x63b80455,0xe82002ab,0xd90c02f2,0x00000000}},	//   _puvn, _मनपा_, _لیه_, --, 
   {{0x290c0135,0x63b81ffc,0x7ddc0241,0xf8b0010f}},	//   _ibda_, _quvn, _kàsá, _זשע_, 
   {{0x63b80455,0xe2f802dd,0xf74061ac,0x00000000}},	//   _vuvn, шемі_, _нехо, --, 
   {{0xc69411c7,0x63b8014f,0x96b9cf23,0x00000000}},	//   _اشاع, _wuvn, _туху_, --, 
   {{0xdce400b0,0x63b8014f,0x86f80154,0xbac800d1}},	//   kihā, _tuvn, _আসিফ_, _ﺗﯩﺠﺎ, 
   {{0x290c0421,0x00000000,0x00000000,0x00000000}},	//   _mbda_, --, --, --, 
   {{0xe7f01d34,0x2120194f,0xf36401af,0xe3a40345}},	//   _घटना_, _wahh_, _нтын, _بشتی, 
   {{0x81f0025c,0x2120003e,0x1df8005b,0x290c00a2}},	// [33b30] _བཀྲི_, _tahh_, резы_, _obda_, 
   {{0x21200036,0xd04c0213,0x00000000,0x00000000}},	//   _uahh_, habə, --, --, 
   {{0x2ba401f9,0xa3cc01f9,0x00000000,0x00000000}},	//   _ओळखा, शीच_, --, --, 
   {{0x6bd4007b,0x33f8010f,0xab8400f5,0xceb401af}},	//   ستمر, רהאנ, пучк, _дәф_, 
   {{0xd94497c7,0x6ab80306,0xd04c06be,0xea000051}},	//   жели, _šafá, dabə, yrất_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8c38016c,0x7bc578af,0x7d380092,0x00000000}},	//   _корӣ_, _utju, _በማናቸ, --, 
   {{0x290c038f,0x574806dc,0x7d1402d0,0x00000000}},	//   _ebda_, рзим_, lexs, --, 
   {{0xe70800e3,0x00000000,0x00000000,0x00000000}},	//   صتين_, --, --, --, 
   {{0x6a1400dd,0xc138054e,0x61e8031c,0x00000000}},	//   _عبقر, _ţânţ, ġell, --, 
   {{0x53a43769,0x660c016b,0xccf0011a,0xd04c03e3}},	//   жанб, _ɔnkɔ, וכי_, babə, 
   {{0xd2a8c2f3,0x965400a7,0xd04c0213,0x00000000}},	//   икне_, _мълч, cabə, --, 
   {{0xc0f00092,0xd29800d4,0x6788009f,0x00000000}},	//   ፍትሄ_, ртні_, _اَنّ_, --, 
   {{0xe820012c,0x00000000,0x00000000,0x00000000}},	//   _मनमा_, --, --, --, 
   {{0x752000ec,0x79600023,0x95c401f7,0x00000000}},	//   _ianz, ግለታት, _ايڪه, --, 
   {{0x7520252e,0xd334084c,0x8ec80137,0x00000000}},	//   _hanz, _фэкы, ргаб_, --, 
   {{0x7521cf24,0x80c829d9,0x00000000,0x00000000}},	// [33b40] _kanz, _त्वे, --, --, 
   {{0x7520009d,0x00000000,0x00000000,0x00000000}},	//   _janz, --, --, --, 
   {{0x10a40354,0xfce0023b,0xddb800d1,0xf1ac0150}},	//   _финн, фохо, _қуяш_, _ﺳﻮﻳﺘ, 
   {{0x7521cf25,0x40980375,0x63bd7d8e,0x7e780010}},	//   _lanz, _כביס, írni, _župe, 
   {{0xc9a80640,0xec34036b,0x253c0023,0x49a40f5c}},	//   авде_, _کوزگ, _ክገብሩ, ојка, 
   {{0x77680fec,0x7521cf26,0xe9183334,0x60c4035a}},	//   _amgx, _nanz, сокі_, _xfhm, 
   {{0xfc0015a3,0x6bd40451,0xdcf40171,0xd9b000d1}},	//   _опро, _رڪار, _ekzē, رەمد, 
   {{0x7521cf27,0x2ee00066,0x6d900108,0x2eb8000d}},	//   _aanz, naif_, räau, _अलोत, 
   {{0x752062e7,0xd04c00ac,0x84b400d1,0xa91c0419}},	//   _banz, rabə, оғлу_, _skľu, 
   {{0x7521cf28,0x454801c0,0xf5a000ec,0x86c400ec}},	//   _canz, рчим_, وميٽ, _ڀيان, 
   {{0x752014ed,0x9938013d,0x00000000,0x00000000}},	//   _danz, _уяту_, --, --, 
   {{0xd04c0213,0x28d8012d,0xa2c4008e,0x00000000}},	//   qabə, डरवि, чәкк, --, 
   {{0x2ee00841,0x9abc013d,0xd5a40014,0xe5e40133}},	//   daif_, _jaŋa, تلیی, _رزشی, 
   {{0x7521cf29,0xb5c43253,0x9abc00e8,0x00000000}},	//   _ganz, _بووم_, _maŋa, --, 
   {{0x2ee007c5,0x74100b24,0xa91c0419,0x00000000}},	//   faif_, _يوها, _ukľu, --, 
   {{0x752000b2,0x442d5715,0x80c809fa,0x98a40171}},	//   _zanz, _irf_, _त्रे, _solī_, 
   {{0x75204437,0x07f80156,0x3eac0639,0x5d54721f}},	// [33b50] _yanz, _དཀའཝ_, ägt_, пкат, 
   {{0x442c168c,0xdd9140b9,0xddcc0083,0x7bc0021c}},	//   _krf_, روا_, lyaŋ, ínuo, 
   {{0x5b15cf2a,0x2004004e,0x7d140fac,0x5f9414b3}},	//   змет, àlid_, rexs, _ниот, 
   {{0x50180d65,0x442c050a,0xead400d4,0x7d1402d0}},	//   _פורו, _mrf_, доць, sexs, 
   {{0x4338001f,0x442cb0bb,0x443c0112,0xdb100248}},	//   _እየተባ, _lrf_, hxt_, _áfír, 
   {{0xe9a9cf2b,0x9abc00e8,0x6e2010a2,0x442c6040}},	//   يدون_, _daŋa, _âmba, _orf_, 
   {{0x75200097,0xac941367,0x2b9c00d7,0x00000000}},	//   _ranz, _жарш, síca_, --, 
   {{0x7521cf2c,0x279401ec,0xab8400db,0x8880114f}},	//   _sanz, мшыр, _жуук, رینن, 
   {{0x7521cf2d,0x442dcf2e,0x443c030d,0x61e80960}},	//   _panz, _arf_, ext_, šelj, 
   {{0x1cd80489,0x442c01e3,0xb95400cf,0xdb14008e}},	//   _ོབས_, _brf_, _بئرت, _muzí, 
   {{0x7521cf2f,0xccf000c8,0xc8c40014,0x442c045a}},	//   _vanz, עכט_, _رٕنی, _crf_, 
   {{0x7521cf30,0x77680921,0x88980302,0x442c005c}},	//   _wanz, _umgx, _הבעי, _drf_, 
   {{0x75215877,0xd251cf31,0x35801621,0x442dcf32}},	//   _tanz, رنس_, _оқиб, _erf_, 
   {{0x7521cf33,0x442c0311,0xd3780137,0x443c002f}},	//   _uanz, _frf_, рчү_, bxt_, 
   {{0x8fa49842,0x2ee0009f,0x00000000,0x00000000}},	//   заве, taif_, --, --, 
   {{0x03a00395,0x6d900108,0x4390119e,0x00000000}},	//   _пищо, jäar, _пајс, --, 
   {{0x2ee00597,0x0e65cf34,0x8cb9cf35,0x00000000}},	// [33b60] raif_, чкан, مداس_, --, 
   {{0x28ac28d4,0x9abc002e,0x7e780010,0x6d9001f4}},	//   टेडि, _raŋa, _župc, väas, 
   {{0x00b8011a,0xfaa00022,0x00000000,0x00000000}},	//   _למימ, ҭахо, --, --, 
   {{0x25605b42,0x0b4402d5,0x7f5c0175,0xcb680063}},	//   _gòlf_, янен, chqq, љаде_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe8944834,0x443c0054,0x6d900108,0x00000000}},	//   маль, yxt_, räas, --, 
   {{0x2cac002e,0x6d5c0332,0x6d90005b,0xdb1400d7}},	//   _àdd_, _ilra, säas, _zuzí, 
   {{0x442c01fa,0x0ae8fad7,0xf7f00131,0x00000000}},	//   _rrf_, _درسي_, رسىد, --, 
   {{0xbb380302,0x442d87a8,0x22a402b5,0x00000000}},	//   _פעמי, _srf_, _kūkū_, --, 
   {{0x26c4070d,0x443dcf36,0x442dcf37,0x2918007b}},	//   scmo_, txt_, _prf_, _úra_, 
   {{0x6d5c020c,0xd04c013b,0x87080108,0x00000000}},	//   _mlra, rabɛ, _геев_, --, 
   {{0xb7d4158b,0x38980a7c,0xea000051,0x00000000}},	//   _روها_, _פיאנ, _quặp_, --, 
   {{0x442c005a,0x06a8015b,0x6d5c0205,0xf64c00ec}},	//   _wrf_, _গ্রি, _olra, _مئو_, 
   {{0x647400ee,0x442c0798,0x00000000,0x00000000}},	//   _оглу, _trf_, --, --, 
   {{0xd5a5483d,0x442c01b9,0x3dc80fac,0xd34403e6}},	//   _تلوی, _urf_, _stcw_, سییه_, 
   {{0x6d5c0eee,0x6cd402dd,0x00000000,0x00000000}},	//   _alra, _ﺘﺸﺭﻴ, --, --, 
   {{0xceb44a92,0xfe7006c2,0x00000000,0x00000000}},	// [33b70] дәр_, ردر_, --, --, 
   {{0x6d5c01ab,0x00000000,0x00000000,0x00000000}},	//   _clra, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d5dcf38,0x00000000,0x00000000,0x00000000}},	//   _elra, --, --, --, 
   {{0x60980020,0x81dc0154,0xc3240154,0x00000000}},	//   _መስጠት_, দূর_, যাপি_, --, 
   {{0x34d86225,0xe9d0143e,0xceb0010f,0x6d900108}},	//   _मजेद, اغن_, _שיך_, säar, 
   {{0xdb140798,0x6af80014,0x00000000,0x00000000}},	//   _cuzã, زى۪س_, --, --, 
   {{0xd76004d3,0x95c807a5,0x00000000,0x00000000}},	//   کۆڵی, олиб_, --, --, 
   {{0x6d5c0076,0x1a646071,0xd4f42401,0xdbd01d1d}},	//   _ylra, _تیشی_, мяны, _nýút, 
   {{0x869800f7,0xb9340150,0x23600327,0x13e9cf39}},	//   өтөт_, _رۋعا_, _ċija_, омой_, 
   {{0x4a08025c,0x458001c0,0x00000000,0x00000000}},	//   _གདོལ_, тгэв, --, --, 
   {{0x468c05db,0x91e401f4,0x00000000,0x00000000}},	//   ịtị_, моме, --, --, 
   {{0x27e03d67,0x256007c5,0xfcd40092,0x00000000}},	//   ćine_, _bòld_, _ይስጡ_, --, 
   {{0x10a42e58,0x0ef40c5a,0xc0f00023,0x32dc0051}},	//   дигн, इल्स_, ፍትሑ_, ậy_, 
   {{0x7a440055,0x98a40064,0x00000000,0x00000000}},	//   _hūtā, _molį_, --, --, 
   {{0x7e79cf3a,0x0cd40a28,0x6e600020,0xe82000dc}},	//   _župa, धर्म, _ለመግባ, _मनसा_, 
   {{0xdddc000f,0xd18421d1,0x4d480902,0x7a4400de}},	// [33b80] _bysű, _олий, опан_, _jūtā, 
   {{0x256007de,0x2004004e,0x0c74009a,0x00000000}},	//   _gòld_, àlic_, وداد, --, 
   {{0x6aa00175,0x7a440055,0xb3980092,0x00000000}},	//   _szmf, _lūtā, ለገውን_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x0d7400c0,0x0ee801f9,0x00000000,0x00000000}},	//   _жывя, टणीस_, --, --, 
   {{0x5aa8009f,0x00000000,0x00000000,0x00000000}},	//   سانَ_, --, --, --, 
   {{0x24540241,0x61e80327,0x00000000,0x00000000}},	//   _múmú_, ġeli, --, --, 
   {{0x61e83f99,0xdd3006be,0xc7642dfc,0x2004031c}},	//   šeli, _kəşm, باتى, ħlix_, 
   {{0xf8cc08ec,0x36840323,0x9f45cf3b,0xe82000af}},	//   _स्वय, дсэн_, élé_, _मनवा_, 
   {{0x69c016b8,0x7a44002b,0xa3d400cf,0x00000000}},	//   _iume, _dūtā, нооч, --, 
   {{0x69c006e4,0x291dcf3c,0xb7f803ce,0xe374013d}},	//   _hume, meva_, _एमएम_, елны, 
   {{0x69c1cf3d,0x291dcf3e,0x463000c7,0x97a40212}},	//   _kume, leva_, _аҭир, _зріл, 
   {{0x69c02e15,0x7a440171,0x00000000,0x00000000}},	//   _jume, _gūtā, --, --, 
   {{0x291dcf3f,0x69c1cf40,0xf1a40114,0x00000000}},	//   neva_, _mume, врсн, --, 
   {{0x69c01f11,0x34f800d9,0x04881e24,0xf1ac07d2}},	//   _lume, _והוד, _بخشو_, _ﺳﻮﻗﺘ, 
   {{0x291dcf41,0x69c1cf42,0x6280002f,0x00000000}},	//   heva_, _oume, ßlos, --, 
   {{0x291dcf43,0x9df9cf44,0x2560067c,0x6d9001f4}},	// [33b90] keva_, янат_, _eòle_, täap, 
   {{0x291c3d67,0x9abc002e,0x00000000,0x00000000}},	//   jeva_, _paŋo, --, --, 
   {{0x291dcf45,0x4a082fb5,0x61fdcf46,0x6134010b}},	//   deva_, _གདུལ_, lusl, _eýlä, 
   {{0x69c093ea,0x61fc127b,0xe7f40490,0x35dc033f}},	//   _bume, ousl, ींना_, पीड़, 
   {{0x69c1cf47,0x291c0270,0xe9d85928,0x61fdcf48}},	//   _cume, feva_, дкі_, nusl, 
   {{0x291dcf49,0xdd942b2a,0x18a5a562,0x3f980054}},	//   geva_, _чагы, налм, llqu_, 
   {{0x69c1cf4a,0x61fdcf4b,0x999001d3,0xbb1843fb}},	//   _eume, husl, éből_, _وزرا_, 
   {{0x69c1cf4c,0x61fdcf4d,0x7a441d86,0x00000000}},	//   _fume, kusl, _pūtā, --, 
   {{0x69c0ae10,0x291c16fe,0x65f801c0,0xe6c40131}},	//   _gume, beva_, мээр_, ختىي, 
   {{0x291c16fe,0x61fdcf4e,0xb6a0036b,0x5dd40150}},	//   ceva_, dusl, ниқл, _ﺘﺨﻤﻴ, 
   {{0x69c1cf4f,0x2624037e,0x00000000,0x00000000}},	//   _zume, をon_, --, --, 
   {{0x69c1cf50,0x7a4402b1,0xd6d8033f,0x61fc0790}},	//   _yume, _tūtā, ykły_, fusl, 
   {{0x7e79cf51,0x61fc00af,0x69c1cf52,0xe604009f}},	//   _župn, gusl, _xume, _لِنَ, 
   {{0x8fd05dc9,0xc5ec0a81,0x2560067c,0xd1300050}},	//   ләмә, _آو_, _pòle_, دمس_, 
   {{0xd478010f,0x454400f1,0x00000000,0x00000000}},	//   _מאַל, _سروې, --, --, 
   {{0x2004af07,0x61fdcf53,0x291db47f,0x25600ba1}},	//   àlia_, busl, zeva_, _vòle_, 
   {{0xc7b005e1,0x61fc1730,0x291dcf54,0xe1880451}},	// [33ba0] רבן_, cusl, yeva_, _ڪئين_, 
   {{0x69c1cf55,0x2cbc03a1,0x8d7400c6,0x27fc037e}},	//   _rume, øvd_, راءا, yuvn_, 
   {{0x69c1cf56,0x291dcf57,0x00000000,0x00000000}},	//   _sume, veva_, --, --, 
   {{0xaca401f2,0x69c1cf58,0x09e5cf59,0x291c0472}},	//   _nrụr, _pume, еодн, weva_, 
   {{0x291dcf5a,0x729402d3,0x69c00023,0x82d4008f}},	//   teva_, _መንቀሊ_, _qume, גונג_, 
   {{0xaca40521,0x69c04ec2,0x98a4294f,0x9cb000db}},	//   _arụr, _vume, _allı_, _چۅكت, 
   {{0x291dcf5b,0x61fc0cf4,0xf1ac0220,0x00000000}},	//   reva_, zusl, _ﺳﻮﻟﺘ, --, 
   {{0x69c1cf5c,0x291c16fe,0x59dc0316,0xb4c800e4}},	//   _tume, seva_, नीहर, _hẽhá, 
   {{0x291c5909,0x69c0198f,0xe7e000e1,0xe9c40022}},	//   peva_, _uume, _गौरा_, _разҿ, 
   {{0x61fdcf5d,0xdb080158,0xd5ac00f1,0xd1d40092}},	//   vusl, _vieå, يځو_, ካከት_, 
   {{0x249804ce,0x98c401b9,0xe2f82080,0x59740024}},	//   ærm_, _شغلن, мені_, _рыту, 
   {{0x61fdcf5e,0x59dc1cba,0x00000000,0x00000000}},	//   tusl, नीवर, --, --, 
   {{0x28ac584e,0x78c4072b,0x00000000,0x00000000}},	//   टेरि, _årvå, --, --, 
   {{0xf125cf5f,0xc32400eb,0x00000000,0x00000000}},	//   льсо, যাধি_, --, --, 
   {{0xd24c036b,0x61fdcf60,0xdfd0007b,0x00000000}},	//   مچی_, susl, شيء_, --, 
   {{0x61fdcf61,0xc87002d3,0x00000000,0x00000000}},	//   pusl, _እንድዒ_, --, --, 
   {{0x2b9c00bc,0xc0c80276,0x00000000,0x00000000}},	// [33bb0] mích_, _нуне_, --, --, 
   {{0x61ec03b4,0x2b9c00bc,0xa0b9cf62,0xf27c0a7c}},	//   _ival, lích_, _огпу_, _מרחש, 
   {{0xdea00405,0xe06002f2,0x1a640066,0x00000000}},	//   _چیزی, _ئێزی, چیزی_, --, 
   {{0x2b9c038e,0xdea00133,0x1a6405af,0x00000000}},	//   ních_, _نیزی, نیزی_, --, 
   {{0xaa59cf63,0xdd90592e,0x05b00034,0x61ec00dc}},	//   ницу_, _نوح_, ीदाब, _jval, 
   {{0x428c069c,0x61ec090c,0x7f4c0381,0x2b9c0051}},	//   _ሓድነት_, _mval, _hocq, hích_, 
   {{0x61ec074d,0x9abc00e8,0xf8100214,0xac180138}},	//   _lval, _jaŋk, استگ, _пору_, 
   {{0x27ec01e4,0x2b9c012c,0x00000000,0x00000000}},	//   _dvdn_, jích_, --, --, 
   {{0x27e01326,0xab85957a,0x95842c31,0x8620073e}},	//   ćina_, _сурк, клие, لکول, 
   {{0x38c8cd11,0x0418009e,0x7f4c0129,0xa98800db}},	//   _хуан_, ধিনী_, _locq, _كۅنۅ_, 
   {{0x61edcf64,0x7e78107d,0xd468d52c,0x00000000}},	//   _aval, _župl, фине_, --, 
   {{0x2cb003be,0x98a40139,0x846c0023,0x00000000}},	//   ündə_, _ullı_, _ብዘመን_, --, 
   {{0x9abc00e8,0x98a40100,0x422002e8,0xcad400d9}},	//   _aaŋk, _malč_, адяв, כורת_, 
   {{0xd17410e0,0x61edcf65,0x5434009d,0x00000000}},	//   тымы, _dval, _ахиу, --, 
   {{0xc0e00a70,0xdff4769a,0x7f4c0165,0x2b9c0c5e}},	//   роск, лять, _bocq, bích_, 
   {{0x2b9c0300,0x9abc002e,0x00000000,0x00000000}},	//   cích_, _daŋk, --, --, 
   {{0xcd0400f7,0xf3f000eb,0x543401e2,0xcde4003b}},	// [33bc0] кпай, _জহির_, _سرګر, тозй, 
   {{0x645c0ac7,0x399800d2,0x00000000,0x00000000}},	//   ørig, bêsi_, --, --, 
   {{0x61ec0b91,0xfbc1cf66,0x2b9c0306,0x3ce1cf67}},	//   _zval, абхо, líci_, _dejv_, 
   {{0x2560067c,0x61ed17df,0x637c00c7,0x31780205}},	//   _mòla_, _yval, rũng, lirz_, 
   {{0x2b9c0122,0x8b6404d3,0x6a1400d1,0x6f0401e3}},	//   níci_, _یارم, умлу, mgic, 
   {{0x6e243dd4,0x2b9c012c,0x6d580267,0x24780b82}},	//   mwib, zích_, övad, _ኢድሪስ_, 
   {{0x2d9801fa,0xece802f5,0x98c4109a,0x39a402d2}},	//   _ikre_, _পাপড, усіл, _sísý_, 
   {{0x59dc09fd,0x00000000,0x00000000,0x00000000}},	//   _नौकर, --, --, --, 
   {{0x6e2402c4,0x58e00183,0xf76c1176,0x667435cf}},	//   nwib, _নাৰী, تاو_, دگار, 
   {{0x38c81afc,0x2b9c0306,0x80b00073,0x5dd40150}},	//   _قامی_, díci_, _आणले, _ﺘﺨﻴﻴ, 
   {{0x6e25cf68,0x2560068c,0x3178010a,0x2b9c0308}},	//   hwib, _còla_, dirz_, tích_, 
   {{0x6e240c10,0x256001e1,0x2b9c02f0,0x61ec01f4}},	//   kwib, _dòla_, fíci_, _pval, 
   {{0x2b9c00c6,0x9f440085,0x6720009f,0xc174ce83}},	//   rích_, élí_, memj, ندست, 
   {{0x660056e4,0x2560067c,0x6720bc4c,0x61ec025c}},	//   mumk, _fòla_, lemj, _vval, 
   {{0x6600004b,0x00000000,0x00000000,0x00000000}},	//   lumk, --, --, --, 
   {{0x6f045dbd,0x2d99cf69,0x61edcf6a,0xdd3003e3}},	//   ggic, _akre_, _tval, fəşa, 
   {{0x6e25cf6b,0x997406be,0xa0a401ec,0x3cdc00bc}},	// [33bd0] gwib, _nəşi_, таңд, गरले_, 
   {{0x2258045f,0x98a40100,0xdd10010e,0x00000000}},	//   mysk_, _salč_, _düşb, --, 
   {{0x98a402e2,0x2258000f,0x7f4c0129,0x9bf40276}},	//   _palč_, lysk_, _tocq, узеч, 
   {{0x66006ae5,0x6e253d88,0x4bc00032,0x2d980254}},	//   kumk, bwib, сөрг, _ekre_, 
   {{0x22580b21,0x98a402e2,0xdb140139,0x67200135}},	//   nysk_, _valč_, _ruzä, demj, 
   {{0xdd904d8d,0x02a0063f,0xd8880131,0xfbd00345}},	//   _چوڭ_, _arịọ, ىھان_, _نتر_, 
   {{0x98143ff4,0x2258002d,0x17b800d8,0x00000000}},	//   ابتا, hysk_, нѓиќ_, --, 
   {{0x5629cf6c,0x3ab004a9,0x6600009f,0x00000000}},	//   ежим_, _кәлт, fumk, --, 
   {{0x660001f0,0x225869e8,0x58d5cf6d,0x00000000}},	//   gumk, jysk_, _бозт, --, 
   {{0x25bc0421,0x256001ab,0x22589855,0x4e34010f}},	//   _civl_, _pòla_, dysk_, אָטן_, 
   {{0x6e240117,0x59a8012d,0x98a40051,0x00000000}},	//   zwib, _चीयर, _tnlđ_, --, 
   {{0x67202804,0x2258045f,0x6600058a,0x00000000}},	//   cemj, fysk_, bumk, --, 
   {{0x52740228,0x22580b21,0x36d0013d,0xa6441888}},	//   ууну, gysk_, _боҗр, _نخون, 
   {{0x6e2106c9,0xc02c02d3,0x8678011a,0x4914013a}},	//   _âmbi, _ብልሽው, _ארנו, प्पो_, 
   {{0xb4dc52f2,0xac9802d3,0x2b9c012c,0x3ddc0327}},	//   तरी_, _ጀሚሮም_, síci_, _ħuwa_, 
   {{0x6e242dab,0x2259cf6e,0x4f9400f7,0x2d9803cd}},	//   twib, bysk_, ургу, _skre_, 
   {{0x0d84785b,0xd1740184,0x69c40356,0x00000000}},	// [33be0] глан, _быны, ţiez, --, 
   {{0x6e243223,0x6f05cf6f,0x672000e2,0x50440818}},	//   rwib, sgic, zemj, _беоб, 
   {{0xadf047b8,0x6721252a,0x6f040267,0xc3240154}},	//   _चिकन_, yemj, pgic, যারি_, 
   {{0xb4dc0254,0x6ea801d9,0x6600009f,0x4f5800ae}},	//   तरु_, _لنجہ_, yumk, _أجدد_, 
   {{0x5ac40131,0x41b0114f,0x7b8400d1,0x0e540395}},	//   рһум_, _خمیر, دالە, _съня, 
   {{0x0828023a,0xe918109a,0x76b80055,0x67d400d8}},	//   еции_, токі_, _māyī, аоку, 
   {{0x66004a7d,0x6721cf70,0x27e000f3,0xc7b80107}},	//   wumk, temj, ćino_, нёи_, 
   {{0x998c084c,0x6600005f,0x6fb405f9,0x7981cf71}},	//   _preţ_, tumk, ंगिं, annw, 
   {{0x933802d3,0x6721cf72,0x237800b5,0xfaa00006}},	//   እኽትታ, remj, visj_, _гато, 
   {{0x6721cf73,0x2258ec01,0x2ba8000d,0x00000000}},	//   semj, vysk_, _छीता, --, 
   {{0x2379cf74,0x6fb40073,0x00000000,0x00000000}},	//   tisj_, ंगां, --, --, 
   {{0x2259cd0e,0x62340108,0x00000000,0x00000000}},	//   tysk_, аему, --, --, 
   {{0x701400fe,0x00000000,0x00000000,0x00000000}},	//   াটোও_, --, --, --, 
   {{0x22580a85,0xa4d4177b,0x98a4002b,0x00000000}},	//   rysk_, _токі, _halā_, --, 
   {{0x6568379c,0x2258045f,0x98a400cd,0xc52401ec}},	//   mhdh, sysk_, _kalā_, _аяққ, 
   {{0x3998000f,0x2259cf75,0x98a400b8,0xc2e401b9}},	//   lêst_, pysk_, _jalā_, _сўки, 
   {{0x63adcf76,0x13d80729,0x79800368,0xdd741677}},	// [33bf0] _ihan, _থিয়, ynnw, агањ, 
   {{0x98a40421,0x63ac01ab,0x3998000f,0x31c400a7}},	//   _lalā_, _hhan, nêst_, _усъв, 
   {{0x64480369,0x3fa40736,0xc0c001af,0x5c740798}},	//   nxdi, _مصحف, _вәғи, јлет, 
   {{0x9f340046,0x5a3423b3,0x63ac0036,0x6568003e}},	//   _темі, инет, _jhan, hhdh, 
   {{0x63adcf77,0x20100356,0xf2d4010f,0xad440137}},	//   _mhan, ltzi_, צעס_, _گۉلۉ, 
   {{0x63adcf78,0x61fc01ab,0x4e78010f,0x8df8011a}},	//   _lhan, irsl, _יארצ, _בהשת, 
   {{0x63adcf79,0x201005f5,0x315806a9,0x98a400b8}},	//   _ohan, ntzi_, ריון_, _balā_, 
   {{0xde540201,0x63ac07ae,0x61fc627e,0x7980013f}},	//   _የመንግ, _nhan, krsl, snnw, 
   {{0x7ae9cf7a,0x7bc5cf7b,0x3998045f,0x790401d3}},	//   magt, _huju, fêst_, _مظال, 
   {{0x63adc8b8,0x7bc5cf7c,0x7ae9cf7d,0xb4dc7123}},	//   _ahan, _kuju, lagt, तरे_, 
   {{0x7bc45df1,0x63ac7001,0x61fc1a7c,0x998c09a8}},	//   _juju, _bhan, ersl, _greš_, 
   {{0x63adcf7e,0x7ae9cf7f,0x98a4005f,0xe7844b53}},	//   _chan, nagt, _galā_, _лучо, 
   {{0x63adcf80,0x7bc5cf81,0x399c02d3,0x55e5cf82}},	//   _dhan, _luju, ልገልቲ_, _толб, 
   {{0x63adcf83,0x77780369,0x7ae806ea,0x6568078c}},	//   _ehan, liux, hagt, chdh, 
   {{0x63ad5dde,0x7bc5cf84,0x7ae9b2c8,0x645c0086}},	//   _fhan, _nuju, kagt, ùrit, 
   {{0x63adcf85,0x7ae9cf86,0x6290020c,0x6e440092}},	//   _ghan, jagt, ékoé, _ከመግባ, 
  
   {{0x7ae80151,0x7659cf87,0x637c0022,0x00000000}},	// [33c00] dagt, nyuy, rĩnt, --, 
   {{0x7bc5cf88,0x2b580214,0x8cb9cf35,0x5164004e}},	//   _buju, گیرد_, نداس_, _түгү_, 
   {{0x7bc41730,0x63ac0d81,0x8fa42472,0xe2a865dd}},	//   _cuju, _yhan, _ване, _لاین_, 
   {{0x63ac0023,0x6568003e,0x7ae80009,0xdc980131}},	//   _xhan, zhdh, gagt, утуш_, 
   {{0xdb09cf89,0x28f86f65,0x7bc40010,0x3950022e}},	//   ازمه_, гель_, _euju, аxs_, 
   {{0x7bc5cf8a,0x1cc40327,0x98a400e2,0xb4dc00cd}},	//   _fuju, _ཌུར_, _salā_, तरो_, 
   {{0x7ae9cf8b,0x7bc5cf8c,0x00000000,0x00000000}},	//   bagt, _guju, --, --, 
   {{0x7ae9cf8d,0x765800ca,0x61fd66b6,0xee5000e4}},	//   cagt, fyuy, yrsl, hẽmo_, 
   {{0x63adcf8e,0x7658089c,0x247002d3,0x7bc40223}},	//   _rhan, gyuy, _ኣሕመድ_, _zuju, 
   {{0x63adcf8f,0x6e20145e,0x998c01a6,0x7bc41f9d}},	//   _shan, _âmbu, _treš_, _yuju, 
   {{0x98a4d663,0x38c8035c,0x63ad3417,0x3998045f}},	//   _talā_, _شالی_, _phan, rêst_, 
   {{0x68e9cf90,0xb9dc069c,0xf7400364,0x63ac094a}},	//   _hedd, _ኣቶ_, _мехо, _qhan, 
   {{0x68e9cf91,0x63ac0dc9,0x61fc0f49,0x02a0063f}},	//   _kedd, _vhan, ursl, _trọọ, 
   {{0x63ac0325,0x68e9cf92,0xd04c013f,0x7ae800de}},	//   _whan, _jedd, yabɔ, zagt, 
   {{0x68e9cf93,0x63adcf94,0x838402f6,0x7ee427a8}},	//   _medd, _than, _выпе, ицае, 
   {{0x63ac123c,0x68e9cf95,0x7bc5cf96,0x201001c0}},	//   _uhan, _ledd, _ruju, rtzi_, 
   {{0xf420038f,0x68e800a9,0x7ae9cf97,0x26100051}},	// [33c10] _འགོད_, _oedd, vagt, nào_, 
   {{0x68e9cf98,0x7bc5355c,0x7ae9cf99,0xc0c00023}},	//   _nedd, _puju, wagt, ጻጸሮ_, 
   {{0x7ae8017a,0xfe7c017a,0x6d580108,0x5f9400f3}},	//   tagt, _geïn_, övaa, _гинт, 
   {{0x7bc4036b,0x68e803cb,0x00000000,0x00000000}},	//   _vuju, _aedd, --, --, 
   {{0x1958f0e0,0x7bc54cb4,0x68e9cf9a,0x7ae9cf9b}},	//   лады_, _wuju, _bedd, ragt, 
   {{0x7bc42c3e,0x68e9cf9c,0x7ae9cf9d,0xceb4011a}},	//   _tuju, _cedd, sagt, _לפרק_, 
   {{0x7ae879f4,0x68e8bf71,0x88e400eb,0x00000000}},	//   pagt, _dedd, _নাশক, --, 
   {{0x68e9cf9e,0xb4dc06ff,0x00000000,0x00000000}},	//   _eedd, तर्_, --, --, 
   {{0x68e9cf9f,0x290c0198,0x163800c6,0x60c4014f}},	//   _fedd, _fcda_, اسبة_, _oghm, 
   {{0x68e9cfa0,0x290c0048,0x636c002d,0x7659cfa1}},	//   _gedd, _gcda_, _jûnf, ryuy, 
   {{0x67d40354,0x3f88012d,0x5dd402dd,0xb4dc00cd}},	//   _доху, _ojcu_, _ﺘﻨﻔﻴ, तरौ_, 
   {{0x68e82930,0x60c5cfa2,0x645c0194,0x00000000}},	//   _zedd, _aghm, øria, --, 
   {{0x68e9cfa3,0x9474114f,0x00000000,0x00000000}},	//   _yedd, شدگا, --, --, 
   {{0xd00824ce,0x863400c8,0x8a78008f,0x98a4054e}},	//   леге_, _לאנג_, אָלק, _gală_, 
   {{0x50300020,0x81c80154,0x24980112,0x00000000}},	//   _ችግሮች, _লবণ_, ürmt_, --, 
   {{0x60c40978,0x00000000,0x00000000,0x00000000}},	//   _eghm, --, --, --, 
   {{0xc7b000d9,0x00000000,0x00000000,0x00000000}},	// [33c20] לבל_, --, --, --, 
   {{0xe81809bb,0x00000000,0x00000000,0x00000000}},	//   _दहला_, --, --, --, 
   {{0x68e9cfa4,0x6aa08067,0x9db8a1a1,0x2cbc01e3}},	//   _redd, _symf, рыту_, ävd_, 
   {{0x68e9cfa5,0x2294063f,0x4a44010b,0x00000000}},	//   _sedd, ụke_, йнев, --, 
   {{0x68e9cfa6,0x429402d3,0x00000000,0x00000000}},	//   _pedd, _መንነት_, --, --, 
   {{0xe6e04244,0x68e8011f,0x69dc0427,0x26100208}},	//   नर्ज, _qedd, _čred, vào_, 
   {{0x2c1c00e1,0xec3401d5,0xfce001c6,0x7d0003b2}},	//   _नहिं_, _بوزگ, _хосо, ónse, 
   {{0x68e9cfa7,0x98a40311,0xd800030a,0xb92800db}},	//   _wedd, _sală_, doăą_, _ۅزمۅ_, 
   {{0x68e9cfa8,0x59a800dc,0x00000000,0x00000000}},	//   _tedd, _चीवर, --, --, 
   {{0x636c006a,0x290c04ba,0xf31401c0,0x3d0808e6}},	//   _kûng, _ucda_, үдээ, ालये_, 
   {{0x24180022,0xb990a012,0x00000000,0x00000000}},	//   шоны_, _علمب, --, --, 
   {{0xf8a40451,0x490c00bc,0x46a401af,0x00000000}},	//   _اگهه_, _ठाडो_, _лаев, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xefdc0020,0x066403e6,0xd5c00055,0x00000000}},	//   ንገድ_, _پاڵپ, _prāś_, --, 
   {{0x636c002d,0x75300118,0x00000000,0x00000000}},	//   _rûnf, řezá, --, --, 
   {{0x9ed8d654,0x442dcfa9,0x9f05207f,0x6d5801e3}},	//   рмат_, _isf_, تورو, övan, 
   {{0x7cc4db35,0x5d5417a2,0x442dcfaa,0xbeb81bce}},	// [33c30] مزام, окат, _hsf_, _mbëg, 
   {{0x636c2776,0x442c0162,0x60c4047e,0x4085cfab}},	//   _bûng, _ksf_, _ughm, _гумб, 
   {{0xaf6401f3,0x00000000,0x00000000,0x00000000}},	//   _መገምገ, --, --, --, 
   {{0x442dcfac,0x9ce80154,0x7d000162,0x00000000}},	//   _msf_, খলেন_, ónsb, --, 
   {{0x442c0048,0x3f980481,0x23680010,0x3c900050}},	//   _lsf_, moqu_, _mlaj_, _کیاز, 
   {{0x636dcfad,0x3f99cfae,0x442dcfaf,0x00000000}},	//   _hûnd, loqu_, _osf_, --, 
   {{0x442dcfb0,0x02f85020,0x9868036b,0x236801d3}},	//   _nsf_, ्लाह_, рийб_, _olaj_, 
   {{0x3f980286,0x00000000,0x00000000,0x00000000}},	//   noqu_, --, --, --, 
   {{0x442c11ce,0x645c1477,0x636c002d,0xee5000e4}},	//   _asf_, ørin, _mûnd, vẽko_, 
   {{0x442c06a3,0xbdd806af,0x00000000,0x00000000}},	//   _bsf_, _trèf, --, --, 
   {{0x2369cfb1,0xdce400d0,0x442cf6ad,0x98a400c0}},	//   _blaj_, kohľ, _csf_, _balą_, 
   {{0xbdd9cfb2,0x2bd02aa1,0x80a00490,0x96b8548b}},	//   _grèg, _तूफा, _गरजे, _кулу_, 
   {{0xe6940588,0xd8000165,0xdce40419,0x00000000}},	//   _еицы, soăą_, dohľ, --, 
   {{0x442c022c,0x73880209,0x00000000,0x00000000}},	//   _fsf_, ррүң_, --, --, 
   {{0x4f78005b,0x9394007b,0x09c401f9,0x98a40210}},	//   ащая_, _وجبا, _लढ्य, _falą_, 
   {{0x3f980481,0xb8e8025c,0x636c002d,0x2bd010eb}},	//   goqu_, _ཊུ_, _rûng, _तंबा, 
   {{0xbea10a69,0x27e01326,0x636c025a,0x442c0076}},	// [33c40] датк, ćini_, _sûng, _zsf_, 
   {{0x4c8400a7,0xefdc069d,0x31a401d3,0xd184011c}},	//   олзв, ንለው_, közi_, _флой, 
   {{0x7ee06911,0x00000000,0x00000000,0x00000000}},	//   سكەن, --, --, --, 
   {{0x8cd81d97,0x88e402a6,0x636c006a,0xd11403ce}},	//   _प्रो, _নাইক, _vûng, द्रण_, 
   {{0x09488a6b,0xbdd81daa,0x00000000,0x00000000}},	//   ички_, _crèd, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x636c045f,0xd90c0ec5,0xefdc02d3,0xde70001f}},	//   _hûne, ایم_, ንገዲ_, _ለመደገ, 
   {{0x3b043117,0x29000276,0x442c0174,0xc7b8034b}},	//   _месо_, şia_, _rsf_, шёл_, 
   {{0x442cf5b8,0x636c045f,0xc5240120,0x15d801d3}},	//   _ssf_, _jûne, оќни, یدیں_, 
   {{0x29180013,0x02e00316,0x636c045f,0x49900edf}},	//   _ùra_, पर्न, _mûne, _تیتر, 
   {{0x2369cfb3,0x98a40210,0x00000000,0x00000000}},	//   _plaj_, _palą_, --, --, 
   {{0xd1f0001f,0x442d083a,0x29d001e1,0x49140b9a}},	//   ግጅት_, _vsf_, _kàa_, प्रो_, 
   {{0x636c002d,0x236801a6,0x29d00248,0x98a40064}},	//   _rûnd, _vlaj_, _jàa_, _valą_, 
   {{0x636c0225,0x386c1ae4,0x6d58aecc,0x29d00241}},	//   _sûnd, _ömrü_, öval, _màa_, 
   {{0xd24c0517,0x442c067c,0x645c00c5,0x29d001ab}},	//   نچی_, _usf_, ärid, _làa_, 
   {{0xa1141129,0x636c002d,0xf4840244,0xa29420c8}},	//   _کودت, _bûne, _باهی, _найі, 
   {{0x29d00248,0x00000000,0x00000000,0x00000000}},	// [33c50] _nàa_, --, --, --, 
   {{0x636c0b21,0x7e780e04,0x33f0013d,0x6f880014}},	//   _wûnd, _žups, _эчәс, ٕنہِ_, 
   {{0xd94400c7,0x00000000,0x00000000,0x00000000}},	//   ҷели, --, --, --, 
   {{0x636c0b21,0x29d00248,0x2bc80220,0xba7521fc}},	//   _fûne, _bàa_, іліп_, ياشت, 
   {{0xd945cfb4,0x636c002d,0x65b401ab,0x00000000}},	//   зели, _gûne, màhf, --, 
   {{0x491400bc,0x00000000,0x00000000,0x00000000}},	//   प्लो_, --, --, --, 
   {{0x645c0140,0x00000000,0x00000000,0x00000000}},	//   øril, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x70a83b90,0x7af827d7,0x46e405f5,0xc7ac06f6}},	//   _गर्ल, _idut, чдын_, دّي_, 
   {{0xae0c01ad,0x6e20ff6c,0x00000000,0x00000000}},	//   िंतन_, _ämbe, --, --, 
   {{0x3a3c0219,0x041c0154,0x00000000,0x00000000}},	//   _hrup_, বয়সী_, --, --, 
   {{0xb4a81098,0x25e80490,0x00000000,0x00000000}},	//   _खरी_, चीही_, --, --, 
   {{0xe7c405f9,0xdb0801c3,0x67f001e1,0x00000000}},	//   _लूटप, _mheà, _tójá, --, 
   {{0x636c045f,0xbdd80241,0x0ef45b99,0x00000000}},	//   _rûne, _orèb, ेल्स_, --, 
   {{0x7af88967,0x636c045f,0x45300e8e,0xd01001d5}},	//   _odut, _sûne, _سىير, علر_, 
   {{0x7af9cfb5,0x645dcfb6,0x229402e3,0xbfc06179}},	//   _ndut, ärie, ụka_, ебск, 
   {{0x741000aa,0xc330010f,0xb4b809b2,0x2e8800c7}},	// [33c60] _روښا, _טוה_, _अणु_, циаҿ_, 
   {{0x7af9cfb7,0xd1b001d5,0x00000000,0x00000000}},	//   _adut, _سیزک, --, --, 
   {{0xdb0801c3,0x636c045f,0x32640014,0xfce00c69}},	//   _bheà, _wûne, _رنگہ, хохо, 
   {{0xdb080e89,0x2560180f,0xdd000421,0x4df401c0}},	//   _cheà, _vòli_, ītāu, _нягт, 
   {{0x98dc0316,0xdb0801c3,0xdb18017a,0x00000000}},	//   नुभए, _dheà, omwê, --, 
   {{0xdb15cfb8,0x3a3c0ea0,0x200443e9,0x07e40114}},	//   _buzó, _drup_, álig_, пцим, 
   {{0x3a3c0194,0xa7b9cfb9,0xdb080192,0x29d001e1}},	//   _erup_, олку_, _fheà, _wàa_, 
   {{0x9518038f,0xdb0808c2,0x66044606,0x645c0140}},	//   ྱུའི_, _gheà, _åikk, ørim, 
   {{0xfb11cfba,0x00000000,0x00000000,0x00000000}},	//   _سولج, --, --, --, 
   {{0xa49435aa,0xa3d4026b,0x00000000,0x00000000}},	//   ویشت, мооч, --, --, 
   {{0xaee40943,0xbdd81801,0x636c002d,0x0ca800dc}},	//   _luṱu, _krèc, _rûnb, _करोम, 
   {{0x3ce003d4,0x618c0240,0x00000000,0x00000000}},	//   _পাছৱ, _ዓብላሊ_, --, --, 
   {{0x27e02ce2,0xf36401c6,0x00000000,0x00000000}},	//   ćinu_, хтэн, --, --, 
   {{0x35b01ed2,0xdb0800c6,0x26e400cc,0x00000000}},	//   _збір, _mheá, _গাটো_, --, 
   {{0x4439cfbb,0x60d4012d,0x1fc40818,0x5f4403c7}},	//   _ép_, rczm, драҳ, ونسل, 
   {{0xdd901f0d,0x00000000,0x00000000,0x00000000}},	//   ھوا_, --, --, --, 
   {{0x7bc801e4,0x86800023,0xdd9003c7,0x00000000}},	// [33c70] ĉgum, _ክትብሎ_, پوا_, --, 
   {{0xe0d001d9,0x00000000,0x00000000,0x00000000}},	//   _جٲد_, --, --, --, 
   {{0x5b147696,0x2b2401f2,0xbdd84e01,0x39480208}},	//   дмет, ọ́ọ̀, _brèc, _đcs_, 
   {{0xbdd859c6,0xdb0801e7,0xcff4011a,0x00000000}},	//   _crèc, _bheá, _קצרה_, --, 
   {{0x3a3c03be,0xcf540302,0x4bc07aea,0xdb0801e7}},	//   _qrup_, _חברת_, төрг, _cheá, 
   {{0x98a5cfbc,0xbdd8007f,0xdb0801e7,0x6e2000c7}},	//   миле, _trèb, _dheá, _ãmba, 
   {{0xc68404fb,0xb4a80574,0xbdd80100,0xdb080e89}},	//   _פِ_, _खरे_, _frèc, _theà, 
   {{0xbdd9cfbd,0x7af8f32a,0x3a3dcfbe,0xcc8403e6}},	//   _grèc, _udut, _trup_, _تۆمه_, 
   {{0x98ac00ac,0xdb080332,0x3a3c010b,0x00000000}},	//   ınıb_, _gheá, _urup_, --, 
   {{0xb86400e5,0xc0dc0240,0x00000000,0x00000000}},	//   _ٹائو, ቓላሊ_, --, --, 
   {{0x79805b12,0x6fb001ad,0xd2500014,0x00000000}},	//   minw, ंतमू, ھنس_, --, 
   {{0x7981cfbf,0x99dc00a2,0x88980375,0x96d000bc}},	//   linw, _erňe, _ובעי, _हलिउ, 
   {{0x0ca81a55,0x00000000,0x00000000,0x00000000}},	//   _कर्म, --, --, --, 
   {{0x98a47502,0xe7f40490,0x7981cfc0,0xd468188b}},	//   _salę_, ींचा_, ninw, _миле_, 
   {{0x8fa5cfc1,0x98a40210,0x00000000,0x00000000}},	//   даве, _palę_, --, --, 
   {{0x7981cfc2,0xcee80345,0x7d0003b2,0x00000000}},	//   hinw, ترسن_, ónsn, --, 
   {{0x1da80c2e,0x7981cfc3,0xd1740e76,0x23780240}},	// [33c80] कतंत, kinw, _жыны, ërje_, 
   {{0x7980045f,0xfce01d39,0x00000000,0x00000000}},	//   jinw, вофо, --, --, 
   {{0x7981cfc4,0xdb08007b,0xb4a866c0,0x00000000}},	//   dinw, _sheá, _खरो_, --, 
   {{0x61e800a8,0x2004219b,0x4aa80137,0x00000000}},	//   ţele, álie_, окен_, --, 
   {{0x7981cfc5,0xddcc03b9,0x00000000,0x00000000}},	//   finw, myaş, --, --, 
   {{0x645c03cd,0x7981cfc6,0x98f400d1,0x3eac0112}},	//   ørik, ginw, ىغىچ, ügte_, 
   {{0x6d5dcfc7,0xbdd80561,0x2560004e,0x670400fb}},	//   _iora, _trèc, _mòlt_, еүеб, 
   {{0x6d5c7912,0x37a405f5,0x39400139,0xc5f800d8}},	//   _hora, мтын_, енәг, оѓо_, 
   {{0x6d5dcfc8,0x4ab0012c,0x798003ac,0x00000000}},	//   _kora, _जरिव, binw, --, 
   {{0x6d5dcfc9,0x79800163,0x6d5800c5,0x64540640}},	//   _jora, cinw, övah, евођ, 
   {{0x69c9cfca,0x088801d5,0x0834030d,0x00000000}},	//   _iide, _بناً_, _юхая, --, 
   {{0x88e4000e,0x6d5dcfcb,0xddcc0276,0x4ab05096}},	//   _নাটক, _lora, nzaţ, _जराव, 
   {{0x69c9cfcc,0x6d5dcfcd,0xf64c6ea9,0x32c80022}},	//   _kide, _oora, _نئو_, дыро_, 
   {{0x6d5dcfce,0x69c9cfcf,0x2294063f,0x00000000}},	//   _nora, _jide, ụko_, --, 
   {{0x6b8003ac,0xb590030d,0x00000000,0x00000000}},	//   _ommg, _шишш, --, --, 
   {{0x69c9cfd0,0x6d5dcfd1,0x79800107,0x69dc0010}},	//   _lide, _aora, zinw, _čren, 
   {{0x6d5dcfd2,0x69c9b95b,0x7981cfd3,0xfeb9cfd4}},	// [33c90] _bora, _oide, yinw, زارت_, 
   {{0x61edcfd5,0xbdd84079,0x79808478,0x5bb81a3e}},	//   _iwal, _crèa, xinw, ेद्व, 
   {{0x61ec1682,0xad240131,0x443c0208,0x798002d0}},	//   _hwal, ئىمى, nvt_, vinw, 
   {{0x6d5dcfd6,0x443d38fb,0x69c9cfd7,0x7981cfd8}},	//   _eora, ivt_, _aide, winw, 
   {{0x6d5d20a1,0x69c8152d,0x61ec0831,0xba291b48}},	//   _fora, _bide, _jwal, تسام_, 
   {{0x6d5dcfd9,0x61edcfda,0x69c9cfdb,0x6b800036}},	//   _gora, _mwal, _cide, _emmg, 
   {{0x69c8d7a3,0x6568020c,0x3158008f,0xac1800f7}},	//   _dide, dkdh, ויגן_, _оору_, 
   {{0x443c0998,0xde70001f,0x7981cfdc,0x4a5004b4}},	//   dvt_, _ለመንግ, sinw, ткәс, 
   {{0x69c9cfdd,0x61edcfde,0x6d5dcfdf,0x00000000}},	//   _fide, _nwal, _yora, --, 
   {{0x69c9cfe0,0x6d5dcfe1,0xddcc0ac1,0x798000f1}},	//   _gide, _xora, zyaş, qinw, 
   {{0x809c06bc,0x6d588234,0x00000000,0x00000000}},	//   _खुले, övai, --, --, 
   {{0x61edcfe2,0x256005d5,0x6b7c0421,0x69c9cfe3}},	//   _bwal, _sòlt_, tōgi, _zide, 
   {{0x998c0427,0x69c88728,0xc7b005d0,0x6d4802d2}},	//   _mrež_, _yide, _עבד_, _ódag, 
   {{0x61ec631d,0x69c807a9,0xea9c00a2,0x7d001d0e}},	//   _dwal, _xide, _ýöňe_, ónsl, 
   {{0x61edcfe4,0x6d5dcfe5,0x56840023,0xd468009d}},	//   _ewal, _rora, _ክትኣቱ_, _хийе_, 
   {{0x6d5dcfe6,0x25600ba1,0x8fa4030d,0x95980092}},	//   _sora, _fòls_, хабе, ገዶችን_, 
   {{0x6d5dcfe7,0x61edcfe8,0x5c40001f,0xc2b001ee}},	// [33ca0] _pora, _gwal, _የሚገር, _бөрш, 
   {{0x6d5dcfe9,0x00000000,0x00000000,0x00000000}},	//   _qora, --, --, --, 
   {{0x61edcfea,0x6d5dcfeb,0x3ab00184,0x0fc4014b}},	//   _zwal, _vora, ғәтт, _пйон, 
   {{0x69c87eb1,0xbdd81e54,0x6d5dcfec,0x200401fa}},	//   _side, _irèn, _wora, šlic_, 
   {{0x6d5dcfed,0x69c86775,0xbdd801ab,0x00000000}},	//   _tora, _pide, _trèa, --, 
   {{0x443c022c,0x69c80548,0x6d5c0393,0x00000000}},	//   yvt_, _qide, _uora, --, 
   {{0xc7c5cfee,0x8b94fd42,0x00000000,0x00000000}},	//   нсии, _зрач, --, --, 
   {{0x69c93722,0xbeb81bce,0x00000000,0x00000000}},	//   _wide, _mbën, --, --, 
   {{0x69c94abb,0x6d400134,0x25086103,0xdb1401e1}},	//   _tide, _ɔman, وردی_, _èbák, 
   {{0x69c9cfef,0x61eca5e6,0x767006a6,0x443c0208}},	//   _uide, _rwal, ульф, tvt_, 
   {{0xddcc2375,0x256067c1,0x61edcff0,0x65680200}},	//   izaš, _sòls_, _swal, rkdh, 
   {{0x443d113c,0x25600ba1,0x61ec02e2,0xe3b80139}},	//   rvt_, _pòls_, _pwal, ktıe_, 
   {{0x61ec01e2,0xbdd833a2,0x2ba8000d,0x98f40051}},	//   _qwal, _arèn, _छीछा, _mỏn, 
   {{0x61ec57cb,0xbdd80036,0x25601497,0x443d4647}},	//   _vwal, _brèn, _vòls_, pvt_, 
   {{0xbdd800f2,0xdfd400c7,0x5dc80150,0x99dc01ef}},	//   _crèn, тобы, _ﺒﺎﻨﺴ, _mrňa, 
   {{0x61edcff1,0xbdd8020c,0x33080150,0x3434007b}},	//   _twal, _drèn, _كيىپ_, _أسود_, 
   {{0x61edcff2,0xa3e4000d,0x00000000,0x00000000}},	// [33cb0] _uwal, _पढ़त_, --, --, 
   {{0xacf80139,0x00000000,0x00000000,0x00000000}},	//   енфу_, --, --, --, 
   {{0x5f94035b,0x98f40051,0x317c011a,0x00000000}},	//   _аинт, _bỏn, _מאזד, --, 
   {{0xa9a4515c,0xead800d4,0x00000000,0x00000000}},	//   ۇمنى, емці_, --, --, 
   {{0xe9d89d2c,0x72ec008f,0x6c8403e6,0x997408ca}},	//   екі_, פֿאַ, پلۆم, кукш, 
   {{0xfd2003e6,0xceb4013d,0xdd9400cf,0x00000000}},	//   _حوسێ, _рәс_, _рагы, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7d040248,0x279400ee,0x00000000,0x00000000}},	//   _férà, лшыр, --, --, 
   {{0x645dcff3,0x0ba40124,0x00000000,0x00000000}},	//   ärin, _рырҭ, --, --, 
   {{0x056000fb,0x662400ae,0x00000000,0x00000000}},	//   ивын, اريك, --, --, 
   {{0x938800c7,0x00000000,0x00000000,0x00000000}},	//   ҧсҭа_, --, --, --, 
   {{0xff5c00e4,0x1cc40327,0xc7d400d9,0x00000000}},	//   _noî_, _ཌུན_, _סוני_, --, 
   {{0xbdd8020c,0xd2f0447d,0x23780240,0x87780a7c}},	//   _srèn, _अजीब_, ërja_, _קאני, 
   {{0x3ce80034,0x46100244,0x00000000,0x00000000}},	//   टरों_, _ئوور, --, --, 
   {{0x10a4e1ad,0xf61400b5,0x7f90031c,0x69dc00d7}},	//   тивн, _hユ_, għqo, _črem, 
   {{0x53a416c0,0x2005cff4,0x72a400d1,0x00000000}},	//   _шайб, ália_, _مەجن, --, 
   {{0x09e402f5,0x636c000f,0x527429a1,0x9194399f}},	// [33cc0] _নিভা, _mûnl, _шуку, _ајнш, 
   {{0xd1b8516c,0xdeac0198,0x8c440026,0x00000000}},	//   _تابا_, ndaƙ, кезе, --, 
   {{0xcee802bf,0x00000000,0x00000000,0x00000000}},	//   _одне_, --, --, --, 
   {{0x8e840064,0x00000000,0x00000000,0x00000000}},	//   _агме, --, --, --, 
   {{0x2fc1cff5,0x82d4008f,0x8e7400d8,0xaa440022}},	//   mmig_, דונג_, _рунч, ыҵал, 
   {{0x2fc1cff6,0x39100212,0xc2780375,0x23b803df}},	//   lmig_, имір, ורני, méje_, 
   {{0xdeac0198,0x6d58005b,0x00000000,0x00000000}},	//   ddaƙ, övau, --, --, 
   {{0x46680f1a,0x636c045f,0x89d86ea9,0x2fc000a3}},	//   дром_, _rûno, _يوزر_, nmig_, 
   {{0x35f1ca61,0x98a400a2,0x2fc00549,0xa4d4003b}},	//   апыр, _dolı_, imig_, лопі, 
   {{0x2fc1cff7,0x386402d2,0x645c01f4,0x00000000}},	//   hmig_, bynr_, ärio, --, 
   {{0x25080244,0x59740006,0x00000000,0x00000000}},	//   ورگی_, _сыту, --, --, 
   {{0x68f8a075,0x06840daf,0xc6a40116,0xf75000ec}},	//   lavd, _иген, _ирли, _پنهج, 
   {{0x7d0008ce,0x00000000,0x00000000,0x00000000}},	//   ónsk, --, --, --, 
   {{0x68f9cff8,0xe2980022,0xd6c401d5,0x00000000}},	//   navd, даҭ_, _сичқ, --, 
   {{0x998c013a,0x00000000,0x00000000,0x00000000}},	//   _jseš_, --, --, --, 
   {{0x2fc0356c,0x645c013c,0x245400ec,0x00000000}},	//   gmig_, øriu, _لنڪس, --, 
   {{0xbdd8067c,0x68f8b0e8,0x998c031c,0x6e200037}},	// [33cd0] _grèl, kavd, _preż_, _ämbl, 
   {{0xdcb001fb,0x61fc007c,0x00000000,0x00000000}},	//   _ở_, mssl, --, --, 
   {{0xff5c00c7,0xdd9401e0,0x2130030a,0x00000000}},	//   _toî_, _ҡамы, mezh_, --, 
   {{0x2011cff9,0x213003bd,0x00000000,0x00000000}},	//   muzi_, lezh_, --, --, 
   {{0x2011cffa,0x636c000f,0xbf0c2ba2,0x99d400ec}},	//   luzi_, _rûnl, िलीन_, اڪرا, 
   {{0x68f80158,0x61fc04e6,0x2131cffb,0x98a4013d}},	//   gavd, issl, nezh_, _solı_, 
   {{0xb8d816f0,0x20109858,0xbdd8020c,0x645d9dae}},	//   _घर_, nuzi_, _mrèm, äril, 
   {{0x80bc015b,0x98a40139,0x00000000,0x00000000}},	//   ্ডপ্, _qolı_, --, --, 
   {{0xab859623,0xadc40241,0xd4f40024,0x1a9400c0}},	//   _турк, _arẹs, ляны, _сааў, 
   {{0x2011cffc,0x7d000174,0x91e000cc,0x00000000}},	//   kuzi_, ónsh, _বিলখ, --, 
   {{0x61fc1021,0x2010249d,0xd388d3a6,0x21300156}},	//   essl, juzi_, ейне_, dezh_, 
   {{0x20106fe4,0xe7852159,0x09e40011,0x00000000}},	//   duzi_, _кучо, _নিতা, --, 
   {{0x2004148b,0x99dc01ef,0x42200395,0x00000000}},	//   álin_, _mrňo, бдяв, --, 
   {{0x213007e4,0x20102f99,0xbdd9cffd,0xd1740220}},	//   gezh_, fuzi_, _crèm, уымы, 
   {{0x2011cffe,0x645dcfff,0x43700451,0xda0c0037}},	//   guzi_, ørit, _گهير, _समझत_, 
   {{0xabcc00d1,0x00000000,0x00000000,0x00000000}},	//   _ﺑﺎﻫﺎ, --, --, --, 
   {{0x21300156,0x00000000,0x00000000,0x00000000}},	// [33ce0] bezh_, --, --, --, 
   {{0x2011d000,0xcb08004b,0xda0c0073,0x2fc00142}},	//   buzi_, ځيان_, _समजत_, smig_, 
   {{0x201001b2,0xa1840220,0x68f803cd,0xe1880451}},	//   cuzi_, _тұра_, vavd, _جئين_, 
   {{0xbeb80de2,0x00000000,0x00000000,0x00000000}},	//   _mbëj, --, --, --, 
   {{0xe9181fe2,0xe8cc00dc,0xe985d001,0xc9840120}},	//   волі_, ाश्च, ақан, луки, 
   {{0xc0c0001f,0xc9f40150,0x00000000,0x00000000}},	//   ጻጸም_, _ەساع, --, --, 
   {{0x68f9d002,0xa34c00c0,0x2d1001f9,0x3868013a}},	//   ravd, _rėžė_, ालील_, _čirá_, 
   {{0x7c900597,0x68f81f53,0x645dd003,0x61fdd004}},	//   _الفص, savd, ärim, yssl, 
   {{0x21300dd4,0x2011d005,0xc58802e8,0xfad4011a}},	//   yezh_, zuzi_, ещне_, _תומך_, 
   {{0x20102dab,0x76b40ce8,0x427c0023,0x61fc007c}},	//   yuzi_, ылыр_, _ብሩኻት_, vssl, 
   {{0x21300dd4,0x635444c9,0x320001a9,0x44280109}},	//   vezh_, авну, _aviy_, ïb_, 
   {{0xaca402e3,0x2011d006,0x61fc0373,0x21300489}},	//   _arịr, vuzi_, tssl, wezh_, 
   {{0x2011d007,0xbdd81497,0x213005c7,0x00000000}},	//   wuzi_, _prèm, tezh_, --, 
   {{0x2011d008,0x61e80276,0xdb0801ab,0x21300489}},	//   tuzi_, ţelo, _dheù, uezh_, 
   {{0x213007e4,0xbdd802bd,0x00000000,0x00000000}},	//   rezh_, _vrèm, --, --, 
   {{0x201001aa,0xc1003a49,0x61fc02d0,0xd04c06be}},	//   ruzi_, шүүл, pssl, ncbə, 
   {{0x2011d009,0xbdd8067c,0xdea087a9,0xae0c02ab}},	// [33cf0] suzi_, _trèm, زیسی, िंगन_, 
   {{0x201000ca,0x41000131,0xb27401af,0x6fd00150}},	//   puzi_, _دېسك, _ылыш, _ﻛﯟﺍﺷ, 
   {{0xbdd8020c,0x2010014b,0x6f2801e7,0xdedc0240}},	//   _krèk, quzi_, íscí, ሕጺኑ_, 
   {{0x2249d00a,0x6d5903bd,0xdcf40205,0x00000000}},	//   _krak_, övar, ıbın, --, 
   {{0x998006c8,0x19581771,0x645c01f4,0x00000000}},	//   ōhō_, кады_, ärij, --, 
   {{0x224807f5,0xd94455ee,0x00000000,0x00000000}},	//   _mrak_, реки, --, --, 
   {{0x9f400109,0x2248020c,0xa3b4033f,0x00000000}},	//   _athé_, _lrak_, झता_, --, 
   {{0x636c002d,0x163800c6,0x224800a2,0x06e40395}},	//   _dûnk, نسخة_, _orak_, амък_, 
   {{0x65f805f5,0x00000000,0x00000000,0x00000000}},	//   лээр_, --, --, --, 
   {{0xbdd801e1,0xf99164e5,0x32040030,0x1424283c}},	//   _arèk, _ابر_, ámym_, адом, 
   {{0x2249d00b,0xf1c80316,0x200402fb,0x5fb4a4cd}},	//   _arak_, ntář_, álil_, ंताल, 
   {{0x2249d00c,0x53a4d4fb,0x25bc0175,0x95b40124}},	//   _brak_, рамб, _ehvl_, ырқә, 
   {{0x00b800d1,0x00000000,0x00000000,0x00000000}},	//   ﻠﯩﺸﺘ, --, --, --, 
   {{0x224843d8,0xd0092c0d,0x0eec5325,0xe2806518}},	//   _drak_, кеге_, जर्स_, яғын, 
   {{0x2249d00d,0x00000000,0x00000000,0x00000000}},	//   _erak_, --, --, --, 
   {{0x68400316,0x2248031c,0xff040276,0xe3b80342}},	//   ládá, _frak_, иеск_, ltın_, 
   {{0x4338008f,0x2248003e,0x4174075e,0x00000000}},	// [33d00] _יעקב, _grak_, _چاپس, --, 
   {{0x01f8008f,0xe3b800fd,0x4175d00e,0x23b825d9}},	//   _שפיל, ntın_, _ناپس, méja_, 
   {{0x22485667,0xfce001c6,0x4c840798,0x00000000}},	//   _zrak_, цохо, јлев, --, 
   {{0x4a4401e0,0xef942f4d,0x6080001f,0x35800023}},	//   инев, _ایرد, ረጋጋት_, _ክጥቀስ_, 
   {{0xe3b80ac4,0xaca40cad,0xca74010b,0x684001ef}},	//   ktın_, _irọr, шужы, kádá, 
   {{0x99f400d6,0x645cb6a5,0x8c440026,0xb8d00131}},	//   сяці, ärik, _кеге, يتىش, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb9140521,0x2ee0010a,0xf7440131,0x7d001d0e}},	//   _kedụ_, ncif_, للىي_, ónsv, 
   {{0xae0c03f3,0x49c9d00f,0x00b8005e,0x4aa85022}},	//   िंटन_, _алан_, ﻠﯩﺴﺘ, _شارپ_, 
   {{0x224801c4,0xd6d8012d,0x00000000,0x00000000}},	//   _rrak_, rdła_, --, --, 
   {{0xe2f8fc53,0xc79400f7,0x22480055,0x5f0800cd}},	//   лені_, _крды, _srak_, िणम्_, 
   {{0x22480438,0xe3b80213,0x363000ec,0x04f40154}},	//   _prak_, atın_, _ڀروس, চলের_, 
   {{0x2ee00077,0x17080214,0x25bc004d,0x00000000}},	//   dcif_, _صفوی_, _thvl_, --, 
   {{0x636c000f,0x200407f5,0x22485794,0x00000000}},	//   _mûni, šlim_, _vrak_, --, 
   {{0x22484872,0x3f840261,0x291800b0,0x00000000}},	//   _wrak_, аѓаа, _örau_, --, 
   {{0x2249d010,0xbdd8067c,0xc2e4036b,0x23b80c6a}},	//   _trak_, _hrèi, _тўки, béja_, 
   {{0x63add011,0x3eac3f87,0x2249d012,0x001c001f}},	// [33d10] _ikan, ægt_, _urak_, ስቲያኖ, 
   {{0xdcf8c8dd,0x442c0ac5,0x5dc802dd,0xad240116}},	//   افات_, _kpf_, _ﺒﺎﻷﺴ, يىقى, 
   {{0x442dd013,0x9f341fe2,0x63ac2252,0xd68801e4}},	//   _jpf_, _лені, _kkan, ndeϲ, 
   {{0x57e9d014,0x442c8d02,0x72440f01,0xe9a8221d}},	//   қдим_, _mpf_, _اپیل, یدون_, 
   {{0x63add015,0xe3b803be,0xf2d400c8,0x442cbe07}},	//   _mkan, ytın_, קעס_, _lpf_, 
   {{0x63ac783f,0x442c0332,0xe3b80213,0xada40006}},	//   _lkan, _opf_, xtın_, _маўл, 
   {{0x63acab88,0x442dd016,0xac94009d,0x7d001d0e}},	//   _okan, _npf_, _дарш, ónsu, 
   {{0x09e400bd,0x69dc994e,0xde540020,0x9aa401e2}},	//   _নিরা, _črev, _ከመንግ, _همزو, 
   {{0xddcc0bc9,0x442dd017,0xe3b80790,0x7f90031c}},	//   pxań, _apf_, ttın_, għqi, 
   {{0xbdd800db,0x068012db,0x0320009d,0xe93800cf}},	//   _crèi, ягын, үдэн, _ۅسۅت_, 
   {{0x442dd018,0xe3b87b54,0x6841bd91,0x53c86b1a}},	//   _cpf_, rtın_, rádá, лгом_, 
   {{0xdecc1954,0x93580022,0x00000000,0x00000000}},	//   ጥመን_, уроу_, --, --, 
   {{0xc7a40014,0x154409a5,0xe3b80342,0x00000000}},	//   _أنی, _гелм, ptın_, --, 
   {{0x63add019,0x442dd01a,0x28cc0490,0x29180267}},	//   _ekan, _fpf_, ाशचि, _örat_, 
   {{0x63ac1132,0xbdd8020c,0x442dd01b,0x940401e2}},	//   _fkan, _krèw, _gpf_, _اوبه, 
   {{0x43901b6b,0x63ac020c,0x63a401e4,0x03a002e8}},	//   _најс, _gkan, _ĉing, _нищо, 
   {{0xed64035b,0xc6d8010f,0xcd04004e,0x00000000}},	// [33d20] онаҿ, אַבר, йпай, --, 
   {{0x442c0bf2,0x09e40eac,0xd1b8030c,0x82a0030d}},	//   _ypf_, _নিলা, _حابا_, _хаьж, 
   {{0x0c241d1c,0xe2a83463,0x8fa5ae02,0x442c010a}},	//   смен, _ماین_, _гане, _xpf_, 
   {{0x645c023a,0x76480142,0xcb14007b,0x00000000}},	//   ärii, _orgy, إذاع, --, 
   {{0xaa580063,0xe5180037,0x00000000,0x00000000}},	//   рилу_, _दालि_, --, --, 
   {{0x7c309936,0x2d8dd01c,0x2b40488c,0x6e25d01d}},	//   ñerí, _öde_, žic_, mtib, 
   {{0x6e25d01e,0x7649d01f,0xbdd8020c,0x00000000}},	//   ltib, _argy, _brèw, --, 
   {{0x442dd020,0xbdd80066,0xdb4c03e6,0xa2a801f9}},	//   _rpf_, _crèw, _لێم_, _घडल्, 
   {{0x6e240de4,0xbdd8068c,0x63ac031c,0xdb4c02f2}},	//   ntib, _prèi, _rkan, _جێن_, 
   {{0x442dd021,0x6e25d022,0x2918003b,0x20041de4}},	//   _ppf_, itib, _øra_, álik_, 
   {{0x9f44025a,0x6e2405b1,0x672000af,0x7649d023}},	//   ëlë_, htib, _यापक_, _ergy, 
   {{0x6e25d024,0x63880aac,0x442c0208,0x00000000}},	//   ktib, рроҳ_, _vpf_, --, 
   {{0xa5f815a0,0xbdd80ba1,0xb6a000c7,0x442c045a}},	//   _телу_, _trèi, _еицл, _wpf_, 
   {{0x442c0175,0x2dcc0150,0x00000000,0x00000000}},	//   _tpf_, _ﺒﺎﻻﻤ, --, --, 
   {{0x34901b74,0x442c00cf,0x6e240393,0x241802dd}},	//   _нашр, _upf_, etib, _тойы_, 
   {{0x63ac2e95,0x44cc03be,0x636c000f,0x764848a2}},	//   _ukan, mə_, _rûnw, _yrgy, 
   {{0x44cc03be,0x6e2422d0,0xe3b80790,0x6448072b}},	// [33d30] lə_, gtib, ntım_, lvdi, 
   {{0x69dc007d,0x8ca800dc,0xd6d8012d,0xacf8009d}},	//   _पढ़ी, _जुहो, ydło_, йнуу_, 
   {{0x44cc11a9,0xfeb804d3,0x6e25d025,0x9c3801af}},	//   nə_, _ڕاست_, atib, рпет_, 
   {{0xe3b803ee,0x2dcc01ec,0x7778036e,0x00000000}},	//   ktım_, _ﺒﺎﻹﻤ, xhux, --, 
   {{0x6e25d026,0x2bb80597,0x7d00066a,0x657803b2}},	//   ctib, حالة_, ónss, _olvh, 
   {{0xbdd87ea5,0x69dc0010,0x1868bf29,0x44cc03e3}},	//   _brèv, _čret, иали_, kə_, 
   {{0xbdd806af,0x00000000,0x00000000,0x00000000}},	//   _crèv, --, --, --, 
   {{0x44cc0cc1,0x65780158,0xd6d8012d,0x00000000}},	//   də_, _alvh, rdło_, --, 
   {{0x96b8242f,0x2004041a,0x79240124,0x7af9d027}},	//   шуку_, šlih_, _гьеж, _ieut, 
   {{0x7af809f0,0x777802b9,0x55884b4d,0xdecc0023}},	//   _heut, shux, рбом_, ጥመና_, 
   {{0xbdd9d028,0x7af8920d,0xddcc0227,0x248002a8}},	//   _grèv, _keut, pxaņ, _ƙima_, 
   {{0x61e80084,0x3f880fac,0x6e2482d7,0xeab001d3}},	//   ̭ele, _nmcu_, ytib, _آٹے_, 
   {{0x320403c6,0xf770168d,0x6e24003a,0x7648010e}},	//   émy_, _واڵ_, xtib, _urgy, 
   {{0x7af9d029,0x3f880ea0,0x63a401e4,0x44cc03b9}},	//   _leut, _amcu_, _ĉine, bə_, 
   {{0xb1484887,0xdb08010e,0xc950011a,0x44cc03e3}},	//   لیکم_, _sheý, ומם_, cə_, 
   {{0x6e25d02a,0xb8f80156,0x7af9d02b,0x3a3c00a2}},	//   ttib, _ཡཔ_, _neut, _osup_, 
   {{0x645c3110,0x4d641ff1,0x10d40153,0x00000000}},	// [33d40] äriv, окав, _мінё, --, 
   {{0xd05c016b,0x3f8801fa,0x20100b4b,0x8cb41b88}},	//   _bepɔ, _emcu_, brzi_, осеч, 
   {{0x6e25d02c,0x7af9d02d,0x3a3c1dd4,0x0b4462bd}},	//   stib, _beut, _asup_, жнен, 
   {{0xaee400cd,0x92bc00fe,0x0a6801d5,0x7d0003b2}},	//   _kuṭu, েডী_, ирли_, ónsr, 
   {{0x7af9d02e,0xbdd8067c,0x44cc03be,0x8a38034b}},	//   _deut, _brèu, zə_, ряет_, 
   {{0x44cc0cc1,0xbdd80228,0x636c000f,0xdb080332}},	//   yə_, _prèv, _hûnt, _bheó, 
   {{0x7af9d02f,0x8b9400f0,0xd90d0d39,0xf98400db}},	//   _feut, _драч, طین_, تنوي_, 
   {{0x44cc0cc1,0xc7641e0e,0x7af80c6a,0x636c000f}},	//   və_, تاتى, _geut, _jûnt, 
   {{0xfcf0a38c,0x636c000f,0x6595d030,0xf1bc01bc}},	//   _ውስጥ_, _mûnt, запу, ोगान, 
   {{0xbdd9d031,0x7af801f7,0x44cc00ac,0x35b01ac1}},	//   _grèu, _zeut, tə_, мбыр, 
   {{0x7af98be8,0xe3b85775,0xf4800395,0x00000000}},	//   _yeut, stım_, дуян, --, 
   {{0x44cc03be,0x9f5000dd,0xbdd807b0,0xe3b9c315}},	//   rə_, sszú_, _krèt, ptım_, 
   {{0x44cc00ac,0xe3b8294f,0x00000000,0x00000000}},	//   sə_, ltık_, --, --, 
   {{0x291dd032,0xbeb824ba,0x2b440204,0x04885ac4}},	//   ngva_, _mbët, _lamc_, _پختو_, 
   {{0x44cc03be,0x636dd033,0xdb0800a3,0xa6bc03d4}},	//   qə_, _bûnt, _mheò, _উলিয়, 
   {{0x9ed846e0,0xa2f40108,0x00000000,0x00000000}},	//   смат_, _эпич, --, --, 
   {{0x239c01e4,0x00000000,0x00000000,0x00000000}},	// [33d50] lĉjo_, --, --, --, 
   {{0x3a3c020b,0x7af9d034,0xe3b8247e,0xbc8c0023}},	//   _rsup_, _seut, ktık_, _ጀጋኑና_, 
   {{0x7af9d035,0xe928025c,0x3a3c0067,0x239c010f}},	//   _peut, _ལྡེབ_, _ssup_, nĉjo_, 
   {{0xbdd87704,0x33200a05,0x25ac013a,0x00000000}},	//   _brèt, _xcix_, hodl_, --, 
   {{0xdb094ffd,0x636c002d,0x2b4479d7,0x7af80810}},	//   _bheò, _hûns, _damc_, _veut, 
   {{0xdb080e89,0xd7b4013f,0x7af9d036,0x4dd80375}},	//   _cheò, _ɔbεt, _weut, _לחשו, 
   {{0x7af9d037,0xbdd927c8,0x636c000f,0xdb0808c2}},	//   _teut, _erèt, _jûns, _dheò, 
   {{0xabcc04a2,0x3a3c0280,0x16641214,0x309c011a}},	//   _ﺑﺎﻳﺎ, _tsup_, звим, ישומ, 
   {{0xbdd8007f,0xdb0808c2,0x3a3c0098,0x25ac0042}},	//   _irès, _fheò, _usup_, fodl_, 
   {{0xdb09d038,0x270c0153,0x861000d1,0xc5ec00f1}},	//   _gheò, vėnų_, رۋىچ, اړن_, 
   {{0x81b00154,0x00000000,0x00000000,0x00000000}},	//   য়দা_, --, --, --, 
   {{0x2120003e,0xddcc08a4,0x363000aa,0x57240150}},	//   _achh_, jzaž, _يواځ, _ءىشك, 
   {{0xbeb8044e,0x636c045f,0x0595cce1,0x1dbc412f}},	//   _mbës, _rûnt, _کانگ, ्गात, 
   {{0x636c000f,0x270c0024,0x1544004e,0x92c05656}},	//   _bûns, rėnų_, _хекм, _ığın, 
   {{0xaca401f2,0x645c6583,0x20b40108,0x98a40064}},	//   _kpụr, ärit, дётс, _valė_, 
   {{0x636c0b21,0xdb080022,0x270c0064,0x00000000}},	//   _dûns, _oheñ, pėnų_, --, 
   {{0x3f640640,0x9f980008,0x291c03b2,0x55f800cc}},	// [33d60] чито_, ráðs_, ygva_, _আমুক_, 
   {{0x645c01e3,0xbdd915a0,0x636c000f,0x7d000162}},	//   årig, _arès, _fûns, ónsp, 
   {{0xbdd8067c,0x6ec0012c,0x2368022e,0x80d8011a}},	//   _brès, लेजु, _yoaj_, _לחיז, 
   {{0xbdd80ba1,0x8fa5d039,0xdb080e89,0x90d4009f}},	//   _crès, _хаме, _sheò, _وآگا, 
   {{0xdb080dd4,0x7c383421,0x2b440208,0x0ab4007b}},	//   _cheñ, _ćure, _vamc_, أحاد, 
   {{0xe3b85775,0x3ab03c1a,0x05b8000d,0x8b6403c7}},	//   ttık_, хәст, _उठइब, _کاسم, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbb41d03a,0xeb5401ec,0xbdd9d03b,0xd5ac00f1}},	//   _песк, _تىرگ, _trèt, یځو_, 
   {{0xd90c5662,0x09e4045e,0xe3b8510c,0xf6200640}},	//   _چیه_, _নিকা, stık_, едњо, 
   {{0xd90c168d,0xe3b8510c,0xba1400ae,0x00000000}},	//   _نیه_, ptık_, _ريما_, --, 
   {{0x290c08e5,0xb600005f,0x9f580200,0x84500137}},	//   _idda_, ēšam, ëzës_, رىحچ, 
   {{0xbeb88302,0x636c002d,0x239c00df,0xa2940006}},	//   _mbër, _rûns, rĉjo_, дамі, 
   {{0x1cdc0327,0x6d80007c,0xe3b8004e,0x00000000}},	//   _ལྔའ_, _köad, йбү_, --, 
   {{0x645d5ce4,0x636c000f,0xd1e00092,0xf7c000d1}},	//   äris, _pûns, _ዞኖች_, ﺯﯨﻠﻪ, 
   {{0x9f400332,0x7d0400e5,0x30a515b5,0x00000000}},	//   _athá_, hérí, ертв, --, 
   {{0x290c04ba,0xe1f00451,0xbf0400cd,0x9df800d8}},	//   _ldda_, _لڳس_, षणेन_, жнат_, 
   {{0x9d546568,0x290dd03c,0x636c045f,0xaee400cd}},	// [33d70] وچست, _odda_, _wûns, _suṣu, 
   {{0x69dc238f,0xdc9800d4,0xfc30007b,0x00000000}},	//   _črep, овзі_, فحص_, --, 
   {{0xbdd9d03d,0x61ec022e,0x83e40150,0xac940454}},	//   _près, _htal, _ﺍﻟﺪﻳ, нафш, 
   {{0x290c32c2,0x443c0a40,0x61e8054e,0xab84117e}},	//   _adda_, iwt_, ţelu, нучк, 
   {{0xd94451e4,0x290c0334,0xbdd81f3f,0x2bcc033f}},	//   дели, _bdda_, _vrès, ़ग़ा, 
   {{0xbdd9d03e,0xeab00597,0x61ec696c,0xceb005d0}},	//   _frèr, دعم_, _mtal, _סים_, 
   {{0xa904cb3f,0x61ec409c,0x1cdc0135,0x9b95d03f}},	//   ربون, _ltal, _ལྔར_, _живц, 
   {{0x290dd040,0x61edd041,0x48c00022,0x5fac01f9}},	//   _edda_, _otal, тәуа, चविल, 
   {{0x61edd042,0xa3d00c2e,0x443c0221,0xe708bf4e}},	//   _ntal, वगन_, ewt_, ستين_, 
   {{0x443c0369,0x7bc91e9e,0x63a4008f,0xb4e40bae}},	//   fwt_, lmgu, _ĉina, बडे_, 
   {{0xd469d043,0x443c0369,0x636c002d,0x53a42309}},	//   цине_, gwt_, _rûnr, данб, 
   {{0x61ec0135,0xdecc1772,0x00000000,0x00000000}},	//   _btal, ባልን_, --, --, 
   {{0x61ec0175,0x645d3c91,0x00000000,0x00000000}},	//   _ctal, ärir, --, --, 
   {{0x61ec00ae,0x26c401e0,0x00000000,0x00000000}},	//   _dtal, _яғын_, --, --, 
   {{0x61edd044,0x54340b43,0xc0e02d57,0x00000000}},	//   _etal, _آرتر, тоск, --, 
   {{0x1fb5145b,0x59dc0316,0x8e740137,0xcee81cb8}},	//   есур, मदार, музч, ідзе_, 
   {{0xc2403db0,0x98a400cd,0x00000000,0x00000000}},	// [33d80] _анык, _balī_, --, --, 
   {{0x9e6400d1,0xf644065f,0x00000000,0x00000000}},	//   راقن, _یئ_, --, --, 
   {{0x77680472,0x2005d045,0xcb084cec,0x98a400ef}},	//   _oogx, álit_, قيان_, _dalī_, 
   {{0xbdd80066,0x7768009a,0x61ec0393,0x7c2001c3}},	//   _isèn, _nogx, _ytal, ànra, 
   {{0x6f05d046,0x61ec01b9,0xc9a800d8,0x00000000}},	//   maic, _xtal, овде_, --, 
   {{0x6f040876,0x27380016,0x00000000,0x00000000}},	//   laic, _ẩn_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6f040013,0x9518031c,0x00000000,0x00000000}},	//   naic, ཱུའི_, --, --, 
   {{0xf7f8013a,0x00000000,0x00000000,0x00000000}},	//   _čáře_, --, --, --, 
   {{0x6f05d047,0x290c01e6,0x61ec01b9,0xf8ac01d3}},	//   haic, _udda_, _rtal, اکے_, 
   {{0x443dd048,0x6f05d049,0x1cdc0135,0x24581cd0}},	//   uwt_, kaic, _ལྔས_, чань_, 
   {{0xb7d425aa,0x2cb803b2,0x443c0221,0x6f0400e4}},	//   _قولا_, _myrd_, rwt_, jaic, 
   {{0x6f05d04a,0x61ec022e,0xc6742824,0x069802f2}},	//   daic, _qtal, _تطاب, _بخات_, 
   {{0x6f0401ab,0x00000000,0x00000000,0x00000000}},	//   eaic, --, --, --, 
   {{0x7bc809a5,0x6f040e9e,0x9f34109a,0x00000000}},	//   ymgu, faic, неві, --, 
   {{0x61ec0a49,0x6f040e89,0x00000000,0x00000000}},	//   _ttal, gaic, --, --, 
   {{0x61edd04b,0x5d54ec43,0x3d241def,0xbdd80129}},	// [33d90] _utal, нкат, дьев, _crèp, 
   {{0x2004066d,0xffe40116,0xc05802bf,0x2cb81c2e}},	//   ális_, _оюмн, _дім_, _byrd_, 
   {{0x5b14db74,0x2e34001f,0x6f05d04c,0x301401c6}},	//   емет, _አያይዘ, baic, _идэр, 
   {{0x6f05168d,0x501805d0,0x00000000,0x00000000}},	//   caic, _צורו, --, --, 
   {{0x34b876f8,0x00000000,0x00000000,0x00000000}},	//   _उर्द, --, --, --, 
   {{0x9a8801d9,0x7bc8054e,0xa3d001f9,0x00000000}},	//   _ہنزٕ_, smgu, वगड_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x279400f7,0x67200158,0x00000000,0x00000000}},	//   кшыр, ggmj, --, --, 
   {{0x9f5000dd,0x15b800ee,0xba746ea9,0x95940d30}},	//   lszó_, зыны_, _غارت, ешні, 
   {{0x7768009a,0xaaa887ee,0x09e400fe,0x00000000}},	//   _wogx, _छुटक, _নিচা, --, 
   {{0x645dd04d,0x00000000,0x00000000,0x00000000}},	//   ärip, --, --, --, 
   {{0x79800455,0x00000000,0x00000000,0x00000000}},	//   lhnw, --, --, --, 
   {{0x5559d04e,0x6f05d04f,0xc62002f5,0x355401d9}},	//   _надя_, vaic, _বৈঠা_, _ٲستھ_, 
   {{0x6f0402a8,0xf780025c,0x00000000,0x00000000}},	//   waic, seħħ_, --, --, 
   {{0x6f040192,0xe4e400d6,0xd6c00183,0x00000000}},	//   taic, _річн, _উলিয, --, 
   {{0xbdd8068c,0x06c403d4,0x3f6408ca,0x10a40166}},	//   _prèp, _ষ্টি, нисо_, _җимн, 
   {{0x6f040876,0x7c38110c,0x1b0400cc,0x20040162}},	// [33da0] raic, _ćura, উলাই_, álir_, 
   {{0x6f040876,0x42c4008e,0xfce0011c,0x00000000}},	//   saic, _ягын_, гофо, --, 
   {{0x6f05d050,0x00000000,0x00000000,0x00000000}},	//   paic, --, --, --, 
   {{0x8a05d051,0xc0500302,0x60c051bb,0x15ac00d1}},	//   езде, _עזר_, ülme, ﻴﺎﺭﻩ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe89442cd,0xa9340046,0x2cb80042,0xfaa401e2}},	//   каль, текш, _tyrd_, رجنی, 
   {{0x27e001e4,0x5be40150,0xf7b400e5,0x00000000}},	//   ĉino_, _айсұ, کدوش_, --, 
   {{0x6bd405d9,0x0ba806ba,0x63a4010f,0x00000000}},	//   _شڪار, _رازى_, _ĉino, --, 
   {{0x6b8001d5,0xbb38010f,0x281405af,0x7f980166}},	//   _ilmg, _צעמי, روکس, läqä, 
   {{0x363016ac,0xa4d4cea6,0x00000000,0x00000000}},	//   اريس, копі, --, --, 
   {{0xbdd8007f,0x6d48032e,0x00000000,0x00000000}},	//   _asèl, _ódau, --, --, 
   {{0xc6a40120,0x00000000,0x00000000,0x00000000}},	//   _прли, --, --, --, 
   {{0xac740020,0xf64c0451,0x6d5c02d0,0xc1a42377}},	//   _በዚህም_, _هئو_, _onra, ејви, 
   {{0x65955916,0xb5cc030d,0x00000000,0x00000000}},	//   _шалу, _гιул, --, --, 
   {{0xdecc1540,0x5f9403b7,0xd34404d3,0x3ebc08a4}},	//   ባውን_, вивт, رییه_, _šut_, 
   {{0x7f980139,0x00000000,0x00000000,0x00000000}},	//   däqä, --, --, --, 
   {{0x02a001f2,0xceb404a9,0xa3e4230e,0x00000000}},	// [33db0] _kpọọ, вәр_, _भूत_, --, 
   {{0x63bc032e,0x9f5001ed,0x6b8001e3,0xf7c000d1}},	//   llsn, tszó_, _almg, ﺯﯨﻴﻪ, 
   {{0x6d5c010a,0x29c001ab,0xeda400db,0x00000000}},	//   _dnra, tòan_, ушто, --, 
   {{0x3f641c31,0x6d5dd052,0xbbc8085c,0x69c9d053}},	//   _чтоб, _enra, िषेक, _ahde, 
   {{0x3ebc01f1,0x63a40115,0x9f5001d3,0x00000000}},	//   _áut_, _ĉinl, sszó_, --, 
   {{0x79800369,0x63bc009a,0x6b80007c,0xdeb001ec}},	//   uhnw, hlsn, _elmg, _бұғы, 
   {{0xd7c838a3,0x69c80051,0x00000000,0x00000000}},	//   ووته_, _dhde, --, --, 
   {{0x06a8015b,0x86f000ec,0x9734013d,0x00000000}},	//   খেছি, لڻها, тэкч, --, 
   {{0x63bc011c,0x88b003d4,0x00000000,0x00000000}},	//   dlsn, টেলক, --, --, 
   {{0x986401ed,0x13e8034b,0x65680200,0x2dcc0220}},	//   _لیتے_, ммой_, gjdh, _ﺒﺎﻟﻤ, 
   {{0x7c280166,0x00000000,0x00000000,0x00000000}},	//   _çorğ, --, --, --, 
   {{0x91e44294,0x63bdd054,0x69c80200,0x00000000}},	//   коме, glsn, _zhde, --, 
   {{0x69c80664,0x7bd80194,0x91640051,0x43900006}},	//   _yhde, _miuu, _hổ_, раўс, 
   {{0x7bd80194,0x57d00073,0x00000000,0x00000000}},	//   _liuu, _हळुह, --, --, 
   {{0x09040154,0x00000000,0x00000000,0x00000000}},	//   _রামু_, --, --, --, 
   {{0x6d5c00a3,0xb2b4008e,0x91640051,0x00000000}},	//   _snra, _бәгъ, _mổ_, --, 
   {{0x4d4804b4,0x00000000,0x00000000,0x00000000}},	// [33dc0] мпан_, --, --, --, 
   {{0x7bd80268,0xd0940139,0x00000000,0x00000000}},	//   _aiuu, _ашмы, --, --, 
   {{0x4fa4035b,0x57d00490,0xcb680640,0x0c25d055}},	//   _аинв, _हळूह, маже_, тмен, 
   {{0xe3b862c7,0x3200007f,0x00000000,0x00000000}},	//   ltır_, _kwiy_, --, --, 
   {{0xdb1400dd,0x7bd9d056,0xc984023b,0xbea00064}},	//   óbál, _diuu, куки, _ваяк, 
   {{0x6d5c127b,0x91640208,0xe3b80205,0x00000000}},	//   _unra, _bổ_, ntır_, --, 
   {{0x26c002d5,0x98a40006,0xcfb80eac,0x9164004d}},	//   _šio_, _dalį_, ংগঠন, _cổ_, 
   {{0x7ae8074d,0xddcc0784,0xca7400c7,0xe3b80790}},	//   ccgt, myaš, _иузы, htır_, 
   {{0xe3b80ab7,0x09e4ba59,0x49b89f21,0x7be400de}},	//   ktır_, _розн, _قائد_, ēruš, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa3d5d057,0xddcc0113,0x98340014,0x86c0004b}},	//   лооч, nyaš, _مِلژ, ديښن, 
   {{0xaca402e3,0xdb1800d2,0xf48000f2,0x588401ee}},	//   _asịr, hlwî, شاپی, _сыђа, 
   {{0x07040451,0xe3b803e0,0xf204a5de,0x00000000}},	//   _ٻيڙي_, ftır_, ияро, --, 
   {{0xf4904bcf,0xf1a401c6,0xdb080139,0x9980010a}},	//   اشید, арсн, _tkeç, _кiен_, 
   {{0x83a8036b,0x03c40131,0x73e00120,0x00000000}},	//   _отиб_, _исим, _којз, --, 
   {{0xddcc0113,0x00000000,0x00000000,0x00000000}},	//   dyaš, --, --, --, 
   {{0x9f412411,0x7bd80393,0x1ae401d5,0x00000000}},	// [33dd0] _juhé_, _riuu, қолм, --, 
   {{0x22480134,0xbbc8190c,0xbdd80066,0x7bd9d058}},	//   _isak_, िष्क, _isèk, _siuu, 
   {{0x9f40020c,0xe0d00014,0x7bd80036,0x5f944965}},	//   _luhé_, _دٲد_, _piuu, _бинт, 
   {{0x22480882,0x777801c6,0x9054011a,0x92d400fe}},	//   _ksak_, xkux, _עברו_, াঁৰ_, 
   {{0x7bd8003a,0x9164004d,0x2b4401c6,0xcb640120}},	//   _viuu, _sổ_, рэхг, ѓаше_, 
   {{0x98a409a5,0xdd95d059,0x8e700116,0xa9240212}},	//   лиле, _сагы, _уқуш, иділ, 
   {{0x2248036b,0x1c380b7e,0x98a40153,0x00000000}},	//   _lsak_, _язвы_, _valį_, --, 
   {{0x9f40030a,0x7bd80381,0x22482641,0x00000000}},	//   _buhé_, _uiuu, _osak_, --, 
   {{0x645c5243,0x95987b17,0xff5c015d,0x0ba400c7}},	//   årin, етну_, _nhîm_, _сырҭ, 
   {{0xb6a01f71,0xdb24004b,0x9164004d,0x00000000}},	//   лиқл, _جوړی, _tổ_, --, 
   {{0x2249d05a,0x973401c0,0x57f401f4,0x19d40150}},	//   _asak_, _бэлч, _спет, _ﺟﻮﻳﻠ, 
   {{0x32000295,0x00000000,0x00000000,0x00000000}},	//   _pwiy_, --, --, --, 
   {{0x224800f8,0x200004fe,0xe3b8510c,0xb34403b9}},	//   _csak_, _awhi_, ttır_, niçə, 
   {{0x6595d05b,0x8698008f,0x4610a32b,0xd0100014}},	//   _качу, _אינז, _اوور, ٝلس_, 
   {{0x22480ac5,0x8d1800e5,0xe3b87aa0,0x00000000}},	//   _esak_, ہزار_, rtır_, --, 
   {{0xe3b8e090,0x60c01dfe,0x00000000,0x00000000}},	//   luın_, ülma, --, --, 
   {{0x0dc82e70,0xe3b80e2d,0x00000000,0x00000000}},	// [33de0] елай_, ptır_, --, --, 
   {{0xe3b8247e,0x00000000,0x00000000,0x00000000}},	//   ltıp_, --, --, --, 
   {{0x7dc800a2,0x55200037,0x00000000,0x00000000}},	//   düsd, _माईए_, --, --, 
   {{0x09e49b81,0x63a401e4,0xca08430d,0xddcc0309}},	//   годн, _ĉink, ендж_, ryaš, 
   {{0x2fc0ec5d,0xaca40248,0xddcc0784,0x8e746c59}},	//   mlig_, _isọr, syaš, _сунч, 
   {{0xfce0468d,0x8c440139,0x82d4008f,0x29d40592}},	//   _горо, _йеге, אונג_, جيتس, 
   {{0xc6e40212,0x00000000,0x00000000,0x00000000}},	//   ліпп, --, --, --, 
   {{0x37a40323,0x2fc0fcc6,0xa61550d6,0x4668524d}},	//   лтын_, nlig_, амич, ером_, 
   {{0x2fc1d05c,0x490401d5,0x69c404b3,0x7dc80205}},	//   ilig_, _موءق, _көкб, büsd, 
   {{0x2fc1d05d,0x9f400165,0x98a40139,0x224801a9}},	//   hlig_, _vuhé_, _enlı_, _rsak_, 
   {{0x2fc1d05e,0xe2f80220,0x68440131,0x59740006}},	//   klig_, кені_, _әнҗа, _тыту, 
   {{0x2fc1d05f,0x2248020b,0x9f4002fb,0x7dc80e78}},	//   jlig_, _psak_, _tuhé_, müse, 
   {{0x2fc1d060,0x0a2c0020,0x6eb04328,0xb28429a3}},	//   dlig_, _አሜሪካ, _अँगु, бырк, 
   {{0x2249d061,0xaca40241,0xa4d40845,0x2fc00165}},	//   _vsak_, _asọr, _колі, elig_, 
   {{0x2fc00450,0x00000000,0x00000000,0x00000000}},	//   flig_, --, --, --, 
   {{0x2fc000ed,0xaf04109a,0x22484c91,0xff5c03cb}},	//   glig_, йчук, _tsak_, _thîm_, 
   {{0x645801fa,0x22480010,0x7dc803b9,0x00000000}},	// [33df0] _hrvi, _usak_, hüse, --, 
   {{0x64580306,0x261c10b7,0x408437ff,0xeeb8e203}},	//   _krvi, _मिनी_, _бумб, улуш_, 
   {{0x9af4a482,0x20008393,0x9f34d832,0xfca84710}},	//   لكات, _uwhi_, _кені, رائو_, 
   {{0x64581b24,0x7dc9d062,0xf34c001f,0x442c06be}},	//   _mrvi, düse, ንፎርሜ, _mqf_, 
   {{0x636c002d,0xaa580063,0x4e1c0210,0x00000000}},	//   _bûnz, лицу_, यूआई_, --, 
   {{0x39a5097f,0x7f4c0393,0x00000000,0x00000000}},	//   ышев, _hacq, --, --, 
   {{0x442dd063,0xa3e409fd,0xa3b4012c,0xdd2001ef}},	//   _nqf_, _भूल_, जका_, _kůži, 
   {{0x7d05d064,0x3f980129,0xa5f001e1,0xb9e4003b}},	//   _hejs, niqu_, _ẹkẹt, _біжи, 
   {{0x6459d065,0xfbe409bd,0x7f4dd066,0x7d05d067}},	//   _arvi, _পবিত, _macq, _kejs, 
   {{0x80b80574,0x636c002d,0x2fc00369,0xadc40022}},	//   _शुभे, _gûnz, zlig_, _osẽs, 
   {{0x3f980286,0x2fc10d6f,0x00000000,0x00000000}},	//   kiqu_, ylig_, --, --, 
   {{0x7f4dd068,0x1634084c,0x645860a3,0xb9dc0092}},	//   _nacq, _ведя, _drvi, _እረ_, 
   {{0x645814dc,0x2fc01506,0xe3b8456f,0x442c0327}},	//   _ervi, vlig_, rtıp_, _eqf_, 
   {{0x7d04038e,0xbdd8007f,0x764800c0,0x00000000}},	//   _nejs, _erèz, _isgy, --, 
   {{0x2fc13548,0x4f940124,0x7f4c0129,0x42500133}},	//   tlig_, арау, _bacq, منێر, 
   {{0xbdd8067c,0x4390147e,0x2fc0ec61,0x261c0807}},	//   _grèz, _мајс, ulig_, _मिमी_, 
   {{0x2fc1d069,0x0e65d06a,0xd1b81ec7,0x7d04036e}},	// [33e00] rlig_, шкан, _لادا_, _bejs, 
   {{0x63a400c8,0x2fc1d06b,0xbdd8007f,0x4fe8020a}},	//   _ĉini, slig_, _krèy, _имон_, 
   {{0x7d045927,0x2fc1d06c,0xc0f40023,0x8b240d1d}},	//   _dejs, plig_, ጎኦም_, идже, 
   {{0xfbc01413,0x636c025a,0x3f9823e0,0x2fc00007}},	//   обхо, _sûnz, ciqu_, qlig_, 
   {{0x7d042d2b,0x00000000,0x00000000,0x00000000}},	//   _fejs, --, --, --, 
   {{0x7d05d06d,0x6e2401f7,0x00000000,0x00000000}},	//   _gejs, muib, --, --, 
   {{0xc864f970,0x76480432,0x2d99d06e,0x7f4c0067}},	//   ртли, _asgy, _imre_, _yacq, 
   {{0x7dc9d06f,0x00000000,0x00000000,0x00000000}},	//   rüse, --, --, --, 
   {{0x38c804d3,0x9ac4010b,0x6e240393,0x00000000}},	//   _یامی_, _гитҗ, nuib, --, 
   {{0xcfec02f5,0x3f99d070,0x261c0a8a,0x00000000}},	//   টীয়_, ziqu_, _मिठी_, --, 
   {{0x2d98013f,0x7c3817a3,0xa2d8b8a8,0x7d780a1e}},	//   _mmre_, _ćurk, नेन्, דריג, 
   {{0x645809a8,0x6e25ce6b,0x06e801ad,0x3898011a}},	//   _vrvi, kuib, _ऑलिव_, _ביבנ, 
   {{0x7f4c1682,0xdd200118,0x97300451,0x46d066c0}},	//   _racq, _růži, _رکيا, देशह, 
   {{0x61e80943,0x6e2400a3,0x00000000,0x00000000}},	//   ̭elw, duib, --, --, 
   {{0x7d05d071,0x7f4d3406,0x3f9819a2,0x6459d072}},	//   _rejs, _pacq, tiqu_, _urvi, 
   {{0x6e2401ab,0x76486c13,0x7f4c06be,0x812400eb}},	//   fuib, _ysgy, _qacq, য়েজ_, 
   {{0x6e25d073,0x3f980286,0xea0001fb,0x7d05d074}},	// [33e10] guib, riqu_, _đếm_, _pejs, 
   {{0x3f980944,0xba7400f1,0x00000000,0x00000000}},	//   siqu_, یاشت, --, --, 
   {{0x2dd800c6,0x7d04780b,0xbdd802e2,0x9cb40137}},	//   شبكة_, _vejs, _osèv, حمات, 
   {{0x7d05276b,0x6e24011c,0x2d99d075,0x00000000}},	//   _wejs, buib, _emre_, --, 
   {{0x7d05d076,0x6e248416,0x2ab800a8,0x00000000}},	//   _tejs, cuib, алць_, --, 
   {{0x5d8525c4,0xd94400ee,0xecf80006,0x00000000}},	//   _السل, секи, _верш_, --, 
   {{0x201051ca,0x00000000,0x00000000,0x00000000}},	//   nszi_, --, --, --, 
   {{0x562801c0,0xda08129e,0x7dc80112,0x79a400c7}},	//   гжим_, _ميره_, büsc, ырҵе, 
   {{0x1a64be6e,0x3ab831b1,0x00000000,0x00000000}},	//   _دیشی_, _شارخ_, --, --, 
   {{0x94748e33,0x00000000,0x00000000,0x00000000}},	//   مدجا, --, --, --, 
   {{0x672001ad,0xb4e4107c,0xdb1402d2,0xe8ec010f}},	//   _याचक_, _भली_, _íbók, _סקאָ, 
   {{0x53a46550,0xdb100139,0xdb200166,0x00000000}},	//   самб, _äfär, _ütäv, --, 
   {{0xd29802bf,0x00000000,0x00000000,0x00000000}},	//   утні_, --, --, --, 
   {{0x3a3c003e,0xc07c02d3,0x261c13f7,0x00000000}},	//   _mpup_, _ዓመጽን_, _मिती_, --, 
   {{0x3a3c0327,0x4fe800d8,0x00000000,0x00000000}},	//   _lpup_, ѓман_, --, --, 
   {{0x6e25d077,0x1305d078,0x645c0b1a,0xa5240327}},	//   tuib, _узим, ærie, _འཐོག_, 
   {{0x0d8407d6,0xd82400ec,0xa3b403ce,0x00000000}},	// [33e20] блан, _ڪڍ_, जकर_, --, 
   {{0xbdd80241,0x02840228,0x7dc80c86,0xd1b00133}},	//   _apèb, _ыйык_, vüsc, _ریزک, 
   {{0x6e2401ab,0x70540345,0x00000000,0x00000000}},	//   suib, _بۆزا, --, --, 
   {{0x9164004d,0x0eb80139,0x0b18007b,0xda6400ec}},	//   _hồ_, _бугы_, اقشة_, ڪامي, 
   {{0x6e25d079,0xfaa000d8,0x00000000,0x00000000}},	//   quib, пацо, --, --, 
   {{0xda641c43,0x00000000,0x00000000,0x00000000}},	//   تامي, --, --, --, 
   {{0x49c802dd,0x00000000,0x00000000,0x00000000}},	//   _ұлан_, --, --, --, 
   {{0x7dc803e3,0x00000000,0x00000000,0x00000000}},	//   müsa, --, --, --, 
   {{0x35f4034c,0x7c3816a3,0x49c836da,0x9f440129}},	//   یرید_, _ćuri, _блан_, êlé_, 
   {{0xe98402dd,0x45486e27,0x9f9801e7,0x97a400cf}},	//   _بارۋ, учим_, váís_, йрөл, 
   {{0xfd4c00b8,0xbb2c0150,0xb2840124,0x00000000}},	//   _cakṛ, _ﺫﻴﻥ_, ҿырк, --, 
   {{0xc32c00d1,0x00000000,0x00000000,0x00000000}},	//   رەخ_, --, --, --, 
   {{0x7dc804cc,0x1cdc0327,0x97d80cc9,0x91640051}},	//   hüsa, _ལྔན_, _тьфу_, _bồ_, 
   {{0x63a400df,0x75d006c2,0x00000000,0x00000000}},	//   _ĉinu, _فينا, --, --, 
   {{0xb9dc067d,0xd3e80790,0x2004ff24,0x00000000}},	//   _እየ_, üştü_, èli_, --, 
   {{0x7dc804cc,0x3898011a,0x00000000,0x00000000}},	//   düsa, אילנ, --, --, 
   {{0x63ad4007,0x39880158,0xa19457bf,0x80b80210}},	// [33e30] _ijan, _høse_, _маич, _एडवे, 
   {{0x61fc257c,0x7dc805d5,0xfd4c0055,0x00000000}},	//   mpsl, füsa, _yakṛ, --, 
   {{0x3a3c2165,0x63ac06ea,0x00000000,0x00000000}},	//   _spup_, _kjan, --, --, 
   {{0x23c81db2,0x63ac96a9,0x61fc01a4,0xbd6801ec}},	//   रतिद, _jjan, opsl, _өрге_, 
   {{0x39880ff7,0x63adb7d1,0x00000000,0x00000000}},	//   _løse_, _mjan, --, --, 
   {{0xb4e41f5e,0x7c853277,0x00000000,0x00000000}},	//   _भले_, _лубе, --, --, 
   {{0xc6b804c5,0xa2d828b8,0x61fc0175,0x32e80327}},	//   ুশোচ, नेत्, hpsl, _རུཥྐ, 
   {{0x63add07a,0xa524025c,0xf9902a9f,0x00000000}},	//   _njan, _འཐུག_, _کبر_, --, 
   {{0x61fc01f5,0xfd4c00dc,0x00000000,0x00000000}},	//   jpsl, _sakṛ, --, --, 
   {{0x63add07b,0xfd4c00b8,0x00000000,0x00000000}},	//   _ajan, _pakṛ, --, --, 
   {{0x61fc0385,0x63ac0f8b,0x9344005b,0x6d800254}},	//   epsl, _bjan, онне, _söak, 
   {{0x39450cb3,0x63ac0200,0xcc54011a,0x00000000}},	//   lens_, _cjan, קברי_, --, 
   {{0x63add07c,0x0cc43323,0x51540261,0x9964012c}},	//   _djan, _वर्म, отву, _můžu_, 
   {{0x63add07d,0x660403e0,0x9164004d,0xa3e40073}},	//   _ejan, _çika, _bố_, _भूक_, 
   {{0x0594b4d5,0x63aca5e5,0xc0e1d07e,0xd009d07f}},	//   _بانگ, _fjan, дорк, ребе_, 
   {{0x63ac0240,0x0c680092,0xe3b82791,0x00000000}},	//   _gjan, _ተቋሞች_, lrın_, --, 
   {{0x1dc413b4,0x39442bab,0xd174010b,0x00000000}},	// [33e40] वतंत, kens_, _дыны, --, 
   {{0xef940b43,0x50440114,0x00000000,0x00000000}},	//   _کیرد, _деоб, --, --, 
   {{0x39443f75,0xbdd8007f,0x0ae827a8,0x8c48010a}},	//   dens_, _asès, адей_, рпев_, 
   {{0x39440354,0x4e28005b,0x00000000,0x00000000}},	//   eens_, _комн_, --, --, 
   {{0x3945d080,0x28f81611,0xbb441b45,0xe98402dd}},	//   fens_, бель_, زلون_, пқан, 
   {{0x3945d081,0xbeb8036e,0xb9e000d4,0x00000000}},	//   gens_, _ecës, міщи, --, 
   {{0x4788022e,0x00000000,0x00000000,0x00000000}},	//   исим_, --, --, --, 
   {{0x8b65d082,0xeb5000db,0x2258005c,0x61fc03b2}},	//   _باسم, _سۉتگ, yvsk_, ypsl, 
   {{0xf76dd083,0x3945d084,0xbdd9d028,0x056814b7}},	//   ضاي_, bens_, _isèr, ајни_, 
   {{0x3945d085,0xc984569c,0x63ac03a1,0xbdd8067c}},	//   cens_, _بشري, _sjan, _usèt, 
   {{0x63add086,0xa3e41533,0x290c0295,0x69d9d087}},	//   _pjan, _भूख_, _ieda_, mmve, 
   {{0x290d1984,0xa7fc0166,0x2c0c012d,0xe3b80139}},	//   _heda_, _arıg, डीयू_, arın_, 
   {{0x290c601a,0xe3b803be,0x916401fb,0x2e3401b8}},	//   _keda_, brın_, _số_, jäf_, 
   {{0x290dd088,0x61fdd089,0x398801bf,0x2e340166}},	//   _jeda_, rpsl, _tøse_, däf_, 
   {{0x290dd08a,0xdfd41301,0x9f400093,0x69d97c8a}},	//   _meda_, зовы, _auhá_, imve, 
   {{0x63ad80ed,0x65780943,0x61fc0efa,0x27ec0200}},	//   _ujan, _hovh, ppsl, _mudn_, 
   {{0x720413ef,0x657806d6,0x39444aee,0x27e001e4}},	// [33e50] _قويم, _kovh, yens_, ʈina_, 
   {{0x290dd08b,0xbdd801e1,0x3945d08c,0xa0040150}},	//   _neda_, _asèr, xens_, _ىسجۇ, 
   {{0x61edd08d,0x657818f7,0x00000000,0x00000000}},	//   _hual, _movh, --, --, 
   {{0x61ec47d8,0x657806d6,0x3945d08e,0x61e402c4}},	//   _kual, _lovh, wens_, _hihl, 
   {{0x61ed1eec,0x290dd08f,0x61e5d090,0x7c38009b}},	//   _jual, _beda_, _kihl, _ćuru, 
   {{0x61edd091,0x6579d092,0x39440660,0x35cc05f9}},	//   _mual, _novh, uens_, _सीढ़, 
   {{0x3944665b,0x61ec57f0,0x61e5d093,0x9164004d}},	//   rens_, _lual, _mihl, _hỗ_, 
   {{0x39452250,0x61e5d094,0x60c40209,0x61ec0311}},	//   sens_, _lihl, _myhm, _oual, 
   {{0x3944057b,0x290cf89e,0x61e4123c,0x61edd095}},	//   pens_, _feda_, _oihl, _nual, 
   {{0x290dd096,0x61e5d097,0x261c01f9,0x00000000}},	//   _geda_, _nihl, _मिरी_, --, 
   {{0x65781aa1,0x61ec096b,0xa2d83166,0x657c0267}},	//   _dovh, _aual, नेस्, örha, 
   {{0x63bd6ea4,0x61edd098,0x00000000,0x00000000}},	//   gosn, _bual, --, --, 
   {{0x61edd099,0x61e40455,0x290c014b,0x00000000}},	//   _cual, _bihl, _yeda_, --, 
   {{0x61edd09a,0x7659d09b,0x61e400bc,0x290c005a}},	//   _dual, mvuy, _cihl, _xeda_, 
   {{0x6194067d,0x61e57311,0x63bc2681,0xdb0800a2}},	//   _ሃገራዊ_, _dihl, bosn, _skeý, 
   {{0x61ec04c9,0x7658009a,0x1308084c,0x0eb80108}},	//   _fual, ovuy, _уний_, бузы_, 
   {{0x61e57311,0xfde40228,0x52740150,0x765804ba}},	// [33e60] _fihl, здук_, _ءابز, nvuy, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x0b4583c2,0xea00004d,0x61ec2321,0x7dc803e0}},	//   знен, _đằm_, _zual, müsl, 
   {{0x261c09d9,0x290c367a,0x61e40928,0x9f40022a}},	//   _मिली_, _seda_, _zihl, _tuhá_, 
   {{0x6f05d09c,0x290dd09d,0x61e5d09e,0xba700a0a}},	//   mbic, _peda_, _yihl, فاوت, 
   {{0x61e406e4,0x290dd09f,0x6f05d0a0,0x7dc80205}},	//   _xihl, _qeda_, lbic, nüsl, 
   {{0xd90cba07,0x6579b486,0x290dd0a1,0xec3401b9}},	//   شین_, _rovh, _veda_, _توزگ, 
   {{0x6e241730,0xbdd8067c,0x6f04022f,0x290dd0a2}},	//   orib, _usèr, nbic, _weda_, 
   {{0x290dd0a3,0x657801d4,0x19f801c6,0x63bdd0a4}},	//   _teda_, _povh, _дэхь_, vosn, 
   {{0x290c0066,0x63bc003e,0x6e2408c2,0xf6d000db}},	//   _ueda_, wosn, irib, ةزىد, 
   {{0x61edd0a5,0x36302b49,0x63bdd0a6,0x61e418f7}},	//   _sual, وریس, tosn, _rihl, 
   {{0x6e25d0a7,0x61e42747,0x60c4049b,0x61edd0a8}},	//   krib, _sihl, _ryhm, _pual, 
   {{0x61ecf8b3,0x63bdd0a9,0x61e5d0aa,0x657806d6}},	//   _qual, rosn, _pihl, _tovh, 
   {{0x61edd0ab,0xbdd9d0ac,0x61e4047e,0x7dc805d1}},	//   _vual, _apèn, _qihl, güsl, 
   {{0x61e5d0ad,0x63bd89ca,0x6e240158,0x63040131}},	//   _vihl, posn, erib, _قوغل, 
   {{0xbdd8004e,0x6e240ffb,0x61e405d5,0x9d080eac}},	//   _asèp, frib, _wihl, _লাইভ_, 
   {{0x61e46993,0x6e25d0ae,0x236800df,0x7dc805d1}},	// [33e70] _tihl, grib, _inaj_, büsl, 
   {{0x60c402f6,0x6f040ba7,0x00000000,0x00000000}},	//   _tyhm, abic, --, --, 
   {{0x6f0531c1,0x39880158,0x76580369,0x5f9401c6}},	//   bbic, _nøsa_, zvuy, _жинт, 
   {{0xbeb88a64,0x6e25d0af,0x6f040051,0xe3b8013d}},	//   _ndëg, brib, cbic, krım_, 
   {{0x6e242b76,0x1a2800d4,0x00000000,0x00000000}},	//   crib, іжки_, --, --, 
   {{0xdb0800e4,0xa9a406ba,0x18680f06,0x00000000}},	//   _ijeí, ىمنى, жаки_, --, 
   {{0x23681326,0xdcf40100,0x8c400112,0xa7fc03e0}},	//   _onaj_, _jozč, ößtm, _arıb, 
   {{0xdb0808e7,0x25ac01a6,0x00000000,0x00000000}},	//   _ekeò, endl_, --, --, 
   {{0x645c0a64,0x66040724,0x1954037e,0x45400131}},	//   ærin, _çikl, _ｈｃｇ_, چچىق, 
   {{0x2470044e,0x6f0415c0,0x00000000,0x00000000}},	//   _ትካላት_, zbic, --, --, 
   {{0x76580108,0x6f047392,0x00000000,0x00000000}},	//   svuy, ybic, --, --, 
   {{0xdb0800c7,0xe3b80205,0x6e25d0b0,0x00000000}},	//   _ojeí, brım_, yrib, --, 
   {{0x6e25d0b1,0x00000000,0x00000000,0x00000000}},	//   xrib, --, --, --, 
   {{0xbdd8026c,0x236801e4,0xc5600166,0x00000000}},	//   _spèn, _enaj_, _акшк, --, 
   {{0xdb0800e4,0x7dc80790,0x6f0401e4,0x14d011a6}},	//   _ajeí, rüsl, tbic, _हरिण, 
   {{0x6e25c22b,0xcf240fb4,0x00000000,0x00000000}},	//   trib, برسي, --, --, 
   {{0x6f05d0b2,0xbea00251,0xb8dc025c,0x0ea802d5}},	// [33e80] rbic, ватк, _གཙ_, цкай_, 
   {{0x6f05d0b3,0x236808ad,0x6e25d0b4,0x00000000}},	//   sbic, _znaj_, rrib, --, 
   {{0x51f4267e,0x626400f2,0x6e24000d,0x13b000cc}},	//   _عسکر, _قایق, srib, _টীয়, 
   {{0x6e25d0b5,0x0afc04c5,0x7ee00136,0x00000000}},	//   prib, ুল্ল_, ركەن, --, 
   {{0x6e25d0b6,0x28f80f30,0x00000000,0x00000000}},	//   qrib, пель_, --, --, 
   {{0x2fc00597,0x6d480122,0x680401e1,0xdd000356}},	//   loig_, ímač, _nìjò, ătăr, 
   {{0xa2a40e5b,0x4b24007b,0x19b80006,0x290001e4}},	//   _चेन्, _يعرف, чуць_, ĝia_, 
   {{0xa7fc0790,0x00000000,0x00000000,0x00000000}},	//   _arıc, --, --, --, 
   {{0xdb4c0133,0xb9e400db,0x00000000,0x00000000}},	//   _دێن_, ستۇۇ, --, --, 
   {{0x398803b2,0x3a2000d8,0x66047aa0,0xd90c0345}},	//   _høsn_, _шмуг, _çikm, _هیه_, 
   {{0x25ac0112,0x09c800cd,0xd40401d9,0x00000000}},	//   rndl_, ितीय, ى۪وم_, --, 
   {{0xc6a5d0b7,0xbdd8068c,0xdcf402fb,0x00000000}},	//   _орли, _apèl, _rozč, --, 
   {{0x39880162,0xaaa4012d,0x00000000,0x00000000}},	//   _møsn_, _खेमक, --, --, 
   {{0x02a00521,0xcfe40131,0x00000000,0x00000000}},	//   _nrụọ, _ﺋﺎﺭﻗ, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9df86145,0x62340022,0xf4840133,0x7dc80205}},	//   знат_, _зеиу, _تاهی, rüsm, 
   {{0x32540598,0x00000000,0x00000000,0x00000000}},	// [33e90] _авыр, --, --, --, 
   {{0xbeb80de2,0x6da40640,0x4084e642,0x9d540472}},	//   _ndëe, виђа, _жумб, عنات, 
   {{0x30f80014,0x070c0d79,0x00000000,0x00000000}},	//   _توپھ_, सराव_, --, --, 
   {{0xe3b80139,0x60c0000d,0x00000000,0x00000000}},	//   drık_, ülmu, --, --, 
   {{0xa2a4772c,0x09040154,0xd944004e,0x00000000}},	//   _चेम्, _রাজু_, еели, --, 
   {{0x9855d0b8,0x785000ac,0x00000000,0x00000000}},	//   етиш, _həvə, --, --, 
   {{0xb8f41889,0x645c0008,0x00000000,0x00000000}},	//   _सर_, æril, --, --, 
   {{0xa2f803f3,0xb8d40210,0x00000000,0x00000000}},	//   ंडोज_, _चख_, --, --, 
   {{0x7af819dc,0x464401e0,0x16a80107,0x999801ee}},	//   _ifut, езын_, явии_, _екат_, 
   {{0x785006be,0xe3b80205,0x00000000,0x00000000}},	//   _ləvə, brık_, --, --, 
   {{0xd469d0b9,0xc7e4021a,0x5574013d,0x00000000}},	//   чине_, _ګډون_, _үгет, --, 
   {{0x7bc8070d,0x78500213,0x6d8001f4,0x00000000}},	//   nlgu, _nəvə, _yöas, --, 
   {{0x77680928,0x7af88a3c,0x00000000,0x00000000}},	//   _ingx, _mfut, --, --, 
   {{0xd174c12a,0xb5a4010a,0x00000000,0x00000000}},	//   хымы, _юрей, --, --, 
   {{0x7af8731f,0x2fc000db,0xb400004e,0x00000000}},	//   _ofut, toig_, _шүнд, --, 
   {{0xd7f00051,0x00000000,0x00000000,0x00000000}},	//   _mũ_, --, --, --, 
   {{0x42a40020,0x785003be,0x7768009a,0x4d6402d5}},	// [33ea0] ለካከት_, _dəvə, _mngx, нкав, 
   {{0x7af9d0ba,0x32000309,0x69a404af,0x8cb4084c}},	//   _afut, _itiy_, _औषधी, нсеч, 
   {{0xcb08a482,0x77680921,0x10a402bf,0x29180295}},	//   كيان_, _ongx, _чинн, _ôrai_, 
   {{0x7c2000ae,0xe3b80205,0x00000000,0x00000000}},	//   ánra, vrık_, --, --, 
   {{0x3b1c0327,0x2bb8013a,0x00000000,0x00000000}},	//   _dduq_, jčce_, --, --, 
   {{0x7af9d0bb,0x7769b4dd,0x7bc9d0bc,0x3ea802f0}},	//   _efut, _angx, algu, šitá_, 
   {{0x67fc00c7,0x07e40640,0xd7f00208,0x00000000}},	//   _oĩje, нцим, _cũ_, --, 
   {{0xca7411ed,0x6604013d,0x00000000,0x00000000}},	//   _пузы, _çikk, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x77681cdf,0x162006ab,0x35b00026,0xfe34010f}},	//   _engx, _मिरर_, лбыр, עריי_, 
   {{0x46e80cfc,0x320003f0,0x351405f5,0x261c1cd2}},	//   _еден_, _atiy_, эжээ_, _मिकी_, 
   {{0xb7d5d0bd,0xaca4063f,0x44200219,0x3d14012d}},	//   _كولا_, _apịr, čk_, _पड़ने_, 
   {{0x3664011c,0x00000000,0x00000000,0x00000000}},	//   _пацо_, --, --, --, 
   {{0x246400c7,0x00000000,0x00000000,0x00000000}},	//   _ахиҳ, --, --, --, 
   {{0x44380de2,0x1fc40107,0xe37401ee,0xdcf40171}},	//   _ëp_, враҳ, _алйы, _nozā, 
   {{0x9e95353d,0x00000000,0x00000000,0x00000000}},	//   پارچ, --, --, --, 
   {{0xb18402fb,0x7dc83536,0x00000000,0x00000000}},	// [33eb0] šťav, lüsi, --, --, 
   {{0x224804b9,0x13d400cc,0x00000000,0x00000000}},	//   _ipak_, _সংয়, --, --, 
   {{0x7af99d58,0x785000ac,0xa2a400dc,0xbbe801c8}},	//   _pfut, _təvə, _चेत्, سرام_, 
   {{0x20000928,0x28c4068f,0x162005d7,0x50180375}},	//   _ithi_, _लुधि, _मिलर_, _קורו, 
   {{0x2e480153,0x00000000,0x00000000,0x00000000}},	//   _пяро_, --, --, --, 
   {{0x98a45aba,0xd945d0be,0x7dc99889,0xf2d4008f}},	//   киле, теки, küsi, נעס_, 
   {{0x7af80af2,0xf4fc01e1,0x7d1401a9,0x7dc800a2}},	//   _tfut, _dẹlé_, maxs, jüsi, 
   {{0x200000f1,0x7af9d0bf,0xd7f0004d,0xb40000d1}},	//   _mthi_, _ufut, _vũ_, ңүлд, 
   {{0x15b96e46,0x9954084c,0x35c000c7,0x00000000}},	//   дыны_, _икац, лаиҳ, --, 
   {{0x20000912,0xa7fc013d,0x8d940092,0x7dc80254}},	//   _othi_, _irın, _መከተል_, füsi, 
   {{0x20000211,0x2249d0c0,0xb0c001ad,0x81d40154}},	//   _nthi_, _apak_, _शुंग, িদা_, 
   {{0x776800f1,0x53a42cdd,0x00000000,0x00000000}},	//   _ungx, тамб, --, --, 
   {{0x20000928,0x4798008f,0x67d4288a,0x95b401e0}},	//   _athi_, _קינס, _соцу, _үрҙә, 
   {{0xddcc0882,0xb9c802d3,0x7dc98aeb,0x00000000}},	//   rvaś, _ዲኻ_, büsi, --, 
   {{0x212026b6,0x238405ac,0x7d1401a9,0x8fa5d0c1}},	//   _ddhh_, åsjø_, daxs, ваве, 
   {{0xb9e8069c,0xe4e400d6,0x3320003e,0xff20014b}},	//   _ሕጊ_, _січн, _udix_, имсо, 
   {{0x200070d0,0x3200002e,0x59c01100,0x00000000}},	// [33ec0] _ethi_, _utiy_, शकार, --, 
   {{0x21743070,0x7d140009,0x3e840241,0xdcf400ef}},	//   _буюр, gaxs, _sítú_, _pozā, 
   {{0xa7fc0e51,0x2b44045a,0x00000000,0x00000000}},	//   _arın, _pbmc_, --, --, 
   {{0x09c80a28,0xf10800db,0x7c3000d4,0xa2d8013a}},	//   ित्य, _تىگۉ_, реїх, नेक्, 
   {{0x7d140429,0x9f48002f,0xc330011a,0x00000000}},	//   baxs, lmaß_, שוד_, --, 
   {{0x8c453bfd,0x660403e0,0xe83801ec,0x00000000}},	//   _иеге, _çiki, епкі_, --, 
   {{0x6d5dd0c2,0xaca40521,0x9f480112,0x00000000}},	//   _iara, _kpọr, nmaß_, --, 
   {{0x37a4717e,0x00000000,0x00000000,0x00000000}},	//   ктын_, --, --, --, 
   {{0xd05c01e4,0x6b8000a3,0xe584009d,0x00000000}},	//   _nepɾ, _iomg, гтнү, --, 
   {{0x824c044e,0x6b800115,0x00000000,0x00000000}},	//   _ዕላማታ, _homg, --, --, 
   {{0x19b800c9,0x6b806e0e,0x2249d0c3,0xbdd800f2}},	//   _чуть_, _komg, _spak_, _spèk, 
   {{0x224805b1,0x787001d9,0x23b400f2,0x00000000}},	//   _ppak_, _خُما, امحس, --, 
   {{0xf670b57a,0x6d5dd0c4,0x200000b8,0x9f4000d7}},	//   _ناوخ, _oara, _sthi_, _tuhú_, 
   {{0x6d5dd0c5,0x6b81d0c6,0x7dc80209,0x9f48002f}},	//   _nara, _lomg, püsi, fmaß_, 
   {{0x6b8003ac,0x355002f2,0x00000000,0x00000000}},	//   _oomg, _ئۆپز, --, --, 
   {{0x6d5dd0c7,0x6b80021a,0x6459d0c8,0x443c0083}},	//   _aara, _nomg, _isvi, mtt_, 
   {{0x69c9d0c9,0xceb4deea,0x28c401ad,0x7d143ff5}},	// [33ed0] _okde, гәр_, _लुसि, taxs, 
   {{0x7ce0022e,0x00000000,0x00000000,0x00000000}},	//   yеrd, --, --, --, 
   {{0x20000928,0x6b800472,0x7d1401d9,0xca380150}},	//   _uthi_, _bomg, raxs, _ﺒﺤﺭ_, 
   {{0x443c43d3,0x6d5dd0ca,0x69c805d1,0x6b8000fd}},	//   itt_, _eara, _akde, _comg, 
   {{0x6d5dd0cb,0x443dd0cc,0x00000000,0x00000000}},	//   _fara, htt_, --, --, 
   {{0x6459d0cd,0x7ce0022e,0x00000000,0x00000000}},	//   _osvi, tеrd, --, --, 
   {{0x6ce402bf,0xe5fc063f,0xaab80131,0x17c801b9}},	//   _віте, _rịịs, ىدۇر_, нгки_, 
   {{0x69c80115,0xfbb400c5,0x00000000,0x00000000}},	//   _ekde, _अदिम, --, --, 
   {{0xa7fc1248,0x6459d0ce,0xbbbc00bc,0x00000000}},	//   _urın, _asvi, एकीक, --, 
   {{0x6d5dd0cf,0x6b80676c,0xa7fc013d,0x00000000}},	//   _xara, _zomg, _krıl, --, 
   {{0x443c074d,0x6b81d0d0,0x7bd842b2,0x00000000}},	//   gtt_, _yomg, _khuu, --, 
   {{0x93940736,0x96b801f0,0x95840150,0x00000000}},	//   اجدا, _пулу_, _әлке, --, 
   {{0x15440b65,0x64580ba1,0xea0001fb,0x7778009a}},	//   _белм, _esvi, _đẫm_, mjux, 
   {{0xd9d004c5,0x00000000,0x00000000,0x00000000}},	//   াদকম, --, --, --, 
   {{0x6d5dd0d1,0xb184012c,0xdb08036e,0x7dc806be}},	//   _rara, šťov, _gjeç, nüsu, 
   {{0xcee80063,0x0c2401e0,0x9f48002f,0x00000000}},	//   едбе_, ҫман, rmaß_, --, 
   {{0x0e6402d5,0x6b80054e,0x9f480e78,0xa7fc1432}},	// [33ee0] ыкан, _romg, smaß_, _arıl, 
   {{0x6b81d0d2,0xdcf40356,0xbdf000cc,0x00000000}},	//   _somg, _roză, _চৌহদ_, --, 
   {{0x8fa490b1,0x7bd800b8,0x69c801f5,0xdc8001d5}},	//   _бане, _bhuu, _rkde, оқро, 
   {{0x7bd94681,0x0b58007b,0x00000000,0x00000000}},	//   _chuu, عشاب_, --, --, 
   {{0x7bd9d0d3,0xbf98010f,0x00000000,0x00000000}},	//   _dhuu, _טיטש, --, --, 
   {{0x443c3d28,0x6d5c0c8c,0x6b802d2f,0x7bd801c4}},	//   ytt_, _uara, _womg, _ehuu, 
   {{0x6b80795b,0x76480024,0x0ba8b071,0x00000000}},	//   _tomg, _apgy, _كارى_, --, 
   {{0x6b8001bf,0x00000000,0x00000000,0x00000000}},	//   _uomg, --, --, --, 
   {{0x0935d0d4,0xaab830a4,0xa91c01f1,0xbdd801ab}},	//   _مراج, _अशिक, _voľb, _spèi, 
   {{0x645804ce,0xa2a44f3c,0x09e5d0d5,0x49900e60}},	//   _psvi, _चेष्, _созн, _دیتر, 
   {{0x443dd0d6,0xbeb80de2,0xe374008e,0xa4d40111}},	//   utt_, _ndën, алны, роні, 
   {{0xdb08069c,0x7dc9d0d7,0x837010cf,0x00000000}},	//   _vjeç, lüst, сқич, --, 
   {{0x82a406ed,0x98f40051,0x00000000,0x00000000}},	//   ушне, _mản, --, --, 
   {{0x64580433,0x36580375,0x7dc805d1,0x39880174}},	//   _tsvi, _נכונ, nüst, _røsk_, 
   {{0x6ab05361,0x64580099,0xbdd800e4,0x00000000}},	//   जपुर, _usvi, _upèi, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xaaa48a57,0x7dc9d0d8,0x9d1400f3,0x00000000}},	// [33ef0] _खेलक, küst, идач, --, 
   {{0x7bd9d0d9,0x91c00131,0x5f1403d4,0x00000000}},	//   _shuu, _дәсл, িলেখ_, --, 
   {{0x9370001f,0x7dc805d1,0x7bd800b5,0x28c4033f}},	//   _እየሆነ_, düst, _phuu, _लुलि, 
   {{0xc1a40046,0x6ab0d7bc,0x9e3422bf,0x98f4004d}},	//   _шыққ, जपूर, _кемч, _cản, 
   {{0xbb50037e,0xceb4010b,0xa2d80846,0x2b4401c6}},	//   _pinケ_, _кәф_, नेच्, сэхг, 
   {{0xdd94969c,0x7dc805d5,0xceb400d1,0xdb18002f}},	//   _тагы, güst, _тәс_, llwü, 
   {{0xa7fc0166,0x00000000,0x00000000,0x00000000}},	//   _urıl, --, --, --, 
   {{0x1dd800e1,0x7bd9d0da,0x178406dc,0xcf9000df}},	//   _बीतत, _uhuu, ргим, ַטי_, 
   {{0xff5c025a,0x7dc805d1,0xa2a401ef,0x00000000}},	//   _maî_, büst, _चेल्, --, 
   {{0x76480354,0xb8d8015b,0xdb18002f,0x629dd0db}},	//   _vpgy, _ঘর_, hlwü, dzso, 
   {{0x7dc80730,0x00000000,0x00000000,0x00000000}},	//   lüss, --, --, --, 
   {{0xc4800a4a,0xd294035b,0x67d40354,0x00000000}},	//   іляк, аргь, _лоху, --, 
   {{0x6d480793,0x7dc80112,0x00000000,0x00000000}},	//   _ödag, nüss, --, --, 
   {{0x98a406b9,0xe61003e6,0xa91c0030,0xddcc033f}},	//   _halı_, _رشه_, _koľa, hwał, 
   {{0x7dc803fa,0xbb2c00d1,0x758000f1,0x00804c91}},	//   hüss, _ﻫﻪﻡ_, _نیکم, олро, 
   {{0x0c7404fb,0x7dc9d0dc,0x00000000,0x00000000}},	//   یداد, züst, --, --, 
   {{0x660471d5,0x98a40ac1,0x96dc0412,0xa3b4033f}},	// [33f00] _çikt, _malı_, _परफॉ, ड़कर_, 
   {{0xe3b805d1,0xddcc012d,0x7dc806be,0x00000000}},	//   brıs_, ewał, düss, --, 
   {{0xa3bc375c,0xfc14007b,0x00000000,0x00000000}},	//   _आदम_, لقلب_, --, --, 
   {{0x7dc802c1,0x9c580137,0x20040f91,0x00000000}},	//   füss, ышуу_, ílie_, --, 
   {{0x8e7400d1,0x7dc9d0dd,0x00000000,0x00000000}},	//   _тунч, güss, --, --, 
   {{0x60c805d1,0x82d4008f,0xa91c0419,0x00000000}},	//   şeme, בונג_, _boľa, --, 
   {{0x7dc9d0de,0x98a493ba,0x02d000bc,0x00000000}},	//   rüst, _balı_, _सर्न, --, 
   {{0x7dc8007d,0xa91c00d0,0x8a040120,0x466800f5}},	//   süst, _doľa, _взае, вром_, 
   {{0xbeb8025a,0x98a40790,0x7dc80037,0x00000000}},	//   _ndël, _dalı_, püst, --, 
   {{0xd90c05d9,0x228c0241,0x960800f1,0x25b8000d}},	//   _ٻڌو_, _lókú_, اکنې_, õrl_, 
   {{0x291dd0df,0x67240086,0x98a47236,0xb8d80183}},	//   mava_, _ôijo, _falı_, _ঘৰ_, 
   {{0xbdd800e4,0x629c002f,0x91c000c7,0x00000000}},	//   _upèv, tzso, ҟәыл, --, 
   {{0xda18068f,0x224c057b,0xf7400276,0x00000000}},	//   नीपत_, ïek_, _фечо, --, 
   {{0x98a4467d,0xddcc012d,0x629c00e5,0xc0f40023}},	//   _zalı_, zwał, rzso, _ፈልሲ_, 
   {{0x291dd0e0,0xff5c00e4,0xddcc033f,0x98a41f02}},	//   iava_, _paî_, ywał, _yalı_, 
   {{0x291dd0e1,0xa7fc03e0,0x98a403e3,0x6604008e}},	//   hava_, _arık, _xalı_, _çiks, 
   {{0x291dd0e2,0xd130182f,0x9ed9d0e3,0xdec405a2}},	// [33f10] kava_, _کمپ_, умат_, сәно, 
   {{0x25ac01ab,0xdcf400ef,0xe3b803b9,0x00000000}},	//   nidl_, _ilzī, prıs_, --, 
   {{0x248c0204,0x21fc0051,0x99880022,0x9af400ae}},	//   nydm_, _hìh_, қәаз_, مكات, 
   {{0xdea03cb9,0xa7fc0166,0x00000000,0x00000000}},	//   _فیزی, _erık, --, --, 
   {{0xeab1d0e4,0x291dd0e5,0x6fc40490,0xddcc012d}},	//   وعه_, fava_, वकरं, rwał, 
   {{0x98a403ee,0x7c85d0e6,0x21fc004d,0xa91c00d0}},	//   _salı_, _кубе, _mìh_, _poľa, 
   {{0x1bd407d8,0x6dc400f7,0xdc380092,0x00000000}},	//   _говя, _بۅلۅ, _ያልሆኑ, --, 
   {{0x291dd0e7,0x98a406be,0xa91c0419,0x7dc9d0e8}},	//   aava_, _qalı_, _voľa, püss, 
   {{0x203c02d3,0xaa580139,0x95c8c02c,0x00000000}},	//   _ይግበረ, _киту_, ллиб_, --, 
   {{0x291dd0e9,0xb86466df,0xf9904e10,0xa9280212}},	//   cava_, _پائو, _ببر_, _віце_, 
   {{0xe858013e,0x38c80139,0x98a40139,0x28f8030d}},	//   _вахш_, _руан_, _talı_, _техь_, 
   {{0x28f0247f,0x461002f2,0xd7d40066,0x00000000}},	//   _تۋىس, _کوور, _اصطک, --, 
   {{0xdebc044e,0x16200b40,0xd628a943,0xb3d40116}},	//   ተደኣ_, _मिटर_, _соле_, ййүә, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xcfb00327,0x645c003a,0xe3b80342,0x00000000}},	//   _དམྱྀ, ærit, msın_, --, 
   {{0x291dd0ea,0xe3b89d58,0x9f4002fb,0xd3e80213}},	//   zava_, lsın_, _tuhý_, üşdü_, 
   {{0xa3bc0c2e,0xd1b896c6,0x6da40184,0x4d492573}},	// [33f20] _आदत_, _مادا_, ҡиға, лпан_, 
   {{0x291dd0eb,0xe3b81d89,0xd108036b,0xeb100254}},	//   xava_, nsın_, _حقده_, ार्त_, 
   {{0x291dd0ec,0xbdd802e2,0x0fd804fb,0xcb680640}},	//   vava_, _apès, _مبحث_, лаже_, 
   {{0xef94006c,0x291dd0ed,0x3f980978,0x5ba40212}},	//   _بیرد, wava_, chqu_, оріз, 
   {{0xe3b99070,0xc6b0015b,0xe984024c,0x00000000}},	//   ksın_, _চর্চ, оқан, --, 
   {{0xda644d49,0x291c004e,0x82d4010f,0x27fc0051}},	//   غاني, uava_, זונג_, tqvn_, 
   {{0xc865d0ee,0x993800d4,0x00000000,0x00000000}},	//   стли, рячу_, --, --, 
   {{0x291dd0ef,0xbb41d0f0,0xf76c821f,0xc7c40063}},	//   sava_, _неск, فاً_, љски, 
   {{0xd0f80a8a,0x00000000,0x00000000,0x00000000}},	//   ्डाण_, --, --, --, 
   {{0x3e5800df,0x00000000,0x00000000,0x00000000}},	//   נדיס, --, --, --, 
   {{0x07a44c70,0x6fc84ed3,0x25ac003e,0x674001d9}},	//   _лажн, लवां, ridl_, _ہێژٕ, 
   {{0xe3b80139,0x00000000,0x00000000,0x00000000}},	//   asın_, --, --, --, 
   {{0xc6d4baa9,0x05845d9f,0xe0b40154,0xd25000ec}},	//   _اتات, _гуйм, _টরেন, ونٽ_, 
   {{0x645d9eca,0x00000000,0x00000000,0x00000000}},	//   æris, --, --, --, 
   {{0xbdd839d3,0x3518011a,0x78f80115,0x00000000}},	//   _opèr, _גוונ, רפלו, --, 
   {{0xa3bc35e8,0x398814f5,0x2d980489,0xf480da05}},	//   _आदि_, _høst_, _alre_, _хушн, 
   {{0x82340228,0x2258023a,0xa91c00d0,0x7df000cf}},	// [33f30] _ارعا, _типы_, _roľn, سقاچ, 
   {{0xa3dc10f7,0xc32c0aaf,0xbdd80ba1,0x3f98f812}},	//   _तीत_, _تەڭ_, _apèr, shqu_, 
   {{0xa91c01f1,0xbdd800f2,0x00000000,0x00000000}},	//   _poľn, _spès, --, --, 
   {{0x39880ff7,0x2d9805be,0xe3b80ac1,0xb82400cc}},	//   _løst_, _elre_, zsın_, _মহলত_, 
   {{0xa91c01a2,0x99dc007f,0x71e812fd,0x00000000}},	//   _voľn, _opňt, _خفیف_, --, 
   {{0xbdd8004e,0xc6b003d4,0x00000000,0x00000000}},	//   _epèr, _চৰ্চ, --, --, 
   {{0xe9d1d0f1,0xeab00372,0xa3d800c5,0x97c41e5a}},	//   رغه_, وعۇ_, ऽता_, يقتو, 
   {{0x9cc80184,0xbeb82568,0x56280114,0x00000000}},	//   _быға_, _ndëk, ажим_, --, 
   {{0xe3b891fc,0x7c34035a,0xd6280108,0x2bb80a59}},	//   tsın_, luxr, шопе_, ेकरा, 
   {{0x7bc9d0f2,0x14250831,0x27e00003,0x00000000}},	//   logu, одом, ċina_, --, 
   {{0xe3b83e67,0x92b40154,0x00000000,0x00000000}},	//   rsın_, _ঝরে_, --, --, 
   {{0x7bc9d0f3,0xe8ec010f,0x1c1006b1,0xcc3800df}},	//   nogu, _עקאָ, डीएल_, סערט, 
   {{0x39880174,0xe3b81432,0x63bc003e,0x63ac010b}},	//   _føst_, psın_, érna, _şonç, 
   {{0xd00801ec,0x00000000,0x00000000,0x00000000}},	//   иеге_, --, --, --, 
   {{0x7bc9d0f4,0xea00001e,0xa5640345,0x00000000}},	//   kogu, _đậm_, _ردون, --, 
   {{0x7bc8035b,0xb8f8025c,0xa48402dd,0x2005d0f5}},	//   jogu, _ལཊ_, _ءجون, ília_, 
   {{0x7bc9d0f6,0x0d85d0f7,0x398833b8,0xc0f402d3}},	// [33f40] dogu, олан, _jøss_, _ፈውሲ_, 
   {{0x425000e5,0x00000000,0x00000000,0x00000000}},	//   _کنیر, --, --, --, 
   {{0xcb082085,0x7bc9d0f8,0xa91c00d0,0x00000000}},	//   ليان_, fogu, _soľo, --, 
   {{0x7bc9d0f9,0x53c80882,0xa91c01f1,0xe800033f}},	//   gogu, रविश, _poľo, _लंबा_, 
   {{0x6f040cf4,0xff54011a,0x00000000,0x00000000}},	//   mcic, _ובכך_, --, --, 
   {{0x6f040268,0x6e25d0fa,0xd15002d3,0xa2ac0846}},	//   lcic, msib, _ህዝባው, ीपत्, 
   {{0x7bc8035b,0x39880b34,0x6e257f54,0x7c24bbb8}},	//   bogu, _røst_, lsib, _морг_, 
   {{0xbdd800e4,0x7bc800e4,0x6ffc01ef,0x00000000}},	//   _upèr, cogu, _ačck, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x48e5d0fb,0x6e25d0fc,0x48741d0a,0x7ce001a9}},	//   _дозв, isib, _وداس, kеrl, 
   {{0xe2f802dd,0x6e24025c,0xa3d4022e,0x00000000}},	//   йені_, hsib, зонч, --, 
   {{0x6f041591,0x00000000,0x00000000,0x00000000}},	//   jcic, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7bc9d0fd,0xd24c00b2,0xc87c03be,0x75d002dd}},	//   zogu, اچي_, şğul_, _قينا, 
   {{0x7bc87c6f,0x3f840261,0x260001e1,0x6e244886}},	//   yogu, оѓаа, _hòo_, esib, 
   {{0x6721d0fe,0x00000000,0x00000000,0x00000000}},	//   namj, --, --, --, 
   {{0x63add0ff,0x6e241187,0x7bc9451a,0xe3b80342}},	// [33f50] _iman, gsib, vogu, nsım_, 
   {{0x63ac299d,0x6f0400d0,0x672001a9,0x7ce00166}},	//   _hman, acic, hamj, bеrl, 
   {{0x7bc9d100,0x672001f7,0x6e25d101,0x63ac0135}},	//   togu, kamj, asib, _kman, 
   {{0x6f04cdd9,0x63ac0327,0x6e240009,0x1b4801d5}},	//   ccic, _jman, bsib, ёзли_, 
   {{0x63add102,0x7bc807dd,0xea000016,0x6e2401d3}},	//   _mman, rogu, _đảm_, csib, 
   {{0xa3dc4d53,0x8df80302,0x4e140302,0xae440050}},	//   _तीस_, _להשת, _מחשב_, _تھٲو, 
   {{0x63add103,0x78550fdc,0x319c0375,0xf1b4011a}},	//   _oman, تیاز_, שבונ, וסס_, 
   {{0x63add104,0x67200117,0x1b140154,0x5fbc024a}},	//   _nman, gamj, _ডাকে_, ्किल, 
   {{0xe9d000d1,0xaa5c0150,0x00000000,0x00000000}},	//   رغۇ_, _кетi, --, --, 
   {{0x693460a1,0x00000000,0x00000000,0x00000000}},	//   _онуу, --, --, --, 
   {{0x5fbd1586,0x6ffc0100,0x53c800db,0x00000000}},	//   ्काल, _gčch, йгом_, --, 
   {{0x63ac07ab,0x260001ab,0x28c40ebb,0x6e240009}},	//   _cman, _fòo_, _लुटि, ysib, 
   {{0x63ac06d1,0x6f0405a1,0xc7b004ae,0xa3bcb37b}},	//   _dman, vcic, _אבא_, _आदर_, 
   {{0x63add105,0xfa1c001f,0x27300137,0x7ce001a9}},	//   _eman, _ስደተኞ, _كۉۉس, tеrl, 
   {{0x6ab8081e,0x2600067c,0xd009d106,0xa7fc0205}},	//   _अश्र, _zòo_, себе_, _isıc, 
   {{0x63add107,0x6e25d108,0x46e00b02,0x63a4031c}},	//   _gman, tsib, _परमह, _ċing, 
   {{0xca380220,0x00000000,0x00000000,0x00000000}},	// [33f60] _ﺒﻤﺎ_, --, --, --, 
   {{0x63ac0fb7,0xd1b81ec7,0x67201710,0x00000000}},	//   _zman, _دابا_, zamj, --, 
   {{0x1b0c03f4,0x6f0401fa,0x67200117,0x63add109}},	//   _হয়ে_, pcic, yamj, _yman, 
   {{0xbeb823f3,0x4f5800c6,0xdb180100,0x6e25d10a}},	//   _beëd, _اجدد_, nnwè, psib, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb0800e4,0x1fc400fe,0x672001f7,0xbdd800e4}},	//   _ijeý, ্ষণস, wamj, _upèp, 
   {{0xc170011a,0x6721861a,0x00000000,0x00000000}},	//   תחו_, tamj, --, --, 
   {{0x68440020,0xa91c01f1,0x98840064,0xdb4c0133}},	//   _የክርስ, _koľk, _eįįt_, _نێم_, 
   {{0xfaa00c56,0x98b000da,0x63adc56c,0xf64005f5}},	//   _зато, ībām_, _rman, нхэн, 
   {{0xf64c9e9d,0x63ac0bb8,0xd6d86240,0x9a480014}},	//   ائي_, _sman, өтө_, _گجہِ_, 
   {{0x672002d3,0xbeb80ea0,0xf76c0133,0x63bc00c7}},	//   pamj, _teëg, _ڕاو_, érno, 
   {{0x63ac020c,0xa3dc00af,0x00000000,0x00000000}},	//   _qman, _तीश_, --, --, 
   {{0x69d80ea0,0x2834001f,0x00000000,0x00000000}},	//   olve, _አርአያ, --, --, 
   {{0xa3dc0c2e,0x2004315a,0x00000000,0x00000000}},	//   _तीर_, ílio_, --, --, 
   {{0xdfd45560,0x69d8002f,0x63add10b,0x35800023}},	//   довы, ilve, _tman, _ክለባት_, 
   {{0x69d87148,0x31941432,0x20040115,0x9f5800a2}},	//   hlve, _ağzı_, ŭlio_, _öyün_, 
   {{0x64481330,0x00000000,0x00000000,0x00000000}},	// [33f70] ltdi, --, --, --, 
   {{0x69d801bf,0x2dd40022,0x00000000,0x00000000}},	//   jlve, ежур, --, --, 
   {{0x6449d10c,0x63bc581c,0xdb0800c7,0x65693625}},	//   ntdi, onsn, _ejeý, iddh, 
   {{0x69d89237,0x63bc42ff,0x1a6450ec,0x644801f5}},	//   elve, nnsn, ویزی_, itdi, 
   {{0x3e3001ed,0xdb18002e,0x00000000,0x00000000}},	//   _سہار, nnwé, --, --, 
   {{0x3f880b91,0x6449d10d,0x69d95b60,0x00000000}},	//   _hocu_, ktdi, glve, --, 
   {{0x246c012c,0xb4a8012d,0xd7c806c5,0x00000000}},	//   _něm_, _गधे_, يوته_, --, 
   {{0xefc8001e,0x49700032,0xa7fc5656,0x8ca00150}},	//   _địch_, еләс, _arıs, _جەمو, 
   {{0x3f880ffb,0x7af9d10e,0x64480072,0x00000000}},	//   _mocu_, _igut, etdi, --, 
   {{0x3f880c95,0xbeb805e4,0x63bc01f5,0x79a409a5}},	//   _locu_, _geëe, ensn, _эрбе, 
   {{0x7af80184,0x63bc02d0,0xca380150,0x00000000}},	//   _kgut, fnsn, _ﺒﺤﺕ_, --, 
   {{0x3f881050,0x63bc007c,0xe7840229,0x00000000}},	//   _nocu_, gnsn, _пучо, --, 
   {{0xdcf401e4,0x1fc4009e,0x15440c75,0xa3dc0073}},	//   _rozĝ, ্ষাস, _желм, _तीळ_, 
   {{0x63bc002d,0x63a40135,0x00000000,0x00000000}},	//   ansn, _ċine, --, --, 
   {{0x3f88041a,0x7af80a49,0x00000000,0x00000000}},	//   _bocu_, _ogut, --, --, 
   {{0x7af9d10f,0x3f89d110,0xa91c00d7,0x0454007b}},	//   _ngut, _cocu_, _poľk, _آلية_, 
   {{0x3f89d111,0x69d800fe,0x00000000,0x00000000}},	// [33f80] _docu_, ylve, --, --, 
   {{0xa2ac0574,0x33200254,0x2d9c00e4,0x00000000}},	//   ीपर्, _heix_, óve_, --, 
   {{0x0b456442,0x3f882b1d,0x1d1802bf,0xbeb8282c}},	//   днен, _focu_, яють_, _reëe, 
   {{0x3ebc05ce,0x3f880cf4,0xa91c0030,0xb3bc0327}},	//   _žute_, _gocu_, _toľk, _ཛམྦུ, 
   {{0xdb2415f6,0x65680368,0xd90c02f2,0x451c00cc}},	//   رووی, yddh, ڵین_, _দাসক_, 
   {{0x33200399,0x7af9d112,0xb95000d1,0x644801d5}},	//   _leix_, _egut, نئىت, ytdi, 
   {{0xfc001b88,0x67d4dfe7,0xa7fc0139,0x8b2410fc}},	//   _апсо, ноку, _arır, _одве, 
   {{0x33200097,0x7af804ba,0xfce035f2,0x00000000}},	//   _neix_, _ggut, _росо, --, 
   {{0x2b4401fa,0x8a4400db,0x483000f1,0x63bc0162}},	//   _icmc_, _تئزم, روکړ, vnsn, 
   {{0x2a640a14,0x26d87204,0x2b440208,0x00000000}},	//   _ismb_, āro_, _hcmc_, --, 
   {{0x3320004e,0x65680882,0x2b4401f7,0x53c800af}},	//   _beix_, rddh, _kcmc_, रवंश, 
   {{0x6449d113,0x63bc0036,0x200401e7,0x00000000}},	//   rtdi, unsn, ílim_, --, 
   {{0x6449d114,0x46e02a09,0x3320004e,0x63bc0857}},	//   stdi, _परिह, _deix_, rnsn, 
   {{0x3f8808e5,0xa7fc0724,0x525005d9,0x246c00bc}},	//   _socu_, _urıs, اچيء, _těm_, 
   {{0x3f880c95,0x332000db,0xf1a59ba8,0x03c40818}},	//   _pocu_, _feix_, трян, _осим, 
   {{0xdb102d8b,0xe0e401d5,0x4f3401d9,0x00000000}},	//   _åfør, дўғо, ى۪پھ_, --, 
   {{0x3f88026c,0x320000ad,0xdcf4013d,0xf2c40024}},	// [33f90] _vocu_, _guiy_, _bozğ, _асэн, 
   {{0x3b1c0007,0x7af80ffb,0x5dd45821,0x00000000}},	//   _seuq_, _sgut, رقائ, --, 
   {{0x33200369,0x5f940124,0x00000000,0x00000000}},	//   _yeix_, _зинт, --, --, 
   {{0x2b440005,0x3320004e,0x26d80213,0x00000000}},	//   _ccmc_, _xeix_, ərov_, --, 
   {{0xdfd000b2,0x200002b5,0x89d40133,0x2b44009d}},	//   _ليگ_, _huhi_, کوور_, тэхг, 
   {{0x200018a6,0x2b44020b,0x1869d115,0x2bb801fa}},	//   _kuhi_, _ecmc_, заки_, dčcu_, 
   {{0x200000af,0x2120003e,0x7af805d5,0x7dc800e5}},	//   _juhi_, _mehh_, _tgut, küsz, 
   {{0x7af9d116,0x2001d117,0x1664998c,0x236800e8}},	//   _ugut, _muhi_, евим, _naaj_, 
   {{0x200018a6,0xea00001e,0x21200254,0x69c40036}},	//   _luhi_, _đầm_, _oehh_, éiec, 
   {{0x2120020b,0x3320004e,0xf8ad9c37,0xa7fc0790}},	//   _nehh_, _seix_, _پکت_, _isın, 
   {{0x332000f7,0x2001d118,0x2368013c,0x00000000}},	//   _peix_, _nuhi_, _baaj_, --, 
   {{0xe894c7c3,0x00000000,0x00000000,0x00000000}},	//   _шахь, --, --, --, 
   {{0x20001132,0x23680de2,0x32000086,0x8fd00032}},	//   _auhi_, _daaj_, _quiy_, ғәнә, 
   {{0x2000d9a6,0x15440209,0x00000000,0x00000000}},	//   _buhi_, _чекм, --, --, 
   {{0x21200263,0x236800e8,0x10a4330e,0x3320004e}},	//   _dehh_, _faaj_, хивн, _teix_, 
   {{0x2120acd7,0xbeb80023,0x8e08118b,0x2498143a}},	//   _eehh_, _ndës, знав_, ørme_, 
   {{0x20000093,0xbea1d119,0xdcf403e3,0x0ea80024}},	// [33fa0] _euhi_, гатк, _pozğ, чкай_, 
   {{0xe3b803b9,0xdee80023,0x00000000,0x00000000}},	//   drıy_, ሚርካ_, --, --, 
   {{0x23680218,0xa7fc0205,0xa91c00d7,0x00000000}},	//   _yaaj_, _asın, _koľv, --, 
   {{0x23680694,0x8fa40120,0x8e8400d8,0xc4d000df}},	//   _xaaj_, _чаме, _згме, נגא_, 
   {{0xc330025d,0x7bc0003e,0x2fc0007c,0xfa30020c}},	//   רוד_, énua, mnig_, هرود, 
   {{0x20000230,0x8c440114,0xb9e000d4,0x00000000}},	//   _yuhi_, _пеге, ліщи, --, 
   {{0xfce1d11a,0x2b440048,0x00000000,0x00000000}},	//   _боро, _tcmc_, --, --, 
   {{0x2fc1d11b,0x670400b0,0xa7741422,0x00000000}},	//   nnig_, kōkō, тлич, --, 
   {{0x2fc1d11c,0xda64216b,0xc8c81dd8,0x854401f4}},	//   inig_, _لالي, _کوان_, нэне, 
   {{0xb2fc003d,0x2fc00368,0x200401d3,0x67c8013a}},	//   _དཔུང_, hnig_, ílik_, děje, 
   {{0x2369d11d,0xa9c40372,0x7ce001d5,0x24180108}},	//   _paaj_, _كۅچۉ, tеri, ьоны_, 
   {{0x2001d11e,0x2fc001a4,0x2120025c,0xdb0c00e4}},	//   _ruhi_, jnig_, _sehh_, _êkôi, 
   {{0x2001d11f,0x3328009d,0x00000000,0x00000000}},	//   _suhi_, эцэн_, --, --, 
   {{0x2001d120,0x23680de2,0xe45400db,0x00000000}},	//   _puhi_, _waaj_, _аккы, --, 
   {{0xbeb8067d,0xc094004b,0x67fc0022,0x23680009}},	//   _ndër, رجست, _tĩju, _taaj_, 
   {{0x443dd121,0x212005b1,0x247002d3,0xa2d400cd}},	//   mut_, _wehh_, _ስራሓት_, _युथ्, 
   {{0x443dd122,0xbeb8002d,0x9df83529,0x21200098}},	// [33fb0] lut_, _beëa, днат_, _tehh_, 
   {{0x20000053,0x443dd123,0x2fc00165,0x4084188b}},	//   _tuhi_, out_, anig_, _зумб, 
   {{0x443dd124,0x7534011a,0x00000000,0x00000000}},	//   nut_, תאבד_, --, --, 
   {{0x290c031c,0xdab800c6,0xab84a30d,0xdeb400c0}},	//   _afda_, وهات_, лучк, _абмы, 
   {{0x443dd125,0xd9451e8d,0x50640020,0x7f5c013c}},	//   hut_, вели, ፎርሜሽ, meqq, 
   {{0x443dd126,0x20d4069f,0x7f5c0eda,0xbeb8000f}},	//   kut_, _धडाध, leqq, _geëa, 
   {{0xea0001fb,0x9f580023,0xa3c00073,0xca3801ec}},	//   _đấm_, _nisë_, ःचा_, _ﺒﺤﺙ_, 
   {{0x7f5c0eda,0xd7c85712,0x3f980472,0x00000000}},	//   neqq, بوبه_, nkqu_, --, 
   {{0x64586c85,0x443c00d5,0x37140014,0xe70816a2}},	//   _apvi, eut_, ورکھ_, رتين_, 
   {{0x443dd127,0xa2d407b7,0xa5e80032,0x2fc0022e}},	//   fut_, _युध्, нлыҡ_, znig_, 
   {{0x443dd128,0x7f5c0140,0x53a400d1,0x2fc0ad31}},	//   gut_, keqq, ванб, ynig_, 
   {{0x8888010f,0x00000000,0x00000000,0x00000000}},	//   _קרײַ, --, --, --, 
   {{0xa2d41a04,0x443d3187,0x1dd0041c,0x2fc00fac}},	//   _युद्, aut_, तकात, vnig_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x443db876,0x7521d129,0x2fc00280,0x00000000}},	//   cut_, _ienz, tnig_, --, 
   {{0x75200399,0x3ebc1591,0xbfc01585,0x7f5c20ac}},	//   _henz, _žuta_, абск, geqq, 
   {{0x2fc000fc,0x7521d12a,0xfc700020,0xa7fc7b54}},	// [33fc0] rnig_, _kenz, _የሚገኙ_, _asıl, 
   {{0x7768014b,0xfa3402d3,0x2b940133,0x7bc001c7}},	//   _lagx, _ብሰላማ, گیرس, énun, 
   {{0x7521d12b,0x2fc0089c,0x4fe8024c,0x73f00055}},	//   _menz, pnig_, _омон_, _ṣṭra, 
   {{0x7521d12c,0x7768014b,0x09c80a94,0x69a40037}},	//   _lenz, _nagx, ाक्य, _कतही, 
   {{0x443dd12d,0xbb4021c3,0x752002d0,0xddcc00a2}},	//   zut_, речк, _oenz, ktaň, 
   {{0x443c6018,0x7520b628,0x9f44006a,0x9f540428}},	//   yut_, _nenz, êlö_, _ògòb_, 
   {{0x77680944,0x9f58026c,0x1c3800c9,0x7d5408a8}},	//   _bagx, _bisè_, _пять_, _שילד_, 
   {{0x443dd12e,0xf76c00c6,0x67c801ef,0x00000000}},	//   vut_, قاً_, dějc, --, 
   {{0x443dd12f,0x9f58007f,0xc96400a7,0x290c01f7}},	//   wut_, _disè_, _ивай, _tfda_, 
   {{0x443dd130,0xb7d401d5,0x29180124,0x48b4005b}},	//   tut_, _یولا_, _ýra_, _ищет, 
   {{0x3564e2af,0x443c0eda,0xbeb8017a,0xc764030c}},	//   трын_, uut_, _neën, _لاشى, 
   {{0x443d4df5,0x75203c3a,0xdce40882,0xe3a401d5}},	//   rut_, _eenz, ndhā, اشدی, 
   {{0x443d8ad4,0x3f8c0008,0xbeb80de2,0x7f5dadc3}},	//   sut_, ögum_, _ndëp, veqq, 
   {{0x443dd131,0x7521d132,0x77680472,0x00000000}},	//   put_, _genz, _zagx, --, 
   {{0x9f34063b,0x7f5c0eda,0x77680b6f,0x443dd133}},	//   леві, teqq, _yagx, qut_, 
   {{0x75200928,0x7f5c0140,0xadc40ca8,0x77680009}},	//   _zenz, ueqq, _ibẹr, _xagx, 
   {{0x7521d134,0xdce40a28,0x5d5447bf,0x7f5dd135}},	// [33fd0] _yenz, ddhā, лкат, reqq, 
   {{0x7f5d427b,0x442c06ea,0x9f580129,0xee74010b}},	//   seqq, _kvf_, _misé_, шлуь, 
   {{0xad24345f,0xa530001f,0x9cb59c23,0x7f5c013c}},	//   شىنى, _ተጠናቀ, دمات, peqq, 
   {{0x7f5db852,0x69c401c7,0x00000000,0x00000000}},	//   qeqq, éien, --, --, 
   {{0x1995d136,0x615402d3,0xdcf40171,0xc684132f}},	//   ладя, _ምምዕባ, _pozē, _اِ_, 
   {{0x9f59d137,0xca742cb0,0xf2d400c8,0x7768b034}},	//   _sisè_, اموش_, סעס_, _sagx, 
   {{0x4851d138,0x7521d139,0x9f5806af,0xadc401e1}},	//   مپوز, _renz, _aisé_, _nbẹr, 
   {{0x7521d13a,0x9f580296,0x6e2c0724,0x1bd42cf1}},	//   _senz, _bisé_, _älbä, _собя, 
   {{0x7521d13b,0xadc40241,0x442c01d5,0xe70800d1}},	//   _penz, _abẹr, _avf_, ختىن_, 
   {{0x77680944,0xd4140bd6,0x442c03b9,0x00000000}},	//   _wagx, льмы, _bvf_, --, 
   {{0xfbb41886,0x7521d13c,0xa8a4041b,0xa91c00d7}},	//   _आगाम, _venz, _крцк, _voľt, 
   {{0x7521d13d,0xbeb80660,0xddcc02fb,0x442c0129}},	//   _wenz, _reën, staň, _dvf_, 
   {{0x7521d13e,0x9f58002e,0xbeb805e4,0x00000000}},	//   _tenz, _gisé_, _seën, --, 
   {{0xc604009e,0xf4b003e6,0xdef80023,0x6adc000d}},	//   লীহা_, _پشتگ, _ገርካ_, _बरक़र, 
   {{0x442c0418,0x142401d5,0x9f4801e7,0x8fa40a5b}},	//   _gvf_, _ёдим, amaí_, гаве, 
   {{0x22680598,0xdd1002fb,0x7e7816a3,0xc6240154}},	//   ätkä_, výši, _šupa, _মমতা_, 
   {{0x63bc067c,0x33b400d1,0x00000000,0x00000000}},	// [33fe0] èrne, _مەھر, --, --, 
   {{0x5164815c,0x00000000,0x00000000,0x00000000}},	//   _своб, --, --, --, 
   {{0x442c022e,0x4c1400db,0x00000000,0x00000000}},	//   _xvf_, ابئس, --, --, 
   {{0xbeb8017a,0x4bd81f0d,0x00000000,0x00000000}},	//   _keël, رباد_, --, --, 
   {{0x7f580986,0x200402f0,0x00000000,0x00000000}},	//   _ñuqa, íliv_, --, --, 
   {{0xe894169c,0x68f803c7,0xe3b803e0,0xdd1000d7}},	//   иаль, نکاح_, nsır_, pýši, 
   {{0xf98403cc,0x9f580248,0x645c025c,0x00000000}},	//   انىي_, _sisé_, ħrik, --, 
   {{0xa91c01f1,0x442c01f7,0x3940008e,0x00000000}},	//   _poľs, _rvf_, анәг, --, 
   {{0x442dd13f,0xe8001414,0x00000000,0x00000000}},	//   _svf_, _लंका_, --, --, 
   {{0x9f58004a,0xa2d400dc,0xa3dc060c,0x442c0051}},	//   _visé_, _युष्, _तीज_, _pvf_, 
   {{0x291c02c4,0x9f580066,0x69c801a4,0x00000000}},	//   mbva_, _wisé_, _ijde, --, 
   {{0x86e407d6,0xbeb8017a,0x00000000,0x00000000}},	//   _йўлд, _beël, --, --, 
   {{0x442c017a,0xf6700133,0x05740116,0x236c00d7}},	//   _wvf_, _هاوخ, _ماغد, ľej_, 
   {{0x9f480597,0xb610021a,0x3ebc07f5,0x236c1155}},	//   rmaí_, _اړيک, _žuto_, žej_, 
   {{0xb97804ac,0x291c006f,0x442dd140,0x58f80327}},	//   ענלי, ibva_, _uvf_, _ཕུབས_, 
   {{0x94240075,0xa3dc0490,0xa4e401d5,0x00000000}},	//   _ئويۇ, _तीच_, _йўқк, --, 
   {{0xbeb80549,0x63bc003a,0xc6040154,0xfeb81bf4}},	// [33ff0] _geël, érnu, লীরা_, رارت_, 
   {{0x601001e4,0xbe8c0241,0x80b400cd,0x00000000}},	//   _aĥme, _aṣáj, ोपदे, --, 
   {{0x2dd80597,0x7ce001d5,0xe8000037,0x00000000}},	//   ابقة_, vеrs, _लंगा_, --, 
   {{0x3f6400f0,0x00000000,0x00000000,0x00000000}},	//   _стоб, --, --, --, 
   {{0x68e40118,0xdb140241,0x00000000,0x00000000}},	//   řidl, _ìbík, --, --, 
   {{0x6af80014,0x00000000,0x00000000,0x00000000}},	//   ھى۪س_, --, --, --, 
   {{0xcdc401a9,0x4bf800db,0x00000000,0x00000000}},	//   _таёқ, ربۅگ_, --, --, 
   {{0x69c9d141,0x888001b9,0xcc840133,0x00000000}},	//   _ejde, تیمن, _خۆمه_, --, 
   {{0xa3d80c2e,0x2d9c01ed,0x7bd9d142,0x4ab0586a}},	//   ़कन_, öveg_, _ikuu, _мөшр, 
   {{0xd4f413c6,0xbeb80660,0xd6c4825e,0xb86400ec}},	//   ияны, _reël, лиққ, _ٽائو, 
   {{0x7bd80d04,0xbeb80af9,0x00000000,0x00000000}},	//   _kkuu, _seël, --, --, 
   {{0x96740024,0x00000000,0x00000000,0x00000000}},	//   _выкі, --, --, --, 
   {{0x7bd84b44,0x59a8012c,0x91e4011c,0x7e7800d7}},	//   _mkuu, _कतार, иоме, _šupn, 
   {{0x463800c8,0x4611d143,0x7bc002fb,0x52c400e1}},	//   _יענע, _بوور, énuj, _लखीस, 
   {{0x7bd89bb6,0x3945d144,0x00000000,0x00000000}},	//   _okuu, igns_, --, --, 
   {{0x7bd80337,0xbeb80ea0,0xa6500345,0x00000000}},	//   _nkuu, _teël, _بێیت, --, 
  
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [34000] --, --, --, --, 
   {{0x7bd9d145,0xbeb80d47,0x09c8009e,0xe05400f2}},	//   _akuu, _geëm, _লীনা, _گیفت_, 
   {{0xcb681515,0xdb140209,0xc0000276,0x67c800bc}},	//   каже_, şaýy, _мпэк, dějn, 
   {{0x9f4800d8,0x7ff4210e,0xe8000037,0x00000000}},	//   rmaã_, _پسپا, _लूगा_, --, 
   {{0xaa58179e,0x68340092,0x00000000,0x00000000}},	//   التا_, _አይሁድ, --, --, 
   {{0x7bd82ad1,0x2d8c00c5,0xc864007b,0x00000000}},	//   _ekuu, _õde_, لطبي, --, 
   {{0xd1c8001f,0x00000000,0x00000000,0x00000000}},	//   _በጌታ_, --, --, --, 
   {{0x25a05725,0xc7c44c70,0xbb41d146,0x893400db}},	//   _œil_, јски, _меск, _چعاا, 
   {{0xfaa1d147,0x093400e3,0xc6e401ec,0xd7e800db}},	//   _дато, _نراج, шікп, دويۇ_, 
   {{0x1658129e,0x00000000,0x00000000,0x00000000}},	//   اسيک_, --, --, --, 
   {{0xddcc0276,0x48b40c9e,0xdcf40153,0x5d78010f}},	//   lvaţ, _тщат, _dozė, אָרנ, 
   {{0x69d99fa6,0x245400db,0x233800b1,0x00000000}},	//   love, _ۇنتس, ыпмы_, --, 
   {{0xbeb80022,0x00000000,0x00000000,0x00000000}},	//   _peëm, --, --, --, 
   {{0xe3a404d3,0xb62c0150,0x4de4000d,0x00000000}},	//   _گشتی, _ﺒﺸ_, _जीलै_, --, 
   {{0xd24c006c,0x69d80311,0x3518008f,0x249801e3}},	//   وچی_, iove, _יוגנ, ärmd_, 
   {{0x34f80302,0xa7fc03ee,0xe8480023,0x443c00a2}},	//   _בהוד, _arız, _ዘይተነ, mrt_, 
   {{0x69d9d148,0x443c01ab,0x41e40006,0xdd58009d}},	// [34010] kove, lrt_, _віна, лаач_, 
   {{0x63bc5592,0x7bd9d149,0x443dd14a,0x629c043b}},	//   lisn, _skuu, ort_, myso, 
   {{0x69d9d14b,0x2b1402e3,0x629ca38b,0x443c0036}},	//   dove, _ịkọ_, lyso, nrt_, 
   {{0x443c3c65,0x63bd0ef3,0x67c8012c,0x69d878d6}},	//   irt_, nisn, dějo, eove, 
   {{0x443c0f2a,0x629dd14c,0x69d809d3,0x00000000}},	//   hrt_, nyso, fove, --, 
   {{0x69d9d14d,0x63bd7147,0xa7fc013d,0xe9d80006}},	//   gove, hisn, _grız, акі_, 
   {{0x63bdd14e,0x260c05f9,0x3158008f,0x394407de}},	//   kisn, _डूबी_, ייגן_, rgns_, 
   {{0x63bd9f2c,0x7bd9d14f,0xa7fc0139,0x443c0175}},	//   jisn, _ukuu, _krıy, drt_, 
   {{0x443c546f,0x69d9d150,0x068000ee,0xdb0c002e}},	//   ert_, bove, згын, ŋkóo, 
   {{0x558831d5,0x8984030d,0xb6a001a9,0x00000000}},	//   убом_, _лкуç, йиқл, --, 
   {{0x9f580270,0x443c0072,0x00000000,0x00000000}},	//   _aisí_, grt_, --, --, 
   {{0x63bdd151,0x00000000,0x00000000,0x00000000}},	//   gisn, --, --, --, 
   {{0x443d31dd,0x113812c4,0x63bc067c,0xe800012d}},	//   art_, лявы_, èrna, _लूटा_, 
   {{0x50b4e8a7,0xcad4011a,0x443c01ef,0x00000000}},	//   бсбу, מורת_, brt_, --, 
   {{0x63bdd152,0x443c1b24,0xa7fc03ee,0x80d80037}},	//   bisn, crt_, _arıy, _मुदइ, 
   {{0xdb18092e,0x63bdd153,0x2499557a,0xbeb8017a}},	//   nnwä, cisn, ärme_, _geëk, 
   {{0x69d9d154,0xdb18002f,0x939401d3,0x0dc922d4}},	// [34020] yove, inwä, _نجکا, глай_, 
   {{0x69d9d155,0xa7fc03b9,0x00000000,0x00000000}},	//   xove, _qrız, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x42500133,0x69d802d0,0x9a7c0092,0x4aa8c893}},	//   _بنیر, wove, _ሩፋኤል_, лкен_, 
   {{0xca5403b7,0xdb5802bf,0xa7fc0139,0x09e4022e}},	//   стењ, рює_, _grıy, бодн, 
   {{0x443c9d34,0x3b180724,0xddcc0311,0x63bd0de6}},	//   yrt_, ıqqa_, rvaţ, zisn, 
   {{0x250807d6,0x00000000,0x00000000,0x00000000}},	//   یردی_, --, --, --, 
   {{0xa6141b8c,0x37a591fe,0x69d9d156,0x63bdd157}},	//   омич, йтын_, sove, xisn, 
   {{0x69d9d158,0x08880032,0x443c0142,0x00000000}},	//   pove, _әбей_, wrt_, --, 
   {{0x443c0427,0x63bdd159,0x629dd15a,0xe5b40006}},	//   trt_, wisn, vyso, ійны, 
   {{0x6d5dd15b,0x63bdd15c,0xf64c130e,0x629c0368}},	//   _mbra, tisn, وئی_, wyso, 
   {{0x443dd15d,0x629c023a,0x572400f7,0xd3f000f1}},	//   rrt_, tyso, _ۇرۇق, وړيد, 
   {{0x63bc9ac0,0x443c0175,0xdb080267,0xb7d41fae}},	//   risn, srt_, _umeå, _اونا_, 
   {{0x629dd15e,0xc2e4006c,0x63bdd15f,0x601001e4}},	//   ryso, _қўйи, sisn, _aĥma, 
   {{0x63bcdb08,0xbeb80ea0,0x9f4800a2,0x00000000}},	//   pisn, _teëk, nmaç_, --, 
   {{0x02a40ec4,0x3435d160,0x629c00c7,0x63bc036e}},	//   _гром, _اسود_, pyso, qisn, 
   {{0x9f580589,0x6d5dd161,0x7ee51af5,0x00000000}},	// [34030] _aisã_, _bbra, сцве, --, 
   {{0x6d5c01ab,0xb8f8031c,0x660400e4,0x9f48010b}},	//   _cbra, _རྙ_, _éiku, kmaç_, 
   {{0x6d5dd162,0x5f940262,0x9f200131,0xefe80014}},	//   _dbra, _динт, _يۈسۈ, _گٹَو_, 
   {{0xc61c0183,0xb06801c0,0x5f8001ec,0xdea007d6}},	//   _দিনা_, _урьж_, _تۇرە, _قیزی, 
   {{0xeb9179a9,0x6d5c0334,0x2b4000d8,0x99f400d4}},	//   عظم_, _fbra, óica_, оякі, 
   {{0x6d5c00a3,0xdb180142,0x00000000,0x00000000}},	//   _gbra, ciwî, --, --, 
   {{0xa3d81533,0x319c00c8,0x9164004d,0x00000000}},	//   ़का_, רבונ, _hộ_, --, 
   {{0x6d5c5cd5,0xd7080a8f,0xd66905b8,0x6a1400db}},	//   _zbra, шние_, لمبو_, زبۇر, 
   {{0xbeb82a28,0x6ffc01ab,0x203c02d3,0x7e7801a6}},	//   _beëi, _dōch, _ክግበረ, _šupj, 
   {{0xdcf400da,0x9f580ffb,0x6d5c05b1,0xd7889528}},	//   _nozī, _lisà_, _xbra, انکو_, 
   {{0xd3891e13,0xe970313e,0x91640208,0x53c808e1}},	//   айне_, _سۇيد, _lộ_, игом_, 
   {{0xbeb8017a,0x4f9c0092,0xc4800f06,0x257800e5}},	//   _teëh, _ቀሪዎቹ_, флюк, vülő_, 
   {{0xddcc01fa,0x6b6008a5,0xd62800f3,0x00000000}},	//   zvaš, _hágæ, _толе_, --, 
   {{0xbeb81af3,0xd4a40075,0x25ac01ab,0x00000000}},	//   _geëi, _милй, chdl_, --, 
   {{0xfc640023,0xd6d40248,0x00000000,0x00000000}},	//   _ደጋጊሙ_, _ìṣiṣ, --, --, 
   {{0x6d5c77d9,0xa2d41cb7,0xbfc80075,0x916401fb}},	//   _sbra, _युक्, لاقە_, _bộ_, 
   {{0x9abc002e,0x8d1807d2,0x6b6003b2,0xa7fc0790}},	// [34040] _deŋk, لزار_, _lágæ, _isıt, 
   {{0xd1b80014,0x63a40003,0xddcc0010,0x257801d3}},	//   _خابا_, _ċini, tvaš, pülő_, 
   {{0x4c69d163,0x4c140145,0x316c0419,0x409000e5}},	//   риен_, زباس, ôdzu_, _ہلیر, 
   {{0xfb800139,0x6830007b,0xddcc00d7,0xe08801f7}},	//   дышн, _lódá, rvaš, _اَٽو_, 
   {{0x98a40100,0xbf9801fb,0x6d5c01ab,0xd1f40092}},	//   _delč_, _kiên, _tbra, _ገዝቶ_, 
   {{0x6d5cd8f7,0x00000000,0x00000000,0x00000000}},	//   _ubra, --, --, --, 
   {{0x99389702,0xfce02be5,0xbf980051,0x00000000}},	//   сячу_, _жоро, _miên, --, 
   {{0x2d99d164,0x3ebc05ce,0x2fc1d165,0xbf98004d}},	//   _hore_, _žuti_, niig_, _liên, 
   {{0x2d981f4c,0xa94400fb,0x00000000,0x00000000}},	//   _kore_, _ндаһ, --, --, 
   {{0x2d99d166,0x7d18009b,0x9f5803b2,0x39400137}},	//   _jore_, _đusk, _misá_, _онуг, 
   {{0x2d99d167,0x7d7802e4,0xdcf400e2,0x2fc0007c}},	//   _more_, בניו, _rozī, kiig_, 
   {{0x2d99d168,0xbeb8017a,0x0c6c0092,0x00000000}},	//   _lore_, _geëw, ቶቡሶች_, --, 
   {{0x77a40bc9,0xdcf4005f,0x2d980ca8,0xbf98ce3e}},	//   _uñxa, _pozī, _oore_, _biên, 
   {{0xbf980261,0x2d9881ec,0xe10000eb,0x00000000}},	//   _ciên, _nore_, ্রসহ_, --, 
   {{0x6569d169,0x9f5819f5,0x9abc00e8,0xe4481075}},	//   medh, _pisà_, _peŋk, _العى_, 
   {{0x64485088,0x02a001f2,0x6568044e,0x67c8013a}},	//   mudi, _apụọ, ledh, dějk, 
   {{0xdea0036b,0x9f5804cc,0x2d982517,0x00000000}},	// [34050] ریسی, _visà_, _bore_, --, 
   {{0x2d99d16a,0x6569d16b,0x4085b300,0xbf98004d}},	//   _core_, nedh, _думб, _giên, 
   {{0x2d99d16c,0x2130036e,0x00000000,0x00000000}},	//   _dore_, mazh_, --, --, 
   {{0x6569d16d,0x2fc001e4,0x64480393,0x2131d16e}},	//   hedh, ciig_, iudi, lazh_, 
   {{0x6569d16f,0x2d99d170,0x6449d171,0xbeb8002e}},	//   kedh, _fore_, hudi, _ndëx, 
   {{0x2d99d172,0x6568069c,0x21300023,0x4ef80375}},	//   _gore_, jedh, nazh_, _להרו, 
   {{0x64481486,0x65680857,0x98a4013a,0x00000000}},	//   judi, dedh, _telč_, --, 
   {{0x2d9808ad,0x644900ae,0x6568020c,0x48c000c7}},	//   _zore_, dudi, eedh, хәуа, 
   {{0xff5c006a,0x6569d173,0xf968084c,0xba740214}},	//   _mbî_, fedh, _врей_, _بازت, 
   {{0x6569d174,0x7bc9d175,0x34a00364,0x6449d176}},	//   gedh, lngu, дгоҳ, fudi, 
   {{0xbf9807ae,0x6449d177,0xbeb8257d,0x7bc80051}},	//   _riên, gudi, _geëv, ongu, 
   {{0x7bc8e396,0x656801ab,0xbf98004d,0x569402e8}},	//   nngu, aedh, _siên, _нает, 
   {{0x21300a2e,0x7bc9d178,0x6569d179,0x6449d17a}},	//   fazh_, ingu, bedh, audi, 
   {{0x64480e8a,0x7bc806a3,0x65680214,0x2130036e}},	//   budi, hngu, cedh, gazh_, 
   {{0x2d99d17b,0x7bc8003e,0xfbd80864,0x2fc00165}},	//   _rore_, kngu, यकाम, tiig_, 
   {{0xc0000e92,0x2d98228f,0xc438011a,0xc0e000d8}},	//   епск, _sore_, _התקי, хоск, 
   {{0x2d983b08,0xa3d80034,0xc24000c7,0x21300165}},	// [34060] _pore_, ़कर_, _знык, bazh_, 
   {{0xc27813e2,0x7bc9d17c,0x73c40184,0x3f8c008c}},	//   _פריי, engu, _хәүе, ögur_, 
   {{0x2d980c58,0x1d1800d6,0xcb09d17d,0x2fc0000d}},	//   _vore_, юють_, ميان_, piig_, 
   {{0x7bc9d17e,0x2d98cf35,0x6569d17f,0x00000000}},	//   gngu, _wore_, zedh, --, 
   {{0x2d99d180,0x6569d181,0xbeb80ea0,0x6449d182}},	//   _tore_, yedh, _seëv, zudi, 
   {{0x7bc9d183,0x00000000,0x00000000,0x00000000}},	//   angu, --, --, --, 
   {{0x6449b419,0x6568002b,0x67d40117,0x00000000}},	//   xudi, vedh, моку, --, 
   {{0x8b640a81,0x6449d184,0x7e780306,0xa7fc1b0d}},	//   _عازم, vudi, _šupi, _asır, 
   {{0x6569d185,0x6449d186,0x7c3800b0,0x00000000}},	//   tedh, wudi, _āuri, --, 
   {{0xb524009e,0xb520005a,0x8914010a,0x00000000}},	//   _মাউথ_, ньюк, _хьац, --, 
   {{0xaac00574,0x644805a7,0xe3b871e1,0x7d780375}},	//   _शेतक, uudi, msız_, זניו, 
   {{0x6449d187,0x656804fb,0x9f8801e1,0x21300489}},	//   rudi, sedh, _lóòs_, wazh_, 
   {{0x1671c3e4,0x6449d188,0x98a400da,0x6569d189}},	//   _ақыр, sudi, _ielā_, pedh, 
   {{0x6449d18a,0xddcc068f,0xe3b88e8e,0xfde805f9}},	//   pudi, ztał, nsız_, _जींस_, 
   {{0xf1b005d9,0xddcc0034,0x64482702,0x03c40116}},	//   اءُ_, ytał, qudi, _нсим, 
   {{0x2130044e,0xe3b83bc1,0x2d9c0267,0x7bc80051}},	//   sazh_, hsız_, öven_, xngu, 
   {{0x63add18b,0xe3b80e51,0xff2801b9,0x333c123b}},	// [34070] _ilan, ksız_, _қўни_, _התחמ, 
   {{0x63add18c,0x7bc80649,0xc32c0131,0xc05824d8}},	//   _hlan, wngu, _جەڭ_, _лім_, 
   {{0x63add18d,0x7bc9d18e,0x2258000f,0x5158011a}},	//   _klan, tngu, ltsk_, _וכתו, 
   {{0x7bc9d18f,0x63ac020c,0xa14801ed,0x3ebc39ae}},	//   ungu, _jlan, _اسکے_, _žutu_, 
   {{0x63ad4a1b,0x7bc968e0,0x2258fbc8,0xe3b82c87}},	//   _mlan, rngu, ntsk_, fsız_, 
   {{0x63add190,0xddcc006d,0x7bc9198d,0xdce40118}},	//   _llan, stał, sngu, lehč, 
   {{0x7bc87fc3,0x26d80790,0xfafc0171,0x00000000}},	//   pngu, şrol_, _žīdu_, --, 
   {{0x22580280,0xbeb80af9,0x63add191,0x255801c6}},	//   ktsk_, _feët, _nlan, үрээ_, 
   {{0xbeb8017a,0x2a640208,0xe3b803e3,0x00000000}},	//   _geët, _gpmb_, bsız_, --, 
   {{0x63add192,0xd4a400d1,0xdecc0023,0xe3b803b9}},	//   _alan, диой, ኣልና_, csız_, 
   {{0x298801c0,0x9f580166,0x782400db,0x00000000}},	//   _эсто_, _kisä_, _رعال, --, 
   {{0x63add193,0xddcc0210,0x00000000,0x00000000}},	//   _clan, ltań, --, --, 
   {{0x36e80eff,0x05940451,0x998c0010,0x63a4025c}},	//   _اراپ_, _ڪانگ, _zveš_, _ċint, 
   {{0x63a40227,0x659402d5,0x9f58005b,0xf7700133}},	//   _ŋint, _пачу, _lisä_, _زاڵ_, 
   {{0x63add194,0xc0e1b688,0x0595d195,0x453000db}},	//   _flan, ворк, _تانگ, _شىير, 
   {{0x63add196,0x00000000,0x00000000,0x00000000}},	//   _glan, --, --, --, 
   {{0x356c0023,0x4e040fbe,0x00000000,0x00000000}},	// [34080] _ድኻታት_, дзаб, --, --, 
   {{0x63ac01b9,0xddcc033f,0x30ac00eb,0x00000000}},	//   _zlan, jtań, _ঐশীস, --, 
   {{0x63add197,0x2a6406d1,0x78a0005b,0xe3b803e0}},	//   _ylan, _spmb_, jynv, vsız_, 
   {{0x09d40b7c,0x160c0073,0x800800e5,0x0ae803c5}},	//   धव्य, सदार_, _گریہ_, одей_, 
   {{0xe3b80d9c,0xdd8c0131,0x9f58013d,0xe91812fa}},	//   tsız_, _گۈل_, _disä_, полі_, 
   {{0xbb340166,0x00000000,0x00000000,0x00000000}},	//   _çänç, --, --, --, 
   {{0xf98c0517,0x98a40618,0xe3b83e67,0x8bf801a9}},	//   شبو_, _pelā_, rsız_, _xo阻a, 
   {{0x8b640228,0xc6a4470c,0x6844001f,0xe3b8e333}},	//   _تاسم, дрои, _ከክርስ, ssız_, 
   {{0xf76dd198,0x0568147e,0xe3b80baa,0x63add199}},	//   شاي_, ојни_, psız_, _rlan, 
   {{0x63add19a,0xc9840f17,0xe3b86656,0x00000000}},	//   _slan, _تشري, qsız_, --, 
   {{0x98a40618,0xc794b42d,0xc8c802f2,0x00000000}},	//   _telā_, _орды, _بوان_, --, 
   {{0x63ac022e,0x00000000,0x00000000,0x00000000}},	//   _qlan, --, --, --, 
   {{0x63ac0030,0xbeb80ea0,0xc1780212,0x68e82c1e}},	//   _vlan, _leër, оїв_, _hydd, 
   {{0xa4d410f5,0x63ac4725,0x2258002d,0x2d9da5af}},	//   _полі, _wlan, rtsk_, övel_, 
   {{0x63ac176f,0x65780ffb,0xa0c400b2,0xdecc02d3}},	//   _tlan, _iavh, ريرو, ኣውን_, 
   {{0x63add19b,0x65780084,0x68e80042,0x24587221}},	//   _ulan, _havh, _mydd, mém_, 
   {{0xb27447b6,0x2459d19c,0x68e800ed,0xddcc007f}},	// [34090] _алыш, lém_, _lydd, ytań, 
   {{0xbeb80af9,0x6578022e,0x290c022e,0x68e803b2}},	//   _beër, _javh, _ngda_, _oydd, 
   {{0x61e5d19d,0x65781aa1,0x24580316,0x9f3401ce}},	//   _ikhl, _mavh, ném_, _пені, 
   {{0x6579d19e,0x290dd19f,0x5a3457aa,0x7e7804a7}},	//   _lavh, _agda_, ендт, _šupu, 
   {{0x3f89d1a0,0x2459d1a1,0x9f0406c2,0x00000000}},	//   _incu_, hém_, _سوسو, --, 
   {{0x68e80f7b,0x6579d1a2,0x24580316,0x290c0327}},	//   _bydd, _navh, kém_, _cgda_, 
   {{0xbeb80942,0x68e80042,0x245800d7,0x00000000}},	//   _geër, _cydd, jém_, --, 
   {{0x69c404d1,0x68e80cfd,0x9b4401d9,0x49700116}},	//   éier, _dydd, _سنطو, вләс, 
   {{0x92e82f8b,0xddcc0227,0x6578014f,0x68e801a8}},	//   _গল্প_, ptań, _bavh, _eydd, 
   {{0x68e80cfd,0xa5e80032,0x569400c7,0x24580d10}},	//   _fydd, млыҡ_, даҩт, fém_, 
   {{0x65793b8b,0xf77121be,0x68e80042,0xe3b803e0}},	//   _davh, _لاش_, _gydd, rpın_, 
   {{0x61e5d1a3,0x96b800f3,0x5274072c,0x00000000}},	//   _akhl, _нулу_, нугу, --, 
   {{0x7778003a,0x1544004e,0x00000000,0x00000000}},	//   mdux, _зелм, --, --, 
   {{0x3f880ba3,0x6579d1a4,0x00d80150,0x24580118}},	//   _ancu_, _gavh, _ﺃﺜﺒﺘ, bém_, 
   {{0x2459d1a5,0xd011d1a6,0x3444009d,0xa5f80244}},	//   cém_, الر_, _юүни_, _تووڕ_, 
   {{0xddcc0054,0x7779d1a7,0x74b4014b,0x27e039e2}},	//   ntaņ, ndux, _нуқс_, čing_, 
   {{0x65780084,0x0d843e5b,0x7659d1a8,0xc7b0010f}},	// [340a0] _yavh, нлан, ntuy, אבן_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x0b4462bd,0xa1c00220,0x8b69d1a9,0x76580051}},	//   енен, _тұрд, зиев_, htuy, 
   {{0x7659d1aa,0x7cd41291,0x00000000,0x00000000}},	//   ktuy, رونز_, --, --, 
   {{0x68e9d1ab,0x24585f28,0x5bc40691,0x67f00588}},	//   _sydd, zém_, ختلف, _ẽjoa, 
   {{0x68e803a2,0x6e248880,0x7778003a,0x245801d3}},	//   _pydd, mpib, edux, yém_, 
   {{0x65780943,0xd90cd87e,0xf8c000cd,0x00000000}},	//   _ravh, زین_, _वेदय, --, 
   {{0x6579d1ac,0x24580316,0x6e24003a,0x3e440023}},	//   _savh, vém_, opib, _ንርእይ, 
   {{0x4aa8006c,0x765940d7,0x68e800a9,0x6578006f}},	//   _экан_, gtuy, _wydd, _pavh, 
   {{0x2459d1ad,0x290c0036,0x68e938b0,0x6e2403b2}},	//   tém_, _ugda_, _tydd, ipib, 
   {{0x6579d1ae,0x76580083,0xf480013e,0x77780381}},	//   _vavh, atuy, гуян, bdux, 
   {{0x38c8bc28,0x2459d1af,0x65780084,0x5ef400dc}},	//   _عالی_, rém_, _wavh, ्धम्_, 
   {{0x657806d6,0x7658004d,0xf770010f,0xd5c00055}},	//   _tavh, ctuy, _תקנ_, _svāś_, 
   {{0x657803a1,0x659400f0,0x00000000,0x00000000}},	//   _uavh, _јаку, --, --, 
   {{0xdce402b1,0xf0d401c6,0x9f340006,0x00000000}},	//   kehā, гжрэ, кеві, --, 
   {{0x6d580268,0x88500023,0x442cce44,0x00000000}},	//   òvan, _ዘይተሰ, _iwf_, --, 
   {{0x5d5586ba,0xbd6800d8,0x00000000,0x00000000}},	// [340b0] ккат, зрее_, --, --, 
   {{0x61e4009a,0x442c01a4,0x6e44036b,0x00000000}},	//   _ukhl, _kwf_, انلم, --, 
   {{0x7c6400c6,0xdb3406ed,0xdc5406ed,0x00000000}},	//   عائل, веењ, твењ, --, 
   {{0x6449d1b0,0x3f8803e0,0x76580784,0xd9a803ce}},	//   irdi, _uncu_, ytuy, कस्ट, 
   {{0x442c00ca,0x64480112,0x6bd4036b,0x98a400c0}},	//   _lwf_, hrdi, دتلر, _melą_, 
   {{0x18683edf,0xdcec510c,0xaac00073,0xdef80240}},	//   даки_, şkın, _शेळक, _ገርና_, 
   {{0xbdd8007f,0x23e00b6d,0xa3c00073,0x00000000}},	//   _avèg, नवाद, ंफा_, --, 
   {{0x765803e0,0x67c8013a,0x00000000,0x00000000}},	//   ttuy, dějs, --, --, 
   {{0x6449d1b1,0x77780381,0xe63401c6,0xdb18002f}},	//   erdi, rdux, лхээ, inwü, 
   {{0x7659d1b2,0xeaf80214,0x6448022e,0x442c0051}},	//   rtuy, _سرقت_, frdi, _bwf_, 
   {{0x6ef800d2,0x7659d1b3,0x64480e3c,0xdb080022}},	//   _kúbí, stuy, grdi, _imeñ, 
   {{0x442cbd04,0x76580113,0xd2f801c6,0x67d40354}},	//   _dwf_, ptuy, дэгч_, _йоху, 
   {{0x6449d1b4,0x76580784,0xa87800cf,0x2d9c00e5}},	//   ardi, qtuy, _жөөт_, övek_, 
   {{0x68e585e5,0x00000000,0x00000000,0x00000000}},	//   şide, --, --, --, 
   {{0x442c1529,0xcfa921a1,0x00000000,0x00000000}},	//   _gwf_, وارم_, --, --, 
   {{0x6ef80241,0x2c18000d,0x00000000,0x00000000}},	//   _núbí, _बंबू_, --, --, 
   {{0xcad0063f,0x8e091f22,0xbea000db,0x63bc0200}},	// [340c0] hịrị, днав_, аатк, ërne, 
   {{0x6e240393,0x7aec0306,0xdb180166,0x00000000}},	//   rpib, _úcty, hiwä, --, 
   {{0x9f48010e,0x00000000,0x00000000,0x00000000}},	//   lmaý_, --, --, --, 
   {{0x8fa41ece,0x6e25d1b5,0xfce000d4,0x00000000}},	//   _раме, ppib, шохо, --, 
   {{0xba707092,0xdb0801c3,0xdce402b1,0xddcc01ef}},	//   لاوت, _smeò, rehā, htař, 
   {{0xdbe401e1,0x6449d1b6,0x00000000,0x00000000}},	//   _lèèy, yrdi, --, --, 
   {{0x2815d1b7,0x5f180e5b,0x8c441d39,0xdb200419}},	//   دوبس, युक्_, _јебе, štár, 
   {{0x6448098d,0x442c00ca,0xdb080022,0xa774020f}},	//   vrdi, _rwf_, _emeñ, улич, 
   {{0x442dd1b8,0xda651f80,0xcad002e3,0xe9444e10}},	//   _swf_, _مالي, rịsị, _مرضی, 
   {{0x64480fb7,0xd90c015e,0x98a40064,0xe3b80205}},	//   trdi, _فیه_, _selą_, rpım_, 
   {{0x644806af,0xcad0063f,0x47f029db,0xb8f403d4}},	//   urdi, pịsị, _күкр, _সৰ_, 
   {{0x442c01a4,0x6448031c,0x00000000,0x00000000}},	//   _vwf_, rrdi, --, --, 
   {{0x442dd1b9,0xdcf40219,0x048800f2,0x00000000}},	//   _wwf_, _razč, سخگو_, --, 
   {{0x442c03cb,0x972000e5,0x00000000,0x00000000}},	//   _twf_, _پہیو, --, --, 
   {{0x999801f1,0x645c004e,0x313448bc,0x00000000}},	//   _ísť_, àrid, реср, --, 
   {{0x02a405c1,0x33b400d1,0x2bc4a786,0x00000000}},	//   _аром, _نەپر, लोमा, --, 
   {{0x9df98c08,0xd50400c7,0x7bc004cc,0x00000000}},	// [340d0] енат_, _ижәҩ, ènum, --, 
   {{0x65a401e1,0x6db4004e,0x00000000,0x00000000}},	//   _tòhu, айуу, --, --, 
   {{0xf190037e,0xdbe401e1,0xbb340166,0x00000000}},	//   _rt願_, _yèèy, _çäkç, --, 
   {{0x31d800cc,0x9b4402c9,0x9ad400d4,0x00000000}},	//   _দীপশ, انشو, люлі, --, 
   {{0xeab0157c,0xfec82099,0x00000000,0x00000000}},	//   يعه_, _آبجو_, --, --, 
   {{0x31b40510,0xf9c402e8,0x2bc428fe,0x00000000}},	//   _täze_, ъщен, लोबा, --, 
   {{0xac94e88a,0x2d1804fb,0x00000000,0x00000000}},	//   _карш, _شکلک_, --, --, 
   {{0xddcc0083,0x8ca00c75,0x4adc0037,0x00000000}},	//   kuaŋ, _دەمو, _फुकव, --, 
   {{0x2da8010e,0x59d800c0,0x00000000,0x00000000}},	//   _öweý_, _здаў_, --, --, 
   {{0xcad001f2,0x6aa40221,0x00000000,0x00000000}},	//   pịrị, äife, --, --, 
   {{0xe619a1d2,0x53a5947a,0xdbe40241,0x00000000}},	//   ндө_, ганб, _pèèy, --, 
   {{0xddcc04b9,0xb8040214,0x1b10015b,0x934402dd}},	//   jvaž, _شباه, ারকে_, ынме, 
   {{0xc22001d3,0x00000000,0x00000000,0x00000000}},	//   یکیو, --, --, --, 
   {{0x4638010f,0xd7600244,0x75800345,0x320c0108}},	//   _טענע, _ئۆکی, _ئیدم, ödy_, 
   {{0xc5f0011a,0x2c1806e3,0x00000000,0x00000000}},	//   _הדג_, _बंधू_, --, --, 
   {{0x645c00f7,0x1fb5d1ba,0xc4d0011a,0x00000000}},	//   àrie, асур, _לגו_, --, 
   {{0x4d65d1bb,0xfc94001f,0x660c05d1,0xfc70001f}},	// [340e0] лкав, _ለሚገኙ_, _ülkü, _ከሚገኙ_, 
   {{0xd1b0036b,0x00000000,0x00000000,0x00000000}},	//   _ایسک, --, --, --, 
   {{0xc984967a,0x10a40c68,0x00c401f4,0x00000000}},	//   ғули, _синн, _блэк_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbb405df2,0x9f58b61d,0x21b803e6,0xaa9400cf}},	//   сечк, _risø_, _سپێک_, рилч, 
   {{0xf98c00cf,0x8274008f,0xc0cc0092,0x00000000}},	//   كبى_, טענע_, _ባጭሩ_, --, 
   {{0xc86400d1,0x6aa40036,0x993800d4,0x9c5800f3}},	//   утли, äifb, тячу_, _ишту_, 
   {{0x3a20b7c3,0xba20010b,0xe3b803e0,0x803400df}},	//   шмәг, шдәк, rpık_, אנקע_, 
   {{0x27e40158,0x889001a9,0x00000000,0x00000000}},	//   romn_, риқх, --, --, 
   {{0x33200098,0x998c0139,0xa5f80063,0xddcc02f0}},	//   _afix_, _iteş_, ђену_, zvaž, 
   {{0xc7640c50,0x35f41e95,0x356401c0,0x27e40010}},	//   _ماشى, دريد_, урын_, pomn_, 
   {{0xdbe4007f,0xd6c40133,0x7f880139,0x236c00df}},	//   _pèéy, امیی, _möqä, ĵejo_, 
   {{0x6594771e,0xdcf400da,0xd25005d9,0xbee00c4c}},	//   _валу, _mazā, ينٽ_, _कुंभ_, 
   {{0x44a4059e,0x348000d1,0x629801e1,0x00000000}},	//   _محبّ, شۇۋې, _àwom, --, 
   {{0x35180bd9,0x7de40046,0x3f65d1bc,0x00000000}},	//   _אוונ, ңізд, лтаб, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x443c6853,0xb818c725,0x6e9401ee,0xddcc0153}},	// [340f0] lst_, _पूनम_, биту, rvaž, 
   {{0x443dd1bd,0x2b440142,0xa1e801d3,0x00000000}},	//   ost_, _admc_, _جذبے_, --, 
   {{0x998c03ee,0x9f4800c6,0x5c740354,0xdcf40171}},	//   _ateş_, llaí_, рлет, _bazā, 
   {{0x443dd1be,0x9f4800ae,0x00000000,0x00000000}},	//   ist_, olaí_, --, --, 
   {{0x443c097d,0x236802d3,0xdb080332,0x9f48007b}},	//   hst_, _mbaj_, _bleá, nlaí_, 
   {{0x443dd1bf,0x9f4807e4,0xd82495be,0xdc5450f0}},	//   kst_, mmañ_, адки, _پرسک, 
   {{0x443dd1c0,0x998c0139,0x9f490b10,0x31591256}},	//   jst_, _eteş_, lmañ_, טיגן_, 
   {{0x443c32be,0xb8740092,0x00000000,0x00000000}},	//   dst_, _በክፍለ_, --, --, 
   {{0x443dd1c1,0x9594177b,0x649c01e4,0x68e408a9}},	//   est_, ашні, bɩik, ğida, 
   {{0x7bc9d1c2,0x27e0341a,0x443dd1c3,0x05a40a8f}},	//   ligu, čina_, fst_, ивый_, 
   {{0xb4acad78,0xd1300014,0x62980241,0xaa0401f7}},	//   ओने_, ۪مس_, _àwoj, _اِلي, 
   {{0x888800c8,0xa8a40228,0x9f49d1c4,0x28a400f7}},	//   _שרײַ, _урук, hlaâ_, _ушуг, 
   {{0x443d62b8,0x68fc03f2,0xb1440023,0x23680210}},	//   ast_, _úrdr, _ንምውዳ, _dbaj_, 
   {{0x443dd1c5,0x7bc9d1c6,0xd130036b,0x98a8033f}},	//   bst_, higu, تمس_, _कथाए, 
   {{0xaca402e3,0x7bc9d1c7,0x9f48007b,0x31b4008e}},	//   _kwụr, kigu, alaí_, _cäza_, 
   {{0x09d00882,0x9f48007b,0x7bc9d1c8,0xc0ec0092}},	//   _तद्य, blaí_, jigu, _ቁፋሮ_, 
   {{0x7bc9d1c9,0x8e7401b9,0x9f4800ae,0x00000000}},	// [34100] digu, шувч, claí_, --, 
   {{0xfb8400f2,0xdcf400ef,0x00000000,0x00000000}},	//   یدنی, _sazā, --, --, 
   {{0x7bc882ff,0x8c7800a7,0xcb084fca,0xa7fc0139}},	//   figu, ъщат_, چيان_, _uqıg, 
   {{0x4aa802de,0x7bc9d1ca,0xcb0878f5,0xaca40521}},	//   ккен_, gigu, نيان_, _nwụr, 
   {{0x49a40184,0x8a042c0b,0xbf980165,0x0ab808de}},	//   ғыҙғ, азде, _viêt, خطاب_, 
   {{0x3eac037e,0x7bc8004e,0x9f4803b2,0x00000000}},	//   øgte_, aigu, lmað_, --, 
   {{0xb9c00491,0x6d5c7236,0x8b95aedc,0xbf98004d}},	//   تقوي, _icra, _крач, _giês, 
   {{0x443dd1cb,0x47840124,0x37a40220,0x00000000}},	//   vst_, рыкб, итын_, --, 
   {{0x443dd1cc,0x3b05d1cd,0xa50000dc,0x9f48fccf}},	//   wst_, _вето_, ैश्च_, llaã_, 
   {{0x443dd1ce,0x6b8003cb,0x36840395,0x00000000}},	//   tst_, _hamg, рсън_, --, 
   {{0x443dd1cf,0x6b81d1d0,0x69c80135,0x19b86c48}},	//   ust_, _kamg, _imde, _суть_, 
   {{0xaca401f2,0x05740075,0x6b81d1d1,0x03c5b276}},	//   _gwụr, _چاغد, _jamg, рсом, 
   {{0x443dc676,0xc6741d93,0xddcc02fb,0x6d5dd1d2}},	//   sst_, _خطاب, braň, _ocra, 
   {{0x443dd1d3,0x7bc9d1d4,0x6b80017a,0xddcc0113}},	//   pst_, zigu, _lamg, kwaš, 
   {{0xdcf40276,0x7bc9d1d5,0x5f940798,0x9f4800ae}},	//   _mază, yigu, бивт, slaí_, 
   {{0x6d5cfc0e,0x6b8179d7,0x7bc95900,0xdcf4054e}},	//   _acra, _namg, xigu, _lază, 
   {{0xceb446e8,0x7bc9d1d6,0x6d5c2ab0,0x69c82611}},	// [34110] бәр_, vigu, _bcra, _omde, 
   {{0x7bc80526,0x00000000,0x00000000,0x00000000}},	//   wigu, --, --, --, 
   {{0x7bc9d1d7,0xf1a4084c,0x9f580166,0x67200175}},	//   tigu, _фрын, _kisü_, kcmj, 
   {{0x6d5dd1d8,0x69c9d1d9,0x6b81d1da,0x6e48002d}},	//   _ecra, _amde, _camg, úsbâ, 
   {{0x6b81d1db,0x238c0024,0xe8e00051,0x7ac400d8}},	//   _damg, _gėjų_, ướu_, јсее, 
   {{0x6d5c007b,0x7af400ac,0x6b8002d0,0xdcf40356}},	//   _gcra, əxtl, _eamg, _cază, 
   {{0x7bc9d1dc,0x18a4504c,0x769003e0,0x00000000}},	//   pigu, сайм, kıyö, --, 
   {{0xba75d1dd,0x6b81d1de,0x7bc80869,0x00000000}},	//   _پارت, _gamg, qigu, --, 
   {{0x2bc8013e,0x7bd803ac,0x6d5c035a,0xddcc02f0}},	//   _туро_, _ijuu, _ycra, traň, 
   {{0x69c80998,0x7af9d1df,0xa8a40139,0x00000000}},	//   _gmde, _izut, срәк, --, 
   {{0xdb08067c,0x2bc41d8a,0x6b800208,0x9f480162}},	//   _bleç, लोवा, _yamg, ymað_, 
   {{0x5ae42fb5,0x645c66ce,0x7bd81418,0x79800857}},	//   _སྙོམ, ària, _jjuu, ldnw, 
   {{0x69c803cb,0x53a40454,0x00000000,0x00000000}},	//   _ymde, _ҳайб, --, --, 
   {{0xc6900302,0xe0c800cc,0xe4c81a4b,0x00000000}},	//   _מאד_, _ষড়ভ, ابین_, --, 
   {{0x8620006c,0x6d5c00b5,0x53a47848,0xd1740032}},	//   _وکیل, _rcra, _гайб, _һыны, 
   {{0x7bd80de2,0x932400f1,0xd3f403d4,0x355015b4}},	//   _njuu, _ارغن, _ঘূৰি_, _اچکز, 
   {{0x7af80085,0x6b801529,0xa3ac1d34,0x00000000}},	// [34120] _nzut, _ramg, _गवत_, --, 
   {{0x6b81d1e0,0x7bd820ac,0x9f580548,0x5ae4025c}},	//   _samg, _ajuu, _bisó_, _སྙེམ, 
   {{0x7af9d1e1,0xdb1804e6,0x7bd80254,0x1db8041c}},	//   _azut, chwë, _bjuu, _इतरत, 
   {{0x6d5c3deb,0x00000000,0x00000000,0x00000000}},	//   _wcra, --, --, --, 
   {{0x9f0400cf,0x2d9c00e5,0x00000000,0x00000000}},	//   _ووپو, öves_, --, --, 
   {{0x6b8120e6,0x38c8cf73,0x7bd80083,0x8c1800ec}},	//   _wamg, گاهی_, _ejuu, _ميسر_, 
   {{0x7af9d1e2,0xa7fc0139,0xa91c0419,0xddcc062d}},	//   _ezut, _opıt, _paľb, ltaş, 
   {{0x27e00fb7,0x6b8002d0,0xd6d8012d,0x00000000}},	//   čino_, _uamg, załe_, --, 
   {{0x7bc00240,0x6674109c,0xddcc56a3,0xc8500023}},	//   ënue, تگار, ntaş, _ዘይምሕ, 
   {{0x69c9d1e3,0x2bc41152,0x00000000,0x00000000}},	//   _umde, लोरा, --, --, 
   {{0x881563dc,0x00000000,0x00000000,0x00000000}},	//   _طباط, --, --, --, 
   {{0xddcc70f7,0x61e03711,0x69d8005f,0xd6d8033f}},	//   ktaş, पक्ष, lnve, wałe_, 
   {{0x69d88943,0xd6d8012d,0x00000000,0x00000000}},	//   onve, tałe_, --, --, 
   {{0xbdd8557b,0xa1580063,0xdb2003b2,0x00000000}},	//   _avèn, јаву_, átúr, --, 
   {{0x7ff5d1e4,0x44248a91,0x14f40220,0x00000000}},	//   مسرا, _ارتف, _وزىڭ, --, 
   {{0x69d80e78,0xa3ac0a59,0xf4841176,0x00000000}},	//   hnve, _गवि_, _داهی, --, 
   {{0x9f580ffb,0x6e94816b,0xdcf40109,0x3f84012c}},	// [34130] _bisò_, питу, _mazą, ěnu_, 
   {{0xbdd9d1e5,0x9f580789,0x998c5946,0x628dd1e6}},	//   _evèn, _pisó_, _svež_, _irao, 
   {{0x9f580548,0x628c05c7,0xa3ac0254,0x7af80827}},	//   _qisó_, _hrao, _गवा_, _szut, 
   {{0x2d9dd1e7,0x628dd1e8,0x7c740092,0x1af40121}},	//   över_, _krao, _የዋለው_, опея, 
   {{0x69d8008c,0xd7c8168d,0x00000000,0x00000000}},	//   fnve, یوته_, --, --, 
   {{0x69d802ed,0x6e2000d5,0x955c0023,0x00000000}},	//   gnve, _émba, ታታትን_, --, 
   {{0x6c5400c0,0x00000000,0x00000000,0x00000000}},	//   _нкру, --, --, --, 
   {{0x628c02b1,0x7bd89585,0xdb180af2,0x65680d47}},	//   _orao, _ujuu, khwé, efdh, 
   {{0x9598bbc9,0xb40405f5,0x19580500,0x86208e33}},	//   атну_, үүлд, _вазы_, وکول, 
   {{0x63a80108,0x00000000,0x00000000,0x00000000}},	//   öenn, --, --, --, 
   {{0xd469d1e9,0x628dd1ea,0x81dc0729,0x21300156}},	//   шине_, _arao, ততা_, dbzh_, 
   {{0x628dd1eb,0x6569cdfd,0x00000000,0x00000000}},	//   _brao, afdh, --, --, 
   {{0x628c0fa3,0xbeb80d27,0x18b001e0,0x00000000}},	//   _crao, _geëx, _хәҙр, --, 
   {{0x628dd1ec,0x00000000,0x00000000,0x00000000}},	//   _drao, --, --, --, 
   {{0xfe7c2776,0x53a401fe,0x628d67eb,0xe50400f7}},	//   _asï_, _макб, _erao, _ىبىي, 
   {{0x63bdd1ed,0x628dd1ee,0x00000000,0x00000000}},	//   chsn, _frao, --, --, 
   {{0x628c2b92,0x9f580ffb,0x21300165,0xdb180036}},	// [34140] _grao, _pisò_, bbzh_, chwé, 
   {{0xda1c00c5,0x00000000,0x00000000,0x00000000}},	//   _पढ़त_, --, --, --, 
   {{0x8fa5d1ef,0x628c030a,0xa91c0419,0x00000000}},	//   _дане, _zrao, _naľa, --, 
   {{0xcb68024d,0xddcc0356,0x3178012d,0x00000000}},	//   раде_, ptaş, lerz_, --, 
   {{0x246c013f,0x0d2000f7,0x7e0001f2,0x60c80115}},	//   _mɛma_, _жүзү, ọsar, ĝeme, 
   {{0x8d9401d9,0x8d7404fb,0x26c001e4,0x00000000}},	//   _بٔست, _باحا, _ĥio_, --, 
   {{0x69d9d1f0,0xc7b8016c,0x9cb000f7,0x00000000}},	//   rnve, иёи_, _كۅكت, --, 
   {{0x4668f486,0x31783370,0xc0cc0092,0x9a2400db}},	//   аром_, herz_, _ባክህ_, زعۇن, 
   {{0x8ad401d3,0x00000000,0x00000000,0x00000000}},	//   _بگاڑ_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x246c013b,0x3178bd10,0x628c01e7,0x00000000}},	//   _bɛma_, derz_, _srao, --, 
   {{0xbdd80ffb,0x628dd1f1,0x1c1c033f,0x00000000}},	//   _avèl, _prao, _बंसल_, --, 
   {{0x9f480228,0xc6d401ed,0xd5b800f7,0xb28400fd}},	//   llaç_, _بتات, рсө_, мырк, 
   {{0x65c00248,0x628c0165,0x31780165,0xc1e8005b}},	//   _dáhù, _vrao, gerz_, рьме_, 
   {{0xd6d8033f,0x5f9400d8,0x00000000,0x00000000}},	//   mała_, пивт, --, --, 
   {{0x628c03bd,0x63bc0227,0xd6d8012d,0x00000000}},	//   _trao, qhsn, lała_, --, 
   {{0x62800618,0x3178030a,0xceb404a9,0x8234007b}},	// [34150] ālos, berz_, пәр_, _برعا, 
   {{0xc058311f,0xd6d8033f,0x22580254,0x31780210}},	//   _кім_, nała_, musk_, cerz_, 
   {{0x246c013f,0x6b8001f2,0x1c380eed,0x2258030a}},	//   _yɛma_, _ịgaf, ёзды_, lusk_, 
   {{0x90780375,0x5bb4af6c,0x00000000,0x00000000}},	//   _פטרי, ंसेव, --, --, 
   {{0x2009d1f2,0xd6d8033f,0x8f98011a,0x59f811f4}},	//   mmai_, kała_, _הירי, бедя_, 
   {{0x2009d1f3,0xd6d80210,0x63bc0200,0x00000000}},	//   lmai_, jała_, ërnj, --, 
   {{0xd6d8033f,0x2008020c,0x6dc400f7,0x7b741095}},	//   dała_, omai_, _تۅلۅ, _وطرا, 
   {{0x02a001f2,0x2009d1f4,0x00000000,0x00000000}},	//   _awọọ, nmai_, --, --, 
   {{0x225801bf,0xb86000f2,0x98540023,0xd6d80210}},	//   jusk_, ساژو, _ዘይምቅ, fała_, 
   {{0xf99001d9,0x95980276,0xd6d8012d,0x65c001e1}},	//   _تبر_, стиу_, gała_, _ráhù, 
   {{0x200800dd,0x2250013f,0x2258000f,0xd7180153}},	//   kmai_, ɑnkɔ_, eusk_, _люлі_, 
   {{0x22581654,0xd4980124,0x41240107,0x00000000}},	//   fusk_, арҭ_, ҷоро_, --, 
   {{0x3864030d,0x3a2c05b1,0xd6d8012d,0xd13000e5}},	//   ltnr_, npgp_, bała_, ٹمز_, 
   {{0x77c000b5,0xd01000f1,0x412401f0,0xd6d80210}},	//   とxbe, ځلس_, зоро_, cała_, 
   {{0x10a400a7,0x3864003a,0x00000000,0x00000000}},	//   чивн, ntnr_, --, --, 
   {{0x2008dd41,0xe3b8a090,0xe50805d9,0xdcf40171}},	//   gmai_, lqın_, _بيٺو_, _enzī, 
   {{0xdce400b8,0x00000000,0x00000000,0x00000000}},	// [34160] bdhī, --, --, --, 
   {{0x2009d1f5,0x71740ef6,0xf1e0012c,0x3864007c}},	//   amai_, _تۇسا, _नदिन, ktnr_, 
   {{0x4c1400db,0x00000000,0x00000000,0x00000000}},	//   سباس, --, --, --, 
   {{0x2008084c,0xef94035c,0x6e21b93e,0xd6d8033f}},	//   cmai_, _تیرد, _émbo, zała_, 
   {{0x7bc002d3,0x3ce00175,0xbf980051,0x00000000}},	//   ënua, _exjv_, _khên, --, 
   {{0x2fc12584,0x8c44f3d3,0x9f480205,0x00000000}},	//   lhig_, _неге, tlaç_, --, 
   {{0x2d9801e6,0xfce07d98,0xbdd80129,0x763800b8}},	//   _inre_, _зоро, _xvèm, _āsaṅ, 
   {{0xd6d8068f,0xc7640075,0x356401c0,0xa77421cc}},	//   wała_, سابى, үрэн_, флич, 
   {{0xd6d8033f,0xcb34008e,0x6d200037,0xcaa4007b}},	//   tała_, _меңъ, _बलाग_, _عصري, 
   {{0x2009d1f6,0x00000000,0x00000000,0x00000000}},	//   zmai_, --, --, --, 
   {{0x200802d5,0x2d99d1f7,0x386401f5,0xd6d8012d}},	//   ymai_, _mnre_, ctnr_, rała_, 
   {{0x78f80375,0xd6d8033f,0x00000000,0x00000000}},	//   _פלאפ, sała_, --, --, 
   {{0x2fc1d1f8,0xa5c402dd,0xd6d8012d,0x20080332}},	//   dhig_, _жөне, pała_, vmai_, 
   {{0xbf99d1f9,0xa91c0030,0x22580165,0x6f8801ec}},	//   _chên, _maľo, rusk_, _ﻗﻤﻨﺎ_, 
   {{0x22580227,0x20082281,0x5ff40452,0x06840150}},	//   susk_, tmai_, дзву, _ﻓﻴﻠﯩ, 
   {{0x2d980311,0x301400a7,0x20080153,0x78840118}},	//   _anre_, едср, umai_, lévá, 
   {{0x2009d1fa,0x330800db,0x00000000,0x00000000}},	// [34170] rmai_, _ىيىپ_, --, --, 
   {{0x2009d1fb,0xadf4399f,0x26c400c0,0xb2bc011a}},	//   smai_, епуш, izmo_, _למחר, 
   {{0x69c00bc0,0x248c009a,0x2fc000a3,0xa3e00037}},	//   वसनी, nvdm_, bhig_, _ददा_, 
   {{0x5f80005e,0x2fc1d1fc,0xdab8007b,0xb6000153}},	//   _جۇرە, chig_, يهات_, ėšim, 
   {{0xbe88a30d,0x00000000,0x00000000,0x00000000}},	//   _усне_, --, --, --, 
   {{0xe9d802dc,0x39f00131,0x39a40f06,0x00000000}},	//   пкі_, رۋاز, яшев, --, 
   {{0xdb0805e4,0x00000000,0x00000000,0x00000000}},	//   _koeë, --, --, --, 
   {{0x2249d1fd,0x96040562,0x562822c3,0xed041075}},	//   _ovak_, रष्ट_, ожим_, _سوقپ, 
   {{0x3864019b,0xf968020f,0x00000000,0x00000000}},	//   stnr_, _грей_, --, --, 
   {{0x2fc00156,0x7924074d,0x00000000,0x00000000}},	//   zhig_, _хьаж, --, --, 
   {{0x2bc40a94,0x00000000,0x00000000,0x00000000}},	//   लोका, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x29d40150,0xfc440118,0xd6d8012d,0xe3b803e0}},	//   _تيەس, _žíly_, mało_, rpıp_, 
   {{0x7658dbe3,0xd6d8012d,0xe3b803e3,0x00000000}},	//   muuy, lało_, qqın_, --, 
   {{0x7659d1fe,0x2fc1d1ff,0x00000000,0x00000000}},	//   luuy, thig_, --, --, 
   {{0xd6d8033f,0x31b400a2,0x940400ec,0xa3c4000d}},	//   nało_, _mäzi_, _توبه, _एतय_, 
   {{0x0d85d200,0x68e405d1,0x42c400a7,0x66e80240}},	// [34180] млан, ğidi, _огън_, mëkë, 
   {{0x27e0341a,0xcad0063f,0xa7fc008e,0x68e52828}},	//   čini_, lịgị, _aqıl, şidi, 
   {{0x7659d201,0xdb180699,0x2248006f,0xd6d8012d}},	//   huuy, viwò, _zvak_, kało_, 
   {{0x7658006f,0xa91c00d7,0x66e80200,0x00000000}},	//   kuuy, _paľo, nëkë, --, 
   {{0xbb4022d7,0x76581418,0xd6d8033f,0x63bc036e}},	//   течк, juuy, dało_, ërni, 
   {{0xf98d3dd1,0x08286d2a,0x3eac17da,0xfaa01f5a}},	//   لبى_, оции_, ägte_, таљо, 
   {{0x22a4025a,0x701c015b,0x2c1800c5,0x3cdc0073}},	//   _këkë_, _তবুও_, _बंटू_, कपणे_, 
   {{0xf76dd202,0xd90c035c,0x76580337,0x062400d8}},	//   لاً_, حیم_, fuuy, мфом, 
   {{0x896495be,0x6e24011f,0xc964010b,0xbb4001ec}},	//   _окаж, nqib, _овай, _шетк, 
   {{0x2e240036,0xfe980375,0xe8b80327,0x48b402e8}},	//   _möf_, קיימ, ྐྱུག, _ощет, 
   {{0xbf9800d2,0x224803a1,0x97540055,0xa2c000e1}},	//   _bhêl, _svak_, _aṇut, रैन्, 
   {{0x7658022f,0xd6d80210,0x00000000,0x00000000}},	//   buuy, cało_, --, --, 
   {{0x2e2402d2,0x00000000,0x00000000,0x00000000}},	//   _nöf_, --, --, --, 
   {{0x7d0002fb,0xa56801d3,0xdcf40419,0x00000000}},	//   ýnsk, _رشتے_, _rozľ, --, 
   {{0x291801f1,0x2e2405d1,0xf0440262,0xf4800961}},	//   _úrad_, _aöf_, кэто, _ауын, 
   {{0x224800b8,0x6ed00037,0x00000000,0x00000000}},	//   _tvak_, _ठेहु, --, --, 
   {{0x6e2415fa,0xa195d203,0xa2d400c6,0x442c0334}},	// [34190] gqib, _запч, _سيدت, _htf_, 
   {{0x442c2fc3,0xd6d80034,0x6619d204,0x00000000}},	//   _ktf_, zało_, _jivk, --, 
   {{0x442c0c09,0x63add205,0x9f58102c,0x66180219}},	//   _jtf_, _koan, _bisô_, _mivk, 
   {{0x63add206,0x442dd207,0x661805ac,0x644801f5}},	//   _joan, _mtf_, _livk, isdi, 
   {{0x63acc084,0x442dd208,0xaa280736,0x00000000}},	//   _moan, _ltf_, وثوق_, --, 
   {{0xd6d80034,0x442c00b5,0x66180165,0x00000000}},	//   wało_, _otf_, _nivk, --, 
   {{0x2019d209,0x644877ad,0x76580083,0xd6d8012d}},	//   _kisi_, jsdi, wuuy, tało_, 
   {{0x6448f498,0x63add20a,0x76581418,0xa7fc008e}},	//   dsdi, _noan, tuuy, _uqıl, 
   {{0x442c045a,0x34b400bc,0xab6800ef,0xf980024c}},	//   _atf_, आन्द, _duļķ, _аҳло, 
   {{0x2019d20b,0x63add20c,0x442c0810,0x6448017a}},	//   _lisi_, _aoan, _btf_, fsdi, 
   {{0x94740f1b,0x63add20d,0x6448178a,0x6619d20e}},	//   رددا, _boan, gsdi, _divk, 
   {{0x2019d20f,0x63ad1239,0x53a4030c,0x00000000}},	//   _nisi_, _coan, хамб, --, 
   {{0x63add210,0x98a40b23,0x64480af9,0x442d0f07}},	//   _doan, _telē_, asdi, _etf_, 
   {{0x2019d211,0xf770168d,0x442c2f1b,0x644801bf}},	//   _aisi_, _ساڵ_, _ftf_, bsdi, 
   {{0x63ac1311,0x2019d212,0x442dd213,0xc0e00372}},	//   _foan, _bisi_, _gtf_, горк, 
   {{0x2019d214,0x63add215,0x6618110c,0x92bc00cc}},	//   _cisi_, _goan, _zivk, _আশী_, 
   {{0x2019d216,0x442c005a,0xc33000d9,0xcc8800f1}},	// [341a0] _disi_, _ztf_, _עוז_, ګناه_, 
   {{0x2019d217,0x3024036b,0xddcc012d,0x317c00d7}},	//   _eisi_, _изоҳ, erał, _úvz_, 
   {{0x2019d218,0x63ac1aac,0x3d2800f1,0x00000000}},	//   _fisi_, _yoan, ستلی_, --, 
   {{0x2019d219,0xed500a81,0x63add21a,0xddcc033f}},	//   _gisi_, _چھا_, _xoan, grał, 
   {{0xca700633,0x00000000,0x00000000,0x00000000}},	//   انتک, --, --, --, 
   {{0x28f9d21b,0x3fc00349,0x6448017a,0x5d140137}},	//   мель_, ্কৃষ, ysdi, ربەز, 
   {{0x2019d21c,0x661801f5,0xddcc0034,0xa91c00d7}},	//   _yisi_, _rivk, brał, _haľk, 
   {{0x6618341a,0xf7440131,0x00000000,0x00000000}},	//   _sivk, ىلىي_, --, --, 
   {{0x63add21d,0x66198a93,0x442dd21e,0x49c804a9}},	//   _roan, _pivk, _stf_, _елан_, 
   {{0x63add21f,0xf76c005e,0x767005d9,0x00000000}},	//   _soan, لاۋ_, اديء, --, 
   {{0x63add220,0x644802d5,0x661800df,0x7870059e}},	//   _poan, usdi, _vivk, _مُلا, 
   {{0x442dd221,0xa3d40137,0x00000000,0x00000000}},	//   _vtf_, томч, --, --, 
   {{0x63add222,0x6618014b,0xe3b803b9,0x00000000}},	//   _voan, _tivk, qqım_, --, 
   {{0x2019d223,0x27e00552,0x63add224,0x64482f81}},	//   _sisi_, činu_, _woan, psdi, 
   {{0x63add225,0x2019d226,0x8004023a,0xdfd42401}},	//   _toan, _pisi_, ечае, вовы, 
   {{0x2019d227,0xdb08010e,0x73c40150,0x00000000}},	//   _qisi_, _aleý, _ميىم, --, 
   {{0x20192c05,0x28c02e1e,0xdb0800a2,0xc0ec0240}},	// [341b0] _visi_, षैति, _bleý, _ቁዋም_, 
   {{0x2019d228,0x7bc0005f,0xf1a511d8,0x9d54823d}},	//   _wisi_, īnum, _брюн, ئنات, 
   {{0xf99c01fb,0x2019d229,0xfbe0035b,0x00000000}},	//   _đè_, _tisi_, гәаҭ, --, 
   {{0x2018003a,0x00000000,0x00000000,0x00000000}},	//   _uisi_, --, --, --, 
   {{0x3f88068c,0x6e980395,0x00000000,0x00000000}},	//   _iacu_, _звяр_, --, --, 
   {{0x3f88983f,0xbdd80ba1,0x7c84055f,0x2b580171}},	//   _hacu_, _avèv, _пубе, _ērce_, 
   {{0x3f89d22a,0x18a5d22b,0x6ce402dd,0x00000000}},	//   _kacu_, тайм, _біте, --, 
   {{0x3f8816a3,0x4ad07d07,0xe6dc8153,0x00000000}},	//   _jacu_, _देवव, मपूज, --, 
   {{0x864000c7,0xaa58041b,0x00000000,0x00000000}},	//   аныж, _питу_, --, --, 
   {{0x3f89d22c,0x00000000,0x00000000,0x00000000}},	//   _lacu_, --, --, --, 
   {{0xf771d22d,0x3945d22e,0x2258002d,0xdcf48af3}},	//   _ماش_, mans_, ersk_, _kozı, 
   {{0x7af9ae8a,0xe6186240,0x00000000,0x00000000}},	//   _kyut, мдө_, --, --, 
   {{0x9474cb3a,0xf4200116,0xc0f001f3,0x00000000}},	//   ردگا, _өзлү, _ፍተሻ_, --, 
   {{0x3945d22f,0x7af8037e,0xd1300fba,0xd7e80354}},	//   nans_, _myut, شمر_, _емçе_, 
   {{0x3f881389,0xbeb800e8,0x2258045f,0x3945d230}},	//   _bacu_, _ngëb, arsk_, ians_, 
   {{0x3f8807a8,0x3b1c0477,0x3a3c010e,0xa91c00d7}},	//   _cacu_, _nguq_, _owup_, _paľk, 
   {{0x3945d231,0x3f880cf4,0xb2b400d1,0xdb08010b}},	// [341c0] kans_, _dacu_, _сәнъ, _pleý, 
   {{0x394526b6,0x3f88068c,0x1ea815eb,0x2d9c0165}},	//   jans_, _eacu_, راقي_, ñve_, 
   {{0x0b4400d6,0xc1b806a9,0xdcf400fd,0x6abc00dc}},	//   внен, _חמיש, _bozı, ्छ्र, 
   {{0x3f88e9e7,0xdb08030a,0x7af808fb,0x710400c7}},	//   _gacu_, _fleü, _byut, _аҧҳа, 
   {{0x3945d232,0x4ad017ee,0x7af800dc,0xaa580faf}},	//   fans_, _देशव, _cyut, хилу_, 
   {{0x7af9d233,0x3f89d234,0x00000000,0x00000000}},	//   _dyut, _zacu_, --, --, 
   {{0x3f882da1,0x67d5d235,0x8c442edc,0x00000000}},	//   _yacu_, локу, _шеве, --, 
   {{0xfce1d236,0x7d01441f,0x3945d237,0x00000000}},	//   _тосо, ünse, aans_, --, 
   {{0x3945d238,0x7af8037e,0x00000000,0x00000000}},	//   bans_, _gyut, --, --, 
   {{0x066800d1,0x00000000,0x00000000,0x00000000}},	//   _ﻳﻪﻧﯩ, --, --, --, 
   {{0x69d9d239,0xb81825c9,0x35f4009f,0xbd5800df}},	//   mive, _पंचम_, خريد_, וכיש, 
   {{0x69d9d23a,0x27e002d1,0x2259d23b,0x62346c49}},	//   live, _ñin_, нимы_, лему, 
   {{0x2a6000a3,0xc6d0030d,0x00000000,0x00000000}},	//   àibh_, _тιак, --, --, 
   {{0x3f89d23c,0xbbac0490,0x00000000,0x00000000}},	//   _sacu_, _झक्क, --, --, 
   {{0x3f64085a,0x3f89d23d,0x69d80156,0x4404001b}},	//   ктаб, _pacu_, iive, _ичиб, 
   {{0x69d806d6,0x39443462,0x6d58578e,0x2b4401f7}},	//   hive, zans_, óvan, _nemc_, 
   {{0x3945d23e,0x61e401af,0x3f89d23f,0xdcf40139}},	// [341d0] yans_, _tjhl, _vacu_, _bazğ, 
   {{0x3f882da1,0x394400db,0x69d809a8,0x7af804ce}},	//   _wacu_, xans_, jive, _ryut, 
   {{0x3945d240,0x7af9d241,0x61f401b9,0x63bc0006}},	//   vans_, _syut, mozl, oksn, 
   {{0x3945d242,0xbdd926ae,0x3f880ba1,0x69d804cc}},	//   wans_, _avèt, _uacu_, eive, 
   {{0x3945d243,0x63bd3e32,0x00000000,0x00000000}},	//   tans_, iksn, --, --, 
   {{0x69d98ba4,0x6d35d244,0xfc301867,0x7af800dc}},	//   give, _верф, _نحر_, _vyut, 
   {{0x39440bd1,0x23680e3c,0xdb0801ab,0x63bc003b}},	//   rans_, _ocaj_, _cleò, kksn, 
   {{0x39445079,0x23680457,0x7af8409c,0x61f4036b}},	//   sans_, _ncaj_, _tyut, hozl, 
   {{0x3945d245,0x69d9d246,0x7af803e0,0xdcf400fd}},	//   pans_, bive, _uyut, _yazğ, 
   {{0x69d834fe,0x39440227,0xddcc0034,0xceb000c8}},	//   cive, qans_, jważ, ציי_, 
   {{0xdb080166,0xddcc012d,0x93440139,0xa2c000cd}},	//   _ileñ, dważ, лнне, रैस्, 
   {{0x91e400b5,0xdb080156,0xddcc012d,0x2d2000bc}},	//   _chのh, _hleñ, eważ, _बल्ल_, 
   {{0xdb080156,0x718402dd,0x779001d3,0x98a40153}},	//   _kleñ, ақпе, _میںا, _pelė_, 
   {{0xa5940801,0x236801e4,0x28d81524,0x61f4022e}},	//   _връщ, _ecaj_, _भेडि, gozl, 
   {{0x86e0021a,0x8f98039b,0x76580d27,0x20b4005b}},	//   _نړیو, нъат_, lruy, аётс, 
   {{0x2498037e,0x63bc03ac,0xddcc0209,0xcfa82e0b}},	//   ærme_, cksn, lsaň, رازم_, 
   {{0x69d9d247,0x827005d9,0x61f401b9,0x8d5904cd}},	// [341e0] yive, _هٿيا, bozl, ешет_, 
   {{0x69d817cd,0x8fe00032,0x10a430c7,0xd18400f5}},	//   xive, рәүҙ, _бион, _слой, 
   {{0x69d9d248,0xdcf40166,0x9f48010e,0x00000000}},	//   vive, _vazğ, llaý_, --, 
   {{0x0a683d63,0x0ae834b1,0xaca4063f,0x69d80f85}},	//   ерки_, ндей_, _ntụr, wive, 
   {{0x69d8db22,0xdb08030a,0x07140075,0x69348ec1}},	//   tive, _bleñ, ﻳﺪﯗ_, لکار, 
   {{0xaca40521,0x76580286,0x0928a9f3,0x7d0003fa}},	//   _atụr, druy, رستي_, ünsc, 
   {{0xbdd80561,0x63bdd249,0x00000000,0x00000000}},	//   _evès, yksn, --, --, 
   {{0xddcc033f,0xda640451,0x9f480432,0x61f40205}},	//   zważ, _چالي, klaý_, zozl, 
   {{0x69d800c7,0x61f4036b,0xbdd8180f,0x854404b4}},	//   pive, yozl, _ivèr, лэне, 
   {{0x647417be,0x69d8e05e,0xdb08030a,0xc6c40150}},	//   агоу, qive, _gleñ, _ەگدە_, 
   {{0xdb0801a8,0x61f401a9,0xd90c02f2,0x00000000}},	//   _hleð, vozl, _قیه_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb181021,0x63bdd24a,0x61f401b9,0x889400c7}},	//   chwä, rksn, tozl, _шиҧх, 
   {{0x3910010a,0x00000000,0x00000000,0x00000000}},	//   _емĕр, --, --, --, 
   {{0x61f501c9,0x645c021c,0x90e40014,0xca2400d1}},	//   rozl, árid, لسٲن, ﭼﺎﺭ_, 
   {{0x61f4036b,0x02a40f7e,0xaac40da5,0x00000000}},	//   sozl, _бром, वनाक, --, 
   {{0xbeb8044e,0x212005b1,0x61f401e4,0x80d00154}},	// [341f0] _afër, _tghh_, pozl, _দুশ্, 
   {{0xbdd8004a,0x00000000,0x00000000,0x00000000}},	//   _avèr, --, --, --, 
   {{0x80d003f4,0x99d404fb,0xa2c000dc,0x00000000}},	//   _দুর্, یتتا, रैर्, --, 
   {{0x1f6400f7,0x5f940116,0x76580309,0x6ed00037}},	//   _өкүм, _тимт, yruy, _ठेकु, 
   {{0xa91c0419,0x00000000,0x00000000,0x00000000}},	//   _maľu, --, --, --, 
   {{0x985407d6,0x3e6c002f,0x6e640108,0x765803e0}},	//   атиш, müt_, _утюж, vruy, 
   {{0x3e6c07c5,0xa4040d2e,0x6aa40036,0xa3c400cd}},	//   lüt_, रताप_, äifr, _एतं_, 
   {{0x9b8822f3,0x7659d24b,0x98a4084c,0x5a3403b7}},	//   _جنرل_, truy, _află_, _внат, 
   {{0xdb0805a4,0x7c251eff,0x4645d24c,0x95846967}},	//   _gleð, _hujr, азын_, алпе, 
   {{0xa5e80032,0xf8040724,0x7658806d,0x00000000}},	//   ллыҡ_, _өчен, rruy, --, 
   {{0x7981d24d,0x53a40323,0x38b80248,0xe85802a9}},	//   menw, аанб, _dàrú_, _бахш_, 
   {{0xc0b8044e,0x7981d24e,0x7c25d24f,0xd39400fb}},	//   ኰነስ_, lenw, _mujr, рәкә_, 
   {{0x527400f7,0x798001f5,0x00000000,0x00000000}},	//   шуну, oenw, --, --, 
   {{0x7981d250,0x3e6dd251,0x052400ee,0x8658011a}},	//   nenw, düt_, _кошк_, _ידני, 
   {{0x1c144a8d,0x246c013f,0x61e800e8,0xdcf400ef}},	//   तगाल_, _bɛmu_, éela, _mazē, 
   {{0x7981d252,0xddcc01e4,0xbfc01422,0x00000000}},	//   henw, ruaŝ, обск, --, 
   {{0x7981d253,0x3e6c05d2,0xace401e0,0xd17400cf}},	// [34200] kenw, güt_, әбеҙ, _кыны, 
   {{0x7c25545d,0x8d19d254,0x798001f5,0xa91c00d7}},	//   _bujr, نزار_, jenw, _zaľu, 
   {{0x798013fe,0x8b2477f7,0x9f48004e,0xcb4401b9}},	//   denw, адее, glaó_, ахли, 
   {{0x3e6dd255,0x7c240477,0xfc001b88,0xce4817a0}},	//   büt_, _dujr, опхо, _изме_, 
   {{0x7981d256,0x3e6c0205,0x00000000,0x00000000}},	//   fenw, cüt_, --, --, 
   {{0xe85474bb,0x7981d257,0x9f5802bd,0xfd6401f2}},	//   منتد, genw, _aksè_, _merụ, 
   {{0xfce0a29d,0x7c25d258,0xc7c40484,0x00000000}},	//   _доро, _gujr, исии, --, 
   {{0x29000053,0x99dc0100,0x2fc0b35a,0x00000000}},	//   āia_, _pwňc, nkig_, --, 
   {{0x798003fa,0x60c801e4,0x889001a9,0x00000000}},	//   benw, ĝemi, сиқх, --, 
   {{0x9f580100,0x7c240113,0x60c801e4,0xd6d80210}},	//   _eksè_, _yujr, ŝemi, jału_, 
   {{0x2fc0225e,0xbeb81bce,0xc7640137,0xa4d80452}},	//   kkig_, _ngën, _ناشى, удну_, 
   {{0x3e6dd259,0xe57800ef,0x00000000,0x00000000}},	//   yüt_, diķe_, --, --, 
   {{0x6595d25a,0x00000000,0x00000000,0x00000000}},	//   _галу, --, --, --, 
   {{0x31c418d9,0x2fc00373,0x00000000,0x00000000}},	//   оссв, ekig_, --, --, 
   {{0x24542ed7,0x439001a9,0x00000000,0x00000000}},	//   _انبس, _ҳақс, --, --, 
   {{0x2fc1d25b,0x3e6c01b8,0x7981d25c,0xd7a80490}},	//   gkig_, tüt_, zenw, कायच, 
   {{0x5d55d25d,0x798002e3,0x7d2401d5,0x00000000}},	// [34210] йкат, yenw, афее, --, 
   {{0x628c0170,0xbbe80131,0x3e6d0fe1,0x65687333}},	//   _isao, ھرام_, rüt_, ngdh, 
   {{0xad246788,0x5c757a22,0xbbe804fb,0xfc6402e8}},	//   زىنى, слет, پرام_, ръзн, 
   {{0x2fc09023,0x5b14010b,0x79804704,0x2cbc0162}},	//   ckig_, бмет, wenw, øvda_, 
   {{0x7981d25e,0xeea80372,0x09c002f5,0x0f7800df}},	//   tenw, _ктрк_, ্চনা, _גארב, 
   {{0x628c0109,0x7980002f,0x323800d9,0x9f4800a2}},	//   _msao, uenw, סטון_, mlañ_, 
   {{0x9f4803bd,0x7981d25f,0x3b6400a7,0x00000000}},	//   llañ_, renw, _възв, --, 
   {{0x071001f2,0x628c8585,0x7981d260,0x6e200c6a}},	//   _gụkọ, _osao, senw, _émbr, 
   {{0x15b809a5,0x9f480165,0x00000000,0x00000000}},	//   гыны_, nlañ_, --, --, 
   {{0x749401f0,0x00000000,0x00000000,0x00000000}},	//   асмӣ_, --, --, --, 
   {{0x628dd261,0xdddc005f,0xd8382be9,0x48dc000d}},	//   _asao, _apsū, _спец_, _कइयो_, 
   {{0x9f48030a,0x249800cc,0xe78579bb,0xd6d80210}},	//   klañ_, ærma_, _мучо, wału_, 
   {{0xf1c801d5,0xd6d8012d,0xd90c02f2,0x00000000}},	//   иқий_, tału_, _تیژ_, --, 
   {{0x645c09c2,0xd7c802f2,0x00000000,0x00000000}},	//   áric, _جوڵه_, --, --, 
   {{0x8fa5d262,0x628c0dd4,0xbdd80100,0x9f4805c7}},	//   баве, _esao, _pwèn, elañ_, 
   {{0xa7fc0724,0x645c05be,0xd1b0036b,0x326400c7}},	//   _uqıt, šric, _کیسک, _деиҳ, 
   {{0x4f08796c,0xc24000c7,0x2fc04fdf,0x7bc800e4}},	// [34220] унан_, _енык, rkig_, dhgu, 
   {{0x2fc1d263,0x42c400db,0x4d140108,0x00000000}},	//   skig_, _ыгын_, бьет, --, 
   {{0x9f480165,0xa6e800fe,0x00000000,0x00000000}},	//   alañ_, _পৰাট, --, --, 
   {{0xcb080451,0x7bc8013f,0x9f4805c7,0x48dc000d}},	//   هيان_, ghgu, blañ_, _कइबो_, 
   {{0x8eb81142,0x4ad000af,0x0eb8013d,0x9f481d0e}},	//   _сынт_, _देखव, _суны_, mlað_, 
   {{0x9f482242,0x9db80166,0x8274010f,0x00000000}},	//   llað_, _кысу_, מענע_, --, 
   {{0xd9b000db,0x67d4004e,0x00000000,0x00000000}},	//   بەلد, жойу, --, --, 
   {{0xa7fc0166,0x7bc8002f,0x00000000,0x00000000}},	//   _aqır, chgu, --, --, 
   {{0x76b402e8,0x3b0473ea,0x7d24659a,0x00000000}},	//   йлър_, _гето_, _ársá, --, 
   {{0xc588656c,0x64540114,0x6d5800e4,0x00000000}},	//   ущие_, овођ, óvah, --, 
   {{0x69c9d264,0x02b1d265,0xba140137,0x2919d266}},	//   _ilde, ुन्न, _ايلا_, _àra_, 
   {{0xff5c006a,0x290dd267,0x03c40fc0,0x48dc0037}},	//   _alîn_, _izda_, ссом, _केयो_, 
   {{0x61e8002e,0x70000011,0x9f48032e,0x00000000}},	//   éelo, ্দাজ_, dlað_, --, 
   {{0x236c068f,0x7bc80023,0x628c0171,0x00000000}},	//   żej_, zhgu, _vsao, --, 
   {{0xe8dc037e,0xcad0063f,0xa7fc0166,0x9f48032e}},	//   _cc付_, dịmị, _uqıs, flað_, 
   {{0x628dd268,0x290c0122,0x9f49d269,0x00000000}},	//   _tsao, _mzda_, tlañ_, --, 
   {{0x628dd26a,0x69c86adb,0xa15833cc,0xe59001e1}},	// [34230] _usao, _olde, _капу_, _àpóí, 
   {{0xcaac015b,0x290c01a9,0x5d540816,0x00000000}},	//   কনাফ, _ozda_, ікет, --, 
   {{0x249c0327,0x9f480321,0x7bc801ab,0xd13000f2}},	//   _jrvm_, blað_, thgu, _تمپ_, 
   {{0x69c86d6e,0x00000000,0x00000000,0x00000000}},	//   _alde, --, --, --, 
   {{0x290dd26b,0x98c400f3,0xddcc0115,0x60c801e4}},	//   _azda_, čuča_, ltaŭ, ĝemu, 
   {{0x7bc9d26c,0x18a40440,0xdce402b1,0x00000000}},	//   shgu, жакм, nehī, --, 
   {{0xddcc008f,0x69c80334,0x89d41ec7,0x00000000}},	//   ntaŭ, _dlde, توور_, --, 
   {{0x69c9d26d,0xdb18002d,0x48c803d4,0x00000000}},	//   _elde, rkwâ, িপূৰ, --, 
   {{0x2b4405f5,0x95c807d6,0x7bd9d26e,0x99840b24}},	//   _хэсг, илиб_, _imuu, _ولرو, 
   {{0xbeb81bce,0xc5ec004b,0xe628007b,0x2a6001e7}},	//   _ngëm, پړه_, حثين_, áibe_, 
   {{0x249c05d5,0x6d5826d3,0x13e835c7,0x00000000}},	//   _crvm_, óvai, имой_, --, 
   {{0x645c0261,0x00000000,0x00000000,0x00000000}},	//   ária, --, --, --, 
   {{0x7bd801fa,0xbdd8007f,0x69c803b2,0x00000000}},	//   _mmuu, _pwèl, _ylde, --, 
   {{0xa7fc008e,0x290c0432,0x659410e4,0x10a40108}},	//   _uqır, _yzda_, _начу, оигн, 
   {{0x5468ada6,0x7bd8dbe3,0x4610d431,0x9f480252}},	//   _тайм_, _omuu, _توور, tlað_, 
   {{0xddcc00dc,0x00000000,0x00000000,0x00000000}},	//   praś, --, --, --, 
   {{0x09c00729,0x0ea8a43c,0x4d480353,0x7e4801d3}},	// [34240] ্চতা, шкай_, ипан_, لسلہ_, 
   {{0x7bd9d26f,0x550c00bc,0xe3b80166,0x00000000}},	//   _amuu, _हराए_, lqıp_, --, 
   {{0xcc3400c6,0xd009be27,0x0638001f,0x9f480413}},	//   زراع, _вене_, _በዲፕሎ, plað_, 
   {{0x95280f50,0xa2c14491,0xbb40cad9,0x7bd800d7}},	//   _ལུའི_, रैक्, децк, _cmuu, 
   {{0xfa30082a,0x6ac407b6,0xdcf40064,0x00000000}},	//   ورود, वनेर, _oazė, --, 
   {{0x8c45d270,0x00000000,0x00000000,0x00000000}},	//   _меге, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc1d401ad,0xf801463e,0xe5780171,0x00000000}},	//   _डग्ग, мчын, diķa_, --, 
   {{0xdcf40024,0x69c8d534,0x3f8c00e4,0x00000000}},	//   _bazė, _tlde, ôgui_, --, 
   {{0x69c801bf,0x98a400c0,0x00000000,0x00000000}},	//   _ulde, _gelį_, --, --, 
   {{0xddcc0311,0x351401c6,0x00000000,0x00000000}},	//   ltaţ, жжээ_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xddcc084c,0xb7d47b7a,0xdcf400c0,0x00000000}},	//   ntaţ, _بونا_, _fazė, --, 
   {{0x35f40502,0x65946c9c,0x00000000,0x00000000}},	//   _ورود_, _хаку, --, --, 
   {{0xdecc1ee0,0x00000000,0x00000000,0x00000000}},	//   ጣውን_, --, --, --, 
   {{0x443dd271,0xf0e80131,0xd1380107,0xddcc0115}},	//   mpt_, زىقى_, ихӣ_, rtaŭ, 
   {{0x443dd272,0x33080150,0xddcc00df,0x8c8400c7}},	// [34250] lpt_, _ويىپ_, staŭ, ҟәра_, 
   {{0x443c0cf9,0x2248034c,0xdd9000c6,0x7bd8000d}},	//   opt_, _iwak_, عوا_, _smuu, 
   {{0x068008b0,0x20980139,0x9f3401ec,0x443cce3e}},	//   ﯩﻤﻨﯩ, _укны_, _нені, npt_, 
   {{0x2248ef96,0x443c1190,0x2bb800c6,0x00000000}},	//   _kwak_, ipt_, يانة_, --, 
   {{0xfa880064,0x8f980677,0x9f04009a,0xbd7001ec}},	//   рсей_, _פישי, _روسو, _оңаш, 
   {{0x22480451,0xe9d83981,0x3e780311,0x443c0175}},	//   _mwak_, окі_, râtă_, kpt_, 
   {{0x443c0196,0xddcc054e,0x717c00df,0x00000000}},	//   jpt_, ataţ, ינגס, --, 
   {{0x7bd9d273,0x443c0ac5,0x2cbc0267,0xd7751fdc}},	//   _umuu, dpt_, ävde_, سابع, 
   {{0x19593e13,0xddcc084c,0x443dd274,0x645dd275}},	//   _газы_, ctaţ, ept_, árin, 
   {{0x443dd276,0xd5c000b8,0x645c0327,0x00000000}},	//   fpt_, _otāś_, ġrin, --, 
   {{0x2249d277,0xd5c00055,0x00000000,0x00000000}},	//   _awak_, _ntāś_, --, --, 
   {{0xd2500014,0x42e400fe,0x00000000,0x00000000}},	//   ٹنس_, _নৰেশ, --, --, 
   {{0x443c6551,0x00000000,0x00000000,0x00000000}},	//   apt_, --, --, --, 
   {{0xc69008a8,0x00000000,0x00000000,0x00000000}},	//   _נאו_, --, --, --, 
   {{0x22482558,0x8fa402d5,0x5ed80154,0x00000000}},	//   _ewak_, паве, _ভুলে, --, 
   {{0xaee40084,0x93440166,0x447400df,0x00000000}},	//   hiṅw, _эние, _זעקל_, --, 
   {{0x22490334,0xcad001f2,0xd5c000b8,0x0e646d55}},	// [34260] _gwak_, rịkị, _etāś_, якан, 
   {{0xdcec0055,0x00000000,0x00000000,0x00000000}},	//   _ūhāp, --, --, --, 
   {{0x22480d27,0x0c24009b,0x8fa4010a,0x41b8011a}},	//   _zwak_, чмен, _еане, _הציע, 
   {{0xcb680063,0x4aa841e5,0x00000000,0x00000000}},	//   саде_, йкен_, --, --, 
   {{0xf1b0726a,0xc33002e4,0x777801bf,0x00000000}},	//   ञापन, גוד_, dfux, --, 
   {{0xddcc0311,0x9e7002dd,0x00000000,0x00000000}},	//   rtaţ, _جۇكت, --, --, 
   {{0x7dc8068f,0xddcc084c,0x87e4010a,0x00000000}},	//   yższ, staţ, зюпе, --, 
   {{0x46680f37,0xddcc0276,0x9f480ffb,0xd90c97d1}},	//   бром_, ptaţ, gnaè_, جیم_, 
   {{0x443c063f,0x00000000,0x00000000,0x00000000}},	//   wpt_, --, --, --, 
   {{0x645c0a16,0x6aa0127b,0x00000000,0x00000000}},	//   ário, _irmf, --, --, 
   {{0x2248d904,0x443c0639,0xddcdd278,0x6d5c0356}},	//   _swak_, upt_, ntaš, _mdra, 
   {{0x27e001f4,0x00000000,0x00000000,0x00000000}},	//   _öin_, --, --, --, 
   {{0xd7a80490,0x443c1e0b,0x00000000,0x00000000}},	//   कारच, spt_, --, --, 
   {{0x443d483e,0x6d5c0851,0xddcc08ad,0x6b2c0327}},	//   ppt_, _ndra, ktaš, _སུའོ_, 
   {{0x7578011a,0x9f3401ec,0xb6000118,0xddcc00d7}},	//   _הטופ, дебі, ášej, jtaš, 
   {{0x6d5c0cfd,0x6aa00c8c,0x6458025c,0x224805e4}},	//   _adra, _ormf, _ivvi, _twak_, 
   {{0x22484cd3,0x442dd279,0xddccafda,0xc3180154}},	// [34270] _uwak_, _huf_, graş, _থ্রি_, 
   {{0x27e002fb,0x442c009f,0xddcc00f3,0xf40403d4}},	//   činy_, _kuf_, ftaš, _ৰূপৰ_, 
   {{0x6d5c0368,0x442c282c,0x6aa1d27a,0xf8d80037}},	//   _ddra, _juf_, _armf, _बधइय, 
   {{0x6d5dd27b,0x92c003d4,0x00000000,0x00000000}},	//   _edra, ্পৰ_, --, --, 
   {{0x442dd27c,0x6d5c0175,0x20080042,0x00000000}},	//   _luf_, _fdra, mlai_, --, 
   {{0x2009d27d,0x6459d27e,0x442c06af,0x6b80127b}},	//   llai_, _ovvi, _ouf_, _ebmg, 
   {{0x442dd27f,0xdcf400ef,0x2a60003d,0x645c3df9}},	//   _nuf_, _mazī, ġiba_, áril, 
   {{0x6d5c5a39,0x6aa00175,0x6608257c,0x645c031c}},	//   _zdra, _frmf, eldk, ġril, 
   {{0x442c2d65,0x6459d280,0x67548891,0x7f4dd281}},	//   _auf_, _avvi, ریوس_, _mecq, 
   {{0x2c600356,0x46e401c6,0xdcf40171,0x2b5800ef}},	//   bădă_, ьдын_, _nazī, _ērci_, 
   {{0x442c05d9,0x200802d5,0x777802b9,0x78442586}},	//   _cuf_, klai_, pfux, _رضام, 
   {{0x67d4049b,0x645801fa,0x20080097,0x7f4c003a}},	//   _поху, _dvvi, jlai_, _necq, 
   {{0x273807ae,0x6459d282,0x2008d65c,0x675404fb}},	//   _ứng_, _evvi, dlai_, _سخنر, 
   {{0x442c007c,0x60340153,0x20080171,0x00000000}},	//   _fuf_, _sąma, elai_, --, 
   {{0x2008c6d1,0x442dd283,0x7f4dd284,0x4124013e}},	//   flai_, _guf_, _becq, доро_, 
   {{0x6d5dd285,0x2d8401e4,0xddccafda,0x20084e96}},	//   _sdra, _ŝme_, traş, glai_, 
   {{0x64580393,0x00000000,0x00000000,0x00000000}},	// [34280] _zvvi, --, --, --, 
   {{0x7ec000d2,0x442c29ef,0x8c442119,0x48dc000d}},	//   _sípú, _yuf_, деже, _कइलो_, 
   {{0x76480007,0x200801ee,0x9db80139,0x00000000}},	//   _lwgy, blai_, чыту_, --, 
   {{0xddcdd286,0x200804cc,0x6d5c012d,0x2c580100}},	//   rtaš, clai_, _wdra, rčd_, 
   {{0xddcc1591,0xdb18002f,0x00000000,0x00000000}},	//   staš, chwü, --, --, 
   {{0x6d5cfa0a,0xef18030d,0x00000000,0x00000000}},	//   _udra, ĕмĕ_, --, --, 
   {{0xd7a80574,0x8b64423b,0x940c01f9,0x5cd4003b}},	//   कांच, _يارم, सताच_, _зітх, 
   {{0x442d970b,0x2d99d287,0x6b80009a,0x0ba8237e}},	//   _ruf_, _hare_, _ubmg, _باسى_, 
   {{0x442dd288,0x09dc031c,0xea641e4b,0x00000000}},	//   _suf_, _སཏྭ_, _سپای, --, 
   {{0x89144352,0x2d99d289,0x20080399,0x25f00073}},	//   _قبائ, _jare_, zlai_, ीकधी_, 
   {{0x20080368,0x38c803e6,0xd90c00ec,0x00000000}},	//   ylai_, _وامی_, _ٿڌو_, --, 
   {{0x2d99d28a,0xdbe40036,0x442c01bf,0xdcf40171}},	//   _lare_, _gëän, _vuf_, _sazī, 
   {{0x2d99d28b,0xdcf400da,0x442c0198,0xdb180e78}},	//   _oare_, _pazī, _wuf_, ckwä, 
   {{0x442c51d0,0xf57400c6,0x629c36ff,0x60c00158}},	//   _tuf_, _يمنع_, rvso, ølmo, 
   {{0x20080649,0x26c40006,0x442c7b14,0x5ff401ee}},	//   tlai_, lymo_, _uuf_, езву, 
   {{0x2d99d28c,0xf481d28d,0x27e401ab,0x20080477}},	//   _aare_, _рушн, nimn_, ulai_, 
   {{0x26c5d28e,0x2d98f06a,0x2009d28f,0x00000000}},	// [34290] nymo_, _bare_, rlai_, --, 
   {{0x2009d290,0x2d980c3e,0x00000000,0x00000000}},	//   slai_, _care_, --, --, 
   {{0x2009d291,0x2f3802e3,0x2d983003,0xeab030cd}},	//   plai_, _ọge_, _dare_, یعه_, 
   {{0x26c4824d,0x2d99d292,0x6d5806ea,0x7d0400d0}},	//   kymo_, _eare_, óvar, _vyjs, 
   {{0x2d989ff4,0x225803b2,0x7d04012d,0xbd3401ec}},	//   _fare_, nssk_, _wyjs, _жүзу_, 
   {{0x2d99d293,0x26c402d5,0x645c025c,0x00000000}},	//   _gare_, dymo_, ġrij, --, 
   {{0x6dc40137,0x00000000,0x00000000,0x00000000}},	//   _جۅلۅ, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2d99d294,0x069400c6,0x05c800dc,0x26c40153}},	//   _yare_, فنية_, िसंब, gymo_, 
   {{0xe93852d4,0xf991c91e,0x2d981574,0x25bc0219}},	//   _قسمت_, _جبر_, _xare_, _covl_, 
   {{0x24e80107,0x00000000,0x00000000,0x00000000}},	//   ҷмӯи_, --, --, --, 
   {{0x28d8012c,0xe8500131,0xccf000df,0x2cbc03b2}},	//   _भेटि, _ئۆيد, רכט_, øvdi_, 
   {{0x225803b2,0xd5480354,0x00000000,0x00000000}},	//   gssk_, _епле_, --, --, 
   {{0x50b40064,0x00000000,0x00000000,0x00000000}},	//   нсбу, --, --, --, 
   {{0x92c00154,0x00000000,0x00000000,0x00000000}},	//   ্পে_, --, --, --, 
   {{0x2d99d295,0x645c0356,0x00000000,0x00000000}},	//   _sare_, ârie, --, --, 
   {{0x0dc9c940,0x00000000,0x00000000,0x00000000}},	// [342a0] плай_, --, --, --, 
   {{0x71740150,0x2d99d296,0x3e8000e2,0x00000000}},	//   _جۇسا, _qare_, dītā_, --, 
   {{0x3a3c089c,0x953c0092,0x00000000,0x00000000}},	//   _atup_, _የአንደ, --, --, 
   {{0x60c00267,0x00000000,0x00000000,0x00000000}},	//   älme, --, --, --, 
   {{0x2d99d297,0x09e409ed,0x32d8033f,0x28d86a42}},	//   _tare_, нодн, _użyć_, _भेजि, 
   {{0x98a46f30,0xf98c00f7,0x645c1de4,0x00000000}},	//   _adlı_, مبى_, árik, --, 
   {{0xc865d298,0xc7c50229,0x9c5800cf,0x26c4015d}},	//   хтли, еспи, _ошту_, wymo_, 
   {{0x26c402d5,0xdb200730,0xf76c08e8,0x645c05be}},	//   tymo_, _äuße, ماً_, šrik, 
   {{0xadf404af,0x25bc005c,0x3e800171,0x00000000}},	//   _आदान_, _povl_, cītā_, --, 
   {{0x26c40006,0x95380137,0x35f001ec,0x00000000}},	//   rymo_, үзөт_, лпыр, --, 
   {{0x07a00014,0xa3d5d299,0xb6000419,0x26c4eb44}},	//   _مۅغُ, вонч, ášaj, symo_, 
   {{0x07d9d29a,0x60340006,0xd4c0717e,0x26c40153}},	//   _عذاب_, _sąmo, рөшк, pymo_, 
   {{0x430802bf,0xd2f401ed,0xb2840124,0xd59400e5}},	//   яхом_, ہکیا_, лырк, رطیک, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf481d29b,0xeaec30fd,0x00000000,0x00000000}},	//   _буын, जपुत_, --, --, 
   {{0x26140574,0x00000000,0x00000000,0x00000000}},	//   _नीती_, --, --, --, 
   {{0xdc880092,0x00000000,0x00000000,0x00000000}},	// [342b0] _አቋራጭ_, --, --, --, 
   {{0x63ac02f0,0x91c00166,0x6d5800c7,0x00000000}},	//   _hnan, _кәсл, óvap, --, 
   {{0x3a3c7553,0x63ac1b66,0x5c740148,0x61e800e8}},	//   _stup_, _knan, тлет, éelu, 
   {{0xeaec45bf,0xb06801c0,0x324404fb,0x63ac0055}},	//   जपूत_, _ярьж_, _جنیف, _jnan, 
   {{0x2bb80491,0x9f4800c6,0x2018007f,0x00000000}},	//   عامة_, nnaí_, _ihsi_, --, 
   {{0x63ac01ee,0x38c461be,0x066800d1,0x00000000}},	//   _lnan, فاعی_, _ﺳﻪﻫﯩ, --, 
   {{0x98a4025c,0x00000000,0x00000000,0x00000000}},	//   _melħ_, --, --, --, 
   {{0x63add29c,0x4cd80183,0xf8100066,0x00000000}},	//   _nnan, _বুকু, دستگ, --, 
   {{0x9f480086,0x79a4041b,0x9f580139,0x3a3cb487}},	//   noañ_, _прже, _iksä_, _utup_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7bc80076,0xe3b80139,0x00000000,0x00000000}},	//   okgu, lqıy_, --, --, 
   {{0x7bc936f1,0x00000000,0x00000000,0x00000000}},	//   nkgu, --, --, --, 
   {{0x9f480332,0x5fa40210,0x55f4022e,0x00000000}},	//   gnaí_, _ऑफ़ल, _ичку, --, 
   {{0x0b741ef7,0x00000000,0x00000000,0x00000000}},	//   በሳደር_, --, --, --, 
   {{0x1c101533,0x9f4801e7,0x7659d29d,0x2ebc00cd}},	//   ़ताल_, anaí_, lsuy, ोन्त, 
   {{0x63ac0c86,0x91e4016c,0x00000000,0x00000000}},	//   _gnan, хоҳе, --, --, 
   {{0xc2b01ac1,0x76580986,0x4418011a,0x00000000}},	// [342c0] _көрш, nsuy, _קופס, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x63ac09a5,0xe98404a9,0x6c3400e5,0x00000000}},	//   _ynan, һқан, اہرا, --, 
   {{0x765802d1,0x8fd00daf,0x0ae804b3,0xff2400db}},	//   ksuy, _тәгә, мдей_, ركەي_, 
   {{0xe9840220,0x27f801ed,0x4a740276,0x00000000}},	//   лқан, _írni_, тыет, --, 
   {{0x7bc80175,0x9f5801f4,0x00000000,0x00000000}},	//   akgu, _eksä_, --, --, 
   {{0x7d0003fa,0x8b9416a4,0xd6d8012d,0xf86000d8}},	//   ünst, _ирач, mały_, авјо, 
   {{0x7bc9d29e,0xd6d8012d,0x2c7d2309,0x00000000}},	//   ckgu, lały_, míd_, --, 
   {{0x76581c06,0xf76ccd5a,0xbeb80036,0x63ac0e89}},	//   gsuy, زاي_, _ugët, _rnan, 
   {{0x6a840075,0xd6d80034,0xe3b803b9,0x00000000}},	//   _илға, nały_, qqız_, --, 
   {{0xc8c9d29f,0x63ac007f,0x647407e6,0xb93400df}},	//   _توان_, _pnan, ыгну, _סטאפ_, 
   {{0x290c0009,0x00000000,0x00000000,0x00000000}},	//   _iyda_, --, --, --, 
   {{0x41e401ce,0x63ac0010,0x290c0200,0xd6d8012d}},	//   віва, _vnan, _hyda_, kały_, 
   {{0x63ada43e,0x9f48007b,0xd6d80210,0x00000000}},	//   _wnan, rnaí_, jały_, --, 
   {{0xbeb85993,0xdfd42075,0x63ac003e,0xd6d8033f}},	//   _ngër, говы, _tnan, dały_, 
   {{0x63add2a0,0x290c0004,0xe57800e2,0x00000000}},	//   _unan, _myda_, diķi_, --, 
   {{0x290c007c,0xac9401f3,0xa2c401af,0x00000000}},	// [342d0] _lyda_, _ዘላለም_, _сәнк, --, 
   {{0x9d54fc75,0x2dd43594,0x290c01b9,0xd6d8012d}},	//   انات, ажур, _oyda_, gały_, 
   {{0x61e40921,0x48dc007d,0x290c9327,0x19c400c7}},	//   _imhl, _कइगो_, _nyda_, қәаг, 
   {{0x765802d1,0x00000000,0x00000000,0x00000000}},	//   ysuy, --, --, --, 
   {{0x290c4952,0xbeb80240,0x7bc80477,0xa7fc013d}},	//   _ayda_, _egër, rkgu, _uqıy, 
   {{0xbdd8007f,0x389403e3,0xee7c0023,0xeab19221}},	//   _vwès, _hərə_, _ይርኣዩ_, تعم_, 
   {{0x389403e3,0x2c7c21dd,0x91b00051,0xac9c0023}},	//   _kərə_, cíd_, _quỷ_, _ቃልሶም_, 
   {{0xccf01203,0x7658019b,0x00000000,0x00000000}},	//   _הכל_, tsuy, --, --, 
   {{0x61e40912,0x290c0009,0x291800a3,0xbeb80200}},	//   _omhl, _eyda_, _ùran_, _zgër, 
   {{0x7af80b6f,0x389403e3,0x765803e0,0x00000000}},	//   _ixut, _lərə_, rsuy, --, 
   {{0x290c0f7b,0x83612374,0xc4c405f5,0xf7700244}},	//   _gyda_, ڭگىل, глэж_, _ناش_, 
   {{0x61e5d2a1,0x52742a20,0xd6d8033f,0x389403b9}},	//   _amhl, лугу, zały_, _nərə_, 
   {{0x76580784,0xe57800e2,0x00000000,0x00000000}},	//   qsuy, ziķi_, --, --, 
   {{0x38a0456f,0x61e400a3,0x0668b071,0x00000000}},	//   _kır_, _cmhl, _ﺳﻪﻣﯩ, --, 
   {{0xdb1803fa,0x389406be,0x649946db,0x0d8400d1}},	//   chwö, _bərə_, _атыр_, һлан, 
   {{0x61e49c78,0xd6d8068f,0x60c05b00,0x4f94eb13}},	//   _emhl, wały_, älma, ыргу, 
   {{0x0d85d2a2,0x38a00139,0xd6d8033f,0x389403b9}},	// [342e0] ллан, _lır_, tały_, _dərə_, 
   {{0x02b40375,0xe57800e2,0x4c3401c6,0xca7401ec}},	//   _עליך_, tiķi_, гэдт, ғуды, 
   {{0x7af8014b,0x0b440826,0x0b8924cf,0xd6d8033f}},	//   _axut, гнен, если_, rały_, 
   {{0x09bc228a,0x2d9c39ae,0x7af801a9,0x290c0142}},	//   ्स्य, žve_, _bxut, _ryda_, 
   {{0x61e400a9,0x15f46b9b,0xa954109a,0xdd740014}},	//   _ymhl, ीकार_, аклі, _چھٔک, 
   {{0x38a003ee,0xcde4010b,0xda64007b,0x00000000}},	//   _bır_, _согй, شاهي, --, 
   {{0x99640046,0x0828a6be,0x7af9d2a3,0x38a000fd}},	//   ртіл, нции_, _exut, _cır_, 
   {{0x60c0022c,0x38a062b6,0x29d001ab,0xd90c30fe}},	//   ølmi, _dır_, _gàan_, ذین_, 
   {{0x6b8400af,0xfaa0a440,0x290c012d,0xf98c00db}},	//   õigu, _лато, _wyda_, زبۈ_, 
   {{0x290c07b9,0x88d80108,0x066802dd,0x00000000}},	//   _tyda_, _пьет_, _ﺳﻪﻧﯩ, --, 
   {{0x290c036b,0xbdd8020c,0xa3b40d30,0x38a0294f}},	//   _uyda_, _otèn, абні, _gır_, 
   {{0xe6e801ee,0x00000000,0x00000000,0x00000000}},	//   _игеҙ_, --, --, --, 
   {{0x623400f5,0x7af80327,0x2a600332,0x00000000}},	//   регу, _xxut, áibh_, --, 
   {{0x69d800fc,0xbdd8fd51,0x38a00139,0x249801bf}},	//   nhve, _atèn, _yır_, ærms_, 
   {{0x69cc09d9,0xdcf400ef,0x461001e2,0x00000000}},	//   _तकनी, _mazģ, _پوډر, --, 
   {{0x645dd2a4,0x00000000,0x00000000,0x00000000}},	//   áriu, --, --, --, 
   {{0x5d55d2a5,0x6448257d,0x13e80150,0x7d69aed9}},	// [342f0] икат, lpdi, _جويۋ_, ешев_, 
   {{0x61e4124c,0xbdd8033b,0x628c02d0,0x1a642a77}},	//   _umhl, _etèn, _ipao, ییزی_, 
   {{0xa114034c,0x389406be,0xc0c800d8,0x00000000}},	//   _خودت, _tərə_, _чупе_, --, 
   {{0x38a00139,0x00000000,0x00000000,0x00000000}},	//   _rır_, --, --, --, 
   {{0x64480649,0xbd680640,0x628c0175,0x38a0510c}},	//   hpdi, _прве_, _jpao, _sır_, 
   {{0x69d8016d,0x38a00205,0x26141be1,0x955c0023}},	//   ghve, _pır_, _नीली_, ዳታትን_, 
   {{0x6d4c00ee,0x38a08411,0x00000000,0x00000000}},	//   şlaý, _qır_, --, --, 
   {{0x16642082,0x7af8009d,0x66e802b5,0x998c0427}},	//   авим, _txut, kīkī, _utež_, 
   {{0xe63401c0,0x6448017a,0x00000000,0x00000000}},	//   йхээ, epdi, --, --, 
   {{0x69d9d2a6,0x55e4c4b4,0x38a02258,0xaee400dc}},	//   chve, рооб, _tır_, _haṃs, 
   {{0x628dd2a7,0xaee4002b,0x00000000,0x00000000}},	//   _apao, _kaṃs, --, --, 
   {{0x61f40369,0xcc740302,0xe57800de,0x48dc0118}},	//   enzl, סגרת_, diķu_, _केटो_, 
   {{0xaee4002b,0x24b801d5,0x43640150,0x00000000}},	//   _maṃs, ننیگ_, шаян_, --, 
   {{0xd17439fb,0x154401af,0x00000000,0x00000000}},	//   шымы, _текм, --, --, 
   {{0x628c00b0,0xb4046bd5,0x0fc4009d,0x00000000}},	//   _epao, _гүнд, айвн, --, 
   {{0x628c037e,0xb2b40139,0x69d80156,0xcf45d2a8}},	//   _fpao, _ләгъ, zhve, рнай, 
   {{0xfbb8009e,0xb644019b,0x347001e0,0x527400db}},	// [34300] ংসাত, _ｊｋ_, _тѳҙѳ, _туйу, 
   {{0xd1b000f2,0x00000000,0x00000000,0x00000000}},	//   _بیسک, --, --, --, 
   {{0x30a400e5,0x00000000,0x00000000,0x00000000}},	//   _الجہ, --, --, --, 
   {{0x8fa5d2a9,0xa3c817cb,0x2b4001ab,0xcb686a40}},	//   _таме, लॉप_, ùic_, таде_, 
   {{0x6fd92d6b,0xaee400b8,0x693401fd,0xeaa00055}},	//   _cíce, _daṃs, مکار, daṃs_, 
   {{0xc864f7ff,0x0d2000ee,0x00000000,0x00000000}},	//   атии, _дүзү, --, --, 
   {{0x69d8f8aa,0x31d800cc,0x00000000,0x00000000}},	//   rhve, _সদাশ, --, --, 
   {{0x69d80363,0xe98400db,0x00000000,0x00000000}},	//   shve, _گارۋ, --, --, 
   {{0xda640be2,0x76b402e8,0x00000000,0x00000000}},	//   _هالي, илър_, --, --, 
   {{0xdb080165,0x6448010a,0x76a402e8,0xf6200114}},	//   _goeñ, tpdi, ртъв_, одњо, 
   {{0x628c03d1,0xc174872f,0x8ae401ec,0x00000000}},	//   _spao, یدست, _сіңл, --, 
   {{0x46e80fbe,0x05a4012d,0x6448139f,0x00000000}},	//   _иден_, _कोरब, rpdi, --, 
   {{0x250807d6,0xe5340064,0x00000000,0x00000000}},	//   ضرگی_, _лель, --, --, 
   {{0x6449b6f4,0xe57800e2,0x645dd2aa,0x6d58148b}},	//   ppdi, tiķu_, áris, ðval, 
   {{0x9df816c3,0x30a40024,0x3618011a,0x00000000}},	//   ҳнат_, ортв, _שווד, --, 
   {{0xadc40241,0x00000000,0x00000000,0x00000000}},	//   _itẹs, --, --, --, 
   {{0x9df814a4,0x628c01e2,0xaee400b8,0xa0a40150}},	// [34310] гнат_, _upao, _raṃs, шаңд, 
   {{0xaee40a28,0x00000000,0x00000000,0x00000000}},	//   _saṃs, --, --, --, 
   {{0x7c642a9f,0x317401f1,0x5f9400d1,0x6fd8007b}},	//   شاال, ňazí_, _линт, _síce, 
   {{0x5b240597,0x6608151c,0x00000000,0x00000000}},	//   مفضل, hodk, --, --, 
   {{0x66080092,0x7c38009b,0x50180a1e,0xba740116}},	//   kodk, _čuru, _תורו, شاشت, 
   {{0xceb030fb,0xe9a86073,0x200804c9,0x6fd8012c}},	//   _זיך_, لدىن_, loai_, _více, 
   {{0xf09400c8,0x6608058a,0xe89801d3,0xac581171}},	//   ַנץ_, dodk, لموں_, _васф_, 
   {{0xddcc341a,0x2009d2ab,0x5a340138,0x00000000}},	//   ntaž, noai_, _гнат, --, 
   {{0xadc401e1,0x6b8401c3,0xdb18002f,0x00000000}},	//   _atẹs, òige, nkwü, --, 
   {{0x2009d2ac,0x66080fb7,0x29d0002e,0xb86810f3}},	//   hoai_, godk, _làaj_, _ајде_, 
   {{0xddcc0024,0x2009c54a,0x53a4030c,0xa95400d4}},	//   ktaž, koai_, банб, _єкці, 
   {{0xe618dc64,0xbdd806af,0x00000000,0x00000000}},	//   лдө_, _stèl, --, --, 
   {{0x059401d9,0xdb200793,0x20080083,0xd5b00118}},	//   _گانگ, _ätäv, doai_, जाआज, 
   {{0xd5b18422,0x660801d9,0xddcc2230,0xcfa80214}},	//   _رفع_, codk, etaž, گاسم_, 
   {{0x3ea8a52b,0x20080b23,0x059414d1,0x7dec00c0}},	//   _arct_, foai_, _دانگ, _mėsė, 
   {{0x2009d2ad,0x1fb401af,0xc6b40244,0x00000000}},	//   goai_, осур, _ئێیچ_, --, 
   {{0x0ea8ca42,0x92e400cc,0xb5080037,0x00000000}},	// [34320] ыкай_, _বুৰ_, _सुतय_, --, 
   {{0x8d180066,0x00000000,0x00000000,0x00000000}},	//   هزار_, --, --, --, 
   {{0x4c84a396,0x00000000,0x00000000,0x00000000}},	//   слев, --, --, --, 
   {{0x7d1800c8,0x6608fd90,0x00000000,0x00000000}},	//   _ĝust, zodk, --, --, 
   {{0xbc642e51,0x69cc05f9,0x99dc007f,0x3eb800b5}},	//   لمەن_, _तकदी, _pwňp, cxqt_, 
   {{0x05a40490,0x2fc00de2,0x00000000,0x00000000}},	//   _कोंब, ljig_, --, --, 
   {{0xa7b82d29,0x00000000,0x00000000,0x00000000}},	//   илку_, --, --, --, 
   {{0x2fc0003e,0x8b641e57,0x00000000,0x00000000}},	//   njig_, _داسم, --, --, 
   {{0x2ee006be,0x00000000,0x00000000,0x00000000}},	//   nzif_, --, --, --, 
   {{0x9f4800d8,0xdb1c01e1,0x00000000,0x00000000}},	//   riaé_, _àyáj, --, --, 
   {{0x660821ed,0xddcc054e,0x2a60031c,0x00000000}},	//   rodk, luaţ, ġibu_, --, 
   {{0x2fc0007c,0x00000000,0x00000000,0x00000000}},	//   jjig_, --, --, --, 
   {{0xbdd80066,0x2fc00076,0xddcc0356,0xa5c40150}},	//   _stèm, djig_, nuaţ, _дөне, 
   {{0xa4d4109a,0x6608058a,0x066807d2,0x00000000}},	//   _молі, qodk, _ﺳﻪﻳﯩ, --, 
   {{0x20080607,0x1fc4013e,0x00000000,0x00000000}},	//   toai_, ораҳ, --, --, 
   {{0xc10005f5,0x20080618,0x3bd40139,0xf28800ec}},	//   жүүл, uoai_, _oçqa_, _ڇپيو_, 
   {{0xddcdd2ae,0x94240372,0x236801e4,0x200800b0}},	// [34330] rtaž, _بويۇ, _idaj_, roai_, 
   {{0xb8c81efe,0x2248151c,0x2009d2af,0xdb180e78}},	//   _བླ_, _itak_, soai_, rkwü, 
   {{0x9f34005e,0x23680fb7,0xddcc02d5,0x443c0054}},	//   _мені, _kdaj_, ptaž, nqt_, 
   {{0xad243f7b,0x747800df,0x00000000,0x00000000}},	//   سىنى, רנאג, --, --, 
   {{0x7f5dd2b0,0x00000000,0x00000000,0x00000000}},	//   maqq, --, --, --, 
   {{0x7f5dd2b1,0xddcc0034,0xdb080332,0x279400c7}},	//   laqq, ntaż, _cneá, ҧшыр, 
   {{0x64ac2220,0xb17c008d,0x2b440129,0xadd97c2b}},	//   nđić, אטור, _ffmc_, _умру_, 
   {{0x2368069c,0x2248207a,0x7f5dd2b2,0x39ac0421}},	//   _ndaj_, _otak_, naqq, _sēsē_, 
   {{0x7f5c0194,0x95940953,0x224801a9,0x0694007b}},	//   iaqq, ошні, _ntak_, قنية_, 
   {{0xfdf81d72,0x7f5dd2b3,0xd5e40212,0x68e40115}},	//   ्विस_, haqq, іжни, ŝida, 
   {{0x2249d2b4,0x6fd800d2,0xc2e40eac,0x7f5c0eec}},	//   _atak_, _líca, _গুলি_, kaqq, 
   {{0x7f5c0140,0xc708063f,0x758000f2,0x93580124}},	//   jaqq, ịrịb, _کیدم, шроу_, 
   {{0xfdf806e3,0x47d080de,0x7f5c025c,0x00000000}},	//   ्वास_, _زيور, daqq, --, 
   {{0x2368030a,0xe6b400db,0xa5f801f4,0x00000000}},	//   _edaj_, _رلىگ, _лечу_, --, 
   {{0xddcdd2b5,0x9f480589,0x224801c6,0x2fc0013f}},	//   mpaň, znaå_, _etak_, tjig_, 
   {{0x7f5c2ece,0x7778014b,0x23680010,0xb62001ec}},	//   gaqq, ngux, _gdaj_, _ﺫﻜ_, 
   {{0x91b00051,0x00000000,0x00000000,0x00000000}},	// [34340] _tuỳ_, --, --, --, 
   {{0x23680fb7,0x7f5c0140,0x0d200137,0xb1c8013d}},	//   _zdaj_, aaqq, дүгү, _уңга_, 
   {{0xfce1a15f,0x15800ed1,0x7f5c06be,0x00000000}},	//   мофо, ﯩﺴﺘﯩ, baqq, --, 
   {{0xddcc084c,0xa7fc0790,0xe8f801e0,0x2a440022}},	//   tuaţ, _avın, ҡһа_, зҭам, 
   {{0xe8f80831,0x8a0496f2,0xaca4acc3,0x29180306}},	//   әһе_, озде, _itọr, _úraz_, 
   {{0xf98c386e,0xd90c0b43,0x3eac00b5,0xe7ec00af}},	//   نبى_, گیم_, ægte_, _जगहा_, 
   {{0x6d5dd2b6,0xdb4c0133,0x00000000,0x00000000}},	//   _iera, _ڕێن_, --, --, 
   {{0x6d5dd2b7,0xd90c6ee9,0xf76c18a5,0x0bd43cc6}},	//   _hera, دیم_, ناً_, _بيرح, 
   {{0x6d5dd2b8,0x6fd806ed,0x00000000,0x00000000}},	//   _kera, _xíca, --, --, 
   {{0x998c00a2,0x3d0c000d,0x00000000,0x00000000}},	//   _rueŧ_, _तुडे_, --, --, 
   {{0x2919ad45,0x2249d2b9,0x69c80857,0x7f5c0784}},	//   _ára_, _stak_, _iode, yaqq, 
   {{0x6d5dd2ba,0x69c800d6,0xa29402d5,0x2248012d}},	//   _lera, _hode, памі, _ptak_, 
   {{0x6d5dd2bb,0x0584010b,0x7f5cc108,0x00000000}},	//   _oera, _дуйм, vaqq, --, 
   {{0x69c9d2bc,0xaca401f2,0x7f5c0135,0x071401ec}},	//   _jode, _atọr, waqq, _ﺳﻮﯓ_, 
   {{0x7f5c32ef,0x91b0004d,0xa1580116,0xddcc012d}},	//   taqq, _quý_, _қану_, rtaż, 
   {{0x6d5dd2bd,0x69c80dd4,0x6fd809c2,0x224801c4}},	//   _aera, _lode, _píca, _ttak_, 
   {{0x6d5dd2be,0x2249d2bf,0x7f5cd714,0xee840006}},	// [34350] _bera, _utak_, raqq, дыхо, 
   {{0x69c9d2c0,0x7f5dd2c1,0xa8040139,0x6f880050}},	//   _node, saqq, _huñğ, ٝنہِ_, 
   {{0x6d5c7c1d,0x7f5c03f0,0xaac400d1,0x00000000}},	//   _dera, paqq, ېتىن, --, 
   {{0x7f5dd2c2,0x6d5dd2c3,0x69c80165,0x00000000}},	//   qaqq, _eera, _aode, --, 
   {{0x7d75d2c4,0xd9441a92,0xaca400a2,0xd824009d}},	//   _واسط, пели, _buỳr, үдли, 
   {{0x69c9d2c5,0x985400d1,0xd9440114,0x6fd8013a}},	//   _code, птиш, чеки, _jícn, 
   {{0x3e90044e,0xa91c00d0,0x69cc023e,0xecf80354}},	//   ምደምታ_, _obľu, _तकरी, _дерш_, 
   {{0x69c80483,0x6d5dd2c6,0x6fd80306,0x629c0175}},	//   _eode, _zera, _lícn, kwso, 
   {{0x69c9d2c7,0x6d5dd2c8,0x7bd9d2c9,0x00000000}},	//   _fode, _yera, _iluu, --, 
   {{0x6d5d8f94,0x69c9d2ca,0xa3c804fa,0x00000000}},	//   _xera, _gode, लॉस_, --, 
   {{0x2b406db6,0xd91800cf,0x6d40013d,0x53a40150}},	//   žice_, _اياش_, _şmak, панб, 
   {{0x69c8bb06,0x7dd00205,0x00000000,0x00000000}},	//   _zode, _hısı, --, --, 
   {{0x7dd003ee,0xc7380375,0xa804008e,0x98b80165}},	//   _kısı, _התנת, _duñğ, _ęsę_, 
   {{0x7bd8013c,0xdb080139,0xf4800133,0x98140244}},	//   _lluu, _eneç, _قاعی, _ببڕا, 
   {{0x7dd00365,0x6d5dd2cb,0x398c00ac,0x7bd82252}},	//   _mısı, _rera, mısı_, _oluu, 
   {{0x6d5dd2cc,0x398ca85c,0xbf98017a,0x00000000}},	//   _sera, lısı_, _skêr, --, 
   {{0x6d5c37bd,0x69cc0c2e,0xded40023,0x00000000}},	// [34360] _pera, _तकली, _የርኢ_, --, 
   {{0xa7fc0598,0x398c456f,0x7bd9d2cd,0x6d5dd2ce}},	//   _avıl, nısı_, _aluu, _qera, 
   {{0x6d5ca927,0x7768020c,0x7bd80254,0xd00800f3}},	//   _vera, _odgx, _bluu, _гене_, 
   {{0x69c80f72,0x6d5dd2cf,0x398c00ac,0x6fb40137}},	//   _sode, _wera, hısı_, _تۅرا, 
   {{0x7bd801c7,0x398c0e2d,0x95800023,0x00000000}},	//   _dluu, kısı_, ቓሳትን_, --, 
   {{0x6d5d3bc1,0x69c8058a,0x7bd80254,0x7dd00205}},	//   _uera, _qode, _eluu, _cısı, 
   {{0x7648e57d,0x7bd816b8,0x7dd003e0,0x68e401e4}},	//   _atgy, _fluu, _dısı, ĝido, 
   {{0xbdd80ba1,0x7bd80549,0xb92000f1,0x68e401e4}},	//   _puèg, _gluu, رځلي, ŝido, 
   {{0x69c80664,0x6fd81a6b,0xbdd801c3,0x9f4800d8}},	//   _tode, _líco, _stèi, liaã_, 
   {{0x69c80024,0x9f6402d2,0x398c1f02,0x00000000}},	//   _uode, _ítök_, gısı_, --, 
   {{0xa3b40153,0x3514009d,0x00000000,0x00000000}},	//   _vėžį_, зжээ_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x629c0d27,0x6fd9d2d0,0xe8d001d9,0xf3640006}},	//   uwso, _pícn, _سۅکھ, этэн, 
   {{0x398c046c,0x04641608,0x3ebc0003,0x00000000}},	//   cısı_, _етим, _ħut_, --, 
   {{0x25080066,0x00000000,0x00000000,0x00000000}},	//   _برشی_, --, --, --, 
   {{0x34f80302,0x4abc0da0,0xf0e8215c,0x00000000}},	//   _להוד, ्हाव, سىقى_, --, 
   {{0x91b00051,0x00000000,0x00000000,0x00000000}},	// [34370] _quỹ_, --, --, --, 
   {{0x6b8400a3,0x7c845016,0x00000000,0x00000000}},	//   òign, зуде, --, --, 
   {{0x7bd9d2d1,0xa7fc0205,0x6bd4036b,0x00000000}},	//   _pluu, _avım, کتلر, --, 
   {{0xbdd9d2d2,0x398c0259,0x4428037e,0x2d9c002d}},	//   _suèd, zısı_, nmc_, ôver_, 
   {{0x398c0365,0xe8100bae,0x21200158,0xaac416ac}},	//   yısı_, ावना_, _hzhh_, فتون, 
   {{0x3f980333,0xf9c47724,0x7dd00dde,0x7c840117}},	//   lequ_, ящен, _qısı, _нубе, 
   {{0x69640372,0x6e21d2d3,0xa7fc0205,0x398c03e0}},	//   ردوق, _ëmba, _evım, vısı_, 
   {{0x3f9823e0,0x7bd9d2d4,0x9b582b97,0x1cc80327}},	//   nequ_, _uluu, _фиат_, ྲྀཾ_, 
   {{0xaa5803b7,0xd05c013f,0x398c0ac1,0x3b1c022e}},	//   _ниту_, _ɔyɑr, tısı_, _uzuq_, 
   {{0x7c2801e3,0x00000000,0x00000000,0x00000000}},	//   lmgr, --, --, --, 
   {{0x398c12ca,0x5ed000fe,0x7c2805ac,0x3dbc0154}},	//   rısı_, _সেমে, omgr, _ইতাল, 
   {{0x6fd8215a,0x3a3c9a23,0xd7c803e6,0xddcc0115}},	//   _cícl, _kuup_, _گوڵه_, draŭ, 
   {{0x398c2fbe,0x86a000fb,0x00000000,0x00000000}},	//   pısı_, _ағыҙ, --, --, 
   {{0xc58c07ae,0xc6900a1e,0xddcc01e4,0x5ed00154}},	//   _hồng_, _סאו_, fraŭ, _সেভে, 
   {{0x38646525,0x461000db,0x3a3c0254,0x25a800f1}},	//   nsnr_, _جوور, _luup_, _ردوي_, 
   {{0x53e01a04,0x00000000,0x00000000,0x00000000}},	//   _पतिश, --, --, --, 
   {{0x3a3c20ac,0x66040115,0xc58c004d,0x0dc92b4a}},	// [34380] _nuup_, _ŭiki, _mồng_, олай_, 
   {{0x270c01dc,0xc58c001e,0x7c28000f,0x38642d8b}},	//   ớng_, _lồng_, emgr, ksnr_, 
   {{0xe810012c,0x7de001e1,0x00000000,0x00000000}},	//   ावमा_, _sísù, --, --, 
   {{0xbdd8067c,0xc58c001e,0x00000000,0x00000000}},	//   _cuèb, _nồng_, --, --, 
   {{0x2005d2d5,0xdb1800d2,0x91d03d1d,0x09e401f4}},	//   élie_, tjwá, _हवाई, модн, 
   {{0xc3300302,0x8d75d2d6,0x39440175,0x8c9400d4}},	//   דוד_, _تاحا, gcns_, _орбі, 
   {{0xc58c01fb,0x3864365a,0x00000000,0x00000000}},	//   _bồng_, gsnr_, --, --, 
   {{0x46682c68,0x2d6400e8,0xc58c004d,0x00000000}},	//   ором_, _féeñ_, _cồng_, --, 
   {{0x4428056a,0xc58c0051,0x7c200356,0x00000000}},	//   vmc_, _dồng_, înre, --, 
   {{0xba2002d5,0x39440175,0x00000000,0x00000000}},	//   _адук, ccns_, --, --, 
   {{0x69d80158,0x47843740,0x2419d2d7,0x00000000}},	//   mkve, _жылб, зоны_, --, 
   {{0x69d9d2d8,0xc58c0208,0xdc440055,0xdcf4012d}},	//   lkve, _gồng_, _jīān, _uczą, 
   {{0xf7d425f9,0x3f9823e0,0x44280c67,0xd24c4144}},	//   _קודש_, vequ_, rmc_, یچی_, 
   {{0x69d9d2d9,0x00000000,0x00000000,0x00000000}},	//   nkve, --, --, --, 
   {{0x3f980a73,0x4428af1a,0x00000000,0x00000000}},	//   tequ_, pmc_, --, --, 
   {{0xf3900208,0x46d000cd,0x00000000,0x00000000}},	//   _hảng_, _तथाह, --, --, 
   {{0xceb41248,0x9f94f8b6,0xbdd8180f,0x69d826ae}},	// [34390] нәр_, _nåå_, _nuèc, kkve, 
   {{0x69d801a4,0x91c000d1,0xddcc054e,0xdce40419}},	//   jkve, _йәсл, draţ, rehľ, 
   {{0x61f407c4,0x3a3d702d,0xf39001fb,0x69d80158}},	//   mizl, _suup_, _mảng_, dkve, 
   {{0x61f40f7d,0x69d8257d,0x3a3c002e,0xf3900208}},	//   lizl, ekve, _puup_, _lảng_, 
   {{0x3d0c10f7,0xbdd80ba1,0xc58c001e,0x7c282963}},	//   _तुरे_, _cuèc, _rồng_, rmgr, 
   {{0x61f443eb,0x86440023,0xca740116,0x00000000}},	//   nizl, _ረዲኤት, رمىش_, --, 
   {{0x2b401a48,0x00000000,0x00000000,0x00000000}},	//   žica_, --, --, --, 
   {{0x69d80373,0xddcc054e,0x61f406be,0x00000000}},	//   akve, braţ, hizl, --, 
   {{0xf3900016,0xddcc0276,0x61f40f7d,0xc58c004d}},	//   _bảng_, craţ, kizl, _vồng_, 
   {{0x69d9d2da,0xf390001e,0x45040241,0x54c40108}},	//   ckve, _cảng_, _ìkọ̀_, ебоб, 
   {{0x61f4792d,0xc58c0051,0x00000000,0x00000000}},	//   dizl, _tồng_, --, --, 
   {{0x7d040009,0x00000000,0x00000000,0x00000000}},	//   _mxjs, --, --, --, 
   {{0x61f56569,0xf48000e5,0x00000000,0x00000000}},	//   fizl, راھی, --, --, 
   {{0x377400c7,0x61f5bd47,0x10a40a5b,0x00000000}},	//   _хыҧс, gizl, нигн, --, 
   {{0x9f9c01a8,0x3d0c01ad,0x7d00000f,0x00000000}},	//   tæðu_, _तुले_, ûnsl, --, 
   {{0x52840276,0x69d80306,0x00000000,0x00000000}},	//   _згиб, zkve, --, --, 
   {{0x9f9c008c,0xe810cead,0xc2b0010b,0x61f5d2db}},	// [343a0] ræðu_, ावता_, _йөрш, bizl, 
   {{0x2c480790,0x9f9401e3,0x10a40117,0x61f40e2d}},	//   _ağda_, _råå_, _зион, cizl, 
   {{0xbdd856ed,0x9f941506,0x69d803cd,0x60d40210}},	//   _suèc, _såå_, vkve, cyzm, 
   {{0xc2e4045e,0xddcc0276,0x4c15d2dc,0x9c000022}},	//   _গুটি_, traţ, رباس, аҧсе, 
   {{0x8a74013e,0x6e20c7b3,0x69d803cd,0xba700244}},	//   хилӣ_, _ëmbo, tkve, هاوت, 
   {{0x69343135,0x8f5004d3,0xbdd8067c,0x69d8030a}},	//   نکار, _شۆڕش, _vuèc, ukve, 
   {{0xd1cc0201,0x8b940006,0x00000000,0x00000000}},	//   _ጥናት_, _прач, --, --, 
   {{0xc7640dd8,0x69d9d2dd,0xf390004d,0x8d740150}},	//   رابى, skve, _sảng_, _تاڭا, 
   {{0x0eb001ad,0x98a800bc,0x36842e80,0x61f403e0}},	//   ीमिड, किउए, нсэн_, yizl, 
   {{0x6808013a,0x00000000,0x00000000,0x00000000}},	//   děde, --, --, --, 
   {{0xd1500020,0xddcc0006,0x61f40790,0x35f0084c}},	//   ራንስፖ, nraš, vizl, упэр, 
   {{0xd7ec16cb,0x6fec054e,0x870400c0,0xf520013d}},	//   _وڃي_, oşcu, _пяле, ыфын, 
   {{0xf390001e,0x61f5d2de,0xc2e400cc,0x823400ae}},	//   _tảng_, tizl, _গুজি_, فرسا, 
   {{0xddcc0006,0x5bdc00dc,0x60d4012d,0x00000000}},	//   kraš, _मत्व, tyzm, --, 
   {{0xddcc16a3,0x3d1c033f,0x88f401e1,0x00000000}},	//   jraš, _भरें_, _yàsẹ, --, 
   {{0x61f41ac8,0x60d4033f,0xddcdd2df,0x6f8401c6}},	//   sizl, ryzm, draš, лууж, 
   {{0x6fd9d2e0,0x1e14010b,0x443806be,0xddcc3e9d}},	// [343b0] _mích, вмая, _iiq_, eraš, 
   {{0x4439d2e1,0x6fd92315,0xddcc0030,0x6e200240}},	//   _hiq_, _lích, fraš, _ëmbl, 
   {{0x6fd80597,0xddcc0010,0xc2e403d4,0x00000000}},	//   _oích, graš, _গুচি_, --, 
   {{0x6fd80998,0xdfd41142,0x25bc0221,0x6d580008}},	//   _ních, _ромы, _lnvl_, ðvar, 
   {{0x4439d2e2,0x4bc001e0,0xddcc0153,0x00000000}},	//   _miq_, шөрг, araš, --, 
   {{0x4438006c,0xe9d80953,0xbdd86f8d,0xddccbc36}},	//   _liq_, нкі_, _etèr, braš, 
   {{0x7e7c0357,0x44380007,0x47a804c5,0xd260005f}},	//   luqp, _oiq_, কানী, _ziņā_, 
   {{0x443908b4,0x6fd800ae,0xc2e400fe,0x99dc01ef}},	//   _niq_, _cích, _গুছি_, _buňc, 
   {{0x5a35d2e3,0x6fd800c6,0xe6d401c0,0xa88404b3}},	//   _анат, _dích, гцээ, _ەلمى, 
   {{0x44380097,0x7c38c2c1,0x00000000,0x00000000}},	//   _aiq_, _hiur, --, --, 
   {{0x7c38123c,0x44380978,0xd1cc001f,0x6fd80332}},	//   _kiur, _biq_, _ጥናቱ_, _fích, 
   {{0x44380007,0x7c3806c8,0x7e7c0309,0x5274010b}},	//   _ciq_, _jiur, kuqp, кугу, 
   {{0x4439d2e4,0x7c38037e,0x7d00002d,0xddcc0010}},	//   _diq_, _miur, ûnsj, zraš, 
   {{0x7c389b4c,0x44380007,0x00000000,0x00000000}},	//   _liur, _eiq_, --, --, 
   {{0x4439d2e5,0xc9500375,0x0160045c,0x1c0021bd}},	//   _fiq_, שמל_, рксо, लचाल_, 
   {{0x44380399,0x7c380363,0xddcc09a8,0xc0001677}},	//   _giq_, _niur, vraš, апск, 
   {{0x0d85d2e6,0x7e7c0d04,0xaa94044e,0x200400d8}},	// [343c0] клан, guqp, _መፍትሒ_, élia_, 
   {{0x73c40184,0x7c3812cf,0xbdd80129,0x443801a9}},	//   _рәүе, _aiur, _stèr, _ziq_, 
   {{0x7c39d2e7,0x21744445,0x6fd9d2e8,0xa3c806e3}},	//   _biur, _суыр, _líci, लॉक_, 
   {{0x44380429,0x7c39d2e9,0xdb080142,0x15d40150}},	//   _xiq_, _ciur, _gaeë, _ﺘﻠﻴﻬ, 
   {{0x2b4009a8,0x6fd801e7,0xaaf40633,0x00000000}},	//   žico_, _rích, دتاچ, --, 
   {{0x6fd80af2,0xddccb9c1,0x7c380393,0x00000000}},	//   _sích, praš, _eiur, --, 
   {{0x7c382b1d,0x6fd80118,0x00000000,0x00000000}},	//   _fiur, _pích, --, --, 
   {{0x7c38b513,0x6e3c55e9,0x0ba802ef,0xa8180451}},	//   _giur, _hirb, _غازى_, رڪار_, 
   {{0xfaa19996,0x4439d2ea,0x6e3dd2eb,0x6fd823d1}},	//   _като, _riq_, _kirb, _vích, 
   {{0x4439d2ec,0x7c39d2ed,0xbdd8180f,0x6e3c0003}},	//   _siq_, _ziur, _luèn, _jirb, 
   {{0x6e3dd2ee,0x7d780302,0xa3d41513,0x4438047e}},	//   _mirb, וניו, гонч, _piq_, 
   {{0x7e7dd2ef,0xe37400fd,0x6fd800e4,0x4438022e}},	//   yuqp, ылмы, _uích, _qiq_, 
   {{0xa3c95256,0x6e3c7ea6,0x6595d2f0,0x99dc02f0}},	//   लॉग_, _oirb, _балу, _huňa, 
   {{0xaca402e3,0x6e3dd2f1,0x35d00108,0x00000000}},	//   _ahọp, _nirb, _вошё, --, 
   {{0x6569d2f2,0x44380978,0x20300092,0x7e7c0477}},	//   madh, _tiq_, _በዴሞክ, wuqp, 
   {{0x6569d2f3,0x442dd2f4,0xaca400b4,0x55500050}},	//   ladh, _òg_, _chọp, _پھیر, 
   {{0x6e3c4a98,0x63add2f5,0x7c39d2f6,0x65680175}},	// [343d0] _birb, _iaan, _riur, oadh, 
   {{0x3f7001dc,0x6569d2f7,0x63add2f8,0x7c39d2f9}},	//   ệu_, nadh, _haan, _siur, 
   {{0x6e3dd2fa,0x63add2fb,0x7c39d2fc,0x5c740220}},	//   _dirb, _kaan, _piur, улет, 
   {{0x63add2fd,0x6569d2fe,0x6e3c0437,0x7e7c0784}},	//   _jaan, hadh, _eirb, puqp, 
   {{0x7c381daa,0x6569d2ff,0x2019d300,0x1a640214}},	//   _viur, kadh, _iksi_, ایطی_, 
   {{0x63add301,0x6e3dd302,0x9f48002e,0x00000000}},	//   _laan, _girb, mnañ_, --, 
   {{0x7c39d303,0xc0d00020,0x6569d304,0x63ac02d0}},	//   _tiur, _የውሃ_, dadh, _oaan, 
   {{0x63add305,0x656801ab,0x28b80276,0x6e3c3fbd}},	//   _naan, eadh, тушэ_, _zirb, 
   {{0x6569b8c3,0x9f4807e4,0x00000000,0x00000000}},	//   fadh, nnañ_, --, --, 
   {{0x6fd9d306,0x24480042,0x9f48030a,0xe63401c6}},	//   _víci, _bûm_, inañ_, ихээ, 
   {{0x63add307,0x15b800fd,0x20180254,0x00000000}},	//   _baan, _җылы_, _oksi_, --, 
   {{0x63add308,0x2448002d,0x7bc8107d,0x00000000}},	//   _caan, _dûm_, njgu, --, 
   {{0x63add309,0x6569d30a,0x92f41fe2,0x6448058a}},	//   _daan, badh, учні, aqdi, 
   {{0x2019d30b,0xbdd8067c,0x24480042,0x6569d30c}},	//   _aksi_, _suèn, _fûm_, cadh, 
   {{0x63add30d,0xe0d400d6,0x24480295,0x6e3c01ab}},	//   _faan, ають, _gûm_, _rirb, 
   {{0x6e3dd30e,0xb2b40139,0xda6400ec,0x412400d8}},	//   _sirb, _кәгъ, _وڏ_, ѓото_, 
   {{0x6e3c0fac,0x9f480489,0x4f243740,0x9e640a11}},	// [343e0] _pirb, gnañ_, удаб, لالن, 
   {{0x63add30f,0x201853b5,0x00000000,0x00000000}},	//   _zaan, _eksi_, --, --, 
   {{0x63add310,0x20180418,0x6e3dd311,0x2d8d8c3c}},	//   _yaan, _fksi_, _virb, _ödem_, 
   {{0x6e3c2ba9,0xcb0805a9,0x3ebc1710,0x63add312}},	//   _wirb, ىيان_, _šute_, _xaan, 
   {{0x6e3dd313,0x6569d314,0xfb845439,0xa3c852f2}},	//   _tirb, yadh, ادمی, लॉट_, 
   {{0x28f9d315,0x48a9d316,0x6e3c007b,0x8d7400db}},	//   кель_, етим_, _uirb, _حاحا, 
   {{0x2018049b,0x65680882,0xe810098b,0x00000000}},	//   _yksi_, vadh, ावला_, --, 
   {{0x61d04d53,0x9f481f60,0x6569d317,0x2448002d}},	//   _सक्ष, nnað_, wadh, _rûm_, 
   {{0xf76d3b7b,0x63add318,0x6569d319,0x64480007}},	//   ساي_, _raan, tadh, wqdi, 
   {{0x19f8030d,0x00000000,0x00000000,0x00000000}},	//   _иэхь_, --, --, --, 
   {{0x63add31a,0x6569d31b,0x9f4809cc,0x2d9800ca}},	//   _paan, radh, knað_, _mbre_, 
   {{0x63acd515,0xd6d8033f,0x00000000,0x00000000}},	//   _qaan, był_, --, --, 
   {{0x6569d31c,0x63add31d,0x2d9800f7,0xf2e4004e}},	//   padh, _vaan, _obre_, бюро, 
   {{0x63add31e,0x855400dd,0xd4f43463,0xe5344f88}},	//   _waan, _حیدر_, اتیژ, _кель, 
   {{0x63adbfba,0x6fd80228,0x9f480008,0x800407d8}},	//   _taan, _lícu, fnað_, гчае, 
   {{0x9f4809f3,0xa3e8227c,0xa2dc07f7,0x9f5401d5}},	//   gnað_, _यति_, _पथप्, рвач, 
   {{0xbdd8180f,0x06d40c58,0xa2c400fd,0xe4d800f2}},	// [343f0] _fuèl, _তেতি, _тәнк, _سوکت_, 
   {{0x9f480489,0x00000000,0x00000000,0x00000000}},	//   rnañ_, --, --, --, 
   {{0xa3e820f0,0xd6d80034,0xbd6801e0,0x5f9402e8}},	//   _यता_, zył_, _үрге_, _кинт, 
   {{0x2d99d31f,0x2cb8003e,0x7bc80369,0x2019d320}},	//   _ebre_, _drrd_, ujgu, _uksi_, 
   {{0x3f88011c,0x290c0009,0xddcc00d0,0x5a35d321}},	//   _iccu_, _axda_, erať, андт, 
   {{0x02a001f2,0xcdc00131,0x00000000,0x00000000}},	//   _gwụọ, _мәхп, --, --, 
   {{0x6dc400cf,0x888001d5,0x60340064,0x00000000}},	//   _دۅلۅ, قیلن, _sąmy, --, 
   {{0xccf023e4,0x96941188,0xac383fe2,0xee7c0023}},	//   _וכל_, арош, _مسقط_, _ክርእዩ_, 
   {{0xe8940022,0x00000000,0x00000000,0x00000000}},	//   _ҳахь, --, --, --, 
   {{0xdcf42799,0x3b1c0309,0xd6d8008e,0x00000000}},	//   _hazı, _iyuq_, етү_, --, 
   {{0xdcf40c07,0x784000dd,0x3f88003a,0xf7702a77}},	//   _kazı, _bőve, _occu_, _هاش_, 
   {{0x3f880327,0xdcf40139,0x61e408a5,0x971400c0}},	//   _nccu_, _jazı, _alhl, _кмец, 
   {{0x9f48022c,0xdcf40205,0x00000000,0x00000000}},	//   vnað_, _mazı, --, --, 
   {{0xdcf441d5,0xd9e40cb4,0x3f89d322,0x249c05da}},	//   _lazı, कसित_, _accu_, _fpvm_, 
   {{0x0594090f,0x9f480252,0x6e200de2,0xc5f8011a}},	//   _خانگ, tnað_, _ëmbi, _בפסט, 
   {{0x60c03e04,0xdcf4d304,0xee800092,0x00000000}},	//   ålma, _nazı, _ይሞክሩ_, --, 
  
   {{0x8d641c22,0x9f4805f7,0x00000000,0x00000000}},	// [34400] ивае, rnað_, --, --, 
   {{0x3f880c95,0x8d553a2a,0xef94030f,0x9f480d12}},	//   _eccu_, ртач, _گیرد, snað_, 
   {{0x0b45d323,0x0c7521c9,0x3b1c0309,0x6fd800d2}},	//   анен, شداد, _ayuq_, _sícu, 
   {{0x3219d324,0xdcf48af3,0x4f940063,0x00000000}},	//   lory_, _cazı, _троу, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x32180fac,0x3c2400c7,0xc0d00092,0xfa308944}},	//   nory_, rõva_, _የግሉ_, يرود, 
   {{0x99645566,0xdcf462c7,0x07e57e68,0x79a001ec}},	//   стіл, _fazı, ицим, ірше, 
   {{0xd90cf968,0x3219662e,0xa7fc0724,0xdcf45775}},	//   رین_, hory_, _avır, _gazı, 
   {{0x3219d325,0x249c0129,0x6b84067c,0x00000000}},	//   kory_, _spvm_, òigu, --, 
   {{0x1dc800cd,0x6b8401e7,0x00000000,0x00000000}},	//   रायत, óigf, --, --, 
   {{0xdcf41ae6,0xc8c9bca2,0x3219d326,0x07a402d5}},	//   _yazı, _جوان_, dory_, _ваен, 
   {{0xc6b4031c,0x1aec0154,0x225800fb,0xb7d0007b}},	//   ནའདུ, _ছুটে_, лимы_, _وقلب, 
   {{0x1dc801bc,0xf8b401c6,0x321844ef,0x1aec00eb}},	//   रामत, _бөө_, fory_, জপথে_, 
   {{0x3d0c13b4,0x3219d327,0x98a80115,0x00000000}},	//   _तुझे_, gory_, ŝaĥ_, --, 
   {{0x91b800fe,0x3f64f239,0x241800fd,0x00000000}},	//   ুসংখ, итаб, _йокы_, --, 
   {{0x85b80451,0x98a40024,0x7cc416d0,0x00000000}},	//   _ساڻس_, _eglė_, یزام, --, 
   {{0x32194a47,0x61e4073c,0xdcf403be,0x6d5800ac}},	// [34410] bory_, _tlhl, _razı, ıvan, 
   {{0xc0d00020,0x2228c5f2,0x32180076,0x4084d63e}},	//   _የግል_, _حزبی_, cory_, _кумб, 
   {{0x331800f8,0x6808012c,0x723400c6,0xc0c847ce}},	//   _مزید_, vědn, _بريط, _рупе_, 
   {{0xdcf4467d,0x22480166,0x00000000,0x00000000}},	//   _qazı, _kuak_, --, --, 
   {{0x6fd9463e,0xfaa4234c,0x22482a1f,0xdcf4008e}},	//   _víct, ршен, _juak_, _vazı, 
   {{0x22483223,0x961c0054,0x1988011b,0x186801b9}},	//   _muak_, kuņa, убки_, гаки_, 
   {{0x6ce410f5,0x2249d328,0xfb8402d5,0xdcf40205}},	//   _діте, _luak_, _вызн, _tazı, 
   {{0x321805dd,0x00000000,0x00000000,0x00000000}},	//   zory_, --, --, --, 
   {{0x1959d329,0x2240123c,0x576401ec,0x74540092}},	//   _базы_, _oihk_, анқұ, _የተፋጠ, 
   {{0x74540020,0x55e4034b,0x487000db,0x00000000}},	//   _የተፈጠ, сооб, زگۅس, --, 
   {{0x32187429,0x80d409bd,0x6e20025a,0x23680156}},	//   vory_, _ডেস্, _êmbe, _beaj_, 
   {{0x224805b1,0xd2f801c0,0x3219d32a,0x740800eb}},	//   _buak_, гэгч_, wory_, োষ্ট_, 
   {{0x22480ac5,0xe730e9d0,0xddcdd32b,0x439002d5}},	//   _cuak_, _قصه_, mpaņ, чаўс, 
   {{0x7659d32c,0x3c2400e4,0x2588013a,0x00000000}},	//   mpuy, kõvo_, _vůlí_, --, 
   {{0x3219d32d,0x47a8015b,0xddcc033f,0x2240002f}},	//   rory_, কারী, braź, _dihk_, 
   {{0x2b406b48,0x3ebc0960,0x8d2801d5,0x81b800cc}},	//   žici_, _šuta_, қоев_, _অকণ_, 
   {{0x32183e91,0x8e09d32e,0x6d580165,0x00000000}},	// [34420] pory_, гнав_, ñvao, --, 
   {{0x765800c7,0x16b4000d,0xad8400cf,0x00000000}},	//   ipuy, _अछैब, تارۇ, --, 
   {{0x1d180953,0x4370036b,0xc8a405d7,0x8fa4055f}},	//   аюць_, _ظهیر, _कैंट, _лане, 
   {{0x680800bc,0x0ae8113e,0x8fa400c7,0x0fd00408}},	//   vědo, лдей_, _уаме, _хιин, 
   {{0x2b44020b,0x00000000,0x00000000,0x00000000}},	//   _vgmc_, --, --, --, 
   {{0x5ed0015b,0x00000000,0x00000000,0x00000000}},	//   _সেকে, --, --, --, 
   {{0x6fcc0490,0xee0002f5,0x7d00000f,0xddcc012d}},	//   हापू, ্তদশ_, ûnst, yraź, 
   {{0xdb080086,0x765800ca,0x00000000,0x00000000}},	//   _eneñ, fpuy, --, --, 
   {{0x76583399,0xdce40882,0xd90c04d3,0x47a80eac}},	//   gpuy, mahā, _ییه_, কালী, 
   {{0x2248003e,0x64744db0,0x00000000,0x00000000}},	//   _ruak_, огоу, --, --, 
   {{0x2249d32f,0x6e20002e,0x1dc81b76,0x200400e5}},	//   _suak_, _ëmbu, रातत, élik_, 
   {{0x2249d330,0xdce59601,0xc6a40a5b,0xee0000cc}},	//   _puak_, nahā, _грки, ্তিশ_, 
   {{0x7dd80194,0x224801c7,0x23680156,0xddcc033f}},	//   _kîst, _quak_, _veaj_, tuaż, 
   {{0x60c008cb,0x1b14009e,0x6d580156,0x2c480205}},	//   ålmo, তেকে_, ñval, _eğdi_, 
   {{0xdce404fe,0x6adc0154,0x00000000,0x00000000}},	//   kahā, _মেমো, --, --, 
   {{0x7dcc02bf,0x22486085,0xd31802e3,0x3c2400e4}},	//   vаsс, _tuak_, ọtụr, võvo_, 
   {{0x9df8c393,0xd32401e4,0x752c033f,0xdd940026}},	// [34430] анат_, jekʈ, ęcze, жазы, 
   {{0xc11801ec,0x7e7000ef,0x00000000,0x00000000}},	//   _бүгi, _ķepī, --, --, 
   {{0x6608005c,0xdfd401f4,0x00000000,0x00000000}},	//   indk, _доны, --, --, 
   {{0xb8a00092,0x3c2400c7,0xbfa800d8,0x00000000}},	//   ጋግጣል_, rõvo_, _стое_, --, 
   {{0x2009d331,0x00000000,0x00000000,0x00000000}},	//   mnai_, --, --, --, 
   {{0xe9a8425b,0xed5805f5,0x2009d332,0x6b8401ab}},	//   مدىن_, _гоё_, lnai_, òigr, 
   {{0xbdd80ba1,0x48501079,0x2009d333,0x99dc00a2}},	//   _nuèi, وپوز, onai_, _huňk, 
   {{0x2009d334,0x66080037,0xab940114,0x00000000}},	//   nnai_, endk, _насљ, --, 
   {{0x6459d335,0x2009d336,0x6b8401e7,0x4645d337}},	//   _atvi, inai_, óige, озын_, 
   {{0xa5e80032,0x765803f0,0x00000000,0x00000000}},	//   йлыҡ_, rpuy, --, --, 
   {{0x2008008b,0xbdd8067c,0x64580175,0x76580790}},	//   knai_, _cuèi, _ctvi, spuy, 
   {{0xa3e80882,0x67d402a9,0x2d8c05d1,0x200801d3}},	//   _यतः_, _ноху, _ödev_, jnai_, 
   {{0x8c181203,0x6458022f,0xcfa8158b,0x2c48010b}},	//   שורי, _etvi, یارم_, _işde_, 
   {{0x20080fda,0xf5e400ec,0x00000000,0x00000000}},	//   enai_, _چڙھي_, --, --, 
   {{0x7640004b,0x764861b1,0x00000000,0x00000000}},	//   _iiny, _hugy, --, --, 
   {{0x54342cb0,0x2009d338,0x7649d339,0x7640037e}},	//   _برتر, gnai_, _kugy, _hiny, 
   {{0xdce40882,0x2bc80490,0x00000000,0x00000000}},	// [34440] vahā, ळासा, --, --, 
   {{0x7641d33a,0xa7fc0724,0x7648064a,0x7768002e}},	//   _jiny, _awıl, _mugy, _legx, 
   {{0x764804ba,0xcb44a2b6,0x00000000,0x00000000}},	//   _lugy, охли, --, --, 
   {{0x7768014b,0x764802d0,0x20080042,0x8b2401f4}},	//   _negx, _ougy, cnai_, одее, 
   {{0x1fb467b0,0x764800c0,0x61f8032e,0x00000000}},	//   _эсэр, _nugy, _áalþ, --, 
   {{0x7641d33b,0x14c811bc,0x66e001e1,0xc8780798}},	//   _niny, िमाण, _lákú, аџи_, 
   {{0x7768379d,0xd7c40574,0x76480064,0x00000000}},	//   _begx, वांच, _augy, --, 
   {{0x7641d33c,0x645801fa,0x76483902,0x5ed00154}},	//   _ainy, _rtvi, _bugy, _সেটে, 
   {{0x76409390,0x2004003a,0xaab83c5a,0x00000000}},	//   _biny, élii_, _دگار_, --, 
   {{0x76480280,0x7641d33d,0x20080024,0x6608007c}},	//   _dugy, _ciny, znai_, undk, 
   {{0x7641d33e,0xbdd8068c,0xba14004b,0x20080024}},	//   _diny, _quèi, _بيلا_, ynai_, 
   {{0x86c5d33f,0xb7d401d9,0x2b4004a7,0xbdd8067c}},	//   _ويان, _وولا_, žicu_, _vuèi, 
   {{0x7641d340,0x76480083,0x630401b9,0x940403e3}},	//   _finy, _gugy, سوسل, ntlə_, 
   {{0x7641d341,0x35640395,0x00000000,0x00000000}},	//   _giny, _дрън_, --, --, 
   {{0x64581a84,0x1dc8012c,0xab8c010e,0x35500345}},	//   _utvi, रासत, _çöwü, _تۆپز, 
   {{0x68500f16,0x7640555e,0x8ed402f5,0x2009d342}},	//   _ሚኒስት, _ziny, _সেইগ, unai_, 
   {{0x200870a6,0x7641d343,0x6e94084c,0x00000000}},	// [34450] rnai_, _yiny, миту, --, 
   {{0x764007a9,0x7d240108,0x20080205,0x00000000}},	//   _xiny, офее, snai_, --, 
   {{0xac94016c,0x20080153,0x3204007f,0x00000000}},	//   дахш, pnai_, èmye_, --, 
   {{0xf534008f,0x3eac005c,0x940403b9,0x00000000}},	//   קטאר_, ægts_, ftlə_, --, 
   {{0xddcc0e04,0x6bd401d5,0xbd68009b,0x00000000}},	//   mraž, بتلر, _врбе_, --, 
   {{0xf9c4026b,0x00000000,0x00000000,0x00000000}},	//   ющен, --, --, --, 
   {{0x7649d344,0x6e2000e4,0xe9a800cf,0x00000000}},	//   _sugy, _êmba, زدون_, --, 
   {{0xac1910b2,0x1dc862be,0x6e2004e6,0x3f980135}},	//   _досу_, रावत, _ëmbr, nfqu_, 
   {{0xeab1d345,0xadc40248,0x15b889d0,0x78b40153}},	//   _لعل_, _afẹr, быны_, _žavė, 
   {{0xe708425b,0x764000b5,0x2d8c01e3,0xddcc013a}},	//   تتىن_, _qiny, _ödet_, hraž, 
   {{0x76480134,0xa490824e,0x00000000,0x00000000}},	//   _wugy, نیوت, --, --, 
   {{0x7641d346,0x76481418,0x8898011a,0x00000000}},	//   _winy, _tugy, _לבעי, --, 
   {{0x7641d347,0xddcd0911,0x47d03bd7,0x00000000}},	//   _tiny, draž, _سيور, --, 
   {{0xd1b800db,0xd3780137,0x67380419,0x00000000}},	//   حاحا_, шчү_, ňajú, --, 
   {{0xddcd0517,0x98bc00bc,0x00000000,0x00000000}},	//   gsaŭ, ्मिए, --, --, 
   {{0x8ca40c2e,0xddcc0024,0x3f9c0694,0xd8380100}},	//   _टैगो, graž, _ñuul_, nmō_, 
   {{0x29000069,0xbea10462,0x8e840108,0x00000000}},	// [34460] ̄ia_, натк, ягае, --, 
   {{0x42f80375,0x0b740023,0xafe401d5,0x98bc09ab}},	//   _להפס, _ከምዘይ_, чоғл, ्माए, 
   {{0xddcc0fb7,0x41d8011a,0xe6a812eb,0xcfe80066}},	//   braž, _החיס, _कन्ज, _هفده_, 
   {{0x645c00c8,0x1b14015b,0xf98c1870,0x00000000}},	//   ŭrig, তেছে_, ۇبى_, --, 
   {{0x43800131,0xaa4400c7,0x00000000,0x00000000}},	//   ﯨﺪﯨﻦ_, дҵал, --, --, 
   {{0x2d8c08cb,0x8274010f,0x00000000,0x00000000}},	//   _øde_, לענע_, --, --, 
   {{0x38c4ca0f,0x00000000,0x00000000,0x00000000}},	//   зуын_, --, --, --, 
   {{0x940406be,0x00000000,0x00000000,0x00000000}},	//   ptlə_, --, --, --, 
   {{0x2e340267,0x862445fb,0x00000000,0x00000000}},	//   räff_, зьне, --, --, 
   {{0xddcc0e3c,0x00000000,0x00000000,0x00000000}},	//   zraž, --, --, --, 
   {{0x69c99316,0xdc4402b5,0x81b80183,0x54780092}},	//   _inde, _hūān, _অকল_, _በደማቅ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xddcdd348,0x6594c583,0x752c012d,0xbc1800df}},	//   vraž, _жалу, ęcza, מוטש, 
   {{0x224401e6,0x00000000,0x00000000,0x00000000}},	//   ölk_, --, --, --, 
   {{0xddcc1326,0x69c914f2,0x7598011a,0x37ac0154}},	//   traž, _mnde, _הסוג, কারর, 
   {{0xddcc01e4,0x00000000,0x00000000,0x00000000}},	//   rsaŭ, --, --, --, 
   {{0x69c951e9,0x4390005e,0xceb41cd1,0xe8f00220}},	// [34470] _onde, _жақс, мәр_, _үшiн_, 
   {{0x816801b9,0x9f48007b,0xadb4444e,0x00000000}},	//   _уриб_, mhaí_, нбуш, --, 
   {{0x26c00006,0x5c7400a8,0xddcc033f,0x3c24000d}},	//   _šiol_, флет, mraż, lõvi_, 
   {{0x5214004e,0xbff800cc,0x00000000,0x00000000}},	//   _ндөт, _আৱৰণ_, --, --, 
   {{0x69c9d349,0x00000000,0x00000000,0x00000000}},	//   _bnde, --, --, --, 
   {{0xceb0011a,0x00000000,0x00000000,0x00000000}},	//   _שים_, --, --, --, 
   {{0x9f4803bd,0x31580a7c,0x00000000,0x00000000}},	//   liañ_, ליגן_, --, --, 
   {{0x2d8c03ee,0x2804063f,0x656401a6,0x00000000}},	//   _öder_, ịanụ_, _điha, --, 
   {{0xc68c143e,0x9f480156,0x00000000,0x00000000}},	//   لِي_, niañ_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7bd805da,0x9f480489,0x6d580165,0xddcc012d}},	//   _kouu, hiañ_, ñvai, draż, 
   {{0xa7fc03e0,0xe7080137,0x1dc80118,0x00000000}},	//   _atıf, تتۉن_, राँत, --, 
   {{0x69c9d34a,0x7bd8007f,0xe818708e,0x00000000}},	//   _ynde, _mouu, _عزمت_, --, 
   {{0xe618005e,0x7bd80270,0x9f480489,0xddcc012d}},	//   _еді_, _louu, diañ_, graż, 
   {{0xd1305285,0x77400345,0x00000000,0x00000000}},	//   ئمز_, _تێکم, --, --, 
   {{0x7bd816b8,0x9f49d34b,0x00000000,0x00000000}},	//   _nouu, fiañ_, --, --, 
   {{0x1dc83eaf,0x9f480597,0xddcc033f,0x81400014}},	// [34480] रांत, chaí_, braż, ٹھیم, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7bd8026c,0x200400db,0x1dc000c7,0x00000000}},	//   _bouu, èlic_, ыҩрн, --, 
   {{0xec3401b9,0xaa6802d3,0x9f48030a,0x26c00064}},	//   روشگ, _ዝተረጋ, biañ_, _šiom_, 
   {{0xbb400953,0x99dc002e,0x69c80175,0x6e200022}},	//   вецк, _luňu, _pnde, _êmbo, 
   {{0x6fb40574,0xddcc054e,0x00000000,0x00000000}},	//   _उघडू, rsaţ, --, --, 
   {{0x69c80393,0xddcc008f,0x8b9400d8,0x940c0073}},	//   _vnde, npaŝ, _орач, ाचाच_, 
   {{0x5fd00574,0xc6e400d4,0xf8000830,0x4c34009d}},	//   हायल, діоп, кчын, _цэгт, 
   {{0xbdd8068c,0x368405f5,0xf41400eb,0x00000000}},	//   _iuèr, мсэн_, সতার_, --, 
   {{0x99dc002e,0x752c068f,0x7bd80036,0x08c42377}},	//   _buňu, ęczn, _zouu, _обзн, 
   {{0x35f40597,0x351405f5,0xbdd80022,0x9f480489}},	//   بريد_, джээ_, _kuèr, ziañ_, 
   {{0x9f4800c6,0x99dc00a2,0xe4e40131,0x066401ec}},	//   thaí_, _duňu, _үскү, _قاتپ, 
   {{0x25084354,0xa7fc0139,0x46300022,0xddcc6f39}},	//   ترکی_, _atıg, _иҭир, traż, 
   {{0xddcc16a3,0x9f4805c7,0xefbc0092,0x00000000}},	//   ksaš, viañ_, _ሲበዛ_, --, 
   {{0xdef0001f,0x9b2c0055,0x85f8002b,0x00000000}},	//   ጃውን_, _dūṣā, cīrṇ, --, 
   {{0xa7fc013d,0x00000000,0x00000000,0x00000000}},	//   _avız, --, --, --, 
   {{0xddcc0115,0x26c00064,0x680801ef,0x00000000}},	// [34490] apaŝ, _šioj_, bědv, --, 
   {{0x9f480dd4,0x44286729,0x25ac0368,0x7bd9d34c}},	//   riañ_, llc_, nedl_, _souu, 
   {{0x4429d34d,0x412000e5,0x00000000,0x00000000}},	//   olc_, _شہرق, --, --, 
   {{0x200c0295,0x1a646813,0x6d4001e4,0x9f4805c7}},	//   _ñei_, فیری_, _ŝmac, piañ_, 
   {{0x44281552,0xbdd8067c,0x2ef40153,0x00000000}},	//   ilc_, _quès, _азяр, --, 
   {{0x7bd8007f,0xe9d802d5,0x95800023,0x25ac01ef}},	//   _wouu, мкі_, ሓታትን_, jedl_, 
   {{0x6c55d34e,0x44280010,0x18a4010a,0x02c80303}},	//   _аксу, klc_, хайм, ामुन, 
   {{0xbdd82508,0xd77400c6,0xe64c0092,0x00000000}},	//   _guèr, رابع, _አነጋጋ, --, 
   {{0xd7086582,0x15b800ee,0x44280327,0x99dc00a2}},	//   яние_, пыны_, dlc_, _suňu, 
   {{0x7c28f971,0xa7fc0139,0x44280165,0x38c8013d}},	//   llgr, _atıd, elc_, _муен_, 
   {{0x442800b5,0x7c280af9,0x752c012d,0x00000000}},	//   flc_, olgr, ęczo, --, 
   {{0xa3c4000d,0x00000000,0x00000000,0x00000000}},	//   _उऋण_, --, --, --, 
   {{0xc7d413e2,0x1ae0015b,0x9b2c00b8,0x09b00154}},	//   _רוני_, _খেতে_, _pūṣā, চারা, 
   {{0xd1d0069c,0x7c283628,0x645c04d4,0x4428030a}},	//   _ከምቲ_, hlgr, íric, alc_, 
   {{0xc950025d,0xdddc012d,0x00000000,0x00000000}},	//   רמל_, łyśm, --, --, 
   {{0x4429d34f,0xddcc0115,0x1ea800ec,0x645c0115}},	//   clc_, rpaŝ, ڀالي_, ŭric, 
   {{0x8d641e2d,0x2004004e,0xddcdd350,0x92b400ae}},	// [344a0] евзе, èlia_, wsaš, _أحبا, 
   {{0x7c28178a,0xfc440306,0x7c3800d7,0x4d140108}},	//   elgr, _šípy_, _ďura, ньет, 
   {{0xfce1d351,0xd1d002d3,0x7d9165f2,0x4d14b34e}},	//   лофо, _ከምታ_, المؤ, хьат, 
   {{0xbdd80ba1,0x7c2804cc,0xb99000d1,0x00000000}},	//   _quèr, glgr, ۇشىغ, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xddcc05d1,0x4278008f,0x7c2802d0,0x00000000}},	//   mpaş, לאנג, algr, --, 
   {{0x6d5cfe96,0x99640220,0x25ac00bc,0xcb680107}},	//   _ifra, ттіл, vedl_, _наве_, 
   {{0x6ec4258d,0x3ebdd352,0x8b640150,0x8c4429a3}},	//   रिपु, _šuti_, _سارم, _чебе, 
   {{0xa614026a,0xddcc0790,0x44280175,0x9a240137}},	//   кмич, npaş, vlc_, رعۇن, 
   {{0xe9c400c7,0x5b359ffa,0xba200064,0xf64c0137}},	//   _шазҿ, _рэсу, _бдук, حئي_, 
   {{0x6d5c016b,0x7c4400b5,0xf990008f,0x241803f5}},	//   _mfra, _årræ, _תרע_, доны_, 
   {{0x25b80010,0x3c74011a,0x00000000,0x00000000}},	//   žrl_, עתכם_, --, --, 
   {{0xe5b5d353,0x6d5c0699,0x4428eb76,0xf8b40137}},	//   _айлы, _ofra, rlc_, _жөө_, 
   {{0x4428030d,0x45340150,0xf7400212,0x7d0020ab}},	//   slc_, _كىشر, _сечо, únsk, 
   {{0x69d801f5,0x65680200,0x00000000,0x00000000}},	//   ijve, mbdh, --, --, 
   {{0x6d5d5762,0xddcc0205,0x00000000,0x00000000}},	//   _afra, fpaş, --, --, 
   {{0x6d5c0175,0x65680009,0x41e4109a,0x00000000}},	// [344b0] _bfra, obdh, _зіна, --, 
   {{0x629ce3e3,0xad2408b0,0x63bc032e,0x73380166}},	//   mtso, گىمى, ldsn, _языр_, 
   {{0x6d5dd354,0xbdd800db,0x63bc03ac,0x30e400c0}},	//   _dfra, _quèq, odsn, _біяб, 
   {{0x6d5dd355,0x629c00fb,0xad240131,0xdcb00208}},	//   _efra, otso, دىمى, _ẩm_, 
   {{0x629dd356,0x6d5c00a9,0xdb140086,0x63bc0373}},	//   ntso, _ffra, _òbüi, idsn, 
   {{0xdb180a40,0x629dd357,0x69d80200,0x00000000}},	//   ndwé, itso, gjve, --, 
   {{0x6e2000d2,0x629c0036,0x00000000,0x00000000}},	//   _ímba, htso, --, --, 
   {{0x629c1f53,0x9bc801ec,0xa7fc03e3,0x63bc005c}},	//   ktso, _تورك_, _atıb, jdsn, 
   {{0x629c61b0,0xd5b0575b,0x19581d37,0x645c063f}},	//   jtso, لفظ_, _жазы_, ̣rit, 
   {{0x629c03cd,0x55e41d5b,0x00000000,0x00000000}},	//   dtso, тооб, --, --, 
   {{0x629c01e0,0x00000000,0x00000000,0x00000000}},	//   etso, --, --, --, 
   {{0x645c0f47,0x00000000,0x00000000,0x00000000}},	//   íria, --, --, --, 
   {{0x629dd358,0x15b8004e,0x00000000,0x00000000}},	//   gtso, _жыйы_, --, --, 
   {{0x61f4031c,0x00000000,0x00000000,0x00000000}},	//   ghzl, --, --, --, 
   {{0x629dd359,0x6ec528d3,0x412400e9,0x00000000}},	//   atso, रिभु, воро_, --, 
   {{0x6d5dd35a,0xddcc0790,0xc0e00120,0x934401af}},	//   _sfra, tpaş, шоск, _инйе, 
   {{0xb8d00003,0xcf44ed7b,0x00000000,0x00000000}},	// [344c0] _ཞར_, тнай, --, --, 
   {{0xbea0bcaa,0xddcc7aa0,0x00000000,0x00000000}},	//   рафк, rpaş, --, --, 
   {{0x8c45835b,0x317807de,0x4fc40124,0x00000000}},	//   веже, marz_, _ҧсҭа, --, 
   {{0x31780034,0xcb091d4b,0x00000000,0x00000000}},	//   larz_, ويان_, --, --, 
   {{0x35b4000d,0xde741291,0x00000000,0x00000000}},	//   _असढ़, _مدّع, --, --, 
   {{0x6d5c379d,0x693404fb,0x3178012d,0xc76400d1}},	//   _ufra, هکار, narz_, ھابى, 
   {{0x63bc00b5,0x2d98054e,0x39c4012d,0x7c7801f0}},	//   ydsn, _icre_, लाड़ि, _оштӣ_, 
   {{0x317835ca,0xfbbc12eb,0xc5e800cd,0x00000000}},	//   harz_, _एफएम, टस्य_, --, 
   {{0x4a45d35b,0x317805ff,0xbb402e70,0xa7fc3361}},	//   _анав, karz_, _ветк, _atıc, 
   {{0x31780210,0x00000000,0x00000000,0x00000000}},	//   jarz_, --, --, --, 
   {{0x02c800dc,0x31780210,0xe3740166,0x00000000}},	//   ाम्न, darz_, ллны, --, 
   {{0x629ca2ec,0xbf980120,0x78f8010f,0x00000000}},	//   ttso, _amên, _קלאפ, --, 
   {{0x61e0049f,0x63bc4bc1,0x629c007f,0x00000000}},	//   öllo, rdsn, utso, --, 
   {{0x629c152d,0x3178030a,0x00000000,0x00000000}},	//   rtso, garz_, --, --, 
   {{0xe5b40032,0x6608058a,0xdd9400fb,0x00000000}},	//   _айһы, midk, ҫабы, --, 
   {{0x6609d35c,0xc0f002d3,0x2d98123b,0x46b409fa}},	//   lidk, _ሃይለ_, _acre_, _अनाह, 
   {{0x644dd35d,0xa15842ec,0x31788e64,0x00000000}},	// [344d0] _iiai, _папу_, barz_, --, 
   {{0x644dd35e,0x280402e3,0x6608020c,0x443806be}},	//   _hiai, ịahụ_, nidk, _hhq_, 
   {{0x644dd35f,0xad242928,0x2cb80198,0x2098008e}},	//   _kiai, لىكى, _csrd_, _якны_, 
   {{0xddcc0030,0xbe60030c,0x66080067,0x6d580165}},	//   dsať, _نۇري, hidk, ñvar, 
   {{0x2009d360,0x644c0851,0x9aa45fb1,0x66080009}},	//   miai_, _miai, امتو, kidk, 
   {{0x20084077,0xe9a8302a,0x644dd361,0x2cb8003e}},	//   liai_, ندىن_, _liai, _fsrd_, 
   {{0x644c0751,0x645c063f,0x5a3402dd,0x6609d362}},	//   _oiai, ̣rir, _ұнат, didk, 
   {{0x20084077,0x9b45d363,0x644c0851,0xae680014}},	//   niai_, _منزو, _niai, _سٕہن_, 
   {{0x7c38015c,0x5b14026a,0x645dd364,0x25bc022e}},	//   _ihur, _смат, írin, _bavl_, 
   {{0x644dd365,0x2009d366,0x2ae00316,0x66080254}},	//   _aiai, hiai_, कहरु_, gidk, 
   {{0x644c1497,0x2009d367,0x7c39d368,0xd794141b}},	//   _biai, kiai_, _khur, _ملاخ, 
   {{0x31782153,0x44380109,0x7c380115,0x644c00d8}},	//   warz_, _chq_, _jhur, _ciai, 
   {{0x644c314e,0x7c39d369,0x2009d36a,0x3178012d}},	//   _diai, _mhur, diai_, tarz_, 
   {{0x7c38062c,0x25bc5522,0x66080009,0x00000000}},	//   _lhur, _gavl_, cidk, --, 
   {{0x644c1311,0x4611d36b,0x7c380521,0x31780210}},	//   _fiai, _دوور, _ohur, rarz_, 
   {{0x2009d36c,0x3179d36d,0x644dd36e,0x7c3802c4}},	//   giai_, sarz_, _giai, _nhur, 
   {{0xc0f00020,0x31780489,0x0dc88a0f,0xd7240183}},	// [344e0] _ሃይል_, parz_, нлай_, মেৰা_, 
   {{0x7c39d36f,0x2cb80334,0xcd3402f2,0x8d1800d1}},	//   _ahur, _psrd_, هراب, ىزار_, 
   {{0xdee00020,0x7c39d370,0x20080006,0x644c0113}},	//   ነተኛ_, _bhur, biai_, _yiai, 
   {{0x2009d371,0x7c39d372,0x66080427,0xbc6414fb}},	//   ciai_, _chur, zidk, چمەن_, 
   {{0x7c39d373,0x09e41309,0xead5d374,0x660801d9}},	//   _dhur, лодн, роль, yidk, 
   {{0x2fc1d375,0x7c39d376,0x4dd400d3,0x66080009}},	//   ldig_, _ehur, _сімф, xidk, 
   {{0x7c39d377,0x2fc0002e,0x4ba4004e,0x6bd400ec}},	//   _fhur, odig_, _бөлү_, _پڪار, 
   {{0x8d740efb,0x7c38047e,0xa7fc00fd,0x46680815}},	//   _جاڭا, _ghur, _awır, нром_, 
   {{0x644c007b,0xdd24005f,0x2fc028dc,0xfaa401b9}},	//   _riai, _cīņa, idig_, _مجلی, 
   {{0x644dd378,0x2009d379,0x7c3802d3,0x661c0010}},	//   _siai, ziai_, _zhur, črko, 
   {{0x644c0170,0x660801d9,0xe5352d7c,0x2fc0017a}},	//   _piai, ridk, рень, kdig_, 
   {{0x2fc00cf9,0x2a640ac5,0x6609d37a,0x7c380200}},	//   jdig_, _ktmb_, sidk, _xhur, 
   {{0x200802d5,0x644c0077,0xb2840228,0x6609054e}},	//   viai_, _viai, йырк, pidk, 
   {{0x2fc09241,0x249c0ac5,0x09b0009e,0x644c0142}},	//   edig_, _tqvm_, চাকা, _wiai, 
   {{0x644dd37b,0x3ea8026c,0xf5580375,0x5fd000bc}},	//   _tiai, _spct_, _אדומ, हालल, 
   {{0x2fc08b14,0x6e3c009a,0x442dd37c,0x64a40032}},	//   gdig_, _ahrb, _óg_, _баҫа, 
   {{0x20080953,0x33a80c04,0x7c3807a9,0x3d88274b}},	// [344f0] riai_, _също_, _rhur, ещен_, 
   {{0x20080953,0x6e3c01f1,0x2fc00165,0x20740064}},	//   siai_, _chrb, adig_, _клоў, 
   {{0x7c39d37d,0x3e780ca8,0x20080006,0x3618011a}},	//   _phur, _bàtá_, piai_, עובד, 
   {{0x7c38e04e,0x50d80a7c,0x3ea80208,0x00000000}},	//   _qhur, _סקרא, _tpct_, --, 
   {{0x7c381aa1,0xfee401d5,0x00000000,0x00000000}},	//   _vhur, _сўнм, --, --, 
   {{0x17ec19e5,0x7c3802b5,0x2a640051,0x00000000}},	//   जस्व_, _whur, _dtmb_, --, 
   {{0x7c39d37e,0x645c00d0,0x00000000,0x00000000}},	//   _thur, íril, --, --, 
   {{0x7c39d37f,0x00000000,0x00000000,0x00000000}},	//   _uhur, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7ae800c0,0x00000000,0x00000000,0x00000000}},	//   mygt, --, --, --, 
   {{0x2fc06fe6,0x7ae8c0c8,0x00000000,0x00000000}},	//   ydig_, lygt, --, --, 
   {{0x93440acf,0x09a80f22,0x2c7c01ef,0x00000000}},	//   инне, _গোপা, _hádá_, --, 
   {{0x59b84ca3,0xe6101dd8,0x6b840332,0x00000000}},	//   _इसार, _کشن_, óigi, --, 
   {{0x1544ff58,0xe194009d,0x00000000,0x00000000}},	//   _келм, йрсэ, --, --, 
   {{0xe4c886bf,0xc24002d5,0x8f9801d5,0x5fd001f9}},	//   _مبين_, інск, къат_, हांल, 
   {{0x2fc03441,0x49180490,0x1b4c001f,0x32640022}},	//   udig_, मॅटो_, ንስትራ, _леиҳ, 
   {{0x9e64a482,0x7659d380,0x12180166,0x37b400fe}},	// [34500] مالن, nquy, _аюны_, _আচাৰ, 
   {{0xc2781a4c,0x76580d04,0x7ae804ce,0x2c482d9a}},	//   _שריי, iquy, dygt, _işdi_, 
   {{0x8fa5d381,0x00e000c0,0x00000000,0x00000000}},	//   _кане, _джэн, --, --, 
   {{0x8ba4234c,0xa7fcc6da,0x8ac4010b,0xbeb80200}},	//   ридж, _atın, ийеж, _pyët, 
   {{0x6e3c01ab,0x0d740024,0x00000000,0x00000000}},	//   _thrb, _выбя, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x218800c8,0x2c6c1ed9,0x8c44bd83,0x00000000}},	//   אָפּ, _dòdò_, _веве, --, 
   {{0xc6a40107,0x00000000,0x00000000,0x00000000}},	//   арои, --, --, --, 
   {{0xdce40882,0x53c8033f,0x00000000,0x00000000}},	//   mbhā, ियनश, --, --, 
   {{0x26c002d5,0x090401d3,0x645c01e4,0xdd18013d}},	//   _šios_, _پڑتی_, ŭrim, _çäçä_, 
   {{0xc7b807d6,0x7d7823e4,0xfe3400df,0x00000000}},	//   _аёл_, כניו, שריי_, --, 
   {{0x0ed4038e,0x26180073,0x7c380419,0x00000000}},	//   ठमाड, _पदवी_, _ďurk, --, 
   {{0x76580208,0xb7d8011a,0xf2e40108,0x28b401f9}},	//   cquy, _שקדי, оюро, ंबवि, 
   {{0xdbd008a5,0x00000000,0x00000000,0x00000000}},	//   _lýðs, --, --, --, 
   {{0x8005d382,0xdfd53521,0x00000000,0x00000000}},	//   ачае, бовы, --, --, 
   {{0x65781682,0x6459d383,0x2aa002bd,0x9f540395}},	//   _hevh, _iuvi, kòb_, свач, 
   {{0x645983b5,0x65780211,0xdce40882,0x5f38005b}},	// [34510] _huvi, _kevh, dbhā, упая_, 
   {{0x6459d384,0x63b401af,0x00000000,0x00000000}},	//   _kuvi, _тәүх, --, --, 
   {{0x6459d385,0x61e403a2,0x65780099,0xdbd009e8}},	//   _juvi, _iohl, _mevh, _býðs, 
   {{0x61e5d386,0x6579d387,0x6459d388,0x6ec418cc}},	//   _hohl, _levh, _muvi, रिशु, 
   {{0x6459d389,0x61e5d38a,0x48a802d3,0x00000000}},	//   _luvi, _kohl, _መርገጽ_, --, 
   {{0x645803b7,0x6579d38b,0x6a140228,0x61e4406c}},	//   _ouvi, _nevh, омчу, _johl, 
   {{0x61e5d38c,0x3a241529,0x645c01e4,0xcc840133}},	//   _mohl, ronp_, ŭrij, _هۆله_, 
   {{0x76580357,0x61e5d38d,0xc17803f9,0xdb18045f}},	//   tquy, _lohl, ɗɗen_, rdwâ, 
   {{0x61e401e0,0x3a245138,0x2aa0067c,0x1a6407d6}},	//   _oohl, ponp_, còb_, _ایتی_, 
   {{0x61e5d38e,0x6459d38f,0x7658fa7e,0x65780790}},	//   _nohl, _buvi, rquy, _cevh, 
   {{0x6459d390,0x69dc0086,0x76580309,0x95b400c7}},	//   _cuvi, _òrea, squy, арҟә, 
   {{0x6459d391,0x65780099,0x67d400ee,0x00000000}},	//   _duvi, _eevh, _моху, --, 
   {{0x61e5d392,0xa3e87f1a,0x64580005,0x243805f5}},	//   _bohl, _मकर_, _euvi, рчээ_, 
   {{0x016011f7,0x00000000,0x00000000,0x00000000}},	//   зкро, --, --, --, 
   {{0x6459d393,0x61e5d394,0xa7fc0139,0x00000000}},	//   _guvi, _dohl, _otıl, --, 
   {{0x61e40184,0x2aa00100,0xdde8583f,0x64900022}},	//   _eohl, yòb_, یرله_, ẽich, 
   {{0x0d84672f,0x429c001f,0x6459d395,0x6579d396}},	// [34520] йлан, ሌቲክስ_, _zuvi, _yevh, 
   {{0xab8c2c44,0xa7fc71e1,0x8d55d397,0x645801b9}},	//   _çözü, _atıl, стач, _yuvi, 
   {{0x64580005,0x8b69d398,0x7f8000d1,0xc95801d5}},	//   _xuvi, гиев_, زلەن, қўл_, 
   {{0x61e5d399,0x2aa00699,0x0b440816,0x90340271}},	//   _zohl, tòb_, бнен, _درخص, 
   {{0x61e42c60,0xdce40882,0xa9782401,0xa95400d4}},	//   _yohl, rbhā, айлу_, оклі, 
   {{0x80b80729,0x61e4036b,0x8db400d3,0x00000000}},	//   _উপত্, _xohl, _усмі, --, 
   {{0x61e185d4,0x6578006f,0x33200393,0x32180af9}},	//   ölli, _revh, _lxix_, inry_, 
   {{0x6579d39a,0x6459d39b,0xd5ac0014,0x5d100116}},	//   _sevh, _ruvi, ێہن_, _تېما, 
   {{0x6578006f,0x6b8400e4,0x00000000,0x00000000}},	//   _pevh, óigu, --, --, 
   {{0xf3f40135,0x38700789,0x7c3813d5,0x7aa00107}},	//   _བཞུད_, ñaré_, _ďuri, _хифз, 
   {{0x6458a518,0x61e5d39c,0x6579d39d,0xa3b40024}},	//   _quvi, _rohl, _vevh, обні, 
   {{0x61e4e7e0,0x65780099,0xe8b40073,0x97c5d39e}},	//   _sohl, _wevh, ंबीच, _وتنم, 
   {{0x65781aa1,0x61e5d39f,0x47340f87,0x3320003a}},	//   _tevh, _pohl, _اراز, _cxix_, 
   {{0x6459d3a0,0x25080633,0x00000000,0x00000000}},	//   _tuvi, _پرتی_, --, --, 
   {{0x61e402b9,0xbfa80166,0xbf8441e5,0x00000000}},	//   _vohl, лтае_, йыай, --, 
   {{0x61e5d38a,0xdb080295,0xaab8000d,0x00000000}},	//   _wohl, _maeò, _इनंक, --, 
   {{0x63add3a1,0x6d480745,0x4429d3a2,0x61e4012c}},	// [34530] _iban, _údaj, moc_, _tohl, 
   {{0x63ad5b2c,0x6d580e3c,0xc0f40092,0xc0d00092}},	//   _hban, žvan, _ለግል_, _ከግል_, 
   {{0x9cb40372,0x442802f0,0xa7fc2ca8,0xc0c800f3}},	//   تمات, ooc_, _atım, _супе_, 
   {{0x4429d3a3,0xeb909124,0x63ac0327,0x7bc400c0}},	//   noc_, فظه_, _jban, _ėjus, 
   {{0x63add3a4,0x3321d3a5,0x2240020c,0x8f9800df}},	//   _mban, _xxix_, _khhk_, _דירי, 
   {{0x95800023,0xdcf40118,0x00000000,0x00000000}},	//   ዓታትን_, _hezč, --, --, 
   {{0x16d02144,0x44280156,0xe7c41fbc,0x319c0a7c}},	//   तम्ब, koc_, वयंप, אבונ, 
   {{0x16640957,0x57e86201,0x63ac01f2,0x4428847c}},	//   овим, рдим_, _nban, joc_, 
   {{0x4429d3a6,0x79a4288b,0x6564008e,0x98b80205}},	//   doc_, _грее, _şiha, ızız_, 
   {{0x74540092,0x2924148b,0x00000000,0x00000000}},	//   _ከተፈጠ, árað_, --, --, 
   {{0x4429ad07,0x63ac0a49,0xddcc00f3,0x98a40024}},	//   foc_, _bban, ksaž, _bylą_, 
   {{0x63ac1529,0xddcc01fa,0x44289567,0x1bf8012d}},	//   _cban, jsaž, goc_, ंसिल_, 
   {{0x572400f7,0x63ac03ce,0x00000000,0x00000000}},	//   _بىشك, _dban, --, --, 
   {{0x63accf3f,0x7c286d05,0x7a3c06af,0x00000000}},	//   _eban, hogr, bête, --, 
   {{0x4428054e,0x63ac0175,0x05c000ab,0x20541436}},	//   boc_, _fban, _वोटब, зтур, 
   {{0x4429d3a7,0x7c29d3a8,0x63acacd9,0x6fc40073}},	//   coc_, jogr, _gban, _लोखं, 
   {{0xc7b006a9,0xb8d80135,0xbea0c8d5,0xdce40374}},	// [34540] ובן_, _ཇག_, матк, kahē, 
   {{0x0d8521ef,0x13a400dd,0x224000a2,0x63ac3903}},	//   ілен, _اچھی_, _ghhk_, _zban, 
   {{0xb60400da,0x00000000,0x00000000,0x00000000}},	//   mašī, --, --, --, 
   {{0x0a6875d7,0x35d805f9,0x00000000,0x00000000}},	//   арки_, बाड़, --, --, 
   {{0x0ab52dd7,0x00000000,0x00000000,0x00000000}},	//   تحاد, --, --, --, 
   {{0xc86413d6,0x67fc0241,0x44280156,0x00000000}},	//   отии, _méje, zoc_, --, 
   {{0x442802d1,0x00000000,0x00000000,0x00000000}},	//   yoc_, --, --, --, 
   {{0x7c29d3a9,0x7a3dd3aa,0x20040129,0xa3e80037}},	//   cogr, vête, élix_, _मकइ_, 
   {{0x4429d3ab,0x00000000,0x00000000,0x00000000}},	//   voc_, --, --, --, 
   {{0x63ad5c2b,0x7a3dd3ac,0x3cec00d2,0xe944583d}},	//   _sban, tête, _îmvú_, _فرضی, 
   {{0x44280dd4,0x46b405f9,0x53d44466,0x07a401b9}},	//   toc_, _अनकह, धांश, _мажн, 
   {{0x7a3c20ef,0xe6180228,0x1ae00154,0xdecc0092}},	//   rête, рдү_, _মেয়া, _ባሁኑ_, 
   {{0x4429d3ad,0xb6c8aaac,0x23dc0574,0xd76401d9}},	//   roc_, _پانے_, याबद, _رانٹ, 
   {{0x442803bd,0x67fdd3ae,0xd24c0133,0x00000000}},	//   soc_, _déje, ێچی_, --, 
   {{0x7c29d3af,0x44280a3a,0xdfd44f35,0x63add3b0}},	//   yogr, poc_, повы, _tban, 
   {{0x63add3b1,0x6d580006,0x844401d5,0x34f80677}},	//   _uban, žval, _بختل, _כהוד, 
   {{0xa7fc0790,0x41e4753d,0x9df80902,0x00000000}},	// [34550] _atık, _діна, бнат_, --, 
   {{0x7c280d29,0x09a804c5,0x91c000d1,0x632c0092}},	//   wogr, _গোসা, _пәсл, ደዘገበ, 
   {{0x61e0008c,0xa1140137,0x91b805d0,0x6ce40024}},	//   öllu, _روحت, _המתי, міце, 
   {{0xc17802a8,0x1fb801af,0x00000000,0x00000000}},	//   ɗɗan_, _улмы_, --, --, 
   {{0xa3e80307,0xda3402d5,0x59b8033f,0x00000000}},	//   _मकई_, педы, _इसआर, --, 
   {{0xceb000d9,0x9cf40150,0xeab000ae,0x00000000}},	//   _רים_, _езгі, ضعه_, --, 
   {{0xb6040006,0x09a803d4,0x00000000,0x00000000}},	//   našū, _গোহা, --, --, 
   {{0x9694855f,0xfcc0013d,0x00000000,0x00000000}},	//   прош, _нәҗм, --, --, 
   {{0x41c84f3c,0x00000000,0x00000000,0x00000000}},	//   ायास, --, --, --, 
   {{0x67fc0129,0xeaf80ccb,0x98e401af,0x00000000}},	//   _réje, _برفت_, _нсеһ, --, 
   {{0x67fc003e,0x2ba8020d,0x00000000,0x00000000}},	//   _séje, छ्वा, --, --, 
   {{0x68fc0139,0x96b80153,0xe61800cf,0x00000000}},	//   _ürda, _гуку_, йдө_, --, 
   {{0x96645443,0x9f58007f,0xd175d3b2,0x00000000}},	//   _экле, _ilsè_, зыбы, --, 
   {{0x36200050,0xdb18002f,0x00000000,0x00000000}},	//   _توتہ, mdwä, --, --, 
   {{0xdb08c96d,0xdb182305,0xb4041075,0x00000000}},	//   _obeï, ldwä, _жүнд, --, 
   {{0x80b80183,0x6d48007b,0x0e6400cf,0x00000000}},	//   _উপশ্, _údai, зкан, --, 
   {{0x65940220,0xdb18002f,0x645c00e4,0xff200150}},	// [34560] _ءجۇر, ndwä, íriv, емто, 
   {{0x3f88009a,0xdcf4008e,0x2bac0055,0x9f4800b8}},	//   _edcu_, _abzı, _ṛc_, bhaþ_, 
   {{0xd7bc2413,0xc170025f,0x645c01e4,0x00000000}},	//   ्याच, _אחת_, ŭriv, --, 
   {{0x0b44119e,0xc0e000db,0x00000000,0x00000000}},	//   пнен, _чоюк, --, --, 
   {{0x92e80011,0xeaf800cd,0x00000000,0x00000000}},	//   _মধু_, ्छेत_, --, --, 
   {{0xbe64352d,0x2c0c02f5,0x4338008f,0x2c1c00cc}},	//   _харж_, ষকেই_, זענב, ততেই_, 
   {{0x6f056983,0xaac400ec,0x00000000,0x00000000}},	//   lzic, _ڊڪشن, --, --, 
   {{0xe70805d9,0x8c1801f7,0x00000000,0x00000000}},	//   يڪشن_, _ايرر_, --, --, 
   {{0x0ae80ee8,0x8a04030d,0x98a40210,0x69a401ee}},	//   _ارزي_, _езае, _mylę_, _олаҡ, 
   {{0x76400142,0xdb180af9,0xbaf800d9,0x00000000}},	//   _chny, kewê, _ההמש, --, 
   {{0xc8c9d3b3,0xbeb802d3,0xc764129d,0x245801af}},	//   _دوان_, _nxën, _فاشى, юань_, 
   {{0x67240124,0x07a4009d,0x00000000,0x00000000}},	//   _ÿijo, _хадн, --, --, 
   {{0x25b401d9,0x86440395,0x00000000,0x00000000}},	//   _ہۆکھ_, _ендж, --, --, 
   {{0x6f05d3b4,0x76b8011a,0x00000000,0x00000000}},	//   dzic, _למדפ, --, --, 
   {{0x91c003a5,0x6f0401a4,0x80d401ad,0x1b1c00cc}},	//   тәыл, ezic, डमें, _তৰাই_, 
   {{0x7534025f,0xc1004276,0xa7fc013d,0xf5340375}},	//   _מאוד_, дүүл, _awız, _מנוי_, 
   {{0x94241e87,0x6ec4002b,0x7a3c0022,0x00000000}},	// [34570] _تويۇ, रिगु, hêta, --, 
   {{0x602400c0,0xb2b80108,0x00000000,0x00000000}},	//   dėme, _эльф_, --, --, 
   {{0x2004068c,0x9f48013d,0x00000000,0x00000000}},	//   èlis_, kkaç_, --, --, 
   {{0xad2408c9,0x5b15d3b5,0x92c00c58,0x00000000}},	//   رىنى, ммет, ূহৰ_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xcf240451,0x00000000,0x00000000,0x00000000}},	//   _آرٽي, --, --, --, 
   {{0xa3cc081e,0x8bf80011,0x00000000,0x00000000}},	//   रया_, েকজন_, --, --, 
   {{0x7a4001ef,0x00000000,0x00000000,0x00000000}},	//   _bítý, --, --, --, 
   {{0x75fc0a85,0xba7401ec,0x00000000,0x00000000}},	//   _lêze, _ءارت, --, --, 
   {{0x7a3c0129,0xf99035b6,0xdb18002f,0xe9f801ec}},	//   bêta, _سبط_, rdwä, _енуі_, 
   {{0x6f05d3b6,0x7981d3b7,0x1ce40327,0x00000000}},	//   zzic, manw, ྫའི_, --, 
   {{0x7981d3b8,0x2e34002f,0x4364004e,0x00000000}},	//   lanw, läft_, маюн_, --, 
   {{0x2ee0025c,0x00000000,0x00000000,0x00000000}},	//   xxif_, --, --, --, 
   {{0xd2500d28,0x7981d3b9,0xb9d80020,0x236801e4}},	//   ئنس_, nanw, _ቡና_, _efaj_, 
   {{0x645dd3ba,0xd01000e3,0x6d5816a3,0x00000000}},	//   írit, نلس_, žvak, --, 
   {{0x7981b768,0x9424242f,0x6f040cf9,0x2e34097d}},	//   hanw, _імпе, tzic, häft_, 
   {{0x7981d3bb,0x33b40131,0x645c00df,0x00000000}},	// [34580] kanw, _قەھر, ŭrit, --, 
   {{0x6f05d3bc,0x71740dd8,0x79800223,0xa91c00d7}},	//   rzic, _سۇرا, janw, _heľe, 
   {{0xfce0f8fa,0xbf980b21,0x7981d3bd,0xdb180100}},	//   кофо, _blêd, danw, lewè, 
   {{0x7a3c00e4,0x00000000,0x00000000,0x00000000}},	//   vêta, --, --, --, 
   {{0xbd0001f5,0x7ff400ec,0x7980e4e2,0xf40000fe}},	//   _éénz, _آسپا, fanw, _উদাৰ_, 
   {{0x7981d3be,0x00000000,0x00000000,0x00000000}},	//   ganw, --, --, --, 
   {{0x9cb000cf,0x3c600117,0x00000000,0x00000000}},	//   _مۅلت, _аксг, --, --, 
   {{0x67fd0ac7,0xbf98000f,0x7a3c06af,0x00000000}},	//   _béja, _glêd, rêta, --, 
   {{0x798000b4,0x9f4803ee,0x00000000,0x00000000}},	//   banw, rkaç_, --, --, 
   {{0x67fdd3bf,0x7981d3c0,0x6b800267,0x00000000}},	//   _déja, canw, _hemg, --, 
   {{0x69c80652,0x6b81d3c1,0x6d5c01e4,0xe41402bf}},	//   _iade, _kemg, _mgra, еднь, 
   {{0x6b8009a5,0xa2940845,0x5de40220,0x00000000}},	//   _jemg, намі, _ﺍﻷﻤﻴ, --, 
   {{0x6595d3c2,0xf770025f,0x69c9143e,0x6b800a2e}},	//   _залу, _סקס_, _kade, _memg, 
   {{0x69c9d3c3,0x6d5c0502,0x6b80b438,0x645c0174}},	//   _jade, _ngra, _lemg, íris, 
   {{0x7ff404d3,0x7864083c,0x00000000,0x00000000}},	//   وسرا, _kıva, --, --, 
   {{0x6b802959,0x79800230,0x69c82238,0x645c00df}},	//   _nemg, zanw, _lade, ŭris, 
   {{0x75fc0a85,0x63bdd3c4,0x7981d3c5,0x69c9d3c6}},	// [34590] _wêze, mesn, yanw, _oade, 
   {{0x69c9d3c7,0x629c1cbd,0x79810858,0x00000000}},	//   _nade, muso, xanw, --, 
   {{0x629dd3c8,0x6b800472,0x5c7400ee,0x6d5c010a}},	//   luso, _bemg, хлет, _dgra, 
   {{0x6d5dd3c9,0x63bdd3ca,0x69c80014,0x7981d3cb}},	//   _egra, nesn, _aade, wanw, 
   {{0x7981d3cc,0x6b81d3cd,0x6d5c0175,0x00000000}},	//   tanw, _demg, _fgra, --, 
   {{0xd945d3ce,0x6d5c025c,0x79800198,0xdb1800e8}},	//   нели, _ggra, uanw, newé, 
   {{0x69c9d3cf,0xdb7c04ce,0x78640139,0x63bdd3d0}},	//   _dade, _mm厚_, _bıva, kesn, 
   {{0x63bc1727,0x69c9cfef,0xb8d4028a,0x6b80031c}},	//   jesn, _eade, _छह_, _gemg, 
   {{0x7bd96c97,0x63bdd3d1,0x7981d3d2,0xfdf02d8f}},	//   _inuu, desn, panw, _आकास_, 
   {{0x69c9d3d3,0x629dd3d4,0x60c401b9,0x6b80005f}},	//   _gade, duso, _oshm, _zemg, 
   {{0x7bd83f50,0x63bdd3d5,0x53a4030c,0x00000000}},	//   _knuu, fesn, нанб, --, 
   {{0x69c8140b,0x629c7499,0x63bdd3d6,0x656801ab}},	//   _zade, fuso, gesn, acdh, 
   {{0x629dd3d7,0xe2804ef9,0x60c5d3d8,0xdea802a8}},	//   guso, ағын, _ashm, ƙoƙi, 
   {{0xdb1804e6,0x69c80067,0x78640205,0xd46800d8}},	//   gewé, _xade, _zıva, _еике_, 
   {{0x63bc17a3,0x92c00729,0xd13006c2,0xb4c000fb}},	//   besn, ূহে_, امز_, _рийҙ, 
   {{0x6d5dd3d9,0x63bdd3da,0x7bd80083,0x00000000}},	//   _sgra, cesn, _nnuu, --, 
   {{0x6b8001c7,0x60c53345,0x6d5c0334,0xdb18045f}},	// [345a0] _remg, _eshm, _pgra, rdwû, 
   {{0x7bd9d3db,0x26c001e4,0x6b81d3dc,0x00000000}},	//   _anuu, _ɨio_, _semg, --, 
   {{0x6d5c0fb7,0x835000aa,0xdc800aac,0xe3b400eb}},	//   _vgra, _ټپیا, иқро, য়ারব, 
   {{0x69c9d3dd,0x7bcc0261,0x6d5c1430,0x7b9401d9}},	//   _sade, _ócul, _wgra, ٹھِس_, 
   {{0x69c9d3de,0xad242002,0x2d9c0ba1,0xddcc06be}},	//   _pade, رىچى, òves_, qqaş, 
   {{0x9f49d3df,0x6b81d3e0,0x63bcd591,0x69c9d3e1}},	//   chañ_, _wemg, zesn, _qade, 
   {{0x69c9d3e2,0x6b8000d2,0x629d6965,0xc170025d}},	//   _vade, _temg, zuso, נחה_, 
   {{0x69c9d3e3,0x07080107,0xa7fc0166,0xe3b403d4}},	//   _wade, зхои_, _suıb, _জোনব, 
   {{0x69c9d3e4,0x63bdd3e5,0x76b4013d,0x3f8c0124}},	//   _tade, vesn, елыр_, ógui_, 
   {{0x48e4dea5,0x31780010,0x629c0dd6,0xfb180677}},	//   _позв, jbrz_, vuso, _זוממ, 
   {{0x2918033d,0x63bdd3e6,0x629dd3e7,0xf1a400bc}},	//   _ära_, tesn, wuso, ख्छन, 
   {{0x629dd3e8,0x9f4807e4,0xc0f4044e,0x75000124}},	//   tuso, zhañ_, _ወፍሪ_, уџье, 
   {{0x1dd019e5,0x67fc003e,0x629c013c,0xfbd00375}},	//   _सफलत, _héjo, uuso, אתר_, 
   {{0x6594262f,0x629dd3e9,0x63bdd3ea,0x41e41cb8}},	//   _раку, ruso, sesn, хіма, 
   {{0x629dd3eb,0x63bdd3ec,0x25082a77,0xdb0801e7}},	//   suso, pesn, _ترشی_, _mbeá, 
   {{0x4e9c001f,0xf0e80131,0x629dd3ed,0x63bcc329}},	//   _ዕርምጃ_, رىقى_, puso, qesn, 
   {{0x6e940276,0x629c0869,0xf458008f,0x9f5410ea}},	// [345b0] литу, quso, _איהר_, твач, 
   {{0x7c840220,0xc059d3ee,0x04e000fe,0x3d240108}},	//   еуде, _нім_, খনীৰ_, ньев, 
   {{0x60c403ac,0x20980166,0x4d48010a,0x00000000}},	//   _ushm, _юкны_, çпан_, --, 
   {{0x2cb8a3a0,0x7bc80589,0x9f480489,0x00000000}},	//   _dprd_, udgu, shañ_, --, 
   {{0x7bc9d3ef,0x1da801ad,0x00000000,0x00000000}},	//   rdgu, _छञपत, --, --, 
   {{0xdd940598,0x7a3c06af,0xbf980129,0xf99000f2}},	//   _шагы, rêto, _flêc, ابش_, 
   {{0x6d8801d9,0x7bb0030c,0xddcc01e4,0x00000000}},	//   _سۅنہ_, _бөлу, npaŭ, --, 
   {{0x628c05da,0x7bd9d3f0,0x67fc06af,0xdce4007f}},	//   _ovao, _unuu, _déjo, nchč, 
   {{0xa3e5d3f1,0x6d480597,0x0680cced,0xdce40374}},	//   नान_, _údar, агын, kahī, 
   {{0xc1c853b7,0xa2c444af,0x212c0118,0x00000000}},	//   ायोग, िबन्, řehy_, --, 
   {{0x628dd3f2,0xe894074d,0xa3cc00dc,0x81e400eb}},	//   _avao, _бахь, रयं_, পসা_, 
   {{0xff5c025a,0x00000000,0x00000000,0x00000000}},	//   _ngî_, --, --, --, 
   {{0x80b8045e,0x645c0115,0x00000000,0x00000000}},	//   _উপগ্, ŭrip, --, --, 
   {{0xb82000bd,0x86780115,0x00000000,0x00000000}},	//   _পঠিত_, _חרסו, --, --, 
   {{0x50581e76,0x25f00764,0x0080024c,0x46101176}},	//   дшая_, ेसरी_, илро, _خوور, 
   {{0xa3cc00dc,0x00000000,0x00000000,0x00000000}},	//   रयः_, --, --, --, 
   {{0x9f58011f,0x2cb8003e,0x0dc801e0,0x42c400cf}},	// [345c0] _alsâ_, _sprd_, млай_, _агын_, 
   {{0x8d189e24,0x00000000,0x00000000,0x00000000}},	//   وزار_, --, --, --, 
   {{0xd0095d25,0x628c004c,0x321800b5,0x00000000}},	//   _жене_, _zvao, miry_, --, 
   {{0xa3e5d3f3,0x67fc5725,0xa91c0419,0x00000000}},	//   नाय_, _réjo, _neľa, --, 
   {{0x67fc0231,0x8e740c72,0x09e43334,0x09a800cc}},	//   _séjo, _шунч, кодн, _গোগা, 
   {{0xc3300bd4,0x32180851,0x67fc0129,0x2fc1d3f4}},	//   בוד_, niry_, _péjo, leig_, 
   {{0xfce0011b,0x9f48014a,0xa3e45c8e,0x5ec800eb}},	//   _коро, ükön_, नाम_, রমণে, 
   {{0x8c441c22,0x32180851,0x2fc1d3f5,0xa7fc0213}},	//   _ребе, hiry_, neig_, _atır, 
   {{0x321806d9,0xe584009d,0x00000000,0x00000000}},	//   kiry_, лтнү, --, --, 
   {{0x32180109,0x2fc000a3,0xdd2400ef,0x00000000}},	//   jiry_, heig_, _dūņa, --, 
   {{0xc7c41d56,0x2a6402d3,0x321806d9,0xddcc0311}},	//   _асли, _humb_, diry_, lpaţ, 
   {{0xdce406c8,0x2a65d3f6,0x2fc0062c,0xd06406be}},	//   wahī, _kumb_, jeig_, _öpər, 
   {{0xb7d47b02,0x321803d1,0x2fc0143a,0xdce400b0}},	//   _جونا_, firy_, deig_, tahī, 
   {{0xf74002e8,0x00000000,0x00000000,0x00000000}},	//   _течо, --, --, --, 
   {{0xceb4c7e0,0x2fc00270,0xc05802bf,0xa0c4004b}},	//   һәр_, feig_, діа_, ديزو, 
   {{0x32180354,0x00000000,0x00000000,0x00000000}},	//   airy_, --, --, --, 
   {{0xceb481fc,0x2a64045a,0x66f428d4,0x00000000}},	// [345d0] ләр_, _numb_, ेनिक_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2fc001ab,0x53a8578b,0xdd14009a,0x00000000}},	//   beig_, _कामश, دواخ, --, 
   {{0x92e403d4,0xffa000db,0x41c81bd6,0x00000000}},	//   পনৰ_, _өлүү, ायकस, --, 
   {{0xee84100e,0xaac5d3f7,0x8f9805d0,0x00000000}},	//   _высо, لتون, _אירי, --, 
   {{0x2a6426e7,0xab8c06be,0x7c9400ae,0xbd680150}},	//   _dumb_, _çönü, _لشرا, _ірге_, 
   {{0x2a6400e8,0x89d400c6,0x00000000,0x00000000}},	//   _eumb_, طوير_, --, --, 
   {{0xe7d40075,0x321806d9,0x6d5002d1,0x00000000}},	//   لمىگ, ziry_, çhaš, --, 
   {{0x2a648356,0x79a40022,0x758007d6,0xa91c00d0}},	//   _gumb_, _арее, لیشم, _veľa, 
   {{0xdbc80254,0x00000000,0x00000000,0x00000000}},	//   _võõb, --, --, --, 
   {{0xd7040116,0xa91c0419,0x00000000,0x00000000}},	//   _әзли, _teľa, --, --, 
   {{0x4c980bd9,0x67240122,0xd7c80345,0x98a40139}},	//   עברו, _žije, _سوته_, _uglı_, 
   {{0x41240364,0x09a800fe,0x32180109,0x2a6400e8}},	//   ҳоро_, _গোটা, tiry_, _xumb_, 
   {{0xa7fc0598,0x471800c8,0x69dc0428,0x10a4033a}},	//   _utır, _אונג, _òret, лигн, 
   {{0x2fc1d3f8,0x321805da,0xe610f85d,0x41240454}},	//   teig_, riry_, _بشن_, горо_, 
   {{0x32180109,0x2cac04e6,0x00000000,0x00000000}},	//   siry_, _äddi_, --, --, 
   {{0x32196630,0x67fc00e8,0x2fc1d3f9,0x69dc1d1d}},	// [345e0] piry_, _béjj, reig_, _óreg, 
   {{0x2a6400cf,0x7e94036b,0x2fc00e89,0xfc1000cc}},	//   _rumb_, انلر_, seig_, িকোষ_, 
   {{0x2a640694,0x3ab00184,0x2fc0004e,0x00000000}},	//   _sumb_, ҙәтт, peig_, --, 
   {{0xae740075,0x0c24b4c7,0x68fc000d,0x863c0023}},	//   _نۇرغ, ымен, _ürdi, _ኣዒንት, 
   {{0xa3e40b03,0xe9841e37,0xa7fc00fd,0x752c012d}},	//   नात_, иқан, _buın, ęczy, 
   {{0xe9180006,0xddcc054e,0x00000000,0x00000000}},	//   колі_, rpaţ, --, --, 
   {{0x2a64002e,0x00000000,0x00000000,0x00000000}},	//   _wumb_, --, --, --, 
   {{0x8a0407a7,0x2a64013f,0xec3425ba,0xddcc0841}},	//   _өзбе, _tumb_, _ئورگ, mpaš, 
   {{0x36840323,0x67fc002e,0x8b24005b,0x4a44014b}},	//   лсэн_, _yéjj, _сдае, _бнав, 
   {{0xa615d3fa,0x37e001d5,0x00000000,0x00000000}},	//   рмоч, _қочг, --, --, 
   {{0xddcc01fa,0x00000000,0x00000000,0x00000000}},	//   npaš, --, --, --, 
   {{0x24180c9e,0x6354729a,0x87080902,0xc6a4009b}},	//   томы_, ивну, _пеев_, _брки, 
   {{0xa7fc013d,0x82a401f4,0x1b340240,0x00000000}},	//   _yuın, ышне, _እናተራ, --, 
   {{0xa4d40064,0x00000000,0x00000000,0x00000000}},	//   _вокі, --, --, --, 
   {{0x5ff41920,0xa3e428e0,0x82a402dd,0x00000000}},	//   азву, नाद_, _өшпе, --, 
   {{0x9f58011f,0xa2c4a3c6,0x1f75d3fb,0x00000000}},	//   _alsá_, िबद्, рлая, --, 
   {{0x644dd3fc,0xa19450d5,0x1e1400ee,0x3374013d}},	// [345f0] _ihai, _капч, амая, _угыр, 
   {{0x644c00a3,0xdd95d3fd,0x22580108,0x00000000}},	//   _hhai, ражы, _шипы_, --, 
   {{0x644dd3fe,0x272044ab,0xad241870,0x443803b9}},	//   _khai, मपुर_, مىكى, _kkq_, 
   {{0x90780bd9,0x629c013c,0xa7fc013d,0xe9a800d1}},	//   _שטרי, orso, _suın, ۇدىن_, 
   {{0x644c7e9f,0x1ae5d3ff,0x7cec0ba1,0x2008f01e}},	//   _mhai, ролм, fòrç, mhai_, 
   {{0xe9d9d400,0x644c1368,0x629c01ab,0x00000000}},	//   лкі_, _lhai, irso, --, 
   {{0x644c0124,0xb4e007f7,0xd944010b,0x629c343a}},	//   _ohai, _नपे_, шеки, hrso, 
   {{0x2009d401,0xdce40882,0x644dd402,0x00000000}},	//   nhai_, cchā, _nhai, --, 
   {{0x7c38e1a0,0xdb18002f,0x57480b01,0x00000000}},	//   _ikur, ndwü, ъзим_, --, 
   {{0x644dd403,0xa2d80882,0x20080369,0x7cec067c}},	//   _ahai, मिन्, hhai_, còrç, 
   {{0x644dd404,0xe0040b26,0x20096daf,0x629c0eda}},	//   _bhai, रसाद_, khai_, erso, 
   {{0x644dd405,0x888001d3,0x78a043e9,0x00000000}},	//   _chai, _بیٹن, munv, --, 
   {{0x644dd406,0x7c3805d9,0x200831e5,0x78a00108}},	//   _dhai, _mkur, dhai_, lunv, 
   {{0x644dd407,0x660801ab,0xff1c00cc,0x00000000}},	//   _ehai, chdk, _দৰ্শ_, --, 
   {{0x644c3c5d,0x7c39d408,0x78a000ac,0x629dd409}},	//   _fhai, _okur, nunv, arso, 
   {{0x644dd40a,0x7c39c8b8,0xc0002850,0x20098e14}},	//   _ghai, _nkur, опск, ghai_, 
   {{0x0d85d40b,0xfbb80882,0xe0d000aa,0x6fa802ab}},	// [34600] илан, ोजनम, يزې_, गलबं, 
   {{0x78a1d40c,0xa7fc0139,0x200800e4,0x00000000}},	//   kunv, _auıl, ahai_, --, 
   {{0xccc400f7,0x78a00ffb,0xa7fc0139,0x00000000}},	//   рбей, junv, _buıl, --, 
   {{0xddcc05be,0x78a00108,0x644c0200,0x00000000}},	//   rpaš, dunv, _xhai, --, 
   {{0xddcdd40d,0xa91c0419,0x00000000,0x00000000}},	//   spaš, _peľo, --, --, 
   {{0x7c39d40e,0xd90c7611,0x78a01418,0x82d408a8}},	//   _ekur, کیم_, funv, יונג_, 
   {{0xc7c400f3,0xf1c40064,0x00000000,0x00000000}},	//   аспи, myšį_, --, --, 
   {{0xc1780198,0x0ba802dd,0x26180210,0x2d9800fb}},	//   ɗɗun_, _جاسى_, योनी_, _шөғө_, 
   {{0x644c0f7b,0xa3e40b4e,0x2b28179e,0x49c801a9}},	//   _rhai, नास_, _صغری_, _илан_, 
   {{0x644dd40f,0x78a000ca,0x67fc00c7,0xb9e400ec}},	//   _shai, bunv, _méji, _پڙهن_, 
   {{0xe5348340,0x25e82ce1,0x78a042bc,0x67fc002e}},	//   сень, जाबी_, cunv, _léji, 
   {{0x2009d410,0x644c01d4,0x78f8008f,0x7a3c0129}},	//   xhai_, _qhai, _שלאפ, vêti, 
   {{0x644c0084,0x629c34b9,0xf7400063,0x8234007b}},	//   _vhai, urso, _децо, لرسا, 
   {{0x363015fa,0x75d1d411,0x20080325,0x644dd412}},	//   _وروس, _وينا, whai_, _whai, 
   {{0x2009d413,0xdb180100,0x443806be,0x3f8400d8}},	//   thai_, ndwò, _tkq_, иѓаа, 
   {{0xa2d486bf,0x644c01f7,0x629c030a,0xf558011a}},	//   _هيبت, _uhai, prso, _בדומ, 
   {{0x63add414,0x9ed80372,0x78a0030a,0xb6a00051}},	// [34610] _ican, ымат_, zunv, _ngầ, 
   {{0x2009d415,0xa3e422e3,0x78a14a2c,0xc8c40118}},	//   shai_, नाव_, yunv, लबाट, 
   {{0x7c38022e,0x60180108,0x00000000,0x00000000}},	//   _pkur, _боня_, --, --, 
   {{0x63ac062c,0xa7fc013d,0x78a03ed2,0x50d800df}},	//   _jcan, _quıl, vunv, _עקרא, 
   {{0x63ac0407,0x78a00223,0x3dcc0154,0xbd68010a}},	//   _mcan, wunv, রাবল, _арбе_, 
   {{0x7c38033f,0xd82401c6,0x00000000,0x00000000}},	//   _wkur, өдли, --, --, 
   {{0xac9407d5,0x63add416,0x7c380240,0x1bd428e8}},	//   _марш, _ocan, _tkur, _ловя, 
   {{0xfd640943,0x63acda30,0x78a1d417,0x00000000}},	//   vhuṱ, _ncan, runv, --, 
   {{0x20180194,0x7d0012e8,0x00000000,0x00000000}},	//   _mmsi_, ønsf, --, --, 
   {{0xd1e81e38,0x78a00066,0x6d580022,0x00000000}},	//   መታት_, punv, ývag, --, 
   {{0x63ac020b,0x88b0072d,0xf8d8000d,0xaf2800cc}},	//   _bcan, _فیوچ, _मछिय, _মৰাণ_, 
   {{0x63adb420,0x00000000,0x00000000,0x00000000}},	//   _ccan, --, --, --, 
   {{0x63ac01ab,0x1634005b,0x23dc202e,0x3688030d}},	//   _dcan, _ледя, याजद, _рсен_, 
   {{0x201927fa,0xcb340677,0xefc40092,0x00000000}},	//   _amsi_, מארי_, _ሻቢያ_, --, 
   {{0x63add418,0xe4c800ec,0x4f94fff2,0x25b800e5}},	//   _fcan, _نبين_, йрау, églő_, 
   {{0x6e3cbc2c,0x4d480046,0x956c001f,0x63ac00ae}},	//   _skrb, қпен_, _አበባን_, _gcan, 
   {{0x0e6815f2,0xb1840419,0xdb1c01e1,0x00000000}},	// [34620] اصري_, _šťuk, _ìyèm, --, 
   {{0xc1b0013d,0xd1c80108,0x00000000,0x00000000}},	//   _нәсы, _слое_, --, --, 
   {{0xab8d2af4,0xa7fc0139,0x25e82d2c,0x50b40114}},	//   _çökü, _suım, जाती_, _успу, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa91c0038,0xfaa1d419,0x63b800a2,0x00000000}},	//   _veľm, зачо, _öwne, --, 
   {{0xa2d8e613,0xf98c1e87,0x05a40037,0xbb40117e}},	//   मित्, ىبى_, _खाइब, чечк, 
   {{0xf98c0be2,0x2d99d41a,0x6d580030,0xdc74005b}},	//   ربو_, _idre_, ývad, _мыть, 
   {{0xc7c477cf,0xe69810ea,0xc6a4130f,0x2004004e}},	//   сски, авиш_, брои, èlix_, 
   {{0xf76c1c62,0xd1c00020,0x63ac00b8,0x00000000}},	//   راي_, ድስት_, _rcan, --, 
   {{0x63ac619b,0x1b2000cc,0x00000000,0x00000000}},	//   _scan, _বৰকে_, --, --, 
   {{0xa3e40034,0x6fa801f9,0x64a40124,0x00000000}},	//   नाल_, गलां, әаҭа, --, 
   {{0x464802dd,0x64a82ac3,0x00000000,0x00000000}},	//   _өзен_, _कमीश, --, --, 
   {{0x41e43981,0x25e84244,0xb284c133,0x65955975}},	//   біва, जादी_, зыск, _далу, 
   {{0x2d9c0261,0x2d98036e,0x2018000d,0x8ecc00eb}},	//   óvel_, _ndre_, _smsi_, রমাগ, 
   {{0xa159d41b,0x60240006,0x00000000,0x00000000}},	//   раву_, lėmi, --, --, 
   {{0x63ad770a,0x25bc01a4,0x2d9803cb,0x98a8033f}},	//   _ucan, _hbvl_, _adre_, łać_, 
   {{0x602402d5,0xff5c06af,0x00000000,0x00000000}},	// [34630] nėmi, _naît_, --, --, 
   {{0x82348ee7,0xf2d4010f,0x00000000,0x00000000}},	//   _درعا, _זעץ_, --, --, 
   {{0x61e5d41c,0xdfd0215e,0x06ac0154,0x9b9400be}},	//   _inhl, _قيد_, _কনফি, قلات, 
   {{0xdad800c7,0xab9402bf,0x2019d41d,0x9f585522}},	//   имец_, зиці, _umsi_, _alså_, 
   {{0x1989d41e,0x786401ed,0x2d980009,0xe7ec012d}},	//   абли_, _műve, _fdre_, झाना_, 
   {{0x38c440ec,0x60240153,0x6e440006,0x09e0022e}},	//   ماعی_, dėmi, _неўз, дошн, 
   {{0x2bd4069f,0xd7e80414,0x7d0005ac,0x00000000}},	//   _ठोका, имке_, ønsd, --, 
   {{0x96943f67,0x7a3c0129,0xfcc00166,0x9cc801ee}},	//   орош, vêtu, _мәҗм, _йыға_, 
   {{0x61e4014b,0xc68c21ec,0x2d98037e,0x3f89d41f}},	//   _onhl, نِي_, _ydre_, _mecu_, 
   {{0x9f480dd4,0x5bc80316,0xdd2400de,0x00000000}},	//   nkañ_, _रसुव, _mūža, --, 
   {{0xf771bac7,0xa3e41161,0xb4e000af,0xc0100882}},	//   _فاش_, नां_, नमे_, ṣṭe_, 
   {{0x3f880b91,0x60240024,0x61e5d420,0xfbb80118}},	//   _necu_, bėmi, _anhl, ोजिम, 
   {{0x75fc045f,0x243801c6,0x91d400d4,0x00000000}},	//   _lêzi, счээ_, оцві, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3f883421,0x75d005d9,0x00000000,0x00000000}},	//   _becu_, _ويچا, --, --, 
   {{0x61e5d421,0x3f89d422,0xa3e40882,0xe7ec033f}},	//   _enhl, _cecu_, नाः_, झाया_, 
   {{0x3f89d423,0xda080490,0xa7fc008e,0xe7bc000d}},	// [34640] _decu_, वसात_, _suık, ्जतप, 
   {{0xfde536a0,0xabe40150,0x00000000,0x00000000}},	//   одук_, _ﺍﻗﻘﺎ, --, --, 
   {{0xa91c0038,0x3f880076,0x69d40b8f,0x0b8814b3}},	//   _veľk, _fecu_, _योगी, асли_, 
   {{0x0b45d424,0x20040200,0x00000000,0x00000000}},	//   онен, ëlit_, --, --, 
   {{0xdd240171,0xca6000c7,0x00000000,0x00000000}},	//   _gūža, дҵақ, --, --, 
   {{0xddd4005f,0x60240024,0xda643cc6,0x090400d4}},	//   _aizņ, vėmi, ساهي, жчим, 
   {{0x8b940c17,0x1cb8031c,0x9f480bcd,0x53a808ec}},	//   _мрач, _མདར_, lkað_, _कांश, 
   {{0x60240024,0x8d740137,0xb4e000bc,0x7d0001bf}},	//   tėmi, _داڭا, नमै_, ønse, 
   {{0x3b040801,0x9f48041e,0xdb180ade,0xc05002e4}},	//   _дето_, nkað_, gewä, וזה_, 
   {{0xa2d84466,0x60240024,0xc5f806ed,0x99f40064}},	//   मिस्, rėmi, рѓи_, _няхі, 
   {{0x6474063b,0xc8c84ce4,0x60240153,0x2ac401e1}},	//   ягну, _خوان_, sėmi, bébò_, 
   {{0x9f482833,0xa3e44ca3,0xdb18002f,0x87040064}},	//   kkað_, नाइ_, bewä, _мяле, 
   {{0xc3480801,0x3f8839b4,0xaabc01ad,0x7a3c0129}},	//   ряне_, _recu_, ोबिक, mêtr, 
   {{0x3f880356,0x2258104e,0x00000000,0x00000000}},	//   _secu_, сигы_, --, --, 
   {{0x3f88003a,0x245800c7,0x00000000,0x00000000}},	//   _pecu_, _лакь_, --, --, 
   {{0x7a3c20ef,0x2168010b,0x38980a7c,0xdb18002f}},	//   nêtr, риңи_, יילנ, mdwö, 
   {{0x85554cb2,0x3f89d425,0xbd680a15,0xabe40220}},	// [34650] _دیگر_, _vecu_, арее_, _ﺍﺗﻘﺎ, 
   {{0x61e401f0,0xceb40166,0x00000000,0x00000000}},	//   _unhl, чәю_, --, --, 
   {{0x9f480dd4,0x3f88026c,0xdb180036,0x041000b8}},	//   rkañ_, _tecu_, zewä, _śuṣm, 
   {{0x9f480dd4,0x4428030a,0x98a40064,0x00000000}},	//   skañ_, nnc_, _zylė_, --, 
   {{0x4429d426,0xfa5001d5,0x80d00db3,0x7d0012e8}},	//   inc_, ورتگ, डिके, ønsb, 
   {{0x6d580122,0x95800023,0x0c9400f7,0x00000000}},	//   ývac, ናታትን_, زدۅگ, --, 
   {{0xc5c00183,0x1a644144,0xe874129d,0x18a401d5}},	//   ্ঞাপ, _کیتی_, ونوگ, чайм, 
   {{0x95f41d72,0x2368047e,0x442815ad,0x97c4034e}},	//   ेस्ट_, _ngaj_, jnc_, ستعم, 
   {{0xb4e01161,0x46e40228,0xa3e40da3,0xdb24023a}},	//   नम्_, здын_, नाई_, öpäi, 
   {{0x2368fb44,0x4429d427,0x00000000,0x00000000}},	//   _agaj_, enc_, --, --, 
   {{0x1cb8031c,0x7c2862af,0x63a801e4,0x779000e5}},	//   _མདས_, ongr, ϲent, _ہیںا, 
   {{0x3894084c,0x7a3c4056,0x7c29d428,0x00000000}},	//   măr_, cêtr, nngr, --, 
   {{0x7c29d429,0x9f48026c,0xa2d800dc,0x9584030d}},	//   ingr, jjaà_, मिष्, _елле, 
   {{0x7c280112,0x442803cb,0x00000000,0x00000000}},	//   hngr, anc_, --, --, 
   {{0x38940276,0x25e80f4a,0xa7fc247e,0x8f980b01}},	//   năr_, जारी_, _atıy, йъат_, 
   {{0x7c2801f5,0xa2d8085c,0xdcf40139,0x00000000}},	//   jngr, मिश्, _sezğ, --, 
   {{0x38940311,0xe7ec00af,0xd174329e,0x00000000}},	// [34660] hăr_, झाता_, _ныны, --, 
   {{0x7c29d42a,0x9f481f60,0xdb080798,0xa2d80bca}},	//   engr, rkað_, _oceâ, मिर्, 
   {{0x01f8011a,0x9f48041e,0x7c29d42b,0x00000000}},	//   _הפיל, skað_, fngr, --, 
   {{0xa3e40d2b,0x00000000,0x00000000,0x00000000}},	//   नाए_, --, --, --, 
   {{0x7a3c0129,0x3a7000d3,0x78a0002f,0x9e7000cf}},	//   vêtr, елір, ernv, _لۇقت, 
   {{0x7c29d42c,0xb9900131,0xf644dd6a,0x38940356}},	//   angr, ىشىغ, _سئ_, făr_, 
   {{0x9f5800e4,0x3894054e,0x00000000,0x00000000}},	//   _nosê_, găr_, --, --, 
   {{0xaca4063f,0xc6a4537c,0xdce4012d,0x00000000}},	//   _chụp, прои, jchę, --, 
   {{0x1cb808ea,0xfaa04a03,0x442802fa,0x78a00165}},	//   _མདོ_, _пато, vnc_, arnv, 
   {{0xda6401f7,0x3b000055,0x05e80276,0x798002d0}},	//   _قالي, _dīpā_, сфии_, cbnw, 
   {{0xf64dd42d,0x2458177b,0x7a3c0129,0x38940356}},	//   دئي_, жань_, pêtr, căr_, 
   {{0xa2d806b1,0x2294004e,0x00000000,0x00000000}},	//   मिल्, мимя, --, --, 
   {{0x37c40dd4,0x69d801f5,0xe7380451,0x442802f0}},	//   _ཁྲིད, odve, _بيشڪ_, rnc_, 
   {{0x4428011c,0x326400d8,0xb0d80f4a,0x00000000}},	//   snc_, етсв, डिंग, --, 
   {{0x7c2800a9,0x1cb80327,0x00000000,0x00000000}},	//   yngr, _མདེ_, --, --, 
   {{0x786405d1,0x940403e3,0x00000000,0x00000000}},	//   _kıvr, kslə_, --, --, 
   {{0x9df85c6e,0x3894054e,0xfb8400fd,0x00000000}},	// [34670] онат_, zăr_, җыен, --, 
   {{0x7c2863ce,0xa3e40d54,0x69d809d8,0x2dd4084c}},	//   wngr, नाक_, jdve, нжур, 
   {{0x7c640137,0x69d9d42e,0x00000000,0x00000000}},	//   ساال, ddve, --, --, 
   {{0x69d80f49,0x38940276,0x9f580fac,0x00000000}},	//   edve, văr_, _olsø_, --, 
   {{0xa3d47db3,0x69d801a4,0xde5800d4,0x00000000}},	//   _सघन_, fdve, _мамі_, --, 
   {{0xd945d42f,0x69d801a4,0x69dc03b2,0xf0b80244}},	//   мели, gdve, _órel, _بایش_, 
   {{0x81dc1c82,0x80d002ab,0xfe7c0042,0xaab402dd}},	//   _থকা_, डिटे, _brïg_, _үйсі, 
   {{0x63bc0196,0x7e64014f,0xd708ce95,0x69d80549}},	//   jfsn, _hijp, жние_, adve, 
   {{0x7bc9d430,0x7e6c0113,0x898400d1,0x00000000}},	//   megu, _jucp, سھەف_, --, 
   {{0x7bc9d431,0x24780092,0x3894054e,0x6aa401e7}},	//   legu, _የተመድ_, păr_, áife, 
   {{0x53a5d432,0x7e6c0309,0x850001d9,0x6aa40327}},	//   манб, _lucp, نوٝن, ġife, 
   {{0x7bc9d433,0x7e64014f,0x3b0002b5,0x8c44054e}},	//   negu, _lijp, _tīpā_, coşă, 
   {{0x248004b9,0x65780175,0x15f400c6,0xd1752570}},	//   _čime_, _ffvh, _يستح, дыбы, 
   {{0x7bc807dd,0x35f8034c,0x7e645d2e,0xa91c0030}},	//   hegu, _درصد_, _nijp, _veľv, 
   {{0x7bc9d434,0x00000000,0x00000000,0x00000000}},	//   kegu, --, --, --, 
   {{0x7bc8c670,0x60100158,0xdb0800db,0x055401f7}},	//   jegu, _nåmd, _oceà, _غليظ_, 
   {{0x9f580395,0x7e640d27,0xe2c800dd,0x0e65d435}},	// [34680] _josè_, _bijp, _فوٹو_, дкан, 
   {{0x9f58db10,0x86200327,0x7e6c0208,0x516400f3}},	//   _mosè_, _ཤམབྷ_, _ducp, _овпб, 
   {{0x7640020b,0x7bc9d436,0x00000000,0x00000000}},	//   _mkny, fegu, --, --, 
   {{0xf765d437,0x7bc9d438,0x7d01d439,0xdef80023}},	//   _لا_, gegu, ønsa, _ወይኒ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xba141d57,0xdb0800a2,0x00000000,0x00000000}},	//   وينا_, _ubeý, --, --, 
   {{0x7bc9d43a,0x69d9d43b,0xf1c000dc,0x246c00bc}},	//   begu, rdve, श्यन, _těmi_, 
   {{0x7bc823e0,0x38c804fb,0x7e6401a4,0x00000000}},	//   cegu, تاهی_, _zijp, --, 
   {{0x6f05d43c,0x9f58026c,0x8b2402d5,0xf4140154}},	//   nyic, _cosè_, _ўдзе, াচার_, 
   {{0xf1c09387,0xbaf80375,0x24800010,0x786403b9}},	//   श्मन, _והמש, _čimb_, _qıvr, 
   {{0xbb281c5c,0x490400c6,0xd7f00051,0x00000000}},	//   ﻤﺎﻡ_, _تواق, _lũy_, --, 
   {{0xc7641c3e,0x7641d43d,0x46e800db,0x00000000}},	//   _قاشى, _ekny, _мден_, --, 
   {{0x236c151c,0x630433d2,0x00000000,0x00000000}},	//   žejo_, روسل, --, --, 
   {{0x6f0402c4,0x7e6c01f5,0xe534234c,0x7bc9d43e}},	//   dyic, _rucp, _пель, zegu, 
   {{0x7e64923a,0x7bc80453,0x00000000,0x00000000}},	//   _rijp, yegu, --, --, 
   {{0x44dc003d,0x7bc80077,0x7e64bdb6,0xa3e4012d}},	//   _iċ_, xegu, _sijp, नाओ_, 
   {{0x7bc9d43f,0x7e65d440,0xdb09d441,0x6d59d442}},	// [34690] vegu, _pijp, _oceá, ývan, 
   {{0xdd91d443,0x7bc9d444,0x645c022f,0x628c37bf}},	//   اوا_, wegu, lmsi, _iwao, 
   {{0x7bc906b5,0x628c0099,0xad24581f,0x645d5f60}},	//   tegu, _hwao, نىكى, omsi, 
   {{0x628cd838,0x6f040526,0x3dcc015b,0xbbe8007b}},	//   _kwao, byic, রাইল, غرام_, 
   {{0x6f040223,0x645dd445,0xef640b01,0xcb940066}},	//   cyic, imsi, _аъро, رنوش_, 
   {{0x628c88fe,0x9f58004e,0x260000e8,0x2009d446}},	//   _mwao, _nosé_, _xòot_, lkai_, 
   {{0x7bc80588,0xbb280952,0x20080153,0xed587c3f}},	//   pegu, ﻤﺎﻥ_, okai_, _жоё_, 
   {{0x20096032,0x76401c06,0x23c000dc,0x15c40116}},	//   nkai_, _skny, ष्मद, ﯩﺴﯩﻐ, 
   {{0x5a34b91c,0x9f580789,0xaae40014,0x2009d447}},	//   _знат, _bosé_, _لسٕو, ikai_, 
   {{0x2008138f,0x645c198f,0xdf0000b8,0xa7fc008e}},	//   hkai_, emsi, _iḍām_, _suıt, 
   {{0x94244494,0x2009d448,0x628c01c8,0xb8b002dd}},	//   емне, kkai_, _awao, _рөлі, 
   {{0x246c00bc,0x6f04198f,0xa91c00d0,0x00000000}},	//   _němu_, yyic, _veľt, --, 
   {{0xa7e400cf,0x8c18011a,0xddcc0216,0x00000000}},	//   _جكنى, פושי, dpaž, --, 
   {{0xd251d449,0x6f04019f,0x645dd44a,0xb9f8001f}},	//   انس_, vyic, amsi, _ሆኑ_, 
   {{0xfe7c006a,0x6ac8015b,0x20b8005b,0x00000000}},	//   _atï_, লিযো, мыть_, --, 
   {{0xb404004e,0x15ec01f9,0x00000000,0x00000000}},	//   _рүмд, जावर_, --, --, 
   {{0xbea1d44b,0x12280276,0xd1c801ee,0x8e0800d8}},	// [346a0] латк, _ноий_, _елпе_, пнав_, 
   {{0x8c94005e,0x9f58172e,0x2009d44c,0x6f0400ca}},	//   ерді, _xosé_, akai_, ryic, 
   {{0xa3e40490,0x601001bf,0xeb080b9a,0x00000000}},	//   नाच_, _såme, वन्त_, --, 
   {{0x601003a1,0x20080064,0x00000000,0x00000000}},	//   _påme, ckai_, --, --, 
   {{0xead46885,0xfaf4072d,0x3b0400d8,0x00000000}},	//   толь, فروغ_, нецо_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x0ae8021a,0xbf98045f,0x3cf0003a,0xe7ec00c5}},	//   _کرزي_, _glês, cxxv_, झाला_, 
   {{0x2fc1a681,0xa7fc0139,0x645c0175,0x6ac803d4}},	//   nfig_, _auır, xmsi, লিবো, 
   {{0x9f59033c,0xf7f00131,0x2fc001e7,0x5ec800fe}},	//   _posé_, اسىد, ifig_, ৰমথে, 
   {{0x2008009d,0x00000000,0x00000000,0x00000000}},	//   zkai_, --, --, --, 
   {{0xe5343417,0x5894004e,0x00000000,0x00000000}},	//   тень, _ашчу, --, --, 
   {{0x645c03b2,0x00000000,0x00000000,0x00000000}},	//   umsi, --, --, --, 
   {{0x3eb8010a,0x41c40006,0x93f00124,0x00000000}},	//   xtqt_, нёва, рҿыц, --, 
   {{0x91a80050,0x7750187f,0x00000000,0x00000000}},	//   ونُے_, _скіф, --, --, 
   {{0x2fc1d44d,0x6d5802fb,0x35f45b74,0xa3b83f6f}},	//   ffig_, ýval, _سرود_, _चाप_, 
   {{0x2009d44e,0x260000e8,0x628c01f7,0x01bc0150}},	//   ukai_, _gòor_, _twao, _ﺠﻤﻌﻨ, 
   {{0x3da5d44f,0x23c09518,0x2009d450,0xbf98017a}},	// [346b0] ереб, ष्णद, rkai_, _blêr, 
   {{0x20081d64,0x50a000d1,0x7d0012e8,0xf318010a}},	//   skai_, _ھەقل, ønso, _чоьш_, 
   {{0x200801af,0xa2d80f90,0x6ce40a4a,0x00000000}},	//   pkai_, मिक्, ліце, --, 
   {{0x6c8401d5,0x8170036b,0xaa4400d1,0x00000000}},	//   النم, _جنگچ, ۇننى, --, 
   {{0xa3b82de3,0x996000ef,0x00000000,0x00000000}},	//   _चान_, dīši_, --, --, 
   {{0x3ce0003a,0xc0e80092,0x00000000,0x00000000}},	//   _trjv_, መጣል_, --, --, 
   {{0x7d00007c,0xade400c0,0x00000000,0x00000000}},	//   änsd, _сцяк, --, --, 
   {{0x1cc049a6,0xf094008d,0xa7fc013d,0x9aa43997}},	//   _ཁྱར_, אנק_, _suır, _لمرو, 
   {{0x7bd80093,0x499001d9,0x19b80114,0x00000000}},	//   _iauu, _چیٖر, _огањ_, --, 
   {{0x7bd80093,0x499001d9,0xe708007b,0xa7fc0139}},	//   _hauu, _نیٖر, عتين_, _quır, 
   {{0x7bd80280,0x57b400d4,0x996000ef,0x00000000}},	//   _kauu, _абет, bīši_, --, 
   {{0x7bd98e19,0xd759d451,0x80c807f7,0x99600171}},	//   _jauu, _قلات_, ाबैं, cīši_, 
   {{0x7bd8b69b,0xe7845bc5,0xa91c00d7,0x00000000}},	//   _mauu, _сухо, _heľp, --, 
   {{0x7bd9d452,0x46a0136b,0xd2506f04,0x26000de2}},	//   _lauu, _ташв, شنز_, _wòor_, 
   {{0x27f400dd,0xf0044bb6,0x00000000,0x00000000}},	//   _شہید_, гүни, --, --, 
   {{0xa3b81533,0x7bd88b14,0xcfa80133,0x77780077}},	//   _चाय_, _nauu, باسم_, ncux, 
   {{0x2fc001bf,0xdd240171,0x00000000,0x00000000}},	// [346c0] rfig_, _rīša, --, --, 
   {{0x7bd80618,0x9104035b,0x9f5801ed,0xd09400fb}},	//   _aauu, _апое, _alsó_, _ишмы, 
   {{0x8fa40022,0xa3b8000d,0x7bd9d453,0x69dc0d12}},	//   _иане, _चाम_, _bauu, _órei, 
   {{0x37a403d4,0xcba4010b,0x8ba4011c,0x00000000}},	//   ক্তৰ, тадй, тидж, --, 
   {{0xbea00372,0x7bd97348,0x00000000,0x00000000}},	//   _каяк, _dauu, --, --, 
   {{0x0d200137,0x245800e4,0xee7400fb,0x00000000}},	//   _күзү, méme_, _аңҡы, --, 
   {{0xc210025f,0x7bd9d454,0xa7fc0166,0xebc401af}},	//   שהו_, _fauu, _suıq, _бәлн, 
   {{0xc7c45d88,0x7d0152bb,0x07080107,0x00000000}},	//   тски, änse, дхои_, --, 
   {{0xd9cc04c5,0x0584010b,0x54940092,0x00000000}},	//   লাজম, кунм, _መሰለህ_, --, 
   {{0x98a400c0,0x09e400d8,0x00000000,0x00000000}},	//   _gylį_, _шозн, --, --, 
   {{0x2618000b,0x29180183,0xddcc0784,0x245800d7}},	//   योगी_, _åra_, nqaš, héme_, 
   {{0xc7248334,0x2a6c08c2,0x1cc00327,0x83700116}},	//   _идей, _hidb_, _ཁྱས_, шқич, 
   {{0x9f580c04,0x6d580122,0x57b00eff,0x26d800e2}},	//   _così_, ývaj, _اڭىز, āros_, 
   {{0x659436b6,0x00000000,0x00000000,0x00000000}},	//   _саку, --, --, --, 
   {{0xf6bc031c,0xf19400d4,0x00000000,0x00000000}},	//   _མདོང, рись, --, --, 
   {{0x344800c7,0x7d00005c,0x00000000,0x00000000}},	//   _ичын_, ønsm, --, --, 
   {{0x9f55d455,0xf2c40064,0x00000000,0x00000000}},	// [346d0] увач, _ксэн, --, --, 
   {{0x629dd456,0x7bd93dfd,0xa3b8012c,0x00000000}},	//   msso, _sauu, _चाड_, --, 
   {{0x629dd457,0x7bd9d458,0xac75d459,0x9354036b}},	//   lsso, _pauu, لانش, _لریچ, 
   {{0x42800020,0x5b1400fb,0x2d9c0077,0x6010007c}},	//   _ዮሐንስ_, лмет, óver_, _fåma, 
   {{0x629dd45a,0x2a6c01ab,0xf1c02645,0x7d0001e3}},	//   nsso, _bidb_, श्वन, änsb, 
   {{0x2a6c0ac5,0x9f58067c,0x629dd45b,0x79a5d45c}},	//   _cidb_, _josí_, isso, трде, 
   {{0x7bd9d45d,0xdb18010e,0x00000000,0x00000000}},	//   _tauu, lewü, --, --, 
   {{0x31580302,0x629d6992,0x00000000,0x00000000}},	//   כיון_, ksso, --, --, 
   {{0x9f5800e4,0x15b80209,0xf990642c,0x00000000}},	//   _hosâ_, ныны_, _نبض_, --, 
   {{0x1cc00135,0x629c1f53,0x9f5802fb,0x00000000}},	//   _ཁྱོ_, dsso, _nosí_, --, 
   {{0x629c198f,0x25e80dad,0x2ed000dc,0xb4bc07f7}},	//   esso, जाजी_, _हन्त, ुबे_, 
   {{0x629ccf5f,0xdd400337,0x68fc0e89,0x56940107}},	//   fsso, _aŋŋa, _àrda, _бадт, 
   {{0x18b00032,0x629c3720,0x95980092,0xdcf40064}},	//   _тәҙр, gsso, ጋጀቱን_, _tezė, 
   {{0x9f5800db,0x245800e4,0xdb180210,0x00000000}},	//   _cosí_, véme_, lewó, --, 
   {{0xe3c82158,0x8fa5d45e,0x629dd45f,0xf8c00154}},	//   ষয়ব, лаве, asso, ্মকথ, 
   {{0xdd400a49,0x1cc0025c,0x629dd460,0x145800ee}},	//   _eŋŋa, _ཁྱེ_, bsso, _яшлы_, 
   {{0xd1cc02d3,0xdb18002f,0x25e801f9,0x00000000}},	// [346e0] _ብዓቢ_, gewü, जाची_, --, 
   {{0xdb100248,0x00000000,0x00000000,0x00000000}},	//   _àgùn, --, --, --, 
   {{0xd008010a,0x00000000,0x00000000,0x00000000}},	//   _зене_, --, --, --, 
   {{0x4bd81d8f,0xdb18068f,0xddcc0784,0xa2d800dc}},	//   عباد_, jewó, rqaš, मिच्, 
   {{0xbca07a32,0x90440451,0xdb18002e,0xaa4400d1}},	//   لمەي, _لنگه, dewó, ۇنچى, 
   {{0x82d4008f,0xc0e8001f,0x7d000036,0x00000000}},	//   טונג_, መጣም_, änsc, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8c442dfa,0x629c0363,0x9c5800cf,0xd90c1888}},	//   _себе, ysso, _ашуу_, بیم_, 
   {{0xa615bb09,0x6b800010,0x1cc00327,0x09e41985}},	//   имич, _ifmg, _ཁཱོ_, _йоан, 
   {{0x9f580022,0x629dd461,0xa2b400dc,0x32180419}},	//   _hosã_, vsso, ेऽस्, jhry_, 
   {{0x69c8031c,0xc7a400fd,0x2419208c,0x6ad417c6}},	//   _ibde, _биек, воны_, _धनुर, 
   {{0x9f580c67,0x629dd462,0x261832ed,0x38c84c12}},	//   _josã_, tsso, योजी_, _سامی_, 
   {{0x69c802fa,0xa5c40724,0x00000000,0x00000000}},	//   _kbde, _көне, --, --, 
   {{0x629dd45a,0xc5bc0003,0x32180286,0x7d002ab7}},	//   rsso, _མཁྲི, ghry_, ønsk, 
   {{0x291c0399,0x9f5801ef,0x00000000,0x00000000}},	//   nzva_, _vosí_, --, --, 
   {{0xa2ac0490,0xb3440213,0x629c1b47,0x00000000}},	//   _जिप्, zaçə, psso, --, 
   {{0x4429d463,0x69c8151c,0x9ed8020a,0x2f1800f5}},	// [346f0] mic_, _obde, ъмат_, готь_, 
   {{0x4429d464,0x1cc00135,0x69c8031c,0xdb18033f}},	//   lic_, _ཁྱུ_, _nbde, zewó, 
   {{0xdcf400da,0x2ce81507,0x4428037e,0x00000000}},	//   _iezī, льцо_, oic_, --, 
   {{0xdea004fb,0xac18036b,0x291c006f,0xdb18007f}},	//   _ویزی, лоху_, dzva_, dewò, 
   {{0xfaa40249,0x68e800a9,0x3f9823e0,0xaac5d465}},	//   ушен, _ardd, maqu_, متون, 
   {{0x7c94021a,0x69c80076,0xd8b80330,0x6d5000d7}},	//   _مشرا, _cbde, ندبا_, _ždaň, 
   {{0x4429d466,0x6ce400d6,0x1bd4010b,0xfb840166}},	//   kic_, _літе, _ковя, _бызн, 
   {{0x2498044e,0x69c8030d,0x44280b3d,0x3f9819a2}},	//   _መሰላት_, _ebde, jic_, naqu_, 
   {{0x3f980a73,0x55f40c98,0xac1800f7,0x656401e4}},	//   iaqu_, ачну, _соту_, _ĝiha, 
   {{0x7c29d467,0xe9d84028,0xe974001f,0xdcf400ef}},	//   ligr, _مذمت_, ጠናከረ_, _nezī, 
   {{0xa8a42424,0x3f9823e0,0x7d003774,0x37a403d4}},	//   _грчк, kaqu_, ønsh, ক্ষৰ, 
   {{0x4429d468,0x00000000,0x00000000,0x00000000}},	//   gic_, --, --, --, 
   {{0xe708eead,0x321802f0,0x00000000,0x00000000}},	//   _متون_, thry_, --, --, 
   {{0x7c29d469,0x3774035b,0x442801e7,0xd5481de6}},	//   higr, _рыҧс, aic_, _ипле_, 
   {{0x7c29d46a,0x3f98011f,0x32180306,0x2d840022}},	//   kigr, faqu_, rhry_, _ęme_, 
   {{0x3f9819a2,0x13050ca4,0x92e80fc0,0x7c28007f}},	//   gaqu_, _взим, _адиб_, jigr, 
   {{0x9f580ee5,0xfe7c0142,0x00000000,0x00000000}},	// [34700] _rosã_, _drïo_, --, --, 
   {{0x7c28017a,0x24580022,0x00000000,0x00000000}},	//   eigr, méma_, --, --, 
   {{0x5ec45313,0x3f980a73,0x9f5800e4,0x8f740212}},	//   _қирғ, baqu_, _posã_, _вугі, 
   {{0xa2ac1092,0x7d00049f,0x3f9819a2,0x386c01e4}},	//   _जिम्, änsa, caqu_, _nigr_, 
   {{0x24580231,0x00000000,0x00000000,0x00000000}},	//   néma_, --, --, --, 
   {{0xf98c5cb5,0x4429d46b,0x1a8800dd,0xc33005d0}},	//   وبى_, zic_, ائنٹ_, חוד_, 
   {{0x44280998,0x2d99d46c,0x2459d46d,0x386c5b0f}},	//   yic_, _iere_, héma_, _bigr_, 
   {{0x4429d46e,0x2d99d46f,0x1cc0003d,0xec3407d6}},	//   xic_, _here_, _ཁྱི_, _اورگ, 
   {{0x4429d470,0x68e80142,0xdb180100,0xb760009d}},	//   vic_, _wrdd, sewò, жтэй, 
   {{0x2d99d471,0xa3b9d472,0x44280034,0xa2ac146c}},	//   _jere_, _चाह_, wic_, _जिब्, 
   {{0x2d99d473,0x4429d474,0x39780bd9,0xe37400fd}},	//   _mere_, tic_, _סטאנ, йлны, 
   {{0x44280076,0x00000000,0x00000000,0x00000000}},	//   uic_, --, --, --, 
   {{0x4429d475,0x2d980225,0x3f980333,0x058538d0}},	//   ric_, _oere_, vaqu_, _куйм, 
   {{0x442887c4,0xd1cc044e,0x2d99d476,0x9f58011c}},	//   sic_, _ብሓቂ_, _nere_, _rosà_, 
   {{0xa1941b6d,0x4429d477,0x3f9819a2,0x36580375}},	//   _қанч, pic_, taqu_, _שכונ, 
   {{0x2d99d478,0x34f81203,0x9f5914d7,0xc0f0001f}},	//   _aere_, _יהוד, _posà_, _ኃይለ_, 
   {{0x2d99d479,0x644c123c,0x7c29d47a,0x7d1803f9}},	// [34710] _bere_, _ikai, vigr, _ƙuso, 
   {{0x2d99d47b,0x3f980286,0xadf410f3,0x91c000d1}},	//   _cere_, saqu_, опуш, _нәсл, 
   {{0x7c2800dc,0x2d99d47c,0x645c0227,0x644c0055}},	//   tigr, _dere_, ïriw, _kkai, 
   {{0x1b0400bd,0x00000000,0x00000000,0x00000000}},	//   _শেষে_, --, --, --, 
   {{0xf1ec09d9,0x7c280882,0x2d99d47d,0x644dd47e}},	//   _छोड़_, rigr, _fere_, _mkai, 
   {{0x2d99d47f,0x7c29d480,0x6e952157,0x6af400ae}},	//   _gere_, sigr, _фиру, تثمر, 
   {{0x644dd481,0x7c2833e7,0x44380240,0x245806af}},	//   _okai, pigr, _ojq_, zéma_, 
   {{0x2d99d482,0x644d2c08,0x1cc00327,0x41a400dc}},	//   _zere_, _nkai, _ཁྱག_, कृतस, 
   {{0x2d99d483,0x7c39d484,0x957400f7,0x00000000}},	//   _yere_, _ijur, йынч, --, 
   {{0x644dd485,0xbc740020,0x2d980077,0x4438010a}},	//   _akai, _ይሁንና_, _xere_, _ajq_, 
   {{0x7c39d486,0x386c7d63,0x55e401b9,0xd1cc0023}},	//   _kjur, _tigr_, _ҳолб, _ብናቱ_, 
   {{0x2459d487,0xb4c400bc,0x96b8009b,0x00000000}},	//   téma_, _उही_, _буку_, --, 
   {{0x291800e4,0x98a40354,0x55e4014b,0x32540092}},	//   _ýrar_, _виçе, _голб, _መቅረባ, 
   {{0x644dd488,0x50b5d489,0x7c38000f,0x24596c35}},	//   _ekai, йсбу, _ljur, réma_, 
   {{0x2d99d48a,0x644c0093,0x7c3800c7,0x44380175}},	//   _rere_, _fkai, _ojur, _fjq_, 
   {{0x2d99d48b,0x7c39d48c,0x24580022,0x33b40345}},	//   _sere_, _njur, péma_, _بڕدر, 
   {{0xc0f00201,0x7d0001e6,0x8678010f,0x0dc9d48d}},	// [34720] _ኃይል_, änsn, ָרעו, ллай_, 
   {{0xc33025f9,0x2d980286,0xa2ac18cc,0x3f8c0d12}},	//   _מוח_, _qere_, _जित्, ðgur_, 
   {{0x2d99d48e,0x626407a7,0x8d59d48f,0x7c39d490}},	//   _vere_, _بايق, ушат_, _bjur, 
   {{0x2d99d491,0xc0f0001f,0x9c5800cf,0xfc6400f1}},	//   _were_, _ኃይሌ_, ашчу_, مخنی, 
   {{0x2d99d492,0x7c39d493,0xfce40092,0xaab40212}},	//   _tere_, _djur, _ማደግ_, ійкі, 
   {{0x7c3800ca,0x2d983bf1,0xc27800df,0x00000000}},	//   _ejur, _uere_, ארסי, --, 
   {{0xa3b84d53,0x7c380003,0x81c8015b,0x19a80220}},	//   _चाल_, _fjur, _রোড_, ртіп_, 
   {{0x7c3802d3,0xcb682bbd,0x00000000,0x00000000}},	//   _gjur, _бабе_, --, --, 
   {{0x0af00323,0x644c0166,0x7d00005c,0x25d81f39}},	//   _хүлэ, _rkai, ønsv, ампы_, 
   {{0x644dd494,0xc0d402d3,0x00000000,0x00000000}},	//   _skai, _ይደሊ_, --, --, 
   {{0x87e42901,0x00000000,0x00000000,0x00000000}},	//   _гюле, --, --, --, 
   {{0x7c38037e,0x14a80d0b,0xa2ad5faa,0x00000000}},	//   _xjur, _किरण, _जिद्, --, 
   {{0x6d5c05b1,0x823406c2,0x00000000,0x00000000}},	//   _lzra, مرسا, --, --, 
   {{0xe29800c7,0x00000000,0x00000000,0x00000000}},	//   лаҭ_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x644dd495,0x68e400a3,0x44380200,0x00000000}},	//   _ukai, āidh, _ujq_, --, 
   {{0x6d5c0898,0x1cc0025c,0xff50b1d7,0x222805af}},	// [34730] _azra, _ཁཱང_, سخر_, _نزدی_, 
   {{0x7c39a382,0x00000000,0x00000000,0x00000000}},	//   _sjur, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d5c00a2,0x00000000,0x00000000,0x00000000}},	//   _ezra, --, --, --, 
   {{0x79e400dd,0x6c84129d,0x00000000,0x00000000}},	//   صوبہ_, زلۇم, --, --, 
   {{0x20180270,0xb4c4033d,0x6010050a,0x7c39d496}},	//   _klsi_, _उहे_, _råmj, _tjur, 
   {{0x16a8016c,0x7c380c6a,0xdb1801c7,0x7d00072b}},	//   авии_, _ujur, ngwë, ønsu, 
   {{0xa3dc45bf,0x5a3400d8,0x2678009d,0x00000000}},	//   ड़न_, _днат, йсээ_, --, 
   {{0xf990036d,0xdce43235,0xd5480415,0x1a64b24a}},	//   _ربط_, lahı, иппе_, _بیتی_, 
   {{0xbf9807ea,0xdb1803fa,0x20180240,0x6ba802d2}},	//   _poêl, gewö, _olsi_, _árgö, 
   {{0xbf9800d8,0xdce5d497,0x28080118,0x00000000}},	//   _boêm, nahı, ětná_, --, 
   {{0x934438a9,0x3cd80037,0x81c80154,0xe6c400ec}},	//   інге, _गैसे_, _রোধ_, _فتوي, 
   {{0x2019d498,0xca7825f9,0xbf98000f,0x00000000}},	//   _alsi_, ינשט, _glêz, --, 
   {{0x7d00049f,0xc0e00276,0x9f4800ee,0x344800ee}},	//   änsl, морк, rjaý_, _гүни_, 
   {{0x3b0000b0,0x3e7c0142,0x434802e3,0x81c80154}},	//   _kūpā_, _bît_, ụpọ_, _রোদ_, 
   {{0x3e7c0311,0x4e041d3e,0x91e4026b,0x6d5dd499}},	// [34740] _cît_, озаб, _допе, _szra, 
   {{0x8d54255b,0xe4c40345,0x00000000,0x00000000}},	//   отеч, _بڵیی, --, --, 
   {{0xb4c4007d,0x3b0000ef,0xdce5d49a,0x00000000}},	//   _उहो_, _lūpā_, fahı, --, 
   {{0x0ae800f7,0x6d5c3883,0x27440200,0xdce403b9}},	//   идей_, _vzra, nënë_, gahı, 
   {{0x6d5c012d,0xfaa00329,0x00000000,0x00000000}},	//   _wzra, дачо, --, --, 
   {{0x48a9d49b,0xa2ac4721,0x27440200,0x00000000}},	//   атим_, _जिस्, hënë_, --, 
   {{0x6d5dd49c,0x7d005b47,0xa3dc00e1,0xdce43535}},	//   _uzra, ønst, ड़म_, bahı, 
   {{0x32c403ee,0x998807f5,0x46a422fd,0xc17000d9}},	//   köy_, đaš_, ошоб, וחו_, 
   {{0xf76c0eff,0xb3040327,0xb4c4000d,0x00000000}},	//   پاي_, ངདསང_, _उहॉ_, --, 
   {{0xd83802b5,0x6368022e,0x00000000,0x00000000}},	//   anō_, hоnc, --, --, 
   {{0x69d9d49d,0x7d780302,0xa2ac00dc,0x997473b3}},	//   meve, יניו, _जिह्, _хууш, 
   {{0x245944f9,0x248c009a,0x32c40790,0x27440200}},	//   rémo_, rpdm_, föy_, gënë_, 
   {{0xb2840108,0x00000000,0x00000000,0x00000000}},	//   дыск, --, --, --, 
   {{0xe8c80156,0x69d9d49e,0x62240131,0x3cd800c5}},	//   _གྱོག, neve, سىزل, _गईले_, 
   {{0xdce403be,0x20180100,0x67700133,0xa2ac041c}},	//   yahı, _plsi_, _تێکڕ, _जिव्, 
   {{0x69d9d49f,0x00000000,0x00000000,0x00000000}},	//   heve, --, --, --, 
   {{0x69d9d4a0,0x2019d4a1,0xa7fc0139,0x1e147fa5}},	// [34750] keve, _vlsi_, _quıy, пмая, 
   {{0x63bdd4a2,0x7db45821,0xa6bc00cc,0xc0280023}},	//   lgsn, تصرا, _অনাট, _ተፈላል, 
   {{0x69d9d4a3,0x9b95d4a4,0xae04129d,0xdce42ca8}},	//   deve, كلات, بولى, tahı, 
   {{0x63bdd4a5,0x61e5d4a6,0x670402b5,0x9f580793}},	//   ngsn, _hahl, _kōkā, _posä_, 
   {{0x61e53401,0xdb0801f5,0xeea84965,0xb4b40950}},	//   _kahl, _ideë, _мтрк_, _चम्_, 
   {{0x69d9d4a7,0x61e5d4a8,0x5e4401d9,0x22c000b0}},	//   geve, _jahl, _رنزٕ, mōkā_, 
   {{0x61e5d4a9,0x00000000,0x00000000,0x00000000}},	//   _mahl, --, --, --, 
   {{0x97d800d6,0xb8d00307,0x3b0000b0,0xf6c40327}},	//   ську_, _झट_, _pūpā_, _ཁྱུང, 
   {{0x2be00490,0xb6a0004d,0x3928001f,0x6010007c}},	//   _नसता, _giấ, _እንዲካ, _våmh, 
   {{0x61e403c6,0x69d9d4aa,0xa3b807f7,0x9f4800a2}},	//   _nahl, ceve, _चाउ_, njañ_, 
   {{0x2744006a,0x7ae8074d,0xe70813f9,0x6624007b}},	//   tënë_, lvgt, متین_, بريك, 
   {{0x61e5d4ab,0x63bc6afa,0x3b0002b5,0x22c002b1}},	//   _aahl, ggsn, _tūpā_, kōkā_, 
   {{0x27440023,0x00000000,0x00000000,0x00000000}},	//   rënë_, --, --, --, 
   {{0x61e40356,0xa2ac0bae,0x00000000,0x00000000}},	//   _cahl, _जिर्, --, --, 
   {{0xff5c145e,0xd1306ea9,0x01600d1d,0xd46800ea}},	//   _azî_, رمر_, екро, _лике_, 
   {{0x69d9d4ac,0xc8640055,0x00000000,0x00000000}},	//   zeve, _kṛṣe, --, --, 
   {{0x61e5d4ad,0x69d87c97,0x4418008d,0x3f6400ea}},	// [34760] _fahl, yeve, _לוקס, зито_, 
   {{0x61e5d4ae,0x69d801bf,0x2d9c00c7,0x00000000}},	//   _gahl, xeve, úve_, --, 
   {{0x0c74179e,0x00000000,0x00000000,0x00000000}},	//   سداد, --, --, --, 
   {{0x61e5d4af,0x69d80302,0x8b680107,0x00000000}},	//   _zahl, weve, биев_, --, 
   {{0x61e4bf45,0x69d9d4b0,0xa3dc00af,0x81dc015b}},	//   _yahl, teve, ड़त_, ণার_, 
   {{0x6935c378,0x0dc8001f,0x69d8017a,0x98a403b9}},	//   وکار, _አቀፉ_, ueve, _azlı_, 
   {{0x9f480321,0x10840131,0x00000000,0x00000000}},	//   ljað_, _ﻫﺎﺯﯨ, --, --, 
   {{0xa2add4b1,0x60100267,0x09c805d9,0xe8dc01f9}},	//   _जिल्, _påmi, _گذري_, _मनीच, 
   {{0xb9006fe9,0x77940166,0x00000000,0x00000000}},	//   _पै_, чкыр_, --, --, 
   {{0x69d80023,0xac08035f,0xca4801f7,0x00000000}},	//   qeve, _унға_, _الئه_, --, 
   {{0x61e409a8,0x00000000,0x00000000,0x00000000}},	//   _rahl, --, --, --, 
   {{0x670402b5,0x320c0108,0x00000000,0x00000000}},	//   _pōkā, ödyn_, --, --, 
   {{0xc34802e8,0x63bc5794,0x00000000,0x00000000}},	//   сяне_, rgsn, --, --, 
   {{0x9f54004a,0x61e4014f,0x7d000267,0x00000000}},	//   _âgée_, _qahl, änsk, --, 
   {{0x61e5d4b2,0x6ac82b1b,0x81dc0eac,0x69c400ce}},	//   _vahl, লিটো, ণাল_, _रानी, 
   {{0x92bc03d4,0x9f48032e,0x00000000,0x00000000}},	//   ীয়ে_, fjað_, --, --, 
   {{0x63add4b3,0x61e5d4b4,0x9f4806ea,0x00000000}},	// [34770] _idan, _tahl, gjað_, --, 
   {{0x0dc80201,0x628d046e,0xc0c800a8,0xa15924f4}},	//   _አቀፍ_, _itao, _луме_, _мапу_, 
   {{0x9f4805c7,0x37a400fe,0x630400d1,0x6d5800e4}},	//   rjañ_, ক্টৰ, _روھل, ývap, 
   {{0xa3dc00af,0x63ac0166,0x00000000,0x00000000}},	//   ड़ि_, _jdan, --, --, 
   {{0x63add4b5,0x7bc8000f,0x7ee4010a,0x00000000}},	//   _mdan, rfgu, _эцне, --, 
   {{0xd9780184,0x3eb80054,0x628d4433,0x961c007f}},	//   әрҙә_, muqt_, _mtao, npņt, 
   {{0xa3dc534e,0x928c0150,0x00000000,0x00000000}},	//   ड़ा_, _ﺒﺨﻁﻑ_, --, --, 
   {{0x628dd4b6,0x76a00241,0xebc4009b,0x00000000}},	//   _otao, _nìyá, _пљун, --, 
   {{0x628c0170,0x9f5800ae,0x46e43a49,0x57dc2982}},	//   _ntao, _aosú_, ддын_, _मसीह, 
   {{0x63add4b7,0xa3dc007d,0xc86400b8,0x00000000}},	//   _adan, ड़ऽ_, _vṛṣe, --, 
   {{0x628c1311,0xe894035b,0xd4680063,0xd5ac01c6}},	//   _atao, _захь, жине_, _хvни, 
   {{0x1cc0031c,0x63ad2855,0xfe7c0129,0x998401d3}},	//   _ཁཱན_, _cdan, _ouï_, _illő_, 
   {{0x0cb8084a,0x63ac00a9,0xf4240131,0xc7b00a7c}},	//   _उम्म, _ddan, _үзлү, _יבא_, 
   {{0x63add4b8,0x628c00c6,0x9f4803b2,0x00000000}},	//   _edan, _dtao, vjað_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x63add4b9,0x9f48022c,0x205403f6,0x00000000}},	//   _gdan, tjað_, етур, --, 
   {{0xbea1d4ba,0x83c00022,0x00000000,0x00000000}},	// [34780] катк, _рбыж, --, --, 
   {{0xcd341367,0x63ac239b,0x9f481f60,0xdcf402e2}},	//   وراب, _zdan, rjað_, _egzč, 
   {{0xd008516c,0x63ac013d,0x7d0001bf,0x32e801e1}},	//   _дене_, _ydan, ønsp, bìyá_, 
   {{0xaca4063f,0xdb9002dd,0x00000000,0x00000000}},	//   _nkụp, _ﺟﯩﺮﻯ_, --, --, 
   {{0x0a684d75,0x6e4400c7,0x00000000,0x00000000}},	//   орки_, _зҵаз, --, --, 
   {{0x2fc00165,0x9e701c3e,0x3219d4bb,0x00000000}},	//   lgig_, _مۇقت, nkry_, --, 
   {{0x3e8000e4,0x00000000,0x00000000,0x00000000}},	//   _tétã_, --, --, --, 
   {{0x2fc120b4,0xe8540137,0x00000000,0x00000000}},	//   ngig_, رچاد, --, --, 
   {{0x6fd045bf,0xc8c804fb,0x63add4bc,0x00000000}},	//   ड्यू, _ژوئن_, _rdan, --, 
   {{0x63ac0652,0x6360063f,0xb990007b,0x628c022e}},	//   _sdan, _ịnon, _للكب, _rtao, 
   {{0xf9c47175,0x2459217b,0x628dd4bd,0xdddc002b}},	//   _تحقی, зань_, _stao, _susū, 
   {{0x7d00aa6c,0x63ac03b9,0x00000000,0x00000000}},	//   änsi, _qdan, --, --, 
   {{0x3218017a,0x63ac1d33,0x245800e4,0x00000000}},	//   fkry_, _vdan, némi_, --, 
   {{0x63ac0198,0x9f5800c6,0x321805e4,0x35f0030d}},	//   _wdan, _tosú_, gkry_, _апшр, 
   {{0xdfd4876e,0xe8dc05d7,0x6d582d1e,0x00000000}},	//   новы, _मनोच, üval, --, 
   {{0x68fc004e,0xa3b8e60e,0x81dc00fe,0x24580098}},	//   _àrdu, _चाट_, ণাই_, kémi_, 
   {{0x628c0451,0x68fc0332,0xfde80108,0x00000000}},	// [34790] _utao, _árdf, жьей_, --, 
   {{0xeeb8074d,0x00000000,0x00000000,0x00000000}},	//   ьлуш_, --, --, --, 
   {{0xa1580da9,0xdd2400de,0x7c840395,0x00000000}},	//   _хану_, _būša, фузе, --, 
   {{0xc0c00116,0xdea05022,0xb6280150,0x00000000}},	//   _пәғи, _میری, _ﮔﯟ_, --, 
   {{0xaf540124,0xaac4b2a9,0xdd2400ef,0xdbd0000d}},	//   _аҽтә, نتون, _dūša, müüd, 
   {{0x69c40073,0xceb0010f,0xdbd00254,0xba7400f2}},	//   _राणी, _גיך_, lüüd, ذاشت, 
   {{0x1cb8031c,0x644401e4,0x00000000,0x00000000}},	//   _ཙའི_, _ĉiin, --, --, 
   {{0xad2401ec,0xdd2400de,0xe7d400d1,0xdbd0000d}},	//   _شىقى, _gūša, نمىگ, nüüd, 
   {{0xac800023,0x9f5801e1,0x00000000,0x00000000}},	//   _ክነሶም_, _posù_, --, --, 
   {{0xdbd00254,0x00000000,0x00000000,0x00000000}},	//   hüüd, --, --, --, 
   {{0x25e0038e,0x69c51afa,0x6e200356,0xdbd0000d}},	//   _कसरी_, _राती, _îmbe, küüd, 
   {{0xccf000c8,0x00000000,0x00000000,0x00000000}},	//   אכט_, --, --, --, 
   {{0xe35401c0,0x32180ea0,0x00000000,0x00000000}},	//   втрэ, tkry_, --, --, 
   {{0x9f5807de,0xd0107b02,0x3218017a,0x6368022e}},	//   _insè_, گلر_, ukry_, mоnl, 
   {{0x32180660,0x2ee005b1,0x4f940f5c,0x00000000}},	//   rkry_, wwif_, ерзу, --, 
   {{0xd010036b,0x3219d4be,0x1fb4045c,0x42cc0154}},	//   دلر_, skry_, ксур, িয়েশ, 
   {{0x0e64262f,0xa075d4bf,0x8570010b,0x326400c7}},	// [347a0] екан, тырш, _иләх, _иеиҳ, 
   {{0xfde5d4c0,0x7e640051,0xb4e0000d,0x245800c7}},	//   ндук_, _chjp, _औनाय_, vémi_, 
   {{0x8fa47111,0xdbd0000d,0xdd240171,0x00000000}},	//   _пане, büüd, _pūša, --, 
   {{0xf765d4c1,0x0b4516e5,0x24597f67,0x141c00c5}},	//   _ما_, ннен, témi_, _पतोह_, 
   {{0x25e00073,0x3f78010f,0xb9340092,0x00000000}},	//   _कसली_, _מאכס, ርካሪዎ, --, 
   {{0xc33000c8,0x0d200209,0x24580de2,0x00000000}},	//   נוג_, _йүзү, rémi_, --, 
   {{0x6f04056a,0x2e24000d,0x00000000,0x00000000}},	//   lxic, _pöff_, --, --, 
   {{0x05c005d7,0x3fc02d40,0x00000000,0x00000000}},	//   _शाहब, ﺭﻗﺎﻧ, --, --, 
   {{0xbb4159a3,0xdddc00c7,0x6f05d4c2,0x4a440815}},	//   _бетк, _susũ, nxic, _знав, 
   {{0xdb400022,0x00000000,0x00000000,0x00000000}},	//   _әҕәо, --, --, --, 
   {{0xa3dc033d,0x47f02758,0x846c0257,0x2e2401a8}},	//   ड़ल_, _бүйр, _ባህርን_, _töff_, 
   {{0x07a401c0,0xc76400d1,0xd82c00ec,0x00000000}},	//   _чадн, _كاشى, _وڍي_, --, 
   {{0xb9dc1954,0x00000000,0x00000000,0x00000000}},	//   _ባት_, --, --, --, 
   {{0x68fc08c2,0x6ea40037,0x00000000,0x00000000}},	//   _àrds, _चौधु, --, --, 
   {{0xa2ac2871,0x628c0064,0x00000000,0x00000000}},	//   _जिक्, _žioč, --, --, 
   {{0xa3d4014b,0x5ff4011c,0x00000000,0x00000000}},	//   _роич, ъзбу, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [347b0] --, --, --, --, 
   {{0x645c2b60,0x611400c7,0xb8e00327,0xdbd00037}},	//   llsi, _адоу, _ཎྀ_, süüd, 
   {{0xdbd000c5,0x645c017a,0x69dc032e,0x00000000}},	//   püüd, olsi, _órey, --, 
   {{0x5b1465a7,0x90880014,0xf534010f,0x749400df}},	//   кмет, _تمَے_, עטאר_, גדאד_, 
   {{0x645c00c6,0xcfc804c5,0x1ae4151a,0xde940063}},	//   ilsi, _লোকন, толм, _јагњ, 
   {{0xe9a80058,0xf2d4008f,0x645c2970,0x24580306}},	//   ىدىن_, רעס_, hlsi, mému_, 
   {{0xe9a9d4c3,0x24580122,0x3e50008e,0x81e000cc}},	//   ردون_, lému_, _eştä_, _নচা_, 
   {{0x2009d4c4,0x645c99c9,0x7d001577,0x00000000}},	//   njai_, jlsi, änsu, --, 
   {{0x24580232,0xa6200023,0x15b830e3,0x48000108}},	//   nému_, _ስለዝደ, мыны_, рпыв, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x245802fb,0x154400cf,0x00000000,0x00000000}},	//   hému_, тенм, --, --, 
   {{0x24580122,0xd6b4011c,0x645c02d2,0x00000000}},	//   kému_, _айдъ, glsi, --, 
   {{0x0441d4c5,0x68fc01ab,0x2e24002f,0xa68400d4}},	//   реян, _àrdr, _höfe_, _блід, 
   {{0x200875e3,0x245802f0,0x91e40063,0xa7640153}},	//   ejai_, dému_, њове, _скід, 
   {{0xe0d0004b,0x1acc0eac,0x6ce0033f,0x8fa44e8b}},	//   یزې_, লিয়া, _गैंग_, каве, 
   {{0x200801d3,0x68fc02d2,0x00000000,0x00000000}},	//   gjai_, _árde, --, --, 
   {{0x6a64067c,0xd26400ee,0x924801a9,0x00000000}},	// [347c0] hòfa, _икий, _озиб_, --, 
   {{0x6f041709,0x20080153,0x00000000,0x00000000}},	//   rxic, ajai_, --, --, 
   {{0xd90405d9,0x00000000,0x00000000,0x00000000}},	//   _اڌ_, --, --, --, 
   {{0x69c40490,0x24580306,0x06ac02dd,0x00000000}},	//   _राही, bému_, _ﺳﻪﺑﻪ, --, 
   {{0x0eb801c0,0x00000000,0x00000000,0x00000000}},	//   _юуны_, --, --, --, 
   {{0xbc643ce1,0x00000000,0x00000000,0x00000000}},	//   ىمەن_, --, --, --, 
   {{0x7d0004f3,0x645c3f27,0x00000000,0x00000000}},	//   änst, ylsi, --, --, 
   {{0x0ba84c2d,0x823c0092,0x645c01b9,0xcb68009b}},	//   _زارى_, _ባለቤቶ, xlsi, _жабе_, 
   {{0x09e57848,0xc8ac1d8a,0x6d5dd4c6,0x49c8010b}},	//   _иоан, _टिकट, _hyra, _олан_, 
   {{0x6d5c27e4,0x49b8dbb4,0xc8b4010b,0x39a00014}},	//   _kyra, _زائد_, _асды, _نیٖہ, 
   {{0x6d5c00a2,0x245802f0,0x47c40117,0x00000000}},	//   _jyra, zému_, _абев, --, 
   {{0x6d5dd4c7,0x68e80142,0x057401d5,0xa29412fa}},	//   _myra, _isdd, _یاغد, ламі, 
   {{0x59c8c4dd,0x645dd4c8,0x6d5c5727,0x81c8015b}},	//   _रामर, rlsi, _lyra, _রোগ_, 
   {{0x24580232,0xdb180085,0x6d5dd4c9,0x645c01a9}},	//   vému_, ngwá, _oyra, slsi, 
   {{0x6d5c020c,0x24580066,0x69c9d4ca,0x0464022e}},	//   _nyra, wému_, _mcde, _итим, 
   {{0x349022f7,0x6b800280,0x245802fb,0x00000000}},	//   _таър, _ngmg, tému_, --, 
   {{0x9df821f3,0x828801b9,0x2009d4cb,0xf8bc0f4a}},	// [347d0] ннат_, _ўсиб_, rjai_, _एम्प, 
   {{0x24580122,0x6b8000b5,0xb2740064,0x00000000}},	//   rému_, _agmg, _клыш, --, 
   {{0x816801b9,0xf1a42401,0x200801d3,0x59c80210}},	//   _юриб_, _трын, pjai_, _राबर, 
   {{0x6d5da114,0x645c0022,0x6b7c0055,0x00000000}},	//   _dyra, îrih, _ṅgas, --, 
   {{0x69c44540,0x6d5dd4cc,0x8c1400c6,0xceb4010b}},	//   _राशी, _eyra, طيور_, _бәх_, 
   {{0xd9440209,0x7ec40882,0x6d5c0267,0x7d000267}},	//   лели, rūpā, _fyra, änss, 
   {{0x6d5c00ee,0x6b840219,0x6e20054e,0x00000000}},	//   _gyra, žiga, _îmba, --, 
   {{0x317c0302,0x6a6456eb,0xb17c011a,0x00000000}},	//   ורומ, ròfa, וטור, --, 
   {{0x6d5c0023,0x1994084c,0x69c80175,0x0ad401d5}},	//   _zyra, _базя, _fcde, _محلگ, 
   {{0xf990473f,0xa2ac190c,0x6a64004e,0x00000000}},	//   _ضبط_, _जिज्, pòfa, --, 
   {{0xb7b1d4cd,0x53a5d4ce,0x00000000,0x00000000}},	//   _көпч, ланб, --, --, 
   {{0x935800f3,0x6d580254,0x00000000,0x00000000}},	//   ергу_, üvai, --, --, 
   {{0x8c18025f,0x9f583b7b,0xd83800a2,0x00000000}},	//   גורי, _mosó_, miō_, --, 
   {{0xd8380270,0x68fc0332,0x7df80171,0x66240137}},	//   liō_, _árdc, _jāsē, _ۅرۉك, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7df800ef,0xa2ac01f9,0xd83800ee,0x00000000}},	//   _lāsē, _जिच्, niō_, --, 
   {{0x6d5dd4cf,0x74140066,0x00000000,0x00000000}},	// [347e0] _syra, _موژا, --, --, 
   {{0x6d782302,0xd1b02ea3,0x00000000,0x00000000}},	//   نجاڭ_, _دیسک, --, --, 
   {{0xd83806c8,0x9f58004e,0xdde801d5,0xc98401a9}},	//   kiō_, _bosó_, ضرله_, қули, 
   {{0x6d5d0be8,0x8b2401ee,0x70540345,0x00000000}},	//   _vyra, лдее, _ئۆرا, --, 
   {{0x6d5c068f,0x69c80205,0xbb400153,0xbab400ae}},	//   _wyra, _pcde, бецк, هدوء_, 
   {{0x6d5dd4d0,0x2d9c0489,0xbb40026b,0x00000000}},	//   _tyra, ñved_, щечк, --, 
   {{0x8c440798,0xc8781fbe,0x36840150,0x00000000}},	//   _беве, нџи_, қсын_, --, 
   {{0xc7c4348d,0x6b80089c,0xa81438ac,0x7b8400f7}},	//   уски, _ugmg, рдиш, _ماكە, 
   {{0x69c80589,0xd1dc0092,0x00000000,0x00000000}},	//   _tcde, ዕስት_, --, --, 
   {{0x6a6400db,0x00000000,0x00000000,0x00000000}},	//   mòfo, --, --, --, 
   {{0xdb0819ff,0x2918efd7,0x6a64004e,0x636801d5}},	//   _ideá, _æra_, lòfo, mоni, 
   {{0x356484c8,0xd838003a,0x80a407f7,0xe3740139}},	//   ырын_, ciō_, टीफे, илны, 
   {{0x6a644b84,0xe4f400cd,0x00000000,0x00000000}},	//   nòfo, ेमहि_, --, --, 
   {{0x6594100e,0xf7700375,0x81c80154,0x128801d5}},	//   _таку, _פקס_, _রোজ_, тиёқ_, 
   {{0xa158d6cd,0x00000000,0x00000000,0x00000000}},	//   таву_, --, --, --, 
   {{0xff0402e8,0x00000000,0x00000000,0x00000000}},	//   лязн, --, --, --, 
   {{0x9f58004e,0x3eac0036,0x6368022e,0x1e340006}},	// [347f0] _rosó_, égt_, kоni, анаў, 
   {{0x91c1d4d1,0x3d24cffb,0x23680100,0xa3dc00e1}},	//   _мәсл, льев, _izaj_, ड़क_, 
   {{0xe0d001d9,0xaac41473,0xaed40220,0x9f581460}},	//   _بٲج_, ەتىن, _қорш, _posó_, 
   {{0xac743c5b,0x6f84086f,0x1bd4e4c1,0x3f980327}},	//   مانش, _гурж, родя, qbqu_, 
   {{0xaee40084,0x6a6401ab,0x9f480332,0x7d00007c}},	//   teṅw, ròfn, odaí_, ånsb, 
   {{0x9f4800c6,0xa2cc2ca5,0xcb640114,0x00000000}},	//   ndaí_, _तमन्, јаше_, --, 
   {{0xd839d4d2,0x590800f7,0x2918031c,0x00000000}},	//   tiō_, тейм_, _żrar_, --, 
   {{0x23680030,0x00000000,0x00000000,0x00000000}},	//   _ozaj_, --, --, --, 
   {{0x0681d4d3,0xb9c40a8e,0x959848a9,0x9a78004e}},	//   огын, _متاه, ктну_, _айат_, 
   {{0xeaf80a7b,0xc5fc00ef,0x00000000,0x00000000}},	//   _حرفت_, _šēra_, --, --, 
   {{0x9f480ba7,0x3e38001f,0xe709d4d4,0x80a40950}},	//   ndaâ_, _በየደረ, نتین_, टीमे, 
   {{0xb6400efb,0x25a000f3,0x68fdd4d5,0x00000000}},	//   _ﺍﷲ_, _đile_, _árda, --, 
   {{0xfbd400dc,0x00000000,0x00000000,0x00000000}},	//   ण्यम, --, --, --, 
   {{0xd9340020,0x00000000,0x00000000,0x00000000}},	//   _እንዳላ, --, --, --, 
   {{0x505811ed,0x463800c8,0x10a400d4,0x00000000}},	//   вшая_, _בעסע, рибн, --, 
   {{0x9f480332,0xd3b80006,0x00000000,0x00000000}},	//   adaí_, _рукі_, --, --, 
  
   {{0x6a64004e,0x0dc801a9,0xc2b001ee,0x447400df}},	// [34800] xòfo, клай_, _мөрш, _דעקל_, 
   {{0xfc1401d5,0xe4ec000d,0x645c00c7,0x00000000}},	//   یقلب_, _जनमि_, îriv, --, 
   {{0xdddc084c,0x2fb4010b,0xc1b8011a,0x7d0001e3}},	//   _susţ, _гөзя, _במיש, änsp, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6e200276,0x3b800daf,0x09e410d9,0xbca00131}},	//   _îmbo, әләг, иодн, ممەي, 
   {{0xbea03afa,0xca54026a,0x3ce8023a,0x98a42b24}},	//   _фарк, штењ, äivä_, _aylı_, 
   {{0xe65801d5,0x5cf40153,0x00000000,0x00000000}},	//   ғинч_, _ляту, --, --, 
   {{0x8c45275a,0xc8c400ec,0x00000000,0x00000000}},	//   _тебе, هوڙن_, --, --, 
   {{0x569400f1,0x4668206d,0x39400352,0x00000000}},	//   یدیځ, кром_, йнәг, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x38c803e6,0x24187ef2,0x00000000,0x00000000}},	//   _لانی_, гоны_, --, --, 
   {{0xb7d4009a,0x00000000,0x00000000,0x00000000}},	//   _نوما_, --, --, --, 
   {{0xe6940597,0xa7a8010b,0x28b0012d,0xc3480108}},	//   _التد, _акҗа_, ींकि, тяне_, 
   {{0x27e5d4d6,0x26c5d4d7,0xc0e00023,0x661c007c}},	//   lemn_, mumo_, _ምሒር_, örkd, 
   {{0x26c5d4d8,0x8174016c,0x9f48007b,0xfbd4227c}},	//   lumo_, равӣ_, rdaí_, ण्डम, 
   {{0x02a478cd,0x9f3402dd,0x27e4007f,0x7578011a}},	//   _кром, бебі, nemn_, _בטופ, 
   {{0x26c5d4d9,0xceb40510,0xf77000c8,0xe4d9d4da}},	// [34810] numo_, йәр_, ַקע_, _شوکت_, 
   {{0x6e200356,0x320c005b,0x291c00e4,0x5d840107}},	//   _îmbl, ödyt_, kyva_, стаҷ, 
   {{0x26c5d4db,0x27e40165,0xed8801ca,0x291c00e4}},	//   humo_, kemn_, рсук_, jyva_, 
   {{0x26c5d4dc,0xdb10025a,0xca4c01ec,0x44280051}},	//   kumo_, _âgën, _ﺍﺜﺭ_, nhc_, 
   {{0x2ef40953,0x1a6446ec,0x27e4054e,0x9f94000d}},	//   _дзяр, میری_, demn_, _müüd_, 
   {{0x26c5d4dd,0x7c94b524,0x2e2401a8,0x00000000}},	//   dumo_, _نشرا, _höfn_, --, 
   {{0x89d4007b,0x291dd4de,0x00000000,0x00000000}},	//   صوير_, gyva_, --, --, 
   {{0x9f94033d,0x26c5d4df,0xac180ff1,0x57e803fb}},	//   _nüüd_, fumo_, _косу_, удим_, 
   {{0x26c5d4e0,0x7bd806fd,0xac1800fd,0xaa942cdd}},	//   gumo_, _ibuu, _тоту_, _митч, 
   {{0x7af9d4e1,0x00000000,0x00000000,0x00000000}},	//   _irut, --, --, --, 
   {{0xe894ea2b,0x00000000,0x00000000,0x00000000}},	//   _дахь, --, --, --, 
   {{0x26c5d4e2,0x985400b0,0x2e240008,0x44280076}},	//   bumo_, _māī_, _nöfn_, ghc_, 
   {{0x7bd9d4e3,0x7af8003e,0x26c5d4e4,0x81c800fe}},	//   _mbuu, _jrut, cumo_, _ৰোধ_, 
   {{0x7af814af,0xdb080139,0xb1540092,0xe4c80244}},	//   _mrut, _ideä, _መቆየታ, دبین_, 
   {{0x7bd80337,0x444401ed,0x4124014b,0x661c3f3b}},	//   _obuu, _گروہ, боро_, örke, 
   {{0x44289878,0xf04401b9,0xc950011a,0x00000000}},	//   chc_, زعزی, פמן_, --, 
   {{0x92b4ca3e,0x7af8063f,0x386c01c3,0x3db400d1}},	// [34820] _احبا, _nrut, _mhgr_, ﻤﻤﯩﺘ, 
   {{0x7bd9d4e5,0xdddc00c0,0x00000000,0x00000000}},	//   _abuu, _pusš, --, --, 
   {{0x7af9d4e6,0x7bd804ba,0x8c4400d8,0x2c040073}},	//   _arut, _bbuu, беже, ळालं_, 
   {{0x26c4409c,0xd0083e9f,0x7d000158,0x291c00e4}},	//   yumo_, _семе_, ånsa, vyva_, 
   {{0x7af87e9f,0x0138001f,0x620405f7,0xbb402f6a}},	//   _crut, _አስተም, _útlá, пецк, 
   {{0x7af9d4e7,0x291c9333,0x26c41cea,0x7bd81418}},	//   _drut, tyva_, vumo_, _ebuu, 
   {{0x7af9d4e8,0x26c40161,0x7bb403d4,0x44280076}},	//   _erut, wumo_, _ইউৰো, yhc_, 
   {{0x26c5d4e9,0x7bd80241,0x7c29d4ea,0x291c00c7}},	//   tumo_, _gbuu, chgr, ryva_, 
   {{0x7af8334b,0x368405f5,0x25ac009a,0x8b24005b}},	//   _grut, йсэн_, tadl_, _удае, 
   {{0x26c5d4eb,0xba21d4ec,0x8a4401d5,0xa635089c}},	//   rumo_, _едук, _ائرم, інні, 
   {{0x9f940254,0x442801ab,0x25ac013a,0x7af8002b}},	//   _püüd_, thc_, radl_, _zrut, 
   {{0x69d90fd3,0x25ac0472,0x7af80022,0x3e6c002f}},	//   lfve, sadl_, _yrut, müte_, 
   {{0x26c40107,0x25082163,0x25ac00bc,0xb854007b}},	//   qumo_, _چربی_, padl_, _النص_, 
   {{0x2e2408a5,0x565401e2,0x00000000,0x00000000}},	//   _söfn_, _وروړ, --, --, 
   {{0x5ff40126,0xa3d40395,0x676400ec,0x00000000}},	//   озву, _дойч, _اُڇل, --, 
   {{0xb088013e,0x00000000,0x00000000,0x00000000}},	//   сёре_, --, --, --, 
   {{0x44380399,0x644c0022,0x6064010b,0xe8200037}},	// [34830] _imq_, _ijai, йҗүң_, _बवना_, 
   {{0x3e6c00c5,0x69d801a4,0x629cecb4,0x7af80076}},	//   küte_, jfve, mpso, _rrut, 
   {{0x7af8327f,0x44380395,0x7c28127b,0x629dd4ed}},	//   _srut, _kmq_, thgr, lpso, 
   {{0x7af9d4ee,0x44380076,0x3d04016b,0x69d80373}},	//   _prut, _jmq_, rεw_, efve, 
   {{0x69c4c7d6,0x4438011c,0x69d803fa,0x0138001f}},	//   _राखी, _mmq_, ffve, _አስቀም, 
   {{0x7af87039,0xe9d80006,0x61f40115,0x7c2802d0}},	//   _vrut, йкі_, ndzl, shgr, 
   {{0x7af8039a,0x386c05d5,0x644c0022,0x3e6c03e0}},	//   _wrut, _phgr_, _ojai, güte_, 
   {{0xdb0801c7,0x7af9d4ef,0x644c01ab,0x60d40036}},	//   _jeeë, _trut, _njai, itzm, 
   {{0x7c39d4f0,0x5628c40a,0xb7e803d4,0x00000000}},	//   _imur, ижим_, কালত_, --, 
   {{0x44380327,0xdb0804e6,0x00000000,0x00000000}},	//   _amq_, _leeë, --, --, 
   {{0x7ae80218,0x44380334,0x7bc80e14,0x629c01f5}},	//   lwgt, _bmq_, oggu, epso, 
   {{0x7bc82831,0xb9dc0201,0x44380801,0x7c38025c}},	//   nggu, _ጥሩ_, _cmq_, _jmur, 
   {{0x644c0158,0x4438022e,0x7c380327,0xdcf400d7}},	//   _djai, _dmq_, _mmur, _nezľ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7c39d4f1,0x388401d3,0xd3b80816,0x00000000}},	//   _omur, _főre_, _купі_, --, 
   {{0x7c380241,0xb2b40166,0x4fe81fbe,0x41d81546}},	//   _nmur, _нәгъ, јман_, म्बस, 
   {{0xf99c0016,0xdb0804e6,0x69ddd4f2,0x69d80af9}},	// [34840] _đèn_, _deeë, _öreg, yfve, 
   {{0x7c384437,0xda640451,0xc240008e,0xd1b045cc}},	//   _amur, _سڏ_, _онык, _زیرک, 
   {{0x0ba80aa0,0x41742c10,0xdb0801f5,0xbe1000cf}},	//   لاشى_, _واپس, _feeë, بولع, 
   {{0x68500020,0xdb08017a,0x00000000,0x00000000}},	//   ንቨስት, _geeë, --, --, 
   {{0x7c3807c5,0xaca40241,0x00000000,0x00000000}},	//   _dmur, _ilọp, --, --, 
   {{0x7c39d4f3,0xdb0801f5,0xec34006c,0x1cbc0327}},	//   _emur, _zeeë, _کورگ, _ཀྀམ_, 
   {{0x082853e9,0xc7c4b34e,0xc2780375,0x6a645d7e}},	//   иции_, оспи, ברסי, nòfi, 
   {{0x276803e6,0xc9b800e5,0x3a200166,0x00000000}},	//   یشکی_, _چدائ_, змәг, --, 
   {{0xbb403b5f,0xdb78001f,0x69d8002f,0x00000000}},	//   _жетк, ባቸውም_, pfve, --, 
   {{0x7c38019f,0xca7400db,0x7cd80055,0xc0d40240}},	//   _zmur, _بەتت_, _ṃriy, _ክደሊ_, 
   {{0x846c1e38,0xf55001c0,0x44380175,0x24980240}},	//   _ባህልን_, двээ, _pmq_, ërm_, 
   {{0x6a6400db,0x5ee00154,0x00000000,0x00000000}},	//   dòfi, নিতে, --, --, 
   {{0xdb084fa5,0xe8f005d9,0xa9380092,0x00000000}},	//   _reeë, _آڻڻ_, _እንቆቅ, --, 
   {{0xe53443a7,0xdb093c1e,0x85440276,0x00000000}},	//   _нель, _seeë, _мэйе, --, 
   {{0x60d40140,0x644c0af9,0x39980a7c,0x7bc8041e}},	//   utzm, _tjai, שילד, yggu, 
   {{0x60d5d4f4,0x443801f0,0x629c0194,0x00000000}},	//   rtzm, _umq_, ppso, --, 
   {{0x645dd4f5,0x44f80b3a,0x63ac00a3,0x41d000cd}},	// [34850] mosi, _hī_, _iean, _तापस, 
   {{0x645dd4f6,0x44f80325,0x63add4f7,0xf99c004d}},	//   losi, _kī_, _hean, _đèo_, 
   {{0x63add4f8,0x628c18a6,0x628400f1,0x69c428d4}},	//   _kean, _huao, _iiho, _राजी, 
   {{0x51580302,0x6285d4f9,0x628c0099,0xad24581f}},	//   _לכתו, _hiho, _kuao, بىمى, 
   {{0x6285d4fa,0x63ac771c,0x44f81a45,0x426c0092}},	//   _kiho, _mean, _lī_, _በህንድ_, 
   {{0x6285d4fb,0x645dd4fc,0x201806e4,0x66180115}},	//   _jiho, hosi, _hosi_, _novk, 
   {{0x2019d4fd,0x6285d4fe,0x628c0421,0x63ac01ab}},	//   _kosi_, _miho, _luao, _oean, 
   {{0x7c394f21,0x63add4ff,0x6285d500,0x201801c4}},	//   _umur, _nean, _liho, _josi_, 
   {{0x2019d501,0x3ce0017a,0x5a34030d,0x59c8012d}},	//   _mosi_, _hpjv_, _енат, _राऊर, 
   {{0x66180218,0x6285d502,0xaee400b8,0x79a406ed}},	//   _covk, _niho, _avṛt, _фрае, 
   {{0x1ddc32fd,0x645dd503,0x2018058a,0x00000000}},	//   न्यत, fosi, _oosi_, --, 
   {{0x63ac3c65,0x645dd504,0x6285d505,0x44f80055}},	//   _cean, gosi, _aiho, _dī_, 
   {{0x63add506,0x62848f4c,0x44f8003a,0x36e803e6}},	//   _dean, _biho, _eī_, _خراپ_, 
   {{0x20180066,0x877800c8,0x63ac0363,0x44f80139}},	//   _aosi_, _פאסי, _eean, _fī_, 
   {{0x6285d507,0x645dd508,0x2019d509,0x63add50a}},	//   _diho, bosi, _bosi_, _fean, 
   {{0x2018f5e9,0x628c0607,0xa3ac3885,0x628400b5}},	//   _cosi_, _fuao, गरण_, _eiho, 
   {{0x2019d50b,0x6285d50c,0x34d9d50d,0x6a6400cf}},	// [34860] _dosi_, _fiho, _बहुद, sòfi, 
   {{0x6285d50e,0x63add50f,0x454001b9,0x999000ee}},	//   _giho, _zean, _آچیق, _ýaňy_, 
   {{0x2019d510,0xc0dc02d3,0x63add511,0x260c012d}},	//   _fosi_, ዕብል_, _yean, ़ाती_, 
   {{0x20180521,0x6285d512,0x59c8000d,0x63ac0332}},	//   _gosi_, _ziho, _राउर, _xean, 
   {{0x62840a4d,0x41d0f059,0xfb800139,0x00000000}},	//   _yiho, _तामस, нышн, --, 
   {{0x628418f7,0x2018036b,0x6e3c01d5,0xdddc013a}},	//   _xiho, _zosi_, _umrb, _pusť, 
   {{0xfce02c9d,0x645dd513,0x2019d514,0xfbe4015b}},	//   _поро, yosi, _yosi_, ফাজত, 
   {{0x44f80383,0x645c003a,0x6618007c,0xab7c0354}},	//   _rī_, xosi, _sovk, _кӳлĕ_, 
   {{0xae201533,0x645c7bdf,0x66180218,0xb8d01715}},	//   _मकान_, vosi, _povk, _जौ_, 
   {{0x63add515,0x44f842ef,0x2a78067c,0x645c208d}},	//   _sean, _pī_, _òrb_, wosi, 
   {{0x63add516,0x628c0421,0x62840223,0x66180010}},	//   _pean, _suao, _riho, _vovk, 
   {{0x6285d517,0x69dc049f,0x628dd518,0x645c0024}},	//   _siho, _öreb, _puao, uosi, 
   {{0x2d99d519,0x2019d51a,0x6285d51b,0x628c020c}},	//   _ofre_, _rosi_, _piho, _quao, 
   {{0x63ac0493,0x2d9c03bd,0x44f804fe,0x4b4c02e3}},	//   _wean, ñvel_, _tī_, lụsọ_, 
   {{0x63add51c,0x2019d51d,0x6285d51e,0xdfd431af}},	//   _tean, _posi_, _viho, мовы, 
   {{0x2d98007f,0x628d7081,0x645dc0ec,0x6285d51f}},	//   _afre_, _tuao, qosi, _wiho, 
   {{0x6285d520,0xb6a001fb,0x201801a9,0x00000000}},	// [34870] _tiho, _nhấ, _vosi_, --, 
   {{0x3e6c006a,0x2018013f,0x2d980332,0x628401ab}},	//   füta_, _wosi_, _cfre_, _uiho, 
   {{0x2019d521,0x6fac00cc,0x00000000,0x00000000}},	//   _tosi_, _ছাৰে, --, --, 
   {{0x7a2c1a82,0x20180618,0x9f580450,0x96bc01ad}},	//   _møte, _uosi_, _anså_, _शिलॉ, 
   {{0xb6a001fb,0x7a2c4606,0x5a540107,0x198801d5}},	//   _chấ, _løte, мъку, обли_, 
   {{0x94fc0003,0xaa441c5c,0x00000000,0x00000000}},	//   _ཟླའི_, ىننى, --, --, 
   {{0x7a2c05ac,0xa3ac6620,0x7c8400d8,0x00000000}},	//   _nøte, गरा_, _хуге, --, 
   {{0xccf0025f,0x661c01e3,0x00000000,0x00000000}},	//   _בכל_, örkn, --, --, 
   {{0xb9e400d4,0x0ccc00eb,0x00000000,0x00000000}},	//   _ніжи, রবৃত, --, --, 
   {{0x7a2c119a,0x34a00818,0x00000000,0x00000000}},	//   _bøte, нгоҳ, --, --, 
   {{0x2458ad72,0xc4c401c4,0x00000000,0x00000000}},	//   lémy_, млэж_, --, --, 
   {{0xbb4c037e,0x1ddc102f,0xa3d80037,0xe8180354}},	//   _gooツ_, न्तत, ठ्ल_, _нохч_, 
   {{0x69dc0205,0x00000000,0x00000000,0x00000000}},	//   _örec, --, --, --, 
   {{0x7a2d3281,0x14c436d2,0x8778011a,0x00000000}},	//   _føte, _विपण, _ואני, --, 
   {{0x7a2c003b,0x987c083c,0x24580419,0x00000000}},	//   _gøte, lçın_, hémy_, --, 
   {{0x60c00321,0xd01001d5,0x62480064,0xe194009d}},	//   álma, خلر_, ežod, _үрээ, 
   {{0xb8fc0003,0x4474008f,0x3f64011c,0x00000000}},	// [34880] _སད_, _קעפל_, дито_, --, 
   {{0xb63c07ad,0xfde40137,0x52740345,0x00000000}},	//   _ｃｍ_, мдук_, _تابز, --, 
   {{0x0b8908c2,0x1ddc00cd,0x00000000,0x00000000}},	//   осли_, न्धत, --, --, 
   {{0xe7c8045e,0x0b4463e6,0x0c247fb5,0x7f800d1f}},	//   _শস্য, мнен, ьмен, رلەن, 
   {{0x8db410f5,0x00000000,0x00000000,0x00000000}},	//   _осві, --, --, --, 
   {{0x2cb807f5,0x1ddc00dc,0x00000000,0x00000000}},	//   _tvrd_, न्दत, --, --, 
   {{0x35a41533,0xda649f43,0x72700092,0x00000000}},	//   _ग़ज़, راهي, ሠረታዊ_, --, 
   {{0x7d00019b,0xc7c428eb,0xb6a001fb,0x7a2c00fe}},	//   ænse, фски, _thấ, _røte, 
   {{0x249c04cc,0x7a2c1445,0x26c4817e,0x05e80798}},	//   _stvm_, _søte, urmo_, офни_, 
   {{0xfaa0b4da,0x00000000,0x00000000,0x00000000}},	//   _рафо, --, --, --, 
   {{0x6e200276,0xa3d4059f,0x00000000,0x00000000}},	//   _îmbu, нонч, --, --, 
   {{0x46a4006c,0x7b040139,0x00000000,0x00000000}},	//   _жадв, _ürtä, --, --, 
   {{0xb3640395,0x598001af,0x970000d1,0x00000000}},	//   върк, _иһәб, _مېيى, --, 
   {{0x78500276,0x7d0001e6,0x8174013e,0xf42003d4}},	//   măva, ånsk, дагӣ_, মোলৰ_, 
   {{0xf1949842,0x24580306,0xf1e4012d,0x00000000}},	//   тись, zémy_, ग़ज़_, --, 
   {{0x34480166,0x00000000,0x00000000,0x00000000}},	//   _очын_, --, --, --, 
   {{0xd24c07d6,0xf2c4008e,0x9f540108,0x62480419}},	// [34890] شچی_, _исэн, хвач, dľov, 
   {{0x24880070,0xbd680a8f,0xe0600133,0x7d6801d5}},	//   _hiam_, орее_, _ڕێزی, ошев_, 
   {{0x24881a4c,0x2240005a,0x15c40131,0x624800d7}},	//   _kiam_, _imhk_, ﯩﺪﯨﻐ, fľov, 
   {{0x3f88009a,0x24880076,0x24580419,0x00000000}},	//   _ugcu_, _jiam_, témy_, --, 
   {{0x2488387a,0x4b4c063f,0xd1400023,0x00000000}},	//   _miam_, wụrọ_, _ነስተው, --, 
   {{0x661c01e6,0x2458004a,0x00000000,0x00000000}},	//   örkl, rémy_, --, --, 
   {{0x248805b1,0x62480419,0x00000000,0x00000000}},	//   _oiam_, bľov, --, --, 
   {{0x2489d522,0x47e80489,0x00000000,0x00000000}},	//   _niam_, _རྒྱམ, --, --, 
   {{0x2369d523,0x00000000,0x00000000,0x00000000}},	//   _nyaj_, --, --, --, 
   {{0x987c1432,0x5a34009d,0x00000000,0x00000000}},	//   rçın_, _янзт, --, --, 
   {{0xd4685ff5,0x693400d8,0x00000000,0x00000000}},	//   зине_, _инфу, --, --, 
   {{0x24880211,0x23680369,0x00000000,0x00000000}},	//   _ciam_, _byaj_, --, --, 
   {{0x2489d524,0x2d9c030a,0x00000000,0x00000000}},	//   _diam_, ñvek_, --, --, 
   {{0x23680100,0xe6119b10,0x6a64067c,0x624800d7}},	//   _dyaj_, _پشه_, lòfr, zľov, 
   {{0x9f5819f5,0x2d9c01d3,0x24f4064e,0x2489d525}},	//   _insù_, űvek_, _ачыр, _fiam_, 
   {{0x2488001e,0x00000000,0x00000000,0x00000000}},	//   _giam_, --, --, --, 
   {{0x23680369,0x9f5800e4,0x27e00037,0x00000000}},	// [348a0] _gyaj_, _hasê_, _öine_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x59c81408,0x624800d0,0x8d5496ed,0x00000000}},	//   _राजर, tľov, хтач, --, 
   {{0x248801d4,0xc4d0010f,0xbca00116,0x00000000}},	//   _xiam_, רגא_, چمەي, --, 
   {{0xe0d0015b,0xbca00131,0xc0000153,0x00000000}},	//   াবৃন, نمەي, _спяк, --, 
   {{0x9e700131,0x62480419,0x00000000,0x00000000}},	//   _نۇقت, sľov, --, --, 
   {{0xaa441e87,0xd9b00075,0x661c0267,0x62480030}},	//   ىنچى, شەند, örkm, pľov, 
   {{0x46200125,0xd90c3e58,0xdc2801b9,0xc0f8010f}},	//   ትዮጵያ, تیم_, _قسقه_, פּוט, 
   {{0x4ac442c6,0x2489d526,0x1b640022,0x09e400d8}},	//   _سياق, _riam_, _антҭ, _поан, 
   {{0x78500356,0xdb4c0345,0x00000000,0x00000000}},	//   răva, _بێه_, --, --, 
   {{0x24880070,0x245802bf,0xd90c03e6,0x46c02e1e}},	//   _piam_, дань_, _ویه_, _शिवह, 
   {{0x2489d527,0x38c80424,0x2295d528,0x77ac0055}},	//   _qiam_, _رامی_, кимя, _ṭavī, 
   {{0xb6a005f5,0x24881730,0x81c80183,0x41e40d30}},	//   _бичл, _viam_, _ৰোগ_, ніва, 
   {{0x75d01b45,0xf10c01ad,0x8ed40154,0xf4dc00cc}},	//   _ميها, हमूद_, হবাগ, _বছৰব, 
   {{0x24888c36,0x8005d529,0x00000000,0x00000000}},	//   _tiam_, нчае, --, --, 
   {{0x63a81709,0x2488bb1d,0x7a2c9b7b,0x68fc0798}},	//   ñend, _uiam_, _møta, _árdu, 
   {{0x9df9d52a,0x7a2c0174,0x00000000,0x00000000}},	// [348b0] мнат_, _løta, --, --, 
   {{0x9f580200,0x2dd4004e,0x00000000,0x00000000}},	//   _hasë_, лжур, --, --, 
   {{0x61e401e2,0x7a2c03b2,0x61e00254,0xa5d80118}},	//   _ibhl, _nøta, õllu, _मानौ, 
   {{0xdea00014,0x7c6400db,0x3e6c04cc,0xdb080432}},	//   _نیری, راال, püto_, _edeý, 
   {{0xac94052f,0x9f580023,0x274400b0,0x1b400092}},	//   _ҡарш, _masë_, nīnī_, _ፓርቲያ, 
   {{0xba753419,0xceb000c8,0xd945d52b,0x7a2c0162}},	//   راشت, _דיך_, кели, _bøta, 
   {{0x940801e4,0x00000000,0x00000000,0x00000000}},	//   _ĉaɾ_, --, --, --, 
   {{0xa904021a,0x6e200276,0xd7080a8f,0x6aa00332}},	//   ابون, _îmbr, дние_, _ftmf, 
   {{0xd5b80228,0x6b840219,0x61e40f91,0x79a40353}},	//   үсү_, žigr, _obhl, _зрее, 
   {{0x7c28049f,0x85b84d66,0xd6d800cf,0x00000000}},	//   lkgr, واپس_, птү_, --, 
   {{0x7a2c0162,0xa8a416a4,0xa3ac00cd,0x53a400cf}},	//   _gøta, _брчк, गरं_, канб, 
   {{0x61e403d5,0x7c29d52c,0x2e241876,0xfbb028f0}},	//   _abhl, nkgr, _höft_, ुणिम, 
   {{0xdb0825e6,0x387c08a7,0x25a00790,0x6aa001a9}},	//   _ideó, mmur_, _şile_, _xtmf, 
   {{0x9f580ffb,0x387dd52d,0x3fc8004b,0xd1740352}},	//   _iasè_, lmur_, ېدلی_, выбы, 
   {{0x9f58067c,0x4f940261,0x7c28d361,0x7850054e}},	//   _hasè_, врзу, kkgr, năvo, 
   {{0x61e40354,0x4428b281,0x13044131,0x387c0213}},	//   _ebhl, ckc_, _азим, nmur_, 
   {{0xc7b01a4c,0x387c008c,0x6388005f,0x9f5801e1}},	// [348c0] יבן_, imur_, _cīnī, _jasè_, 
   {{0x9f58007f,0xd1b8824e,0x387c020c,0x7c280549}},	//   _masè_, _کاکا_, hmur_, ekgr, 
   {{0xf764021a,0xdb080077,0x10a447f9,0x51540276}},	//   _چا_, _odeó, _шинн, _штиу, 
   {{0x61e83341,0x83e8002e,0x387c0200,0xb3b000cc}},	//   đele, _njёl, jmur_, _কাঁজ, 
   {{0x764000aa,0x27e00784,0x7a2ca934,0x81c801ed}},	//   _omny, _ñini_, _søta, _عطیہ_, 
   {{0xf98c386e,0xbb4035dd,0x387c0393,0xad8400db}},	//   يبى_, шечк, emur_, _مازۇ, 
   {{0x7a1000ec,0x00000000,0x00000000,0x00000000}},	//   شبوء, --, --, --, 
   {{0x764195ca,0x7c28b183,0x387dd52e,0x00000000}},	//   _amny, ckgr, gmur_, --, 
   {{0x25a00198,0xf76c00c6,0xca85d52f,0x8b6402f2}},	//   _ƙil_, ياً_, _агай, _شارم, 
   {{0x35e000d6,0x387c0381,0x00000000,0x00000000}},	//   ацюв, amur_, --, --, 
   {{0xf67005f5,0x9f580240,0x44280175,0x00000000}},	//   ргээ, _pasë_, tkc_, --, 
   {{0x76402747,0x07a415ed,0xe7040014,0x9f58020c}},	//   _emny, _радн, _مستی, _fasè_, 
   {{0xe58404a9,0x2be0000d,0x3da807d2,0x37d800cc}},	//   _өткү, _गउईं_, _ﺷﯘﯕﻘ, _মোকৰ, 
   {{0x787400c7,0xa4d400d4,0x00000000,0x00000000}},	//   rãve, _бокі, --, --, 
   {{0x44280491,0x9f5800c7,0xa2440150,0xdddc00ef}},	//   pkc_, _tasë_, _ەرجۇ, _pusž, 
   {{0xc1003bfd,0x9f5800e4,0x3f8c022c,0xc0580816}},	//   гүүл, _hasé_, øgu_, фіг_, 
   {{0x09c85d2d,0x906400f7,0x00000000,0x00000000}},	// [348d0] ল্যা, انقۇ, --, --, 
   {{0x387dd530,0x61e4df90,0x645dd531,0x661c01e3}},	//   zmur_, _ubhl, érif, örkh, 
   {{0xee85d532,0x387dd533,0x9f580066,0xdfd40166}},	//   рыто, ymur_, _masé_, _йоны, 
   {{0x9b585aba,0xdd0c012d,0xdb340120,0x387c022e}},	//   ниет_, _półp, леењ, xmur_, 
   {{0x3e8400fd,0x00000000,0x00000000,0x00000000}},	//   _җиңү_, --, --, --, 
   {{0x7c296e25,0x00000000,0x00000000,0x00000000}},	//   skgr, --, --, --, 
   {{0x291800e4,0xacf80117,0x00000000,0x00000000}},	//   _àral_, _инру_, --, --, 
   {{0xb8d81dd1,0x387c01a8,0xca200150,0xd87400db}},	//   _अब_, umur_, _ﹸﺒﺙ_, داتب, 
   {{0x387dd534,0x76400218,0x9f5807ea,0x00000000}},	//   rmur_, _pmny, _basé_, --, 
   {{0x9f581ada,0x387dd535,0xeab00014,0x00000000}},	//   _casé_, smur_, _گٹے_, --, 
   {{0xdb080139,0x498c0023,0x7d1402d0,0xd3940166}},	//   _ideñ, _ሓሳባቱ_, nxxs, ләпә_, 
   {{0x88980375,0x54349cad,0x00000000,0x00000000}},	//   _טבעי, اردر, --, --, 
   {{0x55e40372,0x9f580066,0xd02406b3,0x04400a89}},	//   _болб, _fasé_, қмай, сеян, 
   {{0x76402747,0x7d0403ac,0x00000000,0x00000000}},	//   _umny, _orjs, --, --, 
   {{0x3e6c0086,0x62980066,0x63a80077,0x4638010f}},	//   müth_, _éwon, ñenc, _רעצע, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7d00037e,0x51b8084c,0x4478010f,0x00000000}},	// [348e0] ænsn, _пыня_, _אנקע, --, 
   {{0xc330025f,0x9f58002e,0x7a2c003b,0x0d2000cf}},	//   _לוח_, _xasé_, _søtn, бүгү, 
   {{0xca840046,0x6138010b,0x61e00ba1,0x8d580818}},	//   ңгей, _ачяр_, òlle, хшат_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3598001f,0x7a2c0174,0xaa4400c7,0x63880171}},	//   _ቁሳቁስ_, _vøtn, аҵал, _tīnū, 
   {{0x2ee03132,0x7d140175,0x6fa01fc4,0x00000000}},	//   mtif_, bxxs, गुरू, --, 
   {{0x6f05d536,0x2ee00213,0x9f5806af,0x1cdc0327}},	//   lvic, ltif_, _rasé_, _ཡཱག_, 
   {{0x0ba80eff,0x6d5c00ac,0x2e2405d5,0xcb680305}},	//   _سارى_, _ixra, _töfs_, _забе_, 
   {{0x6f05d537,0x2ee1d538,0x9f59d539,0x7a2c0162}},	//   nvic, ntif_, _pasé_, _køtl, 
   {{0x7d040005,0x2ee0022f,0x3e480064,0xfa64009b}},	//   _yrjs, itif_, _gėtė_, _баук_, 
   {{0xb9903dca,0x87e4614c,0x82341e87,0x98c40212}},	//   _المب, _бюле, ۇرسا, _всіл, 
   {{0x6f0407f5,0x87047405,0x00000000,0x00000000}},	//   kvic, _مبتل, --, --, 
   {{0x9f58002e,0xa2940d30,0x6f040118,0x41c40006}},	//   _tasé_, рагі, jvic, лёва, 
   {{0xe1344a40,0x9f480209,0x6d5c4cc0,0xa1580111}},	//   ангы, gdaý_, _oxra, вагу_, 
   {{0x6f041ba4,0x6928013f,0x00000000,0x00000000}},	//   evic, sɛef, --, --, 
   {{0xd34416e6,0x645c06af,0x6f04003e,0x00000000}},	//   اییه_, érid, fvic, --, 
   {{0x3da44df9,0x1cdc025c,0x83f40022,0xc2e401b9}},	// [348f0] греб, _ཡཱང_, _аеқс_, _сўйи, 
   {{0x9f5807c5,0x7d140175,0xee2001ec,0x00000000}},	//   _insü_, txxs, пеуi_, --, 
   {{0xf1a4bcf5,0x2ee1d53a,0x1ba402d3,0x6f04010f}},	//   _урын, atif_, _ዝበለጸ_, avic, 
   {{0x3e9412fc,0x787400e4,0xada401d5,0xe8200037}},	//   _مؤسس, kãva, _ҳаёл, _बवगा_, 
   {{0x2ee1d53b,0xdd940209,0x6f040306,0xaae40472}},	//   ctif_, _вагы, cvic, مسوو, 
   {{0x2d9c0156,0xdd0c0241,0x329c011a,0x18a4004e}},	//   ñvet_, _póńp, עבוד, аакм, 
   {{0x18a5444d,0x998800c7,0x3c800055,0x00000000}},	//   шайм, тәаз_, _ṛtuḥ_, --, 
   {{0x9aa46f33,0xfc30007b,0xf98400ec,0x2d9c00e5}},	//   _نمرو, _احس_, پنڊي_, űvet_, 
   {{0xa3d8202e,0x5670069d,0x9d44008e,0x3e480064}},	//   ालन_, _ስብከቱ_, _сеңд, _tėtė_, 
   {{0x7af84cbd,0x6d5c0139,0x00000000,0x00000000}},	//   _isut, _yxra, --, --, 
   {{0xaaf80086,0x38a006b9,0x6f040433,0x5ee00154}},	//   _òbòñ_, _sırf_, zvic, নিটে, 
   {{0x7af80204,0x33b00ca8,0xf3f800d1,0x245800e4}},	//   _ksut, _bẹẹn, уңи_, tĩma_, 
   {{0x7a0802b5,0x8c1802e4,0x00000000,0x00000000}},	//   _tētē, דורי, --, --, 
   {{0x5434107f,0x6f05d53c,0x2c7c0332,0x00000000}},	//   ارگر, vvic, míde_, --, 
   {{0x53a40724,0x92d40154,0x00000000,0x00000000}},	//   _кайб, সবে_, --, --, 
   {{0x3204006d,0x7af8007d,0x6f05d53d,0x6aa40276}},	//   śmy_, _osut, tvic, ţifi, 
   {{0x645dd53e,0x2c7c0332,0x5274010a,0x00000000}},	// [34900] érie, níde_, _вуну, --, 
   {{0x2ee1d53f,0x7bd8127b,0x62480064,0xc6900115}},	//   rtif_, _acuu, nžol, קאב_, 
   {{0x7af9d540,0x63a00210,0x00000000,0x00000000}},	//   _asut, ślne, --, --, 
   {{0xa3d80cf1,0x2ee1d541,0x29180327,0x00000000}},	//   ालय_, ptif_, _ħra_, --, 
   {{0x7d00072b,0x7ff454f0,0x00000000,0x00000000}},	//   ånsr, _ئسپا, --, --, 
   {{0x7bd804ba,0xe8940022,0x2c7c00d7,0x00000000}},	//   _ecuu, бакь, díde_, --, 
   {{0x7af88263,0x2d9c01ed,0x17ac0154,0xe9c400c7}},	//   _esut, űves_, _গাড়ি, _ҳазҿ, 
   {{0xa5d8924b,0x4c358b32,0xbcdc0118,0x787400e4}},	//   _माहौ, _тэгт, žšíh, tãva, 
   {{0xfaa1d542,0xdb180066,0x76b43c1a,0x8034010f}},	//   _мато, jawè, алыр_, ינקע_, 
   {{0xdb18007f,0x0624180b,0x78740022,0x00000000}},	//   dawè, рфим, rãva, --, 
   {{0x351405f5,0x00000000,0x00000000,0x00000000}},	//   ажээ_, --, --, --, 
   {{0x478400f7,0xd838003e,0x69d8017a,0xa4380114}},	//   _кылб, chō_, lgve, узму_, 
   {{0xdd940597,0xdb1800f2,0xa3d800e1,0x2c7c00ae}},	//   ǁ҈ǁ_, gawè, ालब_, cíde_, 
   {{0x3e6c01b8,0x645c003a,0xd6c40101,0x00000000}},	//   püti_, érib, _اموی, --, 
   {{0x661c01a8,0x69d80af9,0xf678011a,0x97400023}},	//   örku, igve, _שאומ, _ክትዓት, 
   {{0x5f440597,0x442dd543,0xddc400e4,0xd6d80210}},	//   منزل, _ôg_, mohũ, szłe_, 
   {{0x41e40006,0x7a2c03b2,0x66f81b76,0xef98014b}},	// [34910] _кіна, _søtm, ्टिक_, ркуш_, 
   {{0x63bdd544,0x3da5d545,0x61f800c0,0x00000000}},	//   lasn, рраб, _сноў_, --, 
   {{0x9b940058,0x61f4a697,0x7af80194,0x00000000}},	//   ملات, mezl, _ssut, --, 
   {{0x2d9c0dd4,0x69d8d2aa,0x272000b0,0x61f5d546}},	//   ñver_, egve, _kōnā_, lezl, 
   {{0x629c0007,0xdd0005a1,0x9f580241,0x5018011a}},	//   nqso, čuđe, _kasí_, _עושו, 
   {{0x69d9d547,0x272000b0,0x63bdd548,0x229c0051}},	//   ggve, _mōnā_, hasn, _mìk_, 
   {{0x60d44dd9,0x00000000,0x00000000,0x00000000}},	//   nuzm, --, --, --, 
   {{0x7af9d549,0x69d8257c,0x2c7c00d0,0x48000395}},	//   _tsut, agve, tíde_, зпъв, 
   {{0x7af9d54a,0x63bc05a1,0x15b80209,0xf1c001f1}},	//   _usut, dasn, лыны_, žšiu_, 
   {{0x9f580270,0xd05c013f,0x63a80077,0xdb080254}},	//   _nasí_, _ɑyɑr, ñenn, _veeä, 
   {{0x63bdd54b,0xd548301d,0xa9081370,0xd7c8007b}},	//   fasn, упне_, _پينل_, _موضه_, 
   {{0x5eac0183,0xd7940597,0x60d40552,0xdb08000d}},	//   _চিনে, _الإخ, duzm, _teeä, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb18551a,0x61f40724,0xc690008f,0x63bc00d7}},	//   gawé, gezl, _זאג_, aasn, 
   {{0xc0dc044e,0x63bdd54c,0x2bd8000d,0xeaf402c3}},	//   _ንቡር_, basn, _डाला, _इन्त_, 
   {{0xb2b41248,0x69d80007,0x9f480165,0x00000000}},	//   _мәгъ, zgve, edañ_, --, 
   {{0x4f085f05,0x61f40419,0x4c680116,0x00000000}},	// [34920] ынан_, bezl, ңизн_, --, 
   {{0x60c8005f,0x00000000,0x00000000,0x00000000}},	//   ņema, --, --, --, 
   {{0x7c380227,0x020001c0,0x01940375,0x527400f2}},	//   _ŋura, _эзэн, _לכיש_, _پاکز, 
   {{0x7a2c003a,0x78500356,0x00000000,0x00000000}},	//   _høth, băvi, --, --, 
   {{0xa3d806bc,0x9f58013d,0x00000000,0x00000000}},	//   ालत_, _yasí_, --, --, 
   {{0x63bdd54d,0xbea0160b,0x69d803cd,0x3ea05b11}},	//   zasn, _харк, ugve, _хирг, 
   {{0xc9140729,0x69d84174,0x3ce81d55,0x9f48041e}},	//   ়ন্ত_, rgve, čivá_, ldað_, 
   {{0x7d540375,0xec3401d5,0x61f4030a,0x629c0200}},	//   _הילד_, _بورگ, zezl, yqso, 
   {{0x3b05d54e,0x9f481f60,0x63bdd54f,0xae1c05f9}},	//   _лето_, ndað_, vasn, नापन_, 
   {{0x63bdd550,0xc8c84710,0x00000000,0x00000000}},	//   wasn, _موئن_, --, --, 
   {{0x38c89a5a,0x63bdd551,0x69c9d552,0x61f5d553}},	//   _مانی_, tasn, _idde, vezl, 
   {{0xb9780a1e,0xe46400a2,0xb7d4009a,0xd548010a}},	//   _גנבי, _ölüş, _هوما_, ăпне_, 
   {{0x7a2c05ac,0x61f42cc7,0x661c01e3,0x00000000}},	//   _bøth, tezl, örks, --, 
   {{0x60d40354,0x290c01fa,0x7d0001a8,0x7ebc01e1}},	//   tuzm, _krda_, ænsk, _làpá, 
   {{0x659400d1,0x8174013e,0x61f52c1f,0xdb180c6a}},	//   _лаһу, савӣ_, rezl, rawé, 
   {{0x272002b1,0x63bd3223,0x00000000,0x00000000}},	//   _tōnā_, qasn, --, --, 
   {{0x69c9d554,0x44f9d555,0x629c010a,0x61f40030}},	// [34930] _odde, _hū_, qqso, pezl, 
   {{0x290dd556,0x44f818a6,0x7a2c03b2,0x7850054e}},	//   _orda_, _kū_, _gøth, răvi, 
   {{0x5f953ca5,0x9f49d557,0x44f80153,0x00000000}},	//   _минт, rdañ_, _jū_, --, 
   {{0x69c9d558,0x44f9d559,0xa3d8024a,0x00000000}},	//   _adde, _mū_, ालि_, --, 
   {{0xdc38038f,0x44f806c8,0x290dd55a,0x69c80175}},	//   għġb, _lū_, _arda_, _bdde, 
   {{0x290c08ad,0x69c80175,0x7874035b,0x00000000}},	//   _brda_, _cdde, tãvo, --, 
   {{0xa3d8482a,0x44f9d55b,0xf1dc0254,0x99d400f1}},	//   ाला_, _nū_, _बासन, متګا, 
   {{0x09c803f4,0x69c9d55c,0x7a2c0579,0x63a80077}},	//   ল্লা, _edde, _møti, ñenl, 
   {{0x55f4c134,0x9f580109,0x290c01b9,0x7a2c03b2}},	//   очну, _jasà_, _erda_, _løti, 
   {{0x44f84a38,0x3e6c000d,0x2c7cdd18,0x6d5800c7}},	//   _bū_, müts_, mída_, úvag, 
   {{0x290c0427,0xd95402f2,0x7a2c7dfa,0x388400e5}},	//   _grda_, _بناخ, _røth, _bőrt_, 
   {{0x1cdc0489,0xd469d55d,0x683c002e,0x5469d55e}},	//   _ཡཱན_, риме_, _cédd, рамм_, 
   {{0x67d4063b,0x645c65fa,0x683c003e,0x14c40490}},	//   _хочу, éria, _dédd, _विकण, 
   {{0x7a2c0162,0x62900241,0xd94801f3,0x00000000}},	//   _bøti, _ìjo̟, _እንዳጋ, --, 
   {{0xd0105e79,0x3e6c07de,0x45a02a8b,0x44f80064}},	//   ولس_, hüts_, _تەپك, _gū_, 
   {{0x9f5804cc,0xf1dcacd2,0x1610033f,0xa3a8012d}},	//   _basà_, _बावन, ़ाकर_, खुद_, 
   {{0x3e6c00dd,0x9f5800db,0x1ea8157c,0xf3ec00cc}},	// [34940] yütt_, _casà_, مالي_, _জোথৰ_, 
   {{0x3e6c05d5,0xd09800ec,0x00000000,0x00000000}},	//   düts_, _پئدا_, --, --, 
   {{0xfce0979a,0x00000000,0x00000000,0x00000000}},	//   дохо, --, --, --, 
   {{0xd008bda8,0x09d0712e,0x00000000,0x00000000}},	//   _теме_, सल्य, --, --, 
   {{0xcaf41867,0x2fc000a3,0xcca8215c,0xfb800139}},	//   تساب, maig_, انچۇ_, мышн, 
   {{0x683c0231,0x2fc1d55f,0x00000000,0x00000000}},	//   _méde, laig_, --, --, 
   {{0x683c7538,0xfce0009d,0x6d580162,0x00000000}},	//   _léde, _ооро, úvad, --, 
   {{0x44f9d560,0x2fc1d561,0x3e6c0254,0x8034010f}},	//   _rū_, naig_, sütt_, ַניע_, 
   {{0x69c80334,0x258400e8,0xdcf40171,0xb76001c6}},	//   _tdde, këlé_, _izzā, дтэй, 
   {{0x44f9d562,0x69c9d563,0x290dd564,0x858812d7}},	//   _pū_, _udde, _trda_, иёна_, 
   {{0x2d980268,0x290c00fd,0x291800f3,0x2fc12300}},	//   _mgre_, _urda_, _šraf_, kaig_, 
   {{0xd6d80034,0xefc00092,0x00000000,0x00000000}},	//   szła_, _ስንዴ_, --, --, 
   {{0x2fc1d565,0x2d9800e2,0x683d0aae,0x7a2c03b2}},	//   daig_, _ogre_, _céde, _søti, 
   {{0x44f81f4c,0x2d980023,0x683c00e8,0x26c40fac}},	//   _tū_, _ngre_, _wédd, msmo_, 
   {{0x683c003e,0x26c405ac,0x2fc008c2,0x00000000}},	//   _tédd, lsmo_, faig_, --, 
   {{0x60c8005f,0x683c0098,0x9f5804cc,0x20c4005f}},	//   ņemo, _féde, _pasà_, rķi_, 
   {{0x644dd566,0x01e004c5,0x4438022e,0x26c433b8}},	// [34950] _imai, য়বদ, _ilq_, nsmo_, 
   {{0x26c5d567,0x3e6c05d5,0xdb2000c7,0x7a2c0174}},	//   ismo_, vüts_, _ëtév, _tøti, 
   {{0x644dd568,0x2fc10567,0x9f5801e1,0x2d8c00d7}},	//   _kmai, baig_, _wasà_, _údel_, 
   {{0x2d98003a,0x26c40024,0x3e6c07de,0x2c7c00d0}},	//   _egre_, ksmo_, tüts_, tída_, 
   {{0x501804ae,0x644cd023,0xc0e00023,0x00000000}},	//   _הורו, _mmai, ምዖም_, --, 
   {{0xceb0dbff,0x7a2c0158,0x44380076,0x3e6c05d5}},	//   _איך_, _løtv, _llq_, rüts_, 
   {{0x644dd569,0x3e6c01b8,0x2c7dd56a,0x00000000}},	//   _omai, süts_, sída_, --, 
   {{0x644c01ab,0xdd9000db,0x6ab80162,0xae1c134e}},	//   _nmai, _يوڭ_, ðafú, नाथन_, 
   {{0xe6d405f5,0x7c38a7dd,0x26c40024,0x7ac4030d}},	//   мцээ, _ilur, gsmo_, _фсбе, 
   {{0x644dd56b,0x683dd56c,0x7c380564,0x645cd1f4}},	//   _amai, _réde, _hlur, érin, 
   {{0xe9380014,0x7c39d56d,0x683c06af,0x645c00e4}},	//   _وسمت_, _klur, _séde, ĩrin, 
   {{0x683c004a,0x644c0139,0x38c80133,0x00000000}},	//   _péde, _cmai, _ماچی_, --, 
   {{0x644c0334,0x00000000,0x00000000,0x00000000}},	//   _dmai, --, --, --, 
   {{0x683dd56e,0x7c386d79,0xa5f80063,0x2fc00076}},	//   _véde, _llur, _мечу_, waig_, 
   {{0x7c39d56f,0xe61017b9,0x644dd570,0x217406ed}},	//   _olur, _جشن_, _fmai, дутр, 
   {{0x644ce6a6,0x2fc0062c,0x3ea80208,0x00000000}},	//   _gmai, uaig_, _btct_, --, 
   {{0x2fc1d571,0x0dc86c15,0x00000000,0x00000000}},	// [34960] raig_, йлай_, --, --, 
   {{0x7c39d572,0x2fc1d573,0xd6bc0154,0x00000000}},	//   _alur, saig_, _আমায, --, 
   {{0x7c39d574,0x0ba852c8,0x644dd575,0x7a2c2a5b}},	//   _blur, ماشى_, _ymai, _jøtu, 
   {{0x7c395f19,0xd6d8068f,0x0c24741d,0x683c0036}},	//   _clur, kuł_, ямен, _médc, 
   {{0x7a2c0579,0x08e4015b,0x7c380334,0xc4a00150}},	//   _løtu, কিছু_, _dlur, _ﺍﻟﺤﻘ_, 
   {{0x38a02c70,0x7c39d576,0xd6d8033f,0xcc2400e5}},	//   _sıra_, _elur, duł_, _کرسٹ, 
   {{0x7c39d577,0x187c02d3,0x2d8c06af,0x7a2c03b2}},	//   _flur, _ብህዝቢ_, _àde_, _nøtu, 
   {{0x7c39d578,0xefe002d3,0x25bc0165,0xb8d02374}},	//   _glur, _ሓሳዊ_, _sevl_, رتىش, 
   {{0x26c40024,0xf6e04889,0xd6d80210,0x00000000}},	//   usmo_, нцэн, guł_, --, 
   {{0x44380421,0x644dd579,0x61e839ae,0x7a2cf5b8}},	//   _slq_, _smai, đelk, _søtv, 
   {{0x644c0421,0x645dd57a,0xa3d534a1,0x47f001c6}},	//   _pmai, ério, монч, _зүйр, 
   {{0x62480122,0x644dd57b,0x7a2c0174,0x44380129}},	//   nžov, _qmai, _døtu, _qlq_, 
   {{0x69dc0267,0x82a4005b,0x63a00210,0x00000000}},	//   _öres, яшне, ślno, --, 
   {{0x7a2c06ea,0x5bb83f7e,0x00000000,0x00000000}},	//   _føtu, _उज्व, --, --, 
   {{0x7a2c022c,0x644dd57c,0x44380208,0xfa74011a}},	//   _gøtu, _tmai, _tlq_, פעלת_, 
   {{0x644dd57d,0x7124129d,0xa3a80210,0x00000000}},	//   _umai, رىقم, खुश_, --, 
   {{0x7a2c03b2,0x6249d57e,0xff5008f0,0x645c007c}},	// [34970] _køtt, džov, رخر_, mnsi, 
   {{0xe28436c1,0xb2bc0375,0xc2240408,0x00000000}},	//   _تطبی, _המזר, _хьий, --, 
   {{0x6284013e,0x7a2dd57f,0x645c01d9,0xdcf81867}},	//   _ihho, _møtt, onsi, تفات_, 
   {{0x645dd580,0x9f340220,0x7a2c0174,0x00000000}},	//   nnsi, _жемі, _løtt, --, 
   {{0x645dd581,0x2019d582,0x3cfc20f0,0x7058030d}},	//   insi, _insi_, _रनवे_, _хаяр_, 
   {{0x200802d5,0x645dd583,0x7a2c168c,0xeab000e3}},	//   ldai_, hnsi, _nøtt, اعن_, 
   {{0x7c3818f7,0x2008009f,0x645c007f,0xca880046}},	//   _tlur, odai_, knsi, _ﺗﻮﺗﻪ_, 
   {{0x20092442,0xdb18006a,0xc0dc02d3,0xd6d8068f}},	//   ndai_, rawâ, _ንኡስ_, tuł_, 
   {{0x200803b4,0x6285d584,0x7a2c0162,0x9b946550}},	//   idai_, _ohho, _søtu, _циац, 
   {{0x645dd585,0xd6d80034,0x200803cb,0x00000000}},	//   ensi, szło_, hdai_, --, 
   {{0x06dc045e,0xa3d80b7c,0x7a2c03b2,0x645c01a8}},	//   _বৈদি, ालं_, _døtt, fnsi, 
   {{0x628401ed,0x69dc0295,0x36c4010b,0x2c580100}},	//   _ahho, _örer, _еңип_, tčdi_, 
   {{0x20080f7b,0x7a2c2c95,0x55e41075,0x92e400b8}},	//   ddai_, _føtt, _жолб, _mṛgī, 
   {{0x645dd586,0x200802d5,0x628431c4,0x7a2c01bf}},	//   ansi, edai_, _chho, _gøtt, 
   {{0x8fa5d587,0xae1c02c3,0x200803cb,0xd00802e8}},	//   дабе, नासन_, fdai_, оеве_, 
   {{0x628442c9,0x683c00f2,0xd5dc01ad,0x20080142}},	//   _ehho, _kéda, _माँज, gdai_, 
   {{0xb8dc0135,0x60d40036,0x4e05d588,0x4ad00037}},	// [34980] _ཀས_, arzm, мзаб, _सिधव, 
   {{0x2019d589,0x683dd58a,0x0dc90617,0x628401ab}},	//   _ensi_, _méda, ілей_, _ghho, 
   {{0xe2a8cefc,0x2018011c,0x2c7c0118,0xc0dc0b82}},	//   _واین_, _fnsi_, bídl_, ንብል_, 
   {{0xc5e003bd,0x8fd000c7,0x2c7c00e4,0x24580022}},	//   _འཁྐྲ, _шәгә, rído_, tĩmi_, 
   {{0x62494874,0xfaa00cda,0x17f800dc,0xd5dc0d79}},	//   ržov, вачо, ्यैव_, _मांज, 
   {{0x48a99e3a,0x245800e4,0xe4640139,0x645c022e}},	//   отим_, rĩmi_, _ölöş, znsi, 
   {{0x26f852f2,0x7a2c9f65,0x998400bc,0x92e40055}},	//   ्ट्र_, _røtt, _dolů_, _hṛdī, 
   {{0x683c54ba,0x61e81591,0xe7cc00cc,0x2bd81025}},	//   _béda, đeli, লভ্য, _डाटा, 
   {{0x6618005a,0x683c0129,0x645dd58b,0x5fe01cd2}},	//   _pnvk, _céda, érim, _फासल, 
   {{0x2009d58c,0x645dd58d,0x683cb0f7,0x66180175}},	//   zdai_, wnsi, _déda, _qnvk, 
   {{0x6aa1d58e,0x245404fb,0xfa3004b3,0x45483d6b}},	//   _humf, فندس, _جىلج, ючим_, 
   {{0x6aa0dd9e,0xf8b00a1e,0x645dd58f,0x6284022e}},	//   _kumf, _ישע_, unsi, _shho, 
   {{0x645dd590,0x7bdc66e5,0x7a2cb3f8,0x47354db6}},	//   rnsi, òqui, _tøtt, _تراز, 
   {{0x6aa1d591,0xf77c0598,0x9f596faa,0x62240131}},	//   _mumf, üçe_, _jaså_, رىزل, 
   {{0x6aa1d592,0x04640063,0x00000000,0x00000000}},	//   _lumf, _отим, --, --, 
   {{0x20097ee2,0x624800de,0x00000000,0x00000000}},	//   udai_, ežot, --, --, 
   {{0x6aa00b45,0x2009d593,0x1e14086f,0x7a2c365a}},	// [34990] _numf, rdai_, нмая, _møtr, 
   {{0x9e7403e6,0x20080142,0x00000000,0x00000000}},	//   رهات, sdai_, --, --, 
   {{0x61e5d594,0x00000000,0x00000000,0x00000000}},	//   _ichl, --, --, --, 
   {{0x7a2c03b2,0x00000000,0x00000000,0x00000000}},	//   _nøtr, --, --, --, 
   {{0xaae49fcb,0x6aa00076,0x1b180121,0x00000000}},	//   نسوو, _cumf, яжды_, --, 
   {{0x683c20ef,0x6aa1d595,0x9964084c,0xd1f00092}},	//   _réda, _dumf, нӂел, ልቆቹ_, 
   {{0x7a2c2c95,0x1bd5395a,0x683dd596,0x00000000}},	//   _søts, _повя, _séda, --, 
   {{0x683dd597,0xda0800aa,0xb90435e8,0xd7040276}},	//   _péda, _ډيره_, _बम_, езии, 
   {{0x61e5d598,0x7a2c0b1a,0x6b75d599,0xdb240248}},	//   _ochl, _døtr, _алту, _àpàl, 
   {{0xab847ccf,0xf77007d6,0x764400e5,0x00000000}},	//   _руск, _یاش_, بیتِ_, --, 
   {{0x683c00f2,0x261000e1,0xbf18000d,0x00000000}},	//   _wéda, _तफरी_, नमुन_, --, 
   {{0x93452217,0x61e5d59a,0x6aa0011f,0x580407d2}},	//   енме, _achl, _yumf, _سوتك, 
   {{0x2bd00574,0x1634084c,0x03d401d3,0xdd30012d}},	//   हणता, _педя, رگٹڈ_, nęła, 
   {{0xc75400d9,0x00000000,0x00000000,0x00000000}},	//   _אינץ_, --, --, --, 
   {{0x4638008f,0x49109f23,0x62480419,0x00000000}},	//   _מעסע, थियो_, ežos, --, 
   {{0x24580022,0x2ff80066,0x00000000,0x00000000}},	//   tũme_, بورگ_, --, --, 
   {{0x862011fc,0xf1d8012c,0x09c80011,0x8e8427a8}},	// [349a0] _شکیل, _भएपन, ল্টা, егае, 
   {{0x2d9c6ab9,0x6aa1d59b,0x3ed001d5,0x245800c7}},	//   øve_, _rumf, اقلر, rũme_, 
   {{0x6aa1d59c,0x41b80375,0x7174313e,0x245800e4}},	//   _sumf, _מציע, _شۇرا, sũme_, 
   {{0x8ac400a7,0x61e4013a,0x00000000,0x00000000}},	//   ейдж, _zchl, --, --, 
   {{0x4dd400d4,0x00000000,0x00000000,0x00000000}},	//   _півф, --, --, --, 
   {{0x683c0332,0x0904ac62,0x00000000,0x00000000}},	//   _cédn, ечим, --, --, 
   {{0x645dd59d,0xc7c408bf,0x4a7401e0,0x5d740798}},	//   érik, нспи, мыҫт, _аутф, 
   {{0x6aa00134,0xc7c569e7,0xd90c036b,0x35b001ec}},	//   _tumf, хски, غین_, ңбыр, 
   {{0xfbc400b2,0x5fa400bc,0x00000000,0x00000000}},	//   _سڀني_, गुटल, --, --, 
   {{0xda6c00b2,0xfaa0013e,0x46a40107,0x60c800de}},	//   _وڏو_, _сафо, _ҷадв, ņemi, 
   {{0x06dc000e,0x00000000,0x00000000,0x00000000}},	//   _বৈশি, --, --, --, 
   {{0x46a5d59e,0x00000000,0x00000000,0x00000000}},	//   _задв, --, --, --, 
   {{0x683c6ede,0xb6d00035,0x6704014b,0x00000000}},	//   _hédo, _مقنع, _рӯйб, --, 
   {{0x6844010b,0xf20414a3,0x00000000,0x00000000}},	//   _янҗа, лясо, --, --, 
   {{0x7a2c05ac,0x3168041b,0xca440150,0xd04c06be}},	//   _møtp, ешто_, _ﺘﺒﺤ_, lubə, 
   {{0x683c2a78,0xaf34f968,0x44e80165,0x7578011a}},	//   _médo, گرفت, mù_, _מטופ, 
   {{0x63add59f,0x5f94035b,0x24883a09,0x3eac0036}},	// [349b0] _ifan, тиат, _iham_, ëgt_, 
   {{0x44e80ad3,0xa3d80e49,0x61e41ffc,0xa30c03ce}},	//   où_, ालक_, _uchl, िटीज_, 
   {{0x2488138f,0xf65000c8,0x1fb801c0,0xa1940a5b}},	//   _kham_, נצע_, _олны_, _јанч, 
   {{0x44e8030a,0xac74030f,0x9b5800ee,0x9f4801e7}},	//   iù_, هانش, миет_, lfaí_, 
   {{0x63add5a0,0x2488f632,0x9f4800ae,0x00000000}},	//   _mfan, _mham_, ofaí_, --, 
   {{0x9f48007b,0x683c0129,0x00000000,0x00000000}},	//   nfaí_, _bédo, --, --, 
   {{0x1868adf4,0x24880109,0xecf80111,0xed58007b}},	//   маки_, _oham_, _перш_, _كشفت_, 
   {{0xac94005e,0x248801fb,0x683c004a,0x44e80165}},	//   _басш, _nham_, _dédo, dù_, 
   {{0xdccc0150,0xc6c000f7,0x38a00790,0x1dc402e5}},	//   _ءﯗﻧﻰ_, айык, _kırk_, _लजात, 
   {{0x24880882,0x99840311,0x7c800023,0x00000000}},	//   _aham_, _colţ_, _ይባሃል_, --, 
   {{0x5588f525,0xd469d5a1,0x9f4800c6,0xbe08015b}},	//   ьбом_, дине_, dfaí_, রাপদ_, 
   {{0x2489d5a2,0xd6d4004e,0xd2f801c6,0xdb2401e1}},	//   _cham_, _ажды, мэгч_, _òpóm, 
   {{0x99840618,0x248807c8,0x63ac0036,0xdb08002e}},	//   _malō_, _dham_, _dfan, _keeñ, 
   {{0x63ac1373,0x2d9c01a2,0x44e80622,0x99840421}},	//   _efan, ľvek_, bù_, _lalō_, 
   {{0x63ac03cb,0x00000000,0x00000000,0x00000000}},	//   _ffan, --, --, --, 
   {{0x63a9d5a3,0x24880477,0x62980066,0x4ad00ebb}},	//   ñent, _gham_, _èwon, _सिलव, 
   {{0x59d00490,0xbea01214,0xc474011a,0x8e080798}},	// [349c0] सणार, иатк, _שתפו_, мнав_, 
   {{0xdb0800e8,0xae1c000d,0x9f4800ae,0x00000000}},	//   _neeñ, नाइन_, cfaí_, --, 
   {{0xc120052f,0xa1840150,0x00000000,0x00000000}},	//   _күрһ, _бұра_, --, --, 
   {{0xef94aeda,0x683c003e,0xdb1800b0,0x7a2c143a}},	//   _میزد, _rédo, kawä, _søtp, 
   {{0x63a80024,0x44e80165,0x00000000,0x00000000}},	//   ženg, zù_, --, --, 
   {{0x6f04015c,0x683c6c80,0x00000000,0x00000000}},	//   mwic, _pédo, --, --, 
   {{0x1cc04933,0x99840421,0x63a0033f,0x2ee001a4}},	//   _གསར_, _falō_, ślni, luif_, 
   {{0x3c9002dd,0x00000000,0x00000000,0x00000000}},	//   _ﺑﺎﺳﻰ_, --, --, --, 
   {{0xc0500302,0x6f05d5a4,0xdb081574,0x683c00f2}},	//   יזה_, nwic, _feeñ, _wédo, 
   {{0x63ac084c,0x614800e8,0xff5c003a,0x29140014}},	//   _sfan, _jëlé, _heîc_, _مہتھ_, 
   {{0x63ac1aa1,0x6f04aa0e,0x2489d5a5,0x2ee00d27}},	//   _pfan, hwic, _pham_, huif_, 
   {{0x6f05d5a6,0x5fe097ad,0x2ee005e4,0x44e808e7}},	//   kwic, _फाइल, kuif_, rù_, 
   {{0x2ee006af,0xf7400a0e,0x864402e8,0x9f480332}},	//   juif_, _кецо, _индж, tfaí_, 
   {{0x7df0038e,0x6f05d5a7,0x24880204,0x2ee00549}},	//   _měsí, dwic, _wham_, duif_, 
   {{0x2489d5a8,0xdfd45a19,0x6f040034,0x9f48007b}},	//   _tham_, ловы, ewic, rfaí_, 
   {{0x63add5a9,0x23680070,0x2488009a,0x44cdb0e0}},	//   _ufan, _txaj_, _uham_, mę_, 
   {{0x44cc6b82,0x62340fc0,0x9d55d5aa,0xd5840133}},	// [349d0] lę_, _бепу, گنات, _لێیه_, 
   {{0x7c800020,0x41b406ff,0x41a40037,0x44280427}},	//   _ይባላል_, _अभिस, _खलिस, ljc_, 
   {{0x44cdd5ab,0x723400c6,0x6f040067,0x661c007c}},	//   nę_, _خريط, awic, örky, 
   {{0x1c1c547d,0x6f05d5ac,0x44280427,0xae1c302b}},	//   फाइल_, bwic, njc_, नाउन_, 
   {{0x6f04014b,0x41a4375c,0xdb080de2,0xaed400fd}},	//   cwic, _खलास, _peeñ, _кояш, 
   {{0x44cc6b82,0xeab000e3,0x3e6c0b70,0x7df001ef}},	//   kę_, زعه_, hütz_, _děsí, 
   {{0x44cc068f,0x7e640113,0x7d44001f,0x99840427}},	//   ję_, _ijjp, ቨርሲቲ, _bolš_, 
   {{0xd7082e3f,0x44cd3dd3,0x420c00cd,0x00000000}},	//   ение_, dę_, ायुः_, --, 
   {{0x4b4c0521,0xab940212,0x00000000,0x00000000}},	//   nụlọ_, _виті, --, --, 
   {{0x7c28007c,0x44cc0210,0xa2b800cd,0x00000000}},	//   ljgr, fę_, ्ठन्, --, 
   {{0x44cd3dd3,0x1cc0025c,0x6f05d5ad,0x00000000}},	//   gę_, _གསས_, zwic, --, 
   {{0xdb1801c7,0x7c280010,0x7af80200,0x8c4406be}},	//   pawä, njgr, _kput, _pişə, 
   {{0xdb1c0166,0x00000000,0x00000000,0x00000000}},	//   _äzäy, --, --, --, 
   {{0x387dd5ae,0x7af9d5af,0x8cc40490,0x44ccfea4}},	//   llur_, _mput, ाठमो, bę_, 
   {{0x44cc068f,0x3ebc025c,0xc5f0011a,0x00000000}},	//   cę_, _ħuta_, _הדו_, --, 
   {{0x6f040639,0x7af9d5b0,0x320c0122,0x1fb53495}},	//   twic, _oput, ždy_, исур, 
   {{0x6f04000f,0x645c004e,0xb8cc0327,0x387c0413}},	// [349e0] uwic, èrie, _ྐང_, ilur_, 
   {{0x387c0649,0xfde40228,0x1c1805d7,0x2ee0017a}},	//   hlur_, лдук_, _नोबल_, ruif_, 
   {{0x7af9d5b1,0xf76416cb,0x63a8a3f3,0x4ac406ab}},	//   _aput, _ڇا_, žene, रीनव, 
   {{0xf765d5b2,0x0b442dc1,0x8b68422d,0xbf9800e4}},	//   _ها_, лнен, ниев_, _raêv, 
   {{0x60c80029,0x44cdb0e0,0x98b80055,0x00000000}},	//   ņemt, zę_, _āsā_, --, 
   {{0xad8400d1,0x00000000,0x00000000,0x00000000}},	//   _نازۇ, --, --, --, 
   {{0x7af9d5b3,0x387dd5b4,0xc278010f,0x9e702d40}},	//   _eput, flur_, ערצי, _بۇلت, 
   {{0x387c05a4,0x44cc0006,0x76400209,0x00000000}},	//   glur_, vę_, _alny, --, 
   {{0x1cc008ea,0x44cc0034,0x00000000,0x00000000}},	//   _གསོ_, wę_, --, --, 
   {{0x44ccd5fb,0xa5f80114,0xca7401af,0x00000000}},	//   tę_, њену_, _субы, --, 
   {{0x387c5001,0xf67001c0,0xbb50037e,0xc6a400d1}},	//   blur_, сгээ, mbaの_, _өрли, 
   {{0x44cc3920,0x764001d3,0x07a47549,0xa4e40073}},	//   rę_, _elny, _садн, _कमीच_, 
   {{0x44cd2a2e,0x6d5800d7,0xf87001c8,0x00000000}},	//   sę_, úvaj, _اهنج, --, 
   {{0x6595d5b5,0x44cd2eb5,0x44280175,0x2a6000ae}},	//   _калу, pę_, sjc_, éibh_, 
   {{0x8fb000b4,0x1cc0031c,0x1fc40107,0xa1942afd}},	//   _ọnọd, _གསེ_, ираҳ, равч, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf3f00597,0x147801ed,0x645c0e33,0x00000000}},	// [349f0] _رأي_, _ججوں_, ériu, --, 
   {{0xb7c00356,0x00000000,0x00000000,0x00000000}},	//   ăţio, --, --, --, 
   {{0x7af9d5b6,0x683c01d3,0xef1000f1,0x387c0413}},	//   _sput, _védj, يټې_, ylur_, 
   {{0xac94013e,0x60c800e2,0x63a801e4,0x5c740395}},	//   бахш, ņems, ɾenc, шлет, 
   {{0xc75800de,0x00000000,0x00000000,0x00000000}},	//   _šūnā, --, --, --, 
   {{0xc4c4027d,0x00000000,0x00000000,0x00000000}},	//   _وْ_, --, --, --, 
   {{0x63bc0280,0x32380375,0xd9443412,0xd8240212}},	//   kbsn, רטון_, рейи, идки, 
   {{0x9f48030a,0x00000000,0x00000000,0x00000000}},	//   leañ_, --, --, --, 
   {{0x7bc9d5b7,0x7af804b9,0xeab08fcb,0x683c0214}},	//   magu, _uput, _فعل_, _médh, 
   {{0x7bc9d5b8,0x387c09f3,0x9f480086,0xc68c009f}},	//   lagu, slur_, neañ_, وِي_, 
   {{0xc04c0882,0x9424af44,0x00000000,0x00000000}},	//   ṣṭa_, амне, --, --, 
   {{0x66240150,0x00000000,0x00000000,0x00000000}},	//   _ۇرىك, --, --, --, 
   {{0xaca4063f,0xb4040032,0x00000000,0x00000000}},	//   mmụt, _һүнд, --, --, 
   {{0x7bc9d5b9,0x52740137,0x20480023,0xa774030d}},	//   hagu, руму, _መለለይ, _улчч, 
   {{0x645c00f7,0x683c020c,0x7e7403ac,0x2d840150}},	//   èric, _bédh, doxp, _ﺩﺍﻋﻰ_, 
   {{0x7bc9d5ba,0x645dd5bb,0x00000000,0x00000000}},	//   jagu, érit, --, --, 
   {{0x7bc9d5bc,0x63a8151c,0x45000135,0x1cc0025c}},	// [34a00] dagu, ženc, _མགོར_, _གསུ_, 
   {{0x68fc0036,0x7e200640,0xd17435c7,0x7bc8005c}},	//   _ärdg, одуж, _вымы, eagu, 
   {{0x61e00077,0xcd040e1d,0x8c94d5d9,0x00000000}},	//   ólle, рпей, арді, --, 
   {{0x683c020c,0x7dd00139,0x00000000,0x00000000}},	//   _gédh, _añsı, --, --, 
   {{0x8a056409,0xc5fc11ba,0x7e74010a,0x0eb89c3a}},	//   изде, ্ঞতা_, boxp, _шуны_, 
   {{0x7bc8013c,0x273c01e1,0x768c03cd,0x433800df}},	//   aagu, _lánú_, løyf, כענב, 
   {{0xda64c903,0x683c026c,0x2b401154,0x93e405f9}},	//   حاني, _hédi, šic_, _कांच_, 
   {{0x7bc9d5bd,0x291801d3,0x2c7c0419,0x00000000}},	//   cagu, _áram_, tídu_, --, 
   {{0x09e4b794,0xbb401c41,0x3b040139,0x8ca8012d}},	//   _возн, _детк, _кето_, _जूतो, 
   {{0x77940137,0x00000000,0x00000000,0x00000000}},	//   шкыр_, --, --, --, 
   {{0x69c9d5be,0x273c6b3c,0x480402bf,0xf64d6546}},	//   _iede, _bánú_, _впев, بئي_, 
   {{0x69c92941,0x290c778b,0x38a00139,0x00000000}},	//   _hede, _isda_, _cıru_, --, 
   {{0x69c9d5bf,0xc6680228,0x683c87ef,0x0524015b}},	//   _kede, _ишке_, _rédh, মনের_, 
   {{0x69c9d5c0,0x224405a4,0x7bc9d5c1,0x290c0066}},	//   _jede, ólk_, zagu, _ksda_, 
   {{0x69c9d5c2,0x645c0231,0x7bc9d5c3,0x24185aba}},	//   _mede, éris, yagu, _бойы_, 
   {{0x69c9d5c4,0x7bc9d5c5,0x683c73a0,0x7598011a}},	//   _lede, xagu, _bédi, _בסוג, 
   {{0x69c9d5c6,0x7bc9d5c7,0x9df82dbf,0xc2e401b9}},	// [34a10] _oede, vagu, лнат_, _тўйи, 
   {{0x683dd5c8,0x7bc84a13,0x91ec1715,0x290c65e7}},	//   _dédi, wagu, _जायज_, _osda_, 
   {{0x7bc9d5c9,0x645c01e7,0x9f480156,0x1af000cc}},	//   tagu, oisi, reañ_, চিছে_, 
   {{0x645dd5ca,0xad243ee0,0x69c9d5cb,0x629401f5}},	//   nisi, تىمى, _aede, lmzo, 
   {{0x7bc803a5,0x290dd5cc,0x645c0037,0x629401f5}},	//   ragu, _asda_, iisi, omzo, 
   {{0x6294007f,0xde580064,0x00000000,0x00000000}},	//   nmzo, _сагі_, --, --, 
   {{0x645dd5cd,0x69c9d5ce,0x98545026,0x768c0158}},	//   kisi, _dede, йтиш, løyg, 
   {{0x645dd5cf,0xb8fc0303,0x69c9d5d0,0xccf00302}},	//   jisi, _ति_, _eede, _מכל_, 
   {{0x6b8000b5,0x9d440220,0x290c01d5,0xe7f8033f}},	//   _gymg, _теңд, _esda_, ्ज़ा_, 
   {{0xba740075,0x9f58180f,0x645c0108,0x4644009d}},	//   _ئارت, _hasó_, eisi, йзын_, 
   {{0x38a00205,0xc1c801ec,0x58a400fe,0x00000000}},	//   _cırt_, _ﺑﯘﺯﺍ, _গৌৰী, --, 
   {{0x645dd5d1,0x6d5800e4,0x00000000,0x00000000}},	//   gisi, úvai, --, --, 
   {{0x69c9d5d2,0x9f581cd7,0x451c031c,0x8c18025d}},	//   _yede, _casü_, ེའུར_, אורי, 
   {{0xe6b404a2,0x645dd5d3,0x683c20ef,0x69c801c0}},	//   _بلوگ, aisi, _rédi, _xede, 
   {{0x63a80e04,0x683c73a0,0x768c003b,0x38a00139}},	//   žena, _sédi, tøyf, _tıru_, 
   {{0x645c3344,0x683cf85a,0x629401a4,0x823434b1}},	//   cisi, _pédi, amzo, _ۇرپا, 
   {{0x91e5d5d4,0x50640184,0x527400ee,0x768c2d8b}},	// [34a20] _лопе, атҡа, _гуну, røyf, 
   {{0x60c402d0,0x768c0158,0xdbf001ef,0x683c00e5}},	//   _fwhm, søyf, _dřík, _védi, 
   {{0x9f580789,0x4b4c063f,0x00000000,0x00000000}},	//   _basó_, pụkọ_, --, --, 
   {{0x9f5809c2,0x683c0798,0x768c0158,0x2ca000c5}},	//   _casó_, _tédi, bøyg, öid_, 
   {{0x7ff5d5d5,0x69c9d5d6,0x290c0042,0x00000000}},	//   _اسپا, _pede, _ssda_, --, 
   {{0x291801ed,0x290c020b,0x69c9d5d7,0xae4401d3}},	//   _árak_, _psda_, _qede, _بھرو, 
   {{0x69c9d5d8,0x645dd5d9,0xfce035cb,0x9f58007f}},	//   _vede, yisi, _норо, _absè_, 
   {{0x645dd5da,0x768c1445,0xbc604c6b,0x00000000}},	//   xisi, høyd, _евск, --, 
   {{0x69c9d5db,0x2ee000a9,0x2fc0113c,0x0b440a27}},	//   _tede, nrif_, ibig_, _унан, 
   {{0x645dd5dc,0x38a00205,0xa2b800cd,0xb9900271}},	//   wisi, _pırt_, ्ठस्, _کلمب, 
   {{0xbeb804e6,0x768c00cc,0x2ee1d5dd,0x290c4c28}},	//   _grëf, døyd, hrif_, _usda_, 
   {{0x2ee1d5de,0x645dd5df,0x487400cf,0x0b8c0023}},	//   krif_, uisi, _ادئس, _ዝሓድር_, 
   {{0x645dd5e0,0x68fc01c7,0xf8b400db,0xde6c0051}},	//   ériq, _ärdb, _көө_, hươn, 
   {{0x2ee1d5e1,0x2fc00e78,0x38a00205,0x00000000}},	//   drif_, ebig_, _tırt_, --, 
   {{0x3658011a,0x941006be,0x00000000,0x00000000}},	//   _תכונ, _liyə_, --, --, 
   {{0x2ee000a9,0xdbf00316,0x645dd5e2,0x768c03cd}},	//   frif_, _přík, qisi, tøyg, 
   {{0x1cc00ed9,0x941003be,0x2ee00368,0xbda4007b}},	// [34a30] _གསང_, _niyə_, grif_, محاو, 
   {{0x9f5801e1,0x768c0158,0xdb200124,0x00000000}},	//   _basò_, røyg, _êtév, --, 
   {{0x9f58204e,0x7c84220f,0xe0d00014,0x2fc1d5e3}},	//   _pasó_, буде, _تٲج_, bbig_, 
   {{0xbeb802d3,0x202000f1,0xdbf00118,0x91a40208}},	//   _rrëf, _تېرې, _třík, _đỏ_, 
   {{0x2ee0067c,0x768c003b,0x00000000,0x00000000}},	//   crif_, løye, --, --, 
   {{0x6bd41823,0x683c246d,0x941006be,0x00000000}},	//   قتۇر, _médu, _diyə_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xeaf97ea9,0x00000000,0x00000000,0x00000000}},	//   _گرفت_, --, --, --, 
   {{0xac940220,0x768c03cd,0x6c3000e5,0x96a800d8}},	//   _хатш, høye, _سہوا, јкоб_, 
   {{0x19592a01,0xbeb804e6,0x768c03cd,0xeb38030d}},	//   _казы_, _trëf, køye, _узуш_, 
   {{0x2fc0010a,0x24b801d5,0x00000000,0x00000000}},	//   ybig_, ینیگ_, --, --, 
   {{0x683c003e,0x3ea0002d,0x768c0158,0x672402f0}},	//   _bédu, _lijt_, døye, _šije, 
   {{0xd628d442,0xf7712f7a,0x15b8004e,0x00000000}},	//   _воле_, _عاص_, _кыйы_, --, 
   {{0x683c07ea,0xb9e002d3,0x53640023,0x10a40212}},	//   _dédu, _የን_, _ትኸይድ_, живн, 
   {{0x2bcc1d2e,0x3ea87636,0x2fc1d5e4,0x768dd5e5}},	//   ारमा, _auct_, tbig_, røyd, 
   {{0x2fc0002f,0x52a800f3,0x00000000,0x00000000}},	//   ubig_, _квим_, --, --, 
   {{0x32d80014,0x3ea1cade,0x2fc1d5e6,0xb00400dc}},	// [34a40] _ادبک_, _bijt_, rbig_, _niḥs, 
   {{0x768d63de,0xde6c004d,0x3ea80afa,0xaff801d3}},	//   løyb, tươn, _duct_, _گہرا_, 
   {{0x8fa5d5e7,0x4fa40a93,0x601000e4,0x3ea00200}},	//   _мане, _минв, _ẽmei, _dijt_, 
   {{0x768c0158,0x2918ea5b,0x00000000,0x00000000}},	//   nøyb, _ĩra_, --, --, 
   {{0x2bcc012c,0xbeb80200,0x00000000,0x00000000}},	//   ारबा, _rrëg, --, --, 
   {{0x6ce401ec,0x41bc2e35,0x7d0c01f4,0x00000000}},	//   _ىززە, ्रयस, äisä, --, 
   {{0x8c44b1c2,0xbea002d5,0xdb2000e4,0xad848e98}},	//   _деве, _царк, _êtîv, _راسۇ, 
   {{0x3ea001a4,0x00000000,0x00000000,0x00000000}},	//   _zijt_, --, --, --, 
   {{0x46691e06,0x7c2c0ba1,0x41bc102f,0xf6e001c6}},	//   иром_, _òcra, ्रमस, мцэн, 
   {{0x683c0231,0x2ca4002d,0xf76c00aa,0x38c80014}},	//   _rédu, _himd_, ځای_, _چانی_, 
   {{0x2919d5e8,0x683c07ea,0x38c9d5e9,0xf76c0214}},	//   _éra_, _sédu, _نانی_, فای_, 
   {{0xd938010b,0x872400e5,0x657000dc,0x00000000}},	//   _учуш_, _وٹام, _ādhā, --, 
   {{0xfbd0025f,0x4910012c,0xd2b402dd,0xd5b80137}},	//   ותר_, थिको_, пқыш_, шсө_, 
   {{0x768c168c,0x10a00131,0x04a8030d,0x00000000}},	//   tøye, _ﺋﺎﺭﯨ, _къий_, --, 
   {{0x6608058a,0x572400db,0xe2980124,0x00000000}},	//   medk, _ورۇق, иаҭ_, --, 
   {{0x6609d5ea,0x768dd5eb,0x00000000,0x00000000}},	//   ledk, røye, --, --, 
   {{0x768c003b,0xcca800d1,0x6f8801d9,0x00000000}},	// [34a50] søye, ەنمۇ_, ۅنہِ_, --, 
   {{0x9e1402d5,0x6609d5ec,0x00000000,0x00000000}},	//   ядзі, nedk, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3ea001f5,0x00000000,0x00000000,0x00000000}},	//   _wijt_, --, --, --, 
   {{0x5e600075,0x20085423,0x8bd001d5,0x6609d5ed}},	//   _كۆرە, meai_, رقوش, kedk, 
   {{0xe9a8049e,0x20080b23,0x66080010,0x2e4401d3}},	//   يدىن_, leai_, jedk, _قہقہ, 
   {{0x6609d5ee,0x6d580332,0x7ae401e2,0x00000000}},	//   dedk, úvat, _ژورې_, --, 
   {{0x2009d5ef,0x2bcc412f,0x00000000,0x00000000}},	//   neai_, ारणा, --, --, 
   {{0x92e40882,0xbeb80036,0x7bd80393,0xa91c0419}},	//   _gṛhī, _frëe, _iduu, _vyľa, 
   {{0x6608020c,0xc8940014,0x00000000,0x00000000}},	//   gedk, _ہانژ, --, --, 
   {{0x2009d5f0,0x3b1c031c,0xfbcc00c5,0x43c00131}},	//   keai_, _hruq_, _हजाम, ﯩﻨﯩﺪ, 
   {{0xd468180b,0x68fc00a2,0x00000000,0x00000000}},	//   симе_, _ärda, --, --, 
   {{0x1fd0045e,0x2009caad,0x6608030a,0x768c0217}},	//   িলাস, deai_, bedk, røyb, 
   {{0x47180a1e,0xd010006c,0xfbd800dc,0x66080427}},	//   _לונג, کلر_, मृतम, cedk, 
   {{0x7bd80ba7,0x20080607,0x46100592,0x00000000}},	//   _oduu, feai_, _سوير, --, 
   {{0x7bd9d5f1,0x15440131,0x00000000,0x00000000}},	//   _nduu, _меһм, --, --, 
   {{0x1cc00489,0xd54800f1,0x00000000,0x00000000}},	// [34a60] _གསཔ_, _خلګو_, --, --, 
   {{0x33200227,0x7bd9d5f2,0x4fc00137,0x00000000}},	//   _irix_, _aduu, بەڭە, --, 
   {{0x3b1c02d1,0xfe406135,0x82380375,0xd0084e73}},	//   _aruq_, энфо, _העיצ, _лене_, 
   {{0xe4780125,0x20080311,0xd6d8033f,0xdb18012d}},	//   _ኩባንያ_, ceai_, zyła_, jawó, 
   {{0x7bd81418,0xbb41d5f3,0xae740131,0x00000000}},	//   _dduu, нецк, _قۇرغ, --, 
   {{0xbc6404a9,0x7bd94eed,0x82d400c8,0xbae0104b}},	//   يمەن_, _eduu, לונג_, ركىي, 
   {{0x6609d5f4,0xd1cc001f,0x2bcc2432,0x3ebc025c}},	//   vedk, _እናት_, ारदा, _ħuti_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x645c0066,0x09e401d5,0x6608df5f,0x9f4800e5}},	//   èrim, _ноан, tedk, őhöz_, 
   {{0x9410013f,0x683c06af,0xd1cc0092,0x3f8c035b}},	//   _tiyɛ_, _cédr, _እናቴ_, ýgui_, 
   {{0x1cc00003,0x32180204,0x6608efce,0x683c0129}},	//   _གསབ_, ddry_, redk, _dédr, 
   {{0x3321d5f5,0x6609481c,0x4dd00154,0xd6d8012d}},	//   _brix_, sedk, ালিং, syła_, 
   {{0x20080b23,0x6608007c,0x61e000e4,0x00000000}},	//   veai_, pedk, óllo, --, 
   {{0x9f5800e4,0xa19401c6,0xb6a001a9,0x60d400e5}},	//   _kasö_, дагч, _зичл, tszm, 
   {{0x3630fd61,0x2009bcb7,0xdb1802e2,0x3de085cf}},	//   _سروس, teai_, nawò, ন্ডল, 
   {{0x32100134,0x768c0158,0x30340108,0x00000000}},	//   _ɔnyɛ_, møya, несё, --, 
   {{0x644dd5f6,0x3e0407d8,0x768c0158,0x623400db}},	// [34a70] _ilai, зяев, løya, _жепу, 
   {{0x644c0211,0x44383959,0x3f840f40,0x20080b23}},	//   _hlai, _hoq_, ānu_, seai_, 
   {{0x4439d5f7,0x644dd5f8,0xbeb801c7,0x20080a8b}},	//   _koq_, _klai, _brëc, peai_, 
   {{0xc0a96c44,0x44380978,0xdeb401f4,0x7c84011c}},	//   _پاگل_, _joq_, _обмы, чузе, 
   {{0x4439d5f9,0xbeb804e6,0x644dd5fa,0x3a240166}},	//   _moq_, _drëc, _mlai, зелү_, 
   {{0x44380978,0x644c0368,0x41bc21b8,0x4c8001d5}},	//   _loq_, _llai, ्रिस, _ییلق, 
   {{0x644dd5fb,0xe9d0721b,0xbeb80036,0xad4400cf}},	//   _olai, اغه_, _frëc, _كۉكۉ, 
   {{0xccf004ae,0x768c05ac,0x644c01ab,0x44382ca7}},	//   _שכן_, døya, _nlai, _noq_, 
   {{0x41bc243c,0x3b1c022e,0x1c1807f7,0xd7600133}},	//   ्रास, _uruq_, _नोएल_, خۆشی, 
   {{0x7c39d5fc,0x644dd5fd,0x7ae8079b,0xbeb801c7}},	//   _hour, _alai, mugt, _zrëc, 
   {{0x7c39d5fe,0x644dd5ff,0x4438016d,0x7ae85363}},	//   _kour, _blai, _boq_, lugt, 
   {{0x33202047,0x4439d600,0x1cc00867,0x7c39d601}},	//   _prix_, _coq_, _གསན_, _jour, 
   {{0x7c380d29,0x7ae8b4bf,0x4439d602,0x644c0036}},	//   _mour, nugt, _doq_, _dlai, 
   {{0x32180198,0x387dd603,0x00000000,0x00000000}},	//   udry_, lour_, --, --, 
   {{0x32180af9,0x644c25a5,0x7ae803f2,0x92e40055}},	//   rdry_, _flai, hugt, _nṛvī, 
   {{0x44380007,0x3321d604,0xdb180784,0x09b82ce6}},	//   _goq_, _trix_, hawñ, _उभ्य, 
   {{0x33200fac,0x2bcc06ff,0xa0740022,0x00000000}},	// [34a80] _urix_, ारसा, хырш, --, 
   {{0x7ae9d605,0x387d1ceb,0x7c38fa55,0x644c0208}},	//   dugt, hour_, _aour, _zlai, 
   {{0x387dd606,0x4438100f,0x7c39d607,0xa32401d9}},	//   kour_, _yoq_, _bour, _قریٖ, 
   {{0x7c38fb21,0x387dd608,0x4438011f,0xfbc005d9}},	//   _cour, jour_, _xoq_, پيوٽ, 
   {{0x7c39d609,0x387dd60a,0x00000000,0x00000000}},	//   _dour, dour_, --, --, 
   {{0xf6449fb1,0xdb180100,0x7a34155b,0x00000000}},	//   _شئ_, tawò, мпір_, --, 
   {{0x7c38ca72,0x7ae80006,0x645c0066,0xf76c0101}},	//   _four, augt, èrik, یاً_, 
   {{0x7c39d60b,0x387dd60c,0x7ae9d60d,0x6e3d3921}},	//   _gour, gour_, bugt, _horb, 
   {{0x63a80ebd,0x644c01ab,0x4439d60e,0x00000000}},	//   ženk, _rlai, _roq_, --, 
   {{0x644dd60f,0x7c382b05,0x2bcc0709,0x6e3dd610}},	//   _slai, _zour, ारवा, _jorb, 
   {{0x6e3dd611,0x387dd612,0x644dd613,0x7c39d614}},	//   _morb, bour_, _plai, _your, 
   {{0x21204c25,0x28141a02,0x9f5800e4,0x644c017a}},	//   _rrhh_, _سوتس, _kasô_, _qlai, 
   {{0x644c04c4,0x6e3c5b5e,0x4438e85f,0x768c00cc}},	//   _vlai, _oorb, _voq_, søya, 
   {{0x6e3dd615,0x6aa836f3,0x2918007b,0x768c05ac}},	//   _norb, _jidf, _áras_, løyn, 
   {{0x6aa9d616,0x644c1ebd,0xefd81b49,0x44388e61}},	//   _midf, _tlai, _ሬድዮ_, _toq_, 
   {{0xd05c01e4,0x66198140,0x644dd617,0x41bc18cc}},	//   _espɾ, _havk, _ulai, ्रहस, 
   {{0x6e3c08ad,0x7c39d618,0x00000000,0x00000000}},	// [34a90] _borb, _rour, --, --, 
   {{0x387dd619,0x7c39d61a,0x3ea584e3,0x63ac0165}},	//   zour_, _sour, önt_, _hgan, 
   {{0x63add61b,0x6e3dd61c,0x7c383046,0xe0d00014}},	//   _kgan, _dorb, _pour, _حٲج_, 
   {{0x7ae93d18,0x661802bf,0x63ac003e,0x7c380165}},	//   tugt, _lavk, _jgan, _qour, 
   {{0x6e3dd61d,0x201800a8,0x63add61e,0x7c380156}},	//   _forb, _iasi_, _mgan, _vour, 
   {{0x2019d61f,0x63ac07d6,0x7ae9d620,0x6aa8003e}},	//   _hasi_, _lgan, rugt, _cidf, 
   {{0x2019d621,0x387dd622,0x63add623,0x7c39d624}},	//   _kasi_, tour_, _ogan, _tour, 
   {{0x63add625,0x6aa803d4,0x7ae80280,0x2019d626}},	//   _ngan, _eidf, pugt, _jasi_, 
   {{0x2019d627,0x62841449,0x387c03bd,0x00000000}},	//   _masi_, _okho, rour_, --, 
   {{0x628556d6,0x387dbcef,0x6aa801c7,0xc0e002d3}},	//   _nkho, sour_, _gidf, ምለስ_, 
   {{0x387dd628,0x2019d629,0x6618151c,0xaaa807f7}},	//   pour_, _oasi_, _davk, _छूटक, 
   {{0x6285d62a,0x63ac00ca,0x00000000,0x00000000}},	//   _akho, _cgan, --, --, 
   {{0x63ac020b,0x29181427,0x55e4009d,0x00000000}},	//   _dgan, _árar_, _золб, --, 
   {{0x63add62b,0x2019d62c,0xe7e8008e,0x00000000}},	//   _egan, _aasi_, _ефәк_, --, 
   {{0x2019d62d,0x62840652,0x24940793,0x6e3c143a}},	//   _basi_, _dkho, äamü_, _rorb, 
   {{0x2019d62e,0x54340d28,0x63aca5e4,0x0f2c0092}},	//   _casi_, _سربر, _ggan, _አመልከ, 
   {{0x628403c1,0xcee80006,0x00000000,0x00000000}},	// [34aa0] _fkho, ядае_, --, --, 
   {{0x66180218,0x6e3dd62f,0x63add630,0xe0d8013e}},	//   _xavk, _qorb, _zgan, явӣ_, 
   {{0x6e3dd631,0x2019d632,0x10a5d633,0x63ac01b9}},	//   _vorb, _fasi_, _пион, _ygan, 
   {{0x2019d634,0x6aa801e3,0x6e3c002f,0x91b81be1}},	//   _gasi_, _sidf, _worb, ्रकै, 
   {{0xfb80013d,0x62840051,0x00000000,0x00000000}},	//   лышн, _ykho, --, --, 
   {{0xfaa001ca,0x2019d635,0x00000000,0x00000000}},	//   гачо, _zasi_, --, --, 
   {{0xa93411ed,0x6aa83a26,0x2019d636,0x63a800d7}},	//   тейш, _vidf, _yasi_, ľeni, 
   {{0x63a85a39,0xbf9805bb,0x66180960,0x00000000}},	//   ženi, _mbên, _savk, --, 
   {{0xd5bc69af,0x63ac006c,0x661816a3,0x6aa82d8b}},	//   ोरंज, _rgan, _pavk, _tidf, 
   {{0x63ad7af9,0x768c03cd,0x6aa8127b,0x49b8007b}},	//   _sgan, søyn, _uidf, _رائد_, 
   {{0x63ac022e,0x98c400c0,0x00000000,0x00000000}},	//   _pgan, _асіл, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2018102c,0x823407a7,0x63ac020b,0x752001c7}},	//   _rasi_, ىرسا, _vgan, _ernz, 
   {{0x2019d637,0x1ca80156,0xbeb9b651,0x6618143a}},	//   _sasi_, བམོ_, _brën, _uavk, 
   {{0x2019d638,0xdfd445b3,0x63ac9b2d,0x9f4800c6}},	//   _pasi_, ковы, _tgan, rgaí_, 
   {{0x63adc69c,0x2019d639,0xbeb80221,0x00000000}},	//   _ugan, _qasi_, _drën, --, 
   {{0x02a49808,0x2019d63a,0x747c008d,0xbeb80a40}},	// [34ab0] _пром, _vasi_, _מנהג, _erën, 
   {{0xbeb8092e,0x62846985,0x2019d63b,0xf2d4010f}},	//   _frën, _ukho, _wasi_, _געץ_, 
   {{0x20182f06,0xbeb80a40,0xc1bc1a22,0x00000000}},	//   _tasi_, _grën, ्रीग, --, 
   {{0x2019d63c,0x92e40882,0xd6d8012d,0x00000000}},	//   _uasi_, _tṛtī, ysł_, --, 
   {{0xac741537,0x7de400d6,0xeab80220,0xdb1003e3}},	//   دالش, _півд, ейі_, _üfüq, 
   {{0x09e00798,0x00000000,0x00000000,0x00000000}},	//   аошн, --, --, --, 
   {{0xf1b40a1e,0x00000000,0x00000000,0x00000000}},	//   נסק_, --, --, --, 
   {{0xa54c0598,0x387001ec,0x58240166,0x63a00210}},	//   _şuşı_, ықет, тмиб, ślny, 
   {{0x973405f5,0xe6d401c0,0x768c03cd,0x6820012d}},	//   тэйч, лцээ, bøyl, _sądó, 
   {{0x1a6400e5,0x00000000,0x00000000,0x00000000}},	//   _جیتی_, --, --, --, 
   {{0x57f56acb,0xa80402dd,0xb40401c0,0x981407d5}},	//   _апет, _әзіл, гүйд, _аьлч, 
   {{0xbeb802d3,0xe858013e,0xbb2c02dd,0x00000000}},	//   _rrën, _пахш_, _ﺨﻠﻕ_, --, 
   {{0x768c00cc,0x27c001e0,0x52bc0406,0x00000000}},	//   løym, _уҡым, ्ठेस, --, 
   {{0xbeb804e6,0x95840354,0x998400c0,0x00000000}},	//   _prën, _илле, _uolų_, --, 
   {{0x016122d4,0x9494022e,0x00000000,0x00000000}},	//   акро, _ишич, --, --, 
   {{0x7af8013c,0xd838003e,0x70340023,0x00000000}},	//   _oqut, njō_, _ኣረዲኦ, --, 
   {{0x59d0033d,0x3f640c17,0x645c01f5,0x2c7c0419}},	// [34ac0] हरार, вито_, ërie, cídy_, 
   {{0xdcf4a697,0x78a8be7a,0xbeb80240,0x95700092}},	//   _agzı, _ligv, _trën, _ጥራትን_, 
   {{0x7af80eda,0xaaa401e0,0xf0500023,0x00000000}},	//   _aqut, ңгеҙ, _መፈለም, --, 
   {{0x0b44063b,0x8b69d63d,0xd6d8033f,0x7d200014}},	//   кнен, миев_, szły_, جہٲن, 
   {{0x768c143a,0x3b80009d,0x00000000,0x00000000}},	//   tøyl, алцг, --, --, 
   {{0x78a80076,0x0904fe9c,0x3944005c,0x3b51166e}},	//   _aigv, вчим, fyns_, шкір, 
   {{0x78a804e6,0x768c0158,0xbd4001d9,0x00000000}},	//   _bigv, gøym, _پھلى, --, 
   {{0x1cdc031c,0x768c143a,0xc17005d0,0xa81400f3}},	//   _ལྗི_, søyl, יחו_, удиш, 
   {{0x7af8009a,0x09f400a8,0xdc74173d,0x78a9d63e}},	//   _gqut, _ачея, _сырь, _digv, 
   {{0x44cc00bc,0x394401e3,0xbf9800df,0x00000000}},	//   tř_, byns_, ויפש, --, 
   {{0xa3d4085e,0xfaa002a9,0x250801b9,0x00000000}},	//   лонч, _тафо, رردی_, --, 
   {{0x69d9d63f,0x443c05a4,0xbeb80221,0x2c7c00d0}},	//   lave, ðu_, _brël, tídy_, 
   {{0xf365d640,0x57a401af,0x04f000eb,0x00000000}},	//   атрн, _йышҡ, জবের_, --, 
   {{0xdb085fe6,0x62240131,0xa5f800f3,0x00000000}},	//   énég, دىسل, _чеку_, --, 
   {{0xf40803d4,0x0f540092,0x04180154,0x00000000}},	//   ষয়ৰ_, _ለመለየ, ধাবী_, --, 
   {{0xbb2c01ec,0x00000000,0x00000000,0x00000000}},	//   _ﺨﻠﻑ_, --, --, --, 
   {{0x69d9d641,0x24881028,0x672405be,0xbeb80036}},	// [34ad0] kave, _ikam_, _šijj, _grël, 
   {{0x9b9403cc,0x5dd46f04,0x00000000,0x00000000}},	//   ۇلات, اقائ, --, --, 
   {{0x3da402d5,0xa2b80034,0xdcf400ef,0x00000000}},	//   траб, _एंड्, _izzī, --, 
   {{0xcb1c01ad,0x63bc01d3,0x00000000,0x00000000}},	//   पिंड_, ncsn, --, --, 
   {{0x69d9d642,0x2488009a,0x78a80784,0x99840356}},	//   fave, _mkam_, _rigv, _balş_, 
   {{0x69d9d643,0x78a8fcf4,0x61f40399,0x2488022e}},	//   gave, _sigv, ngzl, _lkam_, 
   {{0x2488022e,0x6d34008e,0x63bc02d0,0x1ce800e5}},	//   _okam_, _керф, kcsn, _سکاٹ_, 
   {{0x649c0a40,0x2489d644,0x2241d645,0x768c00fe}},	//   léif, _nkam_, _lohk_, røym, 
   {{0x69d9d646,0x4c804bcf,0x46e41f10,0x7af90991}},	//   bave, _اینق, гдын_, _uqut, 
   {{0x69d9d647,0x24881a51,0x7c800023,0xc68402f2}},	//   cave, _akam_, _ክባሃል_, هێنن_, 
   {{0x0680009d,0x00000000,0x00000000,0x00000000}},	//   сгэн, --, --, --, 
   {{0x649c01c7,0x24880200,0xb4e0012d,0x3b840023}},	//   héif, _ckam_, _फटी_, _ንሓድሽ_, 
   {{0xf748007b,0x00000000,0x00000000,0x00000000}},	//   _تجاه_, --, --, --, 
   {{0x2489d648,0xdb1800d2,0x99e40183,0xa565d649}},	//   _ekam_, gcwé, প্ৰক, ادین, 
   {{0xb4040533,0xc0e1d64a,0xd008084c,0xbeb804e6}},	//   _күнд, йорк, неве_, _drëm, 
   {{0x69d9d64b,0xbeb804e6,0x958401af,0x00000000}},	//   zave, _erëm, _илһе, --, 
   {{0x4e28036b,0x69d9d64c,0x00000000,0x00000000}},	// [34ae0] ноан_, yave, --, --, 
   {{0x2bcc11bc,0x1cdc0003,0xc0c40023,0x69d9d64d}},	//   ार्थ, _ལྗང_, ጽሖም_, xave, 
   {{0x4ce43580,0x6eb0230e,0x63a807f5,0xf15402f2}},	//   ужеб, _अंकु, žent, _ئێزد, 
   {{0x69d87a02,0x6934158b,0x00000000,0x00000000}},	//   wave, یکار, --, --, 
   {{0x8fc40022,0x8e7400d8,0x00000000,0x00000000}},	//   _иаҟҵ, _бувч, --, --, 
   {{0x69d8004e,0x00000000,0x00000000,0x00000000}},	//   uave, --, --, --, 
   {{0x69d871dd,0xb7fc05ac,0x7bc8f17d,0xfbcc000d}},	//   rave, ্যনত_, bbgu, _हड़कम, 
   {{0x69d9d64e,0x7b00022c,0x25a00115,0x649c0221}},	//   save, óvtø, _ŝilo_, méig, 
   {{0xc669d64f,0xc9f40597,0x4bc00032,0x248801d5}},	//   ешне_, _مساع, _көҙг, _rkam_, 
   {{0x2bcc085c,0x69d87a06,0x44240139,0xdb4c0244}},	//   ारका, qave, _şn_, _تێه_, 
   {{0xf76c2ea3,0xbeb802d3,0x2459d650,0x6595d651}},	//   قای_, _rrëm, вань_, рану, 
   {{0xd76404d3,0x87247660,0x22400254,0x363002dd}},	//   انیی, _معتم, _sohk_, _ۇرىس, 
   {{0x6eb09543,0xf64c01ed,0x41e402d5,0x649ce2a5}},	//   _अंगु, زئی_, ліва, héig, 
   {{0x4e040a28,0x290c0a2e,0x36f400d9,0x9f48008e}},	//   स्मै_, _kpda_, _עצום_, lgaç_, 
   {{0x326400a7,0xb30c0327,0x00000000,0x00000000}},	//   стяв, གསུང_, --, --, 
   {{0x248801d5,0x9f481427,0x38a003e3,0x00000000}},	//   _ukam_, ffað_, _qırx_, --, 
   {{0x93f400ac,0x9df80c56,0x2d980841,0xa92c0023}},	// [34af0] şəcə, кнат_, _azre_, ተተባህ, 
   {{0x63a80122,0xdd9400f7,0xa0b800c7,0xdcf400de}},	//   žens, аазы, _игоу_, _uzzī, 
   {{0x9d15d652,0x61e40192,0xa1583967,0x649c3a35}},	//   рдеч, _idhl, _рану_, géig, 
   {{0xf1940014,0x60c402d0,0x768c143a,0x00000000}},	//   _دُپھ, _ithm, tøyk, --, 
   {{0x703c0020,0x649d9d6b,0x64a800b8,0x4bb00032}},	//   _አለባቸ, méid, _aśik, әйәс, 
   {{0xeab0034c,0x649c007b,0x768c143a,0x00000000}},	//   سعه_, léid, røyk, --, 
   {{0x98541f71,0xa3c4068f,0xf990bf4e,0x2bcc4f76}},	//   итиш, एडा_, حبش_, ारखा, 
   {{0x6ca42bbd,0x649c3a35,0xd708005b,0xfbc401d5}},	//   _груж, néid, вние_, _ёғли_, 
   {{0x61e40122,0x7e6400b5,0x4970104e,0x00000000}},	//   _odhl, _kmjp, йләс, --, 
   {{0xe7080491,0x60c5d653,0xb8d809bd,0x16641553}},	//   اتين_, _othm, _অব_, рвом, 
   {{0xa3d000cd,0x00000000,0x00000000,0x00000000}},	//   षरं_, --, --, --, 
   {{0xd469d654,0x61e43e7c,0xe77801d3,0xe894c7c3}},	//   тиме_, _adhl, ئلیں_, _лахь, 
   {{0x60c5d655,0xcc38010f,0xd394013d,0x00000000}},	//   _athm, דערט, шәкә_, --, 
   {{0x2b18000d,0x00000000,0x00000000,0x00000000}},	//   _धनसँ_, --, --, --, 
   {{0x7640009f,0xd01001f7,0x649c00ae,0xc5f0011a}},	//   _iony, يلس_, féid, _ודו_, 
   {{0x672496c0,0x7641d656,0x768c0158,0xcd34030f}},	//   _šiji, _hony, døyi, یراب, 
   {{0x91e473ce,0x0e65519e,0x7641d657,0x25b4007b}},	// [34b00] _копе, акан, _kony, _éalú_, 
   {{0x114800a8,0x625800a3,0x9f4801a8,0x00000000}},	//   _апой_, _rìog, rfað_, --, 
   {{0x7641d658,0x768c05ac,0x649c3226,0x00000000}},	//   _mony, røyh, béid, --, 
   {{0x7641d659,0x649c00ae,0x4b2400d8,0x00000000}},	//   _lony, réig, имев, --, 
   {{0x7640004b,0x9504031c,0x91d8000d,0x987000c0}},	//   _oony, _མཱའི_, _बजाई, _ašį_, 
   {{0x7640bda2,0x649c0221,0x290c05b1,0x768c05ac}},	//   _nony, méie, _ppda_, bøyi, 
   {{0x649c0a40,0xfce09d93,0x2ee00129,0x2d9803b9}},	//   léie, _моро, lsif_, _uzre_, 
   {{0xd90c5929,0x7641d65a,0x2cb800d8,0x4ba4064e}},	//   عین_, _aony, _iurd_, _көлү_, 
   {{0x04f000bd,0x2cb9d65b,0x649c04c4,0xefdc001f}},	//   _জনের_, _hurd_, néie, _ሕንድ_, 
   {{0x7641d65c,0xbaf80375,0xca75d65d,0x671c0037}},	//   _cony, _בהמש, _тубы, _बईठक_, 
   {{0x76400502,0x649c04c4,0x24f98bf4,0x00000000}},	//   _dony, héie, ынны_, --, 
   {{0xe704034c,0x38c801ed,0x2ee0020c,0x649c0221}},	//   _هستی, _شامی_, ksif_, kéie, 
   {{0x2cb81529,0x645c00db,0xa91c00d7,0x649c01e7}},	//   _lurd_, èriq, _vyľu, véid, 
   {{0x649c0a40,0x7641d65e,0x177802d5,0xa92800d0}},	//   déie, _gony, _ёсць_, _guľô, 
   {{0xfbd40154,0x40880063,0x6eb003ce,0x00000000}},	//   _হাসত, вљам_, _अंजु, --, 
   {{0x649c04c4,0x764043c1,0x7f0400d4,0xff041b0a}},	//   féie, _zony, иїзд, иязн, 
   {{0x76416b6d,0x649dd65f,0x00000000,0x00000000}},	// [34b10] _yony, géie, --, --, 
   {{0x2cb9d660,0x61e40117,0x649d232d,0xaae0190c}},	//   _burd_, _udhl, séid, _निजक, 
   {{0x60c5d661,0x2ee05fe6,0x649d9d6b,0x49143174}},	//   _uthm, asif_, péid, _भैलो_, 
   {{0x649c350d,0xad240075,0x768c05ac,0x9b58014b}},	//   béie, غىنى, røyi, лиет_, 
   {{0x2cb80109,0x649c04e6,0x00000000,0x00000000}},	//   _eurd_, céie, --, --, 
   {{0x98e40597,0x768c00fe,0x6e940139,0x7a0400d4}},	//   مكتو, løyv, _мияу, рядж, 
   {{0x1869d662,0x76418d87,0x19880108,0x00000000}},	//   лаки_, _rony, ыбки_, --, 
   {{0x7641d663,0x98700024,0x00000000,0x00000000}},	//   _sony, _všį_, --, --, 
   {{0x7641d664,0x7d00004e,0x2c1c0073,0xe8180073}},	//   _pony, ànsf, _नसतं_, _दसरा_, 
   {{0x645dd665,0xbeb80142,0x2cb80213,0xf96801ee}},	//   ërin, _crëi, _yurd_, _ирей_, 
   {{0x649c04c4,0x671c65d9,0x7641d666,0x998400c6}},	//   zéie, _बैठक_, _vony, _الضو, 
   {{0x645c02d5,0xd2f805f5,0x7641d667,0xeb3000cf}},	//   ūrin, лэгч_, _wony, _رۉۉد, 
   {{0x7641d668,0x649c04e6,0x25b80010,0x15b800fb}},	//   _tony, xéie, žrla_, _йыйы_, 
   {{0x649c0a40,0x7640009f,0x11d800c6,0xbeb80142}},	//   véie, _uony, طورة_, _grëi, 
   {{0xdb1800d2,0x649c01c7,0x2ee00042,0x00000000}},	//   ncwâ, wéie, wsif_, --, 
   {{0x649c04c4,0xb4f0004e,0x00000000,0x00000000}},	//   téie, _лүүч, --, --, 
   {{0x127800dd,0x2cb8f6b4,0x2fc001d3,0xb0ac0116}},	// [34b20] _محدث_, _surd_, rcig_, _ﺋﺎﭼﭽ, 
   {{0x649c04c4,0x9e64515c,0x2ee0020c,0xc0cc0023}},	//   réie, يالن, rsif_, _እጃም_, 
   {{0x649c04c4,0x2ee1d669,0xcd0402dd,0x2cb80213}},	//   séie, ssif_, спей, _qurd_, 
   {{0x4bd8be60,0x2d8c0fac,0x2b94129e,0x649c0221}},	//   اباد_, _ødem_, قیزس, péie, 
   {{0x2cb80a85,0x649dd66a,0x15f812eb,0x00000000}},	//   _wurd_, léic, ्भार_, --, 
   {{0x6f040ba7,0x2cb8045a,0x0d20004e,0x7dd003e0}},	//   mtic, _turd_, _нүзү, rısü, 
   {{0xc9d400db,0x649c0332,0x00000000,0x00000000}},	//   _ۇزاب, néic, --, --, 
   {{0xbeb80042,0xd90c028e,0x649c01c7,0x00000000}},	//   _crëw, ضیه_, zéib, --, 
   {{0x09e40124,0x649c04e6,0x00000000,0x00000000}},	//   _гозн, héic, --, --, 
   {{0xda780034,0x84c80166,0x6f040e9e,0x00000000}},	//   _кяє_, лумб_, itic, --, 
   {{0x29189b4c,0x6f05d66b,0x59700150,0xa438009b}},	//   _èra_, htic, _يگىز, азну_, 
   {{0x6f040e8b,0xbeb80042,0x00000000,0x00000000}},	//   ktic, _grëw, --, --, 
   {{0x1cdc031c,0xc1e80153,0x6f0400d7,0x00000000}},	//   _ལྗན_, льве_, jtic, --, 
   {{0x16700046,0xa88400db,0x649c0332,0x0ee0000d}},	//   _оқыр, _الچى, féic, _पिजड, 
   {{0x6f05d66c,0x649c01e7,0x00000000,0x00000000}},	//   etic, réib, --, --, 
   {{0x6f05d66d,0x64a800b8,0xdbe4036e,0x00000000}},	//   ftic, _aśiv, mëçk, --, 
   {{0x768c0158,0x6f0413ee,0x645c952b,0x00000000}},	// [34b30] røyv, gtic, mhsi, --, 
   {{0xbeb80023,0x645c00d7,0x00000000,0x00000000}},	//   _orëv, lhsi, --, --, 
   {{0x7e7400d8,0x203c0240,0x9d180108,0x00000000}},	//   rnxp, _ነገርክ, роет_, --, 
   {{0x645c0007,0xfeb825da,0x768c2d8b,0x9f34753d}},	//   nhsi, _ماست_, løyt, _демі, 
   {{0x20080198,0xc9940150,0x00000000,0x00000000}},	//   mfai_, _ﺘﺭﺍﺙ_, --, --, 
   {{0x768c08fb,0x1a28034b,0xc0cc0023,0x00000000}},	//   nøyt, ржки_, _እጃሙ_, --, 
   {{0x645c01d9,0x20080421,0x12c801ec,0x00000000}},	//   khsi, ofai_, _ﺒﺨﻁﻭ, --, 
   {{0xd6d129c0,0x7de80421,0xa5e80032,0x768c00d4}},	//   وقع_, sēsē, ҡлыҡ_, høyt, 
   {{0x645c01d9,0x0ee01dd1,0x768c143a,0x9d440139}},	//   dhsi, _पिछड, køyt, _уеңд, 
   {{0x7bd84de4,0x3b1c031c,0x00000000,0x00000000}},	//   _heuu, _isuq_, --, --, 
   {{0x768c0158,0x6f0400e2,0x62940419,0x0ee40a8a}},	//   døyt, ztic, dlzo, _ओट्स_, 
   {{0x6f04022f,0x62940d27,0x935801ce,0x649c00e4}},	//   ytic, elzo, аргу_, véic, 
   {{0x55e40372,0x8c1806a9,0xfa240135,0x3b1c031c}},	//   _долб, בורי, _རྣོན_, _jsuq_, 
   {{0x649d1d9e,0x7bd80098,0xc7b00a1e,0x6f040010}},	//   téic, _leuu, _חבד_, vtic, 
   {{0x645c7cbc,0xc0f8001f,0x6f040113,0x2009d66e}},	//   bhsi, _ሊባል_, wtic, ffai_, 
   {{0x6f05d66f,0x7bd80a73,0xd010036b,0x645dd670}},	//   ttic, _neuu, بلر_, chsi, 
   {{0x3b1c031c,0xb8f8031c,0x649c01c7,0x4dcc0154}},	// [34b40] _nsuq_, _འས_, séic, িঃসং, 
   {{0x200854bb,0x7bd80393,0x768c0158,0x649c3b88}},	//   afai_, _aeuu, møys, péic, 
   {{0x3218dfc5,0x768c03d4,0x2d9c03d4,0x7bd9d671}},	//   mery_, løys, åve_, _beuu, 
   {{0x51f42172,0x00000000,0x00000000,0x00000000}},	//   _اسکر, --, --, --, 
   {{0xbb41d672,0x7bd80098,0x768c08fb,0x00000000}},	//   мецк, _deuu, nøys, --, 
   {{0x1ad80953,0x321827f8,0x1cdc0327,0x5f440092}},	//   сьць_, nery_, _ལྗམ_, ረግላቸ, 
   {{0x7bd80421,0x768c4606,0x32180ea0,0x9d5000d1}},	//   _feuu, høys, iery_, _كۆكت, 
   {{0xe8e001dc,0x32180851,0x0708016c,0x00000000}},	//   hiệp_, hery_, ахои_, --, 
   {{0x645c02d3,0x32182278,0xdb080139,0x00000000}},	//   ërim, kery_, _rgeç, --, 
   {{0x32181311,0x93f400ac,0xa5f80114,0x00000000}},	//   jery_, şələ, љену_, --, 
   {{0x3219d673,0x3320004e,0x351401c0,0x7bd80098}},	//   dery_, _asix_, ожээ_, _yeuu, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2b400a40,0x768c2d8b,0x68f801a9,0x32181174}},	//   äich_, tøyt, luvd, fery_, 
   {{0x645c01b9,0x64a800b8,0x3219d674,0xf75001c8}},	//   shsi, _aśit, gery_, _تنهج, 
   {{0x768c168c,0x645c0113,0x322800d4,0x00000000}},	//   røyt, phsi, ціям_, --, 
   {{0x20080421,0x62940789,0x30a48739,0x768c143a}},	//   ufai_, slzo, друв, søyt, 
   {{0x3219d675,0xdb180e78,0x768c0158,0xbfa8117e}},	// [34b50] bery_, ubwü, møyr, ртве_, 
   {{0x7bd80098,0x20080005,0x768c0158,0x3219d676}},	//   _seuu, sfai_, løyr, cery_, 
   {{0x3b1c025c,0xa194299f,0x00000000,0x00000000}},	//   _ssuq_, _ханч, --, --, 
   {{0x21200a2e,0xbeb80036,0xfb7003e6,0x14b4010f}},	//   _ishh_, _brët, وپاگ, פּער_, 
   {{0xaac401e2,0x1038011a,0x00000000,0x00000000}},	//   وتون, _הגרע, --, --, 
   {{0xbeb80a40,0xdb1800d2,0x7bd8003e,0x768c00cc}},	//   _drët, gcwá, _weuu, høyr, 
   {{0x768c03d4,0x7bd8dc85,0x9a780092,0x00000000}},	//   køyr, _teuu, ክለኛው_, --, 
   {{0x768c0158,0xec69d677,0x3219d678,0x2a6c0332}},	//   jøyr, _друк_, zery_, _emdb_, 
   {{0x15b83ee2,0xbeb804e6,0x768c05ac,0xf09408a8}},	//   йыны_, _grët, døyr, ונק_, 
   {{0xf9910220,0x649c068c,0x316c033f,0x768c03cd}},	//   _قبض_, véia, ździ_, vøys, 
   {{0xf9680276,0xd628016c,0xbeb804e6,0x99995b1e}},	//   _трай_, _ҳоле_, _krës, _اپار_, 
   {{0x3219d679,0x768c143a,0xb864132f,0x00000000}},	//   wery_, tøys, _بائو, --, 
   {{0x3219d67a,0x2120022e,0x8c180375,0xd6281c56}},	//   tery_, _ashh_, זורי, _голе_, 
   {{0x768c00fe,0x3219a152,0x66040139,0x00000000}},	//   røys, uery_, _ƒike, --, 
   {{0x10a42bf6,0x3219d67b,0xc6900302,0xbeb80240}},	//   зивн, rery_, _ראו_, _orës, 
   {{0x649dd67c,0x3219d67d,0x84980023,0x16840244}},	//   péia, sery_, ገብርን_, _باڤێ, 
   {{0x3219d67e,0x8fd00166,0x68f801a9,0x00000000}},	// [34b60] pery_, _җәбә, zuvd, --, 
   {{0x0d20104b,0x649c7cda,0xbeb80240,0x00000000}},	//   нүгү, néin, _arës, --, 
   {{0xbeb80036,0xc1b80375,0xc0e00108,0x00000000}},	//   _brës, _למיש, _поэк, --, 
   {{0x649c04c4,0xf05800f1,0x2174010a,0x00000000}},	//   héin, _بیرغ_, _цуьр, --, 
   {{0x2a6dd67f,0xbeb801c7,0x6ea407af,0x00000000}},	//   _pmdb_, _drës, _कठपु, --, 
   {{0x7d0007c5,0x649c01c7,0x27e00153,0xd01804b4}},	//   ànsc, jéin, _žin_, _тфү_, 
   {{0xbeb80221,0x3d90039b,0xbea1d680,0x2ea80db3}},	//   _frës, _зиёр, _чарк, कगीत, 
   {{0xc865d681,0x9d740e26,0x68f9d682,0xec3407d6}},	//   ятли, _تەما_, ruvd, _تورگ, 
   {{0x649d3942,0x2a6c002f,0x68f8022e,0x00000000}},	//   féin, _tmdb_, suvd, --, 
   {{0x649c0a40,0x00000000,0x00000000,0x00000000}},	//   géin, --, --, --, 
   {{0x241805f5,0x38c80b28,0x69c80175,0x68f82a89}},	//   ооны_, _هانی_, _ifde, quvd, 
   {{0x35644090,0x64a80055,0xa5cc1fc4,0x27e0032e}},	//   ярын_, _aśir, _द्रौ, _þin_, 
   {{0x21210ba1,0x768c05ac,0xc0340023,0x649c01e1}},	//   _sshh_, røyr, _ኣረማው, béin, 
   {{0x768c00cc,0x00000000,0x00000000,0x00000000}},	//   søyr, --, --, --, 
   {{0xb59000d1,0x98b80055,0x00000000,0x00000000}},	//   _пишш, _āsī_, --, --, 
   {{0xf0b43334,0x768c08fb,0x00000000,0x00000000}},	//   ейсь, løyp, --, --, 
   {{0xbeb80023,0x69c801c7,0x2cac003e,0xdb081432}},	// [34b70] _rrës, _ofde, _éddy_, ünüd, 
   {{0xee8401c0,0xff5c0142,0x00000000,0x00000000}},	//   ныхо, _ffîn_, --, --, 
   {{0x94100134,0xbeb801c7,0x3cf4012d,0x00000000}},	//   _nhyɛ_, _prës, ँढें_, --, 
   {{0x69c9d683,0xf1a42cc8,0x645c0200,0x00000000}},	//   _afde, _ярын, ërih, --, 
   {{0x94100134,0x768c0158,0xbeb80240,0x7e44010a}},	//   _ahyɛ_, køyp, _erër, _ехве, 
   {{0x1de000e1,0x00000000,0x00000000,0x00000000}},	//   _फ़ित, --, --, --, 
   {{0x768c0217,0x649c007b,0x00000000,0x00000000}},	//   døyp, véin, --, --, 
   {{0xfbd07ee4,0x649c0a40,0x97d80845,0x2a7c0158}},	//   _ستر_, wéin, цьку_, anvb_, 
   {{0x649dd684,0x6ea400ab,0xa2b80d2e,0x00000000}},	//   téin, _कठमु, _एंग्, --, 
   {{0xd5b80228,0x9574004e,0x00000000,0x00000000}},	//   өсү_, дымч, --, --, 
   {{0x99840421,0x649dbd6b,0x0680009d,0x00000000}},	//   _malū_, réin, тгэн, --, 
   {{0x68fc03d4,0x649c0036,0x00000000,0x00000000}},	//   _årda, séin, --, --, 
   {{0x44600801,0x67d400f7,0x00000000,0x00000000}},	//   твяв, _чочу, --, --, 
   {{0xe280ffa3,0x00000000,0x00000000,0x00000000}},	//   лғын, --, --, --, 
   {{0x4124016c,0x661c00c5,0x15780050,0xdee00023}},	//   моро_, õrke, _گٔژھ_, _ናባኻ_, 
   {{0xf6e808ea,0xf04401d5,0xc4f40a7c,0x671c04af}},	//   _ལྗོང, رعزی, _חזקי_, _बैँक_, 
   {{0x0321d685,0xd1b87b6d,0x94840022,0xcfa89f6d}},	// [34b80] _адын, _وادا_, _ныҩд, زارم_, 
   {{0x1b0404c5,0x649c00ae,0x00000000,0x00000000}},	//   োটাই_, héil, --, --, 
   {{0x8c45d686,0x82380375,0xfce1d687,0x00000000}},	//   меже, _ועיצ, вохо, --, 
   {{0x28c4012d,0x9f48010e,0x00000000,0x00000000}},	//   _लंबि, lgaý_, --, --, 
   {{0x671c44ab,0xaca4063f,0xbc840092,0x161c0118}},	//   _बैंक_, _haịp, ሜሪካና_, बजार_, 
   {{0xbca000d1,0xbb400114,0x00000000,0x00000000}},	//   ىمەي, тељк, --, --, 
   {{0x5cf40a89,0x768c05ac,0x649c00ae,0xa2d4000d}},	//   _пяту, vøyp, féil, _बढ़न्, 
   {{0x98f40131,0xbeb801c7,0x649c007b,0x00000000}},	//   رغىچ, _krëp, géil, --, 
   {{0x2d98036e,0x768c05ac,0x00000000,0x00000000}},	//   _hyre_, tøyp, --, --, 
   {{0x2d980124,0xbeb80022,0x45080327,0xdbd808a5}},	//   _kyre_, _osën, _ཀྱུར_, _hæðu, 
   {{0x6475d688,0x00000000,0x00000000,0x00000000}},	//   егну, --, --, --, 
   {{0x18880150,0x00000000,0x00000000,0x00000000}},	//   _есіп_, --, --, --, 
   {{0x2d980129,0xdbd801a8,0x8234cdcc,0x00000000}},	//   _lyre_, _mæðu, ورسا, --, 
   {{0xdbd8032e,0x00000000,0x00000000,0x00000000}},	//   _læðu, --, --, --, 
   {{0x2d9840f2,0x98a40356,0xbeb8036e,0x649c0332}},	//   _nyre_, _urlă_, _rrëq, léim, 
   {{0x27e4a0c5,0xdbd802d2,0x00000000,0x00000000}},	//   namn_, _næðu, --, --, 
   {{0x4438070d,0x644c0618,0x442805b8,0x02a5d689}},	// [34b90] _inq_, _ioai, mdc_, _ором, 
   {{0x644c123c,0x27e5d68a,0x2d980493,0xbeb80221}},	//   _hoai, hamn_, _byre_, _drëp, 
   {{0x644c000f,0x649c007b,0x9bf400a8,0x00000000}},	//   _koai, héim, езеч, --, 
   {{0x644dd68b,0x2d981088,0x6c54074d,0x00000000}},	//   _joai, _dyre_, ккху, --, 
   {{0x644dd68c,0x2d980522,0xd6d80f22,0x27e539bc}},	//   _moai, _eyre_, _দম্প, damn_, 
   {{0x2d982188,0x44280161,0xf2d400c8,0x644dcaa9}},	//   _fyre_, hdc_, דעס_, _loai, 
   {{0x2d98062c,0x6db40131,0xdbd801a8,0x00000000}},	//   _gyre_, _айру, _fæðu, --, 
   {{0x644dd68d,0x2aa0067c,0x69dc00e4,0xdbd808a5}},	//   _noai, ròba_, _õren, _gæðu, 
   {{0x2b90034c,0x442800e3,0x2d980023,0xbbc800bc}},	//   _پیوس, ddc_, _zyre_, ाडीक, 
   {{0x44380369,0x644c0b23,0x0680499d,0x649d50d1}},	//   _anq_, _aoai, лгын, séil, 
   {{0x644dd68e,0x4428010a,0x7c2803b2,0xf8c00133}},	//   _boai, fdc_, odgr, _شمشێ, 
   {{0x3d04068f,0x644dd68f,0x625801c3,0xb9dc001f}},	//   _हमने_, _coai, _dìom, _ብሩ_, 
   {{0x7c39d690,0x644dd691,0x649c01e7,0x00000000}},	//   _mnur, _doai, céim, --, 
   {{0x644c0428,0xbeb80200,0x387c154a,0x00000000}},	//   _eoai, _rrëp, lnur_, --, 
   {{0x644dd692,0xc5f00bd9,0x7c39d693,0xe6102e3e}},	//   _foai, _עדה_, _onur, _خشن_, 
   {{0x387c1bb0,0x644c02a4,0x7c38016b,0x44280175}},	//   nnur_, _goai, _nnur, cdc_, 
   {{0xdbd81f60,0x387c022c,0x7c280368,0x409057c1}},	// [34ba0] _ræðu, inur_, ddgr, القر, 
   {{0x7c39d694,0x2d9800c7,0x7c280b4f,0x387c0112}},	//   _anur, _pyre_, edgr, hnur_, 
   {{0x387d4667,0x7c2801f5,0x2d980200,0x20c42cdd}},	//   knur_, fdgr, _qyre_, _ақсо_, 
   {{0xbeb80221,0x00000000,0x00000000,0x00000000}},	//   _trëp, --, --, --, 
   {{0x387c022f,0x62800219,0xc330010f,0x3f8c025c}},	//   dnur_, člov, ָוו_, żgur_, 
   {{0x3abc00c6,0x2d98067d,0xfb84c26e,0x7c28017a}},	//   _מבמבֿ_, _tyre_, ردنی, adgr, 
   {{0x2d8c006a,0x387c01a8,0x7c38007c,0x8a0402dd}},	//   _âde_, fnur_, _fnur, _үзбе, 
   {{0x387dd695,0x7c39d696,0x9cb80327,0x8a040107}},	//   gnur_, _gnur, _བཤགས, _ӯзбе, 
   {{0x644c000f,0xf6e001c0,0x27e40158,0x26c40009}},	//   _roai, лцэн, ramn_, uqmo_, 
   {{0x649c00c6,0xb7fc02f5,0x644dd697,0x27e4007f}},	//   réim, ্যগত_, _soai, samn_, 
   {{0x2d5c0084,0x644c166a,0xa3d489f1,0x09e40183}},	//   ṋe_, _poai, конч, _নাপা, 
   {{0x44380194,0x387c067c,0x3f840356,0x19c001af}},	//   _qnq_, cnur_, şnui_, _йҙәг, 
   {{0x4429d698,0x644dd699,0x00000000,0x00000000}},	//   rdc_, _voai, --, --, 
   {{0x44380097,0x62240131,0x644c00ad,0x65940022}},	//   _wnq_, خىسل, _woai, _иалу, 
   {{0x644c0b23,0xbeb80200,0x00000000,0x00000000}},	//   _toai, _esël, --, --, 
   {{0x759823e4,0x2d5c0943,0x44380399,0x00000000}},	//   _מיוח, ḓe_, _unq_, --, 
   {{0x649dd69a,0xef1000f1,0xcd000210,0x645c0200}},	// [34bb0] héik, یټې_, _liść_, ëriu, 
   {{0x7c380efa,0x69d80175,0x20e40117,0x00000000}},	//   _snur, jbve, _исмҳ, --, 
   {{0x5ff4aa52,0xee8457aa,0x387c0252,0x00000000}},	//   _изну, уыто, ynur_, --, 
   {{0xacf400ae,0x00000000,0x00000000,0x00000000}},	//   اسلت, --, --, --, 
   {{0x7c29d69b,0x387c022c,0x00000000,0x00000000}},	//   rdgr, vnur_, --, --, 
   {{0x03e400eb,0x00000000,0x00000000,0x00000000}},	//   _কাফী_, --, --, --, 
   {{0xd9440137,0x387dd69c,0x38c41d0a,0x00000000}},	//   тейи, tnur_, راغی_, --, 
   {{0x7c39d69d,0xa98800cf,0x00000000,0x00000000}},	//   _unur, رۅنۅ_, --, --, 
   {{0x649c01c7,0x69d8007c,0x1ab40064,0x00000000}},	//   méih, bbve, _абая, --, 
   {{0x62840e3c,0xbeb800c7,0x387c01e4,0x7e74035a}},	//   _njho, _osëm, snur_, nixp, 
   {{0x1cc8031c,0xe7089831,0x661c0254,0x00000000}},	//   _ྲངས_, وتین_, õrka, --, 
   {{0x628401e4,0x09e40183,0xa3cc04af,0x7bc800a2}},	//   _ajho, _নাযা, शुल_, ncgu, 
   {{0x032000d6,0x13a403e6,0x998401ef,0x00000000}},	//   адян, کۆکی_, _kalů_, --, 
   {{0x649c0036,0x7ae800a3,0x52740137,0x87780a7c}},	//   héih, isgt, туму, _קאסי, 
   {{0x621000dc,0xb40400fb,0x71040022,0xc0e06a7a}},	//   द्धौ_, _йүнд, ыҧна, иорк, 
   {{0x7ea803fa,0x645c02d3,0x9f48030a,0x008000f3}},	//   nüpf, ërit, egañ_, алсо, 
   {{0x1cdc031c,0x4f088c75,0xa3e4000d,0x00000000}},	// [34bc0] _རསུ_, ьнан_, _पड़ि_, --, 
   {{0x09e4045e,0x02f80a1e,0x7ea8002f,0x00000000}},	//   _নাভা, _קלימ, hüpf, --, 
   {{0xcd0402de,0xf8b01bd6,0xfbcc004b,0xc69000df}},	//   тпей, ुदाय, ښتو_, סאב_, 
   {{0xa3e409bb,0x5bd40220,0x00000000,0x00000000}},	//   _पड़ा_, _ﺟﯩﺮﻻ, --, --, 
   {{0xda6402dd,0x80ac0034,0x205581ad,0x00000000}},	//   گاني, ंगरे, _стэр, --, 
   {{0xbb440592,0x69d8002f,0x00000000,0x00000000}},	//   ئلون_, ubve, --, --, 
   {{0x3ab039c7,0xda65ad9a,0xbeb80022,0x7ae801ab}},	//   рәтт, داني, _osëj, asgt, 
   {{0x1cdc031c,0xf9c400fb,0x00000000,0x00000000}},	//   _རྦི_, нгәк_, --, --, 
   {{0xe3e000bd,0x9f48008c,0xcb09d69e,0xc6a5d69f}},	//   _ভালব, ngað_, _زيان_, крои, 
   {{0xf76c0116,0x9f9c02d2,0x00000000,0x00000000}},	//   غاي_, _mæði_, --, --, 
   {{0xf6417eaf,0x00000000,0x00000000,0x00000000}},	//   рхын, --, --, --, 
   {{0x290c0009,0x9978008f,0xf76c01d9,0x00000000}},	//   _iqda_, _אָנפ, _ژاو_, --, 
   {{0xc68c00f1,0x9f9c08a5,0xabc401ec,0x83858c92}},	//   _وېب_, _næði_, _ﺩﯞﻣﺎ, тыне, 
   {{0x649c04e6,0xd25000f1,0x00000000,0x00000000}},	//   zéih, منټ_, --, --, 
   {{0x645c02d3,0x80ac0073,0x60180395,0x00000000}},	//   ëris, ंगले, новя_, --, 
   {{0x9f9c1bb0,0x04883cc6,0xb5b4011a,0x9f48032e}},	//   _bæði_, _تختو_, _בלוח_, fgað_, 
   {{0x1e14d874,0x6285d6a0,0xe814185d,0x9f48041e}},	// [34bd0] лмая, _tjho, थ्या_, ggað_, 
   {{0x645c05f7,0x752c0034,0x290c022e,0x9f48030a}},	//   lksi, łcze, _oqda_, ugañ_, 
   {{0x9f480dd4,0x61e402d0,0xb60000d0,0xdd90007b}},	//   rgañ_, _iehl, úšik, حوا_, 
   {{0x645dd6a1,0x61e5d6a2,0x72981772,0x9f9c08a5}},	//   nksi, _hehl, _ሃብታዊ_, _fæði_, 
   {{0x61e5b6f2,0xb3981b49,0x9f9c01a8,0x649c01c7}},	//   _kehl, _ለንደን_, _gæði_, réih, 
   {{0x6295d6a3,0xdd94b590,0x61e400bc,0x60c4d811}},	//   nozo, _багы, _jehl, _kuhm, 
   {{0x61e4c2ab,0x645d6a26,0x60c4016d,0x00000000}},	//   _mehl, kksi, _juhm, --, 
   {{0xccf0025f,0x61e5d6a4,0x60c40477,0xbeb800e4}},	//   _לכל_, _lehl, _muhm, _osëk, 
   {{0x6295155c,0x60c4003e,0x49700724,0x2504002b}},	//   kozo, _luhm, иләс, _diṭṭ, 
   {{0x61e5d6a5,0x645c9d8f,0x6295d6a6,0x09e40183}},	//   _nehl, eksi, jozo, _নাথা, 
   {{0x60c4016d,0x645c0139,0x62946663,0x00000000}},	//   _nuhm, fksi, dozo, --, 
   {{0x9735bb4a,0x23800020,0xd6d8033f,0xf8ac0345}},	//   _معتص, _የሕዝብ_, zyły_, _بکت_, 
   {{0x06c8009e,0xe8b011dc,0xf6e40124,0x645c030a}},	//   লীবি, _بەيج, _рцен, êria, 
   {{0x6295d6a7,0xc0cc02d3,0x955401b9,0x645dd6a8}},	//   gozo, ብጻሕ_, _مخبا, ërir, 
   {{0x3f88011f,0x61e56d74,0x836001d5,0x9f9c08a5}},	//   _axcu_, _dehl, لگیل, _sæði_, 
   {{0x60c4014f,0x645c2238,0xa59400d4,0x00000000}},	//   _duhm, cksi, _тріщ, --, 
   {{0x61e5d6a9,0x60c5d6aa,0x629446ab,0x527400db}},	// [34be0] _fehl, _euhm, bozo, _буну, 
   {{0x61e5d6ab,0x9f48066a,0x00000000,0x00000000}},	//   _gehl, rgað_, --, --, 
   {{0xf1a8038e,0x3f880998,0x60c40007,0x2d9c037e}},	//   _गरिन, _excu_, _guhm, æve_, 
   {{0x61e4b00f,0x5045d6ac,0x00000000,0x00000000}},	//   _zehl, _семб, --, --, 
   {{0x9ac8040b,0xfbac07f7,0x00000000,0x00000000}},	//   نگلہ_, जेलम, --, --, 
   {{0xa0e401d9,0x28f80276,0x8c44013d,0x09cc00fe}},	//   _حسیٖ, векь_, _өеге, ৰণভা, 
   {{0x645c049b,0x250400b8,0x98e400fb,0x649c00e4}},	//   yksi, _miṣṭ, асыһ, méiv, 
   {{0x62945c46,0xa855d6ad,0xa6f474df,0x649c00e4}},	//   zozo, ркич, азиш, léiv, 
   {{0x62945bb8,0xf6d001b9,0x383000c7,0x645c0205}},	//   yozo, یزید, сныр, vksi, 
   {{0x83840220,0xa3cc2232,0x6294056a,0x062400b1}},	//   ғыме, शुई_, xozo, уфим, 
   {{0x08f9d363,0x62940316,0x46480724,0x25b80267}},	//   _سراب_, vozo, _үзен_, ärl_, 
   {{0x61e5d6ae,0x645c049b,0x60c5d6af,0x3d042aa1}},	//   _sehl, uksi, _ruhm, _हमसे_, 
   {{0xb89153bb,0x62940a5c,0x61e403e0,0xb36400a7}},	//   _النع, tozo, _pehl, бърк, 
   {{0xa5f8173e,0x60c4e5b8,0x61e4014f,0x62340353}},	//   _реку_, _puhm, _qehl, шегу, 
   {{0x6295d6b0,0x61e40810,0xa3d40137,0x250400cd}},	//   rozo, _vehl, _койч, _diṣṭ, 
   {{0x8024028e,0xf4840354,0x00000000,0x00000000}},	//   درآم, _гуьн, --, --, 
   {{0x61e5d6b1,0x6295d6b2,0x33181208,0x6d58dd74}},	// [34bf0] _tehl, pozo, _یزید_, øvan, 
   {{0x60c55f40,0x61e404cc,0x6e540cc9,0x629401d5}},	//   _tuhm, _uehl, бвуф, qozo, 
   {{0x3da43999,0xfbd00214,0x68fc0055,0x00000000}},	//   ураб, متش_, _årdh, --, 
   {{0x649c0a40,0x50d800d9,0x9b5800d8,0xe06002f2}},	//   réiw, _שקרא, киет_, _بێری, 
   {{0x2018198f,0x1ab402e8,0x7dc400ae,0x00000000}},	//   _ibsi_, абдя, _متأك, --, 
   {{0x6bd41823,0x649c0036,0x4ef8011a,0x00000000}},	//   لتۇر, méiu, _בהשו, --, 
   {{0x32580302,0xd8880014,0x00000000,0x00000000}},	//   רסום_, پھان_, --, --, 
   {{0xa3e400c5,0x7ae400f1,0x7a4400de,0x00000000}},	//   _पड़ल_, _مورې_, dītņ, --, 
   {{0x46e5d6b3,0x7b6456cd,0x16644c04,0x3ab00139}},	//   адын_, _стве, ивим, _ләкт, 
   {{0x2489d6b4,0x55e40137,0x00000000,0x00000000}},	//   _ajam_, шооб, --, --, 
   {{0xd469d6b5,0x20180ba7,0x786405c7,0x250400b8}},	//   вине_, _obsi_, _añve, _riṣṭ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2488020c,0x2504002b,0x00000000,0x00000000}},	//   _djam_, _piṣṭ, --, --, 
   {{0xe578005e,0x2019d6b6,0x368826aa,0xbeb8036e}},	//   _өзі_, _absi_, _ясен_, _erëz, 
   {{0x625800ee,0x250400cd,0x649c00c7,0x00000000}},	//   уряр_, _viṣṭ, véiv, --, 
   {{0x0490182c,0x50480020,0xe7ac033f,0xd3f80024}},	//   _ولوح, _ነገሮች, _चरमप, _рэкі_, 
  
   {{0x4dd4f0a5,0x25040882,0xb4b401e0,0x8e080120}},	// [34c00] لتاس, _tiṣṭ, _киҫә, кнав_, 
   {{0x2018000d,0x7c54036b,0x2bac002b,0x00000000}},	//   _ebsi_, یللر_, _ṛco_, --, 
   {{0x10a477c1,0x20d000e4,0x649c00c7,0xbe3000db}},	//   _винн, _ỹiva_, réiv, تىلب, 
   {{0x3d04007d,0xa08002dd,0x05780023,0x649c0332}},	//   _हमरे_, _еңсе, _ኣንብብ_, séiv, 
   {{0xdb0800a3,0x649dd6b7,0x7bf400d3,0x00000000}},	//   _sgeò, méit, рнір_, --, 
   {{0xbea065cb,0x649c007b,0x3ea001a9,0x00000000}},	//   _маяк, léit, _мияг, --, 
   {{0x6f040fa3,0xaba4001f,0x3d900fc0,0xd90c6c71}},	//   luic, ላቸዋል_, _диёр, فیل_, 
   {{0x649dd6b8,0xdcac0137,0xcb7400f3,0x00000000}},	//   néit, _كۉل_, _кузњ, --, 
   {{0xbeb802d3,0x6f05d6b9,0xb9e400cf,0x91e40709}},	//   _rrëz, nuic, اتۇۇ, कराज_, 
   {{0x649c6bd3,0x24880240,0xff14011a,0x00000000}},	//   héit, _sjam_, סקית_, --, 
   {{0x245852f0,0x649c04e6,0x6f0401ab,0x65940c82}},	//   гань_, kéit, huic, сану, 
   {{0x7d0000f7,0x6f05d6ba,0xa5240137,0x00000000}},	//   ànsi, kuic, амүд, --, 
   {{0x649c0036,0x0eb40118,0x00000000,0x00000000}},	//   déit, अगाड, --, --, 
   {{0x3d040034,0x6f0401c3,0x64a4035b,0x00000000}},	//   _हमले_, duic, раҭа, --, 
   {{0x2018020b,0x649c0332,0x00000000,0x00000000}},	//   _pbsi_, féit, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6f05d6bb,0xbdc40108,0x00000000,0x00000000}},	// [34c10] guic, ащей, --, --, 
   {{0x660803a2,0x0d7000b8,0x00000000,0x00000000}},	//   ngdk, _śāṭa, --, --, 
   {{0xbeb800c7,0xa159d6bc,0x00000000,0x00000000}},	//   _osëv, _сану_, --, --, 
   {{0x6f040a73,0x649dd6bd,0x00000000,0x00000000}},	//   buic, méis, --, --, 
   {{0x649da891,0x6f04067c,0xd98406ba,0x6b7401c6}},	//   léis, cuic, ﻪﺭﺩﻩ_, олцу, 
   {{0x2009d6be,0xbeb800e4,0x09e00064,0xe89800e5}},	//   lgai_, _asëv, пошн, یموں_, 
   {{0x649dd6bf,0xceb004ac,0x1bd40131,0xa9c40032}},	//   néis, _מיך_, _гобя, әсәк, 
   {{0x1a6404f2,0x00000000,0x00000000,0x00000000}},	//   _گیتی_, --, --, --, 
   {{0x649dd6c0,0x20086845,0x09e4015b,0xda0401f9}},	//   héis, igai_, _নারা, _राऊत_, 
   {{0xd4d80953,0x20080369,0x1a6401ed,0x966421fa}},	//   льмі_, hgai_, _دیتی_, ское, 
   {{0x993457dc,0x00000000,0x00000000,0x00000000}},	//   _دفات, --, --, --, 
   {{0x1cdc0135,0x649c0077,0xe77801ed,0xab8c00a2}},	//   _རྦབ_, xéit, الیں_, _įözü, 
   {{0x649d1388,0x00000000,0x00000000,0x00000000}},	//   véit, --, --, --, 
   {{0x34a40014,0x3b1c0200,0x6f04054e,0x649c12f2}},	//   _ژۅدٲ, _mpuq_, vuic, féis, 
   {{0x76401385,0x649dd6bd,0x91e40107,0x03e40154}},	//   _inny, téit, _қоне, _কারী_, 
   {{0x6f05d6c1,0x0d84052f,0x320c068f,0x20080399}},	//   tuic, ҡлан, żdy_, ggai_, 
   {{0x3fc9556a,0x8fd00588,0x649c00c6,0x6f040393}},	// [34c20] ادفی_, жәҳә, réit, uuic, 
   {{0x6f05d6c2,0xf76416d5,0x2009d6c3,0xfde400cf}},	//   ruic, _ہا_, agai_, йдук_, 
   {{0x20080a2e,0x3b1c0784,0x1cdc0135,0x09e40183}},	//   bgai_, _apuq_, _རྦད_, _নালা, 
   {{0xf7654416,0x6f0402fa,0x649c00c6,0x0b445130}},	//   _فا_, puic, léir, йнен, 
   {{0x6f05d6c4,0x76400134,0x660803cd,0x6d580254}},	//   quic, _onny, ygdk, ävab, 
   {{0x523804ac,0x33200316,0x649c0597,0x76fc00cc}},	//   רײַנ, _mpix_, néir, ্বাছ_, 
   {{0x9e7000db,0xa2e4012d,0x00000000,0x00000000}},	//   _تۇلت, _कब्ज_, --, --, 
   {{0x7641d6c5,0x3320003e,0x649dd6c6,0x00000000}},	//   _anny, _opix_, héir, --, 
   {{0x7d1801fa,0xca740153,0x00000000,0x00000000}},	//   _ćusi, _лужы, --, --, 
   {{0xbb3800c8,0x76400076,0x38c804d3,0x70b423ff}},	//   _געמי, _cnny, _ڵامی_, ंगुल, 
   {{0xfe98008d,0x649c01c7,0x2009b354,0x00000000}},	//   ריימ, déir, ygai_, --, 
   {{0x7641d6c7,0x649c498d,0x00000000,0x00000000}},	//   _enny, véis, --, --, 
   {{0x332001e0,0x4734e4c4,0x649c0036,0x228c00d0}},	//   _cpix_, _دراز, féir, eľka_, 
   {{0x649dd6c8,0x00000000,0x00000000,0x00000000}},	//   téis, --, --, --, 
   {{0xf64dd6c9,0x200805d5,0xf678011a,0x00000000}},	//   _سئو_, tgai_, _תאומ, --, 
   {{0x649d5f9b,0x20080006,0x80d800fe,0x00000000}},	//   réis, ugai_, _বটদ্, --, 
   {{0x76400731,0x649c8ec5,0x44e802f5,0x00000000}},	// [34c30] _ynny, béir, _কমিক_, --, 
   {{0x63add6ca,0x200801c0,0x649c00ae,0xfe0006b1}},	//   _izan, sgai_, péis, _लाओस_, 
   {{0x60188094,0x00000000,0x00000000,0x00000000}},	//   _коня_, --, --, --, 
   {{0xbeb800e4,0xbbe81541,0x00000000,0x00000000}},	//   _asët, ارام_, --, --, 
   {{0x649c0129,0xdfd000db,0x00000000,0x00000000}},	//   néiq, _ىيگ_, --, --, 
   {{0x63add6cb,0xaed43edb,0x795c0241,0x645c0165}},	//   _mzan, _хорш, _nàwú, êrij, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x63add6cc,0x9c640214,0x649c04e6,0x00000000}},	//   _ozan, _بهرو, zéir, --, 
   {{0x7d000077,0x29180267,0x00000000,0x00000000}},	//   ánsf, _äran_, --, --, 
   {{0x069400c6,0x00000000,0x00000000,0x00000000}},	//   ينية_, --, --, --, 
   {{0xe7682ab4,0x942407c6,0xddd40419,0x649ce2a5}},	//   لحین_, омне, _vozň, véir, 
   {{0x3a2401fa,0xccf0008f,0x00000000,0x00000000}},	//   lenp_, וכט_, --, --, 
   {{0x649dd6cd,0xe6b401d5,0x387c0174,0x00000000}},	//   téir, تلیگ, miur_, --, 
   {{0x63add6ce,0x11d800c6,0x6584007b,0x76407a55}},	//   _dzan, شورة_, áthá, _unny, 
   {{0x63add6cf,0x649d9d6b,0x00000000,0x00000000}},	//   _ezan, réir, --, --, 
   {{0x2055d6d0,0x70b40358,0xbeb800e4,0x649dd6d1}},	//   птур, ंगेल, _osës, séir, 
   {{0x80ac21bd,0x649dd6d2,0x00000000,0x00000000}},	// [34c40] ंगजे, péir, --, --, 
   {{0x7ea801b8,0x00000000,0x00000000,0x00000000}},	//   tüpa, --, --, --, 
   {{0x63ac04ba,0xbeb80036,0x8d28023a,0x00000000}},	//   _zzan, _spëc, роев_, --, 
   {{0x681000c0,0x56240154,0x00000000,0x00000000}},	//   _kėdž, বায়ক_, --, --, 
   {{0x7ff404fb,0xda042983,0x00000000,0x00000000}},	//   _بسپا, _राखत_, --, --, 
   {{0x2f1401b8,0x649c00c7,0xa93401ec,0x00000000}},	//   mäg_, héip, зекш, --, 
   {{0x649c0036,0x00000000,0x00000000,0x00000000}},	//   kéip, --, --, --, 
   {{0x387c05d5,0x4c80036b,0xd90c05af,0x00000000}},	//   giur_, _کیچق, طیه_, --, 
   {{0x06d803d4,0x00000000,0x00000000,0x00000000}},	//   _দিহি, --, --, --, 
   {{0x63ac03b9,0x00000000,0x00000000,0x00000000}},	//   _rzan, --, --, --, 
   {{0x69c80004,0x63ac3ec0,0x387c0098,0x00000000}},	//   _igde, _szan, biur_, --, 
   {{0x248c0120,0x649c0129,0x27e000a2,0x70b40a8a}},	//   õem_, téiq, _ýin_, ंगोल, 
   {{0xf76c83fc,0xfbc80118,0x00000000,0x00000000}},	//   _لاو_, िशतम, --, --, 
   {{0x59dc038e,0x00000000,0x00000000,0x00000000}},	//   नुपर, --, --, --, 
   {{0xc0c80046,0xbeb800e4,0x00000000,0x00000000}},	//   руге_, _osër, --, --, 
   {{0x2f1401b8,0x63ac0af9,0x68e80142,0xa2f40395}},	//   fäg_, _tzan, _mwdd, _епич, 
   {{0x63add6d3,0x9df84eca,0x33740395,0x00000000}},	// [34c50] _uzan, йнат_, _огър, --, 
   {{0x69c80098,0xdd940024,0xbea400d4,0x00000000}},	//   _ngde, пазы, ішай, --, 
   {{0x6ab80175,0x00000000,0x00000000,0x00000000}},	//   dmvf, --, --, --, 
   {{0x69c9d6d4,0x5bb96442,0x6d58005b,0xac7400f2}},	//   _agde, блея_, ävaa, وانش, 
   {{0xfb240075,0xfe7087c6,0xfeb8004b,0x3d04007d}},	//   تراپ, _قدس_, _ناست_, _हमके_, 
   {{0xdc5400dd,0x00000000,0x00000000,0x00000000}},	//   _کرسک, --, --, --, 
   {{0xcc8404d3,0xceb404a9,0x7ea80254,0xe8c800fb}},	//   _کۆنه_, _хәт_, lüpo, ҙгөл_, 
   {{0x2aa00ba1,0x00000000,0x00000000,0x00000000}},	//   fòbs_, --, --, --, 
   {{0x387c1570,0x68e80083,0x7ea801d3,0x649c00e4}},	//   riur_, _ewdd, nüpo, véip, 
   {{0x1ca40244,0x00000000,0x00000000,0x00000000}},	//   _بێڵی_, --, --, --, 
   {{0x1cc80156,0xc5ec021a,0xe9d1d6d5,0x68e8015d}},	//   _ིངས_, اړه_, _شغل_, _gwdd, 
   {{0x93580120,0x00000000,0x00000000,0x00000000}},	//   бргу_, --, --, --, 
   {{0x6edc01e1,0x96b8bb62,0x69d80243,0x00000000}},	//   _ḿbà, _луку_, नुवी, --, 
   {{0x70b42a05,0x2f1401e6,0x649c00e4,0x6d48032e}},	//   ंग्ल, väg_, séip, _ádag, 
   {{0xf004010b,0x00000000,0x00000000,0x00000000}},	//   мүни, --, --, --, 
   {{0x63a80327,0x00000000,0x00000000,0x00000000}},	//   żena, --, --, --, 
   {{0x0e642eca,0x0c240107,0x506400fb,0x00000000}},	// [34c60] пкан, ҷмен, отҡа, --, 
   {{0x2f1401c7,0x00000000,0x00000000,0x00000000}},	//   räg_, --, --, --, 
   {{0x0c25d6d6,0xda040037,0x00000000,0x00000000}},	//   змен, _राजत_, --, --, 
   {{0x7ea805d1,0x00000000,0x00000000,0x00000000}},	//   lüpl, --, --, --, 
   {{0xcf3802bf,0x00000000,0x00000000,0x00000000}},	//   _учні_, --, --, --, 
   {{0x6f0401ab,0xe9940214,0xd90c0133,0x7ea80205}},	//   mric, وهشگ, ڤین_, nüpl, 
   {{0xbeb8145e,0x5cf4c142,0x00000000,0x00000000}},	//   _kpën, _ояту, --, --, 
   {{0x50bc0a94,0x6f05d6d7,0x645c0fda,0x07080107}},	//   ्दिष, oric, ūriz, бхои_, 
   {{0x78640489,0x0ae801c8,0x00000000,0x00000000}},	//   _eñvo, _درزي_, --, --, 
   {{0xe67800d6,0x6f04379c,0x35e00212,0x69c802d0}},	//   ійні_, iric, нцюв, _ugde, 
   {{0xbeb8002e,0x6f05d6d8,0x47940214,0xb71004f2}},	//   _opën, hric, _کجاس, وبیش, 
   {{0x2b218188,0x6f05d6d9,0x00000000,0x00000000}},	//   _यहाँ_, kric, --, --, 
   {{0xa5f9c20e,0x6f0401f5,0xf740009b,0x00000000}},	//   _делу_, jric, _пецо, --, 
   {{0xf2c40474,0xf7b80375,0x00000000,0x00000000}},	//   ессн, _הזדמ, --, --, 
   {{0x6f05d6da,0xf12401c6,0x85440166,0x661c000d}},	//   eric, ньто, _хэле, õrku, 
   {{0x6f05d6db,0x30a53566,0x05940214,0x73d802e8}},	//   fric, ерув, _واژگ, _едър_, 
   {{0x4429d6dc,0xbfa83abd,0x6d59d6dd,0xe8ec031c}},	// [34c70] mec_, стве_, ävan, _ལསའག, 
   {{0x4429d6de,0x00000000,0x00000000,0x00000000}},	//   lec_, --, --, --, 
   {{0x6f040a63,0x2dd800c6,0xf2d8179e,0x00000000}},	//   aric, سبلة_, _وبیش_, --, 
   {{0x4429d6df,0x00000000,0x00000000,0x00000000}},	//   nec_, --, --, --, 
   {{0x1a64205b,0x6f05d6e0,0xc9540075,0xaed40117}},	//   ویری_, cric, ېلىش_, _пояш, 
   {{0x4429d6e1,0xdd940228,0x94fc031c,0xfcc801c6}},	//   hec_, _жагы, _དྷའི_, _гуай_, 
   {{0x4429d6e2,0x09e400fe,0xb81800cc,0x00000000}},	//   kec_, _নাখা, _দোষত_, --, 
   {{0xba7455b8,0x38b000c7,0xac1804b1,0xd87400cf}},	//   _کارت, kãre_, _носу_, باتب, 
   {{0x3cec0118,0xf9c401f4,0x5748003b,0x00000000}},	//   šově_, _ещен, ізом_, --, 
   {{0x7c29d6e3,0x0680010b,0x9994012d,0xae104709}},	//   legr, кгын, ągłe_, ालयन_, 
   {{0x4429d6e4,0xf96800b1,0xff5c03cb,0x85780023}},	//   fec_, _урай_, _sgîl_, _ኣንፈቱ_, 
   {{0x6f05d6e5,0x44281dd5,0x947800d4,0x00000000}},	//   yric, gec_, існу_, --, 
   {{0xe73802bf,0x087400c8,0x78b8026c,0x11d40212}},	//   _неї_, _קענט_, mmuv, дібр, 
   {{0x6f05d6e6,0xbeb801c7,0xba0402d3,0x44280334}},	//   vric, _spën, _ወን_, aec_, 
   {{0x4428a3f5,0x6f041eb9,0x7c2821e3,0x233400c7}},	//   bec_, wric, kegr, _ҧхьр, 
   {{0x61e00c02,0x4429d6e7,0x23c40055,0xcee800a7}},	//   ılla, cec_, _bījī_, ждае_, 
   {{0x6f05657a,0x69a4000d,0x52741a71,0x00000000}},	// [34c80] uric, _चुनी, _жуну, --, 
   {{0x91280a8d,0x00000000,0x00000000,0x00000000}},	//   _джоб_, --, --, --, 
   {{0x6f05d6e8,0x9e6400be,0x7c2802d2,0x00000000}},	//   sric, راكن, fegr, --, 
   {{0x7c28fc8e,0x32d4049b,0x50b44dba,0x21740408}},	//   gegr, _käy_, _існу, _чуьр, 
   {{0xbeb8006a,0xaa440022,0x00000000,0x00000000}},	//   _kpël, нҵал, --, --, 
   {{0x4429d6e9,0x7d00007b,0x78b80083,0x32d40139}},	//   zec_, ánsc, emuv, _mäy_, 
   {{0x7c29d6ea,0x32d40166,0xc95401c6,0xe904009d}},	//   begr, _läy_, ьтды, хцлү, 
   {{0x2901d6eb,0x7c280354,0x4429d6ec,0x8b2403b7}},	//   čia_, cegr, xec_, _одбе, 
   {{0x32d4023a,0x60c801e4,0x00000000,0x00000000}},	//   _näy_, ĉemi, --, --, 
   {{0xba200022,0x442805c7,0x272000fe,0x6f840150}},	//   _идук, wec_, বিলো_, _ﺭﺒﻤﺎ_, 
   {{0x2919d6ed,0xa5080073,0x69cc0205,0x00000000}},	//   _ëra_, वढेच_, ğneğ, --, 
   {{0x69d845a7,0x32d4013d,0xb7d4027d,0xe374013d}},	//   lcve, _bäy_, _قوما_, елмы, 
   {{0x4429d6ee,0x32d400fd,0x1cac0327,0x3630036b}},	//   rec_, _cäy_, _པེལ_, رریس, 
   {{0x659427fe,0x2ca4020c,0x7c295ab5,0x32d40139}},	//   _палу, _lkmd_, zegr, _däy_, 
   {{0x6d58023a,0xa1580107,0x00000000,0x00000000}},	//   äval, чаву_, --, --, 
   {{0x9ed9d6ef,0x38b00022,0xb4f8011a,0x00000000}},	//   змат_, pãre_, _ולהר, --, 
   {{0x7c287209,0x5f94b27b,0x00000000,0x00000000}},	// [34c90] vegr, хиат, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9410016b,0x61f45397,0x32d40724,0x00000000}},	//   _nkyɛ_, mazl, _zäy_, --, 
   {{0x1bd4230c,0x9b940131,0x61f40210,0x91b800d9}},	//   ходя, ىلات, lazl, _ממתי, 
   {{0x7c29d6f0,0x94100134,0x09e40183,0x38940311}},	//   regr, _akyɛ_, _নাজা, năre_, 
   {{0x99d40eff,0xec686b21,0x61f406be,0x00000000}},	//   رتتا, зрәк_, nazl, --, 
   {{0x98a5d6f1,0x6d5805ac,0xeda400db,0x00000000}},	//   нике, øvat, _ашто, --, 
   {{0x61f4e162,0xb90400af,0x00000000,0x00000000}},	//   hazl, _भऽ_, --, --, 
   {{0xfbc4036b,0x61f5d6f2,0x966401ec,0x78b80254}},	//   _ўғли_, kazl, екпе, rmuv, 
   {{0x7af81dc9,0x61f400d7,0x00000000,0x00000000}},	//   _ivut, jazl, --, --, 
   {{0xb16402d3,0x03e4015b,0x7af8032e,0x32d40139}},	//   _ግፍዕታ, _কাজী_, _hvut, _säy_, 
   {{0x1cac031c,0x98b800cf,0x00000000,0x00000000}},	//   _པེས_, _элет_, --, --, 
   {{0x7bd8009a,0x38940356,0x744c0092,0x61f403e0}},	//   _mfuu, găre_, _እየፈጠ, fazl, 
   {{0x7af89715,0x051c0183,0x4b780a7c,0x61f5d6f3}},	//   _mvut, _বছৰৰ_, לארו, gazl, 
   {{0x7bd890ae,0xc68c0014,0xd4680137,0xc5f0010f}},	//   _ofuu, _دِو_, _нике_, _גדו_, 
   {{0x7af9d6f4,0x7bd80a49,0x865000c7,0x69d80427}},	//   _ovut, _nfuu, _акәх, zcve, 
   {{0x61f5d6f5,0x4f080032,0x00000000,0x00000000}},	// [34ca0] bazl, янан_, --, --, 
   {{0x7bd9d6f6,0xa2d40a1c,0x00000000,0x00000000}},	//   _afuu, _यंत्, --, --, 
   {{0x7af89acb,0xfce06d5f,0x021405d0,0x00000000}},	//   _avut, гохо, _אחים_, --, 
   {{0x7af80810,0x693404d3,0x291800b0,0x6ab805d7}},	//   _bvut, ێکار, _ärai_, इग्र, 
   {{0xbb402401,0x8e7401d5,0x00000000,0x00000000}},	//   лецк, _зувч, --, --, 
   {{0x7af800d2,0x7bd9d6f7,0x6d5805ac,0x3f6400d8}},	//   _dvut, _efuu, øvas, _џиро_, 
   {{0x7af9d6f8,0x7bd80083,0x38940276,0x0ca83090}},	//   _evut, _ffuu, zăre_, _فطري_, 
   {{0x61f408ad,0x69d800f3,0x07080107,0x6b8401ee}},	//   zazl, scve, пхои_, _иҫеб, 
   {{0x61f41258,0x3b045336,0xfc1401d5,0xb76001c6}},	//   yazl, _пето_, _سقلب_, гтэй, 
   {{0x3b800452,0xae112fe4,0xbaf8011a,0xe7e01d68}},	//   _слуг, ालिन_, _מהמש, _ग्रा_, 
   {{0xf76d05b4,0x65957eb2,0xc588034b,0x3514009d}},	//   لای_, тану, ящие_, нжээ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x291c00e5,0x59dc00cd,0x00000000,0x00000000}},	//   ltva_, नुवर, --, --, 
   {{0x23a407b7,0x00000000,0x00000000,0x00000000}},	//   _गुणद, --, --, --, 
   {{0x291c01ed,0x3894054e,0x00000000,0x00000000}},	//   ntva_, săre_, --, --, 
   {{0xc0940023,0x91c000c7,0x00000000,0x00000000}},	//   _ዘብጽሕ_, шәыл, --, --, 
   {{0x644dd6f9,0xb6a00116,0x1e140139,0x00000000}},	// [34cb0] _inai, _шиәл, кмая, --, 
   {{0x4438f960,0x80b006ab,0x7bd80083,0x644c01ab}},	//   _haq_, _आठवे, _sfuu, _hnai, 
   {{0x4438a886,0x7af80099,0xaca4063f,0x7ea8014a}},	//   _kaq_, _svut, akọt, nüpi, 
   {{0x4438014f,0x7884033b,0x644c01ab,0xdfd46ef4}},	//   _jaq_, _mèvè, _jnai, _шомы, 
   {{0x4439d6fa,0x644c5320,0x1e5001ed,0x6d5800fe}},	//   _maq_, _mnai, _پہاڑ, øvar, 
   {{0x4439d6fb,0x644c01ab,0x7af8025c,0xe5040432}},	//   _laq_, _lnai, _vvut, _töňň, 
   {{0x644dd6fc,0x6e95d6fd,0x00000000,0x00000000}},	//   _onai, _сиру, --, --, 
   {{0x7af802c4,0x44380978,0x7ea829ef,0x644c5e7c}},	//   _tvut, _naq_, düpi, _nnai, 
   {{0x2ba80c2e,0x5b14dbe2,0x7af88a07,0x7c380276}},	//   _छुपा, _шмат, _uvut, _iaur, 
   {{0x7c39d6fe,0xead5226f,0x4439d6ff,0x6d480014}},	//   _haur, _софь, _aaq_, _تلہِ_, 
   {{0x644c01ab,0x291c2b57,0x44387caa,0xddd4012d}},	//   _bnai, ctva_, _baq_, _kozł, 
   {{0x7c380323,0x644c00c6,0x67d4074d,0x381c00fe}},	//   _jaur, _cnai, _боцу, _মোৰো_, 
   {{0x7c39d700,0x44380842,0xe7c02aa1,0x644dd701}},	//   _maur, _daq_, शेदप, _dnai, 
   {{0xd25018a5,0x7c39d702,0x644dd703,0x6d580821}},	//   جنس_, _laur, _enai, ävak, 
   {{0x443864a2,0x7864030a,0xc6140375,0x644d44e4}},	//   _faq_, _añvi, _יחסי_, _fnai, 
   {{0x7c39d704,0xc00006ed,0x44380051,0x04400354}},	//   _naur, ипск, _gaq_, _веън, 
   {{0x984400da,0xb9000327,0x4fe801ec,0x00000000}},	// [34cc0] dēļ_, _ཨཕ_, змұн_, --, 
   {{0x7c380421,0x752c012d,0x88e000fe,0x5164014b}},	//   _aaur, łczu, _যিসক, _авоб, 
   {{0x4439d705,0x644c01ab,0x7e60005b,0xfd54002b}},	//   _yaq_, _ynai, önpa, _khaṭ, 
   {{0x7c39d706,0x4439d707,0x644c01ab,0xfd54002b}},	//   _caur, _xaq_, _xnai, _jhaṭ, 
   {{0x7c39d708,0xe2a802f2,0x8f740816,0x00000000}},	//   _daur, _زاین_, _руні, --, 
   {{0xe188dbb4,0x291c00dc,0xc3300375,0x7a3401ec}},	//   _آئین_, ttva_, יוד_, кпір_, 
   {{0x6e3dd709,0x7c39d70a,0x635c06be,0xaa4400db}},	//   _iarb, _faur, _dьny, _ەچبى, 
   {{0x7c39d70b,0x291c00dd,0x6e3c9a62,0x38b000c7}},	//   _gaur, rtva_, _harb, tãra_, 
   {{0x291c08ad,0x18541dc8,0x4439d70c,0x644d892f}},	//   stva_, ارىڭ, _raq_, _rnai, 
   {{0x4439d70d,0x7c393ef6,0x78840100,0x09b8007b}},	//   _saq_, _zaur, _pèvè, _قطاع_, 
   {{0x443918ba,0x7c39d70e,0x241801c0,0xfd5400cd}},	//   _paq_, _yaur, ноны_, _bhaṭ, 
   {{0x44380842,0xb9780bd9,0x644c01ab,0x649c00cf}},	//   _qaq_, _קנאי, _qnai, néix, 
   {{0x6e3dd70f,0xfd540055,0x4439d602,0x644c01ab}},	//   _oarb, _dhaṭ, _vaq_, _vnai, 
   {{0x4439d710,0x644d6ba3,0x38940356,0x00000000}},	//   _waq_, _wnai, măra_, --, 
   {{0x644c8b14,0x236c01a2,0x4439d711,0x00000000}},	//   _tnai, šej_, _taq_, --, 
   {{0x644dd712,0x6e3c04c4,0xfd540882,0x00000000}},	//   _unai, _aarb, _ghaṭ, --, 
   {{0x7c39d713,0x73380372,0x6e3cca05,0x59a86c95}},	// [34cd0] _raur, _азыр_, _barb, _चुनर, 
   {{0x7c39d714,0x63add715,0xfe702df0,0x6e3c2f86}},	//   _saur, _iyan, جدر_, _carb, 
   {{0x6e3dd716,0x7c39d717,0x63add718,0x6285d719}},	//   _darb, _paur, _hyan, _imho, 
   {{0x63add71a,0x6e3dd71b,0x6284014f,0x8c84035b}},	//   _kyan, _earb, _hmho, гәуа_, 
   {{0x6e3dd71c,0x63ac2d6f,0x7c39d71d,0x00000000}},	//   _farb, _jyan, _vaur, --, 
   {{0x63add71e,0x7c39d71f,0x6e3dd720,0x5f040124}},	//   _myan, _waur, _garb, _изҭа, 
   {{0x7c39d721,0x63add722,0x00000000,0x00000000}},	//   _taur, _lyan, --, --, 
   {{0x63add723,0x6e3dd724,0x6a74004e,0x628401ab}},	//   _oyan, _zarb, _ràfe, _lmho, 
   {{0x62840460,0x6e3dd725,0x63adcf85,0xac8401e0}},	//   _omho, _yarb, _nyan, _тѳрл, 
   {{0x6e3dd726,0x65680175,0x00000000,0x00000000}},	//   _xarb, fydh, --, --, 
   {{0x4e34008f,0xfd5400b8,0xc7a001d5,0x00000000}},	//   אָכן_, _phaṭ, _қишк, --, 
   {{0x9474188a,0x63add727,0x628403cb,0x38940311}},	//   اددا, _byan, _amho, băra_, 
   {{0x63add728,0xc48001ca,0x3894054e,0x00000000}},	//   _cyan, сляк, căra_, --, 
   {{0x2019d729,0x6b8400ae,0x00000000,0x00000000}},	//   _acsi_, úigi, --, --, 
   {{0x63add72a,0x7ea803fa,0x5094026a,0xf1a400e1}},	//   _eyan, nüpu, грађ, _खुशन, 
   {{0x6e3dd72b,0x6285d72c,0x63ac007f,0x00000000}},	//   _sarb, _emho, _fyan, --, 
   {{0x63add72d,0xd5e01682,0xcf442cc8,0x228c00d0}},	// [34ce0] _gyan, hiḽ, ынай, eľku_, 
   {{0x6e3dd72e,0x00000000,0x00000000,0x00000000}},	//   _qarb, --, --, --, 
   {{0x6e3dd72f,0x8c45d730,0x06d80183,0x85f400c8}},	//   _varb, леже, _দিছি, רמעס_, 
   {{0x6e3c0a81,0xbf980120,0x0134011a,0x00000000}},	//   _warb, _idên, _ערכת_, --, 
   {{0x6e3dd731,0x628400a9,0x32380023,0x649c00db}},	//   _tarb, _ymho, _ብምሕባ, réix, 
   {{0x6e3c2515,0xbb442372,0xfaa1d732,0x00000000}},	//   _uarb, الون_, бачо, --, 
   {{0xfce000d1,0x3ab005a2,0x2d8c00a2,0x00000000}},	//   _госо, сәтт, _äde_, --, 
   {{0x63a8006d,0x00000000,0x00000000,0x00000000}},	//   żeni, --, --, --, 
   {{0x09e44a0b,0x9ba401d9,0x99840153,0xbb4000f3}},	//   _бозн, _پۯوِ_, _balų_, _летк, 
   {{0xe7c000dc,0xaa9400fb,0x00000000,0x00000000}},	//   शेषप, _тѳбә, --, --, 
   {{0x63add733,0xbf98006a,0x48e42077,0xf1a4012d}},	//   _syan, _ndên, _соев, _खुलन, 
   {{0x65680240,0x38940356,0x997496f0,0x7ea85c19}},	//   rydh, păra_, _тууш, lüpt, 
   {{0x261c01ad,0x00000000,0x00000000,0x00000000}},	//   _मापी_, --, --, --, 
   {{0x63add734,0x99840153,0xcfb800cc,0x00000000}},	//   _vyan, _galų_, ংখান, --, 
   {{0x63ac0066,0x0e2c0020,0x20180129,0xf49400f2}},	//   _wyan, _አማካኝ, _pcsi_, _گشود, 
   {{0x9f480270,0x63add735,0x00000000,0x00000000}},	//   maaú_, _tyan, --, --, 
   {{0x63add736,0x7ed433de,0x00000000,0x00000000}},	// [34cf0] _uyan, ازرا, --, --, 
   {{0x62844b7a,0x645c281f,0x00000000,0x00000000}},	//   _umho, ljsi, --, --, 
   {{0xdfd000ec,0x261c924b,0x615400cf,0x69a4044b}},	//   _ويد_, _मानी_, _ئنجئ, _चुली, 
   {{0x6dc4005b,0x645c0010,0x00000000,0x00000000}},	//   ссуж, njsi, --, --, 
   {{0xce500014,0x1084104e,0x00000000,0x00000000}},	//   _ژھمب, _төрк_, --, --, 
   {{0xcb647858,0x7ea80793,0x6294002f,0x38b000e4}},	//   раше_, güpt, nnzo, tãro_, 
   {{0x629401a4,0x7d00002d,0x00000000,0x00000000}},	//   inzo, ânsd, --, --, 
   {{0x645c0113,0x7c840f14,0xd70421fa,0x99840153}},	//   jjsi, _суге, азии, _salų_, 
   {{0x6c540372,0x23a404fa,0xe6d4009d,0x00000000}},	//   _укту, _गुलद, йцээ, --, 
   {{0xe728009f,0x00000000,0x00000000,0x00000000}},	//   اسيو_, --, --, --, 
   {{0x34a4016c,0x7ea80254,0x99840064,0x00000000}},	//   йгоҳ, lüps, _valų_, --, 
   {{0x23a4001f,0x629404cc,0x934402dd,0x23800092}},	//   _ለሕዝብ_, enzo, анме, _ከሕዝብ_, 
   {{0x69e400e4,0x24980264,0x77780175,0x00000000}},	//   _éteé, érma_, qzux, --, 
   {{0x9475d737,0x877808d8,0xf77003e6,0x55e4004e}},	//   ادگا, _באני, _پاڵ_, _токб, 
   {{0x01600f06,0xdd180003,0x94780117,0x00000000}},	//   окро, għże, _аспу_, --, 
   {{0xd010006c,0x6294011c,0x7ea80037,0x20d40150}},	//   تلر_, anzo, küps, сірс, 
   {{0x8e85d738,0x261c52f2,0xa244022e,0xc438011a}},	// [34d00] агае, _मामी_, g訴st, _יתקי, 
   {{0x818400f2,0x00000000,0x00000000,0x00000000}},	//   اچیق_, --, --, --, 
   {{0x8d5407b5,0x0d8400d8,0x00000000,0x00000000}},	//   штач, јлен, --, --, 
   {{0x8b68b4d3,0x6d4803b2,0x0b89d739,0x3cd000d4}},	//   киев_, _ádam, ксли_, іжіс, 
   {{0x31bc013a,0x00000000,0x00000000,0x00000000}},	//   _fází_, --, --, --, 
   {{0xcce4038b,0x32182517,0x7d081432,0x00000000}},	//   _نسري, ngry_, ümsü, --, 
   {{0xfa6416a4,0x00000000,0x00000000,0x00000000}},	//   рајк_, --, --, --, 
   {{0x7d00045f,0xa85401d5,0x6720007c,0x2da80124}},	//   ânse, скич, ttmj, ĩteĩ_, 
   {{0x0ba812b7,0x00000000,0x00000000,0x00000000}},	//   _شارى_, --, --, --, 
   {{0xa3bc084a,0x78a80115,0x645d2587,0x7ea80254}},	//   _अरब_, _ekgv, wjsi, lüpr, 
   {{0xa8e400aa,0x49b801d3,0x245402c9,0x76b40166}},	//   _اړتي, _شائد_, مندس, рлэр_, 
   {{0x645c0007,0x07a4008e,0xa3c400e1,0xc7a4008e}},	//   ujsi, _каен, ौशल_, _киек, 
   {{0x3b1c025c,0x228c0419,0x47341bf4,0x443c0419}},	//   _xquq_, ežka_, _خراز, ľu_, 
   {{0x443dd73a,0x7d01d73b,0xa5f844e4,0x629401f5}},	//   žu_, ánsk, _секу_, unzo, 
   {{0x76b8011a,0x00000000,0x00000000,0x00000000}},	//   _שמופ, --, --, --, 
   {{0x261c0bae,0x31bc013a,0x40540137,0x00000000}},	//   _माडी_, _sází_, جئسس, --, 
   {{0x7de40ae5,0xde400092,0x00000000,0x00000000}},	// [34d10] لسام, _የማይለ, --, --, 
   {{0x35a80210,0x00000000,0x00000000,0x00000000}},	//   _घुड़, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2ba813f5,0x6054179e,0x00000000,0x00000000}},	//   _छुहा, _انحط, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xaac4004b,0x248804ba,0x0af40956,0x00000000}},	//   يتون, _lmam_, حفوظ_, --, 
   {{0x6d5826bb,0x00000000,0x00000000,0x00000000}},	//   ävat, --, --, --, 
   {{0x7ae400aa,0x22400219,0xfb8400fd,0x2ba80118}},	//   _نورې_, _lahk_, _кызн, _छुवा, 
   {{0x3b1c0309,0x051403d4,0x3e340092,0x9b4400f1}},	//   _uquq_, তবোৰ_, _የማዕከ, _دچاو, 
   {{0x2489d73c,0x224000c5,0x00000000,0x00000000}},	//   _amam_, _nahk_, --, --, 
   {{0xd468765f,0x7600013d,0x00000000,0x00000000}},	//   гине_, _rízı, --, --, 
   {{0x261c146c,0x00000000,0x00000000,0x00000000}},	//   _माथी_, --, --, --, 
   {{0xd6280b3b,0x00000000,0x00000000,0x00000000}},	//   _боле_, --, --, --, 
   {{0x248854b2,0xd548004b,0x00000000,0x00000000}},	//   _emam_, _ملتو_, --, --, 
   {{0x261c0490,0x224400d0,0xa3bc00c5,0xd0087651}},	//   _माती_, ôlka_, _अरथ_, леве_, 
   {{0x25b803e0,0x00000000,0x00000000,0x00000000}},	//   ürle_, --, --, --, 
   {{0x63a8ba0a,0xe6100150,0x4e0401a9,0xcee9235d}},	// [34d20] üent, _ءشۇ_, йзаб, удзе_, 
   {{0xc7b00bd9,0x00000000,0x00000000,0x00000000}},	//   לבן_, --, --, --, 
   {{0x63a8038f,0x5dd9d73d,0x10a5d73e,0x31700311}},	//   żent, рфур_, _гинн, ânză_, 
   {{0xbeb80221,0x00000000,0x00000000,0x00000000}},	//   _spët, --, --, --, 
   {{0xe2a002dd,0x00000000,0x00000000,0x00000000}},	//   _ﺍﺳﻪﻡ_, --, --, --, 
   {{0x2ce82651,0x27e0031c,0x42d8010f,0x6d580821}},	//   _نظری_, _żin_, אקסע, ävas, 
   {{0x09283c4b,0x8c45d73f,0x2ec407b6,0x00000000}},	//   استي_, _леве, वगीत, --, 
   {{0xa7740108,0x00000000,0x00000000,0x00000000}},	//   жлич, --, --, --, 
   {{0xb8fc02c3,0x261c0cb2,0x00000000,0x00000000}},	//   _धू_, _मादी_, --, --, 
   {{0xf76c021f,0xda640f2b,0xe9c400c7,0x00000000}},	//   عاي_, _والي, _дазҿ, --, 
   {{0x49980801,0xb0040055,0x00000000,0x00000000}},	//   _стая_, _auḍu, --, --, 
   {{0x7d003c80,0x7ea9d740,0x2240000d,0x86740022}},	//   ánsi, hüpp, _sahk_, рыҩц, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9f580591,0x00000000,0x00000000,0x00000000}},	//   _gesê_, --, --, --, 
   {{0x24880548,0x00000000,0x00000000,0x00000000}},	//   _umam_, --, --, --, 
   {{0x9df9d741,0x5f940588,0x22400254,0xe82008f2}},	// [34d30] инат_, циат, _tahk_, _याना_, 
   {{0x7fd4005e,0x7ae80334,0xb3e801d3,0x00000000}},	//   ріңі, vpgt, _پٹیل_, --, 
   {{0x9cf4005e,0xdfd40724,0xa159d742,0x1cac031c}},	//   ізді, _моны, _тану_, _པེད_, 
   {{0x729c0020,0x00000000,0x00000000,0x00000000}},	//   _ወቅታዊ_, --, --, --, 
   {{0x6d5808ae,0xdea001d5,0x3e6c0205,0x00000000}},	//   ävar, _قیری, _pıtı_, --, 
   {{0xbeb80023,0x9f480332,0x00000000,0x00000000}},	//   _epër, nbaí_, --, --, 
   {{0xeab1d743,0x00000000,0x00000000,0x00000000}},	//   رعه_, --, --, --, 
   {{0xd7081e28,0x9f58b3db,0xddd40118,0xb9380092}},	//   ание_, _resê_, _rozř, _በክልሎ, 
   {{0xcc8404d3,0x07a002a9,0x7af00133,0x61e402d2}},	//   _بۆنه_, маън, _رقاڵ, _ofhl, 
   {{0x7e640455,0x69a41098,0xddd401ef,0xd6d80166}},	//   _jojp, _चुकी, _pozř, лтү_, 
   {{0x7e64047e,0x9f580240,0x7d15d744,0xa5940395}},	//   _mojp, _besë_, nuxs, зрящ, 
   {{0x7e64014f,0x00000000,0x00000000,0x00000000}},	//   _lojp, --, --, --, 
   {{0xcc38008f,0x96b800f3,0xe78400db,0xd13001d9}},	//   בערט, _куку_, _ىلمپ, ژمس_, 
   {{0x4798008f,0xb6c44c91,0x9f48007b,0x99f8010f}},	//   _דינס, _усей, gbaí_, יפֿפ, 
   {{0x76400020,0x9f580023,0xc0e0bf73,0x00000000}},	//   _iany, _fesë_, доск, --, 
   {{0x7641d745,0x603000bc,0xa2d4033f,0x00000000}},	//   _hany, _němč, _यूक्, --, 
   {{0x7641d746,0x7e6407ab,0x0e65d747,0x43640b01}},	// [34d40] _kany, _bojp, окан, _маън_, 
   {{0x7641d748,0x6a74004e,0xbeb80240,0x00000000}},	//   _jany, _ràfo, _spër, --, 
   {{0x995c031c,0x7ea8002f,0xd72400eb,0x10a4009b}},	//   għża_, rüpp, বিয়া_, _мион, 
   {{0xf764198a,0x20d401e4,0xf22000af,0x00000000}},	//   _قا_, _eĥis_, _बाड़_, --, 
   {{0x764000fb,0x91dc000d,0x00000000,0x00000000}},	//   _oany, _मलाई, --, --, 
   {{0x7641d749,0x6f04198f,0x00000000,0x00000000}},	//   _nany, msic, --, --, 
   {{0x6f054b72,0x0c580a5b,0xc8780a5b,0x00000000}},	//   lsic, _крањ_, иџи_, --, 
   {{0x7641d74a,0x261c0412,0x00000000,0x00000000}},	//   _aany, _माही_, --, --, 
   {{0x7641d74b,0xf22009d9,0x6f05d74c,0x9f58b3db}},	//   _bany, _बाढ़_, nsic, _resë_, 
   {{0x9f59d74d,0xf76c00c6,0x7641d74e,0x6f040192}},	//   _desè_, ضاً_, _cany, isic, 
   {{0x7641d74f,0x9f58044e,0x6f043f5b,0x00000000}},	//   _dany, _pesë_, hsic, --, 
   {{0x6f05d750,0x76401418,0x9f58007f,0xc76401d9}},	//   ksic, _eany, _fesè_, _واشى, 
   {{0x7641d751,0xe7240489,0x6f05d752,0x9f58036e}},	//   _fany, _འདྲན_, jsic, _vesë_, 
   {{0x7641d753,0x9f540165,0x24982b3c,0x6f0432e4}},	//   _gany, _égée_, _گنبد_, dsic, 
   {{0x6f04039a,0x9f480332,0x00000000,0x00000000}},	//   esic, rbaí_, --, --, 
   {{0x76401a8a,0x9f58003e,0x6f0403fa,0x7e640455}},	//   _zany, _hesé_, fsic, _sojp, 
   {{0x7641bdf4,0x6f0401ab,0x7e640477,0x541802dd}},	// [34d50] _yany, gsic, _pojp, _ارىڭ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6f04208d,0x7e65d754,0x00000000,0x00000000}},	//   asic, _vojp, --, --, 
   {{0x6f043cef,0x7d148186,0xac9401a9,0x00000000}},	//   bsic, ruxs, махш, --, 
   {{0x6f05d755,0xaae4015e,0x9058011a,0x00000000}},	//   csic, وسوو, _הכרת, --, 
   {{0x38940276,0xd945d756,0x00000000,0x00000000}},	//   mări_, зеки, --, --, 
   {{0x7641d757,0x38940311,0xb93400cf,0x00000000}},	//   _rany, lări_, تۋاا_, --, 
   {{0x7641d758,0x319c27af,0xac74167e,0x442800b5}},	//   _sany, יבונ, _قاقش, jfc_, 
   {{0x38940276,0x00000000,0x00000000,0x00000000}},	//   nări_, --, --, --, 
   {{0x76409f02,0x7c28017a,0x00000000,0x00000000}},	//   _qany, lfgr, --, --, 
   {{0x7641d759,0x442862e5,0x261c08e9,0x6f0401d3}},	//   _vany, ffc_, _मारी_, zsic, 
   {{0xda7800c6,0x7641d75a,0x6f05d75b,0x53a44723}},	//   _тяғ_, _wany, ysic, замб, 
   {{0xd7c807d6,0x38940311,0x81d000eb,0x00000000}},	//   _اوشه_, jări_, হুম_, --, 
   {{0x11d80597,0x7641d75c,0x3894054e,0x00000000}},	//   صورة_, _uany, dări_, --, 
   {{0x2ee00014,0x44280010,0x45f8011a,0x00000000}},	//   wqif_, bfc_, _ההצג, --, 
   {{0x53a41feb,0x442845a7,0x7c2801f5,0x6f040112}},	//   _найб, cfc_, jfgr, tsic, 
   {{0x38940276,0xa2dc012c,0x6f04068c,0xa3e801f9}},	// [34d60] gări_, पदण्, usic, यडर_, 
   {{0x6f05d75d,0x6ffc00eb,0x00000000,0x00000000}},	//   rsic, ইলেও_, --, --, 
   {{0x8d286bfd,0x7c28002f,0xa2d403ba,0x41d8011a}},	//   соев_, ffgr, _यूट्, _לחיס, 
   {{0x3894084c,0x10a48d33,0x70540133,0x8b24004e}},	//   bări_, _химн, _تۆرا, здде, 
   {{0x387c069c,0x3894084c,0x61f4002d,0xd838003a}},	//   dhur_, cări_, _ôflû, deō_, 
   {{0xe9b4d8d1,0x46b8000d,0x67240108,0x7c28032e}},	//   мбль, _उठइह, _äiji, afgr, 
   {{0xe8200034,0x7d0002f0,0x00000000,0x00000000}},	//   _यादा_, ánst, --, --, 
   {{0x387dd75e,0x9f580421,0xd90c8198,0x4428002d}},	//   ghur_, _sesé_, شیه_, xfc_, 
   {{0x8b640aa0,0x9f580129,0x31c40154,0x00000000}},	//   _عارم, _pesé_, ্ডিশ, --, 
   {{0x6aa401c7,0xdab40137,0x81d003d4,0xcc840345}},	//   éifd, _قۇنت_, হঁত_, _بۆچه_, 
   {{0x3894084c,0x38740005,0x291800e4,0xe4040116}},	//   zări_, ñerá_, _êra_, үзүп, 
   {{0x387dd75f,0x1bf43d1d,0x00000000,0x00000000}},	//   chur_, आरएल_, --, --, 
   {{0xf76c1046,0x442801ab,0x00000000,0x00000000}},	//   _ماو_, rfc_, --, --, 
   {{0x44280327,0x4eac0154,0x38940356,0x00000000}},	//   sfc_, কগুল, vări_, --, 
   {{0x442800f3,0x7c28017a,0xd04406be,0xd6c401e2}},	//   pfc_, yfgr, _hikə, _تموی, 
   {{0x3894084c,0xc0c80220,0xa3b47aec,0xa3184130}},	//   tări_, суге_, _झडप_, _джиу_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [34d70] --, --, --, --, 
   {{0x3894084c,0x80241547,0x387c0156,0x00000000}},	//   rări_, _کردم, zhur_, --, 
   {{0x38940276,0x94f406be,0x00000000,0x00000000}},	//   sări_, _bəəs_, --, --, 
   {{0x254c0316,0x38940311,0x5bb802e8,0x9b95d760}},	//   _měl_, pări_, олея_, ولات, 
   {{0xfeb8034c,0xed6000e2,0x7c280036,0x00000000}},	//   _هاست_, āžas_, rfgr, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d347737,0x98a40124,0xd8380421,0x3e7c054e}},	//   _перф, мике, teō_, _cîte_, 
   {{0x31580302,0x01bc015b,0x4a5000fb,0xdcb0007b}},	//   ליון_, _আলাদ, екәс, _شىء_, 
   {{0xdeac0198,0x00000000,0x00000000,0x00000000}},	//   wwaƙ, --, --, --, 
   {{0x387c069c,0x7af9d761,0xf1c000d0,0xd04403b9}},	//   shur_, _iwut, úšku_, _dikə, 
   {{0xd9980491,0x3e7c07ea,0x81d003d4,0x6aa42d45}},	//   _بنات_, _gîte_, হুত_, éife, 
   {{0xd758a751,0x7af8063f,0x254c00bc,0x00000000}},	//   _ولات_, _kwut, _děl_, --, 
   {{0x7bd801f7,0x2bd00b6d,0x00000000,0x00000000}},	//   _mguu, तेपा, --, --, 
   {{0x7af801f2,0xdb08010e,0x320c002d,0xb9e40092}},	//   _mwut, _eyeç, ûdy_, _ይኸ_, 
   {{0x7bd8208d,0xd46800f3,0x00000000,0x00000000}},	//   _oguu, _мике_, --, --, 
   {{0x7bd83d27,0x7af85ac7,0x947400f2,0xb38c0092}},	//   _nguu, _owut, _زدبا, መራውን_, 
   {{0x7af802e3,0x00000000,0x00000000,0x00000000}},	// [34d80] _nwut, --, --, --, 
   {{0x7bd9d762,0xbfc19128,0xd1741367,0x00000000}},	//   _aguu, тбук, _жымы, --, 
   {{0x7af9d763,0x9045abf6,0xd1b00424,0x0c255efe}},	//   _awut, _قنده, _شیرک, дмен, 
   {{0x0bc40150,0x00000000,0x00000000,0x00000000}},	//   _ﺩﻭﺭﻫ, --, --, --, 
   {{0xaa5811eb,0x7d000413,0xfa3000d1,0x24980419}},	//   зилу_, ánsr, چرىد, érmi_, 
   {{0x7bd80083,0x752c033f,0x7af8012d,0x60c80003}},	//   _eguu, łczy, _dwut, ċeme, 
   {{0x7af9d764,0x3ab00116,0xa2b000cd,0x00000000}},	//   _ewut, тәтт, ृतत्, --, 
   {{0x807800c8,0x7bd81418,0x6a744b84,0x29180158}},	//   ַניצ, _gguu, _màfi, _åram_, 
   {{0x65c400e4,0xb9080241,0x0b440139,0xc6a407a5}},	//   _oïhí, _kojọ_, _юнан, дрни, 
   {{0xe8200073,0xa2dc090a,0x3f8c0124,0x00000000}},	//   _यावा_, पदस्, úgui_, --, 
   {{0x35140323,0xc58834d8,0x00000000,0x00000000}},	//   мжээ_, ющие_, --, --, 
   {{0x291dd41c,0xd04403e3,0x00000000,0x00000000}},	//   muva_, _tikə, --, --, 
   {{0x6a7401e1,0x291dd765,0x228c0010,0xb9080248}},	//   _aàfi, luva_, lžki_, _oojọ_, 
   {{0x257400ae,0x291c0165,0x254c0118,0x00000000}},	//   _cúlú_, ouva_, _těl_, --, 
   {{0x291dd766,0x00000000,0x00000000,0x00000000}},	//   nuva_, --, --, --, 
   {{0x7d00000f,0xc10060a1,0x9f4800e8,0xdbfc01f9}},	//   ânsm, нүүл, waañ_, _उजेड_, 
   {{0x291dd767,0x4adc0037,0x9f48002e,0x2bd000bc}},	// [34d90] huva_, _फूलव, taañ_, तेमा, 
   {{0x291dd768,0x752c0034,0x2a6d88e2,0x3f8401e4}},	//   kuva_, ńcze, _nodb_, ŝnuo_, 
   {{0x291dd39b,0x60c8003d,0xdd9000c6,0x7c840107}},	//   juva_, ċemb, دوا_, муде, 
   {{0x291dd769,0x00000000,0x00000000,0x00000000}},	//   duva_, --, --, --, 
   {{0x60cdd76a,0x9f480694,0x00000000,0x00000000}},	//   mmam, paañ_, --, --, 
   {{0x60cdd76b,0x291c0564,0x4ef8011a,0x48c00022}},	//   lmam, fuva_, _מהשו, қәха, 
   {{0x291dd76c,0x60cd5dba,0x6e3000e5,0x00000000}},	//   guva_, omam, ékbő, --, 
   {{0x60cdd76d,0x6295d76e,0x7bd8011f,0x9400016b}},	//   nmam, hizo, _uguu, nnkɔ_, 
   {{0x7af9d76f,0x60cdd770,0xe82001ad,0xf8dc00dc}},	//   _uwut, imam, _यारा_, _पूरय, 
   {{0x629401f7,0x60cc1a75,0x291dd771,0x2a6c0010}},	//   jizo, hmam, buva_, _godb_, 
   {{0x291dd772,0x6295d773,0x60cdd774,0x2b44062c}},	//   cuva_, dizo, kmam, _zsmc_, 
   {{0xe89407dd,0x60cc0030,0xb864009f,0xaa1400c7}},	//   _иахь, jmam, _تائو, vẽih, 
   {{0x60cd78ac,0x78b8012c,0x6295d775,0x7d000b21}},	//   dmam, mluv, fizo, ânsj, 
   {{0x6295d776,0x9f5807c5,0x36200014,0x60cc003e}},	//   gizo, _vesì_, _شوبہ, emam, 
   {{0xa56400c6,0xe6b404fb,0x60cc0e14,0x83600330}},	//   _لدين, _جلوگ, fmam, نگیل, 
   {{0x60cc3433,0x64988395,0x6294004c,0x7a30247e}},	//   gmam, _отыр_, aizo, lıtı, 
   {{0x91e44963,0x291c1cbd,0x78b8005b,0x6295d777}},	// [34da0] _попе, zuva_, iluv, bizo, 
   {{0x60cdd778,0x1ea81b4d,0x7a30b580,0x0d200228}},	//   amam, والي_, nıtı, лүгү, 
   {{0xe8200574,0x60cc013f,0x2b440009,0x9c940241}},	//   _याला_, bmam, _ssmc_, _ṣááj, 
   {{0x2a6dd779,0x8ba42769,0x60cdd77a,0x95b00092}},	//   _sodb_, ниеж, cmam, _ላፕቶፕ_, 
   {{0xfce0052f,0x78b9d77b,0x7a300724,0x291c00d2}},	//   _ҡоро, dluv, kıtı, wuva_, 
   {{0x291dd77c,0x2b440051,0x78b8000d,0xae4400e5}},	//   tuva_, _vsmc_, eluv, _جھرو, 
   {{0x78b83113,0x3ea000fb,0xd9b000d1,0x00000000}},	//   fluv, _сирг, لەكد, --, 
   {{0x291dd77d,0x62949afe,0x38c46215,0x2b45a1fe}},	//   ruva_, zizo, нуын_, _tsmc_, 
   {{0x291dd77e,0x6295d77f,0x86240006,0x9f480205}},	//   suva_, yizo, ньне, rbaç_, 
   {{0x291c17ad,0x6294005c,0x7a301f02,0x00000000}},	//   puva_, xizo, gıtı, --, 
   {{0x6295d780,0x60cdd781,0x89141d93,0xa2b0726b}},	//   vizo, ymam, _سبائ, ृतस्, 
   {{0x629486d2,0x38c840ec,0x363000dd,0x671813f7}},	//   wizo, _فانی_, پریس, _दिपक_, 
   {{0x9f5800e4,0x7dec01d3,0xc1880092,0x00000000}},	//   _mesã_, nősü, _አስመጪ_, --, 
   {{0x7d000225,0x3e7c00c7,0x60cc0083,0xf7bc00d1}},	//   ânsk, _oîta_, wmam, _ﮬﻪﻣﺪ, 
   {{0xc1741af6,0x60cdd782,0x417404b3,0x6d5801e3}},	//   ردست, tmam, راسس, åval, 
   {{0x6295d783,0x60cdd784,0x7d0401e1,0x0459b07f}},	//   sizo, umam, _lérá, _رجعت_, 
   {{0x60cdd785,0x9ed80107,0x00000000,0x00000000}},	// [34db0] rmam, дмат_, --, --, 
   {{0x290c009b,0x6718007d,0x62940240,0xfe7c0129}},	//   _ovda_, _दिनक_, qizo, _ouïe_, 
   {{0x60cccdfe,0x3da53989,0x00000000,0x00000000}},	//   pmam, храб, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x290d4050,0x9d200154,0x6e2c03b2,0xfbc8012d}},	//   _avda_, নবেন_, álbø, ़ेंम, 
   {{0xec680139,0x2b400200,0x6bd40116,0x00000000}},	//   дрәк_, çica_, چتۇر, --, 
   {{0x78b80162,0xabd400d1,0x00000000,0x00000000}},	//   tluv, نزۇت, --, --, 
   {{0x290c009d,0xccf00375,0x78b80108,0x00000000}},	//   _dvda_, _ככל_, uluv, --, 
   {{0x78b95a6d,0x2bd04c19,0x09b00011,0x261c000d}},	//   rluv, तेदा, টেলা, _माखी_, 
   {{0x78b9d786,0x39e8074d,0x9574013d,0xa3b4012d}},	//   sluv, _хьан_, вымч, _झड़_, 
   {{0x7a30236c,0x00000000,0x00000000,0x00000000}},	//   rıtı, --, --, --, 
   {{0x279402dd,0x49a401af,0x00000000,0x00000000}},	//   _өшір, _рыуғ, --, --, 
   {{0x0ddc0023,0xc4e402dd,0x217401d5,0x7a3003e0}},	//   _ንድፊ_, _ﺍﻟﺼﻌ, қурр, pıtı, 
   {{0x67d4e8bb,0x7a300724,0xe2806518,0x00000000}},	//   _сочу, qıtı, йғын, --, 
   {{0x412560fd,0xb9c80240,0x00000000,0x00000000}},	//   коро_, _ዲኺ_, --, --, 
   {{0x43b005db,0x386c0784,0xc950011a,0x00000000}},	//   ụrụ_, _jogr_, סמן_, --, 
   {{0x3fe003b7,0x52a8026a,0x9f5800e4,0xcfa800f2}},	// [34dc0] ржув, _овим_, _resã_, ذارم_, 
   {{0x4dd4f0a5,0x2b58012c,0x00000000,0x00000000}},	//   نتاس, _črc_, --, --, 
   {{0xa3e83ee1,0x221400a8,0x21740166,0x3e8401e1}},	//   _बलम_, _сфыр, _буяр, _sítù_, 
   {{0x0fd8007b,0x7d04032e,0x32dc0241,0x00000000}},	//   _يبحث_, _sérá, báyè_, --, 
   {{0x23bc00e5,0x7d0401ef,0x00000000,0x00000000}},	//   májú_, _pérá, --, --, 
   {{0x290c3b59,0x00000000,0x00000000,0x00000000}},	//   _pvda_, --, --, --, 
   {{0x7d50066d,0x63a81b08,0x00000000,0x00000000}},	//   _پہنچ, üenz, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbb400a52,0x6a7401ab,0x4a446484,0xa3e800c5}},	//   _кетк, _sàfu, _инав, _बलब_, 
   {{0x499418ce,0x290c01a9,0x00000000,0x00000000}},	//   _ишет, _tvda_, --, --, 
   {{0xf76ce8e1,0x0b3c02d3,0x291800e4,0x09040124}},	//   مای_, _ሓርበኛ, _íra_, _рпен, 
   {{0x7d000261,0xc7641b92,0x7dc0022e,0x9908007b}},	//   ânsi, _لاتى, mеst, _أغلق_, 
   {{0x4e20012c,0xc1e8005b,0x66140014,0x7dc0022e}},	//   मलाई_, дьбе_, _یژھا, lеst, 
   {{0x261c007d,0x9f5803b2,0x752c012d,0xfbd000d9}},	//   _माटी_, _nesá_, ńcza, יתר_, 
   {{0x6609d787,0x9f5801e1,0x00000000,0x00000000}},	//   madk, _sesà_, --, --, 
   {{0xff5c145e,0x6609d788,0x26dc01c8,0x9f4800d8}},	//   _azîa_, ladk, _hivo_, mbaú_, 
   {{0x26dc01a6,0x67200477,0x00000000,0x00000000}},	// [34dd0] _kivo_, numj, --, --, 
   {{0x66080050,0x8c8407dd,0x644dd789,0xceb40032}},	//   nadk, қәса_, _haai, гәс_, 
   {{0x644ca8ee,0x228c0118,0xed0400f1,0xfc640395}},	//   _kaai, užku_, لولپ, къдн, 
   {{0x261c05ba,0x6609d78a,0x6721d78b,0x26dc01a6}},	//   _माझी_, hadk, kumj, _livo_, 
   {{0x644dd78c,0x66083887,0x60dda30b,0x2009d78d}},	//   _maai, kadk, _iism, maai_, 
   {{0x60dc04fb,0x26ddd78e,0x20080660,0x644dd78f}},	//   _hism, _nivo_, laai_, _laai, 
   {{0x60dcaaac,0x660801d9,0x644c0093,0xceb00375}},	//   _kism, dadk, _oaai, _הים_, 
   {{0x60dd7929,0x20080069,0x26dc26bb,0x5748004e}},	//   _jism, naai_, _aivo_, езим_, 
   {{0x60ddd790,0x672001f0,0xaab80131,0x6608058a}},	//   _mism, gumj, ردۇر_, fadk, 
   {{0x60ddd791,0x26dc0bd7,0x2008dca9,0x24980076}},	//   _lism, _civo_, haai_, eism_, 
   {{0x26ddd792,0x644c0363,0x2009d793,0xb86800d8}},	//   _divo_, _baai, kaai_, _ојде_, 
   {{0x644dd794,0x2bd01fc4,0x2498014f,0x298404b4}},	//   _caai, तेवा, gism_, _тыуг, 
   {{0x66081973,0x644dd795,0x20080083,0x362001d3}},	//   badk, _daai, daai_, _نوشہ, 
   {{0x60dc002d,0x6d580158,0x66080067,0x877800df}},	//   _aism, åvak, cadk, _ראסי, 
   {{0x644c2f06,0xd9d40729,0x20087eb8,0x13a40133}},	//   _faai, _স্তম, faai_, _ڕۆحی_, 
   {{0x60ddd796,0x26ddd797,0x2009d798,0x644c00ad}},	//   _cism, _zivo_, gaai_, _gaai, 
   {{0x9d540092,0x3ea401a9,0x00000000,0x00000000}},	// [34de0] _የሚፈጽ, еnt_, --, --, 
   {{0x60dc0006,0x644c09b6,0x81d0009e,0xb1c80166}},	//   _eism, _zaai, হুই_, _аңга_, 
   {{0x67201711,0x2009d799,0x8d7400c6,0x644dd79a}},	//   zumj, baai_, داءا, _yaai, 
   {{0x81e80154,0xc198010f,0x6b840156,0x7dc0022e}},	//   মরণ_, _טשיי, ùigo, vеst, 
   {{0x7dc001a9,0x6608350e,0xe2a826a6,0x8f741cd0}},	//   fеss, yadk, _ساین_, _суні, 
   {{0xe94401b9,0x60dce2ac,0x2498007c,0x6608058a}},	//   لربی, _zism, zism_, xadk, 
   {{0x26ddd79b,0x60dc011f,0x66080ef5,0x6720014b}},	//   _rivo_, _yism, vadk, wumj, 
   {{0x26dc1a48,0x3b802cc8,0x8c44234c,0x6608058a}},	//   _sivo_, рләг, _щебе, wadk, 
   {{0x644dd79c,0x6608369d,0xf6e08e21,0x00000000}},	//   _raai, tadk, йцэн, --, 
   {{0x644cd41c,0xa535d79d,0x26dc014f,0xf220012d}},	//   _saai, аноч, _qivo_, _बाग़_, 
   {{0x66080050,0x05cc0574,0x644dd79e,0x26ddd79f}},	//   radk, हेंब, _paai, _vivo_, 
   {{0x69c9d7a0,0x644c0009,0x23784b68,0xa3d40798}},	//   _izde, _qaai, tysj_, ионч, 
   {{0x6609d7a1,0x644dd7a2,0xe6c4008c,0x46f50275}},	//   padk, _vaai, þjóð, _счет, 
   {{0x644dd7a3,0x20082ad4,0x2499d7a4,0x6d1401ad}},	//   _waai, waai_, sism_, _डिंग_, 
   {{0x2499d7a5,0x644d4252,0x2009d7a6,0x222800f2}},	//   pism_, _taai, taai_, _یزدی_, 
   {{0x60ddd7a7,0xa3e811b1,0x00000000,0x00000000}},	//   _qism, _बलि_, --, --, 
   {{0x60ddd7a8,0x2009d7a9,0x2f1811ed,0x0fe000fe}},	// [34df0] _vism, raai_, лоть_, বৰ্ধ, 
   {{0x20096d2e,0x291c07f5,0x63add7aa,0x69c9d7ab}},	//   saai_, krva_, _ixan, _ozde, 
   {{0x60ddd7ac,0x6285d7ad,0xa3e81fe5,0x2009d7ae}},	//   _tism, _ilho, _बला_, paai_, 
   {{0x628401af,0x60dc3b17,0x00000000,0x00000000}},	//   _hlho, _uism, --, --, 
   {{0x6d48006a,0x63ac025c,0x291c07de,0x69c8122b}},	//   _âdan, _jxan, erva_, _azde, 
   {{0x63ac0327,0xfaa4005b,0xee8401f4,0x00000000}},	//   _mxan, ышен, _лысо, --, 
   {{0x6285d7af,0xf2d4010f,0x00000000,0x00000000}},	//   _mlho, זעס_, --, --, 
   {{0x7d00dbd9,0x00000000,0x00000000,0x00000000}},	//   ânsu, --, --, --, 
   {{0x6285d7b0,0x63ad6af7,0x69c801c4,0x16a817a0}},	//   _olho, _nxan, _ezde, квии_, 
   {{0x7a544028,0x6b7400f7,0xab75baa5,0x9ad800ae}},	//   _حضرا, _улуу, _угуш, _شواذ_, 
   {{0x81e8015b,0x661dd7b1,0x00000000,0x00000000}},	//   মরা_, órka, --, --, 
   {{0x6285d7b2,0x752c068f,0x9f581b5d,0x9495d7b3}},	//   _alho, ńczo, _kesä_, ршоч, 
   {{0x39440142,0x966400f5,0x00000000,0x00000000}},	//   lwns_, _вкле, --, --, 
   {{0xeaa00a28,0x471800c8,0x387dd7b4,0x69c802d0}},	//   āṇi_, _יונג, lkur_, _yzde, 
   {{0x63add7b5,0x628401a2,0x3ae81700,0xd044013f}},	//   _exan, _dlho, _løp_, _sikɑ, 
   {{0x387dd7b6,0x09b002f5,0x8fa40124,0x00804530}},	//   nkur_, টেকা, аабе, олсо, 
   {{0xe3d00084,0x387c2880,0x4e05d7b7,0x00000000}},	// [34e00] _nṱha_, ikur_, изаб, --, 
   {{0xa2cc28b8,0x387c00c5,0x00000000,0x00000000}},	//   _दीप्, hkur_, --, --, 
   {{0x387c1bb0,0x8d281def,0x6aa401c7,0xb7f40027}},	//   kkur_, тоев_, éifm, ीराम_, 
   {{0xab04013d,0x00000000,0x00000000,0x00000000}},	//   _ğöbä, --, --, --, 
   {{0xdc283bea,0x63ac025c,0x00000000,0x00000000}},	//   اسمه_, _xxan, --, --, 
   {{0x291c56c0,0xec35d7b8,0x00000000,0x00000000}},	//   trva_, _گورگ, --, --, 
   {{0x7d000225,0xbeb80023,0x6e4400f1,0x8c4400d8}},	//   ânst, _eqës, _پنځم, _кеве, 
   {{0x69c9d7b9,0xec340424,0xa2cc0307,0x387c00d5}},	//   _vzde, _دورگ, _दीन्, gkur_, 
   {{0xc7c4074d,0x6aa800d8,0x478450c0,0x81e803d4}},	//   шски, _tjdf, рыйб, মৰি_, 
   {{0x291c07f5,0x65680175,0x81bc03d4,0x39440142}},	//   prva_, txdh, েশত_, bwns_, 
   {{0x69c86c85,0x387c005f,0x228c01e1,0xf67001c6}},	//   _uzde, bkur_, _lókù_, цгээ, 
   {{0xe2f80046,0xbae000db,0x6ab812e8,0x3978010f}},	//   лемі_, _اكەي, lovf, _שטאנ, 
   {{0x68e9d7ba,0x628401d4,0xbf980022,0x00000000}},	//   _hudd, _plho, _peêm, --, 
   {{0x68e9d7bb,0x273007c5,0x3d140073,0x00000000}},	//   _kudd, màn_, _पटले_, --, 
   {{0x68e81574,0x8005d7bc,0x2731d7bd,0xb59095a2}},	//   _judd, ичае, làn_, _мишш, 
   {{0x63ac05f5,0xdd40010e,0xc0c80220,0x00000000}},	//   _txan, _aňşy, туге_, --, 
   {{0x6285d7be,0x68e9d7bf,0x63ac004b,0x1e15d7c0}},	// [34e10] _tlho, _ludd, _uxan, ймая, 
   {{0x387c006c,0x68e801a4,0xb6200150,0x00000000}},	//   zkur_, _oudd, _ﯨﭗ_, --, 
   {{0xad2404a9,0x387dd7c1,0x68e9d7c2,0x61e4127b}},	//   قىلى, ykur_, _nudd, _ighl, 
   {{0x2bf40107,0x9f580108,0xc058003b,0x00000000}},	//   ояшр, _pesä_, _ріо_, --, 
   {{0x68e9d7c3,0x387c000d,0x00000000,0x00000000}},	//   _audd, vkur_, --, --, 
   {{0x68e9d7c4,0xf8dc00dc,0x1a28011b,0x9f4800ae}},	//   _budd, _पूजय, ужки_, ncaí_, 
   {{0x68e9d7c5,0xfc640354,0x00000000,0x00000000}},	//   _cudd, _къан, --, --, 
   {{0x68e881f1,0x44380589,0x7c841b15,0xc0b8001f}},	//   _dudd, _nbq_, _туге, ዲችሉ_, 
   {{0x7c39d7c6,0x387c479b,0x61e4016d,0x81bc015b}},	//   _ibur, rkur_, _oghl, েশি_, 
   {{0x387dd7c7,0x68e9d7c8,0x7cf00327,0xb348025c}},	//   skur_, _fudd, _eħre, _jaħż, 
   {{0x68e9d7c9,0xe8200574,0x7c380135,0xd6d800f7}},	//   _gudd, _याचा_, _kbur, ктү_, 
   {{0xf771d7ca,0xb4e4038e,0x4438b484,0x61e5d7cb}},	//   _واش_, _बढी_, _cbq_, _aghl, 
   {{0x7c39d7cc,0x291805ac,0x9c7c0432,0x68e800b8}},	//   _mbur, _årar_, _giōe, _zudd, 
   {{0x68e80882,0xb3480327,0x00000000,0x00000000}},	//   _yudd, _naħż, --, --, 
   {{0x7c39d7cd,0x68e83089,0x3e5c0270,0xe61001b9}},	//   _obur, _xudd, _mātē_, _آشه_, 
   {{0x61e4016d,0x2eb00073,0x9f4801e7,0x00000000}},	//   _eghl, जक्त, acaí_, --, 
   {{0x3f64504b,0x6aa401c7,0x00000000,0x00000000}},	// [34e20] бито_, éifk, --, --, 
   {{0x7c39d7ce,0x8fa4013e,0x710000e4,0x09b00011}},	//   _abur, _ҳаме, _ẽkué, টেটা, 
   {{0x8d580228,0x27300109,0xa1c001ec,0x00000000}},	//   ышат_, zàn_, _жұрд, --, 
   {{0x7c38070d,0x68e9d7cf,0x6d48006a,0xdcb80212}},	//   _cbur, _rudd, _âdam, ащі_, 
   {{0x8fd00058,0x68e9d7d0,0x7d00002d,0x00000000}},	//   _хәвә, _sudd, ânsr, --, 
   {{0x68e9d7d1,0x7c39d7d2,0xaa580f37,0x273005da}},	//   _pudd, _ebur, рику_, vàn_, 
   {{0x68e8038f,0x3eac1bce,0x2730007f,0x7a180171}},	//   _qudd, égte_, wàn_, dātē, 
   {{0x6d5c8928,0x7c380521,0xd90c5ec2,0x68e85da9}},	//   _irra, _gbur, ئین_, _vudd, 
   {{0x661dd7d3,0x68e806f2,0x00000000,0x00000000}},	//   órko, _wudd, --, --, 
   {{0x2731d7d4,0x68e9d7d5,0x7c39d7d6,0x7bcc0077}},	//   ràn_, _tudd, _zbur, _ºcur, 
   {{0x87e4495c,0xe8f005d9,0x76b40166,0x00000000}},	//   _люле, _کڻڻ_, слэр_, --, 
   {{0x27300100,0x06c801ec,0x27140051,0x872801a9}},	//   pàn_, _өгей_, ỳnh_, _бўка_, 
   {{0x6b8400a3,0x970000d1,0x00000000,0x00000000}},	//   ùigh, _قېيى, --, --, 
   {{0x6d5dd7d7,0xa5f80452,0x00000000,0x00000000}},	//   _orra, _теку_, --, --, 
   {{0x9f48007b,0xb5c001ec,0x00000000,0x00000000}},	//   rcaí_, _ﺭﺍﻓﻌ, --, --, 
   {{0x9f4800c6,0x00000000,0x00000000,0x00000000}},	//   scaí_, --, --, --, 
   {{0xd24ce109,0x6d5dd7d8,0x7c38037e,0xf28801c6}},	// [34e30] رچی_, _arra, _rbur, рөөд_, 
   {{0x7c38c1a8,0xb37802d3,0x61e4014f,0x6d5c0200}},	//   _sbur, _ይኸዉን_, _ughl, _brra, 
   {{0x2489d7d9,0x9f5801a8,0x7c38022e,0x3254009d}},	//   _klam_, _jesú_, _pbur, _эвэр, 
   {{0x71f868cf,0x4429d7da,0x6d5c0200,0x200c08a5}},	//   _پریس_, ngc_, _drra, _þei_, 
   {{0x6d5dd7db,0x20188d68,0xb348025c,0x00000000}},	//   _erra, _idsi_, _taħż, --, 
   {{0x09d0015b,0xdd94cced,0x24880142,0x00000000}},	//   াশনা, _дагы, _llam_, --, 
   {{0x6d5c08cd,0x248806f7,0x6d580158,0x769c01e1}},	//   _grra, _olam_, åvat, _láyè, 
   {{0x7c38633d,0x66180194,0xe63401c6,0x57e801b9}},	//   _ubur, _advk, үхээ, шдим_, 
   {{0x7b644ec1,0x7a18005f,0x46e401c0,0x00000000}},	//   _утве, tātē, одын_, --, 
   {{0x2489d7dc,0xddd400ef,0x00000000,0x00000000}},	//   _alam_, _nozū, --, --, 
   {{0xd0440085,0x24885dad,0x95840220,0x6720000f}},	//   _kikɔ, _blam_, ілме, armj, 
   {{0x7c29d7dd,0x2488f3e2,0x00000000,0x00000000}},	//   nggr, _clam_, --, --, 
   {{0x78b9d7de,0x2489d7df,0xf7c40eff,0x8888010f}},	//   mouv, _dlam_, _ازاپ, _דרײַ, 
   {{0xb378069c,0x2489d7e0,0x78b80316,0x2b400259}},	//   _ይኸውን_, _elam_, louv, çici_, 
   {{0xd574010a,0x3e7401ef,0x6aa40332,0x2dc801ec}},	//   _фуль, _mýtě_, éifi, _ﺩﺍﻋﻤ, 
   {{0x78b9d7e1,0x53a400d6,0x2488045a,0x90c40150}},	//   nouv, _майб, _glam_, ібае, 
   {{0x52745378,0x8e09d7e2,0x00000000,0x00000000}},	// [34e40] _дуну, инав_, --, --, 
   {{0x8d59d7e3,0x9f5801e1,0x78b8030a,0x6d5c036e}},	//   ишет_, _jesù_, houv, _prra, 
   {{0x78b80bd1,0x0d840953,0x25fc000d,0x4d480353}},	//   kouv, ўлен, ोरती_, рпен_, 
   {{0x6d5c003a,0x853800df,0x00000000,0x00000000}},	//   _vrra, יגעי, --, --, 
   {{0x0a69d7e4,0x78b8007f,0x00000000,0x00000000}},	//   ирки_, douv, --, --, 
   {{0x6d5c007f,0x44280334,0x00000000,0x00000000}},	//   _trra, zgc_, --, --, 
   {{0x6d5dd7e5,0x00000000,0x00000000,0x00000000}},	//   _urra, --, --, --, 
   {{0xa7741f5c,0x78b90454,0x5cf4009d,0xd9b08e98}},	//   злич, gouv, _хяру, رەند, 
   {{0x920819e5,0x4dec0d2e,0x64740022,0xf8940066}},	//   वराज_, _जलाई_, ҧгоу, تخوش_, 
   {{0x7b8400cf,0x2489d7e6,0x657c03cd,0x00000000}},	//   _بافە, _slam_, ørho, --, 
   {{0x2489d7e7,0x78b80af9,0x292402f0,0xc4e402dd}},	//   _plam_, bouv, ývač_, _ﺍﻟﺒﻌ, 
   {{0x78b82047,0x86740022,0x00000000,0x00000000}},	//   couv, сыҩц, --, --, 
   {{0x24881af3,0x20180077,0x6aa40036,0x00000000}},	//   _vlam_, _rdsi_, éifw, --, 
   {{0x9f589933,0x6594dd51,0x20180009,0x00000000}},	//   _gesù_, _налу, _sdsi_, --, 
   {{0x201802fa,0x7cf0038f,0x6d58003a,0x00000000}},	//   _pdsi_, _oħra, æval, --, 
   {{0x2489d7e8,0xb0540014,0x00000000,0x00000000}},	//   _ulam_, ٘پِت, --, --, 
   {{0xde54001f,0x41e5babf,0x4ac817c6,0x00000000}},	// [34e50] _የማይገ, _міна, िताव, --, 
   {{0x7cf0025c,0xefd40023,0x9b941884,0x00000000}},	//   _aħra, ራልያ_, ۋلات, --, 
   {{0x7fd402dd,0x9cf40212,0x78b96059,0x00000000}},	//   сіңі, їзді, youv, --, 
   {{0x8024030f,0x7c280165,0x00000000,0x00000000}},	//   _بردم, uggr, --, --, 
   {{0x78b80481,0xd5d002a0,0x6d5803cd,0x00000000}},	//   vouv, _हरभज, åvar, --, 
   {{0x78b8033b,0x00000000,0x00000000,0x00000000}},	//   wouv, --, --, --, 
   {{0x09e1007b,0x78b80129,0x69dc08a5,0x00000000}},	//   ношн, touv, _úrel, --, 
   {{0x60800092,0x00000000,0x00000000,0x00000000}},	//   _የወጣት_, --, --, --, 
   {{0x78b9d7e9,0xd90c00f2,0x00000000,0x00000000}},	//   rouv, ئیچ_, --, --, 
   {{0x7af9d7ea,0x78b9d7eb,0x00000000,0x00000000}},	//   _itut, souv, --, --, 
   {{0x78b80093,0xd98800fb,0x00000000,0x00000000}},	//   pouv, _ураҙ_, --, --, 
   {{0x6aa40036,0xd4140022,0x52b400cd,0x00000000}},	//   éifv, џьны, ृत्स, --, 
   {{0xdecc0023,0x92f400d4,0x00000000,0x00000000}},	//   እማን_, ячні, --, --, 
   {{0x7af801c8,0xa8b405f5,0x5fb4000d,0x320c1315}},	//   _mtut, _нөөц, _अँजल, údy_, 
   {{0xd1300597,0x45d00640,0x94080104,0x9424010a}},	//   عمر_, _пољс, _лейб_, _емйе, 
   {{0x4fe9d7ec,0x7af9d7ed,0x23b402e3,0xf8c866eb}},	//   сман_, _otut, ụja_, ातिय, 
   {{0x831405d9,0x7af80521,0x3f64011c,0x00000000}},	// [34e60] _فقير_, _ntut, пито_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc924015b,0x4278011a,0x91d800cc,0xf1c00d2e}},	//   _মন্ত_, _האיג, _ব্ৰ্, _एडिन, 
   {{0x3e800092,0x7db0072d,0x6c3800db,0x417401e2}},	//   _የጨረታ_, رمنص, تتئڭ_, _راپس, 
   {{0xe6800023,0xca6000c7,0x00000000,0x00000000}},	//   _ይገብሮ_, нҵақ, --, --, 
   {{0x9f481427,0x9f580241,0x00000000,0x00000000}},	//   mbað_, _ìyáa_, --, --, 
   {{0x7af9d7ee,0xd90c5ec2,0x98a40139,0x2bd01a04}},	//   _etut, لیل_, _arlı_, तेजा, 
   {{0xd600004d,0x0ae8004e,0x00000000,0x00000000}},	//   _đún, _гдай_, --, --, 
   {{0x3b043169,0xf7f0088c,0xe75951ee,0xc4e40220}},	//   _нето_, رسيد, ципі_, _ﺍﻟﺘﻌ, 
   {{0xbaf80302,0xc668005b,0x00000000,0x00000000}},	//   _להמש, сшие_, --, --, 
   {{0xf76c5662,0x6aa40036,0x00000000,0x00000000}},	//   نای_, éifu, --, --, 
   {{0xa8740212,0x00000000,0x00000000,0x00000000}},	//   _іллі, --, --, --, 
   {{0x7af8031c,0xf364ea23,0x00000000,0x00000000}},	//   _xtut, нтрн, --, --, 
   {{0xab040139,0x6718000d,0x00000000,0x00000000}},	//   _ğölä, _दिऔक_, --, --, 
   {{0xfdb400cc,0x7638011a,0x316800d8,0x00000000}},	//   _জণ্ড, _העוג, пшто_, --, 
   {{0xa2cc085c,0xc10001c0,0x00000000,0x00000000}},	//   _दीर्, мүүл, --, --, 
   {{0xa2b42b39,0xe2c800db,0x3438b460,0x00000000}},	// [34e70] _обич, _ووعو_, _رسيد_, --, 
   {{0xdd9001d3,0x7af9d7ef,0x00000000,0x00000000}},	//   نڈز_, _rtut, --, --, 
   {{0x7af9d7f0,0xdd904fe0,0x38d40150,0x00000000}},	//   _stut, خوا_, _ﺟﺎﯞﻛ, --, 
   {{0x9f4809e8,0x00000000,0x00000000,0x00000000}},	//   bbað_, --, --, --, 
   {{0x50a00075,0x657c0fac,0x00000000,0x00000000}},	//   _شەكل, ørhj, --, --, 
   {{0x70940023,0x7e44010a,0x00000000,0x00000000}},	//   _መለሰሉ_, _эхме, --, --, 
   {{0xaed4039b,0x00000000,0x00000000,0x00000000}},	//   _чорш, --, --, --, 
   {{0xa3ac47d0,0x64b801e4,0x6ba801d3,0x41f800cd}},	//   कपा_, lĉif, ásgá, ्रुः_, 
   {{0x7af9d7f1,0x29180162,0x91ac00cc,0x5a3401af}},	//   _utut, _æran_, _গৰাখ, _онат, 
   {{0x6aa404e6,0x00000000,0x00000000,0x00000000}},	//   éift, --, --, --, 
   {{0x2b440158,0x2dc80150,0xb8e000eb,0x00000000}},	//   _zpmc_, _ﺩﺍﻟﻤ, _এও_, --, 
   {{0x53a401c6,0x00000000,0x00000000,0x00000000}},	//   дамб, --, --, --, 
   {{0x79800368,0x7cf0025c,0x536c0023,0x7d140175}},	//   lynw, _oħro, _ስሚዒት_, hsxs, 
   {{0x6d5803b2,0x2be001f9,0x00000000,0x00000000}},	//   ævak, _फणसा, --, --, 
   {{0x2d1c03f3,0xd5d00d01,0xd0100014,0x79800142}},	//   _पटेल_, _हरिज, َلس_, nynw, 
   {{0x44b00166,0x00000000,0x00000000,0x00000000}},	//   _үбәс, --, --, --, 
   {{0x24980240,0x79800142,0xb35816d0,0x00000000}},	// [34e80] ërme_, hynw, _عیسا_, --, 
   {{0x59dc2efd,0x752c0210,0x00000000,0x00000000}},	//   मधार, ńczu, --, --, 
   {{0x661c0210,0x00000000,0x00000000,0x00000000}},	//   órki, --, --, --, 
   {{0xc170011a,0x00000000,0x00000000,0x00000000}},	//   _סחר_, --, --, --, 
   {{0x4bd8a744,0x228c00d0,0x161c01f9,0xda6401e2}},	//   آباد_, ežky_, पणार_, کاني, 
   {{0x79800368,0x693400db,0xd90c0133,0x00000000}},	//   fynw, енку, ڵیه_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd90c0edf,0x38c402dd,0xda6401ec,0x00000000}},	//   صیه_, муын_, _ۋالي, --, 
   {{0x9f48067c,0x2b440129,0x64b80115,0x6aa40036}},	//   rcaç_, _upmc_, lĉig, éifs, 
   {{0x0a8800f7,0x2ba400af,0x7980015d,0x00000000}},	//   _بئرى_, _खेया, bynw, --, 
   {{0x64b801e4,0x6d5803b2,0x00000000,0x00000000}},	//   nĉig, ævah, --, --, 
   {{0xf76dd7f2,0xf0e80208,0x00000000,0x00000000}},	//   _چاو_, _đếch_, --, --, 
   {{0xf76dd7f3,0x69c9d7f4,0xbf98017a,0x00000000}},	//   _ناو_, _hyde, _leêr, --, 
   {{0xf77c0209,0x92280135,0x52b000fb,0x05740116}},	//   äçe_, _སྐྱག_, лҡыс, _ياغد, 
   {{0x9f04021a,0x69c800b5,0x1544074d,0xf1a40798}},	//   ځورو, _jyde, _пĕрр, вртн, 
   {{0x69c8463d,0x442c01bf,0x3954011a,0x00000000}},	//   _myde, _øg_, ושלם_, --, 
   {{0x69c8c0db,0x9c7c010e,0xddd40118,0xb354004e}},	// [34e90] _lyde, _diōl, _pozů, _акыш, 
   {{0x290c0067,0x69c85848,0x00000000,0x00000000}},	//   _owda_, _oyde, --, --, 
   {{0x92282fb5,0x69c82ab7,0xddd401ef,0x00000000}},	//   _སྐྲག_, _nyde, _vozů, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8c1404fb,0x79800368,0x69c9d7f5,0xbec400ef}},	//   ريور_, wynw, _ayde, _amīš, 
   {{0x69c808d7,0x3af80356,0x79800142,0x00000000}},	//   _byde, _râpă_, tynw, --, 
   {{0x69c80142,0x228c00bc,0xceb400d1,0x224400d0}},	//   _cyde, užky_, _чәт_, ôlky_, 
   {{0x69c8072b,0x6aa40036,0x7980522d,0x2c1000cd}},	//   _dyde, éifr, rynw, ारणं_, 
   {{0x69c9d7f6,0xaca801d9,0x79800142,0x00000000}},	//   _eyde, _تھٕے_, synw, --, 
   {{0x798003a2,0x19584990,0x69c80142,0x15b801ec}},	//   pynw, _назы_, _fyde, зымы_, 
   {{0x69c801bf,0x6d480142,0x693401d5,0x41f800dc}},	//   _gyde, _âdat, _анху, ्रैः_, 
   {{0xe78800ec,0x657c8504,0x00000000,0x00000000}},	//   _ڪپهه_, ärha, --, --, 
   {{0x69c9d7f7,0x00000000,0x00000000,0x00000000}},	//   _zyde, --, --, --, 
   {{0xd174a640,0x7f5c0175,0x3580022e,0x00000000}},	//   ныбы, dvqq, _ақоб, --, 
   {{0xf00400d1,0xed800023,0x00000000,0x00000000}},	//   күни, ረክተር_, --, --, 
   {{0xa0b40640,0x9474210e,0x00000000,0x00000000}},	//   вљуј, _سدبا, --, --, 
   {{0x3cfc0989,0x7640020b,0x98a40171,0x00000000}},	// [34ea0] _čuva_, _kbny, _aplī_, --, 
   {{0xd174237e,0xa2c018cc,0x00000000,0x00000000}},	//   _зымы, लकण्, --, --, 
   {{0x9f580789,0x5cf400d4,0x60c80327,0x00000000}},	//   _besó_, вячу, ċemr, --, 
   {{0x69c9d7f8,0xfa300131,0x705403e6,0x64b80115}},	//   _ryde, ۇرىد, _جۆرا, rĉig, 
   {{0x69c82ab7,0x8060023a,0xaa5811eb,0x00000000}},	//   _syde, _свяж, дилу_, --, 
   {{0x69c9d7f9,0xdd4000a2,0x00000000,0x00000000}},	//   _pyde, _oňňy, --, --, 
   {{0x6f05d7fa,0xa2c005c0,0x00000000,0x00000000}},	//   lpic, लकत्, --, --, 
   {{0x764000ca,0xfce1d7fb,0x69c802fb,0x7cf00327}},	//   _abny, _босо, _vyde, _oħrj, 
   {{0x6f05d7fc,0x7640020b,0xdd40010e,0x69c8033f}},	//   npic, _bbny, _aňňy, _wyde, 
   {{0x6d48006a,0x6f0401ab,0xc76405a9,0xda642161}},	//   _âdas, ipic, _ۋاشى, _لامي, 
   {{0x38c9d7fd,0x2a6c005c,0x2ba41025,0xba150565}},	//   _کالی_, _indb_, _खेता, _سينا_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7640020b,0x00000000,0x00000000,0x00000000}},	//   _fbny, --, --, --, 
   {{0x6f0402fa,0x00000000,0x00000000,0x00000000}},	//   dpic, --, --, --, 
   {{0xf125d7fe,0x65944a0b,0x00000000,0x00000000}},	//   льто, _шаку, --, --, 
   {{0x6f04003a,0x30a50e16,0x26cc01f4,0xf434014b}},	//   fpic, грув, lldo_, _беъэ, 
   {{0x752c033f,0x6f040175,0x00000000,0x00000000}},	// [34eb0] ącze, gpic, --, --, 
   {{0x645c08ce,0x00000000,0x00000000,0x00000000}},	//   ldsi, --, --, --, 
   {{0x9f580789,0xa1941606,0x6f0401ab,0xedd80131}},	//   _pesó_, _ранч, apic, еһрә_, 
   {{0x645dd7ff,0x7cc4215c,0x64b800df,0x6f0402d0}},	//   ndsi, رزام, bĉie, bpic, 
   {{0x645c0192,0x2009d800,0x60cc1432,0x6f04010a}},	//   idsi, mbai_, mlam, cpic, 
   {{0xcb647696,0x6aa40036,0x20080153,0xfd101291}},	//   таше_, éifp, lbai_, _مجر_, 
   {{0x4dc40032,0x6e64234c,0xad4400cf,0xf2d4010f}},	//   _артҡ, _стяж, _مۉلۉ, װעק_, 
   {{0x60cdd801,0x2009d802,0x645c3c63,0xa9c400db}},	//   nlam, nbai_, jdsi, دۅمۉ, 
   {{0x645c3be7,0x6d480142,0x6d5803b2,0x00000000}},	//   ddsi, _âdar, ævav, --, 
   {{0x60cc0564,0x645c11ce,0xec14004b,0x20080162}},	//   hlam, edsi, _لوېد, hbai_, 
   {{0xf844009d,0x20080139,0x00000000,0x00000000}},	//   _зүйд_, kbai_, --, --, 
   {{0x6f04accc,0x20080369,0x77901079,0x60cc952a}},	//   ypic, jbai_, _میعا, jlam, 
   {{0x96b4026a,0x8c1802e4,0xa7840244,0x00000000}},	//   _искљ, וורי, _مشوو, --, 
   {{0xcb100302,0x60cdd803,0x6d48014a,0x645c6c2b}},	//   שלם_, elam, _ädag, adsi, 
   {{0xa5645713,0x79680131,0x6f040309,0x236c0115}},	//   _مدين, _ﻳﯧﯖﻰ_, wpic, ĥeja_, 
   {{0x68fc066d,0x6f043c36,0x9f580100,0x645c0009}},	//   _érde, tpic, _resò_, cdsi, 
   {{0xd9ac10f7,0xa2cc74c8,0xc0e07927,0x8fd02cc8}},	// [34ec0] टपुट, _दीक्, ротк, рәнә, 
   {{0x60cdd804,0x64b801e4,0x200800c0,0x00000000}},	//   alam, rĉie, abai_, --, 
   {{0x60cc6a2b,0x20080c09,0xc0cc02d3,0x3219d805}},	//   blam, bbai_, ባሮም_, mary_, 
   {{0x6f05d806,0x321981a6,0x00e000d1,0x21740408}},	//   ppic, lary_, _ﺋﺎﺳﺘ, _суьр, 
   {{0x61f802d2,0x80bc012d,0x00000000,0x00000000}},	//   _íalþ, वकरे, --, --, 
   {{0x3219d807,0xaa440131,0xef180354,0x00000000}},	//   nary_, انغى, ăмĕ_, --, 
   {{0xbea1d7ec,0xe9445bb8,0x645c013c,0x3ea016c0}},	//   _тарк, ارتی, ydsi, _тирг, 
   {{0x3219d808,0x7d5400c8,0x8c440046,0x6d5803b2}},	//   hary_, _בילד_, _шебе, ævau, 
   {{0x321809a5,0xb6a00208,0xe7b400db,0x0b8801e2}},	//   kary_, _trầ, دۅشد, _غضري_, 
   {{0x3ae8034c,0x321871f0,0x8cb8012d,0x657c01e3}},	//   _قبلی_, jary_, एकको, ärho, 
   {{0x648c002d,0x24541375,0x6d4801b8,0x20080024}},	//   _fûil, هندس, _ädad, ybai_, 
   {{0x60cc03be,0x38c8315b,0x645c01f5,0x97a401ec}},	//   xlam, _قانی_, udsi, _өріл, 
   {{0x645dd809,0x60cdd80a,0x3218dd8b,0xd7640150}},	//   rdsi, vlam, fary_, _مەيى_, 
   {{0x3219d80b,0xb6a0008e,0x66d401e1,0x00000000}},	//   gary_, _кичл, bàka, --, 
   {{0x60cdd80c,0x2ba400e1,0x80c40154,0xf3e400fe}},	//   tlam, _खेसा, লগস্, কুলৰ_, 
   {{0xf0b43981,0x60cdd80d,0x62946521,0x645c8186}},	//   айсь, ulam, shzo, qdsi, 
   {{0x3219d80e,0x2009d80f,0x9ed8721f,0x05c400e1}},	// [34ed0] bary_, rbai_, емат_, _रुतब, 
   {{0x60cdd810,0x2ca401c7,0x7de4215c,0x291c0037}},	//   slam, _ammd_, نسام, ksva_, 
   {{0x60cc2e00,0x00000000,0x00000000,0x00000000}},	//   plam, --, --, --, 
   {{0xaac41129,0x1b1800c9,0x60cc9158,0xec240145}},	//   یتون, ежды_, qlam, لىمپ, 
   {{0x9b4448cd,0xeb90027d,0x00000000,0x00000000}},	//   انتو, يظه_, --, --, 
   {{0xbbd009fd,0xec680b8d,0xf8c80882,0x225004cc}},	//   _तरीक, ерәк_, ात्प, nezk_, 
   {{0xdd9401ea,0x98a40408,0xca7400f7,0x6d580162}},	//   _савы, лике, امىش_, ævat, 
   {{0x3219d811,0x00000000,0x00000000,0x00000000}},	//   zary_, --, --, --, 
   {{0x279801c6,0xd63800d4,0x00000000,0x00000000}},	//   втээ_, няні_, --, --, 
   {{0x39a4010b,0x758000d1,0x6b840221,0x95742fe5}},	//   _ишев, иңла, äige, гымч, 
   {{0x3219d812,0x00000000,0x00000000,0x00000000}},	//   vary_, --, --, --, 
   {{0x321886df,0xa8a40120,0x942402dd,0xb8642e0b}},	//   wary_, _крчк, ымме, _جائو, 
   {{0x386c011c,0x61e800ac,0xe7841d39,0x8888010f}},	//   _ingr_, əmlə, _вујо, _ארײַ, 
   {{0xb604fbac,0xd1c804b3,0x9fac00fe,0x00000000}},	//   _рядк, елге_, _খৰ্গ, --, 
   {{0x3219d813,0x1545d814,0xd0d80798,0x00000000}},	//   rary_, _сейм, еќаш_, --, 
   {{0x3219d815,0x00000000,0x00000000,0x00000000}},	//   sary_, --, --, --, 
   {{0xddd40e96,0x32180209,0x9c7c00a2,0xa0740022}},	// [34ee0] _rozš, pary_, _giōi, шырш, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xcd34b23e,0xa2c00574,0x386c0175,0xe2a80451}},	//   طراب, लकर्, _ongr_, _جاين_, 
   {{0x4c1442c6,0xfce00c60,0x00000000,0x00000000}},	//   اباس, бохо, --, --, 
   {{0x41b0109c,0x9e5c0023,0x00000000,0x00000000}},	//   _نمیر, _ደጊምና_, --, --, 
   {{0xc3301203,0x291c05b8,0x386c007f,0x8c9402dd}},	//   מוד_, tsva_, _angr_, _өрбі, 
   {{0x2ca4020b,0x00000000,0x00000000,0x00000000}},	//   _tmmd_, --, --, --, 
   {{0x5ed80183,0x0708016c,0x48c003d4,0x00000000}},	//   _ভূপে, нхои_, শগ্ৰ, --, 
   {{0x6d482045,0x386c005a,0xc7c40108,0xc76400cf}},	//   _ädab, _dngr_, ыски, اابى, 
   {{0x386c0c67,0xfb1806a9,0x3b804eca,0xaca4010e}},	//   _engr_, _נובמ, _улуг, _taỳp, 
   {{0x35140323,0x0904188b,0x647527ee,0x3f5c037e}},	//   лжээ_, _спен, агну, のuv_, 
   {{0xc7646073,0x05840032,0x00000000,0x00000000}},	//   _ماتى, _ҡуйм, --, --, 
   {{0x752c033f,0x24540214,0x236c010f,0xa2c0081e}},	//   ącza, هنگس, ĥejo_, लकल्, 
   {{0xa19401c0,0x22500156,0x2bdc012d,0x00000000}},	//   аагч, uezk_, _बरना, --, 
   {{0x26dc014f,0x86c0004b,0xa0c40769,0xdce400d7}},	//   _ihvo_, _پيژن, ليسو, vzhľ, 
   {{0x2130030a,0x00000000,0x00000000,0x00000000}},	//   ruzh_, --, --, --, 
   {{0x44f9d816,0x2ba473ca,0x1f74e695,0x44380112}},	// [34ef0] _hë_, _खेला, шлая, _icq_, 
   {{0x44f9d817,0x00000000,0x00000000,0x00000000}},	//   _kë_, --, --, --, 
   {{0x44f81bce,0x7fd40220,0x23680306,0xdb1001e1}},	//   _jë_, тіңі, _hraj_, _égún, 
   {{0x44f807db,0x80d02aab,0x9f340220,0x00000000}},	//   _më_, _দূর্, _кемі, --, 
   {{0x44f9d818,0x26dc0455,0x6d59d819,0x35780092}},	//   _lë_, _ohvo_, ævar, _እመቤት_, 
   {{0x44f80151,0x2ba40574,0x1dc4008e,0x1ae401d5}},	//   _oë_, _खेळा, _көен, шолм, 
   {{0x44f92762,0x5975d81a,0x9974010b,0xa3e4041c}},	//   _në_, рылу, рулш, भेत_, 
   {{0x2368010f,0x00000000,0x00000000,0x00000000}},	//   _oraj_, --, --, --, 
   {{0x7c39d81b,0x236801d4,0x6c840597,0xe7e0007d}},	//   _icur, _nraj_, _القم, खेला_, 
   {{0x44f802d3,0x96002e05,0x00000000,0x00000000}},	//   _bë_, ोरेट_, --, --, 
   {{0xf9680032,0xadc400c7,0x7ae0009a,0x60dc02d0}},	//   _ярай_, _osẽr, mmnt, _ohsm, 
   {{0x44f9d81c,0x2368020c,0x141400fb,0xa87c010a}},	//   _dë_, _braj_, шєор, _пычĕ_, 
   {{0x236807c5,0x6605d81d,0xd6d80034,0x00000000}},	//   _craj_, _şike, atła_, --, 
   {{0x64b80115,0x00000000,0x00000000,0x00000000}},	//   rĉia, --, --, --, 
   {{0x7c39d81e,0x91e41d1c,0x44f9bacc,0x95b400fb}},	//   _ocur, рове, _gë_, _әрҙә, 
   {{0x7c3801b2,0x2369d81f,0x66040841,0x64b80115}},	//   _ncur, _fraj_, _điki, lĉin, 
   {{0x4fe8759a,0xa3e42ef1,0x60dc0100,0x44f8b608}},	// [34f00] тман_, भेद_, _dhsm, _zë_, 
   {{0x7c39d820,0x44f8025a,0x2bdc130b,0x27e00192}},	//   _acur, _yë_, _बरबा, _ùine_, 
   {{0xc278025f,0x00000000,0x00000000,0x00000000}},	//   _סרטי, --, --, --, 
   {{0x7c38009a,0x7ae002c4,0xae4401ed,0x83141079}},	//   _ccur, emnt, _گھرو, _حقیر_, 
   {{0xbb4152f0,0x7c380334,0x8f74187f,0x00000000}},	//   жечк, _dcur, _туні, --, 
   {{0x7c3814dc,0x00000000,0x00000000,0x00000000}},	//   _ecur, --, --, --, 
   {{0x7c380175,0x9db9d821,0x64b801e4,0x8274010f}},	//   _fcur, _быту_, dĉin, יעסע_, 
   {{0x7ae00218,0xc8640017,0xf86404da,0x7c3800ae}},	//   amnt, ртки, لمىي_, _gcur, 
   {{0x44f8067d,0x200403be,0x2c0c01ad,0x0ae801ec}},	//   _së_, _əli_, _ड्यू_, _адай_, 
   {{0x46684a77,0x44380077,0x6d5c01ab,0x7aa00022}},	//   трим_, _scq_, _ksra, _диуз, 
   {{0x44f807db,0x82341fcb,0x241954e1,0x443806af}},	//   _që_, یرسا, лоны_, _pcq_, 
   {{0x87e4ff02,0x44f80023,0x92b400fe,0x2368005c}},	//   _кюле, _vë_, জতো_, _praj_, 
   {{0x6d5c089c,0x9f580109,0x66c40075,0x00000000}},	//   _lsra, _jesô_, _гәнж, --, 
   {{0x44f96c72,0x236801f1,0xdb10002e,0x6720007c}},	//   _të_, _vraj_, ëgée, msmj, 
   {{0xbbd0243c,0x6d5c0134,0x425004d3,0x661802d0}},	//   _तर्क, _nsra, مۆکر, _ievk, 
   {{0x23680051,0x00000000,0x00000000,0x00000000}},	//   _traj_, --, --, --, 
   {{0x6d5dd822,0x66180218,0x00000000,0x00000000}},	// [34f10] _asra, _kevk, --, --, 
   {{0xde18866a,0x7c393cd7,0x3ea45c99,0x672002d0}},	//   اقات_, _scur, ònt_, ismj, 
   {{0x661805d1,0xb2bc011a,0x00000000,0x00000000}},	//   _mevk, _במזר, --, --, 
   {{0x6285d823,0x6618151c,0xf1b005d9,0x23b4063f}},	//   _hoho, _levk, _آءٌ_, ụju_, 
   {{0x6285d824,0x20180276,0x6d5dd825,0x67200841}},	//   _koho, _iesi_, _esra, jsmj, 
   {{0x20181125,0x6285d826,0x6720002d,0x6619d827}},	//   _hesi_, _joho, dsmj, _nevk, 
   {{0x201800b2,0x5d84007b,0x6d5c0205,0x00000000}},	//   _kesi_, _الزل, _gsra, --, 
   {{0x6ca41d0d,0x20182804,0x7c39d828,0x960022e3}},	//   _друж, _jesi_, _ucur, ोर्ट_, 
   {{0x2018f5e9,0x66180427,0xdee80b82,0x628402d0}},	//   _mesi_, _bevk, _ሄለን_, _ooho, 
   {{0x6285d829,0x2019d82a,0x66188e70,0x6d5c00ee}},	//   _noho, _lesi_, _cevk, _ysra, 
   {{0x79a501e6,0x752c0034,0xb9480092,0x64b801e4}},	//   _трае, ączo, _መርሆዎ, rĉin, 
   {{0x20199f39,0x00000000,0x00000000,0x00000000}},	//   _nesi_, --, --, --, 
   {{0x6285d82b,0x67d4074d,0x661803e0,0x387c06ea}},	//   _boho, _доцу, _fevk, mjur_, 
   {{0x6285d82c,0xcb100302,0x387c041e,0x64b80115}},	//   _coho, הלך_, ljur_, lĉil, 
   {{0x2019d82d,0x62844ea1,0x34480058,0xb9e00055}},	//   _besi_, _doho, _күни_, _pīṃ_, 
   {{0x387dd82e,0x661803ee,0x7bd81418,0xd83804fe}},	//   njur_, _zevk, _ozuu, ngō_, 
   {{0x2019d82f,0x62840109,0x7bd81418,0x7778056a}},	// [34f20] _desi_, _foho, _nzuu, nxux, 
   {{0x6d5c1509,0x387c03a2,0x201801e1,0x1fb402bf}},	//   _psra, hjur_, _eesi_, істр, 
   {{0x7bd80337,0x387c066a,0x2019d830,0x6e3c003a}},	//   _azuu, kjur_, _fesi_, _vcrb, 
   {{0x2019d831,0x6285d832,0x2bdc6407,0xfce00f06}},	//   _gesi_, _zoho, _बरदा, похо, 
   {{0x387c01e6,0x6284058a,0xddd40419,0x00000000}},	//   djur_, _yoho, _rozť, --, 
   {{0x6d5c00c6,0x20184b2a,0x69dc01ad,0xde345b0f}},	//   _tsra, _zesi_, _फरदी, _мэсь, 
   {{0x7bd804ba,0x20180f98,0x2d8c00b5,0x387c02d2}},	//   _ezuu, _yesi_, _æde_, fjur_, 
   {{0x387dd833,0x257c02d3,0x6619d834,0xf64001c0}},	//   gjur_, _ንመጻኢ_, _sevk, үхэн, 
   {{0x6619d835,0xfce005f5,0x67201e31,0x4784013d}},	//   _pevk, _хото, usmj, сыйб, 
   {{0x7d240d12,0x00000000,0x00000000,0x00000000}},	//   _ársæ, --, --, --, 
   {{0x62845956,0xda65d836,0x661806ea,0x7bd804ba}},	//   _roho, _باقي, _vevk, _zzuu, 
   {{0x6285d837,0x00000000,0x00000000,0x00000000}},	//   _soho, --, --, --, 
   {{0x62841b5c,0x2019d838,0xe2f80220,0x661803e0}},	//   _poho, _resi_, регі_, _tevk, 
   {{0xded40020,0x6285d839,0x6595d83a,0x62240116}},	//   ራችን_, _qoho, _малу, غىزل, 
   {{0x2019d83b,0x628406d9,0xa15819ba,0x35640064}},	//   _pesi_, _voho, шаву_, _грын_, 
   {{0xb9dd2762,0x20180200,0x69b00037,0xb5b4011a}},	//   _እዩ_, _qesi_, _अइनी, _ללוח_, 
   {{0x6285d83c,0x2019d83d,0x644dd83e,0xdde00210}},	// [34f30] _toho, _vesi_, _ibai, łuże, 
   {{0x4390dd36,0x4524025c,0x2019d83f,0x244c022e}},	//   _мақс, _རྗོར_, _wesi_, lоm_, 
   {{0xad242928,0x387c6032,0xf2d4011a,0x00000000}},	//   كىلى, yjur_, _מעץ_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8248069c,0x644dd840,0x9038008f,0x00000000}},	//   _ምምሕዳ, _mbai, _דערה, --, 
   {{0x198801d5,0x00000000,0x00000000,0x00000000}},	//   ибли_, --, --, --, 
   {{0x644c50c2,0x09e00261,0x20dc01ad,0x2c100073}},	//   _obai, мошн, _मठाध, ारखं_, 
   {{0x4524025c,0x7c940150,0x644c00a3,0x2d0401c4}},	//   _རྗེར_, _اشسا, _nbai, _хярг, 
   {{0x6604fccc,0x64b800c8,0xe7080133,0x7bd80205}},	//   _şika, rĉil, یتین_, _uzuu, 
   {{0x644dd841,0x7af80280,0x16a80107,0x387c0fc7}},	//   _abai, _iuut, рвои_, sjur_, 
   {{0x7af8049b,0x25a003f9,0x00000000,0x00000000}},	//   _huut, _ƙila_, --, --, 
   {{0x644c01ab,0x93440150,0x00000000,0x00000000}},	//   _cbai, онме, --, --, 
   {{0x7af9d842,0xa3e4202e,0x43900006,0x00000000}},	//   _juut, भेल_, даўс, --, 
   {{0x7af83859,0x644c0428,0xf6e411e5,0x2bdc52be}},	//   _muut, _ebai, _уцен, _बरसा, 
   {{0xff5c006a,0x6ef00248,0xb404004e,0x00000000}},	//   _asî_, _lóbì, _нүнд, --, 
   {{0x644c00a3,0xe7e0012c,0xa5d800f2,0x00000000}},	//   _gbai, खेका_, _ابهر_, --, 
   {{0x7af9d843,0x0ea9d844,0xa3b0134e,0xb9dc0092}},	// [34f40] _nuut, акай_, _टेप_, _እጩ_, 
   {{0xbc6801ed,0xd17400ee,0xcdd40063,0xd1b800f2}},	//   یجنے_, _дымы, оцењ, _ناجا_, 
   {{0x91e5d845,0xbfa0004d,0x00000000,0x00000000}},	//   _фоне, _hiể, --, --, 
   {{0x7af9d846,0x0b883c18,0xbfa0004d,0x14c8078a}},	//   _buut, исли_, _kiể, रविण, 
   {{0x249802d3,0x921c4da4,0xfafc00b8,0x00000000}},	//   ërmi_, _बजाज_, _śūre_, --, 
   {{0x752c068f,0x7af8198f,0x60c80427,0x09046193}},	//   ńczy, _duut, čeme, очим, 
   {{0x98a4083c,0xfaa006ed,0x14c801bc,0xa3b004aa}},	//   _aslı_, ќајо, रवाण, _टेन_, 
   {{0xd90dd847,0x7af9d848,0x6ef00241,0x3a2004b4}},	//   این_, _fuut, _fóbì, пмәг, 
   {{0x7af80a4d,0x644c0332,0x8b64103f,0x3b04034f}},	//   _guut, _rbai, _بازم, _мето_, 
   {{0x09e410f3,0x644c0268,0x05e83f07,0xe7e0033f}},	//   _дозн, _sbai, ифни_, खेगा_, 
   {{0x7af80036,0x3df8010f,0x36840395,0xa4d400d4}},	//   _zuut, יליד, юсън_, зоні, 
   {{0x7af8037e,0xbfa0004d,0x98c40150,0xded40092}},	//   _yuut, _biể, _есіл, ራችና_, 
   {{0x970004a9,0x443c00da,0x7af80009,0x00000000}},	//   _كېيى, ļu_, _xuut, --, 
   {{0x443c766d,0x00000000,0x00000000,0x00000000}},	//   żu_, --, --, --, 
   {{0x26cdd849,0x65943e25,0xc4c42d8d,0x3169d84a}},	//   modo_, _хайу, _وتبو, ошто_, 
   {{0xd5b800d6,0x644dd84b,0x26cdd84c,0x212c09a8}},	//   _усі_, _ubai, lodo_, čeh_, 
   {{0x4ac81a4e,0xbdf847e7,0xf288009d,0xe4d80066}},	// [34f50] ाकाव, لرضا_, сөөд_, _پوکت_, 
   {{0x7af805a7,0xb378044e,0x26cc6a89,0x7d69d84d}},	//   _ruut, _ክኸዉን_, nodo_, ишев_, 
   {{0x7af9d84e,0x6d4801b8,0x00000000,0x00000000}},	//   _suut, _ädal, --, --, 
   {{0x62940cf9,0x7af80d77,0x26cc0117,0x5f809c97}},	//   lkzo, _puut, hodo_, _كۇزە, 
   {{0x60cc0588,0x26cdd84f,0x7af80067,0x9078011a}},	//   moam, kodo_, _quut, _הטרי, 
   {{0x24880072,0x4ef80375,0xaf3403e6,0x7ce000c5}},	//   _loam_, _להשו, _کرێت, kõrg, 
   {{0x26cc08e7,0x682002e3,0x7af81574,0x752c033f}},	//   dodo_, _ịdab, _wuut, ączk, 
   {{0x60cc0615,0x7af9d850,0x2489d851,0x31bc0a1e}},	//   noam, _tuut, _noam_, יזונ, 
   {{0x26cc01e4,0x00000000,0x00000000,0x00000000}},	//   fodo_, --, --, --, 
   {{0x60cdd852,0x1a6416d0,0x00000000,0x00000000}},	//   hoam, _ریبی_, --, --, 
   {{0x60cdd853,0xd469b785,0x86200ee8,0x65c001ec}},	//   koam, бине_, رکول, кұша, 
   {{0x60cc005b,0x273000f7,0x00000000,0x00000000}},	//   joam, رۉۉس, --, --, 
   {{0x80c4015b,0x60cc00d8,0x3945d854,0x28b04709}},	//   লগঞ্, doam, ltns_, _जगति, 
   {{0xb378069c,0x26cdd855,0x61ac00cc,0x53800023}},	//   _ክኸውን_, codo_, _গড়আ, _ንኸይድ_, 
   {{0x2489d856,0xfec0009e,0x00000000,0x00000000}},	//   _foam_, ্গাধ, --, --, 
   {{0x78b9d857,0xbf9800d8,0x60cc01c4,0xbfa00208}},	//   nnuv, _efêm, goam, _tiể, 
   {{0xded40023,0xc438011a,0x78b80108,0x00000000}},	// [34f60] ራጽን_, _התפי, inuv, --, 
   {{0x1ea88b4d,0x24880109,0xd4f401af,0x00000000}},	//   يالي_, _zoam_, _ьяһы, --, 
   {{0x60cdd858,0x4d480220,0x81f8011a,0x00000000}},	//   boam, спен_, _להיז, --, 
   {{0x60cdd859,0x26cc010f,0x35800023,0xfc0001af}},	//   coam, zodo_, ይልታት_, епцо, 
   {{0x39440171,0x00000000,0x00000000,0x00000000}},	//   etns_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x26cdd85a,0xd9b00075,0xda6443b9,0xfe9808a8}},	//   vodo_, پەند, باني, _פילמ, 
   {{0x7ce000af,0x3da401c6,0x28cc0b98,0x00000000}},	//   võrg, _эксо_, ावधि, --, 
   {{0x2488bed5,0x00000000,0x00000000,0x00000000}},	//   _roam_, --, --, --, 
   {{0x60cdd85b,0xda64007b,0x7ce00254,0x00000000}},	//   zoam, _يالي, tõrg, --, 
   {{0xb521d85c,0x26cdd85d,0x60cd5140,0x35b00276}},	//   ньяк, rodo_, yoam, ебэр, 
   {{0x26cdd85e,0x7d180210,0x00000000,0x00000000}},	//   sodo_, _łusk, --, --, 
   {{0x24888ab9,0x60cdd85f,0x26cc0115,0x91d00cb2}},	//   _voam_, voam, podo_, _दुबई, 
   {{0x60cc0083,0x26cc058a,0xaadc08df,0x7ce00037}},	//   woam, qodo_, यतिक, põrg, 
   {{0x60cdd860,0x629584f2,0x8c4403e3,0x35d00108}},	//   toam, rkzo, _elşə, _пошё, 
   {{0x629401e3,0xe0d800d4,0x00000000,0x00000000}},	//   skzo, ідач_, --, --, 
   {{0x60ccb11f,0x290dd861,0x6d4801b8,0xaadc0864}},	// [34f70] roam, _ltda_, _ädaj, यताक, 
   {{0x60cdd862,0x290c485b,0x00000000,0x00000000}},	//   soam, _otda_, --, --, 
   {{0x60cdd863,0xe0d001d9,0xdea068be,0xf42000fe}},	//   poam, _لٲد_, _ییری, _ভাতৰ_, 
   {{0x660400fd,0x00000000,0x00000000,0x00000000}},	//   _şikl, --, --, --, 
   {{0x290c7e8b,0x7ce000c5,0x78b80162,0x00000000}},	//   _atda_, võrd, vnuv, --, 
   {{0x98a80010,0x00000000,0x00000000,0x00000000}},	//   čač_, --, --, --, 
   {{0x3eb02963,0x00000000,0x00000000,0x00000000}},	//   mixt_, --, --, --, 
   {{0xd709d864,0x607c0023,0x78b801f4,0xa9c40228}},	//   оние_, _ኣረጊት_, unuv, رۅنۉ, 
   {{0x78b9d865,0x7e65d866,0x290c00a2,0x3ab001ec}},	//   rnuv, _kajp, _etda_, _пәкт, 
   {{0xfaf0007b,0x78b8007c,0x68e40327,0x00000000}},	//   _أثر_, snuv, ċida, --, 
   {{0xd6d811ca,0xe89800e5,0x00000000,0x00000000}},	//   йтү_, زمیں_, --, --, 
   {{0x7e643733,0x52c4150d,0x00000000,0x00000000}},	//   _lajp, लक्स, --, --, 
   {{0xd62810fc,0xd7c8315b,0x66281427,0x00000000}},	//   _доле_, _بوشه_, áskú, --, 
   {{0x7e65d867,0x62c00184,0x59e002ab,0xd1756f07}},	//   _najp, лҡыб, _फरार, мыбы, 
   {{0x98e0012c,0x00000000,0x00000000,0x00000000}},	//   _पठाए, --, --, --, 
   {{0x657c00fe,0xd54800ec,0x55c401af,0xba040092}},	//   århe, _هلڪو_, _наҙғ, _ሊጉ_, 
   {{0x7e640455,0x0440084c,0x246400f1,0x3eb028dc}},	// [34f80] _bajp, _реын, _سايټ, fixt_, 
   {{0xb8dc0003,0x69dd22c5,0x66d40241,0x00000000}},	//   _གམ_, _øreg, bàku, --, 
   {{0x10a401d5,0xa2ac09b2,0x00000000,0x00000000}},	//   _жинн, ुचर्, --, --, 
   {{0x290c00ca,0x68fc003e,0x00000000,0x00000000}},	//   _rtda_, _érdi, --, --, 
   {{0xe68002d3,0x00000000,0x00000000,0x00000000}},	//   _ክገብሮ_, --, --, --, 
   {{0x7ce00254,0x00000000,0x00000000,0x00000000}},	//   võre, --, --, --, 
   {{0xd90dbb12,0x2f0404f3,0x6f040227,0x38c00153}},	//   میل_, _hög_, lqic, kūrę_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xec186ba3,0x2ef80208,0x38c000c0,0x00000000}},	//   _меңә_, _kirf_, dūrę_, --, 
   {{0x7ce000e4,0x00000000,0x00000000,0x00000000}},	//   rõre, --, --, --, 
   {{0xf76c1060,0x2f04008c,0x276804fb,0x65940479}},	//   های_, _lög_, زشکی_, хану, 
   {{0xc7640075,0x1bf400af,0x00000000,0x00000000}},	//   _ياشى, ुँचल_, --, --, 
   {{0x499000dd,0x38c9d868,0x98340006,0x00000000}},	//   _سیکر, _بالی_, _чэхі, --, 
   {{0x7d009559,0x3f8c022c,0xddd40306,0x28cc00cd}},	//   ínsk, øgum_, _rozž, ाववि, 
   {{0x69dc00d4,0x4ab4000d,0x38c00064,0x7638011a}},	//   _øred, _अगनव, būrę_, _ועוג, 
   {{0x2f0401e3,0x850001c4,0x00000000,0x00000000}},	//   _bög_, _пүүз, --, --, 
   {{0xadc401e1,0x7e65d869,0x23b400f1,0xc508009f}},	// [34f90] _ipẹr, _pajp, _سمدس, _اتڪل_, 
   {{0x645dd86a,0xf3fc031c,0x00000000,0x00000000}},	//   lesi, _དཔོད_, --, --, 
   {{0x7e65187c,0x2ef801c7,0x91c00075,0x645c01f4}},	//   _vajp, _dirf_, _бәтл, oesi, 
   {{0x2f057497,0x7e640113,0x7c645285,0x21a801ee}},	//   _fög_, _wajp, بائل, _дәғү_, 
   {{0x7e65d86b,0xe0d001d9,0x92b003d4,0xeb9800d4}},	//   _tajp, _لٲگ_, টকৰ_, миї_, 
   {{0x429c02d3,0x00000000,0x00000000,0x00000000}},	//   _ግዝኣት_, --, --, --, 
   {{0xacf40372,0x20080332,0x19c400c7,0x00000000}},	//   رسۅت, ocai_, хәаг, --, 
   {{0x645dd86c,0x2009d86d,0xe8e83e45,0x8f6400db}},	//   jesi, ncai_, وريو_, _زۅۅك_, 
   {{0x59e02aa1,0xfbd03413,0x5b3400e5,0x00000000}},	//   _फरवर, _شتر_, _سٹار, --, 
   {{0xba75d86e,0x46e53acc,0xadc40cad,0x2008003e}},	//   _تارت, ндын_, _apẹr, hcai_, 
   {{0xd468288a,0x35c001f0,0x95541291,0x00000000}},	//   пине_, танҳ, رخدا, --, 
   {{0x59280135,0xd4683e07,0x53a400f3,0x959401ec}},	//   _ལྷགས_, чиме_, еамб, _үшкі, 
   {{0x56940953,0x4ab400bc,0xcc38010f,0x00000000}},	//   _падт, _अगमव, הערט, --, 
   {{0xa76402bf,0x6b840036,0x628001e3,0x1b2000cc}},	//   _шкід, äigi, ölop, _নমাই_, 
   {{0x2bdc6bcf,0x2f04c9df,0x11d800ae,0x00000000}},	//   _बर्थ, _sög_, سورة_, --, 
   {{0x645dd86f,0x2ef80205,0x0440030d,0x6f0401d5}},	//   cesi, _sirf_, _беън, tqic, 
   {{0x43700592,0x7e9401d5,0x00000000,0x00000000}},	// [34fa0] _مهير, کنلر_, --, --, 
   {{0x69b000af,0xd05c03b9,0x00000000,0x00000000}},	//   _अइली, _əyər, --, --, 
   {{0x6f0407d6,0x3219d870,0x9c7c003e,0x70e81086}},	//   sqic, mbry_, _chōo, _огоҳ_, 
   {{0x200807de,0x61e03e0f,0x83e8002e,0xcb442d1f}},	//   ccai_, ülle, _mbёn, ехки, 
   {{0xe2a9d871,0xfce002d3,0x941c013f,0xc050011a}},	//   _راین_, _ዝወጸ_, ɑtɔ_, _גזר_, 
   {{0x645dd872,0x00000000,0x00000000,0x00000000}},	//   zesi, --, --, --, 
   {{0x645dd873,0xddd40024,0x28cc00cd,0x00000000}},	//   yesi, _аўтэ, ावलि, --, 
   {{0xd90da2b3,0x645c0472,0xbf6001d3,0x64b8008f}},	//   زیه_, xesi, _جگہو, nĉit, 
   {{0xb9042413,0x952c0135,0x6d5001a6,0x4aa8022e}},	//   _मी_, ྩེའི_, ždač, _екан_, 
   {{0xfce002d3,0x00000000,0x00000000,0x00000000}},	//   _ዝወጹ_, --, --, --, 
   {{0x645dd874,0x09340472,0x795000e3,0x3218007c}},	//   tesi, _سراج, _مَلا, dbry_, 
   {{0xf29c001f,0x5894009b,0x00000000,0x00000000}},	//   _ግምገማ_, _ишчу, --, --, 
   {{0xf76c1c93,0x200801d4,0x69dc072b,0x38c9d875}},	//   _هاو_, vcai_, _øreb, _عامی_, 
   {{0x3ce402e5,0x066401ec,0xf770010f,0xa1581d0b}},	//   _छीने_, _ساتپ, _תקס_, магу_, 
   {{0x645dd876,0xddd401e4,0xe0440124,0x00000000}},	//   pesi, _bazŝ, кьаҿ, --, 
   {{0x645c02d3,0x18380092,0xf0d4009d,0x00000000}},	//   qesi, _በቀድሞ, гжсэ, --, 
   {{0x200804cc,0x00000000,0x00000000,0x00000000}},	// [34fb0] rcai_, --, --, --, 
   {{0x3f841591,0x20080356,0x00000000,0x00000000}},	//   ćnu_, scai_, --, --, 
   {{0x20080ac5,0x64b801e4,0x00000000,0x00000000}},	//   pcai_, sĉiu, --, --, 
   {{0x2bdc069f,0x7c640150,0x61e40427,0xd114011a}},	//   _बरखा, عاال, _izhl, _שקרה_, 
   {{0x50a00131,0x00000000,0x00000000,0x00000000}},	//   _ئەقل, --, --, --, 
   {{0xfaa40276,0x00000000,0x00000000,0x00000000}},	//   эшен, --, --, --, 
   {{0xceb5d877,0xe0c4009e,0x76a401e1,0x00000000}},	//   _рәт_, ্ষীন, _léyù, --, 
   {{0xb17c0bd9,0x6fa80154,0x00000000,0x00000000}},	//   לטור, _কুয়ে, --, --, 
   {{0x81d41d4c,0x69c80fac,0x1a64036b,0x1af400c0}},	//   িধি_, _exde, _لیشی_, _апая, 
   {{0x79a5d878,0x2d9c0158,0x15b800ee,0xd91400c0}},	//   _прее, øveg_, дымы_, _аджы, 
   {{0x7bd8020b,0x00000000,0x00000000,0x00000000}},	//   _hyuu, --, --, --, 
   {{0x7bd9d879,0x3a2400f3,0x657c050a,0x00000000}},	//   _kyuu, lanp_, årha, --, 
   {{0xccf000c8,0x6d48014a,0x9664010b,0x00000000}},	//   יכט_, _ädav, _акле, --, 
   {{0x64400006,0x00000000,0x00000000,0x00000000}},	//   ėlia, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3a240280,0x92b00eac,0x00000000,0x00000000}},	//   hanp_, টকে_, --, --, 
   {{0x7bd9d87a,0x3a240100,0x64b800df,0x660403e0}},	// [34fc0] _nyuu, kanp_, rĉit, _şiki, 
   {{0xbea00022,0x00000000,0x00000000,0x00000000}},	//   ааук, --, --, --, 
   {{0x2d9c01a2,0x7bd9d87b,0x90c40153,0x0c2401f4}},	//   áve_, _ayuu, _абне, вмен, 
   {{0x7bd866bd,0x2ca000c6,0x00000000,0x00000000}},	//   _byuu, óid_, --, --, 
   {{0x0ae9d87c,0x2d9c245e,0xbec000de,0x09c88109}},	//   ورتي_, šve_, _ķīvi, िथ्य, 
   {{0x63880023,0xdb1001ed,0x61e800bc,0x8e380b24}},	//   _hënë, ágáb, řele, _تسحر_, 
   {{0x7bd804ba,0x5ec401d5,0x00000000,0x00000000}},	//   _eyuu, _сирғ, --, --, 
   {{0x07080107,0x7ce00037,0x00000000,0x00000000}},	//   мхои_, põra, --, --, 
   {{0x3a240083,0xc6a401d5,0x37a4009d,0x47840139}},	//   banp_, врни, втэн_, тыйб, 
   {{0x4de4033f,0xda640b24,0x6b840037,0x00000000}},	//   _कराई_, _مامي, äigu, --, 
   {{0xe5b5d87d,0x00000000,0x00000000,0x00000000}},	//   уйны, --, --, --, 
   {{0x79b4025f,0x35b04e0c,0x638802d3,0x00000000}},	//   _בלבד_, рбюр, _nënë, --, 
   {{0xf7400212,0x2b4001c3,0x27e008ce,0x4ab428fe}},	//   _вечо, àich_, _áin_, _अगाव, 
   {{0xf2c5a32c,0x06b40014,0xded4001f,0x069400ec}},	//   ассн, _جنتک_, ያችን_, _ڳاڙھ, 
   {{0xf56400f7,0x35659664,0x854400c0,0x00000000}},	//   _ашык_, _арын_, _рэле, --, 
   {{0x3a2445b4,0xc1000323,0x30a5d87e,0x61e40316}},	//   zanp_, лүүл, арув, _vzhl, 
   {{0x6ab82d75,0x1f75d87f,0x3a2402e2,0x91c001e0}},	// [34fd0] kivf, ылая, yanp_, _ғәрл, 
   {{0x9e95d880,0x3a2407ab,0x7bd804ce,0x236801e4}},	//   دارچ, xanp_, _ryuu, _isaj_, 
   {{0xad240075,0xa195d881,0xb9080241,0x7bd804ce}},	//   لىلى, _санч, _dajọ_, _syuu, 
   {{0x638800e8,0x23680240,0x19c400c7,0x00000000}},	//   _gënë, _ksaj_, қәзг, --, 
   {{0x6f840137,0x3a240100,0x00000000,0x00000000}},	//   _курж, tanp_, --, --, 
   {{0xad4400cf,0xd6d80210,0x00000000,0x00000000}},	//   _چۉلۉ, kuła_, --, --, 
   {{0x79a40801,0x00000000,0x00000000,0x00000000}},	//   ърде, --, --, --, 
   {{0x7bd8037e,0x8c6402dd,0x3a24007f,0xe9d000d1}},	//   _tyuu, _مەمل_, sanp_, ڭغۇ_, 
   {{0xdb080793,0xfbb4448b,0x00000000,0x00000000}},	//   änäd, _अधिम, --, --, 
   {{0x33200007,0x2120003e,0x55880414,0x06c418bc}},	//   _rwix_, _owhh_, ебом_, лгый_, 
   {{0x33200007,0x2368044e,0x69c40276,0x6d4801b8}},	//   _swix_, _asaj_, şier, _ädat, 
   {{0x757c0023,0xd77400ae,0x00000000,0x00000000}},	//   _ንዘለዎ_, _ماتع, --, --, 
   {{0x236801ed,0xa784072d,0x6388036e,0xbb180150}},	//   _csaj_, _نشوو, _rënë, _ﺴﺩﻯ_, 
   {{0xadc400e4,0xe0e002f5,0x1544c45c,0xd6d8012d}},	//   _apẽr, _মূলভ, _бекм, buła_, 
   {{0x42e4016c,0x236803e0,0x00000000,0x00000000}},	//   умро_, _esaj_, --, --, 
   {{0x92b40154,0x7ce00254,0x61e0000d,0x00000000}},	//   ড়তে_, dõro, ülla, --, 
   {{0xc0e0cadc,0x8fd001e0,0xd394586a,0x00000000}},	// [34fe0] сотк, сәнә, _сәнә_, --, 
   {{0x11d400c6,0x7e200212,0xdb1001e1,0x831800df}},	//   _متجد, йдуж, _ègùn, _רויז, 
   {{0x6388006a,0xd17439fb,0x8d640020,0x3d2804fb}},	//   _tënë, _сыпы, _ታውቋል_, فتنی_, 
   {{0x6adc146b,0x61e80118,0x8fa4014b,0x83d0000d}},	//   यत्र, řelc, _баме, _धुँआ, 
   {{0xba700133,0x00000000,0x00000000,0x00000000}},	//   ڵاوت, --, --, --, 
   {{0xaa582c9d,0x2a6c0548,0xb9e0002b,0x00000000}},	//   тику_, _qadb_, _hūṃ_, --, 
   {{0x2a6c0010,0x6934f729,0x6ab9bd3e,0x00000000}},	//   _vadb_, شکار, rivf, --, 
   {{0x38c48443,0x6d5dd882,0x4789146e,0x068000d1}},	//   луын_, _ipra, есом_, _ﺩﯦﻴﯩ, 
   {{0x7c900491,0x8624a3ea,0x00000000,0x00000000}},	//   _القص, льне, --, --, 
   {{0x26d8145e,0x66b400c7,0x05b006ff,0x00000000}},	//   ôro_, рбоу, ुपलब, --, 
   {{0x76b40139,0x00000000,0x00000000,0x00000000}},	//   улэр_, --, --, --, 
   {{0x236800f3,0xe374026f,0xa4d40212,0x81b801e1}},	//   _psaj_, алмы, ромі, _nìyẹ, 
   {{0x4ccc0154,0x00000000,0x00000000,0x00000000}},	//   ়তপু, --, --, --, 
   {{0x6d5c8be0,0x23680fb7,0x6b340023,0x91d4033f}},	//   _opra, _vsaj_, _ኣይተኻ, _मुहै, 
   {{0x6d5c1529,0x00000000,0x00000000,0x00000000}},	//   _npra, --, --, --, 
   {{0x23680211,0xd34403e6,0x00000000,0x00000000}},	//   _tsaj_, دییه_, --, --, 
   {{0x2369d883,0xd9e00412,0x00000000,0x00000000}},	// [34ff0] _usaj_, _फर्ट, --, --, 
   {{0x6d5c00ae,0x00000000,0x00000000,0x00000000}},	//   _bpra, --, --, --, 
   {{0x6d5cad11,0x1a6400f2,0x00000000,0x00000000}},	//   _cpra, ییری_, --, --, 
   {{0xf1a450c0,0xb1a40166,0x00000000,0x00000000}},	//   _ырын, _ышык, --, --, 
   {{0x6d5c127b,0x442800c7,0xdb84022e,0x00000000}},	//   _epra, iac_, ргли, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4429d884,0xdd940724,0x2ca4000f,0x8df8014b}},	//   kac_, _тавы, _flmd_, _амрӣ_, 
   {{0xacf801c0,0x6db40139,0x961c03ce,0x00000000}},	//   _бнсу_, _уйсу, फर्ट_, --, 
   {{0x7c29d885,0x6d5c0316,0x69dc20e4,0x7d040427}},	//   magr, _zpra, _øren, _hujs, 
   {{0x7c29d886,0x55f4034b,0xbeb80200,0x00000000}},	//   lagr, ичну, _zvër, --, 
   {{0x4429d887,0xd5e40212,0x83e00220,0x55e41b94}},	//   fac_, ржни, _ﺍﺭﺍﺳ, ронб, 
   {{0x49a4052f,0x44280050,0xe97002dd,0x32f000a2}},	//   _тыуғ, gac_, _ءۇيد, _ańyp_, 
   {{0x78b80d04,0x213c00b0,0x00000000,0x00000000}},	//   miuv, _āwha_, --, --, 
   {{0x44280334,0x386c5e59,0xc7a0005b,0x78b9d888}},	//   aac_, _hagr_, _фишк, liuv, 
   {{0x7c29d889,0x154401e0,0x3fe0000d,0x00000000}},	//   kagr, _тейм, _खरउआ_, --, 
   {{0x4428074d,0xa3b056e9,0x661c03ee,0x78b9d88a}},	//   cac_, _टेक_, ırke, niuv, 
  
   {{0x6d5d9d72,0x7c29d88b,0xb4c4590f,0x75200369}},	// [35000] _spra, dagr, ्वी_, _hwnz, 
   {{0x7d05d88c,0x7054168d,0x6d5c031c,0x68e40135}},	//   _bujs, _گۆرا, _ppra, ċidi, 
   {{0x7c286a47,0x4d480220,0x78b80194,0xcd340330}},	//   fagr, тпен_, kiuv, شراب, 
   {{0x6d5c0f72,0x7c29d88d,0xfce03e29,0xfbb4009e}},	//   _vpra, gagr, оохо, _জড়ত, 
   {{0x78b80395,0x6d5c033f,0x620401d3,0x8e84010a}},	//   diuv, _wpra, _átlá, _вăлч, 
   {{0x4429d88e,0xab60001f,0xba14007b,0x8e7400db}},	//   zac_, _ሰውየው_, ليها_, _тумч, 
   {{0xc9842e2d,0x4429d88f,0x78b80140,0x5d74020a}},	//   рули, yac_, fiuv, _лутф, 
   {{0x2d6854ee,0x4429b1ba,0x7c285867,0x3cfc07de}},	//   _işe_, xac_, cagr, _giuv_, 
   {{0x44280bb8,0x0c8401ee,0x00000000,0x00000000}},	//   vac_, _йыҡм, --, --, 
   {{0x4429d890,0x386c0332,0x64400153,0xd1e80092}},	//   wac_, _eagr_, ėlim, ሙርት_, 
   {{0x4429d891,0x3685d892,0x5e78010f,0xc7640b38}},	//   tac_, рсын_, אָרד, _چاتى, 
   {{0x08f9393e,0x78b819f5,0xc7640617,0x00000000}},	//   _شراب_, ciuv, _ناتى, --, 
   {{0xbf980261,0x86e401d5,0x9fe000cc,0x00000000}},	//   _agên, _кўкд, _ভল্গ, --, 
   {{0x7c29d893,0xbeb800e8,0xa5c4013d,0x00000000}},	//   zagr, _awën, _гөме, --, 
   {{0x75200097,0x7c29d894,0xa0c4009a,0xdce400d7}},	//   _gwnz, yagr, ميسو, vyhľ, 
   {{0xf48407d5,0x44280009,0x00000000,0x00000000}},	//   _дуьн, qac_, --, --, 
   {{0x7c29d895,0x644c00ca,0x83b80037,0x00000000}},	// [35010] vagr, _icai, _उधिआ, --, 
   {{0xa2601772,0xf404031c,0x7d040219,0x00000000}},	//   _ስምኦን_, _ཚོུད_, _pujs, --, 
   {{0x78b80d04,0x7fd40220,0x7ce000c5,0xfd44084c}},	//   yiuv, уіңі, sõrm, рэзн, 
   {{0x5b3402c9,0x00000000,0x00000000,0x00000000}},	//   معتر, --, --, --, 
   {{0x7c29d896,0xa3dc068f,0x78b94764,0x2d680724}},	//   ragr, _तुम_, viuv, _eşe_, 
   {{0x3e540316,0x7c29d897,0xbbb452be,0x7d040010}},	//   _dětí_, sagr, _अधीक, _tujs, 
   {{0x78b8f4d1,0x7c29d898,0x6d3401af,0x644c035a}},	//   tiuv, pagr, _мерф, _ocai, 
   {{0x26dc00c8,0x644c0070,0xefd40092,0x00000000}},	//   _akvo_, _ncai, ያግዝ_, --, 
   {{0x78b97df9,0x00000000,0x00000000,0x00000000}},	//   riuv, --, --, --, 
   {{0x644dd899,0x78b9d89a,0x204c0023,0xab600092}},	//   _acai, siuv, _ዝጽበየ, _ሰውዬው_, 
   {{0x60dc0254,0x00000000,0x00000000,0x00000000}},	//   _oksm, --, --, --, 
   {{0xb4c45444,0x75200097,0x644dd89b,0x69c408dd}},	//   ्वे_, _vwnz, _ccai, िपरी, 
   {{0x7ce000c5,0xd39400fb,0x00000000,0x00000000}},	//   tõrj, сәйә_, --, --, 
   {{0x644c02ea,0x69e40022,0x60dc0790,0xbb340023}},	//   _ecai, _êteé, _aksm, _ኣይተዋ, 
   {{0x91e44945,0xb40400ee,0x52740116,0x61e80118}},	//   сове, _мүнд, _ғупу, řeln, 
   {{0x644c0597,0x657c4c5d,0x2d680139,0x00000000}},	//   _gcai, ærhe, _rşe_, --, 
   {{0x4fe977ba,0x71440014,0xc4d00375,0x00000000}},	// [35020] уман_, _ژھرٕ, _מגה_, --, 
   {{0x741400f1,0xa3b0012d,0x00000000,0x00000000}},	//   _اوښا, _टेट_, --, --, 
   {{0x3f8c022c,0x7174a67e,0xd1e80023,0x00000000}},	//   øgur_, _بۇزا, ሙርቲ_, --, 
   {{0x8c440b30,0x00000000,0x00000000,0x00000000}},	//   седе, --, --, --, 
   {{0x4b5400ee,0x00000000,0x00000000,0x00000000}},	//   съет, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd90c10e5,0x00000000,0x00000000,0x00000000}},	//   نیل_, --, --, --, 
   {{0xb4c40882,0xc86440b4,0x69dc072b,0x26dc00ef}},	//   ्वो_, стки, _ørem, _skvo_, 
   {{0x644dd89c,0xc9840131,0xdb4c0133,0x77940395}},	//   _rcai, руһи, _لێن_, йкър_, 
   {{0x644dd89d,0x7ae0089c,0xa534023a,0x46680395}},	//   _scai, clnt, оноч, урим_, 
   {{0x6aa80450,0x65940276,0x276801d3,0x00000000}},	//   _ildf, цану, _چشتی_, --, 
   {{0xf1c0001e,0x7ce000c5,0x291c0165,0x7d780677}},	//   _ương_, võrk, mpva_, אנטו, 
   {{0x3d0c033f,0x00000000,0x00000000,0x00000000}},	//   _तूने_, --, --, --, 
   {{0x46f41301,0xa5f802dd,0x7ce0000d,0x68e40327}},	//   _учет, _келу_, tõrk, ċidu, 
   {{0x21242508,0x00000000,0x00000000,0x00000000}},	//   èlh_, --, --, --, 
   {{0x61e80118,0xa1940124,0x3cd40150,0x00000000}},	//   řelo, баҳч, _ﺘﻌﺎﻤ, --, 
   {{0x6aa8ce5d,0x2d9c1477,0xc2c804fb,0x00000000}},	// [35030] _oldf, øven_, _مبدل_, --, 
   {{0x7ce000c5,0x52440117,0x00000000,0x00000000}},	//   põrk, _мӯсо_, --, --, 
   {{0x6285d89e,0xa3dc12eb,0x9c194ea7,0x00000000}},	//   _inho, _तुत_, لياء_, --, 
   {{0xa3bc084a,0x6aa85d2e,0x3c44007b,0x1b1c00eb}},	//   _आधा_, _aldf, إضاف, _নিবে_, 
   {{0x60c00098,0x00000000,0x00000000,0x00000000}},	//   élmu, --, --, --, 
   {{0xbdf86e9a,0x60c80010,0xab640006,0xd9380a5b}},	//   _مرزا_, čemu, явіл, ачиш_, 
   {{0x7938001f,0x19c400c7,0x99880124,0x6c840116}},	//   _አርቲስ, цәаг, шәаз_, غلۇم, 
   {{0x6aa9d89f,0xaf340345,0x00000000,0x00000000}},	//   _eldf, _برێت, --, --, 
   {{0x62840b4f,0x7ae00306,0x16a801f0,0x00000000}},	//   _onho, plnt, ивии_, --, 
   {{0x91e400b5,0xb4c400cd,0xb8640d17,0xff980092}},	//   doのu, ्व्_, _گائو, _ለጉዳዩ_, 
   {{0x6b3c0092,0x977400c7,0x00000000,0x00000000}},	//   _አልተቻ, стқә, --, --, 
   {{0x2b405a39,0x6285d8a0,0x3945d8a1,0xbaa400d1}},	//   šice_, _anho, muns_, _туғқ, 
   {{0x3945d8a2,0xe19401c0,0x6ef000fd,0x00000000}},	//   luns_, үрсэ, läbe, --, 
   {{0x3945d8a3,0xcb10011a,0x1138004e,0x00000000}},	//   ouns_, ולך_, иябы_, --, 
   {{0xc6140375,0x394535c3,0xd00800ee,0x00000000}},	//   _וחצי_, nuns_, иеве_, --, 
   {{0x6285d8a4,0x47300166,0xb62002dd,0x00000000}},	//   _enho, _энәс, _ﺫﻟ_, --, 
   {{0x39441570,0xdd0000bc,0x2d8c00a2,0x00000000}},	// [35040] huns_, štěs, _ŧde_, --, 
   {{0x39444e1b,0x5164516a,0x91e404c2,0x6ef0008e}},	//   kuns_, _двоб, _мопе, käbe, 
   {{0x39440311,0xe2a801f7,0x5eb800cc,0x00000000}},	//   juns_, _داين_, _অৱহে, --, 
   {{0x5cc40046,0x39446f7b,0x7c803d2a,0x8b642f0d}},	//   псіз, duns_, душе, قاتم, 
   {{0xbc65d8a5,0x6284002d,0x00000000,0x00000000}},	//   زمون_, _ynho, --, --, 
   {{0x394407c5,0x69dc5522,0xfaa063dd,0xbab40006}},	//   funs_, _ørek, мачо, огіх_, 
   {{0xa2cc2ce6,0x3945d8a6,0xda640597,0x48a8e3f0}},	//   _सदस्, guns_, ثاني, итим_, 
   {{0xbc600fbe,0xf98c01c8,0x00000000,0x00000000}},	//   _овск, ئبو_, --, --, 
   {{0x394404cc,0x00000000,0x00000000,0x00000000}},	//   auns_, --, --, --, 
   {{0xb5080d2c,0x3945d8a7,0x9c7c00b0,0x6aa801bf}},	//   _संशय_, buns_, _whōt, _uldf, 
   {{0x3945d8a8,0x2ba8000d,0x6ef00139,0x00000000}},	//   cuns_, कनवा, cäbe, --, 
   {{0x290c123c,0x1b1c00bd,0x00000000,0x00000000}},	//   _iuda_, _নিতে_, --, --, 
   {{0x47d4009f,0x00000000,0x00000000,0x00000000}},	//   _بيشر, --, --, --, 
   {{0x290dd8a9,0xaabc0ad7,0x64b80115,0xc1a41fbe}},	//   _kuda_, ्चिक, nĉiz, ојби, 
   {{0x290dd8aa,0xddc400b0,0xa0240327,0x847c0023}},	//   _juda_, rehū, _འབྱང_, _ንጹርን_, 
   {{0x290dd8ab,0x1f140006,0x00000000,0x00000000}},	//   _muda_, змаў, --, --, 
   {{0x9f58708a,0x290dd8ac,0x394407de,0xaabd27a4}},	// [35050] _også_, _luda_, zuns_, ्चाक, 
   {{0x6285d8ad,0x62200075,0xceb450e5,0x00000000}},	//   _unho, _سۈرە, пәс_, --, 
   {{0x8025b251,0x4438058a,0x69dc01bf,0x21780139}},	//   _ورحم, _kdq_, _øreh, _уйны_, 
   {{0xa0240003,0x5eb800fe,0x00000000,0x00000000}},	//   _འབྲང_, _অৱশে, --, --, 
   {{0x290c7d94,0x7ce000c5,0xf2d001b9,0x6d4803cd}},	//   _auda_, kõrv, _سآی_, _ådan, 
   {{0x2e48656c,0x6ef000fd,0x394407c5,0x91540244}},	//   _мясо_, täbe, tuns_, _بریڤ, 
   {{0x957c0023,0xd9440137,0x18a4c6c2,0x00000000}},	//   ንግቶን_, чейи, займ, --, 
   {{0x290dd8ae,0x3945d8af,0x6ef000fd,0x44380175}},	//   _duda_, runs_, räbe, _ndq_, 
   {{0x7c39d8b0,0x3945d8b1,0x6ef166d8,0x05380092}},	//   _idur, suns_, säbe, _በተማሪ, 
   {{0x3945231e,0x16a800d8,0x00000000,0x00000000}},	//   puns_, свои_, --, --, 
   {{0x290dd8b2,0x1dbc0882,0x00000000,0x00000000}},	//   _guda_, ्पित, --, --, 
   {{0xf7700075,0x895804ae,0x7c38025c,0x00000000}},	//   _ياش_, _לדעת, _jdur, --, 
   {{0x7c3801fa,0xb4add8b3,0x78a80171,0x290c00ef}},	//   _mdur, _गती_, _ilgv, _zuda_, 
   {{0x290dd8b4,0xfe1807af,0x1dbc012a,0x00000000}},	//   _yuda_, _प्लस_, ्पात, --, 
   {{0x7c39d8b5,0x290c06be,0x00000000,0x00000000}},	//   _odur, _xuda_, --, --, 
   {{0x7c39d8b6,0x0dc80032,0xf04401d5,0x94740133}},	//   _ndur, ҡлай_, بعسی, _ردبا, 
   {{0x60c002bd,0x00000000,0x00000000,0x00000000}},	// [35060] èlma, --, --, --, 
   {{0x7c39d8b7,0x00000000,0x00000000,0x00000000}},	//   _adur, --, --, --, 
   {{0x42980375,0xff0800b5,0x0c8425a2,0x91e40107}},	//   _הסיב, _vimで, зылм, _хоне, 
   {{0xdcb802bf,0x00000000,0x00000000,0x00000000}},	//   ощі_, --, --, --, 
   {{0x752c033f,0x15880150,0x00000000,0x00000000}},	//   ączy, _ﯗﻳﺴﯩ, --, --, 
   {{0x7c39d8b8,0xfa3004a9,0x83340a1e,0x78a80254}},	//   _edur, ىرىد, לאנס_, _algv, 
   {{0x3ab00032,0x290c01a9,0x00000000,0x00000000}},	//   хәтт, _quda_, --, --, 
   {{0x290c0333,0x98e401e0,0x7d540a7c,0xc170011a}},	//   _vuda_, мсыһ, _מילד_, תחה_, 
   {{0xbb408a6b,0x290c00f2,0x66f400c7,0x7ce0000d}},	//   _петк, _wuda_, мпиу, tõrv, 
   {{0x290dd8b9,0x61140109,0x7c3802f0,0x6b800112}},	//   _tuda_, _ląla, _zdur, _irmg, 
   {{0x2bc00490,0x270400af,0x7d18012d,0xb5a00108}},	//   _शेता, रदौर_, _łusz, еряй, 
   {{0xc8b4fa1c,0x44380407,0x2ec40154,0x6d4000b8}},	//   _عصاب, _qdq_, ্তিষ, _āmal, 
   {{0x61e40162,0x838402d5,0x2d9c005c,0x7ce00254}},	//   _syhl, чыне, øvej_, mõrt, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x26cc04cc,0x00000000,0x00000000,0x00000000}},	//   mndo_, --, --, --, 
   {{0x61e403c6,0x4de4007d,0x00000000,0x00000000}},	//   _vyhl, _करजई_, --, --, 
   {{0x2489d8ba,0x26cc14b8,0xf1c00327,0x00000000}},	// [35070] _inam_, ondo_, ġġax_, --, 
   {{0x645c01fa,0x61e400bc,0x2ce8031c,0x64400024}},	//   lfsi, _tyhl, _འཚུབ, ėliu, 
   {{0x26cc0261,0x645c0ba7,0x6b81d8bb,0x38c00248}},	//   indo_, ofsi, _armg, _jèrè_, 
   {{0x26cc145e,0x6ef00112,0x00000000,0x00000000}},	//   hndo_, täbc, --, --, 
   {{0x60cdd8bc,0x2018004a,0x9078025d,0xdcf4054e}},	//   mnam, _ifsi_, _וטרי, _arză, 
   {{0x60cc577b,0xbeb801c7,0x7ce0000d,0x2f18009d}},	//   lnam, _stëf, võru, _хорь_, 
   {{0x2489d8bd,0xeab000d1,0xddd40064,0x00000000}},	//   _onam_, دعن_, _mazū, --, 
   {{0x60cdd8be,0x26cdd8bf,0xb4ac1d27,0x7c380548}},	//   nnam, endo_, _गते_, _udur, 
   {{0x60cdd8c0,0x00000000,0x00000000,0x00000000}},	//   inam, --, --, --, 
   {{0x2489d8c1,0x60cdd8c2,0x46e430af,0x38c00ca8}},	//   _anam_, hnam, мдын_, _bèrè_, 
   {{0x645c007c,0x7d0001e1,0x2018032e,0x66d800c7}},	//   ffsi, _gìrì, _ofsi_, џьыр_, 
   {{0x60cdd8c3,0x38c001e1,0x77780267,0x248806af}},	//   jnam, _dèrè_, pvux, _cnam_, 
   {{0x60cdd8c4,0x26d802b5,0xb6840023,0x069400ec}},	//   dnam, ōroa_, _ንፈለማ_, _ڪانھ, 
   {{0x248916b2,0xda0c11b1,0x38c00248,0x60cdd8c5}},	//   _enam_, िखित_, _fèrè_, enam, 
   {{0x35f82cb0,0x24880100,0x60cdd8c6,0x22440d12}},	//   _ارشد_, _fnam_, fnam, ólka_, 
   {{0x60cdd8c7,0x2488011c,0x3d04012d,0x00000000}},	//   gnam, _gnam_, षदों_, --, 
   {{0x69dc2b96,0x212c16a3,0x60c84a97,0x48dc01f9}},	// [35080] _ørev, ćeha_, čemp, खवतो_, 
   {{0x248804b9,0x60cdd8c8,0x6ef001b8,0x00000000}},	//   _znam_, anam, fäba, --, 
   {{0xd009d8c9,0x60cd79fd,0x2489a77e,0x00000000}},	//   _мене_, bnam, _ynam_, --, 
   {{0x60cc0597,0x6e3c0354,0xbeb80200,0xdb4c0133}},	//   cnam, _wdrb, _atëd, ڵێم_, 
   {{0x213c00b0,0x2ab001e1,0xaabc2d81,0x00000000}},	//   _āwhi_, _làbe_, ्चलक, --, 
   {{0x9c7c00b0,0xa95401ec,0x00000000,0x00000000}},	//   _whōp, еккі, --, --, 
   {{0x645d3b91,0x23c43be5,0x094800d4,0x00000000}},	//   yfsi, _लेनद, ічки_, --, 
   {{0xa7742e3f,0x1dbc0b02,0x00000000,0x00000000}},	//   елич, ्परत, --, --, 
   {{0x645c07d6,0x248800b8,0x00000000,0x00000000}},	//   vfsi, _rnam_, --, --, 
   {{0x60cdd8ca,0x24880652,0x26cdd8cb,0xd6d80034}},	//   znam, _snam_, undo_, kułu_, 
   {{0xe4543fe9,0x00000000,0x00000000,0x00000000}},	//   нкны, --, --, --, 
   {{0xc7c4119e,0x67200158,0x645c0e78,0xd6d8012d}},	//   _осли, ppmj, ufsi, dułu_, 
   {{0x250800dd,0x24880393,0x645c08a5,0x60cdd8cc}},	//   _کرتی_, _vnam_, rfsi, vnam, 
   {{0x38c0025a,0x60cdd8cd,0x68e1d8ce,0x3218b8e2}},	//   _tèrè_, wnam, lomd, gcry_, 
   {{0x31c5d8cf,0x60cdd8d0,0x21080cf1,0xbbd80037}},	//   вств, tnam, वदेश_, _बड्क, 
   {{0x2489d8d1,0x68e04242,0x00000000,0x00000000}},	//   _unam_, nomd, --, --, 
   {{0x2ab00de2,0x337400ee,0x7ce00254,0x63a85522}},	// [35090] _màbb_, _агыр, kõrr, øend, 
   {{0x60cdd8d2,0x3d140135,0x68e0047e,0x1b1c0011}},	//   snam, _aħwa_, homd, _নিলে_, 
   {{0x60cdd8d3,0x68e0009a,0x9ea801e0,0x00000000}},	//   pnam, komd, овҡа_, --, 
   {{0x20c4005f,0x61e00e78,0x60cc0986,0x7ce00254}},	//   rķis_, üllu, qnam, võrs, 
   {{0x6ef8063f,0x3f8c05ac,0x3d0c0037,0xda640354}},	//   ụbar, ågud_, _तूरे_, евли, 
   {{0xfaa42d30,0x00000000,0x00000000,0x00000000}},	//   ьшен, --, --, --, 
   {{0x09e077cf,0xed1400c0,0x00000000,0x00000000}},	//   лошн, _амсь, --, --, 
   {{0x2bc00073,0x957400c7,0x00000000,0x00000000}},	//   _शेवा, ҭынч, --, --, 
   {{0xb4ac00dc,0x1b180154,0xd7040120,0x32180051}},	//   _गतौ_, _ঠিকই_, нзии, ycry_, 
   {{0xe6180372,0x1995aedc,0x3d3c0023,0x7ce00254}},	//   үдө_, _пазя, _ኣውቶቡ, põrs, 
   {{0x03a012d7,0xe874036b,0x6d400055,0x00000000}},	//   қиро, رنیگ, _āmak, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3218045a,0x00000000,0x00000000,0x00000000}},	//   tcry_, --, --, --, 
   {{0x3945d8d4,0xd6d80034,0x47980a1e,0x8fd000fb}},	//   orns_, tułu_, _מינס, ғәмә, 
   {{0xe1f001ed,0x69dc0450,0x6fec00cc,0x00000000}},	//   لسِ_, _øret, _কলেও_, --, 
   {{0xc0e073bc,0x32180076,0xe5701063,0x73c401ee}},	//   госк, scry_, _خطه_, _аҡма, 
   {{0x3f65d8d5,0x00000000,0x00000000,0x00000000}},	// [350a0] нито_, --, --, --, 
   {{0x3fe00cda,0x2bc000cd,0xbeb8036e,0x68e00454}},	//   ужув, _शेषा, _atëb, zomd, 
   {{0x3b1c02d1,0x68e1d8d6,0x10a5d8d7,0x7ce000c5}},	//   _atuq_, yomd, _зинн, võrr, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe24002d3,0x394404cc,0x2ab00de2,0xaf0400c7}},	//   _ንምህና, erns_, _ràbb_, _аҿал, 
   {{0xc330025f,0x68e0014b,0x2b400219,0xbb80009a}},	//   רוג_, womd, šico_, الوي, 
   {{0x2bc006ab,0x8c45d8d8,0x0905d8d9,0x00000000}},	//   _शेरा, _певе, нчим, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x68e1d8da,0x00000000,0x00000000,0x00000000}},	//   romd, --, --, --, 
   {{0x2d8c07ea,0xf76dd8db,0xbb38011a,0x68e001bf}},	//   _àdes_, صاً_, _מעמי, somd, 
   {{0xe70401b9,0xdcf40210,0x07d8072d,0x00000000}},	//   _یستی, _wrzą, _کذاب_, --, 
   {{0x68e001a9,0x00000000,0x00000000,0x00000000}},	//   qomd, --, --, --, 
   {{0xdcf4006d,0x46a40006,0xbb3800df,0x00000000}},	//   _urzą, _падв, ּעלי, --, 
   {{0x69dc1600,0x81740107,0x64a40124,0x00000000}},	//   _øres, нагӣ_, хаҭа, --, 
   {{0x96c0010a,0x00000000,0x00000000,0x00000000}},	//   _тăру_, --, --, --, 
   {{0x04c400ec,0x6adc190c,0x00000000,0x00000000}},	//   _ڊوڙي_, मकुर, --, --, 
   {{0xdb740023,0x9f3400d4,0x00000000,0x00000000}},	// [350b0] _በልዎም_, тезі, --, --, 
   {{0xbeb804e6,0xc1080209,0xdec43c1a,0xb3e400cc}},	//   _stëb, _нэме_, тәмо, নেহজ, 
   {{0xf1a40108,0x00000000,0x00000000,0x00000000}},	//   _брян, --, --, --, 
   {{0x9f3401ec,0x00000000,0x00000000,0x00000000}},	//   _иемі, --, --, --, 
   {{0xd9c8012c,0xa3d000dc,0x7e280006,0x1034011a}},	//   िप्ट, वपि_, _ніва_, _בטרם_, 
   {{0x236805b1,0x2a7c01fa,0xaa947420,0x6a8400d4}},	//   _mpaj_, gdvb_, личч, лліа, 
   {{0x5974724b,0x00000000,0x00000000,0x00000000}},	//   тылу, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x23680457,0x6d4002b5,0x00000000,0x00000000}},	//   _npaj_, _āmai, --, --, 
   {{0x97a4008e,0xfaf0007b,0x00000000,0x00000000}},	//   ерүл, _إثر_, --, --, 
   {{0x23697260,0x33200477,0x37700150,0x00000000}},	//   _apaj_, _stix_, тықс, --, 
   {{0x847c0023,0xf8ac0244,0x00000000,0x00000000}},	//   _ንኹለን_, _دکت_, --, --, 
   {{0xcc3800c8,0x69dc037e,0xf66000fd,0x00000000}},	//   וערט, _ører, _белү, --, 
   {{0x7ae1d8dc,0x00000000,0x00000000,0x00000000}},	//   nont, --, --, --, 
   {{0x91e43b55,0x00000000,0x00000000,0x00000000}},	//   тове, --, --, --, 
   {{0x20554547,0x00000000,0x00000000,0x00000000}},	//   лтур, --, --, --, 
   {{0x6ef0154a,0x00000000,0x00000000,0x00000000}},	// [350c0] bäbl, --, --, --, 
   {{0x7ae1d8dd,0x00000000,0x00000000,0x00000000}},	//   jont, --, --, --, 
   {{0x7ae1d8de,0xbeb804e6,0x8d580304,0x6ef001f4}},	//   dont, _stëc, ьшат_, säbo, 
   {{0x10a51fa8,0x8c453220,0xeac800c7,0x00000000}},	//   _римн, теде, mỹi_, --, 
   {{0x7ae1d8df,0xdef80023,0x00000000,0x00000000}},	//   font, ላኽካ_, --, --, 
   {{0x2ab00241,0xdcac0137,0x00000000,0x00000000}},	//   _bàba_, _ۉۉل_, --, --, 
   {{0x987c0213,0xfaa000d8,0x00000000,0x00000000}},	//   _açıb_, рајо, --, --, 
   {{0x6d5dd8e0,0x00000000,0x00000000,0x00000000}},	//   _iqra, --, --, --, 
   {{0xb50c3eaf,0x7ae1d8e1,0x00000000,0x00000000}},	//   _संजय_, bont, --, --, 
   {{0x7ae07086,0x41d80034,0xe81400ab,0xbb8800e5}},	//   cont, _मुझस, _डलवा_, _تحفے_, 
   {{0x2ab00241,0xbeb80221,0x24580212,0xd94400ec}},	//   _gàba_, _zwës, нань_, _مئني, 
   {{0x87e55342,0xdcf40210,0x00000000,0x00000000}},	//   _июле, _brzę, --, --, 
   {{0x888000e5,0x00000000,0x00000000,0x00000000}},	//   _میںن, --, --, --, 
   {{0x6d5c1fc6,0xd5a400f1,0x00000000,0x00000000}},	//   _oqra, _څلوی, --, --, 
   {{0xf1a5d8e2,0xbf98006a,0xb50c00e1,0x6d5c0327}},	//   артн, _ngêr, _संचय_, _nqra, 
   {{0x645415ed,0x2d5c45a7,0xceb40ce8,0x00000000}},	//   _свиђ, díe_, ңәр_, --, 
   {{0x7ae1d8e3,0x23680010,0x6d5dd8e4,0x30145090}},	// [350d0] yont, _upaj_, _aqra, рдур, 
   {{0x7ae1d8e5,0xdd940132,0x00000000,0x00000000}},	//   xont, лазы, --, --, 
   {{0x7ae1d8e6,0x20d44c8b,0xdb2001e1,0x00000000}},	//   vont, _مقدس, _àtúu, --, 
   {{0x4429d8e7,0x7ae1d8e8,0xe06003e6,0x00000000}},	//   nbc_, wont, _دێری, --, 
   {{0x6d5c02d0,0x00000000,0x00000000,0x00000000}},	//   _eqra, --, --, --, 
   {{0xeb90bd1e,0x00000000,0x00000000,0x00000000}},	//   تظم_, --, --, --, 
   {{0x2d9cad6a,0xceb000c8,0xceb402dd,0x9984007b}},	//   øvet_, _פיל_, _сәт_, البو, 
   {{0x7ae1d8e9,0x5eb800cc,0x00000000,0x00000000}},	//   sont, _অৱচে, --, --, 
   {{0x7ae1d8ea,0xd708023a,0x442800b5,0x1a64029e}},	//   pont, нние_, dbc_, _میشی_, 
   {{0xba74112d,0x896005d9,0x7ae051ab,0x00000000}},	//   _جارت, _ڇڏين, qont, --, 
   {{0x69dc0450,0x00000000,0x00000000,0x00000000}},	//   _ørep, --, --, --, 
   {{0xdcf4012d,0x00000000,0x00000000,0x00000000}},	//   _przę, --, --, --, 
   {{0x889805e1,0x387dd8eb,0xcc74011a,0x00000000}},	//   _רבני, mdur_, נעשה_, --, 
   {{0x387d0412,0xd17491e0,0x3980236c,0x00000000}},	//   ldur_, лыбы, _kıs_, --, 
   {{0x7640020b,0x4429d8ec,0x54680108,0x00000000}},	//   _idny, bbc_, _займ_, --, 
   {{0x387dd8ed,0x2d5c04cf,0x4429d8ee,0xa0b40640}},	//   ndur_, víe_, cbc_, аљуј, 
   {{0x0e644712,0xdcf40034,0xdf1407d5,0xeac800c7}},	// [350e0] лкан, _urzę, аьхь, sỹi_, 
   {{0x2d5c0998,0x7640020b,0x8fd000d1,0x717415bf}},	//   tíe_, _jdny, _һәзә, _پۇرا, 
   {{0xd83802b5,0x387c00ee,0x8c4800d8,0x00000000}},	//   kaō_, kdur_, епев_, --, 
   {{0xcc340026,0x2d5c04d4,0x705403e6,0x6adc00cd}},	//   اراع, ríe_, _خۆرا, मक्र, 
   {{0x387dd8ef,0xab9400d4,0xdc7400c7,0xcac800cf}},	//   ddur_, рилі, рыхь, нгде_, 
   {{0x2d9c1512,0x4428004c,0x0eb9d8f0,0xca640116}},	//   øves_, zbc_, _чумы_, الغۇ_, 
   {{0xd8380421,0x7bd80393,0x6d5dd8f1,0xc6a40454}},	//   faō_, _exuu, _uqra, ҳрни, 
   {{0x387c0579,0xa3dc06ab,0x48e00eac,0xd1440092}},	//   gdur_, _तुझ_, মগ্র, _ኤክስፖ, 
   {{0x37a401c6,0x00000000,0x00000000,0x00000000}},	//   гтэн_, --, --, --, 
   {{0x387c8ddb,0x7640020b,0xda6400ec,0x4428014b}},	//   adur_, _cdny, _نامي, wbc_, 
   {{0x291800c7,0xa3dc01f9,0x387cdf83,0x00000000}},	//   _îra_, _तुज_, bdur_, --, 
   {{0x76400142,0x387c06be,0x00000000,0x00000000}},	//   _edny, cdur_, --, --, 
   {{0x3fe002e5,0x2b400332,0x86e401a9,0x00000000}},	//   _कुंआ_, áich_, _йўкд, --, 
   {{0xe2f80046,0xded40092,0x0dd40023,0x00000000}},	//   тегі_, ካችን_, ካርፕ_, --, 
   {{0x2b4003c6,0x3618008f,0x85440064,0x00000000}},	//   šich_, _אווד, _сэле, --, 
   {{0x30a40261,0x00000000,0x00000000,0x00000000}},	//   брув, --, --, --, 
   {{0x9f05d8f2,0x6d59d8f3,0x8db401d5,0x3e6401a9}},	// [350f0] لورو, àvan, یشمچ, tеt_, 
   {{0x387c1ae4,0x9b94ed72,0x00000000,0x00000000}},	//   zdur_, یلات, --, --, 
   {{0xad2420ea,0xa1952dbb,0x7f5c010a,0x387c022e}},	//   مىلى, _танч, stqq, ydur_, 
   {{0x387c0cc1,0x6d400607,0x00000000,0x00000000}},	//   xdur_, _āmat, --, --, 
   {{0x2d9c6ab9,0x1cb80327,0x39800166,0xe9d801ec}},	//   øver_, ྚིཏ_, _sıs_, ңкі_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7bd80009,0x1ca40133,0x6e640108,0x00000000}},	//   _wxuu, _پێشی_, _утяж, --, 
   {{0x52d089b2,0xe7f02ba2,0x18a5d8f4,0x574401a9}},	//   _सद्स, _चरखा_, раим, аниб, 
   {{0x387cdc86,0xf1c0031c,0x00000000,0x00000000}},	//   rdur_, ġġix_, --, --, 
   {{0xd8380421,0x387c0213,0x66040115,0x170401d3}},	//   saō_, sdur_, _ŝika, جہتی_, 
   {{0xd9986bd8,0xd4f439fb,0x32cc0248,0xd5480395}},	//   _جنات_, иямы, _lóyè_, ъпне_, 
   {{0xd3b40588,0x88c00451,0x387c290f,0x00000000}},	//   асгь, _وڪيل, qdur_, --, 
   {{0x7640020b,0xdeac0198,0x00000000,0x00000000}},	//   _tdny, ssaƙ, --, --, 
   {{0x764004ce,0xbeb801c7,0xf4b402f2,0x00000000}},	//   _udny, _stën, _گشتگ, --, 
   {{0x75800166,0x00000000,0x00000000,0x00000000}},	//   _уңна, --, --, --, 
   {{0xd02595e5,0xb63c01ec,0x00000000,0x00000000}},	//   рмай, _ﺁﻨ_, --, --, 
   {{0x3ea00327,0x6eec003a,0x6ef00037,0xcee80395}},	// [35100] _bojt_, _nôbî, läbi, вдае_, 
   {{0xbb54037e,0x515400db,0x2bc001f9,0x00000000}},	//   _oneカ_, _ктму, _शेगा, --, 
   {{0xd17404b4,0x2ab001e1,0x00000000,0x00000000}},	//   _тыпы, _sàbo_, --, --, 
   {{0xb4c44c21,0x00000000,0x00000000,0x00000000}},	//   _एगो_, --, --, --, 
   {{0x6ef075ee,0x2bc003ce,0x2b400332,0xcb740798}},	//   häbi, _शेखा, éic_, руењ, 
   {{0x61e83642,0x00000000,0x00000000,0x00000000}},	//   şele, --, --, --, 
   {{0x224408a7,0x8c940953,0x98a40139,0x23ac01e1}},	//   ólki_, _краі, _aqlı_, _kójú_, 
   {{0x69dc00e4,0x15880220,0xfce026b1,0x67d400db}},	//   _ÿrem, _ﯗﺳﺘﯩ, _досо, йойу, 
   {{0x23ac0241,0x00000000,0x00000000,0x00000000}},	//   _mójú_, --, --, --, 
   {{0x79780084,0x38c8ebe8,0x4aa82208,0x1b1c015b}},	//   ṅwal, _یانی_, _कविव, _নিচে_, 
   {{0x2ca4045f,0x00000000,0x00000000,0x00000000}},	//   _komd_, --, --, --, 
   {{0x291c0369,0x87940014,0x00000000,0x00000000}},	//   mqva_, _نێبر_, --, --, 
   {{0xc6d0030d,0x00000000,0x00000000,0x00000000}},	//   _дιак, --, --, --, 
   {{0xe13401c0,0xa1580c31,0x32cc0241,0x6ef0010b}},	//   йнгы, лагу_, _róyè_, bäbi, 
   {{0x6ac410e3,0x4de40574,0x23ac0ca8,0x9ed8039b}},	//   _वगैर, _जुलै_, _bójú_, ҳмат_, 
   {{0x94100134,0x224d61ec,0x2ca4002d,0x00000000}},	//   _moyɛ_, şek_, _nomd_, --, 
   {{0x23ac0241,0x2904022f,0xc2e8007b,0x9ed800f3}},	// [35110] _dójú_, imma_, _لعدم_, гмат_, 
   {{0x26cd36c0,0x6d4000b8,0xd6d80210,0x00000000}},	//   nido_, _āmar, osła_, --, 
   {{0x3ea00135,0x26cc0067,0x00000000,0x00000000}},	//   _vojt_, iido_, --, --, 
   {{0x26cd2c7b,0xed5802bf,0xd1580023,0x00000000}},	//   hido_, рої_, _ውልቃው, --, 
   {{0x26cdd8f5,0x60cdd770,0x60c000f2,0x00000000}},	//   kido_, miam, èlmu, --, 
   {{0x60cdd8f6,0x26cdd8f7,0xec680724,0x9c6400ec}},	//   liam, jido_, грәк_, _گهرو, 
   {{0x26cc1a36,0xd99810e5,0xbb34013d,0x00000000}},	//   dido_, انعت_, _şädç, --, 
   {{0x60cdd8f8,0x8f4c0023,0x00000000,0x00000000}},	//   niam, _ንርእሶ, --, --, 
   {{0x26cdd8f9,0x6af80014,0xc0600023,0xd63800d4}},	//   fido_, دى۪س_, _ምጽሓፍ, ляні_, 
   {{0x60cdd8fa,0x26cdd8fb,0x2b900014,0x290581a5}},	//   hiam, gido_, _آیوس, amma_, 
   {{0x60cc0953,0x3cfc0070,0x00000000,0x00000000}},	//   kiam, _khuv_, --, --, 
   {{0x60cdd8fc,0xbeb801c7,0xe7f000c5,0xa8340137}},	//   jiam, _stël, _चरचा_, _ۇعۇش, 
   {{0x60cdd8fd,0x26cd12c0,0xd7f40724,0x4365d8fe}},	//   diam, bido_, _узды, баян_, 
   {{0x26cc74c3,0x23ac0241,0x78b8007c,0x72c801f0}},	//   cido_, _sójú_, lhuv, рғоб_, 
   {{0x60cdd8ff,0x3f880483,0x78b801f4,0x320c01f4}},	//   fiam, _arcu_, ohuv, ädy_, 
   {{0x60cdd900,0x6d58026c,0x1ea800f1,0x78b801e3}},	//   giam, àvam, یالي_, nhuv, 
   {{0xddd4151c,0xff2401ed,0x950401d9,0x527400f3}},	// [35120] _razš, مبلی, _پکھہ_, _луну, 
   {{0x6584000f,0x60cc000d,0x9e643769,0x63a801f4}},	//   _úthâ, aiam, قامن, äene, 
   {{0x4d49d901,0x60cc06bb,0xc27800c8,0x4d64496c}},	//   упен_, biam, _גריי, скев, 
   {{0x26cc0261,0x7d18151c,0x3cfc31c5,0x00000000}},	//   zido_, _čust, _chuv_, --, 
   {{0x442411a9,0xeac863eb,0xf1c00327,0x00000000}},	//   _ən_, ағай_, ġġux_, --, 
   {{0x26cc0f71,0x64a401ad,0xba1400ae,0x00000000}},	//   xido_, _ऑक्श, ميها_, --, 
   {{0xda64900f,0x26cdd902,0xc985d903,0x2fc1d904}},	//   تاني, vido_, сули, lzig_, 
   {{0x26cdd905,0x3cfc047e,0x29040e14,0xa8540798}},	//   wido_, _ghuv_, umma_, цкич, 
   {{0x26cc1a36,0x2fc0c08d,0x0b4409a5,0x29040198}},	//   tido_, nzig_, _ынан, rmma_, 
   {{0x60cdc7e2,0x2fc1d906,0x94100134,0x00000000}},	//   ziam, izig_, _woyɛ_, --, 
   {{0x26cc1a36,0xba150b3f,0x351405f5,0xa5f9d907}},	//   rido_, _ايما_, йжээ_, рену_, 
   {{0x2b401674,0x78b850d1,0x09c8009e,0x00000000}},	//   šicu_, chuv, _লুথা, --, 
   {{0x60cdd908,0xbeb804c4,0x2fc00196,0xf1a401c0}},	//   viam, _stëm, jzig_, үрсн, 
   {{0x2b440077,0x60cc0034,0x26cc0009,0x00000000}},	//   _mvmc_, wiam, qido_, --, 
   {{0x60cdd909,0xe604009f,0x00000000,0x00000000}},	//   tiam, _بِغَ, --, --, 
   {{0x442c0432,0x6d400055,0x00000000,0x00000000}},	//   _ýg_, _āmap, --, --, 
   {{0x60cdd90a,0x69dc08a5,0x00000000,0x00000000}},	// [35130] riam, _þref, --, --, 
   {{0x60cdd90b,0x4439d90c,0x3cfc01d5,0x2454136e}},	//   siam, _heq_, _shuv_, _انکس, 
   {{0x4438044e,0x3cfdd90d,0x2fc0030a,0xdd90bac9}},	//   _keq_, _phuv_, azig_, بوا_, 
   {{0x2fc00086,0x4438014f,0x60cc0194,0xf558010f}},	//   bzig_, _jeq_, qiam, רדאמ, 
   {{0x78b8171b,0x4438016d,0x60dc01a4,0x7b647a81}},	//   vhuv, _meq_, _ijsm, стее, 
   {{0x4439d90e,0x2a6c0334,0x0f700131,0x00000000}},	//   _leq_, _cbdb_, _юғур, --, 
   {{0x3cfc01d4,0x7e75d90f,0x78b9d910,0x6994f87a}},	//   _thuv_, mexp, thuv, зрых, 
   {{0x81f8015b,0x5749d911,0x4439d912,0x628005da}},	//   _আলাপ_, азим_, _neq_, ôloj, 
   {{0x78b9d913,0x888004fb,0x7c383727,0xe8040073}},	//   rhuv, بینن, _ieur, शेला_, 
   {{0x7c39d914,0x78b9d915,0x00000000,0x00000000}},	//   _heur, shuv, --, --, 
   {{0x7c39d916,0x4438016d,0xe8f4036b,0x362001d9}},	//   _keur, _beq_, _کسلخ, _ہوشہ, 
   {{0x06a80729,0x7c39d917,0x443801ab,0x6320015b}},	//   গোলি, _jeur, _ceq_, _বিজয়_, 
   {{0x7c39d918,0x4438047e,0xbec000e2,0xa8190db3}},	//   _meur, _deq_, _ķīni, _اتمر_, 
   {{0x7c39bc5a,0x2bbc07b6,0x67d8010f,0xd250009f}},	//   _leur, ्छता, _פֿײג, بنس_, 
   {{0x7e740175,0x4438002e,0x00000000,0x00000000}},	//   dexp, _feq_, --, --, 
   {{0x7c39d919,0x44380369,0x2fc032e9,0x63ac007b}},	//   _neur, _geq_, tzig_, íoná, 
   {{0x8d6c0020,0x85000a81,0x60c00ea0,0x2fc0030a}},	// [35140] _አላቸው_, _زوٝن, ëlma, uzig_, 
   {{0xb8f86d7e,0x2fc1d91a,0x61e80311,0x74640150}},	//   _རམ_, rzig_, şela, _ﺗﻪك_, 
   {{0x7c39d91b,0x10a5d91c,0xd1b0035c,0x106801af}},	//   _beur, _динн, _غیرک, _кинй_, 
   {{0x7c383386,0x2fc1d91d,0xfa300131,0x00000000}},	//   _ceur, pzig_, ۈرىد, --, 
   {{0x7c38e0c8,0xbb4044b5,0x9cb00228,0x00000000}},	//   _deur, дечк, رۅكت, --, 
   {{0x9f80039b,0x41cc07f7,0x8e7406c2,0x00000000}},	//   _яҳуд, _हेडस, _باحض, --, 
   {{0x7c39d91e,0x6e3dd91f,0x3974007b,0x00000000}},	//   _feur, _ierb, قصيد_, --, 
   {{0x7c39d920,0xbeb8044e,0xd90c1888,0x2bbc095f}},	//   _geur, _atëh, هیل_, ्छदा, 
   {{0x6e3dd921,0x4439d922,0xbb400166,0x00000000}},	//   _kerb, _req_, _оетк, --, 
   {{0x7c39d923,0x6e3c107d,0x854c001f,0x44381c2e}},	//   _zeur, _jerb, _በተፈጥ, _seq_, 
   {{0x2419b720,0x6e3dd924,0x44380477,0x7c380099}},	//   йоны_, _merb, _peq_, _yeur, 
   {{0x7e7401fb,0x4438047e,0x2ab001ab,0x2768030f}},	//   zexp, _qeq_, _sàbh_, _هشتی_, 
   {{0x6e3c0b21,0x4439d925,0x7e746445,0x2bec0183}},	//   _oerb, _veq_, yexp, জেৰে_, 
   {{0x6e3dd926,0xd6d8068f,0x9f640098,0x4438014f}},	//   _nerb, kuły_, _étéh_, _weq_, 
   {{0x7e7402d0,0x272001fb,0x4438047e,0x6aa8015d}},	//   vexp, _hòn_, _teq_, _modf, 
   {{0x2720033b,0x6e3dd927,0xd6d8012d,0x70940024}},	//   _kòn_, _aerb, duły_, масф, 
   {{0x6e3c2831,0x7c39d928,0x2720033b,0x224401a8}},	// [35150] _berb, _reur, _jòn_, ólks_, 
   {{0x7c39d929,0x2721d92a,0xfe71d92b,0x6e3dd92c}},	//   _seur, _mòn_, بدر_, _cerb, 
   {{0x7c3951c4,0x7e75d92d,0x62840280,0x6e3c7ea3}},	//   _peur, rexp, _iaho, _derb, 
   {{0x62840831,0x6e3dd92e,0x7e75d92f,0x31c40014}},	//   _haho, _eerb, sexp, _کۅہہ, 
   {{0x7c380372,0x6285d930,0x6e3c0225,0x6aa9d931}},	//   _veur, _kaho, _ferb, _bodf, 
   {{0x6284006c,0x6e3dd932,0x7c39d933,0xd6d80210}},	//   _jaho, _gerb, _weur, buły_, 
   {{0xed59d934,0x6285d935,0xf2d404ac,0x00000000}},	//   _моё_, _maho, ועס_, --, 
   {{0x6e3dd936,0x27203c51,0x7c3801c4,0xe8e80592}},	//   _zerb, _bòn_, _ueur, يريو_, 
   {{0x272001dc,0x6e3dd937,0x645c0115,0x6aa9d938}},	//   _còn_, _yerb, dgsi, _fodf, 
   {{0x6285d939,0x645c2417,0x6aa86dc8,0x27218550}},	//   _naho, egsi, _godf, _dòn_, 
   {{0xbec0005f,0x00000000,0x00000000,0x00000000}},	//   _ķīli, --, --, --, 
   {{0x6285d93a,0x27200192,0x645c03cd,0xb4c81cc3}},	//   _aaho, _fòn_, ggsi, ोचे_, 
   {{0x6285d93b,0x27200016,0x6aa80589,0x5695d93c}},	//   _baho, _gòn_, _yodf, _надт, 
   {{0x6285d93d,0x20181bce,0x9f500086,0x00000000}},	//   _caho, _agsi_, _ôbùm_, --, 
   {{0x6285d93e,0x27200699,0x9608015b,0xcb10011a}},	//   _daho, _zòn_, _শ্রম_, תלם_, 
   {{0x9345d93f,0xe4c800c6,0x27200100,0x4f246f9f}},	//   _ение, _وبين_, _yòn_, здаб, 
   {{0x6e3dd126,0x6285d940,0x00000000,0x00000000}},	// [35160] _perb, _faho, --, --, 
   {{0x1fb410f5,0x6285d941,0x2019d942,0x22640030}},	//   єстр, _gaho, _egsi_, ľský_, 
   {{0x6e3ca927,0xc2780d65,0x6aa90c41,0x22640122}},	//   _verb, _פרטי, _rodf, žský_, 
   {{0x6e3c0639,0x6285d943,0xfce0a0d5,0x00000000}},	//   _werb, _zaho, нохо, --, 
   {{0x6e3c4020,0x6285d944,0x6aa81b24,0xbeb80036}},	//   _terb, _yaho, _podf, _buëd, 
   {{0x6e3c1730,0x2720bff5,0x6284004d,0xff040024}},	//   _uerb, _ròn_, _xaho, _неяк_, 
   {{0x69ddd945,0x27201497,0x00000000,0x00000000}},	//   _žreb, _sòn_, --, --, 
   {{0xf98dd946,0xc1700a1e,0xe73801e0,0xb9500131}},	//   ابو_, גחה_, ҙеү_, رئىت, 
   {{0xb7603163,0x00000000,0x00000000,0x00000000}},	//   нтэй, --, --, --, 
   {{0xc0c80023,0xd9ec000d,0x00000000,0x00000000}},	//   _በጽሐ_, _चुवत_, --, --, 
   {{0x6285d947,0x3f840053,0x27200428,0x24540472}},	//   _raho, ānui_, _wòn_, وندس, 
   {{0x6285d948,0xbec0005f,0x2721d949,0x79b4011a}},	//   _saho, _ķīmi, _tòn_, _מלבד_, 
   {{0x7960013f,0x645dd94a,0x6285d94b,0x29b001d3}},	//   _dɑwu, rgsi, _paho, _سیکڑ, 
   {{0xdef8001f,0x6284014f,0xc3e000fd,0xb6a000d8}},	//   ላችን_, _qaho, _җөмһ, _пичл, 
   {{0x6285d94c,0x38a000a2,0xc0c80023,0x60c0002e}},	//   _vaho, _añry_, _በጽሑ_, ëlmo, 
   {{0x6285d94d,0x2ef40588,0x1fb80b87,0x61e8054e}},	//   _waho, ҵзур, олбы_, şelo, 
   {{0x6285d94e,0x644c9614,0xa0a40150,0x00000000}},	// [35170] _taho, _idai, паңд, --, 
   {{0x62840069,0x644c00a3,0xa19400f3,0x00000000}},	//   _uaho, _hdai, _жаоч, --, 
   {{0x2018070d,0x65680472,0xb63400df,0x00000000}},	//   _tgsi_, ntdh, פראס_, --, 
   {{0x2ab000a3,0x7eb00139,0xa2c80a97,0x00000000}},	//   _màbu_, _sıpı, होर्, --, 
   {{0x2d9c049f,0x68e40313,0x644c32ad,0x3e4c02b1}},	//   äver_, čidl, _mdai, tētē_, 
   {{0xdb200ca8,0x00000000,0x00000000,0x00000000}},	//   _òtít, --, --, --, 
   {{0x644caea6,0x09e00166,0x18a5d94f,0x6c8402f2}},	//   _odai, кошн, дайм, بلۆم, 
   {{0x644dd950,0xe9d029f2,0xae0408b0,0xad2400e5}},	//   _ndai, دغه_, _سوقى, _سرِو, 
   {{0xdc4400e2,0x7eb0294f,0x00000000,0x00000000}},	//   _mīļo, _tıpı, --, --, 
   {{0x644dd951,0xaa080014,0x00000000,0x00000000}},	//   _adai, _کٲمل_, --, --, 
   {{0x3b1c0d04,0x63a8005b,0x00000000,0x00000000}},	//   _huuq_, äenn, --, --, 
   {{0x57b40021,0x394400b5,0x00000000,0x00000000}},	//   _обет, msns_, --, --, 
   {{0x644c015d,0x3b1c058a,0x439002d5,0x00000000}},	//   _ddai, _juuq_, ваўс, --, 
   {{0x644dd952,0x78a8003a,0x3b1c058a,0x00000000}},	//   _edai, _hogv, _muuq_, --, 
   {{0xdef8044e,0x3b1c0014,0x21742c75,0xdeac0115}},	//   ላኽን_, _luuq_, нутр, graƭ, 
   {{0xf1b8038f,0xc5f00375,0x78a81ac9,0x00000000}},	//   ġġ_, _שדה_, _jogv, --, 
   {{0x4de40034,0x454c0092,0x3f641d0f,0x00000000}},	// [35180] _जुड़े_, _በተናጠ, мито_, --, 
   {{0x4dd4027d,0xc0000114,0x00000000,0x00000000}},	//   وتاس, тпук, --, --, 
   {{0x64480008,0x78a8257c,0x91e400a7,0x0c84010b}},	//   ðeig, _oogv, _цоне, дылм, 
   {{0x3b1c0014,0x78a80feb,0xe7d000cd,0x27e001a8}},	//   _buuq_, _nogv, _तेऽप, _þing_, 
   {{0xac6400db,0x00000000,0x00000000,0x00000000}},	//   _ۋئرۇ, --, --, --, 
   {{0x6568036e,0x00000000,0x00000000,0x00000000}},	//   ytdh, --, --, --, 
   {{0x2d8c0281,0x3320005a,0xd1c802d3,0x78a93e29}},	//   _éde_, _luix_, _ጽቡቅ_, _bogv, 
   {{0x3a2020e2,0x3b1c0009,0xba20497a,0x00000000}},	//   нмәг, _fuuq_, ндәк, --, 
   {{0xa3e802a6,0xc7c5d953,0xcb69d954,0x644dd955}},	//   _গণ্য_, ьски, _фазе_, _rdai, 
   {{0x644c04cc,0xa534234c,0xc9b4009b,0x00000000}},	//   _sdai, нноч, _осењ, --, 
   {{0xda640451,0x78a801d3,0x3ea429a8,0xfaa0a209}},	//   _سالي, _fogv, önti_, _шафо, 
   {{0xb89000c6,0x35b02472,0x63a801f4,0x00000000}},	//   _للمع, тбюр, äeno, --, 
   {{0x3868067c,0x87d80244,0xc7b400ae,0x00000000}},	//   òcre_, _بباس_, _تصاع, --, 
   {{0x33200369,0x8174013e,0x2a7c0175,0xe2c806c2}},	//   _duix_, магӣ_, nevb_, سوزو_, 
   {{0xa4d40212,0xb6c800e5,0x4370215c,0x00000000}},	//   _покі, _بانے_, رۇگر, --, 
   {{0x644c90be,0x04280055,0x00000000,0x00000000}},	//   _udai, _nāḍa, --, --, 
   {{0xc21820ef,0xa294dbe2,0x332000cf,0x60980050}},	// [35190] _мєн_, _запі, _guix_, _ہندس_, 
   {{0xad2443e8,0x24880548,0x00000000,0x00000000}},	//   چىلى, _haam_, --, --, 
   {{0x24880225,0xad240131,0x3b1c0014,0xef140137}},	//   _kaam_, نىلى, _suuq_, түрө, 
   {{0x6fd00490,0x24880694,0x00000000,0x00000000}},	//   _ठेवू, _jaam_, --, --, 
   {{0x24c0000e,0x2489d956,0x78a80162,0x00000000}},	//   _উদাহ, _maam_, _rogv, --, 
   {{0x2489d957,0x9f059f66,0x995c0139,0x00000000}},	//   _laam_, _سوزو, _cçşe_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2488bbd7,0x17842e9a,0x22400254,0x00000000}},	//   _naam_, егим, _lehk_, --, 
   {{0x236801d4,0x78a8017a,0xb8e400cd,0x63a80108}},	//   _nqaj_, _vogv, _उत_, äenl, 
   {{0xfaa4d44f,0xd9ec000d,0xaa54014b,0x6d5800c7}},	//   _ўшан, _चुअत_, _авфш, ávag, 
   {{0x24880a40,0x41cc01ad,0x78a8032e,0x00000000}},	//   _baam_, _हेलस, _togv, --, 
   {{0x332000db,0x7eb800e4,0x248856df,0x00000000}},	//   _puix_, _oîpo, _caam_, --, 
   {{0x2489d958,0xdef80023,0xa3f40006,0x82480023}},	//   _daam_, ላኽና_, вярш, _ንምምሳ, 
   {{0xc7d408a8,0x55e43cc5,0xd70400d4,0x260c01f9}},	//   _אוני_, _полб, _язли, डेही_, 
   {{0x2489d959,0x00000000,0x00000000,0x00000000}},	//   _faam_, --, --, --, 
   {{0x2120003e,0x8fa57646,0xc32c0014,0x00000000}},	//   _duhh_, набе, شٕہ_, --, 
   {{0x48f8008f,0xdef80023,0xe7b8012d,0x1d900092}},	// [351a0] פּלא, ላጽን_, इनएप, _የሚወጣ_, 
   {{0x212005b1,0x8c4406be,0x00000000,0x00000000}},	//   _fuhh_, _inşə, --, --, 
   {{0x248801d4,0x75280356,0xbeb8036e,0xd1b80244}},	//   _yaam_, _înză, _atës, _رادا_, 
   {{0x8fa5d95a,0x248800e8,0xa0640023,0x0b440138}},	//   _заме, _xaam_, _ውጽኢታ, ендн, 
   {{0x3f8c0158,0x04280055,0x00000000,0x00000000}},	//   ågut_, _vāḍa, --, --, 
   {{0xfaa06179,0x00000000,0x00000000,0x00000000}},	//   лачо, --, --, --, 
   {{0xff040276,0x9eb400db,0x2a7c045a,0x7d000356}},	//   _черк_, _جۇلئ_, revb_, însc, 
   {{0x7d000af4,0xa774a6e2,0x00000000,0x00000000}},	//   ïnst, влич, --, --, 
   {{0x2b2801b9,0x47700116,0x37e000fe,0x6d4000b8}},	//   _آغری_, уқлу, _পৰবৰ, _āmay, 
   {{0x24880591,0x49902ea3,0x9f58017a,0xfa644db0}},	//   _saam_, _میتر, _bysê_, _паук_, 
   {{0x49b9147b,0x2488003e,0x7a640137,0x24582e80}},	//   _عائد_, _paam_, _سئلە, мань_, 
   {{0x24880194,0xa4d40a4a,0x00000000,0x00000000}},	//   _qaam_, томі, --, --, 
   {{0x5ef40a28,0x6298016b,0xa2c40116,0x22400254}},	//   ्तम्_, _ɔwof, вәнк, _pehk_, 
   {{0x24880429,0x8ca80cb4,0x212012ce,0x454801d5}},	//   _waam_, _झकझो, _puhh_, _ечим_, 
   {{0x31c40a70,0x2489d95b,0x00000000,0x00000000}},	//   гств, _taam_, --, --, 
   {{0xb5f825f9,0x00000000,0x00000000,0x00000000}},	//   _מלוכ, --, --, --, 
   {{0x44280208,0x68e400a3,0x02b00117,0x00000000}},	// [351b0] mcc_, čidh, _бипӯ, --, 
   {{0xdd941c22,0x21200a2e,0x44280e14,0x2294013e}},	//   казы, _tuhh_, lcc_, _риоя, 
   {{0x2120003e,0x60980014,0x00000000,0x00000000}},	//   _uuhh_, _ہنگس_, --, --, 
   {{0x442942cd,0xaed40032,0x636400b0,0xca380150}},	//   ncc_, _ҡояш, pōnā, _ﻓﺨﺭ_, 
   {{0x3f8400e2,0x44280332,0x00000000,0x00000000}},	//   ānus_, icc_, --, --, 
   {{0xac19d95c,0xbeb8036e,0x00000000,0x00000000}},	//   хочу_, _etër, --, --, 
   {{0xd1c8069c,0x7f5c022f,0x442800b5,0x00000000}},	//   _ጽቡቕ_, luqq, kcc_, --, 
   {{0xa3c02413,0x6d5800e4,0x00000000,0x00000000}},	//   ंना_, ávae, --, --, 
   {{0x5b15d95d,0x44280810,0x69dc01a8,0xd708005b}},	//   _амат, dcc_, _þren, мние_, 
   {{0x7d19d95e,0x4428010a,0x29182508,0x9694009b}},	//   _hius, ecc_, _èran_, триш, 
   {{0x7d19d95f,0x4428010a,0x7f5c014f,0xdb180732}},	//   _kius, fcc_, huqq, rzwä, 
   {{0x7f5dd960,0x97d8010b,0x44280042,0x85b0013d}},	//   kuqq, _оьлу_, gcc_, рәшч, 
   {{0x7d183176,0x387d6845,0x39813744,0x65780175}},	//   _mius, meur_, _hűs_, _epvh, 
   {{0x387dd961,0x7d19d962,0xf6e5d963,0x78b9d964}},	//   leur_, _lius, _яцен, lkuv, 
   {{0xddc4000f,0xdcf4033f,0xc240bcf8,0x442855df}},	//   kehű, _wszę, рнск, bcc_, 
   {{0x7d19d965,0x387dd966,0x7641d967,0xc950008d}},	//   _nius, neur_, _heny, ימל_, 
   {{0x76411323,0x0e659abc,0x78b80810,0xff20059f}},	// [351c0] _keny, ккан, ikuv, имто, 
   {{0x7520b628,0x387dd968,0xbeb802d3,0x78b83110}},	//   _kunz, heur_, _stër, hkuv, 
   {{0x76413ca9,0x387dd969,0x78b81059,0x7520009f}},	//   _meny, keur_, kkuv, _junz, 
   {{0x7641d96a,0x75207e0b,0x387c859d,0xdb08012c}},	//   _leny, _munz, jeur_, ěnýc, 
   {{0x7520650b,0x7640f47c,0x00000000,0x00000000}},	//   _lunz, _oeny, --, --, 
   {{0x7521d96b,0x7d193902,0x76402c6b,0xc88003be}},	//   _ounz, _eius, _neny, mişə_, 
   {{0xc985d96c,0x387dd96d,0x7d180093,0x6f1c6fb2}},	//   тули, feur_, _fius, _iirc, 
   {{0x7d195d0e,0x387dd96e,0x68e00354,0x6f1c0381}},	//   _gius, geur_, unmd, _hirc, 
   {{0x7641d96f,0x6f1c9235,0x75216df3,0x3868067c}},	//   _beny, _kirc, _aunz, òcra_, 
   {{0x61e9d970,0x7521d971,0x6f1c031c,0x78b87d05}},	//   şeli, _bunz, _jirc, akuv, 
   {{0x7641d972,0x387c0151,0x6f1dd973,0x75200c86}},	//   _deny, beur_, _mirc, _cunz, 
   {{0x7f5dd974,0x764022a9,0x387c5895,0x752005d5}},	//   yuqq, _eeny, ceur_, _dunz, 
   {{0xed94001f,0x6f1c062e,0x38c81d0a,0x00000000}},	//   _መዋቅር_, _oirc, _تالی_, --, 
   {{0x7521d975,0x764011c1,0x6f1d48f3,0xddd40427}},	//   _funz, _geny, _nirc, _razž, 
   {{0x7521d976,0x4429d977,0x7f5c0455,0xbb380150}},	//   _gunz, pcc_, wuqq, _ﻓﺘﻡ_, 
   {{0x6f1dd978,0x76407ab0,0x7f5dd979,0x16a4035b}},	//   _airc, _zeny, tuqq, _агәҭ, 
   {{0x7d19d97a,0x7641d97b,0x75200516,0x69dc0219}},	// [351d0] _rius, _yeny, _zunz, _žrel, 
   {{0x387dd97c,0x7d19d97d,0x53980302,0x75200230}},	//   zeur_, _sius, _ניתו, _yunz, 
   {{0x6f1dd97e,0x387c20ef,0x7d19d97f,0x5dd4007b}},	//   _dirc, yeur_, _pius, دقائ, 
   {{0xbeb800e8,0x7d180194,0x3980002d,0x387c06af}},	//   _guën, _qius, _rűs_, xeur_, 
   {{0x387d3623,0x6f1dd980,0x7d18a3dc,0xe0d001d9}},	//   veur_, _firc, _vius, _نٲگ_, 
   {{0x6d582b57,0xda6439c1,0x387c4e6e,0x6f1c0205}},	//   ávac, увки, weur_, _girc, 
   {{0x387dd981,0x7640f313,0x78b8b302,0x7d19d982}},	//   teur_, _reny, tkuv, _tius, 
   {{0x6f1dd983,0x7d18013c,0x75200036,0x78b80083}},	//   _zirc, _uius, _runz, ukuv, 
   {{0x7641d984,0x387dd985,0x7521d986,0x78b81d1d}},	//   _peny, reur_, _sunz, rkuv, 
   {{0x387dd987,0xbf98019f,0x46e40372,0x7520db10}},	//   seur_, _eyêg, лдын_, _punz, 
   {{0x7641556e,0x387c07ea,0x7ae0009a,0xd469d988}},	//   _veny, peur_, mnnt, нине_, 
   {{0x76418e6a,0x3f4c0029,0x75200097,0x53a40209}},	//   _weny, kļu_, _vunz, гамб, 
   {{0xe91800d6,0x7e9800da,0x7bc80369,0x7520895d}},	//   _році_, _kāpē, nzgu, _wunz, 
   {{0x7521d989,0x764001c8,0x7bc80097,0x7e9800de}},	//   _tunz, _ueny, izgu, _jāpē, 
   {{0x7ae1d98a,0x11d800c6,0x65b802d2,0x3f4c0171}},	//   innt, رورة_, _vúhú, eļu_, 
   {{0x6f1dd98b,0xbeb804e6,0x7ae001ab,0x00000000}},	//   _sirc, _stëp, hnnt, --, 
   {{0x3f4c00da,0x6f1c005f,0xc7b8013f,0x4fe9d98c}},	// [351e0] gļu_, _pirc, ɑɑse_, хман_, 
   {{0x6f1cc1b5,0x00000000,0x00000000,0x00000000}},	//   _qirc, --, --, --, 
   {{0xbf98006a,0x6f1dd98d,0x00000000,0x00000000}},	//   _ayêd, _virc, --, --, 
   {{0x5fd40574,0x7d001af3,0xdce40882,0xbeb801c7}},	//   _ठेवल, ïnsp, tthā, _huël, 
   {{0x6f1dd98e,0xc8800213,0x92d40011,0xaa440022}},	//   _tirc, qişə_, িকী_, иҵал, 
   {{0xdce40882,0x6934cb2a,0xaa9402ec,0x6f1c01e7}},	//   rthā, анку, рикч, _uirc, 
   {{0xdce40a28,0x00000000,0x00000000,0x00000000}},	//   sthā, --, --, --, 
   {{0x7ae01552,0x69dc0008,0x2d980e78,0x0134008f}},	//   annt, _þrem, _irre_, אָזט_, 
   {{0xd90c034c,0x2918067c,0xdcac0228,0x00000000}},	//   ذیه_, _èram_, _تۉن_, --, 
   {{0xaab817c6,0x65740063,0x466801a9,0xda64b071}},	//   _अविक, агођ, хрим_, _پاكي, 
   {{0xe8d00050,0x00000000,0x00000000,0x00000000}},	//   _وۅتھ, --, --, --, 
   {{0xe3c401c0,0x98c40064,0x00000000,0x00000000}},	//   аргү, _ксіл, --, --, 
   {{0xf76c0345,0xaab84433,0x00000000,0x00000000}},	//   _فاو_, _अवाक, --, --, 
   {{0x248c2aa3,0x2d980086,0xe135d98f,0xa15874df}},	//   žem_, _orre_, ингы, кагу_, 
   {{0x7bc80158,0xba9800df,0x00000000,0x00000000}},	//   zzgu, עסלי, --, --, 
   {{0xa0c401f7,0x00000000,0x00000000,0x00000000}},	//   جيرو, --, --, --, 
   {{0x7cb4039b,0x7ae001a8,0x00000000,0x00000000}},	// [351f0] ққат_, ynnt, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6fd02c35,0x600814fb,0x7e9800e2,0x3c4408de}},	//   _सेकं, _үнүм_, _sāpē, اضاف, 
   {{0x2d98066d,0xd0100066,0x6b74009d,0xda64009a}},	//   _erre_, _ولپ_, йлцу, لاغي, 
   {{0xdd9530ca,0x7bc8002f,0x00000000,0x00000000}},	//   _кагы, rzgu, --, --, 
   {{0x611402d5,0xceb40166,0x00000000,0x00000000}},	//   _sąly, _тәт_, --, --, 
   {{0x4a500139,0x00000000,0x00000000,0x00000000}},	//   бкәс, --, --, --, 
   {{0x7e9800da,0x1a64006c,0x6ebc00dc,0x00000000}},	//   _tāpē, _نیشی_, _एवमु, --, 
   {{0x81b82f8b,0xa9c40166,0x00000000,0x00000000}},	//   _আইন_, рсәк, --, --, 
   {{0x27e00008,0xddc404fe,0x81c000e2,0x1db4012a}},	//   _þinn_, kahō, šēji, ंहित, 
   {{0x9abc0083,0xcdf400d9,0x00000000,0x00000000}},	//   _kuŋo, ימתי_, --, --, 
   {{0x67d40408,0x66280174,0xb9f00092,0xe35401c4}},	//   _лоцу, ískú, _ሜል_, йтрэ, 
   {{0xe80800d4,0x00000000,0x00000000,0x00000000}},	//   _снід_, --, --, --, 
   {{0x3f8808e5,0x00000000,0x00000000,0x00000000}},	//   _ascu_, --, --, --, 
   {{0x0440030d,0x00000000,0x00000000,0x00000000}},	//   _деън, --, --, --, 
   {{0x527465a3,0x130873f6,0x00000000,0x00000000}},	// [35200] _куну, _иний_, --, --, 
   {{0x7c740020,0x2bc4141f,0x9128022e,0x00000000}},	//   _የሌለው_, वनसा, _ижоб_, --, 
   {{0x0d85d990,0x3f880ffb,0x66c401e1,0x61e80112}},	//   рлен, _escu_, _jòka, ßelt, 
   {{0xf5480a28,0xefd4001f,0xa1f00150,0xfaf401b9}},	//   iḥ_, ረሰው_, _رۋقت, یروغ_, 
   {{0xab780014,0xab940212,0xaa581b0a,0x00000000}},	//   امتا_, силі, гилу_, --, 
   {{0x27e00006,0xca740220,0x8c840032,0x69dc08a5}},	//   _žino_, руды, ыҙға_, _þrek, 
   {{0x8c44042f,0x27e00276,0x2d99d991,0x7ae800d0}},	//   _вебе, _ţin_, _urre_, _žlté, 
   {{0xb83802dd,0x00000000,0x00000000,0x00000000}},	//   _زاۆﻭ, --, --, --, 
   {{0xc6a431ba,0x07080107,0x67d4009b,0x00000000}},	//   арни, кхои_, сопу, --, 
   {{0x25b803cd,0x76700f06,0x00000000,0x00000000}},	//   ørlo_, ольф, --, --, 
   {{0x25d80139,0x00000000,0x00000000,0x00000000}},	//   умны_, --, --, --, 
   {{0x66c4007f,0xdb0c0108,0x3518009d,0x00000000}},	//   _dòka, äkök, ижээ_, --, 
   {{0x92d403d4,0xe75800d4,0xf54800b8,0x00000000}},	//   িকৈ_, _силі_, aḥ_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x854402d5,0x937401ec,0x25b801e3,0x00000000}},	//   _тэле, _құрт_, ärld_, --, 
   {{0x30a403b7,0x3618011a,0xc1080166,0x00000000}},	//   орув, _בווד, тэге_, --, 
   {{0x6d59d992,0xc10000db,0x00000000,0x00000000}},	// [35210] ávan, йүүл, --, --, 
   {{0x2e2c01e1,0xa30800e5,0x00000000,0x00000000}},	//   _ròfó_, _حربے_, --, --, 
   {{0x63bd07f4,0xdcf40171,0xaee400dc,0x3da40454}},	//   lysn, _apzā, _saṃr, шраб, 
   {{0x2d5800a8,0xe7b80b7c,0x9b440aaa,0xfbd000c6}},	//   риць_, ेनाप, منصو, يتش_, 
   {{0x3f880cf4,0x63bc009a,0xf2d0036b,0xefd4001f}},	//   _uscu_, nysn, _رآی_, ረተው_, 
   {{0xe8e0004d,0x00000000,0x00000000,0x00000000}},	//   ướt_, --, --, --, 
   {{0xfc640801,0xcdc40b01,0x63bc007c,0xf27c00df}},	//   _възн, _лаёқ, hysn, דרוש, 
   {{0x63bd1bc6,0x00000000,0x00000000,0x00000000}},	//   kysn, --, --, --, 
   {{0x3ab081fc,0xe8a801e0,0xd62828a8,0x96b8b8d3}},	//   _мәкт, рбыҙ_, лопе_, гуну_, 
   {{0x66e43306,0xd3c40131,0x06c41999,0x00000000}},	//   ْأَق, ەتسى, йгый_, --, 
   {{0x8af8008f,0x00000000,0x00000000,0x00000000}},	//   _עפעק, --, --, --, 
   {{0x6ba00598,0x2d5c0943,0xd1bc0b82,0x00000000}},	//   _üzgä, ṋea_, ተኣብ_, --, 
   {{0x63bc01bf,0x17b400fe,0xbf140073,0x9584010a}},	//   gysn, _জেৰি, _तळून_, _ӳлке, 
   {{0x92d404c5,0x32d803b9,0x35c001d5,0x00000000}},	//   িক্_, _küyə_, _малҳ, --, 
   {{0x10a417a0,0xd4d40024,0x00000000,0x00000000}},	//   бивн, _гіпэ, --, --, 
   {{0xd02455da,0x0dc801e0,0xefec0023,0x63bc007c}},	//   смай, ңлай_, ጅያዊ_, bysn, 
   {{0x2d5c0084,0xca3c00d1,0x63a80108,0x00000000}},	// [35220] ḓea_, ﯞﻩﺭ_, äent, --, 
   {{0x52840597,0x00000000,0x00000000,0x00000000}},	//   _الدك, --, --, --, 
   {{0x4aa801e0,0x02b4011a,0xdb200241,0x00000000}},	//   ҫкен_, _הליך_, _òtùt, --, 
   {{0xfa300131,0x00c400f5,0x2bc400bc,0x69dc08a5}},	//   ۋرىد, _глюк_, वनला, _þrei, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x0d48004b,0x4a08aec3,0x00000000,0x00000000}},	//   _مشري_, лэйм_, --, --, 
   {{0xe7d00562,0x7e600022,0x00000000,0x00000000}},	//   _तेजप, ónpe, --, --, 
   {{0xebc40139,0x7d54011a,0x973001d3,0x63bc01f4}},	//   _мәлн, _לילד_, ڈکوا, yysn, 
   {{0x31980100,0xbb4017b4,0x00000000,0x00000000}},	//   _lčz_, _нетк, --, --, 
   {{0x09e40063,0x8554030f,0x9b400092,0x46a40108}},	//   _лозн, میتر_, _ይሰጣቸ, сшиб, 
   {{0xf76d78c3,0x00000000,0x00000000,0x00000000}},	//   وای_, --, --, --, 
   {{0x63bc023a,0x00000000,0x00000000,0x00000000}},	//   tysn, --, --, --, 
   {{0x38c8f2af,0x363007d6,0x00000000,0x00000000}},	//   _حالی_, غریس, --, --, 
   {{0x2905d993,0x15d801d3,0x00000000,0x00000000}},	//   llma_, ادیں_, --, --, 
   {{0x6d580765,0xe4d401d5,0x00000000,0x00000000}},	//   ával, _وقتد, --, --, 
   {{0x7f5c0334,0xfeb8030f,0x63bc03ac,0x00000000}},	//   trqq, گارت_, pysn, --, 
   {{0x290418db,0x9ed9d994,0x6d580029,0x63a9769b}},	// [35230] ilma_, амат_, šval, åend, 
   {{0xfeb81e7c,0x3ca00150,0xde5800d4,0x357000e5}},	//   دارت_, _ﺍﻗﺘﻰ_, ражі_, _بھیڑ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x94100134,0x00000000,0x00000000,0x00000000}},	//   _nnyɛ_, --, --, --, 
   {{0x1b196107,0x60cdd995,0x290401ab,0x88bc03d4}},	//   ажды_, mham, dlma_, ইফাক, 
   {{0x60cdd996,0x6295d997,0x94100134,0x290401f4}},	//   lham, ndzo, _anyɛ_, elma_, 
   {{0x6295d998,0x00000000,0x00000000,0x00000000}},	//   idzo, --, --, --, 
   {{0x60cdd999,0x66c4007f,0xa3b800ab,0x20c8be8c}},	//   nham, _bòko, चहा_, रसिध, 
   {{0x28d8551c,0x60cc009a,0x00000000,0x00000000}},	//   बोधि, iham, --, --, 
   {{0xba748568,0x29040280,0x60cc014b,0x629401f5}},	//   _دارت, alma_, hham, jdzo, 
   {{0x20c86766,0x71500092,0xe8c82bda,0x95940114}},	//   रसाध, ንቲስቶ, ргөл_, црпљ, 
   {{0x26cc01d9,0x629400e2,0xd469d99a,0x00000000}},	//   ahdo_, edzo, шиме_, --, 
   {{0x60cdd99b,0x629401f5,0x00000000,0x00000000}},	//   dham, fdzo, --, --, 
   {{0x62940d27,0x60cdd99c,0x8c18011a,0x00000000}},	//   gdzo, eham, יורי, --, 
   {{0x90b4026a,0x3cfccb5b,0xd0d806ed,0x60cc0162}},	//   ољаш, _okuv_, аќаш_, fham, 
   {{0x62940099,0x6d59d99d,0x92680124,0x00000000}},	//   adzo, ávam, ырҭа_, --, 
   {{0xe4e826c0,0x50640032,0x3ca002dd,0x00000000}},	// [35240] _دعوه_, йтҡа, _ﺍﺗﺘﻰ_, --, 
   {{0x9e645f2e,0x290404ba,0x60cc0055,0x00000000}},	//   كامن, zlma_, aham, --, 
   {{0xc27805e1,0x2d9d2d45,0x75246732,0x9f5800e4}},	//   _דריי, íve_, _kiiz, _pysã_, 
   {{0xfbd817cb,0x26cc0023,0xfce05990,0x8fa40024}},	//   _मेहम, zhdo_, мохо, _даме, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7525d99e,0x00000000,0x00000000,0x00000000}},	//   _liiz, --, --, --, 
   {{0x7c2c2a92,0x00000000,0x00000000,0x00000000}},	//   _širš, --, --, --, 
   {{0x386c04cc,0x2a6000ac,0x00000000,0x00000000}},	//   _ccgr_, şib_, --, --, 
   {{0xca740024,0x00000000,0x00000000,0x00000000}},	//   _мужы, --, --, --, 
   {{0x75240810,0x60cdd99f,0xff7800df,0x00000000}},	//   _aiiz, zham, סטימ, --, 
   {{0x35643ed6,0x60ccfb72,0xa5f80452,0x00000000}},	//   орян_, yham, сену_, --, 
   {{0x693801e4,0x386c0204,0x26cc0023,0x62940034}},	//   _aĉeg, _gcgr_, shdo_, wdzo, 
   {{0x7525d9a0,0x6d5803c6,0x60cc0943,0x68e0155d}},	//   _diiz, ávaj, vham, mimd, 
   {{0x629504ca,0xb6d8010a,0xa9040244,0x00000000}},	//   udzo, _кочĕ_, _ببڕن, --, 
   {{0x60cdd9a1,0x26dc015c,0x75241418,0x6d5800f3}},	//   tham, _imvo_, _fiiz, švaj, 
   {{0x68e1d9a2,0x6569d9a3,0xffe41b0a,0x00000000}},	//   nimd, mudh, оюзн, --, 
   {{0x60cdd9a4,0x65680ba7,0x644c00ef,0xdb18002f}},	// [35250] rham, ludh, _ieai, tzwü, 
   {{0x60cdd9a5,0x644c166a,0x68e1d9a6,0x752404ba}},	//   sham, _heai, himd, _ziiz, 
   {{0x60cc0163,0x644dd9a7,0x68e041bb,0x00000000}},	//   pham, _keai, kimd, --, 
   {{0x6b8002e3,0x6ab8033f,0x644c0332,0x68e0818a}},	//   _ịgag, _अवॉर, _jeai, jimd, 
   {{0x6569d9a8,0x644dd9a9,0x68e18718,0xd7d82017}},	//   hudh, _meai, dimd, _बेंच, 
   {{0x65682395,0x644dd9aa,0xfaa402e8,0x05c81b87}},	//   kudh, _leai, юшен, ानाब, 
   {{0xceb01a4c,0x656805b8,0x2d580276,0x699402d5}},	//   _אים_, judh, _мирь_, дрых, 
   {{0x644dd9ab,0x60dc009a,0x68e1d9ac,0x65691ede}},	//   _neai, _jmsm, gimd, dudh, 
   {{0xfa880b32,0x00000000,0x00000000,0x00000000}},	//   _всей_, --, --, --, 
   {{0x644cb44e,0x752401fa,0x6569d9ad,0x00000000}},	//   _aeai, _siiz, fudh, --, 
   {{0x644c1554,0x6569d9ae,0x60ddd9af,0x935800d1}},	//   _beai, gudh, _omsm, әрму_, 
   {{0x644dd9b0,0x68e003e0,0x25b8007c,0x00000000}},	//   _ceai, cimd, ärla_, --, 
   {{0x644c0076,0x63a801f4,0xe784009b,0xd628009b}},	//   _deai, äenp, _жујо, _лоле_, 
   {{0x6569d9b1,0x2250005a,0x3cec0073,0x00000000}},	//   budh, gazk_, ेकडे_, --, 
   {{0x2f149c56,0x50593521,0x644c1368,0x69dc01a8}},	//   lägg_, йшая_, _feai, _þret, 
   {{0xd5e006d6,0x644c0363,0x00000000,0x00000000}},	//   neḽ, _geai, --, --, 
   {{0xfbd87ef5,0x00000000,0x00000000,0x00000000}},	// [35260] _मेलम, --, --, --, 
   {{0x68e1a638,0x53c402dd,0x6cc80150,0x00000000}},	//   zimd, _мақұ, _ﻓﻠﺘﺴ, --, 
   {{0x644c03d7,0x68e18227,0x71740c71,0x3f8c01a8}},	//   _yeai, yimd, _تۇزا, ægur_, 
   {{0x25b805ac,0x2f14007c,0x00000000,0x00000000}},	//   ørli_, kägg_, --, --, 
   {{0x2f14007c,0x68e06164,0x00000000,0x00000000}},	//   jägg_, vimd, --, --, 
   {{0x3ea8003d,0x6569d9b2,0xc33025f9,0x7c3c0213}},	//   ċità_, yudh, עוו_, ıqra, 
   {{0x8c454f0b,0x68e05a63,0x7a500736,0x0ef80263}},	//   _неве, timd, رضوا, ्तीस_, 
   {{0x6569d9b3,0x00000000,0x00000000,0x00000000}},	//   vudh, --, --, --, 
   {{0x644dd9b4,0xdb4c03e6,0xc7c5d9b5,0x00000000}},	//   _reai, _نێن_, яски, --, 
   {{0x6569d9b6,0x68e1d9b7,0x644dd9b8,0x4544001f}},	//   tudh, simd, _seai, _የተከበ, 
   {{0x6aa9d9b9,0xbeb800e8,0x644dd9ba,0x2bc406b1}},	//   _indf, _guëu, _peai, वनका, 
   {{0x6569d9bb,0x68e1afbf,0x00000000,0x00000000}},	//   rudh, qimd, --, --, 
   {{0x46a5d9bc,0x6569d9bd,0x644ce048,0x00000000}},	//   _надв, sudh, _veai, --, 
   {{0x26dc009a,0x644c0099,0x067401af,0x69dc02d2}},	//   _umvo_, _weai, _худя, _þres, 
   {{0x29180ba1,0xf6780375,0x644c01e7,0x65686ed8}},	//   _èras_, _האומ, _teai, qudh, 
   {{0x11680214,0x98a400b8,0x00000000,0x00000000}},	//   تلفی_, _kulā_, --, --, 
   {{0x6aa9d9be,0xfbd800e1,0x934400db,0xa3e000cd}},	// [35270] _ondf, _मेंम, _قىيۇ, _दधि_, 
   {{0x3f980175,0x00000000,0x00000000,0x00000000}},	//   rvqu_, --, --, --, 
   {{0x1ee800aa,0x5c740024,0x00000000,0x00000000}},	//   موړی_, длет, --, --, 
   {{0x8d280efb,0x6aa9d9bf,0x60dc02d0,0x3ea400e5}},	//   інің_, _andf, _umsm, űnt_, 
   {{0x05dc433a,0xc0b80020,0x00000000,0x00000000}},	//   _फेसब, ተናል_, --, --, 
   {{0x2f140267,0xd9380353,0x00000000,0x00000000}},	//   vägg_, очиш_, --, --, 
   {{0x6dc400cf,0x98a40171,0xb6041155,0xa91c00d7}},	//   _كۅكۅ, _aulā_, _miší, _spľa, 
   {{0xb4bc007d,0x6aa8057d,0xf1c40118,0x267801c6}},	//   _आके_, _endf, liší_, үсээ_, 
   {{0xcd000034,0x7d000311,0x00000000,0x00000000}},	//   _dość_, însu, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x35c00107,0x583800c0,0x00000000,0x00000000}},	//   ханҳ, _дзея_, --, --, 
   {{0x7ae1d9c0,0xcd00068f,0x2f140209,0x6d580022}},	//   lint, _gość_, mäge_, ávai, 
   {{0x2f15d9c1,0x7ae1d9c2,0x96b8b32c,0x00000000}},	//   läge_, oint, _муку_, --, 
   {{0x6d580024,0x57c8095f,0x59d000dc,0x00000000}},	//   švai, िनीह, तनपर, --, 
   {{0x91e402e8,0x7ae00009,0x00000000,0x00000000}},	//   фове, iint, --, --, 
   {{0x69400943,0x4730008e,0x8fa43947,0x661c03b2}},	//   _ṋeke, _янәс, мабе, ýrke, 
   {{0x7ae1d9c3,0x4fe808e2,0x3178033f,0xe1f000f1}},	// [35280] kint, цман_, strz_, نسې_, 
   {{0x7ae1d9c4,0x118c02d3,0x00000000,0x00000000}},	//   jint, _ብግልጺ_, --, --, 
   {{0x7ae1d9c5,0x8d580137,0x2f14007c,0x57c800bc}},	//   dint, юшат_, vägd_, िनुह, 
   {{0x7ae1d9c6,0x2f140724,0x7c8002f6,0x09b400fe}},	//   eint, däge_, вуше, জনমা, 
   {{0xe7e803f4,0x8e5400d4,0x00000000,0x00000000}},	//   _পর্য, _отві, --, --, 
   {{0x7ae1d9c7,0xfaa1d9c8,0x00000000,0x00000000}},	//   gint, качо, --, --, 
   {{0x1eec0150,0x98a40171,0x00000000,0x00000000}},	//   _وﻧﯩﯔ_, _sulā_, --, --, 
   {{0x7ae1d9c9,0xd054013f,0xa7b800d8,0x00000000}},	//   aint, onyɑ, злиу_, --, 
   {{0x9410016b,0xfc000058,0xfce02218,0x066400f1}},	//   _onyɑ_, _апто, _рото, وادپ, 
   {{0x6aa8127b,0xcaa400c6,0x2f1400fd,0xbbd4011a}},	//   _undf, _تصري, bäge_, _חומץ_, 
   {{0xfaa00f5c,0x499400fb,0x00000000,0x00000000}},	//   _јахо, _юшат, --, --, 
   {{0x975400b8,0xa91c00d7,0x98a400b8,0xbb7c02dd}},	//   _aṇus, _ipľo, _tulā_, _ﺤﻔﻅﻪ_, 
   {{0xc6900014,0x05dc2356,0x00000000,0x00000000}},	//   _لِش_, _फेरब, --, --, 
   {{0x0575d9ca,0xf7e401b9,0x6d48031c,0x00000000}},	//   _قاعد, _تآمی, _ħdan, --, 
   {{0x9f580589,0xf67000aa,0x2d9c01bf,0x200c0064}},	//   _myså_, _شاوخ, ævel_, _šei_, 
   {{0x7ae1d9cb,0x2579d9cc,0x250400b8,0x00000000}},	//   zint, mél_, _koṭṭ, --, 
   {{0x2579d9cd,0x98b4031c,0x00000000,0x00000000}},	// [35290] lél_, żgħa_, --, --, 
   {{0x7ae1d9ce,0x66c40100,0xa195d9cf,0x7de41867}},	//   xint, _bòki, _заоч, وسام, 
   {{0x7ae1d9d0,0x257934b3,0x92f0009d,0x8fb401e2}},	//   vint, nél_, _сүрх, ولېږ, 
   {{0x44380175,0x8024007b,0x2f14000d,0x00000000}},	//   _jfq_, _يرحم, väge_, --, 
   {{0x7ae1d9d1,0x2d9c03d4,0xbeb80036,0xa3c00b7c}},	//   tint, åver_, _duër, ूनि_, 
   {{0xdb2400dd,0x2579d9d2,0xe7e80183,0x7ae1d9d3}},	//   _épül, kél_, _পৰ্য, uint, 
   {{0xbeb80036,0x25788708,0xf2d40a7c,0x00000000}},	//   _fuër, jél_, כעס_, --, 
   {{0x2f15d9d4,0xa3c029d6,0x2579d9d5,0xec68004e}},	//   räge_, ूना_, dél_, _орук_, 
   {{0x7c39d9d6,0x2f146186,0x98a4013d,0x6b7401af}},	//   _ifur, säge_, _җиле, _илту, 
   {{0xbf98006a,0x7ae003f0,0x2579d9d7,0xf980059f}},	//   _ayêk, qint, fél_, _аҳко, 
   {{0xaaac0864,0x69dc08a5,0x00000000,0x00000000}},	//   चारक, _þrep, --, --, 
   {{0xcdd8008f,0x63a801e4,0x00000000,0x00000000}},	//   פֿיר, ĥenn, --, --, 
   {{0x7c38985a,0x387dd9d8,0x31c8a7a2,0xe89400d4}},	//   _mfur, mfur_, रन्ध, _шаць, 
   {{0x387dd9d9,0x25787c70,0xe9d8074d,0xd6d8012d}},	//   lfur_, bél_, _икĕ_, ysły_, 
   {{0x7c39d9da,0xd131c205,0x16980014,0x25784e79}},	//   _ofur, امر_, _وٕچھ_, cél_, 
   {{0x387c01d9,0xf48404d3,0x7c38025c,0xa2c010eb}},	//   nfur_, _شاعی, _nfur, रॉब्, 
   {{0x10081411,0x7778011f,0x14240116,0x3cec0175}},	// [352a0] سترى_, ntux, _ядим, dngv_, 
   {{0x7c39d9db,0x4df400c9,0x32d40139,0x00000000}},	//   _afur, няет, _säyf_, --, 
   {{0x7c380175,0x78a8014f,0x00000000,0x00000000}},	//   _bfur, _ongv, --, --, 
   {{0x2d5c0943,0x00000000,0x00000000,0x00000000}},	//   ṋei_, --, --, --, 
   {{0x8fd004a9,0xab940212,0x4abc023e,0xaaac8497}},	//   _сәвә, тилі, ्सलव, चालक, 
   {{0x7c381eef,0x78a80455,0x34cc0490,0x7d0800c5}},	//   _efur, _angv, ासुद, algs, 
   {{0x7c380cfd,0x387dd9dc,0x257800e8,0x00000000}},	//   _ffur, ffur_, xél_, --, 
   {{0x2578628e,0x78740395,0x068400d1,0x00000000}},	//   vél_, ейър_, ﯩﺴﯩﮕ, --, 
   {{0x67d55bec,0x6d5c0165,0xca84010b,0x25787e7d}},	//   топу, _hvra, _пгай, wél_, 
   {{0x2579d9dd,0x78a8014f,0x6d5c107d,0xe9c40022}},	//   tél_, _engv, _kvra, _иазҿ, 
   {{0xa4d4177b,0x7d240fac,0x00000000,0x00000000}},	//   воні, _årsæ, --, --, 
   {{0x25797f7e,0xb6440092,0x00000000,0x00000000}},	//   rél_, _የጠየቀ, --, --, 
   {{0x2579d9de,0xf74000c2,0xe69400c7,0x69d80112}},	//   sél_, _бечо, _аилы, lzve, 
   {{0x69a40cb3,0x6d5dd9df,0xd34403e6,0x25794938}},	//   किपी, _ovra, کییه_, pél_, 
   {{0x78a94ea5,0x69d9d9e0,0x25040055,0xd0540213}},	//   _yngv, nzve, _coṣṭ, liyə, 
   {{0x69d805a1,0x443801a9,0xc0c80f06,0x00000000}},	//   izve, _ufq_, чуге_, --, 
   {{0xe3140261,0x9f05d9e1,0xf484023a,0xd0540213}},	// [352b0] _имињ, نورو, _сущн, niyə, 
   {{0x7c39d9e2,0x00000000,0x00000000,0x00000000}},	//   _sfur, --, --, --, 
   {{0x6284124c,0x7c3818f7,0xf650008f,0x250400cd}},	//   _ibho, _pfur, רצע_, _goṣṭ, 
   {{0x69d8005f,0x06500092,0x98a40210,0x00000000}},	//   dzve, _መጠቀሚ, _kulą_, --, 
   {{0x6d5dd9e3,0x69d800d7,0x00000000,0x00000000}},	//   _evra, ezve, --, --, 
   {{0xd0540213,0xaaa4033f,0x3f4c0327,0x7e9400ec}},	//   diyə, _गोदक, mżu_, _ڪنڀر_, 
   {{0x628418f7,0x6d5826d8,0x00000000,0x00000000}},	//   _mbho, ávat, --, --, 
   {{0x7c388186,0xd05403b9,0x1785c274,0x00000000}},	//   _ufur, fiyə, вгим, --, 
   {{0x387dd9e4,0x6d5c02fb,0x69d80165,0xb78001b9}},	//   rfur_, _zvra, azve, уғли, 
   {{0xa78401f7,0x387c025c,0x41b00709,0x00000000}},	//   اشيو, sfur_, ीहास, --, 
   {{0xd469d9e5,0x39a40131,0x00000000,0x00000000}},	//   мине_, _яшав, --, --, 
   {{0x6285d9e6,0x78a83b7b,0x3af80022,0xd05403b9}},	//   _abho, _ungv, vêpy_, biyə, 
   {{0x6569d9e7,0x62840076,0xd0540213,0x27f400d7}},	//   ardh, _bbho, ciyə, čanú_, 
   {{0x66c40241,0x62840055,0x43400212,0x320c0790}},	//   _bòku, _cbho, рерв, üdyo_, 
   {{0xd575d9e8,0x59d000cd,0xf1c80137,0x00000000}},	//   _руль, तनिर, راسۇ_, --, 
   {{0x62842ffc,0xb92400cd,0x00000000,0x00000000}},	//   _ebho, _pitṛ_, --, --, 
   {{0xd025d9e9,0x6284010a,0x9f5801e1,0x00000000}},	// [352c0] тмай, _fbho, _éyìn_, --, 
   {{0x69a49856,0x5154004e,0x00000000,0x00000000}},	//   किमी, _итму, --, --, 
   {{0xc69008a8,0x71c4013e,0x00000000,0x00000000}},	//   שאב_, _санҷ, --, --, 
   {{0x0b882e58,0xcb686145,0x3f4c025c,0x69d80219}},	//   дски_, даде_, bżu_, vzve, 
   {{0x66c4007f,0x628000db,0x8a740107,0x00000000}},	//   _kòkt, òlog, вилӣ_, --, 
   {{0x69d803fa,0xdce47bc9,0xa9780cc9,0x09b400cc}},	//   tzve, ruhā, ейку_, জনসা, 
   {{0x69d805c7,0x00000000,0x00000000,0x00000000}},	//   uzve, --, --, --, 
   {{0x69d9d9ea,0xa77407c6,0xeb540150,0x6d580010}},	//   rzve, глич, _مىرگ, švas, 
   {{0x8b6400f7,0x69d800e5,0x00000000,0x00000000}},	//   _جازم, szve, --, --, 
   {{0x49901888,0x855402f2,0x00000000,0x00000000}},	//   _نیتر, نیتر_, --, --, 
   {{0x65684bbd,0x00000000,0x00000000,0x00000000}},	//   urdh, --, --, --, 
   {{0x6569d9eb,0x66c401e1,0xba14009f,0x3f4c0210}},	//   rrdh, _ròku, _شينا_, yżu_, 
   {{0x29040427,0x375000db,0x00000000,0x00000000}},	//   moma_, _ەپۇس, --, --, 
   {{0x2905d9ec,0x4908095f,0x00000000,0x00000000}},	//   loma_, ातको_, --, --, 
   {{0x31c594a7,0x66c40100,0x6d4002b1,0x00000000}},	//   аств, _dòkt, _ōman, --, 
   {{0xe4d804fb,0x2f146da3,0x03c41171,0xa0c41063}},	//   _سوخت_, väga_, _асом, ديرو, 
   {{0xb035d9ed,0xdca408b0,0xf288009d,0x00000000}},	// [352d0] рнуш, ғали, хөөд_, --, 
   {{0x2905d9ee,0x62840944,0xfde807d8,0x66c401e1}},	//   homa_, _ubho, мьей_, _tòku, 
   {{0x2905d9ef,0x6e9413d6,0x00000000,0x00000000}},	//   koma_, риху, --, --, 
   {{0x2905d9f0,0xf044084c,0xed5802bf,0x9c6400ec}},	//   joma_, _вэро, тої_, اهشو, 
   {{0x6d59d9f1,0xdb85d9f2,0x2f14007c,0x00000000}},	//   ávar, угли, säga_, --, 
   {{0x2904000d,0xb3e000fe,0x63a801f4,0x00000000}},	//   eoma_, _যুঁজ, äeny, --, 
   {{0x290487f6,0x60cd1a99,0x6d59d9f3,0xfd200133}},	//   foma_, okam, švar, _نوسێ, 
   {{0x60cc4acb,0x6ca4e03a,0xfd1c01e1,0x00000000}},	//   nkam, _круж, _òì_, --, 
   {{0x7d185b62,0x59d0038e,0x6ce40220,0xd7880451}},	//   _ihus, तनहर, _тіре, رندو_, 
   {{0x60cd772c,0x9695d9f4,0xdb100248,0x00000000}},	//   hkam, уриш, _ìgàn, --, 
   {{0x60cdd9f5,0x2905d9f6,0xd5e41173,0xe89801ed}},	//   kkam, boma_, ужни, رمیں_, 
   {{0x2905d9f7,0x7d180221,0xe7fc00ab,0xc0ec0023}},	//   coma_, _jhus, _उँचा_, _ቀጽሪ_, 
   {{0x60cdd9f8,0x7d19d9f9,0x90c401ec,0x00000000}},	//   dkam, _mhus, қбае, --, 
   {{0x320c068f,0x60cdd9fa,0x7d1800ad,0x78b9d9fb}},	//   żdym_, ekam, _lhus, ljuv, 
   {{0x60cc017a,0x7d1800af,0x6abc004e,0x016049b4}},	//   fkam, _ohus, _òrfe, йкро, 
   {{0x60cc7004,0x98a40139,0xdb2003b2,0xc0e1d9fc}},	//   gkam, _kvlı_, _ótæt, боск, 
   {{0x3f640021,0x0ea9d9fd,0x00000000,0x00000000}},	// [352e0] лито_, нкай_, --, --, 
   {{0x9e6519b2,0x60cdd9fe,0x7d19d9ff,0x78b8bb9d}},	//   لامن, akam, _ahus, hjuv, 
   {{0xc27804ac,0x2905da00,0x7d1803d5,0x4d640024}},	//   _אריי, yoma_, _bhus, укев, 
   {{0x7d19da01,0x78b80a49,0x2904022e,0x00000000}},	//   _chus, jjuv, xoma_, --, 
   {{0x2904a58f,0x7d19da02,0x8ae400d3,0xdd3006be}},	//   voma_, _dhus, лікл, _tәşk, 
   {{0x7d180810,0x2905da03,0x7eb800e4,0x00000000}},	//   _ehus, woma_, _oîpy, --, 
   {{0xc985da04,0x7c2c0086,0x7d180332,0x75d006be}},	//   уули, ñirû, _fhus, bəzə, 
   {{0x7d19da05,0xf98c18fd,0xf98401e2,0xd9b014fb}},	//   _ghus, سبى_, انيي_, تەمد, 
   {{0x2c080e3f,0x185400d1,0xfb8400f2,0x00000000}},	//   _شعری_, جرىڭ, _مدلی, --, 
   {{0xcaa40597,0x78b9da06,0x60cdda07,0x7d1802f0}},	//   _حصري, ajuv, zkam, _zhus, 
   {{0x60cc1bb7,0x2905da08,0x368444a5,0x91e4037e}},	//   ykam, poma_, усын_, _shのi, 
   {{0x60cdda09,0x8554130e,0x290403b4,0xddd40100}},	//   xkam, پیکر_, qoma_, _dezň, 
   {{0x60cdda0a,0x00000000,0x00000000,0x00000000}},	//   vkam, --, --, --, 
   {{0x60cdda0b,0x81740107,0xfbb400bc,0xb7c000a2}},	//   wkam, лагӣ_, _आपसम, _ýţan, 
   {{0x20e401f0,0x00000000,0x00000000,0x00000000}},	//   асаҳ, --, --, --, 
   {{0x60cdda0c,0xd1b8001f,0x00000000,0x00000000}},	//   ukam, _ዳኞች_, --, --, 
   {{0x60cdda0d,0x3e687626,0x6f1c01ab,0x24880393}},	// [352f0] rkam, ешен_, _bhrc, _ibam_, 
   {{0x7d19da0e,0x9e1402d5,0xaaa40e85,0xfca800f2}},	//   _shus, адзі, _गोलक, کائو_, 
   {{0x60cdda0f,0x7d19da10,0xdd907b63,0x3da5da11}},	//   pkam, _phus, توا_, ыраб, 
   {{0x7d180309,0x316c5327,0x60cc02d1,0x9b74007b}},	//   _qhus, ádze_, qkam, لاتص, 
   {{0xa3e4038e,0x24889380,0x7d181aa1,0x6618020c}},	//   पछि_, _mbam_, _vhus, _lzvk, 
   {{0x7d180493,0x6dc400db,0x00000000,0x00000000}},	//   _whus, _گۅمۅ, --, --, 
   {{0x7d19da12,0x6d880014,0x78b9da13,0x7f5c0334}},	//   _thus, _مۅلہ_, tjuv, lsqq, 
   {{0x7d1805d9,0xe9a83be1,0x78b8013c,0xddd400d7}},	//   _uhus, ادون_, ujuv, _rezň, 
   {{0x32d40784,0x78b9da14,0x00000000,0x00000000}},	//   _läya_, rjuv, --, --, 
   {{0x2489da15,0x7bc80042,0xd628009b,0x96640798}},	//   _abam_, mygu, копе_, јкне, 
   {{0x7bc9da16,0x78b801e4,0x00000000,0x00000000}},	//   lygu, pjuv, --, --, 
   {{0x94240139,0x49380375,0xa9c40395,0x00000000}},	//   имне, _סגנו, _усук, --, 
   {{0x24880210,0xd4140139,0x00000000,0x00000000}},	//   _dbam_, рьны, --, --, 
   {{0x32d400fd,0x52742a62,0x59a8013a,0xd2500b61}},	//   _bäya_, шуму, किपर, تنس_, 
   {{0x32d40166,0x7bc80022,0x62580209,0x90c4022e}},	//   _cäya_, hygu, ыряр_, абве, 
   {{0x20545cdd,0xa5644caa,0x00000000,0x00000000}},	//   йтур, _ادون, --, --, 
   {{0x412414a4,0x410002bf,0x7bc800c7,0x00000000}},	// [35300] рото_, ізув, jygu, --, 
   {{0xd1742fe5,0xd1c89cff,0xccf800e5,0x00000000}},	//   _кымы, _алое_, ھراؤ_, --, 
   {{0x8c9401ec,0x00000000,0x00000000,0x00000000}},	//   ирді, --, --, --, 
   {{0xcd0400f7,0x69a4033f,0x236c0010,0x00000000}},	//   шпей, किसी, šeje_, --, 
   {{0x35a402e5,0xd68c009d,0x00000000,0x00000000}},	//   गिड़, _хvчи, --, --, 
   {{0x3b040369,0x3198007f,0xa93402dd,0xfa300116}},	//   gonq_, _kōz_, бекш, يرىد, 
   {{0xbae0007b,0xed5001d3,0xddc00150,0xddc4010b}},	//   تكوي, _رھا_, _еттi_, mahş, 
   {{0xdb080118,0xddc4453a,0xd9e400cc,0x00000000}},	//   ěnác, lahş, _পুহম, --, 
   {{0xd90cbb0b,0xbb41da17,0x2b440010,0x00000000}},	//   ریه_, _метк, _utmc_, --, 
   {{0x2b80067c,0x24880042,0x09e400f3,0x37a40395}},	//   mòc_, _sbam_, _козн, ртън_, 
   {{0x2b800ba1,0xca78022e,0xfaa00212,0x24580212}},	//   lòc_, _kitо, _фахо, лань_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x38c81a4b,0xf76c02f2,0x83842b61,0x81e000cc}},	//   _جالی_, _قاو_, шыне, _ফুং_, 
   {{0xd7641079,0xd04403b9,0x00000000,0x00000000}},	//   _انوی, _ilkə, --, --, 
   {{0xf1a5da18,0xf47003e3,0xddc4010e,0x84640395}},	//   ортн, _şüşə_, dahş, _къпе, 
   {{0x64404baa,0x24880117,0x64540114,0x00000000}},	//   ślib, _ubam_, _увиђ, --, 
   {{0x2b800ba1,0x00000000,0x00000000,0x00000000}},	// [35310] jòc_, --, --, --, 
   {{0xfda40640,0x229400c6,0x2b801497,0x5e581c3e}},	//   ијем, _الدس, dòc_, الاس_, 
   {{0x6295da19,0x32d4023a,0xf1a43da1,0xfeb800f1}},	//   mezo, _käyn_, _дрян, _یاست_, 
   {{0x6295da1a,0xdd94005e,0x7bc8a19b,0x69dc0008}},	//   lezo, _қабы, tygu, _þrey, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xaac41c02,0x7bc9da1b,0x00000000,0x00000000}},	//   قتىن, rygu, --, --, 
   {{0x2d9c04ce,0xceb000c8,0x9a5400c7,0xdce400ef}},	//   ævet_, _ציל_, ахқә, arhā, 
   {{0x645dda1c,0xa90410fe,0x6295da1d,0xdb08000f}},	//   jasi, يبين, hezo, _kreë, 
   {{0x62940208,0xf98400ec,0x00000000,0x00000000}},	//   kezo, انڊي_, --, --, 
   {{0x629401fa,0xab280063,0x15b81ee1,0x00000000}},	//   jezo, _вођа_, гымы_, --, 
   {{0x645dda1e,0x6295da1f,0x9f5800e4,0xf5300092}},	//   fasi, dezo, _rysý_, _አደጋዎ, 
   {{0xf8d8007d,0x287400c7,0x00000000,0x00000000}},	//   _बतिय, _дышр, --, --, 
   {{0x690ce02f,0x88980375,0xd6a802cb,0x00000000}},	//   rûet, _תבני, _مدغم_, --, 
   {{0x6295da20,0x8c180302,0x645c20ac,0x00000000}},	//   gezo, טורי, aasi, --, 
   {{0xf8d8006d,0xcb10008d,0x798001ab,0x00000000}},	//   _बताय, פלל_, ntnw, --, 
   {{0xdb080ea0,0xc0e19fb3,0x00000000,0x00000000}},	//   _breë, поск, --, --, 
   {{0x6295da21,0xdb080196,0x0e6422bf,0x7c74001f}},	// [35320] bezo, _creë, йкан, _ከሌላው_, 
   {{0x6294010f,0xf76400db,0x9104010a,0x00000000}},	//   cezo, _ۉا_, _ӳпне, --, 
   {{0x0d85da22,0xade80210,0x00000000,0x00000000}},	//   слен, _टेशन_, --, --, 
   {{0x8b656a15,0xdb080036,0x3eac00e2,0x0c25da23}},	//   ماتم, _freë, ēgta_, бмен, 
   {{0x6b7402bf,0x00000000,0x00000000,0x00000000}},	//   ілку, --, --, --, 
   {{0x645d0694,0x2d9c037e,0x39a401fb,0x0eb81e76}},	//   zasi, æves_, _bđs_, _сумы_, 
   {{0x645dda24,0x2b80180f,0x8c45da25,0x00000000}},	//   yasi, sòc_, _гебе, --, 
   {{0x645dda26,0x6295da27,0x3d28136e,0x00000000}},	//   xasi, zezo, _متقی_, --, 
   {{0x6294013e,0x6d4000b0,0x645dda28,0xdcac00cf}},	//   yezo, _ōmah, vasi, _جۉن_, 
   {{0x645dda29,0x3ddc04c5,0xbf9805d0,0x00000000}},	//   wasi, _বুটল, נייש, --, 
   {{0x6295da2a,0xdb0c007c,0x80d80118,0x00000000}},	//   vezo, äkåk, नसमे, --, 
   {{0x645c0333,0x62945d6e,0x63880124,0x00000000}},	//   uasi, wezo, аӡом_, --, 
   {{0x645daf2a,0x7c580020,0x7640020b,0x00000000}},	//   rasi, ቅስቃሴ, _ffny, --, 
   {{0xdb08180f,0x629405c7,0x80d80073,0x4df80456}},	//   _creè, uezo, नसभे, ्थाई_, 
   {{0x36305218,0x62240131,0x09b4009e,0xa15806d2}},	//   _عروس, زىرل, জনকা, рабу_, 
   {{0x645dda2b,0x316c01a2,0x3ddc015b,0xdb1002d2}},	//   qasi, ádza_, _বুঝল, _ígön, 
   {{0x6295da2c,0xdb08033b,0xbbb407f7,0x42e400cc}},	// [35330] pezo, _freè, _आपेक, পকৌশ, 
   {{0xf44801d3,0xfe240139,0x00000000,0x00000000}},	//   _پلیٹ_, бьен, --, --, 
   {{0xbbe9da2d,0x599c0020,0x00000000,0x00000000}},	//   گرام_, _ቁልፎች_, --, --, 
   {{0x2d580276,0x4c9000d1,0x75780115,0x00000000}},	//   сиць_, җиәс, רטאפ, --, 
   {{0x2d9c019b,0x63ac1bf4,0xab6402bf,0xbbe8009f}},	//   æver_, _jran, звіл, درام_, 
   {{0xd1cc069c,0x8e7023f6,0x63ac0214,0xdb0801c7}},	//   _ኣኼባ_, _оқуш, _mran, _kreé, 
   {{0x6bd42928,0xfd101f3c,0x941003e3,0x00000000}},	//   يتۇر, _فجر_, _dayə_, --, 
   {{0x63ac4020,0x3ea1da2e,0x57440a93,0x00000000}},	//   _oran, _hajt_, ониб, --, 
   {{0x3ea1399f,0x63adda2f,0x00000000,0x00000000}},	//   _kajt_, _nran, --, --, 
   {{0x5589da30,0x00000000,0x00000000,0x00000000}},	//   абом_, --, --, --, 
   {{0x8aa8021a,0x3ea00240,0x00000000,0x00000000}},	//   _خپلې_, _majt_, --, --, 
   {{0x3ea000f3,0x7d080158,0x00000000,0x00000000}},	//   _lajt_, nogs, --, --, 
   {{0x2bac59c9,0x00000000,0x00000000,0x00000000}},	//   चिया, --, --, --, 
   {{0x63ac28ab,0x572402dd,0x3ea015ad,0xd6292dbb}},	//   _dran, _بىتك, _najt_, _коле_, 
   {{0x63adda31,0xd76400dd,0xdb080789,0x66240150}},	//   _eran, _انڈی, _creé, _ىرىك, 
   {{0x2f1400af,0x2bac4da1,0xf0042e2d,0x00000000}},	//   mägi_, चिमा, зүми, --, 
   {{0x09b400dc,0xcee80024,0x8ee800d4,0x3ea0aac9}},	// [35340] _अप्य, адае_, амав_, _bajt_, 
   {{0x77380020,0xe0d8016c,0x3ea00427,0xb0040055}},	//   _አነስተ, авӣ_, _cajt_, _naḥs, 
   {{0x63ac0232,0x3ea0036e,0x8d74007b,0x00000000}},	//   _zran, _dajt_, تاءا, --, 
   {{0xa3c00574,0x3dc40054,0x63adda32,0x00000000}},	//   ूनच_, änwa_, _yran, --, 
   {{0xa2c002ab,0x63ac0072,0x45440092,0x61e800df}},	//   रॉक्, _xran, _የደንበ, ĝele, 
   {{0x29000024,0x66e001e1,0x61e801e4,0xcde4030d}},	//   čiam_, _mákù, ŝele, _догй, 
   {{0x7d0800b5,0x69340330,0x66e00241,0x00000000}},	//   bogs, سکار, _lákù, --, 
   {{0x4789da33,0x7d08009a,0x00000000,0x00000000}},	//   асом_, cogs, --, --, 
   {{0x2919da34,0x2ca400d7,0x80c40154,0x00000000}},	//   ēra_, _iamd_, রোক্, --, 
   {{0x2ca42681,0x63ac8ad5,0x250400dc,0x31780306}},	//   _hamd_, _rran, _kaṇṭ, kurz_, 
   {{0x48640801,0xda64004b,0xf40403d4,0xf5e000d4}},	//   _дълб, _رالي, ৰেমৰ_, діям, 
   {{0x63ad5788,0x96b800d1,0x250400b8,0x00000000}},	//   _pran, _қучу_, _maṇṭ, --, 
   {{0x63ac0213,0x58f8010f,0xd6d800cf,0x82a400d8}},	//   _qran, _פּענ, ртө_, ошве, 
   {{0x9c4c02dd,0x00000000,0x00000000,0x00000000}},	//   _ﺟﯩﻠﯟ_, --, --, --, 
   {{0x63adda35,0x3ea1da36,0x26f82017,0x9ed802dd}},	//   _wran, _rajt_, ुवीर_, ұмат_, 
   {{0x3ea1da37,0x63bc0bc9,0xceb401e0,0x24f800fb}},	//   _sajt_, pxsn, үәр_, _ынйы_, 
   {{0x63ac562c,0x94100134,0xca2c2e56,0x7d0801a8}},	// [35350] _uran, _mayɛ_, ﻨﺪﺍ_, vogs, 
   {{0x317804cc,0x3ea0036e,0x00000000,0x00000000}},	//   burz_, _qajt_, --, --, 
   {{0x80c400bd,0x3ea1399f,0x31780175,0x00000000}},	//   রোগ্, _vajt_, curz_, --, 
   {{0x3ea00054,0xeff002d3,0x249801fa,0x9f341d31}},	//   _wajt_, _ቀይዲ_, nesm_, _немі, 
   {{0x21283150,0x2ca40175,0x7d09da38,0x3ea1da39}},	//   mmah_, _damd_, rogs, _tajt_, 
   {{0x2129da3a,0xec680724,0x9f05da3b,0xcb641cc9}},	//   lmah_, брәк_, _روزو, чаше_, 
   {{0x7c9400c6,0x2128011f,0x00000000,0x00000000}},	//   _وشرا, omah_, --, --, 
   {{0xe9a809b3,0x2f1400c5,0x21280c6a,0x00000000}},	//   زدىن_, vägi_, nmah_, --, 
   {{0x249806d9,0x21280548,0x18680961,0x00000000}},	//   desm_, imah_, _ғали_, --, 
   {{0x2129da3c,0x23780fac,0x6b8400a3,0x55e40d1d}},	//   hmah_, dusj_, àige, зооб, 
   {{0x2128f1af,0xd1bc010c,0xe8c8009d,0x00000000}},	//   kmah_, ሰባት_, сгөл_, --, 
   {{0xe6180228,0x64400034,0x2ca40009,0x2128016d}},	//   өдө_, ślin, _xamd_, jmah_, 
   {{0x21280548,0x88380375,0x00000000,0x00000000}},	//   dmah_, _התנו, --, --, 
   {{0x2bac00dc,0x47d002dd,0x31780112,0x3cfc01e3}},	//   चिता, _سيىر, turz_, _ljuv_, 
   {{0xca7801d5,0xc69008c3,0x00000000,0x00000000}},	//   _mitа, _נאה_, --, --, 
   {{0xcf44154e,0x661ccdaf,0x21280098,0x24f4013d}},	//   знай, ürke, gmah_, _очыр, 
   {{0x8e39da3d,0x2ca405b1,0x7524005a,0xc0e0254f}},	// [35360] مسار_, _ramd_, _ihiz, хотк, 
   {{0x2ca4cc33,0x2128102c,0xbea00ff1,0xdb740092}},	//   _samd_, amah_, наук, _አልያም_, 
   {{0xcd3402c0,0x3cfc0267,0xdb08054e,0x82380375}},	//   سراب, _bjuv_, _preî, _לעיצ, 
   {{0x0c2400d8,0x26f801ad,0x290000d0,0x5cc401ec}},	//   пмен, _ंद्र_, čiak_, мсіз, 
   {{0x7524004c,0xdb0800cf,0x41b001d5,0xb6440023}},	//   _mhiz, _creï, _قمیر, _የጠንቅ, 
   {{0x9b00013e,0xe945da3e,0x00000000,0x00000000}},	//   вҷуд, وربی, --, --, 
   {{0x7524009d,0xc330011a,0x644800e4,0x00000000}},	//   _ohiz, גוג_, ñeik, --, 
   {{0x3684009d,0x2bac00cd,0x00000000,0x00000000}},	//   үсэн_, चिदा, --, --, 
   {{0x693804ac,0x99640137,0x07080107,0x37a4013d}},	//   _aĉet, птөл, йхои_, птэн_, 
   {{0xfa641830,0x94100134,0x75241539,0xcb0805d9}},	//   _наук_, _wayɛ_, _ahiz, _ايئن_, 
   {{0x7525da3f,0x6d4800d8,0x61040064,0x00000000}},	//   _bhiz, _édad, lėle, --, 
   {{0x7525da40,0xc765da41,0x48740220,0x21280009}},	//   _chiz, _فاتى, _ءداس, xmah_, 
   {{0x61040153,0x2128047e,0xc76400d1,0x4cac00cc}},	//   nėle, vmah_, _راشى, _ককাঁ, 
   {{0x249808cd,0x236c09a8,0x752401c6,0xa19402d5}},	//   sesm_, šejo_, _ehiz, магч, 
   {{0x85440228,0x2129da42,0x2f140037,0x00000000}},	//   _ээле, tmah_, nägu_, --, 
   {{0x75240356,0x2129da43,0x610400c0,0x00000000}},	//   _ghiz, umah_, kėle, --, 
   {{0x2129da44,0x00000000,0x00000000,0x00000000}},	// [35370] rmah_, --, --, --, 
   {{0x2129da45,0x75240810,0xceb42c22,0x9e959f80}},	//   smah_, _zhiz, мәс_, بارچ, 
   {{0x0c4801f2,0x21280c6a,0xdb18012d,0x00000000}},	//   _ịdịl, pmah_, zywó, --, 
   {{0xdb08068c,0x75240200,0x6ce400d4,0x3cf406e3}},	//   _preï, _xhiz, ніче, ंचें_, 
   {{0x2d8c010e,0x61040064,0x00000000,0x00000000}},	//   _äden_, gėle, --, --, 
   {{0x4fd40375,0x00000000,0x00000000,0x00000000}},	//   _חושב_, --, --, --, 
   {{0x3cfc10d1,0xceb000d9,0xea8806c2,0xee200150}},	//   _tjuv_, _בים_, سخون_, _берi_, 
   {{0x23681326,0x26ddda46,0xdb18033f,0x3cfc000d}},	//   _ovaj_, _alvo_, tywó, _ujuv_, 
   {{0x7525687f,0x7c39da47,0xd7c804fb,0x64400118}},	//   _rhiz, _igur, زوده_, ělil, 
   {{0x7524019b,0xe9a80372,0xca6800db,0x154401f0}},	//   _shiz, زدۉن_, _ولقۇ_, меом, 
   {{0x23680e3c,0x60dc02d0,0x2a64072d,0xf96801af}},	//   _avaj_, _olsm, _سُنّ, _ырай_, 
   {{0x2f143b52,0xd7d40114,0x00000000,0x00000000}},	//   lägt_, _ожењ, --, --, 
   {{0x75240810,0x321c0306,0xb7b000cf,0xc4c4026b}},	//   _vhiz, _švy_, _чөйч, фляж_, 
   {{0x60dc0cf9,0x387dda48,0xe8e0001e,0x7524045a}},	//   _alsm, lgur_, ượt_, _whiz, 
   {{0x752463dd,0x7c39da49,0x236805c7,0x00000000}},	//   _thiz, _ogur, _evaj_, --, 
   {{0x387c08d2,0x7c39da4a,0x6ee17983,0x3cf4012d}},	//   ngur_, _ngur, _möbe, ंचों_, 
   {{0xdb0800e4,0x130520bf,0x387c01a8,0x61e800df}},	// [35380] _areí, _озим, igur_, ĝela, 
   {{0x29000953,0x7c39da4b,0x60dc0998,0x66c4007f}},	//   čiai_, _agur, _elsm, _bòky, 
   {{0xdb0804cf,0xa301da4c,0x6ee03c86,0x60dc005c}},	//   _creí, _сүре, _nöbe, _flsm, 
   {{0x2ae00037,0x00000000,0x00000000,0x00000000}},	//   _कतहु_, --, --, --, 
   {{0xbb41da4d,0xdb0800e4,0x00000000,0x00000000}},	//   вечк, _ereí, --, --, 
   {{0x7c3801c0,0xdb080407,0x60dc037e,0xddd401ed}},	//   _egur, _freí, _zlsm, _edző, 
   {{0x7c380135,0x60dc0334,0xc9840120,0x00000000}},	//   _fgur, _ylsm, фули, --, 
   {{0x387dda4e,0x2b5800dd,0x6d5c0309,0xdb081cd4}},	//   ggur_, _فیصد_, _iwra, _creâ, 
   {{0x3b8005f5,0x6d480066,0xca855421,0x0c8401af}},	//   _илтг, _édab, _огай, _ныҡм, 
   {{0x6d5dda4f,0x0af001c0,0x7c39ab4e,0x6ee002d2}},	//   _kwra, _шүлэ, _zgur, _höbb, 
   {{0x6ee1da50,0x6aa8a0a9,0x6e3c01a6,0x64400210}},	//   _göbe, _iadf, _mgrb, ślim, 
   {{0x6aa80042,0x7778058a,0x00000000,0x00000000}},	//   _hadf, buux, --, --, 
   {{0x6aa800a2,0x00000000,0x00000000,0x00000000}},	//   _kadf, --, --, --, 
   {{0xf79002d5,0x6d5cd525,0x6ee1bb8a,0x00000000}},	//   _рашэ, _owra, _löbb, --, 
   {{0x23c4044e,0xf6780302,0x6aa9da51,0xb5a1caab}},	//   _bëjë_, _ואומ, _madf, _арый, 
   {{0x6738016d,0xd34402f2,0xc05800db,0x00000000}},	//   _hivj, بییه_, تشسا_, --, 
   {{0x6d5dda52,0x9344215c,0x00000000,0x00000000}},	// [35390] _awra, _كىيۇ, --, --, 
   {{0x7c39da53,0xbef80882,0x6d400e3c,0x6738031c}},	//   _sgur, ्वेन_, _čmar, _jivj, 
   {{0x5c75da54,0x6285da55,0x6d4002b5,0x6ee002d2}},	//   елет, _icho, _ōmar, _böbb, 
   {{0x60dc1445,0x2f14002f,0x00000000,0x00000000}},	//   _ulsm, wägt_, --, --, 
   {{0x6d5c0327,0xc0b81ee0,0x3d2801d5,0x6ee001d3}},	//   _ewra, ሰናል_, متچی_, _döbb, 
   {{0x213805b1,0x6aa8a4fd,0x6ee0002f,0xec68a978}},	//   _hish_, _cadf, _pöbe, прәк_, 
   {{0x6d5dda56,0x6284a7d0,0x2139da57,0x2f140e78}},	//   _gwra, _mcho, _kish_, rägt_, 
   {{0x7c3809a5,0x6aa803ac,0x628401b9,0x2018d9f6}},	//   _ugur, _eadf, _lcho, _kysi_, 
   {{0x2139da58,0x387c0ad9,0x6d5c0034,0x6aa9da59}},	//   _mish_, rgur_, _zwra, _fadf, 
   {{0x2139da5a,0x6285da5b,0x6aa9da5c,0x6d5c02d0}},	//   _lish_, _ncho, _gadf, _ywra, 
   {{0x6739da5d,0x6588016b,0xca780166,0xca38008f}},	//   _divj, _mɛhw, _citе, _זײער, 
   {{0x6285da5e,0x21380731,0x2edc16d1,0x6ee00139}},	//   _acho, _nish_, _यत्त, _xöbb, 
   {{0xd7f40ede,0xdcf400e2,0x6aa80175,0x386c0055}},	//   _язды, _apzī, _yadf, _idgr_, 
   {{0x213801f9,0x46a00032,0x6284002b,0x7ae00332}},	//   _aish_, _башв, _ccho, nhnt, 
   {{0x50b40046,0xf8d01fe5,0xc0ec001f,0x91e502e2}},	//   нсау, _तवाय, _ሁሌም_, хове, 
   {{0x6739da5f,0x00000000,0x00000000,0x00000000}},	//   _zivj, --, --, --, 
   {{0x2139da60,0x65880134,0x6285647e,0x9d7802d3}},	// [353a0] _dish_, _bɛhw, _fcho, _ብቐጻሊ_, 
   {{0x2139da61,0x2f140267,0x00000000,0x00000000}},	//   _eish_, vägs_, --, --, 
   {{0xb91401e1,0x6aa803fa,0x21388905,0x6ee0032e}},	//   _didẹ_, _radf, _fish_, _pöbb, 
   {{0x7c80f0b8,0xfce04f85,0x6aa8002d,0x2138062c}},	//   гуше, лохо, _sadf, _gish_, 
   {{0xdb0800a3,0xbc65b984,0x2018002f,0x62840857}},	//   _breà, رمون_, _gysi_, _ycho, 
   {{0x610402d5,0x1874001f,0x213801a9,0xf1c400d0}},	//   mėla, _በሀገር_, _zish_, chší_, 
   {{0x6ee0066d,0x2138036b,0x8e7c0092,0xdb2400ae}},	//   _több, _yish_, _ያምናሉ_, úpái, 
   {{0xdb080086,0x38ac01ed,0x67380023,0x69dc0790}},	//   _ereà, yörű_, _sivj, _ürem, 
   {{0x65880134,0xfce1da62,0xdb08004e,0xb760009d}},	//   _yɛhw, _сото, _freà, лтэй, 
   {{0xc66802f6,0xd58403e6,0x00000000,0x00000000}},	//   чшие_, چێوه_, --, --, 
   {{0x36d40323,0x29180055,0x00000000,0x00000000}},	//   хдээ_, _ūrau_, --, --, 
   {{0x2d980175,0x3eac00e2,0x555000e5,0x00000000}},	//   _mpre_, ēgti_, جھور, --, 
   {{0x21389d34,0x6738c6a3,0x499003e6,0x00000000}},	//   _rish_, _tivj, _شیکر, --, 
   {{0x29004077,0x24700016,0x213801b9,0xe5e404fb}},	//   čiau_, ễm_, _sish_, _لزبی, 
   {{0x62840122,0x6ec429d9,0x2139da63,0x61e8010f}},	//   _vcho, रानु, _pish_, ĝelo, 
   {{0x2138006c,0x62840034,0x61e801e4,0x00000000}},	//   _qish_, _wcho, ŝelo, --, 
   {{0x2d98434d,0x6285da64,0x644c03cb,0x2138b7c6}},	// [353b0] _apre_, _tcho, _ifai, _vish_, 
   {{0x6285da65,0x21380c30,0x30140137,0x201801ef}},	//   _ucho, _wish_, удур, _vysi_, 
   {{0x213807d6,0x644c0270,0x32d40139,0x92f001c6}},	//   _tish_, _kfai, _cäyu_, _түрх, 
   {{0x610400c0,0x00000000,0x00000000,0x00000000}},	//   bėla, --, --, --, 
   {{0xdb09da66,0x386c0120,0x644c009f,0x7ae000a3}},	//   _areá, _rdgr_, _mfai, thnt, 
   {{0xdb0801e7,0x00000000,0x00000000,0x00000000}},	//   _breá, --, --, --, 
   {{0x644c0421,0xdb0825e6,0x4970010b,0xe9a8007b}},	//   _ofai, _creá, ңләс, فدين_, 
   {{0x0c7004fb,0x644c00a3,0x316c0419,0x00000000}},	//   _نگهد, _nfai, ádzi_, --, 
   {{0x9b600075,0xdb0800a3,0x2d980010,0x3ab002dd}},	//   _ئۆتۈ, _treà, _zpre_, _бәйт, 
   {{0x644d6152,0xdb080077,0xcf9002e4,0x6ec400cd}},	//   _afai, _freá, סטי_, रायु, 
   {{0x644c0332,0x6efc007c,0xd670009d,0x00000000}},	//   _bfai, låbä, _хvнд, --, 
   {{0x8e340302,0x6ee0008e,0x03f000cc,0x00000000}},	//   כנתא_, _möba, _ঘড়ী_, --, 
   {{0x941c0134,0x6ec4041c,0x6ee0002f,0xf7700133}},	//   ɛtɛ_, रामु, _löba, _ڤاڵ_, 
   {{0xd251da67,0x644dda68,0x78a8032e,0x32d401f4}},	//   شنر_, _efai, _hagv, _näyt_, 
   {{0x45d01614,0x0160e846,0x644c00a9,0xab940092}},	//   _војс, икро, _ffai, _መግደል_, 
   {{0x78a817b5,0x00000000,0x00000000,0x00000000}},	//   _jagv, --, --, --, 
   {{0x2d9800a8,0x527400c7,0xa3a800e1,0x3f641d0f}},	// [353c0] _spre_, _иуну, _गैप_, кито_, 
   {{0x78a803cd,0x00000000,0x00000000,0x00000000}},	//   _lagv, --, --, --, 
   {{0x0d847111,0x254c00bc,0x3ea0bb65,0x91e463dd}},	//   тлен, _těle_, рихг, _роне, 
   {{0x6ee00793,0x78a80af9,0x00000000,0x00000000}},	//   _döba, _nagv, --, --, 
   {{0x3ea802f6,0xaca401f2,0x8fd01206,0x00000000}},	//   öitä_, laịt, _тәвә, --, 
   {{0xdb09911a,0xca740220,0x6d7c0023,0x69dc06be}},	//   _preá, туды, _ብጐይታ_, _ürek, 
   {{0x09047918,0x78a8037e,0x2d980010,0xf9a001d9}},	//   кчим, _bagv, _upre_, لٕوُ, 
   {{0x2bb400af,0xe9040022,0x00000000,0x00000000}},	//   ूमदा, ыҧеи, --, --, 
   {{0x3a200679,0xba2001e0,0x06c400eb,0x00000000}},	//   лмәг, лдәк, এসসি, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x24f9da69,0x644c0784,0x78a86672,0xa4d40212}},	//   енны_, _pfai, _fagv, гоні, 
   {{0x29000006,0x00000000,0x00000000,0x00000000}},	//   čias_, --, --, --, 
   {{0x236c00e8,0xe694010a,0xc3e000fb,0x00000000}},	//   éej_, _билы, рөйһ, --, 
   {{0x2b440810,0x78a801a6,0x00000000,0x00000000}},	//   _mumc_, _zagv, --, --, 
   {{0x69d800dd,0x644c0270,0x2b4401a4,0xddc400b0}},	//   nyve, _tfai, _lumc_, rahū, 
   {{0x44b001ec,0x00000000,0x00000000,0x00000000}},	//   _тұмс, --, --, --, 
   {{0x248801e4,0x3134117e,0x9f040472,0x00000000}},	// [353d0] _icam_, ретр, هورو, --, 
   {{0x644802d5,0x9400016b,0x628804a7,0x69d80fac}},	//   žeid, rekɔ_, đeos, kyve, 
   {{0xdc7400fd,0x7d00003e,0x2a78007c,0x00000000}},	//   гыль, énso, _örby_, --, 
   {{0xd1c8001f,0xdb080166,0x2d58084c,0x69b9d50d}},	//   _አልባ_, _kreç, тиць_, ्मनी, 
   {{0xefd40020,0x24880ac5,0x78a80165,0x7e446d7d}},	//   ከተው_, _mcam_, _ragv, _ахбе, 
   {{0xf4140375,0x78a800fe,0x2489709b,0xdce402b1}},	//   ספס_, _sagv, _lcam_, tuhē, 
   {{0x69d80e25,0xaac5da6a,0x248801fa,0x00000000}},	//   gyve, شتون, _ocam_, --, 
   {{0x248800f1,0x00000000,0x00000000,0x00000000}},	//   _ncam_, --, --, --, 
   {{0x78a800b8,0x00000000,0x00000000,0x00000000}},	//   _vagv, --, --, --, 
   {{0x24880076,0x69d81477,0x00000000,0x00000000}},	//   _acam_, byve, --, --, 
   {{0x69d80d27,0x6ec401bc,0x290000d0,0x9988012d}},	//   cyve, रातु, čiar_, łał_, 
   {{0xdb081762,0x2488067c,0xd1bc0023,0xd8a800ec}},	//   _breç, _ccam_, ደኣብ_, _سهتو_, 
   {{0xb404010b,0x00000000,0x00000000,0x00000000}},	//   рүпд, --, --, --, 
   {{0x64480f71,0x4340412c,0x8778008f,0xa6b40801}},	//   ñeir, серв, _נאצי, _всъщ, 
   {{0xd575da6b,0xdb080120,0xc68c01f7,0x61040064}},	//   _суль, _ereç, _رِي_, gėlo, 
   {{0x24880076,0xaca401f2,0x8fa5da6c,0xfd4c00cd}},	//   _gcam_, raịt, лабе, _utkṛ, 
   {{0xaca400b4,0xdb0800a2,0x63780139,0x7f580139}},	// [353e0] saịt, _greç, _исэр_, _çuql, 
   {{0xd17400fb,0x00000000,0x00000000,0x00000000}},	//   _йымы, --, --, --, 
   {{0x217400fd,0x777801a9,0xd1c80257,0x00000000}},	//   _куяр, hrux, _አልቦ_, --, 
   {{0x0b88f95e,0x8d18937d,0x32d40108,0xbea001ec}},	//   ески_, رزار_, _täys_, _қаск, 
   {{0x254c0316,0x60c80086,0x6ec40b7c,0x45600092}},	//   _měla_, _òema, रादु, _ለደንበ, 
   {{0x69d9da6d,0x2b4401f5,0xbb440691,0xbc440137}},	//   tyve, _vumc_, دلون_, _ۅركۉ, 
   {{0x2bd80050,0x00000000,0x00000000,0x00000000}},	//   बैजा, --, --, --, 
   {{0xd90c3345,0xfce035f2,0x9e6401ed,0xa7740108}},	//   ویل_, _лосо, _ماہن, алич, 
   {{0x5cf4010a,0x00000000,0x00000000,0x00000000}},	//   _тяру, --, --, --, 
   {{0x2489da6e,0x00000000,0x00000000,0x00000000}},	//   _scam_, --, --, --, 
   {{0x2bac07d0,0xeb2028d4,0x65940816,0xdad801c8}},	//   चिका, यतीत_, шану, _جهلڪ_, 
   {{0xdb080a16,0x7779da6f,0x2488062c,0xe46400a2}},	//   _preç, brux, _qcam_, _ülüş, 
   {{0x24880204,0x77780158,0xddc400e4,0x254c013a}},	//   _vcam_, crux, rahũ, _děla_, 
   {{0x248800ad,0xb2840150,0x00000000,0x00000000}},	//   _wcam_, йыск, --, --, 
   {{0x31c48807,0x290405e4,0xb2e80014,0x62340108}},	//   бств, onma_, ھٹہٕ_, реву, 
   {{0xd054016b,0xdb080200,0x3cf0000d,0xc54000e5}},	//   mhyɛ, _treç, _आगें_, _پڑگی, 
   {{0x645dda70,0x2904058a,0x835000e5,0x6f880014}},	// [353f0] mbsi, inma_, _چھڑا, ێنہِ_, 
   {{0xbd68b169,0x7f580166,0xb0340108,0x645dda71}},	//   ерде_, _çuqm, снуш, lbsi, 
   {{0x9f480ffb,0x00000000,0x00000000,0x00000000}},	//   zzaè_, --, --, --, 
   {{0x6294e9a7,0x98ac025c,0x00000000,0x00000000}},	//   lfzo, rmeċ_, --, --, 
   {{0x60cdda72,0xda6422e9,0x6ee002d2,0x5fb8000d}},	//   mjam, авли, _köbl, _उछिल, 
   {{0x450800bd,0x3eac005f,0xba7401d3,0x00000000}},	//   রতিক_, ēgts_, ااشت, --, 
   {{0x60cc0953,0x6ee1da73,0xd7880451,0xc9940092}},	//   ojam, _möbl, ھندو_, _መክፈል_, 
   {{0x60cc1269,0x7e640477,0x7779da74,0x6ee0002f}},	//   njam, _hejp, trux, _löbl, 
   {{0x7d18152d,0xa5e80032,0x60cc00e4,0x6c5400db}},	//   _ikus, ҫлыҡ_, ijam, _ыкту, 
   {{0x645c0369,0x60cdda75,0x6ee005d5,0x77791b9c}},	//   ebsi, hjam, _nöbl, rrux, 
   {{0x60cdda76,0x7e64047e,0xaa453b7b,0x2904003e}},	//   kjam, _mejp, _انمى, bnma_, 
   {{0x60cc96a9,0x70d40d0d,0x895800d9,0x7981da77}},	//   jjam, _धकेल, _ידעת, munw, 
   {{0x6ee034eb,0x7d184180,0x7981da78,0x9988012d}},	//   _böbl, _mkus, lunw, łań_, 
   {{0x60cc00da,0x7e640316,0xe61003e6,0x645dda79}},	//   ejam, _nejp, _کشه_, absi, 
   {{0x7d19da7a,0x254c012c,0xdb08003b,0x798004ba}},	//   _okus, _těla_, _greå, nunw, 
   {{0x0f1c05d7,0x7d19da7b,0x60cdda7c,0x657dda7d}},	//   भत्स_, _nkus, gjam, árhe, 
  
   {{0x7e64047e,0xa4840137,0x0fc4010b,0xe04808f0}},	// [35400] _bejp, _اجىن, шйан, اشفه_, 
   {{0x63a904ff,0x7981da7e,0x9e641916,0x60cdda7f}},	//   çene, kunw, مامن, ajam, 
   {{0xc27805e1,0x7e640455,0xd1b0036b,0x645403b2}},	//   _בריי, _dejp, _بیزک, _áeið, 
   {{0xf764168d,0x7981a15a,0x60cc0034,0x622415bf}},	//   _وا_, dunw, cjam, _دىپل, 
   {{0x7d180036,0x00000000,0x00000000,0x00000000}},	//   _dkus, --, --, --, 
   {{0x7d1848b5,0x79802935,0x7e6401e4,0x00000000}},	//   _ekus, funw, _gejp, --, 
   {{0xf9644f35,0x7981da80,0x645c0014,0x1e94010b}},	//   арый_, gunw, ybsi, _уряр, 
   {{0x1cc4025c,0x764000cd,0x00000000,0x00000000}},	//   _ཏོར_, _agny, --, --, 
   {{0x6d41da81,0x79800083,0x7b84313e,0x4aa80139}},	//   _iima, aunw, _نالە, _икан_, 
   {{0x6d41da82,0x7d180316,0x60cc44f3,0x645c01d4}},	//   _hima, _zkus, zjam, wbsi, 
   {{0x6d41da83,0xfb1010de,0x60cc00c0,0x99f41cd0}},	//   _kima, _بولج, yjam, _ляці, 
   {{0xb8800209,0xbb200131,0x00000000,0x00000000}},	//   _душй, ﭼﭽﻪ_, --, --, 
   {{0x6d41da84,0xaca401f2,0x645dda85,0x6b8408c2}},	//   _mima, _nzọp, rbsi, àigh, 
   {{0x6d41da86,0x35f4034c,0xc2040640,0xb6a00166}},	//   _lima, ارید_, аџби, _мичл, 
   {{0x60cdda87,0xaca402e3,0x6d41077c,0xb5c40244}},	//   tjam, _azọp, _oima, _نووم_, 
   {{0x6d41da88,0x60cc2ba4,0x23b49a73,0x5ff40114}},	//   _nima, ujam, _همبس, бзбу, 
   {{0x60cdda89,0x7e64009b,0xa30800e5,0x61600023}},	// [35410] rjam, _pejp, _مردے_, ታቶራዊ_, 
   {{0x63adc469,0x1cc40156,0x53980302,0x60cdda8a}},	//   _isan, _ཏོཤ_, _עיתו, sjam, 
   {{0x6d41da8b,0x254c012c,0x7d1804ce,0x60cc9825}},	//   _bima, _mělo_, _pkus, pjam, 
   {{0x6d41da8c,0x798007a9,0x7e64016d,0x00000000}},	//   _cima, vunw, _wejp, --, 
   {{0x6d41da8d,0x7e64016d,0x7d180313,0x63ac004e}},	//   _dima, _tejp, _vkus, _jsan, 
   {{0xd9445c81,0x63ad7b53,0x1ee40014,0x98ac0b4b}},	//   беки, _msan, _آسِ, rmeč_, 
   {{0x6d41da8e,0x63ac036b,0xa3a81d15,0x7c841cd0}},	//   _fima, _lsan, _गैस_, _вузе, 
   {{0x7d1829e5,0x6d41da8f,0x9b440ee8,0x15b8010b}},	//   _ukus, _gima, _هنرو, ңыны_, 
   {{0x63adda90,0x798002d0,0x00000000,0x00000000}},	//   _nsan, sunw, --, --, 
   {{0x46e44276,0x6d401813,0xadc40248,0x7980034c}},	//   йдын_, _zima, _atẹr, punw, 
   {{0x99d80491,0x6d41da91,0xd4684f2e,0x79800784}},	//   _حواء_, _yima, лине_, qunw, 
   {{0x6d41da92,0xd9b401d9,0x1cc40327,0x6d5801e4}},	//   _xima, _پٔچھ, _ཏོས_, ŭvag, 
   {{0x69cc0311,0x63acb941,0xd4140139,0x00000000}},	//   ăneş, _csan, сьны, --, 
   {{0x63ac020b,0x59bc00dc,0x8c1802e4,0x03a006ed}},	//   _dsan, ्मपर, רושי, џиро, 
   {{0x9555da93,0x63adda94,0x69dc0ab7,0x00000000}},	//   _اختا, _esan, _üret, --, 
   {{0x63a8036e,0x00000000,0x00000000,0x00000000}},	//   çenc, --, --, --, 
   {{0x6d404375,0x4f081f10,0x412474a0,0x12e400cc}},	// [35420] _rima, гнан_, сото_, _নদীদ, 
   {{0x52a8026a,0x00000000,0x00000000,0x00000000}},	//   _свом_, --, --, --, 
   {{0x6d41da95,0x10a404b4,0x6f1c0427,0xb81000fe}},	//   _pima, _линн, _vkrc, াইটত_, 
   {{0x6d41da96,0x61e028b3,0xeb206b9b,0x63ac01d5}},	//   _qima, ølle, यत्त_, _ysan, 
   {{0x6d403d91,0xfbcc0b24,0x63ac0072,0x00000000}},	//   _vima, فتو_, _xsan, --, 
   {{0x6d41da97,0x6f1c07f5,0x906002dd,0x00000000}},	//   _wima, _ukrc, _ﺠﻟا_, --, 
   {{0x6d41da98,0x6935da99,0x00000000,0x00000000}},	//   _tima, онку, --, --, 
   {{0xa3a8033d,0x6d41da9a,0x09282091,0xd90c0344}},	//   _गईल_, _uima, دستي_, پیه_, 
   {{0x7b055996,0x69b802c3,0x00000000,0x00000000}},	//   órtá, ्मही, --, --, 
   {{0x63ac01d5,0x94dc03b9,0x37a402e8,0x00000000}},	//   _rsan, _içən_, стън_, --, 
   {{0x63ac0a49,0xfaa0bbb8,0xe53400f5,0x27300051}},	//   _ssan, _хахо, жень, hàng_, 
   {{0x63ac012c,0x6fc81098,0xf40400fe,0x3cf800cd}},	//   _psan, रमां, ৰেছৰ_, लोपे_, 
   {{0x254c012c,0x7d0000d5,0x69b8878d,0x00000000}},	//   _tělo_, énsi, ्मवी, --, 
   {{0x224403d4,0x61040006,0x248c0034,0x69dc01d3}},	//   ølk_, mėli, żem_, _üres, 
   {{0xa3a819e5,0x31c41b6b,0x61040006,0x63ac020c}},	//   _गैर_, пств, lėli, _wsan, 
   {{0x63adda9b,0x00000000,0x00000000,0x00000000}},	//   _tsan, --, --, --, 
   {{0x610402d5,0xf49423bb,0x9f480129,0xa2440228}},	// [35430] nėli, _رشيد, rzaï_, _وردۇ, 
   {{0xe598001f,0x3cf801ad,0x7b1c00d8,0xfbc000eb}},	//   _ፈቃደኛ_, लोने_, nêut, ্নমত, 
   {{0x80c403d4,0x00000000,0x00000000,0x00000000}},	//   ৰোগ্, --, --, --, 
   {{0x61040006,0xd0180107,0x5bb8447e,0x00000000}},	//   kėli, уфӣ_, илея_, --, 
   {{0x3ae80212,0x61e80115,0x27300051,0x6f85da9c}},	//   _løpe_, ĝelu, càng_, _нурж, 
   {{0x61040006,0x273005d5,0xaac403cc,0x00000000}},	//   dėli, nànd_, كتىن, --, 
   {{0xd12c01d9,0xceb00a7c,0x00000000,0x00000000}},	//   _سۅے_, _קיל_, --, --, 
   {{0xa3a80034,0x273004cc,0xfd100956,0x00000000}},	//   _गईं_, hànd_, _رجز_, --, 
   {{0x61040024,0xa3a800ab,0x2d8c00a2,0x6d3400d8}},	//   gėli, _गैल_, _äder_, _хетф, 
   {{0x9b4400ec,0x69b81bd6,0x9984013a,0x00000000}},	//   _هنڱو, ्मशी, _uzlů_, --, 
   {{0xd629da9d,0xb88000d0,0x1ae401e0,0x4af400f2}},	//   роне_, _príď, _лоҡм, _بکند_, 
   {{0x657c0008,0x3990315a,0x3ae80fac,0x61040064}},	//   árha, mãs_, _døpe_, bėli, 
   {{0x7825da9e,0xe7081547,0x399000d8,0x69dc1ea0}},	//   _اعال, شتین_, lãs_, _ürer, 
   {{0x7b1c06ed,0x09a8025c,0x7ae00548,0x55e49808}},	//   cêut, _བརྩ_, nknt, _молб, 
   {{0x91e40395,0x00000000,0x00000000,0x00000000}},	//   цове, --, --, --, 
   {{0xd710015b,0x00000000,0x00000000,0x00000000}},	//   _হওয়া_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [35440] --, --, --, --, 
   {{0x660c03e0,0xa3a801f7,0x00000000,0x00000000}},	//   _çokç, _اُٿل_, --, --, 
   {{0x15cc0150,0x98a40064,0xa18401ec,0x00000000}},	//   _ﯗﻳﺪﻩ, _nulį_, _нұра_, --, 
   {{0x0c24228e,0x6ee0b1e1,0x8c4448e5,0x399000d8}},	//   омен, _möbi, цеде, dãs_, 
   {{0xaa582bbd,0x00000000,0x00000000,0x00000000}},	//   билу_, --, --, --, 
   {{0x61040006,0x00000000,0x00000000,0x00000000}},	//   vėli, --, --, --, 
   {{0x399000d8,0x933c0092,0xdc640092,0x00000000}},	//   gãs_, በረታታ, _ሲጀምር_, --, 
   {{0x61040024,0x3ae8143a,0xfe4000d4,0x00000000}},	//   tėli, _røpe_, _інто, --, 
   {{0xddc401fa,0x0708013e,0x00000000,0x00000000}},	//   mahš, ихои_, --, --, 
   {{0x61040006,0xda644caa,0xd9d800ec,0x00000000}},	//   rėli, _فامي, _گهمڻ_, --, 
   {{0x81dc00bd,0xbb38008f,0x273004cc,0x69c401c0}},	//   _দেন_, _כעמי, vànd_, _хөлб, 
   {{0x87e42081,0xd76401d3,0x61040064,0x00000000}},	//   _мюле, _کنوی, pėli, --, 
   {{0x7b1c0120,0x273004cc,0xecbc00fe,0x00000000}},	//   pêut, tànd_, _অকাড, --, 
   {{0x050800bd,0x25bc0175,0x00000000,0x00000000}},	//   রতের_, _trvl_, --, --, 
   {{0x6ee001b8,0x62243ee0,0x2a6c0142,0x2731da9f}},	//   _göbi, سىرل, _medb_, rànd_, 
   {{0x273004cc,0xfbc00154,0x00000000,0x00000000}},	//   sànd_, ্নতত, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [35450] --, --, --, --, 
   {{0xd044043b,0x62354a73,0x7de433d2,0x00000000}},	//   _kokɛ, _непу, يسام, --, 
   {{0xac58063f,0xde1800c6,0x00000000,0x00000000}},	//   _ịnụb, حقات_, --, --, 
   {{0xd0440085,0x6ce400d4,0x00000000,0x00000000}},	//   _mokɛ, міче, --, --, 
   {{0x7ba40597,0xeff802d3,0xd0440165,0xfba8010a}},	//   تصام, ወተይ_, _lokɛ, ртей_, 
   {{0x09a86d7e,0x39900798,0x6d58022a,0xdc640092}},	//   _བརྡ_, tãs_, ívac, _ሲጀመር_, 
   {{0x15cc0220,0x00000000,0x00000000,0x00000000}},	//   _ﯗﻳﺮﻩ, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6b741823,0x2368033b,0xb9000254,0x96b80114}},	//   _олту, _nwaj_, _नक_, буну_, 
   {{0xd044043b,0xcf90010f,0x95840828,0x2919daa0}},	//   _bokɛ, עטי_, плое, _íran_, 
   {{0xd7c80397,0x7d09724c,0xd91401ee,0x00000000}},	//   _گوشه_, ongs, _еджы, --, 
   {{0x49980302,0x7d080194,0x79800083,0x00000000}},	//   _לשעב, nngs, mrnw, --, 
   {{0xddd400dd,0x7d08c5be,0xd7c80345,0x96642d57}},	//   _mező, ings, _دوشه_, _екле, 
   {{0x6ee0014a,0x8c1805d0,0x2368012d,0x65880162}},	//   _töbi, מורי, _dwaj_, ðshø, 
   {{0x81dc015b,0x5468011c,0x00000000,0x00000000}},	//   _দেব_, _лайм_, --, --, 
   {{0x61040153,0x61e10d70,0x00000000,0x00000000}},	//   kėlu, ølla, --, --, 
   {{0x23680327,0x0081a32c,0x00000000,0x00000000}},	// [35460] _gwaj_, элто, --, --, 
   {{0x59bc2bf1,0x7d080097,0x00000000,0x00000000}},	//   ्मार, engs, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9988033f,0x00000000,0x00000000,0x00000000}},	//   łaś_, --, --, --, 
   {{0xf8bc00a5,0xddc401f1,0x00000000,0x00000000}},	//   _शोधय, rahš, --, --, 
   {{0xeaf823e9,0x00000000,0x00000000,0x00000000}},	//   ्चेत_, --, --, --, 
   {{0xba71daa1,0x7d08003e,0x00000000,0x00000000}},	//   راوت, bngs, --, --, 
   {{0x1cc40ed9,0x2d7804a7,0x6ec4193d,0x00000000}},	//   _ཏོག_, mče_, राकु, --, 
   {{0x4c3401c0,0x7980d0ab,0x2d786b92,0x00000000}},	//   _хэвт, arnw, lče_, --, 
   {{0x6d5c020c,0xdb0800a2,0x657c01d3,0x00000000}},	//   _ktra, _kreý, árho, --, 
   {{0x2d780331,0x6d5c0472,0xf67005f5,0x47d80154}},	//   nče_, _jtra, эгээ, _বেশী, 
   {{0x6d5c01fb,0x00000000,0x00000000,0x00000000}},	//   _mtra, --, --, --, 
   {{0x2d78151c,0xe694e498,0x254c0316,0x38c8030f}},	//   hče_, _жилы, _měli_, _دالی_, 
   {{0x6d5ddaa2,0x00000000,0x00000000,0x00000000}},	//   _otra, --, --, --, 
   {{0x6d5ddaa3,0x2d78bc55,0x3e800241,0x00000000}},	//   _ntra, jče_, _létà_, --, 
   {{0x972c0023,0x3ebc56a3,0x850000ec,0x2d7801ef}},	//   _ትብዓት, _şut_, _ڊوڙن, dče_, 
   {{0x3ae805ac,0x3014011c,0x00000000,0x00000000}},	// [35470] _løpa_, едтр, --, --, 
   {{0x1cc40dd4,0x7d0803a2,0xdb08010e,0x79800042}},	//   _ཏོང_, wngs, _breý, yrnw, 
   {{0x6d5ddaa4,0x63bc0158,0x7d08020c,0x00000000}},	//   _ctra, lvsn, tngs, --, 
   {{0x7d09daa5,0x6d5ddaa6,0x16a8033f,0x3d14012d}},	//   ungs, _dtra, _कस्ब, तवें_, 
   {{0x212850f9,0xdb0800a2,0x61e001e3,0x00000000}},	//   mlah_, _ereý, ällf, --, 
   {{0x6d5cdce5,0xd1c80092,0x00000000,0x00000000}},	//   _ftra, _አውቆ_, --, --, 
   {{0x7f4c003a,0xdb0800a2,0x00000000,0x00000000}},	//   _hucq, _greý, --, --, 
   {{0x2129daa7,0xdb0805c7,0x672801a4,0x4a5000fd}},	//   nlah_, _hreü, eldj, нкәс, 
   {{0xd1c0a81e,0x21285101,0x6d5c012c,0x63a8eab4}},	//   _ስደት_, ilah_, _ztra, çenl, 
   {{0x2129daa8,0x3cfc01d4,0x7f44014f,0x55e4094e}},	//   hlah_, _hmuv_, _jijq, дооб, 
   {{0x2128dede,0x6d5ddaa9,0xfd6000b8,0x15b80006}},	//   klah_, _xtra, _pitṅ, цыпы_, 
   {{0xdb1800d2,0x21280978,0x00000000,0x00000000}},	//   dvwé, jlah_, --, --, 
   {{0x2128016d,0x4c980302,0x3f8c004e,0x4364497a}},	//   dlah_, חברו, àgul_, маян_, 
   {{0x21280548,0x07a00117,0x00000000,0x00000000}},	//   elah_, _рашн, --, --, 
   {{0x21280ac5,0x50b402dd,0x00000000,0x00000000}},	//   flah_, мсау, --, --, 
   {{0x2129daaa,0x2d7814b2,0x273006d9,0x00000000}},	//   glah_, vče_, màna_, --, 
   {{0x7525daab,0x27301311,0x7f44014f,0xcf4400d4}},	// [35480] _ikiz, làna_, _bijq, днай, 
   {{0x2129daac,0x69dc00d8,0x61f40112,0x2d7802f0}},	//   alah_, _àreg, ßflä, tče_, 
   {{0x550011b1,0x27301311,0x2128016d,0x65880134}},	//   _लगाए_, nàna_, blah_, _bɛhy, 
   {{0xfce03117,0x3cfc00b5,0x0ba80e56,0x3ae80158}},	//   кохо, _cmuv_, قاتى_, _røpa_, 
   {{0x273006d9,0x7524009f,0x7d000066,0x201c0327}},	//   hàna_, _mkiz, ènsa, żwir_, 
   {{0xaa59daad,0x2d788185,0x273003d1,0x6d5c0135}},	//   чику_, pče_, kàna_, _ttra, 
   {{0x6d5ddaae,0x75241418,0x273006d9,0xfe400022}},	//   _utra, _okiz, jàna_, _анро, 
   {{0x7525daaf,0x27315332,0xff5c0142,0xd6740150}},	//   _nkiz, dàna_, _frîd_, _ﺼﺩﻭﺭ_, 
   {{0x64480006,0xdcac00cf,0xd90c158f,0x00000000}},	//   žeik, _دۉن_, حین_, --, 
   {{0x75255ac8,0x212805b1,0x273003d1,0x00000000}},	//   _akiz, zlah_, fàna_, --, 
   {{0x2129dab0,0x6588016b,0x273005da,0x00000000}},	//   ylah_, _yɛhy, gàna_, --, 
   {{0xfa301b16,0xc7640dd8,0x212805b1,0xa4d402bf}},	//   _شىنج, _قاتى, xlah_, хомі, 
   {{0x29041326,0x2128016d,0x00000000,0x00000000}},	//   mima_, vlah_, --, --, 
   {{0x75242252,0x273006d9,0x63bc06ea,0x2128047e}},	//   _ekiz, bàna_, rvsn, wlah_, 
   {{0x2128d257,0xf2057af5,0x9a9402d3,0x69dc00d8}},	//   tlah_, вято, _ዘኽእል_, _àred, 
   {{0x2128207a,0x75040124,0x00000000,0x00000000}},	//   ulah_, _аџье, --, --, 
   {{0x2129dab1,0x26dc02d5,0x6d580308,0x644ddab2}},	// [35490] rlah_, _kovo_, ívan, _igai, 
   {{0x2129dab3,0x26dc0cf4,0x7f44047e,0xf6280137}},	//   slah_, _jovo_, _qijq, _اتۇۇ_, 
   {{0x2129dab4,0x61e004f3,0x644ca5e6,0x26dc00c8}},	//   plah_, älld, _kgai, _movo_, 
   {{0x26dddab5,0xc0c400aa,0xca78022e,0x2128e0a1}},	//   _lovo_, _تېره_, _shtа, qlah_, 
   {{0x644c0161,0x27300170,0x7f440477,0x00000000}},	//   _mgai, zàna_, _tijq, --, 
   {{0x60dc016d,0xff5c0022,0xe3b000cc,0x00000000}},	//   _hosm, _itî_, _চপাব, --, 
   {{0x60dddab6,0xdb0801ab,0x644ddab7,0x6e940261}},	//   _kosm, _breò, _ogai, _ширу, 
   {{0x644ddab8,0xdb080ba1,0x60dc0477,0x273003d1}},	//   _ngai, _creò, _josm, vàna_, 
   {{0xd7c8dc6f,0x26dddab9,0x60dc0023,0xe7f401c6}},	//   سوده_, _bovo_, _mosm, вчээ, 
   {{0x7525daba,0x644cf69d,0x60dc047e,0x26dc0395}},	//   _skiz, _agai, _losm, _covo_, 
   {{0x2905dabb,0x26dc02fa,0xead40801,0xeff800b7}},	//   bima_, _dovo_, _шофь, ወሰደ_, 
   {{0x29041326,0x27300170,0x60dddabc,0xdb081db0}},	//   cima_, ràna_, _nosm, _greò, 
   {{0x26dc0793,0x644c004e,0xdb0805c7,0x273003d1}},	//   _fovo_, _dgai, _hreñ, sàna_, 
   {{0x644ddabd,0xdb080dd4,0x60dc01c3,0x78b9dabe}},	//   _egai, _kreñ, _aosm, lduv, 
   {{0x60dddabf,0x644c01ab,0xf8d000dc,0x7524022e}},	//   _bosm, _fgai, थापय, _tkiz, 
   {{0x78b9dac0,0x69c05843,0x7525d020,0x69dc00f7}},	//   nduv, विती, _ukiz, _àree, 
   {{0xefbc0020,0x60dddac1,0x13b4007b,0x43901f5a}},	// [354a0] _ታዲያ_, _dosm, _أصبح, _бањс, 
   {{0x2905dac2,0x9e6400d1,0x6d5800e5,0x00000000}},	//   zima_, نامن, ívao, --, 
   {{0x2905dac3,0x60dc020c,0xa3017b88,0x4c849c0b}},	//   yima_, _fosm, _түре, елев, 
   {{0x61e1dac4,0x60dddac5,0x00000000,0x00000000}},	//   älle, _gosm, --, --, 
   {{0x29041326,0x37dc015b,0x46d000dc,0x00000000}},	//   vima_, _বেসর, तामह, --, 
   {{0x2905dac6,0xdb08568e,0x2fc000b5,0x60dddac7}},	//   wima_, _breñ, mvig_, _zosm, 
   {{0x26dc08cd,0x98a40ac4,0x60dc047e,0x291808a5}},	//   _rovo_, _atlı_, _yosm, _írak_, 
   {{0xdb080489,0x26dc0162,0x6fc418cc,0x4789dac8}},	//   _dreñ, _sovo_, रिपू, псом_, 
   {{0x3854a2f2,0x26dddac9,0x6b440124,0xdb0801c4}},	//   رشيد_, _povo_, _адаҕ, _ereñ, 
   {{0x644ddaca,0x1b000116,0x38302cc8,0xf1d00e5b}},	//   _sgai, _күчн, ыныр, हमान, 
   {{0x26dddacb,0xfe98008d,0xdb09dacc,0x00000000}},	//   _vovo_, היימ, _greñ, --, 
   {{0x2fc00158,0xdb08032e,0x59d801f9,0x61e003b2}},	//   kvig_, _hreð, _बॅटर, øllm, 
   {{0x26dc23e0,0xf8b00bd9,0x2fc001f5,0x66b45b66}},	//   _tovo_, _תשנ_, jvig_, _аблу, 
   {{0x26dc00a7,0x60dddacd,0x06740395,0x82340271}},	//   _uovo_, _sosm, _чудя, فرزا, 
   {{0x60dc3d2d,0x6d5802fb,0x2fc001f5,0x75e00139}},	//   _posm, íval, evig_, _бәяҗ, 
   {{0x644ddace,0x09a8025c,0x3f980003,0x3494022e}},	//   _ugai, _བརླ_, ttqu_, _баър, 
   {{0x61e001e6,0xff51dacf,0x60dc0393,0xf0e815bf}},	// [354b0] ällb, اخر_, _vosm, رىكى_, 
   {{0x6ee00254,0x00000000,0x00000000,0x00000000}},	//   _söbr, --, --, --, 
   {{0x5c7409a5,0xbd4800c6,0x60dddad0,0x81dc0154}},	//   влет, سؤال_, _tosm, _দের_, 
   {{0x2fc00158,0x78b8017a,0x8c840124,0x9b740472}},	//   bvig_, xduv, кәуа_, ناتص, 
   {{0x09dc02f5,0xdb0803b2,0x00000000,0x00000000}},	//   _ভেলা, _breð, --, --, 
   {{0xeb080131,0xdb09dad1,0x00000000,0x00000000}},	//   ىقنى_, _preñ, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdcac00db,0xda6400ec,0x00000000,0x00000000}},	//   _گۉچ_, راڻي, --, --, 
   {{0x78b9dad2,0x75e801ed,0x1ce00327,0xdb0802d2}},	//   rduv, közö, _ཧྭར_, _freð, 
   {{0xdb09dad3,0x2730002e,0xfd4c00dc,0x67540244}},	//   _treñ, sànn_, _sukṛ, دیوس_, 
   {{0xe4740020,0xdb080789,0xd9e400ce,0xf934010b}},	//   _ጠንካራ_, _ureñ, _कथित_, _коpе_, 
   {{0xd8883e1a,0x6fc411a6,0x3b0403b9,0x00000000}},	//   _آپشن_, रिमू, linq_, --, 
   {{0x1cc4025c,0x98a4013d,0x00000000,0x00000000}},	//   _ཏོན_, _utlı_, --, --, 
   {{0x69dcb4a2,0x48100075,0x59c408df,0x3b0403e3}},	//   _àrec, _әмәс, विपर, ninq_, 
   {{0x2018022e,0xeff8010c,0xdb080037,0x00000000}},	//   _axsi_, ወደድ_, _iseä, --, 
   {{0x8fa42ff7,0x00806d5f,0xc614011a,0x6d580419}},	//   кабе, илсо, _בחצי_, ívam, 
   {{0x412418ec,0xcc1001f2,0x7778022e,0x3b0406be}},	// [354c0] тото_, họrị, nsux, kinq_, 
   {{0x2fc1dad4,0xcc1000b4,0x2bb805f9,0xd1b0179e}},	//   rvig_, kọrị, _इनबा, _پیرک, 
   {{0x2fc02aad,0x3b0406be,0x940400ec,0x00000000}},	//   svig_, dinq_, _سوگه, --, 
   {{0x13e400bd,0x5cc40046,0xc5f40011,0xe7f400bc}},	//   _পেয়, лсіз, _চশমা_, इनमा_, 
   {{0x8b94fac2,0xfbcc0137,0x3b0403b9,0x00000000}},	//   треч, قتو_, finq_, --, 
   {{0x7bdc1196,0x00000000,0x00000000,0x00000000}},	//   äqua, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfce0584b,0xb9e000d6,0xe7b800cf,0x00000000}},	//   _косо, ріши, егиш_, --, 
   {{0xfce0052f,0x0c24039e,0x69c0193d,0xdb0808ce}},	//   _тото, _рман, विही, _treð, 
   {{0xfaa016c3,0x3f8c00e4,0x61e003b2,0x00000000}},	//   _вафо, àgui_, øllk, --, 
   {{0x499004d3,0xaca4063f,0x75e801d3,0x00000000}},	//   _ئیبر, agụt, vözö, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d580122,0x7cf00724,0xc69001d9,0x75e800e5}},	//   ívaj, _uçre, _نِش_, tözö, 
   {{0xa19405f5,0x659471a4,0x21380051,0x00000000}},	//   лагч, _баку, _shsh_, --, 
   {{0x250400b8,0x4124003b,0xb0c401f9,0x75e800e5}},	//   _haṭṭ, вфаб, _लोहग, rözö, 
   {{0x3b040213,0x7ff4030f,0x00000000,0x00000000}},	//   zinq_, پسرا, --, --, 
   {{0x74f81ee3,0x645c01d3,0x00000000,0x00000000}},	// [354d0] _шеър_, mcsi, --, --, 
   {{0x9e740330,0xceb43c1a,0x645c01d3,0x1df80139}},	//   اهات, ләс_, lcsi, незы_, 
   {{0xfa3000c7,0x645c015d,0x91c001af,0x00000000}},	//   hẽrõ_, ocsi, _ләтл, --, 
   {{0x645d0320,0x69dc1cce,0x00000000,0x00000000}},	//   ncsi, _ürey, --, --, 
   {{0xac840046,0x3b0400ac,0x6280033f,0xb4fc011a}},	//   ргіл, tinq_, ólow, ולאר, 
   {{0x6295dad5,0x8f980302,0x45080c58,0x645c0175}},	//   ngzo, _אישי, ৰতিক_, hcsi, 
   {{0xf2d404ac,0x3b0400ac,0x39b40213,0x61e00162}},	//   יעס_, rinq_, _kəsə_, øllh, 
   {{0x8bd4008e,0x8cc8134e,0x00000000,0x00000000}},	//   тмәс_, _सोपो, --, --, 
   {{0x57480107,0xc0d00092,0x3b0403b9,0x00000000}},	//   нзим_, _የጎሳ_, pinq_, --, 
   {{0x2be00316,0x25040055,0x3ea4022e,0xa3c801f9}},	//   कहरू_, _daṭṭ, еnti_, ोमन_, 
   {{0x85e401c6,0x00000000,0x00000000,0x00000000}},	//   гдэв_, --, --, --, 
   {{0x9a98005f,0x645c01ed,0x629401f5,0x39b40213}},	//   žādā, gcsi, egzo, _nəsə_, 
   {{0x59bc0303,0x00000000,0x00000000,0x00000000}},	//   ्मकर, --, --, --, 
   {{0xc7b00375,0x00000000,0x00000000,0x00000000}},	//   _לבד_, --, --, --, 
   {{0x65b83088,0x66243e52,0x00000000,0x00000000}},	//   _ауыр_, _پروك, --, --, 
   {{0x61e0049f,0x66d800d2,0xe61004fb,0x0d840032}},	//   älla, _túkû, _بشه_, ҫлан, 
   {{0xb348003d,0x00000000,0x00000000,0x00000000}},	// [354e0] _agħż, --, --, --, 
   {{0x4df4169c,0x27e000a3,0x2c0400cd,0x00000000}},	//   ляет, _àine_, _शेषं_, --, 
   {{0x0ca9571c,0x80bc15e0,0x91e5dad6,0x80d00eac}},	//   етли_, _लोके, _соне, _সতর্, 
   {{0x0c740722,0x62800f91,0x8b640244,0x00000000}},	//   اداد, ólov, هاتم, --, 
   {{0x6d60107d,0x2cf401f9,0x00000000,0x00000000}},	//   _žvač, _आतील_, --, --, 
   {{0xca740323,0x6b8401fa,0x250400cd,0x00000000}},	//   ууды, šigo, _kaṣṭ, --, 
   {{0xd90c03e6,0x00000000,0x00000000,0x00000000}},	//   ژیم_, --, --, --, 
   {{0x8c4447bf,0x61e00579,0x250400cd,0xa85406bd}},	//   _бебе, ølli, _paṭṭ, шкич, 
   {{0xa6f4cec6,0x47d800fe,0x00000000,0x00000000}},	//   изиш, _বেজী, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3cf800dc,0xf7f001d5,0x250400dc,0x00000000}},	//   लोके_, لسید, _naṣṭ, --, 
   {{0x69c9dad7,0x04642401,0xab940240,0x00000000}},	//   _irde, ытом, _ዘልዕል_, --, 
   {{0xfbc42e1e,0x090400dd,0x69c802f0,0x645cef7b}},	//   लियम, _لڑکی_, _hrde, rcsi, 
   {{0x69c80010,0xb3540063,0x39b403e3,0x00000000}},	//   _krde, скрш, _səsə_, --, 
   {{0x69d80d27,0x250400b8,0xaa84010e,0x629401a4}},	//   nxve, _caṣṭ, _gaýş, rgzo, 
   {{0x7cf01248,0x2504002b,0x555001ed,0x388800c0}},	//   _oçra, _daṣṭ, _گھیر, _gėrį_, 
   {{0xdb0805da,0xa3e800cd,0x00000000,0x00000000}},	// [354f0] _kreô, _यथि_, --, --, 
   {{0x200c00fc,0x63addad8,0x3f8404b9,0x64480006}},	//   _þeim_, _ipan, čnu_, žeis, 
   {{0x6285dad9,0xdc5406ed,0xff5c0142,0xd1000562}},	//   _idho, авењ, _grîn_, रोहण_, 
   {{0xa3e81161,0x6aa89da5,0x00000000,0x00000000}},	//   _यथा_, _abdf, --, --, 
   {{0xa2d80b7c,0x09a8031c,0x3ae806ea,0xca4c02dd}},	//   माप्, _བརྔ_, _høpi_, _ﺍﻟﺨ_, 
   {{0x63addada,0x084c02e3,0x69c801ef,0x80d00073}},	//   _mpan, _kọfị_, _brde, डावे, 
   {{0x69c80356,0xaac4a754,0x19b80006,0xec2800db}},	//   _crde, صتون, туль_, _ەكقى_, 
   {{0x63addadb,0x178401b9,0x86f801e1,0xca68022e}},	//   _opan, агим, _ròpọ, sofа, 
   {{0x6284389c,0x63adbd40,0xccf00302,0x69dc0129}},	//   _odho, _npan, _וכן_, _àren, 
   {{0x3eb08d34,0x7d09dadc,0x6285dadd,0x46e401c0}},	//   next_, ligs, _ndho, идын_, 
   {{0xa2d835a7,0x273002d3,0x69c880b6,0xd469dade}},	//   मान्, _ደኣምበ, _grde, кине_, 
   {{0xd0440085,0x7d09dadf,0x09a8025c,0x273001fb}},	//   _kokɔ, nigs, _བརྗ_, hành_, 
   {{0x63addae0,0x61e004f3,0x543400c0,0xddd400ef}},	//   _cpan, älln, рхну, _bezū, 
   {{0xd0440296,0xcb1000c8,0x394c009b,0x2bb805f9}},	//   _mokɔ, ַלן_, _higs_, _इनसा, 
   {{0x63addae1,0x7d08d2b2,0x4204016c,0x3eb00072}},	//   _epan, kigs, анро_, dext_, 
   {{0x394ddae2,0x6284ca52,0x63ac010a,0x3d1c033f}},	//   _jigs_, _edho, _fpan, यकों_, 
   {{0x7d08017a,0xc0d0001f,0x8f7402bf,0x00000000}},	// [35500] digs, _የጎላ_, рубі, --, 
   {{0x394c0204,0x250400b8,0x8e84004e,0x00000000}},	//   _ligs_, _taṣṭ, ргже, --, 
   {{0x7d0803fa,0x63ac00f3,0x1ea800c6,0x7d74036b}},	//   figs, _zpan, طالي_, لملر_, 
   {{0x0b8823b3,0xd0440085,0x1d880451,0x63ac0124}},	//   вски_, _bokɔ, ائلي_, _ypan, 
   {{0x69c96e31,0x0b45bad3,0x80bc1a04,0x3eb003b9}},	//   _srde, андн, _लोटे, bext_, 
   {{0x69c80c5e,0x00000000,0x00000000,0x00000000}},	//   _prde, --, --, --, 
   {{0xaca401f2,0x394c0204,0x83e800e8,0x2d8c01e7}},	//   _agụp, _bigs_, _ngёn, _íde_, 
   {{0xa77428cf,0x64400213,0xa8780137,0x9d580117}},	//   блич, əlif, اڭار_, _сӯфӣ_, 
   {{0x5fc80037,0x394c0f85,0x7b000fac,0x7cf0010b}},	//   रियल, _digs_, øvtø, _uçra, 
   {{0x69c80219,0x63ac022e,0x00000000,0x00000000}},	//   _trde, _rpan, --, --, 
   {{0x69c8ff6f,0x09a8025c,0x394c123b,0x00000000}},	//   _urde, _བརྒ_, _figs_, --, 
   {{0x63ac05b1,0x394c2f7f,0xc7c40108,0x00000000}},	//   _ppan, _gigs_, _вски, --, 
   {{0x07d8034c,0xd6d8b01b,0x7d01dae3,0xca4c01ec}},	//   _جذاب_, ттө_, ènsi, _ﺍﻟﺠ_, 
   {{0x59bc07b7,0x61e00267,0x2730007f,0x00000000}},	//   ्मचर, ällo, kàni_, --, 
   {{0xb6c8066d,0x6729dae4,0x63ac026c,0x31c51eaa}},	//   _جانے_, modj, _wpan, оств, 
   {{0x63a9dae5,0x20543cc5,0x63ac0055,0x200403b9}},	//   çens, ская, _tpan, _əlif_, 
   {{0x63addae6,0x3eb1dae7,0x81dc0154,0x60380006}},	// [35510] _upan, text_, _দেখ_, упаў_, 
   {{0x4438c05f,0x62850027,0x7d080ea0,0xdbd008a5}},	//   _izq_, _udho, wigs, _nýár, 
   {{0x7d09dae8,0x61f80724,0x9f9403fa,0x9f4c0332}},	//   tigs, ñalı, _füße_, _áníd_, 
   {{0x7c84dc9e,0x61e0022c,0x09a8025c,0x67280cf4}},	//   руже, øllu, _བརྟ_, hodj, 
   {{0x67280384,0x394ddae9,0xa3c800dc,0x00000000}},	//   kodj, _rigs_, ोमि_, --, 
   {{0x7d08300d,0x9984135f,0x394c0332,0x00000000}},	//   sigs, ملتو, _sigs_, --, 
   {{0x394c3371,0xceb00302,0x67280fcf,0xaf3403e6}},	//   _pigs_, _מים_, dodj, _گرێت, 
   {{0xa3c80316,0x2128e82e,0xe9d11147,0x00000000}},	//   ोमा_, noah_, بغه_, --, 
   {{0x7d180921,0x394ddaea,0x8ce42309,0x9bf400fd}},	//   _ijus, _vigs_, _اققۇ, _узач, 
   {{0x67288ef1,0x7c39daeb,0x7d1836dd,0x195800f7}},	//   godj, _izur, _hjus, _бажы_, 
   {{0x7d180784,0x394c039a,0x2128003e,0xa5940d1d}},	//   _kjus, _tigs_, koah_, орящ, 
   {{0xf8d80dba,0x6aac00fe,0x00000000,0x00000000}},	//   _मचिय, _টোপো, --, --, 
   {{0x67280fcf,0x7d1801f7,0x7c380327,0x59c400dc}},	//   bodj, _mjus, _jzur, विवर, 
   {{0x7d19daec,0x7c3805d9,0xe3b80135,0x9f940e78}},	//   _ljus, _mzur, _བརྫང, _süße_, 
   {{0x61040024,0x7d180248,0xf8d8012d,0x74d807b7}},	//   lėly, _ojus, _मचाय, यादृ, 
   {{0x7c3802e3,0x7d1807f5,0xa5642088,0x2bb802ab}},	//   _ozur, _njus, _بدون, _इनला, 
   {{0x7c3805d9,0x33d80213,0xdef80023,0x0ea83671}},	// [35520] _nzur, _bəxş_, ጋጽን_, лкай_, 
   {{0x81dc04c5,0xa2d81a55,0x8e3808f0,0x0ed017ee}},	//   _দেও_, माण्, هسار_, साइड, 
   {{0x7c39daed,0x7d18045f,0x212804ba,0xa18402dd}},	//   _azur, _bjus, boah_, _мұра_, 
   {{0x8fa4a261,0x2730026c,0x859800df,0x00000000}},	//   _ламе, ràni_, טשעו, --, 
   {{0x57d02894,0x00000000,0x00000000,0x00000000}},	//   तमोह, --, --, --, 
   {{0x644003be,0x7d1816b8,0x7c385050,0x62041427}},	//   əlid, _ejus, _dzur, _útlæ, 
   {{0xa2d921a3,0xf964e498,0x67285927,0x7c3801f2}},	//   मात्, брый_, vodj, _ezur, 
   {{0xf98cf629,0x69dc0129,0x249804e6,0x7d180200}},	//   ربى_, _àrem, xgsm_, _gjus, 
   {{0x6d4005d1,0x7d000af9,0x88c401d5,0x00000000}},	//   _ihma, ënse, لتکل, --, 
   {{0xf76c2961,0x8b240953,0x00000000,0x00000000}},	//   راً_, _удзе, --, --, 
   {{0x6d400652,0x67281aff,0x19f80276,0xa4d848a9}},	//   _khma, rodj, _кэць_, адну_, 
   {{0x6729daee,0x61e001e3,0x00000000,0x00000000}},	//   sodj, ällm, --, --, 
   {{0xddd4007f,0x2aec00c5,0x6b840332,0x00000000}},	//   _egzň, _जकाँ_, áigh, --, 
   {{0xd76404fb,0xa2d82170,0x09a8031c,0x3358084c}},	//   _بنوی, माध्, _བརྙ_, сарэ_, 
   {{0x6d40035a,0x00000000,0x00000000,0x00000000}},	//   _ohma, --, --, --, 
   {{0x5ff40798,0x00000000,0x00000000,0x00000000}},	//   озбу, --, --, --, 
   {{0x14d44c5b,0x24880882,0x7d18002d,0x21280204}},	// [35530] धारण, _idam_, _rjus, roah_, 
   {{0x6d41daef,0x9e140953,0x7d1808cb,0x236801e4}},	//   _ahma, одзі, _sjus, _itaj_, 
   {{0x6d4005be,0x59980020,0xb0c41dd1,0x7c3801ed}},	//   _bhma, _ዘርፎች_, _लोकग, _szur, 
   {{0x248802fa,0x6d41daf0,0x3ae833b8,0x98ac0010}},	//   _jdam_, _chma, _løpt_, tleč_, 
   {{0x6d40058a,0x50a000d1,0xde580153,0x00000000}},	//   _dhma, _تەقل, _вагі_, --, 
   {{0x6d41daf1,0xc8a437f3,0x00000000,0x00000000}},	//   _ehma, क्सट, --, --, 
   {{0x6d5801a2,0x248807d6,0x9cf42626,0x7d19daf2}},	//   ívat, _odam_, _дзві, _tjus, 
   {{0x7d18108e,0x24880694,0x2368db8b,0x978801b9}},	//   _ujus, _ndam_, _otaj_, айиб_, 
   {{0x7c39daf3,0x23680211,0x3acc1f1b,0x81dc009e}},	//   _uzur, _ntaj_, _pēpē_, থনি_, 
   {{0xd70834d8,0x2488b77d,0xd7040212,0x61040153}},	//   рное_, _adam_, ізни, rėly, 
   {{0xe8f8052f,0x23680113,0x7be4063f,0x3ae800d4}},	//   рлө_, _ataj_, ̣rụ, _døpt_, 
   {{0x6ee0008e,0xd7380022,0x00000000,0x00000000}},	//   _döby, ыцқә_, --, --, 
   {{0xd7c86b5d,0x387ddaf4,0xf3f400e5,0x00000000}},	//   _خوشه_, maur_, ستحک, --, 
   {{0x387ddaf5,0x2489daf6,0x6d48b56d,0xddd40118}},	//   laur_, _edam_, _èdav, _nezů, 
   {{0x2369daf7,0xd4a409a5,0x10800131,0xd46800db}},	//   _etaj_, _дийй, _ﺩﻩﺭﯨ, _кийе_, 
   {{0x463800c8,0x2244022a,0x387c0356,0xea68025c}},	//   _דעצע, ýlka_, naur_, ċċiż_, 
   {{0x4f09daf8,0xc3d801ec,0x00000000,0x00000000}},	// [35540] анан_, _көрi, --, --, 
   {{0x6d4002d3,0x387ddaf9,0x74d8258d,0x52a80114}},	//   _shma, haur_, यावृ, _твом_, 
   {{0x049014ab,0x4d640d30,0x387c0098,0x9e642162}},	//   _علیح, цкев, kaur_, سالن, 
   {{0x273004cc,0x387c4cab,0xdde8007b,0x00000000}},	//   lànt_, jaur_, حركه_, --, 
   {{0x8bb4034c,0x387c06d1,0x8b247b0a,0xead5dafa}},	//   تصاص, daur_, одде, золь, 
   {{0x3e683ee6,0x273005d5,0xe3b8031c,0x6d59dafb}},	//   _نجفی_, nànt_, _བརྣང, ívas, 
   {{0x14c9bcea,0x387c3743,0x6d4001ab,0x7d0004e6}},	//   ियाण, faur_, _thma, ënsc, 
   {{0x6d5ddafc,0x387ddafd,0x6d40005b,0xa77425ff}},	//   _iura, gaur_, _uhma, плич, 
   {{0x6d5ddafe,0x24880072,0x03ec00cc,0xa8140108}},	//   _hura, _rdam_, _চেনী_, ядиш, 
   {{0xfc4001d9,0xab8c010e,0x61e001e3,0x00000000}},	//   _کھۅپ, _şöwü, ällk, --, 
   {{0x2369daff,0x248801f9,0xa2d8bc82,0x273004cc}},	//   _staj_, _pdam_, मास्, dànt_, 
   {{0xf76c0ed1,0x00000000,0x00000000,0x00000000}},	//   راۋ_, --, --, --, 
   {{0x6d5c1269,0x81ac03f4,0x38c80a98,0x273007c5}},	//   _lura, ওয়া_, _خالی_, fànt_, 
   {{0x6d5ddb00,0x273004cc,0x00000000,0x00000000}},	//   _oura, gànt_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc0c802dd,0xf0d401c6,0x8cc83507,0x00000000}},	//   шуге_, мжсэ, _सोलो, --, 
   {{0x6d5ddb01,0x3210013b,0xdcec005f,0xd34403e6}},	// [35550] _aura, _ɛnyɛ_, ākļo, تییه_, 
   {{0x6d5ddb02,0x53980302,0x3e6800c7,0x387c9dfd}},	//   _bura, _פיתו, ршан_, zaur_, 
   {{0xceb4013d,0x068c02dd,0x00000000,0x00000000}},	//   чәя_, _ﻛﯘﻣﯩ, --, --, 
   {{0xe7bd2640,0x00000000,0x00000000,0x00000000}},	//   ्टाप, --, --, --, 
   {{0x6d58f02c,0x387ddb03,0xb0d801ad,0x50a000d1}},	//   ívar, vaur_, डारग, _سەلل, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d5ddb04,0x9984007b,0x6d5801e4,0x61e001e3}},	//   _gura, ألبو, ŭvar, ällh, 
   {{0x6ee00166,0x1ca40133,0x721c011a,0x00000000}},	//   _söbx, _رێتی_, יווח, --, 
   {{0x6d5ddb05,0x9f480165,0xfbbc2cfd,0x81c000fe}},	//   _zura, lzañ_, _एनिम, ্হি_, 
   {{0x387ddb06,0x6d5ddb07,0x9f480156,0x00000000}},	//   saur_, _yura, ozañ_, --, 
   {{0x6d5ddb08,0x0680b7e2,0xd628013e,0x273007de}},	//   _xura, эгэн, соне_, vànt_, 
   {{0x6d48011c,0x2ec807c1,0x9f480165,0x94243947}},	//   _èdat, _रफ्त, izañ_, змме, 
   {{0x0874008f,0x273007c5,0x527400cf,0x00000000}},	//   _זענט_, tànt_, зубу, --, 
   {{0x254c012c,0x2914033f,0x98a4010a,0xa2d8146b}},	//   _měly_, ądał_, _миçе, माष्, 
   {{0x91e44140,0x27300c86,0x86780375,0x61e00158}},	//   чове, rànt_, _הרצו, øllp, 
   {{0xc0e1db09,0x2d9c0137,0x6d5ddb0a,0x273004cc}},	//   носк, àvem_, _rura, sànt_, 
   {{0x6efc0165,0xa2d800dc,0x273004cc,0x9f480156}},	// [35560] _hæbɪ, माश्, pànt_, ezañ_, 
   {{0x6d5ddb0b,0x5435db0c,0xf7649498,0x3f8ccd11}},	//   _pura, _ورکر, _ۋا_, água_, 
   {{0xa2d808ec,0x98bc1152,0xd1c80354,0x00000000}},	//   मार्, ्याए, _улне_, --, 
   {{0x6d5c601a,0x657c025a,0xec280131,0xacb400cf}},	//   _vura, ârhi, ەكچى_, بەرب, 
   {{0x6d5ddb0d,0x7bcc0077,0x934002d3,0x9f48030a}},	//   _wura, _ácul, _ባእታታ, azañ_, 
   {{0x6d5ddb0e,0xfaa002e8,0x7af000d4,0x254c01ef}},	//   _tura, ешън, нзіє, _děly_, 
   {{0x6d5ddb0f,0x7bc80194,0x2bb80034,0xdb240133}},	//   _uura, avgu, _इनका, بووی, 
   {{0x61e1db10,0x7ae00218,0x00000000,0x00000000}},	//   älli, ajnt, --, --, 
   {{0xd90c2ed3,0x6008022e,0x00000000,0x00000000}},	//   جین_, _nоml, --, --, 
   {{0x86247036,0x27e000a3,0x6b840124,0xace801ee}},	//   зьме, _àinm_, áigu, _умға_, 
   {{0x36d4009d,0x00000000,0x00000000,0x00000000}},	//   чдээ_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa2d8043e,0x47f0008e,0x00000000,0x00000000}},	//   माल्, _чүпр, --, --, 
   {{0xa1587e1b,0x6700166d,0x00000000,0x00000000}},	//   жаву_, _ऋतिक_, --, --, 
   {{0x443c0419,0x00000000,0x00000000,0x00000000}},	//   ťu_, --, --, --, 
   {{0x77a401d9,0xdfd40b7e,0x3618011a,0xc4c40345}},	//   _بێیہ_, мобы, _לווד, _رتبو, 
   {{0x6d9000e4,0x00000000,0x00000000,0x00000000}},	// [35570] _ẽape, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9f4805c7,0xacf401b9,0x46ac2d81,0x6d580124}},	//   uzañ_, کسلت, ज्यह, ívap, 
   {{0xdce40165,0x9f48030a,0x00000000,0x00000000}},	//   mshī, rzañ_, --, --, 
   {{0xfba80d4b,0x00000000,0x00000000,0x00000000}},	//   стей_, --, --, --, 
   {{0x3f980309,0x1cb00327,0x98f40051,0x7bc8007c}},	//   muqu_, དབང_, _củn, rvgu, 
   {{0x3f99db11,0xa9c40597,0xceb0008f,0x9e3400d8}},	//   luqu_, فزيو, _שיל_, _цевч, 
   {{0xad440228,0x00000000,0x00000000,0x00000000}},	//   _كۉلۉ, --, --, --, 
   {{0x3ab014ca,0x2240036e,0x00000000,0x00000000}},	//   _зәйт, _lzhk_, --, --, 
   {{0x55880dbb,0x1a643b7a,0xd708187f,0x6604013a}},	//   обом_, _غیبی_, інне_, _řika, 
   {{0x3f980113,0x00000000,0x00000000,0x00000000}},	//   huqu_, --, --, --, 
   {{0x3f980481,0xdb089a44,0xbb300220,0xb4c8134e}},	//   kuqu_, _iseñ, _ﺭﺍﻥ_, ईये_, 
   {{0x3f9801f0,0x59c400cd,0x00000000,0x00000000}},	//   juqu_, विकर, --, --, 
   {{0x78b9d110,0xe7bc141f,0xa56400f2,0x3f9806be}},	//   leuv, ्टरप, بدین, duqu_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x78b9db12,0x316c00e2,0x98a4008e,0x00000000}},	//   neuv, īdz_, _kulı_, --, 
   {{0x83c000c7,0x3f9800f1,0x6b44004e,0x69dca37d}},	// [35580] _абыж, guqu_, lòge, _àrev, 
   {{0xd5b00acd,0x2ec80882,0x78b8282c,0xff2401d5}},	//   _जहाज, रयेत, heuv, وبلی, 
   {{0x6b4400cf,0xe8140243,0x3ea400a3,0x0d8411f4}},	//   nòge, _तेना_, ònta_, флен, 
   {{0x3f99db13,0xc1700375,0x4f94e4ae,0x00000000}},	//   buqu_, _שחר_, _оргу, --, 
   {{0x61e00267,0xaab4753d,0xc00000c0,0x00000000}},	//   ällv, ейлі, _апяк, --, 
   {{0x27e0038f,0x999000d7,0x00000000,0x00000000}},	//   _ħin_, _šzš_, --, --, 
   {{0x200c0f99,0x3da40276,0x2fc048e9,0x3ea02360}},	//   _þeir_, _окро_, lwig_, _ширг, 
   {{0x69348198,0x8c45db14,0xb4c81524,0x4788720d}},	//   رکار, _жебе, ईयो_, осом_, 
   {{0xdb08002e,0xdc4402b5,0x67d40138,0x00000000}},	//   _eseñ, _tūāo, хопу, --, 
   {{0x05840166,0x00000000,0x00000000,0x00000000}},	//   мумм, --, --, --, 
   {{0xbb5004ce,0x78c4007c,0x19b80064,0x00000000}},	//   _webペ_, örvä, _нуць_, --, 
   {{0x38c804d3,0x2ca001c3,0x00000000,0x00000000}},	//   _وانی_, òidh_, --, --, 
   {{0x27e0046c,0xb7d4007b,0x9c7c010e,0x22580304}},	//   _çin_, _يوما_, _soōk, зигы_, 
   {{0xdd300210,0x00000000,0x00000000,0x00000000}},	//   wężn, --, --, --, 
   {{0x2fc0017a,0xdd30033f,0x6ac800eb,0x00000000}},	//   ewig_, tężn, লাপো, --, 
   {{0x98a40724,0xc1540521,0x64400213,0x00000000}},	//   _yulı_, _ụgbọ, əlin, --, 
   {{0x69dc0077,0xff5c003a,0x3dc00009,0x2fc00076}},	// [35590] _áref, _quî_, _ssjw_, gwig_, 
   {{0x3f980009,0x2f0402d2,0x00000000,0x00000000}},	//   ruqu_, _lögf_, --, --, 
   {{0x3f98abaa,0xddd4598d,0x2ca40f85,0xfe600241}},	//   suqu_, _bezš, _bcmd_, _ẹ̀mí_, 
   {{0x5f800131,0x61e0002f,0x00000000,0x00000000}},	//   _مۇرە, ällu, --, --, 
   {{0x3f9800ac,0x78b81132,0x6ac80154,0xef64014b}},	//   ququ_, veuv, লানো, _аъсо, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xeda46418,0x98a4013d,0x00000000,0x00000000}},	//   _ишто, _sulı_, --, --, 
   {{0x6d4804cc,0x57e81a71,0x200403b9,0x00000000}},	//   _èdap, здим_, _əlin_, --, 
   {{0x78b9db15,0x1d08010b,0x98a4008e,0xc0c40023}},	//   reuv, _деңи_, _qulı_, _ጽንሕ_, 
   {{0xeab000c6,0x6b44004e,0xc7200139,0x61f4010e}},	//   _نعم_, tòge, лдый, kyzl, 
   {{0xceb0008d,0xfbc42c2e,0x4580009d,0x6b440241}},	//   ניט_, लिकम, лгэв, bògb, 
   {{0x98a40724,0x6b440086,0x7e740076,0x2fc00ea0}},	//   _tulı_, ròge, hbxp, ywig_, 
   {{0x3cfc01ef,0x00000000,0x00000000,0x00000000}},	//   _mluv_, --, --, --, 
   {{0x0ecc0c4c,0x00000000,0x00000000,0x00000000}},	//   _होंड, --, --, --, 
   {{0xb9f80201,0x69dc004a,0x2f049632,0x35c00b01}},	//   _ሆነ_, _àret, _högg_, _райҳ, 
   {{0x0cd80729,0x458000a7,0x2fc0005a,0xf1c000d0}},	//   _দত্ত, _сгъв, twig_, ššou_, 
   {{0xc9500375,0x8eb800ee,0xdf740014,0x4e944e77}},	// [355a0] רמן_, зыет_, ندٕب, فشار, 
   {{0x2fc1c712,0xc58401ed,0x0444010b,0x74d800dc}},	//   rwig_, _تھیم_, _япык_, याकृ, 
   {{0x2fc04bb4,0x61e042a7,0x2ca4123b,0x2f0402d2}},	//   swig_, ällt, _pcmd_, _lögg_, 
   {{0x072cc9c6,0x0c2405f5,0x913402bf,0x5cc401ec}},	//   ﻨﯩﯔ_, нмен, _їхні, ксіз, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3cfc003a,0x764400ee,0x752401d5,0xc330011a}},	//   _fluv_, ýjyl, _ojiz, אוג_, 
   {{0x3cfc00f3,0xc91c2b1b,0xfce001e0,0xeff00b82}},	//   _gluv_, দত্ত_, _йосо, _ጂሃድ_, 
   {{0xf76cbc3d,0x69dc00f3,0x8b2402d5,0x00000000}},	//   یای_, _šred, _здае, --, 
   {{0x09e44712,0xcb0818a1,0xbb500f47,0x7524d155}},	//   _позн, _عيان_, _منقب, _ajiz, 
   {{0xdb080165,0x2a6c00ef,0xda643092,0x00000000}},	//   _speç, _ifdb_, _شالي, --, 
   {{0xd90c05d9,0xe61800f7,0x24180006,0xc76415bf}},	//   _وڌي_, здү_, домы_, _كاتى, 
   {{0x990869d2,0xf7f0e84d,0x7641131a,0xf3f802e8}},	//   _تغلق_, _مسود, _ezny, еняш_, 
   {{0x69dd29ce,0xe5b400f7,0x644000ac,0x7525db16}},	//   _àres, _айкы, əlil, _ejiz, 
   {{0x26dc047e,0x69dc0005,0x72280212,0x84640395}},	//   _invo_, _áred, ецтв_, _пъпе, 
   {{0x6008022e,0x8004084c,0x7524036e,0x4ae00073}},	//   _hоmi, нчзе, _gjiz, पाडव, 
   {{0x9078044e,0x600801d5,0xf0b400fd,0x2a6c002f}},	// [355b0] ራስያዊ_, _kоmi, ыйть, _ofdb_, 
   {{0x61e0049f,0xceb40184,0x26cc0368,0x7640010e}},	//   älls, кәс_, nddo_, _yzny, 
   {{0x3cfc0115,0xfe2407d5,0xc32c0150,0x91c000b1}},	//   _pluv_, хьан, _نەڭ_, _кәтл, 
   {{0xa2d8012a,0x44380200,0x6ce400d4,0x00000000}},	//   माक्, _kyq_, ліче, --, 
   {{0x60cc357f,0x60dc51a0,0x29040332,0xed5800d4}},	//   mdam, _insm, dhma_, хої_, 
   {{0x60cddb17,0x60dc020b,0x2905db18,0x6008022e}},	//   ldam, _hnsm, ehma_, _nоmi, 
   {{0x60cddb19,0xf2d4008f,0xdcc400c7,0xea88d0ba}},	//   odam, טעס_, _ишаҿ, رخون_, 
   {{0x60cc0d92,0x26cc0014,0x2904014f,0x20080064}},	//   ndam, eddo_, ghma_, ozai_, 
   {{0x2009db1a,0x6e680014,0xe7f401c6,0x60cddb1b}},	//   nzai_, _آمہِ_, гчээ, idam, 
   {{0x60cddb1c,0x7c39db1d,0x26cc015d,0xe84800db}},	//   hdam, _iyur, gddo_, ةجىن_, 
   {{0x7c380263,0xc6e004c5,0x60cc0006,0x60dc4d25}},	//   _hyur, যসূচ, kdam, _onsm, 
   {{0x2904fa80,0x23dc02ab,0x7c39db1e,0x26cc058a}},	//   chma_, ममंद, _kyur, addo_, 
   {{0x60cddb1f,0x66080034,0x6b4400db,0x7c39db20}},	//   ddam, azdk, lòga, _jyur, 
   {{0xa2d933ab,0x60dddb21,0x200805b8,0x7c388a51}},	//   माग्, _ansm, dzai_, _myur, 
   {{0xd13077f0,0xddc40118,0x6ee000bc,0x14a801f9}},	//   لمس_, dchů, नासँ, _कापण, 
   {{0x60cddb22,0x2009db23,0x75240b45,0x2f040e78}},	//   gdam, fzai_, _ujiz, _möge_, 
   {{0x7c3918e8,0x93e00270,0x61e00621,0xa2d800cd}},	// [355c0] _nyur, makί_, ällr, माख्, 
   {{0x60cddb24,0x9e64009f,0x00000000,0x00000000}},	//   adam, هامن, --, --, 
   {{0x7c39db25,0x60cc00cd,0x4c8401f4,0x00000000}},	//   _ayur, bdam, влев, --, 
   {{0xdb1c006a,0x61e001e6,0x7c38377b,0x60cc0067}},	//   _âyêk, ålle, _byur, cdam, 
   {{0x4e10038e,0x26cc00a9,0x7c387837,0xc61c00dc}},	//   _धेरै_, yddo_, _cyur, _पश्य_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7c3988a5,0x60dc000f,0x6b440ba1,0xca4c02dd}},	//   _eyur, _ynsm, gòga, _ﺍﻟﺒ_, 
   {{0x7c38022e,0x2d9c004e,0xa2d81025,0xdb4c0014}},	//   _fyur, àveu_, _फोन्, _ہێن_, 
   {{0x7c39db26,0x870400a7,0x6e3c0267,0x4aa8010b}},	//   _gyur, вяне, _hyrb, _окан_, 
   {{0x290469a6,0xcc1001f2,0x26cc0083,0xa65403e6}},	//   shma_, pọbị, uddo_, هێشت, 
   {{0x60cddb27,0x6aa802d0,0x200807c5,0x2f040432}},	//   ydam, _icdf, zzai_, _göge_, 
   {{0x69c9db28,0x60cc0399,0x6e3c99c0,0x00000000}},	//   _isde, xdam, _myrb, --, 
   {{0x60cc162a,0xc76402de,0x3544009d,0x00000000}},	//   vdam, _شاشى, рхэв, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3630a5f4,0xbbbc02ab,0x60cd5c83,0x335800a8}},	//   _پروس, _एन्क, tdam, тарэ_, 
   {{0x69c80115,0x2008009d,0x60cc0153,0x00000000}},	//   _msde, tzai_, udam, --, 
   {{0x442ddb29,0x61e001e3,0x22a4014b,0x00000000}},	// [355d0] _âg_, ållb, _йунҳ, --, 
   {{0x63addb2a,0xdf380597,0x60cddb2b,0x7c382d6f}},	//   _iqan, ركات_, sdam, _ryur, 
   {{0x6285db2c,0x7c39db2d,0x69c80113,0x60cc8702}},	//   _ieho, _syur, _nsde, pdam, 
   {{0x60cc01b9,0x7c38022e,0xada40212,0x6e3ddb2e}},	//   qdam, _pyur, раїл, _dyrb, 
   {{0x6285db2f,0x63ac031c,0x6b800142,0x6e3c02d2}},	//   _keho, _jqan, _cwmg, _eyrb, 
   {{0x6285db30,0x7c39db31,0x63ac031c,0x6e3ddb32}},	//   _jeho, _vyur, _mqan, _fyrb, 
   {{0x6285db33,0x3c904c12,0x69c80204,0x7c840276}},	//   _meho, _نیاز, _csde, _аузе, 
   {{0x6285db34,0x63ac0140,0x17c87579,0x78542d77}},	//   _leho, _oqan, егии_, نیاز_, 
   {{0x69c80228,0x21380263,0x63addb35,0x62844fa5}},	//   _esde, _mksh_, _nqan, _oeho, 
   {{0x6285db36,0xc99400aa,0xf1c00122,0xe77800e5}},	//   _neho, _څانګ, ášku_, کلیں_, 
   {{0x941c0cc1,0x63ac4f6b,0x69dc0129,0x69c803b9}},	//   ətə_, _aqan, _àrep, _gsde, 
   {{0x97c4117d,0x661c00d7,0x00000000,0x00000000}},	//   _مقصو, úrka, --, --, 
   {{0x6285db37,0x436400ee,0x644000ac,0x00000000}},	//   _beho, лаян_, əlik, --, 
   {{0x2139db38,0x2568045f,0x69dc0005,0x6284054e}},	//   _aksh_, _fûl_, _árec, _ceho, 
   {{0x6285db39,0x63addb3a,0x1ab000fe,0x61e001e3}},	//   _deho, _eqan, _টোৱা, ällp, 
   {{0x6284009a,0x26005c0e,0x00000000,0x00000000}},	//   _eeho, शनरी_, --, --, 
   {{0x628403c1,0x63ac014b,0xcfa80137,0x6e3c0036}},	// [355e0] _feho, _gqan, عارم_, _syrb, 
   {{0x6285db3b,0xae7400d1,0x00000000,0x00000000}},	//   _geho, شۇرغ, --, --, 
   {{0x10a4010a,0x00000000,0x00000000,0x00000000}},	//   _йинн, --, --, --, 
   {{0x6284ffde,0x7e4801d3,0x6c3401d9,0x7c8026b1}},	//   _zeho, رسلہ_, ٔہرا, буше, 
   {{0x6285db3c,0x92580502,0xa2d81fbc,0x8b9457e5}},	//   _yeho, _تشکر_, माच्, уреч, 
   {{0x69c8172e,0xbb8000c6,0x6e3c5a3f,0x386c02d2}},	//   _psde, حلوي, _tyrb, _afgr_, 
   {{0x14a80490,0x2ca001ab,0x00000000,0x00000000}},	//   _काढण, òids_, --, --, 
   {{0x7aa0016c,0x6b4400cf,0x00000000,0x00000000}},	//   _ҳифз, cògn, --, --, 
   {{0xb6a0004d,0x99840024,0xbcdc0118,0x78580171}},	//   _tuầ, _bylų_, ššíh, _nāvī, 
   {{0xf7b41b45,0xd730001f,0xfaa1db3d,0x3f8c035b}},	//   اديش_, _አባልነ, _гафо, águi_, 
   {{0xe8140412,0x63ac0784,0xc1a020f0,0x69c9db3e}},	//   _तेरा_, _sqan, _ओमेग, _usde, 
   {{0x6285db3f,0x4ae00490,0xe4540166,0x59700244}},	//   _seho, पावव, икны, _بگوز, 
   {{0x6285db40,0xab0001a8,0x785800b8,0x00000000}},	//   _peho, _þjóð_, _cāvī, --, 
   {{0x98ac0374,0x00000000,0x00000000,0x00000000}},	//   moeā_, --, --, --, 
   {{0x628503ae,0xf744a864,0x2138036e,0x00000000}},	//   _veho, _حلوي_, _pksh_, --, 
   {{0x6285db41,0xa07549f8,0x212c00bc,0x63ac025c}},	//   _weho, ргач, čeho_, _tqan, 
   {{0xa294063b,0x6285db42,0x2294656c,0x351c04ae}},	// [355f0] _капі, _teho, _кипя, _רוחנ, 
   {{0x2b4c07ab,0x3e05db43,0x3f98025c,0xde940114}},	//   _nhdc_, ляев, rrqu_, ражњ, 
   {{0xbda40f47,0x7e4400c0,0xbbe8072d,0x6b9c00ef}},	//   طحاو, ухае, کرام_, _ārga, 
   {{0x98ac02b5,0x22440118,0xd0180107,0x00000000}},	//   koeā_, ýlku_, хфӣ_, --, 
   {{0x2d9c0ba1,0xdb54010b,0xbfa80408,0x00000000}},	//   àver_, авды, _ятне_, --, 
   {{0xefc85a52,0xcb640a5b,0x8f9800d9,0x00000000}},	//   _суюк_, шаше_, _בישי, --, 
   {{0xa2ac0316,0xd12c01d9,0x1af8015b,0x1a2802e8}},	//   _जान्, _رۅے_, ্চলে_, ъжки_, 
   {{0xed582e0b,0xbb300150,0x00000000,0x00000000}},	//   _مشقت_, _ﺭﺍﻉ_, --, --, 
   {{0x2f04049f,0x2ca00dd5,0x273003d1,0x3940005f}},	//   _höga_, óide_, làny_, ējs_, 
   {{0xf1c000d0,0x00000000,0x00000000,0x00000000}},	//   ššiu_, --, --, --, 
   {{0xd629db44,0x27300109,0x1ae401ee,0x2a64072d}},	//   тоне_, nàny_, _йоҡм, _اُمّ, 
   {{0x69dc74c3,0x27e00cf4,0x1798010b,0x7948010e}},	//   _área, _šine_, _авды_, _döwý, 
   {{0x93443f6e,0x4524084c,0x2f040254,0x99840064}},	//   инме, ржян_, _löga_, _tylų_, 
   {{0x46100272,0x6d981682,0x273005da,0xd334084c}},	//   _ژوور, ḓan, kàny_, рэмы, 
   {{0xe3b402dd,0xf7700133,0x00000000,0x00000000}},	//   _құр_, _ئاڵ_, --, --, 
   {{0x61e0049f,0x27300109,0x543440ec,0x00000000}},	//   ålla, dàny_, _پربر, --, 
   {{0x8fa409ed,0x8e8400c9,0x4fa40395,0xf4b00116}},	// [35600] разе, игае, ризв, _ﻳﯚﺗﻜ, 
   {{0x27300109,0xa2ac01ad,0x27e1db45,0x3f8c00e4}},	//   fàny_, _जाय्, _áine_, âgua_, 
   {{0x91e422c3,0x4298011a,0x00000000,0x00000000}},	//   _тоне, _בסיב, --, --, 
   {{0x8fa50b8d,0x33380354,0x9c7c010e,0xeff80240}},	//   _каме, lorx_, _soōr, ፈሰይ_, 
   {{0x4ae01c15,0xa2ac08df,0x00000000,0x00000000}},	//   पालव, _जाम्, --, --, 
   {{0x2f040267,0x00000000,0x00000000,0x00000000}},	//   _föga_, --, --, --, 
   {{0x6ac800cc,0x8d580137,0x09040f06,0x068c0150}},	//   লালো, _ашат_, ичим, _ﻛﯘﻟﯩ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3a214661,0x082800a7,0xcb680153,0x00000000}},	//   ймәг, ъцки_, _разе_, --, 
   {{0x6b8400e4,0x4b500244,0x661c1de4,0x00000000}},	//   âigu, _بێتر, úrko, --, 
   {{0xa3a80490,0xa2c4193d,0x5ed8010f,0x76b4008e}},	//   खून_, ाजस्, אַרװ, шлэр_, 
   {{0x25082651,0x79f8011a,0xbb3002dd,0x00000000}},	//   اردی_, _שלאח, _ﺭﺍﻕ_, --, 
   {{0x273005da,0x00000000,0x00000000,0x00000000}},	//   zàny_, --, --, --, 
   {{0x81c011f9,0x20040421,0x28b40034,0x066400d1}},	//   ņēmu, _āli_, ंभवि, _ئاشپ, 
   {{0xdbd00008,0xf19400a7,0x316806ed,0x4548094f}},	//   _lýðr, жись, ишто_, _ичим_, 
   {{0x273005da,0x00000000,0x00000000,0x00000000}},	//   vàny_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [35610] --, --, --, --, 
   {{0x273005da,0x00000000,0x00000000,0x00000000}},	//   tàny_, --, --, --, 
   {{0x2369db46,0xde19db47,0xdc7400c0,0x00000000}},	//   _huaj_, دقات_, быль, --, 
   {{0x23680070,0x273006d9,0x68e401c3,0x6ee000bc}},	//   _kuaj_, ràny_, _òidh, नाउँ, 
   {{0x2368044e,0x24881730,0x98bc00b0,0x273005da}},	//   _juaj_, _meam_, _wiwī_, sàny_, 
   {{0x23680e37,0x9f04dcb1,0x24880192,0x27300109}},	//   _muaj_, _اوسو, _leam_, pàny_, 
   {{0x23680457,0xe9a80979,0xa3a856e9,0x19b805f5}},	//   _luaj_, لدين_, खंड_, ууль_, 
   {{0x2488557f,0x6d3400a8,0xd8880116,0x00000000}},	//   _neam_, _десф, اھان_, --, 
   {{0x2368007f,0x3ab00116,0x2bc8003b,0x00000000}},	//   _nuaj_, _дәйт, _вухо_, --, 
   {{0xc5ec00aa,0x7bd9db48,0x2f04c9df,0x00000000}},	//   کړه_, _iruu, _lögn_, --, 
   {{0x2489db49,0x99d4009a,0x00000000,0x00000000}},	//   _beam_, _دقات, --, --, 
   {{0x7bd9db4a,0x6d9806d6,0x3338493a,0x97040014}},	//   _kruu, ḓal, worx_, _گِتى, 
   {{0x387c008b,0x23680211,0xb4c8068f,0x61e0049f}},	//   mbur_, _cuaj_, _उसी_, ålln, 
   {{0x2369db4b,0xa2ac0574,0x7778056a,0x00000000}},	//   _duaj_, _जाण्, mpux, --, 
   {{0xe1f01291,0x00000000,0x00000000,0x00000000}},	//   وسِ_, --, --, --, 
   {{0x23680218,0x2489db4c,0x387c79fa,0x28bc00dc}},	//   _fuaj_, _geam_, nbur_, ्जयि, 
   {{0x93949dc7,0x7c800092,0x160401f9,0x6ab800eb}},	// [35620] _اجبا, _ይሠራል_, शनवर_, _আফসো, 
   {{0x387c0036,0x00000000,0x00000000,0x00000000}},	//   hbur_, --, --, --, 
   {{0x236801d4,0xa2acc2fc,0x387c0ac5,0x7bd80014}},	//   _zuaj_, _जात्, kbur_, _aruu, 
   {{0x387cedc4,0x236801d4,0x7bd8508f,0x2f040008}},	//   jbur_, _yuaj_, _bruu, _gögn_, 
   {{0x7ee01e0e,0x23680218,0x8a740107,0x64400118}},	//   تكەن, _xuaj_, билӣ_, řliv, 
   {{0xe8e000dc,0xa97800c0,0xbe6401c6,0x6da401ec}},	//   पञ्च, айку_, _гарж_, _қиға, 
   {{0x7bd80a49,0xc27800df,0x00000000,0x00000000}},	//   _eruu, ארצי, --, --, 
   {{0xa77405c1,0x7bd9db4d,0x600801a9,0x87e401e0}},	//   олич, _fruu, _kоmp, йһең_, 
   {{0x7bd9db4e,0x2489db4f,0x00000000,0x00000000}},	//   _gruu, _ream_, --, --, 
   {{0x2369db50,0x2488f7ee,0x2f0401b8,0xa7140220}},	//   _ruaj_, _seam_, _mögo_, імні, 
   {{0x23680023,0x387ddb51,0x00000000,0x00000000}},	//   _suaj_, bbur_, --, --, 
   {{0x07a48c15,0x236801d4,0x387c7236,0x2458084c}},	//   _гадн, _puaj_, cbur_, иань_, 
   {{0x14a83af4,0x23680070,0x69d81347,0x24880208}},	//   _कारण, _quaj_, lvve, _veam_, 
   {{0x2f040008,0xb82000bc,0xcfcc015b,0x2369186c}},	//   _sögn_, šťál, রমান, _vuaj_, 
   {{0x2489db52,0x00000000,0x00000000,0x00000000}},	//   _team_, --, --, --, 
   {{0x23680b89,0xa2d81f13,0xc0580220,0x00000000}},	//   _tuaj_, _फोर्, гіз_, --, 
   {{0x250800f1,0x00000000,0x00000000,0x00000000}},	// [35630] _مرکی_, --, --, --, 
   {{0xad240075,0x7bd80194,0x644ddb53,0x29d800e4}},	//   ۋىلى, _rruu, _izai, _oĩa_, 
   {{0xe0d00014,0xef140137,0x29d80051,0x7fd40150}},	//   _قٲد_, чүрө, _nĩa_, шіңі, 
   {{0x7bd800af,0x00000000,0x00000000,0x00000000}},	//   _pruu, --, --, --, 
   {{0xda65db54,0x2128014f,0x1be801a9,0x00000000}},	//   овли, mnah_, рдли_, --, 
   {{0x21280427,0x00000000,0x00000000,0x00000000}},	//   lnah_, --, --, --, 
   {{0xe9b801d3,0x7a8401ec,0x2f04002f,0x69dc659a}},	//   منوں_, _ۇشام, _mögl_, _árel, 
   {{0xb4c8006d,0x67280196,0x7bd9db55,0x27e03421}},	//   _उसे_, endj, _truu, _šina_, 
   {{0x7bd9db56,0x644d8300,0x387ddb57,0x21280429}},	//   _uruu, _nzai, rbur_, inah_, 
   {{0x21280ac5,0x961002f5,0x777903fa,0xa3cc01ad}},	//   hnah_, _সুগম_, rpux, रबन_, 
   {{0x7d180280,0x7778056a,0x00000000,0x00000000}},	//   _kmus, spux, --, --, 
   {{0x2129db58,0xed8002d3,0x7d18009f,0x672800c5}},	//   jnah_, _ይነብር_, _jmus, andj, 
   {{0x7d19db59,0x21280429,0x00000000,0x00000000}},	//   _mmus, dnah_, --, --, 
   {{0x644c05b8,0xdb0800e4,0x21280429,0x4804034f}},	//   _dzai, _ipeó, enah_, _фешн_, 
   {{0x7d180c8a,0x644ca0d5,0x776001e2,0x00000000}},	//   _omus, _ezai, _iinx, --, 
   {{0x9555db5a,0x7768676c,0xc0e0bf73,0x6eac0118}},	//   _بختا, _kugx, моск, _चाहँ, 
   {{0x4fe901fc,0x09a40882,0x2f0407c5,0x776800e8}},	// [35640] шман_, _गम्य, _fögl_, _jugx, 
   {{0x7761db5b,0x21280548,0x7d186dc8,0x7640c7cf}},	//   _jinx, anah_, _amus, _kyny, 
   {{0x7761db5c,0x77680921,0x3f8c041e,0xdc30005f}},	//   _minx, _lugx, águr_, _eļļa, 
   {{0xf7640bbd,0x764000a9,0x7761db5d,0x0ba80b8c}},	//   _يا_, _myny, _linx, لاتى_, 
   {{0x6b440228,0x76402b52,0x64400213,0x00000000}},	//   lògi, _lyny, əlis, --, 
   {{0x7d19db5e,0x7761db5f,0x7b9401d9,0x00000000}},	//   _emus, _ninx, تھِس_, --, 
   {{0xa2ac05ba,0xd90c0b29,0xf98ddb60,0x76400076}},	//   _जास्, گین_, نبي_, _nyny, 
   {{0x2ef80489,0x00000000,0x00000000,0x00000000}},	//   _horf_, --, --, --, 
   {{0xd90c528e,0x6d41db61,0x2ef80489,0x764000ad}},	//   دین_, _ikma, _korf_, _ayny, 
   {{0x2129db62,0x77600381,0x2ef806af,0x7d18033f}},	//   znah_, _cinx, _jorf_, _zmus, 
   {{0x2129db63,0x764000a9,0x2ef9db64,0x67280023}},	//   ynah_, _cyny, _morf_, rndj, 
   {{0x2f0404cc,0x7641db65,0xa2ac1788,0x00000000}},	//   _sögl_, _dyny, _जाह्, --, 
   {{0x7768009a,0x68000248,0x7761db66,0x21280010}},	//   _gugx, _dájú, _finx, vnah_, 
   {{0x76400368,0x644c05d5,0x69dc031c,0x250908c4}},	//   _fyny, _vzai, _ġrej, _گرتی_, 
   {{0x2129db67,0x7640feaa,0x6b440137,0x2f0405d5}},	//   tnah_, _gyny, gògi, _vögl_, 
   {{0x21280438,0x77606994,0x644c009d,0x6d400219}},	//   unah_, _zinx, _tzai, _nkma, 
   {{0x21291eec,0xc05810f5,0x7761db68,0x3f8401fa}},	// [35650] rnah_, рів_, _yinx, ćnuo_, 
   {{0x6d41db69,0x21296f40,0x7761db6a,0x6b440086}},	//   _akma, snah_, _xinx, bògi, 
   {{0x2ef9db6b,0xdc742401,0x7d180200,0x29040327}},	//   _dorf_, пыль, _pmus, kkma_, 
   {{0x2128820a,0x48d805d7,0x00000000,0x00000000}},	//   qnah_, _खोलो_, --, --, 
   {{0x9f200075,0x3ea4067c,0xab9400d4,0x00000000}},	//   _كۈرۈ, ònts_, дичі, --, 
   {{0x6d41db6c,0x2ef80156,0xfe700014,0xdd943004}},	//   _ekma, _gorf_, _زدس_, _нагы, 
   {{0x6d4008f5,0x00000000,0x00000000,0x00000000}},	//   _fkma, --, --, --, 
   {{0x7d19db6d,0x6ca4e34b,0x7761db6e,0x6d9806d6}},	//   _umus, _оруж, _sinx, ḓah, 
   {{0x47c011ed,0x5b140276,0x7760d6a6,0x76400432}},	//   ебыв, _емат, _pinx, _syny, 
   {{0xd7082140,0x29041c06,0x7760022f,0x1a64036b}},	//   сное_, akma_, _qinx, _عیبی_, 
   {{0xe8f80184,0x77600393,0xd469db6f,0x6d4000a2}},	//   слө_, _vinx, йине_, _ykma, 
   {{0x776128ce,0x9cf8015b,0x76400076,0xd9d80451}},	//   _winx, _আগুন_, _vyny, _پهچڻ_, 
   {{0x776007a9,0x18480220,0x00000000,0x00000000}},	//   _tinx, _اساۋ_, --, --, 
   {{0xd0640213,0x76400142,0x877808c3,0xa3cc04aa}},	//   əqəl, _tyny, _האסי, _रनर_, 
   {{0xa2addb70,0x00000000,0x00000000,0x00000000}},	//   _जार्, --, --, --, 
   {{0x6f1c0fcf,0xd3940131,0x01605192,0x8fd005a2}},	//   _smrc, _нәгә_, ексо, нәгә, 
   {{0x6d4001a6,0x527400db,0x94040066,0x00000000}},	// [35660] _rkma, _нуну, _روده, --, 
   {{0xb4cc0c87,0x26000a8a,0x00000000,0x00000000}},	//   _रघु_, शनची_, --, --, 
   {{0x02f802e4,0x42f80375,0xccc404b3,0xc690010f}},	//   _הלימ, _ההיס, збей, גאב_, 
   {{0x61e0019b,0xc8d8b577,0x2ef9db71,0x00000000}},	//   ælle, _मोंट, _worf_, --, 
   {{0xead4efcc,0x2ef80042,0x6d4001f5,0x27e00327}},	//   доль, _torf_, _vkma, _ġino_, 
   {{0x64400209,0xdb0801ab,0x69dc01a8,0xca440150}},	//   şlig, _speò, _árek, _ﻅﻬﺭ_, 
   {{0xa9340220,0xe8140d2c,0xc9840353,0x3ea4035b}},	//   мекш, _तेजा_, чули, ónte_, 
   {{0x2d9839b4,0x2d680311,0x6d41db72,0x00000000}},	//   _ivre_, _eşec_, _ukma, --, 
   {{0x0580001f,0x29042ac2,0x00000000,0x00000000}},	//   _የደቡብ_, rkma_, --, --, 
   {{0x2d8c003a,0x2905db73,0x8cb4012d,0x00000000}},	//   _ædes_, skma_, ोजको, --, 
   {{0xd90c168d,0xfaa0016c,0xe5350b85,0x7c980092}},	//   دیۆ_, _чахо, день, ፈፀመው_, 
   {{0x891401f7,0x00000000,0x00000000,0x00000000}},	//   _عبائ, --, --, --, 
   {{0xb6c801d3,0x870400c0,0x00000000,0x00000000}},	//   _گانے_, _няке, --, --, 
   {{0x2d984a1f,0x23640fe7,0x97a401ec,0x00000000}},	//   _ovre_, ölj_, _іріл, --, 
   {{0x2d9c03b7,0x76b80302,0x224400b5,0x651801d9}},	//   ável_, _המופ, ælk_, _وقتس_, 
   {{0xa0c44d49,0x6ac800fe,0x00000000,0x00000000}},	//   بيرو, লাটো, --, --, 
   {{0x399000d2,0x6b44068c,0x2d980129,0x9f0401e2}},	// [35670] _kûsá_, lògu, _avre_, وورو, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x644046d5,0xdca40131,0x623400d8,0x00000000}},	//   şlid, җаһи, _цену, --, 
   {{0x4a28031c,0xb1a400fd,0x23b006e3,0x00000000}},	//   _སྨེལ_, _яшьк, _जमाद, --, 
   {{0x2d99db74,0x7c300022,0x00000000,0x00000000}},	//   _evre_, хҵах, --, --, 
   {{0xaa88007b,0x6b4400e4,0xbd680153,0x6ab40395}},	//   كنهم_, kògu, _грае_, есъх, 
   {{0x2d980083,0x94fc031c,0x00000000,0x00000000}},	//   _gvre_, _ཞྭའི_, --, --, 
   {{0xa3cc05f9,0x00000000,0x00000000,0x00000000}},	//   रबा_, --, --, --, 
   {{0x2d8c00b5,0x57e80212,0x1ab42077,0x00000000}},	//   _æder_, ідом_, _обая, --, 
   {{0x1dd0146b,0x6b940790,0xd90c0244,0x80dc000d}},	//   _सनात, şegü, دیچ_, _पोसइ, 
   {{0xb90004c5,0x78b9db75,0x6b44068c,0xcb100375}},	//   _নক_, pfuv, gògu, _שלב_, 
   {{0x92e8000e,0xe280190b,0x00000000,0x00000000}},	//   _মতে_, ңғын, --, --, 
   {{0x224c0118,0x527400db,0x00000000,0x00000000}},	//   řekl_, дубу, --, --, 
   {{0x2bc02871,0x00000000,0x00000000,0x00000000}},	//   _एहसा, --, --, --, 
   {{0x7a00002e,0xd25001d3,0x46100244,0x8678011a}},	//   _gёtt, ئنز_, _لوور, _ורצו, 
   {{0x70a80490,0xd0102586,0x2d9c0118,0xc5f000d9}},	//   गलेल, نلز_, ávem_, _ידו_, 
   {{0x4aac0490,0x850001d9,0x41240395,0xa2d800bc}},	// [35680] _घालव, _شوٝن, фото_, _फोक्, 
   {{0x2bd405f9,0x00000000,0x00000000,0x00000000}},	//   _धनबा, --, --, --, 
   {{0xdd9801ec,0x00000000,0x00000000,0x00000000}},	//   зші_, --, --, --, 
   {{0x0c25db76,0x2f040793,0x69dc0008,0x00000000}},	//   ммен, _mögi_, _árei, --, 
   {{0xfbcc1424,0x00000000,0x00000000,0x00000000}},	//   لتو_, --, --, --, 
   {{0x7bdc0381,0x510c0037,0xc438011a,0x00000000}},	//   æqua, _सतुआ_, חתני, --, 
   {{0x2d680365,0x2d9806af,0x1e94010b,0x28bc00cd}},	//   _eğer_, _uvre_, _яряр, ्जलि, 
   {{0x92e803f4,0xa3a805d7,0xb9e00212,0x3cc400db}},	//   _মতো_, खूँ_, тіши, _олсо_, 
   {{0x37a401c0,0x60c9db77,0x00000000,0x00000000}},	//   мтэн_, _ñeme, --, --, 
   {{0xa3cc0254,0xc8c8158b,0xb3b400eb,0x6cc401ee}},	//   रबस_, _ژوان_, টবাজ, _юйға, 
   {{0xda6400c6,0xead001ee,0x00000000,0x00000000}},	//   _كامي, _аҡһө, --, --, 
   {{0x4804009b,0x00000000,0x00000000,0x00000000}},	//   _опев, --, --, --, 
   {{0x83840022,0xf6d00633,0x00000000,0x00000000}},	//   ьыне, رزید, --, --, 
   {{0x65942038,0x00000000,0x00000000,0x00000000}},	//   _заку, --, --, --, 
   {{0x26cddb78,0x2f04010e,0xa1585d80,0x00000000}},	//   medo_, _gögi_, заву_, --, 
   {{0x5ff5db79,0x00000000,0x00000000,0x00000000}},	//   нзбу, --, --, --, 
   {{0x9f540063,0x00000000,0x00000000,0x00000000}},	// [35690] евач, --, --, --, 
   {{0x26cd04cc,0xbdf800f2,0x9e140024,0x00000000}},	//   nedo_, يرضا_, ндзі, --, 
   {{0x6295db7a,0x71240023,0x00000000,0x00000000}},	//   mazo, _ተወሲዶ, --, --, 
   {{0x26cddb7b,0xc0a8014d,0x00000000,0x00000000}},	//   hedo_, _بادل_, --, --, 
   {{0x6d980943,0x60cddb7c,0x907802e4,0x26cddb7d}},	//   ḓau, meam, _מטרי, kedo_, 
   {{0x629400b2,0x60cc379c,0x60c807dd,0x26cc8b19}},	//   nazo, leam, _ñemb, jedo_, 
   {{0x7dec0134,0x600801a9,0xd9440408,0x00000000}},	//   kɔsɛ, _nоmz, неки, --, 
   {{0x60cddb7e,0x6295db7f,0xb1242e1f,0x00000000}},	//   neam, hazo, _ተወዳዳ, --, 
   {{0x6295db80,0x08c0c5de,0xa6d8009e,0x26cc0115}},	//   kazo, убын, তানট, fedo_, 
   {{0x60cc379c,0x26cddb81,0xdb2402f6,0x6294072d}},	//   heam, gedo_, äpäi, jazo, 
   {{0x6295db82,0xd044043b,0x25ac014b,0x60cddb83}},	//   dazo, _bakɛ, gudl_, keam, 
   {{0x53a4010a,0x95c80022,0x00000000,0x00000000}},	//   намб, оуҭа_, --, --, 
   {{0x60cddb84,0x62940d24,0x9c7c00b0,0xb80414a0}},	//   deam, fazo, _anōk, _تباه, 
   {{0x26cc00aa,0x6295db85,0x2d9c00bc,0xe354009d}},	//   cedo_, gazo, ávek_, втсэ, 
   {{0x60cddb86,0x515401ec,0x55e444a5,0xc69000df}},	//   feam, етау, _чойб, _גאו_, 
   {{0x61e0019b,0x64400730,0x60cddb87,0x6b4400db}},	//   ælla, ßlic, geam, nògr, 
   {{0x6295db88,0xb4cc0574,0xb4ac0490,0x2124180f}},	// [356a0] bazo, रजी_, खली_, èlha_, 
   {{0x6295db89,0xdb18000f,0x27e00010,0x00000000}},	//   cazo, stwê, _šink_, --, 
   {{0x60cddb8a,0x0d843da1,0x02b4011a,0x99b003d4}},	//   beam, хлен, _אליך_, চবুক, 
   {{0xc8ac0fc8,0x2d680724,0x60cddb8b,0x00000000}},	//   _टाइट, _eşen_, ceam, --, 
   {{0x2b5c0109,0x26cc0789,0xbb440101,0x8b24004e}},	//   tmvc_, yedo_, کلون_, ндде, 
   {{0x26cd3258,0x6b840356,0x00000000,0x00000000}},	//   xedo_, ţigo, --, --, 
   {{0xe8780092,0x00000000,0x00000000,0x00000000}},	//   _አቀረቡ_, --, --, --, 
   {{0xf98c4d3f,0x26cc0083,0x629404ba,0xb9c0007b}},	//   حبو_, wedo_, zazo, اقيي, 
   {{0x26cddb8c,0x6295db8d,0xdb180100,0x15c801ec}},	//   tedo_, yazo, ktwè, _ﺒﻴﻨﻬ, 
   {{0x6294db3d,0xf76c00db,0xdee002d3,0x00000000}},	//   xazo, حاي_, _ሓበን_, --, 
   {{0x60cd6597,0x6295db8e,0xb4ac000d,0xf7b40345}},	//   yeam, vazo, खलू_, ودیش_, 
   {{0x26cddb8f,0x6295db90,0x2ca000c6,0xa3cc33ee}},	//   sedo_, wazo, óidh_, रबल_, 
   {{0x046409fe,0x6295db91,0x60cc0dd9,0x00000000}},	//   этом, tazo, veam, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x360002f2,0x00000000,0x00000000,0x00000000}},	//   _مووف, --, --, --, 
   {{0x6295db92,0xdb180036,0x60cc00a3,0x2f0402d2}},	//   sazo, ttwë, ueam, _mögu_, 
   {{0x62940f71,0x9ed9db93,0x60cd1fb8,0x2168010b}},	// [356b0] pazo, ммат_, ream, зиңи_, 
   {{0x60cddb94,0x69c9db95,0x6294022e,0x63a8031c}},	//   seam, _opde, qazo, ġend, 
   {{0x63bc2076,0x60cddb96,0xe134dead,0x00000000}},	//   ltsn, peam, _анны, --, 
   {{0xc0a812fc,0x4c900116,0x2098008e,0x00000000}},	//   _عاجل_, қиәс, _юкмы_, --, 
   {{0x69c9a381,0xbec400de,0x00000000,0x00000000}},	//   _apde, _adīš, --, --, 
   {{0x9f3400d6,0x61e47edf,0x63bc6eb8,0x5d84007b}},	//   _регі, _krhl, itsn, _للسل, 
   {{0x6b440137,0xdb180221,0x6dc400db,0x9e08007b}},	//   tògr, ntwé, _مۅلۅ, _غيرك_, 
   {{0xe9a843e8,0x63bc1061,0x2244219b,0x00000000}},	//   ردىن_, ktsn, ýlky_, --, 
   {{0x69c81529,0x6b440e89,0x81b40154,0x4a500304}},	//   _epde, rògr, ছবি_, лкәс, 
   {{0x55e5db97,0xa2ac243c,0x7c8002d3,0x0dd00092}},	//   вооб, _जाग्, _ይበሃል_, _የነፃ_, 
   {{0xbad00124,0x6b44004e,0x8af8010f,0x00000000}},	//   _аӡқә, pògr, _קלעז, --, 
   {{0xb4ac99b6,0x2f04049f,0x657c01d3,0x0604026b}},	//   खले_, _högt_, írha, тнюк_, 
   {{0x395ddb98,0x3cfdb77c,0x61e4015d,0x4c98011a}},	//   mmus_, _mouv_, _arhl, וברו, 
   {{0x395ddb99,0xaac407b7,0x07a0f239,0xc7b00375}},	//   lmus_, ल्पक, _ташн, _כבד_, 
   {{0x320c0232,0x63bc09b6,0x2f04002f,0x436400f3}},	//   ády_, atsn, _mögt_, тарн_, 
   {{0x3cfc1570,0xcfa800d1,0xd7a401f9,0x00000000}},	//   _nouv_, _ﺷﻪﺭﻗ, _गटाच, --, 
   {{0x7524376b,0x395c16b8,0x016000db,0x63bc0175}},	// [356c0] _imiz, imus_, ркто, ctsn, 
   {{0x71740075,0x395ddb9a,0x75240165,0xc2200d73}},	//   _مۇسا, hmus_, _hmiz, اکیو, 
   {{0x2d9c0588,0x3cfc05d5,0x395ddb9b,0x63a80003}},	//   éve_, _bouv_, kmus_, ġene, 
   {{0x63a819d6,0x3cfc39b4,0xef948c9e,0x625800b1}},	//   šene, _couv_, _میرد, _ярыр_, 
   {{0x2f04008c,0x75249748,0x60c800c7,0x3161db9c}},	//   _sögu_, _mmiz, _ñema, mmiz_, 
   {{0x69c81709,0x395c0381,0x3161db9d,0x2d68010e}},	//   _ppde, emus_, lmiz_, _işem_, 
   {{0x752400b5,0x395c003a,0x2bd40c6f,0x00000000}},	//   _omiz, fmus_, _धनवा, --, 
   {{0x3cfd4ef6,0x3160036b,0x395ddb9e,0xb4ac000d}},	//   _gouv_, nmiz_, gmus_, खलो_, 
   {{0x3160022e,0x63bc01e3,0x00000000,0x00000000}},	//   imiz_, xtsn, --, --, 
   {{0x7525db9f,0x395ddba0,0x8a05dba1,0x61f40175}},	//   _amiz, amus_, _иззе, yxzl, 
   {{0x395ddba2,0x31603c0e,0x69c8005c,0xe5b4dd77}},	//   bmus_, kmiz_, _upde, ыйны, 
   {{0x31600399,0x2ee40134,0x0904010b,0x4290001f}},	//   jmiz_, _ɔmfa_, _шпен, ዝዳንት_, 
   {{0x27e003d4,0x61e40427,0x7d0000d8,0x3160022e}},	//   _éin_, _srhl, ênsi, dmiz_, 
   {{0x75243926,0x63bddba3,0x2f0401b8,0x61e40219}},	//   _emiz, rtsn, _mögs_, _prhl, 
   {{0x2f040793,0x6729dba4,0xf745dba5,0xaac40aff}},	//   _lögs_, midj, _جلوي_, ल्यक, 
   {{0x26dddba6,0x3f980589,0x752407f5,0x61e40306}},	//   _havo_, tsqu_, _gmiz, _vrhl, 
   {{0x26dddba7,0x6728062c,0xa0a40116,0x73d80026}},	// [356d0] _kavo_, oidj, каңд, _адыр_, 
   {{0x656c0325,0x3f99dba8,0x395d7ea5,0x61e001e6}},	//   _hiah, rsqu_, zmus_, ålls, 
   {{0x656c166a,0x26dddba9,0x395ddbaa,0x2d680166}},	//   _kiah, _mavo_, ymus_, _eşem_, 
   {{0x26dddbab,0x67298fe8,0x656d1aca,0x644c020c}},	//   _lavo_, hidj, _jiah, _kyai, 
   {{0x351c0bd9,0x656c03d1,0x644c72ab,0x60dc0356}},	//   וואנ, _miah, _jyai, _iasm, 
   {{0x21285df1,0x656ddbac,0x26dc05b8,0x60dddbad}},	//   liah_, _liah, _navo_, _hasm, 
   {{0x60dddbae,0xdbd00037,0x2009dbaf,0xceb0011a}},	//   _kasm, _hüüa, lyai_, _לים_, 
   {{0x2129dbb0,0x656c06d9,0x6f880014,0x644c00b5}},	//   niah_, _niah, _سنہِ_, _oyai, 
   {{0x20085088,0xded40020,0x26dc01e4,0x644ddbb1}},	//   nyai_, _ራሱን_, _bavo_, _nyai, 
   {{0x26dddbb2,0x21296680,0x60dddbb3,0x79a40276}},	//   _cavo_, hiah_, _lasm, _арде, 
   {{0x656c1509,0x26dddbb4,0x316007d6,0x644c31a9}},	//   _biah, _davo_, ymiz_, _ayai, 
   {{0x2498b03b,0x644c0097,0x395c0204,0x67280076}},	//   gasm_, _byai, qmus_, aidj, 
   {{0x656ddbb5,0xef2847af,0x26dc75fa,0x6729dbb6}},	//   _diah, lmüş_, _favo_, bidj, 
   {{0x60dddbb7,0x26dddbb8,0xf6600228,0x644c002b}},	//   _aasm, _gavo_, _келү, _dyai, 
   {{0x60dd645f,0x2129dbb9,0x656d04d5,0x644c0083}},	//   _basm, fiah_, _fiah, _eyai, 
   {{0x656ddbba,0x212803a2,0x60dc2f19,0x7c38022e}},	//   _giah, giah_, _casm, _oxur, 
   {{0x26dc0e8a,0x644c0007,0x60dd9619,0x3160036b}},	// [356e0] _yavo_, _gyai, _dasm, rmiz_, 
   {{0x60dc3607,0x63a833e9,0x1fb40e92,0x26dc01a9}},	//   _easm, šenc, јстр, _xavo_, 
   {{0x200847d8,0x2129d82d,0x60dc067c,0x3160036b}},	//   ayai_, biah_, _fasm, pmiz_, 
   {{0x60dc037e,0x904405d9,0x31600007,0x6728c2bf}},	//   _gasm, _منجه, qmiz_, zidj, 
   {{0xe94401b9,0x5ec8015b,0x6608033f,0x00000000}},	//   یربی, রয়ে, zydk, --, 
   {{0x2fc00cf0,0xbb40009b,0x7b8400cf,0x00000000}},	//   mtig_, бечк, اانە, --, 
   {{0x60dc0882,0x672808ad,0x26dc0e8a,0x2fc17983}},	//   _yasm, vidj, _ravo_, ltig_, 
   {{0x26dc4077,0x6729dbbb,0x478825ff,0x2fc00142}},	//   _savo_, widj, нсом_, otig_, 
   {{0x26dddbbc,0x67280ffb,0x656c0165,0x7804009d}},	//   _pavo_, tidj, _riah, гээв_, 
   {{0x2fc00639,0x21280ac5,0xf77c15be,0x656ddbbd}},	//   itig_, ziah_, íça_, _siah, 
   {{0x2fc1dbbe,0x644c5c7c,0x64400cc1,0x6729dbbf}},	//   htig_, _syai, əliy, ridj, 
   {{0x2fc067df,0x26dc05b8,0x2009dbc0,0x1b0000d1}},	//   ktig_, _wavo_, yyai_, _гүән, 
   {{0x60dddbc1,0x26dddbc2,0x2fc00d27,0x21280548}},	//   _rasm, _tavo_, jtig_, viah_, 
   {{0x60dddbc3,0x06748c3c,0x212805b1,0x644c01f7}},	//   _sasm, _судя, wiah_, _vyai, 
   {{0x60dc2508,0x656ddbc4,0x21280a2e,0x2fc00660}},	//   _pasm, _tiah, tiah_, etig_, 
   {{0xdbd000af,0x60dc99da,0x00000000,0x00000000}},	//   _püüa, _qasm, --, --, 
   {{0x2fc1dbc5,0x212850f9,0x60dddbc6,0x2d6841b5}},	// [356f0] gtig_, riah_, _vasm, _eşek_, 
   {{0x60dddbc7,0x2129dbc8,0x2ca40036,0xeeb80408}},	//   _wasm, siah_, _admd_, ллуш_, 
   {{0x60dc1161,0x21280490,0x60c807dd,0x74bc00dc}},	//   _tasm, piah_, _ñemo, ष्कृ, 
   {{0x21280ac5,0x60dc007b,0x6e6433fc,0xa3c84709}},	//   qiah_, _uasm, стуж, _ईहा_, 
   {{0xec782080,0x2fc0015d,0xc91c000d,0x00000000}},	//   упі_, ctig_, _बगड़म_, --, 
   {{0x9c7c02b1,0x4aa4009d,0xef280205,0x00000000}},	//   _anōt, акшн_, tmüş_, --, 
   {{0xf2d4008f,0x1dc83ee1,0x998401e2,0x00000000}},	//   מעס_, _रहित, جلبو, --, 
   {{0x7c3801c6,0xef29dbc9,0x2b900f01,0x78680213}},	//   _txur, rmüş_, _کیوس, _növü, 
   {{0xf6f04028,0x279801c6,0x7c39dbca,0xa784150e}},	//   مزدگ, лтээ_, _uxur, یشیو, 
   {{0xd7080b32,0x7bd80a55,0xf7a808b0,0x1dc80490}},	//   тное_, _isuu, _ﺳﻪﻧﺪ, _रहात, 
   {{0xdce9dbcb,0x69940212,0x00000000,0x00000000}},	//   _lieč, _гріх, --, --, 
   {{0x2fc0017a,0x6b840115,0x00000000,0x00000000}},	//   ytig_, ŭige, --, --, 
   {{0xdce801a2,0xd45406bb,0x78693602,0x2d8c0327}},	//   _nieč, ртнь, _dövü, _ħdem_, 
   {{0x0cd001bc,0x00000000,0x00000000,0x00000000}},	//   _सस्म, --, --, --, 
   {{0xd174dfe6,0xe6b41411,0x2fc00042,0xab8c00fd}},	//   рыгы, _الىگ, wtig_, _ğömü, 
   {{0x387c02b4,0x7bd97781,0x63a807f5,0x00000000}},	//   ncur_, _osuu, šena, --, 
   {{0x2fc003fa,0x7bd81418,0x4f253fce,0x7778025c}},	// [35700] utig_, _nsuu, адаб, nqux, 
   {{0x2fc1dbcc,0x387c0098,0x37b400fe,0x00000000}},	//   rtig_, hcur_, _অনাৰ, --, 
   {{0x2fc00ae0,0x7bd80a49,0x00000000,0x00000000}},	//   stig_, _asuu, --, --, 
   {{0x8fd000fd,0x2fc0015d,0xe81800bc,0x504403f6}},	//   _мәзә, ptig_, धनमा_, _вемб, 
   {{0x387c058a,0xeac9dbcd,0x9f9400a2,0x64b40051}},	//   dcur_, лғай_, _küýe_, ờigi, 
   {{0x94f4081f,0x2d9c02fb,0x00000000,0x00000000}},	//   _བོའི_, áves_, --, --, 
   {{0x7bd80337,0xbea001f4,0x00000000,0x00000000}},	//   _esuu, _фаск, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc60c1810,0x7794366d,0x0c2401af,0x00000000}},	//   ान्य_, акыр_, _тман, --, 
   {{0x78680205,0xa7ac00a2,0x00000000,0x00000000}},	//   _sövü, mşüň_, --, --, 
   {{0x20d400e4,0xc8c80244,0x3a780115,0x00000000}},	//   _ẽimi_, _لوان_, _סטאד, --, 
   {{0x486402e8,0xe5340108,0x00000000,0x00000000}},	//   _кълб, семь, --, --, 
   {{0xb9340a7c,0x00000000,0x00000000,0x00000000}},	//   _דראג_, --, --, --, 
   {{0xdce8ada0,0xe694007b,0xcfcc03d4,0xdb0c0162}},	//   _rieč, _الثد, ৰমান, ákøk, 
   {{0x9f94010b,0x012406ed,0xa2940150,0x00000000}},	//   _düýe_, аќам, _қані, --, 
   {{0xa074010b,0xdce83e9d,0x00000000,0x00000000}},	//   сгач, _pieč, --, --, 
   {{0x6579089e,0x29d80208,0x28300092,0x00000000}},	// [35710] _huvh, _lũa_, _እስኪያ, --, 
   {{0x02a5dbce,0x6579dbcf,0x7bd80194,0x1df86b63}},	//   _трим, _kuvh, _rsuu, лезы_, 
   {{0x65785da9,0x7bd80a49,0x29d80051,0x00000000}},	//   _juvh, _ssuu, _nũa_, --, 
   {{0x65781aa1,0xad240c50,0x9bf40276,0xee380212}},	//   _muvh, يىلى, йзеч, шнє_, 
   {{0x657806d6,0x691c00e8,0x7c3000c7,0x2d9c0419}},	//   _luvh, _kéef, цҵах, áver_, 
   {{0x31c401d9,0x5ea4004b,0xefc800cf,0xeab80150}},	//   _دۅہہ, _دمسل, _туюк_, ийі_, 
   {{0x3e300a81,0x98a400d1,0x29d80208,0xfb8401d5}},	//   _بہار, бийе, _cũa_, ادچی, 
   {{0xe8741c5c,0x49c405f5,0xf77c0798,0x691c0036}},	//   ينىگ, ёлын_, íço_, _léef, 
   {{0x7bd983ab,0x387c054e,0x7c84013e,0x98a401e0}},	//   _usuu, rcur_, _буҷе, _ғиле, 
   {{0x387d8e21,0xdb18002d,0x2c04012c,0xe7ec0073}},	//   scur_, stwâ, वहरू_, जमजा_, 
   {{0x63ac013f,0x00000000,0x00000000,0x00000000}},	//   ɑnnɔ, --, --, --, 
   {{0x65781682,0xf38401b9,0x7ae0035a,0x00000000}},	//   _duvh, оғим, ldnt, --, 
   {{0x087400c8,0x00000000,0x00000000,0x00000000}},	//   _הענט_, --, --, --, 
   {{0x44600801,0xf67400d1,0x00000000,0x00000000}},	//   явяв, _ئاشخ, --, --, 
   {{0x65781682,0xe7300acb,0x00000000,0x00000000}},	//   _guvh, _غصه_, --, --, 
   {{0xd13000c6,0x6fac0d0a,0xe61001e2,0x412400cf}},	//   أمر_, _चिदं, _تشه_, босо_, 
   {{0xa49001d9,0x4fe9dbd0,0x5ee00154,0x00000000}},	// [35720] _تیُت, ыман_, নানে, --, 
   {{0x1ea8900f,0x3f8c00e4,0x9f580248,0x00000000}},	//   لامي_, ãgua_, _ìyìn_, --, 
   {{0x0c8547ac,0x6abddbd1,0x80a019c5,0x00000000}},	//   былм, _örfi, زمەن, --, 
   {{0xdcb80212,0x5bb40116,0x00000000,0x00000000}},	//   ищі_, ﭼﯘﺭﻻ, --, --, 
   {{0x2d082ce1,0x8a040220,0x691c1bce,0x00000000}},	//   _वकील_, өзде, _yéef, --, 
   {{0x4788d74f,0xbb41dbd2,0x7ff405d9,0x0054011a}},	//   қсим_, печк, _اسٽا, _לשכת_, 
   {{0x691c1bce,0x8d940014,0x69d80d27,0xdb2403e6}},	//   _jéeg, _دٔزت, uwve, تووی, 
   {{0x61e004ce,0x69d80036,0xe6d01546,0x00000000}},	//   ælli, rwve, तज्ज, --, 
   {{0x691c0694,0x499000f2,0xd90c1dd8,0x644003e0}},	//   _léeg, _کیبر, خین_, ğlik, 
   {{0x64400afb,0x6b8400e4,0x00000000,0x00000000}},	//   şlik, ãigu, --, --, 
   {{0x24f9dbd3,0x691c0de2,0x65780978,0x862402d5}},	//   анны_, _néeg, _quvh, сьпе, 
   {{0x6578047e,0x9f940254,0x00000000,0x00000000}},	//   _vuvh, _püüe_, --, --, 
   {{0x443c737f,0x00000000,0x00000000,0x00000000}},	//   çu_, --, --, --, 
   {{0x63a8506e,0x443c038f,0x659402d5,0x97000131}},	//   šeno, ħu_, _даку, _يېيى, 
   {{0x5ee00011,0x00000000,0x00000000,0x00000000}},	//   নামে, --, --, --, 
   {{0x691c0de2,0xd1f40092,0x00000000,0x00000000}},	//   _déeg, ገነቡ_, --, --, 
   {{0x6aa80162,0x6e2000e4,0xdd9800a2,0x338400c0}},	// [35730] _oddf, _ęmba, _ňň_, _нуэв, 
   {{0x942400d1,0x6d5800e4,0x00000000,0x00000000}},	//   _گوۋۇ, îvan, --, --, 
   {{0x5dd47a13,0xe1f91bf5,0xf1c40c5e,0x00000000}},	//   تقائ, _тенч_, rdší_, --, 
   {{0x6aa9dbd4,0xfe7435e3,0xc0c401e2,0x00000000}},	//   _addf, рүң_, _دېره_, --, 
   {{0x5ee000bd,0x691c0036,0x4bc0009d,0x00000000}},	//   নাবে, _méed, дөхг, --, 
   {{0x691ddbd5,0x198801a9,0xaac42e35,0xdd944eb1}},	//   _léed, абки_, ल्लक, _магы, 
   {{0xaac5d465,0x20300092,0x00000000,0x00000000}},	//   ستون, _በመቀየ, --, --, 
   {{0x6aa80076,0x17857534,0x6b84010f,0x00000000}},	//   _eddf, огим, ŭiga, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd1f40092,0x00000000,0x00000000,0x00000000}},	//   ገነባ_, --, --, --, 
   {{0xceb004ac,0x82e40135,0x9f9400a2,0x00000000}},	//   ויי_, _སྣེའ, _müñe_, --, 
   {{0x628404ce,0xa9a40150,0x7b0c00b5,0x3d04012d}},	//   _afho, _ءمنى, _søuh, _शवों_, 
   {{0x691c1bce,0x2d680139,0xa8786640,0xf780009d}},	//   _déed, _işet_, _احمر_, _эвлү, 
   {{0xd71c0020,0x78b9dbd6,0x00000000,0x00000000}},	//   _ስለሆነ, lguv, --, --, 
   {{0x42040364,0x62840332,0x00000000,0x00000000}},	//   онро_, _dfho, --, --, 
   {{0x78b9dbd7,0x8fd018ce,0x00000000,0x00000000}},	//   nguv, мәгә, --, --, 
   {{0x5275dbd8,0xa9a00150,0xc8480240,0x00000000}},	// [35740] _муну, _ﺍﻹﻤﻜ_, _ምትሕን, --, 
   {{0x0cd40f22,0x00000000,0x00000000,0x00000000}},	//   _সচেত, --, --, --, 
   {{0x691c00c7,0x1ea8143e,0x00000000,0x00000000}},	//   _héee, صالي_, --, --, 
   {{0x92b4c870,0xd0440085,0x0b8819a5,0x691c01e1}},	//   _احکا, _bakɔ, аски_, _kéee, 
   {{0x77e007f7,0x00000000,0x00000000,0x00000000}},	//   कटोक_, --, --, --, 
   {{0xf7654416,0x78b800ef,0x00000000,0x00000000}},	//   _زا_, eguv, --, --, 
   {{0xf64496d3,0x8c440213,0x00000000,0x00000000}},	//   _آئ_, _meşə, --, --, 
   {{0x8c45dbd9,0xb4e40303,0x78b802d2,0x00000000}},	//   _дебе, नयो_, gguv, --, 
   {{0x2d980042,0x7840009d,0x00000000,0x00000000}},	//   _hwre_, дээж, --, --, 
   {{0x691c002e,0x07083cc5,0x89f400c6,0x499001d5}},	//   _séed, рхии_, _وثائ, _قیتر, 
   {{0x69c40276,0x35b03163,0x00000000,0x00000000}},	//   ăies, мбэр, --, --, 
   {{0xe738052f,0x00000000,0x00000000,0x00000000}},	//   реү_, --, --, --, 
   {{0xe694035b,0x60c8035b,0x98f400c7,0x5ee00154}},	//   _еилы, _ñemi, _хҭыс_, নাতে, 
   {{0xf6c00156,0x2d980493,0x691c0036,0xc34802e8}},	//   _ཀཁགང, _owre_, _déee, ряме_, 
   {{0x31c4b8da,0x39800365,0xb6c801ed,0x8c4406be}},	//   мств, _kısa_, _خانے_, _deşə, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb408009d,0x4910000d,0x00000000,0x00000000}},	// [35750] _дээж_, _तवनो_, --, --, 
   {{0x685000b7,0x6fac0d79,0x00000000,0x00000000}},	//   _ሚንስት, _चिरं, --, --, 
   {{0xbd680c69,0x2d9400d4,0x00000000,0x00000000}},	//   арде_, дріс, --, --, 
   {{0x691c0de2,0x9f04bbed,0xe2c802f2,0x00000000}},	//   _léeb, _کوسو, _ئاکۆ_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d4808ce,0x9f580241,0x00000000,0x00000000}},	//   _ídan, _ìyàn_, --, --, 
   {{0x5ee000bd,0x18a452e2,0x940c016b,0xeab047ea}},	//   নাদে, пайм, _ɛfɑ_, ئعه_, 
   {{0x63a80135,0x00000000,0x00000000,0x00000000}},	//   ġenj, --, --, --, 
   {{0x63a804b9,0xca2c08b0,0x78b85d76,0xaac400d1}},	//   šenj, ﻧﺎﺕ_, rguv, ستۈن, 
   {{0x7d180008,0x69c40356,0x00000000,0x00000000}},	//   _hlus, ăier, --, --, 
   {{0x7d19dbda,0xceb0008f,0x78b8022e,0xdeec0092}},	//   _klus, עיט_, pguv, _ቀኑን_, 
   {{0xed80044e,0x1cb8031c,0x6b7c002b,0x4a5808c3}},	//   _ክነብር_, _མཐས_, _ṅgir, _הדעו, 
   {{0x691c00e8,0x8c4400ac,0xaa6400cf,0x43900006}},	//   _féeb, _peşə, _ىچۉۉ, наўс, 
   {{0x78a80036,0x7d19dbdb,0x8778010f,0x958400fb}},	//   _hdgv, _llus, _פאצי, _елке, 
   {{0x7d183926,0x00000000,0x00000000,0x00000000}},	//   _olus, --, --, --, 
   {{0x7d180066,0xdb180221,0x412400cf,0x625800ee}},	//   _nlus, ltwä, посо_, юряр_, 
   {{0x3cfc0073,0x0ea85cde,0xd02401a9,0x00000000}},	// [35760] ळाने_, йкай_, чмай, --, 
   {{0x7d19dbdc,0xdb18002f,0x63b800d7,0x00000000}},	//   _alus, ntwä, ňaný, --, 
   {{0x0dc8023a,0x91a4000d,0x00000000,0x00000000}},	//   слей_, _छिटै, --, --, 
   {{0x0ba957bc,0x4c68cd99,0x00000000,0x00000000}},	//   ماتى_, биен_, --, --, 
   {{0xbca00b24,0x00000000,0x00000000,0x00000000}},	//   رموي, --, --, --, 
   {{0x7d19dbdd,0xd90d59d6,0x2d98013f,0x6b840115}},	//   _elus, ییل_, _twre_, ŭigo, 
   {{0xf98c1371,0x2720004d,0x9f580241,0x00000000}},	//   هبي_, _hòng_, _ìyán_, --, 
   {{0x398003be,0x7d1803cb,0x00000000,0x00000000}},	//   _qısa_, _glus, --, --, 
   {{0x6d41dbde,0xcb0800ec,0x4c9401af,0x00000000}},	//   _ijma, _ٿيان_, _миңс, --, 
   {{0xa6140a5b,0x27200051,0xdb0800f1,0x00000000}},	//   дмоч, _mòng_, _وزله_, --, 
   {{0x272007ae,0x2465dbdf,0xa4d87b17,0x248c0022}},	//   _lòng_, _mūmū_, одну_, ñemo_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2720004d,0x00000000,0x00000000,0x00000000}},	//   _nòng_, --, --, --, 
   {{0x15d800e5,0x00000000,0x00000000,0x00000000}},	//   حدیں_, --, --, --, 
   {{0x65880316,0x2d5c21fc,0xd76401d3,0x00000000}},	//   _běhe, víen_, _تنوی, --, 
   {{0x1cb8025c,0x27200208,0x00000000,0x00000000}},	//   _མཐེ_, _bòng_, --, --, 
   {{0xc05800d6,0x224c0034,0x2720004d,0x00000000}},	// [35770] сів_, łek_, _còng_, --, 
   {{0x272007ae,0x35a40345,0x64d40248,0x00000000}},	//   _dòng_, _بۆێێ_, _ọgọọ, --, 
   {{0x2d5c004e,0x6f1c0332,0x2124180f,0xdcf40171}},	//   ríen_, _dlrc, èlhs_, _auzā, 
   {{0x6d480413,0xa2c411bc,0x27200051,0x69dc08a5}},	//   _ídal, िभक्, _fòng_, _árey, 
   {{0x60cddbe0,0xed5800d6,0x29040129,0x1ae401a9}},	//   mfam, чої_, djma_, долм, 
   {{0x60cddbe1,0xee380408,0x00000000,0x00000000}},	//   lfam, ннĕ_, --, --, 
   {{0x7d1800bc,0xd9440137,0x9d1801f0,0x00000000}},	//   _tlus, меки, _довт_, --, 
   {{0x60cddbe2,0x7d19dbe3,0x9788036b,0x62a401e1}},	//   nfam, _ulus, ойиб_, _ńró, 
   {{0xd6e00729,0x60cddbe4,0xdb180e78,0x2d680139}},	//   বাসয, ifam, ttwä, _işep_, 
   {{0xd6bc04c5,0x29040311,0x00000000,0x00000000}},	//   _অসহয, ajma_, --, --, 
   {{0x60cc05ac,0xdb180112,0x15440150,0x00000000}},	//   kfam, rtwä, денм, --, 
   {{0x78a80334,0x53a43412,0xdb180112,0x8d8c0023}},	//   _udgv, мамб, stwä, _ዝነቅል_, 
   {{0x776002d0,0x47e001e0,0xe5a402dd,0x00000000}},	//   _thnx, _аҙыҡ, _ﻋﻨﺼﺭ_, --, 
   {{0x60cddbe5,0x2720004d,0xd2500050,0x00000000}},	//   efam, _ròng_, ٖنس_, --, 
   {{0x60cc0a55,0xd131dbe6,0xa2cc0882,0x2720004d}},	//   ffam, نمس_, द्ध्, _sòng_, 
   {{0x4f940261,0xe6100345,0x32040210,0x00000000}},	//   држу, _حشه_, ćmy_, --, 
   {{0x4f09dbe7,0x453000db,0xc8480023,0x1fb42377}},	// [35780] онан_, _جىير, _ምድሓን, есхр, 
   {{0x272007ae,0x1cb80003,0x60cc198f,0x3980030a}},	//   _vòng_, _མཐུ_, afam, _oñs_, 
   {{0x60cddbe8,0x56780092,0x4bd800ec,0x02f8011a}},	//   bfam, _ከአንዱ_, ڪباد_, _ולימ, 
   {{0x9e65dbe9,0xdb18020c,0x2720004d,0xdcf400ef}},	//   رالن, luwè, _tòng_, _puzā, 
   {{0x39800694,0x246402b5,0xee480014,0x8b640345}},	//   _añs_, _tūmū_, _کیا٘_, واتم, 
   {{0xbb58037e,0xa8280131,0x00000000,0x00000000}},	//   _rayバ_, ۋۋال_, --, --, 
   {{0x2d5c00cf,0xbb44484d,0x7c3406be,0x63a8025c}},	//   líem_, بلون_, _əbrə, ġeni, 
   {{0x63a801a2,0x6d400309,0xdb180066,0x00000000}},	//   šeni, _ujma, huwè, --, 
   {{0x5ee000bd,0x2d5c0137,0x05800092,0x05a40092}},	//   নারে, níem_, _ከደቡብ_, _ለደቡብ_, 
   {{0xf404015b,0x97800214,0x861401f0,0x00000000}},	//   উনার_, دیوه, деоӣ_, --, 
   {{0x60cc03ee,0xdb180214,0xfaa0cb32,0xfb1000db}},	//   yfam, duwè, _рахо, _جولج, 
   {{0x6b81dbea,0x60cc0165,0x00000000,0x00000000}},	//   _kumg, xfam, --, --, 
   {{0x7a10038e,0x67d4004e,0x00000000,0x00000000}},	//   _větš, _чолу, --, --, 
   {{0x2720007f,0x2d5c4b84,0xca2c0023,0x00000000}},	//   _bòne_, díem_, _እንታዎ, --, 
   {{0x60cc00d2,0x76b808c3,0xf64c00ec,0x00000000}},	//   tfam, _ומופ, _پئو_, --, 
   {{0x2488b245,0x00000000,0x00000000,0x00000000}},	//   _ufam_, --, --, --, 
   {{0x60cc0a55,0x2d5c004e,0x5f7800be,0x1544030d}},	// [35790] rfam, gíem_, سماس_, _чĕтр, 
   {{0x63bd9c08,0xfeb82f84,0xbc7c0092,0x00000000}},	//   musn, تارت_, ዕድንና_, --, 
   {{0x63bddbeb,0x60cc0433,0x5ee00154,0x23b40c4f}},	//   lusn, pfam, নালে, _غمگس, 
   {{0x61e40517,0x63bc4b0a,0x60cc022f,0x2d5c381a}},	//   _ishl, ousn, qfam, bíem_, 
   {{0x6b8007de,0xfeb8104c,0xc0dc0092,0x63a80327}},	//   _cumg, _واست_, ነናል_, ġenw, 
   {{0xdcf40276,0x8f9808a8,0x34dc012c,0x00000000}},	//   _buză, _מישי, _बस्द, --, 
   {{0x7b0c03b2,0x29c8002d,0x63bc0066,0x00000000}},	//   _bøur, gûa_, husn, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6c54d1b9,0x6b810c2c,0x69c80135,0x9d4402dd}},	//   _акту, _gumg, _eqde, _жеңд, 
   {{0x61e58f76,0x00000000,0x00000000,0x00000000}},	//   _oshl, --, --, --, 
   {{0x7bc9dbec,0x63bc0098,0x6b80022e,0x450c0241}},	//   ltgu, eusn, _zumg, _àbọ̀_, 
   {{0xdb180066,0x89940375,0x6b8001d5,0x63bc0327}},	//   duwé, _נכנס_, _yumg, fusn, 
   {{0x61e4b0f0,0x2d9ddbed,0x63bddbee,0x7bc9dbef}},	//   _ashl, ávez_, gusn, ntgu, 
   {{0x74502295,0x2d5c0137,0xc0cc0023,0xd6281eed}},	//   _መንግሥ, víem_, _ብሄረ_, _ноле_, 
   {{0x691c01c7,0xe6c4007b,0xaac40118,0x00000000}},	//   _méen, _شتوي, ल्टक, --, 
   {{0x691c0de2,0xc0e0064d,0xc5780375,0xdb180066}},	//   _léen, лоск, _צרפת, suwè, 
   {{0x63bc0086,0x61e49da5,0x2175dbf0,0x41240395}},	// [357a0] cusn, _eshl, турр, хото_, 
   {{0x357c067d,0x6b81dbf1,0xe2f80489,0x2d5c8d22}},	//   _ኩነታት_, _rumg, _ཕོགཔ_, ríem_, 
   {{0x2d9ddbf2,0x429806a9,0x6b81dbf3,0x10a40139}},	//   ève_, _מסיב, _sumg, _пинн, 
   {{0x2ca000c6,0xb81c0490,0x6b80014f,0xfe4085ce}},	//   úid_, यनाम_, _pumg, ынхо, 
   {{0xfbcd2d62,0x6b80014f,0xa2cc4668,0xec341f0d}},	//   متو_, _qumg, द्व्, خوشگ, 
   {{0x8b640116,0x00000000,0x00000000,0x00000000}},	//   راشم, --, --, --, 
   {{0x6b80014b,0x691c04e6,0x14c40490,0x9e7001ec}},	//   _wumg, _déen, _वाढण, _نۇكت, 
   {{0x6b8005d5,0x63bc0098,0x88b007d6,0x00000000}},	//   _tumg, yusn, ایشچ, --, 
   {{0x0b4462d9,0x63bc0232,0xca4804fb,0x7bc80175}},	//   _знан, xusn, _کلاه_, ctgu, 
   {{0x691c00e8,0x63bcdd29,0x3f8c00c7,0x00000000}},	//   _géen, vusn, ãgui_, --, 
   {{0x65880118,0x5b340153,0x00000000,0x00000000}},	//   _běha, _рэту, --, --, 
   {{0xe534030d,0x178000c7,0x00000000,0x00000000}},	//   темь, ықәг, --, --, 
   {{0x27e08b74,0x62240131,0x691c0694,0x320c0108}},	//   _èin_, ھىرل, _yéen, ädyn_, 
   {{0x62240075,0xeff80b82,0xf2e401f4,0x00000000}},	//   پىرل, ገደደ_, люсо, --, 
   {{0x63bc8590,0x7bc805d5,0xa158013e,0xe81800bc}},	//   susn, ztgu, даву_, धनका_, 
   {{0x36580302,0x970000d1,0x7bc8022e,0x00000000}},	//   _מכונ, _مېۋى, ytgu, --, 
   {{0xdb1800f2,0x3f8c1bce,0xa0747125,0x00000000}},	// [357b0] suwé, ëgu_, тгач, --, 
   {{0x3f8c00da,0x3e6800f3,0x00000000,0x00000000}},	//   īgu_, пшен_, --, --, 
   {{0xad241c02,0x63ac08a7,0x61e5dbf4,0x691c06af}},	//   گىنى, _hvan, _ushl, _réen, 
   {{0x63ac04ac,0x7bc83fc6,0xa2ccdb71,0x691c0694}},	//   _kvan, ttgu, द्र्, _séen, 
   {{0x3bf007dd,0xad253109,0x63ac27ac,0x00000000}},	//   ыҟат, دىنى, _jvan, --, 
   {{0x63acc38c,0x7bc87fff,0x00000000,0x00000000}},	//   _mvan, rtgu, --, --, 
   {{0x7bc9dbf5,0x941003be,0x590800f7,0x63addbf6}},	//   stgu, _deyə_, дейм_, _lvan, 
   {{0x63addbf7,0x98740063,0x9b88007b,0x00000000}},	//   _ovan, купљ, _ينزل_, --, 
   {{0x3ea1399f,0xa904198a,0x6bd401b9,0x96b8741b}},	//   _kejt_, ابىن, _متلر, муну_, 
   {{0x3cfc0073,0x941006be,0x5588009b,0x7b7400ae}},	//   ळावे_, _geyə_, мбом_, _أطرا, 
   {{0xd628cef8,0x3ea00036,0x00000000,0x00000000}},	//   фоне_, _mejt_, --, --, 
   {{0x63ac02c4,0xd7d40022,0x00000000,0x00000000}},	//   _bvan, _ацкь, --, --, 
   {{0x63ac1529,0x2f34001f,0x691c002e,0x941003b9}},	//   _cvan, _በየጊዜ, _méel, _yeyə_, 
   {{0x691c002e,0x3ea0036e,0x661000e8,0x00000000}},	//   _léel, _nejt_, ëkkë, --, 
   {{0x8cd0262c,0x6d4801e1,0x00000000,0x00000000}},	//   ण्डो, _ìdag, --, --, 
   {{0x6b84010f,0x00000000,0x00000000,0x00000000}},	//   ŭigi, --, --, --, 
   {{0x3ea1dbf8,0x63ac0097,0xc0e08702,0x00000000}},	// [357c0] _bejt_, _gvan, шотк, --, 
   {{0xfbe40f22,0xf1540133,0x63a80003,0xd18401a9}},	//   পমাত, _ڕێزد, ġent, _илой, 
   {{0x63addbf9,0x3ea001e3,0x63a802f0,0xaab800e5}},	//   _zvan, _dejt_, šent, ہگار_, 
   {{0x63ac0ffb,0x272001c3,0x3d280fc6,0xd17464c2}},	//   _yvan, _mòna_, وتنی_, _шыпы, 
   {{0x691c226d,0x99400034,0x27200ba1,0x6a7c08fb}},	//   _déel, kół_, _lòna_, jåfø, 
   {{0x3ea0031c,0x00000000,0x00000000,0x00000000}},	//   _gejt_, --, --, --, 
   {{0x27200109,0xa9343f3a,0x2fc00437,0x0d2000cf}},	//   _nòna_, лекш, luig_, _күжү, 
   {{0xcb0800b2,0x2fc00165,0x3ea0031c,0x658801ef}},	//   _ڪيئن_, ouig_, _zejt_, _běhn, 
   {{0x2fc1dbfa,0x31c803d4,0xc8f000e1,0xf80002d5}},	//   nuig_, শবিশ, _अफीम_, ачэн, 
   {{0x2720068c,0x63ac0114,0xcb0805d9,0x2ca413ee}},	//   _bòna_, _rvan, _تيئن_, _hemd_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x27200ba1,0x691c1bce,0x32180432,0x00000000}},	//   _dòna_, _kéem, dyry_, --, 
   {{0x691c1bce,0x63ac003a,0x2fc00af9,0xa91c00d0}},	//   _jéem, _qvan, juig_, _guľa, 
   {{0x63ac0083,0x68e1dbfb,0xdb18002d,0x3630085b}},	//   _vvan, lemd, erwê, اریس, 
   {{0x691c002e,0x661c0158,0x32180432,0x00000000}},	//   _léem, ørkd, gyry_, --, 
   {{0xf6bc0d46,0x68e1dbfc,0x2ca40158,0x3ea0df45}},	//   _མཐོང, nemd, _nemd_, _sejt_, 
   {{0x63addbfd,0x2fc1dbfe,0x691da75f,0x9410016b}},	// [357d0] _uvan, guig_, _réel, _meyɛ_, 
   {{0x63a803c6,0x68e0f369,0x9e240131,0x321800a2}},	//   šens, hemd, лчеһ, byry_, 
   {{0x68e1dbff,0x3cfc0490,0x44280175,0x99ac00eb}},	//   kemd, ळाले_, lzc_, _কঙ্ক, 
   {{0x2fc1dc00,0x68e00b21,0x99400210,0x00000000}},	//   buig_, jemd, zół_, --, 
   {{0x2ca40158,0x68e1dc01,0xc05802dd,0x92e400fe}},	//   _demd_, demd, _іім_, ফাৰ_, 
   {{0x9f340220,0x65880118,0x00000000,0x00000000}},	//   _сегі, _něho, --, --, 
   {{0x99d40dd8,0xe9a805d9,0xec600241,0x00000000}},	//   اتتا, ندين_, _íónì_, --, 
   {{0x57e80209,0x89d5dc02,0x7c840e92,0xd7e80395}},	//   едим_, اوير_, _јуве, емие_, 
   {{0x775c0020,0x2720068c,0x7e7405d9,0x6588013a}},	//   _ህብረተ, _sòna_, _ساڳئ, _běho, 
   {{0x3cfc0218,0x7bd806c8,0x7c80044e,0x15b8b789}},	//   _hnuv_, _ipuu, _ክበሃል_, нымы_, 
   {{0x68e0014b,0xb8b002dd,0xd82400d1,0xd4a4010b}},	//   bemd, _көпі, _әдли, линй, 
   {{0xd185dc03,0x4428010a,0x691c0694,0x68e00205}},	//   ғлай, fzc_, _yéem, cemd, 
   {{0x7c2817da,0x13a403e6,0xe97000cf,0x8888010f}},	//   nzgr, دۆخی_, _بۇيد, _טרײַ, 
   {{0x395ddc04,0x7bd91c9a,0x76c40014,0x272001ab}},	//   llus_, _mpuu, _شُبہ_, _tòna_, 
   {{0x395ddc05,0xe4c80133,0x71040124,0x00000000}},	//   olus_, ربێن_, аҧна, --, 
   {{0xd130495f,0x2fc1dc06,0x661c5b47,0x32180022}},	//   حمر_, tuig_, ørke, ryry_, 
   {{0x7525dc07,0x27200100,0x01600902,0x2b400036}},	// [357e0] _iliz, _mònn_, скто, éick_, 
   {{0x7524adaf,0x3cfc022e,0x691c0129,0x68e000e2}},	//   _hliz, _anuv_, _réem, zemd, 
   {{0x7bd9dc08,0x7524098d,0x2fc00ea0,0x68e1dc09}},	//   _apuu, _kliz, suig_, yemd, 
   {{0xd00806ed,0x2fc1dc0a,0x8700015b,0x0c244660}},	//   _земе_, puig_, এসএফ_, лмен, 
   {{0x9410016b,0x395c00c5,0x75243545,0xb9c00131}},	//   _reyɛ_, dlus_, _mliz, ەقىي, 
   {{0x691c0de2,0x395c00c5,0x31600165,0x00000000}},	//   _géej, elus_, lliz_, --, 
   {{0xfc3c008c,0x2720007f,0x752404ba,0x68e1dc0b}},	//   _þín_, _bònn_, _oliz, temd, 
   {{0x395ddc0c,0x31600007,0x691c0694,0x3cd8000d}},	//   glus_, nliz_, _téem, _गउये_, 
   {{0x68e1dc0d,0x37a4009d,0x8034010f,0x00000000}},	//   remd, лтэн_, ָניע_, --, 
   {{0x68e1dc0e,0x7525dc0f,0x31600007,0x395ddc10}},	//   semd, _aliz, hliz_, alus_, 
   {{0xdce801e4,0xdaa000db,0x31600100,0x3e6401a9}},	//   _lieĝ, _بەىپ, kliz_, tеti_, 
   {{0x6475dc11,0x31600007,0x2d680356,0x07a5dc12}},	//   игну, jliz_, _aşez_, _бадн, 
   {{0x6588012c,0x14c407b7,0x7950009f,0x00000000}},	//   _těho, _वारण, _اَنا, --, 
   {{0x7525dc13,0xa5c5dc14,0x27200100,0x2b403a35}},	//   _eliz, _көме, _zònn_, éich_, 
   {{0x2258cd09,0x691c00e8,0x35f40451,0x565400f1}},	//   тивы_, _néek, _مريد_, _پروړ, 
   {{0x3161dc15,0x7524030a,0x00000000,0x00000000}},	//   gliz_, _gliz, --, --, 
   {{0x656ddc16,0x2d5c004e,0x320c0158,0xf1b8003d}},	// [357f0] _ihah, níeu_, ødyr_, ġġa_, 
   {{0xdbd000fd,0x00000000,0x00000000,0x00000000}},	//   lüçe, --, --, --, 
   {{0x395ddc17,0x3160083a,0x656ddc18,0x7bd80373}},	//   ylus_, bliz_, _khah, _spuu, 
   {{0x5d547979,0x7c280112,0x63bc0af9,0xc6840014}},	//   шкет, tzgr, orsn, _ژِ_, 
   {{0x656c01ab,0x395d42f5,0x00000000,0x00000000}},	//   _mhah, vlus_, --, --, 
   {{0x21280a2e,0x38bc00fd,0x63bc0437,0x7c29dc19}},	//   lhah_, kärü_, irsn, rzgr, 
   {{0x395c007d,0x656ddc1a,0x63bc002f,0x00000000}},	//   tlus_, _ohah, hrsn, --, 
   {{0x63bc2375,0x9b94084c,0xd7c9dc1b,0x2128cca2}},	//   krsn, _виац, نوبه_, nhah_, 
   {{0x7bd9dc1c,0x644c01ab,0x395c000d,0x00000000}},	//   _upuu, _nxai, rlus_, --, 
   {{0x656c98aa,0x2128f73a,0x752402fb,0x31600369}},	//   _ahah, hhah_, _sliz, zliz_, 
   {{0x752470cd,0x63bc2382,0xa91c00d0,0xeb04004e}},	//   _pliz, ersn, _guľo, _учто, 
   {{0x656c0978,0x316001f9,0x212805b1,0x2d5c00db}},	//   _chah, xliz_, jhah_, bíeu_, 
   {{0x21280502,0x656c7299,0x740409bd,0x7ae1dc1d}},	//   dhah_, _dhah, উন্ট_, oent, 
   {{0x656ddc1e,0x684400d4,0x38bc008e,0x00000000}},	//   _ehah, _уніа, bärü_, --, 
   {{0x63bc0013,0x644ddc1f,0x7ae1dc20,0x31600369}},	//   arsn, _exai, ient, tliz_, 
   {{0x7ae1dc21,0x7525dc22,0x6ed80316,0x656c0842}},	//   hent, _uliz, न्नु, _ghah, 
  
   {{0x7ae1dc23,0xdb0800e4,0x3160a8dc,0xe1f000f1}},	// [35800] kent, _aveí, rliz_, يسې_, 
   {{0x7ae1dc24,0x656c0a2e,0x21280218,0x2ea802f2}},	//   jent, _zhah, ahah_, اپای_, 
   {{0x7ae04c28,0x720800f8,0x4c842470,0x691c0036}},	//   dent, _صفحہ_, алев, _féeh, 
   {{0x0ba821ef,0x705403e6,0x7ae0062c,0x2129dc25}},	//   ناتى_, _هۆزا, eent, chah_, 
   {{0x8c44d7eb,0xaa94022e,0x00000000,0x00000000}},	//   шеде, билч, --, --, 
   {{0xbb4006ed,0x2d5c00db,0x1ea8007b,0x67280200}},	//   оечк, víeu_, _مافي_, xhdj, 
   {{0xd9b021ef,0x094801f0,0x00000000,0x00000000}},	//   كەلد, кчии_, --, --, 
   {{0x1ce4031c,0x7ae000d8,0x63bc0363,0x00000000}},	//   _ཨིར_, aent, yrsn, --, 
   {{0x7ae0bbab,0x0745dc26,0x00000000,0x00000000}},	//   bent, ихом, --, --, 
   {{0x656ddc27,0x63bc04b9,0x89d402bf,0x2d5c00cf}},	//   _shah, vrsn, _відш, ríeu_, 
   {{0x656c052f,0x48e448bd,0x6ed807b7,0xd6a40131}},	//   _phah, _воев, न्यु, _ﺋﯘﻻﺭ_, 
   {{0x6aa80368,0xbb800137,0x00000000,0x00000000}},	//   _hedf, _الەي, --, --, 
   {{0x656c1aa1,0x2d5d330f,0xdbd00724,0x1ce4025c}},	//   _vhah, líes_, rüçe, _ཨིལ_, 
   {{0x6ed81a3e,0x63bc143a,0x27b40304,0x212801ab}},	//   न्मु, rrsn, _кәүс, whah_, 
   {{0x656c0184,0x2129dc28,0x6aa80ec3,0x69dc0793}},	//   _thah, thah_, _medf, _äred, 
   {{0x644c0190,0xdb180699,0x6aa80493,0x656ddc29}},	//   _txai, ntwò, _ledf, _uhah, 
   {{0xc058090b,0x385402d3,0x212805b1,0xf1c40030}},	// [35810] тів_, _ምትሕብ, rhah_, teší_, 
   {{0x7ae1dc2a,0x2129dc2b,0xff50e591,0x3ea5dc2c}},	//   xent, shah_, آخر_, únt_, 
   {{0x6285dc2d,0x8c4000ac,0xc0bc00b7,0x7f54003a}},	//   _igho, əğin, ስመር_, roxq, 
   {{0x7ae1dc2e,0x5c7417a2,0x98ac033f,0x3a040133}},	//   went, блет, mieć_, یکای_, 
   {{0x7ae1dc2f,0x6aa9dc30,0x1c39dc31,0x2d8d57a0}},	//   tent, _bedf, ызды_, _éden_, 
   {{0xd1dc044e,0x7ae1dc32,0x691c002e,0x6284031c}},	//   _ንሰብ_, uent, _kéew, _jgho, 
   {{0x6aa846d1,0x2138036e,0x98ac012d,0xec68008e}},	//   _dedf, _kmsh_, nieć_, лрәк_, 
   {{0x6aa8127b,0x62840327,0x83040327,0x1ee800e5}},	//   _eedf, _lgho, _ཅོའུ_, _جوڑی_, 
   {{0x691c0de2,0xa7a80032,0xfc3c00e4,0x17f8007b}},	//   _léew, айыҡ_, _äí_, اربة_, 
   {{0x6285dc33,0x7ae0e483,0x98ac0210,0x00000000}},	//   _ngho, qent, kieć_, --, 
   {{0x998406d5,0x58d40276,0x691c1bce,0x2d5c004e}},	//   _الصو, _гоет, _néew, cíes_, 
   {{0x1ce40156,0x972404d3,0x6285dc34,0x37c00032}},	//   _ཨིས_, _گفتو, _agho, _һәүб, 
   {{0xdcf400da,0x5eac00fe,0xd7f43740,0x37a80354}},	//   _atzī, _চানে, _ызды, _ртен_, 
   {{0xbf980b21,0x0874010f,0x7950009f,0x00000000}},	//   _krêf, _פעסט_, _اَچا, --, 
   {{0x1af00c58,0xf65001d5,0xd9f82072,0x00000000}},	//   চাপে_, _بئش_, ्मित_, --, 
   {{0x691cc52a,0x62843b97,0xd174008e,0x00000000}},	//   _déew, _egho, сыгы, --, 
   {{0x4f240b01,0x13b4007b,0x00000000,0x00000000}},	// [35820] бдаб, _اصبح, --, --, 
   {{0x691c00e8,0xd9f81a2a,0x00000000,0x00000000}},	//   _féew, ्मात_, --, --, 
   {{0x6aa8f8d2,0x248c0232,0xc33000c8,0x98ac012d}},	//   _redf, žeme_, _מוז_, cieć_, 
   {{0x2d5c00eb,0x245402e3,0x00000000,0x00000000}},	//   víes_, ụme_, --, --, 
   {{0x4c54007b,0x24380092,0x00000000,0x00000000}},	//   حضار, _አንደሚ, --, --, 
   {{0x2d5c0789,0x691c002e,0x2fc1dc35,0x00000000}},	//   tíes_, _yéew, mrig_, --, 
   {{0xbea00801,0x691c0694,0x6aa803cd,0x2fc1dc36}},	//   _хаск, _xéew, _vedf, lrig_, 
   {{0xa7b8084c,0x2d5c00db,0x62480677,0x00000000}},	//   алиу_, ríes_, ינוּ_, --, 
   {{0x0c25dc37,0x2fc1dc38,0x7e8401d3,0x00000000}},	//   _уман, nrig_, _árpá, --, 
   {{0x2fc008c2,0xdb18033b,0x44240055,0x00000000}},	//   irig_, stwò, _ān_, --, 
   {{0xbf980b21,0x2fc1dc39,0xd5ac004b,0xc8c80133}},	//   _grêf, hrig_, نځي_, _موان_, 
   {{0x2fc0752e,0x6ed837e3,0x38c804fb,0x691c1574}},	//   krig_, न्तु, _ماهی_, _réew, 
   {{0x597003e6,0x69dc0139,0x00000000,0x00000000}},	//   _تگوز, _äreb, --, --, 
   {{0x2fc1dc3a,0x2d983ae2,0xa5f87e1b,0xc1e8b40e}},	//   drig_, _otre_, _веку_, льбе_, 
   {{0x2d9807ab,0x2fc1dc3b,0xf204005b,0xf74401e2}},	//   _ntre_, erig_, пято, _دلوي_, 
   {{0xa0c5b35c,0x9c7c02b5,0x2fc17605,0x00000000}},	//   تيرو, _maōr, frig_, --, 
   {{0x2d99beb4,0x6284031c,0x83a801d5,0xbe8400ae}},	// [35830] _atre_, _tgho, _ётиб_, مجاو, 
   {{0x691c00e8,0x77240092,0x00000000,0x00000000}},	//   _téew, _ስለሚሰ, --, --, 
   {{0x6ed81d27,0x2fc00165,0x3e68b7a2,0x00000000}},	//   न्धु, arig_, ушан_, --, 
   {{0x2fc0ebad,0x21380672,0x310000dc,0xc058187f}},	//   brig_, _umsh_, _लोपः_, _біг_, 
   {{0x2d99dc3c,0xdb5400ee,0x00000000,0x00000000}},	//   _etre_, овды, --, --, 
   {{0x6ed808ec,0x3cd8000d,0x9e34014b,0x00000000}},	//   न्दु, _गउवे_, _дегч, --, 
   {{0xbf980b21,0xa91c00d0,0xcca80228,0x6d0400db}},	//   _brêg, _guľk, انۇۇ_, تبەق, 
   {{0xe9a806f6,0x64401cce,0x00000000,0x00000000}},	//   حدون_, şliy, --, --, 
   {{0x3f81dc3d,0x1af00183,0x661c2ab7,0x3f88054e}},	//   _kiju_, চাবে_, ørkn, _jucu_, 
   {{0x2d98319f,0x3f89dc3e,0x3f800241,0x16a801f0}},	//   _ytre_, _mucu_, _jiju_, швои_, 
   {{0x3f89dc3f,0x58d401af,0x00000000,0x00000000}},	//   _lucu_, _можт, --, --, 
   {{0x27e0084c,0x26dc0083,0x3f8000f3,0x00000000}},	//   _ţine_, _ebvo_, _liju_, --, 
   {{0x60c8035b,0x3f88054e,0xdbd003e3,0xf1c000d7}},	//   _ñemy, _nucu_, _düça, čšmi_, 
   {{0x59dc1431,0x60dc074d,0x2fc1dc40,0x6fa4000d}},	//   _महार, _absm, vrig_, _चौगू, 
   {{0x2fc00af9,0x00000000,0x00000000,0x00000000}},	//   wrig_, --, --, --, 
   {{0x3f8008e7,0x3f8805b1,0x2fc1dc41,0x09bc015b}},	//   _aiju_, _bucu_, trig_, _আহমা, 
   {{0x78a8066d,0x2fc1dc42,0x3f80005f,0xb64002dd}},	// [35840] _megv, urig_, _biju_, _ﺍﻱ_, 
   {{0x2fc1dc43,0x3f800e3c,0x11e40139,0x60c800e2}},	//   rrig_, _ciju_, _джом, _ķeme, 
   {{0x0ca807d6,0x3f8001e1,0xcc883129,0x2fc0005c}},	//   атли_, _diju_, абее_, srig_, 
   {{0xfbcc05d9,0x2fc0007c,0x00000000,0x00000000}},	//   چتو_, prig_, --, --, 
   {{0xfbcddc44,0x7cd40035,0x3f8815b7,0x00000000}},	//   نتو_, تونز_, _gucu_, --, 
   {{0x09bc015b,0x78a80037,0x0ef80006,0xc3f800df}},	//   _আহবা, _aegv, _тэмы_, ילנש, 
   {{0x2d98003a,0xcce44fde,0x00000000,0x00000000}},	//   _utre_, _وسري, --, --, 
   {{0x78a8067c,0x1cd8025c,0x14c40490,0xa81421fa}},	//   _cegv, _འཁར_, _वागण, здиш, 
   {{0x0709dc45,0xc17006a9,0x78a8005f,0x00000000}},	//   ахни_, וחה_, _degv, --, 
   {{0x2d853190,0x661c2b96,0xcb680120,0xb3d00154}},	//   _hime_, ørko, _тазе_, িবাজ, 
   {{0x2d8437be,0x3cfc0490,0xd45c0092,0xa6ac00cc}},	//   _kime_, ळाचे_, _ማስፈፀ, _খাদট, 
   {{0x691c00e8,0x2720067c,0x2d8401ef,0x00000000}},	//   _céet, _mòni_, _jime_, --, 
   {{0x691c1bce,0x1cd8031c,0x7a400140,0x2d846bfc}},	//   _déet, _འཁལ_, pãtô, _mime_, 
   {{0x7c2c0ab7,0x5f94013e,0x78a801f5,0x2d84123b}},	//   _ücre, ҷиат, _zegv, _lime_, 
   {{0x3f8823e0,0x691c1bce,0x3f80009b,0x2d84035b}},	//   _sucu_, _féet, _riju_, _oime_, 
   {{0x2d84007d,0xbdf8034c,0x5f940124,0x3f880311}},	//   _nime_, یرضا_, зиат, _pucu_, 
   {{0x691c04e6,0x24880042,0x00000000,0x00000000}},	// [35850] _hées, _igam_, --, --, 
   {{0x2d85dc46,0x26cddc47,0x88c00729,0x3f880481}},	//   _aime_, ngdo_, ্জিক, _vucu_, 
   {{0x0cd5dc48,0x2d85dc49,0xb70c0139,0x320c0108}},	//   ठभूम, _bime_, _ñäşm, ädyt_, 
   {{0x5c752fb1,0xd054013f,0x691dab98,0x6294033f}},	//   плет, neyɛ, _mées, lczo, 
   {{0x60cc314c,0x78a80660,0x691c0036,0xb4fc08a8}},	//   mgam, _regv, _lées, יפאי, 
   {{0x60cddc4a,0x2d85d43d,0x629406d8,0x2b5c0200}},	//   lgam, _eime_, nczo, govc_, 
   {{0x78a80c6a,0x661c00ed,0x8a0000a7,0x60cc2f63}},	//   _pegv, ørkl, езще, ogam, 
   {{0x2489dc4b,0xbf980b21,0xdde4013d,0x2d84ae85}},	//   _ngam_, _trêd, _мәҗү, _gime_, 
   {{0x78a803a1,0xccf00375,0xdce801ab,0xdca40116}},	//   _vegv, _אכן_, _gheā, _маңи, 
   {{0x2489dc4c,0x78a81a7c,0x691c0de2,0xf1c00118}},	//   _agam_, _wegv, _séet, íšku_, 
   {{0x60cc5bae,0x2d8418f7,0x691c002e,0x00000000}},	//   kgam, _yime_, _péet, --, 
   {{0x691da607,0x60cc02d3,0x6294033f,0x6130007c}},	//   _dées, jgam, eczo, _hålf, 
   {{0x60cddc4d,0x93c40311,0x4ad00b9a,0x00000000}},	//   dgam, _orăş, _सामव, --, 
   {{0x2488022e,0x691c0de2,0x60cddc4e,0xf7700133}},	//   _egam_, _wéet, egam, _کاڵ_, 
   {{0xc69004ac,0x613048bb,0xdb0801bf,0x248c0010}},	//   _טאג_, _målf, _tveæ, žema_, 
   {{0x60cddc4f,0x661ddc50,0x14c40490,0x394c0af9}},	//   ggam, ärke, _वाटण, _jjgs_, 
   {{0x2d85dc51,0x27200ba1,0xdcf40139,0xc950011a}},	// [35860] _rime_, _sòni_, _suzğ, גמן_, 
   {{0x2d85dc52,0x60cddc53,0x691c00e8,0x00000000}},	//   _sime_, agam, _jéer, --, 
   {{0x0d8403b7,0x83180a1e,0x2d85dc54,0x60cddc55}},	//   член, _הויז, _pime_, bgam, 
   {{0x60cca8cf,0x691c0de2,0x0b88bde1,0x2d840240}},	//   cgam, _léer, бски_, _qime_, 
   {{0x613005ac,0x26cc0477,0x7c8000d8,0x6d480241}},	//   _bålf, ygdo_, нуше, _ìdam, 
   {{0xf765dc56,0xddc80276,0x691c07ea,0x37c00154}},	//   _سا_, _înşe, _néer, ্বার, 
   {{0x2d85dc57,0x4ad00490,0xa9782f6a,0x00000000}},	//   _time_, _साठव, ойку_, --, 
   {{0x691c004a,0x62941afd,0x2d843e79,0x1ce40327}},	//   _rées, zczo, _uime_, _ཨིག_, 
   {{0x77940724,0x0c2406a6,0xeb5400db,0x6ed00210}},	//   пкыр_, _эман, _قىرگ, दलपु, 
   {{0x60cddc58,0x1cd8031c,0xb9e40137,0x3f8c0124}},	//   zgam, _འཁོ_, تتۇۇ, ígui_, 
   {{0xf76c3cd9,0x60cddc59,0xba980375,0xca780023}},	//   داي_, ygam, _הסבי, _ቤትኩም_, 
   {{0xe7380032,0x69d80112,0x62940210,0x00000000}},	//   сеү_, mtve, wczo, --, 
   {{0xf76ccf73,0x69d81072,0x166c02d3,0x691ddc5a}},	//   ضای_, ltve, _ባዕልኻ_, _wées, 
   {{0x69d80373,0xc34802e8,0x00000000,0x00000000}},	//   otve, сяме_, --, --, 
   {{0x69d803bd,0x60cddc5b,0x14c40490,0x6294033f}},	//   ntve, tgam, _वाचण, rczo, 
   {{0x60cddc5c,0x248801ab,0xc05802dd,0x2d580139}},	//   ugam, _ugam_, біз_, _yüeş_, 
   {{0x691c00e8,0x9f9400a2,0x69d812ce,0x250800f2}},	// [35870] _yéer, _müçe_, htve, _هرکی_, 
   {{0x1ce403bd,0x69d9dc5d,0x63a8005f,0xb1c80014}},	//   _ཨིང_, ktve, ģend, تِہن_, 
   {{0x2d940220,0x60cc0208,0x6588013a,0x00000000}},	//   еріс, pgam, _těhu, --, 
   {{0xbf980129,0x9f940139,0x00000000,0x00000000}},	//   _crêc, _nüçe_, --, --, 
   {{0x29fc00df,0x2ca00428,0x7204036b,0x2d580276}},	//   _aĉa_, ñida_, _قویم, чиць_, 
   {{0x59040003,0x93c40356,0xa3d4000d,0x00000000}},	//   _མོངས_, _urăş, _हमन_, --, 
   {{0xeab1dc5e,0x69d811c0,0x691c1bce,0x00000000}},	//   اعه_, gtve, _réer, --, 
   {{0x691c0de2,0x3eb001a4,0x00000000,0x00000000}},	//   _séer, laxt_, --, --, 
   {{0xf1b8038f,0x69dd52bb,0xf09400c8,0x69d80549}},	//   ġġi_, _ären, ענץ_, atve, 
   {{0x7d19b14f,0x6e040014,0xac7402dd,0x0b1800ec}},	//   _hous, _تِہن, _ساقش, _ورلڊ_, 
   {{0x7d19dc5f,0x69d801a4,0x4ad00027,0x6130007c}},	//   _kous, ctve, _सातव, _kåld, 
   {{0x7d19dc60,0xd469dc61,0x691c1bce,0x4a5808c3}},	//   _jous, жиме_, _wéer, _ודעו, 
   {{0x7d19dc62,0x6130050a,0x691c1574,0x25a000d7}},	//   _mous, _måld, _téer, _čile_, 
   {{0x7d19dc63,0x395ddc64,0x6b600432,0xd629dc65}},	//   _lous, lous_, _išgä, _моле_, 
   {{0x7bc9dc66,0xae9401e1,0x00000000,0x00000000}},	//   hugu, _mẹta, --, --, 
   {{0x7d19dc67,0xc0e00021,0x395ddc68,0x9554007b}},	//   _nous, коск, nous_, _تختا, 
   {{0x7bc80551,0xbfc80075,0x691c007f,0x2f0401d5}},	// [35880] jugu, قالە_, _méep, нжаҳ, 
   {{0x7bc9dc69,0x7d180165,0x691c0de2,0x09bc015b}},	//   dugu, _aous, _léep, _আহসা, 
   {{0x7d19dc6a,0x2d9c069c,0x395ddc6b,0xbf986c80}},	//   _bous, ëve_, kous_, _prêc, 
   {{0x7d19dc6c,0x395c0228,0x53d07f1a,0x2720067c}},	//   _cous, jous_, _तमाश, _hònt_, 
   {{0x7d19dc6d,0x395c07ab,0x27200100,0x3160009d}},	//   _dous, dous_, _kònt_, moiz_, 
   {{0x69d9dc6e,0xfd6400e4,0x3160030a,0x395ddc6f}},	//   ttve, _kirỹ, loiz_, eous_, 
   {{0x7d19dc70,0x7bc800da,0xfc3c00bc,0x395c04e6}},	//   _fous, augu, _žít_, fous_, 
   {{0x69d9dc71,0x7bc9a42c,0x6f1ddc72,0x7d19dc73}},	//   rtve, bugu, _horc, _gous, 
   {{0x6d41dc74,0x7bc9dc75,0x6f1ddc76,0x00000000}},	//   _imma, cugu, _korc, --, 
   {{0x7d195033,0x69d9dc77,0x6f1c0455,0x5374001f}},	//   _zous, ptve, _jorc, _በቅዱስ_, 
   {{0x7d19dc78,0x395ddc79,0x6f1ddc7a,0x613001e6}},	//   _yous, bous_, _morc, _håle, 
   {{0x6f1ddc7b,0x6b899ab7,0xc7a4fac2,0xae940241}},	//   _lorc, _hidg, _жидк, _kẹsa, 
   {{0x248c05ce,0x6b88014b,0x61301445,0x1af00154}},	//   žemo_, _kidg, _jåle, চারে_, 
   {{0x6f1ddc7c,0x2ef80077,0x6b894091,0xae940248}},	//   _norc, _narf_, _jidg, _mẹsa, 
   {{0x6b89dc7d,0x6d41dc7e,0x7bc9dc7f,0xe5e802f6}},	//   _midg, _omma, zugu, ömää, 
   {{0x6d40009a,0x6b8801f5,0x7bc9dc80,0x00000000}},	//   _nmma, _lidg, yugu, --, 
   {{0x7d19dc81,0x6f1ddc82,0x93f0013f,0x2720068c}},	// [35890] _rous, _borc, _beyε_, _fònt_, 
   {{0x6d41dc83,0x6f1ddc84,0x7bc9dc85,0x7d1937f5}},	//   _amma, _corc, vugu, _sous, 
   {{0x7d19dc86,0x6f1ddc87,0x2ef80639,0x63ac05b8}},	//   _pous, _dorc, _darf_, _hwan, 
   {{0x7bc9dc88,0x61300b1a,0xd1e40023,0xa1580107}},	//   tugu, _båle, ዝብቲ_, _хаму_, 
   {{0x6130049f,0x6b89dc89,0x6f1ddc8a,0x63ac0184}},	//   _våld, _bidg, _forc, _jwan, 
   {{0x7bc95ebb,0x6f1c00a9,0x7d19dc8b,0x2129dc8c}},	//   rugu, _gorc, _wous, lkah_, 
   {{0x7d1847a0,0x395ddc8d,0x7bc9dc8e,0x1af0009e}},	//   _tous, tous_, sugu, চালে_, 
   {{0x2129dc8f,0x63ada740,0x7bc9dc90,0x6f1c0165}},	//   nkah_, _owan, pugu, _zorc, 
   {{0x6b89dc91,0x7bc8753a,0x63addc92,0x212805b1}},	//   _fidg, qugu, _nwan, ikah_, 
   {{0x395ddc93,0x21291eec,0x6b75dc94,0x657c0076}},	//   sous_, hkah_, _алуу, emsh, 
   {{0x63addc95,0x395ddc96,0x6130383d,0x81e40154}},	//   _awan, pous_, _målb, পিড_, 
   {{0x63addc97,0x2720067c,0x661c11ab,0x21280427}},	//   _bwan, _bòns_, ärka, jkah_, 
   {{0x7825c06d,0x212805b1,0x2720180f,0x00000000}},	//   _تعال, dkah_, _pònt_, --, 
   {{0x63addc98,0x657c5cdc,0xae9401e1,0x6728007c}},	//   _dwan, amsh, _lẹra, ckdj, 
   {{0x63addc99,0x21285101,0xfd6401e1,0x6f1c0077}},	//   _ewan, fkah_, _dirẹ, _rorc, 
   {{0x6f1ddc9a,0x8fd046e8,0x63ac043b,0x2ef813f8}},	//   _sorc, ләгә, _fwan, _sarf_, 
   {{0x6f1ddc9b,0x63addc9c,0x613000cc,0x3160fbff}},	// [358a0] _porc, _gwan, _bålb, roiz_, 
   {{0xd1dc02d3,0x2128011f,0x6f1c014f,0x613003cd}},	//   _ንደቂ_, akah_, _qorc, _råle, 
   {{0x63addc9d,0x61315b21,0xfbcc73c5,0xd184170a}},	//   _zwan, _såle, ەتى_, _плой, 
   {{0x8fa5dc9e,0x6f1d8e12,0x0b887b00,0x823400aa}},	//   _паме, _worc, пски_, _سرپا, 
   {{0x6b89dc9f,0xead4a3ea,0xcb68aa53,0x2ef80003}},	//   _pidg, воль, паде_, _tarf_, 
   {{0x6130119a,0x6f1c04cc,0x6d400175,0x657c01d5}},	//   _våle, _uorc, _wmma, zmsh, 
   {{0x6b89dca0,0xae940ca8,0x657c00ad,0x02d001f9}},	//   _vidg, _fẹra, ymsh, _तासभ, 
   {{0x6d41dca1,0x613008d7,0x69dc01b8,0x6b89dca2}},	//   _umma, _tåle, _ärem, _widg, 
   {{0x0ba80220,0x6b880327,0x082868eb,0x00000000}},	//   _ءارى_, _tidg, яцки_, --, 
   {{0x63addca3,0x6b8802d0,0x00000000,0x00000000}},	//   _rwan, _uidg, --, --, 
   {{0x63ac7483,0x35b005f5,0x2720180f,0xfaa00fc0}},	//   _swan, лбэр, _sòns_, _сахо, 
   {{0x1cdc0ed9,0x63addca4,0xa8f44142,0x613001e3}},	//   ྡུར_, _pwan, _आसिफ_, _målc, 
   {{0x67d5646b,0x212809a8,0x657c1ef0,0x69e00010}},	//   _ролу, vkah_, rmsh, žveč, 
   {{0x63ac02ea,0x764801d3,0x87b800fb,0xe2c800db}},	//   _vwan, ályá, _дуҫт_, بوسو_, 
   {{0x31c4db74,0x2129dca5,0x63ac0e14,0xf4b000fe}},	//   лств, tkah_, _wwan, _কাৰব, 
   {{0x63addca6,0x212872e2,0xc05802dd,0x613001bf}},	//   _twan, ukah_, піз_, _sålb, 
   {{0x212802b4,0x63addca7,0xd2f4168d,0xa3e5dca8}},	// [358b0] rkah_, _uwan, رکیا_, _नहि_, 
   {{0x21290147,0x1cd8025c,0xdea00af6,0xafc41066}},	//   skah_, _འཁང_, شیری, ايلى, 
   {{0x21280a2e,0x623400a8,0xbf98017a,0xae940241}},	//   pkah_, _рену, _grên, _pẹra, 
   {{0xa3e405f9,0xbec00171,0x00000000,0x00000000}},	//   _नहा_, _žīdi, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3f8c0115,0x1ae400d8,0x00000000,0x00000000}},	//   ŭgus_, токм, --, --, 
   {{0x6a940212,0x89d40345,0xceb40166,0xae9401e1}},	//   уріє, نوور_, _шәт_, _tẹra, 
   {{0xf1b40a7c,0x00000000,0x00000000,0x00000000}},	//   אסק_, --, --, --, 
   {{0x661c0267,0x76d4013e,0xfa880150,0x00000000}},	//   ärkn, нунӣ_, _есей_, --, 
   {{0x6d580022,0x00000000,0x00000000,0x00000000}},	//   ĩvae, --, --, --, 
   {{0x5bd002c3,0xc7a400d1,0x00000000,0x00000000}},	//   _समुव, ىگۈل_, --, --, 
   {{0xe89402d5,0x98140214,0x00000000,0x00000000}},	//   _баць, _لبتا, --, --, 
   {{0x1ce40ad3,0xa3cc07f7,0xfbbc03d4,0xe61404b3}},	//   _ཨིན_, शूल_, _ইহঁত, _ەكىگ, 
   {{0x03a0169c,0x79880223,0x461000db,0x00000000}},	//   риро, _higw, _چوور, --, 
   {{0x4611dca9,0x798819e1,0xf1ac0073,0x00000000}},	//   _نوور, _kigw, टींन, --, 
   {{0x1cdc1b4b,0x7bd8013c,0x79880327,0xd1749490}},	//   ྡུས_, _oquu, _jigw, тыгы, 
   {{0x7989dcaa,0x63b805d1,0x661c0162,0x00000000}},	// [358c0] _migw, ğanü, ørkv, --, 
   {{0x7989dcab,0xbf980051,0x8eb000cc,0x00000000}},	//   _ligw, _trên, _চাহগ, --, 
   {{0x7bd9dcac,0x3f8c0ad9,0x1dc80d0d,0xdcf40064}},	//   _aquu, ígur_, ांगत, _juzė, 
   {{0xcca001b9,0x79880142,0x0d200137,0x0c247e3a}},	//   рҳақ, _nigw, шүбү, кмен, 
   {{0x9d580107,0x00000000,0x00000000,0x00000000}},	//   хӯрӣ_, --, --, --, 
   {{0xbea03485,0x3ea00166,0x69dc007c,0xc43805d0}},	//   _варк, _вирг, _ärek, ותני, 
   {{0x7989dcad,0x7bd9dcae,0x61315d33,0x6a48013f}},	//   _bigw, _equu, _håla, rכfo, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x79880cfd,0x8c640cd6,0x391000ee,0xc6a401d5}},	//   _digw, _شطرن, рмыр, крни, 
   {{0x61311c32,0x99640228,0x661c3453,0x60c800de}},	//   _måla, ктөл, ärko, _ķemm, 
   {{0x79880076,0x2d8c01ed,0x00000000,0x00000000}},	//   _figw, _édes_, --, --, 
   {{0xc4bc11a0,0x4ad01524,0x6305dcaf,0x6ab803cd}},	//   ्लेख, _साँव, گوسل, lavf, 
   {{0x38c804d3,0x61304cab,0x00000000,0x00000000}},	//   _زانی_, _nåla, --, --, 
   {{0x6ab8083a,0x2578e1b9,0x7989dcb0,0xe2f40022}},	//   navf, déle_, _zigw, ызгь, 
   {{0x7988d489,0x00000000,0x00000000,0x00000000}},	//   _yigw, --, --, --, 
   {{0xbf980998,0x30a5dcb1,0x79880564,0x257801ed}},	//   _frêl, ирув, _xigw, féle_, 
   {{0x2579cc0d,0xa075dcb2,0xbf9806af,0x6ab80165}},	// [358d0] géle_, угач, _grêl, kavf, 
   {{0xbe8403e6,0xa2f402bf,0x985400ac,0x61f802d5}},	//   نجاو, _споч, _ləğv_, _зноў_, 
   {{0x63bc017a,0x86280023,0xddd40171,0x00000000}},	//   lssn, _ስዉኣት, _izzū, --, 
   {{0xf6500375,0xcac803d4,0x63bc01c7,0x00000000}},	//   בצע_, ল্মফ, ossn, --, 
   {{0x7989dcb3,0xc0580212,0x63bc01e3,0xfbd00066}},	//   _rigw, _цін_, nssn, شتش_, 
   {{0x7989dcb4,0xab640953,0x63bc017a,0x6b747c3f}},	//   _sigw, авіл, issn, алчу, 
   {{0xee840c98,0xd94431fd,0x6d580129,0x798815c0}},	//   _выто, леки, évac, _pigw, 
   {{0x63bc03ac,0x00000000,0x00000000,0x00000000}},	//   kssn, --, --, --, 
   {{0x7988949e,0x090074e7,0x4ad80451,0x00000000}},	//   _vigw, спын, _ڳالھ_, --, 
   {{0x63bc01bf,0xac58024c,0x00000000,0x00000000}},	//   dssn, _рауф_, --, --, 
   {{0x63bcac66,0x7989dcb5,0xd54839c6,0x9584013e}},	//   essn, _tigw, епне_, ллое, 
   {{0x53a5dcb6,0x5f041b90,0x00000000,0x00000000}},	//   ламб, _होस्_, --, --, 
   {{0xd04401e4,0xbf980129,0xa7b80137,0x63bc007c}},	//   _sakɾ, _brêm, _алчу_, gssn, 
   {{0xcc3800c8,0xa3d4007d,0xbf980129,0xa3e42e05}},	//   געשט, _हमर_, _crêm, _नहर_, 
   {{0x61300fac,0x7bc80112,0x55e4004e,0x00000000}},	//   _såla, hrgu, _сойб, --, 
   {{0x61305b47,0x02840024,0x966400fb,0x00000000}},	//   _påla, уйск_, _икһе, --, 
   {{0x4f09dcb7,0xb4d029da,0x7bc801bf,0xb9c80092}},	// [358e0] ннан_, शली_, jrgu, _ደጅ_, 
   {{0xe8d02db6,0xbf9806ed,0x1ea87427,0x613003cd}},	//   _सञ्च, _grêm, نامي_, _våla, 
   {{0x7bc91746,0x00000000,0x00000000,0x00000000}},	//   ergu, --, --, --, 
   {{0x69dc01b8,0x613001e6,0xe7f8012c,0x1ae000eb}},	//   _ärei, _tåla, ्टमा_, _গোলে_, 
   {{0xaab4109a,0x6ab80efa,0x2f8801ee,0x601401ee}},	//   айлі, tavf, _аҙан_, _кєрє, 
   {{0x81e400bd,0x8d9401d9,0xa8243fe6,0x00000000}},	//   পির_, _مٔست, یکشن, --, 
   {{0x8294025f,0x88d40882,0x613001e6,0x6ab80efa}},	//   נדקס_, kṛty, _måln, ravf, 
   {{0x63bddcb8,0x604002e3,0x6ab811ad,0x248c2438}},	//   yssn, ịmen, savf, žemi_, 
   {{0x4c34009d,0x00000000,0x00000000,0x00000000}},	//   _сэвт, --, --, --, 
   {{0x26d9dcb9,0x28a4503c,0x00000000,0x00000000}},	//   üro_, _ग्रि, --, --, 
   {{0x49c80a16,0xca54026a,0x08c40276,0x46680137}},	//   _член_, _стањ, _ббен, эрим_, 
   {{0x9f4800fc,0xd5c40b7c,0x00000000,0x00000000}},	//   hvað_, _विरज, --, --, 
   {{0xbf980261,0x69c404a9,0x00000000,0x00000000}},	//   _prêm, _сөһб, --, --, 
   {{0x661c0158,0xc6a401d5,0x63bc9442,0x787001f7}},	//   ørks, _ёрли, rssn, _اُها, 
   {{0x2d9c0cfc,0x5bd02c2e,0x2aec00bc,0x00000000}},	//   ível_, _सम्व, _आउनु_, --, 
   {{0x4084072c,0x00000000,0x00000000,0x00000000}},	//   гузб, --, --, --, 
   {{0xbf9800d8,0x3ec80640,0x9ed823b8,0xdfd400c0}},	// [358f0] _trêm, ећем_, кмат_, розы, 
   {{0x9f481427,0x00000000,0x00000000,0x00000000}},	//   gvað_, --, --, --, 
   {{0x1cd80156,0x9f480165,0x02484fca,0x335800db}},	//   _འཁད_, uvañ_, _سجدو_, _сүрө_, 
   {{0xdb180086,0xdfd4b7e2,0x00000000,0x00000000}},	//   juwò, _комы, --, --, 
   {{0x61301061,0xc100008e,0x00000000,0x00000000}},	//   _hålo, _күңл, --, --, 
   {{0x9f340046,0x6e940c69,0x6130005c,0x7db5db60}},	//   _тегі, _гиру, _kålo, _مصرا, 
   {{0xec6819b8,0x00000000,0x00000000,0x00000000}},	//   крәк_, --, --, --, 
   {{0x61300b1a,0xaa080ee8,0x44280200,0x57e801d5}},	//   _målo, ازول_, kyc_, вдим_, 
   {{0x691c00e8,0x00000000,0x00000000,0x00000000}},	//   _jéey, --, --, --, 
   {{0x3cfc0b89,0x57455a2a,0xeaf85024,0x98b400fd}},	//   _hauv_, рноб, _مرمت_, ıgın_, 
   {{0x3cfc01d4,0x49d8014d,0x2b540066,0x00000000}},	//   _kauv_, _لانگ_, _دیود_, --, 
   {{0xe9d012e3,0xb4d00b98,0x5434009d,0x00000000}},	//   _رغم_, शले_, ахгу, --, 
   {{0x1cd849a6,0x3cfc0211,0x78b80129,0x661c2147}},	//   _འཁན_, _mauv_, mauv, ørkr, 
   {{0x3cfddcba,0x78b80b23,0x88380375,0xd1c841e5}},	//   _lauv_, lauv, _בתנו, клге_, 
   {{0x28dc1408,0x518400ae,0x00000000,0x00000000}},	//   _यामि, لشرق, --, --, 
   {{0x78b80cfe,0x2d9c00e5,0x68480171,0x44288767}},	//   nauv, ívem_, bīdī, byc_, 
   {{0x69dd81d7,0xcf44845c,0xdfa400c6,0x845800db}},	// [35900] _ärev, анай, محلي, _үрөт_, 
   {{0x61300628,0x75240399,0x691c0de2,0x78b9ccb9}},	//   _håll, _hoiz, _déey, hauv, 
   {{0x78b988f1,0x752404ce,0x2579dcbb,0x613001e3}},	//   kauv, _koiz, léla_, _kåll, 
   {{0x691c00e8,0x752401b9,0x4d640006,0x4d4800a7}},	//   _féey, _joiz, шкев, ъпен_, 
   {{0x3cfc0218,0x7525dcbc,0x613048bb,0x78b9dcbd}},	//   _dauv_, _moiz, _måll, dauv, 
   {{0x7525dcbe,0xf76400c6,0x61f80432,0x661c01f4}},	//   _loiz, _ذا_, _çalý, ärkk, 
   {{0xd90c77c2,0xdb180086,0x2fc03c75,0x9d5003e6}},	//   کین_, tuwò, lsig_, _کۆنت, 
   {{0x2d980483,0x7525dcbf,0x257800d2,0x691c0de2}},	//   _iure_, _noiz, kéla_, _jéex, 
   {{0x2d99dcc0,0x2fc1dcc1,0xb59c0150,0x00000000}},	//   _hure_, nsig_, _ﺍﻟﻨﺘ_, --, 
   {{0xcb0816cb,0x3cfc01d4,0x8b64eb23,0x2fc1dcc2}},	//   _جيئن_, _zauv_, _ئارم, isig_, 
   {{0x2d99dcc3,0x78b9dcc4,0x3cfc0211,0xdce800df}},	//   _jure_, bauv, _yauv_, _skeĉ, 
   {{0x2d99dcc5,0x3cfc0211,0xe7380184,0x691c00e8}},	//   _mure_, _xauv_, теү_, _néex, 
   {{0x2d99dcc6,0x00000000,0x00000000,0x00000000}},	//   _lure_, --, --, --, 
   {{0x6130168c,0x2d99dcc7,0x00000000,0x00000000}},	//   _pålo, _oure_, --, --, 
   {{0x752407d6,0x442833dd,0x2d980115,0x2fc1141f}},	//   _foiz, syc_, _nure_, esig_, 
   {{0x752405f5,0x691c0de2,0x25780c6a,0x684800de}},	//   _goiz, _péey, béla_, pīdī, 
   {{0x2d99dcc8,0x656ddcc9,0x3cfc01d4,0x2fc1dcca}},	// [35910] _aure_, _ikah, _rauv_, gsig_, 
   {{0x2d99dccb,0x3cfc01d4,0x7c2803cd,0xbea401ec}},	//   _bure_, _sauv_, vygr, ршай, 
   {{0x78b9dccc,0x3cfc0457,0x691c0de2,0x2d99dccd}},	//   yauv, _pauv_, _féex, _cure_, 
   {{0x7c2803ac,0x3cfc0457,0x2d8c011c,0xdce80327}},	//   tygr, _qauv_, _èdel_, _ikeċ, 
   {{0x2d99dcce,0x3cfc0211,0x90e407d6,0x656c01c8}},	//   _eure_, _vauv_, _اسپن, _mkah, 
   {{0x3da403b7,0x1cdc0135,0x6131dccf,0x3cfc01bf}},	//   _враб, ྡུང_, _målm, _wauv_, 
   {{0x2d980323,0x656ddcd0,0x78b9dcd1,0x3cfc01d4}},	//   _gure_, _okah, tauv, _tauv_, 
   {{0xe9a80597,0x656ddcd2,0x78b80a73,0xdce8031c}},	//   جدون_, _nkah, uauv, _mkeċ, 
   {{0xb8fd0256,0x2d980323,0x26dc017a,0x9b9401b9}},	//   _ता_, _zure_, _bcvo_, _طلات, 
   {{0x656ddcd3,0x78b9dcd4,0x2d980472,0x613001e3}},	//   _akah, sauv, _yure_, _såll, 
   {{0x2d9802c4,0x7525dcd5,0x2579d343,0x78b806af}},	//   _xure_, _poiz, wéla_, pauv, 
   {{0x2fc00cfd,0x25e800c5,0x257854ba,0x37140014}},	//   ysig_, _जहरी_, téla_, ارکھ_, 
   {{0x75250080,0x2378001f,0x691c06af,0x61300267}},	//   _voiz, _በህዝብ_, _réex, _våll, 
   {{0x656ddcd6,0x60dc03ac,0x3258001f,0x691c002e}},	//   _ekah, _acsm, _የስልጣ, _séex, 
   {{0x656c0418,0x4341dcd7,0x75240109,0x257800e8}},	//   _fkah, черв, _toiz, séla_, 
   {{0x2fc1dcd8,0x3f4c005f,0x2d99727e,0x0dc801e0}},	//   tsig_, kļus_, _rure_, ҫлай_, 
   {{0x4e9474bb,0x2d99dcd9,0xb4b40c70,0x2fc09b41}},	// [35920] مشار, _sure_, टरी_, usig_, 
   {{0x60dc01fa,0x2fc1dcda,0x2d99dcdb,0x69dc143a}},	//   _ecsm, rsig_, _pure_, _åreg, 
   {{0x2fc1dcdc,0xea0001fb,0xdb18000f,0x2d980477}},	//   ssig_, _đắk_, kswâ, _qure_, 
   {{0x2d99dcdd,0x661c00c5,0x4c841468,0x2fc0017a}},	//   _vure_, ärki, блев, psig_, 
   {{0xdb18002d,0xac196676,0x3f4c00e2,0x92b800fe}},	//   dswâ, ролу_, gļus_, ঙলী_, 
   {{0x2d99dcde,0xa3cc0034,0xa51400dc,0x00000000}},	//   _ture_, शूट_, _तच्च_, --, 
   {{0x2d980e14,0x79a002d5,0x04a0002b,0xc33000d9}},	//   _uure_, прые, _tāḍi, הוג_, 
   {{0xdb4c0e53,0xfce05192,0x29dc0010,0x3f4c00ef}},	//   _یێن_, _носо, jšaš_, bļus_, 
   {{0x47880137,0x81e40154,0xec180166,0x49c000e5}},	//   лсом_, পিএ_, _өеңә_, _کےعل, 
   {{0xfe6c00dd,0xcae0004b,0x656c062c,0x997400b8}},	//   _آگے_, _رښتی, _skah, _kāś_, 
   {{0x9a8401af,0x7a6400f3,0x00000000,0x00000000}},	//   _дуїл, _лифг_, --, --, 
   {{0x18180214,0x8edc0154,0x00000000,0x00000000}},	//   _چروک_, ড়িগ, --, --, 
   {{0x7d78d16f,0xdb08008c,0x4875dcdf,0x59640014}},	//   טרטג, _kveð, _اداس, _بدلٲ, 
   {{0xb9f0044e,0x81f00003,0x29040037,0xa19400d8}},	//   _ዞባ_, _བགྱི_, ldma_, жавч, 
   {{0x4174314e,0x69dc08fb,0xb2840137,0x62340108}},	//   مارس, _åred, зытк, цеву, 
   {{0x2905dce0,0x613008cb,0x6d59dce1,0x656c770e}},	//   ndma_, _tålm, éval, _ukah, 
   {{0x68e4002e,0x6130007c,0xaac80da5,0xdce80171}},	// [35930] _ñidu, _hålk, रणाक, _lieģ, 
   {{0xdce80135,0x81400050,0xff50007b,0x41e40024}},	//   _tkeċ, _کۆرن, أخر_, _ліма, 
   {{0x1cd80139,0x00000000,0x00000000,0x00000000}},	//   иджы_, --, --, --, 
   {{0x613001e3,0x5c140022,0x00000000,0x00000000}},	//   _målk, жьку, --, --, 
   {{0xb6040745,0xff0400d1,0xed580212,0x2904025c}},	//   _koší, _лявн, щої_, ddma_, 
   {{0x20080276,0x00000000,0x00000000,0x00000000}},	//   mvai_, --, --, --, 
   {{0x81e4045e,0xf2d4008f,0x20083e9d,0x21380240}},	//   পিক_, לעס_, lvai_, _klsh_, 
   {{0x17c80364,0xd90c7ba2,0x673800ef,0x00000000}},	//   агии_, کیچ_, _alvj, --, 
   {{0xdb181257,0x00000000,0x00000000,0x00000000}},	//   rswâ, --, --, --, 
   {{0x61300158,0x2009dce2,0xaae01d03,0x2c000116}},	//   _bålk, ivai_, _नायक, _чүшм, 
   {{0xbf98000f,0xab8402d5,0x12e000d1,0x00000000}},	//   _grêv, _хутк, ﺍﺷﻼﺭ, --, 
   {{0x2c20015b,0x2138062c,0xdb18002f,0x00000000}},	//   _মেয়ে_, _nlsh_, hrwü, --, 
   {{0x37a80c9e,0x29dc00f3,0xaae0023e,0x04400d1d}},	//   _стен_, ršaš_, _नामक, деян, 
   {{0x257800d2,0xcb98008f,0xf8b401e0,0xa7640150}},	//   bélo_, יסשט, _төҫ_, _екід, 
   {{0xcb110b71,0xb9e00020,0x320c012c,0x00000000}},	//   ולם_, _የኔ_, ídy_, --, 
   {{0xf77002f2,0x00000000,0x00000000,0x00000000}},	//   _باڵ_, --, --, --, 
   {{0x25a17a1c,0x6d58004e,0x6130005c,0x00000000}},	// [35940] _čili_, évam, _målh, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2009dce3,0xc0c4001f,0x551c0456,0x00000000}},	//   avai_, ችሉም_, _बचाए_, --, 
   {{0xb60400d0,0xdb0802d2,0x00000000,0x00000000}},	//   _zoší, _sveð, --, --, 
   {{0x7c80167f,0x8fa40139,0x8b6433d2,0x0ee006e3}},	//   муше, _фаге, ياتم, _पापड, 
   {{0xdff8010f,0x997400cd,0x00000000,0x00000000}},	//   _פּרש, _tāś_, --, --, 
   {{0x613001bf,0x00000000,0x00000000,0x00000000}},	//   _bålh, --, --, --, 
   {{0x63a8084c,0x25780165,0xf984009a,0x660400ef}},	//   ţeni, vélo_, ينوي_, _ņiko, 
   {{0x29058931,0x00000000,0x00000000,0x00000000}},	//   rdma_, --, --, --, 
   {{0xc8c8314c,0xbf9839b4,0xad4400db,0x25780098}},	//   _چوان_, _trêv, _بۉچۉ, télo_, 
   {{0xc8c800b2,0xff7800c8,0x7e980375,0x651887f4}},	//   _نوان_, שטימ, יסיו, مقدس_, 
   {{0x69d9dce4,0x99640220,0x20080006,0x38c8030f}},	//   muve, _етіл, yvai_, _ناهی_, 
   {{0x69d9dce5,0x69dc0158,0x21380076,0x2c5c012d}},	//   luve, _åreb, _rlsh_, bądź_, 
   {{0x4910012c,0x2138058a,0xb9d40023,0x69d80175}},	//   थाको_, _slsh_, _ሸቶ_, ouve, 
   {{0x69d82b1d,0x05743738,0xf5b02361,0x06657860}},	//   nuve, _واعد, _قصيد, _باشپ, 
   {{0x661d12c5,0xe2983008,0x00000000,0x00000000}},	//   ärku, раң_, --, --, 
   {{0x442c04ce,0xb4440137,0x25040055,0x69d9dce6}},	// [35950] _æg_, _жээк, _jeṭṭ, huve, 
   {{0x613039c2,0x99500010,0x2009dce7,0x33f4009f}},	//   _måli, _mšš_, rvai_, _آسيس, 
   {{0x69d9dce8,0x07f80156,0xbf998d0c,0x20080024}},	//   juve, _དགའཝ_, _arêt, svai_, 
   {{0x69d9dce9,0x63800162,0xcfe400fe,0x5f941188}},	//   duve, _fáný, নিজন, _нимт, 
   {{0xbf98004a,0x00000000,0x00000000,0x00000000}},	//   _crêt, --, --, --, 
   {{0x69d818f7,0x80a400bc,0x00000000,0x00000000}},	//   fuve, टुरे, --, --, 
   {{0x69d9dcea,0x1cdc031c,0x28dc0073,0xadbc0153}},	//   guve, ྡུད_, _याशि, _васi, 
   {{0x2b4ddceb,0x7c84010b,0x39481497,0x58240733}},	//   _emdc_, _дузе, òcs_, змиб, 
   {{0x1bd409fe,0x0d280046,0x9d4400ee,0x77400014}},	//   _хозя, _اققۋ_, _деңд, ٘ێشم, 
   {{0x613004f3,0x69d83b6a,0xf8a800bc,0x6dbc00b8}},	//   _dåli, buve, _ट्रय, _ṅait, 
   {{0xb9e400d6,0x69d8054e,0x00000000,0x00000000}},	//   _фізи, cuve, --, --, 
   {{0xfbdc00cd,0x00000000,0x00000000,0x00000000}},	//   _नमाम, --, --, --, 
   {{0xc95006a9,0x88980375,0xf3840116,0x00000000}},	//   _אמא_, _הבני, мғим, --, 
   {{0x3f800208,0x00000000,0x00000000,0x00000000}},	//   _nhju_, --, --, --, 
   {{0xd25022d2,0x661ce489,0x6d59dcec,0x00000000}},	//   رنر_, ärkt, évak, --, 
   {{0x3f8000c5,0x61e001ab,0x00000000,0x00000000}},	//   _ahju_, àlla, --, --, 
   {{0x69d8002f,0x41240353,0xb35c0092,0x00000000}},	// [35960] zuve, чото_, ተማውን_, --, 
   {{0x3f800ffb,0x69d9dced,0xc4800166,0x00000000}},	//   _chju_, yuve, _ялык, --, 
   {{0x69d80005,0x2d9ddcee,0xdbd80166,0x00000000}},	//   xuve, êve_, _eçüg, --, 
   {{0xbf984aee,0x4c84c10f,0x3ce400e1,0x69d9a611}},	//   _prêt, плев, छ्ले_, vuve, 
   {{0x69d8003c,0x250400b8,0xdd8c00d1,0xa07401ec}},	//   wuve, _heṣṭ, شۈك_, _жырш, 
   {{0x69d9dcef,0xdb1800d2,0x00000000,0x00000000}},	//   tuve, tswá, --, --, 
   {{0xb92400b8,0xdce80135,0x25040055,0x00000000}},	//   _hotṛ_, _wieġ, _jeṣṭ, --, 
   {{0x7a50007b,0xf6e40327,0x4788010b,0x09bc00eb}},	//   عضوا, _འཁུང, әсим_, _ইমদা, 
   {{0x2d84023a,0x87042081,0x0b4400f3,0x00000000}},	//   _ihme_, пяне, _енан, --, 
   {{0xb8d056e9,0x200c9358,0xfaa008da,0xe14c0092}},	//   _ज्_, _šeik_, _зафо, _በወንጌ, 
   {{0x24f823b6,0xa4d40111,0x7ec401d3,0x2504002b}},	//   онны_, моні, lépí, _neṣṭ, 
   {{0xda645713,0x61300267,0xba340375,0x7a78010f}},	//   _غالي, _tåli, _מטבח_, _פראס, 
   {{0xb90401d9,0x00000000,0x00000000,0x00000000}},	//   _رٲوم_, --, --, --, 
   {{0x661c0624,0x00000000,0x00000000,0x00000000}},	//   ärks, --, --, --, 
   {{0x61302b27,0x250400cd,0x00000000,0x00000000}},	//   _målv, _ceṣṭ, --, --, 
   {{0x59dc0490,0xdce800e2,0x00000000,0x00000000}},	//   नंतर, _okeā, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [35970] --, --, --, --, 
   {{0x63addcf0,0xd24c066d,0x3ea405d5,0xe7d4095f}},	//   _itan, اچی_, ùnt_, _दिनप, 
   {{0xb8fc0003,0xdce8003d,0xbf980194,0xf1a4011b}},	//   _སྐ_, _jieħ, _prês, _прян, 
   {{0x63ac020b,0x2360004d,0x9e780240,0x00000000}},	//   _ktan, _hjhj_, _ክኢልና_, --, 
   {{0x69c877d4,0x6aa80175,0xcfec00b5,0x7ec400e5}},	//   _avde, _bfdf, xｘx_, gépí, 
   {{0x63ac05d9,0xaac40075,0xbf6401af,0x00000000}},	//   _mtan, ىتىن, _хњми, --, 
   {{0xaac52ede,0x63ac409c,0x6aa9dcf1,0x1988021b}},	//   رتون, _ltan, _dfdf, обки_, 
   {{0x69c9dcf2,0xf1c000bc,0x8bd400d1,0x00000000}},	//   _dvde, ýšit_, чмәс_, --, 
   {{0x63addcf3,0xe5200882,0x7b6439fb,0x69c803ee}},	//   _ntan, यानि_, _етже, _evde, 
   {{0x1cdc0327,0x0ccc0154,0xaa8400a2,0x00000000}},	//   ྡུམ_, রভৃত, _seýş, --, 
   {{0xead4030d,0x00000000,0x00000000,0x00000000}},	//   _чохь, --, --, --, 
   {{0xdce80135,0x69dc03cd,0x00000000,0x00000000}},	//   _dieħ, _årea, --, --, 
   {{0x394c0354,0x63ac0165,0x6d580022,0x661c007c}},	//   _imgs_, _ctan, évai, ärkr, 
   {{0x613048bb,0x00000000,0x00000000,0x00000000}},	//   _målu, --, --, --, 
   {{0x394c058a,0xb3780023,0xa81800db,0xfeac01e1}},	//   _kmgs_, _ራእይን_, _وتۇر_, _ẹ̀yá_, 
   {{0x9f580268,0xdb18002f,0x250400cd,0xc69000d9}},	//   _assà_, lswä, _veṣṭ, _באו_, 
   {{0xdb0800c7,0xc950011a,0x8fa40395,0x00000000}},	// [35980] _eteé, דמן_, фазе, --, 
   {{0xb8dc1b35,0x03d4008f,0xbf98017a,0x394c0327}},	//   _ཁབ_, _קוים_, _prêr, _lmgs_, 
   {{0x831800c8,0x1ea92812,0x6aa8000f,0xb35c001f}},	//   _וויז, سالي_, _rfdf, ተኛውን_, 
   {{0x8fa40262,0x7ec400e5,0x7bc400ef,0x00000000}},	//   _оаме, tépí, _ājur, --, 
   {{0x0b880a31,0x63ac01a9,0x4c140116,0x00000000}},	//   оски_, _xtan, بباس, --, 
   {{0x94fc031c,0xdb0800e4,0x2d9c0e33,0x00000000}},	//   _ཟིའི_, _yteé, íves_, --, 
   {{0xe5200882,0x550c0037,0x394c00ef,0x00000000}},	//   यामि_, ियाए_, _bmgs_, --, 
   {{0xdce80327,0xdd114c86,0x00000000,0x00000000}},	//   _rieħ, müşd, --, --, 
   {{0xeb543ee0,0xdce80135,0x4990036b,0xc17000d9}},	//   _كىرگ, _sieħ, _ییتر, כחה_, 
   {{0x3b804445,0xc9f400c6,0x63ac254f,0xc76403cc}},	//   _алуг, _يساع, _rtan, بابى, 
   {{0xdce80327,0xba980375,0xdd1003b9,0x00000000}},	//   _qieħ, _וסבי, nüşd, --, 
   {{0x2ee400fe,0x7c4000a2,0x00000000,0x00000000}},	//   নজিষ, _övrü, --, --, 
   {{0xbf98006a,0xdce8038f,0x69a4068f,0xf76c0214}},	//   _asên, _wieħ, _चंडी, طای_, 
   {{0xf64c00f8,0xdce8003d,0x774001e1,0x00000000}},	//   ائی_, _tieħ, _túbọ, --, 
   {{0x2578067c,0xc6440137,0x31c40114,0xe7f8095f}},	//   héli_, _تئشى, кств, ्टका_, 
   {{0x8afc02a8,0x63addcf4,0xc0cc0092,0x77c401af}},	//   moƙu, _ttan, _ቤትም_, _эләг_, 
   {{0x63addcf5,0xbf991803,0x320c0b1a,0x03a83779}},	// [35990] _utan, _crêp, ådyr_, _بدبو_, 
   {{0x63ac005f,0x00000000,0x00000000,0x00000000}},	//   ķinā, --, --, --, 
   {{0xbd680276,0x88d40eac,0x6131dcf6,0x00000000}},	//   орде_, থ্যক, _bålt, --, 
   {{0x71f82352,0x2b80068c,0xaee400dc,0x00000000}},	//   _کریس_, vòca_, _puṃs, --, 
   {{0x4ba40220,0x6dac27ac,0x2d9c068c,0xaae00b02}},	//   елің, _ağad, íver_, _नाशक, 
   {{0x15800952,0xdb080022,0x394c0327,0xdb18002f}},	//   ﺩﯨﺴﯩ, _eteî, _smgs_, hrwö, 
   {{0x2ca005be,0xfa480023,0xee2001ec,0xaae000b8}},	//   žida_, _ንዕላማ, _керi_, _नारक, 
   {{0xdd94ec19,0x82fc0327,0xa3c001f9,0xacf8014b}},	//   _чабы, _ཞིའུ_, ुळा_, _онсу_, 
   {{0x7d19dcf7,0x69dc00d6,0x613001e3,0x2ce401d5}},	//   _inus, _åren, _håls, _шўрв, 
   {{0x7d1836d1,0x09bc0154,0xdd9800a2,0x888000ee}},	//   _hnus, _ইমরা, _hiň_, ылыж, 
   {{0x7d185b47,0xf6600137,0xd6180133,0x85e4009d}},	//   _knus, тенү, ستدا_, ндэв_, 
   {{0xd469dcf8,0xa5941422,0x98a400d8,0x00000000}},	//   зиме_, крящ, _џиле, --, 
   {{0x395ddcf9,0x7d1801f7,0x00000000,0x00000000}},	//   mnus_, _mnus, --, --, 
   {{0x395ddcfa,0xdd9800e8,0xd34001ed,0x43900006}},	//   lnus_, _liň_, اہدی, лаўс, 
   {{0x7d19dcfb,0x58fc025c,0x6130007c,0x395c7a9a}},	//   _onus, _དྲོས_, _nåls, onus_, 
   {{0xdd980209,0x7d1804ba,0x546863ed,0xe52000dc}},	//   _niň_, _nnus, _найм_, याणि_, 
   {{0x0161dcfc,0x201c0227,0x62a404a7,0x395d9052}},	// [359a0] укто, äwip_, _štoš, inus_, 
   {{0x7d19dcfd,0xbf9800d2,0x613001e3,0xef9401d5}},	//   _anus, _tsên, _sålt, ئیسد, 
   {{0x257802ea,0xdb096cff,0x4860001f,0x395c004e}},	//   wéli_, _ateï, _ውድድሮ, knus_, 
   {{0x7d1801ab,0x395ddcfe,0x0c85a53d,0x0ee01098}},	//   _cnus, jnus_, нылм, _पावड, 
   {{0x628001f1,0x58fc031c,0xe520449f,0xdd98010e}},	//   ýlov, _དྲེས_, याति_, _diň_, 
   {{0xdd300cc1,0x395ddcff,0x69a402ab,0x7d18035a}},	//   _təşk, enus_, _चंदी, _enus, 
   {{0xbe6401c0,0x613033b8,0xc330010f,0x395c015d}},	//   _зарж_, _tålt, רוו_, fnus_, 
   {{0x7d19dd00,0xdd980209,0x3160af7a,0x6130007c}},	//   _gnus, _giň_, nniz_, _hålr, 
   {{0x6d41dd01,0x0af005f5,0x61301f53,0x6d5806af}},	//   _ilma, _бүлэ, _kålr, évau, 
   {{0x395c1730,0x7b84021f,0x00000000,0x00000000}},	//   anus_, _كالە, --, --, 
   {{0x61301088,0x395c0ba7,0x7d180076,0x24c80137}},	//   _målr, bnus_, _ynus, үгүп_, 
   {{0x395c83bf,0xc8b4007b,0xe8240101,0x00000000}},	//   cnus_, _أصاب, _لذتی, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc0cc02d3,0x69d9dd02,0xbefc0210,0x00000000}},	//   _ኣቢላ_, orve, _उसेन_, --, 
   {{0x6d41dd03,0xc0cc02d3,0xe52000dc,0x8234136e}},	//   _olma, _ኣቢለ_, यादि_, ررسا, 
   {{0x6f1c0356,0x69d85867,0xdea002f2,0x00000000}},	//   _anrc, irve, ڤیزی, --, 
   {{0xdfd02abb,0x69d803fa,0x1f74010b,0xdd9800a2}},	// [359b0] شيا_, hrve, влая, _riň_, 
   {{0x6d41dd04,0x657d813f,0x7d183bdc,0x69d802fb}},	//   _alma, llsh, _snus, krve, 
   {{0x245406c1,0x6dac029f,0xde18007b,0x395d2adb}},	//   _سنگس, _ağab, بقات_, ynus_, 
   {{0xc0cc044e,0x6285dd05,0x91a801d9,0x6b88022e}},	//   _ኣቢሉ_, _izho, _تنَے_, _ahdg, 
   {{0x69d83a5e,0x7d18003a,0x657ddd06,0xfa3400f2}},	//   erve, _vnus, ilsh, کرشد, 
   {{0x212809a8,0x657c69a9,0xee380408,0x395c015d}},	//   ljah_, hlsh, лнĕ_, wnus_, 
   {{0x58fc031c,0x69dc21e3,0xfc0001e0,0x7f5402d0}},	//   _དྲུས_, _årel, тоһү, mixq, 
   {{0x6d59dd07,0x2129dd08,0x7d186e5e,0x7f540393}},	//   évat, njah_, _unus, lixq, 
   {{0x69d9dd09,0x00000000,0x00000000,0x00000000}},	//   arve, --, --, --, 
   {{0x212803a2,0x395ddd0a,0xbf9800c7,0x7bc82b96}},	//   hjah_, snus_, _osêm, msgu, 
   {{0x2b44152d,0x69d805ce,0x7bc805ac,0x657c0076}},	//   _сэтг, crve, lsgu, flsh, 
   {{0xb4ac1094,0x2129dd0b,0x9f480ffb,0x53a5dd0c}},	//   गडे_, jjah_, staè_, камб, 
   {{0x8afc03f9,0x21280e02,0x62840200,0xbb3400d1}},	//   moƙr, djah_, _azho, ﺗﯜﻥ_, 
   {{0x7ae1dd0d,0xb6c00032,0x657c2fb2,0x257800e8}},	//   ngnt, _сикһ, alsh, délu_, 
   {{0xe1f001e2,0x00000000,0x00000000,0x00000000}},	//   یسې_, --, --, --, 
   {{0xf8b19351,0x0161dd0e,0x7bc80267,0xe8080118}},	//   ीरिय, аксо, ksgu, _वनमा_, 
   {{0x3161dd0f,0x6d4007ab,0x62840dd4,0xdb0824c8}},	// [359c0] rniz_, _rlma, _ezho, _ateí, 
   {{0x4e95ab5a,0x7bc80726,0xa49001d9,0x127800c6}},	//   نشار, dsgu, _دیُت, _يحدث_, 
   {{0x200c00da,0xd1f40020,0x54344595,0x6b880175}},	//   _šeit_, ሎቶች_, _سرکر, _rhdg, 
   {{0x6dac47af,0x9e740063,0x2c0801b9,0x84740092}},	//   _ağac, ућуј, فعتی_, _ራስህን_, 
   {{0xfce123a6,0x00000000,0x00000000,0x00000000}},	//   рочо, --, --, --, 
   {{0xbd842dfc,0x9f480428,0x62640150,0x49b800ae}},	//   ىنەن_, bwañ_, _جاۋق, واعد_, 
   {{0x69d80d47,0x6d41dd10,0x9f580af9,0x6d580005}},	//   urve, _tlma, _opsê_, évas, 
   {{0x69d9dd11,0x6d41dd12,0x9f584d3e,0x69dc143a}},	//   rrve, _ulma, _essä_, _årem, 
   {{0xa775dd13,0x6130dac1,0xc8640395,0xcae800f3}},	//   ллич, _målp, ътки, _омаж_, 
   {{0x21280010,0x00000000,0x00000000,0x00000000}},	//   zjah_, --, --, --, 
   {{0xfaa0e846,0xa2c0726b,0xe534d4d5,0x00000000}},	//   _тахо, वरस्, гень, --, 
   {{0x29240122,0x63a800df,0x00000000,0x00000000}},	//   ávač_, ŭenm, --, --, 
   {{0x0ee02cd1,0x58fc0003,0x67d51421,0x657cef41}},	//   _पांड, _དྲིས_, _солу, rlsh, 
   {{0xf76c72f7,0xe37401c0,0xf7400114,0x00000000}},	//   _واو_, улгы, _вељо, --, 
   {{0x41740150,0xf1a437fb,0x35a00261,0x09d0031c}},	//   نارس, иртн, _кајг, ེངྒ_, 
   {{0x6284151c,0x7bc80175,0x42e00154,0x00000000}},	//   _vzho, ysgu, য়েশ, --, 
   {{0x2129dd14,0xdca404a9,0x83a807d6,0xf1950b85}},	// [359d0] rjah_, қали, _ўтиб_, рить, 
   {{0x5f780ef6,0x02b42efd,0x25780de2,0x00000000}},	//   رماس_, _अभिभ, rélu_, --, 
   {{0x6234346d,0xf56800e5,0x00000000,0x00000000}},	//   _сену, _سمیٹ_, --, --, 
   {{0xdfd400fd,0x7bc81141,0xcfb000eb,0x00000000}},	//   _йомы, tsgu, _চিরন, --, 
   {{0x50d80375,0x9f589596,0xfeb800f1,0xab640327}},	//   _אקרא, _asså_, _ياست_, _żżar, 
   {{0x7bc9dd15,0x7ae00218,0x8c144e77,0x6d580588}},	//   rsgu, ugnt, ايور_, évar, 
   {{0x7bc8007c,0x6d5800e4,0x00000000,0x00000000}},	//   ssgu, ĩvar, --, --, 
   {{0x09f40597,0xef2841b5,0x684800e2,0x7bc81141}},	//   افية_, rnüş_, kūdī, psgu, 
   {{0xb8c803e5,0x984c0023,0x97340139,0x4a50013d}},	//   _खल_, _ንትምህ, гэнч, икәс, 
   {{0xfb843339,0x5628173e,0x0884013d,0x00000000}},	//   _рыбн, ежом_, ыбый_, --, 
   {{0x28dc84b7,0x612c0092,0x00000000,0x00000000}},	//   _याचि, ደምትች, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe708030f,0xd45402bf,0x00000000,0x00000000}},	//   رتین_, утнь, --, --, 
   {{0x91e4ab24,0x03a1dd16,0x527531b9,0x47d01541}},	//   логе, сиро, губу, _ايور, 
   {{0xd838010e,0x00000000,0x00000000,0x00000000}},	//   lyō_, --, --, --, 
   {{0x78b80024,0x86780375,0xd174013d,0x00000000}},	//   nbuv, _ארצו, уыгы, --, 
   {{0xd8380209,0x00000000,0x00000000,0x00000000}},	// [359e0] nyō_, --, --, --, 
   {{0xd6d403d4,0x4390009b,0x00000000,0x00000000}},	//   ত্ৰপ, _лањс, --, --, 
   {{0x91640066,0x06d001ec,0x00000000,0x00000000}},	//   _مهده, _ﻛﯘﺳﻪ, --, --, 
   {{0x8698008f,0xd838003e,0x20b40a89,0x9ce40212}},	//   גיעז, kyō_, _вёрс, иціл, 
   {{0xbf9800e4,0x27e001e4,0x00000000,0x00000000}},	//   _osêh, _ĥino_, --, --, 
   {{0x69dc0ac8,0xbea00816,0xaa58014b,0xd8380432}},	//   _årek, _гарк, килу_, dyō_, 
   {{0x58fc003d,0x3f640334,0xea24009d,0x37a40150}},	//   _དྲངས_, _сиро_, рчлү, қтын_, 
   {{0x051c03d4,0x98ac0135,0x00000000,0x00000000}},	//   _পত্ৰ_, tieġ_, --, --, 
   {{0xd90d2b63,0x39100137,0x0f2c0092,0xd838010b}},	//   بین_, смыр, _በማስከ, gyō_, 
   {{0x2ef8007c,0xfd4c01e1,0x9b3c030d,0x00000000}},	//   _jbrf_, _àáró_, _офхi, --, 
   {{0x69c405f5,0xbb3827af,0x00000000,0x00000000}},	//   _төлб, _רעבי, --, --, 
   {{0x36847e3a,0x00000000,0x00000000,0x00000000}},	//   ысын_, --, --, --, 
   {{0x38c9dd17,0x443c0ba1,0xf7600451,0xb7d4cfad}},	//   _سانی_, áu_, _گهوٽ, _مونا_, 
   {{0xae040037,0x4df44707,0x443c025c,0x00000000}},	//   रबान_, ीबाई_, ġu_, --, 
   {{0x443c0029,0x77600014,0xa2943981,0x229402e8}},	//   šu_, _دُؤ, раві, ривя, 
   {{0x0ee02982,0xa3dc070f,0x00000000,0x00000000}},	//   _पाउड, _डिप_, --, --, 
   {{0x9f55dd18,0x00000000,0x00000000,0x00000000}},	// [359f0] авач, --, --, --, 
   {{0x248805b1,0x3e6800a7,0xaae01c15,0x3da400d8}},	//   _izam_, ншен_, _नागक, грдб, 
   {{0x9cb5dd19,0x53980302,0x2b80007f,0x00000000}},	//   لمات, _שיתו, mòch_, --, 
   {{0x2dd8007b,0x91b8011a,0x6d580124,0x00000000}},	//   ابلة_, _שמרי, évap, --, 
   {{0x9f480597,0x316c00d2,0x6d5800c7,0x00000000}},	//   ltaí_, édze_, ĩvap, --, 
   {{0x6dac0166,0x201803e3,0x3e740117,0x00000000}},	//   _iğan, _irsi_, _бигӯ_, --, 
   {{0x9f48007b,0x64b40073,0x00000000,0x00000000}},	//   ntaí_, ंडाळ, --, --, 
   {{0x6bd42928,0xaee41682,0xdb080332,0x248800a2}},	//   شتۇر, ruṅw, _dteá, _ozam_, 
   {{0x9f480491,0x248805b1,0x96b889d2,0x00000000}},	//   htaí_, _nzam_, куну_, --, 
   {{0x16a8013e,0x00000000,0x00000000,0x00000000}},	//   ъвои_, --, --, --, 
   {{0x2489dd1a,0xe8f80046,0xab800020,0xbf980165}},	//   _azam_, _әлі_, ርገዋል_, _brêz, 
   {{0x2019dd1b,0x98751b0e,0x9f4800ae,0xd7f40108}},	//   _orsi_, _клец, dtaí_, _взды, 
   {{0x2018003e,0x67d46ee8,0x00000000,0x00000000}},	//   _nrsi_, _гочу, --, --, 
   {{0x2b800100,0x9f4801e7,0x00000000,0x00000000}},	//   gòch_, ftaí_, --, --, 
   {{0x20194972,0x2489dd1c,0xf5b001d3,0x55e43740}},	//   _arsi_, _ezam_, _اشتھ, _тойб, 
   {{0xca3402dd,0x00000000,0x00000000,0x00000000}},	//   _ﻗﻠﺏ_, --, --, --, 
   {{0xd025dd1d,0x2b800100,0x9f4800ae,0x63b80419}},	// [35a00] шмай, bòch_, ataí_, čaný, 
   {{0xdce801a2,0x1ea8188d,0x20180427,0x98ac0327}},	//   _cieľ, هامي_, _drsi_, bieħ_, 
   {{0x42d808a8,0x9f480332,0xdce800d7,0x00000000}},	//   _בקיע, ctaí_, _dieľ, --, 
   {{0x17040489,0x69dc143a,0x248800a2,0x516400cf}},	//   _མིའམ_, _årei, _yzam_, _түбү_, 
   {{0x3ce802fb,0x238402d2,0x00000000,0x00000000}},	//   _živá_, _ásjó_, --, --, 
   {{0x91d80037,0x00000000,0x00000000,0x00000000}},	//   _बटाई, --, --, --, 
   {{0x3f4c031c,0x00000000,0x00000000,0x00000000}},	//   rżut_, --, --, --, 
   {{0xf98c05e6,0xfce00184,0x63a8008f,0x8ad401c8}},	//   وبي_, _мосо, ŭeni, _چتائ, 
   {{0x8ad5dd1e,0xdcf0038f,0xd90c034c,0x4789dd1f}},	//   _نتائ, _żgħa, عیه_, ксом_, 
   {{0x66180232,0xaae01810,0xcfd00150,0x00000000}},	//   _prvk, _नाटक, _ﺟﻪﻟﺒ, --, 
   {{0xdb08030a,0xfa64283c,0x00000000,0x00000000}},	//   _gweñ, _кафк_, --, --, 
   {{0xe3c401c6,0x2b80033b,0x00000000,0x00000000}},	//   йргү, wòch_, --, --, 
   {{0x2905dd20,0xd90c0451,0x5ecc0154,0xe7b45b7a}},	//   mema_, _سڌي_, ালতে, _امتد, 
   {{0x623419c3,0x81f400c7,0x62800254,0x673c007c}},	//   бегу, аҕоу_, üloo, örjd, 
   {{0x6594084c,0x29040093,0x27e5dd21,0x2b8056ec}},	//   _лаку, oema_, lumn_, gòci_, 
   {{0x9f4800c6,0x201809a8,0x29040d92,0x6dac1432}},	//   rtaí_, _prsi_, nema_, _ağao, 
   {{0x9f4800c6,0x838431af,0x29040083,0x22951b58}},	// [35a10] staí_, _выне, iema_, _گلدس, 
   {{0xb610021a,0x20181505,0x00000000,0x00000000}},	//   _اړیک, _vrsi_, --, --, 
   {{0x26cc617f,0x7de40220,0xeea80104,0xe214023a}},	//   iado_, різд, ртук_, _умны, 
   {{0x26cddd22,0x2905dd23,0x81400014,0x2ca40142}},	//   hado_, jema_, _بۆرن, _cgmd_, 
   {{0x26cddd24,0x2905dd25,0xed5800d6,0x00000000}},	//   kado_, dema_, шої_, --, 
   {{0x60cddd26,0x26cddd27,0x20080428,0x00000000}},	//   laam, jado_, mwai_, --, 
   {{0x29040433,0xd208010f,0xaa8815bf,0x00000000}},	//   fema_, ָלפֿ, ۇنۇم_, --, 
   {{0x2905dd28,0x26cc7499,0x370c033f,0xdb080139}},	//   gema_, eado_, _थोड़ी_, _oteç, 
   {{0x26cddd29,0x20080286,0x775c001f,0x60cd8f02}},	//   fado_, nwai_, _ኅብረተ, iaam, 
   {{0x60cddd2a,0x2009dd2b,0x15b94d6d,0xdb1803fa}},	//   haam, iwai_, лымы_, nswü, 
   {{0x2009dd2c,0x49d9dd2d,0x0680009d,0x00000000}},	//   hwai_, _مانگ_, згэн, --, 
   {{0x60cc1059,0x2009dd2e,0x55e4013e,0x4a5800d9}},	//   jaam, kwai_, _ғоиб, _גדעו, 
   {{0x60cc1dc3,0x6dac3bc1,0x145806a6,0xe7d400bc}},	//   daam, _ağal, ушны_, _दिएप, 
   {{0x26cc302f,0x2009b051,0x06dc0011,0x00000000}},	//   cado_, dwai_, ব্বি, --, 
   {{0x60cddd2f,0x673c0267,0x6ffc0154,0xcf4401ec}},	//   faam, örje, ঁয়াজ_, ұнай, 
   {{0x60cddd30,0x661c04ce,0x10a400c7,0x2ca001fa}},	//   gaam, ærke, сиан, židi_, 
   {{0x7525dd31,0x2009d6ba,0x69dc28b3,0x6d59dd32}},	// [35a20] _iniz, gwai_, _årev, èvam, 
   {{0xdb2401e1,0x00000000,0x00000000,0x00000000}},	//   _àpèm, --, --, --, 
   {{0x20080db6,0x7524219b,0x60cddd33,0x3ea001c6}},	//   awai_, _kniz, baam, чихг, 
   {{0x26cc1a36,0x60cc47ad,0x0c245cd9,0x20080083}},	//   zado_, caam, ймен, bwai_, 
   {{0x26cd3da5,0x2905266c,0x75240327,0x3218017a}},	//   yado_, vema_, _mniz, lvry_, 
   {{0xf765dd34,0x26cc10ba,0x2905dd35,0xdb18007f}},	//   _را_, xado_, wema_, npwè, 
   {{0x2905dd36,0x752400b5,0x00000000,0x00000000}},	//   tema_, _oniz, --, --, 
   {{0x26cc00b4,0x2be000dc,0x7c28010a,0x27e527e1}},	//   wado_, _निपा, bxgr, tumn_, 
   {{0x37a401c0,0xdb000798,0x389c00cd,0xc5a00150}},	//   йтэн_, _milê, _nārī_, _ﺍﻟﻘﻨ_, 
   {{0x290416cb,0x60cddd37,0x7524009d,0x7bdc5b84}},	//   sema_, zaam, _aniz, áque, 
   {{0xf3f4003d,0x60cc8460,0x2905dd38,0x20082251}},	//   _བདུད_, yaam, pema_, zwai_, 
   {{0x29040333,0x60cc058a,0x20080142,0x00000000}},	//   qema_, xaam, ywai_, --, 
   {{0x60cddd39,0x389c002b,0xaaac0456,0x00000000}},	//   vaam, _cārī_, _चलाक, --, 
   {{0x60cddd3a,0x75242939,0x165825da,0x26cc0014}},	//   waam, _eniz, اسیک_, qado_, 
   {{0x60cddd3b,0xdce8005f,0xb1a4cea6,0x61140024}},	//   taam, _pieļ, зшук, одву, 
   {{0x7524000f,0xe2780150,0xae940241,0x00000000}},	//   _gniz, _ﹼﺭﻜﻡ_, _tẹja, --, 
   {{0x69dc12ed,0x656c0124,0xbf980022,0x22a40117}},	// [35a30] _æref, _ijah, _osêt, _мунҳ, 
   {{0x60cddd3c,0x20080649,0x0cb8015b,0x752423cc}},	//   saam, rwai_, ুলোত, _zniz, 
   {{0x60cd322f,0xa294177b,0xf314009d,0x00000000}},	//   paam, _фані, _эдээ, --, 
   {{0x60cddd3d,0x1c380139,0x00000000,0x00000000}},	//   qaam, ияль_, --, --, 
   {{0x656d92c1,0x70580139,0x00000000,0x00000000}},	//   _mjah, _гаяр_, --, --, 
   {{0x3da4912f,0x7ae4242f,0x63bc0064,0xff2801a9}},	//   _граб, сюдж, ipsn, _сўми_, 
   {{0x389c02b5,0x656c035b,0x61f403ac,0x00000000}},	//   _mārū_, _ojah, ntzl, --, 
   {{0x656ddd3e,0x7c2c0129,0x293c00d1,0x00000000}},	//   _njah, _àcro, ﻟﻼﭖ_, --, 
   {{0x57480075,0x2be017ee,0x1d0804a9,0x9f58003a}},	//   изим_, _निया, _йеңи_, _ipsâ_, 
   {{0x75241225,0x656c8b9a,0xbb3406ba,0x4bc0009d}},	//   _sniz, _ajah, ﺗﻜﻪ_, _цөцг, 
   {{0x63bc01f5,0xdb000200,0x4b3000f2,0x00000000}},	//   epsn, _lilë, _تکنس, --, 
   {{0x2be004af,0x389c0171,0x00000000,0x00000000}},	//   _निमा, _pārī_, --, --, 
   {{0x395ddd3f,0x656ddd40,0x61f4002f,0x00000000}},	//   mius_, _djah, etzl, --, 
   {{0x395ddd41,0xdb0006ed,0x656ddd42,0x32180af9}},	//   lius_, _silê, _ejah, tvry_, 
   {{0x69dc17c0,0x2be0023e,0x7524025c,0x98ac031c}},	//   _året, _निभा, _tniz, jjeċ_, 
   {{0xd01000dd,0x395c0839,0x752401a4,0x656c0240}},	//   ولز_, nius_, _uniz, _gjah, 
   {{0xdb00069c,0x395c003a,0x32180af9,0x00800120}},	// [35a40] _cilë, iius_, svry_, длто, 
   {{0x25e02c97,0x395ddd43,0xdb000042,0xc480008e}},	//   _किमी_, hius_, _dilë, _юлык, 
   {{0x10a4c9d8,0x395c02d5,0x0d9800ee,0x8e08020f}},	//   _минн, kius_, атды_, рнев_, 
   {{0x4c853d8a,0x395c269e,0x61e000e4,0x00000000}},	//   олев, jius_, álle, --, 
   {{0x395ddd44,0x6d400227,0xdb004915,0x25e0000d}},	//   dius_, _ŋmas, _kilè, _किभी_, 
   {{0xdb00007f,0x31600bc1,0x395c003a,0x684001e1}},	//   _jilè, liiz_, eius_, _ládú, 
   {{0xbe6431a8,0xdb0002e2,0x395d7f01,0x00000000}},	//   _дарж_, _milè, fius_, --, 
   {{0x395ddd45,0x68400597,0x63bc002d,0x58080327}},	//   gius_, _nádú, ypsn, _ཀརྡོ_, 
   {{0x870400a7,0x7a3c0241,0x3a4000c0,0xb80400ae}},	//   ояне, _pàtú, _įspū_, قييم_, 
   {{0x656c194f,0x00000000,0x00000000,0x00000000}},	//   _sjah, --, --, --, 
   {{0x395ddd46,0xf67005f5,0x3160063f,0x8588005b}},	//   bius_, дгээ, kiiz_, иёма_, 
   {{0x395ddd47,0xda642361,0x2ca005be,0x499001b9}},	//   cius_, _عالي, židu_, _تیبر, 
   {{0x684001e1,0x389c00b0,0xd76401d3,0x877001a9}},	//   _dádú, _pārū_, _کانٹ, _оғиш, 
   {{0xb9d002d3,0x69dc143a,0x248c0115,0x249000a2}},	//   _ኻብ_, _åres, ĥem_, _ılmı_, 
   {{0xdb01dd48,0x9f480724,0x656dabb9,0xbf9800e4}},	//   _dilè, ltaç_, _tjah, _osêr, 
   {{0x61f4010a,0x656c7c18,0xcfb000cc,0x00000000}},	//   rtzl, _ujah, _চিজন, --, 
   {{0x657ddd49,0x389c00b0,0x9ed801d5,0x00000000}},	// [35a50] mosh, _tārū_, ймат_, --, 
   {{0x657ddd4a,0xa294242f,0x395ddd4b,0x63ac0ffb}},	//   losh, _напі, zius_, _iuan, 
   {{0x6d480024,0x9f480790,0x657c0076,0x61f40175}},	//   _įdar, htaç_, oosh, qtzl, 
   {{0x63ac16cb,0x63a45ecd,0x657ddd4c,0x395ddd4d}},	//   _kuan, _hihn, nosh, xius_, 
   {{0x395ddd4e,0x63a40641,0x2b800ba1,0x6ec40131}},	//   vius_, _kihn, jòcs_, ستەق, 
   {{0x63addd4f,0x673800c8,0x63a40477,0xdb00e01a}},	//   _muan, _novj, _jihn, _xilè, 
   {{0x395ddd50,0x657c0e8a,0x63a5dd51,0xeaf93083}},	//   tius_, kosh, _mihn, ترنت_, 
   {{0x63a4025a,0x63addd52,0x657c9b6f,0x6285dd53}},	//   _lihn, _ouan, josh, _myho, 
   {{0x395ddd54,0x657ddd55,0xdb0000e8,0x6dac0139}},	//   rius_, dosh, _lilé, _ağah, 
   {{0x395ddd56,0x6739dd57,0x6e6801d9,0x21381c1d}},	//   sius_, _covj, _امہِ_, _losh_, 
   {{0x395ddd58,0xc994021a,0x63ac18a6,0x6285dd59}},	//   pius_, _ځانګ, _auan, _nyho, 
   {{0x657ddd5a,0xdb0035f5,0x4280010c,0xa3dc10eb}},	//   gosh, _silè, _ረድኤት_, _डिश_, 
   {{0x63ac4888,0xb9d80020,0xdb01dd5b,0x63a4fa2f}},	//   _cuan, _ባለ_, _ailé, _bihn, 
   {{0x63addd5c,0x62840af9,0x31600ba7,0x63a400cd}},	//   _duan, _byho, wiiz_, _cihn, 
   {{0x62840f7b,0x2138006c,0x3cfc0232,0x63ad9311}},	//   _cyho, _bosh_, _obuv_, _euan, 
   {{0x25e005ba,0x657ddd5d,0xdb01dd5e,0x2139dd5f}},	//   _किती_, cosh, _dilé, _cosh_, 
   {{0x63addd60,0xb4d81810,0x2139dd61,0x628403ac}},	// [35a60] _guan, ाणी_, _dosh_, _eyho, 
   {{0xdce81727,0x63a4025a,0xdb00114f,0x00000000}},	//   _dječ, _gihn, _filé, --, 
   {{0x63addd62,0x628400a9,0x32640583,0xdb007cf8}},	//   _zuan, _gyho, _آنجہ, _gilé, 
   {{0x8fa5dd63,0x21381590,0x63addd64,0x2be00f4a}},	//   _наме, _gosh_, _yuan, _निदा, 
   {{0xa2c00490,0x63addd65,0xd0e4004b,0x69c80009}},	//   वरच्, _xuan, _وکړم_, _swde, 
   {{0x657ddd66,0x69c80280,0x2fc1dd67,0x9f54032e}},	//   zosh, _pwde, mpig_, _æfðu_, 
   {{0x657ddd68,0xbf98006a,0x2139dd69,0x9f5802d2}},	//   yosh, _kpên, _yosh_, _essó_, 
   {{0x6dac00ee,0x657c013e,0x213803b9,0xa3dc0709}},	//   _aşag, xosh, _xosh_, _डिल_, 
   {{0x67381f7f,0xdd8c00d1,0x657ddd6a,0x47840022}},	//   _povj, _ئۈن_, vosh, зынб, 
   {{0x63ac47d8,0x442401dc,0xd7dc0574,0x657d52be}},	//   _ruan, _ăn_, _मिरच, wosh, 
   {{0x657ddd6b,0x63addd6c,0xf7f05439,0x3ab8011a}},	//   tosh, _suan, وسید, _המבנ, 
   {{0x63addd6d,0x63a4006a,0x6dac05d1,0x67380455}},	//   _puan, _sihn, _işad, _wovj, 
   {{0x657ddd6e,0x213800ad,0xbf9800e4,0x63a40427}},	//   rosh, _rosh_, _osêp, _pihn, 
   {{0x63addd6f,0x657ddd70,0xdce81f7f,0xf7e00075}},	//   _vuan, sosh, _rječ, _ﺋﻪﻣﻪ, 
   {{0x63a5512b,0xdce88185,0x657ddd71,0x2138045a}},	//   _vihn, _sječ, posh, _posh_, 
   {{0x657ddd72,0x628403c6,0x60f80953,0x213831a1}},	//   qosh, _vyho, ўная_, _qosh_, 
   {{0xe299dd73,0x63a40356,0x6284012d,0xc4c0000d}},	// [35a70] саң_, _tihn, _wyho, _व्यओ, 
   {{0xdce81711,0x9ed80220,0x63a40098,0x6285dd74}},	//   _vječ, імет_, _uihn, _tyho, 
   {{0xdb0000d2,0x2139dd75,0xb9e40154,0x00000000}},	//   _bilî, _tosh_, _খন্ড_, --, 
   {{0xac880240,0x00000000,0x00000000,0x00000000}},	//   _ንዂሎም_, --, --, --, 
   {{0x1be802bf,0x6daca5c1,0x26dc00f3,0x00000000}},	//   ідки_, _aşad, _odvo_, --, 
   {{0xac741272,0xdb0843eb,0x9f05dd76,0x02bc00cd}},	//   رانش, _önün, _توسو, ्रिभ, 
   {{0x3c400171,0x00000000,0x00000000,0x00000000}},	//   _sīvā_, --, --, --, 
   {{0x18a5dd77,0x673c01e6,0x98a4010b,0x6280012d}},	//   майм, örjn, мийе, żlow, 
   {{0x24c400bd,0xfaa40139,0x7d0888fa,0x02bc00dc}},	//   ্লাহ, _ешен, megs, ्राभ, 
   {{0x257801ed,0xdce800e2,0x7d09dd78,0x00000000}},	//   mély_, _pieķ, legs, --, 
   {{0x69dc03cd,0x60dc03ac,0x00000000,0x00000000}},	//   _årep, _odsm, --, --, 
   {{0xb4d87714,0x26dc020c,0x52c47382,0x7d0801c7}},	//   ाणे_, _edvo_, वर्स, negs, 
   {{0xdb000054,0x7999dd79,0x78a80327,0x9f58003a}},	//   _jilï, mmuw, _iggv, _ipsæ_, 
   {{0x88980302,0xdcf40724,0x966413dc,0x7998020c}},	//   _ובני, _muzı, _окле, lmuw, 
   {{0x03a1dd7a,0xe7309e9d,0x799804ba,0x63a800df}},	//   тиро, _حصن_, omuw, ŭenp, 
   {{0x60dc0998,0x79980b45,0x61e001ed,0x257801d3}},	//   _cdsm, nmuw, álla, kély_, 
   {{0x7d08074d,0xb38c0092,0x4fa46031,0x00000000}},	// [35a80] degs, መረውን_, диав, --, 
   {{0x60dc02d0,0x257801ed,0x2fc0257c,0x37bc00fe}},	//   _edsm, dély_, rpig_, _এটাৰ, 
   {{0xace40184,0x2be00c2e,0x90c40032,0x7d0801c7}},	//   ебеҙ, _निहा, _обне, fegs, 
   {{0x25e0006d,0x7d08074d,0x2fc1dd7b,0xdb08003a}},	//   _किसी_, gegs, ppig_, _queî, 
   {{0xa07400c7,0x257800e5,0x00000000,0x00000000}},	//   _зырш, gély_, --, --, 
   {{0x7d0800c5,0x00000000,0x00000000,0x00000000}},	//   aegs, --, --, --, 
   {{0xa6bc00cc,0x00000000,0x00000000,0x00000000}},	//   _ইএলট, --, --, --, 
   {{0xa814623a,0x5fb40073,0xec3402dd,0xb4d800cd}},	//   едиш, _अंमल, _كوزگ, ाणो_, 
   {{0x63680427,0xab640327,0x070801a9,0xc6e400d4}},	//   lžne, _żżur, охни_, мінп, 
   {{0x4b24ad2d,0x99881b24,0x79980337,0x7a3401f2}},	//   _تعرف, ćaš_, amuw, ụtal, 
   {{0x8a04005e,0x92e400b8,0x00000000,0x00000000}},	//   _ізде, _mṛdū, --, --, 
   {{0xc864165d,0x69d9dd7c,0x91b0000d,0xdb0c0241}},	//   _отли, msve, _अढ़ै, _ìkòw, 
   {{0x69d9dd7d,0xb7100244,0x25e01fd2,0x00000000}},	//   lsve, ربیش, _किवी_, --, 
   {{0x69d885a2,0xdb180112,0x399000e4,0x00000000}},	//   osve, sswö, rãse_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69d9dd7e,0x35680046,0xf19400d4,0x00000000}},	//   isve, _орын_, вись, --, 
   {{0x69d81cfd,0x7d09dd7f,0x25a80037,0x2be011a6}},	// [35a90] hsve, vegs, _iial_, _निषा, 
   {{0x69d8143a,0x2d840548,0x7d087585,0x25a800a3}},	//   ksve, _akme_, wegs, _hial_, 
   {{0x25a800c8,0x69d80cf9,0x7d09dd80,0x6dac0bbc}},	//   _kial_, jsve, tegs, _aşab, 
   {{0x2be01715,0x69d9dd81,0x2488a929,0x60dc00b5}},	//   _निशा, dsve, _kyam_, _udsm, 
   {{0x7d09dd82,0x69d801a4,0x25a9dd83,0x00000000}},	//   regs, esve, _mial_, --, 
   {{0x2be01788,0xaac40075,0x3f800784,0x69d9dd84}},	//   _निरा, پتون, _ukju_, fsve, 
   {{0x69d9dd85,0x2d840418,0x3e300014,0xbdc401d3}},	//   gsve, _fkme_, _جہار, _آگئے_, 
   {{0x6e94165d,0x2d7817a3,0x2489dd86,0x25a801ab}},	//   _рису, včeg_, _oyam_, _nial_, 
   {{0x2489dd87,0x69d805e4,0x9940033f,0x7a1006be}},	//   _nyam_, asve, móż_, _mətə, 
   {{0xdd8c0075,0xba2800c6,0x69d87e42,0xe87401d5}},	//   _ئۈچ_, _وسام_, bsve, خچمگ, 
   {{0x2489dd88,0x25a9dd89,0x864001c6,0x69080254}},	//   _ayam_, _bial_, гнэж, ördõ, 
   {{0x86200fa2,0x7a1003b9,0xf8d0012d,0x00000000}},	//   اکول, _nətə, _धजिय, --, 
   {{0x394c00e2,0x37140327,0x61e001d3,0xba040257}},	//   _ilgs_, ྱབྱལ_, álln, _ፊሊ_, 
   {{0x88380302,0x7bd80810,0xd1c00023,0x00000000}},	//   _מתנו, _mvuu, ስሪቱ_, --, 
   {{0x248800f1,0x25a9dd8a,0x845c0092,0x81b805ac}},	//   _eyam_, _fial_, ሰራለን_, _ঘিউ_, 
   {{0xe61004d3,0x25a80363,0x224400fe,0x6d9800e4}},	//   _خشه_, _gial_, ølka_, míag, 
   {{0x69d9dd8b,0x8afc0198,0x4f2499b3,0x7bd804ba}},	// [35aa0] zsve, hiƙa, ндаб, _nvuu, 
   {{0xdb0000d8,0x25a800d0,0xc5f00154,0xa3e41d94}},	//   _bilí, _zial_, _জনতা_, _पटत_, 
   {{0x7bd80337,0x25a8062c,0x7a1003e3,0x4ce400db}},	//   _avuu, _yial_, _fətə, ежеб, 
   {{0x41b80302,0x69d84bc1,0x6b540de2,0xdb000332}},	//   _מצטע, vsve, _kàgg, _dilí, 
   {{0x7c801a21,0xdb018a78,0x708400c7,0x1fb4b697}},	//   луше, _eilí, _рҳаз, _асср, 
   {{0x69d9dd8c,0xdb010358,0x6b541574,0x00000000}},	//   tsve, _filí, _màgg, --, 
   {{0xdb00043b,0x7bd804ba,0x6b5400e8,0x69d80108}},	//   _gilí, _evuu, _làgg, usve, 
   {{0x7a1003b9,0xd0680092,0x00000000,0x00000000}},	//   _xətə, _በመስኩ_, --, --, 
   {{0x69d8037f,0x394c0395,0x0c2440b6,0x6b54002e}},	//   ssve, _dlgs_, _яман, _nàgg, 
   {{0x25a9dd8d,0xdb000a85,0x69d940e1,0x442405d5}},	//   _sial_, _eilâ, psve, _čn_, 
   {{0x2489dd8e,0x25a807c5,0x36d401c6,0x6d980174}},	//   _syam_, _pial_, эдээ_, ríaf, 
   {{0x270c0134,0x98c40022,0x00000000,0x00000000}},	//   _wכn_, _аицҵ, --, --, 
   {{0xf76c034d,0x6b54002e,0xa2c400d1,0x25a9dd8f}},	//   شای_, _càgg, кәнк, _vial_, 
   {{0x6b540de2,0x61e001ed,0x7528005f,0x82a4008e}},	//   _dàgg, állo, ēdza, ешбе, 
   {{0x25a800c8,0x6d9800e4,0x7a1003b9,0x7ce80205}},	//   _tial_, cíag, _pətə, nörü, 
   {{0x6b541bce,0x7a1003e3,0x248800b8,0x00000000}},	//   _fàgg, _qətə, _tyam_, --, 
   {{0x7a100cc1,0x2489dd90,0x3ebc03f9,0x8afc0198}},	// [35ab0] _vətə, _uyam_, _ƙut_, ziƙa, 
   {{0xdb01dd91,0x20e0001e,0x00000000,0x00000000}},	//   _milã, ỗi_, --, --, 
   {{0x817001d9,0x02a48fa3,0x7a1006be,0xa1740064}},	//   _مندچ, _ярим, _tətə, _агні, 
   {{0xbf98006a,0x6b541bce,0x6dadd49a,0xdb0001ef}},	//   _kpêk, _yàgg, _ağas, _vilí, 
   {{0x99400210,0x00000000,0x00000000,0x00000000}},	//   róż_, --, --, --, 
   {{0xc6840592,0x7ce80790,0xdb840395,0x00000000}},	//   _نِ_, förü, ъгли, --, 
   {{0x15e402ab,0x7ce806b9,0xdb080139,0x6e941246}},	//   _किधर_, görü, _iteü, _биру, 
   {{0x8afc03f9,0xdd95dd92,0xcd400014,0x00000000}},	//   riƙa, _рабы, _پھٔٹ, --, 
   {{0x5b146145,0x7d18009a,0x8afc03f9,0x394c01f5}},	//   _имат, _iaus, siƙa, _vlgs_, 
   {{0x7d19dd93,0xdb0000b8,0x6dac0139,0x00000000}},	//   _haus, _dilã, _iğar, --, 
   {{0x7d194f4b,0x6d980077,0x6b541bce,0xd5e402e8}},	//   _kaus, bíad, _sàgg, ъжни, 
   {{0x7d19dd94,0xaa64188c,0x79640214,0xdb0005da}},	//   _jaus, _стук, _dèwè, _hilà, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x1cb0031c,0x36200050,0x00000000,0x00000000}},	//   _ནུའ_, _موتہ, --, --, 
   {{0xdb0080e1,0x69080158,0x2d78107d,0x28a400c7}},	//   _milà, _åsdø, nčec_, _ишәг, 
   {{0x142400d1,0x6b540694,0xc0e00798,0x00000000}},	//   _адим, _tàgg, иоск, --, 
   {{0x10a43304,0x6b5400db,0x00000000,0x00000000}},	// [35ac0] тиан, _hàge, --, --, 
   {{0xb8d03aaf,0xdb0005da,0x00000000,0x00000000}},	//   _དུ_, _nilà, --, --, 
   {{0x7d19dd95,0xc1e401c0,0x6dace94a,0x2d780010}},	//   _baus, _идэж_, _ağar, jčec_, 
   {{0x7d19dd96,0x6b541497,0x4c68180b,0x3d1401f9}},	//   _caus, _màge, миен_, _नसणे_, 
   {{0x7d19dd97,0xdb0004cc,0x6d980789,0x00000000}},	//   _daus, _bilà, víad, --, 
   {{0x7d185692,0x7ce805d1,0xdcf802b5,0xf7641291}},	//   _eaus, törü, rowā, _ضا_, 
   {{0x7d19dd98,0x6f1c007b,0xce4801b9,0xd90c00f1}},	//   _faus, _iarc, _ўзбе_, ګین_, 
   {{0x7d19dd99,0x6f1ddd9a,0xf964081d,0x1cb0025c}},	//   _gaus, _harc, крый_, _ནུར_, 
   {{0x6d400ea3,0x3d140574,0xdb0003d1,0x6d980077}},	//   _ioma, _नसते_, _filà, ríad, 
   {{0x7d181326,0x6f1c04ac,0xdb000120,0x78b80356}},	//   _zaus, _jarc, _vilã, acuv, 
   {{0x6d41dd9b,0xa4d4063b,0xba14a864,0x7d19dd9c}},	//   _koma, лоні, _ليلا_, _yaus, 
   {{0x77600b6f,0x6f1ddd9d,0xedac074d,0x00000000}},	//   _emnx, _larc, огiа_, --, 
   {{0x6d41dd9e,0x2ef804cc,0x796400f2,0xdb000798}},	//   _moma, _ocrf_, _wèwè, _hilá, 
   {{0x6d41dd9f,0xdb0001ed,0x02bc2802,0x00000000}},	//   _loma, _kilá, ्रेन, --, 
   {{0x6d41dda0,0x2259dda1,0x6b540241,0xb794010f}},	//   _ooma, хивы_, _kàgb, _שכוח_, 
   {{0xdb000306,0x6b5401e1,0xe13401ec,0x00000000}},	//   _milá, _jàgb, ынбы, --, 
   {{0x6f1c4a2f,0x7d19dda2,0xdb0174e4,0x1f7400ee}},	// [35ad0] _barc, _raus, _lilá, глая, 
   {{0x7d19dda3,0x6d41dda4,0x6b540cad,0x7bdc02d1}},	//   _saus, _aoma, _làgb, šquk, 
   {{0x6f1ddda5,0x3ea404f3,0xdd94010b,0x6dac06be}},	//   _darc, änt_, гажы, _ağaq, 
   {{0x6d41dda6,0x6f1ddda7,0x7d18011f,0xa15802d5}},	//   _coma, _earc, _qaus, _чаму_, 
   {{0x6f1ddda8,0x7d18004c,0xdb00002e,0x00000000}},	//   _farc, _vaus, _pilà, --, 
   {{0x7d19dda9,0x6d400295,0x2019ddaa,0x9b44007b}},	//   _waus, _eoma, _issi_, طنبو, 
   {{0x7d182f06,0x6d41ddab,0x6dac6565,0x4cd00154}},	//   _taus, _foma, _işan, _হারু, 
   {{0x6f1dddac,0x7d180618,0x2d7801a6,0x00000000}},	//   _zarc, _uaus, rčec_, --, 
   {{0x5c75ddad,0x6b540ca8,0x17844965,0x61e000e5}},	//   _слат, _dàgb, лгим, állj, 
   {{0x6d41ddae,0xdb000077,0x78b94bd7,0x6f1c00db}},	//   _zoma, _filá, scuv, _xarc, 
   {{0x8c400ab7,0x2b4405f5,0x6d41ddaf,0x15441093}},	//   _öğre, _тэтг, _yoma, генм, 
   {{0x1cb008ea,0x6d41ddb0,0x6b5400cf,0x2019ddb1}},	//   _ནུས_, _xoma, _vàge, _ossi_, 
   {{0x6d982815,0x4870001f,0x6dac0139,0xc914011a}},	//   líac, ችኋለሁ_, _oşan, _תחנת_, 
   {{0x7760004b,0x1ae40183,0xd25001d9,0x00000000}},	//   _umnx, প্ৰা, ٕنس_, --, 
   {{0x2018d34f,0x6d982d3f,0x2d7800f3,0x6f1c014f}},	//   _assi_, níac, hčea_, _rarc, 
   {{0x6f1dddb2,0x02bc1f13,0x6dadddb3,0x64580003}},	//   _sarc, ्रॉन, _aşan, _żwie, 
   {{0xd1740032,0xd025ddb4,0x4cd00154,0xdedc0023}},	// [35ae0] _ҡымы, ымай, _হালু, ሕጸን_, 
   {{0x6d41ddb5,0x6f1c014f,0x4ed0015b,0x6dac03b9}},	//   _soma, _qarc, াল্ল, _ağap, 
   {{0x6f1dddb6,0x2019ddb7,0xdb000140,0x60980092}},	//   _varc, _essi_, _kilæ, _ቆንጂት_, 
   {{0x6f1dddb8,0x6d414a0a,0x6d987917,0x661c013c}},	//   _warc, _qoma, díac, ærki, 
   {{0x0b8821ca,0x6d4029ef,0xac19ddb9,0x6f1dddba}},	//   нски_, _voma, толу_, _tarc, 
   {{0x6f1dc450,0x6d41c663,0xdb080e89,0x00000000}},	//   _uarc, _woma, _steò, --, 
   {{0x2be0060c,0x693401f0,0x6b540241,0xaa946d64}},	//   _निका, инку, _pàgb, шикч, 
   {{0xdb00066d,0x5e640137,0x6d4001f4,0xa3e4230e}},	//   _vilá, _ئچكە, _uoma, _पटल_, 
   {{0xcaf49cf0,0x3eb40200,0x00000000,0x00000000}},	//   _مساب, _çetë_, --, --, 
   {{0xdb0000d8,0x6b540241,0x49940139,0x94dc03b9}},	//   _tilá, _wàgb, _өшет, mçək_, 
   {{0x48e42c0b,0xe6950bed,0x6d98215a,0x6b540241}},	//   _боев, рины, cíac, _tàgb, 
   {{0xc8b400c6,0xe3c401c6,0x00000000,0x00000000}},	//   _إصاب, иргү, --, --, 
   {{0x67d443e8,0x6fb00c2e,0xc6a400d1,0x261000c5}},	//   _толу, _अंगू, _өрки, _तनकी_, 
   {{0x77f4025f,0x7c2c0077,0x20180334,0x7bdc00d8}},	//   _עמוד_, _ácre, _rssi_, áqui, 
   {{0x31c50275,0x659400c9,0xf365ddbb,0x62240131}},	//   йств, _каку, стян, جىزل, 
   {{0x2018a324,0x204402d3,0x6d580d47,0xd5b80037}},	//   _pssi_, _ዘመልክ, ëval, _ईंतज, 
   {{0xc05800d6,0x2be00abd,0x45d01c5c,0x62340276}},	// [35af0] хів_, _निगा, _тоқс, _ӂену, 
   {{0x4dc01870,0x00000000,0x00000000,0x00000000}},	//   ﺭﻛﯩﻨ, --, --, --, 
   {{0xb7c00276,0x636809a8,0x9df8008e,0xbf9800e4}},	//   ăţil, lžno, тнет_, _opêv, 
   {{0x20180211,0xdb000139,0x2be095d6,0x00000000}},	//   _tssi_, _kilç, _निखा, --, 
   {{0x645c0007,0x9f480589,0x20180254,0x6dac03e0}},	//   nzsi, guaã_, _ussi_, _işal, 
   {{0x60cdddbc,0x29040af9,0xdb0003b9,0x15e40c5a}},	//   lbam, efma_, _milç, _किलर_, 
   {{0xba75ddbd,0x2d7801a6,0x2614473c,0xaa6400fb}},	//   داشت, mčen_, _फैली_, йешһ, 
   {{0x6d980005,0x60cc0198,0x23b40764,0x2d780010}},	//   ríac, nbam, ंदाद, lčen_, 
   {{0x6d981dec,0x60cc022f,0x399000c7,0x59d00037}},	//   síac, ibam, sãso_, _सबकर, 
   {{0x2d78e045,0x15b8013d,0x00000000,0x00000000}},	//   nčen_, кымы_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x94240209,0x60cc1710,0x00000000,0x00000000}},	//   амме, jbam, --, --, 
   {{0x6b5401ab,0x00000000,0x00000000,0x00000000}},	//   _hàga, --, --, --, 
   {{0x6dac0166,0x60cc003a,0xdb01282a,0x00000000}},	//   _aşal, ebam, _dilç, --, 
   {{0xdb0003f2,0x00000000,0x00000000,0x00000000}},	//   _tilæ, --, --, --, 
   {{0x92d403f4,0x90c5ddbe,0x86780375,0xdb0000a2}},	//   হলে_, рбае, _ברצו, _hilä, 
   {{0x657c00dd,0xdb000598,0xd04403e3,0x81d00154}},	// [35b00] érhe, _kilä, _yekə, হংগ_, 
   {{0x60cc198f,0x9248020a,0x6dadddbf,0x86206786}},	//   abam, _азоб_, _eşal, _اکیل, 
   {{0x60cdddc0,0x98ac01a6,0x06d800cc,0xdb00008e}},	//   bbam, bjeć_, _দামি, _milä, 
   {{0x79880770,0xdb080579,0xdb0001b8,0xdde8583f}},	//   _nkgw, _steð, _lilä, ارله_, 
   {{0x0c7400d1,0x00000000,0x00000000,0x00000000}},	//   جداد, --, --, --, 
   {{0x69dc02bf,0xd90c1893,0x1614012c,0xdb00008e}},	//   _ærek, ہیم_, तबार_, _nilä, 
   {{0x248402d3,0xaca40248,0xbacc0154,0x00000000}},	//   _ሓድሕድ_, _irọp, _রাখছ, --, 
   {{0x8c440598,0x61e000e5,0x00000000,0x00000000}},	//   _кебе, álli, --, --, 
   {{0xdce822c1,0xdb01ddc1,0x06d800bd,0x9f480270}},	//   _sjeć, _bilä, _দাবি, luaá_, 
   {{0xc6a45026,0xdb00d398,0x6b540e89,0x244c01e1}},	//   ирни, _cilä, _fàga, _lómú_, 
   {{0xdb017937,0x093411c7,0x2904b040,0x26cc0477}},	//   _dilä, _پراج, pfma_, rbdo_, 
   {{0x99740775,0x98580882,0xdce80841,0x645c002f}},	//   _лучш, ṇān_, _vjeć, tzsi, 
   {{0xa4140729,0x60cc12fe,0xdb00007c,0x645c0489}},	//   াম্য_, vbam, _filä, uzsi, 
   {{0x838456a4,0x35f404fb,0x38980a1e,0x91e400b5}},	//   рыме, درید_, _סיגנ, raのu, 
   {{0x6dac6648,0x2d7809a8,0x2be00ce0,0x25e001ad}},	//   _aşam, včen_, _निझा, _किटी_, 
   {{0xdb000793,0xb89000db,0x04640212,0x63a8017a}},	//   _zilä, _الۇع, _втом, ïenb, 
   {{0xe2980220,0x92d40183,0x00000000,0x00000000}},	// [35b10] таң_, _হাৰ_, --, --, 
   {{0x2be0024a,0x2d7805be,0x3ec5ddc2,0x00000000}},	//   _निजा, učen_, рсаб, --, 
   {{0x2d781a48,0xf19002dd,0x9cb40116,0x2bd40c22}},	//   rčen_, _ﺒﻌﺩﻡ_, ممات, ठीसा, 
   {{0x61159e50,0x61f41432,0xb2f40327,0x00000000}},	//   _удму, muzl, _བཐོང_, --, 
   {{0x9a6c0125,0xf1a5ddc3,0x8cc4012d,0xc0580150}},	//   ስራኤል_, _фрэн, ाड़ो, _рін_, 
   {{0x6b740323,0xab642626,0x9e341507,0x6b55ddc4}},	//   олчу, овіл, _легч, _pàga, 
   {{0x61f41b0d,0x798802d0,0xfd10009f,0x60100248}},	//   nuzl, _pkgw, _وجر_, bómò, 
   {{0x991400d6,0xdb000139,0x3f900200,0x00000000}},	//   ські, _silä, llxu_, --, 
   {{0xccf00375,0xad240131,0x9f4805c7,0xdc540120}},	//   _מכן_, _بىقى, ltañ_, _увањ, 
   {{0x6d980077,0x6b5400e8,0x9f480165,0xdb014816}},	//   nían, _tàga, otañ_, _bilå, 
   {{0x9f4807e4,0xe81c0c2e,0xdb000793,0x7bc80175}},	//   ntañ_, _बैठा_, _vilä, lpgu, 
   {{0x61f5ddc5,0x2d78009b,0xdb000166,0x00000000}},	//   duzl, jčel_, _wilä, --, 
   {{0x97c40eff,0x114802dd,0x58a40183,0x00000000}},	//   _اقتو, қпай_, _গ্ৰী, --, 
   {{0x2be00157,0xe3b00014,0x290003a2,0x61f41571}},	//   _निघा, ِرِ_, _ñiar_, fuzl, 
   {{0x1544ed5a,0x6d9854fc,0x661c00b5,0x61f40432}},	//   _гейм, dían, ærkt, guzl, 
   {{0x31bc00dd,0x9c7c002e,0x00000000,0x00000000}},	//   _víz_, _ndōo, --, --, 
   {{0x41240c04,0xaca401f2,0x63a806af,0x9378fe06}},	// [35b20] щото_, _prọp, ïenc, _مصدر_, 
   {{0x52741624,0xe7f800af,0x31bc01ed,0xf7e00131}},	//   _гуму, ंढता_, _tíz_, _ﺋﻪﻟﻪ, 
   {{0x0d740244,0x95701ef7,0x00000000,0x00000000}},	//   میسک_, _ብረትን_, --, --, 
   {{0x626401ec,0xfe4001c6,0x00000000,0x00000000}},	//   _گاۋق, янхо, --, --, 
   {{0x8fd00348,0x6d980077,0x19e00150,0x8b2400db}},	//   _хәбә, bían, _ﺍﻹﻨﺠ, йдде, 
   {{0x6d98056a,0x0ae8a3a9,0x00000000,0x00000000}},	//   cían, ارشي_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x205c001f,0xe94400e5,0x9f480d12,0x3ea400c7}},	//   _ለመቅረ, ترتی, ltað_, ýnte_, 
   {{0x1cb007e4,0x0ae80451,0x8afc03f9,0x2d7800f3}},	//   _ནུག_, _مرضي_, hiƙi, nčem_, 
   {{0x9f4808a7,0x00000000,0x00000000,0x00000000}},	//   ntað_, --, --, --, 
   {{0xb0b800c5,0xa2b9ddc6,0x00000000,0x00000000}},	//   _अलंग, ्डस्, --, --, 
   {{0xd1080d41,0x61f4c633,0x69c8010e,0xfbcc012d}},	//   ह्मण_, vuzl, _itde, सीकम, 
   {{0x6dac0209,0x9f48148b,0x00000000,0x00000000}},	//   _aşak, ktað_, --, --, 
   {{0x661c04ce,0x6b54004e,0x61f401fa,0x6d980077}},	//   ærks, _màgo, tuzl, xían, 
   {{0x6d982b76,0xa3e40316,0x2c0409bd,0xd76400e5}},	//   vían, _पटक_, লিয়ে_, _بانٹ, 
   {{0x408400db,0x00000000,0x00000000,0x00000000}},	//   бузб, --, --, --, 
   {{0x03f02b88,0x61f4f740,0x6d980077,0xdbf000bc}},	// [35b30] _བཀྲམ_, suzl, tían, _příh, 
   {{0x69c8415b,0x61f42791,0x9f48032e,0x00000000}},	//   _otde, puzl, gtað_, --, 
   {{0x6d99ddc7,0x7de40220,0x9f480156,0x38ac03e0}},	//   rían, сізд, utañ_, _körü_, 
   {{0x9f49ddc8,0xeea80228,0x00000000,0x00000000}},	//   mraí_, стук_, --, --, 
   {{0x1b180b7e,0x69c800e2,0x9f49ddc9,0x90e400f1}},	//   ижды_, _atde, stañ_, _بسپن, 
   {{0x7528005f,0x9f49ddca,0x201c031c,0x00000000}},	//   ēdzi, ptañ_, ħwid_, --, 
   {{0x9f4806d5,0x69c80175,0x998406c5,0xec680166}},	//   nraí_, _ctde, يلتو, ирәк_, 
   {{0x57e9ddcb,0x7cec01e1,0x3eb80153,0x00000000}},	//   адим_, _dòrà, šytą_, --, 
   {{0x8afc02a8,0x69c800a2,0xe81c000d,0x9f480332}},	//   ziƙi, _etde, _बैदा_, hraí_, 
   {{0x7b7453e2,0x6b54002e,0x49d8c303,0x00000000}},	//   _اطرا, _jàgl, _چانگ_, --, 
   {{0xb8fc03f4,0xf8bc9936,0x7f44014f,0x49d80451}},	//   _তা_, ñés_, _mojq, _نانگ_, 
   {{0x7f44014f,0x9f48007b,0x00000000,0x00000000}},	//   _lojq, draí_, --, --, 
   {{0xdee4044e,0x6d980077,0x661c03cd,0x782401e2}},	//   _ምስኡ_, díal, ærkr, _دعال, 
   {{0x163800c6,0xf00401c0,0xd1c82309,0xd334084c}},	//   _نسبة_, үүни, илге_, цэмы, 
   {{0x9f480597,0xdb0003b2,0xe77801ed,0x1544004e}},	//   graí_, _bilú, _دلوں_, _мекм, 
   {{0x3cfc0218,0x38ac15b7,0x8e380236,0x00000000}},	//   _ncuv_, _görü_, یسار_, --, 
   {{0x9f49263b,0x0fd86d59,0xdb00021c,0x92b42761}},	// [35b40] ttað_, рьбы_, _dilú, _وحدا, 
   {{0xb358066d,0x7525ddcc,0x3d29ddcd,0xcee8084c}},	//   _ایسا_, _haiz, یتنی_, рдже_, 
   {{0x7524019b,0x7f44047e,0x9f49ddce,0x8d6402bf}},	//   _kaiz, _dojq, rtað_, овже, 
   {{0x9f4805a4,0x75259739,0x6d980077,0x2d780030}},	//   stað_, _jaiz, cíal, mček_, 
   {{0x7525ddcf,0x4c149262,0x2d7999ea,0xcfa81fb8}},	//   _maiz, تباس, lček_, _ناسم_, 
   {{0x7525ddd0,0xbb400063,0xc9e801a9,0x00000000}},	//   _laiz, дељк, афид_, --, 
   {{0x2d78994e,0x6d980789,0xdee40023,0x4ac400cd}},	//   nček_, líam, _ምስኣ_, रुषव, 
   {{0x7525ddd1,0x00000000,0x00000000,0x00000000}},	//   _naiz, --, --, --, 
   {{0x6d982760,0xc7642374,0x00000000,0x00000000}},	//   níam, قادى, --, --, 
   {{0x75240099,0xc7640aaf,0x4dec00e1,0xed5801b9}},	//   _aaiz, تابى, _चटाई_, _тоғ_, 
   {{0x7525ddd2,0x2d786185,0x69c8ce29,0x65940246}},	//   _baiz, jček_, _utde, зану, 
   {{0x75240399,0x6dac0213,0x2d780010,0x89a401d3}},	//   _caiz, _ağaz, dček_, _بھتہ_, 
   {{0x75240399,0x6d9800eb,0x636809a8,0x68e1ddd3}},	//   _daiz, víal, lžni, mamd, 
   {{0x68e1ddd4,0x6d987d3d,0xdb000077,0x9f48007b}},	//   lamd, díam, _silú, traí_, 
   {{0x7525ddd5,0x7f44014f,0x63680010,0x38ac0139}},	//   _faiz, _rojq, nžni, _törü_, 
   {{0x9f480491,0x752401c0,0x7f440455,0xb1a400d4}},	//   rraí_, _gaiz, _sojq, дшук, 
   {{0x656dddd6,0xdb00043b,0x9f48007b,0x7f440477}},	// [35b50] _imah, _vilú, sraí_, _pojq, 
   {{0x68e08590,0x752405f5,0x26dc0427,0x2d788c05}},	//   hamd, _zaiz, _jevo_, bček_, 
   {{0xc32c08c9,0x656c003e,0x75240433,0x26ddddd7}},	//   _كەڭ_, _kmah, _yaiz, _mevo_, 
   {{0x26dc5946,0x6d98f466,0x6114ae2e,0x5f44179e}},	//   _levo_, bíam, _эдму, _کنسل, 
   {{0x656d7b4e,0xad242e51,0x6d980a90,0x7f44014f}},	//   _mmah, بىنى, cíam, _tojq, 
   {{0x8b208986,0x656c089c,0x60dc047e,0x26dcc9d5}},	//   едше, _lmah, _hesm, _nevo_, 
   {{0x656dddd8,0x60ddddd9,0x68e1ddda,0x5e58007b}},	//   _omah, _kesm, famd, _الأس_, 
   {{0x26dc16b8,0xceb00375,0x27e401ab,0xf27c05d0}},	//   _aevo_, _טים_, fsmn_, ירוש, 
   {{0x60dddddb,0x7525dddc,0x26dc0395,0x6dac0139}},	//   _mesm, _raiz, _bevo_, _aşaw, 
   {{0x656ddddd,0x60ddddde,0x752405b8,0x70b805d7}},	//   _amah, _lesm, _saiz, _अल्ल, 
   {{0x26dddddf,0x7524006f,0x656c0175,0x6dac00ac}},	//   _devo_, _paiz, _bmah, _ağay, 
   {{0x60dc02fb,0x68e10967,0x2d7901bd,0x25dc01ad}},	//   _nesm, camd, vček_, _खबरी_, 
   {{0x7525dde0,0x395c8ce1,0xd7c8006c,0x06d8015b}},	//   _vaiz, mhus_, _اوته_, _দারি, 
   {{0x656ddde1,0x7525dde2,0x60dc02d0,0x6d98dd69}},	//   _emah, _waiz, _aesm, víam, 
   {{0x60dddde3,0x7525dde4,0xd1e8001f,0x515402dd}},	//   _besm, _taiz, ህፈት_, птау, 
   {{0x2d78955b,0x3e34001f,0x00000000,0x00000000}},	//   rček_, _የሚያከ, --, --, 
   {{0xb4d80d5f,0x0080bf73,0x26dc0139,0x8ee8003b}},	// [35b60] िरी_, елто, _yevo_, ймав_, 
   {{0x656c00c6,0x60dc007d,0x6d98af16,0x2d783883}},	//   _zmah, _eesm, ríam, pček_, 
   {{0x395c049f,0x68e1c4b1,0xb520000d,0x00000000}},	//   khus_, yamd, _बसाय_, --, 
   {{0x60dc5b5e,0x9f480589,0x395c00b5,0x68e1226e}},	//   _gesm, traã_, jhus_, xamd, 
   {{0x395ddde5,0x68e1dde6,0x997400ef,0x2ab80108}},	//   dhus_, vamd, _bāž_, олль_, 
   {{0x395c12e8,0x3b5000d4,0x60dc013a,0x00000000}},	//   ehus_, нкір, _zesm, --, 
   {{0x433c02d3,0x68e003ee,0x7c28a98d,0x06d8009e}},	//   _ኣገባባ, tamd, avgr, _দালি, 
   {{0x8b645d35,0x395ddde7,0x6dac0139,0x26dddde8}},	//   _کارم, ghus_, _aşav, _sevo_, 
   {{0x68e0357f,0x478936a4,0x4428867c,0xf8000006}},	//   ramd, йсом_, xvc_, нчэн, 
   {{0x68e1dde9,0x6dac06be,0x656c00d0,0x99740171}},	//   samd, _ağax, _smah, _gāž_, 
   {{0x26dc030a,0xe7e8007d,0x395dddea,0x00000000}},	//   _vevo_, _टटका_, bhus_, --, 
   {{0x395dddeb,0xc7c40108,0x68e1ddec,0x00000000}},	//   chus_, _ески, qamd, --, 
   {{0x1cb008ea,0x60dddded,0x8afc0198,0x27680133}},	//   _ནུབ_, _resm, siƙu, _وشتی_, 
   {{0x60dc34b0,0x69dc28b3,0xf74026dc,0x7178086c}},	//   _sesm, _æres, _печо, җбур_, 
   {{0x60ddddee,0x67394e8c,0xa195ddef,0x00000000}},	//   _pesm, _invj, давч, --, 
   {{0xf6780302,0x60dc014f,0x6728007c,0xf2c4009d}},	//   _לאומ, _qesm, lddj, _үсэн, 
   {{0x60ddddf0,0xca7801d5,0x00000000,0x00000000}},	// [35b70] _vesm, _intе, --, --, 
   {{0x657dddf1,0xe3a45533,0x395c0156,0x00000000}},	//   lnsh, _تشبی, zhus_, --, 
   {{0xdd901c3b,0x395c072b,0x00000000,0x00000000}},	//   نڈر_, yhus_, --, --, 
   {{0x657dddf2,0x5c740d44,0x62842d2f,0x1cb0031c}},	//   nnsh, млет, _ixho, _ནུད_, 
   {{0x657c062c,0x45240f22,0x395c28b3,0x21381368}},	//   insh, যাপক_, vhus_, _insh_, 
   {{0x20080006,0x657c0327,0x7c28007c,0x00000000}},	//   mtai_, hnsh, rvgr, --, 
   {{0x395dddf3,0x2009d446,0x6dac0166,0x1ea80451}},	//   thus_, ltai_, _aşau, _گاڏي_, 
   {{0x17c862bd,0x628401e2,0xdce809a8,0x8ca80034}},	//   огии_, _mxho, _kmeč, जेहो, 
   {{0x395c1fcd,0x98bc0034,0xed0401ec,0xbec400ef}},	//   rhus_, _nową_, _سولپ, _ezīš, 
   {{0x657dddf4,0x2009ddf5,0xb6040122,0x62840472}},	//   ensh, itai_, _naší, _oxho, 
   {{0x395dddf6,0x7ae06bfc,0x79a40209,0x628400d8}},	//   phus_, mant, _ерде, _nxho, 
   {{0x20080953,0x2129ddf7,0x61f405a1,0xb4d806ff}},	//   ktai_, jdah_, drzl, िरे_, 
   {{0x2129ddf8,0x628401b3,0x6b5401ab,0x69dc0158}},	//   ddah_, _axho, _bàgh, _ærer, 
   {{0x21282a1f,0x657dddf9,0x1cb0025c,0x00000000}},	//   edah_, ansh, _ནུན_, --, 
   {{0x2d78107d,0x7ae0021c,0xdb004d5b,0x21280327}},	//   mčev_, iant, _chlé, fdah_, 
   {{0x7ae1ddfa,0x2d1c0574,0x7bd804ba,0x2128011f}},	//   hant, _नसेल_, _owuu, gdah_, 
   {{0x6285ddfb,0x7bd8020c,0xd2b80276,0x4fe841e5}},	// [35b80] _exho, _nwuu, _мунч_, юман_, 
   {{0x2d781aff,0x21280548,0x316001a9,0x00000000}},	//   nčev_, adah_, shiz_, --, 
   {{0x7ae11b81,0x7bd81418,0x200819f3,0x2129ddfc}},	//   dant, _awuu, atai_, bdah_, 
   {{0x2b0002e5,0x7ae01368,0xf42c0327,0x92d40154}},	//   _राहु_, eant, _སློད_, _হায়_, 
   {{0x7c81ddfd,0x6b5400cf,0xdb00012c,0x62840472}},	//   куше, _hàgi, _zhlé, _zxho, 
   {{0x6dac008e,0x91040139,0x00000000,0x00000000}},	//   _aşat, _эчүд, --, --, 
   {{0x7bd81418,0xdce80427,0x00000000,0x00000000}},	//   _ewuu, _zmeč, --, --, 
   {{0xbea0e29b,0x6b5400f7,0xb4d80864,0x00000000}},	//   _раск, _màgi, िरो_, --, 
   {{0x7ae02ffc,0x28140137,0x79a000a7,0xfce00334}},	//   bant, رودس, ърше, _шото, 
   {{0xddc8084c,0x94f8031c,0x657c9b75,0x21280427}},	//   _înţe, ནཔའི_, wnsh, zdah_, 
   {{0x6b54002e,0xbb41ddfe,0x2008005a,0x2128014f}},	//   _nàgi, _шефк, ztai_, ydah_, 
   {{0xdb0093b8,0x2009ddff,0x657dde00,0x61f42630}},	//   _milý, ytai_, unsh, vrzl, 
   {{0x6b540268,0x2128a720,0xdb01de01,0xb60401ef}},	//   _pàgh, vdah_, _shlé, _paší, 
   {{0xb9f80201,0xa1380020,0xdb00007b,0xdb1802e2}},	//   _መቶ_, _አለመሆ, _phlé, lpwò, 
   {{0xb6040122,0xdce8013a,0x00000000,0x00000000}},	//   _vaší, _smeč, --, --, 
   {{0x2009de02,0xc1780212,0x00000000,0x00000000}},	//   ttai_, іїв_, --, --, 
   {{0x7ae1de03,0xc05810f5,0x2129a207,0xf1940b32}},	// [35b90] yant, ців_, rdah_, тить, 
   {{0x7ae01574,0x2009de04,0x62840190,0xdb000209}},	//   xant, rtai_, _txho, _bilý, 
   {{0x2009de05,0x7ae0b180,0x628400f1,0xf1c40306}},	//   stai_, vant, _uxho, raší_, 
   {{0x7ae1de06,0x20080006,0xdfd4005b,0x2128014f}},	//   want, ptai_, _помы, qdah_, 
   {{0x2008036b,0x7ee400a7,0x6dac0139,0x1c39ab0d}},	//   qtai_, _оцве, _aşas, язды_, 
   {{0xdce801a6,0x7ae0ca67,0x9af433d2,0x6d58036e}},	//   _vjeđ, uant, ركعت, ëvar, 
   {{0x7ae1de07,0xdb01de08,0x1cb00327,0x2d780010}},	//   rant, _gilý, _ནུམ_, včev_, 
   {{0xe9a8384b,0x6e6801d9,0xd824011c,0xfd200345}},	//   ودين_, _کمہِ_, едии, _جورێ, 
   {{0xdb000724,0x9f48010e,0x00000000,0x00000000}},	//   _kilü, graç_, --, --, 
   {{0x7ae1de09,0xd70805cc,0xb4d80882,0xdb0c0241}},	//   qant, чное_, िर्_, _ìkàw, 
   {{0x6dac71e1,0xcf9006a9,0x79c4036b,0xd5e4009d}},	//   _işar, רטי_, _ўқиб_, эжни, 
   {{0xceb0008f,0x9f48004e,0x00000000,0x00000000}},	//   טיי_, braç_, --, --, 
   {{0x7999356e,0x00000000,0x00000000,0x00000000}},	//   mluw, --, --, --, 
   {{0x6b55de0a,0x6d980407,0xdb000790,0x9c7c010e}},	//   _pàgi, ríai, _nilü, _geōe, 
   {{0xff8c01f2,0x03a0023a,0x7584008e,0x05c40118}},	//   ọọkw, уиро, _аңна, _रूपब, 
   {{0xdb01de0b,0x3f800de2,0x6b5400cf,0xfc4400bc}},	//   _kiló, _ajju_, _vàgi, _klíč_, 
   {{0x6dac0139,0xe7cc010f,0xcef4033a,0x00000000}},	// [35ba0] _oşar, ַצאָ, ечењ, --, 
   {{0xdb000793,0x799801ee,0x9fb40118,0x03d4010f}},	//   _cilü, hluw, _přál_, _רוים_, 
   {{0xdb0153fb,0xe2c8868d,0x2b4c007c,0x799838f2}},	//   _liló, _توپو_, _rodc_, kluw, 
   {{0x6dad2d65,0xc8f800eb,0x00000000,0x00000000}},	//   _aşar, _আস্ত_, --, --, 
   {{0xe50437d0,0xdb01de0c,0xdd8c0131,0x79980327}},	//   ष्टि_, _niló, زۈك_, dluw, 
   {{0xbb40ef44,0x799800e8,0xec3401b9,0x46080327}},	//   лечк, eluw, _یوزگ, _ཀྱྀས_, 
   {{0xbea1de0d,0x1e940021,0x443c004d,0x799918bd}},	//   _барк, _артр, ̣u_, fluw, 
   {{0x7999de0e,0xd90c31d6,0xdb000429,0x6dad2c31}},	//   gluw, قیم_, _biló, _eşar, 
   {{0xd90c2b09,0xdb0000d2,0x39100124,0x00000000}},	//   تین_, _ciló, умыр, --, 
   {{0x5ba40046,0x98bc0210,0x00000000,0x00000000}},	//   _алуғ, _mowę_, --, --, 
   {{0x391002dd,0xa4d40212,0x79981bce,0xdb0c0248}},	//   _әмір, коні, bluw, _ìkáw, 
   {{0xdb0067c9,0xcfd001ec,0x00000000,0x00000000}},	//   _filó, _ﺘﻨﻁﺒ, --, --, 
   {{0x38c8168d,0xf4841b10,0x6dac0432,0x2bd40f4a}},	//   _رانی_, гурн, _yşar, ठीचा, 
   {{0xb41400ec,0xdee00092,0x00000000,0x00000000}},	//   اڻيڪ, ነቷን_, --, --, 
   {{0xd0540cc1,0xdb010976,0x443c054e,0xa2940024}},	//   mayə, _kilò, ţu_, таві, 
   {{0xd05400ac,0xdb0003e0,0x00000000,0x00000000}},	//   layə, _silü, --, --, 
   {{0x442c427e,0x5f9459df,0x00000000,0x00000000}},	// [35bb0] _ég_, виат, --, --, 
   {{0xd05403be,0x2d843a4a,0x7c2c0077,0xdb000139}},	//   nayə, _ajme_, _ácri, _qilü, 
   {{0x25a80067,0xf770008f,0x6dac06be,0x00000000}},	//   _khal_, נקע_, _aşaq, --, 
   {{0x9cb40050,0x1bd4769a,0x7c8c02d3,0xd05400ac}},	//   نمات, водя, _ክሓልፍ_, hayə, 
   {{0xd05403be,0x2bc80220,0x25a9d561,0x26e006e3}},	//   kayə, еліп_, _mhal_, _खजूर_, 
   {{0x20180483,0x799800e8,0x25a801ef,0x00000000}},	//   _ipsi_, wluw, _lhal_, --, 
   {{0xee840a8f,0x7999de0f,0xdd9401c0,0x38c401e1}},	//   _быто, tluw, _аавы, _níró_, 
   {{0x991400d6,0x20180263,0xd7c8969f,0xef10004b}},	//   тькі, _kpsi_, ووبه_, _پټې_, 
   {{0xd05400ac,0xe7b40024,0x7c840640,0x799800f2}},	//   fayə, _šešė, _чуве, rluw, 
   {{0x25a848ae,0x79980784,0x20180129,0x38c401d3}},	//   _ahal_, sluw, _mpsi_, _bíró_, 
   {{0xdb01de10,0x7999563b,0x25a80003,0xead40354}},	//   _filò, pluw, _bhal_, _сохь, 
   {{0x2018487c,0xd7f5a55a,0x25a8016d,0xdb0000d2}},	//   _opsi_, _азды, _chal_, _tiló, 
   {{0x25a99af9,0x181800f2,0x67d4014b,0x00000000}},	//   _dhal_, _زرشک_, _бочу, --, 
   {{0xd044013f,0x638401e0,0x394c2517,0xdb00013a}},	//   _mekɔ, лҡым_, _hogs_, _ohlí, 
   {{0x25a801ab,0x2489de11,0x95c801b9,0x20180254}},	//   _fhal_, _exam_, _ўлиб_, _apsi_, 
   {{0x25a8003d,0xdb00004e,0x449000b4,0x217401c6}},	//   _ghal_, _xilò, ụsụ_, гуур, 
   {{0x3f900c5e,0x00000000,0x00000000,0x00000000}},	// [35bc0] foxu_, --, --, --, 
   {{0x394c4a5a,0x25a8007f,0x27e00bbc,0xd37002f2}},	//   _logs_, _zhal_, _çine_, _ئێسک, 
   {{0xdb00013a,0x00000000,0x00000000,0x00000000}},	//   _chlí, --, --, --, 
   {{0xdb00007b,0x1ea83c19,0x00000000,0x00000000}},	//   _dhlí, رالي_, --, --, 
   {{0x0b881b10,0xf1b4012c,0x2d8c004e,0x20180254}},	//   мски_, ंगठन, _ídem_, _gpsi_, 
   {{0x2ca40010,0x6dac0356,0x00000000,0x00000000}},	//   _vzmd_, _eşap, --, --, 
   {{0xe8f80184,0xdb006f90,0xd05400ac,0x63a80af9}},	//   еһе_, _pilò, vayə, ïeni, 
   {{0xdb09de12,0xf98dde13,0x394c0204,0x2d8402f0}},	//   _dueñ, يبي_, _cogs_, _ujme_, 
   {{0xc17006a9,0x6dac03be,0xaf4c001f,0x394cde48}},	//   יחה_, _uşaq, _በማስገ, _dogs_, 
   {{0x25a801d5,0x00000000,0x00000000,0x00000000}},	//   _shal_, --, --, --, 
   {{0x09048e34,0xf76c04d3,0xdb08005a,0xd0540213}},	//   _апен, ڵای_, _gueñ, rayə, 
   {{0x6d980077,0x394d4f22,0xa3d401b9,0xab9c0092}},	//   mías, _gogs_, ломч, ልፈዋል_, 
   {{0x622415bf,0x33f40108,0x00000000,0x00000000}},	//   گىزل, ичёс, --, --, 
   {{0x6b54004e,0x2480001f,0x00000000,0x00000000}},	//   _tàgu, _የዕለት_, --, --, 
   {{0x31c421ca,0x20188106,0x661801c4,0x6594121c}},	//   иств, _spsi_, _upvk, _йаку, 
   {{0xc058005e,0x29040652,0x248801d4,0x25a801c4}},	//   міз_, ngma_, _txam_, _uhal_, 
   {{0xd7240c58,0xd0540134,0x83a800cf,0x9e7400ec}},	// [35bd0] বাৰা_, mayɛ, _отоб_, گهات, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa1580107,0x00000000,0x00000000,0x00000000}},	//   _зану_, --, --, --, 
   {{0xeea80228,0x6d980587,0xff5c0311,0x6e94009d}},	//   ттук_, días, _atît_, шиху, 
   {{0xdb09de14,0x60cc07d0,0x2019de15,0xf04400a8}},	//   _sueñ, mcam, _upsi_, _кэро, 
   {{0x2ca00086,0xaed40024,0x00000000,0x00000000}},	//   üida_, _ворш, --, --, 
   {{0xdb005ec6,0x2e2c0332,0x00000000,0x00000000}},	//   _uhlí, rófá_, --, --, 
   {{0x6bd403e6,0x26cc0009,0xa3b40073,0xe3d800eb}},	//   اتۆر, ecdo_, जगड_, _তিনব, 
   {{0x76d4013e,0x6d9800e4,0x00000000,0x00000000}},	//   кунӣ_, ríat, --, --, 
   {{0x6d980005,0x247c0023,0x00000000,0x00000000}},	//   bías, _ኣስራት_, --, --, 
   {{0x394dde16,0x6d98056a,0x00000000,0x00000000}},	//   _togs_, cías, --, --, 
   {{0xd4680276,0x26cc0009,0xe874036b,0x52bc1fd2}},	//   еиме_, acdo_, انیگ, ्ड्स, 
   {{0x24700201,0xde500198,0x60cc7881,0x00000000}},	//   _ትኩረት_, rƙƙa, dcam, --, 
   {{0x73c40184,0x60cc005a,0x00000000,0x00000000}},	//   ләүе, ecam, --, --, 
   {{0xe708004b,0x60cc0334,0x10802d40,0x00000000}},	//   _شتون_, fcam, ﻩﺭﺩﯨ, --, 
   {{0x60cdde17,0x412400db,0xf7700133,0xb4040ce8}},	//   gcam, лосо_, _حاڵ_, _күмд, 
   {{0xc9500375,0x935800f3,0x00000000,0x00000000}},	// [35be0] זמן_, _зрну_, --, --, 
   {{0xdd9802e2,0x6b54067c,0xb8ec025c,0x00000000}},	//   _akň_, _làgr, _ྱུ_, --, 
   {{0x6d980077,0x1fb401f4,0x21ac0150,0x91e400d4}},	//   xías, рстр, _ﺳﯟﺍﺭ, _щоне, 
   {{0xaff868e7,0x0ca9310f,0x0d841e76,0x6d980077}},	//   _لہرا_, нтли_, ылен, vías, 
   {{0xdb000e89,0x323001ec,0x00000000,0x00000000}},	//   _bhlà, _ءﯗﺭﯨ, --, --, 
   {{0xaab8765c,0x0ba82309,0xdb000192,0x6d980005}},	//   نگار_, راشى_, _chlà, tías, 
   {{0xa3b4073d,0xbb441dc8,0xf6444138,0x60cc0166}},	//   जगत_, الىن_, _ائ_, _älmö, 
   {{0x6d991c67,0x00000000,0x00000000,0x00000000}},	//   rías, --, --, --, 
   {{0x5d75de18,0xef28002f,0xcba4022e,0x00000000}},	//   _турф, chüß_, _баай, --, 
   {{0x60cc0789,0xdb0001ab,0xbc18008f,0x26cc0009}},	//   zcam, _ghlà, _אומש, ucdo_, 
   {{0x4904275c,0xba1406f6,0xe97001d9,0xf1b46d65}},	//   _مواق, _ميلا_, _وۆتھ, ंगान, 
   {{0x6595de19,0x69d9de1a,0x60cdde1b,0xd5ac004b}},	//   раму, mpve, xcam, وځي_, 
   {{0xb9902961,0x69d9de1c,0x3f8400b0,0x60cc00d0}},	//   _النب, lpve, ōnui_, vcam, 
   {{0xaca401f2,0x69d801f5,0x7bcc0129,0x60cc033f}},	//   _nsọp, opve, _écue, wcam, 
   {{0x60cdde1d,0x6d40349c,0x20e401f0,0x00000000}},	//   tcam, _onma, исаҳ, --, 
   {{0xaca402e3,0x6d401c06,0x69d801f5,0x60ccac3b}},	//   _asọp, _nnma, ipve, ucam, 
   {{0x49140882,0xdfd1de1e,0x00000000,0x00000000}},	// [35bf0] भ्यो_, زيا_, --, --, 
   {{0x6d41de1f,0xdb000122,0xbe88084c,0x6b840221}},	//   _anma, _ohlá, нсее_, éigl, 
   {{0x60cc0419,0xbea42077,0xff740092,0x8174014b}},	//   pcam, ушай, _በየወሩ_, _банӣ_, 
   {{0x6d400076,0xdb0008c2,0x69c4010f,0xdfd001f7}},	//   _cnma, _shlà, ĉiel, _ويج_, 
   {{0x705805f5,0xdb0000a3,0x69d8017a,0x2d7816a3}},	//   _баяр_, _phlà, epve, rčep_, 
   {{0x6d41de20,0xdb012376,0x9e24104b,0x69a401e0}},	//   _enma, _lilö, _پىرو, ҙлыҡ, 
   {{0xdb000597,0xcb640212,0x00000000,0x00000000}},	//   _chlá, раще_, --, --, 
   {{0xdb000793,0x1c383cc5,0xdebc0023,0x00000000}},	//   _nilö, _избы_, ታይከ_, --, 
   {{0xdb011988,0x69d80b4f,0x9f4806af,0xac180139}},	//   _ehlá, apve, nsaï_, _йоту_, 
   {{0xe8a80184,0x6d98095b,0x9f48030a,0x36400023}},	//   ыбыҙ_, líap, ouañ_, _ንመግዛ, 
   {{0xaa940108,0x00000000,0x00000000,0x00000000}},	//   _лифч, --, --, --, 
   {{0x6d9800e4,0x00000000,0x00000000,0x00000000}},	//   níap, --, --, --, 
   {{0x452400bd,0xb9ec0020,0xa3b00574,0x7bc80097}},	//   যাংক_, _ነህ_, _ओळख_, nqgu, 
   {{0x47d00451,0x395dde21,0x00000000,0x00000000}},	//   _بيور, lkus_, --, --, 
   {{0x91e408e0,0xdb00007c,0x00000000,0x00000000}},	//   робе, _filö, --, --, 
   {{0x395dde22,0x9f480165,0x01602b2e,0x2dc80116}},	//   nkus_, duañ_, оксо, ғқан_, 
  
   {{0xc0e1de23,0x6d400585,0x395c143f,0x00c5de24}},	// [35c00] _ምንም_, _rnma, ikus_, рлук_, 
   {{0x395dde25,0x00000000,0x00000000,0x00000000}},	//   hkus_, --, --, --, 
   {{0x395c007d,0x6d980077,0x02f800d9,0x42f8011a}},	//   kkus_, fíap, _בלימ, _בהיס, 
   {{0x2ca000d8,0x6d9800e4,0x00000000,0x00000000}},	//   üido_, gíap, --, --, 
   {{0xead434d8,0xfbcdde26,0xdb0000c6,0x395d4e10}},	//   боль, وتو_, _shlá, dkus_, 
   {{0x395c005f,0xa26802d3,0x3160005a,0xdb00007b}},	//   ekus_, _ጽልእን_, lkiz_, _phlá, 
   {{0x6d400083,0x00000000,0x00000000,0x00000000}},	//   _tnma, --, --, --, 
   {{0x6d41de27,0x31600dd4,0x395dde28,0x2568002d}},	//   _unma, nkiz_, gkus_, _kûle_, 
   {{0x316001c6,0x00000000,0x00000000,0x00000000}},	//   ikiz_, --, --, --, 
   {{0xab5c00da,0x69d80158,0x2568045f,0xcba401b9}},	//   _biļe, ppve, _mûle_, _тазй, 
   {{0xf76c0a52,0xdb0001b8,0x31602631,0x6b9801b9}},	//   باي_, _pilö, kkiz_, movg, 
   {{0x69c9de29,0x24f80ce8,0x00000000,0x00000000}},	//   _iude, ынмы_, --, --, 
   {{0x69c9de2a,0xdb000793,0x00000000,0x00000000}},	//   _hude, _vilö, --, --, 
   {{0x69c9de2b,0x236401ed,0x69dc025c,0x6b9801d5}},	//   _kude, ólj_, _ħrej, novg, 
   {{0x69c80262,0x75d00311,0x62340108,0x00000000}},	//   _jude, _răzg, щеву, --, 
   {{0x69c9de2c,0x224c01a6,0x9f640790,0x6b98022e}},	//   _mude, ćek_, ştür_, hovg, 
   {{0x69c9de2d,0xdb01de2e,0x63a80549,0x7f040212}},	// [35c10] _lude, _kilô, ïens, иїжд, 
   {{0x69c9de2f,0x657dde30,0x645ce279,0x395c0010}},	//   _oude, lish, mysi, zkus_, 
   {{0x69c931db,0xa195de31,0x645c4dbd,0x75d00276}},	//   _nude, _ганч, lysi, _găzd, 
   {{0x657dde32,0x2568000f,0x00000000,0x00000000}},	//   nish, _fûle_, --, --, 
   {{0x69c9de33,0x645dde34,0x2568000f,0xf538010f}},	//   _aude, nysi, _gûle_, יטאר_, 
   {{0x7dd00135,0xaac42544,0x395c039a,0xdb000051}},	//   _aħse, يتىن, wkus_, _nilô, 
   {{0x69c81570,0x91a81c82,0x9f4800c6,0x395dde35}},	//   _cude, কদৰ্, nsaí_, tkus_, 
   {{0x69c879d0,0x248c068f,0x395c2e03,0x645c0024}},	//   _dude, żemy_, ukus_, kysi, 
   {{0x7d19de36,0x69c9de37,0x6b98022e,0x00000000}},	//   _ibus, _eude, bovg, --, 
   {{0x395dde38,0x69c9de39,0x657d5f6c,0x7c39de3a}},	//   skus_, _fude, eish, _irur, 
   {{0x69c9de3b,0x657dde3c,0x4438022e,0x645c300b}},	//   _gude, fish, _arq_, eysi, 
   {{0x657dde3d,0x645dde3e,0x7c39de3f,0xdb000798}},	//   gish, fysi, _krur, _vilõ, 
   {{0x7d19de40,0x69c80730,0xdb0006d9,0x9478361e}},	//   _mbus, _zude, _filô, усну_, 
   {{0x69c9de41,0x657dde42,0xf66000db,0x25e401f9}},	//   _yude, aish, _мелү, झीही_, 
   {{0x657ccf3a,0x7d1857d2,0x69c9de43,0x645c062c}},	//   bish, _obus, _xude, aysi, 
   {{0x7c39de44,0x2568000f,0x90c457aa,0x44380175}},	//   _orur, _pûle_, сбае, _frq_, 
   {{0x9f4801e7,0x6b9801a9,0xbfc000f3,0x00000000}},	// [35c20] asaí_, yovg, збук, --, 
   {{0x7d19de45,0xfbc818cc,0x3161a991,0x0434011a}},	//   _abus, ादनम, skiz_, _פטיש_, 
   {{0x7c39de46,0x7dd00327,0x44380327,0x9f4800ae}},	//   _arur, _aħsb, _zrq_, csaí_, 
   {{0x69c9de47,0x7c382d8b,0x4c681d0f,0x81c800eb}},	//   _rude, _brur, лиен_, রীহ_, 
   {{0x69c9de48,0x7c3816b8,0x8ba43cc5,0x6b9801a9}},	//   _sude, _crur, бидж, tovg, 
   {{0x69c9de49,0x657dde4a,0x7d19de4b,0x7c380023}},	//   _pude, zish, _ebus, _drur, 
   {{0x6b9801b9,0x645c033f,0x69c80009,0x77e4002b}},	//   rovg, zysi, _qude, _ācaṣ, 
   {{0x69c8072b,0x6e3c007c,0x657dde4c,0xf964008e}},	//   _vude, _irrb, xish, йрый_, 
   {{0x657dde4d,0xdce83d67,0x69c80066,0x7c380023}},	//   vish, _smeć, _wude, _grur, 
   {{0x69c9de4e,0x657dde4f,0x645c13fa,0x7d18036e}},	//   _tude, wish, vysi, _zbus, 
   {{0x657dde50,0x69c80664,0x645dde51,0xf76c01eb}},	//   tish, _uude, wysi, عاً_, 
   {{0x645ca336,0x6dac0356,0x443982a6,0xc4e0141f}},	//   tysi, _aşaz, _prq_, परेख, 
   {{0x657dde52,0x61e40007,0xb7d41291,0x00000000}},	//   rish, _swhl, _هونا_, --, 
   {{0x657dde53,0x83840046,0x9f480332,0x6b8401e7}},	//   sish, сыме, tsaí_, éigh, 
   {{0x657dde54,0xdce853fb,0x62240131,0x75d0054e}},	//   pish, _umeć, غىرل, _păze, 
   {{0x657dde55,0x9f480597,0xdb0c0030,0x1b000154}},	//   qish, rsaí_, ľkéh, ল্পে_, 
   {{0x9f541f5a,0x6e3c02d0,0xdb0c0306,0xe2980131}},	// [35c30] овач, _arrb, žkéh, уаң_, 
   {{0x7d18014b,0x7c380175,0x9f4800a2,0x34940408}},	//   _sbus, _rrur, braý_, _хаьр, 
   {{0x6f1c0204,0xc18001ed,0x44280142,0xaacc0118}},	//   _dbrc, _فیسٹ, lwc_, ाशनक, 
   {{0x6f1c00f3,0x35cc012d,0x6b840115,0x00000000}},	//   _ebrc, _सूफ़, ɩigi, --, 
   {{0x44280af2,0xfbd02cb0,0x8c4005d1,0xf1a40276}},	//   nwc_, ستش_, _öğle, _хрэн, 
   {{0x7d180263,0xcb6403fb,0xab2814fb,0x00000000}},	//   _wbus, жаше_, مسىل_, --, 
   {{0x81c803f4,0x7d180327,0x9d4401e0,0x00000000}},	//   রীর_, _tbus, _һеңд, --, 
   {{0x7d1801b2,0x7c3802d3,0x7c85083a,0x00000000}},	//   _ubus, _trur, _лузе, --, 
   {{0x7c39de56,0xd8880451,0x00000000,0x00000000}},	//   _urur, جھان_, --, --, 
   {{0x75d0084c,0xd77400c6,0xcc8402f2,0x00000000}},	//   _răzb, تابع, _بۆهه_, --, 
   {{0x16a84140,0xeb300137,0xd548034f,0x451000cc}},	//   рвни_, _سۉيد, апне_, িজনক_, 
   {{0x6eac012d,0x7d080051,0x00000000,0x00000000}},	//   _झरसु, nggs, --, --, 
   {{0x7998083a,0x26e40dd4,0x4428009a,0x5fa8190c}},	//   mouw, ñsoù_, gwc_, कताल, 
   {{0x9a780020,0x79980100,0xa89800db,0xe8840006}},	//   _እንዳለ_, louw, _укчу_, _эгіп, 
   {{0x03a1de57,0x6b8400c6,0x6dac013d,0x6f0001e1}},	//   фиро, éigi, _eşay, _lábà, 
   {{0x7998bd73,0x00000000,0x00000000,0x00000000}},	//   nouw, --, --, --, 
   {{0xd00926f5,0x1b002aab,0x630407d6,0xa5640220}},	// [35c40] резе_, ল্যে_, _کوپل, _ءدىن, 
   {{0x7999c43b,0xe0d80107,0x00000000,0x00000000}},	//   houw, ивӣ_, --, --, 
   {{0x644000da,0x79991de1,0x00000000,0x00000000}},	//   ālie, kouw, --, --, 
   {{0x79980a85,0xd008953e,0x39900124,0x00000000}},	//   jouw, _кеме_, pãsy_, --, 
   {{0xead42d35,0x09d00490,0x7999de58,0xbbd001b9}},	//   поль, सऱ्य, douw, وزوغ, 
   {{0x1ec8030d,0x00000000,0x00000000,0x00000000}},	//   ăлçи_, --, --, --, 
   {{0xbea1de59,0x3ea0b8d1,0xe8b400cd,0x00000000}},	//   _жарк, _жирг, ुश्च, --, 
   {{0x7998d6ce,0x00000000,0x00000000,0x00000000}},	//   gouw, --, --, --, 
   {{0x478979e6,0x00000000,0x00000000,0x00000000}},	//   исом_, --, --, --, 
   {{0x8b643a13,0xd1dc044e,0x79980a73,0x00000000}},	//   _بارم, ሕሪት_, aouw, --, 
   {{0x79982da7,0xe5340024,0x00000000,0x00000000}},	//   bouw, пень, --, --, 
   {{0xda586888,0x00000000,0x00000000,0x00000000}},	//   _уруш_, --, --, --, 
   {{0xd6d8b01b,0x92c40154,0x00000000,0x00000000}},	//   штө_, _উড়ে_, --, --, 
   {{0x18b00032,0x225800ee,0x3a70030d,0xa5c40150}},	//   _яҙыр, бигы_, _илĕр, _нөме, 
   {{0xf64c00ec,0xc8fc00fe,0x00000000,0x00000000}},	//   _لئي_, ্জীত_, --, --, 
   {{0x6609477d,0xd6a80fb4,0xe4c4179e,0xf1c00150}},	//   mudk, _ادهم_, _عصبی, _ﺣﺎﻧﺘ, 
   {{0x6609de5a,0xa07401d5,0x00000000,0x00000000}},	// [35c50] ludk, чгач, --, --, 
   {{0x6729de5b,0x1ccc0327,0x00000000,0x00000000}},	//   nedj, _ླུང_, --, --, 
   {{0x660800c5,0xceb4070e,0x6f000248,0xe23404f2}},	//   nudk, зәт_, _sábà, _عکسب, 
   {{0xf65002e4,0xa194013e,0x6728014f,0x8140ce83}},	//   וצע_, _хамч, hedj, _تۆرن, 
   {{0x6728ccfa,0x79980d27,0x5f8008b0,0x212800d5}},	//   kedj, vouw, _كۇرە, meah_, 
   {{0x67282f61,0x2008020b,0x660828f5,0x00000000}},	//   jedj, muai_, kudk, --, 
   {{0x66091eec,0x7999de5c,0x20081140,0x05c402ab}},	//   judk, touw, luai_, _रंगब, 
   {{0xab5c00de,0xbd940092,0x00000000,0x00000000}},	//   _viļa, ጅቶችም_, --, --, 
   {{0x2008c39e,0x79994a9a,0xe9a80131,0xb8d052be}},	//   nuai_, rouw, غدىن_, _टर_, 
   {{0x7bd80a73,0x799802ea,0x6729de5d,0x00000000}},	//   _ituu, souw, gedj, --, 
   {{0xdce801e4,0x6609de5e,0x15b9418f,0x49d801c8}},	//   _aleĉ, gudk, йымы_, _هانگ_, 
   {{0x2009de5f,0x212805b1,0xe93801d3,0x06640116}},	//   kuai_, jeah_, _وسنت_, ﺴﻼﻣﯩ, 
   {{0x6729de60,0xe468005b,0xf4bc0154,0xfbc800cd}},	//   bedj, ошёл_, ূর্ব, ादिम, 
   {{0x20080198,0x9f480165,0xe3b001d9,0x8838011a}},	//   duai_, krañ_, ٖرِ_, _לתנו, 
   {{0xd2a8e277,0x5ed000bd,0x7bd804ce,0xd04400ac}},	//   скве_, িরাই, _ltuu, əməd, 
   {{0x20080421,0xdb0000c6,0x7bd80a49,0xc69002e4}},	//   fuai_, _chlú, _otuu, _ראה_, 
   {{0x2008a597,0x7bd80a49,0xdb0000ae,0x1458004e}},	// [35c60] guai_, _ntuu, _dhlú, _ышкы_, 
   {{0x9f480165,0x2ca401e3,0x00000000,0x00000000}},	//   frañ_, _rymd_, --, --, 
   {{0x7bd9de61,0x20080607,0x3f8c00d8,0x23340588}},	//   _atuu, auai_, égua_, _цхыр, 
   {{0xdb00007b,0x21280076,0x2009de62,0x672825d7}},	//   _ghlú, ceah_, buai_, zedj, 
   {{0x3219de63,0x9f4805c7,0xef94315b,0x7f4400d1}},	//   ltry_, arañ_, _قیرد, تلەق_, 
   {{0xdce800e4,0x00000000,0x00000000,0x00000000}},	//   _imeĝ, --, --, --, 
   {{0x7bd9de64,0x3219de65,0x67280010,0x66080009}},	//   _etuu, ntry_, vedj, xudk, 
   {{0x6608a0c5,0x1718031c,0x32180afa,0x00000000}},	//   vudk, ྱུའམ_, itry_, --, 
   {{0x67281710,0x5ec0015b,0x00000000,0x00000000}},	//   tedj, শুদে, --, --, 
   {{0x6608000d,0x00000000,0x00000000,0x00000000}},	//   tudk, --, --, --, 
   {{0x6729de66,0x6594e3cd,0xf1accd66,0x08c4252c}},	//   redj, дану, चतान, _ебен, 
   {{0x2c20006d,0x6729de67,0x19b8084c,0x7eb00064}},	//   _यहां_, sedj, _дучь_, _užpū, 
   {{0x660802fb,0xf8bc1d55,0x443c1709,0xe87401d5}},	//   sudk, žér_, íu_, _تنشگ, 
   {{0x20080481,0x6304036b,0x00000000,0x00000000}},	//   vuai_, بوسل, --, --, 
   {{0x35f4a534,0x32180280,0x61e8009b,0xdb0001e7}},	//   _فريد_, gtry_, ćelo, _phlú, 
   {{0x2009de68,0xdb0001c3,0xdcf800b0,0x91c000fd}},	//   tuai_, _dhlù, kiwā, кәял, 
   {{0x656dde69,0x321805da,0x9f480a87,0x00000000}},	// [35c70] _ilah, atry_, frað_, --, 
   {{0x656dde6a,0xdb0000a3,0x212801f7,0x200800b0}},	//   _hlah, _fhlù, seah_, ruai_, 
   {{0x7bd9c980,0x20085088,0xdb0000a3,0xa1581b4f}},	//   _stuu, suai_, _ghlù, _дану_, 
   {{0x2009de6b,0x260401ad,0x9f480156,0x00000000}},	//   puai_, _विनी_, rrañ_, --, 
   {{0x200805d5,0x656c0010,0x4914000d,0x00000000}},	//   quai_, _mlah, _भउजो_, --, 
   {{0x656dde6c,0x8c41de6d,0x7bcc06af,0x9f480165}},	//   _llah, теше, _écum, prañ_, 
   {{0x656cef64,0x51c80150,0x00000000,0x00000000}},	//   _olah, _ﻓﺎﻟﺸ, --, --, 
   {{0x7bd80337,0xbb1801d3,0x00000000,0x00000000}},	//   _ttuu, _گزرا_, --, --, 
   {{0x7bd9de6e,0x00000000,0x00000000,0x00000000}},	//   _utuu, --, --, --, 
   {{0x656dde6f,0x3ab00131,0x6b8400ae,0x00000000}},	//   _alah, _пәйт, éigt, --, 
   {{0x656dde70,0x893000e5,0x00000000,0x00000000}},	//   _blah, رٹیا, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9874010b,0x656c0866,0xc9500a7c,0xd394013d}},	//   _юлдц, _dlah, _שמד_, дәнә_, 
   {{0x656dde71,0xdb000156,0x00000000,0x00000000}},	//   _elah, _sklê, --, --, 
   {{0x656c0076,0xc7b00302,0x27e00327,0x9f4803b2}},	//   _flah, _שבו_, _ħini_, vrað_, 
   {{0x656c0194,0xb35801ed,0x4fe80e92,0xa594005b}},	//   _glah, _کیسا_, жман_, _прыщ, 
   {{0x9c7c06c8,0x9f480bcd,0x00000000,0x00000000}},	// [35c80] _keōu, trað_, --, --, 
   {{0x656c0219,0x00000000,0x00000000,0x00000000}},	//   _zlah, --, --, --, 
   {{0x9f49de72,0xe5780166,0x656c0432,0x00000000}},	//   spaß_, _фзө_, _ylah, --, 
   {{0x5d640046,0x4c85de73,0x6cd40137,0x00000000}},	//   нтіз, млев, رقتا, --, 
   {{0xb32c003d,0x51f40214,0x13e00011,0xfc2c50a3}},	//   _སྲོང_, _عسگر, _বিড়, لحو_, 
   {{0xf764d6f0,0xdcf802b5,0x27e1b468,0x2d4800a2}},	//   _شا_, riwā, _çini_, _ỳedi_, 
   {{0x693401d3,0x6cc801af,0xf4140154,0x00000000}},	//   ٹکار, _еҫем_, িবির_, --, 
   {{0x13d42158,0xa3b405f9,0xfbc80e49,0x9f48014a}},	//   তীয়, _छीन_, ादशम, ököl_, 
   {{0x87044f55,0x1c04072a,0xcba400cf,0x00000000}},	//   мяне, _रियल_, _жаай, --, 
   {{0xf41403f4,0xc0cc0020,0x26d801c3,0x656c00d7}},	//   িবার_, _ኤድስ_, ùro_, _slah, 
   {{0xc95405cc,0x25680204,0x656dde74,0xb32c0327}},	//   _отды, _fûll_, _plah, _སྲེང_, 
   {{0x1bf4007d,0x2ca0031c,0x00000000,0x00000000}},	//   ुंचल_, żidu_, --, --, 
   {{0xdab400cf,0xb3780023,0x00000000,0x00000000}},	//   _قۇۇت_, _ካብዘን_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3d0c0c2e,0x656c01af,0xb284013d,0x0ca805ac}},	//   _डाले_, _tlah, вытк, _ওলোত, 
   {{0x656dde75,0xdb0002e2,0x261806af,0x75a40022}},	//   _ulah, _eklè, méo_, _ишыж, 
   {{0x46d01533,0x6aa81455,0x673805c7,0x69dc0798}},	// [35c90] _सलाह, _lydf, _kavj, _éref, 
   {{0x6aa803ac,0x2c080073,0xa4f800e5,0x236401e3}},	//   _oydf, _समजू_, _بکھر_, öljd_, 
   {{0x673807d6,0x3ea40008,0x2cdc00b4,0x26180129}},	//   _mavj, ænt_, _ịhụ_, néo_, 
   {{0x8e3c03ee,0x67380200,0x00000000,0x00000000}},	//   _оtо_, _lavj, --, --, 
   {{0xdce803ee,0xca7801d5,0x00000000,0x00000000}},	//   _emeğ, _matе, --, --, 
   {{0x67380301,0x26180022,0x00000000,0x00000000}},	//   _navj, kéo_, --, --, 
   {{0x2139de76,0x6aa8015d,0x00000000,0x00000000}},	//   _kash_, _cydf, --, --, 
   {{0x26182047,0x57e83298,0x00000000,0x00000000}},	//   déo_, пдим_, --, --, 
   {{0x3dd4045e,0xed04021f,0xd94400d1,0xb89c0023}},	//   _হিটল, _جوقپ, _җели, _ምድጋፍ_, 
   {{0x2139de77,0xdce85946,0xbbc80316,0x55e53e40}},	//   _lash_, _mleč, ादीक, нооб, 
   {{0xd7c8315b,0x21380076,0x6aa80042,0xab840334}},	//   _کوته_, _oash_, _gydf, _рутк, 
   {{0xca780166,0x21380f85,0xaf080154,0x98740064}},	//   _catе, _nash_, র্পণ_, _плец, 
   {{0xb32c1b35,0x822c0023,0x00000000,0x00000000}},	//   _སྲུང_, _ብውሑዳ, --, --, 
   {{0x21380363,0xd7f80032,0x6739de78,0x26191227}},	//   _aash_, _дуҫ_, _gavj, béo_, 
   {{0xdce80e3c,0x2618003e,0x21382517,0xc68c00ec}},	//   _aleč, céo_, _bash_, _ٿِي_, 
   {{0x67381711,0xdce80fcf,0x2139de79,0x00000000}},	//   _zavj, _omeđ, _cash_, --, 
   {{0x21387723,0x00000000,0x00000000,0x00000000}},	// [35ca0] _dash_, --, --, --, 
   {{0x21380731,0x69dccd11,0xcb0c2356,0xe1f801f0}},	//   _eash_, _éreg, _साइड_, ягӣ_, 
   {{0xe8ac482a,0x21380493,0x1ea83090,0x8d280107}},	//   _चर्च, _fash_, وامي_, зоев_, 
   {{0x21380072,0x2244005c,0x00000000,0x00000000}},	//   _gash_, ælke_, --, --, 
   {{0xdce800f3,0x7525de7a,0x6aa800b5,0xafc40032}},	//   _gleč, _mbiz, _sydf, _аҙай, 
   {{0x09d80135,0x76406873,0xbae002dd,0x00000000}},	//   _འཕྱ_, _orny, _ﺍﭘﺘﺎ, --, 
   {{0x75246643,0x2139de7b,0xa9342e70,0x6738031c}},	//   _obiz, _yash_, вейш, _ravj, 
   {{0x67381727,0xbea004b1,0x06bc05ac,0x00000000}},	//   _savj, _саск, _ইভলি, --, 
   {{0x764081ee,0xc1700375,0x00000000,0x00000000}},	//   _arny, טחה_, --, --, 
   {{0x261820ef,0x6aa90717,0xc8c8004b,0x7bdc04d4}},	//   téo_, _tydf, _ځوان_, íque, 
   {{0x75240083,0x09d8025c,0xa52c031c,0x0cd00154}},	//   _bbiz, _འཕྲ_, _ཧྲུག_, ারীত, 
   {{0x63a40109,0x764001bf,0x26180022,0x00000000}},	//   _skhn, _drny, réo_, --, 
   {{0x75242ab0,0xd83400c7,0x2139de7c,0xf990011a}},	//   _dbiz, _аҿыц_, _rash_, _גרף_, 
   {{0x7524b23d,0x2139de7d,0x26180022,0xa29400d4}},	//   _ebiz, _sash_, péo_, вагі, 
   {{0xf20405b0,0xdce9bb56,0x2139de7e,0x65940022}},	//   лято, _sleč, _pash_, _иаку, 
   {{0x2b4c01af,0x2568002d,0xdce9de7f,0x2138ce08}},	//   _lndc_, _mûlk_, _pleč, _qash_, 
   {{0xc05802bf,0xdebc0b82,0xe3a401b9,0xe37402dd}},	// [35cb0] чів_, ታይን_, _لشدی, _алпы, 
   {{0xdce86185,0x75240076,0x21380c18,0x6608017a}},	//   _vleč, _zbiz, _wash_, ordk, 
   {{0xb32c003d,0xdce81b24,0x2139de80,0x816402dd}},	//   _སྲིང_, _smeđ, _tash_, _كەسك_, 
   {{0x5ff42bbd,0x01e000db,0x00000000,0x00000000}},	//   _изму, _ийүү, --, --, 
   {{0xaacc0dad,0x20180113,0x60dc0076,0x00000000}},	//   ाशंक, _uqsi_, _ifsm, --, 
   {{0x98ac0003,0x71f80244,0x00000000,0x00000000}},	//   jjeġ_, _تریس_, --, --, 
   {{0x1ea801e2,0x00000000,0x00000000,0x00000000}},	//   _ځاځي_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x200806a3,0xac940184,0xaa882002,0x626403f9}},	//   nrai_, _батш, ونۇم_, lɗod, 
   {{0x200819a2,0x75240395,0x00000000,0x00000000}},	//   irai_, _sbiz, --, --, 
   {{0xa9240046,0xcfc80150,0x00000000,0x00000000}},	//   _әділ, _ﺑﻮﺯﺗ, --, --, 
   {{0x20080953,0xd1d40023,0x00000000,0x00000000}},	//   krai_, ርኻብ_, --, --, 
   {{0x38000364,0x78840014,0xb0c05ae4,0xdee40092}},	//   _солҳ, _سێدِ_, _शृंग, ዝሩን_, 
   {{0x2009de81,0x764025a9,0x60dc01bf,0x671819cc}},	//   drai_, _trny, _afsm, _दायक_, 
   {{0xcb100bd9,0x2009de82,0x73c400fb,0x656c00e4}},	//   ילם_, erai_, кәүе, ñohá, 
   {{0x20080042,0x32040419,0xf7700244,0x00000000}},	//   frai_, čmy_, _جاڵ_, --, 
   {{0x2008ba3a,0xa52c031c,0x90c5de83,0xcfc8313e}},	// [35cc0] grai_, _ཧྲིག_, тбае, _ﺑﻮﺭﺗ, 
   {{0xda2003ce,0x00000000,0x00000000,0x00000000}},	//   _महंत_, --, --, --, 
   {{0x2009de84,0x8e4800c6,0x25b001ed,0xc0e00240}},	//   arai_, بلاك_, _álló_, _ዝሕሉ_, 
   {{0x160801ad,0x7644023a,0x8cc4143e,0x0c84121c}},	//   _विनर_, äjyy, نقاه, кылм, 
   {{0x200804cc,0x628003b2,0x00000000,0x00000000}},	//   crai_, úlov, --, --, 
   {{0xdce8031c,0xaa94013d,0x00000000,0x00000000}},	//   _vjeġ, лилч, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdde800f2,0x7e6001f4,0x00000000,0x00000000}},	//   _سرفه_, änpe, --, --, 
   {{0x2d8401af,0x61e81505,0xaca402e3,0xdb00e4dc}},	//   _imme_, ćeli, _kpọp, _chló, 
   {{0x247c02d3,0xac0801e0,0x00000000,0x00000000}},	//   _ኣስማት_, _онға_, --, --, 
   {{0x18185da7,0x7b840c75,0x18540150,0x00000000}},	//   وریک_, _شاكە, _ەرىڭ, --, 
   {{0x20080153,0x3ea40254,0x00000000,0x00000000}},	//   yrai_, ünti_, --, --, 
   {{0xdb00007b,0xf48422c3,0x00000000,0x00000000}},	//   _ghló, аурн, --, --, 
   {{0x2009de85,0x83849684,0x051000eb,0x00000000}},	//   vrai_, тыме, িজের_, --, 
   {{0x69d80369,0xff50035c,0x69c144d7,0x20080142}},	//   nqve, یخط_, omme, wrai_, 
   {{0x2009de86,0xbee81f5e,0x058527c7,0x69c0007f}},	//   trai_, टर्न_, _шулм, nmme, 
   {{0x6e440020,0x25a82ebc,0x5e582352,0x69c00363}},	// [35cd0] _የሚገባ, _ikal_, کلاس_, imme, 
   {{0x2d85de87,0x2009de88,0xa2c4008e,0x9cb400d1}},	//   _amme_, rrai_, _бәбк, ۇمات, 
   {{0x25a80429,0x5f1804af,0x00000000,0x00000000}},	//   _kkal_, _पाठ्_, --, --, 
   {{0x5c7409a5,0x2008011c,0x2d840ffb,0x37e0015b}},	//   ллет, prai_, _cmme_, _মিসর, 
   {{0xff5c003a,0xe2c80244,0x00000000,0x00000000}},	//   _quîs_, _تاکۆ_, --, --, 
   {{0x69c14c33,0x29d80066,0x2d85de89,0xef6402e8}},	//   emme, _béa_, _emme_, _късо, 
   {{0xdb00464c,0xdd94008e,0x81c800fe,0x00000000}},	//   _bhlò, _бавы, ৰীণ_, --, 
   {{0xdb014ffd,0x6440005f,0x1dc40075,0x25a800ef}},	//   _chlò, ālij, _сөзн, _nkal_, 
   {{0xccf00375,0x91e404ce,0xb60402f0,0x17c80107}},	//   _לכן_, _pcにi, _obší, нгии_, 
   {{0x25a85df1,0x69c1de8a,0xb8c80073,0xfa84009b}},	//   _akal_, amme, _गड_, _ићем, 
   {{0x25a806d1,0xdb0001ab,0xaa4401d9,0x00000000}},	//   _bkal_, _fhlò, _پننى, --, 
   {{0x17180156,0xceb027af,0xdb0001c3,0x63780241}},	//   ྱུངམ_, מיי_, _ghlò, _jìnf, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69ddde8b,0xb6c00032,0x7584109c,0x10a40107}},	//   _érec, _килһ, _چیدم, ҳибн, 
   {{0x80a80183,0x236401e3,0x15441075,0x1c0c00c5}},	//   চেম্, ölja_, _бейм, _समझल_, 
   {{0x10a40108,0x70e40124,0x00000000,0x00000000}},	//   гибн, рбаҕ, --, --, 
   {{0x4f240132,0x939484a1,0xf1e80210,0x00000000}},	// [35ce0] лдаб, _مجدا, टीज़_, --, 
   {{0x2d84e816,0x22f80014,0x3f8c002e,0x00000000}},	//   _smme_, _لژِھ_, ёgu_, --, 
   {{0x69c1de8c,0xfe400395,0xdcf80210,0x00000000}},	//   ymme, йнфо, liwę, --, 
   {{0x29d83386,0x0cd0015b,0x00000000,0x00000000}},	//   _réa_, ার্ত, --, --, 
   {{0x6acc0882,0xefc80116,0x00000000,0x00000000}},	//   ाश्र, _аһал_, --, --, 
   {{0x394dde8d,0x29d80124,0xdb0001ab,0xa8f000cc}},	//   _angs_, _péa_, _shlò, _টাইড_, 
   {{0xfc3c01ef,0x00000000,0x00000000,0x00000000}},	//   _šít_, --, --, --, 
   {{0x69c00140,0x00000000,0x00000000,0x00000000}},	//   umme, --, --, --, 
   {{0x69c1de8e,0xa7744623,0x644033fb,0x65bc003e}},	//   rmme, илич, ālik, léhg, 
   {{0x25a85b47,0x29d83386,0x3c600228,0x37e000bd}},	//   _skal_, _téa_, _укуг, _মিশর, 
   {{0xda64511e,0x09e40166,0xfaa00cb6,0x3f8c0588}},	//   _پالي, _соен, _лафо, égui_, 
   {{0x23600165,0xc66801ec,0x3f8c00c7,0x5a7401af}},	//   _sohj_, _үшке_, ĩgui_, _тыуђ, 
   {{0xf76c3c5b,0xa3d401c6,0x00000000,0x00000000}},	//   زای_, рогч, --, --, 
   {{0xf64c00e5,0x00000000,0x00000000,0x00000000}},	//   آئی_, --, --, --, 
   {{0x623400ee,0xb3c800db,0x637801e1,0x00000000}},	//   шеву, улёз_, _lìng, --, 
   {{0x810c6bcf,0x00000000,0x00000000,0x00000000}},	//   िलेख_, --, --, --, 
   {{0xdb00219b,0xd498004e,0x80a800eb,0x00000000}},	// [35cf0] _sklí, _үрө_, _কলঙ্, --, 
   {{0x628000d7,0x61d8022e,0x00000000,0x00000000}},	//   úlos, _имоя_, --, --, 
   {{0xfd88013e,0x75d00311,0xa2c00073,0x7e4401f4}},	//   нёди_, _păzi, ळेश्, ыхае, 
   {{0xeea82897,0xdb0001ef,0x00000000,0x00000000}},	//   утук_, _vklí, --, --, 
   {{0xdca41b88,0xc0a8ba0b,0xf5380375,0x042000cc}},	//   јали, _ساحل_, טראז_, মিকী_, 
   {{0xda6400a7,0xaed4c9fd,0x64d001f9,0x00000000}},	//   ивли, _горш, सखुश, --, 
   {{0xdb000118,0x44380051,0xdb1c0248,0x00000000}},	//   _uklí, _lsq_, _èyík, --, 
   {{0x63780248,0x00000000,0x00000000,0x00000000}},	//   _hìnd, --, --, --, 
   {{0x23a5026a,0xda080ee8,0x00000000,0x00000000}},	//   ओवाद, ريکه_, --, --, 
   {{0x7c39de8f,0x17855fe9,0xd78800ec,0xad2400f1}},	//   _isur, ргом, ئندو_, _پرېو, 
   {{0x61e5de90,0x44380113,0x7bc00327,0x26d80205}},	//   _nthl, _asq_, mmnu, ırop_, 
   {{0xd468d17b,0x69dc0120,0xab640327,0x7bc00037}},	//   виме_, _érea, _ġżir, lmnu, 
   {{0x7d180789,0x61e5de91,0x7bcc06af,0xca5001ec}},	//   _mcus, _athl, _écus, _ﺎﺀﺕ_, 
   {{0x7c3801c8,0x443801a9,0x91e404c2,0x00000000}},	//   _msur, _dsq_, иоге, --, 
   {{0x0cb006e3,0xd1304cdb,0x7d18127b,0x44380f85}},	//   _जर्म, يمس_, _ocus, _esq_, 
   {{0x7d1800d2,0x7c39de92,0x00000000,0x00000000}},	//   _ncus, _osur, --, --, 
   {{0x7c39317b,0xa3dc0490,0x7761de93,0x00000000}},	// [35d00] _nsur, _तूप_, _konx, --, 
   {{0x941c0085,0xc3f806a9,0xafe400d1,0x00000000}},	//   ́tɛ_, _שליש, иоғл, --, 
   {{0x1fb42ecc,0x7c39de94,0x7760056a,0x1db004fa}},	//   сстр, _asur, _monx, जतंत, 
   {{0x7761de95,0x20d402bf,0x7bc00af9,0xcbe40b7e}},	//   _lonx, _гірс, emnu, ацки, 
   {{0x7760009a,0x212c0124,0xaf080154,0x6fb80e49}},	//   _oonx, _ñeha_, র্ষণ_, ्गदू, 
   {{0xec8400c6,0xd1b80020,0x776000f1,0x00000000}},	//   _ĵǿđ_, ቲዎች_, _nonx, --, 
   {{0x7c39de96,0x20040421,0x3f8d22f0,0x65bc0ac0}},	//   _esur, _ālii_, ègue_, léhe, 
   {{0x7d1800c6,0x7bc016b8,0x3d040490,0xa9540150}},	//   _gcus, amnu, हणणे_, скиі, 
   {{0x7761de97,0x6d41de98,0xdc288efb,0x2ef80af9}},	//   _bonx, _iama, _مسله_, _kerf_, 
   {{0x77600f71,0x250861f4,0x4438067c,0x19a80137}},	//   _conx, گردی_, _rsq_, ктөп_, 
   {{0x9f5d24c4,0x4438011c,0x6b88031c,0xa4d402bf}},	//   éwé_, _ssq_, _imdg, йоні, 
   {{0x6d408f58,0x7bcc004a,0x250810e5,0x18880220}},	//   _jama, _écur, دردی_, _өсіп_, 
   {{0x61e4c5e2,0x38540214,0x3d040490,0x86e401d5}},	//   _sthl, _نشود_, हणते_, _кўйд, 
   {{0x6d41de99,0x75d00311,0x7760036e,0x6e3c00d7}},	//   _lama, _răzv, _gonx, _osrb, 
   {{0xf76c4451,0x6d4000b0,0xdfd00451,0xa3b4000d}},	//   _زاو_, _oama, ڳيا_, _छीः_, 
   {{0x776000aa,0x30e9de9a,0x75d00276,0x00000000}},	//   _zonx, ифун_, _căzu, --, 
   {{0xdfd1de9b,0x776000f1,0x4438003a,0x2ef80042}},	// [35d10] سيا_, _yonx, _usq_, _berf_, 
   {{0x7d183c96,0x6d41de9c,0x77600077,0x2ef86c80}},	//   _scus, _aama, _xonx, _cerf_, 
   {{0x2ef9de9d,0x7d18019b,0x61e402d0,0x5cd4007b}},	//   _derf_, _pcus, _uthl, مقاط, 
   {{0x2568002d,0x7bdc0798,0xad240d1f,0xa159dac8}},	//   _gûlt_, íquo, قىمى, _саму_, 
   {{0xad246923,0x6d41de9e,0x2ef80042,0xac180063}},	//   تىنى, _dama, _ferf_, иоцу_, 
   {{0x6d41de9f,0x7c380393,0x3ea400db,0x6f000118}},	//   _eama, _vsur, ünts_, rábí, 
   {{0x6d41dea0,0x7bc001f5,0x6e9401f0,0x9af400c7}},	//   _fama, rmnu, _диру, ацқә, 
   {{0x7c39dea1,0x77600472,0x7c84fb83,0x7d1803ac}},	//   _tsur, _sonx, _кузе, _ucus, 
   {{0x5c980108,0x9d4401ec,0x5c75dea2,0x00000000}},	//   _ская_, _кеңд, _улат, --, 
   {{0x6d41dea3,0xaa6400fd,0x776001a9,0xd1b80092}},	//   _zama, стәк, _qonx, ቲዎቹ_, 
   {{0x6d416f93,0x06c8015b,0x00000000,0x00000000}},	//   _yama, লুসি, --, --, 
   {{0x6d41dea4,0x776001e2,0x00000000,0x00000000}},	//   _xama, _wonx, --, --, 
   {{0xc8d8008f,0x00000000,0x00000000,0x00000000}},	//   _עקסט, --, --, --, 
   {{0x395ddea5,0x65bc00e5,0x00000000,0x00000000}},	//   ljus_, véhe, --, --, 
   {{0x87940014,0x91e5bd25,0x11d8007b,0x395c01f4}},	//   _دَور_, собе, اورة_, ojus_, 
   {{0x2ef9dea6,0x65bc00e5,0xd32400c7,0xd1cc1954}},	//   _serf_, téhe, шьҭи, ጥፈት_, 
   {{0x2ef86d05,0x387ddea7,0x75d0084c,0xdb00005c}},	// [35d20] _perf_, nzur_, _văzu, _iklæ, 
   {{0x395c007d,0x65bd956d,0x254c00c0,0x00000000}},	//   hjus_, réhe, _vėlų_, --, 
   {{0x2ef82a28,0x65bc01ed,0xd1b80150,0xfc3c0306}},	//   _verf_, séhe, _ماحا_, _šíp_, 
   {{0x6d41dea8,0x717407a7,0x2ef8f498,0x6f1c01e2}},	//   _qama, _بۇرا, _werf_, _wcrc, 
   {{0xcb683339,0x6d41dea9,0x0b880f43,0xdb0002fd}},	//   ладе_, _vama, лски_, _sklá, 
   {{0x395c0006,0xa03000db,0x00000000,0x00000000}},	//   ejus_, _تۉكت, --, --, 
   {{0x63780241,0x69cc01f9,0x9f8801af,0x00000000}},	//   _yìnb, _हळदी, _тарҡ_, --, 
   {{0x8d9529c0,0xdb00012c,0x7a340395,0x00000000}},	//   _الرش, _vklá, спър_, --, 
   {{0xd90c30cd,0x092801ec,0x00000000,0x00000000}},	//   ئیه_, _ەستي_, --, --, 
   {{0xa9cc02dd,0x00000000,0x00000000,0x00000000}},	//   _ﺗﯟﯨﺴ, --, --, --, 
   {{0xdb0000bc,0x4a9802d5,0x657ddeaa,0x395c00ef}},	//   _uklá, _стаў_, ërho, bjus_, 
   {{0x68e00354,0x31600135,0x00000000,0x00000000}},	//   qcmd, jjiz_, --, --, 
   {{0x07a473d6,0xd3a40046,0xe788004b,0xc8b5deab}},	//   _ладн, ﺎﻟﯩﻖ_, _نږدي_, _اصاب, 
   {{0xf741deac,0x61e000e4,0x00000000,0x00000000}},	//   _нечо, íllo, --, --, 
   {{0xf7700375,0xd3440133,0x00000000,0x00000000}},	//   _מקס_, ڕییه_, --, --, 
   {{0xc058886f,0x96b800f3,0x207401a9,0x00000000}},	//   ліз_, _тучу_, олбў, --, 
   {{0x657c0597,0x7ff400c6,0xf8b0010f,0x98b4031c}},	// [35d30] mhsh, إسرا, ִשע_, ġgħa_, 
   {{0x644ddead,0x7e600108,0xe3b80ce8,0x00000000}},	//   _irai, änpo, _әбү_, --, 
   {{0xdb0000d2,0x644ddeae,0x32540276,0x622000d1}},	//   _mhlô, _hrai, _евэр, _تۈزە, 
   {{0x644c0bed,0x387c012d,0x657c0051,0x00000000}},	//   _krai, yzur_, nhsh, --, 
   {{0x645c0369,0x6aa403e0,0x00000000,0x00000000}},	//   nxsi, şifl, --, --, 
   {{0x657c0270,0x644ce456,0xc17001d3,0xeb980150}},	//   hhsh, _mrai, _بگڑت, биі_, 
   {{0x2e480801,0x395c0254,0x00000000,0x00000000}},	//   _лято_, tjus_, --, --, 
   {{0x644ddeaf,0x9f480227,0x387c005a,0x21280036}},	//   _orai, msañ_, tzur_, nfah_, 
   {{0x21280a2e,0x657c044e,0x644ddeb0,0x395ddeb1}},	//   ifah_, dhsh, _nrai, rjus_, 
   {{0x2129729c,0x5628ee8d,0xb1880118,0x395c2641}},	//   hfah_, ажом_, _koťá, sjus_, 
   {{0x9fe4015b,0x7ae0003a,0x6b8401f5,0xd62801f0}},	//   _ফটোগ, mcnt, ëige, шоне_, 
   {{0x9425deb2,0x644d9ad8,0x657c0113,0x395c0135}},	//   омме, _brai, ghsh, qjus_, 
   {{0x644ddeb3,0x79880334,0x31600175,0xa8840137}},	//   _crai, _imgw, vjiz_, _ىلمى, 
   {{0x3720031c,0xe4080118,0x657c7d85,0x7af4022e}},	//   _འཁྲལ_, énář, ahsh, аxti, 
   {{0x644ddeb4,0x212881be,0xdb0001e3,0x4611deb5}},	//   _erai, ffah_, _iklä, _قوور, 
   {{0x644ddeb6,0xde540020,0x657ddeb7,0xe60800db}},	//   _frai, _የሚያገ, chsh, _ازوو_, 
   {{0x9f480dd4,0x644c378c,0x3160030a,0x00f400db}},	// [35d40] esañ_, _grai, rjiz_, زىلع_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7ae0003a,0x644c030a,0x65bddeb8,0x7988ccf1}},	//   dcnt, _zrai, léha, _omgw, 
   {{0x32180456,0x8c48447e,0x00000000,0x00000000}},	//   mury_, ипев_, --, --, 
   {{0xd1b804a9,0x2ca000ac,0xcc342824,0x65bc0438}},	//   _ماڭا_, çid_, تراع, néha, 
   {{0x7988014b,0x2ca0003d,0xb18802fb,0x7ae0003a}},	//   _amgw, ħid_, _foťá, gcnt, 
   {{0x7e200b7f,0xd9dc0c58,0x798802d0,0x9e7001ec}},	//   _одрж, ণীসম, _bmgw, _كۇكت, 
   {{0xdb0001c7,0x65bc020c,0x3338031c,0x094800f0}},	//   _aklä, kéha, herx_, рчки_, 
   {{0xfc01deb9,0xdce8009b,0xac0801ee,0x00000000}},	//   _опто, _sleć, _ымаҡ_, --, 
   {{0xdce807f5,0x7988013e,0x644c01ab,0x9f48148b}},	//   _pleć, _emgw, _rrai, nsað_, 
   {{0x644ddeba,0x657ddebb,0x32180375,0x2128009f}},	//   _srai, thsh, jury_, yfah_, 
   {{0x3219debc,0xdb000432,0xdb1001e1,0x00000000}},	//   dury_, _eklä, _àfòp, --, 
   {{0x65bc06fd,0x9f480162,0x813800e5,0x00000000}},	//   géha, ksað_, یسرز_, --, 
   {{0x644d86ca,0x657ddebd,0xf7400114,0x00000000}},	//   _vrai, shsh, _жељо, --, 
   {{0x644c0368,0x72d40a5b,0xf5a405d9,0xf365debe}},	//   _wrai, дорф, _ڪميٽ, фтян, 
   {{0x644ddebf,0x65bc00d5,0xa6dc00fe,0x00000000}},	//   _trai, béha, _মজিয়, --, 
   {{0x644ddec0,0x644000da,0x1f7400ee,0xf0e805a9}},	// [35d50] _urai, ālis, плая, تىقى_, 
   {{0x9f4808a7,0x3494074d,0x00000000,0x00000000}},	//   gsað_, _цаьр, --, --, 
   {{0xee3800d4,0x3d0401f9,0x00000000,0x00000000}},	//   жнє_, हणले_, --, --, 
   {{0xdfd405f5,0xf53800c8,0x00000000,0x00000000}},	//   _номы, ַטור_, --, --, 
   {{0x9ff40135,0x51580375,0x1ae401b9,0xfbe000cc}},	//   _བསྲང_, _הכרו, полм, নীনত, 
   {{0xcb640536,0x00000000,0x00000000,0x00000000}},	//   заше_, --, --, --, 
   {{0x7bcc04cc,0xfd100592,0x7ae0003a,0x09e002e8}},	//   _ècum, _يجر_, rcnt, нощн, 
   {{0x630402a6,0xe9a800c6,0x224000d7,0xbc3800f2}},	//   শ্চয়_, يدين_, _mshk_, _پسرا_, 
   {{0x6bd4345f,0x3219dec1,0xf1b405d0,0x5c7401d5}},	//   ستۇر, zury_, וסק_, _элат, 
   {{0x9ff4025c,0xd708005b,0x00000000,0x00000000}},	//   _བསླང_, щное_, --, --, 
   {{0x321976f9,0x65bc003e,0xd5e400d4,0x00000000}},	//   xury_, wéha, яжни, --, 
   {{0x79880163,0x00000000,0x00000000,0x00000000}},	//   _umgw, --, --, --, 
   {{0x6ad00154,0x5fbc858a,0x00000000,0x00000000}},	//   _স্পো, ्गाल, --, --, 
   {{0xe8201533,0x65bddec2,0x32184ff1,0x06c0009e}},	//   _ममता_, réha, tury_, োড়ি, 
   {{0x03a005f5,0x02c00276,0x14ac0490,0x65bc54ba}},	//   хиро, ейро, _घडवण, méhn, 
   {{0x79980b45,0x65bc003e,0xc2400153,0xd4a4030d}},	//   nnuw, léhn, энск, _нийй, 
   {{0xd008084c,0x4f08e06a,0x9f4803b2,0x7e900150}},	// [35d60] сезе_, йнан_, tsað_, _ﺜﺒﻭﺕ_, 
   {{0x65bc1dd4,0x8c9401ec,0x00000000,0x00000000}},	//   néhn, үрді, --, --, 
   {{0x4dd5dec3,0x63780241,0x6ad000eb,0x00000000}},	//   ستاس, _kìnn, _স্নো, --, 
   {{0x63780ca8,0x9f480321,0xccc4010b,0x41bc0303}},	//   _jìnn, ssað_, пбей, ्षणस, 
   {{0x3ea001f0,0x645801e1,0x00000000,0x00000000}},	//   _ҷирг, _àwit, --, --, 
   {{0x8fd0013d,0x224000a2,0x29000064,0xc0d40023}},	//   _чәбә, _yshk_, _žia_, ይያር_, 
   {{0xbea0014b,0x00000000,0x00000000,0x00000000}},	//   _зарк, --, --, --, 
   {{0xd90ddec4,0x7e980302,0x3ea4002d,0x00000000}},	//   لیم_, _הסלו, ûnte_, --, 
   {{0x81c803d4,0x5dd4dba2,0x391009a5,0x3830013d}},	//   ৰীক_, _цюру, хмыр, еныр, 
   {{0x79980de2,0x00000000,0x00000000,0x00000000}},	//   anuw, --, --, --, 
   {{0x76b40166,0x00000000,0x00000000,0x00000000}},	//   злэр_, --, --, --, 
   {{0x36847655,0x00000000,0x00000000,0x00000000}},	//   ясын_, --, --, --, 
   {{0x65bc00d5,0x00000000,0x00000000,0x00000000}},	//   béhn, --, --, --, 
   {{0x6234013e,0xa5f8022e,0x00000000,0x00000000}},	//   мегу, _деку_, --, --, 
   {{0xa2943334,0xf64c9cce,0x637801e1,0xdb0005ac}},	//   фаві, _مئي_, _fìnn, _uklå, 
   {{0x2d9c00dd,0xb5a402d5,0x00000000,0x00000000}},	//   ével_, _прый, --, --, 
   {{0xf0e82d40,0x65bc00e4,0x00000000,0x00000000}},	// [35d70] سىلى_, lého, --, --, 
   {{0x224006be,0x00000000,0x00000000,0x00000000}},	//   _tshk_, --, --, --, 
   {{0xceb40598,0x69dc00e4,0x6e94011c,0x00000000}},	//   дәт_, _éreh, нифу, --, 
   {{0x6fd803f3,0x9f4800c6,0xf2c4112a,0x614000cf}},	//   _भूकं, mpaí_, _ясын, _جۉرە, 
   {{0xf2a000b5,0x65bc003e,0x7a4400e5,0x00000000}},	//   _mixｘ, hého, kétá, --, 
   {{0x9f05dec5,0x65bc0122,0x9aa800d1,0x9f4801e7}},	//   _زورو, kého, ەچچە_, opaí_, 
   {{0x9950012c,0xa2c00073,0x00000000,0x00000000}},	//   _zář_, ळेच्, --, --, 
   {{0x7f44014f,0x57e80d1d,0xd7e8084c,0x6dc400f7}},	//   _hajq, одим_, омие_, _كۅلۅ, 
   {{0x7999dec6,0x7f440784,0xad2403cc,0x65bc0c6a}},	//   rnuw, _kajq, _سىلى, téhn, 
   {{0xeaf8034c,0x7f440477,0xd6d800f7,0x55e42218}},	//   _فرمت_, _jajq, өтү_, мооб, 
   {{0x7f44016d,0x41bc1221,0x65bc003e,0x63780241}},	//   _majq, ्षास, réhn, _pìnn, 
   {{0x7f44047e,0x7998011f,0x65bc003e,0x3f90025c}},	//   _lajq, qnuw, séhn, hixu_, 
   {{0x3f90005a,0x18680b3e,0xc324015b,0xe72c00a2}},	//   kixu_, _фали_, য়নি_, _ýeşş, 
   {{0xd7c828c4,0x637801e1,0x00000000,0x00000000}},	//   _بوته_, _wìnn, --, --, 
   {{0xc7a1dec7,0x07a001c0,0x3f90005a,0x1545dec8}},	//   _шишк, _шашн, dixu_, _жейм, 
   {{0x764000c0,0x00000000,0x00000000,0x00000000}},	//   _isny, --, --, --, 
   {{0x752400ca,0x6fd802ab,0x00000000,0x00000000}},	// [35d80] _iciz, _भूखं, --, --, 
   {{0x4f08005e,0xe0d075e4,0x52740372,0x69dc011c}},	//   інен_, ازِ_, _жуму, _èreg, 
   {{0x7f44047e,0xfcf41ee0,0xa43c0166,0x00000000}},	//   _dajq, _ዋንጫ_, _käşä_, --, 
   {{0xa3dc007d,0x69dc00c7,0xdd9801ec,0x00000000}},	//   _तूँ_, _érei, пші_, --, 
   {{0x0ba8425b,0x00000000,0x00000000,0x00000000}},	//   ياتى_, --, --, --, 
   {{0x7640020b,0x9ba401d9,0xf98c01e2,0x00000000}},	//   _osny, ٹلى۪, یبي_, --, 
   {{0xfe40014b,0x00000000,0x00000000,0x00000000}},	//   _инро, --, --, --, 
   {{0x75240117,0xf98400f1,0x00000000,0x00000000}},	//   _nciz, وچني_, --, --, 
   {{0xa3dc2de3,0x2fd8031e,0x29d400e4,0x2464036e}},	//   _तूं_, _kirg_, _ẽasa_, _mëmë_, 
   {{0x7525dec9,0x2fd80076,0x24640240,0x4ae000c5}},	//   _aciz, _jirg_, _lëmë_, _पलिव, 
   {{0x7640020b,0x2fd8022e,0x00000000,0x00000000}},	//   _csny, _mirg_, --, --, 
   {{0x19a80046,0x98bc02b5,0xe3e80327,0x65bc0306}},	//   _етіп_, _wawā_, _འཕྱང, rého, 
   {{0x2905deca,0xa43c0166,0x45e40150,0xc76400d1}},	//   mama_, _däşä_, _ﺍﻟﻬﻼ, _ياتى, 
   {{0x2bc401f9,0x7750022e,0x00000000,0x00000000}},	//   _लीमा, _акшф, --, --, 
   {{0x6595decb,0xf6407db4,0x7f440113,0x24640240}},	//   _паку, _ахын, _rajq, _bëmë_, 
   {{0x2905decc,0x2fd80048,0x7524014b,0xf1a40209}},	//   nama_, _airg_, _gciz, врун, 
   {{0x656c02b1,0xd4c1decd,0x2fd80166,0x03c5dece}},	// [35d90] _ioah, _бөрк, _birg_, _осом, 
   {{0x2905decf,0x656c0c34,0x7640010b,0x4428002f}},	//   hama_, _hoah, _ysny, mtc_, 
   {{0x2905ded0,0x656c01e0,0x7f44014f,0x9d140276}},	//   kama_, _koah, _vajq, едеч, 
   {{0x656dded1,0x55d8008f,0x2b1c00bc,0x81400244}},	//   _joah, פֿענ, _नाउँ_, _جۆرن, 
   {{0x656c0184,0xed5800d6,0xe8000316,0x44280810}},	//   _moah, ьої_, लीमा_, ntc_, 
   {{0x20080656,0x656c05da,0x2464036e,0x00000000}},	//   msai_, _loah, _zëmë_, --, 
   {{0x2905ded2,0x44280263,0x2009ded3,0x63780241}},	//   fama_, htc_, lsai_, _rìnl, 
   {{0x656c1cf3,0x200801ab,0x00000000,0x00000000}},	//   _noah, osai_, --, --, 
   {{0x2008f6ad,0xdedc0023,0x00000000,0x00000000}},	//   nsai_, _ኒሕን_, --, --, 
   {{0x20080006,0x52dc012c,0x1665c280,0x7c2826bc}},	//   isai_, _मलेस, евом, mtgr, 
   {{0x656dded4,0x2905ded5,0x7c28002f,0xda0802c9}},	//   _boah, bama_, ltgr, _ريشه_, 
   {{0x290404b9,0x60dc0a40,0x656c00eb,0x200846e4}},	//   cama_, _ngsm, _coah, ksai_, 
   {{0x7c29ded6,0x656c00b5,0xb4e002ab,0x888001d3}},	//   ntgr, _doah, _तली_, _میٹن, 
   {{0x76400263,0xdebc0023,0x29d40150,0x7c280112}},	//   _tsny, ሳርን_, _كيەس, itgr, 
   {{0x7c28a98b,0x20085106,0x5155ded7,0x82a001c4}},	//   htgr, esai_, нтау, гарж, 
   {{0x44280194,0x637801e1,0x4fe9ded8,0x2fd801d5}},	//   btc_, _jìnj, зман_, _sirg_, 
   {{0x20080399,0x69dc00d8,0x7c2801f5,0x24640240}},	// [35da0] gsai_, _érev, jtgr, _vëmë_, 
   {{0x2fd807d6,0x7c28002f,0x2364007c,0x00000000}},	//   _qirg_, dtgr, öljt_, --, 
   {{0x2905ded9,0x2009deda,0x2fd80381,0x7c284653}},	//   yama_, asai_, _virg_, etgr, 
   {{0x60dc0048,0xe0d000aa,0x32182a1f,0x2905dedb}},	//   _ggsm, ازې_, mrry_, xama_, 
   {{0x92e0015b,0x2fd97e6a,0x7c2801bf,0x41bc081e}},	//   দরী_, _tirg_, gtgr, ्षरस, 
   {{0xaca40521,0xf7642d56,0x00000000,0x00000000}},	//   _nrụp, _صا_, --, --, 
   {{0x0f54001f,0xbb500014,0xdb4c02f2,0x00000000}},	//   _ለማሳየ, ان٘ب, تێل_, --, 
   {{0xaca40521,0xc8640305,0x00000000,0x00000000}},	//   _arụp, етои, --, --, 
   {{0x656c06d9,0x7c28be66,0x637801e1,0xde540092}},	//   _roah, ctgr, _sìnm, _የሚደገ, 
   {{0x2905dedc,0x656ddedd,0xdb0000f2,0xdb4c03e6}},	//   sama_, _soah, _njlè, _وێن_, 
   {{0x941c0085,0x656ddede,0xfa300150,0x00000000}},	//   ́tɔ_, _poah, _مىلج, --, 
   {{0x4428074d,0x656c00fb,0x65940139,0x2905dedf}},	//   ttc_, _qoah, таму, qama_, 
   {{0x656c0851,0x6fb001f9,0x00000000,0x00000000}},	//   _voah, जकां, --, --, 
   {{0x656c0134,0x44280171,0x00000000,0x00000000}},	//   _woah, rtc_, --, --, 
   {{0xc0d41e38,0x4429dee0,0x656c0418,0x81c40c9e}},	//   ይያስ_, stc_, _toah, ещае, 
   {{0xb6b80302,0x057400c6,0x7bcc04cc,0x20080099}},	//   _מצוי, _ساعد, _ècuv, tsai_, 
   {{0x7c281528,0x2009dee1,0x236401e3,0x00000000}},	// [35db0] xtgr, usai_, öljs_, --, 
   {{0x2009dee2,0xa308066d,0xe81800c5,0x63a8002e}},	//   rsai_, _کرکے_, _दिना_, éend, 
   {{0x2009dee3,0x81740117,0x00000000,0x00000000}},	//   ssai_, _занӣ_, --, --, 
   {{0x7c29a0e0,0x20c400cf,0x200800c0,0x00000000}},	//   ttgr, _үйүм, psai_, --, 
   {{0x9ff40dd4,0x4ae0000d,0x98bc0210,0x00000000}},	//   _བསྒང_, _पलशव, _kawą_, --, 
   {{0x0f800014,0x00000000,0x00000000,0x00000000}},	//   _پیمُ, --, --, --, 
   {{0x3da402d5,0x7f4000d8,0x895c0241,0xe8e800ec}},	//   _зраб, ônqu, _átọ̀, ڱريو_, 
   {{0xb4e1dee4,0x7c29dee5,0xbd6800db,0x7e600108}},	//   _तले_, ptgr, _эрге_, änpu, 
   {{0xa3dc0c2e,0x48000108,0x00000000,0x00000000}},	//   _तंग_, апыв, --, --, 
   {{0x1a6401d3,0x32180076,0x00000000,0x00000000}},	//   _لیتی_, yrry_, --, --, 
   {{0x398000e8,0xab856f20,0xdb00020c,0x98140133}},	//   _añse_, _сутк, _njlé, ربکا, 
   {{0x63780208,0x00000000,0x00000000,0x00000000}},	//   _hình, --, --, --, 
   {{0xe81814cf,0x00000000,0x00000000,0x00000000}},	//   _दिया_, --, --, --, 
   {{0x69dc011c,0x3b040113,0xd01001d3,0xb7d400ec}},	//   _èrec, nanq_, یلز_, _ڪوڙا_, 
   {{0x69dc01ed,0x63780051,0xd25084a1,0x00000000}},	//   _éret, _mình, جنز_, --, 
   {{0x85000014,0x92e00154,0x637801e1,0x00000000}},	//   _پوٝن, দরে_, _yìnk, --, 
   {{0x00e12281,0x50b40108,0x00000000,0x00000000}},	// [35dc0] ржун, тсву, --, --, 
   {{0xb9000327,0xc474011a,0x7dc0000d,0xcdf4009d}},	//   _ཨཔ_, _סתיו_, võsa, вчды, 
   {{0x8d29dee6,0x11d400ae,0x00000000,0x00000000}},	//   доев_, _لتحد, --, --, 
   {{0x2d0c01f9,0x00000000,0x00000000,0x00000000}},	//   हणेल_, --, --, --, 
   {{0x3d042413,0x6c355b7c,0x63780051,0x00000000}},	//   हणजे_, افتا, _bình, --, 
   {{0x3b040007,0x09c82e35,0xfbcddee7,0x00000000}},	//   ganq_, ाग्य, يتو_, --, 
   {{0x63780241,0x7dc000e4,0x00000000,0x00000000}},	//   _sìnk, sõsa, --, --, 
   {{0x65bc0c6a,0x7be00022,0x9ac800e5,0x00000000}},	//   réhk, ыжәж, رگلہ_, --, 
   {{0x3b04083a,0x0b456549,0xf98ddee8,0x3f8c002e}},	//   banq_, _инан, تبو_, ëgug_, 
   {{0x3dbc0156,0x3b040369,0x6cc40220,0x29180e2d}},	//   _མཚོན, canq_, _айға, şra_, 
   {{0xf76c1473,0x96080184,0xfaa0039b,0xb89c0023}},	//   تاي_, ньяҡ_, _кафо, _ዝድግፍ_, 
   {{0x4990065f,0x241973ea,0x00000000,0x00000000}},	//   _خیبر, номы_, --, --, 
   {{0x15f80107,0x00000000,0x00000000,0x00000000}},	//   мнӯъ_, --, --, --, 
   {{0xc03c0092,0x00000000,0x00000000,0x00000000}},	//   _ዓላማው, --, --, --, 
   {{0x69dc315a,0xd5b000e5,0x00000000,0x00000000}},	//   _éres, _گفٹ_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x92e00183,0xdebc0023,0x00000000,0x00000000}},	// [35dd0] দৰে_, ሳይን_, --, --, 
   {{0x2ef5dee9,0x41c00b02,0x00000000,0x00000000}},	//   изур, _वीरस, --, --, 
   {{0x657c089c,0x9df8005b,0xa1944d01,0x00000000}},	//   oksh, хнет_, _банч, --, 
   {{0x657c6bfc,0x00000000,0x00000000,0x00000000}},	//   nksh, --, --, --, 
   {{0x5bdc185d,0x6ad00011,0xfbac00bc,0x00000000}},	//   मदेव, _স্লো, टवलम, --, 
   {{0x61e42747,0x2b4c0175,0x1a2848a5,0x00000000}},	//   _kuhl, _cadc_, ежки_, --, 
   {{0x61e5deea,0xe8000c2e,0x00000000,0x00000000}},	//   _juhl, लीसा_, --, --, 
   {{0xad240aaf,0x61e4974f,0x3b040369,0x2b4c0334}},	//   _پىكى, _muhl, sanq_, _eadc_, 
   {{0x61e41cea,0x63b401ed,0x63780051,0x00000000}},	//   _luhl, kozn, _tình, --, 
   {{0x7c39deeb,0x63b5deec,0x2ca000ae,0x657cecce}},	//   _ipur, jozn, úide_, eksh, 
   {{0x6aa40790,0x00000000,0x00000000,0x00000000}},	//   şifr, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf771deed,0x69dc02e8,0x3f81bd6c,0xf38401a9}},	//   _پاش_, _èrea, _olju_, иғим, 
   {{0x7c38556c,0x63b46262,0x8898011a,0x00000000}},	//   _mpur, gozn, _אבני, --, 
   {{0x4438020c,0x1b2400cc,0x00000000,0x00000000}},	//   _epq_, _মঘাই_, --, --, 
   {{0x7c38d853,0xd5b07245,0x6568005b,0x5ee000eb}},	//   _opur, _دفع_, öeht, _পড়লে, 
   {{0x3f800175,0xfbc00864,0x7c3801e1,0x90c5deee}},	// [35de0] _blju_, षताम, _npur, убае, 
   {{0x6d9801e4,0x6b98022e,0xc48000db,0x6ed80116}},	//   gŭan, xivg, _ылык, نداڭ_, 
   {{0x7c39deef,0x61e40097,0x71c40117,0x035400df}},	//   _apur, _guhl, _ванҷ, _עיטש_, 
   {{0x2b4ddef0,0x3f81def1,0x4c840408,0x00000000}},	//   _sadc_, _elju_, ллев, --, 
   {{0x6b98009b,0x7c380055,0x7bdc0309,0xaf0803d4}},	//   tivg, _cpur, íqup, ৰ্ষণ_, 
   {{0x7c3801fa,0x61e4014b,0x5c1401c0,0x0eb831af}},	//   _dpur, _yuhl, рьцу, _зубы_, 
   {{0x2b4c00de,0x00000000,0x00000000,0x00000000}},	//   _vadc_, --, --, --, 
   {{0xa815def2,0x63b400d0,0xd72001ad,0x3fe0000d}},	//   адиш, zozn, _माउथ_, _कूँआ_, 
   {{0xc17006a9,0xf7f0006c,0x87050fb6,0x2d841577}},	//   מחה_, یسید, ляне, _ilme_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x63b5def3,0xbf98011a,0x00000000,0x00000000}},	//   vozn, תייש, --, --, 
   {{0x44380221,0x7bcc04cc,0x637801e1,0xe45407ee}},	//   _ppq_, _ècur, _yìnw, акмы, 
   {{0x63b5def4,0x657ddef5,0x61e40030,0xf484eb49}},	//   tozn, rksh, _suhl, бурн, 
   {{0x83840220,0x61e40010,0x00000000,0x00000000}},	//   уыме, _puhl, --, --, 
   {{0x69c00ea0,0x363000e3,0x2d84000d,0x35980092}},	//   olme, _هريس, _olme_, መቻቸት_, 
   {{0x61e407a9,0x4438020b,0x00000000,0x00000000}},	//   _vuhl, _tpq_, --, --, 
   {{0x69c1def6,0x61e401f0,0x4439def7,0xb3800023}},	// [35df0] ilme, _wuhl, _upq_, _ሓገዝን_, 
   {{0x2d85def8,0x2bc40b9a,0x61e5def9,0x69c00112}},	//   _alme_, _लीला, _tuhl, hlme, 
   {{0x25a801e4,0x7c39defa,0xe3a40066,0x00000000}},	//   _kjal_, _spur, _مشگی, --, 
   {{0x69c08d34,0x5bdc00dc,0xdc542377,0x00000000}},	//   jlme, मद्व, ивењ, --, 
   {{0xacf80137,0x00000000,0x00000000,0x00000000}},	//   унчу_, --, --, --, 
   {{0x2d85defb,0x3f8005ce,0x25a801a9,0x9a142bbd}},	//   _elme_, _ulju_, _ljal_, афиш, 
   {{0x25a9bdd0,0xad4400db,0x69c002d2,0x737801e4}},	//   _ojal_, _گۉنۉ, flme, רגוד_, 
   {{0x25a8009a,0x69c1defc,0x00000000,0x00000000}},	//   _njal_, glme, --, --, 
   {{0x7c85defd,0x7d08b69b,0xac383c97,0x7c39defe}},	//   _суве, mags, _مسلط_, _upur, 
   {{0x7d09deff,0x25a8033d,0x6c840491,0x97740798}},	//   lags, _ajal_, _الكم, рѓиј, 
   {{0x21380240,0xc79401d3,0x00000000,0x00000000}},	//   _obsh_, جھنا_, --, --, 
   {{0x7d083604,0x69dc035b,0x00000000,0x00000000}},	//   nags, _érep, --, --, 
   {{0x25a80023,0x5fc4ac66,0x58040116,0x00000000}},	//   _djal_, वताल, _ئوتك, --, 
   {{0x7d08008c,0x7999df00,0x3ddc000f,0x00000000}},	//   hags, liuw, _liuw_, --, 
   {{0x03a0656c,0xd1940cfc,0x7d09279f,0x25a9df01}},	//   циро, ашањ, kags, _fjal_, 
   {{0x394c0af9,0x7998009f,0x05b002e9,0x217400db}},	//   _jags_, niuw, _وموح, буур, 
   {{0x7d09df02,0xd00886de,0x61e80115,0x09c800eb}},	// [35e00] dags, тезе_, ĉela, _লংমা, 
   {{0x799802b5,0xe81828f5,0xbdcc0150,0xa44401f7}},	//   hiuw, _दिसा_, _ﻗﺒﻭل_, _اَٿو, 
   {{0x69c0008e,0xcd050fa8,0x7998009f,0x4e28048a}},	//   ylme, ачли, kiuw, тоен_, 
   {{0x7d080194,0x7998009f,0x394c00ef,0x00000000}},	//   gags, jiuw, _nags_, --, 
   {{0x6c55df03,0xcb680f41,0xbf980129,0x0b44010b}},	//   склу, каде_, _evêq, индн, 
   {{0x7d080175,0x8e7402e8,0x00000000,0x00000000}},	//   aags, _кубч, --, --, 
   {{0x7d09df04,0x80d800bd,0xbea13e4e,0xaa5805d4}},	//   bags, যুদ্, _дарк, البا_, 
   {{0x637801e1,0x69c005c7,0x7d09df05,0x2d84000d}},	//   _hìnt, ulme, cags, _ulme_, 
   {{0x394c36f6,0x69c00008,0x25a80327,0xde540092}},	//   _dags_, rlme, _rjal_, _የሚነግ, 
   {{0x25a80250,0x3cf40118,0xc7c400d8,0x00000000}},	//   _sjal_, उँथे_, јсии, --, 
   {{0x394c06f2,0xe81806ff,0x49900bce,0x3ae800e5}},	//   _fags_, _दिवा_, _ویتر, _شبلی_, 
   {{0xba980375,0x00000000,0x00000000,0x00000000}},	//   _בסבי, --, --, --, 
   {{0xf76c16e6,0x25a80327,0x07a401af,0xc7a4117e}},	//   سای_, _vjal_, _кадн, _кидк, 
   {{0xf7402e91,0x38c803e6,0x7d0801f5,0xa3d401c6}},	//   _мечо, _شانی_, zags, согч, 
   {{0x41e402bf,0x25a80174,0x00000000,0x00000000}},	//   ріга, _tjal_, --, --, 
   {{0x25a80306,0xc059df06,0x00000000,0x00000000}},	//   _ujal_, кіз_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [35e10] --, --, --, --, 
   {{0x67294ef1,0x00000000,0x00000000,0x00000000}},	//   ngdj, --, --, --, 
   {{0x7d09df07,0x00000000,0x00000000,0x00000000}},	//   tags, --, --, --, 
   {{0xe1f80166,0x25b801f4,0x2d9400d4,0x00000000}},	//   _игү_, nosl_, оріс, --, 
   {{0x394c06f2,0x7d0955cc,0x1fe4015b,0x00000000}},	//   _rags_, rags, _পৌরস, --, 
   {{0x644c0451,0x7d09df08,0xe9b801ed,0x394ddf09}},	//   _msai, sags, ینوں_, _sags_, 
   {{0x7d09563b,0x7998020b,0x00000000,0x00000000}},	//   pags, tiuw, --, --, 
   {{0xe8183eaf,0x2128ae08,0x644ddf0a,0x46b8000d}},	//   _दिशा_, ngah_, _osai, _उड़ह, 
   {{0x7998334b,0x15b8054a,0x63780241,0x00000000}},	//   riuw, ғыны_, _yìnt, --, 
   {{0x18a47a32,0xab740491,0x394ddf0b,0xd789df0c}},	//   _қалм, _والإ, _wags_, اندو_, 
   {{0x644ddf0d,0x394ddf0e,0xd918447e,0x00000000}},	//   _asai, _tags_, _боец_, --, 
   {{0x7bc1df0f,0x63a806af,0xd468d964,0x6ad00154}},	//   llnu, éenn, гиме_, _স্কো, 
   {{0xa88400db,0x613000e5,0x00000000,0x00000000}},	//   _ولمى, zóló, --, --, 
   {{0x212801f5,0xd6281606,0xe62801d3,0x85400153}},	//   egah_, _боке_, دثین_, _šėto, 
   {{0x15f44352,0x644c0cc8,0x27e007c5,0x69c40135}},	//   _استح, _esai, _èina_, ċiev, 
   {{0x21290a4d,0x7bc0002f,0x00000000,0x00000000}},	//   ggah_, hlnu, --, --, 
   {{0x644c0036,0x3d0802a0,0xd1746171,0x00000000}},	// [35e20] _gsai, ारने_, _ғыны, --, 
   {{0xd7180183,0x6ef801f0,0xcee80395,0x212800b8}},	//   ত্ৰা_, рфаӣ_, удже_, agah_, 
   {{0x7bc00419,0x00000000,0x00000000,0x00000000}},	//   dlnu, --, --, --, 
   {{0xe8180574,0x0c846f78,0x644c003a,0x7bc0eb06}},	//   _दिला_, йылм, _ysai, elnu, 
   {{0xbf98017a,0x7d2800e5,0x00000000,0x00000000}},	//   _kwêl, ازمہ_, --, --, 
   {{0xd1b8001f,0xe9f80024,0x00000000,0x00000000}},	//   ሲዎች_, анкі_, --, --, 
   {{0x8e840597,0x0ef401f9,0x00000000,0x00000000}},	//   _الأه, ेरीस_, --, --, 
   {{0x7760009a,0x637801e1,0xad4400db,0x9a5400db}},	//   _annx, _jìnr, _گۉچۉ, زعىچ, 
   {{0xdd8001d9,0x637801e1,0x4c84020f,0xdc280472}},	//   _زیوٝ, _mìnr, _улав, _نسله_, 
   {{0xa61411ed,0x644c01c3,0x21280b97,0xb8fc1546}},	//   омоч, _rsai, zgah_, _धृ_, 
   {{0x4ac402de,0xda6c0451,0xba1409a6,0x00000000}},	//   _اياق, _لڏي_, _هيلا_, --, 
   {{0x6b8800e3,0x644c025c,0x27680066,0x00000000}},	//   _hldg, _psai, اشکی_, --, 
   {{0x45e40220,0x00000000,0x00000000,0x00000000}},	//   _ﺍﻟﻌﻼ, --, --, --, 
   {{0x48f0012c,0xb39c0051,0x00000000,0x00000000}},	//   ीरको_, _đểti, --, --, 
   {{0x212804fb,0x63780248,0xf76c1ec7,0x61e800df}},	//   tgah_, _bìnr, _ساو_, ĉelo, 
   {{0x60f8b78a,0x644ddf10,0x35a407fa,0xf194d3a6}},	//   рная_, _tsai, _најг, пись, 
   {{0x644ddf11,0x6b88f34d,0x2129df12,0x7bc003b2}},	// [35e30] _usai, _oldg, rgah_, ylnu, 
   {{0x3f8519ce,0x2128045a,0x7dc00254,0x00000000}},	//   ónu_, sgah_, põsk, --, 
   {{0xdcf81375,0x33f4030f,0x00000000,0x00000000}},	//   لفات_, _وسیس, --, --, 
   {{0xa159df13,0x6b88045f,0xad240131,0x00000000}},	//   _таму_, _aldg, كىمى, --, 
   {{0x6b881730,0x9f200075,0xdc6805f5,0xc10000ee}},	//   _bldg, _يۈرۈ, ралд_, _мүңл, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x99d41b06,0x00000000,0x00000000,0x00000000}},	//   يتبا, --, --, --, 
   {{0xa3e85345,0x09e03580,0x6b8808ce,0xceb002e4}},	//   यदा_, мощн, _eldg, _חיל_, 
   {{0xacf80276,0x7bc002f0,0x02f800cd,0x17f800ae}},	//   _ынту_, plnu, ्राह_, جربة_, 
   {{0xd708005b,0x00000000,0x00000000,0x00000000}},	//   шное_, --, --, --, 
   {{0x65bc00bc,0x969401d5,0xf6600166,0x00000000}},	//   véhr, юриш, ченү, --, 
   {{0x69d0032c,0x959402bf,0x2b40110c,0xd789df14}},	//   _डीपी, ішні, đice_, انگو_, 
   {{0x80d801ad,0x63780241,0xc47c00a2,0x6fd00166}},	//   पेमे, _rìnr, _ðîlş, läce, 
   {{0xd9b40a81,0xd3b802bf,0x6ad00154,0xdb0001e3}},	//   _أچھ, румі_, _স্টো, _eklö, 
   {{0x47d067b3,0xc79400f1,0x00000000,0x00000000}},	//   _تيور, _بانډ, --, --, 
   {{0x9c7c00e8,0xe800012c,0x00000000,0x00000000}},	//   _ngōo, लीका_, --, --, 
   {{0x387ddf15,0x4f09df16,0x25a8004b,0x10a428e8}},	// [35e40] nyur_, инан_, _ددوي_, циан, 
   {{0x9a780150,0x00000000,0x00000000,0x00000000}},	//   _әсiр, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8c4439fb,0x387c0280,0x226402fb,0x9db80108}},	//   жеде, kyur_, šský_, бычу_, 
   {{0xcf249d69,0x1cb4031c,0xfc2c3fe2,0x00000000}},	//   _ورسي, _ཛྙཱ_, نحو_, --, 
   {{0x5fc40490,0xa724009e,0xbad40150,0x09c000cd}},	//   वतःल, _ভস্ম_, _ﻀﺭﺒﺎ, शत्य, 
   {{0x69dc01e1,0x00000000,0x00000000,0x00000000}},	//   _èrek, --, --, --, 
   {{0x3ea40789,0x88a000fb,0x3d08043e,0x3b80008e}},	//   únte_, мғеһ, ारणे_, зләг, 
   {{0xd90cd968,0x5fa000db,0xaf500092,0x00000000}},	//   ایه_, _تەەم, _የማስፈ, --, 
   {{0x6b8801bf,0xe8000210,0x00000000,0x00000000}},	//   _uldg, लीगा_, --, --, 
   {{0x36d401c6,0xeaf801f9,0xfa9000b8,0x00000000}},	//   ждээ_, ुरीत_, _ṣaṇā, --, 
   {{0x387c00f2,0x7dc00254,0x25ac0254,0xdb2001f4}},	//   byur_, tõsi, õel_, ätöp, 
   {{0x27f80214,0xc7c800db,0x3d0815e0,0x349400db}},	//   _افتد_, _кыке_, ारते_, даяр, 
   {{0x6d9801e4,0xaa1400e4,0x82341541,0x5ec407d2}},	//   sŭah, hẽmi, يرزا, _ﺩﺍﯞﺭ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x35f40a8e,0x96b8004e,0x00000000,0x00000000}},	//   _برود_, _уучу_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [35e50] --, --, --, --, 
   {{0x63000efb,0x3ec40276,0x53d02e1e,0xc1e00116}},	//   _سۋرە, осеб, _दीपश, _ﺋﺎﺩﺍ, 
   {{0xdea000dd,0x3cf40118,0x00000000,0x00000000}},	//   ریری, उँले_, --, --, 
   {{0xdde801b9,0x00000000,0x00000000,0x00000000}},	//   لرچه_, --, --, --, 
   {{0x3c4400c6,0x705811dc,0xa0c40592,0x00000000}},	//   تضاف, _даяр_, _ريسو, --, 
   {{0x50d80375,0x00000000,0x00000000,0x00000000}},	//   _לקרא, --, --, --, 
   {{0xbd69df17,0x3da401ce,0x2364005b,0xc0700092}},	//   _крае_, _драб, öljy_, _ከመጠን_, 
   {{0xc1e00131,0x00000000,0x00000000,0x00000000}},	//   _ﺋﺎﺯﺍ, --, --, --, 
   {{0x7d18602b,0xb7b000cf,0x00000000,0x00000000}},	//   _idus, мөкч, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x387ddf18,0xb4b400e1,0x69c4025c,0x00000000}},	//   syur_, _जुड़_, ċier, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x45e402dd,0x00000000,0x00000000,0x00000000}},	//   _ﺍﻟﻜﻼ, --, --, --, 
   {{0xbb2c005e,0xc1e000d1,0x00000000,0x00000000}},	//   _ﯨﻠﻪ_, _ﺋﺎﺭﺍ, --, --, 
   {{0x7d1804b9,0x69d002ab,0xd1c81867,0x7e60005c}},	//   _odus, _डीडी, مبرم_, ånpl, 
   {{0x7d19df19,0x8678011a,0x5504004e,0xde540092}},	//   _ndus, _לרצו, _эпиб, _ከሚያገ, 
   {{0x53a41301,0x76400263,0x00000000,0x00000000}},	// [35e60] _наиб, _hpny, --, --, 
   {{0x7d19df1a,0xc4d0011a,0x00000000,0x00000000}},	//   _adus, _אגח_, --, --, 
   {{0x7d18022e,0xb8e80150,0x00000000,0x00000000}},	//   _bdus, _өкiн, --, --, 
   {{0xdd9800d6,0x00000000,0x00000000,0x00000000}},	//   оші_, --, --, --, 
   {{0x80600816,0x00000000,0x00000000,0x00000000}},	//   _звяж, --, --, --, 
   {{0x7d18049b,0xa0300e26,0x69dc01ed,0x8d9401d9}},	//   _edus, _جۉكت, _érez, _کٔرت, 
   {{0x5ec401a9,0x00000000,0x00000000,0x00000000}},	//   _жирғ, --, --, --, 
   {{0xda64143e,0x00000000,0x00000000,0x00000000}},	//   باهي, --, --, --, 
   {{0x6d4003ac,0xc95801d5,0x8b240064,0x00000000}},	//   _ibma, _ҳўл_, _ндае, --, 
   {{0x0ba800cf,0x00000000,0x00000000,0x00000000}},	//   _اارى_, --, --, --, 
   {{0x7bdc004a,0xda6486bf,0x2e18007f,0xfb1001f7}},	//   ïque, _يامي, nčf_, _سونج, 
   {{0xb7d4066d,0xa3e80cb2,0x80ac012d,0x00000000}},	//   _ہونا_, यदल_, ंपमे, --, 
   {{0x2ef804cc,0x6d400427,0x00000000,0x00000000}},	//   _ofrf_, _mbma, --, --, 
   {{0x4668edb5,0x77f4011a,0x00000000,0x00000000}},	//   _грим_, _צמוד_, --, --, 
   {{0x6d4008a4,0x00000000,0x00000000,0x00000000}},	//   _obma, --, --, --, 
   {{0x31c403b7,0xd6a802da,0x00000000,0x00000000}},	//   есув, _بدهم_, --, --, 
   {{0xe8000073,0xc0580212,0xdebc0b82,0x00000000}},	// [35e70] लीचा_, щів_, ዳይን_, --, 
   {{0x4429df1b,0x6d4003fa,0x3e68004e,0x00000000}},	//   muc_, _abma, йшен_, --, 
   {{0x4429df1c,0x6d40037e,0x645c2ab7,0xa19402d5}},	//   luc_, _bbma, lvsi, _жанч, 
   {{0x39a0026c,0x5ff4016c,0xe0d00014,0x6f1c0142}},	//   _mèsè_, _озму, _لٲج_, _edrc, 
   {{0x4429df1d,0x6d4002b9,0x657c02d3,0xf0440064}},	//   nuc_, _dbma, ërhy, _пэро, 
   {{0x6f1c0077,0x442802c4,0xbf98002d,0x6d41df1e}},	//   _gdrc, iuc_, _stêf, _ebma, 
   {{0x4429df1f,0x6d400332,0x645c06be,0x00000000}},	//   huc_, _fbma, hvsi, --, 
   {{0x7d19df20,0xe81821b1,0x2b40110c,0x6d400332}},	//   _udus, _दिखा_, đica_, _gbma, 
   {{0x442808ad,0xa3bc00bc,0x73f800cc,0x00000000}},	//   juc_, इका_, _অট্ট_, --, 
   {{0x4429df21,0x64400311,0x6294003e,0x81b00154}},	//   duc_, ălil, kzzo, টতি_, 
   {{0x4429df22,0x7c29df23,0x00000000,0x00000000}},	//   euc_, lugr, --, --, 
   {{0x9c7c02b1,0x4428004e,0x645c022e,0x00000000}},	//   _ngōk, fuc_, fvsi, --, 
   {{0x7c29df24,0x1a6404d3,0x2e180100,0x00000000}},	//   nugr, _ریکی_, zčf_, --, 
   {{0x97c4010b,0xe0c400cc,0x00000000,0x00000000}},	//   _юйле, ্শাভ, --, --, 
   {{0x0ca9df25,0x7640020b,0xe2b412cf,0x00000000}},	//   _कश्म, _upny, естэ, --, 
   {{0x6f1c004e,0x7c29df26,0x00000000,0x00000000}},	//   _sdrc, kugr, --, --, 
   {{0x6f1c0230,0x6294011c,0xd838003e,0xc8d8010f}},	// [35e80] _pdrc, azzo, ntō_, ַקעט, 
   {{0x9e5c00b7,0x96d000bc,0x7c28000d,0x6e3c0092}},	//   _ሰላምና_, _हराउ, dugr, _አላግባ, 
   {{0x422005f5,0x20180254,0x910400d8,0x00000000}},	//   _идэв, _evsi_, _опне, --, 
   {{0x3ea40491,0x7c295e21,0xaa580107,0xd7b001f9}},	//   únta_, fugr, ҷику_, ीकडच, 
   {{0x7c28a873,0x61e000db,0x42a40023,0x00000000}},	//   gugr, ïlle, _ጊላነት_, --, 
   {{0xaa580957,0xaca4063f,0x6f1c0b4b,0x6d40020b}},	//   зику_, _nsụp, _udrc, _wbma, 
   {{0x32180109,0x7dc000c5,0x33f4f024,0x00000000}},	//   nsry_, tõst, _läx_, --, 
   {{0xd90c2c6c,0xaca4063f,0x9d500014,0x6d40035a}},	//   میم_, _asụp, _مۆمت, _ubma, 
   {{0x7c28026c,0x4428004e,0x39a001e1,0x00000000}},	//   cugr, xuc_, _sèsè_, --, 
   {{0x80d82f04,0xfc64034c,0x8b6579b5,0x44280841}},	//   যুক্, _تخفی, _تارم, vuc_, 
   {{0xe53470c9,0x46680212,0x00000000,0x00000000}},	//   нень, іром_, --, --, 
   {{0x4428454c,0x89146bd8,0x39a002e2,0x00000000}},	//   tuc_, _آبائ, _vèsè_, --, 
   {{0xd838003a,0x0eec000d,0xb8d000cc,0x00000000}},	//   ctō_, _जलूस_, _টৰ_, --, 
   {{0xf64c00b2,0x645c0082,0xc7644c2d,0x6294002f}},	//   _چئي_, rvsi, _زاتى, tzzo, 
   {{0x4429df27,0x9470350a,0x7c29df28,0x9f480098}},	//   suc_, نگیا, zugr, _ékék_, 
   {{0x69c1df29,0x6294026c,0x44284168,0x00000000}},	//   nome, rzzo, puc_, --, 
   {{0x9e7404d3,0x69c00810,0xc2e8007b,0x44280393}},	// [35e90] کهات, iome, _وعدم_, quc_, 
   {{0x69c1df2a,0x6ea00037,0x7c2803b2,0x69d004aa}},	//   home, _गेहु, vugr, _डीसी, 
   {{0x3d088687,0x62800793,0x00000000,0x00000000}},	//   ारले_, älod, --, --, 
   {{0x7c29df2b,0xbf980b21,0x69c00034,0xc0dc02d3}},	//   tugr, _stêd, jome, ቓልል_, 
   {{0x69c1df2c,0x7c64004e,0xbad000d1,0x00000000}},	//   dome, باال, ﻟﻘﺌﺎ, --, 
   {{0x7c280579,0x9f05df2d,0xedd40131,0x6ee40eff}},	//   rugr, _سورو, ىيەد, رسەل, 
   {{0x69c1df2e,0xdd95df2f,0xb4bc02c3,0x00000000}},	//   fome, _завы, _अड्_, --, 
   {{0x69c00943,0xf99c0ffb,0xeab1df30,0x7c29df31}},	//   gome, òè_, جعه_, pugr, 
   {{0x9f48030a,0xdd0c0210,0xedbc032e,0x1bb40024}},	//   lpañ_, półz, _þóað_, _збаў, 
   {{0x96b87937,0x9c7c02b5,0x33f40166,0x7dc00254}},	//   зуму_, _ngōi, _räx_, põss, 
   {{0x69c1df32,0x21f4005c,0x69d02e05,0x33f40166}},	//   bome, _nåh_, _डीवी, _säx_, 
   {{0xceb00bd4,0x3b040175,0x00000000,0x00000000}},	//   ריט_, lbnq_, --, --, 
   {{0x18690341,0xa978010a,0x00000000,0x00000000}},	//   _хали_, _юйцу_, --, --, 
   {{0x32180ea0,0x33f4007c,0x06800166,0x52747fec}},	//   tsry_, _väx_, _әгън, нубу, 
   {{0xd25002f2,0x00000000,0x00000000,0x00000000}},	//   دنز_, --, --, --, 
   {{0x69dcce4a,0x00000000,0x00000000,0x00000000}},	//   _èret, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [35ea0] --, --, --, --, 
   {{0x69c1df33,0x2b9000e8,0x00000000,0x00000000}},	//   zome, _màcc_, --, --, 
   {{0x69c1df34,0x2b9000e8,0xa3bc05d7,0xef9407d6}},	//   yome, _làcc_, इकर_, _ییرد, 
   {{0x69c1df35,0x6fd000e1,0x00000000,0x00000000}},	//   xome, _तीरं, --, --, 
   {{0x69c1df36,0x8ba40801,0xdb08002d,0x2b90002e}},	//   vome, нидж, _ûnûn, _nàcc_, 
   {{0x69c1df37,0x00000000,0x00000000,0x00000000}},	//   wome, --, --, --, 
   {{0xc330008f,0x69c06460,0x9f480d12,0xbb1401f7}},	//   אוו_, tome, mpað_, رزوا_, 
   {{0xddb800db,0x2adc00cd,0x6e200055,0x00000000}},	//   _жууш_, गेषु_, _āmbh, --, 
   {{0x2b9000e8,0x00000000,0x00000000,0x00000000}},	//   _càcc_, --, --, --, 
   {{0x69c1df38,0x8034010f,0xcac800f3,0x00000000}},	//   some, עניע_, _егзе_, --, 
   {{0x69c1df39,0x65946dac,0x9f4803b2,0x00000000}},	//   pome, вану, ipað_, --, 
   {{0x2b9000e8,0xa6840166,0x69c1df3a,0x00000000}},	//   _fàcc_, елүд, qome, --, 
   {{0xa3bc03f8,0x05840139,0xb92016cc,0x00000000}},	//   इकल_, _җуйм, _صفوي, --, 
   {{0x35f4028e,0xca2c0150,0x27680066,0x00000000}},	//   برید_, _ﺩﻤﺕ_, _زشتی_, --, 
   {{0x69dc1a44,0xf770010f,0xdce80171,0x00000000}},	//   _ères, _תקצ_, _smeļ, --, 
   {{0xf1a5df3b,0x2720190e,0x78c402d2,0x00000000}},	//   грун, _मयुर_, _ísvé, --, 
   {{0x656ddf3c,0x2b9000e8,0x00000000,0x00000000}},	// [35eb0] _inah, _xàcc_, --, --, 
   {{0x6dbc02f0,0x00000000,0x00000000,0x00000000}},	//   nčaf, --, --, --, 
   {{0xa2940826,0xb284004e,0x00000000,0x00000000}},	//   _рані, _быяк, --, --, 
   {{0x9f480156,0x00000000,0x00000000,0x00000000}},	//   rpañ_, --, --, --, 
   {{0xc0d476e2,0xd1140302,0x656c01f7,0x272009b2}},	//   ክራሲ_, _בקרה_, _mnah, _मयूर_, 
   {{0x3f8400c5,0x8b20005b,0x61e801e4,0x8f5000db}},	//   önud_, адше, ĉelu, _ۅچۅش, 
   {{0xce3400c7,0x2b901bce,0xaed59eba,0x59740108}},	//   _аҟхш_, _sàcc_, _борш, выпу, 
   {{0x2b901bce,0x6a641291,0x00000000,0x00000000}},	//   _pàcc_, اطول, --, --, 
   {{0x6e200055,0x00000000,0x00000000,0x00000000}},	//   _āmbi, --, --, --, 
   {{0x6e6801d9,0x8c840022,0x7a0c0055,0x00000000}},	//   _تمہِ_, _шәха_, _ṛtut, --, 
   {{0x44380140,0x2b900694,0xc95401b9,0x00000000}},	//   _aqq_, _wàcc_, رلیش_, --, 
   {{0x7bc1df3d,0x2b90002e,0x00000000,0x00000000}},	//   lonu, _tàcc_, --, --, 
   {{0x660401a6,0xd1302d20,0x00000000,0x00000000}},	//   _čike, یمس_, --, --, 
   {{0x7bc1df3e,0xd628004e,0xd37000ec,0xe35401c6}},	//   nonu, _жоке_, جهس_, лтсэ, 
   {{0x4438013c,0x80dc015b,0x7bc0054e,0x3c3800e4}},	//   _eqq_, _ফ্ল্, ionu, hêv_, 
   {{0x7bc1a943,0x15440124,0x4438003a,0x637801e1}},	//   honu, _реим, _fqq_, _mìny, 
   {{0x7c38009a,0x4fe846dd,0x00800153,0x00000000}},	// [35ec0] _nqur, дман_, алто, --, 
   {{0xdf881aac,0x7bc1df3f,0x63a8002e,0x00000000}},	//   ɔ́kɔ_, jonu, éent, --, 
   {{0x7bc003b4,0x1fb42bf6,0x7c380309,0xbf980142}},	//   donu, устр, _aqur, _stêc, 
   {{0x4c847579,0x00000000,0x00000000,0x00000000}},	//   клев, --, --, --, 
   {{0x7bc135f4,0xbc340592,0x9f480321,0x20d401ec}},	//   fonu, نسوا_, ppað_, _бірс, 
   {{0x7bc1df40,0xbf98002d,0x9c7c00b0,0x80ac0073}},	//   gonu, _dwês, _ngōu, ंपरे, 
   {{0x5b1800cf,0x00000000,0x00000000,0x00000000}},	//   رعوڭ_, --, --, --, 
   {{0x7bc00618,0x00000000,0x00000000,0x00000000}},	//   aonu, --, --, --, 
   {{0x2e3c0008,0x8c440640,0xfce002e8,0xc7b80108}},	//   líf_, _језе, _вото, дён_, 
   {{0x656c0122,0x7bc03344,0xa7754af5,0x7c2401c6}},	//   _snah, conu, улоч, _шоуг_, 
   {{0x44399e7e,0x6d8800e4,0x7c3801a9,0x00000000}},	//   _sqq_, _pÿah, _zqur, --, 
   {{0x8919df41,0x39b40356,0x00000000,0x00000000}},	//   _آغاز_, răsc_, --, --, 
   {{0x338c044e,0x6dbc3879,0x487400f2,0x00000000}},	//   _ሓሙሽተ_, mčad, _جداس, --, 
   {{0x22580184,0x62340261,0xc4d000e1,0x53b46518}},	//   нигы_, легу, _सरीख, лғыр_, 
   {{0x248cb832,0xf31401c6,0xc66801ec,0xeaf00037}},	//   šem_, рдсэ, _ішке_, _चलैत_, 
   {{0x7bc1df42,0x6dbc1050,0x80ac01ad,0xa5340114}},	//   zonu, nčad, ंपले, _снич, 
   {{0x7bc02c6f,0x45a00131,0x84500116,0x00000000}},	// [35ed0] yonu, _مەھك, _ئىخچ, --, 
   {{0x44280334,0x7bc00381,0x3e0402e8,0xe72c00a2}},	//   mrc_, xonu, вядв, _ýeńş, 
   {{0x63a401ab,0x44280472,0x7bc1df43,0x72c8010a}},	//   _imhn, lrc_, vonu, _аçтă, 
   {{0x4328069c,0xad2410a8,0x6dbc00f3,0xdcb80139}},	//   _እምበኣ, لىمى, jčad, нгеч_, 
   {{0x7bc1df44,0x1b488094,0x637801e1,0x00000000}},	//   tonu, езли_, _sìny, --, 
   {{0x44281552,0xda59df45,0x00000000,0x00000000}},	//   irc_, ериш_, --, --, 
   {{0x4429df46,0x00000000,0x00000000,0x00000000}},	//   hrc_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7bc1df47,0x7c39df48,0x57e86d8c,0x63a400a3}},	//   ponu, _uqur, ндим_, _omhn, 
   {{0xfaa40372,0x7bc09169,0x44280810,0xac942f89}},	//   _ишен, qonu, drc_, _тауш, 
   {{0x4429df49,0xab8400f7,0x993442f4,0x00000000}},	//   erc_, _тутк, _مفات, --, 
   {{0xd7c800aa,0x4428bf3f,0x00000000,0x00000000}},	//   _ګوته_, frc_, --, --, 
   {{0x28f80ce7,0xdce863e0,0x7e64004e,0x44280109}},	//   _речь_, _oneč, _lrjp, grc_, 
   {{0xf7708380,0x395ddf4a,0x63a400a3,0x6dbc0cf4}},	//   _خاص_, ldus_, _cmhn, pčag, 
   {{0x4429df4b,0x395c0cf8,0x00000000,0x00000000}},	//   arc_, odus_, --, --, 
   {{0x395ddf4c,0x13040131,0xc6d800df,0x00000000}},	//   ndus_, _өзим, _אַחר, --, 
   {{0xdb0000dd,0x75242959,0x4428009a,0x395ddf4d}},	// [35ee0] _emlé, _idiz, crc_, idus_, 
   {{0xcdf405f5,0x00c40228,0x395c02f6,0x2e3ddf4e}},	//   гчды, улук_, hdus_, tíf_, 
   {{0x11d5df4f,0x7c2801f5,0x6fd00267,0x395c020c}},	//   _متحد, ergr, läck, kdus_, 
   {{0x4278008f,0xd1b007d6,0x2e3c00d0,0x00000000}},	//   _נאכג, _ایرک, ríf_, --, 
   {{0x395c0cfd,0x7524009a,0x432802d3,0x6fd03468}},	//   ddus_, _mdiz, _እምብኣ, näck, 
   {{0x3161df50,0x8f7402bf,0xdce80219,0xbc640123}},	//   ldiz_, _сумі, _gneč, امون_, 
   {{0x2d9c20ef,0x3d080490,0x7c29df51,0xaa94030d}},	//   èves_, ारखे_, argr, рийч, 
   {{0x3161df52,0x7525df53,0xdce80122,0x395c003a}},	//   ndiz_, _ndiz, _zneč, gdus_, 
   {{0xaf6c001f,0x478400cf,0x00000000,0x00000000}},	//   _ለማስፈ, гынб, --, --, 
   {{0x7525df54,0xada40116,0x395ddf55,0x6fd0007c}},	//   _adiz, _сағл, adus_, däck, 
   {{0x44280784,0xf1c4a5b3,0xb7600139,0x00000000}},	//   wrc_, वकान, стый, --, 
   {{0x88c403d4,0x5a95df56,0xda6c05d9,0xe61800f7}},	//   শেষক, _труф, _آڏو_, ндү_, 
   {{0x7dd8010e,0x4428030a,0xc7c40d1d,0x00000000}},	//   _häsý, urc_, _йски, --, 
   {{0x7525df57,0x389800df,0x00000000,0x00000000}},	//   _ediz, _אידנ, --, --, 
   {{0x4429df58,0x6fd017da,0x6594010a,0x86240006}},	//   src_, mäch, _вайу, _сьле, 
   {{0x44280354,0x6fd14c87,0x00000000,0x00000000}},	//   prc_, läch, --, --, 
   {{0xa0743298,0x69dc3c71,0xe7b800cc,0xe3a400f2}},	// [35ef0] шгач, _पठनी, ুগীয, _نشدی, 
   {{0x644ddf59,0x6fd00730,0x98ac00b0,0x395c0024}},	//   _ipai, näch, ngeā_, zdus_, 
   {{0x9c7c00b0,0x395ddf5a,0x3e0403c5,0x00000000}},	//   _ngōr, ydus_, уязв, --, 
   {{0x644c03a2,0x6fd00b70,0xc0d40092,0x00000000}},	//   _kpai, häch, ክራል_, --, 
   {{0x7c28057b,0x16d00807,0x40845889,0x00000000}},	//   urgr, _हर्ब, _сунб, --, 
   {{0x20085088,0x644c0109,0xda640f84,0x3f8c00e2}},	//   mpai_, _mpai, لاعي, īgus_, 
   {{0x6fd048b3,0x6fb401d9,0x644c0055,0x00000000}},	//   däch, _امّا, _lpai, --, 
   {{0x395ddf5b,0x644c0588,0xdce8031c,0x2008002d}},	//   udus_, _opai, _eleġ, opai_, 
   {{0x3f8008ad,0x2009df5c,0x644ddf5d,0x66041ff1}},	//   _koju_, npai_, _npai, _čika, 
   {{0x31600369,0x200804cc,0x6fd00267,0x3f81df5e}},	//   zdiz_, ipai_, väck, _joju_, 
   {{0x3f803858,0x597402d5,0x20080332,0x00000000}},	//   _moju_, _вылу, hpai_, --, 
   {{0x657c02d3,0x63b40399,0x6fd001e6,0x644c007b}},	//   gjsh, enzn, täck, _bpai, 
   {{0xdff000e1,0xf80400a8,0xb16400fb,0x00000000}},	//   _अंगद_, _счен, ҙнаһ, --, 
   {{0x6fd004f3,0x3f800117,0x88980375,0x657c036e}},	//   räck, _noju_, _בבני, ajsh, 
   {{0x644ddf5f,0x6fd0687f,0x46a0013e,0x20080024}},	//   _epai, säck, _машв, epai_, 
   {{0x3f8008e7,0xd130bf17,0x75240472,0x6fd0b83f}},	//   _aoju_, تمر_, _udiz, päck, 
   {{0x3f8007f5,0x3161df60,0xcef414b7,0xc4800395}},	// [35f00] _boju_, rdiz_, ачењ, _млък, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x29fc0115,0x20080421,0x3f81df61,0xa2cc05c0}},	//   _aĉan_, apai_, _doju_, _दुप्, 
   {{0x59d4134e,0x00000000,0x00000000,0x00000000}},	//   _डीलर, --, --, --, 
   {{0x3f800ca8,0x62800b34,0x23ac0427,0xdd8c00d1}},	//   _foju_, ølov, lžja_, رۈك_, 
   {{0xce4818ce,0xca2406ed,0xab380640,0x61f00a87}},	//   _изге_, афии, упку_, _óklá, 
   {{0xdce8025c,0x00000000,0x00000000,0x00000000}},	//   _vleġ, --, --, --, 
   {{0x6fd03262,0x66080334,0x094800d8,0x8fa401f0}},	//   wäch, vpdk, тчки_, _саҳе, 
   {{0x2d85df62,0xa2cc6211,0x3f8001e1,0x00000000}},	//   _iome_, _दुन्, _yoju_, --, 
   {{0x2d84f755,0x25700109,0x00000000,0x00000000}},	//   _home_, kôlà_, --, --, 
   {{0x2d85df63,0x6fd00730,0x0ae806f6,0x3d080490}},	//   _kome_, räch, _شرطي_, ारचे_, 
   {{0x6fd001cf,0xfd800075,0x20080263,0x2d8563c5}},	//   säch, ﯩﻐﺎﻥ_, ypai_, _jome_, 
   {{0x2d850885,0x6fd0002f,0xf4840022,0x00000000}},	//   _mome_, päch, оурн, --, 
   {{0x316c013f,0x6fd00784,0x628001f4,0x00000000}},	//   _ɔdze_, qäch, äloo, --, 
   {{0x3f800022,0x00000000,0x00000000,0x00000000}},	//   _roju_, --, --, --, 
   {{0x2d85df64,0x3f81df65,0xdef01954,0x9ed801ec}},	//   _nome_, _soju_, ልዋን_, қмет_, 
   {{0x644ddf66,0x25a9df67,0x5f94039b,0x3f81df68}},	// [35f10] _upai, _imal_, биат, _poju_, 
   {{0x99500232,0x2009df69,0x2d840810,0x25a80295}},	//   _máš_, rpai_, _aome_, _hmal_, 
   {{0x2d85df6a,0x25a80010,0x200800db,0x80a404af}},	//   _bome_, _kmal_, spai_, _घेरे, 
   {{0x2d846fd3,0x5c7465a7,0x200854e5,0xd254008d}},	//   _come_, йлет, ppai_, _פשרה_, 
   {{0x995003c6,0x25a800fb,0x2d84123b,0x3f81df6b}},	//   _náš_, _mmal_, _dome_, _toju_, 
   {{0x3f8000c0,0x77840023,0xf458011a,0x00000000}},	//   _uoju_, _ዝፈትዋ_, יידר_, --, 
   {{0x5e940597,0x2d85df6c,0x25a800af,0xa2cc2c2e}},	//   _الأط, _fome_, _omal_, _दुम्, 
   {{0x2d8418f7,0xa9c40ee8,0xdb0000ae,0x6dbc0419}},	//   _gome_, يزيو, _imlí, rčac, 
   {{0x7c84010b,0x3a8001d9,0x00000000,0x00000000}},	//   _туве, _ڈیشِ, --, --, 
   {{0x25a9df6d,0x23600198,0x2d84009a,0x995002fb}},	//   _amal_, _nahj_, _zome_, _dáš_, 
   {{0x2d84014b,0x16a89a5c,0x9f58008e,0x00000000}},	//   _yome_, увни_, _itsä_, --, 
   {{0xceb025f9,0x25a801ab,0x57b400db,0x00000000}},	//   ליי_, _cmal_, рбүт, --, 
   {{0x69d03885,0xff140241,0xa2cc6480,0x00000000}},	//   _डीटी, _ẹ̀wù_, _दुब्, --, 
   {{0x25a9df6e,0x79980198,0x69c4063f,0x67640014}},	//   _emal_, lhuw, ịstị_, _وُنل, 
   {{0x03a0013e,0x00000000,0x00000000,0x00000000}},	//   чиро, --, --, --, 
   {{0xc2407969,0x79980433,0x64400083,0x10a41180}},	//   янск, nhuw, ălir, бибн, 
   {{0xc0e0119e,0xdb0000ae,0x4f24001b,0x00000000}},	// [35f20] зотк, _amlí, йдаб, --, 
   {{0x2d8420c6,0x3ddc011f,0x79980113,0xdf2800ae}},	//   _some_, _ahuw_, hhuw, لأمن_, 
   {{0x7999da10,0xc7d40302,0x2d8400ca,0xe4c82b3c}},	//   khuw, צועי_, _pome_, _مبین_, 
   {{0x8d19447b,0x51f401c8,0x00000000,0x00000000}},	//   ازار_, _پسگر, --, --, 
   {{0xdb0001ed,0x79980214,0x8538011a,0x00000000}},	//   _emlí, dhuw, רגני, --, 
   {{0x2d84014b,0x69d03885,0x00000000,0x00000000}},	//   _wome_, _डीजी, --, --, 
   {{0x2d841326,0xbb447cbc,0xd90c036b,0x66040e04}},	//   _tome_, صلين_, چیم_, _čiko, 
   {{0x7998409c,0xd90cb167,0xbb48037e,0x59d40412}},	//   ghuw, نیم_, _cgiゲ_, _डीआर, 
   {{0x3c4801b9,0x98ac0419,0x0c24004e,0xacb40244}},	//   _مثلی_, adeľ_, _ыман, _بڕاب, 
   {{0x99500745,0x799802b5,0x779400db,0x00000000}},	//   _váš_, ahuw, йкыр_, --, 
   {{0x7999d8e9,0x351801c0,0x1d400092,0xf1c8c126}},	//   bhuw, өжээ_, _የምእመ, लवान, 
   {{0x7999df6f,0x59640014,0x38c803e6,0x628001f4}},	//   chuw, _ودنٲ, _ڵانی_, älom, 
   {{0x47840598,0x00000000,0x00000000,0x00000000}},	//   _гыйб, --, --, --, 
   {{0xe694023a,0x73d8010b,0x00000000,0x00000000}},	//   _милы, йдяр_, --, --, 
   {{0x1b1c11ba,0xdb000142,0x00000000,0x00000000}},	//   _নামে_, _ymlâ, --, --, 
   {{0x26dddf70,0x25a80067,0x00000000,0x00000000}},	//   _izvo_, _umal_, --, --, 
   {{0x349401fe,0xf0c00150,0x00000000,0x00000000}},	// [35f30] _наър, ектi_, --, --, 
   {{0x5edc0154,0x00000000,0x00000000,0x00000000}},	//   _বলবে, --, --, --, 
   {{0x2bdc13da,0x9e1400d4,0x00000000,0x00000000}},	//   यतना, ідді, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x79980943,0x913800c8,0xa2cc000d,0x769c0241}},	//   vhuw, _דערק, _दुत्, _káyé, 
   {{0x60dc00e2,0x7998020c,0x9f500200,0x91e400d1}},	//   _izsm, whuw, _mizë_, _ﺋﺎﯕﻼ, 
   {{0xdd95d87d,0x2a6c01c8,0x7999df71,0x6dbc627e}},	//   _давы, _crdb_, thuw, mčan, 
   {{0x1988c48f,0x7f54003a,0x6dbc23cc,0x769c0241}},	//   рбии_, lexq, lčan, _láyé, 
   {{0x26dc006f,0x7d18045f,0x7998472e,0x6fb000fe}},	//   _azvo_, _ieus, rhuw, _জীয়ে, 
   {{0x6dbc05ce,0x7d19df72,0x2b4c0048,0x2ca001c3}},	//   nčan, _heus, _gbdc_, ùide_, 
   {{0x98b805f3,0x2a6c070d,0x7d19df73,0xcb1002e4}},	//   ısı_, _grdb_, _keus, _חלב_, 
   {{0x7d180363,0xd8a805d9,0x6dbc0427,0x1dc807d0}},	//   _jeus, _پهتو_, hčan, िकित, 
   {{0x7d19df74,0xe6b4036b,0x29c8009f,0x00000000}},	//   _meus, قلیگ, _اِنَ_, --, 
   {{0x7d19df75,0x2b9008c2,0x00000000,0x00000000}},	//   _leus, _càch_, --, --, 
   {{0x29fc01e4,0x1544185c,0x776002d0,0x1dc8085c}},	//   _aĉaj_, _дейм, _ianx, िकात, 
   {{0x76400369,0x9f58036e,0x7760036e,0x00000000}},	//   _iqny, _fusë_, _hanx, --, 
   {{0xf5e800ec,0x72a400d1,0x00000000,0x00000000}},	// [35f40] _پڙھي_, زەڭن, --, --, 
   {{0x4e948dca,0x7d180036,0x2b9001ab,0x3fe002bf}},	//   يشار, _aeus, _gàch_, джув, 
   {{0x7d19df76,0x9f5002bd,0x00000000,0x00000000}},	//   _beus, _mizè_, --, --, 
   {{0x7d1801c3,0x00000000,0x00000000,0x00000000}},	//   _ceus, --, --, --, 
   {{0x7d19df77,0x7c800b32,0xcbe40474,0x6dbc0306}},	//   _deus, дуще, оцки, bčan, 
   {{0xc0f00020,0x77600117,0x7d180ea0,0x7bcc0055}},	//   ልካም_, _nanx, _eeus, _ūcur, 
   {{0x6f1ddf78,0x7d19df79,0xfe40014b,0x00000000}},	//   _ierc, _feus, _онро, --, 
   {{0x6f1c2f61,0x8d9401d9,0x7d180438,0xa6f4013e}},	//   _herc, _بٔرت, _geus, ӯзиш, 
   {{0x6f1ddf7a,0x7761b7b3,0x6d4000ac,0xc198008f}},	//   _kerc, _banx, _icma, ישקי, 
   {{0x7761df7b,0x7d182fce,0x6f1c0010,0x478800a7}},	//   _canx, _zeus, _jerc, рсим_, 
   {{0x6f1ddf7c,0x9f50007f,0x7d19df7d,0xf76c007b}},	//   _merc, _dizè_, _yeus, ئاً_, 
   {{0xb3880020,0x769c0241,0x00000000,0x00000000}},	//   _ሚሊየን_, _sáyé, --, --, 
   {{0x7760005a,0x6f1c02d0,0x00000000,0x00000000}},	//   _fanx, _oerc, --, --, 
   {{0x6f1ddf7e,0x77600137,0x6d400175,0x9f500240}},	//   _nerc, _ganx, _lcma, _vizë_, 
   {{0x6dbc04b9,0x6594016c,0x77900214,0x6b88005c}},	//   včan, _наку, _آیپا, _modg, 
   {{0x60f9df7f,0x6f1c2d45,0x6b89df80,0xe69401ee}},	//   сная_, _aerc, _lodg, _миһы, 
   {{0x7d19df81,0x6f1ddf82,0x6b880c8c,0x2b9001ab}},	// [35f50] _reus, _berc, _oodg, _tàch_, 
   {{0xdfd016a2,0x3e69df83,0x7d18562c,0x6d41df84}},	//   ريا_, ишен_, _seus, _acma, 
   {{0x3ea5df85,0x6dbddf86,0x7d19df87,0x41e400c0}},	//   ànt_, rčan, _peus, _міма, 
   {{0x71f8c284,0x6f1c03ac,0xa2d401e2,0x00000000}},	//   _گریس_, _eerc, _ويکت, --, 
   {{0x6dbc07f5,0x6f1ddf88,0x7d19df89,0xdc6801c6}},	//   pčan, _ferc, _veus, салд_, 
   {{0x6b89df8a,0x7d1800ec,0x6f1c05d1,0x5da40014}},	//   _codg, _weus, _gerc, _کمرٕ, 
   {{0x3a544bcf,0x69c46f98,0x7760004e,0x7d1826c1}},	//   تیاج_, čien, _ranx, _teus, 
   {{0x7761df8b,0x6f1c1570,0x6dbc15ad,0x7d18014b}},	//   _sanx, _zerc, nčal, _ueus, 
   {{0xa3bc02f8,0x7761df8c,0xa2cc5690,0x6f1ddf8d}},	//   ेका_, _panx, _दुस्, _yerc, 
   {{0xb3880201,0x77600429,0x6b888007,0x6dbc0427}},	//   _ሚሊዮን_, _qanx, _godg, hčal, 
   {{0x645c0175,0x6d4002d0,0x00000000,0x00000000}},	//   ewsi, _ycma, --, --, 
   {{0x9f58003e,0x2905df8e,0x7761df8f,0x99500030}},	//   _dusé_, ccma_, _wanx, _báť_, 
   {{0x6b88036b,0x1ca8025c,0x7761df90,0x9f50007f}},	//   _yodg, _བཟས_, _tanx, _tizè_, 
   {{0xd75836e7,0x1b1800eb,0xa2cc00cd,0x00000000}},	//   _طلعت_, _ঠাঁই_, _दुह्, --, 
   {{0x70b40d2c,0x91e45c83,0xd83800a2,0x00000000}},	//   ंप्ल, зове, luō_, --, 
   {{0x6f1ddf91,0xd01001d5,0x7f900139,0x142401d5}},	//   _serc, فلر_, _lıqı, _едим, 
   {{0x6f1cf8b3,0x39b4054e,0x8598011a,0x00000000}},	// [35f60] _perc, găsi_, _לשקו, --, 
   {{0xa2cc5d9c,0x7f900139,0xff2000d8,0x00000000}},	//   _दुव्, _nıqı, емфо, --, 
   {{0x6d4004ce,0x63043ba6,0x02f80375,0x5ee00073}},	//   _pcma, _توپل, _ללימ, _करण्_, 
   {{0x717407a7,0x6b880493,0x8c4489d0,0x0d840006}},	//   _تۇرا, _sodg, зеде, ялен, 
   {{0x0b8806bb,0x6b899252,0x2b944354,0x61b00150}},	//   йски_, _podg, ویرس, _شەكا, 
   {{0xee7804d3,0xaab404d3,0x6f1c4e2d,0xead4117e}},	//   _وڵات_, وڵات, _uerc, моль, 
   {{0xdb004c5d,0xbc4400cf,0xd1ec0092,0x00000000}},	//   _omlæ, _ۉركۉ, _ፀሎት_, --, 
   {{0x9f580129,0x79a077e5,0x645c0142,0xff1401e1}},	//   _rusé_, ерье, ywsi, _ẹ̀rù_, 
   {{0x9f500109,0x9f5801e1,0x00000000,0x00000000}},	//   _sizé_, _susé_, --, --, 
   {{0x9f9c0570,0x00000000,0x00000000,0x00000000}},	//   yìí_, --, --, --, 
   {{0x1ca81b35,0xe53402d5,0x36d401c6,0xdb0001ef}},	//   _བཟོ_, мень, здээ_, _umlá, 
   {{0xa2cc07b7,0x19c0052f,0x645c02c4,0x6dbc0165}},	//   _दुष्, _үҙәг, twsi, kčam, 
   {{0x645c01a4,0x00000000,0x00000000,0x00000000}},	//   uwsi, --, --, --, 
   {{0x66b40372,0x0624cffb,0x645c015d,0x80c0000d}},	//   _облу, _ефим, rwsi, _रखबे, 
   {{0xa2cd193c,0xf2c462bd,0x00000000,0x00000000}},	//   _दुश्, естн, --, --, 
   {{0x20180042,0xc05801ec,0x9f4000ae,0x00000000}},	//   _pwsi_, йіз_, rmhí_, --, 
   {{0xa2cc4438,0x1b040183,0x6dbc110c,0xb40801c0}},	// [35f70] _दुर्, ৰণতে_, rčal, _нээж_, 
   {{0x39b4054e,0xdea001e2,0x5f7833d2,0x00000000}},	//   răsi_, پیری, غماس_, --, 
   {{0x5e582969,0x00000000,0x00000000,0x00000000}},	//   تلاس_, --, --, --, 
   {{0x9cb4d52d,0x5bd400dc,0xca4000d1,0x00000000}},	//   ومات, धत्व, _ﻛﯚﺯ_, --, 
   {{0x61e0057b,0x714400cf,0x80e9df92,0x00000000}},	//   ïllu, _سۉلۅ, _دردِ_, --, 
   {{0x6dbc9a64,0x9f5c006a,0x1b1c00cc,0x72040345}},	//   nčaj, ëwä_, _নাহে_, _توێم, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xceb0025d,0x6dbc0010,0x9d18104e,0xad440108}},	//   _סין_, hčaj, _фоат_, _пхук, 
   {{0x7f900139,0xa90587da,0xac19df93,0x00000000}},	//   _tıqı, ربين, _ноту_, --, 
   {{0x386c01f5,0x648801e4,0xe8a801e0,0x00000000}},	//   _vrgr_, tɾin, ябыҙ_, --, 
   {{0xa2cc924b,0x00000000,0x00000000,0x00000000}},	//   _दुल्, --, --, --, 
   {{0xd83800b0,0x00000000,0x00000000,0x00000000}},	//   puō_, --, --, --, 
   {{0x7988015d,0xc4800395,0xdb1c01e1,0x85580066}},	//   _iogw, вляк, _ìyók, آشپز_, 
   {{0x2d9c00e2,0x527400db,0x00000000,0x00000000}},	//   īvei_, мубу, --, --, 
   {{0x79886df0,0x59e00073,0x47d07da6,0x00000000}},	//   _kogw, _पठार, _جيور, --, 
   {{0xdb000162,0x00000000,0x00000000,0x00000000}},	//   _umlæ, --, --, --, 
   {{0x7989df94,0xac50001f,0x660400ef,0x00000000}},	// [35f80] _mogw, _መፍትሄ, _čiki, --, 
   {{0x7989df95,0xdc380139,0x00000000,0x00000000}},	//   _logw, _nçıg, --, --, 
   {{0xa3bd6c08,0x59ac05f9,0x27e00c09,0x1ca8031c}},	//   ेकर_, टफार, _ɗin_, _བཟུ_, 
   {{0x7988fc3f,0xfbcc129e,0xdc380139,0x00000000}},	//   _nogw, یتو_, _açıg, --, 
   {{0x4194034c,0xdb00007c,0x6fb400cf,0x0c740345}},	//   _آشپز, _omlä, _كۅرا, بداد, 
   {{0x69c400d0,0x61e8025c,0x00000000,0x00000000}},	//   čiem, ċele, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7988058a,0x3f8c0135,0xc19800df,0x00000000}},	//   _cogw, ġjuż_, ַשיי, --, 
   {{0x7988fb3c,0x6dbc01f1,0x0b449f6f,0x69dc01c7}},	//   _dogw, yčaj, _онан, _ërem, 
   {{0x79888dfa,0x26d80037,0x00000000,0x00000000}},	//   _eogw, üroo_, --, --, 
   {{0x2b1474f6,0x6d440115,0x25d92b9b,0xe69401c4}},	//   _न्यु_, ϲial, змны_, хины, 
   {{0xdb0000ee,0x7989df96,0x9a24007b,0x80cc01f9}},	//   _emlä, _gogw, _أعلن, _दडले, 
   {{0xe2f801ec,0x00000000,0x00000000,0x00000000}},	//   зегі_, --, --, --, 
   {{0x9f580c95,0x79880bd7,0xb7d40150,0x6ed40303}},	//   _cusì_, _zogw, _قونا_, _बुभु, 
   {{0x798886dc,0x01880229,0x00000000,0x00000000}},	//   _yogw, ощай_, --, --, 
   {{0x5edc00bd,0x79880067,0x00000000,0x00000000}},	//   _বললে, _xogw, --, --, 
   {{0x6dbc0427,0x00000000,0x00000000,0x00000000}},	// [35f90] pčaj, --, --, --, 
   {{0x6dbc0171,0x00000000,0x00000000,0x00000000}},	//   bčak, --, --, --, 
   {{0x63b5df97,0x9df8023a,0xee380212,0xa1940117}},	//   mizn, чнет_, днє_, _занч, 
   {{0x63b5df98,0xcfa40124,0x628001f4,0x6294010e}},	//   lizn, _ҧырҩ, älou, myzo, 
   {{0x8024a832,0x61eddf99,0x629402fb,0x9f580c5e}},	//   _ترجم, mmal, lyzo, _husí_, 
   {{0x61eddf9a,0xf5500051,0x1ae401d5,0xb188013a}},	//   lmal, _nấng_, нолм, _taťá, 
   {{0x7988055a,0x61eddf9b,0x19f40120,0x62950ddf}},	//   _pogw, omal, нџир, nyzo, 
   {{0x9f580e96,0xad140022,0xb8b00220,0x63b4022e}},	//   _musí_, _аҿцә, көлі, hizn, 
   {{0x1ca80135,0x61eddf9c,0xed0402dd,0x00000000}},	//   _བཟི_, imal, _شولپ, --, 
   {{0x61eddf9d,0x79880bd7,0x63b41dd5,0x00000000}},	//   hmal, _wogw, jizn, --, 
   {{0x61eddf9e,0x7988058a,0x63b4022e,0x19580064}},	//   kmal, _togw, dizn, _нажы_, 
   {{0x6dbc107d,0x00000000,0x00000000,0x00000000}},	//   včak, --, --, --, 
   {{0x61ec005f,0xa3bc00dc,0x63b401a9,0x00000000}},	//   dmal, ेकं_, fizn, --, 
   {{0x61eddf9f,0x63b5dfa0,0x26e405c7,0x6dbc0100}},	//   emal, gizn, üsoù_, tčak, 
   {{0x9f5000bc,0x61edb6fc,0x00000000,0x00000000}},	//   _cizí_, fmal, --, --, 
   {{0x61ec8894,0xf0040058,0x9f580f91,0x00000000}},	//   gmal, күми, _dusí_, --, 
   {{0x63b5dfa1,0x8e840244,0x00000000,0x00000000}},	// [35fa0] bizn, کلاه, --, --, 
   {{0x63b408a4,0x61ed7781,0xa0080154,0xa3bc00cd}},	//   cizn, amal, _লিখব_, ेकः_, 
   {{0xfbc000dc,0x6294012d,0x00000000,0x00000000}},	//   वचनम, cyzo, --, --, 
   {{0x61bc4195,0xbd6402bf,0xccc4247f,0x61ec2d7c}},	//   ्कृष, ерше_, нбей, cmal, 
   {{0x6ab80d0d,0xfce001c6,0xc5f000df,0xf0042a9d}},	//   इप्र, гоцо, אדא_, _рүзи, 
   {{0x8fd030cb,0xaa582c25,0xcef804fb,0x6af400f1}},	//   _сәбә, дику_, _رفرش_, نګار, 
   {{0xbb8041fa,0x2dc802dd,0x2b5c0427,0x00000000}},	//   الىي, _قارۋ_, revc_, --, 
   {{0x26d804cc,0x00000000,0x00000000,0x00000000}},	//   ürom_, --, --, --, 
   {{0x63b4014b,0x62940210,0x00000000,0x00000000}},	//   yizn, zyzo, --, --, 
   {{0x27f942fc,0x61eca47f,0xc6a5dfa2,0x0ae81913}},	//   örn_, zmal, ерми, _فرضي_, 
   {{0x349403a5,0x61eddfa3,0x63b433dc,0x6294037e}},	//   қарр, ymal, vizn, xyzo, 
   {{0x1b000131,0x61eda6ba,0x63b4012d,0xe3a400dc}},	//   _йүән, xmal, wizn, _ājñā, 
   {{0x69c1dfa4,0x648801e4,0x66040064,0x00000000}},	//   mnme, pɾim, _čiku, --, 
   {{0xc76431f0,0xb36400a7,0x6294012d,0x838401ec}},	//   _ساتى, лъск, tyzo, хыме, 
   {{0xf64c16cb,0x69c1dfa5,0x63b5dfa6,0xf670007b}},	//   _هئي_, onme, rizn, _مايخ, 
   {{0x69c1dfa7,0x61eddfa8,0x250812a7,0x6294033f}},	//   nnme, umal, _غربی_, ryzo, 
   {{0x69c40419,0xe2980139,0x00000000,0x00000000}},	// [35fb0] čieh, чаң_, --, --, 
   {{0x69c00112,0x442800e4,0xd6c000fe,0x00000000}},	//   hnme, msc_, _উৰিয, --, 
   {{0x1ca81e81,0x61ece03b,0xd1d4001f,0xceb40131}},	//   _བཟང_, pmal, ራሮች_, вәт_, 
   {{0x4429dfa9,0x69c001a4,0xa19400c7,0xdb1402d2}},	//   osc_, jnme, _рамч, _íbúi, 
   {{0x30e447c5,0xea000051,0x00000000,0x00000000}},	//   _бірб, tiếp_, --, --, 
   {{0xcf8c021a,0x69c129bb,0x9f340220,0x4428007b}},	//   _وژل_, enme, _шегі, isc_, 
   {{0xab28b74b,0x00000000,0x00000000,0x00000000}},	//   رسول_, --, --, --, 
   {{0x29fc0115,0x396001f0,0x2d9c0200,0x7c8400f3}},	//   _aĉas_, униҳ, ëvet_, _пузе, 
   {{0x44280034,0x57e80853,0x98a4026b,0x6b74004e}},	//   jsc_, мдим_, типе, _өлту, 
   {{0x69c1dfaa,0xb7cc0154,0x96b820c8,0x00000000}},	//   anme, রষ্ট, думу_, --, 
   {{0x4428084c,0x55e417a0,0x1d40001f,0x00000000}},	//   esc_, кооб, _የምንመ, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x5fd02efd,0x799888fe,0x446002e8,0x00000000}},	//   तकाल, mkuw, авяв, --, 
   {{0x395ddfab,0x7c29dfac,0xd7c8e9ff,0x00000000}},	//   leus_, isgr, _توته_, --, 
   {{0x79980451,0x442800c6,0xa0740220,0xc320b32c}},	//   okuw, asc_, қытш, рмск, 
   {{0x7c280feb,0x395ddfad,0x3cfc047e,0x7999dfae}},	//   ksgr, neus_, _nguv_, nkuw, 
   {{0x395c04cc,0x1cac031c,0x14f8004b,0x7c2801f5}},	// [35fc0] ieus_, ྒགས_, _کوښښ_, jsgr, 
   {{0x7525dfaf,0x6dbc08a4,0xbf980489,0xa30004b4}},	//   _heiz, nčav, _stêr, _гүре, 
   {{0x7525dfb0,0x395c02f6,0x79980694,0x5cc402dd}},	//   _keiz, keus_, kkuw, ңсіз, 
   {{0xdd98005e,0x395d2972,0x7c2826bd,0x717400db}},	//   нші_, jeus_, fsgr, _حۇرا, 
   {{0xcfa8abd7,0x7525c58f,0x69c00162,0x00000000}},	//   _قاسم_, _meiz, vnme, --, 
   {{0x7525dfb1,0xdb000030,0x799801f7,0x6dbc00f3}},	//   _leiz, _zmlú, ekuw, jčav, 
   {{0x395c00db,0x2a8c016b,0x7c28017a,0x69c003b2}},	//   feus_, rɛbo_, asgr, tnme, 
   {{0x752400de,0x395c1dd4,0x2d9c00da,0x799822d0}},	//   _neiz, geus_, īves_, gkuw, 
   {{0x69c1dfb2,0x2d9c00e2,0x7c28035a,0x8b240006}},	//   rnme, ūves_, csgr, _адзе, 
   {{0x8b6410de,0x2508ca19,0x99881a48,0x79981418}},	//   _جارم, کردی_, čaš_, akuw, 
   {{0x7525dfb3,0x6595dfb4,0x3160030a,0x7f38011a}},	//   _beiz, гану, keiz_, ועיו, 
   {{0x395cc799,0xa2cc185d,0x316005c7,0xe6180137}},	//   ceus_, _दुग्, jeiz_, мдү_, 
   {{0x752403bd,0xc7c5dfb5,0x07a4035b,0x991400c0}},	//   _deiz, _иски, _иадн, _сьхі, 
   {{0x61bc1944,0x00000000,0x00000000,0x00000000}},	//   ्क्ष, --, --, --, 
   {{0x67280cfe,0x7525b5ba,0x44280493,0x31600097}},	//   madj, _feiz, ssc_, feiz_, 
   {{0x75240097,0x44280810,0x31600007,0x7c280368}},	//   _geiz, psc_, geiz_, ysgr, 
   {{0x62200075,0x9f5819f5,0xf12401c6,0x25b801a9}},	// [35fd0] _گۈزە, _pusà_, рьсо, misl_, 
   {{0x656c18a6,0x6729dfb6,0x75240156,0x7c282a5b}},	//   _haah, nadj, _zeiz, vsgr, 
   {{0x656ddfb7,0x7c29dfb8,0x75240099,0x2294d77e}},	//   _kaah, wsgr, _yeiz, _синя, 
   {{0xf6500bd9,0x9f5000d2,0x656ddfb9,0x395ccc75}},	//   יצע_, _dizá_, _jaah, xeus_, 
   {{0x656ddfba,0x61fc025a,0x2129dfbb,0x395ddfbc}},	//   _maah, _iisl, maah_, veus_, 
   {{0x656d4e25,0x2129dfbd,0x61fc016d,0x00000000}},	//   _laah, laah_, _hisl, --, 
   {{0x61fddfbe,0x395ddfbf,0x7c800032,0x995000d7}},	//   _kisl, teus_, ыҫҡа, _váž_, 
   {{0x656ddfc0,0x7c28127b,0x61fddfc1,0x2128102c}},	//   _naah, psgr, _jisl, naah_, 
   {{0x7525dfc2,0x395ddfc3,0x644c0457,0x7999dfc4}},	//   _reiz, reus_, _nqai, rkuw, 
   {{0x6729dfc5,0x395ddfc6,0x61fc1574,0xdd9809a5}},	//   gadj, seus_, _lisl, _diňe_, 
   {{0x656ddfc7,0x395ddfc8,0x7525dfc9,0x2129981d}},	//   _baah, peus_, _peiz, kaah_, 
   {{0x61fc016d,0x656c00d8,0x21280009,0x00000000}},	//   _nisl, _caah, jaah_, --, 
   {{0x656cc0a0,0x2129dfca,0x75240007,0x67280cf4}},	//   _daah, daah_, _veiz, badj, 
   {{0x61fddfcb,0x3160f178,0x75240112,0x6dbc0010}},	//   _aisl, weiz_, _weiz, lčat, 
   {{0x61fddfcc,0x656ddfcd,0x7bc14764,0xdb000036}},	//   _bisl, _faah, innu, _allë, 
   {{0x2fd82831,0x656c1132,0x61fc02fb,0x46b00034}},	//   _skrg_, _gaah, _cisl, ुपरह, 
   {{0x3161dfce,0x4fe8074d,0x00000000,0x00000000}},	// [35fe0] reiz_, еман_, --, --, 
   {{0x61fddfcf,0x656c022f,0x31600369,0x6dbc0010}},	//   _eisl, _zaah, seiz_, hčat, 
   {{0x527512e5,0x656ddfd0,0xe3b40046,0xdb000ffb}},	//   _супу, _yaah, _тұр_, _illè, 
   {{0x6dbc0122,0x656c35a3,0x9e58013e,0x7bc1dfd1}},	//   jčat, _xaah, ъруф_, ennu, 
   {{0x60dc0432,0xfbbc0011,0xdb000200,0x6ed47220}},	//   _gysm, েতনত, _gllë, _बुरु, 
   {{0x0a68a6be,0x6a1400a6,0x61fc6107,0x00000000}},	//   ерии_, амку, _zisl, --, 
   {{0x2d4800c7,0xdd98010e,0xc330011a,0x9f440241}},	//   _аҧеи_, _siňe_, מוג_, _òlá_, 
   {{0x7bc1dfd2,0x61fddfd3,0xfe40084c,0x6728020c}},	//   annu, _xisl, _ынсо, wadj, 
   {{0xfce02678,0x656ddfd4,0x24980076,0xdce803e0}},	//   _гото, _raah, xysm_, _ineğ, 
   {{0x656c0766,0x38540597,0xdbd0004b,0x00000000}},	//   _saah, اشيد_, _وښود, --, 
   {{0x656ddfd5,0x6729dfd6,0x7fd400c8,0x21280548}},	//   _paah, radj, רויס_, yaah_, 
   {{0x67280cf4,0x656c8c88,0xdb00004a,0x21280548}},	//   sadj, _qaah, _allè, xaah_, 
   {{0x25b801fa,0x656ddfd7,0x67280ef5,0x6dbd3ec2}},	//   risl_, _vaah, padj, lčas, 
   {{0x656ddfd8,0x60dc017a,0x2128011f,0xc17410ef}},	//   _waah, _rysm, waah_, گدست, 
   {{0x61fddfd9,0x656ddfda,0xf76d0249,0x21280429}},	//   _pisl, _taah, _راو_, taah_, 
   {{0xdb00067c,0x6114a99d,0x00000000,0x00000000}},	//   _ellè, рдау, --, --, 
   {{0x60f85a19,0x61fddfdb,0x644c2a1f,0x2168010b}},	// [35ff0] тная_, _visl, _uqai, ниңи_, 
   {{0x61fddfdc,0x9f4000c6,0x21280429,0x60dc02fb}},	//   _wisl, lmhú_, saah_, _vysm, 
   {{0x6dbc0232,0x61fddfdd,0x20080393,0x60dd5b23}},	//   jčas, _tisl, sqai_, _wysm, 
   {{0x5c7536a4,0x61fc05d9,0xad24040d,0x6dbc1f48}},	//   илет, _uisl, مىمى, dčas, 
   {{0x6dbc0313,0x20080194,0x68e401c3,0xb89c0023}},	//   včat, qqai_, _ùidh, _ጎልጎል_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd1d4001f,0x7bc00158,0x00000000,0x00000000}},	//   ራጮች_, rnnu, --, --, 
   {{0x985401af,0x00000000,0x00000000,0x00000000}},	//   атош, --, --, --, 
   {{0x6dbccc1a,0xd1d8001f,0x00000000,0x00000000}},	//   rčat, _ኮከብ_, --, --, 
   {{0x1a641b12,0x9984b4a9,0xb60402f0,0x19580022}},	//   _نیتی_, الکو, _neší, хаҩы_, 
   {{0x6dbc0384,0xda080271,0x00000000,0x00000000}},	//   mčar, _شيشه_, --, --, 
   {{0x58d40c04,0xe78401b9,0x98b80354,0x00000000}},	//   _коет, _қучо, _илет_, --, 
   {{0xdb0020ef,0x61e80003,0x69c400d7,0x00000000}},	//   _allé, ċell, čiet, --, 
   {{0x6dbc80b6,0xbf9805d5,0x969400f0,0x00000000}},	//   nčar, _quêl, _вриш, --, 
   {{0x950000cf,0x55e400d8,0x7a0000e5,0x00000000}},	//   _وۋدۇ, _кокб, _főte, --, 
   {{0xd17450c0,0xd01007d6,0xe8500244,0x00000000}},	//   шыгы, قلر_, _بۆید, --, 
  
   {{0x02d8547d,0x6dbc0219,0x50440a5b,0x3ea40014}},	// [36000] _मुठभ, zčas, резб, یشمہ, 
   {{0x3364004b,0x2d80005f,0x25a0025c,0x409001d5}},	//   _اندې, ķiem_, _ċili_, غللر, 
   {{0x4338008d,0x0e65dfde,0x3f640107,0x91e42642}},	//   _בעיב, ркен, рихо_, _воне, 
   {{0xb60401ef,0x00000000,0x00000000,0x00000000}},	//   _zeší, --, --, --, 
   {{0x2ca006d5,0x9f508021,0xbd84143e,0x00000000}},	//   áid_, _bizä_, شنون_, --, 
   {{0xc474011a,0x60c80064,0x6dbc0064,0x00000000}},	//   יתנו_, _žemg, gčar, --, 
   {{0x2ca005be,0xead80006,0x0a6801a9,0x00000000}},	//   šid_, ымкі_, трли_, --, 
   {{0x35a4001f,0x0c3800c6,0x6dbc0010,0x00000000}},	//   ገኙበት_, _لكرة_, rčas, --, 
   {{0xdb00003a,0x2b580214,0xa8980137,0xc7c400d8}},	//   _illî, _میشد_, укпу_, исои, 
   {{0xc8c93df8,0x0a38010b,0x9f500139,0x6dbc07f5}},	//   _یوان_, _ачды_, _gizä_, pčas, 
   {{0xc985dfdf,0x23ac01e1,0xdce80171,0x00000000}},	//   _вули, _lójù_, _bleķ, --, 
   {{0x2a6c0687,0x241812c4,0xb604013a,0x3ab8011a}},	//   _isdb_, ломы_, _seší, _במבנ, 
   {{0xd7640050,0x5edc015b,0x28140efc,0xb6040419}},	//   _گانٹ, _বলছে, _اوتس, _peší, 
   {{0x998801f1,0x00000000,0x00000000,0x00000000}},	//   čať_, --, --, --, 
   {{0x63a402f0,0x00000000,0x00000000,0x00000000}},	//   _vlhn, --, --, --, 
   {{0x6dbc02f0,0x00000000,0x00000000,0x00000000}},	//   zčar, --, --, --, 
   {{0x34941d56,0xb6040030,0x301423be,0x712406ba}},	// [36010] _маър, _teší, ждур, زىلم, 
   {{0x2b4c0048,0x92e400fe,0x00000000,0x00000000}},	//   _ncdc_, _ফলৰ_, --, --, 
   {{0x60c80024,0x6dbc1a48,0x2bbc06ff,0x34d800e5}},	//   _žemd, včar, ्चना, _مذید_, 
   {{0xa11401ec,0x802401d3,0xf1e0002e,0x9f500166}},	//   _دوحت, _پرحم, s斡r_, _sizä_, 
   {{0x3d0c0316,0x00000000,0x00000000,0x00000000}},	//   ाडौं_, --, --, --, 
   {{0x1b481de1,0x3e14034c,0xda6443b9,0xac7401d5}},	//   узки_, _نظرس, ماعي, غانش, 
   {{0x3f80a3b7,0x35a40092,0x00000000,0x00000000}},	//   _inju_, ገኙባት_, --, --, 
   {{0x2b4c4e3d,0x394800db,0x00000000,0x00000000}},	//   _ecdc_, ücs_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xab84014b,0x00000000,0x00000000,0x00000000}},	//   _мухк, --, --, --, 
   {{0x3f7c0421,0x69c400d0,0x997421f3,0xdce800de}},	//   _iāuē_, čier, _гулш, _pleķ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3f80000d,0x00000000,0x00000000,0x00000000}},	//   _onju_, --, --, --, 
   {{0xb4e835e8,0x3e74025c,0xd704023a,0x27480118}},	//   _भरी_, _oħt_, _узки, _vůní_, 
   {{0x4ee00011,0x490c0118,0x00000000,0x00000000}},	//   _বল্ল, णुको_, --, --, 
   {{0xd54806ed,0x91040150,0x00000000,0x00000000}},	//   _спие_, спае, --, --, 
   {{0x1008db35,0x9008007b,0x2bbc08df,0x00800139}},	// [36020] اترى_, ازرق_, ्चमा, плто, 
   {{0x44740375,0xd1b001b9,0xdb1c01e1,0x00000000}},	//   _פעיל_, _کیرک, _ìyèk, --, 
   {{0x69dc0998,0x0d200137,0xc7b8010f,0x00000000}},	//   _íreg, зүбү, נצעט, --, 
   {{0x3f800337,0x2b4c01ab,0x60c80024,0x80d001f9}},	//   _enju_, _scdc_, _žeme, _भुके, 
   {{0x7f800131,0xdb0000e5,0x00000000,0x00000000}},	//   تلەن, _omló, --, --, 
   {{0x2a6c0120,0xff04010b,0x00000000,0x00000000}},	//   _psdb_, _герк_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa81402d7,0xda6406f6,0xad84568c,0x094821b4}},	//   одиш, تاهي, _باسۇ, учки_, 
   {{0xddb801c0,0xbd3000cf,0x2d8403e0,0x9db80150}},	//   _турш_, _رىلع, _inme_, _тыру_, 
   {{0xa7b80798,0x00000000,0x00000000,0x00000000}},	//   рлоу_, --, --, --, 
   {{0xc95801b9,0xf4000154,0x91f8007a,0x00000000}},	//   _бўл_, ্ঠার_, ्दाज_, --, 
   {{0x24f83baa,0x00000000,0x00000000,0x00000000}},	//   инны_, --, --, --, 
   {{0xe895dfe0,0x2ec400dc,0x487400f1,0x4cd800cc}},	//   _фаль, वपुत, _دداس, _বৃতু, 
   {{0x26d80112,0x466801af,0x00000000,0x00000000}},	//   üros_, _брим_, --, --, 
   {{0x65943db0,0xb2840c9e,0x67380175,0xe2f800d4}},	//   _маку, пытк, _idvj, реві_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf1945aa2,0xa61400c7,0x60c800d7,0x7538011a}},	// [36030] чить, _узқә, _žemb, _האחד_, 
   {{0x2d84007f,0xdb242ca8,0x00000000,0x00000000}},	//   _anme_, üsüy, --, --, 
   {{0xa19444c1,0xa1592ad8,0xdb1c01e1,0x00000000}},	//   _данч, _кану_, _ìyék, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6738b745,0x408406ed,0x9b4401b9,0x628001bf}},	//   _odvj, _ѓумб, قنشو, ælof, 
   {{0x2019dfe1,0xc5cc0eac,0x00000000,0x00000000}},	//   _itsi_, রতিপ, --, --, 
   {{0x25a8009a,0x661801c8,0x198800c9,0xfe700035}},	//   _olal_, _ntvk, ибки_, _عدس_, 
   {{0x9f4000d7,0x00000000,0x00000000,0x00000000}},	//   dlhé_, --, --, --, 
   {{0xb4e80c2e,0x9c1831ed,0x09d8031c,0x98ac031c}},	//   _भरे_, _ضياء_, _རཉྫ_, ffeġ_, 
   {{0x25a9dfe2,0x69dddfe3,0x00000000,0x00000000}},	//   _alal_, _êren, --, --, 
   {{0xfaa5dfe4,0x67380010,0xdd2400ef,0x00000000}},	//   _ушан, _ddvj, _mūžo, --, 
   {{0x2018007d,0x21380200,0xdd9800d7,0x63000154}},	//   _otsi_, _ndsh_, _miňo_, ্রাট_, 
   {{0x2019dfe5,0x92e400bd,0xd668004b,0x67380010}},	//   _ntsi_, _ফলে_, _چمتو_, _fdvj, 
   {{0xb9d402d3,0x00000000,0x00000000,0x00000000}},	//   _ሽም_, --, --, --, 
   {{0x2019dfe6,0x64580bc9,0x3ddc0209,0x21380200}},	//   _atsi_, _äwin, _okuw_, _bdsh_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc7bc91aa,0xd4683cc5,0x00000000,0x00000000}},	// [36040] žđem_, _типе_, --, --, 
   {{0x3ddc1bce,0x386c021e,0xcee80006,0xdb016cdf}},	//   _akuw_, _msgr_, адзе_, _allí, 
   {{0x2019dfe7,0xcd04146a,0x00000000,0x00000000}},	//   _etsi_, очли, --, --, 
   {{0x9fc80124,0x91e40138,0x00000000,0x00000000}},	//   агӡа_, _фоме, --, --, 
   {{0x3d2816e6,0x0b891559,0xdce802b5,0xb4e80764}},	//   شتنی_, иски_, _paeā, _भरो_, 
   {{0xf7640075,0x00000000,0x00000000,0x00000000}},	//   _غا_, --, --, --, 
   {{0xc218013f,0xdb000129,0xee38030d,0x00000000}},	//   ɔɔso_, _allâ, çнĕ_, --, 
   {{0x8c45755c,0xd90c7b43,0x0134010f,0x00000000}},	//   _мебе, هیم_, ֿרית_, --, 
   {{0x386c00ca,0xdde812ea,0x6ef002d2,0xbc4400db}},	//   _csgr_, _طرفه_, _fóbí, _وركۉ, 
   {{0x8d640023,0xeae800cc,0x00000000,0x00000000}},	//   _ሰምበል_, _পলীম, --, --, 
   {{0xbf98003a,0x00000000,0x00000000,0x00000000}},	//   _quêi, --, --, --, 
   {{0xe7380032,0x24980736,0x00000000,0x00000000}},	//   шеү_, منجد_, --, --, 
   {{0xf76cf9e1,0x69c1dfe8,0x00000000,0x00000000}},	//   رای_, mime, --, --, 
   {{0x201804cc,0x82a400db,0x00000000,0x00000000}},	//   _rtsi_, ошбе, --, --, 
   {{0x21380023,0x2019dfe9,0x69c001ab,0x80d02c2e}},	//   _pdsh_, _stsi_, oime, _भुजे, 
   {{0x25a8009a,0x201803e0,0x85309c1d,0x00000000}},	//   _ulal_, _ptsi_, _کوکچ, --, 
   {{0x69c164a8,0x6ab801ad,0x34b4023a,0xc3040127}},	// [36050] iime, ेपुर, _объё, _وبدو, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbd68d55b,0x0afc00eb,0x00000000,0x00000000}},	//   ирде_, ুরুল_, --, --, 
   {{0xdd9001ed,0xc8c8012c,0xe1240327,0xed580212}},	//   رڈز_, ापाट, _འབྲད_, жої_, 
   {{0x2018b846,0xd1140375,0x7c640137,0x00000000}},	//   _utsi_, _מקרה_, تاال, --, 
   {{0x69c09e7a,0xeda40022,0x00000000,0x00000000}},	//   eime, зшәо, --, --, 
   {{0x69c1dfea,0xba740b38,0x386c01bf,0x00000000}},	//   fime, تاشت, _ssgr_, --, 
   {{0x69c01e56,0x19880107,0x00000000,0x00000000}},	//   gime, сбии_, --, --, 
   {{0xac18014b,0x00000000,0x00000000,0x00000000}},	//   _моту_, --, --, --, 
   {{0x69c1dfeb,0x00000000,0x00000000,0x00000000}},	//   aime, --, --, --, 
   {{0x69c1dfec,0x46e4013d,0x02d82052,0x00000000}},	//   bime, здэн_, _मुलभ, --, 
   {{0x69c1dfed,0xd1bc001f,0xd4680120,0xaa6401d5}},	//   cime, ሰበት_, биме_, _ютук, 
   {{0xc68c0014,0xd4d80006,0x00000000,0x00000000}},	//   نِی_, сьні_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa6b40801,0x00000000,0x00000000,0x00000000}},	//   _осъщ, --, --, --, 
   {{0x60c80006,0xfa380092,0x00000000,0x00000000}},	//   _žema, _አይሰማ, --, --, 
   {{0x6ed40c2e,0x94a801d9,0x00000000,0x00000000}},	// [36060] _बुजु, _داغِ_, --, --, 
   {{0x3fe0ee43,0xcef40a5b,0x00000000,0x00000000}},	//   ежув, пчењ, --, --, 
   {{0x69c1dfee,0x8d8406d3,0x0ea4012d,0x00000000}},	//   yime, зулд, कैंड, --, 
   {{0x8a74016c,0x0ca81422,0x91b800fe,0x00000000}},	//   ҷикӣ_, йтли_, _আৱৰ্, --, 
   {{0xdd99dfef,0x7c1000d4,0xacc800c7,0x00000000}},	//   _doň_, едіє, цҳаз_, --, 
   {{0x69c1dff0,0x8c8400fb,0x60c801a8,0xbc6400db}},	//   wime, оҙға_, _þema, سمىن_, 
   {{0xe9f80953,0xaca40248,0x99ec00b8,0x00000000}},	//   онкі_, _iwọp, _ṣaḍd, --, 
   {{0xdd9800a2,0xddb8030d,0x00000000,0x00000000}},	//   _goň_, _дууш_, --, --, 
   {{0xf98c1fd6,0xf6b4031c,0x8c442716,0x8c242f84}},	//   ابى_, _བཟུང, _хезе, _رفاه, 
   {{0x6dbc00b0,0x60080024,0x8c2003d4,0x772400cc}},	//   kōak, _užme, _নিপন_, _মাউছ_, 
   {{0x69c1dff1,0x6b88019b,0xbb400354,0xba14007b}},	//   pime, _indg, _чехк, _فيلا_, 
   {{0x69c00200,0x00000000,0x00000000,0x00000000}},	//   qime, --, --, --, 
   {{0xdb000077,0xf4840166,0x00000000,0x00000000}},	//   _illá, нурн, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdfd1dff2,0xd24c036b,0x5ba800cd,0x00000000}},	//   ھيا_, گچی_, _कत्व, --, 
   {{0x9424302a,0xca50044e,0xdfd10dc2,0xea000051}},	// [36070] _قويۇ, _ዘይብሎ, پيا_, chấp_, 
   {{0xdd9809a5,0x22a401d5,0x6f7401f0,0x00000000}},	//   _soň_, _жумҳ, нгуф, --, 
   {{0xdb00056a,0x3bf00588,0x3ea45f48,0x00000000}},	//   _ollá, ҵҟат, ánt_, --, 
   {{0x23480405,0x6b880857,0x00000000,0x00000000}},	//   _اسکی_, _andg, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb01dff3,0x1af0015b,0xa06800c7,0x00000000}},	//   _allá, _চলবে_, _лаҭа_, --, 
   {{0xfd4400c0,0x00000000,0x00000000,0x00000000}},	//   _нэан, --, --, --, 
   {{0x6b89dff4,0xaac4004b,0x997c0150,0x00000000}},	//   _endg, عتون, рткi, --, 
   {{0x2be801ad,0x7c94007b,0x5c74030d,0x00000000}},	//   _चीकू_, _عشرا, _юлат, --, 
   {{0xdb0000dd,0xbf980129,0x9bc00137,0x00000000}},	//   _ellá, _guêt, _جەتۉ, --, 
   {{0x7bc0281b,0x2bbc00b8,0x00000000,0x00000000}},	//   minu, ्चरा, --, --, 
   {{0x7bc1dff5,0xdecc0092,0x1ac801ef,0x00000000}},	//   linu, ኤልና_, िपीठ, --, 
   {{0x7bc001f4,0x00000000,0x00000000,0x00000000}},	//   oinu, --, --, --, 
   {{0x6dbc0270,0xd62800db,0xca880023,0xdee00023}},	//   tōak, _доке_, ናልኩም_, ዓርን_, 
   {{0x91e40a83,0x7bc06f76,0x840000d8,0x00000000}},	//   дове, iinu, тпрж, --, 
   {{0x7bc1dff6,0x2174009d,0x00000000,0x00000000}},	//   hinu, нуур, --, --, 
   {{0x7bc1dff7,0x00000000,0x00000000,0x00000000}},	// [36080] kinu, --, --, --, 
   {{0x7bc16e30,0xef9401b9,0xc71000dc,0xd54801e2}},	//   jinu, ریزد, _krīḍ, _الکو_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfcb8001f,0x22440419,0x00000000,0x00000000}},	//   ዲሰጡ_, álke_, --, --, 
   {{0x53d01a2a,0x6ab805c0,0x00000000,0x00000000}},	//   _सदाश, ेप्र, --, --, 
   {{0xbf9807ea,0x09d40490,0x9f5802f0,0xfa3000d1}},	//   _quêt, डक्य, _kusý_, ھرىد, 
   {{0xd9b03f7b,0xfa3001ec,0x69dc0022,0x8d540114}},	//   گەند, نريد, _êrek, _отач, 
   {{0xdd1c054e,0x3b8011ca,0x00000000,0x00000000}},	//   râţi, еләг, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6b88019b,0x7bc1dff8,0x0ba8cf33,0x092403d4}},	//   _undg, cinu, _بارى_, _যাওঁ_, 
   {{0xbf9800e4,0x36d401c0,0x00000000,0x00000000}},	//   _kuêr, ддээ_, --, --, 
   {{0xda6421ec,0xf64c00dd,0xfaa187de,0x7a640137}},	//   _سامي, گئی_, _шахо, _تئكە, 
   {{0x79f80375,0xd838007f,0x52b001e0,0xd37c00d1}},	//   _ולאח, nyōl_, ҫҡыс, ﻤﻠﯩﻖ_, 
   {{0x1af0015b,0x60c80153,0x00000000,0x00000000}},	//   _চলতে_, _žemo, --, --, 
   {{0xdb0003b2,0x055c01ec,0xd1bc0092,0x00000000}},	//   _ellæ, _күнi_, ሰጠት_, --, 
   {{0x250810e5,0x7bc1dff9,0xfcb8001f,0xfa7408c3}},	//   _عربی_, zinu, ዲሰጥ_, ועלת_, 
   {{0x7bc1dffa,0xdecc001f,0x98bc0166,0x00000000}},	// [36090] yinu, ኤውን_, _yawı_, --, 
   {{0x7bc1dffb,0x6d440077,0x9e1402dd,0x00000000}},	//   xinu, óian, еджі, --, 
   {{0x7bc1dffc,0x92f001c6,0xad242374,0x00000000}},	//   vinu, _бүрх, چىمى, --, 
   {{0xad2417de,0x7bc1dffd,0x00000000,0x00000000}},	//   نىمى, winu, --, --, 
   {{0x7bc03fe5,0x9f50013d,0x00000000,0x00000000}},	//   tinu, _kizü_, --, --, 
   {{0x7bc0b0b3,0x5ba80bae,0x00000000,0x00000000}},	//   uinu, कसेव, --, --, 
   {{0x7bc1dffe,0xbf98003a,0x0b14007b,0xfe900133}},	//   rinu, _fuêr, رقية_, _جیاج, 
   {{0xceb006a9,0x00000000,0x00000000,0x00000000}},	//   _עין_, --, --, --, 
   {{0x7bc1dfff,0x4438045a,0x00000000,0x00000000}},	//   pinu, _nvq_, --, --, 
   {{0x7c39a137,0xfaa40228,0x7bc00194,0xaa640116}},	//   _ivur, _ошен, qinu, хтәк, 
   {{0x95980020,0x443800ac,0x60c83831,0x7c382507}},	//   ገሪቱን_, _avq_, _žeml, _hvur, 
   {{0xd4680120,0xdb00036e,0xc710002b,0x00000000}},	//   пиме_, _allç, _vrīḍ, --, 
   {{0x798843d6,0x7d180921,0x98bc013d,0x00000000}},	//   _ingw, _mfus, _tawı_, --, 
   {{0x7c3805b8,0x395c0381,0xdd9800a2,0x8898011a}},	//   _mvur, lfus_, _diňi_, _מבני, 
   {{0x387c2242,0x00000000,0x00000000,0x00000000}},	//   lvur_, --, --, --, 
   {{0x395de000,0xdb000724,0x7c3806ea,0x7d180135}},	//   nfus_, _illä, _ovur, _nfus, 
   {{0x7988014b,0x016000f7,0x00000000,0x00000000}},	// [360a0] _mngw, ыкто, --, --, 
   {{0x7d19e001,0x9f500139,0x387c0174,0x00c4457e}},	//   _afus, _gizü_, ivur_, хлук_, 
   {{0x7c39e002,0x05540f01,0x7989e003,0xbfc80137}},	//   _avur, _غلیظ_, _ongw, ساكە_, 
   {{0x79881a89,0xd1b9e004,0xd0082346,0x9f4000e4}},	//   _nngw, _راجا_, _неме_, nohê_, 
   {{0xcbe40798,0x00000000,0x00000000,0x00000000}},	//   нцки, --, --, --, 
   {{0x7989e005,0x7d180857,0x00000000,0x00000000}},	//   _angw, _efus, --, --, 
   {{0x9b243334,0x7c39e006,0x60080153,0x00000000}},	//   тфіл, _evur, _užma, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d4003be,0xc7c43169,0x387c022c,0xdb008504}},	//   _idma, есни, gvur_, _allä, 
   {{0x7989e007,0x31600092,0x6d40013a,0x26140401}},	//   _engw, hfiz_, _hdma, _नंदी_, 
   {{0xb90429da,0xffb400c8,0x7c38004c,0x6d400139}},	//   _मु_, גליש_, _zvur, _kdma, 
   {{0x79880280,0x31600369,0x7c380174,0x9f500139}},	//   _gngw, jfiz_, _yvur, _sizü_, 
   {{0x07a5e008,0xdb0018c3,0x2508129e,0x316000a2}},	//   _падн, _ellä, بردی_, dfiz_, 
   {{0xe2f8005e,0xf75005d4,0x6d400421,0xb7d40131}},	//   дегі_, _منهج, _ldma, _كونا_, 
   {{0x6d4004b9,0x4b10045e,0x62240131,0x79880142}},	//   _odma, _সজাগ_, ئىرل, _yngw, 
   {{0x6f1c013f,0x6d401529,0x443889fd,0x7e640098}},	//   _afrc, _ndma, _tvq_, _rpjp, 
   {{0x263c01e4,0x80c000db,0xdee00023,0x00000000}},	// [360b0] lĉo_, اڭجە, ዓይን_, --, 
   {{0xdb00049b,0x6d41e009,0x657c14dc,0x9f200075}},	//   _yllä, _adma, ldsh, شۈرۈ, 
   {{0x395de00a,0x645de00b,0x657c0072,0x263c008f}},	//   yfus_, ltsi, odsh, nĉo_, 
   {{0x657de00c,0x7de40e56,0x628569d1,0x6d40003e}},	//   ndsh, رسام, _irho, _cdma, 
   {{0x645de00d,0x61ede00e,0x657de00f,0x76a0013f}},	//   ntsi, mlal, idsh, mɑye, 
   {{0x645c08e7,0xcb640a83,0x79880649,0x6d40035a}},	//   itsi, ваше_, _sngw, _edma, 
   {{0x7d1800d2,0xafe405f5,0x9e35e010,0x645c00af}},	//   _tfus, _соёл, _шевч, htsi, 
   {{0x645de011,0x61ede012,0x9f40044e,0x7d19e013}},	//   ktsi, nlal, kohë_, _ufus, 
   {{0x645da59a,0x7c395596,0x21287547,0x61ede014}},	//   jtsi, _uvur, ibah_, ilal, 
   {{0x81d411ba,0x6285e015,0xd278044e,0x21280ac5}},	//   িতি_, _orho, _ብግብሪ_, hbah_, 
   {{0x21280a2e,0x645de016,0x628401d4,0xba2824e0}},	//   kbah_, etsi, _nrho, _رسام_, 
   {{0x7989e017,0x645d72d7,0x21280007,0xdb000036}},	//   _ungw, ftsi, jbah_, _vllä, 
   {{0x61ec136f,0x2128138f,0x645de018,0x62840368}},	//   dlal, dbah_, gtsi, _arho, 
   {{0x657c60b7,0xc7a01b4f,0x966400db,0x00000000}},	//   adsh, _вишк, _акке, --, 
   {{0x645c32ff,0x62840789,0x55f40276,0x515400fd}},	//   atsi, _crho, _ичиу, ктау, 
   {{0x61ede019,0x645de01a,0x22440306,0xdbdc0ca8}},	//   glal, btsi, álka_, _láày, 
   {{0x6285e01b,0x6e3c54ae,0x63b40175,0x91048abc}},	// [360c0] _erho, _svrb, bhzn, тпае, 
   {{0x61ede01c,0x62840175,0x21280009,0x31600156}},	//   alal, _frho, abah_, sfiz_, 
   {{0x61ede01d,0x2129dfca,0x9f580ffb,0xdd98002e}},	//   blal, bbah_, _pusò_, _liňu_, 
   {{0x6d40037e,0x90c402d5,0x61ec0356,0xbd640114}},	//   _qdma, _абме, clal, врше_, 
   {{0x1ae82cc5,0x00000000,0x00000000,0x00000000}},	//   টেমে_, --, --, --, 
   {{0xce4800ee,0x8fd02f89,0xff200798,0x32001180}},	//   _озге_, _тәбә, _вмро, lmiy_, 
   {{0x657c0009,0x8d58014b,0x00000000,0x00000000}},	//   ydsh, _ошат_, --, --, 
   {{0x3200e219,0x6935b99b,0x6d41e01e,0x645d3327}},	//   nmiy_, اکار, _udma, ytsi, 
   {{0x3831e01f,0x645de020,0x3338031c,0x00000000}},	//   аныр, xtsi, karx_, --, 
   {{0x6e00063f,0x645c0218,0x21280198,0x61ed02a3}},	//   _ịchụ, vtsi, zbah_, zlal, 
   {{0xe5343b2b,0x61ede021,0x2128009f,0x27ec0334}},	//   лень, ylal, ybah_, rldn_, 
   {{0x645c1a82,0x263c00c8,0x21291424,0x79a007b5}},	//   ttsi, rĉo_, xbah_, _врше, 
   {{0x645de022,0x3200022e,0x21280427,0xc7b801a9}},	//   utsi, dmiy_, vbah_, _оёк_, 
   {{0x645de023,0x212803a2,0x61ecfbf2,0x3200011f}},	//   rtsi, wbah_, wlal, emiy_, 
   {{0x764c006d,0x61ecc6ee,0x645de024,0x212838ba}},	//   ącyc, tlal, stsi, tbah_, 
   {{0x645de025,0x61ede026,0x854400db,0x81a8015b}},	//   ptsi, ulal, _рэке, কোন_, 
   {{0x61ede027,0xb114ec1f,0x660de028,0xca2c0131}},	// [360d0] rlal, рмуш, _iiak, ﯨﺪﺍ_, 
   {{0x21282b10,0x660de029,0x6285e02a,0xe7380115}},	//   sbah_, _hiak, _trho, naĵ_, 
   {{0x660c89c4,0x6285e02b,0x212803a2,0xdbdc0241}},	//   _kiak, _urho, pbah_, _ráày, 
   {{0x9c59e02c,0x1c391ed9,0x2128011f,0x61ecdd5e}},	//   ешку_, езды_, qbah_, qlal, 
   {{0x660de02d,0x60080024,0xe73801e4,0x9c6480de}},	//   _miak, _užmo, kaĵ_, اهتو, 
   {{0x660de02e,0x23700158,0x723401b9,0xab28210e}},	//   _liak, nezj_, _حریط, پسول_, 
   {{0x660c06c8,0xcb940372,0x6e94a677,0xca145f32}},	//   _oiak, انىش_, _киру, _ﺳﯩﺮ_, 
   {{0x16180d5f,0x660de02f,0x99f40006,0x99d000cc}},	//   _नंबर_, _niak, ыялі, াত্ক, 
   {{0x76b000ac,0x00000000,0x00000000,0x00000000}},	//   məyə, --, --, --, 
   {{0x76b003be,0x660de030,0xe73801e4,0x20000332}},	//   ləyə, _aiak, gaĵ_, nmhi_, 
   {{0x660c0605,0xaba800ec,0x41e017c6,0xf6600139}},	//   _biak, _جهلم_, पवास, шенү, 
   {{0x660c0395,0xdb0001e7,0x98b80cb6,0x76b003e3}},	//   _ciak, _ollú, _плет_, nəyə, 
   {{0x7998009f,0x1a64158b,0x764401d3,0x33380003}},	//   mjuw, _شیکی_, ریکِ_, tarx_, 
   {{0x52740137,0xdbdc0241,0x00000000,0x00000000}},	//   лубу, _yááy, --, --, 
   {{0x660c0170,0xdb000332,0x47d001e2,0xb7d400d1}},	//   _fiak, _allú, _ديور, _كوچا_, 
   {{0x660c409c,0xee94015e,0x00000000,0x00000000}},	//   _giak, یداک, --, --, 
   {{0xbfa00570,0x6dbc02b5,0x320003f0,0x52740133}},	// [360e0] _àwọn_, kōar, rmiy_, _ڵادز, 
   {{0x320007d6,0xb35800dd,0x660c00d7,0xdb200248}},	//   smiy_, _جیسا_, _ziak, _àtèt, 
   {{0x79980227,0x4d480861,0x00000000,0x00000000}},	//   kjuw, епен_, --, --, 
   {{0x660c02b9,0xcd3405d9,0x00000000,0x00000000}},	//   _xiak, اراب, --, --, 
   {{0x8ba5b6e9,0xac941d39,0xdc8000c7,0x00000000}},	//   лидж, ралш, оқто, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3f640212,0xe73800df,0x7998031c,0xbea0010a}},	//   _щиро_, vaĵ_, fjuw, _ларк, 
   {{0x60c80006,0xdb00000f,0x76b00213,0x6cc800fb}},	//   _žemi, _yllú, cəyə, _иҫем_, 
   {{0x660de031,0xe73801e4,0x00000000,0x00000000}},	//   _riak, taĵ_, --, --, 
   {{0x660de032,0x75c400e5,0x00000000,0x00000000}},	//   _siak, lőzh, --, --, 
   {{0x660c4a3e,0x80c8a4cd,0xe73801e4,0x659460a1}},	//   _piak, _सेने, raĵ_, аану, 
   {{0x2418040e,0x888400c6,0x1b0c00eb,0x00000000}},	//   комы_, _مؤتم, _সড়কে_, --, 
   {{0x660c0481,0x443cf812,0x81a80154,0x248c01e4}},	//   _viak, éu_, কোড_, ĥemo_, 
   {{0x660de033,0x00000000,0x00000000,0x00000000}},	//   _wiak, --, --, --, 
   {{0x660de034,0x6235e035,0x00000000,0x00000000}},	//   _tiak, ребу, --, --, 
   {{0x161805ba,0x660c0270,0x6070001f,0x20cc0115}},	//   _नंतर_, _uiak, _ስርጭት_, _pɾi_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [360f0] --, --, --, --, 
   {{0x2489e036,0x00000000,0x00000000,0x00000000}},	//   _iram_, --, --, --, 
   {{0x76b003be,0x00000000,0x00000000,0x00000000}},	//   təyə, --, --, --, 
   {{0x2489e037,0x20cc01e4,0x91c020b0,0x3de81c3e}},	//   _kram_, _tɾi_, _дәул, رعاپ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7a0000e5,0xdb84004e,0x00000000,0x00000000}},	//   _lőtt, ргки, --, --, 
   {{0x248801ab,0x79980810,0x81a80eac,0x00000000}},	//   _lram_, tjuw, কোণ_, --, 
   {{0x2489e038,0x13d021b8,0xceb401ec,0x7a0000e5}},	//   _oram_, _सद्भ, _тәу_, _nőtt, 
   {{0x24880070,0x80c81d8a,0x799800f2,0x9b954db6}},	//   _nram_, _सेमे, rjuw, _پلات, 
   {{0xfbd1e039,0x16657f97,0x6d480014,0x9665b868}},	//   _اتر_, авом, _للہِ_, акое, 
   {{0x2489e03a,0x96b8dd46,0xd87400db,0x5fdc07af}},	//   _aram_, тупу_, _چاتب, _मदनल, 
   {{0x2489e03b,0x55e45e0c,0x80c800bc,0xc0f00023}},	//   _bram_, ромб, _सेभे, ፍራስ_, 
   {{0x24880072,0xb4c00cb4,0xe6b407d6,0x999000e5}},	//   _cram_, ंछे_, للیگ, _ízű_, 
   {{0x2489e03c,0xdb000036,0xd7c800f1,0x27fc0051}},	//   _dram_, _nolë, _جوته_, _ghvn_, 
   {{0x2489e03d,0x1db4024a,0x00000000,0x00000000}},	//   _eram_, ंसात, --, --, 
   {{0xdb002776,0x248869cd,0xa6440691,0x1b0803d4}},	//   _polê, _fram_, _اخون, _ৰজাই_, 
   {{0x00800323,0x0fc4026b,0x00000000,0x00000000}},	// [36100] олто, айан, --, --, 
   {{0xc4380375,0x52a81171,0xa3e000cd,0x918000cf}},	//   _שתיי, _авом_, धकः_, حۇڭۇ, 
   {{0xdb000023,0x527401a9,0xdff40815,0x00000000}},	//   _dolë, _тупу, сять, --, 
   {{0xd1b0c5f2,0x4c84dd37,0x6450031c,0x00000000}},	//   _بیرک, илев, żhiż, --, 
   {{0x2e3c01e1,0xdb000240,0x24880139,0x69dc02d2}},	//   _báfá_, _folë, _xram_, _írei, 
   {{0x81d400bd,0x2a6cfd72,0xdb004915,0x6b7402ff}},	//   িতঃ_, _ppdb_, _kolè, слку, 
   {{0xba700b38,0x2e3c0248,0x00000000,0x00000000}},	//   قايت, _dáfá_, --, --, 
   {{0xdb001f2d,0xc98400f3,0xc8641422,0x3ce40037}},	//   _molè, руки, атои, _छुवे_, 
   {{0xb9940a8f,0x8cd00345,0x00000000,0x00000000}},	//   рвых_, _بڵاڤ, --, --, 
   {{0x87040724,0x2489e03e,0x2c60033b,0x60c80432}},	//   ияне, _rram_, mòd_, _ýeme, 
   {{0xdb000066,0x2c60007f,0xfbd8012d,0x00000000}},	//   _nolè, lòd_, _बदतम, --, 
   {{0xa3c807af,0x00000000,0x00000000,0x00000000}},	//   लोन_, --, --, --, 
   {{0xd90c00b2,0x176802dd,0x2c60007f,0x487404f2}},	//   _ٻڌي_, _әріп_, nòd_, _خداس, 
   {{0x53b4190b,0x60c80213,0x00000000,0x00000000}},	//   йғыр_, _ümmə, --, --, 
   {{0x17e40014,0xdb010dcf,0xf64000c7,0x81c4023a}},	//   _اسنُ, _colè, _дхын, ащае, 
   {{0xa5351e5d,0xbf042ecf,0xdb00004e,0x67380162}},	//   _унич, _वृषभ_, _dolè, _hevj, 
   {{0x2489e03f,0x00000000,0x00000000,0x00000000}},	// [36110] _uram_, --, --, --, 
   {{0xdf380597,0xff502088,0x7e28177b,0x2c6002e2}},	//   اكات_, تخر_, віда_, dòd_, 
   {{0xdb00034c,0x3ea5e040,0x661805ac,0x6738014f}},	//   _golè, ânt_, _juvk, _mevj, 
   {{0x63a4e989,0x67380427,0x60c80153,0x2e2c01e1}},	//   _hohn, _levj, _žemu, _sòfò_, 
   {{0x63a538a1,0x2d58084c,0x4429e041,0x9f400418}},	//   _kohn, ричь_, npc_, lohí_, 
   {{0x67381f7f,0x20180421,0x63a4605b,0x8c400120}},	//   _nevj, _iusi_, _john, чеше, 
   {{0xdb01e042,0x63a5e043,0x2139e044,0x20189fe3}},	//   _kolé, _mohn, _kesh_, _husi_, 
   {{0x2139e045,0x201005d9,0x2019e046,0x63a5e047}},	//   _jesh_, _hizi_, _kusi_, _lohn, 
   {{0xdb01e048,0x57e86888,0x2011e049,0x9f580120}},	//   _molé, лдим_, _kizi_, _fusô_, 
   {{0x20180dc9,0x213802a4,0xdb000085,0x2010009f}},	//   _musi_, _lesh_, _lolé, _jizi_, 
   {{0x2019e04a,0x6b9c00f7,0x6738031c,0x2011e04b}},	//   _lusi_, _òrga, _devj, _mizi_, 
   {{0x20181529,0x213802d3,0xdb00893a,0x63a46bba}},	//   _ousi_, _nesh_, _nolé, _aohn, 
   {{0xdb000699,0x65f805f5,0x20180418,0x1458008e}},	//   _solè, рээр_, _nusi_, ышны_, 
   {{0xdb0000f7,0x96955efe,0x28f80108,0x00000000}},	//   _polè, _гриш, _течь_, --, 
   {{0x21389682,0x63a406a3,0xdb01e04c,0x2c6002bd}},	//   _besh_, _dohn, _bolé, zòd_, 
   {{0x2019e04d,0xdb01e04e,0xcfa8030f,0x6624007b}},	//   _busi_, _colé, گارم_, _بروك, 
   {{0x2011e04f,0xdb0095e7,0x75240472,0x20182b1d}},	// [36120] _bizi_, _dolé, _ifiz, _cusi_, 
   {{0x2019e050,0xcfa804d3,0x21380009,0xc4980375}},	//   _dusi_, دارم_, _eesh_, _עשית, 
   {{0x20183386,0x20100365,0x2139e051,0x0e65e052}},	//   _eusi_, _dizi_, _fesh_, скен, 
   {{0x2019e053,0x7e4800dd,0xdb00032b,0x63a41d55}},	//   _fusi_, اسلہ_, _golé, _zohn, 
   {{0x20182ebc,0x2011e054,0xeb100c2e,0x75240223}},	//   _gusi_, _fizi_, ाश्त_, _mfiz, 
   {{0xf7643b5f,0x2011e055,0x2d802b57,0x21380200}},	//   _عا_, _gizi_, žie_, _zesh_, 
   {{0x752405f5,0x4429e056,0x21380363,0x63a001a8}},	//   _ofiz, zpc_, _yesh_, ölni, 
   {{0x4429e057,0x8b649347,0x426c02d3,0x2c60067c}},	//   ypc_, _گارم, _ስግኣት_, pòd_, 
   {{0xa3c98188,0x76400fac,0x20180067,0xdb0000a2}},	//   लोड_, _avny, _xusi_, _illý, 
   {{0xc078008d,0x7524b62f,0x2010020c,0xbb4014b3}},	//   נטיש, _afiz, _xizi_, _неук, 
   {{0x7bdc0231,0xc9848d05,0x6738fccf,0x2a780100}},	//   éque, _гули, _vevj, _èrb_, 
   {{0x63a5e058,0xe6180228,0x31bc013a,0xc8880066}},	//   _sohn, лдү_, _jízd_, _مختل_, 
   {{0x6739472e,0x63a5e059,0x2139dd5f,0x850003ce}},	//   _tevj, _pohn, _resh_, रेंट_, 
   {{0x2019e05a,0x4429e05b,0x38c82580,0xaee41682}},	//   _rusi_, rpc_, _حامی_, hiṱu, 
   {{0x63a4006a,0x95600198,0x60080024,0x44280356}},	//   _vohn, _imمn, _užmi, spc_, 
   {{0x63a409f0,0x2019e05c,0x201036b5,0x7c296e29}},	//   _wohn, _pusi_, _sizi_, ypgr, 
   {{0x656de05d,0x63a4156f,0x20180481,0x213802d3}},	// [36130] _ibah, _tohn, _qusi_, _vesh_, 
   {{0x20109169,0x2019e05e,0xdb000162,0x60c80841}},	//   _qizi_, _vusi_, _allý, _žems, 
   {{0x2011e05f,0xdb01e060,0xc6180154,0x2138036e}},	//   _vizi_, _tolé, থীরা_, _tesh_, 
   {{0x2018096b,0x20100451,0x656c022f,0x00000000}},	//   _tusi_, _wizi_, _jbah, --, 
   {{0xa3bce342,0x201805c3,0x656de061,0x2010bc38}},	//   _आता_, _uusi_, _mbah, _tizi_, 
   {{0x2004180f,0x1a280108,0xd9b0134e,0x00000000}},	//   _òli_, ажки_, जस्ट, --, 
   {{0x656de062,0x2614033f,0x7c2801e3,0x00000000}},	//   _obah, _नंगी_, spgr, --, 
   {{0x3f80005b,0xdb001cce,0x81d405ac,0xa3c803ce}},	//   _haju_, _illü, িতক_, लोत_, 
   {{0x764c033f,0xa3e8000d,0xf98400f1,0xdb980064}},	//   ącym, बवा_, لنډي_, _квач_, 
   {{0x656c01b2,0x752402e8,0x3f81e063,0x17c800c7}},	//   _abah, _sfiz, _jaju_, ргои_, 
   {{0xb0d001ad,0xb9e400d4,0x00000000,0x00000000}},	//   _सेनग, _ліди, --, --, 
   {{0x3f81e064,0x99440354,0x00000000,0x00000000}},	//   _laju_, _хiай_, --, --, 
   {{0x2d98013f,0x98a48404,0x00000000,0x00000000}},	//   _ɑre_, _филе, --, --, 
   {{0xf804f0f6,0x5804075e,0x7640020b,0x3f8009a8}},	//   _учен, _بوتك, _tvny, _naju_, 
   {{0x656c0205,0xdb0000e5,0x4ca800eb,0x00000000}},	//   _fbah, _illó, _খোঁ, --, 
   {{0x656c006a,0x3f800194,0x752405d5,0xa9080228}},	//   _gbah, _aaju_, _ufiz, _ئيۇل_, 
   {{0x3f808590,0x3dcc4251,0xdb00000d,0x00000000}},	// [36140] _baju_, িকাল, _allü, --, 
   {{0x3f800798,0x1c1c007d,0xcef41f5a,0x7f4800f1}},	//   _caju_, _पढ़ल_, очењ, لسمې_, 
   {{0x9590001f,0x28d00243,0x00000000,0x00000000}},	//   _ልማትን_, _तेनि, --, --, 
   {{0x3ea401e6,0x80c8078a,0x0ca8010b,0x00000000}},	//   änta_, _सेवे, итли_, --, 
   {{0x3f800de2,0x61e000e5,0xdb0000e5,0xab94003b}},	//   _faju_, élle, _olló, зилі, 
   {{0x1c380845,0x6264036b,0x00000000,0x00000000}},	//   сяць_, _بایق, --, --, 
   {{0xaca40248,0x6d440077,0xba200116,0x4dd400d4}},	//   _itọp, óias, үдәк, _діаф, 
   {{0xdb00026c,0x00000000,0x00000000,0x00000000}},	//   _alló, --, --, --, 
   {{0x2d8401e4,0x3f8048bf,0x656c025c,0xa2d05b99}},	//   _iame_, _yaju_, _rbah, _डेन्, 
   {{0x2d840c3a,0x3f8000e8,0x00000000,0x00000000}},	//   _hame_, _xaju_, --, --, 
   {{0x656c089c,0x494401c6,0x00000000,0x00000000}},	//   _pbah, _дэлб, --, --, 
   {{0x2d85e065,0xda640150,0x00000000,0x00000000}},	//   _jame_, _ءالي, --, --, 
   {{0xf4842460,0x248c0137,0xe894356a,0x81a800cc}},	//   мурн, íem_, _халь, কোঁ_, 
   {{0xdb00067c,0x2d852690,0x9f4000e4,0x00000000}},	//   _illò, _lame_, kohá_, --, 
   {{0xc6a406ed,0x656c0327,0x69dc0174,0x00000000}},	//   _фрли, _tbah, _íres, --, 
   {{0x2d840573,0x224de066,0x656c5055,0x44b00046}},	//   _name_, ček_, _ubah, _жұмс, 
   {{0x1af000bd,0xdce80135,0x3f808507,0x7538011a}},	// [36150] _চলছে_, _ineħ, _paju_, _ואחד_, 
   {{0x25a80363,0xd24c2c04,0x00000000,0x00000000}},	//   _hoal_, خچی_, --, --, 
   {{0x2d85e067,0x25a8000f,0x195000b5,0x3f81e068}},	//   _bame_, _koal_, _ｎｐｏ_, _vaju_, 
   {{0x127800c8,0x2d84565d,0xdce8025c,0x25a80254}},	//   _פארע, _came_, _jneħ, _joal_, 
   {{0x25a9e069,0x61ede06a,0xdce8025c,0x3f8026bb}},	//   _moal_, moal, _mneħ, _taju_, 
   {{0x61ede06b,0xd0f80918,0x25a80037,0x67f401e1}},	//   loal, ्धरण_, _loal_, bàji, 
   {{0xdb00067c,0x236001b9,0xa2d001ad,0xd94400db}},	//   _allò, _mchj_, _डेम्, пейи, 
   {{0x61ec6386,0x2d84e397,0x25a80363,0xdce80327}},	//   noal, _game_, _noal_, _nneħ, 
   {{0x3ddc0086,0xb92000e4,0x00000000,0x00000000}},	//   _ijuw_, _karẽ_, --, --, 
   {{0x2d85e06c,0x61ec123c,0xdb000306,0xdb200ca8}},	//   _zame_, hoal, _holí, _àtàt, 
   {{0x61ede06d,0x2d85e06e,0xdb000122,0x25a80076}},	//   koal, _yame_, _kolí, _boal_, 
   {{0x25a9e06f,0x61ede070,0x2d840694,0xa3c81025}},	//   _coal_, joal, _xame_, लोस_, 
   {{0x25a80363,0x28f80276,0xdce80841,0x80c8072a}},	//   _doal_, _дець_, _obeč, _सेले, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x61ede071,0x25a8bb36,0x00000000,0x00000000}},	//   foal, _foal_, --, --, 
   {{0x61ec01c0,0xd02401d5,0x00000000,0x00000000}},	//   goal, змай, --, --, 
   {{0x2d84e073,0xc0e00395,0x5444007b,0x00000000}},	// [36160] _rame_, еотк, _عندك, --, 
   {{0x2d85e072,0x61ec0618,0xdb000309,0xb4b8982f}},	//   _same_, aoal, _polì, चनी_, 
   {{0xdb01e073,0x61ede074,0x2d84036e,0x83180677}},	//   _bolí, boal, _pame_, _לויז, 
   {{0xdb001ada,0x1ea800c6,0x91e43e4f,0x8634008f}},	//   _colí, غالي_, _хоме, פאנג_, 
   {{0xbd4004fb,0x2d85e075,0xdb01537b,0x6ad411bc}},	//   رنوي, _vame_, _dolí, धप्र, 
   {{0x2d841c1d,0x00000000,0x00000000,0x00000000}},	//   _wame_, --, --, --, 
   {{0xdb005b84,0x7bdc5725,0x2d842517,0x00000000}},	//   _folí, équa, _tame_, --, 
   {{0xaca4063f,0xdb00032e,0x00000000,0x00000000}},	//   ntịt, _golí, --, --, 
   {{0xf98c00c6,0x25a9e076,0x7cd401d3,0x00000000}},	//   طبي_, _roal_, _ٹولز_, --, 
   {{0x25a88a77,0x61ec05da,0x7a2403e0,0x6eb00210}},	//   _soal_, zoal, _sıte, ंहपु, 
   {{0xb8f02d6c,0x25a99f92,0x00000000,0x00000000}},	//   _हे_, _poal_, --, --, 
   {{0xf76c04d3,0xba980375,0x61ec005a,0xa2ac1b6e}},	//   پای_, _לסבי, xoal, ीनस्, 
   {{0x08f8a37e,0x25a9e077,0x00000000,0x00000000}},	//   _اراب_, _voal_, --, --, 
   {{0xc76400db,0x69c0014f,0x61ec062c,0xc6b40327}},	//   _راتى, lhme, woal, ྒྱུུ, 
   {{0x61ede078,0x2b4c01fa,0x25a9e079,0xdce8003d}},	//   toal, _mddc_, _toal_, _tneħ, 
   {{0x69c00007,0x0584020a,0x61f802d5,0x9f4401e1}},	//   nhme, _хукм, інаў_, _ólú_, 
   {{0x25b800e8,0xdb000c5e,0x00000000,0x00000000}},	// [36170] ërlu_, _rolí, --, --, 
   {{0x61ed62c6,0xdb012da1,0x44380194,0x00000000}},	//   soal, _solí, _iwq_, --, 
   {{0x3d0c0490,0x2f1807d5,0x69c1074b,0xe1343863}},	//   तेने_, чохь_, khme, _онны, 
   {{0xa3c8447d,0x22440306,0xc68411f2,0x00000000}},	//   लोर_, álku_, _یِ_, --, 
   {{0x69c1e07a,0xdb01e07b,0x00000000,0x00000000}},	//   dhme, _volí, --, --, 
   {{0xdb0000d8,0x5a9400d8,0x00000000,0x00000000}},	//   _rolâ, дриф, --, --, 
   {{0x7ccc01d3,0x00000000,0x00000000,0x00000000}},	//   _bőrö, --, --, --, 
   {{0x69c00842,0x3ea403b2,0x00000000,0x00000000}},	//   ghme, øntu_, --, --, 
   {{0x7d19e07c,0xdb000798,0x3cfc0205,0x6f18022e}},	//   _igus, _bolã, _uzuv_, оvch, 
   {{0x69c046e1,0x7c380ca8,0x41f800dc,0x00000000}},	//   ahme, _iwur, ्षुः_, --, 
   {{0x7c380810,0x7d000241,0x31bc02f0,0x3cec0118}},	//   _hwur, _fìrí, _líza_, řově_, 
   {{0x69c1e07d,0x7c3805db,0x5f0405d7,0xd4680120}},	//   chme, _kwur, _वरन्_, оиме_, 
   {{0xb4b82ecf,0x7d1801f7,0x6fc00139,0xe8940024}},	//   चने_, _mgus, _höce, _паць, 
   {{0x395de07e,0x7c3800ca,0x536c02d3,0xf8040724}},	//   lgus_, _mwur, _ስምዒት_, _эчен, 
   {{0x7c3802c4,0x7d19e07f,0xb03400f1,0x395c00c0}},	//   _lwur, _ogus, ځورګ, ogus_, 
   {{0x7d19e080,0x395de081,0x7c39e082,0x00000000}},	//   _ngus, ngus_, _owur, --, 
   {{0x61e1069d,0x44380007,0x395de083,0xc48000db}},	// [36180] élla, _gwq_, igus_, _алык, 
   {{0x7d19e084,0x395c01ab,0x3fc800f1,0x61e80010}},	//   _agus, hgus_, يدلی_, čela, 
   {{0x7c39e085,0xa3001945,0x2148007b,0x4d641cd0}},	//   _awur, _бүре, áthú_, дкев, 
   {{0x7c380223,0x69c0036e,0x00000000,0x00000000}},	//   _bwur, xhme, --, --, 
   {{0x0c7800c1,0x75e807c4,0xa074030d,0xacc800c7}},	//   تصاب_, mızd, _пырш, чҳаз_, 
   {{0x6fc005d1,0x7d19e086,0x31608e4e,0x7c380210}},	//   _böce, _egus, lgiz_, _dwur, 
   {{0x69c1e087,0x7c38bf88,0x6f1c0010,0x9e7000db}},	//   thme, _ewur, _igrc, _مۇلت, 
   {{0x31600517,0x75e807c4,0x41b8008f,0x395de088}},	//   ngiz_, nızd, ַציע, ggus_, 
   {{0x6d41e089,0x7c3801f2,0x19440014,0xf3e400fe}},	//   _iema, _gwur, ریوٝ_, _গঠনৰ_, 
   {{0xda6c00b2,0x31600399,0x395c01ab,0x38c001e1}},	//   _ڇڏي_, hgiz_, agus_, _sèré_, 
   {{0x6d4037bd,0xbbd402e4,0xdb0000db,0x6b8801ab}},	//   _kema, _קובץ_, _golà, _iadg, 
   {{0x6d41e08a,0x31600007,0xb990007b,0x395c01ab}},	//   _jema, jgiz_, _للمب, cgus_, 
   {{0x6d41e08b,0xf9c45ec2,0x4734004b,0x6f1c0427}},	//   _mema, _تحلی, _قرغز, _ogrc, 
   {{0xa3c8006d,0x6d41e08c,0x27680b28,0xdb000d4e}},	//   लों_, _lema, _رشتی_, _holá, 
   {{0x38c1e08d,0x6b89e08e,0xdb000232,0x7a2462c7}},	//   _tèré_, _madg, _kolá, _kıta, 
   {{0x22a40364,0x75e80166,0x00000000,0x00000000}},	//   _ҷумҳ, gızd, --, --, 
   {{0x5f95e08f,0x6e3c0009,0x657ccebf,0xdb00299d}},	// [36190] ниат, _awrb, mesh, _molá, 
   {{0x6d4004c9,0x7d18011c,0x7c38d9ef,0x31bc02fb}},	//   _aema, _sgus, _rwur, _víza_, 
   {{0x5d540c78,0x6d41e090,0x645de091,0x75e80724}},	//   екет, _bema, lusi, bızd, 
   {{0x6285e092,0x657dc61f,0x3f840989,0x6d41e093}},	//   _isho, nesh, žnu_, _cema, 
   {{0x6d41e094,0x645d1837,0xdb00004e,0x6b882749}},	//   _dema, nusi, _solà, _badg, 
   {{0x657de095,0x6d40007d,0x6b892e54,0x7d19e096}},	//   hesh, _eema, _cadg, _wgus, 
   {{0x645c00b2,0x6d41e097,0x387c05b1,0x6b8870d4}},	//   husi, _fema, wwur_, _dadg, 
   {{0x657de098,0x7d188544,0x645de099,0xceb00302}},	//   jesh, _ugus, kusi, _גיל_, 
   {{0x657de09a,0x395c5201,0x645c5c07,0x7c3894a7}},	//   desh, rgus_, jusi, _uwur, 
   {{0x645de09b,0x6b89e09c,0x31600007,0x6285e09d}},	//   dusi, _gadg, zgiz_, _osho, 
   {{0x6285e09e,0x6d40a8a9,0x657de09f,0x79a4d877}},	//   _nsho, _yema, fesh, _орде, 
   {{0x657de0a0,0x6d41e0a1,0x645de0a2,0x69340a8d}},	//   gesh, _xema, fusi, _анцу, 
   {{0x645de0a3,0x6285e0a4,0x394c0267,0x25e40073}},	//   gusi, _asho, _idgs_, ऐवजी_, 
   {{0x6b8801d9,0x62840175,0x21280076,0x28dc00cd}},	//   _xadg, _bsho, ecah_, मपरि, 
   {{0x645c4077,0x61e81326,0x657d8170,0xb6c001e0}},	//   ausi, čeln, besh, _шикһ, 
   {{0x645de0a5,0x657c1cea,0x6284010a,0xdde0010e}},	//   busi, cesh, _dsho, _çuňd, 
   {{0x394de0a6,0x6d402b8a,0x3161e0a7,0x645de0a8}},	// [361a0] _mdgs_, _rema, rgiz_, cusi, 
   {{0x6284030d,0x7bc1e0a9,0x2128011f,0x75e926df}},	//   _fsho, jhnu, acah_, sızd, 
   {{0x6d405101,0x6b89e0aa,0x7bc1e0ab,0x87b4010f}},	//   _pema, _radg, dhnu, עלעס_, 
   {{0x10a5e0ac,0xcd041b6d,0x6d4002d3,0x80c82366}},	//   _зимн, нчли, _qema, _सेके, 
   {{0x628402fa,0x6d4005b8,0x6b8805e4,0x531410ac}},	//   _zsho, _vema, _padg, _تذکر, 
   {{0xdb01e0ad,0xead44587,0x657c05d9,0x6d41e0ae}},	//   _solá, коль, zesh, _wema, 
   {{0x6d41e0af,0x657c00ec,0x645de0b0,0xdb019c01}},	//   _tema, yesh, zusi, _polá, 
   {{0x657c15fa,0x7bc001a2,0x645de0b1,0x6b880204}},	//   xesh, ahnu, yusi, _wadg, 
   {{0x657de0b2,0xdb0003f7,0x7bc00218,0xfce1e0b3}},	//   vesh, _volá, bhnu, _бото, 
   {{0x7bc03262,0x645de0b4,0xc5f801bc,0x72800023}},	//   chnu, vusi, ृष्य_, ሕነታዊ_, 
   {{0x81d404c5,0x645c789a,0xcc880055,0x16d80107}},	//   াকত_, wusi, _hṛ_, ҷмӯъ_, 
   {{0x645de0b5,0xcc8800b8,0x00000000,0x00000000}},	//   tusi, _kṛ_, --, --, 
   {{0x645c20ac,0x657de0b6,0x2ee40134,0x8cd41b76}},	//   uusi, resh, _ɛmfa_, _मेमो, 
   {{0xae2000e1,0x33841606,0x67d401ec,0x75e80139}},	//   यदान_, лусв, _шолу, gızb, 
   {{0x657de0b7,0x61e004d4,0x81740107,0x00000000}},	//   pesh, éllo, навӣ_, --, 
   {{0x657de0b8,0x61e999ea,0xdb00003a,0x62840118}},	//   qesh, čelo, _illô, _vsho, 
   {{0x645c0eda,0x2128020b,0xdbd000c5,0x62840334}},	// [361b0] qusi, rcah_, tüüb, _wsho, 
   {{0x6285e0b9,0x644de0ba,0x21280010,0x81c400ef}},	//   _tsho, _ivai, scah_, _slēģ, 
   {{0x62849c7a,0x00000000,0x00000000,0x00000000}},	//   _usho, --, --, --, 
   {{0x644c0006,0xcc8800cd,0x75e805d1,0xdd14104c}},	//   _kvai, _bṛ_, mızc, نواخ, 
   {{0x23bc0241,0x644c0129,0xdb007aa0,0x69a41223}},	//   _jìjo_, _jvai, _kolç, कानी, 
   {{0xd9c802ab,0xcc880055,0x00000000,0x00000000}},	//   िफ्ट, _dṛ_, --, --, 
   {{0x68fc03be,0x7bc013d5,0x00000000,0x00000000}},	//   ərdi, rhnu, --, --, 
   {{0x644de0bb,0x59740953,0x7bc1c456,0xe7b8031c}},	//   _ovai, тыку, shnu, _ħuġġ, 
   {{0xac7401ec,0xa3d000e1,0x644c01ab,0x23bc0ca8}},	//   _مالش, वफा_, _nvai, _nìjo_, 
   {{0x6fc001b8,0xd5a0037e,0x2be8012d,0x56280153}},	//   _köca, _kgでm_, _जदयू_, мжом_, 
   {{0x644d517b,0xd70834d8,0xa2d03d1d,0x00000000}},	//   _avai, ьное_, _डेल्, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2bb80d41,0xdb000432,0x798802d0,0xb0d000e1}},	//   _अवमा, _bolç, _iagw, _सेंग, 
   {{0x7989e0bc,0x23bc0241,0x644de0bd,0x5274121c}},	//   _hagw, _dìjo_, _dvai, кубу, 
   {{0x434006bb,0xdb01e0be,0x03a1e0bf,0x7989e0c0}},	//   ресв, _dolç, широ, _kagw, 
   {{0x79880109,0x2688007b,0x950401d3,0x00000000}},	//   _jagw, _أخوي_, _لہجے_, --, 
   {{0x7989e0c1,0x644c0399,0xd01007d6,0x448401af}},	// [361c0] _magw, _gvai, للر_, _абын_, 
   {{0x7989e0c2,0xdb00010e,0xbfc030e3,0x00000000}},	//   _lagw, _golç, абук, --, 
   {{0x0e65e0c3,0x644de0c4,0xb640037e,0x1ae80154}},	//   ткен, _zvai, _ｎｄ_, য়েতে_, 
   {{0x7989e0c5,0x069400c8,0xcc8800b8,0x644c0064}},	//   _nagw, כדעם_, _pṛ_, _yvai, 
   {{0xa3c82450,0xdb000213,0xdde00309,0xc0e000d4}},	//   लोक_, _yolç, ñuša, _вояк, 
   {{0x7988009f,0xcc880055,0x80c80210,0x00000000}},	//   _aagw, _vṛ_, _सेटे, --, 
   {{0x7989e0c6,0x3ea05a42,0x29000006,0x0a6806ed}},	//   _bagw, _кирг, _šia_, фрли_, 
   {{0x798807a8,0x26c002b1,0x236c00f3,0xcc880055}},	//   _cagw, _āio_, đeji_, _tṛ_, 
   {{0x798851e2,0xc7c4009d,0x00000000,0x00000000}},	//   _dagw, всни, --, --, 
   {{0x2cc49d58,0x7a241f02,0x00000000,0x00000000}},	//   ırdı_, _kıtl, --, --, 
   {{0x644de0c7,0x7988015d,0x00000000,0x00000000}},	//   _svai, _fagw, --, --, 
   {{0x7989e0c8,0x3ea40bc9,0xb7d401d5,0xdbd0010e}},	//   _gagw, änti_, _یونا_, _müýn, 
   {{0x443de0c9,0x00000000,0x00000000,0x00000000}},	//   èu_, --, --, --, 
   {{0x79893b0a,0xdb0006be,0xf6d002f2,0x60c800a2}},	//   _zagw, _qolç, ازید, _ýemi, 
   {{0x7989e0ca,0xdb000139,0xa3c8447d,0x6594004e}},	//   _yagw, _golä, लोग_, _байу, 
   {{0x31c41e8a,0x644c00e2,0x00000000,0x00000000}},	//   асув, _tvai, --, --, 
   {{0x644c0e1a,0xdb000166,0xdfd000ec,0xdee00023}},	// [361d0] _uvai, _tolç, ٽيا_, ናይን_, 
   {{0x2489e0cb,0x75e80205,0x00000000,0x00000000}},	//   _isam_, mıza, --, --, 
   {{0xdb0000cc,0xd1c80092,0x00000000,0x00000000}},	//   _kolå, _በጎች_, --, --, 
   {{0xdbd00432,0x00000000,0x00000000,0x00000000}},	//   _düýn, --, --, --, 
   {{0x1158008f,0x7989e0cc,0xf1a40006,0x75e815b7}},	//   _אדרע, _ragw, _трэн, nıza, 
   {{0x7989e0cd,0x1ae4036b,0xaf3400f2,0xcb641f91}},	//   _sagw, лолм, _نرفت, гаше_, 
   {{0x7989e0ce,0x248801b9,0x00000000,0x00000000}},	//   _pagw, _lsam_, --, --, 
   {{0x24880bb8,0xceb000c8,0x60c80024,0x6eb00118}},	//   _osam_, _פין_, _žemy, ंहरु, 
   {{0x69a40184,0x24880134,0xdbd000af,0x7989e0cf}},	//   рлыҡ, _nsam_, _küün, _vagw, 
   {{0x79889546,0x1db80574,0xdb00007c,0x00000000}},	//   _wagw, _आवडत, _polä, --, 
   {{0x2489e0d0,0x7989e0d1,0x2bb83885,0x61e82375}},	//   _asam_, _tagw, _अवता, čelj, 
   {{0x75e805d1,0x68e40c5e,0x00000000,0x00000000}},	//   fıza, _žide, --, --, 
   {{0x292400d7,0x00000000,0x00000000,0x00000000}},	//   ásať_, --, --, --, 
   {{0x485005d3,0x67d5e0d2,0x884c001f,0xd2500050}},	//   _اپوز, _кочу, _ማሰባሰ, ٝنس_, 
   {{0x248800da,0xa6a816ac,0xe2b40153,0x35c4014b}},	//   _esam_, _لايق_, астэ, _вайҳ, 
   {{0x2488000f,0x546801af,0x75e80139,0x00000000}},	//   _fsam_, _заим_, bıza, --, 
   {{0x91040c9e,0x69a40073,0x5ed00154,0xdbd00432}},	// [361e0] упае, काती, _তুলে, _süýn, 
   {{0x2bb80acd,0x63e4004b,0x91e001e0,0x00000000}},	//   _अवधा, _نېټې_, рәүһ, --, 
   {{0x7a25e0d3,0xdb200241,0xc7d4011a,0x00000000}},	//   _bıtm, _àtùt, נועי_, --, 
   {{0xccc40228,0x248801a9,0x0dc800db,0x6ccc02dd}},	//   лбей, _ysam_, элей_, _ﺒﻁﺭﻴ, 
   {{0x32000218,0x3d0c47b8,0x00000000,0x00000000}},	//   mliy_, तेले_, --, --, 
   {{0x3200006c,0xf00400d1,0xaa580ff1,0xdbd0010e}},	//   lliy_, _түзи, вику_, _tüýn, 
   {{0xff0405bc,0x00000000,0x00000000,0x00000000}},	//   _берк_, --, --, --, 
   {{0x48a88456,0x5eac02f5,0x7a2403e0,0x00000000}},	//   етом_, _টেকে, _gıtm, --, 
   {{0x52b00490,0x00000000,0x00000000,0x00000000}},	//   ीनुस, --, --, --, 
   {{0xdb0003cd,0x248801d5,0x7b840228,0x6924035b}},	//   _solå, _rsam_, _مامە, ымҩа, 
   {{0x24880139,0x32001180,0x00000000,0x00000000}},	//   _ssam_, kliy_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x59b00022,0xb5c80014,0xe2c800e5,0x00000000}},	//   _фҩыс, اوُم_, ھورو_, --, 
   {{0x7c2c0129,0x53b401e0,0x00000000,0x00000000}},	//   _écre, иғыр_, --, --, 
   {{0x7bdc2d7d,0xdb000158,0x3200020c,0x8cd42ef1}},	//   équi, _tolå, fliy_, _मेसो, 
   {{0x24880457,0x26cc0064,0x00000000,0x00000000}},	//   _tsam_, mzdo_, --, --, 
   {{0x361c025f,0x660de0d4,0x248806ed,0xdbd0000d}},	// [361f0] _אוהד, _ihak, _usam_, _püün, 
   {{0x645c01a6,0x7a2403e0,0x1ae800cc,0x00000000}},	//   mrsi, _sıtm, _ওৰফে_, --, 
   {{0x660c0084,0x32008fe9,0xa15800c7,0x26cc0036}},	//   _khak, bliy_, _иану_, nzdo_, 
   {{0x645de0d5,0xf2c40184,0xa19450d5,0xf6500375}},	//   orsi, _ысын, _тамч, מצע_, 
   {{0x660c06e4,0x645c0194,0x5ca400f7,0xdbd00037}},	//   _mhak, nrsi, рилб, _tüün, 
   {{0x60cc0944,0x660c020c,0x645de0d6,0x50a00131}},	//   mzam, _lhak, irsi, _بەكل, 
   {{0xdce804b9,0x660c03c1,0x645c0112,0x1a64036b}},	//   _obeć, _ohak, hrsi, شیشی_, 
   {{0x660c0433,0xdb000241,0xa83001e1,0x00000000}},	//   _nhak, _kolú, _ẹmẹs, --, 
   {{0x60cde0d7,0xc9a400c9,0xe9a80131,0x57e893cf}},	//   nzam, рвые_, ادىن_, кдим_, 
   {{0x660c0325,0x60cd0253,0x7f44014f,0xdb0001e1}},	//   _ahak, izam, _jejq, _molú, 
   {{0x660c0a28,0x645c0af5,0x7f440455,0x3c280174}},	//   _bhak, ersi, _mejq, _høv_, 
   {{0x660de0d8,0x60cde0d9,0x00000000,0x00000000}},	//   _chak, kzam, --, --, 
   {{0x660de0da,0x75e80724,0x446000a7,0x2f0c0241}},	//   _dhak, bızn, овяв, _kógí_, 
   {{0x60cde0db,0x660de0dc,0x7f44014f,0x1db80037}},	//   dzam, _ehak, _nejq, _आवऽत, 
   {{0x645c0af5,0x3c280ac8,0x60cc05c7,0x78b801a9}},	//   arsi, _løv_, ezam, lyuv, 
   {{0xdb00043b,0x660c0bd7,0x200002c4,0xaad80316}},	//   _bolú, _ghak, elhi_, _भइसक, 
   {{0x75245c18,0x60cc1529,0x7f44014f,0x78b8a84e}},	// [36200] _igiz, gzam, _bejq, nyuv, 
   {{0x7bc40054,0x7524030a,0x7640009f,0xd83802b1}},	//   _ŋjun, _hgiz, _kwny, ipō_, 
   {{0x8e847fb5,0x7f44025c,0x4d4802dd,0x0374011a}},	//   ргее, _dejq, впен_, _דתית_, 
   {{0xaca40032,0x7640009f,0xeac80220,0x660d9dc6}},	//   йгеһ, _mwny, ңғай_, _xhak, 
   {{0x9f400770,0x7f440135,0x60cc033f,0x2498069d}},	//   tlhô_, _fejq, czam, _ህዋሳት_, 
   {{0x99840421,0x35a80dad,0x78b80407,0x3c280450}},	//   _fulū_, गाड़, dyuv, _døv_, 
   {{0x75254437,0xdb0001e1,0x8cd4095f,0x00000000}},	//   _ogiz, _kolù, _मेरो, --, 
   {{0x7525e0dd,0x645c03cb,0xdb14010b,0x00000000}},	//   _ngiz, yrsi, _ýaýy, --, 
   {{0x6e21e0de,0x7f44047e,0xdde90404,0x3ce40073}},	//   _iimb, _yejq, _صرفه_, जपणे_, 
   {{0x7525312c,0x645c2ce2,0x61e80558,0xcb680120}},	//   _agiz, vrsi, čeli, _јаже_, 
   {{0x660c8cdb,0x6e21e0df,0x7bdcdf44,0x65942503}},	//   _phak, _kimb, èque, бану, 
   {{0x6e21e0e0,0x660c009a,0x00000000,0x00000000}},	//   _jimb, _qhak, --, --, 
   {{0x6e21e0e1,0x660c1aa1,0xb3b41b57,0x76400363}},	//   _mimb, _vhak, ुसंख, _ewny, 
   {{0x660d46b3,0x7525e0e2,0x38c80e60,0x60cc09a8}},	//   _whak, _egiz, _جامی_, vzam, 
   {{0x660de0e3,0x6e21e0e4,0xdb01e0e5,0xa159e0e6}},	//   _thak, _oimb, _solú, лаву_, 
   {{0x69c1e0e7,0x36309cc3,0x660c05d9,0xf1a40228}},	//   nkme, _بروس, _uhak, орун, 
   {{0x656c4539,0x2000c48b,0xdb000248,0x60cc0618}},	// [36210] _icah, tlhi_, _dolù, uzam, 
   {{0x60cde0e8,0xdb019614,0x6e21e0e9,0x3c28037e}},	//   rzam, _volú, _aimb, _røv_, 
   {{0x6e21e0ea,0x60cc068f,0x22940597,0x69c02147}},	//   _bimb, szam, _الجس, kkme, 
   {{0x656c02fa,0x60cc007f,0x84e00241,0x00000000}},	//   _jcah, pzam, _ṣẹṣẹ, --, 
   {{0x6e21e0eb,0x7f440218,0xacf82bbd,0xed580006}},	//   _dimb, _tejq, анцу_, роі_, 
   {{0x6e215d46,0x69c0017a,0x3ea401e3,0x00000000}},	//   _eimb, ekme, änts_, --, 
   {{0x6e21e0ec,0xdca481fc,0x9f9400c5,0x3da40229}},	//   _fimb, раһи, _müüb_, _краб, 
   {{0x5909e0ed,0x68e46b48,0x3c280450,0x75e80166}},	//   лейм_, _žida, _tøv_, gızl, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x656c6a2a,0xd7c803e6,0x69c09d08,0x31bc01d3}},	//   _acah, اوده_, akme, _vízi_, 
   {{0x6e20b05f,0x16c002ab,0x3cd800af,0x75e80790}},	//   _yimb, शनेब, _खेते_, bızl, 
   {{0xd8742a60,0x6e21e0ee,0x69c1e0ef,0x6af400db}},	//   _هاتب, _ximb, ckme, _گۉۉس_, 
   {{0x69a44da1,0xe6b4036b,0xd4f40108,0x1834010f}},	//   कारी, ملیگ, сяны, _פאַל_, 
   {{0xe8f800d4,0xa8040024,0x7990031c,0x00000000}},	//   _тлі_, _дзіл, żewġ, --, 
   {{0xd20401d9,0x00000000,0x00000000,0x00000000}},	//   مبرى, --, --, --, 
   {{0x75248aa7,0x2fd8020c,0x69dc0248,0xd7600244}},	//   _ugiz, _smrg_, _ìret, _بۆگی, 
   {{0x6e21e0f0,0x0ce05d2d,0x4fe9e0f1,0xc5f00a7c}},	// [36220] _rimb, _বর্ত, гман_, _מדה_, 
   {{0x5274010a,0x06ac00cc,0x336401e2,0x00000000}},	//   _луму, _ছেটি, _بندې, --, 
   {{0xa3000046,0x6e21e0f2,0xbcf0031c,0xe1f0004b}},	//   _жүре, _pimb, _བཙུཊ_, سسې_, 
   {{0x6e200429,0xa2d002ab,0x5eac00cc,0x00000000}},	//   _qimb, _डेट्, _টেঙে, --, 
   {{0x6e21e0f3,0xd09401f4,0x00000000,0x00000000}},	//   _vimb, _ушны, --, --, 
   {{0x6e2005d9,0x69c003a2,0x769401e1,0x425004d3}},	//   _wimb, wkme, _ẹyi, _بنێر, 
   {{0x6e21e0f4,0x69a41715,0xc3300302,0x28d005d7}},	//   _timb, काली, לוג_, _तेजि, 
   {{0x6e20f17a,0x00000000,0x00000000,0x00000000}},	//   _uimb, --, --, --, 
   {{0x69c09398,0xccc5e0f5,0xaec001e1,0x75e80139}},	//   rkme, _убай, _òòbè, gızm, 
   {{0x7c2c0231,0x75e82ed0,0x69c03453,0x67d400d4}},	//   _écra, sızl, skme, іону, 
   {{0x9ba01df2,0xfaa190ee,0x00000000,0x00000000}},	//   _زەيى, _нафо, --, --, 
   {{0x6fc0049f,0xa5f9e0f6,0x86e401b9,0x75e8013d}},	//   _böck, рему_, _қўлд, bızm, 
   {{0xdb01e0f7,0x6aa828fe,0x00000000,0x00000000}},	//   _anlè, _कपुर, --, --, 
   {{0xa3d401c0,0xa2840023,0x00000000,0x00000000}},	//   цогч, _ምልክን_, --, --, 
   {{0x69dc0ca8,0x00000000,0x00000000,0x00000000}},	//   _ìres, --, --, --, 
   {{0x6fc00730,0x00000000,0x00000000,0x00000000}},	//   _höch, --, --, --, 
   {{0x7bc40bc9,0xdb0007ea,0x6fc032e9,0xf3180131}},	// [36230] _ŋjum, _enlè, _köch, _қоюш_, 
   {{0x0ce00c58,0x6aa80034,0x6190001f,0x3fd4015b}},	//   _বৰ্ত, _कपूर, ህበራዊ_, তক্ষ, 
   {{0x6fc009f0,0x63a4035a,0x9d5400be,0x00000000}},	//   _möch, _inhn, قنات, --, 
   {{0x6fc003fa,0xdca4035b,0x00000000,0x00000000}},	//   _löch, ҩаҧи, --, --, 
   {{0xdb0000ae,0x2d580276,0x7a2400e5,0x00000000}},	//   _inlé, сичь_, _műte, --, 
   {{0xda58039b,0x7b641436,0x00000000,0x00000000}},	//   ариш_, стде, --, --, 
   {{0x63a4003e,0xeb5400db,0x00000000,0x00000000}},	//   _mnhn, سىيگ, --, --, 
   {{0x985400c7,0x22440122,0xfbd003e6,0x98bc012d}},	//   отош, álky_, _کتر_, _lewą_, 
   {{0x81b80154,0x00000000,0x00000000,0x00000000}},	//   _অগা_, --, --, --, 
   {{0x6fc00112,0x36400092,0x6d440162,0x00000000}},	//   _röck, _የተጨማ, ðiav, --, 
   {{0x6b9de0f8,0x7a24045f,0x95847b98,0x7bc1e0f9}},	//   _órga, _bűte, олне, mknu, 
   {{0x63a40208,0xd7c82c04,0xdb14010e,0x00000000}},	//   _anhn, اوگه_, _ýañy, --, 
   {{0x65f801c0,0x4df8010f,0xd79402e8,0x00000000}},	//   сээр_, שפרא, _мидъ, --, 
   {{0x6fc0002f,0x00000000,0x00000000,0x00000000}},	//   _vöck, --, --, --, 
   {{0x7bc161c3,0x00000000,0x00000000,0x00000000}},	//   iknu, --, --, --, 
   {{0x41241d0f,0x6fc0007c,0xd76400f1,0x00000000}},	//   жото_, _töck, _انډی, --, 
   {{0x7bc00008,0xb0c449fc,0x00000000,0x00000000}},	// [36240] kknu, लैंग, --, --, 
   {{0x248c00ee,0xdf48007b,0xc0c40092,0x00000000}},	//   çeme_, مؤمن_, _ሸክም_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8d75e0fa,0xcd04d20e,0x10a400f3,0x6fc00139}},	//   تائا, опей, _димн, _möci, 
   {{0xe19401c6,0x00000000,0x00000000,0x00000000}},	//   _эрээ, --, --, --, 
   {{0x0eb80a89,0xe2a80133,0x00000000,0x00000000}},	//   _кубы_, _ئاین_, --, --, 
   {{0x37dc03d4,0x4418011a,0x00000000,0x00000000}},	//   নকাৰ, בוסס, --, --, 
   {{0x3c600139,0x00000000,0x00000000,0x00000000}},	//   чкәг, --, --, --, 
   {{0xc2100302,0xcb69e0fb,0x00000000,0x00000000}},	//   והה_, _вазе_, --, --, 
   {{0xc07800c8,0xc71000b8,0x7bc03fd6,0x692400dc}},	//   סטיש, _apīḍ, cknu, _dṛḍh, 
   {{0x6594117e,0x00000000,0x00000000,0x00000000}},	//   пану, --, --, --, 
   {{0x6fc003fa,0xda6401e2,0x00000000,0x00000000}},	//   _wöch, _رامي, --, --, 
   {{0x6fc00e78,0x00000000,0x00000000,0x00000000}},	//   _töch, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d5c02b5,0xe658007b,0x94700133,0xf76de0fc}},	//   _ēran, _البث_, وگیا, _شاو_, 
   {{0x26d80030,0x3cd800af,0x1ae80154,0x00000000}},	//   úrou_, _खइले_, য়েকে_, --, 
   {{0x7bc04eb7,0xf0bc00b8,0xe2980150,0x00000000}},	// [36250] yknu, _īṣad_, шаң_, --, 
   {{0xdb200232,0x7a240139,0x00000000,0x00000000}},	//   _štít, _kıtt, --, --, 
   {{0xdb0009a5,0x68e4012c,0x92f005f5,0x7bc00250}},	//   _bolý, _židl, _зүрх, vknu, 
   {{0x836404fb,0x20cc022e,0x12f8011a,0x00000000}},	//   _ادکل, _dоir_, _להתב, --, 
   {{0x7bc02b57,0xdb000432,0x1d080114,0x00000000}},	//   tknu, _dolý, љели_, --, 
   {{0x44380a2e,0x20041f60,0x46c84c5b,0x00000000}},	//   _mtq_, _óli_, ानाह, --, 
   {{0xcb640108,0xbd6800d8,0x8b2000d8,0x00000000}},	//   чаще_, _врзе_, ндше, --, 
   {{0x7c2c004a,0x7bc1e0fd,0xdb00010b,0x394800e5}},	//   _écro, sknu, _golý, úcs_, 
   {{0x9d44678d,0x4438010a,0x7e740204,0x6c54004e}},	//   _меңд, _ntq_, ltxp, _окту, 
   {{0x7c39e0fe,0x77f40574,0x59a8012c,0x7a240205}},	//   _itur, ुतेक_, काहर, _bıtt, 
   {{0x4439e0ff,0x00000000,0x00000000,0x00000000}},	//   _atq_, --, --, --, 
   {{0x69dc0024,0xca940375,0xd7c8331c,0xb80807f7}},	//   _įreg, _מדעי_, _گوته_, _सीरम_, 
   {{0x18a400ee,0x3d0c0073,0xc9500a7c,0x98a40395}},	//   _халм, तेचे_, _טמא_, _хиле, 
   {{0x319801f2,0x88980375,0x7e740158,0x7c380175}},	//   _ọz_, _לבני, ktxp, _mtur, 
   {{0xdb00014a,0x7c38022e,0xe70801ec,0x7a240790}},	//   _nolü, _ltur, _وتىن_, _gıtt, 
   {{0x7c39e100,0x00000000,0x00000000,0x00000000}},	//   _otur, --, --, --, 
   {{0x7c3801b2,0xdb01e101,0x3cd802fe,0x7a240205}},	// [36260] _ntur, _koló, _खेले_, _zıtt, 
   {{0xdb00496e,0xc0000798,0x00000000,0x00000000}},	//   _bolü, епук, --, --, 
   {{0x7c39e102,0x0d840209,0x03b80375,0xdb010a06}},	//   _atur, злен, _הציל, _moló, 
   {{0x7c38003e,0xdb000248,0x68e400d7,0x00000000}},	//   _btur, _loló, _židm, --, 
   {{0xdb0001e1,0xc19800d9,0x00000000,0x00000000}},	//   _ooló, _השכי, --, --, 
   {{0x7c3800ae,0x00000000,0x00000000,0x00000000}},	//   _dtur, --, --, --, 
   {{0x7c39e103,0xdb01e104,0x7744001f,0x00000000}},	//   _etur, _golü, _የሠራተ, --, 
   {{0x2bb8243c,0x7c38004e,0x28c4020a,0xad840150}},	//   _अवका, _ftur, дшоҳ, _تاسۇ, 
   {{0x67d42472,0x7c3800ae,0xdcf00327,0xe8b80073}},	//   допу, _gtur, _ħgħa, ेनेच, 
   {{0xdb01e105,0x2b4c0048,0xc5f400cd,0xa63c0092}},	//   _coló, _uedc_, ीत्य_, _የተወደ, 
   {{0xcb080026,0xdb000241,0xf67019bb,0xbb38011a}},	//   _ايان_, _doló, нгээ, _העבי, 
   {{0xc9d401b9,0xe954009f,0x00000000,0x00000000}},	//   _عزاب, _آراڌ, --, --, 
   {{0xc7c417a0,0x07a51a8f,0xdb0027b9,0x250801b9}},	//   _нски, _надн, _foló, تردی_, 
   {{0xdb0000d2,0x6d2c031c,0x00000000,0x00000000}},	//   _goló, _སུའེ_, --, --, 
   {{0x36303b44,0x6594004e,0xb284013d,0xb778123b}},	//   _كريس, _жайу, нытк, _האוש, 
   {{0xdb01e106,0x3f9c013d,0xb64401ec,0x00000000}},	//   _kolò, _şuu_, _ﻋﺞ_, --, 
   {{0x3168013e,0x25a80205,0xdb0003e0,0x5f945e0c}},	// [36270] яшро_, _inal_, _solü, миат, 
   {{0xdb01e107,0xa2b4278e,0x313401c6,0x25a801ef}},	//   _molò, _उपप्, _үеэр, _hnal_, 
   {{0x657c058a,0x00000000,0x00000000,0x00000000}},	//   ofsh, --, --, --, 
   {{0x6285e108,0xdb01e109,0x5bc400dc,0x7c380139}},	//   _ipho, _volü, वस्व, _ptur, 
   {{0x61ede10a,0x6e3c0165,0x00000000,0x00000000}},	//   mnal, _etrb, --, --, 
   {{0x61ede10b,0x38c00241,0x82e80327,0x00000000}},	//   lnal, _lérú_, _རྨོའ, --, 
   {{0xdb00ec21,0x6284010a,0x0f3007d6,0x7a240139}},	//   _roló, _jpho, _شکلد, _rıts, 
   {{0xa2b419e5,0xdb01e10c,0x6284055a,0x25a8102c}},	//   _उपन्, _soló, _mpho, _nnal_, 
   {{0x7c39e10d,0xdb01e10e,0xd888121e,0x9b5801c6}},	//   _utur, _colò, تھان_, _миат_, 
   {{0x25a807d5,0x6285e10f,0x657de110,0xd7c8007b}},	//   _anal_, _opho, efsh, زوجه_, 
   {{0x628401d4,0x5975e111,0x657cecac,0xdb000ba1}},	//   _npho, _жылу, ffsh, _voló, 
   {{0x82e8025c,0x61ed09da,0xceb00375,0xbec400ef}},	//   _རྨེའ, jnal, דיט_, _grīš, 
   {{0x61ecceb3,0x38c001e1,0xdb00559d,0x7a2403e0}},	//   dnal, _dérú_, _toló, _fıtr, 
   {{0x61ede112,0x25a8011f,0x657c058a,0x21380200}},	//   enal, _enal_, afsh, _afsh_, 
   {{0x394c039a,0x61ec0008,0xe1c845c7,0x62840175}},	//   _kegs_, fnal, रसंघ, _cpho, 
   {{0x61ede113,0x6285e114,0x54680131,0x25a80010}},	//   gnal, _dpho, _даим_, _gnal_, 
   {{0x6285e115,0x394c0098,0x6e3de116,0x41dc078a}},	// [36280] _epho, _megs_, _strb, _नगरस, 
   {{0x7e784ca5,0x25a814b2,0x62840334,0x940400c6}},	//   _ćupr, _znal_, _fpho, _زوجه, 
   {{0xce480220,0x62840051,0xe0d00014,0x25a800a2}},	//   ізде_, _gpho, نزے_, _ynal_, 
   {{0x61ed2e5d,0x0c8400db,0x00000000,0x00000000}},	//   cnal, дыкм, --, --, 
   {{0x3200006c,0x63a0006a,0x00000000,0x00000000}},	//   moiy_, ôlng, --, --, 
   {{0x1ae800bd,0xdb2001a2,0x8aa5e117,0x628402d0}},	//   য়েছে_, _štát, дрид, _ypho, 
   {{0xa93445b3,0x394de118,0x0a680212,0x657c017a}},	//   нейш, _begs_, ірки_, yfsh, 
   {{0x60700201,0xdb01e119,0x3200036b,0x00000000}},	//   _ድርጅት_, _polò, noiy_, --, 
   {{0xbd3001ec,0x38c001e1,0xe9445226,0x00000000}},	//   _شىلع, _rérú_, ورکی, --, 
   {{0x796001e1,0x3c6000db,0x00000000,0x00000000}},	//   _pìwà, _шкуг, --, --, 
   {{0x394c0493,0xc958022e,0x00000000,0x00000000}},	//   _fegs_, _дўл_, --, --, 
   {{0x75e801d3,0x6285bd70,0x657c002f,0x499401ec}},	//   yűze, _rpho, ufsh, _ішет, 
   {{0x657de11a,0x6285e11b,0x64c402dd,0x21380076}},	//   rfsh, _spho, ريسل, _rfsh_, 
   {{0x46680798,0x2ba41cba,0x628401f4,0x61ed8d0a}},	//   _дрим_, _गोमा, _ppho, wnal, 
   {{0x394c0793,0x8cd43c71,0x81740107,0x00000000}},	//   _yegs_, _मेघो, мавӣ_, --, 
   {{0x61ed508b,0xdb00000f,0x4ab4000d,0x00000000}},	//   unal, _ynlâ, _अपनव, --, 
   {{0x77bc0120,0x9f4000f2,0x661c8c66,0x5f9400e5}},	// [36290] _têxt, lihé_, mmsk, ٹلائ, 
   {{0x62840cf9,0x644de11c,0x5f9400e3,0x30a402e8}},	//   _tpho, _iwai, علائ, ърсв, 
   {{0x62842939,0x644c0433,0x661c2694,0x320001a9}},	//   _upho, _hwai, omsk, boiy_, 
   {{0x644de11d,0x61ec00ac,0xed5800d4,0x234802f2}},	//   _kwai, qnal, дої_, _بسکی_, 
   {{0x394de11e,0xdb84049d,0x9138008f,0x00000000}},	//   _regs_, егли, _מערק, --, 
   {{0x394de11f,0x644c5416,0x9f8c02d2,0xdb2002f0}},	//   _segs_, _mwai, _kþí_, štíp, 
   {{0x394c1590,0x0c200022,0x00000000,0x00000000}},	//   _pegs_, ымшн, --, --, 
   {{0x2001e120,0x644de121,0xc95403cc,0x661c00f3}},	//   lohi_, _owai, ىلىش_, jmsk, 
   {{0x60700020,0x394c29c2,0x644c01ab,0x98a5e122}},	//   _ድርጊት_, _vegs_, _nwai, хипе, 
   {{0x2001e123,0xdce89d28,0x244c01fa,0x661cfeeb}},	//   nohi_, _ubeđ, džm_, emsk, 
   {{0xd5e45cf0,0x2bac00a5,0x644de124,0xd7081f39}},	//   ежни, चारा, _awai, яное_, 
   {{0x20000c09,0x644c0428,0x58d51d84,0xaa64c03b}},	//   hohi_, _bwai, _поет, _штук, 
   {{0x2001e125,0x320007d6,0xdd9800a2,0x48e40037}},	//   kohi_, voiy_, _maň_, _जइयो_, 
   {{0x644d0b3a,0xd9b401d9,0x661c000f,0x79980784}},	//   _dwai, _تٔچھ, amsk, lduw, 
   {{0x32000086,0x2000414b,0xb808033f,0x6d540055}},	//   toiy_, dohi_, _सीएम_, _ṇimā, 
   {{0x7999e126,0x68e46f98,0xc320a415,0xdd9800d0}},	//   nduw, _židi, умск, _naň_, 
   {{0x1cc81b35,0x644c0cfd,0x3ea00227,0x20000270}},	// [362a0] ིགས_, _gwai, _arjt_, fohi_, 
   {{0x4478008d,0xb3580edf,0x9d340023,0x200001d5}},	//   _צניע, _زیرا_, _ብሓፈሽ, gohi_, 
   {{0x66282258,0x637801e7,0x00000000,0x00000000}},	//   _üskü, súnó, --, --, 
   {{0xc0f036bc,0xa2b40316,0x644c0142,0x00000000}},	//   ግራም_, _उपत्, _ywai, --, 
   {{0xdd99e127,0x27e006a3,0x200155c6,0x2600045b}},	//   _daň_, _ïing_, bohi_, रवती_, 
   {{0x48e4000d,0x00000000,0x00000000,0x00000000}},	//   _जइबो_, --, --, --, 
   {{0x3ea06b62,0x702c0327,0x661de128,0xcf24009f}},	//   _йирг, _ཧྤྷུ_, ymsk, _سرسي, 
   {{0x7998089c,0xdd9800a2,0xd72000fe,0x3cd8000d}},	//   gduw, _gaň_, পুৱা_, _खेके_, 
   {{0xc8340023,0x9f40020c,0xfd54011a,0x00000000}},	//   _ኣደራዕ, wihé_, _רשמי_, --, 
   {{0x644c0433,0x9f4000f2,0xdd980419,0x78d000c7}},	//   _rwai, tihé_, _zaň_, ужьх, 
   {{0x644de129,0x79980086,0xa5f9e12a,0x00000000}},	//   _swai, bduw, дену_, --, 
   {{0x644c0295,0x661c0158,0x41bc0037,0x2ba40f4a}},	//   _pwai, umsk, _एकइस, _गोता, 
   {{0x20019ab7,0xb9b80375,0x9f4000f2,0xf990010f}},	//   yohi_, _מצאת, sihé_, _תרנ_, 
   {{0x5ef40a28,0x276801d5,0x7dd005d2,0x661c03ac}},	//   ्थम्_, _آششی_, _içse, smsk, 
   {{0x3f840037,0x20006b31,0x75e80139,0x97340153}},	//   õnum_, vohi_, gızs, _рэчч, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x20001f45,0x644de12b,0x97f407d6,0x1f740209}},	// [362b0] tohi_, _uwai, _سکیز_, клая, 
   {{0x7c2de12c,0x868000b5,0x69440010,0xdd98010e}},	//   _écri, _pc用u, lčeč, _saň_, 
   {{0x2001e12d,0xf3640262,0xdd9800a2,0x5398011a}},	//   rohi_, _стын, _paň_, _חיתו, 
   {{0x248801f2,0xe13802dd,0xc0580212,0x00000000}},	//   _kpam_, _ізгі_, _ніг_, --, 
   {{0x248805b1,0xc0c80092,0x408400d8,0x00000000}},	//   _jpam_, አደራ_, _џумб, --, 
   {{0x248805da,0x2ba402ab,0xdd9800a2,0x2000022e}},	//   _mpam_, _गोदा, _waň_, qohi_, 
   {{0x9f048ca8,0x79980086,0xa3e80307,0x2d84009f}},	//   _شورو, tduw, _मगन_, _fbme_, 
   {{0xceb002e4,0x248801d5,0xc0f02440,0x9c6401c8}},	//   _דיל_, _opam_, ግራሙ_, _لهرو, 
   {{0x24880211,0x1b7800d8,0x00000000,0x00000000}},	//   _npam_, _обањ_, --, --, 
   {{0x47c01064,0xdb0004d4,0x7f54003a,0x00000000}},	//   ибыв, _enlá, naxq, --, 
   {{0x24880134,0xfaa400ee,0x7dd00139,0x15441fd4}},	//   _apam_, _яшан, _eçse, кенм, 
   {{0x55e400a8,0x5a2401d9,0xe6b401b9,0x00000000}},	//   томб, _شباہ, چلیگ, --, 
   {{0x25580323,0x248806af,0xe6b49bcb,0x8d58011a}},	//   эрээ_, _cpam_, _ەلىگ, וכרי, 
   {{0xd705e12e,0x248800b5,0x67d400d1,0x59a80f90}},	//   _изли, _dpam_, _йочу, काकर, 
   {{0x7f54003a,0x91e40cb6,0x00000000,0x00000000}},	//   daxq, вове, --, --, 
   {{0x016017a0,0x217401c0,0xdb0002d2,0x153c002b}},	//   иксо, луур, _folö, _nāḍī, 
   {{0xc320009e,0xbf84004d,0xc95002e4,0x05ac0b4c}},	// [362c0] বুলি_, _ýcủa_, ימן_, टारब, 
   {{0xdb0001bf,0x4090036b,0xab5c00ef,0x91800228}},	//   _inlæ, ؤللر, _koļe, دۇڭۇ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8c4474e9,0x1ea82ea8,0xdb00399d,0x1e940022}},	//   веде, عالي_, _yolö, ырур, 
   {{0xdc4402b1,0x998c00a2,0x00000000,0x00000000}},	//   tūāh, mleň_, --, --, 
   {{0x6b7401a9,0x998c00a2,0x00000000,0x00000000}},	//   улку, lleň_, --, --, 
   {{0xba7127b2,0x00000000,0x00000000,0x00000000}},	//   لايت, --, --, --, 
   {{0xa2b46236,0x499001d5,0x39a000c7,0x39e400c7}},	//   _उपस्, شیتر, ашьв, кьын_, 
   {{0x0c25e12f,0x00000000,0x00000000,0x00000000}},	//   _аман, --, --, --, 
   {{0x0ba83e52,0xab5c00ef,0x8c25e130,0x00000000}},	//   _تارى_, _boļe, _شفاه, --, 
   {{0xda6431ed,0xdb0004ce,0x6ae0015b,0x24892ccb}},	//   _ماني, _anlæ, _পুরো, _spam_, 
   {{0x25ac0724,0xb99000cf,0x39e4014b,0x00000000}},	//   ñel_, _ۅلۅب, _идхо_, --, 
   {{0xb9040011,0x00000000,0x00000000,0x00000000}},	//   _মু_, --, --, --, 
   {{0x7c2c468a,0x00000000,0x00000000,0x00000000}},	//   _ècre, --, --, --, 
   {{0xf2c5a985,0x7bdc00cf,0x00000000,0x00000000}},	//   астн, èqui, --, --, 
   {{0x2ba5b1c8,0xf6700244,0x00000000,0x00000000}},	//   _गोसा, _ئاوخ, --, --, 
   {{0x2488151c,0xf19416ab,0x836001d9,0x746801c6}},	// [362d0] _upam_, шить, _پۯزل, _ирэв_, 
   {{0x645cd468,0xcaf010eb,0x00000000,0x00000000}},	//   mssi, _अखंड_, --, --, 
   {{0x69dc02d5,0x645c0caa,0xa1580816,0x00000000}},	//   _įren, lssi, _пану_, --, 
   {{0x2618003e,0x00000000,0x00000000,0x00000000}},	//   léob_, --, --, --, 
   {{0x645c049b,0x2ba405f9,0xb0280372,0x2d58084c}},	//   nssi, _गोहा, ركۅم_, тичь_, 
   {{0x645de131,0x00000000,0x00000000,0x00000000}},	//   issi, --, --, --, 
   {{0x9aa4168d,0x5f2000cc,0x00000000,0x00000000}},	//   امبو, _প্ৰখ_, --, --, 
   {{0x645c002e,0xaac400d1,0xac750bd3,0x00000000}},	//   kssi, شتىن, _چالش, --, 
   {{0x645c0b21,0xbc38132f,0x2d580108,0x00000000}},	//   jssi, _آسرا_, _шить_, --, 
   {{0x645c005c,0x365c001f,0xac0800f3,0x00000000}},	//   dssi, _ለተጨማ, _анђа_, --, 
   {{0x645c22a9,0xdb0006ed,0x98940022,0x00000000}},	//   essi, _colô, туқә, --, 
   {{0xdb0000d2,0xd4681910,0xf9901867,0x645c02d2}},	//   _dolô, ниме_, _خبط_, fssi, 
   {{0xaca4063f,0x9878008f,0x65f9e132,0xc4800600}},	//   vaịs, _נאַט, тээр_, бляк, 
   {{0x387c02d3,0x96940e92,0xa2b49201,0x00000000}},	//   mtur_, _бриш, _उपश्, --, 
   {{0x645de133,0x00000000,0x00000000,0x00000000}},	//   assi, --, --, --, 
   {{0xdb009c56,0x645c005c,0xa2b43156,0xab5c00ef}},	//   _inlä, bssi, _उपर्, _koļc, 
   {{0x387de134,0x645c010a,0x260016da,0xd01007d6}},	// [362e0] ntur_, cssi, रवरी_, ملر_, 
   {{0x387de135,0x76400263,0x00000000,0x00000000}},	//   itur_, _ktny, --, --, 
   {{0x77440020,0x91e41149,0x387cf60d,0x0e640150}},	//   _የአስተ, _боне, htur_, укен, 
   {{0xdd980220,0x717400d1,0x00000000,0x00000000}},	//   кші_, _خۇرا, --, --, 
   {{0x387c069c,0xf76416cb,0x29d80332,0xf64401d3}},	//   jtur_, _ٿا_, _héag_, _گئ_, 
   {{0x387c08cb,0x2ba401ad,0x4ed00354,0x00000000}},	//   dtur_, _गोशा, _гιов, --, 
   {{0xf64400aa,0x387c16b8,0x0a6801a9,0x00000000}},	//   _دئ_, etur_, хрли_, --, 
   {{0x645de136,0x387c2880,0x2ba40d01,0xd90c01d3}},	//   yssi, ftur_, _गोरा, ڈیم_, 
   {{0x76400a2e,0xdb00363f,0xd90c75ab,0x645c022e}},	//   _atny, _anlä, ویم_, xssi, 
   {{0xdb012d6b,0x8078008f,0xc078010f,0xa2b428fe}},	//   _polô, עניצ, עטיש, _उपल्, 
   {{0xe5b4f525,0x387c1730,0xc9841607,0x21e401f2}},	//   айны, atur_, _були, ịhia_, 
   {{0x387c022e,0x65c80107,0x00000000,0x00000000}},	//   btur_, ттоҳ_, --, --, 
   {{0x387de137,0x645c0af5,0x7640000f,0x00000000}},	//   ctur_, ussi, _etny, --, 
   {{0x645de138,0x0b1400eb,0x241804b4,0x00000000}},	//   rssi, াশীল_, тогы_, --, 
   {{0xa159e139,0xd7b00073,0x229402e8,0xa2940006}},	//   каву_, जारच, шивя, шаві, 
   {{0x29d800c6,0x645c00d4,0x00000000,0x00000000}},	//   _déag_, pssi, --, --, 
   {{0x9f55e13a,0xdb000267,0x00000000,0x00000000}},	// [362f0] ивач, _inlå, --, --, 
   {{0x6aa87944,0x6d41e13b,0x2ba40c5a,0x3f859524}},	//   _ordf, _afma, _गोला, ýnu_, 
   {{0x7dd0496e,0x387de13c,0x29d801e7,0xde9406ed}},	//   _açsa, ztur_, _géag_, раењ, 
   {{0x387de13d,0x00000000,0x00000000,0x00000000}},	//   ytur_, --, --, --, 
   {{0x387de13e,0x6aa800ae,0x29d801e7,0x9b4401d5}},	//   xtur_, _ardf, _méad_, لچاو, 
   {{0xdfd42de5,0x442002d1,0x387c2611,0x00000000}},	//   _тогы, nmj_, vtur_, --, 
   {{0xdd95e13f,0x1ddc1fd2,0x00000000,0x00000000}},	//   _кавы, _मतपत, --, --, 
   {{0x387de140,0x3ac4002e,0xd78805d9,0x38ac01a8}},	//   ttur_, _dёpp_, ھنجو_, jörð_, 
   {{0x69a400fb,0xacf83f1b,0x61e000e5,0xf1b400df}},	//   слыҡ, _бнту_, élly, מסק_, 
   {{0xe7e00050,0x387d523d,0x67240115,0x00000000}},	//   गोला_, rtur_, _ŝija, --, 
   {{0x387de141,0xdab80b73,0x98b003e0,0x00000000}},	//   stur_, _جهات_, ğzı_, --, 
   {{0x44200007,0x29d800c6,0x00000000,0x00000000}},	//   emj_, _céad_, --, --, 
   {{0x3cf0012d,0xe810000d,0x00000000,0x00000000}},	//   _आखों_, _ठीका_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7641e142,0x1545e143,0x3f9002fb,0x42e4013e}},	//   _utny, _кейм, dexu_, амро_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2dc874ec,0xaca402e3,0x762400ec,0x673402d2}},	// [36300] ққан_, _kwụp, _پڙھن, _áfjá, 
   {{0x5275e144,0x49180c22,0x00000000,0x00000000}},	//   _куму, मेटो_, --, --, 
   {{0x8e74014b,0x3ea0009d,0x00000000,0x00000000}},	//   рузч, жихг, --, --, 
   {{0xbd645aa2,0x00000000,0x00000000,0x00000000}},	//   арше_, --, --, --, 
   {{0x61e00221,0xfce0009d,0x00000000,0x00000000}},	//   ëlle, ооцо, --, --, 
   {{0x628000db,0xaa582f5c,0x00000000,0x00000000}},	//   àlog, гику_, --, --, 
   {{0x160409d9,0x975400b8,0x61f002d2,0x00000000}},	//   रवार_, _aṇor, _óhlý, --, 
   {{0xb9c00075,0x7e980375,0xc32000fe,0x00000000}},	//   ققىي, _בסלו, বুকি_, --, 
   {{0xb9c00491,0xd7b00073,0x29d800ae,0x7dd000a2}},	//   تقيي, जांच, _réad_, _uçsa, 
   {{0xc6a5073a,0x3d180cb4,0x7b840131,0x29d801e7}},	//   арми, _बरते_, _نامە, _séad_, 
   {{0xaa4400cf,0xfaa1e145,0xdc8c0023,0x00000000}},	//   _اچتى, _мафо, _መልሰይ_, --, 
   {{0x291803be,0x44200309,0x00000000,0x00000000}},	//   əran_, wmj_, --, --, 
   {{0x49a401ee,0x998c0139,0x00000000,0x00000000}},	//   _быҙғ, lmeş_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb9dc0125,0x29d8007b,0x44200175,0x65b00133}},	//   _ኤች_, _téad_, rmj_, _فیدڕ, 
   {{0x29d80098,0x00000000,0x00000000,0x00000000}},	//   _héab_, --, --, --, 
   {{0x3f900306,0x26cc0064,0x00000000,0x00000000}},	// [36310] texu_, lydo_, --, --, 
   {{0x44200309,0x00000000,0x00000000,0x00000000}},	//   qmj_, --, --, --, 
   {{0xceb410db,0x660c0083,0xa19428eb,0x00000000}},	//   бәт_, _kkak, _ланч, --, 
   {{0xeea82f26,0x93142bc0,0x00000000,0x00000000}},	//   штук_, _دوپش, --, --, 
   {{0x660d7b53,0x61ec02f6,0x9b4400c6,0xab5c00ef}},	//   _mkak, mial, منشو, _soļa, 
   {{0x60cde146,0xab5c00ef,0x00000000,0x00000000}},	//   myam, _poļa, --, --, 
   {{0x60cde147,0xf21c1533,0x660de148,0x00000000}},	//   lyam, _भीड़_, _okak, --, 
   {{0x660de149,0xeab1e14a,0x7c9401d9,0x00000000}},	//   _nkak, بعه_, _پشرا, --, 
   {{0xdb00002d,0xfaa039b8,0x00000000,0x00000000}},	//   _ynlû, сақо, --, --, 
   {{0x61ede14b,0x7b74ebc2,0x60cc0099,0x3a84023a}},	//   hial, _خطرا, iyam, _выдв, 
   {{0x61ede14c,0x60cde14d,0x1ae403d4,0x7e600332}},	//   kial, hyam, _পুৰা, ánph, 
   {{0x60cde14e,0x660c0c6a,0x61ec01b9,0x00000000}},	//   kyam, _ckak, jial, --, 
   {{0x60cde14f,0x660c0770,0x18696a23,0xe468005b}},	//   jyam, _dkak, _сали_, ишёл_, 
   {{0x660de150,0xb9f00020,0x60cde151,0x7d1801f7}},	//   _ekak, _ዝም_, dyam, _mzus, 
   {{0x660c03a0,0xa3e822e3,0x60cc1418,0x26181f5d}},	//   _fkak, _मगर_, eyam, méon_, 
   {{0x61ede152,0x463800c8,0x2619e153,0xa6440214}},	//   gial, _געקע, léon_, _بخون, 
   {{0x60cde154,0x637c01e1,0xd98c0150,0x00000000}},	// [36320] gyam, _kàǹ, _ﺒﺄﺤﺩ_, --, 
   {{0xcf2405d4,0x637c01e1,0x61ede155,0xbfc00229}},	//   مرضي, _jàǹ, aial, пбук, 
   {{0x7d1804ce,0x60cc2dff,0x823400ec,0xdb240ca8}},	//   _azus, ayam, _ٿرپا, _àpèj, 
   {{0x26185eb5,0x60cc1421,0x9e64f9ca,0x926800c7}},	//   héon_, byam, زامن, _ирҭа_, 
   {{0x4478008f,0x60cde156,0x00000000,0x00000000}},	//   ָנצע, cyam, --, --, 
   {{0x78b80077,0x0fd8007b,0x0b58010b,0x7d1800d7}},	//   dxuv, _إبحث_, урды_, _dzus, 
   {{0x1cc80156,0x7d19e157,0x26180129,0xa2840023}},	//   ིགཔ_, _ezus, déon_, _ምውናን_, 
   {{0x26cc0024,0x60d000a2,0x00000000,0x00000000}},	//   vydo_, _ähmý, --, --, 
   {{0x637c01e1,0x660c0113,0xa3e8000d,0x26cc015d}},	//   _bàǹ, _rkak, _मगल_, wydo_, 
   {{0x61ede158,0x660c0591,0x961000cc,0xf41800cc}},	//   zial, _skak, _সংগম_, _ধূসৰ_, 
   {{0x37a5e159,0x09e4005b,0xc6e40150,0x00000000}},	//   стын_, _ложн, сіпп, --, 
   {{0x61ec4fbb,0x60cc0a55,0x00000000,0x00000000}},	//   xial, yyam, --, --, 
   {{0x26180066,0x5fb80073,0x60cd5192,0x00000000}},	//   béon_, _उचलल, xyam, --, 
   {{0x69c02625,0x660c003e,0x61ec033f,0x3d182122}},	//   ljme, _wkak, wial, _बरसे_, 
   {{0x61ede15a,0x660c031c,0x60cc0309,0xbb3808a8}},	//   tial, _tkak, wyam, רעלי, 
   {{0x660de15b,0x69c01509,0x60cde15c,0x61ec003a}},	//   _ukak, njme, tyam, uial, 
   {{0xa2b40574,0x35f85837,0xdb0000d8,0x60cde15d}},	// [36330] _उपक्, _درود_, _calê, uyam, 
   {{0x60cde15e,0x2fd80332,0x44380166,0x850000f1}},	//   ryam, _clrg_, _iuq_, _ووژن, 
   {{0x4439d2ec,0x61ede15f,0x23b401b9,0x2fd80112}},	//   _huq_, pial, _همکس, _dlrg_, 
   {{0x4431e160,0x443802d3,0xdb00315a,0xdb240241}},	//   _hix_, _kuq_, _falê, _àpéj, 
   {{0x4439e161,0x61fc0d27,0x44300009,0x1d080063}},	//   _juq_, _ijsl, _kix_, јели_, 
   {{0x4438d8a7,0x8b3400d1,0x00000000,0x00000000}},	//   _muq_, ەۋەر_, --, --, 
   {{0x4439e162,0x44300375,0x798803ac,0xdab80006}},	//   _luq_, _mix_, _pbgw, рылі_, 
   {{0xdb002776,0x4431e163,0x3cfc0218,0xa28402d3}},	//   _halë, _lix_, _txuv_, _ምግናን_, 
   {{0x7e740a40,0x44380842,0x7d1800ec,0x443000db}},	//   luxp, _nuq_, _uzus, _oix_, 
   {{0x4430101d,0x16648b16,0x57e80d84,0x96640d08}},	//   _nix_, овом, рдом_, окое, 
   {{0x7c39e164,0xdb000023,0xa2b4878d,0x00000000}},	//   _huur, _malë, _उपग्, --, 
   {{0x4431e165,0x4439e166,0xc908063f,0xda1c033f}},	//   _aix_, _buq_, ịbịr, _पठित_, 
   {{0x7c382053,0x44300135,0x443800e8,0xdb000ac8}},	//   _juur, _bix_, _cuq_, _anlø, 
   {{0x44300207,0x443851ab,0x7e740113,0x17c802e8}},	//   _cix_, _duq_, kuxp, _ъгли_, 
   {{0x4431e167,0x7c3833eb,0x64580003,0xf1c801ef}},	//   _dix_, _luur, _ħwie, _lhář_, 
   {{0x395de168,0x44383aaf,0x443000f7,0x11493cde}},	//   naus_, _fuq_, _eix_, рпай_, 
   {{0x4fe9e169,0x44380007,0x7c39e16a,0x44310e7c}},	// [36340] аман_, _guq_, _nuur, _fix_, 
   {{0x395de16b,0xdb011121,0xa448007b,0x00000000}},	//   haus_, _valê, _اشيك_, --, 
   {{0xdb0054f1,0x395de16c,0x2ba403e5,0xab5c00de}},	//   _walê, kaus_, _गोगा, _soļo, 
   {{0x7c39e16d,0x4438d543,0x395de16e,0x904401c8}},	//   _buur, _yuq_, jaus_, _ونجه, 
   {{0xdb0002d3,0x395ce575,0x7c38a6ec,0x7e7402d0}},	//   _falë, daus_, _cuur, auxp, 
   {{0x0a69e16f,0x7c3983a8,0xdb01e170,0x8a68036b}},	//   арии_, _duur, _kalè, ашиб_, 
   {{0x6e200175,0x395c01f4,0x00000000,0x00000000}},	//   _thmb, faus_, --, --, 
   {{0x395de171,0x7c39e172,0x6e3dadeb,0xdb018d78}},	//   gaus_, _fuur, _iurb, _malè, 
   {{0x7c38331f,0x6e3c05f5,0x614000dd,0xdb000100}},	//   _guur, _hurb, _háló, _lalè, 
   {{0x31600369,0x4439e173,0x0ab40736,0x00000000}},	//   haiz_, _ruq_, _وحاد, --, 
   {{0x4439e174,0x395de175,0x4430025c,0x7c380196}},	//   _suq_, baus_, _rix_, _zuur, 
   {{0x6e3de176,0x395de177,0x7c39e178,0x44308089}},	//   _murb, caus_, _yuur, _six_, 
   {{0x4431e179,0x6e3c005a,0x44381fc6,0x7c380067}},	//   _pix_, _lurb, _quq_, _xuur, 
   {{0xdb01e17a,0x6e3c115d,0x00000000,0x00000000}},	//   _balè, _ourb, --, --, 
   {{0x44300483,0x6e3de17b,0xdb01b845,0x3160020b}},	//   _vix_, _nurb, _calè, faiz_, 
   {{0xdb018457,0x4439e17c,0x41e40024,0x3d18000d}},	//   _dalè, _tuq_, ціга, _बरले_, 
   {{0x24a0044e,0xdb0002d3,0x443091f3,0x44380113}},	// [36350] ሃደራት_, _palë, _tix_, _uuq_, 
   {{0x6e3de17d,0xdb0002e2,0x657c037e,0x7c39e17e}},	//   _burb, _falè, lgsh, _ruur, 
   {{0x7c39e17f,0xdb01e180,0x6e3de181,0x31600007}},	//   _suur, _galè, _curb, baiz_, 
   {{0x63a5e182,0x7c38a717,0x628400f1,0x31600007}},	//   _hahn, _puur, _iqho, caiz_, 
   {{0x63a5adb4,0x2138009a,0x7c3931eb,0x395de183}},	//   _kahn, _igsh_, _quur, vaus_, 
   {{0x6e3de184,0x7c380e29,0x63a496c2,0xdb00294d}},	//   _furb, _vuur, _jahn, _halé, 
   {{0x6e3de185,0x63a5e186,0xdb003386,0x395de187}},	//   _gurb, _mahn, _kalé, taus_, 
   {{0x63a4145e,0x7c39e188,0xceb000d9,0x00000000}},	//   _lahn, _tuur, _איל_, --, 
   {{0xdb0082a1,0x6e3c4f61,0x63a402d0,0x57e801b9}},	//   _malé, _zurb, _oahn, йдим_, 
   {{0x395ca8ca,0x62840921,0xdb01e189,0x6e3c0076}},	//   saus_, _oqho, _lalé, _yurb, 
   {{0x395de18a,0x31600007,0x068001c0,0x6be400ae}},	//   paus_, yaiz_, нгэн, _تكلم, 
   {{0x63a401c7,0xdb0000bc,0x248000b0,0x657c03b2}},	//   _aahn, _nalé, kōmā_, ggsh, 
   {{0x63a5e18b,0x628401b3,0xdb01e18c,0x00000000}},	//   _bahn, _aqho, _salè, --, 
   {{0x63a5e18d,0xdb01e18e,0x62840798,0x00000000}},	//   _cahn, _palè, _bqho, --, 
   {{0xdb002cc3,0x63a40548,0x8c180375,0x29d801e7}},	//   _balé, _dahn, מושי, _méan_, 
   {{0xdb01e18f,0x056000a7,0x6e3c0978,0x29d800ae}},	//   _valè, _звън, _rurb, _léan_, 
   {{0x63a4145e,0x62842d2f,0xdb0187a0,0xdce800f3}},	// [36360] _fahn, _eqho, _dalé, _oceđ, 
   {{0x6e3de190,0x63a4006a,0xdb01e191,0x29d80332}},	//   _purb, _gahn, _talè, _néan_, 
   {{0x6e3de192,0xdb01e193,0x4338008d,0x316000d8}},	//   _qurb, _falé, _לעיב, paiz_, 
   {{0xdb0056b1,0x63a5cba3,0x8d2800c2,0xd7f0004d}},	//   _galé, _zahn, боев_, hĩ_, 
   {{0xc170025f,0x63a5e194,0x2d8000e2,0x00000000}},	//   _אחר_, _yahn, ļie_, --, 
   {{0x6e3de195,0xdb2404d3,0xdb000118,0x00000000}},	//   _turb, ژووی, _zalé, --, 
   {{0x29d80491,0x657c017a,0xc76400d1,0x00000000}},	//   _déan_, ygsh, ۋادى, --, 
   {{0xdb000de2,0x60a4001f,0x6b980205,0x00000000}},	//   _xalé, ፈልጉት_, sevg, --, 
   {{0xfce04132,0xcb680b3b,0x00000000,0x00000000}},	//   _зото, _газе_, --, --, 
   {{0x3b81e196,0xaa900022,0xab2800d1,0x9e7000db}},	//   _плуг, _аҳкә, _ғоҗа_, _سۇۇت, 
   {{0x63a5e197,0xca74010b,0x00000000,0x00000000}},	//   _rahn, _хузы, --, --, 
   {{0x63a5e198,0x2618003e,0x38c800f2,0x7ab8011a}},	//   _sahn, méok_, _گامی_, _לצבו, 
   {{0x63a589c7,0x2618003e,0x657c01e3,0xe6180137}},	//   _pahn, léok_, rgsh, йдү_, 
   {{0xdb01e199,0x38c811fc,0x42452090,0xa294109a}},	//   _salé, _دامی_, зхаб, магі, 
   {{0xdb01a01b,0x63a400dc,0x61e00023,0xf770011a}},	//   _palé, _vahn, ëllo, _טקס_, 
   {{0x63a5e19a,0x12e80150,0x00000000,0x00000000}},	//   _wahn, _ﺎﺒﻌﻭ, --, --, 
   {{0x63a5e19b,0xdb01e19c,0x656c2127,0x00000000}},	// [36370] _tahn, _valé, _idah, --, 
   {{0x644de19d,0x71241c5c,0xdb000098,0x7dd02791}},	//   _itai, رىلم, _walé, _içsi, 
   {{0xdb007dec,0x6285e19e,0x00000000,0x00000000}},	//   _talé, _uqho, --, --, 
   {{0x656c0327,0x29d83226,0x1ca40133,0xac8c0023}},	//   _jdah, _séan_, وێزی_, _ሓይሎም_, 
   {{0x656c01c8,0x644c0036,0x29d83012,0x69c06236}},	//   _mdah, _jtai, _péan_, वानी, 
   {{0x644c17fa,0xb6040024,0xdbf00118,0xc8f400fe}},	//   _mtai, ėšik, příl, _চৰ্ত_, 
   {{0xcbc4004b,0x6e940107,0x60c800d8,0x1a283da1}},	//   بېلو_, _пиру, _àemb, ожки_, 
   {{0x656d4861,0x644de19f,0x32dc011a,0x00000000}},	//   _ndah, _otai, מחונ, --, 
   {{0x644de1a0,0xd7740691,0xfc7000ec,0xac941954}},	//   _ntai, وادع, _سپاھ, _መልሶም_, 
   {{0x656de1a1,0x6604010f,0x00000000,0x00000000}},	//   _adah, _ĉika, --, --, 
   {{0x644de1a2,0xf9b0013e,0x00000000,0x00000000}},	//   _atai, _пажӯ, --, --, 
   {{0xb8f0015b,0x98f40166,0x00000000,0x00000000}},	//   _হই_, _оялч, --, --, 
   {{0x656c031c,0x799801f7,0x45d002d5,0xe5840131}},	//   _ddah, meuw, тоўс, _ﻫﯚﻛﯜ, 
   {{0x644c00c6,0x79980438,0xc0b80092,0x00000000}},	//   _dtai, leuw, _ሲሰራ_, --, 
   {{0x644de1a3,0xd25005d9,0x43402b2e,0x00000000}},	//   _etai, ئنر_, тесв, --, 
   {{0x644c01c3,0x29d800ae,0xbaac03d4,0xd010006c}},	//   _ftai, _néal_, _কথাছ, چلر_, 
   {{0xdce80135,0xd0100517,0x82dc0327,0x92ac00fe}},	// [36380] _ddeċ, نلر_, ོནཔའ, কহে_, 
   {{0x79990f45,0xee7c0023,0x00000000,0x00000000}},	//   heuw, _ብቐረባ_, --, --, 
   {{0x29d80597,0x0d8400c9,0x69c005c0,0x79980098}},	//   _béal_, длен, वामी, keuw, 
   {{0xc0b80092,0x00000000,0x00000000,0x00000000}},	//   _ሲሰሩ_, --, --, --, 
   {{0x4478008f,0x7998015d,0xdb4c02f2,0x00000000}},	//   ַנקע, deuw, ڵێن_, --, 
   {{0x63a80198,0x9cb000db,0xf064030d,0x00000000}},	//   ɓens, دۅكت, ăкĕп, --, 
   {{0xebc4052f,0x29d80165,0xfe4002a9,0xbea00124}},	//   _үҙен, _féal_, _ансо, _иарк, 
   {{0xd90c03e6,0xdde848cd,0x00000000,0x00000000}},	//   ڕین_, _فرقه_, --, --, 
   {{0x47e002f5,0x390401c4,0x00000000,0x00000000}},	//   _পদবী, дээн_, --, --, 
   {{0x6d4401a2,0x29190eb3,0xd90cb167,0x644c0332}},	//   žiad, āra_, حیه_, _rtai, 
   {{0x644de1a4,0x656c020b,0x2578022e,0x79980098}},	//   _stai, _pdah, _bоlа_, beuw, 
   {{0xa2cc0882,0x7998003e,0x00000000,0x00000000}},	//   सहस्, ceuw, --, --, 
   {{0x443c07ae,0x656c0010,0xf48400c0,0xe8940024}},	//   êu_, _vdah, курн, _чаль, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa19402bf,0xf4356fe6,0x7d140213,0x00000000}},	//   навч, терэ, əxsu, --, 
   {{0x656c811c,0x644c498d,0x00000000,0x00000000}},	//   _udah, _ttai, --, --, 
   {{0x644de1a5,0x29d887ef,0xdcf800b0,0xdea00101}},	// [36390] _utai, _réal_, rewī, گیزی, 
   {{0x25a822b0,0x2d840839,0x69c047b8,0x00000000}},	//   _haal_, _acme_, वाडी, --, 
   {{0x25a9e1a6,0xd3540375,0xaca4063f,0x9db89d86}},	//   _kaal_, _איתי_, bsịt, зылу_, 
   {{0x25a8198f,0xc05802bf,0x41d01fbc,0x2d580276}},	//   _jaal_, _міг_, _सविस, диць_, 
   {{0x25a9e1a7,0x5c1407e6,0x00000000,0x00000000}},	//   _maal_, ньку, --, --, 
   {{0x25a81bce,0x1be80108,0x00000000,0x00000000}},	//   _laal_, ядли_, --, --, 
   {{0x450404c5,0x2d840076,0x7998044a,0x41d061f2}},	//   োধিক_, _fcme_, teuw, _सवास, 
   {{0x25a81bce,0x22400254,0x59840dab,0x00000000}},	//   _naal_, _muhk_, хлиб, --, 
   {{0xfd103ded,0x7999e1a8,0x69a40032,0xbf1c0073}},	//   _شجر_, reuw, тлыҡ, _भरुन_, 
   {{0xeb901f84,0x22400194,0x9f4400a2,0xdb0001ef}},	//   _نظم_, _ouhk_, _ölä_, _halí, 
   {{0x25a9e1a9,0xa3e80254,0xdb00765a,0x22400254}},	//   _baal_, _मगज_, _kalí, _nuhk_, 
   {{0xa95400d6,0x25a88200,0x69c00b4e,0x00000000}},	//   _акці, _caal_, वाणी, --, 
   {{0x25a83d27,0xd3c41df2,0xdb01e1aa,0xdce80118}},	//   _daal_, ىتسى, _malí, _odeč, 
   {{0xc7a00e26,0xdb001709,0x8afc0198,0xbf1c0490}},	//   _бишк, _lalí, laƙa, _भरून_, 
   {{0x25a9e1ab,0xcb1000c8,0xc0e001b9,0x00000000}},	//   _faal_, ָלן_, ҳотк, --, 
   {{0x25a9e1ac,0xdb000c5e,0x00000000,0x00000000}},	//   _gaal_, _nalí, --, --, 
   {{0x69c00574,0xc0e03594,0xc9500375,0xd0240395}},	// [363a0] वाती, готк, טמן_, емай, 
   {{0x75258e39,0x25a80196,0xc14405f5,0x8afc03f9}},	//   _iziz, _zaal_, _үзэж_, haƙa, 
   {{0xdb000232,0x25a801d9,0x00000000,0x00000000}},	//   _balí, _yaal_, --, --, 
   {{0xdb000077,0xa3000046,0x25a80014,0x91e4013e}},	//   _calí, _түсе, _xaal_, _чоме, 
   {{0x8afc03f9,0xc91c00c5,0x708400c7,0x32001eca}},	//   daƙa, _परेम_, _шҳаз, mniy_, 
   {{0x3d2804d3,0x8aa5e1ad,0x752401c8,0xab940212}},	//   ستنی_, ерид, _mziz, тикі, 
   {{0xbb440046,0xca300150,0x00000000,0x00000000}},	//   رلين_, _ﺭﯞﺡ_, --, --, 
   {{0xdb01e1ae,0xf1e006ab,0x69c02cbb,0x7525e1af}},	//   _galí, नसिन, वाधी, _oziz, 
   {{0x75249390,0x25a8039a,0x3200011f,0x6fc41fc4}},	//   _nziz, _raal_, iniy_, रापू, 
   {{0x25a9e1b0,0xdb01e1b1,0x00000000,0x00000000}},	//   _saal_, _zalí, --, --, 
   {{0x25a9e1b2,0x7525af2a,0x69c0227c,0x7b8442c6}},	//   _paal_, _aziz, वादी, _سالە, 
   {{0x48e40c56,0x32008e4e,0xdb000139,0x00000000}},	//   _поев, jniy_, _xalí, --, 
   {{0x99e80d28,0x25a9e1b3,0x7870aaab,0x0a24001f}},	//   _تعلق_, _vaal_, _مُنا, ሽከርካ, 
   {{0xf8b005e1,0x25a9e1b4,0x7524004c,0x4668010b}},	//   _תשס_, _waal_, _dziz, _ерим_, 
   {{0x25a9c129,0x75240928,0xdce80fb7,0x18281bf3}},	//   _taal_, _eziz, _rdeč, _تقوی_, 
   {{0x3201e1b5,0x0584013d,0x00000000,0x00000000}},	//   gniy_, _чукм, --, --, 
   {{0xd4c034b1,0x248806af,0x2c2000dc,0xf49401b9}},	// [363b0] _көрк, _uqam_, यतां_, _یشید, 
   {{0x661c3402,0xdb0009d7,0x29d80438,0x32000548}},	//   llsk, _salí, _béak_, aniy_, 
   {{0x8afc02a8,0x63ac005f,0xdb001155,0x661c017a}},	//   yaƙa, ļinā, _palí, olsk, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb005e45,0xc0b400d1,0x5ca400db,0x48e00154}},	//   _valí, _яғач_, тилб, মপুর, 
   {{0x8afc03f9,0x661de1b6,0xe9d80419,0x00000000}},	//   waƙa, hlsk, _stĺp_, --, 
   {{0x981404d3,0xdb01e1b7,0x2ca00327,0x00000000}},	//   ێبخا, _salâ, ħida_, --, 
   {{0xdd9402dd,0x661c005c,0x00000000,0x00000000}},	//   _шабы, jlsk, --, --, 
   {{0xdb0006ed,0x17683955,0x6d4401f1,0xcc840133}},	//   _balã, үрүп_, žiac, _لۆنه_, 
   {{0xdb0006ed,0x29d80098,0x676c0023,0x1be400af}},	//   _calã, _léah_, _ሰበይቱ_, _कतिल_, 
   {{0x200002c4,0x3200cd93,0x9f500200,0x7d1806be}},	//   inhi_, yniy_, _amzë_, _hyus, 
   {{0x7d1831fe,0xdd980100,0xdb0006d9,0x661cd608}},	//   _kyus, _akňz_, _ialà, glsk, 
   {{0xdb000109,0xd9780184,0x7d18037e,0xb4cc00ab}},	//   _halà, _ерҙә_, _jyus, लहे_, 
   {{0x661c08c8,0x387de1b8,0xdb000798,0x3200a24e}},	//   alsk, muur_, _galã, wniy_, 
   {{0x7c2c04cc,0x7d181180,0x387ce2cd,0x59c4043e}},	//   _ècru, _lyus, luur_, वापर, 
   {{0xdb0056ed,0x00000000,0x00000000,0x00000000}},	//   _malà, --, --, --, 
   {{0x76403fdc,0x7d19e1b9,0xdb000851,0x7525e1ba}},	// [363c0] _huny, _nyus, _lalà, _uziz, 
   {{0x7641e1bb,0x3fe1e1bc,0xdbe400e8,0x32003cf6}},	//   _kuny, ажув, _dëël, sniy_, 
   {{0x7d19e1bd,0x387de1be,0xfe40b32d,0xdb0005da}},	//   _ayus, huur_, анхо, _nalà, 
   {{0x76407752,0xf765e1bf,0x7760014b,0x7d19e1c0}},	//   _muny, _ھا_, _lenx, _byus, 
   {{0x7dc10ef4,0xf764a638,0x69c00316,0x7d19e1c1}},	//   شقون, _پا_, वासी, _cyus, 
   {{0xfbcc3ee0,0x387de1c2,0x7d1803f0,0xdb01e1c3}},	//   قتى_, duur_, _dyus, _balà, 
   {{0xdb0026b7,0x7ac00801,0x76413ce4,0x203001ed}},	//   _calà, исъе, _nuny, _اہلس, 
   {{0xdb01e1c4,0x387de1c5,0x00000000,0x00000000}},	//   _dalà, fuur_, --, --, 
   {{0x6d41e1c6,0x387c2a28,0x7761e1c7,0x76400810}},	//   _igma, guur_, _benx, _auny, 
   {{0x69c00b6d,0xbb8000db,0x00000000,0x00000000}},	//   वाही, _ەلەي, --, --, 
   {{0x66f40c98,0xdce8005f,0x37a40228,0x764000cf}},	//   упну, _ideā, ттын_, _cuny, 
   {{0x7641e1c8,0x387dc731,0x6f1c062c,0x22b0033f}},	//   _duny, buur_, _myrc, _rąk_, 
   {{0x661c049f,0x7641e1c9,0xdb0000d8,0x387c1b9d}},	//   rlsk, _euny, _talã, cuur_, 
   {{0xdb003fb1,0x7760009a,0x7641e1ca,0x29d80098}},	//   _halá, _genx, _funy, _séah_, 
   {{0x6d4032a9,0x764120dc,0xdb0026f6,0xa5f800f3}},	//   _ogma, _guny, _kalá, _пеку_, 
   {{0x29180365,0x6d400280,0xd6d802bf,0x3208010b}},	//   ğraf_, _ngma, _яті_, вхун_, 
   {{0xdb01e1cb,0x77600b6f,0x7640c553,0x5f95e1cc}},	// [363d0] _malá, _yenx, _zuny, лиат, 
   {{0x7d1804ce,0x6d402711,0x77605133,0x764004ce}},	//   _ryus, _agma, _xenx, _yuny, 
   {{0x6d400a2e,0xf77025f9,0x387c0d27,0x7d19e1cd}},	//   _bgma, שקע_, zuur_, _syus, 
   {{0x20000223,0x6f1c03cb,0xa1140345,0x387c0009}},	//   snhi_, _dyrc, _موجت, yuur_, 
   {{0x6aa845a7,0xdb00004e,0x1bd40212,0x26180c6a}},	//   _asdf, _salà, лодя, léos_, 
   {{0x387c0926,0x6d41e1ce,0x6f1c007c,0x7e7400db}},	//   vuur_, _egma, _fyrc, _لارئ, 
   {{0xab84050b,0xdb01e1cf,0x3da40022,0x6f1c03cb}},	//   ручк, _balá, _ираб, _gyrc, 
   {{0x387de1d0,0x7641e1d1,0xdb000ba1,0x00000000}},	//   tuur_, _runy, _valà, --, 
   {{0xdb01e1d2,0x7641a545,0x7d1807d6,0x77600200}},	//   _dalá, _suny, _uyus, _penx, 
   {{0x764027ed,0x387dc731,0xdb000332,0x00000000}},	//   _puny, ruur_, _ealá, --, 
   {{0x6d40030d,0x6fc40490,0x76400067,0x69c001ad}},	//   _ygma, रातू, _quny, वाशी, 
   {{0x26182047,0x764018f7,0xdb012a61,0x387c0254}},	//   déos_, _vuny, _galá, puur_, 
   {{0x764046a6,0x69c01af8,0x77600240,0xd4f40137}},	//   _wuny, वारी, _tenx, уяны, 
   {{0x7640d3e5,0x0440e918,0xd90c0244,0xb4c40d2e}},	//   _tuny, серн, _ویژ_, _एपी_, 
   {{0x91e43dc8,0x76400083,0xfbd81bd6,0x5164004e}},	//   гове, _uuny, _भवनम, лүнү_, 
   {{0xcfa80424,0x00000000,0x00000000,0x00000000}},	//   کارم_, --, --, --, 
   {{0x6f1c0042,0x00000000,0x00000000,0x00000000}},	// [363e0] _syrc, --, --, --, 
   {{0x53a4026a,0x386c01f5,0x26180098,0x00000000}},	//   _саоб, _mvgr_, béos_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc2781a4c,0xa1540801,0x8c440220,0x26180098}},	//   _ארטי, _върш, геде, léor_, 
   {{0x6f1c0142,0x00000000,0x00000000,0x00000000}},	//   _wyrc, --, --, --, 
   {{0xdb01e1d3,0xaca402e3,0x6f1c015d,0x00000000}},	//   _salá, _ntụp, _tyrc, --, 
   {{0xba71e1d4,0xdb000c5e,0x29d80332,0x69c028d4}},	//   مايت, _palá, _méav_, वाली, 
   {{0xaca4063f,0x6d41e1d5,0x394c00cf,0xddc002dd}},	//   _atụp, _ugma, _cfgs_, _мұхи, 
   {{0x3dc0801b,0x274c001f,0xdb0003b2,0xb760009d}},	//   _уйтг, _ነበረበ, _valá, өтэй, 
   {{0xfd640055,0x00000000,0x00000000,0x00000000}},	//   dapṛ, --, --, --, 
   {{0xdb0000f8,0x394c0421,0xe69401c0,0xda64143e}},	//   _talá, _ffgs_, шины, _ناني, 
   {{0xe4e401c0,0x69c00073,0xa5f8026b,0xc1d00b67}},	//   асгү, वाळी, тему_, _सवेग, 
   {{0x349401c6,0x00000000,0x00000000,0x00000000}},	//   баяр, --, --, --, 
   {{0x25ac0316,0xfbc48153,0x49900244,0x00000000}},	//   žel_, लायम, _ئیکر, --, 
   {{0x7528033f,0x81740107,0x05040154,0x00000000}},	//   ędza, лавӣ_, োধের_, --, 
   {{0x96b801f4,0x00000000,0x00000000,0x00000000}},	//   _шучу_, --, --, --, 
   {{0xdb00002f,0x00000000,0x00000000,0x00000000}},	// [363f0] _unlö, --, --, --, 
   {{0x1e0c0034,0x6190001f,0x6ac4012d,0xd2f47771}},	//   िक्ष_, ኅበራዊ_, _वपूर, اکیا_, 
   {{0xa195e1d6,0x9ac41418,0x2258023a,0xb5c804fb}},	//   _канч, _kiŋŋ, _шины_, _شویم_, 
   {{0xdd95e1d7,0x6d440006,0x6b9c0205,0xd9a40150}},	//   рады, žian, _ırga, _ﻋﻤﺎﺩ_, 
   {{0xdb0005d1,0x25fc00af,0x61e0036e,0x68e40135}},	//   _kalç, _लगनी_, ëllu, _żidn, 
   {{0x9ac404ba,0x00000000,0x00000000,0x00000000}},	//   _liŋŋ, --, --, --, 
   {{0xc0e8001f,0x1ae4c133,0xdb000139,0x9e340120}},	//   _መርሀ_, ройм, _malç, _вевч, 
   {{0x7e60045f,0xec2800db,0x00000000,0x00000000}},	//   ânpu, _ەككى_, --, --, 
   {{0x49c405f5,0x9c39e1d8,0x7c840f5c,0xac74007b}},	//   рлын_, _апат_, _љубе, _هالش, 
   {{0x2cb8193a,0xdb000166,0x00000000,0x00000000}},	//   _حافظ_, _nalç, --, --, 
   {{0xdb0012ed,0x00000000,0x00000000,0x00000000}},	//   _salæ, --, --, --, 
   {{0x19582ecc,0xdb01e1d9,0xd1bc0023,0x6abc02d2}},	//   _рады_, _palæ, ዱታት_, _árfa, 
   {{0xdb01e1da,0x2618003e,0x94240108,0x9878010f}},	//   _balç, téor_, имме, _סאַט, 
   {{0xdb01e1db,0x96b8009b,0x00000000,0x00000000}},	//   _calç, _аћиф_, --, --, 
   {{0x6efc0158,0x9575e1dc,0xb65001c8,0x00000000}},	//   _måbø, _кыпч, _اعتڪ, --, 
   {{0x56940184,0x00000000,0x00000000,0x00000000}},	//   _баҫт, --, --, --, 
  
   {{0x50b47b00,0x90c457aa,0xdb008af3,0x798802d0}},	// [36400] јсбу, шбае, _halä, _mcgw, 
   {{0x78a80175,0x04d808a8,0xdb00008e,0xbfc001f4}},	//   _msgv, _סקיל, _kalä, обук, 
   {{0x37e40f22,0x798802d0,0x77440092,0x00000000}},	//   _পদার, _ocgw, _ከአስተ, --, 
   {{0xdb00014a,0x0694008f,0x61e094f5,0x8234187c}},	//   _malä, ידעם_, ëllt, _پرپا, 
   {{0xac981eeb,0xdb002573,0xfa900092,0x00000000}},	//   انتا_, _yalç, _መሞከር_, --, 
   {{0xdb0000ac,0x3ea8023a,0x0ca402e5,0xb18802f0}},	//   _xalç, äitä_, _गनीम, _feťá, 
   {{0x046000e4,0x00000000,0x00000000,0x00000000}},	//   ãhẽv, --, --, --, 
   {{0x27e003a2,0xc0e8001f,0x6fc401f9,0x00000000}},	//   _œin_, _መርህ_, रावू, --, 
   {{0xc7c5e1dd,0xfce00323,0x88b007d6,0x00000000}},	//   асни, _дото, تیشچ, --, 
   {{0xdb00014a,0x0ba9e1de,0x5fc81af8,0x7b8400db}},	//   _balä, _جارى_, रायल, _پاكە, 
   {{0x09e43bb3,0x29d80ba1,0x5100000d,0x77940276}},	//   _кожн, _béat_, लपुआ_, шкэр_, 
   {{0xdb00ce28,0xf33c0092,0x00000000,0x00000000}},	//   _salç, ናንትና, --, --, 
   {{0xdb01e1df,0x5fc80a97,0x00000000,0x00000000}},	//   _palç, रामल, --, --, 
   {{0x83840150,0x00000000,0x00000000,0x00000000}},	//   шыме, --, --, --, 
   {{0xdb01e1e0,0xb82400db,0xa3d401f0,0xe2340092}},	//   _galä, _ئبنۇ, _ғонч, _በሥርዓ, 
   {{0x31c400d6,0x046400d8,0x00000000,0x00000000}},	//   осув, _ктом, --, --, 
   {{0xceb4052f,0xdb0166d8,0x40740116,0x00000000}},	// [36410] ҙәр_, _zalä, شلاڭ_, --, 
   {{0xd24c0244,0xdb00013d,0x00000000,0x00000000}},	//   بچی_, _yalä, --, --, 
   {{0x4420110c,0x98bc025c,0x61e00036,0xdb00008e}},	//   mlj_, _mewġ_, ëlls, _xalä, 
   {{0x442001a8,0x00000000,0x00000000,0x00000000}},	//   llj_, --, --, --, 
   {{0x09a83ae9,0xf3f004fb,0x6fc401ad,0xe1340276}},	//   _བལྟ_, _رأی_, राशू, _ынмы, 
   {{0x79880332,0x00000000,0x00000000,0x00000000}},	//   _scgw, --, --, --, 
   {{0x6fc4166d,0x798802d0,0xb4c4012d,0x48c00022}},	//   रारू, _pcgw, _एप्_, ҟәца, 
   {{0x7c6496d3,0x19c401d5,0x2cac01f4,0x00000000}},	//   _نائل, сбим, ähdä_, --, 
   {{0x5ef800bd,0x5c7400c7,0xdb000139,0x00000000}},	//   _অডিও_, _ылат, _salä, --, 
   {{0xdb0171e9,0x59c40316,0x29d800d5,0x798802d0}},	//   _palä, वाहर, _béas_, _wcgw, 
   {{0x6c3001d3,0xdb00013d,0x00000000,0x00000000}},	//   _تہوا, _qalä, --, --, 
   {{0xdb0007c5,0xeab1a239,0x8af8008f,0x5a340063}},	//   _valä, _زعم_, _גלעז, _унет, 
   {{0x7528033f,0xfbd800cd,0x00000000,0x00000000}},	//   ędzo, _भवाम, --, --, 
   {{0xdb000724,0x59c40a59,0x00000000,0x00000000}},	//   _talä, वावर, --, --, 
   {{0xd19800fd,0xaab00118,0x00000000,0x00000000}},	//   лтач_, झिएक, --, --, 
   {{0x68ec0c40,0x395de1e1,0x11d800c6,0x98bc0327}},	//   _öldü, nbus_, دورة_, _zewġ_, 
   {{0x395de1e2,0x25fc0034,0x94741291,0x44200427}},	// [36420] ibus_, _लगती_, _ادبا, blj_, 
   {{0x442000f3,0x395c2994,0x3d08012d,0x00000000}},	//   clj_, hbus_, ़पने_, --, 
   {{0x6d4402d5,0x387dddfc,0x29d801e7,0x00000000}},	//   žiam, hrur_, _méar_, --, 
   {{0x09b4033f,0x29d80332,0xa18401ec,0xc33000d9}},	//   _अफेय, _léar_, _мұса_, _מות_, 
   {{0x3160009f,0x41941fae,0x50b5e1e3,0xa07401af}},	//   mbiz_, _اشپز, _усну, _мырш, 
   {{0x62802cd7,0x395de1e4,0x0e6843b9,0x387c004e}},	//   álog, ebus_, _مصري_, drur_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6280098d,0x2fd4003d,0x8afc0198,0x8d9401d9}},	//   šlog, żagħ_, naƙi, _دٔرت, 
   {{0x8b95e1e5,0x29d9e1e6,0xa2840023,0x9a840092}},	//   _греч, _béar_, _ዝውንን_, ነተኛው_, 
   {{0x6abc01d3,0x29d800ae,0x27f800a3,0x00000000}},	//   _árfo, _péas_, òrn_, --, 
   {{0x395c01b9,0x5fc80490,0x29d800ae,0x44200010}},	//   bbus_, रातल, _déar_, vlj_, 
   {{0x387c2b10,0x395c037e,0x00000000,0x00000000}},	//   brur_, cbus_, --, --, 
   {{0xba15e1e7,0xdb00050a,0x29d800ae,0x29000254}},	//   _اينا_, _valå, _féar_, _äia_, 
   {{0xf64c3c73,0x29d8007b,0x00000000,0x00000000}},	//   بئی_, _géar_, --, --, 
   {{0x3f9c00c8,0x29140014,0x7bd80a7c,0xb794011a}},	//   _ĝuu_, _دہکھ_, נקלו, _הכוח_, 
   {{0x3ebc6b48,0x00000000,0x00000000,0x00000000}},	//   _čut_, --, --, --, 
   {{0x660c0022,0xb9dc02d3,0x00000000,0x00000000}},	// [36430] _ijak, _እዮ_, --, --, 
   {{0x645de1e8,0x9f44046c,0x6e4c0023,0x1f741cd0}},	//   mpsi, _ölü_, _ብኣጋጣ, ілея, 
   {{0x660c0579,0x3160004e,0xfbc423c1,0x395de1e9}},	//   _kjak, bbiz_, लासम, ybus_, 
   {{0x660c0083,0x9c5808e1,0x387d5c28,0x00000000}},	//   _jjak, ашку_, yrur_, --, 
   {{0x61ede1ea,0x629401c0,0x1c3800ee,0x660de1eb}},	//   mhal, ltzo, азды_, _mjak, 
   {{0x50a004a9,0x3ee5e1ec,0x660c05be,0x63b402b9}},	//   _تەكل, _любв, _ljak, ndzn, 
   {{0xdce80640,0x6295e1ed,0x1a641550,0x660de1ee}},	//   _odeć, ntzo, زیشی_, _ojak, 
   {{0x61ede1ef,0x395c409c,0x660de1f0,0xa2840023}},	//   nhal, ubus_, _njak, _ዝውነን_, 
   {{0x395de1f1,0x57e9e1f2,0x60cc1b08,0x61ec0069}},	//   rbus_, идим_, nxam, ihal, 
   {{0x660de1f3,0x61ede1f4,0x395d6cff,0x387d2eea}},	//   _ajak, hhal, sbus_, rrur_, 
   {{0x61ed0226,0x645c0369,0x395c0421,0x8afc03f9}},	//   khal, epsi, pbus_, yaƙi, 
   {{0x67e40100,0x62940158,0x60cc009a,0x61ec01d3}},	//   _fòjo, dtzo, kxam, jhal, 
   {{0x61ede1f5,0x660de1f6,0x18684132,0x31600175}},	//   dhal, _djak, _тали_, vbiz_, 
   {{0x3160ef54,0x8afc0198,0x61ede1f7,0xe854010a}},	//   wbiz_, waƙi, ehal, _хĕрн, 
   {{0x61ede1f8,0x1cb80003,0x8afc02a8,0x60cc04cc}},	//   fhal, _མནའ_, taƙi, exam, 
   {{0x61ede1f9,0x660c044e,0xdb0000ae,0x316001bf}},	//   ghal, _gjak, _balú, ubiz_, 
   {{0xdb0017cd,0x6d440030,0x60cc676c,0x316001c6}},	// [36440] _calú, žiak, gxam, rbiz_, 
   {{0x7525e1fa,0x290000d0,0x61ecb27b,0xd9400023}},	//   _iyiz, _žiak_, ahal, _ኣጠቓቕ, 
   {{0x61ec2747,0x7e640211,0xb8d80135,0x4d480261}},	//   bhal, _cwjp, _ཆན_, апен_, 
   {{0x75240100,0x7644037e,0x9e65e1fb,0xd1b80131}},	//   _kyiz, _jiiy, سامن, _ئادا_, 
   {{0x764400b5,0x93fc0490,0x32000429,0xdb0001e7}},	//   _miiy, _उगाच_, miiy_, _galú, 
   {{0x7524e19c,0x32000429,0x00000000,0x00000000}},	//   _myiz, liiy_, --, --, 
   {{0xc0e80020,0xff04014b,0x47b000eb,0x00000000}},	//   _መርሐ_, _дерк_, জামী, --, 
   {{0x752449cf,0xfa30088c,0x2fd93c2d,0x7644037e}},	//   _oyiz, وريد, _horg_, _niiy, 
   {{0x1cb80003,0x7525592f,0xc76400d1,0x00000000}},	//   _མནར_, _nyiz, يادى, --, 
   {{0x61ede1fc,0x660c168c,0x32000548,0x3b81bf6e}},	//   zhal, _sjak, hiiy_, _олуг, 
   {{0x75240912,0x32000429,0x76440009,0x61ec34bc}},	//   _ayiz, kiiy_, _biiy, yhal, 
   {{0x61ede1fd,0x2fd83c5d,0x752401aa,0x76440198}},	//   xhal, _lorg_, _byiz, _ciiy, 
   {{0x61edd19e,0x75240796,0x3200036b,0x7645e1fe}},	//   vhal, _cyiz, diiy_, _diiy, 
   {{0x645de1ff,0x68ec050e,0x2fd801f5,0x1cb8031c}},	//   rpsi, ıldı, _norg_, _མནལ_, 
   {{0x63b40029,0x75240107,0xdb01e200,0x660de201}},	//   rdzn, _eyiz, _balù, _tjak, 
   {{0x660de202,0x62944bfa,0x60cc01c6,0xdb0000d7}},	//   _ujak, rtzo, txam, _palú, 
   {{0x2fd97a67,0xdb0005d5,0x661d748e,0x629401f5}},	// [36450] _borg_, _dalù, mosk, stzo, 
   {{0x61ede203,0x656c18a6,0x644c0093,0x6e200810}},	//   shal, _heah, _iuai, _akmb, 
   {{0x61ede204,0x656c67f1,0x64440280,0x320100ae}},	//   phal, _keah, _iihi, biiy_, 
   {{0x6445e205,0x661de206,0x644de207,0x60cc0227}},	//   _hihi, nosk, _kuai, pxam, 
   {{0x6445e208,0xe7bc0a28,0x656c01e0,0x2fd80455}},	//   _kihi, ्ञाप, _meah, _forg_, 
   {{0x644d5a4f,0x656de209,0x2fd880e3,0x6444014f}},	//   _muai, _leah, _gorg_, _jihi, 
   {{0x6445e20a,0x644de20b,0x2001e20c,0x661de20d}},	//   _mihi, _luai, mihi_, kosk, 
   {{0x2fd80936,0x6445e20e,0x5fc83b29,0x644ca526}},	//   _zorg_, _lihi, रावल, _ouai, 
   {{0x644c3c60,0x644404ba,0x69c00490,0xfc304336}},	//   _nuai, _oihi, वाजी, _قحط_, 
   {{0x6445e20f,0x76440a81,0x200006e4,0x75248aa7}},	//   _nihi, _siiy, nihi_, _ryiz, 
   {{0x644c0b23,0x656c0109,0x661c01c4,0x59f80276}},	//   _auai, _beah, fosk, _лежя_, 
   {{0x6445e210,0x644c35b8,0x656c0311,0xd1e0001f}},	//   _aihi, _buai, _ceah, ነበት_, 
   {{0x644c7e9f,0x2001e211,0x7a100276,0x79980564}},	//   _cuai, kihi_, găte, mfuw, 
   {{0x644de212,0x75241446,0x64440098,0x61fc1538}},	//   _duai, _vyiz, _cihi, _amsl, 
   {{0x6444eb2a,0x644c01ab,0xc79405d9,0x3200011f}},	//   _dihi, _euai, _رپيا_, tiiy_, 
   {{0x644de213,0x2fd9e214,0x6d440024,0x644401bf}},	//   _fuai, _sorg_, žiai, _eihi, 
   {{0x644de215,0x6445e216,0x752437ea,0x4f080b8d}},	// [36460] _guai, _fihi, _uyiz, әнен_, 
   {{0x64447bc3,0x61fde217,0x8fd00032,0x3200011f}},	//   _gihi, _emsl, хәмә, siiy_, 
   {{0x644c005a,0x998c627e,0xe8a800bc,0xe1f000f1}},	//   _zuai, zmeš_, _कन्च, رسې_, 
   {{0x6445e218,0xec100241,0x00000000,0x00000000}},	//   _zihi, _ọ̀rú, --, --, 
   {{0x64440a81,0x47b0045e,0x2001e219,0xc1b80375}},	//   _yihi, জাতী, bihi_, _המכש, 
   {{0x64440564,0x661de21a,0xd1b80133,0x00000000}},	//   _xihi, zosk, _ئاگا_, --, 
   {{0xa3cc0574,0x25fc00c5,0x3ea15f68,0x00000000}},	//   ळात_, _लगली_, _пирг, --, 
   {{0x2dc8005e,0x00000000,0x00000000,0x00000000}},	//   _باسۋ_, --, --, --, 
   {{0x656c000f,0x78b803b2,0x48a801d5,0x00000000}},	//   _reah, gvuv, ётим_, --, 
   {{0x656de21b,0x644ccb51,0x68e1e21c,0x7b0401ed}},	//   _seah, _ruai, rymd, ártá, 
   {{0x1cb80dd4,0x644de212,0x656de21d,0x661de21e}},	//   _མནོ_, _suai, _peah, tosk, 
   {{0x644c0421,0x200002c4,0xe94407d6,0x00000000}},	//   _puai, zihi_, _قرشی, --, 
   {{0x644c3795,0x6445e21f,0x18b001e0,0x4430a270}},	//   _quai, _pihi, _аҙыр, _phx_, 
   {{0x20000564,0x61fd2936,0x661de220,0x2814315b}},	//   xihi_, _smsl, sosk, _توتس, 
   {{0x656c0084,0x6445e221,0x661cbd39,0x224c01e4}},	//   _teah, _vihi, posk, ĉeko_, 
   {{0x644de222,0x6445e223,0xdb0003cd,0x2001e224}},	//   _tuai, _wihi, _valø, wihi_, 
   {{0x2001e225,0x6445e226,0xc05802bf,0x4431e227}},	// [36470] tihi_, _tihi, сіб_, _thx_, 
   {{0x44240491,0x1b000154,0x00000000,0x00000000}},	//   _ón_, _লুফে_, --, --, 
   {{0x2001e228,0x24980472,0x78b8004c,0x00000000}},	//   rihi_, ltsm_, zvuv, --, 
   {{0x2001b566,0x61fde229,0xc0c80120,0x0dd800f1}},	//   sihi_, _umsl, _луге_, يانګ_, 
   {{0xee3810f5,0x200004fe,0x00000000,0x00000000}},	//   їні_, pihi_, --, --, 
   {{0xda59e22a,0xfbc405d7,0x92c003d4,0x00000000}},	//   ориш_, लाइम, ্নৰ_, --, 
   {{0x7528068f,0xcd500014,0xee840108,0x00000000}},	//   ędzi, رى۪ک, _пыто, --, 
   {{0xceb025f9,0x28a8000d,0xb60801ef,0x78b8000d}},	//   _ביל_, _कनखि, _myší, tvuv, 
   {{0x80dc015b,0xad4400f7,0x00000000,0x00000000}},	//   _নেত্, _كۉمۉ, --, --, 
   {{0xd7080a8f,0xab94009b,0x17f800ae,0x00000000}},	//   жное_, _пауљ, تربة_, --, 
   {{0x7998006f,0x97e80205,0x78b80821,0x00000000}},	//   pfuw, _ığdı, svuv, --, 
   {{0x7ae006a3,0x78b80810,0x00000000,0x00000000}},	//   mynt, pvuv, --, --, 
   {{0x6d442aa9,0x7ae1e22b,0xab04000d,0x00000000}},	//   žiav, lynt, öövä, --, 
   {{0x67d45d0b,0x59c41df0,0xd70401a9,0x00000000}},	//   _почу, वाकर, _озли, --, 
   {{0xd6181eeb,0x00000000,0x00000000,0x00000000}},	//   _وتبا_, --, --, --, 
   {{0x7ae000ad,0x00000000,0x00000000,0x00000000}},	//   iynt, --, --, --, 
   {{0x41243529,0x7ae1e22c,0x00000000,0x00000000}},	// [36480] дото_, hynt, --, --, 
   {{0x7ae00652,0x543401e2,0x52a8003b,0x00000000}},	//   kynt, _تربر, _двом_, --, 
   {{0x0cc40037,0x60c8031c,0x4610150e,0x7ae00108}},	//   लम्म, _ġeme, _سویر, jynt, 
   {{0x700002f5,0x7ae0005b,0xe6b00b98,0x60c800c0}},	//   ্তেও_, dynt, _जनसङ, _šeme, 
   {{0xc1700302,0x7ae0e7a4,0x4638008f,0x09b40154}},	//   _בחר_, eynt, קענע, ঝামা, 
   {{0x92c002a6,0xb114030d,0x00000000,0x00000000}},	//   ্নী_, ăмăш, --, --, 
   {{0x160dc0d6,0x7ae0e73f,0xfbcc352e,0xba71e22d}},	//   ाचार_, gynt, شتو_, نايت, 
   {{0x25b80036,0x00000000,0x00000000,0x00000000}},	//   xdsl_, --, --, --, 
   {{0x25b8011c,0x7ae00076,0x24980175,0x478400db}},	//   vdsl_, aynt, xtsm_, мынб, 
   {{0x7ae003a2,0x0134011a,0xcbc40066,0x00000000}},	//   bynt, ורפת_, _تزري, --, 
   {{0xcb082781,0x7ae1e22e,0x00000000,0x00000000}},	//   _بيان_, cynt, --, --, 
   {{0x6d4402d5,0x19b80276,0xc8c80014,0x8a04013d}},	//   žiau, _нучь_, _ووان_, _юзее, 
   {{0xdb000232,0x38c80344,0x12cc009e,0xd90c00ec}},	//   _malý, _واهی_, রনোদ, _ٿڌي_, 
   {{0x7a10084c,0xf9043047,0x153000c7,0x00000000}},	//   măta, _تأمی, ыҕыр, --, 
   {{0x212c0841,0x3c7400d1,0x00000000,0x00000000}},	//   _šeh_, ﭽﯩﺴﻰ_, --, --, 
   {{0xb60802fb,0xae001fd2,0x00000000,0x00000000}},	//   _vyší, लोमन_, --, --, 
   {{0x60f82ecc,0x7a10084c,0x8cc0433a,0xc34802d5}},	// [36490] чная_, năta, लिफो, _мяне_, 
   {{0x5fc8375c,0x7ae0023a,0xa3d400cf,0xdd300210}},	//   राइल, yynt, _чооч, rężo, 
   {{0x6834068c,0x00000000,0x00000000,0x00000000}},	//   càde, --, --, --, 
   {{0x7ae001f4,0x9d1400db,0x00000000,0x00000000}},	//   vynt, ндеч, --, --, 
   {{0x7ae000a9,0x00000000,0x00000000,0x00000000}},	//   wynt, --, --, --, 
   {{0x81c0009e,0x7ae0382d,0xdb0008a5,0x00000000}},	//   _্তি_, tynt, _valþ, --, 
   {{0xc4c818cc,0x4cbc0154,0xfd50014b,0x00000000}},	//   ामुख, ্নগু, _анбӯ, --, 
   {{0xfe41e22f,0xdb013ce3,0x7ae0b770,0x00000000}},	//   _شکای, _galý, rynt, --, 
   {{0x6dc40228,0x7a100356,0xdb0003e0,0x00000000}},	//   _جۅنۅ, găta, _halü, --, 
   {{0x7ae00652,0xb8d409b4,0xb7bc0154,0x9f58020c}},	//   pynt, _चन_, েস্ট, èyèk_, 
   {{0xd629be89,0x28e80137,0xdb0006be,0xaa94010a}},	//   зоне_, здөп_, _jalü, _аихч, 
   {{0x7a100356,0xdb000205,0xe500000d,0x00000000}},	//   băta, _malü, _लेहि_, --, 
   {{0x89d4168d,0x8cc07039,0x7a10054e,0x18a4e4e9}},	//   _سوور_, लियो, căta, _чалм, 
   {{0xccf0011a,0x00000000,0x00000000,0x00000000}},	//   נכם_, --, --, --, 
   {{0x628000f3,0x5fc8012c,0x12cc0154,0x00000000}},	//   šlon, राईल, রন্দ, --, 
   {{0xc6e401d9,0x8cc0012d,0x00000000,0x00000000}},	//   _ستى۪, लिमो, --, --, 
   {{0xdb01e230,0x04540597,0x4fe801b9,0x92c00eac}},	// [364a0] _kaló, _كلية_, пман_, ্নে_, 
   {{0xdb01e231,0x9008007b,0xd88c02dd,0x00000000}},	//   _jaló, أزرق_, _ﻛﻪﻟﯟ, --, 
   {{0x0d84d29c,0xdb000793,0x0dc8014b,0x5f000022}},	//   елен, _calü, зули_, аҷра, 
   {{0x0d200137,0xc278011a,0x00000000,0x00000000}},	//   гүбү, _צרכי, --, --, 
   {{0x60c8a37d,0xab9400d4,0xc0e0014b,0x00000000}},	//   _àemp, вилі, _бояк, --, 
   {{0x031c0bb2,0xdb01e232,0x00000000,0x00000000}},	//   _मुँह_, _naló, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7e980302,0xdb00020c,0xac8401a9,0x00000000}},	//   _מסלו, _mblè, _аҳдл, --, 
   {{0xdb01b064,0xdde95497,0xccc401e0,0x00000000}},	//   _baló, _غرفه_, _ябай, --, 
   {{0xdb003822,0x7a10054e,0x6d440024,0x00000000}},	//   _caló, răta, žias, --, 
   {{0x031c1533,0xf67005f5,0xb8d001b9,0xc984e274}},	//   _मुंह_, лгээ, نتیش, _зули, 
   {{0x7a100311,0xba8801d3,0x00000000,0x00000000}},	//   păta, _رحمۃ_, --, --, 
   {{0x99740818,0x92c000eb,0x00000000,0x00000000}},	//   _рухш, ্নো_, --, --, 
   {{0xdb000789,0xa68800e5,0x00000000,0x00000000}},	//   _galó, _قصبے_, --, --, 
   {{0xdb00004e,0x6aa803b2,0xb2840830,0xd05406be}},	//   _halò, _jpdf, лытк, myyə, 
   {{0xdb0002e2,0x00000000,0x00000000,0x00000000}},	//   _kalò, --, --, --, 
   {{0xdb01e233,0x00000000,0x00000000,0x00000000}},	// [364b0] _salü, --, --, --, 
   {{0x6fb9e234,0xdb008a9e,0x00000000,0x00000000}},	//   нгур_, _palü, --, --, 
   {{0x44201a4c,0x63a80bb8,0x63a401c3,0xd3540375}},	//   moj_, đend, _ibhn, _ביתי_, 
   {{0x442030fb,0xdb0007de,0xaf3400c6,0x1278008f}},	//   loj_, _valü, اركت, _קארע, 
   {{0x442001a6,0xdb0000a2,0x00000000,0x00000000}},	//   ooj_, _walü, --, --, 
   {{0x4420008f,0x2005e235,0xfe701291,0xbfa8010b}},	//   noj_, _öli_, _مدر_, _этме_, 
   {{0x3da57118,0x00000000,0x00000000,0x00000000}},	//   _праб, --, --, --, 
   {{0x4421e236,0xdb0009c2,0xaac4004b,0x0e0001f0}},	//   hoj_, _saló, اتون, _кӯчо, 
   {{0xdb00642b,0x6d4401f1,0x29000030,0x69a40032}},	//   _calò, žiar, _žiar_, улыҡ, 
   {{0xf094008d,0x3f900051,0x00000000,0x00000000}},	//   אנץ_, ngxu_, --, --, 
   {{0x44201a4c,0xdb0134c2,0x00000000,0x00000000}},	//   doj_, _való, --, --, 
   {{0x3ddc0936,0x7a1000a8,0x63a50b07,0x7c21e237}},	//   _jouw_, măto, _abhn, lonr, 
   {{0x442000c8,0x7a10084c,0xdb004e72,0x3ddc0d27}},	//   foj_, lăto, _galò, _mouw_, 
   {{0x4421e238,0x3ddc614d,0xdb0004e6,0x58040046}},	//   goj_, _louw_, _ablé, _جوتك, 
   {{0x7a10084c,0xddc800d0,0x35c4024c,0x516400db}},	//   năto, _tieň, _байҳ, күнү_, 
   {{0x108804a2,0x54c400c7,0x7c21e239,0x8ca0012d}},	//   _ﺗﻪﺭﯨ, _абиб, honr, _गहलो, 
   {{0x4421e23a,0xda6400b2,0x683401ab,0x65680022}},	// [364c0] boj_, _گڏ_, làda, ñehe, 
   {{0x4421e23b,0x672c0252,0x00000000,0x00000000}},	//   coj_, _óljó, --, --, 
   {{0x3ddc0cf9,0x7c2000df,0x00000000,0x00000000}},	//   _bouw_, donr, --, --, 
   {{0x98b0012c,0x7a100356,0x0c840166,0x00000000}},	//   íběh_, dăto, выкм, --, 
   {{0x3ddc017a,0x7c20072d,0xc0c4022e,0x00000000}},	//   _douw_, fonr, _ишёқ, --, 
   {{0x8aa5e23c,0x67e4007f,0xc0e80240,0x00000000}},	//   врид, _jòjt, _ዘክሩ_, --, 
   {{0x7a10084c,0xdb00068c,0x00000000,0x00000000}},	//   găto, _salò, --, --, 
   {{0x4421e23d,0xa9346feb,0x3ddc77d0,0x726c02d3}},	//   zoj_, лейш, _gouw_, _ጸጥታዊ_, 
   {{0x44200bf1,0xebc40352,0x4c0000f1,0x8bb408ca}},	//   yoj_, _бәйн, _پېغل, _ақлу_, 
   {{0x4421e23e,0xdb00004e,0x7c200072,0x394c0c18}},	//   xoj_, _valò, conr, _eggs_, 
   {{0x4421e23f,0x7a1000a8,0x38300166,0x00000000}},	//   voj_, căto, рнэр, --, 
   {{0x888401c6,0x628003b2,0x00000000,0x00000000}},	//   _алдж, álom, --, --, 
   {{0x44201a4c,0xc8b400dc,0xf7b403e6,0xfa300131}},	//   toj_, _अनिट, ردیش_, _ئىنج, 
   {{0xa2940006,0x7a3400e4,0x00000000,0x00000000}},	//   лагі, rãte, --, --, 
   {{0x4421e240,0xf8340375,0x00000000,0x00000000}},	//   roj_, _שנות_, --, --, 
   {{0x44209996,0x7ab80a7c,0xdb2000e4,0x00000000}},	//   soj_, וצלו, ítép, --, 
   {{0x4421e241,0x270c0134,0x7a100311,0x3ddc01a4}},	// [364d0] poj_, _hɛn_, zăto, _rouw_, 
   {{0x3ddc007f,0xefbc0023,0x4421e242,0x00000000}},	//   _souw_, _ደቀይ_, qoj_, --, 
   {{0xa19400d1,0x3ddc033b,0xb2841999,0x7c2001f4}},	//   _йанч, _pouw_, _кыяк, vonr, 
   {{0xed5810f5,0xdb0001c7,0x2d9400d4,0xf654011a}},	//   вої_, _ublé, иріс, דסאי_, 
   {{0xe2140124,0x3ddc01a4,0xae0400cf,0x00000000}},	//   _амҽы, _vouw_, جونى, --, 
   {{0x7a100276,0x3ddc01a4,0xfb8406a6,0x5a94520c}},	//   tăto, _wouw_, тыдн, гриф, 
   {{0x61ede243,0xaed4016c,0x7c20005c,0x3ddc0d27}},	//   okal, _корш, ronr, _touw_, 
   {{0x61ede244,0x7c21e245,0x7a100276,0x00000000}},	//   nkal, sonr, răto, --, 
   {{0x7a10084c,0x61ede246,0x9d140c9e,0xd7e8074d}},	//   săto, ikal, _сдач, емпе_, 
   {{0x270c0605,0x7a100311,0x61ec81d4,0x3a3c0113}},	//   _bɛn_, păto, hkal, smup_, 
   {{0x61ede247,0xd7047401,0x46e401c6,0x55e43a49}},	//   kkal, узни, гдэн_, гонб, 
   {{0x270c0605,0x61ede248,0x394c01f5,0xceb008a8}},	//   _dɛn_, jkal, _uggs_, זיט_, 
   {{0x61ed474c,0x1abc0b27,0xe63401c6,0x27ec0051}},	//   dkal, ्मकथ, рхээ, bkdn_, 
   {{0x61ede249,0xdc34010f,0x00000000,0x00000000}},	//   ekal, טאָט_, --, --, 
   {{0x61ecc09b,0x47980a7c,0x00000000,0x00000000}},	//   fkal, _ניקס, --, --, 
   {{0x61ec7004,0x7d1803e3,0xb16400fb,0x00000000}},	//   gkal, _oxus, рнаһ, --, 
   {{0x90c5e24a,0x7d180117,0x4fa400c7,0xfbb006e3}},	// [364e0] ыбае, _nxus, лиав, ंजाम, 
   {{0xdd401418,0x270c1958,0xcef40798,0x00000000}},	//   _eŋŋo, _yɛn_, лчењ, --, 
   {{0x7d181709,0x8d85e24b,0x69b81bd6,0x00000000}},	//   _axus, гулд, ्यमी, --, 
   {{0xdd0000b0,0x00000000,0x00000000,0x00000000}},	//   _ōtāt, --, --, --, 
   {{0xa3a806ab,0xa07400c9,0x6b75e24c,0x20d401ec}},	//   _गॉड_, _высш, аллу, _кірс, 
   {{0xfbcc1473,0x00000000,0x00000000,0x00000000}},	//   كتى_, --, --, --, 
   {{0x8c940046,0x7d19325c,0x38c401ec,0x00000000}},	//   _әрбі, _exus, ғуын_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x270c0134,0x0b940633,0x89340116,0x00000000}},	//   _sɛn_, _مجاد, دعغا, --, 
   {{0x61ede24d,0x8c459484,0x270c013f,0xca7402d5}},	//   zkal, _сезе, _pɛn_, _буды, 
   {{0x61ede24e,0x7fd4008f,0xa5f80063,0xa61400f5}},	//   ykal, אויס_, вену_, имоч, 
   {{0x7d18022e,0xfb18011a,0x61ec9d49,0x00000000}},	//   _yxus, _אובמ, xkal, --, 
   {{0x61ede24f,0x67d48f54,0x1cb80327,0xaab4000d}},	//   vkal, _волу, _མནབ_, _अईँक, 
   {{0x60c8107d,0x61ede250,0xe2f40124,0xe7040101}},	//   _šemo, wkal, азгь, _پستی, 
   {{0x3f8409cc,0x61ed87bb,0x3960026c,0x69c0017a}},	//   ónum_, tkal, _éssé_, odme, 
   {{0x673822c1,0x61ede251,0x69c1e252,0x82346b73}},	//   _izvj, ukal, ndme, ارسا, 
   {{0x1f7401d5,0x00000000,0x00000000,0x00000000}},	// [364f0] илая, --, --, --, 
   {{0x61ede253,0x79480432,0x92c005ac,0x7094024c}},	//   skal, _höwü, ্নড়_, сафф, 
   {{0x5d540372,0x3c38002d,0xf3642cc8,0x79480432}},	//   акет, nêve_, _утын, _köwü, 
   {{0x405400cf,0x7a3400e4,0x69c0007c,0x6b9c032e}},	//   _مئسس, kãta, jdme, _örgj, 
   {{0x25a80109,0x33f401e3,0x69c0031c,0x00000000}},	//   _mbal_, _häxa_, ddme, --, 
   {{0xdb0007de,0x3f803421,0x7e740451,0xda64edb5}},	//   _malö, _udju_, _مارئ, авки, 
   {{0x69c00cf9,0x25a80122,0xefc801d5,0x6ff40210}},	//   fdme, _obal_, _суяк_, yńcz, 
   {{0x7d18005a,0x9c641541,0x00000000,0x00000000}},	//   _txus, _نهرو, --, --, 
   {{0xdcf400e2,0x33f401e3,0x00000000,0x00000000}},	//   ābēj, _läxa_, --, --, 
   {{0x25a9e254,0x69c1e255,0x00000000,0x00000000}},	//   _abal_, adme, --, --, 
   {{0xe9d800f7,0x7948010e,0x00000000,0x00000000}},	//   ткө_, _böwü, --, --, 
   {{0xdb0001b8,0xd4f4004e,0x99800354,0x00000000}},	//   _balö, аягы, _хiан_, --, 
   {{0x794809a5,0xdb0029ef,0x00000000,0x00000000}},	//   _döwü, _calö, --, --, 
   {{0x395c0393,0xdb0007c5,0x25a80100,0x00000000}},	//   lcus_, _dalö, _ebal_, --, 
   {{0xdb000316,0x387de256,0x395c0175,0x00000000}},	//   _oblí, lsur_, ocus_, --, 
   {{0x395c1730,0xe3b402dd,0x63a80841,0x794800ee}},	//   ncus_, _құс_, đena, _göwü, 
   {{0x1149e257,0x422000d6,0x661c01ed,0x69b80b7c}},	// [36500] тпай_, ідув, érke, ्यती, 
   {{0x387c05b1,0x7e780210,0x53a401f4,0x00000000}},	//   isur_, _łupa, _таоб, --, 
   {{0x69c001d9,0xff20ae46,0x387c0790,0x00000000}},	//   ydme, омфо, hsur_, --, 
   {{0x387c022c,0x1138cced,0x248c02fb,0xccc4004e}},	//   ksur_, _аягы_, šeme_, ибей, 
   {{0x34a400bc,0x00000000,0x00000000,0x00000000}},	//   _ओहोद, --, --, --, 
   {{0xce640014,0x395c0381,0xbc64143e,0x387c0450}},	//   _ندرى, ecus_, جمون_, dsur_, 
   {{0x387c0204,0x00000000,0x00000000,0x00000000}},	//   esur_, --, --, --, 
   {{0x2d84009a,0x79a00acf,0x387c0066,0x69c0493a}},	//   _udme_, орье, fsur_, udme, 
   {{0x25a80354,0x69c003a1,0x387c7480,0xdb0c02fb}},	//   _rbal_, rdme, gsur_, čkám, 
   {{0x31600399,0x395c0793,0xdb000306,0x07e40063}},	//   hciz_, acus_, _zblí, рцим, 
   {{0xdb011010,0x387c0204,0x60c80327,0xf3fc0154}},	//   _balõ, asur_, _ġemm, ঁচার_, 
   {{0x395c3113,0x31600399,0x69c00175,0x00000000}},	//   ccus_, jciz_, qdme, --, 
   {{0x250865dc,0xdb0c005b,0x00000000,0x00000000}},	//   ارجی_, äköh, --, --, 
   {{0xdb000793,0x49902f4d,0xd68c009d,0x00000000}},	//   _valö, _ایکر, _бvри, --, 
   {{0xf2c44945,0x673801fa,0x0585e258,0x794800a2}},	//   остн, _uzvj, _купм, _töwü, 
   {{0x33f401e6,0xdb0000d8,0x057400d1,0x00000000}},	//   _växa_, _galõ, _ئاغد, --, 
   {{0x7058040e,0xdb000109,0xab5c0171,0x00000000}},	// [36510] иатр_, _halô, _zaļe, --, 
   {{0x657de259,0x908801ed,0x5f789abe,0xdb00013a}},	//   lash, املے_, اماس_, _sblí, 
   {{0x63b40fb7,0x395c003a,0x9d556e8a,0x00000000}},	//   mezn, ycus_, منات, --, 
   {{0x63b41156,0xdd94a9e6,0x387c8791,0x6294004c}},	//   lezn, сады, ysur_, muzo, 
   {{0x645c0007,0x6295e25a,0x00000000,0x00000000}},	//   nqsi, luzo, --, --, 
   {{0x657de25b,0xdd10031c,0x00000000,0x00000000}},	//   hash, _iżża, --, --, 
   {{0x657de25c,0x629401fa,0x1cb8031c,0x7a10054e}},	//   kash, nuzo, _མནམ_, lăti, 
   {{0x657c044e,0xdb0002fb,0x395c003a,0x6fa001ec}},	//   jash, _ublí, ucus_, _ﺍﯕﻌﺎ_, 
   {{0x657de25d,0x9d1816c3,0x63b400dd,0x62948dc8}},	//   dash, _соат_, kezn, huzo, 
   {{0x395de25e,0x62951c96,0xdb000120,0x31600097}},	//   scus_, kuzo, _salõ, zciz_, 
   {{0x657c633d,0x387de25f,0xfde80490,0x79e40050}},	//   fash, ssur_, _झकास_, _پوشہ_, 
   {{0xd469e260,0x6294b0e8,0x7bc1e261,0x19582e70}},	//   лиме_, duzo, ldnu, _сады_, 
   {{0xf3f800ee,0x01cc00fe,0x9864009f,0x00000000}},	//   иңи_, ৰসাদ, _اُته, --, 
   {{0x63b455e2,0xe708066d,0x7bc1e262,0x6295e263}},	//   gezn, اتین_, ndnu, fuzo, 
   {{0x55e40209,0xdb0000d8,0x6294867b,0x59bc00dc}},	//   _гойб, _talõ, guzo, ्यपर, 
   {{0x657cd041,0x6ba4001f,0x00000000,0x00000000}},	//   cash, _መጽሐፈ_, --, --, 
   {{0x63b5e264,0x7a10084c,0xc860063f,0xa3a802e5}},	// [36520] bezn, găti, _kọọd, _गॉव_, 
   {{0x6295e265,0x00000000,0x00000000,0x00000000}},	//   buzo, --, --, --, 
   {{0x2c084bcf,0x7bc00327,0x00000000,0x00000000}},	//   یعتی_, ddnu, --, --, 
   {{0xac68044e,0x7e6001ed,0x831401d5,0xa6e400fe}},	//   _ዝተፈጸ, ínpa, _چقیر_, _ফেঁট, 
   {{0x7c8012a2,0x62800316,0x61b00150,0x8598011a}},	//   пуще, álov, _زەلا, רשנו, 
   {{0x657de266,0x0c7c0092,0xcca400db,0x40300153}},	//   zash, _ከግማሽ_, _ۇچتۇ_, _неўс, 
   {{0x657de267,0x3ea80216,0x6281e268,0x7aec0419}},	//   yash, čitá_, šlov, _čitá, 
   {{0x63b44966,0xc2780a1e,0x7bc1e269,0x657c36ba}},	//   zezn, ארקי, adnu, xash, 
   {{0x657de26a,0xcb682488,0xc86001f2,0xdb000109}},	//   vash, _базе_, _bọọd, _salô, 
   {{0x657de26b,0xb7f40724,0x00000000,0x00000000}},	//   wash, йныф_, --, --, 
   {{0x25d9e26c,0xe5b45a19,0x00000000,0x00000000}},	//   амны_, ойны, --, --, 
   {{0xbb3800c8,0x00000000,0x00000000,0x00000000}},	//   _געבי, --, --, --, 
   {{0xa439e26d,0x629518eb,0xa96800d1,0x63b4072d}},	//   изму_, wuzo, _биҗа_, tezn, 
   {{0x657c4437,0x63a81326,0x67d40d08,0x645c1290}},	//   sash, đeno, _фоку, rqsi, 
   {{0x657de26e,0x63b5e26f,0x00000000,0x00000000}},	//   pash, rezn, --, --, 
   {{0x245c01dc,0x657cb63b,0x6295e270,0xe4d890b2}},	//   _tìm_, qash, ruzo, _نوبت_, 
   {{0xc05800e3,0x6295094b,0xdb0001e7,0x645d0996}},	// [36530] اشرا_, suzo, _mblá, qqsi, 
   {{0x600803be,0x3f8400d2,0x7a100356,0x6294013a}},	//   _kömə, ûnu_, răti, puzo, 
   {{0xad240ed1,0xf1c4d295,0xdb0002fb,0x00000000}},	//   ۋىمى, _लोकन, _oblá, --, 
   {{0xb8c84933,0x7a10054e,0x00000000,0x00000000}},	//   _བྱ_, păti, --, --, 
   {{0xac840220,0x7c8801af,0x00000000,0x00000000}},	//   згіл, ущев_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7e640054,0x7bc1e271,0x6e94013e,0xbd680640}},	//   _utjp, rdnu, _ниру, _брзе_, 
   {{0x6b880083,0x00000000,0x00000000,0x00000000}},	//   _eddg, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x16a80107,0x6d5c0166,0xa3a80210,0x00000000}},	//   авои_, _ğrai, _गॉल_, --, 
   {{0xae006b9b,0x1a64030f,0xcf9005d0,0x00000000}},	//   लोकन_, _بیبی_, וטי_, --, 
   {{0x58d40a83,0xc860063f,0xa2bc2144,0xd628490c}},	//   _моет, _wọọd, शबन्, роме_, 
   {{0x6284ea1e,0x628006af,0xddc8033f,0xab5c00ef}},	//   _avho, âlon, _kieł, _haļa, 
   {{0xdce80030,0xd9b40014,0x2b40012c,0xdb0002fb}},	//   _oceľ, _دٔچھ, řice_, _zblá, 
   {{0x998c00d0,0x934402dd,0x00000000,0x00000000}},	//   tieň_, інбе, --, --, 
   {{0x268800c6,0xab5c0171,0x37b800eb,0x00000000}},	//   _اخوي_, _maļa, _অচির, --, 
   {{0x85780137,0x00000000,0x00000000,0x00000000}},	// [36540] _өсөт_, --, --, --, 
   {{0xe1f8016c,0xbdc801d3,0x7a100356,0xddc8012d}},	//   агӣ_, یدنے_, mătu, _nieł, 
   {{0x91e50c5b,0x7a100311,0xb8f8031c,0x7e9401d5}},	//   _доне, lătu, _ལཌ_, قنلر_, 
   {{0x680001e1,0x6b880142,0x3c38035b,0x00000000}},	//   _kájù, _sddg, vêva_, --, 
   {{0x82b40dd4,0x504400a8,0xae0005f9,0x26d8063f}},	//   _བགོའ, _мемб, लोगन_, ̣ro_, 
   {{0x9db80150,0x00000000,0x00000000,0x00000000}},	//   _қысу_, --, --, --, 
   {{0x68000241,0x00000000,0x00000000,0x00000000}},	//   _lájù, --, --, --, 
   {{0x48a83967,0xab5c00da,0x7999e272,0xd90c0344}},	//   атом_, _daļa, gguw, گیه_, 
   {{0x01f8010f,0x4ba4004e,0x3c3800e4,0x00000000}},	//   יפקל, _дөйү_, sêva_, --, 
   {{0xc6a4736a,0x27f81873,0x29180276,0xd90de273}},	//   орми, órn_, ăra_, دیه_, 
   {{0xab5c005f,0x8cc039d7,0xc9848dbb,0xe3c5e274}},	//   _gaļa, लिको, _дули, үргү, 
   {{0x37b40154,0x7a100356,0x00000000,0x00000000}},	//   জাগর, fătu, --, --, 
   {{0x38c9b887,0x7a10084c,0xab5c00e2,0x62840051}},	//   _پانی_, gătu, _zaļa, _svho, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x236c01e4,0xf4340006,0x00000000,0x00000000}},	//   ĝej_, ферэ, --, --, 
   {{0x7a10054e,0x63e401e2,0x00000000,0x00000000}},	//   bătu, _کېسې_, --, --, 
   {{0x660de275,0x7a100276,0x59bc00dc,0xdd9000e5}},	// [36550] _imak, cătu, ्यतर, ہوا_, 
   {{0x6280012c,0x249805b1,0x79980198,0xf0e80131}},	//   álos, musm_, zguw, غىلى_, 
   {{0x35d01d15,0xe188010b,0xdd9000c6,0x683400a3}},	//   _तोड़, _гөзе_, فوا_, ràdh, 
   {{0x628004b9,0x25b800bc,0xaab40073,0x680001e1}},	//   šlos, nesl_, ंबईक, _yájù, 
   {{0x660de276,0xa0c4352e,0x2249e277,0x408400d8}},	//   _mmak, _عيسو, mmak_, _ќумб, 
   {{0x2249e278,0xac1800f7,0x660c2681,0xab5c00de}},	//   lmak_, оочу_, _lmak, _paļa, 
   {{0x6834004e,0xf4140375,0x7a100356,0x20d401a8}},	//   càdi, ופס_, zătu, búið_, 
   {{0x22481295,0x6db4004e,0x59bc043e,0x80dc00bc}},	//   nmak_, _ойсу, ्यधर, _नपाइ, 
   {{0x63a81326,0x799803f9,0x22480548,0x9b9400d8}},	//   đenj, rguw, imak_, _ниац, 
   {{0xfbd00592,0x01ac00cc,0x05a4009d,0x00000000}},	//   _تتر_, _চোমদ, үвэй_, --, 
   {{0x2249e279,0x59bc0b98,0x680001e1,0xeff80023}},	//   kmak_, ्यदर, _sájù, _ፈታዊ_, 
   {{0x224805a1,0x07a0016c,0x2ae8012c,0x660c045a}},	//   jmak_, _ҷашн, जहरु_, _cmak, 
   {{0x22480548,0x00000000,0x00000000,0x00000000}},	//   dmak_, --, --, --, 
   {{0x660de27a,0x5f00015b,0x7a10054e,0x2248002e}},	//   _emak, _এখনও_, rătu, emak_, 
   {{0x7a100311,0xd25001d3,0x3c380022,0x947400f2}},	//   sătu, فنس_, hêvo_, _کدبا, 
   {{0x7a100311,0x45a0215c,0x2249e27b,0x00000000}},	//   pătu, _كەپك, gmak_, --, 
   {{0x9f500268,0x7645e27c,0xe50805d9,0x00000000}},	// [36560] _alzà_, _ihiy, _ويٺو_, --, 
   {{0x22480429,0x6130032e,0x940401c8,0x00000000}},	//   amak_, _sólþ, _روجه, --, 
   {{0x59bc1b61,0x76440014,0x0ea83004,0x660c01d5}},	//   ्यार, _khiy, скей_, _ymak, 
   {{0x2248011f,0x94000134,0x683400cf,0xf1c4085c}},	//   cmak_, mukɑ_, ràdi, _लोचन, 
   {{0x6ab4206b,0x69cc0bae,0x00000000,0x00000000}},	//   ंब्र, _दोषी, --, --, 
   {{0xdd98007f,0x79880165,0x76440076,0x0fd800c6}},	//   _alňd_, _adgw, _lhiy, _ابحث_, 
   {{0x75280034,0xfa30129e,0xff200153,0xddc80210}},	//   ędzy, کرود, _змро, _bień, 
   {{0x76440810,0xc6a401c0,0x75240356,0xad8400cf}},	//   _nhiy, үрни, _oxiz, _زارۇ, 
   {{0xdb000e78,0x96200154,0x660c0055,0xc7c400d8}},	//   _ablä, নতাম_, _rmak, псни, 
   {{0x6d4011f9,0x7644014b,0x2249e27d,0x798801ab}},	//   _izma, _ahiy, zmak_, _edgw, 
   {{0x65952fb1,0x22498aad,0x7645e27e,0xdcf800b0}},	//   ману, ymak_, _bhiy, mawā, 
   {{0x7645e27f,0x7e78012d,0x19b000fb,0xae000d2e}},	//   _chiy, _łupk, _аҡъю, लोचन_, 
   {{0x764422a9,0x320001f7,0xe91801d3,0x22480205}},	//   _dhiy, dhiy_, _براڈ_, vmak_, 
   {{0x660c0268,0xd8b40c4f,0x00000000,0x00000000}},	//   _wmak, _آگيا_, --, --, 
   {{0x22481295,0x24981509,0x4a280135,0x25b8011c}},	//   tmak_, susm_, _སྩོལ_, pesl_, 
   {{0x7645e280,0x6d4001e4,0x31c402bf,0x2248011f}},	//   _ghiy, _ozma, нсув, umak_, 
   {{0x2249e281,0xdcf804fe,0x6d4000b0,0x661c3bdc}},	// [36570] rmak_, kawā, _nzma, mnsk, 
   {{0x22489c11,0xb035e282,0x64c8000d,0x4ac01df0}},	//   smak_, енуш, िटीश, _वैभव, 
   {{0x22482c44,0x6d41e283,0xa1591b4a,0x2488072b}},	//   pmak_, _azma, _ману_, _hvam_, 
   {{0x661de284,0x32001bb7,0x2488332c,0x629409a8}},	//   nnsk, chiy_, _kvam_, mrzo, 
   {{0x61fc070d,0x661ca293,0xdca5e285,0x00000000}},	//   _ilsl, insk, фали, --, 
   {{0x44300139,0x629401f5,0x60cde286,0xfbd006c2}},	//   _jkx_, orzo, mvam, عتش_, 
   {{0x661c022c,0x6b8400db,0x6d40022e,0x1df80108}},	//   knsk, رشول, _ezma, _девы_, 
   {{0x248801f5,0xbdf800ec,0x00000000,0x00000000}},	//   _ovam_, _ارسا_, --, --, 
   {{0xac94a69a,0x764402b9,0x61fc0254,0x00000000}},	//   _патш, _rhiy, _mlsl, --, 
   {{0x7645e287,0x79600241,0x661c6e1c,0x59bc92c1}},	//   _shiy, _bíwó, ensk, ्यहर, 
   {{0x61fc08cd,0x60cde288,0x67e402e2,0x7645e289}},	//   _olsl, hvam, _jòjy, _phiy, 
   {{0x661c0627,0x76440472,0x6b9cc9df,0xcb10025d}},	//   gnsk, _qhiy, _örgr, _בלב_, 
   {{0xdd00012c,0x7a100311,0x60cc047e,0x92a800cc}},	//   _čtět, bătr, jvam, _গছে_, 
   {{0x661de28a,0x64449b55,0x59bc07b7,0x61fc8ecc}},	//   ansk, _chhi, ्यवर, _alsl, 
   {{0x24880a28,0x76440bc9,0x644401ab,0x82a1ddef}},	//   _evam_, _thiy, _dhhi, карж, 
   {{0x752401c4,0x6445e28b,0x64580064,0x00000000}},	//   _txiz, _ehhi, _žaiž, --, 
   {{0x4fe8074d,0x142438cb,0x0fc4010b,0x10a400c7}},	// [36580] оман_, _одим, мйан, ьиан, 
   {{0x320001b9,0x644400a3,0x61fc282c,0xe1f0004b}},	//   shiy_, _ghhi, _elsl, پسې_, 
   {{0x60cde28c,0x32000309,0x6d40033f,0x00000000}},	//   avam, phiy_, _szma, --, 
   {{0x3f8409cc,0x60cde28d,0x3200022e,0x2e3400f7}},	//   ónur_, bvam, qhiy_, رباڭ, 
   {{0xdb08278a,0xd478008f,0xf76401e2,0x00000000}},	//   čnýc, קאַל, _ټا_, --, 
   {{0x0a69e28e,0xfbcd9644,0x20002b34,0xe2a801d9}},	//   ории_, لتى_, chhi_, _باین_, 
   {{0x661de28f,0x6d400034,0xdcf800b0,0x61fc0334}},	//   ynsk, _wzma, rawā, _ylsl, 
   {{0x63a80bb8,0x33f40139,0x00000000,0x00000000}},	//   đeni, _däxi_, --, --, 
   {{0x6d41e290,0x661de291,0xdde82088,0xdc7400c7}},	//   _uzma, vnsk, _عرفه_, _зыхь, 
   {{0xddc8005f,0x06e0015b,0x7e78012d,0xa9c400db}},	//   _cieņ, মনসি, _łupi, بۅچۉ, 
   {{0x24891254,0x60ccbf23,0x661c148b,0x00000000}},	//   _svam_, zvam, tnsk, --, 
   {{0x661d6133,0x1de002ab,0xdbd8032e,0x60cde292}},	//   unsk, फायत, _hæðs, yvam, 
   {{0x661de293,0x61fc020c,0x2488003a,0x7a100356}},	//   rnsk, _rlsl, _qvam_, pătr, 
   {{0x6294012d,0x60cc014f,0xe8bc0073,0x69b808a3}},	//   trzo, vvam, ्टीच, ्यकी, 
   {{0xa5f87656,0x60cc014f,0xb28473b5,0x37a400cc}},	//   _неку_, wvam, кытк, _কোকৰ, 
   {{0x60cde294,0x24880882,0xdbd802d2,0xc218003b}},	//   tvam, _tvam_, _læðs, ієв_, 
   {{0xdb0000db,0x24880393,0x4430013d,0x00000000}},	// [36590] _eclè, _uvam_, _tkx_, --, 
   {{0x60cde295,0x44300227,0xf1d81d8a,0x60c98f8d}},	//   rvam, _ukx_, डाउन, _šems, 
   {{0xef180491,0x60cde296,0x63a5e297,0xceb40d52}},	//   ммѕ_, svam, _ichn, нәт_, 
   {{0x2001360c,0x61fc01bf,0x60cc014f,0x00000000}},	//   shhi_, _ulsl, pvam, --, 
   {{0x60cc016d,0xee3800d4,0x00000000,0x00000000}},	//   qvam, єні_, --, --, 
   {{0x9f640108,0x00000000,0x00000000,0x00000000}},	//   ätät_, --, --, --, 
   {{0x80dc146b,0x21380240,0x6bd403e6,0xdd940006}},	//   _नपुं, _hysh_, کتۆر, _павы, 
   {{0x22582e95,0x1ae80154,0x00000000,0x00000000}},	//   _jisk_, _কেউই_, --, --, 
   {{0xddc800da,0x2259e298,0x63a4022e,0xfb840166}},	//   _pieņ, _misk_, _ochn, _жыен, 
   {{0xd70802f6,0x63a4009f,0x21380731,0x00000000}},	//   зное_, _nchn, _mysh_, --, 
   {{0xf53c001f,0x06805ce3,0xab84fcc3,0x21380142}},	//   _በኦሮሚ, лгэн, _шутк, _lysh_, 
   {{0x63a400a3,0xdb0000d0,0x6738036e,0x00000000}},	//   _achn, _oblú, _dyvj, --, 
   {{0x20100472,0x9d1c0154,0x00000000,0x00000000}},	//   _omzi_, _তরুন_, --, --, 
   {{0xd7c82ea3,0x00000000,0x00000000,0x00000000}},	//   _روبه_, --, --, --, 
   {{0x22580072,0x931402dd,0x2138022e,0x044000a7}},	//   _bisk_, رورش, _aysh_, уерн, 
   {{0x201000ca,0x63a40c8c,0x06800395,0x155801ee}},	//   _amzi_, _echn, _сгън, _эшкњ_, 
   {{0x41240353,0x00000000,0x00000000,0x00000000}},	// [365a0] еото_, --, --, --, 
   {{0xdb002cd7,0xd9bc0892,0x59d0007d,0x21380240}},	//   _eclé, ्युट, _दोसर, _dysh_, 
   {{0xa3a801ad,0xdbd80aab,0x00000000,0x00000000}},	//   _गॉट_, _ræðs, --, --, 
   {{0x4d480220,0xdb000332,0xdbd803b2,0xff200022}},	//   ппен_, _gclé, _sæðs, ымхо, 
   {{0x3ebc3421,0x02d4036b,0x213800a2,0x4f940798}},	//   _ćute_, _قویب_, _gysh_, _прву, 
   {{0x22580122,0xab3800a8,0x683401ab,0xd1f80092}},	//   _zisk_, мплу_, hàdr, ጋዮች_, 
   {{0xd9bc06bc,0x7f40010b,0x59d00da3,0xdb0000d7}},	//   ्यूट, _берж, _दोहर, _zblú, 
   {{0x49b800ae,0xa934011c,0x00000000,0x00000000}},	//   ساعد_, кейш, --, --, 
   {{0x0c3800c6,0xc0cc001f,0xcb7400d8,0x00000000}},	//   _فكرة_, _ጥቅስ_, _зуењ, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdd98010a,0xf76da416,0x00000000,0x00000000}},	//   _ашĕ_, حاً_, --, --, 
   {{0x63a5e299,0x00000000,0x00000000,0x00000000}},	//   _schn, --, --, --, 
   {{0x22580375,0x63a40210,0x00000000,0x00000000}},	//   _risk_, _pchn, --, --, 
   {{0xdb01b5da,0x64a40124,0xe70400e5,0x00000000}},	//   _sclé, наҭа, _لسبی, --, 
   {{0xf6d005d4,0x56c40032,0x2138036e,0xc66804b4}},	//   _مزيد, _ашыҡ, _sysh_, _эшле_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x213802d3,0x656de29a,0x65680022,0x63a42149}},	// [365b0] _qysh_, _ifah, ñehu, _tchn, 
   {{0x2259e29b,0x63a40455,0xc4441968,0x30140137}},	//   _wisk_, _uchn, _سیزن_, гдур, 
   {{0x2259a6a9,0xfbdc01fb,0x00000000,0x00000000}},	//   _tisk_, _đê_, --, --, 
   {{0xdd95e29c,0x22580254,0x7e7400db,0x00000000}},	//   тады, _uisk_, _ۋازئ, --, 
   {{0x656c009f,0x00000000,0x00000000,0x00000000}},	//   _mfah, --, --, --, 
   {{0x2010004b,0xd1140375,0xefc80148,0x7b6400ee}},	//   _umzi_, _יקרה_, _пуск_, хтде, 
   {{0x656c0270,0xa3c8000d,0x386c02d2,0xab5c00ef}},	//   _ofah, _ईसन_, _stgr_, _zaļk, 
   {{0x6dc40137,0x8bd40166,0xeb0400c7,0xf2d400df}},	//   _مۅمۅ, емәс_, ыччо, רעק_, 
   {{0x69b80d2c,0x9f480724,0x49c401c6,0xdc54009b}},	//   ्यजी, şkän_, тлын_, _авањ, 
   {{0x3f81e29d,0x656c0134,0x3d900032,0x6604031c}},	//   _jeju_, _afah, _шиғр, _ċika, 
   {{0xd62801f0,0xfa8001b9,0x00000000,0x00000000}},	//   доне_, _ёқим, --, --, 
   {{0x3f81b2e5,0x00000000,0x00000000,0x00000000}},	//   _leju_, --, --, --, 
   {{0x65f805f5,0x97c40334,0xe9f800d4,0x893000e5}},	//   хээр_, _айле, _янці_, _پٹوا, 
   {{0xd370179c,0x656de29e,0x38a80e38,0xdef8001f}},	//   شهر_, _efah, mør_, _ፈጣን_, 
   {{0x60c80219,0x0365e29f,0x38a812ed,0x30240107}},	//   _šemp, тиск_, lør_, ҳзаҳ, 
   {{0x30900020,0xee8c0023,0x00000000,0x00000000}},	//   _እርግጥ_, _ኣፍሊጣ_, --, --, 
   {{0x38a83c02,0xe85004d3,0x4fa40166,0x3f800200}},	// [365c0] nør_, _خۆید, киав, _beju_, 
   {{0xd1cc0023,0xc0cc0023,0x00000000,0x00000000}},	//   _ጥንቲ_, _ጥቅሲ_, --, --, 
   {{0x0d84468d,0x38a8eda6,0x0dc9e2a0,0x3f80005f}},	//   влен, hør_, дули_, _deju_, 
   {{0x38a80ac8,0x3ea407de,0x80a01c3e,0x00000000}},	//   kør_, ànta_, امەن, --, 
   {{0x38a8fb06,0x60c80077,0x3f800200,0x998c0210}},	//   jør_, _áemp, _feju_, kieł_, 
   {{0x38a828b3,0x3f8000e2,0xab5c00e2,0x00000000}},	//   dør_, _geju_, _kaļi, --, 
   {{0x27e001fa,0x00000000,0x00000000,0x00000000}},	//   _đin_, --, --, --, 
   {{0x38a886ee,0xddc80034,0xdb4c03e6,0xab5c00ef}},	//   før_, _mieś, سێن_, _maļi, 
   {{0x38a804ce,0x2d85e2a1,0x01ac00eb,0xa78c0150}},	//   gør_, _ieme_, _চোঁদ, _ﻓﻘﺭﺓ_, 
   {{0x2d85687f,0xa774005b,0x4a9400f0,0x998c0210}},	//   _heme_, ылоч, _ајду, gieł_, 
   {{0x2d840280,0x656de2a2,0xddc8033f,0xa71400d4}},	//   _keme_, _pfah, _nieś, умні, 
   {{0x2d85e2a3,0xfd540055,0x38a801bf,0x00000000}},	//   _jeme_, _apaṭ, bør_, --, 
   {{0x69c1e2a4,0x2d85e2a5,0xe8946ebd,0x53dc0bca}},	//   meme, _meme_, _саль, मांश, 
   {{0x2d85e2a6,0x998c02f0,0x4aa40073,0x00000000}},	//   _leme_, rleť_, _गमाव, --, 
   {{0xe8e007ae,0xa19459e6,0x17e40014,0x3f8000c7}},	//   _đội_, лавч, _حسنُ, _reju_, 
   {{0xd9e41533,0x2d85e2a7,0x656c00ec,0x69c08bab}},	//   कायत_, _neme_, _ufah, neme, 
   {{0x69c1e2a8,0x3f81e2a9,0xab5c00de,0xc66801af}},	// [365d0] ieme, _peju_, _daļi, _эшһе_, 
   {{0x69c1e2aa,0x7538011a,0x00000000,0x00000000}},	//   heme, _באחד_, --, --, 
   {{0xd24c036b,0x33f401e6,0x25a84266,0x2d85e2ab}},	//   تچی_, _växt_, _kcal_, _beme_, 
   {{0x69c0ef64,0x25a8005a,0x2d85e2ac,0xab5c0171}},	//   jeme, _jcal_, _ceme_, _gaļi, 
   {{0x2d85e2ad,0x25a80124,0x5c14064d,0x3f81e2ae}},	//   _deme_, _mcal_, льку, _teju_, 
   {{0x38a895b0,0xb4fc0375,0x44219ff6,0xab5c00de}},	//   vør_, ופדי, nnj_, _zaļi, 
   {{0x69c1e2af,0x2d85e2b0,0x6b5c143a,0x00000000}},	//   feme, _feme_, vågø, --, 
   {{0x38a839c2,0x3960016c,0x44200221,0x2d840798}},	//   tør_, шниҳ, hnj_, _geme_, 
   {{0xb7800131,0xae0400d1,0x04f403d4,0xce501f0d}},	//   ағли, _ئوقى, ীপুৰ_, _اھلب, 
   {{0x38a81512,0x2d85e2b1,0x95fc0c4c,0x07640092}},	//   rør_, _zeme_, ॉफ्ट_, _ተናገረ_, 
   {{0x38a80e38,0x2d8405d1,0x4420036e,0x00000000}},	//   sør_, _yeme_, dnj_, --, 
   {{0x69c1e2b2,0x8af8008d,0x23600268,0x44200097}},	//   ceme, _אלעז, _aghj_, enj_, 
   {{0xb7b00724,0xd0440213,0x7c20062c,0x3a3c0477}},	//   _көнч, _erkə, onnr, mlup_, 
   {{0x25a80472,0x3a3de2b3,0xed78001f,0xddc8033f}},	//   _ecal_, llup_, ከታታይ_, _pieś, 
   {{0x7c2088d9,0xd71000fe,0x96b800db,0x27f8007c}},	//   innr, _সুৰা_, _чулу_, örne_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc0e053e9,0x2d85e2b4,0x442001fa,0x998c0034}},	// [365e0] ботк, _reme_, bnj_, mień_, 
   {{0x2d85e2b5,0xd1b00345,0xfd540055,0x00000000}},	//   _seme_, _گیرک, _upaṭ, --, 
   {{0x69c1e2b6,0x3a3c045f,0x2d85e2b7,0x33f40166}},	//   yeme, klup_, _peme_, _fäxr_, 
   {{0x69c00372,0x0ca834da,0x831800c8,0x8aa407d6}},	//   xeme, етки_, _טויז, ҳрид, 
   {{0x69c1e2b8,0x2d85e2b9,0x00000000,0x00000000}},	//   veme, _veme_, --, --, 
   {{0x69c0015c,0xdb000005,0x3d28208f,0x8aa4300e}},	//   weme, _eclí, رتنی_, грид, 
   {{0x69c1e2ba,0xc0000640,0x2e8800c7,0x00000000}},	//   teme, _упрк, _рҩеи_, --, 
   {{0x2d840295,0x6604031c,0x26d80419,0x7c2001e7}},	//   _ueme_, _ċiko, ťrok_, annr, 
   {{0xd9b01183,0x47841075,0x00000000,0x00000000}},	//   تەند, лынб, --, --, 
   {{0x69c1e2bb,0x25a8070d,0xa81402f4,0xc7c44727}},	//   seme, _scal_, рдош, усии, 
   {{0x69c1e2bc,0x8034010f,0x00000000,0x00000000}},	//   peme, רניע_, --, --, 
   {{0x69c09665,0x44200097,0x00000000,0x00000000}},	//   qeme, wnj_, --, --, 
   {{0xd82c05d9,0xf76c0b28,0x25a800db,0x00000000}},	//   _ڪڍي_, غای_, _vcal_, --, 
   {{0xdcf80210,0x00000000,0x00000000,0x00000000}},	//   gawę, --, --, --, 
   {{0x4420009b,0xdb0002f0,0x998c012d,0x00000000}},	//   rnj_, _oblý, bień_, --, 
   {{0x0585e2bd,0xbb38008f,0x998c012d,0x7ff400f2}},	//   _сукм, געלי, cień_, گسرا, 
   {{0x80dc06ab,0x657de2be,0xe8e001fb,0x442001a6}},	// [365f0] नमें, mbsh, _đới_, pnj_, 
   {{0x7e740227,0xdb000432,0xeae439a1,0x69cc0073}},	//   tpxp, _ablý, _कपूत_, _दोघी, 
   {{0xf04400a8,0xdd90007b,0x00000000,0x00000000}},	//   сэто, قوا_, --, --, 
   {{0x248de2bf,0x5278011a,0x5cf40137,0x00000000}},	//   šemu_, _שנרא, иялу, --, 
   {{0x61ed52c0,0x66040003,0xa3c837f3,0x2fd801e0}},	//   mjal, _ċikl, _ईसा_, _өҫтө_, 
   {{0x5a942c31,0xeda40022,0x7114010a,0x9aa400ae}},	//   ариф, ашәо, _уçса, لمتو, 
   {{0x6d9c01f1,0x610c022e,0x61ede2c0,0x7c200175}},	//   _sťaž, _bўlg, ojal, rnnr, 
   {{0xcc8403e6,0x5c740f5c,0x4ca800eb,0x00000000}},	//   _چۆنه_, _влат, চৌধু, --, 
   {{0x7e64014f,0x0885e2c1,0x61ec0108,0x00000000}},	//   _hujp, абый_, ijal, --, 
   {{0x998c006d,0x61ede2c2,0x7e6401e4,0x657c002f}},	//   wień_, hjal, _kujp, ebsh, 
   {{0xd5e4516a,0x3a3c0649,0x7e640113,0x61ec5142}},	//   ажни, plup_, _jujp, kjal, 
   {{0x7bc1e2c3,0x61ecd9a1,0xd4682a9d,0x7e6401ef}},	//   lenu, jjal, киме_, _mujp, 
   {{0x61ede2c4,0x7e640455,0x7bc001f5,0x7a1400f1}},	//   djal, _lujp, oenu, _لښکر_, 
   {{0x7bc1e2c5,0x998c0034,0x07a1e2c6,0x69340137}},	//   nenu, sień_, _дашн, _унчу, 
   {{0x7e640218,0x61ede2c7,0x7bc0017a,0x998c033f}},	//   _nujp, fjal, ienu, pień_, 
   {{0x7bc1e2c8,0x61ec09cc,0xdebc0023,0x00000000}},	//   henu, gjal, _ሰዲኤ_, --, 
   {{0x7bc1e2c9,0x51540138,0x4638010f,0x00000000}},	// [36600] kenu, ртву, _בעקע, --, 
   {{0x7bc1e2ca,0x3fe00cda,0x61ede2cb,0xab5c00e2}},	//   jenu, ожув, ajal, _zaļu, 
   {{0x61ec0f8b,0xf2c02b1b,0x63a0012d,0x0ea80026}},	//   bjal, _উপকণ, ólne, ткей_, 
   {{0x61ed3fbc,0xfe4027cb,0x10a406b3,0x610c01a9}},	//   cjal, онхо, _кимн, _bўld, 
   {{0xcbe4f3e5,0x7d9400d3,0xa3bc01ad,0x00000000}},	//   ицки, рвіс_, ीएच_, --, 
   {{0xa4c40139,0x320001d5,0x403000c0,0x00000000}},	//   _läşü_, lkiy_, _меўс, --, 
   {{0x4290044e,0x657c0067,0x00000000,0x00000000}},	//   _ዝኾነት_, ybsh, --, --, 
   {{0x32000784,0xfa30027d,0x00000000,0x00000000}},	//   nkiy_, يريد, --, --, 
   {{0x8ba401f4,0x00000000,0x00000000,0x00000000}},	//   _визж, --, --, --, 
   {{0x61edcabe,0x7bc0003a,0x320002d1,0x6d41e2cc}},	//   zjal, cenu, hkiy_, _iyma, 
   {{0x6d404159,0x9f500240,0x32000de2,0x00000000}},	//   _hyma, _rozë_, kkiy_, --, 
   {{0x80a40034,0x7af40267,0x6b880e21,0x00000000}},	//   टूडे, äxte, _hedg, --, 
   {{0x8545e2cd,0xa9a40131,0x26d8008f,0x61eda6ff}},	//   рэне, _виҗд, ŭro_, vjal, 
   {{0x6d400998,0xc7640131,0x00000000,0x00000000}},	//   _myma, _ئاشى, --, --, 
   {{0x3f841bb0,0x61ede2ce,0x6d400a73,0xe6940597}},	//   ðnum_, tjal, _lyma, _البد, 
   {{0x6b89e2cf,0x7bc0005a,0x6d401432,0x417402f2}},	//   _ledg, zenu, _oyma, شارس, 
   {{0x7bc1e2d0,0x3f64013d,0xf65001f7,0x00000000}},	// [36610] yenu, атеб, _تئو_, --, 
   {{0x61ede2d1,0xddc80166,0x7bc1e2d2,0x3f840252}},	//   sjal, _bieş, xenu, únu_, 
   {{0x6d41e2d3,0xe8e007ae,0x7bc1e2d4,0xe2f80220}},	//   _ayma, _đời_, venu, _сені_, 
   {{0x661de2d5,0x7bc1e2d6,0x62840455,0x6d4003cd}},	//   nisk, wenu, _iwho, _byma, 
   {{0x6d4000a9,0x7bc1a02e,0xad240c50,0x6c8401d5}},	//   _cyma, tenu, يىمى, قلنم, 
   {{0x661de2d7,0x7e6401e4,0x5ff41513,0x6d4015c0}},	//   hisk, _tujp, _узгу, _dyma, 
   {{0x661de2d8,0x6d41e2d9,0x6b880076,0x5e840014}},	//   kisk, _eyma, _dedg, _دٔزم, 
   {{0xa3d80cb4,0x99e407d6,0x3eb0010a,0x6b8803ac}},	//   _ठोस_, сжид, mtxt_, _eedg, 
   {{0x7bc0e724,0x6d41e2da,0x2d583cc5,0xda6400ec}},	//   penu, _gyma, _вить_, جاڻي, 
   {{0x57e88456,0x20000472,0x661c0af9,0x628402d0}},	//   удом_, nkhi_, eisk, _owho, 
   {{0x32000784,0x3eb00175,0x27f85f47,0x00000000}},	//   ykiy_, ntxt_, örna_, --, 
   {{0xdb0000c6,0x6b88045a,0x00000000,0x00000000}},	//   _gclá, _zedg, --, --, 
   {{0x4dd8011a,0x00000000,0x00000000,0x00000000}},	//   אחרו, --, --, --, 
   {{0xdd98007f,0xd9e41b57,0x661c0064,0x00000000}},	//   _blňk_, कावत_, aisk, --, 
   {{0x91e5e2db,0x32000113,0x15780014,0x516400cf}},	//   бове, tkiy_, _یٔژھ_, йүнү_, 
   {{0x661de2dc,0x4f0825a2,0x3eb00334,0x20000009}},	//   cisk, ңнан_, dtxt_, ekhi_, 
   {{0x3200377b,0x114826c4,0xd2a802dd,0xc0e04c87}},	// [36620] rkiy_, упай_, _өкпе_, потк, 
   {{0x32012b6f,0x50b40107,0x6d41e2dd,0x00000000}},	//   skiy_, исҷу, _ryma, --, 
   {{0x6d41e2de,0x8d18034c,0x6b881ada,0x00000000}},	//   _syma, گزار_, _redg, --, 
   {{0x6b881caa,0x6604025c,0xcd04010b,0x41dc0118}},	//   _sedg, _ċikk, йчли, _पोपस, 
   {{0xc1700375,0xcd341ec7,0x7e7801a6,0x8cb406a6}},	//   _מחר_, حراب, _čupe, ссеч, 
   {{0x661de2df,0x6d400232,0xddc80724,0x6b88025c}},	//   zisk, _vyma, _tieş, _qedg, 
   {{0x6d40068f,0x6b882d8b,0x276801d5,0x661c01f4}},	//   _wyma, _vedg, یشدی_, yisk, 
   {{0x6b880f85,0x00000000,0x00000000,0x00000000}},	//   _wedg, --, --, --, 
   {{0x661de2e0,0x6d41e2e1,0xdc7400c7,0xcd0400db}},	//   visk, _uyma, _дыхь, _упай, 
   {{0x661de2e2,0xd90c0330,0x6b8802d0,0xda6400ec}},	//   wisk, خیه_, _uedg, _ڀاني, 
   {{0x661de2e3,0x442482aa,0xab5c0171,0xa3c801f9}},	//   tisk, _ın_, _vaļs, ोयस_, 
   {{0x628400e4,0x25ac0790,0x25f80073,0x00000000}},	//   _rwho, üel_, _उकळी_, --, 
   {{0x07080209,0x00000000,0x00000000,0x00000000}},	//   _әхли_, --, --, --, 
   {{0x25ac003d,0x00000000,0x00000000,0x00000000}},	//   żel_, --, --, --, 
   {{0x87340022,0xa19400db,0x940003b9,0x00000000}},	//   _ыҟоу_, жабч, nskə_, --, 
   {{0x250803e6,0x661c0113,0x68e401ab,0x3eb00175}},	//   _نرخی_, qisk, _àids, vtxt_, 
   {{0xc0cc0020,0x26dc01fa,0x6098297d,0x3eb00175}},	// [36630] _ጥቅም_, _hrvo_, شناس_, wtxt_, 
   {{0x3eb0003e,0x00000000,0x00000000,0x00000000}},	//   ttxt_, --, --, --, 
   {{0x2001e2e4,0xe2c80133,0x00000000,0x00000000}},	//   rkhi_, _ئاخۆ_, --, --, 
   {{0x20000472,0x3eb00175,0xe3a40066,0x00000000}},	//   skhi_, rtxt_, _اشکی, --, 
   {{0x3eb00334,0x00000000,0x00000000,0x00000000}},	//   stxt_, --, --, --, 
   {{0x3eb00354,0x7ea0063f,0x26dc047e,0x8ca000cf}},	//   ptxt_, _ọput, _orvo_, بەكو, 
   {{0x8c140137,0x33fc010f,0xd5a8262c,0xdce82ca8}},	//   تيور_, רהונ, _कालज, ınıd, 
   {{0xaac42160,0x60dc8bbb,0x00000000,0x00000000}},	//   ستىن, _krsm, --, --, 
   {{0x26dc6583,0x9d1801d5,0x00000000,0x00000000}},	//   _arvo_, _тоат_, --, --, 
   {{0x39400029,0x2ca00597,0x9ac40083,0xad240046}},	//   ājs_, áide_, _akŋŋ, _عىلى, 
   {{0xa2c8012d,0x00000000,0x00000000,0x00000000}},	//   _हैल्, --, --, --, 
   {{0x26dc2d2b,0xd5a80574,0x656802fb,0xfa000327}},	//   _drvo_, _काळज, žehn, _མཞིན_, 
   {{0xc4805159,0x195802d5,0xd9440120,0xd469e2e5}},	//   мляк, _тады_, _ќели, риге_, 
   {{0x8650001f,0x79880042,0x67d40815,0x00000000}},	//   መለከት, _hegw, _ночу, --, 
   {{0x60dc02d0,0x63a001d3,0xc0cc0092,0x00000000}},	//   _arsm, ólna, _ጥቅማ_, --, 
   {{0x42057039,0xd4a4010b,0x00000000,0x00000000}},	//   онсо_, _диий, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [36640] --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x15fc0d01,0x60dc057d,0x00000000,0x00000000}},	//   _उकार_, _ersm, --, --, 
   {{0x79882a22,0x9f500789,0x00000000,0x00000000}},	//   _negw, _alzó_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd0080b8d,0xb03400f1,0x0fd8005b,0x00000000}},	//   _теге_, _روزګ, _тьмы_, --, 
   {{0x7989e2e6,0xe8e007ae,0x08140489,0xd9e42232}},	//   _begw, _đối_, ྲིལཝ_, कांत_, 
   {{0x0d85e2e7,0xbd8400db,0x0d9001f7,0x00000000}},	//   _флан, _ۇچۇن_, _آگاھ, --, 
   {{0xc7c43e4f,0xdb000139,0x7989e2e8,0x27680214}},	//   осни, _aclä, _degw, یشگی_, 
   {{0x7988035a,0xc68d4060,0xdcf8013d,0x00000000}},	//   _eegw, نېت_, lawğ, --, 
   {{0x998c012d,0x00000000,0x00000000,0x00000000}},	//   nieś_, --, --, --, 
   {{0x91d9e2e9,0xc95801d5,0x16580014,0x48e40798}},	//   _पोलै, _кўл_, ٝسُک_, _моев, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x67d497da,0x998c068f,0xe2f8d8f9,0x798802e2}},	//   _хоку, kieś_, бегі_, _zegw, 
   {{0x7988004c,0x26dc0064,0xdb1001e1,0x00000000}},	//   _yegw, _urvo_, _ńgún, --, 
   {{0x60dc0010,0xa0755944,0xba98010f,0xf3640f06}},	//   _prsm, згач, יסלי, ьтян, 
   {{0x60f807d8,0x610c022e,0x2c7001ab,0x9f483361}},	// [36650] щная_, _bўla, _nàd_, şkün_, 
   {{0x26cc0009,0xdfd000ae,0x00000000,0x00000000}},	//   owdo_, عيا_, --, --, 
   {{0x9f500395,0x248801bf,0x00000000,0x00000000}},	//   _alzò_, _hwam_, --, --, 
   {{0x2489e2ea,0x623400a7,0x629458a5,0x66140205}},	//   _kwam_, _хему, mszo, _çekı, 
   {{0x7989e2eb,0x629401d3,0x2c700129,0x60dc0162}},	//   _regw, lszo, _càd_, _ursm, 
   {{0x7989e2ec,0x60cde2ed,0x5ff401b9,0x00000000}},	//   _segw, mwam, _эзгу, --, 
   {{0x248800f1,0x60cde2ee,0x6295e2ef,0x7988f3cc}},	//   _lwam_, lwam, nszo, _pegw, 
   {{0x62940196,0x24880472,0x60cc0083,0xdd9001e2}},	//   iszo, _owam_, owam, _سوئ_, 
   {{0x2489368a,0x79880099,0x60cde2f0,0x00000000}},	//   _nwam_, _vegw, nwam, --, 
   {{0x7989e2f1,0x6294179a,0x2a6c00f3,0x656802fb}},	//   _wegw, kszo, _fudb_, žehl, 
   {{0x2489966e,0x60cde2f2,0x6b9c0109,0x79886209}},	//   _awam_, hwam, _ôrga, _tegw, 
   {{0x6295e2f3,0x24880086,0x310000cd,0x00000000}},	//   dszo, _bwam_, ोनमः_, --, 
   {{0x998c0034,0x20cc00a2,0x6295e2f4,0x00000000}},	//   zieś_, _nži_, eszo, --, 
   {{0x387ce88c,0x24880204,0x96940075,0x60cc0083}},	//   mpur_, _dwam_, _ериш, dwam, 
   {{0x91e455c3,0x387c0008,0x629401ed,0x32500092}},	//   пове, lpur_, gszo, _በሥልጣ, 
   {{0x60cc0161,0x2488007f,0x387c01e4,0xb9fc0092}},	//   fwam, _fwam_, opur_, _ጁን_, 
   {{0x387c1dda,0x2488063f,0x7e79031e,0x60cde2f5}},	// [36660] npur_, _gwam_, _čupa, gwam, 
   {{0x20cc0cf4,0x130982df,0x387c02d2,0x629401d3}},	//   _dži_, _гной_, ipur_, bszo, 
   {{0x0e65e2f6,0x60ccb3e0,0x248801f5,0x20cc00ef}},	//   чкен, awam, _zwam_, _eži_, 
   {{0x60cde2f7,0x99dc00d7,0x00000000,0x00000000}},	//   bwam, dlňo, --, --, 
   {{0x8c443f6e,0x0fd81e76,0x60cc2ad1,0x4d140124}},	//   педе, _львы_, cwam, џьет, 
   {{0xbca00ae5,0xddc8033f,0x29d80208,0x7d2006c2}},	//   رمىي, _cheł, _ứa_, عفون, 
   {{0xd90de2f8,0x8f68022e,0x00000000,0x00000000}},	//   ییم_, _ваҳб_, --, --, 
   {{0x7e98011a,0x60e4013d,0x00000000,0x00000000}},	//   _לסלו, _ütmä, --, --, 
   {{0x3ebc1050,0xe8e001fb,0xec342c04,0x387c045a}},	//   _ćuti_, _đồi_, _قورگ, gpur_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x60cde2f9,0x2489e2fa,0x896400ee,0x9e6401d3}},	//   zwam, _swam_, _екеж, _راہن, 
   {{0x60cde2fb,0x6ec400bc,0x00000000,0x00000000}},	//   ywam, _रहनु, --, --, 
   {{0xd1d002d3,0x3494010b,0x63a00034,0x8384113e}},	//   ከናት_, наяр, ólno, зыбе, 
   {{0x158c0075,0x629401ed,0x80d806b1,0x00000000}},	//   _ﻛﯩﺸﯩ, tszo, निसे, --, 
   {{0xb354147e,0x60cde2fc,0xf7d4011a,0x77b8011a}},	//   екрш, wwam, _מוגש_, _המוח, 
   {{0xf7440375,0x6295e2fd,0x00000000,0x00000000}},	//   _عليي_, rszo, --, --, 
   {{0x660de2fe,0x629400dd,0x60cc01f5,0x9f500c5e}},	// [36670] _ilak, sszo, uwam, _vozí_, 
   {{0x60cc51a9,0x660de2ff,0x62952e75,0x00000000}},	//   rwam, _hlak, pszo, --, 
   {{0x660de300,0x4421e301,0x60cde302,0xceb41f0e}},	//   _klak, mij_, swam, мәт_, 
   {{0x4421e303,0x387c03f2,0x00000000,0x00000000}},	//   lij_, ypur_, --, --, 
   {{0x660de304,0x20cc1050,0x9c580414,0x60cc014b}},	//   _mlak, _uži_, ошку_, qwam, 
   {{0x4421e305,0x660ccff6,0x6d880014,0x9f3401ec}},	//   nij_, _llak, _ہۅمہ_, _жегі, 
   {{0x80d8de66,0xeb9006c7,0x2249284a,0x9f05e306}},	//   निवे, اظه_, olak_, _غورو, 
   {{0x4420d7f4,0x2ca005be,0x3f901155,0xadd40063}},	//   hij_, šida_, laxu_, _посљ, 
   {{0x4421e307,0x2249e308,0x7c840117,0x00000000}},	//   kij_, ilak_, _хубе, --, 
   {{0x4421e309,0x2249e30a,0x99dc0232,0x387de30b}},	//   jij_, hlak_, plňo, rpur_, 
   {{0x2249e30c,0x4421e30d,0x387de30e,0x7c21e30f}},	//   klak_, dij_, spur_, minr, 
   {{0x7c21e310,0x387de311,0x44200428,0x49d9e312}},	//   linr, ppur_, eij_, _وانگ_, 
   {{0x22481c06,0x210002d5,0x4421e313,0xd7f40150}},	//   dlak_, nčią_, fij_, _озды, 
   {{0x4421e314,0x3a3de315,0x660de316,0x7c20a1d6}},	//   gij_, loup_, _elak, ninr, 
   {{0x660c2b9d,0x3f90058a,0xc7b00a7c,0xd758007b}},	//   _flak, daxu_, _סבה_, _بلغت_, 
   {{0x2249e317,0x442001f5,0xc68c01f7,0x00000000}},	//   glak_, aij_, _ئِي_, --, 
   {{0x4421e318,0x7c21e319,0xa3d800ab,0x80d8084d}},	// [36680] bij_, kinr, _ठोक_, निषे, 
   {{0x44200f72,0x2249e31a,0x3f900009,0x5274004e}},	//   cij_, alak_, gaxu_, _оуму, 
   {{0x2249cc3f,0x3a3de31b,0xb8fc0135,0x660de31c}},	//   blak_, koup_, _སན_, _ylak, 
   {{0x9f5005d5,0x224800d5,0xb64000b5,0x4d4821fa}},	//   _dozà_, clak_, _ｃｏ_, опен_, 
   {{0xdd98007f,0x41744418,0x9e65e31d,0x764401f7}},	//   _alňs_, _تاپس, رامن, _mkiy, 
   {{0x7c21e31e,0x98b000bc,0x00000000,0x00000000}},	//   ginr, ůběh_, --, --, 
   {{0x76440083,0x00000000,0x00000000,0x00000000}},	//   _okiy, --, --, --, 
   {{0x442109cc,0x7645e31f,0xd5a847d0,0xddc805c7}},	//   zij_, _nkiy, _कागज, _cheń, 
   {{0x2fd80489,0xebc40daf,0x44200369,0x7b040064}},	//   _karg_, _зәйн, yij_, _įstū, 
   {{0x7645e320,0x2249e321,0x2fd8062c,0xc60400dc}},	//   _akiy, zlak_, _jarg_, शस्य_, 
   {{0xe8e007ae,0x2fd9e322,0x2249e323,0x44208a8a}},	//   _đổi_, _marg_, ylak_, vij_, 
   {{0x2fd9e324,0x0904c1ef,0x6dc405be,0x3a3c06af}},	//   _larg_, _опен, _učač, coup_, 
   {{0x4421e325,0x22480b4f,0x58e00150,0x3f900009}},	//   tij_, vlak_, _مۋيك, yaxu_, 
   {{0x76440a49,0x2249e326,0x64a40022,0x290400a2}},	//   _ekiy, wlak_, маҭа, myma_, 
   {{0x4421072a,0x660de327,0x3e740327,0x3f900113}},	//   rij_, _tlak, _oħta_, vaxu_, 
   {{0x660de328,0x4421e329,0x22480357,0x35f800c6}},	//   _ulak, sij_, ulak_, _يريد_, 
   {{0x2fd84b31,0x2905e32a,0x656de32b,0x2249e32c}},	// [36690] _barg_, nyma_, _igah, rlak_, 
   {{0x2249e32d,0x4420016d,0x200c0064,0xb03403c5}},	//   slak_, qij_, _įeis_, внуш, 
   {{0x656de32e,0x6445e32f,0x2905e330,0xa195e331}},	//   _kgah, _ikhi, hyma_, _панч, 
   {{0x1cb80491,0x2248011f,0x4430004d,0x7c200784}},	//   كاتب_, qlak_, _hjx_, winr, 
   {{0x2fd9e332,0xdb08031d,0x656d47bd,0x61fc9a14}},	//   _farg_, čníc, _mgah, _iosl, 
   {{0x2fd9e333,0x290400ee,0x61fddde6,0x3ea407de}},	//   _garg_, dyma_, _hosl, ànts_, 
   {{0x6445e334,0x7c21e335,0x656de336,0xdcf800b0}},	//   _mkhi, rinr, _ogah, tawē, 
   {{0x656de337,0xf8ac0517,0x7c213548,0x61fc005f}},	//   _ngah, لکت_, sinr, _josl, 
   {{0x6445e338,0x632c001f,0x2904b363,0x2fd80076}},	//   _okhi, ደሚጠበ, gyma_, _yarg_, 
   {{0x61fde339,0x656c0516,0x6445e33a,0x76440166}},	//   _losl, _agah, _nkhi, _skiy, 
   {{0x999000dd,0x868000b5,0x00000000,0x00000000}},	//   őző_, ni用p, --, --, 
   {{0x644444bf,0x61fc0029,0xd8740597,0x29051d00}},	//   _akhi, _nosl, _كاتب, byma_, 
   {{0x610c022e,0x00000000,0x00000000,0x00000000}},	//   _bўlm, --, --, --, 
   {{0x93442ba5,0x27fc0051,0xe8f80816,0x5ea400cc}},	//   енге, _govn_, _юлі_, _গৈছে, 
   {{0x61fd7f38,0x78b9e33b,0x7d040055,0x1aec0011}},	//   _bosl, ltuv, _hīrā, জনকে_, 
   {{0x78b80953,0x7645e33c,0x64440107,0x61fde33d}},	//   otuv, _ukiy, _ekhi, _cosl, 
   {{0x78b9e33e,0x64441132,0x00000000,0x00000000}},	// [366a0] ntuv, _fkhi, --, --, 
   {{0x9044bce4,0x61fc02d0,0x2fd801d5,0x0eb802dd}},	//   رناه, _eosl, _qarg_, зуды_, 
   {{0x78b81059,0x2fd9e33f,0x61fc0363,0x2905e340}},	//   htuv, _varg_, _fosl, zyma_, 
   {{0x61fde341,0x78b81d64,0xc278011a,0xa2c8012d}},	//   _gosl, ktuv, _מרטי, _हैट्, 
   {{0x2fd9e342,0x101402d5,0xb14400c7,0x4ec00154}},	//   _targ_, _зьвя, _рҽал, োমেল, 
   {{0xfbcc5734,0x628004d4,0x64440175,0x2ca00024}},	//   متى_, ílog, _xkhi, šido_, 
   {{0x61fc754d,0xbb8000d1,0xaa5800e5,0x78b800c0}},	//   _yosl, دلىي, ولتا_, etuv, 
   {{0x2905e343,0x6e21e344,0xc0e40014,0x48a89fad}},	//   tyma_, _ummb, _تکہٕ_, птом_, 
   {{0x7d0400b8,0xc0d00092,0x6bd4014b,0x78b80153}},	//   _cīrā, _ያነሰ_, _ақлӣ_, gtuv, 
   {{0x290400ee,0x00000000,0x00000000,0x00000000}},	//   ryma_, --, --, --, 
   {{0xfaa000c2,0x78b80b23,0x37a40137,0x76b40139}},	//   _бахо, atuv, хтын_, нлэр_, 
   {{0x6444009a,0x78b80153,0x00000000,0x00000000}},	//   _skhi, btuv, --, --, 
   {{0x65d80014,0x61fde345,0xe8e0004d,0xf9f80375}},	//   _लाà_, _rosl, _đỗi_, _מהאמ, 
   {{0x61fde346,0x69c0017a,0x00000000,0x00000000}},	//   _sosl, lfme, --, --, 
   {{0xf65000b2,0x236401e3,0xc30001e2,0x00000000}},	//   _ڏئي_, älj_, اړخی, --, 
   {{0x656c0230,0x61fdb17d,0x86f00451,0xd04403e3}},	//   _ugah, _qosl, _ليڪچ, _iskə, 
   {{0x61fc957c,0x69c00b4f,0x8004004e,0x00000000}},	// [366b0] _vosl, ifme, нчже, --, 
   {{0x64444b7a,0xb60400bc,0x00000000,0x00000000}},	//   _ukhi, rmář, --, --, 
   {{0x61fde347,0x78b83d4f,0x68e45c9a,0x00000000}},	//   _tosl, ztuv, _šidl, --, 
   {{0x78b8824d,0x69c001f5,0x61fc00c0,0x00000000}},	//   ytuv, jfme, _uosl, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x99dc0316,0xec280131,0xac191318,0xea680046}},	//   plňk, ىكنى_, ночу_, _ﺷﺎﺭﯞ, 
   {{0xdce800d0,0x201000ef,0x30344a1a,0x7d040055}},	//   _udeľ, _ilzi_, _серё, _sīrā, 
   {{0x78b9e348,0xaae54855,0x4ac000e1,0x7d0400e2}},	//   ttuv, اسوو, _शहरव, _pīrā, 
   {{0x78b8b0b9,0x2258022e,0x1a6407d6,0xf98400f1}},	//   utuv, _mhsk_, _ییتی_, ونډي_, 
   {{0x78b85c07,0xd7080b32,0x6bd46e1d,0x7d0400cd}},	//   rtuv, дное_, _متمر, _vīrā, 
   {{0x78b8db6c,0x19b80064,0x00000000,0x00000000}},	//   stuv, _жуль_, --, --, 
   {{0x78b80fda,0x3dcc0083,0xb8d403d4,0x7d058465}},	//   ptuv, negw_, _চন_, _tīrā, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2bc46ae8,0xe3b001d9,0x00000000,0x00000000}},	//   ल्पा, ٝرِ_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x20104d72,0xd13127e0,0x6d5c01e4,0x00000000}},	//   _alzi_, لمز_, _ŝram, --, 
   {{0x4124896b,0xd6c4044c,0x3e7406be,0xb0ac012d}},	// [366c0] вото_, _чиққ, _açt_, टूंग, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xaad000e1,0x00000000,0x00000000,0x00000000}},	//   _थैंक, --, --, --, 
   {{0xbea00c98,0xcd043004,0x5154a0d5,0x00000000}},	//   рацк, кпей, _атгу, --, 
   {{0xa154011c,0x00000000,0x00000000,0x00000000}},	//   _бърш, --, --, --, 
   {{0x8f741cb8,0x00000000,0x00000000,0x00000000}},	//   _шумі, --, --, --, 
   {{0x67d407d6,0xfbcc0f87,0x63a00034,0x6b980327}},	//   қону, زتو_, ólni, _ġagħ, 
   {{0xc33004ac,0x39a40241,0x69c0002f,0x00000000}},	//   יוו_, _rìsà_, ufme, --, 
   {{0xed5005d9,0xcb080451,0x5cc407fc,0x4784004e}},	//   _اھا_, _ڪيان_, _مغلق, кынб, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6594e380,0x7e780e04,0x4a7400c7,0x66b407e6}},	//   лану, _čupk, _рызт, ыбну, 
   {{0xa5f80c69,0xdd9800d0,0x6b995d41,0xc8c801e2}},	//   хему_, _koňa_, lavg, _يوان_, 
   {{0xb6c001c6,0xb6a00051,0xe50801f7,0x00000000}},	//   гөөд, _huấ, ريسو_, --, 
   {{0xecc4015b,0xc6e0031c,0x6b98e20c,0x00000000}},	//   _এছাড, ེའདུ, navg, --, 
   {{0x2bc40be7,0x9f500589,0x27f801a8,0xa7fc0342}},	//   ल्या, _kozå_, örnu_, rmıd, 
   {{0x6b9808cd,0xa7fc03e0,0x00000000,0x00000000}},	//   havg, smıd, --, --, 
   {{0x6b984cab,0x00000000,0x00000000,0x00000000}},	// [366d0] kavg, --, --, --, 
   {{0x4425e349,0x2bc43994,0xbf64ad19,0xa3d40261}},	//   _ön_, ल्मा, نداو, _сооч, 
   {{0x3f641925,0x00000000,0x00000000,0x00000000}},	//   ттаб, --, --, --, 
   {{0x9d14004e,0x00000000,0x00000000,0x00000000}},	//   лдеч, --, --, --, 
   {{0x3dcc00ca,0xada40953,0x3cf00490,0x361c0a7c}},	//   regw_, раіл, ंमधे_, וואד, 
   {{0x63b40399,0xcbb40116,0x18a495a1,0x6b980171}},	//   ngzn, лғуш_, ңайм, gavg, 
   {{0x63b4005f,0x6e947bde,0x80d82bf1,0x00000000}},	//   igzn, _вису, निके, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9bc40efb,0x610c01a9,0x49c5e34a,0x18680107}},	//   _مۇشە_, _bўli, улын_, наии_, 
   {{0x6bd400db,0xad240116,0x00000000,0x00000000}},	//   _ۅتۅر, _ئىكى, --, --, 
   {{0xd788021a,0x612801a9,0x966400d8,0x00000000}},	//   ونکو_, _hоld, лкое, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x98a5e34b,0xd39430cb,0x00000000,0x00000000}},	//   _силе, ләнә_, --, --, 
   {{0xf7710686,0x657c0009,0x3ae00139,0xe6a800db}},	//   _ئاش_, acsh, _kıp_, رچۉۉ_, 
   {{0x7bc0022f,0xb6a0004d,0x55e41188,0xd628014b}},	//   ifnu, _xuấ, _бойб, _поке_, 
   {{0x2215e34c,0x00000000,0x00000000,0x00000000}},	//   афур, --, --, --, 
   {{0x4fe9e34d,0x4638008f,0x3ae00166,0x6b980fac}},	// [366e0] нман_, _רעפע, _lıp_, yavg, 
   {{0x0c840150,0xdfa5e34e,0x00000000,0x00000000}},	//   ңылм, لحمي, --, --, 
   {{0xdd9893b8,0x0d843f67,0x03d4008f,0x3ae00139}},	//   _soňa_, глен, _גוים_, _nıp_, 
   {{0xad840075,0x3ea5e34f,0x516400db,0x0d2000db}},	//   рқай, ánta_, _бүбү_, бүбү, 
   {{0x7bc101c7,0xb6a00208,0x6b980162,0xdbd003b2}},	//   ffnu, _suấ, tavg, týðu, 
   {{0xd010240f,0x6ab800cc,0x99dc00d7,0x00000000}},	//   _الس_, _আনবো, voňa, --, 
   {{0x6b981f53,0x00000000,0x00000000,0x00000000}},	//   ravg, --, --, --, 
   {{0x6b982ff9,0xaa54026a,0x6128022e,0x00000000}},	//   savg, јвиш, _qоlg, --, 
   {{0x7e783324,0x390401c0,0xfce01d5b,0xa814005b}},	//   _čupi, гээн_, _лото, идиш, 
   {{0x99dc00d0,0x610c022e,0xb6a00051,0x7b0400e5}},	//   dlňu, _qўli, _tuấ, írtá, 
   {{0xf6700323,0x1cb00135,0x12d4015b,0x3ae00139}},	//   йгээ, _ཐའོ_, হমুদ, _gıp_, 
   {{0x78c40267,0x00000000,0x00000000,0x00000000}},	//   årvä, --, --, --, 
   {{0x27f86916,0x3ae00205,0x657c0332,0x2ca001e7}},	//   örns_, _zıp_, rcsh, áidh_, 
   {{0xf76c0014,0xdb0001e7,0x727800e4,0x68e40327}},	//   _ٹاو_, _gcló, _ẽkañ, _ġidh, 
   {{0xa2940006,0xbec400ef,0xbd801954,0x22940395}},	//   рабі, _kvīš, _ይጠቅም_, рибя, 
   {{0x2bc40034,0xe1341952,0xc2541e4b,0x00000000}},	//   ल्ता, анбы, اخست, --, 
   {{0x36350d72,0x1cb00003,0x3fa80640,0x32d80133}},	// [366f0] _دروس, _ཐའེ_, ењем_, نگێک_, 
   {{0xf0e80058,0x351c0375,0xf954011a,0x00000000}},	//   دىكى_, _רוזנ, רסמת_, --, 
   {{0xef1400f7,0x63a4036e,0x3ad403b9,0x25083fe6}},	//   бүрө, _idhn, _təpə_, _سرکی_, 
   {{0x6285e350,0x22a00024,0x3ae00139,0x6e940022}},	//   _itho, mėk_, _rıp_, сицу, 
   {{0x7ae00218,0x62840165,0x6128022e,0x22a00153}},	//   wvnt, _htho, _qоld, lėk_, 
   {{0x628403a2,0xfe700214,0x00000000,0x00000000}},	//   _ktho, _هدر_, --, --, 
   {{0x62840b4b,0x63a401d5,0x22a000c0,0x00000000}},	//   _jtho, _mdhn, nėk_, --, 
   {{0x6285e351,0x1a047863,0xdb000332,0xde5800c0}},	//   _mtho, рпим, _scló, _рабі_, 
   {{0x62840477,0x80d8858c,0x98a4010a,0x7bc0002f}},	//   _ltho, निटे, шипе, pfnu, 
   {{0x3ae06648,0x3ddc0036,0x5824026b,0xd82400c7}},	//   _tıp_, _hauw_, рмоб, рдои, 
   {{0x6285e352,0x99f40953,0x3ddc01f5,0xcfb40375}},	//   _ntho, _вялі, _kauw_, בלתי_, 
   {{0x63a44230,0x22a00153,0xd6280114,0x00000000}},	//   _adhn, dėk_, томе_, --, 
   {{0x6285e353,0x661c02d3,0x98d8012c,0x99dc0306}},	//   _atho, ërka, _भनिए, loňo, 
   {{0x7999e354,0x3ddc01a4,0x27300137,0x00000000}},	//   lauw, _lauw_, تۉۉس, --, 
   {{0x5275646b,0x62840200,0xc7b0011a,0xb3800023}},	//   ругу, _ctho, _ובו_, ሓሕዛን_, 
   {{0x99dc0122,0x3ddc0d27,0xcb1000c8,0xd185c778}},	//   plňu, _nauw_, קלן_, рлай, 
   {{0x6285e355,0xd0247d9d,0x112c0092,0xc0e001f4}},	// [36700] _etho, амай, _በመዲና, оотк, 
   {{0x8fa43b78,0x799802b5,0x2174024c,0x80a404e4}},	//   раже, hauw, _ҳурр, _चिरे, 
   {{0x81c88961,0x7998601a,0xe0480ec9,0x2bdc012c}},	//   লয়_, kauw, اشقه_, _यसबा, 
   {{0x9e65e356,0x217409a5,0xcd047e7e,0x91e4d450}},	//   مانن, _гурр, ичли, _томе, 
   {{0x2ca00597,0x79980086,0x3ddc77d0,0xcd3400be}},	//   éid_, dauw, _dauw_, جراب, 
   {{0x8aa4006c,0x628403ac,0xbec40171,0x00000000}},	//   арид, _ytho, _svīš, --, 
   {{0x7b60005b,0x3ea13da1,0x00000000,0x00000000}},	//   отъе, _мирг, --, --, 
   {{0x3ddc0196,0x79980086,0xd01005d9,0xc03c0092}},	//   _gauw_, gauw, _الڳ_, ናገረው, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x99dc00d7,0x00000000,0x00000000,0x00000000}},	//   boňo, --, --, --, 
   {{0x79980112,0x00000000,0x00000000,0x00000000}},	//   bauw, --, --, --, 
   {{0x62840055,0x06245265,0x00000000,0x00000000}},	//   _rtho, рфом, --, --, 
   {{0x62841368,0x47841e35,0x00000000,0x00000000}},	//   _stho, _кыйб, --, --, 
   {{0x6284003a,0x2814129d,0x158c00d1,0x00000000}},	//   _ptho, _دوتس, _ﻛﯩﺘﯩ, --, 
   {{0x99dc0232,0x46d802e5,0x00000000,0x00000000}},	//   plňt, _बनिह, --, --, 
   {{0xdd9800e8,0x058448bc,0x00000000,0x00000000}},	//   _roňo_, _тукм, --, --, 
   {{0x3ddd522f,0x7178013d,0x00000000,0x00000000}},	// [36710] _rauw_, рбур_, --, --, 
   {{0x3ea56355,0x79980210,0x22a000c0,0x00000000}},	//   ánto_, zauw, pėk_, --, 
   {{0x6285e357,0xc0dc044e,0x3ddc0373,0xdd90007b}},	//   _utho, _ነዞም_, _pauw_, كوا_, 
   {{0x7d08049f,0x25b80008,0x00000000,0x00000000}},	//   tygs, ngsl_, --, --, 
   {{0x224801c0,0x7d080477,0x00000000,0x00000000}},	//   moak_, uygs, --, --, 
   {{0x7999e358,0x60dde359,0x224801c0,0x3ddde35a}},	//   wauw, _issm, loak_, _wauw_, 
   {{0x9f04036b,0x3e68010b,0x3e74031c,0x79993d93}},	//   _اوزو, _ашан_, _oħti_, tauw, 
   {{0x224805f5,0x5c74119e,0x00000000,0x00000000}},	//   noak_, _глат, --, --, 
   {{0x2bc40574,0x1cb00135,0x9d15e35b,0x799819a2}},	//   ल्हा, _ཐའི_, _удач, rauw, 
   {{0x7999e35c,0x60dc010a,0x2249e35d,0xdd98010e}},	//   sauw, _mssm, hoak_, _heň_, 
   {{0x2248152d,0x7998079b,0xddc80083,0xa6b40108}},	//   koak_, pauw, _nkeŋ, осящ, 
   {{0x22482574,0xd6180133,0x60dc035a,0xdd98010e}},	//   joak_, اتدا_, _ossm, _jeň_, 
   {{0xddc80083,0x224801c0,0x261800e1,0xd7c80753}},	//   _akeŋ, doak_, _पतरी_, _موشه_, 
   {{0x67d40798,0xa7fc0166,0x00000000,0x00000000}},	//   _мочу, lmın, --, --, 
   {{0x60dc0857,0x2248009d,0x6abc01e3,0x6280010f}},	//   _assm, foak_, _ärft, ŭlon, 
   {{0x224805f5,0x00000000,0x00000000,0x00000000}},	//   goak_, --, --, --, 
   {{0x51543b78,0x60dc010a,0x4878008f,0xe73801e4}},	// [36720] ству, _cssm, ָטעס, raĵe_, 
   {{0x51540107,0x8d840133,0x54341888,0xc95000d9}},	//   атҷу, ڕشتن, _دربر, למן_, 
   {{0x224805f5,0x610c01a9,0x8d85d4c5,0x60dc035a}},	//   boak_, _bўls, булд, _essm, 
   {{0x22480263,0xa6c000a2,0x00000000,0x00000000}},	//   coak_, _çöşl, --, --, 
   {{0xdd99e35e,0x2b980022,0x6fd80cb4,0xd478008f}},	//   _deň_, акль_, ड़दं, נאַל, 
   {{0x9f51e35f,0x9cb000cf,0x00000000,0x00000000}},	//   _onzè_, بۅكت, --, --, 
   {{0x8ae402bf,0xdce80115,0x2618023e,0x00000000}},	//   сілл, _reeĥ, _पतली_, --, 
   {{0x60dc00b5,0xdd9800ee,0x5ba40116,0x9e7000db}},	//   _yssm, _geň_, бләғ, _قۇلت, 
   {{0x0948005b,0x00000000,0x00000000,0x00000000}},	//   ычки_, --, --, --, 
   {{0x224805f5,0x6d400857,0xa7fc0342,0xdd9800a2}},	//   zoak_, _ixma, amın, _zeň_, 
   {{0x661c044e,0x28d800e1,0xe75800d4,0x49c800fb}},	//   ërko, _बैरि, рині_, _булм_, 
   {{0xc95807d6,0x224801c0,0x2ca005be,0xb990009f}},	//   _йўл_, xoak_, šidu_, _فلمب, 
   {{0x22480109,0x3ce823ef,0x00000000,0x00000000}},	//   voak_, चिये_, --, --, 
   {{0x26dc0099,0x60dc0c6a,0xaa4400db,0x49903737}},	//   _tsvo_, _rssm, _انچى, _بیکر, 
   {{0x9f4002d3,0x224801c0,0xa7fc0205,0x00000000}},	//   rdhë_, toak_, lmıo, --, 
   {{0xb6840451,0x00000000,0x00000000,0x00000000}},	//   _اپيل_, --, --, --, 
   {{0x224805f5,0x60f94cb6,0xdd98010e,0x00000000}},	// [36730] roak_, шная_, _reň_, --, 
   {{0x24881574,0x224805f5,0xef980137,0xdd98010b}},	//   _itam_, soak_, йкуш_, _seň_, 
   {{0x6d41e360,0x9ed9e361,0x224801c6,0x998c0306}},	//   _axma, рмет_, poak_, hneš_, 
   {{0x6455e362,0x6b84005e,0x998c23cc,0x9f4000f2}},	//   llzi, ۋشىل, kneš_, ndhé_, 
   {{0x60dc02d0,0x00000000,0x00000000,0x00000000}},	//   _ussm, --, --, --, 
   {{0x2bc4038e,0x998de363,0xdd98002e,0xddc80356}},	//   ल्ला, dneš_, _weň_, _bieţ, 
   {{0xe9a83955,0x661c05be,0x248801c7,0x9f40020c}},	//   ڭدىن_, khsk, _ltam_, kdhé_, 
   {{0x25a95102,0x248801b9,0x6128022e,0xfca801c8}},	//   _ndal_, _otam_, _zоla, _مائو_, 
   {{0x2488013b,0x16d000dc,0x99d400f2,0x00000000}},	//   _ntam_, तब्ब, متکا, --, 
   {{0xd82400d6,0x25a9e364,0xa7fc03ee,0x2bb8007b}},	//   ідни, _adal_, smın, _هامة_, 
   {{0xfaa446e8,0x2489e365,0xda080ccb,0x645400d7}},	//   _ышан, _atam_, _پيشه_, dlzi, 
   {{0x6454002f,0x6d40007c,0x00000000,0x00000000}},	//   elzi, _yxma, --, --, 
   {{0x9554b8c6,0x25a80368,0x6d400072,0xdc900023}},	//   تخدا, _ddal_, _xxma, _ዚነበረ_, 
   {{0x25a802d2,0x00000000,0x00000000,0x00000000}},	//   _edal_, --, --, --, 
   {{0x1cd8b444,0x2489e366,0x25a8025c,0xdb0002fb}},	//   _འགའ_, _etam_, _fdal_, _odlí, 
   {{0x661c0385,0x6455e367,0x2c60067c,0x862402dd}},	//   chsk, alzi, mòde_, _وبيە, 
   {{0xd0112272,0x387c89b9,0xe73801e4,0x09bc0154}},	// [36740] ولر_, nqur_, maĵa_, _আসমা, 
   {{0xe73801e4,0x263c010f,0x25a800d7,0x00a40150}},	//   laĵa_, nĉon_, _zdal_, _ﺷﻪﺗﺘ, 
   {{0x3e74031c,0x387c022e,0x59d8000d,0x0eb80108}},	//   _oħtu_, hqur_, ढ़ार, рузы_, 
   {{0xe7380115,0x00000000,0x00000000,0x00000000}},	//   naĵa_, --, --, --, 
   {{0x8c940220,0x2b5801a6,0xfbcc2374,0xe8e00051}},	//   ірді, _šrc_, چتى_, _đỏi_, 
   {{0xfbcd29e6,0xddc80276,0x80d000db,0x2c60007f}},	//   نتى_, _pieţ, _تۅكچ, kòde_, 
   {{0xdb00030a,0xe73801e4,0x09bc0154,0x00000000}},	//   _adlâ, kaĵa_, _আসবা, --, 
   {{0xddc8084c,0xe8f801e0,0x3ea5e368,0x2bdc0709}},	//   _vieţ, йһе_, ânte_, _यसवा, 
   {{0x1cd80003,0xe73801e4,0x6d40031c,0x693401e0}},	//   _འགར_, daĵa_, _uxma, яниу, 
   {{0x998c0010,0xa9c400cf,0x00000000,0x00000000}},	//   rneš_, تۅچۉ, --, --, 
   {{0x2489e369,0x25a80077,0x998c0427,0xfaa0d43a}},	//   _stam_, _pdal_, sneš_, _жахо, 
   {{0xa4d40212,0xe73801e4,0xe81c23ef,0x248801ef}},	//   помі, gaĵa_, _फतवा_, _ptam_, 
   {{0xb3e402f5,0x25a80010,0x093496d3,0x34940209}},	//   মানজ, _vdal_, _براج, маяр, 
   {{0xddc80030,0xf76c2e3e,0x2c61e36a,0x00000000}},	//   _mieš, عای_, bòde_, --, 
   {{0xddc80171,0x00000000,0x00000000,0x00000000}},	//   _lieš, --, --, --, 
   {{0x25a805f5,0x06640c75,0x00000000,0x00000000}},	//   _udal_, _باتپ, --, --, 
   {{0x20000117,0x161402dd,0x00000000,0x00000000}},	// [36750] tjhi_, _ءسىڭ, --, --, 
   {{0x7428007b,0x00000000,0x00000000,0x00000000}},	//   _وكيف_, --, --, --, 
   {{0x80a41d8a,0x153804d3,0x88c00eac,0x81740117}},	//   _चिके, _نزیک_, ্টিক, _манӣ_, 
   {{0xddc80171,0x8d8c0150,0x00000000,0x00000000}},	//   _bieš, _ﺟﯩﺮﺕ_, --, --, 
   {{0xddc8005f,0x00000000,0x00000000,0x00000000}},	//   _cieš, --, --, --, 
   {{0x6d7c0023,0x5a940120,0xaadc01f9,0x00000000}},	//   _ብዓውታ_, приф, _मनशक, --, 
   {{0x60d80259,0xdd944f35,0xbdd401d5,0x00000000}},	//   şamı, _навы, _وآرت, --, 
   {{0x41c8043e,0x68e4031c,0x2cb00b97,0x00000000}},	//   ाभिस, _ġidr, üldü_, --, 
   {{0x263c0115,0xe73801e4,0x00000000,0x00000000}},	//   tĉon_, vaĵa_, --, --, 
   {{0x2c60180f,0x65b401a9,0xac7400db,0xa7fc0139}},	//   tòde_, _sоhа, _قالش, lmıj, 
   {{0xfa8001b9,0xec2400f7,0x263c00df,0xe7380115}},	//   _ўқим, _تىلپ, rĉon_, taĵa_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xea640014,0xe73801e4,0x00000000,0x00000000}},	//   _تھوی, raĵa_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x662801bf,0x00000000,0x00000000,0x00000000}},	//   øskø, --, --, --, 
   {{0x395c00b7,0x15441cc2,0xc6c40327,0x00000000}},	//   _ወታደራ, _нейм, _ཀྱིུ, --, 
   {{0x2bdc0316,0x00000000,0x00000000,0x00000000}},	// [36760] _यसला, --, --, --, 
   {{0xddc8247c,0x52746191,0xbd0000bc,0x05600139}},	//   _rieš, _нуму, _mléč, _явын, 
   {{0x6128022e,0x8d84010b,0xddc800de,0x00000000}},	//   _hоll, пулд, _sieš, --, 
   {{0xddc9e36b,0x612801a9,0xadb8129d,0x00000000}},	//   _pieš, _kоll, تۇرا_, --, 
   {{0xafc40032,0xd7bc01f9,0x00000000,0x00000000}},	//   _оҙай, ्भाच, --, --, 
   {{0xddc80953,0x00000000,0x00000000,0x00000000}},	//   _vieš, --, --, --, 
   {{0xad88013e,0x46d80037,0x00000000,0x00000000}},	//   _мавҷ_, _बनइह, --, --, 
   {{0xddc80029,0x2d8001a2,0xa4f00006,0x7f38011a}},	//   _tieš, žieb_, _lėšų_, _העלו, 
   {{0x0c24bdd4,0xa7fc0205,0xa40c000d,0x00000000}},	//   _еман, smım, _सकलप_, --, 
   {{0x9f500789,0x8ba41513,0xead001ee,0x5c140354}},	//   _gozó_, _хижж, _аҡкө, _оьху, 
   {{0x1cd86d7e,0xfcc80020,0x9ba005a9,0xfb10237e}},	//   _འགོ_, አዴግ_, _شەيى, _كوكج, 
   {{0xf76c275c,0x3ea401d3,0xba1400cf,0xb0ac0401}},	//   داً_, ánti_, _ىيلا_, _चिंग, 
   {{0xe80c00bc,0x00000000,0x00000000,0x00000000}},	//   ाउदा_, --, --, --, 
   {{0x28c000d1,0x00000000,0x00000000,0x00000000}},	//   _ﻣﻪﺳﻠ, --, --, --, 
   {{0xe73800df,0x86140117,0x00000000,0x00000000}},	//   maĵo_, _некӣ_, --, --, 
   {{0x754801ed,0xe738008f,0x76b8011a,0x00000000}},	//   észé, laĵo_, _המהפ, --, 
   {{0x838411ed,0xf0d401c0,0x1cd80327,0x00000000}},	// [36770] _ныне, нжтэ, _འགེ_, --, 
   {{0xe73800c8,0x3f640276,0x00000000,0x00000000}},	//   naĵo_, птеб, --, --, 
   {{0x3ea4066d,0x6d5c01e4,0x00000000,0x00000000}},	//   ént_, _ŝrap, --, --, 
   {{0x5d3411c7,0xe3f801f7,0x00000000,0x00000000}},	//   وفائ, _اوڍڻ_, --, --, 
   {{0xe738008f,0xac8402dd,0x23b00210,0x00000000}},	//   kaĵo_, егіл, _जयाद, --, 
   {{0xa3cc2208,0x80d002f5,0xe73801e4,0xadbc02dd}},	//   रभि_, সিদ্, jaĵo_, _қауi, 
   {{0x62800232,0xcb64ec43,0xaed5e36c,0xe738008f}},	//   íloh, маше_, _порш, daĵo_, 
   {{0x6aa83ddd,0x00000000,0x00000000,0x00000000}},	//   _dvdf, --, --, --, 
   {{0x97a46073,0xa3cc2894,0xe7380115,0x7c642586}},	//   үрүл, रभा_, faĵo_, _فائل, 
   {{0xe738010f,0xdcac00cf,0x00000000,0x00000000}},	//   gaĵo_, _مۉچ_, --, --, 
   {{0x57480138,0x00000000,0x00000000,0x00000000}},	//   юзом_, --, --, --, 
   {{0xcb10025f,0x2c60067c,0x00000000,0x00000000}},	//   _שלא_, mòda_, --, --, 
   {{0x65f801c0,0xe73800df,0x2bc441ac,0x00000000}},	//   чээр_, baĵo_, ल्का, --, 
   {{0xe73801e4,0x263c010f,0xc7cc0051,0x80d40d2e}},	//   caĵo_, nĉoj_, _hống_, डबैं, 
   {{0xa6a80b24,0x55e400db,0x78b85979,0xed740023}},	//   _فايق_, _жойб, luuv, እስተይ_, 
   {{0xdbc800c5,0xb9d80023,0xe72400d4,0x00000000}},	//   mõõd, _ቡን_, _яєчн, --, 
   {{0x263c00df,0xc7cc0208,0x7d0400ef,0x4fa400f0}},	// [36780] kĉoj_, _mống_, _jūrā, дизв, 
   {{0x78b80093,0xe1f80107,0x00000000,0x00000000}},	//   iuuv, огӣ_, --, --, 
   {{0x1cd80135,0x09bc015b,0x99dc02f0,0x3ea001c6}},	//   _འགུ_, _আসসা, loňu, вихг, 
   {{0x78b820ac,0xe738008f,0x3ea40276,0x2c600086}},	//   kuuv, zaĵo_, ânta_, dòda_, 
   {{0x78b8013c,0x20d4177b,0xe820012c,0x00000000}},	//   juuv, _пірс, यसमा_, --, 
   {{0x09c400dc,0x6aa802d0,0xa7fc0205,0x8fd001ee}},	//   लभ्य, _pvdf, rmık, _шәбә, 
   {{0x2bc44a8d,0xc7cc004d,0xe738008f,0x00000000}},	//   ल्गा, _bống_, vaĵo_, --, 
   {{0xc7cc001e,0xe820443a,0x48a8ac29,0x00000000}},	//   _cống_, यसभा_, отом_, --, 
   {{0xe73800c8,0xec340e2c,0x78b80140,0xba7002f2}},	//   taĵo_, _كورگ, guuv, خاوت, 
   {{0x7d0400cd,0x00000000,0x00000000,0x00000000}},	//   _dūrā, --, --, --, 
   {{0xe738008f,0xa635b71e,0x76b40139,0x00000000}},	//   raĵo_, енні, млэр_, --, 
   {{0xe738010f,0x00000000,0x00000000,0x00000000}},	//   saĵo_, --, --, --, 
   {{0xe738010f,0x45480eed,0xd6c40133,0x00000000}},	//   paĵo_, ючом_, ومیی, --, 
   {{0x9f6400e5,0x00000000,0x00000000,0x00000000}},	//   űtés_, --, --, --, 
   {{0x6adc0bc0,0x45042f8b,0xf6e00022,0x69c0017a}},	//   _मनोर, _লেখক_, _ацын, ogme, 
   {{0x69c00978,0xc64400db,0x80d000eb,0x00000000}},	//   ngme, _تئتى, সিস্, --, 
   {{0x0464f112,0x3135e36d,0x69c00024,0xf6540375}},	// [36790] _отом, ветр, igme, _בצק_, 
   {{0x660c123c,0x1ae4009e,0x00000000,0x00000000}},	//   _hoak, কমতে_, --, --, 
   {{0x660de36e,0x33580137,0x68e00142,0x81e400cc}},	//   _koak, _жүрө_, hwmd, পাব_, 
   {{0x44200455,0x932405af,0x00000000,0x00000000}},	//   lhj_, _سرپن, --, --, 
   {{0xfcc80020,0x660de36f,0x2c600428,0x69c1e370}},	//   _አደጋ_, _moak, wòda_, dgme, 
   {{0xc7cc01dc,0x660de371,0x200400af,0x69c0017a}},	//   _sống_, _loak, _õli_, egme, 
   {{0x263c00df,0x38100133,0x00000000,0x00000000}},	//   rĉoj_, ێژتر, --, --, 
   {{0x7d0404fe,0x1a64006c,0x69c01f53,0x660c005c}},	//   _pūrā, ریشی_, ggme, _noak, 
   {{0x2d500e53,0x1cd8031c,0x4420037e,0x9cb41867}},	//   _پێوس, _འགི_, khj_, _سمات, 
   {{0xddc801a2,0x660de372,0x6678001f,0x78b9e373}},	//   _dieť, _aoak, _ከተማዋ_, ruuv, 
   {{0xe3180156,0x660de374,0xc7cc001e,0x78b80869}},	//   ུགསཔ_, _boak, _tống_, suuv, 
   {{0xc7cc07ae,0x660c020b,0x7d0402b5,0x06042d29}},	//   _uống_, _coak, _tūrā, енюк_, 
   {{0x660c7db9,0x2a780ba1,0x25e00037,0x00000000}},	//   _doak, _èrba_, _ओघरी_, --, 
   {{0x442019f5,0xeee0000d,0x28d80210,0x00000000}},	//   ghj_, _गईलऽ_, _बैटि, --, 
   {{0x660c03c1,0xaca40521,0x3a3c0356,0x2bc43507}},	//   _foak, mpụt, onup_, ल्टा, 
   {{0x660c0109,0x3a3c0140,0xc690011a,0xc68c01c8}},	//   _goak, nnup_, _גאה_, _اِي_, 
   {{0xdb00037e,0x76440248,0x798802d0,0xe084007b}},	// [367a0] _udlæ, _ijiy, _mfgw, نجلي, 
   {{0xbfc03a32,0x44200036,0x00000000,0x00000000}},	//   лбук, chj_, --, --, 
   {{0xa30196b4,0x68e00175,0x7c21e375,0xa3cccc83}},	//   _күре, zwmd, dhnr, रभर_, 
   {{0x9e6433d2,0x00000000,0x00000000,0x00000000}},	//   نانن, --, --, --, 
   {{0x01a400c6,0x644000bc,0x09bc0154,0xb81c00bc}},	//   _якяк_, čliv, _আসলা, मघाम_, 
   {{0xd0540134,0x0ba80c75,0xdcac00f7,0x00000000}},	//   _ɔbɛy, ساتى_, زۉم_, --, 
   {{0xddc801f1,0x78a80393,0x00000000,0x00000000}},	//   _sieť, _avgv, --, --, 
   {{0x69c000ca,0xd9b016a0,0x2bc405d7,0x3a3de376}},	//   ugme, لەمد, ल्जा, gnup_, 
   {{0x69c1e377,0xc7c405f5,0x660c00b0,0x6e2002d2}},	//   rgme, нсни, _roak, _ilmb, 
   {{0x660de378,0x764423db,0x386401ab,0xa81401b9}},	//   _soak, _ajiy, _chnr_, тдош, 
   {{0x81e40c58,0x6595e379,0x660cb5b4,0x2cb00006}},	//   পাত_, кану, _poak, žodį_, 
   {{0x660c01ee,0xdcec0153,0x4a444316,0x67a40092}},	//   _qoak, škąj, _янев, _ለአዲሱ_, 
   {{0x660c0170,0x6ab800cc,0x00000000,0x00000000}},	//   _voak, _আনটো, --, --, 
   {{0x76440b6f,0x660c016b,0x3e640037,0x3b500354}},	//   _ejiy, _woak, mõte_, _лкĕр, 
   {{0x660de37a,0x22580108,0x290406be,0x00000000}},	//   _toak, дивы_, lxma_, --, 
   {{0xdb00000f,0x6ec401f9,0x00000000,0x00000000}},	//   _belê, ांनु, --, --, 
   {{0x661c0023,0x2904000f,0x1b540092,0x00000000}},	// [367b0] ërku, nxma_, _ሜድትራ, --, 
   {{0xd9dc858c,0x00000000,0x00000000,0x00000000}},	//   _मस्ट, --, --, --, 
   {{0xafc42e51,0xdd91e37b,0x4430198f,0x612801a9}},	//   ايمى, لوا_, _imx_, _mоli, 
   {{0xee3802bf,0x7cf806ea,0x6295e37c,0x00000000}},	//   ннє_, jørð, mpzo, --, 
   {{0x61ec01c5,0x61fde37d,0x6e2001ab,0x44300bfa}},	//   mdal, _insl, _dlmb, _kmx_, 
   {{0x61ede37e,0x21298830,0x6e20af7b,0x44300076}},	//   ldal, mzah_, _elmb, _jmx_, 
   {{0x60cde37f,0x4431e380,0x26cc036e,0x9f340212}},	//   ltam, _mmx_, jtdo_, _реві, 
   {{0x9f50025a,0x60cde381,0x7cf80174,0xf8ac00f2}},	//   _bozö_, otam, gørð, مکت_, 
   {{0x5c75b288,0x60cc6a3a,0x2128020b,0x44303bb7}},	//   _алат, ntam, nzah_, _omx_, 
   {{0x60cde382,0x644402b9,0x61ec02f6,0x212805b1}},	//   itam, _njhi, hdal, izah_, 
   {{0x60cde383,0x7e7801f7,0xb6040118,0x998c054e}},	//   htam, _kiup, hlář, cheş_, 
   {{0x60cde384,0x4431e385,0x61ede386,0x199402bf}},	//   ktam, _amx_, jdal, _радя, 
   {{0x61ed4e54,0x60cde387,0x271c004d,0xf8ac01d5}},	//   ddal, jtam, ản_, _اکب_, 
   {{0x7bc1e388,0x21280a2e,0x61fde389,0x6824026c}},	//   ngnu, dzah_, _ansl, _còdd, 
   {{0x03a1d323,0xd2503520,0x443000ae,0xdb000798}},	//   рисо, لنس_, _dmx_, _selê, 
   {{0xc2406b9c,0x61ede38a,0x7e79e38b,0x60cde38c}},	//   анск, gdal, _niup, ftam, 
   {{0x60cc286b,0x7ae001ee,0x90446ea9,0xfbb0024a}},	// [367c0] gtam, hwnt, پناه, ीलाम, 
   {{0x61fde38d,0x61ede38e,0x224c05ce,0x44300e78}},	//   _ensl, adal, čeka_, _gmx_, 
   {{0x60cde38f,0x1ea831ed,0x61ede390,0x69dc013f}},	//   atam, فاني_, bdal, ɑref, 
   {{0x7e78084c,0x71740952,0x60cc5284,0x61ec058a}},	//   _ciup, _مۇزا, btam, cdal, 
   {{0x60cc00cf,0x6cd42ba5,0xc5f0008d,0x628001e4}},	//   ctam, اقتا, ידא_, ŭlot, 
   {{0x3e6400af,0xdb0150d1,0x417401ec,0x5045e391}},	//   võte_, _kelè, _جاپس, _регб, 
   {{0xaa59e392,0xbea1e393,0xfaa1e394,0x61fc045f}},	//   нику_, _васк, ашын, _ynsl, 
   {{0x7e782819,0xdb01e395,0x68241c69,0x6128022e}},	//   _giup, _melè, _mòde, _sоli, 
   {{0xfce1e396,0x48c003f4,0x693404d3,0x9f480793}},	//   _кото, ্ট্র, دکار, üköl_, 
   {{0x61ede397,0x6128022e,0x00000000,0x00000000}},	//   zdal, _qоli, --, --, 
   {{0x61ed9e95,0x26d85b5e,0x21292ae9,0x27fc0051}},	//   ydal, ïro_, zzah_, _vnvn_, 
   {{0x60cde398,0xa7fc62c7,0x2128a7a4,0x61ec5e47}},	//   ytam, klıg, yzah_, xdal, 
   {{0x67d47d0b,0x60cde399,0xcc8800b8,0x27fc0208}},	//   _болу, xtam, _dṛg_, _tnvn_, 
   {{0xdb00067c,0x998c00d7,0x00000000,0x00000000}},	//   _belè, mieš_, --, --, 
   {{0xdb00180f,0x6824068c,0x81e4015b,0x3358084c}},	//   _celè, _còde, পাস_, варэ_, 
   {{0x61ede39a,0xdb01e39b,0xcc8800b8,0xa7fc0166}},	//   udal, _delè, _kṛd_, flıg, 
   {{0x61ede39c,0xceb5e39d,0x7e78004e,0xa7fc0205}},	// [367d0] rdal, һәт_, _riup, glıg, 
   {{0x60cde39e,0x61ede39f,0x661de3a0,0x7e7803a0}},	//   rtam, sdal, lksk, _siup, 
   {{0x60cde3a1,0x6455e3a2,0xceb4d074,0x63a40649}},	//   stam, mozi, ләт_, _iehn, 
   {{0x60cde3a3,0xbb200201,0x63a4006a,0xa7fc723e}},	//   ptam, ታውቀዋ, _hehn, llıd, 
   {{0x91b80302,0x6284533a,0x60ccf071,0x63a4005b}},	//   _אמרי, _huho, qtam, _kehn, 
   {{0x6285e3a4,0x645405b8,0xa7fc3361,0x9c640214}},	//   _kuho, nozi, nlıd, دهتو, 
   {{0x63a5e3a5,0x7e79e3a6,0x661cf905,0x6285e3a7}},	//   _mehn, _tiup, kksk, _juho, 
   {{0x63a5e3a8,0x6285e3a9,0x64557efa,0x661c01a4}},	//   _lehn, _muho, hozi, jksk, 
   {{0x6455e3aa,0xa7fc0365,0x2011e3ab,0x62843ce3}},	//   kozi, klıd, _kozi_, _luho, 
   {{0xdb01e3ac,0x63a5e3ad,0x2011e3ae,0x6285e3af}},	//   _lelé, _nehn, _jozi_, _ouho, 
   {{0x6285e3b0,0x2011e3b1,0x998c0427,0xa7fc03b9}},	//   _nuho, _mozi_, mnež_, dlıd, 
   {{0xdb01e3b2,0x63a40d16,0x6824067c,0x2259e3b3}},	//   _relè, _aehn, _ròde, _nksk_, 
   {{0x63a5e3b4,0x7999e3b5,0x628400b0,0x20100798}},	//   _behn, mbuw, _auho, _oozi_, 
   {{0x6455e3b6,0x6285e3b7,0x63a40369,0x201016a3}},	//   gozi, _buho, _cehn, _nozi_, 
   {{0x63a5e3b8,0xdb01e3b9,0x7a440064,0x00000000}},	//   _dehn, _belé, pūtę, --, 
   {{0xdb01e3ba,0x661d71ec,0xb3e4015b,0xd1740d31}},	//   _celé, cksk, মাইজ, гызы, 
   {{0x6455e3bb,0x4125e3bc,0x6284003a,0xdb00020c}},	// [367e0] bozi, гото_, _euho, _welè, 
   {{0xdb01e3bd,0x78b80d04,0xa7fde3be,0x645409b1}},	//   _telè, iruv, rlıg, cozi, 
   {{0x62841389,0x2011e3bf,0xb4e40882,0xdb0000dd}},	//   _guho, _dozi_, _ननु_, _felé, 
   {{0xdb01e3c0,0x63a5e3c1,0xa7fc0213,0x78b8ff6c}},	//   _gelé, _zehn, nmır, kruv, 
   {{0xc0f40020,0xcd34527d,0xf078013d,0x00000000}},	//   ወቃል_, دراب, _җиңә_, --, 
   {{0x78b9e3c2,0x998cb36f,0x628400b5,0x2011e3c3}},	//   druv, vieš_, _yuho, _gozi_, 
   {{0xfbcd042c,0x81e400bd,0xc9842bf6,0x661de3c4}},	//   ستو_, পার_, лупи, yksk, 
   {{0x6455e3c5,0xd90c04d3,0x7999e3c6,0x637000e4}},	//   zozi, ژین_, gbuw, ẽngu, 
   {{0x6455e3c7,0x998c0010,0x201001a9,0xa3e401ad}},	//   yozi, bnež_, _yozi_, _नसल_, 
   {{0x7998022f,0x998c00d0,0x07e40114,0x00000000}},	//   abuw, rieš_, уцим, --, 
   {{0x6455e3c8,0xbc7016ef,0x63a5e3c9,0x799800e8}},	//   vozi, _اهلب, _rehn, bbuw, 
   {{0x6285e3ca,0x63a5e3cb,0xca7400fd,0x661c0165}},	//   _ruho, _sehn, _сузы, uksk, 
   {{0x661de3cc,0x6455e3cd,0x6285e3ce,0x1cd8031c}},	//   rksk, tozi, _suho, _འགབ_, 
   {{0x6285e3cf,0xdb01e3d0,0xa7fc7975,0x2258030a}},	//   _puho, _selé, rmıs, _sksk_, 
   {{0x443c1326,0x2010036b,0x63a4023a,0xa7fc1cce}},	//   đu_, _rozi_, _vehn, rlıd, 
   {{0x628418f7,0x63a47e42,0x855401ed,0x998c0010}},	//   _vuho, _wehn, _میجر_, znež_, 
   {{0x6455e3d1,0x2011e3d2,0x62840280,0xa7fc08a9}},	// [367f0] pozi, _pozi_, _wuho, mlıb, 
   {{0x6285e3d3,0xa7fde3d4,0xdb0000d5,0xf49401ec}},	//   _tuho, qlıd, _welé, _اشيد, 
   {{0xdb0028f2,0x3f65441e,0x998c0427,0x00000000}},	//   _telé, утаб, vnež_, --, 
   {{0x1cd80135,0x6cf0107c,0x00000000,0x00000000}},	//   _འགད_, चिंग_, --, --, 
   {{0x9e95a66f,0xacf80108,0x00000000,0x00000000}},	//   _چارچ, лнцу_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x1b4806bb,0x263c0115,0x00000000,0x00000000}},	//   ъзки_, nĉos_, --, --, 
   {{0x78b9e3d5,0x94f4025c,0x9f40036e,0x99f400d4}},	//   truv, _བླའི_, hehë_, рякі, 
   {{0xd945e3d6,0x79980b45,0x8880005b,0xd8240395}},	//   репи, rbuw, олыж, идии, 
   {{0x9998033f,0x78b810f1,0x18680114,0x00000000}},	//   ósł_, rruv, ђани_, --, 
   {{0x26dc031c,0xd6280107,0xddc84a97,0xfd8400d1}},	//   _cpvo_, воне_, _miež, ﺭﺋﺎﻥ_, 
   {{0x59740228,0x60dc5d2e,0x78b9e3d7,0xddc80024}},	//   _кылу, _opsm, pruv, _liež, 
   {{0x98a46058,0x18a5e3d8,0xb4c0912c,0x00000000}},	//   _тиле, _талм, ँढे_, --, 
   {{0x03a13c68,0xddc83c49,0x00000000,0x00000000}},	//   жиро, _niež, --, --, 
   {{0x60dde3d9,0x26dc0175,0x68fc00e2,0x044011f4}},	//   _apsm, _gpvo_, ārde, церн, 
   {{0x2fd805b1,0x682401ab,0x9f400022,0x00000000}},	//   _sbrg_, _iòda, pehê_, --, 
  
   {{0xddc800da,0x2d8001f1,0xa64401e2,0x00000000}},	// [36800] _biež, žiek_, _دخون, --, 
   {{0xcef4026a,0x3e6400c7,0xa7fc03e0,0xf98401e2}},	//   ичењ, võta_, mlıc, _ژب_, 
   {{0xe7f80d2c,0x68240100,0x0dc8024c,0xa7fc0205}},	//   ्ञता_, _jòda, вули_, llıc, 
   {{0x682401c3,0x53d130a4,0x2aac01e1,0xe0440022}},	//   _mòda, द्रश, _lóbá_, анӡи, 
   {{0x7c9c0023,0xa7fc0790,0xab9401ec,0x00000000}},	//   _ዝተርፍ_, nlıc, билі, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7f40e587,0xed5001ed,0x00000000,0x00000000}},	//   _держ, _کھا_, --, --, 
   {{0xd90d5a4c,0xc054001f,0xdb4cb4d5,0x3f800200}},	//   کیه_, ያገለግ, رێن_, _zgju_, 
   {{0x2d840280,0x2aac01e1,0x094800a7,0xfa30030f}},	//   _igme_, _bóbá_, ъчки_, ترود, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xcb0805d9,0x682401c3,0x49c85f38,0x00000000}},	//   _جيان_, _còda, _ален_, --, 
   {{0xe3c401c6,0x059000b8,0xa7fc0205,0x00000000}},	//   өргү, _jāḍy, flıc, --, 
   {{0x17e00154,0xe8940f06,0x00000000,0x00000000}},	//   বাড়ি, _уаль, --, --, 
   {{0xddc8010e,0xa1580022,0x00000000,0x00000000}},	//   _ejeň, ҳабу_, --, --, 
   {{0x2d84070d,0x9f400240,0xe00407f7,0x466801a9}},	//   _ogme_, rehë_, रासद_, _ирим_, 
   {{0x60dc2a1f,0xda0807f7,0x263c00df,0x0590002b}},	//   _ppsm, वायत_, rĉos_, _nāḍy, 
   {{0xd4c0013d,0x609800ec,0x00000000,0x00000000}},	// [36810] _нөрк, انئس_, --, --, 
   {{0x25a83b08,0x998c00d0,0xc82801f3,0x00000000}},	//   _heal_, mieť_, _ብዙሃን, --, 
   {{0x24880457,0xdb0004ce,0x25a894f9,0x998c00d0}},	//   _huam_, _udlø, _keal_, lieť_, 
   {{0x2489e3da,0x31040b6d,0xd9a4007d,0x24800fac}},	//   _kuam_, रमशः_, _गजेट, _hihm_, 
   {{0x25a9e3db,0xddc800d7,0x998c00d7,0x00000000}},	//   _meal_, _tiež, nieť_, --, 
   {{0x25a9e3dc,0x24880070,0xdec4035b,0x3de40154}},	//   _leal_, _muam_, _гәдо, ফাইল, 
   {{0x24880190,0x1cd80156,0x6ef001ed,0xa7fc0790}},	//   _luam_, _འགམ_, róbá, zlıc, 
   {{0x25a9e3dd,0x6824068c,0x97c43c1a,0xa7fc0205}},	//   _neal_, _ròda, әйне, ylıc, 
   {{0x24880218,0xe8a80184,0x31380023,0x00000000}},	//   _nuam_, абыҙ_, _ኮንተይ, --, 
   {{0x998c01a2,0xdca40184,0x6824067c,0xd94404a9}},	//   dieť_, _ваҡи, _pòda, _қели, 
   {{0x25a9e3de,0x383c001f,0x7d080477,0xdb00022a}},	//   _beal_, _ይኖርብ, lxgs, _kelí, 
   {{0xddc83d79,0x248800a3,0x25a800c6,0xa7fc05d1}},	//   _nież, _buam_, _ceal_, tlıc, 
   {{0x24880457,0x25a80c30,0xdb001ab0,0xd9440640}},	//   _cuam_, _deal_, _melí, _ћели, 
   {{0x248802d3,0x80d0009e,0xd97801af,0xa7fc0205}},	//   _duam_, সিঞ্, _ирҙә_, rlıc, 
   {{0xddc80034,0x25a823d2,0xf76c004b,0x98a401e0}},	//   _bież, _feal_, _ډاډ_, _тиһе, 
   {{0x2489dba2,0x25a80bec,0xdb00012c,0x3c280174}},	//   _fuam_, _geal_, _nelí, _høvd_, 
   {{0xdea800b5,0x3ebc00b0,0x998c0030,0x2c60068c}},	// [36820] _a型_, _āuta_, cieť_, sòdi_, 
   {{0x25a87b73,0xb4e405f9,0x8fa43d2a,0x918000cf}},	//   _zeal_, नबी_, саже, تۇڭۇ, 
   {{0xdb00315a,0x20540845,0x7e9401b9,0x91e40798}},	//   _belí, ітур, منلر_, _лоне, 
   {{0x8d280364,0xdb002815,0x24880457,0xd17400ee}},	//   лоев_, _celí, _yuam_, _гыгы, 
   {{0xdb01e3df,0x24880218,0x20b40064,0x00000000}},	//   _delí, _xuam_, _мёрс, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf7640220,0xdb003df9,0x059000b8,0x998c00d7}},	//   _ءا_, _felí, _tāḍy, zieť_, 
   {{0xae0c13b4,0xdb00045f,0xea1802e8,0x786c7e78}},	//   _सचिन_, _belâ, ржиш_, høvd, 
   {{0x25a9e3e0,0xf98c16a2,0xc6a401c6,0x47841075}},	//   _real_, ربي_, өрни, йынб, 
   {{0x24880070,0x25a9e3e1,0xed58020a,0x998c0419}},	//   _ruam_, _seal_, _боғ_, vieť_, 
   {{0x24880483,0x25a9e3e2,0xdb0000d2,0x24800037}},	//   _suam_, _peal_, _yelí, _rihm_, 
   {{0x24880070,0x24f82cc8,0x41940150,0x327c0150}},	//   _puam_, анмы_, _ﺘﻘﺎﺱ_, _ﺣﺎﻻﺱ_, 
   {{0x2489e3e3,0xb8d0034c,0x25a847b4,0xddc80327}},	//   _quam_, _فتوش, _veal_, _rież, 
   {{0x24880070,0x25a80204,0x998c0030,0xecac0051}},	//   _vuam_, _weal_, rieť_, _đólà_, 
   {{0xc058005e,0x7a240054,0x25a9e3e4,0xdb000120}},	//   ңіз_, _uñtc, _teal_, _zelâ, 
   {{0x2489e3e5,0x9f500120,0x32f8007f,0x682402e2}},	//   _tuam_, _fazê_, _dčy_, _kòdo, 
   {{0x3c280183,0xdb001892,0x2488003a,0x00000000}},	// [36830] _høve_, _relí, _uuam_, --, 
   {{0x656c325f,0x32f80100,0xddc8033f,0x00000000}},	//   _izah, _fčy_, _wież, --, 
   {{0xdb009ccb,0x00000000,0x00000000,0x00000000}},	//   _pelí, --, --, --, 
   {{0xdb000309,0xa1580120,0x00000000,0x00000000}},	//   _qelí, _ваму_, --, --, 
   {{0x224801ed,0x786c1512,0xd3fc0183,0x3c2812ed}},	//   mnak_, løve, ুসৰি_, _løve_, 
   {{0x224800dd,0x656c01c8,0xdb007cfb,0x5a94013e}},	//   lnak_, _mzah, _relâ, ориф, 
   {{0x3c2800fe,0xcfe4009e,0x2248009d,0x786c03cd}},	//   _nøve_, নাখন, onak_, nøve, 
   {{0x2249e3e6,0x9e240372,0x3ea4054e,0x00000000}},	//   nnak_, _بىرو, ântu_, --, 
   {{0x2249e3e7,0x786cb59a,0x656c0526,0x682400db}},	//   inak_, høve, _nzah, _còdo, 
   {{0xd7c875a6,0x682401e1,0xcc8800b8,0x786c01bf}},	//   جوده_, _dòdo, _kṛn_, køve, 
   {{0x2248066d,0x656de3e8,0xd5e4871a,0x44200158}},	//   knak_, _azah, ожни, dkj_, 
   {{0xceb00bd9,0x3c281455,0x786c20e4,0xdb00045f}},	//   ויט_, _døve_, døve, _telâ, 
   {{0x22494cf9,0x9f5002d3,0x6824007f,0x3a3c0140}},	//   dnak_, _bazë_, _gòdo, miup_, 
   {{0x22483892,0x656de3e9,0x3a3c0140,0xa7fc73d8}},	//   enak_, _dzah, liup_, llın, 
   {{0x656de3ea,0x786d487d,0x00000000,0x00000000}},	//   _ezah, røvd, --, --, 
   {{0x3a3de3eb,0x2249e3ec,0x154411dc,0xa7fc3235}},	//   niup_, gnak_, _мейм, nlın, 
   {{0x9f500023,0x99dc010e,0x00000000,0x00000000}},	// [36840] _fazë_, miňd, --, --, 
   {{0x8f98020a,0xb4c807f7,0x9f500200,0x0d0800f2}},	//   ръат_, ोझी_, _gazë_, یقاً_, 
   {{0x224830f9,0x9f50007f,0xcee821fa,0x3fc801d9}},	//   bnak_, _jazè_, рдее_, شدلی_, 
   {{0xcbc400bd,0x77600200,0x8e740166,0x99dc010b}},	//   _এসেছ, _mynx, цузч, niňd, 
   {{0x3a3c013c,0x9f5002bd,0xa7fc03b9,0x21280064}},	//   diup_, _lazè_, dlın, _ліён_, 
   {{0x7c801de1,0xdb0000d2,0x6824067c,0xab940212}},	//   муще, _ndló, _ròdo, чикі, 
   {{0x27e004ac,0x3a3c20ac,0x74d002f5,0x1b1c015b}},	//   _ĝin_, fiup_, িবিউ, _ভেবে_, 
   {{0x68242508,0x27e000c8,0x9e700efb,0xddc8013d}},	//   _pòdo, _ŝin_, _كۇلت, _ikeş, 
   {{0x3c280217,0x67d426c7,0xb4e403e5,0xdce80327}},	//   _søve_, попу, नबो_, _tfeġ, 
   {{0x57b0192c,0x224800dd,0xa7fc0213,0x00000000}},	//   ىڭىز, znak_, alın, --, 
   {{0x2249e3ed,0x49a401e0,0xda6400f1,0x9b7459e1}},	//   ynak_, _һыҙғ, _کالي, _ىڭىز_, 
   {{0xba15e3ee,0x09040276,0xb9911b58,0x81dc0154}},	//   _ويلا_, _мпен, _قلمب, _ধোন_, 
   {{0x7a240bc9,0xdb000798,0x20a802e5,0xf10421bd}},	//   _uñta, _telã, _चौंध, रमोद_, 
   {{0x786c0ac7,0x3c2801bf,0x00000000,0x00000000}},	//   tøve, _tøve_, --, --, 
   {{0x224800dd,0xdb000085,0x070400ec,0xc8c4009f}},	//   tnak_, _kelá, _ڇيڙي_, _اوڙن_, 
   {{0x786c95a0,0x6fd80073,0x427400d1,0x5fdc6b26}},	//   røve, न्सू, _ﺳﺎﻗﭽ, न्नल, 
   {{0x656d3d4c,0xf6e4025c,0x0575e3ef,0x838400a8}},	// [36850] _uzah, _འགོང, _باغد, _мыне, 
   {{0x2249e3f0,0x3f84022c,0x6b880175,0xd6d403e6}},	//   snak_, ønu_, _ngdg, _بژیت_, 
   {{0x3a3c0d04,0x224801ed,0x9ed836f0,0xa1940276}},	//   yiup_, pnak_, смет_, _нанч, 
   {{0x6b880165,0xdb000306,0xa7fc0205,0x00000000}},	//   _agdg, _nelá, klıo, --, 
   {{0xdca439a5,0x3a3c20ac,0x5ca4499d,0x290000c0}},	//   чали, viup_, чилб, _šian_, 
   {{0x682402e2,0x81e402f5,0xdb00004e,0xefc801c6}},	//   _bòdm, পাও_, _pelà, _муск_, 
   {{0xf6e40f50,0x3a3c3a97,0xec6801e0,0xdb003df9}},	//   _འགེང, tiup_, өрәк_, _belá, 
   {{0x99d40244,0x9f50007f,0x6dc4023a,0x69dc01d3}},	//   ستبا, _razè_, _осуж, őren, 
   {{0x3a3c003e,0x00000000,0x00000000,0x00000000}},	//   riup_, --, --, --, 
   {{0x81e404c5,0x3a3c0194,0x998c06be,0x6964568c}},	//   পাট_, siup_, bkeş_, بدىق, 
   {{0x3a3c013c,0xa7fc5531,0xdb0001ed,0xddc8054e}},	//   piup_, mlıl, _felá, _gheţ, 
   {{0x3cfc01a6,0xa7fce090,0x00000000,0x00000000}},	//   _kruv_, llıl, --, --, 
   {{0x99dc010e,0x00000000,0x00000000,0x00000000}},	//   giňe, --, --, --, 
   {{0xa7fc7b54,0x6b8800a3,0x88980375,0xe89800e5}},	//   nlıl, _xgdg, _הבסי, _بموں_, 
   {{0xe87401d5,0x00000000,0x00000000,0x00000000}},	//   _تنوگ, --, --, --, 
   {{0xa7fc453a,0x00000000,0x00000000,0x00000000}},	//   hlıl, --, --, --, 
   {{0xdd980100,0xa7fc247e,0xc0e000cf,0xd025e3f1}},	// [36860] _enňk_, klıl, нотк, пмай, 
   {{0xa7fc0139,0x00000000,0x00000000,0x00000000}},	//   jlıl, --, --, --, 
   {{0xd548021a,0x1ea80b24,0xa7fc0f77,0x00000000}},	//   _خلکو_, قاني_, dlıl, --, 
   {{0x61e80166,0x00000000,0x00000000,0x00000000}},	//   _ıelg, --, --, --, 
   {{0x2d800221,0xdb000030,0xc780001f,0xac840022}},	//   äie_, _relá, ነስተኛ_, дҳал, 
   {{0x8aa410d6,0xdb01aeba,0x00000000,0x00000000}},	//   прид, _selá, --, --, 
   {{0xdb0004d4,0x00000000,0x00000000,0x00000000}},	//   _pelá, --, --, --, 
   {{0x998c274a,0xa8980276,0x499008dc,0x3ea400c7}},	//   rkeş_, окиу_, ریتر, ãnte_, 
   {{0x1b1c04c5,0xdb00d3eb,0x3cfc007c,0x6ec44438}},	//   _ভেদে_, _velá, _gruv_, ांकु, 
   {{0x2d800153,0x62800118,0xa7fc0205,0x8b940395}},	//   žies_, íloz, rlıo, _храч, 
   {{0xfaa1e3f2,0x09e4716a,0x37a40137,0xb8d0315b}},	//   _захо, _ножн, чтын_, وتیش, 
   {{0xdb00037e,0x00000000,0x00000000,0x00000000}},	//   _belæ, --, --, --, 
   {{0x67d40372,0x3c2805ac,0x5fdc0709,0xda0807f7}},	//   _жолу, _høva_, न्डल, वारत_, 
   {{0x3cec0c2e,0x3c280162,0x38380023,0xb978011a}},	//   _इनसे_, _køva_, _ትፈልጥ, _הנדי, 
   {{0xa7fc03e0,0x00000000,0x00000000,0x00000000}},	//   nlım, --, --, --, 
   {{0x32640261,0xa7fd6879,0x2258104e,0x00000000}},	//   етув, zlıl, цибы_, --, 
   {{0xdff41b88,0x3c2805ac,0xa7fc0baa,0xdb00005c}},	// [36870] мпањ, _løva_, ylıl, _gelæ, 
   {{0x44ed2bf9,0x1cb8031c,0x83a801d5,0xd69c0220}},	//   _iż_, ྙེལ_, _утиб_, _ﺃﻨﻅﺭ_, 
   {{0xd24c004b,0xe7d400cd,0x00000000,0x00000000}},	//   اچۍ_, _दानप, --, --, 
   {{0x3cfde3f3,0xfbdc0316,0xa7fc06be,0x00000000}},	//   _pruv_, प्नम, dlım, --, 
   {{0xa7fc6654,0xed580212,0x786c03b2,0xd69c0150}},	//   tlıl, пої_, høva, _ﺃﺨﻁﺭ_, 
   {{0x41c80316,0x9b441046,0x69dc00e5,0xdb740150}},	//   िलवस, وچاو, őrel, _ﺸﻭﺭﻯ_, 
   {{0xa7fcae4a,0x6f64023a,0x786c03cd,0xdb000200}},	//   rlıl, _звёз, jøva, _melç, 
   {{0x3cfc23ee,0xaac40533,0x00000000,0x00000000}},	//   _truv_, رتىن, --, --, 
   {{0xa7fc43dd,0x2004068c,0x00000000,0x00000000}},	//   lmıy, _òlis_, --, --, 
   {{0xa7fc9c13,0xdb00005c,0x00000000,0x00000000}},	//   qlıl, _relæ, --, --, 
   {{0x44ec068f,0xa7fc1918,0x682401ab,0x00000000}},	//   _aż_, nmıy, _mòdh, --, 
   {{0x99580311,0x5fdc227c,0x15440139,0xdcf8008e}},	//   _câţi_, न्तल, демм, lawı, 
   {{0x7989e3f4,0xdb003535,0x25840055,0x3dcc00eb}},	//   _iggw, _belç, _nīlī_, _রসাল, 
   {{0x69346161,0xa7fc1f02,0x00000000,0x00000000}},	//   _янчу, kmıy, --, --, 
   {{0x44ec0003,0xfbdc4668,0x6fcc0b98,0xd9f00037}},	//   _eż_, प्यम, ालसं, _अघात_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x1cb8003d,0x682400a3,0xdb016f0f,0xa7fc0205}},	// [36880] ྙེས_, _bòdh, _helä, zlım, 
   {{0xdff40cf9,0x682400a3,0xdb00008e,0x00000000}},	//   _ъ슜_, _còdh, _kelä, --, 
   {{0x79882f63,0xa3000209,0x1b1c015b,0x5fdc0a97}},	//   _oggw, _йүре, _ভেসে_, न्धल, 
   {{0xf985336e,0x3c280158,0x29000024,0xdb0000a2}},	//   _لب_, _røva_, _šiam_, _melä, 
   {{0xa7fc07c4,0x83148235,0x3c2800fe,0xd76402d3}},	//   rmız, _فقیر_, _søva_, _ሻዕብያ_, 
   {{0x79881418,0xdd9802e2,0x3eac01d3,0x3cec000d}},	//   _aggw, _efň_, újtó_, _इनरे_, 
   {{0x15ec0034,0xda080490,0x3f641d39,0x00000000}},	//   ज़ार_, वांत_, _жиро_, --, 
   {{0x2c0004c5,0xa7fc03e0,0x37a400cc,0x00000000}},	//   ্সেই_, rlım, _খাগৰ, --, 
   {{0xc7c401c0,0xe944179e,0xb99000d1,0x7c9000ae}},	//   мсни, عربی, خشىغ, _للقص, 
   {{0xdb00eabc,0x79882252,0x682402e2,0x6cc40116}},	//   _belä, _eggw, _kòdi, _ойға, 
   {{0xa7fc62c7,0x00000000,0x00000000,0x00000000}},	//   llık, --, --, --, 
   {{0xa5f834d8,0xdb01e3f5,0x6824004e,0xfd540055}},	//   чему_, _selç, _mòdi, _avaṭ, 
   {{0xdd3003be,0xa7fc0e51,0xf7f14b4f,0x276800f2}},	//   _məşh, nlık, رسید, _کششی_, 
   {{0x67d446e5,0x3e6400e4,0x28140244,0x38c401ec}},	//   _чоку, rõti_, _سوبس, _ішің, 
   {{0xdb01e3f6,0x682401ab,0xa7fc0205,0xdd1000a2}},	//   _gelä, _ròdh, hlık, küşe, 
   {{0xa7fc1918,0x3c2806ea,0xf64400c7,0x682401c3}},	//   klık, _nøvn_, _ахьн, _sòdh, 
   {{0x26cde3f7,0xb284094e,0xcc8800b8,0xdb000139}},	// [36890] ludo_, тырк, _dṛk_, _telç, 
   {{0x4424001e,0xa7fc2737,0xdb0017f9,0x9f35020a}},	//   _ôn_, tmıy, _helå, незі, 
   {{0x26cde3f8,0x6825e3f9,0xf5180214,0x63b5e3fa}},	//   nudo_, _còdi, _فتیش_, mazn, 
   {{0x63b40552,0xa7fc1f02,0x9d54198a,0x5d541f99}},	//   lazn, rmıy, ىنات, нкет, 
   {{0x61ede3fb,0x343804fb,0x26cd5fe0,0xaee40055}},	//   meal, _رسید_, hudo_, _puṃr, 
   {{0x61ec653f,0x60cde3fc,0x26cde3fd,0xa7fc510c}},	//   leal, muam, kudo_, pmıy, 
   {{0x60cc7b6c,0x998c00e2,0x9f500306,0x4ac4000d}},	//   luam, riež_, _kazí_, रंगव, 
   {{0x61ec36f5,0xdb000267,0xa7fc0205,0x63b40166}},	//   neal, _relä, llıh, hazn, 
   {{0x63b403c6,0xdb01e3fe,0xa3c0069f,0xd825e3ff}},	//   kazn, _selä, ुला_, едпи, 
   {{0x61ede400,0x63b465d2,0xdb01e401,0xc5c4009e}},	//   heal, jazn, _pelä, ষ্মপ, 
   {{0x60ccbbef,0x61ede402,0x0cc0009e,0xdb003bd1}},	//   huam, keal, োবৃত, _belå, 
   {{0x60cd455f,0xdb0001b8,0x61ecba9c,0x6128022e}},	//   kuam, _velä, jeal, _dоlz, 
   {{0x63b415ad,0x6824033b,0xdb008ce1,0x60cc0108}},	//   fazn, _nòdw, _delå, juam, 
   {{0xdb000598,0x26cde403,0x60cde404,0x63b5e405}},	//   _telä, budo_, duam, gazn, 
   {{0x26cd20bc,0x91e47b98,0x61ede406,0xa7fc247e}},	//   cudo_, нове, feal, zlık, 
   {{0xa7fc3279,0x682402e2,0x61ede407,0x60cde408}},	//   ylık, _bòdw, geal, fuam, 
   {{0x63b40b91,0x60cde409,0x6824004e,0x4fa40cb6}},	// [368a0] bazn, guam, _sòdi, еизв, 
   {{0x3c281512,0x682435f5,0x54341e24,0x68e4005b}},	//   _søvn_, _pòdi, _سرخر, _äide, 
   {{0x60cc00a3,0x61ec0254,0x4ecc0154,0xdd1008a9}},	//   auam, beal, রব্ল, tüşe, 
   {{0x61ede40a,0xa7fc1918,0x60cc003a,0x00000000}},	//   ceal, tlık, buam, --, 
   {{0x26cc00d8,0x70840124,0x1dd001ad,0xdd1005d1}},	//   zudo_, _аҳаз, _हारत, rüşe, 
   {{0xa7fc825f,0x29fc0208,0xe0900133,0x26cc6140}},	//   rlık, _ỉa_, _ئیلخ, yudo_, 
   {{0xec3401b9,0x7ac0010b,0xaa5957bd,0x00000000}},	//   _یورگ, гсые, мику_, --, 
   {{0x998c0034,0x63b402f0,0x26cc391d,0x3c2801bf}},	//   cież_, zazn, vudo_, _høvl_, 
   {{0x9e700075,0xfce1e40b,0x6824007f,0x26cc01f2}},	//   _ئۇنت, _йото, _mòdv, wudo_, 
   {{0x26cde40c,0x61ede40d,0xdb000250,0x786c0162}},	//   tudo_, zeal, _selå, søvn, 
   {{0x36d405f5,0x60cc0085,0x63b4fb52,0xa3c00254}},	//   ндээ_, zuam, vazn, ुलस_, 
   {{0x26cc05b8,0x61ec005a,0x63b4012d,0x00000000}},	//   rudo_, xeal, wazn, --, 
   {{0x63b40518,0x28f80a8f,0x34944caf,0x26cc00d8}},	//   tazn, _цель_, лаяр, sudo_, 
   {{0xaad41533,0x998c0034,0x26cde40e,0x61ec017a}},	//   _धमाक, zież_, pudo_, weal, 
   {{0x63b40e8b,0xa294de10,0x1dd000bc,0x86e401a9}},	//   razn, табі, _हालत, _чўлд, 
   {{0x60cde40f,0x9f50013d,0x786c005c,0x63b4013a}},	//   tuam, _qazí_, høvl, sazn, 
   {{0x660de410,0xdb00045f,0x3c2800b5,0x63b40427}},	// [368b0] _inak, _belû, _bøvl_, pazn, 
   {{0x61ede411,0x83a807d6,0x7a4400f2,0x660c01a8}},	//   seal, _этиб_, _kètè, _hnak, 
   {{0xceb49151,0x60cde412,0x660c713c,0x61ede413}},	//   кәт_, suam, _knak, peal, 
   {{0x61ec036b,0x660c004e,0x9b840133,0x00000000}},	//   qeal, _jnak, ۆڤان, --, 
   {{0x60cde414,0x660de415,0x53780092,0x00000000}},	//   quam, _mnak, _በስደት_, --, 
   {{0xdb00002d,0x3e840241,0x3e6400c5,0x9b840133}},	//   _gelû, _bìtì_, võtu_, نڤان, 
   {{0x660c1326,0x7a44020c,0x9960002e,0x998c033f}},	//   _onak, _nètè, _tëŋk_, pież_, 
   {{0x68240137,0x660c2252,0x00000000,0x00000000}},	//   _mòdu, _nnak, --, --, 
   {{0x261403e5,0x9bc80a11,0xb05400f1,0xb5b00154}},	//   धानी_, _يورك_, _شپېت, _কালচ, 
   {{0x660de416,0x7a4400f2,0x16fc0135,0x96b80138}},	//   _anak, _bètè, _ཟླུམ_, муму_, 
   {{0x6824004e,0xdb000241,0x89f401d3,0x00000000}},	//   _nòdu, _lelú, رٹیز_, --, 
   {{0x8be40eac,0xeab00f84,0x1a6400f2,0x00000000}},	//   _গোপন_, _طعم_, _جیبی_, --, 
   {{0x660c01ee,0xdb0000d7,0x00000000,0x00000000}},	//   _dnak, _nelú, --, --, 
   {{0x660de417,0x9c7c06c8,0x446000a7,0xdcec0024}},	//   _enak, _opōm, ивяв, škėj, 
   {{0x78b80436,0xc7d404ae,0x9264085b,0xe854010a}},	//   lsuv, _יוסי_, ندرم, _сĕрн, 
   {{0xdb00000f,0x7998d3a7,0x29000024,0x46a0059f}},	//   _belú, ncuw, _šiai_, _таъв, 
   {{0x76446837,0xd185e418,0x947800fb,0x00000000}},	// [368c0] _imiy, тлай, _осоу_, --, 
   {{0x8fd03d09,0x78b87533,0x8fa4003b,0x9f404a84}},	//   шәмә, isuv, таже, kehä_, 
   {{0xf9bc00b5,0xa3c00562,0x78b803b9,0xddd80210}},	//   _cm程_, ुलर_, hsuv, dowł, 
   {{0x78b805a7,0xdb0001ed,0x471800c8,0x4d480395}},	//   ksuv, _felú, וועג, мпен_, 
   {{0x7644090c,0x3e6400c5,0x786c0450,0x78b80301}},	//   _mmiy, võtt_, tøvl, jsuv, 
   {{0x78b80254,0x8538011a,0x00000000,0x00000000}},	//   dsuv, וגני, --, --, 
   {{0x9f500109,0x60c800df,0xdde000a2,0x69c400db}},	//   _gazà_, _ĥemi, _ýuşe, гөлб, 
   {{0xda08202e,0x26c000c8,0xc9842ed8,0xe8f800cf}},	//   वागत_, _ĉio_, купи, енич_, 
   {{0x6e200170,0x66e8013f,0x7a4402e2,0x4c85e419}},	//   _iomb, _mɛke, _sètè, _алав, 
   {{0x6e21e41a,0x7645e41b,0x7a4402e2,0xb6c400e5}},	//   _homb, _amiy, _pètè, ھاپے_, 
   {{0x6e21e41c,0x78b80124,0x88c401b9,0x9e6400e5}},	//   _komb, asuv, رتکل, _شاہن, 
   {{0x6e21e41d,0xf6d004fb,0x79980de2,0xdd300213}},	//   _jomb, گزید, ccuw, nəşl, 
   {{0x6e21e41e,0xdd1007b3,0x9f50056a,0x1cb8031c}},	//   _momb, _müşa, _mazá_, ྙེག_, 
   {{0x43b09e7e,0x76456b82,0x7a44ac7c,0x660c00b0}},	//   шҡор, _emiy, _tètè, _wnak, 
   {{0x6e21e41f,0xdb0000d2,0x660c00b5,0x2ef80327}},	//   _oomb, _selú, _tnak, _nsrf_, 
   {{0x6e21e420,0x27fde421,0xe5e8049b,0x660d71f8}},	//   _nomb, _havn_, ämää, _unak, 
   {{0x99dc010e,0x00000000,0x00000000,0x00000000}},	// [368d0] diňl, --, --, --, 
   {{0x656de422,0x6e2000ec,0xb0340046,0x27fc03b2}},	//   _iyah, _aomb, ануш, _javn_, 
   {{0x6e21e423,0x2a64025a,0x64440099,0xdd9000c6}},	//   _bomb, komb_, _imhi, موا_, 
   {{0x656c04ba,0x9f5006d9,0xdb0004d4,0x99dc02f0}},	//   _kyah, _vazà_, _telú, viňo, 
   {{0x4430020b,0x22481d4d,0x1be80798,0x78b8007c}},	//   _klx_, miak_, едли_, xsuv, 
   {{0x27fdc5f5,0x61fde424,0x2249e425,0x656de426}},	//   _navn_, _hasl, liak_, _myah, 
   {{0x6e201311,0x61fde427,0xf4140bd4,0x3cec2aa1}},	//   _fomb, _kasl, יפס_, _इनके_, 
   {{0x61fde428,0x2249862a,0x6e21e429,0xdb00332c}},	//   _jasl, niak_, _gomb, _melø, 
   {{0x61fde42a,0x656de42b,0x2129e42c,0x7e79e42d}},	//   _masl, _nyah, nyah_, _ihup, 
   {{0x2249e42e,0x212805b1,0x78b85979,0x9e700116}},	//   hiak_, iyah_, rsuv, _ئۇچت, 
   {{0x656de42f,0x22480323,0x6e21e430,0x2a65e431}},	//   _ayah, kiak_, _yomb, bomb_, 
   {{0x61fc8847,0x656de432,0xfbdc53c3,0x09181c82}},	//   _nasl, _byah, प्रम, _তেওঁ_, 
   {{0x656c01aa,0xb4c00574,0x27fc0162,0x2249e433}},	//   _cyah, ुढे_, _favn_, diak_, 
   {{0xdb0095a0,0x2129e434,0x656de435,0x27fc493a}},	//   _belø, dyah_, _dyah, _gavn_, 
   {{0xd251e436,0x656c6e0e,0xcfb0045e,0x60dc0327}},	//   منس_, _eyah, _চালন, _aqsm, 
   {{0x22480323,0x644402c4,0x7645e437,0x61fc1368}},	//   giak_, _emhi, _umiy, _casl, 
   {{0x6e203e81,0x44300ac5,0x656c003e,0x2128efe0}},	// [368e0] _romb, _flx_, _gyah, gyah_, 
   {{0xdb000579,0x7e79e438,0x66e8013f,0x644401c3}},	//   _felø, _ahup, _wɛke, _gmhi, 
   {{0x0dc9e439,0x2249e43a,0xa56450b5,0x61fde43b}},	//   елей_, biak_, _مدین, _fasl, 
   {{0x7e7807dd,0x2128020c,0x6e20014f,0x22485f0b}},	//   _chup, byah_, _qomb, ciak_, 
   {{0x6e21e43c,0x7e79e43d,0xd99c0150,0xe7d4000d}},	//   _vomb, _dhup, _ﺍﺸﺘﺩ_, _दालप, 
   {{0x6e201cdf,0x7e79e43e,0x443000d8,0x10140006}},	//   _womb, _ehup, _xlx_, _сьмя, 
   {{0xbea000fd,0x6d5c0882,0x6e21e43f,0x61fde440}},	//   _гаск, _śrad, _tomb, _yasl, 
   {{0x48a81468,0x27fcc300,0x7e78014f,0x6e2001f7}},	//   нтом_, _savn_, _ghup, _uomb, 
   {{0x9c7c06c8,0x2a64045a,0xed501f0d,0x8de801af}},	//   _opōh, romb_, _بھا_, _офҡа_, 
   {{0xd90dda2d,0x22480323,0x656c015c,0x8034008f}},	//   بیه_, ziak_, _ryah, ָנטע_, 
   {{0x656de441,0x21280a2e,0x682402e2,0x2a640219}},	//   _syah, zyah_, _bòdr, pomb_, 
   {{0x2129c6e5,0x02a001f2,0x656c0588,0x2248009d}},	//   yyah_, shịọ, _pyah, xiak_, 
   {{0x61fc0724,0x3201e442,0xdb000158,0x44300356}},	//   _rasl, ddiy_, _selø, _plx_, 
   {{0x656de443,0x61fc3aed,0x34940fc0,0xb7d40214}},	//   _vyah, _sasl, сарр, _موها_, 
   {{0x61fde444,0x4669e445,0x224975d5,0x69dc00e5}},	//   _pasl, _прим_, tiak_, őreu, 
   {{0x61fc047e,0x00000000,0x00000000,0x00000000}},	//   _qasl, --, --, --, 
   {{0x2248152d,0x61fde446,0xb15c0408,0x2128003e}},	// [368f0] riak_, _vasl, ентi, uyah_, 
   {{0x2249e447,0x7e79e448,0x61fc003d,0x26cc01b8}},	//   siak_, _shup, _wasl, ordo_, 
   {{0x61fc09a5,0x7e79e449,0x2249e44a,0x9ed88083}},	//   _tasl, _phup, piak_, тмет_, 
   {{0x61fc0597,0xab80001f,0x64540ffb,0x2128014f}},	//   _uasl, _ያሳያል_, lnzi, pyah_, 
   {{0x21283223,0x7e780084,0x3c28022c,0xa7fc029f}},	//   qyah_, _vhup, _høvi_, nlıs, 
   {{0x6455e44b,0x00000000,0x00000000,0x00000000}},	//   nnzi, --, --, --, 
   {{0x60cde44c,0x7e79e44d,0x201001f7,0xa3dc07f7}},	//   lram, _thup, _inzi_, _डान_, 
   {{0x60cde44e,0x645403fa,0x7e79e44f,0xa7fc05d1}},	//   oram, hnzi, _uhup, klıs, 
   {{0x26ccdbd1,0xf8bc02ea,0x6824067c,0x661c00f3}},	//   erdo_, éé_, _ròdr, djsk, 
   {{0x2001e450,0x60cc0a55,0xe8e805d9,0xd7080b32}},	//   ndhi_, iram, اريو_, вное_, 
   {{0x290000d0,0x20000067,0x6c84007b,0x290401a9}},	//   _šiat_, idhi_, _اللم, avma_, 
   {{0x60cde451,0x6455e452,0x96649398,0x4a9804ae}},	//   kram, enzi, ркме, _סינג, 
   {{0x60cde453,0x20100810,0x95743a4e,0x786c0174}},	//   jram, _onzi_, рынч, høvi, 
   {{0x26cc05a1,0x9695e454,0x786c03b2,0x2bc807b7}},	//   brdo_, _криш, køvi, रणया, 
   {{0x60cde455,0x2001511e,0x580401e0,0x00000000}},	//   eram, ddhi_, _боҙғ, --, 
   {{0x60cde456,0x9fe402a6,0x2011e457,0x64540451}},	//   fram, নযোগ, _anzi_, anzi, 
   {{0x6454009a,0x3201e458,0x1458013d,0xefe8ae3e}},	// [36900] bnzi, rdiy_, _ашны_, ллаһ_, 
   {{0xd378004e,0xa7fc0139,0xb3e400eb,0x00000000}},	//   _үчү_, llır, _ফোরজ, --, 
   {{0x60cde459,0x91e5e45a,0x32000a73,0xd7dc00ce}},	//   aram, _коне, pdiy_, _मानच, 
   {{0x0e65e45b,0x20100451,0xbf1002f2,0x20001210}},	//   шкен, _enzi_, تومب, adhi_, 
   {{0x60cdb3d6,0xebc40184,0xa3dc05d7,0x41000153}},	//   cram, йҙан, _डाम_, _дзяв, 
   {{0x786c05ac,0xd0113bab,0x0ac4011b,0x2c7800fd}},	//   bøvi, _بلس_, ащим, ыйль_, 
   {{0x661c033f,0x244c0427,0x2bc80118,0xa7fc294f}},	//   yjsk, nžma_, रणबा, zlıs, 
   {{0x0a6800a7,0x00000000,0x00000000,0x00000000}},	//   ърли_, --, --, --, 
   {{0x4234010f,0x00000000,0x00000000,0x00000000}},	//   ינקל_, --, --, --, 
   {{0x29000006,0xdc7400c7,0x00000000,0x00000000}},	//   _šias_, _лыхь, --, --, 
   {{0x66e8016b,0xfaa1e45c,0x60cde45d,0x78740209}},	//   _bɛka, _дахо, zram, рйэр_, 
   {{0xa7fc0ac1,0xca74013d,0x48e400f3,0x00000000}},	//   tlıs, _тузы, _водв, --, 
   {{0x2000058a,0x60cc01a9,0x00000000,0x00000000}},	//   ydhi_, xram, --, --, 
   {{0x6455c5fd,0xdd980209,0x60cde45e,0xa7fc05d1}},	//   unzi, _maňa_, vram, rlıs, 
   {{0x20100607,0x4244013e,0x64540112,0x60cc058a}},	//   _rnzi_, ахаб, rnzi, wram, 
   {{0x60cde45f,0xdce83421,0xf194011b,0xa7fc0bb9}},	//   tram, _uzeć, жить, mlıq, 
   {{0x60cde460,0xc32c4d2d,0xa7fc6656,0x98ac012d}},	// [36910] uram, سەڭ_, llıq, rzeć_, 
   {{0x60cc9ace,0x200001f7,0x786c05ac,0xcfb000cc}},	//   rram, udhi_, tøvi, _চাউন, 
   {{0x60cde461,0xa7fc887f,0x66e8016b,0x2001e462}},	//   sram, nlıq, _yɛka, rdhi_, 
   {{0x60cc0882,0xdb000122,0x5de401b9,0xdd980419}},	//   pram, _celý, ёжла, _baňa_, 
   {{0x60cc0cc1,0x786c332c,0xa7fc03b9,0x00000000}},	//   qram, søvi, hlıq, --, 
   {{0x20100099,0xdd98010e,0xdb00032e,0x10cc0046}},	//   _unzi_, _daňa_, _velþ, _ﺗﻪﺣﻨ, 
   {{0x186855da,0x1b1c00eb,0x99dc0432,0x00000000}},	//   ғани_, _ভেজে_, liňi, --, 
   {{0xdb0009a5,0x61e8007d,0xa7fc00ac,0x1cb8025c}},	//   _gelý, _öeld, dlıq, ྙེད_, 
   {{0x682402e2,0xfd9400fb,0xd9440022,0xa3dc000d}},	//   _pòdp, _йөҙә_, сепи, _डाढ_, 
   {{0xfc306bc6,0xd7c86e1d,0x18680120,0x3b64030d}},	//   _بحر_, دوده_, ѓани_, _къев, 
   {{0xa294044e,0x6a6c000f,0xd6287a12,0x00000000}},	//   ግባእን_, tûft, гоне_, --, 
   {{0x03a00364,0x00000000,0x00000000,0x00000000}},	//   ҷиро, --, --, --, 
   {{0x99840597,0x89940375,0x00000000,0x00000000}},	//   _الشو, _הכנס_, --, --, 
   {{0x03a16276,0x51540032,0xd7c83bd7,0xa7fc06be}},	//   зиро, ҡтау, _صوبه_, blıq, 
   {{0x7a240227,0x4fe800d1,0xcc74011a,0x00000000}},	//   _uñts, һман_, מעשה_, --, 
   {{0xdb000036,0x85000014,0x2214014b,0x99940023}},	//   _aflë, _کوٝن, офур, _መሳሪሒ_, 
   {{0x261462be,0xdb00010e,0x30240107,0x99dc00ee}},	// [36920] धारी_, _relý, озаҳ, giňi, 
   {{0x1cb8081f,0xdb01e463,0x04400262,0x1ce4031c}},	//   ྙེན_, _belü, _неын, _ཨཱཿ_, 
   {{0xd9f805ba,0x4f7802f6,0xdd9800ee,0xddc80030}},	//   ्यात_, ущая_, _saňa_, _kmeň, 
   {{0x99dc00a2,0xd5c000b8,0x00000000,0x00000000}},	//   biňi, bhāś_, --, --, 
   {{0xa7fc723e,0xdb00000d,0x1db80037,0x00000000}},	//   zlıq, _eelü, _उजरत, --, 
   {{0xdb0000dd,0x48a80853,0xdd9800d0,0xdfa81bf4}},	//   _felü, қтим_, _vaňa_, _نطفه_, 
   {{0x0ae82998,0xdb000086,0xc330010f,0xfaa047c5}},	//   ارتي_, _gelü, ּוח_, пшын, 
   {{0x3ea5e464,0x1b1c015b,0x00000000,0x00000000}},	//   ínte_, _ভেঙে_, --, --, 
   {{0xc7b80a93,0xad5401b9,0x786c0174,0x391000c7}},	//   лён_, _بچاغ, høvu, змыр, 
   {{0xa7fc73d8,0xdb000034,0xb6040153,0x00000000}},	//   tlıq, _celó, _įšal, --, 
   {{0x3c0c00de,0x4aa80798,0x5fdc28fe,0x00000000}},	//   _dēvē_, _скен_, न्टल, --, 
   {{0xa7fd839d,0x00000000,0x00000000,0x00000000}},	//   rlıq, --, --, --, 
   {{0xda64fefb,0x59f8010f,0x00000000,0x00000000}},	//   _بالي, _כּסד, --, --, 
   {{0xdb0026b7,0x229400a7,0x00000000,0x00000000}},	//   _geló, живя, --, --, 
   {{0x2be00b9c,0x25e0375c,0xcfdc0eac,0xa7fc43bc}},	//   _नाना, _कापी_, ড়ান, qlıq, 
   {{0xf494114f,0x80c4000d,0x00000000,0x00000000}},	//   _کشيد, _लिआइ, --, --, 
   {{0xdb0005d1,0xd5b82519,0x00000000,0x00000000}},	// [36930] _selü, _өсө_, --, --, 
   {{0xdb01e465,0x99dc0209,0xddc800d0,0x7538011a}},	//   _pelü, riňi, _zmeň, _לאחד_, 
   {{0x3ea408f7,0xa195e466,0x99dc0209,0x3cf8473c}},	//   ënt_, _манч, siňi, लौने_, 
   {{0x25e009d9,0xdb0001ed,0xdd94010b,0x5d3400ec}},	//   _काफी_, _velü, цады, يفائ, 
   {{0x25e050dc,0x9c7de467,0xddc8012d,0xf1c40118}},	//   _कानी_, _opōt, _zjeś, stší_, 
   {{0xfeb83baf,0xd838007f,0x00000000,0x00000000}},	//   _مارت_, npōt_, --, --, 
   {{0xdb0003b7,0x9994044e,0x9f05e468,0x9e34023a}},	//   _reló, _መሳርሒ_, _بوزو, _девч, 
   {{0xdb01e469,0xddc80327,0x00000000,0x00000000}},	//   _belò, _jheż, --, --, 
   {{0xdb002cf4,0xcd740092,0x49c4009d,0x00000000}},	//   _peló, ራቸውና_, цлын_, --, 
   {{0x7e69e46a,0xdb000100,0x224c00d0,0x2be01b6e}},	//   logp, _delò, čeky_, _नाया, 
   {{0xdb008f8d,0x522002d3,0x00000000,0x00000000}},	//   _veló, _ተጻብኦ, --, --, 
   {{0x2918007b,0xefd00023,0x00000000,0x00000000}},	//   ófaí_, _ብድድ_, --, --, 
   {{0x2be01bd6,0xf770c73b,0x25aceb82,0xdb01e46b}},	//   _नामा, _کاش_, ñela_, _teló, 
   {{0xdb01e46c,0x92a00150,0x93580816,0x786c03b2}},	//   _aflé, _ﺃﻟﻭﻑ_, арбу_, tøvu, 
   {{0x96b8008e,0x55e40150,0x998c0210,0x00000000}},	//   _тулу_, _дойб, yjeś_, --, 
   {{0x24800036,0x03641436,0x786c0174,0x2be000cd}},	//   _ehhm_, циск_, røvu, _नाभा, 
   {{0xd0242218,0xc34c0092,0xefd40092,0x00000000}},	// [36940] омай, _አድርጌ, _የታየ_, --, 
   {{0xcee82f23,0x00000000,0x00000000,0x00000000}},	//   идзе_, --, --, --, 
   {{0x2be000ce,0x3cfc00c5,0x1ce40327,0x1fb40153}},	//   _नाबा, _asuv_, _ཨཱུ_, ястр, 
   {{0x0ca853e9,0xe4c403e6,0xdd9800d7,0xfbd40118}},	//   атки_, _بڵێی, _daňo_, _ठाउम, 
   {{0x10a4005b,0x00000000,0x00000000,0x00000000}},	//   _фигн, --, --, --, 
   {{0x8aa40409,0xdb00068c,0x858000d1,0x8ec40ee8}},	//   орид, _relò, _ﺭﻭﺯﺍ_, _وآزم, 
   {{0xc4b401d9,0x68400241,0x00000000,0x00000000}},	//   _अब्ख, _ládù, --, --, 
   {{0xdb00067c,0xc0e40014,0xf98c00ec,0x00000000}},	//   _pelò, _دکہٕ_, ھبي_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb00004e,0x08299099,0x07080117,0x00000000}},	//   _velò, рции_, ахми_, --, 
   {{0x3cfc022e,0x81b80154,0x8078010f,0xcb680108}},	//   _zsuv_, _ঘাস_, שניצ, _таже_, 
   {{0xeb34004b,0x2be002c3,0x2bc8043e,0x00000000}},	//   _ورڅخ, _नाडा, रणवा, --, 
   {{0x08f8132f,0x69c06937,0x7a6400f7,0x25e00b03}},	//   _خراب_, mame, _بئلە, _काठी_, 
   {{0x7e680af9,0x8c4406be,0x00000000,0x00000000}},	//   zogp, _buşə, --, --, 
   {{0xc7640228,0x69c05f8b,0x3394024c,0x561400eb}},	//   _باشى, oame, дарё, াসড়ক_, 
   {{0xbb380a1e,0x6abc03cd,0xa3dc0073,0x80c401f9}},	//   בעלי, _ærfu, _डाव_, ाळले, 
   {{0x69c1e46d,0x00000000,0x00000000,0x00000000}},	// [36950] iame, --, --, --, 
   {{0xbfa84f55,0x00000000,0x00000000,0x00000000}},	//   ртае_, --, --, --, 
   {{0x69c03aaa,0x87ec031c,0xddc8031c,0x8c440213}},	//   kame, _ཨིནྡ, _theż, _guşə, 
   {{0x69c1e46e,0x3cfc0407,0x786c28b3,0xa159e46f}},	//   jame, _psuv_, nøvr, _гаму_, 
   {{0x1d09e470,0x9f400004,0x6364001f,0x7e68005c}},	//   сели_, ffhã_, _መቆጣጠ, rogp, 
   {{0x69c1e471,0x44206f52,0x00000000,0x00000000}},	//   eame, njj_, --, --, 
   {{0x69c1e472,0x6f58020a,0x3c8c0150,0x00000000}},	//   fame, _дарё_, _ﺨﺎﺼﹰ_, --, 
   {{0x69c1e473,0x3cfc0218,0xef10004b,0x735c0a7c}},	//   game, _tsuv_, _ګټې_, יכוח, 
   {{0xe8e00016,0x6a6400c6,0x4420009f,0x1ce4031c}},	//   _đợi_, بطول, kjj_, _ཨཱི_, 
   {{0xb09c0375,0x8880010b,0x99dc0306,0x574410d6}},	//   ביזר, нлыж, viňu, зноб, 
   {{0x2be02ce6,0xa9e40150,0xf66400cf,0x42780092}},	//   _नाता, _ﺍﻋﯩﺴ, денү, _በጥንት_, 
   {{0x3d2000b0,0x44202112,0x786c0450,0x764800e5}},	//   _tūwā_, ejj_, tøvs, تیبِ_, 
   {{0x88dc0eac,0x9cf800cc,0xd7c8691d,0x00000000}},	//   _বৈঠক, _আপুন_, _هوشه_, --, 
   {{0xb4dc01ad,0x786c12e8,0x25e00037,0x00000000}},	//   _डमी_, røvs, _काथी_, --, 
   {{0xe8e80003,0xa3dc0cb4,0x00000000,0x00000000}},	//   _འདོག, _डार_, --, --, 
   {{0x10a5847f,0x51640137,0x80c4000d,0x00000000}},	//   зиан, зүмү_, _लिखइ, --, 
   {{0x260802e5,0x00000000,0x00000000,0x00000000}},	// [36960] ियरी_, --, --, --, 
   {{0xf8a40131,0x157c0116,0x00000000,0x00000000}},	//   _ۋة_, _ﺭﻭﺳﯩ, --, --, 
   {{0x3a3c0d04,0xc3b40115,0x00000000,0x00000000}},	//   khup_, _מליץ_, --, --, 
   {{0x69c1e474,0x3ea40113,0x0d2000cf,0x00000000}},	//   xame, ínta_, нүбү, --, 
   {{0xe8e80003,0x2be00825,0x7dc08efe,0x2bc80ebb}},	//   _འདེག, _नादा, رقون, रणला, 
   {{0x68e4049b,0x8cd000e1,0x0ae802c9,0x00000000}},	//   _äidi, _ठिठो, مربي_, --, 
   {{0xd9f9e475,0xc5c4045e,0x00000000,0x00000000}},	//   ्यंत_, ষ্টপ, --, --, 
   {{0x69c000db,0xb9c000d1,0x00000000,0x00000000}},	//   uame, ىقىي, --, --, 
   {{0xa3dc1533,0xcb0800ec,0x00000000,0x00000000}},	//   _डाल_, _گيان_, --, --, 
   {{0xdc28021a,0xa81401d5,0x00000000,0x00000000}},	//   _وسله_, фдош, --, --, 
   {{0x69c1e476,0x25ac0005,0xcb08a864,0x00000000}},	//   pame, ñelo_, _ديان_, --, 
   {{0x25848cae,0x69c05f39,0x3a3c047e,0x09e478d2}},	//   _lūlū_, qame, chup_, _ходн, 
   {{0x786c14f5,0x4420002d,0x00000000,0x00000000}},	//   røvr, tjj_, --, --, 
   {{0xa3dc0490,0x7b0403b2,0xaad0000d,0xab5c00de}},	//   _डाळ_, _órtú, _सटाक, _ceļg, 
   {{0xf31401c0,0xd8840214,0xc34c0092,0xc6a4444e}},	//   ндрэ, _تهوی, _ባዘጋጀ, _эрли, 
   {{0x4420037e,0x258400de,0x30a800eb,0x00000000}},	//   sjj_, _pūlī_, _ওয়েস, --, 
   {{0x236c068f,0xa15800c7,0xc058003b,0x00000000}},	// [36970] łej_, цаау_, біж_, --, 
   {{0xdfd00720,0x70c800c7,0x00000000,0x00000000}},	//   ئيا_, ñohẽ, --, --, 
   {{0x93740220,0xef1400db,0x00000000,0x00000000}},	//   _жұрт_, нүрө, --, --, 
   {{0xdd9022be,0x9d543ccf,0x5cf402bf,0x270c0118}},	//   نوا_, ونات, дяку, _měn_, 
   {{0x61ec2b92,0xdb01e477,0x320801c6,0x25a80200}},	//   mfal, _jelö, _эхэн_, _mfal_, 
   {{0x61ede478,0x00000000,0x00000000,0x00000000}},	//   lfal, --, --, --, 
   {{0xe8e90d57,0xdb000793,0x25a80368,0xdea001d5}},	//   _འདུག, _lelö, _ofal_, _شیشی, 
   {{0x61ede479,0xcdcc004b,0x0f800014,0x81b800cc}},	//   nfal, _نښه_, _شینُ, _ঘাঁ_, 
   {{0xa3dc0574,0xdb0001b8,0x61ede47a,0x42780092}},	//   डला_, _nelö, ifal, _በጥናት_, 
   {{0x3a3d2fb8,0x25a80429,0x6824007f,0x61ec17da}},	//   shup_, _afal_, _kòdy, hfal, 
   {{0x5b24007b,0x00000000,0x00000000,0x00000000}},	//   _تفضل, --, --, --, 
   {{0xdb01e47b,0x7bc1e47c,0x59f801f4,0x00000000}},	//   _belö, lanu, _федя_, --, 
   {{0x61ec0bed,0x1fd40729,0xb3b80003,0x00000000}},	//   dfal, স্যস, _དབྱུ, --, 
   {{0x7bc1e47d,0x61ede47e,0xe8140118,0xb604013a}},	//   nanu, efal, _थोपा_, dnář, 
   {{0x03a01d18,0xb0c00034,0xe8240050,0xd251e47f}},	//   тисо, शीनग, _سروٝ, ننس_, 
   {{0x7bc00516,0x61ec0bed,0xdd84121e,0xe73007d6}},	//   hanu, gfal, _مڈ_, _حصه_, 
   {{0xdb000730,0x10a401d5,0x00000000,0x00000000}},	// [36980] _gelö, физн, --, --, 
   {{0x61ede480,0x61e800c5,0xdb00032e,0x00000000}},	//   afal, _öeln, _aflí, --, 
   {{0x441804ac,0x7bc1e481,0x71c4016c,0xd37003e6}},	//   _וויס, danu, _панҷ, _شێرک, 
   {{0xab5c00de,0x00000000,0x00000000,0x00000000}},	//   _jeļe, --, --, --, 
   {{0x7bc19130,0x8c45e482,0x25e00037,0x8c880114}},	//   fanu, меде, _कासी_, ољка_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x160c19e5,0xdb00054e,0x27340241,0xab3801f4}},	//   ियार_, _aflâ, _múnú_, япку_, 
   {{0x2be00574,0x7bc00140,0xbea00120,0x00000000}},	//   _नावा, aanu, _јатк, --, 
   {{0x7bc019f6,0xcce400db,0xf9640006,0x00000000}},	//   banu, _تسزي, дрэй_, --, 
   {{0x25e02413,0x7bc1e483,0xa3dc07f7,0x61ec01d3}},	//   _काही_, canu, _डाइ_, zfal, 
   {{0x61ede484,0x7fd40a1e,0xf8013716,0x79e402dd}},	//   yfal, וויס_, тчын, _ﺍﻋﯩﻤ, 
   {{0xa4d40845,0xa7fc0790,0x61ec0009,0x00000000}},	//   номі, nlız, xfal, --, 
   {{0x0935e485,0x61ec2ff9,0x67d40108,0x00000000}},	//   _تراج, vfal, _золу, --, 
   {{0x61ec0b1d,0xca680137,0x81b800cc,0xdb00000d}},	//   wfal, _الچۇ_, _ঘাই_, _eelõ, 
   {{0x61ede486,0x25a8038f,0x82340efc,0xf76c48ca}},	//   tfal, _tfal_, وررا, _پاو_, 
   {{0x7bc1e487,0xddd800a2,0x00000000,0x00000000}},	//   zanu, dowş, --, --, 
   {{0x7bc1e488,0xe0d80d30,0xa3dc01ad,0x00000000}},	// [36990] yanu, ядач_, _डाऊ_, --, 
   {{0x61ede489,0x7bc1e48a,0x00000000,0x00000000}},	//   sfal, xanu, --, --, 
   {{0x7bc1e48b,0x61ede48c,0x9df9e48d,0x09d40154}},	//   vanu, pfal, знет_, থ্যা, 
   {{0x7bc0b33d,0x6f84009d,0x00000000,0x00000000}},	//   wanu, тууж, --, --, 
   {{0xb1e404a9,0x00000000,0x00000000,0x00000000}},	//   _шәрқ, --, --, --, 
   {{0xdb85e48e,0x628de48f,0x00000000,0x00000000}},	//   нгли, lmao, --, --, 
   {{0x2be194ac,0x628de490,0xdab80006,0xaac40116}},	//   _नारा, omao, чылі_, پتىن, 
   {{0x6455e491,0x7bc1e492,0xbf7001e1,0xa7fc0db1}},	//   hizi, sanu, _gbàṣ, mlıy, 
   {{0x6455e493,0x2d5800c9,0xa7fde494,0x00000000}},	//   kizi, _жить_, llıy, --, 
   {{0x7bc1e495,0x00000000,0x00000000,0x00000000}},	//   qanu, --, --, --, 
   {{0x6455e496,0x25e01533,0xa7fc0ac1,0xe9d80137}},	//   dizi, _काशी_, nlıy, чкө_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x98e40597,0x25e046c7,0x358402a9,0xa7fc0205}},	//   _أكتو, _कारी_, ъқиб, hlıy, 
   {{0x6455a13e,0xa7fc247e,0x00000000,0x00000000}},	//   gizi, klıy, --, --, 
   {{0x9f5000e4,0xdb0000d8,0x94843160,0x00000000}},	//   _mazó_, _telõ, дыңд, --, 
   {{0xc320b0b9,0x628d279f,0x64540099,0xa7fc0139}},	//   ымск, gmao, aizi, dlıy, 
   {{0x6455e497,0xe81452f2,0x2be09856,0x8fd00166}},	// [369a0] bizi, _थोडा_, _नाला, ләвә, 
   {{0x645405fe,0x628c0421,0x3fe1845e,0xefd00023}},	//   cizi, amao, лжув, ብሩዎ_, 
   {{0x26140073,0xa7fc08a9,0x2d9801e1,0x00000000}},	//   धाची_, glıy, _ńre_, --, 
   {{0x4d65e498,0x8d6406a6,0xf9842279,0xba900150}},	//   нкев, нвее, _مب_, _ﺟﺎﻻﯕ, 
   {{0x25e0033f,0x00000000,0x00000000,0x00000000}},	//   कलती_, --, --, --, 
   {{0x8f740212,0xbca0007b,0x00000000,0x00000000}},	//   _зубі, دموي, --, --, 
   {{0x25e0084a,0xd1c00092,0x2bb40b26,0x3f64014b}},	//   _काली_, _ዴኤታ_, ुरबा, _зиро_, 
   {{0x645415e6,0x3f78008f,0x37000327,0x28d42c2e}},	//   zizi, _זאלס, _མནྟལ_, _दिदि, 
   {{0x6455e499,0x0d8430ba,0x2d800327,0x00000000}},	//   yizi, _члан, żieb_, --, 
   {{0x2d8401a6,0x2ef80166,0x6454002f,0x78d000c7}},	//   _izme_, _kprf_, xizi, ыжьх, 
   {{0x8ad43ded,0x998c01a6,0x9cec0327,0x00000000}},	//   _ستائ, rkeš_, _ལཱོས, --, 
   {{0x25e00490,0x6455e49a,0xbb380375,0x3cf40037}},	//   _काळी_, wizi, _מעבי, _एहमे_, 
   {{0x6455e49b,0xa7fc2737,0x00000000,0x00000000}},	//   tizi, zlıy, --, --, 
   {{0xa7fc0baa,0xe85401d5,0x64540489,0xe2f802dd}},	//   ylıy, _جنتد, uizi, мегі_, 
   {{0x6455e49c,0x00000000,0x00000000,0x00000000}},	//   rizi, --, --, --, 
   {{0x645541bd,0xa3dc1533,0x2d8401fa,0x62240131}},	//   sizi, _डाक_, _ozme_, خىرل, 
   {{0x6455e49d,0x628de49e,0xe2981870,0x7bcd2c5b}},	// [369b0] pizi, rmao, заң_, _œcum, 
   {{0xa7fc62c7,0x6455e49f,0xb6040064,0x628de4a0}},	//   tlıy, qizi, _įšil, smao, 
   {{0xc2c803c7,0x3f6407a5,0xf7cc0150,0x00000000}},	//   _عبدل_, хтаб, _ﻛﯘﻳﺪ, --, 
   {{0xebbc037e,0x62340116,0xa7fc0e51,0xf770008f}},	//   _dj中_, _рему, rlıy, אקע_, 
   {{0x9f500005,0xa3d46620,0x3134014b,0xa7fc9f9f}},	//   _pazó_, _हया_, _беяр, slıy, 
   {{0x50a00131,0xdb00032e,0xa7fc5775,0xfbd0115a}},	//   _ئەلل, _aflá, plıy, اتش_, 
   {{0xcb64c89b,0x2d840205,0x8c400f06,0x5e58020f}},	//   каше_, _ezme_, реще, _живя_, 
   {{0x6e9460a9,0xc1340092,0x00000000,0x00000000}},	//   _бису, _የመድኃ, --, --, 
   {{0x08c084d8,0x66e8016b,0x98141374,0xd94424fc}},	//   абын, _mɛku, نبدا, тепи, 
   {{0x39a41aac,0x3ea00023,0xa3dc01f9,0x00000000}},	//   _bísó_, _kujt_, _डाग_, --, 
   {{0xdbf8033f,0x888001c6,0xead40354,0x00000000}},	//   _włók, рлэж, _бохь, --, 
   {{0xaee40055,0x997400c7,0x3ea00240,0xd4a41321}},	//   _akṛp, _иулш, _mujt_, кимй, 
   {{0xa3dc1fbc,0x3ea0036e,0x00000000,0x00000000}},	//   डलं_, _lujt_, --, --, 
   {{0x987804ac,0xc7a04bf5,0x07a0074d,0x161c012d}},	//   _קאַט, _кишк, _кашн, _बचकर_, 
   {{0x291800b0,0x02c0130f,0x96640354,0x96a801d5}},	//   ārae_, ийро, _икке, _ўкиб_, 
   {{0x244c05be,0x00000000,0x00000000,0x00000000}},	//   džmu_, --, --, --, 
   {{0x28c40d2c,0xc68c01f7,0x00000000,0x00000000}},	// [369c0] लीपि, _بِي_, --, --, 
   {{0x161850dc,0x68e403cd,0x147452d4,0x3f9c03e0}},	//   धाकर_, _åide, _جابج, _şuur_, 
   {{0xdff400fd,0x03d4008f,0xd138001f,0x4f944986}},	//   ыять, _בוים_, ኩላቸው, трау, 
   {{0xdd9800e8,0xab5c00e2,0xd1b80133,0xefd00023}},	//   _laňu_, _neļa, _تادا_, ብኩዎ_, 
   {{0x9e640592,0xbb4c00b5,0xada400d1,0x82bc0327}},	//   دالن, _nhlカ_, ваҗл, _མཆོའ, 
   {{0xd7dc0490,0xdd9800e8,0x8fa40261,0x320000ad}},	//   _मागच, _naňu_, _јаве, leiy_, 
   {{0x28d40037,0xab5c0171,0x28c416ae,0x00000000}},	//   _दिहि, _beļa, लीनि, --, 
   {{0x32000428,0xab5c00e2,0xb00400cd,0xdb0002d2}},	//   neiy_, _ceļa, _duḥs, _oflæ, 
   {{0x2d840b91,0xdd98002e,0xc278011a,0x3b800ce8}},	//   _uzme_, _baňu_, ורקי, лләг, 
   {{0x32000076,0xd90c00f2,0x383000c7,0x00000000}},	//   heiy_, ثیه_, иныр, --, 
   {{0xdd9800e8,0x32000428,0xdb00f113,0x250400b8}},	//   _daňu_, keiy_, _aflæ, _kuṇṭ, 
   {{0x79a00b3e,0x25ac0165,0x39a402d2,0x53b40417}},	//   _крше, ùel_, _vísó_, ңғыр_, 
   {{0xba1425aa,0x0fe00574,0xdb1001e1,0xa7fc0205}},	//   _جينا_, _पांढ, _ìfòp, rnıb, 
   {{0x68e1e4a1,0x00000000,0x00000000,0x00000000}},	//   mumd, --, --, --, 
   {{0x68e1e4a2,0xe4e400f7,0x00000000,0x00000000}},	//   lumd, _өспү, --, --, 
   {{0xf65000b2,0x32000086,0xdde00219,0x3ea0036e}},	//   _وئي_, geiy_, _žuže, _rujt_, 
   {{0x68e18068,0x660c0270,0x82380092,0xa0c40472}},	// [369d0] numd, _iaak, _የወረዳ, ايطو, 
   {{0xa3dc05f9,0xe28400d1,0x14d800df,0x00000000}},	//   _डाट_, _ﯪﺩﻩﻡ_, _אַטמ, --, 
   {{0x660de4a3,0x50a40184,0x26cc0221,0x32000086}},	//   _kaak, _ҡурҡ, nsdo_, beiy_, 
   {{0x660c1a7f,0x2ca40263,0x68e1e4a4,0x3ea00200}},	//   _jaak, _bumd_, kumd, _vujt_, 
   {{0x660de4a5,0x629de4a6,0xd7f00208,0x68e001a9}},	//   _maak, _iiso, hĩa_, jumd, 
   {{0x660de4a7,0x629de4a8,0x68e003e0,0x00000000}},	//   _laak, _hiso, dumd, --, 
   {{0x60cde4a9,0x629de4aa,0x824802d3,0x20002d3b}},	//   lsam, _kiso, _ሓረስታ, mehi_, 
   {{0x60cde4ab,0x2001e4ac,0x629de4ad,0xdd9568e8}},	//   osam, lehi_, _jiso, _бабы, 
   {{0x629de4ae,0xab5c005f,0x6d5c00dc,0x00000000}},	//   _miso, _veļa, _śrav, --, 
   {{0x629dd72a,0x2001e4af,0x60cde4b0,0x7c84c9fd}},	//   _liso, nehi_, isam, _рубе, 
   {{0x660de4b1,0x60cde4b2,0x6d68054e,0x629de4b3}},	//   _baak, hsam, ăsaţ, _oiso, 
   {{0x60cde4b4,0x629de4b5,0x2001e4b6,0x660c0548}},	//   ksam, _niso, hehi_, _caak, 
   {{0x660de4b7,0x2001e4b8,0x82bc031c,0xfbc400e1}},	//   _daak, kehi_, _མཆུའ, _रजाम, 
   {{0x60cde4b9,0x629dc699,0x32000086,0x15e40037}},	//   dsam, _aiso, weiy_, _कावर_, 
   {{0x660de4ba,0x629c982e,0x43400139,0x60cde4bb}},	//   _faak, _biso, берв, esam, 
   {{0x629c0e02,0x660c0a49,0x626415c3,0x673c00cc}},	//   _ciso, _gaak, لاقق, ørje, 
   {{0x7645e4bc,0x60cde4bd,0x200003a0,0x320008e7}},	// [369e0] _iliy, gsam, fehi_, reiy_, 
   {{0x660de4be,0x629c00a9,0x2ca40477,0x17d40183}},	//   _zaak, _eiso, _rumd_, ত্ৰি, 
   {{0x7645e4bf,0x660de4c0,0x60cde4c1,0x629de4c2}},	//   _kliy, _yaak, asam, _fiso, 
   {{0x629de4c3,0x60cde4c4,0x660c03d9,0x28d40bae}},	//   _giso, bsam, _xaak, _दिलि, 
   {{0x764401c8,0x200001f7,0x62a8005f,0x60cc01e7}},	//   _mliy, behi_, ēpoš, csam, 
   {{0x3ed004a9,0x0ba80594,0xc0cc0023,0x00000000}},	//   شقۇر, راتى_, ብኹም_, --, 
   {{0xa3d40490,0x7645e4c5,0x68e1e4c6,0x629de4c7}},	//   हणत_, _oliy, wumd, _yiso, 
   {{0x629c3ce4,0x4ea40184,0x2be006e3,0x8c440166}},	//   _xiso, _арҡа, _नाका, _өебе, 
   {{0xc7c401c0,0xf77c0213,0xdbf8012d,0x4d6400c0}},	//   лсни, əçi_, głów, _скав, 
   {{0x660de4c8,0x76459802,0x68e087a7,0x3cf805d0}},	//   _saak, _aliy, rumd, _אלמנ, 
   {{0x660de4c9,0x7644406e,0x60cde4ca,0x39900023}},	//   _paak, _bliy, zsam, _ማዓልቲ_, 
   {{0x66e8013f,0x60cde4cb,0x660c011f,0x76440076}},	//   _bɛkr, ysam, _qaak, _cliy, 
   {{0x629de4cc,0x660c06e4,0x09340214,0x68e06edb}},	//   _riso, _vaak, _حراج, qumd, 
   {{0x7644e765,0x660de4cd,0x25e02ba2,0x3cf4007d}},	//   _eliy, _waak, _काकी_, _एहसे_, 
   {{0x629de4ce,0x660c0af5,0x7644007f,0x2001e4cf}},	//   _piso, _taak, _fliy, vehi_, 
   {{0x7644020c,0xaca401f2,0x629c350e,0x20001e2b}},	//   _gliy, ghịr, _qiso, wehi_, 
   {{0x629de4d0,0xa3d58011,0x2001e4d1,0x6b880175}},	// [369f0] _viso, _копч, tehi_, _lzdg, 
   {{0x60cc66f2,0x2be00d41,0x629da1c1,0xb4fc0677}},	//   rsam, _नागा, _wiso, _טפחי, 
   {{0x60cc32ff,0x629de4d2,0x2be80307,0x82bc031c}},	//   ssam, _tiso, च्छू_, _མཆིའ, 
   {{0x20008075,0x60cde4d3,0xceb5e4d4,0xaca401f2}},	//   sehi_, psam, рәр_, chịr, 
   {{0x1d08eb89,0x2001e4d5,0x4430002e,0x16c001ad}},	//   тели_, pehi_, _kox_, _शब्ब, 
   {{0xab5c00da,0x44301574,0x9f05e4d6,0x1ed800ec}},	//   _ceļo, _jox_, _پورو, _لارڊ_, 
   {{0x44300483,0x15e4000d,0xdd04c6da,0x6d5c00b8}},	//   _mox_, _कालर_, ısız, _śrat, 
   {{0x4431e4d7,0x224804ce,0xaac40b24,0x00000000}},	//   _lox_, nhak_, حتون, --, 
   {{0x7e79e4d8,0xa3d40490,0x644400d8,0xddd8007f}},	//   _ikup, हणा_, _olhi, viwň, 
   {{0x4431e4d9,0xdb007e42,0xdbf80210,0x00000000}},	//   _nox_, _aflå, rłów, --, 
   {{0x22481187,0x7e78025c,0x7644033b,0x7b647e32}},	//   khak_, _kkup, _pliy, _стае, 
   {{0x6445e4da,0x998c0de2,0xc9540345,0xab5c00ef}},	//   _alhi, ndeŋ_, الیش_, _zeļo, 
   {{0x7e784b44,0x44301bfd,0x7ae1e4db,0x2248034c}},	//   _mkup, _box_, lunt, dhak_, 
   {{0x7ae0010a,0xc0d402d3,0x224801f5,0x3a3c020c}},	//   ount, ርከስ_, ehak_, lkup_, 
   {{0x4431e4dc,0x3a3de4dd,0xc5f80f22,0xe2b46816}},	//   _dox_, okup_, ইয়া_, йстэ, 
   {{0xc2401cb6,0x7645e4de,0x7e780425,0x3a3c03a2}},	//   онск, _uliy, _nkup, nkup_, 
   {{0x4fe9e4df,0x4430527a,0x01a42cdd,0x8678011a}},	// [36a00] кман_, _fox_, ркук_, _ברקו, 
   {{0x7e79e4e0,0x7ae1e4e1,0x4431e4e2,0x3b040007}},	//   _akup, kunt, _gox_, kwnq_, 
   {{0xeaf42413,0x7ae1e4e3,0x3a3c0194,0x224800a3}},	//   _आहेत_, junt, kkup_, bhak_, 
   {{0x2249e4e4,0x7ae1e4e5,0x02000153,0x00000000}},	//   chak_, dunt, _дзюн, --, 
   {{0xcfa85ec2,0x443003be,0xdde80345,0x7ae098ff}},	//   _لازم_, _yox_, ارمه_, eunt, 
   {{0x7ae1e4e6,0x7e782935,0x80bc012d,0x00000000}},	//   funt, _ekup, _लौटे, --, 
   {{0x7ae1e4e7,0xaa59e4e8,0xbb5000b5,0x0a680117}},	//   gunt, лику_, _ribボ_, крии_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7ae004cc,0xc864011c,0x00000000,0x00000000}},	//   aunt, итои, --, --, 
   {{0x2248020c,0x3a3cabc1,0xa7fde4e9,0xa7b80124}},	//   zhak_, akup_, anın, ылоу_, 
   {{0x44300207,0x7ae1e4ea,0x22480589,0xdb000066}},	//   _rox_, cunt, yhak_, _nglè, 
   {{0x4431e4eb,0x64440076,0x7e78031c,0xb95000f2}},	//   _sox_, _slhi, _xkup, _ژئوت, 
   {{0x443084d6,0x64440211,0x368805f5,0x21280548}},	//   _pox_, _plhi, рсэн_, xxah_, 
   {{0xad64004d,0x7c7c0092,0x1adc00cc,0x00000000}},	//   _đừn, ስፈልግ_, _ভৈয়া, --, 
   {{0x22481060,0xeaf40574,0x81c4005b,0x00000000}},	//   thak_, _आहोत_, ищае, --, 
   {{0x6aa833e6,0x656c01c4,0x25e05d4f,0x3cf4000d}},	//   _mudf, _txah, _काटी_, _एहले_, 
   {{0x2249c3a2,0x644427cc,0x4431e4ec,0x6aa801e4}},	// [36a10] rhak_, _tlhi, _tox_, _ludf, 
   {{0x7e788847,0x2249e4ed,0x7ae081f1,0x44300381}},	//   _skup, shak_, yunt, _uox_, 
   {{0x7ae01709,0xceb40058,0x3b040007,0x63a402d0}},	//   xunt, йәт_, xwnq_, _ighn, 
   {{0xf1c402fb,0x7ae008a1,0xab5c00de,0x00000000}},	//   ruší_, vunt, _ceļm, --, 
   {{0x7ae1e4ee,0xdca4657f,0xdb00004e,0x6aa8035a}},	//   wunt, щали, _iglé, _audf, 
   {{0x7ae1e4ef,0x7e7800d2,0xaca401f2,0xec780212}},	//   tunt, _wkup, chọr, апі_, 
   {{0xd1f00020,0x5478008f,0x28c405d7,0x7ae180cd}},	//   _ሃሳብ_, נְננ, लीसि, uunt, 
   {{0x7e79e4f0,0x2011e4f1,0x915c0051,0x85040118}},	//   _ukup, _hazi_, _hắc_, षबाट_, 
   {{0x20115877,0x3a3de4f2,0x26d801ed,0x63a4014f}},	//   _kazi_, rkup_, áron_, _oghn, 
   {{0xad242928,0x6aa80009,0x63a40042,0x69c40037}},	//   _بىكى, _fudf, _nghn, _õien, 
   {{0x20105c1e,0x6aa80bed,0x2259e4f3,0x915c004d}},	//   _mazi_, _gudf, _omsk_, _mắc_, 
   {{0x7d19e4f4,0x673c022c,0x22580158,0x63a5e4f5}},	//   _krus, ørja, _nmsk_, _aghn, 
   {{0x7d180077,0x95740724,0x0a10ebd3,0x38c80835}},	//   _jrus, сынч, _رووح, _руен_, 
   {{0x7d1814af,0x998c0432,0x00000000,0x00000000}},	//   _mrus, ndeō_, --, --, 
   {{0xf771e4f6,0x434008da,0x00000000,0x00000000}},	//   _باش_, перв, --, --, 
   {{0x63a4047e,0x28c40034,0xa7fc00ac,0x7d184350}},	//   _eghn, लीवि, hnıl, _orus, 
   {{0xaf380020,0x412406ed,0x6ad00f22,0x915c0208}},	// [36a20] _በሚመለ, бото_, সংযো, _bắc_, 
   {{0xc0f40020,0x20100311,0x648801a8,0x9404004b}},	//   ፈፃሚ_, _cazi_, lþin, _اوده, 
   {{0x1ea82266,0x1fb514bb,0x2011e4f7,0x2d8000da}},	//   لاني_, юстр, _dazi_, ļiem_, 
   {{0x7d19e4f8,0x25740521,0xc2b063e1,0xfb8800d1}},	//   _brus, ụle_, _хөрш, _ﺗﯜﺯﯛ, 
   {{0x7d19e4f9,0x2011e4fa,0x604001f2,0xfce00faf}},	//   _crus, _fazi_, _ịmek, зочо, 
   {{0x2011e4fb,0xfbcc04a9,0x7d18bdd8,0xac18fddb}},	//   _gazi_, ىتى_, _drus, року_, 
   {{0x7d19e4fc,0x78b80254,0x00000000,0x00000000}},	//   _erus, epuv, --, --, 
   {{0x2010379d,0x409003e6,0x7f38008f,0x00000000}},	//   _zazi_, _ولێر, _געלו, --, 
   {{0x2011e4fd,0x22b0012d,0x06a00150,0x00000000}},	//   _yazi_, _mąka_, _ﺍﻟﻘﯩ, --, 
   {{0x6aa803cb,0x00000000,0x00000000,0x00000000}},	//   _tudf, --, --, --, 
   {{0x7d1813d5,0xab5c00ef,0x80780677,0x00000000}},	//   _zrus, _meļk, רניצ, --, 
   {{0x7d18a955,0x00000000,0x00000000,0x00000000}},	//   _yrus, --, --, --, 
   {{0x67d407d5,0x7d1801a9,0x891401d3,0x7a78010f}},	//   _долу, _xrus, _دبائ, _גראס, 
   {{0x490c0037,0x058401a9,0x00000000,0x00000000}},	//   _तैयो_, _қуйм, --, --, 
   {{0x6304036b,0x915c0051,0x00000000,0x00000000}},	//   غورل, _rắc_, --, --, 
   {{0x20100173,0x915c0208,0xc64400db,0x00000000}},	//   _sazi_, _sắc_, _دئتى, --, 
   {{0xf19454ea,0x6f1de4fe,0xa7fc06be,0x9f4401e1}},	// [36a30] зить, _arrc, hnım, _ùlú_, 
   {{0x7d19e4ff,0x60c8031c,0x2010427b,0x03c401a9}},	//   _rrus, _ħemd, _qazi_, _усим, 
   {{0x201116e8,0x7d181505,0x6234084c,0xe1f800db}},	//   _vazi_, _srus, _дену, _кенч_, 
   {{0x2011c9d8,0x505002d3,0x1df80104,0xd37001f7}},	//   _wazi_, _መጨረሽ, реды_, _آهٽ_, 
   {{0x351c010f,0x915c0051,0x6fcc01ec,0x5c741d4d}},	//   ָוונ, _tắc_, _ﺗﯘﺭﺷ, олдт, 
   {{0x7d18062c,0xbbb000bc,0x802400ae,0x00000000}},	//   _vrus, ँडेक, _ارحم, --, 
   {{0x1a29ccf3,0x61fc0165,0x00000000,0x00000000}},	//   ижки_, _kbsl, --, --, 
   {{0x69c4000d,0xdb200248,0x00000000,0x00000000}},	//   _õiel, _ètít, --, --, 
   {{0xbbe8f73d,0x3f8000a2,0x00000000,0x00000000}},	//   _مرام_, _hyju_, --, --, 
   {{0xeb480166,0x78b80064,0x00000000,0x00000000}},	//   рчәк_, rpuv, --, --, 
   {{0x61fc05dd,0x69c033b8,0x68e0002d,0xd6280276}},	//   _obsl, bbme, armd, аоне_, 
   {{0x78b816b5,0x46d807f7,0x00000000,0x00000000}},	//   ppuv, _भिरह, --, --, 
   {{0xdb0004ce,0x64880008,0xa3d401bc,0x1414003b}},	//   _aflø, rþin, हणं_, оєвр, 
   {{0x61fde500,0x15e40037,0x00000000,0x00000000}},	//   _absl, _काकर_, --, --, 
   {{0x03a1e501,0x78a0009a,0x78a80321,0x648801a8}},	//   диро, _iinv, _hugv, pþin, 
   {{0x78a0022c,0xcb1004ae,0x00000000,0x00000000}},	//   _hinv, ולל_, --, --, 
   {{0x69dc016b,0x78a1e502,0x00000000,0x00000000}},	// [36a40] ɔred, _kinv, --, --, 
   {{0x78a00003,0x70540133,0xa7fc0205,0x00000000}},	//   _jinv, سۆزا, ynım, --, 
   {{0x78a1e503,0x78a805e4,0x4f080166,0x00000000}},	//   _minv, _lugv, рнен_, --, 
   {{0x0d85e504,0x2bb470b0,0x78a1e505,0xf8a4007b}},	//   олен, ुर्थ, _linv, _ية_, 
   {{0xc278025f,0x7ee00aaf,0x78a000c7,0x3f80032e}},	//   _כרטי, ككەن, _oinv, _eyju_, 
   {{0x78a0ed26,0xcee9e506,0x8f74109a,0xdff40153}},	//   _ninv, _پرسن_, _дубі, _нясь, 
   {{0x78a80158,0x29183a71,0x00000000,0x00000000}},	//   _augv, āram_, --, --, 
   {{0x26d85f5b,0x78a003ac,0x78a80162,0xa2cc01ad}},	//   árom_, _ainv, _bugv, _तबस्, 
   {{0x78a00489,0x0d7401d3,0x391000c7,0x00000000}},	//   _binv, _بیشک_, дмыр, --, 
   {{0x60c800ee,0x78a00055,0x00000000,0x00000000}},	//   _çeme, _cinv, --, --, 
   {{0x2d8416fd,0xa7fc0139,0x00000000,0x00000000}},	//   _hyme_, lnık, --, --, 
   {{0xa5f811ed,0x78a1e507,0xa2b00073,0x00000000}},	//   щему_, _einv, _आंब्, --, 
   {{0x78a0bb75,0x7e9804ae,0x1fd40154,0xe818009d}},	//   _finv, יסטו, স্টস, _голч_, 
   {{0x78a00139,0x00000000,0x00000000,0x00000000}},	//   _ginv, --, --, --, 
   {{0x78a80112,0xab5c00ef,0xa2941cd0,0x00000000}},	//   _zugv, _beļi, заві, --, 
   {{0x78a00d27,0xab5c00e2,0xa7fc0139,0x5f9400c7}},	//   _zinv, _ceļi, knık, ҧиат, 
   {{0x25a8007d,0x78a00399,0x3fa8026a,0xa6dc00cc}},	// [36a50] _igal_, _yinv, ањем_, _বহিয়, 
   {{0x27ecb484,0x00000000,0x00000000,0x00000000}},	//   ngdn_, --, --, --, 
   {{0x998800df,0xb36c0092,0x908801d3,0xa31800d4}},	//   _ĵaŭ_, አቸውን_, حملے_, _ужну_, 
   {{0x6115e508,0xbb300150,0x00000000,0x00000000}},	//   _едму, _ﺯﺠﻨ_, --, --, 
   {{0x61ec005f,0xfeb80214,0x212c010e,0x00000000}},	//   mgal, _چارت_, _çeh_, --, 
   {{0x1138011a,0x1b4801d5,0x00000000,0x00000000}},	//   _התשל, йзли_, --, --, 
   {{0xfe70c895,0x78a08295,0x57e80184,0x1ca404d3}},	//   _قدر_, _rinv, ҡдим_, _کێتی_, 
   {{0xefc80016,0x78a005e4,0x25a9e509,0xdc5401d3}},	//   _đỉnh_, _sinv, _ngal_, _کررک, 
   {{0x61ede50a,0x78a003bd,0x7c840114,0x00000000}},	//   igal, _pinv, _дуже, --, 
   {{0x25a80005,0x78a0014f,0xf6140037,0x61ec010b}},	//   _agal_, _qinv, _तोड़ि_, hgal, 
   {{0x61ede50b,0x7e680208,0x00000000,0x00000000}},	//   kgal, ongp, --, --, 
   {{0x63b4068f,0x25a80161,0x78a80af9,0x95e42c07}},	//   eczn, _cgal_, _tugv, कलेट_, 
   {{0x61ede50c,0x78a1e50d,0x28f80006,0x998401e2}},	//   dgal, _tinv, _мець_, _علتو, 
   {{0x25a9e50e,0xf30405f5,0x78a0020b,0x61edbe5f}},	//   _egal_, мжгү, _uinv, egal, 
   {{0x7e681c06,0x96b80228,0x25ac1d35,0x61ec01ab}},	//   kngp, _уулу_, žela_, fgal, 
   {{0xcb101a4c,0x673c6583,0x25740521,0x95c801a9}},	//   עלן_, ärje, ụla_, _улиб_, 
   {{0x068000fd,0x41240484,0xab5c00ef,0x00000000}},	// [36a60] _ягън, пото_, _veļi, --, 
   {{0x61ede50f,0x2d84017a,0x4f94084c,0x00000000}},	//   agal, _ryme_, преу, --, 
   {{0xc4380302,0x2d840ffb,0x61ec0009,0x25a8010e}},	//   _התיי, _syme_, bgal, _ygal_, 
   {{0x2d843eba,0xa2b01cd2,0x61ede510,0x10a4014b}},	//   _pyme_, _आंत्, cgal, _нимн, 
   {{0x7cd402bf,0x3ebc0427,0x7ae0002f,0x9f4000ae}},	//   змір_, _čute_, ernt, rghá_, 
   {{0x26d801ed,0xe2a802f2,0x7e680051,0x00000000}},	//   árok_, _داین_, angp, --, 
   {{0xaab8468e,0x69c40254,0x00000000,0x00000000}},	//   زگار_, _õiek, --, --, 
   {{0x2d840493,0x5b1800db,0x00000000,0x00000000}},	//   _tyme_, زعىڭ_, --, --, 
   {{0x63b4006d,0xfce1e511,0x7ae00198,0x98f000f1}},	//   yczn, _пото, arnt, نګوا, 
   {{0x61ede512,0xbc602678,0x25a800a3,0x3cf8000d}},	//   zgal, _звук, _sgal_, ोबरे_, 
   {{0xa2b05325,0x61ed28bc,0xd1c001f3,0xbb4000d8}},	//   _आंध्, ygal, ትራት_, _пефк, 
   {{0x61ece23f,0x15d000d1,0x1b0001f0,0x00000000}},	//   xgal, _ﻛﯩﺮﻩ, _рӯшн, --, 
   {{0xab5c00e2,0x61ede513,0x00000000,0x00000000}},	//   _ceļv, vgal, --, --, 
   {{0xf8b4011a,0x61ec9055,0x00000000,0x00000000}},	//   _צפוי_, wgal, --, --, 
   {{0x61ede514,0xe704006c,0xb7f8011a,0x00000000}},	//   tgal, _آستی, _הפות, --, 
   {{0x61ede515,0x25a8f917,0xf314009d,0x64400254}},	//   ugal, _ugal_, эдсэ, ölib, 
   {{0xe4d8004b,0xf77c0790,0xe474009b,0x05c00118}},	// [36a70] _بوخت_, ğçe_, _олињ, _व्यब, 
   {{0x3015e516,0x61ede517,0x03c44a2f,0xdb0008a5}},	//   ндур, sgal, _эсим, _aflý, 
   {{0x61ec01d3,0xa27801f4,0x00000000,0x00000000}},	//   pgal, _мбоу_, --, --, 
   {{0x61ec009a,0xb6a40051,0xdb2000e5,0x00000000}},	//   qgal, _nhẫ, _ütés, --, 
   {{0xa3b0561f,0x6e9405f5,0xdc7400c7,0x00000000}},	//   _ओला_, хицу, мыкь, --, 
   {{0xf1c40306,0x7ae001c7,0x998c0210,0x00000000}},	//   prší_, trnt, ydeł_, --, 
   {{0x09bc3fae,0x7bc0002f,0x6e4800e5,0x00000000}},	//   _ইয়া, rbnu, árbó, --, 
   {{0xdd942ba5,0xab081473,0xca040801,0x18b40063}},	//   _жабы, ستىق_, днъж_, мљор, 
   {{0xdd90004b,0xd78800ec,0xbb7400f2,0x00000000}},	//   _شوئ_, ڪندو_, _کلاچ_, --, 
   {{0xefc801dc,0x574448a9,0x1038010f,0x00000000}},	//   _định_, дноб, ַגרע, --, 
   {{0x55e4016c,0xd788742b,0xf41c00fe,0xcfb4011a}},	//   монб, تندو_, _নকলৰ_, ולתי_, 
   {{0xab5c00de,0x6b74010a,0x00000000,0x00000000}},	//   _ceļu, _ялху, --, --, 
   {{0x66e8016b,0x00000000,0x00000000,0x00000000}},	//   _mɛky, --, --, --, 
   {{0x2c0000cd,0x00000000,0x00000000,0x00000000}},	//   ल्पं_, --, --, --, 
   {{0xfa080003,0x00000000,0x00000000,0x00000000}},	//   _ཁྲོན_, --, --, --, 
   {{0x22140107,0x00000000,0x00000000,0x00000000}},	//   нфур, --, --, --, 
   {{0x321c00bc,0x644004cc,0xd1840108,0xc690011a}},	// [36a80] ěvy_, ölic, флай, _באה_, 
   {{0x15e4012d,0x00000000,0x00000000,0x00000000}},	//   कलकर_, --, --, --, 
   {{0x66e80134,0x2919e518,0x00000000,0x00000000}},	//   _bɛky, ārai_, --, --, 
   {{0x93ec084a,0xd17400f7,0xc3300677,0x6d5c06be}},	//   _जाँच_, _жыгы, _סור_, _əraf, 
   {{0xfa08025c,0x21748e9e,0x00000000,0x00000000}},	//   _ཁྲེན_, _зурр, --, --, 
   {{0x7c8000c9,0xdd98010e,0xae3401e2,0x987c013d}},	//   куще, _jaňy_, _ګورډ, kçıl_, 
   {{0xfd640022,0xce480006,0xb6a40051,0x00000000}},	//   _kyrỹ, _дзве_, _phẫ, --, 
   {{0xddc80139,0x00000000,0x00000000,0x00000000}},	//   _imeş, --, --, --, 
   {{0x93ec09d9,0x67d412e7,0xe5e40116,0x00000000}},	//   _जांच_, нопу, _ﺋﯚﻟﻜ, --, 
   {{0x8b240261,0xed5802a9,0x00000000,0x00000000}},	//   _одзе, _доғ_, --, --, 
   {{0x26d9e519,0xd8f41f70,0xda6c00ec,0x00000000}},	//   éro_, وزیک, _گڏو_, --, 
   {{0x26d800e4,0x00000000,0x00000000,0x00000000}},	//   ĩro_, --, --, --, 
   {{0x25ac2a25,0xfaa000c0,0x00000000,0x00000000}},	//   želo_, _рацо, --, --, 
   {{0xc2b8007b,0x2a64045a,0x00000000,0x00000000}},	//   قارئ_, limb_, --, --, 
   {{0xdd9800a2,0x2c0000dc,0x00000000,0x00000000}},	//   _daňy_, ल्यं_, --, --, 
   {{0xa0c40ada,0xc0d40092,0x00000000,0x00000000}},	//   فيرو, ይረሱ_, --, --, 
   {{0x05740131,0x6b8801bf,0xe4d806c2,0x00000000}},	// [36a90] _تاغد, _lydg, _عودت_, --, 
   {{0xdfd0530d,0x2a6400a8,0xbf6404d3,0xdb000112}},	//   ايا_, himb_, وداو, _pflü, 
   {{0x2dbc02e3,0xf2c400d1,0x3f8401a8,0x00000000}},	//   _ịkụ_, _исян, ænu_, --, 
   {{0x53980375,0x12c401ec,0xdd904706,0x00000000}},	//   _מיתו, _ﺩﺨﻠﻭ, هوا_, --, 
   {{0xe3a40517,0x22480309,0xac9c0023,0x00000000}},	//   _تشکی, mkak_, _ውዒሎም_, --, 
   {{0x6b89e51a,0x2248005a,0xfc000bd6,0x00000000}},	//   _bydg, lkak_, токү, --, 
   {{0x7e7400dd,0xfa08025c,0x1b4854ea,0x6b8803cb}},	//   _قارئ, _ཁྲུན_, язки_, _cydg, 
   {{0x99d478e3,0x224801c6,0x6b880175,0x9f400158}},	//   رتبا, nkak_, _dydg, gghå_, 
   {{0x5c745c9e,0x2248011f,0x18a4014b,0x00000000}},	//   _злат, ikak_, наим, --, 
   {{0xdb00011f,0x2248d68d,0xad2400f1,0x00000000}},	//   _eglá, hkak_, _ګرېو, --, 
   {{0x2249e51b,0x96641695,0x6b88015d,0x6aa400df}},	//   kkak_, екне, _gydg, ĉifr, 
   {{0x673c01e3,0x99740117,0x00000000,0x00000000}},	//   ärja, _пулш, --, --, 
   {{0x3fcc0150,0x00000000,0x00000000,0x00000000}},	//   _ﻗﺘﺎﻧ, --, --, --, 
   {{0xb4b00dba,0xd1c00023,0x00000000,0x00000000}},	//   _ओढी_, ትያት_, --, --, 
   {{0x57bc07f7,0x24680092,0x6440000d,0x00000000}},	//   ोरीह, ሰማራት_, ölia, --, 
   {{0x3ddc0066,0x00000000,0x00000000,0x00000000}},	//   _nduw_, --, --, --, 
   {{0xd0245026,0x26d801a2,0xc0e19128,0xd6e0009e}},	// [36aa0] нмай, árov_, лотк, _বহিয, 
   {{0x7525e51c,0x2a6431b1,0x15780050,0x69c40254}},	//   _iriz, zimb_, _ؤژھ_, _õiev, 
   {{0x7524009b,0xcd34158b,0x8e0801af,0x8de400ae}},	//   _hriz, کراب, знев_, فكاه, 
   {{0x2248005a,0x6b9c03b2,0x673c06ea,0x00000000}},	//   ckak_, _úrgi, ørji, --, 
   {{0xac187804,0x3ddc0368,0xac8401b9,0x6b88005c}},	//   долу_, _dduw_, вҳал, _sydg, 
   {{0x3ddc0086,0x7d2000f1,0x75240200,0x00000000}},	//   _eduw_, افون, _mriz, --, 
   {{0x2a640099,0xff040276,0x00000000,0x00000000}},	//   timb_, _перк_, --, --, 
   {{0xbea01ee1,0x320001d5,0xc3300677,0x00000000}},	//   _баск, nfiy_, רוה_, --, 
   {{0xc864a752,0xaca40131,0x3b80151e,0xfa300136}},	//   етни, _агаһ, кләг, ارىد, 
   {{0xd90c04d3,0x224801c6,0x6b880ea0,0x2a640472}},	//   تیه_, zkak_, _tydg, simb_, 
   {{0xf8018bf4,0x7525e51d,0x442c0208,0x00000000}},	//   учын, _ariz, _đg_, --, 
   {{0x7525e51e,0x2248009d,0x6d5c002b,0x00000000}},	//   _briz, xkak_, _śray, --, 
   {{0x7524084c,0xfa080003,0xe7280133,0x00000000}},	//   _criz, _ཁྲིན_, ستگۆ_, --, 
   {{0x7525e51f,0xddc81f7f,0x38c804fb,0xf77c2737}},	//   _driz, _mješ, _راهی_, şça_, 
   {{0x7525e520,0xddc8a068,0xf2e41b0a,0x49901a4b}},	//   _eriz, _lješ, люто, _جیکر, 
   {{0x1fcc015b,0x26dc0455,0x998c0b3d,0x26d80f91}},	//   _লাইস, _ivvo_, lješ_, árou_, 
   {{0x60f845b3,0x2249e521,0x22b0033f,0x7524b8b4}},	// [36ab0] ьная_, rkak_, _mąki_, _griz, 
   {{0x224801c6,0x998c041a,0x00000000,0x00000000}},	//   skak_, nješ_, --, --, 
   {{0x661de522,0x9df81dde,0x00000000,0x00000000}},	//   odsk, днет_, --, --, 
   {{0xddc80e3c,0x60c81330,0x00000000,0x00000000}},	//   _bješ, _çemo, --, --, 
   {{0xed58090b,0x81d402a6,0x661cd41c,0x628c0332}},	//   ної_, _সাপ_, idsk, mlao, 
   {{0x628cdd97,0x00000000,0x00000000,0x00000000}},	//   llao, --, --, --, 
   {{0x628c0b23,0xa7fc00ac,0x998c110c,0x3d100037}},	//   olao, hnıs, dješ_, _धनवे_, 
   {{0x661de523,0x25ac892f,0x628c2877,0x00000000}},	//   jdsk, želj_, nlao, --, 
   {{0x661c7c1d,0x628c01ab,0xdcf8007b,0x394801d3}},	//   ddsk, ilao, _زفات_, ács_, 
   {{0x661c2960,0x628de524,0x1ea800aa,0xa90416ac}},	//   edsk, hlao, _راځي_, ابين, 
   {{0x628c0174,0x81d40154,0x3d1801e1,0x00000000}},	//   klao, _সান_, bàwá_, --, 
   {{0xe9d0ab88,0xd9982be7,0x320001b9,0x27941945}},	//   _هغه_, _قنات_, xfiy_, ышыр, 
   {{0x26dd175e,0x957450d5,0xd9440063,0x00000000}},	//   _evvo_, тынч, _јели, --, 
   {{0x661c3e1d,0x7524030a,0x628c0165,0x3dd400fe}},	//   adsk, _vriz, elao, _হাফল, 
   {{0xd010006c,0x60dc74b5,0x75240156,0x96944965}},	//   یلر_, _avsm, _wriz, _ириш, 
   {{0x628de525,0x7525e526,0x69c400c5,0xd2500472}},	//   glao, _triz, _õiet, جنر_, 
   {{0xc0cc044e,0x7525e527,0x60c8010e,0x3200022e}},	// [36ac0] _ኣባል_, _uriz, _çeml, rfiy_, 
   {{0xddc81727,0x6454245f,0x35580014,0xf9840133}},	//   _rješ, chzi, _ٲسکھ_, _ۆب_, 
   {{0x628c06d9,0x5284007b,0x38c401e1,0x91e401af}},	//   blao, _للدك, _yírò_, _ионе, 
   {{0xf9840050,0xddc81f7f,0x628c0589,0x00000000}},	//   _نب_, _pješ, clao, --, 
   {{0x0b8c0023,0xd7e00073,0x1ea807fc,0x00000000}},	//   _ምቕያር_, पणाच, رامي_, --, 
   {{0xddc81f7f,0x00000000,0x00000000,0x00000000}},	//   _vješ, --, --, --, 
   {{0x661de528,0x00000000,0x00000000,0x00000000}},	//   ydsk, --, --, --, 
   {{0x797806d6,0xddc83c52,0x7989e529,0x00000000}},	//   _ṅwan, _tješ, _bygw, --, 
   {{0xa02c044e,0x661c0010,0xc7c5e52a,0x25ac0427}},	//   _ሰማእታ, vdsk, ксни, želk_, 
   {{0x79880042,0x38c401e1,0x941806be,0xe854868d}},	//   _dygw, _sírò_, _tipə_, اندد, 
   {{0x2ac80241,0xf8f4037e,0x998c0010,0xa5f9e52b}},	//   _dìbò_, _eラ_, rješ_, нену_, 
   {{0x996402dd,0x79880042,0x661d4a89,0x2cac00e5}},	//   _өтіл, _fygw, udsk, _hidd_, 
   {{0x2cac0522,0x661c1455,0x3dd400bd,0x2ab801e1}},	//   _kidd_, rdsk, _হামল, _héb_, 
   {{0x661c074d,0x26d801ed,0x67d40137,0xa2c400d1}},	//   sdsk, áros_, _соку, ләмк, 
   {{0x2cac0221,0x81d40154,0xe0440022,0xf4340139}},	//   _midd_, _সাব_, қьаҿ, шерэ, 
   {{0x673c0579,0x2cac0a40,0x26d80024,0x06641411}},	//   ørju, _lidd_, šros_, _جاتپ, 
   {{0x2ab800e8,0xe2980131,0x628c0dd6,0x6454007f}},	// [36ad0] _léb_, даң_, rlao, phzi, 
   {{0x628c0c67,0x9f35b74d,0x2cac01c7,0x25d400db}},	//   slao, лезі, _nidd_, _جۇڭگ_, 
   {{0x628d70f1,0x00000000,0x00000000,0x00000000}},	//   plao, --, --, --, 
   {{0x5d540bd6,0x2cac0042,0xc0e401d9,0x6234022e}},	//   лкет, _aidd_, _لہرن_, _сему, 
   {{0x2cac04e6,0x00000000,0x00000000,0x00000000}},	//   _bidd_, --, --, --, 
   {{0x10000243,0x2cac06be,0xf04441b9,0x1fcc00eb}},	//   र्दश_, _cidd_, _кэсо, _লাকস, 
   {{0x8c40a2ed,0x2cac03b2,0xbea46518,0xddd8007f}},	//   сеще, _didd_, _ашай, viwņ, 
   {{0x9e2400db,0x00000000,0x00000000,0x00000000}},	//   _حىرو, --, --, --, 
   {{0x6bd40136,0x7ae400f1,0x8c6800f1,0xe3d80154}},	//   اتۇر, روکې_, _ګټلې_, _তানব, 
   {{0x2cade52c,0x2ab801e1,0x69a40032,0x43bc00cd}},	//   _gidd_, _féb_, шлыҡ, ्रोऽ, 
   {{0xdb00032e,0xd7c80133,0xe3d800cc,0x00000000}},	//   _aflö, ووکه_, তলাব, --, 
   {{0x4ae000aa,0xcf900375,0x2cade52d,0x00000000}},	//   _اړول, מטי_, _zidd_, --, 
   {{0x49d852d4,0x2c0000dc,0xb60801ef,0xf484085b}},	//   _سانگ_, ल्वं_, _arší, لاسی, 
   {{0x972407fc,0x88c005d9,0xd388030c,0x00000000}},	//   _مفتو, _اڪيل, ейге_, --, 
   {{0x91e4c6dd,0x044012e7,0xa7840133,0x35c40107}},	//   лове, щерн, _پشوو, _кайҳ, 
   {{0x85b00075,0xb9fc0092,0x00000000,0x00000000}},	//   _гәрч, _ሁን_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [36ae0] --, --, --, --, 
   {{0x8fa5e52e,0xc4d002e4,0x20c401f0,0x00000000}},	//   газе, _הגז_, рқро_, --, 
   {{0xd6e002f5,0x2cac143a,0xc7d40375,0x1fb4084c}},	//   _বহুপ, _ridd_, רועי_, рсур, 
   {{0x2cac04c4,0x4dd5e52f,0xdb200248,0xd5c00055}},	//   _sidd_, اتاس, _ètùt, bjāś_, 
   {{0x8c45e530,0x2cac020c,0x2ab80129,0x00000000}},	//   леде, _pidd_, _séb_, --, 
   {{0x2ab80c6a,0xcb1806ed,0x00000000,0x00000000}},	//   _péb_, еќи_, --, --, 
   {{0xcfa80133,0x356c0092,0x2cac00e5,0x00000000}},	//   _ساسم_, ሰራበት_, _vidd_, --, 
   {{0x25ac2a0d,0x2574063f,0x00000000,0x00000000}},	//   želi_, ụli_, --, --, 
   {{0x2ab80c6a,0xebc40131,0xc68c00d1,0xa8540798}},	//   _wéb_, _кәйн, ۋېت_, икич, 
   {{0x27f800db,0xdc2800f1,0x00000000,0x00000000}},	//   ürn_, _لسمه_, --, --, 
   {{0xa634177b,0x36d401c0,0x3dd400fe,0x8034008f}},	//   анні, лдээ_, _হাতল, אניע_, 
   {{0xe7e00316,0x9f6401d3,0x00000000,0x00000000}},	//   _गएका_, ütés_, --, --, 
   {{0xdaa00137,0x58fc0327,0x72d400cd,0x00000000}},	//   _بەيپ, _དཱགས_, _āveṇ, --, 
   {{0xe4800209,0x63542766,0x83840139,0x81d40154}},	//   _ösüş, авгу, гыбе, _সাধ_, 
   {{0x4df401ad,0xe75801ec,0xf2c4588c,0x845c0023}},	//   ीभाई_, _шикі_, йстн, ሰማማዕ_, 
   {{0x1fdc0303,0x7790036b,0xdb080129,0x60c80205}},	//   मण्ड, _دیپا, înée, _çemk, 
   {{0xf6741176,0x00000000,0x00000000,0x00000000}},	// [36af0] _داوخ, --, --, --, 
   {{0x5d3401d3,0x1fc421f3,0x00000000,0x00000000}},	//   یفائ, рраҳ, --, --, 
   {{0xceb4052f,0x44fde531,0x22940212,0xd1380092}},	//   иәт_, lî_, _виня, _ከመቼው, 
   {{0xf318004e,0x00000000,0x00000000,0x00000000}},	//   _союш_, --, --, --, 
   {{0x44fc24ba,0x11d8011a,0x00000000,0x00000000}},	//   nî_, _שחשב, --, --, 
   {{0xdca5e532,0x2c0005c0,0x00000000,0x00000000}},	//   шали, ल्लं_, --, --, 
   {{0x5b34084c,0xed8800d1,0xf4140a7c,0x0b1400ae}},	//   рэлу, ксәк_, מפס_, لقوة_, 
   {{0x2f1802bf,0xdd0800d0,0x64b401f9,0x00000000}},	//   _щось_, môžt, ंदाळ, --, 
   {{0xd7fc068f,0x7e681c06,0x00000000,0x00000000}},	//   мσв_, migp, --, --, 
   {{0x7e684e9b,0x6fe0012c,0x96b9e533,0x7c8400a7}},	//   ligp, mácí, куму_, _субе, 
   {{0xb0640730,0xa3d8007d,0xa2b03042,0x00000000}},	//   lmäß, ारन_, _आंग्, --, 
   {{0x7e681c06,0x69c40254,0x00000000,0x00000000}},	//   nigp, _õiep, --, --, 
   {{0xb0640e78,0xdb0001e7,0x95941cb8,0x00000000}},	//   nmäß, _nglú, ршні, --, 
   {{0x7e68113c,0x7d18014b,0x629ce263,0x38b80165}},	//   higp, _msus, _ahso, _iêr_, 
   {{0x386400ca,0x7e681b26,0x38b80156,0xb0640e78}},	//   _imnr_, kigp, _hêr_, hmäß, 
   {{0x7d19e534,0x38b803bd,0x212c05be,0x877808d8}},	//   _osus, _kêr_, _šeha_, _באצי, 
   {{0x7d180134,0xb5940051,0x6fe001ef,0x00000000}},	// [36b00] _nsus, cạpc, jácí, --, 
   {{0x629c94c9,0xd0100035,0x38b86729,0x8598011a}},	//   _ehso, تلط_, _mêr_, _בשפו, 
   {{0x7d19e535,0xd5b802ab,0x38b805c7,0x7e6802d0}},	//   _asus, _इलाज, _lêr_, figp, 
   {{0x4d480220,0xd1b800cf,0x00000000,0x00000000}},	//   кпен_, _جادا_, --, --, 
   {{0x76441529,0xfc4400d7,0x0ba800d1,0x00000000}},	//   _moiy, _číry_, ھاتى_, --, 
   {{0x0ba80aaf,0xcb09e536,0x00000000,0x00000000}},	//   پاتى_, вхид_, --, --, 
   {{0xfbcc00bd,0xe3e800c8,0x2fd801c7,0x7d19e537}},	//   _রাখত, אַפֿ, _ierg_, _esus, 
   {{0x38b8f0ec,0x76440076,0x44fc011f,0x6f1c02d0}},	//   _bêr_, _noiy, yî_, _isrc, 
   {{0x6e200393,0x2fd80166,0x00000000,0x00000000}},	//   _iamb, _kerg_, --, --, 
   {{0x6e21e538,0x38b80385,0xa8541422,0xbc61e539}},	//   _hamb, _dêr_, скоч, _двук, 
   {{0x6e21e53a,0x2fd8084c,0x76440076,0xcab80022}},	//   _kamb, _merg_, _boiy, _рызц_, 
   {{0xf76de485,0x6e21e53b,0x44fde53c,0x76440076}},	//   باً_, _jamb, tî_, _coiy, 
   {{0x6e21e53d,0x38b80dd4,0xdb100267,0x48b40108}},	//   _mamb, _gêr_, öför, _тщет, 
   {{0x76440086,0x44fc006a,0xe2f89684,0x2fd80166}},	//   _eoiy, rî_, легі_, _nerg_, 
   {{0x6e2002ea,0x66e81086,0x629c0076,0x3dd400eb}},	//   _oamb, _сулҳ_, _phso, _হাসল, 
   {{0x6e21e53e,0x09a800bd,0x2fd80526,0x69c00048}},	//   _namb, _গ্যা, _aerg_, ncme, 
   {{0x2fd86040,0x6f1c022e,0x69c001e7,0xf12400c7}},	// [36b10] _berg_, _asrc, icme, жьхо, 
   {{0x6e21e53f,0x83849f4d,0xb0340137,0x3cfc01d5}},	//   _aamb, _выме, онуш, _rquv_, 
   {{0x6e208732,0x644403a2,0x7e680522,0x7d19e540}},	//   _bamb, _iohi, tigp, _ssus, 
   {{0x6445e541,0x4430004d,0xb0640e78,0x442001d3}},	//   _hohi, _hnx_, tmäß, ldj_, 
   {{0x6e21e542,0x6445e543,0x2fd800ad,0x61fc02d0}},	//   _damb, _kohi, _ferg_, _icsl, 
   {{0x9f3584e2,0x6444ef45,0x6e20127b,0x38b80165}},	//   _легі, _johi, _eamb, _rêr_, 
   {{0x6445e544,0x6e200c11,0x09ac0c58,0x270c0134}},	//   _mohi, _famb, ছুমা, _yɛne_, 
   {{0x6e207f0b,0x6445e545,0x38b8ab50,0x73780375}},	//   _gamb, _lohi, _pêr_, יגוד_, 
   {{0x7d19e546,0x97d800d6,0x7e7800c7,0x64440014}},	//   _usus, льну_, _ijup, _oohi, 
   {{0x6e21e547,0x6445e548,0x38b96f79,0x76440076}},	//   _zamb, _nohi, _vêr_, _soiy, 
   {{0x6e21e549,0x9b95e54a,0x38b80a85,0x44f0003d}},	//   _yamb, _الات, _wêr_, _བཀུར_, 
   {{0x644402b5,0x6e21e54b,0x61fc00a3,0x69c00356}},	//   _aohi, _xamb, _ncsl, ccme, 
   {{0x6445e54c,0x78b80140,0x3864003e,0x5d78010f}},	//   _bohi, qquv, _tmnr_, ראָק, 
   {{0x6445743b,0x7e7807f5,0x76440810,0x00000000}},	//   _cohi, _ljup, _woiy, --, 
   {{0x6445e54d,0x7e78035b,0x76440208,0x2fd80166}},	//   _dohi, _ojup, _toiy, _rerg_, 
   {{0x64440488,0x7e79e54e,0x2fd9afdc,0xe6c400ae}},	//   _eohi, _njup, _serg_, _بتوي, 
   {{0x6e21e54f,0x44300998,0x2fd8167a,0x6445e550}},	// [36b20] _ramb, _fnx_, _perg_, _fohi, 
   {{0x7e79e551,0x6445e552,0x395c0165,0x44200175}},	//   _ajup, _gohi, izus_, cdj_, 
   {{0x6e21e553,0x2fd9e554,0x8ee84f33,0x81d40154}},	//   _pamb, _verg_, умев_, _সার_, 
   {{0x6e21e555,0x6445e556,0xa3d800c5,0x8fa40022}},	//   _qamb, _zohi, ारथ_, _ҳаге, 
   {{0x6e21346d,0x7e78a249,0x395c0218,0x5e244352}},	//   _vamb, _djup, jzus_, تعلق, 
   {{0x6e200161,0x7e79e557,0x6444036b,0x395c005f}},	//   _wamb, _ejup, _xohi, dzus_, 
   {{0xa3d8547d,0x395c0489,0x64400e03,0x62800129}},	//   ारत_, ezus_, ölii, élog, 
   {{0x6e21e558,0x00000000,0x00000000,0x00000000}},	//   _uamb, --, --, --, 
   {{0xed5000f8,0x69c0407c,0xbea000c0,0x48a83dab}},	//   _تھا_, rcme, _хатк, лтом_, 
   {{0x69c1e559,0x31600165,0xa774084c,0x27fc0051}},	//   scme, iziz_, жлоч, _qcvn_, 
   {{0x6445e55a,0x3ae82580,0x395c0165,0xc8b0036b}},	//   _rohi, _مبنی_, azus_, _کلتک, 
   {{0x644407d6,0x9a700020,0xa5f9e55b,0x09284fca}},	//   _sohi, ብዛኛው_, шему_, _مستي_, 
   {{0x81d41aba,0x6445e55c,0x368805f5,0x27fc004d}},	//   _সাল_, _pohi, ссэн_, _tcvn_, 
   {{0x2768034d,0x6444036b,0xf6500137,0x00000000}},	//   _پشتی_, _qohi, _ۋئي_, --, 
   {{0x6445e55d,0x44213476,0x3ef802dd,0x29045397}},	//   _vohi, rdj_, _ءﻭﺯﻯ_, ltma_, 
   {{0x6445e55e,0x21780228,0x442004ce,0x0b8c001f}},	//   _wohi, айбы_, sdj_, _ምንድር_, 
   {{0x6445e55f,0x660de560,0x31341830,0x7e7805ac}},	// [36b30] _tohi, _ibak, петр, _rjup, 
   {{0xb7bc0241,0xf8b00677,0xca9c0023,0x00000000}},	//   _iṣé, פשע_, ልየኩም_, --, 
   {{0x6d4400b0,0x395c0a05,0x61fc00a2,0x2904000d}},	//   äian, zzus_, _tcsl, htma_, 
   {{0x9d549afc,0x395c05b1,0x660c0f85,0xa2940816}},	//   ينات, yzus_, _jbak, _фамі, 
   {{0x660de561,0x00000000,0x00000000,0x00000000}},	//   _mbak, --, --, --, 
   {{0xa3d8cace,0xf77c4890,0x2128047e,0x1b481078}},	//   ारि_, şçi_, mvah_, изли_, 
   {{0xda58cd5f,0x60cde562,0x3cec010a,0x660de563}},	//   ириш_, lpam, srgv_, _obak, 
   {{0x7e780309,0x660c005a,0x998c00a2,0x00000000}},	//   _ujup, _nbak, gdeş_, --, 
   {{0x60cde564,0x395c030a,0x3a3c0010,0x6af801d9}},	//   npam, uzus_, rjup_, لى۪س_, 
   {{0x660ccd30,0x60cde565,0x395de566,0xd7080108}},	//   _abak, ipam, rzus_, аное_, 
   {{0x660c04ba,0x2904020c,0x21280455,0x00000000}},	//   _bbak, atma_, hvah_, --, 
   {{0xd02000bd,0x60cc0240,0xeb480137,0x2129b748}},	//   নায়_, kpam, _учук_, kvah_, 
   {{0x9584005e,0x60cc16a3,0x2c0005f9,0x21280369}},	//   ілге, jpam, _रामू_, jvah_, 
   {{0x660c2558,0x225803b2,0xc31000eb,0xe8840024}},	//   _ebak, _alsk_, হিনি_, _егіп, 
   {{0x7ae004ba,0x00000000,0x00000000,0x00000000}},	//   nsnt, --, --, --, 
   {{0x660c0521,0x316001c0,0x03a0014b,0xd5480798}},	//   _gbak, tziz_, фисо, _впие_, 
   {{0x60cc3604,0xe3b8013e,0x20c84cec,0x61e800ef}},	// [36b40] gpam, рбӣ_, مبلي_, _ķelt, 
   {{0x225812ed,0x81d4015b,0x660c022e,0x10a533d4}},	//   _elsk_, _সাঃ_, _zbak, цизн, 
   {{0x225803b2,0x11d400c6,0xb8d80327,0x60cc0022}},	//   _flsk_, _وتحد, _ཇང_, apam, 
   {{0x1ea83c19,0x212822ce,0x00000000,0x00000000}},	//   ماني_, bvah_, --, --, 
   {{0xd13001d9,0xfce123a6,0xacf81f39,0x00000000}},	//   _غمس_, дочо, ёнку_, --, 
   {{0xc6140a28,0x09d0078a,0xac184c04,0xf8a4007b}},	//   _तस्य_, सर्य, соку_, _زة_, 
   {{0xe2a84dc1,0x8b640066,0x00000000,0x00000000}},	//   _خاین_, غاتم, --, --, 
   {{0xdb14010b,0x29040135,0x00000000,0x00000000}},	//   _çaýy, ttma_, --, --, 
   {{0x998cf3aa,0x00000000,0x00000000,0x00000000}},	//   rdeş_, --, --, --, 
   {{0x2905e567,0xa7fc2fbe,0xc86400c6,0x3cfc00cd}},	//   rtma_, lnız, تطبي, _रमते_, 
   {{0x2905e568,0xa3d87db3,0x660c05b1,0x2129e45d}},	//   stma_, ारस_, _pbak, zvah_, 
   {{0x60cc03f0,0x1db009bb,0xe5b40150,0x4668022e}},	//   ypam, ुँचत, яймы, рром_, 
   {{0x60cc0113,0xc9741e2f,0x7a7800df,0xdb2001e1}},	//   xpam, _بااث, _דראס, _àtòs, 
   {{0xc1d013e0,0x21280ffb,0x11780240,0x00000000}},	//   तर्ग, vvah_, _ተመራጺ_, --, 
   {{0xb1c800b4,0x3494013e,0x60cc03f0,0x424446ee}},	//   _ọrịa_, фарр, wpam, охаб, 
   {{0x21280fb7,0x660de569,0xa3d8b577,0xb68800db}},	//   tvah_, _ubak, ारह_, _وپول_, 
   {{0x60b5e56a,0xf1943f51,0xc32c2dfc,0xf41003d4}},	// [36b50] سمائ, дить, رەڭ_, ায়ৰ_, 
   {{0x3dd4045e,0x2129e56b,0x071c0037,0xf0e82b62}},	//   _হাইল, rvah_, _बनाव_, زىمى_, 
   {{0x60cde56c,0x24bc03d4,0x00000000,0x00000000}},	//   spam, _অবিহ, --, --, 
   {{0x60cde56d,0x21280369,0x1df80eed,0x9e08007b}},	//   ppam, pvah_, седы_, صيتك_, 
   {{0x628c0618,0x60cc0113,0x02d800c5,0xf6540677}},	//   moao, qpam, _बबुन, וצף_, 
   {{0x64540cf9,0x628c0421,0x8cf01870,0x00000000}},	//   nkzi, loao, ركىش, --, 
   {{0x7bc00200,0x00000000,0x00000000,0x00000000}},	//   rcnu, --, --, --, 
   {{0x7290044e,0xdb0005d5,0x628de56e,0x00000000}},	//   _መእተዊ_, _iglü, noao, --, 
   {{0x6e9402bf,0xae041d00,0xa7fc013d,0x00000000}},	//   _циту, _توقى, lnıy, --, 
   {{0x628c00b0,0xad240c50,0x0d2004a9,0x02d80037}},	//   hoao, _زىمى, _чүшү, _बबून, 
   {{0xe7bc032c,0x25040055,0x87e000f1,0x6e3801e7}},	//   ोड़प, _duṭṭ, رګول, _úabá, 
   {{0xfbcc1971,0x64540115,0x628c00d8,0x00000000}},	//   _स्तम, ekzi, joao, --, 
   {{0x4a980bd9,0xf498001f,0xa7fc03b9,0x00000000}},	//   _פינג, _መቅረብ_, hnıy, --, 
   {{0xddc8c75b,0xb9d8001f,0xc1d00150,0x00000000}},	//   _njež, _ባሉ_, _ﺘﺘﺭﺍ, --, 
   {{0x998c00f3,0x81bc00cc,0x973401c6,0x03a000c7}},	//   njež_, _ীয়_, _хэлч, еиро, 
   {{0xc240030d,0x90c401ec,0x94040066,0x00000000}},	//   ннск, збае, _کوده, --, 
   {{0xddc81711,0xd4680104,0x00000000,0x00000000}},	// [36b60] _bjež, _гипе_, --, --, 
   {{0xb4d82d6c,0x628c0421,0x64540112,0x6b840e78}},	//   ाठी_, aoao, ckzi, ßigk, 
   {{0x0dc90b20,0xa3d800ab,0x628c00e4,0x03b8011a}},	//   були_, ारर_, boao, _לציל, 
   {{0x9e65e56f,0x628c00b5,0x3dd400cc,0xa0680022}},	//   وانن, coao, _হাউল, баӡа_, 
   {{0xacf802bf,0x7e60017a,0x00000000,0x00000000}},	//   інку_, ënpa, --, --, 
   {{0xdb0001e7,0xddc800dc,0x00000000,0x00000000}},	//   _ngló, _kleś, --, --, 
   {{0x8fa40064,0x2504002b,0x6b780124,0x00000000}},	//   _хаве, _kuṣṭ, цәас_, --, 
   {{0xdde86a15,0xfaa000ee,0x2504002b,0x3f780a7c}},	//   _ورقه_, ншын, _juṣṭ, _האלס, 
   {{0x851805f9,0x67d40798,0x69342099,0x250400cd}},	//   _पैंट_, мопу, بکار, _muṣṭ, 
   {{0x47840224,0xddc8012d,0x00000000,0x00000000}},	//   зымб, _oleś, --, --, 
   {{0x29180209,0xda6405d9,0x26d850b6,0xc8280023}},	//   ňra_, _ڪالي, èro_, እምማን, 
   {{0x250400b8,0x00000000,0x00000000,0x00000000}},	//   _nuṣṭ, --, --, --, 
   {{0x09a803f4,0x4e0c00dc,0xa3d80406,0x89140022}},	//   _গ্রা, ण्यै_, ारल_, _хьец, 
   {{0x25040055,0xaa84010e,0x64540165,0x7ea00254}},	//   _auṣṭ, _duýş, ukzi, mõpe, 
   {{0x628c0270,0x645401f5,0xa2940006,0xded80092}},	//   toao, rkzi, даві, ሮቹን_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x644025c6,0x250400dc,0xb28400c7,0x00000000}},	// [36b70] ölis, _duṣṭ, хырк, --, 
   {{0x628c0607,0x4424002d,0x76880166,0x00000000}},	//   soao, _ûn_, gıyf, --, 
   {{0xddc91f18,0x00000000,0x00000000,0x00000000}},	//   _vjež, --, --, --, 
   {{0x81400131,0x00000000,0x00000000,0x00000000}},	//   _كۆزن, --, --, --, 
   {{0xece802bf,0x00000000,0x00000000,0x00000000}},	//   зділ_, --, --, --, 
   {{0x5fe12df6,0x3c9001d5,0x7ea00254,0x00000000}},	//   _फ़िल, ریاز, dõpe, --, 
   {{0x9f040137,0x9aa5df4f,0x09a80011,0x00000000}},	//   _توزو, ومتو, _গ্লা, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3ddc000f,0x7c840276,0xae041d00,0x7ea00254}},	//   _ieuw_, _еуже, _سولى, gõpe, 
   {{0xe89800e5,0x77380023,0x00000000,0x00000000}},	//   ےمیں_, _ክመልሰ, --, --, 
   {{0x3ddc003e,0xd6d800fd,0x88800276,0x7ea00254}},	//   _keuw_, әтү_, тлэж, aõpe, 
   {{0x81d0000e,0x00000000,0x00000000,0x00000000}},	//   হৃত_, --, --, --, 
   {{0xa3d80b9c,0xb4d9e570,0x250400b8,0x00000000}},	//   ारं_, ाठे_, _ruṣṭ, --, 
   {{0x768800fd,0x9860001f,0xddc8012d,0x250400cd}},	//   kıyg, _ስለሆኑ_, _pleś, _suṣṭ, 
   {{0xdb20068c,0x9d080154,0x27f8012d,0x250400cd}},	//   çuèl, লিয়ন_, órne_, _puṣṭ, 
   {{0xcb100375,0x00000000,0x00000000,0x00000000}},	//   כלל_, --, --, --, 
   {{0xc0e02b8e,0x998c003d,0x4938010f,0x00000000}},	// [36b80] котк, jjeż_, ֿגעו, --, 
   {{0x75240928,0xa3d80a28,0x4fe8005e,0x6b840209}},	//   _isiz, ारः_, імен_, şigi, 
   {{0xc4380375,0x260403ce,0x250400dc,0xe0d00145}},	//   _ותיי, _वामी_, _tuṣṭ, نزە_, 
   {{0x90c462d9,0x2c006bf2,0x64a00311,0x47a803d4}},	//   _обме, _राहू_, rţiş, চুকী, 
   {{0x92d46569,0x60c9e571,0x0ca8524d,0xcd3469f2}},	//   _সময়_, _çemp, отки_, براب, 
   {{0x13e003f4,0x3ddc0cf9,0x7525e572,0x76880ac1}},	//   _বাড়, _eeuw_, _msiz, lıyd, 
   {{0x09e0015b,0xff200b01,0x00000000,0x00000000}},	//   _যাবা, _имро, --, --, 
   {{0x75240107,0x32000bfa,0x7688236c,0x00000000}},	//   _osiz, ngiy_, nıyd, --, 
   {{0x7525477f,0xfbcc00dc,0x687c0023,0x094800f5}},	//   _nsiz, _स्वम, _ብለይቲ_, ючки_, 
   {{0x0c24160b,0x47dc2b1b,0x7ea00254,0x00000000}},	//   _імен, _মাহী, rõpe, --, 
   {{0x7525e573,0x7ea00037,0x451000cc,0x26c000c0}},	//   _asiz, sõpe, িয়াক_, _čios_, 
   {{0xf6d0036b,0xc95801d5,0x00000000,0x00000000}},	//   کزید, _мўл_, --, --, 
   {{0x69dc013f,0x7a6400f7,0x98a81b0d,0x752401d3}},	//   ɔrep, _تئلە, _çağ_, _csiz, 
   {{0xfa082fb5,0x00000000,0x00000000,0x00000000}},	//   _གཡོན_, --, --, --, 
   {{0x75240928,0xc76419c5,0x9f40036e,0x00000000}},	//   _esiz, _تاشى, rahë_, --, 
   {{0x768800fd,0x00000000,0x00000000,0x00000000}},	//   gıyd, --, --, --, 
   {{0x661c0070,0x9f4000f2,0x60f82f6a,0x54d801d3}},	// [36b90] mesk, mahé_, яная_, _ٹِپس_, 
   {{0x9f400214,0x260401f9,0xddc80210,0x00000000}},	//   lahé_, _वाडी_, _wjeż, --, 
   {{0x7688294f,0x00000000,0x00000000,0x00000000}},	//   bıyd, --, --, --, 
   {{0x9f4000f2,0x76880205,0xddc80210,0x00000000}},	//   nahé_, cıyd, _ujeż, --, 
   {{0x212c02ea,0xed580212,0x91f40375,0x661c03cd}},	//   _éeh_, мої_, _אמרו_, iesk, 
   {{0x661de574,0x3dd400eb,0x00000000,0x00000000}},	//   hesk, _হাওল, --, --, 
   {{0x661c246f,0xaae40fb4,0x9f4000f2,0x60c800d8}},	//   kesk, نسيو, kahé_, _éemb, 
   {{0xdd945a19,0x200164a8,0xbf18228d,0x00000000}},	//   _забы, lghi_, नबीन_, --, 
   {{0x59c00c2e,0x20000395,0x9f4000f2,0x38980092}},	//   शखबर, oghi_, dahé_, _ህብረቱ_, 
   {{0x2001e575,0x661c0037,0x768808a9,0x00000000}},	//   nghi_, eesk, zıyd, --, 
   {{0x75240083,0x15b850c0,0x25b40213,0xdd9800a2}},	//   _ssiz, зыгы_, ədlə_, _hyň_, 
   {{0x661c4531,0x260472c0,0x9f40020c,0x1a6401b9}},	//   gesk, _वाणी_, gahé_, _سیخی_, 
   {{0x7d0802c4,0x03a001e0,0x04280023,0x00000000}},	//   ntgs, ғито, _ብምጽን, --, 
   {{0x2bacb213,0x6280020c,0x187400df,0x00000000}},	//   टेवा, élon, _רײַך_, --, 
   {{0x81d402a6,0x9694d466,0x9f400066,0xdd9800a2}},	//   _সাজ_, _приш, bahé_, _lyň_, 
   {{0x2001e576,0x752406d9,0x661de577,0x9f4004fb}},	//   eghi_, _tsiz, cesk, cahé_, 
   {{0x7524016c,0xdd980209,0x60dc0368,0x7689b056}},	// [36ba0] _usiz, _nyň_, _cwsm, rıyd, 
   {{0x2000c7cc,0xfbcc02ab,0x76880342,0xc000004e}},	//   gghi_, _स्लम, sıyd, лпук, 
   {{0x91e42b39,0x0dc86a7c,0xbfc8215c,0x00000000}},	//   _поне, пули_, سالە_, --, 
   {{0x4e942002,0xc3300375,0xcd046bb6,0xd1b00424}},	//   رشار, _עור_, ечки, _میزک, 
   {{0xd1741e49,0x60dc0368,0x768800ac,0x04200154}},	//   _чыны, _gwsm, cıye, মারী_, 
   {{0xbb7c0020,0x661c0c57,0xdd9800a2,0x00000000}},	//   _ድንጋጌ_, zesk, _dyň_, --, 
   {{0xbb4406f6,0x9f400214,0x00000000,0x00000000}},	//   فلون_, yahé_, --, --, 
   {{0x0a68036b,0x3ab00139,0x00000000,0x00000000}},	//   ярли_, гәчт, --, --, 
   {{0x0d480592,0xdd9800a2,0x4c840153,0x00000000}},	//   _عشري_, _gyň_, _злав, --, 
   {{0x661c0161,0xa3c4012c,0x9f40020c,0xa85400d4}},	//   wesk, उँछ_, wahé_, ткоч, 
   {{0x661de578,0xa5f9d954,0x9f4000f2,0x260409b2}},	//   tesk, мену_, tahé_, _वादी_, 
   {{0xff7806a9,0x4aa9e579,0xda6c00b2,0xc985e57a}},	//   לטימ, _экен_, _وڏي_, _пули, 
   {{0x661de57b,0x9f400214,0x2bac04af,0xfaa00354}},	//   resk, rahé_, टेरा, _сацо, 
   {{0x9f400066,0xefc00023,0x25ec00bc,0xdde0012d}},	//   sahé_, ስላዊ_, _आएकी_, _żuże, 
   {{0x02a400e6,0x82a411ed,0x84500131,0x661d143e}},	//   ерам, ешае, نىڭچ, pesk, 
   {{0xbb380a7c,0xe3d800eb,0x00000000,0x00000000}},	//   העלי, _তাওব, --, --, 
   {{0xddc949ab,0x41741884,0x15a001ec,0x6ee0002b}},	// [36bb0] _aleş, رارس, _ﺍﺭﺳﯩ, _ādiṣ, 
   {{0x76882c78,0xdd98010e,0x00000000,0x00000000}},	//   rıye, _ryň_, --, --, 
   {{0x20008dfb,0xddc80356,0xe1d80212,0xdf38007b}},	//   rghi_, _cleş, _одні_, بكات_, 
   {{0xa3d8069f,0x768803e0,0x3f84031c,0x00000000}},	//   ारक_, mıyc, ħnu_, --, 
   {{0xceb42751,0xddc9e57c,0x2d580212,0x768815b7}},	//   тәр_, _eleş, ниць_, lıyc, 
   {{0x5aec031c,0x2bd807f7,0x00000000,0x00000000}},	//   _ལྷུམ, डरगा, --, --, 
   {{0x2bac3874,0x00000000,0x00000000,0x00000000}},	//   टेला, --, --, --, 
   {{0xcd4000dd,0x25ec033f,0xaac43346,0x67400023}},	//   _چھوٹ, _आएगी_, دتون, _ንመዋእ, 
   {{0xee85cee5,0xe97802d3,0x0c9400cf,0x17f86a87}},	//   _сыро, _ክትርኢ_, ردۇگ, وردة_, 
   {{0x69a4052f,0x9cb42f84,0x224800a2,0x00000000}},	//   ылыҡ, _شمات, hjak_, --, 
   {{0x245c0241,0x2249e57d,0xd1c0001f,0x27f9e57e}},	//   _aìmo_, kjak_, ስራቅ_, órna_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xceb01a4c,0xd8241ee3,0x2249e57f,0x98e401ee}},	//   ייט_, _адли, djak_, _рсеһ, 
   {{0xdb0c01a8,0x00000000,0x00000000,0x00000000}},	//   _þjóf, --, --, --, 
   {{0x1cc049a6,0x16080574,0x044075e1,0xa8a40798}},	//   _གཤའ_, _वापर_, шерн, _срцк, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xddc800a2,0x236c00df,0x00000000,0x00000000}},	// [36bc0] _sleş, ĝeja_, --, --, 
   {{0xddc8054e,0xb064013d,0x004401e2,0x00000000}},	//   _pleş, kläş, نیټي_, --, 
   {{0x52a8026a,0x2aa800d2,0xdec801ec,0x22480419}},	//   _овом_, lûbe_, еуіл_, bjak_, 
   {{0xcce41001,0xedf40214,0x3e680101,0x00000000}},	//   نستي, ايشگ, وجنی_, --, 
   {{0x260404af,0x8c44113e,0x16080bca,0xa1840150}},	//   _वासी_, кеде, _वानर_, _бұта_, 
   {{0x8fa40022,0x63b8010b,0x00000000,0x00000000}},	//   _ааге, _ýaný, --, --, 
   {{0xbae002d5,0x00000000,0x00000000,0x00000000}},	//   ацый, --, --, --, 
   {{0x09e00154,0x00000000,0x00000000,0x00000000}},	//   _যাহা, --, --, --, 
   {{0x4c1404fb,0x1cc0031c,0xcd04004e,0x29140014}},	//   _لباس, _གཤར_, _шпай, اہتھ_, 
   {{0x2249e580,0x260405f9,0xca78022e,0x00000000}},	//   zjak_, _वाही_, _ertа, --, 
   {{0x3ff80375,0x0ab401ec,0x2814104c,0x2034010f}},	//   ופיע, _ٴحاد, نوکس, אָרש_, 
   {{0xa4d400d4,0x00000000,0x00000000,0x00000000}},	//   ломі, --, --, --, 
   {{0x06e000af,0xda6400c6,0x62800129,0xe9180212}},	//   _कौरव_, _حالي, élom, _чолі_, 
   {{0x2484000d,0x00000000,0x00000000,0x00000000}},	//   õlm_, --, --, --, 
   {{0x2249e581,0xf2c5e582,0x234801d5,0xd3440133}},	//   tjak_, истн, رسآی_, ۆییه_, 
   {{0x3265e583,0xddc800d0,0xca500150,0x057400fb}},	//   атув, _omeš, _ﺎﻁﺊ_, _аҙмы_, 
   {{0x2249e584,0xd34404d3,0xdb00013a,0x00000000}},	// [36bd0] rjak_, نییه_, _vzlé, --, 
   {{0xb0640598,0x2248cf17,0x7688c6da,0x60980345}},	//   yläş, sjak_, mıya, رناس_, 
   {{0x9ed9e585,0x2249e586,0x9df9e587,0x7688d16c}},	//   хмет_, pjak_, енет_, lıya, 
   {{0x236800e2,0x2bb805c0,0x00000000,0x00000000}},	//   ģijā_, ेखना, --, --, 
   {{0x76881ae4,0x9f4003a0,0x66ec05f9,0xad24027d}},	//   nıya, mahí_, _झिझक_, لروو, 
   {{0x9f400093,0xdb8400d1,0x00000000,0x00000000}},	//   lahí_, лгли, --, --, 
   {{0xa2b80c00,0x768803b9,0x9f045b74,0x00000000}},	//   ्दप्, hıya, _حوزو, --, 
   {{0x0b140597,0xb0640724,0x1c041152,0xf2d4008f}},	//   اقية_, rläş, _रावल_, בעק_, 
   {{0x1bd4010b,0xb60400bc,0xa7fc0205,0x00000000}},	//   _бозя, nkář, rhın, --, 
   {{0x7d189181,0x2c002e2d,0x574834cd,0xb8d8072a}},	//   _ipus, _дүшм, езом_, _आओ_, 
   {{0x9f4006c8,0xddc81156,0xd5e461db,0x55e492fe}},	//   kahí_, _zmeš, лжни, лонб, 
   {{0x98ac151c,0x6b9c0194,0x00000000,0x00000000}},	//   mveč_, _ørga, --, --, 
   {{0x38a9caf0,0x5ed80154,0x260469dd,0xa2b800cd}},	//   jørg_, _ডিফে, _वारी_, ्दन्, 
   {{0x7d180223,0x9878008f,0xb604013a,0x00000000}},	//   _mpus, _ראַט, dkář, --, 
   {{0xe89801d3,0xd25001d9,0x00000000,0x00000000}},	//   _جموں_, ٕنز_, --, --, 
   {{0x768800a2,0x1b1c00eb,0x00000000,0x00000000}},	//   bıya, পটপে_, --, --, 
   {{0x3f8dd81d,0x76880205,0x00000000,0x00000000}},	// [36be0] şgul_, cıya, --, --, 
   {{0x6ecc03b9,0xf9840137,0x00000000,0x00000000}},	//   _ağba, _ۇب_, --, --, 
   {{0xddc8340e,0x7d19e588,0x98ac151c,0xc6240154}},	//   _smeš, _apus, jveč_, যারা_, 
   {{0x1ea80bbd,0xb81007b7,0xfe40009d,0x4d641cd0}},	//   ناني_, त्तम_, йнхо, лкев, 
   {{0xa3d80073,0x48bc0154,0x6bd400ec,0xad2400d1}},	//   ारच_, _ইব্র, لڪار, شىغى, 
   {{0xac18bbc9,0xddc80219,0x7d7404fb,0x05940240}},	//   току_, _vmeš, دمهر_, _መንቅብ_, 
   {{0x26044425,0x1fb434d8,0x7d196eb4,0x7688e333}},	//   _वाली_, _встр, _epus, zıya, 
   {{0x0e64010b,0xaa55e589,0x6fe800de,0x00000000}},	//   _ёкан, рвиш, sūcē, --, 
   {{0xb924063f,0xddc88841,0xb8d000f2,0x87e4022e}},	//   _ijuọ_, _umeš, یتیش, люне, 
   {{0x38a806ea,0x76880790,0x00000000,0x00000000}},	//   jørd_, vıya, --, --, 
   {{0xb8c923db,0x6280552d,0x1cc00327,0x7d180118}},	//   _की_, élok, _གཤོ_, _zpus, 
   {{0xe5b4e9b1,0xe6959f58,0x48e401c6,0x65a8022e}},	//   ийны, римы, _бодв, lоhi, 
   {{0x38a852fd,0x00000000,0x00000000,0x00000000}},	//   førd_, --, --, --, 
   {{0x67d5545f,0x768893ba,0x6f1c035a,0x82340330}},	//   _току, rıya, _oprc, گرسا, 
   {{0x236c00c8,0x9f400270,0xf74000d8,0x00000000}},	//   ĝejo_, tahí_, _гејо, --, 
   {{0x1fdc5b82,0x82342f84,0xb6e00137,0xb6040118}},	//   यर्ड, درسا, _уюшк, tkář, 
   {{0x1cc0025c,0x6f1c02d0,0xa075e52a,0x42500133}},	// [36bf0] _གཤེ_, _aprc, агач, لۆگر, 
   {{0x25a9e58a,0x67380427,0xb60400bc,0xc0bc0092}},	//   _izal_, _krvj, rkář, ስማማ_, 
   {{0x4421e58b,0xba0401f3,0x00000000,0x00000000}},	//   mej_, _ፊፋ_, --, --, 
   {{0x44213a58,0x7de4071c,0x623449d2,0x38a8319f}},	//   lej_, اسام, _тему, møre_, 
   {{0x9d45057c,0x11200023,0x7688013d,0x00000000}},	//   релд, ስተውዓ, kıyn, --, 
   {{0x4421e58c,0x91e400b5,0x7d180306,0x2078010f}},	//   nej_, niのs, _vpus, _יאָא, 
   {{0x4420002d,0x7d18012d,0x7ea00254,0x76880139}},	//   iej_, _wpus, lõpm, dıyn, 
   {{0x4421e58d,0x94e0013b,0x25a80209,0x98ac0427}},	//   hej_, _kɔɔ_, _ozal_, rveč_, 
   {{0x4421e58e,0xa7fde58f,0xdcb82347,0x38a8332e}},	//   kej_, kkıd, _агач_, høre_, 
   {{0x4420bdcd,0x9854c6b5,0x38a801bf,0x0ac40022}},	//   jej_, ртиш, køre_, ышәҭ, 
   {{0x4421717f,0x7c21e590,0x38a802bf,0x25a9e591}},	//   dej_, menr, jøre_, _azal_, 
   {{0x38a800b5,0x2bb8007b,0xeff80092,0x00000000}},	//   døre_, _صالة_, _ወዳድ_, --, 
   {{0x6738002d,0x3ebd0fe9,0x7c200d27,0xf4844144}},	//   _ervj, _miut_, oenr, ماسی, 
   {{0x7c21e592,0x38a86ab9,0x3ebc05b1,0x052410f3}},	//   nenr, føre_, _liut_, јорк_, 
   {{0x38a8037e,0x2139e593,0x42e401f0,0x00000000}},	//   gøre_, _arsh_, имро_, --, 
   {{0x76880365,0x94e0013b,0x7c21e594,0x1f40001f}},	//   mıyo, _bɔɔ_, henr, _የሚያም, 
  
   {{0x4421e595,0x76880365,0x6f1c0232,0x1c040bc0}},	// [36c00] bej_, lıyo, _sprc, रलाल_, 
   {{0x4421e596,0x6aa4038f,0x3ebc067c,0x61e801e4}},	//   cej_, ċifi, _aiut_, _ĵele, 
   {{0x7c21e597,0x76880365,0x16080034,0x248c0789}},	//   denr, nıyo, वलपर_, éeme_, 
   {{0x3ebde598,0x1fb40209,0x00000000,0x00000000}},	//   _ciut_, ссур, --, --, 
   {{0x3ebc01f2,0x7640023a,0x7c20002f,0xfbcc03d4}},	//   _diut_, ömyy, fenr, _ৰাজত, 
   {{0x7c21e599,0x76880365,0x98ac00d0,0xa2b800bc}},	//   genr, kıyo, dveď_, ्दथ्, 
   {{0x6f1c0118,0x64900166,0xcb448eea,0x16140073}},	//   _uprc, _uñiş, рхли, तभार_, 
   {{0x4421e59a,0x2aa800d2,0xbb440fb4,0x4a24031c}},	//   zej_, fûba_, ؤلين_, _རྒཡལ_, 
   {{0x48a9e59b,0x7c206688,0x3b8029db,0x4421e59c}},	//   ктом_, benr, йләг, yej_, 
   {{0x673801fa,0x442004cc,0x8b94009b,0x00000000}},	//   _prvj, xej_, _креч, --, 
   {{0x4421e59d,0xc6a4da86,0x25a80827,0xf844013d}},	//   vej_, ирми, _szal_, рчый_, 
   {{0x442014cf,0x67380010,0x181801b9,0x4dcc0150}},	//   wej_, _vrvj, پریک_, _ﺗﯩﯖﻨ, 
   {{0x442144b2,0xd8f8021a,0x76881918,0xa7fc05d1}},	//   tej_, _مونږ_, mıyl, tkıd, 
   {{0x2905e59e,0x7688456f,0x25a802fb,0x7aec000d}},	//   muma_, lıyl, _vzal_, _äitä, 
   {{0x2905e59f,0x4420b8dd,0x94e0016b,0x86e407d6}},	//   luma_, rej_, _sɔɔ_, _тўлд, 
   {{0x4421e5a0,0x7c2001f5,0x7688d304,0x38a82ab7}},	//   sej_, zenr, nıyl, røre_, 
   {{0x4420003d,0x2905e5a1,0x660de5a2,0x25a80b6f}},	// [36c10] pej_, numa_, _icak, _uzal_, 
   {{0x4421e5a3,0xa2c40124,0x76880205,0xa7fc008e}},	//   qej_, _гәак, hıyl, lkıb, 
   {{0x2c0003f3,0x7c2001a4,0xa2940816,0x344800db}},	//   _राजू_, venr, _гані, _ъчън_, 
   {{0x2905e5a4,0x7c20089c,0x94e0013f,0x9f4005d5}},	//   kuma_, wenr, _tɔɔ_, rahà_, 
   {{0x61ede5a5,0x29040029,0x7c21e5a6,0x3134036b}},	//   maal, juma_, tenr, _деяр, 
   {{0x61ede5a7,0x2905e5a8,0x60cc6b6c,0x76880790}},	//   laal, duma_, mqam, yıyo, 
   {{0x7c21e5a9,0x212805b1,0x60ccc7ad,0x660de5aa}},	//   renr, lwah_, lqam, _ocak, 
   {{0x61ede5ab,0x2905e5ac,0x660de5ad,0x21280548}},	//   naal, fuma_, _ncak, owah_, 
   {{0x7c21e5ae,0x61ec0140,0x60cd32a9,0xf8ac0345}},	//   penr, iaal, nqam, وکت_, 
   {{0x61ede5af,0xb8fc367a,0x76880365,0x660de5b0}},	//   haal, _तऽ_, tıyo, _acak, 
   {{0x290406c8,0x212831e5,0x7688e090,0xefc00092}},	//   auma_, hwah_, bıyl, ስፋው_, 
   {{0x2129e5b1,0x61ede5b2,0x768803ee,0x660c0055}},	//   kwah_, jaal, rıyo, _ccak, 
   {{0x61ede5b3,0x2905e5b4,0x660c0076,0x768805d1}},	//   daal, cuma_, _dcak, sıyo, 
   {{0x629de5b5,0x76880365,0x660c0333,0x21280ac5}},	//   _akso, pıyo, _ecak, dwah_, 
   {{0x61ede5b6,0x60cc0194,0x768985f8,0x00000000}},	//   faal, eqam, lıym, --, 
   {{0x61ede5b7,0x690400e5,0x00000000,0x00000000}},	//   gaal, _útdí, --, --, 
   {{0x60cc1cdf,0x042000fe,0x7645e5b8,0x00000000}},	// [36c20] gqam, মাজী_, _iniy, --, 
   {{0x7688495b,0xa47400f1,0xca840116,0x00000000}},	//   zıyl, _وپيږ, ﺭﻟﯘﻕ_, --, 
   {{0x61ede5b9,0x629c0418,0x20b800c9,0x9f4003a0}},	//   baal, _fkso, рыть_, tahá_, 
   {{0x29049d20,0x61ec6243,0x938800c7,0x1c0407f7}},	//   yuma_, caal, _асҭа_, _राउल_, 
   {{0x2128058a,0x2905e5ba,0x4d1400ee,0x7688236c}},	//   cwah_, xuma_, сьет, vıyl, 
   {{0xce485e18,0x00000000,0x00000000,0x00000000}},	//   _өзге_, --, --, --, 
   {{0x29040605,0x7688495b,0x27ec0010,0x7645e5bb}},	//   wuma_, tıyl, vadn_, _oniy, 
   {{0x2905e5bc,0xf55402d3,0xccc401f4,0x00000000}},	//   tuma_, _ዝጸንሐ, _гбай, --, 
   {{0x76888eb9,0xfe401def,0xc7c5e5bd,0xfce0a8dc}},	//   rıyl, _энто, йсни, _ното, 
   {{0x1cc00d46,0x7645dbc0,0x61ec2f99,0x7689439a}},	//   _གཤག_, _aniy, zaal, sıyl, 
   {{0x61ede5be,0x212805b1,0x27ecef98,0xa580001f}},	//   yaal, zwah_, radn_, _የኦሮሞ_, 
   {{0x290443c1,0x2bd44ed3,0xe73801e0,0x09e00154}},	//   puma_, ठुरा, геү_, _যাকা, 
   {{0x61ede5bf,0x2905e5c0,0xa2b800dc,0x093400c6}},	//   vaal, quma_, ्दस्, _دراج, 
   {{0x76440570,0x5ed803f4,0x39bc002b,0x00000000}},	//   _eniy, _ডিসে, _dāsī_, --, 
   {{0x4a241b4b,0x2129e5c1,0xb80442c6,0x60cc0113}},	//   _རྒོལ_, wwah_, _ايىم_, wqam, 
   {{0x26f8025c,0x61ec0421,0x21280548,0x63a800bc}},	//   _དྷརྨ_, uaal, twah_, řeno, 
   {{0x61ede5c2,0x91c0008e,0x0f380092,0x00000000}},	// [36c30] raal, дәрл, _የሚለየ, --, 
   {{0x60cc0a55,0x21280548,0x00000000,0x00000000}},	//   rqam, rwah_, --, --, 
   {{0x61ede5c3,0x60cc0bf1,0x2bcc1cc3,0x00000000}},	//   paal, sqam, ाशना, --, 
   {{0x61ede5c4,0x44300369,0x1cc0031c,0x2128014f}},	//   qaal, _hax_, _གཤང_, pwah_, 
   {{0x60ccc203,0x21280161,0x9d34013f,0x44300009}},	//   qqam, qwah_, ɛfɛɛ_, _kax_, 
   {{0x4430002e,0x351c0375,0xb0640112,0x8c412515}},	//   _jax_, טודנ, rläß, деше, 
   {{0x38a80158,0xd1cc01f3,0x00000000,0x00000000}},	//   jøra_, _እንባ_, --, --, 
   {{0x44301590,0x38a82d8b,0xdaa80e92,0xbc6401d9}},	//   _lax_, døra_, јвид_, _گۅتن_, 
   {{0x7e79e5c5,0x644418f7,0x44300789,0x00000000}},	//   _imup, _onhi, _oax_, --, 
   {{0xa87411ed,0x44301bce,0x38a8cade,0x9f40003a}},	//   зующ, _nax_, føra_, rahæ_, 
   {{0xe9d863f5,0x00000000,0x00000000,0x00000000}},	//   шкө_, --, --, --, 
   {{0x6445e5c6,0x44300477,0x19b9e5c7,0x8f98011a}},	//   _anhi, _aax_, _куль_, ייתי, 
   {{0x4431e5c8,0x7e7801ee,0x64440051,0x00000000}},	//   _bax_, _mmup, _bnhi, --, 
   {{0x443084d4,0xa7fc05d1,0x2bcc078a,0xf810029e}},	//   _cax_, rkıc, ाशया, _رستگ, 
   {{0x7e7912f1,0x395c047e,0xa7fc03e0,0x00000000}},	//   _omup, lyus_, skıc, --, 
   {{0x6444013f,0x764401a9,0x00000000,0x00000000}},	//   _enhi, _uniy, --, --, 
   {{0x4fe9e5c9,0x395c0978,0xfc4402fb,0x11482309}},	// [36c40] иман_, nyus_, _číny_, шпай_, 
   {{0x7e79e5ca,0x4430020b,0x3b040007,0x64440036}},	//   _amup, _gax_, kunq_, _gnhi, 
   {{0x0eb80220,0x0dc8c134,0x27f92e75,0x00000000}},	//   ауды_, алей_, órni_, --, 
   {{0x2dc82e56,0x443001d5,0x395c0113,0xd17400db}},	//   сқан_, _zax_, kyus_, _дыгы, 
   {{0xfd0c188d,0xa2b8255c,0x32e80209,0x6444000f}},	//   نجو_, ्दर्, lşy_, _ynhi, 
   {{0x395cad43,0x7e780810,0x5ed8015b,0xcfa8030f}},	//   dyus_, _emup, _ডিরে, _نازم_, 
   {{0x0a69e5cb,0x8a68036b,0xbb4006ed,0x4a240327}},	//   ирии_, ишиб_, дејк, _རྒུལ_, 
   {{0xfaa039fb,0xdb0006af,0xcde40395,0x38a80162}},	//   мшын, _mylè, _фоай, vøra_, 
   {{0xf98c00dd,0xbe1025ef,0xfb8400b1,0x32e8010e}},	//   ہبی_, _توقع, йбәк_, hşy_, 
   {{0xc7b8016c,0x76880139,0xa7740108,0x00000000}},	//   иён_, bıyk, злоч, --, 
   {{0x4431e5cc,0x31600369,0xdb00020c,0xca78022e}},	//   _rax_, hyiz_, _nylè, _istо, 
   {{0x44303d27,0xb37002d3,0x38a8143a,0x84800023}},	//   _sax_, _ጥልያን_, røra_, _ናብራን_, 
   {{0x31600007,0x26d912b3,0x00000000,0x00000000}},	//   jyiz_, ūro_, --, --, 
   {{0x4431e5cd,0x00000000,0x00000000,0x00000000}},	//   _qax_, --, --, --, 
   {{0x32e80209,0x236401ed,0x4430d51b,0x335800a8}},	//   gşy_, álj_, _vax_, оарэ_, 
   {{0x26040574,0x4431e5ce,0xdb000200,0x659400d4}},	//   _वाटी_, _wax_, _sylë, _найу, 
   {{0xf6c40135,0x44300375,0x442403b2,0x00000000}},	// [36c50] _གཤོང, _tax_, _ºn_, --, 
   {{0x4424110e,0x64440784,0xf0e80075,0xbf6409a6}},	//   _ún_, _unhi, تىكى_, يداو, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x38a8f905,0x05ac0073,0x00000000,0x00000000}},	//   jørn_, _घराब, --, --, 
   {{0xee380006,0x00000000,0x00000000,0x00000000}},	//   ўні_, --, --, --, 
   {{0xc6240154,0x802400ae,0x00000000,0x00000000}},	//   যাটা_, _برحم, --, --, 
   {{0x2258005a,0x00000000,0x00000000,0x00000000}},	//   _kosk_, --, --, --, 
   {{0x7e7929cd,0x6d5c0cc1,0xe3bc0eac,0x395ce597}},	//   _umup, _əraz, _অভাব, tyus_, 
   {{0x5c75a56b,0x63a401bf,0x699401c6,0x00000000}},	//   _елат, _lyhn, дрэх, --, 
   {{0x6f8801d9,0xd708034b,0x22580165,0xad240131}},	//   _انہِ_, бное_, _losk_, _تىكى, 
   {{0x38a8e2ba,0x91a000bc,0x6aa40327,0x96b8004e}},	//   børn_, _कुनै, ċifr, йуму_, 
   {{0x316005b1,0xe81c1b97,0x395c014f,0x00000000}},	//   yyiz_, ब्बा_, pyus_, --, 
   {{0x09e0015b,0x38c80166,0xf77000ec,0x00000000}},	//   _যাচা, _туен_, _ڪاش_, --, 
   {{0xa7fc825f,0xd3940139,0xe70800ec,0x00000000}},	//   lkın, зәмә_, _ڀتين_, --, 
   {{0xf7707e76,0x2258045f,0x07a010e2,0x91e40126}},	//   _تاش_, _bosk_, _пашн, зобе, 
   {{0x32e809a5,0x02c023d6,0xa7fda0fa,0x03a05acb}},	//   rşy_, ейсо, nkın, хисо, 
   {{0x64880b4b,0x942400f0,0x00000000,0x00000000}},	// [36c60] džif, _емпе, --, --, 
   {{0x75259626,0x628006af,0xe3b8013e,0x00000000}},	//   _ipiz, élor, сбӣ_, --, 
   {{0xa7fc0ab7,0x53a5e5cf,0x00000000,0x00000000}},	//   kkın, _ханб, --, --, 
   {{0xdbd80139,0x00000000,0x00000000,0x00000000}},	//   _eçüd, --, --, --, 
   {{0xd1b9e5d0,0x38a80b1a,0x80d00d2e,0x00000000}},	//   _دادا_, vørn_, _भूपे, --, 
   {{0x752403d1,0xefc00023,0x3fc80066,0x00000000}},	//   _mpiz, ድላው_, _هدفی_, --, 
   {{0xdd3800dc,0x00000000,0x00000000,0x00000000}},	//   _kāśy, --, --, --, 
   {{0x43c00131,0xbea02ccb,0x752401a6,0x00000000}},	//   ﯩﺮﯨﺪ, _заск, _opiz, --, 
   {{0xbe101411,0x00000000,0x00000000,0x00000000}},	//   _سولع, --, --, --, 
   {{0x6d41e5d1,0x60c8011c,0xdd7401d9,0x2cb808c2}},	//   _irma, _èeme, _تھٔک, _òrd_, 
   {{0xe6943596,0x75240789,0x7bd80375,0x6d40007f}},	//   дины, _apiz, _הקבו, _hrma, 
   {{0xfb84088e,0x63a80118,0x00000000,0x00000000}},	//   _عدلی, řenk, --, --, 
   {{0xdb000724,0xc4c400bc,0x00000000,0x00000000}},	//   _ezlä, लदेख, --, --, 
   {{0x6d4003b9,0x00000000,0x00000000,0x00000000}},	//   _mrma, --, --, --, 
   {{0x85545ab7,0x34941e0a,0x00000000,0x00000000}},	//   زیگر_, харр, --, --, 
   {{0x6d41e5d2,0xfbdc07ae,0x63a40308,0x2905e5d3}},	//   _orma, _đêm_, _vyhn, orma_, 
   {{0x2c7000e8,0x6d400477,0x225802fb,0xdb0000bc}},	// [36c70] _kàdd_, _nrma, _vosk_, _vylé, 
   {{0x2c700de2,0xf0e80131,0x35b49735,0xb0340354}},	//   _jàdd_, سىمى_, _ябыр, ннуш, 
   {{0xa2b46b1a,0x2259c091,0x00000000,0x00000000}},	//   _обоч, _tosk_, --, --, 
   {{0x6d400a2e,0xdc0400bc,0xfb5000e5,0xd3440345}},	//   _brma, रल्ड_, ہربھ, _تیفه_, 
   {{0x628c0b4b,0x61fc02d0,0x00000000,0x00000000}},	//   mnao, _idsl, --, --, 
   {{0x998c6041,0x27fc0051,0xd1cc1954,0x5f94009d}},	//   jdeš_, _ndvn_, _እንቶ_, _жигт, 
   {{0x6d41e5d4,0x9e95e5d5,0x628c01e7,0x00000000}},	//   _erma, _قارچ, onao, --, 
   {{0xd1cc067d,0x628de5d6,0xae1405f9,0x661c0d27}},	//   _እንተ_, nnao, _डायन_, jfsk, 
   {{0xa7fc0bcc,0x29040421,0x628de5d7,0x6dc40372}},	//   rkın, grma_, inao, _كۅمۅ, 
   {{0x2c70002e,0x7d080004,0x661d4116,0xa7fc2258}},	//   _càdd_, mugs, efsk, skın, 
   {{0x7525e5d8,0xa2cc05f9,0x661c0738,0x290489c2}},	//   _spiz, _दूल्, ffsk, arma_, 
   {{0x80e00183,0x61fc03b2,0xfa240327,0x60dc000d}},	//   _পিন্, _ndsl, _ཡིིན_, _otsm, 
   {{0x2c7000e8,0xdd3800b8,0xa2c0095f,0x7ea00254}},	//   _fàdd_, _rāśy, लगन्, lõps, 
   {{0x2c70002e,0x61fc02d0,0x29180276,0x661c0af9}},	//   _gàdd_, _adsl, ărat_, afsk, 
   {{0x03a05e3e,0x60dc000f,0x7d0808a7,0x648805be}},	//   виро, _atsm, hugs, džid, 
   {{0x7d08089c,0xd2a80006,0xefd40023,0x00000000}},	//   kugs, ікае_, _ኪንዮ_, --, 
   {{0x8ff806d0,0x38a801bf,0xdd380055,0x11e40150}},	// [36c80] قرار_, hørm_, _vāśy, зжұм, 
   {{0xc4800a89,0x61fc02d0,0x628d86bc,0x00000000}},	//   _альк, _edsl, anao, --, 
   {{0x68e4003d,0x60dc03ac,0x00000000,0x00000000}},	//   _ħidm, _etsm, --, --, 
   {{0x0d8421db,0x0eb812c4,0x7e9401b9,0xbec00055}},	//   млен, цузы_, ونلر_, _śīrt, 
   {{0xf42c0135,0x78a004ba,0xd1b92b63,0x749c002b}},	//   _སྲོད_, _oknv, _گاگا_, _ṛṣip, 
   {{0xd01109b9,0x00000000,0x00000000,0x00000000}},	//   _جلس_, --, --, --, 
   {{0x7d080006,0x1f580262,0x661c0af9,0xd1cc0023}},	//   augs, _ешть_, yfsk, _እንታ_, 
   {{0xfe403461,0x7d081c06,0x60dc000f,0xf3f4015b}},	//   _инсо, bugs, _ytsm, _জাফর_, 
   {{0x6d41e5d9,0x390405f5,0x20cc0219,0x26dde5da}},	//   _urma, мээн_, _vžig_, _stvo_, 
   {{0xe3c40c58,0x628c0165,0x63a80118,0x29040200}},	//   ্ৰিব, znao, řeni, rrma_, 
   {{0xf42c0135,0xf414015b,0x68e0009a,0x91ec01ef}},	//   _སྲེད_, াজার_, spmd, जराज_, 
   {{0x2c7000e8,0x2bcc09b2,0x661c0112,0x8cc4012d}},	//   _wàdd_, ाशवा, ufsk, ादको, 
   {{0x661de5db,0x9f40007b,0xa7fd1475,0x00000000}},	//   rfsk, rbhé_, lkım, --, 
   {{0x6aa000d2,0xddc80432,0x9f4003b2,0x00000000}},	//   lomf, _eneň, rahú_, --, 
   {{0x7d09e5dc,0xa7fc0205,0x00000000,0x00000000}},	//   zugs, nkım, --, --, 
   {{0x6aa1e5dd,0xe0d82401,0x61700092,0x628c01f4}},	//   nomf, здач_, _ለመውጣ, unao, 
   {{0x85b80050,0x628d64f7,0xf2c40276,0xa3d40353}},	// [36c90] _باغس_, rnao, тсрн, _попч, 
   {{0xa7fc03ee,0x6aa1e5de,0x25a80139,0x31c40063}},	//   kkım, homf, _iyal_, ђств, 
   {{0x6aa1c402,0x26c80083,0xef140137,0x2cbc01a9}},	//   komf, _kiao_, күрө, dmvd_, 
   {{0x25a80198,0x61fc037e,0x6aa0005c,0x9cf401ec}},	//   _kyal_, _udsl, jomf, езді, 
   {{0x26c9e5df,0x92280003,0xece802bf,0xa7fc510c}},	//   _miao_, _སྒྲག_, дділ_, tkıl, 
   {{0x26c9e5e0,0x7d09e5e1,0xc6200eac,0xfeb80451}},	//   _liao_, rugs, _বোমা_, _ڀارت_, 
   {{0xa7fd2109,0x6aa00472,0x248000a3,0x80d000cd}},	//   rkıl, fomf, _mmhm_, _भूते, 
   {{0x1cc00ed9,0x26c9e5e2,0x6aa1e5e3,0xa7fc2258}},	//   _གཤམ_, _niao_, gomf, skıl, 
   {{0x26d81709,0xdbc801e0,0xaac47aaf,0x00000000}},	//   íron_, _етеҙ_, ختون, --, 
   {{0x38a806ea,0xd7080108,0x15f0012d,0x00000000}},	//   mørk_, пное_, _अजहर_, --, 
   {{0x6aa00b6f,0x050c0c58,0x25a9e5e4,0xe8f801e0}},	//   bomf, িবোৰ_, _ayal_, плө_, 
   {{0x26c9e5e5,0x6aa1e5e6,0x00000000,0x00000000}},	//   _ciao_, comf, --, --, 
   {{0x648805be,0xf4843c5b,0xca78022e,0x26c801e3}},	//   džib, ناسی, _istа, _diao_, 
   {{0x25ac07de,0x00000000,0x00000000,0x00000000}},	//   üela_, --, --, --, 
   {{0x6ed40d2c,0x25a80083,0x00000000,0x00000000}},	//   _बंधु, _eyal_, --, --, 
   {{0x26c807ae,0x160837f3,0xda000118,0x76880166}},	//   _giao_, _वाटर_, ोलित_, gıyt, 
   {{0x4124896b,0xd5b096b4,0xd008084c,0x03ec00eb}},	// [36ca0] ното_, _حفظ_, зезе_, _জারী_, 
   {{0x6aa08a07,0x00000000,0x00000000,0x00000000}},	//   zomf, --, --, --, 
   {{0x6aa0b539,0xec10004d,0x409001d5,0xdb0000d0}},	//   yomf, hếch_, دللر, _bylí, 
   {{0x64884a38,0x23b40241,0x7ee000d1,0x00000000}},	//   ržie, _wùjí_, چكەن, --, 
   {{0xe1f401d5,0xd5c000b8,0x52bc0709,0x00000000}},	//   _шҳт_, bdāś_, ्दीस, --, 
   {{0x6aa1e5e7,0xbd400338,0xa7fc0205,0x64880064}},	//   womf, انوي, tkım, pžie, 
   {{0x6aa005ac,0xcfa80b24,0x00000000,0x00000000}},	//   tomf, _راسم_, --, --, 
   {{0xdb00045f,0x7ea00037,0xa7fc03e0,0x00000000}},	//   _bylâ, sõpr, rkım, --, 
   {{0x6aa1e5e8,0x7ac00108,0xa2c00118,0x00000000}},	//   romf, ысше, लगत्, --, 
   {{0x25a80493,0x6aa0143a,0x7ea0000d,0x00000000}},	//   _ryal_, somf, lõpp, --, 
   {{0x25a8008b,0x6aa001f7,0x49c80902,0x00000000}},	//   _syal_, pomf, _елен_, --, 
   {{0x768805d1,0xa4d400d4,0x00000000,0x00000000}},	//   dıys, комі, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69dc068f,0x648801fa,0xca7801a9,0x20cc013a}},	//   śred, džic, _zstа, _lžic_, 
   {{0xc6a401fc,0x27e0001e,0x7688013d,0x00000000}},	//   _прии, _đinh_, gıys, --, 
   {{0xc0cc001f,0x00000000,0x00000000,0x00000000}},	//   _እህል_, --, --, --, 
   {{0x7ea0000d,0x8114007b,0x00000000,0x00000000}},	// [36cb0] dõpp, عذرا, --, --, 
   {{0x3015e5e9,0x23d432c6,0xc0c00092,0x00000000}},	//   лдур, _दलिद, ቻችሁ_, --, 
   {{0xf42c6d7e,0xe8181e61,0xdea1e5ea,0x03c400d1}},	//   _སྲིད_, _दाना_, لیسی, _ясим, 
   {{0x91a00ebb,0x7ea0000d,0xbef000db,0xec100051}},	//   _कुवै, gõpp, _ەۋاع, yếch_, 
   {{0x7ae00334,0xdb00022a,0x32640064,0x00000000}},	//   wpnt, _vylí, _стэв, --, 
   {{0x8005007b,0xdca40131,0xad4400db,0x00000000}},	//   _ячме, ъали, دۉكۉ, --, 
   {{0x70941ee3,0x5a940276,0x65c80055,0xf5ec01e1}},	//   _сарф, криф, _hīhī, _lẹẹ_, 
   {{0xcff40eac,0xdb000139,0x38a80162,0x8bd4008e}},	//   _চায়_, _uylí, pørk_, нмәс_, 
   {{0x4bb0010b,0xfd000166,0x004c0092,0xfd10007b}},	//   лйәс, _сүлп, _አረንጓ, _حجز_, 
   {{0x7d184e61,0x57441422,0x99640139,0x00000000}},	//   _iqus, вноб, етүл, --, 
   {{0x79640241,0xf6640166,0x42780092,0x7688013d}},	//   _béwú, генү, _አጥንት_, dıyr, 
   {{0xf5ec0248,0x15b82e5d,0xca78022e,0xab840137}},	//   _bẹẹ_, дыгы_, _ustа, _суук, 
   {{0x27e00356,0x6b9c0174,0x32640107,0xae140037}},	//   _şine_, _ørgr, қеаҳ, _डासन_, 
   {{0xd7c801d5,0x7688c8d8,0x00000000,0x00000000}},	//   _قوشه_, tıys, --, --, 
   {{0x88980302,0xa3e009bb,0xf8ac0133,0x04400114}},	//   _קבצי, दड़_, _پکک_, јесн, 
   {{0x20540116,0x2214180b,0x45300137,0x00000000}},	//   қтур, лфур, _چىير, --, 
   {{0x10a400e4,0xa2b877d7,0x7ea00254,0x31440022}},	// [36cc0] виан, ्दज्, võpp, ыдаҳ, 
   {{0x3fe13566,0x6488107d,0x6ecc03b9,0x38a806ea}},	//   ижув, ržic, _aşba, føri_, 
   {{0x7d191dcb,0x9f50007f,0x91a0473c,0xd1b0179e}},	//   _aqus, _jezè_, _कुरै, _چیزک, 
   {{0x8d84869e,0x9f5002d3,0xfe41e5eb,0x64880153}},	//   кулд, _zezë_, инхо, mžia, 
   {{0xd174f5c3,0xfcd000ec,0x7ea00037,0x64880064}},	//   _рыны, لينج, rõpp, lžia, 
   {{0xfbcde5ec,0x60c800d8,0x6ecc0205,0x7ea00037}},	//   يتى_, _éemp, _eşba, sõpp, 
   {{0x09c80882,0xf764d839,0x7d18013c,0xe81801f9}},	//   ाख्य, _ئا_, _equs, _दाबा_, 
   {{0x2c700248,0x5ed80183,0x98a8031c,0x26d9e5ed}},	//   _dàda_, _ডিচে, _ħaġ_, írom_, 
   {{0x27e002a8,0xccc412cd,0x67d40120,0xe9440244}},	//   _ƙin_, _абай, лопу, اربی, 
   {{0x9f50007f,0x2c7001ab,0x60c801e4,0x42780092}},	//   _bezè_, _fàda_, _ɨemo, _አጥነት_, 
   {{0xdeb40198,0x81c800bd,0xf8b001c0,0x64880419}},	//   _arzƙ, রুপ_, рбээ, jžia, 
   {{0x64884077,0xf76c036d,0x9f5002bd,0xfaa00eba}},	//   džia, تاً_, _dezè_, _кахо, 
   {{0x5bc40032,0x64880024,0x9f500200,0xe6780150}},	//   _иҫән_, ežia, _pezë_, _үйлі_, 
   {{0x074439f6,0x9f500100,0xdb0000d7,0xe2c800f1}},	//   _ахим, _fezè_, _hylá, ځوسو_, 
   {{0x248c071b,0x9f51193a,0xa6f4036b,0xc7640372}},	//   đem_, _gezè_, _ёзиш, _جاشى, 
   {{0xbb38025d,0x41742162,0x81c80154,0x38a803b2}},	//   ועלי, پارس, রুফ_, vøri_, 
   {{0xc058dbe2,0x81c800bd,0x9f50036e,0x9f4000ae}},	// [36cd0] між_, রুন_, _tezë_, rbhí_, 
   {{0x3f640e76,0x249806c2,0x00000000,0x00000000}},	//   ктеб, _سنجد_, --, --, 
   {{0x20cc00c0,0xbfa80107,0x2f1c02d2,0x00000000}},	//   _džia_, фтае_, gíg_, --, 
   {{0x9db80166,0x00000000,0x00000000,0x00000000}},	//   нылу_, --, --, --, 
   {{0x63a92187,0x1d0801f0,0xab5c0171,0x9f400205}},	//   ƙens, хели_, _ogļs, lahü_, 
   {{0x67381f7f,0x2138036e,0x00000000,0x00000000}},	//   _osvj, _issh_, --, --, 
   {{0x3ec5e5ee,0x9b4474dd,0x18a5e5ef,0x26d800df}},	//   _асаб, انبو, ғанм, ŭroj_, 
   {{0x44200175,0x21380200,0xfbdc0051,0x995800d8}},	//   hfj_, _kssh_, _đêu_, ејоф_, 
   {{0x3ddc0086,0x7d180113,0x9f500100,0x64880419}},	//   _ifuw_, _uqus, _sezè_, zžia, 
   {{0x3eac020c,0x64880024,0x00000000,0x00000000}},	//   llgt_, yžia, --, --, 
   {{0xb7c00154,0x25ac025c,0x00000000,0x00000000}},	//   োর্ট, żell_, --, --, 
   {{0x69dc00bc,0x21380200,0x56e001ec,0x00000000}},	//   ěrec, _ossh_, _құмғ, --, 
   {{0x6b6801e1,0x80d00456,0x00000000,0x00000000}},	//   _tègú, _भूले, --, --, 
   {{0x7d0808c2,0x3a3de5f0,0xa784072d,0x00000000}},	//   irgs, ldup_, اشیو, --, 
   {{0xe818007d,0xb8600214,0xb3a452be,0x64880153}},	//   _दाता_, _ماژو, _खुशख, užia, 
   {{0x3a3de5f1,0x6488673c,0x00000000,0x00000000}},	//   ndup_, ržia, --, --, 
   {{0xd025e5f2,0x64880024,0x00000000,0x00000000}},	// [36ce0] лмай, mžin, --, --, 
   {{0x3ddc0134,0x648984a4,0x64c400b2,0x9f500798}},	//   _afuw_, lžin, _پيپل, _zezé_, 
   {{0x44181a4c,0x8e09d315,0x6f1c0175,0x64880064}},	//   _אויס, енев_, _qqrc, ožin, 
   {{0xc6081c82,0x236401e6,0xe4f401d5,0x64880024}},	//   ষ্ঠা_, älje_, _حقیگ, nžin, 
   {{0x2dc824a7,0xaff801ed,0xac185f9e,0xac84e737}},	//   тқан_, _لہذا_, волу_, аҳал, 
   {{0x8fa40835,0x63a80112,0x26d800e5,0x7e9415bf}},	//   _баге, ßeng, írok_, پنۇر_, 
   {{0x6fb861f2,0x00000000,0x00000000,0x00000000}},	//   _अरिं, --, --, --, 
   {{0x7c34016b,0x6ecc0139,0x00000000,0x00000000}},	//   _ɔbrɛ, _işbo, --, --, 
   {{0xe8181f82,0x64880cf4,0x3b802cc8,0x9f500129}},	//   _दादा_, džin, иләг, _rezé_, 
   {{0xada5e5f3,0x61e80254,0x64880153,0xc6e50086}},	//   _бағл, _õelv, ežin, лімп, 
   {{0x8b942bbd,0xe65400d4,0x00000000,0x00000000}},	//   _срач, авнь, --, --, 
   {{0x74140154,0xa5f80108,0x00000000,0x00000000}},	//   াজোট_, ъему_, --, --, 
   {{0xddc9e5f4,0xe919089c,0xa4d400d3,0xd4f40022}},	//   _kleš, _ролі_, рогі, аҭых_, 
   {{0xe3753b99,0xf485e5f5,0x38a803b2,0xc7640137}},	//   алгы, бусн, føru_, _مابى, 
   {{0x38a80174,0x87040024,0x00000000,0x00000000}},	//   tørv_, _сяле, --, --, 
   {{0x2138036e,0x44200162,0x00000000,0x00000000}},	//   _pssh_, sfj_, --, --, 
   {{0x20cc3421,0xa0c40b24,0xddc80118,0xafc400d1}},	// [36cf0] _džin_, ليرو, _oleš, ەيلى, 
   {{0x9d540d83,0x38a803b2,0x00000000,0x00000000}},	//   ینات, børu_, --, --, 
   {{0x63a80e78,0x9e140150,0x00000000,0x00000000}},	//   ßend, иджі, --, --, 
   {{0x63a80365,0xddc901dd,0x38a85522,0x00000000}},	//   ğend, _aleš, lørt_, --, 
   {{0xad2401d9,0x63a826f8,0xddc81154,0xed580212}},	//   مروو, şend, _bleš, лої_, 
   {{0x61ede5f6,0x1fb873b5,0xafe4009d,0x00000000}},	//   lbal, _алгы_, _гоёл, --, 
   {{0x7de4005e,0x61ede5f7,0x3a3c0194,0x00000000}},	//   _бізд, obal, tdup_, --, 
   {{0x61ede5f8,0x5a65e5f9,0x91400085,0x38a820e4}},	//   nbal, ркиб, lɔ́_, hørt_, 
   {{0x9ac40083,0x38a800b5,0x61ec017a,0x61e8000d}},	//   _naŋŋ, kørt_, ibal, _õelu, 
   {{0x648802d5,0x38a8dd44,0xc6200183,0x61ec06be}},	//   džio, jørt_, _বোলা_, hbal, 
   {{0x61ede5fa,0xab840024,0x64880153,0x00000000}},	//   kbal, _луцк, ežio, --, 
   {{0x9ac404ba,0x61ede5fb,0x64880024,0x20cc0064}},	//   _baŋŋ, jbal, užin, _ožio_, 
   {{0x61ede5fc,0x38a82759,0x81c82aab,0xb7fc015b}},	//   dbal, ført_, রুত_, ্ভবত_, 
   {{0x61ede5fd,0x69340276,0xa9c40124,0xe7080330}},	//   ebal, _ынчу, _усхк, ختین_, 
   {{0x61ec2b24,0x55e400f7,0x94840139,0x74380240}},	//   fbal, _койб, гыңд, _ብዝገብ, 
   {{0x61ede5fe,0xe0f4003d,0x11e4074d,0x0050001f}},	//   gbal, _བསྡད_, ржам, _ለማከና, 
   {{0xdb00023a,0x273401d9,0x00000000,0x00000000}},	// [36d00] _hylä, _نى۪س, --, --, 
   {{0x91400296,0xdb01e5ff,0x61ede600,0x38a80158}},	//   gɔ́_, _kylä, abal, mørs_, 
   {{0x61ede601,0xe81802c3,0x20cc00c0,0xdd9801ec}},	//   bbal, _दासा_, _ežio_, ңші_, 
   {{0x9ac404ba,0x63a80112,0x1ea82161,0x91b800cf}},	//   _yaŋŋ, ßene, هاني_, _үгүт_, 
   {{0xcbb0015b,0x823400cf,0x63a805d1,0x00000000}},	//   _চলেছ, _ئرپا, ğene, --, 
   {{0x63a80724,0xdb000139,0xbd4000db,0x00000000}},	//   şene, _oylä, زنىي, --, 
   {{0x64880cf4,0x657c00b5,0x38a801bf,0x00000000}},	//   džil, zzsh, hørs_, --, 
   {{0x7f3806a9,0xbea1e602,0x15f00412,0x00000000}},	//   _בעלו, _даск, _अजगर_, --, 
   {{0x0d85e603,0x20cc02f0,0x256c0241,0x00000000}},	//   _тлан, _ožil_, _mólú_, --, 
   {{0xc7c5e604,0x61ede605,0xc8644727,0x256c0241}},	//   исни, zbal, ртии, _lólú_, 
   {{0x61ede606,0x38a8022c,0xa5f9e607,0x6b6c00de}},	//   ybal, vørt_, лену_, _bēgš, 
   {{0xe81823ef,0x46681f99,0xe6940c9e,0x185402dd}},	//   _दावा_, тром_, симы, _ۇرىڭ, 
   {{0x0935e608,0x67d40124,0xdb0000a2,0x61ec022e}},	//   _خراج, _лолу, _pylç, vbal, 
   {{0x61ec4d57,0xe69410ef,0x00000000,0x00000000}},	//   wbal, _گلبد, --, --, 
   {{0x38c8687d,0x38a81477,0x00000000,0x00000000}},	//   _شاهی_, rørt_, --, --, 
   {{0x61ec0161,0x38a8332e,0xd4980107,0x00000000}},	//   ubal, børs_, врӣ_, --, 
   {{0x2fd00085,0x63a803fa,0x16140150,0xe2980116}},	// [36d10] ɛngɛ_, ßenb, _اسىڭ, ваң_, 
   {{0x61ede609,0xa1940364,0xae14134e,0x648800c0}},	//   sbal, _ҳамч, _डाउन_, ožim, 
   {{0x63a80209,0x61ec0a43,0x41a42ba2,0x30a400d4}},	//   şenb, pbal, _कुरस, ірув, 
   {{0x61ec01d9,0x9408016b,0xa19400ee,0x59c807f7}},	//   qbal, sobɔ_, _гамч, ाइमर, 
   {{0xaee400b8,0x628c0254,0xa7fc0205,0xc0e40240}},	//   _klṛp, miao, nkıs, _ዜብሉ_, 
   {{0x628de60a,0x9e24215c,0x00000000,0x00000000}},	//   liao, _گىرو, --, --, 
   {{0x213403e0,0x00000000,0x00000000,0x00000000}},	//   şahı_, --, --, --, 
   {{0x628de60b,0x81cc0183,0x80d800bc,0x20400092}},	//   niao, ৱৰণ_, _बढाइ, _የማበረ, 
   {{0xd7040131,0x9f50013a,0x00000000,0x00000000}},	//   әзми, _mezí_, --, --, 
   {{0x9855e60c,0x6488219b,0xda180073,0x00000000}},	//   стиш, užil, _धावत_, --, 
   {{0xd78800ec,0x2c1c0073,0xe818098a,0x00000000}},	//   انجو_, _नातं_, _दारा_, --, 
   {{0x60c427cc,0xb4d016d1,0x00000000,0x00000000}},	//   hmhm, षद्_, --, --, 
   {{0x628de60d,0x98e4007b,0x41a429d9,0x00000000}},	//   diao, _اكتو, _कुलस, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6a7c0de2,0x628c4add,0x3ebc005b,0x91e40395}},	//   _déff, fiao, _ohut_, йове, 
   {{0x20cc00f3,0x236411ab,0x628de60e,0x3ebc0051}},	//   _džim_, älja_, giao, _nhut_, 
   {{0x00e401d5,0x26d800d7,0x00000000,0x00000000}},	// [36d20] متلی, írov_, --, --, 
   {{0x20cc0306,0x3ebc0200,0xa7fc0205,0xb3740023}},	//   _užil_, _ahut_, lkır, ከላይን_, 
   {{0x4f0800c7,0x3ebde60f,0x256c0ca8,0x00000000}},	//   унен_, _bhut_, _tólú_, --, 
   {{0x3ebc016d,0xa7fc0790,0x60c401ab,0x9e640116}},	//   _chut_, nkır, amhm, يانن, 
   {{0x64882625,0x3ebc0013,0x1ea85f8e,0xe924031c}},	//   džij, _dhut_, جالي_, _འདེབ_, 
   {{0xff240014,0xc0e00117,0x00000000,0x00000000}},	//   شبۅی, _хорк, --, --, 
   {{0x3f6412b9,0xabb40124,0x00000000,0x00000000}},	//   _лиро_, әақә, --, --, 
   {{0x25ac068f,0x6c3400aa,0x00000000,0x00000000}},	//   żeli_, _ژباړ, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x628c5594,0xeb2c0092,0x00000000,0x00000000}},	//   ziao, ደተገለ, --, --, 
   {{0x38a803cd,0xa6340a4a,0x36d401c6,0x00000000}},	//   tørr_, онні, йдээ_, --, 
   {{0xba14038b,0xa7fc2258,0x6489208e,0xc5e003ce}},	//   _هيما_, tkıs, ržim, कुंठ_, 
   {{0x28f8026b,0xb59401ec,0x00000000,0x00000000}},	//   _тель_, зияш, --, --, 
   {{0xf485e610,0xa7fc03ee,0x2b4c0882,0x648800bc}},	//   пусн, rkıs, _krdc_, mžik, 
   {{0x9a28004d,0xa7fc05d1,0xe1d800d4,0x81cc00fe}},	//   _hươu_, skıs, идві_, ৱৰা_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x0575e611,0x628c0489,0xdb00000f,0x00000000}},	// [36d30] _داغد, riao, _bylû, --, 
   {{0x44243a75,0x628c0421,0x5f9400a7,0x3ebc41fb}},	//   _ùn_, siao, оизт, _shut_, 
   {{0x20cc01a6,0x3ebde612,0x5dd4084c,0x628de613}},	//   _užim_, _phut_, оюлу, piao, 
   {{0x81c800bd,0xe1880166,0x00000000,0x00000000}},	//   রুষ_, _көзе_, --, --, 
   {{0x80e00c58,0x9c58117e,0x00000000,0x00000000}},	//   _পিক্, ишку_, --, --, 
   {{0xc05800d6,0x9f400221,0x81c80154,0xa7fc03e0}},	//   _сім_, nchë_, _র্থ_, zkır, 
   {{0x3ebc03a2,0xa7fc05d1,0x61b8033f,0x9f440208}},	//   _thut_, ykır, _आरुष, _ýlà_, 
   {{0x998c0010,0x9a280208,0x648802f0,0x00000000}},	//   rdež_, _bươu_, užij, --, 
   {{0x2b4c00a3,0x81c8015b,0x888001d3,0xae041870}},	//   _erdc_, রুর_, ڈینن, _رولى, 
   {{0xad240150,0x8d880092,0x6b840115,0x00000000}},	//   _ءىلى, ሜያቸው_, ŝiga, --, 
   {{0x2b4c0048,0x09a802f5,0x2ca1bd09,0x96b85e0c}},	//   _grdc_, খেলা, éide_, иуму_, 
   {{0xd95402e9,0x8f18011a,0x00000000,0x00000000}},	//   _وناخ, סורת, --, --, 
   {{0x15b80510,0x6ef0007f,0x00000000,0x00000000}},	//   рыны_, _kòbò, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd2502115,0x434000a7,0x00000000,0x00000000}},	//   ونس_, мерв, --, --, 
   {{0x4f58035c,0x63a80e78,0x6f0001d3,0x63a0000f}},	//   یجاد_, ßena, _lábá, ûlna, 
   {{0x9f400ffb,0x629c0009,0xc68c00ec,0x45800395}},	// [36d40] lchè_, _djso, _جِي_, _огъв, 
   {{0xd009a003,0x68e57756,0x6ecd2828,0x3864032e}},	//   реже_, _éide, _işbi, _jonr_, 
   {{0x9f41e614,0x81c800bd,0x7645e615,0x64880558}},	//   nchè_, রুল_, _kaiy, džih, 
   {{0x4d48a90c,0x2c1c00dc,0x6fdc0412,0x00000000}},	//   ипен_, _नाहं_, _बलवं, --, 
   {{0x7645e616,0x6ef00100,0x53dc07f7,0xad8400d1}},	//   _maiy, _bòbò, _मलाश, чқай, 
   {{0x6f0000ae,0x7645e617,0x8fd00022,0xcb080818}},	//   _cábá, _laiy, _ҵәҵә, ахид_, 
   {{0x76440076,0x38a803b2,0x98c40139,0x6ed4000d}},	//   _oaiy, vørp_, _şuğa_, _बंटु, 
   {{0x7645e618,0x752401d5,0x2c1c0a59,0x00000000}},	//   _naiy, _oqiz, _नावं_, --, 
   {{0xddc80122,0x3e740205,0x76880166,0x00000000}},	//   _pleť, _uçta_, bıyz, --, 
   {{0x6d41e619,0x00000000,0x00000000,0x00000000}},	//   _isma, --, --, --, 
   {{0x76440c09,0x2c700192,0x09e56c3e,0xc7643769}},	//   _baiy, _ràdh_, _доен, زادى, 
   {{0x7644037e,0x6ef00100,0x00000000,0x00000000}},	//   _caiy, _zòbò, --, --, 
   {{0x394005f5,0x7644037e,0x2fd8003e,0x768806be}},	//   _онцг, _daiy, _ogrg_, nıyy, 
   {{0x6a7c4aee,0x29045d2e,0xe2f802dd,0x26d801d3}},	//   _défe, msma_, йегі_, íros_, 
   {{0x9f404d72,0x29040b21,0x76440363,0x6d400009}},	//   cchè_, lsma_, _faiy, _lsma, 
   {{0x764402a8,0x32000086,0x27fc33b8,0xdd9800a2}},	//   _gaiy, gaiy_, _hevn_, _heňe_, 
   {{0x2905e61a,0x26dc06e4,0x75240472,0x84640395}},	// [36d50] nsma_, _huvo_, _gqiz, _дъне, 
   {{0x764402a8,0x26dc0115,0xdb000030,0x27fde61b}},	//   _zaiy, _kuvo_, _vylú, _jevn_, 
   {{0x2491e61c,0x6d41e61d,0x64453d93,0x7645e61e}},	//   mizm_, _asma, _iahi, _yaiy, 
   {{0x9f41e61f,0x6445e620,0x2905e621,0x27fc7166}},	//   nché_, _hahi, ksma_, _levn_, 
   {{0x6445e622,0x26dde623,0x61fd0950,0x2904000f}},	//   _kahi, _luvo_, _iesl, jsma_, 
   {{0x2491e624,0x61fc076f,0x6445e625,0x6d4004ce}},	//   nizm_, _hesl, _jahi, _dsma, 
   {{0x644597e5,0x2001e626,0x6d41e627,0x60dde628}},	//   _mahi, mahi_, _esma, _husm, 
   {{0x2001e629,0x60d40ab7,0x61fde62a,0x2904000f}},	//   lahi_, _hizm, _jesl, fsma_, 
   {{0x61fc0365,0x7645e62b,0x7e79e62c,0x60dc950b}},	//   _mesl, _raiy, _ilup, _jusm, 
   {{0x26dc4077,0x6445e62d,0x2001e62e,0x6a7de62f}},	//   _buvo_, _nahi, nahi_, _réfe, 
   {{0x66e8038e,0x60dde630,0x60d40369,0x7645e631}},	//   _někd, _lusm, _mizm, _paiy, 
   {{0x9f4137d7,0x76440d04,0x60dc3a3b,0x2001e632}},	//   rchè_, _qaiy, _ousm, hahi_, 
   {{0x6445279f,0x2001e633,0x6d40010a,0x9f4007c5}},	//   _bahi, kahi_, _xsma, schè_, 
   {{0x2001e634,0x6445e635,0x7e7889b9,0x32000295}},	//   jahi_, _cahi, _llup, waiy_, 
   {{0x6444bcc3,0x7e79e636,0x7645e637,0x200004fb}},	//   _dahi, _olup, _taiy, dahi_, 
   {{0x9f40c5bf,0x60d400da,0x61fc0e3c,0x60dc014f}},	//   cché_, _aizm, _cesl, _busm, 
   {{0x6445e638,0x60dde639,0x2001e63a,0x32000428}},	// [36d60] _fahi, _cusm, fahi_, raiy_, 
   {{0x60dde63b,0x7e79e63c,0x64459b3a,0x8fa406bb}},	//   _dusm, _alup, _gahi, пазе, 
   {{0x7e780455,0x0eb839fb,0x60dc01ab,0x6d400175}},	//   _blup, буды_, _eusm, _ssma, 
   {{0x61fde63d,0x0dc805cc,0x2001e63e,0x60d4009d}},	//   _gesl, блей_, aahi_, _eizm, 
   {{0x6445e63f,0x2001e640,0x60dc00a2,0xfd0c00ec}},	//   _yahi, bahi_, _gusm, هجو_, 
   {{0x644400ac,0x2000020c,0x7e79e641,0xc1b80375}},	//   _xahi, cahi_, _elup, _למכש, 
   {{0x394c030d,0x2904002d,0x661c17b5,0x9f400129}},	//   _args_, wsma_, ygsk, yché_, 
   {{0x7e7804b9,0x2905e642,0x60dc0a2e,0x6d40b171}},	//   _glup, tsma_, _yusm, _tsma, 
   {{0x6d41e643,0x26dc014a,0x48a9d7fe,0xbea0d594}},	//   _usma, _suvo_, йтом_, _чатк, 
   {{0x60d4006c,0x2905e644,0x7d78011a,0x7e7800d7}},	//   _xizm, rsma_, _הנמו, _zlup, 
   {{0x394c01f5,0x9f4006af,0x3ae00205,0x2905e645}},	//   _ergs_, tché_, _tıpa_, ssma_, 
   {{0x09281371,0xc98401c0,0x27fc0165,0x661c0158}},	//   _هستي_, _нули, _wevn_, ugsk, 
   {{0x6445e646,0x9f41e647,0x2001e648,0x7c3003cd}},	//   _pahi, rché_, yahi_, _ådrø, 
   {{0x26dde649,0x61fde64a,0x60dd4a75,0x9f41e64b}},	//   _tuvo_, _sesl, _rusm, rbhú_, 
   {{0x2491e64c,0x6445e64d,0x60dde64e,0x2001e64f}},	//   rizm_, _vahi, _susm, vahi_, 
   {{0x2001e650,0x6445e651,0x60f9e652,0x2491e653}},	//   wahi_, _wahi, жная_, sizm_, 
   {{0x20001243,0x644433c3,0x61fde654,0x648807f5}},	// [36d70] tahi_, _tahi, _vesl, dživ, 
   {{0x7e789f65,0x660c020c,0x64441bb6,0x200002b5}},	//   _slup, _hdak, _uahi, uahi_, 
   {{0x2001e655,0x61fc3f58,0x7e79e656,0xc3041ec7}},	//   rahi_, _tesl, _plup, _عبدو, 
   {{0x2001e657,0xa1580046,0x660c007f,0x60dde658}},	//   sahi_, _даму_, _jdak, _tusm, 
   {{0x20001e27,0x660c009a,0x60dc8234,0xceb40daf}},	//   pahi_, _mdak, _uusm, фәр_, 
   {{0x7e7805b1,0x2249e659,0x21291af6,0xe81800e1}},	//   _wlup, ldak_, mtah_, _दागा_, 
   {{0x2f180276,0x21287b10,0x7e7801ef,0x00000000}},	//   _норь_, ltah_, _tlup, --, 
   {{0x660de65a,0x7e79e65b,0xcf9000c8,0x908400db}},	//   _ndak, _ulup, _סטן_, _ىچەك_, 
   {{0x212885dc,0x2248005a,0x981402f2,0x00000000}},	//   ntah_, idak_, وبدا, --, 
   {{0x660de65c,0x2248011f,0xac9400d8,0x00000000}},	//   _adak, hdak_, _зауш, --, 
   {{0x395c0070,0x2249e65d,0x63a80e78,0x21283d91}},	//   sxus_, kdak_, ßenl, htah_, 
   {{0x660c020c,0x2129e65e,0x22494aa6,0xfa24031c}},	//   _cdak, ktah_, jdak_, _རཡིན_, 
   {{0xd9441515,0x660de65f,0x22480548,0x63a83712}},	//   _цели, _ddak, ddak_, şenl, 
   {{0x2258000f,0x660de660,0x2128016d,0x22480327}},	//   _ansk_, _edak, dtah_, edak_, 
   {{0x2129e661,0x41e8063f,0x91e5e662,0xb9c80b82}},	//   etah_, _ụsọ_, добе, _ሳራ_, 
   {{0x648802d5,0xd1741555,0x2129e663,0xc7b00375}},	//   džiu, мызы, ftah_, _שבה_, 
   {{0x41240a83,0x2128011f,0x66e80118,0x648800c0}},	// [36d80] мото_, gtah_, _věke, ežiu, 
   {{0x22480548,0x22580d12,0x3ae000c7,0x6ad80183}},	//   adak_, _ensk_, _oñp_, ণীটো, 
   {{0xa3b405f9,0x2128011f,0x9fc4059f,0xb5c000cc}},	//   _छुप_, atah_, еҳра_, _ইলিচ, 
   {{0x11d4007b,0x21287b10,0x00000000,0x00000000}},	//   _يتحد, btah_, --, --, 
   {{0x6488098d,0x98bc0100,0x21280548,0x9f400c95}},	//   rživ, _aswč_, ctah_, lchì_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x64880232,0x9f400ffb,0x225803b2,0x66e801ef}},	//   mžit, nchì_, _ynsk_, _měkc, 
   {{0x64880427,0x20cc0064,0x00000000,0x00000000}},	//   lžit, _džiu_, --, --, 
   {{0x660c022e,0x0c25e664,0x20400092,0xa3b40118}},	//   _rdak, _оман, _የማቅረ, _छुन_, 
   {{0x6a7de665,0x81c8015b,0x2cb80332,0x6da401ec}},	//   _défa, রুক_, _órd_, _жиға, 
   {{0xe7580212,0xdb0000a2,0x00000000,0x00000000}},	//   чині_, _kylý, --, --, 
   {{0x787cff0c,0x63a80e78,0x21285bf1,0x20cc013a}},	//   _rêve, ßenm, ytah_, _uživ_, 
   {{0x63a803ee,0x660c1d55,0xdd9802f0,0x00000000}},	//   ğenm, _vdak, _keňa_, --, 
   {{0x64880024,0x2128047e,0x1b2000fe,0x1af000eb}},	//   yžiu, vtah_, _মনতে_, _ঘটতে_, 
   {{0x46a41c22,0x628002d5,0xf8340302,0x6a7c00f2}},	//   _ошиб, ūlom, _חנות_, _zéfa, 
   {{0x212881f1,0x00000000,0x00000000,0x00000000}},	//   ttah_, --, --, --, 
   {{0xf194b19d,0x2249a368,0x00000000,0x00000000}},	// [36d90] вить, rdak_, --, --, 
   {{0x2129e666,0x2249e667,0xd0640023,0x60b4b1d7}},	//   rtah_, sdak_, _ተማሂሩ_, رمائ, 
   {{0x2129e668,0x4430003e,0x9f400268,0xf31401c0}},	//   stah_, _ibx_, cchì_, _идээ, 
   {{0x4430030d,0xdb08003e,0x2128047e,0x00000000}},	//   _hbx_, _énén, ptah_, --, 
   {{0xace8b68e,0x21287b04,0x00000000,0x00000000}},	//   ورول_, qtah_, --, --, 
   {{0x9b44007b,0x351c011a,0x00000000,0x00000000}},	//   فنتو, קוונ, --, --, 
   {{0x6a7c67fc,0x0d6000db,0x79b800d1,0x00000000}},	//   _séfa, _ەگىپ, ﺧﺸﯩﻤ, --, 
   {{0x4430037e,0xdb0000a2,0x6f880050,0x35d0012d}},	//   _lbx_, _gylý, _کنہِ_, सेड़, 
   {{0x9f400491,0x6db434b1,0xfd104028,0x5d547701}},	//   ichí_, _айту, _ججز_, _якат, 
   {{0xb9049f6b,0xd9440116,0xad240137,0xdd9801ef}},	//   _मं_, _җеки, _جىكى, _geňa_, 
   {{0x20040051,0x00000000,0x00000000,0x00000000}},	//   _ôliu_, --, --, --, 
   {{0x95840220,0x443002f0,0xfbdc0051,0x907402dd}},	//   елме, _abx_, _đêy_, _ﺼﻠﺤﺔ_, 
   {{0x25000588,0x03a008ca,0x4a9800df,0x00000000}},	//   аҧым, ҳиро, _צינג, --, 
   {{0x4431e669,0xb5e40150,0xccf008c3,0x00000000}},	//   _cbx_, _ﺍﯞﯨﺰ, רכם_, --, 
   {{0xf771e66a,0x03a139f8,0x00000000,0x00000000}},	//   _جاش_, гиро, --, --, 
   {{0x4430070d,0x09c40729,0x9f402b1d,0x11d8007b}},	//   _ebx_, _ষ্টা, rchì_, سوطة_, 
   {{0x8ff83009,0x90c4ad0e,0xa81801ec,0x9f400c86}},	// [36da0] كرار_, ебае, _ءتۇر_, schì_, 
   {{0x0ddc02d3,0x64880122,0xdb0000a2,0xc1e4009d}},	//   _ናቕፋ_, užit, _sylý, _үдэж_, 
   {{0xdef802d5,0x64888256,0x00000000,0x00000000}},	//   дыі_, ržit, --, --, 
   {{0x0dc84f13,0xdd9800d7,0x00000000,0x00000000}},	//   плей_, _seňa_, --, --, 
   {{0xdb000365,0x6440000d,0x64880064,0x00000000}},	//   _eylü, õlig, mžir, --, 
   {{0x4430002d,0xdb0000d7,0x00000000,0x00000000}},	//   _xbx_, _nyló, --, --, 
   {{0x8fa5e66b,0xddc8231e,0x92e00c58,0x0b5800ee}},	//   _чаве, _glež, নীৰ_, ярды_, 
   {{0x66e800bc,0xfaa02758,0x00000000,0x00000000}},	//   _něka, лшын, --, --, 
   {{0x3ea40124,0x8238010f,0x00000000,0x00000000}},	//   énte_, לעקצ, --, --, 
   {{0x67d571b5,0x63a80e78,0x20cc01ef,0x3ea400c7}},	//   копу, ßenk, _užit_, ĩnte_, 
   {{0x44305d2e,0xb9049e51,0x65c80055,0xdab400db}},	//   _rbx_, _मू_, _mūhū, رۇۇت_, 
   {{0x63a8fd2a,0x44300175,0xe694005b,0xbf980a7c}},	//   şenk, _sbx_, тимы, לייש, 
   {{0x443051fa,0x648805be,0x66e80118,0x39100244}},	//   _pbx_, džir, _děka, _مونز, 
   {{0xe8944e5a,0x00000000,0x00000000,0x00000000}},	//   _шаль, --, --, --, 
   {{0xd1dc001f,0x3ce4012d,0xc7940166,0x00000000}},	//   ዕራቡ_, _छूने_, _ярды, --, 
   {{0xb0ec00bd,0x78600022,0x77b8011a,0xf7b805d0}},	//   _ওয়েব_, _акәз, _ממוח, _מזומ, 
   {{0x44311e9e,0xb4e81c62,0x00000000,0x00000000}},	// [36db0] _tbx_, _كىيم_, --, --, 
   {{0xf1c8075e,0xefdc02d3,0x3e7403e0,0x6440000d}},	//   رولى_, ሕጋዊ_, _içti_, õlid, 
   {{0x26c9e66c,0xa2b000cd,0xa3d40798,0x00000000}},	//   _khao_, ंवद्, _јонч, --, 
   {{0x442005ac,0x9db801ec,0xddc801ef,0x00000000}},	//   lgj_, мылу_, _vlež, --, 
   {{0x9d4420f3,0x32540153,0x81c800eb,0x00000000}},	//   телд, _свяр, রুজ_, --, 
   {{0x4420ffe8,0xd11406a9,0x00000000,0x00000000}},	//   ngj_, _בקשה_, --, --, 
   {{0x2011e66d,0x442000b5,0xddc814b2,0x63a80112}},	//   _idzi_, igj_, _ulež, ßenh, 
   {{0x6a7cc90c,0x442000b5,0x26c80208,0x205c0092}},	//   _défo, hgj_, _nhao_, _ለማበረ, 
   {{0xdfe40dad,0x9f4004cc,0x2cbc0076,0xa7fc0e2d}},	//   _औलाद_, lchà_, blvd_, lkıy, 
   {{0x26c801af,0x20040037,0x98540107,0x499001d9}},	//   _ahao_, _õlid_, ттиш, جیٖر, 
   {{0xd1dc00b7,0x44200158,0x3e740205,0x00000000}},	//   ዕራብ_, dgj_, _açti_, --, 
   {{0x26c9e66e,0x00000000,0x00000000,0x00000000}},	//   _chao_, --, --, --, 
   {{0x2010013f,0x3a3c01e3,0x00000000,0x00000000}},	//   _odzi_, meup_, --, --, 
   {{0x201013a1,0x44201125,0x26c80588,0xe0f4031c}},	//   _ndzi_, ggj_, _ehao_, _བསྟད_, 
   {{0x66e801ef,0x00000000,0x00000000,0x00000000}},	//   _těka, --, --, --, 
   {{0x3ddc0b6f,0x00000000,0x00000000,0x00000000}},	//   _nguw_, --, --, --, 
   {{0xc0e03c85,0x6b84010f,0x0694007b,0xd0241a71}},	// [36dc0] иотк, ĝigi, _جنية_, кмай, 
   {{0x1cac025c,0xf8b039bc,0x6b8400df,0x66e801ef}},	//   ྔོས_, ुतिय, ŝigi, _měkn, 
   {{0x403000d6,0xb32c0327,0x6ecc06be,0x2138036e}},	//   реєс, _སཱིང_, _bşbp, _epsh_, 
   {{0x20100bd7,0x6a7de66f,0x91e40276,0xae7400d1}},	//   _edzi_, _réfo, _шоме, دۇرغ, 
   {{0x3a3c003e,0x6a7c06af,0x25f4033f,0xf8b0448b}},	//   deup_, _défl, ूरती_, ुताय, 
   {{0xfbcc004b,0x00000000,0x00000000,0x00000000}},	//   ښتي_, --, --, --, 
   {{0x9c7c0421,0x9f400589,0x8aa5e670,0xaa94344a}},	//   _atōs, rchã_, крид, ликч, 
   {{0x787c6c80,0xbb4400ae,0x656801f4,0x00000000}},	//   _rêva, ئلين_, äehk, --, 
   {{0x63a803ee,0x44200200,0x99dc00a2,0x4d48030d}},	//   ğeni, ygj_, deňd, _юпан_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x638800e8,0x26c801fb,0x64880cf4,0x44200200}},	//   _mëné, _phao_, džip, vgj_, 
   {{0xf98c00aa,0x3a3c00d5,0x9f4003f0,0x00000000}},	//   _ژبو_, ceup_, nchá_, --, 
   {{0x9f4005d5,0xa3b4000d,0x00000000,0x00000000}},	//   zchà_, _छँह_, --, --, 
   {{0x26c80374,0xb6c422cb,0x00000000,0x00000000}},	//   _whao_, лөөд, --, --, 
   {{0x26c807ae,0x442002d3,0xdef4001f,0x41e43981}},	//   _thao_, rgj_, ዎቹን_, віза, 
   {{0x21380240,0xddc80327,0x02bc4c5b,0xa7fc0205}},	//   _ppsh_, _pleż, ्षेन, vkıy, 
   {{0x6a7c20ef,0xf4840b8a,0x9f4000d7,0x00000000}},	// [36dd0] _réfl, _چاپی, dchá_, --, 
   {{0xf485c5cd,0x02c00b67,0xa7fc0205,0x1558011a}},	//   _ناپی, _वीरभ, tkıy, _נכתב, 
   {{0x20cc3421,0xdea116cb,0xde1800c6,0x2294010b}},	//   _džip_, میسی, فقات_, _биня, 
   {{0x9f400c86,0xa7fc03ee,0x271c004d,0x3df0013e}},	//   rchà_, rkıy, ảng_, рҷас, 
   {{0xed58090b,0x9f401570,0x3d2429e7,0xa7fc236c}},	//   кої_, schà_, тьев, skıy, 
   {{0x66e8038e,0x61ede671,0x201002c4,0x6388002e}},	//   _něko, lcal, _udzi_, _gëné, 
   {{0x3a3c3386,0x5b340966,0x6a7c0129,0x7095e672}},	//   teup_, اعتر, _téfl, _тарф, 
   {{0x66e80316,0xe0f40135,0x00000000,0x00000000}},	//   _pěkn, _བསྙད_, --, --, 
   {{0x3a3c3386,0xe9a800e5,0x99dc00a2,0x00000000}},	//   reup_, ہدین_, jeňe, --, 
   {{0x3a3de673,0x00000000,0x00000000,0x00000000}},	//   seup_, --, --, --, 
   {{0xd628013e,0xd70802d5,0x3a3c003e,0x28e80137}},	//   ноне_, энне_, peup_, ндөп_, 
   {{0x8af8011a,0x00000000,0x00000000,0x00000000}},	//   _נהני, --, --, --, 
   {{0xceb00a1e,0x65c00030,0xcad4011a,0x81c803d4}},	//   מיט_, _náhľ, _עונת_, ৰুত_, 
   {{0xd878007b,0xdb2003b2,0x61ec586b,0x00000000}},	//   _سمعت_, _ítót, ecal, --, 
   {{0x9f400784,0x61ec0200,0x00000000,0x00000000}},	//   ychá_, fcal, --, --, 
   {{0x61ede674,0x15440117,0x00000000,0x00000000}},	//   gcal, _беим, --, --, 
   {{0x4638010f,0x10a432b1,0xe3b001e2,0x00000000}},	// [36de0] _טעקע, гиан, مرې_, --, 
   {{0x61ede675,0x9f400113,0xcee8447e,0x00000000}},	//   acal, wchá_, едже_, --, 
   {{0x81e00154,0xe0d400d4,0x20b80108,0x6620013a}},	//   _নজর_, рють, тыть_, _úzký, 
   {{0x61ede676,0x0d845954,0x0dc87c58,0x127800c6}},	//   ccal, ллен, нули_, _أحدث_, 
   {{0xd1744619,0x3ea5e677,0x63a80e78,0xa2b0041c}},	//   _сыны, énta_, ßenv, ंवर्, 
   {{0xd01001d9,0x6b7401c0,0x9f4002d1,0x00000000}},	//   _دلس_, иллу, schá_, --, 
   {{0xf7640720,0x61ec005b,0xbc6410e0,0x00000000}},	//   _اا_, _ällö, امىن_, --, 
   {{0x9f4002d1,0xd0840022,0x00000000,0x00000000}},	//   qchá_, _рыҭи, --, --, 
   {{0x39040323,0xddc80166,0x00000000,0x00000000}},	//   лээн_, _ineş, --, --, 
   {{0x61ede678,0xcb6800f3,0x00000000,0x00000000}},	//   zcal, _пазе_, --, --, 
   {{0x61ec0334,0x66e800bc,0x1b28007b,0x00000000}},	//   ycal, _věko, _لأني_, --, 
   {{0x61ede679,0x09e4009d,0x00000000,0x00000000}},	//   xcal, _содн, --, --, 
   {{0x02a41b74,0x6b8401e4,0x940806be,0x00000000}},	//   ҳрам, ĝigu, libə_, --, 
   {{0x67d5e67a,0x61ec0175,0x2ca001e7,0x00000000}},	//   _колу, wcal, éidh_, --, 
   {{0xa3d49a9a,0xddc8054e,0x12e40107,0x00000000}},	//   ровч, _oneş, иётҳ, --, 
   {{0xb710b249,0x4eb40154,0x00000000,0x00000000}},	//   _ابوش, জগুল, --, --, 
   {{0x940803be,0x35f43cc5,0x7dd80139,0x00000000}},	// [36df0] hibə_, _упыр, _mäsü, --, 
   {{0xe4d801e2,0x00000000,0x00000000,0x00000000}},	//   _جوخت_, --, --, --, 
   {{0x61ede67b,0x2ef40327,0x321000e5,0x00000000}},	//   pcal, _ġafà_, ályú_, --, 
   {{0x5d556cec,0x9e3400d4,0x00000000,0x00000000}},	//   икет, редч, --, --, 
   {{0x2d580212,0x00000000,0x00000000,0x00000000}},	//   лиць_, --, --, --, 
   {{0x787c0129,0x63a803e0,0xdca400f0,0x00000000}},	//   _rêvo, şenu, јаки, --, 
   {{0xda645211,0x00000000,0x00000000,0x00000000}},	//   ивки, --, --, --, 
   {{0x195800c7,0x00000000,0x00000000,0x00000000}},	//   ҵаҩы_, --, --, --, 
   {{0x5fd00210,0x00000000,0x00000000,0x00000000}},	//   थेरल, --, --, --, 
   {{0xd04c03e3,0xefdc0023,0x940806be,0x7c8000fb}},	//   _bibə, ሕጋዝ_, bibə_, _ыҫла, 
   {{0xfa34aaab,0x96640aa8,0x9f40003a,0x88c401c6}},	//   _مرشد, акне, schæ_, рлэв_, 
   {{0x96940b01,0xcfb4011a,0xc0f00092,0x00000000}},	//   ррош, ילתי_, ፍረስ_, --, 
   {{0xb8d8009e,0x3e740790,0x00000000,0x00000000}},	//   _আও_, _uçtu_, --, --, 
   {{0x18681fbe,0x00000000,0x00000000,0x00000000}},	//   _јаки_, --, --, --, 
   {{0xd7b80213,0x8898011a,0xe77800e5,0x00000000}},	//   çədə_, _בבסי, _ملوں_, --, 
   {{0xc3200064,0xd1303092,0x00000000,0x00000000}},	//   юмск, يمز_, --, --, 
   {{0x6a7c0332,0x00000000,0x00000000,0x00000000}},	// [36e00] _défh, --, --, --, 
   {{0xf48400e5,0x00000000,0x00000000,0x00000000}},	//   _چاھی, --, --, --, 
   {{0xb8e41b4b,0xd2a8e662,0x63a80e78,0x8fa4007b}},	//   _ཉེ_, _акне_, ßent, جماه, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8c45e67c,0x1ea8e25c,0xac8401b9,0x7dd8013d}},	//   иеде, دالي_, бҳал, _räsü, 
   {{0x8f74177b,0xcf250661,0x68e400ae,0x00000000}},	//   _кубі, _پرسي, _éidi, --, 
   {{0x2d81e67d,0xd1b80075,0x3f656d35,0xd90c01ed}},	//   šie_, _ساڭا_, _киро_, ہین_, 
   {{0x940800ac,0xddc8054e,0xf3ec0154,0x00000000}},	//   ribə_, _uneş, করির_, --, 
   {{0xc865e67e,0xd90cc870,0x1ea81c4e,0xbd8401d9}},	//   атни, فین_, _صافي_, _پنٕن_, 
   {{0x9da4034c,0x6a7c004a,0xdcac0372,0x692400c7}},	//   _اصفه, _méfi, _كۉن_, амҩа, 
   {{0x8b940e92,0x4a7401d9,0x4a4401f4,0x940803b9}},	//   _трач, _پُشر, _внев, qibə_, 
   {{0x05e8016c,0x00000000,0x00000000,0x00000000}},	//   ъфои_, --, --, --, 
   {{0x25ac1f02,0xdd980432,0xe91800d3,0xc7640137}},	//   çel_, _reňk_, _солі_, _چابى, 
   {{0xb8c803f4,0x1cac0135,0x24852385,0x25ac0135}},	//   _কী_, ྔོག_, ólm_, ħel_, 
   {{0x66e800bc,0xe6580395,0xf7900153,0x00000000}},	//   _měkk, _бийч_, _машэ, --, 
   {{0x32646567,0xbf64429e,0xa19401b9,0xdb0001e3}},	//   отув, یداو, бабч, _tylö, 
   {{0xbad00150,0x00000000,0x00000000,0x00000000}},	// [36e10] _ﺟﯟﺳﺎ, --, --, --, 
   {{0x6a7de67f,0x63a803fa,0x657c00a2,0x44240158}},	//   _défi, ßens, mysh, _øn_, 
   {{0x657ced17,0x3f65e680,0x9df83e1e,0x6d440200}},	//   lysh, штаб, гнет_, çian, 
   {{0x81c80183,0xdd98010e,0xe188008e,0x00000000}},	//   ৰুষ_, _heňi_, _йөзе_, --, 
   {{0x657c010b,0xbd6800a7,0x9f0401d5,0x3d1401f9}},	//   nysh, ърже_, _گوزو, _निळे_, 
   {{0x20847677,0x00000000,0x00000000,0x00000000}},	//   _السّ, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x657c010e,0x00000000,0x00000000,0x00000000}},	//   kysh, --, --, --, 
   {{0x657c036e,0x5c74030d,0x00000000,0x00000000}},	//   jysh, _ллат, --, --, 
   {{0xac740491,0x657de681,0x00000000,0x00000000}},	//   _والش, dysh, --, --, 
   {{0x5a34030d,0x46e40e3b,0x1b2000eb,0x00000000}},	//   _гнет, йдэн_, _মনকে_, --, 
   {{0x8b980375,0xa9084fca,0x00000000,0x00000000}},	//   _גבעת, _چينل_, --, --, 
   {{0x95980452,0x657c010b,0x00000000,0x00000000}},	//   утну_, gysh, --, --, 
   {{0xbee401f9,0x00000000,0x00000000,0x00000000}},	//   _ओढून_, --, --, --, 
   {{0x6379e682,0xa3b405f9,0xc7a06bed,0xdd980432}},	//   астр_, _छुआ_, _нишк, _deňi_, 
   {{0x4fa401e0,0xe6b401ec,0x00000000,0x00000000}},	//   ҙиев, _ولوگ, --, --, 
   {{0x63a80e78,0x00000000,0x00000000,0x00000000}},	// [36e20] ßenr, --, --, --, 
   {{0xd334084c,0x68e53bdc,0x142454d9,0x00000000}},	//   _лэмы, _èide, _удом, --, 
   {{0x92e0015b,0x00000000,0x00000000,0x00000000}},	//   নীড়_, --, --, --, 
   {{0x1dd81b61,0xa92800a2,0x8d84004e,0x00000000}},	//   _बृहत, _hažž, йулд, --, 
   {{0x82341001,0x3200022e,0x82a04c91,0x00000000}},	//   _ارپا, mbiy_, _хаяж, --, 
   {{0x2b4c05b1,0x3200036b,0xf8a400c6,0x41b00133}},	//   _psdc_, lbiy_, _رة_, _ژمێر, 
   {{0x3f540327,0x32000009,0x6af400f1,0x0ba800cf}},	//   _għu_, obiy_, زګار, داشى_, 
   {{0xc3300302,0x657c95da,0x00000000,0x00000000}},	//   פוח_, yysh, --, --, 
   {{0x0d84398a,0x205c001f,0xa3b400ab,0x657c00d8}},	//   _улан, _ለማቅረ, _छुई_, xysh, 
   {{0xdb000129,0xc86400d8,0xa7140114,0x00000000}},	//   _pylô, стии, одољ, --, 
   {{0xb8ec3eaf,0x8d840bd6,0x657c017a,0xf8000006}},	//   _वी_, _туңд, wysh, ччын, 
   {{0x6d40003e,0x46680d84,0x657d1e05,0x25d801c4}},	//   _kpma, уром_, tysh, имны_, 
   {{0x6d40007f,0x99dc0419,0x00000000,0x00000000}},	//   _jpma, peňa, --, --, 
   {{0x657c067d,0xf7f001d9,0x6d4001f4,0xd4980107}},	//   rysh, _ٹٲٹھ, _mpma, ҳрӣ_, 
   {{0x657de683,0x3495a85b,0x00000000,0x00000000}},	//   sysh, чарр, --, --, 
   {{0x6d41e684,0x657c7e14,0x622416a0,0x32088abc}},	//   _opma, pysh, تىرل, йхун_, 
   {{0xb6340592,0x98ac0306,0x00000000,0x00000000}},	// [36e30] _رعيت, zteč_, --, --, 
   {{0xf4200c58,0x44ec0205,0x00000000,0x00000000}},	//   ম্বৰ_, _iü_, --, --, 
   {{0x6455e685,0x6d41e686,0x320007d6,0x3da429db}},	//   mdzi, _apma, bbiy_, әреб, 
   {{0x44ede687,0x6d4000f2,0x6455e688,0xa3b400e1}},	//   _kü_, _bpma, ldzi, _छुए_, 
   {{0x628c0597,0x44ec2045,0x648801fa,0x1cd800cf}},	//   mhao, _jü_, džiz, адды_, 
   {{0x6455e689,0x44ede68a,0x628de68b,0xb08800c0}},	//   ndzi, _mü_, lhao, _лёсе_, 
   {{0x44ec2045,0x6455e68c,0x6d400083,0x20000564}},	//   _lü_, idzi, _epma, mbhi_, 
   {{0x64540a2e,0x44ec007d,0xf8b00882,0x6d400334}},	//   hdzi, _oü_, ुत्प, _fpma, 
   {{0x3ebc15a5,0x6455e68d,0x44ec2ca8,0x200001ab}},	//   _ikut_, kdzi, _nü_, obhi_, 
   {{0x6454068f,0x313c02d3,0xdcf804ba,0xad244c2d}},	//   jdzi, _ኣጋጣሚ, nywč, _رىمى, 
   {{0x628de68e,0x3ebc20ac,0x44edb8eb,0xdcac0228}},	//   khao, _kkut_, _aü_, _كۉچ_, 
   {{0x44ec29ef,0x6455e2dc,0x6d40010a,0x00000000}},	//   _bü_, edzi, _ypma, --, 
   {{0x44ec0cc1,0x18698702,0x99dc0030,0x79a40276}},	//   _cü_, _вали_, meňo, _урже, 
   {{0x44ec8d95,0x6a7de68f,0x99dde690,0x6455e691}},	//   _dü_, _défu, leňo, gdzi, 
   {{0x44ed2c4a,0x63a80e78,0x628c03d5,0x9f4001e7}},	//   _eü_, ßenp, fhao, achú_, 
   {{0x44ede692,0x6455e693,0x628c01e7,0x00000000}},	//   _fü_, adzi, ghao, --, 
   {{0x3201e442,0x0ff800c6,0x6454bdd8,0x98680419}},	// [36e40] rbiy_, لعاب_, bdzi, _lúč_, 
   {{0x394c0798,0x628c0093,0x320001b9,0x8ff80352}},	//   _msgs_, ahao, sbiy_, рхау_, 
   {{0x6d40030d,0x9f500165,0x628c0332,0xc438011a}},	//   _spma, _bezñ_, bhao, _דתיי, 
   {{0x628de694,0x44ede695,0x20000099,0x6a7c020c}},	//   chao, _yü_, abhi_, _yéfu, 
   {{0x3ebc03a2,0x2d5802bf,0x4638008f,0x00000000}},	//   _dkut_, силь_, שענע, --, 
   {{0x3a2c0048,0x3ebc07ab,0xcb180798,0x0b5800ae}},	//   _acgp_, _ekut_, аќи_, لشعب_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d400421,0x6454d591,0x9f400789,0xfe400209}},	//   _tpma, zdzi, ychú_, _онсо, 
   {{0xfe4010f5,0x48a86d56,0x6d41ad7d,0x7d040124}},	//   _інфо, итом_, _upma, rũrã, 
   {{0x44ede696,0x6a7c07ea,0xc198008f,0x0b1800c6}},	//   _rü_, _réfu, ישפי, _نقطة_, 
   {{0x44ec0c86,0x99dc2f5d,0x0a6800f3,0x00000000}},	//   _sü_, beňo, _врли_, --, 
   {{0x6454068f,0x44ede697,0x42941b49,0xb90c063f}},	//   wdzi, _pü_, _መለኮት_, nanị_, 
   {{0xa3dc0882,0xfad400c8,0xf5e401ec,0x00000000}},	//   तेन_, _וואך_, дірм, --, 
   {{0x6aa1e698,0x44ec29ef,0x6455e699,0x628c02b1}},	//   limf, _vü_, udzi, whao, 
   {{0x6455e69a,0x44ec025a,0x628de69b,0x9f4000ae}},	//   rdzi, _wü_, thao, schú_, 
   {{0x44ec2045,0xe78400c2,0x6aa1e69c,0x2ee4017a}},	//   _tü_, _муқо, nimf, _nimf_, 
   {{0x628de69d,0x672816a3,0x44ec0254,0x60c40842}},	// [36e50] rhao, ludj, _uü_, tlhm, 
   {{0x660c0385,0x628de69e,0x6aa00198,0x601000c7}},	//   _heak, shao, himf, _ẽmbu, 
   {{0x660c18a6,0x67282625,0x6aa001f7,0xa3b4000d}},	//   _keak, nudj, kimf, _छँट_, 
   {{0x02a40139,0x826019c5,0xf77008a8,0xdc2c01e1}},	//   _фром, _تۇرن, וקע_, _ẹ̀yi, 
   {{0x63ac0029,0x224801c0,0x6aa00472,0x629ccba3}},	//   šinā, meak_, dimf, _imso, 
   {{0x660de69f,0x22480323,0x672801fa,0x21280066}},	//   _leak, leak_, kudj, muah_, 
   {{0x3ebc0a2e,0x212805b1,0x2f1801c0,0x2ca0068c}},	//   _tkut_, luah_, _морь_, èida_, 
   {{0x224801c0,0x6aa0014b,0xa3dc08e6,0x00000000}},	//   neak_, gimf, तेय_, --, 
   {{0x99dd6178,0x98a409a5,0xd944292c,0xa05c0092}},	//   reňo, зипе, чепи, _ለማንሳ, 
   {{0x224801c4,0xe9a8129d,0x99dc00d7,0x00000000}},	//   heak_, تدىن_, seňo, --, 
   {{0x629cc424,0x660de6a0,0x6aa000ca,0x2249e6a1}},	//   _omso, _beak, bimf, keak_, 
   {{0x85140490,0x224801c0,0x6aa0014b,0x8f98011a}},	//   _तिखट_, jeak_, cimf, מיתי, 
   {{0x22480323,0x660de6a2,0x15b8723f,0x4a70132f}},	//   deak_, _deak, сыны_, _سُور, 
   {{0x629de6a3,0xd2500214,0x1834010f,0x00000000}},	//   _amso, کنر_, _זאַל_, --, 
   {{0x660c72dc,0x67280e3c,0x224801c4,0x00000000}},	//   _feak, cudj, feak_, --, 
   {{0xc7b006a9,0x224801c0,0x660c6e1c,0x5fc40150}},	//   _רבה_, geak_, _geak, _ﺩﺍﭘﺘ, 
   {{0x66e80316,0x00000000,0x00000000,0x00000000}},	// [36e60] _děku, --, --, --, 
   {{0x629de6a4,0x2ee4004e,0x6aa0013e,0x8598011a}},	//   _emso, _simf_, zimf, _לשפו, 
   {{0x3db40156,0x224801c0,0x660c01e2,0x1cac031c}},	//   _བཙུན, beak_, _yeak, ྔོན_, 
   {{0x212827ed,0x22480c6a,0x6aa00472,0xa3b49e51}},	//   buah_, ceak_, ximf, _छुट_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xeb9c74bb,0xabb400c7,0x00000000,0x00000000}},	//   ҳ̸ҳ_, ҟақә, --, --, 
   {{0x6aa0192e,0x629c0042,0x00000000,0x00000000}},	//   timf, _ymso, --, --, 
   {{0xb4d80882,0x67280158,0xfaec01c8,0x3ce4000d}},	//   िषु_, vudj, دثو_, _छूके_, 
   {{0x660de6a5,0x6aa1e6a6,0x67280066,0x0d84022e}},	//   _reak, rimf, wudj, _элан, 
   {{0x660ca769,0x67280003,0x50bc29ea,0x224801c0}},	//   _seak, tudj, ्तिष, zeak_, 
   {{0x660de6a7,0x66e80316,0x6a7c004a,0xc7641183}},	//   _peak, _někt, _défr, سادى, 
   {{0x224801c0,0x6aa0208d,0x00000000,0x00000000}},	//   xeak_, qimf, --, --, 
   {{0x6728e108,0x660de6a8,0x3ea549ed,0x00000000}},	//   sudj, _veak, énti_, --, 
   {{0xb9d8025f,0xc98404a9,0xfd4c0432,0x660c6f94}},	//   _החדש, _муһи, _aziỳ, _weak, 
   {{0x22480323,0x7528068f,0x660de6a9,0x00000000}},	//   teak_, ądza, _teak, --, 
   {{0x2129e6aa,0x8124031c,0x660c02d0,0x04e80154}},	//   tuah_, _ཤཀྱཱ_, _ueak, _কবীর_, 
   {{0x2249e6ab,0x91c004a9,0x00000000,0x00000000}},	// [36e70] reak_, вәрл, --, --, 
   {{0x21280092,0x224801c6,0xf1f401c0,0xdea001d5}},	//   ruah_, seak_, _үзээ, چیسی, 
   {{0x2128001f,0x3f85e6ac,0xdea04d2f,0x2d8003cd}},	//   suah_, ánu_, نیسی, øien_, 
   {{0x629de6ad,0x3f8c068f,0x3f84025c,0x46d000cd}},	//   _umso, ągu_, ġnu_, _धीमह, 
   {{0x3f840b91,0x1be801b9,0x2129e6ae,0x4cf000f1}},	//   šnu_, одли_, quah_, نګلس, 
   {{0x8c408b82,0xac8401ec,0x6b9800cd,0x00000000}},	//   веше, нгіл, _śroṇ, --, 
   {{0x6a7c4fc1,0x0f300451,0xaac4004b,0x99dc00d7}},	//   _réfr, _لکند, کتون, reňm, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4430200c,0xa3dc041c,0x43300023,0xdd000064}},	//   _ocx_, तेत_, _ይግበኣ, _įtėv, 
   {{0x6f8801d9,0x7e79e6af,0x00000000,0x00000000}},	//   _بنہِ_, _houp, --, --, 
   {{0x7e79e6b0,0xe9a800e5,0x00000000,0x00000000}},	//   _koup, قدین_, --, --, 
   {{0x4430070d,0x7e79b228,0x38640af9,0x00000000}},	//   _acx_, _joup, _wnnr_, --, 
   {{0x7e78007f,0x00000000,0x00000000,0x00000000}},	//   _moup, --, --, --, 
   {{0x7e79e6b1,0x4431e6b2,0x00000000,0x00000000}},	//   _loup, _ccx_, --, --, 
   {{0xca9c0023,0x84e000f5,0x00000000,0x00000000}},	//   ግረኩም_, торж, --, --, 
   {{0x7e780433,0x47d0030c,0x22140108,0x00000000}},	//   _noup, _جيىر, еффр, --, 
   {{0x44300175,0x00000000,0x00000000,0x00000000}},	// [36e80] _fcx_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7e79e6b3,0xa56401d5,0x00000000,0x00000000}},	//   _boup, _قدین, --, --, 
   {{0x7e79e6b4,0x0dc84ea8,0x00000000,0x00000000}},	//   _coup, олей_, --, --, 
   {{0x41000801,0xbea00640,0x7e79e6b5,0x00000000}},	//   _изяв, њачк, _doup, --, 
   {{0xec1401d5,0x00000000,0x00000000,0x00000000}},	//   روبد, --, --, --, 
   {{0x0b58010b,0x80b0012d,0x3fe0014b,0x00000000}},	//   юрды_, _आदते, _ажрв, --, 
   {{0x7e7806af,0x433002d3,0xfaa02fe5,0x3d140210}},	//   _goup, _ይግባኣ, кшын, _निचे_, 
   {{0x3dc007d6,0xbea010fc,0xb520012c,0x3ea40100}},	//   _айтг, _ратк, _बिषय_, ènte_, 
   {{0x433002d3,0x7e780077,0xa7740b7e,0x27f800a3}},	//   _ይግብኣ, _zoup, елоч, ùrn_, 
   {{0x7e79e6b6,0x3ce40dad,0xf76c038b,0x0cc836c7}},	//   _youp, _छूटे_, لاَ_, ितीम, 
   {{0x4990082a,0x3b0402e8,0xb0d0012d,0x85440139}},	//   _لیبر, _цецо_, _तीसग, мэге, 
   {{0x4431e6b7,0xe584009d,0x00000000,0x00000000}},	//   _pcx_, хтнү, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc79400ee,0x2508179e,0x00000000,0x00000000}},	//   _юрды, _کربی_, --, --, 
   {{0x27386bf8,0x60f889f1,0x0cc800dc,0xdb081bce}},	//   mén_, зная_, ितुम, ënée, 
   {{0x7e79e6b8,0xfbc400cc,0x00000000,0x00000000}},	// [36e90] _roup, ষেপত, --, --, 
   {{0x6fa01533,0x7e79e6b9,0x2bc40c2e,0x00000000}},	//   _गेहू, _soup, _लुभा, --, 
   {{0x7e79e6ba,0x2739e6bb,0xdfd400c0,0x00000000}},	//   _poup, nén_, хожы, --, 
   {{0x05d000e1,0xd5a401d5,0x8c840124,0xae040116}},	//   _सराब, _آلیی, ҕәуа_, نومى, 
   {{0x1d0896f2,0x22580175,0x2739364c,0xceb404b4}},	//   чели_, _iask_, hén_, хәр_, 
   {{0x7e78006f,0x2739e6bc,0xd24c0014,0x91c000fb}},	//   _woup, kén_, _پچہ_, _сәсл, 
   {{0x2739e6bd,0x7e780699,0x2259e6be,0x20100356}},	//   jén_, _toup, _kask_, _iezi_, 
   {{0x2739e6bf,0x2010009d,0x61340023,0x99dc010e}},	//   dén_, _hezi_, _ይርድኣ, leňi, 
   {{0x20105906,0x2258029d,0x00000000,0x00000000}},	//   _kezi_, _mask_, --, --, 
   {{0x20100d29,0x7d183b6a,0x27380bfa,0x22580254}},	//   _jezi_, _ivus, fén_, _lask_, 
   {{0x7d181125,0x2011e6c0,0x2739e6c1,0x00000000}},	//   _hvus, _mezi_, gén_, --, 
   {{0x20100364,0xb4d81d90,0x225800df,0x99dc00a2}},	//   _lezi_, िष्_, _nask_, heňi, 
   {{0xd945e6c2,0x3eac00c6,0xa3dc0073,0xd7c801d5}},	//   _чели, ingt_, तेस_, توگه_, 
   {{0x27380615,0x9584005e,0x7d180943,0x2010004b}},	//   bén_, _үлке, _mvus, _nezi_, 
   {{0x213807d6,0x273821fc,0x395c16b8,0x3ce40037}},	//   _aqsh_, cén_, lvus_, _छूछे_, 
   {{0x7d1801f0,0xd0480213,0x91e40108,0x395c0064}},	//   _ovus, ənəv, еобе, ovus_, 
   {{0x95540491,0x7644015c,0x2011e6c3,0x22580205}},	// [36ea0] _أخبا, _ibiy, _bezi_, _dask_, 
   {{0x2258000f,0x3eac02c1,0x395c0024,0xa3dc1a04}},	//   _eask_, engt_, ivus_, तेह_, 
   {{0x7d19e6c4,0x2011c5f4,0x225805c7,0x53a5e6c5}},	//   _avus, _dezi_, _fask_, _чанб, 
   {{0x940401d5,0x22580139,0x395c01e4,0x00000000}},	//   _توگه, _gask_, kvus_, --, 
   {{0x76440502,0x2d80054e,0x00000000,0x00000000}},	//   _mbiy, âie_, --, --, 
   {{0x2011e6c6,0x8fa40022,0x3eac04e6,0x395de6c7}},	//   _gezi_, _заге, angt_, dvus_, 
   {{0x7d19e6c8,0x3a3c0194,0x76452590,0x395d9052}},	//   _evus, ffup_, _obiy, evus_, 
   {{0x2011e6c9,0x2739e6ca,0x00000000,0x00000000}},	//   _zezi_, vén_, --, --, 
   {{0xd90c4987,0x2010004b,0x7c340240,0x27387e7d}},	//   قین_, _yezi_, çarë, wén_, 
   {{0x8b941dbc,0x2739e6cb,0x6da4014b,0x00000000}},	//   _преч, tén_, _зиға, --, 
   {{0x764404ba,0xf98c04fb,0x66940063,0x9ba00e8e}},	//   _bbiy, لبی_, ванђ, _پەيى, 
   {{0x2739e6cc,0xa5f80108,0xb6c800e5,0x00000000}},	//   rén_, ьему_, ٹاپے_, --, 
   {{0x22582ab7,0x16700220,0x9f40180f,0xab280116}},	//   _rask_, рқыр, nchò_, _хоҗа_, 
   {{0x76450db9,0x2739e6cb,0x00000000,0x00000000}},	//   _ebiy, pén_, --, --, 
   {{0x201007ab,0x2259e6cd,0x00000000,0x00000000}},	//   _rezi_, _pask_, --, --, 
   {{0x20105062,0x76440cad,0x26dc01e1,0x00000000}},	//   _sezi_, _gbiy, _òwo_, --, 
   {{0x22582ab7,0x9f4007de,0x80240035,0xb5a400c0}},	// [36eb0] _vask_, schü_, فرام, _брэй, 
   {{0x6e20011f,0x2259e6ce,0x6728017a,0x34940354}},	//   _admb, _wask_, ordj, _баьр, 
   {{0x2011e6cf,0x4ab029da,0x64442747,0x6f1c01fa}},	//   _vezi_, ुकाव, _ibhi, _cvrc, 
   {{0x531800c8,0x20107f87,0x6e947db4,0x395c0024}},	//   _קורצ, _wezi_, лиху, yvus_, 
   {{0x760c00c8,0x61fc0076,0xa3f402ab,0xa3dc095f}},	//   פּאַ, _ifsl, _आलाप_, तेर_, 
   {{0x2129e6d0,0x00000000,0x00000000,0x00000000}},	//   mrah_, --, --, --, 
   {{0x6445e6d1,0x9f400407,0x5fc40490,0x3e3001ed}},	//   _mbhi, rchó_, _वडिल, _مہار, 
   {{0x7d1801fa,0x395c0037,0x00000000,0x00000000}},	//   _tvus, tvus_, --, --, 
   {{0x7d185b36,0x21280652,0xb60400bc,0x6445e6d2}},	//   _uvus, nrah_, ndář, _obhi, 
   {{0x2128207a,0x395de6d3,0x0d200372,0x5fc419cc}},	//   irah_, rvus_, _түшү, _वडाल, 
   {{0x21280649,0xd628013e,0x61fc045f,0xfb24014d}},	//   hrah_, моне_, _ofsl, _سراپ, 
   {{0x64440a28,0x212960cf,0x00000000,0x00000000}},	//   _abhi, krah_, --, --, 
   {{0x21286e2b,0x672801f5,0x7ae80009,0x4a9808a8}},	//   jrah_, ardj, _iigt, _קינג, 
   {{0x61fde6d4,0x7ae80589,0x98a43756,0x64440055}},	//   _afsl, _higt, _шиле, _cbhi, 
   {{0x7ae8089c,0x212804fb,0x64440055,0xb9d80b82}},	//   _kigt, erah_, _dbhi, _ኣሉ_, 
   {{0xd04c0085,0x76440b6f,0x6445e6d5,0x31600165}},	//   _libɔ, _ubiy, _ebhi, tviz_, 
   {{0x21296530,0x6f1c0118,0x7ae80064,0xe2a808f0}},	// [36ec0] grah_, _svrc, _migt, رافن_, 
   {{0x7ae9e6d6,0x644401ab,0x3161e6d7,0x64400254}},	//   _ligt, _gbhi, rviz_, õlit, 
   {{0x2129e6d8,0x99dc0419,0xa3a80b27,0x00000000}},	//   arah_, meňu, _खेप_, --, 
   {{0x0d85e6d9,0x2129e6da,0x7ae80810,0x0dc80107}},	//   клен, brah_, _nigt, мули_, 
   {{0xfd540055,0x00000000,0x00000000,0x00000000}},	//   _khaṣ, --, --, --, 
   {{0x53d405d7,0xfd54002b,0xf8a433d2,0x00000000}},	//   _धराश, _jhaṣ, _ضة_, --, 
   {{0x8fa5e6db,0x7ae9e6dc,0x6fe00c58,0x3f5404ce}},	//   _раве, _bigt, _প্ৰে, でup_, 
   {{0x6728248d,0xfb8007e6,0xa3e40073,0x00000000}},	//   vrdj, рышн, _फणस_, --, 
   {{0x7ae9e6dd,0x3911e6de,0x4ce401b9,0xa7fc2737}},	//   _digt, амыр, _ажаб, ndıg, 
   {{0x4b500014,0x7ae8002f,0x29040790,0xcb6800f3}},	//   _نێتر, _eigt, rpma_, _оазе_, 
   {{0x212805b1,0x64442de1,0x00000000,0x00000000}},	//   zrah_, _rbhi, --, --, 
   {{0x64440280,0x21289c8f,0xfd540055,0x7ae9e6df}},	//   _sbhi, yrah_, _ahaṣ, _gigt, 
   {{0x3855271c,0xfd5400b8,0x00000000,0x00000000}},	//   رشید_, _bhaṣ, --, --, 
   {{0x229403cd,0x50bc07f7,0x67d4074d,0x7ae8002f}},	//   _måke_, ्तऋष, _йолу, _zigt, 
   {{0xa3dc028a,0x64440789,0x00000000,0x00000000}},	//   तें_, _vbhi, --, --, 
   {{0xa5c45ab1,0x2128c85d,0x7ae801d9,0x00000000}},	//   _бөге, trah_, _xigt, --, 
   {{0x229405ac,0xe0d867f0,0x26c800a2,0x6440000d}},	// [36ed0] _nåke_, едач_, _ikao_, õlis, 
   {{0x64440028,0x99dc0306,0x64400115,0x6454009b}},	//   _ubhi, meňt, ĵlis, _свођ, 
   {{0xa7fc0205,0x00000000,0x00000000,0x00000000}},	//   mdıd, --, --, --, 
   {{0x2129e6e0,0xa3dc0882,0xf2040153,0x00000000}},	//   prah_, तेः_, _вяро, --, 
   {{0x7ae9e6e1,0x26c801c8,0x9d440220,0x2128031c}},	//   _rigt, _mkao_, уелд, qrah_, 
   {{0x7ae9e6e2,0x229400cc,0x628da477,0x40840064}},	//   _sigt, _dåke_, lkao, _румб, 
   {{0x7ae9e6e3,0xfeb83818,0x60c4016d,0xf41800cc}},	//   _pigt, _قارت_, mohm, _তামৰ_, 
   {{0x628c02ce,0xddc80003,0x60c4607b,0x7d2400f1}},	//   nkao, _koeż, lohm, _ليرې_, 
   {{0x7ae8105c,0x2004000d,0x628c03b2,0x99840b24}},	//   _vigt, _õlis_, ikao, الخو, 
   {{0xd7081c22,0x26c9e6e4,0x7ae8017a,0x9854f5e8}},	//   нное_, _akao_, _wigt, утиш, 
   {{0x16a95b4d,0x7ae8409c,0x628c01f4,0xa7fc03e0}},	//   евни_, _tigt, kkao, zdıg, 
   {{0x60c427cc,0xb80012eb,0x19b8030d,0x00000000}},	//   hohm, _श्रम_, _пуль_, --, 
   {{0xba1400ec,0x28080419,0x00000000,0x00000000}},	//   _ٻيڙا_, ätná_, --, --, 
   {{0x7998009f,0xc95000d9,0xa7fc0205,0x09c400eb}},	//   mzuw, _למד_, vdıg, শেহা, 
   {{0x60c4020b,0x7998002f,0x66dc00e5,0x00000000}},	//   dohm, lzuw, dékf, --, 
   {{0x628de6e5,0x18a400b1,0x53780240,0x00000000}},	//   gkao, _шаһм, _ኪኸይድ_, --, 
   {{0x4125e6e6,0xd7c8021a,0x7999e6e7,0xe800012c}},	// [36ee0] лото_, _توګه_, nzuw, लुवा_, 
   {{0x45980bd4,0x248004cc,0x628c004c,0x22940158}},	//   _נסיע, _gohm_, akao, _råke_, 
   {{0x998c0010,0xd0080166,0x00000000,0x00000000}},	//   jfež_, _җебе_, --, --, 
   {{0xff2401b9,0xe3b401ec,0x99dc0432,0x00000000}},	//   ابلی, _тұс_, neňs, --, 
   {{0x60c40455,0x217434bb,0x9988010e,0xa3b417ee}},	//   bohm, _курр, _ýaň_, जपथ_, 
   {{0x6adc2b3d,0x79980bd7,0x090401b9,0x00000000}},	//   मग्र, dzuw, қчим, --, 
   {{0x27e00115,0xcb448ce7,0xbc64009f,0xa7fc06be}},	//   _ĝino_, ухли, طمين_, ndıe, 
   {{0x229408fb,0x79980112,0xbb450565,0xa3b40210}},	//   _tåke_, fzuw, الين_, जपत_, 
   {{0x99dc1525,0xa7fc0205,0x00000000,0x00000000}},	//   deňs, ydıd, --, --, 
   {{0x628d5721,0xefdc01f3,0xaf480092,0xce3400f1}},	//   zkao, ንጋይ_, _አላስፈ, _جوړک, 
   {{0x67d40137,0x00000000,0x00000000,0x00000000}},	//   рону, --, --, --, 
   {{0x478401e0,0x6e240332,0x00000000,0x00000000}},	//   _ҡыйб, óibh, --, --, 
   {{0x7998033f,0xda64007b,0x00000000,0x00000000}},	//   czuw, _خالي, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x628c37e9,0x4cdc0154,0x60c4022e,0x99dc01ef}},	//   tkao, মদপু, vohm, beňs, 
   {{0x67000521,0xddc80003,0x41e5df06,0x66dc00e5}},	//   _ịkwa, _poeż, гіза, dékg, 
   {{0xb6340132,0x36341c3e,0xcf940066,0x66dc00e5}},	// [36ef0] _اعىت, _ارىس, یدمژ, tékf, 
   {{0x3015e6e8,0x00000000,0x00000000,0x00000000}},	//   йдур, --, --, --, 
   {{0x60c5e6e9,0x779000ac,0x2d8001c7,0x79980165}},	//   rohm, təxə, äien_, zzuw, 
   {{0x60c40477,0x00000000,0x00000000,0x00000000}},	//   sohm, --, --, --, 
   {{0xa3a8d44d,0x2b4c00db,0xddc407b5,0x00000000}},	//   _खेत_, _apdc_, јбли, --, 
   {{0x99dc012c,0x00000000,0x00000000,0x00000000}},	//   zeňs, --, --, --, 
   {{0x3f84007d,0x75280034,0x5a94013e,0x3e0400c0}},	//   änud_, ądzi, ириф, _бязв, 
   {{0x7998002f,0x6fac0208,0xcb44010a,0x00000000}},	//   tzuw, _ýthứ, ăхли, --, 
   {{0xa9042b09,0x2b4c0ac5,0x22c40521,0x5c74020f}},	//   یبین, _epdc_, ịkwa_, _клат, 
   {{0xa3b50676,0x7999e6ea,0x5745e6eb,0x5fb80709}},	//   जपा_, rzuw, аноб, _आशाल, 
   {{0x79980e78,0x00000000,0x00000000,0x00000000}},	//   szuw, --, --, --, 
   {{0x55e400c7,0x15b8013d,0x00000000,0x00000000}},	//   ионб, выгы_, --, --, 
   {{0xf7700a81,0x5d78010f,0x00000000,0x00000000}},	//   _گاش_, דאָק, --, --, 
   {{0x17c82b97,0x00000000,0x00000000,0x00000000}},	//   _игли_, --, --, --, 
   {{0xc7a11394,0xf771e6ec,0xd25025a7,0x2b4c0ac5}},	//   _мишк, _داش_, ينس_, _xpdc_, 
   {{0x6b6001ed,0xf8bc002e,0x53a40107,0x56640066}},	//   lágá, ééf_, гаҳб, _ضدعف, 
   {{0x0161e6ed,0x644000cf,0x00000000,0x00000000}},	// [36f00] окто, òlic, --, --, 
   {{0xfe6c00aa,0xa6cc00fe,0xd008009b,0x00000000}},	//   ېدو_, _ৰূপট, теже_, --, 
   {{0xb4c41df1,0xa7fc03b9,0x20c80472,0x00000000}},	//   ौती_, ldıc, ابقي_, --, 
   {{0xb8d41efe,0xcd04a3c8,0x8d6421fa,0x00000000}},	//   _ཙམ_, ачки, ивее, --, 
   {{0xd175e6ee,0x8d5408da,0x00000000,0x00000000}},	//   _тыны, ртеч, --, --, 
   {{0x66dc8708,0x00000000,0x00000000,0x00000000}},	//   méke, --, --, --, 
   {{0x66dc00dd,0xef1000aa,0xbca0007b,0x00000000}},	//   léke, _رڼا_, تموي, --, 
   {{0x320000e8,0x00000000,0x00000000,0x00000000}},	//   nciy_, --, --, --, 
   {{0x14c400dc,0xaa4810e0,0x66dc00e5,0x00000000}},	//   लकाण, _ەستە_, néke, --, 
   {{0x7b840075,0x2b4c01f7,0x00000000,0x00000000}},	//   _ھالە, _tpdc_, --, --, 
   {{0x7e00063f,0x2b4c04cc,0x66dc0098,0xddc80166}},	//   _ọsis, _updc_, héke, _kaeş, 
   {{0x19a80220,0x2ef80036,0x67d40075,0x00000000}},	//   _өтіп_, _murf_, _қойу, --, 
   {{0xddc8054e,0xb990027d,0xa3a8000d,0x00000000}},	//   _maeş, _ولمب, _खइह_, --, 
   {{0x7b040066,0x66dca5b2,0x6d400334,0xddc8013d}},	//   _èstè, déke, _mqma, _laeş, 
   {{0x02a5056f,0x82a4b0b9,0xe70475a7,0xfdd04540}},	//   арам, ашае, _استی, _तर्फ, 
   {{0x6d40022e,0x3f8406ea,0x00000000,0x00000000}},	//   _oqma, ønum_, --, --, 
   {{0xc429e6ef,0xddc800df,0xa1140592,0x41e400d4}},	// [36f10] _июне_, _pneŭ, صوات, ріва, 
   {{0x998c0219,0x2454009a,0x80042cdd,0x00000000}},	//   ngeš_, _اندس, рчае, --, 
   {{0x6455e6f0,0x6d41e6f1,0x00000000,0x00000000}},	//   mezi, _aqma, --, --, 
   {{0x2ef82a28,0xb9d802d3,0xe3f8113e,0x320000e8}},	//   _durf_, _ኣፉ_, _جىگت_, cciy_, 
   {{0xdce801e4,0x91a80014,0x00000000,0x00000000}},	//   _hreĉ, _منَے_, --, --, 
   {{0x661de6f2,0xdd9401e0,0x00000000,0x00000000}},	//   hask, _һабы, --, --, 
   {{0x1fe45d2d,0x661de6f3,0x2001e6f4,0x645400a7}},	//   _প্রস, kask, mchi_, iezi, 
   {{0x661de6f5,0x2001e6f6,0x6455e6f7,0x13a804c5}},	//   jask, lchi_, hezi, _খুড়, 
   {{0xd1e0044e,0x6455e6f8,0x6ea800a7,0x2000037e}},	//   _ጐይታ_, kezi, _търг_, ochi_, 
   {{0x2001e6f9,0x6455e6fa,0xfbe000cc,0x15b86171}},	//   nchi_, jezi, নুগত, ғымы_, 
   {{0x2001e6fb,0x661de6fc,0x66dc01d3,0xe0b40c58}},	//   ichi_, fask, zéke, _জীৱন, 
   {{0x6455e6fd,0x2000036b,0x6b6001ed,0x66dc01d3}},	//   eezi, hchi_, ságá, yéke, 
   {{0x6455e6fe,0x2001e6ff,0x3d080073,0x00000000}},	//   fezi, kchi_, ठीचे_, --, 
   {{0x6455e700,0x20000227,0x66dc00dd,0x22944535}},	//   gezi, jchi_, véke, _råka_, 
   {{0x66dc0c6a,0x200001d5,0x9f440ca8,0x00000000}},	//   wéke, dchi_, _àlè_, --, 
   {{0x66dc066d,0x2001e701,0x661c058a,0x55f40137}},	//   téke, echi_, cask, _учку, 
   {{0x6455e702,0xd0242365,0x2ef94314,0x0634011a}},	// [36f20] bezi, ймай, _surf_, _הנפט_, 
   {{0x6455e703,0x6d4001b9,0xb35801d3,0x2d800036}},	//   cezi, _rqma, _پیرا_, äiem_, 
   {{0x66dde704,0xb4c4012c,0x752402f0,0xb9000327}},	//   séke, एकी_, _hviz, _ྩེ_, 
   {{0xc330025f,0x2001e705,0x2294143a,0xd17404f0}},	//   _צור_, achi_, _tåka_, _лыгы, 
   {{0xf76455c1,0x9e640131,0x2ef80e78,0x4638008f}},	//   _کا_, تالن, _wurf_, רענע, 
   {{0x2001e706,0x2ef81590,0x661c0210,0x00000000}},	//   cchi_, _turf_, zask, --, 
   {{0x661de707,0x8aa402a9,0xbb44007b,0x00000000}},	//   yask, йрид, ملون_, --, 
   {{0x6455e708,0x7524030a,0x63a80115,0x66dc00e5}},	//   zezi, _oviz, ŝeng, zékb, 
   {{0x6455e709,0x47840588,0x6d400166,0x98ac0135}},	//   yezi, ӡынб, _uqma, wweġ_, 
   {{0x415800c8,0xc17002e4,0xf98c007b,0x00000000}},	//   נדיג, פחת_, عبي_, --, 
   {{0x661de70a,0x7525e70b,0x4a4406ac,0xc078008f}},	//   task, _aviz, _гнев, אטיש, 
   {{0x661c0165,0x75240200,0x200001d5,0x66dc00e5}},	//   uask, _bviz, zchi_, dékc, 
   {{0xc9d411dc,0x66dc01ed,0x2000f1de,0x49900244}},	//   _ازاب, tékb, ychi_, _ریدر, 
   {{0x661c3c41,0x64540dd4,0xdce801e4,0x200001b9}},	//   sask, uezi, _preĉ, xchi_, 
   {{0x6455e70c,0x20000517,0xf8bc07ea,0x87047c3c}},	//   rezi, vchi_, éée_, _ابتل, 
   {{0x6454fd4f,0x661de70d,0x00000000,0x00000000}},	//   sezi, qask, --, --, 
   {{0x6455e70e,0x2001e70f,0xa3a83d1d,0x352400db}},	// [36f30] pezi, tchi_, _खेर_, _فىيف, 
   {{0x656de710,0x64540240,0x63541d1c,0x643400d1}},	//   _irah, qezi, _двоу, _بىدئ, 
   {{0x2001e711,0x752405b8,0x9df8873c,0x224c00c7}},	//   rchi_, _zviz, анет_, _ñeko_, 
   {{0x2001e712,0x656c044e,0x3fa00135,0x41e400d3}},	//   schi_, _krah, _ħruġ_, _гіга, 
   {{0x2001e713,0x657c02d0,0x00000000,0x00000000}},	//   pchi_, nxsh, --, --, 
   {{0xa3bc05ba,0x2001e714,0x656c009f,0x2248013d}},	//   _अशा_, qchi_, _mrah, lfak_, 
   {{0xddc80232,0xa3dc0490,0xc0c002d3,0x00000000}},	//   _dneš, तेच_, ኻኽር_, --, 
   {{0x656de715,0x00000000,0x00000000,0x00000000}},	//   _orah, --, --, --, 
   {{0xadbc030d,0x00000000,0x00000000,0x00000000}},	//   _батi, --, --, --, 
   {{0x3eade716,0x57481768,0x28a4c8bf,0x2bc40550}},	//   ligt_, азом_, गोलि, _लुका, 
   {{0xa3a814cf,0x75241675,0x2248020b,0x00000000}},	//   _खेल_, _sviz, kfak_, --, 
   {{0x656c1161,0x247836bc,0x3eade717,0xddc80306}},	//   _brah, _ኢየሱስ_, nigt_, _zneš, 
   {{0x2248002d,0x00000000,0x00000000,0x00000000}},	//   dfak_, --, --, --, 
   {{0x09b00c58,0xa7fceaab,0x3eac0e78,0x769800b8}},	//   _চৰকা, ldın, higt_, _dãya, 
   {{0x91c40729,0x656de718,0xdbd40086,0x3eac0267}},	//   _শৃংখ, _erah, _kùñi, kigt_, 
   {{0xa3a80574,0xa7fc456f,0xdbd40086,0x656c0327}},	//   _खेळ_, ndın, _jùñi, _frah, 
   {{0x3eade719,0x75240268,0xe8001af8,0x656c6d11}},	// [36f40] digt_, _uviz, लुका_, _grah, 
   {{0x92a8045e,0xd0240150,0x00e0011c,0x00000000}},	//   খকে_, імей, джун, --, 
   {{0xe44800db,0x656c0010,0xb9e00023,0x00000000}},	//   _الپى_, _zrah, _ሪጋ_, --, 
   {{0xdbd40428,0x3eade71a,0xddc800f3,0xc7b0011a}},	//   _nùñi, gigt_, _sneš, ובב_, 
   {{0xdce80003,0x66dde71b,0x63a80115,0x8d58117e}},	//   _greċ, néka, ĝene, ршет_, 
   {{0x8fa4074d,0xcf24216b,0xd47800df,0x00000000}},	//   _даге, _ورزي, שאַל, --, 
   {{0x66dc0066,0x3ead3e29,0xddc80427,0x00000000}},	//   héka, bigt_, _vneš, --, 
   {{0x66dc065c,0x0de80092,0x00000000,0x00000000}},	//   kéka, ቅልፍ_, --, --, 
   {{0x66dc0098,0x00000000,0x00000000,0x00000000}},	//   jéka, --, --, --, 
   {{0xb4c402f8,0x656c02d3,0x6da40131,0xddc801a6}},	//   एको_, _rrah, _диға, _uneš, 
   {{0x656c0066,0xe75802bf,0xb4c400bc,0x7dec0064}},	//   _srah, щині_, एकै_, _vėsū, 
   {{0x656de71c,0xc6a402bf,0x49c85232,0x07f800c7}},	//   _prah, ірни, _клен_, ыхҩы_, 
   {{0x66dc020c,0x3688009d,0x00000000,0x00000000}},	//   géka, цсэн_, --, --, 
   {{0x656cb22c,0xdce80327,0x84c8084c,0x3ead0253}},	//   _vrah, _rreċ, румб_, zigt_, 
   {{0x224803ee,0x68e8007c,0xc6d4007b,0x00000000}},	//   tfak_, mmdd, _وتعت, --, 
   {{0x656de71d,0xd498016c,0x3eac0267,0xdce8003d}},	//   _trah, арӣ_, xigt_, _preċ, 
   {{0x656d6b3e,0x3eac2611,0x00000000,0x00000000}},	// [36f50] _urah, vigt_, --, --, 
   {{0x9418013f,0xe4d814a5,0x3eac002f,0x00000000}},	//   _mmpɛ_, _دوخت_, wigt_, --, 
   {{0xd1dc693c,0x3eade71e,0xc2e4036b,0xa7fc7975}},	//   ንያቱ_, tigt_, _мўми, ydın, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3eade71f,0x41e44dba,0x5278011a,0x12780a7c}},	//   rigt_, _фіна, _הנרא, _הארע, 
   {{0x3eac7589,0xa0c43be1,0xace80b24,0x00000000}},	//   sigt_, _ريزو, يرول_, --, 
   {{0x26c000c8,0x3eac0267,0x66dc00e5,0x00000000}},	//   _ĉion_, pigt_, zéka, --, 
   {{0xd12c01d9,0x69dc003a,0xaae415f2,0x00000000}},	//   _جۅے_, ęren, وسيو, --, 
   {{0xf2d400c8,0x67000521,0xa7fc1b0d,0x7c641f0d}},	//   ועק_, _ịkpa, rdın, _وائل, 
   {{0x3ebc0327,0x68e80083,0x66dc03df,0x00000000}},	//   _hjut_, gmdd, véka, --, 
   {{0x186807d6,0xd70400d1,0x66dc002e,0x84680023}},	//   _ҳали_, язни, wéka, _ትምራሕ_, 
   {{0x98ac0fb7,0xa7fc4956,0x2bc41889,0xf4180183}},	//   mreč_, ldıl, _लुटा, _তাইৰ_, 
   {{0x1869e720,0xaab00118,0x00000000,0x00000000}},	//   _гали_, _जगतक, --, --, 
   {{0x66dde721,0xa7fcae47,0x3ebc05ce,0xab6800ef}},	//   réka, ndıl, _ljut_, baļķ, 
   {{0xccf00375,0xaee40055,0xc0c8063f,0x66dc893a}},	//   תכם_, _cnṛp, ọọk_, séka, 
   {{0x3ebdc40f,0xe70812ea,0x66dde722,0x00000000}},	//   _njut_, _بتون_, lékn, --, 
   {{0x8ff8007b,0x569400fb,0x00000000,0x00000000}},	// [36f60] مرار_, _маҫт, --, --, 
   {{0x3ebde723,0xdce80c5e,0x00000000,0x00000000}},	//   _ajut_, _breč, --, --, 
   {{0x3ebc031c,0x823400e5,0x00000000,0x00000000}},	//   _bjut_, _کرپا, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2cac00d7,0x00000000,0x00000000,0x00000000}},	//   _pmdd_, --, --, --, 
   {{0x2054b191,0x2bb8134e,0x00000000,0x00000000}},	//   _отср, इपला, --, --, 
   {{0xd5c4025c,0xc0e05090,0xdce80064,0xbfc0033a}},	//   _གཙྀག, _чорк, _greč, _збрк, 
   {{0x3ebc007c,0x00000000,0x00000000,0x00000000}},	//   _gjut_, --, --, --, 
   {{0x3ea5e724,0xdce80219,0x00000000,0x00000000}},	//   ënte_, _zreč, --, --, 
   {{0x98ac01a6,0xc7c402e8,0x3ebc031c,0xcb080451}},	//   breč_, зсми, _zjut_, _هيئن_, 
   {{0x0a6800f3,0x00000000,0x00000000,0x00000000}},	//   _грли_, --, --, --, 
   {{0x37a448f0,0xfaa17118,0xba1400c6,0x7b940a1e}},	//   ятын_, _пахо, _فيما_, _מכבד_, 
   {{0xa7fc5656,0x00000000,0x00000000,0x00000000}},	//   ldım, --, --, --, 
   {{0x66dc0098,0xf48461ac,0xe2f800d4,0x00000000}},	//   cékn, нусн, жеві_, --, 
   {{0xf76d542f,0xc76401ec,0xa7fc123d,0x7aec0139}},	//   _ماي_, _ءاتى, ndım, _çitä, 
   {{0x326402bf,0xaacc085c,0x00000000,0x00000000}},	//   нтув, ाविक, --, --, 
   {{0xdce80fb7,0x66dde725,0xa7fd05c3,0xd5b000e5}},	// [36f70] _sreč, léko, ydıl, _لفٹ_, 
   {{0xdce9e726,0x3ebc002d,0x4294001f,0x26d80200}},	//   _preč, _sjut_, _መገኘት_, llso_, 
   {{0x4421e727,0x3ebc002d,0xaacc17c6,0x00000000}},	//   maj_, _pjut_, ावाक, --, 
   {{0x4421e728,0xdce8151c,0x95700023,0xa19400c0}},	//   laj_, _vreč, _እኩባን_, _жамч, 
   {{0x629de729,0x66dc003e,0xdd3800b8,0x9d448726}},	//   _ilso, yékn, _kāũy, фелд, 
   {{0x4421e72a,0xdce802d5,0x66dc012c,0x2004000d}},	//   naj_, _treč, kéko, _üli_, 
   {{0x66dc00dd,0xa7fd80c8,0x44200311,0xbea40166}},	//   jéko, rdıl, iaj_, _ешай, 
   {{0x4421e72b,0xe7d01d8a,0x66dc01ed,0x91780208}},	//   haj_, _हड़प, déko, _hấp_, 
   {{0x4421e72c,0x98ac09a8,0x3ea40066,0x66dc3e3b}},	//   kaj_, sreč_, èntu_, tékn, 
   {{0x4421e72d,0x7d18da30,0x9855e72e,0xed589cdf}},	//   jaj_, _iwus, фтиш, _عشقت_, 
   {{0x7c20e3c4,0x629de72f,0x7d180810,0x3f440037}},	//   manr, _olso, _hwus, nõu_, 
   {{0x7c21e730,0x7d1802e3,0x00000000,0x00000000}},	//   lanr, _kwus, --, --, 
   {{0x4421e731,0x80bc05d7,0xe8a80139,0x00000000}},	//   faj_, ्वाइ, _çuğı, --, 
   {{0x4421e732,0x629de733,0x7c21e734,0x66dc634d}},	//   gaj_, _also, nanr, lékl, 
   {{0x3f440037,0xe3b0009f,0x00000000,0x00000000}},	//   jõu_, هرِ_, --, --, 
   {{0x7c20001f,0x3a3de735,0x7d19e736,0x00000000}},	//   hanr, ngup_, _owus, --, 
   {{0x76441446,0x0560084c,0x63a8010f,0x54c4014b}},	// [36f80] _iciy, _авын, ĝena, _обиб, 
   {{0x629de737,0x92bc09bd,0x917801fb,0x3de0009e}},	//   _elso, ইতে_, _cấp_, যশাল, 
   {{0x7d19e738,0x7c21e739,0x00000000,0x00000000}},	//   _awus, danr, --, --, 
   {{0x38640076,0x110800ec,0x00000000,0x00000000}},	//   _lanr_, _وٺجي_, --, --, 
   {{0x7d18014b,0xcce400aa,0x7c206729,0x66dc01ed}},	//   _cwus, وستي, fanr, zéko, 
   {{0x26c00115,0x7ee003cc,0x7d18033f,0x91780208}},	//   _ĉiom_, ىكەن, _dwus, _gấp_, 
   {{0x7d1801f0,0x3e500882,0x3c486241,0x629c02d0}},	//   _ewus, ṛtam_, تثنی_, _ylso, 
   {{0x4421e73a,0xa7fc07c4,0x6f1c0142,0xf8bc0036}},	//   zaj_, rdım, _iwrc, één_, 
   {{0x4421e73b,0x7c20f9a6,0x316002fa,0x1f3402d3}},	//   yaj_, banr, nwiz_, _ብቐዳም, 
   {{0x6e2007dd,0x66dc066d,0x7645e73c,0x6b9c000d}},	//   _hemb, téko, _aciy, _ürgo, 
   {{0x4421e73d,0x6e21e73e,0x3864007f,0xa7fc1918}},	//   vaj_, _kemb, _danr_, ldık, 
   {{0x6e205447,0x4421e2fb,0x66dde73f,0x00000000}},	//   _jemb, waj_, réko, --, 
   {{0x4421e740,0xa7fc03ee,0xfaa421f4,0x66dc003e}},	//   taj_, ndık, _تجلی, séko, 
   {{0x6e21e741,0x66dc003e,0x00000000,0x00000000}},	//   _lemb, péko, --, --, 
   {{0x4421e742,0xb76000fd,0x66dc01d3,0x00000000}},	//   raj_, _атый, lékm, --, 
   {{0x68f8047e,0x386400f3,0x09e01431,0x3f84007c}},	//   _hivd, _zanr_, _पराठ, änum_, 
   {{0x4421e743,0x7c20074d,0x31600007,0xa074036b}},	// [36f90] paj_, yanr, gwiz_, нгач, 
   {{0x70743306,0x7d18004c,0x20d40150,0xefdc02d3}},	//   َالذ, _rwus, رقاس, ንጋዕ_, 
   {{0x6445e744,0x68f8047e,0x672803b2,0x7df00116}},	//   _ichi, _mivd, nsdj, چقاچ, 
   {{0x6e202ebc,0x316000ca,0x7c21e745,0x6f1c015d}},	//   _cemb, bwiz_, wanr, _dwrc, 
   {{0x6e21e746,0x7c20022c,0x61ac00bd,0x40f0035b}},	//   _demb, tanr, _কুরআ, _аҧар, 
   {{0x6e21e747,0x212803e0,0x8c40839a,0x8d600108}},	//   _eemb, msah_, геше, увше, 
   {{0x6445d015,0x7c200309,0x6e21e748,0xf8ac1272}},	//   _mchi, ranr, _femb, یکت_, 
   {{0xc1e04d53,0x7c21ad63,0x7d180810,0x2128011f}},	//   _खराब_, sanr, _twus, osah_, 
   {{0x6445e749,0x2129e74a,0x7d19e74b,0x7e79e74c}},	//   _ochi, nsah_, _uwus, _inup, 
   {{0x6445e74d,0x6e21e74e,0xa8741de1,0x21280548}},	//   _nchi, _zemb, вующ, isah_, 
   {{0x7e79e74f,0xe8000034,0x68f9e750,0x61fc03ac}},	//   _knup, ोड़ा_, _divd, _ogsl, 
   {{0x6445e751,0x38640165,0x61fc03b2,0x2129e752}},	//   _achi, _wanr_, _ngsl, ksah_, 
   {{0xaacc0118,0x00000000,0x00000000,0x00000000}},	//   ावरक, --, --, --, 
   {{0x1869e753,0x61fc035a,0x644400cd,0x2128c492}},	//   _хаки_, _agsl, _cchi, dsah_, 
   {{0x64441713,0xa7fc05d1,0x7e780862,0xd7040354}},	//   _dchi, zdık, _onup, _язйи, 
   {{0x6445e754,0x7e7801f2,0x76440223,0x212805b1}},	//   _echi, _nnup, _uciy, fsah_, 
   {{0x6e21e755,0x59d4033d,0x2fd80162,0x00000000}},	// [36fa0] _remb, _डुमर, _syrg_, --, 
   {{0x6e21e756,0x7e79e757,0x61fc035a,0x6f1c0042}},	//   _semb, _anup, _egsl, _pwrc, 
   {{0x6e21e758,0xe4c8007b,0x28a40037,0x4f64007b}},	//   _pemb, _تبين_, गोटि, عاطف, 
   {{0x1ea89486,0x6e21e759,0xe1f000aa,0x212805b1}},	//   واني_, _qemb, اسې_, bsah_, 
   {{0x6e21e75a,0x6fd01d15,0x21280548,0x6445e75b}},	//   _vemb, _तुरं, csah_, _ychi, 
   {{0x6e21e75c,0x7e78a898,0xa7fc0790,0x6f1c0143}},	//   _wemb, _enup, rdık, _twrc, 
   {{0x6e21e75d,0x8fa40798,0x70cc012d,0x00000000}},	//   _temb, _џабе, ़कील, --, 
   {{0x68f9361e,0xfce00032,0x0d2001c0,0x6b9c0254}},	//   _sivd, _ҡото, _бүдү, _ürgm, 
   {{0xbea1e75e,0x68f80455,0x00000000,0x00000000}},	//   _сатк, _pivd, --, --, 
   {{0x68f8047e,0xcb6800c0,0x00000000,0x00000000}},	//   _qivd, _назе_, --, --, 
   {{0x21280122,0x68f800df,0xaee400b8,0x8034008f}},	//   zsah_, _vivd, _goṣp, ענטע_, 
   {{0x499004fb,0x21280548,0x68f8047e,0xdb1401e1}},	//   _میبر, ysah_, _wivd, _àbáw, 
   {{0x644407d6,0x21280548,0x66dc01ed,0xba14007b}},	//   _pchi, xsah_, lékk, _أيها_, 
   {{0x83842309,0x644401a9,0x672801e3,0x3f840254}},	//   ныбе, _qchi, psdj, änuk_, 
   {{0x2128011f,0xa3d4442d,0x070809a5,0xb9e400cf}},	//   wsah_, товч, _эхли_, _قتۇۇ, 
   {{0x21280a2e,0x7a380793,0x64440165,0xb7d800df}},	//   tsah_, mätü, _wchi, _מקוי, 
   {{0x60f83c1b,0x6445e75f,0x660de760,0x7a380166}},	// [36fb0] дная_, _tchi, _ifak, lätü, 
   {{0x6445e761,0x2129e762,0x7e7812ed,0x94f80327}},	//   _uchi, rsah_, _snup, _ཐངགི_, 
   {{0x21280429,0x6d44026c,0xbfa800a7,0x21d80150}},	//   ssah_, àian, чтае_, _ﺃﺼﺩﺭ, 
   {{0x2129729c,0x660c025c,0x66dc01d3,0x61fc035a}},	//   psah_, _jfak, dékk, _ugsl, 
   {{0x21280548,0x660cd8b7,0xdc6801c0,0xf6180375}},	//   qsah_, _mfak, далд_, תחדש_, 
   {{0x91c00116,0x8d9000d1,0xfbac0154,0x7a380139}},	//   _тәсл, شلىش, _চুষত, kätü, 
   {{0x660c016c,0x4c90026a,0x2d8004e6,0xabd41d00}},	//   _ofak, ријс, äier_, _ﭘﺎﻧﺎ, 
   {{0x7e79e763,0x660c031c,0xa3e802e5,0x61340023}},	//   _unup, _nfak, _बरन_, _ክርድኣ, 
   {{0xfc302e2e,0xdce8054e,0xca800f15,0x00000000}},	//   _محض_, _creă, ргый, --, 
   {{0x660de764,0xd708c937,0x20d000c7,0x66dc00e5}},	//   _afak, мное_, _ỹijo_, lékh, 
   {{0x7a0c00b8,0xaab00419,0x00000000,0x00000000}},	//   _ṛtus, štáľ_, --, --, 
   {{0x9694368e,0xb90400fe,0x1a64114f,0x764800e5}},	//   трош, _মং_, _شیخی_, ریخِ_, 
   {{0xd9450324,0x0561e765,0x00000000,0x00000000}},	//   _рели, авян, --, --, 
   {{0x660de766,0xd13087ad,0x28f8084c,0x00000000}},	//   _efak, یمز_, _зечь_, --, 
   {{0x660c0270,0xb9ec044e,0xb9cc00b7,0x00000000}},	//   _ffak, _ሓራ_, _ስል_, --, 
   {{0x91e40354,0x02c00c69,0xd1740733,0x00000000}},	//   вобе, айсо, кызы, --, 
   {{0x412418ec,0x464400c7,0x66dc00e5,0x00000000}},	// [36fc0] кото_, _рзын_, dékh, --, 
   {{0x85000050,0x00000000,0x00000000,0x00000000}},	//   _خوٝن, --, --, --, 
   {{0x92e80fc0,0xcf442401,0x6e240174,0x00000000}},	//   _одоб_, тней, ðibo, --, 
   {{0x99dc007f,0xb2b4013d,0x9f500332,0x814000cf}},	//   nfňs, _сәгъ, ábán_, انەن, 
   {{0xb82402f5,0xfbac009e,0x00000000,0x00000000}},	//   _মানত_, _চুলত, --, --, 
   {{0x66dc01ed,0xbd84009f,0x00000000,0x00000000}},	//   tékk, ئنون_, --, --, 
   {{0x2d800262,0x00000000,0x00000000,0x00000000}},	//   ţie_, --, --, --, 
   {{0x8334010f,0x66dc4e79,0x00000000,0x00000000}},	//   דאקס_, rékk, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x81e400cc,0x00000000,0x00000000,0x00000000}},	//   _পলম_, --, --, --, 
   {{0x4a4400e4,0x69c402d5,0x660c0810,0xe69463eb}},	//   _анев, _žied, _pfak, гины, 
   {{0x3f8402b1,0xf1b42bf1,0x00000000,0x00000000}},	//   änui_, ूपान, --, --, 
   {{0x167002dd,0x5fd80037,0x00000000,0x00000000}},	//   сқыр, _बुनल, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x660c0135,0x62340108,0x0268004e,0x00000000}},	//   _tfak, леву, мшай_, --, 
   {{0x660c2747,0x6e241d0e,0x00000000,0x00000000}},	//   _ufak, ðibl, --, --, 
   {{0xf0e800d1,0x00000000,0x00000000,0x00000000}},	// [36fd0] ھىمى_, --, --, --, 
   {{0x80bc0d2c,0x301457c6,0xd1e400db,0x00000000}},	//   ्वें, идур, ايكۋ, --, 
   {{0xdfd1e767,0x44317f8e,0x3f64023b,0x66dc01d3}},	//   حيا_, _idx_, ътаб, tékh, 
   {{0x5398011a,0x00000000,0x00000000,0x00000000}},	//   _נירו, --, --, --, 
   {{0x443000d8,0x00000000,0x00000000,0x00000000}},	//   _kdx_, --, --, --, 
   {{0x9f05e768,0x6c5401c6,0x1be801d5,0x3e3000e5}},	//   _موسو, икчу, ндли_, _چہار, 
   {{0xfe240354,0xef640395,0x00000000,0x00000000}},	//   _аьзн, _къто, --, --, 
   {{0x3f7000f3,0x66dc003e,0x00000000,0x00000000}},	//   _iću_, béki, --, --, 
   {{0x6e9509f1,0x4bb000d1,0xceb00a7c,0xf98001d5}},	//   _титу, ийәс, _הין_, рҳло, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x5b141575,0x6fb800e1,0x80bc00eb,0x00000000}},	//   _смет, ्पयू, ্তপ্, --, 
   {{0x4431e769,0x90940023,0xba281f0d,0x00000000}},	//   _adx_, _ዘየድሊ_, _آسام_, --, 
   {{0x44300334,0xd70404a9,0x1994447e,0x00000000}},	//   _bdx_, _өзли, _щадя, --, 
   {{0x3f7004a7,0x00000000,0x00000000,0x00000000}},	//   _oću_, --, --, --, 
   {{0x03a1e76a,0x0fbc015b,0x17b000cc,0xf77035cf}},	//   биро, _অর্ধ, _ঘুৰি, _خاش_, 
   {{0xc240578a,0x00000000,0x00000000,0x00000000}},	//   йнск, --, --, --, 
   {{0x44300f85,0x91ec4142,0x30240107,0x9554007b}},	// [36fe0] _fdx_, चेंज_, изаҳ, _إخبا, 
   {{0x44300472,0x502400db,0x00000000,0x00000000}},	//   _gdx_, افاك, --, --, 
   {{0xb4c02413,0x0eb801ec,0xdb0c01e1,0x00000000}},	//   ंची_, нуды_, _òkèt, --, 
   {{0xcd281de1,0x0dc8010b,0xa2d40073,0x00000000}},	//   ежде_, нлей_, ढवण्, --, 
   {{0xf0842491,0x270c0118,0xbea01f5a,0x998c0327}},	//   _پیاپ, _měna_, љачк, ggeż_, 
   {{0x4430003a,0x82600014,0x7e040137,0x24a80092}},	//   _xdx_, _پگہٕ, _ۅسكۅ, _ሊከሰት_, 
   {{0x8fa480e4,0x4fa4030d,0x00000000,0x00000000}},	//   _саве, _сивв, --, --, 
   {{0xbea0cadc,0xfaa039fb,0x693405f5,0xddc802fb}},	//   _ласк, йшын, аниу, _oceň, 
   {{0x69c400c0,0x00000000,0x00000000,0x00000000}},	//   _žieb, --, --, --, 
   {{0x478400cf,0x77300092,0x00000000,0x00000000}},	//   гымб, _በተመደ, --, --, 
   {{0x443002fa,0x27f9557b,0x6e44001f,0x00000000}},	//   _rdx_, ärn_, _የምንች, --, 
   {{0x6b7c0020,0x46681188,0x2a600332,0x63a801e4}},	//   ተደረገ_, хром_, _úib_, ŝenk, 
   {{0x4430bb2d,0xb4c006e3,0x00000000,0x00000000}},	//   _pdx_, ंचू_, --, --, 
   {{0xa3e8000d,0x00000000,0x00000000,0x00000000}},	//   _बरद_, --, --, --, 
   {{0x80bc00cc,0x3898010f,0x3358084c,0x33840395}},	//   ্তম্, _איגנ, ларэ_, бутв, 
   {{0xfd540055,0x0fbc03d4,0x00000000,0x00000000}},	//   _ekaṣ, _অৰ্ধ, --, --, 
   {{0xddc9e76b,0x4431e76c,0xf65006f6,0x26c800c7}},	// [36ff0] _snež, _tdx_, _رئي_, _ijao_, 
   {{0x1ae0ccc0,0x4430003a,0xb9cc0092,0x00000000}},	//   _पठ्ठ, _udx_, _ስው_, --, 
   {{0x5ed401d5,0x00000000,0x00000000,0x00000000}},	//   ажжу, --, --, --, 
   {{0xdce80bb8,0x64540d27,0x2f3800c6,0x6b7c0356}},	//   _kreć, lfzi, اثلة_, _măgă, 
   {{0x80bc7f53,0x661c0036,0x628ca4d5,0x00000000}},	//   ্তব্, ibsk, mjao, --, 
   {{0xddc8031c,0x628de76d,0x11380375,0x64540112}},	//   _ineż, ljao, _בתשל, nfzi, 
   {{0x66dde76e,0xdb20418f,0x5f940025,0x00000000}},	//   léku, _ötür, _тивт, --, 
   {{0xdd946322,0xceb400d1,0xca740136,0x63a801e4}},	//   _кабы, _кәч_, لمىش_, ĝenh, 
   {{0x3c4446c9,0x628c0037,0xa3e8000d,0x00000000}},	//   _مضاف, ijao, _बरऽ_, --, 
   {{0x26c80241,0x661c0e78,0xddc80327,0x6b7c0356}},	//   _ajao_, ebsk, _mneż, _băgă, 
   {{0x2bb80a59,0x270c0118,0xcc78010f,0x00000000}},	//   ेपणा, _pěna_, _שװער, --, 
   {{0x59747734,0x66dc0022,0x997400f3,0x00000000}},	//   _выку, kéku, _вукш, --, 
   {{0xaee40055,0x89d40133,0x00000000,0x00000000}},	//   _haṃp, _پوور_, --, --, 
   {{0xb4c02413,0x6b7c0311,0xa848027d,0xaee400b8}},	//   ंचे_, _făgă, _ملهم_, _kaṃp, 
   {{0x661c1e10,0x6b7c0356,0x3d0801bf,0x9a60074d}},	//   bbsk, _găgă, _løw_, _хiун_, 
   {{0xc6e40014,0x00000000,0x00000000,0x00000000}},	//   _پتى۪, --, --, --, 
  
   {{0x7999e76f,0x1014282b,0xd184bf78,0xd024759d}},	// [37000] nyuw, لباد, шлай, имай, 
   {{0x7524014b,0x1308034b,0x7e94036b,0x71c401f0}},	//   _iwiz, _иной_, ینلر_, _ҳамҷ, 
   {{0xa7fc4952,0x3ddc002e,0x75240810,0x4e28afe2}},	//   ldır, _ayuw_, _hwiz, воен_, 
   {{0x7525e770,0xc7540375,0xcd2800f2,0xd17400db}},	//   _kwiz, ייעץ_, نستن_, _кыгы, 
   {{0xa7fc0c07,0xfd0ca9e7,0xc23400d9,0x00000000}},	//   ndır, وجو_, _דרכו_, --, 
   {{0x752531f3,0xd7a40490,0xd1bc069d,0x66dde771}},	//   _mwiz, खनाच, _ተርታ_, lékt, 
   {{0xf7640f66,0x8aa577d5,0xab780132,0x7524033b}},	//   _با_, ирид, امبا_, _lwiz, 
   {{0xaee400b8,0x66dc0098,0xa3e8443a,0xfaec0b24}},	//   _daṃp, nékt, _बरस_, وثي_, 
   {{0x4c848d20,0x752521a9,0xfce802d3,0x8c441768}},	//   _клав, _nwiz, _ህጹጽ_, _везе, 
   {{0x6f000098,0xb4c00dba,0xc61c1d3b,0xa7fc06be}},	//   _himc, ंचो_, पर्य_, ddır, 
   {{0xdce80bb8,0x6f01e772,0x752463d0,0x67d40432}},	//   _sreć, _kimc, _awiz, сону, 
   {{0x7524e19c,0xdce808ad,0x6f0001d9,0x66dc003e}},	//   _bwiz, _preć, _jimc, jékt, 
   {{0x2a64151c,0x799800ca,0x661de773,0x66dc01d3}},	//   memb_, cyuw, rbsk, dékt, 
   {{0xdce8098d,0x6f00b2f1,0xf7b47b02,0xb8d00244}},	//   _vreć, _limc, ادیش_, _وتوش, 
   {{0x66dc003e,0x6440004e,0x69dc002f,0xed340023}},	//   fékt, òliq, ßref, _ኣይቅኑ, 
   {{0xdce804b9,0x66dc2def,0x26c80451,0x6f0094f6}},	//   _treć, téku, _ujao_, _nimc, 
   {{0x7525e774,0x628de775,0x853074dd,0x00000000}},	// [37010] _gwiz, rjao, _بوخچ, --, 
   {{0x26d9e776,0x656cc1f5,0x6f000c8c,0x2a64009a}},	//   loso_, _isah, _aimc, hemb_, 
   {{0x9f541e76,0x66dc0098,0x6f000205,0x2a64036e}},	//   свеч, séku, _bimc, kemb_, 
   {{0x63ac00da,0xf1d83bec,0xa7fc0213,0xddc80327}},	//   ģinā, _भुवन, ndıq, _tneż, 
   {{0xaee40a28,0xee381ed2,0x26d8011c,0xad2403cc}},	//   _saṃp, рні_, ioso_, قىنى, 
   {{0x26d9e777,0x656c36df,0x3f143267,0x22480139}},	//   hoso_, _msah, _نظرآ, lgak_, 
   {{0x26d9e778,0xa7fc3e67,0x3e686518,0x66dc0098}},	//   koso_, zdır, _ишан_, néks, 
   {{0x26d9a58f,0xa7fc3279,0x6f01e779,0x79989728}},	//   joso_, ydır, _gimc, tyuw, 
   {{0x656c0327,0x66dc003e,0xd94400f5,0x00000000}},	//   _nsah, héks, щепи, --, 
   {{0x7525e77a,0x799803f9,0x6f01aeb5,0xd8a83090}},	//   _rwiz, ryuw, _zimc, اهدو_, 
   {{0x75244ba8,0x656de77b,0x26d802e8,0xd629e77c}},	//   _swiz, _asah, foso_, лоне_, 
   {{0xa7fc03be,0x26d9e77d,0xe9b801ed,0x75240100}},	//   tdır, goso_, انیں_, _pwiz, 
   {{0x15b800fb,0x9f54032e,0x998400f2,0x00000000}},	//   уыны_, _ófær_, _دلشو, --, 
   {{0xa7fc3361,0x66dc0c6a,0x69dc01f9,0xc974123b}},	//   rdır, féks, _पडती, _לגני_, 
   {{0x26d83d81,0xdee40020,0x656c4b26,0x03a0da85}},	//   boso_, ሜሽን_, _esah, пиро, 
   {{0x7525e77e,0x26d9e77f,0x2249e780,0x69dc002f}},	//   _twiz, coso_, ggak_, ßreg, 
   {{0x66dc737d,0x75248f96,0x0fc401e0,0xfe54002e}},	// [37020] rékt, _uwiz, әйен, nu鯵u_, 
   {{0x224801c4,0x66dc0098,0x6f000d63,0x00000000}},	//   agak_, sékt, _simc, --, 
   {{0x6f000455,0x66dc003e,0x447800df,0x00000000}},	//   _pimc, pékt, _ענטע, --, 
   {{0x52840597,0x0d8400ee,0x6f000455,0x63a008cb}},	//   _الحك, йлен, _qimc, ølne, 
   {{0x8d548439,0xc21004ae,0x2a6569e6,0xc6d800df}},	//   стеч, _מהר_, vemb_, אַגר, 
   {{0xd478008f,0x26d809c2,0x00000000,0x00000000}},	//   ראַל, zoso_, --, --, 
   {{0x26d9e781,0x6f000192,0x7f4035dd,0xa0d4004b}},	//   yoso_, _timc, _нерж, _بېلا_, 
   {{0x9e700075,0x26d80005,0x0eb80139,0x00000000}},	//   _يۇلت, xoso_, _сугы_, --, 
   {{0x26d80835,0x2a64003a,0xfe54002e,0x7e94007b}},	//   voso_, remb_, gu鯵u_, _انقر_, 
   {{0x26d9e782,0x2a6400d8,0x66dc0098,0x224801a9}},	//   woso_, semb_, yéks, zgak_, 
   {{0x26d9e783,0x656c0083,0xa7fc0213,0xe75800d4}},	//   toso_, _ssah, tdıq, шині_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x66dc003e,0x00000000,0x00000000,0x00000000}},	//   wéks, --, --, --, 
   {{0x26d9e784,0xf8bc01c7,0x66dc3980,0x6b9c000d}},	//   soso_, éét_, téks, _ürgs, 
   {{0x26d9e785,0x443c0baf,0x02a5e786,0xa7fc03b9}},	//   poso_, ğu_, брам, pdıq, 
   {{0x443c71d5,0x656de787,0x26d801e0,0x66dd8c4b}},	//   şu_, _tsah, qoso_, réks, 
   {{0x656c122d,0x22484eb0,0x41e4177b,0x66dc01c7}},	// [37030] _usah, rgak_, сіва, séks, 
   {{0xa30801d3,0xc0380023,0x00000000,0x00000000}},	//   _پردے_, _ኣምሲል, --, --, 
   {{0xde19e788,0xa2943334,0x22940395,0x00000000}},	//   لقات_, _дані, _диня, --, 
   {{0x91a80014,0xde580212,0x99e400a2,0x00000000}},	//   _چنَے_, раді_, laňň, --, 
   {{0x09d80327,0x69c40419,0xc0c800f3,0x00000000}},	//   _ཡཙྪ_, _žien, _буве_, --, 
   {{0x69dc00e1,0x00000000,0x00000000,0x00000000}},	//   _पड़ी, --, --, --, 
   {{0x71f80133,0x00000000,0x00000000,0x00000000}},	//   _پرێس_, --, --, --, 
   {{0xdce84ca5,0x7f40004e,0x00000000,0x00000000}},	//   _iseč, ànqu, --, --, 
   {{0xeea800db,0x00000000,0x00000000,0x00000000}},	//   _утрк_, --, --, --, 
   {{0xa3e80574,0xe8a80032,0xfe54002e,0x195800c7}},	//   _बरं_, йбыҙ_, ru鯵u_, гаҩы_, 
   {{0xe9a85929,0xd704054d,0x966400d8,0x4a9000f1}},	//   لدین_, юзни, окне, سټیز, 
   {{0xa9cc0150,0x19580006,0x00000000,0x00000000}},	//   _ﯗﻟﯩﺴ, _вады_, --, --, 
   {{0x261805f9,0xf8bc004a,0x66dc01d3,0x48e8000d}},	//   पड़ी_, éés_, tékr, _घीवो_, 
   {{0xdce8a5e2,0xe8940023,0x141800ae,0x52e000cd}},	//   _oseč, _ይፈልጡ_, شيرة_, पत्स, 
   {{0x371400e5,0xc8d8011a,0x00000000,0x00000000}},	//   _ارتھ_, _דקסט, --, --, 
   {{0x66dcae51,0x1ca80327,0xbb480023,0x00000000}},	//   sékr, _བཞའ_, _ዘይተዋ, --, 
   {{0x06340375,0x00000000,0x00000000,0x00000000}},	// [37040] _ונפט_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfe6c004b,0x8e09e789,0x00000000,0x00000000}},	//   ږدو_, анев_, --, --, 
   {{0x63a8008f,0xdc300171,0x00000000,0x00000000}},	//   ĝent, _eļļo, --, --, 
   {{0xac18f430,0x823404fb,0x00000000,0x00000000}},	//   болу_, _برپا, --, --, 
   {{0x63b80086,0x3cc4004e,0x00000000,0x00000000}},	//   _ñanü, олчо_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc865e78a,0x80bc03f4,0x3ea400d8,0xccc4187f}},	//   отни, ্তর্, ênte_, _дбай, 
   {{0x1ca8031c,0x6d6000bc,0x764001a8,0x415800df}},	//   _བཞར_, ěvač, ómyn, סדיג, 
   {{0xa7140006,0x00000000,0x00000000,0x00000000}},	//   ямні, --, --, --, 
   {{0x99880209,0xe8c80725,0xf8bc06af,0x00000000}},	//   _ýaş_, ргүл_, éér_, --, 
   {{0x660801a6,0xb604010b,0x05e801a9,0x00000000}},	//   žeko, дярк, рфни_, --, 
   {{0xf484022e,0x39580139,0x00000000,0x00000000}},	//   мусн, _äqsa_, --, --, 
   {{0x8728036b,0x00000000,0x00000000,0x00000000}},	//   _тўла_, --, --, --, 
   {{0xa5340902,0x9f440241,0x611401ec,0x00000000}},	//   _енич, _álé_, здау, --, 
   {{0x35b40801,0x67100210,0x00000000,0x00000000}},	// [37050] _обър, _ठंडक_, --, --, 
   {{0xf0e80075,0x00000000,0x00000000,0x00000000}},	//   قىقى_, --, --, --, 
   {{0x23788d1a,0x00000000,0x00000000,0x00000000}},	//   _امجد_, --, --, --, 
   {{0x9df80108,0x00000000,0x00000000,0x00000000}},	//   бнет_, --, --, --, 
   {{0x44200175,0xceb4013d,0x00000000,0x00000000}},	//   obj_, чәр_, --, --, 
   {{0x9f34005e,0x00000000,0x00000000,0x00000000}},	//   _негі, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfeb803e6,0xa3e8000d,0x00000000,0x00000000}},	//   _ئاست_, _बरई_, --, --, 
   {{0xfd1004f2,0x00000000,0x00000000,0x00000000}},	//   _آجر_, --, --, --, 
   {{0xddc81ebd,0x7d19e78b,0x00000000,0x00000000}},	//   _gaeš, _itus, --, --, 
   {{0x66dc00e5,0x00000000,0x00000000,0x00000000}},	//   tékp, --, --, --, 
   {{0x6440066a,0x69dc002f,0x00000000,0x00000000}},	//   ólin, ßrec, --, --, 
   {{0xb8b0005e,0x66dc00dd,0xf48401b9,0x00000000}},	//   _жөні, rékp, واسی, --, 
   {{0xf4bc02f5,0x7d18009f,0x28f80276,0x1ca80327}},	//   ৃত্ব, _mtus, _дечь_, _བཞས_, 
   {{0xb4bc2983,0x66dc0098,0x00000000,0x00000000}},	//   _आगी_, pékp, --, --, 
   {{0x7d18877b,0xc65c0023,0xd2f801c6,0x00000000}},	//   _otus, ዳበልካ_, сэгч_, --, 
   {{0x7d183b02,0x0161e78c,0x00000000,0x00000000}},	// [37060] _ntus, нкто, --, --, 
   {{0xdce800c8,0x63a80115,0x00000000,0x00000000}},	//   _preĝ, ĝenr, --, --, 
   {{0xb4e81b76,0x3e340240,0x00000000,0x00000000}},	//   बती_, _ከምዝከ, --, --, 
   {{0x69c402d5,0x92b4210e,0x0df40092,0x00000000}},	//   _žiem, _رحجا, _ጎርፍ_, --, 
   {{0xc2780375,0x1ea8009a,0x00000000,0x00000000}},	//   _הרכי, غامي_, --, --, 
   {{0x8eb401d3,0x00000000,0x00000000,0x00000000}},	//   _کمرش, --, --, --, 
   {{0x7d18049b,0xaa943de2,0x9aec00b8,0x00000000}},	//   _etus, дийч, _ṣaḍu, --, 
   {{0x7c200218,0x9ad8004b,0x7f3802e4,0x5ae40022}},	//   abnr, يديځ_, _לעלו, мсыҕ, 
   {{0xd90c2b3c,0x2f380100,0x44200334,0xb4bc0037}},	//   لین_, lčg_, ybj_, _आगू_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf98c2f0c,0x6d440024,0x38308e21,0x26180073}},	//   نبی_, šiad, энэр, पडली_, 
   {{0x1ca849a6,0x6f1c0589,0xf7a400d1,0x00000000}},	//   _བཞོ_, _mtrc, ﺴﻼﻣﺪ, --, 
   {{0x36880323,0x44200158,0x78b400c0,0x0984010a}},	//   чсэн_, tbj_, _žavū, _халǎ, 
   {{0x6f1c0e3c,0x78f400e5,0x92bc0011,0x00000000}},	//   _otrc, _فٹنس_, েতো_, --, 
   {{0x4421e78d,0x02a40006,0x66b40f06,0x00000000}},	//   rbj_, прам, _обку, --, 
   {{0x2cac0109,0x67380003,0x68e80042,0x00000000}},	//   _lldd_, _ivvj, lldd, --, 
   {{0xa074efaf,0x7c200175,0x80251fdc,0x94711211}},	// [37070] мгач, ybnr, كرام, رگیا, 
   {{0x7d180194,0x1ca8031c,0xca4802dd,0x9f7c0092}},	//   _rtus, _བཞེ_, _ﺁﻴﺔ_, _የሚውሉ_, 
   {{0x7d19e78e,0xa3d40395,0x00000000,0x00000000}},	//   _stus, _цонч, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xcbfc015b,0x527800d9,0x660800e4,0x00000000}},	//   ুরোধ_, _ונרא, ñeky, --, 
   {{0x2cac01fa,0x67380003,0x00000000,0x00000000}},	//   _cldd_, _ovvj, --, --, 
   {{0xdce80790,0x7a4001e1,0x00000000,0x00000000}},	//   _ereğ, _nìtà, --, --, 
   {{0x7d180421,0xeea801b9,0x68e802d0,0x00000000}},	//   _ttus, _етук_, eldd, --, 
   {{0x3ebde78f,0x7d19e790,0x67380327,0x6e240077}},	//   _imut_, _utus, _avvj, ñibe, 
   {{0xb4bc4425,0xa3ad4eb8,0x7e680036,0x9f440248}},	//   _आगे_, कना_, legp, _àló_, 
   {{0xab8400f3,0x00000000,0x00000000,0x00000000}},	//   _пуцк, --, --, --, 
   {{0x3ebc025c,0x00000000,0x00000000,0x00000000}},	//   _jmut_, --, --, --, 
   {{0x7af98cdd,0xe6340323,0x3ebd2291,0x00000000}},	//   mmut, эхээ, _mmut_, --, 
   {{0x7af9e791,0xb4e805c0,0xe72800f1,0x97c400c0}},	//   lmut, बते_, _کسوو_, _ойле, 
   {{0x5fd82ba2,0x7af804ba,0x00000000,0x00000000}},	//   _बँगल, omut, --, --, 
   {{0x7af804d4,0x00000000,0x00000000,0x00000000}},	//   nmut, --, --, --, 
   {{0x6f1de792,0x7af80099,0x00000000,0x00000000}},	// [37080] _strc, imut, --, --, 
   {{0x3ebc00e8,0x8fa5de9a,0x7af9e793,0x8888010f}},	//   _amut_, мазе, hmut, ֿרײַ, 
   {{0x3ebc070d,0xf2e81046,0xdee40023,0x00000000}},	//   _bmut_, _فکره_, ምሮኡ_, --, 
   {{0x1ca80135,0x7af80118,0xbea0013d,0x00000000}},	//   _བཞུ_, jmut, кахк, --, 
   {{0xb1842347,0x68e805ac,0xac1800f3,0xfbc007af}},	//   _яңад, yldd, полу_, _वेबम, 
   {{0x3ebc5d69,0x7af8022f,0x5fd80254,0xb4bc012c}},	//   _emut_, emut, _बुकल, _आगो_, 
   {{0x6f1c1e31,0x55f800cc,0x00000000,0x00000000}},	//   _utrc, _আভোক_, --, --, 
   {{0x7af801ed,0x2b41e794,0xd05c013f,0x68e80009}},	//   gmut, čic_, ampɔ, wldd, 
   {{0x2ee401fa,0x68e80083,0xc198008f,0x9f440241}},	//   _ikmf_, tldd, ַשטי, _àlò_, 
   {{0x5fd40f44,0x7af80337,0x7a400241,0xcb680395}},	//   _दशमल, amut, _pìtà, _мазе_, 
   {{0xa7fcca2c,0x4788003b,0x00000000,0x00000000}},	//   ldız, ісом_, --, --, 
   {{0x092000eb,0xe694009d,0x00000000,0x00000000}},	//   _মিঠু_, химы, --, --, 
   {{0xd424015b,0xf98c1291,0x00000000,0x00000000}},	//   _বাড়ি_, _نبو_, --, --, 
   {{0x67d42dc1,0xf76d5aa1,0xf9c4bab9,0xa2c01157}},	//   _полу, _چاي_, _تحمی, रोन्, 
   {{0x9f540162,0x3af000e4,0x00000000,0x00000000}},	//   _ófør_, sãpe_, --, --, 
   {{0xb80402dd,0x4adc215d,0x3af000e4,0x00000000}},	//   _تيىم_, मविव, pãpe_, --, 
   {{0x3ebc0194,0x660de795,0x354401c0,0x7e680158}},	// [37090] _rmut_, _igak, _ихэв, vegp, 
   {{0xdea0035c,0x3ebc2380,0x7af804a7,0xdfd001f7}},	//   گیری, _smut_, zmut, هيء_, 
   {{0x660c5bae,0x2b5801c7,0x623400f3,0x00000000}},	//   _kgak, _ärch_, _пену, --, 
   {{0xdea06071,0x21380023,0xa194747c,0x9df80108}},	//   دیری, _tvsh_, _замч, пнет_, 
   {{0x660c356c,0xdce81591,0x62040014,0x7e6800d8}},	//   _mgak, _sređ, _سوسٕ, regp, 
   {{0xdce81591,0x629de796,0x7e6803cd,0xec68010b}},	//   _pređ, _hoso, segp, җрәк_, 
   {{0x629de797,0x660de798,0x60c4003e,0xdd9001d3}},	//   _koso, _ogak, mihm, ضوں_, 
   {{0xdce80640,0x629de799,0x3ebc03ee,0x9f0400c6}},	//   _vređ, _joso, _umut_, _أورو, 
   {{0x7af912c5,0x270c013a,0x00000000,0x00000000}},	//   rmut, _měnu_, --, --, 
   {{0x660c37c1,0x98540853,0xfbc40131,0xad241c62}},	//   _agak, хтиш, _оғли_, _شىمى, 
   {{0xdce804b9,0xdecc1772,0x629de79a,0x57e816ab}},	//   _uređ, _እሙን_, _ooso, ядом_, 
   {{0xa7fc71d5,0x19b94209,0x60c4014f,0xa2c03166}},	//   ndıy, _нуль_, hihm, रोम्, 
   {{0x1c180456,0x69340117,0x692400d4,0x00000000}},	//   नुअल_, _анчу, _аміа, --, 
   {{0x629c0b23,0x660c01c4,0xc95000d9,0x00000000}},	//   _aoso, _egak, _עמו_, --, 
   {{0x629c636f,0x764400c7,0x00000000,0x00000000}},	//   _boso, _иҭна, --, --, 
   {{0x629de79b,0xb81803ce,0x092000eb,0x00000000}},	//   _coso, पुरम_, _মিতু_, --, 
   {{0x3f800327,0x00000000,0x00000000,0x00000000}},	// [370a0] _arju_, --, --, --, 
   {{0x200c0213,0x2ee406be,0xa2c00f4a,0xa5e801ee}},	//   _şeir_, _skmf_, रोब्, _юлыҡ_, 
   {{0x629de79c,0xef3c02d3,0x00000000,0x00000000}},	//   _foso, _ኣልዒል, --, --, 
   {{0x629de79d,0x71c400c7,0x4ebc0011,0x60c401f4}},	//   _goso, _аамҷ, ইক্ল, aihm, 
   {{0x6c540120,0x2d584130,0x00000000,0x00000000}},	//   вклу, филь_, --, --, 
   {{0x629de79e,0x00000000,0x00000000,0x00000000}},	//   _zoso, --, --, --, 
   {{0x6cc000c6,0x629de79f,0x00000000,0x00000000}},	//   _ẁōгľ, _yoso, --, --, 
   {{0x629c0051,0x00000000,0x00000000,0x00000000}},	//   _xoso, --, --, --, 
   {{0x0d85e7a0,0xb8240c58,0x30c4009e,0x660c01a9}},	//   _ялан, _মাজত_, ্তীস, _rgak, 
   {{0x1ca86d7e,0x2d85e7a1,0x8154010f,0x00000000}},	//   _བཞག_, _irme_, עסיע_, --, 
   {{0xc5f850dc,0x67d5e7a2,0xc7642160,0xbb40074d}},	//   ृश्य_, тону, رادى, _бехк, 
   {{0xda6400ec,0x2d8425b4,0x00000000,0x00000000}},	//   _لاهي, _krme_, --, --, 
   {{0x38c81af6,0x00000000,0x00000000,0x00000000}},	//   _کانی_, --, --, --, 
   {{0xc25404d3,0x5fd800c5,0xa7fc0205,0x00000000}},	//   کخست, _बुझल, zdıy, --, 
   {{0x629de7a3,0x60c5e7a4,0xa7fc0790,0x276817a5}},	//   _poso, vihm, ydıy, _آشتی_, 
   {{0x629de7a5,0x660c01b2,0x2d85e7a6,0x0b500023}},	//   _qoso, _ugak, _orme_, _ዘይተማ, 
   {{0x629c03b4,0x65940021,0x00000000,0x00000000}},	// [370b0] _voso, _рапу, --, --, 
   {{0x629de7a7,0xdd9003c7,0x4424010e,0x00000000}},	//   _woso, یوا_, _ýn_, --, 
   {{0x629de7a8,0xdfd00597,0x443001f5,0x60c5e7a9}},	//   _toso, جيا_, _iex_, rihm, 
   {{0x44300f85,0x00000000,0x00000000,0x00000000}},	//   _hex_, --, --, --, 
   {{0x44300267,0x60c4014f,0xdee40023,0xa7fc236c}},	//   _kex_, pihm, ምሮኻ_, rdıy, 
   {{0xac84005e,0x60c4014f,0x00000000,0x00000000}},	//   лгіл, qihm, --, --, 
   {{0xdea05022,0x9e140006,0x00000000,0x00000000}},	//   _پیشی, _адбі, --, --, 
   {{0x4431e7aa,0x00000000,0x00000000,0x00000000}},	//   _lex_, --, --, --, 
   {{0x5c7409a5,0x2d840427,0x5d541f39,0x7f780220}},	//   _илат, _grme_, _шкат, _ﺃﻤل_, 
   {{0x7e79e7ab,0xa2c01cba,0x6c74764c,0x6f880050}},	//   _haup, रोत्, _مطمئ, _تنہِ_, 
   {{0x7e79e7ac,0xca74141b,0x9b9403c7,0x00000000}},	//   _kaup, رمیش_, _جلات, --, 
   {{0x44300d27,0x9984007b,0x7e79e7ad,0x00000000}},	//   _aex_, _للصو, _jaup, --, 
   {{0x7e79e7ae,0x67241225,0xd251e7af,0xdb1001a8}},	//   _maup, _čije, ینس_, ðfær, 
   {{0x7e79e7b0,0x6ef80077,0x00000000,0x00000000}},	//   _laup, míbe, --, --, 
   {{0x4431e7b1,0x6ef80316,0x9984004b,0xdee40092}},	//   _dex_, líbe, _سلګو, ዜሽን_, 
   {{0xc240df65,0x958539f8,0x44300067,0xc7d4011a}},	//   инск, _алие, _eex_, _שוקי_, 
   {{0x4431e7b2,0x6ef80077,0x26d80407,0x00000000}},	// [370c0] _fex_, níbe, éroe_, --, 
   {{0x7e780618,0x44300129,0x84e0030d,0x947400f2}},	//   _aaup, _gex_, _воьж, _شدخا, 
   {{0xb4c0069f,0xe0d400d6,0x96c40316,0x6ef809c2}},	//   ूची_, ують, _लगाउ, híbe, 
   {{0x7e79e7b3,0x0dc8005b,0xa2c000cd,0x00000000}},	//   _caup, млей_, रोद्, --, 
   {{0x7e79e7b4,0xbea0147e,0x0d3c0023,0x00000000}},	//   _daup, јачк, _ኣይፋል, --, 
   {{0x4431e7b5,0x0d3c044e,0x13c40154,0x69b0012d}},	//   _xex_, _ኣይፈል, _শুয়, आईसी, 
   {{0x7e784894,0x09c80882,0xbb4000d8,0x00000000}},	//   _faup, ाप्य, аејк, --, 
   {{0x7e79e7b6,0x3e8401b9,0xc330011a,0x00000000}},	//   _gaup, _ийсо_, בוה_, --, 
   {{0xbea073b8,0xcd046f78,0x2d840276,0x00000000}},	//   _татк, _апай, _urme_, --, 
   {{0x7e78b847,0x3af000c7,0x8b240395,0xddd800a2}},	//   _zaup, rãpa_, _адже, lewş, 
   {{0x4431e7b7,0x7e7808cd,0x00000000,0x00000000}},	//   _rex_, _yaup, --, --, 
   {{0x44319aeb,0xc6a4ab37,0x601801e1,0xf801e7b8}},	//   _sex_, трои, _kúmó, шчын, 
   {{0x6ef809c2,0xc76405a9,0x76b800f5,0x00000000}},	//   cíbe, راگى, тляр_, --, 
   {{0x26d80098,0xf76c0330,0x25ac0003,0x00000000}},	//   érob_, حای_, ġel_, --, 
   {{0x25acaaca,0x44316553,0x3494020a,0xf7f00050}},	//   šel_, _vex_, шарр, _پٲٹھ, 
   {{0x44300de2,0x00000000,0x00000000,0x00000000}},	//   _wex_, --, --, --, 
   {{0x7e79e7b9,0x60f8652e,0x44302238,0x24180108}},	// [370d0] _raup, еная_, _tex_, _попы_, 
   {{0x7e79e7ba,0xdce8248d,0x00000000,0x00000000}},	//   _saup, _iseć, --, --, 
   {{0x7e79e7bb,0xdca401d5,0x00000000,0x00000000}},	//   _paup, ғайи, --, --, 
   {{0xa2941fe2,0x00000000,0x00000000,0x00000000}},	//   _самі, --, --, --, 
   {{0x3cdc10f7,0x7e780589,0x6d442e84,0x6ef80005}},	//   गवले_, _vaup, šian, xíbe, 
   {{0x6455e7bc,0x7e78009f,0x00000000,0x00000000}},	//   ngzi, _waup, --, --, 
   {{0x7e799fb7,0x00000000,0x00000000,0x00000000}},	//   _taup, --, --, --, 
   {{0xdce8e108,0x6ef80005,0xc0c001e0,0x00000000}},	//   _oseć, tíbe, _сәғи, --, 
   {{0x9d100154,0x00000000,0x00000000,0x00000000}},	//   _সৌরভ_, --, --, --, 
   {{0x6ef809ff,0x00000000,0x00000000,0x00000000}},	//   ríbe, --, --, --, 
   {{0x6ef8172e,0xec240131,0x09e00131,0x97c40006}},	//   síbe, _ئىمپ, _қошн, уйне, 
   {{0x6b9c0268,0xcb100375,0x98a40139,0x00000000}},	//   _àrga, _הלא_, _әике, --, 
   {{0xd945e7bd,0x4a98008d,0x00000000,0x00000000}},	//   _сели, _רינג, --, --, 
   {{0xd394b392,0x395de7be,0xb4c03af7,0x00000000}},	//   гәмә_, mtus_, ूचे_, --, 
   {{0x395de7bf,0xb9cc0020,0x4340274b,0xc8d8011a}},	//   ltus_, _ድል_, йерв, _אקסט, 
   {{0x661c0589,0x395c8938,0xe6b400db,0x00000000}},	//   ccsk, otus_, _ۅلۉگ, --, 
   {{0x395c2b55,0xd184069a,0x76440cad,0x90880150}},	// [370e0] ntus_, ылай, _idiy, нбаб_, 
   {{0x395d7321,0xaee40882,0x7525e7c0,0x00c4004e}},	//   itus_, bhṛt, _itiz, глук_, 
   {{0x395c00af,0x53a4010b,0xcf440fdc,0x0c84054a}},	//   htus_, _санб, уней, ғылм, 
   {{0x395cff64,0x75240175,0xd17400ee,0x52740022}},	//   ktus_, _ktiz, _йыгы, _суоу, 
   {{0x395de7c1,0x2cc401d5,0x00000000,0x00000000}},	//   jtus_, аrdа_, --, --, 
   {{0x752401c8,0xfce1e7c2,0x764401a9,0xbd84951b}},	//   _mtiz, бочо, _ldiy, انون_, 
   {{0x0ba8030c,0x7644b8c0,0x395de7c3,0x4c680139}},	//   عاتى_, _odiy, etus_, _җиен_, 
   {{0x7644ef1d,0x395c1979,0x7525e7c4,0x63a00174}},	//   _ndiy, ftus_, _otiz, ølni, 
   {{0x7524015c,0x3161e7c5,0x395de7c6,0xc98401f7}},	//   _ntiz, ntiz_, gtus_, اشبي, 
   {{0x7644013b,0xad4400cf,0x4158010f,0xc170011a}},	//   _adiy, _مۉچۉ, עדיג, צחת_, 
   {{0x7525e7c7,0x395de7c8,0x386402d2,0x00000000}},	//   _atiz, atus_, _dbnr_, --, 
   {{0x395d96c0,0xdce8041a,0xe7380184,0x00000000}},	//   btus_, _pseć, неү_, --, 
   {{0x395cc51b,0x6454010a,0x7644015d,0xb8d0315b}},	//   ctus_, tgzi, _ddiy, شتیش, 
   {{0x76440ab7,0xc6a40058,0x386405ac,0x00000000}},	//   _ediy, _әрки, _gbnr_, --, 
   {{0x6d4000b5,0x828802a9,0x7524007c,0xddc80118}},	//   _lvma, нсаб_, _etiz, _dceř, 
   {{0x6e2436ed,0x75258df9,0x193c037e,0x6d41432e}},	//   ñibl, _ftiz, _ｐｗｃ_, _ovma, 
   {{0xf1945d99,0x40842d29,0xa2c000dc,0xa4d400c0}},	// [370f0] бить, лужб, रोष्, _вопі, 
   {{0x656de7c9,0x35b404b3,0x3dc40220,0xb0340117}},	//   _ipah, _ыбыр, _ﯨﺮﯨﻘ, йнуш, 
   {{0x3f843b6e,0x6d40022c,0x6445e7ca,0xf47c02d3}},	//   ínu_, _avma, _idhi, _ብምሃብ_, 
   {{0x656c025a,0x395c0006,0x7524030a,0x539805d0}},	//   _kpah, ytus_, _ytiz, _סירו, 
   {{0x395de7cb,0x1ca8003d,0x6b89e7cc,0x6d4000c0}},	//   xtus_, _བཞད_, _ardg, _cvma, 
   {{0x656de7cd,0x71440372,0xa2c000cd,0x00000000}},	//   _mpah, _دۉكۅ, रोर्, --, 
   {{0x644401c8,0x6d41e7ce,0x00000000,0x00000000}},	//   _mdhi, _evma, --, --, 
   {{0x395de7cf,0x656c00c7,0x00000000,0x00000000}},	//   ttus_, _opah, --, --, 
   {{0x81e403f4,0x395de7d0,0x6b8803fa,0x21280784}},	//   যের_, utus_, _erdg, npah_, 
   {{0x395de7d1,0x64440214,0x6ef80789,0xac9456d6}},	//   rtus_, _ndhi, míba, _лауш, 
   {{0x7525e7d2,0x316001c0,0xd6294ec8,0x656c00cd}},	//   _stiz, ztiz_, коне_, _apah, 
   {{0x6445e7d3,0x395de7d4,0x75240295,0x95843947}},	//   _adhi, ptus_, _ptiz, алме, 
   {{0x6ef91ac5,0xe9a8861f,0x64440055,0xadc40022}},	//   níba, _مدون_, _bdhi, _osẽp, 
   {{0xed68001f,0xb4e01408,0x00000000,0x00000000}},	//   _ሳይቀር_, तवे_, --, --, 
   {{0x656de7d5,0x1ca8031c,0x6445e7d6,0x03a0014b}},	//   _epah, _བཞན_, _ddhi, оиро, 
   {{0x644400f2,0x764403f9,0x316007c5,0x78a0501d}},	//   _edhi, _udiy, ttiz_, _honv, 
   {{0x7525e7d7,0x86780375,0x90c57fe7,0x067800df}},	// [37100] _utiz, _ירקו, абае, _ינקל, 
   {{0x3161e7d8,0x78a05144,0x3d0c0034,0x6440032e}},	//   rtiz_, _jonv, ादों_, ólit, 
   {{0x31614f8e,0xa3cc0d2c,0xde400240,0xa464009f}},	//   stiz_, _शेप_, _ከምዝለ, _اُپٻ, 
   {{0x0dc81a4f,0x6d440006,0x78a1e7d9,0xdde801b9}},	//   кули_, šiam, _lonv, گرمه_, 
   {{0x6440022c,0x6444003e,0xa2c00073,0xe3b8014b}},	//   ðlig, _ydhi, रोळ्, _абӯ_, 
   {{0x1d1802d5,0x311c00dc,0x00000000,0x00000000}},	//   уюць_, _भूयः_, --, --, 
   {{0x7f40084c,0x8fa41b50,0x00000000,0x00000000}},	//   _мерж, _таве, --, --, 
   {{0xc3300375,0x6d41e7da,0xa3cc07af,0x7a0c002b}},	//   קוח_, _tvma, _शेफ_, _ṛtas, 
   {{0x78a000c8,0xa3cc298e,0x59ac095f,0x237c0023}},	//   _bonv, _शेन_, टनगर, _ብውድብ_, 
   {{0xc5cc00eb,0x00000000,0x00000000,0x00000000}},	//   রথমপ, --, --, --, 
   {{0x27f80ac8,0x78a1e7db,0x656de7dc,0x091c00fe}},	//   årn_, _donv, _spah, _দিওঁ_, 
   {{0x49a40032,0x09e41e35,0x49c8213a,0xbf98010f}},	//   _ҡыҙғ, _коен, _илен_, דיטש, 
   {{0xfd780075,0x78a002e2,0x497408f0,0x00000000}},	//   ﻠﻐﺎﻥ_, _fonv, _خداآ, --, 
   {{0x78a00165,0xc64400cf,0x00000000,0x00000000}},	//   _gonv, دئگى, --, --, 
   {{0xdce8038f,0x68e9e7dd,0xf7f001ec,0x00000000}},	//   _speċ, modd, _وسىد, --, 
   {{0x68e9e7de,0x78a001a4,0x00000000,0x00000000}},	//   lodd, _zonv, --, --, 
   {{0x26c81326,0x656de7df,0x21280c6a,0x846402e8}},	// [37110] _imao_, _upah, upah_, _къне, 
   {{0xde40069c,0x6444648b,0x68e800a9,0xceb40032}},	//   _ከምዘለ, _udhi, nodd, ҡәт_, 
   {{0x2128030a,0x00000000,0x00000000,0x00000000}},	//   spah_, --, --, --, 
   {{0x22944116,0x68e9e7e0,0x21280548,0x00000000}},	//   _الحس, hodd, ppah_, --, 
   {{0x26c801ee,0x68e9e7e1,0xfc54001f,0x260c01e4}},	//   _mmao_, kodd, _የሽግግ, nɾo_, 
   {{0x3134593c,0x6ef9e7e2,0xdd940046,0x3e44004d}},	//   _ферр, ríba, _қазы, ốt_, 
   {{0x68e9e7e3,0xfe700271,0x7d2400f1,0xaf1c0064}},	//   dodd, _ودر_, _چيرې_, _апсi, 
   {{0xaae4004b,0x78a00af9,0x24800112,0x1a64ace5}},	//   يسيو, _sonv, _lahm_, صیتی_, 
   {{0x78a00219,0x68e839ea,0xaac4178c,0x00000000}},	//   _ponv, fodd, تتون, --, 
   {{0x26c97743,0xdcf8fc68,0x248003fa,0x26d8a8d8}},	//   _amao_, _صفات_, _nahm_, éron_, 
   {{0xd70800c9,0x78a1e7e4,0xa7fc0205,0x00000000}},	//   лное_, _vonv, sfın, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x68e9e7e5,0x1869e7e6,0x78a1e7e7,0x00000000}},	//   bodd, _бали_, _tonv, --, 
   {{0xdce819d6,0x68e80268,0xf8a8033f,0x00000000}},	//   _opeč, codd, _छविय, --, 
   {{0x248002fa,0xdee4010c,0x09a80327,0x00000000}},	//   _dahm_, ምሮን_, _པཎྜ_, --, 
   {{0xd17410de,0x7cfdcaa9,0x147400cf,0x00000000}},	//   йызы, lêrd, جاڭج, --, 
   {{0x248001a9,0x7999e7e8,0x10140553,0x36b800f1}},	// [37120] _fahm_, nxuw, مباد, _مخکښ_, 
   {{0x6d4413aa,0xd008008e,0x4f9401ec,0x1bec0037}},	//   šiak, гезе_, йреу, _चुभल_, 
   {{0xa524031c,0xde540092,0xf1540133,0xc4800139}},	//   _འཕོག_, _የምዝገ, _ژێرد, _элэк, 
   {{0xddc8025c,0x25bc0790,0x2480002f,0x8e3800d1}},	//   _faeż, _özlü_, _zahm_, اسار_, 
   {{0x68e917b1,0xacc821b5,0x00000000,0x00000000}},	//   yodd, аҳаз_, --, --, 
   {{0x3d28675b,0x7d2801d3,0x09b400cc,0x00000000}},	//   اتنی_, ازنہ_, _জখলা, --, 
   {{0x672408ad,0x79886548,0xcc3400db,0x00000000}},	//   _čijo, _argw, _ۇراع, --, 
   {{0xfbcc16ac,0x68e9e7e9,0x00000000,0x00000000}},	//   عتو_, wodd, --, --, 
   {{0x68e98701,0x8c440209,0xdce801ef,0x00000000}},	//   todd, _гезе, _zpeč, --, 
   {{0x98ac0030,0x26c9e7ea,0x00000000,0x00000000}},	//   ateľ_, _smao_, --, --, 
   {{0x68e9e7eb,0x24812936,0x0a6801af,0x00000000}},	//   rodd, _rahm_, _брли_, --, 
   {{0xfaa1e7ec,0x68e800a9,0x2480067c,0xf400015b}},	//   _нахо, sodd, _sahm_, ্ডার_, 
   {{0x68e9e7ed,0x00000000,0x00000000,0x00000000}},	//   podd, --, --, --, 
   {{0x68e9e7ee,0x69c000d7,0x00000000,0x00000000}},	//   qodd, mzme, --, --, 
   {{0x8724a4ca,0x2480022e,0x424401ec,0x69c000d7}},	//   _اعتم, _vahm_, йхаб, lzme, 
   {{0x272401f2,0x26c800b5,0xbb38008f,0xe7051cc7}},	//   _ịnwa_, _umao_, טעלי, _بستی, 
   {{0x69c1e4b2,0xa158063b,0x26d80161,0xdce9e7ef}},	// [37130] nzme, разу_, mnso_, _speč, 
   {{0x6edc007f,0x00000000,0x00000000,0x00000000}},	//   včba, --, --, --, 
   {{0x836400c6,0x69c00175,0xa7fc0205,0x00000000}},	//   _ادخل, hzme, kfım, --, 
   {{0xa158f0c2,0xb61001e1,0xbec00171,0x00000000}},	//   _каму_, _àṣet, _šūbe, --, 
   {{0xee381ed2,0x7cb40364,0xdca407d6,0xad240075}},	//   сні_, бқат_, жали, كىنى, 
   {{0x61fc00da,0x69c03341,0x80240ee8,0x1d0801e5}},	//   _izsl, dzme, _درحم, шели_, 
   {{0x01d80154,0x00000000,0x00000000,0x00000000}},	//   _দরিদ, --, --, --, 
   {{0x26d89d74,0x7cfc002d,0x00000000,0x00000000}},	//   érol_, dêre, --, --, 
   {{0x8bd40166,0x00000000,0x00000000,0x00000000}},	//   ймәс_, --, --, --, 
   {{0x25ec2871,0x98ac0030,0x00000000,0x00000000}},	//   _घड़ी_, steľ_, --, --, 
   {{0x7d19e7f0,0x7f54045a,0x00000000,0x00000000}},	//   _huus, nuxq, --, --, 
   {{0x7d19e7f1,0x9cc80184,0x6aa002d0,0x00000000}},	//   _kuus, _сыға_, cjmf, --, 
   {{0x7d181059,0x6e241709,0x91e4037e,0xdee4010c}},	//   _juus, ñibi, _auのi, ምሮና_, 
   {{0x7d19e7f2,0x7cfc145e,0x3a3ca303,0x69dc03ee}},	//   _muus, bêre, laup_, ğret, 
   {{0x7d19e7f3,0xc22401f2,0x61fc0139,0xd2a80640}},	//   _luus, _ụkọc, _azsl, акве_, 
   {{0x3a3de7f4,0x38b8045f,0x00000000,0x00000000}},	//   naup_, _dêre_, --, --, 
   {{0x7d19e7f5,0x453000cf,0x00000000,0x00000000}},	// [37140] _nuus, _قىير, --, --, 
   {{0x38b8000f,0x3a3c107d,0x6ef8067c,0x54680aac}},	//   _fêre_, haup_, tíbo, _таом_, 
   {{0x7d181140,0x3a3d4de9,0x6ef80162,0x99dc0432}},	//   _auus, kaup_, bíbl, laňd, 
   {{0x7d19e7f6,0xb63c037e,0x6ef89223,0x60c8010e}},	//   _buus, _ｆｔ_, ríbo, _įeme, 
   {{0xcd0408b7,0x7d180009,0xcce47286,0x99dc00a2}},	//   очки, _cuus, يستي, naňd, 
   {{0x7d19e7f7,0x69c00427,0x00000000,0x00000000}},	//   _duus, vzme, --, --, 
   {{0xa2c04719,0x26d80009,0x00000000,0x00000000}},	//   रोक्, ynso_, --, --, 
   {{0x3a3c0d04,0x7d19e7f8,0x69c1e7f9,0x01d803d4}},	//   gaup_, _fuus, tzme, _দৰিদ, 
   {{0x7d19e7fa,0x6f1de7fb,0x69c008a4,0x7cfc05e4}},	//   _guus, _hurc, uzme, wêre, 
   {{0x48a80432,0x6f1de7fc,0x7cfc002d,0x69c00112}},	//   ртим_, _kurc, têre, rzme, 
   {{0x69c001d3,0x7d480023,0x00000000,0x00000000}},	//   szme, _ብተናጸ, --, --, 
   {{0x7d199f14,0xfb1002dd,0x986800d7,0x787c0064}},	//   _yuus, _قولج, _gúľ_, ešvė, 
   {{0x2ab8020c,0x7d186ed5,0xf98001c6,0x00000000}},	//   _géba_, _xuus, _огцо, --, 
   {{0x6f1c0c8c,0xdb0c0ca8,0x00000000,0x00000000}},	//   _ourc, _òkòt, --, --, 
   {{0x6f1de7fd,0x02a455ee,0xddc800a2,0xe1f80064}},	//   _nurc, орам, _edeň, _šų_, 
   {{0x2ab802ea,0x8234b805,0x3f84066a,0x6edc007f}},	//   _yéba_, ترسا, ænum_, dčbo, 
   {{0xa2c00c5a,0x69b007f7,0x417400f2,0xa7fc0205}},	// [37150] रोग्, आईटी, غارس, kfık, 
   {{0x7d19e7fe,0x6f1de7ff,0xddc8084c,0x9d440209}},	//   _ruus, _burc, _aceş, җекд, 
   {{0x7d19e800,0xddc80118,0x6ef803b2,0x00000000}},	//   _suus, _zdeň, píbl, --, 
   {{0x6f1c91e1,0xef19e801,0x7d19e802,0xde580212}},	//   _durc, імі_, _puus, саді_, 
   {{0xad25e803,0x7d180014,0x7eb0036e,0x61fc00de}},	//   وروو, _quus, _uçpm, _uzsl, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3a3c0cfe,0x2ab806fd,0xf8ac0133,0x00000000}},	//   taup_, _séba_, ێکت_, --, 
   {{0xf6b80ed9,0x7d19e804,0x33dc011a,0x00000000}},	//   _བཞེང, _tuus, יחוד, --, 
   {{0x3a3c008b,0x5d34009f,0x18680798,0x00000000}},	//   raup_, _رفائ, бапи_, --, 
   {{0x6c540372,0x49c528a1,0x3a3c003e,0xf2c800c5}},	//   _окуу, ялын_, saup_, _रग्घ, 
   {{0xe9a813f9,0x6f1c06be,0x6e400166,0x2b54072d}},	//   مدین_, _xurc, _özbä, _قیود_, 
   {{0x3a3c0cfe,0x19580953,0xa3c0012c,0x27f8004e}},	//   qaup_, _гады_, ्छन_, ürna_, 
   {{0xe9800046,0xeab06640,0x6d440153,0x65b001e1}},	//   _ақын, _جعل_, šiav, _róhú, 
   {{0xd6d81248,0x2eb893cb,0x516400f7,0xe8940023}},	//   ртү_, _आत्त, үүнү_, _ክፈልጡ_, 
   {{0xe8240014,0x7bc0002f,0x00000000,0x00000000}},	//   _غروٝ, nznu, --, --, 
   {{0x29180428,0x6f1c016d,0x55e4010a,0x00000000}},	//   _òeaò_, _rurc, _нойб, --, 
   {{0x6f1de805,0xa8b401c6,0x00000000,0x00000000}},	// [37160] _surc, _хөөц, --, --, 
   {{0x6f1de806,0xc600013d,0xa3cc06e3,0x25ac000d}},	//   _purc, _язый, _शेव_, äele_, 
   {{0xb4e8069f,0x6f1c0ba7,0x00000000,0x00000000}},	//   यकी_, _qurc, --, --, 
   {{0x12780597,0x54340014,0x1ea90565,0x4718010f}},	//   _احدث_, _برکر, ياني_, צונג, 
   {{0x6f1c045f,0xa2d82ac3,0x24e401ec,0x32f0010e}},	//   _wurc, नचर्, _ﺍﺳﻪﻣ, gşyň_, 
   {{0x41242901,0xad240116,0x00000000,0x00000000}},	//   _хоро_, كىچى, --, --, 
   {{0xe05479f8,0x6f1c0009,0x26d837b5,0x5eb800cc}},	//   _زینت_, _uurc, érok_, েকজে, 
   {{0x25ec0073,0x63a001e3,0x00000000,0x00000000}},	//   _घडली_, älni, --, --, 
   {{0x657c009a,0x7bc000d7,0x3da400d8,0x00000000}},	//   xwsh, aznu, _екто_, --, 
   {{0x87e4011c,0x00000000,0x00000000,0x00000000}},	//   зюме, --, --, --, 
   {{0xaca4063f,0xe678109a,0x00000000,0x00000000}},	//   gbụr, ойні_, --, --, 
   {{0xa3cc9401,0x7cfc00d8,0x6d440024,0xe6180137}},	//   _शेष_, mêra, šiau, өдү_, 
   {{0x8bec015b,0x7cfc0194,0x657c01f5,0x00000000}},	//   টেশন_, lêra, uwsh, --, 
   {{0x657c00ca,0x00000000,0x00000000,0x00000000}},	//   rwsh, --, --, --, 
   {{0xe29801e0,0x00000000,0x00000000,0x00000000}},	//   ҙаҡ_, --, --, --, 
   {{0x95980201,0xb7d8011a,0x00000000,0x00000000}},	//   ገራችን_, _לקוי, --, --, 
   {{0x2a340201,0xa3cc00e1,0x00000000,0x00000000}},	// [37170] _በኢትዮ, _शेर_, --, --, 
   {{0x72044d2f,0x7bc000d7,0x00000000,0x00000000}},	//   رولم, yznu, --, --, 
   {{0x5f79e807,0x00000000,0x00000000,0x00000000}},	//   تماس_, --, --, --, 
   {{0x270c0118,0xdea00244,0x9df804c2,0x00000000}},	//   _pěny_, خیری, онет_, --, 
   {{0xef20012d,0xa7fc1ea0,0x00000000,0x00000000}},	//   ężar_, lgıd, --, --, 
   {{0x7bc00732,0x00000000,0x00000000,0x00000000}},	//   tznu, --, --, --, 
   {{0x0c3400c6,0xacf401d5,0x00000000,0x00000000}},	//   ذكية_, رسهت, --, --, 
   {{0x7bc005ce,0xa2c00bca,0x00000000,0x00000000}},	//   rznu, रोच्, --, --, 
   {{0x9ac40083,0x00000000,0x00000000,0x00000000}},	//   _neŋŋ, --, --, --, 
   {{0x57480b59,0x00000000,0x00000000,0x00000000}},	//   озом_, --, --, --, 
   {{0xbb5000b5,0x57e801f4,0x69dc0205,0x00000000}},	//   _dmcハ_, юдом_, şrep, --, 
   {{0x9ac40083,0x6440066a,0xddc800e8,0x095000cf}},	//   _beŋŋ, ðlin, _ndeŋ, رۉۉڭ, 
   {{0x2b40098d,0x00000000,0x00000000,0x00000000}},	//   ćice_, --, --, --, 
   {{0x38c001e1,0x9178004d,0xb4e83347,0xe600010b}},	//   _dérù_, _lập_, यके_, ыҗын, 
   {{0x53140798,0x00000000,0x00000000,0x00000000}},	//   дфау, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x672408ad,0x3f8000af,0x00000000,0x00000000}},	// [37180] _čiji, _asju_, --, --, 
   {{0x92cc0eac,0xf9852766,0x00000000,0x00000000}},	//   শকে_, _یب_, --, --, 
   {{0x784c001f,0x6ef800bc,0x69d412eb,0x00000000}},	//   _በአንጻ, líbi, _बेनी, --, 
   {{0x2ab8003e,0x917801fb,0x51544965,0x00000000}},	//   _rébo_, _cập_, _отгу, --, 
   {{0x2175e808,0x3f8002d2,0xad2400d1,0x94200073}},	//   _пурр, _esju_, رىغى, _मलाच_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xff21e809,0x00000000,0x00000000,0x00000000}},	//   _амсо, --, --, --, 
   {{0xc4b8190e,0xc00000f3,0x00000000,0x00000000}},	//   _उत्ख, _рпск, --, --, 
   {{0x9d500133,0xc0d00092,0x0d84010a,0x00000000}},	//   _مۆنت, ያሟሉ_, _юлан, --, 
   {{0xd90de80a,0xb4e9e80b,0x2d85e80c,0x6d440006}},	//   مین_, यको_, _isme_, šias, 
   {{0xf98c24c5,0xc0540375,0x69c4003d,0x81840150}},	//   هبی_, וביץ_, _żied, _ﻗﻴﻤﺔ_, 
   {{0x6ef800d8,0x00000000,0x00000000,0x00000000}},	//   fíbi, --, --, --, 
   {{0x2d84038e,0x6ef80597,0xd7640133,0xfe34011a}},	//   _jsme_, ríbh, ونیی, ורכי_, 
   {{0x998800a2,0x00000000,0x00000000,0x00000000}},	//   _ýaš_, --, --, --, 
   {{0x38c8e326,0x2cac00a9,0x77a401d9,0x00000000}},	//   _بانی_, _modd_, _ہێیہ_, --, 
   {{0xd4980364,0xd1bc001f,0x2cac08fb,0x290d6569}},	//   орӣ_, ሰጡት_, _lodd_, lmda_, 
   {{0xf8b4009d,0x00000000,0x00000000,0x00000000}},	// [37190] _хөө_, --, --, --, 
   {{0x4425e80d,0x9418013f,0x2cac00e8,0x00000000}},	//   _ün_, _mopɛ_, _nodd_, --, 
   {{0xdfd1e80e,0x2d844650,0x00000000,0x00000000}},	//   ديا_, _asme_, --, --, 
   {{0xf1d011bc,0xabc80150,0x9f04009a,0x00000000}},	//   _सेवन, _ﺒﺒﻘﺎ, روشو, --, 
   {{0x2d84003e,0x2cade80f,0x41e40212,0x31680117}},	//   _csme_, _bodd_, _ціна, _ошро_, 
   {{0x2cacc92c,0x1fb800fd,0x290c01d5,0x00000000}},	//   _codd_, _елгы_, jmda_, --, 
   {{0x38b8002d,0x2cad553c,0x917801fb,0x2d84d1e7}},	//   _bêrn_, _dodd_, _tập_, _esme_, 
   {{0x2d840065,0xd12c0014,0x6e95e0b3,0xff040006}},	//   _fsme_, _خۅے_, _иису, _цягн, 
   {{0x2cac00a9,0x9d558811,0xaed4945d,0x6b600023}},	//   _fodd_, _سنات, _ротш, ተሃለወ_, 
   {{0xa3c017cb,0x3ebc0008,0x290c0009,0xdce80171}},	//   ्छा_, _hlut_, gmda_, _dreģ, 
   {{0xa92431ee,0x3ebc143a,0x69d400bc,0x00000000}},	//   ндөл, _klut_, _बेठी, --, 
   {{0x0bb4010f,0x290c0205,0xb4e808a3,0xab8400d8}},	//   _אלעם_, amda_, यक्_, _јуфк, 
   {{0x7af9e810,0x918000d1,0x00000000,0x00000000}},	//   mlut, ﻧﺰﯗﭼ, --, --, 
   {{0x7af832ff,0x3ebc03f0,0x58040150,0x00000000}},	//   llut, _llut_, _كوشك, --, 
   {{0x6ef800d2,0x3ebc023a,0x7af84593,0xdedc010c}},	//   síbi, _olut_, olut, _ሕጻን_, 
   {{0x7af9e811,0x6584005b,0x00000000,0x00000000}},	//   nlut, äthä, --, --, 
   {{0xbb4c037e,0x7af9e812,0x142401ec,0x00000000}},	// [371a0] _jalカ_, ilut, _пдпм, --, 
   {{0x7af9e813,0x2d840077,0x26d80030,0xd33400a8}},	//   hlut, _rsme_, érov_, _пэмы, 
   {{0x3ebde814,0x7af9e815,0x2cade816,0xc4380375}},	//   _blut_, klut, _rodd_, _מתיי, 
   {{0x3ebc05c7,0x92b400c6,0x11d402bf,0x98ac0010}},	//   _clut_, _أحدا, _зігр, dpeč_, 
   {{0x82e80003,0x70840022,0x8634010f,0x2cac007c}},	//   _རྩིའ, _иҳаз, גאנג_, _podd_, 
   {{0xa7fc05d1,0x2cac058a,0xdde00356,0x7af8000d}},	//   ngıc, _qodd_, _ţuţe, elut, 
   {{0x3ebc3caa,0x7af9e817,0xdff4013d,0xc0e000c0}},	//   _flut_, flut, _аять, _сорк, 
   {{0x7af9e818,0x3ebc0793,0x2cac002e,0x290c0254}},	//   glut, _glut_, _wodd_, wmda_, 
   {{0x63b4068f,0x00000000,0x00000000,0x00000000}},	//   zyzn, --, --, --, 
   {{0x2919e819,0x7af9e81a,0xdc28f7fd,0xc7c42571}},	//   öra_, alut, _قسمه_, есми, 
   {{0x7af80cfe,0x64400008,0x27f82f48,0x290c0790}},	//   blut, ðlim, ærn_, rmda_, 
   {{0x7af9e81b,0x94180134,0x63b402fb,0xf801e81c}},	//   clut, _wopɛ_, vyzn, ычын, 
   {{0x7950009f,0x9f50013a,0xf5e40150,0x00000000}},	//   _مَنا, _ryzí_, гірм, --, 
   {{0xf990010f,0xf76c0271,0x00000000,0x00000000}},	//   _תרס_, جای_, --, --, 
   {{0xf76c0502,0xdce80327,0x00000000,0x00000000}},	//   _هاي_, _jreġ, --, --, 
   {{0x63b400d7,0x326410d6,0x00000000,0x00000000}},	//   ryzn, лтув, --, --, 
   {{0xddc9e81d,0x26d80122,0xf6500451,0x98ac02f0}},	// [371b0] _obeš, érou_, _طئي_, zpeč_, 
   {{0x3ebc2f55,0xc4c40244,0x00000000,0x00000000}},	//   _slut_, _ستخو, --, --, 
   {{0x3ebde81e,0x00000000,0x00000000,0x00000000}},	//   _plut_, --, --, --, 
   {{0x926010de,0x00000000,0x00000000,0x00000000}},	//   _ەگەم, --, --, --, 
   {{0x629de81f,0x628c1509,0x5d680276,0x7c700131}},	//   _inso, mdao, филм_, лғач, 
   {{0x628c1028,0xa2d807b7,0x00000000,0x00000000}},	//   ldao, नचक्, --, --, 
   {{0xdfd40064,0xdd9000e5,0xbbd800cd,0x00000000}},	//   _ровы, طوں_, यपेक, --, 
   {{0xdd940022,0xfe700271,0x6440022e,0x00000000}},	//   _иабы, _حدس_, аlik, --, 
   {{0x7af832ff,0x2b40098d,0x2d5802f6,0x69d40ce0}},	//   rlut, ćica_, _пить_, _बेदी, 
   {{0xfba80276,0x00000000,0x00000000,0x00000000}},	//   _нтей_, --, --, --, 
   {{0x7af9e820,0x81d400bd,0x628de821,0x629de822}},	//   plut, িথি_, kdao, _onso, 
   {{0x7af80d04,0x997400c0,0x00000000,0x00000000}},	//   qlut, _аукш, --, --, 
   {{0x186816a4,0x628c01a9,0x00000000,0x00000000}},	//   _жали_, ddao, --, --, 
   {{0x395de823,0xb4dc0073,0x99dc00a2,0x00000000}},	//   muus_, ढचे_, laňo, --, 
   {{0x0441e824,0x9484f1c2,0x395de825,0x87d005d9}},	//   ресн, ныңд, luus_, _پٺيا, 
   {{0xd5b06f43,0x628cd2b2,0x45f00521,0x395dc9f9}},	//   _نفع_, gdao, ụpụ_, ouus_, 
   {{0x395de826,0x629c0175,0x422006ed,0x2bd8000d}},	// [371c0] nuus_, _dnso, рдув, _भेना, 
   {{0x629de827,0x7644062c,0x8494001f,0x628c01ab}},	//   _enso, _heiy, ገኛለን_, adao, 
   {{0xb9e80201,0x75240cf9,0x395de828,0x7644d6f1}},	//   _ሕግ_, _huiz, huus_, _keiy, 
   {{0x7525e829,0x395cb6a5,0x7644007f,0xdce80003}},	//   _kuiz, kuus_, _jeiy, _rreġ, 
   {{0x7645dc72,0x7525e82a,0x395de82b,0x2c780229}},	//   _meiy, _juiz, juus_, ейль_, 
   {{0xfd0d3455,0x91e4037e,0x395c0381,0xdce80135}},	//   يجو_, _auでi, duus_, _preġ, 
   {{0x7525e82c,0x0ba80150,0x8f14084c,0x629c0076}},	//   _luiz, باشى_, _афач, _ynso, 
   {{0x7645e82d,0x395de82e,0x75240156,0x31600165}},	//   _neiy, fuus_, _ouiz, ouiz_, 
   {{0x75240100,0x395de82f,0xc76400d1,0xcd2801c8}},	//   _nuiz, guus_, ھادى, _آسرن_, 
   {{0x76440109,0x1bec033d,0xc7640075,0x6d41e830}},	//   _aeiy, _चुकल_, پادى, _iwma, 
   {{0x76440363,0x26140037,0x2ab80241,0x99dc010b}},	//   _beiy, नेनी_, _lébi_, laňl, 
   {{0xda647500,0x752409b6,0x395de831,0x02a0063f}},	//   _ماهي, _buiz, buus_, tbọọ, 
   {{0x395d38f1,0x764400ad,0x59d82208,0xa9540d30}},	//   cuus_, _deiy, _बेपर, _склі, 
   {{0x75240cf9,0x76440076,0xa3d4009d,0x00000000}},	//   _duiz, _eeiy, гогч, --, 
   {{0xa3ccc39f,0x76440363,0x26d8908d,0x00000000}},	//   _शेख_, _feiy, éros_, --, 
   {{0x291c08f5,0xf2c43334,0x76440363,0x6d406873}},	//   _hiva_, асун, _geiy, _owma, 
   {{0x26d9e832,0x752403f9,0x628c7ea1,0x291de833}},	// [371d0] miso_, _guiz, rdao, _kiva_, 
   {{0x26d8676c,0x2ab80248,0x76440009,0x291d3c96}},	//   liso_, _débi_, _zeiy, _jiva_, 
   {{0x27280225,0x6d41e834,0x7645e835,0x6444003a}},	//   _jûn_, _awma, _yeiy, _iehi, 
   {{0xf77004ac,0x6444166a,0x291de836,0x395de837}},	//   יקע_, _hehi, _liva_, yuus_, 
   {{0x6445e838,0xad24185e,0x22480591,0xee381ed2}},	//   _kehi, لىنى, maak_, тні_, 
   {{0x291de839,0x26d9e83a,0x395c02f6,0x64440109}},	//   _niva_, hiso_, vuus_, _jehi, 
   {{0x26d9e83b,0x61fc01ab,0x2128011f,0x6d4003ac}},	//   kiso_, _hysl, lqah_, _ewma, 
   {{0x6445e83c,0xc2040bb2,0x291c0e8a,0x2249e83d}},	//   _lehi, _शराब_, _aiva_, naak_, 
   {{0x26d9cd21,0x291de83e,0x6d4002a8,0x99dc0122}},	//   diso_, _biva_, _gwma, raňo, 
   {{0x61fde83f,0xad2404a9,0x6445e840,0x7645e841}},	//   _mysl, _ئىلى, _nehi, _seiy, 
   {{0x395de842,0x26d9e843,0x752529ab,0x22480548}},	//   suus_, fiso_, _suiz, kaak_, 
   {{0x26d8014c,0x291c0077,0x6ef88607,0x395c0381}},	//   giso_, _eiva_, líbr, puus_, 
   {{0x75240015,0x64442e8d,0x764403b4,0x291c0607}},	//   _quiz, _behi, _veiy, _fiva_, 
   {{0x27280225,0x291c0007,0x76440086,0x21280429}},	//   _fûn_, _giva_, _weiy, dqah_, 
   {{0x26d9e844,0x6445e845,0xb4041e87,0x61fc03ac}},	//   biso_, _dehi, рүнд, _aysl, 
   {{0x26d9e846,0x291de847,0x644406c8,0x61fc002d}},	//   ciso_, _ziva_, _eehi, _bysl, 
   {{0xa7fc70f7,0x6445e848,0x291c18f7,0x61fc0142}},	// [371e0] ngın, _fehi, _yiva_, _cysl, 
   {{0x6444152d,0x291c036b,0x53a4014b,0x8fa44b1f}},	//   _gehi, _xiva_, _баоб, лазе, 
   {{0x2249e849,0x4f941ac1,0x2128011f,0x2ab8003e}},	//   baak_, ырау, aqah_, _wébi_, 
   {{0x64444252,0xb05400e5,0x00000000,0x00000000}},	//   _zehi, _چھات, --, --, 
   {{0x316077d0,0x6445e84a,0x4638008f,0xdcb0004d}},	//   quiz_, _yehi, גענע, _bỏ_, 
   {{0x26d9e84b,0x0b888f79,0xdcb00051,0xac9401f0}},	//   ziso_, есии_, _cỏ_, ракш, 
   {{0x291de84c,0x26d9e84d,0x162c00b7,0xcd0402dd}},	//   _riva_, yiso_, ዱስትሪ, _ұпай, 
   {{0x291de84e,0x27280a85,0x26d801d9,0xad8400d1}},	//   _siva_, _rûn_, xiso_, _پارۇ, 
   {{0x26d9e84f,0x27280b21,0x3a2c04cc,0xc2780375}},	//   viso_, _sûn_, _dfgp_, גרפי, 
   {{0x26d800aa,0xfaa007d6,0x224896e6,0x2728000f}},	//   wiso_, _қачо, zaak_, _pûn_, 
   {{0x64455f7f,0x26d9e850,0x2248020c,0x00f4011a}},	//   _rehi, tiso_, yaak_, רזים_, 
   {{0x644427ed,0x49c80601,0x8588036b,0x22480548}},	//   _sehi, _плен_, нёга_, xaak_, 
   {{0x26d9e851,0x291c06e4,0x27280b21,0x6445e852}},	//   riso_, _tiva_, _wûn_, _pehi, 
   {{0x26d9e853,0x83840209,0x61fd2815,0x2249e854}},	//   siso_, лыбе, _rysl, waak_, 
   {{0x26d9e855,0x61fc00b5,0x6445e856,0x2249e857}},	//   piso_, _sysl, _vehi, taak_, 
   {{0x6445e858,0x59d803f3,0x26d801af,0xdee40023}},	//   _wehi, _बेडर, qiso_, ዝኮነ_, 
   {{0x2249e859,0x60f80b32,0x6445e85a,0xf0e806ba}},	// [371f0] raak_, вная_, _tehi, گىلى_, 
   {{0x04648d61,0x21280a2e,0x61fc0232,0x2249e85b}},	//   _стим, rqah_, _vysl, saak_, 
   {{0x8004d550,0x61fd5b23,0x2249adbb,0xa7fc236c}},	//   учае, _wysl, paak_, zgın, 
   {{0x22483209,0x67040b4c,0xa7fc247e,0xa2c40116}},	//   qaak_, रतिक_, ygın, _тәгк, 
   {{0x2128025a,0x7cfc0489,0xddc800d0,0xdc6920fe}},	//   qqah_, lêri, _obeť, валд_, 
   {{0x8d900131,0x7a1800b8,0xc0c80064,0x00000000}},	//   زلىش, _jātū, _чуме_, --, 
   {{0x7a1802b5,0x2bd84668,0xdcb00051,0x00000000}},	//   _mātū, _भेदा, _vỏ_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7c640372,0x4aa5e85c,0xdcb00051,0xf27c011a}},	//   _ماال, ркын_, _tỏ_, תרחש, 
   {{0x26d89b4c,0x7c9426c6,0xa7fc0e2d,0x1bd40815}},	//   èron_, _حشرا, rgın, _козя, 
   {{0xe9a997a2,0xba740b24,0x4c9800d9,0x7a18411e}},	//   ندین_, _ماشت, _שבעו, _sātī, 
   {{0x89d56f6c,0x7a180374,0x6b9de85d,0xe8f801e0}},	//   اویر_, _pātī, _árga, клө_, 
   {{0xcb10025f,0xd9454f59,0x98a5e85e,0xc994004b}},	//   _ולא_, _тели, _виле, _پانګ, 
   {{0x04400798,0x00000000,0x00000000,0x00000000}},	//   жерн, --, --, --, 
   {{0x9344d1d8,0x00000000,0x00000000,0x00000000}},	//   рнбе, --, --, --, 
   {{0xd13000c6,0x00000000,0x00000000,0x00000000}},	//   قمر_, --, --, --, 
   {{0x225c0034,0xaca40521,0x41240aa8,0xb60801ef}},	// [37200] ówka_, waọr, иото_, _duší, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x53a532b1,0x940405af,0x2484000d,0x00000000}},	//   _танб, _خوده, õlme_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd9b400eb,0x00000000,0x00000000,0x00000000}},	//   _জেসম, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7988015d,0x00000000,0x00000000,0x00000000}},	//   _asgw, --, --, --, 
   {{0x21f00ca8,0x00000000,0x00000000,0x00000000}},	//   _ẹhin_, --, --, --, 
   {{0x7cfc025a,0x8d2802bf,0xf1e40154,0x00000000}},	//   zêri, _розв_, _মরুভ, --, 
   {{0xc7b812c4,0x2ab800d5,0xc1700375,0x3f000327}},	//   вём_, _rébu_, קחת_, _མཚོའ_, 
   {{0x7a1800b0,0xfd1c04cc,0x870402dd,0xe69401af}},	//   _rātū, _èìa_, ияме, бины, 
   {{0x7bd80375,0xd1f00023,0xe8c80150,0x00000000}},	//   _בקבו, ጌላት_, тгүл_, --, 
   {{0xe894dbe2,0x7a1802b5,0xb60802f0,0x34b407d0}},	//   _галь, _pātū, _ruší, ुसूद, 
   {{0xb60802f0,0xe5a400c7,0x00000000,0x00000000}},	//   _suší, аиҭи, --, --, 
   {{0x22580108,0x4ad8012d,0x424400d8,0x00000000}},	//   ливы_, _बगाव, ихаб, --, 
   {{0x6d5c02b1,0x9f6000d5,0x798803cb,0xd8080064}},	//   _āran, _éséy_, _ysgw, _схіл_, 
   {{0x20046185,0xf19407d8,0xf480001f,0x38b80051}},	// [37210] _šli_, оить, ስቀመጥ_, _sêri_, 
   {{0xf0e804a9,0xa7fc6648,0x272401f2,0x25080517}},	//   لىقى_, ygıl, _ịnya_, _حربی_, 
   {{0xb60802fb,0x35f848a7,0x61e80153,0xde041206}},	//   _tuší, _مرید_, _želd, әпли, 
   {{0x443001ef,0xa7fc03e0,0x00000000,0x00000000}},	//   _hfx_, vgıl, --, --, 
   {{0x44300166,0x1278008f,0xbd6801f4,0x00000000}},	//   _kfx_, _גארע, трее_, --, 
   {{0x8c4074a0,0xa0c400ec,0xf538011a,0xad4400db}},	//   пеше, _ايسو, סטור_, تۉكۉ, 
   {{0x2005066d,0x00000000,0x00000000,0x00000000}},	//   _áli_, --, --, --, 
   {{0xa7fc03ee,0x00000000,0x00000000,0x00000000}},	//   rgıl, --, --, --, 
   {{0x7e79e85f,0x61e802d2,0x6d34011c,0x00000000}},	//   _ibup, _þeld, _метф, --, 
   {{0xd7001d8a,0x44300175,0xf1e400fe,0x00000000}},	//   ोष्ठ_, _nfx_, _মৰুভ, --, 
   {{0x192c02d3,0x9b94e1a2,0x2bc80395,0x00000000}},	//   _ተኣሲሮ, _دلات, _куцо_, --, 
   {{0x5b142424,0x44300112,0x0f78010f,0x1dbc37cc}},	//   _умет, _afx_, נארב, ्नपत, 
   {{0x7e79aa88,0x7988545b,0x00000000,0x00000000}},	//   _mbup, _usgw, --, --, 
   {{0x3a3c06d1,0x14580166,0x00000000,0x00000000}},	//   lbup_, ышмы_, --, --, 
   {{0xe3b0121e,0x78a1e860,0x9734a706,0x00000000}},	//   ورِ_, _innv, _اعتص, --, 
   {{0x44300218,0x7e7801f2,0x26140073,0x395c0037}},	//   _efx_, _nbup, नेही_, orus_, 
   {{0x955476d7,0x4638008f,0x395d1280,0x988000ef}},	// [37220] _اخبا, _געפע, nrus_, _līči_, 
   {{0x7e780b6f,0x4431e861,0x395de862,0x270c05ac}},	//   _abup, _gfx_, irus_, _সংযো_, 
   {{0x0eb81084,0x59d84ca3,0xa7fc03e0,0x00000000}},	//   луды_, _बेसर, ygım, --, 
   {{0x61e85946,0x91e44d5f,0x395de863,0x69c4025c}},	//   _žele, _гоме, krus_, _żiem, 
   {{0x395c5770,0xa1540395,0x3e681bf4,0x00000000}},	//   jrus_, _мърш, اجمی_, --, 
   {{0x7e79e864,0x395de865,0xdb0801f1,0xab38003b}},	//   _ebup, drus_, ľnýc, апку_, 
   {{0xdb080232,0x395d0fb2,0x00000000,0x00000000}},	//   žnýc, erus_, --, --, 
   {{0x7cfc003a,0x395c030a,0x797c06ba,0x0a681d5b}},	//   dêru, frus_, ﯩﻤﯩﺰ_, урки_, 
   {{0xd90c3e66,0x00000000,0x00000000,0x00000000}},	//   چین_, --, --, --, 
   {{0xd90c50c9,0xf67405f5,0xcce486bf,0xdce80205}},	//   نین_, үгээ, _اسري, _ipeğ, 
   {{0x395d6bf9,0x78a00051,0x316003e3,0xd1bc0240}},	//   arus_, _dnnv, hriz_, _ደይብ_, 
   {{0x395de866,0x4430014f,0x8afc03f9,0x78a001c7}},	//   brus_, _sfx_, buƙa, _ennv, 
   {{0x395de867,0x7af001d3,0x8a0401f4,0x00000000}},	//   crus_, űjtö, _узде, --, 
   {{0x316005d5,0x27f8004e,0x00000000,0x00000000}},	//   driz_, ürns_, --, --, 
   {{0xf8d80302,0x2418c3ce,0x44300051,0xc79400cf}},	//   _תחומ, ровы_, _vfx_, _ырды, 
   {{0x871001e1,0x00000000,0x00000000,0x00000000}},	//   bépọ, --, --, --, 
   {{0x26c80093,0x56780137,0x31600e04,0xe0d80212}},	// [37230] _ilao_, _ئشىڭ_, griz_, адач_, 
   {{0xca780139,0x00000000,0x00000000,0x00000000}},	//   _ittе, --, --, --, 
   {{0xdea012e1,0x26147220,0x68e801bf,0xa24400cf}},	//   ویسی, नेरी_, indd, _ورحۇ, 
   {{0x395de868,0x3161e869,0xbe485a0c,0x75dc0171}},	//   yrus_, briz_, اشام_, bāzī, 
   {{0x316002e8,0x26c801af,0x9cf402bf,0xdd0008a9}},	//   criz_, _mlao_, озді, _ştır, 
   {{0x660c0bd7,0x26c801e4,0x395de86a,0x3134010b}},	//   _mzak, _llao_, vrus_, _херр, 
   {{0x26c801ee,0x225805c7,0xddd8002d,0x395c0042}},	//   _olao_, _kdsk_, rdwű, wrus_, 
   {{0xcfb000bd,0x660d5054,0x7e79e86b,0x1a6452cb}},	//   _টেকন, _ozak, _ubup, زیتی_, 
   {{0x660de86c,0x59d8443a,0x68e80042,0x00000000}},	//   _nzak, _बेशर, fndd, --, 
   {{0x26c9e86d,0x395de86e,0x420400cd,0x2dd800ae}},	//   _alao_, rrus_, _शरैः_, _طبقة_, 
   {{0x16a802d7,0x2138070d,0x660de86f,0x26c80109}},	//   авни_, _ltsh_, _azak, _blao_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7af808f5,0x26142d8f,0x660c06d8,0x00000000}},	//   mout, नेली_, _czak, --, 
   {{0x660c1cbd,0x98a41248,0x26c8d481,0x7af9e870}},	//   _dzak, _фике, _elao_, lout, 
   {{0x2139e871,0x38b8002d,0x7cfc002d,0x6d5c00cd}},	//   _atsh_, _dêrt_, lêrs, _āram, 
   {{0x7af9e872,0x4950044e,0x26c9b71c,0x6b5001e7}},	//   nout, _መነባብ, _glao_, _hógá, 
   {{0xe3b000aa,0x59c80882,0x2b4007f5,0xe6c40220}},	// [37240] ورې_, िनिर, ćici_, _ءتىي, 
   {{0x7af9e873,0x31600323,0x00000000,0x00000000}},	//   hout, rriz_, --, --, 
   {{0xde5402d3,0x26c8009a,0x43dc0241,0x00000000}},	//   _ከምዝገ, _ylao_, _tìrẹ_, --, 
   {{0x3161924e,0x7af9e874,0xfbcc04c5,0x6b51e875}},	//   priz_, jout, িপাত, _lógá, 
   {{0xf76400b2,0x7af9e876,0x0ca86522,0x316001a9}},	//   _ڪا_, dout, итки_, qriz_, 
   {{0x99dc002e,0xab940212,0x14cc01f9,0x00000000}},	//   naňu, зикі, होचण, --, 
   {{0xf765e273,0x7af9e877,0xbc640ccb,0x1fb40329}},	//   _تا_, fout, زمين_, _естр, 
   {{0x7af9e878,0x673801fa,0x68e80042,0x00000000}},	//   gout, _rtvj, wndd, --, 
   {{0x4ce5e879,0x224c0254,0x00000000,0x00000000}},	//   _джаб, _õeke_, --, --, 
   {{0x26c808ad,0x3c6000f7,0xf98c01c8,0x00000000}},	//   _slao_, _окуг, ئبي_, --, 
   {{0x7af9e87a,0x660c066d,0x66cc045f,0x00000000}},	//   bout, _szak, _lûke, --, 
   {{0xbb400395,0x00000000,0x00000000,0x00000000}},	//   _цецк, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x21380240,0xa3a8000d,0x00000000,0x00000000}},	//   _rtsh_, _गऊआ_, --, --, 
   {{0xd5ac00f1,0x33942cdd,0x00000000,0x00000000}},	//   نځی_, марё, --, --, 
   {{0x66cc002d,0x660c009d,0x26c800e4,0x0584022e}},	//   _bûke, _tzak, _ulao_, _дуом, 
   {{0x69c1e87b,0x660de87c,0x38b8002d,0xf6500451}},	// [37250] nyme, _uzak, _gêrs_, _شئي_, 
   {{0x7af9e87d,0x66cc000f,0xc8c8098a,0xde540023}},	//   zout, _dûke, िसिट, _ከምዘገ, 
   {{0x62340d5c,0x7af9e87e,0x69c1e87f,0x6e2401e4}},	//   _нену, yout, hyme, ɾibi, 
   {{0x66cc002d,0x35e0033f,0x69c001f4,0x00000000}},	//   _fûke, _पेड़, kyme, --, 
   {{0xdca51bf5,0x2138009a,0x9d44010b,0x6b9c032e}},	//   зали, _utsh_, челд, _árgj, 
   {{0x69c1e880,0x91b80302,0x7af80100,0x00000000}},	//   dyme, _המשי, wout, --, 
   {{0x7af9e881,0xd0f837c8,0x5f4400e5,0x9a68007b}},	//   tout, ्तरण_, _رچال, ممثل_, 
   {{0x69c003ac,0x6e64009b,0x91540244,0x186800c7}},	//   fyme, _отуж, _برێڤ, әани_, 
   {{0x7af9e882,0x69c0f281,0xec6c0022,0xfaa02bcb}},	//   rout, gyme, _иҿ_, зақо, 
   {{0x7af9e883,0x8308031c,0xade000c5,0x18680063}},	//   sout, _ཁེའུ_, _खइतन_, љани_, 
   {{0xb8e025fe,0x7af9e884,0xd6281de1,0x00000000}},	//   _एक_, pout, йоне_, --, 
   {{0x77400020,0x60c40649,0x38b804cc,0x6a9402bf}},	//   _የደረሰ, hkhm, _pêrs_, _оріє, 
   {{0x6b500597,0x1dbc00dc,0x6d5c002b,0x00000000}},	//   _tógá, ्नित, _ārak, --, 
   {{0xaa64052f,0x66cc002d,0x69d40dba,0xab280137}},	//   _етәк, _rûke, _बेटी, _اسەل_, 
   {{0x66cc000f,0x03a1e885,0x99dc0122,0xf4940023}},	//   _dûkb, ниро, raňu, _ዚዛረብ_, 
   {{0xc3201677,0x61e81da2,0x1dbca06f,0x00000000}},	//   емск, _žela, ्नात, --, 
   {{0x4fe81b15,0x79981418,0xa2cc04aa,0x453000db}},	// [37260] әмен_, nvuw, _सतर्, _كىير, 
   {{0x41000890,0x8f7401ec,0xddc8013a,0x00000000}},	//   езув, зуді, _udeř, --, 
   {{0x69c13e4f,0xd41800cc,0x00000000,0x00000000}},	//   zyme, _ত্ৰি_, --, --, 
   {{0xce300424,0x66cc045f,0x69c001f4,0x00000000}},	//   روتک, _tûke, yyme, --, 
   {{0x69c020a2,0xac9400d8,0xdcfc00dc,0x00000000}},	//   xyme, далш, _śyām, --, 
   {{0x69c01155,0x61e8032e,0xbd8400cf,0x00000000}},	//   vyme, _þela, سنىن_, --, 
   {{0x3f640395,0x69c003cb,0x00000000,0x00000000}},	//   _ниро_, wyme, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x0dc8941b,0xddc85a54,0x7e800150,0x99dc01ef}},	//   _улай_, _zbež, _ﺭﺤﻠﺕ_, daňs, 
   {{0x6d5c04fe,0x48a847cc,0x7d540375,0x69c1e886}},	//   _ārah, стим_, _מימד_, ryme, 
   {{0x69c0015d,0x799804ba,0x67d40212,0xddc80210}},	//   syme, avuw, фону, _odeś, 
   {{0x7998004c,0x69c00789,0x99dc02f0,0x00000000}},	//   bvuw, pyme, taňt, --, 
   {{0x2b40041a,0x00000000,0x00000000,0x00000000}},	//   ćicu_, --, --, --, 
   {{0xddc800b8,0x9ba00131,0xb3d80154,0xf6440588}},	//   _adeś, _سەۋى, _দুইজ, _ҧхын, 
   {{0x443c008f,0x00000000,0x00000000,0x00000000}},	//   ĝu_, --, --, --, 
   {{0x443c0115,0xbb380677,0x00000000,0x00000000}},	//   ŝu_, מעלי, --, --, 
   {{0xa0c4314c,0xe50800f7,0x00000000,0x00000000}},	// [37270] ويرو, _ويعو_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x60c403a2,0x2418023a,0x2d300023,0xdce800d7}},	//   rkhm, _фоны_, _እተኻየ, _preľ, 
   {{0xd09003be,0xe81402ab,0x7df000d1,0x16180c22}},	//   _müəs, _डरना_, ىقاچ, नेवर_, 
   {{0x7e840006,0x00000000,0x00000000,0x00000000}},	//   _įspė, --, --, --, 
   {{0x9c640b24,0x41500408,0x00000000,0x00000000}},	//   ذهبو, ăвĕс, --, --, 
   {{0xddc80427,0xefbc0092,0x3f800171,0x00000000}},	//   _ubež, ቲባው_, _upju_, --, 
   {{0x998c0301,0x988000e2,0x20100171,0x00000000}},	//   rbež_, rīču_, _izzi_, --, 
   {{0x2f19e887,0x7c84165d,0x5c740184,0xddc80327}},	//   _хоть_, _нуже, _олат, _jbeż, 
   {{0x57e8034b,0xddc80327,0x2d80031c,0x00000000}},	//   ждом_, _mbeż, ħiet_, --, 
   {{0xac75e888,0x6d5c0b10,0x966400d3,0x7b44085b}},	//   _سالش, _ārai, мкне, _رئال, 
   {{0xddc8025c,0x7bc00024,0x00000000,0x00000000}},	//   _obeż, mynu, --, --, 
   {{0x7bc1e889,0x00000000,0x00000000,0x00000000}},	//   lynu, --, --, --, 
   {{0xe8f80220,0x00000000,0x00000000,0x00000000}},	//   _елі_, --, --, --, 
   {{0xaf800023,0x60c800a2,0x7bc000c0,0x00000000}},	//   _ሓፍትና_, _įemp, nynu, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7bc1e88a,0x80b40154,0x00000000,0x00000000}},	// [37280] hynu, ঃসন্, --, --, 
   {{0x2f2800a2,0xe19401c0,0x7bc03f8a,0x00000000}},	//   _aşga_, эрсэ, kynu, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2d840139,0x26143507,0x7bc16c26,0x00000000}},	//   _ppme_, नेकी_, dynu, --, 
   {{0xdc3805d1,0x4718008f,0x7bc00009,0x200403b2}},	//   _açıd, קונג, eynu, _ølin_, 
   {{0x0ba88818,0xd054013b,0x23640427,0x9d6401d9}},	//   قابى_, _ɛbɛy, šlje_, رنى۪, 
   {{0xe8f801e0,0x7bc1e88b,0xe05400f2,0x00000000}},	//   үһе_, gynu, _سینت_, --, 
   {{0x63a00267,0x998c031c,0xbae00006,0x5ec40154}},	//   ålni, bbeż_, кцый, লোবে, 
   {{0x225c0034,0xbe3001ec,0xd90c0133,0x00000000}},	//   ówki_, _شىلب, ڕیه_, --, 
   {{0xa03c0092,0x00000000,0x00000000,0x00000000}},	//   _ይቀንሳ, --, --, --, 
   {{0x7cd40214,0x7bc00142,0x273800f5,0x00000000}},	//   _تولز_, cynu, язнь_, --, 
   {{0xf76c168d,0xd6d40276,0x59d821bd,0xa5f8014b}},	//   گای_, еӂь_, _बेकर, зему_, 
   {{0x36d4dba2,0x00000000,0x00000000,0x00000000}},	//   тояр, --, --, --, 
   {{0xf76c7380,0xc7642dfc,0x61e809a8,0x261400e1}},	//   دای_, _قابى, _želo, नेगी_, 
   {{0x25ac0311,0x81680092,0x00000000,0x00000000}},	//   ţel_, ስፒታሉ_, --, --, 
   {{0xf76c03e6,0x3264fb98,0x6ef803b2,0x00000000}},	//   _ئاو_, ктув, píby, --, 
   {{0x02dc0cb4,0x7bc08689,0x5ec40154,0x00000000}},	// [37290] _नगीन, zynu, লোডে, --, 
   {{0xdfd5e88c,0x00000000,0x00000000,0x00000000}},	//   нозы, --, --, --, 
   {{0xe3740209,0x7bc0045a,0x00000000,0x00000000}},	//   _ялны, xynu, --, --, 
   {{0x4dc408b0,0xa7fc62c7,0xddc8031c,0x2bd8000d}},	//   ﯩﻠﯩﻨ, lgıs, _tbeż, _भइजा, 
   {{0x628c06c8,0x2d58084c,0x6d44054e,0x00000000}},	//   meao, дичь_, ţian, --, 
   {{0x6454d6dc,0x628de88d,0xd13c033f,0x00000000}},	//   nazi, leao, żące_, --, 
   {{0x64546f7b,0x201004ba,0x00000000,0x00000000}},	//   iazi, _uzzi_, --, --, 
   {{0x628d1f19,0x8d600092,0xdd951741,0x99d4009a}},	//   neao, ሰባቸው_, _пабы, فتخا, 
   {{0xdce8031c,0x3948180f,0x998c0003,0x8c40002f}},	//   _eseġ, ècs_, qbeż_, ößch, 
   {{0x6455e88e,0x7bc1e88f,0x00000000,0x00000000}},	//   jazi, pynu, --, --, 
   {{0x6455e890,0x628c0108,0x38440092,0x88c400eb}},	//   dazi, keao, _የአርብ, ষোভক, 
   {{0x2bd874f6,0x00000000,0x00000000,0x00000000}},	//   _भेटा, --, --, --, 
   {{0x6455e891,0x00000000,0x00000000,0x00000000}},	//   fazi, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2795e892,0x628c0270,0xb4e000e1,0x94846518}},	//   _ашыр, feao, _दगी_, мыңд, 
   {{0xe81406ab,0xe8b00131,0xa7fc05d1,0x628c01ab}},	//   _डरता_, _مەۋج, rgıt, geao, 
   {{0x6455e893,0x10a40117,0x6fec0154,0x016000db}},	// [372a0] bazi, ниан, _করেও_, лкто, 
   {{0x6455bfeb,0x00000000,0x00000000,0x00000000}},	//   cazi, --, --, --, 
   {{0xb4cc2aa1,0x0e64d0f9,0x00000000,0x00000000}},	//   लसी_, екен, --, --, 
   {{0x481400c8,0x2aa001e1,0x00000000,0x00000000}},	//   ײַבן_, _ḿbú_, --, --, 
   {{0x1ea8027d,0xdde80244,0x7e240212,0x82a001ec}},	//   ظامي_, ورهه_, ніша_, _саяж, 
   {{0x2b4c0175,0x30f400cd,0x00000000,0x00000000}},	//   _pwdc_, _आदिः_, --, --, 
   {{0xf765e894,0x612800c0,0xae140210,0x00000000}},	//   _حا_, _užla, तेजन_, --, 
   {{0x6455e895,0xc3300375,0xbb8000ae,0x00000000}},	//   zazi, נוח_, اليي, --, 
   {{0xa7fc247e,0x6380054e,0x00000000,0x00000000}},	//   ygıs, mânţ, --, --, 
   {{0x6455e896,0xddc80114,0x657802b1,0x6d40491b}},	//   xazi, _uceš, _äwhi, _itma, 
   {{0x4a4400d4,0x8ca403ba,0xab7002f2,0x00000000}},	//   _знев, _टोयो, _ئۆبژ, --, 
   {{0x645554fe,0x61e800c0,0x02dc28f0,0x00000000}},	//   wazi, _želm, _नगेन, --, 
   {{0x6455e897,0x00000000,0x00000000,0x00000000}},	//   tazi, --, --, --, 
   {{0xab640639,0x6454014b,0x6d400477,0xf89001af}},	//   _grüß, uazi, _mtma, _башќ, 
   {{0x0808188d,0xe8d00050,0x628c02b1,0x67d40212}},	//   _عزتي_, _مۅکھ, teao, _шоку, 
   {{0x6455e898,0x6d41e899,0x290de89a,0x00000000}},	//   sazi, _otma, llda_, --, 
   {{0x6455e89b,0x628c030a,0x00000000,0x00000000}},	// [372b0] pazi, reao, --, --, 
   {{0x657c676c,0xdce80135,0xd4c001e0,0x6454df83}},	//   mtsh, _iseħ, _көск, qazi, 
   {{0x6d41e89c,0x6d440311,0x99dc02f0,0x00000000}},	//   _atma, ţial, ybňo, --, 
   {{0x657c0af9,0x290c022e,0x623400db,0x4ca800eb}},	//   otsh, hlda_, _шему, _কতগু, 
   {{0x2249e89d,0x6d4005b1,0xdce80135,0x290cefaf}},	//   mbak_, _ctma, _jseħ, klda_, 
   {{0x657de89e,0x2cac5975,0x6d5c0055,0xfeb80066}},	//   itsh, _cndd_, _ārat, _کاست_, 
   {{0x6d41e89f,0x2248011f,0xa3d02d93,0x00000000}},	//   _etma, obak_, वनि_, --, 
   {{0x2249e8a0,0x290de8a1,0x6b880175,0x657cc1af}},	//   nbak_, elda_, _dpdg, ktsh, 
   {{0x657de8a2,0x290c02d2,0xceb401af,0x00000000}},	//   jtsh, flda_, _шәф_, --, 
   {{0xa3d00cb4,0x3ebde8a3,0x6bd40075,0x657c6285}},	//   वना_, _hout_, ختۇر, dtsh, 
   {{0x3ebc21a3,0x657de8a4,0x22480c6a,0x6d40013a}},	//   _kout_, etsh, kbak_, _ztma, 
   {{0x7d01e8a5,0x3ebc0a85,0xdb004056,0x224801f5}},	//   lons, _jout_, _orlé, jbak_, 
   {{0x3a2c014b,0x3ebc0334,0xe77801ed,0x2249e8a6}},	//   _iggp_, _mout_, ولیں_, dbak_, 
   {{0x7d01e8a7,0x3ebde8a8,0x2248005a,0xb4cc230e}},	//   nons, _lout_, ebak_, लसे_, 
   {{0x657de8a9,0xdb000129,0x00000000,0x00000000}},	//   atsh, _arlé, --, --, 
   {{0x7d01e8aa,0x657c429b,0x3ebd118d,0x8afc0198}},	//   hons, btsh, _nout_, tuƙi, 
   {{0x657c0334,0x66cc002d,0xd4f4586a,0x91293d96}},	// [372c0] ctsh, _mûkl, _аяны, джаб_, 
   {{0x7d001a82,0x3ebde8ab,0xb40405f5,0x6d4001ab}},	//   jons, _aout_, _бүгд, _rtma, 
   {{0x7d01e8ac,0x3ebde8ad,0x6d41e8ae,0xdb0001c7}},	//   dons, _bout_, _stma, _erlé, 
   {{0x3ebc2d59,0xf15403e6,0xb4b401e0,0xae5400ec}},	//   _cout_, _مێرد, _риүә, اراڻ, 
   {{0x7d01e8af,0x3ebde8b0,0x290de8b1,0x2cac0327}},	//   fons, _dout_, ylda_, _pndd_, 
   {{0x7d01e8b2,0xac19e8b3,0x7dc02374,0x6f6400d1}},	//   gons, нолу_, شقىن, _مۇئم, 
   {{0x3ebde8b4,0xc0e1e8b5,0x63800356,0x9db41411}},	//   _fout_, _торк, pânţ, _ەگىز_, 
   {{0x33202963,0x6d400175,0x657c036e,0xebc401e0}},	//   nmix_, _ttma, ytsh, _ҡәйн, 
   {{0x7d01e8b6,0x6d41e8b7,0x657c020c,0x290c022e}},	//   bons, _utma, xtsh, tlda_, 
   {{0x3ebc0196,0x2cac0109,0x290c04cc,0x92ac0154}},	//   _zout_, _undd_, ulda_, _কতো_, 
   {{0x8d60001f,0x657c009a,0xdce80135,0x3320031c}},	//   ሰጣቸው_, wtsh, _sseħ, kmix_, 
   {{0x657c11ad,0x7c2401ed,0x49c800ee,0x4ca80154}},	//   ttsh, _újra, _олен_, _কতটু, 
   {{0x657c0943,0x2b5c0175,0x35e4041b,0x00000000}},	//   utsh, lsvc_, ацрв, --, 
   {{0x873407dd,0xb8d00137,0x00000000,0x00000000}},	//   _иҟоу_, _ۅتۉش, --, --, 
   {{0xdfe0033f,0x22480549,0x55c00139,0x99140024}},	//   _गेंद_, tbak_, _һәрз, _сьці, 
   {{0x68e9e8b8,0x63a4242a,0x66d80241,0x2248007f}},	//   lidd, _vrhn, _dúkù, ubak_, 
   {{0x7d0142b6,0x3ebde8b9,0x2249e8ba,0x356873f6}},	// [372d0] yons, _rout_, rbak_, _ирэн_, 
   {{0x660de8bb,0x68e9e8bc,0x3ebc0660,0x22480f49}},	//   _iyak, nidd, _sout_, sbak_, 
   {{0x7d01e8bd,0x3ebc007f,0x33200998,0x660de8be}},	//   vons, _pout_, bmix_, _hyak, 
   {{0x660de8bf,0x9df83c1f,0x7d00055a,0x00000000}},	//   _kyak, ннет_, wons, --, 
   {{0x629d5fe3,0x68e82252,0x5d84036b,0x672c008f}},	//   _iaso, kidd, التل, _miaj, 
   {{0x660c51a9,0x3ebc0699,0x629de8c0,0x9b4400aa}},	//   _myak, _wout_, _haso, هنتو, 
   {{0x3ebde8c1,0x7d01e8c2,0x629de8c3,0x68e9e8c4}},	//   _tout_, rons, _kaso, didd, 
   {{0x7d01e8c5,0x629de8c6,0x1a6468ff,0x672de8c7}},	//   sons, _jaso, ایشی_, _niaj, 
   {{0x660de8c8,0x7d01e8c9,0x68e9e8ca,0x0b1400ae}},	//   _nyak, pons, fidd, دقية_, 
   {{0x629de8cb,0x68e9e8cc,0x26d80023,0x7c8400d8}},	//   _laso, gidd, ëron_, _шубе, 
   {{0x660de8cd,0x629c0270,0xab9402bf,0x672c8489}},	//   _ayak, _oaso, _вихі, _biaj, 
   {{0x629d5f7f,0x660de8ce,0xed500050,0x997400c7}},	//   _naso, _byak, _دپے_, _букш, 
   {{0x660c01aa,0x68e9e8cf,0x672c6678,0x1869e8d0}},	//   _cyak, bidd, _diaj, _зали_, 
   {{0x660de8d1,0x68e9e8d2,0x629c0072,0x78440064}},	//   _dyak, cidd, _aaso, _рэдж, 
   {{0x629de8d3,0x672c01e4,0x999c031c,0x94780022}},	//   _baso, _fiaj, _lewż_, _ҧсоу_, 
   {{0x672c07de,0xb2440032,0xdd980100,0xd294035b}},	//   _giaj, рмаһ, _osň_, ыргь, 
   {{0x660de8d4,0x629c0978,0xca7801a9,0xe04800f2}},	// [372e0] _gyak, _daso, _mutа, چشمه_, 
   {{0x332000d5,0x629c0c8c,0x798803ac,0xe2980107}},	//   smix_, _easo, _mpgw, наӣ_, 
   {{0x629ca628,0x61e801e4,0x00000000,0x00000000}},	//   _faso, _ɾeli, --, --, 
   {{0x629c0d29,0x68e80a49,0xa2980023,0x00000000}},	//   _gaso, zidd, _ወጻኢን_, --, 
   {{0x68e80a49,0x0c84013d,0xd178003b,0x00000000}},	//   yidd, гыйм, _ясні_, --, 
   {{0x629d7f56,0x61b002dd,0x68e8350e,0xd47800df}},	//   _zaso, _بەكا, xidd, גאַל, 
   {{0x629d614b,0x68e93682,0xfc3c01fb,0x00000000}},	//   _yaso, vidd, _đít_, --, 
   {{0x68e9e8d5,0xc87c008e,0x00000000,0x00000000}},	//   widd, _äğza_, --, --, 
   {{0x8c445e18,0xfe40084c,0x68e9e8d6,0x88e806ed}},	//   _безе, _ынто, tidd, еќна_, 
   {{0x672c00c8,0x660d682d,0xdce801e4,0x8178010f}},	//   _siaj, _ryak, _breĵ, עװיק, 
   {{0x68e9e8d7,0x660de8d8,0xda6405d9,0xa29802d3}},	//   ridd, _syak, _چاهي, _ወጻእን_, 
   {{0x68e9e8d9,0xda642834,0x0664460e,0x660c00b8}},	//   sidd, _ناهي, دادپ, _pyak, 
   {{0x672de8da,0x629de8db,0x68e9e8dc,0xa89801f0}},	//   _viaj, _raso, pidd, _аклу_, 
   {{0x660de8dd,0x629de8de,0x68e80429,0x29d40451}},	//   _vyak, _saso, qidd, _ٽيڪس, 
   {{0x629de8df,0x38c81968,0x672d8991,0x00000000}},	//   _paso, _ثانی_, _tiaj, --, 
   {{0x629d8285,0x23640010,0xc5e400cc,0x660c00dc}},	//   _qaso, šljo_, _গুণা_, _tyak, 
   {{0x660cfd4f,0xe2988c6c,0x250801b9,0xa4d80064}},	// [372f0] _uyak, наң_, _لردی_, _адпу_, 
   {{0x629de8e0,0x25a9e8e1,0x6d5c1d86,0x00000000}},	//   _waso, _iral_, _ārap, --, 
   {{0x629c398e,0x5f941d9d,0x7a299070,0x25a80030}},	//   _taso, риет, _kötü, _hral_, 
   {{0x25a9e8e2,0x26d80051,0x00000000,0x00000000}},	//   _kral_, nhso_, --, --, 
   {{0xee383334,0xceb41945,0xee840166,0x00000000}},	//   уні_, шәр_, сыхо, --, 
   {{0xad241b56,0x5ca5e8e3,0xdca41159,0x798803ac}},	//   مىنى, рикб, раки, _rpgw, 
   {{0x26d80014,0x3028004e,0xc1d001af,0x00000000}},	//   khso_, _боёп_, _төңә, --, 
   {{0x443001f9,0x7988009a,0x25a86eee,0x9f05a05b}},	//   _lgx_, _ppgw, _oral_, _ئورو, 
   {{0x7e78b761,0x66cc002d,0x44300798,0x26d80009}},	//   _icup, _tûkj, _ogx_, dhso_, 
   {{0x52d088f2,0x17855b29,0x260800e1,0x88800108}},	//   _सत्स, агом, _सड़ी_, ольж, 
   {{0x25a88b14,0xfba88540,0x798803ac,0x38000107}},	//   _aral_, _ятай_, _wpgw, сонҳ, 
   {{0xf1b005c7,0x775c0092,0x00000000,0x00000000}},	//   _ɡ͡b_, _ለደረሰ, --, --, 
   {{0x25a8011c,0x7e78009a,0x44300175,0x3a3c007c}},	//   _cral_, _mcup, _bgx_, mcup_, 
   {{0xccf004ac,0xd1e80125,0x395de8e4,0xa3d000dc}},	//   ַכן_, መደበ_, msus_, वनं_, 
   {{0x395de8e5,0x4431e8e6,0xb40400f7,0x186801af}},	//   lsus_, _dgx_, сүнд, _заһи_, 
   {{0x7a286f30,0x7e78014b,0x25a80b21,0xb4f40228}},	//   _götü, _ncup, _fral_, рүүч, 
   {{0x25a9e8e7,0x395de8e8,0x8d7802dd,0x5154130f}},	// [37300] _gral_, nsus_, _ﹼﻔﺎﻕ_, ртбу, 
   {{0x395de8e9,0x4f640f47,0x7e784c28,0x3a3c03e0}},	//   isus_, لاصف, _acup, hcup_, 
   {{0x395de8ea,0xa62c02d3,0xdb000332,0xd1e8069d}},	//   hsus_, ተዘይተ, _arlí, መደቡ_, 
   {{0x395de8eb,0x7e78454a,0x3a3c00b5,0x0dc80108}},	//   ksus_, _ccup, jcup_, клей_, 
   {{0x3a3de8ec,0x61e9e8ed,0x4638010f,0x161807af}},	//   dcup_, _želv, דענע, नेचर_, 
   {{0x3161e8ea,0x7e792346,0x395c000d,0x53b81546}},	//   msiz_, _ecup, dsus_, _उपाश, 
   {{0x395de8ee,0x7e7801a4,0x99dc0432,0x00000000}},	//   esus_, _fcup, maňy, --, 
   {{0x3a3c00b5,0x7e780332,0x99dc010b,0x8ca41fd2}},	//   gcup_, _gcup, laňy, _टोरो, 
   {{0x3161e8ef,0xabb407dd,0x395c0254,0x00000000}},	//   nsiz_, рақә, gsus_, --, 
   {{0x48a803cc,0x87440092,0x7a280139,0x61e80432}},	//   ттим_, _የተለቀ, _sötü, _ýele, 
   {{0x7a2801b8,0x3161e8f0,0x395c0393,0xbb400563}},	//   _pötü, hsiz_, asus_, _дехк, 
   {{0x25a811c1,0x31609f7e,0x443022d5,0x3a3c26c2}},	//   _pral_, ksiz_, _sgx_, ccup_, 
   {{0x058425a1,0x395de8f1,0x31603c0e,0x368801c6}},	//   шунм, csus_, jsiz_, шсэн_, 
   {{0x31602994,0x439001e0,0x28f80108,0x00000000}},	//   dsiz_, ҙағс, _щель_, --, 
   {{0xd1e80092,0x00000000,0x00000000,0x00000000}},	//   መደብ_, --, --, --, 
   {{0x25a9e8f2,0x9700063f,0x3161e8f3,0xe2c831b1}},	//   _tral_, ọkrị, fsiz_, دورو_, 
   {{0x25a9e8f4,0xe8e00051,0x31607ad9,0x00000000}},	// [37310] _ural_, _chủy_, gsiz_, --, 
   {{0x7e782b1d,0x116801d5,0xb6300150,0x99dc0432}},	//   _scup, اللی_, _ﺒﺽ_, gaňy, 
   {{0x4425c2b2,0x67380200,0x22940f06,0x00000000}},	//   _àn_, _juvj, _линя, --, 
   {{0x61e8098d,0x31609169,0x224c010e,0x81740117}},	//   _želu, bsiz_, _ýek_, _камӣ_, 
   {{0x395d7a0b,0xdc6801c6,0xfe74010b,0x225800ef}},	//   xsus_, галд_, лүң_, _iesk_, 
   {{0x2258030a,0x395c00c5,0x7c85e8f5,0x26d80240}},	//   _hesk_, vsus_, руде, ëroj_, 
   {{0x21381590,0x2259e8f6,0x6b580ce8,0x395c0042}},	//   _hush_, _kesk_, ашыр_, wsus_, 
   {{0x2138069c,0x395c007d,0x00000000,0x00000000}},	//   _kush_, tsus_, --, --, 
   {{0x395de8f7,0x213802d3,0x22580156,0x7c6400cf}},	//   usus_, _jush_, _mesk_, _ناال, 
   {{0x395de8f8,0x2139e8f9,0x71d80302,0x22583ebb}},	//   rsus_, _mush_, יוחד_, _lesk_, 
   {{0x395de8fa,0x31600399,0x3a3c0369,0x21300165}},	//   ssus_, zsiz_, pcup_, _mizh_, 
   {{0x395de8fb,0x3160036b,0x2130030a,0x7ad800c5}},	//   psus_, ysiz_, _lizh_, _बतिअ, 
   {{0x18a40209,0x2138054e,0x00000000,0x00000000}},	//   _галм, _nush_, --, --, 
   {{0x2ec40a28,0x2ed401bc,0xc5e402f5,0xa9040372}},	//   _वक्त, _दत्त, _গুহা_, _وبون, 
   {{0x21381497,0x22591d78,0x3864002f,0x942401f0}},	//   _aush_, _besk_, _idnr_, ёмбе, 
   {{0x3161e8fc,0x2258094f,0x21380c18,0xaab000bc}},	//   tsiz_, _cesk_, _bush_, झाएक, 
   {{0x76440248,0x22588a83,0x4644eb13,0x32e8010e}},	// [37320] _ifiy, _desk_, _узын_, lşyk_, 
   {{0x3161e8fd,0x2139e8fe,0x15ec05d7,0x00c400f5}},	//   rsiz_, _dush_, _चेयर_, блук_, 
   {{0x21300156,0x225803b2,0xf21c012d,0x00000000}},	//   _dizh_, _fesk_, पेज़_, --, 
   {{0xe8e007ae,0x3161e8ff,0x21300156,0xae740131}},	//   _thủy_, psiz_, _eizh_, تۇرغ, 
   {{0x213800ca,0x31601444,0xc1b00166,0x00000000}},	//   _gush_, qsiz_, _нәфы, --, 
   {{0x2130030a,0x225805c7,0x76440139,0xd00801f4}},	//   _gizh_, _zesk_, _lfiy, _беге_, 
   {{0x986c0201,0x7644022e,0xab6400a2,0x0b8801d5}},	//   _በአሁኑ_, _ofiy, _osüş, усли_, 
   {{0x764401e1,0x63a001bf,0x00000000,0x00000000}},	//   _nfiy, ælni, --, --, 
   {{0x3d885d28,0x213801b9,0x6738014f,0x8db40212}},	//   _محلی_, _xush_, _suvj, _усві, 
   {{0x77400020,0x6738014f,0x7645e900,0xc1980a7c}},	//   _የተመሰ, _puvj, _afiy, נשיי, 
   {{0x6738014f,0xe8e00208,0xa7fc013d,0x00000000}},	//   _quvj, _nhụy_, lgız, --, 
   {{0xe7380184,0x66f801e4,0xd7e8010a,0x00000000}},	//   леү_, rĉko, ăмне_, --, 
   {{0x05e801d5,0x00000000,0x00000000,0x00000000}},	//   уфни_, --, --, --, 
   {{0x2139e901,0x67d4030d,0xba14007b,0x599001c8}},	//   _rush_, _молу, _ايها_, _آڌيء, 
   {{0x225849a6,0x213005c7,0x61280024,0xd734009d}},	//   _pesk_, _rizh_, _užli, _мүэх_, 
   {{0xca1408b0,0x2139e902,0xf2c400db,0x00000000}},	//   _ﺳﻮﺕ_, _push_, псун, --, 
   {{0x21300156,0x2259e903,0x213801d5,0x66140a81}},	// [37330] _pizh_, _vesk_, _qush_, _گژھا, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x644406d6,0x2138039a,0x62340261,0x225867ae}},	//   _ifhi, _wush_, _мену, _tesk_, 
   {{0x2138d359,0xdb000332,0xdd94004e,0x00000000}},	//   _tush_, _orlá, жады, --, 
   {{0x21300489,0x7d6832b1,0x00000000,0x00000000}},	//   _tizh_, ушев_, --, --, 
   {{0x1b4805c1,0xdb0800d0,0x69ac28e0,0x00000000}},	//   азки_, ľníc, जिनी, --, 
   {{0xdb080122,0x2004026c,0x3864002f,0x00000000}},	//   žníc, _âli_, _rdnr_, --, 
   {{0xcf9006a9,0x5ac80166,0x8d600092,0x7ed40066}},	//   _קטן_, рлим_, ደባቸው_, _ازسا, 
   {{0xa7fc0724,0x6445e904,0x99dc02f0,0x25e8302b}},	//   mgıy, _ofhi, ybňu, _चेली_, 
   {{0xe6c4098d,0x1868147e,0xa7fc0205,0x00000000}},	//   _češć, јани_, lgıy, --, 
   {{0x6d440276,0x6844001f,0xc5e40154,0x61e003b9}},	//   ţiat, _የአምስ, _গুলা_, _əlla, 
   {{0x644406d6,0xd6295d25,0xc7a40aaf,0x00000000}},	//   _afhi, ионе_, زگىل_, --, 
   {{0x7ae8010a,0x64440332,0x00000000,0x00000000}},	//   _imgt, _bfhi, --, --, 
   {{0x97c40228,0x28f80108,0xba1400ec,0xcd94123b}},	//   _وقشو, _лечь_, _پيڙا_, חדשת_, 
   {{0x78a0003a,0xd37000c6,0x942401ec,0x988000de}},	//   _ianv, ظهر_, імбе, _mīļi_, 
   {{0x25b404cf,0x78a00156,0x959400d8,0x00000000}},	//   ñaló_, _hanv, _дрољ, --, 
   {{0x79980083,0x32dc0241,0x90c400fb,0x4638010f}},	// [37340] nwuw, _níye_, обае, _דעפע, 
   {{0x78a1e905,0xe8e001fb,0x7ae80036,0x2ae001e1}},	//   _janv, _thụy_, _lmgt, _mùkọ_, 
   {{0x78a000dc,0xed5001d3,0x4fe80798,0x00000000}},	//   _manv, ڑھا_, јмен_, --, 
   {{0x78a02005,0x00000000,0x00000000,0x00000000}},	//   _lanv, --, --, --, 
   {{0x2264012c,0x26d80023,0x28dc012c,0x78a00267}},	//   řský_, ëroi_, यसमि, _oanv, 
   {{0xa7fc71d5,0x78a02d88,0x00000000,0x00000000}},	//   rgız, _nanv, --, --, 
   {{0x799804ba,0x3f640cb6,0x00000000,0x00000000}},	//   ewuw, _миро_, --, --, 
   {{0x78a0bbd7,0x66cc002d,0x64a00327,0xff040276}},	//   _aanv, _jûkt, _iġiż, _деск_, 
   {{0x78a1e906,0x00000000,0x00000000,0x00000000}},	//   _banv, --, --, --, 
   {{0x23640fb7,0xd90de907,0x78a0f569,0xa774a15c}},	//   šlji_, هین_, _canv, плоч, 
   {{0x4a4455a8,0x78a1e908,0x4af80276,0xa71402dd}},	//   _днев, _danv, _кэдя_, змні, 
   {{0xfd540248,0x79980175,0x32dc01e1,0x00000000}},	//   _alaṣ, bwuw, _yíye_, --, 
   {{0x78a00007,0xdb0000c6,0x09980956,0x00000000}},	//   _fanv, _urlá, _خضاب_, --, 
   {{0x78a00998,0xd18c0023,0x00000000,0x00000000}},	//   _ganv, _ህርፋን_, --, --, 
   {{0xa7fc0e2d,0x2419caab,0x236400e5,0x00000000}},	//   ygıy, совы_, élj_, --, 
   {{0x290de909,0x78a065f8,0x236de90a,0xdb0001bf}},	//   loda_, _zanv, čej_, _erlæ, 
   {{0x78a01e7d,0x66cc000f,0x290c0009,0xf1cc00b8}},	// [37350] _yanv, _dûkt, ooda_, _īṣat_, 
   {{0x290de90b,0x644406d6,0x26c818a6,0x32dc01e1}},	//   noda_, _ufhi, _hoao_, _ríye_, 
   {{0xff040b87,0xb3780092,0x00000000,0x00000000}},	//   оядн, ርቲውን_, --, --, 
   {{0x53980bd4,0x26c9e90c,0x8c840022,0x00000000}},	//   _פירו, _joao_, ҟәуа_, --, 
   {{0x64a00327,0x290de90d,0xddd8007f,0xa7fc0e2d}},	//   _eġiż, koda_, pawō, rgıy, 
   {{0xacf80137,0xece80212,0x00000000,0x00000000}},	//   ончу_, оділ_, --, --, 
   {{0x290de90e,0x78a1e90f,0x00000000,0x00000000}},	//   doda_, _ranv, --, --, 
   {{0x78a1e910,0x26c80418,0x1a641888,0xdea00330}},	//   _sanv, _noao_, سیتی_, _سیتی, 
   {{0x78a03883,0x7c8449f3,0x290c022e,0x9d5402f2}},	//   _panv, _муже, foda_, _رنات, 
   {{0x26c8eba4,0xedb40933,0x78a1168b,0xae2000e1}},	//   _aoao_, _تحفظ, _qanv, _बरतन_, 
   {{0x9f4564f5,0x78a1e911,0x26c803f9,0xd7089b81}},	//   _älä_, _vanv, _boao_, йное_, 
   {{0x78a1e912,0xe8f82c12,0x00000000,0x00000000}},	//   _wanv, йлө_, --, --, 
   {{0x290c4437,0x78a1e913,0x66cc002d,0xd944010b}},	//   boda_, _tanv, _rûkt, _эели, 
   {{0x7af9e914,0x290de915,0x78a001bf,0x00000000}},	//   lnut, coda_, _uanv, --, 
   {{0x0874010f,0x61e801ef,0x00000000,0x00000000}},	//   _זעצט_, _želp, --, --, 
   {{0x7af9e916,0x26c801e4,0x27f80030,0x91e41149}},	//   nnut, _goao_, úrne_, побе, 
   {{0xdb014800,0x86780375,0x48e000bc,0x958400db}},	// [37360] _irlä, _הרפו, टोको_, _элпе, 
   {{0x7af9e917,0x2bec000d,0x00000000,0x00000000}},	//   hnut, _अइलू_, --, --, 
   {{0x7af9bfef,0x2cb80ba1,0x45240327,0xe5040127}},	//   knut, _òrdi_, _རྫིར_, _تبيي, 
   {{0x290db63d,0x257c02f0,0xfe4001f4,0x00000000}},	//   zoda_, _ušlý_, енцо, --, 
   {{0x7af803c6,0x290de918,0x1ea80597,0x00000000}},	//   dnut, yoda_, تالي_, --, 
   {{0xfce01d9c,0x7af9e919,0xd24c0133,0xab9400d4}},	//   ночо, enut, _شۆڕ_, дикі, 
   {{0x290c0bb8,0xbc6402eb,0x7af8007f,0x00000000}},	//   voda_, سمين_, fnut, --, 
   {{0x290de91a,0x00000000,0x00000000,0x00000000}},	//   woda_, --, --, --, 
   {{0x42900023,0x68ec022e,0x00000000,0x00000000}},	//   _ምጽኣት_, аldа, --, --, 
   {{0xf98c36e9,0x7af80194,0x00000000,0x00000000}},	//   ابي_, anut, --, --, 
   {{0x7af9e91b,0x00000000,0x00000000,0x00000000}},	//   bnut, --, --, --, 
   {{0x290de91c,0x2b4c0048,0x7b840150,0x7af80841}},	//   soda_, _itdc_, _ءالە, cnut, 
   {{0x290de91d,0x6f000076,0x00000000,0x00000000}},	//   poda_, _mjmc, --, --, 
   {{0x248c1b24,0xdb01e91e,0x2b4c007f,0x290c0e14}},	//   đemo_, _erlä, _ktdc_, qoda_, 
   {{0x02680006,0x00000000,0x00000000,0x00000000}},	//   йшай_, --, --, --, 
   {{0x38141203,0x00000000,0x00000000,0x00000000}},	//   _מקום_, --, --, --, 
   {{0x69c002fa,0xf1944676,0x00000000,0x00000000}},	// [37370] nxme, нить, --, --, 
   {{0xf1a401c0,0x7a40032e,0xb1140108,0x00000000}},	//   эрсн, _kító, емуш, --, 
   {{0x7af80606,0xf5b42e07,0x12440451,0xe374013d}},	//   ynut, _قصید, _ڪئپٽ, _юлны, 
   {{0x7af80175,0x00000000,0x00000000,0x00000000}},	//   xnut, --, --, --, 
   {{0x64d00574,0x628c030a,0x7af802f0,0x71a40153}},	//   _सकाळ, mfao, vnut, _заўз, 
   {{0x7b1400e4,0x80b40154,0x00000000,0x00000000}},	//   pãuk, ঃসঙ্, --, --, 
   {{0x7af993f3,0x6e20014b,0x7a400241,0x00000000}},	//   tnut, _ezmb, _nító, --, 
   {{0x7af80268,0x628c6729,0x00000000,0x00000000}},	//   unut, nfao, --, --, 
   {{0x2d58023a,0xa2880023,0x00000000,0x00000000}},	//   _нить_, _ምጽናዕ_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7af803c6,0xd90c0330,0x00000000,0x00000000}},	//   pnut, هیچ_, --, --, 
   {{0xa508025c,0xeb9000c6,0x6ab40006,0x1a640244}},	//   _གཉུག_, _حظك_, _псіх, _کیکی_, 
   {{0x18684170,0x628c0042,0x00000000,0x00000000}},	//   _дали_, dfao, --, --, 
   {{0xd7c804d3,0x613000fd,0xb884010b,0x00000000}},	//   _ووشه_, nılğ, _худй, --, 
   {{0xdc440953,0x04400acf,0x69dc01e4,0x206c0023}},	//   jūči, тесн, ŝret, _ኣምላኹ_, 
   {{0xfbac04c5,0x628c0142,0x00000000,0x00000000}},	//   _কথাত, gfao, --, --, 
   {{0x10a4014b,0x61e80432,0xd184009d,0x00000000}},	// [37380] миан, _ýell, ьлай, --, 
   {{0x2f1c0077,0x00000000,0x00000000,0x00000000}},	//   tígo_, --, --, --, 
   {{0x13084b2c,0x6440fc95,0x3cf027c6,0x00000000}},	//   _мной_, žlic, ्चने_, --, 
   {{0xfd0c065f,0x00000000,0x00000000,0x00000000}},	//   یجو_, --, --, --, 
   {{0xd1740139,0x644c032e,0x00000000,0x00000000}},	//   _юыны, _álið, --, --, 
   {{0xdc4400c0,0x00000000,0x00000000,0x00000000}},	//   būči, --, --, --, 
   {{0xf7649300,0x0ba800cf,0xd01001b9,0xbb4412e3}},	//   _جا_, تاشى_, _شلر_, ولون_, 
   {{0xfbcc1a59,0x32dc01e1,0xcf2401c8,0x00000000}},	//   شتى_, _yíya_, _آرسي, --, 
   {{0x8c4400db,0x4c8401d5,0xa93400c7,0x613000fd}},	//   _жезе, _олав, неиш, bılğ, 
   {{0x41b800c8,0x6d400072,0xdc4400b0,0x00000000}},	//   קציע, _iuma, _tūām, --, 
   {{0x66f4228c,0x988000de,0x67d41069,0x00000000}},	//   епну, _līķi_, хону, --, 
   {{0xc958022e,0x00000000,0x00000000,0x00000000}},	//   _дўк_, --, --, --, 
   {{0x6d41e91f,0x7af4067c,0x7aa0004e,0x00000000}},	//   _juma, èxte, _шицз, --, 
   {{0x6d41e920,0x46ac01ad,0x7a400248,0x2a6403c7}},	//   _muma, _जोरह, _tító, lamb_, 
   {{0x6d41e921,0x1cbc0003,0xa2940953,0x645404cc}},	//   _luma, _ཆོལ_, наві, rbzi, 
   {{0x6d41e922,0x2a65d91e,0xd04c03b9,0x00000000}},	//   _ouma, namb_, _ilbə, --, 
   {{0x6d41e923,0x26d80953,0x628de924,0x61300724}},	// [37390] _numa, ūros_, rfao, yılğ, 
   {{0xa11426c0,0x2a65e925,0x60c40211,0xdd9800a2}},	//   روات, hamb_, ujhm, _gyňy_, 
   {{0x657de926,0x6d40096b,0xf48401ec,0x26d80051}},	//   lush, _auma, _руын, okso_, 
   {{0x6d41e927,0x63a4036b,0x1e540023,0x670006b1}},	//   _buma, _ishn, _ዝበጽሓ, ैविक_, 
   {{0x6d41e928,0x657de929,0xad2403cc,0x3d1800bc}},	//   _cuma, nush, چىنى, यतले_, 
   {{0xad243ee0,0x224803e0,0xee3800d4,0xeb600092}},	//   نىنى, lcak_, фні_, _ማነጋገ, 
   {{0x657de92a,0x61300724,0x26d806ea,0x2248011f}},	//   hush, rılğ, kkso_, ocak_, 
   {{0x657c89a2,0x6d400831,0x2a640109,0xfeb842b5}},	//   kush, _fuma, gamb_, _باست_, 
   {{0x6d41386a,0x657de92b,0xee8402d5,0x00000000}},	//   _guma, jush, _шыро, --, 
   {{0x657de92c,0x09000220,0x63a401b9,0x57e861ac}},	//   dush, лпын, _oshn, здом_, 
   {{0x6d41e92d,0xac740e26,0x2a6401b3,0x224800d5}},	//   _zuma, _جاقش, bamb_, kcak_, 
   {{0x657de92e,0x2a640204,0x224801fa,0x27f800d0}},	//   fush, camb_, jcak_, úrna_, 
   {{0x657c0c10,0x6d400050,0x58d4722e,0x63a40784}},	//   gush, _xuma, _подт, _ashn, 
   {{0x26d9e92f,0x09f40375,0x8d6c0092,0x00000000}},	//   ëror_, _אמנם_, _አውቀው_, --, 
   {{0xb4051a47,0x141800c6,0x18680304,0x0874010f}},	//   түнд, سيرة_, _даһи_, _טעסט_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x42040408,0x63a46a41,0x8cc00764,0x657de930}},	// [373a0] енто_, _eshn, लामो, cush, 
   {{0x6d41e931,0x53a49808,0x84e0010a,0x988000ef}},	//   _ruma, _заоб, _боьж, _vīķi_, 
   {{0x4f78005b,0x48f8010f,0xef940066,0x00000000}},	//   ящая_, פּמא, خیزد, --, 
   {{0x6d41e932,0x040801dc,0x2248002e,0x00000000}},	//   _puma, _lượn, ccak_, --, 
   {{0xe4e80133,0x32e800a2,0x00000000,0x00000000}},	//   _رعیه_, bşyr_, --, --, 
   {{0x6d4018f7,0xac19e933,0xeb182645,0x101400c0}},	//   _vuma, молу_, दत्त_, _зьбя, 
   {{0x657de934,0x6d403887,0x2a64696c,0x32dc01e1}},	//   zush, _wuma, tamb_, _jíyo_, 
   {{0x657de935,0xa3c00490,0xbb5400b5,0x00000000}},	//   yush, ंमत_, _mのhd, --, 
   {{0x6d418341,0x657c8186,0xb9946cea,0x5fa000cf}},	//   _uuma, xush, евых_, _مەەم, 
   {{0x657de936,0x3e3001b9,0x2a640100,0xad6801f0}},	//   vush, _صفلر, samb_, _нағз_, 
   {{0xd1e0001f,0x657d1635,0x5cf402bf,0x0408004d}},	//   _ሐይቅ_, wush, _ряту, _dượn, 
   {{0x657de937,0x09e40a16,0xdef8044e,0xa7640228}},	//   tush, _поен, _ገበን_, нкүд, 
   {{0xc4842f7c,0x26d8c9d7,0x46300124,0x00000000}},	//   ىڭدە_, rkso_, ыҭир, --, 
   {{0x657c555f,0x32dc00d2,0x0408004d,0xc764075e}},	//   rush, _bíyo_, _gượn, _كابى, 
   {{0x657c04ce,0x00000000,0x00000000,0x00000000}},	//   sush, --, --, --, 
   {{0x41e50ee8,0xf3140323,0x657de938,0x61e8010e}},	//   ніза, гдсэ, push, _ýelk, 
   {{0x657de939,0x224825a9,0x41e40d30,0x55c071fe}},	// [373b0] qush, rcak_, хіва, _кәрз, 
   {{0x656de93a,0x00000000,0x00000000,0x00000000}},	//   _ivah, --, --, --, 
   {{0x63a40113,0x224803e0,0x00000000,0x00000000}},	//   _ushn, pcak_, --, --, 
   {{0xb1842b57,0xd3540375,0xdb0000ae,0x64d12b81}},	//   šťas, _שירי_, _tslé, _सकुश, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x656c0526,0x394c0254,0x32dc0248,0x116815b4}},	//   _mvah, _rtgs_, _yíyo_, _زلفی_, 
   {{0xe8100cf1,0x00000000,0x00000000,0x00000000}},	//   _ठुला_, --, --, --, 
   {{0x394c0115,0x656de93b,0xb8081025,0x04080051}},	//   _ptgs_, _ovah, _सुगम_, _sượn, 
   {{0xceb10b71,0xaac4278f,0xf4000276,0xf2d4010f}},	//   _דין_, اتىن, ăţii_, טעק_, 
   {{0x686c044e,0xadf5e93c,0x5d34121a,0x5ea80154}},	//   _ሰበይቲ_, _спуш, _شفائ, _ককটে, 
   {{0x656de93d,0x040801fb,0xf66407ee,0x00000000}},	//   _avah, _vượn, ленү, --, 
   {{0x656c0084,0x19583947,0x00000000,0x00000000}},	//   _bvah, _жады_, --, --, 
   {{0x040807ae,0x27940220,0x00000000,0x00000000}},	//   _tượn, _ұшыр, --, --, 
   {{0xe9d86563,0xe7ec05dc,0xe9d001e2,0x5fe028fe}},	//   _які_, _छेका_, _دغم_, पनाल, 
   {{0x398817c1,0x656db775,0x5748036b,0x53a00092}},	//   løs_, _evah, _ўзим_, ጎርዮስ_, 
   {{0x9f9c00d8,0xe8b000db,0x00000000,0x00000000}},	//   nçõe_, _نەۋج, --, --, 
   {{0x26180d01,0xd13003c7,0x39882b96,0xc240010b}},	// [373c0] _युपी_, لمر_, nøs_, рнук, 
   {{0x3ed001b9,0x00000000,0x00000000,0x00000000}},	//   یقلر, --, --, --, 
   {{0x656c004c,0x61e003b9,0x00000000,0x00000000}},	//   _zvah, _əlli, --, --, 
   {{0xdde801d5,0x00000000,0x00000000,0x00000000}},	//   کرمه_, --, --, --, 
   {{0x39880217,0xcd29e93e,0x8c600022,0x00000000}},	//   jøs_, وستن_, иҵаҵ, --, 
   {{0x39880fac,0x00000000,0x00000000,0x00000000}},	//   døs_, --, --, --, 
   {{0xaa941058,0x00000000,0x00000000,0x00000000}},	//   гийч, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x0d848b11,0x00000000,0x00000000,0x00000000}},	//   _шлан, --, --, --, 
   {{0x27f82d37,0x00000000,0x00000000,0x00000000}},	//   úrno_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2cac3b8e,0xe58401c0,0x7b8400db,0x0ae81541}},	//   _hadd_, лтгү, _جاكە, _غرضي_, 
   {{0xe8941fdf,0x6aa153dd,0x2f1c00ae,0x00000000}},	//   _баль, memf, rígh_, --, 
   {{0x6aa1e93f,0xf7f007d6,0xb9140022,0x61e80432}},	//   lemf, اسید, _иҭыӡ_, _ýeli, 
   {{0x37a4f71e,0x2cac0036,0x38c803e6,0x65c8036e}},	//   _атын_, _madd_, _تانی_, _bëhë, 
   {{0x2cade940,0xf8340375,0x248c012c,0x6aa02d2f}},	//   _ladd_, _בנות_, řem_, nemf, 
   {{0xe2982de5,0x656c1155,0xf8b400db,0x00000000}},	// [373d0] маң_, _uvah, _чөө_, --, 
   {{0x25a8103a,0xa6140022,0x2cac0142,0x00000000}},	//   _isal_, _изқә, _nadd_, --, 
   {{0xa3d40261,0x6aa0009a,0x00000000,0x00000000}},	//   _сонч, kemf, --, --, 
   {{0x630001ec,0x38600210,0x00000000,0x00000000}},	//   _اۋرە, ójrz_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2cac0bfa,0x5f44f427,0x00000000,0x00000000}},	//   _cadd_, _منسل, --, --, 
   {{0x2cacc990,0x30a402e8,0x00000000,0x00000000}},	//   _dadd_, _тряв, --, --, 
   {{0x6aa00b6f,0x59840212,0x7f4000d8,0x25a9e941}},	//   gemf, глиб, ínqu, _osal_, 
   {{0xad240058,0x2cac06f2,0x3ebc20ac,0x9eb401af}},	//   _چىقى, _fadd_, _inut_, _ишҡә, 
   {{0x2cac011f,0x398811c0,0xdce80219,0x00000000}},	//   _gadd_, røs_, _kveč, --, 
   {{0x3ebde942,0x6aa00921,0xf48459c7,0xab8403a6}},	//   _knut_, bemf, یاسی, _вучк, 
   {{0xeab000c6,0x35c408ca,0x0f7800df,0x00000000}},	//   _وعن_, қаҳҳ, עארב, --, 
   {{0x55f4046e,0x26c40046,0xaab4103c,0x7d000e89}},	//   учну, рғын_, _خصلت, onns, 
   {{0x3b1de943,0x0ac40124,0xdce82890,0xddd8007f}},	//   lluq_, _ашәҭ, _oveč, pawņ, 
   {{0x7d0003d5,0xdb008607,0x170401ed,0xe3b0aaab}},	//   inns, _islâ, _مہدی_, يرِ_, 
   {{0x3b1c0213,0x0764023b,0xe3540006,0xdb0001ef}},	//   nluq_, _саъй_, ртрэ, _oslí, 
   {{0x65680306,0xab9c0092,0xdce800de,0x6d440356}},	// [373e0] šehr, ወሰደው_, _aveč, ţiaz, 
   {{0x6aa0d059,0x3ebde944,0x3b1c01a9,0x00000000}},	//   zemf, _anut_, hluq_, --, 
   {{0xdb000309,0x6aa1e945,0x2cade946,0x00000000}},	//   _aslí, yemf, _radd_, --, 
   {{0x3ebc00ad,0xf15403e6,0x2cac002e,0x61e80210}},	//   _cnut_, _نێرد, _sadd_, _żele, 
   {{0xdce80010,0x2cac0334,0x9e65ac10,0x11d40166}},	//   _eveč, _padd_, شانن, _сюня, 
   {{0x33200135,0x6aa00b6f,0x3ebc06fd,0x4f642363}},	//   llix_, wemf, _enut_, _مارف, 
   {{0x6aa01cea,0x23840023,0xc1e801e1,0x00000000}},	//   temf, _ዝውዳእ_, _ọ̀ré, --, 
   {{0x8d7404a9,0x2cac0de2,0x7d001554,0x8cc007f7}},	//   _مائا, _wadd_, anns, लाहो, 
   {{0xdce88e70,0x6aa0016b,0xc865e947,0x2cac002b}},	//   _zveč, remf, лтни, _tadd_, 
   {{0x6aa0401f,0x2919e948,0x00000000,0x00000000}},	//   semf, ôra_, --, --, 
   {{0xcb0800db,0x00000000,0x00000000,0x00000000}},	//   _كيئن_, --, --, --, 
   {{0xc9843ab9,0xe5b4247f,0xa6341ed7,0x25a9e949}},	//   _буки, аймы, инні, _psal_, 
   {{0xfb1004fb,0xeb100073,0x33200327,0xc9d402f2}},	//   _اونج, ावीत_, dlix_, _حزاب, 
   {{0xf76c00aa,0x00000000,0x00000000,0x00000000}},	//   _ځاي_, --, --, --, 
   {{0x241831af,0x3320a270,0xf76c00ae,0x00000000}},	//   товы_, flix_, _فاي_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdce8bdd8,0xdb00000f,0xddc800bc,0xa5c46215}},	// [373f0] _sveč, _yslâ, _odeš, _төне, 
   {{0x660c01b3,0x3b1c0213,0xd1f0010c,0x3ebc007c}},	//   _ixak, zluq_, _ጂቡቲ_, _snut_, 
   {{0x672de94a,0x3320004e,0x351c0375,0xa2940111}},	//   _khaj, blix_, _אוזנ, _кані, 
   {{0xde94026a,0x68e8003e,0x1cbc0327,0x657c0009}},	//   радњ, hhdd, _ཆོང_, orsh, 
   {{0xddc486e5,0x3cf0190c,0x00000000,0x00000000}},	//   рбли, ्चले_, --, --, 
   {{0x61ecc28e,0x657c6f8b,0x00000000,0x00000000}},	//   mzal, irsh, --, --, 
   {{0xdce8e108,0x61ed864b,0x672cbb62,0xdfd401c4}},	//   _uveč, lzal, _ohaj, _товы, 
   {{0x61ec01f7,0x3ebd416b,0x00000000,0x00000000}},	//   ozal, _unut_, --, --, 
   {{0x660c02b9,0x7e681c06,0x7f44047e,0x3b1c00ac}},	//   _nxak, magp, _hujq, rluq_, 
   {{0x7e69e94b,0x672c0223,0x644001fa,0x33200007}},	//   lagp, _ahaj, žlij, zlix_, 
   {{0x660c606a,0x672c00dc,0x657c3b4d,0x61ec01d5}},	//   _axak, _bhaj, ersh, hzal, 
   {{0x672de94c,0x7e68bffa,0x61ede94d,0xa3b81fd2}},	//   _chaj, nagp, kzal, चिन_, 
   {{0x7af9e94e,0xa9046b5d,0x61ec01fa,0xdb005c17}},	//   miut, شبین, jzal, _islà, 
   {{0x7af9e94f,0x61ede950,0x68e803cb,0x2f1c03b2}},	//   liut, dzal, chdd, lígt_, 
   {{0x660cc1d2,0x7f440211,0x7e687bad,0x657de951}},	//   _exak, _nujq, kagp, arsh, 
   {{0x7af80d8d,0x672c0842,0x38640393,0x61ec01a9}},	//   niut, _ghaj, _henr_, fzal, 
  
   {{0x7645e952,0x61ede953,0x7e69e954,0xe3b0004b}},	// [37400] _igiy, gzal, dagp, يرې_, 
   {{0x7af9e955,0x7f4402d3,0x3d0c012d,0x54341291}},	//   hiut, _bujq, िवों_, _پرخر, 
   {{0x4fa5b425,0x7af9e956,0x61ede957,0x09d02f36}},	//   риев, kiut, azal, _तथ्य, 
   {{0x61ec0925,0x7f44014f,0x33200399,0x20040427}},	//   bzal, _dujq, qlix_, _žlic_, 
   {{0x61ec0034,0x7af8003a,0x32dc01e1,0x00000000}},	//   czal, diut, _níyi_, --, 
   {{0x066800d1,0x00000000,0x00000000,0x00000000}},	//   _ﻳﯩﻠﯩ, --, --, --, 
   {{0x7af89933,0x764419a0,0x00000000,0x00000000}},	//   fiut, _ogiy, --, --, 
   {{0x76455a68,0x37c81c82,0x7af8013c,0x657de958}},	//   _ngiy, ানাৰ, giut, yrsh, 
   {{0x3864003e,0x0c740214,0x09040212,0x68e80142}},	//   _benr_, _نداد, ичом, thdd, 
   {{0x428c1540,0x672de959,0x7644015c,0xdb00004e}},	//   _ነጻነት_, _shaj, _agiy, _eslà, 
   {{0x61ede95a,0x38640c67,0x38c45ab1,0x7af9e95b}},	//   zzal, _denr_, руын_, biut, 
   {{0x7af9e95c,0x672cd0dd,0x6e200076,0x657c8ee2}},	//   ciut, _qhaj, _kymb, trsh, 
   {{0x61ec005a,0x20c8076e,0x8624013d,0x00000000}},	//   xzal, रामध, рьне, --, 
   {{0xdb0c049b,0x61ede95d,0x76440337,0x657c0023}},	//   äköi, vzal, _egiy, rrsh, 
   {{0x77600369,0xc7640075,0x7e68079b,0x672de95e}},	//   _gwnx, _ئاتى, yagp, _thaj, 
   {{0xf2c5e95f,0x61ede960,0x660c01c0,0x672de961}},	//   осун, tzal, _txak, _uhaj, 
   {{0x05848317,0x660c4b2a,0x250804fb,0x6e2000bc}},	// [37410] _туйм, _uxak, _مردی_, _nymb, 
   {{0x77600369,0x7f44047e,0x00000000,0x00000000}},	//   _ywnx, _pujq, --, --, 
   {{0x7e688b14,0x6445e962,0x5f9579ea,0x291c014b}},	//   tagp, _ighi, сиет, _mkva_, 
   {{0xdb000030,0x00000000,0x00000000,0x00000000}},	//   _oslá, --, --, --, 
   {{0x6e21e963,0x7e68a928,0x7af80140,0x00000000}},	//   _cymb, ragp, viut, --, 
   {{0x64440003,0x6e20e042,0x7f44047e,0x7af80210}},	//   _jghi, _dymb, _tujq, wiut, 
   {{0x7e69e964,0x7af9e804,0x00000000,0x00000000}},	//   pagp, tiut, --, --, 
   {{0x9f04249f,0x291de965,0x6e20003a,0x61e800a2}},	//   _اورو, _akva_, _fymb, _ýels, 
   {{0x60d4ceba,0x7af9e966,0x68f89e91,0x64440268}},	//   _kozm, riut, _bmvd, _oghi, 
   {{0x644401dc,0x7af9e967,0x557401e0,0x00000000}},	//   _nghi, siut, ҙѳмт, --, 
   {{0xdb0000e4,0x3f912e5d,0x6e20036e,0x60d40419}},	//   _eslá, ntxu_, _zymb, _mozm, 
   {{0x60d423ee,0x6445e968,0x291c01e4,0x3f90005a}},	//   _lozm, _aghi, _ekva_, itxu_, 
   {{0x291c0270,0x644400f3,0x69c4025c,0x00000000}},	//   _fkva_, _bghi, _ġieg, --, 
   {{0xdff80950,0x18689cb8,0x98e5e969,0x3f540327}},	//   ्पाद_, _саки_, _دكتو, _iħuf_, 
   {{0xdce800d7,0x61280064,0x00000000,0x00000000}},	//   _opeľ, _užly, --, --, 
   {{0xdebc044e,0x7644bf65,0x6b9c28bc,0x60d402d0}},	//   ተድኣ_, _ugiy, _ärge, _aozm, 
   {{0x60d45b89,0x9f480030,0x5154014b,0xf53400f1}},	// [37420] _bozm, ľkým_, стбу, _وبخښ, 
   {{0x6e21e96a,0x60d51932,0x9f480306,0x00000000}},	//   _rymb, _cozm, žkým_, --, 
   {{0xdb0000b5,0x00000000,0x00000000,0x00000000}},	//   _islæ, --, --, --, 
   {{0x50640032,0x64440135,0x8fa4216c,0x00000000}},	//   ртҡа, _zghi, _қабе, --, 
   {{0x2dc84da8,0x21741188,0x8350158b,0x4718010f}},	//   шқан_, _мурр, _وپیا, נונג, 
   {{0xdcb001fb,0xbea000c7,0x00000000,0x00000000}},	//   _cả_, _ҭарк, --, --, 
   {{0x6e20045f,0x894c0248,0x00000000,0x00000000}},	//   _wymb, _ìjẹ̀, --, --, 
   {{0xa3b806e3,0x6e21e96b,0xfde400d1,0x00000000}},	//   चित_, _tymb, рдәк_, --, 
   {{0xba701075,0x60d49169,0xabb400c7,0x00000000}},	//   سايت, _yozm, сақә, --, 
   {{0xa7746be6,0x48a885c0,0xa7fc0205,0x00000000}},	//   олоч, утим_, ybıd, --, 
   {{0xf98c7935,0x00000000,0x00000000,0x00000000}},	//   وبی_, --, --, --, 
   {{0x49903028,0x6444026c,0xf1c807b7,0xdb00007b}},	//   _فیبر, _sghi, रमान, _tslá, 
   {{0x09bc009e,0x00000000,0x00000000,0x00000000}},	//   েনহা, --, --, --, 
   {{0x442401dc,0x1cbc0327,0xbae000cf,0x39105074}},	//   _ơn_, _ཆོབ_, _وكەي, _емір, 
   {{0x60d4489c,0x00000000,0x00000000,0x00000000}},	//   _rozm, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x60f802d5,0x60d5e96c,0x64440135,0x3158007b}},	// [37430] аная_, _pozm, _tghi, مجلة_, 
   {{0x64443336,0x70958587,0x3f900003,0x00000000}},	//   _ughi, зафф, ttxu_, --, 
   {{0x4425e96d,0x60d4007f,0x2508179e,0x00000000}},	//   _án_, _vozm, _مرگی_, --, 
   {{0xdea1e96e,0x3f9001c4,0x41c400c0,0x7c3000c7}},	//   بیری, rtxu_, _лёга, ҧҵах, 
   {{0x629c90e7,0x60d4496e,0x988000ef,0xdc68009d}},	//   _ibso, _tozm, _pūļi_, аалд_, 
   {{0xa0c423bb,0xdb7821fa,0x7c85e96f,0xc0c81357}},	//   _بيسو, асиш_, суде, _суме_, 
   {{0x629c0010,0x09d4015b,0xca2401ec,0xdcb00051}},	//   _kbso, _তেলা, _ﹼﺎﺭ_, _vả_, 
   {{0x788001ed,0x6e9400f3,0x00000000,0x00000000}},	//   kívü, _нису, --, --, 
   {{0xdd9404b4,0x5c74188b,0xdcb00051,0x00000000}},	//   _фазы, _млат, _tả_, --, 
   {{0x98a400d8,0x00000000,0x00000000,0x00000000}},	//   циое, --, --, --, 
   {{0xd7081064,0x629d4164,0x3da800cc,0x00000000}},	//   иное_, _obso, _খপিল, --, 
   {{0x629c0369,0xead4030d,0x00000000,0x00000000}},	//   _nbso, _нохь, --, --, 
   {{0xdce800ef,0x00000000,0x00000000,0x00000000}},	//   _opeļ, --, --, --, 
   {{0x629de970,0x00000000,0x00000000,0x00000000}},	//   _abso, --, --, --, 
   {{0x1cbc0135,0x00000000,0x00000000,0x00000000}},	//   _ཆོན_, --, --, --, 
   {{0x69940014,0x91e52930,0x629c00d7,0x38840356}},	//   _بێیس_, ообе, _cbso, şură_, 
   {{0xdb0000ee,0x00000000,0x00000000,0x00000000}},	// [37440] _islä, --, --, --, 
   {{0x00c455dc,0x505802d5,0xdbe4002e,0x7cec005c}},	//   олук_, ршая_, _lëñm, _hørf, 
   {{0xd25001d9,0x00000000,0x00000000,0x00000000}},	//   _ٲنس_, --, --, --, 
   {{0xb8d80003,0x847c0023,0x12b800d1,0x079800df}},	//   _ཅལ_, ሕዳርን_, ﻧﻠﻪﺭ, יסעל, 
   {{0xc27802e4,0x7f800131,0x61e8010e,0x00000000}},	//   _דרכי, كلەن, _ýelp, --, 
   {{0xcf59e971,0xda1c007d,0x00000000,0x00000000}},	//   _врач_, _पड़त_, --, --, 
   {{0x64400122,0x00000000,0x00000000,0x00000000}},	//   žliv, --, --, --, 
   {{0xbb140691,0xfbcc0451,0x69c4025c,0x2d80031c}},	//   يزيا_, ئتو_, _ġieb, ġieb_, 
   {{0xc3301203,0x0c79e972,0x00000000,0x00000000}},	//   ווה_, _نصاب_, --, --, 
   {{0xc7b80500,0x00000000,0x00000000,0x00000000}},	//   аём_, --, --, --, 
   {{0xebc4008e,0xc050011a,0x00000000,0x00000000}},	//   _хәлн, וזת_, --, --, 
   {{0x8cc020f0,0x00000000,0x00000000,0x00000000}},	//   लाको, --, --, --, 
   {{0xb8d00133,0x674401d3,0x00000000,0x00000000}},	//   ستیش, _کرتے, --, --, 
   {{0xdb000139,0x61e8012d,0x00000000,0x00000000}},	//   _eslä, _żelo, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6b500201,0x91d40729,0x490005f5,0x27f80419}},	//   _ሚኒስቴ, _সেইখ, _хүүг, úrnu_, 
   {{0xdfd116e4,0xf194023a,0x91c01a98,0x629c0332}},	// [37450] کيا_, мить, нәрл, _vbso, 
   {{0x250800f2,0x00000000,0x00000000,0x00000000}},	//   _دربی_, --, --, --, 
   {{0xdca400d1,0xeff00092,0x6e240327,0xf0e800d1}},	//   җайи, _ፀባይ_, żibl, غىمى_, 
   {{0x9408016b,0xdd940209,0x9e341f39,0xd434011a}},	//   rebɔ_, зады, пееч, _מרתק_, 
   {{0x7ced3239,0xa3b803f8,0xd254011a,0x00000000}},	//   _jørg, चिव_, _משרה_, --, 
   {{0x64541570,0x361c0a1e,0x11d80375,0x00000000}},	//   nczi, בודד, _החשב, --, 
   {{0x2d500428,0x628c0286,0x8c41b814,0xdec40209}},	//   _eàe_, ogao, неше, _нәдо, 
   {{0x628de973,0x5ac9e974,0x20c940c6,0x1cbc025c}},	//   ngao, слим_, रावध, _ཆོམ_, 
   {{0xceb0dbff,0x7cec20e4,0x7e79e975,0x3f540003}},	//   _אין_, _nørg, _idup, _wħud_, 
   {{0x7cec2dba,0xddcc0153,0x3940007c,0x00000000}},	//   _sørf, škųj, öjs_, --, 
   {{0x628c5bae,0x3f540003,0x61e80327,0x888000e5}},	//   kgao, _uħud_, _żell, ریٹن, 
   {{0x7cec1477,0x6844001f,0xa3c000e1,0xdb0001e3}},	//   _børg, _ከአምስ, ूमन_, _arlö, 
   {{0x7ae8005f,0x06056c20,0x4ab40956,0x00000000}},	//   _ilgt, зняк_, _رُوح_, --, 
   {{0x395c26c2,0xdb000036,0x7bc400d8,0x7cec5522}},	//   mpus_, _oplë, _àjus, _dørg, 
   {{0x7e780552,0x395de976,0x7cec00b5,0xb4cc03ce}},	//   _odup, lpus_, _tørf, _रची_, 
   {{0xdb0048b3,0x645405d5,0x628c2b4b,0x00000000}},	//   _erlö, aczi, ggao, --, 
   {{0xd184113e,0x31440107,0x00000000,0x00000000}},	// [37460] ялай, ддаҳ, --, --, 
   {{0x7e782b1d,0x7cec0feb,0x45f8011a,0x00000000}},	//   _adup, _jørd, _להפג, --, 
   {{0xcf4406a6,0x7cec01bf,0x8e48007b,0x00000000}},	//   чней, _mørd, ملاك_, --, 
   {{0x7ceceda6,0x395d6d7f,0xd17400fd,0x0dc804b3}},	//   _lørd, kpus_, _ныгы, йлей_, 
   {{0xdde801f7,0x00000000,0x00000000,0x00000000}},	//   يرهه_, --, --, --, 
   {{0x7ced6c24,0x7ae80037,0x7e7800d7,0x9f4000c7}},	//   _nørd, _algt, _edup, nyhê_, 
   {{0xab386be6,0x7e780139,0x102400cf,0x3160022e}},	//   опку_, _fdup, _رةسپ, lpiz_, 
   {{0xd1d0001f,0x00000000,0x00000000,0x00000000}},	//   _የሞት_, --, --, --, 
   {{0x7ae803b2,0x0af001c6,0xa6b400cc,0xba700133}},	//   _dlgt, _үүлэ, টামট, ژایت, 
   {{0x7ae80024,0x7cec2b96,0x00000000,0x00000000}},	//   _elgt, _rørg, --, --, 
   {{0x7cec708a,0x395c003a,0x27f80e89,0x8a44009f}},	//   _sørg, apus_, àrn_, _فَان, 
   {{0xca7401ee,0x00000000,0x00000000,0x00000000}},	//   _хужы, --, --, --, 
   {{0x7ced6cb5,0xe89400c0,0x8464011c,0x00000000}},	//   _førd, _жаль, зъбе, --, 
   {{0x7cec75f9,0xb978011a,0x00000000,0x00000000}},	//   _gørd, _פנוי, --, --, 
   {{0x290d057f,0x6454a3cc,0xa2940024,0x3898010f}},	//   mnda_, rczi, маві, _ליגנ, 
   {{0x0a48001f,0x628c0cf4,0x7cec01bf,0x72d4009b}},	//   _መሳሪያ, ugao, _iøre, носф, 
   {{0x7cecf940,0x290c0c86,0x26c9ab2a,0xdb00143a}},	// [37470] _høre, onda_, _inao_, _uslå, 
   {{0x7cec019b,0x0465761a,0x290de977,0x712400d1}},	//   _køre, _этим, nnda_, ۈرەل, 
   {{0x290de978,0x00000000,0x00000000,0x00000000}},	//   inda_, --, --, --, 
   {{0x7cec0217,0x290c0066,0xd37000ec,0x00000000}},	//   _møre, hnda_, _جهٽ_, --, 
   {{0x7cec4606,0x26c9ab2a,0x00000000,0x00000000}},	//   _løre, _mnao_, --, --, 
   {{0xa2d806ab,0x59280327,0xf5300092,0x00000000}},	//   फॉर्, _ཤེེས_, _በቅንነ, --, 
   {{0x290c0198,0xdbf000bc,0x200400a2,0x9f4000e4}},	//   dnda_, přím, _äli_, nyhë_, 
   {{0x290de979,0x7e785055,0x6b852374,0x7cec0217}},	//   enda_, _udup, رشىل, _sørd, 
   {{0x290c0008,0xadbc010a,0x00000000,0x00000000}},	//   fnda_, _латi, --, --, 
   {{0x395dd02c,0x26c8325f,0x7cec05ac,0x290c04ba}},	//   rpus_, _anao_, _børe, gnda_, 
   {{0x16a9e97a,0x395de97b,0x7cec05ac,0x426802d3}},	//   овни_, spus_, _vørd, ታትነት_, 
   {{0x7cec4c2e,0x395c1612,0xdb000221,0x7a840220}},	//   _døre, ppus_, _oplé, _ءشام, 
   {{0xdce80640,0x3b000248,0x7cec01bf,0x7d00062c}},	//   _cveć, _eèpè_, _tørd, oins, 
   {{0x7cede97c,0x26c80851,0x63540006,0x7d002720}},	//   _føre, _enao_, _sąna, nins, 
   {{0x7cec04ce,0xd9b401d9,0x394400a2,0x394c0f85}},	//   _gøre, _رٔژھ, _iins_, _hugs_, 
   {{0x3944008c,0xdb0000ae,0x98800171,0x00000000}},	//   _hins_, _bplé, _pūķi_, --, 
   {{0x7d003142,0x394c3d19,0x39440036,0x7cec21e3}},	// [37480] kins, _jugs_, _kins_, _mørb, 
   {{0x7d01e97d,0x26c81326,0x394de97e,0x3945e97f}},	//   jins, _znao_, _mugs_, _jins_, 
   {{0x26c8089c,0x394c0493,0x4f7800c9,0x635405da}},	//   _ynao_, _lugs_, ющая_, _tąna, 
   {{0x6b98074d,0x7d000e78,0x7cec00b5,0x91e401b9}},	//   vtvg, eins, _nørb, _жоме, 
   {{0x290c09a5,0x7d01e980,0x00000000,0x00000000}},	//   ynda_, fins, --, --, 
   {{0xa3e405f9,0x3944847c,0x00000000,0x00000000}},	//   बैक_, _nins_, --, --, 
   {{0x3b1c0369,0x290c06ea,0xdc8001b9,0x394de981}},	//   fouq_, vnda_, уқхо, _augs_, 
   {{0x7cec1088,0x3b1c0369,0x290c0223,0x33200369}},	//   _røre, gouq_, wnda_, noix_, 
   {{0x7d01e982,0x7cede983,0x394450eb,0x290c7fa5}},	//   bins, _søre, _bins_, tnda_, 
   {{0x3945e984,0x290de985,0x394c1c1d,0x753c01fa}},	//   _cins_, unda_, _dugs_, jmrz, 
   {{0x3945e986,0xdce9354e,0x6d48f0dc,0x290de987}},	//   _dins_, _sveć, _iida, rnda_, 
   {{0x394536e4,0x6d49d5bf,0xfbd00302,0xa7fc0205}},	//   _eins_, _hida, _שתף_, bbın, 
   {{0x3945e988,0x6d49e989,0x37c803d4,0xbb4000f0}},	//   _fins_, _kida, ানগৰ, _рецк, 
   {{0x6d49e98a,0x22580334,0x394400c0,0x00000000}},	//   _jida, _sfsk_, _gins_, --, 
   {{0x6d49e98b,0x6f0003ac,0xdb01e98c,0x00000000}},	//   _mida, _ommc, _splé, --, 
   {{0x7d01e98d,0x6d49e98e,0x26c801c8,0xa3e400e1}},	//   zins, _lida, _unao_, बैग_, 
   {{0x35b40c26,0x7d01e98f,0xdce80989,0x6d5c02b1}},	// [37490] _абыр, yins, _uveć, _ōran, 
   {{0x6d49e990,0x656c18a6,0xe7d0045e,0x673c007c}},	//   _nida, _iwah, ানীয, lmsj, 
   {{0x656de991,0x3b1c0097,0x3320004e,0xd4c0008e}},	//   _hwah, youq_, boix_, _сөяк, 
   {{0x7d001bb7,0x6d49e992,0x9db8b71d,0xa7fc05d1}},	//   wins, _aida, зыку_, ybın, 
   {{0x7d01e993,0x6d49e994,0xdb00dd10,0xbd680220}},	//   tins, _bida, _uplé, ірде_, 
   {{0x6d49e995,0x394c2d21,0x656c0526,0x7cec08fb}},	//   _cida, _rugs_, _mwah, _sørb, 
   {{0xa3c011b1,0x39440493,0x656db3f6,0x1be9e996}},	//   ूमि_, _rins_, _lwah, ядки_, 
   {{0x7d001fcd,0x3944ee45,0x6d49e997,0x656de998}},	//   sins, _sins_, _eida, _owah, 
   {{0x656c0943,0x7d01e999,0xc9a49d9c,0x3945e99a}},	//   _nwah, pins, евые_, _pins_, 
   {{0x6d49e99b,0xa3c00316,0x7d0037cf,0xddc80216}},	//   _gida, ूमा_, qins, _kdež, 
   {{0x3945e99c,0x656de99d,0x62800270,0xd7040a31}},	//   _vins_, _awah, _ēlon, езни, 
   {{0x3945e99e,0x6d49e99f,0x656d29cd,0x394cba52}},	//   _wins_, _zida, _bwah, _tugs_, 
   {{0x332006af,0x6d48f5a0,0xfafc00e8,0x3944045a}},	//   voix_, _yida, _ňëw_, _tins_, 
   {{0x6d480d81,0xddc9a2de,0x79981bce,0x00000000}},	//   _xida, _odež, mtuw, --, 
   {{0x03a0bbdd,0x656c0214,0x7999e9a0,0xd8240395}},	//   лиро, _ewah, ltuw, _ядки, 
   {{0x6e24025c,0x8fd00124,0x032001c4,0x00000000}},	//   żibi, қәгә, гдсн, --, 
   {{0x656c0cfd,0x7999e9a1,0x90c463eb,0xb24401e0}},	// [374a0] _gwah, ntuw, нбае, тмаһ, 
   {{0x42200763,0x9a3c001f,0x8f740220,0x00000000}},	//   удув, _የኢንዱ, еуді, --, 
   {{0x4ea46dc3,0x53a40261,0x33200129,0x00801171}},	//   ерла, _џамб, poix_, улхо, 
   {{0x6d481334,0x79981c04,0x00000000,0x00000000}},	//   _sida, ktuw, --, --, 
   {{0x6d49e9a2,0xb14400c7,0xc330011a,0x00000000}},	//   _pida, _аҽал, _תור_, --, 
   {{0x6d49e9a3,0x7dc016ac,0xb7b801e1,0xbd8400cf}},	//   _qida, اقون, _ọ̀wo, رنىن_, 
   {{0x6d49e9a4,0x57c82d3b,0xfba40108,0xa3b80d2e}},	//   _vida, िमोह, етый_, चिए_, 
   {{0x6d49e9a5,0x799801f2,0x2739571f,0x3f840113}},	//   _wida, ftuw, méng_, ánue_, 
   {{0x6d49e9a6,0x79981c06,0xad840372,0x2739e9a7}},	//   _tida, gtuw, _جازۇ, léng_, 
   {{0x656d8e3b,0x391000ee,0x6d480857,0xa7fc0166}},	//   _rwah, лмыр, _uida, bbıl, 
   {{0x0a680440,0x656ccebf,0x2738551a,0xe94401b9}},	//   _ерли_, _swah, néng_, _یرتی, 
   {{0x2cbc0175,0x00000000,0x00000000,0x00000000}},	//   ldvd_, --, --, --, 
   {{0x48e4db20,0x27397106,0x8a040354,0x673c007c}},	//   _подв, héng_, _язде, rmsj, 
   {{0x273800d5,0x00000000,0x00000000,0x00000000}},	//   kéng_, --, --, --, 
   {{0x69c01347,0x7cec143a,0x273806fd,0x00000000}},	//   lvme, _jøra, jéng_, --, 
   {{0x656c015c,0x27380098,0x57a401af,0x00000000}},	//   _twah, déng_, _рышҡ, --, 
   {{0x656de9a8,0xf5a800d1,0x00000000,0x00000000}},	// [374b0] _uwah, _пәрқ_, --, --, 
   {{0x69c40135,0x26d80010,0x31c40114,0x2d800003}},	//   _ġiel, ljso_, ћств, ġiel_, 
   {{0x2d8001a2,0x5f940801,0x248000d8,0x273800d5}},	//   šiel_, тиет, _idhm_, géng_, 
   {{0x26d80010,0x7998fd3d,0x6f640214,0x09b400cc}},	//   njso_, ytuw, اهنم, _জপনা, 
   {{0xa3b87f1a,0x5d18109a,0xaac400bc,0x2f1c00e5}},	//   चिक_, мікс_, वयनक, nígy_, 
   {{0xdca4ad0e,0x25a8004e,0xee382626,0x06680131}},	//   таки, _mpal_, хні_, _ﻳﯩﻐﯩ, 
   {{0x27380098,0xacf40214,0x3034005b,0x5bbc013a}},	//   céng_, دسنت, _берё, ्मेव, 
   {{0x7cec0158,0x7999e9a9,0x00000000,0x00000000}},	//   _døra, ttuw, --, --, 
   {{0xdc740209,0x00000000,0x00000000,0x00000000}},	//   _агзы, --, --, --, 
   {{0x3eade9aa,0x7ceccefd,0x799800e8,0x57e868dd}},	//   legt_, _føra, rtuw, ддом_, 
   {{0x25a97fa7,0x7999e9ab,0x7cec3c02,0x00000000}},	//   _apal_, stuw, _gøra, --, 
   {{0x3eac04e6,0x00000000,0x00000000,0x00000000}},	//   negt_, --, --, --, 
   {{0x267801c0,0x4e78008f,0x273801c7,0x5d7800df}},	//   эсээ_, וארצ, zéng_, ואָק, 
   {{0x3eac0036,0x2738003e,0x3f540166,0x00000000}},	//   hegt_, yéng_, _oçu_, --, 
   {{0x25a9e9ac,0xddc80003,0x47d00592,0x3f540135}},	//   _epal_, _adeż, _نيور, _sħun_, 
   {{0xb4f40137,0x2ed01a55,0x00000000,0x00000000}},	//   түүч, _सचेत, --, --, 
   {{0x2cbc04ce,0x3f540724,0x434065f5,0x3eade9ad}},	// [374c0] ydvd_, _açu_, ретв, degt_, 
   {{0x27393dfd,0x4f6400e3,0x00000000,0x00000000}},	//   téng_, ناصف, --, --, 
   {{0xee841248,0xdb0029d3,0x3eac002f,0x8f7412fa}},	//   гълү, _aplí, fegt_, тузі, 
   {{0x71740447,0x2d800029,0x2739e9ae,0x69c402d5}},	//   _مۇرا, šiem_, réng_, _šiem, 
   {{0x7cec03d4,0x273801c7,0x00000000,0x00000000}},	//   _søra, séng_, --, --, 
   {{0x2739e9af,0x0ba407d8,0x00000000,0x00000000}},	//   méne_, вшим, --, --, 
   {{0x4044f35c,0x27380de2,0x69a4000d,0xfce00798}},	//   _апро_, léne_, _कहही, ројо, 
   {{0x7ac13718,0x2cbcd7aa,0x7cec0174,0x00000000}},	//   асье, sdvd_, _vøra, --, 
   {{0xc864ac62,0x27381bce,0x443c0208,0x6aa404b3}},	//   ктни, néne_, ̀u_, _ەشتە, 
   {{0x48a86141,0x7cec005c,0x00000000,0x00000000}},	//   фтим_, _hørn, --, --, 
   {{0x8c4409a5,0x7cec01bf,0xe7d00154,0x273800e4}},	//   _реже, _kørn, ান্য, héne_, 
   {{0x25a8002e,0x2738114f,0x00000000,0x00000000}},	//   _ppal_, kéne_, --, --, 
   {{0x7cec5522,0xb604010b,0xf6280212,0x00000000}},	//   _mørn, аярк, віри_, --, 
   {{0x3ead2fb7,0x00000000,0x00000000,0x00000000}},	//   zegt_, --, --, --, 
   {{0x80d800cc,0x7f540076,0x00000000,0x00000000}},	//   ণসম্, xqxq, --, --, 
   {{0x3265e9b0,0x3f54003d,0x00000000,0x00000000}},	//   итув, _dħul_, --, --, 
   {{0x2458084c,0x25a80219,0x273800e8,0xb5a400c0}},	// [374d0] _папь_, _upal_, géne_, _крэй, 
   {{0x3eac04ef,0x00000000,0x00000000,0x00000000}},	//   wegt_, --, --, --, 
   {{0x7cede9b1,0x3ead1378,0xfe7002da,0x657c02d0}},	//   _børn, tegt_, لدش_, lssh, 
   {{0xd04c043b,0xde180131,0xad2401b9,0x3eac0036}},	//   _kobɛ, ىقات_, یروو, uegt_, 
   {{0x657c1c42,0x3ead1ea3,0x7c700131,0x6e9401af}},	//   nssh, regt_, иғач, ричу, 
   {{0x7c85e9b2,0xd04c013f,0x11682ab4,0x657c00b5}},	//   туде, _mobɛ, _سلفی_, issh, 
   {{0x7cec01bf,0xafe400cf,0x00000000,0x00000000}},	//   _førn, _коёл, --, --, 
   {{0x6d680054,0xb91401f2,0x5e440014,0x7cec0162}},	//   ärañ, bagọ_, _منزٕ, _gørn, 
   {{0xa2e400fe,0x00000000,0x00000000,0x00000000}},	//   _নগাও, --, --, --, 
   {{0x5d344028,0x657c02d0,0x00000000,0x00000000}},	//   _صفائ, dssh, --, --, 
   {{0xd7080953,0xdea803f9,0x273800d0,0xd7c842f4}},	//   енне_, _sheƙ, zéne_, روحه_, 
   {{0x15b80228,0x195809a5,0x79c401f0,0xdb1001e1}},	//   ныгы_, _зады_, _ақиб_, _ìgàl, 
   {{0x98a49398,0x18a5e9b3,0xa978010a,0x8ab4011a}},	//   _биле, _балм, _айчу_, _תהנו_, 
   {{0x97c4152f,0x6d5c00b0,0x7bc003b2,0x273800e4}},	//   _مقتو, _ōrak, ovnu, véne_, 
   {{0x045400c6,0xb7b000fd,0xca240150,0xe354009d}},	//   الفة_, _төпч, _ﹼﺎﺕ_, иттэ, 
   {{0x934400f7,0x51640137,0x273800e4,0x00000000}},	//   унбе, лүмү_, téne_, --, 
   {{0xf8b40574,0x3bc00f77,0x00000000,0x00000000}},	// [374e0] _असाय, _lıq_, --, --, 
   {{0x45f80375,0x63b40083,0x2d800030,0x273800d0}},	//   _נהיג, bwzn, šiek_, réne_, 
   {{0x20544143,0x3bc000fd,0x903400d3,0x00000000}},	//   ртур, _nıq_, ухач, --, 
   {{0x6b9ca98b,0x69a400c5,0x00000000,0x00000000}},	//   _ärgi, _कहली, --, --, 
   {{0xf76400f8,0xc2780bd4,0x7f800131,0x7bc00162}},	//   _گا_, _ארכי, للەن, evnu, 
   {{0x7cec05ac,0xf0040116,0xdb00659a,0xdb246e92}},	//   _døro, _күзи, _osló, یووی, 
   {{0xf765e9b4,0x7cec366f,0xae0402e5,0xc1a40220}},	//   _دا_, _tørn, _शेरन_, _ﺷﻴﺰﺍ, 
   {{0x7cede9b5,0xaa54039b,0xde9400cf,0x00000000}},	//   _føro, швиш, _ەجەب, --, 
   {{0x7cc80171,0x89d41291,0x00000000,0x00000000}},	//   _bērē, اتعط, --, --, 
   {{0xc1980375,0x00000000,0x00000000,0x00000000}},	//   עשיי, --, --, --, 
   {{0xfb8407d6,0x7cec0fac,0x7b840220,0x657c035a}},	//   _مدنی, _mørl, _مانە, wssh, 
   {{0x657c0857,0x00000000,0x00000000,0x00000000}},	//   tssh, --, --, --, 
   {{0x7a780a1e,0xe7b0012c,0x09e402bf,0x657c0221}},	//   _טראס, _जनकप, _щодн, ussh, 
   {{0xa6b40729,0xf76cbd87,0x657c127b,0xdb000022}},	//   টাইট, _کاو_, rssh, _iplá, 
   {{0x47846518,0x899001af,0x00000000,0x00000000}},	//   _сылб, _тиҙє, --, --, 
   {{0xd04c013b,0x657c01f5,0xa5c402dd,0xe214e9c6}},	//   _wobɛ, pssh, _көге, амбы, 
   {{0xa074036b,0x375001d9,0x40880114,0xb7b80241}},	// [374f0] игач, _پھۯس, ељем_, _ọ̀ro, 
   {{0x7cec08fb,0x82340137,0x40740137,0x7bc000d7}},	//   _røro, _ەرسا, الاڭ_, yvnu, 
   {{0x7ced6ca0,0xa3d40cb6,0x00000000,0x00000000}},	//   _søro, _тонч, --, --, 
   {{0xa195e9b6,0xdb0002fb,0x65c400b8,0xa7fc0205}},	//   _камч, _oplá, _gįhã, mcıd, 
   {{0x7cec0579,0x7bc00218,0x127800c8,0x41e40024}},	//   _førl, wvnu, _בארע, _сіна, 
   {{0x7cec005c,0xb63800df,0x00000000,0x00000000}},	//   _gørl, ארדס_, --, --, 
   {{0x4c900640,0xa7fc2ca8,0x23800153,0x0c7000db}},	//   цијс, ncıd, nėj_, زگلد, 
   {{0xdb0001e7,0x1ae463dd,0x5984030d,0xf8b41a4e}},	//   _bplá, роим, алиб, _असहय, 
   {{0x7cec01bf,0x7cc800ef,0x2918022e,0x00000000}},	//   _hørm, _pērē, еra_, --, 
   {{0x3ebde9b7,0xe9a81564,0xfd11cc4f,0x7cec0162}},	//   _haut_, ادين_, _اجر_, _kørm, 
   {{0x3ebc0029,0x7cec0174,0x3f90022a,0x7cc800ef}},	//   _kaut_, _jørm, nuxu_, _vērē, 
   {{0xdb0000db,0x3ebde9b8,0x00000000,0x00000000}},	//   _eslò, _jaut_, --, --, 
   {{0x3ebde9b9,0x7cc800e2,0x00000000,0x00000000}},	//   _maut_, _tērē, --, --, 
   {{0xdb0000ae,0x00000000,0x00000000,0x00000000}},	//   _tsló, --, --, --, 
   {{0x7cede9ba,0x18a40166,0x7cfc00c0,0x00000000}},	//   _rørl, _баһм, _išrė, --, 
   {{0x3ebde9bb,0x7cec03a1,0xd265e9bc,0x02840b7e}},	//   _naut_, _sørl, ркай, ийск_, 
   {{0x26c40085,0xa7fc00a2,0x00000000,0x00000000}},	// [37500] ɛlo_, daıy, --, --, 
   {{0x273842b4,0x74f40150,0xddc80356,0x23800064}},	//   ména_, _اۋسا, _sfeş, bėj_, 
   {{0x2739e9bd,0x3ebde9be,0x96d800bc,0xa2e403d4}},	//   léna_, _baut_, _बचाउ, _নগৰখ, 
   {{0x3ebde9bf,0x7cec2f48,0xebd80116,0x00000000}},	//   _caut_, _dørm, ғдиш_, --, 
   {{0x2d800221,0x3ebccae1,0x7cec005c,0x27384e6e}},	//   éie_, _daut_, _tørl, néna_, 
   {{0x7cec0158,0x25ac9c11,0xac19e9c0,0x00000000}},	//   _førm, çeli_, лолу_, --, 
   {{0x3ebde9c1,0xdb000232,0x27380129,0x2ec401af}},	//   _faut_, _splá, héna_, _гөлм, 
   {{0x8d7403e6,0x27380438,0x3ebc00c0,0x99880064}},	//   _نائا, kéna_, _gaut_, _šaš_, 
   {{0xdb00037e,0x27380098,0xbb44007b,0x4d48004e}},	//   _oplæ, jéna_, جلين_, _апан_, 
   {{0x3ebc005a,0x27380438,0xc7c5e9c2,0xbad80150}},	//   _zaut_, déna_, асми, _ﺃﻗﺼﺎ, 
   {{0x00540375,0xd7640133,0x0134011a,0x00000000}},	//   ישית_, ینیی, שרית_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x27380098,0x26c400bc,0xf98c4710,0xdb0002f0}},	//   géna_, ělo_, _قبو_, _uplá, 
   {{0x248c03fa,0x3f900009,0xb978010f,0x06681870}},	//   ßem_, yuxu_, _ינדי, _ﺳﯩﻨﯩ, 
   {{0x290de9c3,0xf76c1473,0x38c8965c,0x7cec03cd}},	//   mida_, _قاي_, _جانی_, _børj, 
   {{0x290de9c4,0x248c0db1,0x2738003e,0x7cec072b}},	//   lida_, şem_, béna_, _rørm, 
   {{0x672de9c5,0x3ebc4460,0x7cec365a,0x290c0108}},	// [37510] _ikaj, _raut_, _sørm, oida_, 
   {{0x290de9c6,0x3ebde9c7,0x4aa400dc,0x356802e8}},	//   nida_, _saut_, क्तव, _трън_, 
   {{0x3ebde9c8,0x7cede9c9,0x1fb80220,0xf770008f}},	//   _paut_, _førj, _ءﺑﯩﺰ_, ַקס_, 
   {{0x290de9ca,0x02a4a44d,0x8f6801ed,0x27f800d0}},	//   hida_, _тром, النے_, úrny_, 
   {{0x3ebc20ef,0x672c9511,0x2be400cc,0xadbc003b}},	//   _vaut_, _mkaj, _কেলৈ_, кацi, 
   {{0x61ec2935,0x290de9cb,0xdb2008a5,0x00000000}},	//   myal, jida_, _útúr, --, 
   {{0x290de9cc,0xdd9000dd,0x61ec2ac2,0x7cec00b5}},	//   dida_, زوں_, lyal, _hørk, 
   {{0x672c1dc9,0x3ebc04cc,0x290c07c5,0x3960013e}},	//   _nkaj, _uaut_, eida_, ониҳ, 
   {{0x290de9cd,0x61ede9ce,0x00000000,0x00000000}},	//   fida_, nyal, --, --, 
   {{0x290de9cf,0x672db6b2,0x61ec0d04,0x4aa40037}},	//   gida_, _akaj, iyal, _कउअव, 
   {{0xad2416a0,0x273800d5,0x00000000,0x00000000}},	//   _بىلى, wéna_, --, --, 
   {{0x61ec2f99,0x2739e9d0,0x290c006f,0x05c00490}},	//   kyal, téna_, aida_, शिंब, 
   {{0x7af80099,0x7cec01bf,0x6441e9d1,0x00000000}},	//   mhut, _nørk, ýlin, --, 
   {{0x61ede9d2,0x27383847,0xd7c83669,0x09e1e9d3}},	//   dyal, réna_, _موته_, _хошн, 
   {{0x27387cd8,0xf76c01d9,0xa8a40798,0x7af8000d}},	//   séna_, _کاڈ_, _фрчк, ohut, 
   {{0x7cede9d4,0x27380098,0x61ec03e0,0x00000000}},	//   _børk, péna_, fyal, --, 
   {{0x61ec01ed,0xdb000166,0x527401d5,0x00000000}},	// [37520] gyal, _iplä, _қуну, --, 
   {{0x629c3a45,0x7cec12ed,0x0ed8033f,0x7af801ab}},	//   _ecso, _dørk, णाभड, hhut, 
   {{0x629c1529,0x61ec3699,0x4fa40353,0xf98400f1}},	//   _fcso, ayal, сиев, _ډب_, 
   {{0x290de9d5,0x61ede9d6,0x7cede9d7,0x92b42bd8}},	//   zida_, byal, _førk, _احدا, 
   {{0x290de9d8,0x61ec00ca,0x7af9e9d9,0x6c54014b}},	//   yida_, cyal, dhut, оклу, 
   {{0x290de9da,0x3e480024,0x320001d5,0x06681df2}},	//   xida_, dėtį_, mziy_, _ﺳﯩﻠﯩ, 
   {{0x290de9db,0x00000000,0x00000000,0x00000000}},	//   vida_, --, --, --, 
   {{0xbea0209b,0x290de9dc,0x6d5c02b5,0x7af9e9dd}},	//   _наск, wida_, _ōrau, ghut, 
   {{0x290de9de,0x0d8400e4,0xe8f800d8,0x6ab802c3}},	//   tida_, _ылан, инич_, _आसीर, 
   {{0x672cd32e,0x41b8008f,0x80d85edd,0x7cec005c}},	//   _skaj, נציע, नाये, _nørh, 
   {{0x290de9df,0x7af80882,0x66b49b81,0xfb103016}},	//   rida_, bhut, обну, _کونج, 
   {{0x290de9e0,0x7af9e9e1,0x61ede9e2,0x7b8400db}},	//   sida_, chut, yyal, _داكە, 
   {{0xeb1409d9,0x2cac0165,0x80d98e2f,0x61ec9d12}},	//   तचीत_, _kbdd_, नामे, xyal, 
   {{0x290c0517,0x2d840066,0x7cec0212,0xdb0000a2}},	//   qida_, _mvme_, _rørk, _eplä, 
   {{0x672c009b,0xe2980032,0x7ced4a75,0x61ec0113}},	//   _tkaj, һаң_, _sørk, wyal, 
   {{0x61ec021a,0x672de9e3,0x3814011a,0x00000000}},	//   tyal, _ukaj, _לקום_, --, 
   {{0xe2984da8,0xf65000b2,0x61ec090c,0x7cec353e}},	// [37530] лаң_, _ٻئي_, uyal, _førh, 
   {{0x7af9e9e4,0x00000000,0x00000000,0x00000000}},	//   zhut, --, --, --, 
   {{0xdfd0157c,0x7af8009a,0x25ac031c,0x00000000}},	//   بيا_, yhut, ħelu_, --, 
   {{0x7cec708a,0x61ede9e5,0x629c02d0,0x00000000}},	//   _tørk, pyal, _ucso, --, 
   {{0x7af84214,0x7cec0e38,0x3da40cb6,0x93f403e3}},	//   vhut, _høri, среб, _çərə, 
   {{0x4aa40bc0,0x3f800010,0x935443fb,0x1be82c25}},	//   क्सव, _tvju_, _دریچ, идли_, 
   {{0x8c4089d0,0x7cec03b2,0x00000000,0x00000000}},	//   меше, _jøri, --, --, 
   {{0x68f8143a,0x1988013e,0xdb0001bf,0xdd940024}},	//   _alvd, абии_, _oplå, _мабы, 
   {{0x7af9e9e6,0x68f803ac,0x44300267,0xda080832}},	//   rhut, _blvd, _lyx_, شيده_, 
   {{0x7af80b12,0x7e782e6c,0x69c4025c,0x1784a401}},	//   shut, _heup, _ġiet, огом, 
   {{0x7af81935,0x7e79e9e7,0x60c40597,0x20001aa1}},	//   phut, _keup, idhm, nzhi_, 
   {{0x7e7801f7,0x7cec2dba,0x68f8933c,0x7af9e9e8}},	//   _jeup, _sørh, _elvd, qhut, 
   {{0x7e79e9e9,0x00000000,0x00000000,0x00000000}},	//   _meup, --, --, --, 
   {{0x7e79e9ea,0x1869e9eb,0xab44002b,0xe2b401c6}},	//   _leup, _таки_, _iṣṭi, үстэ, 
   {{0x59a80037,0x00000000,0x00000000,0x00000000}},	//   _कहँर, --, --, --, 
   {{0x20001682,0xdb000267,0x7a0800e2,0x64580139}},	//   dzhi_, _eslö, pētī, _şwit, 
   {{0x395c0309,0x20000165,0x10a54c90,0x7cec01bf}},	// [37540] nqus_, ezhi_, жизн, _tørh, 
   {{0x7cecf5b8,0x98a4007f,0xd498004e,0xa7fc08a9}},	//   _føri, kolč_, _өрү_, mbır, 
   {{0x09b41fad,0x7cec03cd,0x256401d9,0xa7fc013d}},	//   _अन्य, _gøri, _وایُ, lbır, 
   {{0x7e78003e,0x60c403d5,0xd1740139,0x8d6800f0}},	//   _ceup, adhm, _мыгы, ајка_, 
   {{0x7e79e9ec,0x00000000,0x00000000,0x00000000}},	//   _deup, --, --, --, 
   {{0x0b88016c,0xc5f00375,0x61b004b3,0x4638010f}},	//   асии_, ודד_, _سەما, בענע, 
   {{0x7e780618,0x31600066,0x96c807f7,0x44306b41}},	//   _feup, lqiz_, ियाउ, _xyx_, 
   {{0x7e7977c2,0x7d0000e4,0xbb402377,0x00000000}},	//   _geup, tãrõ, мејк, --, 
   {{0x4aa400dc,0x4c840114,0x7bc80171,0xa9f40118}},	//   क्षव, _млав, _ēmuž, इनेछ_, 
   {{0x2d806c85,0x69c40030,0x8c4400f0,0x66740023}},	//   šies_, _šies, _дезе, _ጠቕላላ_, 
   {{0x7e79e9ed,0x3cec0037,0x5f0000cd,0x00000000}},	//   _yeup, _अवते_, _शतम्_, --, 
   {{0x0708013e,0xf76c90c7,0x7cec0162,0xe98400cf}},	//   рхои_, کای_, _røri, _فاتۋ, 
   {{0xda6405e6,0x7ceca98d,0x60c40009,0xa87400d4}},	//   _راني, _søri, ydhm, _еллі, 
   {{0x4aa472c0,0xdb00002d,0x4430022e,0x7cec03b2}},	//   क्रव, _oplû, _pyx_, _pøri, 
   {{0x4309e9ee,0x1aec0154,0x1cb00327,0x466802dd}},	//   ахам_, _জগতে_, ནྶི_, _ﺳﯩﭽﯟ, 
   {{0x7cec0158,0x28a8033f,0x62240116,0x00000000}},	//   _vøri, कभवि, كىزل, --, 
   {{0x05740220,0x60f831af,0xa7fc03b9,0x00000000}},	// [37550] _باعد, бная_, mbıq, --, 
   {{0x7e79e9ef,0x7cec01bf,0xceb400fb,0x00000000}},	//   _seup, _hørv, үәт_, --, 
   {{0x4425e9f0,0x7e79e9f1,0x37040014,0x7cec01bf}},	//   _ân_, _peup, _رویِ, _kørv, 
   {{0xf8b4084a,0x2000e2ee,0x6ac400cd,0x00000000}},	//   _अस्प, rzhi_, वयोर, --, 
   {{0x7e780810,0x80d817c6,0xfe74010b,0x98a4007f}},	//   _veup, नादे, йүң_, wolč_, 
   {{0x9f04ff4e,0x8d900075,0x14dc090a,0x7e7882f6}},	//   _کورو, رلىش, मायण, _weup, 
   {{0x0ec4069f,0x7e79e9f2,0x00000000,0x00000000}},	//   _रोकड, _teup, --, --, 
   {{0x7cec03cd,0x69c4031c,0x599400d8,0x00000000}},	//   _nørv, _ġier, проѕ, --, 
   {{0xdd90c69a,0x00000000,0x00000000,0x00000000}},	//   _سوا_, --, --, --, 
   {{0x9b600075,0x395c0113,0x6b980174,0x00000000}},	//   _كۆتۈ, rqus_, ðagø, --, 
   {{0xccf00d65,0x395de9f3,0x38000364,0x7cec143a}},	//   _רכב_, squs_, фонҳ, _børv, 
   {{0xeab002f2,0x1aa800cc,0x00000000,0x00000000}},	//   _لعه_, _খোৰা, --, --, 
   {{0xcb100302,0x7cec33b8,0x395d2291,0x6aa400cc}},	//   _אלא_, _dørv, qqus_, _খোকো, 
   {{0x45a00131,0xa7fc0205,0x00000000,0x00000000}},	//   رەپك, mcın, --, --, 
   {{0x61380ffb,0x9f58020c,0x00000000,0x00000000}},	//   rìll, _èyèl_, --, --, 
   {{0xe708038b,0x8778008f,0xa3bc01ad,0x00000000}},	//   _وتين_, _פאפי, _इनर_, --, 
   {{0xa7fc029f,0x7cec005c,0x1aa803d4,0xc690010f}},	// [37560] ncın, _høru, _খোৱা, _נאז_, 
   {{0x50584684,0x3160022e,0x00000000,0x00000000}},	//   сшая_, rqiz_, --, --, 
   {{0x7cec2147,0x00000000,0x00000000,0x00000000}},	//   _jøru, --, --, --, 
   {{0x81b80154,0x94745533,0x7cec01bf,0x00000000}},	//   _অপর_, _بدکا, _møru, --, 
   {{0x7cec03b2,0xd25057fb,0x00000000,0x00000000}},	//   _løru, _سنس_, --, --, 
   {{0xd13000c6,0x26f801ad,0xcf58030d,0x6b9801b9}},	//   _أمس_, _ंत्र_, _грач_, tuvg, 
   {{0xa9f40316,0x9f480306,0x00000000,0x00000000}},	//   इन्छ_, žkám_, --, --, 
   {{0xfbcc15fa,0xf9a002d3,0x69d402e8,0x6b9801d5}},	//   اتو_, _ገዲፎም_, джиф, ruvg, 
   {{0x7cec0ef9,0xcfbc00fe,0xa898004e,0x00000000}},	//   _rørv, _ইপিন, окпу_, --, 
   {{0x7cede9f4,0x00000000,0x00000000,0x00000000}},	//   _sørv, --, --, --, 
   {{0xe695e9f5,0x6b98022e,0x00000000,0x00000000}},	//   мины, quvg, --, --, 
   {{0x5bb400c2,0x7bd80375,0x7cec003b,0x0b4400f7}},	//   _юсуф, _לקבו, _døru, _энен, 
   {{0xe7380032,0xdce801e4,0x273800e5,0x00000000}},	//   йеү_, _steĉ, lénk_, --, 
   {{0x7cec0579,0x4ad800cd,0x00000000,0x00000000}},	//   _føru, भावव, --, --, 
   {{0x7cec0579,0xa848072d,0x5b2000e5,0x273800e5}},	//   _tørv, _بلغم_, _سہیل, nénk_, 
   {{0x7cec7eb1,0xf2c40075,0xf40800c6,0xf83402e4}},	//   _hørt, нсун, سيقى_, _מנות_, 
   {{0x7cec04ce,0xed880153,0x00000000,0x00000000}},	// [37570] _kørt, žųjų_, --, --, 
   {{0x656de9f6,0xa3d400cf,0xab480150,0xa7fc0205}},	//   _itah, _жооч, _ﺗﺎﺑﯟ_, ncıo, 
   {{0x656c0327,0x3f840ab9,0x7cec332e,0x00000000}},	//   _htah, énu_, _mørt, --, 
   {{0xc0c400aa,0xdd942487,0x3f90031c,0xb65401e1}},	//   _ډېره_, дады, rrxu_, _àṣep, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x11d80302,0x656dab2a,0x98a4005f,0xa7fc03e0}},	//   _וחשב, _mtah, kolā_, vcın, 
   {{0x9b440811,0x1ae4cea6,0x1b48005b,0x00000000}},	//   ونتو, дойм, озки_, --, 
   {{0x80d829da,0x656c2486,0x7cec03b2,0x98a40171}},	//   नावे, _otah, _røru, dolā_, 
   {{0x656d31f3,0x49c405f5,0x7cec3c02,0x00000000}},	//   _ntah, длын_, _søru, --, 
   {{0x67240115,0x7cec0162,0x7c64211f,0xa7fc03e0}},	//   _ĉija, _pøru, _رائل, rcın, 
   {{0x656de9f7,0xdb0004ce,0x7cec0450,0x00000000}},	//   _atah, _oplø, _dørt, --, 
   {{0x7cec0579,0x6b9c62ad,0xa7fc03ee,0x9584004e}},	//   _vøru, _årga, mcıl, млме, 
   {{0x7cec2759,0x06049a41,0x7ae80158,0x98a43d2a}},	//   _ført, дняк_, _iogt, _жиле, 
   {{0xd04c0085,0x79991a02,0x7cec0fac,0x2488069d}},	//   _kobɔ, muuw, _tøru, _ሮበርት_, 
   {{0x656c0325,0x03a114ea,0x7cec08d7,0xa7fc03ee}},	//   _etah, киро, _hørs, ncıl, 
   {{0x7cec037e,0x656c0327,0x7ae9e9f8,0x2334011c}},	//   _kørs, _ftah, _jogt, ехур, 
   {{0x7ae80076,0x7cec143a,0x145800c7,0x90c5e9f9}},	// [37580] _mogt, _jørs, _мшны_, мбае, 
   {{0x7ae8392f,0xa7fc0205,0x00000000,0x00000000}},	//   _logt, kcıl, --, --, 
   {{0x7ae8a887,0x00000000,0x00000000,0x00000000}},	//   _oogt, --, --, --, 
   {{0x656c0270,0x7ae9e9fa,0x03a40014,0x7998009f}},	//   _ytah, _nogt, _تۯٲو_, kuuw, 
   {{0x656c05b1,0xa3003e1f,0xaba801ec,0x00000000}},	//   _xtah, _сүте, _ﺴﻴﻘﺎ, --, 
   {{0x8c340107,0xc1b00022,0xd00833ea,0x00000000}},	//   молӣ_, _шәсы, _деге_, --, 
   {{0x7ae9e9fb,0x7cec0ac8,0xa2a40882,0x80d801ad}},	//   _bogt, _rørt, ङ्क्, नारे, 
   {{0x7cede9fc,0x7999e9fd,0xd1d00092,0xf4200154}},	//   _børs, fuuw, _ከሞት_, _ধরার_, 
   {{0x7ae80151,0x79980083,0x7cec06ea,0xa7fc03e0}},	//   _dogt, guuw, _pørt, acıl, 
   {{0x7cec12ed,0x656c01a9,0xcb74009b,0x00000000}},	//   _dørs, _rtah, _жудњ, --, 
   {{0x656de9fe,0xa715937f,0x78a0010a,0x7ae801d3}},	//   _stah, емні, _dcnv, _fogt, 
   {{0x7cec708a,0x6594013e,0x7ae80009,0x00000000}},	//   _førs, наму, _gogt, --, 
   {{0x273891f8,0xfd540055,0xc9f400c6,0x7bc416d9}},	//   néni_, _anaṣ, _تساع, _ájur, 
   {{0xba540677,0x656c01ef,0xa7fc4e7e,0x00000000}},	//   _חסדו_, _vtah, lcım, --, 
   {{0x7ae801d4,0xf4340024,0xc6e40150,0x00000000}},	//   _yogt, верэ, _жіпп, --, 
   {{0x7ae80014,0x656c0083,0xddd80784,0x2738df8a}},	//   _xogt, _ttah, hawš, kéni_, 
   {{0x656de9ff,0xa2a444af,0x60f82f6a,0x3f440254}},	// [37590] _utah, ङ्ग्, пная_, lõug_, 
   {{0x31c40063,0xa7fc15b7,0x00000000,0x00000000}},	//   њств, ycıl, --, --, 
   {{0x26c8166a,0x8364007b,0x30a40395,0x00000000}},	//   _kaao_, _تدخل, ъртв, --, 
   {{0x7ced6205,0xa7fc05d1,0xc30401d3,0xa2a40303}},	//   _nørr, vcıl, _آبدو, ङ्ख्, 
   {{0x26c80083,0x7ae80014,0xa1580063,0x00000000}},	//   _maao_, _rogt, _хагу_, --, 
   {{0x7ceccc33,0x7f480477,0x00000000,0x00000000}},	//   _rørs, smgq, --, --, 
   {{0x4ad8069f,0x7cec4673,0x26c80093,0x6b5c0124}},	//   भांव, _sørs, _oaao_, _oĩgu, 
   {{0x1a6523d4,0x2481b507,0x79993878,0xa7fc0790}},	//   ریتی_, _lehm_, tuuw, rcıl, 
   {{0x7ae9ea00,0xd04c013f,0xeda402a9,0x00000000}},	//   _vogt, _wobɔ, _ашхо, --, 
   {{0x799801af,0x24800e78,0x00000000,0x00000000}},	//   ruuw, _nehm_, --, --, 
   {{0x26c80083,0x7cec03d4,0x7ae9ea01,0x25a9ea02}},	//   _baao_, _førr, _togt, _aqal_, 
   {{0x7cec1477,0x7a8400f2,0x00000000,0x00000000}},	//   _tørs, _آشام, --, --, 
   {{0xe3b01973,0xd704009d,0xaa5877a8,0xaa880066}},	//   یرِ_, _үзли, _жицу_, _آنهم_, 
   {{0x18a5ea03,0x98a40166,0x2ebc01ad,0x00000000}},	//   _чакм, _чике, _ईस्त, --, 
   {{0x26c80618,0x00000000,0x00000000,0x00000000}},	//   _faao_, --, --, --, 
   {{0x27f9bd18,0x91e5ea04,0x994800b2,0x26c804ba}},	//   ørne_, нобе, _بلڪل_, _gaao_, 
   {{0x98a4054e,0xe16400f1,0x43880023,0x00000000}},	// [375a0] colă_, ندلي, _ንውልቀ_, --, 
   {{0x76446105,0x91e4016c,0x4644013d,0x25dc012d}},	//   _iziy, _ҷоме, _язын_, खमरी_, 
   {{0x4478025d,0x273804fb,0x00000000,0x00000000}},	//   _מניע, wéni_, --, --, 
   {{0x0dc9ea05,0x3f4400c5,0x2739ea06,0x87780a7c}},	//   зуки_, jõud_, téni_, פאני, 
   {{0x6440005f,0xc69008a8,0x33200327,0x00000000}},	//   ļlie, ראד_, mnix_, --, 
   {{0x8bc4086f,0xdd8c0131,0xfce1ea07,0x7cec143a}},	//   есид, زۈم_, лочо, _sørr, 
   {{0x798803ac,0x2cbc03cd,0x00000000,0x00000000}},	//   _avgw, revd_, --, --, 
   {{0x273800d2,0x764401a9,0xa6b400cc,0x00000000}},	//   péni_, _oziy, _জোনট, --, 
   {{0x764454bc,0x332001f5,0x69c001f5,0x7cec03b2}},	//   _nziy, inix_, uwme, _vørr, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7cec39c2,0x2480026c,0x6d48014f,0x0b940ca5}},	//   _tørr, _rehm_, _ihda, _سجاد, 
   {{0xc98400d1,0x28d14590,0x7cec0162,0x81e400cc}},	//   _зуки, _थोरि, _hørp, বনত_, 
   {{0x36880323,0xbb400f5c,0x33200327,0x00000000}},	//   эсэн_, _сецк, dnix_, --, 
   {{0x7644006f,0x98a40276,0x26c804ba,0x7cec03cd}},	//   _dziy, rolă_, _waao_, _jørp, 
   {{0x7644a21d,0x26c83495,0x6b5c0588,0x97c401ee}},	//   _eziy, _taao_, _tĩgu, _арыһ, 
   {{0xdebc1772,0xdb0013d5,0x25a80135,0x66b40022}},	//   ሰትን_, _oplý, _tqal_, _рбиу, 
   {{0xf194b19d,0x6d48268c,0x76740451,0x25fc033f}},	// [375b0] лить, _ohda, _صديء, रैशी_, 
   {{0x802415c3,0x6f00035a,0x673c1876,0x00000000}},	//   ىرام, _almc, llsj, --, 
   {{0x3320031c,0x00000000,0x00000000,0x00000000}},	//   bnix_, --, --, --, 
   {{0xdce80427,0x7a140ca8,0x6d49ea08,0xde184c84}},	//   _vteč, _lábẹ, _ahda, وقات_, 
   {{0x5ca401c0,0x643400cf,0x00000000,0x00000000}},	//   вилб, _سىڭئ, --, --, 
   {{0x273802fb,0x5bb4023b,0x3f8400e5,0xc30400f2}},	//   ménu_, всиф, ánus_, _آبگو, 
   {{0x6d4801c3,0x7cec003b,0xdce8ebd0,0x3f44000d}},	//   _dhda, _dørp, _uteč, tõud_, 
   {{0x394400a3,0x7de40212,0x00000000,0x00000000}},	//   _shns_, _пізд, --, --, 
   {{0x5d55ea09,0x7cec2ab7,0x00000000,0x00000000}},	//   _акат, _førp, --, --, 
   {{0x6d4801c3,0xd9440640,0xf8d802e5,0x98a43f05}},	//   _ghda, ђени, बाइय, kolą_, 
   {{0x6445ea0a,0x33200227,0x7b8001a9,0x00000000}},	//   _nzhi, ynix_, _ёғид, --, 
   {{0x9abc002e,0xda1400d8,0x15b80166,0x00000000}},	//   roŋs, _идењ, мыгы_, --, 
   {{0x7af9ea0b,0x644406df,0x00000000,0x00000000}},	//   mkut, _azhi, --, --, 
   {{0x81e42aab,0x7af9ea0c,0xb92400d1,0x33200327}},	//   বনা_, lkut, _яфей, wnix_, 
   {{0x3f840311,0xe3b000f1,0x00000000,0x00000000}},	//   ânul_, یرې_, --, --, 
   {{0x7af9ea0d,0x64441aa1,0x1ce00156,0x7f580a73}},	//   nkut, _dzhi, _སོའ_, _niuq, 
   {{0x3321ea0e,0x64440099,0x7645a61d,0x23b0001f}},	// [375c0] rnix_, _ezhi, _uziy, _ልውውጥ_, 
   {{0x77602d2f,0x7af9e812,0x4101ea0f,0x8598010f}},	//   _kunx, hkut, азув, _קשיו, 
   {{0x7af9ea10,0x4ea449a4,0x7760003a,0x7cec072b}},	//   kkut, врла, _junx, _rørp, 
   {{0x77600227,0x7f580399,0x7cec2d8b,0x6d4801a9}},	//   _munx, _ciuq, _sørp, _shda, 
   {{0x7f59ea11,0xbea01920,0xd1740220,0x77602c76}},	//   _diuq, рачк, _шыны, _lunx, 
   {{0x7af831a9,0xf0042f8d,0xdb0000d0,0x06840116}},	//   ekut, _йүзи, _vplý, _ﻓﯩﻠﯩ, 
   {{0x7cec03b2,0xa7fc0790,0xd1f40023,0x00000000}},	//   _vørp, rcık, _ዉልቀ_, --, 
   {{0x7af9ea12,0x00000000,0x00000000,0x00000000}},	//   gkut, --, --, --, 
   {{0x0dc80032,0xdb0003b2,0x0d2000db,0xa9340022}},	//   _юлай_, _uplý, _күдү, леиш, 
   {{0x7af9ea13,0x8b9401c0,0x0ed80073,0x6d4802d0}},	//   akut, _ардч, णाकड, _uhda, 
   {{0x2739ea14,0x8ac4006c,0x38c42de5,0xbc0800db}},	//   ként_, _аёлл, туын_, _ۉرۅۅ_, 
   {{0x3f440254,0x00000000,0x00000000,0x00000000}},	//   põue_, --, --, --, 
   {{0x862400fd,0x6a84010b,0x673c01e3,0x00000000}},	//   тьне, _алҗа, rlsj, --, 
   {{0x77600077,0x00000000,0x00000000,0x00000000}},	//   _funx, --, --, --, 
   {{0x1ce00135,0x02a444e2,0xa2943981,0xf5242401}},	//   _སོལ_, крам, лаві, рфян, 
   {{0xf76c1c93,0xa5c400fd,0xfbd000dc,0x27380306}},	//   _باو_, _йөге, थितम, ténu_, 
   {{0xb2842f6a,0xe3c401c6,0xf1f40022,0x00000000}},	// [375d0] рыск, _өрнү, азтэ, --, 
   {{0xd37000b2,0xdb0005d5,0x27380308,0x25080f01}},	//   _گهٽ_, _splü, rénu_, _سرخی_, 
   {{0x7af850d4,0xf4840046,0x64440165,0x77600067}},	//   ykut, _туын, _uzhi, _xunx, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3da40b16,0x27380fac,0x7af801e4,0x00000000}},	//   треб, léns_, vkut, --, 
   {{0x7074034e,0x00000000,0x00000000,0x00000000}},	//   _نافذ, --, --, --, 
   {{0x7af9ea15,0x3ec47d9d,0x00000000,0x00000000}},	//   tkut, _исаб, --, --, 
   {{0xfeb80137,0x05c002ab,0x80d80dba,0x9f3401ec}},	//   _تاست_, षबाब, नाके, _себі, 
   {{0x99d40f87,0x7af9ea16,0x850001ad,0x6dc40137}},	//   اتبا, rkut, रघाट_, _ۅزەل, 
   {{0x7760170c,0x57e815a0,0xd7e80c9e,0x00000000}},	//   _punx, едом_, емое_, --, 
   {{0x7af83209,0x7760102c,0x00000000,0x00000000}},	//   pkut, _qunx, --, --, 
   {{0xd5e401c0,0x7af80784,0x27f800cc,0x8f98011a}},	//   гжми, qkut, ørna_, עירי, 
   {{0xb8b00150,0x00000000,0x00000000,0x00000000}},	//   _көні, --, --, --, 
   {{0x1ce02fb5,0xc9900597,0x950401ed,0x273810d8}},	//   _སོས_, _الوظ, اہدے_, féns_, 
   {{0x273801d3,0x00000000,0x00000000,0x00000000}},	//   tént_, --, --, --, 
   {{0x084001d9,0xdd8401ed,0x00000000,0x00000000}},	//   _دۆپُ, _وڈ_, --, --, 
   {{0xc6900375,0x61e80129,0xf0840124,0x00000000}},	// [375e0] _האח_, _àell, икаҿ, --, 
   {{0x27398f12,0x51555d49,0x79980198,0xd434007b}},	//   béns_, утбу, iruw, _معجب, 
   {{0x2738056a,0x764800ac,0x00000000,0x00000000}},	//   céns_, ədya, --, --, 
   {{0x71740e8e,0x00000000,0x00000000,0x00000000}},	//   _نۇرا, --, --, --, 
   {{0x1ea8007b,0x9e70215c,0x74400092,0x00000000}},	//   ضاني_, تۇقت, _ተቆጣጥ, --, 
   {{0x79987691,0x936001f2,0xac181de8,0x6b740107}},	//   druw, _ọnyị, колу_, алку, 
   {{0x6fc802ab,0x7ee000d1,0x00000000,0x00000000}},	//   _रनिं, شكۈن, --, --, 
   {{0xdb0001ab,0xcb44f87a,0x6af400d8,0x25f80210}},	//   _splò, ыхли, рзиф, ॉनमी_, 
   {{0xbef40302,0xd90c01ed,0x799888e6,0x27380798}},	//   _עצמו_, ڈین_, gruw, zéns_, 
   {{0xd90dea17,0xc910015b,0x48a801a9,0x00000000}},	//   وین_, সক্ত_, хтим_, --, 
   {{0x29200131,0x98a40064,0x00000000,0x00000000}},	//   ﺸﯩﭗ_, nolę_, --, --, 
   {{0x7998004b,0x7b140311,0x1ce00327,0xa764004e}},	//   bruw, nţul, _སོོ_, лкүд, 
   {{0xa02405ac,0x00000000,0x00000000,0x00000000}},	//   _ভৰাব_, --, --, --, 
   {{0x67d4013e,0xe374009d,0x98a40064,0xc8b00066}},	//   _воку, илгы, kolę_, _طلبک, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x41e4242f,0x80a435e8,0x27380077,0xd0b006be}},	//   ліза, _चाहे, réns_, mşəd, 
   {{0x1cc4031c,0xe7043fe6,0x82345cfc,0x00000000}},	// [375f0] _ཏྲའ_, _مسکی, ارزا, --, 
   {{0x1cb00327,0x00000000,0x00000000,0x00000000}},	//   _ཐཡེ_, --, --, --, 
   {{0x1558011a,0x00000000,0x00000000,0x00000000}},	//   _שכתב, --, --, --, 
   {{0xdea0006c,0x9df80108,0x00000000,0x00000000}},	//   تیری, кнет_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x79980113,0x60180395,0x00000000,0x00000000}},	//   wruw, _ровя_, --, --, 
   {{0xdab802d5,0x4c900139,0x79986e4a,0x00000000}},	//   тыкі_, биәс, truw, --, 
   {{0x0ae5ea18,0x7999ea19,0xc96001af,0x00000000}},	//   рдый_, uruw, овый, --, 
   {{0x7999ea1a,0x696400ae,0x996400cf,0x00000000}},	//   rruw, حديق, лтүл, --, 
   {{0x7b14084c,0x1cc40327,0x95fc0118,0x00000000}},	//   lţum, _ཏྲར_, उन्ट_, --, 
   {{0x799802d1,0xdcb400bc,0x00000000,0x00000000}},	//   pruw, _आउँछ, --, --, 
   {{0xd8f40502,0x644001d3,0x8f34011a,0xceb00677}},	//   _پزشک, ülin, שארו_, קיך_, 
   {{0x23d0033f,0x06680ef6,0x00000000,0x00000000}},	//   हिंद, _ﺳﯩﻘﯩ, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [37600] --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x0e65ea1b,0xf9840014,0xc4980375,0x00000000}},	//   акен, _ڈب_, _בשית, --, 
   {{0xf9840502,0x20547559,0x9f6401d3,0x98a4e1eb}},	//   _وب_, стур, átás_, rolę_, 
   {{0x7b140276,0xc2780375,0x00000000,0x00000000}},	//   rţul, _ברכי, --, --, 
   {{0xcbc4038b,0x0ba815bf,0xb1483fb8,0x00000000}},	//   لزبي, نابى_, _صیام_, --, 
   {{0x72280154,0x00000000,0x00000000,0x00000000}},	//   _মরিচ_, --, --, --, 
   {{0xbea1ea1c,0x6b4c000f,0x3ea01620,0xdd8001d9}},	//   _маск, kûge, _мисг, _کیوٝ, 
   {{0x6b4c045f,0x00000000,0x00000000,0x00000000}},	//   jûge, --, --, --, 
   {{0x9d5004d3,0x1cc4031c,0xcc840244,0x00000000}},	//   _فۆنت, _ཏིར_, _ئۆغه_, --, 
   {{0x60d800c8,0xbd300150,0x8ae40212,0x5eb800eb}},	//   אַרג, _بىلع, _вілл, _ইফতে, 
   {{0x6b4c045f,0x7bf8010f,0xe584009d,0x00000000}},	//   fûge, _שפאצ, йтгү, --, 
   {{0x80a474f6,0xa3c80034,0xda64009f,0xdb3400ec}},	//   _चाले, लौन_, _اامي, _اونڌ, 
   {{0x2418190b,0x00000000,0x00000000,0x00000000}},	//   гогы_, --, --, --, 
   {{0x1cc4031c,0x78ac02f0,0x00000000,0x00000000}},	//   _ཏིལ_, živý, --, --, 
   {{0xe704dbb4,0x00000000,0x00000000,0x00000000}},	//   _دستی, --, --, --, 
   {{0x3359ea1d,0xe29800d1,0x40880114,0x00000000}},	// [37610] ратэ_, каң_, вљем_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa7fc0342,0x234801d5,0xdfd001f7,0x998c0419}},	//   mcıs, _مسحی_, ثيا_, azeň_, 
   {{0x2cac01c3,0x00000000,0x00000000,0x00000000}},	//   _acdd_, --, --, --, 
   {{0x628c0421,0x2e380276,0xc8a40037,0xaabc190c}},	//   maao, апць_, _खांट, ्जनक, 
   {{0x628dea1e,0xe980001f,0xa7fc0342,0x00000000}},	//   laao, _ያተኮረ_, ncıs, --, 
   {{0x6fd00332,0x60c46f35,0xfee400c0,0x00000000}},	//   rócá, mehm, _кўам, --, 
   {{0x60c5ea1f,0x628c06c8,0xce50040b,0xff040212}},	//   lehm, naao, _کھمب, _тягн, 
   {{0x18680798,0xee200150,0x00000000,0x00000000}},	//   лапи_, _жетi_, --, --, 
   {{0x60c5ceb3,0x628c089c,0x15b802dd,0xed5800f3}},	//   nehm, haao, қымы_, _вођ_, 
   {{0xdab80953,0x628dea20,0xd90c04fb,0x00000000}},	//   _былі_, kaao, ویچ_, --, 
   {{0x38c4036b,0xa924004e,0x00000000,0x00000000}},	//   _چاغی_, йдөл, --, --, 
   {{0x1cc4025c,0x00000000,0x00000000,0x00000000}},	//   _ཏྲོ_, --, --, --, 
   {{0x1cc4025c,0x6a240214,0x3800013e,0x00000000}},	//   _ཏིས_, _بفهم, _молҳ, --, 
   {{0x68fdea21,0x628c0b23,0x60c40113,0x279400c7}},	//   örde, faao, dehm, _дшыр, 
   {{0x27f80598,0xd265335d,0x55e4030d,0x00000000}},	//   ärne_, скай, _гоиб, --, 
   {{0xd174dcd2,0x8678011a,0x15b804b3,0x00000000}},	// [37620] сыбы, _גרפו, _сыйы_, --, 
   {{0xd17402dd,0x00000000,0x00000000,0x00000000}},	//   _қымы, --, --, --, 
   {{0x1cc4003d,0x3ce802a0,0x00000000,0x00000000}},	//   _ཏྲེ_, चाने_, --, --, 
   {{0x81b40154,0xcf440108,0x8e0800d8,0x00000000}},	//   চয়ই_, щней, лнев_, --, 
   {{0x9e65ea22,0x1ee83bd6,0xa6b400cc,0x00000000}},	//   زانن, شووی_, _জোঁট, --, 
   {{0xd131ea23,0xe7a821b8,0x7dc0841d,0x00000000}},	//   _رمز_, _कमलप, سقىن, --, 
   {{0x4478010f,0xfbccfefb,0xd00800d8,0x00000000}},	//   אנצע, فتي_, _севе_, --, 
   {{0x8eb00220,0x00000000,0x00000000,0x00000000}},	//   _رەتت, --, --, --, 
   {{0x3eb000ac,0x7d2401a8,0x2cad1039,0xc8648b1b}},	//   əxt_, órsá, _tcdd_, йтни, 
   {{0x1ce00867,0x426802d3,0xc6a404a9,0x2919ea24}},	//   _སོག_, ዳስነት_, әрни, òra_, 
   {{0x628c030a,0xa7fc0790,0x00000000,0x00000000}},	//   yaao, vcıs, --, --, 
   {{0x25d84627,0x3f440254,0x00000000,0x00000000}},	//   аммы_, jõul_, --, --, 
   {{0xe8942607,0x628c0421,0xbb38010f,0xa63452c4}},	//   _даль, vaao, _געאי, інгі, 
   {{0xf76cba07,0x3ce80037,0x18186c71,0x00000000}},	//   بای_, चाये_, اریک_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6ec403e5,0x3f540327,0xc1e80108,0x290c4a11}},	//   _रसगु, _uħux_, льзе_, lhda_, 
   {{0x672dea25,0x60c46085,0xa4d45b97,0x628c0076}},	// [37630] _ijaj, tehm, _допі, raao, 
   {{0x657dea26,0x00000000,0x00000000,0x00000000}},	//   mpsh, --, --, --, 
   {{0x672c01fa,0x60c40477,0x09ac0154,0x628c0108}},	//   _kjaj, rehm, _কনফা, paao, 
   {{0x1ce01efe,0x672c2252,0x14180375,0x0af80154}},	//   _སོང_, _jjaj, _כותב, ইফুল_, 
   {{0x290c0050,0x14dc0490,0x60c41057,0x00000000}},	//   khda_, _फोडण, pehm, --, 
   {{0x672c187e,0x61ed0698,0x60c40455,0x91b80115}},	//   _ljaj, mxal, qehm, _דמשי, 
   {{0x5ea5ea27,0x81b800bd,0x7b0400e4,0xdd9000dd}},	//   _ومسل, _আছি_, _añua, سوں_, 
   {{0x9f041a71,0x672c0214,0xbd680063,0x8c14007b}},	//   _بورو, _njaj, _брже_, غيير_, 
   {{0x41cc0034,0x61edea28,0x7b140356,0x00000000}},	//   _सैमस, nxal, nţui, --, 
   {{0x672c0a55,0xac94005b,0x61ec00db,0x290c0135}},	//   _ajaj, _науш, ixal, ghda_, 
   {{0x657dea29,0x2d9800b0,0x79e401ed,0xe77801d3}},	//   epsh, _ārei_, _گوشہ_, یلیں_, 
   {{0x290c0014,0x61ec0472,0x00000000,0x00000000}},	//   ahda_, kxal, --, --, 
   {{0x15b9ea2a,0x672dea2b,0xe97002dd,0xa90400f2}},	//   шыны_, _djaj, _كۇيد, زبین, 
   {{0x672c009a,0x290dea2c,0xa7fc03e0,0xd7c80472}},	//   _ejaj, chda_, rcır, _نوته_, 
   {{0x61ec00e8,0x7b14054e,0x94841219,0xdebc0b82}},	//   exal, eţui, йыңд, ደስን_, 
   {{0x672c0200,0x60c04dd9,0x2368007b,0x00000000}},	//   _gjaj, _ılma, صحفي_, --, 
   {{0x15c808b0,0x61ec01e2,0x00000000,0x00000000}},	// [37640] ﻪﻧﺪﻩ, gxal, --, --, 
   {{0x7645ea2d,0x7764022f,0x1ce0025c,0xd0780395}},	//   _iyiy, _hiix, _སོཊ_, рсач_, 
   {{0x753dea2e,0x3134010a,0x00000000,0x00000000}},	//   morz, çетр, --, --, 
   {{0x290cdc2f,0x63a001a2,0x776400e8,0x753c0034}},	//   zhda_, álne, _jiix, lorz, 
   {{0x09ac0154,0x00000000,0x00000000,0x00000000}},	//   _কনভা, --, --, --, 
   {{0x76444539,0xd478010f,0x00000000,0x00000000}},	//   _myiy, באַל, --, --, 
   {{0x8ec401d5,0xaa9402e8,0x4e1800bc,0x19f800fe}},	//   _وآرم, пийч, _मेरै_, ইছোঁ_, 
   {{0x7645ea2f,0x753c033f,0x332000e8,0x37cc0154}},	//   _oyiy, horz, niix_, িমার, 
   {{0x753c006d,0x76440134,0xcce400e3,0x00000000}},	//   korz, _nyiy, _وسطي, --, 
   {{0x672c0bb8,0x6441ea30,0xa8140364,0x0ca800ec}},	//   _sjaj, ülik, здош, _خطري_, 
   {{0x7645ea31,0xdce808ad,0x1cc40135,0x77640014}},	//   _ayiy, _steć, _ཏྲི_, _biix, 
   {{0x290c006c,0x76440230,0xc98400f3,0x00000000}},	//   shda_, _byiy, _дуки, --, 
   {{0x753dea32,0x76440526,0x6d580549,0x78c40158}},	//   forz, _cyiy, omva, ørvå, 
   {{0x657dea33,0x753dea34,0x290c022e,0x00000000}},	//   rpsh, gorz, qhda_, --, 
   {{0x7645ea35,0x291c0230,0x7764198f,0x6d5801e2}},	//   _eyiy, _imva_, _fiix, imva, 
   {{0xf2c5ea36,0x68f88f30,0x672dea37,0xdebc1772}},	//   мсун, _hovd, _ujaj, ደትን_, 
   {{0x7179ea38,0x673cb003,0x753c1790,0x657c009a}},	// [37650] жбур_, mosj, borz, qpsh, 
   {{0x61ec01d9,0x673ce3bd,0x68f8022e,0x7b14054e}},	//   rxal, losj, _jovd, rţui, 
   {{0x656dea39,0x3b1c0113,0x3320058a,0xaabc00bc}},	//   _huah, yiuq_, biix_, ्जाक, 
   {{0x656de207,0x6565ea3a,0x7764208d,0x6d59b8da}},	//   _kuah, _hihh, _xiix, emva, 
   {{0x6564020c,0xc0c400f1,0x7dc40116,0x00000000}},	//   _kihh, _وېره_, تتاك, --, 
   {{0x656dea3b,0x65640477,0x68f9ea3c,0x673c036e}},	//   _muah, _jihh, _novd, hosj, 
   {{0x656dea3d,0xec682cc8,0x65640037,0x673c0200}},	//   _luah, әрәк_, _mihh, kosj, 
   {{0x753cb631,0x291c090c,0x6564192e,0x212001fa}},	//   zorz, _amva_, _lihh, lihh_, 
   {{0x3b1c0d04,0x77640014,0x4431ea3e,0x68f9ea3f}},	//   riuq_, _riix, _lxx_, _bovd, 
   {{0xac7402dd,0x76440526,0x6565ea40,0x00000000}},	//   _قامش, _ryiy, _nihh, --, 
   {{0x753dea41,0x656c04fe,0x60d5ea42,0x64440218}},	//   vorz, _auah, _mazm, _nyhi, 
   {{0x656c5df1,0x291c1992,0x3b1c0357,0x753c068f}},	//   _buah, _emva_, qiuq_, worz, 
   {{0x753dea43,0xf968084c,0x656c0051,0x186800d8}},	//   torz, _трей_, _cuah, _лали_, 
   {{0x60d5ea44,0x7644a1d3,0x77640449,0x2491ea45}},	//   _nazm, _vyiy, _wiix, gazm_, 
   {{0x4431ea46,0x25a000b8,0x9894035b,0x77640009}},	//   _cxx_, _aśṛṇ, _дуқә, _tiix, 
   {{0x656c0418,0x6b9c037e,0x656401ab,0x0440008e}},	//   _fuah, _ærge, _eihh, хесн, 
   {{0x65f8152d,0x753dea47,0x7645ea48,0x656c00c7}},	// [37660] _дээр_, porz, _uyiy, _guah, 
   {{0x3ebc51e2,0x65640007,0x60d403b9,0x42500efc}},	//   _abut_, _gihh, _cazm, رنلر, 
   {{0x3ddc0bc9,0x60d401a9,0x00000000,0x00000000}},	//   _aruw_, _dazm, --, --, 
   {{0xbffc009e,0xfbc00154,0x00000000,0x00000000}},	//   ্পূণ_, ্মাত, --, --, 
   {{0x656474cb,0x2cc80327,0x6b8802d0,0xdf5800d1}},	//   _yihh, _གྲུབ, _swdg, ڭشەش_, 
   {{0x60d5ea49,0xdde97237,0x673c0841,0x6d58127b}},	//   _gazm, ترمه_, zosj, umva, 
   {{0x68f811ad,0x644405b1,0x6d5801e3,0x3cd80073}},	//   _rovd, _xyhi, rmva, _गोळे_, 
   {{0x68f8014f,0x6d5802d0,0x60d400d7,0x64400254}},	//   _sovd, smva, _zazm, ülii, 
   {{0x60d412ca,0x673dea4a,0xba701456,0x68f80427}},	//   _yazm, vosj, رايت, _povd, 
   {{0x656dea4b,0x49c8039b,0x3ebc036e,0x68f803e3}},	//   _ruah, _ҳукм_, _zbut_, _qovd, 
   {{0x673dea4c,0x6565ea4d,0x656d1621,0xe758003b}},	//   tosj, _rihh, _suah, жині_, 
   {{0x656c028c,0xb9007ff3,0x656466ee,0x68f80455}},	//   _puah, _पो_, _sihh, _wovd, 
   {{0xb0ac05ba,0x673c03a1,0x80d004c5,0x6564020c}},	//   _चांग, rosj, সাত্, _pihh, 
   {{0x291c844d,0x1ce0031c,0x6444023a,0x6564014f}},	//   _umva_, _སོབ_, _pyhi, _qihh, 
   {{0x38c9ea4e,0x2490036b,0x673c0841,0x656c0066}},	//   _دانی_, razm_, posj, _wuah, 
   {{0x656c04fe,0x65640455,0xf744119e,0x00000000}},	//   _tuah, _wihh, _пејо, --, 
   {{0x65640254,0x60f80006,0xf1a4be81,0x93f403b9}},	// [37670] _tihh, оная_, ерхн, _çənə, 
   {{0x64442d2f,0x3ebc003e,0xdef800e8,0x200001e2}},	//   _tyhi, _sbut_, _soŋ_, tyhi_, 
   {{0x44240165,0x24580276,0xe2f802dd,0x60d5ea4f}},	//   _ãn_, _фань_, _дені_, _vazm, 
   {{0x1cc40003,0x2120020b,0x26d8002f,0xddd80327}},	//   _ཏིང_, sihh_, ndso_, pawż, 
   {{0xc0d0001f,0x60d405d1,0x1ce0031c,0xa158050b}},	//   _የፀረ_, _tazm, _སོད_, _маму_, 
   {{0xee3810f5,0xa3b0000d,0xdb78361e,0xdca40818}},	//   чні_, _ऐमा_, осиш_, факи, 
   {{0xcf8c01d9,0xab5c0171,0x00000000,0x00000000}},	//   _نژن_, _spļa, --, --, 
   {{0x6440006d,0xa3c400af,0x99e41422,0x8b3400d1}},	//   żliw, _एहन_, джид, ۋۋەر_, 
   {{0x629c0998,0xdef8002e,0xf1e0024a,0x79e400e5}},	//   _mdso, _liŋk_, नियन, سودہ_, 
   {{0x2738066d,0x7b04095b,0xdce022a2,0x00000000}},	//   mény_, _iñum, _kilč, --, 
   {{0xdce0007f,0x629dea50,0x38000107,0x00000000}},	//   _jilč, _odso, хонҳ, --, 
   {{0xeab000c6,0x3ce8482a,0x00000000,0x00000000}},	//   _معه_, चावे_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x629dea51,0xd8241b6b,0x320c002b,0x00000000}},	//   _adso, _одли, _ādy_, --, 
   {{0xf84405f5,0xc95002e4,0x186801af,0x273801ef}},	//   _хүнд_, _שמו_, _лаһи_, hény_, 
   {{0x8d98001f,0x63a001d3,0x91e4180b,0x07a021f3}},	//   ገነባው_, álna, мобе, _раън, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [37680] --, --, --, --, 
   {{0x629cf8bd,0x79880042,0xf1e000cd,0x00000000}},	//   _edso, _mwgw, निबन, --, 
   {{0x2d8000e2,0x00f400db,0xf1a800f1,0x00000000}},	//   ģiem_, بىلع_, غاړه_, --, 
   {{0x09ac0154,0x61e8560e,0x00000000,0x00000000}},	//   _কনসা, _šele, --, --, 
   {{0x273801ed,0x00000000,0x00000000,0x00000000}},	//   gény_, --, --, --, 
   {{0x6c54011c,0xc614011a,0x00000000,0x00000000}},	//   нклу, וחני_, --, --, 
   {{0x798802d0,0xfce00120,0x00000000,0x00000000}},	//   _awgw, тојо, --, --, 
   {{0xcee808f0,0x00000000,0x00000000,0x00000000}},	//   _برسن_, --, --, --, 
   {{0x273801d3,0x109001ec,0x00000000,0x00000000}},	//   pénz_, _ﺟﯘﺩﯨ, --, --, 
   {{0xcce40597,0xc7b8023a,0x00000000,0x00000000}},	//   _تسري, оём_, --, --, 
   {{0xfa301291,0x00000000,0x00000000,0x00000000}},	//   فرید, --, --, --, 
   {{0x79880142,0x00000000,0x00000000,0x00000000}},	//   _fwgw, --, --, --, 
   {{0x6abdea52,0xb8d04bf3,0x27682c26,0x79d000c7}},	//   ्जीर, رتیش, _کشتی_, _аҩыӡ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3eacee5c,0x91c0c7e0,0x27380122,0x224c02f0}},	//   yggt_, һәрл, zény_, _šek_, 
   {{0x7b14054e,0xdbd801a8,0x00000000,0x00000000}},	//   lţur, _mæðr, --, --, 
   {{0x443c068f,0x0414009e,0xb3640395,0x91c0104e}},	// [37690] łu_, _দুখী_, търк, ләрл, 
   {{0x7b14084c,0x273801ed,0x8024c019,0xdce000d7}},	//   nţur, vény_, ورام, _pilč, 
   {{0x44249c56,0xa2943334,0x35f88235,0x2294010a}},	//   _än_, _пані, _فرید_, _пиня, 
   {{0x629c2a2c,0x27385955,0xdce00153,0x00000000}},	//   _udso, tény_, _vilč, --, 
   {{0x75680014,0xab5c00ef,0xd25000ec,0x6e94f88c}},	//   _ریہہ_, _apļo, _منٽ_, тичу, 
   {{0x273826f6,0xdce000ef,0x00000000,0x00000000}},	//   rény_, _tilč, --, --, 
   {{0x8c41bb9c,0x9f05ea53,0x8d600108,0x00000000}},	//   леше, _كوسو, ывше, --, 
   {{0x7b0403f0,0x1ce0025c,0x8d840092,0x00000000}},	//   _iñuk, _སོམ_, ነባቸው_, --, 
   {{0x1d340801,0xfdf0000d,0x00000000,0x00000000}},	//   _зная, _आपिस_, --, --, 
   {{0x1784016c,0xbbe81ec7,0x6c84007b,0x00000000}},	//   нгом, _ورام_, _للكم, --, 
   {{0xb8d445bf,0xac941188,0x00000000,0x00000000}},	//   _छा_, _рахш, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7e780451,0x7ae8127b,0x98a4084c,0x7b30054e}},	//   _mfup, _ingt, _зиле, căua, 
   {{0x6b4c002d,0xf484036b,0x98a400e2,0x00000000}},	//   jûgj, ضاسی, rolē_, --, 
   {{0xd3700d7a,0x98a400e2,0x1a6402f2,0x00000000}},	//   اهر_, solē_, _تیکی_, --, 
   {{0x93f403e3,0x38c800f1,0x00000000,0x00000000}},	//   _çəmə, _داچی_, --, --, 
   {{0xcb1000c8,0x0574007b,0x00000000,0x00000000}},	// [376a0] אלן_, _كمية_, --, --, 
   {{0x7e78090c,0x4f94084c,0xe0840592,0x8fd03c1a}},	//   _afup, ерду, نجمي, ләбә, 
   {{0x7ae9ea54,0xe0480133,0x6440000d,0x00000000}},	//   _ongt, وشمه_, ülit, --, 
   {{0xa300052f,0xc7b008a8,0x24540241,0x00000000}},	//   _күсе, רבא_, _wùmí_, --, 
   {{0x7b0400e4,0x21740124,0xa3002de5,0xb2440022}},	//   _iñuh, _ауср, _түте, _рҭад, 
   {{0x7ae9ea55,0x0634010f,0xdd8c0116,0x00000000}},	//   _angt, ענסט_, تۈك_, --, 
   {{0x1fb5ea56,0x68fc0254,0x00000000,0x00000000}},	//   _истр, ördm, --, --, 
   {{0x1dd001bc,0xbb4000d8,0x00000000,0x00000000}},	//   _दैवत, лејк, --, --, 
   {{0xc7b8013e,0x80d0015b,0x00000000,0x00000000}},	//   ӯён_, সার্, --, --, 
   {{0x7ae8127b,0x00000000,0x00000000,0x00000000}},	//   _engt, --, --, --, 
   {{0x60c054ee,0x08280a8f,0x7b140356,0x181801d9}},	//   _ölme, яции_, rţur, ِرُک_, 
   {{0x7b300356,0xca740024,0x00000000,0x00000000}},	//   lăun, _чужы, --, --, 
   {{0x80d0033f,0x00000000,0x00000000,0x00000000}},	//   ड़मे, --, --, --, 
   {{0x63a11bcc,0xdce000cd,0x7b300356,0x27f8072b}},	//   álno, _kilā, năun, ørns_, 
   {{0xa2940953,0xd6b40133,0x00000000,0x00000000}},	//   каві, رشێک, --, --, 
   {{0xe2c808f0,0x1cc40327,0xdce000de,0x00000000}},	//   بورو_, _ཏྲན_, _milā, --, 
   {{0x4ac02311,0x3870036e,0x00000000,0x00000000}},	// [376b0] व्यव, _çarë_, --, --, 
   {{0x69dc1d86,0x6441ea57,0x00000000,0x00000000}},	//   āreh, ülis, --, --, 
   {{0xa3c4007d,0x7e78e63f,0x09a8031c,0x0465ea58}},	//   _एहि_, _pfup, _བའྀ_, _ятим, 
   {{0x82c80327,0x00000000,0x00000000,0x00000000}},	//   _ཅིིའ, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7b040d04,0xdce00055,0xa3c4000d,0x00000000}},	//   _iñui, _bilā, _एहा_, --, 
   {{0xdce80790,0x31340334,0xdce00171,0x200402d2}},	//   _eteğ, _серр, _cilā, _æli_, 
   {{0x99d577bc,0x7e7800ec,0x1ae43e9f,0x00000000}},	//   نتخا, _ufup, тоим, --, 
   {{0x32e00327,0x9ba40014,0xa7fc03e0,0x00000000}},	//   _སྃསྐ, رٕکى, mcıy, --, 
   {{0xa9c41541,0xa7fc0205,0x00000000,0x00000000}},	//   ازيو, lcıy, --, --, 
   {{0x7ae80270,0xab843e4d,0xdce00055,0x18680120}},	//   _tngt, _бучк, _gilā, ќани_, 
   {{0xd628f9aa,0xa7fc0790,0x00000000,0x00000000}},	//   доме_, ncıy, --, --, 
   {{0x4ad800e1,0xaa88007b,0xdce000de,0xadf4030d}},	//   _मोटव, _أنهم_, _zilā, _упăш, 
   {{0x79980b45,0x93f400ac,0x98a406ed,0x97c40137}},	//   msuw, _çəkə, _рике, _айке, 
   {{0x65c00efb,0x1cc40135,0x61e8031c,0xa848007b}},	//   _құра, _ཏིན_, _ġela, _كلهم_, 
   {{0x2d8000a8,0x2484719a,0x59a40073,0x00000000}},	//   ţiei_, ılma_, _गटार, --, 
   {{0xd175ea59,0x50940063,0x7998f578,0x00000000}},	// [376c0] тыбы, вређ, nsuw, --, 
   {{0x7998bc61,0x00000000,0x00000000,0x00000000}},	//   isuw, --, --, --, 
   {{0x7998020c,0x3f440254,0xc7740092,0x00000000}},	//   hsuw, jõus_, _የቡድኑ_, --, 
   {{0x7999ea5a,0x7b040309,0xfe6c0533,0x0dc80116}},	//   ksuw, _iñuw, ەگە_, дуки_, 
   {{0xfe41ea5b,0x68fc0254,0x00000000,0x00000000}},	//   анцо, ördk, --, --, 
   {{0x81700075,0xdce000ef,0x00000000,0x00000000}},	//   _ئۆلچ, _pilā, --, --, 
   {{0x2ec41473,0xfbcd9566,0x00000000,0x00000000}},	//   _бөлм, قتي_, --, --, 
   {{0xfa200154,0xdce000cd,0xe9d8009d,0x00000000}},	//   _পড়ল_, _vilā, емич_, --, 
   {{0x6f000fa3,0x79981c04,0x4d6421b5,0x98a40024}},	//   _iomc, gsuw, _акав, nolė_, 
   {{0x998c0034,0xf98c0592,0xdce0002b,0xdc740064}},	//   dzeń_, آبي_, _tilā, _быць, 
   {{0x6f01c402,0xe695ea5c,0x4ac475a6,0x3cd81b57}},	//   _komc, лины, _لياق, _गोटे_, 
   {{0x6f0005b1,0xbf98010f,0x7b300356,0xd7640133}},	//   _jomc, ויטש, năul, ێنیی, 
   {{0x6f000989,0x6b4c002d,0x98a40153,0xc1c802dd}},	//   _momc, jûgi, jolė_, _ﺗﻴﺮﺍ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc2f000c7,0x00000000,0x00000000,0x00000000}},	//   аҟны, --, --, --, 
   {{0x6f001cdf,0x6d48020c,0x41e402dd,0xa3c803ce}},	//   _nomc, _lkda, кіза, लौग_, 
   {{0x2fd800ca,0x998c068f,0xc0900248,0x6d480399}},	// [376d0] _asrg_, czeń_, _aláṣ, _okda, 
   {{0xc0f0001f,0x047401b9,0x20040327,0x68fc007c}},	//   _ቃጠሎ_, _جلدک_, _żliq_, ördh, 
   {{0x6f01ea5d,0xdca408ca,0x7e7400ae,0x79980210}},	//   _bomc, ҳали, ناشئ, zsuw, 
   {{0x6d49ea5e,0x6f01dca2,0x00000000,0x00000000}},	//   _akda, _comc, --, --, 
   {{0xdca5ea5f,0x6f000419,0xa7fc0790,0x00000000}},	//   гали, _domc, rcıy, --, 
   {{0x3f4400af,0xdfd400fd,0x00000000,0x00000000}},	//   tõus_, _йогы, --, --, 
   {{0x6f0005b1,0x3f646561,0x00880131,0x9f340064}},	//   _fomc, _атаб, _ﺗﯘﺗﯘ, _беві, 
   {{0x7999ea60,0x6d4801e3,0x7b300356,0x9b940150}},	//   tsuw, _ekda, căul, _ەلات, 
   {{0x39442a1f,0xae0419c5,0x00000000,0x00000000}},	//   _pkns_, _پولى, --, --, 
   {{0x6f001cdf,0x27e000ef,0x819801ec,0x00000000}},	//   _zomc, _ņina_, _ﻀﺨﻤﺔ_, --, 
   {{0xd82422e9,0x6f001cdf,0x799803f9,0x95fc033f}},	//   удни, _yomc, ssuw, ॉन्ट_, 
   {{0x290c0280,0xf7041719,0x00000000,0x00000000}},	//   akda_, рҗим, --, --, 
   {{0x61e800f3,0x7af80200,0x6d486873,0x00000000}},	//   _šeln, mjut, _ykda, --, 
   {{0x7af834db,0x998c0034,0x7b300356,0x6e240332}},	//   ljut, rzeń_, zăul, úibi, 
   {{0xdce80030,0x998c0034,0x03a0020a,0x9358084c}},	//   _oveľ, szeń_, йиро, ерау_, 
   {{0x7af94c3c,0xa3c400c5,0x8fd000fb,0x65cc02dd}},	//   njut, _एहर_, ҙәгә, _ﺑﻴﯩﻠ, 
   {{0x3f8003b2,0x4ea401b9,0x90c40121,0x00000000}},	// [376e0] _atju_, ҳрла, лбае, --, 
   {{0x7b040357,0x6f014f2c,0x7af9ea61,0x98a40024}},	//   _iñuu, _somc, hjut, rolė_, 
   {{0x7f580117,0x0ea81411,0x7af9ea62,0x68fdea63}},	//   _bhuq, екей_, kjut, ördi, 
   {{0x7f59ea64,0x7af80357,0x6f00014f,0x41cc012d}},	//   _chuq, jjut, _qomc, _सैकस, 
   {{0x7af9ea65,0x290c09a5,0xbea00cb6,0xcca0024c}},	//   djut, ykda_, сачк, йҳақ, 
   {{0x7f58014b,0x6f000944,0xb5cc0055,0x52741291}},	//   _ehuq, _womc, _śṛdh, _جاگز, 
   {{0x6f01ea66,0x60c0002f,0x7af80003,0x3c900108}},	//   _tomc, _ölma, fjut, щищё, 
   {{0xfbcc0447,0x7af86b4e,0xefcc0092,0x00000000}},	//   ستى_, gjut, _በባዶ_, --, 
   {{0xd90c0133,0x00000000,0x00000000,0x00000000}},	//   ژیه_, --, --, --, 
   {{0x41b800c8,0x391158e4,0xc1b8008f,0x7af80124}},	//   עציע, ймыр, עמיש, ajut, 
   {{0x290c0fc4,0x66f400d8,0x5ba400d4,0x00000000}},	//   rkda_, апну, _вріз, --, 
   {{0xddc800ef,0x8034010f,0xe8e8013d,0x00000000}},	//   _dzeņ, רנטע_, хмүд_, --, 
   {{0x2bd00034,0x4b5004d3,0xc8640116,0x00000000}},	//   थौरा, _پێکر, _өтки, --, 
   {{0x69c00006,0xe4140124,0xd1ec0092,0x00000000}},	//   mtme, адгь, ጁነት_, --, 
   {{0x69c1ea67,0xab5c00ef,0xa4f800e5,0x00000000}},	//   ltme, _apļi, _یکسر_, --, 
   {{0x2bac6d65,0x2d840fcf,0x69c1ea68,0x57a40032}},	//   _घटना, _otme_, otme, _тышҡ, 
   {{0x69c1ea69,0xa5f80262,0x417400db,0xdfd000ec}},	// [376f0] ntme, _репу_, اارس, ڪيا_, 
   {{0x69c1ea6a,0x7f585310,0x31c40640,0x309401f7}},	//   itme, _shuq, љств, مشمس, 
   {{0xdfd0021a,0x7f58094a,0xff056442,0x69c000af}},	//   تيا_, _phuq, лядн, htme, 
   {{0x69c0143a,0x4174075e,0x00000000,0x00000000}},	//   ktme, _ماسس, --, --, 
   {{0x628dea6b,0x26c800ec,0x6cf02232,0xfda40640}},	//   mbao, _mbao_, चांग_, ујем, 
   {{0xa2bc1f13,0x628c01c6,0x69c067c4,0x00000000}},	//   शभक्, lbao, dtme, --, 
   {{0x7af80cfe,0x7f58094a,0x2d84509e,0x26c80295}},	//   tjut, _thuq, _etme_, _obao_, 
   {{0x628dea6c,0x69c1ea6d,0x9b04020a,0x7af80037}},	//   nbao, ftme, рзид, ujut, 
   {{0x7af8033d,0xa2dc0c2e,0x69c0005c,0x3ab00075}},	//   rjut, _पसन्, gtme, _һәпт, 
   {{0x7b040227,0x26c80083,0x7af9ea6e,0xc0f0001f}},	//   _añut, _abao_, sjut, _ፍትህ_, 
   {{0x628c2b92,0x69c1ea6f,0xd04c0213,0xbab40133}},	//   kbao, atme, _babə, _مناڵ_, 
   {{0x96649780,0x98a4007f,0x3b640395,0x00000000}},	//   икне, milč_, _съзв, --, 
   {{0x69c1ea70,0xda1c00ab,0x69dc01e4,0x59d80118}},	//   ctme, _बेचत_, ցres, _भनिर, 
   {{0x2bdc1889,0x26c80295,0x69cc054e,0x00000000}},	//   _मनमा, _ebao_, âneş, --, 
   {{0x67540014,0x8400041b,0x00000000,0x00000000}},	//   _گیَس_, опрж, --, --, 
   {{0x628c1c06,0x52840137,0x68fc0254,0x00000000}},	//   gbao, ргаб, ördv, --, 
   {{0x2bdc02ab,0x4204009b,0xc6900375,0x61e803b2}},	// [37700] _मनभा, анто_, _ואח_, _áell, 
   {{0x10a42083,0x14242cc9,0x86580375,0x00000000}},	//   рижн, _вдом, _בדפי, --, 
   {{0x64c401f7,0x00000000,0x00000000,0x00000000}},	//   _ايپل, --, --, --, 
   {{0x69c1ea71,0x25ac01f1,0x628c0208,0x00000000}},	//   ytme, šele_, cbao, --, 
   {{0x69c06144,0x1ea9ea72,0x02dc01f9,0x00000000}},	//   xtme, طاني_, _पोटभ, --, 
   {{0x16f4025c,0x0ba5ea73,0x1d8800ec,0xbb4400f2}},	//   _བོའམ_, ашим, ائني_, یلون_, 
   {{0x4124072c,0x2c1c0154,0x00000000,0x00000000}},	//   _торо_, _পুড়ে_, --, --, 
   {{0x69c15b60,0xa3c80490,0xfba41a04,0x504402a9}},	//   ttme, ोबत_, _गिरम, _беҳб, 
   {{0xb99402d5,0x69c0a9e9,0x7c2c0213,0xd1dc0240}},	//   авых_, utme, _əkrə, _ዓቐብ_, 
   {{0xdde80502,0xc8640536,0x0905ea74,0x69c1ea75}},	//   _حرفه_, итни, рчим, rtme, 
   {{0x8c45ea76,0x294424ae,0x5cf40166,0x00000000}},	//   _теже, ﻘﯩﭗ_, _уяту, --, 
   {{0xdce8025c,0x69c03f5b,0x0708013e,0x61e9565f}},	//   _iweġ, ptme, тхои_, _šelm, 
   {{0x661dea77,0xda6c0451,0x00000000,0x00000000}},	//   uzsk, _ٻڏي_, --, --, 
   {{0xb89000cf,0x6b4c00e4,0x661c5923,0x00000000}},	//   _ۇلۇع, rûgu, rzsk, --, 
   {{0x68fc00af,0x7b0401c4,0xdce8025c,0xc6a400f3}},	//   ördu, _iñur, _jweġ, _крпи, 
   {{0x26c801c8,0x273402dd,0x628c031c,0x1a6c0241}},	//   _ubao_, _دىبس, ubao, _ẹẹ́t, 
   {{0x628c0165,0x00000000,0x00000000,0x00000000}},	// [37710] rbao, --, --, --, 
   {{0xc6102e04,0x00000000,0x00000000,0x00000000}},	//   डनीय_, --, --, --, 
   {{0xdce80327,0x00000000,0x00000000,0x00000000}},	//   _nweġ, --, --, --, 
   {{0x62340276,0xdfd402dd,0x63b40010,0xddc800ef}},	//   _гему, _қобы, muzn, _ageš, 
   {{0x63b401ef,0xc0c80023,0x00000000,0x00000000}},	//   luzn, _በዳሂ_, --, --, 
   {{0x99d400d1,0x00000000,0x00000000,0x00000000}},	//   ەتدا, --, --, --, 
   {{0xd04c013f,0x714400f7,0x00000000,0x00000000}},	//   _mabɛ, _بۉلۅ, --, --, 
   {{0xfeb9ea78,0x2bb80034,0x00000000,0x00000000}},	//   _جاست_, _इमरा, --, --, 
   {{0xdd91ea79,0x00000000,0x00000000,0x00000000}},	//   _روا_, --, --, --, 
   {{0xa3c8073d,0xa2c82274,0x09e007d5,0x98a4033b}},	//   ोबा_, _हॉस्, чоьн, pilč_, 
   {{0xb8cc01ad,0x63b402f0,0xab5c00ef,0x574401d5}},	//   _ओय_, juzn, _apļu, йноб, 
   {{0x15b8823b,0x63b42625,0x97c400cf,0x00000000}},	//   лыгы_, duzn, _ۇقتو, --, 
   {{0x99840491,0x8b54011a,0x00000000,0x00000000}},	//   _التو, _פינס_, --, --, 
   {{0x59400014,0x63b401ef,0xaa580114,0x09ac00cc}},	//   _ژکھہ, fuzn, _тичу_, _কনচা, 
   {{0x637807dd,0x7bc001a4,0xded00092,0x00000000}},	//   истр_, ntnu, ሩንና_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7bc000c5,0xd7c800f2,0xf42003d4,0x5164004e}},	// [37720] htnu, _شوکه_, _মুখৰ_, йүмү_, 
   {{0x5c7002d3,0x7bc0007c,0x63b402f0,0x5044041b}},	//   _ኣጀንዳ_, ktnu, buzn, безб, 
   {{0x44740375,0xa564007b,0x50580108,0x00000000}},	//   _לעיל_, _بدين, ушая_, --, 
   {{0xbea02401,0x5f2400d4,0x6b9c02d2,0x3f6401f0}},	//   зацк, офіз, _ærgi, бихо_, 
   {{0xdee4007b,0xd250009f,0x7bc000d7,0x5274014b}},	//   تألي, _رنس_, etnu, _вуҳу, 
   {{0xdce00153,0x3ff000db,0x8658011a,0x00000000}},	//   _kilę, تكۅر, נדסי, --, 
   {{0xcf5800d8,0x00000000,0x00000000,0x00000000}},	//   _брач_, --, --, --, 
   {{0x2b4009a8,0xa92800a2,0x00000000,0x00000000}},	//   čico_, _myžž, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdce8003d,0xb2f8025c,0x9e8c0023,0x00000000}},	//   _tweġ, _པོའང_, ህድርና_, --, 
   {{0x7bc0e9a7,0x94080134,0x8ae400d4,0x00000000}},	//   ctnu, rabɛ_, _гілл, --, 
   {{0x63b4022e,0xa3c800bc,0x00000000,0x00000000}},	//   vuzn, ोबस_, --, --, 
   {{0x7b040309,0x9b6400db,0xe8d001d9,0x3b8400db}},	//   _iñup, _بەيم_, _ہۅکھ, _көөп_, 
   {{0x63b40e3c,0x657c01b9,0x00000000,0x00000000}},	//   tuzn, rqsh, --, --, 
   {{0x02a5ea7a,0x00000000,0x00000000,0x00000000}},	//   йрам, --, --, --, 
   {{0xddc8033f,0x4df8012d,0x00000000,0x00000000}},	//   _cześ, ्हाई_, --, --, 
   {{0xf8b4499d,0x00000000,0x00000000,0x00000000}},	// [37730] _төө_, --, --, --, 
   {{0x7bc00232,0xa3d46f9f,0x612803e3,0xa2c8353b}},	//   ytnu, _дооч, _kölə, _हॉर्, 
   {{0xd9a4a4cd,0x00000000,0x00000000,0x00000000}},	//   _गट्ट, --, --, --, 
   {{0x3f84005f,0xf7b8010f,0x00000000,0x00000000}},	//   īnu_, רזאמ, --, --, 
   {{0x06e00011,0x3f843d4f,0xefe00023,0xa4540092}},	//   যাপি, ūnu_, _ዓደይ_, _መስጠት, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xff50e5e7,0x5ea4013e,0x81a800cc,0x00000000}},	//   _فخر_, _ҳуҷҷ, _খহি_, --, 
   {{0x2f184ea5,0x5985ea7b,0xe8a801e0,0x00000000}},	//   _лось_, олиб, ҡбыҙ_, --, 
   {{0xbd840014,0x3ebc003a,0xaac401e2,0x00000000}},	//   _اۆتن_, _icut_, ښتین, --, 
   {{0x6bd40058,0x612803b9,0xed5800f3,0x3d906171}},	//   تتۇر, _bölə, _гођ_, _миғр, 
   {{0x06e00eac,0x8c38013e,0x00000000,0x00000000}},	//   যানি, _кофӣ_, --, --, 
   {{0x7f480117,0x612806be,0x68fc007c,0x00000000}},	//   nogq, _dölə, ördr, --, 
   {{0x98a5ea7c,0x18a4ef94,0xd54800c6,0x00000000}},	//   _диле, _далм, لجسم_, --, 
   {{0x98a4005f,0xddc80034,0x1869975c,0x00000000}},	//   bilā_, _sześ, _кали_, --, 
   {{0x27940124,0x3448010b,0xd468041b,0x98a400de}},	//   _ешыр, сүни_, риве_, cilā_, 
   {{0xc0cc001f,0x25acc1b4,0x27f812ed,0x2bdc4ead}},	//   _ጥቆማ_, šela_, årne_, _मनसा, 
   {{0x869800f7,0xa92800a2,0x91040108,0x98a40064}},	// [37740] _өтөт_, _wyžž, опае, nolį_, 
   {{0x3ebdea7d,0x101400cf,0xc4800108,0x00000000}},	//   _acut_, يباد, _ольк, --, 
   {{0xc0f0044e,0xe3b40046,0xcd280424,0xb4c80709}},	//   _ፍትሒ_, _нұр_, یستن_, ोजी_, 
   {{0xa3c9ea7e,0x7f48009a,0x09c0009e,0x637400e4}},	//   ोबर_, gogq, ্টতা, _ỹnga, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd7a87922,0x9e6436ce,0x00000000,0x00000000}},	//   _किंच, سانن, --, --, 
   {{0xbb81ea7f,0x0eb9ea80,0x8fa414b3,0xcb180798}},	//   ولوي, _вузы_, _фабе, иќи_, 
   {{0x61e800d7,0x00000000,0x00000000,0x00000000}},	//   _šeli, --, --, --, 
   {{0x2bdc00e1,0x06e00011,0x21300051,0x00000000}},	//   _मनवा, যামি, _ýnhé_, --, 
   {{0xc7c43e4f,0xa7b80276,0x00000000,0x00000000}},	//   осми, блоу_, --, --, 
   {{0xc07800c8,0x807808a8,0xc1c41a55,0x62800139}},	//   יטיש, יניצ, _रङ्ग, _şlom, 
   {{0xda64ef7d,0x858801d5,0x00000000,0x00000000}},	//   _کامي, иёга_, --, --, 
   {{0x6aa1ea81,0xa2a80073,0xc95801b9,0x00000000}},	//   mamf, टणस्, _кўк_, --, 
   {{0x7f480921,0x58fc031c,0x6aa000e5,0xa3c82356}},	//   zogq, _ྟོགས_, lamf, ोबल_, 
   {{0x38c825cb,0x7f480b6f,0xbab00150,0xdb000118}},	//   _خانی_, yogq, _ءمۇب, _svlé, 
   {{0xf7f0e4c4,0x6aa1ea82,0xc7640e76,0xeaac0183}},	//   _آسود, namf, _باتى, ক্ৰম, 
   {{0x26d9ea83,0x00000000,0x00000000,0x00000000}},	// [37750] meso_, --, --, --, 
   {{0x26d82f95,0xe298052f,0x3ebdea84,0x7f48009a}},	//   leso_, раҡ_, _scut_, wogq, 
   {{0x6aa0016b,0x2ee406be,0x672c00d7,0xf0e82d40}},	//   kamf, _bamf_, _kmaj, تىلى_, 
   {{0x26d9ea85,0x6aa0009f,0x9df80417,0x8abc00eb}},	//   neso_, jamf, йнет_, ্যুৎ, 
   {{0x672dea86,0x2369ea87,0x98a4054e,0x629c0171}},	//   _mmaj, mmaj_, nilă_, _ieso, 
   {{0x26d9ea88,0x629dea89,0x23689843,0xdb200241}},	//   heso_, _heso, lmaj_, _ìtús, 
   {{0x629dea8a,0x7ed55b7c,0x26d8a188,0x44200472}},	//   _keso, _وزرا, keso_, nzj_, 
   {{0x629c1311,0x6aa00b6f,0x672c00b5,0x2368047e}},	//   _jeso, gamf, _nmaj, nmaj_, 
   {{0x629d2f0d,0x26d803f0,0x00000000,0x00000000}},	//   _meso, deso_, --, --, 
   {{0x672ddddd,0x629dea8b,0x9cb402dd,0x2368016d}},	//   _amaj, _leso, _ءمات, hmaj_, 
   {{0x26d9ea8c,0xad246923,0x6aa1ea8d,0x629c0368}},	//   feso_, _تىلى, bamf, _oeso, 
   {{0x26d9ea8e,0x6aa00b6f,0x629dea8f,0x2369ea90}},	//   geso_, camf, _neso, jmaj_, 
   {{0x23680455,0x64480112,0x4f14008f,0x98a4054e}},	//   dmaj_, ßein, פֿטן_, gilă_, 
   {{0x672dea91,0x629dea92,0xb4c800af,0x273801fb}},	//   _emaj, _aeso, ोजे_, hĩnh_, 
   {{0x629c5d05,0x26d9ea93,0x96b8361e,0xe3b0009f}},	//   _beso, beso_, _лупу_, َرِ_, 
   {{0x26d826ce,0x98a400a8,0x629dea94,0x672c0427}},	//   ceso_, bilă_, _ceso, _gmaj, 
   {{0x98a40311,0x00000000,0x00000000,0x00000000}},	// [37760] cilă_, --, --, --, 
   {{0x672d2973,0x629dea95,0x6aa1ea96,0x2369ea97}},	//   _zmaj, _eeso, zamf, amaj_, 
   {{0x629c2f06,0x6aa056ea,0x3b1c02d1,0xa2c801ad}},	//   _feso, yamf, khuq_, ह्ह्, 
   {{0x629dea98,0x3f84ada8,0x0e640c75,0x672c0135}},	//   _geso, ínua_, пкен, _xmaj, 
   {{0xe2c8004b,0x3b1c0009,0xb6500023,0xf23400f2}},	//   _بوټو_, dhuq_, _መንቀሊ, _آبجک, 
   {{0x629dea99,0x6aa0014b,0x26d8141e,0x8fa4014b}},	//   _zeso, wamf, zeso_, _наге, 
   {{0x629c3917,0x6aa1ea9a,0x26d86cb1,0x79880142}},	//   _yeso, tamf, yeso_, _atgw, 
   {{0x2004004e,0x2f1800db,0x26d80306,0x4038011a}},	//   _àlia_, _بىرگ_, xeso_, _הגלג, 
   {{0x6aa1ea9b,0x00000000,0x00000000,0x00000000}},	//   ramf, --, --, --, 
   {{0x672dea9c,0x98a40276,0x26d9ea9d,0x23680cf4}},	//   _smaj, vilă_, weso_, zmaj_, 
   {{0x26d9ea9e,0x2368016d,0x764800ee,0x7644022e}},	//   teso_, ymaj_, şdyl, _axiy, 
   {{0x6d580370,0xc5b4025c,0x98a4054e,0x3b1c4376}},	//   llva, _བཀྱི, tilă_, chuq_, 
   {{0x26d94c1e,0x629dea9f,0x6d59eaa0,0x7764058a}},	//   reso_, _reso, olva, _dhix, 
   {{0x26d8da76,0x629deaa1,0x98a4054e,0x2ec809b2}},	//   seso_, _seso, rilă_, रभुत, 
   {{0x629deaa2,0x291d3bdf,0x76440564,0x26d9eaa3}},	//   _peso, _ilva_, _exiy, peso_, 
   {{0x77640327,0x672deaa4,0x98a40356,0x00000000}},	//   _ghix, _umaj, pilă_, --, 
   {{0xc5b40ed9,0x2369eaa5,0x91c023c9,0x629deaa6}},	// [37770] _བཀྲི, rmaj_, кәрл, _veso, 
   {{0x629deaa7,0x2369eaa8,0x6afc0327,0x00000000}},	//   _weso, smaj_, _ཐོའོ_, --, 
   {{0x25a9eaa9,0xa3e04ca3,0x2ec800dc,0x2368047e}},	//   _hval_, _धनि_, रभूत, pmaj_, 
   {{0xde19eaaa,0x64440472,0x25a85c3d,0x673c143a}},	//   يقات_, _ixhi, _kval_, nnsj, 
   {{0x1d080b57,0xb8fc0003,0x291c00c7,0xb27428f1}},	//   жели_, _སྒ_, _olva_, _плюш, 
   {{0x062c0020,0x8648044e,0xe60400b8,0x798802d0}},	//   _አንድነ, _ሓድነት, _hįųņ, _rtgw, 
   {{0x61edeaab,0x8c4002dd,0x27380051,0x00000000}},	//   lval, кеше, cũng_, --, 
   {{0x25a9eaac,0x291deaad,0x68f8005a,0xdd9802e2}},	//   _oval_, _alva_, _anvd, _twň_, 
   {{0x61edeaae,0x7e79eaaf,0xda080472,0x00000000}},	//   nval, _igup, زيده_, --, 
   {{0x61ece9d7,0x7764350e,0x3b1c0309,0xad440228}},	//   ival, _shix, shuq_, _كۉنۉ, 
   {{0xa9c4034c,0x2000036e,0x798802d0,0x99d41927}},	//   وزیو, nxhi_, _wtgw, ستکا, 
   {{0x291deab0,0x27f80158,0x63b40427,0xda1406ed}},	//   _elva_, årna_, drzn, _одењ, 
   {{0x61ec6991,0x6b9c00b5,0xadf00ebb,0x00000000}},	//   jval, _ærgr, चियन_, --, 
   {{0x673c05e4,0x1be0012c,0xcdb4011a,0x00000000}},	//   ansj, _खनाल_, ופשה_, --, 
   {{0x61edeab1,0x25a80354,0x776400f1,0xc0dc2440}},	//   eval, _eval_, _thix, ሐንስ_, 
   {{0x7e79eab2,0x61ec01f5,0x00000000,0x00000000}},	//   _ngup, fval, --, --, 
   {{0x6d580857,0x764402c4,0x61ecfd8c,0x64441e16}},	// [37780] ylva, _uxiy, gval, _exhi, 
   {{0x7e78decf,0x70d80037,0x98a40064,0xd3f80064}},	//   _agup, ड़ेल, bilą_, _дэмі_, 
   {{0xf8cc0882,0xdb000162,0xd468084c,0x00000000}},	//   त्यय, _avlí, _фине_, --, 
   {{0x61edeab3,0x00000000,0x00000000,0x00000000}},	//   bval, --, --, --, 
   {{0xbea0119e,0x8d6810f3,0xb1440022,0x0d48009a}},	//   тачк, ојка_, _зҽал, يشتي_, 
   {{0x0b88016c,0xcfa802f2,0xe820302b,0x00000000}},	//   осии_, _وازم_, मनमा_, --, 
   {{0x1fb400c0,0x00000000,0x00000000,0x00000000}},	//   _пстр, --, --, --, 
   {{0xba700131,0xc0cc0023,0x00000000,0x00000000}},	//   ھايت, _ኣበሳ_, --, --, 
   {{0x3da4004e,0x7b70007b,0x49440e3b,0x00000000}},	//   _окто_, خطوا, дэнб, --, 
   {{0x2bb005f9,0x00000000,0x00000000,0x00000000}},	//   ींदा, --, --, --, 
   {{0x06e00011,0xe7580212,0xdd3003e3,0x0828005b}},	//   যাসি, зині_, _həşi, юции_, 
   {{0xdce00139,0x673c0036,0x660801f4,0x00000000}},	//   _kilğ, unsj, äeko, --, 
   {{0x673c7328,0x98a4012d,0x092801c8,0x00000000}},	//   rnsj, wilą_, _وستي_, --, 
   {{0x61edeab4,0x63b4033f,0x70d800ab,0x00000000}},	//   vval, trzn, ड़ोल, --, 
   {{0xc6042f8b,0x200002c4,0x61edeab5,0x2ba407f7}},	//   _লেখা_, xxhi_, wval, _गौमा, 
   {{0x61ec08fb,0xfddc000d,0x00000000,0x00000000}},	//   tval, _खईलस_, --, --, 
   {{0x61ec0357,0xaad000bc,0xb284a1a1,0xdd3006be}},	// [37790] uval, थ्यक, тыск, _nəşi, 
   {{0x70941b74,0x64440190,0x3f84baac,0x200002b9}},	//   вафф, _txhi, ínuo_, txhi_, 
   {{0x9ed8005e,0xf65000dd,0x6444009a,0x24584b00}},	//   змет_, _مئی_, _uxhi, _хань_, 
   {{0xdce0c8d8,0x20000240,0x61edeab6,0xdd3003e3}},	//   _bilğ, rxhi_, pval, _bəşi, 
   {{0x1db00d79,0x00000000,0x00000000,0x00000000}},	//   ुंधत, --, --, --, 
   {{0x13a80244,0x00000000,0x00000000,0x00000000}},	//   _بنێی_, --, --, --, 
   {{0x3fc403e6,0x3ec401af,0x00000000,0x00000000}},	//   _زگای_, _осаб, --, --, 
   {{0x7e782dab,0x99e401d5,0x00000000,0x00000000}},	//   _ugup, ежид, --, --, 
   {{0x2259078a,0x25ac9ae3,0x98a400f3,0x00000000}},	//   _jysk_, šelj_, нипе, --, 
   {{0x7c640228,0xadd801c0,0x00000000,0x00000000}},	//   _قاال, _юмуу_, --, --, 
   {{0x60c002d2,0x00000000,0x00000000,0x00000000}},	//   _ölmu, --, --, --, 
   {{0x50180375,0xba740725,0x3ab001ee,0x00000000}},	//   פורו, _قاشت, _рәкт, --, 
   {{0x4a9800c8,0x00000000,0x00000000,0x00000000}},	//   _זינג, --, --, --, 
   {{0x80cc015b,0x6fe0000d,0x00000000,0x00000000}},	//   _হোস্, _गईलख_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x225802d2,0x07a001a9,0x00000000,0x00000000}},	//   _bysk_, _саън, --, --, 
   {{0x2bdc194b,0xd6c4022e,0x00000000,0x00000000}},	// [377a0] _मन्थ, _жиққ, --, --, 
   {{0x2258033f,0xdd300213,0x51540107,0x00000000}},	//   _dysk_, _rəşi, хтбу, --, 
   {{0xf1ac03f3,0x06e000bd,0x5434073e,0xb80c1cd2}},	//   _चिकन, যারি, _سردر, ाहिम_, 
   {{0x317805d5,0x326401d9,0xd6b003d4,0xf8cc00dc}},	//   _wirz_, _لنجہ, ট্ৰপ, त्तय, 
   {{0xbea406f6,0x0c840139,0xdce00139,0xc278011a}},	//   رهون_, ныйм, _qilğ, _מרכי, 
   {{0x7b040784,0x63440153,0x00000000,0x00000000}},	//   _iñuy, mėna, --, --, 
   {{0x20548b82,0xdce001ab,0x2258012d,0x63440153}},	//   _аттр, _ghlč, _zysk_, lėna, 
   {{0x200c373d,0xc278010f,0x606401af,0x00000000}},	//   çmiş_, ּריי, _ресҡ, --, 
   {{0xf98deab7,0x2bac0490,0x2bdc00bc,0xabb40124}},	//   یبی_, _घटका, _मनका, хақә, 
   {{0x6fc40574,0x4d140022,0xdde8009a,0x00000000}},	//   ांपू, _џьат, _غرقه_, --, 
   {{0xe6940474,0xad4400f7,0xf7a404b4,0x98a40064}},	//   кины, _كۉچۉ, нъяк_, nilę_, 
   {{0xf4842097,0x9ba00131,0x0b44187f,0x63440153}},	//   ғурн, _ئەيى, _янен, kėna, 
   {{0xe9840150,0x06e00011,0xb7141b0a,0x2718012d}},	//   _شاشۋ, যালি, удящ, दसौर_, 
   {{0x2b40098d,0x22580267,0x634400c0,0x98a400c0}},	//   čicu_, _rysk_, dėna, kilę_, 
   {{0x39540302,0x597400c7,0x00000000,0x00000000}},	//   _רשום_, _рыцу, --, --, 
   {{0x47d402f5,0x870401b9,0x4900133a,0x660801bf}},	//   ধিদী, _سببل, _рүүг, øeks, 
   {{0x12e4013e,0xbb38011a,0x63440064,0x00000000}},	// [377b0] ъёрҳ, פעמי, gėna, --, 
   {{0xf124e643,0xe414030d,0x225800c0,0x31340150}},	//   льхо, _адоь, _vysk_, геур, 
   {{0xac8c02d3,0x44240267,0x38980115,0x00000000}},	//   _ሓቢሮም_, _ån_, פיאנ, --, 
   {{0xdb0003c6,0x22581455,0xdd947aa6,0xceb400c7}},	//   _ovlá, _tysk_, вады, кәу_, 
   {{0x9f0401d9,0xf31801f0,0x63440064,0x2d8801ec}},	//   _یوسو, _чояш_, cėna, ейіп_, 
   {{0x7c84049b,0x00000000,0x00000000,0x00000000}},	//   худе, --, --, --, 
   {{0x5e9400c6,0xf04400c0,0x00000000,0x00000000}},	//   _للأط, _бэто, --, --, 
   {{0x9f440109,0xd0240150,0x133c0092,0x00000000}},	//   _élà_, _شوقۋ, _የእነዚ, --, 
   {{0x6b84010f,0x00000000,0x00000000,0x00000000}},	//   ĉiga, --, --, --, 
   {{0x3f81eab8,0xfb840022,0xa3e000dc,0x00000000}},	//   _kuju_, _зыдн, _धनं_, --, 
   {{0x2f380421,0x00000000,0x00000000,0x00000000}},	//   lōga_, --, --, --, 
   {{0x3f800bfa,0x5a34005b,0xeb9800d4,0x00000000}},	//   _muju_, _инет, _чиї_, --, 
   {{0x7ae800b5,0x3f800356,0xf780009d,0x00000000}},	//   _iagt, _luju_, _өвлү, --, 
   {{0x7ae8022c,0x2c1400a2,0x32dc0051,0x00000000}},	//   _hagt, _ïîëü, _ậy_, --, 
   {{0x3f819977,0xdb00031d,0x7ae801af,0x78a0009a}},	//   _nuju_, _zvlá, _kagt, _ienv, 
   {{0x78a1eab9,0x7ae9eaba,0x2b0411b1,0xd04c0085}},	//   _henv, _jagt, वायु_, _mabɔ, 
   {{0x78a00489,0x90c4678d,0x98a40034,0xcb1000d9}},	// [377c0] _kenv, кбае, wilę_, בלן_, 
   {{0x3f81eabb,0x7ae80250,0x78a00100,0x4f9406ed}},	//   _buju_, _lagt, _jenv, врду, 
   {{0x3f8005a1,0x9345491b,0xb63c0150,0x00000000}},	//   _cuju_, _анне, _ﺄﻱ_, --, 
   {{0x7ae8f1f6,0x78a15b71,0x3f804a52,0x63440064}},	//   _nagt, _lenv, _duju_, pėna, 
   {{0x54345263,0x00000000,0x00000000,0x00000000}},	//   _سرگر, --, --, --, 
   {{0x78a18dac,0x7ae801f5,0x61b00137,0x2a60025c}},	//   _nenv, _aagt, _دەكا, _ġib_, 
   {{0x8fa40364,0x7ae9eabc,0x3f800810,0x29000208}},	//   _шаве, _bagt, _guju_, _đia_, 
   {{0x78a00097,0x7ae801d9,0x25b81427,0x00000000}},	//   _aenv, _cagt, yrsl_, --, 
   {{0xeff40092,0x00000000,0x00000000,0x00000000}},	//   _ግብዣ_, --, --, --, 
   {{0x391000c7,0x3a7000b1,0x00000000,0x00000000}},	//   имыр, шлыр, --, --, 
   {{0x2d85eabd,0xa774fc32,0xdd3000ac,0x7ae8143a}},	//   _hume_, ллоч, ləşm, _fagt, 
   {{0x78a01aa7,0x2d85eabe,0x6595711b,0xdb0003b2}},	//   _eenv, _kume_, ламу, _avlæ, 
   {{0xfb180375,0xb76401c0,0x2d840037,0x25ac1bce}},	//   _קודמ, ртэй, _jume_, éel_, 
   {{0x78a1eabf,0x69c1eac0,0x2d840451,0xe50800f1}},	//   _genv, mume, _mume_, ريزو_, 
   {{0x69c1eac1,0x2d85eac2,0x67d400ee,0x7ae80432}},	//   lume, _lume_, _сойу, _yagt, 
   {{0x7ae80548,0x78a00066,0x69c0003e,0x3f80022e}},	//   _xagt, _zenv, oume, _ruju_, 
   {{0x2d8400a8,0x26c863ce,0x60f82075,0x3f80213f}},	// [377d0] _nume_, _icao_, нная_, _suju_, 
   {{0x31c407fa,0x3f80013c,0x00000000,0x00000000}},	//   јств, _puju_, --, --, 
   {{0x69c1eac3,0x2d84a013,0x00000000,0x00000000}},	//   hume, _aume_, --, --, 
   {{0x2d84b040,0x2f380421,0x9408016b,0x00000000}},	//   _bume_, tōga_, rabɔ_, --, 
   {{0x2d840c95,0x69c1eac4,0xf1a41fbe,0x52d40677}},	//   _cume_, jume, _врсн, _גורע_, 
   {{0x69c1a2dd,0x7ae9eac5,0x2d85eac6,0xdc69eac7}},	//   dume, _sagt, _dume_, налд_, 
   {{0x7ae87004,0x2d841709,0x78a1eac8,0xdce001ab}},	//   _pagt, _eume_, _renv, _chlā, 
   {{0x69c1eac9,0x2d85eaca,0x78a0501a,0x7ae8011f}},	//   fume, _fume_, _senv, _qagt, 
   {{0x7ae9eacb,0xa3c40d0a,0x960000e1,0x78a08eaf}},	//   _vagt, उंड_, _लपेट_, _penv, 
   {{0x7ae9eacc,0x60c40007,0x26c80798,0xddc8031c}},	//   _wagt, nghm, _acao_, _mgeż, 
   {{0x7ae9eacd,0x9815eace,0x2d84eb82,0x3ab004a9}},	//   _tagt, ابخا, _zume_, _кәпт, 
   {{0x69c1eacf,0x2d85ead0,0x7ae800b5,0x78a00165}},	//   bume, _yume_, _uagt, _wenv, 
   {{0x69c1ead1,0x2d85ce7d,0x78a0c4e9,0x00000000}},	//   cume, _xume_, _tenv, --, 
   {{0x98a400fd,0x2ee001bc,0xd39405a2,0x18a40ce8}},	//   _сике, _नस्त, ләмә_, _сакм, 
   {{0x2480010e,0x344800ee,0x00000000,0x00000000}},	//   _dghm_, түни_, --, --, 
   {{0xf8cc0882,0x27f80212,0x52740137,0x91e40395}},	//   त्रय, ærne_, гузу, лобе, 
   {{0x6aa80183,0x673c02e2,0x00000000,0x00000000}},	// [377e0] _গামো, èrje, --, --, 
   {{0x2d85ead2,0xd17405a2,0x00c409a5,0x628c0332}},	//   _rume_, уыбы, ллук_, acao, 
   {{0x69c1ead3,0x05740375,0x00000000,0x00000000}},	//   zume, _תגים_, --, --, 
   {{0x2d840d81,0x69c1ead4,0x9185ead5,0x644000cf}},	//   _pume_, yume, _مجسم, úlie, 
   {{0x865002d3,0x69c00014,0x00000000,0x00000000}},	//   _መንነት, xume, --, --, 
   {{0x2d840200,0x00000000,0x00000000,0x00000000}},	//   _vume_, --, --, --, 
   {{0x6ecc0034,0x69c1ead6,0x6b8401e4,0xfbcc007b}},	//   _हापु, wume, ĉigo, كتي_, 
   {{0x69c1ead7,0x2d85ead8,0xe9a813f9,0x00000000}},	//   tume, _tume_, نگتن_, --, 
   {{0x2d85cf05,0xc6e40220,0x2ba42677,0xdde8004b}},	//   _uume_, ңімп, _गौरा, _لرله_, 
   {{0xdb0001e6,0xc7b80c98,0x6a840022,0xc62000cc}},	//   _avlä, нём_, ылҩа, _পখলা_, 
   {{0x815400c8,0x69c03760,0x6d480175,0x00000000}},	//   רסיע_, sume, _ijda, --, 
   {{0x69c1ead9,0xfaa006ed,0x29180037,0x00000000}},	//   pume, _гацо, örab_, --, 
   {{0x60c40334,0x98a406be,0x00000000,0x00000000}},	//   yghm, allı_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf7706e93,0x24580108,0x4cc400cc,0x693400e5}},	//   تای_, тавь_, _এসাঁ, _مکھر, 
   {{0x290c04b9,0x63440024,0x00000000,0x00000000}},	//   ljda_, rėno, --, --, 
   {{0x24800208,0x00000000,0x00000000,0x00000000}},	// [377f0] _tghm_, --, --, --, 
   {{0xb27447c7,0x60c5eada,0x628c007b,0xbfa80209}},	//   слуш, ughm, scao, етде_, 
   {{0x60c4016d,0x00000000,0x00000000,0x00000000}},	//   rghm, --, --, --, 
   {{0x5398025f,0x06e000bd,0x6d49eadb,0xb284010b}},	//   _שירו, যাকি, _ajda, _гырк, 
   {{0xde040798,0xdca42360,0x00000000,0x00000000}},	//   рпли, аали, --, --, 
   {{0x5bb595fc,0x295400d1,0x4af400f2,0x00000000}},	//   асиф, _ﺋﯜﭺ_, یکند_, --, 
   {{0x8ea400f7,0x00000000,0x00000000,0x00000000}},	//   الۇۇ, --, --, --, 
   {{0x7c2856c0,0x63a001a2,0x6d4802d0,0xd5b401ad}},	//   _đorđ, álny, _ejda, _अटलज, 
   {{0x13dc3857,0x7f580117,0xc9a40108,0x00000000}},	//   ডিয়, _ikuq, авые_, --, 
   {{0x9f5002fb,0xf8ac030f,0xfca800ec,0x19a80132}},	//   _mrzí_, سکت_, _سائو_, нтүп_, 
   {{0x6c840491,0xd7045c9e,0x5745eadc,0x69dc0276}},	//   _المم, азни, иноб, ărea, 
   {{0x7bc1eadd,0x15b8010b,0x00000000,0x00000000}},	//   munu, кыгы_, --, --, 
   {{0xa06402d3,0xb8e80154,0x00000000,0x00000000}},	//   _ውሳኔታ, _লস_, --, --, 
   {{0x9424021f,0x18341291,0x00000000,0x00000000}},	//   амге, _پرتح, --, --, 
   {{0x7f580928,0x53a416c3,0x3cf000bc,0x00000000}},	//   _okuq, рабб, _आफैं_, --, 
   {{0x95844945,0x46a0085a,0x96b83348,0xc3202424}},	//   _клие, _даъв, _руку_, омск, 
  
   {{0x55e4010b,0xe6c400cf,0x37b40154,0xe3b401ec}},	// [37800] _топб, _اتىي, _জহির, _құт_, 
   {{0x7f58bf21,0x98bc07f7,0x41004a03,0x7b300356}},	//   _akuq, _एएफए, озув, găuz, 
   {{0x7bc1eade,0x98bc05d7,0x753deadf,0x00000000}},	//   junu, _एएनए, mirz, --, 
   {{0x7bc1eae0,0x14d0412f,0xfd540ca8,0x64400210}},	//   dunu, द्रण, _ibaṣ, źlic, 
   {{0xcd04228e,0x00000000,0x00000000,0x00000000}},	//   ички, --, --, --, 
   {{0x7f580928,0x7bc0c821,0x5164004e,0x00000000}},	//   _ekuq, funu, _түзү_, --, 
   {{0xfba5eae1,0x00000000,0x00000000,0x00000000}},	//   атый_, --, --, --, 
   {{0x753c026c,0x7bf402e8,0x00000000,0x00000000}},	//   hirz, рнър_, --, --, 
   {{0x2728000f,0x7bc1eae2,0xa0640023,0x753deae3}},	//   _jûne_, aunu, _ውሳነታ, kirz, 
   {{0x2728045f,0x3b1c0113,0x69341e76,0x00000000}},	//   _mûne_, akuq_, ённу, --, 
   {{0x6d58789b,0xe83802bf,0x7bc1eae4,0x4c3402d5}},	//   mova, упні_, cunu, _тэат, 
   {{0x7b840075,0x00000000,0x00000000,0x00000000}},	//   _ئالە, --, --, --, 
   {{0x6b88faea,0x094831b0,0xfd5401e1,0x9f6400dd}},	//   _hudg, _ички_, _abaṣ, ítés_, 
   {{0x7c280fb9,0x79c402f2,0x00000000,0x00000000}},	//   _ömrü, _ئووف_, --, --, 
   {{0x02a469bd,0xdce00006,0x6b89eae5,0x838400f7}},	//   ирам, _eilė, _judg, рыге, 
   {{0x6d59eae6,0x6b89eae7,0x634400c0,0x00000000}},	//   hova, _mudg, mėnk, --, 
   {{0x6d582333,0x673c0dad,0xf771eae8,0x764809a5}},	// [37810] kova, misj, _تاو_, şdyr, 
   {{0x7bc1eae9,0x661dbaf5,0x6d59273e,0x6b88257d}},	//   yunu, mysk, jova, _oudg, 
   {{0x661c000f,0x6b89eaea,0x24180220,0x7bc00213}},	//   lysk, _nudg, _соны_, xunu, 
   {{0x7bc1eaeb,0x673deaec,0x00000000,0x00000000}},	//   vunu, nisj, --, --, 
   {{0x6d59eaed,0x661c0b21,0x2728045f,0x6b880055}},	//   fova, nysk, _gûne_, _audg, 
   {{0x06e00154,0x673c000d,0x33f403c7,0x00000000}},	//   যাটি, hisj, _اسیس, --, 
   {{0x6b882ab1,0x673c6eeb,0x661cf59b,0x00000000}},	//   _cudg, kisj, hysk, --, 
   {{0x7bc1eaee,0x7f587ea9,0x753c1529,0x673c02d3}},	//   runu, _ukuq, zirz, jisj, 
   {{0x6d584ea1,0x661c04ce,0x673c1a82,0x7bc1eaef}},	//   bova, jysk, disj, sunu, 
   {{0x7bc1eaf0,0x6d58278a,0x661deaf1,0x6b88045a}},	//   punu, cova, dysk, _fudg, 
   {{0x7bc1eaf2,0x673c0a85,0x6b89eaf3,0x753c005f}},	//   qunu, fisj, _gudg, virz, 
   {{0x661c0b21,0x673c8e5d,0xdce00064,0x28d81be1}},	//   fysk, gisj, _pilė, ब्बि, 
   {{0xcb100302,0xaa09eaf4,0x661c0b21,0x673c007f}},	//   _מלא_, _نزول_, gysk, èrja, 
   {{0x63a40369,0x7998b35f,0x2728000f,0x2618012d}},	//   _bwhn, mpuw, _rûne_, _पथरी_, 
   {{0xfd640241,0x673c168c,0x2728000f,0x06e0015b}},	//   _burẹ, bisj, _sûne_, যাজি, 
   {{0x661deaf5,0xe7ec228d,0x93599fa2,0x0440118b}},	//   bysk, _जनता_, ургу_, чесн, 
   {{0x6d59eaf6,0x79980784,0x04e403d4,0x00000000}},	// [37820] yova, npuw, _ওচৰৰ_, --, 
   {{0xd008192a,0x3320ba45,0x94080117,0x1bf806e3}},	//   лезе_, skix_, _беоб_, ्माल_, 
   {{0x2728002d,0x8e3806c1,0x63a800f3,0x4938010f}},	//   _wûne_, گسار_, ćenc, נגעו, 
   {{0x8cd80a28,0x6b895a4f,0x5275eaf7,0x8d8408ca}},	//   प्नो, _rudg, _гугу, букд, 
   {{0x1ea807c0,0x612001f2,0x6b89eaf8,0x998800a2}},	//   شاني_, _ịlek, _sudg, _çaň_, 
   {{0xfa341b49,0xc0dc4be7,0x40a83ee6,0x6b8800dc}},	//   _እስላማ, ፒታል_, _مخفی_, _pudg, 
   {{0x661c84c9,0x92c8009e,0x6b747995,0xeee4072d}},	//   zysk, লজী_, олку, _وغری, 
   {{0x6d59eaf9,0x6b88014f,0x0d840395,0x673c9306}},	//   sova, _vudg, _глан, xisj, 
   {{0x6d593542,0x673deafa,0x7998089c,0x00000000}},	//   pova, visj, gpuw, --, 
   {{0x8c44170a,0x6d59eafb,0x6b880165,0x8ba401a9}},	//   _лезе, qova, _tudg, _гижж, 
   {{0xfce1eafc,0x673c4b35,0x4158008f,0x29440873}},	//   _хохо, tisj, רדיג, ﺘﯩﭗ_, 
   {{0x661deafd,0x5fc801f9,0x00000000,0x00000000}},	//   tysk, ांतल, --, --, 
   {{0x673deafe,0xc95801b9,0x00000000,0x00000000}},	//   risj, _йўк_, --, --, 
   {{0x673c1a82,0x661deaff,0xda64a521,0x1954004b}},	//   sisj, rysk, _بامي, _وروڼ, 
   {{0x661deb00,0x673deb01,0x634400c0,0x00000000}},	//   sysk, pisj, lėni, --, 
   {{0x69c1eb02,0x661c94ea,0xcfcc015b,0x054401c6}},	//   orme, pysk, রবান, рүүл_, 
   {{0x69c008cd,0x9f440241,0x00000000,0x00000000}},	// [37830] nrme, _èlé_, --, --, 
   {{0x69c0be47,0x00000000,0x00000000,0x00000000}},	//   irme, --, --, --, 
   {{0xefe0044e,0x69c00112,0x5f9400d8,0x00000000}},	//   _ናተይ_, hrme, циет, --, 
   {{0x9df8d936,0xad2408b0,0xe2f80212,0x79980309}},	//   инет_, ۋىنى, _темі_, ypuw, 
   {{0xf10800db,0x00000000,0x00000000,0x00000000}},	//   _گۉلۉ_, --, --, --, 
   {{0x28d8c725,0x9f5002f0,0xa3cc08f2,0x634400c0}},	//   _बॉलि, _drzá_, _रमा_, dėni, 
   {{0x69c00d49,0x60a002d3,0x00000000,0x00000000}},	//   erme, _ጎስጓስ_, --, --, 
   {{0x29181876,0x81600345,0x00000000,0x00000000}},	//   öran_, _بۆڕۆ, --, --, 
   {{0x3eac00b5,0x00000000,0x00000000,0x00000000}},	//   magt_, --, --, --, 
   {{0x3eac00ed,0x79980113,0x00000000,0x00000000}},	//   lagt_, rpuw, --, --, 
   {{0x1868311b,0x69c1eb03,0xd7080953,0x57480556}},	//   рани_, arme, анне_, изом_, 
   {{0x9a240116,0x3eac0072,0x61fc00ee,0x00000000}},	//   _мулa, nagt_, _orsl, --, 
   {{0xdce000b8,0x64400162,0x00000000,0x00000000}},	//   _nilī, úlin, --, --, 
   {{0xdb0003a1,0x00000000,0x00000000,0x00000000}},	//   _avlø, --, --, --, 
   {{0x48ec05ba,0x61fd305e,0x798001e2,0x96b81b4f}},	//   _असतो_, _arsl, _iinw, _купу_, 
   {{0x79800639,0x7988ad5d,0x3eac3586,0x00000000}},	//   _hinw, _kugw, jagt_, --, 
   {{0x7981eb04,0x3eacecf1,0x6b8400df,0x00000000}},	// [37840] _kinw, dagt_, ĉigi, --, 
   {{0x7989eb05,0x79800263,0xdce0002b,0x273401d9}},	//   _mugw, _jinw, _dilī, _وى۪س, 
   {{0x7981eb06,0x4fe9eb07,0xdd98007f,0xe1f0040b}},	//   _minw, рмен_, _atň_, وسے_, 
   {{0x798006d6,0x61fc01e4,0x0e64004e,0xf984007b}},	//   _linw, _frsl, окен, _يب_, 
   {{0x3e7c00b0,0x3f84041e,0x6aa800cc,0x00000000}},	//   _rätü_, ínur_, _গালো, --, 
   {{0xdb000142,0x7981bdfc,0x63440024,0x9e702374}},	//   _bwlï, _ninw, vėni, رۇلت, 
   {{0x79880857,0x3eac991b,0xc02400f1,0x409006c2}},	//   _augw, bagt_, _وړمه_, _آلفر, 
   {{0x7989eb08,0x7981eb09,0x00000000,0x00000000}},	//   _bugw, _ainw, --, --, 
   {{0x798194f7,0x69c00489,0x00000000,0x00000000}},	//   _binw, urme, --, --, 
   {{0xada49246,0x79800014,0x00000000,0x00000000}},	//   _мағл, _cinw, --, --, 
   {{0x7981eb0a,0x1cf448a7,0x80cc02a0,0x2ba4012d}},	//   _dinw, _رکوع_, स्टइ, _ऐबटा, 
   {{0x79800730,0x2cacad79,0x1db0033f,0x98a40171}},	//   _einw, _hedd_, ुंचत, filē_, 
   {{0x2cadeb0b,0x79881418,0x28f82179,0x79800419}},	//   _kedd_, _gugw, _гель_, _finw, 
   {{0x79800369,0x2418425c,0x2cac025c,0x999401d3}},	//   _ginw, богы_, _jedd_, _ڈھیر_, 
   {{0x38980375,0x2cac03cb,0xdce00171,0x00000000}},	//   _דיונ, _medd_, _silī, --, 
   {{0x68e9eb0c,0x2cac03a1,0x61fc1050,0xd498016c}},	//   ledd, _ledd_, _prsl, ирӣ_, 
   {{0x2cac0f7b,0x3eac00b5,0x798019c8,0x68e80042}},	// [37850] _oedd_, vagt_, _yinw, oedd, 
   {{0x8024167e,0x68e9eb0d,0x25a9eb0e,0x79800564}},	//   يرام, nedd, _iwal_, _xinw, 
   {{0x94180134,0x3eadeb0f,0xa29428f6,0x00000000}},	//   _mepɛ_, tagt_, _нані, --, 
   {{0x68e9eb10,0x25a80b45,0x00000000,0x00000000}},	//   hedd, _kwal_, --, --, 
   {{0x7de40491,0x68e88daf,0x3eadeb11,0xdd9000f1}},	//   تسام, kedd, ragt_, روغ_, 
   {{0x3eadeb12,0x61ec0925,0x79885571,0x68e803a1}},	//   sagt_, mwal, _rugw, jedd, 
   {{0x61ed3bc3,0x7981eb13,0x68e9eb14,0x2a70013f}},	//   lwal, _rinw, dedd, ɑnbɑ_, 
   {{0x7981eb15,0x25a8349b,0x13580092,0x80a0000d}},	//   _sinw, _owal_, _ለእነዚ, गरके, 
   {{0x61edeb16,0x7981eb17,0x7f480921,0x68e80368}},	//   nwal, _pinw, mngq, fedd, 
   {{0x68e9eb18,0x798802b9,0x61edeb19,0x2cac04e6}},	//   gedd, _vugw, iwal, _gedd_, 
   {{0x61ec15d3,0x25a82f2b,0x99857b47,0x21980150}},	//   hwal, _awal_, _کلتو, _ﺘﻨﻔﻴ_, 
   {{0x61edeb1a,0x79819a26,0x79890494,0xfbf0014b}},	//   kwal, _winw, _tugw, _ноҷӯ, 
   {{0x68e9eb1b,0x61edeb1c,0x63b40034,0x7f480472}},	//   bedd, jwal, eszn, ingq, 
   {{0x61edeb1d,0x25a80135,0x68e9eb1e,0x2cac031c}},	//   dwal, _dwal_, cedd, _xedd_, 
   {{0x61edeb1f,0xb9e4044e,0xd4680276,0xe14002d3}},	//   ewal, _ዮሃ_, сиве_, _ተረጋጊ, 
   {{0x61ec192e,0x96a801d5,0x63440064,0x00000000}},	//   fwal, _укиб_, kėnu, --, 
   {{0x61edeb20,0x25a84430,0x7bc002fd,0x15448372}},	// [37860] gwal, _gwal_, hrnu, _неим, 
   {{0x7f480226,0x01600902,0x00000000,0x00000000}},	//   engq, екуо, --, --, 
   {{0x2cadeb21,0x2294063f,0x362401d9,0x61ec04ba}},	//   _redd_, _ụke_, _روگہ, awal, 
   {{0x68e9eb22,0x2cadeb23,0x61edeb24,0xdb2001e1}},	//   zedd, _sedd_, bwal, _ìtès, 
   {{0x61ec2747,0x68e9eb25,0x7bc001f5,0x1ee802f2}},	//   cwal, yedd, ernu, زووی_, 
   {{0x7dc01066,0xd00801ee,0x68e801bf,0xe7ec000d}},	//   رقىن, _леге_, xedd, _जनला_, 
   {{0x8fa47ffa,0x68e9eb26,0x9418013f,0x7bc00e3c}},	//   _хабе, vedd, _repɛ_, grnu, 
   {{0x68e9eb27,0x2cac03cb,0x00000000,0x00000000}},	//   wedd, _wedd_, --, --, 
   {{0x2cadeb28,0x68e9eb29,0x7bc020ac,0xccc40137}},	//   _tedd_, tedd, arnu, _нбай, 
   {{0x29181873,0x36d801c0,0x63b4033f,0x9f50013d}},	//   ðra_, үдээ_, yszn, _erzä_, 
   {{0x61ec068f,0x68e9eb2a,0xca8408da,0x00000000}},	//   zwal, redd, _егей, --, 
   {{0x68e9eb2b,0x25a802bd,0x61edeb2c,0x00000000}},	//   sedd, _pwal_, ywal, --, 
   {{0x68e8127b,0xb0cc0a97,0x61ecb021,0xdb2402f2}},	//   pedd, ालाग, xwal, _زووی, 
   {{0x61edeb2d,0x25a802e2,0xdb00015d,0x0a440092}},	//   vwal, _vwal_, _gwlâ, _ዕድሜያ, 
   {{0x63a82d2b,0x61edeb2e,0xf8d80375,0x00000000}},	//   ćeno, wwal, _החומ, --, 
   {{0x61edeb2f,0x28d87382,0x25a9eb30,0x59a801bc}},	//   twal, ब्रि, _twal_, चीवर, 
   {{0x25a80214,0x672deb31,0x61ec01f5,0x483000f1}},	// [37870] _uwal_, _ilaj, uwal, _زوکړ, 
   {{0xe298052f,0x61edeb32,0x672deb33,0x7bc00008}},	//   саҡ_, rwal, _hlaj, yrnu, 
   {{0x61edeb34,0x672deb35,0xdb0006ea,0x28d43c71}},	//   swal, _klaj, _avlý, _दानि, 
   {{0x7bc00989,0x672c00f2,0x61edeb36,0x6e94035b}},	//   vrnu, _jlaj, pwal, еицу, 
   {{0x61ec00aa,0x672deb37,0x44200158,0x12f8011a}},	//   qwal, _mlaj, lyj_, _והרב, 
   {{0x672c0bf1,0x2369eb38,0x6d2402dd,0x6ea80014}},	//   _llaj, llaj_, ндіз, _ہۆمہ_, 
   {{0xdd9000f8,0x6ee40100,0x46bc0316,0x672deb39}},	//   روں_, _bčbč, ्लाह, _olaj, 
   {{0x9f05eb3a,0xfeb80330,0xbcd82099,0xfdb00166}},	//   _تورو, _داست_, _گذرا_, _зәкя, 
   {{0x1dd0302b,0x7bc005ce,0x97240724,0xd7c800f1}},	//   _समित, srnu, äşmä, ښوده_, 
   {{0x672deb3b,0x9cb404fb,0x00000000,0x00000000}},	//   _alaj, _آمات, --, --, 
   {{0x442000b5,0x2369eb3c,0x00000000,0x00000000}},	//   jyj_, klaj_, --, --, 
   {{0x98ac41d5,0x2369eb3d,0x1dd00e57,0x7c200042}},	//   ının_, jlaj_, _समात, mynr, 
   {{0xd91401c0,0x5a2401ed,0x2369eb3e,0x7c2002d0}},	//   _одды, _تباہ, dlaj_, lynr, 
   {{0x672c0100,0x2369eb3f,0x28d49f23,0xb4c80892}},	//   _elaj, elaj_, _दायि, उले_, 
   {{0x2369eb40,0x00000000,0x00000000,0x00000000}},	//   flaj_, --, --, --, 
   {{0x2369eb41,0xca680372,0x672deb42,0x2c3c0023}},	//   glaj_, _الۇۇ_, _glaj, _ክንጅም, 
   {{0x7c21eb43,0xd18400c0,0x27e001a6,0x5f1000dc}},	// [37880] hynr, длай, _ćini_, णान्_, 
   {{0x672c1505,0x2368010f,0xd17418c7,0x7c20010e}},	//   _zlaj, alaj_, фыбы, kynr, 
   {{0x2369eb44,0x4f6400ae,0x00000000,0x00000000}},	//   blaj_, واصف, --, --, 
   {{0x6e94036b,0x00000000,0x00000000,0x00000000}},	//   رلتا, --, --, --, 
   {{0x9f6400dd,0x3f900e14,0x48ec01f9,0x00000000}},	//   ítás_, aqxu_, _असलो_, --, 
   {{0xeee0000d,0x0c840166,0x98a40246,0x00000000}},	//   _गउवऽ_, мыйм, milė_, --, 
   {{0xfbcdeb45,0xd00800d8,0x7c2000a2,0x7e6c0171}},	//   لتي_, _ќебе_, gynr, _ģipš, 
   {{0x7764031c,0x8eb00150,0x29000205,0x00000000}},	//   _nkix, _شەتت, _şia_, --, 
   {{0x44200034,0x88e800d8,0x98a400c0,0x00000000}},	//   zyj_, оќна_, nilė_, --, 
   {{0x7c2003a2,0xa8158c08,0x672d63c9,0xbb3c00d1}},	//   bynr, едош, _slaj, ﯜﻳﻰ_, 
   {{0xcb68722e,0x672deb46,0x8c257cd3,0x00000000}},	//   _даже_, _plaj, _تفاه, --, 
   {{0x272800d2,0x8cd82802,0x672c031c,0xa63402dd}},	//   _vûno_, प्रो, _qlaj, енмі, 
   {{0x672c022a,0x78c405ac,0x00000000,0x00000000}},	//   _vlaj, ærvå, --, --, 
   {{0x44200200,0x00000000,0x00000000,0x00000000}},	//   tyj_, --, --, --, 
   {{0x5f100882,0x291c0393,0x672deb47,0x00000000}},	//   णाम्_, _iova_, _tlaj, --, 
   {{0x68f8105c,0x291deb48,0x672c99ec,0x44200034}},	//   _havd, _hova_, _ulaj, ryj_, 
   {{0x291c0eed,0x250804fb,0x23680113,0xe7c800e2}},	// [37890] _kova_, _فردی_, rlaj_, kļūš, 
   {{0x291deb49,0x68f831c5,0x236805b1,0xf5241188}},	//   _jova_, _javd, slaj_, _афюн, 
   {{0x6564009a,0x2e9c02e3,0x2369eb4a,0x2bac0210}},	//   _ikhh, _ịjụ_, plaj_, jśc_, 
   {{0x68f802d3,0x41c402ab,0x9f200131,0x00000000}},	//   _lavd, _लिपस, دۈرۈ, --, 
   {{0x1d0806da,0x68f801a9,0x7c20002d,0x80f000c7}},	//   зели_, _oavd, wynr, _иҿах, 
   {{0x68f9eb4b,0x8cd81b76,0xc0580212,0x00000000}},	//   _navd, प्लो, _діб_, --, 
   {{0xdb000548,0xa3c4547d,0x3f900327,0x00000000}},	//   _awlá, उंट_, qqxu_, --, 
   {{0x7c20002d,0x158c02dd,0x00000000,0x00000000}},	//   rynr, _ﻛﻮﺑﯩ, --, --, 
   {{0x6b64006a,0x291deb4c,0xda0828fa,0x68f8022e}},	//   _sïgî, _bova_, سيده_, _bavd, 
   {{0x63a89ac0,0x291deb4d,0x7c200649,0x7a9c0490}},	//   ćenj, _cova_, pynr, _ग्रॅ, 
   {{0x291deb4e,0xdef8002e,0xad241178,0x3158008f}},	//   _dova_, _kaŋ_, _جىلى, ויזן_, 
   {{0x656406d1,0x9f48020c,0x2bc801ec,0x00000000}},	//   _akhh, èkèl_, _іліп_, --, 
   {{0x291c05d5,0x65640175,0x68f80427,0x80c40011}},	//   _fova_, _bkhh, _favd, র্য্, 
   {{0x291c02c4,0x7af9eb4f,0x68f801b9,0x98a40024}},	//   _gova_, ldut, _gavd, vilė_, 
   {{0x187400c8,0x229400b4,0x88f401ec,0x77640327}},	//   _אײַך_, _ụka_, _سىير_, _tkix, 
   {{0x23b05345,0x3ebc0e02,0x291c00f3,0x98a40153}},	//   _जबरद, _ndut_, _zova_, tilė_, 
   {{0x68f8016d,0x00000000,0x00000000,0x00000000}},	// [378a0] _yavd, --, --, --, 
   {{0x7af802f6,0x00000000,0x00000000,0x00000000}},	//   hdut, --, --, --, 
   {{0xb4ac06bc,0xc0d000db,0x00000000,0x00000000}},	//   खरी_, ايمب, --, --, 
   {{0x7af80023,0xd1b08fde,0x00000000,0x00000000}},	//   jdut, _میرک, --, --, 
   {{0xdef8002e,0x7af9eb50,0x95ec012c,0x718446ee}},	//   _daŋ_, ddut, _छनोट_, _ақае, 
   {{0x7af80077,0x3ebc005b,0x2c0400d1,0x00000000}},	//   edut, _edut_, күзм, --, 
   {{0x291d662e,0xd478008f,0x68f8014f,0x70cc0892}},	//   _rova_, האַל, _ravd, ालील, 
   {{0x68f807d6,0x291deb51,0x7af801f5,0xee4400c7}},	//   _savd, _sova_, gdut, _иҭеи, 
   {{0x291c0115,0x68f80240,0x28d44709,0x4e040166}},	//   _pova_, _pavd, _दादि, _язаб, 
   {{0x7af8208d,0x3a7029db,0xf1bc0131,0xf98c3592}},	//   adut, ылыр, _ﺧﻪﻟﻘ, حبي_, 
   {{0x291deb52,0x7af8022f,0xe75802bf,0x68f8016d}},	//   _vova_, bdut, дині_, _vavd, 
   {{0x81e402f5,0x291c0099,0x65942401,0x00000000}},	//   ভিত_, _wova_, каму, --, 
   {{0x291c2f09,0x5f1000dc,0x320001d5,0xbb38011a}},	//   _tova_, णात्_, jviy_, _צעדי, 
   {{0x291c00a7,0xb7dc00fe,0x00000000,0x00000000}},	//   _uova_, _বছৰট, --, --, 
   {{0x24840267,0x96a00412,0xa2ac0118,0x3cf000cd}},	//   älm_, _क्वॉ, जरल्, ूयते_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf65000b2,0x60f831af,0xdef8002e,0x60d40175}},	// [378b0] _ٿئي_, мная_, _raŋ_, _pczm, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf650066d,0xf8b00bd9,0xdcb0004d,0xaf980212}},	//   _نئی_, רשע_, _rẻ_, етіх_, 
   {{0xdcb0004d,0xbf641d0a,0x02a40024,0x3078007b}},	//   _sẻ_, رداو, _яром, رحلة_, 
   {{0x62980165,0x7af80003,0x00000000,0x00000000}},	//   ñwou, vdut, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdef800e8,0x7af8045f,0x606401b9,0xdcb0004d}},	//   _taŋ_, tdut, _شهرل, _vẻ_, 
   {{0x3ebc6085,0x64400034,0x7af8023a,0x00000000}},	//   _udut_, źliw, udut, --, 
   {{0xdd95eb53,0x7af9eb54,0xceb401af,0x00000000}},	//   _разы, rdut, _рәх_, --, 
   {{0x7af8011c,0x95ec0316,0x00000000,0x00000000}},	//   sdut, _छनौट_, --, --, 
   {{0xeb3000cf,0x3ab001af,0x00000000,0x00000000}},	//   _گۉيد, _йәпт, --, --, 
   {{0x15c82d40,0x3ab000fb,0x00000000,0x00000000}},	//   _ﺑﻪﺭﺩ, _сәкт, --, --, 
   {{0x98a40270,0x96540395,0xceb0011a,0x00000000}},	//   nilī_, тънч, סיך_, --, 
   {{0xb4ac3b29,0x629deb55,0x96a010eb,0xd94400d8}},	//   खरे_, _afso, _क्रॉ, _шели, 
   {{0xa2ac0210,0x00000000,0x00000000,0x00000000}},	//   _ज़ख्, --, --, --, 
   {{0x91e4201d,0x98a40093,0x07a0059f,0xd9e40037}},	//   кобе, kilī_, _таън, _कहात_, 
   {{0x8778008f,0x673c0023,0x00000000,0x00000000}},	// [378c0] _קאפי, ërje, --, --, 
   {{0x6458006d,0x10a40828,0x70cc0b40,0x45b4008f}},	//   _świe, тижн, ालेल, _שפיל_, 
   {{0xd2a811ed,0x53a4136b,0xd9e4000d,0x00000000}},	//   _окне_, _шанб, _कहऽत_, --, 
   {{0x25ac084c,0x527400a8,0x00000000,0x00000000}},	//   ţele_, _аугу, --, --, 
   {{0xdce0007f,0x2284022e,0x00000000,0x00000000}},	//   _eklč, _буёг, --, --, 
   {{0x9e65eb56,0x4638010f,0x2ae40118,0x00000000}},	//   دامن, וענע, झ्नु_, --, 
   {{0xddc8013a,0x00000000,0x00000000,0x00000000}},	//   _vzeš, --, --, --, 
   {{0x96a006ab,0x74b800fe,0xcee802f2,0xfbcc01e2}},	//   _क्लॉ, জলিউ, _ترسن_, آتو_, 
   {{0x63a804b9,0x0d85eb57,0xecd4e9f1,0x0e6400c7}},	//   ćeni, _алан, _محاک, _ркан, 
   {{0x0c7875f5,0xc27800d9,0x39a40248,0x0905eb58}},	//   _قصاب_, ורפי, _sísò_, тчим, 
   {{0x5bc42ed7,0x98e401e0,0x2d8deb59,0x00000000}},	//   _متنف, усыһ, _iide_, --, 
   {{0x2d8ceaa1,0x4a4401af,0x00000000,0x00000000}},	//   _hide_, _инев, --, --, 
   {{0x2d8d3ef6,0x69dc0311,0x2b980208,0x00000000}},	//   _kide_, ăres, _héc_, --, 
   {{0x2d8deb5a,0x02c80316,0x67d58f55,0xa3d401c6}},	//   _jide_, िल्न, _боку, логч, 
   {{0x2d8d5bfe,0x9fbc0011,0x00000000,0x00000000}},	//   _mide_, _ইঙ্গ, --, --, 
   {{0x2d8deb5b,0x81e400bd,0x2b980051,0x4900009d}},	//   _lide_, ভিস_, _méc_, _сүүг, 
   {{0x91c009a5,0x2d8c12ef,0x00000000,0x00000000}},	// [378d0] йәрл, _oide_, --, --, 
   {{0x2d8c2165,0x637803b2,0x0574516c,0x60b5eb5c}},	//   _nide_, _búný, _جاعد, امائ, 
   {{0x91c000d1,0x00000000,0x00000000,0x00000000}},	//   _қәтл, --, --, --, 
   {{0x2d8c2047,0xdd9563b6,0x05b401ad,0x62340117}},	//   _aide_, гады, _अबाब, _бему, 
   {{0x2d8deb5d,0xdcb001fb,0x00000000,0x00000000}},	//   _bide_, _hỏi_, --, --, 
   {{0x8d280046,0x2d8c00fd,0x2b980051,0x00000000}},	//   ннің_, _cide_, _béc_, --, 
   {{0x2d8deb5e,0x8c40955d,0x6b7c0055,0x00000000}},	//   _dide_, йеше, _ṅgap, --, 
   {{0x2b993dd9,0x133c0020,0x2d8c168c,0xfeb802e9}},	//   _déc_, _ከእነዚ, _eide_, _زارت_, 
   {{0x2d8d3d43,0x00000000,0x00000000,0x00000000}},	//   _fide_, --, --, --, 
   {{0x2d8deb5f,0xe70801d9,0x320400d7,0x6e2412ce}},	//   _gide_, ۆتُن_, _šmyk_, äibe, 
   {{0x28d41a2a,0x178401c0,0xe9a802f2,0x00000000}},	//   _दारि, лгом, _یدون_, --, 
   {{0xeb3400aa,0x2d8deb60,0xdb000267,0xeab000db}},	//   _پرمخ, _zide_, _avlö, _ۇعۇ_, 
   {{0x2d8c88e8,0x5df8010f,0x00000000,0x00000000}},	//   _yide_, עפֿנ, --, --, 
   {{0x21dc02dd,0x00000000,0x00000000,0x00000000}},	//   _ﺇﺴﺘﺭ, --, --, --, 
   {{0x0fcc00eb,0x00000000,0x00000000,0x00000000}},	//   _রন্ধ, --, --, --, 
   {{0xd9440116,0x764002f0,0x23340117,0x70cc00cd}},	//   _шеһи, úmys, ахур, ाल्ल, 
   {{0x314400a6,0x904400ec,0x899400df,0x00000000}},	// [378e0] адаҳ, گناه, ָכעס_, --, 
   {{0x80c40154,0x00000000,0x00000000,0x00000000}},	//   র্স্, --, --, --, 
   {{0x2d8deb61,0x00000000,0x00000000,0x00000000}},	//   _ride_, --, --, --, 
   {{0x5fc8189a,0x2d8c0c3e,0x00000000,0x00000000}},	//   ांजल, _side_, --, --, 
   {{0x2d8c1280,0x2b99eb62,0x3c6c00d1,0x00000000}},	//   _pide_, _séc_, ﻴﯩﺘﻰ_, --, 
   {{0x3b0c0097,0x2d8c0548,0x8fd00166,0xd130007b}},	//   _angq_, _qide_, _гәдә, _امس_, 
   {{0x0b88a577,0xbccc00d0,0xc4d0011a,0x5cc40150}},	//   нсии_, íťaž, צגה_, рсіз, 
   {{0x2d8deb63,0x81e40154,0x2b980051,0xc0f40092}},	//   _wide_, ভির_, _véc_, _ወቀሳ_, 
   {{0x2d8c3371,0x5f1005ba,0x2dc8005e,0x0948311b}},	//   _tide_, णार्_, _جازۋ_, ечни_, 
   {{0x3b0c0399,0xc2340375,0x2d8deb64,0x00000000}},	//   _engq_, טרפו_, _uide_, --, 
   {{0x7c900491,0x4ae40517,0xfa30006c,0xa7140816}},	//   _المص, _бўла, لرید, амні, 
   {{0xd7c400cd,0x00000000,0x00000000,0x00000000}},	//   _विरच, --, --, --, 
   {{0x29195403,0xebc40131,0xf5c401b9,0x6595eb65}},	//   öras_, _сәһн, йёрм, рагу, 
   {{0xdb01eb66,0x49900214,0xfd7c0023,0x00000000}},	//   _atlè, _پیگر, ትፈልጦ_, --, 
   {{0x896001d9,0x67d400db,0x43080818,0x6e3c03b9}},	//   _پُژن, _тойу, нхам_, _ərba, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc2f4015b,0xc6a40022,0x55c0728c,0x6ed8000d}},	// [378f0] ঙালি_, _ирҿи, _мәрз, _डा़ँ, 
   {{0xf1c800c6,0x81e40eac,0x193800b5,0x9f5002f0}},	//   اولى_, ভিল_, _ｔｏｐ_, _drzý_, 
   {{0xa3e800bc,0x00000000,0x00000000,0x00000000}},	//   _यहि_, --, --, --, 
   {{0x63a4009f,0x709400c2,0x00000000,0x00000000}},	//   _ithn, _ҳарф, --, --, 
   {{0xdce1eb67,0x9b448f52,0x00000000,0x00000000}},	//   _jilħ, ینتو, --, --, 
   {{0xa3e804af,0xdce0031c,0xa159eb68,0xdee002d3}},	//   _यहा_, _milħ, _рагу_, ነትካ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x80c40154,0x6f84009d,0x19c401d5,0x00000000}},	//   র্শ্, _гууж, абим, --, 
   {{0x7f482d2f,0xdce0025c,0x1a6401d5,0x00000000}},	//   migq, _nilħ, جیشی_, --, 
   {{0x63a401ee,0x3b0c0369,0x7f49eb69,0xeff00092}},	//   _othn, _wngq_, ligq, _ቀጣዩ_, 
   {{0x6ac8007c,0x00000000,0x00000000,0x00000000}},	//   årfö, --, --, --, 
   {{0xdce00327,0x7f480472,0x27a40092,0xe8e800f2}},	//   _bilħ, nigq, ለሥላሴ_, پریو_, 
   {{0x63a400c6,0x16b402a0,0x9974010a,0x2818029e}},	//   _athn, _अजीब, _кукш, نفیگ_, 
   {{0x6458006d,0x18a5eb6a,0x98a531b9,0x7bc40fac}},	//   _świa, _такм, _тике, _åjus, 
   {{0xd468cf08,0xdb006bc5,0x63a40ac5,0x95b400c7}},	//   тиве_, _atlé, _cthn, ырҟә, 
   {{0x527475fe,0x00000000,0x00000000,0x00000000}},	//   аузу, --, --, --, 
   {{0xf6b00ca8,0x79980309,0x938801e0,0x98a40064}},	// [37900] _gẹẹs, nquw, есҡа_, nilį_, 
   {{0x399803b7,0x8678011a,0x00000000,0x00000000}},	//   _mês_, _ברפו, --, --, 
   {{0x39980b21,0x217401f4,0x00000000,0x00000000}},	//   _lês_, сутр, --, --, 
   {{0x4e280353,0x80c40154,0x4e0400db,0x00000000}},	//   коен_, র্ল্, изеб, --, 
   {{0x4df4023a,0x8e38ce83,0xfe40009d,0x02000024}},	//   ряет, خسار_, онцо, _дзян, 
   {{0x8bc4006c,0xeff0001f,0xd7c40a8a,0x00000000}},	//   асид, _ቀጣይ_, _विंच, --, 
   {{0x0eb801ec,0xdd8c00d1,0x16b4012d,0x00000000}},	//   _аузы_, رۈم_, _अजूब, --, 
   {{0x399805d5,0xbb80c530,0x98a40024,0x94f4031c}},	//   _bês_, يلوي, filį_, _བིའི_, 
   {{0x6f0001ab,0x39980142,0x5b181411,0x00000000}},	//   _iamc, _cês_, اعىڭ_, --, 
   {{0x8c443b5f,0x399800d8,0x6f01eb6b,0x00000000}},	//   _кезе, _dês_, _hamc, --, 
   {{0x6d49eb6c,0x6f01eb6d,0xc60c00cd,0x00000000}},	//   _imda, _kamc, ाम्य_, --, 
   {{0x09e5eb6e,0x98a40006,0x6f01eb6f,0x07451323}},	//   _водн, bilį_, _jamc, рхом, 
   {{0x93f8013f,0x6f002630,0x2bc402e3,0x39980142}},	//   _mepε_, _mamc, _ịche_, _gês_, 
   {{0x6f01eb70,0x69c02507,0x7f480912,0x00000000}},	//   _lamc, msme, zigq, --, 
   {{0x2728002d,0x7f480944,0x3978008f,0x1828552d}},	//   _bûnt_, yigq, _שטונ, _مقوی_, 
   {{0x6f01eb71,0xdce00135,0xc6a400d8,0x224c02d2}},	//   _namc, _tilħ, _трки, _þekk_, 
   {{0x6d49eb72,0xf99000c8,0xe5f0005b,0x63a40042}},	// [37910] _omda, ַרף_, ödää, _wthn, 
   {{0xe2980032,0xb1142db7,0x31c402d5,0x69c1eb73}},	//   таҡ_, омуш, ўств, isme, 
   {{0x6f000a07,0x63a80841,0xf4840345,0xff5000ae}},	//   _bamc, ćens, _واپی, يخص_, 
   {{0x26d8034c,0x6d49eb74,0x6f01eb75,0x69c000da}},	//   ngso_, _amda, _camc, ksme, 
   {{0x7cb404a9,0xde05eb76,0x69c070d2,0x6f01eb77}},	//   иқат_, спли, jsme, _damc, 
   {{0xee38063b,0x69c012ed,0xad240c50,0x6d480175}},	//   шні_, dsme, يىنى, _cmda, 
   {{0x27280b21,0x6f00007f,0xc0c000fd,0x200400e5}},	//   _jûns_, _famc, _гәҗи, _éli_, 
   {{0x6d49eb78,0x399804cc,0x7f480117,0x6f01eb79}},	//   _emda, _pês_, qigq, _gamc, 
   {{0x69c008ce,0x00000000,0x00000000,0x00000000}},	//   gsme, --, --, --, 
   {{0x27fc05b1,0x6f01eb7a,0x6d48022e,0x399800d8}},	//   _bsvn_, _zamc, _gmda, _vês_, 
   {{0x6f01eb7b,0x3998045f,0x69c00549,0xe7100024}},	//   _yamc, _wês_, asme, _dėžė, 
   {{0x61fc0c8c,0x6f000548,0x9cc80220,0x69c0005c}},	//   _ossl, _xamc, _шыға_, bsme, 
   {{0x6d48015d,0x95840b6e,0x00000000,0x00000000}},	//   _ymda, йлме, --, --, 
   {{0x27280a85,0xdd980432,0x27fc0051,0x00000000}},	//   _sûnt_, _muň_, _fsvn_, --, 
   {{0x61fdeb7c,0x1dd01d15,0x97c402dd,0x672c00e5}},	//   _assl, _समझत, _اقبو, üljö, 
   {{0x2728000f,0x53a5eb7d,0x6f900116,0x00000000}},	//   _dûns_, _қамб, _ﺑﺎﻫﺎ_, --, 
   {{0x6f01eb7e,0x61fc0175,0xdd98010e,0x00000000}},	// [37920] _ramc, _cssl, _nuň_, --, 
   {{0x2728045f,0x1dd00490,0x229c6791,0xc0e00798}},	//   _fûns_, _समजत, _pákó_, зофк, 
   {{0x61fdeb7f,0x6f01eb80,0x7e7800b5,0x4ea401b9}},	//   _essl, _pamc, _azup, брла, 
   {{0xdd9800e8,0x3fc8036b,0x6f01eb81,0x69c1eb82}},	//   _buň_, ادلی_, _qamc, ysme, 
   {{0x7ee01b06,0x81e42aab,0xb7ec015b,0x2cbc019b}},	//   سكون, ভিউ_, য়মিত_, tavd_, 
   {{0x69c19b76,0x6bd8007b,0x00000000,0x00000000}},	//   vsme, لوتس_, --, --, 
   {{0x6f007b10,0x69c1c712,0x3c04004d,0xe7100153}},	//   _tamc, wsme, _cđv_, _rėžė, 
   {{0xfbcc07a7,0xaf349a79,0x2e8800d1,0x00000000}},	//   رتى_, _بورژ, _көли_, --, 
   {{0x69c1eb83,0x6d4800a2,0x2bd40412,0x7f40036e}},	//   usme, _tmda, _धमका, ënqe, 
   {{0x69c1eb84,0x6d48c28e,0x00000000,0x00000000}},	//   rsme, _umda, --, --, 
   {{0x69c1eb85,0xdd800014,0x4785a965,0xe71000c0}},	//   ssme, _تیوٝ, йымб, _vėžė, 
   {{0x69c1eb86,0x6d58005f,0xddc8033f,0xdd9800e8}},	//   psme, lnva, _rzeź, _yuň_, 
   {{0xe9181fe2,0x6d58127b,0xc985eb87,0xe944129e}},	//   _волі_, onva, _луки, _ورتی, 
   {{0x6d59e7b6,0x61fc0175,0x46d866c0,0x00000000}},	//   nnva, _rssl, _भावह, --, 
   {{0x6d59eb88,0xf43406a6,0xb804009f,0x7b0408a5}},	//   inva, перэ, _هيوم_, _ártú, 
   {{0x61fc0004,0x00000000,0x00000000,0x00000000}},	//   _pssl, --, --, --, 
   {{0x2728002d,0x68e801f5,0x236801e4,0xe1d80006}},	// [37930] _wûns_, ofdd, roaj_, рдзі_, 
   {{0x660deb89,0x6d5801f5,0x25a9eb8a,0x3998011a}},	//   _irak, jnva, _ital_, טימד, 
   {{0xa2941fe2,0x7e7801ed,0x6440026c,0x22940d6f}},	//   _мані, _szup, ùlid, _миня, 
   {{0x660deb8b,0x6d58b730,0x4470004b,0x00000000}},	//   _krak, enva, _ونکړ, --, 
   {{0x5fc4069f,0x9f41eb8c,0x660c037e,0x61fc02d0}},	//   _लटकल, nthé_, _jrak, _ussl, 
   {{0x6d59560a,0x28d40d79,0x00000000,0x00000000}},	//   gnva, _दागि, --, --, 
   {{0x26c82625,0x98a40006,0x9f340212,0x00000000}},	//   _odao_, nklą_, _деві, --, 
   {{0x6d59eb8d,0x25a9eb8e,0x7f58014b,0x26c803d1}},	//   anva, _otal_, _ujuq, _ndao_, 
   {{0xe9a820bf,0x660c0687,0x7e780034,0x28d46495}},	//   یدین_, _nrak, _uzup, _दाखि, 
   {{0x26c80109,0x57e885c0,0xbd680640,0x68e80051}},	//   _adao_, адом_, _србе_, gfdd, 
   {{0x660d0f8f,0x25a9eb8f,0x7c8400d8,0x2bc8014b}},	//   _arak, _atal_, _ѓузе, _гучо_, 
   {{0x7bc06130,0xd5e4022e,0xd97800c7,0x00000000}},	//   msnu, ожми, ырқә_, --, 
   {{0x82e45078,0xba2841f5,0x660c5b3c,0x7bc003cd}},	//   _སྡེའ, _حسام_, _crak, lsnu, 
   {{0x21200327,0x00000000,0x00000000,0x00000000}},	//   jjhh_, --, --, --, 
   {{0x660deb90,0x7bc06afa,0x03a1eb91,0x25a800b8}},	//   _erak, nsnu, дисо, _etal_, 
   {{0x163800c6,0x52a800a7,0x7bc0bb46,0xd7581e24}},	//   _نسخة_, рвам_, isnu, _خلعت_, 
   {{0x660deb92,0x6d580724,0xd1302e0b,0x00000000}},	// [37940] _grak, ynva, ومر_, --, 
   {{0x7bc0bf1a,0x645400e5,0x9a98002b,0x00000000}},	//   ksnu, áfiá, _śālā, --, 
   {{0x660d84bb,0xdb0003b2,0x4fa4236b,0x6d580fac}},	//   _zrak, _atlí, циев, vnva, 
   {{0x660c4b36,0x7bc0002f,0xb3585533,0x8e081de6}},	//   _yrak, dsnu, _ایرا_, инев_, 
   {{0xb62c00b5,0x8d65282f,0x00000000,0x00000000}},	//   _ｔｓ_, овде, --, --, 
   {{0xf985cc9c,0x0ba5eb93,0x6d596ab3,0x00000000}},	//   _زب_, ошим, unva, --, 
   {{0x6d58f971,0x7bc07e42,0x1fb5eb94,0x7ee000d1}},	//   rnva, gsnu, _нстр, سكۈن, 
   {{0xdb000120,0x68e80142,0x00000000,0x00000000}},	//   _atlâ, wfdd, --, --, 
   {{0xb9943f48,0xccc4040e,0x9da406c2,0x00000000}},	//   овых_, _мбай, _فصله, --, 
   {{0x4c15c201,0x224c0209,0x660deb95,0x0214011a}},	//   _وباس, _ýeke_, _rrak, קחים_, 
   {{0x20042242,0x25a889fb,0x660deb96,0x7bc00fac}},	//   _álit_, _stal_, _srak, csnu, 
   {{0x660c1fc4,0x25a80118,0xe8c80139,0x00000000}},	//   _prak, _ptal_, шгүл_, --, 
   {{0xb6040006,0x00000000,0x00000000,0x00000000}},	//   мярк, --, --, --, 
   {{0xfa740375,0x25a803b2,0x673c02d0,0x41e400e5}},	//   _ועדת_, _vtal_, shsj, ےساف, 
   {{0x660deb97,0x3494dd4c,0x00000000,0x00000000}},	//   _wrak, дарр, --, --, 
   {{0x324c001f,0xa5c40139,0x00000000,0x00000000}},	//   _በመምጣ, _нөге, --, --, 
   {{0x660deb98,0xc5480014,0x25a92b50,0xf771eb99}},	// [37950] _urak, _نجدٕ_, _utal_, _جاو_, 
   {{0x7bc112cf,0x40a80440,0xe5cc0150,0xa6dc0154}},	//   ysnu, ръан_, _ﺑﻪﻳﻜ, _বসিয়, 
   {{0x5f941d9d,0xbf700248,0x00000000,0x00000000}},	//   чиет, _apàṣ, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4fe80124,0x06540092,0x00000000,0x00000000}},	//   _қырҭ_, _ግላዊነ, --, --, 
   {{0x61f83bc1,0x5e440014,0xc1080006,0x00000000}},	//   ğalı, _ہنزٕ, _тэме_, --, 
   {{0x61f87975,0x714400db,0x7058014b,0x33980150}},	//   şalı, _تۉلۅ, _дарр_, _ﻛﺎﻟﻲ_, 
   {{0x3cf405d7,0xcfa40124,0x4094035b,0x00000000}},	//   _एसके_, _хырҩ, _ырҭт, --, 
   {{0xaf34007b,0x59740139,0x7bc0007c,0x00000000}},	//   _غرفت, зыну, ssnu, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x1869eb9a,0x2c7400c6,0x7e700150,0x00000000}},	//   сани_, rúdú_, _ﺸﻜﻠﺕ_, --, 
   {{0xabd401b9,0x501808a8,0x15b800db,0x00000000}},	//   _آزلت, צורו, йыгы_, --, 
   {{0x1818036b,0x00000000,0x00000000,0x00000000}},	//   _گرشک_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd7c8004b,0xdee80092,0x00000000,0x00000000}},	//   _اوبه_, መሆን_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd6c449d2,0x312800c7,0x6f740150,0x00000000}},	// [37960] _диққ, онаҿ_, _ﺸﺌﻨﺎ_, --, 
   {{0x068110d1,0x74f40150,0x41000212,0x00000000}},	//   _ягын, _تۋسا, нзув, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x798003ac,0x00000000,0x00000000,0x00000000}},	//   _lhnw, --, --, --, 
   {{0x527402a9,0xadd8109a,0xad0400c7,0x00000000}},	//   _хуну, імку_, мҧад, --, 
   {{0xdb004d74,0xdd996689,0xc2780375,0x00000000}},	//   _atlà, іші_, _לרכי, --, 
   {{0xfba40166,0x00000000,0x00000000,0x00000000}},	//   птый_, --, --, --, 
   {{0xd90cc678,0x6a1400d8,0x46d80118,0x00000000}},	//   یین_, дмиу, _भाइह, --, 
   {{0x0dc800db,0xabb40022,0x00000000,0x00000000}},	//   _ылай_, чақә, --, --, 
   {{0xf98c04d3,0xb4c8012d,0x98a400c0,0x00000000}},	//   ێبی_, ॉलो_, oklę_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb095497,0x00000000,0x00000000,0x00000000}},	//   _وزنه_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb5240c98,0x00000000,0x00000000,0x00000000}},	//   ньск, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb7d80375,0x00000000,0x00000000,0x00000000}},	//   _הקהי, --, --, --, 
   {{0x9a9800b8,0x00000000,0x00000000,0x00000000}},	// [37970] _śākā, --, --, --, 
   {{0xfc3c0118,0x817002f2,0x00000000,0x00000000}},	//   _řím_, رناچ, --, --, 
   {{0x67202d8f,0x389800c8,0xe3a5eb9b,0xdee8001f}},	//   यापक_, ציאנ, _تشخی, መሆኑ_, 
   {{0xdb0000d7,0x00000000,0x00000000,0x00000000}},	//   _otlá, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb00c318,0x7c85eb9c,0x6e3c06be,0x00000000}},	//   _atlá, чуде, _ərbi, --, 
   {{0x3e040153,0x00000000,0x00000000,0x00000000}},	//   _нязв, --, --, --, 
   {{0x2c70022e,0x00000000,0x00000000,0x00000000}},	//   鼠di_, --, --, --, 
   {{0x9f4000c6,0x3ebc3f5b,0x00000000,0x00000000}},	//   ithí_, _heut_, --, --, 
   {{0xf19002dd,0x9f4401e1,0xc22401e1,0x00000000}},	//   _ﺒﺎﺴﻡ_, _èló_, _ọ́fí, --, 
   {{0x201008ad,0x81b0045e,0xe9b800e5,0x00000000}},	//   _mrzi_, _টিন_, _کنوں_, --, 
   {{0x7af9eb9d,0x3ebc0165,0x80c40183,0xe0d4009e}},	//   meut, _meut_, ৰ্য্, স্যভ, 
   {{0x7af951b5,0x3ebc00f3,0x98a40024,0x00000000}},	//   leut, _leut_, yklę_, --, 
   {{0xfc3c012c,0x68fc000d,0x00000000,0x00000000}},	//   _říj_, õrde, --, --, 
   {{0x7af9eb9e,0xc7d40302,0x00000000,0x00000000}},	//   neut, _חוקי_, --, --, 
   {{0x2011eb9f,0x00000000,0x00000000,0x00000000}},	// [37980] _arzi_, --, --, --, 
   {{0x7af8049b,0x2010098d,0x80c40154,0x00000000}},	//   heut, _brzi_, র্ঘ্, --, 
   {{0x3ebdeba0,0x7af9eba1,0x1fa400d6,0xaca4063f}},	//   _beut_, keut, еріг, nyụr, 
   {{0x201008ad,0x2054448f,0xe084038b,0x7af8713c}},	//   _drzi_, хтур, رجلي, jeut, 
   {{0x7af9eba2,0x657800b0,0x8d8402f2,0x00000000}},	//   deut, _ūwhi, وشتن, --, 
   {{0x9e6506f6,0x7f801b56,0x236c00bc,0x80c403d4}},	//   رانن, ىلەن, čeje_, ৰ্ব্, 
   {{0x3ebc0270,0xcf59eba3,0x67200c5a,0xdb000419}},	//   _feut_, _драч_, यामक_, _stlá, 
   {{0x31a5eba4,0xbb90005e,0x3ebc017a,0x7af80098}},	//   _köz_, _ﺟﺎﻧﻪ_, _geut_, geut, 
   {{0xbb4405d4,0x4e059d69,0x00000000,0x00000000}},	//   بلين_, _юзаб, --, --, 
   {{0x81b00eac,0x3d2800f1,0x9f440ca8,0x00000000}},	//   _টিম_, _وتلی_, _èlò_, --, 
   {{0x7af9eba5,0x29192524,0xf98c06f6,0xbd3010e0}},	//   beut, ıra_, جبي_, _جىلع, 
   {{0x32000113,0xdb0002d2,0xd6d40276,0x6f0400e4}},	//   kwiy_, _atlæ, нӂь_, ôich, 
   {{0x25adeba6,0xdb249783,0xdb0000d7,0x9988371e}},	//   ëel_, _سووی, _utlá, _çaş_, 
   {{0xddc80210,0x00000000,0x00000000,0x00000000}},	//   _rzeż, --, --, --, 
   {{0xf8d802e4,0xf801eba7,0x00000000,0x00000000}},	//   _וחומ, _ачын, --, --, 
   {{0xf65000b2,0xc7640b38,0xd6e40037,0x00000000}},	//   _ھئي_, _تاتى, _कायथ_, --, 
   {{0xf65000b2,0x61140220,0x05b86722,0x61d8023a}},	// [37990] _پئي_, ндау, _بدعت_, ямая_, 
   {{0x20100e3c,0x672c030a,0x3ebc269e,0x6280008f}},	//   _przi_, _hoaj, _seut_, _ŝlos, 
   {{0x3ebc2047,0x2cec0135,0x672c030a,0x7af9eba8}},	//   _peut_, _ལྡེབ, _koaj, yeut, 
   {{0x672c035b,0x20100010,0xf31800db,0x00000000}},	//   _joaj, _vrzi_, _жоюш_, --, 
   {{0x31a40fcd,0x3ebc0231,0x629c2819,0x7af84c18}},	//   _göz_, _veut_, _igso, veut, 
   {{0x0c6c0201,0xdd9000dd,0x7af8003e,0x672c013a}},	//   _ስዕሎች_, ھوں_, weut, _loaj, 
   {{0x60c5c6b5,0x49f80156,0x7af9eba9,0x3ebc0e39}},	//   mahm, _དགུལ_, teut, _teut_, 
   {{0x60c5ebaa,0x31a40598,0x46d80892,0x00000000}},	//   lahm, _yöz_, _भागह, --, 
   {{0x7af9ebab,0xd05c016b,0xd90c0066,0x00000000}},	//   reut, sepɔ, ییچ_, --, 
   {{0x60c5ebac,0x7af9ebad,0x44200175,0x00000000}},	//   nahm, seut, kxj_, --, 
   {{0x672c06d9,0x629c01d9,0x88c4009d,0x00000000}},	//   _boaj, _ogso, элэв_, --, 
   {{0x60c5ebae,0x672c0276,0x32000113,0xaadc00bc}},	//   hahm, _coaj, ywiy_, _याएक, 
   {{0x60c446a3,0xa9041888,0x00000000,0x00000000}},	//   kahm, ربین, --, --, 
   {{0x60c44c86,0x629c0c67,0x6934016c,0x80c40183}},	//   jahm, _agso, _инчу, ৰ্ত্, 
   {{0x60c5ebaf,0x31a49f19,0x672debb0,0x7cf06b27}},	//   dahm, _söz_, _foaj, mırı, 
   {{0x7cf02573,0x95c801a9,0x00000000,0x00000000}},	//   lırı, _елиб_, --, --, 
   {{0xd184034b,0xdb000166,0x60c4058a,0x50d40066}},	// [379a0] елай, _itlä, fahm, فزار, 
   {{0x7cf0b580,0x020011db,0xd175ebb1,0xe3b0004b}},	//   nırı, ызун, хыбы, طرې_, 
   {{0x998c02f0,0xdce800ef,0x00000000,0x00000000}},	//   rveň_, _dueļ, --, --, 
   {{0x81cc015b,0x31a40166,0x0e6403de,0x3f6401f0}},	//   _শহর_, _töz_, нкен, нихо_, 
   {{0x7cf02706,0x70f405d9,0x200002b1,0x60c4047e}},	//   kırı, _لڳائ, awhi_, bahm, 
   {{0x60c4020c,0x00000000,0x00000000,0x00000000}},	//   cahm, --, --, --, 
   {{0xfbcc7427,0x7cf02ed0,0x4c34009d,0x00000000}},	//   متي_, dırı, ээдт, --, 
   {{0xb34403b9,0x80c403d4,0x00000000,0x00000000}},	//   _biçə, ৰ্দ্, --, --, 
   {{0x7cf003e0,0x00000000,0x00000000,0x00000000}},	//   fırı, --, --, --, 
   {{0x7cf01ea0,0x00000000,0x00000000,0x00000000}},	//   gırı, --, --, --, 
   {{0x09dc0eac,0x00000000,0x00000000,0x00000000}},	//   _বৈশা, --, --, --, 
   {{0xf3f800fe,0x0ab4007b,0x00000000,0x00000000}},	//   ুমাৰ_, _أحاد, --, --, 
   {{0x672c0170,0x60c4c492,0xfa3000f2,0x7cf00166}},	//   _voaj, yahm, _مرود, bırı, 
   {{0xdb00008e,0x7cf00205,0x00000000,0x00000000}},	//   _etlä, cırı, --, --, 
   {{0x291c6f9e,0x290c0009,0x00000000,0x00000000}},	//   _inva_, mdda_, --, --, 
   {{0x6b9c0005,0xa6f400c7,0x290c8186,0x60c40477}},	//   _érgu, _рзиш, ldda_, wahm, 
   {{0x290c01d9,0x291c033b,0x60c4047e,0x3f800064}},	// [379b0] odda_, _knva_, tahm, _ėju_, 
   {{0x290debb2,0x69d80490,0xb2740b38,0x41a401ad}},	//   ndda_, _मिनी, улуш, _कंठस, 
   {{0x290cb545,0x200002b5,0xfd1c0208,0xc07c0240}},	//   idda_, uwhi_, _đì_, _ዕዳጋን_, 
   {{0x629debb3,0xc0ec02d3,0x7cf03361,0x61e80356}},	//   _ugso, _ቀዳም_, zırı, _ţelu, 
   {{0x1d0815a0,0x7cf04674,0x60c4045b,0x00000000}},	//   дели_, yırı, pahm, --, 
   {{0x5ff4228e,0x8d280046,0xe5cc00d1,0x60c4014f}},	//   _изгу, мнің_, _ﺑﻪﻟﻜ, qahm, 
   {{0x61edebb4,0x2cac0165,0x7cf003e0,0x00000000}},	//   ltal, _dfdd_, vırı, --, 
   {{0x25ac06d6,0x291c5f78,0x9f0400cf,0x61edebb5}},	//   ̭ela_, _anva_, _جورو, otal, 
   {{0x7cf04947,0x2a3405f5,0x8b205ac1,0x2249ebb6}},	//   tırı, гээр, рдые, nzak_, 
   {{0x61edebb7,0xdb001bce,0x2248009d,0x291c0356}},	//   ital, _kulë, izak_, _cnva_, 
   {{0x61edebb8,0x7cf0e948,0x7e78002b,0x00000000}},	//   htal, rırı, _hyup, --, 
   {{0x61edebb9,0x291c0337,0x290c581e,0x7e78037e}},	//   ktal, _enva_, adda_, _kyup, 
   {{0xcb34025f,0x61edebba,0x4a7043bb,0xdb000023}},	//   _שאני_, jtal, _پُور, _lulë, 
   {{0x290c6f19,0xf3b4004e,0x00000000,0x00000000}},	//   cdda_, лөмы, --, --, 
   {{0x61edebbb,0xd1fc00b5,0x0fcc00fe,0x96b400f3}},	//   etal, _cmのｇ_, _ৰন্ধ, _испљ, 
   {{0xdb00049f,0x224801f5,0x6f900150,0x00000000}},	//   _utlä, fzak_, _ﺑﺎﻋﺎ_, --, 
   {{0x61edebbc,0x22480d27,0xe7081b45,0x060446e5}},	// [379c0] gtal, gzak_, _ستين_, _анык_, 
   {{0x236c009b,0xdb000200,0x00000000,0x00000000}},	//   čeja_, _bulë, --, --, 
   {{0x61edebbd,0x7e79ebbe,0xd468084c,0xb4c008a3}},	//   atal, _ayup, _цине_, ुणी_, 
   {{0x61edebbf,0x00000000,0x00000000,0x00000000}},	//   btal, --, --, --, 
   {{0x61edebc0,0x290debc1,0x6df40a2c,0x2248033f}},	//   ctal, ydda_, اكتا, czak_, 
   {{0xdb000de2,0x7e7800b8,0x290c058a,0x00000000}},	//   _fulë, _dyup, xdda_, --, 
   {{0x7e78020c,0xd478008f,0x4f95ebc2,0x00000000}},	//   _eyup, ואַל, _арау, --, 
   {{0xcee80006,0xb5b800cc,0x8d940092,0x00000000}},	//   _ідзе_, _জিনচ, _ልጃቸው_, --, 
   {{0xdb000241,0x00000000,0x00000000,0x00000000}},	//   _mulè, --, --, --, 
   {{0x2cac0198,0xdb0001e1,0x6e240036,0x290c0067}},	//   _ufdd_, _lulè, äibu, udda_, 
   {{0x6d59ebc3,0x91ac00bd,0x61ec01ed,0xe7e00eac}},	//   miva, টওয়্, ztal, বব্য, 
   {{0x290c0009,0x00000000,0x00000000,0x00000000}},	//   sdda_, --, --, --, 
   {{0x094835dd,0x61edebc4,0xe7e41b57,0x7aec0ba1}},	//   _очки_, xtal, _कमवा_, òcte, 
   {{0x6d59ebc5,0x61edd57f,0x291c0223,0x281402ef}},	//   niva, vtal, _unva_, _موتس, 
   {{0x68380248,0x61eccd03,0xe2f80212,0xb84400f1}},	//   _dúdú, wtal, неві_, _لټول_, 
   {{0x61edebc6,0x6d59ebc7,0x22480323,0x838402dd}},	//   ttal, hiva, tzak_, тыге, 
   {{0x61edebc8,0xdb01ebc9,0xf1a4fbd3,0x00000000}},	// [379d0] utal, _utlå, архн, --, 
   {{0x61edebca,0x6d581326,0x68380241,0xdb00036e}},	//   rtal, jiva, _gúdú, _pulë, 
   {{0x6d59ebcb,0xaeb001f2,0x3448010b,0x2249ebcc}},	//   diva, _ịnọs, _ачян_, szak_, 
   {{0x673d0d02,0x63a4003e,0x224801f5,0xdb000240}},	//   nksj, _iuhn, pzak_, _vulë, 
   {{0x6d59d20c,0x61edebcd,0x63a4062c,0x00000000}},	//   fiva, qtal, _huhn, --, 
   {{0x6d59ebce,0x1be865cb,0x6574030a,0x7e78002b}},	//   giva, едки_, nozh, _vyup, 
   {{0x63a4014f,0x673c08fb,0x6ce400d4,0x00000000}},	//   _juhn, kksj, річе, --, 
   {{0x63a5ebcf,0x9b04016c,0x213005c7,0x7c65714b}},	//   _muhn, узид, _hozh_, _یاال, 
   {{0x6d59ebd0,0x63a4025a,0x213003bd,0x98a53b72}},	//   biva, _luhn, _kozh_, липе, 
   {{0x6d582b13,0xdb00020c,0xdd95ebd1,0x673c01f5}},	//   civa, _mulé, _сазы, eksj, 
   {{0x63a4014f,0x1bb40064,0x00000000,0x00000000}},	//   _nuhn, _сбеў, --, --, 
   {{0xe7e40c2e,0x2ab8084c,0x00000000,0x00000000}},	//   _कमरा_, _алць_, --, --, 
   {{0xcb10025f,0x00000000,0x00000000,0x00000000}},	//   _ללא_, --, --, --, 
   {{0x673c08fb,0x2130030a,0x18689808,0x63a40356}},	//   aksj, _nozh_, _пали_, _buhn, 
   {{0x63a4020c,0xd17439fb,0xdb000268,0x59400014}},	//   _cuhn, ңызы, _pulè, _نکھہ, 
   {{0xdb0000e8,0x63a40477,0xd25028ee,0x3179ebd2}},	//   _bulé, _duhn, منز_, _skrz_, 
   {{0x6575ebd3,0xdb00004e,0xa2a403ba,0x00000000}},	// [379e0] bozh, _culé, _कलर्, --, 
   {{0x6d59ebd4,0x00000000,0x00000000,0x00000000}},	//   xiva, --, --, --, 
   {{0x6d59ebd5,0x63a40007,0x00000000,0x00000000}},	//   viva, _guhn, --, --, 
   {{0x5274006c,0x24840790,0x8de802e8,0x81b00154}},	//   _бугу, ülme_, ефка_, _টির_, 
   {{0x21300165,0x00000000,0x00000000,0x00000000}},	//   _fozh_, --, --, --, 
   {{0x21300dd4,0x6d580607,0xe7e42c30,0x0c840166}},	//   _gozh_, uiva, _कमला_, лыйм, 
   {{0x0d8401ec,0x7bd000ec,0x673c007c,0x00000000}},	//   _ұлан, متيء, yksj, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d59ebd6,0x0c2452c0,0x00000000,0x00000000}},	//   piva, _әмен, --, --, 
   {{0x0904033a,0xb4c000cd,0x00000000,0x00000000}},	//   учим, ुणो_, --, --, 
   {{0x2d8c009a,0x657533bf,0x451003d4,0x415800df}},	//   _ihde_, vozh, _সকলক_, תדיג, 
   {{0x63a40209,0x673c003b,0x07080107,0x0a8800db}},	//   _ruhn, uksj, ххои_, _كئشى_, 
   {{0x63a4145e,0x673c2611,0x3f5c00a2,0x00000000}},	//   _suhn, rksj, _uçuň_, --, 
   {{0x237805b1,0x63a41710,0x00000000,0x00000000}},	//   _sksj_, _puhn, --, --, 
   {{0x657403f7,0xdb0000f2,0x2d8c003a,0x00000000}},	//   rozh, _sulé, _mhde_, --, 
   {{0xf2c4ba1d,0x236c151c,0xa2b5ebd7,0xc7640150}},	//   йсун, čejo_, рбач, _حاتى, 
   {{0x63a4145e,0xa4d4160b,0xc7940022,0x00000000}},	// [379f0] _wuhn, _копі, _ирҩы, --, 
   {{0x63a5ebd8,0xdb00026c,0x00000000,0x00000000}},	//   _tuhn, _vulé, --, --, 
   {{0xefcc001f,0x00000000,0x00000000,0x00000000}},	//   _አባይ_, --, --, --, 
   {{0xdb00b7e6,0x9f0400db,0x2d8c0205,0x3988005c}},	//   _tulé, شوتو, _ahde_, møse_, 
   {{0x398817c1,0x00000000,0x00000000,0x00000000}},	//   løse_, --, --, --, 
   {{0x11d80375,0x61fc035a,0xee380006,0x00000000}},	//   _בחשב, _ipsl, ыні_, --, 
   {{0x00cc08b0,0x20040ba1,0x39880b1a,0x5f9406ed}},	//   _ﻗﯘﺗﻘ, _èli_, nøse_, _вивт, 
   {{0xfeb80a2c,0x2d8c0200,0x00000000,0x00000000}},	//   _سارت_, _ehde_, --, --, 
   {{0x49c5ebd9,0x00000000,0x00000000,0x00000000}},	//   алын_, --, --, --, 
   {{0x5894084c,0x00000000,0x00000000,0x00000000}},	//   ишну, --, --, --, 
   {{0x1869ebda,0xad243baf,0xb3a40034,0x67200db3}},	//   тани_, _دىلى, _खूंख, यांक_, 
   {{0x7d01ebdb,0x61fdebdc,0x00000000,0x00000000}},	//   lens, _opsl, --, --, 
   {{0x7d0166d2,0x958409a5,0x060400c0,0x00000000}},	//   oens, илме, аняк_, --, 
   {{0xdb00cade,0x92e00154,0x3ce40051,0x00000000}},	//   _atlø, _ধসে_, ngnv_, --, 
   {{0x7d01ebdd,0x987800c8,0x4cc80154,0x61fdebde}},	//   iens, _באַט, _রামু, _apsl, 
   {{0x60d405b1,0x3f9c0093,0x00000000,0x00000000}},	//   _adzm, _niuu_, --, --, 
   {{0x90c57c97,0x91e5ebdf,0x63a80115,0x87780677}},	// [37a00] ибае, розе, ĉena, _באקי, 
   {{0x50b4054a,0x59dc0562,0x00000000,0x00000000}},	//   рсау, _मिनर, --, --, 
   {{0x7d01ebe0,0x35dc05f9,0x4f95ebe1,0x4fe80a3b}},	//   dens, _बिड़, арду, тмен_, 
   {{0x91e49808,0x7d00005b,0xd1c80354,0x00000000}},	//   _коме, eens, _илме_, --, 
   {{0x7d00977d,0x10a46ee2,0xcbb0015b,0x00000000}},	//   fens, _вигн, _ঘটেছ, --, 
   {{0x4638008f,0x644008fb,0xd5c00055,0x00000000}},	//   כענע, ølig, cyāś_, --, 
   {{0xe7e00eac,0xd01000e5,0x9a98002b,0x00000000}},	//   _বন্য, _بلز_, _śāpā, --, 
   {{0x61fc0334,0x0b8810fc,0x00000000,0x00000000}},	//   _ypsl, њски_, --, --, 
   {{0x7d01ebe2,0xd9b01473,0x3b800032,0x2d8c01ab}},	//   bens, كەند, өләг, _thde_, 
   {{0x7d01ebe3,0x00000000,0x00000000,0x00000000}},	//   cens, --, --, --, 
   {{0xa7740415,0x00000000,0x00000000,0x00000000}},	//   йлоч, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x0a14d98f,0xc9842d3c,0x00000000,0x00000000}},	//   _خوشح, _куки, --, --, 
   {{0x385404fb,0x6595ebe4,0x00000000,0x00000000}},	//   اشید_, сагу, --, --, 
   {{0x47880131,0x00000000,0x00000000,0x00000000}},	//   _исим_, --, --, --, 
   {{0x7d01ebe5,0x38980375,0x398812ed,0xa278013d}},	//   zens, _ביונ, røse_, гббу_, 
   {{0x443c0029,0x60f8034b,0x337400d3,0x00000000}},	// [37a10] ņu_, лная_, ігур, --, 
   {{0x7d01ebe6,0x9f4007a8,0x68e80042,0x00000000}},	//   xens, muhé_, ngdd, --, 
   {{0x7d013765,0x3f9c0270,0x3494074d,0xc44402f2}},	//   vens, _piuu_, _маьр, _ئیزن_, 
   {{0x7d01ebe7,0xdb00e73f,0x4f94004b,0x660c0205}},	//   wens, _utlø, مانځ, _ksak, 
   {{0x25a84237,0x88dc00bd,0x9f40020c,0x61fc0175}},	//   _jual_, ব্যক, nuhé_, _upsl, 
   {{0x26c80b2e,0x25a9ebe8,0x660debe9,0xdc6801c0}},	//   _leao_, _mual_, _msak, лалд_, 
   {{0x8d600b7e,0x660c022e,0x5fd01d68,0x00000000}},	//   явше, _lsak, _हिटल, --, 
   {{0x7d00281b,0x19c4322e,0x00000000,0x00000000}},	//   sens, ббим, --, --, 
   {{0x660debea,0x7d00241f,0x25a807c5,0x00000000}},	//   _nsak, pens, _nual_, --, 
   {{0x5d840597,0x26c80093,0x9f40020c,0x83040327}},	//   _الطل, _aeao_, duhé_, _ཅིའུ_, 
   {{0x25a805d5,0x78a02852,0x18a401e0,0xfb2405d3}},	//   _aual_, _vgnv, _һалм, _پراپ, 
   {{0x26c80077,0x25a9ebeb,0x5f0405b3,0xdb0002f0}},	//   _ceao_, _bual_, _रसोई_, _kulí, 
   {{0x25a84e4c,0x98a5ebec,0xab740597,0x660c795e}},	//   _cual_, _лиле, _بالإ, _csak, 
   {{0x98a400a7,0x89d405d3,0x55200210,0x00000000}},	//   _уике, _اوور_, माइए_, --, 
   {{0x660debed,0x26c81132,0xa55002d3,0xa5040006}},	//   _esak, _feao_, _ሃገራዊ, цяўл, 
   {{0x9f401a9b,0x25a801e7,0xddc8002b,0xdb2000fd}},	//   buhé_, _fual_, _jyeų, _ütär, 
   {{0x25a9ebee,0xd9f80d0d,0xe048036b,0x54840092}},	// [37a20] _gual_, ्बित_, یشمه_, _በድምፅ_, 
   {{0x6264581f,0x00c400db,0x00000000,0x00000000}},	//   زاقق, йлук_, --, --, 
   {{0xdb000268,0x6360063f,0x0ca801d5,0x00000000}},	//   _pulì, ịnaa, қтли_, --, 
   {{0x4878008f,0x69d8121d,0xdb0002f0,0x0c8401e0}},	//   אטעס, _मिली, _bulí, ҙылм, 
   {{0xdb01ebef,0xfc3c01ef,0x00000000,0x00000000}},	//   _vulì, _říp_, --, --, 
   {{0x8bc5ebf0,0xafe40131,0xc5f8010f,0x00000000}},	//   бсид, _қоғл, רפסט, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xeb38016c,0x7b10011c,0x00000000,0x00000000}},	//   рзиш_, здъх, --, --, 
   {{0xdb000077,0xc7c4009d,0x00000000,0x00000000}},	//   _gulí, өсни, --, --, 
   {{0xc7b80c98,0x00000000,0x00000000,0x00000000}},	//   лём_, --, --, --, 
   {{0x25a9ebf1,0x6d49ebf2,0x9f400214,0x660c38f2}},	//   _sual_, _ilda, wuhé_, _ssak, 
   {{0x09e41baa,0x39440fac,0xbc4400cf,0x9f40020c}},	//   _годн, _elns_, _اركۉ, tuhé_, 
   {{0x25a9ebf3,0x25a13b13,0xdb00004e,0xfaa400e5}},	//   _qual_, _pihl_, _xulí, _اجمی, 
   {{0x660c0f72,0x9f400066,0xbd0000d7,0x7a78010f}},	//   _vsak, ruhé_, _gréč, _ערגס, 
   {{0x182801d3,0x9f400035,0x37a40166,0x63a80115}},	//   _نقوی_, suhé_, _лтын_, ĉeno, 
   {{0x660debf4,0x25a8003e,0xa5c4008e,0x00000000}},	//   _tsak, _tual_, _мөге, --, 
   {{0x6d4800f8,0x660debf5,0xe6b402ab,0x76b80139}},	// [37a30] _olda, _usak, ंडीज, _улыр_, 
   {{0xa2a40950,0x00000000,0x00000000,0x00000000}},	//   _कलक्, --, --, --, 
   {{0xdb0000d0,0xe2f801ec,0xe29800fb,0x00000000}},	//   _sulí, _кені_, уаҡ_, --, 
   {{0x6d49ebf6,0xc3040150,0x3cf80316,0x00000000}},	//   _alda, _ابدو, ल्ने_, --, 
   {{0x795c0241,0x5de41cb8,0xdca44411,0xa194011c}},	//   _jáwè, іжка, оали, _мамч, 
   {{0x52780375,0x7d6871fe,0x23680477,0x5bb4011c}},	//   _כנרא, ышев_, lnaj_, осиф, 
   {{0x2369ebf7,0x795c01e1,0x7cc40150,0xb0884c91}},	//   onaj_, _láwè, _ۇزام, _гёте_, 
   {{0x6d49ebf8,0x2369ebf9,0xa158014b,0x00000000}},	//   _elda, nnaj_, _саҳу_, --, 
   {{0xc9a51fdf,0x27e0123c,0x6d480083,0x671c01ad}},	//   овые_, _āina_, _flda, _बोधक_, 
   {{0x682c02d3,0x23680369,0x261c3347,0xf8ac15d6}},	//   _ትካላት, hnaj_, मिनी_, رکت_, 
   {{0x23680007,0xeca4041b,0xbb2800d1,0x00000000}},	//   knaj_, _хјун, ﺧﻼﻕ_, --, 
   {{0xbf84001e,0x59f8084c,0x2369ebfa,0x00000000}},	//   _điền_, _ведя_, jnaj_, --, 
   {{0xaa5815a0,0x6d49ebfb,0x23680419,0x00000000}},	//   _лицу_, _ylda, dnaj_, --, 
   {{0x236801e4,0xaa88007b,0x00000000,0x00000000}},	//   enaj_, _انهم_, --, --, 
   {{0xdb0001b8,0x3cf9ebfc,0xc3100011,0x1418007b}},	//   _otlü, ल्ये_, হানি_, جيزة_, 
   {{0x2369ebfd,0x96b803b7,0x3f840356,0x00000000}},	//   gnaj_, _туку_, înul_, --, 
   {{0x4cc80154,0x52a80210,0x00000000,0x00000000}},	// [37a40] _রাসু, _कलीस, --, --, 
   {{0x7f580113,0x23680115,0x3cf844d0,0x06800166}},	//   _amuq, anaj_, ल्मे_, _югын, 
   {{0xb64401ec,0x0ea800db,0x99dc0432,0x00000000}},	//   _ﺍﻷ_, акей_, lyňd, --, 
   {{0x4eb800bd,0xed5000ec,0x00000000,0x00000000}},	//   ুল্ল, ڙھا_, --, --, 
   {{0xc330011a,0x00000000,0x00000000,0x00000000}},	//   _חור_, --, --, --, 
   {{0x4cc80154,0xfbcc00ec,0x00000000,0x00000000}},	//   _রাহু, چتي_, --, --, 
   {{0x290004ac,0xfbcdebfe,0x00000000,0x00000000}},	//   _ĝia_, پتى_, --, --, 
   {{0x290000c8,0xcf2401e2,0x98a40024,0xbc6400db}},	//   _ŝia_, _برسي, oklė_, تمىن_, 
   {{0x8d6406ed,0x33600092,0xaa580452,0x00000000}},	//   _двае, _ተወሰደ_, сипу_, --, 
   {{0xdb0000cf,0x13b003d4,0x236c0118,0x48a9736b}},	//   _eulà, টীয়, čeji_, штим_, 
   {{0xe6a40116,0xdce00064,0x7dcc01e1,0xaaa401ee}},	//   зугү, _aklė, _tòsá, _егеҙ, 
   {{0x23680399,0x28ac033f,0xdb5800c0,0x00000000}},	//   xnaj_, _फ़्रि, _люі_, --, 
   {{0xfd540cad,0x2368cd97,0xe91802bf,0xbf98008f}},	//   _adaṣ, vnaj_, _голі_, ייטש, 
   {{0x2368fc69,0x7e9c0150,0x00000000,0x00000000}},	//   wnaj_, _ﻁﺭﻴﻕ_, --, --, 
   {{0x23680115,0xdb0001ef,0x00000000,0x00000000}},	//   tnaj_, _hulá, --, --, 
   {{0xf7b443bb,0xdb007dcd,0x73040eed,0x22580ce8}},	//   _بدوش_, _kulá, мчуж, бибы_, 
   {{0x2369bf87,0xdee80023,0x00000000,0x00000000}},	// [37a50] rnaj_, _ሙኳኑ_, --, --, 
   {{0xf2040ce8,0x59dc2c30,0x23680477,0x06a00220}},	//   ьясо, _मिसर, snaj_, _ﺍﯞﻗﯩ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x23680399,0x69c40327,0xfe7000f2,0xa2a4000d}},	//   qnaj_, _ħien, ودش_, _कलट्, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x1d08db2e,0xf1c4033f,0xc0e80023,0x00000000}},	//   секи_, _लौटन, ዘቦም_, --, 
   {{0x3a3c0113,0x261c0210,0x00000000,0x00000000}},	//   wyup_, मिडी_, --, --, 
   {{0xe6b40027,0x35dc000d,0x00000000,0x00000000}},	//   ंडोज, _बिल़, --, --, 
   {{0xfe40168d,0x6d68041e,0x09f400ae,0x00000000}},	//   _تکای, ðrað, كفية_, --, 
   {{0xae0407d2,0x3a3c0113,0x98740063,0x00000000}},	//   _توكى, ryup_, зумљ, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb0019e4,0x3a3c1f06,0x00000000,0x00000000}},	//   _fulá, pyup_, --, --, 
   {{0x7af87456,0xdb0002fb,0x00000000,0x00000000}},	//   mfut, _gulá, --, --, 
   {{0x7af80793,0xd6d80228,0xe9b801d3,0x5d78010f}},	//   lfut, штү_, _بنوں_, מאָק, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x52a800a7,0xd2a80953,0xe8e80327,0x8838011a}},	//   свам_, скае_, _འཐོག, _לתצו, 
   {{0x7af98e7c,0x86600092,0x11e4026b,0x00000000}},	// [37a60] ifut, ለካከት, яжам, --, 
   {{0x80c40183,0x7af8002f,0x00000000,0x00000000}},	//   ৰ্ঘ্, hfut, --, --, 
   {{0x98a40024,0x4fa4011c,0x00000000,0x00000000}},	//   rklė_, чиев, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x1ea83738,0x71742dfc,0x9e640214,0x3ea802f0}},	//   زاني_, _قۇرا, واهن, _šitá_, 
   {{0xf98400f8,0x261c0490,0xa1f001ec,0x8bc40166}},	//   _سب_, मिती_, _جۋكت, псид, 
   {{0x0ba801ec,0x00000000,0x00000000,0x00000000}},	//   حاتى_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc9846191,0xbb44007b,0x00000000,0x00000000}},	//   зуни, ثلين_, --, --, 
   {{0x7af80270,0xcc3400db,0x2d9801e1,0x7db8011a}},	//   afut, _ىراع, _òre_, _לצמצ, 
   {{0xf98c26c0,0x96bc0073,0x5c140408,0x6ed028f0}},	//   دبي_, _व्हॉ, _оьцу, दरपु, 
   {{0xda6400b2,0xa5f80b32,0xdb000306,0x9f4000e4}},	//   _ڪامي, оему_, _tulá, muhã_, 
   {{0xb5b800fe,0x00000000,0x00000000,0x00000000}},	//   _জিউচ, --, --, --, 
   {{0xda64ab80,0x25a40008,0x69c1ebff,0xae9401e1}},	//   _تامي, öll_, mpme, _wẹwo, 
   {{0x97ac03ee,0x78f80375,0x68fc000d,0x00000000}},	//   üştü, _לפגו, õrdu, --, 
   {{0xc6a520bd,0x69c001a4,0x6e204cab,0x00000000}},	//   _эрки, opme, _ormb, --, 
   {{0xb1842b57,0xc0a800db,0x611402dd,0x2fd8045a}},	// [37a70] _šťav, ماال_, мдау, _avrg_, 
   {{0x69c4003d,0x69c136cc,0x66ec0cb4,0x00000000}},	//   _ħiel, ipme, _झाँक_, --, 
   {{0xefd80023,0x00000000,0x00000000,0x00000000}},	//   _ርእየ_, --, --, --, 
   {{0x3e84067c,0x6e2000d7,0xc4c40244,0x59dc06b1}},	//   jítú_, _brmb, _بتکو, _मिलर, 
   {{0x6e2002b9,0x5d780108,0xf2040153,0x00000000}},	//   _crmb, ойдя_, _пяро, --, 
   {{0x661c0158,0x236c009b,0x270800fe,0x71a40153}},	//   ivsk, čeju_, ষাটো_, _паўз, 
   {{0x7af81cea,0x6454026c,0x6e2002d0,0x3fc403e6}},	//   tfut, nzzi, _ermb, _رگای_, 
   {{0xefd802d3,0x63a801e4,0xa3e4000d,0x00000000}},	//   _ርእዩ_, ĉenh, _निन_, --, 
   {{0x660803ee,0x6e200036,0x00000000,0x00000000}},	//   çekl, _grmb, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x661dec00,0x7af8006f,0xd7082069,0x33600023}},	//   evsk, pfut, онне_, _ተወሊደ_, 
   {{0x50180302,0x6454ca82,0x00000000,0x00000000}},	//   קורו, dzzi, --, --, 
   {{0x64409f65,0xa8040220,0x2004008e,0xdec80092}},	//   ølin, _үзіл, _älif_, _አናን_, 
   {{0xe9180212,0x97ac03e0,0x00000000,0x00000000}},	//   _ночі_, üşsü, --, --, 
   {{0xdce000b8,0xb9e01ee0,0x00000000,0x00000000}},	//   _aklī, _ጫማ_, --, --, 
   {{0xd9e00073,0x00000000,0x00000000,0x00000000}},	//   _गटात_, --, --, --, 
   {{0x64540268,0x4dd0009e,0x336001f3,0x00000000}},	// [37a80] azzi, _সমভূ, _ተወለደ_, --, 
   {{0x92cc015b,0x00000000,0x00000000,0x00000000}},	//   রলে_, --, --, --, 
   {{0xdb0036e1,0x6f00045a,0x00000000,0x00000000}},	//   _gulç, _pbmc, --, --, 
   {{0x0e640046,0x527400f7,0x69c003b2,0xcf4401f4}},	//   мкен, _жугу, ypme, ьней, 
   {{0xdd8c0075,0xdfa40592,0x00000000,0x00000000}},	//   ڭۈل_, رحمي, --, --, 
   {{0xfe4002e8,0xdb00008e,0xb38c0051,0x6440d026}},	//   ънчо, _yulç, _độch, älig, 
   {{0x41a400cd,0x00000000,0x00000000,0x00000000}},	//   _कूटस, --, --, --, 
   {{0xdb00014a,0xff20013e,0x160c012c,0x6a14ac8a}},	//   _nulä, _имсо, िबार_, емиу, 
   {{0x3cf86c08,0x6e20014f,0x88b001b9,0x63a800df}},	//   ल्हे_, _urmb, نیشچ, ĉeni, 
   {{0x0d4800aa,0x69c1ec01,0x00000000,0x00000000}},	//   _بشري_, rpme, --, --, 
   {{0xdb000139,0x00000000,0x00000000,0x00000000}},	//   _bulä, --, --, --, 
   {{0x69c0613e,0x4a45ec02,0x7b840c75,0xc0540092}},	//   ppme, _онев, _قانە, ቀርባለ, 
   {{0xdb000023,0x3cf81098,0x661c0158,0x00000000}},	//   _sulç, ल्वे_, uvsk, --, 
   {{0x6b81ec03,0x661dec04,0x6454002f,0x92cc0154}},	//   lomg, rvsk, tzzi, রলো_, 
   {{0x2d9c0161,0x99980030,0xfc3c01ef,0x10840116}},	//   imve_, ásť_, _říz_, ﺒﯩﺮﯨ, 
   {{0x290dec05,0x6b81ec06,0x49140316,0x64540ffb}},	//   leda_, nomg, भएको_, rzzi, 
   {{0x60c8009b,0x64540ffb,0x9f4000e4,0x760400e5}},	// [37a90] _đemb, szzi, juhá_, _vízö, 
   {{0x33601b49,0xdb0003fa,0xc0a86f04,0x40880114}},	//   _ተወልደ_, _zulä, زائل_, ољем_, 
   {{0x6b8000f1,0xdb000139,0x00000000,0x00000000}},	//   komg, _yulä, --, --, 
   {{0x290dec07,0x62340640,0xc2e80127,0x00000000}},	//   heda_, _зему, _بعدم_, --, 
   {{0x290dec08,0x162012eb,0xe28401b9,0xd04c06be}},	//   keda_, मियर_, _سطحی, _mdbə, 
   {{0x290c1f7f,0x61edec09,0x02ec00ab,0x00000000}},	//   jeda_, mual, _छाँह_, --, 
   {{0x290c02d5,0x61edbd6d,0x6b800d27,0x3fc401d3}},	//   deda_, lual, fomg, _آگئی_, 
   {{0x7094651e,0x6b81ec0a,0x2d9c003a,0x290c0009}},	//   _расф, gomg, amve_, eeda_, 
   {{0x61edec0b,0x290c0793,0x98f4010b,0x00000000}},	//   nual, feda_, нянч, --, 
   {{0x290dec0c,0xd1001b51,0x54ec033f,0x61ec0254}},	//   geda_, र्पण_, _जाइए_, iual, 
   {{0x6b81ec0d,0xe9d80137,0x644003b2,0x00000000}},	//   bomg, пкө_, ølil, --, 
   {{0x61edec0e,0x290c0037,0x7bc00393,0xdb00032e}},	//   kual, aeda_, mpnu, _atlö, 
   {{0x290dec0f,0x61ec8bba,0x3c400014,0x7bc0a6ba}},	//   beda_, jual, _سێکِ, lpnu, 
   {{0x290dec10,0x61edec11,0x00000000,0x00000000}},	//   ceda_, dual, --, --, 
   {{0x61ec003a,0xb18401ef,0x00000000,0x00000000}},	//   eual, _šťov, --, --, 
   {{0x61ec54bb,0x23e001ad,0x00000000,0x00000000}},	//   fual, _फिरद, --, --, 
   {{0x1148021f,0x00000000,0x00000000,0x00000000}},	// [37aa0] ппай_, --, --, --, 
   {{0x7bc0020c,0x01ac00fe,0x6b810db3,0x74f40046}},	//   kpnu, _চৌহদ, zomg, _جۋسا, 
   {{0x4f09ec12,0xdd9802e2,0x61ec0b23,0xd3d807c0}},	//   знен_, _epňk_, aual, _عبدا_, 
   {{0xa3e40c2e,0x61ec05b1,0x2cac01ab,0xe82007d0}},	//   _नित_, bual, _sgdd_, यिता_, 
   {{0x61ec15a5,0x290dec13,0x94740f01,0xbd8404fb}},	//   cual, yeda_, _زدگا, کنون_, 
   {{0x3cf96c08,0xfd0c02dd,0x8fd1ec14,0x61b00131}},	//   ल्ले_, مجى_, _бәдә, _ئەلا, 
   {{0x290dec15,0x5cc402dd,0xcbe401c6,0xc3100154}},	//   veda_, тсіз, хцли, হারি_, 
   {{0x290dec16,0x00000000,0x00000000,0x00000000}},	//   weda_, --, --, --, 
   {{0xd9b04d2d,0x2cac0208,0x7bc000d7,0x00000000}},	//   لەند, _tgdd_, apnu, --, 
   {{0x98b80228,0x6b81ec17,0x49900330,0x201c0210}},	//   үлөт_, somg, دیتر, łwie_, 
   {{0x290dec18,0x61edec19,0x4aa8005e,0x8ae400d4}},	//   reda_, zual, _екен_, _зілл, 
   {{0x290dec1a,0x261c10b7,0x6b8001a9,0x6f0400e4}},	//   seda_, मिली_, qomg, õich, 
   {{0x290c0490,0xb605ec1b,0xf62800d4,0x6fd001f9}},	//   peda_, лярк, ніри_, डीतू, 
   {{0x290c013e,0xa3b406e3,0x2bf400dc,0x00000000}},	//   qeda_, _छंद_, _इमां_, --, 
   {{0xf7705022,0x00000000,0x00000000,0x00000000}},	//   _گاو_, --, --, --, 
   {{0xf31401c0,0xf364010b,0xdcb00051,0x00000000}},	//   лдсэ, гтун, _nản_, --, 
   {{0x672dec1c,0xf770208f,0x65940022,0xe69801b9}},	// [37ab0] _inaj, _داو_, _иаиу, _ювиш_, 
   {{0xdb000267,0x32b801c0,0x35f8007b,0x00000000}},	//   _utlö, _үгээ_, _أريد_, --, 
   {{0x61eda42a,0xdcb001fb,0xe37400ee,0x672c012d}},	//   sual, _bản_, _алны, _knaj, 
   {{0x61ecc5e7,0x229400ae,0x00000000,0x00000000}},	//   pual, _للجس, --, --, 
   {{0x672dec1d,0xa3b4375c,0x61ec0d63,0xdd9400c7}},	//   _mnaj, _छूत_, qual, ҭаҵы, 
   {{0x50a00075,0x45ac0131,0x2d580276,0x39883b97}},	//   _چەكل, _ﻳﻮﻟﻼ, ничь_, røsk_, 
   {{0xdb0000d2,0x4cc800bd,0x1af4015b,0x672c01d5}},	//   _gulû, _রাখু, _আসবে_, _onaj, 
   {{0x672c1418,0x1a283da1,0x38000107,0x00000000}},	//   _nnaj, джии_, қомҳ, --, 
   {{0xfe70b3cc,0xfe400722,0xdb0000d2,0xf2d4008f}},	//   _صدر_, _حکای, _kulú, נעץ_, 
   {{0x672dec1e,0x7bc001a8,0x00000000,0x00000000}},	//   _anaj, ppnu, --, --, 
   {{0x77a40107,0xdcb00051,0x00000000,0x00000000}},	//   ллоҷ, _hảo_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc4bc0034,0xeab037ba,0x00000000,0x00000000}},	//   ्रूख, _اعم_, --, --, 
   {{0x09e0c786,0x672dec1f,0xb4dc0073,0x99dc02f0}},	//   _тошн, _enaj, डणे_, lyňo, 
   {{0xae9401e1,0x00000000,0x00000000,0x00000000}},	//   _lẹpo, --, --, --, 
   {{0x1cb01b4b,0xfbe00729,0x9f440248,0x00000000}},	//   _དཔའ_, _মহাত, _ílè_, --, 
   {{0x03a1ec20,0x776400f1,0xc24000db,0x00000000}},	// [37ac0] рито, _imix, антк, --, 
   {{0x672dec21,0xdcb001fb,0x98a40064,0x00000000}},	//   _znaj, _sản_, nklį_, --, 
   {{0x8fa44d06,0x4fa400a7,0xdb00032e,0x7a440241}},	//   важе, вижв, _dulú, _yétú, 
   {{0xd2940124,0xdcb001fb,0x670401ad,0x649800ee}},	//   _аргь, _bảo_, ष्पक_, _ятыр_, 
   {{0xf23401d9,0xbdf41867,0x63a80115,0x99dc010e}},	//   _صبحک, نروا_, ĉent, dyňo, 
   {{0xdb0000d2,0xa91c0419,0x0c8404f0,0x660803e0}},	//   _gulú, koľa, кыйм, çeki, 
   {{0xdcf401d3,0x00000000,0x00000000,0x00000000}},	//   اہمت_, --, --, --, 
   {{0x27e00115,0x8f0801d5,0xa8140107,0xea180120}},	//   _ĉin_, _تآسف_, ҳдош, ежиш_, 
   {{0x3ea01d0f,0x00000000,0x00000000,0x00000000}},	//   _витг, --, --, --, 
   {{0x1cb00c99,0x35dc0034,0x77640548,0x00000000}},	//   _དཔར_, _बिज़, _amix, --, 
   {{0x2cbc0165,0x6b64037e,0x3940007c,0x99dc0432}},	//   mcvd_, とgot, öjsa_, lyňl, 
   {{0x0a6909e0,0x00000000,0x00000000,0x00000000}},	//   _орли_, --, --, --, 
   {{0x57b00150,0xf98400cf,0x00000000,0x00000000}},	//   _құят, رچۇي_, --, --, 
   {{0xda640592,0x848c02d3,0x7764da7d,0x3ea80419}},	//   _حامي, _መስርዕ_, _emix, _úcte_, 
   {{0x291c02b9,0x1af4015b,0xdca4012c,0x00000000}},	//   _iava_, _আসতে_, गेपछ, --, 
   {{0x291dec22,0xb9d8206f,0x672c05d9,0xc76434b1}},	//   _hava_, _አብ_, _unaj, _جاتى, 
   {{0x291dec23,0x26d9ec24,0x9f4401e1,0x00000000}},	// [37ad0] _kava_, maso_, _ílé_, --, 
   {{0xb9f80020,0x291dec25,0xf0e80208,0x776400d7}},	//   _ዘዴ_, _java_, _đảnh_, _zmix, 
   {{0x291dec26,0x617002d3,0x00000000,0x00000000}},	//   _mava_, ኣለማዊ_, --, --, 
   {{0x291dec27,0x26d9ec28,0xc0c80092,0x00000000}},	//   _lava_, naso_, _አዳም_, --, 
   {{0x2369ec29,0x291c0270,0x26d80421,0xde04010b}},	//   miaj_, _oava_, iaso_, упли, 
   {{0x291d38e2,0x2369ec2a,0x26d9ec2b,0x1cb800ae}},	//   _nava_, liaj_, haso_, راتب_, 
   {{0x656405da,0x6808013f,0x2249ec2c,0xdb00005c}},	//   _mmhh, _yɛde, lyak_, _kulø, 
   {{0x2369ec2d,0xd24c01ed,0x291c00c5,0x670400af}},	//   niaj_, _بچہ_, _aava_, ष्मक_, 
   {{0x22487020,0x291dec2e,0x26d80134,0xdea01c05}},	//   nyak_, _bava_, daso_, _ایشی, 
   {{0x291c601a,0x8cc86a04,0x224822d0,0x23680070}},	//   _cava_, _स्पो, iyak_, hiaj_, 
   {{0x291dec2f,0x26d9ec30,0x60d4008f,0x23680115}},	//   _dava_, faso_, _mezm, kiaj_, 
   {{0x26d80a49,0x27f800a3,0x3c1403b9,0x69b4035b}},	//   gaso_, àrna_, _nəvə_, ықәс_, 
   {{0x55f46feb,0x2368010f,0x59dc0892,0x00000000}},	//   ычну, diaj_, _मिटर, --, 
   {{0x60d41f48,0x291c54bc,0xeff802d3,0x1cb0031c}},	//   _nezm, _gava_, _ወሲዱ_, _དཔས_, 
   {{0x26d9ec31,0xb4043db0,0x8cc81a2a,0x2368010f}},	//   baso_, шүнд, _स्फो, fiaj_, 
   {{0x291c1311,0x26d9ec32,0x2368008f,0x6564003e}},	//   _zava_, caso_, giaj_, _emhh, 
   {{0x60d5ec33,0x7e7802b9,0xb1640032,0x291dec34}},	// [37ae0] _bezm, _nxup, анаһ, _yava_, 
   {{0x291c18f7,0x10a407d6,0x2ecc694b,0xdb00026c}},	//   _xava_, гизн, ार्त, _vulù, 
   {{0x60d400a8,0xd468a710,0xdcb001fb,0x8e382e07}},	//   _dezm, _чине_, _cảm_, کسار_, 
   {{0x236800c8,0x2248020c,0x7c840023,0x00000000}},	//   ciaj_, byak_, _ምሕላው_, --, 
   {{0x3ebc0477,0x3b1c022e,0x42a401d5,0xafc400db}},	//   _dfut_, dduq_, _буёғ, ايچى, 
   {{0x60d4a697,0x24680020,0x26d98e1a,0x3f8c00af}},	//   _gezm, ደሚሉት_, zaso_, algu_, 
   {{0x7e790793,0xab5c0029,0x26d9ec35,0x291dec36}},	//   _exup, _atļa, yaso_, _rava_, 
   {{0x291dec37,0x26d800aa,0x00000000,0x00000000}},	//   _sava_, xaso_, --, --, 
   {{0x291dec38,0x26d9ec39,0x3201ec3a,0x47841219}},	//   _pava_, vaso_, ntiy_, ғынб, 
   {{0x60d41248,0x26d9ec3b,0x02140375,0x2368010f}},	//   _xezm, waso_, נחים_, ziaj_, 
   {{0x291dec3c,0xe894652e,0xfb11ec3d,0x23680211}},	//   _vava_, рань, _گونج, yiaj_, 
   {{0x3dd402f5,0x236801d4,0x291dec3e,0xd1e8001f}},	//   _সমতল, xiaj_, _wava_, ቆሙት_, 
   {{0x291dec3f,0x26d9ec40,0xe944034c,0x3cf805d7}},	//   _tava_, raso_, _پرشی, ल्के_, 
   {{0x6d59ec41,0x26d9ec42,0x8cc802ab,0x4420017a}},	//   nhva, saso_, _स्मो, tvj_, 
   {{0x26d9ec43,0x60d41529,0x2368010f,0x87e40395}},	//   paso_, _rezm, tiaj_, _сюле, 
   {{0xe3140640,0x60d401d5,0x320001d5,0x00000000}},	//   јмањ, _sezm, ftiy_, --, 
   {{0x2369ec44,0x60f806a6,0x60d40240,0x05c8033f}},	// [37af0] riaj_, кная_, _pezm, ़ीखब, 
   {{0x1cb06d7e,0x660dec45,0x236876da,0x6564014b}},	//   _དཔེ_, _ipak, siaj_, _umhh, 
   {{0x6d580a28,0x60d40122,0x5eb46128,0x23680d24}},	//   dhva, _vezm, айет, piaj_, 
   {{0x398817c1,0x660c02e3,0x2249ec46,0x60d4012d}},	//   løst_, _kpak, pyak_, _wezm, 
   {{0xa91c01f1,0x91c000d1,0x78500213,0x60d4008e}},	//   voľn, _дәхл, rəvə, _tezm, 
   {{0x660dec47,0x6d580978,0x61edec48,0x3988003b}},	//   _mpak, ghva, mral, nøst_, 
   {{0x660c0055,0x8d9000d1,0x351c011a,0x00000000}},	//   _lpak, غلىش, גוונ, --, 
   {{0x2001ec49,0x7e7801c6,0x61ec0869,0xdd0405d1}},	//   mthi_, _txup, oral, ısıy, 
   {{0x2000540f,0x660c1c06,0x7e780113,0x61ec1cce}},	//   lthi_, _npak, _uxup, nral, 
   {{0x6d580842,0xaa08475d,0x9f400022,0xdd941367}},	//   chva, ازيل_, juhú_, _тазы, 
   {{0x20001060,0x660dec4a,0x61ec01f1,0x5b340276}},	//   nthi_, _apak, hral, _вэлу, 
   {{0x65740007,0x2001ec4b,0xd7f800c7,0x00000000}},	//   enzh, ithi_, нуҭ_, --, 
   {{0x26100034,0x644033eb,0x398803b2,0x61edec4c}},	//   दौली_, älin, føst_, jral, 
   {{0x98a40678,0x2001ec4d,0x18a5ec4e,0x660c0a2e}},	//   _киле, kthi_, _калм, _dpak, 
   {{0x660dec4f,0x2000036e,0xa3e40303,0x00000000}},	//   _epak, jthi_, _निः_, --, 
   {{0x61edec50,0x6d58030a,0x0454007b,0x3200022e}},	//   fral, zhva, جلفة_, ttiy_, 
   {{0x52a9ec51,0x6608456f,0x20000042,0x99dc013a}},	// [37b00] твам_, çekt, ethi_, dyňk, 
   {{0x00c4119e,0x00000000,0x00000000,0x00000000}},	//   илук_, --, --, --, 
   {{0x61edec52,0xd10039de,0xe18805d9,0x15700131}},	//   aral, र्षण_, ائقن_, _ﭼﯜﺷﯩ, 
   {{0x61edec53,0x660c00c7,0x33200327,0x4898010f}},	//   bral, _ypak, qdix_, דיעװ, 
   {{0x61edec54,0x6d59ec55,0x32000784,0x64400158}},	//   cral, thva, qtiy_, øliv, 
   {{0xcbe5ec56,0xd1300014,0x92cc015b,0x2d5000a3}},	//   ации, _بمس_, _রায়_, _gàel_, 
   {{0x8fa55645,0x2c082fc0,0x5044010b,0x6d580413}},	//   _ваве, اعتی_, _тевб, rhva, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x0e644b17,0x4d15ec57,0x0d2000cf,0x00000000}},	//   _ткан, _вьет, _мүдү, --, 
   {{0x3ea80306,0xe81801c6,0x00000000,0x00000000}},	//   _úcta_, гооч_, --, --, 
   {{0x660dec58,0x6808016b,0x61ec02f0,0xc050010f}},	//   _spak, _bɛda, zral, ַזש_, 
   {{0x8cc8ba7f,0x61edec59,0x60d8013f,0x660c0135}},	//   _स्तो, yral, ɔwmu, _ppak, 
   {{0x0c840032,0x00000000,0x00000000,0x00000000}},	//   _сыҡм, --, --, --, 
   {{0x61ed3b4f,0xaad00014,0x00000000,0x00000000}},	//   vral, _بۅکژ, --, --, 
   {{0x398800ed,0xfa00025c,0x61edec5a,0xad640208}},	//   røst_, _མདོན_, wral, _đứn, 
   {{0x660803e0,0x00000000,0x00000000,0x00000000}},	//   çeks, --, --, --, 
   {{0x61ec06d6,0x660dec5b,0x2d8c010e,0x75e4008e}},	// [37b10] ural, _upak, _okde_, _мәрҗ, 
   {{0x61edec5c,0x00000000,0x00000000,0x00000000}},	//   rral, --, --, --, 
   {{0x6808013f,0x09fc0011,0x71241884,0x20000051}},	//   _yɛda, ্টিং_, تىلم, uthi_, 
   {{0x61edec5d,0x2001ec5e,0xdb0000a2,0x5f0401b9}},	//   pral, rthi_, _bulý, ёзла, 
   {{0x539825f9,0x2000034c,0x1af400bd,0xdd95ec5f}},	//   _תירו, sthi_, _আসলে_, бады, 
   {{0x2000004b,0x9f046393,0x00000000,0x00000000}},	//   pthi_, _گورو, --, --, 
   {{0xdce00306,0x00cc1870,0x1ae4004e,0x00000000}},	//   _umlč, _ﺗﯘﺗﻘ, бойм, --, 
   {{0x2d8c00c8,0x61e803cd,0xdea02099,0x69c4025c}},	//   _ekde_, _åels, _فیضی, _ħier, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3f5403e3,0x00000000,0x00000000,0x00000000}},	//   _uçub_, --, --, --, 
   {{0xdb0003ee,0xe9a8007b,0x1869ec60,0x6441ec61}},	//   _kulü, جدين_, уани_, älil, 
   {{0x975400ea,0xbbb009ab,0x00000000,0x00000000}},	//   стољ, ँदीक, --, --, 
   {{0x279805f5,0x590801ee,0x00000000,0x00000000}},	//   ртээ_, _белм_, --, --, 
   {{0xd46800db,0x00000000,0x00000000,0x00000000}},	//   гиге_, --, --, --, 
   {{0xb4b82d8f,0xa2a40709,0x69c40139,0x00000000}},	//   _छली_, चेस्, _çier, --, 
   {{0x3f9c013f,0xdcb00208,0xb38c0051,0x00000000}},	//   _nhuu_, _cải_, _đồch, --, 
   {{0x91e40107,0x43411a8f,0x31440107,0xd1740150}},	// [37b20] созе, четв, одаҳ, быжы, 
   {{0x3f9dec62,0x50b40150,0x00000000,0x00000000}},	//   _ahuu_, ссау, --, --, 
   {{0x4fe80220,0x94240b7e,0xe4ec00cd,0xdcb00051}},	//   умен_, _умне, _जयति_, _fải_, 
   {{0x3f9dec63,0xadc40022,0xdcfc002b,0xb5048153}},	//   _chuu_, ahẽr, _āyām, श्रय_, 
   {{0x3f9c45b2,0x00000000,0x00000000,0x00000000}},	//   _dhuu_, --, --, --, 
   {{0xad241411,0x00000000,0x00000000,0x00000000}},	//   زىعى, --, --, --, 
   {{0xfa00038f,0x6b5c0694,0x00000000,0x00000000}},	//   _མདུན_, _jégg, --, --, 
   {{0xd90c03e6,0xdb200241,0x391000c7,0x00000000}},	//   ێین_, _àtìr, ҧмыр, --, 
   {{0x6b5c90fc,0x2d8c05b1,0xfe4109e0,0xdce80139}},	//   _légg, _tkde_, _енто, _änğa, 
   {{0x23800024,0xdb000790,0x2d8c00a2,0x00000000}},	//   mėje_, _zulü, _ukde_, --, 
   {{0x238002d5,0x6b5c002e,0xa7147a9c,0x00000000}},	//   lėje_, _négg, омні, --, 
   {{0xe69580e2,0x644001f4,0x00000000,0x00000000}},	//   жимы, älim, --, --, 
   {{0x23800953,0xc668399f,0x00000000,0x00000000}},	//   nėje_, ушне_, --, --, 
   {{0x6b5c00e8,0x29180037,0x00000000,0x00000000}},	//   _bégg, õrad_, --, --, 
   {{0x64b805f9,0xc7c40114,0x6b5c00e5,0x00000000}},	//   _आलीश, _усли, _végf, --, 
   {{0x443c04b9,0xa91c01a2,0x6b5c1574,0xa7fc0205}},	//   ću_, koľk, _dégg, rzıd, 
   {{0xe82022e3,0xd6d80228,0x45f00135,0xdb00002e}},	// [37b30] यिका_, _өтө_, _བཀྲས_, _kulò, 
   {{0xdb00014a,0xba980375,0xa2a400dc,0x23800153}},	//   _sulü, רסמי, चेष्, dėje_, 
   {{0x4425ec64,0xdcb001fb,0x00000000,0x00000000}},	//   _én_, _tải_, --, --, 
   {{0x6235b4f3,0x60c9ec65,0xefd80023,0xf484030d}},	//   _дему, _şemd, _ርብዒ_, _хуьн, 
   {{0x1cb0003d,0xdce000b8,0x23800024,0xdb0801d3}},	//   _དཔང_, _amlā, gėje_, _önél, 
   {{0x629c005f,0x6b5c002e,0xa1584964,0x00000000}},	//   _izso, _yégg, _тагу_, --, 
   {{0x8c400801,0xc0c4001f,0x00000000,0x00000000}},	//   деще, ችኋል_, --, --, 
   {{0x23800024,0x1b489931,0x7640005b,0x19c4c6c2}},	//   bėje_, рзии_, ämyk, обим, 
   {{0x6808013f,0x99780023,0xa06848fb,0xa3d80073}},	//   _bɛdo, _ይብለኒ_, _саңа_, ठीत_, 
   {{0xae040220,0xb4b800ab,0xdb00368c,0x00000000}},	//   _ءولى, _छले_, _puló, --, 
   {{0x9f400200,0x00000000,0x00000000,0x00000000}},	//   jshë_, --, --, --, 
   {{0x16a83117,0x165800c7,0x00000000,0x00000000}},	//   ивни_, аргь_, --, --, 
   {{0x6b5c003e,0x7af8007c,0x00000000,0x00000000}},	//   _dégd, mgut, --, --, 
   {{0x7af9ec66,0x9f400023,0x99780240,0xc668030d}},	//   lgut, fshë_, _ይብሉኒ_, ăшне_, 
   {{0x629c0072,0xb9dc001f,0x7af80083,0x39440afa}},	//   _azso, _ጥሬ_, ogut, _ions_, 
   {{0x7af9ec67,0x39440ba1,0xfbe4001e,0x82600023}},	//   ngut, _hons_, _để_, _ፊልምታ, 
   {{0xcb1004ae,0x7af9ec68,0xa92400d7,0x644003b2}},	// [37b40] ולן_, igut, siľň, ølir, 
   {{0x3945ec69,0x23800006,0x6b5c00e8,0x50940063}},	//   _jons_, vėje_, _tégg, оређ, 
   {{0x3945ec6a,0x7af801e0,0x629c0076,0xe0d402bf}},	//   _mons_, kgut, _ezso, яють, 
   {{0xb8d81b4b,0x11d41fe2,0x3945ec6b,0x23800006}},	//   _མུ_, _мігр, _lons_, tėje_, 
   {{0x542402dd,0x6fe000ae,0x7af80fac,0xff24129e}},	//   _ءﯗﻣﯩ, _bácá, dgut, تبلی, 
   {{0x3945ec6c,0x8bc447b3,0xfd0c10a8,0x23800024}},	//   _nons_, осид, نجى_, rėje_, 
   {{0x6b5dec6d,0x23800006,0x99a40213,0x09e00073}},	//   _lége, sėje_, _şuşa_, पळ्य, 
   {{0x8cc812eb,0x7af9ec6e,0x0ba800cf,0x23800024}},	//   _स्रो, ggut, جاتى_, pėje_, 
   {{0x3945ec6f,0xbb440fb4,0xbf100214,0x6ed07688}},	//   _bons_, تلين_, _زولب, _ड्यु, 
   {{0x7af82ece,0x6441ec70,0x39443046,0x6f000208}},	//   agut, älik, _cons_, _hcmc, 
   {{0x6d49ec71,0xbd640345,0x4ae401a9,0x00000000}},	//   _ioda, _بڕنه_, _дўла, --, 
   {{0xf1f000e1,0xd5840022,0x00000000,0x00000000}},	//   _चिढ़_, ҟәыл_, --, --, 
   {{0x6d49ec72,0x3945ec73,0x6b5c01ed,0x7b84107b}},	//   _koda, _fons_, _cége, _بالە, 
   {{0x6d49ec74,0x39440ea0,0x6b5c0129,0x02d1617c}},	//   _joda, _gons_, _dége, तर्न, 
   {{0x1cb81e81,0x29c007ae,0x9f400200,0x00000000}},	//   _ཚུལ_, _hòa_, ushë_, --, 
   {{0x6d49ec75,0x394401f5,0x368c02e3,0x3358084c}},	//   _loda, _zons_, ọnịk, оасэ_, 
   {{0x6d49ec76,0x3d180316,0x0584039b,0x6b5c01e1}},	// [37b50] _ooda, _यसले_, _муом, _kégb, 
   {{0x6d49ec77,0x8cc83806,0x6f0002d0,0x6519ec78}},	//   _noda, _स्लो, _acmc, _اقدس_, 
   {{0x7af80024,0x29c00208,0x2608012d,0x7fe8007b}},	//   ygut, _lòa_, ाझवी_, شراف_, 
   {{0x6b5dec79,0x6d480192,0xdea00344,0x29c000a2}},	//   _légb, _aoda, فیزی, _oòa_, 
   {{0x1dc43306,0x6f04067c,0xdd950e61,0x629c00e5}},	//   أْتِ, òica, пады, _uzso, 
   {{0x6d49ec7a,0x24d80154,0x8fc400f7,0x91b873cd}},	//   _coda, _তাঁহ, زمۇۇ, _למשי, 
   {{0x6d49ec7b,0x7af87dac,0x2c4c0134,0x7aec0077}},	//   _doda, tgut, yɛde_, ócto, 
   {{0x7af8f4b3,0x39442537,0x60c5ec7c,0x5e58014b}},	//   ugut, _sons_, lchm, _либя_, 
   {{0x7af8716e,0x6d49ec7d,0x60c40332,0x00000000}},	//   rgut, _foda, ochm, --, 
   {{0x6d49ec7e,0x7af851e2,0x6b5c01d3,0x60c402c2}},	//   _goda, sgut, _rége, nchm, 
   {{0x6b5c0241,0x60c43262,0x394405d5,0x661dec7f}},	//   _dégb, ichm, _vons_, ewsk, 
   {{0x6d49ec80,0x24980020,0xa3e59a49,0xdb200248}},	//   _zoda, _መስራት_, _निज_, _àtàr, 
   {{0x6d480df9,0x39443fe5,0xe600010b,0x7f580327}},	//   _yoda, _tons_, вҗын, _ċuql, 
   {{0x6b5c00dd,0x7f580986,0x1ddc16ae,0x6d48008e}},	//   _vége, _lluq, नीयत, _xoda, 
   {{0x7f580912,0xc6e401d9,0x00000000,0x00000000}},	//   _oluq, _کتى۪, --, --, 
   {{0x97ac00ac,0x60c4045f,0x6b5c01ed,0x00000000}},	//   üşdü, echm, _tége, --, 
   {{0xd29802bf,0xd26479a0,0x0034001f,0x50b81888}},	// [37b60] стві_, чкай, _የሚከና, مداد_, 
   {{0x7f580921,0xeb1803ce,0xd17419b0,0x00000000}},	//   _aluq, _दस्त_, чыбы, --, 
   {{0x94240228,0x68fc56ed,0xb3a400fb,0x00000000}},	//   _эмне, òrdi, _олоһ, --, 
   {{0x6d49ec81,0x806001c0,0xc7d4011a,0xb3580345}},	//   _soda, эвхж, פוני_, _بیرا_, 
   {{0xa3b41533,0x6f000165,0xdbd80139,0x1620012c}},	//   _छूट_, _vcmc, _eçüe, मिटर_, 
   {{0x7f59366a,0x6d49ec82,0xe6d802ab,0x3f542d9a}},	//   _eluq, _qoda, _भज्ज, _uçun_, 
   {{0x6d49ec83,0xfbcc143e,0x23800153,0x00000000}},	//   _voda, هتي_, lėja_, --, 
   {{0x6d49ec84,0x7b600c9e,0x0b880640,0x6440005b}},	//   _woda, етье, љски_, älii, 
   {{0x6d48fb7f,0x23800006,0x4d64009b,0x00000000}},	//   _toda, nėja_, _екав, --, 
   {{0xbe100137,0x6d49ec85,0x00000000,0x00000000}},	//   _سومع, _uoda, --, --, 
   {{0xa91c01a2,0xcb680e92,0x6b5c01d3,0x661c012d}},	//   koľv, _лаже_, _végb, wwsk, 
   {{0x29c00016,0xcaf40220,0x23800024,0x752800d7}},	//   _tòa_, _ءساب, kėja_, ôdzn, 
   {{0x661c0582,0x60c4015d,0x238000c0,0xf6e4009d}},	//   uwsk, ychm, jėja_, эцэн, 
   {{0x23800006,0xa8e400f1,0x00000000,0x00000000}},	//   dėja_, _کړکي, --, --, 
   {{0x92cc0183,0x00000000,0x00000000,0x00000000}},	//   ৰলৈ_, --, --, --, 
   {{0x62340107,0x00000000,0x00000000,0x00000000}},	//   мебу, --, --, --, 
   {{0x248c006d,0x60c5ec86,0x23800024,0x67c80118}},	// [37b70] łem_, tchm, gėja_, _děje, 
   {{0x60c469b4,0x290c01d5,0x00000000,0x00000000}},	//   uchm, nfda_, --, --, 
   {{0x60c5ec87,0x490c1a55,0x290c01ab,0x92cc00fe}},	//   rchm, त्यो_, ifda_, _ৰাৰ_, 
   {{0x60c44fbe,0x9e752914,0x5e580150,0x238000c0}},	//   schm, وهات, يلاس_, bėja_, 
   {{0x6dc40131,0xdb000267,0x6b8407f5,0xc0c9ec88}},	//   ۈزۈل, _kulö, čigl, _губе_, 
   {{0x91a801d9,0x63a80083,0xdb00007c,0x00000000}},	//   _ونَے_, ŋend, _julö, --, 
   {{0xea0001dc,0xc0940244,0x3f6400f0,0x00000000}},	//   _đại_, _رجست, _етаб, --, 
   {{0x7f580481,0xd1d40023,0x7d24004b,0x00000000}},	//   _uluq, _ይህብ_, _ډيرې_, --, 
   {{0x3f8d1db8,0xaac400ae,0x00000000,0x00000000}},	//   mogu_, رتين, --, --, 
   {{0x26c80618,0x57e9ec89,0x69a40032,0x00000000}},	//   _afao_, одом_, нлыҡ, --, 
   {{0x4528031c,0x00000000,0x00000000,0x00000000}},	//   _སྣེར_, --, --, --, 
   {{0x290c01ab,0x3f8c0171,0x3448010b,0xdb10007c}},	//   afda_, nogu_, җүми_, åfär, 
   {{0x80e0015b,0xdb4c4451,0xf99c0165,0x98a403e0}},	//   _পান্, _مێژ_, ïès_, rhlı_, 
   {{0x26c80109,0xdb0005d5,0x23800153,0x00000000}},	//   _efao_, _culö, vėja_, --, 
   {{0x3f8c033d,0x6b5c7de2,0xd7c80133,0x141800ae}},	//   kogu_, _héga, _بوبه_, غيرة_, 
   {{0xfa08003d,0x03a1af21,0xe84802dd,0x130802d5}},	//   _ཁྱོན_, висо, _ءجون_, ўнай_, 
   {{0x60c8a697,0x3f8dcbad,0x00000000,0x00000000}},	// [37b80] _şema, dogu_, --, --, 
   {{0x6b5c73a0,0x23800006,0x248c03e0,0x00000000}},	//   _méga, rėja_, şema_, --, 
   {{0x6b5c0231,0x23800153,0x00000000,0x00000000}},	//   _léga, sėja_, --, --, 
   {{0x2bc40c2e,0x3f8dec8a,0x23800024,0x7c5c0092}},	//   _लंबा, gogu_, pėja_, ታውሰው_, 
   {{0xed15ec8b,0x6b5c7747,0x912000c7,0xd1740006}},	//   емль, _néga, _иҿаҵ, _жывы, 
   {{0x1ea87427,0xfa080327,0x63a80327,0x00000000}},	//   ساني_, _ཁྱེན_, ċene, --, 
   {{0xab9410f5,0xc0d41772,0x3f8c16a3,0xdff4005b}},	//   никі, ርኩም_, bogu_, _пять, 
   {{0x6b5c1bce,0x00000000,0x00000000,0x00000000}},	//   _béga, --, --, --, 
   {{0x6b5c01d3,0xf4140154,0xa9540150,0x00000000}},	//   _céga, াটির_, екпі, --, 
   {{0x6b5c7c92,0x2d980022,0x00000000,0x00000000}},	//   _déga, _óre_, --, --, 
   {{0x2c4c013f,0x00f40375,0x1abc00cc,0xbb444605}},	//   bɛda_, וזים_, _ইজৰা, سلین_, 
   {{0xa91c0030,0x1ba801d3,0x5ba400d4,0xa7fc03e0}},	//   voľu, _فانٹ_, _зріз, bzın, 
   {{0x6b5c020c,0x4528031c,0xf62800d4,0xf98c15b4}},	//   _géga, _སྣུར_, міри_, طبی_, 
   {{0x6d59ec8c,0x8c400213,0xab5c00ef,0x00000000}},	//   nkva, şğul, _duļe, --, 
   {{0xa3d800af,0x6d5803cd,0x349401f0,0x00000000}},	//   ठीं_, ikva, варр, --, 
   {{0x6b5c1bce,0xd1d40092,0x6d580037,0x00000000}},	//   _yéga, _ይህች_, hkva, --, 
   {{0x80e02baf,0xf7700133,0x00000000,0x00000000}},	// [37b90] _পাব্, _ڕای_, --, --, 
   {{0x1af400bd,0xa30801ed,0x00000000,0x00000000}},	//   _আসছে_, _کردے_, --, --, 
   {{0x3f8c4031,0x65740165,0x99880135,0xa7fc0205}},	//   togu_, mizh, _ħaż_, zzın, 
   {{0x2d8004c4,0x65740489,0x23800006,0x30a402bf}},	//   éien_, lizh, mėjo_, трув, 
   {{0x80e002a6,0x6455ec8d,0x238002d5,0x3f8dec8e}},	//   _পাঠ্, lyzi, lėjo_, rogu_, 
   {{0xdca5ec8f,0x11d8025f,0x6b5dec90,0x6d5801e3}},	//   нали, _מחשב, _réga, gkva, 
   {{0x63adec91,0x23800006,0x5bb42a24,0x44300254}},	//   oman, nėjo_, нсиф, _jrx_, 
   {{0x63adec92,0xc09001e1,0x6d58017a,0x00000000}},	//   nman, _gbáṣ, akva, --, 
   {{0x63adec93,0x8cc86527,0x44300077,0x6574030a}},	//   iman, _स्को, _lrx_, kizh, 
   {{0x63adec94,0x238002d5,0xa7fc05d1,0x6d5817e2}},	//   hman, kėjo_, rzın, ckva, 
   {{0x63adec95,0xa91c00d0,0xdb000051,0x23800064}},	//   kman, voľt, _bulô, jėjo_, 
   {{0x23800953,0x6b5c020c,0x966441e5,0x00000000}},	//   dėjo_, _téga, екме, --, 
   {{0x443009ad,0x657406d1,0xcf54011a,0x00000000}},	//   _arx_, fizh, גברת_, --, 
   {{0x18680801,0x86a00032,0x64540306,0x68fc00a3}},	//   _нали_, ығыҙ, fyzi, òrdt, 
   {{0xd04c013f,0x4430508f,0x63adec96,0x9878008f}},	//   _debɛ, _crx_, fman, _מאַט, 
   {{0x66240598,0xc32014b7,0x44300fac,0x27940124}},	//   ätkä, лмск, _drx_, _ишыр, 
   {{0x6d58003b,0x4430000d,0x00000000,0x00000000}},	// [37ba0] ykva, _erx_, --, --, 
   {{0x63adec97,0x23800006,0x410024fc,0xe3b80107}},	//   aman, bėjo_, лзув, збӣ_, 
   {{0x5ed003f4,0x63ac4745,0x64400f23,0x8f7401ec}},	//   _হয়ে, bman, älit, нуді, 
   {{0x80e00729,0x4ea507cf,0xa2c03be5,0xa4900345}},	//   _পাণ্, нрла, लखण्, _ئیفت, 
   {{0x6d580115,0x00000000,0x00000000,0x00000000}},	//   tkva, --, --, --, 
   {{0x644093e0,0xac19ec98,0x6b5c01d3,0xb50407af}},	//   ålig, доку_, _cégn, श्चय_, 
   {{0x6d59ec99,0xbd401823,0xfa080327,0xc4d0011a}},	//   rkva, انىي, _ཁཱུན_, נגה_, 
   {{0x6d59ec9a,0x67c8038e,0x65740010,0x00000000}},	//   skva, _něja, zizh, --, 
   {{0x6808013f,0xc3300375,0x0d84039e,0x6d5801bf}},	//   _yɛdw, רוח_, _злан, pkva, 
   {{0x1e800cef,0x7a1000ec,0xc864013d,0xfce000f3}},	//   _әһәм, ابيء, етми, _бофо, 
   {{0x63adec9b,0x1cb849a6,0xd04c016b,0xdb2423cf}},	//   yman, _ཚུག_, _rebɛ, رویی, 
   {{0x63adec9c,0x23800006,0x65740099,0x0a480276}},	//   xman, vėjo_, wizh, _нзей_, 
   {{0xf7100016,0x63adec9d,0xdb0801ed,0x6574030a}},	//   _tầng_, vman, _önál, tizh, 
   {{0xb524467b,0x63ac0986,0xda65ec9e,0xe97401b9}},	//   льск, wman, _جامي, _جهتد, 
   {{0x63adec9f,0x6575eca0,0x25ec00e1,0x00000000}},	//   tman, rizh, _अटकी_, --, 
   {{0x238002d5,0x6b5c0129,0xa7fc0790,0x24d80154}},	//   rėjo_, _mégo, nzım, _তাওহ, 
   {{0x63adeca1,0x23800153,0x64540129,0x427400f2}},	// [37bb0] rman, sėjo_, syzi, رارآ, 
   {{0x4430e630,0x0680035b,0x23800153,0x644016ca}},	//   _trx_, _аҳҭн, pėjo_, älis, 
   {{0x63adeca2,0x6b5c07ea,0xc0a83dca,0xa3d4010b}},	//   pman, _négo, سائل_, _шонч, 
   {{0x2d9c04d4,0x63ac0986,0x00000000,0x00000000}},	//   elve_, qman, --, --, 
   {{0x6b5c05d5,0xac840220,0x1cb8031c,0x00000000}},	//   _pégn, ңгіл, _ཚུང_, --, 
   {{0x6b5c002e,0x29180254,0x00000000,0x00000000}},	//   _bégo, õral_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6344001f,0x6b5c004a,0xc84802d3,0x2d9c0200}},	//   _ከወጣበ, _dégo, _ንመራሕ, alve_, 
   {{0x44200457,0x5984010b,0x9e94215c,0x0b40ca0f}},	//   hwj_, клиб, _شارچ, рнын, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8cc8547d,0x18684986,0x798002d0,0xebe400d4}},	//   _स्टो, фани_, _vjnw, _боєп, 
   {{0x3ce40165,0x1a64029e,0x60c800a2,0x00000000}},	//   lanv_, _لیبی_, _şeml, --, 
   {{0xdb1800e8,0x6b5c0036,0xcb10011a,0x00000000}},	//   _liwë, _mégl, _כלא_, --, 
   {{0xeab05821,0x6b5c007f,0x3ea80306,0x7d0001c7}},	//   _طعن_, _légl, _úctu_, ngns, 
   {{0x3ebc0263,0x3ce40165,0x84e0005b,0x00000000}},	//   _ogut_, ianv_, росж, --, 
   {{0x3ebc138f,0x6b5c07ea,0x27f80030,0xd77400db}},	//   _ngut_, _négl, árne_, _جاتع, 
   {{0x490c00dc,0xd4f473b6,0x55880114,0xe1f000e5}},	// [37bc0] त्वो_, _ияны, _обим_, یسے_, 
   {{0x3ebc180f,0x00000000,0x00000000,0x00000000}},	//   _agut_, --, --, --, 
   {{0xe1f01a59,0x6b5c00e8,0x76a801e1,0x85200345}},	//   لسە_, _bégl, _fèyí, _ئوپۆ, 
   {{0xb900025c,0x6b5c003e,0xc91c146b,0x53a400d8}},	//   _ཨབ_, _régo, _भस्म_, _јамб, 
   {{0x332000f7,0x6b5deca3,0x00000000,0x00000000}},	//   meix_, _dégl, --, --, 
   {{0x33200097,0x6b5c020c,0x3ce40156,0x52740c60}},	//   leix_, _pégo, ganv_, _зуҳу, 
   {{0x3d2801b9,0x26d8058a,0x00000000,0x00000000}},	//   بتنی_, ybso_, --, --, 
   {{0x3321eca4,0x3b1c0369,0x61f0032e,0x95f00210}},	//   neix_, geuq_, _áklæ, _अटूट_, 
   {{0x15ec05f9,0x44200007,0xdd8001d9,0x1ee800e5}},	//   _जिगर_, zwj_, _گیوٝ, _سڈنی_, 
   {{0xdbd80261,0xd9b02033,0x44200369,0x1ea81913}},	//   _açõe, مەند, ywj_, _ساقي_, 
   {{0x44200211,0x6b5c0694,0x1c380006,0x108400d1}},	//   xwj_, _yégl, _пяць_, _ﯪﻟﺪﯨ, 
   {{0xa5f91f1b,0x6f0400e4,0x00000000,0x00000000}},	//   нему_, òich, --, --, 
   {{0x33200228,0x80e002f5,0xab5c00e2,0xe9443cc4}},	//   deix_, _পাস্, _guļa, _مرثی, 
   {{0xa2d40d1a,0xf98c01d5,0xfaa06fe4,0x00000000}},	//   युन्, _وبو_, _тачо, --, 
   {{0x68e9eca5,0x4788026a,0x2ee4017a,0x87940014}},	//   madd, _осим_, _oemf_, _لێدر_, 
   {{0x3321eca6,0xf7700128,0x68e9eca7,0x490c255c}},	//   geix_, _واي_, ladd, त्रो_, 
   {{0x6b5c0231,0x61140046,0xdb1804fb,0x442001d4}},	// [37bd0] _régl, лдау, _diwè, swj_, 
   {{0x660c014b,0x672c36c6,0x00000000,0x00000000}},	//   _iqak, _haaj, --, --, 
   {{0x672deca8,0x332000cf,0xe3b800f3,0x00000000}},	//   _kaaj, beix_, _плоч_, --, 
   {{0x672deca9,0x68e9ecaa,0x3ce40083,0x00000000}},	//   _jaaj, hadd, wanv_, --, 
   {{0x68e9ecab,0x672c32ff,0x63bc0280,0x6b5c01ed}},	//   kadd, _maaj, _iisn, _végl, 
   {{0x672decac,0x68e9ecad,0x63bdecae,0x365c0a7c}},	//   _laaj, jadd, _hisn, וכדנ, 
   {{0x68e9cdc3,0x63bdecaf,0x629c003a,0x6b5c01ed}},	//   dadd, _kisn, _hyso, _tégl, 
   {{0x2001ecb0,0x672decb1,0x63bc020c,0x660c0194}},	//   muhi_, _naaj, _jisn, _oqak, 
   {{0x68e9ecb2,0x2000166a,0x660decb3,0x39600107}},	//   fadd, luhi_, _nqak, иниҳ, 
   {{0x61edecb4,0x629decb5,0x68e9ecb6,0x63bdecb7}},	//   isal, _myso, gadd, _lisn, 
   {{0x200015a5,0x672decb8,0x660decb9,0x61ec03be}},	//   nuhi_, _baaj, _aqak, hsal, 
   {{0x61edecba,0x63bdecbb,0x21200441,0x68e80083}},	//   ksal, _nisn, hehh_, aadd, 
   {{0x68e9ecbc,0x672decbd,0x629c0158,0x200000b0}},	//   badd, _daaj, _nyso, huhi_, 
   {{0x63bdecbe,0x68e80050,0x2000123c,0x61ec262a}},	//   _aisn, cadd, kuhi_, dsal, 
   {{0x63bdecbf,0x33200372,0x660c01f0,0xd4685f0d}},	//   _bisn, teix_, _eqak, хиве_, 
   {{0x629c0263,0x212002ea,0x672c01d9,0x20000066}},	//   _byso, eehh_, _gaaj, duhi_, 
   {{0x61edecc0,0x33200228,0x776400f1,0x03a00868}},	// [37be0] gsal, reix_, _ilix, сито, 
   {{0x629c00b5,0xdb1800f2,0x63bc0162,0x20000270}},	//   _dyso, _diwé, _eisn, fuhi_, 
   {{0x5ecc00bd,0x61ec0eda,0x672decc1,0xe3b000aa}},	//   ারনে, asal, _yaaj, صرې_, 
   {{0x672c8531,0x0e64728c,0x63bdecc2,0x998c00d0}},	//   _xaaj, лкен, _gisn, steň_, 
   {{0x80e003f4,0x68e9ecc3,0x629c0368,0x61ec00e5}},	//   _পার্, yadd, _gyso, csal, 
   {{0x2001ecc4,0x68e85284,0x6c540261,0x77640200}},	//   buhi_, xadd, иклу, _llix, 
   {{0x68e9ecc5,0x01605fce,0x77640472,0x2000011f}},	//   vadd, _укро, _olix, cuhi_, 
   {{0x68e82252,0x63bc0429,0x4fc40032,0x97ac0205}},	//   wadd, _xisn, _асҡа, üşlü, 
   {{0x68e9ecc6,0x672decc7,0x00000000,0x00000000}},	//   tadd, _raaj, --, --, 
   {{0x672decc8,0x7765ecc9,0xa815ecca,0x628000dc}},	//   _saaj, _alix, адош, _ślok, 
   {{0x68e9eccb,0x7765eccc,0x672deccd,0x61ec2fb8}},	//   radd, _blix, _paaj, zsal, 
   {{0x61edecce,0x68e9eccf,0x77645133,0x672c0009}},	//   ysal, sadd, _clix, _qaaj, 
   {{0x68e807d5,0x63bdecd0,0x61ec0548,0x6b5c01d3}},	//   padd, _risn, xsal, _légk, 
   {{0x7765ecd1,0x672d8253,0x63bc0227,0x68e9ecd2}},	//   _elix, _waaj, _sisn, qadd, 
   {{0x7765ecd3,0x629decd4,0x63bdecd5,0x61edecd6}},	//   _flix, _syso, _pisn, wsal, 
   {{0x61edecd7,0x20000d04,0x672c0194,0x63bc025c}},	//   tsal, vuhi_, _uaaj, _qisn, 
   {{0x63bc51dc,0x61edb241,0xafc4192c,0x660c009a}},	// [37bf0] _visn, usal, ەيمى, _uqak, 
   {{0x629c0745,0x2001ecd8,0x61edecd9,0x63bdecda}},	//   _vyso, tuhi_, rsal, _wisn, 
   {{0x61edecdb,0x629c006d,0x63bdecdc,0x6b5c01d3}},	//   ssal, _wyso, _tisn, _cégk, 
   {{0x5ecc0183,0x63bc1db0,0x00000000,0x00000000}},	//   াৰনে, _uisn, --, --, 
   {{0x2001ecdd,0x1d0817d0,0x714400cf,0x00000000}},	//   suhi_, вели_, _گۉلۅ, --, 
   {{0x20000053,0xee3800dd,0x2368020b,0xaf04010b}},	//   puhi_, اقوں_, lhaj_, ачәк, 
   {{0xa3d80490,0x3e400014,0xdca401f0,0x2248013d}},	//   ठीच_, _گێشٲ, шаки, lxak_, 
   {{0x2369ad4b,0x3d2801d5,0x9f048dff,0xdc940023}},	//   nhaj_, بتچی_, _خورو, _ልዕለይ_, 
   {{0x1dc4013d,0x6b5c01d3,0xdb140241,0x00000000}},	//   _төен, _mégh, _ìbíw, --, 
   {{0xa2d4085c,0x9b440326,0xbb8001ec,0x00000000}},	//   युत्, انکو, _ﺩﻓﻌﻪ_, --, 
   {{0x98a5ecde,0x18a5ecdf,0x68fce0ff,0x77640254}},	//   рине, ранм, órda, _plix, 
   {{0x27f99c01,0xab841a5c,0x9a7800cf,0xca7402f2}},	//   árna_, _лучк, _ийет_, امیش_, 
   {{0xd945ece0,0xc6000b30,0x77640393,0x236801e4}},	//   _вели, озяй, _vlix, dhaj_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x09d805ac,0x00000000,0x00000000,0x00000000}},	//   _দিযা, --, --, --, 
   {{0x7764fec3,0x23680978,0xd66800f1,0xe7d401c8}},	//   _ulix, ghaj_, _لمبو_, _اميگ, 
  
   {{0x40340020,0x50d5ece1,0x42c52159,0x6b5c0332}},	// [37c00] _የሚገኙ, لزار, ргун_, _dégh, 
   {{0x50b856e8,0x00000000,0x00000000,0x00000000}},	//   نداد_, --, --, --, 
   {{0xd0249db8,0xa6a897f7,0x23680369,0x53a40114}},	//   рмей, _لایق_, bhaj_, _ванб, 
   {{0x2369ece2,0xa2d444af,0x6b5c00e5,0x98a408a9}},	//   chaj_, युद्, _végk, nklı_, 
   {{0xdce003ee,0x00000000,0x00000000,0x00000000}},	//   _aklı, --, --, --, 
   {{0x1fb40022,0x86340677,0x00000000,0x00000000}},	//   _ҳсур, יאנג_, --, --, 
   {{0x50a80882,0x7eb829ef,0x6b5c0129,0x0b8848e5}},	//   _करिष, _päpü, _hégi, ксии_, 
   {{0x83780092,0x20e400b8,0x99dc0432,0x00000000}},	//   _ተወዳጅ_, _āśiṣ, lyňy, --, 
   {{0x7eb80793,0x60c80356,0x00000000,0x00000000}},	//   _väpü, _şemi, --, --, 
   {{0xdd8c04a9,0x6b5c00dd,0x2919ece3,0x8c78023a}},	//   _كۈن_, _mégi, ýra_, _ищет_, 
   {{0x6b5da91c,0x01340302,0xe75800d4,0x00000000}},	//   _légi, ברית_, гині_, --, 
   {{0x23680023,0xbb40074d,0x3f5400a2,0x00000000}},	//   xhaj_, _мехк, _uçut_, --, 
   {{0xa934010b,0x2248011f,0x29d40eff,0x9b640137}},	//   _гелш, xxak_, _ايتس, _دەيم_, 
   {{0x99dc00a2,0x00000000,0x00000000,0x00000000}},	//   jyňy, --, --, --, 
   {{0xdcb00208,0xe2f80212,0xa3d401d5,0x99dc00ee}},	//   _bảy_, леві_, собч, dyňy, 
   {{0x224801c0,0xc61c00cc,0x00000000,0x00000000}},	//   txak_, দিবা_, --, --, 
   {{0x41e4753d,0x47d000ec,0x6b5c00e5,0x00000000}},	// [37c10] ріба, _ايڊر, _cégi, --, 
   {{0xdb0800c6,0x2369ece4,0x6b5c06af,0x99dc00ee}},	//   imeá, shaj_, _dégi, gyňy, 
   {{0xf0e8c9c6,0x44241675,0x00000000,0x00000000}},	//   شىنى_, _èn_, --, --, 
   {{0xdecc02d3,0x6e24031c,0x00000000,0x00000000}},	//   _ኢድካ_, ħibn, --, --, 
   {{0xd3340bd9,0xb284005b,0x6d5c0327,0x99dc0432}},	//   _פרשה_, _дырк, _ċrar, byňy, 
   {{0xc0c80063,0xfc840023,0x00000000,0x00000000}},	//   _шуме_, _ዝሕግዙ_, --, --, 
   {{0x6b5c0ba1,0x9f34109a,0x7c84ca7c,0xdea01809}},	//   _zégi, _леві, шуде, _کیشی, 
   {{0x21300156,0xdcb00051,0x9f440cad,0x00000000}},	//   _hazh_, _xảy_, _ìlà_, --, 
   {{0x5ecc015b,0x21300156,0x1cb80327,0xaaac095f}},	//   ারদে, _kazh_, _ཚུམ_, _चरणक, 
   {{0x97d8a6bb,0xa6e000fe,0x23800064,0x00000000}},	//   льму_, _ভাগট, mėju_, --, 
   {{0x315800c8,0x21300066,0x3f540205,0x63a80327}},	//   ייזן_, _mazh_, _uçus_, ċenj, 
   {{0x6e4000fd,0x213005c7,0x18a48f62,0x0f78010f}},	//   _üzbä, _lazh_, _қайм, ָרשל, 
   {{0x98a40ab7,0x64407a1e,0x23800153,0x00000000}},	//   rklı_, ålin, nėju_, --, 
   {{0xceb0025f,0x6b5da91c,0x64400115,0xa2d400cd}},	//   פים_, _régi, ĥlin, युस्, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x317800d7,0x09d80154,0x238000c0,0x22b00055}},	//   _smrz_, _দিতা, kėju_, _ṅka_, 
   {{0x52a873b8,0x213005c7,0x23800064,0x53c40150}},	// [37c20] увам_, _bazh_, jėju_, рағұ, 
   {{0x6b5c01ed,0x23800153,0xf1c00419,0x00000000}},	//   _végi, dėju_, čšou_, --, 
   {{0x99dc0209,0xe0d402bf,0x256c01e1,0x00000000}},	//   ryňy, юють, _wólù_, --, 
   {{0x46104bcf,0x441800df,0x6e2403e0,0x00000000}},	//   _بویر, _גוטס, çibo, --, 
   {{0xb1480502,0x00000000,0x00000000,0x00000000}},	//   _پیام_, --, --, --, 
   {{0xf985ece5,0x2130030a,0x1ea80592,0xe5840055}},	//   _رب_, _gazh_, جامي_, _ājīā, 
   {{0xc0d40b82,0x00000000,0x00000000,0x00000000}},	//   ይኩም_, --, --, --, 
   {{0x23800064,0x00000000,0x00000000,0x00000000}},	//   bėju_, --, --, --, 
   {{0x0e6436da,0x2bc42802,0x9f440248,0x98a800de}},	//   _укан, _लंका, _ìlá_, _ēkās_, 
   {{0xdb09ece6,0x3f5403b9,0x9e6400f2,0x9f440241}},	//   rmeá, _uçur_, _بافن, _ílò_, 
   {{0xcb0805d9,0xc198008f,0xfcd030bf,0x2cb80192}},	//   _ميان_, רשיי, _رينج, _àrd_, 
   {{0x32002165,0x61e80432,0x00000000,0x00000000}},	//   kriy_, _çelg, --, --, 
   {{0x32005fda,0x8bf800cc,0x0c8401af,0x00000000}},	//   jriy_, _আহিন_, _тыҡм, --, 
   {{0x3200011f,0xf7f001d9,0x6b5c00e5,0x00000000}},	//   driy_, _کٲٹھ, _cégv, --, 
   {{0x291c006f,0x213005c7,0x29d40451,0xf98400f1}},	//   _ibva_, _razh_, _ايڪس, _دنوي_, 
   {{0x6304498b,0xb38c0208,0x00000000,0x00000000}},	//   تورل, _đểch, --, --, 
   {{0xe800547d,0xa2d40b7c,0x2769ece7,0xc2e401d5}},	// [37c30] लंका_, युष्, _مشکی_, _қўни, 
   {{0x37d80c58,0xa2d805d7,0x26c40118,0x00000000}},	//   _ভিতৰ, _फ्र्, ělou_, --, 
   {{0x320001c8,0x21300156,0x3a840131,0x00000000}},	//   ariy_, _vazh_, ﺭﻏﯘﻥ_, --, 
   {{0x2d8c7313,0x21300156,0xfc3c0306,0x32000100}},	//   _ajde_, _wazh_, _čí_, briy_, 
   {{0x291c006f,0x67c800bc,0x68f801ef,0x644003b2}},	//   _obva_, _ději, _odvd, ælif, 
   {{0xe1884445,0xa2d400dc,0x6ffc054e,0x71a400c0}},	//   _төбе_, युर्, făcă, _наўз, 
   {{0x6b5db108,0x1b49ece8,0xa2c0084d,0xdc68005a}},	//   _légu, изки_, वशक्, райд_, 
   {{0x291c006f,0x998c00ef,0x23800064,0x5ac80166}},	//   _abva_, dveš_, pėju_, шлим_, 
   {{0x49c40323,0xc8d80574,0x291cb69f,0x61e80205}},	//   олын_, _म्हट, _bbva_, _çeld, 
   {{0xec68070e,0x2d800036,0xfba80150,0x00000000}},	//   ррәк_, éiet_, _өтей_, --, 
   {{0x291c00f3,0xdd8c0131,0xdecc0023,0xfe2403e0}},	//   _dbva_, _كۈچ_, _ብመን_, şçıl_, 
   {{0x6b5d919a,0xa2d813f7,0x00000000,0x00000000}},	//   _bégu, _फ्ल्, --, --, 
   {{0x3f9c16cb,0x320001b9,0x0604011c,0x00000000}},	//   _mkuu_, xriy_, оняк_, --, 
   {{0x6b5dece9,0x7ae80660,0x200002c4,0x2d50004e}},	//   _dégu, _hegt, krhi_, _sàez_, 
   {{0x3f9c0093,0x6b5c0248,0xdb2001e1,0x00000000}},	//   _okuu_, _eégu, _àtór, --, 
   {{0xd04c013f,0x3201dfd3,0x60d40208,0x434002e8}},	//   _mebɔ, triy_, _afzm, месв, 
   {{0x7ae8066d,0xe70838eb,0x2fd80e78,0xe6b40132}},	// [37c40] _megt, _اتىن_, _strg_, _ىلىگ, 
   {{0x7ae9ecea,0x3f9c020b,0x32000784,0x78a0032e}},	//   _legt, _akuu_, rriy_, _kynv, 
   {{0x4f940372,0x61e80327,0x320001d5,0x0ff826c6}},	//   орду, _ħele, sriy_, شعاب_, 
   {{0x5275eceb,0x7ae9ecec,0x78a00363,0x3200020c}},	//   _дугу, _negt, _mynv, priy_, 
   {{0x4cd003d4,0x20000254,0xdd8c00d1,0x00000000}},	//   হৰফু, arhi_, گۈل_, --, 
   {{0x463800c8,0xdb08023a,0x6b5c01d3,0x64400162}},	//   יענע, hmeä, _légt, ælig, 
   {{0x3f9c0270,0x6ab4146b,0x7ae80064,0x34a80073}},	//   _fkuu_, ुश्र, _begt, _गरोद, 
   {{0x291c070d,0x0b884c70,0x7ae80175,0xaa541575}},	//   _sbva_, јски_, _cegt, звиш, 
   {{0x7ae9eced,0x09480e91,0x0d84368e,0xfaa00114}},	//   _degt, ачни_, _длан, маћо, 
   {{0x6b5decee,0x61e8acf4,0x7ae801d9,0x2d8c0306}},	//   _régu, _çele, _eegt, _ujde_, 
   {{0xcb681d39,0x6b5decef,0x2d9decf0,0x3a2c00c0}},	//   _каже_, _ségu, move_, _esgp_, 
   {{0x2d9d7c45,0x6b5d5ce3,0x2498001f,0x7ae808a5}},	//   love_, _pégu, _መስማት_, _gegt, 
   {{0x291c070d,0x6b5c1bce,0x291800c5,0xfb506ea9}},	//   _tbva_, _dégt, õras_, _تپند, 
   {{0x2d9decf1,0x2768168d,0xda6452c8,0x291c1682}},	//   nove_, _گشتی_, _عاني, _ubva_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6b8001b9,0xd1dc0092,0xdaa000d1,0x27680271}},	//   nimg, ንጨት_, _تەۋپ, _دشتی_, 
   {{0x2d9decf2,0x60f80aec,0xc1e811ed,0x00000000}},	// [37c50] kove_, йная_, рьбе_, --, 
   {{0x290c9f93,0x2d9decf3,0x26c80270,0xb5c85598}},	//   ngda_, jove_, _hgao_, _گویم_, 
   {{0x2d9c3858,0x20000589,0x60c82ba3,0x6b801eca}},	//   dove_, urhi_, _şems, kimg, 
   {{0x2fc40334,0x6b5c01ed,0xf48407d5,0x20000393}},	//   _cimg_, _mégs, _цуьн, rrhi_, 
   {{0x7ae80591,0x24bc0729,0x2d9c05a1,0x26c801c8}},	//   _regt, _অভিহ, fove_, _mgao_, 
   {{0xd05c013f,0x3cf400c5,0x7ae82ba4,0x34380214}},	//   napɛ, ीलें_, _segt, _اسید_, 
   {{0x2fc4a8cf,0x6f040332,0x00000000,0x00000000}},	//   _fimg_, óicc, --, --, 
   {{0x3f9decf4,0x2d8004c4,0x26c9ecf5,0x6b81ecf6}},	//   _ukuu_, éier_, _ngao_, gimg, 
   {{0x34a802f8,0x2d9c08a4,0x7ae9ecf7,0x6b5c017a}},	//   _गर्द, bove_, _vegt, _régt, 
   {{0x26c80618,0xdb18011f,0x290c01e6,0x7ae915e1}},	//   _agao_, _diwá, ggda_, _wegt, 
   {{0x2fc40408,0x6b8006b4,0x7ae81bce,0xfcec0092}},	//   _yimg_, bimg, _tegt, ጂንግ_, 
   {{0x2fc40334,0x6370007c,0x00000000,0x00000000}},	//   _ximg_, _hånf, --, --, 
   {{0x78a00af9,0x6b5c01ed,0x1a641d0a,0x00000000}},	//   _wynv, _végt, _ریدی_, --, 
   {{0x78a00076,0x00000000,0x00000000,0x00000000}},	//   _tynv, --, --, --, 
   {{0x04401b0a,0x394423bd,0x6370007c,0x2b400332}},	//   нерн, _inns_, _månf, _óicc_, 
   {{0x69c40a40,0x00000000,0x00000000,0x00000000}},	//   _éier, --, --, --, 
   {{0x2d9decf8,0x2fc40175,0x938801e0,0x00000000}},	// [37c60] yove_, _rimg_, асҡа_, --, 
   {{0x6b8001b9,0xef24031c,0x2fc40334,0x8678011a}},	//   zimg, _ལིངྐ_, _simg_, _לרפו, 
   {{0x2d9c1505,0xb4d813f7,0x53a42c0b,0x6b8001a9}},	//   vove_, ाडी_, _наоб, yimg, 
   {{0xed580030,0x0e8c063f,0x0dc9ecf9,0xbea405d9}},	//   _soľ_, kịtị_, буки_, ڻهون_, 
   {{0x39441675,0x290c8f30,0x6d343dc8,0x6b800175}},	//   _onns_, ygda_, делф, vimg, 
   {{0x09d800bd,0xbcf00075,0x9e640150,0x6b5decfa}},	//   _দিলা, ىسىغ, بامن, _négr, 
   {{0x80e000bd,0xfe6c00dd,0x2fc40175,0xdb180241}},	//   _পাচ্, نگے_, _timg_, _siwá, 
   {{0x39440876,0x2d9d67bb,0x67c80118,0x53bc00dc}},	//   _anns_, sove_, _mějt, ्दिश, 
   {{0x0e65ecfb,0x6b8001b9,0xbf1000db,0x00000000}},	//   _экан, rimg, _سولب, --, 
   {{0xde440014,0x0afc009e,0xa97802bf,0x5be402dd}},	//   _آیوو_, ্জেল_, ійну_, _ﺍﻨﺩﻻ, 
   {{0x6b800408,0x53bc813f,0x6b5decfc,0x457001e1}},	//   pimg, ्दाश, _dégr, _nìwọ_, 
   {{0x6d48025a,0x6b5c01d3,0xa924010b,0x6b80022e}},	//   _hnda, _végs, чдүл, qimg, 
   {{0x798800d2,0x63700267,0x28f8026b,0xb4d80a8a}},	//   ólwá, _hång, _дель_, ाडू_, 
   {{0xdb100267,0x998c012d,0x00000000,0x00000000}},	//   åför, ateł_, --, --, 
   {{0x6d480bd7,0x00000000,0x00000000,0x00000000}},	//   _mnda, --, --, --, 
   {{0x63700628,0x26c83881,0x466819c3,0x00000000}},	//   _mång, _ugao_, _гром_, --, 
   {{0x63700628,0x6440f2bb,0x00000000,0x00000000}},	// [37c70] _lång, ælib, --, --, 
   {{0x6d480943,0xc4f801b9,0x313401ee,0xab5c0171}},	//   _nnda, _اعظا_, неур, _guļv, 
   {{0x7fe82f84,0x6370007c,0x00000000,0x00000000}},	//   صراف_, _nång, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x44304cdf,0x00000000,0x00000000,0x00000000}},	//   _hsx_, --, --, --, 
   {{0xdca4275b,0x6370007c,0x00000000,0x00000000}},	//   мали, _bång, --, --, 
   {{0x6b5decfd,0x7094013e,0x00000000,0x00000000}},	//   _régr, _зарф, --, --, 
   {{0x3ab00032,0x42800023,0x6b5ca39a,0x00000000}},	//   нәлт, _ጨካናት_, _ségr, --, 
   {{0x44300263,0x20400092,0x7e44030d,0x00000000}},	//   _lsx_, _የሚቀረ, _эхве, --, 
   {{0x6371ecfe,0xceb00375,0xfaa0e73b,0x00000000}},	//   _hånd, _יין_, мақо, --, 
   {{0x63700628,0x4431ecff,0x6b5c00dd,0x7c6400c6}},	//   _gång, _nsx_, _végr, _عائل, 
   {{0x0e8c01f2,0xf1c00030,0x24c40154,0x4c98011a}},	//   mịrị_, čšiu_, ্রাহ, _ובעו, 
   {{0x27e004b9,0x6371ed00,0x795c025a,0x0e8c02e3}},	//   _čine_, _månd, _sêwu, lịrị_, 
   {{0x18685cf0,0x7f5800d8,0x44300129,0x2ca005d2}},	//   _мали_, _louq, _bsx_, şide_, 
   {{0x7bc400d8,0xd4680120,0x67c8013a,0x00000000}},	//   _éjus, циве_, _dějs, --, 
   {{0x443003b9,0x60c80205,0x279401af,0x00000000}},	//   _dsx_, _şemp, _пшыр, --, 
   {{0x03a1ed01,0xcad001f2,0x0e8c063f,0x31441086}},	// [37c80] тито, _kịrị, hịrị_, ндаҳ, 
   {{0xdb1801c7,0x0e8c00b4,0x3ea80306,0x00000000}},	//   _hiwä, kịrị_, _úcty_, --, 
   {{0x637008cb,0x68fc0798,0x7f59ed02,0x00000000}},	//   _bånd, órdi, _bouq, --, 
   {{0x6d480117,0xb8dc0135,0x0e8c01f2,0xfd540241}},	//   _snda, _ཀཻ_, dịrị_, _ifaṣ, 
   {{0x63a8003d,0x6370049f,0x6d4805b1,0xdb1800a2}},	//   ċent, _sång, _pnda, _miwä, 
   {{0xcf2400ec,0x61e80200,0x00000000,0x00000000}},	//   _ڪرسي, _çela, --, --, 
   {{0x7f580007,0xfccc0023,0x00000000,0x00000000}},	//   _fouq, _ብጸጋ_, --, --, 
   {{0x7f580007,0xcf240740,0x6370007c,0xfba400cf}},	//   _gouq, _ترسي, _vång, мтый_, 
   {{0x0e8c01f2,0x00000000,0x00000000,0x00000000}},	//   rịsị_, --, --, --, 
   {{0x6d490e06,0x0e8c01f2,0x637001e3,0x67f402d2}},	//   _unda, bịrị_, _tång, _nýjá, 
   {{0xcad001f2,0x7f580399,0x0e8c01f2,0x637012ed}},	//   _dịrị, _youq, pịsị_, _håne, 
   {{0x4431ed03,0x09e402bf,0xd1d40023,0x00000000}},	//   _rsx_, _жодн, _ክህቡ_, --, 
   {{0x9f6420ef,0xba700244,0x00000000,0x00000000}},	//   étés_, _لاوت, --, --, 
   {{0x6370501b,0x224401ef,0x4920014b,0x00000000}},	//   _måne, _člk_, _рӯиҳ, --, 
   {{0xb8047ae6,0x6fb00210,0x00000000,0x00000000}},	//   _قيوم_, ड़गां, --, --, 
   {{0xb9e400db,0x41e401ec,0x00000000,0x00000000}},	//   _رتۇۇ, діжа, --, --, 
   {{0x7f5806af,0xa4d400d4,0xa2d400cd,0xddd80210}},	// [37c90] _rouq, _попі, युग्, zywł, 
   {{0x9f440570,0x6370007c,0x00000000,0x00000000}},	//   _ìlú_, _sånd, --, --, 
   {{0x7f58617f,0x00000000,0x00000000,0x00000000}},	//   _pouq, --, --, --, 
   {{0x931402dd,0xa2e80327,0x63a8031c,0x00000000}},	//   _كوپش, _འབྲཻ, ċens, --, 
   {{0xf2c4036b,0x23680010,0x637001e3,0xb27400c0}},	//   _асрн, mkaj_, _vånd, _аляш, 
   {{0xee39ed04,0x236804ac,0x0e8c01f2,0xe1342b95}},	//   ьні_, lkaj_, tịrị_, _янгы, 
   {{0x7f5806af,0x44e401a9,0x1a641550,0xbff001af}},	//   _touq, _mе_, کیشی_, _рүеш, 
   {{0x2368008f,0xd1d402d3,0x0e8c05db,0x8c84035b}},	//   nkaj_, _ክህብ_, rịrị_, хәуа_, 
   {{0x1a6407d6,0xcad001f2,0x0e8c05db,0x3f8c01f7}},	//   عیتی_, _pịrị, sịrị_, mngu_, 
   {{0x3f8c009a,0x44e40139,0xadb401ee,0xa91c00d7}},	//   lngu_, _nе_, _абуш, tiľa, 
   {{0x3f8c00e8,0x00000000,0x00000000,0x00000000}},	//   ongu_, --, --, --, 
   {{0xd6d000c6,0x3f8ca945,0x23680115,0xdb4c0133}},	//   طقس_, nngu_, jkaj_, _چێژ_, 
   {{0x15b8049b,0x2b14ff88,0x485000cf,0xac800023}},	//   зывы_, _धातु_, _ەپىز, _ክንሶም_, 
   {{0x3f8c006a,0x03a002a9,0xdb08017a,0xd5b0007b}},	//   hngu_, ҳисо, kleë, افس_, 
   {{0xf899a7f9,0xb4d8012c,0x00000000,0x00000000}},	//   _بخشش_, ाडौ_, --, --, 
   {{0x53a5ed05,0x6440003a,0x3b1c031c,0x00000000}},	//   хабб, ælia, nfuq_, --, 
   {{0x86b00046,0x060400c7,0x9f440cad,0x00000000}},	// [37ca0] _бәрі, _знык_, _ìlù_, --, 
   {{0x7645ed06,0x6370369d,0x6fd42122,0xb78800fb}},	//   _iriy, _råne, _बंदू, _хәүе_, 
   {{0xc4800a89,0x3ddc52ec,0x2d80004e,0x764400cd}},	//   _блэк, _atuw_, èiem_, _hriy, 
   {{0x91e5ed07,0x764442ba,0x3f8c0083,0x236922b9}},	//   _поме, _kriy, gngu_, ckaj_, 
   {{0xa3bc0c2e,0x332124fb,0x4364064e,0xd1d40023}},	//   इगर_, mfix_, _чаян_, _ክህቦ_, 
   {{0x3f8ded08,0xfe040131,0xd1740137,0x7645ed09}},	//   angu_, رقىي_, _чымы, _mriy, 
   {{0xcfa813ea,0x8bc400a8,0x00000000,0x00000000}},	//   _فارم_, нсид, --, --, 
   {{0x7645ed0a,0x63700fac,0xabcc0150,0x00000000}},	//   _oriy, _tåne, _ﻗﯟﻋﺎ, --, 
   {{0x7f1401c8,0x0a68003b,0x00000000,0x00000000}},	//   _سيلز_, ярки_, --, --, 
   {{0xc278159d,0x236800d7,0xbec000ef,0x00000000}},	//   פריי, zkaj_, _žīgu, --, 
   {{0x7644d499,0xe89402d5,0x7ee000db,0xfce018cd}},	//   _ariy, тань, _شكەن, _сохо, 
   {{0x7645bc20,0x67280115,0xdee00023,0xa2d400cd}},	//   _briy, ĵejo, _ሓቦን_, युञ्, 
   {{0x764400f2,0x3d14007d,0x3494039b,0xc9840139}},	//   _criy, _नामे_, ҳарр, _пуки, 
   {{0x7645ed0b,0x6d580007,0x7954030d,0x00000000}},	//   _driy, njva, _пичĕ, --, 
   {{0x3321ed0c,0x7645ed0d,0x3494013e,0x91a4063f}},	//   ffix_, _eriy, гарр, ̣ọ_, 
   {{0x76445077,0x33210118,0x27f8022a,0x236802e2}},	//   _friy, gfix_, árnu_, ukaj_, 
   {{0x76453987,0x2368970c,0xc6a54dac,0x611403fb}},	// [37cb0] _griy, rkaj_, _ярки, кдау, 
   {{0x673ded0e,0x68e8003e,0xa2d400dc,0xb11400db}},	//   ldsj, nbdd, युज्, лмуш, 
   {{0x661c1d13,0x3ddc01f5,0xa0c401e0,0x764400b8}},	//   ltsk, _stuw_, тшаһ, _zriy, 
   {{0x30a5ed0f,0x644402c4,0x673ded10,0x661ded11}},	//   урув, _irhi, ndsj, otsk, 
   {{0x3f8c0194,0xf3640246,0x673c01a4,0x00000000}},	//   rngu_, _стэн, idsj, --, 
   {{0x63ad1d11,0x661ded12,0x00000000,0x00000000}},	//   llan, itsk, --, --, 
   {{0x63aded13,0x20d40010,0x661c78ec,0x00000000}},	//   olan, ržič_, htsk, --, 
   {{0x661c11ad,0xa2d41a2a,0x673c1455,0x00000000}},	//   ktsk, युच्, jdsj, --, 
   {{0x63ac447c,0x27e01505,0x661c05be,0x00000000}},	//   ilan, _čina_, jtsk, --, 
   {{0xdcf80f01,0x661c1347,0x673c000f,0x81e000cc}},	//   _آفات_, dtsk, edsj, _নটা_, 
   {{0x64440190,0x5b144132,0x7644020b,0x661c0575}},	//   _nrhi, _амет, _sriy, etsk, 
   {{0xefc0067d,0x63ac006c,0x7645ed14,0x661ded15}},	//   _ስለዚ_, jlan, _priy, ftsk, 
   {{0x6441ed16,0x661c037e,0x68e8003e,0x7bc8153a}},	//   ælin, gtsk, bbdd, _iigu, 
   {{0x7bc9ed17,0x673c000f,0x848c02d3,0x33200175}},	//   _higu, adsj, _ዘስምዕ_, wfix_, 
   {{0x63aded18,0x61fc1121,0x661ded19,0xd13017a5}},	//   flan, _avsl, atsk, یمر_, 
   {{0x63aded1a,0x7645ed1b,0xd370143e,0x7bc80139}},	//   glan, _triy, جهر_, _jigu, 
   {{0x7bc81410,0x76457cc4,0x64440730,0x33203873}},	// [37cc0] _migu, _uriy, _erhi, rfix_, 
   {{0x63aded1c,0xc2400209,0xa7fc0205,0x00000000}},	//   alan, шнук, kyıl, --, 
   {{0x64440055,0x7bc80254,0x8fd00ce8,0x6440007c}},	//   _grhi, _oigu, рәгә, ålit, 
   {{0x7bc9ed1d,0x63aded1e,0x0e641c3e,0x59d02052}},	//   _nigu, clan, ккен, सदार, 
   {{0x5274004e,0x9cb802dd,0x00000000,0x00000000}},	//   _руну, _ﺸﺭﻭﻋ, --, --, 
   {{0x7bc9ed1f,0xc0e12cb4,0x00000000,0x00000000}},	//   _aigu, _ворк, --, --, 
   {{0x63700267,0x673c03b2,0x00000000,0x00000000}},	//   _håna, ydsj, --, --, 
   {{0x7bc9ed20,0x661dc94e,0x6f000175,0x6d580fac}},	//   _cigu, ytsk, _udmc, sjva, 
   {{0x7bc85101,0x3b51ed21,0xbe400014,0x79f000c7}},	//   _digu, ркыр, _پھن٘, азых, 
   {{0x637033f3,0x7bc809cc,0x63aded22,0x661c09a8}},	//   _måna, _eigu, zlan, vtsk, 
   {{0xdb080209,0x63703953,0x3d142c33,0x0b580354}},	//   lmeý, _låna, _नाते_, _орды_, 
   {{0x661c933c,0x7bc9ed23,0x79800472,0x63aded24}},	//   ttsk, _gigu, _emnw, xlan, 
   {{0x63aded25,0x673ded26,0x2cac0042,0xdc30012d}},	//   vlan, rdsj, _hydd_, rżąc, 
   {{0x661c0bb8,0x7bc9ed27,0x63aded28,0x27fc00e3}},	//   rtsk, _zigu, wlan, _tvvn_, 
   {{0x661ded29,0x7bc9ed2a,0xa4f801d3,0x5ecc00fe}},	//   stsk, _yigu, وکھر_, াৰটে, 
   {{0x63aded2b,0x7bc802b9,0x2cac0142,0x0544009d}},	//   ulan, _xigu, _mydd_, хүүл_, 
   {{0x80d4032c,0xa7fc1918,0xa2b434b7,0xa1943a49}},	// [37cd0] _बलदे, zyıl, убач, гаач, 
   {{0x4070013e,0x6370007c,0x61e80205,0x00000000}},	//   ағгу, _dåna, _çelm, --, 
   {{0x31c4c260,0xceb4052f,0x2cac0042,0x31340212}},	//   рств, ғәт_, _nydd_, рехр, 
   {{0x63ad1811,0x61fded2c,0x2258005b,0x5f4401d5}},	//   qlan, _tvsl, _зимы_, طنتل, 
   {{0x7bc91038,0x3cfc0316,0xaf054012,0xdb08010e}},	//   _rigu, रणले_, рпіл, gmeý, 
   {{0x2cac0f7b,0x6db47d60,0x00000000,0x00000000}},	//   _bydd_, айчу, --, --, 
   {{0x41ac858c,0x8ea400f7,0x00000000,0x00000000}},	//   _जीएस, _ەلقۇ, --, --, 
   {{0x2cac0cfd,0x7bc8022e,0x06e000bc,0x00000000}},	//   _dydd_, _qigu, _क्लव_, --, 
   {{0x7bc9ed2d,0x0b40035b,0xcfdc00eb,0xa2a828fe}},	//   _vigu, снын, _ডিএন, _झुम्, 
   {{0x2cac0cfd,0x7bc8020b,0x57e9ed2e,0x00000000}},	//   _fydd_, _wigu, ндом_, --, 
   {{0x7bc9ed2f,0x1869ed30,0x98a4054e,0x64400162}},	//   _tigu, хани_, delă_, ælil, 
   {{0x55e455da,0x7bc8013c,0xab84de05,0x5918025c}},	//   ломб, _uigu, _кучк, ྱུངས_, 
   {{0xda6400ec,0x95980114,0x00000000,0x00000000}},	//   _ڄاڻي, етву_, --, --, 
   {{0x9a800201,0x6370049f,0x798001e2,0x69640c75}},	//   _ይሆናል_, _råna, _umnw, _ندىق, 
   {{0x637000cc,0x0ac40022,0x61e8036e,0xccf0011a}},	//   _såna, _ишәҭ, _çelj, מכם_, 
   {{0x6b5800a2,0x17b000cc,0x00000000,0x00000000}},	//   _iºgä, _ঘূৰি, --, --, 
   {{0x69cc00c5,0x63c401e0,0x98a40356,0xdb080254}},	// [37ce0] _üleü, ратҡ, belă_, dmeü, 
   {{0x6618012d,0x00000000,0x00000000,0x00000000}},	//   żakó, --, --, --, 
   {{0x4f09ed31,0xe1f000d1,0x20d400d4,0xa7fc0205}},	//   енен_, مسە_, ріус, yyım, 
   {{0x2caded32,0x4ed00154,0x6370007c,0x00000000}},	//   _rydd_, ার্ল, _tåna, --, 
   {{0x2cac0f7b,0x3fc8036b,0x00000000,0x00000000}},	//   _sydd_, ردمی_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x637001e3,0x291800a3,0xf1d81be1,0x2ca00205}},	//   _månn, òram_, _भूतन, ğido_, 
   {{0x40900491,0x8fa5ed33,0x2ec5ed34,0x92d403d4}},	//   _الفر, _сабе, _көлм, হৰৰ_, 
   {{0x2cac0042,0x00000000,0x00000000,0x00000000}},	//   _wydd_, --, --, --, 
   {{0x29181570,0x2cac0158,0xaac074c8,0x00000000}},	//   üra_, _tydd_, शेषक, --, 
   {{0xba70249f,0xdb08067c,0x98a4054e,0x00000000}},	//   لایت, cleï, velă_, --, 
   {{0x68e40259,0x6b5c01d3,0x64400162,0x6f0400c7}},	//   _şidd, _légz, ælim, óich, 
   {{0xb8c98502,0xd92805f5,0xdecc0023,0x98a40356}},	//   _कु_, хцөл_, _ኢድና_, telă_, 
   {{0x2638002e,0x6474141c,0x00000000,0x00000000}},	//   _fόon_, аггу, --, --, 
   {{0x76480882,0x3d14000d,0x356800ee,0x320c00b8}},	//   ādya, _नासे_, урян_, _ādya_, 
   {{0xdb18007f,0xdb200030,0xf31401c0,0x443c0115}},	//   _chwè, _štúr, йдсэ, ĉu_, 
   {{0xb71400cf,0x98a40356,0x20400092,0x82341888}},	// [37cf0] _ابىش, pelă_, _የሚመር, درزا, 
   {{0x83f4013f,0xa2a8074f,0x6fcc01ec,0x00000000}},	//   ɑɑno, _झुण्, _ﺑﺎﺭﺷ, --, 
   {{0xf4842d7f,0x1fc40107,0x00000000,0x00000000}},	//   _гуян, ардҳ, --, --, 
   {{0xc43000e5,0x00000000,0x00000000,0x00000000}},	//   _پکڑت, --, --, --, 
   {{0x12f8011a,0xdb08002f,0xa7fc03e0,0x00000000}},	//   _בהרב, rmeü, rzıy, --, 
   {{0xdce00115,0x2d58084c,0x9d440209,0x00000000}},	//   _kolĉ, личь_, рекд, --, 
   {{0x9f340816,0xefc00240,0x00000000,0x00000000}},	//   _кеві, _ድለዩ_, --, --, 
   {{0xdb1800d2,0x3d140490,0x1a0400f0,0x1e5000e5}},	//   _khwé, _नावे_, апим, _وہاڑ, 
   {{0x637000cc,0xdea0036b,0x1c2000af,0x4af40ee8}},	//   _låno, _بیشی, _महकल_, شکند_, 
   {{0x58240117,0xd82401f4,0x00000000,0x00000000}},	//   амоб, адои, --, --, 
   {{0x80b0009e,0x7a480208,0x6b5c01d3,0x7e6801e3}},	//   জশক্, _bêtô, _légy, lygp, 
   {{0x6370ae44,0x85400153,0x00000000,0x00000000}},	//   _sånn, žėli, --, --, 
   {{0x7af9ed35,0x7e6802fa,0x6b5c01ed,0x6d5c00a3}},	//   maut, nygp, _négy, _òrac, 
   {{0x7af9ed36,0x05a4084c,0xdb08002e,0xc27001e1}},	//   laut, ивяй_, mmeñ, _ọ̀yá, 
   {{0x6b5c020c,0x7af80353,0x00000000,0x00000000}},	//   _aégy, oaut, --, --, 
   {{0x7af9ed37,0xdce0008f,0xfbd400fe,0x98a40064}},	//   naut, _dolĉ, _সবাত, gelą_, 
   {{0xd1841896,0xc240013d,0x057408dc,0x7af8f272}},	// [37d00] алай, онтк, _چاپد, iaut, 
   {{0x7af9ed38,0x31b4025a,0x7764005a,0xc5f8008f}},	//   haut, räzo_, _hoix, _שפיט, 
   {{0x7af9ed39,0x6b5c00dd,0x629c16b8,0x8d84158b}},	//   kaut, _végz, _exso, یشتن, 
   {{0x7af9ed3a,0x1ea846bc,0xd3700244,0x00000000}},	//   jaut, گامي_, _بێرک, --, 
   {{0x7765ed3b,0x60c8010f,0x6370007c,0x3dcc00fe}},	//   _moix, _ĝeme, _månl, _ৰিজল, 
   {{0xdde9ed3c,0x7af87da5,0x60c80115,0x1ea806c2}},	//   ارنه_, eaut, _ŝeme, دامي_, 
   {{0x7af8c9ad,0x998c068f,0x61e8025c,0x3d14012d}},	//   faut, steś_, _ħeli, _नारे_, 
   {{0x7af9ed3d,0x2fd80076,0xcde402e8,0x00000000}},	//   gaut, _iurg_, _воай, --, 
   {{0x3200036b,0x0dc8dfe6,0x3f64147e,0x729c0023}},	//   nsiy_, _алай_, _тито_, _ዉድባዊ_, 
   {{0xd90cb167,0xa2b800dc,0xaa940131,0x2fd9ed3e}},	//   فیه_, ्धत्, _қилч, _kurg_, 
   {{0x7af8601a,0x776400cf,0x38300276,0x2fd8017a}},	//   baut, _boix, онэр, _jurg_, 
   {{0x7af9ed3f,0x77652ed2,0x2fd9ed40,0xa8140116}},	//   caut, _coix, _murg_, _ғдиш, 
   {{0x2fd80731,0x32000113,0x86240166,0x00000000}},	//   _lurg_, jsiy_, шьне, --, 
   {{0x61e9b92e,0x2419ed41,0xe8180276,0xda640691}},	//   _çeli, логы_, _бокч_, _دامي, 
   {{0x63bc009a,0x7764004e,0x999801f1,0x00000000}},	//   _phsn, _foix, ísť_, --, 
   {{0xc76404a9,0x68f9d57f,0x7764005a,0x2e20007f}},	//   _خاتى, _hevd, _goix, kòf_, 
   {{0x3d14134e,0x00000000,0x00000000,0x00000000}},	// [37d10] _नाले_, --, --, --, 
   {{0x2fd9ed42,0xcfdc02f5,0x68f9ed43,0x7764005a}},	//   _burg_, _ডিজন, _jevd, _zoix, 
   {{0x7af9ed44,0x68f83923,0x2fd8054e,0x92d400fe}},	//   yaut, _mevd, _curg_, হৰে_, 
   {{0x6565ed45,0x68f9057f,0xa2940d30,0x998c0419}},	//   _hohh, _levd, _гамі, areň_, 
   {{0x7af9ed46,0x1d092f24,0x61e80135,0x932401f7}},	//   vaut, гели_, _ħelw, _ارپن, 
   {{0x2fd800d8,0x5918031c,0x68f9ed47,0x65640254}},	//   _furg_, ྱུབས_, _nevd, _johh, 
   {{0x70943500,0x91c0723c,0x7058040e,0x6565ed48}},	//   _дарф, _хәтл, _карр_, _mohh, 
   {{0x2001ed49,0x65640167,0x8ce40e26,0xdd90dc89}},	//   mshi_, _lohh, لقۇۇ, _کوئ_, 
   {{0x7af9ed4a,0x65640280,0x68f80165,0x6370007c}},	//   raut, _oohh, _bevd, _rånl, 
   {{0x7af9ed4b,0x7765ed4c,0x6564014f,0xd9381f87}},	//   saut, _soix, _nohh, учиш_, 
   {{0x2000633d,0x9cb47251,0x7af9ed4d,0x98a4ec38}},	//   nshi_, _امات, paut, сине, 
   {{0x20017251,0x7af80d04,0x2638002e,0x320001a9}},	//   ishi_, qaut, _tόol_, ysiy_, 
   {{0xd94409a5,0x3200036b,0x2001ed4e,0x68f80010}},	//   _гели, xsiy_, hshi_, _fevd, 
   {{0x200120cc,0xdb0801ab,0xdcb00208,0x320001a9}},	//   kshi_, lleà, _kỷ_, vsiy_, 
   {{0x464400c7,0x2e2002e2,0x2000036e,0x00000000}},	//   _ҳзын_, zòf_, jshi_, --, 
   {{0xe3b03306,0x2000022e,0x320001a9,0xc2000037}},	//   ِرْ_, dshi_, tsiy_, _लिखब_, 
   {{0x68f80477,0x2fd915c4,0x40340092,0x2001ed4f}},	// [37d20] _yevd, _surg_, _ከሚገኙ, eshi_, 
   {{0x86580302,0x3200036b,0x20000240,0x50b801f7}},	//   _עדיי, rsiy_, fshi_, هداد_, 
   {{0xc324425b,0xd4680724,0x53a405f5,0x2fd801d5}},	//   شكەن_, _сине_, _ганб, _qurg_, 
   {{0xd498035b,0xc7d40375,0xbf10007b,0x2e20007f}},	//   _арҭ_, צוני_, كومب, tòf_, 
   {{0x471804ac,0x2fd80af9,0x6564037e,0x320002d1}},	//   רונג, _wurg_, _yohh, qsiy_, 
   {{0x2001ed50,0x2fd9ed51,0x2e2002e2,0x4638010f}},	//   bshi_, _turg_, ròf_, טענע, 
   {{0x68f9ed52,0x2e20180f,0x8fa401d5,0xdb1801e1}},	//   _revd, sòf_, _همآه, _niwó, 
   {{0x68f9ed53,0x6440003a,0x00000000,0x00000000}},	//   _sevd, ælii, --, --, 
   {{0x70b800bc,0xbc0800db,0x98a40246,0x00000000}},	//   _अरुल, _ۅرنۅ_, djlı_, --, 
   {{0x98a400c0,0x00000000,0x00000000,0x00000000}},	//   lelę_, --, --, --, 
   {{0x68f805ac,0x63a8003d,0x00000000,0x00000000}},	//   _vevd, ċenz, --, --, 
   {{0x656400f3,0x98a40153,0x00000000,0x00000000}},	//   _sohh, nelę_, --, --, 
   {{0x0ab410e5,0x68f86044,0x37a801c6,0x02a42d6b}},	//   _احاد, _tevd, стэн_, _कुंभ, 
   {{0x2000caf5,0xf7700131,0xa2b800dc,0x70b800bc}},	//   yshi_, _ۋاي_, ्धस्, _अरूल, 
   {{0x2000006c,0x2b44003e,0xdb0800ae,0x98a400c0}},	//   xshi_, odmc_, lleá, kelę_, 
   {{0x8bf80183,0x65640085,0x02a0063f,0xf3641a5c}},	//   _ইমান_, _wohh, swọọ, птун, 
   {{0x98a40024,0x672c0ca8,0x60f98b08,0x65640254}},	// [37d30] delę_, _ibaj, иная_, _tohh, 
   {{0x2001ed54,0xdb18007f,0x6370007c,0xdb0800ae}},	//   tshi_, _jiwò, _kånk, ileá, 
   {{0x9ed80276,0x245801c0,0x2034fc68,0x99dc00d0}},	//   амет_, _тань_, تفاس, yvňo, 
   {{0x2001ed55,0x6370007c,0xdb080646,0x00000000}},	//   rshi_, _månk, kleá, --, 
   {{0x672c044e,0x2000037e,0x787c01ed,0x637003cd}},	//   _mbaj, sshi_, _kávé, _lånk, 
   {{0x1be84f13,0x2001ed56,0x272c022e,0xc0c80798}},	//   адки_, pshi_, hоn_, _бубе_, 
   {{0x672ded57,0xdde802f2,0x272c022e,0x2000022e}},	//   _obaj, ارچه_, kоn_, qshi_, 
   {{0xdb180428,0x99e4023a,0x672c0327,0x6d5c01c3}},	//   _aiwò, ожид, _nbaj, _òran, 
   {{0x61eded58,0xdce000bc,0xae7401ed,0x224801a4}},	//   npal, _holč, _ٹھنڈ, nvak_, 
   {{0x672ded59,0x3f8ded5a,0x61ec427f,0xdcb00208}},	//   _abaj, ligu_, ipal, _tỷ_, 
   {{0xdce0007f,0xdb0804cc,0x2ee40175,0x61ec6f35}},	//   _jolč, pleà, _yfmf_, hpal, 
   {{0x3f8ded5b,0xdce00219,0x224801f5,0xec680137}},	//   nigu_, _molč, kvak_, _урук_, 
   {{0x61eded5c,0x96b80137,0x224801f5,0x672c16d7}},	//   jpal, руну_, jvak_, _dbaj, 
   {{0x61eded5d,0x22480af9,0x672d5fea,0x3f8ded5e}},	//   dpal, dvak_, _ebaj, higu_, 
   {{0x3f8ded5f,0x9344026b,0x00000000,0x00000000}},	//   kigu_, онве, --, --, 
   {{0x3f8c1326,0x672ccafd,0x2248017a,0x07e402f2}},	//   jigu_, _gbaj, fvak_, _بزوێ, 
   {{0x27e004b9,0x61ec417f,0x2ee40333,0xb144001f}},	// [37d40] _čini_, gpal, _rfmf_, _የማይታ, 
   {{0x60c80115,0x2ca04283,0x3f8c032e,0x53c40150}},	//   _ŝema, şidi_, eigu_, сағұ, 
   {{0xcf44046e,0x61ec427f,0x98a40153,0x3f8c0009}},	//   жней, apal, telę_, figu_, 
   {{0x61ec1901,0xdce00e04,0x3f8c0083,0x672c031c}},	//   bpal, _dolč, gigu_, _xbaj, 
   {{0x61ec0561,0x2cb801a6,0x91e4030d,0x63a001d3}},	//   cpal, _šrd_, _фоге, élne, 
   {{0x63a83896,0xa2b80882,0xcbe43252,0x9e64007b}},	//   čene, ्धर्, оции, ثامن, 
   {{0xc0f0044e,0x3f8c01d9,0xdce00331,0xd478008f}},	//   ልኩም_, bigu_, _golč, יאַל, 
   {{0xdb08007b,0xc4d000d9,0xdcac0137,0x00000000}},	//   tleá, וגו_, دۉم_, --, 
   {{0x61e800fd,0xfbcc0769,0x00000000,0x00000000}},	//   _çelt, ختو_, --, --, 
   {{0xdb180142,0x00000000,0x00000000,0x00000000}},	//   _chwâ, --, --, --, 
   {{0x61eded60,0xdb08007b,0xc7b8005b,0x2cb800ae}},	//   zpal, sleá, иём_, _árd_, 
   {{0x61eded61,0x4789ed62,0xdb08498d,0x00000000}},	//   ypal, рсом_, pleá, --, 
   {{0x2d8c0205,0x272c022e,0x00000000,0x00000000}},	//   _kmde_, rоn_, --, --, 
   {{0x3f8cd99d,0xa4e40073,0x272c022e,0x00000000}},	//   zigu_, कडेच_, sоn_, --, 
   {{0xb9c09448,0x672c025c,0x69c9a56d,0x224801f5}},	//   _تقوي, _tbaj, mmde, wvak_, 
   {{0x61eded63,0x2d8c026c,0x672ce64b,0x69c803e0}},	//   tpal, _lmde_, _ubaj, lmde, 
   {{0x61eded64,0x2d8c0472,0xdce1ed65,0x69c801f5}},	// [37d50] upal, _omde_, _solč, omde, 
   {{0x61eded66,0x22480158,0x463802d3,0xdce13ec2}},	//   rpal, rvak_, ራተጂካ, _polč, 
   {{0x8005640a,0x3f8ded67,0x613002d2,0x635400f3}},	//   ючае, tigu_, _aðlæ, _евну, 
   {{0x61eded68,0x6440437d,0xdce00219,0x389808a8}},	//   ppal, æliu, _volč, סיאנ, 
   {{0x63aded69,0x61ec0357,0xf77400d9,0xdb0800a2}},	//   moan, qpal, וקף_, lleç, 
   {{0x63aded6a,0x11d80375,0xdce00427,0x3f8ded6b}},	//   loan, _לחשב, _tolč, sigu_, 
   {{0x44300076,0x69c80118,0xdc6801c4,0x757c010f}},	//   _jpx_, dmde, сайд_, שטופ, 
   {{0x63aded6c,0x69c81af3,0x61e9ed6d,0x3d142208}},	//   noan, emde, _çels, _नाके_, 
   {{0xdb180784,0x63ac0311,0x44300166,0x00000000}},	//   _qiwñ, ioan, _lpx_, --, 
   {{0x63aded6e,0xceb0010f,0xa3ac0073,0xec68013d}},	//   hoan, _טין_, गवड_, срәк_, 
   {{0x63aded6f,0xa3bc2007,0x4430070d,0x00000000}},	//   koan, ेगा_, _npx_, --, 
   {{0x63aded70,0x69c8002d,0x63700267,0x4cb8011a}},	//   joan, amde, _fåni, _המעג, 
   {{0x63aded71,0x4430dc66,0xc994004b,0xa3d4000d}},	//   doan, _apx_, _کانګ, िआई_, 
   {{0x44300175,0x95980116,0xd46804b3,0x00000000}},	//   _bpx_, стму_, биге_, --, 
   {{0x63aded72,0x9878008f,0x862001d5,0x00000000}},	//   foan, _לאַט, وکیل, --, 
   {{0x63aded73,0x2334013e,0x00000000,0x00000000}},	//   goan, мхур, --, --, 
   {{0x291800a3,0x66c8022e,0x00000000,0x00000000}},	// [37d60] órag_, rоkc, --, --, 
   {{0xdb080254,0x2f2c00b8,0x00000000,0x00000000}},	//   lleä, _ṛg_, --, --, 
   {{0x3ebc07ab,0x63aded74,0x00e4036b,0xb4d80d79}},	//   _azut_, boan, ستلی, िशी_, 
   {{0x63a9ed75,0x63aded76,0x53a4f7bd,0x3fc803c7}},	//   čenc, coan, _хамб, مدنی_, 
   {{0x69c80368,0x00000000,0x00000000,0x00000000}},	//   ymde, --, --, --, 
   {{0x443003b9,0x00000000,0x00000000,0x00000000}},	//   _ypx_, --, --, --, 
   {{0x6d5c0086,0xdcac0372,0x637001bf,0x0b880395}},	//   _òram, لۉك_, _såni, йсии_, 
   {{0xaa5402e8,0x6204010e,0x00000000,0x00000000}},	//   двиш, _ätlä, --, --, 
   {{0xc330025f,0x0d85ed77,0xa3ac47b8,0x69c800d4}},	//   תוח_, _елан, गवत_, tmde, 
   {{0x63aded78,0x6371ed79,0xbe300046,0x69c80112}},	//   zoan, _våni, _سىمب, umde, 
   {{0x63ac0451,0x69c801a4,0x27f84bc2,0x1fb40354}},	//   yoan, rmde, èrn_, _асăр, 
   {{0xe6941de1,0x4424003a,0x98b80137,0x40b8010f}},	//   димы, _īn_, өлөт_, מזיס, 
   {{0x63ac0170,0x2be400bd,0x27e0245e,0x3b600014}},	//   voan, _গিয়ে_, _činu_, _سُوِ, 
   {{0xa2cc3af4,0x63aded7a,0xdce03da0,0xdb080205}},	//   _दृष्, woan, _kolā, tleç, 
   {{0x63aded7b,0x60c80115,0x74a400d8,0x00000000}},	//   toan, _ĝemo, ејте, --, 
   {{0x443000d8,0xb5c80014,0xb89800d9,0x00000000}},	//   _vpx_, ٲوہم_, _לבוש, --, 
   {{0xa2cc07b6,0x63aded7c,0xf31401c0,0xdde400b0}},	// [37d70] _दृश्, roan, эдтэ, āpūw, 
   {{0x63aded7d,0x6440041e,0x3ebc012d,0xb3740092}},	//   soan, ælis, _rzut_, _የወይን_, 
   {{0x4425ed7e,0xf1c80597,0x63aded7f,0x7094023b}},	//   _ën_, أولى_, poan, нафф, 
   {{0x27f803f7,0xf484030d,0x33d40064,0xfc4400d7}},	//   árny_, _чуьн, _піўт, žíky_, 
   {{0x32540006,0x9d447bf7,0x00000000,0x00000000}},	//   _звяр, делд, --, --, 
   {{0xdd91ed80,0xee380212,0x361c0375,0x00000000}},	//   ضوع_, яні_, מודד, --, 
   {{0x8c401de1,0xdbf000bc,0x00000000,0x00000000}},	//   веще, příj, --, --, 
   {{0x3f9c022f,0xdce0005f,0x00000000,0x00000000}},	//   _ujuu_, _dolā, --, --, 
   {{0xef1800c6,0x4aa4004e,0x00000000,0x00000000}},	//   _ѕмѕ_, мкън_, --, --, 
   {{0xdc3000d7,0x00000000,0x00000000,0x00000000}},	//   mýľt, --, --, --, 
   {{0x7d01ed81,0xa3ac34f8,0xdce000b8,0xed04211f}},	//   mans, गवा_, _golā, _سونپ, 
   {{0x291800a3,0xd7c9d8db,0x00000000,0x00000000}},	//   òrar_, توجه_, --, --, 
   {{0x5c7401af,0x00000000,0x00000000,0x00000000}},	//   _хәҙр_, --, --, --, 
   {{0xdd98007f,0x89d808a8,0xe00ce60e,0x61e80327}},	//   _dwňg_, _וחסי, _हिंद_, _ħelp, 
   {{0x39440b1d,0x80d002f5,0x00000000,0x00000000}},	//   _ians_, দুত্, --, --, 
   {{0x39445bd2,0x7d01ed82,0x527400cf,0xdbd800a2}},	//   _hans_, hans, музу, mçän, 
   {{0x39457eea,0xd4f4ca0f,0xe72800ec,0x64400162}},	// [37d80] _kans_, _ояны, _رسيو_, ælir, 
   {{0x39444fa5,0x7645ed83,0x1de00c2e,0x6265ed84}},	//   _jans_, _isiy, _पढ़त, راقق, 
   {{0x3945ed85,0x7d01ed86,0x753ded87,0x9405845d}},	//   _mans_, dans, merz, _توجه, 
   {{0x3944382f,0x357c1ee0,0x753dd5ad,0x7d00111b}},	//   _lans_, _ጥምቀት_, lerz, eans, 
   {{0x7d01ed88,0xdce000e2,0x2d5800c7,0x94740133}},	//   fans, _solā, зиль_, _ردگا, 
   {{0x753ded89,0x241474bb,0x3945ed8a,0x764401f7}},	//   nerz, _íæãí, _nans_, _msiy, 
   {{0x8bc5cacb,0x753c01c7,0x00000000,0x00000000}},	//   мсид, ierz, --, --, 
   {{0x753ded8b,0x7645ed8c,0xdef8002e,0xdd98007f}},	//   herz, _osiy, _boŋu_, _awňd_, 
   {{0x753ded8d,0xbf1000cf,0x7645ed8e,0x39440f85}},	//   kerz, _جوقب, _nsiy, _bans_, 
   {{0x39443d19,0x6f002ca8,0x1ea8007b,0xdb08007c}},	//   _cans_, _hemc, _راقي_, vleå, 
   {{0x3945ed8f,0x753ded90,0x6f000432,0x51c80220}},	//   _dans_, derz, _kemc, _ﺑﻮﻟﺸ, 
   {{0x6d49ed91,0xabd41c5c,0x55e8015b,0x6f000332}},	//   _hada, _ﺟﺎﻣﺎ, _কয়েক_, _jemc, 
   {{0x6f01ed92,0x753c0730,0x7b840150,0x6370007c}},	//   _memc, ferz, _تالە, _månt, 
   {{0x3945ed93,0x753c9aff,0x6f002959,0x63700b1a}},	//   _gans_, gerz, _lemc, _lånt, 
   {{0x76440928,0x6d498d44,0x69d9ed94,0x68e80175}},	//   _esiy, _mada, _iive, mcdd, 
   {{0x69d9ed95,0x7d006ca0,0x6f01ed96,0x257c0ffb}},	//   _hive, zans, _nemc, _dìla_, 
   {{0x69d9ed97,0x6d49ed98,0x753ded99,0x673c00cc}},	// [37d90] _kive, _oada, berz, mesj, 
   {{0x7d01ed9a,0x69d8a057,0x3944022e,0x753ded9b}},	//   xans, _jive, _xans_, cerz, 
   {{0x69d9ed9c,0x6f003917,0x7d01ed9d,0xa3d582a7}},	//   _mive, _bemc, vans, _пооч, 
   {{0x6445ed9e,0x7d01ed9f,0x6d49eda0,0x6f000205}},	//   _ishi, wans, _aada, _cemc, 
   {{0x6d49eda1,0xdd95eda2,0x2f140241,0x152000fe}},	//   _bada, нады, _súgà_, য়ৰী_, 
   {{0x6d49eda3,0xceb5b653,0x6f00035a,0x673c0158}},	//   _cada, хәс_, _eemc, hesj, 
   {{0x6d49eda4,0x7d01eda5,0x673deda6,0x3945eda7}},	//   _dada, rans, kesj, _rans_, 
   {{0x7d01eda8,0x661deda9,0x6445edaa,0x6d480876}},	//   sans, kusk, _mshi, _eada, 
   {{0x39440585,0x6d49edab,0x7d01edac,0x69d9edad}},	//   _pans_, _fada, pans, _bive, 
   {{0x6445edae,0x69d9edaf,0x661dedb0,0x7d01edb1}},	//   _oshi, _cive, dusk, qans, 
   {{0x7b6480df,0x64440537,0x673dedb2,0x6f00003c}},	//   _отде, _nshi, fesj, _yemc, 
   {{0x753dedb3,0x673dedb4,0x70dc38d2,0x39440221}},	//   werz, gesj, _बल्ल, _wans_, 
   {{0x6445edb5,0x753dedb6,0x69d9edb7,0x6d49edb8}},	//   _ashi, terz, _five, _yada, 
   {{0x69d9edb9,0x18a5edba,0x98a46b80,0x6d48292a}},	//   _give, _палм, _пиле, _xada, 
   {{0x753dedbb,0x7f580086,0x637001e6,0x61fc127b}},	//   rerz, _onuq, _nåns, _awsl, 
   {{0x753c0801,0x661dedbc,0x7645edbd,0x11d800c6}},	//   serz, busk, _tsiy, كورة_, 
   {{0x7f48074d,0x6445431a,0x6f00282c,0x661db415}},	// [37da0] ddgq, _eshi, _remc, cusk, 
   {{0x7f580227,0x6f002959,0x644402d3,0x6370050a}},	//   _anuq, _semc, _fshi, _båns, 
   {{0x6d482f86,0x61fc0857,0x6d5dedbe,0x00000000}},	//   _rada, _ewsl, _òrai, --, 
   {{0x6d49edbf,0x6f000455,0xb35801ed,0x61fc0042}},	//   _sada, _qemc, _تیرا_, _fwsl, 
   {{0x6f00014f,0x3f840240,0xa3ac0073,0x912800cf}},	//   _vemc, ënua_, गवर_, _ىسسق_, 
   {{0x6d49edc0,0xd00842c6,0x6f01abc0,0x7f58047e}},	//   _qada, _неге_, _wemc, _enuq, 
   {{0x6d49edc1,0x69d9edc2,0x6f01edc3,0x6444037e}},	//   _vada, _rive, _temc, _xshi, 
   {{0x6d49edc4,0x69d9edc5,0xa91c00d0,0x661c022e}},	//   _wada, _sive, dhľa, yusk, 
   {{0x6d49edc6,0xbea00372,0x673c09a8,0x3ea072a0}},	//   _tada, _батк, vesj, _битг, 
   {{0x6d481cdf,0xd90c3028,0xf8a8001e,0x69d80194}},	//   _uada, قیه_, ười_, _qive, 
   {{0x673dedc7,0x0ae8009f,0x00000000,0x00000000}},	//   tesj, _فرشي_, --, --, 
   {{0x661dedc8,0x69d898dc,0xdce00356,0xcaf4007b}},	//   tusk, _wive, _tolă, _أساب, 
   {{0x69d9edc9,0x9b882f84,0x2c7401ed,0xdb24036b}},	//   _tive, _تخلف_, _سیکھ_, _شووی, 
   {{0x661c3aad,0x69d8013c,0x092805d9,0x27100208}},	//   rusk, _uive, _رستي_, ễn_, 
   {{0xf4841fe2,0xf4340006,0x03c4bf77,0x3cf0482a}},	//   гутн, лерэ, есам, ुरते_, 
   {{0x63a807f5,0x661dedca,0xc7641a59,0x673c0455}},	//   čeno, pusk, _سابى, qesj, 
   {{0x64440810,0xdb080332,0x00000000,0x00000000}},	// [37db0] _wshi, tleú, --, --, 
   {{0x6445edcb,0x660c493b,0x06c4009e,0x00000000}},	//   _tshi, _ivak, _এলপি, --, 
   {{0x212005b1,0x660c03b2,0x00000000,0x00000000}},	//   rghh_, _hvak, --, --, 
   {{0xdea01056,0x224c00ef,0x00000000,0x00000000}},	//   لیزی, _šeku_, --, --, 
   {{0x61fc0014,0xb2741b04,0x2368047e,0x4174075e}},	//   _uwsl, _бляш, mjaj_, _كاسس, 
   {{0x23695b35,0x660c009a,0xdb0801bf,0xa91c0419}},	//   ljaj_, _mvak, lleø, yhľa, 
   {{0xbe800131,0x00000000,0x00000000,0x00000000}},	//   _әқли, --, --, --, 
   {{0x660c1326,0xd9c808dd,0x7f48074d,0x2369edcc}},	//   _ovak, रष्ट, qdgq, njaj_, 
   {{0x99dc0030,0xce500014,0x660c0055,0x7b04002b}},	//   yvňu, _پھنب, _nvak, _āstī, 
   {{0x69a40032,0x23680842,0x99d4007b,0xf1cc02dd}},	//   ллыҡ, hjaj_, ختبا, _ﺒﺎﻟﻘ, 
   {{0x660dedcd,0x45240729,0x98a5edce,0x18a40121}},	//   _avak, য়াক_, тине, танм, 
   {{0x660c0a28,0x2368016d,0x00000000,0x00000000}},	//   _bvak, jjaj_, --, --, 
   {{0x2369edcf,0x07a1edd0,0x660c0306,0xd9440139}},	//   djaj_, раян, _cvak, _аели, 
   {{0x26c4c5dc,0x660c389e,0xd7c805d9,0x5bd001f9}},	//   ығын_, _dvak, _ڪوبه_, _हळुव, 
   {{0x5fd061ef,0x00000000,0x00000000,0x00000000}},	//   तगाल, --, --, --, 
   {{0xd7c9b89e,0x00000000,0x00000000,0x00000000}},	//   _توبه_, --, --, --, 
   {{0x46440124,0xddc8030a,0x2638002e,0x248c00df}},	// [37dc0] _азын_, _kreń, _wόor_, ĝema_, 
   {{0x50d400be,0x248c01e4,0x6608031c,0x00000000}},	//   نزار, ŝema_, ġekt, --, 
   {{0x660d2ef9,0xd02400ee,0x2368047e,0x00000000}},	//   _zvak, тмей, bjaj_, --, 
   {{0x660c00c7,0x00000000,0x00000000,0x00000000}},	//   _yvak, --, --, --, 
   {{0x80d0015b,0x8d84010b,0x43644164,0x3f1000d4}},	//   দুল্, кукд, _раян_, рдіс, 
   {{0x98a406c8,0xd1743947,0x00000000,0x00000000}},	//   nelē_, _рымы, --, --, 
   {{0x50c41715,0xab940212,0x4e0c012c,0xcfa800db}},	//   _वरिष, ликі, _ठिकै_, _قارم_, 
   {{0xdc5401e2,0x35b40210,0x00000000,0x00000000}},	//   اروک, ंकड़, --, --, 
   {{0x98a40069,0xa9281b56,0x60c80115,0xc0cc001f}},	//   kelē_, ىزدە_, _ĝemi, ባይል_, 
   {{0xa3c800e1,0x660c0166,0x00000000,0x00000000}},	//   _लीन_, _rvak, --, --, 
   {{0x660c1326,0xcad002e3,0xddc80165,0xbb440345}},	//   _svak, _gịnị, _dreń, رلین_, 
   {{0xd2680150,0x00000000,0x00000000,0x00000000}},	//   лiмш, --, --, --, 
   {{0x99646240,0xa935edd1,0x2368016d,0xf98c136e}},	//   ттөл, _белш, vjaj_, صبی_, 
   {{0xe85474bb,0x660c0270,0xdb100008,0xe4b80220}},	//   _منتد, _vvak, ðgön, елгі_, 
   {{0x99dc0100,0x2368047e,0x00000000,0x00000000}},	//   pwňc, tjaj_, --, --, 
   {{0x4de002e5,0x660c002b,0x6d5c02d2,0x00000000}},	//   खदाई_, _tvak, _óraf, --, 
   {{0x2369edd2,0x660c2939,0xdee40aac,0x443dedd3}},	// [37dd0] rjaj_, _uvak, қоли, ňu_, 
   {{0x224c107d,0xfe700214,0x2368016d,0x00000000}},	//   _šeks_, یدش_, sjaj_, --, 
   {{0x2368047e,0x1168872f,0xb3740240,0x00000000}},	//   pjaj_, علمی_, _የለዉን_, --, 
   {{0x54780a1e,0x2368016d,0xdca400d1,0xef540022}},	//   _נטרו, qjaj_, һали, икхь, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdca418f4,0xa194014b,0x00000000,0x00000000}},	//   лали, _сагч, --, --, 
   {{0xf0440276,0x5bb410fc,0x50a400fb,0x84e8012d}},	//   _кэто, лсиф, _бутҡ, जुएट_, 
   {{0x29182880,0x18a401ec,0x77a803e3,0x00000000}},	//   óran_, ғамм, kıxa, --, 
   {{0x5974064e,0xab6800ef,0x00000000,0x00000000}},	//   гыну, duļķ, --, --, 
   {{0xfaa046ee,0xd9440063,0x00000000,0x00000000}},	//   лақо, ћени, --, --, 
   {{0x1bf400c0,0x00000000,0x00000000,0x00000000}},	//   _спеў, --, --, --, 
   {{0x0e8c01f2,0xeb7402d5,0xabd40150,0xab7c0408}},	//   kịlị_, _вышэ, _ﺟﺎﻳﺎ, _овхi, 
   {{0x98a40618,0xa91c0419,0x00000000,0x00000000}},	//   telē_, chľo, --, --, 
   {{0xceb00d65,0x7af975ef,0x4a9800c8,0x00000000}},	//   צים_, lbut, _אינג, --, 
   {{0xe9b8121e,0x3ce81be1,0xdce00055,0x7af804ba}},	//   _جنوں_, _चलने_, _allī, obut, 
   {{0x7af9edd4,0xd3c41473,0x00000000,0x00000000}},	//   nbut, اتسى, --, --, 
   {{0x0e8c063f,0x660804a7,0x7af9edd5,0x52a80395}},	// [37de0] gịlị_, šekr, ibut, хвам_, 
   {{0x7af82076,0x6fec0213,0x068007ee,0xb3e80117}},	//   hbut, _ağca, _ыгын, _илоҷ_, 
   {{0x7bc800b5,0x8f7401ec,0xdce000ef,0xddc80171}},	//   _ohgu, луді, _ellī, _kreņ, 
   {{0x205443e8,0x7af8151c,0x4364010b,0x79800175}},	//   штур, jbut, _баюн_, _llnw, 
   {{0x5274049e,0x7af9edd6,0xbea00500,0x00000000}},	//   _суну, dbut, бацк, --, 
   {{0xc0e1edd7,0x2be802ab,0x7af9edd8,0xdce0012d}},	//   _горк, _चंदू_, ebut, _kolę, 
   {{0x8fa4189d,0xa3c823ef,0x80d000cd,0xe0540066}},	//   _баве, _लीड_, भेदे, _پینت_, 
   {{0xfba46c31,0x7af889f7,0x0a68014b,0x998c0432}},	//   лтый_, gbut, ерои_, lseň_, 
   {{0xcad0063f,0xcc88004b,0x4d140108,0x00000000}},	//   _gịlị, _ګناه_, _бьет, --, 
   {{0x7af901bc,0x2d984c51,0xddb000db,0xdb08010b}},	//   abut, _öre_, _وڭوب, mleý, 
   {{0x7af9edd9,0xa9283ee0,0xdb0800ee,0x00000000}},	//   bbut, ىزگە_, lleý, --, 
   {{0x38c40184,0x60c000cc,0x8625b630,0x63a9edda}},	//   ыуын_, _ølme, льге, čenk, 
   {{0xba1486bf,0x7b8402dd,0x998c00a2,0xdb080432}},	//   _مينا_, _حالە, kseň_, nleý, 
   {{0x91800208,0xe9181cb8,0x7bc80200,0xda641913}},	//   _nền_, _рокі_, _zhgu, _خامي, 
   {{0xb978010f,0xa4d40111,0x248c0115,0x00000000}},	//   _אנגי, рові, ĝemo_, --, 
   {{0xdb0800ee,0xa2f42cdd,0x87040153,0x00000000}},	//   kleý, рпач, _сяке, --, 
   {{0x91800051,0x00000000,0x00000000,0x00000000}},	// [37df0] _bền_, --, --, --, 
   {{0x26c8325f,0x611402bf,0x4175eddb,0xa7fc0139}},	//   _izao_, рджу, دارس, dyız, 
   {{0x31c434d8,0x00000000,0x00000000,0x00000000}},	//   сств, --, --, --, 
   {{0x9f200075,0x661c6df9,0x4421eddc,0x39980248}},	//   تۈرۈ, orsk, muj_, _kásè_, 
   {{0xaf0400d6,0x4421eddd,0x7af8010a,0x661c0010}},	//   спіл, luj_, vbut, nrsk, 
   {{0x7bc80198,0x22580623,0x661d7603,0x3fc404d3}},	//   _shgu, _irsk_, irsk, _ڵگای_, 
   {{0x7af9edde,0x4421eddd,0x661c0112,0xcc8400d4}},	//   tbut, nuj_, hrsk, ибше_, 
   {{0x7af80a73,0x661c0010,0xdca40075,0xdb0800a2}},	//   ubut, krsk, лаһи, bleý, 
   {{0x7af9eddf,0x628c8fe9,0x5ac816c3,0x4421ede0}},	//   rbut, nzao, ълим_, huj_, 
   {{0x4421ede1,0x661c8ef1,0x7af817b8,0x0d2009a5}},	//   kuj_, drsk, sbut, _дүшү, 
   {{0x7bc80cf9,0x4421ede2,0x661dede3,0x6ce4040b}},	//   _thgu, juj_, ersk, _آمن, 
   {{0x4421ede4,0x3ebc356c,0xae1c00af,0x7c2001d3}},	//   duj_, _kyut_, _निमन_, munr, 
   {{0x44200097,0x661c0010,0x9994012d,0x00000000}},	//   euj_, grsk, ęgła_, --, 
   {{0x4421ede5,0x628c0bd7,0x39980241,0xda640451}},	//   fuj_, dzao, _dásè_, _ماڻي, 
   {{0x4420006d,0x661dede6,0x22580166,0xdb080156}},	//   guj_, arsk, _arsk_, kleü, 
   {{0x661dede7,0x68fc0205,0x00000000,0x00000000}},	//   brsk, ırde, --, --, 
   {{0x3ebdc909,0xd26404f0,0x95c801d5,0x00000000}},	// [37e00] _nyut_, шкай, _илиб_, --, 
   {{0xd1755ff9,0x44200034,0x02000137,0x91800051}},	//   шыбы, buj_, юзун, _bến_, 
   {{0x4421ede5,0x628c0356,0x00000000,0x00000000}},	//   cuj_, azao, --, --, 
   {{0x3fc8168d,0xcad002e3,0xdb0800ee,0x64c5ede8}},	//   ندنی_, _dịjị, tleý, _ديپل, 
   {{0x506401e0,0x00000000,0x00000000,0x00000000}},	//   ытҡа, --, --, --, 
   {{0xdb09ede9,0x3ebc0055,0xec1401d5,0x7c200042}},	//   rleý, _dyut_, موتد, funr, 
   {{0x2918007b,0x98a400c0,0x7c2000ef,0x00000000}},	//   óram_, melė_, gunr, --, 
   {{0x8fa50bf0,0xfbcdea72,0xa3d807f7,0x77a803b9}},	//   _табе, وتي_, ाषय_, dıxo, 
   {{0x4421edea,0xa93401ec,0x200402d2,0x7d240332}},	//   zuj_, бепш, _ælir_, úrsá, 
   {{0x63a874f4,0x98a40024,0x44200309,0x661dedeb}},	//   čeni, nelė_, yuj_, vrsk, 
   {{0x2d9dedec,0x3ce809fd,0x44200218,0xc7c42db7}},	//   mive_, _चलते_, xuj_, исми, 
   {{0x2d9deded,0x4421edee,0xa5f8e085,0x661ce045}},	//   live_, vuj_, лему_, trsk, 
   {{0x661c2ad4,0x247c02d3,0x4420033f,0x67d40116}},	//   ursk, _ጥልመት_, wuj_, _һоку, 
   {{0x2d9c5909,0x4421edef,0x661dedf0,0x25a801d3}},	//   nive_, tuj_, rrsk, اضحی_, 
   {{0x290da54c,0x67d40262,0x98a40006,0xdb0829d3}},	//   mada_, _локу, delė_, cleó, 
   {{0x290dedf1,0x052403f4,0x44203e8f,0x661dedf2}},	//   lada_, য়ের_, ruj_, prsk, 
   {{0x4421edf3,0x26c985fd,0xea3000fd,0x6594010b}},	// [37e10] suj_, _uzao_, _çığa_, _гапу, 
   {{0x225801fa,0x4421edf4,0x628c31cd,0x20e401f0}},	//   _vrsk_, puj_, rzao, ссаҳ, 
   {{0x290dedf5,0xd1280131,0xdb0800a3,0x4420047e}},	//   iada_, اقمۇ_, ileò, quj_, 
   {{0x3ebc03a2,0x1bec012d,0x00000000,0x00000000}},	//   _pyut_, _चंबल_, --, --, 
   {{0x290dedf6,0x2d9dedf7,0xef1802bf,0x98a400c0}},	//   kada_, five_, рмі_, belė_, 
   {{0x2d9dedf8,0x2249edf9,0x61ec4b2a,0x00000000}},	//   give_, mwak_, mqal, --, 
   {{0x22481c06,0x672c1050,0x00000000,0x00000000}},	//   lwak_, _ocaj, --, --, 
   {{0x672c01d4,0x1b48209b,0x7c21edfa,0x2d9c0099}},	//   _ncaj, узии_, runr, aive_, 
   {{0x290dedfb,0x61ededfc,0xfeb81bff,0x3ebdedfd}},	//   fada_, nqal, _شارت_, _uyut_, 
   {{0x2d9dedfe,0x7c200502,0x672ca547,0x598410fc}},	//   cive_, punr, _acaj, слоб, 
   {{0xdef80020,0x61ec01d5,0x00000000,0x00000000}},	//   _ሊሆን_, hqal, --, --, 
   {{0x22480c6a,0x1038008f,0x4c98011a,0x21ec02d2}},	//   kwak_, נגרע, _גבעו, _oþh_, 
   {{0x290dedff,0x6d680798,0xbbd0012c,0x00000000}},	//   bada_, _àsaú, दगीक, --, 
   {{0x63bc0217,0x61ec3a73,0xdb080192,0x6e2400a3}},	//   _aksn, dqal, cleò, àibi, 
   {{0x2b900722,0x61ec0194,0x0e8c063f,0x00000000}},	//   _رییس, eqal, tịkị_, --, 
   {{0x2d9dee00,0xe9243ae9,0x087400c8,0x21ec02d2}},	//   zive_, _འཐོབ_, _לעצט_, _bþh_, 
   {{0x61ec00aa,0xae1c6f64,0x22480280,0x11e8188d}},	// [37e20] gqal, _निधन_, gwak_, اعري_, 
   {{0x2d9c022f,0xf4780220,0x63bc0254,0xb5980244}},	//   xive_, _көбі_, _eksn, _ئێسا_, 
   {{0x2d9dee01,0x61ec0869,0xa3c803e5,0x98a40024}},	//   vive_, aqal, _लीव_, relė_, 
   {{0x2d9c009f,0x2248007f,0x61ec2988,0x0e65ee02}},	//   wive_, bwak_, bqal, йкен, 
   {{0x290dee03,0x2d9c97aa,0x7764025c,0x3adc00b8}},	//   yada_, tive_, _mnix, _jāpī_, 
   {{0xe9240327,0x4638010f,0xc69000df,0x9e6433d2}},	//   _འཐེབ_, רעסע, האד_, تامن, 
   {{0x2d9dee04,0x63bc05ac,0xd478008f,0xfd0c0a9e}},	//   rive_, _yksn, טאַל, رجو_, 
   {{0x290dee05,0x3b5002e8,0xea18119e,0xddc80210}},	//   wada_, зкър, ажиш_, _kreś, 
   {{0x290dee06,0x2d9c0588,0x0ea83e38,0x3adc0055}},	//   tada_, pive_, _скай_, _nāpī_, 
   {{0x77640472,0x672c0395,0x2d9c0240,0xad8400f7}},	//   _anix, _scaj, qive_, _بارۇ, 
   {{0x39b401c0,0xc1b8010f,0x67d400db,0x00000000}},	//   слээ_, רמיש, жону, --, 
   {{0xea640424,0x49c800ee,0x2248012d,0x61edee07}},	//   _وپای, _өлен_, ywak_, yqal, 
   {{0x290cc559,0xfa3004fb,0xda64143e,0x3adc0055}},	//   pada_, _فرود, _واهي, _cāpī_, 
   {{0x290dee08,0x77653bc1,0xbb800150,0x00000000}},	//   qada_, _enix, _ولەي, --, 
   {{0xdef8001f,0x2248011f,0xb934011a,0x00000000}},	//   _ሊሆኑ_, wwak_, _הרוג_, --, 
   {{0x22480548,0x61ec01a9,0x00000000,0x00000000}},	//   twak_, tqal, --, --, 
   {{0x22480086,0x06d4015b,0x659400c7,0x63bc0208}},	// [37e30] uwak_, _থ্রি, _маиу, _vksn, 
   {{0x61edee09,0x2248011f,0x35f800c6,0x27e002fb}},	//   rqal, rwak_, _اريد_, _činy_, 
   {{0x65640472,0x9ee88316,0x61ec0986,0x1fb8004e}},	//   _inhh, لفضل_, sqal, алжы_, 
   {{0xe7c80303,0x69ac0574,0xff04177b,0x22480100}},	//   रतिप, ीकडी, сяжн, pwak_, 
   {{0x61edee0a,0x31c401d9,0xe18802dd,0x1d0802e8}},	//   qqal, _کۅلہ, _көже_, аели_, 
   {{0xace805d9,0xceb40022,0x00000000,0x00000000}},	//   ٽرول_, цәс_, --, --, 
   {{0xe7c823ef,0x757c011a,0x00000000,0x00000000}},	//   रताप, רטופ, --, --, 
   {{0xdd98007f,0xdb080aab,0x00000000,0x00000000}},	//   _kwňk_, gleð, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa3d84d53,0xd8744715,0x00000000,0x00000000}},	//   ाषा_, زادب, --, --, 
   {{0x6564004d,0x3adc0055,0x628800ef,0xa3c83cc3}},	//   _anhh, _pāpī_, _ļeon, _लील_, 
   {{0x99740166,0xe9a8136e,0x00000000,0x00000000}},	//   _мукш, شدین_, --, --, 
   {{0x15b823c0,0x817c0023,0x3adc00b8,0x00000000}},	//   рымы_, ረኽበሉ_, _vāpī_, --, 
   {{0x84e005f5,0x7764025c,0x97c442f4,0x00000000}},	//   дорж, _tnix, _وتعم, --, 
   {{0x77648191,0x27f80419,0x00000000,0x00000000}},	//   _unix, írne_, --, --, 
   {{0xd5740139,0x03a004c2,0x00000000,0x00000000}},	// [37e40] _дунь, фито, --, --, 
   {{0x10a431df,0x00000000,0x00000000,0x00000000}},	//   оизн, --, --, --, 
   {{0xd469ee0b,0xcee80c56,0xd0441c3e,0x98a40171}},	//   _тине_, адее_, تپاي, delī_, 
   {{0xddc8006d,0x66c801a9,0x00000000,0x00000000}},	//   _treś, mоkr, --, --, 
   {{0xdd4400b7,0x63a801a6,0xe354004e,0xc7d4011a}},	//   _ኦሊምፒ, čent, _этээ, קוני_, 
   {{0x6a800241,0x00000000,0x00000000,0x00000000}},	//   _láfú, --, --, --, 
   {{0x0b89ee0c,0x26c40085,0x7e000241,0x00000000}},	//   исии_, ́lo_, _ọstr, --, 
   {{0x31791ceb,0x4478010f,0x31b400d7,0x00000000}},	//   _horz_, ינצע, väzy_, --, 
   {{0xbea00e26,0x9f4c03fa,0x31780165,0x8d188d46}},	//   _жатк, _hieß_, _korz_, _نزار_, 
   {{0xddc801e4,0x291808e7,0x8c441797,0x8d840b24}},	//   _kreŝ, ûra_, _мезе, _بشرن, 
   {{0x8154008f,0x65940131,0x2e4401e1,0x00000000}},	//   קסטע_, җаву, béfò_, --, 
   {{0xa3c800af,0x07080107,0xaee40055,0x00000000}},	//   _लीं_, шхои_, ciṃs, --, 
   {{0xdb080730,0x9f4c03fa,0x00000000,0x00000000}},	//   ließ, _ließ_, --, --, 
   {{0xe8947cdb,0x26c400da,0xe924031c,0x3178030a}},	//   _наль, ālo_, _འཐིབ_, _norz_, 
   {{0xdb080730,0x43080117,0x817c0023,0x00000000}},	//   nieß, ихам_, ረኽብሉ_, --, 
   {{0x638800c7,0x659400c7,0x00000000,0x00000000}},	//   сӡом_, цаҳу, --, --, 
   {{0xdb0803fa,0x3be4004d,0x00000000,0x00000000}},	// [37e50] hieß, _hđqt_, --, --, 
   {{0xf1c800d1,0x45400244,0x00000000,0x00000000}},	//   قوقى_, _تۆسق, --, --, 
   {{0xf0e80075,0x4425ee0d,0x00000000,0x00000000}},	//   زىنى_, _ên_, --, --, 
   {{0x63a803c6,0x23480b29,0x00000000,0x00000000}},	//   čens, _اسدی_, --, --, 
   {{0xdce00724,0x3179ee0e,0x6cf80490,0x00000000}},	//   _bolğ, _forz_, ुरंग_, --, 
   {{0xddc8008f,0xa91c0419,0x00000000,0x00000000}},	//   _freŝ, ykľa, --, --, 
   {{0x30a41614,0xdb080112,0xdce003e3,0xf2e00154}},	//   _жртв, gieß, _dolğ, যুদণ, 
   {{0x3178007f,0x6370007c,0xc7ac0200,0x6d5c02d2}},	//   _zorz_, _påny, _njё_, _óran, 
   {{0xee780014,0x9cb400e5,0x00000000,0x00000000}},	//   _ویٔژ_, _کمات, --, --, 
   {{0xacf5ee0f,0x00000000,0x00000000,0x00000000}},	//   _قسمت, --, --, --, 
   {{0xad24215c,0x00000000,0x00000000,0x00000000}},	//   _زىنى, --, --, --, 
   {{0xba74007b,0x00000000,0x00000000,0x00000000}},	//   _واشت, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x61e80115,0x00000000,0x00000000,0x00000000}},	//   _ɨele, --, --, --, 
   {{0xfbc81db2,0x00000000,0x00000000,0x00000000}},	//   ातिम, --, --, --, 
   {{0xd185310f,0x31789584,0x527406ed,0x1bec000d}},	// [37e60] плай, _porz_, чуву, _चूसल_, 
   {{0xdce00100,0x7645ee10,0x00000000,0x00000000}},	//   _anlč, _ipiy, --, --, 
   {{0x7d000175,0xfbc800dc,0xcf440153,0x8fa40114}},	//   dbns, ाताम, зней, паже, 
   {{0x91e400e6,0xdce003b9,0x00000000,0x00000000}},	//   _номе, _solğ, --, --, 
   {{0x2ee001c7,0x7c20002f,0x3e8000b8,0x91e400d8}},	//   äif_, ernr, _nītā_, _хоге, 
   {{0x7644014b,0x32000113,0x2a600010,0xdce00139}},	//   _mpiy, mpiy_, _šibo_, _qolğ, 
   {{0xbc3402dd,0xdce00166,0x00000000,0x00000000}},	//   كسيا_, _volğ, --, --, 
   {{0x7644007f,0xdce00139,0xdb08002f,0x00000000}},	//   _opiy, _wolğ, rieß, --, 
   {{0xaa59da33,0x00000000,0x00000000,0x00000000}},	//   ципу_, --, --, --, 
   {{0xddc80724,0x6fec03e3,0xc0e00023,0xdb08002f}},	//   _ireş, _ağci, ምጋም_, pieß, 
   {{0x7645ee11,0xfa3159c9,0x2d8c137e,0xc1700375}},	//   _apiy, ورید, _ilde_, תחת_, 
   {{0x47889551,0xddc803e0,0x00000000,0x00000000}},	//   ссом_, _kreş, --, --, 
   {{0x32000113,0x3e8000cd,0x9ba000cf,0xe9180111}},	//   jpiy_, _gītā_, _جەيى, _долі_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d58de16,0x00000000,0x00000000,0x00000000}},	//   idva, --, --, --, 
   {{0x69c9ee12,0xddc80166,0x00000000,0x00000000}},	//   llde, _oreş, --, --, 
   {{0x26dc4e53,0x69c9ee13,0x442000d8,0x6d5802d0}},	// [37e70] _àwo_, olde, srj_, kdva, 
   {{0x6d580d27,0x673c69a9,0x69c803e0,0x00000000}},	//   jdva, lfsj, nlde, --, 
   {{0x69c9ee14,0xc0c400f1,0x00000000,0x00000000}},	//   ilde, سېره_, --, --, 
   {{0x2d8c0323,0x6d58f25d,0xafc404da,0x69c8002f}},	//   _alde_, edva, ىيلى, hlde, 
   {{0xdd95ee15,0xddc800a8,0x291c007f,0x6d5801a4}},	//   мады, _creş, _odva_, fdva, 
   {{0x63adee16,0x3e80005f,0x61fc85f7,0x6d5c659a}},	//   lnan, _rītā_, _itsl, _óral, 
   {{0xddc800a2,0x3e8000cd,0x00000000,0x00000000}},	//   _ereş, _sītā_, --, --, 
   {{0x69c9ee17,0x2d8caa4a,0x6445ee18,0x6dc401e4}},	//   elde, _elde_, _mphi, _aĉaĵ, 
   {{0x63adee19,0xddc8084c,0xd0200c58,0x2a3430ab}},	//   inan, _greş, _নহয়_, нээр, 
   {{0x63adee1a,0x6445ee1b,0x69c80c86,0x49c401c0}},	//   hnan, _ophi, glde, млын_, 
   {{0x63ac9ee0,0x2001b132,0x2ce8030d,0x00000000}},	//   knan, nphi_, _хьуо_, --, 
   {{0x69c9ee1c,0x63acdba0,0x7f48009a,0x673c0334}},	//   alde, jnan, negq, gfsj, 
   {{0x7bd9ee1d,0x2bb80597,0x7ae802d0,0x195841e5}},	//   mmuu, _عامة_, _iggt, _мады_, 
   {{0x7bd9500e,0x45d00006,0x00000000,0x00000000}},	//   lmuu, коўс, --, --, 
   {{0x63ac008c,0x3f9c0a73,0x61fc00da,0xf484105f}},	//   fnan, _omuu_, _atsl, راسی, 
   {{0x6d5808ad,0x7bd802f6,0x64440036,0x562822c3}},	//   zdva, nmuu, _dphi, _джим_, 
   {{0x64440912,0x76442251,0xdce0005f,0x7bd9ee1e}},	// [37e80] _ephi, _upiy, _kolē, imuu, 
   {{0x3f9c198f,0xc6e40014,0x7bd8d4d8,0x98d0012c}},	//   _amuu_, _تتى۪, hmuu, _हराए, 
   {{0x61fc0857,0x63ad078a,0xa3c8033f,0x7bd80254}},	//   _etsl, bnan, _लीक_, kmuu, 
   {{0xddc800a8,0x8fd1ee1f,0x7f48009a,0x61fc0334}},	//   _preş, тәгә, gegq, _ftsl, 
   {{0x69c8d85d,0x98a40024,0xddc803b9,0x00000000}},	//   ylde, kelį_, _qreş, --, 
   {{0xf9850350,0xdce0005f,0x7bd987ca,0x6d58a9ab}},	//   _شب_, _nolē, emuu, udva, 
   {{0x98a40006,0x7f4801f0,0x00e0118f,0xc0e00022}},	//   delį_, begq, _ажрн, _аорк, 
   {{0xaa550c3b,0x91e4013e,0xfc6002e8,0x69c8031c}},	//   евиш, _хоҳе, тъшн, wlde, 
   {{0x094824fc,0xc278008f,0x3b500137,0x98a40064}},	//   очни_, ַרטי, ткыр, felį_, 
   {{0x7bd80ba7,0x98a40024,0x69c8fb8b,0xca280023}},	//   amuu, gelį_, ulde, _ተቐቢሎ, 
   {{0x69c80628,0xcc3449fa,0x63adee20,0x00000000}},	//   rlde, _زراع, ynan, --, 
   {{0xfcd1ee21,0x998c01a6,0x63ac002e,0x00000000}},	//   _شينج, rteš_, xnan, --, 
   {{0x6445ee22,0x63adee23,0x29180597,0xa3c82c97}},	//   _sphi, vnan, óras_, _लीग_, 
   {{0x63ac0034,0x20000054,0x27fc004d,0xfaa40066}},	//   wnan, yphi_, _ttvn_, _تجمی, 
   {{0x63adee24,0xfa08003d,0x7f480117,0x00000000}},	//   tnan, _གསོན_, yegq, --, 
   {{0x63ac3386,0x37a802dd,0x0544009d,0x00000000}},	//   unan, _отын_, чүүл_, --, 
   {{0x63adee25,0xb604012c,0x02a0063f,0x00000000}},	// [37e90] rnan, tvář, ptọọ, --, 
   {{0x63adee26,0x660dee27,0x645400f3,0x00000000}},	//   snan, _iwak, _звођ, --, 
   {{0x31c44676,0x6444124c,0x27e9ee28,0x660c0e8a}},	//   тств, _uphi, _kian_, _hwak, 
   {{0x660c42e8,0x46d002fe,0x63ac0113,0x2f5402dd}},	//   _kwak, _सराह, qnan, ктіс, 
   {{0x27e9ee29,0x61fccf77,0x2fc40014,0xe2c801f7}},	//   _mian_, _utsl, _dkmg_, _روسو_, 
   {{0x660dee2a,0x27e9ee2b,0x7f480921,0x98a40356}},	//   _mwak, _lian_, segq, nglă_, 
   {{0x660c816a,0x2fc40014,0x27e8005a,0x7bd8017a}},	//   _lwak, _fkmg_, _oian_, tmuu, 
   {{0x27e8008f,0x660c1449,0x3f9c2878,0x7bd9ee2c}},	//   _nian_, _owak, _umuu_, umuu, 
   {{0x660c02b9,0x7bd9ee2d,0x99e5ee2e,0x26c952f1}},	//   _nwak, rmuu, нжид, _nyao_, 
   {{0x2dd5ee2f,0x7bd9ee30,0x27e801c4,0xe8f800f7}},	//   _ажур, smuu, _aian_, үлө_, 
   {{0x7ae8074d,0x27e9ee31,0x1868188b,0x660c62bc}},	//   _tggt, _bian_, чани_, _awak, 
   {{0x660c43c4,0x29181f60,0x27e9ee32,0x06c40154}},	//   _bwak, órar_, _cian_, _এলজি, 
   {{0x27e9ee33,0x660c2d2f,0x0f34010f,0x6a140117}},	//   _dian_, _cwak, ערשט_, _амчу, 
   {{0xe4e0000d,0x00000000,0x00000000,0x00000000}},	//   _गृहि_, --, --, --, 
   {{0x660dee34,0x27e9ee35,0x044158b4,0x260c0153}},	//   _ewak, _fian_, лерн, ažo_, 
   {{0x27e90014,0x660c007f,0x921c0037,0x00000000}},	//   _gian_, _fwak, _पिआज_, --, 
   {{0x660dee36,0x00000000,0x00000000,0x00000000}},	// [37ea0] _gwak, --, --, --, 
   {{0x27e80de7,0xa38c00b8,0xbbc800dc,0x00000000}},	//   _zian_, _kāśī_, ातुक, --, 
   {{0x660dee37,0x41b007d6,0x4fe80798,0x4f2400d8}},	//   _zwak, دملر, чмен_, едеб, 
   {{0x2ea81a69,0x00000000,0x00000000,0x00000000}},	//   وپای_, --, --, --, 
   {{0x59b0047f,0x1ea80ccb,0x6d5c87b3,0x8264d59e}},	//   ीकार, واهي_, _órak, _заяв_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xcbe40484,0x00000000,0x00000000,0x00000000}},	//   нции, --, --, --, 
   {{0xd1c0001f,0x22680139,0xc33000df,0x00000000}},	//   ሻዎች_, _ütkä_, ָוז_, --, 
   {{0x7fd400c8,0x27e9ee38,0xcaa43997,0x49a40798}},	//   _טולס_, _rian_, عصبي, ејна, 
   {{0x27e804ac,0x660dcd34,0x291400f2,0x00000000}},	//   _sian_, _rwak, خودآ, --, 
   {{0x660dee39,0x27e9ee3a,0x48a8fe9c,0xba716f88}},	//   _swak, _pian_, ятим_, نایت, 
   {{0x27e9ee3b,0xb904539d,0xaaa401e0,0x05a801ec}},	//   _qian_, _मृ_, _игеҙ, _ﺍﻳﺘﭙ, 
   {{0x27e804ac,0xa9541cd0,0xb5f40395,0x00000000}},	//   _vian_, _аклі, лзящ, --, 
   {{0x26c80451,0x27e8017a,0x260c2ba4,0x0cd000cc}},	//   _vyao_, _wian_, ržo_, াশীত, 
   {{0x27e9ee3c,0x69d84e9b,0x752800d2,0x00000000}},	//   _tian_, _ihve, ódza, --, 
   {{0x660c046a,0x27e8009a,0x817801ec,0x00000000}},	//   _twak, _uian_, _ﺤﻠﻘﺔ_, --, 
   {{0x660dee3d,0x69d80055,0x443c00e8,0x07040f90}},	// [37eb0] _uwak, _khve, ŋu_, _व्यव_, 
   {{0xdb0801e7,0x00000000,0x00000000,0x00000000}},	//   ánúc, --, --, --, 
   {{0x4425ee3e,0xf4848bbd,0x2bac00bc,0xf524084c}},	//   _ín_, _буян, pěch_, _сфын, 
   {{0xda20007d,0x141800d9,0x00000000,0x00000000}},	//   _मिलत_, _קורב, --, --, 
   {{0xfde80b7e,0x69d800c5,0xfafc00e8,0x3ce00073}},	//   чьей_, _ohve, ñëm_, टेने_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa0c4819a,0x5bb400d8,0x00000000,0x00000000}},	//   _شيرو, ксиф, --, --, 
   {{0x66e800b0,0x69d9ee3f,0xdea0036b,0x2ce800c7}},	//   _kīkī, _ahve, _پیتی, хьчо_, 
   {{0xda200490,0x00000000,0x00000000,0x00000000}},	//   _मिळत_, --, --, --, 
   {{0xd944026a,0x69d9ee40,0x59840cd7,0xa38c0055}},	//   њени, _chve, тлоб, _pāśī_, 
   {{0xd82402e8,0x00000000,0x00000000,0x00000000}},	//   ъдни, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x98b04ba9,0xff2400b5,0x1a640133,0x7af80356}},	//   ızı_, _xlsの, _شیدی_, mcut, 
   {{0x9f51ee41,0x7af9ee42,0x7f59ee43,0x00000000}},	//   _buzë_, lcut, _lauq, --, 
   {{0x6fd80005,0x983402d5,0x387006be,0x00000000}},	//   líce, _рэлі, _çxr_, --, 
   {{0x69d802d3,0xc320e3cc,0x4cdc00cc,0x9664010a}},	//   _zhve, имск, নুকু, _акие, 
   {{0xcb1004ac,0x00000000,0x00000000,0x00000000}},	// [37ec0] ילן_, --, --, --, 
   {{0x45d01fbe,0xd0080b3b,0x4101ee44,0x69d80200}},	//   _коњс, деже_, изув, _xhve, 
   {{0x7f580369,0x7af8020c,0x6d5c0332,0x00000000}},	//   _bauq, kcut, _órai, --, 
   {{0x7f59ee45,0x4ea407d6,0x2054010b,0x00000000}},	//   _cauq, крла, ытур, --, 
   {{0x7f580097,0xfe6cc578,0x2b40002e,0x00000000}},	//   _dauq, قدو_, _ñici_, --, 
   {{0xbea1ee46,0x00000000,0x00000000,0x00000000}},	//   шачк, --, --, --, 
   {{0x7f598be2,0xdce00024,0x25ac002e,0xbd8400db}},	//   _fauq, _molė, éeli_, ئنىن_, 
   {{0x7c8062d9,0x69d8036b,0x6fd80120,0x7af8003c}},	//   руше, _shve, fíce, gcut, 
   {{0x8ca003ce,0x3a700395,0x00000000,0x00000000}},	//   _केरो, илър, --, --, 
   {{0x7c2c0162,0x6fd800d7,0x00000000,0x00000000}},	//   ðirø, sícd, --, --, 
   {{0x78d00124,0x39b4009d,0x65a8013a,0x00000000}},	//   ижьх, тлээ_, jžha, --, 
   {{0x7af80268,0xfb8006a6,0x0ae8009f,0xba700133}},	//   ccut, _вышн, _قرشي_, _چاوت, 
   {{0x7b840150,0x7bc400e4,0xba7002f2,0x00000000}},	//   _جالە, _êjua, _ناوت, --, 
   {{0x24580124,0x00000000,0x00000000,0x00000000}},	//   нагь_, --, --, --, 
   {{0x4990034c,0x03c4994d,0x21840107,0x73300241}},	//   _میکر, всам, қтаҳ, _ńdáṣ, 
   {{0x7795ee47,0x45680055,0x00000000,0x00000000}},	//   _نیپا, _ṛtāv_, --, --, 
   {{0x7f59ee48,0x61d81507,0xd8b40014,0x00000000}},	// [37ed0] _rauq, емая_, _لگێا_, --, 
   {{0x45a004a9,0x661c1455,0x41740b24,0x00000000}},	//   _ئەسك, mssk, خارس, --, 
   {{0xb9dc0020,0x661dee49,0x7f58067c,0xdef0007b}},	//   _ብዬ_, lssk, _pauq, مًا_, 
   {{0x624801e4,0xff04bef7,0x00000000,0x00000000}},	//   _pɾod, тяжн, --, --, 
   {{0x661dee4a,0x7af803ee,0x53980375,0x48bc0154}},	//   nssk, vcut, _נישו, উইয়র, 
   {{0xbbc8197c,0x7f59ee4b,0x7db42073,0x6fd800bc}},	//   ात्क, _wauq, خصصا, více, 
   {{0x60d402d0,0x7af8cb99,0x00000000,0x00000000}},	//   _uzzm, tcut, --, --, 
   {{0x661dee4c,0x00000000,0x00000000,0x00000000}},	//   kssk, --, --, --, 
   {{0x99150ee8,0x19c42c11,0x661c01bf,0x7c2401d3}},	//   льні, лбим, jssk, ريکہ_, 
   {{0x7af9ee4d,0x661c1455,0xfd0002dd,0x988c0023}},	//   scut, dssk, _түкп, _ዝመርሑ_, 
   {{0x5b240597,0x661c4606,0x6fd80118,0x00000000}},	//   _مفضل, essk, síce, --, 
   {{0x9f50019f,0xd628119e,0xddc800d7,0xb8c80037}},	//   _buzé_, номе_, _speň, _गध_, 
   {{0x661d5b27,0xdce000c0,0x4b7800df,0xc7a04964}},	//   gssk, _polė, _ראנו, сияк, 
   {{0xdb08067c,0xfe08012d,0x00000000,0x00000000}},	//   lneà, सीएस_, --, --, 
   {{0x46440220,0x661c017a,0x00000000,0x00000000}},	//   _ұзын_, assk, --, --, 
   {{0x3864004e,0x661c00b5,0x73c401e0,0x03a032b1}},	//   _irnr_, bssk, рҡма, бисо, 
   {{0x3a3dee4e,0x5f44001f,0xdce00064,0xf744014b}},	// [37ee0] ntup_, _የሌላቸ, _tolė, _беқо, 
   {{0x42c40228,0x61e807c5,0xdce00064,0x50d40633}},	//   угун_, _èell, _uolė, هزار, 
   {{0x649800ee,0x82a001b9,0x00000000,0x00000000}},	//   _атяр_, _ҳаяж, --, --, 
   {{0x3a3dee4f,0xa4900214,0x98a40205,0x00000000}},	//   ktup_, _بیفت, ndlı_, --, 
   {{0x8fd00032,0xdd9802e2,0x0dc80a42,0x43640334}},	//   _ғәжә, _pwňp_, нуки_, _саян_, 
   {{0xf1b809fa,0x6c35ee50,0xd1746171,0x00000000}},	//   _आदिन, لفتا, _сымы, --, 
   {{0xac94519a,0x0b8904cd,0xdef800e8,0x22580419}},	//   райш, еспи_, _saŋe_, _zssk_, 
   {{0x661c0158,0x00000000,0x00000000,0x00000000}},	//   yssk, --, --, --, 
   {{0x38640077,0xdd9802e2,0xc9840aac,0x3d700014}},	//   _arnr_, _twňp_, гуни, _گُلز, 
   {{0x661c050a,0x935c0b82,0xbb453ecd,0x00000000}},	//   vssk, _ቅጽበታ, پلین_, --, 
   {{0x6d49ee51,0x57c00131,0x2a600327,0x1bec23ef}},	//   _ibda, ﺯﻟﯩﺮ, _ġibu_, _चंचल_, 
   {{0x27ec0036,0x00000000,0x00000000,0x00000000}},	//   öen_, --, --, --, 
   {{0xc6a5ee52,0xf98c168d,0xda640150,0x661c01c7}},	//   урни, زبی_, _پاني, ussk, 
   {{0x994800d0,0x7954022e,0x00000000,0x00000000}},	//   _púť_, _бишр_, --, --, 
   {{0x67d443be,0xdb080120,0x6f009979,0x2eb029d9}},	//   _коку, lneá, _ofmc, जपुत, 
   {{0x69d887d9,0x7f900166,0x290c01a9,0x00000000}},	//   _नीती, _oçqa, lbda_, --, 
   {{0x6d49ee53,0x248c00da,0x623400e4,0xdb08007b}},	// [37ef0] _obda, ņem_, резу, nneá, 
   {{0x290c009a,0xdb0800ae,0x00000000,0x00000000}},	//   nbda_, ineá, --, --, 
   {{0x7f90008e,0x846400a7,0xe038084c,0x25ac0de2}},	//   _açqa, _съпе, тзеч_, éelu_, 
   {{0x6d49ee54,0x5478008d,0x2eb0007d,0x3a3c0784}},	//   _abda, _סטרו, जपूत, ytup_, 
   {{0x8f5000f2,0x00000000,0x00000000,0x00000000}},	//   زنوش, --, --, --, 
   {{0xc0c80114,0x00000000,0x00000000,0x00000000}},	//   _зубе_, --, --, --, 
   {{0xf538008d,0xdc7400c0,0x91b8011a,0xff040064}},	//   אטור_, рыль, _ימשי, _бязн, 
   {{0x3a3c0eda,0x6d4802d0,0xdb0801f5,0x7058010b}},	//   ttup_, _ebda, mieë, _щаср_, 
   {{0xdb080af9,0x290c0175,0xdce00171,0xdb0c0248}},	//   lieë, fbda_, _kolī, _àjíg, 
   {{0x3a3dee55,0x2a600327,0xcac401c6,0xba1400ec}},	//   rtup_, _ġibt_, ргье_, نڊڪا_, 
   {{0x77e816c3,0x6fd829d3,0x6d340150,0xdb08257c}},	//   ллоҳ_, líca, _اۋىس_, nieë, 
   {{0x3a3c0784,0x00000000,0x00000000,0x00000000}},	//   ptup_, --, --, --, 
   {{0x3a3c0d04,0x7bc801ee,0x6fd804cf,0x290c025c}},	//   qtup_, _ikgu, níca, bbda_, 
   {{0xceb00d65,0x38640165,0xdce000e2,0xc6a4010a}},	//   קים_, _trnr_, _nolī, ăрни, 
   {{0xdd0000bc,0x7980035a,0x00000000,0x00000000}},	//   _štět, _ionw, --, --, 
   {{0x7980037e,0x1305ee56,0xdb0801a4,0xcb10008f}},	//   _honw, рзам, dieë, ַלב_, 
   {{0x7981ee57,0x86b00046,0xdce00171,0x00000000}},	// [37f00] _konw, _дәрі, _bolī, --, 
   {{0x6fd86bdf,0xdb080d27,0x7980047e,0x7584008e}},	//   díca, fieë, _jonw, _уңга, 
   {{0xdb080d27,0xc2e4015b,0x7981ee58,0x7bc80432}},	//   gieë, গুলি_, _monw, _okgu, 
   {{0x6fd912c0,0x6e200098,0x0e65ee59,0x7981ee5a}},	//   fíca, _pvmb, икен, _lonw, 
   {{0xe2800075,0xda1438d2,0x5275ee5b,0x63a0017a}},	//   _еһти, _दौलत_, _туну, ëlne, 
   {{0x7bc8062d,0xdb0801a4,0x3dc40036,0x6440004e}},	//   _akgu, bieë, gonw_, àlig, 
   {{0x20b8169c,0xdb080122,0x00000000,0x00000000}},	//   _быть_, šnýc, --, --, 
   {{0x4f941fbe,0x8e84010a,0xdce00171,0xbb8000d1}},	//   _тргу, _кгбе, _zolī, قلىي, 
   {{0x7980b0dd,0x3dc40472,0x8d55ee5c,0x2a600327}},	//   _bonw, bonw_, _втеч, _ġibs_, 
   {{0x7981ee5d,0x6d4802d0,0xf98c01f7,0xdb0800ae}},	//   _conw, _ubda, ِبَ_, rneá, 
   {{0x7980013f,0x290c022e,0x3cf8010f,0x00000000}},	//   _donw, rbda_, _סלאנ, --, 
   {{0x4ae4036b,0x4aa85409,0x6fb801ad,0x00000000}},	//   _кўла, _икен_, ेकिं, --, 
   {{0x798032a7,0xdb0801a4,0x00000000,0x00000000}},	//   _fonw, zieë, --, --, 
   {{0x7981ee5e,0x3884013f,0xe91800c0,0x00000000}},	//   _gonw, wɑre_, _сокі_, --, 
   {{0x69c9ee5f,0x6fb81fbc,0xa4d401ce,0x3854007b}},	//   mode, ेकां, сові, _نشيد_, 
   {{0x7980d157,0xdce0005f,0xe8d00014,0xa2f40006}},	//   _zonw, _solī, _وۅکھ, спач, 
   {{0xb7dc02e4,0x7980ada9,0x69c80076,0xdce1a9cc}},	// [37f10] _בקהי, _yonw, oode, _polī, 
   {{0xf65000b2,0xdb0801f5,0x00000000,0x00000000}},	//   _آئي_, tieë, --, --, 
   {{0x644000db,0x8024009a,0x00000000,0x00000000}},	//   àlid, شرام, --, --, 
   {{0xdb080cf9,0xff50fd61,0x3dc40083,0x6fd8021c}},	//   rieë, تخط_, wonw_, tíca, 
   {{0x63adee60,0xd37804ac,0x69c9ee61,0xdb09ee62}},	//   mian, _ערשט, kode, sieë, 
   {{0x63adee63,0xdb081af3,0xb324025c,0x69c8026c}},	//   lian, pieë, _འཇོང_, jode, 
   {{0x69c85110,0x79801028,0xe0e42aab,0xdd100135}},	//   dode, _ronw, _প্রভ, _iżżo, 
   {{0x63adee64,0x7981ee65,0x628c009f,0x3f8c037e}},	//   nian, _sonw, oyao, qkgu_, 
   {{0x628c0770,0x69c9ee66,0x63ac03ac,0x389403b9}},	//   nyao, fode, iian, mərə_, 
   {{0x69c9ee67,0x38940cc1,0xf1c800bc,0x7980016d}},	//   gode, lərə_, _tvář_, _qonw, 
   {{0x63adee68,0x61e40e9e,0x49c401c0,0x57e801ee}},	//   kian, imhl, слэн_, лдом_, 
   {{0x63adee69,0x6d94002e,0x798001e2,0xe9d822fd}},	//   jian, _jàan, _wonw, лкө_, 
   {{0x69c9ee6a,0x63adee6b,0x7980324c,0xf99c0129}},	//   bode, dian, _tonw, èès_, 
   {{0x628c0161,0x2b9800e4,0x38940213,0xa9c40244}},	//   dyao, _véce_, hərə_, _وزوو, 
   {{0x63adee6c,0x80a401ad,0xccf00375,0x47d000f1}},	//   fian, _टेले, לכם_, _ډيور, 
   {{0x96944dba,0x03a06545,0x00000000,0x00000000}},	//   _грош, писо, --, --, 
   {{0x389403e3,0x00000000,0x00000000,0x00000000}},	// [37f20] dərə_, --, --, --, 
   {{0x63ac37e7,0x422002bf,0x59dc07f7,0x6e240010}},	//   aian, ядув, _नीमर, šibk, 
   {{0x389400ac,0x0fb40133,0xb62c0150,0x766401f7}},	//   fərə_, مێسک_, _ﯗﻥ_, _اُڌم, 
   {{0x61e41db0,0x644000db,0xdb08248c,0x527400db}},	//   amhl, àlie, nneä, _лугу, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9e6400d1,0x06a800eb,0x00000000,0x00000000}},	//   غانن, _গুডি, --, --, 
   {{0x0578069c,0x389400ac,0x0ba40b7e,0x2ca00115}},	//   _ኣገባብ_, bərə_, йшим, ĝido_, 
   {{0x6d94002e,0x6fd80077,0x69c8033f,0x441808d8}},	//   _gàan, míco, wode, אוקס, 
   {{0x69c9ee6d,0x0d85ee6e,0x7e4800e5,0x3a700166}},	//   tode, _ллан, _مسلہ_, злыр, 
   {{0x63adee6f,0x2919ee70,0x00000000,0x00000000}},	//   zian, úra_, --, --, 
   {{0x69c9ee71,0x63ac0357,0x6fd8311a,0x00000000}},	//   rode, yian, níco, --, 
   {{0x69c9ee72,0x63adee73,0x6f040309,0xf7d800d1}},	//   sode, xian, ñich, ﯟﺍﻳﻪ, 
   {{0x63adee74,0xa5f8034b,0x9f640129,0xdb242b96}},	//   vian, регу_, êtés_, øpåv, 
   {{0x63adee75,0x389400ac,0xe5080b24,0x6e24031c}},	//   wian, zərə_, شيرو_, ġibh, 
   {{0x63adee76,0x7b040098,0x24180024,0x00000000}},	//   tian, _ésté, робы_, --, 
   {{0xdb08737f,0x63acb0b3,0x06a8009e,0x628c0083}},	//   rneç, uian, _গুণি, tyao, 
   {{0x63adee77,0x00000000,0x00000000,0x00000000}},	// [37f30] rian, --, --, --, 
   {{0x63adee78,0x628c0165,0x00000000,0x00000000}},	//   sian, ryao, --, --, 
   {{0xe4d804fb,0x00000000,0x00000000,0x00000000}},	//   _خودت_, --, --, --, 
   {{0x63ac0194,0xf4840d23,0x00000000,0x00000000}},	//   qian, _راپی, --, --, 
   {{0x2bcc193d,0xdb0805ac,0x44200076,0x00000000}},	//   ावना, nneå, lsj_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4420168c,0x7528012d,0x00000000,0x00000000}},	//   nsj_, ódzi, --, --, 
   {{0x2cb802fb,0xdde400fb,0x00000000,0x00000000}},	//   _šedý_, сәғү, --, --, 
   {{0x1a64006c,0xdce0010f,0xdea0036b,0xfeb8007b}},	//   تیشی_, _malĉ, _تیشی, _صارت_, 
   {{0x7db5ee79,0x2cb400c6,0x6fd8004e,0x6fec0356}},	//   _اصرا, éadú_, hícl, _aşch, 
   {{0x9b586c00,0x00000000,0x00000000,0x00000000}},	//   _виет_, --, --, --, 
   {{0x63bc009a,0x00000000,0x00000000,0x00000000}},	//   _njsn, --, --, --, 
   {{0x44200af9,0x00000000,0x00000000,0x00000000}},	//   esj_, --, --, --, 
   {{0x7ddc002d,0x75e000e5,0x6e240332,0x1868022e}},	//   lêsb, köze, áibi, _ваки_, 
   {{0xe9b800dd,0x5fc8047f,0xe84800ec,0x8c2001a9}},	//   _دنوں_, िकाल, _هجين_, _ta知i, 
   {{0xfa240003,0x3e8000b0,0x1309ee7a,0x2bccdc75}},	//   _ལྗོན_, _kūtā_, рнай_, ावया, 
   {{0xd18401ee,0x6458012d,0x00000000,0x00000000}},	// [37f40] олай, _ćwie, --, --, 
   {{0x9f5005d5,0x76440477,0x776400cf,0x6fd8215a}},	//   _auzà_, _iqiy, _haix, tíco, 
   {{0x776401c0,0xdce000df,0x3e800055,0x20b80006}},	//   _kaix, _falĉ, _lūtā_, быць_, 
   {{0x776401c6,0xb324031c,0x753c033f,0xd7c811bc}},	//   _jaix, _འཇིང_, lgrz, रविच, 
   {{0x91e41f5c,0x3b1c0399,0x77658d5b,0x6fd802fb}},	//   _моме, dauq_, _maix, síco, 
   {{0x7764005a,0x10a4368e,0x332000cf,0x2bcc00cd}},	//   _laix, _дигн, laix_, ावभा, 
   {{0xd7c807b7,0x00000000,0x00000000,0x00000000}},	//   रवाच, --, --, --, 
   {{0x776400f7,0x2b9800d5,0xc20c01d9,0x3e800055}},	//   _naix, _béca_, _سٔہ_, _būtā_, 
   {{0x7c200218,0x3aec02b1,0x00000000,0x00000000}},	//   asnr, _röpü_, --, --, 
   {{0x59dc05f9,0x0c7473c9,0x3e8000b8,0x442003cd}},	//   _नीदर, _وداد, _dūtā_, ysj_, 
   {{0x77644f7b,0x6d582828,0x75e001ed,0x7644058a}},	//   _baix, meva, közb, _aqiy, 
   {{0x77644f7b,0x2b980129,0x200439b4,0x00000000}},	//   _caix, _féca_, _élie_, --, 
   {{0x39982776,0x38c00036,0x41bc00dc,0x3e8000ef}},	//   _sêse_, tèrë_, ्वमस, _gūtā_, 
   {{0x6d58033d,0x442003cd,0xdb0803cd,0x320001a9}},	//   neva, tsj_, rneå, dqiy_, 
   {{0x7765a774,0x291c1039,0x6fec05d1,0x6d58017a}},	//   _faix, _ieva_, _eşci, ieva, 
   {{0x6d59ee7b,0x776405f5,0x291dee7c,0x442008fb}},	//   heva, _gaix, _heva_, rsj_, 
   {{0x6d59ee7d,0x291c009b,0x44205b4c,0xdb1001ed}},	// [37f50] keva, _keva_, ssj_, áfér, 
   {{0x35b40150,0x4ae00037,0x070401e2,0x00000000}},	//   _обыр, _परनव, _ايښي_, --, 
   {{0x6d59ee7e,0x291dee7f,0xe3740598,0x3321ee80}},	//   deva, _meva_, _елны, baix_, 
   {{0x291dee81,0x6565ee82,0x64445a6a,0x9ee80597}},	//   _leva_, _hahh, _iqhi, مفضل_, 
   {{0x1d09d59e,0xee38160b,0x6d5872dc,0x65640254}},	//   бели_, жні_, feva, _kahh, 
   {{0x291dee83,0x8d60005b,0x00000000,0x00000000}},	//   _neva_, евше, --, --, 
   {{0x3b1c0d04,0x6565ee84,0x3e800055,0x00000000}},	//   tauq_, _mahh, _sūtā_, --, 
   {{0x21200a2e,0x61f5ee85,0x6f04025a,0x291c1a96}},	//   lahh_, _hizl, rïbï, _aeva_, 
   {{0x60d5ee86,0x6d59ee87,0x291dee88,0x77640007}},	//   _hyzm, beva, _beva_, _raix, 
   {{0x291dee89,0x65640455,0x673c002f,0x699401f4}},	//   _ceva_, _nahh, egsj, дрюх, 
   {{0x291dee8a,0x776410ba,0x64440070,0x61fd2f81}},	//   _deva_, _paix, _nqhi, _lusl, 
   {{0x2121ee8b,0x6564359a,0x291c8234,0x673c0158}},	//   hahh_, _aahh, _eeva_, ggsj, 
   {{0x64440054,0x776400f7,0x291c0421,0x65640477}},	//   _aqhi, _vaix, _feva_, _bahh, 
   {{0x291c0579,0x15b9769c,0x61f4031c,0x98a40166}},	//   _geva_, сымы_, _nizl, _ниле, 
   {{0x61fc928b,0x6565ee8c,0x64580034,0x00000000}},	//   _ausl, _dahh, _ćwic, --, 
   {{0x61f40029,0x6d5879d7,0x98940131,0x320001a9}},	//   _aizl, zeva, _муқә, tqiy_, 
   {{0x6d59ee8d,0x64440472,0x61f48795,0x65640109}},	// [37f60] yeva, _eqhi, _bizl, _fahh, 
   {{0xdb18063f,0x61fc0724,0x3200036b,0x3320020c}},	//   _akwü, _dusl, rqiy_, saix_, 
   {{0x6d59ee8e,0x61f5ee8f,0x61fdee90,0xc3240131}},	//   veva, _dizl, _eusl, زكەن_, 
   {{0x2120003e,0x6d59ee91,0x60d41327,0xdfa415f2}},	//   aahh_, weva, _dyzm, وحني, 
   {{0x6d59d180,0xc3300bd4,0x6fd80030,0x320001b9}},	//   teva, _אור_, líck, qqiy_, 
   {{0xdce003e0,0x80a40118,0x00000000,0x00000000}},	//   _allı, _टेके, --, --, 
   {{0x6d59ee92,0x291dee93,0x6fd80030,0x60d40432}},	//   reva, _reva_, níck, _gyzm, 
   {{0x291c0e26,0x6d59ee94,0x2bcc0b7d,0x61fc011f}},	//   _seva_, seva, ावधा, _yusl, 
   {{0x6d59ee95,0x8d192dda,0x291dee96,0xbea099fb}},	//   peva, _هزار_, _peva_, _затк, 
   {{0xd90c3c46,0xdce00724,0x7e98011a,0xceb401ee}},	//   لیه_, _ellı, _הסמו, _мәҙ_, 
   {{0x291c1570,0x4c15ee97,0xfcf40092,0x6e240327}},	//   _veva_, _رباس, _ሊመጣ_, ġibu, 
   {{0x291ddf8e,0x6565ee98,0x00000000,0x00000000}},	//   _weva_, _sahh, --, --, 
   {{0x291c0228,0xf1cc033f,0x2120020c,0x673c01e3}},	//   _teva_, ़कान, yahh_, rgsj, 
   {{0x291c0921,0xfa24031c,0x6565ee99,0x2490012d}},	//   _ueva_, _ལྗིན_, _qahh, tyzm_, 
   {{0xa3d40440,0x65642a89,0xf554009d,0x00000000}},	//   довч, _vahh, эврэ, --, 
   {{0x61fdee9a,0x61f5957e,0x5908031c,0xf365652b}},	//   _pusl, _sizl, _གཅོས_, нтун, 
   {{0x6565ee9b,0x672c0ca8,0xdd300024,0x61fc0477}},	// [37f70] _tahh, _idaj, _lęši, _qusl, 
   {{0x660dee9c,0x61f40fed,0xe7e003ba,0x65640036}},	//   _itak, _qizl, _गीता_, _uahh, 
   {{0xf99004ac,0xe2f998d4,0x660c0451,0x672c0427}},	//   ערע_, _мені_, _htak, _kdaj, 
   {{0xf0e828f7,0x660c0093,0xdea04667,0x61fd2151}},	//   سىنى_, _ktak, نیزی, _tusl, 
   {{0x61f46733,0xc108010b,0x39a00248,0x2369ee9d}},	//   _tizl, _гэбе_, _jésù_, mdaj_, 
   {{0x59080867,0x660c05d9,0xddc80034,0x22493fb2}},	//   _གཅེས_, _mtak, _speł, mtak_, 
   {{0x1b2003f4,0x22481579,0x1be848a5,0xdd9001ed}},	//   _যাবে_, ltak_, одки_, ٹوں_, 
   {{0x2369ee9e,0x672dee9f,0x2b9820ef,0xdfd00597}},	//   ndaj_, _ndaj, _déco_, _شيء_, 
   {{0x660cf730,0x2249eea0,0xd95802d5,0x236801e4}},	//   _ntak, ntak_, ошні_, idaj_, 
   {{0x672deea1,0x2248005a,0x23680978,0x41bcc126}},	//   _adaj, itak_, hdaj_, ्विस, 
   {{0x22481529,0xad241b56,0x236809a8,0x06a80eac}},	//   htak_, _سىنى, kdaj_, _গুলি, 
   {{0x2368016d,0xab845541,0xdce0013d,0xe6a801f4}},	//   jdaj_, _пучк, _ullı, köää, 
   {{0x41bc1c9e,0x672c0083,0xd944026a,0xdce08847}},	//   ्वास, _ddaj, _жели, _malč, 
   {{0x2249eea2,0x660c020c,0x23683f43,0xf544009d}},	//   dtak_, _dtak, edaj_, эдгү, 
   {{0x044038e0,0x660deea3,0x224801c4,0x15f8012d}},	//   керн, _etak, etak_, _एंकर_, 
   {{0x660c0003,0x23d4084c,0x98a401ee,0x00000000}},	//   _ftak, ецур, _ниһе, --, 
   {{0x680800bc,0x6fd81d55,0x07a0020a,0x2249eea4}},	// [37f80] _věde, síck, _шаън, gtak_, 
   {{0x3e3402d3,0x672c613c,0x6fd8ba0a,0x236801e4}},	//   _ኣርካይ, _zdaj, míci, adaj_, 
   {{0x65c0005e,0x6fd9eea5,0x4294001f,0x2248011f}},	//   _сұра, líci, መልከት_, atak_, 
   {{0xe6b401b9,0x660c00e4,0x00000000,0x00000000}},	//   _آلیگ, _ytak, --, --, 
   {{0x6fd9eea6,0x0dc8007b,0x2bcc00b8,0x00000000}},	//   níci, يبتى_, ावसा, --, 
   {{0xddc801e4,0x00000000,0x00000000,0x00000000}},	//   _freŭ, --, --, --, 
   {{0x52dc5b14,0x00000000,0x00000000,0x00000000}},	//   _मरुस, --, --, --, 
   {{0xc0e08340,0x5908031c,0x1ea8438b,0x200400f2}},	//   _роск, _གཅུས_, _کافي_, _élia_, 
   {{0xfe4048bd,0x2b98002e,0xc0400092,0x00000000}},	//   _инто, _wéco_, _ያልተለ, --, 
   {{0xc27805e1,0xabb407dd,0x6fd801f1,0xa815eea7}},	//   קריי, ьақә, díci, ндош, 
   {{0x2249b048,0x01340375,0xe8940024,0x2d8c2ffe}},	//   ztak_, ורית_, хань, _iode_, 
   {{0x2d8c0212,0x23680369,0x660c033f,0x2248b53c}},	//   _hode_, xdaj_, _ptak, ytak_, 
   {{0x4ae0060c,0x672c0010,0x23680978,0x6fd848f4}},	//   _परिव, _vdaj, vdaj_, rích, 
   {{0x2d8deea8,0x660c5a54,0x2368047e,0x00000000}},	//   _jode_, _vtak, wdaj_, --, 
   {{0x2d8deea9,0x6fd858bb,0x2368047e,0x2bac012d}},	//   _mode_, pích, tdaj_, eści_, 
   {{0x224830f9,0x660c2252,0xdd980209,0x2d8deeaa}},	//   ttak_, _ttak, _muňa_, _lode_, 
   {{0x2369c97b,0x6170001f,0xdb140066,0xdb080fac}},	// [37f90] rdaj_, _ለማውጣ, ébék, rneø, 
   {{0x22480552,0xdce001fa,0xd8b401ed,0x2d8deeab}},	//   rtak_, _salč, _آگیا_, _node_, 
   {{0x2249eeac,0xd4c00184,0xdce01a48,0x5574008f}},	//   stak_, _бөтк, _palč, _װערן_, 
   {{0x9f048073,0x22498b54,0x23680978,0x32f413bd}},	//   روتو, ptak_, qdaj_, ركەز, 
   {{0x1d0879a7,0x2d8deead,0xd3441550,0xdce1eeae}},	//   пели_, _bode_, _سیله_, _valč, 
   {{0xc0c8084c,0x71240014,0xdd9800a2,0x00000000}},	//   _дубе_, _لرِل, _buňa_, --, 
   {{0x6fd8c2f1,0x2d8c0373,0xdef800b0,0xdce0007f}},	//   zíci, _dode_, _laŋi_, _talč, 
   {{0x99d49fb2,0xefc800cf,0x3ab0104e,0x00000000}},	//   کتبا, _жуук_, кәлт, --, 
   {{0x2d8deeaf,0x3f9c198f,0xddc80311,0x00000000}},	//   _fode_, _iluu_, _creţ, --, 
   {{0x2d8c7a1e,0x394004cc,0x6fd80561,0x00000000}},	//   _gode_, üjs_, víci, --, 
   {{0x2bcc2e1e,0x2c24030d,0xaac40066,0x00000000}},	//   ावशा, _аьчг, فتین, --, 
   {{0x6fd859f9,0x2bac033f,0x00000000,0x00000000}},	//   tíci, yści_, --, --, 
   {{0xdb1800d2,0xddc80356,0x79c401b9,0x2bcc041c}},	//   _tjwâ, _greţ, _оқиб_, ावरा, 
   {{0xd9450be2,0x7bd9eeb0,0x6fd83cb4,0x00000000}},	//   _чеки, lluu, ríci, --, 
   {{0x3f9c208d,0x680800bc,0x2edc4c19,0x6fd8022a}},	//   _oluu_, _vědc, _बर्त, síci, 
   {{0xb4e005ba,0xdedc001f,0x7bd9487b,0x6fd80798}},	//   _तरी_, ሔርን_, nluu, píci, 
   {{0x7bd802f6,0xe63405f5,0xfbc431f0,0xe93802dd}},	// [37fa0] iluu, _ихээ, _ەت_, _ءسۇت_, 
   {{0x3f9deeb1,0x7bd801f4,0x10a4119e,0x2bac0210}},	//   _aluu_, hluu, низн, rści_, 
   {{0x3f9c1f74,0x2d8c0f85,0x75e00790,0x7bd81b99}},	//   _bluu_, _rode_, lözo, kluu, 
   {{0x53a40853,0x2d8deeb2,0x00e4036b,0xfae40035}},	//   _чамб, _sode_, رتلی, _مث_, 
   {{0x2d8c10b4,0xfd5400b8,0x7bd8058a,0xdd9800a2}},	//   _pode_, _hyaṣ, dluu, _suňa_, 
   {{0x3f9c0093,0x11140014,0xaca4063f,0x2d8c0009}},	//   _eluu_, _سِرس, stọr, _qode_, 
   {{0x2d8c0419,0x3f9c022f,0xc0e1b8dd,0x7bd95947}},	//   _vode_, _fluu_, _борк, fluu, 
   {{0x2d8c013b,0x7bd80357,0xddc8084c,0xc0f00023}},	//   _wode_, gluu, _preţ, ፍኩም_, 
   {{0x0a0802e3,0x66e802b5,0x2d8c0112,0xdb4c4732}},	//   _bụụr, _kūkū, _tode_, تێن_, 
   {{0x7a50cbdb,0xa2c03c16,0x7bd9eeb3,0xddc80311}},	//   اضيا, लपत्, aluu, _vreţ, 
   {{0x6dc400f7,0xfd54002b,0x7bd81b99,0x00000000}},	//   _كۅچۅ, _nyaṣ, bluu, --, 
   {{0x7bd801d9,0x2b9804e6,0x9abc002e,0xc76400d1}},	//   cluu, _méck_, saŋa, راجى, 
   {{0x81d4000e,0x2b9804e6,0xddc800d7,0x75e00205}},	//   াগত_, _léck_, _hreš, gözo, 
   {{0xddc9eeb4,0xdce024b8,0x00000000,0x00000000}},	//   _kreš, _halā, --, --, 
   {{0x6fd89ccb,0xa4d401ce,0x2b980036,0xdce1eeb5}},	//   lícu, тові, _néck_, _kalā, 
   {{0x7c300232,0x998c107d,0xdce000cd,0xf8d8011a}},	//   _údrž, mreš_, _jalā, _מחומ, 
   {{0x27e80664,0x6fd8215a,0xdce019ae,0x00000000}},	// [37fb0] _ihan_, nícu, _malā, --, 
   {{0xddc9eeb6,0xb6bc0375,0x65180532,0xdce000cd}},	//   _oreš, _מצחי, _تقدس_, _lalā, 
   {{0x6fd81280,0x31c41b88,0x27e9eeb7,0x3e84065f}},	//   hícu, уств, _khan_, کشاف, 
   {{0x2b980221,0xdce00055,0x9f3401ec,0x3c040051}},	//   _déck_, _nalā, теді, _bđvn_, 
   {{0x27e801ab,0xddc80024,0x75e001d3,0xaf040006}},	//   _mhan_, _areš, közl, упіл, 
   {{0xddc816a3,0x3d8827a8,0x00000000,0x00000000}},	//   _breš, ящен_, --, --, 
   {{0x27e9eeb8,0x2b980036,0x2258005a,0xdce000dc}},	//   _ohan_, _géck_, _hpsk_, _balā, 
   {{0x27e80016,0x3f9c03a0,0xe7e005f9,0x20105c71}},	//   _nhan_, _uluu_, _गीला_, _itzi_, 
   {{0x7bd80af5,0x2b980221,0xdce01c52,0xea94009d}},	//   rluu, _méch_, _dalā, гшээ, 
   {{0x27e801d9,0xddc839e2,0x75e1b740,0x00000000}},	//   _ahan_, _freš, gözl, --, 
   {{0xddc81326,0xb4e0033d,0x27e81554,0x2258020b}},	//   _greš, _तरे_, _bhan_, _lpsk_, 
   {{0x27e9eeb9,0x291805f7,0x6fd80789,0x68e401e4}},	//   _chan_, ðrar_, bícu, _ĝidt, 
   {{0x27e9eeba,0x31a40166,0x7f9003b9,0xddc83493}},	//   _dhan_, _yözd_, _uçqu, _zreš, 
   {{0x27e80156,0x201001ab,0x31a5eebb,0xfd540055}},	//   _ehan_, _otzi_, _köze_, _pyaṣ, 
   {{0x98a40cef,0x3a3c0140,0x27e80e9e,0x225800c0}},	//   _шике, luup_, _fhan_, _apsk_, 
   {{0x27e9eebc,0x36fc0135,0x6fd801f1,0xded40f7c}},	//   _ghan_, _དཔྲལ_, níct, ይልን_, 
   {{0x95c8006c,0x2b9804e6,0x3a3c0140,0x63c401e0}},	// [37fc0] _олиб_, _déch_, nuup_, уатҡ, 
   {{0xef942584,0x50b800ae,0x00000000,0x00000000}},	//   گیرد, وداد_, --, --, 
   {{0x01603ab6,0x00000000,0x00000000,0x00000000}},	//   ркхо, --, --, --, 
   {{0xee0c02e3,0x27e80240,0xef9401b9,0x1ea801e2}},	//   _aṅụr, _xhan_, دیرد, کامي_, 
   {{0xfe4073e6,0x7f8000c6,0x201001c6,0x3a3c013c}},	//   инцо, شلون, _etzi_, juup_, 
   {{0xddc9eebd,0xdce0005f,0xf00401c0,0x624801e4}},	//   _preš, _salā, _бүжи, _pɾov, 
   {{0x8bc5eebe,0xdce00a30,0x8eb00075,0x2fc400d8}},	//   ксид, _palā, _ھەتت, _tjmg_, 
   {{0x6fd9eebf,0x0ba82a8b,0xfbcc951b,0xddc80010}},	//   tícu, باتى_, يتي_, _vreš, 
   {{0x27e80cfd,0x3a3c0869,0x7d0c004d,0x4d64119e}},	//   _rhan_, guup_, _đcsv, _икав, 
   {{0x27e9eec0,0xddc9eec1,0x6fd825e6,0xff24037e}},	//   _shan_, _treš, rícu, _iosの, 
   {{0xf98c038b,0x6fd80005,0x31a4a697,0xba702be7}},	//   تبي_, sícu, _göze_, هایت, 
   {{0xdb1800d2,0x6d4804cc,0x75e0bd8f,0xd9400022}},	//   _tjwá, _hcda, sözl, аҵәи, 
   {{0x9ba00e76,0xbb44007b,0x1da800cd,0x00000000}},	//   _دەيى, _شلون_, _कतमत, --, 
   {{0x2b980221,0x27e80c3a,0x6e200042,0x998c0427}},	//   _séch_, _whan_, _mwmb, preš_, 
   {{0x27e820c6,0xdecc044e,0x2258037e,0x69d87a9c}},	//   _than_, _እዘን_, _spsk_, _ikve, 
   {{0x27e9eec2,0x26c4002f,0xdaa000d1,0xd8e40153}},	//   _uhan_, ßlos_, _خەۋپ, _сціп, 
   {{0xa5c4010b,0x6d48035a,0x00000000,0x00000000}},	// [37fd0] _бөве, _ocda, --, --, 
   {{0xe5e5eec3,0x290c123b,0xb1145fad,0x3f51eec4}},	//   _حزبی, ncda_, имуш, _ṣu_, 
   {{0xdce001e4,0x290c0014,0x2d9c0010,0xf6d401d3}},	//   _kolĥ, icda_, dkve_, _مزید, 
   {{0x6fd402bf,0x6d49eec5,0xff51ba02,0x00000000}},	//   аціє, _acda, شخص_, --, 
   {{0xdd95eec6,0x31a441b5,0x6e200042,0xb2842fe5}},	//   лады, _söze_, _cwmb, _кырк, 
   {{0xaca4044e,0x00000000,0x00000000,0x00000000}},	//   _ገይሮም_, --, --, --, 
   {{0x201005f5,0x3944009a,0x6f040f03,0xfd480ca8}},	//   _utzi_, _rcns_, žica, _kamẹ, 
   {{0xdfd434d8,0x69d8d6a8,0x3a3c0140,0x6d49eec7}},	//   _собы, _akve, tuup_, _ecda, 
   {{0x7ddc000f,0xae740014,0x290c0175,0x6a2400c7}},	//   nêsk, _پھنڈ, fcda_, азыҕ, 
   {{0x49c401c0,0x3a3c013c,0xdb08143a,0xae040131}},	//   ллын_, ruup_, dieå, _ئولى, 
   {{0xdb080267,0x3a3c0869,0x6808013a,0x98a40205}},	//   tieä, suup_, _dědo, telı_, 
   {{0x69d800df,0x3a3c0194,0x6fd80077,0x290c058a}},	//   _ekve, puup_, lícr, acda_, 
   {{0x69d803a0,0xdb0801e3,0x00000000,0x00000000}},	//   _fkve, rieä, --, --, 
   {{0xfd4801e1,0xd468d964,0xdb080013,0x2cb800d7}},	//   _aamẹ, ниге_, cneò, _žrdi_, 
   {{0x91b8000d,0x983400c0,0x00000000,0x00000000}},	//   _एगबै, _сэлі, --, --, 
   {{0xdce00311,0xd2500014,0x2b9801ef,0x00000000}},	//   _zală, ٝنر_, _péci_, --, 
   {{0x24640020,0xd174010b,0xd20400cf,0x00000000}},	// [37fe0] _ትውልድ_, лыжы, ابرى, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6fd80077,0x12e401ec,0x9474007b,0x00000000}},	//   dícr, тіңг, _إدخا, --, 
   {{0x624801e4,0x00000000,0x00000000,0x00000000}},	//   _pɾot, --, --, --, 
   {{0x947443fb,0xc7d40375,0x290c0175,0x4718010f}},	//   _شدگا, נוני_, ycda_, גונג, 
   {{0xd13001d9,0xa2c01408,0xf8cc000d,0x00000000}},	//   _دمس_, लपर्, _सु्प, --, 
   {{0xbd840202,0x2d9c03ca,0x00000000,0x00000000}},	//   انىن_, rkve_, --, --, 
   {{0x69d801a2,0x9f4c0004,0xb69002d3,0x2d9c8c7a}},	//   _skve, _pieå_, _ዝጸንሑ_, skve_, 
   {{0x601801e1,0xdce00051,0x6fd800d7,0x00000000}},	//   _túmò, _pală, sícs, --, 
   {{0x6d4806be,0x00000000,0x00000000,0x00000000}},	//   _ucda, --, --, --, 
   {{0x9f4c0589,0x6808012c,0x8154008f,0x00000000}},	//   _wieå_, _vědo, נסטע_, --, 
   {{0x67d4013e,0x4ae401b9,0x5ba40212,0x00000000}},	//   рому, _йўла, _кріз, --, 
   {{0xdce001e4,0xba700133,0x29c8014b,0x00000000}},	//   _volĥ, _هاوت, _аӣни_, --, 
   {{0x69d80212,0x2bcc1223,0x5ed000cc,0xdb080450}},	//   _ukve, ावका, তেকে, rieå, 
   {{0xddc80055,0xb808447d,0x75340118,0xf4840212}},	//   _apeś, _संयम_, _řezá, бутн, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7ddc019f,0x00000000,0x00000000,0x00000000}},	// [37ff0] bêsh, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe1e40490,0x241800ee,0xded40023,0x00000000}},	//   _कठीण_, _шоны_, ይውን_, --, 
   {{0x7f241d93,0x00000000,0x00000000,0x00000000}},	//   اءال, --, --, --, 
   {{0x6aa4031c,0x27f80216,0xdb1c01e1,0x00000000}},	//   _żifn, írny_, _òyéw, --, 
   {{0xdce005da,0x6d940de2,0x5bdc00dc,0x00000000}},	//   _lalą, _sàar, मत्व, --, 
   {{0x9624005f,0xdca401b9,0x98a4031c,0xc1e8000d}},	//   _ziņā, райи, ralċ_, _जीयब_, 
   {{0x6fd800d0,0x75e001d3,0x06a80154,0x00000000}},	//   sícr, tözk, _গুছি, --, 
   {{0x9df8edb4,0x00000000,0x00000000,0x00000000}},	//   _анат_, --, --, --, 
   {{0x69a40032,0xd04c03b9,0x00000000,0x00000000}},	//   йлыҡ, _aybə, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe9d800f7,0x00000000,0x00000000,0x00000000}},	//   ккө_, --, --, --, 
   {{0xdce005da,0x9594003b,0x00000000,0x00000000}},	//   _dalą, ашві, --, --, 
   {{0x2b980129,0xd04c03e3,0x42bc05ac,0x0a100244}},	//   _décu_, _eybə, _আৰ্শ, _بووح, 
   {{0x5fc5d8b3,0x1868014b,0x00000000,0x00000000}},	//   लचाल, _райи_, --, --, 
   {{0xd25086bf,0xdce00153,0x00000000,0x00000000}},	//   ينز_, _galą, --, --, 
  
   {{0x99dc02fb,0x114800f7,0x85000014,0x03a014b3}},	// [38000] stňu, кпай_, _ژوٝن, цито, 
   {{0x962400e2,0xb78801af,0x75e000e5,0x00000000}},	//   _viņā, _рәүе_, közi, --, 
   {{0xcf255e12,0x00000000,0x00000000,0x00000000}},	//   لرشي, --, --, --, 
   {{0x8fa406ed,0x5274004e,0x00000000,0x00000000}},	//   јаде, _кугу, --, --, 
   {{0xcfa80344,0x4365eec8,0x6f0400d7,0x0364004e}},	//   _یارم_, _таян_, žico, _тияк_, 
   {{0xd174e548,0x3ed02374,0x6c34007b,0xb4e0012d}},	//   _тымы, ڭقۇر, مفتا, _तरफ़_, 
   {{0x0c85eec9,0x0ba42310,0xbc6401eb,0x75e000a2}},	//   рылм, ишим, لمون_, gözi, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xaab812dd,0xfbcc15f2,0xbea000f7,0x680801ef}},	//   دگار_, بتو_, _датк, _vědm, 
   {{0xb994023a,0xddc800d0,0x49900244,0x00000000}},	//   ивых_, _preť, تیتر, --, 
   {{0x2b9806af,0x98a4007f,0xc198011a,0xdce0012d}},	//   _sécu_, balč_, דשיי, _palą, 
   {{0xcb680261,0x2cf40073,0xc6a5eeca,0x00000000}},	//   _јаде_, ेखील_, арги, --, 
   {{0xf98c0bce,0x8cd80037,0x00000000,0x00000000}},	//   سبی_, _पुतो, --, --, 
   {{0x2b98f20f,0xddc80030,0x25a401a8,0x38700162}},	//   _vécu_, _treť, óll_, ðarí_, 
   {{0x7b040066,0x00000000,0x00000000,0x00000000}},	//   _èsté, --, --, --, 
   {{0x248c0bb8,0xc7b80108,0x98c400d4,0x00000000}},	//   ćem_, _шёл_, _усіл, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [38010] --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa3d5eecb,0xe038084c,0x00000000,0x00000000}},	//   _гонч, узеч_, --, --, 
   {{0xd460044e,0x6b8400a3,0x00000000,0x00000000}},	//   _ስልጣኑ_, _òigh, --, --, 
   {{0xdb080118,0x00000000,0x00000000,0x00000000}},	//   áníc, --, --, --, 
   {{0xdca400d1,0x43740139,0xa30800e5,0x5ca400db}},	//   йали, _суүт, _جرگے_, йилб, 
   {{0xf1b005d9,0xdb08219b,0x4c900063,0x6808013a}},	//   _آءُ_, šníc, зијс, _dědk, 
   {{0xdd9800a2,0x00000000,0x00000000,0x00000000}},	//   _muňi_, --, --, --, 
   {{0x29182c6f,0xa0a4005e,0x7f580b6f,0x5974f198}},	//   ıran_, _таңд, _ibuq, быну, 
   {{0x7e7918c9,0xd9440640,0x198802e8,0xaac40145}},	//   _irup, љени, убои_, تتىن, 
   {{0x7e780219,0x2b98013a,0x00000000,0x00000000}},	//   _hrup, _péct_, --, --, 
   {{0x997c00bc,0x1b20015b,0xdb0c0241,0x59d40118}},	//   pňů_, _যাকে_, _àkàt, ठकहर, 
   {{0x96b80228,0xfc5c0023,0xe7b00137,0x00000000}},	//   ууну_, ጋግጸል, بۅيد, --, 
   {{0x3a3ce3d4,0x7e780139,0x00000000,0x00000000}},	//   mrup_, _mrup, --, --, 
   {{0x7f581cdf,0x798003ac,0xdb080036,0x3a3c014f}},	//   _obuq, _innw, jheë, lrup_, 
   {{0x4430011c,0x7e780083,0x00000000,0x00000000}},	//   _dvx_, _orup, --, --, 
   {{0x15b80184,0x3a3deecc,0xd7c800f1,0xf2c400c7}},	// [38020] _быны_, nrup_, _ټوکه_, циаҿ, 
   {{0x7f580117,0xdb080254,0x00000000,0x00000000}},	//   _abuq, mneõ, --, --, 
   {{0x7e79eecd,0x3a3c016d,0x3d083042,0x647400c0}},	//   _arup, hrup_, ाशने_, _дыяф, 
   {{0x4ea40323,0x7e780158,0x3a3c0263,0xfd1c0208}},	//   йрла, _brup, krup_, _đìa_, 
   {{0x7e781caa,0x529800a7,0x3a3c047e,0x527400db}},	//   _crup, _съня_, jrup_, _ууну, 
   {{0x7f58379d,0x3a3deece,0x8658011a,0x64400174}},	//   _ebuq, drup_, רדסי, álig, 
   {{0x3a3c0728,0x680801ef,0xfe6c00e5,0x00000000}},	//   erup_, _vědk, وگے_, --, 
   {{0x7981eecf,0x7e79eed0,0x4f94887d,0x00000000}},	//   _annw, _frup, _ургу, --, 
   {{0x3a3deed1,0x7bc801f5,0x00000000,0x00000000}},	//   grup_, _djgu, --, --, 
   {{0x7980035a,0x2b98afc7,0x00000000,0x00000000}},	//   _cnnw, _pécs_, --, --, 
   {{0xeff002d3,0x3a3c9f5c,0xd82c00ec,0x00000000}},	//   _ልሙድ_, arup_, نڍي_, --, 
   {{0x798004ba,0x4789eed2,0x7e79eed3,0x3a3c047e}},	//   _ennw, усом_, _yrup, brup_, 
   {{0x44300175,0x7b84247f,0xef48001f,0xaa940395}},	//   _svx_, _دالە, _መኮንኖ, _филч, 
   {{0x86e407d6,0x443001f5,0x3a340a1e,0x28880066}},	//   _қўйд, _pvx_, _פרום_, _نصبی_, 
   {{0x69c9eed4,0xf485eed5,0xf98c1699,0x00000000}},	//   mnde, путн, _سبو_, --, 
   {{0x69c803fa,0x7ddc000f,0x44300327,0x61d0043e}},	//   lnde, lêst, _vvx_, तक्ष, 
   {{0x69c9eed6,0xf7701473,0x98a41a14,0x79800142}},	// [38030] onde, _ساي_, malā_, _ynnw, 
   {{0x64400228,0x69c9eed7,0x661c4bc1,0x6d5801f5}},	//   àlis, nnde, mpsk, jfva, 
   {{0x64402d3f,0xddc80356,0x661c0010,0x00000000}},	//   álid, _apeş, lpsk, --, 
   {{0x69c9e4b2,0x98a4166a,0x7e79eed8,0x645400ca}},	//   hnde, nalā_, _prup, mtzi, 
   {{0x63adeed9,0x7e7803be,0x39980b21,0x64547765}},	//   mhan, _qrup, _kêst_, ltzi, 
   {{0x63adeeda,0x69c9eedb,0x657407a9,0x3a3c014f}},	//   lhan, jnde, ndzh, vrup_, 
   {{0x6454152d,0xa2c054cb,0x3998000f,0x98a40f40}},	//   ntzi, लपक्, _mêst_, kalā_, 
   {{0x69c9eedc,0xa3e8726e,0x39980a85,0x3a3deedd}},	//   ende, यति_, _lêst_, trup_, 
   {{0x7ddc0385,0x63adeede,0x661c01f5,0x64540112}},	//   fêst, ihan, jpsk, htzi, 
   {{0x3a3deedf,0x69c9eee0,0x39980b21,0x3b1c05b1}},	//   rrup_, gnde, _nêst_, sbuq_, 
   {{0x63ac5a6a,0xa3e81428,0x5c740276,0x3a3c014f}},	//   khan, यता_, _флет, srup_, 
   {{0x63ac2784,0x7bc8e6a1,0x628c009a,0x7f48cdcc}},	//   jhan, _ujgu, kxao, nggq, 
   {{0x63adeee1,0x39980a85,0x3a3c047e,0xcf54011a}},	//   dhan, _bêst_, qrup_, חברת_, 
   {{0x63adeee2,0x98a5eee3,0x18a50fb9,0x6454002f}},	//   ehan, _миле, _малм, ftzi, 
   {{0x63adeee4,0x6e3402d3,0x98a40b13,0x7bd80270}},	//   fhan, _ኣይንኽ, balā_, oouu, 
   {{0x63adeee5,0x7bd80810,0x98a40055,0x00000000}},	//   ghan, nouu, calā_, --, 
   {{0x39980a85,0x7ddc045f,0x6f05eee6,0x3320058a}},	// [38040] _fêst_, nêss, žick, rbix_, 
   {{0x63adeee7,0x0f2006ab,0xb3580133,0x7bd80129}},	//   ahan, मर्स_, _گیرا_, houu, 
   {{0x10695c71,0x4f09eee8,0x7bd96817,0xc0e40014}},	//   рией_, анен_, kouu, ۅکہٕ_, 
   {{0x63ac2c42,0x69c80369,0x225c0118,0xa488009f}},	//   chan, znde, ízký_, _اَٽل_, 
   {{0x69c9eee9,0xdd98002e,0x61e401ab,0x75e000e5}},	//   ynde, _luňu_, blhl, bözt, 
   {{0x644001f1,0x85f8002b,0x00000000,0x00000000}},	//   šlie, _kīrṇ, --, --, 
   {{0x8fa469e2,0xfc2c00ec,0xd01001d5,0xbd6410da}},	//   _даве, نحي_, _آلر_, ірше_, 
   {{0x69c80368,0x6d5805b1,0x661deeea,0x2918afeb}},	//   wnde, sfva, ypsk, ıram_, 
   {{0x8cd80825,0x69c803b2,0x00000000,0x00000000}},	//   _पुरो, tnde, --, --, 
   {{0x69c80226,0x63adeeeb,0xdd9800e8,0x65b00241}},	//   unde, zhan, _buňu_, _móhù, 
   {{0x69c8a7b3,0x39980b21,0x2004003e,0x7ddc045f}},	//   rnde, _rêst_, _élit_, rêst, 
   {{0xdd98002e,0x63ac036e,0xdc9800db,0x8b3000e5}},	//   _duňu_, xhan, _утуш_, _کہکش, 
   {{0x63ac1aa1,0x69c80369,0x19a801e0,0x0e3c0023}},	//   vhan, pnde, ртөп_, _ኣይኣም, 
   {{0x63adeeec,0x69c80369,0x64541196,0xeaf80073}},	//   whan, qnde, ttzi, ुशीत_, 
   {{0x65740004,0x85f8002b,0x3d0800cd,0xa84800ae}},	//   rdzh, _cīrṇ, ाशते_, _العم_, 
   {{0x661c6066,0x645405f5,0x63adeeed,0x3998002d}},	//   ppsk, rtzi, uhan, _wêst_, 
   {{0x63ac66e7,0xe8100c2e,0x64540196,0x27f8062c}},	// [38050] rhan, _ठंडा_, stzi, mmsn_, 
   {{0x63adeeee,0x64540295,0x6b840332,0x00000000}},	//   shan, ptzi, _óigf, --, 
   {{0x35f8175f,0x672c2831,0x660c2bae,0x63ac1fd8}},	//   _بريد_, _keaj, _huak, phan, 
   {{0x63ac094a,0x660401f4,0x00000000,0x00000000}},	//   qhan, _hihk, --, --, 
   {{0x660405b1,0x3e68eb89,0x2368010f,0x00000000}},	//   _kihk, ршен_, meaj_, --, 
   {{0x98a400a8,0x660c18f7,0x224801c6,0x6aa00368}},	//   nală_, _muak, muak_, dymf, 
   {{0x224805f5,0x660c123c,0x6605eeef,0x8cbc687b}},	//   luak_, _luak, _mihk, _वेदो, 
   {{0x672deef0,0xdd9001d3,0x23680115,0x98a4054e}},	//   _neaj, ظوں_, neaj_, hală_, 
   {{0x224801c0,0x660c0194,0x0f31eef1,0x7bd80108}},	//   nuak_, _nuak, _سکند, rouu, 
   {{0xae44034c,0x8308031c,0x66046775,0xeda40fc0}},	//   _آپلو, _ཀུའུ_, _nihk, _ошхо, 
   {{0x660deef2,0x672c0489,0x63bc002d,0x224801c4}},	//   _auak, _beaj, _omsn, huak_, 
   {{0x660deef3,0x224801c0,0x00000000,0x00000000}},	//   _buak, kuak_, --, --, 
   {{0xa3c12717,0x660c003e,0x224801c6,0x672c0356}},	//   ्चन_, _cuak, juak_, _deaj, 
   {{0x224801c0,0x660deef4,0x98a40276,0x6d5c0205}},	//   duak_, _duak, gală_, _ırak, 
   {{0x18a42d7f,0x680801ef,0x00000000,0x00000000}},	//   _хайм, _bědu, --, --, 
   {{0x660c1132,0xd774bfae,0x88380375,0xd7c80133}},	//   _fuak, _رابع, _התקו, _دوبه_, 
   {{0x660c0022,0x63bc010a,0x224801c6,0x98a4054e}},	// [38060] _guak, _dmsn, guak_, bală_, 
   {{0x867805e1,0x64410053,0x98a4084c,0x63bc0175}},	//   _פריו, álic, cală_, _emsn, 
   {{0x7f34044e,0xddc81a48,0x63bc0175,0x23680240}},	//   _ከምዝኽ, _brež, _fmsn, beaj_, 
   {{0x2249eef5,0xe1f00131,0x236801e4,0xd2f801c6}},	//   buak_, ىسە_, ceaj_, _гэгч_, 
   {{0x1ae00183,0xff001fe2,0xddc80841,0xdd0002b1}},	//   খেতে_, няшн, _drež, _ātār, 
   {{0x86340677,0x00000000,0x00000000,0x00000000}},	//   לאנג_, --, --, --, 
   {{0xf00405f5,0xda10000d,0x3d3000cf,0x00000000}},	//   _жүжи, _डूबत_, رعوس, --, 
   {{0xea180a0e,0xddc80064,0x98a40356,0x3b5002e8}},	//   ожиш_, _grež, zală_, екър, 
   {{0xe9448117,0x672deef6,0x2004004e,0xeee401b9}},	//   وردی, _reaj, _èlia_, _آغزی, 
   {{0x672c0810,0x660deef7,0xddc80427,0x98a40356}},	//   _seaj, _ruak, _zrež, xală_, 
   {{0x672dbdd0,0x224801c0,0x98a40311,0xbd301075}},	//   _peaj, zuak_, vală_, _سىنع, 
   {{0x660deef8,0x2248005a,0x00000000,0x00000000}},	//   _puak, yuak_, --, --, 
   {{0x660c1590,0x98a4084c,0xdce0008f,0x660425c6}},	//   _quak, tală_, _malĝ, _pihk, 
   {{0xe944104a,0x660deef9,0x63bc008b,0x66e00a8a}},	//   _آرشی, _vuak, _smsn, _गुणक_, 
   {{0x98a4084c,0x660425e4,0xd318063f,0x660c6085}},	//   rală_, _vihk, _ọtụr, _wuak, 
   {{0x22480323,0x660deefa,0xdd0002b5,0x98a40356}},	//   tuak_, _tuak, _ōtīr, sală_, 
   {{0x25082633,0x98a40276,0x236800df,0x66041577}},	// [38070] _وردی_, pală_, reaj_, _tihk, 
   {{0x224805f5,0xddc8010f,0x236801e4,0xf31401c6}},	//   ruak_, _pseŭ, seaj_, _үдээ, 
   {{0xddc9eefb,0x224801c0,0x6e3c001f,0x9f54109a}},	//   _prež, suak_, _አልገባ, двеч, 
   {{0xdb18019f,0x63bc06a3,0x2248009d,0xece000ab}},	//   _amwî, _umsn, puak_, _फड़फ, 
   {{0xee3800d6,0xddc8009b,0xdb08002f,0x00000000}},	//   зні_, _vrež, rieü, --, 
   {{0xdb0801f5,0x00000000,0x00000000,0x00000000}},	//   theï, --, --, --, 
   {{0x91c0151e,0xefdc0023,0x00000000,0x00000000}},	//   _рәтл, _ንወዲ_, --, --, 
   {{0x64c4107d,0x98a40024,0xdaa801a9,0x00000000}},	//   _ičić, nalą_, жвид_, --, 
   {{0x5d55eefc,0x75e001d3,0xb34406be,0x2ea806b1}},	//   _окат, közp, _qoçə, कनृत, 
   {{0x09f4007b,0x00000000,0x00000000,0x00000000}},	//   وفية_, --, --, --, 
   {{0x98a40024,0x00000000,0x00000000,0x00000000}},	//   kalą_, --, --, --, 
   {{0xc5e400fe,0xc3200154,0x00000000,0x00000000}},	//   _গংগা_, বৃতি_, --, --, 
   {{0x26cc0241,0x98a400c0,0x00000000,0x00000000}},	//   _àjo̟_, dalą_, --, --, 
   {{0xe9d8005e,0x6b840192,0x4e2000fe,0x00000000}},	//   _екі_, _òigr, _নিমখ_, --, 
   {{0xdce00166,0x84e001c6,0xe51c000d,0xa3e800cd}},	//   _kolı, ворж, बुधि_, यतं_, 
   {{0x644174e4,0x13f81524,0x98a400c0,0x00000000}},	//   ália, ्देह_, galą_, --, 
   {{0xd5b0cea5,0x60d402d0,0x86680023,0x6b840332}},	// [38080] _لفظ_, _axzm, ሳተፍቲ_, _óige, 
   {{0x10a402af,0x6440a2ef,0x8d800092,0x99dc013a}},	//   мизн, šlia, ናኝተው_, duňk, 
   {{0xc3242e51,0xd1b00014,0x98a400c0,0x8f0814a3}},	//   سكەن_, _ییرک, balą_, охла_, 
   {{0xa3e817c6,0xddc8031c,0x2054084c,0x44780a7c}},	//   यतः_, _ereż, этур, _ונטע, 
   {{0xfe6deefd,0x63786135,0x00000000,0x00000000}},	//   لدو_, _эсэр_, --, --, 
   {{0x9e64237e,0xddd80100,0x6c54004e,0x00000000}},	//   عانن, ntwň, екку, --, 
   {{0xdce0008e,0x25ac0de2,0x00000000,0x00000000}},	//   _bolı, ëeli_, --, --, 
   {{0x3179eefe,0x8aa40212,0x7c8193a0,0x99dc01ef}},	//   _harz_, дрод, туше, buňk, 
   {{0x317800ee,0xaf4800f1,0x00000000,0x00000000}},	//   _karz_, _وشړل_, --, --, 
   {{0x291808e7,0x00000000,0x00000000,0x00000000}},	//   ùra_, --, --, --, 
   {{0x3179eeff,0xc90c0412,0xe94400f2,0x00000000}},	//   _marz_, _सलीम_, ورگی, --, 
   {{0x317812ba,0xcb680276,0x00000000,0x00000000}},	//   _larz_, _фаде_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x44280153,0x66140014,0xdce0013d,0x98a40210}},	//   жцам_, ٘ژھا, _zolı, walą_, 
   {{0xddc8031c,0x31a400ee,0xdce00139,0x00000000}},	//   _rreż, _gözi_, _yolı, --, 
   {{0x60d405b1,0xdce0013d,0x78a4005c,0x46680108}},	//   _rxzm, _xolı, øjve, _дром_, 
   {{0xddc8003d,0x3179ef00,0xf64405f5,0x8234c35c}},	// [38090] _preż, _barz_, _ихэн, برزا, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x317801a9,0xe454013d,0x98a43f05,0x00000000}},	//   _darz_, _якны, palą_, --, 
   {{0xa294160b,0x78f8008f,0xdb200fac,0x00000000}},	//   _замі, קלאפ, _åtør, --, 
   {{0x3179ef01,0x3d080118,0x00000000,0x00000000}},	//   _farz_, ाशले_, --, --, 
   {{0x23784536,0x31780165,0x99dc0118,0xdce0008e}},	//   _hasj_, _garz_, ruňk, _solı, 
   {{0x64c4009b,0x2130030a,0x8d900b38,0xdce1ef02}},	//   _učić, _iezh_, الىش, _dalğ, 
   {{0xc0cc02d3,0xad140075,0xdce00166,0x0d600150}},	//   ኣክል_, нпәә, _qolı, _ەگيپ, 
   {{0xb4bc2871,0x31a40209,0x00000000,0x00000000}},	//   _अध्_, _sözi_, --, --, 
   {{0xad240075,0x2011ef03,0xadf43671,0x00000000}},	//   _لىكى, _kuzi_, _апуш, --, 
   {{0xdb50f703,0xa3c01431,0x2011ef04,0x21300156}},	//   _مَا_, ्चा_, _juzi_, _mezh_, 
   {{0x201134bb,0xba7400d1,0xd774007b,0xdce00166}},	//   _muzi_, _ياشت, راجع, _zalğ, 
   {{0x2011ef05,0x6440fde4,0xd944030d,0xdce000fd}},	//   _luzi_, álin, _зели, _yalğ, 
   {{0xceb164c8,0x201002e2,0xf9c5ef06,0x31a4008e}},	//   נים_, _ouzi_, _ющен, _tözi_, 
   {{0x6808013a,0x00000000,0x00000000,0x00000000}},	//   _vědr, --, --, --, 
   {{0x3178382f,0x21300165,0xddd80100,0x85000014}},	//   _sarz_, _aezh_, stwň, اوِن, 
   {{0x20112bbd,0x21300dd4,0x8228031c,0xd185ef07}},	// [380a0] _auzi_, _bezh_, _སྦྱི_, нлай, 
   {{0x4f38069c,0x2011ef08,0x317801b9,0x00000000}},	//   _ከምዘይ, _buzi_, _qarz_, --, 
   {{0x65c0005e,0x25a402f6,0xa5040124,0x201000d8}},	//   _тұра, ölle_, _аҵра_, _cuzi_, 
   {{0x201005a1,0x2fc001c3,0xdce0008e,0x00000000}},	//   _duzi_, òig_, _salğ, --, 
   {{0x7764014b,0x21300156,0x317805d1,0x82a001c0}},	//   _mbix, _fezh_, _tarz_, _баяж, 
   {{0xc90c0034,0xdce000fd,0x4638010f,0x8fa40022}},	//   _सलेम_, _qalğ, לענע, ьаҵе, 
   {{0x20100e04,0xb808072a,0xc1b00166,0x99dc00d7}},	//   _guzi_, _संगम_, _сәты, erňo, 
   {{0x9518031c,0xc0e10872,0x00000000,0x00000000}},	//   _ྱུའི_, _соск, --, --, 
   {{0x213007e4,0x2010043b,0xdce00166,0x98a40064}},	//   _yezh_, _zuzi_, _talğ, malę_, 
   {{0x776401c4,0x6e2002d0,0x20103149,0xafe401b9}},	//   _abix, _itmb, _yuzi_, _чоғл, 
   {{0x2d8def09,0xdde8006c,0x4b2400d8,0x00000000}},	//   _inde_, _آرقه_, _змев, --, 
   {{0xe8c83004,0xa92400d0,0x8884009d,0x00000000}},	//   згүл_, deľň, _үлдж, --, 
   {{0x37a805f5,0x9ba000d1,0x00000000,0x00000000}},	//   хтэн_, _خەيى, --, --, 
   {{0x9f4c00ae,0x00000000,0x00000000,0x00000000}},	//   _mheá_, --, --, --, 
   {{0xdb0800c6,0x2d8c017a,0xf990008f,0x21300165}},	//   mheá, _mnde_, _תרצ_, _rezh_, 
   {{0x2011ef0a,0x427c02d3,0x00000000,0x00000000}},	//   _ruzi_, _ብርክት_, --, --, 
   {{0x2d8def0b,0x201006ee,0x213003bd,0x490005f5}},	// [380b0] _onde_, _suzi_, _pezh_, _шүүг, 
   {{0x20100fcf,0x44200ffb,0x7178ae2b,0x00000000}},	//   _puzi_, ppj_, нбур_, --, 
   {{0x6e200083,0x21300156,0x2010013d,0x00000000}},	//   _atmb, _vezh_, _quzi_, --, 
   {{0x21300489,0xd3440133,0x03bc00cc,0x98a400c0}},	//   _wezh_, _لیفه_, _আৱৰণ, galę_, 
   {{0xdd94de69,0x53980375,0xdb200393,0x733800ee}},	//   кады, _חירו, _ætér, _язяр_, 
   {{0x2010015c,0x00000000,0x00000000,0x00000000}},	//   _tuzi_, --, --, --, 
   {{0xe810012c,0xdc7412c4,0x224800a2,0x00000000}},	//   _ठूला_, тыль, lrak_, --, 
   {{0x2d8def0c,0x291c007f,0x6d5c00b0,0xdd90014d}},	//   _ende_, _afva_, _öran, _ھوا_, 
   {{0x2d8c00d8,0x2a3419bb,0x7e280111,0xaffc010a}},	//   _fnde_, лээр, _хіба_, _хотi, 
   {{0x2249ef0d,0x49c46135,0xdb080332,0xc1bc000d}},	//   irak_, клын_, gheá, _एगोग, 
   {{0xb604038e,0x3f9cd481,0x64400122,0x3dc400d2}},	//   ntář, _kouu_, álil, minw_, 
   {{0x2249ef0e,0x99d4dd80,0x68fc03b2,0x00000000}},	//   krak_, عتکا, ýrda, --, 
   {{0x1ca404d3,0x224801fa,0x31a401ed,0xdb08007b}},	//   _سێکی_, jrak_, _közt_, bheá, 
   {{0xdb18019f,0xdb08007b,0xd9444727,0xa9240030}},	//   _umwâ, cheá, _реки, teľň, 
   {{0x224805f5,0xe80005d7,0x00000000,0x00000000}},	//   erak_, ोदशा_, --, --, 
   {{0x6379ef0f,0x2c7c012c,0x7764058a,0x8cd40073}},	//   нсур_, ládá_, _ubix, मॅटो, 
   {{0x261809d9,0xe8000034,0xd5d40166,0xd174010b}},	// [380c0] _यूपी_, ोदरा_, _аюны, кыжы, 
   {{0xa92401f1,0x7ae80006,0x0634010f,0x98a40210}},	//   peľň, _mygt, _שניט_, walę_, 
   {{0x7ae9ef10,0x2248011f,0x50588727,0xdce00171}},	//   _lygt, arak_, ьшая_, _malē, 
   {{0x224978bb,0xd25021de,0x53a457e5,0x8898011a}},	//   brak_, _پنس_, _рамб, ובעי, 
   {{0xa3c002e5,0x7ae80209,0x2249dfe9,0x98a43f05}},	//   ्चर_, _nygt, crak_, ralę_, 
   {{0xd1300346,0x8c640107,0x00000000,0x00000000}},	//   _خمس_, втид, --, --, 
   {{0x2d8c16b8,0x8fd00166,0x00000000,0x00000000}},	//   _vnde_, _кәдә, --, --, 
   {{0x6b7401c6,0xc4d00375,0xbb800145,0x7e8c00d1}},	//   улиу, יגו_, للىي, ﺑﺒﻪﺕ_, 
   {{0x4e059465,0x9e65b04d,0xc054001f,0x69c400db}},	//   _азаб, _مالن, _ያልተገ, лөкб, 
   {{0x2d8db876,0x7ae804ce,0x2d9800c7,0xc7640116}},	//   _unde_, _dygt, _õre_, ھاجى, 
   {{0x2249ef11,0xc7d40208,0x3e541954,0xe75800d4}},	//   zrak_, _ởđâu_, _ወልደየ, нині_, 
   {{0x2249ef12,0xbb4000d8,0x644000d7,0x00000000}},	//   yrak_, _вецк, álim, --, 
   {{0x2c7c1a5e,0x00000000,0x00000000,0x00000000}},	//   bádá_, --, --, --, 
   {{0xdbd00008,0x18180214,0xa7fc0790,0xdce000de}},	//   lýðs, بریک_, ktıg, _galē, 
   {{0x22480209,0xa3c000ce,0xb5940022,0x00000000}},	//   wrak_, ्चल_, ширш, --, 
   {{0x224827f8,0x3dc4007f,0xdb0801e3,0x2bb80456}},	//   trak_, zinw_, rieö, इफटा, 
   {{0x27e9ef13,0x69c9ef14,0x60980214,0xb9d80092}},	// [380d0] _ikan_, oide, کناس_, _አቻ_, 
   {{0x69c9ef15,0x2249ef16,0x128801a9,0x3f9c01c7}},	//   nide, rrak_, عملی_, _souu_, 
   {{0x69c80014,0x27e801a9,0x2249ef17,0x00000000}},	//   iide, _kkan_, srak_, --, 
   {{0x2249ef18,0x69c9ef19,0x25a00b70,0x00000000}},	//   prak_, hide, _hohl_, --, 
   {{0x63adef1a,0x69c9ef1b,0x250861f4,0x9d44f1c2}},	//   mkan, kide, _ترکی_, гелд, 
   {{0x2900008f,0x7ae8037e,0x6d5c0309,0x27e8022e}},	//   _ĝian_, _rygt, _öral, _lkan_, 
   {{0x61e4b578,0x27e9ef1c,0x25a0012c,0x3f9c0270}},	//   mohl, _okan_, _mohl_, _touu_, 
   {{0x61e5ef1d,0xdb0803b7,0x69c8b49a,0xfe70034c}},	//   lohl, nheç, eide, _پدر_, 
   {{0x1a640517,0x69c9ef1e,0xdce1ef1f,0x9aa4446a}},	//   ایتی_, fide, _palē, امخو, 
   {{0x27e9ef20,0x69c9ef21,0x63adef22,0x61e5ef23}},	//   _akan_, gide, hkan, nohl, 
   {{0x27e80a2e,0x200c138f,0x64400063,0xad240131}},	//   _bkan_, _kiei_, šlij, _ئىمى, 
   {{0x61e5ef24,0x7ae8007c,0x00000000,0x00000000}},	//   hohl, _tygt, --, --, 
   {{0x69c8152d,0x61e5ef25,0x200def26,0x63adef27}},	//   bide, kohl, _miei_, dkan, 
   {{0x63adef28,0x27e8006c,0x69c980a5,0x61e401af}},	//   ekan, _ekan_, cide, johl, 
   {{0x63adef29,0x61e5ef2a,0xa3c007b7,0x00000000}},	//   fkan, dohl, ्चं_, --, 
   {{0x63ac13e1,0x969463e6,0x200c054e,0xded4010c}},	//   gkan, _брош, _niei_, ክልን_, 
   {{0x61e5ef2b,0xded402d3,0xcb10010f,0x00000000}},	// [380e0] fohl, _ክፉእ_, מלן_, --, 
   {{0x63addd2c,0x25a004cc,0x61e5ef2c,0x11d8007b}},	//   akan, _gohl_, gohl, روضة_, 
   {{0x63ad93d5,0x200c01c4,0xcc10012d,0x4f2435ce}},	//   bkan, _biei_, _ढूंढ_, гдеб, 
   {{0x69c9ef2d,0x63adef2e,0x27e80ac5,0x670001f2}},	//   zide, ckan, _xkan_, ịkeb, 
   {{0x61e5ef2f,0x2d580474,0x200c1730,0x25b40024}},	//   bohl, виль_, _diei_, šalų_, 
   {{0x200c06a3,0xa7fc0790,0x69c9ef30,0x56a00092}},	//   _eiei_, ptıg, xide, _ልዩነቱ_, 
   {{0x6d5c0086,0xbd4000cf,0x00000000,0x00000000}},	//   _öram, حنىي, --, --, 
   {{0x69c9ef31,0xd1e4001f,0xbc64951b,0xbb24009d}},	//   wide, ማዎች_, امين_, лцье_, 
   {{0x4c9001a9,0x00000000,0x00000000,0x00000000}},	//   риқс, --, --, --, 
   {{0x63adef32,0x27e9ef33,0x644000d0,0x69c83beb}},	//   zkan, _skan_, álik, uide, 
   {{0x63adef34,0x0c240d08,0xf9640474,0x00000000}},	//   ykan, _смен, урый_, --, 
   {{0x61e5ef35,0x63ac01c6,0x6440005f,0xcb14007b}},	//   zohl, xkan, šlik, _إذاع, 
   {{0xb8e83eb6,0xc9845026,0x61e5ef36,0xc68c004b}},	//   _रे_, _буйи, yohl, سېد_, 
   {{0x2d9c044e,0x63adef37,0x69c80009,0x61e401a9}},	//   njve_, wkan, qide, xohl, 
   {{0x63adef38,0x61e401b9,0x69d801a4,0x27e801a9}},	//   tkan, vohl, _ijve, _tkan_, 
   {{0x25a00639,0x61e5ef39,0x27e9ef3a,0x477000d1}},	//   _wohl_, wohl, _ukan_, _уқму, 
   {{0x63ac33c1,0xa1580022,0xade41fc4,0xb77c00df}},	// [380f0] rkan, каау_, गवान_, _טאהש, 
   {{0x63adef3b,0x00000000,0x00000000,0x00000000}},	//   skan, --, --, --, 
   {{0x63ac6ea0,0x200c0356,0xb2e801d9,0xa074008e}},	//   pkan, _piei_, نٹہٕ_, ргеч, 
   {{0x61e41cdf,0x38b80241,0xf0e800d1,0x99600171}},	//   sohl, _háré_, دىمى_, cīņu_, 
   {{0x61e402f0,0x200c0356,0xef1800d4,0x00000000}},	//   pohl, _viei_, умі_, --, 
   {{0xe7d004a2,0x200c016b,0x80bc02f5,0x2d9c036e}},	//   ﺗﺎﺭﻟ, _wiei_, ্থব্, gjve_, 
   {{0x200c013f,0x00000000,0x00000000,0x00000000}},	//   _tiei_, --, --, --, 
   {{0x69d80477,0x2d980086,0xdfd40220,0x44300175}},	//   _ajve, _òren_, _тобы, _mwx_, 
   {{0x9f4c0004,0x64400010,0x00000000,0x00000000}},	//   _cheå_, šlih, --, --, 
   {{0xc9a40a8f,0xd9440063,0x19c4009b,0x6288025c}},	//   ивые_, јени, рбом, _ġeol, 
   {{0x38ac24ba,0x00000000,0x00000000,0x00000000}},	//   dörö_, --, --, --, 
   {{0xd7041b6d,0xf7780022,0x5fb40210,0x00000000}},	//   изни, уҧи_, ंसिल, --, 
   {{0x2bb80597,0x38b801e1,0x8f98011a,0x57c4000d}},	//   _حالة_, _báré_, דירי, _लगीह, 
   {{0x27e00115,0x3b1c03b9,0xdef00092,0x00000000}},	//   _ĉine_, lcuq_, ልልና_, --, 
   {{0x13a40133,0x00000000,0x00000000,0x00000000}},	//   لۆدی_, --, --, --, 
   {{0x53a41ee3,0x7e7809a8,0xdb0c0241,0x3b1c06be}},	//   шабб, _osup, _àkót, ncuq_, 
   {{0x7e780161,0x4220bec3,0x130802d5,0x3a3c0790}},	// [38100] _nsup, ждув, тнай_, nsup_, 
   {{0x44300097,0x3a3c20ac,0x55880022,0x00000000}},	//   _fwx_, isup_, _рбом_, --, 
   {{0x7e79ef3c,0x753c0950,0xa9e40131,0x660801f5}},	//   _asup, marz, ﻏﺮﯨﺴ, ïeke, 
   {{0x4ea5ef3d,0x0ea894f8,0x7e7801af,0x753c0034}},	//   ирла, ккей_, _bsup, larz, 
   {{0xdce002d5,0x7e79ef3e,0x4718008f,0xa7fc05d1}},	//   _kalė, _csup, דונג, ltıc, 
   {{0x753def3f,0x6b8002d0,0x00000000,0x00000000}},	//   narz, wdmg, --, --, 
   {{0x7e78b9d2,0xefcc02d3,0x10a4dfe7,0x7dc04cd0}},	//   _esup, _ጠጠው_, _тивн, تقون, 
   {{0xd9b00075,0x7e78010a,0x23b405ac,0xfba4023a}},	//   ۋەند, _fsup, _kåja_, итый_, 
   {{0x753c068f,0x67fc003e,0x6b840332,0x7a3400cf}},	//   karz, néje, _óigm, апыр_, 
   {{0x8c44010b,0x753c0034,0x00000000,0x00000000}},	//   _веже, jarz, --, --, 
   {{0x753c068f,0x3a3c20ac,0x6288025c,0x998400fb}},	//   darz, asup_, _ġeom, стыһ, 
   {{0x0a6865cb,0x6d593288,0x38b80ca8,0x67d4009b}},	//   _арки_, lgva, _sáré_, сому, 
   {{0x44300369,0x23b401e3,0x753db264,0x81bc00fe}},	//   _swx_, _nåja_, farz, ুকত_, 
   {{0x27340208,0x245800c7,0x00000000,0x00000000}},	//   ấn_, лагь_, --, --, 
   {{0xdb0c01e1,0x00000000,0x00000000,0x00000000}},	//   _àkòt, --, --, --, 
   {{0x6d580369,0xf8b408a8,0x00000000,0x00000000}},	//   hgva, _כפוי_, --, --, 
   {{0x753c0dd4,0x673cd7c5,0x6d580369,0x00000000}},	// [38110] barz, masj, kgva, --, 
   {{0xdce00953,0x673c0482,0x290000c8,0x6d580007}},	//   _galė, lasj, _ĝiaj_, jgva, 
   {{0x7e79ef40,0xf0e80075,0x2900008f,0xdef00023}},	//   _ssup, لىكى_, _ŝiaj_, ልውን_, 
   {{0x9f0406d5,0x6575ef41,0x673c037f,0x3a3c010a}},	//   موضو, lezh, nasj, ysup_, 
   {{0x5398011a,0x00000000,0x00000000,0x00000000}},	//   _עישו, --, --, --, 
   {{0x2858001f,0x6d581876,0x6574030a,0x673c340f}},	//   _ጉባኤያ, ggva, nezh, hasj, 
   {{0x6455ef42,0x673c1a82,0xdca401b9,0xb5b80375}},	//   nuzi, kasj, сайи, שלוח_, 
   {{0x7e788b14,0x3a3c20ac,0x186800c2,0x753c012d}},	//   _tsup, tsup_, қами_, zarz, 
   {{0x6455ef43,0xefc9ef44,0x673def45,0x3a3c0869}},	//   huzi, _турк_, dasj, usup_, 
   {{0x6455b533,0x3a3c0869,0x6ea4012c,0xbc4400cf}},	//   kuzi, rsup_, कहरु, _ۅرچۉ, 
   {{0x3a3def46,0x261c026c,0x753c0156,0x64542255}},	//   ssup_, _aìo_, varz, juzi, 
   {{0x6455ef47,0x673c1a82,0x753c068f,0xdce00006}},	//   duzi, gasj, warz, _salė, 
   {{0x753def48,0xdce00153,0x5aa800ec,0xaa5800f3}},	//   tarz, _palė, _ڄاڻَ_, _вичу_, 
   {{0x657403bd,0x673c045f,0x753c05c7,0x56940124}},	//   gezh, aasj, uarz, ааҭт, 
   {{0x6455ef49,0x3944009a,0x89d5d36b,0x753c019d}},	//   guzi, _idns_, _دوور_, rarz, 
   {{0xb4e800ab,0x6d580399,0x673c0158,0xa7fc029f}},	//   _बडी_, zgva, casj, rtıc, 
   {{0x6575ef4a,0x03a1ef4b,0x753def4c,0x11d8007b}},	// [38120] bezh, чито, parz, هورة_, 
   {{0x6455ef4d,0x76440117,0x6d580369,0x67fc48bf}},	//   buzi, _iviy, xgva, réje, 
   {{0x6455c7e2,0xf8b405d7,0x49380a7c,0x5ea40154}},	//   cuzi, आनिय, רגעו, _খেলে, 
   {{0xb35801ed,0x00000000,0x00000000,0x00000000}},	//   _خیرا_, --, --, --, 
   {{0x0dc806ed,0x2dc8c7b0,0x00000000,0x00000000}},	//   луки_, ақан_, --, --, 
   {{0x1108aaa2,0x0c7400e5,0xac9400cf,0x00000000}},	//   _مغزي_, مدعد, жакш, --, 
   {{0x0c844619,0x8bc40aac,0x6d59ef4e,0xcd3400cf}},	//   сылм, йсид, rgva, _ۇراب, 
   {{0x1ae0015b,0x00000000,0x00000000,0x00000000}},	//   খেছে_, --, --, --, 
   {{0x64546b9d,0x65740489,0x673c03a1,0xc9844143}},	//   zuzi, yezh, vasj, буни, 
   {{0x394404cc,0x6455ef4f,0x6d58010a,0xc278008d}},	//   _cdns_, yuzi, qgva, נריי, 
   {{0xd90c096d,0x6575ef41,0x6d49ef50,0x673c1a82}},	//   نیه_, vezh, _idda, tasj, 
   {{0x657407e4,0x20042a4a,0x6455ef51,0x00000000}},	//   wezh, _èlit_, vuzi, --, 
   {{0xcaf4005e,0x673c1a82,0x6455ef52,0xe97001d9}},	//   _اساب, rasj, wuzi, _ہۆکھ, 
   {{0x673def53,0x764400b8,0x65740156,0xb99001ec}},	//   sasj, _dviy, uezh, _ىلنب, 
   {{0x6575ef54,0x673c168c,0x85f800cd,0x76440205}},	//   rezh, pasj, _cūrṇ, _eviy, 
   {{0x6455ef55,0x6d480083,0x00000000,0x00000000}},	//   ruzi, _ldda, --, --, 
   {{0x6d49ef56,0x645566a5,0x6575ef57,0x60240064}},	// [38130] _odda, suzi, pezh, _mėme, 
   {{0x6454026c,0x7675ef58,0x32642081,0x00000000}},	//   puzi, _эльф, ятсв, --, 
   {{0x76440433,0x720400ae,0x00000000,0x00000000}},	//   _zviy, أولم, --, --, 
   {{0x6d49ef59,0xa2940006,0x6fd400d4,0x22940395}},	//   _adda, _дамі, пціє, _димя, 
   {{0x236801e4,0xdef00023,0x00000000,0x00000000}},	//   mfaj_, ልፍን_, --, --, 
   {{0x5bb00c93,0x2368848b,0x00000000,0x00000000}},	//   जस्व, lfaj_, --, --, 
   {{0x4c900640,0x00000000,0x00000000,0x00000000}},	//   дијс, --, --, --, 
   {{0x6d482252,0x5ba9ef5a,0x5bc4007b,0x3c400014}},	//   _edda, рким_, تقبل, _ہێتِ, 
   {{0x602402d5,0x00000000,0x00000000,0x00000000}},	//   _dėme, --, --, --, 
   {{0x27e000c8,0x6d48009a,0x64440810,0xed040133}},	//   _ĉina_, _gdda, _ovhi, _کومپ, 
   {{0xa3e84728,0x1869ef5b,0x98a40276,0xad244c2d}},	//   मका_, шани_, цине, _رىنى, 
   {{0x588400c7,0xd709ef5c,0x966400d8,0x00000000}},	//   быҭа, инне_, окме, --, 
   {{0x7bc80460,0xd945ef5d,0x6445ef5e,0x81c000de}},	//   _imgu, _дели, _avhi, _ķēni, 
   {{0x85f80882,0x26c40961,0x00000000,0x00000000}},	//   _pūrṇ, яғын_, --, --, 
   {{0x798008e7,0x64a40b45,0x97c4e20f,0xb4b40034}},	//   _ianw, sɗin, _وقتو, झने_, 
   {{0x045400c6,0xa7fc0bc7,0x7981ef5f,0xd7c814a5}},	//   تلفة_, ltın, _hanw, _خوبه_, 
   {{0x798070e0,0xdce000cd,0x7bc80334,0x2f880032}},	// [38140] _kanw, _balī, _mmgu, ҙҙан_, 
   {{0xa7fc0e98,0x7980b423,0xe3b8016c,0x67fc0098}},	//   ntın, _janw, абӣ_, méja, 
   {{0x7981ef60,0xdce00029,0x7bc8014b,0x64401427}},	//   _manw, _dalī, _omgu, álit, 
   {{0x7981ef61,0x98a40618,0xa7fc03e0,0x68fc03b2}},	//   _lanw, lalē_, htın, ýrdi, 
   {{0x79800a85,0x644001f1,0xa7fc8eac,0x64440810}},	//   _oanw, šlit, ktın, _zvhi, 
   {{0x98a40069,0x79800198,0x7bc800a9,0xdce0005f}},	//   nalē_, _nanw, _amgu, _galī, 
   {{0xdb18019f,0xb4e80d0d,0x00000000,0x00000000}},	//   _umwû, _बडो_, --, --, 
   {{0x0b8802d7,0x79803441,0xe86401c0,0x0a680107}},	//   рски_, _aanw, үхнү, арои_, 
   {{0x7981ef62,0x35a40023,0x00000000,0x00000000}},	//   _banw, ፈኛታት_, --, --, 
   {{0x6d48019b,0x7bc8379d,0x67fc0789,0x798003cb}},	//   _udda, _emgu, déja, _canw, 
   {{0x01f8010f,0xe8940006,0x98a400ef,0x00000000}},	//   שפיל, чань, dalē_, --, 
   {{0xc7c402bf,0xa7fcd7c2,0x7980035a,0x67fc00e8}},	//   існи, atın, _eanw, féja, 
   {{0x7981ef63,0x8ad400dd,0x236801d4,0xaa94074d}},	//   _fanw, _بتائ, vfaj_, _хилч, 
   {{0x98a4005f,0x7981ef64,0x9f9402d2,0x00000000}},	//   galē_, _ganw, _lýðs_, --, 
   {{0x7bc80042,0xded40023,0x83c80798,0x00000000}},	//   _ymgu, _ክዉን_, аѓаа_, --, 
   {{0xdce000da,0xd5b8016c,0x67fc00d5,0x00000000}},	//   _salī, асӣ_, béja, --, 
   {{0xdce00029,0x7981ef65,0xa91c00d0,0x23680115}},	// [38150] _palī, _yanw, ndľo, rfaj_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x64440810,0xdce000b8,0xc05843e1,0xa30800e5}},	//   _uvhi, _valī, різ_, _گردے_, 
   {{0xd47804ac,0xb68801ed,0xe3740209,0x644001a6}},	//   _פארל, _اپیل_, _элмы, šlis, 
   {{0x53980302,0xa7fdef66,0xa3080014,0x1df8034b}},	//   _הירו, ytın, _دردے_, беды_, 
   {{0xa7fc03be,0x00000000,0x00000000,0x00000000}},	//   xtın, --, --, --, 
   {{0x9f35992f,0x7981ef67,0x3eac005c,0x00000000}},	//   _неві, _ranw, sygt_, --, 
   {{0x7981ef68,0x5f8000db,0x3c2003e0,0x291802f0}},	//   _sanw, _سۇتە, _cıva_, žral_, 
   {{0x7981ef69,0xa7fc05d1,0x5d540120,0xc0f00023}},	//   _panw, ttın, _нкат, ሃይም_, 
   {{0xad240131,0x7db402eb,0x7980047e,0x00000000}},	//   _يىقى, _بصرا, _qanw, --, 
   {{0xa7fc0bcc,0x798027bb,0x181400af,0xd8240212}},	//   rtın, _vanw, णदेव_, ядни, 
   {{0x79800bed,0x7bc82939,0xe8f82c12,0xe9d800cf}},	//   _wanw, _umgu, өлө_, йкө_, 
   {{0x19940801,0x7bd836b7,0x7981ef6a,0xa7fc0790}},	//   _надя, mnuu, _tanw, ptın, 
   {{0xa7fc2fbe,0xf48450c9,0x67fc0c6a,0xaab80118}},	//   ltıl, وازی, réja, इनरक, 
   {{0x291c0030,0xe3b001d9,0x00000000,0x00000000}},	//   ázať_, ھرِ_, --, --, 
   {{0xa7fc07c4,0x7bd8b7a8,0x03a1ef6b,0x68fdef6c}},	//   ntıl, nnuu, нисо, ürde, 
   {{0x51185821,0x9664014b,0x41b001d5,0x644003b2}},	// [38160] مزاح_, _экпе, کملر, álir, 
   {{0xa7fc03e0,0x00000000,0x00000000,0x00000000}},	//   htıl, --, --, --, 
   {{0x106919ef,0xa7fc62c7,0x7bd82430,0xb358187c}},	//   сией_, ktıl, knuu, _ویسا_, 
   {{0x20540588,0x7bd80009,0x00000000,0x00000000}},	//   ьтур, jnuu, --, --, 
   {{0xa3e806ab,0x7bd9ef6d,0x5f180006,0x00000000}},	//   मकर_, dnuu, іццё_, --, 
   {{0x2b400427,0x2480022e,0xd13000ae,0x3c2003e0}},	//   _žic_, _yshm_, _سمر_, _sıva_, 
   {{0xddc80276,0xc0e0fd06,0x7bd80af9,0x8c9400d4}},	//   _speţ, _зорк, fnuu, ярді, 
   {{0xa0d40058,0x27e000df,0x3f640b01,0xbc00004e}},	//   _تېما_, _ĉino_, _нисо_, нчый, 
   {{0xcc89ef6e,0x8ea419b6,0xc9840640,0xf1c000dc}},	//   _گناه_, _عصرن, пуни, _एतान, 
   {{0x2919ef6f,0x7bd9ef70,0x7c3400c7,0x00000000}},	//   øra_, anuu, ñaré, --, 
   {{0x7bd9ef71,0x3c200139,0xe270010e,0x00000000}},	//   bnuu, _tıva_, _ỳüzl, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8a040026,0x68e40055,0x00000000,0x00000000}},	//   _езде, _śidd, --, --, 
   {{0x88b40327,0x00000000,0x00000000,0x00000000}},	//   ྒྱུར, --, --, --, 
   {{0xa7fc03e0,0x00000000,0x00000000,0x00000000}},	//   ltım, --, --, --, 
   {{0xa2940006,0x65e401ec,0xf8d808c3,0x68fc0162}},	//   мабі, _ﺍﺳﯩﻠ, _לחומ, ýrdu, 
   {{0xa7fc0790,0x00000000,0x00000000,0x00000000}},	// [38170] ntım, --, --, --, 
   {{0x04f80154,0x00000000,0x00000000,0x00000000}},	//   _আলীর_, --, --, --, 
   {{0x7bd9ef72,0xa7fc03e0,0x00000000,0x00000000}},	//   ynuu, htım, --, --, 
   {{0x67000050,0x64540552,0x7bd80067,0xa7fc236c}},	//   _ईराक_, mrzi, xnuu, ktım, 
   {{0x63bc0135,0x67fc003e,0x44200175,0xdb0803b9}},	//   _ilsn, héjo, lqj_, mkeç, 
   {{0x64540196,0x00000000,0x00000000,0x00000000}},	//   orzi, --, --, --, 
   {{0xa7fc62c7,0x628c0254,0x04f800eb,0x00000000}},	//   ttıl, lvao, _আলুর_, --, 
   {{0x7bd80607,0x628c0109,0x00000000,0x00000000}},	//   unuu, ovao, --, --, 
   {{0xa7fc2706,0xbd6813d6,0x7bd8d6d6,0x628c030a}},	//   rtıl, _грее_, rnuu, nvao, 
   {{0x628c0618,0x7bd9ef73,0x00000000,0x00000000}},	//   ivao, snuu, --, --, 
   {{0x63bc0158,0xa7fc6654,0xdb08013d,0x00000000}},	//   _olsn, ptıl, kkeç, --, 
   {{0x6454e8a8,0x6d5c02d2,0x00000000,0x00000000}},	//   drzi, _örar, --, --, 
   {{0x64541543,0xedd40150,0x00000000,0x00000000}},	//   erzi, _تيەد, --, --, 
   {{0x63bc0196,0x628c05c7,0xda083997,0x00000000}},	//   _alsn, dvao, _بيته_, --, 
   {{0xa3e81a2a,0xd7c8208f,0x97c400ee,0x69dc01a6}},	//   मकं_, _ووته_, _ойке, čret, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x59e07220,0x63bc00a3,0x6454010a,0x60240153}},	// [38180] _पदार, _dlsn, arzi, _rėma, 
   {{0x50d5ef74,0x50b87da6,0x645401a6,0x61e802d2}},	//   وزار, يداد_, brzi, _íell, 
   {{0x7bc40006,0xdb0802f6,0x85980375,0x8fa449c4}},	//   _įjun, lkeä, _ושיו, маже, 
   {{0xa7fc00ac,0xa3e800dc,0x2ff400db,0x00000000}},	//   ytım, मकः_, رتاڭ, --, 
   {{0x3c2005c7,0x9f5000e5,0xdb080108,0x4e7807fc}},	//   _añv_, óbál_, nkeä, تحاد_, 
   {{0xcc280124,0x60c8012c,0xfbcc00f1,0x00000000}},	//   оцид_, _řeme, یتي_, --, 
   {{0xdb08005b,0x00000000,0x00000000,0x00000000}},	//   hkeä, --, --, --, 
   {{0x0ba82a8b,0xa7fc0e2d,0x98a40153,0x00000000}},	//   تاتى_, ttım, lalė_, --, 
   {{0x53c48cce,0x32180109,0x3c2005c7,0x0ae8007b}},	//   रोएश, _kiry_, _eñv_, غربي_, 
   {{0x6e200810,0xa7fc0e2d,0x8cb40556,0xdce00064}},	//   _iumb, rtım, _осеч, _galį, 
   {{0x6e21ef75,0x6d5c0309,0x628c0099,0xcb680395}},	//   _humb, _öraq, zvao, _маже_, 
   {{0x6e21ef76,0xdb1800d2,0x64540010,0x942006be}},	//   _kumb, _hlwî, vrzi, _öpər_, 
   {{0xefe402d3,0x2c68000f,0xf8b4004e,0x99dc010e}},	//   _ምኻድ_, lûd_, зөө_, huňy, 
   {{0x6e21ef77,0x321805da,0x645401fa,0xe98401ec}},	//   _mumb, _niry_, trzi, _ساتۋ, 
   {{0x67d4e278,0x6e21ef78,0xa7fc510c,0xe01c033f}},	//   _поку, _lumb, ntık, _बूंद_, 
   {{0x32180afa,0x91c005a2,0x6e21d39d,0x99dc00a2}},	//   _airy_, ңәрл, _oumb, duňy, 
   {{0x65941064,0x6e21ef79,0xa19401c0,0xf6e40006}},	// [38190] _запу, _numb, наач, _ацэн, 
   {{0x628d6222,0xa7fc05d1,0x202c02d3,0x645404a7}},	//   rvao, ktık, _ብዲሞክ, przi, 
   {{0x6e21ef7a,0x656402d1,0xdb0801ab,0x628c0108}},	//   _aumb, _ichh, nheò, svao, 
   {{0x77640165,0x32180042,0x00000000,0x00000000}},	//   _xcix, _eiry_, --, --, 
   {{0x6e21ef7b,0xee384dba,0x32180851,0x9f4d4ffd}},	//   _cumb, дні_, _firy_, _bheò_, 
   {{0x9f4c08c2,0x2249ef7c,0x6e201948,0x321800d7}},	//   _cheò_, msak_, _dumb, _giry_, 
   {{0x6e2000e8,0x2249ef7d,0x3f6401b9,0x91c000fb}},	//   _eumb, lsak_, _отаб, _сәтл, 
   {{0x6e21ef7e,0x22480548,0xdb09d701,0x59e000bc}},	//   _fumb, osak_, dheò, _पदहर, 
   {{0x2249310f,0x04f8015b,0x00000000,0x00000000}},	//   nsak_, _আলোর_, --, --, 
   {{0x6d5c0309,0x9f4c01ab,0x2248102c,0x414c0023}},	//   _örap, _gheò_, isak_, _ኣምሊጦ, 
   {{0x7c6400db,0x2248022e,0xdb0801e7,0x00000000}},	//   _زاال, hsak_, theó, --, 
   {{0x2249ef7f,0x65647368,0x6e21ad35,0xdb08005b}},	//   ksak_, _achh, _yumb, tkeä, 
   {{0x97c40046,0x22480369,0x92f8015b,0x6e21ef80}},	//   _үйле, jsak_, _অল্প_, _xumb, 
   {{0x69dc04fe,0xdb08049b,0x22492a67,0x2d980295}},	//   ōrer, rkeä, dsak_, _òret_, 
   {{0xccf0008f,0x2248d6cc,0xdb080156,0x187400df}},	//   ָכן_, esak_, mheñ, _טײַך_, 
   {{0x65640036,0x224805e4,0x6288025c,0x00000000}},	//   _echh, fsak_, _ġeor, --, 
   {{0x2249ef81,0x321805da,0x35c40022,0xa9580220}},	// [381a0] gsak_, _piry_, _аапҳ, _ءجۇر_, 
   {{0x6e21ef82,0xdb080165,0x4250006c,0x00000000}},	//   _rumb, nheñ, انلر, --, 
   {{0x6e21ef83,0x22480194,0xa6a82c04,0x3218750d}},	//   _sumb, asak_, _فایق_, _viry_, 
   {{0x6e21ef84,0xba040020,0x00000000,0x00000000}},	//   _pumb, _ወጪ_, --, --, 
   {{0x224952c4,0x6e21ef85,0xc7d4025d,0x2ebc00dc}},	//   csak_, _qumb, עוני_, ्छेत, 
   {{0x6e200c11,0xe19405f5,0xdce0029f,0xa7fc05d1}},	//   _vumb, _ирсэ, _anlı, ttık, 
   {{0x8d18066d,0x6e21ef86,0xaca4063f,0xc5f0011a}},	//   _ہزار_, _wumb, kpụr, אדג_, 
   {{0x8aa4b3ef,0x2c68002d,0xa7fc03e0,0x00000000}},	//   ерод, rûd_, rtık, --, 
   {{0x9d1002f5,0x6e2001c8,0x68f805ac,0xa7fc0e2d}},	//   সুলভ_, _uumb, _syvd, stık, 
   {{0xbe10f283,0xa7fc03ee,0xdb0800a3,0x1fe000eb}},	//   _موقع, ptık, theò, বতঃস, 
   {{0x815400c8,0x0c9409a5,0x61e801e4,0x2249ef87}},	//   עסטע_, _яшая, _ŭelk, zsak_, 
   {{0x22480429,0x67d44965,0x4ae401b9,0x00000000}},	//   ysak_, тому, _пўла, --, 
   {{0x42d82aab,0x7d2401e6,0x0ae805d9,0x787401ec}},	//   _দর্শ, _årså, _عرصي_, _үйір_, 
   {{0xdb08030a,0x2248eb28,0xe858004e,0x1ad80354}},	//   cheñ, vsak_, _жакш_, _юьхь_, 
   {{0x22480309,0xdb08005c,0x00000000,0x00000000}},	//   wsak_, rkeå, --, --, 
   {{0x22497f1a,0xf3641cd6,0x00000000,0x00000000}},	//   tsak_, лтун, --, --, 
   {{0x672c0687,0x224801c4,0xd7e800db,0xdb0803b2}},	// [381b0] _ifaj, usak_, _تويۇ_, nheð, 
   {{0x2249ef88,0x00000000,0x00000000,0x00000000}},	//   rsak_, --, --, --, 
   {{0x2249ef89,0x6adc09fa,0x2459ef8a,0x00000000}},	//   ssak_, मपुर, _юань_, --, 
   {{0xf0e804a9,0x9e34652e,0xdb08030a,0x9ed8010b}},	//   رىنى_, ведч, zheñ, ммет_, 
   {{0xaad0202e,0x224801a9,0x62342377,0x00000000}},	//   _तेलक, qsak_, _јегу, --, 
   {{0x6270044e,0x3ec400c7,0x7e6801bf,0x00000000}},	//   _ስርዓተ_, _ҧсаб, rtgp, --, 
   {{0xdca40075,0xcfbc0011,0x00000000,0x00000000}},	//   тайи, েকজন, --, --, 
   {{0x0ed002ab,0xbd64001f,0x6adc024a,0xcf8c1dd8}},	//   _देवड, _ሰዎችም_, मपूर, _وژن_, 
   {{0x9b0401b9,0x6ab401c6,0xfe740166,0x00000000}},	//   ъзид, гсэх, _чүл_, --, 
   {{0xdd9400c7,0x81b000eb,0x00000000,0x00000000}},	//   _шазы, জোর_, --, --, 
   {{0xdb080156,0x99d410e8,0x00000000,0x00000000}},	//   rheñ, فتگا, --, --, 
   {{0xdb0803bd,0x60240036,0xdce00166,0x00000000}},	//   sheñ, _nėmm, _unlı, --, 
   {{0xdb18007f,0x59840117,0x00000000,0x00000000}},	//   _emwò, _аллб, --, --, 
   {{0xceb00d65,0x672c06d9,0xeab000c6,0x42d80183}},	//   סים_, _efaj, _دعم_, _দৰ্শ, 
   {{0x04402dbf,0x8ee000cc,0x96b800db,0x00000000}},	//   иерн, _বৰাগ, ساڭز_, --, 
   {{0x087400c8,0x00000000,0x00000000,0x00000000}},	//   _יעצט_, --, --, --, 
   {{0x0321ef8b,0xd70800a8,0x73e40137,0x00000000}},	// [381c0] рдун, _юние_, _ۅيدۅ, --, 
   {{0x14240364,0x53c402ab,0x73c401e0,0x01d400d1}},	//   _идом, रोजश, тәүе, ﺘﺎﻳﻨ, 
   {{0x4da8045e,0x98600023,0xaa140022,0x98a4002b}},	//   কসমূ, _ተሰሪዑ_, sẽgu, dalī_, 
   {{0x3fc812ea,0x2c4c0118,0x00000000,0x00000000}},	//   ودنی_, věd_, --, --, 
   {{0xa2d828df,0x00000000,0x00000000,0x00000000}},	//   _नेप्, --, --, --, 
   {{0xdbc8000d,0xdb0803b2,0x98a40171,0x00000000}},	//   _mõõn, vheð, galī_, --, 
   {{0xcbe59912,0xdb0c006a,0xe804012c,0xdbc80254}},	//   кции, _âkêt, रतमा_, _lõõn, 
   {{0xc0e0c44a,0x09d80490,0x00000000,0x00000000}},	//   _тоск, यच्य, --, --, 
   {{0x0d852261,0xfbcdef8c,0x0e64004e,0x98a40055}},	//   _илан, تتو_, _шкан, balī_, 
   {{0x672c0327,0x693400c7,0x98a40055,0x00000000}},	//   _sfaj, ыноу, calī_, --, 
   {{0x2d8c03ee,0xa814c0bb,0x00000000,0x00000000}},	//   _iade_, лдош, --, --, 
   {{0x2d8def8d,0xe8e001fb,0xcb0802dd,0x6eb80da5}},	//   _hade_, _ngụy_, _قيان_, ्नपु, 
   {{0xc9a80b7f,0x6b80030a,0xa7fc0139,0x00000000}},	//   _овде_, memg, ktıv, --, 
   {{0x2d8def8e,0xa4d400d6,0x49900133,0xe73800c7}},	//   _jade_, гогі, _ئیدر, ьеҭ_, 
   {{0x2d8c20c6,0xb9780302,0x66d803b2,0x672c0003}},	//   _made_, _חנוי, _búkø, _tfaj, 
   {{0x2d8def8f,0xc76402dd,0x6b81ef90,0x00000000}},	//   _lade_, _شابى, nemg, --, 
   {{0x2d8c002d,0xe69401ee,0x00000000,0x00000000}},	// [381d0] _oade_, _сипы, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x442428cf,0xa3d57738,0x0fec2cfd,0x6b80013d}},	//   _în_, _бонч, जवंश_, kemg, 
   {{0x443011ce,0x2d8c011f,0xa7fc013d,0x00000000}},	//   _itx_, _aade_, luıb, --, 
   {{0x6b800077,0x4431ef91,0x2d8c1b2a,0xceb471fe}},	//   demg, _htx_, _bade_, ләф_, 
   {{0x2d8def92,0x1d082c28,0x4431ef93,0x3134576f}},	//   _cade_, нели_, _ktx_, _верр, 
   {{0x443005b1,0x427c0092,0x00000000,0x00000000}},	//   _jtx_, _ሥርአት_, --, --, 
   {{0x44300334,0xefbc0020,0x98a40618,0x67fc01e1}},	//   _mtx_, ታታይ_, salī_, béji, 
   {{0x3f9c0d62,0xee84100e,0xfeb81de7,0x41b59e1e}},	//   _inuu_, _выхо, _غارت_, _आकास, 
   {{0x2d8def94,0x5fb805ba,0x7e780085,0x00000000}},	//   _gade_, _आवडल, _ipup, --, 
   {{0x2dd80597,0x6b800117,0x4430000d,0x00000000}},	//   _شبكة_, bemg, _ntx_, --, 
   {{0xdb0803cd,0xdbc80254,0xcc38010f,0x00000000}},	//   kkeø, _põõn, _נענט, --, 
   {{0x69e40086,0xeb9800d4,0x00000000,0x00000000}},	//   òweò, _шиї_, --, --, 
   {{0xd945ef95,0x2d8c0077,0x29c00208,0x699402e8}},	//   _секи, _xade_, _hòan_, _връх, 
   {{0x44303c36,0x987800c8,0x00000000,0x00000000}},	//   _ctx_, _טאַט, --, --, 
   {{0x7e7800c7,0x00000000,0x00000000,0x00000000}},	//   _opup, --, --, --, 
   {{0x31440364,0xa3b400af,0x1304010a,0x3f8c0042}},	// [381e0] идаҳ, _जकर_, узам, ddgu_, 
   {{0x3f9def96,0x10a402bf,0x9585ef97,0x4430007c}},	//   _anuu_, лизн, _слое, _ftx_, 
   {{0x2d8def98,0x7e79ef99,0x6b80009f,0x00000000}},	//   _rade_, _apup, yemg, --, 
   {{0x2d8def9a,0xce486d56,0x7e78603f,0x53a5ef9b}},	//   _sade_, езде_, _bpup, _самб, 
   {{0x2d8def9c,0xdbd0002f,0x00000000,0x00000000}},	//   _pade_, _süßl, --, --, 
   {{0x7e78020b,0xcd281fa1,0x8aa42c11,0x00000000}},	//   _dpup, رستن_, ғрид, --, 
   {{0x2d8def9d,0x7e79ef9e,0x6adc8109,0x6b81ef9f}},	//   _vade_, _epup, मप्र, temg, 
   {{0xaa55e501,0x9e6401b9,0x91e40117,0x00000000}},	//   авиш, _چالن, _роҳе, --, 
   {{0x6b81efa0,0x2d8defa1,0xfa30583f,0x15e001ec}},	//   remg, _tade_, یرید, _ﺍﺳﺎﺩ, 
   {{0x6b81efa2,0x2d8c003a,0x00000000,0x00000000}},	//   semg, _uade_, --, --, 
   {{0x2919efa3,0xdce00327,0x753c0210,0x00000000}},	//   ära_, _talġ, dbrz, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4431efa4,0x7bd8010f,0x00000000,0x00000000}},	//   _stx_, _אקאו, --, --, 
   {{0xa9346f63,0x4430fe1d,0xa91c0030,0x38540214}},	//   _текш, _ptx_, reľb, خشید_, 
   {{0x69c835ab,0xf98c2363,0x00000000,0x00000000}},	//   mhde, _ربو_, --, --, 
   {{0x92600092,0xc6a424fc,0x00000000,0x00000000}},	//   _ዕርምጃ, _брои, --, --, 
   {{0xf771efa5,0x27e802e2,0x779400f1,0x93240154}},	// [381f0] _راي_, _ijan_, _ایټا, বরূপ_, 
   {{0x69c92a45,0x363410fe,0xa2d80073,0x00000000}},	//   nhde, _اريس, _नेण्, --, 
   {{0x7e780268,0xdb080ac8,0x161c033f,0x69c80363}},	//   _spup, skeø, _यूटर_, ihde, 
   {{0x83a802f6,0x7e780270,0x69d407b6,0x14d4010f}},	//   _чтоб_, _ppup, योती, _כותל_, 
   {{0xa7fc1432,0x69c80067,0xdb1005d2,0x3c2000e5}},	//   ltıs, khde, ügün, _műve_, 
   {{0x5c5400c7,0x27e801e4,0xa1580108,0x00000000}},	//   атиф, _ljan_, _шагу_, --, 
   {{0x63ac02d5,0xa7fc3e67,0xa2d8590f,0x69c800a3}},	//   ojan, ntıs, _नेत्, dhde, 
   {{0x63ac0107,0xdb180548,0x3ba00107,0x69c80327}},	//   njan, _alwá, слиҳ, ehde, 
   {{0x6e943c06,0x7e79efa6,0x63adefa7,0x7f484242}},	//   _литу, _upup, ijan, magq, 
   {{0x27e9efa8,0x69c9efa9,0x63adefaa,0x986400e5}},	//   _ajan_, ghde, hjan, لیتے_, 
   {{0x63adefab,0x61e5efac,0x29c0004d,0x9f5801e1}},	//   kjan, inhl, _tòan_, _òsó_, 
   {{0x63adefad,0x69c80014,0x7f48014b,0xd629efae}},	//   jjan, ahde, nagq, коме_, 
   {{0x63adefaf,0x7bd80869,0x60240153,0x69c800b8}},	//   djan, miuu, _dėmi, bhde, 
   {{0x69c809a4,0x7bd80eda,0x200c0076,0x63ac00db}},	//   chde, liuu, _lhei_, ejan, 
   {{0x3944f8c8,0x7f4800f1,0x200c0036,0x63adefb0}},	//   _iens_, kagq, _ohei_, fjan, 
   {{0x61e5efb1,0x3945efb2,0x63adc00b,0x27e8c447}},	//   enhl, _hens_, gjan, _gjan_, 
   {{0x39440c3a,0x7bd80093,0x95740209,0x1068084c}},	// [38200] _kens_, iiuu, _кынч, ӂией_, 
   {{0x3945efb3,0x200c04fe,0x63ac3ed2,0x98a40153}},	//   _jens_, _ahei_, ajan, nalį_, 
   {{0x63adefb4,0x4f240a8f,0x200c01ab,0x3945efb5}},	//   bjan, адеб, _bhei_, _mens_, 
   {{0x76442001,0x200defb6,0x69c80489,0xa7fc00fd}},	//   _kwiy, _chei_, zhde, ltır, 
   {{0x200c0040,0x7bd80194,0x6e940ce4,0x0dc81086}},	//   _dhei_, diuu, силу, куки_, 
   {{0x39440228,0x7644e1a0,0x69c8036e,0x200c01f4}},	//   _nens_, _mwiy, xhde, _ehei_, 
   {{0x8bc46287,0xac99efb7,0x7f480944,0xdc5400aa}},	//   исид, انبا_, bagq, مريک, 
   {{0x06e4015b,0x7bd80859,0xa7fc03e0,0x00000000}},	//   _নরসি, giuu, htır, --, 
   {{0xa7fc70f7,0x394410d0,0x4c90036b,0x69c96ba3}},	//   ktır, _bens_, сиқс, thde, 
   {{0x63adefb8,0x3945efb9,0x27e8036e,0x98a40064}},	//   zjan, _cens_, _sjan_, galį_, 
   {{0x7645efba,0x63adefbb,0x3945efbc,0x27e8003d}},	//   _awiy, yjan, _dens_, _pjan_, 
   {{0x3945efbd,0x6d49efbe,0x76444a73,0x69c9efbf}},	//   _eens_, _heda, _bwiy, shde, 
   {{0x6d49a373,0x63adefc0,0x787801b8,0xaa584b17}},	//   _keda, vjan, _pävö, _силу_, 
   {{0x6d481326,0x3945efc1,0x76455cbc,0x63ac0054}},	//   _jeda, _gens_, _dwiy, wjan, 
   {{0x6d484535,0x63adefc2,0x69d87ac7,0x7f480fec}},	//   _meda, tjan, _imve, yagq, 
   {{0x6d49efc3,0x27e9efc4,0xa7fc00fd,0x63ac0006}},	//   _leda, _ujan_, rtıs, ujan, 
   {{0x787801b8,0x200c1e44,0x3944047e,0x6d48035a}},	// [38210] _tävö, _rhei_, _yens_, _oeda, 
   {{0x63adefc5,0x7f480944,0x39440005,0x2cbc0158}},	//   sjan, wagq, _xens_, kyvd_, 
   {{0x63adefc6,0x200c00fb,0x2a64511f,0x6f0003ac}},	//   pjan, _phei_, humb_, _aymc, 
   {{0x6444014f,0x6d49efc7,0x00000000,0x00000000}},	//   _iwhi, _aeda, --, --, 
   {{0x7bd80140,0xd344158b,0x00000000,0x00000000}},	//   viuu, _دیقه_, --, --, 
   {{0x6444009a,0x7f480b6f,0x5ac8036b,0x6f0003cb}},	//   _kwhi, sagq, ғлом_, _dymc, 
   {{0x6d49efc8,0x200defc9,0xdd940220,0x98a40024}},	//   _deda, _thei_, _қажы, valį_, 
   {{0x3945efca,0x2369efcb,0x1dd80303,0x69d80bd7}},	//   _sens_, ngaj_, _भगवत, _amve, 
   {{0x6d49efcc,0x7bd820ac,0x0f3000b2,0x8f6801ed}},	//   _feda, riuu, _رکند, _حلقے_, 
   {{0x6d49efcd,0x1ae49bcb,0x7644f948,0x7bd9efce}},	//   _geda, _қолм, _rwiy, siuu, 
   {{0x764406e4,0x64440295,0x3945efcf,0xd78805d9}},	//   _swiy, _nwhi, _vens_, هندو_, 
   {{0x39440e29,0x69d8cf3e,0x6d493d45,0xcc74011a}},	//   _wens_, _emve, _zeda, _לגעת_, 
   {{0x6445efd0,0xa7fc825f,0x6d48478b,0xdb080165}},	//   _awhi, ttır, _yeda, nkeü, 
   {{0x6d4801c0,0xd4680209,0x64440175,0xab180212}},	//   _xeda, лиге_, _bwhi, _тієї_, 
   {{0xa7fd05c3,0x67280010,0xa91c00d7,0x00000000}},	//   rtır, žeja, peľa, --, 
   {{0xa7fc825f,0x76440230,0xf8140214,0xdb080254}},	//   stır, _twiy, _بستگ, kkeü, 
   {{0x76442dab,0x6444014b,0xa7fc0365,0x66140175}},	// [38220] _uwiy, _ewhi, ptır, bmzk, 
   {{0x01d40491,0xd1940640,0x60240064,0xa7fc0139}},	//   موقع_, љшањ, _lėmu, ltıp, 
   {{0x6d49efd1,0x2a6406d6,0x4598010f,0x8ed80214}},	//   _reda, zumb_, _עסטע, گذار_, 
   {{0x4fe8005e,0x68fdefd2,0x38940311,0xa2d80073}},	//   ымен_, ürdi, _măr_, _नेव्, 
   {{0xc330025d,0x5fb801f9,0x59b801f9,0x00000000}},	//   _מור_, _आवरल, ेसार, --, 
   {{0x6d480429,0x226400bc,0xa91c00d0,0x60940014}},	//   _qeda, ňský_, deľn, _ژۆلس_, 
   {{0x6d49efd3,0x00000000,0x00000000,0x00000000}},	//   _veda, --, --, --, 
   {{0x6f000034,0x2ec4004e,0xd1c00092,0x2ff80244}},	//   _tymc, _мөлм, ጻዎች_, _ئورگ_, 
   {{0x6d49efd4,0x64a410eb,0x00000000,0x00000000}},	//   _teda, _ऑप्श, --, --, 
   {{0x2a640d6f,0xf400015b,0x6d49efd5,0x02b40a7c}},	//   rumb_, ্দির_, _ueda, צליך_, 
   {{0xe80403ce,0x00000000,0x00000000,0x00000000}},	//   रतला_, --, --, --, 
   {{0xa3bc1d8a,0x57400023,0x00000000,0x00000000}},	//   _अवध_, _ጨንፈራ, --, --, 
   {{0x6444013f,0xf4000154,0x494400c0,0xa7fc0139}},	//   _swhi, ্দার_, _лэйб, buın, 
   {{0x69d8022c,0xe91800d4,0x779400e5,0xa2d800cd}},	//   _umve, _колі_, _ہیپا, _नेष्, 
   {{0xb9d80375,0xa91c00d7,0x00000000,0x00000000}},	//   _תחוש, meľo, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe7780116,0x23689718,0x61d80006,0x65940006}},	// [38230] _бақә_, rgaj_, амая_, _дапу, 
   {{0xa1580f37,0x84c8014b,0x00000000,0x00000000}},	//   ражу_, _бумб_, --, --, 
   {{0x6445efd6,0x5f940395,0xf0e800d1,0x00000000}},	//   _uwhi, жиет, مىكى_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7d0401ed,0x60240153,0x00000000,0x00000000}},	//   _újsz, _rėmu, --, --, 
   {{0x629c02d0,0x00000000,0x00000000,0x00000000}},	//   _irso, --, --, --, 
   {{0xa91c00d0,0x69ac00dc,0x6fb800cc,0x00000000}},	//   deľo, जानी, _আগৰে, --, 
   {{0x23c810f7,0xa91c0038,0x00000000,0x00000000}},	//   रसिद, teľn, --, --, 
   {{0x2bd800cd,0x00000000,0x00000000,0x00000000}},	//   बोधा, --, --, --, 
   {{0x38940311,0x09f4007b,0xeeb86d64,0x00000000}},	//   _păr_, يفية_, _улуш_, --, 
   {{0xd7e8656c,0x15f8068f,0x23c85168,0x57e80f37}},	//   имое_, ृतसर_, रसाद, идом_, 
   {{0x629defd7,0xa91c01f1,0x6aa400c0,0x00000000}},	//   _orso, peľn, _šife, --, 
   {{0x99d425aa,0xd6284d75,0x19948354,0xa2d80f4a}},	//   _وتتا, роге_, _мадя, _नेल्, 
   {{0x29c001ab,0xa9a40150,0xa91c00d7,0x39a401af}},	//   _nòah_, _ىمنى, ceľo, _ышев, 
   {{0x629defd8,0xb4042692,0x1868013e,0x656001d3}},	//   _arso, зүнд, _тайи_, ólha, 
   {{0x03a0a440,0x00000000,0x00000000,0x00000000}},	//   мисо, --, --, --, 
   {{0x6fb803d4,0xb6c800e5,0x52a80395,0x00000000}},	// [38240] _আগলৈ, _داغے_, швам_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x629defd9,0x00000000,0x00000000,0x00000000}},	//   _erso, --, --, --, 
   {{0xed5800d7,0x0fd80022,0x00000000,0x00000000}},	//   _sdľ_, шьзы_, --, --, 
   {{0xfe6c1d1f,0x2ec40825,0x00000000,0x00000000}},	//   ندو_, वनेत, --, --, 
   {{0x21748c21,0x86980677,0xac9401ec,0x00000000}},	//   _нуср, יינז, закш, --, 
   {{0x0ca9efda,0x9f4802f0,0x00000000,0x00000000}},	//   ртли_, škám_, --, --, 
   {{0x261000ab,0x3f6400d8,0x00000000,0x00000000}},	//   _दीनी_, _мисо_, --, --, 
   {{0xa91c0038,0x37d00eac,0x9f580162,0xfbcc01d3}},	//   teľo, াচার, _ósá_, ڑتی_, 
   {{0x2ec40166,0x00000000,0x00000000,0x00000000}},	//   _мөһм, --, --, --, 
   {{0x28f8242f,0xa91c0419,0xd90c029e,0x00000000}},	//   сень_, reľo, هیه_, --, 
   {{0x27ec0086,0xfbc0673b,0x18180014,0x00000000}},	//   õen_, _обхо, ٝرُک_, --, 
   {{0xf98c79f8,0xa91c0030,0x2ac4013d,0x070801d5}},	//   ربی_, peľo, _хәйв, рхни_, 
   {{0x02a001f2,0x80b800ce,0x00000000,0x00000000}},	//   nrụọ, _एथले, --, --, 
   {{0x61400421,0x3495efdb,0xa7fc0139,0x00000000}},	//   _lâlâ, марр, luım, --, 
   {{0x62241a59,0xe2340640,0x629c0118,0x00000000}},	//   كىرل, знањ, _prso, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [38250] --, --, --, --, 
   {{0xed880024,0xdfd00451,0x00000000,0x00000000}},	//   šųjų_, ڙيا_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x070c0073,0x724400db,0x00000000,0x00000000}},	//   _सराव_, سپۅل, --, --, 
   {{0x629defdc,0x6304036b,0x645401d3,0x3e845b7a}},	//   _urso, _روسل, lszi, تشاف, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xff500050,0x7dcc072b,0x9f5001d3,0x6454072d}},	//   _ٲخر_, _løsg, óból_, nszi, 
   {{0x5ba8aa53,0x628c01f7,0x00000000,0x00000000}},	//   ским_, owao, --, --, 
   {{0x628c00f2,0xdb0803b2,0x4aa40124,0x00000000}},	//   nwao, gkeð, зкын_, --, 
   {{0x5dd4f3bb,0x645401ed,0x00000000,0x00000000}},	//   _عقائ, kszi, --, --, 
   {{0x628c4d11,0x2bd85219,0x645400e5,0x00000000}},	//   hwao, बोहा, jszi, --, 
   {{0x628defdd,0x7f580327,0x60100fac,0x00000000}},	//   kwao, _jduq, låmb, --, 
   {{0x7bc81494,0x00000000,0x00000000,0x00000000}},	//   _ilgu, --, --, --, 
   {{0xceb1efde,0x98549794,0x4a98010f,0x00000000}},	//   עים_, _етиш, _לינג, --, 
   {{0x6455efdf,0x00000000,0x00000000,0x00000000}},	//   gszi, --, --, --, 
   {{0x44e4016b,0x7f580327,0x3a3c0334,0x574801d5}},	//   _dε_, _nduq, opup_, _узим_, 
   {{0xa3bc0d2c,0x55e40c60,0x958401ee,0x00000000}},	// [38260] _अवर_, _ноиб, _елпе, --, 
   {{0x7f580428,0xe3b8013e,0x27240051,0x128401f3}},	//   _aduq, ббӣ_, _ặng_, _ርክክብ_, 
   {{0x2ec40a28,0x7bc9efe0,0x69ac07b7,0x00000000}},	//   वन्त, _olgu, जाती, --, 
   {{0x628c0083,0x7dcc00b5,0xd01001b9,0xaee401e0}},	//   bwao, _løsd, رلش_, мбеһ, 
   {{0x7f580327,0x82a002e8,0xa91c0419,0x00000000}},	//   _dduq, _заяж, veľm, --, 
   {{0x7bc8a0fb,0x7f590baf,0x2b98001e,0x44e4013b}},	//   _algu, _eduq, _ức_, _yε_, 
   {{0xa91c0030,0x2054209b,0x151c0183,0x4ba400db}},	//   teľm, _оттр, বুৰী_, зөлү_, 
   {{0x0b89ca2e,0x7b6045b5,0x0a680353,0x00000000}},	//   сски_, нтье, брои_, --, 
   {{0x645401d3,0x800801d3,0x00000000,0x00000000}},	//   zszi, _طرفہ_, --, --, 
   {{0x2dc801ec,0xddc800de,0x645400e5,0x00000000}},	//   _بارۋ_, _aveņ, yszi, --, 
   {{0x48a8005b,0xa3bc0073,0x00000000,0x00000000}},	//   ётом_, _अवल_, --, --, 
   {{0x7be40724,0x601003cd,0x00000000,0x00000000}},	//   ıruç, påme, --, --, 
   {{0x44e4013b,0xbb4000f7,0x59d8012c,0xdee00023}},	//   _sε_, _чечк, योहर, _ጐደና_, 
   {{0x6454066d,0x44e4013f,0xba14007b,0x00000000}},	//   tszi, _pε_, _فينا_, --, 
   {{0x03c49caa,0x9f5c00d2,0xf4842119,0xaa140124}},	//   псам, hlwá_, нутн, hẽku, 
   {{0x6455efe1,0x00000000,0x00000000,0x00000000}},	//   rszi, --, --, --, 
   {{0x645400dd,0xb7dc0375,0xa194004e,0x00000000}},	// [38270] sszi, _לקהי, маач, --, 
   {{0x645401d3,0x45488ed9,0xe80400bc,0x00000000}},	//   pszi, _учим_, रतका_, --, 
   {{0xc0580046,0x7dcc05ac,0xaac80118,0x00000000}},	//   сіз_, _jøse, ाईँक, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7dcc32b8,0x53980375,0x00000000,0x00000000}},	//   _løse, _וירו, --, --, 
   {{0x7a4001e1,0x00000000,0x00000000,0x00000000}},	//   _lítò, --, --, --, 
   {{0x29680023,0xdb08007c,0xddd000e5,0x00000000}},	//   _ጸሓፋይ_, nkeö, ófűt, --, 
   {{0xaac80316,0x7a400248,0x00000000,0x00000000}},	//   ाईंक, _nítò, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9d5400f2,0x00000000,0x00000000,0x00000000}},	//   _آنات, --, --, --, 
   {{0x3a3c00b5,0x7e68002f,0x7ae400f1,0xdd240064}},	//   spup_, lugp, توکې_, lūži, 
   {{0x7dcc0158,0x7bc8036b,0xdbcc0139,0x00000000}},	//   _døse, _ulgu, _qıäf, --, 
   {{0x7e680c67,0x1ca404d3,0x7dcc0158,0xe87401b9}},	//   nugp, _رێکی_, _tøsd, ونیگ, 
   {{0x26100c2e,0x00000000,0x00000000,0x00000000}},	//   _दीदी_, --, --, --, 
   {{0x49d9efe2,0x7e681c06,0x00000000,0x00000000}},	//   _بانگ_, hugp, --, --, 
   {{0x22580254,0xa7fc2ca8,0x00000000,0x00000000}},	//   _bvsk_, lrın, --, --, 
   {{0xc68c01f7,0x00000000,0x00000000,0x00000000}},	// [38280] _نِي_, --, --, --, 
   {{0xa7fc719a,0x00000000,0x00000000,0x00000000}},	//   nrın, --, --, --, 
   {{0xeee00037,0xa91c0419,0x00000000,0x00000000}},	//   _खइहऽ_, veľk, --, --, 
   {{0x4f083576,0xa7fc0205,0x00000000,0x00000000}},	//   онен_, hrın, --, --, 
   {{0x2dc80873,0xa91c01f1,0xe2c80451,0x515400d8}},	//   пқан_, teľk, _فوٽو_, _отву, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xcfa9efe3,0x00000000,0x00000000,0x00000000}},	//   _باسم_, --, --, --, 
   {{0xdb180100,0xebc4013d,0x00000000,0x00000000}},	//   _jowè, _җәйн, --, --, 
   {{0x2d98002d,0x7dcc0fac,0x224c036e,0x7a4001e1}},	//   _ûre_, _pøse, _çeke_, _sítò, 
   {{0x69d4c119,0x48a80212,0x00000000,0x00000000}},	//   योगी, ітом_, --, --, 
   {{0x6e2805d5,0x5ba402bf,0xa7fc0adc,0x00000000}},	//   _hidb, _пріз, arın, --, 
   {{0xdb18007f,0xa7fc0213,0xbc18008f,0x6e280051}},	//   _nowè, brın, _וואש, _kidb, 
   {{0x7dcc037e,0x6e29b0b5,0xda6400ec,0xdebc0092}},	//   _tøse, _jidb, _ساهي, _ተተኪ_, 
   {{0x6e29efe4,0x2418e368,0xa4d40d30,0xe50800ec}},	//   _midb, зовы_, хові, سيرو_, 
   {{0xddc80316,0x69c800df,0x6e2801e3,0xf36400db}},	//   _dveř, lkde, _lidb, ктун, 
   {{0x69c80165,0xc30400eb,0x00000000,0x00000000}},	// [38290] okde, লেনি_, --, --, 
   {{0x6e28014f,0x00000000,0x00000000,0x00000000}},	//   _nidb, --, --, --, 
   {{0xba0402d3,0x35f800c6,0x4eac015b,0x00000000}},	//   _ዋዛ_, _تريد_, কনোল, --, 
   {{0x66040098,0x6e2801e7,0x863c0092,0x00000000}},	//   _hkhk, _aidb, _ዮሐንስ, --, 
   {{0xddc8012c,0x672c0010,0x69c803cd,0x2fc00254}},	//   _zveř, _mgaj, kkde, öiga_, 
   {{0x63bdefe5,0xac80044e,0x6e28058a,0x69c801f5}},	//   _hosn, _ረክላም_, _cidb, jkde, 
   {{0x61e4136f,0x63bdefe6,0x7e681c06,0x672c8934}},	//   mihl, _kosn, sugp, _ogaj, 
   {{0x672defe7,0x61e43917,0x3a240585,0xd9b81f13}},	//   _ngaj, lihl, _sinp_, ेस्ट, 
   {{0xa7fca090,0x6e2802e2,0x291800ee,0x64a403f9}},	//   trın, _fidb, ýran_, rɗiy, 
   {{0x672defe8,0x61e40944,0x6e280941,0x63bdefe9}},	//   _agaj, nihl, _gidb, _losn, 
   {{0xa7fc5775,0x63bc03ac,0x49c401c6,0x98240014}},	//   ltıy, _oosn, хлэн_, ى۪تہ_, 
   {{0x69c802fa,0x63bdefea,0x61e5efeb,0x2cb808c2}},	//   akde, _nosn, hihl, _àrda_, 
   {{0x61e40b6f,0xa7fd7998,0x34c84f3c,0x26100037}},	//   kihl, ntıy, रन्द, _दीही_, 
   {{0x247c044e,0x69c85b00,0x672c01e4,0xdb1800e8}},	//   _ኣካላት_, ckde, _egaj, _nowé, 
   {{0x61e5efec,0x63bdb85c,0x69ac7220,0x00000000}},	//   dihl, _bosn, जारी, --, 
   {{0x63bc6ffe,0x7ec400b0,0xdb1802bd,0x61e4062c}},	//   _cosn, _kīpā, _powè, eihl, 
   {{0x61e4124c,0x63bdec01,0xaac800bc,0x00000000}},	// [382a0] fihl, _dosn, ाईएक, --, 
   {{0x61e5efed,0x42040063,0x212c0205,0x00000000}},	//   gihl, енуо_, _şehr_, --, 
   {{0xfe6cef2b,0xefc402d3,0xdb180221,0x63bdefee}},	//   ەدى_, _ጸሓይ_, _dowé, _fosn, 
   {{0x63bc0072,0x6e28007c,0x00000000,0x00000000}},	//   _gosn, _sidb, --, --, 
   {{0xfeb4034c,0x490405f9,0x628800e2,0xbea00006}},	//   فاوت_, _सुनो_, _ģeog, лацк, 
   {{0x63bc02fb,0xd9c801ad,0xddc80055,0x60102b96}},	//   _zosn, ाघोट, _iveś, råma, 
   {{0x6e29efef,0xbd402a8b,0x00000000,0x00000000}},	//   _vidb, دنىي, --, --, 
   {{0x1ea805d9,0x798002d0,0x644001e4,0xdcac0137}},	//   _ڪافي_, _abnw, ŭlig, تۉم_, 
   {{0x6e28045a,0x00000000,0x00000000,0x00000000}},	//   _tidb, --, --, --, 
   {{0x7ec4002b,0x69c8017a,0xc0b80092,0x00000000}},	//   _dīpā, ukde, _ተነሣ_, --, 
   {{0xb94801e1,0x787400ee,0x67d40107,0x5a3400cf}},	//   _jẹyá, нйэр_, вону, ннөт, 
   {{0x61e40928,0x2d9c01ed,0x00000000,0x00000000}},	//   zihl, ldve_, --, --, 
   {{0xf8b53acc,0x61e4136f,0xdb080023,0x63bdeff0}},	//   дөө_, yihl, vjeç, _rosn, 
   {{0x63bdeff1,0x00000000,0x00000000,0x00000000}},	//   _sosn, --, --, --, 
   {{0x63bc237d,0x61e5eff2,0xa7fc0205,0x6ab0000d}},	//   _posn, vihl, lrım, _जपुर, 
   {{0x61e402c4,0x672c0427,0x00000000,0x00000000}},	//   wihl, _ugaj, --, --, 
   {{0x61e55f94,0xddc80055,0x63bc0538,0x66f40120}},	// [382b0] tihl, _cveś, _vosn, _шпиу, 
   {{0x63bc020b,0xddc80055,0x947000e5,0x628800de}},	//   _wosn, _dveś, دگیا, _ģeod, 
   {{0x61e5eff3,0xddc800b8,0xa7fc1432,0x63bdeff4}},	//   rihl, _eveś, yrıl, _tosn, 
   {{0x61e42935,0x60c4049b,0xa7fc1f02,0x00000000}},	//   sihl, ryhm, ttıy, --, 
   {{0xee39eff5,0x61e5edd2,0xd35406a9,0x44300135}},	//   ені_, pihl, _שישי_, _hux_, 
   {{0x4429eff6,0x1d0809a5,0x8d60656c,0xa7fc510c}},	//   _hic_, мели_, авше, rtıy, 
   {{0xace800dd,0x44300254,0x50a000d1,0xaf04070e}},	//   ٹرول_, _jux_, _پەنل, кчәк, 
   {{0x4431eff7,0x685402d3,0x6ca416ac,0xa7fc0e2d}},	//   _mux_, _መሰላት, اصول, ptıy, 
   {{0x4431eff8,0x592849a6,0xfb840724,0x3f8c037e}},	//   _lux_, _ལུངས_, _җыен, megu_, 
   {{0x3f8c008c,0x9f4c0139,0x3e78007f,0x00000000}},	//   legu_, _ikeñ_, mêt_, --, 
   {{0x443063ce,0x4429eff9,0x999000dd,0xc8c401d9}},	//   _nux_, _oic_, öző_, نوٝن_, 
   {{0x4429effa,0x3f8c0cfd,0x7ec400b0,0xa7fc0205}},	//   _nic_, negu_, _tīpā, brım, 
   {{0x4431effb,0x7c2801e2,0xa91c0030,0x3e78a573}},	//   _aux_, _iigr, deľu, nêt_, 
   {{0x443045a7,0x7c29bb24,0x4429effc,0xdce047af}},	//   _bux_, _higr, _aic_, _halı, 
   {{0xdce0a493,0x3f8c01c0,0x996000de,0x00000000}},	//   _kalı, kegu_, cīšu_, --, 
   {{0x4429effd,0x44301730,0x3f8c2630,0x7c29effe}},	//   _cic_, _dux_, jegu_, _jigr, 
   {{0x44300231,0x3f8defff,0xdce01d89,0xb86c001f}},	// [382c0] _eux_, degu_, _malı, _በሰጠው_, 
   {{0x85000014,0x3e780142,0xdce003b9,0x00000000}},	//   _چوٝن, dêt_, _lalı, --, 
   {{0x7e7803f0,0x7c2801c3,0x850001d9,0xa6a86a75}},	//   _aqup, _oigr, _نوٝن, _قایق_, 
   {{0x7c291c60,0x4429f000,0xa3a80d2c,0xc3242160}},	//   _nigr, _gic_, _गोप_, ركەن_, 
   {{0x7dcc005c,0xad84c7b0,0x00000000,0x00000000}},	//   _søsa, лқай, --, --, 
   {{0x7c29f001,0x4429f002,0x3f8c00af,0x2d9c003a}},	//   _aigr, _zic_, aegu_, udve_, 
   {{0xdce04952,0x7e780472,0x7c29f003,0x4f940022}},	//   _balı, _equp, _bigr, _ирау, 
   {{0xdb0c006a,0x3f8c03b4,0xbeb40316,0x7c2800cf}},	//   _âkût, cegu_, _šíře, _cigr, 
   {{0xdce006b9,0x16009a53,0xa9340024,0x00000000}},	//   _dalı, लकार_, лепш, --, 
   {{0x7dcc0174,0x7c280142,0x996000e2,0x6f0400db}},	//   _høsn, _eigr, tīšu_, üicu, 
   {{0x6e0000aa,0x7c280067,0xc1540375,0xdce04e7e}},	//   _پېژن, _figr, כשיו_, _falı, 
   {{0x6d59f004,0x7c280522,0xa91c01f1,0x7dcc00cc}},	//   lava, _gigr, deľt, _jøsn, 
   {{0xf40800bd,0x7dcc03b2,0x00000000,0x00000000}},	//   লগার_, _møsn, --, --, 
   {{0x4429f005,0x7dcd0721,0xdce02523,0x7c280156}},	//   _sic_, _løsn, _zalı, _zigr, 
   {{0x4429f006,0xdce01918,0x44310f90,0x6d580158}},	//   _pic_, _yalı, _qux_, iava, 
   {{0x6d59f007,0xdce01248,0x7af07483,0xa7742424}},	//   hava, _xalı, šetš, _слич, 
   {{0x3f8c0ffb,0x44280f85,0x644003b2,0xa91c00d7}},	// [382d0] vegu_, _vic_, ílib, reľu, 
   {{0x6d581326,0x4429f008,0x61542c10,0x3e7806af}},	//   java, _wic_, انائ, vêt_, 
   {{0x64901682,0xf0e80075,0x3f8df009,0x7dcc005c}},	//   _ḽifh, پىنى_, tegu_, _bøsn, 
   {{0x4429f00a,0x5ec0015b,0xa7fc0139,0x00000000}},	//   _uic_, _শেষে, drık, --, 
   {{0x35a809d9,0x7c29f00b,0x6d59f00c,0x00000000}},	//   _छोड़, _rigr, fava, --, 
   {{0x6d59f00d,0x6575f00e,0xdce06655,0x7c29f00f}},	//   gava, ngzh, _salı, _sigr, 
   {{0x7c29f010,0xdce003e3,0x03780055,0x00000000}},	//   _pigr, _palı, _śuṅg, --, 
   {{0xdce0654f,0x6d58013c,0x3f8c009a,0x5a940117}},	//   _qalı, aava, qegu_, гроф, 
   {{0x7c29f011,0x7e780784,0x9df80a5b,0x00000000}},	//   _vigr, _uqup, _знат_, --, 
   {{0xad240131,0xdd9000f1,0xa7fc0205,0x7c280210}},	//   _چىكى, _دوئ_, brık, _wigr, 
   {{0xd7e80724,0xdce07a0e,0xac9402a9,0x88c4009d}},	//   емне_, _talı, _вахш, глэв_, 
   {{0x18a40184,0x1b040f22,0xbbe800c6,0xa9080451}},	//   _ҡалм, শেষে_, _غرام_, ئيٽل_, 
   {{0xeab042b5,0xbb54037e,0x7dcc0fac,0xaba80123}},	//   _وعه_, _sのwe, _jøso, _جهنم_, 
   {{0xaa6401af,0x00000000,0x00000000,0x00000000}},	//   _тешһ, --, --, --, 
   {{0xda1805f9,0x98a40153,0x00000000,0x00000000}},	//   _नीयत_, mblį_, --, --, 
   {{0x6d59f012,0x9424c78c,0xb40443be,0x80a40490}},	//   zava, умбе, рүмд, घटने, 
   {{0x6d59f013,0xd185f014,0x7dcc01bf,0xe35401c6}},	// [382e0] yava, ллай, _røsn, ртсэ, 
   {{0xd058005e,0x64402cd7,0x7644c0dc,0x6d5800d8}},	//   ерді_, ílic, _itiy, xava, 
   {{0x6d59f015,0x8fa51393,0x7644022e,0x76b406be}},	//   vava, лаже, _htiy, _dəyş, 
   {{0x6d59f016,0x339803e6,0x00000000,0x00000000}},	//   wava, _جۆرج_, --, --, 
   {{0x6d59f017,0x9e9407d6,0x00000000,0x00000000}},	//   tava, لاوچ, --, --, 
   {{0xc30400fe,0xbea400ec,0x00000000,0x00000000}},	//   লেহি_, اهون_, --, --, 
   {{0xefbc0020,0xa3a80574,0xbc65f018,0xa0280137}},	//   ሳሳይ_, _गोड_, همون_, رسۅك_, 
   {{0x776400f1,0xfcf00023,0x00000000,0x00000000}},	//   _ndix, _ጎነጽ_, --, --, 
   {{0x76445d0c,0x0ae80597,0xbea00354,0x8e740120}},	//   _ntiy, عربي_, _латк, _љубч, 
   {{0xafe407d6,0x7764005a,0xc278008f,0xfe34011a}},	//   _соғл, _adix, עריי, _ערבי_, 
   {{0x76440bf1,0x28f8759f,0xfc64004b,0x9c58004e}},	//   _atiy, тень_, _مخنی, _ашчу_, 
   {{0x7dcc4e9b,0xc7642f7c,0x00000000,0x00000000}},	//   _løsl, دادى, --, --, 
   {{0xa91c01a2,0xf3fc03d4,0x09e4014b,0x85880024}},	//   teľs, ্ষাৰ_, _йодн, нёва_, 
   {{0x0cb46569,0x76440076,0x77640381,0xc7c400d1}},	//   জনীত, _dtiy, _edix, _әски, 
   {{0x7645f019,0xf5e412fa,0x00000000,0x00000000}},	//   _etiy, сіям, --, --, 
   {{0x78ac02f0,0x00000000,0x00000000,0x00000000}},	//   šivý, --, --, --, 
   {{0xfc3c0232,0xe5e5556a,0x22581064,0x8234104c}},	// [382f0] _čím_, _نزدی, тизы_, اررا, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6445f01a,0x15f4012c,0x237801bf,0x24600153}},	//   _ithi, ँचथर_, _ucsj_, mėm_, 
   {{0x24600153,0x00000000,0x00000000,0x00000000}},	//   lėm_, --, --, --, 
   {{0x22482c3e,0x644402d3,0x00000000,0x00000000}},	//   mpak_, _kthi, --, --, 
   {{0x2249dd90,0xa3b81e61,0xdb080158,0x80bc00fe}},	//   lpak_, चाप_, ljeø, _এইক্, 
   {{0x9e95f01b,0x644452f4,0xa7fc3361,0x5ba82854}},	//   _پارچ, _mthi, nsıd, тким_, 
   {{0x2249f01c,0xafc410de,0xdb080158,0x8b20005b}},	//   npak_, _ايقى, njeø, одъе, 
   {{0x64448479,0x3f9c0093,0x6cc401d9,0x933c0092}},	//   _othi, _hauu_, _گٲمٕ, ያስተዳ, 
   {{0x64440dc7,0x6ce400d6,0x97c5f01d,0xa7fc03e0}},	//   _nthi, _ліце, لقدو, ksıd, 
   {{0x2249f01e,0xcc38010f,0x97540114,0x246000c0}},	//   kpak_, _סענט, штољ, dėm_, 
   {{0x3f9df01f,0xa3b8028a,0x7dcc0fac,0x27f8003e}},	//   _mauu_, चान_, _løsm, érna_, 
   {{0xd9443085,0x3f9c1132,0x98a4147e,0x224801a4}},	//   _теки, _lauu_, _вике, dpak_, 
   {{0x7dcc03cd,0x6aa40327,0x7ddc00c0,0x24600064}},	//   _røsl, _ġifi, _išsė, gėm_, 
   {{0xa3a80c2e,0x764404ba,0x644004d4,0x96a801f0}},	//   _गोद_, _ttiy, ília, _акиб_, 
   {{0x6445f020,0x22482296,0x7645f021,0x11e47fb5}},	// [38300] _ethi, gpak_, _utiy, ажам, 
   {{0x5434bab9,0x644001e4,0x24600064,0x65b8022e}},	//   _پردر, ŭlia, bėm_, _буюр_, 
   {{0x22480280,0x672c0023,0x4f9430ab,0x92d400eb}},	//   apak_, ተዘይብ, ирду, িপে_, 
   {{0x53a5f022,0x53c8d59c,0xe1f00328,0x00000000}},	//   _тамб, _रविश, يسە_, --, 
   {{0xdb18002e,0x8d74007b,0x00000000,0x00000000}},	//   _nowà, لاغا, --, --, 
   {{0x8c6456ff,0x644403ac,0x00000000,0x00000000}},	//   атид, _ythi, --, --, 
   {{0x3f9c0093,0xb5d802f5,0x644400d8,0x8f7400d4}},	//   _fauu_, _সদাচ, _xthi, _вузі, 
   {{0x0b88713a,0xbae40154,0xc330010f,0xa3b8c488}},	//   тски_, _পড়ছ, ֿות_, चाय_, 
   {{0x9e65f023,0x82040327,0x00000000,0x00000000}},	//   _هالن, _ཀཉྩི_, --, --, 
   {{0xa7fc2ca8,0x00000000,0x00000000,0x00000000}},	//   nrıv, --, --, --, 
   {{0x291833f3,0xe75802bf,0x224801c4,0xa7fc00a2}},	//   åra_, лині_, zpak_, hsıe, 
   {{0x0ae9f024,0xe69402f6,0x224803f0,0x6445f025}},	//   _идей_, бимы, ypak_, _rthi, 
   {{0x6445f026,0x9b7410de,0x00000000,0x00000000}},	//   _sthi, _اڭىز_, --, --, 
   {{0x6444003a,0xd8e00327,0x24600153,0x693400db}},	//   _pthi, ེནཡི, tėm_, _унку, 
   {{0xb8e8015b,0xda18000d,0x00000000,0x00000000}},	//   _রে_, _नीित_, --, --, 
   {{0x49901b12,0x2249f027,0xc2f80154,0x9f6403e0}},	//   _ایگر, tpak_, _আরবি_, çtür_, 
   {{0x6444015d,0x05847fa5,0x848c0240,0x00000000}},	// [38310] _wthi, _кунм, _ምፍራሕ_, --, 
   {{0x22480af9,0x65640200,0x24600064,0x00000000}},	//   rpak_, _udhh, pėm_, --, 
   {{0x6445f028,0x27e81529,0x2249f029,0x3f9c20d6}},	//   _uthi, _kman_, spak_, _pauu_, 
   {{0x2fc4004e,0x9ed8010b,0x2248011f,0x00000000}},	//   _comg_, лмет_, ppak_, --, 
   {{0x27e8208d,0x9d451e70,0x25a0002f,0x00000000}},	//   _mman_, белд, _kahl_, --, 
   {{0x629df02a,0x27e8061c,0x25a1f02b,0x22a4014b}},	//   _isso, _lman_, _jahl_, _куҳҳ, 
   {{0x27e9f02c,0x3f9c0418,0x3c9016e0,0x25a01d13}},	//   _oman_, _tauu_, تیاز, _mahl_, 
   {{0x27e9f02d,0x351c0375,0x3ab001e0,0x3a400107}},	//   _nman_, כוונ, жәкт, омиҳ, 
   {{0xa7fc0139,0x00000000,0x00000000,0x00000000}},	//   ksıb, --, --, --, 
   {{0x27e8d0ea,0x25a1f02e,0x2fc4045a,0xa3a8000d}},	//   _aman_, _nahl_, _zomg_, _गोस_, 
   {{0xae0424a7,0x2fc401b9,0x629c0076,0xe8f80032}},	//   _بولى, _yomg_, _lsso, ҫлө_, 
   {{0x629df02f,0x27e80263,0x00000000,0x00000000}},	//   _osso, _cman_, --, --, 
   {{0x7bd80050,0x5928025c,0x5c7401af,0x00000000}},	//   mhuu, _ལུམས_, _тәҙр_, --, 
   {{0x27e9f030,0xd1e8001f,0xe8e805af,0x7bd81aed}},	//   _eman_, ሙበት_, اریو_, lhuu, 
   {{0x200df031,0xc994004b,0xa3a800ab,0x6440008f}},	//   _okei_, _دانګ, _गोह_, ŭlin, 
   {{0x629c01af,0x7bd8a2d1,0x0838008f,0x00000000}},	//   _bsso, nhuu, _געקל, --, 
   {{0x7bd8022f,0x55e4010b,0x52a80153,0x1614000d}},	// [38320] ihuu, _гопб, ывам_, _दीअर_, 
   {{0x200c043b,0x27e807ab,0x7bd80093,0x25a00327}},	//   _akei_, _zman_, hhuu, _gahl_, 
   {{0x629df032,0x7bd974ea,0x27e81529,0xe708fc20}},	//   _esso, khuu, _yman_, _متین_, 
   {{0x25a1f033,0x939469e7,0x27e9f034,0xa7fc0205}},	//   _zahl_, _اجدا, _xman_, msıc, 
   {{0x7bd80a55,0xdfa400c6,0xed5800d7,0x00000000}},	//   dhuu, تحلي, _peľ_, --, 
   {{0x200df035,0x06c802f5,0xfd0c0451,0x21740117}},	//   _ekei_, _লেডি, ڙجي_, _муср, 
   {{0xed5800d0,0x8fa40064,0x7bd80009,0x00000000}},	//   _veľ_, _лаве, fhuu, --, 
   {{0xd009f036,0x7dcc0fac,0x00000000,0x00000000}},	//   _себе_, _løsh, --, --, 
   {{0x3b5000fd,0xa3b87688,0xf1dc000d,0x00000000}},	//   чкыр, चात_, _यतान, --, 
   {{0x27e9f037,0x7bd8208d,0x960062a8,0x4d1401f4}},	//   _sman_, ahuu, लकोट_, _льет, 
   {{0x27e807ab,0x8b648c9e,0xa7b80640,0xc1b8008f}},	//   _pman_, _هاشم, алну_, אמיש, 
   {{0x7bd88928,0x9f4c044e,0x0c24165d,0xc7b4036b}},	//   chuu, _vjeç_, _умен, сқич_, 
   {{0x27e81529,0x25a0009a,0x2d8c030a,0x87040395}},	//   _vman_, _pahl_, _kbde_, сяне, 
   {{0x644006ed,0x68e403f9,0x7dcd65d4,0x00000000}},	//   ílio, _ƙidd, _røsk, --, 
   {{0x69d9f038,0x27e81529,0x7dcc0e38,0x25a1f039}},	//   _ilve, _tman_, _søsk, _vahl_, 
   {{0x25a1f03a,0x363412ea,0xb68800ec,0x8660010a}},	//   _wahl_, _کريس, _ڇپيل_, _ениç, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [38330] --, --, --, --, 
   {{0x200df03b,0xa3a800c5,0xcb40022e,0x2cac0142}},	//   _skei_, _गोर_, _aloќ, _ordd_, 
   {{0x55500014,0x633400f3,0x00000000,0x00000000}},	//   _تھُر, _менђ, --, --, 
   {{0x2d8c016b,0xdea1483d,0xdb080588,0x629c0166}},	//   _abde_, ویزی, ejeý, _tsso, 
   {{0x69d9f03c,0x629c0083,0x2cac0368,0x3e682b97}},	//   _olve, _usso, _ardd_, ушен_, 
   {{0x1c10033f,0xdbd00139,0x00000000,0x00000000}},	//   _डीजल_, _küçl, --, --, 
   {{0x200c0093,0x7bd8009a,0xa7fc1432,0xdb180432}},	//   _tkei_, thuu, nrıs, _kowç, 
   {{0x69d9f03d,0x7bd80093,0xa3d800dc,0x00000000}},	//   _alve, uhuu, ऽसि_, --, 
   {{0x7bd9f03e,0x2d8c0175,0x7dcc03cd,0xea000051}},	//   rhuu, _fbde_, _løsi, _giẫy_, 
   {{0x7bd9f03f,0xc5b8054e,0x628800de,0x9b940066}},	//   shuu, _ţînţ, _ģeol, _ژلات, 
   {{0xd7c8004b,0x7bd8022f,0x7dcc0174,0x00000000}},	//   لوده_, phuu, _nøsi, --, 
   {{0x69d9f040,0x6d5c0086,0x16a82a3b,0xdb1800a2}},	//   _elve, _ôrar, авми_, _nowç, 
   {{0x8f98011a,0xab640006,0x1a6401e2,0x00000000}},	//   בירי, _хвіл, _بیخی_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x04404303,0x00000000,0x00000000,0x00000000}},	//   десн, --, --, --, 
   {{0x7f58937c,0x50b80214,0x7dcc072b,0x497001ee}},	//   _neuq, یداد_, _døsi, _еләс, 
   {{0x98a40ba5,0x3a3c0784,0x69d89da5,0xe6b800a2}},	// [38340] malı_, nqup_, _ylve, _käýä, 
   {{0x98a4ae47,0xa7fc0790,0x50d4009a,0x4220026b}},	//   lalı_, brıs, يزار, ддув, 
   {{0xdbd00365,0x4fa47228,0x00000000,0x00000000}},	//   _güçl, жиев, --, --, 
   {{0x98a49d58,0x6e440124,0x00000000,0x00000000}},	//   nalı_, зҵаз, --, --, 
   {{0x4e95920b,0x2d8c03b2,0xb8f80327,0x00000000}},	//   تشار, _pbde_, _ལཎ_, --, 
   {{0x98a41ae4,0x4718008f,0x00000000,0x00000000}},	//   halı_, בונג, --, --, 
   {{0x98a4956f,0x3b000064,0x25fc0073,0x00000000}},	//   kalı_, _lūpą_, ोवती_, --, 
   {{0x95900023,0x2ff8009f,0x00000000,0x00000000}},	//   _ልዝብን_, _اورگ_, --, --, 
   {{0x98a43235,0x00000000,0x00000000,0x00000000}},	//   dalı_, --, --, --, 
   {{0xa2ac0490,0xc30400cc,0x59b16b62,0xa87400d4}},	//   ीमत्, লেকি_, जागर, плоі, 
   {{0x2cac00a9,0x98a46654,0x399c00e4,0x7de00022}},	//   _urdd_, falı_, _sãsõ_, sãsõ, 
   {{0x3fc40131,0x98a40898,0x00000000,0x00000000}},	//   ﯩﻐﺎﻧ, galı_, --, --, 
   {{0xa3b8256a,0xe5340124,0x00000000,0x00000000}},	//   चास_, зегь, --, --, 
   {{0x69d80ec3,0xdb180036,0x224c03e0,0x00000000}},	//   _ulve, _dowä, _çeki_, --, 
   {{0x1284044e,0xf485f041,0x98a4d16c,0x03c400f5}},	//   _ይርከብ_, мутн, balı_, осам, 
   {{0x98a4d7c2,0x60c800e4,0xb8083592,0x00000000}},	//   calı_, _ńemo, _ويوم_, --, 
   {{0xa2ac0be7,0x934400db,0x00000000,0x00000000}},	// [38350] ीमध्, سىلۇ, --, --, 
   {{0x7f580007,0x41750bd3,0xa158292c,0x00000000}},	//   _seuq, تارس, сажу_, --, 
   {{0x5f94011c,0x00000000,0x00000000,0x00000000}},	//   зиет, --, --, --, 
   {{0x6234c1ef,0xf49442c2,0xe80000bc,0x9cf40150}},	//   _нему, _کشید, ईवटा_, үзді, 
   {{0x7dcc05ac,0x9d44586a,0xc17406c2,0x00000000}},	//   _møsv, пелд, _ودست, --, 
   {{0xdca40075,0xc0c813dc,0x7dcc0fac,0x98a467ab}},	//   заки, _кубе_, _løsv, zalı_, 
   {{0x98a445a5,0xc3040154,0x6dc400db,0x00000000}},	//   yalı_, লেখি_, بۅلۅ, --, 
   {{0x2258037e,0x00000000,0x00000000,0x00000000}},	//   _kwsk_, --, --, --, 
   {{0x6aa46bc8,0x98a41d89,0xf41400d9,0x00000000}},	//   _šifr, valı_, ופק_, --, 
   {{0x3a3c0113,0x00000000,0x00000000,0x00000000}},	//   rqup_, --, --, --, 
   {{0x98a40aba,0x161402e5,0x3a3c0309,0xdb4c0014}},	//   talı_, _दीगर_, squp_, _یێژ_, 
   {{0x6d3401ec,0x8bc4010a,0x00000000,0x00000000}},	//   _تۋىس_, _нихç, --, --, 
   {{0x98a40ba5,0xd6d00014,0x1a643135,0x3a3c013c}},	//   ralı_, رقس_, _عیدی_, qqup_, 
   {{0x98a52d8c,0x00000000,0x00000000,0x00000000}},	//   salı_, --, --, --, 
   {{0x98a44953,0x60100158,0xa7fc4dd9,0x00000000}},	//   palı_, nåms, ssıa, --, 
   {{0xa7fd20de,0xa3a8012d,0xb4f400cf,0x98a40bb9}},	//   lsın, _गोआ_, зүүч, qalı_, 
   {{0x8778011a,0x646000cd,0x00000000,0x00000000}},	// [38360] _האפי, _āviś, --, --, 
   {{0xa7fc4a4a,0x00000000,0x00000000,0x00000000}},	//   nsın, --, --, --, 
   {{0x89c4013f,0x8538011a,0xf8c80b67,0x00000000}},	//   _awoכ_, _לגיי, ाहिय, --, 
   {{0xb4b800e1,0x33b41411,0xa7fc03e0,0x00000000}},	//   चमी_, _تەرر, hsın, --, 
   {{0xa3b82f0a,0xa7fc825f,0xe2800131,0x00000000}},	//   चार_, ksın, _иһти, --, 
   {{0x1ea8f7d1,0x4718008f,0x00000000,0x00000000}},	//   غاني_, זונג, --, --, 
   {{0xa7fc15b7,0x00000000,0x00000000,0x00000000}},	//   dsın, --, --, --, 
   {{0x8ae40212,0x00000000,0x00000000,0x00000000}},	//   зіол, --, --, --, 
   {{0x7dcc05ac,0xd30c00b5,0xabb40124,0xcd3400f2}},	//   _røsv, nｇ_, зақә, _فراب, 
   {{0x64400085,0x2d9847f1,0xb4bc000d,0xa7fc0166}},	//   ílik, _úre_, _आपू_, gsın, 
   {{0xa31809fd,0x6d4802d0,0x49044709,0x39b401c6}},	//   _दर्ज_, _ifda, _सुखो_, члээ_, 
   {{0x27ec0428,0x0c24004e,0x64400115,0xc3040154}},	//   òen_, _эмен, ŭlik, লেটি_, 
   {{0xa7fc0139,0xb764009d,0x00000000,0x00000000}},	//   bsın, этэй, --, --, 
   {{0x49b8065f,0x473400e5,0xc984678e,0x00000000}},	//   _داؤد_, _کرغز, _رشتي, --, 
   {{0xa3b83885,0x7c2c013d,0x00000000,0x00000000}},	//   चाल_, _çirä, --, --, 
   {{0x7dcc00d6,0x00000000,0x00000000,0x00000000}},	//   _høst, --, --, --, 
   {{0x6d4801f5,0x7dcc03b2,0xed5800d0,0x00000000}},	// [38370] _ofda, _køst, _hoľu_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x635400ee,0x00000000,0x00000000,0x00000000}},	//   _овну, --, --, --, 
   {{0x6d49f042,0xa7fc03ee,0x7dcd3280,0x75f800d0}},	//   _afda, zsın, _løst, _väzň, 
   {{0x9ac40083,0x25080330,0x82a4008e,0x00000000}},	//   _kuŋŋ, _درکی_, _эшне, --, 
   {{0x7dcc4673,0x99dc02e2,0xf1a4033a,0xbdc401f4}},	//   _nøst, npňt, _прсн, ящей, 
   {{0x6d480175,0xad64015e,0xfc3c01ef,0x00000000}},	//   _dfda, راوه, _čís_, --, 
   {{0x82e803bd,0x6d48035a,0x6f84009d,0x4904000d}},	//   _ལྟོའ, _efda, _пууж, _सँजो_, 
   {{0x6d48022e,0xd12c01d9,0x291804cc,0xcf90011a}},	//   _ffda, _مۅے_, üran_, _בטן_, 
   {{0x27e0003d,0x224c0240,0xa3b800c5,0x00000000}},	//   _ċina_, _çeku_, चाँ_, --, 
   {{0xa7fc12ca,0x68e403f9,0x5cd4484d,0x50d800df}},	//   rsın, _ƙida, _تقاط, ַקשא, 
   {{0xec240372,0x00000000,0x00000000,0x00000000}},	//   _كىلپ, --, --, --, 
   {{0x7bc8eb18,0x7dcc06ea,0xd70801ec,0xa7fc9f9f}},	//   _iogu, _føst, інге_, psın, 
   {{0x7bc80124,0xa7fc723e,0xcb2400f1,0x00000000}},	//   _hogu, qsın, _غړيو_, --, 
   {{0x7bc9f043,0xb4b81a04,0x00000000,0x00000000}},	//   _kogu, चमे_, --, --, 
   {{0x7dcc0162,0x7ec4002b,0xc3040154,0xa7fdf044}},	//   _køss, _kūpā, লেছি_, nsıl, 
   {{0x7bc804b9,0x00000000,0x00000000,0x00000000}},	// [38380] _mogu, --, --, --, 
   {{0x7bc9f045,0x7dcc0158,0x020000c2,0xe3b80107}},	//   _logu, _møss, взун, обӣ_, 
   {{0x7dcc26ff,0x7bc80cad,0xd01001b9,0x7ec400de}},	//   _løss, _oogu, پلش_, _lūpā, 
   {{0x7bc82af2,0x3e340023,0x00000000,0x00000000}},	//   _nogu, _እተዛረ, --, --, 
   {{0x27f801d3,0x8678010f,0x00000000,0x00000000}},	//   érni_, ַרקו, --, --, 
   {{0x7bc80489,0x00000000,0x00000000,0x00000000}},	//   _aogu, --, --, --, 
   {{0x7dcc12ed,0x7bc9f046,0x207407d8,0x35700023}},	//   _røst, _bogu, _путё, ስሳታት_, 
   {{0x7bc977f5,0x7dcc08d7,0x425001d3,0x00000000}},	//   _cogu, _søst, _سنہر, --, 
   {{0x0d853435,0x798002d0,0x00000000,0x00000000}},	//   _олан, _bcnw, --, --, 
   {{0x798003ac,0x7dcc12e8,0x7e2000c0,0x00000000}},	//   _ccnw, _døss, _адуж, --, 
   {{0x2d9c069c,0x7bc89b4c,0x00000000,0x00000000}},	//   meve_, _fogu, --, --, 
   {{0x2d9df047,0xdab400db,0x00000000,0x00000000}},	//   leve_, بۇۇت_, --, --, 
   {{0xa2fc033f,0xfb841079,0xbb404c87,0xf40403d4}},	//   _एशेज_, _آدمی, _речк, লতাৰ_, 
   {{0x7bc9f048,0x2d9df049,0x809c0037,0x00000000}},	//   _zogu, neve_, _गईले, --, 
   {{0x7bc9f04a,0x83c800d8,0xa7fc1f02,0x00000000}},	//   _yogu, оѓаа_, lsım, --, 
   {{0x2d9df04b,0x7bc81709,0x6b801e92,0xd5b8016c}},	//   heve_, _xogu, ngmg, осӣ_, 
   {{0x4e0c0034,0x2d9df04c,0xa7fc083c,0x24980066}},	// [38390] ाकाई_, keve_, nsım, _کنجد_, 
   {{0x2d9c0439,0x7dcc08cb,0xc1781867,0x00000000}},	//   jeve_, _løsr, تصرا_, --, 
   {{0x2d9df04d,0xdb0c145e,0x996000e2,0x1f7402e8}},	//   deve_, _âköt, nūšu_, елея, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2d9df04e,0x7bc86c01,0x809c07f7,0xb40801c6}},	//   feve_, _rogu, _गैरे, _цээж_, 
   {{0x7bc96741,0x7ec40882,0xf28801d9,0x7dcc2dba}},	//   _sogu, _rūpā, _تھٲو_, _røss, 
   {{0x7bc9f04f,0x7ec40055,0x00000000,0x00000000}},	//   _pogu, _sūpā, --, --, 
   {{0x2d9c003a,0x2e20067c,0x201802d2,0x00000000}},	//   aeve_, ròfa_, _ósi_, --, 
   {{0x2d9c0023,0xa7fc1b0d,0x6ffc02e2,0x00000000}},	//   beve_, rsıl, dčch, --, 
   {{0x2d9df050,0x7bc9f051,0xdb08017a,0x00000000}},	//   ceve_, _wogu, ldeë, --, 
   {{0x7bc9f052,0xfe1804af,0x00000000,0x00000000}},	//   _togu, _पीएस_, --, --, 
   {{0x7ec404fe,0xad24237e,0x00000000,0x00000000}},	//   _tūpā, _شىنى, --, --, 
   {{0xa3b8228d,0x96b9bc90,0xb4e8000d,0x00000000}},	//   चाई_, чуну_, _मेड़_, --, 
   {{0x99600171,0x00000000,0x00000000,0x00000000}},	//   būšu_, --, --, --, 
   {{0x809c1d8a,0xdb180036,0xa2cc0154,0x41f800dc}},	//   _गैले, _onwë, _রেলও, ्वैः_, 
   {{0x03a0d5ec,0x2d9df053,0x045400c6,0x00000000}},	//   лисо, zeve_, علقة_, --, 
   {{0x27f8067c,0xfe0ca4cd,0xc68c01c8,0x00000000}},	// [383a0] èrne_, िवास_, _هِي_, --, 
   {{0x06540a1e,0x63b8025c,0xc17c0064,0x00000000}},	//   _רייך_, _ħanż, _žėri_, --, 
   {{0x2d9df054,0xc32c0014,0x00000000,0x00000000}},	//   veve_, لٕہ_, --, --, 
   {{0x10154855,0x2d9c014b,0x24f40006,0x00000000}},	//   رباد, weve_, _шчыр, --, 
   {{0x2d9df055,0xa3a80254,0x644002f0,0x00000000}},	//   teve_, _गोट_, íliv, --, 
   {{0xd1c80228,0xbb800075,0xc69000df,0x00000000}},	//   _элге_, ۇلىي, טאד_, --, 
   {{0x2d9df056,0xfe6c08c9,0x7dcc0158,0x29cc0055}},	//   reve_, لگە_, _pøsr, _jñaś_, 
   {{0x2d9df057,0x291804cc,0xa3b807f7,0x00000000}},	//   seve_, üram_, चाए_, --, 
   {{0x2d9c09cb,0xc984af86,0xaab8132f,0x9c44009d}},	//   peve_, нуни, بگار_, нхөл, 
   {{0x2d9c0023,0xaa580092,0xa7fc0205,0x00000000}},	//   qeve_, _ያደረጋ, rsım, --, 
   {{0x29195bc5,0x6d5802c4,0xde4c0023,0x8cb40354}},	//   æra_, mbva, _ዝተዓወ, _ясач, 
   {{0xf7440120,0xa7fc03e0,0x00000000,0x00000000}},	//   леџо, msık, --, --, 
   {{0xa7fc03e0,0x00000000,0x00000000,0x00000000}},	//   lsık, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x34940588,0x98a40032,0x24180006,0x35b40022}},	//   ларр, _ауыҙ, довы_, ыбрр, 
   {{0x75d80259,0x66b4035b,0x69c801e6,0x4784004e}},	//   _ağzı, _абиу, ljde, _чыкб, 
   {{0xddc800a3,0x00000000,0x00000000,0x00000000}},	// [383b0] _steō, --, --, --, 
   {{0xf65031ed,0x00000000,0x00000000,0x00000000}},	//   _ائي_, --, --, --, 
   {{0x250802e1,0x69c9f058,0x00000000,0x00000000}},	//   _زردی_, ijde, --, --, 
   {{0x645401f5,0xf77400df,0xa3d4005a,0x00000000}},	//   mpzi, ָקס_, _ромч, --, 
   {{0xd3440345,0x00000000,0x00000000,0x00000000}},	//   _شیله_, --, --, --, 
   {{0x6454007c,0x00000000,0x00000000,0x00000000}},	//   opzi, --, --, --, 
   {{0x63adf059,0x628c023a,0x10340137,0x00000000}},	//   odan, ltao, ربۅگ, --, 
   {{0xac440214,0xdd9001d3,0x00000000,0x00000000}},	//   دئوه, اوں_, --, --, 
   {{0x628df05a,0x5e600131,0x6d58007c,0x00000000}},	//   ntao, _ئۆتە, bbva, --, 
   {{0x63ac0097,0x201c0784,0x628c00b0,0x00000000}},	//   hdan, llwi_, itao, --, 
   {{0x63adf05b,0xac7465fe,0xaa580020,0x9b9400c6}},	//   kdan, _مانش, _ያደርጋ, _للات, 
   {{0x63adf05c,0x628c03cd,0x201c007f,0x2cb80332}},	//   jdan, ktao, nlwi_, _árda_, 
   {{0x63adf05d,0x7bd80194,0x00000000,0x00000000}},	//   ddan, mkuu, --, --, 
   {{0x63adf05e,0x201c014b,0x63bdf05f,0x7bd9f060}},	//   edan, hlwi_, _ansn, lkuu, 
   {{0xc560c8cb,0x00000000,0x00000000,0x00000000}},	//   ркск, --, --, --, 
   {{0x63adf061,0x657802b5,0x7bd97088,0xa3b801ad}},	//   gdan, _ēwhe, nkuu, चाग_, 
   {{0x628c089c,0xc2400228,0x7bd80083,0x03a17d74}},	// [383c0] gtao, интк, ikuu, шито, 
   {{0x63adf062,0x63bc0076,0x86780375,0xd4f40166}},	//   adan, _ensn, _קריו, _аямы, 
   {{0x63adf063,0x7bd9f064,0x8fa4f631,0x628c0d04}},	//   bdan, kkuu, каже, atao, 
   {{0x76440a73,0x63adf065,0x7764005a,0xd2940022}},	//   _kuiy, cdan, _jeix, _иргь, 
   {{0xb8d0003d,0x7765df90,0x6e95b64f,0x7bd80009}},	//   _ཝན_, _meix, التا, dkuu, 
   {{0x77640077,0x76440083,0x7bd9f066,0x27100208}},	//   _leix, _muiy, ekuu, ễng_, 
   {{0xbca00a2c,0xad240131,0x321800d7,0x6d58002f}},	//   لموي, دىغى, _ikry_, rbva, 
   {{0x77647a26,0x7bd80254,0x00000000,0x00000000}},	//   _neix, gkuu, --, --, 
   {{0x6af401e2,0x00000000,0x00000000,0x00000000}},	//   دګار, --, --, --, 
   {{0x7bd874e0,0x00000000,0x00000000,0x00000000}},	//   akuu, --, --, --, 
   {{0x63ac4944,0x77640226,0x41780375,0x67d4499d}},	//   ydan, _beix, וניב, гону, 
   {{0x63ad2d37,0x3834084c,0xdbd0010e,0x67fc00e4}},	//   xdan, инэр, _küýl, kũje, 
   {{0x7765f067,0x63ac05a1,0x051c00bd,0xdb180432}},	//   _deix, vdan, _দলের_, _kowý, 
   {{0x76440198,0xf42000fe,0x00000000,0x00000000}},	//   _duiy, _মূলৰ_, --, --, 
   {{0x06c802a6,0x7765f068,0x63adf069,0x00000000}},	//   _লেখি, _feix, tdan, --, 
   {{0x77658d9f,0x645404cc,0x628c16ca,0x00000000}},	//   _geix, rpzi, ttao, --, 
   {{0x7645f06a,0x291c829d,0xb36402e8,0xf4340276}},	// [383d0] _guiy, _hyva_, ръск, ретэ, 
   {{0x63adf06b,0x628c4b54,0xcfd80150,0xc0e40014}},	//   sdan, rtao, _ﺃﺠﻭﺒ, پہرن_, 
   {{0x20843306,0x628df06c,0x201c0770,0x63adf06d}},	//   الصّ, stao, tlwi_, pdan, 
   {{0x6615f06e,0x63adf06f,0x7764004e,0x764400b5}},	//   lozk, qdan, _xeix, _yuiy, 
   {{0x201c07ab,0x6445f070,0x26d80009,0xb2740006}},	//   rlwi_, _huhi, nyso_, _кляш, 
   {{0x6445f071,0xee3810f5,0x27f80113,0x6615f072}},	//   _kuhi, вні_, hisn_, nozk, 
   {{0x6444007d,0x656400c5,0x7bd80e03,0x00000000}},	//   _juhi, _mehh, tkuu, --, 
   {{0x6445f073,0x656459fc,0x7bd8311e,0x6614005a}},	//   _muhi, _lehh, ukuu, hozk, 
   {{0x44280585,0x776441a0,0x6614d030,0x6444047e}},	//   _mhc_, _reix, kozk, _luhi, 
   {{0x77652d8e,0x7bd9f074,0x6565f075,0x236922b8}},	//   _seix, skuu, _nehh, haaj_, 
   {{0x7765138e,0x6445f076,0x661401c4,0xdbd00037}},	//   _peix, _nuhi, dozk, _küül, 
   {{0x6564003e,0x442801f7,0x236866a6,0x2b1402e3}},	//   _aehh, _nhc_, jaaj_, ịkọ_, 
   {{0xe9a9c7e7,0x644400af,0xa7fc1cce,0x27f85051}},	//   ردین_, _auhi, nrıy, èrna_, 
   {{0x6445f077,0x661401c0,0x22480429,0x00000000}},	//   _buhi, gozk, dqak_, --, 
   {{0x7765f078,0x6564020b,0xd17402dd,0x291c0153}},	//   _teix, _dehh, ғызы, _gyva_, 
   {{0x65640093,0x4429a4f3,0x6445f079,0x764404ba}},	//   _eehh, _chc_, _duhi, _tuiy, 
   {{0x64440270,0x6615f07a,0xb16400fb,0x00000000}},	// [383e0] _euhi, bozk, инаһ, --, 
   {{0x644403a0,0x4429c7a1,0x91641ec7,0x67fc0124}},	//   _fuhi, _ehc_, اهاه, rũje, 
   {{0x64440537,0x22480429,0x44280798,0x6474008e}},	//   _guhi, aqak_, _fhc_, _кыяф, 
   {{0x44280618,0x4f0823d6,0x6564014b,0x61f4030a}},	//   _ghc_, ннен_, _zehh, _emzl, 
   {{0x6564293d,0xdce00327,0x6445a3ea,0x69a401f9}},	//   _yehh, _felċ, _zuhi, _कसली, 
   {{0xc6900302,0x0ca87f95,0xdb18010e,0x6c54490c}},	//   צאו_, етии_, _dowü, акку, 
   {{0x9f4c0295,0xe944036b,0xa3b80490,0x4125f07b}},	//   _ejeñ_, یردی, चाच_, _боро_, 
   {{0x75f403be,0x6614005a,0x4090ba4f,0xdbd0010e}},	//   _düzə, zozk, _دلفر, _tüýl, 
   {{0x291c00c7,0x1ea80be2,0xccc401e0,0xdd240153}},	//   _syva_, _لالي_, _әбей, rūši, 
   {{0x8c45f07c,0x26d800c7,0x9f5c01e1,0x00000000}},	//   _беже, vyso_, bowó_, --, 
   {{0x02140302,0x656405d5,0x75f400ac,0xe8940a89}},	//   רחים_, _rehh, _güzə, шань, 
   {{0x6565f07d,0x013408c3,0x00000000,0x00000000}},	//   _sehh, טרית_, --, --, 
   {{0x6445f07e,0xd1c80020,0xdb18033f,0x6614009d}},	//   _suhi, _በጀት_, _dowó, tozk, 
   {{0x6445f07f,0x6564014f,0xd8f4158b,0x26d800d7}},	//   _puhi, _qehh, ازیک, ryso_, 
   {{0xe534034b,0x6615f080,0x656597dd,0xb8e80183}},	//   ревь, rozk, _vehh, _ৰে_, 
   {{0x644535e8,0x65640117,0x661401c4,0xf364f3d3}},	//   _vuhi, _wehh, sozk, йтун, 
   {{0x236835a3,0x4428b4a2,0x6565f081,0x2bdc000d}},	// [383f0] raaj_, _vhc_, _tehh, _बवना, 
   {{0x64441f4c,0xdb18033b,0xdbd00254,0xa7fc0205}},	//   _tuhi, _kowò, _süül, vrıy, 
   {{0x2458a5de,0x00000000,0x00000000,0x00000000}},	//   _шань_, --, --, --, 
   {{0x9ed8280b,0x442804cc,0x234807d6,0xbf642a9f}},	//   кмет_, _uhc_, _جسدی_, اداو, 
   {{0xea00001e,0x224913f4,0x75f406be,0xcfa40022}},	//   _giầy_, qqak_, _süzə, рыхҩ, 
   {{0x629c0483,0x91c050e5,0x1278008f,0x7c280334}},	//   _ipso, _мәхл, _באשע, _shgr, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x99e40e92,0xc4b00aff,0xfe7401af,0x7ee400c0}},	//   ижид, ुमुख, _сүл_, _сцве, 
   {{0xdb18007f,0xfc6402e8,0xdce001ef,0x00000000}},	//   _bowò, _бъдн, _helč, --, 
   {{0xdb180034,0x97c4716a,0x00000000,0x00000000}},	//   _powó, айне, --, --, 
   {{0x629df082,0x5b140801,0xdce01710,0x1a78010b}},	//   _opso, _кмет, _jelč, _абды_, 
   {{0x629c0175,0x7b4400d0,0x00000000,0x00000000}},	//   _npso, rčuľ, --, --, 
   {{0xeaf81c40,0xdb18033b,0xe8f801ec,0xad9c0419}},	//   _حرمت_, _fowò, _өлі_, _skĺz, 
   {{0x629c1326,0xb0a40034,0x93440c69,0xbb2801ec}},	//   _apso, _गैंग, инве, _ﺤﺎﻥ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
  
   {{0xdef800e8,0x2d9801d3,0x51640212,0x00000000}},	// [38400] _deŋk_, _öreg_, иваб, --, 
   {{0x68e4012c,0x5154054a,0xdebc0023,0xdbd00432}},	//   _řidi, ртау, _ሰደኤ_, _müñl, 
   {{0x10a4228c,0x68e402a8,0xe00002ab,0xcf44751d}},	//   риен, _ƙidi, लचंद_, аней, 
   {{0x2e20007f,0xb6300150,0x64c4009f,0x00000000}},	//   mòfi_, _ﺒﻼ_, _ايٽل, --, 
   {{0xdce0e126,0x9e9401d5,0x630400ec,0x6cb4009d}},	//   _delč, ماوچ, _هوٽل, өөжт, 
   {{0x9ba40014,0x00000000,0x00000000,0x00000000}},	//   ۅلى۪, --, --, --, 
   {{0xcbe41d9d,0x8fa4d05b,0xdce00064,0x4fa4010a}},	//   иции, _каве, _felč, _кивв, 
   {{0xa7fc03ee,0xfc2c00c6,0x629c0334,0x00000000}},	//   nsıt, وحي_, _ypso, --, 
   {{0xea18130f,0xf07801af,0x00000000,0x00000000}},	//   лжиш_, _шиңә_, --, --, 
   {{0xafe4036b,0xbd8400db,0xdce000ef,0x00000000}},	//   _тоғл, _ەنەن_, _zelč, --, 
   {{0xbe100c78,0xcb0805d9,0xa81401f0,0xa91c00d7}},	//   _بولع, _ڌيان_, йдош, rgľo, 
   {{0xfb800022,0x00000000,0x00000000,0x00000000}},	//   _дышн, --, --, --, 
   {{0xdbd000a2,0x803400df,0x1bf800df,0x00000000}},	//   _güñl, ינטע_, _גלײב, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa8840eff,0x00000000,0x00000000,0x00000000}},	//   _العى, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x809c068f,0xe6940597,0x62242f7c,0x22580108}},	// [38410] _गैजे, _الخد, مىرل, уизы_, 
   {{0xc05800d3,0x00000000,0x00000000,0x00000000}},	//   від_, --, --, --, 
   {{0xea0007ae,0xb63400db,0x3568005b,0xdce000ef}},	//   _giấy_, _بةيش, _трын_, _pelč, 
   {{0xa294187f,0x00000000,0x00000000,0x00000000}},	//   _ламі, --, --, --, 
   {{0x75e4063f,0x539802e4,0x8c400032,0xdce002f0}},	//   _ọziz, _גירו, үеше, _velč, 
   {{0x1d085915,0x00000000,0x00000000,0x00000000}},	//   лели_, --, --, --, 
   {{0xddc8084c,0xa7fc00ac,0x2cac00e2,0xdce0013a}},	//   _aveţ, nsıs, _csdd_, _telč, 
   {{0x5ff5f083,0x5ba8009b,0x00000000,0x00000000}},	//   _узбу, уким_, --, --, 
   {{0x3da4009b,0x00000000,0x00000000,0x00000000}},	//   _вреб, --, --, --, 
   {{0x3940005c,0xa7fc0205,0x00000000,0x00000000}},	//   øjs_, ksıs, --, --, 
   {{0xd9440131,0x9cb401e2,0x00000000,0x00000000}},	//   _һели, _دمات, --, --, 
   {{0xa924009d,0x00000000,0x00000000,0x00000000}},	//   өдөл, --, --, --, 
   {{0x05c00034,0x07a01214,0xd9440408,0xbac81291}},	//   शांब, чаян, _лели, _جذام_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69dc01f4,0x00000000,0x00000000,0x00000000}},	//   öree, --, --, --, 
   {{0x93441d39,0x00000000,0x00000000,0x00000000}},	//   снае, --, --, --, 
   {{0x6280002b,0x98a403b9,0x11e401a9,0x8350072d}},	// [38420] _āloc, mblı_, бжам, سپلا, 
   {{0x321c0109,0xdb0800a3,0x00000000,0x00000000}},	//   ôvy_, ideà, --, --, 
   {{0x2d8c004e,0x0fd9f084,0x53a40137,0xd05800d4}},	//   _rcde_, льды_, _ланб, урзі_, 
   {{0xe6b42099,0xd1b000f1,0x00000000,0x00000000}},	//   _الیگ, _ډیرک, --, --, 
   {{0x2d8c0205,0x00000000,0x00000000,0x00000000}},	//   _pcde_, --, --, --, 
   {{0x7dcc01bf,0xad8400cf,0x00000000,0x00000000}},	//   _køsy, زاتۇ, --, --, 
   {{0x8f740153,0x00000000,0x00000000,0x00000000}},	//   _гузі, --, --, --, 
   {{0xaa540063,0x0b8877a4,0xebd863dd,0xc00010fc}},	//   овиш, уски_, рдиш_, _епск, 
   {{0x8aa401d5,0xf1dc012d,0xa7fc0205,0x00000000}},	//   ёрид, _मकान, ksır, --, 
   {{0x7cd40214,0x00000000,0x00000000,0x00000000}},	//   _گومز_, --, --, --, 
   {{0x2fc401f5,0x00000000,0x00000000,0x00000000}},	//   _knmg_, --, --, --, 
   {{0x69dc01e3,0xc38401e1,0x00000000,0x00000000}},	//   öreb, bẹ̀ẹ, --, --, 
   {{0xdce0005f,0xfaa000d8,0xbab4007b,0x6a8801ee}},	//   _ielā, _нацо, _هدوء_, _төйм_, 
   {{0x291807c5,0x78500356,0x00000000,0x00000000}},	//   üras_, _săve, --, --, 
   {{0x67d4014b,0x00000000,0x00000000,0x00000000}},	//   _моку, --, --, --, 
   {{0xa7fc0205,0x00000000,0x00000000,0x00000000}},	//   rsıs, --, --, --, 
   {{0x27e9f085,0xaee40882,0xdce000de,0xb79400ae}},	// [38430] _ilan_, rvṛt, _melā, _رؤيت, 
   {{0x672c0230,0x27e805c7,0xdb080077,0x91c0070e}},	//   _izaj, _hlan_, ndeá, мәсл, 
   {{0xa3d40902,0x81740107,0xb525f086,0x00000000}},	//   _донч, _қавӣ_, _ньюк, --, 
   {{0xdb0800c6,0x7a2c168c,0x27e8003e,0xdce00171}},	//   hdeá, møte, _jlan_, _nelā, 
   {{0x27e9f087,0x7a2c0fac,0xb28400c0,0x00000000}},	//   _mlan_, løte, _нырк, --, 
   {{0x27e803cb,0x22580419,0x00000000,0x00000000}},	//   _llan_, _itsk_, --, --, 
   {{0x27e93a66,0x7a2c0158,0xdce000d7,0x00000000}},	//   _olan_, nøte, _velď, --, 
   {{0x8c41f088,0x672c00d0,0xefbc0092,0x6994009d}},	//   меще, _ozaj, ዳታው_, үрэх, 
   {{0x672c0526,0x62480cf4,0xdea028e3,0x00000000}},	//   _nzaj, _džog, _آیتی, --, 
   {{0x27e9f089,0x7c84030d,0x00000000,0x00000000}},	//   _alan_, _гуде, --, --, 
   {{0x27e9f08a,0xdce00270,0x672df08b,0x7a2c1445}},	//   _blan_, _felā, _azaj, jøte, 
   {{0x27e82517,0x8ca40073,0x00000000,0x00000000}},	//   _clan_, चबरो, --, --, 
   {{0xfb240eff,0x291807de,0x672c033f,0x7dcc01bf}},	//   _اراپ, ürar_, _czaj, _søsy, 
   {{0x27e9f08c,0xcb340302,0x672c006f,0x7a2c05ac}},	//   _elan_, _ואני_, _dzaj, føte, 
   {{0x672c0083,0x62800421,0xd4680220,0x200c00c7}},	//   _ezaj, _āloa, рибе_, _ojei_, 
   {{0x27e897ef,0x56e001ec,0x00000000,0x00000000}},	//   _glan_, _жұмғ, --, --, 
   {{0x0838010f,0xdc385043,0x00000000,0x00000000}},	// [38440] _דעקל, nçın, --, --, 
   {{0x51840736,0x7a2c03cd,0x51580006,0x00000000}},	//   تشرق, bøte, ршаў_, --, 
   {{0x27e800a2,0x00000000,0x00000000,0x00000000}},	//   _ylan_, --, --, --, 
   {{0x61380108,0xdc386b5f,0x00000000,0x00000000}},	//   счур_, kçın, --, --, 
   {{0x2d58d226,0xddc9f08d,0x47980a7c,0xb0040055}},	//   биль_, _sveš, שינס, _naḥp, 
   {{0xddc80316,0x624800f3,0x00000000,0x00000000}},	//   _kteř, _džod, --, --, 
   {{0xbd840ccb,0xebc46b62,0xbb480150,0xdce00055}},	//   زنين_, зәлн, _ﺂﺨﻲ_, _pelā, 
   {{0xd0089f59,0x60c05c0c,0x394401c3,0x2d8149ab}},	//   _тебе_, _álma, _agns_, şie_, 
   {{0x49a40120,0xdce000dc,0x00000000,0x00000000}},	//   ојна, _velā, --, --, 
   {{0x27e9f08e,0x00000000,0x00000000,0x00000000}},	//   _slan_, --, --, --, 
   {{0x27e8ea8a,0x6d48a580,0x7f800150,0x597008dc}},	//   _plan_, _igda, _رلەن, رگوز, 
   {{0x394404cc,0x8ae4003b,0x00000000,0x00000000}},	//   _egns_, _мілл, --, --, 
   {{0xca740131,0x6d5c00c7,0x27e8045a,0x092000cc}},	//   _بەخت_, _õras, _vlan_, _নলওঁ_, 
   {{0x27e9f08f,0xda6400aa,0x672cfada,0x7a2c00d4}},	//   _wlan_, _راهي, _vzaj, tøte, 
   {{0x69d9f090,0x672c033f,0xf98c0956,0x00000000}},	//   _iove, _wzaj, _شبو_, --, 
   {{0x69d80ac7,0x27e9f091,0xe2f80046,0x7a2c05ac}},	//   _hove, _ulan_, бебі_, røte, 
   {{0xf771f092,0x672df093,0x6d480857,0xea000051}},	// [38450] _شاي_, _uzaj, _ogda, _nhẫy_, 
   {{0x69d9f094,0x45a0167e,0x6d48daab,0xc2d801e1}},	//   _jove, _تەسك, _ngda, _ọ̀mù, 
   {{0x69d9f095,0xef58063f,0x2418010a,0x00000000}},	//   _move, _ịfụn, _гоны_, --, 
   {{0x69d9f096,0x6d49f097,0x225800d7,0x00000000}},	//   _love, _agda, _ttsk_, --, 
   {{0x81d42158,0x225800cc,0xfe540f01,0x69d8127b}},	//   ়োগ_, _utsk_, زیاب_, _oove, 
   {{0xdce00311,0xbdc4005b,0xf1a401c6,0x3ce40118}},	//   _nelă, ющей, _орсн, जनले_, 
   {{0x200c032e,0x00000000,0x00000000,0x00000000}},	//   _tjei_, --, --, --, 
   {{0xcf8c11fc,0x69d80165,0xdc383bc1,0x6d48035a}},	//   _مژه_, _aove, tçın, _egda, 
   {{0x69d80460,0x3f9c020c,0xab44001f,0x3d140073}},	//   _bove, _ibuu_, _የኢየሱ, _फडके_, 
   {{0xab0812b7,0x69d822a1,0x61e40649,0x991401ce}},	//   تتىق_, _cove, nkhl, зьмі, 
   {{0xd7c85da7,0x49c405f5,0xd82416a8,0x00000000}},	//   موده_, члэн_, здни, --, 
   {{0x3ebdf098,0x201c0034,0xed048e98,0x00000000}},	//   _krut_, nowi_, _تومپ, --, 
   {{0x1cd80156,0x69d81730,0x3f9c0099,0x3ebc00d5}},	//   ོརམ_, _fove, _mbuu_, _jrut_, 
   {{0x69d9f099,0x75f00139,0x00000000,0x00000000}},	//   _gove, _mäzg, --, --, 
   {{0x3f9c016b,0x201df09a,0x00000000,0x00000000}},	//   _obuu_, kowi_, --, --, 
   {{0x69d9f09b,0x201d4f36,0xddc8012c,0x48780375}},	//   _zove, jowi_, _vteř, _הטקס, 
   {{0x69d80b6f,0xb3780023,0x201d79f7,0x82a0010b}},	// [38460] _yove, _ክኽውን_, dowi_, натж, 
   {{0x69d80f71,0x422003b7,0x3f9df09c,0xd9a80073}},	//   _xove, едув, _abuu_, _कसोट, 
   {{0x947400c6,0x4fa43ed6,0x4fc40212,0x0080014b}},	//   _عددا, зиев, зсла, елхо, 
   {{0x61e403a2,0x6249f09d,0x804400c7,0x527422cb}},	//   akhl, _džob, _ẽtég, _нугу, 
   {{0x6d480280,0xe81c121d,0xff054d06,0x3db800d1}},	//   _pgda, नवता_, пецк_, ﻠﻠﯩﺘ, 
   {{0x8c640131,0x3ebc0210,0x00000000,0x00000000}},	//   птид, _drut_, --, --, 
   {{0x69d9f09e,0xc02400f1,0x201c0210,0x00000000}},	//   _rove, _کړله_, bowi_, --, 
   {{0x3ebdf09f,0x60180724,0x69d86945,0x3f9c01e1}},	//   _frut_, _cämğ, _sove, _gbuu_, 
   {{0xfbcc1473,0x3ebc0225,0x6d4800f3,0x0d840408}},	//   اتى_, _grut_, _tgda, _нлан, 
   {{0x3ea401d9,0xe9f81ae2,0xea000208,0x6d49f0a0}},	//   _عشقہ, інні_, _khẩy_, _ugda, 
   {{0xdb1803fa,0x63a80113,0x69d9f0a1,0x2e200ba1}},	//   _anwä, _ñeng, _vove, sòfs_, 
   {{0x69d9f0a2,0x00000000,0x00000000,0x00000000}},	//   _wove, --, --, --, 
   {{0x9f4c049f,0x59700075,0x00000000,0x00000000}},	//   _umeå_, رگۈز, --, --, 
   {{0x69d828b3,0xca740032,0x7a7800d9,0xbb38011a}},	//   _uove, _дуҫы, _פרוס, _העדי, 
   {{0x128402d3,0xc7ac00e8,0xea00004d,0xaa58009f}},	//   _ክርከብ_, _njёg_, _nhẩy_, _الڪا_, 
   {{0x6844009f,0x00000000,0x00000000,0x00000000}},	//   _تَعل, --, --, --, 
   {{0x06240276,0x61d8c133,0x7a2c0162,0xdb0803e0}},	// [38470] _нфом, омая_, løta, rdeç, 
   {{0x201df0a3,0x00000000,0x00000000,0x00000000}},	//   wowi_, --, --, --, 
   {{0x5f946134,0x201c033f,0x00000000,0x00000000}},	//   диет, towi_, --, --, 
   {{0x3ebdf0a4,0xdb080158,0xd9a80141,0x00000000}},	//   _prut_, ldeå, _कस्ट, --, 
   {{0xbb1408b0,0x201c033f,0x27f800d7,0x00000000}},	//   ﺰﯨﻞ_, rowi_, érny_, --, 
   {{0x3ebc084c,0x60c001ed,0xdb08efdc,0xdca40c60}},	//   _vrut_, _álmo, ndeå, даки, 
   {{0xd9a805f9,0x23e0012d,0x201c0210,0x00000000}},	//   _कसौट, _नवाद, powi_, --, 
   {{0x69dc0624,0x2d984350,0xe1f8009f,0x00000000}},	//   ören, _ören_, _اوڀڙ_, --, 
   {{0x3ebdf0a5,0x7ed408f0,0x75f00166,0x5ac80212}},	//   _urut_, _عزرا, _häze, ілом_, 
   {{0xdb080221,0xcdcc00f1,0x628000b8,0x00000000}},	//   leeë, _پښه_, _ālol, --, 
   {{0x9b59f0a6,0x7a2c03b2,0xdebc0023,0x00000000}},	//   _диет_, gøta, ዳኣኒ_, --, 
   {{0xdb09f0a7,0x44380129,0x75f0002f,0x48e000d4}},	//   neeë, jmq_, _mäze, тоюв, 
   {{0x7c39f0a8,0x8f980302,0x75f00139,0x3f8c058a}},	//   mmur, חירי, _läze, iggu_, 
   {{0x7c39f0a9,0x7a2c0158,0x1868004e,0x864000c0}},	//   lmur, bøta, _даки_, княж, 
   {{0x75f00a43,0x7c380356,0x00000000,0x00000000}},	//   _näze, omur, --, --, 
   {{0x25a00175,0x7c39f0aa,0xdb0804e6,0x03a00454}},	//   _ebhl_, nmur, jeeë, кисо, 
   {{0xdb09f0ab,0x87780375,0xdb18002f,0x7c39f0ac}},	// [38480] deeë, _ואפי, _unwä, imur, 
   {{0xea00001e,0x3f8c0009,0x06040166,0xd78801d3}},	//   _phẩy_, eggu_, _онык_, _انکو_, 
   {{0xdb0801f5,0xd434007b,0x00000000,0x00000000}},	//   feeë, _يعجب, --, --, 
   {{0x7c3800df,0xd010007b,0x4ea400d8,0x00000000}},	//   jmur, خلص_, дрка, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x78500276,0x7c38022f,0x52740107,0x00000000}},	//   _năvo, emur, _нуҳу, --, 
   {{0xcfa9f0ad,0x75f0013d,0x4125f0ae,0x00000000}},	//   _وارم_, _gäze, _жоро_, --, 
   {{0x7c39f0af,0xfde5e39d,0x0ba80116,0x8ae4003b}},	//   gmur, здәк_, زابى_, діол, 
   {{0xc984b6c2,0x6aa806ab,0x63a80694,0x3f98067c}},	//   муни, कबेर, _ñene, òque_, 
   {{0x7c39f0b0,0x00000000,0x00000000,0x00000000}},	//   amur, --, --, --, 
   {{0x75f00598,0x7c38003a,0x8c440452,0x6d5802d0}},	//   _xäze, bmur, _жеже, mcva, 
   {{0x75f020b2,0xfce0cdc1,0x6d5801d3,0x3c3000e4}},	//   _näzb, _шохо, lcva, tãve_, 
   {{0x28b0c853,0x00000000,0x00000000,0x00000000}},	//   _जनवि, --, --, --, 
   {{0x3c30035b,0x00000000,0x00000000,0x00000000}},	//   rãve_, --, --, --, 
   {{0x34943ab2,0x3f8c03b2,0x00000000,0x00000000}},	//   карр, yggu_, --, --, 
   {{0x7850054e,0x4dd800fe,0x00000000,0x00000000}},	//   _zăvo, _ভগোৱ, --, --, 
   {{0xdb0801f5,0x00000000,0x00000000,0x00000000}},	// [38490] veeë, --, --, --, 
   {{0x75f00793,0xdb0877d0,0x00000000,0x00000000}},	//   _päze, weeë, --, --, 
   {{0x6249c3c0,0x7c39f0b1,0x6574036e,0xdb088a45}},	//   _džoa, ymur, mazh, teeë, 
   {{0x6575f0b2,0x75f00030,0x7c3800b5,0x1e940e4e}},	//   lazh, _väze, xmur, еркр, 
   {{0x63adf0b3,0xdb080036,0x3adc01e1,0x00000000}},	//   mean, reeë, _ḿpè_, --, 
   {{0x69dc049f,0x75f00209,0x657402d3,0xdb08002d}},	//   örel, _täze, nazh, seeë, 
   {{0x7c39f0b4,0x4c900063,0x260c0419,0x00000000}},	//   tmur, гијс, eľok_, --, 
   {{0x63adf0b5,0x186800c7,0x00000000,0x00000000}},	//   nean, ҟами_, --, --, 
   {{0x628c0a73,0x65743b7f,0x9b0801b9,0x8e2800e5}},	//   nuao, kazh, яниб_, _کيلۓ_, 
   {{0x63adf0b6,0x2ee001c7,0x65740200,0x00000000}},	//   hean, äife_, jazh, --, 
   {{0x63adf0b7,0x866c0882,0x628c00b0,0x7c380158}},	//   kean, _āyuṣ, huao, pmur, 
   {{0x63adf0b8,0xcc540375,0x9c38010b,0xd0f8010f}},	//   jean, _טבעי_, _эпет_, פּיר, 
   {{0x7bc96dd9,0x63adf0b9,0x7f58009a,0x6574020b}},	//   _ingu, dean, _mfuq, fazh, 
   {{0x657402d3,0x00000000,0x00000000,0x00000000}},	//   gazh, --, --, --, 
   {{0x63ac29ef,0xa59400bc,0xe474084c,0x00000000}},	//   fean, _žďár, кутэ, --, 
   {{0x9345f0ba,0x24540158,0x7e7800e4,0x63adf0bb}},	//   енбе, _dåm_, _ovup, gean, 
   {{0x75f00030,0x00000000,0x00000000,0x00000000}},	// [384a0] _väzb, --, --, --, 
   {{0x6aa401c7,0x00000000,0x00000000,0x00000000}},	//   _äife, --, --, --, 
   {{0x7bc9f0bc,0x63adf0bd,0xcfa400ee,0x24f4010b}},	//   _ongu, bean, ешли, _ачяр, 
   {{0x7bc9f0be,0x00000000,0x00000000,0x00000000}},	//   _nngu, --, --, --, 
   {{0xfbd01d27,0x00000000,0x00000000,0x00000000}},	//   थानम, --, --, --, 
   {{0x7bc8ed87,0x923402dd,0xe2500345,0x00000000}},	//   _angu, _سىزش, _ئێلخ, --, 
   {{0x7e780564,0x7bc8020b,0x6b2c0020,0x69dc403a}},	//   _evup, _bngu, _ስትራቴ, örem, 
   {{0xcfa921cf,0x65740240,0x00000000,0x00000000}},	//   _عازم_, zazh, --, --, 
   {{0x3ea0010b,0x628000dc,0x00000000,0x00000000}},	//   _йитг, _ālok, --, --, 
   {{0xddc8013d,0x63adb3a2,0x6d580477,0x8d7400d1}},	//   _iteş, zean, qcva, _سائا, 
   {{0x6575f0bf,0x2bb81ab2,0x63ac17fa,0xa7fc6d5b}},	//   vazh, _आसपा, yean, msız, 
   {{0x63ad0c80,0xa7fc0adc,0x00000000,0x00000000}},	//   xean, lsız, --, --, 
   {{0x09e5f0c0,0xa9b401c0,0x24540fac,0xe6b80166}},	//   _подн, _айлч, _såm_, _mäçä, 
   {{0xa7fc5531,0x63ac0e47,0xbb4006ed,0xe6b80139}},	//   nsız, wean, _сечк, _läçä, 
   {{0x63ad6ab8,0xf484228e,0x6574522f,0x27f8067c}},	//   tean, лутн, razh, èrns_, 
   {{0x6574044e,0x628c0b23,0x63ac6b57,0xa7fc1cce}},	//   sazh, tuao, uean, hsız, 
   {{0x63ac2d53,0x6249814a,0xa7fc03ee,0x65740810}},	// [384b0] rean, _džon, ksız, pazh, 
   {{0x63adf0c1,0x07700132,0x00000000,0x00000000}},	//   sean, _جۇڭح, --, --, 
   {{0x63adf0c2,0xddc803ee,0x7e7875f9,0xea000051}},	//   pean, _ateş, _svup, _nhậy_, 
   {{0xd478010f,0x103401d5,0x3c30035b,0x63ac01b9}},	//   _קארל, نبنگ, kãva_, qean, 
   {{0x2368084c,0xfbc001ec,0xa7fc0342,0x00000000}},	//   mbaj_, ғұло, fsız, --, 
   {{0x628006c8,0x00000000,0x00000000,0x00000000}},	//   _āloh, --, --, --, 
   {{0x270c068f,0x3134911e,0xf1b00592,0x00000000}},	//   सपुर_, _берр, _اءُ_, --, 
   {{0x7c8c0092,0xbdf800f2,0x00000000,0x00000000}},	//   _የይለፍ_, _کررا_, --, --, 
   {{0x7bc8003a,0x670000c5,0xa7fc06be,0x67280135}},	//   _vngu, _लेलक_, bsız, żejj, 
   {{0xa7fc06be,0x00000000,0x00000000,0x00000000}},	//   csız, --, --, --, 
   {{0xd789f0c3,0xa3c00550,0x75f000fd,0x5c7401af}},	//   وندو_, ंया_, _näza, _рлет, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xaae4e9f1,0x2369f0c4,0xa7fc2737,0x49d800ec}},	//   _مسوو, dbaj_, nsıy, _ڪانگ_, 
   {{0x56940124,0x00000000,0x00000000,0x00000000}},	//   наҭт, --, --, --, 
   {{0x26c40421,0x2bb852be,0x49d801b9,0x75f000fd}},	//   āloa_, _आसमा, _تانگ_, _cäza, 
   {{0x255801c6,0xa7fc236c,0x00000000,0x00000000}},	//   _үрээ_, ksıy, --, --, 
   {{0x93440b3e,0x0838010f,0x00000000,0x00000000}},	// [384c0] тнае, _קעפל, --, --, 
   {{0xa7fc1432,0x00000000,0x00000000,0x00000000}},	//   npın, --, --, --, 
   {{0x49f80003,0x5044041b,0xc32c0014,0xb06400fd}},	//   ྒྲིལ_, вежб, مٕہ_, ktäş, 
   {{0x4f080046,0x4fe817b4,0x1ad000bc,0x00000000}},	//   мнен_, ьмен_, तमाथ, --, 
   {{0xa7fc1b0d,0x3f980086,0x226402fb,0x69dc02fc}},	//   tsız, òqua_, čský_, örek, 
   {{0x1ea8007b,0x7ee014fb,0x00000000,0x00000000}},	//   عاني_, شكىن, --, --, 
   {{0xfe6c16a0,0xa7fc8eb9,0x9d640014,0x25a40254}},	//   مگە_, rsız, دنى۪, õlli_, 
   {{0x0b882830,0xdb180066,0xcfa800cf,0x8fa44258}},	//   фски_, _kawè, _تاسم_, _шабе, 
   {{0xea000016,0x3a715284,0xbe3000f7,0x00000000}},	//   _nhảy_, алыр, _چىقب, --, 
   {{0x4ca8045e,0xa7fc6656,0x3c30035b,0x00000000}},	//   কিবু, qsız, rãva_, --, 
   {{0x3c300022,0x29180205,0x00000000,0x00000000}},	//   sãva_, çra_, --, --, 
   {{0x260417cb,0xb5c80014,0x29180135,0xa7fc03b9}},	//   होनी_, ۆوُم_, ħra_, nsıx, 
   {{0x4ab40562,0xea00001e,0x6f0448cb,0x00000000}},	//   _अनिव, _chảy_, úich, --, 
   {{0xe9183334,0x00000000,0x00000000,0x00000000}},	//   _полі_, --, --, --, 
   {{0x6248faf7,0x00000000,0x00000000,0x00000000}},	//   _džol, --, --, --, 
   {{0xdb1800f2,0x349416a4,0x2c1003d4,0x68e8015d}},	//   _bawè, јатр, াতকৈ_, mydd, 
   {{0x2369f0c5,0xb355947a,0x76b9cd6a,0x36880166}},	// [384d0] rbaj_, ркуш, _алыр_, _исэн_, 
   {{0x672d0d18,0x236801e4,0xbbdc810b,0x260c00d7}},	//   _iyaj, sbaj_, _फक्क, eľov_, 
   {{0x68e80cfd,0x351801c0,0x6604005a,0x25081968}},	//   nydd, _ажээ_, _imhk, _سردی_, 
   {{0x672c0337,0x443c067c,0x25b00118,0xd7d40073}},	//   _kyaj, _òu_, lezl_, धायच, 
   {{0x63bc03a2,0xdd0005a1,0x68e80368,0x5ea40bbf}},	//   _iasn, _čuđe, hydd, امتل, 
   {{0x68e801e6,0x714400cf,0xa7fc03e0,0x9298011a}},	//   kydd, _چۉكۅ, rsıy, _אישת, 
   {{0x672c04ba,0xb1e404a9,0x260c00d7,0x00000000}},	//   _lyaj, _тәтқ, bľov_, --, 
   {{0x5f44c998,0x68e800a9,0x672c019b,0x92e400fe}},	//   _منزل, dydd, _oyaj, বছৰ_, 
   {{0x63bdf0c6,0xdb188851,0x5974ae78,0x672c8075}},	//   _masn, _kawé, лыну, _nyaj, 
   {{0x63bdf0c7,0xdb18003e,0x68e80368,0x95840023}},	//   _lasn, _jawé, fydd, ምታትን_, 
   {{0x77940502,0x9b94021a,0x672df0c8,0xdb18003e}},	//   لیغا, _ملات, _ayaj, _mawé, 
   {{0x672df0c9,0x63bc019b,0xdb18020c,0x629c01b9}},	//   _byaj, _nasn, _lawé, _oqso, 
   {{0x672c0526,0x1ca404d3,0x48000153,0x4b7800df}},	//   _cyaj, _شێکی_, спяв, _נאסו, 
   {{0x68e800a9,0xa9048d24,0xdb18002e,0x63bde110}},	//   bydd, ابین, _nawé, _aasn, 
   {{0x63bdf0ca,0x18a5f0cb,0x672c0337,0x79800098}},	//   _basn, _сайм, _eyaj, _idnw, 
   {{0x63bdbefb,0x62483421,0xdb180066,0xea00004d}},	//   _casn, _džom, _pawè, _thảy_, 
   {{0x7af82b1d,0xdb180066,0x00000000,0x00000000}},	// [384e0] nzut, _bawé, --, --, 
   {{0xdb180c6a,0x63bc007b,0x3c300022,0x00000000}},	//   _cawé, _easn, kãvo_, --, 
   {{0x82a0005e,0x7af802c4,0x63bdf0cc,0xb35850ec}},	//   _қарж, hzut, _fasn, _لیزا_, 
   {{0x63bdf0cd,0xb4e01b57,0x7bd82dff,0xbb1801ec}},	//   _gasn, थही_, jjuu, _ﺴﻬﻡ_, 
   {{0xd29800d4,0x00000000,0x00000000,0x00000000}},	//   _ятні_, --, --, --, 
   {{0xdb18255a,0x7af80bd7,0xa6e00154,0x00000000}},	//   _gawé, dzut, _পেঁয়, --, 
   {{0x0cd0045e,0xea00001e,0x7af8005a,0xf9f80011}},	//   ়ন্ত, _nhạy_, ezut, ীকাল_, 
   {{0xd0117b61,0x63bc058a,0x7af80112,0x00000000}},	//   _الر_, _xasn, fzut, --, 
   {{0x68e80f7b,0x00000000,0x00000000,0x00000000}},	//   wydd, --, --, --, 
   {{0x672c2dab,0x68e8b195,0xddc80010,0x7bd80108}},	//   _ryaj, tydd, _zvež, ajuu, 
   {{0xd90c1416,0xea0007ae,0xe918177b,0x78740209}},	//   ویه_, _chạy_, тоні_, лйэр_, 
   {{0x68e938b0,0x672c0055,0x25380023,0xdb0800a2}},	//   rydd, _pyaj, ረኸብኩ, ldeý, 
   {{0x63bc07f5,0x68e800a9,0x62480cf4,0x75f000d0}},	//   _rasn, sydd, _džoj, _väzn, 
   {{0x672df0ce,0x63bdf0cf,0x659403b7,0xb6040276}},	//   _vyaj, _sasn, јаву, бяск, 
   {{0x63bdc07f,0x25b00165,0x6474004e,0x00000000}},	//   _pasn, rezl_, ргбу, --, 
   {{0xdb186085,0x63bc51ab,0xd5b80107,0x672c00dc}},	//   _sawé, _qasn, нсӣ_, _tyaj, 
   {{0x629c0354,0xa2943334,0x672c0107,0xdb180098}},	// [384f0] _qqso, разі, _uyaj, _pawé, 
   {{0x63bc3d19,0xddc8565b,0xa5c40046,0x26c9f0d0}},	//   _wasn, _svež, _төме, _irao_, 
   {{0x7af8f518,0x15580375,0xffe40212,0x63a800e4}},	//   zzut, _בכתב, людн, _ñeno, 
   {{0xa294242f,0x26c808a4,0x27f8004d,0xdef000ae}},	//   _камі, _krao_, nhsn_, يًا_, 
   {{0x442801fa,0x7bd80254,0x260c00d7,0xc2e401a9}},	//   _ikc_, vjuu, sľou_, _сўни, 
   {{0x7bc40029,0x26c801af,0x260df0d1,0x1d083756}},	//   ējum, _mrao_, pľou_, кели_, 
   {{0x7bd8023a,0xf1a4010b,0x6b840116,0x00000000}},	//   tjuu, _урян, ڭشىل, --, 
   {{0x7af9bc34,0x26c81050,0xddc83421,0x628c02b5}},	//   tzut, _orao_, _uvež, orao, 
   {{0x628c68c8,0xde5800d6,0xa7fc3535,0x7bd86775}},	//   nrao, _разі_, rpıl, rjuu, 
   {{0x7bd800af,0x99840093,0x7af9f0d2,0x49c4f571}},	//   sjuu, molū_, rzut, альн_, 
   {{0x98a5f0d3,0x44280113,0x81e40183,0xae44454b}},	//   шине, _okc_, _বগা_, _اپلو, 
   {{0x26c8030a,0x99d408dc,0x628df0d4,0x442800ef}},	//   _brao_, اتکا, krao, _nkc_, 
   {{0xd7340212,0x1aa80037,0x97340e3b,0x00000000}},	//   рхнь, _कहिथ, рэнч, --, 
   {{0xd94431b0,0x442802fa,0x798002d0,0x624800ef}},	//   _кели, _akc_, _udnw, _džok, 
   {{0x44291872,0x26c8010f,0x7a2cb3f8,0x15440798}},	//   _bkc_, _erao_, jøti, ревм, 
   {{0x442802fa,0x628df0d5,0x35c401a9,0x50d4020c}},	//   _ckc_, frao, шаҳҳ, یزار, 
   {{0x26c8172e,0x628c0408,0x62641216,0x4429f0d6}},	// [38500] _grao_, grao, مالق, _dkc_, 
   {{0x442801e4,0xdce00115,0xc950010f,0x9478022e}},	//   _ekc_, _selĝ, ַמד_, _исму_, 
   {{0x9f5c00b0,0x53a5f0d7,0xd46813dc,0x9404028e}},	//   kiwä_, _канб, _шине_, _نوده, 
   {{0x8fa41d83,0xc7ac002e,0x628c01e7,0x25ac04a7}},	//   раде, _njёl_, brao, đele_, 
   {{0xad8402dd,0xd1740108,0x906400cf,0x00000000}},	//   йқай, _выбы, انچۇ, --, 
   {{0x2cac0311,0xdce00213,0x7c2802d2,0x683c0129}},	//   _ppdd_, _aclı, _akgr, méde, 
   {{0x31780998,0x20240ad9,0x4f9406ed,0x9f6400d7}},	//   _ierz_, ósið_, _врзу, štár_, 
   {{0x8aa49133,0x3178368b,0x44280051,0x00000000}},	//   арод, _herz_, _xkc_, --, 
   {{0x1ea832e8,0x7d0c00ac,0x31780156,0x683c0036}},	//   _مالي_, _əksə, _kerz_, néde, 
   {{0x7c2801e4,0x7e98011a,0xa7fc2ca8,0xfe98011a}},	//   _ekgr, _בסמו, rpım, _ביממ, 
   {{0x31780065,0x5dd400db,0x8c3401af,0x815400df}},	//   _merz_, _уюту, _күкр_, יסיע_, 
   {{0xcb680640,0xfb840214,0x00000000,0x00000000}},	//   _раде_, _ندهی, --, --, 
   {{0x67002d2c,0x4429f0d8,0xea000208,0x76b800ee}},	//   _लेखक_, _rkc_, _nhầy_, аляр_, 
   {{0xddc80f8b,0x628c0dd4,0x4429f0d9,0x683c0005}},	//   _kweš, vrao, _skc_, déde, 
   {{0xe944182f,0x75f00139,0x44282370,0x440400db}},	//   _ارشی, _gäzm, _pkc_, ачаб, 
   {{0x26c80016,0x4900009d,0x47341f0d,0x00000000}},	//   _trao_, _гүүг, _پرعز, --, 
   {{0x317805c7,0xea000051,0x44280064,0x683c00e5}},	// [38510] _berz_, _chầy_, _vkc_, géde, 
   {{0x12884876,0x628c01c4,0xb2741e87,0x27b401af}},	//   املی_, rrao, юлуш, _тәүс, 
   {{0xdb0801ab,0x628c01ab,0x31780205,0x00000000}},	//   ndeò, srao, _derz_, --, 
   {{0x44290582,0x628c8706,0xe81c00bc,0x00000000}},	//   _ukc_, prao, नवटा_, --, 
   {{0x683c0231,0xdce00166,0xb28400db,0x00000000}},	//   céde, _belğ, _мырк, --, 
   {{0x3178030a,0x61f402d0,0x1c44010b,0xed5800d7}},	//   _gerz_, _ulzl, әним, _paľa_, 
   {{0x22583570,0x804801f0,0x6dc40137,0x00000000}},	//   _husk_, _ачаб_, تۅلۅ, --, 
   {{0x2250005a,0x2258005c,0x63a8013d,0x00000000}},	//   _hizk_, _kusk_, _öend, --, 
   {{0x22580113,0xdd0001a6,0xdb18002f,0xfe7401ee}},	//   _jusk_, čuđa, _unwü, _түл_, 
   {{0x3e4001d9,0x00000000,0x00000000,0x00000000}},	//   _بێتٲ, --, --, --, 
   {{0x22580489,0xddc0007f,0xd8240107,0x00000000}},	//   _lusk_, _pilņ, йдои, --, 
   {{0x981400c6,0x6be4007b,0x17f8007b,0x00000000}},	//   إبدا, _وكلم, اردة_, --, 
   {{0xdb09f0da,0x9b4525c4,0xdce00166,0x13e801d5}},	//   rdeó, _انشو, _yelğ, қмай_, 
   {{0xd998f2af,0x69dd3b7a,0x683c01ed,0x7850054e}},	//   _صنعت_, öret, véde, _săvu, 
   {{0x1da80882,0x00000000,0x00000000,0x00000000}},	//   च्यत, --, --, --, 
   {{0x22592161,0x75f00139,0xd7300092,0xe62c0092}},	//   _busk_, _käzk, _በጦርነ, ደረገላ, 
   {{0x77640327,0x3178030a,0xd3340276,0x00000000}},	// [38520] _ifix, _perz_, сэвы, --, 
   {{0x683df0db,0x51540046,0x00000000,0x00000000}},	//   réde, стау, --, --, 
   {{0x225801c4,0x3179f0dc,0x2d980022,0x25a40ba1}},	//   _eusk_, _verz_, _ĸre_, òlle_, 
   {{0xea000016,0x22581654,0x7764025c,0x317805c7}},	//   _thầy_, _fusk_, _jfix, _werz_, 
   {{0x3178a81c,0x7764031c,0x6e080022,0x7a2c0174}},	//   _terz_, _mfix, аҭам_, løtu, 
   {{0xdbd000f1,0x2fc00427,0xe16806c2,0x10f40064}},	//   ېښود, žig_, _نصفه_, _лябя, 
   {{0xfbd001f9,0x00000000,0x00000000,0x00000000}},	//   थांम, --, --, --, 
   {{0x4478010f,0xa7fc0205,0x00000000,0x00000000}},	//   אנקע, rpık, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7765f0dd,0x2d9812ed,0x00000000,0x00000000}},	//   _afix, _øre_, --, --, 
   {{0xebc400d1,0x7a2c03b2,0x4c68010a,0x601000d7}},	//   _дәпн, jøtu, _сиен_, sťme, 
   {{0x7a2c03b2,0x5bc400ae,0x00000000,0x00000000}},	//   døtu, _وتنف, --, --, 
   {{0xf1c83347,0x85880006,0x69dc0267,0xe658009d}},	//   रयान, лёва_, öres, ригч_, 
   {{0x77651d3a,0x00000000,0x00000000,0x00000000}},	//   _efix, --, --, --, 
   {{0x75f0013d,0x7a2c0174,0xea000051,0x00000000}},	//   _mäzh, gøtu, _chấy_, --, 
   {{0x499002f2,0x00000000,0x00000000,0x00000000}},	//   _بیگر, --, --, --, 
   {{0xded41b49,0x81684d87,0x78b402f0,0x00000000}},	// [38530] ሪቃን_, греб_, _šxvx, --, 
   {{0xbb38008f,0x7a2c03b2,0x26040d0d,0x00000000}},	//   רעמי, bøtu, होशी_, --, 
   {{0x356818ce,0xa0b802dd,0x60c80022,0x69c001ad}},	//   _урын_, ргеу_, _ņemb, _वसनी, 
   {{0x9f4c0270,0x260413f7,0x22582634,0x2008004d}},	//   _aleá_, होरी_, _tusk_, òai_, 
   {{0x5398025f,0x9f4c0332,0xa15800d3,0x82341bf4}},	//   _דירו, _bleá_, _вагу_, _هرسا, 
   {{0x7a2c4098,0xd6e40154,0xa7fc06be,0x00000000}},	//   nøtt, _পেঁয, lqıd, --, 
   {{0x656402d0,0xa0c4027d,0xdb0c0055,0x6f040332}},	//   _mfhh, _بيزو, _ājñe, úicr, 
   {{0x7ff4113e,0x1be80107,0x00000000,0x00000000}},	//   _اسسا, рдии_, --, --, 
   {{0x0ae434d8,0x6249c3c0,0xe7dc18cc,0x9f4c0332}},	//   ждый_, _džov, यानप, _fleá_, 
   {{0xc9a53c4b,0x3ebc0140,0x7a2c143a,0x00000000}},	//   овье_, _isut_, jøtt, --, 
   {{0xdb092c7d,0x99d44710,0x00000000,0x00000000}},	//   rdeñ, متگا, --, --, 
   {{0x69dd7155,0x3ebc009a,0xdb0804d4,0xfa8000d1}},	//   örer, _ksut_, sdeñ, _еқим, 
   {{0x75f009a5,0x0c4001d9,0x3cdc1098,0x3ebc01c7}},	//   _häzi, _تھوَ, _कपडे_, _jsut_, 
   {{0xa2cc227c,0x00000000,0x00000000,0x00000000}},	//   सिन्, --, --, --, 
   {{0x77640135,0xdce00171,0x3a0401e2,0x00000000}},	//   _tfix, _ielē, _پکښی_, --, 
   {{0x25ac1674,0xa3e406ab,0x75f0010e,0xdce000de}},	//   đela_, बॉल_, _mäzi, _helē, 
   {{0x1ca80d46,0xdca4004b,0xc32c0014,0x3ebc0051}},	// [38540] _བདའ_, _ګډ_, پٕل_, _nsut_, 
   {{0xea0001dc,0x3fc804fb,0xd185f0de,0x52b800bc}},	//   _thấy_, یدنی_, ілей, _उनीस, 
   {{0x683c0098,0x3ebc005b,0x75f02123,0x6ca80220}},	//   léda, _asut_, _näzi, _ﺴﻴﺎﺴ, 
   {{0x888800c8,0x9f4c01e7,0xed580419,0x527428f3}},	//   שרײַ, _sleá_, _paľo_, _мугу, 
   {{0x683c06af,0xce4800f3,0x00000000,0x00000000}},	//   néda, азде_, --, --, 
   {{0x8c642f96,0x656403ac,0xdce000ef,0x00000000}},	//   отид, _xfhh, _nelē, --, 
   {{0xac940c9e,0x75f00166,0xd7c80073,0x66fc06be}},	//   чайш, _cäzi, ियाच, _mьka, 
   {{0x248519ce,0x6249f0df,0x00000000,0x00000000}},	//   álmi_, _džou, --, --, 
   {{0x7a2c2dba,0xdce000ef,0x9e65a416,0x00000000}},	//   jøts, _belē, _فالن, --, 
   {{0x09481b10,0x3eb806a9,0xc3300302,0x00000000}},	//   ични_, _דצמב, ווח_, --, 
   {{0x1ca8025c,0x75f000fd,0xdde801b9,0x4158008f}},	//   _བདར_, _gäzi, _ارقه_, ידיג, 
   {{0x2fc407d6,0x62480c5e,0x00000000,0x00000000}},	//   _jamg_, _užov, --, --, 
   {{0x0ab818a2,0x7a2c1512,0x2fc40048,0x6b800280}},	//   _خطاب_, tøtt, _mamg_, mamg, 
   {{0x2d9c008f,0xca2c0952,0x6b81535f,0xfa300150}},	//   ngve_, ﻨﯩﺶ_, lamg, _قىنج, 
   {{0xe86401c0,0x7a2c143a,0x2d9c01bf,0x75f0008e}},	//   _эхлү, røtt, igve_, _xäzi, 
   {{0x248df0e0,0x6b81f0e1,0xdb180789,0x683c8851}},	//   čem_, namg, _hawá, béda, 
   {{0xaabc74c8,0x27e9f0e2,0x78b005ce,0x683c004a}},	// [38550] ्टिक, _ioan_, čevš, céda, 
   {{0x27e9f0e3,0x6b8002d0,0x81680022,0xa91c00d7}},	//   _hoan_, hamg, рраб_, maľb, 
   {{0x2fc401af,0x27e8153b,0x6b80005f,0x55b80375}},	//   _bamg_, _koan_, kamg, _המתו, 
   {{0x6b80026c,0x9ed8023a,0x27e81e56,0xaabc0404}},	//   jamg, ймет_, _joan_, ्टाक, 
   {{0x27e9f0e4,0x6b803906,0x3ebc0240,0x9e34008e}},	//   _moan_, damg, _qsut_, педч, 
   {{0xdd901c43,0x27e83d4a,0x1ea800ec,0x00000000}},	//   روع_, _loan_, لاڻي_, --, 
   {{0x6b81f0e5,0x7d240014,0x3134bb65,0x7c9c0092}},	//   _ịgab, غٲبہ_, _жерр, _ፌዴራል_, 
   {{0xfeb81501,0x260c01fa,0x6b81f0e6,0x27e84c91}},	//   _پارت_, džom_, gamg, _noan_, 
   {{0x3ebc6228,0xdce0005f,0x9e7403e6,0x25a001a9}},	//   _usut_, _pelē, _رهات, _ochl_, 
   {{0x27e80093,0x2d980139,0x00000000,0x00000000}},	//   _aoan_, _örep_, --, --, 
   {{0xae04040d,0x2fc40a2e,0x6b81f0e7,0x27e80489}},	//   _تولى, _yamg_, bamg, _boan_, 
   {{0x27e9f0e8,0x00000000,0x00000000,0x00000000}},	//   _coan_, --, --, --, 
   {{0x27e9f0e9,0x00000000,0x00000000,0x00000000}},	//   _doan_, --, --, --, 
   {{0x9a840184,0x27e8adc8,0x683c020c,0xaa290220}},	//   _дуҫл, _eoan_, réda, _وثوق_, 
   {{0x2eb8032c,0x8ccc0034,0x200d0a98,0x27e9f0ea}},	//   _इन्त, थियो, _omei_, _foan_, 
   {{0x683df0eb,0x27e81368,0xf678008e,0xb4ac000d}},	//   lédn, _goan_, _мәгъ_, _गही_, 
   {{0x2d9c08fb,0x00000000,0x00000000,0x00000000}},	// [38560] ygve_, --, --, --, 
   {{0x200df0ec,0x2bb84438,0x60c800e2,0x645000de}},	//   _amei_, _आस्थ, _ņema, _ādiņ, 
   {{0x6624007b,0xc32c0014,0x6b800454,0x00000000}},	//   _تريك, نٕہ_, yamg, --, 
   {{0x6b8002c4,0x27e9d21a,0x0874010f,0x00000000}},	//   xamg, _xoan_, פענט_, --, 
   {{0xed501893,0x21e402dd,0xcf24007b,0x620803b2}},	//   چھا_, _ﺍﻷﺩﻭ, أرضي, ðplá, 
   {{0x200c0428,0xed500131,0xdb080254,0x00000000}},	//   _emei_, نھا_, ndeõ, --, 
   {{0xfe6c192c,0x2fc401d5,0xbd84007b,0x00000000}},	//   نگە_, _tamg_, سنين_, --, 
   {{0xbb800131,0xbc64007b,0x528802dd,0x00000000}},	//   ىلىي, أمين_, _ﺗﻪﯕﯩ, --, 
   {{0x8b6401ed,0x9f4c0139,0xaab8114f,0x8e740395}},	//   _ہاشم, _rleç_, تگار_, _хубч, 
   {{0x27e9f0ed,0x6b81f0ee,0xb4ac01f9,0x00000000}},	//   _soan_, samg, _गहू_, --, 
   {{0x2d8c01c7,0x27e80156,0xcb080451,0x0c75a865}},	//   _idde_, _poan_, _ڏيان_, _رداد, 
   {{0x75f02045,0x8ba53d96,0x25a0002f,0x6b8001a9}},	//   _mäzu, _хидж, _schl_, qamg, 
   {{0x27e9f0ef,0x92dc04c5,0x1ca8025c,0x5c3000f2}},	//   _voan_, তনু_, _བདོ_, _جکوز, 
   {{0x38c812e1,0x25ac110c,0x0a1800cc,0x00000000}},	//   _گاهی_, đelo_, _নীৰৱ_, --, 
   {{0x27e9f0f0,0x69c80cfd,0x81b800fe,0x4b5002f2}},	//   _toan_, mdde, _আচল_, _تێکر, 
   {{0x69c9f0f1,0x2d8c05d5,0xc6a4084c,0x9f5c02e2}},	//   ldde, _ldde_, _ерои, chwè_, 
   {{0x683df0f2,0x69d8003e,0x69c9f0f3,0x2d8df0f4}},	// [38570] lédo, _knve, odde, _odde_, 
   {{0x69c9f0f5,0xe6c8166d,0x00000000,0x00000000}},	//   ndde, िटीज, --, --, 
   {{0x69c9f0f6,0xe37401c6,0x00000000,0x00000000}},	//   idde, _олны, --, --, 
   {{0x2d8cc473,0xa2cc0882,0x00000000,0x00000000}},	//   _adde_, सिद्, --, --, 
   {{0x63adf0f7,0x69d83002,0x6249f0f8,0x88e0009e}},	//   mfan, _onve, _džor, মনিক, 
   {{0x63ad6285,0x683c0264,0x6e380175,0x00000000}},	//   lfan, kédo, glvb, --, 
   {{0x63adf0f9,0x260c00d7,0x00000000,0x00000000}},	//   ofan, ežok_, --, --, 
   {{0x69d9f0fa,0x63adf0fb,0x69c80a85,0x2d8cfe56}},	//   _anve, nfan, edde, _edde_, 
   {{0x63adf0fc,0x7f580944,0x2d8c030a,0x69c801a4}},	//   ifan, _iguq, _fdde_, fdde, 
   {{0x7e78209c,0x69c801f5,0x63ac2a13,0x394c0023}},	//   _iwup, gdde, hfan, _መሓውራ, 
   {{0xf8ad51fb,0x7e780395,0x63ac032e,0x683c003e}},	//   اکت_, _hwup, kfan, gédo, 
   {{0x7e7802e3,0x201df0fd,0x63ac0007,0x7bc4005f}},	//   _kwup, nnwi_, jfan, ējus, 
   {{0x201df0fe,0x63adf0ff,0xf1e000cd,0x00000000}},	//   inwi_, dfan, नामन, --, 
   {{0x63ac2430,0xaabc141f,0x00000000,0x00000000}},	//   efan, ्टरक, --, --, 
   {{0x7f58209c,0x683c06af,0x63ac6937,0x00000000}},	//   _oguq, cédo, ffan, --, 
   {{0x04403a61,0x7f586b2b,0x893400d9,0x5274009b}},	//   весн, _nguq, _קרקע_, дужу, 
   {{0xb2440184,0x69d9f100,0xc6c00137,0xd5dc4709}},	// [38580] емаһ, _ynve, _айык, मादज, 
   {{0x7f580944,0x63ac1559,0x422006ed,0x63a80166}},	//   _aguq, afan, вдув, _öenn, 
   {{0x1068470e,0x7e7960fe,0x4fa438ca,0x76400316}},	//   цией_, _awup, диев, ůmys, 
   {{0x63ac03ac,0x00000000,0x00000000,0x00000000}},	//   cfan, --, --, --, 
   {{0x69c92c5f,0x1ca8025c,0x51640137,0x683c01d3}},	//   ydde, _བདུ_, _жүзү_, zédo, 
   {{0x7f580944,0x7e78033f,0xe2c40166,0x646808ce}},	//   _eguq, _dwup, _яһуд_, _ósið, 
   {{0x7e79e40e,0xacf8d47b,0xd1306e25,0xbc641a9b}},	//   _ewup, янку_, _شمر_, ومون_, 
   {{0x63a80de2,0xc3f8010f,0x69c803cb,0x683c00e5}},	//   _ñent, ַליש, wdde, gédl, 
   {{0x7e7801f2,0xe7dc041c,0x2be00210,0x00000000}},	//   _gwup, यासप, काबू_, --, 
   {{0x63ac0369,0x62500342,0x2d8c01e3,0xdce00064}},	//   zfan, cıoğ, _udde_, _nelė, 
   {{0x69c800a9,0x63adf101,0x588401e0,0xfde400f2}},	//   rdde, yfan, нъяҡ, _تکنو_, 
   {{0xe694c920,0x683c0098,0xddc80139,0x0ae800f1}},	//   нимы, rédo, _kueş, _ورشي_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69d9f102,0xa2cc19cc,0xbb38011a,0xdb180432}},	//   _unve, सिस्, _ועדי, _sawç, 
   {{0x63ac008c,0x03c5f103,0xf4840d30,0x69342bb6}},	//   tfan, мсам, кутн, _янку, 
   {{0xeac807ae,0x63ac01f7,0x60c9f104,0x97540055}},	//   _kỹ_, ufan, _ņemo, _aṇup, 
   {{0x63adf105,0x4ca800bd,0x26c400da,0x61e401ee}},	// [38590] rfan, কিটু, ālos_, tjhl, 
   {{0xeac807ae,0x63adf106,0x7e780099,0xdce000c0}},	//   _mỹ_, sfan, _rwup, _gelė, 
   {{0x63ad85b0,0xf1a400a7,0xee140011,0x66148fa3}},	//   pfan, ъртн, াকাশ_, mizk, 
   {{0x6615f107,0x984400b0,0xddc0010b,0xbb5002dd}},	//   lizk, _kēā_, _bilş, _ﻋﻮﻱ_, 
   {{0x644df108,0x4174313e,0x00000000,0x00000000}},	//   mmai, _ياسس, --, --, 
   {{0x644c060a,0x44380054,0x9d4414ca,0x236801e4}},	//   lmai, llq_, нелд, lcaj_, 
   {{0x644df109,0x5c54288a,0xe4780166,0x625003e0}},	//   omai, нтиф, _üzäğ, rıoğ, 
   {{0x236800c8,0x7f580944,0x7e780099,0x661401c4}},	//   ncaj_, _uguq, _twup, hizk, 
   {{0x7e780921,0x661401c6,0x644c0108,0x2ee004e6}},	//   _uwup, kizk, imai, äift_, 
   {{0x0b401914,0x644df10a,0x00000000,0x00000000}},	//   ынын, hmai, --, --, 
   {{0x661405f5,0xeac800e4,0xa3c0041c,0x38040107}},	//   dizk, _eỹ_, ूया_, вонҳ, 
   {{0xac7400cf,0x2368036e,0x00000000,0x00000000}},	//   _شامش, jcaj_, --, --, 
   {{0xdce00006,0x19f80139,0x6614002f,0x7c39f10b}},	//   _pelė, _нэкь_, fizk, mlur, 
   {{0x661401c6,0x236800df,0x644c8d89,0xceb00677}},	//   gizk, ecaj_, emai, איך_, 
   {{0x7c38954c,0x644c3a0d,0xdce00064,0x00000000}},	//   olur, fmai, _velė, --, 
   {{0x7c388fc8,0xa7fd839d,0x644df10c,0xd4140022}},	//   nlur, lqın, gmai, хьгы, 
   {{0x7c39f10d,0x661401c4,0x130802d5,0x338c0023}},	// [385a0] ilur, bizk, чнай_, _ንኽልተ_, 
   {{0x644df10e,0x7c3828d9,0x5bbc00cd,0x00000000}},	//   amai, hlur, ्युव, --, 
   {{0x644df10f,0x7c382b4b,0x00000000,0x00000000}},	//   bmai, klur, --, --, 
   {{0x4ea5f110,0x644c1635,0x4fe80572,0x4f240026}},	//   ерка, cmai, ямен_, ндеб, 
   {{0x4ca80154,0x007c0150,0x71840150,0xf8d800cd}},	//   কিছু, _ﺯﯨﺸﯘ, _ақзе, यमुप, 
   {{0x7c38000d,0x00000000,0x00000000,0x00000000}},	//   elur, --, --, --, 
   {{0xeac80016,0x7c3802d2,0xdb08017a,0xc5f0025d}},	//   _sỹ_, flur, ffeï, רדו_, 
   {{0x7c3808a7,0xcb080801,0x661401c6,0x800801ed}},	//   glur, зход_, zizk, _فرقہ_, 
   {{0x6abc66c0,0xdb08002f,0x00000000,0x00000000}},	//   ्टेर, rgeß, --, --, 
   {{0xeac8004d,0x7c38054e,0x644df111,0x00000000}},	//   _vỹ_, alur, zmai, --, 
   {{0x1ca82b65,0x644df112,0x7c39f113,0x021404ae}},	//   _བདག_, ymai, blur, תחים_, 
   {{0x7c39f114,0x644df115,0x00000000,0x00000000}},	//   clur, xmai, --, --, 
   {{0x644df116,0x6614a0f0,0x00000000,0x00000000}},	//   vmai, tizk, --, --, 
   {{0x3910005e,0x25a5f117,0xdb0801b9,0x644c0334}},	//   _өмір, üll_, _غزنه_, wmai, 
   {{0x6615f118,0x644df119,0xa91c00d0,0x79c4007b}},	//   rizk, tmai, maľo, _سويف_, 
   {{0xcbec015b,0x644c0e89,0x66144c91,0x00000000}},	//   _ওষুধ_, umai, sizk, --, 
   {{0x2369f11a,0x644d977f,0xdd0001a6,0xb9dc0b82}},	// [385b0] rcaj_, rmai, _čuče, _ቤታ_, 
   {{0xa91c00d0,0xf2040139,0x00000000,0x00000000}},	//   naľo, ляхо, --, --, 
   {{0x644c3727,0x236801fa,0xd4c02cc8,0x00000000}},	//   pmai, pcaj_, _көтк, --, 
   {{0xa91c0419,0x3d14000d,0x00000000,0x00000000}},	//   haľo, _भइबे_, --, --, 
   {{0x53981203,0x6abc06bc,0x00000000,0x00000000}},	//   _קישו, ्टोर, --, --, 
   {{0xf5182be7,0x7e3400d1,0xa91c0419,0x998400a2}},	//   _آتیش_, رۋاز_, vaľn, molŧ_, 
   {{0x7c380276,0x1fc400c7,0x6e240036,0xdce000de}},	//   tlur, _ираҳ, éiba, _ielī, 
   {{0x5bbc00dc,0xdce00311,0x7c380083,0x8bd015bf}},	//   ्येव, _află, ulur, لقىش, 
   {{0x2fc000af,0x7c39f11b,0x9f4c0af9,0x683c020c}},	//   õige_, rlur, _moeë_, médh, 
   {{0x7c39f11c,0x00000000,0x00000000,0x00000000}},	//   slur, --, --, --, 
   {{0xac940364,0xaae45194,0x7c380311,0xa7fc0724}},	//   _бахш, نسیو, plur, rqın, 
   {{0x5b140a70,0x21e401ec,0x24b80154,0x00000000}},	//   _имет, _ﺍﻷﺴﻭ, ুমাহ, --, 
   {{0xa91c00d0,0x00000000,0x00000000,0x00000000}},	//   baľo, --, --, --, 
   {{0x7bc803a5,0xa7fc0cc1,0x683c0066,0xdce000e2}},	//   _hagu, qqın, hédh, _nelī, 
   {{0x7bc9f11d,0x7980002d,0x6aa40036,0x00000000}},	//   _kagu, _ienw, _äifr, --, 
   {{0x7bc9f11e,0x7981f11f,0x65c002dd,0x260c0064}},	//   _jagu, _henw, _құса, džou_, 
   {{0x7981f120,0x6b84007d,0x60d402d0,0x00000000}},	// [385c0] _kenw, _õige, _arzm, --, 
   {{0x7bc9f121,0x7981f122,0x60d40034,0xdce000ef}},	//   _lagu, _jenw, _brzm, _celī, 
   {{0x79800b58,0x10a5f123,0x7bc9f124,0x9424033a}},	//   _menw, тиен, _oagu, _амне, 
   {{0x7bc9ae73,0x8fd00184,0x7981f125,0x9378007b}},	//   _nagu, шәгә, _lenw, _تصدر_, 
   {{0xa2c01533,0xb8e00135,0x52740209,0x5bbc00dc}},	//   रौद्, _ཌར_, _шуну, ्यैव, 
   {{0x79800455,0x273c007b,0xfe41e2c6,0x5d8001e0}},	//   _nenw, lánú_, анчо, йғуж, 
   {{0x6abc0401,0xc0e0408a,0x6cd5f126,0xe7f400bc}},	//   ्ट्र, _корк, اقبا, ँउमा_, 
   {{0x7bc9f127,0x25ac7313,0x79800036,0x66e800e8}},	//   _cagu, đeli_, _aenw, _jëkë, 
   {{0x7bc9f128,0x7981f129,0x66e8036e,0x00000000}},	//   _dagu, _benw, _mëkë, --, 
   {{0x683df12a,0x66e800e8,0x7bc946e1,0x3b50dfe6}},	//   médi, _lëkë, _eagu, шкыр, 
   {{0x7bc9f12b,0x683c06af,0x79800142,0x7874010b}},	//   _fagu, lédi, _denw, кйэр_, 
   {{0x7bc9f12c,0x79804d25,0x00000000,0x00000000}},	//   _gagu, _eenw, --, --, 
   {{0x8a05f12d,0x7981f12e,0x683c39b2,0xa91c0030}},	//   _изде, _fenw, nédi, paľo, 
   {{0x6aa0983f,0x7981f12f,0xb66802a9,0xdbd80166}},	//   mumf, _genw, тиёз_, _eçäb, 
   {{0x6d5c01a2,0x6aa1f130,0xa7fc00ac,0xe7dc012d}},	//   _úrad, lumf, lqım, याआप, 
   {{0x4cbc4251,0x7bc9f131,0x25ac00bc,0x260c00e2}},	//   ্মপু, _xagu, řel_, ežot_, 
   {{0x6aa1f132,0xdce00171,0x00000000,0x00000000}},	// [385d0] numf, _pelī, --, --, 
   {{0x683c00f2,0x36d4010a,0x00000000,0x00000000}},	//   dédi, _тоьр, --, --, 
   {{0xf65000f7,0xd7a8d295,0x00000000,0x00000000}},	//   _بئي_, _कामच, --, --, 
   {{0xf8b01a4c,0x60d40e3c,0x00000000,0x00000000}},	//   ישע_, _vrzm, --, --, 
   {{0x7bc9f133,0x5398025f,0x645c8b14,0x6aa02625}},	//   _ragu, _אירו, _iisi, jumf, 
   {{0x645df134,0x6db4074d,0xaf0401ca,0x3cdc190c}},	//   _hisi, ийчу, шпіл, कमले_, 
   {{0x645df135,0x683c034c,0x66e8002e,0x60d402d0}},	//   _kisi, pédh, _yëkë, _urzm, 
   {{0x645df136,0x7981f137,0x5ac8beee,0x6aa0014b}},	//   _jisi, _senw, елим_, fumf, 
   {{0x6aa02939,0x79800368,0x7bc89698,0x628df138}},	//   gumf, _penw, _vagu, nsao, 
   {{0xaac405d7,0x628c0051,0x00000000,0x00000000}},	//   _वनरक, isao, --, --, 
   {{0x5c75f139,0x26c80b23,0x645df13a,0xd8b80133}},	//   _слет, _asao_, _oisi, رددا_, 
   {{0x7bc80eda,0x6aa1f13b,0x628c020c,0xd709f13c}},	//   _uagu, bumf, ksao, енме_, 
   {{0xaae40133,0x6aa1f13d,0xf6640139,0xca4c0150}},	//   _نسوو, cumf, регү, _ﻌﻭﺩ_, 
   {{0x645df13e,0x98a49298,0xd9440116,0x18a4010b}},	//   _aisi, _бике, _йели, _бакм, 
   {{0x26c803d1,0x260c0171,0x00000000,0x00000000}},	//   _esao_, ežos_, --, --, 
   {{0x645df13f,0x68fc2b96,0xb4c40562,0x00000000}},	//   _cisi, ørde, _एनी_, --, 
   {{0xc68cf703,0x645df140,0x628c1b26,0x04406ff7}},	// [385e0] _فِي_, _disi, gsao, сетн, 
   {{0x645df141,0x690809a5,0x71040588,0x7468036b}},	//   _eisi, _ösdü, аҧга, _изоҳ_, 
   {{0x645df142,0x628c1140,0x66e8002e,0x6aa00356}},	//   _fisi, asao, _tëkë, zumf, 
   {{0x4cbc009e,0x00000000,0x00000000,0x00000000}},	//   ্মমু, --, --, --, 
   {{0x877800c8,0x63c400fb,0x00000000,0x00000000}},	//   גאני, _таяҡ, --, --, 
   {{0x3a24003e,0x683c73a0,0x804400db,0x00000000}},	//   _njnp_, rédi, _ەركۅ, --, 
   {{0x645df143,0x683c0798,0x6aa0c478,0x8f740153}},	//   _yisi, sédi, wumf, _бузі, 
   {{0x683df144,0x645c18f7,0x50640184,0x291800c6}},	//   pédi, _xisi, _атҡа, úram_, 
   {{0xc9840828,0x00000000,0x00000000,0x00000000}},	//   луни, --, --, --, 
   {{0x6aa1f145,0x6a142be9,0x60c800de,0x00000000}},	//   rumf, рмоу, _ņemi, --, 
   {{0x6aa0f49e,0xac84010a,0x00000000,0x00000000}},	//   sumf, _тӳлл, --, --, 
   {{0x6aa002c4,0xa8340063,0xe8f8013d,0x00000000}},	//   pumf, ремљ, елү_, --, 
   {{0xcaf4fbe8,0x645dae6e,0xa7fc00ac,0x00000000}},	//   _حساب, _risi, qqım, --, 
   {{0x645df146,0x00000000,0x00000000,0x00000000}},	//   _sisi, --, --, --, 
   {{0xaf7800b7,0x00000000,0x00000000,0x00000000}},	//   ርስትና_, --, --, --, 
   {{0x628df147,0x26c80109,0x645df148,0x6d4800d7}},	//   tsao, _tsao_, _qisi, _mzda, 
   {{0x26c80cf4,0x9f5c00d2,0xf1e00490,0xa5c4010b}},	// [385f0] _usao_, khwá_, नांन, _көве, 
   {{0x6d49f149,0x260c0024,0x628c0165,0x6e240036}},	//   _ozda, ržos_, rsao, éibl, 
   {{0x645df14a,0x628c023a,0x290c0369,0x00000000}},	//   _tisi, ssao, nzda_, --, 
   {{0x645df14b,0xa3d45977,0x25ac110c,0x628c00b5}},	//   _uisi, _томч, đelu_, psao, 
   {{0xdee5f14c,0x00000000,0x00000000,0x00000000}},	//   роли, --, --, --, 
   {{0xa0c44b13,0x683c020c,0x3eac00d8,0xf1ac0073}},	//   _پيرو, médu, rtgt_, _चायन, 
   {{0x9d44010b,0xa2cc3517,0x00000000,0x00000000}},	//   шекд, सिक्, --, --, 
   {{0xb7b000fe,0x00000000,0x00000000,0x00000000}},	//   _ছফ্ট, --, --, --, 
   {{0x6d485440,0xbda50dbc,0x290c0030,0x1a0400d1}},	//   _ezda, _محاو, ezda_, ипим, 
   {{0x7c844676,0x2ef5f14d,0x9b9401d3,0x00000000}},	//   _буде, _узур, _چلات, --, 
   {{0xb4c400af,0xe874036b,0x01cc0154,0x1ca40133}},	//   _एने_, ینیگ, রাপদ, _ڵێکی_, 
   {{0x6604003e,0xe7dc5612,0x00000000,0x00000000}},	//   _alhk, यागप, --, --, 
   {{0x290c033f,0x87e40032,0x62488ab2,0x597400db}},	//   azda_, рһың_, _džoz, _кыйу, 
   {{0x3e6808fb,0x672c0175,0x7af9f14e,0x290c022e}},	//   _møt_, _dxaj, myut, bzda_, 
   {{0x7af84f08,0xd6a00055,0x98a40137,0xd938010f}},	//   lyut, _kṛkī_, _тийе, _בײַש, 
   {{0x93c800e5,0x6258e668,0x00000000,0x00000000}},	//   کاڑہ_, ғрур_, --, --, 
   {{0x7af9f14f,0x88380375,0xd185f150,0x3e68003b}},	// [38600] nyut, _בתקו, илай, _nøt_, 
   {{0x7af80d04,0x38606ff9,0x9f4c0137,0x37c40bd6}},	//   iyut, _hiir_, _lleó_, _тәүб, 
   {{0x1da80882,0x3861f151,0xa91c0419,0x00000000}},	//   च्छत, _kiir_, vaľk, --, 
   {{0x7af81187,0x38600067,0x28a800e1,0x00000000}},	//   kyut, _jiir_, _कमसि, --, 
   {{0xfe6df152,0x683c20ef,0x3861f153,0x9f5c0327}},	//   ودو_, cédu, _miir_, nkwè_, 
   {{0x38601bce,0x273401fb,0xd24c0133,0x00000000}},	//   _liir_, ụng_, _کۆڕ_, --, 
   {{0x8fd09e04,0xac18c4b4,0x20d40816,0x00000000}},	//   _мәдә, локу_, _літс, --, 
   {{0x776401f0,0x6d4802fb,0x38601bce,0x3e6803b2}},	//   _ngix, _vzda, _niir_, _føt_, 
   {{0xfba40764,0x0dc801e0,0x61f403b2,0xbf98011a}},	//   _गारम, _илай_, _áflø, _שימש, 
   {{0x386001ab,0x6d4800b5,0x2d98035b,0x00000000}},	//   _aiir_, _tzda, _ÿre_, --, 
   {{0x38603d27,0xddc815b2,0x672c002e,0x67d4797f}},	//   _biir_, _uteš, _sxaj, бону, 
   {{0x290df154,0x7af9f155,0x3860058a,0x9cf40131}},	//   rzda_, byut, _ciir_, _учуш, 
   {{0x38600694,0xf8b405f5,0x167001ec,0x7af800dc}},	//   _diir_, гөө_, пқыр, cyut, 
   {{0xfa30034c,0x776401c4,0x85880108,0x00000000}},	//   _ورود, _egix, ъёма_, --, 
   {{0xedf406bc,0x83a81b74,0x3860d695,0x66040232}},	//   _अवैध_, ктаб_, _fiir_, _vlhk, 
   {{0x672c0218,0x38601bce,0x71f80214,0x00000000}},	//   _txaj, _giir_, یرلس_, --, 
   {{0xfd540882,0x62d80006,0x37b000cc,0x00000000}},	// [38610] _draṣ, ымаў_, _জোকৰ, --, 
   {{0x683df156,0x3d14007d,0x07700150,0x00000000}},	//   rédu, _भइले_, _دۇڭح, --, 
   {{0x35f8090f,0x65640c8c,0x3e68168c,0x2f7402e3}},	//   _خريد_, _ighh, _søt_, _ịnọ_, 
   {{0x38600de2,0xf1e0012c,0x3e6803b2,0x1cc00327}},	//   _xiir_, नाउन, _pøt_, གསལ_, 
   {{0xc25404fb,0x2bbc0b7c,0x8d2802dd,0x92b001ec}},	//   _نخست, ्जना, ңнің_, _ىڭكا, 
   {{0xee3810f5,0x44280208,0xf1a41fbe,0x00000000}},	//   ані_, _hjc_, _мрсн, --, 
   {{0x70947ecf,0x442800b5,0x99d475de,0xdd940022}},	//   _марф, _kjc_, ەتجا, _ҳазы, 
   {{0x61f40369,0x7af9f157,0x44280171,0x00000000}},	//   _hozl, tyut, _jjc_, --, 
   {{0xdd95f158,0x7af80357,0x201df159,0x386000e8}},	//   _газы, uyut, miwi_, _riir_, 
   {{0x201df15a,0x7af9f15b,0x3ebc003e,0x38611ba9}},	//   liwi_, ryut, _iput_, _siir_, 
   {{0x3861f15c,0x9f4c0139,0x7af802d1,0x61f4033f}},	//   _piir_, _ileñ_, syut, _mozl, 
   {{0x3ebc03a2,0x68fc022c,0x201c02b9,0xd94400d1}},	//   _kput_, ørda, niwi_, _қейи, 
   {{0x38600221,0x9f4c0165,0x41c4041c,0x00000000}},	//   _viir_, _kleñ_, रजास, --, 
   {{0x201df15d,0x4429f15e,0x99840597,0xaee400b8}},	//   hiwi_, _ajc_, _الثو, _atṛp, 
   {{0x201df15f,0x3861e188,0x44280171,0xfd5400cd}},	//   kiwi_, _tiir_, _bjc_, _praṣ, 
   {{0x65640477,0x201c009f,0x4428054e,0x00000000}},	//   _eghh, jiwi_, _cjc_, --, 
   {{0x3ebdf160,0x61f50647,0x201df161,0x5fe000bc}},	// [38620] _nput_, _bozl, diwi_, फाईल, 
   {{0x442800ca,0x52740131,0x61f40356,0x292804a7}},	//   _ejc_, _қуму, _cozl, štaš_, 
   {{0x44280a73,0x3ebdf162,0x61f403e0,0xe7dc0073}},	//   _fjc_, _aput_, _dozl, याचप, 
   {{0x4f09f163,0x8fa421e0,0x63a800e2,0x0ca80107}},	//   лнен_, саде, _ķeng, ҳтии_, 
   {{0x248c00da,0x3ebc0472,0xbea018b6,0x60c800e2}},	//   ņemt_, _cput_, зачк, _ņemt, 
   {{0x201c0069,0x61f45556,0x7c28017a,0xd0102ab4}},	//   aiwi_, _gozl, _ajgr, _کلر_, 
   {{0xdd98454e,0x201c01f7,0xacc821f3,0x20240162}},	//   рші_, biwi_, рҳез_, ðsið_, 
   {{0x8aa43acc,0x683c003e,0x1cc00327,0x61f401b9}},	//   брод, hédr, གསཿ_, _zozl, 
   {{0x1ea800b2,0x7c280036,0x61f46164,0x3a700166}},	//   _نالي_, _djgr, _yozl, плыр, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7a340276,0x9f4c02d2,0x41b8010f,0xfce0014b}},	//   спэр_, _hleð_, נצטע, _нофо, 
   {{0xcb680601,0x00000000,0x00000000,0x00000000}},	//   _саде_, --, --, --, 
   {{0x98b80aed,0x683c0158,0x4428062c,0x1be40ce0}},	//   āsā_, fédr, _rjc_, कारल_, 
   {{0x8624cadc,0x201df164,0x6e2400c6,0x442801fb}},	//   сьме, ziwi_, éibh, _sjc_, 
   {{0x61f4a3f5,0x201c268a,0x00000000,0x00000000}},	//   _rozl, yiwi_, --, --, 
   {{0x61f5f165,0x201c02b9,0x93f400ac,0x00000000}},	//   _sozl, xiwi_, _şərə, --, 
   {{0x201c0564,0x7cfc0248,0x00e001ec,0x4df820f0}},	// [38630] viwi_, _kàrú, _ﺍﻧﺘﺘ, ्साई_, 
   {{0x3ebc0194,0xdb19f166,0x6564014f,0x201df167}},	//   _rput_, _kawò, _ughh, wiwi_, 
   {{0x5f78040d,0x201df168,0x61f40427,0x3ebdf169}},	//   لماس_, tiwi_, _vozl, _sput_, 
   {{0x3ebc013c,0xa2c404a9,0xdb18007f,0x248c005f}},	//   _pput_, _мәзк, _mawò, ņems_, 
   {{0x61f5f16a,0x201c1b7b,0x4438bf5f,0xdb18007f}},	//   _tozl, riwi_, moq_, _lawò, 
   {{0x201df16b,0x4439c085,0xdc99f16c,0xa7fc0790}},	//   siwi_, loq_, атиш_, rpıy, 
   {{0xd7a83622,0xcc842f33,0x1be802f6,0x4438013c}},	//   _कालच, обще_, идки_, ooq_, 
   {{0x44380af5,0x6b80089c,0xe7d80316,0x201c014b}},	//   noq_, gbmg, _बोलप, qiwi_, 
   {{0x3f8df16d,0x3ebc009b,0x9f4c03b2,0x6d5c86cf}},	//   magu_, _uput_, _gleð_, _úran, 
   {{0x4438d36a,0x99640228,0xa91c00d0,0xdd903346}},	//   hoq_, өтүл, haľu, _آوا_, 
   {{0xd7e8a99b,0x44393d70,0x6aa06eea,0x97c43da1}},	//   амне_, koq_, armf, ойне, 
   {{0x3f8df16e,0x4438cb0a,0xdb08017a,0x48c800fe}},	//   nagu_, joq_, ngeë, িমূৰ, 
   {{0x4439f16f,0x6cb400db,0x99f40064,0x00000000}},	//   doq_, _дөөт, _мякі, --, 
   {{0x3f8df170,0x7c398409,0xab38004e,0x00000000}},	//   hagu_, lour, _упчу_, --, 
   {{0x3f8c01c0,0xdb18007f,0x443801b9,0x63bc0175}},	//   kagu_, _gawò, foq_, _bbsn, 
   {{0xf1ac47d0,0x63bcbb96,0x4438013c,0x3f8c11d4}},	//   _चाहन, _cbsn, goq_, jagu_, 
   {{0xdb105725,0x3f8dd009,0x0ca40073,0x15b8004e}},	// [38640] éfèr, dagu_, _गम्म, _кыны_, 
   {{0x7c39f171,0xd7a80ebb,0x00000000,0x00000000}},	//   hour, _काँच, --, --, 
   {{0x7c395d04,0x4438c108,0x3f8c0b23,0xd4680063}},	//   kour, boq_, fagu_, _њиме_, 
   {{0x7c39f172,0x3f8caa20,0x4438037e,0xb4c82ce6}},	//   jour, gagu_, coq_, ोटी_, 
   {{0x7c39f173,0x99840219,0x3dc4015d,0xddc000c0}},	//   dour, dolž_, fenw_, _gilū, 
   {{0xd1bc0020,0x3dc4015d,0xa7fc0166,0x00000000}},	//   ሰቦች_, genw_, lqıt, --, 
   {{0x3f8df174,0x7c39f175,0xb1482c26,0x412401f0}},	//   bagu_, four, _ایام_, _доро_, 
   {{0x7c39f176,0x3f8c0526,0x8fe4007b,0x00000000}},	//   gour, cagu_, _بأسم, --, 
   {{0x1a7801d5,0xa91c00d7,0x61f00a87,0x00000000}},	//   یشیک_, haľt, _íklæ, --, 
   {{0xdb180d29,0x443801b9,0xce0400e3,0x388401d3}},	//   _pawò, zoq_, _بذري, főr_, 
   {{0x7c39f177,0x4439f178,0x2d8c045f,0xbe102ba5}},	//   bour, yoq_, _iede_, _تولع, 
   {{0x2d8dcc21,0x7c38c6d9,0x38bc0847,0xfc000114}},	//   _hede_, cour, _särö_, _опхо, 
   {{0x77640c04,0x4439f179,0x2d8df17a,0x1a2401d9}},	//   държ, voq_, _kede_, _کرنُ, 
   {{0x2d8df17b,0x3f8c005a,0x44380066,0x00000000}},	//   _jede_, zagu_, woq_, --, 
   {{0x69c9f17c,0x2d8df17d,0x44380eda,0x3f8df17e}},	//   mede, _mede_, toq_, yagu_, 
   {{0x69c9f17f,0x2d8df180,0x3f8c011f,0x00000000}},	//   lede, _lede_, xagu_, --, 
   {{0x4439f181,0x4168026a,0x00000000,0x00000000}},	// [38650] roq_, ајем_, --, --, 
   {{0x69c9f182,0x443832ff,0x7c39f183,0xdb100231}},	//   nede, soq_, zour, éfér, 
   {{0x4439f184,0x69c9f185,0x3f8df186,0xa91c0419}},	//   poq_, iede, tagu_, paľu, 
   {{0x69c9f187,0x2d8c0381,0x92a80183,0x823405d9}},	//   hede, _aede_, _খনৰ_, _ڀرسا, 
   {{0x63adf188,0x3f8df189,0x2d8df18a,0x69c9f18b}},	//   mgan, ragu_, _bede_, kede, 
   {{0x63adf18c,0x69c8c75b,0x2d8df18d,0x3f8c005a}},	//   lgan, jede, _cede_, sagu_, 
   {{0x7c39f18e,0x2d8df18f,0x63ac5bae,0xdce00003}},	//   tour, _dede_, ogan, _belġ, 
   {{0x3f8c0194,0x69c80076,0x7c380165,0xd6a000b8}},	//   qagu_, eede, uour, _kṛtī_, 
   {{0x2d8df190,0x7c39f191,0x63adf192,0x00000000}},	//   _fede_, rour, igan, --, 
   {{0x63adf193,0x2d8df194,0x7c39f195,0x388401ed}},	//   hgan, _gede_, sour, tőr_, 
   {{0x7c39f196,0x63ac9676,0x692401f0,0x00000000}},	//   pour, kgan, ҷмӯа, --, 
   {{0x63ac0007,0xad240075,0x2bc800db,0xb8f002db}},	//   jgan, _تىمى, _мучо_, _सई_, 
   {{0x63ac39c2,0x2d8c016b,0xdb1000fd,0xfa1400f1}},	//   dgan, _yede_, ägän, _ورتګ_, 
   {{0x63adf197,0x7e7800ec,0x2d8c01c6,0x3d1c09ab}},	//   egan, _mtup, _xede_, _बधाइ_, 
   {{0x1cc00489,0xb4c8190e,0x00000000,0x00000000}},	//   གསི_, ोटे_, --, --, 
   {{0x63ac5dd2,0x68fdf198,0x273402e3,0x00000000}},	//   ggan, ärde, ụna_, --, 
   {{0x7e7800ca,0x0694007b,0xefe00023,0x9574005b}},	// [38660] _ntup, _فنية_, ዓታዊ_, _нынч, 
   {{0x63adf199,0xdb08002e,0x51540150,0x00000000}},	//   agan, ggeé, птеу, --, 
   {{0x2d8df19a,0x7e79f19b,0x63ac0083,0x66005df7}},	//   _rede_, _atup, bgan, ölke, 
   {{0x69c9f19c,0x45240327,0x00000000,0x00000000}},	//   zede, _རྨིར_, --, --, 
   {{0x2d8df19d,0x69c9f19e,0x4424013f,0xe1f001d3}},	//   _pede_, yede, ɑn_, رسے_, 
   {{0xd25001d9,0x69c80005,0xdce006be,0xb064002f}},	//   _سنز_, xede, _adlı, fräß, 
   {{0x2d8df19f,0xe81c05f9,0x7e79f1a0,0x00000000}},	//   _vede_, _पगला_, _etup, --, 
   {{0x2d8c0286,0x6d5c0022,0x70540133,0x99840064}},	//   _wede_, _úram, _کۆڵا, kolų_, 
   {{0x2d8c0bed,0x69c9f1a1,0x7e7800ca,0x4f080184}},	//   _tede_, tede, _gtup, _унан_, 
   {{0x63adf1a2,0x7d2401d3,0x69c9107b,0x00000000}},	//   zgan, ársá, uede, --, 
   {{0x69c9f1a3,0x63ac7fa5,0xb4c80034,0x28f801dd}},	//   rede, ygan, ोटो_, цень_, 
   {{0xcc15f1a4,0x4c15f1a5,0x63ac0007,0x60c0007c}},	//   _عذاب, _عباس, xgan, _älme, 
   {{0xf40403d4,0x00000000,0x00000000,0x00000000}},	//   ৰচাৰ_, --, --, --, 
   {{0x69c9c9e3,0x63ac058a,0x291801e7,0x00000000}},	//   qede, wgan, úras_, --, 
   {{0x63adf1a6,0xd6a00055,0x67d400db,0x6934030d}},	//   tgan, _bṛsī_, _жойу, _юнку, 
   {{0x63adf1a7,0xbb5000d1,0x660001e3,0x00000000}},	//   ugan, _ﺋﻮﻥ_, ölkb, --, 
   {{0x63adf1a8,0x27e9f1a9,0x3358084c,0x61f80006}},	// [38670] rgan, _inan_, затэ_, онаў_, 
   {{0xb0c8000d,0xa7fc06be,0x00000000,0x00000000}},	//   रबंग, cqır, --, --, 
   {{0x55b8011a,0xf1a44f73,0xd5b000bc,0x00000000}},	//   _ומתו, эртн, _जातज, --, 
   {{0xd2f4004b,0x63e4004b,0xc0c001e0,0xdb7c0b82}},	//   _ښکلا_, _تېرې_, мәғи, ረንደም_, 
   {{0x27e8009a,0x9ea802bf,0xb2740212,0x00000000}},	//   _mnan_, івка_, _пляш, --, 
   {{0x06680131,0x9d443160,0x00000000,0x00000000}},	//   _ﻳﻮﻟﯩ, мелд, --, --, 
   {{0x27e9f1aa,0xdce00327,0x31340117,0x3d14000d}},	//   _onan_, _melħ, _зерр, _भेखे_, 
   {{0x92c00183,0x27e8008e,0x5ba8005b,0xbb2400e5}},	//   ্মৰ_, _nnan_, цким_, ےتھے_, 
   {{0x7e79f1ab,0x200df1ac,0xa7fc00ac,0xee840024}},	//   _utup, _ilei_, yqır, _зыхо, 
   {{0x27e9f1ad,0xf2d4008f,0xdce000ef,0xeec4009f}},	//   _anan_, געץ_, _eglā, _سيمپ, 
   {{0x200c2ad4,0xd78800b2,0x6ce4177b,0xed040150}},	//   _klei_, يندو_, _піце, _كوكپ, 
   {{0x7d01f1ae,0x27e801ab,0x00000000,0x00000000}},	//   myns, _cnan_, --, --, 
   {{0x27e9f1af,0x29180d12,0x7d01f1b0,0x00000000}},	//   _dnan_, úrar_, lyns, --, 
   {{0x200c0228,0x27e851d0,0xf1ac0cf1,0xd46832b0}},	//   _llei_, _enan_, _चाइन, живе_, 
   {{0x200c0381,0xa6c801ed,0x344800ee,0x98d0000d}},	//   _olei_, _ہوٹل_, зүни_, _तनिए, 
   {{0x23d4084c,0x00000000,0x00000000,0x00000000}},	//   нцур, --, --, --, 
   {{0x60c805be,0xdce0031c,0x7d002694,0x6600007c}},	// [38680] _ćema, _felħ, hyns, ölkc, 
   {{0x7d01f1b1,0x200df1b2,0x27e8d7fc,0x394401a8}},	//   kyns, _alei_, _znan_, _kyns_, 
   {{0x200df1b3,0x040000bd,0x3944010b,0x23780051}},	//   _blei_, রোধী_, _jyns_, _ffsj_, 
   {{0x39440ea0,0x67480174,0xe7c0043e,0x4f240139}},	//   _myns_, _ósjó, ष्पप, мдеб, 
   {{0xda0c07af,0x00000000,0x00000000,0x00000000}},	//   ाघात_, --, --, --, 
   {{0x200df1b4,0x6da412dd,0x7d00ecf1,0x00000000}},	//   _elei_, رمعم, fyns, --, 
   {{0x0ca802bf,0x39440076,0xd00800f0,0x7d000432}},	//   ітки_, _nyns_, _деве_, gyns, 
   {{0x200c330f,0x60340153,0x00000000,0x00000000}},	//   _glei_, tąme, --, --, 
   {{0x39449d34,0xfbccecb1,0x3e78054e,0xaef800cc}},	//   _ayns_, شتي_, _câtă_, _আইকণ_, 
   {{0x27e801ab,0x3944a5b6,0xc33000d9,0xbea0013d}},	//   _snan_, _byns_, כוח_, _шаук, 
   {{0x200c0286,0x27e8007f,0xf1ac0456,0x92a800cc}},	//   _ylei_, _pnan_, _चाईन, _খনো_, 
   {{0x6d4803ac,0x3d1428fe,0x00000000,0x00000000}},	//   _iyda, _भेटे_, --, --, 
   {{0xc7640617,0x92c00154,0x00000000,0x00000000}},	//   بادى, ্মু_, --, --, 
   {{0x3944037e,0xa4d5df06,0x27e80142,0x6d4800d7}},	//   _fyns_, ногі, _wnan_, _kyda, 
   {{0x69d80851,0x443c0016,0x6d48010e,0x04640798}},	//   _iave, _ưu_, _jyda, дтам, 
   {{0x27e803bd,0x6d4800ee,0x69d9a167,0x765c03cb}},	//   _unan_, _myda, _have, amry, 
   {{0x69d9f1b5,0x7d01f1b6,0x6d49451f,0x26dc0241}},	// [38690] _kave, zyns, _lyda, _éwo_, 
   {{0x69d98c6c,0x6d49f1b7,0x200c0042,0x7d0001f4}},	//   _jave, _oyda, _slei_, yyns, 
   {{0x69d9f1b8,0x200c1028,0x6d4808cb,0x2f7c02e3}},	//   _mave, _plei_, _nyda, _ịmụ_, 
   {{0x69d9f1b9,0x6fd40212,0x1558011a,0x7d000108}},	//   _lave, кціє, _מכתב, vyns, 
   {{0x6d49f1ba,0x3d14ec76,0x200c0af9,0x69d802d0}},	//   _ayda, _भेजे_, _vlei_, _oave, 
   {{0x7cd003be,0x7d01f1bb,0x3d24013f,0x6dc40131}},	//   _hərə, tyns, _pɑw_, نزىل, 
   {{0x6d4873b0,0x7cd00213,0xaee40055,0xc0c80023}},	//   _cyda, _kərə, _puṃp, በቶም_, 
   {{0x200c084c,0xcb940075,0x69d9f1bc,0x1bb800c6}},	//   _ulei_, ىنىش_, _aave, سابع_, 
   {{0x7d01f1bd,0x3944cf77,0xdb0801f5,0x9e2403cc}},	//   syns, _syns_, rgeï, _كىرو, 
   {{0x69d9f1be,0x7d000652,0x7c840262,0x00000000}},	//   _cave, pyns, _жуде, --, 
   {{0xd8247201,0x69d9f1bf,0x6d4800a9,0xae040046}},	//   едни, _dave, _gyda, _جولى, 
   {{0x69d9f1c0,0x68fd493a,0xb8e432ed,0x7cd003b9}},	//   _eave, ärda, _उह_, _nərə, 
   {{0x69d9f1c1,0x3944000f,0x6d480064,0x4aa4000d}},	//   _fave, _wyns_, _zyda, _खियव, 
   {{0x69d9f1c2,0x7bd80a63,0x99d402f2,0x8af8011a}},	//   _gave, lduu, _ستتا, _מפנק, 
   {{0x3f9ceabd,0x89d400ec,0x7cd00213,0x660001e3}},	//   _oduu_, _سوير_, _bərə, ölka, 
   {{0x69d81d2d,0x7bd9f1c3,0x7cd00213,0x00000000}},	//   _zave, nduu, _cərə, --, 
   {{0x69d8192e,0x7cd003be,0x52a800a7,0x00000000}},	// [386a0] _yave, _dərə, явам_, --, 
   {{0x69d9f1c4,0x3f9c8ebb,0x5ef400cd,0xc738011a}},	//   _xave, _aduu_, ्हन्_, _מתפת, 
   {{0x4fc5f1c5,0x7cd00213,0x00000000,0x00000000}},	//   есла, _fərə, --, --, 
   {{0x283c0125,0x68fc0579,0x7cd000ac,0x6d4803cb}},	//   _ኩባንያ, ørdi, _gərə, _ryda, 
   {{0x7bd822a9,0x6d49f1c6,0xff05f1c7,0x04000154}},	//   dduu, _syda, нецк_, রোহী_, 
   {{0x3f9c016b,0x7cd000ac,0x6d4800a2,0x00000000}},	//   _eduu_, _zərə, _pyda, --, 
   {{0x8fa5f1c8,0x00000000,0x00000000,0x00000000}},	//   _паве, --, --, --, 
   {{0x6d48278a,0x7bd9f1c9,0x2054299e,0x69d9f1ca}},	//   _vyda, gduu, _атур, _save, 
   {{0x69d9f1cb,0x6d48006d,0x1cc003bd,0x4fc401e0}},	//   _pave, _wyda, གསཔ_, _осҡа, 
   {{0x7bd8198f,0x6d485794,0xe9f800d4,0x4d1401f4}},	//   aduu, _tyda, єнні_, _пьет, 
   {{0x0b885402,0x69d9f1cc,0x7bd8198f,0x6d487885}},	//   _если_, _vave, bduu, _uyda, 
   {{0x69d8975e,0x7bd80009,0x00000000,0x00000000}},	//   _wave, cduu, --, --, 
   {{0x25a400e4,0xfe9800df,0x00000000,0x00000000}},	//   óllo_, ּילמ, --, --, 
   {{0x7cd000ac,0x3b500006,0x683c00e5,0x00000000}},	//   _sərə, _скір, nédz, --, 
   {{0x248c0bb8,0xd9ec03e5,0x4b5003e6,0xf6c80327}},	//   ćemo_, जारत_, _جێکر, གསུང, 
   {{0x7cd00213,0x972000e5,0x00000000,0x00000000}},	//   _qərə, اہیو, --, --, 
   {{0x6b84033d,0xe7c128d3,0x7cd000ac,0xcbc000cd}},	// [386b0] _õigu, ष्णप, _vərə, व्यञ, 
   {{0xe7b0000d,0x00000000,0x00000000,0x00000000}},	//   _झाँप, --, --, --, 
   {{0x7cd011a9,0x5f94d3bb,0x25a001ab,0x36340150}},	//   _tərə, виет, _idhl_, _حريس, 
   {{0x24800098,0xf8b0008f,0x00000000,0x00000000}},	//   _ithm_, טשע_, --, --, 
   {{0x644da984,0x248000a2,0x7bd80327,0x00000000}},	//   mlai, _hthm_, vduu, --, 
   {{0x6235597f,0x644df1cd,0x7bd801d9,0xdca5a4cc}},	//   _регу, llai, wduu, ваки, 
   {{0xdce0068f,0x0c70036b,0x3ce8012d,0x71e40153}},	//   _oglą, لگند, झमें_, _сцяж, 
   {{0x644df1ce,0x9f200075,0x8ca011b1,0x26c80960}},	//   nlai, _پۈتۈ, _गिरो, _opao_, 
   {{0x7bd9f1cf,0xdd9400c7,0x644df1d0,0x00000000}},	//   rduu, _аазы, ilai, --, 
   {{0x644df1d1,0x7bd9f1d2,0x1a041fbe,0xaac42dd0}},	//   hlai, sduu, тпом, اتين, 
   {{0x644df1d3,0x3eac62b4,0xcd4000e5,0x00000000}},	//   klai, lugt_, _پھوٹ, --, 
   {{0x1ce031d9,0x73fc04c5,0x6600007c,0x00000000}},	//   _སླར_, _ইষ্ট_, ölkn, --, 
   {{0x644df1d4,0x8c180375,0x00000000,0x00000000}},	//   dlai, _קוני, --, --, 
   {{0x25fc01ad,0x644df1d5,0x1de000dc,0x2af000bc}},	//   रॉली_, elai, पयित, ेहरु_, 
   {{0x629c003a,0xb40400f7,0x644d18ab,0x15440798}},	//   _avso, гүнд, flai, тевм, 
   {{0x644c1489,0x34f400d1,0x00000000,0x00000000}},	//   glai, вҗүт, --, --, 
   {{0x91940063,0x9584010a,0x00000000,0x00000000}},	// [386c0] вјеш, _илпе, --, --, 
   {{0x644df1d6,0x464400c7,0x3eac0174,0xf49c0023}},	//   alai, _изын_, dugt_, _ንፍለጥ_, 
   {{0x644df1d7,0x00000000,0x00000000,0x00000000}},	//   blai, --, --, --, 
   {{0x644df1d8,0x8fa467b7,0x3eacbc7f,0x00000000}},	//   clai, таде, fugt_, --, 
   {{0x37dc015b,0x7ed000c6,0x3eac0036,0x00000000}},	//   ধাপর, لزوا, gugt_, --, 
   {{0x43652e74,0xf1ac033f,0xd1749b96,0x2d5803cf}},	//   _шаян_, _चाटन, _шымы, ниль_, 
   {{0x4f9448fb,0x3eac03ef,0x00000000,0x00000000}},	//   _арзу, augt_, --, --, 
   {{0x3eac0194,0xcb0831df,0x6f380354,0x00000000}},	//   bugt_, дход_, _пӳлĕ, --, 
   {{0x0e65f1d9,0xc984013e,0xabb4035b,0x2ea80133}},	//   _акан, куни, вақә, _سپای_, 
   {{0x2bd405f9,0x644c0007,0x68fc007c,0x00000000}},	//   _दसवा, zlai, ärdo, --, 
   {{0x26c80e3c,0x644df1da,0x00000000,0x00000000}},	//   _spao_, ylai, --, --, 
   {{0x27edf1db,0x4b240b7e,0x644c04e6,0x8b2410ae}},	//   ñen_, _имев, xlai, _идее, 
   {{0x25a0562c,0x2c790334,0x644c00e2,0xc6a46a11}},	//   _pdhl_, _héd_, vlai, ърни, 
   {{0x27ec01d3,0x937401ec,0xdce0012d,0x644c015d}},	//   űen_, ғұрт_, _wglą, wlai, 
   {{0x6b8400c5,0x644df1dc,0x212000bc,0xbb340092}},	//   _õigs, tlai, _मधेश_, _ይስተዋ, 
   {{0x644df1dd,0x61140046,0x68fc022c,0x1ce0031c}},	//   ulai, ңдау, ørdu, _སླས_, 
   {{0x644df1de,0x26c81b24,0x2c780036,0x33744b53}},	// [386d0] rlai, _upao_, _léd_, ргур, 
   {{0x6eb800dc,0xc64400db,0x90640131,0xdb081e0b}},	//   ोऽनु, _جئبى, ۇنلۇ, ngeá, 
   {{0x24802a1f,0x644df1df,0x32d80210,0x00000000}},	//   _uthm_, plai, eżyć_, --, 
   {{0x629c058a,0x00000000,0x00000000,0x00000000}},	//   _tvso, --, --, --, 
   {{0xf8ac0073,0x00000000,0x00000000,0x00000000}},	//   _झम्प, --, --, --, 
   {{0x2c7805c7,0x3ead4607,0x00000000,0x00000000}},	//   _béd_, rugt_, --, --, 
   {{0x2c780332,0x709408ca,0xddc00171,0x4c900114}},	//   _céd_, _васф, _cilš, бијс, 
   {{0x2c780113,0x00000000,0x00000000,0x00000000}},	//   _déd_, --, --, --, 
   {{0x2fc001ab,0x1b480108,0xa0a43452,0x00000000}},	//   òige_, эзии_, _шаңд, --, 
   {{0x60c800e4,0x00000000,0x00000000,0x00000000}},	//   _ņemy, --, --, --, 
   {{0xbef0069f,0xaad8000b,0xadf00037,0xb86c0092}},	//   _आपुन_, _बैठक, चारन_, _አደጋው_, 
   {{0x9815f1e0,0xb8e81715,0xfab4037e,0xb8f8012c}},	//   ابدا, _रङ_, _tル_, _डन_, 
   {{0xba74fd47,0xb6040306,0x53a41c34,0x00000000}},	//   _شاشت, ášov, ғазб, --, 
   {{0x98e5f1e1,0x1ce0025c,0xb8b00220,0x6d5c08c2}},	//   _مكتو, _སློ_, _көмі, _ùrac, 
   {{0xb60400d7,0x00000000,0x00000000,0x00000000}},	//   ššov, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x969401d5,0x78100b4c,0x00000000,0x00000000}},	// [386e0] _ёриш, ासीक_, --, --, 
   {{0x47180677,0x00000000,0x00000000,0x00000000}},	//   _נויג, --, --, --, 
   {{0xd0080801,0xe7c000cd,0x00000000,0x00000000}},	//   неже_, ष्वप, --, --, 
   {{0x1ce0025c,0xb4c000ab,0x2d980427,0x93f403e3}},	//   _སླེ_, ंझी_, _žre_, _şəfə, 
   {{0xadf01d94,0x00000000,0x00000000,0x00000000}},	//   चालन_, --, --, --, 
   {{0x2c780165,0x00000000,0x00000000,0x00000000}},	//   _péd_, --, --, --, 
   {{0xdb080158,0x0ca801b9,0x0fe00304,0xac1800f3}},	//   ngeæ, хтли_, _гөлү, коку_, 
   {{0xddc0b9bd,0x2c7879e9,0x00000000,0x00000000}},	//   _vilš, _véd_, --, --, 
   {{0x75280b21,0xdb4c4451,0x00000000,0x00000000}},	//   údzj, وێم_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4c8411ed,0xdb180e78,0xe81801d5,0xdb080332}},	//   _слев, _abwä, вонч_, rgeá, 
   {{0xdb240133,0xa7fc03b9,0x00000000,0x00000000}},	//   اویی, lqız, --, --, 
   {{0x69c4053f,0xaa9400cf,0x00000000,0x00000000}},	//   _көнб, _тилч, --, --, 
   {{0xa7fc03b9,0x00000000,0x00000000,0x00000000}},	//   nqız, --, --, --, 
   {{0x38c477de,0x03c5f1e2,0x3ce402e5,0x066802dd}},	//   _буын_, лсам, झिये_, _ﺳﻮﻧﯩ, 
   {{0x3fdc045e,0x00000000,0x00000000,0x00000000}},	//   _ভক্ষ, --, --, --, 
   {{0x46680354,0x41e40816,0x33840064,0x00000000}},	// [386f0] _пром_, ліжа, сусв, --, 
   {{0x45a001ec,0x00000000,0x00000000,0x00000000}},	//   _دەسك, --, --, --, 
   {{0xa7fc06be,0x00000000,0x00000000,0x00000000}},	//   dqız, --, --, --, 
   {{0xd7080183,0xefcc0023,0x00000000,0x00000000}},	//   ৰপৰা_, _አበይ_, --, --, 
   {{0x53980302,0xb284084c,0x60340024,0x625801c3}},	//   _בירו, _гыск, sąmo, rìob, 
   {{0x622404a9,0xdb080724,0x1ce0025c,0x5de4117e}},	//   _ئىسل, lgeç, _སླུ_, ржка, 
   {{0xdfd40108,0x30e400c0,0x00000000,0x00000000}},	//   _ковы, _літб, --, --, 
   {{0xace8ac69,0x69a401e0,0xdb082ca8,0x4b840395}},	//   ارول_, ҡлыҡ, ngeç, айън_, 
   {{0x91c803d4,0x00000000,0x00000000,0x00000000}},	//   ৰাৰ্, --, --, --, 
   {{0xaab4000d,0x00000000,0x00000000,0x00000000}},	//   ंढ़क, --, --, --, 
   {{0x5bb9ae02,0xdb091025,0xec3401d5,0x00000000}},	//   _алея_, rfeñ, شویگ, --, 
   {{0xfc6400a7,0xd1b80023,0x00000000,0x00000000}},	//   _съзн, _ሳዓት_, --, --, 
   {{0x68fc00cc,0xda340064,0x5eb800eb,0x00000000}},	//   ørdr, _кеды, _ইনডে, --, 
   {{0x81a8febc,0x645c011f,0x98140214,0xc1dc1a55}},	//   ক্ত_, _ahsi, ابگا, नयोग, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf815f1e3,0x645c0113,0x9694d150,0x672001e4}},	//   _دستگ, _chsi, _крош, ŝlja, 
   {{0x645d0531,0x00000000,0x00000000,0x00000000}},	// [38700] _dhsi, --, --, --, 
   {{0x85b00075,0xe7300254,0x00000000,0x00000000}},	//   _мәсч, tööü, --, --, 
   {{0x2dc80131,0x00000000,0x00000000,0x00000000}},	//   һқан_, --, --, --, 
   {{0x3a240129,0x4aa40412,0x00000000,0x00000000}},	//   _lmnp_, _खिलव, --, --, 
   {{0x2dc802dd,0x87780115,0x00000000,0x00000000}},	//   лқан_, דאני, --, --, 
   {{0x625800a3,0x7ee000db,0x00000000,0x00000000}},	//   rìoc, زكىن, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa3c81b87,0xebd80a31,0xb03400f1,0x99840118}},	//   ल्प_, удиш_, _اورګ, filů_, 
   {{0xebc40032,0x3f641422,0x660001e3,0xbc641063}},	//   _ғәйн, _вито_, ölkk, جمين_, 
   {{0xdb08f3aa,0xa7fc03b9,0x00000000,0x00000000}},	//   zgeç, qqız, --, --, 
   {{0x2d9df1e4,0x1cc40327,0x6e280f85,0x00000000}},	//   mave_, _ཏཱར_, _imdb, --, 
   {{0x2d9df1e5,0x397402d3,0x998400bc,0x00000000}},	//   lave_, _በዓልቲ_, bilů_, --, 
   {{0xc984036b,0xa3c80141,0x7d0c00d0,0x7b8400d1}},	//   _куйи, ल्फ_, čisť, _ئامە, 
   {{0x2d9df1e6,0xa3c80316,0xf2dc00cc,0x25ac0112}},	//   nave_, ल्न_, ঠমাণ, ßel_, 
   {{0x2d9c0421,0x65940058,0xf5e402bf,0x24180a89}},	//   iave_, _қану, ціям, говы_, 
   {{0x25ac0724,0x2d9cb180,0x290d63d7,0x00000000}},	//   şel_, have_, myda_, --, 
   {{0x2d9df1e7,0x290df1e8,0x00000000,0x00000000}},	// [38710] kave_, lyda_, --, --, 
   {{0x72182401,0x3ebc022e,0x290c0067,0x00000000}},	//   ажур_, _rqut_, oyda_, --, 
   {{0x66040649,0x645df1e9,0x2d9df1ea,0x995400a2}},	//   _iohk, _thsi, dave_, _müşk_, 
   {{0x0ee002ab,0x660401f4,0xf0e80124,0x00000000}},	//   पिंड, _hohk, шьук_, --, 
   {{0xdee43afa,0x6605f1eb,0x2d9df1ec,0x225996be}},	//   соли, _kohk, fave_, _ملحد_, 
   {{0x2d9df1ed,0xae040131,0xdb0811c0,0x660401f4}},	//   gave_, يونى, ngeå, _johk, 
   {{0x4c900640,0x31347760,0x660406be,0xde340092}},	//   пијс, _дерр, _mohk, ክለኛው, 
   {{0xf538025d,0x6605f1ee,0x6e280175,0x2d9c0022}},	//   ינוי_, _lohk, _emdb, aave_, 
   {{0xa3c994ac,0xfce001b9,0x59740137,0x290c0067}},	//   ल्य_, соқо, йыну, eyda_, 
   {{0x2d9df1ef,0x7528068f,0x66040036,0x00000000}},	//   cave_, ździ, _nohk, --, 
   {{0x9d544767,0x4aa400c5,0x290c00a2,0x00000000}},	//   _انات, _खिअव, gyda_, --, 
   {{0xa3c844ab,0x96b9f1f0,0x1cb00327,0x88b40154}},	//   ल्म_, лугу_, _ཞྀག_, _জনশক, 
   {{0x44e400df,0x7ae4004b,0x290c058a,0x1038010f}},	//   _aĵ_, _خوشې_, ayda_, רגרע, 
   {{0xdb081600,0xf484006c,0xd1f80023,0x290c010e}},	//   ggeå, قاری, ሊታት_, byda_, 
   {{0x660406a3,0x60c001e6,0x798003ac,0x290c0009}},	//   _dohk, _älmh, _ifnw, cyda_, 
   {{0x2d9d8ecd,0x38a1ef66,0x93f403be,0x44e40115}},	//   zave_, mır_, _şəbə, _dĵ_, 
   {{0x38a005f3,0xb34403be,0x9f54020c,0xc20c0014}},	// [38720] lır_, _keçə, _èfèr_, کٔل_, 
   {{0x81a803f4,0x660520ee,0x2d6c013b,0x63bc02d0}},	//   ক্স_, _gohk, yɛe_, _ecsn, 
   {{0x38a06f30,0x2d9df1f1,0x38602a1f,0x3eac04e6}},	//   nır_, vave_, _khir_, ergt_, 
   {{0x2d9df1f2,0x68fdf1f3,0x2f880184,0x7ae8792b}},	//   wave_, ärdi, рҙан_, _orgt, 
   {{0x2d9df1f4,0x9f482242,0x386000a3,0x6604037e}},	//   tave_, ðað_, _mhir_, _yohk, 
   {{0xdb1800d2,0x7bc80083,0x38a06648,0x1ea8c852}},	//   _gcwé, _abgu, kır_, شاهي_, 
   {{0x2d9df1f5,0x7ae950a7,0x3860022e,0x64407439}},	//   rave_, _argt, _ohir_, élig, 
   {{0x38a13a66,0x2d9df1f6,0x2d6c016b,0xe0d0004b}},	//   dır_, save_, rɛe_, _ډزې_, 
   {{0x34d49518,0x2d9df1f7,0x2d6c0134,0x995403b9}},	//   दबुद, pave_, sɛe_, _püşk_, 
   {{0x3861f1f8,0x38a003ee,0x290df1f9,0xff140375}},	//   _ahir_, fır_, tyda_, _הקמת_, 
   {{0x660583b5,0xa3c81ab2,0x67d400f7,0x38600055}},	//   _rohk, ल्ड_, оону, _bhir_, 
   {{0x3861892f,0x290c010b,0x66040254,0x5a3400db}},	//   _chir_, ryda_, _sohk, йнөт, 
   {{0x38600067,0x66040108,0xf1d8012d,0x00000000}},	//   _dhir_, _pohk, ड़ान, --, 
   {{0x38a0c5d2,0xbb38008f,0x91c800dc,0xb34406be}},	//   bır_, _געדי, स्मै, _geçə, 
   {{0x386014d0,0x38a003e0,0x00000000,0x00000000}},	//   _fhir_, cır_, --, --, 
   {{0x69c805e4,0x3860014f,0x60c0013d,0x00000000}},	//   lfde, _ghir_, _älmi, --, 
   {{0x6605f1fa,0x69c80373,0x93f403b9,0x00000000}},	// [38730] _tohk, ofde, _şəcə, --, 
   {{0x39a8043b,0x798002d0,0x00000000,0x00000000}},	//   _pɔsɔ_, _xfnw, --, --, 
   {{0x69c80af9,0x20d40a11,0xc0e40092,0x06680150}},	//   ifde, تقاس, _ማተም_, _ﺳﻮﻳﯩ, 
   {{0x9f54cfae,0x321804ba,0x64400077,0x00000000}},	//   овеч, _elry_, élid, --, 
   {{0x38a02c6f,0x41e4177b,0xf65001d3,0x248c107d}},	//   zır_, _ліва, _زئی_, ćemu_, 
   {{0x628df1fb,0x38a1c6f3,0xb8c8081f,0xee3802bf}},	//   mpao, yır_, _བྷ_, бні_, 
   {{0x4428eed2,0x38a000ac,0xa3c825fe,0xfe7401f0}},	//   _kmc_, xır_, ल्थ_, рӯғ_, 
   {{0x69c80430,0x7af801c4,0xb3440213,0x38a00e2d}},	//   efde, txut, _seçə, vır_, 
   {{0x4429f1fc,0x628df1fd,0x9e340d6f,0x69c80036}},	//   _mmc_, npao, _деач, ffde, 
   {{0x38a071e1,0x38600050,0x81a800bd,0x49c42235}},	//   tır_, _shir_, ক্র_, ольн_, 
   {{0x4429f1fe,0x61e40013,0x332000d8,0x00000000}},	//   _omc_, idhl, zzix_, --, 
   {{0x38a045a5,0x7e79f1ff,0x4428fcbb,0x69c8005c}},	//   rır_, _kuup, _nmc_, afde, 
   {{0x38a0b753,0x7c28a2e5,0x3860004e,0x7e785979}},	//   sır_, _imgr, _vhir_, _juup, 
   {{0x7e7805b8,0xeab00133,0x38a03bc1,0x44280f85}},	//   _muup, _سعه_, pır_, _amc_, 
   {{0x201df200,0x3861f201,0x44281587,0x7e780821}},	//   khwi_, _thir_, _bmc_, _luup, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4429f202,0x628c1e92,0x7e79f203,0xe578016c}},	// [38740] _dmc_, gpao, _nuup, рзӣ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7e780607,0x7c2803d4,0x628c0421,0xcf980120}},	//   _auup, _omgr, apao, ајл_, 
   {{0x44298e12,0xf6e8031c,0x201c0978,0x660044b3}},	//   _gmc_, _སློང, ghwi_, ölkv, 
   {{0x7e78198f,0xaad82db8,0x6440f20f,0xbea08e38}},	//   _cuup, _बैंक, élie, дачк, 
   {{0x0ca9f204,0x7c29f205,0x00000000,0x00000000}},	//   атии_, _amgr, --, --, 
   {{0xdce0236c,0xdd9801ec,0x00000000,0x00000000}},	//   _belı, сші_, --, --, 
   {{0x201c016d,0x291808c2,0xbc6400ae,0x00000000}},	//   chwi_, ùram_, يمون_, --, 
   {{0x1ea8143e,0xdce00205,0xd5c8a740,0x00000000}},	//   _هالي_, _delı, िभाज, --, 
   {{0x2dc80150,0x82f4011a,0x70540244,0x00000000}},	//   _دارۋ_, קציב_, _بۆڵا, --, 
   {{0x7c28004e,0x69c801f5,0x0af800cc,0x00000000}},	//   _fmgr, rfde, ইনেল_, --, 
   {{0xdce00790,0x91c82314,0x00000000,0x00000000}},	//   _gelı, स्तै, --, --, 
   {{0x09e5f206,0x7e7895bd,0x4428387a,0x8f4c0023}},	//   _модн, _xuup, _rmc_, _ንዓኣቶ, 
   {{0x09280214,0x44281587,0xa9785a52,0x0ae800ec}},	//   _پستي_, _smc_, _уйку_, _مرڪي_, 
   {{0x4429f207,0x7c280042,0x92c803d4,0x00000000}},	//   _pmc_, _ymgr, লটো_, --, 
   {{0x68fc0037,0x00000000,0x00000000,0x00000000}},	//   ärdu, --, --, --, 
   {{0x442806af,0x00000000,0x00000000,0x00000000}},	// [38750] _vmc_, --, --, --, 
   {{0x628c0cb6,0x7e7811a6,0x00000000,0x00000000}},	//   rpao, _ruup, --, --, 
   {{0x442851e5,0x628c003e,0xf5040014,0x201c0477}},	//   _tmc_, spao, _ہِیُ, thwi_, 
   {{0x7e79aaf5,0x60c5f208,0xf0e80075,0x4428ed6f}},	//   _puup, rthm, غىنى_, _umc_, 
   {{0x644df209,0x2120020c,0x836401af,0x00000000}},	//   moai, szhh_, _фњнд, --, 
   {{0x644df20a,0x201df20b,0x8eb00145,0xc1e801f4}},	//   loai, shwi_, رمىش, _тьме_, 
   {{0x7c28004e,0x625800a3,0x00000000,0x00000000}},	//   _pmgr, nìom, --, --, 
   {{0x644df20c,0xff28036b,0x44380098,0x2b900214}},	//   noai, _кўзи_, nnq_, پیوس, 
   {{0x644c0421,0xdb081347,0xbda81e24,0x00000000}},	//   ioai, ngeø, _نطام_, --, 
   {{0x644cccb6,0xaee40882,0xadb4004e,0x00000000}},	//   hoai, saṃs, _обуш, --, 
   {{0x644df20d,0x1cc40327,0x066802dd,0x00000000}},	//   koai, _ཏཱི_, _ﺳﻮﻋﯩ, --, 
   {{0x9984136e,0x7c28bb50,0x644c0022,0xdce00166}},	//   _کلثو, _umgr, joai, _uelı, 
   {{0xed9c693c,0x644c01c0,0xd87407d6,0x4b780375}},	//   _ግንባር_, doai, _کاتب, _האנו, 
   {{0xa3c83d60,0x44380097,0x4dfc00dc,0xaa7c0023}},	//   ल्स_, enq_, लायै_, _ኣሰቃቒ_, 
   {{0x644c04c9,0x7c38010a,0x18688f18,0x49d804f2}},	//   foai, onur, _лаки_, _دانگ_, 
   {{0x1ce007e4,0x7c39f20e,0x644c1140,0x26c40356}},	//   _སླབ_, nnur, goai, ălor_, 
   {{0x7c39f20f,0x00000000,0x00000000,0x00000000}},	// [38760] inur, --, --, --, 
   {{0x7c381196,0x59bc00dc,0xe2440b24,0x6600007c}},	//   hnur, ्भिर, وخلي, ölkt, 
   {{0x64401dec,0xa3c8007d,0x7c39c091,0x644cdbd9}},	//   élic, ल्ह_, knur, boai, 
   {{0x62809a4d,0xd3d8007b,0x7c380432,0x06cc00eb}},	//   _člov, _ابدا_, jnur, িটরি, 
   {{0x59bcb305,0xe7c01a3e,0x7c380162,0x0374011a}},	//   ्भार, ष्टप, dnur, _מתכת_, 
   {{0xd250007b,0x00000000,0x00000000,0x00000000}},	//   _أنس_, --, --, --, 
   {{0x1ce00003,0xdb1800d2,0xa3c80d41,0xb1740150}},	//   _སླད_, _ncwâ, ल्व_, _ﺟٶﺗﺎ, 
   {{0x7c39f210,0x5928025c,0x1fb4004e,0x00000000}},	//   gnur, _སྟེས_, _осур, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2bac004d,0x644df211,0x8e4800db,0x7c3801ab}},	//   ớc_, zoai, _الئك_, anur, 
   {{0x7c38208d,0xdde801d5,0x644c01f7,0x5b14004e}},	//   bnur, _برقه_, yoai, змөт, 
   {{0xe7594012,0x0134011a,0x00000000,0x00000000}},	//   жимі_, לרית_, --, --, 
   {{0x644c0356,0xb71403c5,0x00000000,0x00000000}},	//   voai, едящ, --, --, 
   {{0x68fc0267,0xb604084c,0x644c062c,0xe9181cd0}},	//   ärds, няск, woai, _молі_, 
   {{0x644df212,0x88c40327,0xc888009a,0x00000000}},	//   toai, _ཀཱིར, _اختل_, --, 
   {{0x395402e4,0x499001b9,0x00000000,0x00000000}},	//   _משום_, _تیگر, --, --, 
   {{0x644df213,0xe5e401d5,0x1ce00327,0x66000267}},	// [38770] roai, _قزدی, _སླན_, ölks, 
   {{0x644df214,0x3254010b,0xc0d80092,0x00000000}},	//   soai, евур, _ኖሯል_, --, 
   {{0x644df215,0xf4840354,0x00000000,0x00000000}},	//   poai, _пуян, --, --, 
   {{0x98c408ad,0xa3c8134e,0xe2f80150,0x00000000}},	//   žući_, ल्श_, _демі_, --, 
   {{0x7c38022c,0x823496b4,0x00000000,0x00000000}},	//   vnur, _فرسا, --, --, 
   {{0xee3800d3,0x2b1000bc,0x00000000,0x00000000}},	//   пні_, दैछु_, --, --, 
   {{0xc3380020,0x7c380162,0x00000000,0x00000000}},	//   _በመጠቀ, tnur, --, --, 
   {{0x7c380037,0xad440372,0x00000000,0x00000000}},	//   unur, رۉنۉ, --, --, 
   {{0xafc4021f,0x4bc0009d,0xd9e000eb,0x00000000}},	//   _سيلى, төхг, বাসম, --, 
   {{0x7c38000d,0x00000000,0x00000000,0x00000000}},	//   snur, --, --, --, 
   {{0x1869f216,0xaac47983,0x41cc102f,0x00000000}},	//   жани_, وتین, स्यस, --, 
   {{0x69dc0086,0xfbc000fe,0xdc0400cf,0x5b15c457}},	//   ôrer, ্যহত, _تسئۋ, _омет, 
   {{0xddc00006,0x8c1400ec,0xd7600133,0x1ae401c6}},	//   _milž, _زيور_, کۆکی, _цолм, 
   {{0x3f9c0421,0x7bd9f217,0x79e400e5,0x00000000}},	//   _leuu_, leuu, _روبہ_, --, 
   {{0x38c4004b,0x00000000,0x00000000,0x00000000}},	//   _راغی_, --, --, --, 
   {{0x68fd0fd7,0xc950025d,0xd76003e6,0xb404010b}},	//   årde, _שמה_, _لۆجی, хүмд, 
   {{0x11e401b9,0x64400129,0x00000000,0x00000000}},	// [38780] мжам, élia, --, --, 
   {{0x7bd80098,0x51640137,0xf9f800cc,0x00000000}},	//   heuu, дүгү_, ইসকল_, --, 
   {{0x1cc80003,0x3f9dd671,0x7bd80093,0xddc000e2}},	//   ྲངས_, _beuu_, keuu, _bilž, 
   {{0x6d5c08c2,0xf1a80133,0x28b00037,0x00000000}},	//   _ùrai, زاڕه_, _झिसि, --, 
   {{0x6d5c0122,0xb8ec025c,0x63b80034,0x7bd80dd9}},	//   _úraz, _ུད_, ówne, deuu, 
   {{0x3f9cb0eb,0x7bd8003e,0xe4c82a77,0xad8400f7}},	//   _eeuu_, eeuu, _ببین_, راتۇ, 
   {{0xc0e000c7,0x50d0e572,0x8c6402dd,0xdb18012d}},	//   _иорк, _सहिष, мтид, _obwó, 
   {{0xc338001f,0x7bd8017a,0x00000000,0x00000000}},	//   _በመጥቀ, geuu, --, --, 
   {{0x2fc4007f,0x9e240014,0x9eb00116,0x00000000}},	//   _icmg_, بى۪و, _مەنغ, --, 
   {{0x93f406be,0x00000000,0x00000000,0x00000000}},	//   _şələ, --, --, --, 
   {{0x2919f218,0x28f83f51,0x7bd80165,0xbe10107b}},	//   ára_, чень_, beuu, _جولع, 
   {{0x60c000cc,0x2fc00e89,0xebc40139,0xdce000ef}},	//   _ålme, òigh_, _чәкн, _eglē, 
   {{0x6f0404d1,0x29180024,0x784401c6,0x8a043947}},	//   äich, šra_, тээж, _озде, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa3d454d9,0x00000000,0x00000000,0x00000000}},	//   новч, --, --, --, 
   {{0xe3c405f5,0xc864036b,0x00000000,0x00000000}},	//   эргү, _ўтки, --, --, 
   {{0x27e9f219,0x2bd0412f,0x3358084c,0x82340b24}},	// [38790] _iaan_, थ्या, датэ_, ورطا, 
   {{0x27e9f21a,0x91c807f7,0xb978010f,0xd838009d}},	//   _haan_, स्लै, ַנדי, _мэө_, 
   {{0x27e80a55,0x31c40801,0x7bd8003e,0x81c400ef}},	//   _kaan_, ъств, yeuu, _neēš, 
   {{0x27e9f21b,0x2fc40421,0xa29402d5,0x9514011a}},	//   _jaan_, _ccmg_, _памі, _נקרא_, 
   {{0x27e9f21c,0x4270035b,0xdea0036b,0x25a0002f}},	//   _maan_, _аҳас, ایطی, _kehl_, 
   {{0x780c0574,0x2ee403e3,0xdc9800d1,0x00000000}},	//   _हक्क_, _dsmf_, птиш_, --, 
   {{0x3f9df21d,0x25a1f21e,0x24800254,0xddc04a38}},	//   _teuu_, _mehl_, _juhm_, _tilž, 
   {{0x27e856bd,0xdb180429,0x5ba9f21f,0x7bd8003e}},	//   _naan_, _acwá, чким_, ueuu, 
   {{0x6b840075,0xef540801,0x3da4c40a,0x25a001bf}},	//   خشىل, _акть, _жреб, _oehl_, 
   {{0xfdf0032c,0x629c0042,0x7bd80037,0x00000000}},	//   _आफिस_, _mwso, seuu, --, 
   {{0x27e9f220,0x200c05e4,0x00000000,0x00000000}},	//   _baan_, _koei_, --, --, 
   {{0x27e801d9,0x2b4015ad,0x41cc0882,0x28b0000d}},	//   _caan_, _žice_, स्तस, _झिरि, 
   {{0x27e9f221,0xcc3800c8,0xdb08002f,0x41cc0037}},	//   _daan_, _צענט, ngeü, _सउंस, 
   {{0xdb1800d2,0x200df222,0x6441f223,0xd945f224}},	//   _gcwá, _loei_, élin, _пели, 
   {{0x27e99d8b,0x7dd07236,0x629c83fb,0xd4680114}},	//   _faan_, mısı, _awso, зиве_, 
   {{0x27e9f225,0x7dd191ab,0x00000000,0x00000000}},	//   _gaan_, lısı, --, --, 
   {{0x2480382c,0x25a01196,0xd264004e,0xa90800db}},	// [387a0] _euhm_, _fehl_, екай, _ىيۇل_, 
   {{0x7764d059,0x7dd03279,0x27e80b4f,0xc61400cc}},	//   _izix, nısı, _zaan_, ডোবা_, 
   {{0x27e9f226,0x629c7511,0x200c0b4f,0xe574014b}},	//   _yaan_, _ewso, _boei_, _аҷр_, 
   {{0x7dd000ac,0x765df227,0xf3b400fd,0xcf440a89}},	//   hısı, llry, _шөгы, нней, 
   {{0x200c01a4,0x7dd02737,0x8d8400d1,0x00000000}},	//   _doei_, kısı, нуйд, --, 
   {{0x41c40490,0x2d5803cf,0x00000000,0x00000000}},	//   _लायस, миль_, --, --, 
   {{0x200c3a65,0x80d00137,0x7dd00205,0x00000000}},	//   _foei_, _مۅلچ, dısı, --, 
   {{0x83c00ed1,0x200c257c,0x776466d4,0x00000000}},	//   ﺭﻗﺎﻳ, _goei_, _ozix, --, 
   {{0x27e81c06,0xfbcc15f2,0xad440372,0x00000000}},	//   _raan_, صتي_, رۉچۉ, --, 
   {{0x27e9f228,0x60340109,0x76400158,0x1d940153}},	//   _saan_, ląmp, émyl, _арцё, 
   {{0x77640b6f,0x27e9f229,0x00000000,0x00000000}},	//   _azix, _paan_, --, --, 
   {{0x24800086,0x27e80067,0xe9d80137,0x38c455b2}},	//   _ruhm_, _qaan_, чкү_, راپی_, 
   {{0x27e80664,0x81a80f22,0x81e404c5,0x7dd02ca8}},	//   _vaan_, ক্ট_, ভাত_, bısı, 
   {{0x27e96282,0x49902580,0x7dd00259,0xf5e5f22a}},	//   _waan_, _حیدر, cısı, лісм, 
   {{0x64400231,0x27e9f22b,0x0464b66b,0x77646e0e}},	//   élio, _taan_, етам, _ezix, 
   {{0x2bbc0998,0xa6f4084c,0x25a001f5,0x1d340023}},	//   ﬁcat_, _азиш, _wehl_, _ክንእዘ, 
   {{0xf6d4040b,0x200c0ea0,0xd9300023,0xa2d401f7}},	// [387b0] _یزید, _roei_, _ኣንቶን, ضيات, 
   {{0x200c0e02,0x24800254,0xc0c801ec,0xf990010f}},	//   _soei_, _tuhm_, зуде_, ָרף_, 
   {{0x1cbc0156,0x00000000,0x00000000,0x00000000}},	//   _ཇའེ_, --, --, --, 
   {{0x443c1105,0x7dd006b9,0xdf3800c6,0x35680166}},	//   _ñu_, zısı, وكات_, _ярын_, 
   {{0xdee4603a,0x7dd00365,0x6d4884d4,0xb36400a7}},	//   толи, yısı, _axda, _бърк, 
   {{0xfe54006c,0x200c01f5,0x00000000,0x00000000}},	//   ریاب_, _woei_, --, --, 
   {{0x200c067c,0xdb081196,0x7dd003e0,0x00000000}},	//   _toei_, sgeü, vısı, --, 
   {{0xbb6407ad,0x7a4400ef,0x00000000,0x00000000}},	//   _netホ_, _mītņ, --, --, 
   {{0x2d8c0175,0x6d4802d0,0x93f40213,0x7dd02c87}},	//   _ffde_, _exda, _şəkə, tısı, 
   {{0x7f580113,0x00000000,0x00000000,0x00000000}},	//   _iyuq, --, --, --, 
   {{0xd94403a6,0x7dd03e67,0x00000000,0x00000000}},	//   тени, rısı, --, --, 
   {{0x68fc01e6,0x00000000,0x00000000,0x00000000}},	//   årda, --, --, --, 
   {{0x7dd00259,0xaa94009d,0x00000000,0x00000000}},	//   pısı, _бичч, --, --, 
   {{0xd1f80023,0x00000000,0x00000000,0x00000000}},	//   ዊታት_, --, --, --, 
   {{0x78680165,0xe2980150,0x00000000,0x00000000}},	//   eñve, _ﺘﺨﻭﻡ_, --, --, 
   {{0x1cc40156,0x88b800d9,0x00000000,0x00000000}},	//   _ཏཱན_, _חזקי, --, --, 
   {{0x77640fec,0x46e40276,0x99540432,0x63b80210}},	// [387c0] _uzix, _адын_, _süňk_, ówna, 
   {{0x42200a13,0xc1a00118,0x00000000,0x00000000}},	//   адув, říně, --, --, 
   {{0x7f580784,0xa0880220,0x00807503,0x00000000}},	//   _ayuq, есіз_, алхо, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfd540248,0x00000000,0x00000000,0x00000000}},	//   _ipaṣ, --, --, --, 
   {{0x93f40cc1,0xfe6c037b,0x2cac01f5,0xc69008a8}},	//   _şəhə, يدو_, _pvdd_, סאו_, 
   {{0xa3c8000b,0x4338001f,0x10a401c6,0x00000000}},	//   ल्क_, _በመተባ, _шивн, --, 
   {{0xcfa80424,0x2ec40304,0x00000000,0x00000000}},	//   _زارم_, _бөкм, --, --, 
   {{0x0dc80220,0xbf1000db,0x00000000,0x00000000}},	//   _олай_, _پولب, --, --, 
   {{0x1dc80490,0x2d980124,0x00000000,0x00000000}},	//   _रायत, _ýre_, --, --, 
   {{0x6e38009a,0x2cb801d3,0x9cd400ec,0x00000000}},	//   mivb, _írd_, _مملڪ, --, 
   {{0x28c403f3,0xe695f22c,0xfb80013d,0x00000000}},	//   लंबि, лимы, _кышн, --, 
   {{0x64402d7d,0x6564003e,0xbc180a7c,0x9f9c02d2}},	//   élim, _szhh, _קודש, _mæðu_, 
   {{0x9f9c02d2,0x00000000,0x00000000,0x00000000}},	//   _læðu_, --, --, --, 
   {{0x03c44077,0xd5d00303,0x00000000,0x00000000}},	//   ксам, द्धज, --, --, 
   {{0x996402bf,0x6e38014f,0xdce00153,0x342400d4}},	//   _стіл, hivb, _eglė, афув, 
   {{0xa3c80014,0x46681086,0x6e380250,0x78680156}},	// [387d0] ल्ग_, _ором_, kivb, uñve, 
   {{0x6e380477,0x00000000,0x00000000,0x00000000}},	//   jivb, --, --, --, 
   {{0x24186cea,0x2a7c01f5,0x65940124,0x00000000}},	//   _зоны_, _mivb_, _иаҿу, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x53980302,0xbe300124,0x6ee4027d,0x00000000}},	//   _רישו, аҭаш, لسول, --, 
   {{0x9d440220,0xf194030d,0x00000000,0x00000000}},	//   лелд, _вирь, --, --, 
   {{0x5c541f91,0x9f9c08a5,0xefd40023,0xf268014b}},	//   лтиф, _fæðu_, የድዎ_, _риёл_, 
   {{0x649001e4,0x1a6401d5,0x00000000,0x00000000}},	//   _eĥig, گیتی_, --, --, 
   {{0xdd95f22d,0x68fc007c,0x91c80210,0x00000000}},	//   _базы, årdn, स्कै, --, 
   {{0x1a655b33,0x1a040d1d,0x41c003ce,0x7e840150}},	//   دیتی_, упом, शलिस, _ﻗﻮﺳﺎ_, 
   {{0xf2d00b33,0x1cbc025c,0x17c8036b,0x7c840117}},	//   _सङ्घ, _ཇའི_, нгни_, _рузе, 
   {{0xed0401b9,0xf5ec00af,0x973401c6,0xd8240022}},	//   _خومپ, _छोड़ि_, гэгч, удми, 
   {{0x201c0810,0x00000000,0x00000000,0x00000000}},	//   ikwi_, --, --, --, 
   {{0xfd5400cd,0x00000000,0x00000000,0x00000000}},	//   _spaṣ, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf8140214,0xdb2003b2,0xb4f400cf,0x00000000}},	//   _خستگ, _ítór, гүүч, --, 
   {{0xa92000ac,0x9f9c01a8,0x045400ae,0x00000000}},	// [387e0] _çörə, _ræðu_, القة_, --, 
   {{0x55e51d5b,0x8698008f,0x00000000,0x00000000}},	//   _сооб, _רייז, --, --, 
   {{0x409001b9,0x00000000,0x00000000,0x00000000}},	//   مللر, --, --, --, 
   {{0x592808ea,0xe04400c7,0xfd540055,0x00000000}},	//   _སྟབས_, аҧсе_, _upaṣ, --, 
   {{0x6e38047e,0x6c34150e,0x00000000,0x00000000}},	//   tivb, یفتا, --, --, 
   {{0xc1e5105c,0x90a44e10,0x00000000,0x00000000}},	//   _مکمل_, _محرم, --, --, 
   {{0x6e3801e6,0xdd9802dd,0x6fcc01f9,0x00000000}},	//   rivb, тші_, _हापू, --, 
   {{0x0ba81dc8,0xcb0808fc,0x00000000,0x00000000}},	//   رابى_, еход_, --, --, 
   {{0xa3c8000b,0x81e400bd,0xb9200109,0xfbcc004b}},	//   ल्ट_, ভার_, _terỳ_, ښتی_, 
   {{0x4ea400c7,0x80c8012d,0x0564013a,0x00000000}},	//   _арҧа, _हममे, _římě_, --, 
   {{0xeff002d3,0x28140214,0xd9e40b27,0xd26000e2}},	//   _ጃንዳ_, لودس, _कसरत_, miņā_, 
   {{0xb4fc03d4,0xf964151e,0xbb44072d,0x00000000}},	//   ীনাথ_, ырый_, ئلین_, --, 
   {{0x2ac40075,0x38340816,0x00000000,0x00000000}},	//   _тәйв, сняр, --, --, 
   {{0x27ed27e9,0x201c009a,0x6ecc00dc,0x00000000}},	//   žen_, zkwi_, _समनु, --, 
   {{0xf9900302,0x2d9c0810,0xb9c000f7,0x63b8012d}},	//   _פרק_, ibve_, _اقىي, ówno, 
   {{0xc7c8004e,0x00000000,0x00000000,0x00000000}},	//   _чыке_, --, --, --, 
   {{0xc64400db,0x00000000,0x00000000,0x00000000}},	// [387f0] _مئدى, --, --, --, 
   {{0x649001e4,0xbb3800c8,0xa5340212,0x00000000}},	//   _aĥie, געמי, _вноч, --, 
   {{0xa3d4eba2,0x5f9418fd,0xd2600171,0x00000000}},	//   _конч, للائ, diņā_, --, 
   {{0x33840323,0xdfd41e76,0x7868030a,0x00000000}},	//   _гурв, роды, oñva, --, 
   {{0x69d88356,0x4439f22e,0x53cc0490,0x5f0401b9}},	//   _obve, miq_, _हॉटश, рзла, 
   {{0x44387885,0xef180953,0xaca401f2,0x625801ab}},	//   liq_, ымі_, chịp, rìos, 
   {{0x47a800cc,0x00000000,0x00000000,0x00000000}},	//   _কানী, --, --, --, 
   {{0x4439f22f,0x69d80112,0x63a80037,0xe0e401a9}},	//   niq_, _abve, _õend, _йўғо, 
   {{0x2fc0007b,0x6d5c03b2,0x29180162,0xd26000de}},	//   óige_, _øran, øran_, biņā_, 
   {{0x4439f230,0xd26000de,0x00000000,0x00000000}},	//   hiq_, ciņā_, --, --, 
   {{0x8b300882,0x4439f231,0xfd4400c0,0x00000000}},	//   rṇaṃ_, kiq_, _сэан, --, 
   {{0x44380007,0x00000000,0x00000000,0x00000000}},	//   jiq_, --, --, --, 
   {{0x4439f232,0x8c180302,0x46e599a4,0x68f805ac}},	//   diq_, _שוני, адян_, _ervd, 
   {{0x7c386018,0x7ae801ab,0xc5b4009d,0x00000000}},	//   liur, _isgt, ирсө, --, 
   {{0x4439f233,0x798002d0,0x00000000,0x00000000}},	//   fiq_, _ignw, --, --, 
   {{0x7c39f234,0x44380399,0x44e40042,0xd26000e2}},	//   niur, giq_, _dŵ_, ziņā_, 
  
   {{0x93580063,0x0874010f,0x00000000,0x00000000}},	// [38800] трву_, _דעקט_, --, --, 
   {{0x7c39f235,0xc6900302,0x7ae80129,0x0201f236}},	//   hiur, _ואז_, _msgt, озун, 
   {{0x7c39f237,0x4439d7a7,0xcfa40075,0x65b86215}},	//   kiur, biq_, ашли, _суыр_, 
   {{0x7bc802c4,0x7c380481,0x4439f238,0xd01001d5}},	//   _ncgu, jiur, ciq_, غلش_, 
   {{0x3dac009e,0x7c38054e,0xd9e4033f,0x3ce8000d}},	//   চ্ছল, diur, क़ात_, _अैबे_, 
   {{0x2b400427,0xfe40322b,0xdb080254,0x38a000e5}},	//   _žico_, ончо, ngeõ, kűr_, 
   {{0xcd045260,0x2d9c0200,0x00000000,0x00000000}},	//   рчли, rbve_, --, --, 
   {{0x7c39f239,0x2900054e,0x01600212,0x00000000}},	//   giur, _ăia_, _єкто, --, 
   {{0x68f80175,0x5cc402dd,0x00000000,0x00000000}},	//   _srvd, асөз, --, --, 
   {{0x4439f23a,0x7c3801f5,0x6f2803e0,0x00000000}},	//   ziq_, aiur, ırcı, --, 
   {{0x4439f23b,0xeff8001f,0x7c38054e,0xc864020f}},	//   yiq_, ጋጀው_, biur, итми, 
   {{0x7c38084c,0x44380007,0x00000000,0x00000000}},	//   ciur, xiq_, --, --, 
   {{0x4439f23c,0xaa94007b,0x44e40042,0x78680165}},	//   viq_, _التث, _sŵ_, uñva, 
   {{0x20c80574,0x44380309,0x69d803ac,0xa5f80114}},	//   ांमध, wiq_, _ubve, ћеву_, 
   {{0x4439f23d,0x2918712c,0x91a8012d,0x22440790}},	//   tiq_, ärad_, टरनै, _ılk_, 
   {{0x99941973,0x69c8e24f,0x193c00b5,0xb978011a}},	//   _پھیر_, lgde, _ｐｈｉ_, _בנוי, 
   {{0xf65016cb,0x61d9f23e,0x00000000,0x00000000}},	// [38810] _ڪئي_, лмая_, --, --, 
   {{0x69c9f23f,0x4439f240,0x2184136b,0x7c380006}},	//   ngde, siq_, стаҳ, ziur, 
   {{0x44386eb3,0x69c801f5,0x68e80042,0xc0d00092}},	//   piq_, igde, nwdd, _የቁም_, 
   {{0x1dc80574,0x4439f241,0x7c38054e,0x00000000}},	//   _राहत, qiq_, xiur, --, 
   {{0x7c39f242,0x645c0205,0xe374004e,0xb408009d}},	//   viur, _iksi, _ылмы, _тээж_, 
   {{0xa1580166,0x3eac143a,0xf7ac00d1,0x00000000}},	//   _багу_, rsgt_, _ﻳﯩﻠﺪ, --, 
   {{0x61e44ca8,0x7c39f243,0x00000000,0x00000000}},	//   mehl, tiur, --, --, 
   {{0x1be9f244,0x61e5f245,0x1dc846c7,0x69c80549}},	//   удии_, lehl, _रावत, egde, 
   {{0x7c39536d,0x645c020b,0x63adf246,0x28c400e1}},	//   riur, _mksi, iaan, लूसि, 
   {{0x63adf247,0x7c39f248,0x69c8369d,0x61e5f249}},	//   haan, siur, ggde, nehl, 
   {{0x60c481be,0xac94059f,0x00000000,0x00000000}},	//   nuhm, _дахш, --, --, 
   {{0x5c75a49b,0xb954044e,0x78a00369,0x61e5f24a}},	//   _улет, _ላዕለዎ, _vwnv, hehl, 
   {{0x63adf24b,0x60c414f9,0x61e456fc,0xceb0008f}},	//   daan, huhm, kehl, ּיל_, 
   {{0x63ac01f5,0xe8e800ec,0x61e401ef,0x00000000}},	//   eaan, _چريو_, jehl, --, 
   {{0x63adf24c,0x66dc01e6,0x8cc800cd,0x05240139}},	//   faan, _påkö, संयो, борк_, 
   {{0x63adf24d,0x68fc037e,0x28b80276,0x60c40477}},	//   gaan, ærde, _тушэ_, duhm, 
   {{0x61e40730,0x862001b9,0x00000000,0x00000000}},	// [38820] fehl, زکیل, --, --, 
   {{0x61e506cc,0xf8d80210,0x00000000,0x00000000}},	//   gehl, _बहाय, --, --, 
   {{0x645c1132,0x00000000,0x00000000,0x00000000}},	//   _fksi, --, --, --, 
   {{0x63adf24e,0x93580120,0x00000000,0x00000000}},	//   caan, _бргу_, --, --, 
   {{0x61e5f24f,0x69c8ce29,0x92f400d6,0x3fc9f250}},	//   behl, ygde, _учні, ادمی_, 
   {{0x60c43223,0x7ee023f6,0xd25000dd,0x68e80042}},	//   buhm, سكىن, _رنز_, ywdd, 
   {{0x645c0664,0x00000000,0x00000000,0x00000000}},	//   _yksi, --, --, --, 
   {{0x8cc80882,0x69c801d4,0x99840064,0x00000000}},	//   संबो, wgde, kilų_, --, 
   {{0xbea061ac,0x00000000,0x00000000,0x00000000}},	//   _натк, --, --, --, 
   {{0x63ac0a49,0x23ac0006,0x69c8057b,0x00000000}},	//   zaan, mųjų_, ugde, --, 
   {{0x63acc1f0,0x29182776,0x69c801a4,0xded4001f}},	//   yaan, âra_, rgde, _የቡና_, 
   {{0x63adf251,0x61e41cdf,0xc6a401c6,0x6edc00ce}},	//   xaan, zehl, йрги, _यहाँ, 
   {{0x63adf252,0xf1a8a05b,0x23ac0006,0x61e57882}},	//   vaan, गरान, nųjų_, yehl, 
   {{0x63adf253,0xdb0804d3,0x41c44ff1,0x28f8084c}},	//   waan, _خزمه_, _लाइस, _векь_, 
   {{0x63adf254,0xa9340116,0xf4840137,0x67d4030d}},	//   taan, _фейш, зуун, _дойу, 
   {{0x290c0007,0x61e49ff9,0x63ac0140,0x88ac0154}},	//   mxda_, wehl, uaan, _কমপক, 
   {{0x61e5f255,0x6e29f256,0x23ac0024,0x77980166}},	// [38830] tehl, _oldb, jųjų_, _укыр_, 
   {{0x23ac0024,0x60c4014f,0x00000000,0x00000000}},	//   dųjų_, tuhm, --, --, 
   {{0x61e5f257,0x493c02d3,0x416800d8,0x00000000}},	//   rehl, _ኣንበብ, ујам_, --, 
   {{0x63adf258,0x60c40a2e,0x645c0309,0x6e2802d0}},	//   qaan, ruhm, _uksi, _aldb, 
   {{0x60c5c6b5,0x61e400d2,0xdef4010b,0x7e6002d0}},	//   suhm, pehl, юпды, tlnp, 
   {{0x2c4c012c,0x9f480086,0xfe0002ab,0x61e40477}},	//   věda_, ñañ_, लाइस_, qehl, 
   {{0xfbd4009e,0x7a3c01e1,0x784401d3,0x00000000}},	//   _দোষত, _látè, lőve, --, 
   {{0x6e28a194,0x290c0009,0x026002f2,0x00000000}},	//   _eldb, dxda_, _بێڕێ, --, 
   {{0x9b04187f,0xd78801e2,0xff0400d4,0x8c14009a}},	//   ізод, یندو_, _уявн, تيير_, 
   {{0xc2140165,0x00000000,0x00000000,0x00000000}},	//   _joʔ_, --, --, --, 
   {{0xa3c81804,0x41c407f7,0x52c40118,0x00000000}},	//   ईला_, _लाईस, _लम्स, --, 
   {{0xad240150,0x66040208,0x9b58004e,0x00000000}},	//   _عىنى, _anhk, _киет_, --, 
   {{0x493c0023,0x00000000,0x00000000,0x00000000}},	//   _ኣንቢብ, --, --, --, 
   {{0x98a400ee,0x18a4010b,0x3b1c0455,0x784400e5}},	//   _дике, _дакм, myuq_, dőve, 
   {{0x18681b2e,0x98600055,0xc31400fe,0x00000000}},	//   _каки_, _eųā_, _ঠেলি_, --, 
   {{0xd875459b,0xccf00302,0xdec80b82,0x6adc0154}},	//   _باتب, וכל_, በለን_, বিরো, 
   {{0x386015f6,0x3b1c0309,0x04400f06,0x00000000}},	// [38840] _ikir_, nyuq_, фетн, --, 
   {{0x23ac0024,0xf7a40244,0x00000000,0x00000000}},	//   vųjų_, _بلکێ, --, --, 
   {{0x765cca60,0xd468e2cc,0x64401186,0x69dc00e4}},	//   mory, _вине_, èlic, õrei, 
   {{0x81e48961,0x765c0034,0x23ac0024,0x7bcc0ffb}},	//   ভাগ_, lory, tųjų_, òcul, 
   {{0x087400c8,0x310c02dd,0xaedc0816,0x00000000}},	//   קענט_, _ءﺳﻮﺯ_, ублi, --, 
   {{0x6d5c0158,0x765db328,0x23ac0024,0x773c0092}},	//   _ørak, nory, rųjų_, _አንስተ, 
   {{0x09b000fe,0x32d4008e,0x00000000,0x00000000}},	//   চলমা, läy_, --, --, 
   {{0xfe6c0058,0x29000953,0x765df259,0x3219f25a}},	//   ىگە_, _čia_, hory, _hory_, 
   {{0x765df25b,0x63b80034,0x290002b5,0x4544001f}},	//   kory, ówni, _ōia_, _የድንበ, 
   {{0x38600214,0x765c00b5,0x6adc00cc,0x00000000}},	//   _akir_, jory, বিলো, --, 
   {{0x77640921,0x649001e4,0x682c045f,0xfa304630}},	//   _ayix, _aĥin, _lûde, بريد, 
   {{0x3219f25c,0x290c571b,0x32d4008e,0xb084003b}},	//   _lory_, rxda_, käy_, овiд, 
   {{0x9bc40489,0x649001e4,0x765c75d3,0xe944028e}},	//   _ཁྐྲོ, _cĥin, fory, ترکی, 
   {{0x765df25d,0xb6040276,0x32194cc7,0x32d4008e}},	//   gory, мяск, _nory_, däy_, 
   {{0x649001e4,0x55c00022,0xf4640055,0x00000000}},	//   _eĥin, хәыз, _ṭvaṃ_, --, 
   {{0x784401d3,0x2814ecfe,0x00000000,0x00000000}},	//   tőve, _روخس, --, --, 
   {{0x321844f1,0x0188005b,0x765c00e4,0xe8f80139}},	// [38850] _bory_, ащей_, bory, _yäşе, 
   {{0xa1580064,0x3ce80037,0xba980a7c,0x784400e5}},	//   базу_, _अईले_, יסמי, rőve, 
   {{0x6440f85a,0xc0c800c0,0xd31c0241,0x3f8001e1}},	//   élis, рузе_, _ò̟nà_, _ńju_, 
   {{0x15580302,0x443c00b0,0x3b1c0309,0xb68805af}},	//   _לכתב, _öu_, yyuq_, _دپیل_, 
   {{0x06f8032c,0x37b0015b,0xdb0c00cc,0x32188f40}},	//   एटिव_, _কামর, _åhøy, _fory_, 
   {{0x44282aa4,0xee3802bf,0x32181329,0x00000000}},	//   _hlc_, оні_, _gory_, --, 
   {{0xed88052f,0x00000000,0x00000000,0x00000000}},	//   әсәк_, --, --, --, 
   {{0x765df25e,0x61f5f25f,0x714400db,0x321800a2}},	//   zory, _hazl, _تۉمۅ, _zory_, 
   {{0x442838bc,0x3b1c0cfe,0x765df260,0x61f5f261}},	//   _mlc_, uyuq_, yory, _kazl, 
   {{0x4429f262,0x61f5ab50,0x3b1c02d1,0x38600064}},	//   _llc_, _jazl, ryuq_, _skir_, 
   {{0x765df263,0x61f5f264,0x4428327f,0x00000000}},	//   vory, _mazl, _olc_, --, 
   {{0x5c7400cf,0x2240003e,0x765c012d,0x4429f265}},	//   _элет, hihk_, wory, _nlc_, 
   {{0x47a803d4,0xc0dc001f,0x3b1c02d1,0x7c2802d0}},	//   _কাশী, _ነሐሴ_, qyuq_, _ilgr, 
   {{0x44280dd4,0x7af9f266,0xc4281c02,0x7bd81ad7}},	//   _alc_, mvut, ەتكە_, lfuu, 
   {{0xd468ebd7,0x3218e7e8,0x386001b9,0x7af9f267}},	//   محرم_, _rory_, _tkir_, lvut, 
   {{0x4429f268,0x765df269,0x3861abb9,0xc4801b10}},	//   _clc_, sory, _ukir_, елск, 
   {{0x4429f26a,0x77640fec,0x3219f26b,0xf8d86c52}},	// [38860] _dlc_, _uyix, _pory_, _बहुप, 
   {{0xdb18002e,0x765c03b9,0x00000000,0x00000000}},	//   _adwë, qory, --, --, 
   {{0x61f40399,0x321803d1,0x32d40724,0x4429f26c}},	//   _dazl, _vory_, säy_, _flc_, 
   {{0x4429f26d,0x4f080139,0xddc801e4,0xeea40150}},	//   _glc_, йнен_, ĝoŝt, _ﺎﻨﻭﻥ_, 
   {{0x61f40ab7,0x3219f26e,0xddc801e4,0xbea00798}},	//   _fazl, _tory_, ŝoŝt, еачк, 
   {{0x61f5e8ea,0x7af81cea,0x7bd81418,0x00000000}},	//   _gazl, dvut, efuu, --, 
   {{0xe6a8084a,0xc0e00c69,0x7bd9e112,0xb14800f2}},	//   _कब्ज, _порк, ffuu, _بیام_, 
   {{0x9f4c0166,0x6ec400cd,0x00000000,0x00000000}},	//   _eneñ_, _रिपु, --, --, 
   {{0xd90c0272,0x64900115,0x61f54c01,0xaee400cd}},	//   ییه_, _aĥil, _yazl, _duṣp, 
   {{0x7bd854f8,0x8318008f,0xf1cc08df,0xdb68009d}},	//   afuu, צויז, ालिन, өрөл_, 
   {{0x7af80869,0x00000000,0x00000000,0x00000000}},	//   avut, --, --, --, 
   {{0x7af90ed2,0x00000000,0x00000000,0x00000000}},	//   bvut, --, --, --, 
   {{0x44280066,0xf1cc11bc,0x00000000,0x00000000}},	//   _rlc_, ालान, --, --, 
   {{0x4428045a,0x00000000,0x00000000,0x00000000}},	//   _slc_, --, --, --, 
   {{0xa3d4fe9c,0x248c01e4,0xb9d8011a,0x00000000}},	//   мовч, ĉemo_, _החוש, --, 
   {{0x44280395,0x61f40209,0x27ec0254,0x00000000}},	//   _qlc_, _sazl, õend_, --, 
   {{0x64407d9b,0xa5f80276,0xa77400fb,0x00000000}},	// [38870] éliq, _депу_, _юлич, --, 
   {{0x61f47a0e,0x45a000d1,0x00000000,0x00000000}},	//   _qazl, _سەرك, --, --, 
   {{0xf770168d,0x3c40007f,0x61f400d8,0x44289ff4}},	//   _لای_, _jèvè_, _vazl, _tlc_, 
   {{0x26d827be,0xe3a43293,0x7bd80009,0x00000000}},	//   otso_, _تشدی, xfuu, --, 
   {{0x644df26f,0x6f0002c4,0x26d9f270,0x61f402ea}},	//   mnai, _crmc, ntso_, _tazl, 
   {{0x629df271,0x644df272,0x27f801ab,0xfe7006c2}},	//   _itso, lnai, hdsn_, ردش_, 
   {{0x644df273,0xaee40882,0x3cf40034,0x81b000cc}},	//   onai, _puṣp, ंटें_, _টাপ_, 
   {{0x6f000175,0x7af8000d,0x00000000,0x00000000}},	//   _frmc, tvut, --, --, 
   {{0xdd9413d7,0x644df274,0x7bd90125,0x7af80140}},	//   _жазы, inai, rfuu, uvut, 
   {{0x644c0fa3,0x7af9f275,0x629c0925,0x649001e4}},	//   hnai, rvut, _mtso, _aĥim, 
   {{0x7bd80e8a,0x26d818d6,0x7af9f276,0x644df277}},	//   pfuu, etso_, svut, knai, 
   {{0x644c7b2b,0x629df278,0x210004a7,0x00000000}},	//   jnai, _otso, mčić_, --, 
   {{0x81b002a6,0x629df279,0x2100041a,0xcfb40375}},	//   _টান_, _ntso, lčić_, ולרי_, 
   {{0x644df27a,0x644000f2,0x00000000,0x00000000}},	//   enai, èlin, --, --, 
   {{0x2100098d,0x629df27b,0x9855f27c,0x644c0042}},	//   nčić_, _atso, _отиш, fnai, 
   {{0x644df27d,0x63bc003a,0x629c037e,0x52a800d8}},	//   gnai, _cdsn, _btso, жвам_, 
   {{0x4b7804ac,0x4340241e,0x6d5c0174,0xd6a800ae}},	// [38880] ַטעג, ветв, _ørav, _بدعم_, 
   {{0x644c65f2,0x210005be,0x464400fd,0xd7c81af5}},	//   anai, kčić_, _озын_, _اوکه_, 
   {{0x629c0184,0x644df27e,0x210007f5,0x3cf4012d}},	//   _etso, bnai, jčić_, ंटों_, 
   {{0x644c0e9e,0xcf441e76,0xe0d001d9,0x00000000}},	//   cnai, мней, ازٕ_, --, 
   {{0x1dc801f9,0x00000000,0x00000000,0x00000000}},	//   _राखत, --, --, --, 
   {{0x14e00073,0xd1740150,0x00000000,0x00000000}},	//   _पहाण, _жыбы, --, --, 
   {{0x649001e4,0x9e64484d,0x2ae00037,0xfce00a5b}},	//   _aĥij, راهن, _कहहु_, војо, 
   {{0xab78001f,0x629c00d7,0x00000000,0x00000000}},	//   _የታየው_, _ytso, --, --, 
   {{0x984400da,0x3c4002e2,0xa0742347,0x48d800cc}},	//   _dēļ_, _sèvè_, _чырш, _বছেৰ, 
   {{0x4d755f6a,0x210001a6,0x0374011a,0xd5c0010a}},	//   _قطار, bčić_, ותפת_, _хlин, 
   {{0xd8b8031c,0x644df27f,0x2d8d4a6c,0x67d430ab}},	//   _དྷཱི, ynai, _igde_, нону, 
   {{0x2b4007f5,0x3c400100,0xcb0802dd,0x00000000}},	//   _žicu_, _vèvè_, _ويان_, --, 
   {{0x2ba40fc8,0x26d80e1a,0x776400a7,0xaa4801ec}},	//   _ग्या, utso_, върж, _ىستە_, 
   {{0x26d805f5,0x68fc38aa,0x236c003d,0x78880100}},	//   rtso_, årds, _ġej_, tèvè, 
   {{0x644df280,0x9f4c0270,0x236c01fa,0x00000000}},	//   tnai, _maeá_, _šej_, --, 
   {{0x644c166a,0x4900009d,0x60c400d7,0x00000000}},	//   unai, _зүүг, vrhm, --, 
   {{0xf485df3b,0x6594d2e8,0x78880100,0x63b400b8}},	// [38890] турн, _папу, sèvè, _āgnī, 
   {{0x644df281,0x3254023b,0xf6980ae5,0x41680063}},	//   snai, ввур, _ﻛﻮﻣﭙ, ојем_, 
   {{0x644c01ab,0x00000000,0x00000000,0x00000000}},	//   pnai, --, --, --, 
   {{0x2d8c7d4f,0x210008ad,0x20080428,0x63bc005c}},	//   _agde_, včić_, ñai_, _udsn, 
   {{0x629df282,0xe7e00a94,0x539802e4,0x786805c7}},	//   _utso, ग्या_, _מירו, uñvi, 
   {{0x9cf40556,0x00000000,0x00000000,0x00000000}},	//   ечиш, --, --, --, 
   {{0xc0c002d3,0x291800c5,0x6d3c0023,0xa6e400cc}},	//   _ትብሉ_, äral_, _ክንፈር, _ফছফট, 
   {{0x21001b24,0x2cac01a4,0x00000000,0x00000000}},	//   rčić_, _dwdd_, --, --, 
   {{0x1b14009e,0x00000000,0x00000000,0x00000000}},	//   _তেজে_, --, --, --, 
   {{0x6ec407f7,0x21002630,0x99d40244,0x00000000}},	//   _रितु, pčić_, رتخا, --, 
   {{0x18683181,0x89d40014,0x273c00d7,0x00000000}},	//   зани_, روَر_, yšnú_, --, 
   {{0xdb3406ed,0xfde400ec,0x00000000,0x00000000}},	//   _пеењ, _رکڻو_, --, --, 
   {{0x5bbc0073,0x8c1414af,0x00000000,0x00000000}},	//   ोलीव, _سيور_, --, --, 
   {{0x7a4400ef,0x00000000,0x00000000,0x00000000}},	//   _būtņ, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x98141b45,0xc0c00f7c,0xd1c0069d,0x00000000}},	//   _سببا, _ትብሎ_, ትዩት_, --, 
   {{0x4250036b,0x47c0005b,0xd2500271,0x00000000}},	// [388a0] گنلر, _сбыв, هنر_, --, 
   {{0x58fc2fb5,0x00000000,0x00000000,0x00000000}},	//   _ཟློས_, --, --, --, 
   {{0x1cc8081f,0xc0c0044e,0x1dc884b8,0x61400022}},	//   ིངས_, _ትብል_, _राजत, аҵра, 
   {{0x217428fc,0x80a00116,0x00000000,0x00000000}},	//   туур, چمەن, --, --, 
   {{0x5fd0069f,0x9f4c0093,0x2d8c00a3,0x00000000}},	//   _हारल, _paeá_, _pgde_, --, 
   {{0x80d811ba,0x00000000,0x00000000,0x00000000}},	//   ণিজ্, --, --, --, 
   {{0x0fe14d9b,0x00000000,0x00000000,0x00000000}},	//   _бөлү, --, --, --, 
   {{0x291833fe,0xcb8400d1,0x00000000,0x00000000}},	//   äram_, ىمغۇ_, --, --, 
   {{0x1ea802dd,0x00000000,0x00000000,0x00000000}},	//   _ياكي_, --, --, --, 
   {{0x2d99f283,0x00000000,0x00000000,0x00000000}},	//   _üre_, --, --, --, 
   {{0xba703004,0x39b405f5,0x61e0002f,0xdb0801e7}},	//   دايت, элээ_, _ölle, raeá, 
   {{0x2fc00597,0x00000000,0x00000000,0x00000000}},	//   óigh_, --, --, --, 
   {{0xead5f284,0xfaa058e2,0xe8f000ec,0xfb800354}},	//   _роль, _бачо, اڻڻ_, _йышн, 
   {{0x291805ac,0xe9800024,0x00000000,0x00000000}},	//   øras_, _калi_, --, --, 
   {{0x0cbc00cc,0x383400c7,0xa934004e,0x00000000}},	//   _আহুত, _әныр, _шекш, --, 
   {{0x442c0332,0x49901888,0x00000000,0x00000000}},	//   óg_, _جیگر, --, --, 
   {{0x42a4001f,0x8808010f,0x86240024,0xdee00092}},	// [388b0] _ጉብኝት_, ĝĝĥĥ, _зьне, ነቴን_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2184016c,0x69d80959,0x31c40171,0x00000000}},	//   ттаҳ, _मानी, dīzē_, --, 
   {{0x2b200316,0xd24c0014,0xd1c00092,0x00000000}},	//   यहाँ_, ٕچہ_, ትዩቱ_, --, 
   {{0x141810df,0x682c000f,0x0af00154,0x00000000}},	//   _חורב, _lûdo, জমুল_, --, 
   {{0xf77400c8,0x9d441555,0x9f0401b9,0x00000000}},	//   נקס_, келд, _یوزو, --, 
   {{0xf1c002f0,0xeda4d1b4,0x00000000,0x00000000}},	//   íšer_, ушчо, --, --, 
   {{0x1ae47696,0x00000000,0x00000000,0x00000000}},	//   воим, --, --, --, 
   {{0x200df285,0x00000000,0x00000000,0x00000000}},	//   _inei_, --, --, --, 
   {{0xfe240022,0xaae40b61,0x6440007f,0xef6402e8}},	//   _џьан, اسيو, èlij, _съсо, 
   {{0x7e61f286,0x2dd80597,0x200df287,0xd7c803e6}},	//   monp, _سبلة_, _knei_, ووده_, 
   {{0xea8800fb,0x00000000,0x00000000,0x00000000}},	//   мбөл_, --, --, --, 
   {{0x2919b76e,0xcc38010f,0x7e600254,0x00000000}},	//   ørar_, _קענט, oonp, --, 
   {{0xceb03d99,0x7e61f288,0x2c4c0316,0x00000000}},	//   שים_, nonp, vědi_, --, 
   {{0x200c0069,0xa90421ec,0x682c00d2,0x5fd001ad}},	//   _onei_, _مبين, _kûdl, _हांल, 
   {{0x73c40032,0xe7e0012c,0x7e60037e,0x23d400a8}},	//   ыҡма, ग्दा_, honp, лцур, 
   {{0x7e605f79,0xdd18025c,0xf36401d3,0x00000000}},	// [388c0] konp, _aħże, ائزی, --, 
   {{0x200dd562,0x7e61f289,0x00000000,0x00000000}},	//   _anei_, jonp, --, --, 
   {{0x200c039a,0x00000000,0x00000000,0x00000000}},	//   _bnei_, --, --, --, 
   {{0xc9500375,0x4f240209,0x0ee8117e,0xf3fc00cc}},	//   סמא_, кдеб, дьки_, _এককৰ_, 
   {{0xb8d0031c,0x200c0356,0x93580063,0x528400ae}},	//   _ཞས_, _dnei_, _црну_, _للحك, 
   {{0x200c0325,0x7e61f28a,0x00000000,0x00000000}},	//   _enei_, gonp, --, --, 
   {{0x31c400e2,0xa9b400d1,0xbd8400ec,0x00000000}},	//   rīzē_, ңйич, پنين_, --, 
   {{0x31bc0118,0x00000000,0x00000000,0x00000000}},	//   bází_, --, --, --, 
   {{0x8e84013d,0x8eb00131,0x05d01fd2,0x00000000}},	//   _агае, _ئەتت, _तालब, --, 
   {{0x7e61f28b,0x215400fd,0x8e84030d,0x00000000}},	//   conp, _çäçü, _шăпч, --, 
   {{0xc0b802d3,0xcc3400c7,0x3a70008e,0x70e00118}},	//   _ቲቶስ_, _ихды, рлэр, _नहोल, 
   {{0x0b443f6e,0x0c240395,0x00000000,0x00000000}},	//   _инен, _шмен, --, --, 
   {{0x228c0064,0x00000000,0x00000000,0x00000000}},	//   _ožka_, --, --, --, 
   {{0xa4d41ed2,0x26c414b2,0xe6d402d2,0x00000000}},	//   логі, člo_, _óvíð, --, 
   {{0xfa74025f,0x973001ed,0x046401c6,0xa2d41fd2}},	//   _שעות_, لکیا, втам, यून्, 
   {{0x7e6001e4,0x5fd004af,0xc7c401f4,0x00000000}},	//   zonp, _हाइल, _рски, --, 
   {{0x05100154,0x76600100,0x0cbc00fe,0x7e6002d0}},	// [388d0] সনের_, èzyè, _আহোত, yonp, 
   {{0xf2040c60,0x6ecc0073,0x31bc0118,0xa5f80798}},	//   ияхо, _समजु, vází_, _џену_, 
   {{0xb28400cf,0x7e6001f4,0xa3d40395,0x00000000}},	//   рытк, vonp, _йонч, --, 
   {{0x05d005d7,0x6fd40212,0x7e6002e2,0xf48400f2}},	//   _ताँब, иціє, wonp, _پاپی, 
   {{0x7e61f28c,0x00000000,0x00000000,0x00000000}},	//   tonp, --, --, --, 
   {{0x7e60037e,0x200c0042,0x00000000,0x00000000}},	//   uonp, _wnei_, --, --, 
   {{0x7e61f28d,0x200ddbdf,0x316800f3,0x00000000}},	//   ronp, _tnei_, _ашто_, --, 
   {{0x200df28e,0x7e61f28f,0x1bb800c6,0xfaa001ec}},	//   _unei_, sonp, رابع_, ңақо, 
   {{0xdea05c81,0x05d01098,0x7e61f290,0x48d000fe}},	//   _ایتی, _तांब, ponp, তবোৰ, 
   {{0x7e600455,0x2c4c013a,0x00000000,0x00000000}},	//   qonp, dědu_, --, --, 
   {{0x2ba425fe,0xed040050,0xd9440798,0x00000000}},	//   _ग्वा, _پونپ, уени, --, 
   {{0x94a8040b,0xb8e839de,0x4c980375,0x69d80356}},	//   ہارِ_, _लि_, _טבעו, _ecve, 
   {{0x142401d5,0xd7c8315b,0x8c1800d9,0x00000000}},	//   қдам, ووگه_, _רוני, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf485735c,0x69d80574,0x660000d0,0xf8b4000d}},	//   لاری, _माती, ôlka, _आबिय, 
   {{0x04402470,0x00000000,0x00000000,0x00000000}},	//   бесн, --, --, --, 
   {{0x1305f291,0x4fc4036b,0xb2440032,0x11e402dd}},	// [388e0] ызам, ҳсла, амаһ, лжам, 
   {{0x3f9c0418,0x00000000,0x00000000,0x00000000}},	//   _afuu_, --, --, --, 
   {{0xe7e001d9,0x3ebc0262,0x4fa407c6,0xc5f005d0}},	//   ग्वा_, _avut_, гиев, _הדת_, 
   {{0x68fc04ce,0xe6f4025c,0x1bf8033f,0x00000000}},	//   ærdi, _བརྩན_, ्यफल_, --, 
   {{0xc7d40302,0x81b0015b,0x0d9000d1,0x3ebc01ef}},	//   רוני_, _টার_, مگاھ, _cvut_, 
   {{0x6cd4282b,0x3f9c0270,0xccf815ed,0xc0d0001f}},	//   لقتا, _efuu_, ећи_, _ከሁሉ_, 
   {{0x8c64bba2,0xf8a400c6,0xcce5f292,0x997406be}},	//   лтид, _دة_, استي, _rəşt_, 
   {{0x5d100131,0xef940244,0x00000000,0x00000000}},	//   تېما, _ئیشد, --, --, 
   {{0x4dd414a5,0xdb0c0248,0x356c0092,0x00000000}},	//   _متاس, _èkìt, ሰሩበት_, --, 
   {{0xa2d413b4,0x2ba41d97,0x2fc401c7,0x96240055}},	//   यंत्, _ग्रा, _hdmg_, _jaņā, 
   {{0x7d900597,0x8d54241e,0xbe1000db,0x962400ef}},	//   _المؤ, _стач, _دولع, _maņā, 
   {{0x8154008f,0x00000000,0x00000000,0x00000000}},	//   רסטע_, --, --, --, 
   {{0xdee0044e,0x15780075,0xefcc2440,0x00000000}},	//   _ነተን_, ﻠﯩﺸﯩ, _ባንድ_, --, 
   {{0xe94468e7,0xc61004c5,0x6a7400cf,0xe3b000cc}},	//   _پرتی, হস্থ_, màfo, _ছাইব, 
   {{0x91b000cc,0x00000000,0x00000000,0x00000000}},	//   _চাংখ, --, --, --, 
   {{0x63540108,0x00000000,0x00000000,0x00000000}},	//   авбу, --, --, --, 
   {{0x649001e4,0x2bdc215d,0xded40b82,0x00000000}},	// [388f0] _aĥit, _याना, ከብን_, --, 
   {{0x6aa40240,0x00000000,0x00000000,0x00000000}},	//   _çifu, --, --, --, 
   {{0xc54801d9,0x61543fe2,0x00000000,0x00000000}},	//   _سجدٕ_, جنائ, --, --, 
   {{0x2ba41df0,0xb6580092,0x00000000,0x00000000}},	//   _ग्ला, _ወቅታዊ, --, --, 
   {{0x27e9e07a,0x621401d3,0x3e780022,0x335800cf}},	//   _mban_, _پہاڑ_, hête_, _бүтө_, 
   {{0x3e78000f,0x2d940395,0x5fd005c0,0x00000000}},	//   kête_, бръс, _हाकल, --, 
   {{0x27e9f293,0x63adf294,0x16d00950,0x80d00154}},	//   _oban_, oban, _तम्ब, _ধৈর্, 
   {{0x9c24016c,0x27e8208d,0xdd9001d3,0xefd015b7}},	//   рдид, _nban_, حوں_, _çöpü_, 
   {{0x63adf295,0x15782e56,0x9ed802d5,0x9b4401d3}},	//   iban, ﻠﯩﺴﯩ, _шмат_, شندو, 
   {{0x27e9f296,0x63adf297,0xad2401ec,0xdb0801e1}},	//   _aban_, hban, _گىمى, _òním, 
   {{0x63adf298,0x3804016c,0x5fb8033f,0xeda4004e}},	//   kban, бонҳ, _उजाल, _ышто, 
   {{0x7bc402d5,0x201c009f,0x2bdc0bca,0xad240131}},	//   ėjus, njwi_, _याया, _دىمى, 
   {{0xab29f299,0x00000000,0x00000000,0x00000000}},	//   _مسول_, --, --, --, 
   {{0x63adf29a,0x27e9f29b,0xeab003e6,0xb8e8015b}},	//   eban, _eban_, _رعه_, _রঙ_, 
   {{0x89d80302,0x63ac294f,0x23ac022e,0x948414d4}},	//   _יחסי, fban, _bоj_, ғыңд, 
   {{0x63adf29c,0x27e80241,0xd7080108,0x00000000}},	//   gban, _gban_, _ание_, --, 
   {{0x6aa5f29d,0x96740953,0x2918000d,0x00000000}},	// [38900] _çift, _выні, ärav_, --, 
   {{0x63adf29e,0x1544026a,0x73c401e0,0x55e400cf}},	//   aban, _веом, шәүе, _тооб, 
   {{0x63adf29f,0x1ae00011,0xdd18025c,0x00000000}},	//   bban, বিয়া, għża, --, 
   {{0x35dc367a,0x20c80451,0x00000000,0x00000000}},	//   _बाड़, ابلي_, --, --, 
   {{0x2bdc0490,0x644001f5,0xc0e40014,0x47980677}},	//   _याबा, ëlie, ُکہٕ_, דינס, 
   {{0xe6f4025c,0xbea400ec,0xbc6400f2,0xadd800d4}},	//   _བརྣན_, جهون_, یمون_, умку_, 
   {{0xdd980046,0x2ce80405,0x101401d9,0x217401c6}},	//   уші_, اظتی_, _پکاں_, _гутр, 
   {{0x69d80574,0x0c841945,0x6a7400cf,0x6d5c00c7}},	//   _माही, шылм, tàfo, _ÿram, 
   {{0x27e80263,0xbea1f2a0,0x35dc0cb4,0xabb4035b}},	//   _rban_, _матк, _बाढ़, аақә, 
   {{0x63adf2a1,0xc9840262,0xbae002d5,0x3e780129}},	//   zban, иуни, іцый, tête_, 
   {{0x63adf2a2,0x4ac00574,0x019400df,0x00000000}},	//   yban, _शिकव, יכיש_, --, 
   {{0x63adf2a3,0x3e7807ea,0xc6a4ed34,0x00000000}},	//   xban, rête_, ирги, --, 
   {{0x63adf2a4,0x660000d7,0x00000000,0x00000000}},	//   vban, ôlko, --, --, 
   {{0x59dc0254,0xdce0012d,0xe85410e8,0x00000000}},	//   _मायर, _wylą, _گنبد, --, 
   {{0x3a78008f,0xa8e4004b,0xf7b0110e,0xc7c400d8}},	//   _שטוד, _اړخي, _wẹẹb, _кспи, 
   {{0x27e9f2a5,0x81b0045e,0x63ac5a7a,0xe4a401d5}},	//   _uban_, _টাই_, uban, ирғо, 
   {{0x63acb77d,0x00000000,0x00000000,0x00000000}},	// [38910] rban, --, --, --, 
   {{0x63adf2a6,0x00000000,0x00000000,0x00000000}},	//   sban, --, --, --, 
   {{0x720401b9,0x61e401ab,0x5f94007b,0x326400d4}},	//   تولم, rfhl, ملائ, ітув, 
   {{0x63ac6edb,0x1fb829dc,0xcfa80150,0x00000000}},	//   qban, улды_, _ﺷﯩﺮﻗ, --, 
   {{0x644df2a7,0x00000000,0x00000000,0x00000000}},	//   miai, --, --, --, 
   {{0x644df2a8,0x3cf00401,0x00000000,0x00000000}},	//   liai, ंबले_, --, --, 
   {{0x30a41b88,0x6284dc95,0xefcc0023,0x00000000}},	//   _мртв, mmho, _ባዕዲ_, --, 
   {{0x644df2a9,0x6285f2aa,0x31cc015b,0x9f3410da}},	//   niai, lmho, র্দশ, _лебі, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x644df2ab,0x0b4062eb,0x6285f2ac,0xaf34009f}},	//   hiai, янын, nmho, _برفت, 
   {{0x69d90256,0x644df2ad,0x3cf00073,0xa3c80709}},	//   _मारी, kiai, ंबळे_, ैला_, 
   {{0x9b940597,0x628427cc,0x644c009f,0x00000000}},	//   _الإت, hmho, jiai, --, 
   {{0x7c39f2ae,0x644df2af,0x2bdc3fec,0x3894054e}},	//   mhur, diai, _याता, _mări_, 
   {{0xa87805f5,0x7c38522f,0x0f7800df,0x095000cf}},	//   лөөт_, lhur, טארב, تۉۉڭ, 
   {{0x644df2b0,0x18680131,0x443800b5,0x62841554}},	//   fiai, _йаки_, fhq_, dmho, 
   {{0x7c39f2b1,0x44380204,0x6285f2b2,0x59dc00e1}},	//   nhur, ghq_, emho, _माडर, 
   {{0x7c380009,0x13080024,0x00000000,0x00000000}},	// [38920] ihur, ынай_, --, --, 
   {{0x644c0618,0x00000000,0x00000000,0x00000000}},	//   aiai, --, --, --, 
   {{0x644df2b3,0xd009f2b4,0x7c39f2b5,0x1bf83507}},	//   biai, леже_, khur, ्याल_, 
   {{0x644df2b6,0x7c3801af,0x443803f0,0xcca400d1}},	//   ciai, jhur, chq_, ەنغۇ_, 
   {{0x628401ab,0x412401e0,0x5fb8000d,0x00000000}},	//   bmho, _һоро_, _उजरल, --, 
   {{0x509415ed,0x82a0074d,0x00000000,0x00000000}},	//   _грађ, _харж, --, --, 
   {{0x7c39f2b7,0xdc1000bd,0x8fa400c7,0x412400d8}},	//   fhur, িউনস_, _габе, _лоро_, 
   {{0xd1b80efb,0x38940356,0x768001f4,0xd24c0345}},	//   _جاڭا_, _gări_, löyd, _تۆڕ_, 
   {{0xcf243346,0x00000000,0x00000000,0x00000000}},	//   _ارزي, --, --, --, 
   {{0x7c3800b0,0x644df2b8,0x38940356,0xdde80ee8}},	//   ahur, ziai, _zări_, _نرمه_, 
   {{0x8d180014,0x7c387ab2,0x8c44368e,0x7c300005}},	//   _حٲضر_, bhur, _леже, ñerá, 
   {{0x644c021c,0x6fd803ce,0x00000000,0x00000000}},	//   xiai, डलिं, --, --, 
   {{0x644df2b9,0x7680e20c,0x6284015d,0x246000c0}},	//   viai, köyd, ymho, nėme_, 
   {{0x68fc037e,0x2918712c,0x167002dd,0x644c0142}},	//   ærds, äras_, мқыр, wiai, 
   {{0x644df2ba,0x59dc1361,0x03c4030d,0x2918007c}},	//   tiai, _मातर, йсам, årad_, 
   {{0x644c0421,0x24600024,0x490001c6,0xb1380092}},	//   uiai, kėme_, _дүүг, _በሚያሳ, 
   {{0x644df2bb,0x62840332,0x00000000,0x00000000}},	// [38930] riai, tmho, --, --, 
   {{0x644df2bc,0x4439f2bd,0x7c39f2be,0x38940311}},	//   siai, shq_, zhur, _sări_, 
   {{0x644df2bf,0x7c39f2c0,0x4438010a,0x628423bd}},	//   piai, yhur, phq_, rmho, 
   {{0x628408c2,0x7c380200,0x1f74011c,0x00000000}},	//   smho, xhur, олея, --, 
   {{0x9f05f2c1,0x645c0784,0x7c399999,0x246000c0}},	//   توشو, _ijsi, vhur, gėme_, 
   {{0x4ac00490,0x81e40154,0x2d9402e8,0x9e240e56}},	//   _शिजव, _মোর_, пръс, تىتو, 
   {{0xf1cc0150,0x00000000,0x00000000,0x00000000}},	//   _ﻗﯘﻧﺘ, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7c39f2c2,0xdb180036,0x7c400960,0x63b80034}},	//   rhur, _iewë, _ćurč, ówny, 
   {{0x5ce400c6,0x8a400133,0x00000000,0x00000000}},	//   _وكذل, وێنن, --, --, 
   {{0x9d54374c,0x7c39f2c3,0x261c04af,0x29540108}},	//   _بنات, phur, मानी_, зъяр, 
   {{0x186821f0,0xe50c0243,0x7c3803b9,0x00000000}},	//   рами_, हिनि_, qhur, --, 
   {{0x2918007c,0x00000000,0x00000000,0x00000000}},	//   ärar_, --, --, --, 
   {{0x7bd82878,0xdce000de,0x00000000,0x00000000}},	//   lguu, _uzlē, --, --, 
   {{0xd94400d1,0x958403de,0x00000000,0x00000000}},	//   _фейи, ілбе, --, --, 
   {{0x7bd9f2c4,0x00000000,0x00000000,0x00000000}},	//   nguu, --, --, --, 
   {{0x3a240585,0xf00405f5,0x645c002d,0x2bdc0574}},	// [38940] _konp_, үүги, _djsi, _यासा, 
   {{0x6aa40597,0x645df2c5,0x6b8401ab,0x00000000}},	//   _éife, _ejsi, _ùige, --, 
   {{0x10a46799,0x00000000,0x00000000,0x00000000}},	//   циен, --, --, --, 
   {{0x4f09f2c6,0x23e05345,0x7af801f2,0x10680276}},	//   инен_, _फायद, kwut, шией_, 
   {{0x7680023a,0x7bd80014,0x00000000,0x00000000}},	//   pöyd, dguu, --, --, 
   {{0x24600024,0x877800df,0x00000000,0x00000000}},	//   rėme_, באני, --, --, 
   {{0x7af80083,0x00000000,0x00000000,0x00000000}},	//   ewut, --, --, --, 
   {{0xdb180a40,0x7bd9f2c7,0x3e780129,0x0434010f}},	//   _gewë, gguu, rêta_, ַטיש_, 
   {{0x6a74004e,0x69c400db,0x00000000,0x00000000}},	//   làfi, пөйб, --, --, 
   {{0xf7ac01ec,0x2bdc07b7,0x00000000,0x00000000}},	//   _ﺳﯩﻤﺪ, _यावा, --, --, 
   {{0xc27800c8,0xdb18002e,0xfdf401ad,0xc198011a}},	//   שריי, _yewë, ंजरस_, ישיי, 
   {{0x27ec09a5,0x6e2801fa,0x8b69f2c8,0xd1c0001f}},	//   ýen_, _hodb, _киев_, _ስድብ_, 
   {{0xc0c82295,0xe7e000c5,0xdaa00ae5,0x65940064}},	//   _አዲስ_, ग्गा_, _كەيپ, загу, 
   {{0xeaf801f9,0xf98c0066,0x00000000,0x00000000}},	//   ्टीत_, عبی_, --, --, 
   {{0x6e29f2c9,0x622421ea,0x2aa000a3,0x25ac0115}},	//   _modb, ۋىرل, _hòb_, ĝel_, 
   {{0x6e29f2ca,0x2aa002bd,0xf8680137,0x25ac01e4}},	//   _lodb, _kòb_, _وموي_, ŝel_, 
   {{0x2aa0033b,0x6e28127b,0xa3cc033f,0x05080154}},	// [38950] _jòb_, _oodb, रणब_, রহের_, 
   {{0xdb18007f,0x26d9f2cb,0x6e28014f,0x27f803b2}},	//   _dewè, muso_, _nodb, lesn_, 
   {{0x31c405b0,0xdfd04706,0xd5f8011a,0x00000000}},	//   ьств, فيا_, _הפתר, --, 
   {{0xa2940845,0x2ee40208,0xf7f8010f,0x00000000}},	//   _намі, _bqmf_, ַזוך_, --, 
   {{0x6605f2cc,0x81e403f4,0x63bc0029,0x6e28863d}},	//   _kahk, _মোঃ_, _iesn, _bodb, 
   {{0x46d0069f,0xe6f40135,0x629c013c,0x6e280014}},	//   _तिनह, _བརླན_, _iuso, _codb, 
   {{0x629df2cd,0x6605f2ce,0x6294009a,0x26d9f2cf}},	//   _huso, _mahk, _iizo, huso_, 
   {{0x6605f2d0,0x26d9f2d1,0x62942a8f,0x60c402d3}},	//   _lahk, kuso_, _hizo, mshm, 
   {{0x6e28019b,0x6295f2d2,0x60c5f2d3,0x629df2d4}},	//   _fodb, _kizo, lshm, _juso, 
   {{0x63bdf2d5,0x26d9f2d6,0x6604b302,0x2aa001ab}},	//   _lesn, duso_, _nahk, _dòb_, 
   {{0x6295f2d7,0x629df2d8,0x60c402d3,0x6e4401b9}},	//   _mizo, _luso, nshm, _تنلم, 
   {{0x6295f2d9,0x629c07ab,0x26d9a9b4,0x63bdf2da}},	//   _lizo, _ouso, fuso_, _nesn, 
   {{0x6604a75d,0x1cc80dd4,0x26d801c8,0x60c40023}},	//   _bahk, ིངམ_, guso_, hshm, 
   {{0x6295f2db,0xd9456e01,0x60c5f2dc,0x644005e4}},	//   _nizo, _нели, kshm, ëlin, 
   {{0x60c4044e,0x63bdf2dd,0x629df2de,0xca340375}},	//   jshm, _besn, _auso, _מנסה_, 
   {{0x26d9f2df,0x629df2e0,0x629405b8,0x63bcada0}},	//   buso_, _buso, _aizo, _cesn, 
   {{0x6294651b,0xc0c80020,0x60c4044e,0x26d9f2e1}},	// [38960] _bizo, _አዲሱ_, eshm, cuso_, 
   {{0x38600385,0x629423db,0x629d4022,0x62643868}},	//   _hjir_, _cizo, _duso, والق, 
   {{0x6295f2e2,0xdb180066,0x7bc805a1,0x629c00d8}},	//   _dizo, _dewé, _odgu, _euso, 
   {{0x63bdf2e3,0x629c003a,0x6e28151c,0x6a7400cf}},	//   _gesn, _fuso, _sodb, ràfi, 
   {{0x629c0516,0x6295a517,0x82a00395,0x00000000}},	//   _guso, _fizo, _паяж, --, 
   {{0x765c083a,0x6295f2e4,0xdb1804e6,0x27f80099}},	//   nnry, _gizo, _gewé, zesn_, 
   {{0x63bc009a,0x32180af9,0x765c017a,0x3320003a}},	//   _yesn, _inry_, inry, lxix_, 
   {{0x629c0092,0x26d8f95d,0x7c980092,0xeff80240}},	//   _yuso, yuso_, ፈፃሚው_, ወድያ_, 
   {{0x77640564,0x629401f0,0x2a6c0212,0x6e28047e}},	//   _nxix, _yizo, todb_, _todb, 
   {{0x38600649,0x7f380302,0x26d9f2e5,0xa93401e0}},	//   _ajir_, _העמו, vuso_, деош, 
   {{0x26d802ce,0x2489f2e6,0x6604023a,0x2aa00100}},	//   wuso_, ymam_, _rahk, _wòb_, 
   {{0x6605f2e7,0x26d9f2e8,0x7d7800c8,0xc95807d6}},	//   _sahk, tuso_, _פראג, _қўл_, 
   {{0x63bc0f92,0x60c40240,0x2488007f,0x66041577}},	//   _resn, zshm, vmam_, _pahk, 
   {{0x26d9f2e9,0x27f81509,0x682c002d,0x60c5f2ea}},	//   ruso_, sesn_, _pûds, yshm, 
   {{0x6295f2eb,0x26d9f2ec,0x77641709,0x629df2ed}},	//   _rizo, suso_, _exix, _suso, 
   {{0x26d9f2ee,0x629df2ef,0x6295f2f0,0xdb080428}},	//   puso_, _puso, _sizo, maeò, 
   {{0x2489f2f1,0x63bc33dc,0x6605f2f2,0x76b800c7}},	// [38970] rmam_, _vesn, _tahk, _елыр_, 
   {{0x60c4044e,0x26c80421,0xaad41025,0x629deef9}},	//   tshm, _ivao_, _दिनक, _vuso, 
   {{0x63bcb515,0x0a4c02d3,0x248805d1,0xa3e43be5}},	//   _tesn, _ንእስራ, pmam_, _नाप_, 
   {{0x60c4044e,0x629c2252,0x3218011c,0x290c04cc}},	//   rshm, _tuso, _enry_, ivda_, 
   {{0x4429f2f3,0x60c5f2f4,0xdee4020f,0x6295f2f5}},	//   _ioc_, sshm, фоли, _tizo, 
   {{0x4429f2f6,0x69d80490,0x60c4036e,0xe3f801f7}},	//   _hoc_, _मागी, pshm, _اوڏڻ_, 
   {{0x31c40014,0x60c40240,0x4174215c,0x4429f2f7}},	//   _سۅنہ, qshm, _راسس, _koc_, 
   {{0x442927cf,0x26c80109,0x2cac004d,0xdaa82ff5}},	//   _joc_, _ovao_, _dtdd_, овид_, 
   {{0xe82013b4,0x442922d9,0xa3e42017,0x26c801f5}},	//   याना_, _moc_, _नान_, _nvao_, 
   {{0x4429f2f8,0x3da473ef,0x6d68041e,0x00000000}},	//   _loc_, _храб, árað, --, 
   {{0x4428067c,0x26c9f2f9,0xd944042f,0xaae45a9d}},	//   _ooc_, _avao_, фени, وسیو, 
   {{0x44283e91,0x00000000,0x00000000,0x00000000}},	//   _noc_, --, --, --, 
   {{0x9f4c0165,0x7c2803ac,0x3321f2fa,0x7d0401e1}},	//   _kaeñ_, _iogr, xxix_, bérá, 
   {{0x4429f2fb,0x7a3c4056,0xdc8001b9,0xcb10011a}},	//   _aoc_, _bête, _яққо, _שלג_, 
   {{0x4429f2fc,0x00000000,0x00000000,0x00000000}},	//   _boc_, --, --, --, 
   {{0x7764005a,0xba740244,0x7c29f2fd,0x00000000}},	//   _txix, _باڵت, _jogr, --, 
   {{0x44283c36,0x7c29f2fe,0xa2d444ab,0x16640114}},	// [38980] _doc_, _mogr, यंग्, _овим, 
   {{0x7c29f2ff,0x7a3c20ef,0x3b18002e,0x22400175}},	//   _logr, _fête, _àqqu_, ghhk_, 
   {{0x4429f300,0x26c80b91,0xc6900375,0x05600064}},	//   _foc_, _zvao_, _שאת_, _авэн, 
   {{0xfe6df301,0x4de808b0,0x7c29f302,0x4429f303}},	//   یدو_, ﺎﺗﯩﻨ, _nogr, _goc_, 
   {{0xbea1a804,0x6adc00e1,0x00000000,0x00000000}},	//   вачк, _ममेर, --, --, 
   {{0x0ca9f304,0x44280165,0x11d4007b,0xdce00205}},	//   отии_, _zoc_, _تتحد, _aglı, 
   {{0xa3e45edd,0xe820038e,0x81e40c58,0x442805c7}},	//   _नाम_, यामा_, _মোক_, _yoc_, 
   {{0x44280137,0x09c40574,0x7c2857f5,0xa2d4257b}},	//   _xoc_, लण्य, _cogr, यूक्, 
   {{0x7c29f305,0xcb44074d,0x00000000,0x00000000}},	//   _dogr, ьхки, --, --, 
   {{0x7c287a55,0x5ed400cc,0x00000000,0x00000000}},	//   _eogr, _ধনচে, --, --, 
   {{0x7c280363,0x261cb37b,0xf1c40150,0x00000000}},	//   _fogr, मासी_, _ﺨﺩﻤﺘ, --, 
   {{0x26c80004,0x7c280066,0x290d3513,0xdb080332}},	//   _pvao_, _gogr, rvda_, sbeá, 
   {{0x44281590,0x7a3c145e,0xd7b4013f,0x00000000}},	//   _roc_, _sête, _nkyε, --, 
   {{0x44289ff4,0xfcd000cf,0x7c29b280,0x00000000}},	//   _soc_, _سيۇج, _zogr, --, 
   {{0x4429f306,0x64419ff0,0xb9d8123b,0x00000000}},	//   _poc_, ūlim, _וחוש, --, 
   {{0x7a3c20ef,0x7c280005,0x1ad403d4,0x261c02a0}},	//   _vête, _xogr, _তৈয়া, माही_, 
   {{0x6adc0037,0x13a80066,0x00000000,0x00000000}},	// [38990] _ममोर, سنلی_, --, --, 
   {{0x7a3c07ea,0xa2940816,0x00000000,0x00000000}},	//   _tête, хазі, --, --, 
   {{0xf770034d,0x44281948,0x00000000,0x00000000}},	//   _مای_, _toc_, --, --, 
   {{0x4429f307,0xd6c4030f,0x69d8044b,0x00880116}},	//   _uoc_, _تمیی, _माझी, _ﺑﺎﺗﯘ, 
   {{0xd00c05d9,0x7c28d615,0x6ee548cd,0xb4440064}},	//   صلو_, _rogr, نسول, _рээк, 
   {{0xa3cc0d2c,0x7c29f308,0x1d080137,0x00000000}},	//   रणव_, _sogr, зеки_, --, 
   {{0xdfd434d8,0x237803cd,0xdce000e2,0x76800108}},	//   _повы, _hysj_, _izlī, köyn, 
   {{0xdde804fb,0xc5f803f9,0x249801d5,0x00000000}},	//   ترچه_, ɓɓen_, _jism_, --, 
   {{0xed5801a2,0x24980789,0x7c280427,0x78680205}},	//   _veľa_, _mism_, _vogr, nıve, 
   {{0x6b64025a,0xdd9406a6,0x00000000,0x00000000}},	//   _sïgï, _зазы, --, --, 
   {{0x61e000fc,0x7c29f309,0xe6f4025c,0x49c401c0}},	//   _öllu, _togr, _བརྔན_, элэн_, 
   {{0x24980219,0x7c5451ae,0xeff80023,0x786803e0}},	//   _nism_, _کلچر_, ወስዶ_, kıve, 
   {{0x6d640356,0x798401ec,0x69d801f9,0xda340024}},	//   ătaţ, _ﺭﺍﺩﻉ_, _माची, _педы, 
   {{0xceb1f30a,0xeff802d3,0x00000000,0x00000000}},	//   רים_, ወስደ_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x52a80801,0xe8200d2c,0x35dc05b3,0x00000000}},	//   звам_, याणा_, _बाक़, --, 
   {{0x969493c0,0x69dc068f,0x52840304,0x11d404f2}},	// [389a0] _прош, óreg, егаб, فتاد, 
   {{0x28a40724,0xca5000d1,0x04fc00cc,0x00000000}},	//   _яшәг, ﺎﻏﺎ_, _উপৰৰ_, --, 
   {{0x78a800a8,0x261c00e1,0x705404d3,0xc690010f}},	//   _învă, मारी_, نۆسا, _גאז_, 
   {{0x237803cd,0x2fc0007b,0xe0840472,0x00000000}},	//   _fysj_, úig_, نجني, --, 
   {{0x320400d1,0xa3000572,0x11d40212,0xe82000cd}},	//   _иҗаб, _күте, _півр, याता_, 
   {{0xd9d402f5,0xd17401af,0x00000000,0x00000000}},	//   ত্তম, _зыбы, --, --, 
   {{0xfaa00150,0x00000000,0x00000000,0x00000000}},	//   қшын, --, --, --, 
   {{0xbc446d66,0x6fa4012d,0x00000000,0x00000000}},	//   ечье_, _ओलिं, --, --, 
   {{0xfbcdf30b,0x81e400bd,0x6a74004e,0x0e6400d8}},	//   حتى_, _মোট_, dàfr, _зкан, 
   {{0xc3300302,0xdb18045f,0xbea0013d,0x00000000}},	//   טוח_, _bewâ, _сафк, --, 
   {{0x6440006a,0xdde807d6,0x6fa40073,0x47f0009d}},	//   ëlik, _ترقه_, _ओलां, гүйр, 
   {{0x80d05e58,0x4158008f,0xa3e4000d,0x78680205}},	//   _डिसे, לדיג, _नाध_, yıve, 
   {{0x261c9f23,0xd1f40023,0x00000000,0x00000000}},	//   माली_, ወንታ_, --, --, 
   {{0xb605f30c,0xe944036b,0x2c4c0118,0x00000000}},	//   ляск, _لربی, vědy_, --, 
   {{0xe820534e,0xa3e41fc4,0xfa7400d9,0x2498012d}},	//   यादा_, _नाद_, _רעות_, _pism_, 
   {{0x249801b9,0x47880063,0xb978011a,0x768001f4}},	//   _qism_, _нспм_, _מנוי, löyl, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [389b0] --, --, --, --, 
   {{0x78680205,0x3374022e,0x00000000,0x00000000}},	//   rıve, угур, --, --, 
   {{0x65940b7f,0xdb080158,0x6d5c01ef,0x00000000}},	//   _јану, mbeå, _žran, --, 
   {{0xdfd40105,0x76800108,0x00000000,0x00000000}},	//   тоды, höyl, --, --, 
   {{0xa2c40116,0x768008a9,0x80d0012d,0x00000000}},	//   _шәвк, köyl, _डिवे, --, 
   {{0xee39ed04,0x200802d5,0xdce000e2,0x26d80009}},	//   нні_, žai_, _uzlī, irso_, 
   {{0x25e80d54,0x1fc4014b,0x00000000,0x00000000}},	//   _जानी_, _арзҳ, --, --, 
   {{0x351c011a,0x00000000,0x00000000,0x00000000}},	//   לוונ, --, --, --, 
   {{0x0c200276,0xe7e400d1,0x89d40014,0x76800205}},	//   рмын, _ﺋﯚﺯﻟ, ھوَر_, föyl, 
   {{0x44380175,0x6f0403e0,0x00000000,0x00000000}},	//   hkq_, çice, --, --, 
   {{0x18680aa5,0x26d80381,0x3dc40100,0x23e00073}},	//   дани_, erso_, manw_, _फांद, 
   {{0x3dc40042,0x00000000,0x00000000,0x00000000}},	//   lanw_, --, --, --, 
   {{0xc0c0044e,0x7c383386,0x3f9c00ec,0xa3e400af}},	//   _ስእሊ_, mkur, _mguu_, नलन_, 
   {{0x3e7800d2,0x7a3c06af,0x00000000,0x00000000}},	//   fêti_, _fêta, --, --, 
   {{0xa3cc0b9c,0x3ae803a1,0xd944236a,0x26d80009}},	//   रणं_, løp_, _шеки, arso_, 
   {{0x3f9df30d,0x7d000113,0x00000000,0x00000000}},	//   _nguu_, iwns, --, --, 
   {{0x78a1f30e,0xd6280108,0x398801e1,0x00000000}},	// [389c0] _hunv, _жопе_, bósé_, --, 
   {{0x3f9c01f2,0x78a1f30f,0x7c39f310,0x3dc40100}},	//   _aguu_, _kunv, hkur, janw_, 
   {{0x7c393927,0xa5d800c8,0x3ebc7dec,0x66000254}},	//   kkur, _אַרי, _awut_, õlke, 
   {{0x53a40588,0x78a00a1d,0xef6401c0,0xa3cc00cd}},	//   _шамб, _munv, лэлү, रणः_, 
   {{0x3ae8168c,0x78a0030a,0xe1f06c68,0x00000000}},	//   jøp_, _lunv, شسە_, --, 
   {{0x3f9c022f,0x31cc00eb,0x00000000,0x00000000}},	//   _eguu_, র্জশ, --, --, 
   {{0x78a1f311,0x7c39f312,0x44440014,0x8c647c47}},	//   _nunv, fkur, _سرێہ, ктид, 
   {{0xf1d40184,0x46d02e1e,0x26d8003a,0x00000000}},	//   _шөғө, _तिलह, yrso_, --, 
   {{0x4e04026a,0x4478010f,0x4f080139,0x00000000}},	//   _изаб, ונקע, _юнан_, --, 
   {{0x656803ee,0x78a1f313,0x7c3800b0,0x8c4006be}},	//   şehi, _bunv, akur, _əğya, 
   {{0x78a13321,0x7c3800da,0x35dc0034,0x2fc40166}},	//   _cunv, bkur, _बाज़, _kemg_, 
   {{0xc1700302,0x7c39f314,0x78a131d2,0x23e0012c}},	//   יחת_, ckur, _dunv, _फाइद, 
   {{0xead4d010,0x2fc405b1,0xa5c402dd,0xed2801e2}},	//   _соль, _memg_, лөне, _زړګي_, 
   {{0x78a00083,0x80d001ad,0xe8200118,0x00000000}},	//   _funv, _डिले, याहा_, --, 
   {{0xa3d407d6,0xd5a4dc89,0x78a02a5b,0x00000000}},	//   ловч, الفی, _gunv, --, 
   {{0x0ed02c35,0x442c0174,0x00000000,0x00000000}},	//   _सिंड, ðg_, --, --, 
   {{0x3495f315,0x78a000ca,0x27e80098,0x6d5c02fb}},	// [389d0] ратр, _zunv, _ican_, _žral, 
   {{0x69c9f316,0xa3e405ba,0xe8200574,0x78a1f317}},	//   nade, _नाव_, यावा_, _yunv, 
   {{0x7c380986,0xe5349a41,0xf1a40209,0x3dc40100}},	//   ykur, _сень, ррун, vanw_, 
   {{0x27e80076,0x3dc40083,0x7c38007c,0x12b000cc}},	//   _jcan_, wanw_, xkur, _চিৰদ, 
   {{0x69c9a618,0x63adf318,0xde5800d4,0x2bf800cd}},	//   kade, mcan, наді_, ्जनं_, 
   {{0x69c9f319,0x5de49a41,0x9f5c020c,0xc0e80092}},	//   jade, ужка, newé_, _መጣር_, 
   {{0x69c874c3,0x7c39f31a,0x63ad4ebc,0x61e401e7}},	//   dade, tkur, ocan, mghl, 
   {{0x69c9f31b,0x27e8003e,0x7c380810,0x3dc404ba}},	//   eade, _ncan_, ukur, sanw_, 
   {{0xa0680efb,0x69c9f31c,0x200c03a0,0x78a1f31d}},	//   _жаңа_, fade, _iaei_, _sunv, 
   {{0x69c9f31e,0x27e83386,0x200c03a2,0x63ac0007}},	//   gade, _acan_, _haei_, hcan, 
   {{0x200df31f,0x63adf320,0x78a00477,0x61e5f321}},	//   _kaei_, kcan, _qunv, ighl, 
   {{0xb8c9f322,0x63ac0399,0xad2400d1,0x61e5f323}},	//   _कं_, jcan, _خىمى, hghl, 
   {{0x69c9f324,0x26c4e17f,0x61e401ee,0x78a00526}},	//   bade, ағын_, kghl, _wunv, 
   {{0x27e800ca,0x200c0b23,0x78a000cc,0x68ec01ed}},	//   _ecan_, _laei_, _tunv, öldö, 
   {{0xa3e439de,0xe8200a59,0xa9041095,0x63ac27ac}},	//   _नाश_, याशा_, _نبين, fcan, 
   {{0x94255a5c,0x200c0093,0x63ac0399,0xb4e4012d}},	//   ымбе, _naei_, gcan, _नमी_, 
   {{0xa3e400ab,0xe8200456,0x00000000,0x00000000}},	// [389e0] _नार_, यारा_, --, --, 
   {{0x63adf325,0x99d403d4,0x61e4032e,0x00000000}},	//   acan, ত্ৰক, gghl, --, 
   {{0x25e802a0,0x63ac0009,0x00000000,0x00000000}},	//   _जाती_, bcan, --, --, 
   {{0x63adf326,0x69c9f327,0x61e5f328,0x200c0142}},	//   ccan, zade, aghl, _caei_, 
   {{0x69c9f329,0xdb0c0248,0x00000000,0x00000000}},	//   yade, _òkèr, --, --, 
   {{0xd2503345,0x69c9f32a,0x99840006,0xbea4007b}},	//   _طنز_, xade, nklų_, دهون_, 
   {{0x9f4c0086,0x59dc05f9,0x8678010f,0xddc000c0}},	//   _ebeà_, _माजर, ערצו, _aklų, 
   {{0x69c9f32b,0xcbe42f23,0xdc8001d5,0x6d5c02d2}},	//   wade, уцки, оқхо, _þram, 
   {{0xfbcc3cda,0x4f6401ed,0xe0e400eb,0x00000000}},	//   ستي_, _صارف, নবৃন, --, 
   {{0x63ac0226,0x27e9184e,0x69c9f32c,0x00000000}},	//   zcan, _scan_, uade, --, 
   {{0x63ac11a9,0xe8202413,0x27e8005a,0xa3e415c0}},	//   ycan, याला_, _pcan_, _नाल_, 
   {{0x69c9f32d,0xe8c82b8d,0x7a3c0129,0x8ba411f7}},	//   sade, нгүл_, _fêto, _сидж, 
   {{0x69c9f32e,0x1ce0025c,0xb8c800c5,0x27e80076}},	//   pade, _ཧའོ_, _कू_, _vcan_, 
   {{0x63ac0007,0x69c9f32f,0xaa5800e5,0x00000000}},	//   wcan, qade, _جلتا_, --, 
   {{0x63adf330,0x6595f331,0xe7ec0316,0x046400ee}},	//   tcan, раву, _झापा_, гтам, 
   {{0x63adf332,0x2614000d,0x27e80205,0x00000000}},	//   ucan, _फोरी_, _ucan_, --, 
   {{0x855801e1,0x76800108,0x176800db,0x00000000}},	// [389f0] _dìtẹ, köyh, _үрөп_, --, 
   {{0x200df333,0xc0c80220,0x61e5f334,0xe8fc0327}},	//   _saei_, еуде_, ughl, _ྐྱོབ_, 
   {{0xdfd192b4,0x61e4016d,0x63adf335,0x1ce0025c}},	//   قيا_, rghl, pcan, _ཧའེ_, 
   {{0xa2dc08df,0x61e400ae,0x00000000,0x00000000}},	//   _पिप्, sghl, --, --, 
   {{0xddc5f336,0xe2982f16,0x6b8401ab,0x00000000}},	//   абли, _җаң_, _ùigh, --, 
   {{0xfafc0240,0xa3e402c3,0x00000000,0x00000000}},	//   çëm_, _नाँ_, --, --, 
   {{0x9d4464cf,0x200c0618,0x31340408,0xa158014b}},	//   рейд, _taei_, _лерр, _раву_, 
   {{0x3e780129,0x9f34346d,0x00000000,0x00000000}},	//   vêtu_, _кебі, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x94f4b444,0xa2dc5096,0xf2d4008f,0x00000000}},	//   _བྱའི_, _पिन्, זעץ_, --, 
   {{0xd824a752,0xb4d400af,0xa3e5f337,0xab2804b3}},	//   адни, _हटे_, नला_, _ەسىل_, 
   {{0xc0e80023,0x00000000,0x00000000,0x00000000}},	//   _መኣስ_, --, --, --, 
   {{0x98b42737,0xc5b40011,0x00000000,0x00000000}},	//   ıgım_, _জয়প, --, --, 
   {{0x261c228d,0x79a40798,0x00000000,0x00000000}},	//   मागी_, _срде, --, --, 
   {{0x43b001f2,0xf484397d,0x99840064,0x00000000}},	//   _ụrụ_, ماری, rklų_, --, 
   {{0x03a0f3e5,0xdb0c0248,0x00000000,0x00000000}},	//   жито, _àkós, --, --, 
   {{0x3e780129,0x662000e4,0x00000000,0x00000000}},	// [38a00] nêts_, ñykã, --, --, 
   {{0x422044b5,0xb9381ef7,0x00000000,0x00000000}},	//   одув, _ይመስሎ, --, --, 
   {{0x4fc5f338,0xd094801b,0x96d40022,0xed5800d7}},	//   асла, ашды, _ссқә, _veľk_, 
   {{0x765df339,0x2570313e,0x6440e7cc,0x008060a9}},	//   liry, _رۇقس, ëlit, олхо, 
   {{0x2f880032,0x1ce00327,0x61f801e7,0x76800108}},	//   уҙан_, _ཧའུ_, íblí, töyh, 
   {{0x765df33a,0x4df4054a,0xcdf401c6,0x3e840395}},	//   niry, рядт, рчды, айчо_, 
   {{0xb4e4bc82,0xc11400dd,0x4124452c,0xdce00006}},	//   _नमो_, _پہنچ_, _коро_, _mylė, 
   {{0x70440132,0x00000000,0x00000000,0x00000000}},	//   _ارسە, --, --, --, 
   {{0xd5c434a5,0xab38023a,0xef9401b9,0x753c02d0}},	//   वराज, уппу_, _ایشد, hyrz, 
   {{0x8d5801ee,0x00000000,0x00000000,0x00000000}},	//   _ишет_, --, --, --, 
   {{0x765df33b,0x02140375,0x9e940451,0x00000000}},	//   diry, בחים_, _اهلڪ, --, 
   {{0xdb18092e,0xdb0800cf,0xa3e400c5,0xc60c041c}},	//   _bewä, cceï, _नाइ_, ाय्य_, 
   {{0x0a6800ee,0x2918008f,0x478468dc,0x7c0400ae}},	//   _ирки_, ŭra_, рынб, _ضيوف_, 
   {{0x765c0a49,0x7aec004e,0xe6889805,0xe4e401c6}},	//   giry, àcte, انسى_, йсбү, 
   {{0x98580882,0xdb180036,0x03c41d5b,0x6934084c}},	//   ṇām_, _eewä, исам, _ынку, 
   {{0x765c0076,0xe5a435e3,0x34489607,0x779400e5}},	//   airy, риңи, ачун_, _ڈیپا, 
   {{0x765df33c,0xdb180639,0x49906112,0x86e401b9}},	// [38a10] biry, _gewä, _دیگر, _тўйд, 
   {{0x20dc08a5,0x765c010e,0x673c010e,0x00000000}},	//   _náið_, ciry, mysj, --, 
   {{0x2458170a,0x6441f33d,0x673c045f,0x5ff4009d}},	//   _бань_, ëlis, lysj, йзжу, 
   {{0x5f942dbf,0xf18401ec,0x00000000,0x00000000}},	//   биет, _ﺩﺍﺌﻡ_, --, --, 
   {{0x93f80302,0x673c045f,0x09dc0eac,0x00000000}},	//   _גלרי, nysj, ব্যা, --, 
   {{0xdca40364,0x9d446518,0x00000000,0x00000000}},	//   баки, йелд, --, --, 
   {{0xdea007d6,0x20dc08a5,0xc0f40092,0x00000000}},	//   _کیتی, _dáið_, ወቅም_, --, 
   {{0x765dc69c,0x44d00210,0x69dc950c,0xa2800345}},	//   ziry, ić_, óren, _بیڕو, 
   {{0x765c94a7,0xa3e402e5,0x4b2006a6,0x753c033f}},	//   yiry, _नाई_, змыв, zyrz, 
   {{0x3e784aee,0x673c0b21,0x79e400dd,0x00000000}},	//   rêts_, dysj, جودہ_, --, 
   {{0x1ce0025c,0xdd1402f2,0xbc48010b,0x00000000}},	//   _ཧའི_, _دواخ, _ичде_, --, 
   {{0x7c840733,0x673c000f,0x2240003e,0x765df33e}},	//   _тузе, fysj, hkhk_, wiry, 
   {{0x44d0068f,0xac740597,0xaad4038e,0x765df33f}},	//   eć_, _بالش, _दिएक, tiry, 
   {{0x09dc02a6,0xa3e405d7,0x765c0076,0x00000000}},	//   ব্বা, _नाउ_, uiry, --, 
   {{0x765df340,0x25e822e3,0xf8d800e1,0xdce000c0}},	//   riry, _जारी_, _मटिय, _vylė, 
   {{0x673df341,0x765df342,0x00000000,0x00000000}},	//   bysj, siry, --, --, 
   {{0xa2dc3f55,0x765df343,0x44d00034,0xdce00153}},	// [38a20] _पिण्, piry, ać_, _tylė, 
   {{0x765c3cf6,0x6aa401c3,0x00000000,0x00000000}},	//   qiry, _èife, --, --, 
   {{0x0ce1f344,0x656803e0,0x00000000,0x00000000}},	//   _মন্ত, şehr, --, --, 
   {{0x4ea41fbe,0x00000000,0x00000000,0x00000000}},	//   брка, --, --, --, 
   {{0x2dc9f345,0x261c0490,0xdb9000d1,0x2a3c0023}},	//   иқан_, माची_, ﻟﯩﺮﻯ_, _ይገብሮ, 
   {{0xa2dc06ff,0x847402d3,0xdb0c0241,0x00000000}},	//   _पित्, _ረብሓን_, _ìjùg, --, 
   {{0xd1304739,0x613c0174,0xc0e15d37,0x00000000}},	//   _عمر_, _vælú, _норк, --, 
   {{0x2ec4010b,0xce480116,0x673c01f4,0x8fd001ee}},	//   _дөкм, _өзбе_, yysj, _хәжә, 
   {{0x25e81715,0x20dc022c,0xd90c04d3,0xa03000db}},	//   _जाली_, _táið_, ێیه_, _تۉنت, 
   {{0xdb08004e,0xb3e4012c,0x673c002d,0x00000000}},	//   cceí, गलुङ_, vysj, --, 
   {{0xc92402a6,0x28f802bf,0xdb0800e4,0x2d980241}},	//   মন্ত_, шень_, mbeý, _àre_, 
   {{0x673df346,0xc198010f,0x81880150,0x00000000}},	//   tysj, טשיי, _ﺒﺭﻴﺔ_, --, 
   {{0xf1a801ad,0x00000000,0x00000000,0x00000000}},	//   कखान, --, --, --, 
   {{0x25a495b0,0x27ec0003,0xdb0800a2,0x00000000}},	//   øll_, żen_, nbeý, --, 
   {{0x673c0a85,0xe5980212,0x87e40395,0xeb3400f1}},	//   sysj, ркві_, _люпе, _درڅخ, 
   {{0x7cec067c,0x2d8c0419,0x44d00210,0x00000000}},	//   _hòrç, _mzde_, rć_, --, 
   {{0xf7f5f347,0x44d00210,0x00000000,0x00000000}},	// [38a30] _رسيد, sć_, --, --, 
   {{0xa3e44d53,0xe8201d24,0x2d8c06be,0x225801f4}},	//   _नाक_, याका_, _ozde_, шизы_, 
   {{0xdb180b21,0x3f640cef,0x31c402d5,0x00000000}},	//   _bewû, әтеб, яств, --, 
   {{0x2419f348,0x84c000fb,0xf8b0010f,0x6614012d}},	//   _томы_, _мәғд, לשע_, ldzk, 
   {{0x644c3c76,0xa2940064,0x00000000,0x00000000}},	//   mhai, _мамі, --, --, 
   {{0x291c04cc,0x6614012d,0x3e680108,0x4e14000d}},	//   _orva_, ndzk, ышен_, _धोआई_, 
   {{0x644c166a,0x80d00401,0x6284031c,0xc0e80092}},	//   ohai, _डिटे, mlho, _መባሉ_, 
   {{0x6285e174,0x69d9f349,0x644df34a,0x4c900640}},	//   llho, _adve, nhai, мијс, 
   {{0x291df34b,0x628405e4,0x644c0109,0x24600024}},	//   _arva_, olho, ihai, lėms_, 
   {{0x644df34c,0xdd940022,0x2dd4084c,0x1a380798}},	//   hhai, _дазы, _нжур, рџиќ_, 
   {{0x644df34d,0x246002d5,0x291c0558,0x19885894}},	//   khai, nėms_, _crva_, рбни_, 
   {{0xa3e41025,0xbc640014,0x6284002f,0x00000000}},	//   _नाग_, _دۅبن_, hlho, --, 
   {{0x644df34e,0x7cec9b4c,0x7bc800da,0x291df34f}},	//   dhai, _fòrç, _iegu, _erva_, 
   {{0xd945f350,0x7bc9f351,0xceb0008f,0x6284013f}},	//   _мели, _hegu, ויך_, jlho, 
   {{0x7bc92a3a,0x644df352,0x62854719,0x2608012d}},	//   _kegu, fhai, dlho, ाज़ी_, 
   {{0x644c3c76,0x6285f353,0x76a00570,0x7bc8035b}},	//   ghai, elho, _báyì, _jegu, 
   {{0x7bc8105c,0xa7940084,0x11d400cf,0x4dc8015b}},	// [38a40] _megu, _nṱha, قتاد, _রাসূ, 
   {{0x7a3c004a,0x78a4023a,0x644c00e4,0xc0e80092}},	//   _bêti, _hiiv, ahai, _መጣሁ_, 
   {{0x644df354,0x53a416c3,0x7bc80280,0x78a4b6a5}},	//   bhai, _манб, _oegu, _kiiv, 
   {{0x644df355,0x79803689,0x78a400b8,0x16200b27}},	//   chai, _mynw, _jiiv, माकर_, 
   {{0x2f182db3,0x79800421,0x6284009a,0xda082274}},	//   соль_, _lynw, blho, _वसंत_, 
   {{0x78a5f356,0xd1740220,0x7bc800c5,0x24600153}},	//   _liiv, _дыбы, _aegu, bėms_, 
   {{0x7bc9f357,0x69dc033f,0x00000000,0x00000000}},	//   _begu, órem, --, --, 
   {{0x7bc9f358,0x78a56ea7,0x09e01fbc,0x425000db}},	//   _cegu, _niiv, पल्य, _ىچەر, 
   {{0x7bc8642b,0x798002d0,0xe1880023,0x0b88010a}},	//   _degu, _aynw, _ዝሳቐዩ_, шски_, 
   {{0xbf100a2c,0xc9841638,0x7980002d,0x7bc9f359}},	//   _زومب, жуми, _bynw, _eegu, 
   {{0x644cc5e5,0x7bc9f35a,0x7980015d,0xed5800d7}},	//   yhai, _fegu, _cynw, _peľu_, 
   {{0x644c0457,0x7bc9f35b,0x79800042,0xdb1801e1}},	//   xhai, _gegu, _dynw, _lewù, 
   {{0x2cac0221,0x78a5f35c,0x644c004c,0xc6a51ee7}},	//   _hudd_, _diiv, vhai, юрни, 
   {{0x644df35d,0x7bc9f35e,0xba1400aa,0x69d9f35f}},	//   whai, _zegu, _وينا_, _udve, 
   {{0x644c23a7,0x2cadf360,0x7bc9f361,0x7980015d}},	//   thai, _judd_, _yegu, _gynw, 
   {{0xe0182413,0x68e9f362,0x2cac002e,0x43740184}},	//   _नोंद_, mudd, _mudd_, ҡуҡт, 
   {{0x6285f363,0x68e9f364,0x644df365,0x2cac771b}},	// [38a50] tlho, ludd, rhai, _ludd_, 
   {{0x6594713a,0x24600006,0x00000000,0x00000000}},	//   _напу, tėms_, --, --, 
   {{0x644c4464,0xdb080491,0x68e9f366,0xf0e8005e}},	//   phai, iceá, nudd, قىلى_, 
   {{0x26c85ff2,0x78a405c7,0x24600024,0x7a3c0129}},	//   _kwao_, _xiiv, rėms_, _vêti, 
   {{0x7bc9f367,0x645df368,0x68e9f369,0x7680023a}},	//   _regu, _imsi, hudd, pöyt, 
   {{0x68e9f36a,0x2cadf36b,0x26c80451,0x645c01ab}},	//   kudd, _budd_, _mwao_, _hmsi, 
   {{0x7bc9f36c,0x68e80a49,0x2cac03cb,0xa19401c6}},	//   _pegu, judd, _cudd_, _хавч, 
   {{0x68e9f36d,0x2cac0036,0xdfd0007b,0x00000000}},	//   dudd, _dudd_, _سيئ_, --, 
   {{0x7bc9f36e,0x78a425c6,0x7980015d,0x00000000}},	//   _vegu, _riiv, _synw, --, 
   {{0x2cac457a,0x68e80a49,0x78a5f36f,0x7bc9f370}},	//   _fudd_, fudd, _siiv, _wegu, 
   {{0x2cac04d1,0x7bc9f371,0x645df372,0x68e9f373}},	//   _gudd_, _tegu, _omsi, gudd, 
   {{0x18687724,0xb90023ef,0x7680007c,0xd71c0092}},	//   сами_, _फट_, jöyr, _ስላልነ, 
   {{0x78a5f374,0x7980002d,0xe82000e1,0xa3c000af}},	//   _viiv, _wynw, याजा_, ुरन_, 
   {{0x68e9f375,0x645df376,0x6d640086,0x798000ad}},	//   budd, _amsi, _ôwañ, _tynw, 
   {{0x26c80295,0x78a416b5,0x68e9f377,0xda6400ec}},	//   _ewao_, _tiiv, cudd, _واڻي, 
   {{0xa2dc01ad,0x768001f4,0x00000000,0x00000000}},	//   _पिश्, töys, --, --, 
   {{0x26c8007f,0x00000000,0x00000000,0x00000000}},	// [38a60] _gwao_, --, --, --, 
   {{0x645cd689,0x3a240334,0xd1940063,0x91940114}},	//   _emsi, _jnnp_, пшењ, пјеш, 
   {{0xe82005ba,0xa3e405dc,0x26c81682,0x10a4084c}},	//   याचा_, _नाच_, _zwao_, чиен, 
   {{0x236c0010,0x2cac045a,0x00000000,0x00000000}},	//   _žeje_, _rudd_, --, --, 
   {{0x68e9f378,0x2cadf379,0x638001f0,0xc3200153}},	//   zudd, _sudd_, _аҳта, _змяк, 
   {{0x7ee023f6,0x52742afd,0x00000000,0x00000000}},	//   ركىن, _хуму, --, --, 
   {{0xe7ec05ba,0x645c0174,0x20b8005b,0x68e87caa}},	//   _झाला_, _ymsi, _мыть_, xudd, 
   {{0x68e82252,0x3dc00209,0x00000000,0x00000000}},	//   vudd, _үйтг, --, --, 
   {{0x2cac002e,0x68e95e47,0x290c0327,0x00000000}},	//   _wudd_, wudd, wwda_, --, 
   {{0x2cac1574,0x68e80a49,0xbf1004a9,0x00000000}},	//   _tudd_, tudd, _чүшә, --, 
   {{0x6e29f37a,0xdb08007b,0x8c9401ec,0xa3c016ae}},	//   _indb, rceá, _ерді, ुरम_, 
   {{0x68e99d26,0xdb08007b,0xa2dc0a8a,0x6fcc00dc}},	//   rudd, sceá, _पिल्, ारिं, 
   {{0x68e9f37b,0x36d488d6,0xfaf5f37c,0x4c9400c7}},	//   sudd, нояр, _فروغ_, _диҧс, 
   {{0xe81c05dc,0xda6405d9,0x645c00c5,0x65941ae2}},	//   _बोरा_, _ٺاهي, _smsi, дагу, 
   {{0xfa31f37d,0x6fcc0574,0xa4d40212,0x79f8011a}},	//   _سرود, ारां, ьові, _הלוח, 
   {{0x045400db,0x00000000,0x00000000,0x00000000}},	//   سئزد, --, --, --, 
   {{0x26c8166a,0x4a080327,0x6e28127b,0x00000000}},	// [38a70] _uwao_, _ཀྲོལ_, _ondb, --, 
   {{0xc87c0112,0x09dc00eb,0x00000000,0x00000000}},	//   loß_, ব্রা, --, --, 
   {{0xb19400d1,0x21840107,0xe45400db,0x15f8b8b4}},	//   еһрә, фтаҳ, _жкны, _והתע, 
   {{0x645df37e,0x6e29f37f,0x00000000,0x00000000}},	//   _umsi, _andb, --, --, 
   {{0x2fc0307d,0x44f4004e,0x2488d8fb,0x00000000}},	//   ñiga_, lç_, mlam_, --, 
   {{0xc87c0e78,0x786801d3,0xf774008f,0xef7400f2}},	//   hoß_, műve, עקס_, ردنظ, 
   {{0x44f5f380,0x2489f381,0xffe4487f,0xefe80092}},	//   nç_, olam_, _нюан, _መጓዝ_, 
   {{0xe81c3e63,0x6e29bed9,0x2489f382,0x44f40205}},	//   _बोला_, _endb, nlam_, iç_, 
   {{0x3da401e0,0xa3d400e1,0x24880381,0xcd240171}},	//   _ереб, _सजन_, ilam_, _ķēžu_, 
   {{0x2489abb9,0xd945f383,0x19a800f7,0x25e810f4}},	//   hlam_, деои, өтүп_, _जागी_, 
   {{0x7e61f384,0xdde8004b,0x3a240051,0xfd44004e}},	//   minp, _هرڅه_, _vnnp_, _ээан, 
   {{0x7e61f385,0xfafc036e,0x00000000,0x00000000}},	//   linp, çës_, --, --, 
   {{0x3804013e,0x7b640209,0x2488982e,0xcfb800cc}},	//   _ҷойҳ, _этже, dlam_, ুলচন, 
   {{0x7e61f386,0x248972f7,0xdb200407,0x6f040c3c}},	//   ninp, elam_, _ñuño, çici, 
   {{0x24881529,0x98700122,0x672801e4,0xe9a80345}},	//   flam_, láč_, ĥeja, _عدون_, 
   {{0x2489f387,0x7e608408,0x6294022e,0x78b0005f}},	//   glam_, hinp, _ahzo, ēgvā, 
   {{0x7e600986,0x9695f388,0x987002fb,0x3860007b}},	// [38a80] kinp, _орош, náč_, _imir_, 
   {{0x2489f389,0x7e606df9,0x7a3c0129,0x00000000}},	//   alam_, jinp, _têtu, --, 
   {{0x958402dd,0x6e280175,0xe8e0004d,0x98700306}},	//   _ілме, _rndb, _trụy_, háč_, 
   {{0x2489f38a,0x987002fb,0x00000000,0x00000000}},	//   clam_, káč_, --, --, 
   {{0x7e6002d0,0x00000000,0x00000000,0x00000000}},	//   finp, --, --, --, 
   {{0x7e61f38b,0x0d2004a9,0xb03400f1,0xc754010f}},	//   ginp, күзү, _ګورګ, וינץ_, 
   {{0x32180109,0x7a3c002d,0x9b500023,0x00000000}},	//   _iary_, _lêts, _ክቆጻጸ, --, 
   {{0x3219f38c,0xc5f802a8,0xd1b800db,0x99880205}},	//   _hary_, ɓɓun_, _داڭا_, _şaş_, 
   {{0xa3c0007d,0x3f644cc1,0x3219f38d,0xa9e40131}},	//   ुरत_, _жито_, _kary_, ۈزگۈ, 
   {{0x3860035c,0x693400a8,0x6fcc00af,0x248815c0}},	//   _amir_, еноу, ारवं, zlam_, 
   {{0xc87c03fa,0x32180c30,0x0ae800ec,0x2489f38e}},	//   toß_, _mary_, _ڀرتي_, ylam_, 
   {{0x32180432,0x987002f0,0x394001bf,0x0b4401ee}},	//   _lary_, báč_, øjsa_, _онен, 
   {{0x38600135,0x32180109,0x24897642,0x2a6c01ab}},	//   _dmir_, _oary_, vlam_, pndb_, 
   {{0x3861f38f,0x3219f390,0xfd54002b,0x2b5003e0}},	//   _emir_, _nary_, _avaṣ, ılcı_, 
   {{0x2489f391,0x44f45b33,0xae00190e,0x758803cf}},	//   tlam_, uç_, ल्यन_, дств_, 
   {{0x32180109,0x44f5f392,0x248802e2,0x7e60002f}},	//   _aary_, rç_, ulam_, zinp, 
   {{0x32183254,0x2489f393,0x7e61f394,0x1618000d}},	// [38a90] _bary_, rlam_, yinp, _फोकर_, 
   {{0x3219f395,0x2489f396,0x7a3c06af,0x0188023a}},	//   _cary_, slam_, _hêtr, ощей_, 
   {{0x24880365,0x321805d6,0x7e60005b,0xa3d54253}},	//   plam_, _dary_, vinp, _понч, 
   {{0x32180076,0x7e600784,0x26d80327,0x00000000}},	//   _eary_, winp, osso_, --, 
   {{0xdee4085a,0x7e61f397,0x4429f398,0x321871d3}},	//   холи, tinp, _inc_, _fary_, 
   {{0xee382626,0x98700f91,0xef180006,0x44280051}},	//   мні_, váč_, ьмі_, _hnc_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7e617f14,0x3219f399,0x44295e86,0xa3c05b82}},	//   sinp, _zary_, _jnc_, ुरि_, 
   {{0x7e61f39a,0x2ef406bb,0x4429f39b,0x6f8801d9}},	//   pinp, _изтр, _mnc_, _ہنہِ_, 
   {{0x4428089c,0x7e602b34,0x3ebdf39c,0x6e940022}},	//   _lnc_, qinp, _itut_, _аиуу, 
   {{0xa3c0228d,0x4428022f,0x26d80198,0x00000000}},	//   ुरा_, _onc_, esso_, --, 
   {{0x44280004,0x98700306,0x97c4010b,0x00000000}},	//   _nnc_, páč_, эйме, --, 
   {{0x7c28302f,0xdb080112,0x00000000,0x00000000}},	//   _ingr, ebeö, --, --, 
   {{0x4429f39d,0x95841dc8,0x7af8208d,0xf4844c0e}},	//   _anc_, елге, mtut, چاری, 
   {{0x26d8011c,0x321805da,0x23b4063f,0xbb500131}},	//   asso_, _rary_, _ụja_, _سۆھب, 
   {{0x3219f39e,0x386002d1,0x236c0010,0xd6f8030d}},	//   _sary_, _umir_, _žeja_, _ехош_, 
   {{0xae0051a5,0x3219f39f,0x287401af,0x00000000}},	// [38aa0] ल्डन_, _pary_, _шышр, --, 
   {{0x4429f3a0,0x7af9f3a1,0xd7c86071,0xb9f8001f}},	//   _enc_, itut, _بوکه_, _ሆን_, 
   {{0x3ebdf3a2,0x7c29f3a3,0x44280022,0x7af800af}},	//   _atut_, _ongr, _fnc_, htut, 
   {{0x3219f3a4,0x44280407,0x7af81f53,0x101403af}},	//   _wary_, _gnc_, ktut, عباد, 
   {{0x3218dd8b,0xc7d4011a,0xf38401af,0x00000000}},	//   _tary_, תוני_, _рғам, --, 
   {{0x7c29016d,0xbea056b6,0x9e70167e,0x98a40153}},	//   _angr, гачк, لۇقت, pylė_, 
   {{0x7c280109,0xdcb00051,0x33200327,0xb14800f2}},	//   _bngr, _củ_, lvix_, _تیام_, 
   {{0x7af9f3a5,0x26d8003a,0x2b440076,0x00000000}},	//   ftut, ysso_, tymc_, --, 
   {{0x7af87de9,0xdb180730,0x00000000,0x00000000}},	//   gtut, _gewü, --, --, 
   {{0x7c29f3a6,0x3a700166,0x00000000,0x00000000}},	//   _engr, ллыр, --, --, 
   {{0x7af82e52,0xfce00354,0x00000000,0x00000000}},	//   atut, _бохо, --, --, 
   {{0xc1700375,0x00000000,0x00000000,0x00000000}},	//   טחת_, --, --, --, 
   {{0x442800ca,0x7af9f3a7,0xda1443fb,0x3ebc0135}},	//   _rnc_, ctut, رسیک, _xtut_, 
   {{0x4429f3a8,0xe7ec28fe,0x00000000,0x00000000}},	//   _snc_, _झाका_, --, --, 
   {{0x25a404f3,0x4428e844,0x6d59f3a9,0x69c80076}},	//   äll_, _pnc_, nzva, mbde, 
   {{0x6d59f3aa,0x4428cc2e,0x69c80175,0x00000000}},	//   izva, _qnc_, lbde, --, 
   {{0xc6a467b5,0xf6502b9f,0x00000000,0x00000000}},	// [38ab0] _прои, _گئي_, --, --, 
   {{0x3ebc0194,0x68e80d27,0x6d580122,0x341c0882}},	//   _rtut_, ordd, kzva, ātaḥ_, 
   {{0x4429f3ab,0x7af801c0,0xf1256476,0xa2dc47b8}},	//   _tnc_, ztut, льцо, _पिक्, 
   {{0x6d58006f,0x7af9f3ac,0x00000000,0x00000000}},	//   dzva, ytut, --, --, 
   {{0xdb180100,0xd00c06c5,0x7af8037e,0x41e40153}},	//   _lewò, زلو_, xtut, _піва, 
   {{0x3ebc0393,0xdb0c01e1,0x1d0801f4,0x00000000}},	//   _vtut_, _àkés, деки_, --, 
   {{0x92a4006d,0xdd90066d,0x93c4084c,0xa3d40034}},	//   _dołą, گوں_, sfăş, _सजा_, 
   {{0x7af9f3ad,0x810800aa,0xad241afc,0x00000000}},	//   ttut, _ورځې_, اروو, --, 
   {{0xdd90066d,0xa3b809ab,0x7af9f3ae,0x6d580810}},	//   دوں_, _चलन_, utut, azva, 
   {{0x7af9f3af,0xdb18007f,0xdcb00208,0xae141f0d}},	//   rtut, _bewò, _tủ_, _مذمت, 
   {{0x7af9156e,0x6d5800ef,0x00000000,0x00000000}},	//   stut, czva, --, --, 
   {{0x201df3b0,0x7c29f3b1,0xdb18007f,0x69c8208d}},	//   ndwi_, _ungr, _dewò, abde, 
   {{0x7af80357,0x15b800f7,0xa2dc01ad,0x00000000}},	//   qtut, дыбы_, _पिग्, --, 
   {{0x63bc02a5,0xdb180100,0x421800dc,0x00000000}},	//   _afsn, _fewò, नयोः_, --, 
   {{0xe81c690c,0x6604009d,0x00000000,0x00000000}},	//   _बोका_, _dbhk, --, --, 
   {{0xc950025f,0x15ec0034,0x9f4c00cf,0xc3080154}},	//   _כמו_, _जाकर_, _oceà_, রিনি_, 
   {{0x52a800a7,0x201c015d,0x69dc0174,0x1dd0a71d}},	// [38ac0] двам_, ddwi_, ðreg, हरात, 
   {{0x3321f3b2,0x6458025c,0xd6a800ae,0x00000000}},	//   rvix_, _ċwie, _تدعم_, --, 
   {{0x10a416ab,0x1cbc0327,0xd0180395,0x00000000}},	//   вижн, ྀམས_, дфл_, --, 
   {{0xe804007a,0xcf45f3b3,0x8fa400f2,0xa3b8000d}},	//   ष्पा_, кней, نماه, _चलय_, 
   {{0x92a4068f,0x2340001f,0x59e00073,0x69c802d0}},	//   _połą, _የመኖሪ, पणार, ybde, 
   {{0x68e800a9,0xacf834e2,0x91e40022,0x00000000}},	//   yrdd, енку_, _шоге, --, 
   {{0x2175f3b4,0x6d58030a,0xbfd000db,0x00000000}},	//   _бутр, uzva, ايۇع, --, 
   {{0x6bd400ec,0xfd400139,0x00000000,0x00000000}},	//   اڪار, рэшн, --, --, 
   {{0xdb1802e2,0x68e80142,0xa07401ec,0x00000000}},	//   _sewò, wrdd, _сырш, --, 
   {{0xdb180100,0x705402f2,0x00000000,0x00000000}},	//   _pewò, _جۆڵا, --, --, 
   {{0x67d400f7,0x3ea800d0,0x02dc000d,0x00000000}},	//   лону, žitú_, _फट्न, --, 
   {{0x4bd99bd3,0xc0dc0023,0x0ba800cf,0x00000000}},	//   _آباد_, _ሕብሪ_, _قاشى_, --, 
   {{0xf8b431ee,0xbb8000f1,0x2d8cf6ad,0xf8040006}},	//   нөө_, _پلوي, _hyde_, шчэн, 
   {{0xe9440214,0x236c0010,0x00000000,0x00000000}},	//   _مربی, _žejo_, --, --, 
   {{0xc7c42424,0xd9940014,0x2d8c005c,0xa26c0240}},	//   _испи, _مۆٝت_, _jyde_, _በረኻን_, 
   {{0xc1c800dc,0xb8840408,0xb1680092,0x00000000}},	//   िर्ग, _вуьй, _ተሸላሚ_, --, 
   {{0x2d8c037e,0x04040183,0x00000000,0x00000000}},	// [38ad0] _lyde_, ৱালী_, --, --, 
   {{0x7aec0228,0x32540276,0xc0dc02d3,0x2d8c0432}},	//   àcti, авур, _ሕብረ_, _oyde_, 
   {{0x2d8c037e,0xc0581cb8,0x00000000,0x00000000}},	//   _nyde_, мід_, --, --, 
   {{0x5f780ae5,0xae001b76,0x00000000,0x00000000}},	//   ىماس_, ल्सन_, --, --, 
   {{0x5f043298,0xa2ddf3b5,0xe8042bf1,0x00000000}},	//   узла, _पिट्, ष्या_, --, 
   {{0x644df3b6,0x2d8c5b4f,0x00000000,0x00000000}},	//   lkai, _byde_, --, --, 
   {{0x628549ae,0x2d8c00d8,0x1ea80451,0x644c04b1}},	//   moho, _cyde_, واڻي_, okai, 
   {{0x644c2af2,0x6285f3b7,0xa1940022,0xe8040b98}},	//   nkai, loho, _ааҳч, ष्मा_, 
   {{0x644c9f8e,0x628401af,0x9b44c9f0,0xae0017cb}},	//   ikai, ooho, انخو, ल्हन_, 
   {{0x6284f43c,0x644c023a,0x00000000,0x00000000}},	//   noho, hkai, --, --, 
   {{0x644df3b8,0x2ba40307,0x1869845e,0xacf801d5}},	//   kkai, खेबा, еани_, _анху_, 
   {{0x6285f3b9,0x00000000,0x00000000,0x00000000}},	//   hoho, --, --, --, 
   {{0x1ae4023b,0x7c3803b2,0xc3080154,0xcc3800df}},	//   _солм, mjur, রিডি_, _רענט, 
   {{0x7c392b8f,0x644c0024,0xa2dc228d,0xd5b000ae}},	//   ljur, ekai, _पिज्, صفر_, 
   {{0xa3c000dc,0x1a64135f,0x00000000,0x00000000}},	//   ुरं_, _لیکی_, --, --, 
   {{0x644df3ba,0xd17401ec,0x3ce803ce,0x00000000}},	//   gkai, қызы, _घटने_, --, 
   {{0xe2f80156,0x07a0020a,0x47c0023a,0x6284022e}},	// [38ae0] _ཕྱདཔ_, _лаън, _убыв, foho, 
   {{0x6285e661,0x644c0433,0xe8041408,0x7c395e4f}},	//   goho, akai, ष्ठा_, hjur, 
   {{0x4fe85c89,0xd1940b3e,0xe578004e,0x00000000}},	//   емен_, ушањ, _үзө_, --, 
   {{0x644c2e18,0xa3c000dc,0xb3b8243c,0xa2dc1c54}},	//   ckai, ुरः_, _अलिख, _पिच्, 
   {{0x6285f3bb,0xa3b8007d,0x7c39f3bc,0x2d8c017a}},	//   boho, _चलत_, djur, _syde_, 
   {{0xd250121a,0x6285f3bd,0x00000000,0x00000000}},	//   _انس_, coho, --, --, 
   {{0x0ca91438,0xe81c00c5,0x9e643769,0xcd0402e8}},	//   нтии_, _बोझा_, جانن, учли, 
   {{0x8fa49b70,0xfe6c1b56,0x7c380413,0x00000000}},	//   _бабе, يگە_, gjur, --, 
   {{0x2d8c0204,0x0a69f3be,0xa2dc05f9,0xaa55006e}},	//   _wyde_, ерни_, _पिछ्, ивиш, 
   {{0x644c0323,0xc330011a,0x6c341bf4,0x00000000}},	//   zkai, מוח_, افکا, --, 
   {{0x4cdc0729,0xbe302002,0xe8580305,0xa3d4098a}},	//   _মহকু, _دىلب, ванш_, _सजल_, 
   {{0x6285f3bf,0xd8f401d3,0x00000000,0x00000000}},	//   zoho, گزیک, --, --, 
   {{0xead443a7,0x6285f3c0,0x8d8c02d3,0x00000000}},	//   _толь, yoho, _ምቕባል_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x644c0664,0xa4d400d6,0x628403d1,0x442842cd}},	//   tkai, робі, voho, нцам_, 
   {{0x6284e097,0x644df3c1,0x00000000,0x00000000}},	//   woho, ukai, --, --, 
   {{0x644c355e,0xe8046c5a,0x3359f3c2,0xe1f00014}},	// [38af0] rkai, ष्णा_, гатэ_, قسؔ_, 
   {{0x644df3c3,0x00000000,0x00000000,0x00000000}},	//   skai, --, --, --, 
   {{0x6285f3c4,0x644c3209,0x6d5c00e4,0x7c3988d1}},	//   roho, pkai, _ýrah, yjur, 
   {{0x6285f3c5,0xa3b8007d,0x00000000,0x00000000}},	//   soho, _चलि_, --, --, 
   {{0x6284c81f,0xd2f401ed,0xd34412ea,0x00000000}},	//   poho, _نکلا_, _پیله_, --, 
   {{0xb6bc010f,0x714400cf,0x00000000,0x00000000}},	//   עצוי, _گۉمۅ, --, --, 
   {{0xa3b80d5f,0x7c3808ce,0x2dd8007b,0x918801af}},	//   _चला_, tjur, ابهة_, _артҡ_, 
   {{0x3ab0506f,0x1c45f3c6,0x30a40064,0x00000000}},	//   бәкт, рним, _грув, --, 
   {{0x7c39f3c7,0x920002e5,0xaac4036b,0x705802a9}},	//   rjur, र्वज_, یتین, _сатр_, 
   {{0xdea007d6,0xa3b800af,0xda65f3c8,0xdb0c0248}},	//   _بیتی, _चलऽ_, рвои, _àkís, 
   {{0xdd145dcd,0x26c40150,0x00000000,0x00000000}},	//   _خواخ, ұғын_, --, --, 
   {{0x18689dc2,0x95ec07c1,0x00000000,0x00000000}},	//   тами_, जल्ट_, --, --, 
   {{0x7bd9f3c9,0x6c8400c6,0x6ed807f7,0x2bc9f3ca}},	//   mauu, _النم, नीपु, _сухо_, 
   {{0x79e400dd,0x7bd9f3cb,0xdb1817da,0x00000000}},	//   _صوبہ_, lauu, _bewö, --, 
   {{0xd46806ed,0x00000000,0x00000000,0x00000000}},	//   виве_, --, --, --, 
   {{0x7bd8079b,0x00000000,0x00000000,0x00000000}},	//   nauu, --, --, --, 
   {{0xd39429db,0xd2651917,0x94a801e0,0x00000000}},	// [38b00] рәнә_, акай, етҡа_, --, 
   {{0x91e46f00,0x7bd8f1d3,0x00000000,0x00000000}},	//   роже, hauu, --, --, 
   {{0x2cf43daa,0xdb180730,0x7bd9f3cc,0x00000000}},	//   _इमेल_, _gewö, kauu, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x60c85946,0x8d8c0023,0x2ee00221,0x11d4187f}},	//   _čeme, _ምዕቡል_, éif_, _вібр, 
   {{0x7f440075,0xe4c85bb8,0x7f8001e2,0x00000000}},	//   شلىق_, _جبین_, غلون, --, 
   {{0x3dcc015b,0x0634010f,0x9034074d,0x3cf4007b}},	//   _রাখল, ינסט_, _кхач, لعيد_, 
   {{0x0fb40244,0x00000000,0x00000000,0x00000000}},	//   _ئێشک_, --, --, --, 
   {{0x0ea9f3cd,0xac080eff,0x09d80154,0x00000000}},	//   _акай_, _ەرتە_, _দাবা, --, 
   {{0xaa59f3ce,0x7bd80270,0x00000000,0x00000000}},	//   الدا_, aauu, --, --, 
   {{0x7bd83bbe,0x2f0126b6,0xbd5401d9,0xdcac00f1}},	//   bauu, lòg_, _پرٕژ, _ګډو_, 
   {{0x3ce815e0,0xc864014b,0xad2400d1,0x00000000}},	//   _घटते_, ртои, _پىچى, --, 
   {{0x01cc02dd,0x00000000,0x00000000,0x00000000}},	//   _ﺗﯘﯕﻌ, --, --, --, 
   {{0x847402d3,0xfaa000c0,0x2918025c,0x00000000}},	//   _የብላን_, _дачо, ħrab_, --, 
   {{0x69d9f3cf,0x6595b868,0x00000000,0x00000000}},	//   _ieve, саву, --, --, 
   {{0x69d9f3d0,0x291c02c4,0x00000000,0x00000000}},	//   _heve, _isva_, --, --, 
   {{0x69d9f3d1,0xa5c40166,0x5eb800d1,0x00000000}},	// [38b10] _keve, _гөбе, ﻧﺪﯗﺭ, --, 
   {{0x69d86d8b,0x60c800f3,0xa2cc00e1,0x00000000}},	//   _jeve, _čemb, दीग्, --, 
   {{0x245460ee,0x69d9f3d2,0xdfd00597,0x6615f3d3}},	//   _هندس, _meve, كيا_, mezk, 
   {{0x8474069c,0x23bc0248,0x661401c6,0x2a6c01ab}},	//   _የብሉን_, _dájó_, lezk, hidb_, 
   {{0x69d9f3d4,0x291c07c5,0x7bd80641,0x2f00359e}},	//   _oeve, _lsva_, vauu, gòg_, 
   {{0x69d9f3d5,0x661405f5,0xb28402d5,0xa3c00037}},	//   _neve, nezk, _дыск, ुरक_, 
   {{0x9d440046,0x7bd83bf3,0xa15839be,0x00000000}},	//   сейд, tauu, _саву_, --, 
   {{0x91e400b5,0x69d802d0,0x2489f3d6,0x66148106}},	//   _auとw, _aeve, noam_, hezk, 
   {{0x291c0421,0x661401c4,0xc5fc00e2,0x7bd8000d}},	//   _asva_, kezk, ļēji_, rauu, 
   {{0x69d9d81f,0x248806d9,0x7bd80254,0xda6401a9}},	//   _ceve, hoam_, sauu, ёвни, 
   {{0x69d9f3d7,0x66140323,0x7bd9f3d8,0x2fdc010e}},	//   _deve, dezk, pauu, _özgä_, 
   {{0x69d9f3d9,0x9855dade,0x2a6c01ab,0xcd9405d0}},	//   _eeve, стош, aidb_, _הדעת_, 
   {{0x41a40574,0x907827af,0x98a40032,0x69d81e13}},	//   केतस, רטרי, _һике, _feve, 
   {{0x69d9f3da,0x661401c0,0xed8002d3,0x24540158}},	//   _geve, gezk, _ይሕብር_, _råma_, 
   {{0x98a5f3db,0x59081cb8,0x00000000,0x00000000}},	//   _лике, _сейм_, --, --, 
   {{0x69d9f3dc,0x2ba400c5,0x00000000,0x00000000}},	//   _zeve, खेवा, --, --, 
   {{0x04403523,0x69d8a0a5,0x6614005a,0x11e43de2}},	// [38b20] четн, _yeve, bezk, йжам, 
   {{0x60d40369,0x59040135,0xd9f802ab,0xff8402d3}},	//   _bwzm, _མྱོས_, ्भित_, _ንሓዋሩ_, 
   {{0x2489f3dd,0x60d40369,0xd4680262,0x00000000}},	//   boam_, _cwzm, _бине_, --, 
   {{0x257c24ba,0x4fa47b88,0xc4300014,0x765c0455}},	//   _wâlï_, биев, _ٹکِت, lhry, 
   {{0xd9f80490,0x6db421cb,0x38380092,0x00000000}},	//   ्भात_, ойлу, _እየተሠ, --, 
   {{0xdce00c3c,0x4718010f,0x2f0000a3,0x765c0142}},	//   _azlı, טונג, ròg_, nhry, 
   {{0x8c641b6d,0x60d40369,0x6d5c0003,0x00000000}},	//   йтид, _gwzm, _żrab, --, 
   {{0x59040135,0xce0400b2,0x6614009d,0x0160009d}},	//   _མྱེས_, _گذري, zezk, _эксо, 
   {{0x69d9f3de,0x4e281985,0xc61c00eb,0x0b880108}},	//   _peve, _йоан_, দাতা_, ыски_, 
   {{0xc3300d65,0x69d8069c,0x248806d9,0x9f7801af}},	//   פות_, _qeve, zoam_, _тссф_, 
   {{0x69d9f3df,0xa3b8033d,0x66144fdf,0x96b0033f}},	//   _veve, _चलल_, vezk, _इंजॉ, 
   {{0x69d9f3e0,0x764802f6,0xc86401b9,0xfce001c6}},	//   _weve, ödyn, ётни, _хоцо, 
   {{0x69d9f3e1,0x661405f5,0x24880109,0x47855d48}},	//   _teve, tezk, voam_, сынб, 
   {{0x7aec04cf,0x69d8014b,0x291c0810,0xa5f80640}},	//   ácte, _ueve, _tsva_, јеву_, 
   {{0x661405f5,0x24880170,0xfd880873,0x291c4f58}},	//   rezk, toam_, ﺗﻘﺎﻥ_, _usva_, 
   {{0x661401c0,0x3d1810eb,0x635400d4,0x00000000}},	//   sezk, _मनसे_, овбу, --, 
   {{0x27e84437,0x24880170,0x61d8034b,0xe2f80212}},	// [38b30] _idan_, roam_, имая_, резі_, 
   {{0x672df3e2,0x765df3e3,0x27e814bb,0x248803d1}},	//   _iraj, chry, _hdan_, soam_, 
   {{0x672c02fd,0x248805da,0x27e8022e,0x6ed8002b}},	//   _hraj, poam_, _kdan_, _āmiṣ, 
   {{0x9f5c007f,0x443c0037,0x00000000,0x00000000}},	//   dewò_, _õu_, --, --, 
   {{0x27e801b9,0x20d400d7,0x00000000,0x00000000}},	//   _mdan_, sťi_, --, --, 
   {{0x672c0066,0x27e9f3e4,0x00000000,0x00000000}},	//   _mraj, _ldan_, --, --, 
   {{0xe6b401ad,0x00000000,0x00000000,0x00000000}},	//   ंदुज, --, --, --, 
   {{0x27e9f3e5,0x672df3e6,0x794c01e1,0x00000000}},	//   _ndan_, _oraj, _lòwú, --, 
   {{0x672c0066,0x3d184709,0xa2cc23e9,0x9b44072d}},	//   _nraj, _मनवे_, दीच्, زندو, 
   {{0x27e9f3e7,0xda6400d6,0xddc0007f,0x2ca0031c}},	//   _adan_, івни, _kolō, ċida_, 
   {{0x26c8325f,0xd944c575,0x27e80009,0x98a40f64}},	//   _atao_, цени, _bdan_, жине, 
   {{0x27e9f3e8,0xbd880023,0x97d800c7,0x00000000}},	//   _cdan_, _ናታቶም_, шьоу_, --, 
   {{0x765df3e9,0x200c0007,0x672c07de,0xfb24004b}},	//   thry, _mbei_, _craj, _دراپ, 
   {{0x27e9f3ea,0x672df3eb,0x91e400b5,0xb8b00220}},	//   _edan_, _draj, _auのw, _нөмі, 
   {{0x200df3ec,0x27e8031c,0x9424009b,0x6d5c00a2}},	//   _obei_, _fdan_, омве, _ýrat, 
   {{0x53c9f3ed,0xd9f80db3,0x45a000db,0xdb0c01e1}},	//   ргам_, ्भवत_, بەپك, _òkór, 
   {{0x672df3ee,0x765d58af,0x60c80219,0xd25014af}},	// [38b40] _graj, phry, _čema, ونر_, 
   {{0x27e801b9,0xd1940f14,0x2d800356,0xa3b80037}},	//   _zdan_, ошењ, şiei_, _चलअ_, 
   {{0xa3d409bb,0x672df3ef,0xe718008e,0x27e9b5a6}},	//   _सड़क_, _zraj, _käğä, _ydan_, 
   {{0xd008b9d7,0x22f801d9,0x00000000,0x00000000}},	//   реде_, _گژِھ_, --, --, 
   {{0x4ea45df2,0xe7180724,0x9f5c00d2,0x2a3c0240}},	//   орка, _mäğä, tfwá_, _ክገብሮ, 
   {{0xddc00270,0x648000e2,0x00000000,0x00000000}},	//   _folō, rķie, --, --, 
   {{0xf984f166,0x463800df,0x00000000,0x00000000}},	//   _آب_, יעסע, --, --, 
   {{0x2fc40798,0xcb080024,0x0ca801a9,0x00000000}},	//   _ufmg_, аход_, штли_, --, 
   {{0x27e9f3f0,0x6fd00c2e,0xfba401c6,0xef10004e}},	//   _rdan_, _ड्यू, жтэй_, _чүлө, 
   {{0xf55002d3,0x764802f6,0x27e8022e,0x672c0200}},	//   _ጅግንነ, ödyl, _sdan_, _rraj, 
   {{0x26c808ad,0x672df3f1,0xc1b800c8,0x41b800c8}},	//   _stao_, _sraj, ימיש, יציע, 
   {{0x672df3f2,0xc86402bf,0x27e8022e,0x5fb000af}},	//   _praj, ітни, _qdan_, ुँचल, 
   {{0x3b040276,0x672c025c,0x8b644710,0x00000000}},	//   _мецо_, _qraj, _باضم, --, 
   {{0x672df3f3,0x00000000,0x00000000,0x00000000}},	//   _vraj, --, --, --, 
   {{0xe5980212,0x6aa80036,0x27e8022e,0x4b500133}},	//   скві_, mmdf, _tdan_, _رێگر, 
   {{0x27e9f3f4,0x229c05da,0x59040327,0x00000000}},	//   _udan_, dìka_, _མྱིས_, --, 
   {{0xddc00421,0x26c80115,0x672df3f5,0xa5f80114}},	// [38b50] _solō, _utao_, _uraj, _лепу_, 
   {{0x3d18302b,0x00000000,0x00000000,0x00000000}},	//   _मनले_, --, --, --, 
   {{0x659455a7,0x00000000,0x00000000,0x00000000}},	//   _хану, --, --, --, 
   {{0x200c037e,0x25e0000d,0x397800df,0xa35c0139}},	//   _qbei_, _क़डी_, סטאנ, cäğä_, 
   {{0x5438010f,0xddc400c7,0xde941d39,0x4ad823ef}},	//   _הערא, пбли, падњ, _मौलव, 
   {{0x69c406be,0x00000000,0x00000000,0x00000000}},	//   _şien, --, --, --, 
   {{0xdfd4100e,0xdef8010b,0x00000000,0x00000000}},	//   _новы, рыҗ_, --, --, 
   {{0x8025f3f6,0x00000000,0x00000000,0x00000000}},	//   _برآم, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xadf44d87,0x76b400a2,0xe71800fd,0x29180327}},	//   _опуш, _ańyn, _säğä, ħran_, 
   {{0xbd681e2d,0x99d400d1,0x00000000,0x00000000}},	//   _трае_, يتگا, --, --, 
   {{0xe718013d,0x6c54030d,0x00000000,0x00000000}},	//   _qäğä, _окху, --, --, 
   {{0xfa808efe,0x00000000,0x00000000,0x00000000}},	//   _оқим, --, --, --, 
   {{0xe718013d,0xda083092,0x00000000,0x00000000}},	//   _wäğä, _طيبه_, --, --, 
   {{0xceb09b62,0xf84801c0,0xae000807,0xe718008e}},	//   תים_, _дүнд_, ल्टन_, _täğä, 
   {{0x5904031c,0x00000000,0x00000000,0x00000000}},	//   _མྱགས_, --, --, --, 
   {{0x78a40357,0xf9400014,0x0874010f,0x91b8007b}},	// [38b60] _ihiv, _رچھَ, _מעקט_, مطار_, 
   {{0x42200212,0x63780816,0x941803b9,0x00000000}},	//   ндув, істр_, _əyər_, --, 
   {{0xefd0067d,0x34a4039b,0x78a4022e,0x955400f2}},	//   _ጥራይ_, _огоҳ, _khiv, _رخدا, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6aa80334,0xc61c00eb,0x00000000,0x00000000}},	//   ymdf, দারা_, --, --, 
   {{0x229c06d9,0x00000000,0x00000000,0x00000000}},	//   pìka_, --, --, --, 
   {{0xdd8c0131,0x09d80eac,0x78a401f4,0x82a000db}},	//   لۈك_, _দালা, _ohiv, _чарж, 
   {{0x78a40810,0xdb1801c7,0x00000000,0x00000000}},	//   _nhiv, _ofwä, --, --, 
   {{0xfbcc007b,0x00000000,0x00000000,0x00000000}},	//   دتى_, --, --, --, 
   {{0x78a41028,0x7aecd7b4,0x59040135,0xc985f3f7}},	//   _ahiv, ácta, _མྱངས_, зуми, 
   {{0x78a400cd,0x00000000,0x00000000,0x00000000}},	//   _bhiv, --, --, --, 
   {{0x78a5f3f8,0x99980137,0x81c40171,0x69cc0b67}},	//   _chiv, өкөт_, _izēš, _द्री, 
   {{0x78a40055,0xb9000c6f,0xc050011a,0x00000000}},	//   _dhiv, _पौ_, גזר_, --, 
   {{0x78a4000d,0xfb180677,0x3d10000d,0x3b5000d4}},	//   _ehiv, _לודמ, _दहमे_, _якір, 
   {{0x9f5402d2,0x60c9f3f9,0x00000000,0x00000000}},	//   _íför_, _čemo, --, --, 
   {{0x78a55fd4,0x00000000,0x00000000,0x00000000}},	//   _ghiv, --, --, --, 
   {{0xa2b400d6,0xe99002dd,0xf31401c6,0x00000000}},	// [38b70] дбач, _سۇڭگ, ндтэ, --, 
   {{0x78a5c2fe,0x93680092,0x31c401f4,0xe5b40150}},	//   _zhiv, _በዘመነ_, есцв, _ойпы, 
   {{0xf0e81183,0x3cf800c5,0x00000000,0x00000000}},	//   كىلى_, _एमें_, --, --, 
   {{0xb5a4013d,0x00000000,0x00000000,0x00000000}},	//   _ярый, --, --, --, 
   {{0x645db672,0xc3f4004b,0x338401c0,0xaec40212}},	//   _ilsi, _وکړئ_, _зурв, ебіл, 
   {{0xef18dbe2,0x00000000,0x00000000,0x00000000}},	//   ямі_, --, --, --, 
   {{0xa194009d,0x00000000,0x00000000,0x00000000}},	//   _цавч, --, --, --, 
   {{0xf53800c8,0x81c4005f,0xc05800db,0x5ac9f3fa}},	//   לטור_, _dzēš, _اشسا_, олим_, 
   {{0xdb08fa01,0x78a402b9,0x7648005b,0x99f40006}},	//   _önüm, _rhiv, ödyk, мяні, 
   {{0x78a5f3fb,0x1a649057,0x00000000,0x00000000}},	//   _shiv, بیتی_, --, --, 
   {{0x3ebc3e36,0x78a40589,0x645c85d7,0x636801a9}},	//   _huut_, _phiv, _olsi, _sоnl, 
   {{0x3ebc0037,0x24b00116,0x00000000,0x00000000}},	//   _kuut_, _ﺳﺎﻻﻣ, --, --, 
   {{0x81c00c58,0x3ebc0254,0x00000000,0x00000000}},	//   _এজন_, _juut_, --, --, 
   {{0x3ebc049b,0x645c102c,0xfaa40b8d,0x7af9f3fc}},	//   _muut_, _alsi, _эшен, muut, 
   {{0x78a406d6,0xb4040372,0x3ebdf3fd,0x00000000}},	//   _thiv, нүнд, _luut_, --, 
   {{0x645c030d,0x3a240784,0xded00092,0x53680b82}},	//   _clsi, _hanp_, የሙን_, ሲያዊት_, 
   {{0x7af8049b,0x91e43fbb,0x3ebc0660,0x213005c7}},	// [38b80] nuut, дозе, _nuut_, _arzh_, 
   {{0xe3b00d83,0x3a240254,0xc04c0014,0x00000000}},	//   ارِ_, _janp_, یٖل_, --, 
   {{0x7af9f3fe,0x7174129d,0x00000000,0x00000000}},	//   huut, رۇرا, --, --, 
   {{0x7af9f3ff,0x3ebdf400,0x3a24b3ad,0x00000000}},	//   kuut, _buut_, _lanp_, --, 
   {{0x7af9f401,0x213005c7,0x044001af,0xbec000b8}},	//   juut, _erzh_, _реян, _śūre, 
   {{0x3a2402fa,0x7af80449,0x27440023,0x248c0118}},	//   _nanp_, duut, _hënë_, čeme_, 
   {{0x2744036e,0x00000000,0x00000000,0x00000000}},	//   _kënë_, --, --, --, 
   {{0x32c46648,0x7af8fa69,0x8fa400d8,0x3dc000ee}},	//   _köy_, fuut, _жабе, нйәг, 
   {{0x7af80eda,0x3a240204,0x4e041064,0x27440de2}},	//   guut, _banp_, _озаб, _mënë_, 
   {{0x274402d3,0x8d542c0b,0x3a700139,0x00000000}},	//   _lënë_, _отеч, клыр, --, 
   {{0x64480086,0x61e000af,0xddb8074d,0x3a2400ef}},	//   _òeig, _õlle, _хууш_, _danp_, 
   {{0x7af8852e,0x6e29f402,0x274402d3,0xdc8802dd}},	//   buut, _hadb, _nënë_, _есіл_, 
   {{0xfc640403,0x6e280156,0x32c40139,0x478800f5}},	//   _تخلی, _kadb, _nöy_, юсом_, 
   {{0x659401ce,0x9f64003e,0xe658009d,0x00000000}},	//   еагу, étér_, чигч_, --, 
   {{0x6e29f403,0x274402d3,0xa3b1f404,0xb5955b1f}},	//   _madb, _bënë_, टेन_, вирш, 
   {{0x6e29817d,0x3a241529,0x32c403e0,0xf48401c6}},	//   _ladb, _zanp_, _böy_, вуун, 
   {{0xf771f405,0xc6a4013e,0x6e280857,0x3495b868}},	// [38b90] _پاي_, _орои, _oadb, татр, 
   {{0x76748292,0x6e29f406,0x2294005e,0x6e3c01ab}},	//   _альф, _nadb, رلاس, _òrbh, 
   {{0x66054f78,0x3ebc20ac,0x00000000,0x00000000}},	//   _ichk, _suut_, --, --, 
   {{0x7af9f407,0xf1a4084c,0x27441bce,0x6e280067}},	//   yuut, трун, _gënë_, _aadb, 
   {{0x6e29f408,0x3ebc039a,0xc2b00124,0x32c40213}},	//   _badb, _quut_, _аҩаш, _göy_, 
   {{0x7af802f6,0x27440023,0x6e29f409,0x00000000}},	//   vuut, _zënë_, _cadb, --, 
   {{0x21300dd4,0x6e280014,0x7af9861e,0x3a240100}},	//   _urzh_, _dadb, wuut, _ranp_, 
   {{0x3ebc226d,0x6e28127b,0x4c900063,0x30a4022e}},	//   _tuut_, _eadb, лијс, _арув, 
   {{0x6605f40a,0x201df40b,0x6e2801e7,0xdd9001d3}},	//   _ochk, mewi_, _fadb, خوں_, 
   {{0x7af9f40c,0x201df40d,0x61e5f40e,0x6e280009}},	//   ruut, lewi_, nahl, _gadb, 
   {{0x7af98f02,0x6ab8a8d5,0x5bb80276,0x2d800311}},	//   suut, _divf, _елея_, şier_, 
   {{0x66048dbd,0x61e483ad,0x6e280034,0x7af9f40f}},	//   _achk, hahl, _zadb, puut, 
   {{0x61e5f410,0x3a24157e,0x274402d3,0xa3b001ad}},	//   kahl, _tanp_, _rënë_, टेम_, 
   {{0x61e5f411,0x201c00a2,0x00000000,0x00000000}},	//   jahl, hewi_, --, --, 
   {{0x61e42831,0x32c4415b,0x51f40014,0x00000000}},	//   dahl, _söy_, ہسار, --, 
   {{0x27440023,0x6605f412,0x33209e25,0x00000000}},	//   _qënë_, _echk, twix_, --, 
   {{0x274402d3,0x61e5f413,0x3861f414,0x51f400c6}},	// [38ba0] _vënë_, fahl, _ilir_, فسار, 
   {{0x998400dd,0x3320a7b1,0x02000108,0x25e01546}},	//   lelő_, rwix_, лзун, करणी_, 
   {{0x274424ba,0x38601529,0x50b9f415,0x6e3c00cf}},	//   _tënë_, _klir_, سداد_, _òrbi, 
   {{0x6295f416,0x68fc00f7,0xe3b0021a,0x6e29f417}},	//   _ekzo, àrdi, ارې_, _sadb, 
   {{0x61e42747,0xe804d8eb,0x6e29f418,0xc7d405d0}},	//   bahl, ष्टा_, _padb, גוני_, 
   {{0x7bc8346e,0x6e28014f,0x61b000db,0x68e80142}},	//   _afgu, _qadb, _چەكا, ysdd, 
   {{0x6e28151c,0x998401d3,0xe1940153,0x00000000}},	//   _vadb, kelő_, _артэ, --, 
   {{0x6e280429,0xfbd800cc,0x4ba400db,0x00000000}},	//   _wadb, _ধাউত, нөлү_, --, 
   {{0x6e29f419,0x09d8025c,0x00000000,0x00000000}},	//   _tadb, _འབྱ_, --, --, 
   {{0x6e280064,0x00000000,0x00000000,0x00000000}},	//   _uadb, --, --, --, 
   {{0x3861f41a,0x67d5f41b,0x6ab80115,0x69c8004e}},	//   _blir_, кону, _vivf, rcde, 
   {{0x61e5f41c,0xa3b042e3,0x66046144,0x8154008f}},	//   zahl, टेड_, _schk, גסטע_, 
   {{0x61e44b26,0x00000000,0x00000000,0x00000000}},	//   yahl, --, --, --, 
   {{0xbb38159d,0x09d82eab,0x38601529,0x6a64026c}},	//   _מעדי, _འབྲ_, _elir_, _sòff, 
   {{0xdb180066,0x6595f41d,0x75880108,0xa3dc1cd2}},	//   _rgwé, таву, еств_, डरल_, 
   {{0x61e4bda2,0x38600368,0x00000000,0x00000000}},	//   wahl, _glir_, --, --, 
   {{0x61e5f41e,0x6604007f,0x00000000,0x00000000}},	// [38bb0] tahl, _tchk, --, --, 
   {{0x6604544b,0xa1596c6f,0xb2743d2a,0x290c01b9}},	//   _uchk, мазу_, глуш, otda_, 
   {{0x61e5f41f,0x290df420,0xdfd00f17,0x9f4c05d5}},	//   rahl, ntda_, ليا_, _ideé_, 
   {{0x61e4e765,0xe37510d1,0xf990008f,0x00000000}},	//   sahl, _алмы, ארע_, --, 
   {{0x4429f421,0xd9acc853,0x61e4d059,0xfbc002dd}},	//   _iac_, _घण्ट, pahl, құло, 
   {{0x44280de4,0x998401d3,0x61e4014f,0x290c7e8b}},	//   _hac_, zelő_, qahl, ktda_, 
   {{0x4429f422,0x8d60656c,0x9d44021f,0x201d52c0}},	//   _kac_, ивше, тейд, pewi_, 
   {{0x4429f423,0xf19435dd,0x23680115,0xfcd00092}},	//   _jac_, _сись, ozaj_, _የቅጂ_, 
   {{0x2369262b,0x44286dc7,0xcb040451,0x2d9812e8}},	//   nzaj_, _mac_, نڊون_, _øren_, 
   {{0x4429f424,0xaf340ccb,0x290c022e,0x98ac0100}},	//   _lac_, _حرفت, ftda_, čnčl_, 
   {{0x4429ad07,0x290c0209,0x998401d3,0xa3b00a59}},	//   _oac_, gtda_, telő_, टेत_, 
   {{0x4429af91,0xbc6401d9,0x1bd41422,0x00000000}},	//   _nac_, _سۅخن_, _родя, --, 
   {{0x7c29f425,0x998401d3,0x290c0213,0x00000000}},	//   _iagr, relő_, atda_, --, 
   {{0x4429f426,0x2369f427,0x7c29f428,0x998401ed}},	//   _aac_, dzaj_, _hagr, selő_, 
   {{0x7c29b2c8,0x44299b6b,0x2610086b,0x1988023a}},	//   _kagr, _bac_, द्धी_, _юбки_, 
   {{0x7c2880f3,0xc48021ca,0x4429f429,0x38600263}},	//   _jagr, алск, _cac_, _ulir_, 
   {{0x13080953,0x48040276,0x00000000,0x00000000}},	// [38bc0] ьнай_, _реын_, --, --, 
   {{0x7c29f42a,0x4429f42b,0x51540220,0xa7a801e0}},	//   _lagr, _eac_, ктеу, _яйыҡ_, 
   {{0x4429f42c,0x71c4016c,0x3fa4013f,0xeff00023}},	//   _fac_, ваҷҷ, ɑtuɑ_, _ቃንዛ_, 
   {{0x6b8408a5,0x00000000,0x00000000,0x00000000}},	//   _þigg, --, --, --, 
   {{0x2368012d,0x00000000,0x00000000,0x00000000}},	//   czaj_, --, --, --, 
   {{0x290cf575,0x765df42d,0xdce01ae6,0x44281a9f}},	//   ytda_, nkry, _aylı, _zac_, 
   {{0xc0e072fb,0x4429f42e,0x7d21f42f,0xaa942f0d}},	//   _воск, _yac_, لفون, ғинч, 
   {{0x4429f430,0x41a400c7,0x6480005f,0x10a45a41}},	//   _xac_, _рвсн_, eķij, _рибн, 
   {{0x7c29f431,0x65c80248,0x00000000,0x00000000}},	//   _dagr, _jèhó, --, --, 
   {{0x7c29f432,0x290c0083,0x765c01bf,0xdb1001d3}},	//   _eagr, ttda_, jkry, ágán, 
   {{0x7c282507,0x29180109,0x01f8011a,0x00000000}},	//   _fagr, ïra_, ופיל, --, 
   {{0x290d65ed,0x7c29f433,0x23680790,0x5d78010f}},	//   rtda_, _gagr, yzaj_, _אָננ, 
   {{0x6d5802d5,0x290df434,0x6a6401ab,0x4784672f}},	//   lyva, stda_, _pòfd, тынб, 
   {{0x7c29f435,0x44299b6b,0x765c00cc,0x89d400d4}},	//   _zagr, _sac_, gkry, _рідш, 
   {{0x2418e29b,0x290c036b,0x25a401e6,0x44282401}},	//   новы_, qtda_, åll_, мцам_, 
   {{0x7c28011f,0x4428058a,0x00000000,0x00000000}},	//   _xagr, _qac_, --, --, 
   {{0x4429f436,0xc360001f,0xe5a40116,0x6d59046d}},	// [38bd0] _vac_, _መዘጋጀ, тиңи, hyva, 
   {{0x4428bf47,0x765c0076,0x7648005b,0x3d100037}},	//   _wac_, ckry, ödyt, _दहले_, 
   {{0xf7700f66,0x4429f437,0x8545f438,0x2368b2fe}},	//   _های_, _tac_, _рэпе, szaj_, 
   {{0xcfdc2f8b,0x4429f439,0xa15800c7,0x00000000}},	//   _ডাউন, _uac_, маҷу_, --, 
   {{0x7c280438,0xd00d00b3,0xdea001d3,0x7fc800bc}},	//   _ragr, سلو_, میری, ाडौँ, 
   {{0xfcd00020,0x6d58035a,0xde040108,0x00000000}},	//   _የህግ_, fyva, упки, --, 
   {{0x7c29f43a,0x6d58541b,0x8174014b,0x00000000}},	//   _pagr, gyva, _равӣ_, --, 
   {{0x24980ac5,0x7c28011f,0xa6d8015b,0x00000000}},	//   _jksm_, _qagr, _তিনট, --, 
   {{0x7c2802c4,0x00000000,0x00000000,0x00000000}},	//   _vagr, --, --, --, 
   {{0xed04049e,0x7c280429,0x6d5802fb,0x765c0267}},	//   _چولپ, _wagr, byva, xkry, 
   {{0x7c29f43b,0x00000000,0x00000000,0x00000000}},	//   _tagr, --, --, --, 
   {{0xbbe8d537,0x5b24c232,0x5b3475b0,0xdce000fd}},	//   _آرام_, _مفصل, _معتر, _uylı, 
   {{0x7bd9f43c,0xc2000490,0xacb01075,0x765c17b5}},	//   mbuu, _लांब_, _بەيب, tkry, 
   {{0x7bd9f43d,0x7af9f43e,0x68f80793,0xa90402f2}},	//   lbuu, mrut, üadü, دبین, 
   {{0x765df43f,0x7af8fbd4,0x7bd804ba,0x958402e8}},	//   rkry, lrut, obuu, улве, 
   {{0x765c0591,0x7bd9f440,0x7af820ac,0x23d40588}},	//   skry, nbuu, orut, ицур, 
   {{0x7bd8022f,0x52a8651e,0x7af826bc,0x225000d0}},	// [38be0] ibuu, евам_, nrut, _bozk_, 
   {{0x1544a678,0x00000000,0x00000000,0x00000000}},	//   _беом, --, --, --, 
   {{0x7af9f441,0xe2b46623,0xe4e400c0,0x00000000}},	//   hrut, рстэ, _кіўн, --, 
   {{0xd4680640,0x25a515b8,0xc0e1f442,0x8f0809ac}},	//   _чиме_, ülle_, соцк, ехка_, 
   {{0x7af9f443,0x7bd8058a,0xcef40063,0x00000000}},	//   jrut, dbuu, учењ, --, 
   {{0x7af9f444,0x6d59f445,0x11d800c6,0x7bd890ae}},	//   drut, tyva, _سورة_, ebuu, 
   {{0x7af820ac,0xdcc40116,0x00000000,0x00000000}},	//   erut, аңхе_, --, --, 
   {{0x7af9f446,0x7bd93f9f,0x6d59f447,0x00000000}},	//   frut, gbuu, ryva, --, 
   {{0x6d59f448,0x3b500395,0xa07450cb,0x00000000}},	//   syva, йкър, _тырш, --, 
   {{0x7bd8198f,0x6d59f449,0x00000000,0x00000000}},	//   abuu, pyva, --, --, 
   {{0x7af80af5,0x7bd8d430,0x00000000,0x00000000}},	//   arut, bbuu, --, --, 
   {{0x6368022e,0x7bd8058a,0x8b680120,0x4bd80b24}},	//   _kоnt, cbuu, _пиев_, _أباد_, 
   {{0x7af9f44a,0x7c900597,0xaa500092,0x00000000}},	//   crut, _النص, _ይፈለጋ, --, 
   {{0x26e41533,0x631c0eac,0x2ca0031c,0xb60400d4}},	//   _कबीर_, নিময়_, ċidu_, йяск, 
   {{0x67d4405c,0x35d4014b,0x00000000,0x00000000}},	//   _койу, сосё, --, --, 
   {{0x248c1fe6,0x291c0120,0xb884030d,0xe818014b}},	//   čemo_, _ipva_, _гуьй, _роич_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [38bf0] --, --, --, --, 
   {{0x7aec26c8,0x6b840022,0xe7d00137,0x00000000}},	//   ácti, _ÿigu, _دۅڭگ, --, 
   {{0xcfd4015b,0x00000000,0x00000000,0x00000000}},	//   _হয়ন, --, --, --, 
   {{0x7bd801d9,0xc64801d3,0x00000000,0x00000000}},	//   xbuu, _آجکل_, --, --, 
   {{0x2008005f,0x5de56625,0xa3b00764,0x60c82438}},	//   ļai_, ажла, टेश_, _čemu, 
   {{0x7af9f44b,0x644df44c,0x636801d5,0x00000000}},	//   vrut, ljai, _qоnu, --, 
   {{0xceb49151,0xe0440124,0xa3b0012c,0x62840165}},	//   рәт_, _кьаҿ, टेर_, mnho, 
   {{0x7af9f44d,0x644df44e,0xa1940124,0xe72c00a2}},	//   trut, njai, _баҳч, _güçý, 
   {{0x7af80cfe,0x7bd9f44f,0x644c03a2,0x628401f5}},	//   urut, rbuu, ijai, onho, 
   {{0x6285f450,0x644cb2f0,0x7bd8198f,0x9e94453c}},	//   nnho, hjai, sbuu, _ئارچ, 
   {{0x186876ac,0x4a4002bf,0x636801b9,0xdd940cab}},	//   вани_, інюв, _kоns, _тажы, 
   {{0x62844a67,0x7af9059e,0x60c000d5,0x7bd80009}},	//   hnho, prut, _élmu, qbuu, 
   {{0x1ae40220,0xcf90010f,0x644d7c31,0xbec400ef}},	//   _толм, ַטל_, djai, blīš, 
   {{0xaa500020,0x7d000a40,0x6285f451,0xda082984}},	//   _ይፈልጋ, ouns, jnho, _شيبه_, 
   {{0x18a4064e,0x98a45740,0x1a6435cf,0x644c032e}},	//   _какм, _кике, _میکی_, fjai, 
   {{0xdd00012c,0x6a6401ab,0x68fc0077,0x644c01d3}},	//   _štěs, _iòfa, árde, gjai, 
  
   {{0xa3b00574,0xa3d405f9,0x00000000,0x00000000}},	// [38c00] टेल_, हड़_, --, --, 
   {{0xc241f452,0x00000000,0x00000000,0x00000000}},	//   онук, --, --, --, 
   {{0x3f9df453,0x7d0090cb,0x067c0efb,0x644d5e03}},	//   _ayuu_, juns, _ﻭﺑﻠﯩ, bjai, 
   {{0x7d00b0e9,0x6284b730,0x4914010f,0x00000000}},	//   duns, anho, יקעל_, --, 
   {{0x4478010f,0x2be400fe,0x00000000,0x00000000}},	//   _ינטע, _গালৈ_, --, --, 
   {{0xb7ec0c58,0x7d000925,0x2bac000d,0x00000000}},	//   কলিত_, funs, _चरबा, --, 
   {{0x8c6443d4,0x7d01f454,0x829000db,0xdde80345}},	//   итид, guns, _بۇلچ, ارهه_, 
   {{0x7cc001d3,0x00000000,0x00000000,0x00000000}},	//   _bőrb, --, --, --, 
   {{0x15e41533,0xddd40209,0x4e2800a8,0x7d0001ab}},	//   करार_, _ýaşy, _иоан_, auns, 
   {{0x8eb01a59,0x7d006731,0x91a82d8f,0x00000000}},	//   _بەتت, buns, _कराई, --, 
   {{0x7d01f455,0xc9840131,0xc23400d9,0x0c24447e}},	//   cuns, рупи, בריו_, _вмен, 
   {{0x2ca00332,0x00000000,0x00000000,0x00000000}},	//   _óid_, --, --, --, 
   {{0x62840368,0x6f055638,0x00000000,0x00000000}},	//   ynho, àich, --, --, 
   {{0xa3d801f9,0x00000000,0x00000000,0x00000000}},	//   ठुन_, --, --, --, 
   {{0x644df456,0xa4d402bf,0x7aec00d0,0x48a8013d}},	//   tjai, собі, áctv, _итим_, 
   {{0xfa000003,0x2fc413bb,0x7468036b,0x6285f457}},	//   _མཐོན_, _ngmg_, арув_, wnho, 
   {{0x644df458,0xa3b00034,0x00000000,0x00000000}},	// [38c10] rjai, टें_, --, --, 
   {{0x628406ef,0x7d0003f9,0x70380214,0x644c1c3a}},	//   unho, yuns, یسنس_, sjai, 
   {{0x6285f459,0x644c01ed,0x6b8401e4,0xf0e80145}},	//   rnho, pjai, _ɾiga, لىلى_, 
   {{0x26c80374,0x9ef400c6,0x26c0002f,0x672c0200}},	//   _kuao_, مستش, _hiho_, _ksaj, 
   {{0x7d01f45a,0x26c003c1,0x27e80c3e,0xde5802bf}},	//   wuns, _kiho_, _mean_, ладі_, 
   {{0x27e9f45b,0x7d01f45c,0x672c0451,0xf20411ed}},	//   _lean_, tuns, _msaj, _мясо, 
   {{0x26c81d50,0x26c0037e,0x4f30001f,0xbd680801}},	//   _luao_, _miho_, _በውይይ, ърде_, 
   {{0x7d01f45d,0x6b8401fa,0x27e97341,0x26c1f45e}},	//   runs, _žiga, _nean_, _liho_, 
   {{0x7d01f45f,0xdf5400aa,0x672df460,0xdd901f70}},	//   suns, _ارزښ, _nsaj, _کوا_, 
   {{0x7d000502,0xda6432b1,0xaae4007b,0x00000000}},	//   puns, свои, آسيو, --, 
   {{0x26c818a6,0x672c0124,0x7c841606,0x27e80e21}},	//   _auao_, _asaj, _куде, _bean_, 
   {{0x27e800a3,0xb8ec11bc,0xb9400240,0x00000000}},	//   _cean_, _वं_, _ንዘለዎ, --, 
   {{0x26c0003e,0xfb2404d3,0x8c1400c6,0x672c01ed}},	//   _biho_, _خراپ, _طيور_, _csaj, 
   {{0xa3bd6c08,0x27e80363,0x76b4010e,0xc200000d}},	//   ेखन_, _eean_, _ańyr, _लागब_, 
   {{0x200c0333,0x27e80b21,0x26c00477,0x2558084c}},	//   _ocei_, _fean_, _diho_, артэ_, 
   {{0x27e8428b,0x26c80618,0xd18401e0,0x00000000}},	//   _gean_, _fuao_, ҡлай, --, 
   {{0x636806be,0x12c801f7,0xd3940139,0x00000000}},	// [38c20] _sоnr, اظري_, сәнә_, --, 
   {{0x27e88fe9,0xd6d80598,0x200c0311,0xd9f80950}},	//   _zean_, _итү_, _acei_, ूलित_, 
   {{0x27e9c6bc,0x0dc80b01,0x0654010f,0x00000000}},	//   _yean_, қули_, _הייך_, --, 
   {{0xcf447df2,0x672c035b,0x65602b96,0x00000000}},	//   йней, _ysaj, ølhe, --, 
   {{0x11d43334,0x00000000,0x00000000,0x00000000}},	//   _гібр, --, --, --, 
   {{0x2be000cd,0x00000000,0x00000000,0x00000000}},	//   नर्थ, --, --, --, 
   {{0xc278008f,0x26e4012d,0x00000000,0x00000000}},	//   _ערלי, _कब्र_, --, --, 
   {{0xbfc80150,0x00000000,0x00000000,0x00000000}},	//   _ماكە_, --, --, --, 
   {{0xfbcc0979,0x27e9f461,0x09b000cd,0xef940244}},	//   رتي_, _rean_, ुख्य, _بیشد, 
   {{0x26c800b0,0x7f38008f,0x27e9f462,0x41d800cd}},	//   _ruao_, _געמו, _sean_, मुपस, 
   {{0x8d640020,0x27e9f463,0x672c0083,0x26c1f464}},	//   ታውቋል_, _pean_, _ssaj, _riho_, 
   {{0xc864d550,0x26c01682,0x26c9d518,0xc9842b20}},	//   стои, _siho_, _puao_, _қули, 
   {{0x27e9f465,0x26c051e2,0xb8ec00c5,0x672c0327}},	//   _vean_, _piho_, _वू_, _qsaj, 
   {{0x05747c8a,0x27e9f466,0x3cec0490,0x672c0010}},	//   مازد, _wean_, ींचे_, _vsaj, 
   {{0x27e800af,0x26c00455,0xba14011a,0x00000000}},	//   _tean_, _viho_, _החוץ_, --, 
   {{0x26c8a33e,0x27e80295,0xd79802e3,0x6a640241}},	//   _tuao_, _uean_, ọpụr, _kòfo, 
   {{0x672c0451,0xb7dc008f,0xa2d43bd7,0x75680014}},	// [38c30] _usaj, _עקזי, زيات, لییہ_, 
   {{0x6a640100,0x05840139,0x02a51c3d,0x00000000}},	//   _mòfo, _гумм, ёрам, --, 
   {{0xddc0010f,0xc058187f,0x00000000,0x00000000}},	//   _bolŝ, лід_, --, --, 
   {{0x3e681a82,0x356800cf,0xf0b800f2,0x00000000}},	//   _møte_, _ырын_, مانش_, --, 
   {{0xddc410f5,0x2489f467,0xc3400354,0x00000000}},	//   обли, mnam_, _хĕл_, --, 
   {{0x539805d0,0x9d4400ee,0x24883e9d,0x6e940212}},	//   _כירו, жекд, lnam_, пичу, 
   {{0x2489f468,0xcf8c02f2,0x5d680395,0x00000000}},	//   onam_, _یژه_, рийм_, --, 
   {{0x2489f469,0xd9e00d2c,0xfe70129e,0xb5ac0150}},	//   nnam_, फर्ट, _کدر_, _ﺴﺭﻴﻌ, 
   {{0x2489f46a,0x5ac80114,0x00000000,0x00000000}},	//   inam_, јлом_, --, --, 
   {{0x24880649,0x3e68143a,0xda0800ec,0x19b800a8}},	//   hnam_, _bøte_, جيده_, иунь_, 
   {{0xd8255099,0x24880113,0x00000000,0x00000000}},	//   одни, knam_, --, --, 
   {{0x68fc659a,0xcd9408a8,0x00000000,0x00000000}},	//   árda, _ודעת_, --, --, 
   {{0x2489f46b,0xda3402d5,0x00000000,0x00000000}},	//   dnam_, _меды, --, --, 
   {{0x2a6c009a,0xaa4401ec,0xed800023,0x00000000}},	//   chdb_, _ىننى, _ክሕብር_, --, 
   {{0x6600022c,0x9478e06f,0x00000000,0x00000000}},	//   ólka, асау_, --, --, 
   {{0x60c85c07,0x2489f46c,0xb9dc2e1f,0x9f4c003a}},	//   _čemp, gnam_, _ጥር_, _ideæ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [38c40] --, --, --, --, 
   {{0x2488102c,0x25ac0118,0x38c40248,0x00000000}},	//   anam_, řela_, bèrè_, --, 
   {{0x2489f46d,0x96d40124,0xf0380092,0x00000000}},	//   bnam_, _усқә, _በምርም, --, 
   {{0x24886a9b,0x91d821f2,0x20c400ef,0x409001b9}},	//   cnam_, _प्रै, _aķis_, وللر, 
   {{0x59c800bc,0x00000000,0x00000000,0x00000000}},	//   रशार, --, --, --, 
   {{0x6b841aff,0xccf80640,0x3e8400a7,0xef240092}},	//   _žigo, аћи_, ойчо_, _ሰውየው, 
   {{0x6a64004e,0x00000000,0x00000000,0x00000000}},	//   _sòfo, --, --, --, 
   {{0xa3b00807,0x00000000,0x00000000,0x00000000}},	//   टेक_, --, --, --, 
   {{0xfbcc0131,0x3e68168c,0xca25f46e,0x9ad8004b}},	//   ختى_, _søte_, офни, یدیځ_, 
   {{0x24889a4d,0xc87c002f,0x53d800cd,0x00000000}},	//   znam_, wiß_, युतश, --, 
   {{0x2489f46f,0xba701c62,0x2bac032c,0x2f2401e1}},	//   ynam_, بايت, _चरवा, bégò_, 
   {{0x0b45f470,0x6a6400cf,0x4e14012c,0xc8780798}},	//   _мнен, _tòfo, प्रै_, рџо_, 
   {{0xddc00139,0x24883493,0xc87c002f,0x00000000}},	//   _kolş, vnam_, riß_, --, 
   {{0x24880649,0x38c40100,0x91d80456,0x00000000}},	//   wnam_, tèrè_, _प्लै, --, 
   {{0x64c466c0,0x6b6001e1,0xd8f400f1,0x00000000}},	//   वदेश, _fágú, _فزيک, --, 
   {{0x9ba075de,0x82e40327,0xa6f4022e,0x00000000}},	//   _تەۋى, _སྦུའ, _езиш, --, 
   {{0x2489f471,0x324c0092,0x00000000,0x00000000}},	// [38c50] rnam_, _በማምጣ, --, --, 
   {{0x2489f472,0x02a4187f,0x00000000,0x00000000}},	//   snam_, ірам, --, --, 
   {{0x1fa80116,0x6b8400ef,0x00000000,0x00000000}},	//   әкли_, _žigl, --, --, 
   {{0x24880548,0xb5a401af,0x00000000,0x00000000}},	//   qnam_, _юрый, --, --, 
   {{0xddc1f473,0xdee40395,0x733800c0,0x00000000}},	//   _bolş, чоли, _дзяр_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xcee80014,0x81740150,0x00000000,0x00000000}},	//   _گرٲن_, _ﺼﺒﻐﺔ_, --, --, 
   {{0xa3bc0316,0x99840093,0x6f0401ab,0x00000000}},	//   ेखि_, pelū_, àict, --, 
   {{0xddc00139,0x00000000,0x00000000,0x00000000}},	//   _golş, --, --, --, 
   {{0xd944016a,0x98a45e2d,0x18a400ee,0x38040107}},	//   чени, зине, занм, монҳ, 
   {{0xa3bc0562,0xdc0401ec,0x660003b2,0x00000000}},	//   ेखा_, _ءساۋ, ólkn, --, 
   {{0x9f64020c,0x44f4003d,0x00000000,0x00000000}},	//   ètèr_, eħ_, --, --, 
   {{0x7d0001f5,0x35c401f0,0x69080162,0x3c94009f}},	//   orns, ҷаҳҳ, ðsdø, _اَچج_, 
   {{0xceb0025f,0x44f4003d,0x2d9820e4,0xb4040137}},	//   גים_, għ_, _øret_, мүнд, 
   {{0x8c440213,0x00000000,0x00000000,0x00000000}},	//   toşə, --, --, --, 
   {{0x42c400ee,0xe3b001d3,0xd264004e,0x00000000}},	// [38c60] згун_, ہرے_, пкай, --, 
   {{0x1ddc00cd,0x00000000,0x00000000,0x00000000}},	//   नुमत, --, --, --, 
   {{0xa5c00022,0xd02400ee,0x8658011a,0x00000000}},	//   _аҩре, змей, _הדיי, --, 
   {{0xd009f474,0x942401af,0x6b843858,0x00e53ecd}},	//   седе_, _эмме, _žigm, ستمی, 
   {{0x7d00cac9,0x384c001f,0xddc1f475,0x8bc400d1}},	//   erns, _እየተጠ, _polş, үсид, 
   {{0xa3b002e5,0xddc0013d,0x4718010f,0xff24075e}},	//   _ओरत_, _qolş, מונג, سكىي_, 
   {{0xf984007b,0x2a7c0f85,0x0c84004e,0x00000000}},	//   _أب_, _rmvb_, зыпм, --, 
   {{0x46201ef7,0x00000000,0x00000000,0x00000000}},	//   _ትዮጵያ, --, --, --, 
   {{0x0ae8007b,0x7d0001c3,0xfba4009d,0x00000000}},	//   حربي_, arns, зтэй_, --, 
   {{0xa3b107c7,0x68fc01ed,0xb7ec03d4,0x0374011a}},	//   टेट_, árdo, _কাষত_, פתית_, 
   {{0xbc6442c2,0xe89402d5,0x2d9800e4,0xcda8009f}},	//   زمین_, дань, _âre_, _اهاه_, 
   {{0x27ec1709,0xe1740240,0x00000000,0x00000000}},	//   úen_, _ረኸብኩ_, --, --, 
   {{0xb8d0f712,0xbb40033a,0x44f40327,0x00000000}},	//   _जी_, _пецк, wħ_, --, 
   {{0x26c4014a,0x2be40154,0x00000000,0x00000000}},	//   ölo_, _গায়ে_, --, --, 
   {{0x494405f5,0x04640220,0x00000000,0x00000000}},	//   _хэлб, птам, --, --, 
   {{0xc7c5f476,0x3e694e5f,0x00000000,0x00000000}},	//   _эски, _møta_, --, --, 
   {{0x3e6806ea,0xf41c03d4,0x00000000,0x00000000}},	// [38c70] _løta_, _পোহৰ_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x24580251,0x673c03cd,0xd49801f0,0x0584010a}},	//   _дань_, lvsj, ёрӣ_, _хупм, 
   {{0xdea0036b,0x00000000,0x00000000,0x00000000}},	//   چیری, --, --, --, 
   {{0x2484020c,0xa3b000af,0x69d8032e,0x41e400c0}},	//   élmu_, _ओरि_, _ofve, _ніва, 
   {{0x3e6806ea,0x64a4035b,0x00000000,0x00000000}},	//   _bøta_, _хаҭа, --, --, 
   {{0x5ff40314,0x388801ed,0xb378001f,0x00000000}},	//   _озву, lőre_, ሪያውን_, --, 
   {{0x69d9f477,0x6aa829d0,0xa3b000c5,0x61e401ab}},	//   _afve, eldf, _ओरा_, lbhl, 
   {{0x6574003e,0xb7ec03d4,0x378401e1,0xa3b001f9}},	//   hzzh, _কালত_, _oódẹ_, टेच_, 
   {{0x9f4c01c7,0x61e400ae,0x4aa400c7,0x00000000}},	//   _leeë_, nbhl, мкын_, --, 
   {{0x3e6806ea,0x61e40afe,0x6cd001ec,0x00000000}},	//   _gøta_, ibhl, _ﻗﺎﺳﻴ, --, 
   {{0x95e41152,0x61e412ef,0xd7c8007b,0x00000000}},	//   कर्ट_, hbhl, توحه_, --, 
   {{0x7bc9514d,0x2d9820e4,0x00000000,0x00000000}},	//   _iggu, _ører_, --, --, 
   {{0x753c012c,0x32e401e1,0xab640006,0x388800e5}},	//   tvrz, _léyò_, _явіл, dőre_, 
   {{0x79a400cf,0x543401f4,0x00000000,0x00000000}},	//   _эрде, мхау, --, --, 
   {{0x61e4009a,0x00000000,0x00000000,0x00000000}},	//   ebhl, --, --, --, 
   {{0x78a5f478,0x00000000,0x00000000,0x00000000}},	// [38c80] _ikiv, --, --, --, 
   {{0x99840118,0xf6b400db,0x291801ab,0x00000000}},	//   nelů_, _سۅزج, àrag_, --, 
   {{0x85b9f479,0x7bc9f47a,0xf55c0205,0x00000000}},	//   _واپس_, _oggu, çüğe_, --, 
   {{0x7bc8034c,0xa0880220,0x61e436f4,0xc0e000c0}},	//   _nggu, псіз_, abhl, тоцк, 
   {{0x2ab00109,0x35a4000d,0x00000000,0x00000000}},	//   hàba_, _खँड़, --, --, 
   {{0xa3bc03f3,0x7bc9f47b,0x00000000,0x00000000}},	//   ेखर_, _aggu, --, --, 
   {{0x78a40083,0xfd0c0451,0x998400bc,0xdc385043}},	//   _okiv, لجي_, delů_, _açıb, 
   {{0x78a44539,0x4ba400cf,0x00000000,0x00000000}},	//   _nkiv, мөлү_, --, --, 
   {{0xdeb80092,0x00000000,0x00000000,0x00000000}},	//   _ሲገኝ_, --, --, --, 
   {{0xf8cc0b9c,0x7bc82252,0xc98433d2,0x0e683c19}},	//   _संशय, _eggu, думи, _بصري_, 
   {{0x388800e5,0x00000000,0x00000000,0x00000000}},	//   zőre_, --, --, --, 
   {{0x6aa802d0,0x5ee000eb,0x00000000,0x00000000}},	//   sldf, _নিতে, --, --, 
   {{0x78a40010,0xbb80004b,0x6a6401e1,0x99840118}},	//   _dkiv, _ټلوي, _lòfi, belů_, 
   {{0x78a5f47c,0x388801ed,0x7b8400f7,0x056806ed}},	//   _ekiv, vőre_, _تامە, ојби_, 
   {{0xda647286,0xc7640372,0x6d5c01ab,0x00000000}},	//   _ثاني, ساڭى, _àrad, --, 
   {{0xf9900375,0x78f8011a,0x388800e5,0x00000000}},	//   _שרק_, _ולהפ, tőre_, --, 
   {{0x290df47d,0x4e0df47e,0x6574003e,0xa2b40063}},	// [38c90] luda_, _सांई_, szzh, ебач, 
   {{0xa5e40131,0x61e400a3,0x00000000,0x00000000}},	//   _سۈرە_, ubhl, --, --, 
   {{0x69dc0008,0x45a00228,0x388801d3,0x61e41cf8}},	//   ðrey, _شەرك, sőre_, rbhl, 
   {{0x5f95f47f,0xe3e80135,0xc4440014,0xdfd43fe9}},	//   ниет, _འབྲང, _تیرن_, ходы, 
   {{0x645df480,0x02c00724,0x44380789,0x00000000}},	//   _iosi, _җиңү, mdq_, --, 
   {{0x290dc74a,0x645df481,0x5ee004c5,0x7bc805b1}},	//   kuda_, _hosi, _নিদে, _sggu, 
   {{0x645df482,0x290df483,0xdca4ba05,0x6285f484}},	//   _kosi, juda_, наки, miho, 
   {{0x645df485,0x6285f486,0x290df487,0x15c40131}},	//   _josi, liho, duda_, ﯩﺮﯨﻐ, 
   {{0x645c9d40,0x99840316,0x0c214a40,0x7ed401d5}},	//   _mosi, telů_, умын, _آزرا, 
   {{0x6285f488,0x78a438aa,0x60c9f489,0x290df48a}},	//   niho, _skiv, _hiem, fuda_, 
   {{0x290c9022,0x60c9f48b,0x645df48c,0xee840153}},	//   guda_, _kiem, _oosi, _рыто, 
   {{0x60c802d5,0x9b581c3e,0x7ae80218,0x7bc9f48d}},	//   _jiem, _ниет_, _twgt, _uggu, 
   {{0x60c9f48e,0x6285f48f,0x7c3806be,0x00000000}},	//   _miem, kiho, mdur, --, 
   {{0x60c9f490,0x290df491,0x645c03c1,0xcb10011a}},	//   _liem, buda_, _aosi, _עלו_, 
   {{0xd9440372,0xdec002d3,0x290c2ca8,0x1868014b}},	//   _чейи, _ትኹን_, cuda_, _наки_, 
   {{0x60c9f492,0x78a53cfa,0x57e8036b,0x6b8400f3}},	//   _niem, _ukiv, _эдим_, _žigi, 
   {{0x645de240,0x6a64067c,0x7c380005,0xeac80022}},	// [38ca0] _dosi, _sòfi, idur, _sỹi_, 
   {{0x6285f493,0x60c8049b,0x6a640241,0xddd40432}},	//   giho, _aiem, _pòfi, _ýaňy, 
   {{0x60c804cc,0x7c3804fb,0xfbdc0b4c,0x00000000}},	//   _biem, kdur, नडाम, --, 
   {{0x60c9f494,0x645c00b4,0x6284017a,0x7c38054e}},	//   _ciem, _gosi, aiho, jdur, 
   {{0x60c96e4e,0x6285f495,0x8e8408a2,0x290df496}},	//   _diem, biho, нгде, zuda_, 
   {{0x645df497,0x290df498,0x7c38003a,0x6285f499}},	//   _zosi, yuda_, edur, ciho, 
   {{0x60c808f5,0x645df49a,0x290c0213,0x9e6400d1}},	//   _fiem, _yosi, xuda_, خانن, 
   {{0x8fa46b1c,0x7c39649a,0x60c80007,0x290d00a2}},	//   _забе, gdur, _giem, vuda_, 
   {{0x614c001f,0x290df49b,0xdf140354,0x00000000}},	//   _በጋዜጣ, wuda_, _аьхь, --, 
   {{0x60c9f49c,0x290df49d,0x7c39f49e,0xbea18e4a}},	//   _ziem, tuda_, adur, _баук, 
   {{0x60c80399,0x7c380169,0x6448032e,0x00000000}},	//   _yiem, bdur, _óeig, --, 
   {{0x628419ab,0x290df49f,0xa3b005d7,0x9f5800e4}},	//   ziho, ruda_, _ओरल_, _ÿsã_, 
   {{0x290df4a0,0xe63402d3,0x6d5cf62f,0x00000000}},	//   suda_, _ብምግላ, _àrab, --, 
   {{0x62840789,0x290c0205,0xe7a4084d,0x00000000}},	//   xiho, puda_, _गुणप, --, 
   {{0x628402f0,0x248402e3,0x6a640100,0x2418373e}},	//   viho, ịmma_, _sòfw, мовы_, 
   {{0x645c833b,0x628501c6,0xf4840137,0xb8080220}},	//   _qosi, wiho, гуун, _كيىم_, 
   {{0xe4ec09d9,0x645c07d6,0x60c00214,0xe1200327}},	// [38cb0] _जबकि_, _vosi, _èlmi, ཿསྐད_, 
   {{0x60c9f4a1,0x645df4a2,0x7c39f4a3,0xf48401e0}},	//   _siem, _wosi, zdur, _ҡуян, 
   {{0x60c9f4a4,0x6285f4a5,0x645df4a6,0x7c3927bf}},	//   _piem, riho, _tosi, ydur, 
   {{0x6285f4a7,0x645df4a8,0xf1a40228,0x7c380213}},	//   siho, _uosi, урун, xdur, 
   {{0x6285f4a9,0x60c9f4aa,0xf1e8002e,0x00000000}},	//   piho, _viem, _s斡ey_, --, 
   {{0x60c9f4ab,0x7c385136,0x00000000,0x00000000}},	//   _wiem, wdur, --, --, 
   {{0x60c9f4ac,0x7c39f4ad,0xe06003e6,0xa0c401ee}},	//   _tiem, tdur, _پێشی, _ашаһ, 
   {{0x6f0446aa,0x60c8017a,0x1c442d29,0x8cb40014}},	//   šica, _uiem, тним, نگنس_, 
   {{0xfb8003e6,0xab1801c6,0x00000000,0x00000000}},	//   دگای, нцэх_, --, --, 
   {{0x7c39b264,0x00000000,0x00000000,0x00000000}},	//   sdur, --, --, --, 
   {{0xad242002,0xaaf80086,0x7cc000e5,0x9d5400ae}},	//   _مىلى, òbòñ_, _lőri, _جنات, 
   {{0x7c540451,0xac940139,0x18680138,0x00000000}},	//   _ڪلچر_, _йахш, фами_, --, 
   {{0xb3c03166,0xac740066,0x68e4013a,0xf3f000fe}},	//   _शृंख, _حالش, _čide, _ছালৰ_, 
   {{0x7af8143a,0x6d5c08c2,0x7bd80009,0x00000000}},	//   msut, _àrac, lcuu, --, 
   {{0x7af9f4ae,0x6ef800d2,0x00000000,0x00000000}},	//   lsut, _kúbá, --, --, 
   {{0xb4ac0a59,0x18a5f4af,0xb7ec0183,0x7af80254}},	//   गते_, _шайм, _কাকত_, osut, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [38cc0] --, --, --, --, 
   {{0x7af9f4b0,0x91e5f4b1,0x7bd8022f,0x37a800fe}},	//   isut, тоже, hcuu, _গণপৰ, 
   {{0x3861f4b2,0x6e3d12c0,0x5ee00f22,0x00000000}},	//   _koir_, _órbi, _নিষে, --, 
   {{0x7af9f4b3,0x00000000,0x00000000,0x00000000}},	//   ksut, --, --, --, 
   {{0x38600363,0xc7d400d9,0x6e480139,0x00000000}},	//   _moir_, דוני_, нҗаб_, --, 
   {{0x3861f4b4,0x7af92f98,0x877800d9,0x00000000}},	//   _loir_, dsut, ואני, --, 
   {{0x66002880,0x1ea81541,0x0dc002d3,0x38600363}},	//   ólki, راهي_, ትርፎ_, _ooir_, 
   {{0x3861f4b5,0x2900010f,0x987c0139,0x5ee003d4}},	//   _noir_, _ĉia_, _oçın_, _নিৰূ, 
   {{0x7af9f4b6,0xe3e8010f,0x00000000,0x00000000}},	//   gsut, ײַפֿ, --, --, 
   {{0x79780084,0x3860464c,0x18b001e0,0x7bd80009}},	//   _ṅwal, _aoir_, ҙҙыр, acuu, 
   {{0xd6e0febc,0x7af8b800,0x38608133,0x987c029f}},	//   _বিষয, asut, _boir_, _açın_, 
   {{0x3861f4b7,0xb4ac53b7,0x7bd80ba7,0x4b500014}},	//   _coir_, गतो_, ccuu, _نێبر, 
   {{0x3860036b,0x00000000,0x00000000,0x00000000}},	//   _doir_, --, --, --, 
   {{0x05740150,0x00000000,0x00000000,0x00000000}},	//   نازد, --, --, --, 
   {{0x386001ab,0x75887b0a,0x00000000,0x00000000}},	//   _foir_, вств_, --, --, 
   {{0x58fc025c,0x386003d5,0x2ca4000f,0x00000000}},	//   _དྷིས_, _goir_, nomd_, --, 
   {{0x27f8083a,0x1da8012d,0x00000000,0x00000000}},	// [38cd0] masn_, _चुनत, --, --, 
   {{0x5ee00154,0x2a6c01ab,0x3860022e,0xb27401ec}},	//   _নিলে, nkdb_, _zoir_, алуш, 
   {{0xdfd1f4b8,0xc0bc02d3,0x2ca4002d,0xf2c51af5}},	//   ميا_, _ስሙር_, komd_, рстн, 
   {{0x6ef802e3,0x5ff42f26,0x00000000,0x00000000}},	//   _ụbar, узду, --, --, 
   {{0x24881730,0x6f0400f3,0x00000000,0x00000000}},	//   miam_, šicn, --, --, 
   {{0x6d440053,0x2489f4b9,0x9410016b,0xee380212}},	//   āian, liam_, koyɛ_, кні_, 
   {{0x23680205,0x00000000,0x00000000,0x00000000}},	//   lyaj_, --, --, --, 
   {{0x2489f4ba,0x7af9f4bb,0xefc00023,0x00000000}},	//   niam_, tsut, ትውዎ_, --, 
   {{0x7af80eda,0x61f401d5,0x5d5402dd,0x38600042}},	//   usut, _kezl, _әкет, _roir_, 
   {{0x3861f4bc,0x7af9f4bd,0x2489f4be,0x7bd9f4bf}},	//   _soir_, rsut, hiam_, scuu, 
   {{0x7af80680,0xae44021a,0x2489f4c0,0x61f4010f}},	//   ssut, _خپلو, kiam_, _mezl, 
   {{0x05a40c2e,0x236803ee,0x24880109,0x7af9f4c1}},	//   _गड़ब, kyaj_, jiam_, psut, 
   {{0x38609083,0x2489f4c2,0x7af80227,0x60d4867c}},	//   _voir_, diam_, qsut, _luzm, 
   {{0x53a4136b,0x61f5f4c3,0x2a6c0784,0x040800fe}},	//   ҳабб, _nezl, ckdb_, হ্মী_, 
   {{0x38600e89,0x3b1c06be,0x00000000,0x00000000}},	//   _toir_, ltuq_, --, --, 
   {{0x2489f4c4,0x2bc001ad,0xb35800f1,0xe8740228}},	//   giam_, शेवा, پیسا_, _ۅنۉگ, 
   {{0x60d401c4,0xd78800ec,0x10a400d1,0xdb080166}},	// [38ce0] _auzm, _سندو_, ңизн, _önäm, 
   {{0x3b1c0d04,0x60d51eff,0x61f40200,0x00000000}},	//   ituq_, _buzm, _cezl, --, 
   {{0x61f40276,0x6a64007f,0x25a40e78,0x2489f4c5}},	//   _dezl, _kòfr, üllt_, biam_, 
   {{0x2489f4c6,0x3b1c0cfe,0x60d40226,0x81740150}},	//   ciam_, ktuq_, _duzm, _ﹼﺒﻌﺔ_, 
   {{0x4365f4c7,0x2ca405be,0x61f40205,0x00000000}},	//   _баян_, vomd_, _fezl, --, 
   {{0x33200227,0xbea11cbc,0x61f400a2,0x6f0416a3}},	//   mtix_, бачк, _gezl, šico, 
   {{0x7d213dd1,0x202408a7,0xc0e1f4c8,0x20c800f7}},	//   مفون, úsið_, _госк, ربۅي_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3321f4c9,0x3a240327,0xc43800d9,0x00000000}},	//   ntix_, _bbnp_, תתפי, --, 
   {{0x2bc01788,0xc330025f,0x24880120,0x2ca401f5}},	//   शेषा, צות_, ziam_, somd_, 
   {{0x33200227,0xc27800c8,0x6a640100,0x24880134}},	//   htix_, גריי, _bòfr, yiam_, 
   {{0x236804ba,0x24880381,0x6fdc00bc,0x00000000}},	//   yyaj_, xiam_, _फलफू, --, 
   {{0x2489f4ca,0x394405e4,0x978401e0,0x6d480055}},	//   viam_, _erns_, атрҙ, _hrda, 
   {{0xbb3804ac,0x2488068f,0xe98401ec,0x36d44411}},	//   _רעגי, wiam_, _پاتۋ, сорр, 
   {{0x24880de4,0x00000000,0x00000000,0x00000000}},	//   tiam_, --, --, --, 
   {{0x6d48bc55,0x60d408a4,0x6d580007,0x61f5f4cb}},	//   _mrda, _ruzm, ixva, _sezl, 
   {{0x2489c1e0,0x60d40139,0x621800dc,0x290c022e}},	// [38cf0] riam_, _suzm, _पादौ_, lrda_, 
   {{0x6d49f4cc,0x2489f4cd,0x672cb114,0x236802bd}},	//   _orda, siam_, _ipaj, ryaj_, 
   {{0x24881730,0x66001f60,0x61f41462,0x00000000}},	//   piam_, ólku, _vezl, --, 
   {{0x290c00d7,0x00000000,0x00000000,0x00000000}},	//   irda_, --, --, --, 
   {{0x6d49f4ce,0x61f4a67c,0x6e280175,0x2c78002e}},	//   _arda, _tezl, _bbdb, _médd_, 
   {{0x3b1c0d04,0x9f480086,0x6d480841,0x60d41ba4}},	//   vtuq_, ûañ_, _brda, _tuzm, 
   {{0x6e28010a,0x99d40214,0x5ff401f4,0x00000000}},	//   _dbdb, یتدا, _взбу, --, 
   {{0x3b1c0cfe,0x6d4805da,0x3e68022c,0x9b0410cf}},	//   ttuq_, _drda, _møti_, азид, 
   {{0xaae400f9,0x290cdb58,0x6d484ed4,0x6d5c00a3}},	//   یسیو, erda_, _erda, _àran, 
   {{0xea24110e,0xab283592,0x92a4012d,0x00000000}},	//   ẹ́rẹ, اسيل_, _gałą, --, 
   {{0x672df4cf,0x3b1c0309,0xdd9002f2,0x7cc000e5}},	//   _apaj, stuq_, _بوا_, _bőrt, 
   {{0x3ea5f4d0,0x92a40034,0x660401f7,0x98a4de2f}},	//   lont_, _załą, _adhk, риме, 
   {{0x290df4d1,0x3b1c3209,0xa3d80cb2,0x3a2400fd}},	//   arda_, qtuq_, ाशन_, _белү_, 
   {{0x4b78b4a1,0x3ea5f4d2,0x290df4d3,0xd945f4d4}},	//   _באנו, nont_, brda_, _веки, 
   {{0x39440204,0xc6c00006,0x12c80ef6,0x00000000}},	//   _urns_, ійск, _ﺑﻮﻻﺭ, --, 
   {{0x3ea5f4d5,0x5748059f,0x33200135,0x45a00137}},	//   hont_, _азим_, ttix_, تەپك, 
   {{0x3ea5d2b4,0xd25007c0,0x083800df,0x00000000}},	// [38d00] kont_, ينر_, _יעקל, --, 
   {{0x3ea40dd4,0x3e680174,0xd5b8013d,0x00000000}},	//   jont_, _føti_, _үсү_, --, 
   {{0x3320025c,0x95980262,0x00000000,0x00000000}},	//   stix_, _штиу_, --, --, 
   {{0x09d00316,0x2c788024,0xcf44447e,0xd00992b3}},	//   _सल्य, _xédd_, иней, теде_, 
   {{0x3ea5f4d6,0x6d4805ce,0x3fc804fb,0x92a40210}},	//   font_, _srda, ندهی_, _pałą, 
   {{0x3ea40489,0x290c00ee,0xd0100050,0x00000000}},	//   gont_, yrda_, _ڈلس_, --, 
   {{0xd01000aa,0x00000000,0x00000000,0x00000000}},	//   _ولس_, --, --, --, 
   {{0xa3d80d2c,0x290c036b,0x20540276,0x00000000}},	//   ाशय_, vrda_, _лтур, --, 
   {{0x3ea4a4fd,0xcfa80244,0xf8d01a47,0x00000000}},	//   bont_, _شارم_, _संजय, --, 
   {{0x3ea41c1d,0x2c78002e,0x6d480139,0x2b400171}},	//   cont_, _sédd_, _trda, _šics_, 
   {{0xfce185fb,0x6d4878f2,0x67d45e2d,0x02b408a8}},	//   _дохо, _urda, йону, שליך_, 
   {{0x2c7801e1,0x9f4c003a,0x68e80175,0x4c680166}},	//   _béde_, _ideò_, rpdd, _шиен_, 
   {{0xb71461ff,0x290c44f0,0x67d400d1,0x3e6803b2}},	//   одящ, srda_, _қопу, _søti_, 
   {{0xf8b89bb1,0xe944036b,0xaa2c005b,0xc9840214}},	//   лөө_, _هربی, äjää_, _پشتي, 
   {{0x3ab804ae,0xf8d01100,0x00000000,0x00000000}},	//   _שמונ, _संचय, --, --, 
   {{0x3ea5f4d7,0xfa200003,0xf7a8063f,0x054401c6}},	//   zont_, _འཁོན_, ọmịk_, гүүл_, 
   {{0x4ab8007d,0x672d774c,0x73d801a9,0x00000000}},	// [38d10] _उठाव, _upaj, рдур_, --, 
   {{0xa4f8583d,0xa158009b,0x00000000,0x00000000}},	//   _مکرر_, лазу_, --, --, 
   {{0x3ea5f4d8,0x24180139,0x32c8005b,0xc0580006}},	//   vont_, _йоны_, рыто_, кід_, 
   {{0x65600158,0x3ea5f4d9,0x6aa803cb,0x00000000}},	//   ølhu, wont_, hodf, --, 
   {{0x9f4c003a,0x3ea5f4da,0x491400cd,0x00000000}},	//   _adeò_, tont_, पूतो_, --, 
   {{0x3ea40165,0xa6a001ec,0xdc000562,0x61e806be}},	//   uont_, _ﺍﻳﻪﻝ_, ोल्ड_, _şelf, 
   {{0x3ea5f4db,0xceb47400,0x4429f4dc,0x1ddc00cd}},	//   ront_, сәт_, _kbc_, नुगत, 
   {{0x4429f4dd,0x00000000,0x00000000,0x00000000}},	//   _jbc_, --, --, --, 
   {{0x4429f4de,0x5ee0045e,0x3ea5f4df,0x1868023b}},	//   _mbc_, _নিকে, pont_, ҳани_, 
   {{0xfc3c038e,0x44280c67,0x408416c3,0xfe7034f6}},	//   ží_, _lbc_, _суҳб, _بدر_, 
   {{0x1869f4e0,0x1989589d,0x9f4c0166,0x207800df}},	//   гани_, убни_, _ideñ_, ָאָא, 
   {{0x4429bd86,0x00000000,0x00000000,0x00000000}},	//   _nbc_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x44282734,0x00000000,0x00000000,0x00000000}},	//   _abc_, --, --, --, 
   {{0xceb06da4,0x4429f4e1,0xd9c400bd,0xd5b1f4e2}},	//   פיל_, _bbc_, _শ্রম, سفر_, 
   {{0x4428045a,0xf8d000cd,0x00000000,0x00000000}},	//   _cbc_, _सूचय, --, --, 
   {{0x04540597,0x00000000,0x00000000,0x00000000}},	// [38d20] حلقة_, --, --, --, 
   {{0x6f040313,0x644803f2,0x8ee400fe,0x9594009b}},	//   šick, _óein, _নিলগ, _грмљ, 
   {{0x4429f4e3,0x47d00150,0x236c0003,0x35c40107}},	//   _fbc_, _بيۋر, _żejt_, _фанҳ, 
   {{0x7c28010a,0x00000000,0x00000000,0x00000000}},	//   _nbgr, --, --, --, 
   {{0xb4c4068f,0x3e68022c,0xe1f00131,0x00000000}},	//   एगी_, _løtu_, سسە_, --, 
   {{0xbea0e2de,0x44280099,0x7c29f4e4,0x5ee00154}},	//   пачк, _zbc_, _abgr, _নিখে, 
   {{0xcd29f4e5,0x0ca80c69,0x2d99f4e6,0xa2a4084d}},	//   استن_, лтии_, _žreb_, कवर्, 
   {{0xfa20025c,0xc4d0008d,0xfd0df4e7,0x83a4000d}},	//   _འཁུན_, הגה_, رجى_, _कुँआ, 
   {{0x9e6401ed,0x8aa4004e,0xf1dc07b7,0x00000000}},	//   _ڈالن, йрод, _बलान, --, 
   {{0x9e640491,0xc3300302,0xbf10178c,0xc27800df}},	//   _والن, לוח_, _رومب, ָרטי, 
   {{0xdde80633,0x00000000,0x00000000,0x00000000}},	//   _خرقه_, --, --, --, 
   {{0xc19804ac,0x6aa800e5,0xccc401f4,0x00000000}},	//   רשטי, sodf, _убей, --, 
   {{0x6f040588,0x315002d3,0x83a400e1,0x44281587}},	//   áich, _መጋበር, _कुंआ, _rbc_, 
   {{0x4429f4e8,0x69dd3ec2,0xfa3000db,0x00000000}},	//   _sbc_, žreb, _فرىد, --, 
   {{0x3e68022c,0x00000000,0x00000000,0x00000000}},	//   _gøtu_, --, --, --, 
   {{0xe74000a2,0x7ce403e0,0x00000000,0x00000000}},	//   _näçü, _fırf, --, --, 
   {{0x4429f4e9,0x33580276,0x6298002e,0x2c20043e}},	// [38d30] _vbc_, батэ_, éwoo, _यानं_, 
   {{0x442804ce,0xc2e4036b,0x28147aaf,0x6edc0037}},	//   _wbc_, _қўми, _اوکس, _पढ़ु, 
   {{0x26c00472,0x3e69161c,0x41c007f7,0xa3d40137}},	//   _ihho_, _møtt_, वेंस, _монч, 
   {{0x442845a7,0x68e40308,0x3e6806ea,0x248c0139}},	//   _ubc_, _čidl, _løtt_, _öem_, 
   {{0x7ce462c7,0x3494030d,0x00000000,0x00000000}},	//   _kırg, _хаяр, --, --, 
   {{0x63bc005f,0x4cd0015b,0x3e6803cd,0x7c280175}},	//   _izsn, _সবগু, _nøtt_, _sbgr, 
   {{0x3f9c058a,0x44f4007f,0x7cc000e5,0x00000000}},	//   _wxuu_, nŧ_, _bőrp, --, 
   {{0x9b0807d6,0x7ce40139,0x00000000,0x00000000}},	//   аниб_, _lırg, --, --, 
   {{0x5e58221d,0x3e680162,0xfe2400c7,0x4ae000f1}},	//   _پلاس_, _bøtt_, _гьен, وړول, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa3d8483e,0xa2e405ac,0x00000000,0x00000000}},	//   ाशा_, _ফটোখ, --, --, 
   {{0x7c2803ac,0x17c8011c,0x00000000,0x00000000}},	//   _ubgr, игни_, --, --, 
   {{0x3e4c9334,0x3e680162,0x9038008f,0x7ce40205}},	//   _tētē_, _føtt_, בערה, _bırg, 
   {{0x7ce4013d,0xebc000fb,0x00000000,0x00000000}},	//   _cırg, _яҙын, --, --, 
   {{0x63bc06be,0x92d400eb,0x00000000,0x00000000}},	//   _azsn, _সবে_, --, --, 
   {{0x76900241,0x6f0401f1,0xf484158b,0xf1b8031c}},	//   _bóyè, šici, سازی, _ġġ_, 
   {{0x7ce403e0,0x73e40137,0x96b8009b,0x00000000}},	// [38d40] _hırd, _ۉيدۅ, _вуну_, --, 
   {{0x7ce40ab5,0x00000000,0x00000000,0x00000000}},	//   _kırd, --, --, --, 
   {{0xda201094,0x27e4012d,0xd6e000cc,0x00000000}},	//   _मानत_, ślne_, _বিয়প, --, 
   {{0x5ee06569,0x2174009d,0x00000000,0x00000000}},	//   _নিজে, чуур, --, --, 
   {{0x5274013e,0x61e80166,0x00000000,0x00000000}},	//   _дуву, _şele, --, --, 
   {{0x7f440075,0x25ac0311,0x6e0400db,0x00000000}},	//   زلىق_, şele_, سستە, --, 
   {{0x3e680174,0xd0580024,0x00000000,0x00000000}},	//   _røtt_, _краі_, --, --, 
   {{0x2c79ad2a,0x3e69f4ea,0x61e80114,0x00000000}},	//   _béda_, _søtt_, _đeli, --, 
   {{0x7a3c02d5,0x2c78003e,0x4478008f,0xbc6432f7}},	//   kštė, _céda_, ינקע, تمين_, 
   {{0x5ee00f22,0x7ce403e0,0x00000000,0x00000000}},	//   _নিচে, _bırd, --, --, 
   {{0x7ce42b24,0xdc8002d3,0x3e6803b2,0x41d800df}},	//   _cırd, _ክጅምር_, _vøtt_, יחיס, 
   {{0x7ce408a9,0xbdc000d1,0xb4c419cc,0x00000000}},	//   _dırd, _غەيۋ, एगो_, --, 
   {{0x9f5c0066,0x3e680162,0xc7b80818,0xcf2c0023}},	//   gawè_, _tøtt_, рён_, _ሰልፊታ, 
   {{0x7ce41ea0,0x7a3c0064,0x00000000,0x00000000}},	//   _qırg, gštė, --, --, 
   {{0x04640d44,0x2458005b,0x7ce4236c,0x91a801f9}},	//   отам, бавь_, _gırd, _जुलै, 
   {{0x6e38014f,0x224c062d,0x00000000,0x00000000}},	//   hevb, _şek_, --, --, 
   {{0xa2d5f4eb,0xc7c41def,0x245401d3,0x7ce40139}},	// [38d50] سيات, _ьски, _ہندس, _tırg, 
   {{0x6e3878e0,0xd4980022,0xe748014b,0x00000000}},	//   jevb, арӡ_, _кӯҳе_, --, 
   {{0x7ce5ef02,0x9f5c0066,0xe048036b,0x5db802dd}},	//   _xırd, mawé_, یشچه_, _ﺸﺭﻋﻴ, 
   {{0x9f5c065c,0xf1a4084c,0xa4380114,0x00000000}},	//   lawé_, фрун, _узму_, --, 
   {{0x24840214,0x63bc00ef,0x00000000,0x00000000}},	//   èlmu_, _uzsn, --, --, 
   {{0x69d80007,0x9f5c0066,0x9d44010b,0xc290030f}},	//   _ngve, nawé_, зекд, _غیاب, 
   {{0x61e40597,0x2c7804fb,0x00000000,0x00000000}},	//   mchl, _séda_, --, --, 
   {{0x61e48ccf,0x718401d9,0x00000000,0x00000000}},	//   lchl, _کٔہن, --, --, 
   {{0x61e43e7c,0x7ce403e0,0x00000000,0x00000000}},	//   ochl, _sırd, --, --, 
   {{0x61e5f4ec,0x7e740116,0xdc800023,0x5984009b}},	//   nchl, _بارئ, _ክጅመር_, злоб, 
   {{0x61e5f4ed,0x2c780687,0xf2d4011a,0x7ce40bb9}},	//   ichl, _wéda_, ועץ_, _qırd, 
   {{0x201df4ee,0x61e400ae,0x069001ef,0x00000000}},	//   ngwi_, hchl, _šípů_, --, 
   {{0x31b80846,0x7ce40205,0x00000000,0x00000000}},	//   _अर्ध, _dıre, --, --, 
   {{0x9f5c093a,0xab640212,0x7ae85e71,0x61e402f0}},	//   gawé_, _ювіл, _itgt, jchl, 
   {{0x491002f8,0x61e402f0,0xc0bc0023,0x00000000}},	//   _थियो_, dchl, ስምስ_, --, 
   {{0x7ce403e0,0x00000000,0x00000000,0x00000000}},	//   _gıre, --, --, --, 
   {{0xb2440184,0x69d802d0,0x5efc00cd,0x38a40139}},	// [38d60] ммаһ, _ygve, रीम्_, gıre_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x464405f5,0x85f402e4,0x4638008f,0xd548007b}},	//   _эзэн_, _מציע_, _פעטע, _الجو_, 
   {{0xcf2c044e,0x6d5c0013,0x61e47d20,0x00000000}},	//   _ሰልፍታ, _àrai, achl, --, 
   {{0x93944028,0x6e3802d0,0xad9c0419,0x00000000}},	//   _رجحا, tevb, _zdĺh, --, 
   {{0xf8c892c2,0x0ca800d1,0x00000000,0x00000000}},	//   रगुप, әтки_, --, --, 
   {{0x4278008f,0x7ae806be,0x00000000,0x00000000}},	//   _פאלג, _atgt, --, --, 
   {{0xc1980302,0x016002a9,0x7ce40205,0xb7bc01e1}},	//   _השלי, _яксо, _bırb, _ẹ̀wo, 
   {{0x4f65f4ef,0xb5c4009e,0x4f080961,0x00000000}},	//   _عارف, ্ডিচ, _ынан_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa804049e,0x27ec00c7,0x00000000,0x00000000}},	//   үзүл, ñeno_, --, --, 
   {{0x61e402f0,0x00000000,0x00000000,0x00000000}},	//   zchl, --, --, --, 
   {{0x61e5f4f0,0x69d80109,0x996800d0,0xaa5c0064}},	//   ychl, _tgve, hŕňa_, _велi, 
   {{0x090401b9,0x00000000,0x00000000,0x00000000}},	//   _ечим, --, --, --, 
   {{0x7ab80375,0x61e4022e,0xda646a87,0x00000000}},	//   _הצגו, vchl, _تاني, --, 
   {{0xf1b0033f,0x61e4015d,0x00000000,0x00000000}},	//   _झड़न, wchl, --, --, 
   {{0xc76402dd,0x27e9f4f1,0x7ce40790,0x00000000}},	// [38d70] _ءابى, _ifan_, _kırc, --, 
   {{0x61e4039a,0x1eb8031c,0x228c03b9,0x00000000}},	//   uchl, _བེེཌ, _kökə_, --, 
   {{0x250824c5,0x61e5f4f2,0x5f9400e5,0x00000000}},	//   _برخی_, rchl, ڈلائ, --, 
   {{0xdfd1bd7f,0x61e4dece,0x5f781df2,0x00cc0075}},	//   نيا_, schl, يماس_, _ﺑﺎﺷﻘ, 
   {{0xd1f00020,0x7a0c013f,0x443968fc,0x00000000}},	//   _ልጆች_, _wɔtɔ, meq_, --, 
   {{0x44380eda,0x7a0c013f,0x6114009b,0x00000000}},	//   leq_, _tɔtɔ, _одгу, --, 
   {{0xdd9000dd,0x27e8008c,0xdca5f4f3,0x31340b00}},	//   کوں_, _ofan_, маки, _перр, 
   {{0x44380680,0x27e807ab,0x9870005f,0xc5bc0154}},	//   neq_, _nfan_, kšā_, _আলাপ, 
   {{0x200df4f4,0xddc1679c,0x3ab00ce8,0x00000000}},	//   _idei_, _bolţ, нәкт, --, 
   {{0x27e9f4f5,0xddc00311,0x4439f4f6,0x7ce40205}},	//   _afan_, _colţ, heq_, _cırc, 
   {{0x19c44e0c,0x4439f4f7,0x18a5f4f8,0xae040220}},	//   ьбом, keq_, данм, _سونى, 
   {{0x27e801ab,0x6d4402b5,0x44380200,0x00000000}},	//   _cfan_, āiat, jeq_, --, 
   {{0xac184d15,0x7c39f4f9,0xddc00e39,0x987000e2}},	//   _хочу_, meur, _malō, gšā_, 
   {{0x7c39f4fa,0x27e8c53b,0xf544009d,0x00000000}},	//   leur, _efan_, ндгү, --, 
   {{0xceb164c8,0x200c005a,0x1868ef44,0xb4d81df0}},	//   דים_, _odei_, _маки_, ादे_, 
   {{0x200c0226,0x44380399,0x00000000,0x00000000}},	//   _ndei_, geq_, --, --, 
   {{0xc8c40050,0x61e80790,0x55f40108,0x00000000}},	// [38d80] _زوٝن_, _şela, _очну, --, 
   {{0x200c05b1,0xf7e40131,0x25ac0356,0x00000000}},	//   _adei_, _ﺋﯩﻜﻪ, şela_, --, 
   {{0x7c39f4fb,0xd4680510,0x54c4082d,0x4438628c}},	//   keur, _дине_, _обоб, beq_, 
   {{0x7c3861d0,0x443802d1,0xa3d800dc,0xd618104c}},	//   jeur, ceq_, ाशः_, _اتکا_, 
   {{0x7c39f4fc,0x00000000,0x00000000,0x00000000}},	//   deur, --, --, --, 
   {{0x6b840209,0x2c78003e,0x00000000,0x00000000}},	//   _ýigi, _pédo_, --, --, 
   {{0xddc00421,0x6cd413d7,0x7d2000d1,0x00000000}},	//   _falō, ىقتا, نفون, --, 
   {{0x7c39f4fd,0x00cc005e,0xcb09f4fe,0xf8c83ee1}},	//   geur, _ﺑﺎﺳﻘ, оход_, रगोप, 
   {{0xcf45f4ff,0xfba405f5,0x8fd000fb,0xef1000db}},	//   _юнай, дтэй_, _рәжә, _сүлө, 
   {{0x25840de2,0x1da80d79,0xabb4035b,0x2c2001f9}},	//   _jëlé_, _चुकत, мақә, _यावं_, 
   {{0x7c39f500,0x021406a9,0x6d5c0114,0x02d8012c}},	//   beur, וחים_, _šraf, _बढ्न, 
   {{0x7c39f501,0xb4d800dc,0x00000000,0x00000000}},	//   ceur, ादो_, --, --, 
   {{0x4438013c,0x7a3402e3,0xb4d80118,0x00000000}},	//   veq_, ụtak, ादै_, --, 
   {{0xf98c11e9,0xddc06e98,0x228c06be,0x3bb8011a}},	//   ابی_, _holš, _tökə_, _ומדד, 
   {{0x4439f502,0x7ce405d1,0xe8954194,0x768401e0}},	//   teq_, _kıra, _пакь, тыяж, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d5c02d2,0x00000000,0x00000000,0x00000000}},	// [38d90] _áraf, --, --, --, 
   {{0x44380eda,0x7c39f503,0x609401e1,0x00000000}},	//   seq_, zeur, _ṣàán, --, 
   {{0x7c38004a,0xddc01132,0x4438014f,0x41240006}},	//   yeur, _palō, peq_, ьфаб, 
   {{0x7c380129,0x1da8000d,0x4438047e,0xafe400d4}},	//   xeur, _चुगत, qeq_, воїл, 
   {{0x7c39f504,0x38a403e0,0x00000000,0x00000000}},	//   veur, nıra_, --, --, 
   {{0x7c380c6a,0x8f501e57,0x00000000,0x00000000}},	//   weur, انوش, --, --, 
   {{0x7ce40ab7,0x7c39f505,0xddc1f506,0x987000d0}},	//   _bıra, teur, _bolš, váľ_, 
   {{0xe48c001f,0x7ce403b9,0x7c38a8d8,0x9c2408ca}},	//   _መለኪያ_, _cıra, ueur, хдид, 
   {{0xab1801c0,0x9f60012d,0x9e340798,0x00000000}},	//   мцэх_, ępów_, _пеач, --, 
   {{0x7c39f507,0x38a400fd,0x00000000,0x00000000}},	//   seur, dıra_, --, --, 
   {{0x7c386792,0x02d87e29,0x7ce405d1,0xd8241798}},	//   peur, बदुन, _fıra, ндни, 
   {{0xddc00010,0x7ce40166,0xb904228d,0x38a44e7e}},	//   _golš, _gıra, _बढ_, fıra_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb4d80a28,0x3ab0134b,0x00000000,0x00000000}},	//   ाद्_, _шәйт, --, --, 
   {{0x7ce400fd,0x00000000,0x00000000,0x00000000}},	//   _yıra, --, --, --, 
   {{0xd7082077,0x09000395,0xb184013a,0xf54000d7}},	//   _ение_, _спън, _šťou, šťou_, 
   {{0xb4d800dc,0x00000000,0x00000000,0x00000000}},	// [38da0] ादौ_, --, --, --, 
   {{0xc7d40375,0x66280030,0x63780212,0xe2a80531}},	//   _אופי_, ľský, єстр_, والن_, 
   {{0x6628219b,0x9574013d,0x00000000,0x00000000}},	//   žský, _чыпч, --, --, 
   {{0xfbc4040b,0xd0102be7,0x4fa52185,0x4fc5f508}},	//   _مت_, الش_, ниев, нсла, 
   {{0x08e47f53,0xb24400c7,0x141c0023,0x17b000fe}},	//   _কিছু_, _иҭад, _ዲምሓኩ, ঘেৰি, 
   {{0x7ce40baf,0x00000000,0x00000000,0x00000000}},	//   _sıra, --, --, --, 
   {{0x78a40789,0xfd0c06f6,0xddc0012c,0xc5f00375}},	//   _ojiv, مجي_, _polš, נדה_, 
   {{0x7ce40213,0x2d9808a5,0x00000000,0x00000000}},	//   _qıra, _þrem_, --, --, 
   {{0xc62402a6,0xddc000f3,0xfc2c007b,0x7ce40166}},	//   য়তা_, _volš, صحي_, _vıra, 
   {{0x78a5f509,0xdde801b9,0xe78800f1,0x00000000}},	//   _ajiv, _قرمه_, ېږدي_, --, 
   {{0x2d980a40,0xda201d94,0x7ce40790,0x8d540139}},	//   _äre_, _मारत_, _tıra, _ятач, 
   {{0x38a4ae47,0x7ce40139,0x4960010b,0x76840150}},	//   tıra_, _kırn, внүң, ңырж, 
   {{0xc6a448ce,0xbc64511e,0x78a40165,0xfb100451}},	//   ерви, _سمون_, _djiv, _مونج, 
   {{0x7aec0005,0x6d5c01c3,0x499000f2,0x99840153}},	//   ícte, _àras, _میخر, gelų_, 
   {{0x38a405d1,0x28c40022,0x6d5c00e5,0x00000000}},	//   sıra_, _ишиҳ, _árad, --, 
   {{0xb884074d,0x00000000,0x00000000,0x00000000}},	//   _буьй, --, --, --, 
   {{0x99840064,0x00000000,0x00000000,0x00000000}},	// [38db0] belų_, --, --, --, 
   {{0xdb18002d,0x6b8400e4,0xb2840166,0x00000000}},	//   _bywê, _ýigu, лыхк, --, 
   {{0xb7bc01e1,0x00000000,0x00000000,0x00000000}},	//   _ẹ̀ro, --, --, --, 
   {{0xe3c4009d,0x1f740108,0x00000000,0x00000000}},	//   _аргү, клея, --, --, 
   {{0x7c3c03be,0x644c85b5,0x7ce4013d,0x69d001f9}},	//   _öyrə, mdai, _cırn, डेती, 
   {{0x644df50a,0x7ce40213,0x69dc0010,0x98700064}},	//   ldai, _dırn, žrej, mšą_, 
   {{0xa3d821bd,0x645c0327,0x644df50b,0x00000000}},	//   ाशक_, _knsi, odai, --, 
   {{0x44e40428,0x62840455,0x7ff400e5,0x00000000}},	//   _mõ_, lhho, _سسرا, --, 
   {{0x60c855fa,0x5ba8021b,0x644c00a3,0xbec400ef}},	//   _ihem, ьким_, idai, enīš, 
   {{0x644dd05d,0x78a405ac,0x6284004d,0x25ac0118}},	//   hdai, _sjiv, nhho, řely_, 
   {{0x60c9f50c,0x645df50d,0xb934001f,0x38040107}},	//   _khem, _onsi, _እያካሄ, лонҳ, 
   {{0xdb180296,0x644c0007,0x60c801c7,0x61e800a2}},	//   _ezwá, jdai, _jhem, _şell, 
   {{0x80c800bd,0x60c9f50e,0x644df50f,0x78780055}},	//   িদপ্, _mhem, ddai, _jãvi, 
   {{0x09e1f510,0x60c8062c,0xfaa400fd,0x44e40208}},	//   _кошн, _lhem, _яшен, _bõ_, 
   {{0xceb013e2,0xd9580046,0x60c9f511,0x78a4017a}},	//   ייך_, _ішкі_, _ohem, _tjiv, 
   {{0x644d969a,0x60c80433,0x78a4009f,0x39440175}},	//   gdai, _nhem, _ujiv, _isns_, 
   {{0x0440011b,0x645c00d7,0x99840064,0x00000000}},	// [38dc0] шетн, _dnsi, pelų_, --, 
   {{0x644c35b8,0x60c8013b,0x11d40330,0x6284a30b}},	//   adai, _ahem, نتاد, ghho, 
   {{0x44e4001e,0xc0dc02d3,0xc614011a,0x7ce40205}},	//   _gõ_, _ንብል_, _בחיי_, _sırn, 
   {{0x644ca8cf,0x6560007c,0x00000000,0x00000000}},	//   cdai, ålhe, --, --, 
   {{0x1614dad1,0x60c98b72,0xefc00023,0x8fd0008e}},	//   _तयार_, _dhem, ድልዮ_, рәвә, 
   {{0x62840978,0x60c9f512,0x5275268f,0xfe6c0e56}},	//   chho, _ehem, _руму, قدى_, 
   {{0xd0a80014,0x3320004e,0x645df513,0x00000000}},	//   _قطرن_, luix_, _ynsi, --, 
   {{0x60c9f514,0x7ce4510c,0x63ac0036,0xfde40075}},	//   _ghem, _tırn, _ënnë, ндәк_, 
   {{0x3b1c0357,0x0b88040e,0x394400f3,0x7ce40205}},	//   guuq_, ьски_, _asns_, _hırl, 
   {{0x3a2402fa,0x7ce4456f,0x644ca348,0x60c80010}},	//   _ccnp_, _kırl, zdai, _zhem, 
   {{0x644c00a9,0x0c2400a8,0x7ce40166,0xed780092}},	//   ydai, _амен, _jırl, ክራቲክ_, 
   {{0x44e5f515,0x1cc00135,0x2ee4009a,0x60c802d3}},	//   _rõ_, _གེར_, _kumf_, _xhem, 
   {{0x941c016b,0x9f5000b5,0x7c2c067c,0xda1403e6}},	//   _ɔtɔ_, åbøl_, òcre, _ڵسوک, 
   {{0xa6c41183,0x65947125,0x7b8400d1,0x00000000}},	//   اقسى, гагу, _جامە, --, 
   {{0x644c0051,0xa9343866,0x00000000,0x00000000}},	//   tdai, _сейш, --, --, 
   {{0x44e40016,0xed10004d,0x644df516,0x02c800cd}},	//   _võ_, _đổi_, udai, ऽग्न, 
   {{0x644d5620,0x60c81dc2,0x3320004e,0xc6a539a5}},	// [38dd0] rdai, _rhem, guix_, _арни, 
   {{0x60c9f517,0x644c0192,0x2c780098,0x672c025c}},	//   _shem, sdai, _dédi_, _iqaj, 
   {{0x6d49f518,0x660406a3,0x60c80bc8,0x7ce40724}},	//   _nsda, _iehk, _phem, _cırl, 
   {{0x6285f519,0x332000f7,0x645df51a,0x6604023a}},	//   shho, buix_, _unsi, _hehk, 
   {{0x60c80943,0x6d487c9a,0xe8e0001e,0x672c025c}},	//   _vhem, _asda, _ướt_, _jqaj, 
   {{0x7ce4029f,0x672c025c,0x290c01a9,0x660401f4}},	//   _fırl, _mqaj, ksda_, _jehk, 
   {{0x60c9f51b,0x6294036b,0x6604151c,0x672c0327}},	//   _them, _imzo, _mehk, _lqaj, 
   {{0x60c800ca,0x9f04f434,0x6605f51c,0x1b48fc32}},	//   _uhem, _مورو, _lehk, езии_, 
   {{0x6d49f51d,0xa2b80c00,0x7ce40205,0x00000000}},	//   _esda, ्तप्, _zırl, --, 
   {{0x4aa44afc,0x63bc002f,0x3b1c0067,0xad240145}},	//   лкын_, _mysn, ruuq_, _چىلى, 
   {{0x7ce40365,0x672c0140,0x7c85f51e,0x63bc2b96}},	//   _kırm, _aqaj, _иуде, _lysn, 
   {{0x672c025c,0x1869f51f,0x6cd40150,0x00000000}},	//   _bqaj, хами_, _ﺟﺎﺳﺴ, --, 
   {{0x3b1c0014,0x629401f5,0x63bc11ad,0x290c01ab}},	//   quuq_, _omzo, _nysn, asda_, 
   {{0x6d5c00c6,0xd9f402dd,0x290c01a9,0xcb10010f}},	//   _árac, _صستة, bsda_, _פלו_, 
   {{0x63bc0054,0x6604022e,0xa2b800dc,0x39440100}},	//   _aysn, _dehk, ्तन्, _usns_, 
   {{0x1cc00135,0x212006d1,0x672c031c,0x2c78007f}},	//   _གེས_, duhh_, _fqaj, _pédi_, 
   {{0x7ce4510c,0x6154001f,0x38a40205,0x32d803b9}},	// [38de0] _sırl, _የሚወጣ, nırm_, lüyə_, 
   {{0x7ce40790,0x2c7801d3,0x33200393,0x260401ad}},	//   _pırl, _védi_, ruix_, वरणी_, 
   {{0x7ce4013d,0x91e40107,0x0e6400fb,0x51540150}},	//   _qırl, воҷе, ҫкен, ытау, 
   {{0x2c78003e,0x50b8eead,0x7ce406be,0x09b4010f}},	//   _tédi_, رداد_, _cırm, אפעט_, 
   {{0x7ce403b9,0x26d001ef,0xc62400eb,0x00000000}},	//   _dırm, _úooú_, য়রা_, --, 
   {{0x69dc00e2,0x7ce403e0,0x6448032e,0x03a00798}},	//   žrei, _tırl, _óeir, _ѓиро, 
   {{0x26040073,0x7ce40205,0x0fe0004e,0x290c022e}},	//   वरती_, _fırm, _лөлү, xsda_, 
   {{0x6d480158,0x7ce403e0,0x290c01a9,0x205401ee}},	//   _vsda, _gırm, vsda_, _ктур, 
   {{0x6d4806af,0x2ec40026,0x00000000,0x00000000}},	//   _wsda, _көкм, --, --, 
   {{0x672c0327,0xb7e400eb,0xdb240066,0x00000000}},	//   _rqaj, পরোয়, گویی, --, 
   {{0x8c243c4b,0x02b4008f,0x660426bb,0x290c00a3}},	//   _مفاه, רליך_, _rehk, usda_, 
   {{0x290df520,0x6604265c,0x67d400db,0x7ce406be}},	//   rsda_, _sehk, иону, _xırm, 
   {{0xc9840220,0xa2b800dc,0x66041577,0xed580419}},	//   _әули, ्तम्, _pehk, _szľh_, 
   {{0x386006be,0x63bc01e3,0x769406be,0x98700064}},	//   _enir_, _rysn, _yüyə, išę_, 
   {{0x66041073,0x63bc0419,0x32d803b9,0x00000000}},	//   _vehk, _sysn, cüyə_, --, 
   {{0x3860060a,0x66040196,0x672c025c,0x00000000}},	//   _gnir_, _wehk, _tqaj, --, 
   {{0x6605f521,0x00000000,0x00000000,0x00000000}},	// [38df0] _tehk, --, --, --, 
   {{0xa158a6bb,0x63bc4e86,0x7ce403e0,0x6cd00220}},	//   казу_, _vysn, _sırm, _ﺗﺎﺑﻴ, 
   {{0x9410016b,0x63bc75cc,0x81c4023a,0x212030b5}},	//   nnyɛ_, _wysn, ущае, uuhh_, 
   {{0x63bc03d4,0x7ce400ac,0x212000b5,0x9f540395}},	//   _tysn, _qırm, ruhh_, ивеч, 
   {{0xde05f522,0x24891905,0x5ed5e0ed,0x2ff80276}},	//   апли, mham_, ажду, унчь_, 
   {{0x4429f523,0x2489f524,0x62940921,0xd33427af}},	//   _hcc_, lham_, _umzo, _דרשה_, 
   {{0x44281418,0x365c0375,0x7ce40e51,0x00000000}},	//   _kcc_, תכונ, _tırm, --, 
   {{0xaf346249,0x2489f525,0x7ce405d1,0x9b340408}},	//   _گرفت, nham_, _hırk, ахош, 
   {{0x9ed80022,0x7ce42258,0x38600162,0x4c8001ca}},	//   _амат_, _kırk, _rnir_, ільв, 
   {{0x4429f526,0xdd94cced,0x00000000,0x00000000}},	//   _lcc_, _казы, --, --, 
   {{0x2489f527,0x442834fe,0x3da5f528,0xac8401c0}},	//   kham_, _occ_, _сраб, ргөл, 
   {{0x4429f529,0xcb9404d3,0x589400c7,0x00000000}},	//   _ncc_, انیش_, ршоу, --, 
   {{0x248800dc,0x99840618,0x00000000,0x00000000}},	//   dham_, malō_, --, --, 
   {{0x9584034f,0xe9a801d3,0x00000000,0x00000000}},	//   алге, ئدین_, --, --, 
   {{0x4429f52a,0x9494008e,0x154400d8,0x00000000}},	//   _bcc_, ашач, шевм, --, 
   {{0x2489f52b,0x3861f52c,0xc4801614,0x26dc00f2}},	//   gham_, _unir_, олск, _èwon_, 
   {{0x7c29f52d,0x51f40132,0x7ce40205,0x00000000}},	// [38e00] _mcgr, لسار, _bırk, --, 
   {{0x44289acb,0x24880548,0x96b80f01,0x527400f7}},	//   _ecc_, aham_, _جابز_, шубу, 
   {{0x44284b5a,0x24880882,0x850001d9,0x056401e0}},	//   _fcc_, bham_, _ووٝن, _күрһ_, 
   {{0x2489f52e,0x9f5c00b0,0x4428045a,0xd39401e0}},	//   cham_, kawä_, _gcc_, _кәзә_, 
   {{0x8fa40b30,0x4500025c,0x7ce403e0,0x91e400f3}},	//   шаде, _མཆོར_, _fırk, _воге, 
   {{0x8c4400ac,0x44280798,0x63a80024,0x1ee803e6}},	//   mişə, _zcc_, _ženg, دووی_, 
   {{0x84680092,0x00000000,0x00000000,0x00000000}},	//   _አገሩን_, --, --, --, 
   {{0xc0e1f52f,0xbf680118,0xefd80092,0x00000000}},	//   _фотк, _šíři, ኖሚው_, --, 
   {{0x8aa5f530,0x9f4c0694,0x7c2c00db,0xca2c0150}},	//   ирод, _feeñ_, òcra, _ﺨﻴﺭ_, 
   {{0xc3301203,0x25adf531,0x00000000,0x00000000}},	//   קות_, şeli_, --, --, 
   {{0xba71e1d4,0xa2b80882,0x4500025c,0xc278008f}},	//   تايت, ्तत्, _མཆེར_, דריי, 
   {{0x7ee01411,0x2488cc7a,0x63a802d2,0x8c4403b9}},	//   _اكەن, xham_, _þeng, kişə, 
   {{0xc7c5f532,0x00000000,0x00000000,0x00000000}},	//   рсни, --, --, --, 
   {{0x9f4c0de2,0x10a000d1,0x76b81de6,0x8c4406be}},	//   _xeeñ_, ﺋﺎﺭﯨ, иляр_, dişə, 
   {{0x2489f533,0x24180aec,0x00000000,0x00000000}},	//   tham_, ловы_, --, --, 
   {{0x59f404fb,0x26040073,0xb9d8011a,0x7ce40205}},	//   _پکیج_, वरही_, _בחוש, _sırk, 
   {{0x2489f534,0x00000000,0x00000000,0x00000000}},	// [38e10] rham_, --, --, --, 
   {{0x2489f535,0xf770021a,0x44280a49,0x56f001c0}},	//   sham_, _ځای_, _wcc_, _хүрс, 
   {{0x4429f536,0xf77011fc,0x2489f537,0x84680092}},	//   _tcc_, _فای_, pham_, _አገርን_, 
   {{0x24880d04,0x00000000,0x00000000,0x00000000}},	//   qham_, --, --, --, 
   {{0xd00c742b,0xf3180724,0x5438008f,0xa2b800dc}},	//   رلو_, _кояш_, _גערא, ्तद्, 
   {{0x4dd41c5c,0x9abc0083,0x7ce40790,0x00000000}},	//   ﻟﻘﯩﻨ, kuŋa, _hıri, --, 
   {{0xc064074d,0x00000000,0x00000000,0x00000000}},	//   _къай, --, --, --, 
   {{0xca2c0150,0x00000000,0x00000000,0x00000000}},	//   _ﺨﺴﺭ_, --, --, --, 
   {{0x6d5c9537,0xba0400c7,0x29180174,0x00000000}},	//   _áran, аҭла_, áran_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd944722e,0x2c200073,0x9d5401e2,0x00000000}},	//   щени, _याचं_, _دنات, --, 
   {{0x18a4baa7,0x8c440213,0x7f5806be,0x98a40f06}},	//   самм, yişə, _kruq, симе, 
   {{0x3ea40076,0x45000327,0x00000000,0x00000000}},	//   onnt_, _མཆུར_, --, --, 
   {{0x15b8004e,0x3b1c03e3,0x00000000,0x00000000}},	//   гыбы_, mruq_, --, --, 
   {{0x7af80483,0x3ea40e89,0x98f400db,0x00000000}},	//   lput, innt_, _уялч, --, 
   {{0x7bc8009d,0x4d78010f,0xf98400ec,0x7af801f4}},	//   _kzgu, אָמא, _ٽنڊي_, oput, 
   {{0x7af9f538,0x53c80a89,0x69dc0010,0x52a80395}},	// [38e20] nput, угам_, žret, гвам_, 
   {{0x7af80810,0xc0e002d3,0x00000000,0x00000000}},	//   iput, _ዝቖመ_, --, --, 
   {{0x7f580309,0xc6900302,0x7af8020b,0xf0780032}},	//   _aruq, _מאז_, hput, ғиҙә_, 
   {{0x7bc9f539,0x7f58036e,0xe7e800fe,0xe8ec010f}},	//   _ozgu, _bruq, পৰীয, דקאָ, 
   {{0x8c4403be,0x7f5801f5,0x7af9f53a,0x4fb4073e}},	//   qişə, _cruq, jput, حصار, 
   {{0xacf9f53b,0x3320067c,0x7af80171,0x00000000}},	//   анку_, mrix_, dput, --, 
   {{0x7af80393,0xb1483267,0xac9401f4,0x00000000}},	//   eput, _خیام_, жайш, --, 
   {{0x2250030d,0x7af88c58,0x6cd40150,0x0cb00118}},	//   _zazk_, fput, _ﺟﺎﺗﺴ, ँकेम, 
   {{0x7af890a3,0x33202bcc,0x00000000,0x00000000}},	//   gput, nrix_, --, --, 
   {{0x8f080124,0xfbcc0137,0xff280240,0x00000000}},	//   _ахҧа_, ةتى_, _ደልሃመ, --, 
   {{0x7bc801b9,0x80c8015b,0xbab401c0,0xd90c0451}},	//   _ezgu, িদর্, сгэх_, نڌي_, 
   {{0xc1700375,0x00000000,0x00000000,0x00000000}},	//   לחת_, --, --, --, 
   {{0x6d5808cb,0x321805d7,0x00000000,0x00000000}},	//   lvva, _odry_, --, --, 
   {{0x321803d1,0x249805b1,0x245402e3,0xe65801c0}},	//   _ndry_, _smsm_, _ụm_, шигч_, 
   {{0xa2b80a28,0x7a5046c9,0xddc000ef,0x00000000}},	//   ्तस्, _رضوا, _rnlū, --, 
   {{0xcd00068f,0x6d5c0327,0x33200327,0x34940006}},	//   mość_, _ġral, frix_, паср, 
   {{0x41e40aaa,0x3ea40008,0xf5a800d1,0x6d580455}},	// [38e30] مساف, ynnt_, _ғәрқ_, hvva, 
   {{0x6aa807ab,0xb27400d1,0xa5f80063,0x00000000}},	//   nndf, плуш, _њену_, --, 
   {{0xcd00068f,0x91c000fd,0x33200fac,0x7af800e2}},	//   ność_, дәтл, arix_, zput, 
   {{0xdbd80798,0x3b1c7885,0x68f80010,0x7af84432}},	//   nção, yruq_, _mtvd, yput, 
   {{0x62200075,0x5de401d5,0x6d580171,0x00000000}},	//   _يۈرە, ожла, evva, --, 
   {{0xcd00068f,0xee3800d6,0xa1580166,0x9cf40114}},	//   kość_, йні_, _кагу_, очиш, 
   {{0x6d5ccd7a,0x29180419,0x2be40241,0x00000000}},	//   _áral, áral_, _ẹyọm, --, 
   {{0xa2b81a3e,0x7af80c8c,0x7f59f53c,0x6aa9f53d}},	//   ्तव्, tput, _truq, endf, 
   {{0x7f58427b,0x248c0092,0x7af8000d,0x00000000}},	//   _uruq, _መወሰድ_, uput, --, 
   {{0x7af9f53e,0xed88013d,0x00000000,0x00000000}},	//   rput, рсәк_, --, --, 
   {{0xcd000034,0x3b1c0327,0x186800db,0x00000000}},	//   gość_, sruq_, аани_, --, 
   {{0x7af95158,0x5bb8005b,0x00000000,0x00000000}},	//   pput, _клея_, --, --, 
   {{0xcd18168d,0xe7f80cb4,0x00000000,0x00000000}},	//   _مرۆڤ_, ंड़ा_, --, --, 
   {{0x96b82c9d,0xcd00033f,0x00000000,0x00000000}},	//   руму_, bość_, --, --, 
   {{0x7ae0021a,0x7ae81f60,0xcd000210,0x00000000}},	//   _iint, _hugt, cość_, --, 
   {{0x08c04261,0x7ae1f53f,0x332074da,0xc624015b}},	//   _общн, _hint, trix_, য়গা_, 
   {{0x7ae9f540,0xc0380092,0x47d00137,0x00000000}},	// [38e40] _jugt, _የሌላው, _ۉيۉر, --, 
   {{0x7ae1f541,0xca3c0131,0x6d580113,0x6d5c02f0}},	//   _jint, ﻟﻐﺎ_, yvva, _šram, 
   {{0x7ae1f542,0x4fe9f543,0x7ae9f544,0x7ce4236c}},	//   _mint, амен_, _lugt, _kıru, 
   {{0x7ae1f545,0xa0a40046,0x7ae802d0,0x61e8013d}},	//   _lint, пшіл, _ougt, _şelt, 
   {{0x7ae00c8c,0xce481586,0x7ae80ea0,0xa2b800dc}},	//   _oint, изде_, _nugt, ्तश्, 
   {{0x7ae1f546,0x8d743abe,0xddc00fb7,0x20180208}},	//   _nint, قاعا, _dolž, _ôsin_, 
   {{0xa2b80b98,0xfd0c5edc,0x7ae80fda,0x3eac00d0}},	//   ्तर्, نجي_, _augt, _žlté_, 
   {{0x6d5d1a61,0x7ae9f547,0x7ae1f548,0x2919f549}},	//   _áram, _bugt, _aint, áram_, 
   {{0x0a69f54a,0xcd00068f,0xc4d00302,0xbb4000d8}},	//   арни_, wość_, וגה_, дењк, 
   {{0x7ae1f54b,0x7ae99b8c,0xcd00033f,0x7e20b154}},	//   _cint, _dugt, tość_, _одуж, 
   {{0x3cf00419,0x00000000,0x00000000,0x00000000}},	//   ľavé_, --, --, --, 
   {{0x8c455e11,0x7ae1f54c,0x7ae8037e,0x6c34764c}},	//   _феде, _eint, _fugt, _رفتا, 
   {{0xf41003d4,0x6aa40372,0xba70411c,0xaa58014b}},	//   িলাৰ_, _ىشتە, سایت, _гилу_, 
   {{0x7ae1f54d,0x6d5c0003,0x53a00023,0x236c025c}},	//   _gint, _ġraj, _ፍርያት_, _ħej_, 
   {{0x97300b28,0x7ae8002f,0x6b800042,0xa4d400d4}},	//   وکیا, _zugt, lymg, зові, 
   {{0x7ae038f3,0x7ae89b58,0x00000000,0x00000000}},	//   _zint, _yugt, --, --, 
   {{0x7ae1f54e,0xe2c82620,0x00000000,0x00000000}},	// [38e50] _yint, مورو_, --, --, 
   {{0xe7f8069f,0x7ae081f1,0x7ce40790,0x00000000}},	//   ंडवा_, _xint, _kırt, --, 
   {{0x26c0004b,0xddc1e10b,0x27e800ef,0x8168024c}},	//   _ikho_, _solž, _kgan_, шраб_, 
   {{0x27e80a2e,0xddc009a8,0x7ce406be,0x00000000}},	//   _jgan_, _polž, _mırt, --, 
   {{0x27e8022e,0x6d5d5ce3,0xaf040212,0x59d001f9}},	//   _mgan_, _áraj, дпіл, _हरभर, 
   {{0x27e80517,0x7ae859bf,0xc5dc0154,0x00000000}},	//   _lgan_, _rugt, _ব্যপ, --, 
   {{0x7ae1f54f,0x62843917,0xdc981f71,0x7ae881f1}},	//   _rint, mkho, йтиш_, _sugt, 
   {{0x27e9f550,0x62840656,0x7ae800ee,0x9f3410da}},	//   _ngan_, lkho, _pugt, _небі, 
   {{0x62841db4,0xdd9000dd,0x3ab004a9,0x0b40008e}},	//   okho, بوں_, мәкт, енын, 
   {{0x6285f551,0x27e805ba,0x26c001ee,0x200c0093}},	//   nkho, _agan_, _nkho_, _heei_, 
   {{0x6285f552,0x7ce44dd9,0x2d9808a5,0x00000000}},	//   ikho, _cırt, _þrep_, --, 
   {{0x26c0136f,0x7ae9f553,0x7ae02517,0xdb3804fb}},	//   _akho_, _tugt, _wint, _هستش_, 
   {{0x7ae1f554,0x27e80a2e,0x7c39f555,0x628403cd}},	//   _tint, _dgan_, mfur, kkho, 
   {{0x27e9f556,0x7c39f557,0x200c0421,0x7ce4029f}},	//   _egan_, lfur, _leei_, _fırt, 
   {{0xf485f558,0x7c38009f,0x7ce4236c,0xc68c01d9}},	//   واری, ofur, _gırt, ھِہ_, 
   {{0x26c02d56,0x6285f559,0x7c39f55a,0x7ce403ee}},	//   _ekho_, ekho, nfur, _hırs, 
   {{0x62840270,0x7c380810,0x94a80032,0x7ce40790}},	// [38e60] fkho, ifur, атҡа_, _kırs, 
   {{0x7ce40ac1,0x7c380067,0x27e9f55b,0x7690013d}},	//   _yırt, hfur, _zgan_, _säyf, 
   {{0x86780302,0x200c01e1,0x27e8036b,0x00000000}},	//   _הריו, _beei_, _ygan_, --, 
   {{0x76900724,0x200c067c,0x6285ac84,0x057400f1}},	//   _bäyg, _ceei_, akho, _راپد, 
   {{0x7c380493,0x769000fd,0x62840327,0xffe01572}},	//   dfur, _cäyg, bkho, нюшн, 
   {{0x62840628,0x7f440075,0x7c38020b,0x6d5d5ce3}},	//   ckho, سلىق_, efur, _árak, 
   {{0x7c39f55c,0x200c0607,0x6cd5f55d,0xb82400fe}},	//   ffur, _feei_, وقتا, য্যত_, 
   {{0xdbf00118,0x61e00332,0x80d000db,0xefd80023}},	//   břík, _úlla, _كۅلچ, ኮላይ_, 
   {{0x769002f6,0x27e8036b,0x7ce42737,0x88e401ec}},	//   _käyd, _rgan_, _sırt, _ﺍﻟﺘﻀ, 
   {{0x7c39f55e,0x27e8e0aa,0x7ce42791,0x433c0240}},	//   afur, _sgan_, _pırt, _ኣጋባባ, 
   {{0x8c4535ea,0x7690013d,0xe7f80490,0x7ce406be}},	//   _неже, _mäyd, ंडला_, _qırt, 
   {{0x7c3802fa,0x8cb80137,0x2ca00254,0x00000000}},	//   cfur, _ادئس_, _öid_, --, 
   {{0x7ce40365,0xe7bc02f5,0xddc0008f,0x6285f55f}},	//   _fırs, ৃশ্য, _malŝ, ykho, 
   {{0x7ce42ca8,0x6ef00051,0x941003e3,0x00000000}},	//   _tırt, _đàlạ, miyə_, --, 
   {{0x27e8006c,0xe944006c,0x941003be,0xba700690}},	//   _tgan_, _آرتی, liyə_, _ساوت, 
   {{0x27e80295,0xdde002b5,0xf55401c0,0x28142f4d}},	//   _ugan_, _ōtūr, эвсэ, _کوکس, 
   {{0x76900139,0x94100213,0x349403d0,0x389c011a}},	// [38e70] _bäyd, niyə_, хатр, _ליהנ, 
   {{0xedf8089a,0x200c0607,0x62840161,0x26c000f1}},	//   ुरोध_, _seei_, ukho, _ukho_, 
   {{0xc5f83eaf,0x6285f560,0xe29801e0,0x941003b9}},	//   ्रीय_, rkho, баҡ_, hiyə_, 
   {{0xdbf0012c,0x62847dcd,0xc0a800cf,0x7690008e}},	//   třík, skho, حائل_, _päyg, 
   {{0xef194012,0x82340137,0x62840051,0x00000000}},	//   змі_, _ىرسا, pkho, --, 
   {{0xddc44a2e,0x6e9588b9,0x941000ac,0x7e2812fa}},	//   мбли, ничу, diyə_, сіда_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdbf00316,0x64480086,0x7690013d,0xe988008e}},	//   přík, _ñeid, _zäyd, _şuşı, 
   {{0x7c39f561,0xdfd0007b,0x00000000,0x00000000}},	//   rfur, _شيئ_, --, --, 
   {{0x7c39f562,0x7690013d,0x7ce406be,0x00000000}},	//   sfur, _käye, _qırs, --, 
   {{0x7c39f563,0x6b8400ef,0x00000000,0x00000000}},	//   pfur, _ačgā, --, --, 
   {{0x186800c9,0xac94016c,0x7690008e,0x7c38058a}},	//   цами_, _пахш, _mäye, qfur, 
   {{0x9b4410e8,0x79e400e5,0x63a8010e,0x941003b9}},	//   _آنتو, _ٹوبہ_, _ženn, ciyə_, 
   {{0xcb100375,0xaa581c56,0x7ce40790,0x00000000}},	//   _ילד_, _ничу_, _tırs, --, 
   {{0x9b4400f1,0x59d0258d,0x00000000,0x00000000}},	//   _رنګو, _हरिर, --, --, 
   {{0x130802d5,0x769000fd,0x7ce406be,0x61e8010e}},	//   жнай_, _säyd, _zırr, _şelp, 
   {{0x1cc049a6,0x03a031e2,0x7690008e,0x00000000}},	// [38e80] _གེན_, вито, _päyd, --, 
   {{0x76900166,0x81d403d4,0x59d00b67,0x00000000}},	//   _bäye, াখন_, _हरार, --, 
   {{0x63a8008c,0x769000fd,0x00000000,0x00000000}},	//   _þenn, _cäye, --, --, 
   {{0x4fa404b4,0x6d5c6d6c,0xe4e40153,0x8fa4085b}},	//   миев, _árai, _піўн, وماه, 
   {{0x7690049b,0x09b81810,0x5dd401ec,0x00000000}},	//   _täyd, _उड्य, _ﺘﺭﻭﻴ, --, 
   {{0x76900166,0xccf80063,0x00000000,0x00000000}},	//   _fäye, оћи_, --, --, 
   {{0xfe6c4f3d,0x10a47401,0x7690008e,0xf1c800db}},	//   شدو_, _живн, _gäye, _راسۇ_, 
   {{0x7ce405d1,0xbb4802dd,0xc198011a,0x00000000}},	//   _sırr, _ﺀﯗﻱ_, _ושלי, --, 
   {{0xd488001f,0xca241cc9,0x76900139,0x1da00092}},	//   _መገናኛ_, мфни, _zäye, ልካቾች_, 
   {{0x3f940014,0x941000ac,0x4dd40150,0xabcc01ec}},	//   _تھٔد_, riyə_, _قتاس, _ﮔﻪﻧﺎ, 
   {{0x2919f564,0x3c800882,0x39b405f5,0xdd800050}},	//   éra_, ṛtaḥ_, длээ_, _میوٝ, 
   {{0xdb18012d,0x941003e3,0x00000000,0x00000000}},	//   _czwó, piyə_, --, --, 
   {{0x27ecb832,0x8705f565,0x941003e3,0x00000000}},	//   ženo_, ьяне, qiyə_, --, 
   {{0x2c740014,0x3b5000d6,0xd628031c,0xc5f81c54}},	//   _آیکھ_, _шкір, _སྐྱབ_, ्रेय_, 
   {{0x7aec01a2,0x7ce40e2d,0xfa30027d,0x1d840092}},	//   íctv, _kırp, _شرود, ክራቶች_, 
   {{0xb8d4045e,0x3448016c,0x70b807f7,0x999000d7}},	//   _জী_, мчун_, इकोल, ýzť_, 
   {{0x7c2c00cf,0x38340022,0x7690008e,0x00000000}},	// [38e90] òcri, _рныр, _säye, --, 
   {{0x2ca4002d,0xdfd00b38,0x00000000,0x00000000}},	//   himd_, ۇيا_, --, --, 
   {{0x6615f566,0x35b400c0,0x00000000,0x00000000}},	//   mazk, _абэр, --, --, 
   {{0xdfd005d9,0x76900139,0x6615ea34,0x4ff40241}},	//   هيا_, _gäyb, lazk, _oṣuṣ, 
   {{0x644df567,0x2489f568,0xd01401d5,0xe5e4136e}},	//   meai, mkam_, رقوش_, _تزکی, 
   {{0x644df569,0xd344021a,0x6614009d,0x61e00332}},	//   leai, _سیمه_, nazk, _úllo, 
   {{0xad5806a6,0x2d940395,0x31c400f3,0x00000000}},	//   дрых_, кръс, _аств, --, 
   {{0x2489f56a,0xa2b85b29,0x661401c6,0x644df56b}},	//   nkam_, ्तक्, hazk, neai, 
   {{0x248806a3,0x6615f56c,0xb2e801d9,0x1ae413f3}},	//   ikam_, kazk, _رٹہٕ_, ноим, 
   {{0x2489f56d,0x1cc049a6,0x644df56e,0xddc0010e}},	//   hkam_, _གེམ_, heai, _galş, 
   {{0x24889cfb,0x661401c6,0x6d5c0010,0x38040107}},	//   kkam_, dazk, _šrav, конҳ, 
   {{0xd1d4044e,0x2bb82d8f,0x644c01f4,0x00000000}},	//   ራርባ_, _उँचा, jeai, --, 
   {{0x66142a1f,0x644df56f,0x24880419,0x00000000}},	//   fazk, deai, dkam_, --, 
   {{0xd6d02047,0x66140323,0x2488005f,0x960802a0}},	//   اقس_, gazk, ekam_, वरेट_, 
   {{0x98a489c3,0xb40411dc,0x2604000d,0xceb005d0}},	//   _пике, күнд, वरजी_, טיך_, 
   {{0xb9fc02d3,0x644c4056,0xbeec0073,0x2a7c01ef}},	//   _ቀሺ_, geai, _चढून_, _zovb_, 
   {{0x6614005a,0x6d5d80de,0x00000000,0x00000000}},	// [38ea0] bazk, _árav, --, --, 
   {{0x7765f570,0x95740022,0x82a00276,0x2bb80037}},	//   _irix, _зымч, гауж, _उँघा, 
   {{0xd0243c1f,0x39440ac5,0x644c037e,0x2488002e}},	//   емей, _jpns_, beai, bkam_, 
   {{0x7764005a,0x1af4015b,0x765c017a,0xefc00023}},	//   _krix, _ইবনে_, ldry, _ድሉው_, 
   {{0x63f40014,0x26040490,0xb4adf571,0xa4900244}},	//   _شہلس_, वरची_, कची_, _ئیقت, 
   {{0x471800c8,0xff2404da,0x7ce40205,0x00000000}},	//   לונג, ركىي_, _sırp, --, 
   {{0x52bc2122,0x753c01e0,0xd0088404,0x00000000}},	//   ्तीस, ntrz, _неве_, --, 
   {{0x77640f71,0xc0e039a6,0x661401c6,0x7ce403b9}},	//   _orix, _боск, zazk, _qırp, 
   {{0xfba401c6,0xfde40116,0xdf700133,0xef1000db}},	//   етэй_, мдәк_, _نگوب, _түлө, 
   {{0x6614009d,0x6d5c0427,0x248858b9,0x00000000}},	//   xazk, _šrau, zkam_, --, 
   {{0x39440073,0xe8940953,0x661400bc,0x7764036e}},	//   _cpns_, вань, vazk, _arix, 
   {{0x77642b55,0x27ec10b8,0x6d48047e,0x52bc06ff}},	//   _brix, øen_, _ipda, ्तुस, 
   {{0x7765dac7,0x661405f5,0x644c0b23,0x2489f572}},	//   _crix, tazk, veai, vkam_, 
   {{0x765c0af9,0x00000000,0x00000000,0x00000000}},	//   gdry, --, --, --, 
   {{0x6615f107,0x0464e085,0x2489f573,0x7765f574}},	//   razk, нтам, tkam_, _erix, 
   {{0x391006bb,0x77640077,0x661401c6,0x6d5c02d2}},	//   _смър, _frix, sazk, _árau, 
   {{0x77640077,0x644df575,0x6614005a,0x00000000}},	// [38eb0] _grix, reai, pazk, --, 
   {{0x6d48105c,0x644df576,0x673c0158,0x00000000}},	//   _opda, seai, mtsj, --, 
   {{0x673c193f,0x644df577,0x24880841,0x659400d8}},	//   ltsj, peai, pkam_, _рану, 
   {{0x75285327,0x2ff8084c,0x59d4033f,0x31c40329}},	//   ádze, енць_, डेटर, усув, 
   {{0x673df578,0x6d482602,0x23d4a7a2,0x291c00ef}},	//   ntsj, _apda, _दरिद, _lvva_, 
   {{0x673df579,0xae8801ec,0x00000000,0x00000000}},	//   itsj, нбіз_, --, --, 
   {{0xbd680276,0x673c000f,0x2618000d,0x00000000}},	//   ярде_, htsj, _बजनी_, --, 
   {{0xa06801d9,0x27ec09a8,0x673c143a,0x3b0401e1}},	//   _تٍرٕ_, ženj_, ktsj, _nípò_, 
   {{0xa0a40046,0x9e140953,0x673c045f,0x6d4802d0}},	//   _заңд, _адзі, jtsj, _epda, 
   {{0x673cd3da,0x3944020b,0x4aa400f7,0xfca801c8}},	//   dtsj, _ppns_, ккын_, _کائو_, 
   {{0x3ea5f57a,0x673c4fa5,0x4aa0000d,0x7c8403c5}},	//   mint_, etsj, _ओगरव, _пуде, 
   {{0x98a5f57b,0x3ea5f57c,0x673df57d,0x291c007f}},	//   тиме, lint_, ftsj, _dvva_, 
   {{0x3b040ca8,0x291c0055,0x765c17b5,0x3ea5f57e}},	//   _dípò_, _evva_, tdry, oint_, 
   {{0x3ea5f57f,0x76900724,0xd94400c7,0xe47c0092}},	//   nint_, _bäya, _аеки, _የሙከራ_, 
   {{0x673c9a83,0x765df580,0x6d5c0008,0x7bc9f581}},	//   atsj, rdry, _árat, _hygu, 
   {{0x765dd5e1,0x6a740022,0x7bc800c7,0x3ea5f582}},	//   sdry, _акәӡ, _kygu, hint_, 
   {{0x753c006d,0x78a468d7,0xb2440184,0x3ea4cc5b}},	// [38ec0] strz, _imiv, лмаһ, kint_, 
   {{0xfbc40133,0x3ea40064,0x020000d4,0x52bc07b7}},	//   _ۆت_, jint_, изун, ्तेस, 
   {{0xfbc40502,0x3ea5f583,0x7bc9f584,0xd7886ea9}},	//   _چت_, dint_, _lygu, _رنگو_, 
   {{0xfbc478db,0xa08802dd,0x16080d79,0x7bc801a9}},	//   _نت_, нсіз_, वरकर_, _oygu, 
   {{0x81e00eac,0x656800b0,0x662808a5,0x00000000}},	//   ফুল_, āehe, _ískó, --, 
   {{0x3ea5f585,0x7f800131,0xb644037e,0x479808a8}},	//   gint_, شلىن, _ｎｇ_, וינס, 
   {{0x82a01760,0x7bc9f586,0x90c40006,0x7690013d}},	//   _тарж, _aygu, _абве, _xäya, 
   {{0x7bc80fac,0x3ea5f587,0x673c045f,0x0fe007ee}},	//   _bygu, aint_, ytsj, _көлү, 
   {{0x2ec40032,0x3ea5f588,0x27ec0010,0x6e3c010e}},	//   _йөкм, bint_, ženk_, _örbo, 
   {{0x63a802d5,0x3ea4e487,0x78a401ed,0xc9840107}},	//   _ženk, cint_, _amiv, вуми, 
   {{0x6d481f38,0x7bc8022c,0x2d99f589,0xbab401c0}},	//   _upda, _eygu, _åre_, тгэх_, 
   {{0x673cdf4f,0x78b80419,0x00000000,0x00000000}},	//   ttsj, _ľavé, --, --, 
   {{0x76900724,0x673c000f,0x00000000,0x00000000}},	//   _säya, utsj, --, --, 
   {{0x673df58a,0x6d5c00c6,0x78a41418,0x29180553}},	//   rtsj, _áras, _emiv, áras_, 
   {{0x673df58b,0xc98410fc,0x78a40200,0x00000000}},	//   stsj, _јули, _fmiv, --, 
   {{0x656405be,0x6aa80784,0x673c000f,0x3ea5f58c}},	//   _vrhh, lidf, ptsj, zint_, 
   {{0x68ec009a,0x3ea40472,0x00000000,0x00000000}},	// [38ed0] _iiad, yint_, --, --, 
   {{0x68edf58d,0x76900309,0x3ea429b1,0x41e40345}},	//   _hiad, _täya, xint_, نساف, 
   {{0x3ea5f58e,0x7690049b,0x68edf58f,0xe6940022}},	//   vint_, _käyn, _kiad, _аиҿы, 
   {{0x2eec0526,0x68ec03d1,0x5f943576,0x69dc01a8}},	//   _aidf_, _jiad, лиет, þrey, 
   {{0x645df590,0x68ec0851,0xaab41a55,0x98a4054e}},	//   _iasi, _miad, ुवाक, lulă_, 
   {{0xaec4242f,0xb284a57a,0x68edf591,0x7bc8035b}},	//   абіл, _кыск, _liad, _rygu, 
   {{0x3ea5f592,0xdca42cdd,0xa195f593,0x5ca401a9}},	//   rint_, лаки, _савч, ликб, 
   {{0x68edf594,0x3ea5f595,0x7bc800e4,0x00000000}},	//   _niad, sint_, _pygu, --, 
   {{0x60c99db1,0x7d24004b,0x00000000,0x00000000}},	//   _ikem, ريکې_, --, --, 
   {{0xdd94010b,0x7bc802f0,0x80b001f9,0x00000000}},	//   _йазы, _vygu, ेकवे, --, 
   {{0x68edf596,0x7690013d,0x00000000,0x00000000}},	//   _biad, _bäyn, --, --, 
   {{0x68edddc4,0x973405f5,0x7bc806ea,0x7690008e}},	//   _ciad, лэгч, _tygu, _cäyn, 
   {{0x7bc80ab7,0x68edf597,0x60c801f7,0x29180bcd}},	//   _uygu, _diad, _mkem, árar_, 
   {{0x645df598,0x68ec0113,0x24a002d3,0x6a2437ba}},	//   _aasi, _eiad, _ፍሽለት_, _نفهم, 
   {{0x68edf599,0x98a40276,0xd9442374,0x60c9dab7}},	//   _fiad, gulă_, _сейи, _okem, 
   {{0x68edf59a,0x60c8043b,0x78a5f59b,0x645df59c}},	//   _giad, _nkem, _umiv, _casi, 
   {{0x645df59d,0x53a4001f,0x98700327,0xdb0c01f4}},	// [38ee0] _dasi, _ጊዜያት_, eġħ_, _äkäs, 
   {{0x68edf59e,0x60c84481,0x645df59f,0x644800e4}},	//   _ziad, _akem, _easi, _ñein, 
   {{0x645df5a0,0x98a40311,0xdb20032e,0x2618012d}},	//   _fasi, culă_, _ótæp, _बजती_, 
   {{0x645df5a1,0x1015f5a2,0x2eec002d,0x68edf5a3}},	//   _gasi, اباد, _sidf_, _xiad, 
   {{0x3f640108,0x8e84004e,0xdedc0240,0x00000000}},	//   лицо_, лгде, _ሕሹኽ_, --, 
   {{0x60c9f5a4,0x645df5a5,0xddc00109,0xd05006be}},	//   _ekem, _zasi, _lalŕ, _əgər, 
   {{0xa2c008ec,0x00000000,0x00000000,0x00000000}},	//   ववर्, --, --, --, 
   {{0x645df5a6,0x6aa8015d,0x00e4114f,0x00000000}},	//   _xasi, widf, _متقی, --, 
   {{0x68ec01a2,0x0ba800cf,0x7c80005b,0x80b0012d}},	//   _riad, عابى_, суще, ेकरे, 
   {{0x68edf5a7,0x76900108,0xabb40588,0xacd40022}},	//   _siad, _säyn, лақә, ыбқә, 
   {{0x68edf5a8,0xfbcc0efb,0x60c8002d,0xcd041422}},	//   _piad, يتۋ_, _ykem, _спей, 
   {{0x4f440020,0x6fb84da4,0x00000000,0x00000000}},	//   _መልዕክ, _अशां, --, --, 
   {{0x68edf5a9,0x6aa801e4,0x3b040117,0x6f04035b}},	//   _viad, pidf, _бечо_, ãich, 
   {{0x645df5aa,0x68edf5ab,0x758c0023,0x98a40356}},	//   _sasi, _wiad, _ዓመጽቲ_, tulă_, 
   {{0x645df5ac,0x68ec0201,0x24186feb,0x769002f6}},	//   _pasi, _tiad, ковы_, _täyn, 
   {{0x69d9f5ad,0x645df5ae,0x752801a2,0x2d9c0099}},	//   _izve, _qasi, ádza, izve_, 
   {{0x645df5af,0x60c80166,0x181830d1,0xefd80023}},	// [38ef0] _vasi, _rkem, _شريک_, ኮላዊ_, 
   {{0x645df5b0,0x60c80fbf,0x649003cd,0x00000000}},	//   _wasi, _skem, _gåin, --, 
   {{0x76900139,0x98700092,0x00000000,0x00000000}},	//   _mäyl, _እየሆኑ_, --, --, 
   {{0x645c23e0,0x3cf80034,0x7690013d,0x3494014b}},	//   _uasi, _लंबे_, _läyl, _гаюр, 
   {{0x39980241,0x9f5406be,0xd9d02e2a,0x00000000}},	//   _kásé_, _üfüq_, _हर्ट, --, 
   {{0x69d82e31,0x00000000,0x00000000,0x00000000}},	//   _ozve, --, --, --, 
   {{0x69d80099,0x9f058a8f,0xad2406f6,0x00000000}},	//   _nzve, _چورو, مريو, --, 
   {{0x9f041de5,0x60c9f5b1,0x27e40210,0x32d40139}},	//   _نورو, _ukem, ślny_, häyl_, 
   {{0x39300020,0x76900598,0x69d8030a,0x5fc000db}},	//   _በተያያ, _bäyl, _azve, _بەشۅ, 
   {{0x7f58031c,0x7690008e,0x00000000,0x00000000}},	//   _isuq, _cäyl, --, --, 
   {{0xd9448374,0x6d5c035b,0xec4802dd,0xdc740354}},	//   шени, _árap, _әзіл_, _выль, 
   {{0x69d8006f,0x649003cd,0x6c740117,0xadbc030d}},	//   _dzve, _såin, _гушх, _яахi, 
   {{0x69d8bf23,0x7f580327,0x1ad4036b,0x00000000}},	//   _ezve, _jsuq, _кўкр, --, 
   {{0x1a6403e6,0xceb0010f,0x00000000,0x00000000}},	//   _ئیدی_, ַין_, --, --, 
   {{0x7af8025c,0x00000000,0x00000000,0x00000000}},	//   lqut, --, --, --, 
   {{0x62954ab8,0xb4d00882,0x7af80194,0x2e2c0241}},	//   _alzo, षते_, oqut, _kófà_, 
   {{0x3860003a,0x13e9f5b2,0x7af98fd5,0x3b1c0113}},	// [38f00] _iair_, тмай_, nqut, nsuq_, 
   {{0xb7f804c5,0x3860662c,0x76901b5d,0x55880022}},	//   _অজিত_, _hair_, _käym, _абом_, 
   {{0x86780302,0x90c411ed,0x25f40764,0x3861f5b3}},	//   _סרטו, абже, ्डरी_, _kair_, 
   {{0x50442ff5,0x386000d8,0x3dd8009e,0x98a4762b}},	//   редб, _jair_, দশাল, bulą_, 
   {{0x38604f7f,0x00000000,0x00000000,0x00000000}},	//   _mair_, --, --, --, 
   {{0x3860034c,0x62940076,0x61e801e4,0x81400014}},	//   _lair_, _glzo, _ŝele, _ژھنم, 
   {{0x50580209,0x76900139,0x7fd4013d,0x00000000}},	//   _ишая_, _räyl, лфәт_, --, 
   {{0x32181311,0x3861f5b4,0x2d9c0240,0xcce4007b}},	//   _hery_, _nair_, rzve_, جستي, 
   {{0x321803d1,0x7af8014b,0x00000000,0x00000000}},	//   _kery_, gqut, --, --, 
   {{0x32180170,0x0a6870b2,0x7f3802e4,0xaa580063}},	//   _jery_, трии_, _בעמו, ћину_, 
   {{0x7af8c203,0x3b1c0014,0x3861f5b5,0x769008b9}},	//   aqut, asuq_, _bair_, _cäym, 
   {{0x3861f5b6,0x32180170,0x0ae805d9,0x00000000}},	//   _cair_, _lery_, _ڌرتي_, --, 
   {{0x3861842a,0x25f4012c,0x7ce40139,0x00000000}},	//   _dair_, ्डली_, _nıry, --, 
   {{0x32191f29,0xdb241077,0xb5c400d1,0x00000000}},	//   _nery_, _اووی, ﺮﻏﯩﺰ, --, 
   {{0x69d8143f,0x3861f5b7,0x00000000,0x00000000}},	//   _uzve, _fair_, --, --, 
   {{0x386000a9,0x224c01e4,0x98a40024,0x629402f0}},	//   _gair_, _ŝek_, tulą_, _slzo, 
   {{0x32180109,0x6d5802b9,0xa06814d4,0x644800e4}},	// [38f10] _bery_, hwva, ғала_, _ñeim, 
   {{0xb2740137,0x3218012d,0x483000f1,0x00000000}},	//   олуш, _cery_, _اوکړ, --, 
   {{0x7f580327,0x386000cd,0x00000000,0x00000000}},	//   _ssuq, _yair_, --, --, 
   {{0x68f80477,0x7af80309,0x1d0801f0,0xa06800d8}},	//   _muvd, yqut, қеии_, ѓала_, 
   {{0x3219f5b8,0x68f8022e,0x2b400036,0x335800cf}},	//   _fery_, _luvd, _äich_, _күтө_, 
   {{0xee3800d6,0x32180660,0x00000000,0x00000000}},	//   ині_, _gery_, --, --, 
   {{0xefd40020,0x7af80784,0x00000000,0x00000000}},	//   _ይዘው_, wqut, --, --, 
   {{0x7f580113,0x32180109,0x3b1c0194,0x00000000}},	//   _tsuq, _zery_, tsuq_, --, 
   {{0x7f580107,0x5ac816d8,0x00000000,0x00000000}},	//   _usuq, ллим_, --, --, 
   {{0x3861f5b9,0x201c1813,0x7af803f0,0xda5801d5}},	//   _sair_, lawi_, rqut, уриш_, 
   {{0x3860ecb4,0x7af80309,0x3da41d4a,0xac8401c6}},	//   _pair_, squt, _траб, сгөл, 
   {{0x201df5ba,0x68f8014f,0xf4240327,0x6c84007b}},	//   nawi_, _duvd, _འཇེད_, _وللم, 
   {{0x7af832ff,0xdef8002e,0x3861f5bb,0xe7f8000d}},	//   qqut, _juŋ_, _vair_, ूड़ा_, 
   {{0x201df5bc,0xaac5f5bd,0x64480428,0x38604d0e}},	//   hawi_, _وتون, _ñeij, _wair_, 
   {{0x201df5be,0x3861f5bf,0x321806d9,0x769000fd}},	//   kawi_, _tair_, _rery_, _häyk, 
   {{0x386050c2,0x201df5c0,0xba040020,0x321843af}},	//   _uair_, jawi_, _ቋሚ_, _sery_, 
   {{0x201df5c1,0x7690023a,0x3219f5c2,0x3a2400e5}},	// [38f20] dawi_, _jäyk, _pery_, _kdnp_, 
   {{0x68f91eb2,0x2008009d,0x09c4000d,0x00000000}},	//   _yuvd, ñain_, _रुँठ, --, 
   {{0x3219f5c3,0x33201caa,0x27ec04a7,0x63a800c0}},	//   _very_, ssix_, žent_, _žent, 
   {{0x201d6c60,0x33200254,0x00000000,0x00000000}},	//   gawi_, psix_, --, --, 
   {{0x32180170,0x76900108,0x33200327,0x00000000}},	//   _tery_, _näyk, qsix_, --, 
   {{0x91e49c36,0x00000000,0x00000000,0x00000000}},	//   _гоге, --, --, --, 
   {{0x201df5c4,0x1ea82e6f,0x0d48004b,0x6d5801f5}},	//   bawi_, جاني_, اشتي_, uwva, 
   {{0x61b00e26,0x76900139,0x68f8022e,0x5dd40150}},	//   _تەما, _bäyk, _ruvd, _ﺘﻭﻗﻴ, 
   {{0x3a2401ee,0x68f8fa80,0x7c2c09c2,0x15f8060c}},	//   _bdnp_, _suvd, ócra, ्डार_, 
   {{0x0e6800c6,0x00000000,0x00000000,0x00000000}},	//   _حصري_, --, --, --, 
   {{0x3d283e66,0x68f8047e,0x61040153,0xc278011a}},	//   _متنی_, _quvd, _vėlg, אריי, 
   {{0x769001f4,0x00000000,0x00000000,0x00000000}},	//   _häyh, --, --, --, 
   {{0x27ec02f6,0xc7c4287c,0x769001f4,0xf8040006}},	//   äen_, ссни, _käyh, ячэн, 
   {{0x7b840220,0x7ce4013d,0x00000000,0x00000000}},	//   _دامە, _sırx, --, --, 
   {{0x201df5c5,0x64480022,0xbc4c0248,0x00000000}},	//   yawi_, _ñeik, _àṣíw, --, 
   {{0x7ce40213,0xc7a8007b,0x00000000,0x00000000}},	//   _qırx, _مدخل_, --, --, 
   {{0x6e2803cd,0x76900139,0xe758155b,0xf8b4011a}},	// [38f30] _oddb, _xäyk, _типі_, _משק_, 
   {{0x63a8596b,0x201c31e5,0xa5c40139,0x27ec4a38}},	//   _žens, wawi_, _дөбе, žens_, 
   {{0x201df5c6,0x61540736,0xf77002f2,0x68fc01e7}},	//   tawi_, تنائ, _قای_, írdh, 
   {{0x6e29f5c7,0xd00c00aa,0x5f940451,0xd7640244}},	//   _addb, پلو_, يلائ, _انیی, 
   {{0x201cdc83,0x21200263,0x98a40064,0x00000000}},	//   rawi_, sshh_, gulę_, --, 
   {{0x6e2802d0,0x201df5c8,0x00000000,0x00000000}},	//   _cddb, sawi_, --, --, 
   {{0xdc981f71,0x201df5c9,0x3a240100,0xdca401b9}},	//   итиш_, pawi_, _rdnp_, жайи, 
   {{0x201c094a,0x44380207,0xcf2c05d1,0x98a4012d}},	//   qawi_, ngq_, üğüm_, bulę_, 
   {{0x610400c0,0x00000000,0x00000000,0x00000000}},	//   _dėle, --, --, --, 
   {{0x9e94167e,0x3f8c0368,0x23680115,0x769001f4}},	//   _بارچ, mygu_, ivaj_, _väyk, 
   {{0x3f8c0f7b,0x249808cd,0xdd9003e6,0xddc00024}},	//   lygu_, _olsm_, _توا_, _malū, 
   {{0x2368008f,0xad2401ec,0x61040153,0xd7e83460}},	//   kvaj_, _ءىنى, _gėle, имне_, 
   {{0x07a0010b,0x2368014f,0x888014a3,0x00000000}},	//   даян, jvaj_, фляж, --, 
   {{0x236993ea,0x769000a2,0xdb18012d,0x98b80205}},	//   dvaj_, _käyi, _wywó, ıyıp_, 
   {{0x24980263,0x20c805c0,0xd9b401d9,0x3f8c015d}},	//   _blsm_, िकाध, _گٔژھ, hygu_, 
   {{0xd4080345,0x00000000,0x00000000,0x00000000}},	//   شترم_, --, --, --, 
   {{0x52a8c43d,0x7c3812c5,0x290000c0,0x00000000}},	// [38f40] авам_, igur, _čiai_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x16c4033f,0x76900108,0x00000000,0x00000000}},	//   लकीब, _räyh, --, --, 
   {{0xd4680640,0x7c38036e,0x54344c0e,0x3f8c0042}},	//   _тиме_, jgur, _بردر, fygu_, 
   {{0x7c39f5ca,0x4365f5cb,0x161c3105,0xb8f8031c}},	//   dgur, _даян_, _बजार_, _འེ_, 
   {{0xddc00153,0x610400c0,0x4090008e,0x00000000}},	//   _galū, _sėle, зрәт, --, 
   {{0x4124016c,0xbea00261,0x00000000,0x00000000}},	//   _моро_, ќајк, --, --, 
   {{0x7c39f5cc,0x6ab400dc,0x6834022e,0xc5f002e4}},	//   ggur, ुव्र, _nоdа, ודו_, 
   {{0x1fd000bd,0x61040153,0x4ae401d5,0x61f802d2}},	//   ়েবস, _vėle, жўна, _áblá, 
   {{0x7c39f5cd,0x0eb81de6,0x95600092,0x00000000}},	//   agur, _тубы_, _ትልቁን_, --, 
   {{0x2b440407,0x6d440311,0xf1d0033f,0x42d80375}},	//   stmc_, ăias, _तुमन, שקיע, 
   {{0x48a9f5ce,0x00000000,0x00000000,0x00000000}},	//   ртом_, --, --, --, 
   {{0x7c400306,0xe8c80150,0x2be805ac,0x1a1800cc}},	//   ívrž, игүл_, _ট্ৰে_, _দাৰু_, 
   {{0x24540016,0xf8b80137,0x70b8000d,0x00000000}},	//   _ấm_, йөө_, ेकुल, --, 
   {{0xbae0007b,0xa91c00d7,0x69dc952a,0x00000000}},	//   _تكوي, tyľu, üred, --, 
   {{0xa81400ee,0x7b0406ea,0xddc003ef,0x236801e4}},	//   _эдиш, _úrtø, _salū, tvaj_, 
   {{0xddc046e4,0xc208009f,0x00000000,0x00000000}},	// [38f50] _palū, لغام_, --, --, 
   {{0x28142be7,0x41680640,0x23680115,0x00000000}},	//   _بوکس, ијем_, rvaj_, --, 
   {{0xddc0005f,0x24580064,0xa07401ec,0x3f8c0042}},	//   _valū, _лань_, зылш, wygu_, 
   {{0xf77011dc,0x00000000,0x00000000,0x00000000}},	//   _ساۋ_, --, --, --, 
   {{0x4429f5cf,0x82342e6f,0x25f4012c,0x23680455}},	//   _idc_, _ورسا, ्डकी_, qvaj_, 
   {{0x7c380135,0x00000000,0x00000000,0x00000000}},	//   wgur, --, --, --, 
   {{0x44280208,0xdeec0092,0x00000000,0x00000000}},	//   _kdc_, ጀለኛ_, --, --, 
   {{0x44280129,0x5dd40150,0x67280327,0x00000000}},	//   _jdc_, _ﺘﺭﻜﻴ, ġejj, --, 
   {{0x7c39f5d0,0x4429f5d1,0x32d40227,0xa0a40116}},	//   rgur, _mdc_, wäyi_, _даңд, 
   {{0x7c39f5d2,0x752801f1,0xae040131,0x00000000}},	//   sgur, ádzk, _يوقى, --, 
   {{0x7690023a,0x9bf40276,0x4428012d,0x7c38022e}},	//   _käyv, _езеч, _odc_, pgur, 
   {{0xdee402d3,0xeb300372,0x00000000,0x00000000}},	//   _ዝረአ_, رۉۉد, --, --, 
   {{0x7c280857,0x00000000,0x00000000,0x00000000}},	//   _idgr, --, --, --, 
   {{0x4429f5d3,0x200c00ac,0x98700153,0xaa58022e}},	//   _adc_, əmiş_, pšį_, _мичу_, 
   {{0x442809ac,0xd5b000c6,0x00000000,0x00000000}},	//   _bdc_, رفر_, --, --, 
   {{0x44280f85,0x00000000,0x00000000,0x00000000}},	//   _cdc_, --, --, --, 
   {{0x10082e51,0x88380375,0x083808a8,0x00000000}},	// [38f60] ەتتى_, _התפו, _העפל, --, 
   {{0x920000cd,0xd4f40064,0x00000000,0x00000000}},	//   _śābd, _нямы, --, --, 
   {{0x4429f5d4,0x7c2963c9,0x114802dd,0xc0d80023}},	//   _fdc_, _odgr, спей_, _ሕሙም_, 
   {{0x44280998,0x4fe817a0,0xfbc8102f,0x70b8033f}},	//   _gdc_, бмен_, ाथाम, ेकेल, 
   {{0x1b000eac,0x291801ed,0xef7400e5,0xe3b40150}},	//   লীতে_, áraz_, بخاک, _жұт_, 
   {{0xe1f03f7b,0x7c2816b8,0xbea06c1f,0x543404fb}},	//   رسە_, _adgr, начк, _برگر, 
   {{0xfd0c00b2,0xf0780184,0x91e400ee,0xc0e40014}},	//   هجي_, _һиңә_, _хове, زکہٕ_, 
   {{0xc5f00375,0x7ae0002f,0x01a401ee,0x00000000}},	//   עדה_, _ahnt, _экск_, --, 
   {{0x7ae001e0,0x7c28010a,0x3b50004e,0xdcac00db}},	//   _bhnt, _ddgr, екыр, جۉن_, 
   {{0x7c283fc1,0x00000000,0x00000000,0x00000000}},	//   _edgr, --, --, --, 
   {{0x29189b4c,0xade81fd5,0x00000000,0x00000000}},	//   èra_, टेशन_, --, --, 
   {{0x8c440353,0x76900139,0x4ce400db,0x00000000}},	//   _хеде, _xäyv, _эжеб, --, 
   {{0x4429f5d5,0x4bd800aa,0x69dc0790,0x29000153}},	//   _rdc_, _اباد_, üreb, _čiau_, 
   {{0x4429f5d6,0xa9340137,0x00000000,0x00000000}},	//   _sdc_, _жекш, --, --, 
   {{0x4429f5d7,0xa4d43334,0x61e801e4,0xa48c0023}},	//   _pdc_, дові, _ĝelo, _ዘለውዎ_, 
   {{0x61e800df,0x70b800bc,0xdee40023,0xb884030d}},	//   _ŝelo, ेकोल, _ዝረኤ_, _зуьй, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [38f70] --, --, --, --, 
   {{0xd5ac00f1,0xe2980022,0x00000000,0x00000000}},	//   اځی_, әаҧ_, --, --, 
   {{0x4429f5d8,0x76900166,0x00000000,0x00000000}},	//   _tdc_, _cäyu, --, --, 
   {{0x4429f5d9,0xc0d80092,0x9f340150,0x00000000}},	//   _udc_, ዕምሮ_, деді, --, 
   {{0x644c05b1,0x7c280477,0x00000000,0x00000000}},	//   mfai, _rdgr, --, --, 
   {{0x644df5da,0x00000000,0x00000000,0x00000000}},	//   lfai, --, --, --, 
   {{0x236cb0e8,0x644d0238,0xceb400fd,0x37c800fe}},	//   _šejh_, ofai, фәт_, ৰেপৰ, 
   {{0x644df5db,0x9b0801b9,0x610400c0,0x759c011a}},	//   nfai, ониб_, _gėla, מיוח, 
   {{0x7690426d,0x644c0421,0x00000000,0x00000000}},	//   _käyt, ifai, --, --, 
   {{0x02bc00dc,0x644c01e7,0x769001f4,0x62840327}},	//   ्विभ, hfai, _jäyt, njho, 
   {{0x7c280175,0x76900139,0x95600023,0x00000000}},	//   _tdgr, _mäyt, _ትፍትን_, --, 
   {{0x7c29f5dc,0x47ac00cc,0x26f80401,0x32d40139}},	//   _udgr, _ঘড়ী, ंदूर_, läyt_, 
   {{0x644c0597,0x02bc102f,0x9a28004e,0x00000000}},	//   dfai, ्वाभ, _долб_, --, 
   {{0x76900664,0x3d000309,0xa904030f,0x69dc0790}},	//   _näyt, _kñw_, ببین, ürec, 
   {{0x644df5dd,0xe8e80066,0x00000000,0x00000000}},	//   ffai, تریو_, --, --, 
   {{0xf4844a23,0x644c007b,0x00000000,0x00000000}},	//   رازی, gfai, --, --, 
   {{0xd264bd80,0x26180037,0x00000000,0x00000000}},	// [38f80] мкай, _बड़की_, --, --, 
   {{0x77640928,0xe85c0030,0x644d177a,0x00000000}},	//   _isix, mýšľ, afai, --, 
   {{0x765df5de,0x644df5df,0x51940023,0x67200301}},	//   mery, bfai, መርኮሰ_, ćlje, 
   {{0x753df5e0,0x644c00c6,0xa3c8447d,0x628401e4}},	//   murz, cfai, _लुक_, ajho, 
   {{0x3d000227,0x61040153,0x8fd00166,0x00000000}},	//   _añw_, _vėla, тәвә, --, 
   {{0xfe6c08c9,0xc3300bd9,0x765df5e1,0x60c801e4}},	//   لدى_, _בוש_, nery, _ĉeme, 
   {{0x753da338,0x016000c2,0x13dc0aff,0xbd640108}},	//   nurz, _икро, _मरुभ, дрые_, 
   {{0x765df5e2,0x7765f5e3,0xecc401c0,0x769008e2}},	//   hery, _osix, эшлү, _käys, 
   {{0x765c531c,0x9f4c0139,0x6af46bb6,0x00000000}},	//   kery, _rgeç_, нзиф, --, 
   {{0x765df5e4,0x753c44ef,0x644c067c,0x8eb01c3e}},	//   jery, kurz, zfai, _جەتت, 
   {{0x7765f5e5,0x765df5e6,0x644df5e7,0x6f00009f}},	//   _asix, dery, yfai, _humc, 
   {{0x6f01f5e8,0x1cdc003d,0x29180140,0x9ce40212}},	//   _kumc, _རེར_, âraq_, _зціл, 
   {{0x765df5e9,0x0574168d,0x681000bc,0x6f00058a}},	//   fery, ژارد, vědč, _jumc, 
   {{0x765c99d0,0x77640175,0x753df5ea,0x6f01f5eb}},	//   gery, _dsix, furz, _mumc, 
   {{0x7765f5ec,0x04640046,0x753c970f,0xfaa000d8}},	//   _esix, мтам, gurz, _јајо, 
   {{0x76900724,0x32d4005b,0x00000000,0x00000000}},	//   _bäys, käys_, --, --, 
   {{0x644df5ed,0x765c2f99,0x69d86a56,0x26c000fb}},	// [38f90] rfai, bery, _hyve, _tjho_, 
   {{0x644df5ee,0xa2d431ed,0x69d80158,0x62840369}},	//   sfai, ريات, _kyve, ujho, 
   {{0x673c03a1,0x26d1f5ef,0xdb0c02f0,0x644df5f0}},	//   lusj, mozo_, čkéh, pfai, 
   {{0x26d1f5f1,0x76900139,0x6565f5f2,0x6284003b}},	//   lozo_, _fäys, _ishh, sjho, 
   {{0x76900664,0x6d48157f,0x69d820e4,0x673c00b5}},	//   _täyt, _aqda, _lyve, nusj, 
   {{0x2d48145e,0x69d80455,0x26d1f5f3,0xe2c846bc}},	//   fûe_, _oyve, nozo_, _روزو_, 
   {{0xe66801ec,0x644800e4,0x69d801bf,0x9cf40117}},	//   _ءﺍﭖ_, _ñeis, _nyve, нчиш, 
   {{0x26d1f5f4,0x765df5f5,0xace801f7,0x00000000}},	//   hozo_, zery, وريل_, --, 
   {{0x753df5f6,0x7690005b,0x673c000d,0xf04403f5}},	//   zurz, _mäyr, jusj, _шэро, 
   {{0x961c0316,0x0ae40598,0x65647155,0x69d8005c}},	//   _बजेट_, ндый_, _oshh, _byve, 
   {{0xdd91f5f7,0x765df5f8,0xae74066d,0x26d1f5f9}},	//   _حوا_, very, _جھنڈ, dozo_, 
   {{0x77650616,0x69d80158,0x673c08fb,0x1869f5fa}},	//   _psix, _dyve, fusj, чами_, 
   {{0x6565f5fb,0x753c0112,0x673df5fc,0x9f5800fd}},	//   _ashh, wurz, gusj, _üsä_, 
   {{0x26d0637e,0xcb340a1e,0x753c012d,0xcb642bbd}},	//   gozo_, _נאצי_, turz, _чаше_, 
   {{0x69d84077,0x7690008e,0x63a80432,0x00000000}},	//   _gyve, _bäyr, _ýenj, --, 
   {{0x673c168c,0x1309f5fd,0x76900139,0x5ac80244}},	//   busj, знай_, _cäyr, _باڤێ_, 
   {{0xb9dc0201,0x765cb496,0x26d1f5fe,0x77640921}},	// [38fa0] _ብር_, pery, bozo_, _usix, 
   {{0xdb180227,0x753c026c,0x32d4005b,0x51640137}},	//   _ixwä, purz, väys_, нүгү_, 
   {{0x6f01f5ff,0x7690013d,0x91e4034b,0x302401f0}},	//   _sumc, _fäyr, хоже, взеҳ, 
   {{0x7690049b,0x6f00016d,0x65c002dd,0x6298017a}},	//   _täys, _pumc, _тұса, ëwor, 
   {{0x6f00014f,0x76900139,0xfbac0892,0xf1d0228d}},	//   _qumc, _häyq, _जेलम, _तुरन, 
   {{0x11d402bf,0xa3c82e1e,0xa3bc07f7,0x6f000477}},	//   _зібр, _लुट_, इपर_, _vumc, 
   {{0xc69023e4,0x6f00014b,0xbd8400c6,0x32d4005b}},	//   ראו_, _wumc, فنون_, säys_, 
   {{0x76900724,0x26d1f600,0x6f00009f,0x69d80f12}},	//   _xäyr, zozo_, _tumc, _ryve, 
   {{0x69d8117e,0x26d000f1,0x00000000,0x00000000}},	//   _syve, yozo_, --, --, 
   {{0xc331214c,0x328400d1,0x673c000d,0x00000000}},	//   נות_, _ﯬﻣﻪﺱ_, vusj, --, 
   {{0xcd340050,0x26d005da,0xdd8001d9,0x6d48014f}},	//   _سراب, vozo_, _نیوٝ, _uqda, 
   {{0x26f83eaf,0x673df601,0x26d002ce,0x1b000588}},	//   ंद्र_, tusj, wozo_, ыҟәг, 
   {{0x69d8070d,0x26d1f602,0x6564f9cf,0xfce00f06}},	//   _wyve, tozo_, _sshh, _соцо, 
   {{0x69d84e9b,0x656405be,0x673df603,0x167000c7}},	//   _tyve, _pshh, rusj, ақьр, 
   {{0x26d1f604,0xf1d0023e,0x69d8014b,0x00000000}},	//   rozo_, _तुलन, _uyve, --, 
   {{0x26d1f605,0x34c0000d,0xa77401f0,0x00000000}},	//   sozo_, _एदृद, _алич, --, 
   {{0x2a7c24d1,0x7c2c5178,0x3358084c,0x26d0010f}},	// [38fb0] _knvb_, ócri, натэ_, pozo_, 
   {{0x26d0141b,0x056800f0,0x00000000,0x00000000}},	//   qozo_, _ејми_, --, --, 
   {{0x94100134,0xf2c4023a,0x00000000,0x00000000}},	//   nhyɛ_, устн, --, --, 
   {{0x42c02b1b,0x672c01bf,0xf1c85a07,0xa3b40153}},	//   ্গেশ, _kvaj, رونى_, _абмі, 
   {{0x672c0327,0x7690005b,0x3818011a,0xb3c801c6}},	//   _jvaj, _käyp, תקדם_, _зурж_, 
   {{0xb18c044e,0x6235f606,0x5398011a,0x0c7001d5}},	//   ዘይኮነ_, _шегу, _חישו, یگند, 
   {{0xdca400c9,0x3f980309,0xaca80014,0xad580108}},	//   каки, šqu_, کھٕے_, ерых_, 
   {{0x2489f607,0x672c0cf4,0x00000000,0x00000000}},	//   njam_, _ovaj, --, --, 
   {{0x3ab0506f,0x4b200a89,0x69a401e0,0x9f2000d1}},	//   ләкт, амыв, ҫлыҡ, _ئۈتۈ, 
   {{0x3da40faa,0x1ee803e6,0xdd94035b,0x00000000}},	//   _преб, _کوڕی_, _иазы, --, 
   {{0x98a47cd1,0x2b58054e,0x18a4010b,0x611403b9}},	//   вине, ărca_, ванм, _işlә, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x672c01fa,0xda6504ae,0x00000000,0x00000000}},	//   _cvaj, _авли, --, --, 
   {{0x672d015d,0x998400c6,0x26c414d4,0xaa6401ee}},	//   _dvaj, _للتو, лғын_, _бешһ, 
   {{0xceb06da4,0x672d5087,0x398001b9,0x344800ee}},	//   בים_, _evaj, _صیحف, нүни_, 
   {{0x161c012d,0x00000000,0x00000000,0x00000000}},	//   _बजकर_, --, --, --, 
   {{0x25ac0115,0xf2c40022,0xf8640117,0x00000000}},	// [38fc0] ĝela_, гиаҿ, _авқо, --, 
   {{0x200c0605,0x51f41896,0x60c80115,0x24880153}},	//   _afei_, نسار, _ĉema, ajam_, 
   {{0x672c05b8,0xdd8401d9,0x6264129d,0x00000000}},	//   _zvaj, _اڈ_, داقق, --, 
   {{0x644800e4,0x00000000,0x00000000,0x00000000}},	//   _ñeip, --, --, --, 
   {{0xb184010b,0xcee800ec,0x63a800ef,0x00000000}},	//   _әңед, ورتن_, _ļeng, --, 
   {{0x6e9400c6,0x00000000,0x00000000,0x00000000}},	//   طلبا, --, --, --, 
   {{0x0d640395,0x00000000,0x00000000,0x00000000}},	//   тълм, --, --, --, 
   {{0x6c3401d3,0xfce401e2,0x00000000,0x00000000}},	//   اہشا, نځني_, --, --, 
   {{0x0e640124,0xfba401c6,0xcf44011c,0x00000000}},	//   _икан, втэй_, _шнай, --, 
   {{0x98a5f608,0x9e65f609,0x8b9400fd,0x6ee40100}},	//   kulē_, _مامن, ерүч, bòba, 
   {{0x672df60a,0xbc642fc0,0xe8940153,0xe5a00150}},	//   _svaj, رمین_, гань, _ﺍﻁﺎﺭ_, 
   {{0x2aa0067c,0xc7c401c6,0x00000000,0x00000000}},	//   _dòba_, всги, --, --, 
   {{0x0eb40316,0x3cf805f9,0xbb400064,0x00000000}},	//   _अगाड, _लूटे_, _вечк, --, 
   {{0x248803a2,0xf98c004b,0xe97401f7,0xfaa00120}},	//   wjam_, _ژبي_, _مهتد, _ваљо, 
   {{0x2489f60b,0x98a400de,0xddc00171,0xf964586a}},	//   tjam_, gulē_, _kalš, _арый_, 
   {{0x9ba00131,0x672c00b8,0x00000000,0x00000000}},	//   _خەۋى, _tvaj, --, --, 
   {{0x2489f60c,0x672c09a8,0xddc1f60d,0x00000000}},	// [38fd0] rjam_, _uvaj, _malš, --, 
   {{0x02bc1d03,0x67280010,0x00000000,0x00000000}},	//   ्वेन, šejs, --, --, 
   {{0x24880054,0x65959f58,0xe038084c,0x00000000}},	//   pjam_, _сану, езеч_, --, 
   {{0x24880054,0x00000000,0x00000000,0x00000000}},	//   qjam_, --, --, --, 
   {{0x33844140,0x00000000,0x00000000,0x00000000}},	//   _курв, --, --, --, 
   {{0x64a40022,0x714400db,0x00000000,0x00000000}},	//   _раҭа, _چۉلۅ, --, --, 
   {{0x8ff4425b,0x20081709,0xddc0009b,0x69dc0205}},	//   نزۇچ, ñais_, _balš, ürel, 
   {{0x2aa0067c,0x27ec00bc,0x6ee5b79d,0x00000000}},	//   _ròba_, ženy_, ròba, --, 
   {{0xddc002f8,0x7094013d,0x00000000,0x00000000}},	//   _dalš, _татф, --, --, 
   {{0x7f580113,0x2fc0007b,0x9915f60e,0xdea055b2}},	//   _ipuq, úige_, льмі, _دیتی, 
   {{0x4ff40241,0xdc5401d5,0x00000000,0x00000000}},	//   _iṣaṣ, _مرشک, --, --, 
   {{0xf8c402f5,0x00000000,0x00000000,0x00000000}},	//   োষ্ঠ, --, --, --, 
   {{0xb8ccc853,0x51940023,0x00000000,0x00000000}},	//   _गत_, መርኰሰ_, --, --, 
   {{0xd9446073,0xc6d401c0,0xe63401c6,0x6a58014b}},	//   _беки, гссө, ихсэ, _ашъё_, 
   {{0xceb006a9,0x2d980205,0x00000000,0x00000000}},	//   זים_, _üret_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x78a5f60f,0xdee00023,0x527467f0,0x00000000}},	// [38fe0] _iliv, ሞምን_, лужу, --, 
   {{0x16640063,0x4220010b,0x78a40419,0xfbc40137}},	//   _свом, йдув, _hliv, _ۇت_, 
   {{0x7f5802d1,0x78a47f9d,0xc690008f,0xe3b001d3}},	//   _apuq, _kliv, _לאז_, مرے_, 
   {{0x1b1809bd,0xfbc405d9,0x2edc694b,0x21742360}},	//   _দিনে_, _هت_, यत्त, шуур, 
   {{0x78a401f7,0x00000000,0x00000000,0x00000000}},	//   _mliv, --, --, --, 
   {{0x3fc9f610,0x78a4004e,0x40a803e6,0xbfc80116}},	//   ردنی_, _lliv, وخۆی_, رانە_, 
   {{0xf985c5a6,0xddc00153,0x00000000,0x00000000}},	//   _اب_, _palš, --, --, 
   {{0xcce401f7,0x69dc03e0,0xac9400d8,0x00000000}},	//   دستي, ürem, раиш, --, 
   {{0x4090fdc2,0xe1f0004b,0xc86401d5,0x0d8401e0}},	//   _القر, _هسې_, қтни, _әлен, 
   {{0x78a5f611,0xc9840114,0x00000000,0x00000000}},	//   _aliv, гуми, --, --, 
   {{0x78a5f612,0x2d981088,0x7af000bc,0xa2d40118}},	//   _bliv, _ære_, _řetí, बकत्, 
   {{0x78a5f613,0x1cdc0003,0x61e000b5,0xfce08b11}},	//   _cliv, _རེག_, _ølle, _лохо, 
   {{0x78a402c4,0xfcd071f1,0x19c000fb,0x00000000}},	//   _dliv, _اينج, йҙәг, --, 
   {{0x78a4035a,0xc6a41955,0x2d9801ed,0xdce000e2}},	//   _eliv, урми, _üres_, _islā, 
   {{0x78a46035,0x25ac010f,0xc95801d5,0x00000000}},	//   _fliv, ĝelo_, _чўл_, --, 
   {{0x78a5f614,0xd6d8013e,0x25ac0115,0x00000000}},	//   _gliv, етӣ_, ŝelo_, --, 
   {{0x68edf615,0xa2b5f616,0x00000000,0x00000000}},	// [38ff0] _ihad, абач, --, --, 
   {{0x27e8152d,0xf77002dd,0x6235015b,0x78a40427}},	//   _izan_, _ءاي_, режу, _zliv, 
   {{0x68edf617,0x78a402f6,0x2184016c,0x61040024}},	//   _khad, _yliv, штаҳ, _kėli, 
   {{0x8025f618,0x99c000fe,0x78a401ef,0x00000000}},	//   ارام, _উৰুক, _xliv, --, 
   {{0x68edf619,0xdef400ee,0x3ae80fac,0x61040064}},	//   _mhad, апды, løpe_, _mėli, 
   {{0x63ac021a,0x68ec020c,0x1cdc031c,0x62240131}},	//   mzan, _lhad, _རེང_, _خىسل, 
   {{0x63adf61a,0x6ee40ba1,0xa1940120,0x2c000241}},	//   lzan, mòbl, _тавч, _ẹjọ_, 
   {{0x63adf61b,0x27e83c7a,0x1b18015b,0x98a400e2}},	//   ozan, _ozan_, _দিবে_, kslā_, 
   {{0x63adf61c,0x60c80295,0x201df61d,0xd5d000bc}},	//   nzan, _ijem, mbwi_, _दुईज, 
   {{0x60c8501b,0x78a583c8,0x68edf61e,0x63ac05da}},	//   _hjem, _sliv, _ahad, izan, 
   {{0x27e9f61f,0x7e61f620,0x60c81a82,0x68ec0882}},	//   _azan_, menp, _kjem, _bhad, 
   {{0x7e61f621,0x63ac061c,0x60c804ba,0xefdc0240}},	//   lenp, kzan, _jjem, ሕግዝ_, 
   {{0x63ac04a7,0x68edf622,0x60c801f7,0x78a4012c}},	//   jzan, _dhad, _mjem, _vliv, 
   {{0x63add6ce,0x7e61f623,0x8f98008f,0x96b9f624}},	//   dzan, nenp, דישי, туму_, 
   {{0x68ec1549,0x27e9f625,0x7ce80209,0x60c9f626}},	//   _fhad, _ezan_, _görý, _ojem, 
   {{0x60c82804,0x68edf627,0x78a5f628,0x61040006}},	//   _njem, _ghad, _uliv, _gėli, 
  
   {{0x63adf629,0x7e61f62a,0x65740165,0x965402e8}},	// [39000] gzan, kenp, avzh, _кънч, 
   {{0x60c90b7c,0x6d5c0254,0x68ec0419,0x7e6001f4}},	//   _ajem, _ärag, _zhad, jenp, 
   {{0x7e61f62b,0x63adf62c,0x11480eff,0x2eec007c}},	//   denp, azan, тпей_, _rhdf_, 
   {{0x68ec0200,0x63ac01ef,0x00000000,0x00000000}},	//   _xhad, bzan, --, --, 
   {{0x63ac068f,0x60c9f62d,0x7e60fc8e,0xd3940075}},	//   czan, _djem, fenp, _тәвә_, 
   {{0x8d75f62e,0x60c844d5,0x3a24007f,0xfba80154}},	//   لاعا, _ejem, _nenp_, খপাত, 
   {{0xceb80198,0x8d85f62f,0x1ea8951b,0x217400f3}},	//   riƙ_, рулд, داني_, _лутр, 
   {{0x60c9f630,0x7dc010a8,0x00000000,0x00000000}},	//   _gjem, تقىن, --, --, 
   {{0x5378001f,0x7e604431,0xfde401e0,0x68edf631}},	//   _ሠራዊት_, benp, лдәк_, _rhad, 
   {{0x8d7404a9,0x3a240077,0x68eceea1,0x60c805d6}},	//   _پائا, _cenp_, _shad, _zjem, 
   {{0x63adf632,0x68edf633,0x00000000,0x00000000}},	//   zzan, _phad, --, --, 
   {{0x63adf634,0x68ec01ee,0x6e29f635,0x8b64114f}},	//   yzan, _qhad, _hedb, _ناتم, 
   {{0x68ec0084,0x610402d5,0x2d9df636,0x4a7401e0}},	//   _vhad, _vėli, lyve_, _ҡыҫт, 
   {{0x6e28014f,0x69c400fd,0x98a40064,0x00000000}},	//   _jedb, _гөмб, kulė_, --, 
   {{0x68edf637,0x6e2838aa,0xe98402dd,0x2d9c01d3}},	//   _thad, _medb, _داشۋ, nyve_, 
   {{0x63adf638,0x1b1803f4,0x7e6001a4,0x27e801c4}},	//   tzan, _দিতে_, zenp, _tzan_, 
   {{0x63ac21c9,0x60c8000f,0x7e6161d9,0x27e803e0}},	// [39010] uzan, _rjem, yenp, _uzan_, 
   {{0x63adf639,0x60c839ca,0xb3c806ab,0x85443cc5}},	//   rzan, _sjem, _रखरख, _кэме, 
   {{0x592c2fb5,0x63adf63a,0xa4d41cb8,0x3208014b}},	//   ྩེགས_, szan, _гоні, рхун_, 
   {{0x9f4c010e,0x290c058a,0x63ac007f,0x00000000}},	//   _egeý_, iqda_, pzan, --, 
   {{0x1fb958ff,0x3f6448f0,0x7e601072,0x60c801ef}},	//   ылды_, ртеб, tenp, _vjem, 
   {{0x6e2800b8,0x2294007b,0x81147ff6,0x2368012d}},	//   _cedb, _الآس, _نذرا, mwaj_, 
   {{0x365c0302,0x6e2803f9,0x62940472,0x7e61f63b}},	//   דכונ, _dedb, _iozo, renp, 
   {{0x60c82bcd,0x7e61e5a9,0x6e28127b,0x6295f63c}},	//   _ujem, senp, _eedb, _hozo, 
   {{0x62941aac,0xdd90066d,0x7e600100,0xab280032}},	//   _kozo, توں_, penp, аныҡ_, 
   {{0x6e2801ab,0x7ed400db,0x7e600309,0x7e7400d1}},	//   _gedb, _ئزرا, qenp, ﻠﻠﻪﺕ_, 
   {{0x6295f63d,0x2d980166,0x00000000,0x00000000}},	//   _mozo, _ürep_, --, --, 
   {{0x2368014b,0x6e2801e4,0xac74007b,0x115800df}},	//   kwaj_, _zedb, _وانش, נדרע, 
   {{0x629437cf,0x290c0067,0x592c0327,0xdb0c0241}},	//   _oozo, aqda_, ྩེངས_, _àjàd, 
   {{0x6294105c,0x1a640517,0x60d80309,0x2368037e}},	//   _nozo, _ایدی_, howm, dwaj_, 
   {{0x61040064,0x00000000,0x00000000,0x00000000}},	//   _kėlu, --, --, --, 
   {{0x6295f63e,0x6d5c0254,0x63a80210,0x00000000}},	//   _aozo, _ärae, _żena, --, 
   {{0x6295f63f,0x96b9f640,0x13e9f641,0x60d9f642}},	// [39020] _bozo, _буну_, умай_, dowm, 
   {{0x62940311,0x00000000,0x00000000,0x00000000}},	//   _cozo, --, --, --, 
   {{0x6295f643,0xd1cc001f,0x84e0007d,0x00000000}},	//   _dozo, ጥፋት_, _कीकट_, --, 
   {{0xcfa49a9a,0x241800d4,0x2d9c0022,0x00000000}},	//   йшли, _вірю_, vyve_, --, 
   {{0xefdc0023,0x00000000,0x00000000,0x00000000}},	//   ዕልዎ_, --, --, --, 
   {{0xcd480323,0x62946b9e,0x2d9c598e,0x1cdc0327}},	//   гчид_, _gozo, tyve_, _རེཔ_, 
   {{0x6e280726,0x60d8020c,0xf8d80073,0x00000000}},	//   _vedb, bowm, ठवाय, --, 
   {{0x62945318,0x54f800af,0x6ad019cc,0xeb389100}},	//   _zozo, ्दिए_, सक्र, азиш_, 
   {{0x00803f1d,0x6e293b0c,0x6295f644,0x2d9c12c1}},	//   _элто, _tedb, _yozo, syve_, 
   {{0x0a680364,0x25040882,0xaab402bf,0x2b440175}},	//   урии_, niṣṭ, ійні, rumc_, 
   {{0x290c0007,0x769000fd,0x00000000,0x00000000}},	//   uqda_, _fäyz, --, --, 
   {{0x290c2994,0x2368033f,0x61040064,0x00000000}},	//   rqda_, ywaj_, _gėlu, --, 
   {{0x62800162,0xc7b80107,0x00000000,0x00000000}},	//   _ólog, уён_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3ab80d65,0x6295f645,0xba707224,0xe8940124}},	//   _תמונ, _rozo, _راوت, _макь, 
   {{0x1cdc0003,0xc0b8001f,0x00000000,0x00000000}},	//   _རེབ_, ሳቀስ_, --, --, 
   {{0x61140cc1,0x3ae805ac,0xed480023,0x00000000}},	// [39030] _işlə, løpa_, _ዘይቅኑ, --, 
   {{0x629407d6,0x062477cf,0x25081fb8,0xf4a80092}},	//   _qozo, _уфим, _پردی_, _መገለጥ_, 
   {{0xb7141291,0x00000000,0x00000000,0x00000000}},	//   _وبیش, --, --, --, 
   {{0x62948132,0x6ee401c3,0x7cd00356,0x00000000}},	//   _wozo, lòbh, mărg, --, 
   {{0x6295f646,0x645c198f,0xde0422c3,0x60d8013f}},	//   _tozo, _ibsi, опли, rowm, 
   {{0x4429f647,0x88cc00bd,0xbee000cd,0x25040055}},	//   _hec_, রতিক, गतेन_, ciṣṭ, 
   {{0x1cdc3aaf,0x44284862,0x3ae805ac,0xec0401e1}},	//   _རེད_, _kec_, jøpa_, _ẹhọn, 
   {{0xdfd4470e,0x4429f648,0x80258fbc,0x61040006}},	//   _добы, _jec_, _درآم, _dėlt, 
   {{0xfe74021f,0x61040153,0xdaa88cff,0xbfa8009b}},	//   _гүл_, _vėlu, ивид_, _стве_, 
   {{0x442807e4,0xddd0012d,0x00000000,0x00000000}},	//   _lec_, ągłe, --, --, 
   {{0x645df649,0x442806ee,0x3da4004e,0x00000000}},	//   _obsi, _oec_, _ураб, --, 
   {{0x4428c51b,0x6b8401fa,0x98a40024,0xac940131}},	//   _nec_, _šige, kslą_, _нахш, 
   {{0x7c2800e2,0x63a8025c,0x9054011a,0x7a4001d3}},	//   _iegr, _żenn, חברו_, gítü, 
   {{0x05d80c2e,0x0b14007b,0x00000000,0x00000000}},	//   _मुहब, _بقوة_, --, --, 
   {{0x4429f64a,0x25040882,0x1c0c02ab,0x645c0175}},	//   _bec_, viṣṭ, _हलाल_, _bbsi, 
   {{0x5f44001f,0x645c045a,0xc950011a,0x195801af}},	//   _የግንቦ, _cbsi, _חמה_, _баҫы_, 
   {{0x7c28d787,0x25040a28,0x44283d4a,0x00000000}},	// [39040] _megr, tiṣṭ, _dec_, --, 
   {{0x7c29f64b,0x44290996,0x645cdb94,0x1dc800dc}},	//   _legr, _eec_, _ebsi, िपात, 
   {{0x4428a3d4,0x00000000,0x00000000,0x00000000}},	//   _fec_, --, --, --, 
   {{0x4429f64c,0xc0b8001f,0x6ee40137,0x8fa400f2}},	//   _gec_, ሳቀሱ_, mòbi, يماه, 
   {{0xa3bc1d68,0x76900139,0xe6400023,0x00000000}},	//   ेपण_, _säyy, _ንምእን, --, 
   {{0x4429f64d,0x877825f9,0x7c281730,0xbea015ed}},	//   _zec_, יאני, _aegr, мачк, 
   {{0x0ca9f64e,0x10a5f64f,0x44280489,0x506401d9}},	//   итии_, _дивн, _yec_, _وارِ, 
   {{0x4429f650,0x14d80073,0x00000000,0x00000000}},	//   _xec_, ढविण, --, --, 
   {{0x7c29f651,0xfbcc01ed,0xf07801af,0xdcac0372}},	//   _degr, ہتی_, _киңә_, دۉن_, 
   {{0x60c8010f,0x1b1800fe,0x00000000,0x00000000}},	//   _ĉemi, _দিশে_, --, --, 
   {{0xc27825f9,0x2918044e,0xfbcdf652,0x3ed40150}},	//   בריי, ëra_, فتی_, _بولج_, 
   {{0x7c2885de,0x2919f653,0x67d40454,0x00000000}},	//   _gegr, īra_, зому, --, 
   {{0x29185c07,0x27ec12ed,0x6011066d,0x00000000}},	//   ūra_, åen_, _hómó, --, 
   {{0x7c291889,0x2f10002e,0xaa59017f,0x6ee400cf}},	//   _zegr, _màg_, _طلبا_, fòbi, 
   {{0x25a42bb4,0x7c29f654,0x4428005b,0x06b8010b}},	//   áll_, _yegr, ицам_, гыңъ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x44281828,0x2f100051,0x78a0007c,0x00000000}},	// [39050] _vec_, _nàg_, ömve, --, 
   {{0x7cd00276,0x04e8015b,0x98a40024,0xb9e40137}},	//   măre, কদের_, rslą_, _اتۇۇ, 
   {{0x9410016b,0xdfd0004b,0x76900139,0x7cd0054e}},	//   nkyɛ_, ډيا_, _räyx, lăre, 
   {{0xdfd00372,0xf990008d,0x4429f655,0x0044004b}},	//   ىيا_, ורע_, _uec_, تیري_, 
   {{0x7c29f656,0x7cd00311,0x50a00131,0xa30801d3}},	//   _regr, năre, رەكل, _درجے_, 
   {{0x644df657,0x93701b49,0x1d09f658,0x326421fa}},	//   lgai, _ብርሃነ_, беки_, _отсв, 
   {{0x7c280810,0x644df659,0x7cd00356,0x66140210}},	//   _pegr, ogai, hăre, iczk, 
   {{0x2f1001c3,0xd3340345,0x00000000,0x00000000}},	//   _fàg_, _ببێژ, --, --, 
   {{0x7c29f65a,0x6ee40100,0x644dcc4b,0x00000000}},	//   _vegr, zòbi, igai, --, 
   {{0x7c29f65b,0x644c0007,0x1cdc031c,0x7cd0054e}},	//   _wegr, hgai, _རེམ_, dăre, 
   {{0x644c4d11,0x00000000,0x00000000,0x00000000}},	//   kgai, --, --, --, 
   {{0x644c0007,0x6614033f,0x7c2802d0,0x6d5c000d}},	//   jgai, eczk, _uegr, _äraa, 
   {{0x7cd0054e,0x8d600092,0x00000000,0x00000000}},	//   găre, _ሰርተው_, --, --, 
   {{0x3b1c0784,0xb81c04aa,0x644df65c,0x00000000}},	//   mpuq_, _भ्रम_, egai, --, 
   {{0x98a5f65d,0x69dc9482,0x09e00818,0x00000000}},	//   _нике, üret, _пошн, --, 
   {{0x1cc807e4,0xd87407d2,0x940c016b,0x6ee400db}},	//   _ིམས_, _رابب, ɔfɛ_, ròbi, 
   {{0x386000ca,0x7cd00276,0xc8c40014,0xd4680032}},	// [39060] _ibir_, căre, _روٝن_, _һине_, 
   {{0x644df65e,0x9694026a,0x00000000,0x00000000}},	//   agai, _хриш, --, --, 
   {{0x3860003d,0x8698008f,0x4ff40248,0x00000000}},	//   _kbir_, _הייז, _iṣiṣ, --, 
   {{0x2f100137,0x77640158,0x644c010a,0x765c0368}},	//   _pàg_, _kpix, cgai, lfry, 
   {{0x38601574,0x59dc00ab,0xb4d81bd6,0x00000000}},	//   _mbir_, _नुसर, िवी_, --, 
   {{0x3321f65f,0x765cdf4f,0xfd0c18a2,0x3b1c0455}},	//   mpix_, nfry, گجو_, dpuq_, 
   {{0x3321f660,0xacf80953,0x7cd0054e,0xac940354}},	//   lpix_, онку_, zăre, дайш, 
   {{0x3860002e,0x6614012d,0xc2240241,0x00000000}},	//   _nbir_, zczk, _ẹ̀rí, --, 
   {{0x3320ef77,0x765c4b68,0x6614033f,0x4ff40ca8}},	//   npix_, kfry, yczk, _oṣiṣ, 
   {{0x3861f661,0x765c000f,0x644df662,0x4ff40248}},	//   _abir_, jfry, zgai, _nṣiṣ, 
   {{0x05d852f2,0xcc1002e3,0x9e640014,0x765db32a}},	//   _मुंब, _bọtị, _زالن, dfry, 
   {{0x48a83967,0x4ff40ca8,0x386001ab,0x644c0097}},	//   стом_, _aṣiṣ, _cbir_, xgai, 
   {{0x765c0368,0x00000000,0x00000000,0x00000000}},	//   ffry, --, --, --, 
   {{0x6d580373,0xe7e01157,0x765c5cf8,0x7cd00356}},	//   otva, _गुणा_, gfry, răre, 
   {{0x6d59f663,0x644cba3a,0xc984074d,0x386001ab}},	//   ntva, tgai, _хули, _fbir_, 
   {{0x3860031c,0x3218017a,0x644df664,0x2d5801e4}},	//   _gbir_, _afry_, ugai, _pɩej_, 
   {{0x3858215e,0xe5a40116,0xdce00064,0xa2a40014}},	// [39070] _رشيد_, чиңи, _erlė, وٝرى, 
   {{0x644df665,0x6d58002b,0x38600cf4,0x24980036}},	//   sgai, ktva, _zbir_, _wosm_, 
   {{0x91c00058,0x6d5801a4,0x9200002b,0x00000000}},	//   вәтл, jtva, _śārd, --, 
   {{0x644c0369,0x00000000,0x00000000,0x00000000}},	//   qgai, --, --, --, 
   {{0x7eac174e,0x2d7c01e4,0x5ec400bd,0x00000000}},	//   _løpe, _aĉe_, _লীগে, --, 
   {{0x6d586fa8,0x5de401c6,0x00000000,0x00000000}},	//   ftva, мжла, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x70580b01,0x5ba80815,0xb7bc00d1,0x00000000}},	//   _наср_, жким_, ﻧﻼﺭﻏ, --, 
   {{0xd1d402d3,0x765c0368,0x490400ab,0x6d5c0037}},	//   ካይቭ_, yfry, _संजो_, _äran, 
   {{0x718401d9,0x7f480117,0x3b1cb3c1,0x998400a2}},	//   _تٔہن, mugq, rpuq_, nalŧ_, 
   {{0x81dc3fa7,0xdd900740,0x7f4801b3,0x7c8452d1}},	//   দের_, _جوا_, lugq, _нуде, 
   {{0x7eac003b,0x3321d6aa,0x765c0142,0x00000000}},	//   _døpe, ypix_, wfry, --, 
   {{0xbbe9f666,0x8c14038b,0xddc001a6,0x765c002d}},	//   _ارام_, _غيور_, _jalž, tfry, 
   {{0xcc10063f,0x69d805d7,0xd944004e,0xddc000d7}},	//   _fọsị, _नुकी, _жеки, _malž, 
   {{0x99841060,0x765d6f6b,0x7cd00276,0x00000000}},	//   _آلبو, rfry, cărc, --, 
   {{0x7f48edcf,0x1ad400bd,0x2aa001e1,0x65640175}},	//   kugq, _হওয়া, _dòbu_, _dphh, 
   {{0x765c0225,0xcc1001f2,0x3b0406be,0x00000000}},	// [39080] pfry, _kọrị, _kinq_, --, 
   {{0x3320010a,0x6d585db4,0x00000000,0x00000000}},	//   rpix_, ytva, --, --, 
   {{0x98a400c0,0x9424014b,0x00000000,0x00000000}},	//   nulį_, _омне, --, --, 
   {{0x4fe8b9ac,0x53a5f667,0xefd0001f,0xa0a402dd}},	//   омен_, _жамб, _ሥራው_, ншіл, 
   {{0xb3840184,0x7ae00083,0x7f48009a,0x00000000}},	//   _яһал, _oknt, gugq, --, 
   {{0x6d581161,0xd250b991,0xcc1001f2,0xa3bc3874}},	//   ttva, _جنس_, _nọrị, ेपर_, 
   {{0x6d582dba,0x00000000,0x00000000,0x00000000}},	//   utva, --, --, --, 
   {{0x7f481cdf,0x291c004e,0xdd9001ed,0x7eac1445}},	//   bugq, _rtva_, اوٹ_, _røpe, 
   {{0x6d59f668,0x7ae000fb,0x0a692042,0x0fb40244}},	//   stva, _bknt, орни_, _تێشک_, 
   {{0x3b0485f8,0x2b440c67,0x6d5c0037,0xfe4001a9}},	//   _cinq_, rrmc_, _ärao, _анфо, 
   {{0xc278011a,0x6d58022e,0xfa2400cc,0x00000000}},	//   קרטי, qtva, _মাখল_, --, 
   {{0x7ae00083,0x7c8000c7,0xdb0801ed,0x8c448ab1}},	//   _eknt, _ауше, szeá, _цеде, 
   {{0x6f0802e2,0x7cd00311,0x2fc0007b,0xba70036b}},	//   _kidc, sărc, úigh_, رایت, 
   {{0x7cd00311,0x057402f2,0x291c00b8,0x00000000}},	//   măra, وازد, _ttva_, --, 
   {{0x6f09f669,0x7cd00311,0x291c0158,0x00000000}},	//   _midc, lăra, _utva_, --, 
   {{0x6f080421,0x00000000,0x00000000,0x00000000}},	//   _lidc, --, --, --, 
   {{0xfd4c06d6,0x29080a73,0x6f0845bc,0x33580276}},	// [39090] _dziṱ, _iiaa_, _oidc, матэ_, 
   {{0x27e9f66a,0x2909f66b,0x68fc03f2,0x6f08014f}},	//   _iyan_, _hiaa_, lmsd, _nidc, 
   {{0x672c0433,0x7f480921,0x26c1f66c,0x68fc0332}},	//   _hwaj, wugq, _imho_, omsd, 
   {{0x27e83142,0x672c0a68,0x851805db,0x11f401d5}},	//   _kyan_, _kwaj, _ụgwọ_, رتلگ, 
   {{0x6f09f66d,0x42700022,0xbf6808de,0x68fc8b98}},	//   _bidc, _иҳас, تصام_, imsd, 
   {{0xd354025f,0x672df66e,0x62241b56,0x7cd00356}},	//   _אישי_, _mwaj, _سىرل, dăra, 
   {{0x672df66f,0xceb5f670,0x27e80139,0x290801e1}},	//   _lwaj, хәт_, _lyan_, _oiaa_, 
   {{0xb0e80156,0x672c0b6f,0x2908013f,0x91c00220}},	//   _ཧེགེ, _owaj, _niaa_, _сәул, 
   {{0x27e9f671,0x200c0618,0x672c0198,0x7f486b6c}},	//   _nyan_, _igei_, _nwaj, qugq, 
   {{0x2ef5f672,0xdd94dccd,0xc0d40023,0x3da4011c}},	//   _азур, _пазы, ርዮም_, _ореб, 
   {{0x2908013f,0x27e9f673,0x672db1cb,0x2918010f}},	//   _biaa_, _ayan_, _awaj, ŭran_, 
   {{0x2d980228,0x672c046a,0x26c0022e,0x29080010}},	//   _àrea_, _bwaj, _amho_, _ciaa_, 
   {{0x1b1803f4,0x7ba40597,0x29080327,0xc95401d5}},	//   _দিকে_, _تصام, _diaa_, ولیش_, 
   {{0x27e9f674,0x09a80156,0xd9380075,0x68fc057b}},	//   _dyan_, བརྡ_, _ечиш_, amsd, 
   {{0xcc1002e3,0x672c0241,0x27e999d1,0x200c005a}},	//   _kọpị, _ewaj, _eyan_, _ogei_, 
   {{0x200c0084,0x25a4b5a4,0x6ee40ba1,0x27ec012d}},	//   _ngei_, ølla_, nòbr, żena_, 
   {{0x672c0c09,0x27e9f675,0x43402f33,0xb91000cd}},	// [390a0] _gwaj, _gyan_, летв, _ahaḥ_, 
   {{0xddc00327,0x00000000,0x00000000,0x00000000}},	//   _balż, --, --, --, 
   {{0x065400c8,0x1068170a,0x425069f2,0x10a40f06}},	//   _אייך_, зией_, انمر, нижн, 
   {{0x2908070d,0x62800077,0x6f08d6ff,0xb9100055}},	//   _xiaa_, _ólon, _sidc, _dhaḥ_, 
   {{0x730400c7,0x00000000,0x00000000,0x00000000}},	//   _аҿаз, --, --, --, 
   {{0xfe6c1ee2,0x7f443ee0,0x7f808b4d,0x7cd0084c}},	//   مدى_, رلىق_, الون, văra, 
   {{0x6f09f676,0x2a6c0219,0x00000000,0x00000000}},	//   _vidc, vedb_, --, --, 
   {{0x6d5cfa09,0x7cd0054e,0xdc8001d5,0xbd4000d1}},	//   _äram, tăra, иқхо, اھلى, 
   {{0x290802fa,0x798003ac,0x1fb40261,0x6f08058a}},	//   _riaa_, _arnw, _исфр, _tidc, 
   {{0x672c8a22,0x29080194,0x27e8123b,0x6f0802d0}},	//   _rwaj, _siaa_, _ryan_, _uidc, 
   {{0x0c24242f,0x27e9f677,0x200c0259,0x02b4008f}},	//   _змен, _syan_, şmiş_, גליך_, 
   {{0x01340302,0x7cd00276,0x27e80100,0x6c340d2f}},	//   ערכת_, păra, _pyan_, _شفتا, 
   {{0x3834010b,0x29080171,0xab700244,0x00000000}},	//   ыняр, _viaa_, _ئۆخژ, --, 
   {{0x672c007f,0x27e80100,0x00000000,0x00000000}},	//   _vwaj, _vyan_, --, --, 
   {{0x29080134,0xba14008f,0x05d844eb,0x00000000}},	//   _tiaa_, _אחוץ_, _मुखब, --, 
   {{0x672df678,0x69d805c7,0x27e9e6e3,0x00000000}},	//   _twaj, _ixve, _tyan_, --, 
   {{0x672cf714,0x7eac00fe,0xa6f5f679,0x27e9cca6}},	// [390b0] _uwaj, _løpa, _изиш, _uyan_, 
   {{0x555001d3,0x622000d1,0x00000000,0x00000000}},	//   دھیر, شۈرە, --, --, 
   {{0x01080133,0x7cd00356,0x00000000,0x00000000}},	//   ستاو_, dărn, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd4c06833,0xef18eeec,0x6d5c0037,0xf31801f0}},	//   _төрк, емі_, _äraj, _пояш_, 
   {{0xdee40364,0x8fa012b4,0x6e9468ba,0xb910002b}},	//   ъоли, раше, личу, _thaḥ_, 
   {{0x200c1570,0xb2840228,0x6ee41497,0xad2400ec}},	//   _tgei_, _сыяк, tòbr, هريو, 
   {{0xfeb80502,0x61f403ac,0x81dc03d4,0x00000000}},	//   _کارت_, _izzl, দেউ_, --, 
   {{0x9f5401ca,0x00000000,0x00000000,0x00000000}},	//   _швач, --, --, --, 
   {{0x7f595de2,0xbdf88ee7,0x798003ac,0x00000000}},	//   _iquq, _فرضا_, _prnw, --, 
   {{0xda080a12,0x00000000,0x00000000,0x00000000}},	//   بيده_, --, --, --, 
   {{0x26d005d5,0x0900009d,0x7ae400f1,0x00000000}},	//   enzo_, ипэн, _ګوتې_, --, 
   {{0x7d080280,0xacb00137,0x3ae80174,0x00000000}},	//   _iigs, _دەيب, høpi_, --, 
   {{0x7f580472,0x7d08cd1e,0x61f4035a,0xf48401d5}},	//   _mquq, _higs, _ozzl, گاسی, 
   {{0x7d08089c,0x8704fffd,0x3f580208,0x79806e99}},	//   _kigs, терв_, hêu_, _urnw, 
   {{0x7d09f67a,0x7f580921,0x17840022,0xc87c002f}},	//   _jigs, _oquq, _агим, toße_, 
   {{0xb9d8044e,0xb9dc0020,0x61f403ac,0xaf4002d3}},	// [390c0] _ኣላ_, _ሥር_, _azzl, _ነፍስወ, 
   {{0x96f80597,0x7d090820,0x42200261,0xb38c0023}},	//   _تعبر_, _ligs, идув, _መካይን_, 
   {{0x98c40918,0x7f595de2,0x69d80489,0xc87c0112}},	//   _लगाए, _aquq, _xxve, soße_, 
   {{0x4fc5f67b,0x4fa439b8,0x00804929,0x00000000}},	//   ксла, киев, илхо, --, 
   {{0x7eac01bf,0x00000000,0x00000000,0x00000000}},	//   _søpa, --, --, --, 
   {{0x7d0802d0,0x6d5c00c5,0x2edc206b,0x00000000}},	//   _aigs, _ärak, मकेत, --, 
   {{0x7d09f67c,0x7f580472,0xbea0399f,0xad2410e0}},	//   _bigs, _equq, рајк, دىعى, 
   {{0x7d08e306,0x291906c9,0x00000000,0x00000000}},	//   _cigs, íram_, --, --, 
   {{0x7d09bc86,0x00000000,0x00000000,0x00000000}},	//   _digs, --, --, --, 
   {{0xfbcc192c,0xc3300302,0x7d0800ad,0xa02001a8}},	//   تتى_, סות_, _eigs, _þörf, 
   {{0xc688001f,0x7cd00311,0x6e380267,0x1da800dc}},	//   _ማሻሻያ_, căro, mavb, _कथयत, 
   {{0xfce000f3,0x81dc0154,0x7cf400c7,0x00000000}},	//   _кохо, দেক_, tãre, --, 
   {{0x1cdc0327,0xc7b801a9,0x0b940244,0x00000000}},	//   _ལྩི_, фён_, _ججاد, --, 
   {{0x6e38010a,0x25a40158,0x00000000,0x00000000}},	//   navb, øllo_, --, --, 
   {{0x26cc041a,0x61380248,0x7d080432,0x499002f2}},	//   đeo_, _mùlá, _ümsü, _ئیجر, 
   {{0xa7740262,0x7d080067,0x7cf40022,0x3f580051}},	//   _блич, _xigs, pãre, yêu_, 
   {{0x7cd00356,0xf314009d,0x00000000,0x00000000}},	// [390d0] zăro, идтэ, --, --, 
   {{0xd5ac0050,0x00000000,0x00000000,0x00000000}},	//   _کہِ_, --, --, --, 
   {{0x1b182158,0x25a4049f,0x673df67d,0x6d5dbd41}},	//   _দিছে_, älld_, lssj, _ärah, 
   {{0x601811ed,0x38b40055,0x63a80210,0x00000000}},	//   ходя_, _tãre_, _żenu, --, 
   {{0x7d09f67e,0xbe30035b,0x00000000,0x00000000}},	//   _rigs, иҭаш, --, --, 
   {{0x7d09f67f,0x2a7c0175,0xbc900051,0xa15800f3}},	//   _sigs, _navb_, _cứnh, _пагу_, 
   {{0x9400013f,0x7d09f680,0x61f4035a,0x2918010f}},	//   _wokɔ_, _pigs, _uzzl, ŭraj_, 
   {{0x673d65dd,0x00000000,0x00000000,0x00000000}},	//   kssj, --, --, --, 
   {{0x7d09f681,0x7f5801f0,0x6e380455,0x1ae40354}},	//   _vigs, _uquq, bavb, лоим, 
   {{0x3cfc0218,0x7d08017a,0x673c0efa,0x80bc07af}},	//   smuv_, _wigs, dssj, लोरे, 
   {{0x7d09279f,0x18a5f682,0x98a400f7,0xf2d400d9}},	//   _tigs, ганм, гине, יעץ_, 
   {{0x61e01125,0xd7600133,0x380401f0,0x673c032e}},	//   _øllu, مۆبی, ионҳ, fssj, 
   {{0x2a7c00db,0x4c980a1e,0x673df683,0xe7340124}},	//   _favb_, _רבנו, gssj, аҵы_, 
   {{0x99847ee4,0xa9c41079,0x00000000,0x00000000}},	//   _ملتو, ازیو, --, --, 
   {{0xd4680261,0x673c0076,0x00000000,0x00000000}},	//   ниве_, assj, --, --, 
   {{0x673c03cd,0x00000000,0x00000000,0x00000000}},	//   bssj, --, --, --, 
   {{0xd7c803e6,0x19f801d9,0x5778007b,0x779403b9}},	// [390e0] _سوده_, _تِژھ_, _أصبح_, _bəxş, 
   {{0x13a8004b,0x00000000,0x00000000,0x00000000}},	//   ونځی_, --, --, --, 
   {{0x2215f684,0x98a40166,0x00000000,0x00000000}},	//   рфур, ltlı_, --, --, 
   {{0x25a4bfb5,0xbf0c068f,0xc05402dd,0x00000000}},	//   älle_, ादून_, гіш_, --, 
   {{0x6e3802fb,0x98a400fd,0x0ee87c76,0x9f940112}},	//   tavb, ntlı_, ньки_, rüße_, 
   {{0xf125b99b,0x61040006,0x91e40d97,0x00000000}},	//   _نظری, _mėly, _боге, --, 
   {{0x2175f685,0x1ea82abb,0x61040064,0x00000000}},	//   _кутр, خاني_, _lėly, --, 
   {{0x0d50044e,0x98a40166,0x00000000,0x00000000}},	//   _ዘይፈል, ktlı_, --, --, 
   {{0xfba40323,0x3dc00116,0x8ac80114,0xfe6c00db}},	//   гтэй_, ийәг, ећна_, زدۈ_, 
   {{0xafe4006c,0x9e65f686,0x81dc045e,0x9f580241}},	//   _боғл, _نامن, দেও_, _àsá_, 
   {{0xfbcc011d,0xabcc02dd,0x39102e80,0xbe1001e2}},	//   قتی_, _ﯗﻟﻌﺎ, ймэр, _اومع, 
   {{0x957402d3,0x1c0c02fe,0x673c03cd,0xfbcc0228}},	//   ርነትን_, _हलचल_, tssj, تتۉ_, 
   {{0x8ae401af,0xaa5c01ec,0x00000000,0x00000000}},	//   _йікл, _желi, --, --, 
   {{0x673c03cd,0x00000000,0x00000000,0x00000000}},	//   rssj, --, --, --, 
   {{0x04640598,0x494401c0,0xe5340108,0x00000000}},	//   лтам, _сэлб, ребь, --, 
   {{0x673c03cd,0x99f400d4,0xf98c007b,0x39100395}},	//   pssj, _тячі, _ربى_, _умър, 
   {{0x63045a16,0x61040024,0x628002d2,0x00000000}},	// [390f0] لورل, _gėly, _ólok, --, 
   {{0x5f9401d3,0x00000000,0x00000000,0x00000000}},	//   یلائ, --, --, --, 
   {{0xe2980184,0xc0c808e4,0x659471a4,0x7cf400c7}},	//   наҡ_, нуде_, _тану, hãra, 
   {{0x3ae833b8,0x20d400df,0x7cf40124,0xded40023}},	//   løpt_, rĥio_, kãra, ይዎን_, 
   {{0x4439f687,0x90700214,0x05758187,0x9f6006be}},	//   maq_, زهوش, _شاھد, _öpüm_, 
   {{0x4439f688,0xd34407d6,0x64a40022,0x16000073}},	//   laq_, _ضیمه_, _саҭа, ळेवर_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4439f689,0xccb00124,0x00000000,0x00000000}},	//   naq_, жәшь, --, --, 
   {{0xc5f804c5,0x7e8802b1,0x44380194,0x00000000}},	//   _আলফা_, _pēpē, iaq_, --, 
   {{0x4439f68a,0x20080fda,0x3ae8143a,0x98a40051}},	//   haq_, žais_, jøpt_, vslđ_, 
   {{0x4439f68b,0xbd480597,0x5c75f68c,0x3fa002e3}},	//   kaq_, _سؤال_, _влет, ̣rụ_, 
   {{0x25400953,0xa3b437f3,0x4439f502,0xac180408}},	//   dėl_, जना_, jaq_, _боцу_, 
   {{0x7c39f68d,0x44380842,0x00000000,0x00000000}},	//   maur, daq_, --, --, 
   {{0x7c39f68e,0x98a4e090,0x8bd404a9,0x61040153}},	//   laur, rtlı_, _әмәс_, _vėly, 
   {{0xceb01203,0xf9900b24,0x00000000,0x00000000}},	//   חים_, _دبش_, --, --, 
   {{0x7c39f68f,0x4439f690,0x1425f691,0xb4d00490}},	//   naur, gaq_, рдам, वचे_, 
   {{0x0321f692,0x07a03461,0x6d5c00c5,0xdd8421de}},	// [39100] ждун, _маън, _ärav, _کڈ_, 
   {{0x7c39f693,0x44389585,0x78a4005b,0x1664009b}},	//   haur, aaq_, _hoiv, _твом, 
   {{0x7c39f694,0xdbd00209,0x78a49ea5,0x4438ff39}},	//   kaur, lýär, _koiv, baq_, 
   {{0x443811a9,0xcfa5b477,0xa0880220,0x92c4015b}},	//   caq_, ишли, лсіз_, উকে_, 
   {{0x69dc07de,0xcf58005b,0xb9d80023,0xee200150}},	//   ürez, треч_, _ኣጋ_, пелi_, 
   {{0x7c380076,0x7f80515c,0x78a40e03,0x00000000}},	//   eaur, زلىن, _loiv, --, 
   {{0x78a4062c,0x50940063,0xc0d40023,0x00000000}},	//   _ooiv, _крађ, ይሮም_, --, 
   {{0x78a40281,0xc0e0524d,0x7c3800cd,0x7cf400c7}},	//   _noiv, _доск, gaur, tãra, 
   {{0x4f080372,0xef9401b9,0x00000000,0x00000000}},	//   _анан_, _دیشد, --, --, 
   {{0x8aa5f695,0x4438467d,0x7cf5316d,0xdbd000ee}},	//   ррид, zaq_, rãra, dýär, 
   {{0x4439f696,0x7c380086,0x021402e4,0xddc00042}},	//   yaq_, baur, יחים_, _balŵ, 
   {{0x7c39f697,0xb4e00316,0x48a81def,0x00000000}},	//   caur, दको_, ттом_, --, 
   {{0x78a420ef,0x44390728,0x3ae80fac,0x7b8401ec}},	//   _doiv, vaq_, tøpt_, _پانە, 
   {{0x443803f0,0xa3b4012d,0xbb3800d9,0x38b400b8}},	//   waq_, जनस_, _יעדי, _vãra_, 
   {{0x4439f698,0xddc00142,0x00000000,0x00000000}},	//   taq_, _falŵ, --, --, 
   {{0x44380194,0x00000000,0x00000000,0x00000000}},	//   uaq_, --, --, --, 
   {{0x4439f699,0x68edf69a,0x1854237e,0x7a400139}},	// [39110] raq_, _ikad, _ارىڭ, _fítı, 
   {{0x4439f69b,0x00000000,0x00000000,0x00000000}},	//   saq_, --, --, --, 
   {{0x44384375,0x7c39f484,0xe4d89924,0x68ec0171}},	//   paq_, yaur, _مودت_, _kkad, 
   {{0x4439f69c,0x7c396602,0xfd540055,0x00000000}},	//   qaq_, xaur, chaṭ, --, 
   {{0x68ec4b44,0x7c39f69d,0x78a0007c,0x00000000}},	//   _mkad, vaur, ömvi, --, 
   {{0x63adf69e,0x7cd000a8,0x7c39f69f,0x7d0400dd}},	//   myan, mări, waur, _éjsz, 
   {{0x7c39f6a0,0x68edf6a1,0x7cd00276,0xdca4004e}},	//   taur, _okad, lări, йаки, 
   {{0x9c5825ec,0x68edf6a2,0x63ac00b5,0x2dd8007b}},	//   ушку_, _nkad, oyan, جبهة_, 
   {{0x7c39f6a3,0x60c9f6a4,0x7cd0084c,0xdcb0001e}},	//   raur, _imem, nări, _của_, 
   {{0x68eca238,0x7c39f6a5,0x63adf6a6,0x6fa4012c}},	//   _akad, saur, iyan, कहरू, 
   {{0x7c39f6a7,0x78a5f6a8,0xba04015b,0x645c03cb}},	//   paur, _poiv, োর্ড_, _ocsi, 
   {{0x63adf6a9,0xd78816cb,0x7c380481,0x19d401b9}},	//   kyan, هنجو_, qaur, _қўлё, 
   {{0x63adf6aa,0x60c800b4,0x78a5f6ab,0x7cd0054e}},	//   jyan, _mmem, _voiv, jări, 
   {{0x63adf6ac,0x68edf6ad,0xdbd00209,0x7cd00276}},	//   dyan, _ekad, rýär, dări, 
   {{0x78a40664,0x18a45afd,0x60c9f6ae,0x6d5c00af}},	//   _toiv, _гайм, _omem, _ärat, 
   {{0x25a404f3,0x60c80784,0x00000000,0x00000000}},	//   älla_, _nmem, --, --, 
   {{0x63adf6af,0x7cd00276,0x645c0175,0x15a801ec}},	// [39120] gyan, gări, _dcsi, _ءﺳﺎﯞ, 
   {{0x60c9f6b0,0x645c0334,0x00000000,0x00000000}},	//   _amem, _ecsi, --, --, 
   {{0xc690025f,0x63adf6b1,0x4f0802dd,0x99840024}},	//   _זאת_, ayan, ңнен_, malų_, 
   {{0x63adf6b2,0x7cd00311,0x947400cf,0x6d6401e1}},	//   byan, bări, _اددا, _lẹ́ṣ, 
   {{0x63adf6b3,0x7cd0084c,0xf98526b1,0x00000000}},	//   cyan, cări, _کب_, --, 
   {{0x8d74516c,0x60c9f6b4,0x99840024,0x87780a1e}},	//   ماعا, _emem, nalų_, טאני, 
   {{0x11d80597,0x9e65f6b5,0x8d852cd0,0x60c80175}},	//   _صورة_, تانن, сулд, _fmem, 
   {{0xd0088a6f,0x27ec012d,0x39b406be,0x25a40174}},	//   _бебе_, żeni_, cəsə_, ølli_, 
   {{0xf9840597,0x99840006,0x68ec01c4,0xbb440338}},	//   _שب_, kalų_, _rkad, ملين_, 
   {{0x68ec17c0,0xac980ee8,0x2c0400cd,0x00000000}},	//   _skad, انکا_, शेषं_, --, 
   {{0x63adf6b6,0x7cd0084c,0x68ec022e,0x998400c0}},	//   zyan, zări, _pkad, dalų_, 
   {{0x63ac4437,0x2d8c010e,0x8b640133,0x00000000}},	//   yyan, _irde_, _هاتم, --, 
   {{0x68ec0a73,0x63ac0072,0x7cd00356,0x00000000}},	//   _vkad, xyan, xări, --, 
   {{0x63ad0aec,0x99840006,0xdb2595ec,0x2d8c0165}},	//   vyan, galų_, _بووی, _krde_, 
   {{0xa99c0589,0x63acbdff,0x00000000,0x00000000}},	//   _lãºä_, wyan, --, --, 
   {{0x63adf6b7,0x7cd0084c,0x68edf6b8,0x3b600050}},	//   tyan, tări, _ukad, _بێیہ, 
   {{0x63ac7b8a,0x99840024,0x03180345,0x00000000}},	// [39130] uyan, balų_, اترت_, --, 
   {{0x2d8df6b9,0x63ad42c5,0x7cd0084c,0x60c9f6ba}},	//   _orde_, ryan, rări, _smem, 
   {{0x7cd00276,0xdfd000e5,0x00000000,0x00000000}},	//   sări, ڈيا_, --, --, 
   {{0x7cd00276,0x63adf6bb,0x8488001f,0xdfd0724c}},	//   pări, pyan, _መቻሉን_, ويا_, 
   {{0x2d8c054e,0x7eac0162,0x63adf6bc,0x47a800cc}},	//   _arde_, _høpi, qyan, _চেতী, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x62940516,0x814003e6,0x25fc0073,0x00000000}},	//   _inzo, _رۆشن, ळेची_, --, 
   {{0x1b49cd3c,0x60c9f6bd,0x7cf400e4,0x760001ef}},	//   азии_, _umem, rãro, _hází, 
   {{0x2d8defd2,0x6284e20a,0x7eac0212,0xab1801c6}},	//   _erde_, odho, _løpi, йцэх_, 
   {{0x6285f6be,0x7ed42d4b,0x5ac80f37,0x05640118}},	//   ndho, _ازرا, рлом_, _číně_, 
   {{0xad243955,0x62851f98,0x2d8c0427,0xfd4401d3}},	//   _فىلى, idho, _grde_, _ایبٹ_, 
   {{0x9b9465fe,0xa3e841ac,0x62840332,0x38b40055}},	//   _ولات, यथा_, hdho, _vãro_, 
   {{0x2bd0007d,0x62941190,0x99840153,0x6d5c0254}},	//   _तइया, _onzo, talų_, _ärar, 
   {{0x6285f6bf,0x00000000,0x00000000,0x00000000}},	//   jdho, --, --, --, 
   {{0x69442781,0x98a5f6c0,0x6285f6c1,0x18a43756}},	//   _فضيل, _мике, ddho, _макм, 
   {{0x6285454c,0xa3b400dc,0x00000000,0x00000000}},	//   edho, जनं_, --, --, 
   {{0xe6c8107d,0x99840153,0xe6180107,0xd6d0007b}},	// [39140] šašć, palų_, рдӣ_, _يقع_, 
   {{0x7cd0084c,0x6284058a,0x91f40108,0x00000000}},	//   măru, gdho, очеч, --, 
   {{0xa99c0589,0x2bd009b4,0x2c4c0024,0xd469f6c2}},	//   _sãºä_, _तेना, lėdų_, _кине_, 
   {{0x62941691,0x6285f6c3,0x765df6c4,0x00000000}},	//   _enzo, adho, lgry, --, 
   {{0x7cd00276,0x6285f6c5,0xa3b4448b,0x3b1c014f}},	//   năru, bdho, जनः_, jquq_, 
   {{0xfe6c1ee2,0x765df6c6,0xc7b002e4,0x628408c2}},	//   ندى_, ngry, ובד_, cdho, 
   {{0x7d21f6c7,0x016052f0,0x38600526,0x7cd0054e}},	//   وفون, _окро, _ocir_, hăru, 
   {{0x8f740064,0x00000000,0x00000000,0x00000000}},	//   _музі, --, --, --, 
   {{0x6b840327,0x3320031c,0x3ae80162,0x00000000}},	//   _ġigs, nqix_, tøpp_, --, 
   {{0x2d8c09a8,0x386006be,0x3e680101,0xaa580114}},	//   _trde_, _acir_, _نجمی_, љину_, 
   {{0x386001ab,0x2d8c005a,0x765df6c8,0x3ae803b2}},	//   _bcir_, _urde_, dgry, røpp_, 
   {{0x6d580037,0xe724031c,0x7cd0054e,0xcb68009b}},	//   muva, _འཕྱན_, făru, _ваде_, 
   {{0x7cd0054e,0xdc7400c7,0x32180432,0x6284058a}},	//   găru, _хыхь, _ogry_, ydho, 
   {{0x2bd002e5,0x98a400c0,0x00000000,0x00000000}},	//   _तेया, kslė_, --, --, 
   {{0x6d59f6c9,0x39a00014,0xa5f80117,0xc5f00154}},	//   nuva, _ہییہ, севу_, ছেনা_, 
   {{0x291c003a,0x2d98004e,0x6284058a,0x6d580254}},	//   _iuva_, _àreu_, wdho, iuva, 
   {{0x6d59f6ca,0x7cd00276,0xe7240327,0x291c007c}},	// [39150] huva, căru, _འཕྲན_, _huva_, 
   {{0x291cf948,0x9f9403b2,0x6285f6cb,0xefdc01f3}},	//   _kuva_, _nýár_, udho, ንግዳ_, 
   {{0x6d580c95,0x6285f6cc,0x26d1f6cd,0x291c01f4}},	//   juva, rdho, mizo_, _juva_, 
   {{0x26d1f6ce,0x291c9af8,0x6d59f6cf,0x66c80064}},	//   lizo_, _muva_, duva, džki, 
   {{0x291df6d0,0x6d58017a,0xc2540066,0x00000000}},	//   _luva_, euva, _وخست, --, 
   {{0x6d58b875,0x26d1f6d1,0x6284300b,0x291c0124}},	//   fuva, nizo_, qdho, _ouva_, 
   {{0x291c019f,0x6d59f6d2,0x7cd00356,0xc05828f6}},	//   _nuva_, guva, zăru, _віз_, 
   {{0x26d003d1,0x1c4402bf,0x765c0034,0xace801c8}},	//   hizo_, чним, zgry, يريل_, 
   {{0x26d1f6d3,0x291c0b23,0xfa505024,0x386000a3}},	//   kizo_, _auva_, وردگ, _rcir_, 
   {{0x38600048,0x291df6d4,0x7cd00276,0x6d59f6d5}},	//   _scir_, _buva_, văru, buva, 
   {{0x291df6d6,0x26d1f6d7,0x6d5c0037,0x7c842143}},	//   _cuva_, dizo_, _ärap, _муде, 
   {{0x291df6d8,0x2d58084c,0x18681468,0x7cd00356}},	//   _duva_, _фиць_, щами_, tăru, 
   {{0x26d14e89,0xdb240108,0x291803f2,0x3b1c06be}},	//   fizo_, öpät, írar_, qquq_, 
   {{0x291c1570,0x26d1f6d9,0x00000000,0x00000000}},	//   _fuva_, gizo_, --, --, 
   {{0x765df6da,0x291df6db,0x00000000,0x00000000}},	//   rgry, _guva_, --, --, 
   {{0x9f4c043b,0x3860009a,0x26d00810,0x5f440092}},	//   _ayeí_, _ucir_, aizo_, _ከግንቦ, 
   {{0x26d05d23,0x291c0e8a,0x6d59f6dc,0xb9f800b7}},	// [39160] bizo_, _zuva_, zuva, _ቅር_, 
   {{0x26d19aaf,0x39a4013f,0x3e6c0790,0x291df6dd}},	//   cizo_, nɑso_, nıtı_, _yuva_, 
   {{0xba04069d,0x27ec0135,0x00000000,0x00000000}},	//   _ለካ_, żent_, --, --, 
   {{0x6d58601a,0x3a2401f5,0xa0a40220,0x61f4010e}},	//   vuva, _lfnp_, мшіл, _dyzl, 
   {{0xd2f805f5,0x3e6c71d5,0x6d59f6de,0x00000000}},	//   _гэвч_, kıtı_, wuva, --, 
   {{0x321800ee,0x00000000,0x00000000,0x00000000}},	//   _ugry_, --, --, --, 
   {{0x61f40209,0x00000000,0x00000000,0x00000000}},	//   _gyzl, --, --, --, 
   {{0x2054e77b,0x291df6df,0x26d1f6e0,0x00000000}},	//   _отур, _ruva_, zizo_, --, 
   {{0x291df6e1,0x6d59f6e2,0x39440076,0x26d049cf}},	//   _suva_, suva, _avns_, yizo_, 
   {{0xc3300d65,0x1ea8037b,0x6d58eebc,0x291c0083}},	//   עות_, _والي_, puva, _puva_, 
   {{0x26d1f6e3,0x291df6e4,0x6d590c64,0x00000000}},	//   vizo_, _quva_, quva, --, 
   {{0x7eac0162,0x67d51f2e,0x6d48035a,0xe5a80241}},	//   _døpu, дому, _ivda, _àfẹ́, 
   {{0x26d000b2,0x5cc401f7,0xe8ac01f9,0xe8f8004e}},	//   tizo_, _تغلق, _चवीच, йлү_, 
   {{0xba140491,0x291df6e5,0xfaa00816,0xf1ac012d}},	//   _فيها_, _tuva_, _пачо, चहान, 
   {{0x26d1f6e6,0x35e400d6,0x7cd00276,0x00000000}},	//   rizo_, ецтв, părt, --, 
   {{0x26d1f6e7,0xf4840137,0x61f401ef,0x00000000}},	//   sizo_, нуун, _ryzl, --, 
   {{0xf770030f,0x61f4010b,0x00000000,0x00000000}},	// [39170] _یای_, _syzl, --, --, 
   {{0x672df6e8,0x6d4838bb,0xe70479f8,0x26d0013e}},	//   _itaj, _ovda, _تسبی, qizo_, 
   {{0xe1380046,0x24180724,0xcfa80011,0x00000000}},	//   ізді_, _моны_, _খেলন, --, 
   {{0x98a40276,0x672c0135,0x61f40030,0x15f00037}},	//   mplă_, _ktaj, _vyzl, _आँतर_, 
   {{0x2489f6e9,0x6d486e96,0x672c0135,0x7fe875b0}},	//   mdam_, _avda, _jtaj, حراف_, 
   {{0x672c00ec,0xb284013d,0x00000000,0x00000000}},	//   _mtaj, _пыск, --, --, 
   {{0xa3b4006d,0x236804ac,0xb8d00327,0x248800c0}},	//   जनक_, ltaj_, _ནྭ_, odam_, 
   {{0x2489f6ea,0x6d49f6eb,0x672df6ec,0xbff00150}},	//   ndam_, _dvda, _otaj, _كۋاب, 
   {{0x2369f6ed,0x672c1419,0x3f880129,0x6d49f6ee}},	//   ntaj_, _ntaj, _écu_, _evda, 
   {{0x2368008f,0x248805d1,0xfe242247,0x9e940244}},	//   itaj_, hdam_, _хьан, _تارچ, 
   {{0x672df6ef,0x7eac0fac,0x2368014f,0x00000000}},	//   _ataj, _døpt, htaj_, --, 
   {{0x2368008f,0x672c031c,0x24882112,0x00000000}},	//   ktaj_, _btaj, jdam_, --, 
   {{0x2369f6f0,0xd7e80220,0x2f00067c,0x07a01422}},	//   jtaj_, імге_, lòga_, ваян, 
   {{0x24880483,0x24980129,0x00000000,0x00000000}},	//   edam_, _ansm_, --, --, 
   {{0x672df6f1,0x2488017a,0x2369f6f2,0x00000000}},	//   _etaj, fdam_, etaj_, --, 
   {{0x236800df,0x79800857,0x6bd40137,0x66c80064}},	//   ftaj_, _isnw, _تتۅر, džku, 
   {{0x52a80ec6,0x212c0e04,0xf4280137,0x52840139}},	// [39180] овам_, _čeha_, _ۉيدۉ_, мгаб, 
   {{0x24880099,0x85740150,0x00000000,0x00000000}},	//   adam_, _ﺠﻴﺩﺍ_, --, --, 
   {{0xd72403d4,0x7eac08fb,0x2368010f,0xb9e40092}},	//   _বিয়া_, _løps, ataj_, _ይኼ_, 
   {{0x798003ac,0x00000000,0x00000000,0x00000000}},	//   _msnw, --, --, --, 
   {{0x91cc0316,0xcf780f84,0x23680113,0x672c031c}},	//   _धेरै, تصاص_, ctaj_, _xtaj, 
   {{0xd130214b,0x40900139,0x00000000,0x00000000}},	//   _لمس_, ерәт, --, --, 
   {{0x2f000ba1,0x57b8012c,0xee8401ec,0xc2202bef}},	//   gòga_, उनुह, дықо, _شکلو, 
   {{0x4f941ee3,0xb4bc00dc,0x00000000,0x00000000}},	//   _орзу, _अतो_, --, --, 
   {{0x0e65f6f3,0x79800857,0x09d401f9,0x00000000}},	//   _окан, _asnw, डप्य, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x28f8242f,0x9e64177a,0x6d4803cd,0x2489f6f4}},	//   зень_, _سالن, _uvda, ydam_, 
   {{0x2369f6f5,0xdc4402b5,0x95740b82,0x7c90007b}},	//   ytaj_, _tūāk, ይነትን_, _للمص, 
   {{0x672c025c,0x24880205,0x8ac401a9,0x00000000}},	//   _qtaj, vdam_, _оёкл, --, 
   {{0x9f5406af,0x2498ad72,0x23680100,0x00000000}},	//   égée_, _snsm_, vtaj_, --, 
   {{0x7eac03cd,0x84980451,0x2489bb14,0x672c0210}},	//   _køpr, يئرس_, tdam_, _wtaj, 
   {{0x672c025c,0x248831f9,0x00000000,0x00000000}},	//   _ttaj, udam_, --, --, 
   {{0x2489f6f6,0x672df6f7,0x00000000,0x00000000}},	// [39190] rdam_, _utaj, --, --, 
   {{0x2369f6f8,0x24880483,0xddd40086,0x712400d1}},	//   rtaj_, sdam_, ũbũm, چىلم, 
   {{0x23689996,0x281401a9,0x24880af9,0xf55401c6}},	//   staj_, _توکس, pdam_, _ивээ, 
   {{0xefdc0023,0x2368010f,0x00000000,0x00000000}},	//   ንግዕ_, ptaj_, --, --, 
   {{0x23687769,0xef00000d,0x00000000,0x00000000}},	//   qtaj_, _लीहऽ_, --, --, 
   {{0x44282165,0xc0341772,0x630407d6,0x00000000}},	//   _hfc_, ርትራው, _سوزل, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd71800fe,0x5ba9f6f9,0x2bd0000d,0xdb840902}},	//   তীয়া_, зким_, _तेहा, егии, 
   {{0xbe801638,0x6d5c0158,0x7eac03b2,0x44280b84}},	//   _ақли, _åran, _døpr, _mfc_, 
   {{0xfeb87a1f,0x7980035a,0xb4bc0bca,0x34dc0303}},	//   _بارت_, _psnw, _अत्_, _यद्द, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x98a47f21,0x97c5f6fa,0xd5c8000d,0x3c440efe}},	//   химе, ейме, _हेगड़, _آضاف, 
   {{0x81d00154,0x57b80118,0x00000000,0x00000000}},	//   _হুম_, उनेह, --, --, 
   {{0x9aa5df0c,0x8bd40375,0x00a00150,0xd94400d8}},	//   _سمبو, _אונו_, _ﺍﻗﺴﯘ, _зеки, 
   {{0x7ae0009a,0x998400c6,0xaa0800db,0x00000000}},	//   _ijnt, _ألبو, _ۉزۉل_, --, 
   {{0x4429f6fb,0x00000000,0x00000000,0x00000000}},	//   _cfc_, --, --, --, 
   {{0x13042add,0x00000000,0x00000000,0x00000000}},	// [391a0] езам, --, --, --, 
   {{0x8351f6fc,0x07a0030d,0x00000000,0x00000000}},	//   اپلا, _саьн, --, --, 
   {{0x4429f6fd,0x741403e6,0x7c29f6fe,0x00000000}},	//   _ffc_, روڕا, _ofgr, --, 
   {{0x44280998,0x53a5f6ff,0x00000000,0x00000000}},	//   _gfc_, _замб, --, --, 
   {{0xbee801f9,0x00000000,0x00000000,0x00000000}},	//   टवून_, --, --, --, 
   {{0x7c29f700,0x2bd00a28,0xbea04ccf,0x44280175}},	//   _afgr, _तेषा, лачк, _zfc_, 
   {{0x91e4ee8b,0x4428ba54,0x1ee80133,0xad8400d1}},	//   _чове, _yfc_, بووی_, ئاتۇ, 
   {{0x7ae000f3,0xd0102586,0x00000000,0x00000000}},	//   _ajnt, _ملز_, --, --, 
   {{0x7ae001e0,0xcfa80137,0x00000000,0x00000000}},	//   _bjnt, _عارم_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7c280175,0x28483baf,0x2bd006e3,0x00000000}},	//   _ffgr, үзүп_, _तेरा, --, 
   {{0x7c808f3a,0xfce00354,0x00000000,0x00000000}},	//   _буше, _йохо, --, --, 
   {{0x7eac03b2,0xab0001a8,0x4429f701,0x37d400cc}},	//   _køpp, þjóð_, _rfc_, _ধুবৰ, 
   {{0x6d59f702,0x44280f85,0x6e38022e,0x00000000}},	//   orva, _sfc_, nbvb, --, 
   {{0x4429e05b,0x212c012c,0xfaf40375,0x00000000}},	//   _pfc_, _čeho_, _רצוי_, --, 
   {{0x69c80153,0x79f8011a,0xf3fc00fe,0x6aa801e3}},	//   mzde, _מלוח, ্শনৰ_, ljdf, 
   {{0x6d5804a7,0x69c8002f,0x00000000,0x00000000}},	// [391b0] hrva, lzde, --, --, 
   {{0x44280286,0x6d581a48,0xa19489f1,0x27e801c4}},	//   _wfc_, krva, казч, _ixan_, 
   {{0x4429f703,0x2908058a,0x68fc017a,0x69c82305}},	//   _tfc_, _khaa_, olsd, nzde, 
   {{0x6d59f704,0x9f3402bf,0xc87c0112,0x00000000}},	//   drva, веді, neß_, --, 
   {{0x2bd00490,0x6d595fb5,0x68fc127b,0xddc001ef}},	//   _तेला, erva, ilsd, _zelň, 
   {{0xf77406a9,0x3ea401af,0x2908020c,0x6f080208}},	//   רקס_, ujnt_, _lhaa_, _chdc, 
   {{0x29080022,0x5de402e8,0xb38c0092,0x00000000}},	//   _ohaa_, ъжка, _መያዙን_, --, 
   {{0xad24acec,0x91c00220,0x27e800d8,0x2f0001e1}},	//   دروو, _тәул, _oxan_, bògo_, 
   {{0x0b41f705,0x26c00261,0x6d58000d,0xd02402dd}},	//   анын, _olho_, arva, _شولۋ, 
   {{0x29080d62,0x68fc4d25,0x0a380092,0x00000000}},	//   _ahaa_, elsd, _የበርካ, --, 
   {{0xbbe800dd,0x27e803e3,0x49c4009d,0x00000000}},	//   _کرام_, _axan_, влэн_, --, 
   {{0x2d98748d,0x2909f706,0x26c006ed,0x7cf4035b}},	//   _área_, _chaa_, _alho_, tãru, 
   {{0x2908198f,0x3370001f,0x48e000a7,0x69c8033f}},	//   _dhaa_, _አካሄደ_, рояв, azde, 
   {{0x290801c6,0x32c42737,0x25ec00c5,0x00000000}},	//   _ehaa_, _köye_, _आँखी_, --, 
   {{0x26c001f1,0xdedc0023,0xd4680798,0x7b880150}},	//   _dlho_, _ንኹን_, миве_, _ﻓﻴﺠﺏ_, 
   {{0x2909f707,0x27ec020c,0x26c001ef,0x97b42b2e}},	//   _ghaa_, ékné_, _elho_, _асош, 
   {{0xd264022e,0xe3b001d9,0x00000000,0x00000000}},	// [391c0] ккай, ٝرٕ_, --, --, 
   {{0x86b0005e,0xe8000073,0x6d580072,0xc2240241}},	//   _кәсі, ोधरा_, yrva, _ẹ̀lí, 
   {{0x29080205,0x10680108,0x00000000,0x00000000}},	//   _yhaa_, дией_, --, --, 
   {{0x6d58074d,0x7eac168c,0x9344010b,0x7f4400d1}},	//   vrva, _søpp, _инме, ھلىق_, 
   {{0x7f440131,0x65c401f0,0x80a01291,0x00000000}},	//   پلىق_, _абӯа, شمون, --, 
   {{0x8d7402de,0x6d59f708,0xb91400cd,0xc87c0112}},	//   ناعا, trva, _ekaḥ_, zeß_, 
   {{0x8d847d0b,0x6d59f709,0x00000000,0x00000000}},	//   тулд, urva, --, --, 
   {{0x6d58007c,0x69c80306,0xd0081075,0x98a40139}},	//   rrva, vzde, _жебе_, kulı_, 
   {{0xc4d00302,0x29080076,0xfd4c0241,0xcbe402e8}},	//   יגה_, _rhaa_, _kojọ, ъцки, 
   {{0x69c809a4,0xcc10063f,0x2909f70a,0x6d580841}},	//   tzde, _fọnị, _shaa_, prva, 
   {{0xfaa1f70b,0x02b425f9,0x9e640150,0x5ba4013e}},	//   ршын, דליך_, _حاقن, врӯз, 
   {{0x6fb82c2e,0x81e40154,0xe75803de,0x5dd800df}},	//   ्नपू, _পরম_, нимі_, _אַנס, 
   {{0x26c001d4,0xc87c0112,0x87e44316,0x97300133}},	//   _plho_, reß_, тюне, یکیا, 
   {{0xbc180302,0x69c401c0,0x4c94010a,0x00000000}},	//   _חודש, _бөмб, _пиçс, --, 
   {{0x0905f70c,0x2908020c,0xe9f80024,0xf5240166}},	//   _ичим, _thaa_, _янкі_, ифтн, 
   {{0xdaa400c7,0x851805db,0x27e801c4,0xba140375}},	//   _агәҩ, _ụgbọ_, _txan_, _בחוץ_, 
   {{0x22500204,0x26c0016d,0x02680108,0x00000000}},	// [391d0] _pdzk_, _tlho_, дшей_, --, 
   {{0xaa3c0108,0x00000000,0x00000000,0x00000000}},	//   _äxää_, --, --, --, 
   {{0xe298052f,0x25ec000d,0xa0b8b27b,0x00000000}},	//   маҡ_, _आँटी_, нгжу_, --, 
   {{0x55b8011a,0x00000000,0x00000000,0x00000000}},	//   _נמרו, --, --, --, 
   {{0xb9fc4614,0xc3400408,0x00000000,0x00000000}},	//   _उर्फ_, _тĕл_, --, --, 
   {{0x7e600218,0x5f040ede,0x65c80036,0x00000000}},	//   ugnp, ызла, _gëhé, --, 
   {{0x72d49a41,0x6120010e,0x92b000db,0xdef801e0}},	//   _торф, _bŷle, _اڭقا, мыҫ_, 
   {{0xf1c85cb5,0xf3e400fe,0x00000000,0x00000000}},	//   _شوقى_, _খৰিৰ_, --, --, 
   {{0x9e3411f7,0xdd90179e,0x00000000,0x00000000}},	//   _безч, _گوا_, --, --, 
   {{0xbdf8009f,0xd354011a,0x0ae4013d,0xcae40139}},	//   _قرضا_, ניתי_, лдый_, лмыж_, 
   {{0xdd90369f,0x1868d6e7,0x691000c7,0x893001d3}},	//   _دوا_, нани_, _oñeĝ, یٹیا, 
   {{0x60d80142,0x6c8400db,0xfca8009f,0xa3b4012d}},	//   niwm, _ۅلۅم, _تائو_, ड़ना_, 
   {{0xb8dc0a28,0x7c394ce2,0xf48403e6,0xea88872f}},	//   _आक_, mbur, یاری, رخین_, 
   {{0x7c39f70d,0xcb64041b,0x12bc009e,0xaac400f7}},	//   lbur, _саше_, _আদ্দ, _ۅتۉن, 
   {{0xc7a4036b,0x00000000,0x00000000,0x00000000}},	//   نگیل_, --, --, --, 
   {{0x7c39f70e,0x6600002f,0x00000000,0x00000000}},	//   nbur, ülka, --, --, 
   {{0x7c39f70f,0x932401d5,0xb3a401e0,0x13080006}},	// [391e0] ibur, اررن, шлаһ, енай_, 
   {{0x7c39f710,0x51640228,0x00000000,0x00000000}},	//   hbur, лүгү_, --, --, 
   {{0x9400013f,0x25a541ae,0xdd840014,0x4438037e}},	//   _ankɔ_, ällt_, _بڈ_, bbq_, 
   {{0x7c389a58,0x4fe9f711,0xa0880220,0x00000000}},	//   jbur, нмен_, ксіз_, --, 
   {{0x41240032,0x6cd4179e,0x00000000,0x00000000}},	//   _ҡоро_, یقتا, --, --, 
   {{0x6e94798c,0xd2504e77,0x00000000,0x00000000}},	//   рику, _دنس_, --, --, 
   {{0x3cfc05b1,0x02c000f7,0x644800de,0xbea00120}},	//   fluv_, _уйро, _ķeiz, сајк, 
   {{0x7c39f712,0x60d8012d,0xbfc000fb,0xc198011a}},	//   gbur, ciwm, рбәк, _אשלי, 
   {{0xe0d4023a,0xdce000de,0xdd980139,0xcee80064}},	//   _тюрь, _aplē, ешө_, _здае_, 
   {{0x7c39f713,0x00000000,0x00000000,0x00000000}},	//   abur, --, --, --, 
   {{0x39b401c0,0x00000000,0x00000000,0x00000000}},	//   глээ_, --, --, --, 
   {{0x7c3847af,0x02140375,0x00000000,0x00000000}},	//   cbur, טחים_, --, --, 
   {{0xcc10063f,0x2fc001c3,0xc7b8009d,0x00000000}},	//   _kọmị, ùigh_, хён_, --, 
   {{0xa53401b9,0xe6940139,0x00000000,0x00000000}},	//   ингч, шигы, --, --, 
   {{0x05b85220,0x6458012d,0x00000000,0x00000000}},	//   ردست_, ówio, --, --, 
   {{0x6fc40073,0x00000000,0x00000000,0x00000000}},	//   वनां, --, --, --, 
   {{0xb6c419bb,0x33580276,0x00000000,0x00000000}},	// [391f0] рөөд, латэ_, --, --, 
   {{0x25a4049f,0x7c386bc8,0xf3f800d1,0x00000000}},	//   älls_, zbur, унуш_, --, 
   {{0x7c39f714,0x00000000,0x00000000,0x00000000}},	//   ybur, --, --, --, 
   {{0x2f0001ab,0x363417a6,0x00000000,0x00000000}},	//   lògh_, _پریس, --, --, 
   {{0x3cfc00b5,0x00000000,0x00000000,0x00000000}},	//   vluv_, --, --, --, 
   {{0x7c387c26,0x00000000,0x00000000,0x00000000}},	//   wbur, --, --, --, 
   {{0x3cfc037e,0x64c801f9,0x00000000,0x00000000}},	//   tluv_, _रताळ, --, --, 
   {{0x7c38167a,0xa3e800c5,0x00000000,0x00000000}},	//   ubur, _बशा_, --, --, 
   {{0xfe7405f5,0x7c398d44,0x4b20023a,0x3ab001e0}},	//   _бүл_, rbur, омыв, йәкт, 
   {{0x7c39f715,0x00000000,0x00000000,0x00000000}},	//   sbur, --, --, --, 
   {{0x7c381a10,0x787c2c95,0x18a4fbd3,0x99d40345}},	//   pbur, _nåvæ, аанм, شتدا, 
   {{0xae340139,0x81e40154,0x7c38022e,0x6ce4003b}},	//   _күәт_, _পরা_, qbur, _ліче, 
   {{0x9038008f,0x81a800fe,0xec4c010f,0x00000000}},	//   כערה, গনি_, _טעאָ, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb8cc00bd,0xca740137,0x1c0c07f7,0x62800162}},	//   _গত_, _ئمىش_, ाइकल_, _óloy, 
   {{0xd7c800aa,0xc9500302,0x00000000,0x00000000}},	//   _لوبه_, _ומה_, --, --, 
   {{0x931401d5,0x7a2802d2,0x94a800fb,0x2bc80456}},	// [39200] لورش, _götó, нтҡа_, ाईया, 
   {{0x8fa40214,0xd1940120,0x42c41b11,0xb8640345}},	//   یماه, ишењ, агун_, _ئاژو, 
   {{0xd18465a7,0xd0243129,0x39a4013f,0x543403c7}},	//   рлей, амей, pɑsu_, _پرجر, 
   {{0x2bc804aa,0x25a4007c,0x00000000,0x00000000}},	//   ाईमा, ålle_, --, --, 
   {{0x09e00a28,0x4ea5f716,0x2fc001ed,0x00000000}},	//   _पश्य, ирка, áig_, --, 
   {{0xef00000d,0x00000000,0x00000000,0x00000000}},	//   _लीखऽ_, --, --, --, 
   {{0xf9840014,0x32c400a2,0x9d640014,0x00000000}},	//   _بب_, _göya_, ٕنى۪, --, 
   {{0xaa58037e,0xfd0dc205,0x00000000,0x00000000}},	//   _ciｎd, وجي_, --, --, 
   {{0x212cbc4a,0x32c4013d,0x5d6400db,0x00000000}},	//   _čehi_, _zöya_, атөз, --, 
   {{0x81e403d4,0x3f980393,0xabb40588,0x2bc80118}},	//   _পৰি_, æque_, иақә, ाईबा, 
   {{0x6d6025f7,0xe8940a89,0x4c847b0a,0x00000000}},	//   ývač, бань, _влев, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x27ec12df,0x81e43fae,0x9b9404d3,0x290400e2}},	//   çen_, _পৰা_, _هاوڵ, ēla_, 
   {{0x26c40296,0x27ec0135,0x00000000,0x00000000}},	//   ólo_, ħen_, --, --, 
   {{0x2458084c,0x00000000,0x00000000,0x00000000}},	//   лавь_, --, --, --, 
   {{0x2d8c007f,0x32c400ac,0xfd4800b8,0xc7b8004e}},	//   _msde_, _röya_, _choṇ, _аёо_, 
   {{0x5f080a28,0x630401b9,0x32c40139,0x88c475f5}},	// [39210] ितम्_, مورل, _söya_, _متکل, 
   {{0x3240001f,0x1ad801ad,0x2f000241,0x00000000}},	//   _ይቀርባ, योपथ, bògi_, --, 
   {{0xb630313e,0x322800d4,0x05840408,0x00000000}},	//   _ﺑﺎ_, ріум_, _тупм, --, 
   {{0xdef002d3,0xfd4800b8,0x846435e3,0x00000000}},	//   ልዎን_, _ghoṇ, _өзүң_, --, 
   {{0x644df717,0xcc1002e3,0x2d8c056a,0x2ff80276}},	//   maai, _dọkị, _asde_, анць_, 
   {{0x644df718,0xddc402bf,0x141802e4,0x00000000}},	//   laai, йбли, _תושב, --, 
   {{0x2d8c0204,0x63ac054e,0x6285f719,0x04f800fe}},	//   _csde_, ţină, meho, ্দীৰ_, 
   {{0x6285f71a,0x644df71b,0x00000000,0x00000000}},	//   leho, naai, --, --, 
   {{0x2d8c0098,0x00000000,0x00000000,0x00000000}},	//   _esde_, --, --, --, 
   {{0x6285f71c,0x644cc81f,0x6d6401e4,0x9938004e}},	//   neho, haai, _ŝtaŭ, ляму_, 
   {{0x644c18a6,0x7fd40220,0x5c740120,0x00000000}},	//   kaai, _сіңі, _глет, --, 
   {{0x6285f71d,0x644df71e,0xadbc030d,0x00000000}},	//   heho, jaai, _шахi, --, 
   {{0x6285f1b9,0x644c00ad,0x99d400f2,0x00000000}},	//   keho, daai, شتگا, --, 
   {{0x6285f71f,0xdb0801e1,0x4fd800df,0x00000000}},	//   jeho, _ònàj, אַלד, --, 
   {{0x6284019b,0xceb00302,0x644c0b23,0xd9d40154}},	//   deho, הים_, faai, _সুরম, 
   {{0x644c2ae1,0xf068001f,0x142401b9,0x00000000}},	//   gaai, ተዳዳሪ_, сдам, --, 
   {{0x03a10a33,0x62840418,0x78a45079,0xb4e832ed}},	// [39220] пито, feho, _iniv, _बदी_, 
   {{0xa3e801ad,0xfbc40014,0x09ac00cc,0x00000000}},	//   _बशर_, _ہت_, _ছেটা, --, 
   {{0xd468010b,0x644c058a,0xd388013d,0x00000000}},	//   _йине_, baai, _өйне_, --, 
   {{0xfbc49cc3,0x644c0363,0xdce000fd,0x4fc41a51}},	//   _فت_, caai, _orlı, йсла, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdfa40597,0x62843c36,0x7f8000d1,0x7f14009f}},	//   تحمي, ceho, سلىن, مينز_, 
   {{0x78a5f720,0xfcbc0020,0x068400d1,0x2bd019cc}},	//   _oniv, _ድምጽ_, ﻪﺗﻨﯩ, _तेजा, 
   {{0x4598010f,0x00000000,0x00000000,0x00000000}},	//   רסקע, --, --, --, 
   {{0x92e82baf,0x6ea801ed,0x0fc4010b,0xab954012}},	//   মতী_, _پناہ_, _уйан, ципі, 
   {{0x644c01a4,0xa9540640,0x8aa408ca,0xc8640075}},	//   zaai, овољ, срид, әтни, 
   {{0x6da8016b,0x644c0009,0x753c0210,0x02f800df}},	//   rɛas, yaai, jprz, רלימ, 
   {{0x48a852d8,0x6284002f,0x753c0210,0x98a4013d}},	//   утом_, zeho, dprz, frlı_, 
   {{0x628400aa,0x644c04c9,0xe8900023,0xfa3007d6}},	//   yeho, vaai, _ዝዛረቡ_, غرید, 
   {{0x644c5095,0x00000000,0x00000000,0x00000000}},	//   waai, --, --, --, 
   {{0x644c72dc,0x62843400,0x98a403e0,0xc95801a9}},	//   taai, veho, arlı_, _сўл_, 
   {{0xfcbc069c,0xf98c0597,0x78a40c86,0x6284017a}},	//   _ድምጺ_, _أبو_, _gniv, weho, 
   {{0x6285f721,0x68ec0248,0xa2b4519f,0x62d80006}},	// [39230] teho, _ijad, обач, амаў_, 
   {{0x1cac031c,0x673c002d,0x644df722,0x15f00037}},	//   _ཕྭན_, mpsj, saai, _आँचर_, 
   {{0x644df723,0x6285f724,0xf0e80116,0x00000000}},	//   paai, reho, ڭىنى_, --, 
   {{0x6285f725,0x04640edb,0x644c0009,0x443c010e}},	//   seho, _утом, qaai, _ýu_, 
   {{0x6285f726,0x68ec0451,0x6574017a,0x1fa951de}},	//   peho, _mjad, ltzh, ркли_, 
   {{0xfcbc0092,0x00000000,0x00000000,0x00000000}},	//   _ድምጸ_, --, --, --, 
   {{0x68ec6255,0x5ebc0eac,0x6574005a,0xb6bc0a1e}},	//   _ojad, ্চলে, ntzh, רצוי, 
   {{0xa0c4082e,0x68ec0241,0x40e40345,0x00000000}},	//   _بيرو, _njad, _اورێ_, --, 
   {{0xb9400020,0x60c9f727,0x5ac86418,0x753c033f}},	//   _የተካሄ, _ilem, илим_, zprz, 
   {{0x63ac004e,0x78a5f728,0x91bc0c58,0x2ee00221}},	//   ixan, _sniv, ্পৰ্, éift_, 
   {{0xfc301079,0xfcbc1772,0x63ac0051,0xdb4c02f2}},	//   _فحش_, _ድምጹ_, hxan, رێژ_, 
   {{0x18682edc,0xb4e800af,0x98a400f3,0xdce00139}},	//   шами_, _बदे_, циме, _trlı, 
   {{0x60c8055a,0x68edf729,0x78a40393,0xeb3000cf}},	//   _mlem, _djad, _vniv, _كۉيد, 
   {{0x1a640d73,0x63ac0213,0x89d40133,0xd944011c}},	//   _بیدی_, dxan, _ژوور_, _деки, 
   {{0x60c9f72a,0x06840131,0xda0c0b27,0x6d5c01e3}},	//   _olem, ﻪﺗﻠﯩ, _हरित_, _årat, 
   {{0x25a401e6,0x63ac0ba7,0x68ec0200,0x753c0210}},	//   ålla_, fxan, _gjad, rprz, 
   {{0x77941ae5,0x1b40001f,0x753c033f,0x63ac79d4}},	// [39240] _عیسا, _የነበራ, sprz, gxan, 
   {{0x60c9f72b,0x68ec033f,0x00000000,0x00000000}},	//   _alem, _zjad, --, --, 
   {{0x60c9f72c,0x86780a7c,0x00000000,0x00000000}},	//   _blem, _דריו, --, --, 
   {{0x63ac00ac,0x70540472,0x3dcc00eb,0x8d8c0092}},	//   bxan, سنتا, িপাল, መደበው_, 
   {{0x60c86085,0x10141a57,0xfe6c004b,0xbf30027d}},	//   _dlem, آباد, ږدي_, وروغ, 
   {{0x200c0810,0x479808a8,0x3945f72d,0x69dc00d7}},	//   _dzei_, יינס, _owns_, úrek, 
   {{0xd13036fe,0x00000000,0x00000000,0x00000000}},	//   _آمر_, --, --, --, 
   {{0x60c9f72e,0x008001c0,0x13dc00eb,0x00000000}},	//   _glem, _олсо, _ভুয়, --, 
   {{0x8e745a19,0x4a240135,0x66d001e1,0x2ee001c7}},	//   _мужч, _རྔུལ_, _jókù, éifs_, 
   {{0x66d00241,0xd9d400eb,0x00000000,0x00000000}},	//   _mókù, _সুইম, --, --, 
   {{0x2d99f72f,0xe894084c,0x60c8023a,0x63a80129}},	//   _ére_, пань, _ylem, _àenv, 
   {{0x63adf730,0x6d48047e,0x00000000,0x00000000}},	//   yxan, _iwda, --, --, 
   {{0x63adf731,0xdc2800c6,0xc05000d9,0x00000000}},	//   xxan, _اسمه_, וזר_, --, 
   {{0x673c143a,0x81c000de,0x00000000,0x00000000}},	//   rpsj, _ņēmu, --, --, 
   {{0x2ebc00bd,0x2f00068c,0xc4d80063,0xe91800c0}},	//   _অগাষ, lògs_, ађа_, _локі_, 
   {{0x63adf732,0x68ecd739,0x673c1445,0x04f80183}},	//   txan, _ujad, ppsj, ্দ্ৰ_, 
   {{0x68fc02d3,0x2918004e,0xb80802dd,0x81e40154}},	// [39250] mosd, mmsa_, _ويىم_, _পরই_, 
   {{0x63adf733,0x6d49f734,0x00000000,0x00000000}},	//   rxan, _owda, --, --, 
   {{0x672c02d3,0xdb1001d3,0x00000000,0x00000000}},	//   _huaj, égén, --, --, 
   {{0x63adf735,0x6ab83c12,0x672df736,0x397800c8}},	//   pxan, _lovf, _kuaj, שטאנ, 
   {{0x6d480050,0x2489f737,0x60c9a4c5,0x672de4ff}},	//   _awda, meam_, _vlem, _juaj, 
   {{0x672c044e,0x2489f738,0x23680218,0x6ab801e4}},	//   _muaj, leam_, muaj_, _novf, 
   {{0x60c81ebd,0x672c02d3,0x2369dcfe,0x629402d0}},	//   _tlem, _luaj, luaj_, _iazo, 
   {{0x60c9f739,0x2489f73a,0x6295f73b,0x672c01b8}},	//   _ulem, neam_, _hazo, _ouaj, 
   {{0x6295f73c,0x9f0419bc,0x200c01c0,0x672c0100}},	//   _kazo, _فورو, _uzei_, _nuaj, 
   {{0xdd949f4d,0xc0f0044e,0x6295f73d,0x29180a55}},	//   _назы, ልዮም_, _jazo, emsa_, 
   {{0x672c00ec,0x23680457,0x6abc5b00,0x1fbc00cc}},	//   _auaj, huaj_, örfa, _অধিস, 
   {{0xad244d8d,0x6294382f,0x68fcdd69,0x672d2420}},	//   _قىلى, _lazo, gosd, _buaj, 
   {{0x2489f73e,0xb3881b49,0x672c3eba,0x6295f73f}},	//   deam_, _ሚልዮን_, _cuaj, _oazo, 
   {{0x6295f740,0x672df741,0x2919f742,0x2368010f}},	//   _nazo, _duaj, amsa_, duaj_, 
   {{0x68fc01a9,0x66d001e1,0x00000000,0x00000000}},	//   bosd, _sókù, --, --, 
   {{0x01c03857,0x5fbc4c5b,0x24881cd4,0x672c000d}},	//   ্পাদ, ्नाल, geam_, _fuaj, 
   {{0x6295f743,0x672c0124,0x23684a10,0xdce000de}},	// [39260] _bazo, _guaj, guaj_, _aplī, 
   {{0x4798025f,0xd174010b,0x95c8f69e,0x00000000}},	//   _פייס, зыды, _глоб_, --, 
   {{0x2489f744,0x62940489,0x798002d0,0x00000000}},	//   beam_, _dazo, _jpnw, --, 
   {{0x3f9c013f,0x2489f745,0xf8cc547d,0x23680115}},	//   _bruu_, ceam_, ासिय, buaj_, 
   {{0x439002d5,0x798003ac,0x6d480142,0x00000000}},	//   _заўс, _lpnw, _swda, --, 
   {{0x6295f746,0x87780a1e,0xfe6c007b,0xd17401ee}},	//   _gazo, מאני, هدى_, _ныбы, 
   {{0x6ab812e8,0xf8cc243c,0x68fc01d5,0x00000000}},	//   _rovf, ासाय, yosd, --, 
   {{0x2bc80316,0x68fc01a9,0x00000000,0x00000000}},	//   ाईला, xosd, --, --, 
   {{0xfc3c26c8,0x6295f747,0x0b88016c,0x63a8b4a2}},	//   ñía_, _yazo, ёсии_, _àent, 
   {{0x7f380302,0x672c044e,0x3cec005a,0xbf600451}},	//   _לעמו, _ruaj, _ejgv_, _سگهو, 
   {{0x68fdf748,0x7aec0077,0x0c244130,0x00000000}},	//   tosd, écta, _емен, --, 
   {{0x2488003a,0xbb449924,0xa3ac03ce,0x63a802d2}},	//   xeam_, _کلون_, _कपल_, _áeng, 
   {{0x672c044e,0x23680218,0x2489f737,0xab9400d4}},	//   _quaj, xuaj_, veam_, _цилі, 
   {{0x0ebc45bf,0x672c02d3,0x98ac0882,0x236801e4}},	//   ्सिड, _vuaj, ānām_, vuaj_, 
   {{0x67241059,0x7a7800d9,0x00000000,0x00000000}},	//   _vihj, _הרוס, --, --, 
   {{0x2369f749,0x672c044e,0x6294036b,0x00000000}},	//   tuaj_, _tuaj, _sazo, --, 
   {{0x6295f74a,0x2489f74b,0x672c01f7,0xc6a401b9}},	// [39270] _pazo, ream_, _uuaj, _ерни, 
   {{0x23689b9f,0x9734008f,0x6294571b,0x248935fc}},	//   ruaj_, _קרתא_, _qazo, seam_, 
   {{0x6295f74c,0xc4c4038b,0x24880356,0x63a80064}},	//   _vazo, _فتحو, peam_, _šend, 
   {{0x04640a8f,0x2368020c,0xe4540166,0x00000000}},	//   _этом, puaj_, _юкмы, --, 
   {{0x6295f74d,0x0418015b,0x645c0165,0x62900022}},	//   _tazo, _ফ্রী_, _idsi, _иҳаӡ, 
   {{0xcfe01c82,0xde04033a,0x8fa00354,0xaec401ec}},	//   _বৰঙন, мпли, таше, нбіл, 
   {{0xefec1e38,0x4429f74e,0x00000000,0x00000000}},	//   _ህያው_, _kgc_, --, --, 
   {{0x7cf4025a,0xa2d805d7,0xca6801d5,0x3f9c0037}},	//   dûrû, फोर्, _sifа, _truu_, 
   {{0x645c0789,0x5ba801ce,0x3e5c00e2,0xbe4816a2}},	//   _mdsi, іком_, tātē_, _هشام_, 
   {{0x2d9c0083,0x1a6400e5,0x00000000,0x00000000}},	//   bvve_, ذیبی_, --, --, 
   {{0x6f8801d9,0xdc740153,0x00000000,0x00000000}},	//   _ونہِ_, _жыль, --, --, 
   {{0xa3ac0316,0x00000000,0x00000000,0x00000000}},	//   कमा_, --, --, --, 
   {{0x7d19f74f,0x7c29f750,0x00000000,0x00000000}},	//   mmus, _iggr, --, --, 
   {{0x645df751,0x5bc80a59,0x00000000,0x00000000}},	//   _adsi, िनीव, --, --, 
   {{0xcb10025f,0x4429f752,0x7d19f753,0xd4c40b24}},	//   _שלו_, _bgc_, omus, وغري, 
   {{0x7d180502,0x3cfc04cc,0x656001ed,0xe9a800cf}},	//   nmus, nouv_, álha, _ردىن_, 
   {{0x7d19f754,0x00000000,0x00000000,0x00000000}},	// [39280] imus, --, --, --, 
   {{0x81d42158,0xe3b0e647,0x645c90e7,0x7d19f755}},	//   াপন_, درِ_, _edsi, hmus, 
   {{0x63a8038f,0x442800cf,0x6eac00bc,0x00000000}},	//   _ġene, _fgc_, चासँ, --, 
   {{0x44280998,0x7c280214,0x00000000,0x00000000}},	//   _ggc_, _nggr, --, --, 
   {{0x7d189e7a,0x00000000,0x00000000,0x00000000}},	//   dmus, --, --, --, 
   {{0xbea11c4e,0xd5a0037e,0x59ac2ac3,0x00000000}},	//   качк, _cmでi_, टमार, --, 
   {{0x7c280334,0xdcb00051,0x2bb800cd,0xbea000d8}},	//   _bggr, _hủy_, ेन्थ, тајк, 
   {{0x8bc4009d,0x00000000,0x00000000,0x00000000}},	//   дсод, --, --, --, 
   {{0xc0e040c5,0x09a400cd,0x00000000,0x00000000}},	//   _ротк, गम्य, --, --, 
   {{0x7d19f756,0x7c28035a,0xff24028e,0x28e00037}},	//   amus, _eggr, _قبلی, _पगहि, 
   {{0xdb0800e4,0x00000000,0x00000000,0x00000000}},	//   gyeñ, --, --, --, 
   {{0x6d5852fd,0x7d19f757,0xef5402d3,0xf3e400cc}},	//   msva, cmus, _ምተደል, _খৰছৰ_, 
   {{0x6d581455,0x9ba0198a,0x00000000,0x00000000}},	//   lsva, _مەيى, --, --, 
   {{0x6595f758,0x6d58127b,0x00000000,0x00000000}},	//   нагу, osva, --, --, 
   {{0xf98c5706,0x44286e25,0x19c00166,0xc984009f}},	//   _نبي_, _pgc_, _бәяг, _آشتي, 
   {{0x538802d3,0x6d59f759,0x63a8025c,0x09c86211}},	//   _ምክያድ_, isva, _ġenb, ानीय, 
   {{0xe3140261,0x442801f5,0x49440023,0x00000000}},	// [39290] емањ, _vgc_, _የተባብ, --, 
   {{0x6d582bf2,0x44280789,0x41e4454b,0x7d1801ed}},	//   ksva, _wgc_, وساف, zmus, 
   {{0x7d19f75a,0x35f44838,0x4429f75b,0xe13800d4}},	//   ymus, _апэр, _tgc_, їзді_, 
   {{0x6d581347,0x645c04ce,0x44280129,0x00000000}},	//   dsva, _udsi, _ugc_, --, 
   {{0x6d58127b,0x81e4015b,0xf0b800f2,0x00000000}},	//   esva, _পরও_, بالش_, --, 
   {{0x6d5801a8,0xdb1403b2,0xa1582902,0x00000000}},	//   fsva, _óbøt, _нагу_, --, 
   {{0x6d59f75c,0x8eb00137,0xf2044130,0x00000000}},	//   gsva, امىش, _аято, --, 
   {{0x9f5000dd,0x7d1800b5,0x313400ea,0xb068009b}},	//   ából_, umus, _јетр, _оруж_, 
   {{0x3cfc2165,0x213005c7,0x6d582301,0x5bc84244}},	//   rouv_, _huzh_, asva, िनेव, 
   {{0x21300156,0x6d5801bf,0x00000000,0x00000000}},	//   _kuzh_, bsva, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe0bc015b,0x00000000,0x00000000,0x00000000}},	//   _আগুন, --, --, --, 
   {{0xbbe9f75d,0xec74035b,0x20340023,0x00000000}},	//   _برام_, _рҿы_, _ብዓሰር, --, 
   {{0x213007e4,0xaa38001f,0x32c40139,0x97c40150}},	//   _ouzh_, _በፓርላ, _töyi_, _үйке, 
   {{0x24980311,0xfb840022,0x00000000,0x00000000}},	//   _basm_, _хыҵн, --, --, 
   {{0x9425f75e,0x5f14009e,0xd394151e,0x77a40117}},	//   ембе, াদিও_, нәгә_, _алиҷ, 
   {{0x38607e9f,0xd7c830cd,0xbb1400d1,0x9654011c}},	// [392a0] _idir_, _روده_, ﻳﯘﻥ_, _пънч, 
   {{0x6d58023a,0x3940001f,0x00000000,0x00000000}},	//   ysva, _የተደራ, --, --, 
   {{0x38600139,0x00000000,0x00000000,0x00000000}},	//   _kdir_, --, --, --, 
   {{0x25a404ce,0x26142aa1,0xe3b0004b,0x4aa40037}},	//   ælle_, _धरती_, درې_, _कोनव, 
   {{0x2130030a,0x4ea4010b,0x6d58127b,0x00000000}},	//   _euzh_, ерйа, wsva, --, 
   {{0x6d59f75f,0xd1c80220,0xb38c001f,0x386001a9}},	//   tsva, _елге_, ሆነውን_, _ldir_, 
   {{0x213005c7,0x6d59f760,0xdd8c0131,0x00000000}},	//   _guzh_, usva, يۈك_, --, 
   {{0x3860002e,0xdd980212,0x24840023,0xcb440124}},	//   _ndir_, ьші_, _ርኽሰት_, нхои, 
   {{0xa074678d,0xaf2401e0,0x00000000,0x00000000}},	//   _шырш, _апаһ, --, --, 
   {{0x3860a94c,0x601401ee,0x00000000,0x00000000}},	//   _adir_, _рєсє, --, --, 
   {{0xfbcc2352,0x28f8759f,0x3ed0006c,0xc278011a}},	//   لتی_, день_, _حقلر, הריי, 
   {{0x386001ab,0x95740240,0x00000000,0x00000000}},	//   _cdir_, ክነትን_, --, --, 
   {{0xc7c41638,0x2498036b,0x8ae40212,0xbb41f761}},	//   хсни, _rasm_, _пікл, _бечк, 
   {{0x386011a9,0x65603b7b,0x81d400cc,0x7bdc0051}},	//   _edir_, álho, াপত_, _ýqua, 
   {{0x3a3400c8,0x758854ea,0xc984bd83,0x00000000}},	//   _ארום_, нств_, _чули, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe30403bd,0x62341d39,0xd1c40240,0x00000000}},	// [392b0] _མེདཔ_, везу, _ጸዲቑ_, --, 
   {{0x537c069c,0x36d40408,0x00000000,0x00000000}},	//   እሰያት_, _боьр, --, --, 
   {{0xa5f802ee,0x3860022e,0x00000000,0x00000000}},	//   _цену_, _ydir_, --, --, 
   {{0x30740415,0x00000000,0x00000000,0x00000000}},	//   гушс, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe2f400c7,0x23680455,0x0e60133a,0xd345af6a}},	//   _рзгь, mraj_, акшн, _شیمه_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x81d4045e,0x6b840276,0x5ba85e3e,0x44380129}},	//   াপদ_, _ţiga, дким_, ncq_, 
   {{0x386001ab,0x23680115,0x00000000,0x00000000}},	//   _rdir_, nraj_, --, --, 
   {{0x23680552,0x9e94da98,0x5d84007b,0x0c200276}},	//   iraj_, _جارچ, _للطل, шмын, 
   {{0xdd903251,0x236872bd,0x18680b01,0xa03402d3}},	//   _خوا_, hraj_, мани_, _ብሓንሳ, 
   {{0x23697f7d,0xade42401,0x386001d5,0xac7400f2}},	//   kraj_, _сцук, _qdir_, _ماهش, 
   {{0x81d402a6,0xda0c2274,0x7c38003a,0x2368ec48}},	//   াপি_, _हरकत_, mcur, jraj_, 
   {{0x7c385cb7,0x2369f762,0x00000000,0x00000000}},	//   lcur, draj_, --, --, 
   {{0xdecc001f,0xceb00a1e,0x23681426,0x89d414af}},	//   _እኛን_, סיל_, eraj_, _لوور_, 
   {{0x3861f763,0x38c80ec9,0x236802e2,0xfb1000ec}},	//   _udir_, _ساعی_, fraj_, _جوڙج, 
   {{0x2369f764,0x940c016b,0xa3e40c6e,0x7c380022}},	// [392c0] graj_, ɛfɛ_, _भेद_, icur, 
   {{0x1dd0043e,0x00000000,0x00000000,0x00000000}},	//   तनात, --, --, --, 
   {{0x236801e4,0x7c3801f5,0x00000000,0x00000000}},	//   araj_, kcur, --, --, 
   {{0x4fe9c5dc,0x2368c5a6,0xa0a402dd,0x00000000}},	//   ммен_, braj_, лшіл, --, 
   {{0x7ae000f1,0x9c7c003a,0x7c38058a,0x32c40166}},	//   _omnt, tiōn, dcur, _söyu_, 
   {{0x7c380381,0x94d0000d,0x00000000,0x00000000}},	//   ecur, _सतुआ, --, --, 
   {{0x7c38003a,0x91e4bf73,0x15d002dd,0xaa9401d5}},	//   fcur, _рове, _ﮔﺎﺯﻩ, қинч, 
   {{0x0574069c,0xc5f00375,0x0c840209,0xe80400cd}},	//   _ይግባእ_, ידו_, тыкм, रथमा_, 
   {{0x09c87922,0x4f25f765,0x7ae000fb,0x248df766}},	//   ान्य, _адаб, _bmnt, _ñeme_, 
   {{0x9510025c,0x7c38054e,0xa3e4000d,0xbb440066}},	//   _ཉེའི_, acur, _भइस_, کلین_, 
   {{0x236852bf,0x6aa400db,0x8b64072d,0x00000000}},	//   zraj_, _ەشبە, راکم, --, 
   {{0x7ae000f1,0x8c441a92,0x48a91e06,0xc1700375}},	//   _emnt, _реде, фтом_, סחר_, 
   {{0x4aa4000d,0x00000000,0x00000000,0x00000000}},	//   _कोथव, --, --, --, 
   {{0x23680649,0x0c6c0092,0x00000000,0x00000000}},	//   vraj_, _በቀጣዩ_, --, --, 
   {{0xa4d402bf,0x25a401a8,0x00000000,0x00000000}},	//   гові, íll_, --, --, 
   {{0x2369f767,0x4aa402ab,0x69c80363,0x4438030a}},	//   traj_, _कोतव, myde, ucq_, 
   {{0x4438180f,0x29080270,0x7799f768,0xa0a402dd}},	// [392d0] rcq_, _ikaa_, _акыр_, ғалд, 
   {{0x236818dd,0xfde0007d,0x00000000,0x00000000}},	//   rraj_, _कइलस_, --, --, 
   {{0x69c92300,0x7c380334,0x236906be,0x28140101}},	//   nyde, ycur, sraj_, _جوکس, 
   {{0x2368008f,0x9d440b8d,0xdff44166,0x69c8062c}},	//   praj_, ңелд, ляль, iyde, 
   {{0x26c0fa1b,0x69c90da3,0xa3ac02e5,0x290801c8}},	//   _koho_, hyde, _कपट_, _mkaa_, 
   {{0x26c0009f,0x69c83c38,0x248c00e4,0xaf040006}},	//   _joho_, kyde, _ñemb_, апіл, 
   {{0x26c1f769,0x41240022,0xdbd000a2,0x69c8005c}},	//   _moho_, _афаб, _düým, jyde, 
   {{0x29081d36,0x26c1f76a,0x7c380798,0x69c801bf}},	//   _nkaa_, _loho_, ucur, dyde, 
   {{0x7c39f76b,0x69c8062c,0xcc840108,0x00000000}},	//   rcur, eyde, убые_, --, 
   {{0x26c1f76c,0x2909f76d,0xfe706b18,0xdbd0010b}},	//   _noho_, _akaa_, _خدر_, _güým, 
   {{0x212c020c,0x49c401c0,0x69c9f76e,0x7c3801f5}},	//   _kieh_, глэн_, gyde, pcur, 
   {{0x5b1400fd,0x63a80135,0x00000000,0x00000000}},	//   _өмет, _ġenn, --, --, 
   {{0x69c8062c,0x00000000,0x00000000,0x00000000}},	//   ayde, --, --, --, 
   {{0x7ae1eac1,0x69c8037e,0x212c0731,0xdbd000af}},	//   _umnt, byde, _lieh_, _müüm, 
   {{0x18a5f76f,0x29080270,0x26c001e4,0x7bd801a4}},	//   _байм, _fkaa_, _doho_, lzuu, 
   {{0x97c52b48,0x212c02b4,0x200c0085,0x00000000}},	//   _مقبو, _nieh_, _oyei_, --, 
   {{0x9345f770,0x7bd9f771,0xdb1403b2,0x5284001b}},	// [392e0] унзе, nzuu, _óbót, лгаб, 
   {{0x26c1578c,0x62640f87,0xb91400b8,0x3d0c00cd}},	//   _goho_, لامق, _ajaḥ_, ातुं_, 
   {{0x506543f8,0x200c043b,0x212c016b,0x10a40e92}},	//   гтла, _ayei_, _bieh_, лижн, 
   {{0x2ecc00dc,0xdbd000a2,0x00000000,0x00000000}},	//   ऽस्त, _süým, --, --, 
   {{0x212c0134,0x69c80034,0x0874008f,0x70c40807}},	//   _dieh_, zyde, רענט_, _वकील, 
   {{0x69c802f6,0x23b000cf,0x00000000,0x00000000}},	//   yyde, _بۅكس, --, --, 
   {{0x200c02ea,0x8d85f772,0x69c80072,0xcd8400db}},	//   _eyei_, اشتن, xyde, اجتى, 
   {{0xbd8505ee,0x69c9f773,0x212c031c,0x412400d8}},	//   انين_, vyde, _gieh_, _босо_, 
   {{0x200c016b,0x7bd801a4,0x691cdf8a,0x69c8d6c4}},	//   _gyei_, gzuu, léeg, wyde, 
   {{0x69c95ca3,0xc3300bd9,0x212c0e78,0x2909f774}},	//   tyde, זוז_, _zieh_, _skaa_, 
   {{0x26c1f775,0x7bd81418,0x69c80076,0xfaa001ec}},	//   _roho_, azuu, uyde, сшын, 
   {{0x26c1f776,0x69c9f777,0xa3e4367a,0xc8ac05d7}},	//   _soho_, ryde, _भइल_, टाइट, 
   {{0x26c1f778,0x8a040046,0x69c8005c,0x63a8025c}},	//   _poho_, _өзде, syde, _ġeno, 
   {{0x63a801ef,0xa3e43cc3,0x00000000,0x00000000}},	//   _šeno, _भेष_, --, --, 
   {{0x26c005da,0x00000000,0x00000000,0x00000000}},	//   _voho_, --, --, --, 
   {{0x26c0013f,0xd1e4001f,0x2908009f,0x47f0010b}},	//   _woho_, ሚነት_, _ukaa_, _гүмр, 
   {{0x26c1f779,0x212c0649,0xbec4005f,0x07e4010b}},	// [392f0] _toho_, _rieh_, ldīš, _щцкм, 
   {{0x212df77a,0xa5c40046,0x22280424,0x00000000}},	//   _sieh_, _көбе, نزای_, --, 
   {{0x2d8c0472,0xdfd005d9,0x7aec04d4,0x6b84054e}},	//   _npde_, ڊيا_, écti, _ţigl, 
   {{0xdfd01fd6,0x5f7404fb,0x00000000,0x00000000}},	//   ييا_, لاتر, --, --, 
   {{0x644df77b,0x212d2202,0x00000000,0x00000000}},	//   mbai, _vieh_, --, --, 
   {{0x644df77c,0x3ce40037,0x7bd80205,0x00000000}},	//   lbai, _जगहे_, vzuu, --, 
   {{0xaac8012c,0x644c0e89,0x9d440150,0x62840332}},	//   ाउनक, obai, шейд, mfho, 
   {{0x644c05f5,0x62842233,0x7bd801a4,0xdbd0000d}},	//   nbai, lfho, tzuu, _tüüm, 
   {{0x644c0810,0xbec400ef,0x00000000,0x00000000}},	//   ibai, edīš, --, --, 
   {{0x644df77d,0x6284007b,0x5ac82069,0x7bd801a4}},	//   hbai, nfho, тлом_, rzuu, 
   {{0x79e400e5,0x00000000,0x00000000,0x00000000}},	//   اوجہ_, --, --, --, 
   {{0xd8258059,0x644c0007,0x628400ae,0xcd4000e5}},	//   идни, jbai, hfho, _بھوٹ, 
   {{0xa3e4007d,0x644c0332,0x00000000,0x00000000}},	//   _भेल_, dbai, --, --, 
   {{0x9400016b,0x628409b6,0xef180354,0x00000000}},	//   _makɔ_, jfho, _умĕ_, --, 
   {{0x09e006ed,0x6cec02e5,0x644c015d,0x62840332}},	//   _мошн, _जगमग_, fbai, dfho, 
   {{0x6284017a,0x644d1ef9,0xf37801c6,0x00000000}},	//   efho, gbai, лөгч_, --, 
   {{0x68fc01ed,0x60c80135,0x6284002f,0x00000000}},	// [39300] érde, _ċemp, ffho, --, 
   {{0x55e51d5b,0x644df77e,0x628401e7,0xa3e40073}},	//   _вооб, abai, gfho, _भेळ_, 
   {{0xd1741c3e,0x644df77f,0x00000000,0x00000000}},	//   рызы, bbai, --, --, 
   {{0x4fc4f011,0x765c9398,0xb358066d,0x644c01c3}},	//   исла, lary, _میرا_, cbai, 
   {{0x98a42573,0xddc001e4,0x7524005c,0x248c00e4}},	//   nslı_, _velŝ, mmiz, _ñema_, 
   {{0xb8d8031c,0x7f5c0194,0x7524ce7c,0x8c9c012d}},	//   _ཛོ_, âqqa, lmiz, _खोजो, 
   {{0xdce00365,0x90b400d8,0x42e400d8,0x00000000}},	//   _aslı, _кљаш, _тмро_, --, 
   {{0x7d21c4b5,0x7525f780,0x765df781,0xfbe4015b}},	//   يفون, nmiz, hary, _পড়ত, 
   {{0x765df782,0x7524022e,0x00000000,0x00000000}},	//   kary, imiz, --, --, 
   {{0x765d22ac,0x644c5426,0x6b800083,0xca2401a9}},	//   jary, zbai, rtmg, ифни, 
   {{0x765df783,0x00000000,0x00000000,0x00000000}},	//   dary, --, --, --, 
   {{0x1cb4025c,0x644c0007,0xbe1001d5,0x4aa4000d}},	//   _ཝོར_, xbai, _بومع, _कोरव, 
   {{0x765df784,0x6284017a,0xa3e40037,0x00000000}},	//   fary, yfho, _भें_, --, 
   {{0x765df785,0x443c031c,0x00000000,0x00000000}},	//   gary, _żu_, --, --, 
   {{0x6abc0008,0xe94422cd,0x7aec1497,0x66d80248}},	//   örfu, _ارتی, ècte, _nìke, 
   {{0x7524010e,0x00000000,0x00000000,0x00000000}},	//   gmiz, --, --, --, 
   {{0x644df786,0x765df787,0x1cb4031c,0x691c002e}},	// [39310] rbai, bary, _ཝོལ_, géee, 
   {{0x765c0882,0x644c0013,0x75240109,0x225800f2}},	//   cary, sbai, amiz, الاد_, 
   {{0x3ce41b57,0x273c0cad,0x45a000db,0x7524022e}},	//   _जगले_, _hìn_, _بەزك, bmiz, 
   {{0x628400c6,0x65740099,0x273c0cad,0x00000000}},	//   sfho, muzh, _kìn_, --, 
   {{0x273c0248,0xddc00356,0x62840175,0x60d802d0}},	//   _jìn_, _belş, pfho, rhwm, 
   {{0x4aa4069f,0x273c004d,0x5398011a,0x91d400cc}},	//   _कोलव, _mìn_, _גישו, _দশৰ্, 
   {{0xad58b0b9,0x9400013f,0x940c013b,0x9f940254}},	//   арых_, _wakɔ_, ɛfɑ_, _hüüa_, 
   {{0x765c0209,0x63a8025c,0x313400f5,0x00000000}},	//   zary, _ġenj, _фетр, --, 
   {{0x65740010,0x00000000,0x00000000,0x00000000}},	//   huzh, --, --, --, 
   {{0x9f94007d,0xbd680276,0x6575f788,0x22400113}},	//   _müüa_, _арде_, kuzh, nchk_, 
   {{0x765df789,0x2a7c004e,0x9f9400c5,0x752401d5}},	//   vary, _dcvb_, _lüüa_, ymiz, 
   {{0x765df78a,0x64400139,0x313c0023,0xfca82e0b}},	//   wary, _şlin, _ክነብር, _جائو_, 
   {{0x765df78b,0x9b440fb4,0xd7f0007b,0x2bc800d8}},	//   tary, _انتو, سكس_, _вујо_, 
   {{0x5018011a,0x9984009f,0xd6d0007b,0xaa94030d}},	//   טורו, _هلتو, أقس_, _мичч, 
   {{0x6574030a,0xd4698513,0x00000000,0x00000000}},	//   guzh, ливе_, --, --, 
   {{0x765df78c,0x6820063f,0x7524806e,0xd3b802bf}},	//   sary, _ịden, umiz, лузі_, 
   {{0x765df78d,0x6af801d9,0x273c01fb,0xd26400db}},	// [39320] pary, _حى۪س_, _gìn_, йкай, 
   {{0x765c022e,0xddc000e5,0x00000000,0x00000000}},	//   qary, _lelő, --, --, 
   {{0xd184130f,0xc32c0050,0x752401a9,0x91e40395}},	//   слей, رٕم_, pmiz, щоже, 
   {{0x273c110e,0x00000000,0x00000000,0x00000000}},	//   _yìn_, --, --, --, 
   {{0x0ee810f5,0x273c0051,0x00000000,0x00000000}},	//   льки_, _xìn_, --, --, 
   {{0x11d484da,0xb1b401ec,0x4798011a,0x00000000}},	//   _любя, _وڭاش, טינס, --, 
   {{0xddc1f78e,0x10a5f78f,0xc690011a,0xbd840346}},	//   _belő, _ливн, פאה_, منون_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbf1001a9,0xfde40075,0x00000000,0x00000000}},	//   _کولب, идәк_, --, --, 
   {{0x63a8627e,0x42d8010f,0x273c0cad,0x00000000}},	//   _šenk, ָקטע, _rìn_, --, 
   {{0x2d99f790,0xddc001d3,0xcd34bfae,0x273c110e}},	//   _ère_, _felő, _طراب, _sìn_, 
   {{0x021423e4,0x6d4801a9,0x0ba8129d,0x00000000}},	//   מחים_, _itda, _ماتى_, --, 
   {{0x4c147610,0x00000000,0x00000000,0x00000000}},	//   _اباس, --, --, --, 
   {{0xf40000bd,0xfaa0bf2a,0xe5b40139,0x00000000}},	//   ্ধার_, _начо, ойгы, --, 
   {{0xc5140014,0xe50800aa,0x9f9400af,0x0464b391}},	//   مبرت, ليسو_, _süüa_, йтам, 
   {{0x657405b8,0x9f940037,0x273df791,0x00000000}},	//   ruzh, _püüa_, _tìn_, --, 
   {{0xe29801e0,0x00000000,0x00000000,0x00000000}},	// [39330] һаҡ_, --, --, --, 
   {{0x6d487ade,0xe2d80014,0x00000000,0x00000000}},	//   _otda, جارچ_, --, --, 
   {{0xe2980032,0xc0c9f792,0x248c00e4,0xf7f401ec}},	//   лаҡ_, луде_, _ñemo_, _وسۋد, 
   {{0x051400fe,0x00000000,0x00000000,0x00000000}},	//   _দূৰৰ_, --, --, --, 
   {{0x6d49f793,0x00000000,0x00000000,0x00000000}},	//   _atda, --, --, --, 
   {{0x24883450,0x62340395,0x00000000,0x00000000}},	//   lfam_, _феву, --, --, 
   {{0x9db9f794,0x31c403c5,0x00000000,0x00000000}},	//   рылу_, _еств, --, --, 
   {{0x3c2c00ac,0xa91c00d7,0x00000000,0x00000000}},	//   _növü_, ytľa, --, --, 
   {{0x6d48047e,0x200800e2,0x00000000,0x00000000}},	//   _etda, ļais_, --, --, 
   {{0x3f9c198f,0x24880327,0x5d84007b,0xdd940024}},	//   _isuu_, hfam_, _ولذل, _мазы, 
   {{0xaa44001f,0xad2401d9,0x1cd80327,0xad5800d4}},	//   _የአምላ, _کرٕو, ོལད_, _гріх_, 
   {{0xa3d80034,0x69dc01ab,0x6abc01e3,0x00000000}},	//   ़ना_, ùrea, örfr, --, 
   {{0x68fc0407,0x98159566,0x00000000,0x00000000}},	//   érda, تبدا, --, --, 
   {{0xf8b80184,0x9a280276,0x24881bce,0x00000000}},	//   рөҫ_, _колб_, efam_, --, 
   {{0xd628e7ee,0x9b4400ec,0x00000000,0x00000000}},	//   рове_, _انڪو, --, --, 
   {{0xb4042002,0x3f9c005b,0x79800208,0x691c0036}},	//   зүмд, _osuu_, _iqnw, réec, 
   {{0x78a40421,0xba0404b2,0x00000000,0x00000000}},	// [39340] _iaiv, _ሊል_, --, --, 
   {{0x78a5f795,0x39800156,0x03200107,0x24880064}},	//   _haiv, oñs_, ддун, afam_, 
   {{0x78a5f796,0x3f9c023a,0x37180583,0x00000000}},	//   _kaiv, _asuu_, _پرکھ_, --, 
   {{0xfbc43c5a,0x78a5f797,0x6d4801a9,0xa08802dd}},	//   _قت_, _jaiv, _rtda, йсіз_, 
   {{0x78a5f798,0x6d49f799,0x3e5000b8,0x00000000}},	//   _maiv, _stda, _ṛtau_, --, 
   {{0x78a5f79a,0x0cd000dc,0xcd34009a,0x00000000}},	//   _laiv, तस्म, يرعب, --, 
   {{0x3f9c0093,0xbd408207,0x63a8003d,0x00000000}},	//   _esuu_, ونوي, _ġeni, --, 
   {{0x78a5f79b,0x0ca9f79c,0xff2400b5,0xae740139}},	//   _naiv, ртки_, _vpsの, _şığa, 
   {{0x39800165,0x788401d3,0xaa882824,0x00000000}},	//   eñs_, zívó, منظم_, --, 
   {{0xcb180cfc,0x78a40099,0x37c0015b,0xc984020f}},	//   јќи_, _aaiv, উনার, оуми, 
   {{0x6d481a82,0x78a5f79d,0x7be0013f,0x4424001e}},	//   _utda, _baiv, _ɑtuɑ, ̀n_, 
   {{0x7aec30cf,0x78a40a28,0x59700447,0x9590010c}},	//   éctr, _caiv, رگىز, ውነትን_, 
   {{0x78a5f79e,0x603403be,0x398005c7,0xc6a400d8}},	//   _daiv, _həmç, añs_, орви, 
   {{0x66d80248,0x69280055,0xa3e406b1,0xaa5c0150}},	//   _bìka, _aśet, _भेग_, _секi, 
   {{0x78a5f79f,0x61ac0220,0x5eec033f,0xe858010a}},	//   _faiv, _ءﻭﺭﺕ_, _अगस्_, _лайш_, 
   {{0xd6d80364,0x78a5f7a0,0xa854004e,0x00000000}},	//   атӣ_, _gaiv, _экич, --, 
   {{0x3d0829da,0x68ec090c,0x33844b1f,0x00000000}},	// [39350] ावते_, _imad, духв, --, 
   {{0x24880161,0x66d801e1,0x68ec01bf,0x466800f3}},	//   sfam_, _fìka, _hmad, _трим_, 
   {{0x78a405b8,0x419400d1,0x00000000,0x00000000}},	//   _yaiv, تماڭ_, --, --, 
   {{0x3f9c090c,0xf0e80046,0xea000208,0x00000000}},	//   _psuu_, يىلى_, _ngậy_, --, 
   {{0x68ec44fc,0x645df7a1,0xa4f80574,0x63a80135}},	//   _mmad, _iesi, ्कीच_, _ġenw, 
   {{0x645df7a2,0x68ec01b9,0x33580276,0x630400f1}},	//   _hesi, _lmad, _фарэ_, _روزل, 
   {{0x645df7a3,0x81f4aaac,0x68edf7a4,0x290000df}},	//   _kesi, _بہار_, _omad, _ĉian_, 
   {{0xad24092f,0x68edf7a5,0x645df7a6,0xbb141870}},	//   وريو, _nmad, _jesi, ﺰﺩﻩ_, 
   {{0x78a5f7a7,0x645df7a8,0x3f9c0e14,0xb9400092}},	//   _raiv, _mesi, _usuu_, _ከተካሄ, 
   {{0x645c6580,0x78a5f7a9,0x60c8166a,0xee74030d}},	//   _lesi, _saiv, _hoem, _олуь, 
   {{0x60c87168,0x78a40433,0x4ef800c8,0xaf0800c6}},	//   _koem, _paiv, _פלעג, _بقلم_, 
   {{0x645df7aa,0x78a40286,0x60c80af9,0xdd9400c7}},	//   _nesi, _qaiv, _joem, _маҷы, 
   {{0x78a5f7ab,0x60c8d023,0xaac49163,0xac180408}},	//   _vaiv, _moem, ستین, _доцу_, 
   {{0x78a5f7ac,0x68edf7ad,0x645c0493,0x60c9f7ae}},	//   _waiv, _emad, _aesi, _loem, 
   {{0x645df7af,0x78a5f7b0,0xceb002e4,0x00000000}},	//   _besi, _taiv, עיל_, --, 
   {{0x60c9f7b1,0x9344e2de,0x68ec037e,0x691df7b2}},	//   _noem, знае, _gmad, léen, 
   {{0x52381ec7,0x00000000,0x00000000,0x00000000}},	// [39360] مساح_, --, --, --, 
   {{0x691df7b3,0x645df7b4,0x68ec0023,0x42c4010b}},	//   néen, _eesi, _zmad, пгун_, 
   {{0x60c87d49,0x645c096b,0x68edf7b5,0x62640137}},	//   _boem, _fesi, _ymad, باقق, 
   {{0x645df7b6,0x60c80e17,0xc95005d0,0xfbd81408}},	//   _gesi, _coem, גמא_, यनाम, 
   {{0x446000a7,0x60c9f7b7,0x80d000db,0x00000000}},	//   _явяв, _doem, رۅكچ, --, 
   {{0x645c0928,0xa3e4205d,0x00000000,0x00000000}},	//   _zesi, _भेट_, --, --, 
   {{0x645c2935,0x60c80381,0x1ee803e6,0x4638010f}},	//   _yesi, _foem, تووی_, זעצע, 
   {{0x60c8a1f8,0xd13000c6,0xc02400f1,0x00000000}},	//   _goem, _أمر_, _کړمه_, --, 
   {{0x68ec01b9,0x248c0139,0x00000000,0x00000000}},	//   _rmad, _öeme_, --, --, 
   {{0x68edf7b8,0x60c801a4,0x691c1bce,0xeaf800bc}},	//   _smad, _zoem, géen, ुवेत_, 
   {{0x1ea9f7b9,0xc6a48bbd,0x68fc0022,0x00000000}},	//   _باقي_, үрги, érdo, --, 
   {{0xfce10b85,0x8b6442b5,0x61e00254,0x00000000}},	//   _похо, _فاتم, _ülle, --, 
   {{0x7d280014,0x691c1bce,0xfbcc1541,0xfc3c0419}},	//   _ازلہ_, béen, _متو_, žíc_, 
   {{0x645c730f,0x691d1803,0x597000f7,0xeff80240}},	//   _sesi, céen, رگۉز, _ገደደ_, 
   {{0xa3e41533,0x68ec01d5,0xfaa00120,0x2bd405c0}},	//   _भेज_, _tmad, _чајо, धनका, 
   {{0x68edf7ba,0xba1402e4,0x645c036e,0x00000000}},	//   _umad, _מחוץ_, _qesi, --, 
   {{0x60c9f7bb,0x645df7bc,0x68fc01e6,0x391401d9}},	// [39370] _roem, _vesi, mnsd, _سوٝز, 
   {{0x645c124c,0x60c9f7bd,0x29194e67,0x82340127}},	//   _wesi, _soem, llsa_, سرطا, 
   {{0x645df7be,0x68fc127b,0x60c9f7bf,0xe6940124}},	//   _tesi, onsd, _poem, _еиҿы, 
   {{0x68fc91d0,0x645c1132,0xdb080af9,0x00000000}},	//   nnsd, _uesi, tveë, --, 
   {{0x9c7c00b0,0x60c8030a,0x68fdf7c0,0x00000000}},	//   kiōr, _voem, insd, --, 
   {{0x63ac19f8,0x67240076,0x60c80af9,0xa1580024}},	//   mvan, _jhhj, _woem, _магу_, 
   {{0x60c8ec47,0x00000000,0x00000000,0x00000000}},	//   _toem, --, --, --, 
   {{0x63acd831,0x1b49255e,0x9b4449f6,0x66d800e4}},	//   ovan, озии_, ونبو, _oìko, 
   {{0x9f05f7c1,0x4c900640,0xdea001d5,0x00000000}},	//   _قورو, тињс, _لیشی, --, 
   {{0x7f580472,0x68fc0036,0x3d0800dc,0x00000000}},	//   _iwuq, ensd, ावहे_, --, 
   {{0x7e61f7c2,0x63adf7c3,0x691c2d7d,0x6f0401e7}},	//   manp, hvan, réen, éice, 
   {{0x7e61f7c4,0xdf70069c,0x63adf7c5,0xad246073}},	//   lanp, _ብሰንኪ_, kvan, _كىلى, 
   {{0x63adf7c6,0x691c20ef,0x48e028e8,0x00000000}},	//   jvan, péen, тояв, --, 
   {{0x63ac72ab,0x7e601bb7,0x68fc0a40,0x29181c06}},	//   dvan, nanp, ansd, alsa_, 
   {{0x9949f7c7,0xaac4021a,0x63adf7c8,0x4aa407f7}},	//   _بلبل_, _ستون, evan, _कोटव, 
   {{0x7e61f7c9,0x7f580b6f,0xd39402d9,0x3dac00cc}},	//   hanp, _owuq, мәгә_, _কথাল, 
   {{0x63adf7ca,0x7e61f7cb,0xccf00302,0x98b002e2}},	// [39380] gvan, kanp, דכן_, _jiyč_, 
   {{0x6724026c,0x15b80139,0x63a80135,0x38602517}},	//   _ghhj, _дымы_, _ġent, _heir_, 
   {{0xd6280aec,0x7f58209c,0x63a809a8,0xd62431ed}},	//   _фоне_, _awuq, _šent, _تعظي, 
   {{0x63adf7cc,0x50b98f31,0x386000ad,0x00000000}},	//   bvan, غداد_, _jeir_, --, 
   {{0x3861f7cd,0x6aa80cfd,0x3e44002e,0xcf240979}},	//   _meir_, yddf, _bёt_, ورتي, 
   {{0x290000c8,0x386076bf,0x7e60047e,0xbea00120}},	//   _ĉiam_, _leir_, ganp, ваљк, 
   {{0xc690025f,0x7f58014b,0xadd802bf,0x68fdf7ce}},	//   דאו_, _ewuq, ямку_, ynsd, 
   {{0x38600c86,0xfafc01c7,0xd00800db,0x6aa80042}},	//   _neir_, éën_, _дебе_, wddf, 
   {{0x7e61f7cf,0x63a80077,0xcfa804fb,0x9c7c003a}},	//   banp, _áent, _بازم_, tiōr, 
   {{0x3860007b,0x7e609add,0x321800e4,0xcdd40640}},	//   _aeir_, canp, _kyry_, _оцењ, 
   {{0x38603e7c,0x0c841c3e,0x2919f7d0,0x691c00e8}},	//   _beir_, _жылм, tlsa_, béel, 
   {{0x63ac07c4,0x386000a9,0x68fc01c7,0x00000000}},	//   yvan, _ceir_, unsd, --, 
   {{0x3861f7d1,0x0ae805d9,0x291800f3,0x248c00c7}},	//   _deir_, _ورتي_, rlsa_, _ñemi_, 
   {{0x63ac9e25,0x68fc011c,0x973003e6,0x00000000}},	//   vvan, snsd, ێکیا, --, 
   {{0x0904301d,0x386001ab,0x75881b0a,0x987c0205}},	//   _очим, _feir_, мств_, açık_, 
   {{0x63adf7d2,0x7e605f79,0xb90400fd,0x659401b9}},	//   tvan, zanp, _үзәк, маҳу, 
   {{0x63adf7d3,0x32180432,0x33380254,0x7e61f7d4}},	// [39390] uvan, _ayry_, _birx_, yanp, 
   {{0x63acb180,0x63a80118,0x00000000,0x00000000}},	//   rvan, _šens, --, --, 
   {{0x63adf7d5,0x7e61f7d6,0x38600493,0x2900010f}},	//   svan, vanp, _yeir_, _ĉiaj_, 
   {{0x63ac0196,0x32180142,0x7e61f7d7,0xe2c80451}},	//   pvan, _dyry_, wanp, _کوسو_, 
   {{0x7e61f7d8,0x1fb80121,0x00000000,0x00000000}},	//   tanp, ялды_, --, --, 
   {{0x691d04dd,0xdb1001d3,0x741400e5,0x00000000}},	//   déem, égün, _شوّا, --, 
   {{0x7e61f7d9,0x316800f7,0x3d0813f7,0x236800df}},	//   ranp, _ошто_, ावले_, lsaj_, 
   {{0x50a023f6,0x7e61f7da,0xfbd80073,0x63a802d2}},	//   _مەمل, sanp, यनलम, _áens, 
   {{0x7e600986,0x3861f7db,0x7f580921,0x2369f7dc}},	//   panp, _reir_, _uwuq, nsaj_, 
   {{0x0c214d6d,0x7e600986,0x200005d1,0x1a64552d}},	//   ымын, qanp, şhis_, ریبی_, 
   {{0x38600649,0x46c00316,0x817c0092,0x00000000}},	//   _peir_, शानह, _ያውቃሉ_, --, 
   {{0x2368008f,0x00000000,0x00000000,0x00000000}},	//   ksaj_, --, --, --, 
   {{0x3861f7dd,0x7d19f7de,0x236801e4,0x1b48008e}},	//   _veir_, mlus, jsaj_, _эзли_, 
   {{0x38603d19,0x00000000,0x00000000,0x00000000}},	//   _weir_, --, --, --, 
   {{0x3861f7df,0x7d1816ca,0x00000000,0x00000000}},	//   _teir_, olus, --, --, 
   {{0x386000a3,0x00000000,0x00000000,0x00000000}},	//   _ueir_, --, --, --, 
   {{0x3219f7e0,0x7d1802f6,0xd734030d,0x00000000}},	// [393a0] _syry_, ilus, _пхоь, --, 
   {{0x7d19f7e1,0x321817ad,0x333806be,0x230800f1}},	//   hlus, _pyry_, _qirx_, وتلي_, 
   {{0x7d19f7e2,0x30800020,0x65c001ec,0x1048011c}},	//   klus, _የምግብ_, _кұра, пяли_, 
   {{0xa0a40220,0xfc243226,0x00000000,0x00000000}},	//   кшіл, _مح_, --, --, 
   {{0x7d1800af,0x00000000,0x00000000,0x00000000}},	//   dlus, --, --, --, 
   {{0x6e94d77e,0x7d19f7e3,0x321801f4,0x00000000}},	//   тику, elus, _tyry_, --, 
   {{0x7d19f7e4,0x1ea84c1c,0x509400f3,0x00000000}},	//   flus, باني_, _прађ, --, 
   {{0x7d19f7e5,0x61e000af,0xbc6412b7,0xfc3c00d0}},	//   glus, _ülla, ىمىن_, žín_, 
   {{0xc0e1f7e6,0x8e380472,0x20000790,0x00000000}},	//   _сотк, _فسار_, şhir_, --, 
   {{0x7d19f7e7,0x00000000,0x00000000,0x00000000}},	//   alus, --, --, --, 
   {{0x7d19f7e8,0x00000000,0x00000000,0x00000000}},	//   blus, --, --, --, 
   {{0x66080ab7,0x67d4009b,0x9ba000f7,0xaf540023}},	//   şekk, вому, _چەيى, _ዝተሰለ, 
   {{0xc7340116,0xc7b80108,0x16140037,0x00000000}},	//   нҗиш_, чён_, _दुबर_, --, 
   {{0xf98c429e,0x00000000,0x00000000,0x00000000}},	//   جبی_, --, --, --, 
   {{0xb59400c7,0xf98c009a,0x00000000,0x00000000}},	//   лирш, _هبي_, --, --, 
   {{0xf484a6e6,0x00000000,0x00000000,0x00000000}},	//   луун, --, --, --, 
   {{0x4ca8009e,0x69dc4606,0xb6c40137,0x23680115}},	// [393b0] কাপু, øref, төөд, usaj_, 
   {{0x236800c8,0x7d180205,0xa1580f06,0x00000000}},	//   rsaj_, zlus, дажу_, --, 
   {{0x7d180368,0x4db003d4,0x23682bcc,0x00000000}},	//   ylus, জহুৱ, ssaj_, --, 
   {{0xf1a400fd,0x23680115,0x7d1801e3,0x00000000}},	//   ырун, psaj_, xlus, --, 
   {{0x7d181adc,0x00000000,0x00000000,0x00000000}},	//   vlus, --, --, --, 
   {{0xd00c67b3,0x691c002e,0xfe708c7e,0xc2e401d5}},	//   غلو_, féek, ادش_, _чўми, 
   {{0x7d18033d,0x8234c284,0x611400d1,0xddc0005f}},	//   tlus, _سرسا, _адву, _ielū, 
   {{0x7d19f7e9,0xf1b800c7,0x313400f0,0x00000000}},	//   ulus, _áġa_, _беср, --, 
   {{0x248c00c7,0x3cfc014f,0x00000000,0x00000000}},	//   _ñemu_, rnuv_, --, --, 
   {{0x7d19f7ea,0x9f4800d8,0x00000000,0x00000000}},	//   slus, çaõ_, --, --, 
   {{0x7d19f7eb,0x00000000,0x00000000,0x00000000}},	//   plus, --, --, --, 
   {{0x7d180309,0x00000000,0x00000000,0x00000000}},	//   qlus, --, --, --, 
   {{0x629419d6,0x8ba40032,0x657802b1,0xb7c00eac}},	//   _obzo, _аҙыҡ_, _āwha, উন্ট, 
   {{0x07a0041b,0xc0e80023,0xddc03e9d,0x00000000}},	//   јарн, _ቆሎሴ_, _nelū, --, 
   {{0xc44c01f2,0x758438be,0x994801a9,0x00000000}},	//   _ụgụr, ыңна, _ўпиб_, --, 
   {{0x6295f7ec,0x00000000,0x00000000,0x00000000}},	//   _abzo, --, --, --, 
   {{0xd70803b7,0x1cb40327,0x68a800f1,0x503c0092}},	// [393c0] _оние_, _ཝོན_, _سايټ_, ክትሪሽ, 
   {{0x69dc383d,0x00000000,0x00000000,0x00000000}},	//   øreg, --, --, --, 
   {{0x629402c4,0xcb100bd9,0xbb340724,0xd18400c0}},	//   _dbzo, סלב_, şäwç, тлей, 
   {{0x3d08033f,0x00000000,0x00000000,0x00000000}},	//   हकों_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc7d4025f,0xddc000c0,0xd9e0098b,0x00000000}},	//   כוני_, _gelū, खनात_, --, 
   {{0x7d040024,0xe7a809ab,0x00000000,0x00000000}},	//   kūrę, _चैनप, --, --, 
   {{0xfd0cbd0e,0x13d40c58,0x32080408,0x00000000}},	//   يجي_, _সেয়, ăхăн_, --, 
   {{0x7d040024,0x00000000,0x00000000,0x00000000}},	//   dūrę, --, --, --, 
   {{0x691c00e8,0x00000000,0x00000000,0x00000000}},	//   péek, --, --, --, 
   {{0xfbcd6e84,0xc27804ae,0xbe3000cf,0x98b00055}},	//   متی_, וריי, _نىكب, _siyā_, 
   {{0xcd3469bb,0x6c54010b,0x8154008f,0xea000208}},	//   _شراب, _ёклу, כסטע_, _ngấy_, 
   {{0x390801c0,0xaa9422cb,0xb9245fd0,0x00000000}},	//   тээн_, _билч, рфэй, --, 
   {{0xb7140108,0x00000000,0x00000000,0x00000000}},	//   идящ, --, --, --, 
   {{0x69dc1600,0x6b800083,0xc9840108,0x00000000}},	//   øred, lumg, _рули, --, 
   {{0xba340375,0xee240154,0xb88407d5,0x20800092}},	//   _בטוח_, _পলাশ_, _куьй, _ከሌሎቹ_, 
   {{0x45a00075,0x6304036b,0x6b8006ea,0x00000000}},	// [393d0] _ھەرك, هورل, numg, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x91c01fc7,0xddc000ef,0xbb1801ec,0x00000000}},	//   бәтл, _velū, _ﺴﻭﻯ_, --, 
   {{0xc0a811c7,0x6b800dca,0x210d1487,0xf9900a1e}},	//   بائل_, kumg, िकेश_, ירע_, 
   {{0x4d440220,0x6b8001d5,0x00000000,0x00000000}},	//   қпын_, jumg, --, --, 
   {{0x41756cd6,0x644df7ed,0x9ec400c7,0x00000000}},	//   _لارس, lcai, ыӡбе, --, 
   {{0xfc3c0232,0x6284014f,0x644c1554,0xdb080022}},	//   žím_, mgho, ocai, uveí, 
   {{0x6285f7ee,0x6b801427,0xca4802dd,0x00000000}},	//   lgho, fumg, _ﺁﺨﺭ_, --, 
   {{0x6b80401f,0x644d22a0,0x691c002e,0x00000000}},	//   gumg, icai, léew, --, 
   {{0xfeb8215c,0x6285f7ef,0x9f340046,0x644df7f0}},	//   _تارت_, ngho, _сезі, hcai, 
   {{0x5dd419db,0x644c0369,0x62849b61,0x5d54a4c9}},	//   _حقائ, kcai, igho, _скет, 
   {{0x83e8002e,0x6284014f,0x7c840120,0xd7e818c7}},	//   ccёg, hgho, _јуже, емме_, 
   {{0x6285f7f1,0x644c0007,0xad240131,0x00000000}},	//   kgho, dcai, _ئىنى, --, 
   {{0x99d4117d,0x62840477,0x53a40116,0x00000000}},	//   _متبا, jgho, һабб, --, 
   {{0x5eac2baf,0x6284b01d,0x59740166,0x00000000}},	//   চাপে, dgho, _сылу, --, 
   {{0x69dc003b,0x6e3c02d2,0x00000000,0x00000000}},	//   øree, _úrbe, --, --, 
   {{0x14259bf3,0xa7a800fb,0x94241f39,0x00000000}},	// [393e0] удам, _айыҡ_, умае, --, 
   {{0x644c4695,0x794002d3,0x00000000,0x00000000}},	//   acai, _ኩነታት, --, --, 
   {{0x394c00a8,0x35c40364,0x765c01e3,0x644c01ab}},	//   _însă_, _танҳ, mbry, bcai, 
   {{0x644df7f2,0xef5402d3,0x62840076,0x6b80022e}},	//   ccai, _ዝተወል, agho, yumg, 
   {{0xe70803e6,0x6284c6a3,0x7ae002d0,0xc0e40014}},	//   _ستین_, bgho, _olnt, ھکہٕ_, 
   {{0x765df7f3,0x804400f7,0x00000000,0x00000000}},	//   nbry, _ۅركۅ, --, --, 
   {{0x6b8001f0,0xc30401f4,0xfe6c00e5,0x00000000}},	//   wumg, _серж_, ںگے_, --, 
   {{0xc0e00cc9,0xab7589f2,0x2ba8000d,0x3a7000fb}},	//   _лоск, агиш, _कनदा, ҡлыр, 
   {{0xfe6c192c,0x7ae001e0,0x1614ccc0,0x9c7c003a}},	//   زگە_, _blnt, _दुसर_, phōn, 
   {{0x8aa405c2,0x6b81f7f4,0x644c0007,0x6a14014b}},	//   урид, rumg, zcai, импу, 
   {{0xc278008f,0x644c0076,0x6b80002f,0x00000000}},	//   ערטי, ycai, sumg, --, 
   {{0x8c440861,0x644c0399,0x6d58be7a,0x62840165}},	//   _седе, xcai, mpva, zgho, 
   {{0x69dc1455,0x6d580b4f,0x765c005c,0x00000000}},	//   øreb, lpva, fbry, --, 
   {{0x765c007c,0x00000000,0x00000000,0x00000000}},	//   gbry, --, --, --, 
   {{0x644c1028,0x6284047e,0x00000000,0x00000000}},	//   tcai, vgho, --, --, 
   {{0x644ca0a9,0xe7b801af,0xa7b800d8,0x18180133}},	//   ucai, _агиш_, _алиу_, عرێک_, 
   {{0x644c148c,0x29080ba7,0x6284014f,0xa2f40006}},	// [393f0] rcai, _ijaa_, tgho, апач, 
   {{0x644df7f5,0x29080158,0x941006be,0x00000000}},	//   scai, _hjaa_, neyə_, --, 
   {{0x6285f7f6,0xf0e80131,0x61140212,0x26c001f4}},	//   rgho, گىنى_, аджу, _inho_, 
   {{0xd5ac0d62,0x644c0369,0x6284014f,0x00000000}},	//   _تہِ_, qcai, sgho, --, 
   {{0xf0e8345f,0x6d580549,0xfc3c0306,0x62840455}},	//   دىنى_, epva, žík_, pgho, 
   {{0x6e2403f9,0x8234446a,0x6284a306,0xd3440244}},	//   ƙibl, _مرزا, qgho, _ئیله_, 
   {{0x249805b1,0x2908299d,0x90640228,0x00000000}},	//   _kbsm_, _ojaa_, انۇۇ, --, 
   {{0x29080451,0x1c45f7f7,0x7ae001ab,0xf37c0023}},	//   _njaa_, шним, _slnt, _ክርእዮ_, 
   {{0x0b4046fd,0x1a640517,0x5eac00cc,0x765c0142}},	//   онын, لیشی_, চাবে, ybry, 
   {{0x2909f7f8,0x80c001f9,0x00000000,0x00000000}},	//   _ajaa_, ळावे, --, --, 
   {{0x7ce40165,0x765c1347,0x00000000,0x00000000}},	//   _añre, vbry, --, --, 
   {{0x3c440491,0x26c0022e,0x691c0098,0xf8c80118}},	//   _إضاف, _anho_, kéeu, kléř_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xaa8800c6,0x4b78008f,0x212c0731,0x691c003e}},	//   _منهم_, _יאנו, _lheh_, déeu, 
   {{0x765d5b77,0x7bd80429,0xd4680120,0x8af8011a}},	//   rbry, lyuu, киве_, _שהצי, 
   {{0x26c0013f,0x765ce461,0x7804010b,0x7bd80083}},	//   _enho_, sbry, _гүма, oyuu, 
  
   {{0x3945f7f9,0x7bd93190,0xe5740107,0xd264117e}},	// [39400] _huns_, nyuu, _қҷт_, икай, 
   {{0x3945f7fa,0x3941f7fb,0x7bd8037e,0x00000000}},	//   _kuns_, _hiis_, iyuu, --, 
   {{0x50647617,0x867800c8,0xc6900302,0x3941f7fc}},	//   атла, _בריו, _ואת_, _kiis_, 
   {{0x7764004b,0x212df7fd,0x394404cc,0x7bd96f77}},	//   _kwix, _cheh_, _muns_, kyuu, 
   {{0x39440f71,0x212df7fe,0x39406ed1,0x80a1f7ff}},	//   _luns_, _dheh_, _miis_, زمون, 
   {{0x394110d0,0x00000000,0x00000000,0x00000000}},	//   _liis_, --, --, --, 
   {{0x3945f800,0xbd640c9e,0x4ca800fe,0x10a401f4}},	//   _nuns_, арые_, কাসু, _кивн, 
   {{0x3941f801,0x682801d5,0x7a2c00e5,0x00000000}},	//   _niis_, sоdi, zóté, --, 
   {{0x6d5802b9,0x9c7c003e,0x80780375,0x394400ef}},	//   spva, chōm, _שנמצ, _auns_, 
   {{0x39440c86,0x1ea88958,0x290805ac,0x6d580254}},	//   _buns_, _مامي_, _sjaa_, ppva, 
   {{0x77640054,0x6f19f802,0x3944056a,0xbf11f803}},	//   _awix, movc, _cuns_, _بولب, 
   {{0x7c81f804,0x6d49f805,0x6f19f806,0x3945f807}},	//   _душе, _iuda, lovc, _duns_, 
   {{0x6d49f808,0x3941f809,0xa91c00d7,0x00000000}},	//   _huda, _diis_, guľa, --, 
   {{0x6d49f80a,0xad2404a9,0x6f18bc66,0x3945f80b}},	//   _kuda, _ئىچى, novc, _funs_, 
   {{0x39449fc4,0x3940002d,0x2610121d,0x6d48f6ad}},	//   _guns_, _fiis_, _दुखी_, _juda, 
   {{0x6d49f80c,0x6f19f80d,0x3940002e,0x2a6c0219}},	//   _muda, hovc, _giis_, ladb_, 
   {{0x6d49f80e,0x0268034b,0x478400db,0x00000000}},	// [39410] _luda, вшей_, _тыйб, --, 
   {{0x2919f80f,0x212df810,0x6d488010,0x2a6c00a3}},	//   losa_, _sheh_, _ouda, nadb_, 
   {{0x6f18f61c,0x80c805d7,0x80c00490,0xe5b400fd}},	//   dovc, _सचदे, ळाले, _уйны, 
   {{0x68fdf811,0x2ca40b21,0x7bd8427c,0x39400067}},	//   nisd, jemd_, yyuu, _xiis_, 
   {{0x6d49f812,0x29180395,0x24881c06,0x2ca401f5}},	//   _auda, iosa_, mgam_, demd_, 
   {{0x6d49f813,0x2489f814,0xef184077,0x2919f815}},	//   _buda, lgam_, амі_, hosa_, 
   {{0x2919f816,0x6d49f817,0x212c06a3,0x68fc022c}},	//   kosa_, _cuda, _theh_, kisd, 
   {{0x6d49f818,0x2919f819,0x2489a0fc,0x3944771c}},	//   _duda, josa_, ngam_, _runs_, 
   {{0x2919f81a,0x68fdf81b,0x3941f81c,0x6d4999ca}},	//   dosa_, disd, _riis_, _euda, 
   {{0x39409469,0x7bd80d04,0x6d49f81d,0x6564003e}},	//   _siis_, ryuu, _fuda, _owhh, 
   {{0x6d49f81e,0x1869f81f,0x13c0045e,0x2919f820}},	//   _guda, лани_, োনয়, fosa_, 
   {{0x291800aa,0xcd940302,0x394401b8,0x7bd8020c}},	//   gosa_, _לדעת_, _vuns_, pyuu, 
   {{0x3941f821,0x00000000,0x00000000,0x00000000}},	//   _viis_, --, --, --, 
   {{0x7c281326,0x6d49f822,0x39400a85,0x39443c9e}},	//   _izgr, _yuda, _wiis_, _tuns_, 
   {{0x2919f823,0x3941f824,0x44284fa5,0xe9a8143e}},	//   bosa_, _tiis_, _azc_, _ندين_, 
   {{0x3f9c0069,0x6f180306,0x7d080af9,0x3940003a}},	//   _opuu_, zovc, _jjgs, _uiis_, 
   {{0x77640784,0x130801c6,0x4428013a,0x6f1800d7}},	// [39420] _uwix, гнай_, _czc_, yovc, 
   {{0x16a8b2f3,0xe6180107,0x9f540ca8,0x00000000}},	//   _свои_, удӣ_, _ègùn_, --, 
   {{0xd0447d09,0x691ddbd5,0x9044007b,0x6f1800d0}},	//   مپاي, cées, مناه, vovc, 
   {{0x4fe9f825,0xcac400eb,0x00000000,0x00000000}},	//   лмен_, এসএফ, --, --, 
   {{0x6d49f826,0x6f19f827,0x752401f7,0x8888008f}},	//   _suda, tovc, mliz, טרײַ, 
   {{0xfe6c04a9,0x6d49f828,0x291804d4,0x00000000}},	//   ىدى_, _puda, zosa_, --, 
   {{0xfe6df829,0x6f19f82a,0x2919f82b,0xdb180221}},	//   ردو_, rovc, yosa_, _erwë, 
   {{0x6f180978,0x752426e3,0x6d480564,0x29180005}},	//   sovc, nliz, _vuda, xosa_, 
   {{0x2919f82c,0x6d480117,0x6f1832fe,0x2ca40b4f}},	//   vosa_, _wuda, povc, remd_, 
   {{0x6d49f82d,0x7524016c,0x2ca5f82e,0x2b9001c3}},	//   _tuda, hliz, semd_, ràc_, 
   {{0x29181aac,0x68fdf82f,0x2a6c0219,0xbea0030d}},	//   tosa_, tisd, radb_, _хахк, 
   {{0x7aec35fb,0x9f5800e4,0x2a6c01ab,0xcb6801f0}},	//   èctr, _ãsã_, sadb_, _баде_, 
   {{0x7525f830,0x9410016b,0x68fdf831,0xa924004e}},	//   dliz, reyɛ_, risd, йдүл, 
   {{0x2919f832,0x6f0407dd,0x68fdf833,0x76480024}},	//   sosa_, éich, sisd, ždyn, 
   {{0x2919f834,0xec1400aa,0x161400af,0x00000000}},	//   posa_, _اوږد, _दुआर_, --, 
   {{0x291819a2,0x2489f835,0x442801a4,0x61e0000d}},	//   qosa_, ugam_, _pzc_, _ülli, 
   {{0x2489f836,0x69dc0036,0x00000000,0x00000000}},	// [39430] rgam_, äref, --, --, 
   {{0x7525f837,0x9f940724,0xdb090bce,0x33740276}},	//   aliz, lüçe_, rveç, ягур, 
   {{0x7525f838,0xf48465dc,0x00000000,0x00000000}},	//   bliz, _کاپی, --, --, 
   {{0x7525f839,0x00000000,0x00000000,0x00000000}},	//   cliz, --, --, --, 
   {{0x8c40002f,0x9fc814b3,0x33840117,0x00000000}},	//   äßli, ргла_, _нурв, --, 
   {{0x53a00137,0x41e400c0,0x00000000,0x00000000}},	//   _تۅكك, _ліба, --, --, 
   {{0xc058005e,0x63bc020b,0xad580c98,0xdbd000fd}},	//   _біз_, _hrsn, брых_, _küçm, 
   {{0x691c0036,0x00000000,0x00000000,0x00000000}},	//   zéer, --, --, --, 
   {{0x69dc3570,0x2d980221,0xa91c0030,0x9b440691}},	//   øren, _ären_, tuľn, غندو, 
   {{0x0b1400c6,0x8b30143e,0xaa740092,0x9e34030d}},	//   يقية_, وفيش, _ለአረጋ, _дезч, 
   {{0x3ea4f449,0x75240034,0x6b80002d,0x691c0036}},	//   ment_, yliz, armg, véer, 
   {{0x1dbc000d,0x9f94013d,0x8de801af,0x00000000}},	//   ्मठत, güçe_, _тыуғ_, --, 
   {{0x7d1807d5,0x7c29c3c0,0x691c0036,0x75240165}},	//   mous, _uzgr, téer, vliz, 
   {{0x7d181bb3,0xd70402bf,0x61300267,0xa91c00d0}},	//   lous, ізви, låld, buľo, 
   {{0x3ea5f83a,0x63bcad03,0xdb08023a,0x7524004b}},	//   ient_, _arsn, rveä, tliz, 
   {{0x3ea5f83b,0x7d19f83c,0x75240451,0xd7c805af}},	//   hent_, nous, uliz, _نوبه_, 
   {{0x3ea5f83d,0x7525f83e,0xeb3401d9,0x8c34010f}},	// [39440] kent_, rliz, _بى۪د, ַטעס_, 
   {{0x7d19f83f,0x7524dd69,0x63bc2753,0x42c400cf}},	//   hous, sliz, _drsn, огун_, 
   {{0x7525f840,0x7d19f841,0xfbcc02f5,0x59c9f842}},	//   pliz, kous, িনিত, िमिर, 
   {{0x4fc42ecc,0x7d19f843,0x3ea40363,0xdbd00139}},	//   жска, jous, eent_, _küäm, 
   {{0x65780325,0x3ea5f844,0x7d19f845,0xdb180036}},	//   _āwhi, fent_, dous, _erwé, 
   {{0x1c1c033d,0x59c83599,0x7d180857,0x81c400ef}},	//   _पड़ल_, िमार, eous, _spēš, 
   {{0xf985014d,0xe8000034,0x7d180036,0x0dc82c31}},	//   _تب_, _लेना_, fous, рули_, 
   {{0x7d19f846,0x00000000,0x00000000,0x00000000}},	//   gous, --, --, --, 
   {{0x3ea5f847,0xcb08141c,0xe7a80034,0x0ba40212}},	//   bent_, иход_, _चैंप, ішим, 
   {{0x3ea5f848,0x69dc08cb,0xa91c00d7,0x00000000}},	//   cent_, øreo, tuľo, --, 
   {{0x7d19f849,0xe0d0004b,0x68fc00cf,0xfcd000ec}},	//   bous, _غزې_, èrdo, _ڪينج, 
   {{0x7d19f84a,0x00000000,0x00000000,0x00000000}},	//   cous, --, --, --, 
   {{0x9f940724,0x5eac015b,0xe94450f0,0xbb141884}},	//   rüçe_, চারে, _کرتی, ﺳﺘﻪ_, 
   {{0x61315b21,0xeaa000b8,0x00000000,0x00000000}},	//   måle, _koṭy_, --, --, 
   {{0xfc3c0316,0x6aa8127b,0x00000000,0x00000000}},	//   žít_, medf, --, --, 
   {{0x3ea5f84b,0x63bc5653,0xddc0cd97,0x25a00fac}},	//   zent_, _prsn, _jelš, _vphl_, 
   {{0x3ea5f84c,0x00000000,0x00000000,0x00000000}},	// [39450] yent_, --, --, --, 
   {{0x7d19f84d,0x63bc1505,0x3ea5f84e,0x6aa83978}},	//   zous, _vrsn, xent_, nedf, 
   {{0x3ea47d6a,0x7d18037e,0x407400d1,0x613001e3}},	//   vent_, yous, قلاڭ_, håle, 
   {{0x3ea5f84f,0x7d180005,0x63bc0010,0x6aa803ac}},	//   went_, xous, _trsn, hedf, 
   {{0x6131f850,0x98c40552,0x8ccc0034,0x7d19f851}},	//   jåle, šući_, थानो, vous, 
   {{0xdb080ea0,0x3ea40129,0x7d18f74e,0x00000000}},	//   rweë, uent_, wous, --, 
   {{0x3ea5c682,0x69dc17c1,0x5eac009e,0x5de406a6}},	//   rent_, ørel, চালে, яжка, 
   {{0x63adf852,0xddc000e2,0x00000000,0x00000000}},	//   owan, _celš, --, --, 
   {{0xff503fe2,0x92ac0c58,0xddc0012c,0xfe1801ad}},	//   _آخر_, কাৰ_, _delš, _पुरस_, 
   {{0x7d19f853,0x613001e6,0x63adf854,0x6aa8ce5d}},	//   sous, såld, iwan, gedf, 
   {{0x63adf855,0x9b4400f2,0x00000000,0x00000000}},	//   hwan, _کنتو, --, --, 
   {{0x394401e6,0xae053b7b,0xaa440092,0x380401f0}},	//   öms_, _تومى, _ከአምላ, домҳ, 
   {{0x63adf856,0x6aa80ffb,0xda643a47,0x6ab803b2}},	//   jwan, bedf, _евли, ðafý, 
   {{0xcc38010f,0x6aa80857,0xe9a87611,0x501800d9}},	//   _פעסט, cedf, حدین_, מורו, 
   {{0x1dbd2433,0xd629f857,0x63adf858,0x00000000}},	//   ्मित, сове_, ewan, --, 
   {{0x63ac13c4,0x95740124,0x69dc0108,0xf4840633}},	//   fwan, _ҭынч, äree, باسی, 
   {{0x63adf859,0xdb0803b2,0x5778007b,0x00000000}},	// [39460] gwan, _ínól, _اصبح_, --, 
   {{0x1dbc0a28,0x00000000,0x00000000,0x00000000}},	//   ्मात, --, --, --, 
   {{0x7f59f85a,0x2928006a,0x63adf85b,0x2454063f}},	//   _atuq, _âtaâ_, awan, _ụme_, 
   {{0x63adf85c,0x6aa89108,0x00000000,0x00000000}},	//   bwan, zedf, --, --, 
   {{0x63adeac1,0x8f98010b,0x00000000,0x00000000}},	//   cwan, съет_, --, --, 
   {{0x7f800ae5,0xddc00010,0xe1f001ed,0xb4bc012c}},	//   رلىن, _selš, ءسے_, _आफु_, 
   {{0x6aa80627,0xddc00171,0x3da004b4,0x00000000}},	//   vedf, _pelš, ерыб, --, 
   {{0xe05475ab,0x0ca853ef,0x2d980221,0x69dc0a64}},	//   _قیمت_, стки_, _ärem_, ørem, 
   {{0x3f6406bb,0xddc1089a,0x4fe9f85d,0xdd1000ee}},	//   _нито_, _velš, _уман_, _müňl, 
   {{0x6130708a,0xddc80356,0xfbcc00e5,0x7c2c0139}},	//   råle, _înşa, چتی_, _şirä, 
   {{0xfbcdf85e,0x6aa8127b,0xddc02e03,0x442401fb}},	//   نتی_, redf, _telš, ́n_, 
   {{0x63adf85f,0x6130143a,0x6aa93b1d,0x00000000}},	//   ywan, påle, sedf, --, 
   {{0x69dc0724,0x63ac43cc,0x6aa802d0,0x8ae40153}},	//   äreb, xwan, pedf, _нікл, 
   {{0x63adf860,0x657401d3,0x00000000,0x00000000}},	//   vwan, tszh, --, --, 
   {{0x63acf0b0,0xa2ac08df,0x00000000,0x00000000}},	//   wwan, ीयस्, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x68edf861,0x63ac0810,0xdd1000a2,0xa2b5f862}},	// [39470] _ilad, uwan, _düňl, мбач, 
   {{0x63adf863,0x85440209,0x466001ec,0xa2cc00cd}},	//   rwan, _нэме, _سۇرق, साध्, 
   {{0x68edf864,0x63adf865,0xe8001d15,0x00000000}},	//   _klad, swan, _लेता_, --, 
   {{0xf1c001dc,0x9f2004a9,0x68ec0066,0x2eec0789}},	//   ương_, چۈرۈ, _jlad, _aldf_, 
   {{0x68ec00d0,0x63adf866,0xa2cc00cd,0x00000000}},	//   _mlad, qwan, साद्, --, 
   {{0x68edf867,0xe2c9f868,0x70940116,0xbe88010b}},	//   _llad, _بوسو_, _җафф, ссде_, 
   {{0x68edf869,0xdd9001ed,0xad2412ea,0xcd2800d1}},	//   _olad, ڑوں_, کروو, ﺷﻨﯩﯔ_, 
   {{0x7f580a73,0xa0c400f1,0x68ec0241,0xdd9000e5}},	//   _ttuq, _تيرو, _nlad, ّوں_, 
   {{0x1dbc02ab,0x7f59f86a,0x7e440353,0x00000000}},	//   ्महत, _utuq, _ехее, --, 
   {{0x68edf86b,0xa91c01f1,0x98b005d1,0x00000000}},	//   _alad, buľk, _ıcın_, --, 
   {{0xa91c00d7,0x00000000,0x00000000,0x00000000}},	//   cuľk, --, --, --, 
   {{0x68edf86c,0x310000dc,0x00000000,0x00000000}},	//   _clad, लोपः_, --, --, 
   {{0x68ed5bef,0x9aa40014,0xe99401b9,0x00000000}},	//   _dlad, _ہێکے_, وهیگ, --, 
   {{0x68edf86d,0x1a6401b9,0x69dc0036,0xe6d4009d}},	//   _elad, _تیدی_, ärec, нцсэ, 
   {{0xceb10b71,0x68edf86e,0x7de0002e,0x00000000}},	//   כים_, _flad, _gёst, --, 
   {{0x60c8b9b9,0x00000000,0x00000000,0x00000000}},	//   _nnem, --, --, --, 
   {{0xca280150,0xeaf80244,0xa91c0419,0x00000000}},	// [39480] _ﺣﺎﺕ_, _برۆت_, zuľk, --, 
   {{0x68edf86f,0x91e400d8,0x38c80248,0x00000000}},	//   _zlad, мозе, bìrà_, --, 
   {{0x10483f36,0x68ec01b9,0x91a8007b,0x00000000}},	//   ояли_, _ylad, تهاك_, --, 
   {{0x2d9800e2,0xc0c424cd,0x705400f2,0x00000000}},	//   _īre_, душе_, رنتا, --, 
   {{0x60c80036,0xb63802dd,0xe19401c4,0x00000000}},	//   _dnem, _ﺘﻌ_, _үрсэ, --, 
   {{0x9344160b,0x60c9f870,0x69dc2ab7,0x59dc078a}},	//   _інве, _enem, ørek, महार, 
   {{0x1ea80597,0x00000000,0x00000000,0x00000000}},	//   ثاني_, --, --, --, 
   {{0x2d8001f1,0x00000000,0x00000000,0x00000000}},	//   čie_, --, --, --, 
   {{0xb4bc012c,0xbec002b5,0x6f040332,0x6fdc00cc}},	//   _आफै_, āūra, éics, _মেৰে, 
   {{0x68ec3831,0x613145fb,0x60c802fb,0xa91c00d7}},	//   _slad, måla, _znem, puľk, 
   {{0x68edf871,0xe8940006,0x20180162,0x00000000}},	//   _plad, нань, _øsir_, --, 
   {{0x8b641e4a,0x6e28022e,0x68ec03e3,0xbac000d1}},	//   _قاتم, _iydb, _qlad, _ﺩﯦﺘﺎ, 
   {{0xebc4008e,0x613001e3,0xfbcc0244,0x00000000}},	//   _чәйн, nåla, _نتو_, --, 
   {{0x68edf872,0x6d5c0200,0xf98df873,0x00000000}},	//   _wlad, _çras, دبی_, --, 
   {{0x68ec014c,0xb604cadc,0xf6280212,0xfaa0041b}},	//   _tlad, вятк, діти_, _рајо, 
   {{0x68edf874,0x390400c7,0x613001e3,0xf48400db}},	//   _ulad, _аџьб, kåla, куун, 
   {{0x6e281088,0xead003d4,0x6ab805c7,0x2c200183}},	// [39490] _lydb, িসীম, _kavf, মেৰে_, 
   {{0xf7700075,0x60c9f875,0x6e2803ac,0xdc100213}},	//   _ئاي_, _snem, _oydb, _ləğv, 
   {{0x305c02e3,0x69dc0158,0x00000000,0x00000000}},	//   _ịlụ_, øreh, --, --, 
   {{0x6ab8072b,0x00000000,0x00000000,0x00000000}},	//   _lavf, --, --, --, 
   {{0x60c85a54,0x443c0327,0xbb1801ec,0x00000000}},	//   _vnem, _àu_, _ﺴﻭﻑ_, --, 
   {{0x6ab80175,0x6d5c0327,0x8f50179e,0x00000000}},	//   _navf, _ħrar, دنوش, --, 
   {{0x6e2803cb,0x4ad01df0,0x00000000,0x00000000}},	//   _cydb, तानव, --, --, 
   {{0x60c83917,0xeb4c001f,0xdd9400ee,0xa2cc23e9}},	//   _unem, _አነጋገ, _җады, साव्, 
   {{0x6e2803b2,0xa0682e2d,0xdea02a77,0x3a24010b}},	//   _eydb, _маңа_, _میشی, _synp_, 
   {{0x30140276,0xbda4007b,0xb4bc2d81,0xed880166}},	//   _рдур, _يحاو, _आफ्_, чсәк_, 
   {{0x6e28015d,0xd9c81152,0x00000000,0x00000000}},	//   _gydb, िमेट, --, --, 
   {{0x69dc0108,0x00000000,0x00000000,0x00000000}},	//   ärea, --, --, --, 
   {{0x9f58014a,0x6b743a49,0xab640064,0x62940210}},	//   _äsä_, _алчу, _авіл, _oczo, 
   {{0x6ab805c7,0x273c0092,0x00000000,0x00000000}},	//   _gavf, _በቅርበ, --, --, 
   {{0x18a54671,0x245402e3,0x00000000,0x00000000}},	//   _займ, _ụma_, --, --, 
   {{0xdb18019f,0x00000000,0x00000000,0x00000000}},	//   _urwâ, --, --, --, 
   {{0x78a4bf65,0xccf000c8,0x00000000,0x00000000}},	// [394a0] _ibiv, אכן_, --, --, 
   {{0x6ab807d6,0x915c0051,0x00000000,0x00000000}},	//   _xavf, _hẳn_, --, --, 
   {{0xd011f876,0x00000000,0x00000000,0x00000000}},	//   گلش_, --, --, --, 
   {{0x6e29dd15,0x69dc03cd,0x73c401af,0xfafc00b8}},	//   _rydb, ørei, _иҡба, _śūla_, 
   {{0x78a5f877,0x6e28005c,0xe6300092,0x00000000}},	//   _mbiv, _sydb, _በትናን, --, 
   {{0x6130a0c5,0x8778010f,0x8ea00116,0x00000000}},	//   råla, לאני, الغۇ, --, 
   {{0xf9854cc3,0xc69000c8,0x78a40083,0xa2ccdb71}},	//   _حب_, טאג_, _obiv, सार्, 
   {{0xc19804ae,0x6ab805c7,0x613003cd,0x00000000}},	//   _משלי, _savf, påla, --, 
   {{0xf0780032,0x00000000,0x00000000,0x00000000}},	//   _ниңә_, --, --, --, 
   {{0x78a5f878,0x6e280af9,0xc984084c,0xc000329b}},	//   _abiv, _tydb, нуми, _спук, 
   {{0xfaa1f879,0x61140109,0x3d2801e2,0x00000000}},	//   ушын, ląla, _کتلی_, --, 
   {{0x3d881bf3,0x00000000,0x00000000,0x00000000}},	//   _رحمی_, --, --, --, 
   {{0xdc740588,0x6ab801a9,0xc7c80006,0x2d9c01d3}},	//   _рыхь, _tavf, чыне_, ltve_, 
   {{0x78a40a49,0x61300450,0x00000000,0x00000000}},	//   _ebiv, jåln, --, --, 
   {{0x2d9c01ed,0x6d5c06af,0x7ab8011a,0x1fac17ee}},	//   ntve_, _érad, _מצגו, _टन्ड, 
   {{0x61e40306,0x00000000,0x00000000,0x00000000}},	//   vyhl, --, --, --, 
   {{0x8d9402d3,0x1d940092,0xb4e800db,0x00000000}},	// [394b0] _ዘይብል_, ኙነቶች_, رىكم_, --, 
   {{0x78a439ca,0x46686d64,0x47d000ec,0x00000000}},	//   _zbiv, _эрим_, _ليڊر, --, 
   {{0x859c08b0,0x715802dd,0x31680798,0x2d9ce009}},	//   ﺍﻧﺪﺍ_, еріс_, ешчо_, jtve_, 
   {{0x62940034,0x7d04020c,0x5f74030f,0x59f8010f}},	//   _wczo, _mèrè, ناتر, וּנד, 
   {{0x7d0400f2,0x5ff40395,0xaca40240,0x00000000}},	//   _lèrè, ъзду, _ገቢሮም_, --, 
   {{0x6294012d,0x97380092,0x00000000,0x00000000}},	//   _uczo, _በቅድስ, --, --, 
   {{0xbe4800e5,0x00000000,0x00000000,0x00000000}},	//   _ہشام_, --, --, --, 
   {{0x4428036e,0xdb0c01e1,0x6dc40472,0x00000000}},	//   _kyc_, _ùkúr, ازول, --, 
   {{0x69dc1248,0xe8002983,0x0c7001d5,0x5e58022e}},	//   ären, _लेला_, شگند, _жизя_, 
   {{0x7d04020c,0xec1800aa,0x3f8c037e,0x99d400c6}},	//   _bèrè, رځنګ_, mugu_, نتجا, 
   {{0x3f8df87a,0xbb14005e,0x645c000f,0x2d9c0030}},	//   lugu_, ﺳﺘﻰ_, _ofsi, ctve_, 
   {{0x7d0404fb,0xa3d00316,0x38140133,0xdb080254}},	//   _dèrè, वमा_, ێژکر, lveü, 
   {{0x3f8df87b,0x442824b6,0x4ad80451,0x907800d9}},	//   nugu_, _nyc_, _ڪانھ_, וטרי, 
   {{0x645dcc21,0x7d040248,0x00000000,0x00000000}},	//   _afsi, _fèrè, --, --, 
   {{0x3f8d7221,0x645c08a5,0x00000000,0x00000000}},	//   hugu_, _bfsi, --, --, 
   {{0x3f8df87c,0x78a489f4,0x49700184,0xc4809088}},	//   kugu_, _ubiv, _өләс, илск, 
   {{0x44280ac5,0x3f8c0526,0xfb94037e,0x69dc2b96}},	// [394c0] _cyc_, jugu_, _jリ_, ørev, 
   {{0x3f8df87d,0x03a1f87e,0x9410013f,0x7c280254}},	//   dugu_, рифо, deyɔ_, _mygr, 
   {{0x63a8005f,0x7c29ed32,0x61300267,0x30a40092}},	//   _ģene, _lygr, råln, _ለምግብ_, 
   {{0x6ea4012c,0x00000000,0x00000000,0x00000000}},	//   च्नु, --, --, --, 
   {{0x7525f87f,0x613000cc,0x7c2801e3,0x691c0694}},	//   moiz, måll, _nygr, géey, 
   {{0xb8e4025c,0xd4983f1d,0x7d2001e2,0x00000000}},	//   _ཌལ_, _эрү_, یفون, --, 
   {{0x7c28035a,0xdce00166,0xb644037e,0x3f8c000d}},	//   _aygr, _aqlı, _ｎｙ_, augu_, 
   {{0x3f8df880,0x7c280b1a,0xc0e03de5,0x7524d8d4}},	//   bugu_, _bygr, _коск, noiz, 
   {{0x3f8df881,0xc0e00724,0xdfa400c6,0x3cd002dd}},	//   cugu_, _тотк, _محلي, ржыс, 
   {{0x61300628,0x28a40882,0x6ef401ab,0x7d0400f2}},	//   håll, ग्नि, _bàbe, _pèrè, 
   {{0x752401c6,0x7c28035a,0x765c0175,0xfb3001c6}},	//   koiz, _eygr, dcry, рнээ, 
   {{0x92ac00bd,0x7d040100,0x7524007f,0x4b500133}},	//   কায়_, _vèrè, joiz, _پێدر, 
   {{0x6d58074d,0x7c2805ac,0x6d5c004a,0x7524005a}},	//   lqva, _gygr, _érab, doiz, 
   {{0x6d415593,0x2d59f882,0x7d0432aa,0x65946ad8}},	//   lmma, _kée_, _tèrè, лагу, 
   {{0x6ea4081e,0x35e402d5,0x6ef5f883,0x6d580369}},	//   च्यु, ацтв, _kàbb, nqva, 
   {{0x7525f884,0x6d4037b6,0x3f8ca1d3,0x2d5801c7}},	//   goiz, nmma, yugu_, _mée_, 
   {{0x6d40049b,0x2d580429,0x6ef40de2,0x645c022e}},	// [394d0] imma, _lée_, _màbb, _vfsi, 
   {{0x7bdd8379,0x3f8c01c8,0x6ef40de2,0x00000000}},	//   _àque, vugu_, _làbb, --, 
   {{0x2d59f885,0x752401c4,0x00000000,0x00000000}},	//   _née_, boiz, --, --, 
   {{0x3f8df886,0x66000008,0x98b000b8,0x7524a29f}},	//   tugu_, úlku, _khyā_, coiz, 
   {{0x7084005e,0xf0e800d1,0x00000000,0x00000000}},	//   ргіз, خىنى_, --, --, 
   {{0x3f8db576,0x539806a9,0x2d590ec1,0x6d41f887}},	//   rugu_, _אישו, _bée_, emma, 
   {{0x3f8c04d8,0x6d580369,0x69dc1577,0x7c28010e}},	//   sugu_, gqva, ärel, _sygr, 
   {{0x2d59adfa,0x2499f888,0xca7802dd,0x00000000}},	//   _dée_, _jcsm_, _ﺤﺩﻭﺩ_, --, 
   {{0x1b49f889,0x3f8c0869,0x765c03ac,0x00000000}},	//   нзии_, qugu_, ycry, --, 
   {{0x6d41f88a,0x2d582d7d,0xa2c81d72,0x693401ed}},	//   amma, _fée_, _होम्, یکٹر, 
   {{0x7c28068f,0x6ef400e8,0x752401f7,0x62f40154}},	//   _wygr, _fàbb, yoiz, _আদায়_, 
   {{0x249801e4,0x7c281d8a,0x00000000,0x00000000}},	//   _ncsm_, _tygr, --, --, 
   {{0x7525f88b,0x1dbc07d0,0x07a1f88c,0x6130007c}},	//   voiz, ्मकत, баян, våll, 
   {{0x249802fa,0xd39400d1,0x2d580241,0x00000000}},	//   _acsm_, һәгә_, _yée_, --, 
   {{0x69ddf88d,0x7525f88e,0x765c0109,0x940c0213}},	//   øret, toiz, rcry, əfə_, 
   {{0xd3941945,0x765c062c,0xdb2401d3,0x00000000}},	//   ләгә_, scry, _جوڈی, --, 
   {{0x7525f88f,0x59400050,0x5bd011a6,0xe474009d}},	// [394e0] roiz, _پکھہ, _तपोव, русэ, 
   {{0x27ec00ed,0x77640014,0x00000000,0x00000000}},	//   øene_, _itix, --, --, 
   {{0x869805e1,0x6d40138f,0x03a0039b,0x752403d1}},	//   _אייז, ymma, _қиро, poiz, 
   {{0x6ae00316,0x50b8314e,0xcf981fbe,0x00000000}},	//   _पक्र, عداد_, ејк_, --, 
   {{0x6ef40de2,0xa4f801d9,0x3348010b,0x2d58002e}},	//   _ràbb, _شکٲر_, _аҗам_, _sée_, 
   {{0x2d800029,0x6ef400e8,0xe8d000dc,0x409000d1}},	//   ņiem_, _sàbb, _तच्च, арәт, 
   {{0x3861f890,0xc69002e4,0xd13000c6,0x6d40007f}},	//   _ofir_, צאה_, _همس_, tmma, 
   {{0x6d41f891,0x69dc4a42,0xc5f0011a,0x00000000}},	//   umma, ärem, מדו_, --, 
   {{0x4e9406d5,0x6fb802ab,0x2d5804e6,0x00000000}},	//   _مشار, _इनिं, _wée_, --, 
   {{0x2d5800e8,0x6f840228,0x3fe00120,0x6d40127b}},	//   _tée_, _مۇچۅ, _ужув, smma, 
   {{0x28f828af,0x6ef40694,0x8d6400f3,0x00000000}},	//   вень_, _tàbb, _свее, --, 
   {{0xecb801ad,0x00000000,0x00000000,0x00000000}},	//   _आसिफ, --, --, --, 
   {{0xead44587,0xa6c81f0d,0x00000000,0x00000000}},	//   _воль, پوزل_, --, --, 
   {{0x3861f892,0x69dc0a64,0xbb8000c6,0x3f98031c}},	//   _efir_, øres, _الوي, ħqux_, 
   {{0x776402c4,0xc984ab9e,0x7e54008d,0xe800007d}},	//   _etix, _сули, רסלב_, _लइका_, 
   {{0xdb18101c,0xdb080174,0x00000000,0x00000000}},	//   _erwä, lveð, --, --, 
   {{0x225805a2,0x00000000,0x00000000,0x00000000}},	// [394f0] визы_, --, --, --, 
   {{0xf744009b,0x00000000,0x00000000,0x00000000}},	//   _лењо, --, --, --, 
   {{0x386000fc,0xa2c80574,0x461005d9,0xa5f80276}},	//   _yfir_, _होण्, _چوڌر, _рену_, 
   {{0x65640857,0x00000000,0x00000000,0x00000000}},	//   _ithh, --, --, --, 
   {{0x69dc023a,0x60240120,0xb3640395,0x00000000}},	//   ärej, јдла, _гъск, --, 
   {{0x41747486,0x2369f893,0x2ff80276,0x6304ce83}},	//   _مارس, mpaj_, ынчь_, _ئوسل, 
   {{0x1dc41524,0x2369f894,0x383c037e,0x2a6c010a}},	//   विधत, lpaj_, _ｊgｇ_, dbdb_, 
   {{0xa2c80574,0xa2cc01bc,0x2368010f,0xb82003d4}},	//   _होत्, साक्, opaj_, নেটত_, 
   {{0x23680bf1,0xea000208,0x00000000,0x00000000}},	//   npaj_, _dzậy_, --, --, 
   {{0xb60802fb,0x9b05f895,0x9f3402dd,0xaed4009b}},	//   noší, рзод, _тезі, _лоуш, 
   {{0x18681ff0,0x19880395,0xd69c00d1,0x4aa40166}},	//   кани_, ъбни_, ﺍﺷﻼﺭ_, шкэн_, 
   {{0x6fdc00bd,0xdb08056a,0x6d5c003e,0x97c5f896}},	//   _মেয়ে, rveñ, _éraa, айме, 
   {{0x69dcfb11,0x656403ac,0x23680309,0x2d980221}},	//   ører, _athh, jpaj_, _ärer_, 
   {{0xddc000c0,0x00000000,0x00000000,0x00000000}},	//   _melž, --, --, --, 
   {{0x7ae006d5,0xd628682f,0x89d4a0c3,0xd93801b9}},	//   _iont, тове_, _نوور_, _ичиш_, 
   {{0x7ae1f897,0x649800d1,0x65540395,0x17c8014b}},	//   _hont, лтур_, сърф, _агии_, 
   {{0xdbd806ed,0x1305f898,0x6ef401c3,0xd7c807d6}},	// [39500] _açúc, азам, _làba, _شوده_, 
   {{0x7ae1f899,0x65840162,0xa2cc00cd,0x00000000}},	//   _jont, óthú, साग्, --, 
   {{0x6ef408c2,0xd4a401e0,0x98d82e05,0x00000000}},	//   _nàba, _кинй, _बचाए, --, 
   {{0x4fe8405a,0x10a4466e,0x0fc4010b,0xa0a401ec}},	//   кмен_, ридн, ийен, йшіл, 
   {{0x7ae1f89a,0xa2cc1a04,0xcd34129e,0xb5f401ec}},	//   _oont, साख्, یرعب, _түңі, 
   {{0x7ae1f89b,0x69dd487b,0xfe6c007b,0x630401e2}},	//   _nont, ärek, ودى_, _هوټل, 
   {{0x6ef401c3,0x91e40209,0x00000000,0x00000000}},	//   _càba, _тове, --, --, 
   {{0x7ae0387b,0xcd281046,0x00000000,0x00000000}},	//   _aont, خستن_, --, --, 
   {{0x7ae0c6ee,0x0a6801b9,0x23c815e0,0x3ea401d9}},	//   _bont, крни_, रियद, _چشمہ, 
   {{0x3584001f,0xe800033f,0x00000000,0x00000000}},	//   _ክፍተት_, _लेगा_, --, --, 
   {{0x7ae1f89c,0x6ef401e1,0xc2780a7c,0xdb080bcd}},	//   _dont, _gàba, כריי, rveð, 
   {{0x7ae00156,0x2369f89d,0x959002d3,0x644000df}},	//   _eont, ypaj_, ፍነትን_, _ŝlim, 
   {{0xe800b340,0xaa0000f1,0x00000000,0x00000000}},	//   _लेखा_, تېژي, --, --, 
   {{0x7ae1f89e,0x79780084,0xbb4147b0,0x7bdca37d}},	//   _gont, ṅwah, _дечк, _àqua, 
   {{0x236802d1,0xc9840114,0x00000000,0x00000000}},	//   wpaj_, _ђуки, --, --, 
   {{0x7ae001b3,0x7468036b,0x61300267,0x2368007c}},	//   _zont, ирув_, rålk, tpaj_, 
   {{0x2908bca1,0x7ae1f89f,0x33580276,0x442c005c}},	// [39510] _imaa_, _yont, иатэ_, æg_, 
   {{0x61303c12,0x2369f8a0,0x7ae1f8a1,0x024803e6}},	//   måli, rpaj_, _xont, نجاو_, 
   {{0x26c0d481,0x605400c6,0x315800c6,0x236803f0}},	//   _iaho_, مناط, لجنة_, spaj_, 
   {{0x26c00032,0x40840120,0x00000000,0x00000000}},	//   _haho_, ружб, --, --, 
   {{0x26c1f8a2,0x29080134,0x4da802d3,0x1fa80209}},	//   _kaho_, _mmaa_, _መርገጺ_, укли_, 
   {{0x26c1f8a3,0xaf0400d6,0x63bc02d0,0xdfd401ec}},	//   _jaho_, опіл, _issn, _қозы, 
   {{0x7ae1f8a4,0x2908049b,0xd3444667,0x1d0867f0}},	//   _ront, _omaa_, _ایله_, леки_, 
   {{0x6f0801e2,0x26c003a0,0xad2401c8,0x00000000}},	//   _emdc, _laho_, يريو, --, 
   {{0x6d5c0ffb,0xbe841ec7,0xc27001e1,0x5bd000cd}},	//   _éran, _نجاو, _ẹ̀sá, तमेव, 
   {{0x26c085ba,0x2909f8a5,0x7ae00978,0x3dac03d4}},	//   _naho_, _amaa_, _qont, কিবল, 
   {{0x7ae1f8a6,0x69dc0b34,0x00000000,0x00000000}},	//   _vont, ørep, --, --, 
   {{0x7ae1f8a7,0xa2c81f13,0xbab400cc,0xdbf0013a}},	//   _wont, _होस्, জাইছ, _hřív, 
   {{0x7ae1f8a8,0x26c1f8a9,0x915c0051,0x00000000}},	//   _tont, _baho_, _mắn_, --, 
   {{0x2908acd7,0x7bc801e4,0xc5b401c0,0xaa082418}},	//   _emaa_, _irgu, өрсө, ازیل_, 
   {{0x9985f8aa,0xd94498c1,0x212c4a16,0x26c1f8ab}},	//   _البو, _леки, _okeh_, _daho_, 
   {{0x39800e2d,0xa904007b,0x245c01e1,0x00000000}},	//   mıs_, _وبين, _rámó_, --, 
   {{0x26c006d6,0x0b60063f,0x044010a7,0x63bc8e7a}},	// [39520] _faho_, _kụọr, зетн, _cssn, 
   {{0x212c0502,0x7bc80e04,0x53a40166,0x95840117}},	//   _akeh_, _mrgu, _һамб, _ллое, 
   {{0x39400218,0x0b60063f,0x28a488f2,0x63bc76d4}},	//   _khis_, _mụọr, ग्वि, _essn, 
   {{0x53a411af,0x26c1f8ac,0x2bbd147c,0x69dc023a}},	//   _ламб, _zaho_, ्टमा, ärei, 
   {{0x26c05d12,0xd3d80014,0x398005d1,0x80a10404}},	//   _yaho_, _صبحا_, hıs_, سمون, 
   {{0x26c001c4,0xa4f01bc5,0x4ea401b9,0x43400314}},	//   _xaho_, _kışı_, ёрла, _неяв, 
   {{0xdbf0012c,0xbd64005b,0x00000000,0x00000000}},	//   _dřív, брые_, --, --, 
   {{0x7bc801a6,0x61e00de2,0x915c0208,0x4204010a}},	//   _brgu, _àlla, _gắn_, _унсо_, 
   {{0xac18b96f,0xa2cc1fbc,0xefb001d5,0x92d80011}},	//   ропу_, साच्, _آیتگ, ়সী_, 
   {{0x29081c1d,0x1ea80ef8,0x2bbc00bc,0x1dc400cd}},	//   _smaa_, _نامي_, ्टबा, विशत, 
   {{0x7bc8ce7f,0x26c0316f,0x68fc0023,0xdde8004b}},	//   _ergu, _raho_, ërdo, _پرله_, 
   {{0x26c1f8ad,0x3940016d,0x5a340228,0xfce1f8ae}},	//   _saho_, _chis_, өнөт, _нохо, 
   {{0xcc3410de,0x26c00165,0x39400067,0x00000000}},	//   _اراع, _paho_, _dhis_, --, 
   {{0x61307214,0x3940a403,0x29dc00d7,0x00000000}},	//   råli, _ehis_, ešať_, --, 
   {{0x26c048dd,0x6ef400a3,0x6eb0012c,0x8b6403e6}},	//   _vaho_, _làbo, _आउनु, _ئاڵم, 
   {{0x26c073cf,0xa4f003ee,0x2909f8af,0x3941f8b0}},	//   _waho_, _dışı_, _umaa_, _ghis_, 
   {{0x26c1f8b1,0x69c81088,0x391401d9,0xc87c0e78}},	// [39530] _taho_, lvde, _روٝز, maß_, 
   {{0x7cfc0241,0x28a409ab,0x06b40214,0xc87c0112}},	//   _kàrù, ग्रि, _اندک_, laß_, 
   {{0x9c7c04fe,0x2919f8b2,0x28dc243c,0x69c80165}},	//   ikōr, onsa_, यापि, nvde, 
   {{0xa3d531b9,0x29180192,0xa2c807af,0x00000000}},	//   _домч, nnsa_, _होर्, --, 
   {{0xdbf0012c,0x7bd8022f,0x3f8dbfcb,0x7cfc01e1}},	//   _přív, xxuu, urgu_, _làrù, 
   {{0x39800365,0xe2f80220,0x3f8c0327,0x00000000}},	//   yıs_, _тегі_, rrgu_, --, 
   {{0x7bc400da,0x00000000,0x00000000,0x00000000}},	//   ājum, --, --, --, 
   {{0x2919f8b3,0x212c020c,0x00000000,0x00000000}},	//   éral_, _ukeh_, --, --, 
   {{0x28dc07b7,0xc87c0112,0xdb200166,0xdbf0013a}},	//   यानि, daß_, _şuña, _třív, 
   {{0x7bd80050,0x2919f7f8,0x598400db,0x7bc8003a}},	//   rxuu, ensa_, олоб, _vrgu, 
   {{0xd9442dc1,0x39400070,0x310000cd,0x00000000}},	//   жени, _phis_, लोकः_, --, 
   {{0x28a406e3,0x291805d5,0x7bdc0129,0x00000000}},	//   ग्लि, gnsa_, _àquo, --, 
   {{0xbbe80f11,0x45240003,0x7d08030d,0x7bc9f8b4}},	//   _حرام_, _རྩེར_, _imgs, _urgu, 
   {{0x7f580a81,0x2919f8b5,0x7cfc01e1,0x8c1808a8}},	//   _muuq, ansa_, _fàrù, _דוני, 
   {{0x39409770,0x7f5801d9,0xe46400b8,0x98a400ee}},	//   _this_, _luuq, _aññā, _дийе, 
   {{0xe3b0040b,0x68fdf8b6,0x00000000,0x00000000}},	//   کرِ_, chsd, --, --, 
   {{0x03a00184,0x1309f8b7,0x2368007b,0x480002e8}},	// [39540] мито, анай_, محلي_, _опъв, 
   {{0x51f46fb7,0x16a87b7e,0x6d5c32bc,0xa4f00139}},	//   يسار, _твои_, _ũram, _tışı_, 
   {{0x7d0802d0,0x8af8010f,0x00000000,0x00000000}},	//   _omgs, ספעק, --, --, 
   {{0x28ddf8b8,0x7f580067,0x92d80154,0x6e4400c7}},	//   यायि, _buuq, ়সে_, ҧҵаз, 
   {{0x4fb40127,0x8d6c0092,0xf3f81de6,0x00000000}},	//   تصار, _አሏቸው_, _уңа_, --, 
   {{0x7f580009,0xb8dc0327,0x00000000,0x00000000}},	//   _duuq, _ངི_, --, --, 
   {{0x21740d0c,0xccf8026a,0x28dc1b61,0x98c80034}},	//   _нутр, ићи_, यामि, ियाए, 
   {{0x6d5df8b9,0x7f58058a,0x6ef401ab,0xebc40166}},	//   _éram, _fuuq, _tàbo, зәкн, 
   {{0xd010a012,0x8fa401af,0x29186f92,0x3f657850}},	//   _غلط_, _фазе, éram_, _мито_, 
   {{0x28dc8109,0x67f00ca8,0xddd4010e,0x00000000}},	//   याभि, _lójú, _çaşy, --, 
   {{0xa9342401,0x68fdf8ba,0x3f880055,0x00000000}},	//   зенш, thsd, _åcur_, --, 
   {{0x69c801e6,0x98a00374,0x2919f8bb,0x00000000}},	//   rvde, tokā_, unsa_, --, 
   {{0x61301347,0x4c141ec7,0x6c380c75,0x3fbc0131}},	//   målt, _بباس, _اتاڭ_, ﻠﻐﺎﻧ, 
   {{0x3af8006a,0xc87c0112,0x00000000,0x00000000}},	//   _pêpe_, saß_, --, --, 
   {{0x67f00248,0xa4d42626,0xc87c0112,0x00000000}},	//   _bójú, пові, paß_, --, 
   {{0x3b800daf,0x69dc005b,0x00000000,0x00000000}},	//   _эләг, äreu, --, --, 
   {{0x31780175,0x8ca0012d,0x3a2001af,0xc764c947}},	// [39550] _awrz_, _गानो, _нмәг, _بابى, 
   {{0x7f580a63,0x026802d5,0x00000000,0x00000000}},	//   _ruuq, ршай_, --, --, 
   {{0x53a00201,0x7f59f8bc,0x11685175,0x45a00372}},	//   _ውይይት_, _suuq, مللی_, _تەزك, 
   {{0x915c0208,0x00000000,0x00000000,0x00000000}},	//   _sẵn_, --, --, --, 
   {{0x9f3400d6,0x7f580a63,0x5ba80037,0x00000000}},	//   педі, _quuq, _कहेव, --, 
   {{0x63b86f38,0xbb5400b5,0xdb0c03b2,0x5f0406dc}},	//   ğanı, bのjf, _íkøs, язла, 
   {{0x63b862b6,0x40840261,0xad5831af,0x00000000}},	//   şanı, _муаб, орых_, --, 
   {{0x7f580e14,0x00000000,0x00000000,0x00000000}},	//   _tuuq, --, --, --, 
   {{0xad25f8bd,0x2d98049f,0x00000000,0x00000000}},	//   بروو, _åren_, --, --, 
   {{0x4ad001ad,0x0c2000a8,0x1a041985,0xb4e8012d}},	//   तागव, эмын, зпом, _भव्_, 
   {{0x1b0c0183,0x99d41888,0xadbc030d,0x00000000}},	//   সকলে_, ستدا, _вахi, --, 
   {{0x61304bc1,0x69ac45bf,0x12e00046,0x8ca0012d}},	//   måls, _जहरी, _ﺍﻷﻤﺭ, _गायो, 
   {{0x1c380598,0xd7f1f8be,0x3d900166,0x7d19f8bf}},	//   _узды_, ركس_, _хиҗр, mnus, 
   {{0x7d183cfe,0xe6d4009d,0x00000000,0x00000000}},	//   lnus, мцсэ, --, --, 
   {{0x69dc0e03,0x69080158,0x7d1812bb,0x154400d8}},	//   äret, øsdø, onus, зевм, 
   {{0x7d19f8c0,0xd7c8009f,0x00000000,0x00000000}},	//   nnus, _هوبه_, --, --, 
   {{0xaad00490,0x23c8012c,0x7d1804cc,0x6130007c}},	// [39560] _थोडक, रिषद, inus, håls, 
   {{0x7d18bb9d,0xe7c8033f,0x61300728,0x8b54010f}},	//   hnus, िटरप, kåls, פיעס_, 
   {{0x7d1803cd,0x8658011a,0x5064008e,0x00000000}},	//   knus, _לדיי, птла, --, 
   {{0x4fc4652e,0x23780334,0x8fa40884,0xa49000f2}},	//   зска, _fwsj_, заде, _لیفت, 
   {{0x7d19ba2a,0x4524031c,0x28dc193d,0xe44801ec}},	//   dnus, _རྩིར_, याति, _ولپى_, 
   {{0x7d1800af,0x6e95f8c1,0x0838008f,0x2bbc06ff}},	//   enus, фику, זענל, ्टसा, 
   {{0x4341ea0f,0x1ea9042c,0x0dc818f4,0x422000d8}},	//   _черв, تاني_, сули_, _здрв, 
   {{0x8fa5f8c2,0x00000000,0x00000000,0x00000000}},	//   _набе, --, --, --, 
   {{0x613003cd,0x00000000,0x00000000,0x00000000}},	//   rålt, --, --, --, 
   {{0x7d180784,0xbea04db0,0x00000000,0x00000000}},	//   anus, _паук, --, --, 
   {{0xe8940006,0x2d99f8c3,0x2bbc0b02,0x00000000}},	//   мань, _êre_, ्टहा, --, 
   {{0x28dca1f3,0xd7fc004d,0x3cfc022e,0x0214011a}},	//   याधि, đăng_, chuv_, לחים_, 
   {{0x2c085311,0xb9a001ed,0xc7b80108,0xbb4445cc}},	//   _بعضی_, ومیٹ, щён_, تلین_, 
   {{0xc5b40003,0x69dc023a,0x00000000,0x00000000}},	//   _བགྱི, äres, --, --, 
   {{0x28ddf8c4,0xbb2801ed,0x69dc332e,0xdb08029e}},	//   यादि, _اتنے_, åred, _بزنه_, 
   {{0x399800d9,0x00000000,0x00000000,0x00000000}},	//   _היהד, --, --, --, 
   {{0x260c12eb,0x00000000,0x00000000,0x00000000}},	// [39570] _डेरी_, --, --, --, 
   {{0xba00001f,0x04fc015b,0xcd000210,0x00000000}},	//   _ፎቅ_, ্কের_, leść_, --, 
   {{0x4aac19cc,0x245801c6,0xf19400c7,0x00000000}},	//   ज्यव, _мань_, еихь, --, 
   {{0x29185f14,0x6ef401ab,0x61300fac,0x68fc036e}},	//   érah_, _hàbh, våls, ërdh, 
   {{0x7d180174,0x00000000,0x00000000,0x00000000}},	//   vnus, --, --, --, 
   {{0x53b40075,0x9f04009a,0x98a00153,0x00000000}},	//   _юғур_, بوتو, moką_, --, 
   {{0x7c740092,0x00000000,0x00000000,0x00000000}},	//   _የቀረው_, --, --, --, 
   {{0x6ef400a3,0x71440137,0x61300efa,0xcd000210}},	//   _làbh, _كۉلۅ, råls, jeść_, 
   {{0x7d19f8c5,0x3cfc007c,0x00000000,0x00000000}},	//   rnus, rhuv_, --, --, 
   {{0xff500597,0x7d180086,0x3cfc07d6,0x6ef400a3}},	//   _أخر_, snus, shuv_, _nàbh, 
   {{0x6e9428e8,0x260c1bf9,0x23c800bc,0x00000000}},	//   _чиху, _डेली_, रिँद, --, 
   {{0x3af8006a,0x5c14010b,0x00000000,0x00000000}},	//   _dêpa_, _оьлу, --, --, 
   {{0x99d404fb,0x69dc0267,0x102c0023,0x00000000}},	//   ستگا, ärer, _እናተዘ, --, 
   {{0x2bbc0316,0x6ef401ab,0xa3c00c4c,0x00000000}},	//   ्टरा, _càbh, ंबन_, --, 
   {{0x09ac0135,0x00000000,0x00000000,0x00000000}},	//   _ཕྱྭ_, --, --, --, 
   {{0x23c807d0,0x2bc40b8f,0x00000000,0x00000000}},	//   रिंद, _वनमा, --, --, 
   {{0x6ef401c3,0x47c00153,0x00000000,0x00000000}},	// [39580] _fàbh, _абыв, --, --, 
   {{0xfbc404d3,0x6ef401c3,0x4b4800df,0x00000000}},	//   _یت_, _gàbh, ַגײַ, --, 
   {{0xdbf00154,0x00000000,0x00000000,0x00000000}},	//   _জেমস_, --, --, --, 
   {{0xb11c045e,0x7f8000d1,0x00000000,0x00000000}},	//   তত্ব_, ھلىن, --, --, 
   {{0x6ef400f7,0x7f800131,0x68fc0240,0xd01006c2}},	//   _hàbi, پلىن, ërdi, خلش_, 
   {{0x68fc02e2,0x00000000,0x00000000,0x00000000}},	//   èrdz, --, --, --, 
   {{0xf98400f8,0x82a000fb,0x61b0215c,0x78a400d7}},	//   _جب_, _шарж, _مەلا, _ociv, 
   {{0xdb18245f,0x67201fe6,0x4090007b,0x00000000}},	//   _erwü, člji, _للفر, --, 
   {{0xf0780184,0x6ef4004e,0x28ddf8c6,0x26c400d7}},	//   _миңә_, _làbi, यासि, ôlok_, 
   {{0x78a40005,0xbb4416a2,0xc984008e,0x00000000}},	//   _aciv, ولين_, муми, --, 
   {{0x4c6809a5,0x6ef400a3,0xfbcc0244,0x00000000}},	//   _диен_, _ràbh, هتی_, --, 
   {{0x6ef40e89,0x2d9d0129,0x167001ec,0xc8fc0154}},	//   _sàbh, muve_, ңқыр, ৃক্ত_, 
   {{0x2d9df8c7,0x18b00032,0x28a405d7,0x5ea40183}},	//   luve_, уҙыр, ग्गि, _গোটে, 
   {{0xa6340150,0x00000000,0x00000000,0x00000000}},	//   енгі, --, --, --, 
   {{0x2d9c184d,0x00000000,0x00000000,0x00000000}},	//   nuve_, --, --, --, 
   {{0x6624005f,0xd6d8013e,0xa0280327,0x00000000}},	//   _ārkā, отӣ_, _སྙྀང_, --, 
   {{0x1cbc025c,0x6ef400a3,0x68ec02d0,0x02a40212}},	// [39590] _ཆིལ_, _tàbh, _ioad, дрем, 
   {{0x68edf8c8,0x28dc412f,0x2d9df8c9,0x98a08327}},	//   _hoad, यावि, kuve_, roką_, 
   {{0x68edf8ca,0x2d9c04d4,0x6ef4642b,0x98a0033f}},	//   _koad, juve_, _gàbi, soką_, 
   {{0x68ec0b21,0x2d9c2b1d,0x78a40165,0x69dc03cd}},	//   _joad, duve_, _xciv, ørey, 
   {{0x645c409c,0x68ec51e2,0xd24c0014,0x00000000}},	//   _igsi, _moad, لچہ_, --, 
   {{0x68edf8cb,0x2d9c0810,0x7bdca547,0xf774011a}},	//   _load, fuve_, _àqui, דקס_, 
   {{0x6ef400db,0x31c40014,0x335800a8,0xf1a40354}},	//   _xàbi, _لۅلہ, _царэ_, _иртн, 
   {{0x6285f8cc,0xc0c80020,0x68edf513,0x684800ef}},	//   laho, በትም_, _noad, _kūdī, 
   {{0x2d9c0421,0x5f9400dd,0xaffc010a,0x00000000}},	//   auve_, _سلائ, _дотi, --, 
   {{0x60c80097,0x628418e0,0x78a5f8cd,0x2d9c192e}},	//   _haem, naho, _sciv, buve_, 
   {{0x68edf8ce,0x60c9f8cf,0x18a44cc4,0x98a43594}},	//   _boad, _kaem, нанм, нине, 
   {{0x68edf8d0,0x6285f8d1,0x645df8d2,0x6ef44b84}},	//   _coad, haho, _ngsi, _ràbi, 
   {{0x60c84c06,0x6285f8d3,0xb8e8006d,0x68edf8d4}},	//   _maem, kaho, _उस_, _doad, 
   {{0x60c80007,0x645c00e8,0x00000000,0x00000000}},	//   _laem, _agsi, --, --, 
   {{0x60c80607,0x6285f8d5,0x68ec0363,0x28dc6d65}},	//   _oaem, daho, _foad, याशि, 
   {{0x60c80399,0x68edf8d6,0x1cbc0135,0xdb08017a}},	//   _naem, _goad, _ཆིས_, kteë, 
   {{0x28dc11b1,0x6285f8d7,0x645c0175,0x00000000}},	// [395a0] यारि, faho, _dgsi, --, 
   {{0x6285f8d8,0x68ec00d8,0x645df8d9,0x42c400db}},	//   gaho, _zoad, _egsi, нгун_, 
   {{0x60c8d850,0x68ec01e1,0xd46800f3,0x00000000}},	//   _baem, _yoad, _нине_, --, 
   {{0x60c80097,0xcfa47e12,0xd0240209,0xca5400df}},	//   _caem, ешки, нмей, גיעז_, 
   {{0x60c9f8da,0x087400c8,0xc9500a1e,0x2d9c0472}},	//   _daem, גענט_, אמא_, wuve_, 
   {{0x2d9df8db,0x040801fb,0x00000000,0x00000000}},	//   tuve_, _lưỡn, --, --, 
   {{0xa2c802ab,0x60c8003a,0x7bcc003a,0xc0f00023}},	//   _होट्, _faem, æcun, ግሮም_, 
   {{0x60c80399,0x2d9c416e,0xf8d000cd,0x00000000}},	//   _gaem, ruve_, _तोलय, --, 
   {{0xfba40323,0x68ecf8b1,0x4f240006,0x2d9df8dc}},	//   нтэй_, _road, _здаб, suve_, 
   {{0x68edf8dd,0x8aa4023b,0x2d9c00e4,0x60c80166}},	//   _soad, хрид, puve_, _zaem, 
   {{0x69c40323,0x60c80007,0x68ec045f,0x3dac009e}},	//   төлб, _yaem, _poad, কিউল, 
   {{0x6285f8de,0x0408001e,0xaad00037,0x88c40066}},	//   zaho, _cưỡn, _थोरक, رتجل, 
   {{0x6285f8df,0x68edf8e0,0x04080016,0x12e002dd}},	//   yaho, _voad, _dưỡn, _ﺍﻷﻁﺭ, 
   {{0x443c003d,0xdb1800d2,0x68ec016b,0x62855ea5}},	//   _ġu_, _tswá, _woad, xaho, 
   {{0x645c089c,0x68edf8e1,0x443df8e2,0x7ce4010e}},	//   _pgsi, _toad, _šu_, _añry, 
   {{0x62840134,0xf98c5534,0x61e000e8,0xa93400cf}},	//   waho, _ابو_, _àlli, _шейш, 
   {{0x6285f8e3,0x60c80097,0x00000000,0x00000000}},	// [395b0] taho, _raem, --, --, 
   {{0x2d8df8e4,0x60c80399,0x00000000,0x00000000}},	//   _ovde_, _saem, --, --, 
   {{0x60c9f8e5,0x6ea41b61,0x00000000,0x00000000}},	//   _paem, च्छु, --, --, 
   {{0x6285f8e6,0x67240051,0x557400df,0xc4ac00fe}},	//   saho, _hjhj, _שערן_, _চোৰজ, 
   {{0x6285f8e7,0x2d8c01fa,0x60c9f8e8,0x315800c6}},	//   paho, _avde_, _vaem, رجمة_, 
   {{0x63acf3f4,0x62840009,0x5db801ec,0x00000000}},	//   mtan, qaho, _ﺤﻴﻭﻴ, --, 
   {{0x60c9f8e9,0x9f046824,0x2d94010b,0x63b00427}},	//   _taem, _یورو, грыс, ženč, 
   {{0x63acd64c,0xa0c40592,0x1ed80451,0x1a64036b}},	//   otan, _جيرو, _ڪارڊ_, چیشی_, 
   {{0x2d8c03ee,0x201829ef,0x1a64c5f2,0xdea007d6}},	//   _evde_, _äsi_, نیشی_, _نیشی, 
   {{0x63adf8ea,0xda642901,0xef90072d,0x00000000}},	//   itan, ъвои, _ایود, --, 
   {{0x63adf8eb,0xdb08020c,0xd1c80240,0x00000000}},	//   htan, nteé, _ጽብቕ_, --, 
   {{0xa3c06c08,0x00000000,0x00000000,0x00000000}},	//   ंबा_, --, --, --, 
   {{0x63adf8ec,0x7bc400e2,0xbe200154,0x00000000}},	//   jtan, ājus, _ফরিদ_, --, 
   {{0x1a6416d0,0x00000000,0x00000000,0x00000000}},	//   _جیدی_, --, --, --, 
   {{0x63adf8ed,0x04080051,0x00000000,0x00000000}},	//   etan, _tưỡn, --, --, 
   {{0xe9d015fa,0xab740014,0x81d400fe,0xd39405a2}},	//   _دغه_, _جۅیا_, িহা_, кәгә_, 
   {{0x63aca7ea,0x38600066,0x5744004e,0x446000d4}},	// [395c0] gtan, _igir_, _иниб, рвув, 
   {{0x67240ffb,0xc7d40375,0x3cec0334,0x479808a8}},	//   _gjhj, _יופי_, _logv_, _קייס, 
   {{0x63adf8ee,0x77640789,0xdb180139,0x0160341e}},	//   atan, _huix, _iswä, акхо, 
   {{0x63adf8ef,0x7764067c,0xc480241e,0x3cec06ea}},	//   btan, _kuix, _клюк, _nogv_, 
   {{0x63ad2d8f,0x6fb40330,0x6e9401c6,0x00000000}},	//   ctan, امتا, гилу, --, 
   {{0x77640830,0xcdd80640,0x00000000,0x00000000}},	//   _muix, дњи_, --, --, 
   {{0x5155f8f0,0x7dc00a2c,0x386001d5,0x92340150}},	//   _атау, لقون, _ogir_, _شىرش, 
   {{0x38601105,0x2c040166,0x00000000,0x00000000}},	//   _ngir_, лүем, --, --, 
   {{0xfd0c0502,0x3cec004e,0xcb440124,0x00000000}},	//   تجو_, _dogv_, кхои, --, 
   {{0x3861f8f1,0x2d8c03e0,0x00000000,0x00000000}},	//   _agir_, _tvde_, --, --, 
   {{0x63ac05f5,0x2bc43f2c,0xbae002d5,0x2d9800c7}},	//   ztan, _वनवा, рцый, _íre_, 
   {{0x63adf8f2,0x776400db,0x6f19107e,0x00000000}},	//   ytan, _buix, livc, --, 
   {{0x63adf8f3,0x8b65f8f4,0x776400db,0xab9400d4}},	//   xtan, _شاشم, _cuix, _силі, 
   {{0x6f180122,0xc0500375,0xca7400fa,0x25a4002e}},	//   nivc, יזר_, _руды, àllo_, 
   {{0x6d5c003e,0xfa31f8f5,0x63adf8f6,0x57b002dd}},	//   _éras, _پرود, wtan, _құрт, 
   {{0x4dbc009e,0x6f180477,0x5a5402e8,0x854400b1}},	//   ্মপূ, hivc, _съчу, тэге, 
   {{0x63adf8f7,0x776400cf,0x67d5c904,0x47e001e0}},	// [395d0] utan, _guix, _сопу, _тәнҡ, 
   {{0x63adf8f8,0x6f181a48,0x68fc017a,0xc2b80b24}},	//   rtan, jivc, lksd, بارئ_, 
   {{0x3265f8f9,0x6734031c,0xc1080166,0x00000000}},	//   ртув, mozj, мэде_, --, 
   {{0x40700046,0x6734012d,0x61e4036e,0x5f740066}},	//   рғау, lozj, rxhl, هاتر, 
   {{0x63ac8dbd,0x2919f8fa,0x68fdf8fb,0x2489f8fc}},	//   qtan, iisa_, iksd, maam_, 
   {{0x2919f8fd,0x2489f8fe,0x6234561e,0x6565f8ff}},	//   hisa_, laam_, _бегу, _kuhh, 
   {{0xdc6801c0,0x6565cccf,0x68fc03cd,0x00000000}},	//   найд_, _juhh, kksd, --, 
   {{0x2488c3e3,0x68fc8e04,0xdd102ba3,0x2919f900}},	//   naam_, jksd, _düşl, jisa_, 
   {{0x2919f901,0x69dca2d9,0x67340135,0x00000000}},	//   disa_, åren, kozj, --, 
   {{0x2488198f,0x77640137,0xef140228,0x2918067c}},	//   haam_, _ruix, _күчө, eisa_, 
   {{0x2919f902,0x2489f903,0x2b5c05c7,0x00000000}},	//   fisa_, kaam_, _divc_, --, 
   {{0x2919f904,0x2489f905,0x7764004e,0x61e00de2}},	//   gisa_, jaam_, _puix, _àllu, 
   {{0x7764172e,0x2489f906,0x3ab00131,0xac740244}},	//   _quix, daam_, _кәнт, _ئامش, 
   {{0x6734038f,0x65640369,0x68fc0240,0x2918bd88}},	//   gozj, _buhh, ërdr, aisa_, 
   {{0x2919f907,0x44280213,0x2489f908,0xb3b80154}},	//   bisa_, _axc_, faam_, ঁয়াজ, 
   {{0x6499f909,0x65646085,0x386000ca,0x7764004e}},	//   ктур_, _duhh, _ugir_, _tuix, 
   {{0x93a80f11,0xdb082694,0x00000000,0x00000000}},	// [395e0] عارف_, nteï, --, --, 
   {{0x91e5f90a,0x6564a665,0x03a118b2,0xdb1801c7}},	//   лозе, _fuhh, сифо, _erwö, 
   {{0x65640369,0x24881bce,0xd6180133,0xe164007b}},	//   _guhh, baam_, _ستدا_, لدني, 
   {{0x4428070d,0x10482db9,0x2488011f,0x64740276}},	//   _fxc_, няли_, caam_, _вырф, 
   {{0x7525f90b,0xb4c01f5e,0x3ce4033f,0x10140066}},	//   mniz, ंजी_, झाने_, دباد, 
   {{0xa3c034ef,0x918430fe,0x5184117d,0x09ac0327}},	//   ंबर_, _مجرم, _مشرق, _ཕྱྀ_, 
   {{0x29191ca6,0x4dbc045e,0xfc3c0077,0xcf4402dd}},	//   yisa_, ্মভূ, üín_, _ұнай, 
   {{0x7525f90c,0x29180e4d,0x6f18014f,0x68400419}},	//   nniz, xisa_, sivc, _hádž, 
   {{0x2919f90d,0xd0241553,0x9f5002fb,0x63a801c7}},	//   visa_, _смай, žbám_, _äent, 
   {{0x2919f90e,0x24880cf9,0xfce01086,0x0ac40251}},	//   wisa_, zaam_, _қочо, ущим, 
   {{0x6ef400f7,0xfb3005f5,0x2489f90f,0x61e001ab}},	//   _fàbr, снээ, yaam_, _àllt, 
   {{0x1cbc0003,0xcb6800c7,0x29180869,0x63a803cd}},	//   _ཆིག_, _заде_, uisa_, _åeng, 
   {{0x2919f910,0x68fceab6,0x6d40dd11,0x65640254}},	//   risa_, rksd, mlma, _suhh, 
   {{0x2919f911,0x2488cdba,0x6564dd29,0x7525f912}},	//   sisa_, waam_, _puhh, eniz, 
   {{0x6d5c01e4,0x6d4145fe,0x45480fbe,0x6735f913}},	//   _ɨran, olma, ечам_, rozj, 
   {{0x7525f914,0x2919f915,0x44280137,0x69d9f916}},	//   gniz, qisa_, _pxc_, _irve, 
   {{0x6d4005c3,0x4428020c,0x69dc0b1a,0x64a402dd}},	// [395f0] ilma, _qxc_, æref, лаңа, 
   {{0x7525f917,0x2489f918,0x2d9c05a1,0x65640254}},	//   aniz, saam_, krve_, _tuhh, 
   {{0xf7712a7a,0x6d400198,0x00000000,0x00000000}},	//   _وای_, klma, --, --, 
   {{0x108808b0,0xf3180032,0x24887f5b,0x6d4001bf}},	//   _ﻗﯩﺮﯨ, _ҡояш_, qaam_, jlma, 
   {{0xd344036b,0x00000000,0x00000000,0x00000000}},	//   _چیقه_, --, --, --, 
   {{0x6d41f919,0x26d006e4,0x1cbc0003,0xc3000583}},	//   elma, ndzo_, _ཆིང_, _آسی, 
   {{0x26d06009,0x62940433,0x6d400072,0x00000000}},	//   idzo_, _idzo, flma, --, 
   {{0x62940841,0x6234020a,0x6d4005d5,0xf1b800e4}},	//   _hdzo, _беҳу, glma, _ãġa_, 
   {{0x4b85f91a,0x28d80a28,0x69d9f91b,0x9b05a06d}},	//   айын_, _बोधि, _arve, изид, 
   {{0x6d41f91c,0xdd949c36,0xdb08004e,0x29181e93}},	//   alma, _важы, rteï, èran_, 
   {{0x69d80bb8,0x629402c4,0x00000000,0x00000000}},	//   _crve, _mdzo, --, --, 
   {{0x69d80bb8,0x28dd20ed,0x1ea80451,0x00000000}},	//   _drve, यागि, _ساڄي_, --, 
   {{0x69d9f91d,0x6295f91e,0x7d1820ac,0x3cfc0218}},	//   _erve, _odzo, mius, mkuv_, 
   {{0x7d19f91f,0x62940564,0xd6242361,0x7bc9f920}},	//   lius, _ndzo, لعزي, _isgu, 
   {{0x2d982d62,0x63bcfe62,0xdce00010,0xd9445a52}},	//   _året_, _apsn, _lulč, _кеки, 
   {{0x9424b82f,0x6294006f,0x88800801,0xf4f80014}},	//   амбе, _adzo, _длъж, دورں_, 
   {{0x53a41a92,0x52a812e7,0x691c0022,0x00000000}},	// [39600] разб, квам_, rĩet, --, 
   {{0x7d19f921,0x9695f922,0x752405b1,0x9259f923}},	//   hius, _триш, sniz, نشار_, 
   {{0x6d400209,0x8698010f,0x3cfc0037,0x00000000}},	//   ylma, _בייז, kkuv_, --, 
   {{0x53a5f924,0x6295f925,0x3cfc0218,0x7d180268}},	//   _камб, _edzo, jkuv_, jius, 
   {{0x3980000f,0x2bbc033f,0x69dc04e6,0x6d4001bf}},	//   hűs_, ्टछा, ärez, vlma, 
   {{0x79800c8c,0xc7d40375,0x6d400009,0x00000000}},	//   _ownw, יוני_, wlma, --, 
   {{0x7d180eda,0x0dc86545,0xcd040276,0xbea00798}},	//   fius, тули_, ичии, цајк, 
   {{0x7d19f926,0x92a4068f,0x6d41f927,0x684001e7}},	//   gius, _wyłą, ulma, nádú, 
   {{0x6d41f928,0x629406af,0x00000000,0x00000000}},	//   rlma, _égoï, --, --, 
   {{0x2d9c012c,0x0eb80108,0x00000000,0x00000000}},	//   prve_, _шубы_, --, --, 
   {{0x7d19f929,0x3cfc0218,0x7bc9f92a,0x79a027a8}},	//   bius, bkuv_, _esgu, оряе, 
   {{0x7d19f92b,0xfce1f92c,0x69d80427,0x6d4002d0}},	//   cius, _мохо, _vrve, qlma, 
   {{0xead4e085,0x60dd2e90,0x8154010f,0x6b74010a}},	//   _голь, _ósme, יסטע_, _уллу, 
   {{0x3ad047ed,0x00000000,0x00000000,0x00000000}},	//   _وينز, --, --, --, 
   {{0x26d0006d,0xfa7406a9,0x69d8127b,0x69dc00b5}},	//   rdzo_, _דעות_, _urve, æred, 
   {{0x3f8c00a9,0x25b00334,0x7bc803cb,0x20f40c5a}},	//   ysgu_, rtzl_, _ysgu, _आवेश_, 
   {{0xa0680220,0x838429db,0x3ce405f9,0x64b8037e}},	// [39610] қала_, рыбе, झाते_, もima, 
   {{0x7d19f92d,0x6234041b,0x69c8343b,0xdef80023}},	//   zius, безу, owde, ዋቱን_, 
   {{0xe0440058,0xdce00024,0x40740131,0xa5f82bcb}},	//   әнли, _sulč, للاڭ_, _сену_, 
   {{0x273c006a,0x7d180005,0xe5780166,0x28dc00bc}},	//   _fânî_, xius, _изү_, याटि, 
   {{0x7d180eda,0x3cfc01d4,0xdb080798,0x80240b8c}},	//   vius, vkuv_, nteã, جرام, 
   {{0x4175f92e,0x6294004c,0x63042bef,0x9ea812e7}},	//   _نارس, _udzo, _اوسل, увка_, 
   {{0x7d19f92f,0x3cfc0037,0x00000000,0x00000000}},	//   tius, tkuv_, --, --, 
   {{0x273c025a,0x02c40825,0x5ba8011b,0x62080205}},	//   _yânî_, _रघुन, гким_, ıslı, 
   {{0x7d19f930,0xdb080587,0x3b440092,0x3ec400d4}},	//   rius, steí, _የባለቤ, _всеб, 
   {{0x7d19f931,0x3cfce379,0x1c1c007d,0x5f44007b}},	//   sius, skuv_, _बइठल_, _انطل, 
   {{0x5dd400c6,0x7d18098e,0x00000000,0x00000000}},	//   _دقائ, pius, --, --, 
   {{0x7d180140,0x2d9800fb,0x00000000,0x00000000}},	//   qius, _төшө_, --, --, 
   {{0x2d981347,0x59d4095f,0x7bc800a2,0xaf700092}},	//   _årer_, धिहर, _usgu, _ብቃትና_, 
   {{0xa3c05345,0xcc38010f,0x00000000,0x00000000}},	//   ंबई_, _גענט, --, --, 
   {{0xe8d8001e,0x69940022,0x89d401f7,0x00000000}},	//   _giỏ_, _дрых, _هوور_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [39620] --, --, --, --, 
   {{0xe3b00583,0x86b002dd,0x00000000,0x00000000}},	//   برِ_, _нәсі, --, --, 
   {{0x28dc0157,0x7ae0009a,0xbec000e2,0x00000000}},	//   याचि, _mnnt, _ķīps, --, 
   {{0x6600332c,0x10a41a21,0xe7d400e5,0x00000000}},	//   ølke, сидн, _امیگ, --, 
   {{0x6aa8003b,0x42e000db,0xd3f400cc,0x4938011a}},	//   ygdf, تكەق, _ঘেৰি_, נגנו, 
   {{0x4dbc00bd,0xa3bc00e1,0x69dc0158,0x69c80042}},	//   ্মসূ, _आहत_, årek, ywde, 
   {{0x2175f932,0x2c240154,0x814000e5,0x00000000}},	//   _мутр, _পরেই_, _کچلن, --, 
   {{0x7ae00e89,0x6b740124,0x25a4026c,0x0ca856ac}},	//   _annt, олиу, àlli_, утки_, 
   {{0x7ae000fb,0x6d5c026c,0xc4d0011a,0xcfa9f933}},	//   _bnnt, _èram, לגה_, _حازم_, 
   {{0x7ae1f934,0xdb4c0133,0x1d8800ec,0xadc41de6}},	//   _cnnt, نێن_, _چئني_, _мазһ, 
   {{0x6f08127b,0x69c8282c,0x44240208,0x00000000}},	//   _ildc, uwde, ̃n_, --, 
   {{0x7ae0022c,0x9d7403e6,0x00000000,0x00000000}},	//   _ennt, _بڕوا_, --, --, 
   {{0x69dc005c,0xf98c0133,0xaa940117,0x8c4401f4}},	//   æreb, وبێ_, _дилч, _уеде, 
   {{0x98bc00da,0xf1c82208,0x28d801ad,0x248c0064}},	//   ētā_, रबान, _बोरि, _žem_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x183801f2,0xc86401a9,0x1cbc0327,0xdce000cd}},	//   ọmụm, _утки, _ཆིབ_, _kulā, 
   {{0x2909f935,0x6f080857,0xa2f4009b,0xe8d80208}},	// [39630] _ilaa_, _oldc, опач, _giề_, 
   {{0x2908070d,0x442401fb,0x00000000,0x00000000}},	//   _hlaa_, ăn_, --, --, 
   {{0xdb09f936,0x611402bf,0x12880014,0xb97800df}},	//   nteá, оджу, شمنی_, ָרדז, 
   {{0xdb080597,0x76480210,0x00000000,0x00000000}},	//   iteá, żdyc, --, --, 
   {{0x29080076,0xa3bc00c5,0x00000000,0x00000000}},	//   _mlaa_, _आहि_, --, --, 
   {{0x13b8008f,0xd2f42ab4,0x5f047a83,0x91540133}},	//   _דזשע, _وکلا_, юзла, مرۆڤ, 
   {{0x29098fd7,0xcd440131,0xde3c0240,0x00000000}},	//   _olaa_, ﺗﻨﯩﯔ_, _ኣታኽል, --, 
   {{0x28d849f1,0xa2d007f7,0x00000000,0x00000000}},	//   _बोलि, ठयक्, --, --, 
   {{0x212c020c,0x9b08036b,0x00000000,0x00000000}},	//   _ijeh_, иниб_, --, --, 
   {{0xe5180a28,0x2909f937,0x0b40084c,0x3dc000cc}},	//   नोति_, _alaa_, мнын, ্মবল, 
   {{0x29080363,0x7ae00051,0x5c740395,0x00000000}},	//   _blaa_, _vnnt, _длет, --, 
   {{0x8afc0198,0x249801f5,0x00000000,0x00000000}},	//   _riƙe, _ndsm_, --, --, 
   {{0x3c45f938,0x290802c4,0x9bc800f1,0xac18030d}},	//   _اضاف, _dlaa_, _خداې_, _лоцу_, 
   {{0x7ae003a1,0x2909450d,0xead4034b,0x657802b5}},	//   _unnt, _elaa_, _ночь, _ōwha, 
   {{0x24982238,0xdb0800ae,0xd4680798,0x00000000}},	//   _bdsm_, cteá, ииве_, --, 
   {{0x212c02d3,0x32ac00af,0x00000000,0x00000000}},	//   _njeh_, _चाहऽ, --, --, 
   {{0x1cbc0135,0x96b9f939,0x13e9f93a,0x044000f3}},	// [39640] _ཆིན_, _куну_, шмай_, детн, 
   {{0x212c00e4,0xea8c010f,0x00000000,0x00000000}},	//   _ajeh_, ָנאָ, --, --, 
   {{0x5064006c,0xdee40023,0x00000000,0x00000000}},	//   отла, ማናን_, --, --, 
   {{0xe3b001e2,0x00000000,0x00000000,0x00000000}},	//   برې_, --, --, --, 
   {{0x67481d0e,0x00000000,0x00000000,0x00000000}},	//   _ásjó, --, --, --, 
   {{0x0eb80220,0x4aac00dc,0x20c40022,0x409000d1}},	//   руды_, ज्ञव, _ҭирҭ, прәт, 
   {{0x39400793,0x7f440131,0xbd64005b,0xdce0411e}},	//   _okis_, غلىق_, орые_, _sulā, 
   {{0x61e0066d,0x39400218,0x8fa4010b,0x2174059f}},	//   _álla, _nkis_, _мабе, _хурр, 
   {{0x60dc03b2,0xef20025c,0xb7cc00eb,0x00000000}},	//   _ósma, _żżur_, ামুয়, --, 
   {{0x2909f93b,0x39413274,0xfbcc05d9,0xed5800d7}},	//   _slaa_, _akis_, ئتي_, _esľp_, 
   {{0xbf11f93c,0xd6a00055,0x3941f93d,0x00000000}},	//   _تولب, _mṛdū_, _bkis_, --, 
   {{0xdce0b872,0x0ae8004b,0x26f407f7,0xdb08002f}},	//   _tulā, ارکي_, ीघ्र_, preß, 
   {{0xdb0800c6,0x290800ad,0xc1b40b98,0x69cc0210}},	//   steá, _vlaa_, _इङ्ग, _तनवी, 
   {{0x108804a2,0x3941f93e,0x3af80af9,0xa5f806a6}},	//   _ﻗﯩﺰﯨ, _ekis_, _dêps_, бегу_, 
   {{0x29085bae,0x85585285,0x0ae800f1,0x00000000}},	//   _tlaa_, لشرز_, _مرګي_, --, 
   {{0x2908022f,0x6fbc0073,0x00000000,0x00000000}},	//   _ulaa_, ोबां, --, --, 
   {{0xdcf0025c,0x02680108,0x00000000,0x00000000}},	// [39650] żgħa, ашей_, --, --, 
   {{0xb3541086,0x32b8007b,0xd04c03e3,0x00000000}},	//   дкуш, قدمة_, _ödəd, --, 
   {{0xf078063f,0x00000000,0x00000000,0x00000000}},	//   _ịgụn, --, --, --, 
   {{0x249800ec,0x55d800c8,0x25a40ffb,0x291800f2}},	//   _udsm_, _פֿינ, àllu_, èrah_, 
   {{0xdee5f93f,0xd344006c,0x00000000,0x00000000}},	//   золи, _کیله_, --, --, 
   {{0xef180212,0x9f6001d3,0xc178009a,0x00000000}},	//   омі_, _épül_, _نصرا_, --, 
   {{0x3ce4000d,0x00000000,0x00000000,0x00000000}},	//   झाले_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb080120,0x00000000,0x00000000,0x00000000}},	//   nteç, --, --, --, 
   {{0x7de5f940,0x05c874f6,0x39403344,0xcd500014}},	//   _وسام, ाबाब, _skis_, وى۪ک, 
   {{0xd945f941,0x8fb400f1,0x6b8400a2,0x00000000}},	//   зени, _ولېږ, _çign, --, 
   {{0x69d01d8a,0x201006be,0x1214010f,0x00000000}},	//   धिजी, _əzin_, פֿיר_, --, 
   {{0xad240014,0x7d08005f,0xe7d40212,0x31c807b7}},	//   _ترٕو, _ilgs, мірю, _रन्ध, 
   {{0xab8400d8,0x4b7808c3,0x00000000,0x00000000}},	//   _цуцк, _האסו, --, --, 
   {{0x7bd80357,0x2ae8000d,0x00000000,0x00000000}},	//   lvuu, जारु_, --, --, 
   {{0x141800c6,0x98a002b1,0x66000158,0x39404fe7}},	//   ميزة_, rokē_, ølka, _ukis_, 
   {{0x7bd9f942,0xdb0801bf,0xc32c0014,0x00000000}},	// [39660] nvuu, rteæ, گٕل_, --, 
   {{0xae1c007d,0x00000000,0x00000000,0x00000000}},	//   _भइलन_, --, --, --, 
   {{0x7bd8023a,0x154400f3,0x660801e4,0x00000000}},	//   hvuu, _неом, ŝekr, --, 
   {{0x8afc03f9,0x4fe843e6,0x00000000,0x00000000}},	//   _miƙa, ймен_, --, --, 
   {{0x61e001ed,0x00000000,0x00000000,0x00000000}},	//   _álln, --, --, --, 
   {{0x7d0800af,0x2f100694,0xdb08023a,0x00000000}},	//   _algs, _màgg_, nteä, --, 
   {{0x8afc03f9,0x7bd82ae9,0x8d840137,0x00000000}},	//   _niƙa, evuu, чулд, --, 
   {{0x3cb002e8,0xdb080108,0xebc40166,0xc198011a}},	//   ейър, hteä, дәкн, _לשלי, 
   {{0x8fa42235,0x0ae808f0,0xdce000e2,0x6fc00037}},	//   _хазе, مردي_, _atlē, _एहिं, 
   {{0x52c8015b,0x7d09f943,0x63680153,0x00000000}},	//   রাকৃ, _elgs, _užne, --, 
   {{0x8afc0198,0xbea000c7,0x02b40375,0x37c80327}},	//   _ciƙa, _чахк, הליך_, གསའད, 
   {{0x2fc5f944,0x00000000,0x00000000,0x00000000}},	//   _kpmg_, --, --, --, 
   {{0xdee40023,0x6da4013d,0xc6e400d4,0x3d1401f9}},	//   ማዓኒ_, _хиҗа, півп, बोळे_, 
   {{0x2f10002e,0xaa5c02dd,0x00000000,0x00000000}},	//   _dàgg_, _келi, --, --, 
   {{0x3ab80375,0x7ab80375,0x15f41b76,0xf56800d4}},	//   _המונ, _הצוו, ीनगर_, зшук_, 
   {{0xc864004e,0x00000000,0x00000000,0x00000000}},	//   _этки, --, --, --, 
   {{0x63040137,0xb8d415eb,0x00000000,0x00000000}},	// [39670] وورل, _ستيش, --, --, 
   {{0x72d41de6,0x79b400e5,0x02c44e8f,0xdb080205}},	//   ноуф, _بھیڑ_, रजेन, rteç, 
   {{0xdb0800d8,0x55700107,0x181800f2,0x00000000}},	//   steç, _аҳст, _هریک_, --, 
   {{0x7964020c,0x2f101574,0xf79802f2,0x00000000}},	//   lèwè, _yàgg_, _بڕێک_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x670c1d8a,0x61e001ed,0x7bd80337,0xff500066}},	//   हसिक_, _állo, vvuu, رخش_, 
   {{0x628406e4,0x60dc0789,0x26c000b8,0xf678010f}},	//   mbho, _ósmo, _mbho_, לײגט_, 
   {{0x8afc0198,0x7964020c,0x693800df,0x6138013d}},	//   _riƙa, hèwè, lĉef, _qälğ, 
   {{0x69dc4e9b,0xceb803f9,0x2d9820e4,0x3135050f}},	//   æren, siƙa_, _æren_, _четр, 
   {{0xfeb88d4e,0x1a040801,0x7bd80b4f,0x693801e4}},	//   _دارت_, дпом, rvuu, nĉef, 
   {{0x98a5f945,0x628401e2,0xae040220,0x7bd8691f}},	//   мине, ibho, _كوكى, svuu, 
   {{0x81dc000e,0x26c005be,0x6b8000d2,0x48e03d6b}},	//   _তথা_, _abho_, bpmg, воюв, 
   {{0xcd4001ed,0xdb09835f,0x00000000,0x00000000}},	//   _جھوٹ, tteä, --, --, 
   {{0xdb18007f,0x76480790,0xdb0801e3,0x00000000}},	//   _eswò, üdyo, fteå, --, 
   {{0x26c001c4,0xdb08005b,0x28d80bae,0x15440798}},	//   _dbho_, rteä, _बोकि, девм, 
   {{0x2f10002e,0x6284d8b7,0xfd6000dc,0xdb080108}},	//   _tàgg_, ebho, _pitṛ, steä, 
   {{0x59d4190c,0xc9500302,0x94a80032,0x00000000}},	// [39680] धिकर, _במה_, йтҡа_, --, 
   {{0x03a0085a,0x55e40137,0x27ec0fac,0x872001c6}},	//   тифо, _жооб, åene_, _амьж, 
   {{0xd46818ce,0x00000000,0x00000000,0x00000000}},	//   _мине_, --, --, --, 
   {{0x8fa4192a,0x4fc46690,0x62845a80,0x31980100}},	//   даде, дска, abho, rčz_, 
   {{0x75240337,0x693801e4,0x62840327,0xc0540212}},	//   miiz, bĉef, bbho, міш_, 
   {{0x26dc0134,0x7525f946,0x693801e4,0x0ef80807}},	//   _ɔwoo_, liiz, cĉef, ्सेस_, 
   {{0xcdf401c0,0x00000000,0x00000000,0x00000000}},	//   ьчды, --, --, --, 
   {{0x98a00153,0xa0b4009b,0x00000000,0x00000000}},	//   mokė_, _пљуј, --, --, 
   {{0x8fd00032,0xdb0801f5,0xfba401c0,0x69380115}},	//   _шәжә, cueë, мтэй_, lĉeg, 
   {{0x3f98003a,0x499002f2,0x29a400c7,0x00000000}},	//   âque_, نیتر, нымҳ, --, 
   {{0x7524216e,0xfb3001c6,0x201003b9,0x1b0400eb}},	//   kiiz, тнээ, _əzim_, ষোভে_, 
   {{0xcb680a83,0xbe104ea7,0x00000000,0x00000000}},	//   _даде_, _جومع, --, --, 
   {{0x6d41f947,0x79680066,0x784401c6,0x3d2001e1}},	//   moma, wèwè, вэрж, _wèwè_, 
   {{0x6d41f948,0xed5000aa,0x75e401f2,0x28b000ab}},	//   loma, _شپږ_, _ọzay, _झावि, 
   {{0x81b002f5,0x31c81a2a,0xa5f82bbd,0x98a00153}},	//   _জৈন_, रबोध, чеву_, jokė_, 
   {{0xc8640d1d,0x75240337,0x6284009a,0x7968020c}},	//   _отпи, giiz, wbho, rèwè, 
   {{0x693801e4,0x00000000,0x00000000,0x00000000}},	// [39690] tĉef, --, --, --, 
   {{0x6d40014c,0xa2d431e4,0x00000000,0x00000000}},	//   homa, عيات, --, --, 
   {{0x752404ba,0x693801e4,0x00000000,0x00000000}},	//   biiz, rĉef, --, --, 
   {{0x6d41f949,0xc0c4004b,0x5574010f,0x628401e7}},	//   joma, بېره_, _רערן_, sbho, 
   {{0x2574049f,0x54780375,0x200800e4,0x00000000}},	//   _hål_, _מטרו, áai_, --, 
   {{0x63adf94a,0x6ec41e4a,0x417400d1,0xccb000c7}},	//   muan, نتىق, _يازس, ҳәшь, 
   {{0x6d41f94b,0x63ace11c,0x200847c0,0x69dc08cb}},	//   foma, luan, šai_, ærel, 
   {{0xdfd4b0b9,0x28c01684,0x63adf94c,0x00000000}},	//   _побы, ष्मि, ouan, --, 
   {{0xdd9002f2,0x00000000,0x00000000,0x00000000}},	//   _ڕوا_, --, --, --, 
   {{0x63ac0194,0x0f5407d2,0x2c0000d1,0x7525f94d}},	//   iuan, _كةلگ, рүшм, ziiz, 
   {{0x6d41f94e,0x75241418,0x00000000,0x00000000}},	//   boma, yiiz, --, --, 
   {{0x6d411db3,0x63adf94f,0xdb080cfc,0x6cd80111}},	//   coma, kuan, nteú, _офіс_, 
   {{0x75255b28,0x090006a6,0x69dc072b,0x00000000}},	//   viiz, упян, årer, --, 
   {{0x25741347,0xa2c00b02,0x00000000,0x00000000}},	//   _bål_, र्म्, --, --, 
   {{0x7525f950,0x63ac0076,0x6b540cad,0x00000000}},	//   tiiz, euan, bàgb, --, 
   {{0xeff80020,0x69a40490,0x63ad20b1,0x00000000}},	//   _ጉባዔ_, _किती, fuan, --, 
   {{0x63adf951,0x7525e9fd,0x31c800dc,0x61e001d3}},	// [396a0] guan, riiz, रब्ध, _állj, 
   {{0x28c112a4,0x75241418,0x53c401ec,0x00000000}},	//   ष्ठि, siiz, мағұ, --, 
   {{0x6d41f952,0x7f4c0092,0x98a00210,0x81b000eb}},	//   yoma, _ዕቃዎች, anką_, _জৈব_, 
   {{0xa2c01fe7,0x66003b22,0xe8d80051,0x00000000}},	//   र्ब्, älke, _việ_, --, 
   {{0x63adf953,0xa6a80214,0x10a4013d,0x00000000}},	//   cuan, _عایق_, _җизн, --, 
   {{0x2d8c079b,0x8afc02a8,0x80f40166,0x00000000}},	//   _pwde_, _riƙo, дхәт_, --, 
   {{0x69380115,0x10a40229,0xdce00205,0x8d7400be}},	//   lĉee, _пивн, _avlı, راغا, 
   {{0xc5f00302,0x69dc2b96,0x5ecc0154,0x00000000}},	//   רדה_, ærem, লাগই, --, 
   {{0x410007d6,0xf044036b,0xdb1801c7,0xbcf000d1}},	//   _ёзув, _شعری, _opwä, اسىغ, 
   {{0x2d8c00a2,0xce4801af,0x00000000,0x00000000}},	//   _twde_, _еззе_, --, --, 
   {{0xdce00205,0x79900108,0x2d980248,0x4c840153}},	//   _evlı, лиэф, _ìre_, _злев, 
   {{0x6d41f954,0x4990ca19,0x63adf955,0x98a0012d}},	//   qoma, پیکر, yuan, ynką_, 
   {{0xa2c02232,0x63adf956,0xbb2801ed,0x2574005c}},	//   र्ड्, xuan, _کتنے_, _sål_, 
   {{0xdc282352,0x63acf2fc,0x2574168c,0x3874013f}},	//   _تسمه_, vuan, _pål_, _ɔbrɑ_, 
   {{0x29181497,0x00000000,0x00000000,0x00000000}},	//   èras_, --, --, --, 
   {{0x7c4402d2,0x00000000,0x00000000,0x00000000}},	//   _ísré, --, --, --, 
   {{0x02a4035b,0x63ac0393,0x28c000cd,0x00000000}},	// [396b0] ерем, uuan, ष्णि, --, 
   {{0x257401e6,0xb464009f,0x00000000,0x00000000}},	//   _tål_, ادِه, --, --, 
   {{0x63adf957,0x68ec0036,0x672800e8,0xf2c40108}},	//   suan, _knad, éeju, ыстн, 
   {{0x63adf958,0x68ec0327,0xbac40150,0xb97800df}},	//   puan, _jnad, _ﺒﻤﺤﺎ, פנדי, 
   {{0x63adf959,0x389c00c8,0x68edf95a,0x00000000}},	//   quan, ליאנ, _mnad, --, 
   {{0xf7740bd9,0x2489f95b,0xfe9000e5,0x00000000}},	//   אקס_, lbam_, ایاج, --, 
   {{0x68edf95c,0x31c40014,0xa2c011bc,0xdd9042f4}},	//   _onad, _مۅلہ, र्ण्, جوع_, 
   {{0x68edf95d,0x24880649,0xada80372,0xb6080118}},	//   _nnad, nbam_, ردىق_, liší, 
   {{0xd9d80316,0xa2c0412f,0x5ed400fd,0x8f640137}},	//   बट्ट, र्थ्, _ижау, رۅۅك_, 
   {{0xafc40150,0xdb080fac,0x6e9401f0,0xdd908863}},	//   _حيكى, nteø, _бифу, _نوئ_, 
   {{0x68ec0135,0xdb080158,0x7f41f95e,0x00000000}},	//   _bnad, iteø, monq, --, 
   {{0xa2c1f95f,0x68ec0311,0x7f403098,0xaac40150}},	//   र्त्, _cnad, lonq, _ەتين, 
   {{0x24880427,0x3ab000fb,0x06d80154,0x00000000}},	//   dbam_, _йәнт, দানি, --, 
   {{0xc76576cb,0x7f408faf,0x24880381,0x2bf0012c}},	//   кияж_, nonq, ebam_, ेहरू_, 
   {{0xceb06da4,0xcb100375,0xd93801b9,0xd62855e4}},	//   יים_, _דלג_, _очиш_, фове_, 
   {{0x68ec0ade,0x7f4031c5,0xd9448087,0x267801c6}},	//   _gnad, honq, _шейи, _үсээ_, 
   {{0x7f41f960,0x940003e3,0xdd8400e5,0x00000000}},	// [396c0] konq, _yekə_, _گڈ_, --, 
   {{0x248803a2,0x68ec1710,0x7f400477,0x00000000}},	//   abam_, _znad, jonq, --, 
   {{0xa2c00882,0x24880de2,0x68ede552,0xca2c0116}},	//   र्ध्, bbam_, _ynad, ﯩﻜﺎ_, 
   {{0x1cdc0327,0x59a8000d,0x69a403ba,0x10a414b3}},	//   ྣབས_, _किनर, _किसी, тидн, 
   {{0x087400c8,0xb4c004fa,0x69380115,0xef9401d5}},	//   דענט_, ूजी_, lĉec, ایطد, 
   {{0xfe6c2033,0x7f400522,0xa3c1bcea,0xa2c00782}},	//   يدى_, gonq, ूबर_, र्द्, 
   {{0x6b5598c2,0x7db0007b,0x68400023,0x00000000}},	//   jàga, لصيا, _ሓድሕድ, --, 
   {{0xebd81f87,0x00000000,0x00000000,0x00000000}},	//   едиш_, --, --, --, 
   {{0x5045f961,0x7f400472,0x31bc0789,0x272c0427}},	//   _реаб, bonq, líz_, lžne_, 
   {{0x68ec0316,0x2f1001e1,0x248816a3,0x00000000}},	//   _snad, _fàga_, zbam_, --, 
   {{0x68ec0161,0xe89406a6,0x272c0427,0xe8d80051}},	//   _pnad, лань, nžne_, _giớ_, 
   {{0x0c25146d,0xe8d801fb,0x5d743129,0x1c1c00e1}},	//   _имен, _khỉ_, _суфф, _बेकल_, 
   {{0xe7d0045e,0x68ec0306,0xebc400fb,0x00000000}},	//   াম্য, _vnad, _сәйн, --, 
   {{0x68ec0198,0x2d9c003a,0x98a00210,0x00000000}},	//   _wnad, osve_, inkę_, --, 
   {{0xf62800d6,0xbb440014,0x68ec025c,0x69380115}},	//   віти_, _جلون_, _tnad, rĉeb, 
   {{0x68ecb2cf,0x69d9f962,0xdb18002d,0x7f40209c}},	//   _unad, _isve, _opwû, zonq, 
   {{0xe8d80016,0x2489f963,0x7f41f964,0x9730158b}},	// [396d0] _nhỉ_, rbam_, yonq, شکیا, 
   {{0x2294ba6e,0x59a80882,0x2488011f,0x4908012c}},	//   الاس, _किमर, sbam_, ासको_, 
   {{0x26d1f965,0x69d80334,0x69dc072b,0x00000000}},	//   mezo_, _jsve, æreh, --, 
   {{0x26d155b4,0x40840063,0xf4840354,0x00000000}},	//   lezo_, тужб, _вурн, --, 
   {{0xe8d801dc,0x443c0016,0x2d9c02d3,0xa3bc00e1}},	//   _chỉ_, _âu_, esve_, _आहट_, 
   {{0x69d9f966,0x26d1f967,0x6ee40131,0x141802e4}},	//   _osve, nezo_, لسىل, _טורב, 
   {{0x2d95f968,0x81f401d9,0x629403ac,0x69d8002f}},	//   арыс, _جہار_, _iezo, _nsve, 
   {{0x26d1f969,0x62940156,0x7f40009a,0x98a00374}},	//   hezo_, _hezo, sonq, rokī_, 
   {{0x26d1f96a,0x69d81731,0x6295f96b,0x20180212}},	//   kezo_, _asve, _kezo, _åsi_, 
   {{0xcf8c04d3,0xdb08017a,0x7f40cb4f,0x00000000}},	//   _رژه_, mreë, qonq, --, 
   {{0x9cb47467,0x6295f96c,0x2bd805f9,0x26d1f96d}},	//   _ممات, _mezo, _बैठा, dezo_, 
   {{0x6295f96e,0x56800020,0x6d5c011c,0xbad003d4}},	//   _lezo, ንዳንዱ_, _èrap, ়াইছ, 
   {{0x69d8004e,0x3cec0395,0xdb092810,0x2c00010b}},	//   _esve, _ingv_, queï, _мүъм, 
   {{0x6295f96f,0x26d1f970,0x3f9d98bd,0x7a1006be}},	//   _nezo, gezo_, _mvuu_, hətə, 
   {{0xa664007b,0x00000000,0x00000000,0x00000000}},	//   لطفو, --, --, --, 
   {{0xf48430fe,0xdb080af9,0x31bc01d3,0x98a0033f}},	//   شاری, kreë, víz_, ynkę_, 
   {{0x6295f971,0x26d08967,0xdce0005f,0x691c0022}},	// [396e0] _bezo, bezo_, _atlī, rũet, 
   {{0xdb08017a,0x26d0008f,0xd17400ee,0x31bc00c7}},	//   dreë, cezo_, гыды, tíz_, 
   {{0x629445b4,0x6fb800cd,0x00000000,0x00000000}},	//   _dezo, ोऽभू, --, --, 
   {{0xefd40201,0x79800083,0x31bc0077,0xdb08017a}},	//   _የሰው_, _mtnw, ríz_, freë, 
   {{0xdb080af9,0x69380115,0x63785c89,0xa2c018cc}},	//   greë, nĉea, _асср_, र्ह्, 
   {{0x6295f972,0x2d9c66b3,0xc7d4011a,0x00000000}},	//   _gezo, tsve_, טוני_, --, 
   {{0xf985a40c,0x7bc82672,0x78a400d8,0x2d9c0393}},	//   _دب_, _apgu, _odiv, usve_, 
   {{0x78a5f973,0x62940912,0x4cbc0c58,0xdb0805e4}},	//   _ndiv, _zezo, ্যভু, breë, 
   {{0x62940912,0xdb080d27,0xa2c041ac,0x26d1f974}},	//   _yezo, creë, र्व्, yezo_, 
   {{0xc9841719,0x26d00472,0x00000000,0x00000000}},	//   луми, xezo_, --, --, 
   {{0x26d1f975,0x0d8460a7,0x00000000,0x00000000}},	//   vezo_, _слен, --, --, 
   {{0x26d1f976,0xa9280137,0x00000000,0x00000000}},	//   wezo_, ئزدە_, --, --, 
   {{0xe8d801dc,0x26d1f977,0x6d4402d5,0x78a40327}},	//   _giờ_, tezo_, čiad, _ddiv, 
   {{0x69d9f978,0xca740993,0x26d005c7,0x69240124}},	//   _tsve, _суды, uezo_, умҭа, 
   {{0x6294159f,0x26d1f979,0x6595f97a,0x2bd802e5}},	//   _rezo, rezo_, рабу, _बैता, 
   {{0xa775f97b,0x26d00bd7,0x60780023,0x00000000}},	//   _клич, sezo_, _ብሓጎስ_, --, 
   {{0x2919f97c,0x6295f97d,0x67d422bf,0xf48401f4}},	// [396f0] mhsa_, _pezo, _топу, сусн, 
   {{0x27e9f97e,0x29180998,0x98a00b13,0x78a400bc}},	//   _iran_, lhsa_, mikā_, _zdiv, 
   {{0x62940dd4,0x466807d6,0xe8d8001e,0x8025f97f}},	//   _vezo, _ярим_, _nhị_, گرام, 
   {{0x3265f980,0x27e9f981,0x62940912,0xdb0805e4}},	//   стув, _kran_, _wezo, treë, 
   {{0xe8d801f2,0x6295f982,0x8024007b,0xdb08017a}},	//   _ahị_, _tezo, درام, ureë, 
   {{0xde05f983,0xa2c007f8,0xaec400d6,0x8afc0198}},	//   ипли, र्श्, йбіл, _fiƙi, 
   {{0xe8d807ae,0x408400f7,0xdb080ea0,0x29198cfe}},	//   _chị_, _бузб, sreë, khsa_, 
   {{0x7a1000ac,0xa2c028a2,0x00000000,0x00000000}},	//   qətə, र्र्, --, --, 
   {{0x63adf984,0x9ed806bb,0x60c868d7,0xceb802a8}},	//   nran, _имат_, _ibem, ziƙi_, 
   {{0x19c400f3,0xae0400d1,0x00000000,0x00000000}},	//   абом, _گومى, --, --, 
   {{0x63ad9f4c,0x27e89b4c,0xe8d8063f,0x00000000}},	//   hran, _aran_, _ghị_, --, 
   {{0xa3e408e9,0x61e001d3,0x98a00171,0x00000000}},	//   पटा_, _állu, fikā_, --, 
   {{0x60c85b9d,0x201c0433,0x27e9f985,0x1c1c00c5}},	//   _mbem, nzwi_, _cran_, _बेचल_, 
   {{0x63adf986,0x27e96bdc,0x958400f7,0x201c0810}},	//   dran, _dran_, илге, izwi_, 
   {{0x63adf987,0x60c9f988,0x96644a77,0x19b8d9ee}},	//   eran, _obem, ркве, _руль_, 
   {{0x63adf989,0x51f40330,0x693801e4,0x18a400c7}},	//   fran, یسار, lĉen, _таим, 
   {{0x63ac2d61,0x69dc12e8,0x98a0002b,0x00000000}},	// [39700] gran, ærev, cikā_, --, 
   {{0x201c171b,0x86b002dd,0xa2c01d68,0x00000000}},	//   dzwi_, _мәсі, र्ल्, --, 
   {{0x60c804ba,0x98a00064,0x00000000,0x00000000}},	//   _bbem, nokį_, --, --, 
   {{0x40900372,0xe16400c6,0xdb08020c,0x100400d1}},	//   ۅلۅر, مدني, sreè, иялм, 
   {{0xdb083a6c,0x272c0219,0x6b54004e,0x66000158}},	//   nteó, lžna_, xàgo, ølkv, 
   {{0x09b402a6,0x60c8043b,0x80c40154,0x62080162}},	//   _জনসা, _ebem, _রোদ্, íplá, 
   {{0x272c0219,0x00000000,0x00000000,0x00000000}},	//   nžna_, --, --, --, 
   {{0x60c801e1,0x2918009a,0x6b54004e,0xac58020f}},	//   _gbem, xhsa_, tàgo, лайф_, 
   {{0xcfa800db,0x008028a8,0x70540137,0x29181bce}},	//   _جازم_, _флуо, _اچاا, ëram_, 
   {{0xe8d801dc,0x3178fe25,0x7c2c0332,0x00000000}},	//   _thị_, _kurz_, úcra, --, 
   {{0x63adf98a,0x98a00069,0x60c8002d,0xe8182ba2}},	//   zran, wikā_, _ybem, नैना_, 
   {{0x27e89dff,0x98a01a14,0x67d4024c,0xa934030d}},	//   _pran_, tikā_, бому, семш, 
   {{0x63ac0227,0x27e803e3,0x00000000,0x00000000}},	//   xran, _qran_, --, --, 
   {{0x98a00aed,0x8afc0198,0x2918036b,0xaa5801d5}},	//   rikā_, _riƙw, shsa_, _йилу_, 
   {{0x63adf98b,0x35e43334,0xe8d8004d,0xf98c01c8}},	//   wran, оцтв, _giở_, _قبي_, 
   {{0x63ac27f8,0xf9900375,0xe50801c8,0x00000000}},	//   tran, _ורק_, ديرو_, --, 
   {{0x27e9f98c,0x8284282b,0x00000000,0x00000000}},	// [39710] _uran_, لجال, --, --, 
   {{0x98b000b8,0xc6a40395,0x317807f7,0x00000000}},	//   _ijyā_, _трии, _burz_, --, 
   {{0x81a529f5,0x63adf98d,0x2bd805d7,0x676401d9}},	//   شحال, sran, _बैसा, _پُھل, 
   {{0xa0c4314c,0x10880ae5,0xa3d40205,0xe29800c7}},	//   صيتو, _ﺗﯩﺮﯨ, _göğü_, таҧ_, 
   {{0x63adf98e,0xe8d8004d,0xdb080254,0x00000000}},	//   qran, _nhọ_, tteü, --, 
   {{0xdce00598,0x3394059f,0x3178002f,0x04e001e1}},	//   _bulğ, _фарё, _furz_, baṣọ, 
   {{0x69380115,0xdb080037,0x00000000,0x00000000}},	//   vĉen, rteü, --, --, 
   {{0x60c9f98f,0x5bc400c6,0xa0c40214,0xdb080037}},	//   _ubem, مقبل, _ديرو, steü, 
   {{0xe8d802e3,0xdca40184,0xcae001ad,0xad24009a}},	//   _chọ_, _ғали, कएंड_, تروو, 
   {{0x9f540241,0x61e000e5,0x00000000,0x00000000}},	//   _ìgàn_, _álls, --, --, 
   {{0xd1bc206f,0x1a28399f,0x693801e4,0x660001e3}},	//   _ሰባት_, ужни_, rĉen, älkl, 
   {{0x6d4400d0,0x59c402dd,0x00000000,0x00000000}},	//   čiac, _ۇيتك, --, --, 
   {{0x7d19f990,0x1ae47136,0xdb85a544,0x693801e4}},	//   mhus, _голм, _угли, mĉel, 
   {{0xba75840d,0xd759f991,0x69380115,0xdce0008e}},	//   _ئاشت, الست_, lĉel, _yulğ, 
   {{0x1a655ea6,0x7d1801c8,0x69dc0b1a,0x2d98072b}},	//   _دیدی_, ohus, æret, _æret_, 
   {{0x7d188859,0xf8dc6ab8,0x693800df,0x25f80210}},	//   nhus, _बसिय, nĉel, _उपरी_, 
   {{0xdb080407,0x7d18009f,0x13e9f992,0x00000000}},	// [39720] lteñ, ihus, ымай_, --, 
   {{0x7d1800d2,0x237808fb,0x969401b9,0xe3b0004b}},	//   hhus, _dusj_, _уриш, ګرې_, 
   {{0x7d19f993,0xdb09f994,0x8b5400c8,0x0544001f}},	//   khus, nteñ, ציעס_, _የቴሌቪ, 
   {{0x7d18005c,0x14d406c2,0x00000000,0x00000000}},	//   jhus, _ازدح, --, --, 
   {{0x7d19f995,0x4f9405f5,0xdce00166,0x9e3c0092}},	//   dhus, ёрду, _sulğ, ትራቴጂ, 
   {{0x7d1801bf,0x00000000,0x00000000,0x00000000}},	//   ehus, --, --, --, 
   {{0xacf95db9,0x4cbc04c5,0xcd4801c0,0xdce000fd}},	//   инку_, ্যসু, лчид_, _qulğ, 
   {{0xc5f0011a,0x64580327,0x00000000,0x00000000}},	//   לדו_, żwie, --, --, 
   {{0x2bd8012c,0x3fc800f2,0xbe140327,0x00000000}},	//   _बैशा, _مدلی_, ħħaħ, --, 
   {{0xbea04d06,0x7d1800d8,0xdce0013d,0x254000c0}},	//   _наук, ahus, _tulğ, mėle_, 
   {{0x7d1813c4,0xaa59f996,0x80d80154,0x2bd828d4}},	//   bhus, рину_, ণার্, _बैरा, 
   {{0x7d19f997,0xe8d8001e,0xceb80198,0x61e00142}},	//   chus, _thọ_, riƙu_, _âlle, 
   {{0xceb803f9,0xdb080137,0x25400153,0x00000000}},	//   siƙu_, creï, nėle_, --, 
   {{0x69dc14f5,0x3bb80375,0x7c300306,0x2d98072b}},	//   æres, _עמוד, šerá, _æres_, 
   {{0x75881064,0xb0c8185d,0xc984009d,0xd1bc0092}},	//   йств_, रभाग, _уули, _ሰባቱ_, 
   {{0xa3e400ab,0x00000000,0x00000000,0x00000000}},	//   पटल_, --, --, --, 
   {{0x8384010b,0x9e3c0257,0x00000000,0x00000000}},	// [39730] сыбе, ትራተጂ, --, --, 
   {{0x24980280,0xa5d401af,0x7d18030a,0x20e40051}},	//   _wesm_, _джош, zhus, _ồi_, 
   {{0x91c02c22,0x272c0219,0x368801af,0x00000000}},	//   мәтл, lžno_, _усын_, --, 
   {{0x7d19f998,0x193c00b5,0x237803cd,0x00000000}},	//   xhus, _ｐｉｐ_, _tusj_, --, 
   {{0x7d181aa1,0x272c0427,0x2bd8466d,0x88e00154}},	//   vhus, nžno_, _बैला, যাপক, 
   {{0xa1940953,0x645df999,0x98a06dd3,0x9f04072d}},	//   _магч, _izsi, miką_, توتو, 
   {{0xe8d807ae,0xd3448efb,0x7d19f99a,0x98a03f05}},	//   _nhỏ_, _بیله_, thus, liką_, 
   {{0xdb8439c1,0x5ba92023,0x7d18009f,0x25400064}},	//   огии, аким_, uhus, bėle_, 
   {{0x98a07063,0x272c0010,0x693800df,0x3cfc0254}},	//   niką_, jžno_, rĉel, rjuv_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7d19f99b,0xcf44198a,0x3da400c7,0xe8d80051}},	//   phus, _بىلۋ, _ыраб, _chỏ_, 
   {{0xdb082d86,0x81b80183,0x7d188faf,0x693801e4}},	//   rteñ, _অনা_, qhus, bĉem, 
   {{0x2f100e89,0x69ddf99c,0xdb0809c2,0x00000000}},	//   _bàgh_, ærer, steñ, --, 
   {{0x7bd8009f,0x98a00153,0x00000000,0x00000000}},	//   mwuu, diką_, --, --, 
   {{0x7ae1f99d,0xdb083eba,0xaae41056,0x00000000}},	//   _iant, nreí, _رسوو, --, 
   {{0x7ae1f99e,0x98a0762b,0x98bc02b5,0x3b0403b9}},	//   _hant, fiką_, ētē_, _honq_, 
   {{0x7ae1f99f,0xc9500375,0x3b0406be,0x98a03f05}},	// [39740] _kant, _קמח_, _konq_, giką_, 
   {{0x6b8400c6,0x00000000,0x00000000,0x00000000}},	//   _éige, --, --, --, 
   {{0x7ae06bfc,0x645c0076,0x1544013e,0x28c000dc}},	//   _mant, _ezsi, _меом, ष्कि, 
   {{0xc0e8044e,0x4fe89187,0x11480137,0x00000000}},	//   _መበል_, имен_, шпей_, --, 
   {{0x7ae1f9a0,0x00000000,0x00000000,0x00000000}},	//   _oant, --, --, --, 
   {{0x7ae1f9a1,0x00000000,0x00000000,0x00000000}},	//   _nant, --, --, --, 
   {{0x29181d64,0xdb080789,0x7bd81418,0x00000000}},	//   ūrai_, greí, ewuu, --, 
   {{0x7ae1f9a2,0x6b54004e,0xef94bbed,0x0ba400fb}},	//   _aant, màgi, _فیصد, ошом, 
   {{0x7ae1f9a3,0xa2c011a0,0x6b54004e,0x00000000}},	//   _bant, र्क्, làgi, --, 
   {{0x7ae0bf0a,0xfe6c1a59,0xbb4405d4,0x3b040165}},	//   _cant, رگە_, يلين_, _conq_, 
   {{0xdb0804cf,0x6adc04c5,0x7bd80ba7,0x98a00006}},	//   creí, বালো, awuu, ziką_, 
   {{0x7ae1395d,0xf98c036b,0xdb080174,0x00000000}},	//   _eant, کبی_, steð, --, 
   {{0x7ae1f9a4,0x3b040d27,0x27ec21fc,0xe8d80208}},	//   _fant, _fonq_, íen_, _chề_, 
   {{0x7ae1f9a5,0x3b040399,0xe8d801fb,0xad2400cf}},	//   _gant, _gonq_, _thỏ_, _بىچى, 
   {{0x6f08014f,0xfb1823e4,0x348802e3,0x80d80490}},	//   _modc, _דוגמ, _ọdị_, _नसले, 
   {{0x7ae1f9a6,0x25ad108f,0x6f080477,0x98a00006}},	//   _zant, čel_, _lodc, tiką_, 
   {{0x2908cf11,0x2b80180f,0x6f0802d0,0xe8d80051}},	// [39750] _ioaa_, _jòc_, _oodc, _ghề_, 
   {{0x29080418,0x6f08014f,0x3b041bce,0x98a00153}},	//   _hoaa_, _nodc, _xonq_, riką_, 
   {{0x26c1f9a7,0x290803c1,0x2b801497,0xa2c000dc}},	//   _icho_, _koaa_, _lòc_, र्ग्, 
   {{0x690c00d2,0x6d5c00b0,0x8f680014,0x3228003b}},	//   _iûes, _ūran, ۅلنے_, ціум_, 
   {{0xf4840e83,0xd24c2832,0xdb0806ed,0x290872dc}},	//   _تاپی, نچہ_, queç, _moaa_, 
   {{0x29080751,0x6f080175,0xaf05df06,0xd5a40345}},	//   _loaa_, _codc, мпіл, _بلێی, 
   {{0x6284016d,0x6d45c696,0x29080561,0xdca4036b}},	//   mcho, čian, _ooaa_, пайи, 
   {{0x6285f9a8,0x2908045a,0x5bb4011c,0x00000000}},	//   lcho, _noaa_, псоф, --, 
   {{0x26c1a366,0x3e280020,0x2b8001ab,0x6284c0e8}},	//   _ocho_, _እንዲከ, _còc_, ocho, 
   {{0x7ae1f9a9,0x29080418,0x26c001d4,0xdb18033b}},	//   _qant, _aoaa_, _ncho_, _apwò, 
   {{0x29080134,0x62840810,0x5e58007b,0x69dc072b}},	//   _boaa_, icho, _الاس_, ærep, 
   {{0x26c1f9aa,0x62840978,0x7ae1f9ab,0x60d8eefe}},	//   _acho_, hcho, _want, newm, 
   {{0x62850c41,0x690c0295,0x98540138,0x2874035b}},	//   kcho, _rûet, ятош, дырр, 
   {{0x62840978,0x7ae1f9ac,0x1ae409a5,0xaac40150}},	//   jcho, _uant, _хокм, _قتىن, 
   {{0x6285f9ad,0x29080270,0x8af80375,0x59099377}},	//   dcho, _foaa_, _להסי, _гейм_, 
   {{0x6285f9ae,0x9f4c05e4,0xe8d801fb,0x26c00e21}},	//   echo, _breë_, _thề_, _echo_, 
   {{0xa6d000fe,0x52a8011c,0x00000000,0x00000000}},	// [39760] ায়ট, йвам_, --, --, 
   {{0x969407d6,0x212c032b,0xb9140055,0x6440033f}},	//   _эриш, _ameh_, _anaḥ_, _ślic, 
   {{0xd010107f,0x00000000,0x00000000,0x00000000}},	//   کلش_, --, --, --, 
   {{0x60d803a2,0x6285f9af,0x15440510,0x6f08157f}},	//   gewm, acho, _хемм, _sodc, 
   {{0x6284ceb3,0x28c01c15,0x80a00e31,0x6f09f9b0}},	//   bcho, ष्टि, رمون, _podc, 
   {{0x6285f9b1,0x212c0098,0x2b8112c4,0x394000f3}},	//   ccho, _emeh_, _ròc_, _ljis_, 
   {{0x2b80004e,0x6f09f9b2,0x3941b257,0x00000000}},	//   _sòc_, _vodc, _ojis_, --, 
   {{0xc0e0d550,0x2b80068c,0x6f080477,0x6600005b}},	//   _поск, _pòc_, _wodc, älki, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfbcc099f,0x6b94001f,0x98a00210,0x00000000}},	//   اتي_, _ያደረገ_, mikę_, --, 
   {{0x38602171,0xa2c003f3,0xe8d8004d,0x98a06dd3}},	//   _azir_, र्ट्, _nhể_, likę_, 
   {{0x26c004c4,0x14cc090a,0x62843e9e,0xbac401ec}},	//   _scho_, ह्मण, zcho, _ﺒﻤﺜﺎ, 
   {{0x3940090c,0x26c004cc,0x98a0012d,0x4c3401c6}},	//   _djis_, _pcho_, nikę_, _ээжт, 
   {{0x108804a2,0x9f4c067c,0x05745734,0x6284007c}},	//   _ﺗﯩﺰﯨ, _creè_, كارد, xcho, 
   {{0x2908016b,0x62840978,0x941003e3,0x00000000}},	//   _toaa_, vcho, mayə_, --, 
   {{0x58f4025c,0x6284047e,0x69c8002f,0x00000000}},	//   _བོགས_, wcho, mtde, --, 
   {{0x47b4025c,0x26c00165,0x25400064,0x045400db}},	// [39770] _བཀྲམ, _tcho_, gėla_, سئرد, 
   {{0x6285f9b3,0x212df9b4,0x26c044ef,0x98a00064}},	//   ucho, _smeh_, _ucho_, dikę_, 
   {{0x62854388,0x60d8013f,0x00000000,0x00000000}},	//   rcho, tewm, --, --, 
   {{0x311401ce,0x9f4c0ea0,0x69c80af9,0xa2c000dc}},	//   нфіс, _treë_, itde, र्ज्, 
   {{0x6284016d,0xdee52f5b,0x3164107d,0x94100213}},	//   pcho, доли, _dhmz_, kayə_, 
   {{0xdb081f08,0xd2b40075,0x752800e2,0x62840978}},	//   kreá, _оқуш_, īdze, qcho, 
   {{0xa3e4038e,0x316401fa,0xb9000327,0xc2540133}},	//   पटक_, _fhmz_, _ཤྲ_, _رخست, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69c9f9b5,0x92c00c58,0x1c4402bf,0x9f540b87}},	//   etde, ্যৰ_, ьним, _жвач, 
   {{0xa2c00a94,0x58f4031c,0x39400175,0xdb0800ae}},	//   र्च्, _བོངས_, _sjis_, freá, 
   {{0xbbe9f9b6,0x69c8005c,0xda700014,0x00000000}},	//   _گرام_, gtde, کُھ_, --, 
   {{0xa3bc00dc,0x1ca403e6,0x00000000,0x00000000}},	//   _इमं_, _کێکی_, --, --, 
   {{0xbbe804fb,0xdb08013a,0x00000000,0x00000000}},	//   _درام_, areá, --, --, 
   {{0xdb0987cb,0x9400016b,0xab6402bf,0x7d08143a}},	//   breá, _mekɔ_, _звіл, _hogs, 
   {{0x69c9f9b7,0x9f4c0789,0x38c800e5,0x9b8801f7}},	//   ctde, _creé_, gíró_, _انڪل_, 
   {{0x291802d3,0x7d0801ed,0x34482f8d,0xa2c000cd}},	//   ërat_, _jogs, зүми_, र्घ्, 
   {{0x316400f3,0x7d0803cd,0x13080006,0x2ca0000d}},	// [39780] _rhmz_, _mogs, онай_, _õide_, 
   {{0xe8d8431d,0x446003b7,0x7d08005c,0x38c800e5}},	//   _thể_, твув, _logs, bíró_, 
   {{0x7d0983a8,0x25a401d3,0xe2b48602,0x6370008e}},	//   _oogs, állt_, эстэ, dınğ, 
   {{0x6265f9b8,0x7d09f9b9,0xe2b4009d,0xf004004e}},	//   رالق, _nogs, _үсрэ, нүби, 
   {{0x09d8012c,0xd434007b,0x69c80036,0x00000000}},	//   _बन्य, _آعجب, ztde, --, 
   {{0x6d4402d5,0x00000000,0x00000000,0x00000000}},	//   čiam, --, --, --, 
   {{0x7d09f9ba,0xde3402d3,0x69c9f9bb,0x2d8c0798}},	//   _bogs, _ክንከው, xtde, _qtde_, 
   {{0x693801e4,0xad541b40,0x05500023,0x00000000}},	//   lĉev, رچاغ, _መእሰሪ, --, 
   {{0x7d0802fa,0xb018063f,0x63700166,0xab741078}},	//   _dogs, ọọvụ_, bınğ, нгиш, 
   {{0x37c40c58,0x69c9f9bc,0xdb080005,0x270c00bc}},	//   ষবাৰ, ttde, treá, _सकेर_, 
   {{0x6935640a,0x2e0c0134,0x02b40375,0x7d0801ed}},	//   енну, bɛfa_, והים_, _fogs, 
   {{0x7d092f65,0x8bf00022,0xdb0801e7,0x00000000}},	//   _gogs, _аҧих, rreá, --, 
   {{0x69c9f9bd,0x272c0219,0x2ca40165,0xa9340166}},	//   stde, lžni_, mamd_, _җепш, 
   {{0x92c0015b,0x5fb028b8,0x69c9f9be,0x00000000}},	//   ্যু_, ुंतल, ptde, --, 
   {{0xa4d41fe2,0x272c0427,0x7d08010b,0x7ab8011a}},	//   нові, nžni_, _yogs, _וצוו, 
   {{0xdb080158,0x7d080067,0x563c0092,0x00000000}},	//   greæ, _xogs, ደሚያጠ, --, 
   {{0x29180029,0x94100134,0x1ae003d4,0xf48400c0}},	// [39790] ūras_, mayɛ_, বাৰা, тусн, 
   {{0x94000134,0xc7640a52,0x69380115,0x00000000}},	//   _rekɔ_, _تابى, gĉev, --, 
   {{0x2ca401f5,0xf2c402e8,0x6d440024,0x67343625}},	//   kamd_, ъстн, čiaj, mizj, 
   {{0xc08002d3,0xc618257b,0x67346f39,0x9f5401e1}},	//   _ክበጽሕ_, ननीय_, lizj, _ìgún_, 
   {{0x656c0548,0x7d080369,0x9f3402bf,0xf0e80131}},	//   mmah, _rogs, неді, بىنى_, 
   {{0x656df9bf,0x2f1800c9,0x80d8012c,0x2489f9c0}},	//   lmah, мочь_, _नसके, lcam_, 
   {{0x637000fd,0xddc000e2,0x31c400f0,0x656c0067}},	//   rınğ, _izlū, _иств, omah, 
   {{0x2489f9c1,0x656df9c2,0x00000000,0x00000000}},	//   ncam_, nmah, --, --, 
   {{0x656df9c3,0xf1080137,0x2489f9c4,0x7d0802d2}},	//   imah, _تۉنۉ_, icam_, _vogs, 
   {{0x656cc85d,0x2489f9c5,0x09b403d4,0xeeb80408}},	//   hmah, hcam_, _জনজা, _олуш_, 
   {{0x656c3a97,0x99d40a11,0x6b8400ae,0x67340003}},	//   kmah, رتدا, _éign, dizj, 
   {{0x2ca400c6,0x656c014f,0xd8240902,0x00000000}},	//   camd_, jmah, едми, --, 
   {{0x24880998,0xb8d80764,0xdce00024,0x6440012d}},	//   dcam_, _चय_, _sulė, _ślin, 
   {{0x29180ba7,0xdb0867c1,0x24882ab9,0x656c0254}},	//   aksa_, dreç, ecam_, emah, 
   {{0xceb06da4,0xd6880150,0x00000000,0x00000000}},	//   טים_, _ﺒﺸﻜﺭ_, --, --, 
   {{0x2edc2db6,0x656c2c53,0x4610009f,0x00000000}},	//   _यस्त, gmah, دوفر, --, 
   {{0xaab80150,0xdb0800d8,0x00000000,0x00000000}},	// [397a0] _ءدۇر_, greç, --, --, 
   {{0x656df9c6,0x24880393,0x67340135,0x3188236c}},	//   amah, acam_, cizj, _ağza_, 
   {{0x24887156,0x693800df,0x00000000,0x00000000}},	//   bcam_, rĉev, --, --, 
   {{0x92c18da0,0x5064d147,0x4fc4ab37,0x656c01d9}},	//   ্যে_, нтла, еска, cmah, 
   {{0x9f4c26b7,0xdb080798,0x75240099,0x8934008f}},	//   _creï_, creç, mhiz, ערנע_, 
   {{0xdf44013e,0x7f800472,0x00000000,0x00000000}},	//   вҷуд_, دلون, --, --, 
   {{0x6d5c002e,0xc69002e4,0x00000000,0x00000000}},	//   _ërak, נאה_, --, --, 
   {{0x201000ac,0xdb0802f6,0x2f1000db,0xe0d001d9}},	//   _əziz_, hreä, _pàgs_, _پزِ_, 
   {{0xcf450ee8,0x9e6403e6,0x2ca401f5,0xf004009d}},	//   _знай, _یامن, ramd_, _шүди, 
   {{0x7bd00451,0xbbd0007b,0x24880205,0xece000eb}},	//   اتيء, ازيغ, zcam_, ভাইড, 
   {{0x6734044e,0x7524855a,0x656c0014,0xe89551d7}},	//   vizj, khiz, ymah, кань, 
   {{0x67340034,0xbc646a0e,0x24882a6e,0x0b88011c}},	//   wizj, ظمین_, xcam_, _ески_, 
   {{0x6d400198,0x29180037,0x88e00154,0x656c014f}},	//   mnma, rksa_, যালক, vmah, 
   {{0xb6e41cb8,0x94100134,0x26c40793,0x2488062c}},	//   люск, sayɛ_, ülo_, wcam_, 
   {{0x2489f9c7,0x6d41f9c8,0x656df9c9,0x6735f9ca}},	//   tcam_, onma, tmah, rizj, 
   {{0x6d403459,0x656df9cb,0x7524414c,0x24880a2f}},	//   nnma, umah, ghiz, ucam_, 
   {{0x656df9cc,0x6d41f9cd,0x2489f9ce,0x7aec0332}},	// [397b0] rmah, inma, rcam_, _áitú, 
   {{0x656df9cf,0x2489ba36,0xdb0806ed,0xd6a40014}},	//   smah, scam_, rreç, _لگِم_, 
   {{0x752561eb,0x2489f9d0,0xc0b802d3,0x952c001f}},	//   bhiz, pcam_, _ደሓር_, _ተገኝተ, 
   {{0x7525f9d1,0x6d40b4b6,0xdb0800d8,0x00000000}},	//   chiz, jnma, preç, --, 
   {{0x71240131,0x00000000,0x00000000,0x00000000}},	//   دىنم, --, --, --, 
   {{0x6d40d6c4,0x14180375,0x69d894fc,0xddc00171}},	//   enma, _חושב, _opve, _uzlū, 
   {{0x6938010f,0xe8d80051,0x1d08004e,0x62340f06}},	//   nĉes, _ghệ_, дейи_, _реву, 
   {{0x6d402611,0x5ff424fc,0x61f400c0,0x00000000}},	//   gnma, _избу, _irzl, --, 
   {{0x69d8143f,0x1f7402dd,0x00000000,0x00000000}},	//   _apve, _алая, --, --, 
   {{0x6d41f9d2,0x7524006f,0xa3e81025,0xdce0002b}},	//   anma, zhiz, _मनन_, _kulī, 
   {{0x3ea5f9d3,0xbd6809a5,0xfdb00139,0x00000000}},	//   mant_, _ерде_, _сәля, --, 
   {{0x61f449ad,0x047c00cd,0xca78022e,0x75240200}},	//   _mrzl, _gūḍh, ritа, xhiz, 
   {{0x88e009bd,0x6b540137,0x7d18009f,0x7524006f}},	//   যাংক, ràgr, mkus, vhiz, 
   {{0xcc38008f,0xca78022e,0x6e48032e,0xfd200345}},	//   _קעסט, pitа, _ísbú, _جوڵێ, 
   {{0x7524016c,0xb8e804c5,0x7d191a99,0x46a00a5b}},	//   thiz, _উস_, okus, расв, 
   {{0x7d19f9d4,0xdce80153,0xb40400cf,0x00000000}},	//   nkus, kmeč, гүмд, --, 
   {{0x79800943,0x7525f9d5,0x7d19f9d6,0xc4800cdd}},	// [397c0] _hunw, rhiz, ikus, рлук, 
   {{0x7525f9d7,0x3ea5f9d8,0x78a5f9d9,0x7d18d62e}},	//   shiz, jant_, _heiv, hkus, 
   {{0x7d19f9da,0x6d406fdf,0x7525f9db,0x321c0122}},	//   kkus, ynma, phiz, ávy_, 
   {{0x798006d6,0x6ec452be,0x1ccc025c,0xefbc02d3}},	//   _munw, _राहु, ླུས_, _ደሃይ_, 
   {{0xf3f81248,0x7981f9dc,0x3ea43046,0x78a401f5}},	//   _яңа_, _lunw, fant_, _meiv, 
   {{0x3ea5f9dd,0x78a5f9de,0x6d405e23,0x69380115}},	//   gant_, _leiv, wnma, nĉer, 
   {{0x3da12171,0x798004ba,0x2e0c0134,0xf98496e0}},	//   арыб, _nunw, rɛfo_, _خب_, 
   {{0x78a5f9df,0x7d19969a,0xcd28009f,0x202403b2}},	//   _neiv, gkus, بستن_, ísið_, 
   {{0x3ea5f9e0,0x6d41f9e1,0x2e0c013f,0x02cc00dc}},	//   bant_, rnma, pɛfo_, स्वभ, 
   {{0x680800e8,0x7d19f9e2,0xc984009b,0x620802d2}},	//   _lëjë, akus, куми, _íslö, 
   {{0xc3300d65,0x78a5f9e3,0xf98c01f7,0x00000000}},	//   שות_, _beiv, يبَ_, --, 
   {{0x7d18067c,0x78a5f9e4,0x7981f9e5,0x1ce00135}},	//   ckus, _ceiv, _dunw, _སིར_, 
   {{0xead443a7,0x78a5f9e6,0x2fc00e89,0x00000000}},	//   _боль, _deiv, àigh_, --, 
   {{0x7981f9e7,0x2eec0223,0xfa30712d,0x00000000}},	//   _funw, _jadf_, ارید, --, 
   {{0x78a4b26d,0xaad801ad,0x00000000,0x00000000}},	//   _feiv, _बॉयक, --, --, 
   {{0x3ea5f9e8,0xdb080158,0x6aa80142,0xf98c015e}},	//   zant_, rreå, ladf, _ببو_, 
   {{0x3ea5f9e9,0x442c00a3,0x82a40108,0xdce000de}},	// [397d0] yant_, àg_, вшее, _sulī, 
   {{0x27e81311,0x68edf9ea,0x3ea5f9eb,0x79800c09}},	//   _isan_, _haad, xant_, _yunw, 
   {{0xf77066a3,0x68edf9ec,0x7d19f9ed,0xe5340064}},	//   _باي_, _kaad, ykus, _бень, 
   {{0x68ec56d7,0x3ea5f9ee,0x27e803a2,0xdce80153}},	//   _jaad, want_, _ksan_, tmeč, 
   {{0x68edf9ef,0x657df9f0,0x14d4008d,0x94b80375}},	//   _maad, _iish, _גורל_, _אמרת, 
   {{0x68edf9f1,0x63adf9f2,0x657df9f3,0x9c24036b}},	//   _laad, msan, _hish, ғдод, 
   {{0x657df9f4,0x7d19f9f5,0x645c003a,0xdb080af9}},	//   _kish, tkus, _hysi, sseë, 
   {{0x7981f9f6,0x3ea5f9f7,0x63adf9f8,0x68edf9f9}},	//   _runw, sant_, osan, _naad, 
   {{0x657df9fa,0x79800cad,0x78a5f9fb,0x27e8013f}},	//   _mish, _sunw, _reiv, _nsan_, 
   {{0x657df9fc,0x78a5f9fd,0x645d8ba9,0x3ea5f9fe}},	//   _lish, _seiv, _mysi, qant_, 
   {{0x68edf9ff,0x18a5fa00,0x63adfa01,0x98a5fa02}},	//   _baad, ланм, hsan, лине, 
   {{0x657dfa03,0x68ec8531,0x798002b9,0x645c20d2}},	//   _nish, _caad, _vunw, _oysi, 
   {{0xb8ec561f,0x78a4493b,0x68edfa04,0x79800564}},	//   _ला_, _veiv, _daad, _wunw, 
   {{0x657dfa05,0x63adfa06,0x78a5fa07,0x70e00034}},	//   _aish, dsan, _weiv, _नस्ल, 
   {{0x27e9fa08,0x63adfa09,0x78a419a2,0x645dfa0a}},	//   _esan_, esan, _teiv, _aysi, 
   {{0x657dfa0b,0x68eccd76,0x63adfa0c,0x1ce0025c}},	//   _cish, _gaad, fsan, _སིས_, 
   {{0x63adfa0d,0x0fbc04c5,0x657cf8b1,0x645c0042}},	// [397e0] gsan, _ইন্ধ, _dish, _cysi, 
   {{0x657c0731,0x68ecde45,0x645c003a,0x47980a1e}},	//   _eish, _zaad, _dysi, _רייס, 
   {{0xe8d807ae,0x68ec0a4d,0x645dfa0e,0x657c0d8b}},	//   _nhớ_, _yaad, _eysi, _fish, 
   {{0x657cbd18,0xd0242777,0x68ec6ed9,0x63adfa0f}},	//   _gish, лмей, _xaad, bsan, 
   {{0x63adfa10,0x60c9fa11,0x1ce0025c,0x645c771b}},	//   csan, _dcem, _སྲེ_, _gysi, 
   {{0x657ddddd,0x9f4dfa12,0x60c80c8c,0xa3b84ed3}},	//   _zish, _creà_, _ecem, _घटत_, 
   {{0x657dde3d,0xe8d801fb,0x6aa80254,0xed500066}},	//   _yish, _chớ_, vadf, يپت_, 
   {{0x657c01d9,0x9f4c00d8,0x00000000,0x00000000}},	//   _xish, _preã_, --, --, 
   {{0xfba40323,0x6aa85f03,0x00000000,0x00000000}},	//   лтэй_, tadf, --, --, 
   {{0x68edfa13,0x2eec0998,0x00000000,0x00000000}},	//   _saad, _uadf_, --, --, 
   {{0x63ac0399,0x68edfa14,0x2a7801b8,0x6aa867c4}},	//   zsan, _paad, ärb_, radf, 
   {{0x68edfa15,0x63adfa16,0x27e9fa17,0xbb400131}},	//   _qaad, ysan, _psan_, _һечк, 
   {{0x68ed83b5,0x657dfa18,0x63adfa19,0x201804cc}},	//   _vaad, _rish, xsan, _üsit_, 
   {{0x657dfa1a,0x68edfa1b,0x6d4402d5,0x8af400ac}},	//   _sish, _waad, čiau, _şəff, 
   {{0x657dfa1c,0x645dfa1d,0x63adfa1e,0x68edfa1f}},	//   _pish, _sysi, wsan, _taad, 
   {{0x657dfa20,0x27e9fa21,0x6aa43885,0xa81413d6}},	//   _qish, _tsan_, _खजुर, _вдиш, 
   {{0x27e9fa22,0x23b45734,0xb97c008f,0x63adfa23}},	// [397f0] _usan_, شماس, _אנהי, usan, 
   {{0x60c8cdd9,0x645c01f1,0x657d4ce2,0xa3a83166}},	//   _scem, _vysi, _wish, _गौण_, 
   {{0x63adfa24,0x645dfa25,0xa4d41cb8,0x00000000}},	//   ssan, _wysi, _коні, --, 
   {{0x645c0034,0x63adfa26,0xf48400ee,0xa438baa7}},	//   _tysi, psan, _гурн, _азму_, 
   {{0x50a00131,0x645d6e42,0x357802d3,0x6b8401e7}},	//   زەلل, _uysi, _ጠለባት_, _éigh, 
   {{0x9f4c00c6,0x6ee40131,0xe8d80208,0x25400064}},	//   _breá_, مسىل, _phớ_, dėli_, 
   {{0x1ce00dd4,0xc0ec0020,0x9f4c0789,0x62240131}},	//   _སྲུ_, ቀድሞ_, _creá_, _ئىزل, 
   {{0xa3e85c0b,0xa3b80c2e,0x5f940276,0xa0c50696}},	//   _मना_, _घटा_, _виат, _خيرو, 
   {{0xde34001f,0x933c0092,0x3ab00352,0x6d5c0055}},	//   _እንዲለ, _በየቦታ, бәйт, _īrat, 
   {{0xe8d80208,0x0c20010b,0x301400db,0x00000000}},	//   _thớ_, юмын, _удур, --, 
   {{0x88cc009e,0xda644e8b,0x88a8022e,0x6abc03f2}},	//   িজনক, рвни, _soћa, órfa, 
   {{0x47dc02f5,0xbd880023,0x5278011a,0x00000000}},	//   মিনী, _ሓቲቶም_, כנתא, --, 
   {{0x6d4401a2,0x47c002e8,0xac180408,0x00000000}},	//   čiat, обяв, _йоцу_, --, 
   {{0xde340201,0x273c0020,0x3cec08a5,0x6c54004e}},	//   _እንዳለ, _አቅርበ, _hagv_, _укчу, 
   {{0xe8d807ae,0x946400a2,0x1bec1b76,0x00000000}},	//   _giữ_, _mańń, जिकल_, --, 
   {{0xe8d8004d,0xd39401e0,0xf48404f2,0x00000000}},	//   _khờ_, иәгә_, صاری, --, 
  
   {{0xdb08f466,0x448401ee,0x8958123b,0x00000000}},	// [39800] queó, рбун_, _בדקת, --, 
   {{0x81dc0eac,0x60dc03e0,0x00000000,0x00000000}},	//   তিন_, _ısma, --, --, 
   {{0x11e40032,0x65c002dd,0x972400f1,0x00000000}},	//   ржем, _нұра, _مفکو, --, 
   {{0xeff8001f,0xefd4001f,0xe3b000f1,0x50b8132f}},	//   _ለሰው_, _ከሰው_, ترې_, ئداد_, 
   {{0xe8d80016,0xdb080789,0x00000000,0x00000000}},	//   _nhờ_, hueñ, --, --, 
   {{0x6b840597,0x03a0013e,0x0eb9c6a4,0x637802d5}},	//   _éigi, _фиро, туды_, _бсср_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb080789,0xfa08015b,0x2174009d,0x00000000}},	//   dueñ, শনাল_, _гуур, --, 
   {{0xe8d807ae,0x38600796,0x8ee80261,0x98a000b0}},	//   _chờ_, _nyir_, _имав_, hikē_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb09fa27,0xe91801ce,0x0d842472,0xb1a4074d}},	//   gueñ, гоні_, _тлен, агiд, 
   {{0x6d45a353,0x644802d2,0x00000000,0x00000000}},	//   čias, _þeig, --, --, 
   {{0x1ce0003d,0xab940597,0x3ea80108,0x00000000}},	//   _སྲི_, _التغ, _öitä_, --, 
   {{0x7bd80bd9,0x00000000,0x00000000,0x00000000}},	//   _סקוו, --, --, --, 
   {{0x05741a59,0xca748443,0xf7700c4f,0x00000000}},	//   لارد, _туды, باَ_, --, 
   {{0x81dc02f5,0xdb0800cf,0x386008ce,0x0ae80451}},	//   তিম_, queò, _fyir_, _سرڪي_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [39810] --, --, --, --, 
   {{0x64a401e0,0x6d5c02d2,0x00000000,0x00000000}},	//   раҡа, _íraf, --, --, 
   {{0x8c18015b,0x3858030f,0x20b8008e,0x64480064}},	//   _তেমন_, _مشید_, гыль_, _žeid, 
   {{0x6ec4000d,0x00000000,0x00000000,0x00000000}},	//   _राउु, --, --, --, 
   {{0x443c00b0,0x00000000,0x00000000,0x00000000}},	//   _äu_, --, --, --, 
   {{0xdee42678,0x1ec866b4,0xd0042dbf,0x6440033f}},	//   соки, улки_, сеше_, _śliw, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdcf80214,0xdc6801c6,0xe8d80208,0xe2c800ec}},	//   افظت_, лайд_, _phờ_, _جوڳو_, 
   {{0x9c5807e6,0x00000000,0x00000000,0x00000000}},	//   ышку_, --, --, --, 
   {{0xfe75fa28,0xeab800d1,0x4de0000d,0x6fcc000d}},	//   _күл_, ңйө_, _कैकई_, _समतू, 
   {{0x5d840597,0x6d4401f1,0xdb0800cf,0x00000000}},	//   _الصل, čiar, sseï, --, 
   {{0x9f4c067c,0xe8d8001e,0xd9441c7b,0xf88800fb}},	//   _breç_, _thờ_, семи, шҡил_, 
   {{0xdb0809d7,0x201d4a5f,0xe8d80208,0x4d7800df}},	//   sueñ, nywi_, _giử_, _ערנע, 
   {{0xb78801e0,0x2c1400bc,0x00000000,0x00000000}},	//   ләүе_, धहरू_, --, --, 
   {{0xdb08db58,0x96640124,0xfdf401ad,0x18a4026b}},	//   queñ, скве, ंटिस_, _лайм, 
   {{0x8a140302,0x64984627,0x00000000,0x00000000}},	//   _לחצו_, итур_, --, --, 
   {{0x138800c6,0x1bec1f13,0xc9500375,0x76d801f0}},	// [39820] اخرى_, जिटल_, _ממה_, _кунӣ_, 
   {{0x9485fa29,0x1ce00327,0xa3e80037,0x00000000}},	//   рыңд, _སིཀ_, _मनर_, --, 
   {{0x65b802ac,0x00000000,0x00000000,0x00000000}},	//   _куяр_, --, --, --, 
   {{0x10489d39,0x00000000,0x00000000,0x00000000}},	//   ляли_, --, --, --, 
   {{0x136400ec,0x98c4012d,0x00000000,0x00000000}},	//   _هاسٽ, _वाईए, --, --, 
   {{0xd1314c4e,0xc7d400d9,0x00000000,0x00000000}},	//   _کمر_, מוני_, --, --, 
   {{0x1ce00003,0xe8d801fb,0x8778008f,0xc6900a1e}},	//   _སྲང_, _nhở_, נאצי, לאג_, 
   {{0x229c025a,0xeb2012eb,0x7e940b38,0xdc840023}},	//   _tâkâ_, यस्त_, لنۇر_, _ቐዳማይ_, 
   {{0xd02401c0,0x705403e6,0x6abc03b2,0x00000000}},	//   _умай, _بۆشا, órfo, --, 
   {{0xe9d80640,0xab3800d4,0x00000000,0x00000000}},	//   амоч_, рпоу_, --, --, 
   {{0xfbcd97a2,0xe8d8001e,0x00000000,0x00000000}},	//   وتی_, _chở_, --, --, 
   {{0xc27825f9,0x1ce0025c,0x63a8f77f,0x9f4c0200}},	//   טריי, _སིག_, _çeng, _preç_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x81dc39db,0x66000fac,0xe8d80248,0x00000000}},	//   তিত_, ålko, _ikọ_, --, 
   {{0x9c7c02b5,0xb604005b,0x00000000,0x00000000}},	//   neōn, пятк, --, --, 
   {{0x181803e6,0xca7001d9,0xb884030d,0x00000000}},	//   ارێک_, _وچھک, _нуьй, --, 
   {{0x828400c6,0x846400a7,0x86e401d5,0xdb080432}},	// [39830] مجال, съве, _лўнд, hreý, 
   {{0x6b849965,0x63a8031c,0x46a40108,0x00000000}},	//   _éigu, _ħend, _ушиб, --, 
   {{0xa3a80d54,0xe7ec0d26,0x02681214,0x6098007b}},	//   _गौर_, _चैता_, ушай_, لناس_, 
   {{0xb9dc001f,0x69c03347,0xe8d80208,0xa0c40f54}},	//   _ኤዲ_, _विनी, _khố_, زيتو, 
   {{0xe8d827dd,0x5ff40137,0xd12c01f7,0xcf8c0014}},	//   _nkọ_, юзду, ضمو_, نژل_, 
   {{0x1ce00135,0xd00c14a0,0x707400ec,0x00000000}},	//   _སིང_, ئلو_, سانذ, --, 
   {{0xe8d8413b,0x2d9412c4,0x46d800dc,0x8d90104c}},	//   _akọ_, прыс, म्यह, ولوش, 
   {{0x5bb4334e,0xfc340023,0x7ed4072d,0x00000000}},	//   ософ, _እትገል, _گزرا, --, 
   {{0xe8d8004d,0x4b8402dd,0x3ab00131,0xdfd0027d}},	//   _nhố_, ойын_, пәйт, _زيا_, 
   {{0xe8d801fb,0xa3e00c6e,0x7ed41046,0x00000000}},	//   _phở_, _दहन_, _دزرا, --, 
   {{0x1ddc1546,0x00000000,0x00000000,0x00000000}},	//   _महित, --, --, --, 
   {{0x60d80175,0xee74030d,0x00000000,0x00000000}},	//   nfwm, _элхь, --, --, 
   {{0xbf840016,0x629401a4,0x77f404af,0x07a01608}},	//   _điển_, _ofzo, इटेक_, маян, 
   {{0x1ddc61b8,0xe8d8001e,0x907802e4,0x9f500066}},	//   _महात, _thở_, יטרי, ébèl_, 
   {{0xd78800ec,0x00000000,0x00000000,0x00000000}},	//   _ھندو_, --, --, --, 
   {{0x62940196,0x76b81945,0x94242133,0xde340023}},	//   _afzo, шһүр_, омбе, _ክንዕወ, 
   {{0xa3e80882,0x39a401ed,0x52a81b38,0xe610004b}},	// [39840] _मनः_, lős_, ивам_, وشې_, 
   {{0x70b46c5a,0x09a8031c,0x55e400d8,0x38b401e1}},	//   ुल्ल, _བསྩ_, _дооб, búrí_, 
   {{0x798401f2,0x00000000,0x00000000,0x00000000}},	//   _kiiw, --, --, --, 
   {{0xe7b00014,0xcf9800d8,0x00000000,0x00000000}},	//   _زۅہد, ајк_, --, --, 
   {{0xd01001d5,0x7524009f,0xf6e8031c,0xeff80023}},	//   بلش_, mkiz, _སྲོང, _ጋህዲ_, 
   {{0x7525fa2a,0x3dc4009a,0x79840254,0x00000000}},	//   lkiz, funw_, _liiw, --, 
   {{0xb05400dd,0x75240083,0x90e401c8,0x37d000eb}},	//   _کھات, okiz, _وسرن, িবির, 
   {{0x7525fa2b,0x7984208d,0x6f0001f1,0x39a401d3}},	//   nkiz, _niiw, _bábä, dős_, 
   {{0x0ed00574,0x4ae402d5,0xfc340023,0x5fd000bc}},	//   _सापड, оўна, _እትፍለ, _समयल, 
   {{0x37d000bd,0x9f4c0c67,0x63a82ac2,0xa0a40117}},	//   িবার, _preå_, _çene, _маӣд, 
   {{0x28f85322,0x7525fa2c,0xaa58009b,0x39a400e5}},	//   бень_, kkiz, сину_, gős_, 
   {{0xe8d807ae,0x7984002e,0x2d8c003a,0xcbf01524}},	//   _phố_, _ciiw, _iude_, _अनपढ_, 
   {{0x6d41fa2d,0x7984de1f,0x2d8c09a8,0xceb80198}},	//   mima, _diiw, _hude_, shƙu_, 
   {{0x2d8c0912,0xa3e0000d,0x00000000,0x00000000}},	//   _kude_, _दहब_, --, --, 
   {{0x858925e5,0x6d40b730,0x00000000,0x00000000}},	//   рёга_, oima, --, --, 
   {{0x69c9fa2e,0x2d8dfa2f,0x79840241,0xe8d8004d}},	//   mude, _mude_, _giiw, _thố_, 
   {{0x2d8c4a1f,0x6b8400ae,0x69c00c70,0xdb0800ae}},	// [39850] _lude_, _éigs, _विडी, lseá, 
   {{0x6d41fa30,0x2d8c0936,0xdc74001f,0x75240083}},	//   hima, _oude_, _የታሪክ_, akiz, 
   {{0x2d8c010a,0xc0e8044e,0xdb087479,0x6ec43f7e}},	//   _nude_, _ዘበለ_, nseá, _राजु, 
   {{0x6d4049f9,0xdb080491,0x7984002e,0xc4c4007b}},	//   jima, iseá, _xiiw, _بتدو, 
   {{0x2d8dfa31,0x6d41fa32,0x69c9fa33,0x30740137}},	//   _aude_, dima, hude, мушс, 
   {{0x2d8dfa34,0x69c8dd34,0x6d40017a,0xfe400133}},	//   _bude_, kude, eima, وکای, 
   {{0x6d41fa35,0x69c9fa36,0x2d8c03f9,0x57f40135}},	//   fima, jude, _cude_, _བླློ_, 
   {{0x6d41fa37,0x69c9fa38,0x2d8dfa39,0xaad807f7}},	//   gima, dude, _dude_, ब्सक, 
   {{0x798402b1,0x29ec0055,0xa0a40220,0x69c8062c}},	//   _riiw, _aśa_, _маңд, eude, 
   {{0x752401c0,0x09a8031c,0x79840694,0x2d8c17a0}},	//   zkiz, _བསྡ_, _siiw, _fude_, 
   {{0x6d41fa3a,0x2d8dfa3b,0xc4c8068f,0x69c9fa3c}},	//   bima, _gude_, िलाओ, gude, 
   {{0xdce82220,0x39a401ed,0x00000000,0x00000000}},	//   dmeć, rős_, --, --, 
   {{0xf6e8025c,0x69c93187,0x46380092,0x00000000}},	//   _སྲུང, aude, _አስገራ, --, 
   {{0x69c87389,0xdb082760,0x2d8dfa3d,0x1ca402f2}},	//   bude, rreó, _yude_, _بێکی_, 
   {{0x798400b0,0x752401a9,0x00000000,0x00000000}},	//   _tiiw, tkiz, --, --, 
   {{0x1a64034c,0x75241418,0x6b8401e7,0x49b8011a}},	//   _ویکی_, ukiz, _éigr, _המקס, 
   {{0x7525fa3e,0xd43c001f,0xe87400db,0x02c428fe}},	// [39860] rkiz, _ተዘጋጅ, _ۉنۉگ, _लाखभ, 
   {{0x7525fa3f,0x8838011a,0x041800cc,0x00000000}},	//   skiz, _לתפו, _নেহী_, --, 
   {{0x672001e6,0x00000000,0x00000000,0x00000000}},	//   ölje, --, --, --, 
   {{0x660000b5,0x2d8c3046,0xdb0800e4,0x98a00064}},	//   ælke, _rude_, ireñ, rikė_, 
   {{0x6d41fa40,0x2d8dfa41,0x69c9fa42,0x4080004e}},	//   vima, _sude_, zude, нушб, 
   {{0x6d400bc9,0x2d8dfa43,0x69c8a89e,0x00000000}},	//   wima, _pude_, yude, --, 
   {{0x6d41fa44,0x10a40cfc,0x69c00b7c,0xdce07234}},	//   tima, _нивн, _विधी, _atlı, 
   {{0x69c9fa45,0x2d8c0286,0x1ce0025c,0xdb08030a}},	//   vude, _vude_, _སྲད_, dreñ, 
   {{0xfd0c0a11,0x69c9fa46,0x6d5c0022,0x7c90009a}},	//   اجى_, wude, _êram, رشيا, 
   {{0x6d41fa47,0x81dc03f4,0x2d8dfa48,0x3f98003a}},	//   sima, তির_, _tude_, íque_, 
   {{0x6d41fa49,0x4c85fa4a,0x2d8c00c5,0x7ac009a5}},	//   pima, _елев, _uude_, хсые, 
   {{0x61e001c7,0x6d4003f0,0xdb0800ae,0x7c5400f2}},	//   _älle, qima, rseá, _کلهر_, 
   {{0x69c9fa4b,0xec34036b,0x60dc00ee,0x3908009d}},	//   sude, _توشگ, _ösme, чээн_, 
   {{0x69c9fa4c,0xdb080789,0xa3bc01ad,0x18180014}},	//   pude, breñ, ींस_, زرُک_, 
   {{0xa4d4dbe2,0x69c8014b,0xcc040014,0x693400f0}},	//   мові, qude, _ذٲژن_, _онку, 
   {{0x092843cd,0x1ce0025c,0x5ec4015b,0xd43c0023}},	//   _دستي_, _སིབ_, ল্পে, _ተመዝጊ, 
   {{0x2909fa4d,0xa2f40153,0x00000000,0x00000000}},	// [39870] _inaa_, мпач, --, --, 
   {{0x1ce00135,0xdee80092,0xe8d80051,0x6abc0332}},	//   _སྲན_, ሙትን_, _thồ_, órfh, 
   {{0xf6e85a4f,0xa3b82232,0x81c40108,0xe5343b8f}},	//   _སྲིང, _घटक_, ящае, _жень, 
   {{0x6f08035a,0x00000000,0x00000000,0x00000000}},	//   _andc, --, --, --, 
   {{0x5f74032f,0xa3e017e6,0x9f35fa4e,0xb97c010f}},	//   واتر, _दहि_, меді, צנדי, 
   {{0xdce0003d,0x82343ee6,0x00000000,0x00000000}},	//   _kulħ, _فرزا, --, --, 
   {{0x2908208d,0x1ce0025c,0x00000000,0x00000000}},	//   _onaa_, _སིད_, --, --, 
   {{0xe8d80016,0x2909fa4f,0xa3e00490,0x6f08a2e5}},	//   _khổ_, _nnaa_, _दहा_, _endc, 
   {{0xdb080008,0x00000000,0x00000000,0x00000000}},	//   freð, --, --, --, 
   {{0x29080605,0xdb09fa50,0x2b90c5ff,0x00000000}},	//   _anaa_, treñ, دیوس, --, 
   {{0x13e46569,0x7f401cdf,0x88dc04c5,0x49c4009d}},	//   নিয়, minq, _বোধক, млэн_, 
   {{0xdb09fa51,0x5fd033af,0x18693005,0x29080356}},	//   rreñ, _समाल, жами_, _cnaa_, 
   {{0x3c400014,0xe8d8004d,0x00000000,0x00000000}},	//   _سێدِ, _nhổ_, --, --, 
   {{0x59c41db2,0x2909fa52,0x7f41fa53,0x344800ee}},	//   _विपर, _enaa_, ninq, җүги_, 
   {{0x212c7020,0xd6280801,0x0c940133,0x00000000}},	//   _oleh_, цове_, _ردۆگ, --, 
   {{0x24f4f026,0x7f4000f1,0xadf0007d,0x00000000}},	//   нчур, hinq, _अईसन_, --, 
   {{0x0440cdea,0x3941fa54,0x61e8041a,0x1ce0025c}},	// [39880] ветн, _imis_, _ćela, _སིན_, 
   {{0x212c0548,0xd7757b5e,0xdb0801bf,0x57480798}},	//   _aleh_, _تابع, sseæ, _фзом_, 
   {{0x212dfa55,0x7f41fa56,0x6abc0174,0xda0c21f6}},	//   _bleh_, dinq, órfi, िमित_, 
   {{0x50640323,0xd04400aa,0xd7d00b7d,0xdb0800d8}},	//   мтла, وپاي, _तमाच, bseç, 
   {{0x39400009,0x7bcc004e,0x7f4003e3,0x00000000}},	//   _mmis_, àcul, finq, --, 
   {{0x212c0438,0x7f400921,0x800801ed,0x527400ee}},	//   _eleh_, ginq, ترمہ_, _жубу, 
   {{0x3941fa57,0xac94d832,0x20000374,0x00000000}},	//   _omis_, найш, āhia_, --, 
   {{0x41000395,0x00000000,0x00000000,0x00000000}},	//   _изсв, --, --, --, 
   {{0x7f40007f,0x69c062be,0x81dc0154,0x21740454}},	//   binq, _विही, তিঃ_, _чурр, 
   {{0x3941fa58,0x7f400622,0x29080493,0x00000000}},	//   _amis_, cinq, _snaa_, --, 
   {{0x8e480597,0x28f9fa59,0x1ce0025c,0x22940241}},	//   _بلاك_, пень_, _སྲམ_, _húkó_, 
   {{0xfd4c01f2,0x212c0ac5,0x0c2400a8,0x00000000}},	//   _mejọ, _xleh_, _омен, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x39900261,0x3941fa5a,0x7bdc2305,0x5c7400fb}},	//   _fãs_, _emis_, _äqua, _яҙыр_, 
   {{0x2908016b,0x00000000,0x00000000,0x00000000}},	//   _tnaa_, --, --, --, 
   {{0x29d81509,0x28884bcf,0xe8d80016,0x7f41fa5b}},	//   méa_, _عصبی_, _phổ_, zinq, 
   {{0xc6a40075,0x7f41fa5c,0x212c0076,0x29d8020c}},	// [39890] _орни, yinq, _rleh_, léa_, 
   {{0xd6c402a6,0x0269fa5d,0x59c416ae,0xdb0800d8}},	//   শ্বয, ошей_, _विमर, rseç, 
   {{0x91c0891e,0x212c0e04,0x29d9fa5e,0x394003b2}},	//   ләтл, _pleh_, néa_, _ymis_, 
   {{0xe8d8001e,0x249800d8,0x7f41fa5f,0xe1640214}},	//   _thổ_, _ufsm_, winq, رضای, 
   {{0x7f41fa60,0x212c0076,0x29d80098,0xdee44eca}},	//   tinq, _vleh_, héa_, еоли, 
   {{0x7df003be,0x69d800d8,0x29d8806d,0x00000000}},	//   _həsə, _oqve, kéa_, --, 
   {{0x7f41fa61,0x212c09a8,0x7df00213,0x00000000}},	//   rinq, _tleh_, _kəsə, --, 
   {{0x7f41fa62,0x29d8020c,0x212cf32c,0xfbd001ad}},	//   sinq, déa_, _uleh_, _दमदम, 
   {{0x7df00cc1,0x7f401730,0x5e5842c2,0x00000000}},	//   _məsə, pinq, _کلاس_, --, 
   {{0xfbc002f5,0x3f9c0ba7,0x7f4003f0,0x69c007b7}},	//   ্বলত, _ituu_, qinq, _विशी, 
   {{0x29d80c6a,0x00000000,0x00000000,0x00000000}},	//   géa_, --, --, --, 
   {{0x5d5400a7,0x3940031c,0x7df003b9,0x86a000fb}},	//   _якет, _qmis_, _nəsə, ңғыҙ, 
   {{0x7d09fa63,0xc83402d3,0x00000000,0x00000000}},	//   _ings, _ኣድማዕ, --, --, 
   {{0xac75fa64,0x8c1802e4,0x7bd8198f,0x61f401d3}},	//   _شانش, _מוני, mtuu, _oszl, 
   {{0x7bd9fa65,0x3f9c0270,0x672001e6,0x29d87d9b}},	//   ltuu, _ltuu_, ölja, céa_, 
   {{0x3f9c0a55,0x394001e4,0x7bd804ba,0x7df00213}},	//   _otuu_, _umis_, otuu, _cəsə, 
   {{0xb48401e0,0x1304022e,0x53c80600,0x00000000}},	// [398a0] ткаһ, нзам, ягам_, --, 
   {{0x7d08008b,0x44600798,0x00000000,0x00000000}},	//   _lngs, увув, --, --, 
   {{0x3f9dfa66,0xe8d80016,0x7bd802f6,0x7d080c8c}},	//   _atuu_, _chỗ_, htuu, _ongs, 
   {{0x7bd9fa67,0x7ae001ab,0x229402d2,0x2be0000d}},	//   ktuu, _lbnt, _púkó_, _कहलू_, 
   {{0xd4340597,0xb3840131,0xf3840220,0xe08400ec}},	//   _أعجب, _аһал, _ағам, نجهي, 
   {{0x9f4c0421,0x69c01408,0xe1f000e5,0x00000000}},	//   _aseâ_, _विली, دسے_, --, 
   {{0x3f9c013f,0x7d08003e,0x7bd9fa68,0xfeb42a9f}},	//   _etuu_, _bngs, etuu, راوت_, 
   {{0x7ae00223,0x7bd9fa69,0x068400d1,0x29d8753e}},	//   _abnt, ftuu, ﯩﺮﯨﮕ, véa_, 
   {{0xcb4470df,0x7ae001e0,0x7bd81c04,0x29d80066}},	//   ехни, _bbnt, gtuu, wéa_, 
   {{0x20180137,0xdbcc0022,0xc438011a,0x3b500139}},	//   _àsia_, _añóg, פתיי, лкыр, 
   {{0xc331214c,0x7bd8d430,0xfc2c3c46,0x00000000}},	//   רות_, atuu, لحی_, --, 
   {{0x29d9fa6a,0x7bd97348,0xe9d80137,0x1dc00139}},	//   réa_, btuu, пкү_, _төшн, 
   {{0x7bd9fa6b,0x29d8032b,0x7df003e3,0x00000000}},	//   ctuu, séa_, _rəsə, --, 
   {{0x941c0134,0xc6a400ee,0x29d9fa6c,0x6d5c00b8}},	//   _ɛtɔ_, эрми, péa_, _īray, 
   {{0x7d09fa6d,0x09a8031c,0x77845aae,0x00000000}},	//   _yngs, _བསྲ_, улёз, --, 
   {{0x59c41025,0xc4c811b1,0x7df000ac,0x3568004e}},	//   _वितर, िलेख, _qəsə, ерун_, 
   {{0x784428fc,0x00000000,0x00000000,0x00000000}},	// [398b0] _бээж, --, --, --, 
   {{0x69c9fa6e,0x68fdfa6f,0x27e9fa70,0x29180427}},	//   orde, ldsd, _ipan_, ljsa_, 
   {{0x7df003be,0x7a280793,0x25b81913,0x00000000}},	//   _təsə, mötö, _تهجد_, --, 
   {{0x27e80263,0x09a8031c,0x628002f0,0x29180010}},	//   _kpan_, _བསླ_, _úlom, njsa_, 
   {{0x656cc492,0x69c9fa71,0x68fc0f49,0x7bd9fa72}},	//   mlah, hrde, idsd, xtuu, 
   {{0x27e8016b,0xd00504f2,0xdee4c6c2,0x00000000}},	//   _mpan_, теше_, токи, --, 
   {{0x7d0801fa,0xeff802d3,0x7bd8011f,0xb35406ed}},	//   _pngs, _ወደይ_, wtuu, _скрш, 
   {{0x7bd8360c,0x656c0455,0x27e80428,0x68fc1cf1}},	//   ttuu, nlah, _opan_, jdsd, 
   {{0x69c94c79,0x7a284c88,0xdbcc0086,0x3f9c22a9}},	//   erde, kötö, _añòg, _utuu_, 
   {{0x7bd9fa73,0x656dfa74,0x59c438db,0x05780092}},	//   rtuu, hlah, _विदर, _በጥበብ_, 
   {{0x7bd9f1cf,0x27e9fa75,0x98a5fa76,0x656d59c0}},	//   stuu, _apan_, кине, klah, 
   {{0x27e801ab,0xd945fa77,0x7d086e8a,0x26c12a48}},	//   _bpan_, теми, _ungs, _adho_, 
   {{0x656dfa78,0x69c80af4,0x7bd80cfe,0x3f880129}},	//   dlah, arde, qtuu, _écus_, 
   {{0x27e80a2e,0x66040427,0x656c058a,0x68fc035a}},	//   _dpan_, _brhk, elah, adsd, 
   {{0x63bc4e97,0x27e80086,0x9a6800c6,0x656dfa79}},	//   _avsn, _epan_, _تمثل_, flah, 
   {{0x656dfa7a,0x9e780023,0x98a00064,0x0f1c09ab}},	//   glah, _ብንስሓ_, mikį_, _बक्स_, 
   {{0x63a809a5,0x63c401e0,0x00000000,0x00000000}},	// [398c0] _çenl, латҡ, --, --, 
   {{0x656c01d9,0x1cb0031c,0x5778007b,0x200800df}},	//   alah, _དབའ_, _تصبح_, ĥail_, 
   {{0x656d9e5d,0x41b0036b,0x25a00051,0x98a00064}},	//   blah, لملر, _gthl_, nikį_, 
   {{0x4fc5fa7b,0xdb1800d2,0xd0246128,0x656c0014}},	//   вска, _dvwé, кмей, clah, 
   {{0x7ff0ad6b,0xb4c003f3,0xc0540220,0x64740276}},	//   لسوا, ीली_, кіш_, _бырф, 
   {{0x2c6c00ae,0xadd80108,0xd1c800f3,0x00000000}},	//   hódú_, емку_, _олге_, --, 
   {{0x434000a7,0x00000000,0x00000000,0x00000000}},	//   _терв, --, --, --, 
   {{0x98a00024,0x00000000,0x00000000,0x00000000}},	//   dikį_, --, --, --, 
   {{0x9f4c2760,0x5fc85d4f,0x6d5c0022,0x7a2802fc}},	//   _creó_, _रियल, _íram, yötö, 
   {{0x27e8083a,0x29a40124,0x8f7412fa,0xef180171}},	//   _rpan_, лымҳ, _рубі, _piļu_, 
   {{0x27e88c75,0x69c8225e,0x656dfa7c,0x00000000}},	//   _span_, urde, ylah, --, 
   {{0x1cb00003,0xdde82be7,0x290c01c6,0x68fc01f5}},	//   _དབར_, _سرمه_, ñea_, udsd, 
   {{0x656c016d,0x68fdfa7d,0xcc140a8e,0xc7c400a7}},	//   vlah, rdsd, _جذاب, ъсни, 
   {{0x656dfa7e,0xbb40bd8c,0x6604107d,0xaa580815}},	//   wlah, _кечк, _prhk, _пилу_, 
   {{0x80d01533,0x27e80076,0x7a286c3f,0x656dfa7f}},	//   _डाले, _wpan_, rötö, tlah, 
   {{0x656d4b5b,0x644000ac,0xd4f401c6,0x00000000}},	//   ulah, _əlif, лжсө, --, 
   {{0x656dfa80,0x1cb00135,0x27e80c6a,0x0ed00073}},	// [398d0] rlah, _དབལ_, _upan_, _सांड, 
   {{0x656dfa81,0x6fcc0490,0xe4e40131,0xc76402de}},	//   slah, _समजू, _өсмү, _جابى, 
   {{0x656dfa82,0xe8d80208,0xc32c1884,0xdb080332}},	//   plah, _nhừ_, مەڭ_, tseú, 
   {{0x59c41cb7,0x1fb800fd,0x656c016d,0xe618009d}},	//   _विसर, елды_, qlah, _ждү_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x543800c8,0xa2a801d9,0x64a400c7,0x3cac00fe}},	//   _טערא, _سُرٕ_, _шаҭа, _টাইৱ, 
   {{0x02ac16da,0xe8d8004d,0x62340107,0xb2840064}},	//   टरीन, _chừ_, _севу, _вытк, 
   {{0x9f4c4d72,0xdb080fac,0x63a80327,0x00000000}},	//   _creò_, lseø, _ħenj, --, 
   {{0xa0540953,0x59c400dc,0xf10800db,0x00000000}},	//   _сваі, _विहर, _جۉنۉ_, --, 
   {{0x9f4c08e7,0xdd942503,0xdb0803cd,0x00000000}},	//   _ereò_, _бажы, nseø, --, 
   {{0x5cd47146,0x59846ec2,0xaad400cd,0x00000000}},	//   _مقاط, ллоб, _दारक, --, 
   {{0x3944068c,0x17c801d5,0x00000000,0x00000000}},	//   òms_, нгми_, --, --, 
   {{0x1ae5fa83,0x59c43fec,0x7d180162,0x7c8414b3}},	//   _болм, _विवर, mjus, _руже, 
   {{0x3cfc0037,0x00000000,0x00000000,0x00000000}},	//   lduv_, --, --, --, 
   {{0xceb06da4,0x62802195,0x57240075,0x7c380407}},	//   מים_, _úloh, نىڭك, lzur, 
   {{0xb4c07b05,0x69dc0137,0x1cb0031c,0x3cfc0037}},	//   ीले_, àree, _དབས_, nduv_, 
   {{0x7c38f324,0xa3bc0490,0x66000158,0x03a1567f}},	// [398e0] nzur, ींग_, ålkr, йито, 
   {{0x7d19fa84,0x96a80139,0xdce80010,0x0ed03507}},	//   hjus, _якоб_, dleč, _साइड, 
   {{0x65c0005e,0x7d180252,0x7c3803e0,0x00000000}},	//   _мұра, kjus, hzur, --, 
   {{0x7d18a9bb,0x00000000,0x00000000,0x00000000}},	//   jjus, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7c38006f,0x7d183e9d,0x00000000,0x00000000}},	//   dzur, ejus, --, --, 
   {{0x6d5c08a5,0x00000000,0x00000000,0x00000000}},	//   _írak, --, --, --, 
   {{0x42507f51,0x8678008f,0x7c380e78,0xdce9fa85}},	//   _انفر, ערקו, fzur, bleč, 
   {{0xcce40150,0x6440012d,0x00000000,0x00000000}},	//   _ەستي, _śliz, --, --, 
   {{0x7d180869,0x7528000f,0xe8d80208,0xdb0c0241}},	//   ajus, êdzj, _thừ_, _èjìd, 
   {{0xaa59fa86,0x39b405f5,0xe944fc15,0xbf1000f7}},	//   тину_, ллээ_, لرحی, _دولب, 
   {{0xe8d8001e,0x050c03d4,0x7d18012d,0xe7cc0150}},	//   _khứ_, _সত্ৰ_, cjus, _ﺑﻪﺭﻟ, 
   {{0x69c00e49,0x7c38033f,0x63a00419,0x2fc000ae}},	//   _विकी, czur, _člno, áigh_, 
   {{0x7bf80302,0x1cb0031c,0x4ab800a7,0x644003b9}},	//   _נפוצ, _དབོ_, _чудя_, _əlid, 
   {{0xdce8ef6b,0x00000000,0x00000000,0x00000000}},	//   zleč, --, --, --, 
   {{0xbb2c0952,0x44380334,0xe454064e,0x00000000}},	//   ﺩﺍﻡ_, tzq_, акбы, --, 
   {{0xb8d42309,0x47880b3b,0x02a426b1,0xe8d80051}},	// [398f0] _اتىش, _псом_, грем, _nhứ_, 
   {{0xdce9e2bf,0x33844bea,0x44380334,0x00000000}},	//   vleč, бухв, rzq_, --, 
   {{0x7c380395,0xdce80e3c,0x762801a9,0x00000000}},	//   zzur, zmeđ, _бўяб_, --, 
   {{0x7c380034,0xdce8388e,0x1cb00327,0xdb085522}},	//   yzur, tleč, _དབེ_, sseø, 
   {{0xe8d807ae,0xa29400d6,0x657c02d0,0xa2dc00cd}},	//   _chứ_, _вагі, _ihsh, _पाप्, 
   {{0x2f1807d8,0x70941086,0xdce80427,0x00000000}},	//   лочь_, _ғафф, rleč, --, 
   {{0xf2040801,0x7d18023a,0xdce80427,0x00000000}},	//   _лято, tjus, sleč, --, 
   {{0x7c39fa87,0x1ea805d9,0x7d19fa88,0xdce84a38}},	//   tzur, راڻي_, ujus, pleč, 
   {{0x75ec066d,0x7d19fa89,0x7c38009f,0x09a8031c}},	//   _közö, rjus, uzur, _བསྔ_, 
   {{0xff51b258,0x9f4c030a,0x7c380112,0x5a94023b}},	//   _اخر_, _treñ_, rzur, шриф, 
   {{0xa2dc3cbe,0xece80220,0x7ae4004b,0x657c01d5}},	//   _पान्, _әділ_, نوکې_, _ohsh, 
   {{0xbb2c005e,0x657c01ab,0x7d180003,0x00000000}},	//   ﺩﺍﻥ_, _nhsh, qjus, --, 
   {{0xeb9801ec,0x00000000,0x00000000,0x00000000}},	//   _биі_, --, --, --, 
   {{0x657c03ac,0xe6d401c6,0x38780092,0xcc38010f}},	//   _ahsh, йцсэ, _በዕለቱ_, _בענט, 
   {{0x18a41925,0x645c2bcc,0x98a400cf,0x644006be}},	//   _кайм, _axsi, _кийе, _əlie, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdbcc0086,0x9345fa8a,0x00000000,0x00000000}},	// [39900] _eñög, анае, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x645d700a,0x00000000,0x00000000,0x00000000}},	//   _exsi, --, --, --, 
   {{0x355401d9,0xcfa45a06,0x1c1401ad,0x8658011a}},	//   _اۆرز, ашки, तमाल_, _ידיי, 
   {{0x31ac007f,0x09a80135,0xfcc80092,0x2fc05821}},	//   _bòzò_, _བསྐ_, _በስጋ_, éig_, 
   {{0x671846fb,0xaf70001f,0xaad400bc,0x75ec0bbc}},	//   दायक_, _ቤቶችና_, _दाइक, _gözö, 
   {{0xd1e80092,0x00000000,0x00000000,0x00000000}},	//   መቶች_, --, --, --, 
   {{0xe8d807ae,0x2d98e20f,0x412400f3,0x8d846c68}},	//   _thứ_, _érem_, _косо_, шулд, 
   {{0x61e80989,0x25ac01fa,0x4125fa8b,0xbd843592}},	//   _ćeli, ćeli_, _тото_, جنين_, 
   {{0x8ca406ab,0x68400023,0x00000000,0x00000000}},	//   _ट्रो, _ኣስማት, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x0c840372,0x2d9c003a,0x64400213,0x00000000}},	//   _кылм, mqve_, _əlib, --, 
   {{0x27edfa8c,0x628002fb,0x290400bc,0x8b94084c}},	//   ïen_, _úlov, ěla_, _треч, 
   {{0x6cb40032,0x2904033f,0x657c0200,0x63a845d8}},	//   _төҫт, śla_, _shsh, _çeni, 
   {{0x25a42ec8,0x09a8025c,0xa3d80490,0x2d84005b}},	//   ëll_, _བསྒ_, ठून_, omme_, 
   {{0x02ac353b,0x00000000,0x00000000,0x00000000}},	//   टर्न, --, --, --, 
   {{0xb5c00ed1,0x2d84023a,0xfa00031c,0x86e401b9}},	// [39910] ﺭﮔﯩﺰ, imme_, _མནོན_, _кўнд, 
   {{0x02a5fa8d,0x48e00c5a,0xd9ec00ab,0xba0000b7}},	//   ррам, ट्रो_, _जहमत_, _ሌባ_, 
   {{0xa2dc9201,0x2d9c0200,0x00000000,0x00000000}},	//   _पाठ्, jqve_, --, --, 
   {{0x67240455,0x657c01d5,0x00000000,0x00000000}},	//   _hohj, _uhsh, --, --, 
   {{0x838445b3,0x50a00075,0x75ec013d,0x00000000}},	//   _выве, سەلل, _tözö, --, 
   {{0x2d84023a,0xb36400a7,0x9f0401d3,0x7bdc0112}},	//   emme_, _дъск, صوبو, _äqui, 
   {{0x67240455,0x2d941e76,0xe8d80208,0x9eb400c7}},	//   _mohj, орыс, _nhữ_, ашқә, 
   {{0x09a8025c,0x7ff404fb,0x6724023a,0xf6580375}},	//   _བསྟ_, _پسرا, _lohj, יסוי_, 
   {{0x5f9475b0,0x1ae4004e,0x00000000,0x00000000}},	//   _طلائ, бопм, --, --, 
   {{0x7de410f5,0x2d8402f6,0xada40030,0x67240455}},	//   _відд, amme_, _spĺň, _nohj, 
   {{0xe8d807ae,0x6f1c067c,0xb3a80154,0x00000000}},	//   _chữ_, _òrca, _ওয়াজ, --, 
   {{0xfd200133,0xdec801f0,0x97d8117e,0x1bd401f4}},	//   _گوڵێ, _шуғл_, льгу_, _годя, 
   {{0x0c940150,0xfc6400a7,0x644006be,0x7ac0014b}},	//   _ادمگ, _тъжн, _əlic, _дилҷ, 
   {{0x6d50033f,0xdb0800db,0x2bdc024a,0xceb000df}},	//   ądał, nseü, _ममता, ּין_, 
   {{0x5fd00037,0x5908004e,0x00000000,0x00000000}},	//   _समझल, _бейм_, --, --, 
   {{0x744c001f,0xd468009b,0x5894010a,0x00000000}},	//   _በመፍጠ, гибе_, _ушку, --, 
   {{0xf4843c5b,0xeb340014,0x00000000,0x00000000}},	// [39920] زاری, _دى۪د, --, --, 
   {{0xa2dd2bb7,0x5fd00490,0x00000000,0x00000000}},	//   _पाण्, _समजल, --, --, 
   {{0x2d8408ae,0x00000000,0x00000000,0x00000000}},	//   ymme_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd37003e6,0x9878008f,0x356c0240,0x00000000}},	//   _فێرک, װאַט, _ደሴታት_, --, 
   {{0x03a033a6,0x2ca0003d,0xecb4009e,0xfae41291}},	//   _хиро, _żid_, _টাইড, _عث_, 
   {{0xa2dc6236,0x10a40108,0x00000000,0x00000000}},	//   _पात्, _гибн, --, --, 
   {{0xc0e1fa8e,0xdb18007f,0x2d9c0240,0x386001b9}},	//   _носк, _avwà, rqve_, _oxir_, 
   {{0x88b4015b,0xeb386bce,0x63a00419,0x00000000}},	//   _ঝালক, изиш_, _člnk, --, 
   {{0xb0d80b26,0x00000000,0x00000000,0x00000000}},	//   _डाँग, --, --, --, 
   {{0x99500316,0x3860036b,0x672401f4,0x3a70008e}},	//   lář_, _axir_, _rohj, злэр, 
   {{0x48a9fa8f,0x9fc4035b,0x6725fa90,0x00000000}},	//   ытом_, _уҳәа_, _sohj, --, 
   {{0x6725fa91,0xc8642c71,0x9950012c,0x1aec02f5}},	//   _pohj, стни, nář_, জয়ে_, 
   {{0x7bd8010f,0x795801ec,0xe8d80051,0xa2dc0c22}},	//   _עקוו, _қиыр_, _thữ_, _पाध्, 
   {{0xde4836bc,0x3860070d,0x057474dd,0xa5f800f3}},	//   _እንደገ, _exir_, مارد, шеву_, 
   {{0x78a40270,0xe8d801fb,0x61e0005b,0x99500118}},	//   _gfiv, _khử_, _älli, kář_, 
   {{0x6725fa92,0x6d5c08a5,0xa2dc1408,0x9950013a}},	// [39930] _tohj, _írau, _पाद्, jář_, 
   {{0x9950013a,0x00000000,0x00000000,0x00000000}},	//   dář_, --, --, --, 
   {{0xf7740a7c,0x00000000,0x00000000,0x00000000}},	//   _מקץ_, --, --, --, 
   {{0x88b400eb,0x00000000,0x00000000,0x00000000}},	//   _ঝাঁক, --, --, --, 
   {{0x68ed15f5,0xe8d8312b,0x38600a73,0xf77003e6}},	//   _mbad, _ajị_, _xxir_, _زای_, 
   {{0x7a3c066d,0xf650066d,0x250400b8,0x00000000}},	//   _játé, _آئی_, baṣṭ, --, 
   {{0x63adfa93,0x62040014,0xdb08030a,0x9d4401ec}},	//   lpan, _بوزٕ, rseü, жейд, 
   {{0x63ac696c,0xa159fa94,0x644802d2,0x9950013a}},	//   opan, _табу_, _þeis, bář_, 
   {{0x60c9fa95,0x63adfa96,0x6aa46f38,0xde480020}},	//   _idem, npan, _şifa, _እንዲገ, 
   {{0x200d06c9,0xb1780008,0x63ac009f,0xf0000131}},	//   _irei_, _þórð, ipan, _чүши, 
   {{0x68ec00c6,0x63adfa97,0x200c0165,0x61e5fa98}},	//   _bbad, hpan, _hrei_, nthl, 
   {{0x63adfa99,0x200c00c8,0x61e5fa9a,0x3f840175}},	//   kpan, _krei_, ithl, lmnu_, 
   {{0x06e002a6,0x60c800d8,0x63ac01e4,0x59c4146b}},	//   য়নি, _mdem, jpan, _विकर, 
   {{0x68edfa9b,0xdce00139,0x8f9808a8,0x00000000}},	//   _ebad, _iulı, יישי, --, 
   {{0x60c9fa9c,0x23d40327,0x63ac00d7,0x85b0013d}},	//   _odem, ུངའཕ, epan, мәяч, 
   {{0x61e400c6,0x60c9fa9d,0x68ecacd9,0x78a40618}},	//   dthl, _ndem, _gbad, _ufiv, 
   {{0x63ac22b9,0xccf09b62,0xdec81772,0x61e40042}},	// [39940] gpan, וכן_, በሉን_, ethl, 
   {{0x60c9fa9e,0x68edfa9f,0x99500118,0x00000000}},	//   _adem, _zbad, vář_, --, 
   {{0x63ac00c6,0x200c00e4,0x94840993,0xe7f80139}},	//   apan, _arei_, сыңд, _käşä, 
   {{0x63ac02fa,0x200dfaa0,0x3f840ba7,0x995000bc}},	//   bpan, _brei_, emnu_, tář_, 
   {{0x200dfaa1,0x60c926bf,0xf2cc0154,0x61e424b6}},	//   _crei_, _ddem, র্ষণ, athl, 
   {{0x60c9faa2,0x200c0639,0x185c001f,0x99500118}},	//   _edem, _drei_, _ወንድሞ, rář_, 
   {{0x644800fc,0x200dfaa3,0xdce00139,0x995000bc}},	//   _þeir, _erei_, _aulı, sář_, 
   {{0xdce01248,0x200c103d,0xbd840451,0x00000000}},	//   _bulı, _frei_, ينون_, --, 
   {{0x200dbd2c,0x0ba80b8c,0xff2401ed,0x8538010f}},	//   _grei_, جابى_, _ڈبلی, יגקי, 
   {{0x68ecf596,0x60c821ed,0x8d1800ec,0x00000000}},	//   _sbad, _zdem, _ھزار_, --, 
   {{0xa2dc190e,0xe7f80166,0x63adfaa4,0xe8d80051}},	//   _पास्, _bäşä, zpan, _nhợ_, 
   {{0x63adfaa5,0xe8d807ae,0x68ec031c,0x4c680139}},	//   ypan, _thử_, _qbad, _киен_, 
   {{0x63ac010a,0x9ba0ba6e,0x81b403f9,0xe7f80139}},	//   xpan, _كەيى, ɓɓuk, _däşä, 
   {{0xe8d80241,0xdb08067c,0x61e4015d,0x63ac0254}},	//   _ijọ_, sseò, ythl, vpan, 
   {{0xbb8145d2,0xe8d80016,0x63add1aa,0x6d5dfaa6}},	//   _تلوي, _chợ_, wpan, _íras, 
   {{0x63ac0882,0x68edfaa7,0xdce00724,0xe4994194}},	//   tpan, _ubad, _yulı, скач_, 
   {{0xa3b400c5,0x5ec40154,0x00000000,0x00000000}},	// [39950] छीं_, ল্টে, --, --, 
   {{0x63adfaa8,0x00000000,0x00000000,0x00000000}},	//   rpan, --, --, --, 
   {{0xe7f80598,0x63adfaa9,0x200c020c,0xb1e40116}},	//   _yäşä, span, _srei_, мәтқ, 
   {{0x61e5faaa,0x200dfaab,0xa0c40b24,0xe7f80139}},	//   rthl, _prei_, سيتو, _xäşä, 
   {{0xf0e820ea,0x63ac0357,0x656c0170,0xe8d80521}},	//   تىنى_, qpan, moah, _njọ_, 
   {{0xd00dfaac,0x200c00a8,0x656c0032,0x5398011a}},	//   الو_, _vrei_, loah, _לישו, 
   {{0xe8d80521,0x31c41614,0xdce00724,0xa4f80327}},	//   _ajọ_, _оств, _sulı, _ཕྲོག_, 
   {{0x200dfaad,0x644003be,0x6b880d27,0x60c86394}},	//   _trei_, _əlin, emdg, _udem, 
   {{0xdce000fd,0xe7f80166,0xdfd15ae2,0x5ba80114}},	//   _qulı, _räşä, _سيا_, љком_, 
   {{0x656dfaae,0x0b4002d5,0x1b4801a9,0x00000000}},	//   hoah, еньн, ёзни_, --, 
   {{0x656ce4a0,0xed0400ec,0x9ed80117,0x00000000}},	//   koah, _ڊولپ, _вмҷт_, --, 
   {{0xdce00724,0xe7f80139,0x00000000,0x00000000}},	//   _tulı, _qäşä, --, --, 
   {{0xad246923,0x4c98011a,0x00000000,0x00000000}},	//   _تىنى, _הבנו, --, --, 
   {{0x93f8002e,0x00000000,0x00000000,0x00000000}},	//   _b胃nn, --, --, --, 
   {{0x656c05da,0x69040267,0x06800798,0x00000000}},	//   foah, ötdä, егрн, --, 
   {{0xe9a8b8c6,0x656c02b5,0x5894013d,0xe3b00014}},	//   _بدون_, goah, _эшку, چرٕ_, 
   {{0x7984079b,0xa2dc9856,0x00000000,0x00000000}},	// [39960] _ihiw, _पाश्, --, --, 
   {{0xe8d8001e,0x10e40150,0x77940133,0x02c000f5}},	//   _thợ_, _ﺍﻤﺘﻨ, _زیزا, ейфо, 
   {{0xa2dca05b,0x656c06d9,0xe2a9faaf,0x00000000}},	//   _पार्, boah, تاقن_, --, 
   {{0x2ca401a9,0x068c00d1,0x00000000,0x00000000}},	//   xcmd_, _ﻛﯜﻧﯩ, --, --, 
   {{0x64580589,0xe7c0005e,0xe474084c,0x00000000}},	//   ºwie, ﻣﻴﺎﻟ, _журэ, --, 
   {{0x439002d5,0x00000000,0x00000000,0x00000000}},	//   _паўс, --, --, --, 
   {{0x6aa403e0,0x4e9401d9,0xcd4801c6,0x00000000}},	//   _şifo, _ہشار, йчид_, --, 
   {{0x7524015c,0x9c7c0421,0xc5f005d0,0x63c4008e}},	//   njiz, igōf, גדה_, _ätnä, 
   {{0x4e952a77,0xe8d8004d,0x644003b9,0x5fc80210}},	//   _فشار, _nhỡ_, _əlio, _रिएल, 
   {{0x798400b0,0x7524026c,0x656c009f,0xa54c0092}},	//   _ahiw, hjiz, zoah, _በወንጀ, 
   {{0x75242ebc,0x656c01f7,0xfb3001c6,0xdb080d12}},	//   kjiz, yoah, хнээ, rseð, 
   {{0x7985fab0,0xdb18007f,0x0d84ec37,0x2bd445c7}},	//   _chiw, _avwä, _элен, _दिपा, 
   {{0x656c0170,0x79840066,0xa2dc4108,0x249801bf}},	//   voah, _dhiw, _पाल्, _rgsm_, 
   {{0x25a40789,0x59c41fe7,0x6d400165,0x6b880175}},	//   íllo_, _विचर, lhma, qmdg, 
   {{0x79841682,0x249805b1,0x656c02b5,0x00000000}},	//   _fhiw, _pgsm_, toah, --, 
   {{0x1cb0025c,0x2d98004e,0x75240240,0x6d410ae4}},	//   _དབབ_, _éreu_, gjiz, nhma, 
   {{0x656dfab1,0x9c7c0421,0x00000000,0x00000000}},	// [39970] roah, agōf, --, --, 
   {{0x2bd4107c,0x79840198,0x656dfab2,0x6600005c}},	//   _दिना, _zhiw, soah, ælks, 
   {{0x6514066d,0x6d406e7a,0x91c06023,0x656c2a8f}},	//   _ہوگئ, khma, кәтл, poah, 
   {{0x656c01e0,0x75240009,0x00000000,0x00000000}},	//   qoah, cjiz, --, --, 
   {{0x6d41fab3,0x1fc4013e,0x00000000,0x00000000}},	//   dhma, фреҳ, --, --, 
   {{0x64400213,0xb2d8013d,0x41e40153,0x00000000}},	//   _əlil, _çıpç, _ніба, --, 
   {{0x4175fab4,0xd344036b,0x6ec401b9,0x00000000}},	//   _فارس, _تیله_, رتوق, --, 
   {{0x6d41fab5,0x5ba8ea45,0x47b000cc,0x43c89c97}},	//   ghma, оким_, _জিনী, _ﺗﻪﯕﺪ, 
   {{0x7984015d,0x00000000,0x00000000,0x00000000}},	//   _rhiw, --, --, --, 
   {{0x1a6431d6,0x7985fab6,0x6d41fab7,0x3f800131}},	//   ویشی_, _shiw, ahma, _яғла, 
   {{0x798402d1,0x8d600092,0xcf440116,0x00000000}},	//   _phiw, ቶቻቸው_, _تىلۋ, --, 
   {{0x6d41fab8,0x79840309,0x00000000,0x00000000}},	//   chma, _qhiw, --, --, 
   {{0xba740f01,0x1ae40220,0x6c740354,0x2bd4023e}},	//   _کاشت, _жолм, _пушх, _दिया, 
   {{0x79840053,0x99d4072d,0x00000000,0x00000000}},	//   _whiw, _قتبا, --, --, 
   {{0x7985fab9,0x7524017a,0x46a001a9,0x15a00220}},	//   _thiw, tjiz, тасв, _ﻋﺎﺷﯩ, 
   {{0x79840069,0x2bd4228d,0xd6280107,0x589400db}},	//   _uhiw, _दिमा, боҳе_, _ошпу, 
   {{0x1304013e,0x1cb0031c,0x45fc0327,0x00000000}},	// [39980] мзам, _དབན_, _ཝརྨས_, --, 
   {{0x3b05faba,0x00000000,0x00000000,0x00000000}},	//   _janq_, --, --, --, 
   {{0x3b042e95,0x4718010f,0x2604012d,0x0b300092}},	//   _manq_, _וויג, _हैपी_, _ይገባኛ, 
   {{0x3b040113,0x70d80490,0x2d8c0220,0x6d400200}},	//   _lanq_, डलेल, _ﺗﺎﻋﻰ_, xhma, 
   {{0x2f180dce,0x48e01025,0x3cf0090a,0x00000000}},	//   золь_, ट्टो_, ्जने_, --, 
   {{0x2bd401ad,0x2ec809fa,0x6d4002d0,0x00000000}},	//   _दिबा, रणेत, whma, --, 
   {{0x6d41fabb,0x90c41f89,0x644000ac,0x273c01e1}},	//   thma, _обве, _əlim, _jìna_, 
   {{0xc1b00166,0x853800df,0x00000000,0x00000000}},	//   _рәфы, ַגיי, --, --, 
   {{0x7ae001e0,0x6d40003e,0xc9a00150,0x00000000}},	//   _bcnt, rhma, _ﺍﻟﺸﻙ_, --, 
   {{0x6d41fabc,0xfe6c01d3,0x00000000,0x00000000}},	//   shma, اگے_, --, --, 
   {{0x3b040369,0x6d406cb5,0x00000000,0x00000000}},	//   _danq_, phma, --, --, 
   {{0x6f080477,0x67d41606,0x00000000,0x00000000}},	//   _hadc, ному, --, --, 
   {{0x3b040de2,0x8b240261,0xead40139,0x65c400c7}},	//   _fanq_, _одде, _золь, _oïhá, 
   {{0x3b05fabd,0xdce808a4,0x6f08014f,0x490c0037}},	//   _ganq_, tleć, _jadc, _तोरो_, 
   {{0x6f0806f2,0xbb5004ce,0xe8d8004d,0xf79402d5}},	//   _madc, _webマ_, _nhủ_, тарэ, 
   {{0x69c9fabe,0x6f0837c5,0x00000000,0x00000000}},	//   msde, _ladc, --, --, 
   {{0x6b980cfe,0xdce808ad,0x69c9fabf,0x1c1000ab}},	// [39990] _kivg, sleć, lsde, ़ियल_, 
   {{0x68fdfac0,0xdb0806ed,0x27e80784,0x6f09fac1}},	//   lesd, mpeã, _iqan_, _nadc, 
   {{0xe8d801dc,0x69c913bc,0x6b980477,0xf6e400c7}},	//   _chủ_, nsde, _mivg, _рцын, 
   {{0xa9e00729,0x66040986,0x68fc127b,0x00000000}},	//   _বনাঞ, _ishk, nesd, --, 
   {{0xe3b8031c,0x26c1fac2,0xb97c0a1e,0x00000000}},	//   _བསྲང, _keho_, קנדי, --, 
   {{0x26c18c80,0x5de5fac3,0x69c9bddf,0x6f09fac4}},	//   _jeho_, ежка, ksde, _cadc, 
   {{0x26c0aaf3,0x68fc713c,0x6f0870d4,0x25a0005c}},	//   _meho_, kesd, _dadc, _juhl_, 
   {{0x69c9fac5,0x26c1fac6,0x3b04968b,0x68fc01a4}},	//   dsde, _leho_, _sanq_, jesd, 
   {{0x6b9807c5,0x68fcc35e,0x6f080332,0x00000000}},	//   _bivg, desd, _fadc, --, 
   {{0xe3b80003,0x660407d6,0x26c0e372,0x9b0407a5}},	//   _བསླང, _oshk, _neho_, хзод, 
   {{0x212c0093,0x27e8bdb8,0x6b99fac7,0xceb4013d}},	//   _koeh_, _aqan_, _divg, _чәч_, 
   {{0x68fdfac8,0x63bc035a,0xada401af,0x00000000}},	//   gesd, _owsn, _раїл, --, 
   {{0x6605fac9,0x26c00280,0x07a0497a,0x69c9faca}},	//   _ashk, _beho_, лаян, asde, 
   {{0x6b9808cd,0xeb980220,0xdb0800c5,0x25a0005c}},	//   _givg, _жиі_, tseõ, _buhl_, 
   {{0xd6280801,0x69c8c2c2,0x26c1facb,0x68fc0857}},	//   чове_, csde, _deho_, besd, 
   {{0x0524084c,0x68fc127b,0xdb1401e1,0xdc940092}},	//   носк_, cesd, _ńbèr, _መታሰር_, 
   {{0x39402819,0x6605facc,0x95840150,0x00000000}},	// [399a0] _ilis_, _eshk, _үлпе, --, 
   {{0x39400457,0xe8d80016,0x26c0003b,0x5fc85d4f}},	//   _hlis_, _phủ_, _geho_, _रिजल, 
   {{0x6f09facd,0x212c0098,0x39401a48,0x63bc0c8c}},	//   _radc, _boeh_, _klis_, _ewsn, 
   {{0x0cd8045e,0x0654008f,0x64580210,0x00000000}},	//   _দস্ত, _טייך_, źwia, --, 
   {{0x7bcd12c0,0xed50034c,0x26c025be,0x6f09face}},	//   ácul, یپت_, _yeho_, _padc, 
   {{0xe8d9facf,0x394000db,0x69c80ea0,0x6f08047e}},	//   _thủ_, _llis_, ysde, _qadc, 
   {{0x7bc9fad0,0x3941fad1,0xbea40451,0x6f080455}},	//   _avgu, _olis_, رهين_, _vadc, 
   {{0xd174e88a,0x68fc02c4,0x63a80798,0x6f08058a}},	//   _чыгы, xesd, _éenc, _wadc, 
   {{0x68fdfad2,0x0c74001f,0x6b98047e,0x6f09fad3}},	//   vesd, _አዳራሽ_, _pivg, _tadc, 
   {{0x3941fad4,0x00000000,0x00000000,0x00000000}},	//   _alis_, --, --, --, 
   {{0x4dd4021a,0x68fdfad5,0x26c000c7,0x39410118}},	//   _ستاس, tesd, _reho_, _blis_, 
   {{0x69c913bc,0x2244509e,0x394001ab,0x26c1fad6}},	//   rsde, _ülke_, _clis_, _seho_, 
   {{0x68fdfad7,0x26c1fad8,0xc7c401c0,0x25a0002f}},	//   resd, _peho_, эсни, _suhl_, 
   {{0x3941fad9,0x68fdfada,0x69c8168c,0xff1c037e}},	//   _elis_, sesd, psde, _khzの, 
   {{0xe8d844fc,0xbb800597,0x66040309,0x4b5003e6}},	//   _ahụ_, _حلوي, _qshk, _لێکر, 
   {{0x26c0337a,0x3940a819,0xa81400d1,0x24180166}},	//   _weho_, _glis_, _адиш, мобы_, 
   {{0x26c1fadb,0xdb0800e4,0x2d80031c,0x00000000}},	// [399b0] _teho_, lpeá, ċieh_, --, 
   {{0xa2d40372,0x212dfadc,0x862402d5,0x644006be}},	//   ئيات, _soeh_, _зьме, _əlih, 
   {{0x66040309,0x212c01a4,0xe854abd7,0x25d8009d}},	//   _ushk, _poeh_, _سنگد, _юмны_, 
   {{0xa2dd0b67,0xe4540139,0x614000db,0xb62c0150}},	//   _पाक्, _акмы, جۉرە, _ﻔﺕ_, 
   {{0xdee5ab27,0x260402ab,0x307400cf,0x00000000}},	//   воли, _हैती_, лушс, --, 
   {{0x09b4015b,0x00000000,0x00000000,0x00000000}},	//   _ঝিনা, --, --, --, 
   {{0x99640171,0x9f580248,0x8f3000d8,0x00000000}},	//   _lēš_, _èsí_, рејц, --, 
   {{0xa2d800cd,0x00000000,0x00000000,0x00000000}},	//   मलक्, --, --, --, 
   {{0x6ff40472,0x00000000,0x00000000,0x00000000}},	//   _مسلط, --, --, --, 
   {{0x2d98068c,0x39400332,0x00000000,0x00000000}},	//   _èren_, _slis_, --, --, 
   {{0xd9446b83,0x394070cd,0xb4e43174,0x13fc0412}},	//   вени, _plis_, गलमय_, _उन्ह_, 
   {{0x7bc9fadd,0x9c38026a,0x9f4c0166,0x26c40162}},	//   _tvgu, _опет_, _iseñ_, ðlon_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9a15ac29,0x7d09fade,0xe9a82e07,0x480006ed}},	//   _афиш, _hags, بدین_, јпрв, 
   {{0x7d08089c,0x590800db,0x00000000,0x00000000}},	//   _kags, _жейм_, --, --, 
   {{0xe8d807ae,0x3941fadf,0xb4dd9527,0x7d09d8bb}},	//   _phụ_, _ulis_, ठले_, _jags, 
   {{0x7d08778b,0x5ed00574,0x178400d1,0xa34801e1}},	// [399c0] _mags, सणाऱ, _игим, _tọ̀t, 
   {{0x7d081876,0x2bd43a62,0x00000000,0x00000000}},	//   _lags, _दिसा, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7d08f1f6,0xe8d80016,0x3de4009e,0x9c7c0100}},	//   _nags, _thụ_, পবাল, nfōs, 
   {{0xc0e04408,0xaed4041b,0x00000000,0x00000000}},	//   рочк, голш, --, --, 
   {{0x40302235,0xd334084c,0xac6c0092,0x2bc4012d}},	//   решс, _рэмы, _አሳማኝ_, लीफा, 
   {{0x7d09fae0,0x4204016c,0x2bc408dd,0xbea000d8}},	//   _bags, _инро_, लीना, шајк, 
   {{0x21743bfd,0x6b44007f,0x7d080009,0x00000000}},	//   _буур, _mòge, _cags, --, 
   {{0x7d09fae1,0x8fa4cd5c,0xefb0006c,0x4fa5fae2}},	//   _dags, _разе, _ایتگ, _ризв, 
   {{0x2019fae3,0x7d0801e7,0x61f806ea,0x7ee02ba5}},	//   _ásia_, _eags, _íblá, _ەكەن, 
   {{0x2bd42368,0x7d0878d5,0xcd040116,0xbea00107}},	//   _दिवा, _fags, _ачли, _тахк, 
   {{0xa92003be,0xe945bac5,0x13a800fe,0x00000000}},	//   _şöbə, اردی, খীয়, --, 
   {{0xdb080491,0xdce80115,0xc8640798,0x00000000}},	//   speá, nleĝ, ттни, --, 
   {{0x7a50073e,0xc5fc00e2,0xbb400063,0x7d080166}},	//   اضیا, ņēmu_, _вељк, _zags, 
   {{0xa4d410f5,0x0575459b,0x6e3801d3,0x7d08010b}},	//   лові, نارد, nyvb, _yags, 
   {{0x354402bf,0x7d080009,0x3568010b,0xfa6400d8}},	//   ахув, _xags, врун_, _шајк_, 
   {{0x6b440428,0xa0a4504c,0xa2f4005b,0x743400d8}},	// [399d0] _eòge, қалд, лпач, антф, 
   {{0x46a40307,0xa2940006,0x46b400cd,0x00000000}},	//   _खलिह, газі, _अभिह, --, 
   {{0xe65800a8,0x6b4401e1,0x00000000,0x00000000}},	//   _чинч_, _kògb, --, --, 
   {{0x6ee00118,0x00000000,0x00000000,0x00000000}},	//   _नाउँ, --, --, --, 
   {{0x9f341d31,0x2bc41fd2,0x6b4401e1,0x9d4401e0}},	//   леді, लीमा, _mògb, ҫелд, 
   {{0x7d09fae4,0x6b440248,0xa2dc0829,0xdee40395}},	//   _sags, _lògb, _पाट्, уоки, 
   {{0x7d087004,0x7f8402d3,0xd3440344,0x00000000}},	//   _pags, ምለኻዊ_, _حیله_, --, 
   {{0x2bd407af,0x2bc42052,0x00000000,0x00000000}},	//   _दिशा, लीभा, --, --, 
   {{0x313453cd,0x7d09fae5,0xa2dc726b,0x59740150}},	//   _тетр, _vags, _पाञ्, ғыну, 
   {{0x9b45fae6,0x7d080429,0x0b4002dd,0x9f5801e1}},	//   اندو, _wags, йнын, _èsà_, 
   {{0x7d08c643,0x2bc49401,0x5cf401c6,0x00000000}},	//   _tags, लीबा, _бялу, --, 
   {{0x4a4002bf,0x48e000d4,0x00000000,0x00000000}},	//   снюв, боюв, --, --, 
   {{0x9f580120,0x6ee0063f,0x030001ad,0x00000000}},	//   _ésó_, _ịbid, रजाह_, --, 
   {{0x07a04df9,0xc7a01fbe,0xcc38008f,0xfa504278}},	//   сарн, сирк, _רעסט, _پرتگ, 
   {{0x7bd80cfe,0x6b458988,0x1da80210,0x00000000}},	//   lruu, _fògb, _चूमत, --, 
   {{0xf8a80c2e,0x69940006,0x00000000,0x00000000}},	//   _गलिय, _крых, --, --, 
   {{0xc950025f,0x7bd80108,0x00000000,0x00000000}},	// [399e0] _למה_, nruu, --, --, 
   {{0x7bd8198f,0x1ad40183,0xe5780107,0x26040210}},	//   iruu, ত্ৰা, езӣ_, _हैवी_, 
   {{0x9484d1da,0x8b54008f,0x7bd80009,0xdb08005b}},	//   тыңд, ניעס_, hruu, mpeä, 
   {{0x106800a8,0x2bd4228d,0x50641f10,0x6d9c0055}},	//   нией_, _दिला, лтла, _aũan, 
   {{0xc5ec004b,0x7ff00066,0x00000000,0x00000000}},	//   _وړې_, مسوا, --, --, 
   {{0x7bd8ce7f,0xdce97318,0x82a001c4,0x00000000}},	//   druu, rleĝ, _гарж, --, 
   {{0x7bd8022f,0x201803b2,0xbfc80150,0x23ac00d7}},	//   eruu, _ásin_, _ۋاكە_, _iľja_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x60cc0252,0x6b440ca8,0x7bd80862,0x00000000}},	//   ðame, _rògb, gruu, --, 
   {{0xab9c001f,0xdb4c03e6,0x3eb40118,0xa2dc000d}},	//   _ወዲያው_, وێن_, četí_, _पाछ्, 
   {{0xe3b8025c,0x03740375,0x7bd80a55,0x42d8010f}},	//   _བསྐང, רתית_, aruu, עקטע, 
   {{0x0c840032,0x7bd80449,0xa3d400c5,0xdce80e2d}},	//   _йылм, bruu, _सटल_, mleğ, 
   {{0xb9542405,0x15ac0131,0xdce80e2d,0x7bd80067}},	//   свящ, _ﻳﺎﺭﺩ, lleğ, cruu, 
   {{0x26c400d2,0xe9440214,0x85b8007b,0xaa94d174}},	//   úlo_, ارگی, فارس_, _килч, 
   {{0xf9905311,0x9c7c00b0,0x6b4401e1,0xe69401f4}},	//   تبی_, ngōn, _tògb, ривы, 
   {{0x58fc0327,0xa2dc190c,0x55100037,0x00000000}},	//   _ཟིགས_, _पाङ्, _ढोआए_, --, 
   {{0x3218003e,0x98c405f5,0xc7642a8b,0x2604012d}},	// [399f0] _arry_, _өсөл, _مادى, _हैरी_, 
   {{0x3495afb6,0x00000000,0x00000000,0x00000000}},	//   саур, --, --, --, 
   {{0xdb08ff76,0xa3e002ab,0x00000000,0x00000000}},	//   speç, _धमक_, --, --, 
   {{0x1fb40024,0x7bd95e95,0x55c000fb,0x00000000}},	//   аскр, yruu, _фәрз, --, 
   {{0x60257a18,0x32180098,0xa2ac06b1,0x7bd800e8}},	//   рдла, _erry_, _जलप्, xruu, 
   {{0x44380175,0x7ed40101,0xf4841046,0x00000000}},	//   myq_, ازشا, _داپی, --, 
   {{0x7bd8e7c5,0x644c3987,0xd24c0014,0x32380092}},	//   wruu, lzai, _ہۆے_, _በሚኖሩ, 
   {{0x7bd9fae7,0x00000000,0x00000000,0x00000000}},	//   truu, --, --, --, 
   {{0x644dfae8,0x7bd9fae9,0x00000000,0x00000000}},	//   nzai, uruu, --, --, 
   {{0x7bd83388,0xe818085c,0x644c01c7,0x58fc0327}},	//   rruu, दिना_, izai, _ཟིངས_, 
   {{0xfc3c00bc,0x32dc01e1,0xaf340137,0x644c01c7}},	//   ší_, _háyà_, _ارقت, hzai, 
   {{0x273c01dc,0x7bd80037,0x9b440066,0x39440d12}},	//   _hình_, pruu, انگو, óms_, 
   {{0x273c004d,0x2bc403ce,0x28b4000d,0x7c85faea}},	//   _kình_, लीदा, ंड़ि, _суже, 
   {{0x644c898f,0x7c3801b9,0x6c84007b,0x00000000}},	//   dzai, myur, _الهم, --, 
   {{0x273c01dc,0x32dc0248,0xa7542077,0x04340092}},	//   _mình_, _láyà_, стящ, _የመገን, 
   {{0x6a14004b,0x1ccc0327,0x273c0208,0x00000000}},	//   _دبهر, _ྱབས_, _lình_, --, 
   {{0x78a5faeb,0x7c39faec,0x26140115,0xd74c0023}},	// [39a00] _igiv, nyur, _eĥo_, _ሃገርነ, 
   {{0x7c3801e2,0x224c0118,0xe2a8009f,0xc32000f3}},	//   iyur, _řeka_, هامن_, омук, 
   {{0x7c3800ca,0x420400f0,0x64c400ec,0x00000000}},	//   hyur, инфо_, _ڏيپل, --, 
   {{0xfbc5faed,0x7c38c437,0x41d81cd2,0x00000000}},	//   _وت_, kyur, मंजस, --, 
   {{0x273c01dc,0xe8180c66,0x80c80490,0xd01001b9}},	//   _bình_, दिया_, हणजे, تلش_, 
   {{0xbfc800d1,0xfe6c00f1,0x00000000,0x00000000}},	//   ئانە_, ژدي_, --, --, 
   {{0x7c3800f1,0x7f8000d1,0x273c0051,0x2ec400fb}},	//   eyur, غلىن, _dình_, _һөйм, 
   {{0xc0e1faee,0x78a5faef,0xdce8236c,0x826401a9}},	//   _моск, _ngiv, rleğ, _тасв_, 
   {{0xdde005a1,0xdce805d1,0x4f0801af,0x00000000}},	//   ćušn, sleğ, _инан_, --, 
   {{0x78a5faf0,0x6204002e,0xbea000d8,0x8aa401a9}},	//   _agiv, _ñulé, _дафк, шрид, 
   {{0x644dfaf1,0x6fb001d9,0xc9840120,0x00000000}},	//   zzai, _بۅڈا, иуми, --, 
   {{0x6b440086,0x7c39faf2,0x44380175,0x00000000}},	//   _dòga, byur, yyq_, --, 
   {{0x7c380796,0x0ba8030c,0x80c40950,0x644003b9}},	//   cyur, _شاشى_, ारते, _əlis, 
   {{0x6d41faf3,0x78a5faf4,0x6b4401c3,0x644c04cc}},	//   lkma, _egiv, _fòga, vzai, 
   {{0x7aec0122,0x6d400334,0xf9900451,0x16083885}},	//   žitý, okma, _ڪبو_, _हैदर_, 
   {{0x644c152d,0xf524ed5a,0x2eb400cd,0x00000000}},	//   tzai, офун, ुरुत, --, 
   {{0x68ec00fd,0x6d4001a4,0x02a4014b,0xf9901291}},	// [39a10] _icad, ikma, арем, _تبو_, 
   {{0x20e40943,0x23bc0ca8,0x4438036e,0x28b40412}},	//   _ḓi_, _aájò_, ryq_, ंडवि, 
   {{0xf77010de,0x6d413e11,0x41e402bf,0x273c004d}},	//   _تاي_, kkma, різа, _rình_, 
   {{0x6d41faf5,0x273c0208,0x644c0051,0x00000000}},	//   jkma, _sình_, pzai, --, 
   {{0x2eec0175,0x657c0200,0x7c38045a,0x00000000}},	//   _bcdf_, _iksh, xyur, --, 
   {{0x6d4027bb,0x63adfaf6,0x657c0208,0x7c39faf7}},	//   ekma, mqan, _hksh, vyur, 
   {{0x6720023a,0x68ec03ac,0x63acbf70,0x80c40a97}},	//   öljy, _ocad, lqan, ारदे, 
   {{0x61e49888,0x68ec009a,0x63ac013c,0x1d25faf8}},	//   muhl, _ncad, oqan, смим, 
   {{0x273c01dc,0x63adfaf9,0x61e45107,0x4a000135}},	//   _tình_, nqan, luhl, _མགུལ_, 
   {{0x6aa44ba9,0x60c9fafa,0x200c0a73,0x6d400d47}},	//   _şifr, _heem, _isei_, akma, 
   {{0x7c39fafb,0x61e40a2e,0xdce89d28,0x8ea400cf}},	//   syur, nuhl, sleđ, _المۇ, 
   {{0x60c9fafc,0xfc300a8e,0xdde801b9,0x644003e3}},	//   _jeem, _وحش_, _لرچه_, _əlir, 
   {{0x61e5fafd,0x63ac016d,0x00000000,0x00000000}},	//   huhl, jqan, --, --, 
   {{0x61e42ffc,0x60c9fafe,0x9964dfe6,0x68edfaff}},	//   kuhl, _leem, ртүл, _ecad, 
   {{0x19b5fb00,0x63ac0194,0x68ec01ab,0x61e4023a}},	//   _احتج, eqan, _fcad, juhl, 
   {{0x60c9fb01,0x68edfb02,0x200c013f,0xda6405d9}},	//   _neem, _gcad, _osei_, _پاڻي, 
   {{0x63ac047e,0x1da80210,0x00000000,0x00000000}},	// [39a20] gqan, _चूसत, --, --, 
   {{0x61e40117,0xc32c0014,0x42c400db,0x00000000}},	//   fuhl, ٹٕم_, йгун_, --, 
   {{0x60c9fb03,0x61e5fb04,0x200c013f,0x63accba2}},	//   _beem, guhl, _asei_, aqan, 
   {{0xc690025f,0x60c8011f,0x63ac047e,0x6d40058a}},	//   _מאת_, _ceem, bqan, xkma, 
   {{0x200c070d,0x60cc0008,0x60c9554f,0x6560067c}},	//   _csei_, ðama, _deem, èlhe, 
   {{0x425005bd,0xe818b658,0x2eb40243,0x1fa40150}},	//   _کنفر, दिता_, ुरेत, іріг, 
   {{0x200dfb05,0x60c9fb06,0x60300055,0x00000000}},	//   _esei_, _feem, _aśmā, --, 
   {{0x60c8b0d7,0xebd8055f,0x0c84004e,0xfafc00ef}},	//   _geem, адиш_, йыпм, _šūpo_, 
   {{0x6d41fb07,0xfba401c0,0x3cf400ae,0x00000000}},	//   rkma, йтэй_, صعيد_, --, 
   {{0x68edfb08,0x60c9fb09,0x6d41a7e6,0x9f0800cf}},	//   _scad, _zeem, skma, _ۅزۅك_, 
   {{0x8e851206,0x3f9807ea,0x60c9fb0a,0x28b40401}},	//   _الاه, ïque_, _yeem, ंडलि, 
   {{0x60c9fb0b,0x63ac4376,0xf1e40150,0xa89800f3}},	//   _xeem, yqan, _ﺎﻻﻟﺘ, икну_, 
   {{0xead484da,0x2d8401ab,0x60dc0419,0xa8740150}},	//   _доль, mlme_, _ôsme, ілгі, 
   {{0x046401e0,0x63ac016d,0xf1d801f9,0x00000000}},	//   ҡтам, vqan, डळान, --, 
   {{0x2c7400dd,0x2bc405d7,0x76580153,0x63ac014f}},	//   _دیکھ_, लीरा, _žvyr, wqan, 
   {{0x657dfb0c,0xda6400ec,0x63adfb0d,0x68edfb0e}},	//   _qksh, _باهي, tqan, _ucad, 
   {{0x61e5fb0f,0x6d9c0055,0x2d840334,0xe8b401f9}},	// [39a30] wuhl, _aũak, ilme_, ंडीच, 
   {{0x63acd5d6,0x60c9fb10,0x02a41575,0xc76404b3}},	//   rqan, _seem, срам, _دابى, 
   {{0x63ac1bb7,0xe53405cc,0x60c8cd11,0xf2c40395}},	//   sqan, _день, _peem, ястн, 
   {{0x657d18bc,0x61e4036b,0x63ac3927,0x00000000}},	//   _uksh, ruhl, pqan, --, 
   {{0x63adfb11,0x9f99fb12,0x5f740b6c,0x1ec80408}},	//   qqan, авду_, ياتر, алли_, 
   {{0x60c9fb13,0xa92006be,0x00000000,0x00000000}},	//   _weem, _şölə, --, --, 
   {{0x60c9fb14,0x31c436dd,0xf1080137,0x00000000}},	//   _teem, _нств, _گۉنۉ_, --, 
   {{0x2bd42007,0x1c440212,0x00000000,0x00000000}},	//   _दिखा, жним, --, --, 
   {{0x6fe013b4,0x200c06ed,0x9f044fdc,0x2bc4454f}},	//   _नियं, _usei_, _وورو, लीला, 
   {{0x2d841497,0x00000000,0x00000000,0x00000000}},	//   alme_, --, --, --, 
   {{0x2d8401ab,0xe9b801d3,0xdb0c01e1,0x00000000}},	//   blme_, ینیں_, _òjíb, --, 
   {{0x69dc307d,0x67240ffb,0x6fe01431,0x00000000}},	//   área, _anhj, _निमं, --, 
   {{0x224c012c,0x39a0007f,0x00000000,0x00000000}},	//   _řekl_, fèsè_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x785c005f,0x00000000,0x00000000,0x00000000}},	//   tāvī, --, --, --, 
   {{0xf4840133,0x25ac01e4,0x00000000,0x00000000}},	// [39a40] ساری, ĉela_, --, --, 
   {{0x6fe013b4,0x39a40248,0x00000000,0x00000000}},	//   _निबं, bèsè_, --, --, 
   {{0xd629fb15,0x321c13d5,0xd4a401af,0x959400f3}},	//   _тоне_, ívy_, _минй, _мрмљ, 
   {{0x216402dd,0x2eb44c5b,0x10a42377,0xa7f40244}},	//   птіг, ुर्त, цидн, _بقیژ, 
   {{0xc95005d0,0x00000000,0x00000000,0x00000000}},	//   ומא_, --, --, --, 
   {{0xac082302,0xcdd810fc,0x5274022e,0x00000000}},	//   ەردە_, ањи_, _дубу, --, 
   {{0xdd9001ed,0x03a00835,0xcd48009d,0x00000000}},	//   کوٹ_, _циро, ичид_, --, 
   {{0x2ee00e2d,0x2d840165,0x00000000,0x00000000}},	//   şif_, ulme_, --, --, 
   {{0x46bcb8a8,0x6b4401ab,0x9c7c00b0,0x777c01a9}},	//   ्रमह, _fògl, ngōh, korx, 
   {{0x0b880798,0x00000000,0x00000000,0x00000000}},	//   јсии_, --, --, --, 
   {{0x777c004e,0x8fd001e0,0xe97800db,0x00000000}},	//   dorx, _эҙҙә, йбош_, --, 
   {{0x8ba5fb16,0x39a402bd,0x00000000,0x00000000}},	//   _дидж, vèsè_, --, --, 
   {{0xcb69fb17,0xc198008f,0xbd3000db,0xe8d80051}},	//   _каде_, ישטי, _تىنع, _gjờ_, 
   {{0x3b0402e8,0x00000000,0x00000000,0x00000000}},	//   _мечо_, --, --, --, 
   {{0x46bc00bc,0x3a702360,0x00000000,0x00000000}},	//   ्रबह, _олшр, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x777dfb18,0x273c01e1,0x00000000,0x00000000}},	// [39a50] borx, _sìnu_, --, --, 
   {{0xe8d801fb,0x777c00cf,0xdce80115,0x47d000ec}},	//   _thỳ_, corx, mmeĥ, _فيڊر, 
   {{0x26d1fb19,0x33380165,0x208800d1,0x80c40073}},	//   mazo_, _dorx_, әйли_, ारले, 
   {{0x26d1fb1a,0x6b4401ab,0xa1580063,0x00000000}},	//   lazo_, _sògl, љаду_, --, 
   {{0xe8d802e3,0xf7713ecd,0x00000000,0x00000000}},	//   _amị_, _سای_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9d44ae78,0x8eb00451,0x00000000,0x00000000}},	//   зейд, رميش, --, --, 
   {{0x26d01311,0xfbe000d1,0x00000000,0x00000000}},	//   hazo_, _ﺋﻪﺭﻛ, --, --, 
   {{0x26d051b9,0x69dc0518,0x777c01a9,0x00000000}},	//   kazo_, áren, yorx, --, 
   {{0x26d000ec,0x0c70036b,0x9c7c00b0,0xa92400d0}},	//   jazo_, رگند, ngōi, ížny, 
   {{0x26d03eba,0x2b5c062c,0x6b44c3c8,0xbd6800db}},	//   dazo_, _dmvc_, _gògm, _крде_, 
   {{0x6d8c000f,0x8df8011a,0x00000000,0x00000000}},	//   lûan, _להעת, --, --, 
   {{0x7c640228,0x26d1fb1b,0xec240150,0x24d000cc}},	//   _باال, fazo_, _يىمپ, িলাহ, 
   {{0x26d1fb1c,0x9078025d,0xe7ec00bc,0x00000000}},	//   gazo_, מטרי, _जमरा_, --, 
   {{0xba75fb1d,0xd945fb1e,0x39b40356,0x00000000}},	//   _باشت, _неки, _băse_, --, 
   {{0x82b4003d,0xdd98033b,0x89d8011a,0xe8186c5a}},	//   _བཅུའ, nmň_, _החקי, दिशा_, 
   {{0x26d1b2f7,0xda180f4c,0x6560068c,0x23e4003b}},	// [39a60] bazo_, धिवत_, èlha, дієв, 
   {{0xe81803f3,0x26d1fb1f,0x779407d6,0xa3cc03ba}},	//   दिरा_, cazo_, _آیسا, _रबर_, 
   {{0x9f580241,0x00000000,0x00000000,0x00000000}},	//   _èsù_, --, --, --, 
   {{0x39b40356,0x53a4009d,0x3f8482c7,0x00000000}},	//   _găse_, _намб, elnu_, --, 
   {{0xc32416a0,0x33f40227,0x7f8000f1,0x00000000}},	//   تكەن_, qäx_, کلون, --, 
   {{0x22400175,0xc7d400d9,0x00000000,0x00000000}},	//   byhk_, לוני_, --, --, 
   {{0xd4680092,0x00000000,0x00000000,0x00000000}},	//   _በመጠኑ_, --, --, --, 
   {{0xac080c50,0x3f840552,0xd130e4c4,0x26d004d4}},	//   ەرگە_, alnu_, _ثمر_, zazo_, 
   {{0x26d1fb20,0x60dc00d7,0x00000000,0x00000000}},	//   yazo_, _ôsma, --, --, 
   {{0x8e8416a4,0xf1e00950,0x00000000,0x00000000}},	//   _егзе, _पटान, --, --, 
   {{0xc3300302,0x63a80798,0x26d005da,0x00000000}},	//   תות_, _éenv, vazo_, --, 
   {{0x26d005d9,0x00000000,0x00000000,0x00000000}},	//   wazo_, --, --, --, 
   {{0x26d1fb21,0x7c801515,0x4c84009d,0x815400df}},	//   tazo_, _пуше, _элдв, לסטע_, 
   {{0x2efc00d2,0xe8d80cad,0x00000000,0x00000000}},	//   nfvf_, _imọ_, --, --, 
   {{0xb6041fe2,0x2d9806af,0xbaf80375,0x25ac0115}},	//   нятк, _ères_, _להגש, ĉelo_, 
   {{0xe8d8001e,0x69d9fb22,0x15a00131,0x26d0004b}},	//   _thự_, _ivve, _ﺋﺎﺧﯩ, sazo_, 
   {{0x26d00f71,0xa7747745,0xdb0800a2,0x00000000}},	// [39a70] pazo_, _олич, hpeý, --, 
   {{0x291805be,0x26d0022e,0x00000000,0x00000000}},	//   ldsa_, qazo_, --, --, 
   {{0xf7700132,0x00000000,0x00000000,0x00000000}},	//   _حاي_, --, --, --, 
   {{0xe4c4031b,0x6604009a,0x291803a2,0xa3b402bf}},	//   _تصدی, _iphk, ndsa_, _обмі, 
   {{0x29d807ae,0xd12d6a15,0x6adc17c6,0x656c0477}},	//   hĩa_, شمو_, _मयूर, mnah, 
   {{0x35f87735,0x69d80801,0x656dfb23,0x63bc02d0}},	//   _برید_, _ovve, lnah, _itsn, 
   {{0xe8d80241,0x656c0067,0x00000000,0x00000000}},	//   _amọ_, onah, --, --, 
   {{0x656dfb24,0xdca404a9,0x68fc0d27,0x9c24967a}},	//   nnah, майи, jfsd, ддид, 
   {{0x69d9fb25,0x46bc08ec,0x656dfb26,0x29180003}},	//   _avve, ्राह, inah, ddsa_, 
   {{0x99041b37,0x63bc022e,0x656d617f,0xdcfc2ca8}},	//   षज्ञ_, _mtsn, hnah, ızıy, 
   {{0x68fc343a,0x656c1427,0x3a240166,0x00000000}},	//   ffsd, knah, ченү_, --, 
   {{0x68fc004e,0xa3cc01ad,0xd9580212,0xd94400f3}},	//   gfsd, रठा_, ішні_, феми, 
   {{0x656c0014,0x69d9fb27,0x5b3400ae,0x00000000}},	//   dnah, _evve, _يعتر, --, 
   {{0x6fe0098a,0x9b440214,0x4c980375,0x656cb3b6}},	//   _निसं, _زنبو, _ובנו, enah, 
   {{0xc7a03f08,0x656dfb28,0x63bc00b5,0xe8d80051}},	//   тирк, fnah, _atsn, _nhỷ_, 
   {{0xd9980014,0x656cf119,0x1868013e,0xbe9c0055}},	//   _بختا_, gnah, _майи_, _iṣīk, 
   {{0x7985fb29,0x97b401b9,0xeb340244,0x00000000}},	// [39a80] _ikiw, _ўсиш, _ترۆخ, --, 
   {{0x656dfb2a,0xdb0895fc,0x39a40248,0x00000000}},	//   anah, mpeó, _fèsì_, --, 
   {{0x656c0050,0x9694036b,0x63bc02d0,0x69d80156}},	//   bnah, _юриш, _etsn, _xvve, 
   {{0xd0084ec9,0x656c01d9,0x63bc0109,0x6b4408c2}},	//   жеде_, cnah, _ftsn, _eògh, 
   {{0x7ff005d9,0x798579e3,0xd92c001f,0x6b4408c2}},	//   نسوا, _mkiw, _እየተን, _fògh, 
   {{0xf7ac00d1,0x6e946ed2,0x00000000,0x00000000}},	//   _ﻳﻮﻟﺪ, нилу, --, --, 
   {{0x4390016c,0x79841418,0x7bc9fb2b,0x68fc0334}},	//   _раёс, _okiw, _awgu, yfsd, 
   {{0x82900075,0x798404ba,0x63a804cc,0xc18802d2}},	//   _شۇنچ, _nkiw, _èenc, _þápó, 
   {{0x008000a8,0x63a800d8,0xa2b401f9,0x00000000}},	//   _алто, _éent, ेरच्, --, 
   {{0x7985fb2c,0x4c90036b,0x656c01c4,0x00000000}},	//   _akiw, ниқс, znah, --, 
   {{0x656c0a81,0x5ae40022,0x00000000,0x00000000}},	//   ynah, хсыҕ, --, --, 
   {{0x4cd46646,0x00000000,0x00000000,0x00000000}},	//   _آغاز, --, --, --, 
   {{0x6b45fb2d,0xfc2c2cc0,0x39a40241,0xef1800ef}},	//   _lògi, _نحو_, _sèsì_, _kaļ_, 
   {{0xfc6475e5,0x79842f99,0x68fc00b5,0x39a40241}},	//   _تخمی, _ekiw, sfsd, _pèsì_, 
   {{0x656dfb2e,0x6b4401ab,0xef1800ef,0x00000000}},	//   tnah, _rògh, _maļ_, --, 
   {{0x656dfb2f,0x61e402fb,0x6b4401ab,0xb5940108}},	//   unah, vrhl, _sògh, висш, 
   {{0x92a8015b,0x23ac0427,0x00000000,0x00000000}},	// [39a90] _গড়ে_, _ožje_, --, --, 
   {{0x656dfb30,0x61e40306,0x160800ce,0xa61400d4}},	//   snah, trhl, _हैकर_, _змоч, 
   {{0x656dfb31,0xa4d400d4,0x00000000,0x00000000}},	//   pnah, _поні, --, --, 
   {{0x6b4408e7,0x656c058a,0x00000000,0x00000000}},	//   _dògi, qnah, --, --, 
   {{0x80240491,0x77a80050,0x5f0428e5,0x63bdb75c}},	//   برام, _رێہہ_, езла, _utsn, 
   {{0x39b40276,0xdcf80083,0x6fe007af,0x84ec1524}},	//   _lăsa_, _okwă, _निरं, _छाँट_, 
   {{0x41740046,0xc17435e6,0x60dc00d7,0x00000000}},	//   _قارس, _قدرت, _ôsmo, --, 
   {{0xdb0c0ca8,0x00000000,0x00000000,0x00000000}},	//   _àkúr, --, --, --, 
   {{0xdcf80083,0x81b403f9,0x1f7400c0,0x00000000}},	//   _akwă, ɓɓak, _злая, --, 
   {{0xbe800fc0,0x2f5401af,0x00000000,0x00000000}},	//   _иқли, _итєс, --, --, 
   {{0x12d00150,0xdd9400c0,0xaed4014b,0x00000000}},	//   _ﺘﺩﻴﺭ, _зажы, _рохш, --, 
   {{0x6560067c,0xdc74005b,0x3f880055,0x00000000}},	//   èlhl, _пыль, _ūcuh_, --, 
   {{0xad24005e,0x89f401d3,0x7d180162,0x00000000}},	//   _جىنى, وٹیز_, mdus, --, 
   {{0xcc381a4c,0x7d19fb32,0xcf9000df,0x00000000}},	//   _מענט, ldus, ָטל_, --, 
   {{0x1ca404d3,0x0450001f,0x7d180037,0x85b0013d}},	//   _تێکی_, _ለመገን, odus, ләяч, 
   {{0x7d18367a,0xdb0809ff,0x79840451,0x6fe00d0a}},	//   ndus, mpeñ, _ukiw, _निलं, 
   {{0x7d19e33b,0x7648003b,0x33840107,0x00000000}},	// [39aa0] idus, ødyb, вваҳ, --, 
   {{0xc4800228,0x7d18023a,0x00000000,0x00000000}},	//   улук, hdus, --, --, 
   {{0xdce800d0,0x7d18007c,0x52741f0d,0x00000000}},	//   eneč, kdus, رائز, --, 
   {{0x64400213,0x00000000,0x00000000,0x00000000}},	//   _əliz, --, --, --, 
   {{0x044000ee,0x00000000,0x00000000,0x00000000}},	//   _беян, --, --, --, 
   {{0xe3280156,0xe3f400cf,0x7d19fb33,0x6b440241}},	//   _ལོགཔ_, _جۉكت_, edus, _tògi, 
   {{0xdb0c01e1,0x0dc8003b,0x00000000,0x00000000}},	//   _àkùr, чули_, --, --, 
   {{0x7d19fb34,0xabb40588,0xefe80023,0x00000000}},	//   gdus, ҭақә, መለይ_, --, 
   {{0x70cccaa0,0x25a4026c,0xd0244bcc,0x00000000}},	//   ारील, ìlli_, _ямай, --, 
   {{0x7d1800af,0x00000000,0x00000000,0x00000000}},	//   adus, --, --, --, 
   {{0x2bc407f7,0xa2d01be1,0x00000000,0x00000000}},	//   लीजा, धरत्, --, --, 
   {{0x7d180083,0x00000000,0x00000000,0x00000000}},	//   cdus, --, --, --, 
   {{0xdb0800a3,0x00000000,0x00000000,0x00000000}},	//   rpeò, --, --, --, 
   {{0xc6a5fb35,0xadf40254,0x3bb8011a,0x00000000}},	//   ерби, _इमान_, _צמוד, --, 
   {{0xa4d40111,0x4ddc00cc,0x00000000,0x00000000}},	//   кові, _মহুৱ, --, --, 
   {{0xe508038b,0x80cc0118,0x00000000,0x00000000}},	//   بيرو_, _हजें, --, --, 
   {{0xd76400e5,0x00000000,0x00000000,0x00000000}},	// [39ab0] رنہی, --, --, --, 
   {{0x7d180cf4,0xefd402d3,0x6f1c0332,0x00000000}},	//   zdus, _ራህዋ_, _órch, --, 
   {{0x64400cc1,0x9c7c02b5,0x46a4008e,0x78c802d2}},	//   _əliy, ngōr, _яшиб, _ísví, 
   {{0xf77007d2,0x15a000d1,0x928c0150,0x63e400f1}},	//   _پاۋ_, _ﺋﺎﺳﯩ, _ﺒﻭﻗﻑ_, _لېرې_, 
   {{0x7d19fb36,0xf99400df,0x00000000,0x00000000}},	//   vdus, ארף_, --, --, 
   {{0x8c14045e,0x7d18232c,0xdce801fa,0x672087ee}},	//   ়মান_, wdus, rneč, मयिक_, 
   {{0xc68c0020,0x6b44067c,0xd3440244,0x00000000}},	//   _መስሪያ_, _jògu, _جیله_, --, 
   {{0x7d19fb37,0x6295a6ff,0x00000000,0x00000000}},	//   udus, _izzo, --, --, 
   {{0x7d1802e5,0xb7bc04c5,0xad24009f,0x00000000}},	//   rdus, _অট্ট, طريو, --, 
   {{0x7d180200,0x6b4401e1,0x8b2001f4,0x00000000}},	//   sdus, _oògu, адье, --, 
   {{0x5a94136b,0x212c0098,0xae0401ec,0x00000000}},	//   ъриф, _kneh_, _مولى, --, 
   {{0x81c0febc,0x6e640006,0x7d180009,0x00000000}},	//   _এটা_, _стуж, qdus, --, 
   {{0x212c06fd,0xaae40133,0x9f5801e1,0x96b800db}},	//   _mneh_, _ڵسوو, _èsó_, дубу_, 
   {{0x6b44067c,0x7bd80a55,0xcc54011a,0x00000000}},	//   _bògu, msuu, _בבני_, --, 
   {{0x6fd800d2,0x212c003e,0x7bd89e7a,0x00000000}},	//   _kúcá, _oneh_, lsuu, --, 
   {{0x3de004c5,0x7bd8005b,0x998416ac,0x00000000}},	//   _মহাল, osuu, _جلبو, --, 
   {{0x7bd9fb38,0x6295fb39,0x850001d9,0x00000000}},	// [39ac0] nsuu, _azzo, شوٕن, --, 
   {{0x7bd9fb3a,0x212d2e83,0x394001ab,0x6fd801e7}},	//   isuu, _aneh_, _hois_, _lúcá, 
   {{0xcb10011a,0x00000000,0x00000000,0x00000000}},	//   שלב_, --, --, --, 
   {{0x5065fb3b,0x212c0100,0x106998c5,0x7bd9fb3c}},	//   ктла, _cneh_, мией_, ksuu, 
   {{0x3941fb3d,0x212c151c,0x8fd0104e,0x00000000}},	//   _mois_, _dneh_, рәбә, --, 
   {{0xe8d8063f,0xb8d40135,0x212c0098,0x69dc005f}},	//   _ikụ_, _ཟུ_, _eneh_, šrei, 
   {{0x7bd8198f,0x00000000,0x00000000,0x00000000}},	//   esuu, --, --, --, 
   {{0x3941fb3e,0xbd6412c4,0xac940952,0xaeec0139}},	//   _nois_, крые_, лайш, _şıği, 
   {{0x7bd9fb3f,0x2174490c,0x0ae8e7e1,0x00000000}},	//   gsuu, _сурр, وردي_, --, 
   {{0x39407e9f,0x8fa400f2,0xfbcc07fc,0x00000000}},	//   _aois_, _شماه, آتي_, --, 
   {{0x3941fb40,0x28f8759f,0x7bd9fb41,0xb00400b8}},	//   _bois_, нень_, asuu, _duḥp, 
   {{0x3940327f,0x7bd9fb42,0x9f5801e1,0x00000000}},	//   _cois_, bsuu, _èsò_, --, 
   {{0x3941fb43,0xe8d802e3,0x2d85fb44,0x79580131}},	//   _dois_, _nkụ_, mome_, тияр_, 
   {{0x7bdc16b8,0x6b440ba1,0x3941fb45,0xaa9401d5}},	//   _æqua, _pògu, _eois_, _йилч, 
   {{0x39402047,0xe8d800b4,0xf64401d5,0x36d410e4}},	//   _fois_, _akụ_, ахтн, роср, 
   {{0x2d85fb46,0x97000131,0x02c800dc,0xb9e000d4}},	//   nome_, لېۋى, िर्न, _тіши, 
   {{0x9c7c00b0,0x82b40327,0x00000000,0x00000000}},	// [39ad0] ngōp, _བཅདའ, --, --, 
   {{0x995003c6,0xa2d4f8e2,0x212c0030,0x39400010}},	//   máš_, ايات, _sneh_, _zois_, 
   {{0x6d5c0953,0x2d84a06b,0x9951fb47,0x02a52247}},	//   _įran, kome_, láš_, трам, 
   {{0xe5341c65,0x2d840006,0x7bd9500e,0x39400165}},	//   _семь, jome_, ysuu, _xois_, 
   {{0x2d85fb48,0xdee5fb49,0x995002fb,0x7bd8058a}},	//   dome_, голи, náš_, xsuu, 
   {{0x20d001dc,0xd00c0075,0xef84109a,0xe2c8aebe}},	//   ại_, سلى_, аліп, _سورو_, 
   {{0x2d85fb4a,0x629401a9,0x995002f0,0xfce01171}},	//   fome_, _uzzo, háš_, ҳоқо, 
   {{0x2d85fb4b,0x7bd80af5,0x99500122,0x212c0c6a}},	//   gome_, tsuu, káš_, _uneh_, 
   {{0x3941fb4c,0x5f95fb4d,0x7bd9fb4e,0x60d8014f}},	//   _rois_, _биат, usuu, mawm, 
   {{0x7bd80680,0x394138c8,0x99500122,0x60d8f23a}},	//   rsuu, _sois_, dáš_, lawm, 
   {{0x3941fb4f,0x7bd9bfba,0x2d8405e4,0xda649214}},	//   _pois_, ssuu, bome_, увни, 
   {{0x2d85fb50,0x7bd8023a,0x60d80309,0x15a00131}},	//   come_, psuu, nawm, _ﺋﺎﺋﯩ, 
   {{0x3941fb51,0xb8cc0882,0xded4001f,0x7bd9fb52}},	//   _vois_, _कः_, _ራስን_, qsuu, 
   {{0x60d803f0,0x00000000,0x00000000,0x00000000}},	//   hawm, --, --, --, 
   {{0x4cd404c5,0x7ae0035a,0x9599fb53,0x3941fb54}},	//   _ধাতু, _idnt, етау_, _tois_, 
   {{0x99500306,0x52740116,0x23b403ce,0x00000000}},	//   báš_, қузу, _अंशद, --, 
   {{0xb4e40034,0x94240024,0x69dc00e4,0x142400c7}},	// [39ae0] _नयी_, ымае, árev, ыдам, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x99e00729,0x10700952,0x2d84037e,0x00000000}},	//   _বহুক, ﻻﺭﺩﯨ, yome_, --, 
   {{0xdb0806ed,0x2d84056a,0xe19401c6,0x00000000}},	//   mpeõ, xome_, арчэ, --, 
   {{0x2d85fb55,0x7ee00131,0xc0e035dd,0xf1e003e5}},	//   vome_, ڭكىن, сочк, _पटकन, 
   {{0x07f00156,0x2d84007f,0x8bc40131,0x6df4007b}},	//   _བཀལཝ_, wome_, қсид, لكتا, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe6d00a94,0x00000000,0x00000000,0x00000000}},	//   _तज्ज, --, --, --, 
   {{0x7ae001e0,0x2d85fb56,0x2d581bce,0x2ec411ca}},	//   _bdnt, rome_, _léeg_, _көйм, 
   {{0x2d85fb57,0x3b5000f7,0x9950022a,0x00000000}},	//   some_, йкыр, váš_, --, 
   {{0xaa95fb58,0x7ae0020c,0x69340c9e,0x2d581bce}},	//   ринч, _ddnt, анну, _néeg_, 
   {{0xe9d80228,0x2d840117,0x6e280857,0x995013d5}},	//   нкү_, qome_, _irdb, táš_, 
   {{0xfce50661,0x26c400e8,0x48a80108,0x00000000}},	//   _صفوي_, ñloo_, этом_, --, 
   {{0x27b40184,0x99500306,0xb8cc1df0,0x00000000}},	//   ләүс, ráš_, _कृ_, --, 
   {{0x6b4401c3,0x05749bfe,0x00000000,0x00000000}},	//   _fògr, هارد, --, --, 
   {{0x69c9fb59,0x2d59ab98,0x995000d7,0x00000000}},	//   mpde, _déeg_, páš_, --, 
   {{0x69c9fb5a,0x2909fb5b,0x2d58002e,0x60dc00d0}},	// [39af0] lpde, _ibaa_, _téef_, _ôsmi, 
   {{0x6e2812ed,0x60d80784,0x00000000,0x00000000}},	//   _ordb, wawm, --, --, 
   {{0x627405d9,0x6594009b,0x09c40154,0xf7ac0150}},	//   جهائ, _вану, _শয়তা, _ﺳﻮﻣﺪ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x29083d27,0x6e29fb5c,0x60d8bcd4,0x00000000}},	//   _mbaa_, _ardb, rawm, --, 
   {{0x2d59dbd5,0x363401d5,0x60d80455,0xcee40108}},	//   _léed_, _ئریس, sawm, адше_, 
   {{0x2908016b,0x93c40311,0x60d8047e,0xb3540114}},	//   _obaa_, rtăş, pawm, _укрш, 
   {{0xf1a46afe,0x2fc400a3,0x60d8047e,0x3cec00c5}},	//   _грун, _ftmg_, qawm, छलें_, 
   {{0x6e283262,0x69dc00e4,0x00000000,0x00000000}},	//   _erdb, âren, --, --, 
   {{0x2909fb5d,0x6b44067c,0xdb000036,0x2b9001ab}},	//   _abaa_, _sògr, mmlë, nàch_, 
   {{0x3f85fb5e,0xa3c80037,0xd6d00014,0x00000000}},	//   monu_, _ईऽऽ_, ۪قس_, --, 
   {{0x26c006d6,0xb4e434ef,0xd824084c,0x23ac0010}},	//   _afho_, _नये_, адми, _ožjo_, 
   {{0x2f2401ed,0x69c80051,0x00000000,0x00000000}},	//   ségű_, apde, --, --, 
   {{0x3f85fb5f,0x2908063f,0x81900023,0x6e2802d0}},	//   nonu_, _ebaa_, ዛረበሉ_, _yrdb, 
   {{0x597443a7,0x6db801e4,0x200c0066,0x24980139}},	//   _выпу, _aĉaj, _lpei_, _azsm_, 
   {{0x3f84f43c,0x29092d9e,0x9f140327,0x7804008e}},	//   honu_, _gbaa_, _ཊིའཀ_, _лүма, 
   {{0x25a400cf,0x49180073,0x00000000,0x00000000}},	// [39b00] ïlla_, _बसतो_, --, --, 
   {{0x3f85fb60,0x42c40212,0xa6c80451,0x00000000}},	//   jonu_, игун_, _ٽوٽل_, --, 
   {{0x3f84601a,0x200dfb61,0xe8d80022,0x8b54008f}},	//   donu_, _apei_, _akỹ_, סיעס_, 
   {{0x27ec5166,0x4fc47969,0xd024010b,0x98bc0153}},	//   šene_, аска, имей, ėtė_, 
   {{0x96d837c8,0x00000000,0x00000000,0x00000000}},	//   _बजाउ, --, --, --, 
   {{0x200c0649,0x661800a2,0x3f88002b,0x00000000}},	//   _dpei_, _çaký, _ūcur_, --, 
   {{0xefb007d6,0xfde40075,0x00000000,0x00000000}},	//   _کیتگ, ңдәк_, --, --, 
   {{0x15ac0150,0x00000000,0x00000000,0x00000000}},	//   _ﺳﺎﺯﺩ, --, --, --, 
   {{0x60cdfb62,0x3f8401a9,0x200806af,0x7e6c06be}},	//   ñame, bonu_, çait_, _əkpə, 
   {{0x3f843ea7,0x00000000,0x00000000,0x00000000}},	//   conu_, --, --, --, 
   {{0x246c001f,0x5d5401e0,0xcd34bbcc,0xdb140332}},	//   _በመሄድ_, ркөт, _پراب, ábái, 
   {{0xbc64dbb4,0xb4c000bc,0x00000000,0x00000000}},	//   امین_, ँडो_, --, --, 
   {{0xb4c000bc,0x00000000,0x00000000,0x00000000}},	//   ँडै_, --, --, --, 
   {{0xa5f931c6,0x4785fb63,0x5c9401f7,0x00000000}},	//   легу_, рымб, _اُهڃ, --, 
   {{0xbb2801d3,0x6b89e075,0xbb38010f,0x00000000}},	//   _جتنے_, modg, _בעגי, --, 
   {{0x29080998,0x48640801,0x6b89fb64,0x2418034b}},	//   _ubaa_, _въоб, lodg, лобы_, 
   {{0x9fe011ba,0xc76404a9,0x3f844a4a,0xe4980139}},	// [39b10] _মঙ্গ, _نادى, yonu_, укач_, 
   {{0x609800d1,0x00000000,0x00000000,0x00000000}},	//   ۇناس_, --, --, --, 
   {{0x200c16b8,0x3f8419f5,0xc1a40a5b,0x8bfc00eb}},	//   _spei_, vonu_, ајди, ্টিন_, 
   {{0xf0e83ed0,0x2d581bce,0x6b887155,0xc0c800f3}},	//   لىمى_, _léeb_, hodg, туже_, 
   {{0x3f85fb65,0x00000000,0x00000000,0x00000000}},	//   tonu_, --, --, --, 
   {{0xff042cfe,0x6b881505,0x44281a9f,0x62341d39}},	//   рядн, jodg, _irc_, _легу, 
   {{0x3f85fb66,0xd5ac0014,0x644dfb67,0x31c41a6d}},	//   ronu_, _زہے_, lyai, _мств, 
   {{0x656dfb68,0x3f85fb69,0x20085941,0xdb0001c7}},	//   niah, sonu_, çais_, mmlé, 
   {{0x4428031c,0x3f85fb6a,0xdfd0188d,0x63a4007b}},	//   _jrc_, ponu_, _ريا_, omhn, 
   {{0x4428058a,0xef140228,0x656dfb6b,0x5ac80a89}},	//   _mrc_, _мүчө, hiah, ылом_, 
   {{0x5e940597,0x44288e2b,0x63a41549,0x656dfb6c}},	//   _الاط, _lrc_, imhn, kiah, 
   {{0x644dfb6d,0x44380175,0x6d34014b,0x00000000}},	//   kyai, kxq_, _мехф, --, 
   {{0x656dfb6e,0x3ab02b8d,0x17f8007b,0x6b89158a}},	//   diah, _мәнт, درجة_, bodg, 
   {{0x6b8400f7,0x8c40010b,0xe7380107,0xbac80064}},	//   _وشول, _хеше, қеӣ_, _рыдж_, 
   {{0xceb164c8,0xd94400ee,0x4429fb6f,0xcf900115}},	//   לים_, _гейи, _arc_, פטל_, 
   {{0xa9c403e6,0x656dfb70,0x00000000,0x00000000}},	//   _بزوو, giah, --, --, 
   {{0x7c39fb71,0x644dfb72,0x00000000,0x00000000}},	// [39b20] nxur, gyai, --, --, 
   {{0x7c29fb73,0x4429fb74,0x63a40332,0x27f40419}},	//   _mrgr, _drc_, gmhn, ňaný_, 
   {{0x4429fb75,0xc720010b,0x00000000,0x00000000}},	//   _erc_, _эдэй, --, --, 
   {{0x10a5fb76,0x63a400c6,0x7c280042,0x644dfb77}},	//   биен, amhn, _orgr, byai, 
   {{0x4429fb78,0x5ec800bd,0xfecc00bd,0x75240472}},	//   _grc_, _রয়ে, _রাজধ, mdiz, 
   {{0x9345fb79,0x6628007f,0x3fc801b9,0x8898011a}},	//   _унге, _èskò, ادنی_, נבסי, 
   {{0x7c2800a9,0x44280427,0x628001bf,0x00000000}},	//   _argr, _zrc_, _ølop, --, 
   {{0x7525fb7a,0xfe6cbd0e,0x39b40276,0x11a001ee}},	//   ndiz, عدو_, _găsi_, _эҫеү, 
   {{0x75240451,0xdd9000e5,0x00000000,0x00000000}},	//   idiz, بوٹ_, --, --, 
   {{0x7524913a,0x00000000,0x00000000,0x00000000}},	//   hdiz, --, --, --, 
   {{0x39b405f5,0x7c29fb7b,0xfb3001c0,0x19c000fb}},	//   йлээ_, _ergr, чнээ, үҙәг, 
   {{0x656dfb7c,0x644c0198,0x6b88c113,0x00000000}},	//   xiah, yyai, sodg, --, 
   {{0x7525fb7d,0x7c280010,0xc19808a8,0x656dfb7e}},	//   ddiz, _grgr, טשטי, viah, 
   {{0x4428003e,0x4ab9fb7f,0x3c740a1e,0x6b88022e}},	//   _rrc_, _судя_, _פתגם_, qodg, 
   {{0x44288c75,0x656dfb80,0xdb180af9,0x20dc0024}},	//   _src_, tiah, _ouwê, lšių_, 
   {{0x6d41fb81,0x644cd6bd,0x63a801c7,0xf31401c0}},	//   njma, tyai, _éenz, үдтэ, 
   {{0x656dfb82,0x6d4001a4,0x66c400d1,0x00000000}},	// [39b30] riah, ijma, _мәвж, --, 
   {{0x656c01a2,0x02a43252,0xa774030d,0x00000000}},	//   siah, брем, _флоч, --, 
   {{0x644c0a28,0x75240419,0xf1c81359,0x00000000}},	//   syai, bdiz, مولى_, --, 
   {{0x4429fb83,0x20dc0064,0x00000000,0x00000000}},	//   _trc_, kšių_, --, --, 
   {{0x6d4005a1,0x657c01a4,0x4429fb84,0xf524013d}},	//   djma, _ijsh, _urc_, _эфэн, 
   {{0x3e800023,0xdcec0205,0x00000000,0x00000000}},	//   _ይቕረታ_, _ıkıs, --, --, 
   {{0x622400d1,0x3944007c,0x00000000,0x00000000}},	//   _بىزل, ömsk_, --, --, 
   {{0x1be9fb85,0xdd900597,0x7c3801c6,0x5bc401d5}},	//   адии_, بوع_, txur, ойиб, 
   {{0x20180c86,0xdc8802d3,0xc058003b,0x00000000}},	//   _èsi_, _ምድላይ_, _сів_, --, 
   {{0x7c380213,0xdce80024,0x764803cd,0x25500051}},	//   rxur, mieč, ødyk, _hđlđ_, 
   {{0xdce9a353,0x9e747092,0x2a600198,0xdd940006}},	//   lieč, _بهات, _ƙiba_, _дажы, 
   {{0xdce800f3,0x63680213,0x76a001e1,0x20dc0064}},	//   dneć, _dönə, _láyí, bšių_, 
   {{0xdce999d7,0x1ae40209,0x7c28002f,0x00000000}},	//   nieč, _долм, _urgr, --, 
   {{0x657c036e,0x25500208,0xee38010a,0x00000000}},	//   _ajsh, _lđlđ_, _ннĕ_, --, 
   {{0xd9448db9,0x15b82fe5,0x27ec031c,0x00000000}},	//   _меки, рыгы_, ġena_, --, 
   {{0xdce802d5,0x00000000,0x00000000,0x00000000}},	//   kieč, --, --, --, 
   {{0xdce80024,0xdb0c0241,0x00000000,0x00000000}},	// [39b40] jieč, _òjób, --, --, 
   {{0x7525fb86,0x636800ac,0xdce8673c,0x00000000}},	//   sdiz, _yönə, dieč, --, 
   {{0x464400c0,0x00000000,0x00000000,0x00000000}},	//   _дзэн_, --, --, --, 
   {{0x1049fb87,0x6b6001e1,0x00000000,0x00000000}},	//   ияли_, _kágù, --, --, 
   {{0x60cc094a,0xcfa5fb88,0x53a4d31e,0x10158f14}},	//   ñama, ошки, _мамб, تباد, 
   {{0x2d81fb89,0x88980375,0x6b6001e1,0x8de800c7}},	//   čiem_, בבני, _mágù, афиа_, 
   {{0x49180490,0x00000000,0x00000000,0x00000000}},	//   _बसलो_, --, --, --, 
   {{0xd1300ada,0xdce800c0,0x00000000,0x00000000}},	//   _تمر_, bieč, --, --, 
   {{0xb054063f,0x2d9804e6,0x8b6400c6,0xceb40131}},	//   ọọrụ_, _ërem_, قادم, _һәқ_, 
   {{0x20dc0006,0x91e400b5,0x3e800023,0x0434010f}},	//   ršių_, _jeはu, _ይቕሬታ_, קטיש_, 
   {{0x6f18047e,0x00000000,0x00000000,0x00000000}},	//   mevc, --, --, --, 
   {{0x6b600241,0xfbcc0efb,0x6f1800f3,0x20dc00c0}},	//   _bágù, رتۋ_, levc, pšių_, 
   {{0x7d78010f,0x8b64007b,0x00000000,0x00000000}},	//   _דראג, _واتم, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc4d815ed,0xb6040cc9,0x00000000,0x00000000}},	//   иђа_, мятк, --, --, 
   {{0x6f180455,0x057401d5,0x26cc01e4,0x00000000}},	//   hevc, زازد, ŝeo_, --, 
   {{0x23b400f7,0x34940107,0x00000000,0x00000000}},	// [39b50] سماس, датр, --, --, 
   {{0x2919fb8a,0x6f1817a3,0xdb1800f2,0xdce9fb8b}},	//   lesa_, jevc, _cuwè, vieč, 
   {{0xf77057d4,0xdb19fb8c,0x6f194911,0x61140150}},	//   _جاي_, _duwè, devc, здеу, 
   {{0xdce80024,0xe038084c,0x657c0200,0x00000000}},	//   tieč, йзеч_, _ujsh, --, 
   {{0x25a9fb8d,0x6724007d,0x00000000,0x00000000}},	//   mmal_, _kahj, --, --, 
   {{0x2919fb8e,0x25a9fb8f,0x6725fb90,0x7bdc0381}},	//   hesa_, lmal_, _jahj, _æqui, 
   {{0x2919fb91,0x6725fb92,0x63b4014b,0x25a80548}},	//   kesa_, _mahj, _iizn, omal_, 
   {{0x25a9fb93,0x2919fb94,0x6725fb95,0x63bd7f52}},	//   nmal_, jesa_, _lahj, _kusn, 
   {{0x2919fb96,0x25a803fa,0x63b40946,0x71440137}},	//   desa_, imal_, _kizn, _تۉنۅ, 
   {{0x25a80730,0x92ac1c82,0x6725fb97,0x63b4c2aa}},	//   hmal_, ওঁৰ_, _nahj, _jizn, 
   {{0x25a9fb98,0x68fdfb99,0x61e4ad03,0x63b5fb9a}},	//   kmal_, fgsd, nshl, _mizn, 
   {{0x2919fb9b,0xad240075,0x201c022f,0x63bc02e2}},	//   gesa_, _يىلى, owwi_, _ousn, 
   {{0x6725fb9c,0x63bd187c,0xdb180066,0x25a80548}},	//   _bahj, _nusn, _luwé, dmal_, 
   {{0xac748818,0x63b400d7,0x00000000,0x00000000}},	//   _تامش, _nizn, --, --, 
   {{0x2919fb9d,0x63bc097d,0x67240978,0x8f980375}},	//   besa_, _ausn, _dahj, מישי, 
   {{0x63bc0cfd,0xdb180066,0x2d580694,0x06040b7e}},	//   _busn, _suwè, _léen_, янск_, 
   {{0xf48404fb,0x61e4062c,0x92e801b9,0x00000000}},	// [39b60] ذاری, eshl, йдаб_, --, 
   {{0x63bc0477,0x25a9fb9e,0x0320121c,0x2d59bacc}},	//   _dusn, amal_, ндун, _néen_, 
   {{0xdb180066,0x63b42625,0x69c400e2,0x62940051}},	//   _cuwé, _dizn, _čiek, _cyzo, 
   {{0x2d8001a2,0x63bdfb9f,0xdb180214,0xdb0c09f3}},	//   čiek_, _fusn, _duwé, _ákær, 
   {{0x2d581bce,0x63bc003e,0xdb18020c,0x61e4286e}},	//   _béen_, _gusn, _tuwè, ashl, 
   {{0x29182f99,0x934547ad,0x63b40399,0x6e95fba0}},	//   zesa_, _энге, _gizn, милу, 
   {{0x2919fba1,0x6f182625,0x03a007d6,0x2d580221}},	//   yesa_, revc, _чиро, _déen_, 
   {{0x63bc3a97,0x2918004e,0x63b4022e,0x4f6443fb}},	//   _yusn, xesa_, _zizn, _کارف, 
   {{0x2919fba2,0x63bc0014,0x8e840214,0x00000000}},	//   vesa_, _xusn, _کلاه, --, 
   {{0xc610045e,0x63a83fa8,0xc0dc02d3,0x2d580de2}},	//   হিতা_, _èent, _ነሓሰ_, _géen_, 
   {{0xc3309b62,0x442401fb,0x7bc801a9,0xd6e000cc}},	//   גות_, ̉n_, _etgu, বলায, 
   {{0x6724014f,0x25a8344a,0x00000000,0x00000000}},	//   _sahj, xmal_, --, --, 
   {{0x68fdfba3,0x2d580694,0x8c340107,0xbd40007b}},	//   rgsd, _yéen_, _холӣ_, _سنوي, 
   {{0x2919fba4,0x68fc45a7,0xbb406d2a,0x63bdfba5}},	//   sesa_, sgsd, _печк, _rusn, 
   {{0x2919fba6,0x63b40552,0x25a80e78,0x65949c36}},	//   pesa_, _rizn, tmal_, даву, 
   {{0x63b5fba7,0x29180286,0x62940306,0x63bdfba8}},	//   _sizn, qesa_, _ryzo, _pusn, 
   {{0x68edfba9,0x25a9fbaa,0xdb180214,0x6724047e}},	// [39b70] _idad, rmal_, _suwé, _tahj, 
   {{0x02a4e21a,0x25a9fbab,0x63b401b9,0x63bc014f}},	//   прем, smal_, _qizn, _vusn, 
   {{0x60cdfbac,0xfe18032c,0x63b43421,0x8024004b}},	//   ñamo, _भैंस_, _vizn, ګرام, 
   {{0x63bc9400,0x61e40332,0x2d580694,0xc6100f22}},	//   _tusn, rshl, _séen_, হিদা_, 
   {{0x68ec01c8,0x63b40129,0x63bc0821,0x443dfbad}},	//   _mdad, _tizn, _uusn, _çu_, 
   {{0x6ee400d1,0xa2a40b67,0x00000000,0x00000000}},	//   ىسىل, _करप्, --, --, 
   {{0x68edfbae,0x6ee40691,0x9d4402dd,0x61e401d5}},	//   _odad, رسول, дейд, qshl, 
   {{0x27e9301c,0x68edfbaf,0x7bc804e6,0x2d580036}},	//   _ovan_, _ndad, _ptgu, _wéen_, 
   {{0x60c9b7b3,0x27e8017a,0xace8009f,0x00000000}},	//   _ifem, _nvan_, سريل_, --, 
   {{0x68edfbb0,0x224c00bc,0x00000000,0x00000000}},	//   _adad, _řeky_, --, --, 
   {{0x27e8159f,0x6f040051,0x00000000,0x00000000}},	//   _avan_, đict, --, --, 
   {{0xa2cd92ae,0xfd200133,0x7dc403b9,0xa2a407b7}},	//   दुत्, _سوتێ, _tısb, _करन्, 
   {{0x60c8013f,0x7d18004a,0x68ec0368,0x2d580de2}},	//   _mfem, meus, _ddad, _méel_, 
   {{0x68edfbb1,0x2d58002e,0x75e40100,0xaca80014}},	//   _edad, _léel_, _lčzň, _ژھیے_, 
   {{0x60c80076,0x99500306,0x59080137,0x27e80f85}},	//   _ofem, máž_, _дейм_, _evan_, 
   {{0x7d19fbb2,0x995002fb,0x2fc0010f,0x85b00139}},	//   neus, láž_, ŭigi_, кәяч, 
   {{0x27e80007,0x96b80228,0xaac4012c,0x00000000}},	// [39b80] _gvan_, _муну_, लुकक, --, 
   {{0x7d19fbb3,0x7bdc003a,0x995002fb,0x00000000}},	//   heus, _æquu, náž_, --, 
   {{0xc87c0639,0x2d58002e,0x7d19fbb4,0x27e804a7}},	//   raße_, _béel_, keus, _zvan_, 
   {{0x27e9fbb5,0x68ec01ab,0x00000000,0x00000000}},	//   _yvan_, _xdad, --, --, 
   {{0x2d5801c7,0xc0e1fbb6,0x7d19fbb7,0x27e8022e}},	//   _déel_, точк, deus, _xvan_, 
   {{0x3fc800f2,0xa2cc00cd,0xa0300137,0x4030064e}},	//   زدهی_, दुद्, دۉكت, тешс, 
   {{0x7d1996cc,0x42040364,0x60c9fbb8,0xb640037e}},	//   feus, _онро_, _ffem, _ｃｂ_, 
   {{0x7d19fbb9,0x217401c0,0xdc380790,0x2eec0042}},	//   geus, _зуур, _açıc, _wddf_, 
   {{0xef100228,0x68ec00a3,0x00000000,0x00000000}},	//   _бүлө, _rdad, --, --, 
   {{0x7f48004b,0x8e38143e,0x00000000,0x00000000}},	//   _وسلې_, _وسار_, --, --, 
   {{0x7d2404f3,0x2d580036,0x27e844b3,0xfdf803ce}},	//   örsä, _héem_, _svan_, _एमएस_, 
   {{0x7d1807e9,0x3d2804d3,0xdce801e4,0x00000000}},	//   ceus, _وتنی_, tleĥ, --, 
   {{0x2d581bce,0xc865fbba,0xed580419,0x00000000}},	//   _jéem_, фтни, _guľa_, --, 
   {{0xc050008f,0x00000000,0x00000000,0x00000000}},	//   דזש_, --, --, --, 
   {{0x7dc4825f,0x45480798,0x00000000,0x00000000}},	//   _kısa, очам_, --, --, 
   {{0x68edb285,0x6e3c0ffb,0xe9442bef,0x27e800b8}},	//   _udad, _àrbu, _سربی, _tvan_, 
   {{0x2d5820ef,0x27e801f0,0x6d4c0208,0x00000000}},	// [39b90] _réel_, _uvan_, _đoạ, --, 
   {{0x25083821,0xdb009cba,0x7d19fbbb,0x00000000}},	//   _کردی_, omlá, zeus, --, 
   {{0x7d19fbbc,0x00000000,0x00000000,0x00000000}},	//   yeus, --, --, --, 
   {{0x2d580036,0x99500f91,0xa0c4131e,0x7dc40205}},	//   _béem_, záž_, ريتو, _nısa, 
   {{0x7d1806af,0xe8d80248,0x00000000,0x00000000}},	//   veus, _nlọ_, --, --, 
   {{0x2d5804e6,0x6dc40372,0xde05fbbd,0x7d19fbbe}},	//   _déem_, چۅلۅ, епки, weus, 
   {{0xe8d827dd,0x3eb001e6,0x7d19fbbf,0xca6801d5}},	//   _alọ_, äxt_, teus, _kafе, 
   {{0xf1a401ec,0xb1a400c0,0x00000000,0x00000000}},	//   _арун, _ашук, --, --, 
   {{0x7d19fbc0,0x27ec151c,0x729801d9,0x21680209}},	//   reus, šenj_, _فضہس_, _диңи_, 
   {{0x7d19fbc1,0xaf3401d5,0x398403b9,0x00000000}},	//   seus, _لرمت, dısa_, --, 
   {{0x99500122,0xdd980122,0xcf8c0014,0x7d19fbc2}},	//   ráž_, plň_, _اژن_, peus, 
   {{0x25b80483,0x99500232,0x98b000cd,0xd9443aeb}},	//   _nisl_, sáž_, _anyā_, хеми, 
   {{0x99500306,0x2bb80d79,0xef98010a,0x00000000}},	//   páž_, _उंचा, _акăш_, --, 
   {{0xaff800a2,0x9b44009f,0x00000000,0x00000000}},	//   _çüňň, _سنبو, --, --, 
   {{0x59b8069f,0x25b8002f,0x07a0234c,0x00000000}},	//   _ईंटर, _bisl_, уарн, --, 
   {{0xa2cc1524,0x25b802e8,0x237000f3,0x6994035b}},	//   दुस्, _cisl_, _amzj_, _ирых, 
   {{0x25b804cc,0xe7f44530,0xdebc0092,0x00000000}},	// [39ba0] _disl_, _ичээ, ሰራን_, --, 
   {{0x78a55238,0x00000000,0x00000000,0x00000000}},	//   _iziv, --, --, --, 
   {{0xa2a42413,0xd1741688,0x00000000,0x00000000}},	//   _करण्, ныды, --, --, 
   {{0xef9401d5,0xd008ead2,0xe5b00046,0x00000000}},	//   چیرد, зеде_, _ﺳﺎﻳﻜ, --, 
   {{0xc0e4007b,0x7dc40139,0x00000000,0x00000000}},	//   رفون_, _rısa, --, --, 
   {{0x2d580694,0x3f6400d4,0x81cc00eb,0x00000000}},	//   _géej_, ничо_, _শির_, --, 
   {{0x82a1fbc3,0x2d580036,0xf7ac01ec,0x00000000}},	//   _барж, _wéem_, _ﺳﻮﻟﺪ, --, 
   {{0xd0090ba0,0x7dc4a090,0x7985fbc4,0xbd643cc5}},	//   _небе_, _qısa, _njiw, ерье_, 
   {{0xfbcd23d4,0x78a43a41,0x70540244,0x00000000}},	//   یتی_, _nziv, _جۆشا, --, 
   {{0x7984009f,0x2d58002e,0x00000000,0x00000000}},	//   _ajiw, _xéej_, --, --, 
   {{0x28f9fbc5,0x78a5b523,0xefe80092,0x38640092}},	//   мень_, _aziv, መወዝ_, _ሲመለሱ_, 
   {{0xc2780375,0x2fc001e4,0x00000000,0x00000000}},	//   לריי, ŭigu_, --, --, 
   {{0x7984003e,0x2d580548,0x00000000,0x00000000}},	//   _djiw, _léek_, --, --, 
   {{0x78a5fbc6,0xa5c40026,0x28d00f4a,0x00000000}},	//   _dziv, көме, _थ्रि, --, 
   {{0x78a4a21d,0xe695fbc7,0xfa302abb,0xca74013d}},	//   _eziv, тивы, _مريد, _яуды, 
   {{0xba980302,0x81cc00fe,0x3a34011a,0xbc4c0241}},	//   _מסוי, _শিল_, _טרום_, _ìṣíw, 
   {{0x2de40150,0x00000000,0x00000000,0x00000000}},	// [39bb0] _ﺍﻹﻴﻤ, --, --, --, 
   {{0xe654030d,0xc98400ec,0x00000000,0x00000000}},	//   _авоь, _تشڪي, --, --, 
   {{0xa4d89dc2,0x78a400f3,0x91c001e0,0xa2cc00cd}},	//   _одну_, _zziv, иәтл, दुष्, 
   {{0x60b49f21,0xdfd42cc8,0x20740064,0x00000000}},	//   نمائ, воды, кулё, --, 
   {{0x2ca00e89,0x00000000,0x00000000,0x00000000}},	//   _ùidh_, --, --, --, 
   {{0x21280219,0x8f6801d3,0xa0c400ec,0x7cf800fd}},	//   žah_, ولنے_, ريڪو, kärü, 
   {{0xa0c4009f,0x00000000,0x00000000,0x00000000}},	//   _ليزو, --, --, --, 
   {{0xa2cc090a,0x9c5822c3,0x2618012d,0xdb0c0241}},	//   दुर्, дшоу_, _पहनी_, _ákúr, 
   {{0x5f08033f,0xdfd021e7,0x5e580451,0x00000000}},	//   _साप्_, _ضيا_, _ڪلاس_, --, 
   {{0x2d580429,0xdb18000f,0xc100004b,0x764801f4}},	//   _léeh_, _suwâ, _جوړي, ädyk, 
   {{0x78a401ed,0x7cf8013d,0x00000000,0x00000000}},	//   _sziv, gärü, --, --, 
   {{0x3cec04cc,0x38640092,0x00000000,0x00000000}},	//   _udgv_, _ሲመልሱ_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd6d00bbf,0x290401ed,0xe8700023,0x7cf8008e}},	//   شقر_, őlap_, _ብኸምኡ_, bärü, 
   {{0x7ae00c8c,0xa754005b,0x9a880023,0x00000000}},	//   _ient, утящ, _ዓንኬል_, --, 
   {{0x7ae1fbc8,0x597400cf,0x6e3c00e5,0x00000000}},	//   _hent, _шылу, _árbe, --, 
   {{0xc950025f,0x7ae18409,0x1304014b,0x32180d63}},	// [39bc0] _כמה_, _kent, кзам, _spry_, 
   {{0x7ae1fbc9,0x1cc0031c,0x11d40024,0x00000000}},	//   _jent, _ཁུའ_, відр, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x377402dd,0x00000000,0x00000000,0x00000000}},	//   _шықс, --, --, --, 
   {{0xcfa824e0,0x7ae0cf56,0x855800f2,0xb4c0ac66}},	//   واتم_, _oent, _آشپز_, ुडी_, 
   {{0x7ae1036d,0x2ca00003,0x0e8c0092,0x35840092}},	//   _nent, _ġid_, _ምንዛሬ_, _የብቃት_, 
   {{0x2ca00114,0x91e40120,0xea000051,0x27ec025c}},	//   _šid_, _шове, _trẩy_, ġeni_, 
   {{0xdb18433e,0x7ae1b1be,0xdce803ee,0x2d9800e2}},	//   _auwà, _aent, rneğ, _īres_, 
   {{0x7104035b,0x4f0801ec,0x00000000,0x00000000}},	//   _аҧҵа, _онан_, --, --, 
   {{0x3a24020b,0x35b40034,0xc20c0014,0xcdf4010b}},	//   _bsnp_, ंगड़, _دٔہ_, _ачды, 
   {{0x7ae1fbca,0x6ed87ef5,0x8aa401d5,0xcd0400c0}},	//   _dent, _न्यु, ърид, _апей, 
   {{0x7ae1fbcb,0x5e78010f,0x00000000,0x00000000}},	//   _eent, _אָנד, --, --, 
   {{0x7ae1fbcc,0x27ece612,0x60cdfbcd,0x8c4453e8}},	//   _fent, éen_, ñami, _шеде, 
   {{0x9a9800ef,0x00000000,0x00000000,0x00000000}},	//   _ļāvā, --, --, --, 
   {{0xa9341411,0x00000000,0x00000000,0x00000000}},	//   _бейш, --, --, --, 
   {{0x7ae1fbce,0x5fa80892,0x00000000,0x00000000}},	//   _zent, _चीनल, --, --, 
   {{0x1cc01f21,0x7ae1fbcf,0x2908004e,0x1b2400eb}},	// [39bd0] _ཁུལ_, _yent, _icaa_, বারই_, 
   {{0x7ae00f71,0x05000154,0x00000000,0x00000000}},	//   _xent, উজের_, --, --, 
   {{0x36d801c6,0x63e400f1,0x69c8031c,0x60f80395}},	//   _шдээ_, _څېرې_, nqde, енея_, 
   {{0xfe4039b1,0xa4d40212,0x7dc40139,0x91c00166}},	//   یکای, _щомі, _sıso, сәрл, 
   {{0x80c8012c,0x9f5c002e,0x60d80142,0x73e400c0}},	//   ाडौं, luwé_, rbwm, _коўз, 
   {{0x2fc4022e,0xefe802d3,0x5f056d0b,0xdca40075}},	//   _dumg_, ዘለዋ_, узка, һайи, 
   {{0x6f08030d,0xa3c80034,0x43740131,0xdb18002e}},	//   _dcdc, _लंड_, _зуңт, _ruwà, 
   {{0xdca40075,0x29086fe8,0x7648005b,0x1d247745}},	//   лайи, _ncaa_, ädyi, умим, 
   {{0x7ae028cf,0x2d58002e,0x6f080175,0x9f5c0066}},	//   _pent, _léew_, _fcdc, huwé_, 
   {{0x69c401a2,0x7ae1d2e2,0x00000000,0x00000000}},	//   _čier, _qent, --, --, 
   {{0x7dc40365,0x2909fbd0,0xdb180034,0x2d580694}},	//   _kısm, _bcaa_, _stwó, _néew_, 
   {{0x7ae1fbd1,0x26c00bd7,0xefe8044e,0x29089ca8}},	//   _went, _agho_, ዘለዉ_, _ccaa_, 
   {{0x212c003e,0x3a2401f5,0x69c80009,0xada400d4}},	//   _maeh_, _wsnp_, aqde, _таїл, 
   {{0xda640a2c,0x212c0369,0xa8740a8f,0x7ae177b4}},	//   _ماعي, _laeh_, рующ, _uent, 
   {{0xdb000267,0x00000000,0x00000000,0x00000000}},	//   rmlä, --, --, --, 
   {{0x212c0399,0x1cc0031c,0x00000000,0x00000000}},	//   _naeh_, _ཁུས_, --, --, 
   {{0x3941fbd2,0x0441fbd3,0xdb180034,0x39840214}},	// [39be0] _inis_, бетн, _utwó, _میگف, 
   {{0xf98816cb,0x39400295,0xe3cc0154,0x91200055}},	//   _سنڌي_, _hnis_, _লিখব, _ṛṇaś, 
   {{0x2d5800e8,0x39400327,0x7dc40139,0x00000000}},	//   _géew_, _knis_, _qısl, --, 
   {{0xcfcc1884,0x867800d9,0x00000000,0x00000000}},	//   _ﻗﻮﺭﻗ, _טריו, --, --, 
   {{0x212c0007,0xefe8044e,0x8fd0053f,0x394001ab}},	//   _daeh_, ዘለዎ_, сәбә, _mnis_, 
   {{0xe8d8063f,0xd39401ee,0x00000000,0x00000000}},	//   _ijụ_, _сәбә_, --, --, 
   {{0x7f440dd8,0x3940014a,0xf1540133,0xd2501291}},	//   الىق_, _onis_, _پێشد, _انز_, 
   {{0x212c01ab,0xd174e8fc,0xefc40b82,0xefe80023}},	//   _gaeh_, _сыгы, ጸለይ_, ዘለው_, 
   {{0x290800ca,0x21740354,0x00000000,0x00000000}},	//   _rcaa_, _турр, --, --, 
   {{0x3941fbd4,0x0a694194,0x2909fbd5,0xefb001d5}},	//   _anis_, ерми_, _scaa_, _بیتگ, 
   {{0x212c0036,0x6e280332,0x69c80009,0x00000000}},	//   _yaeh_, _usdb, uqde, --, 
   {{0xe8640323,0x2d581574,0x02b4008f,0x39400332}},	//   ахгү, _réew_, טליך_, _cnis_, 
   {{0xec352596,0x4c54007b,0xe794527d,0x17800092}},	//   _خوشگ, _حضار, لاسک, _የህዝቡ_, 
   {{0x3941fbd6,0x00000000,0x00000000,0x00000000}},	//   _enis_, --, --, --, 
   {{0xe8d80521,0x29082e4b,0x39406a47,0xbb8000f1}},	//   _ajụ_, _tcaa_, _fnis_, _دلوي, 
   {{0x3941fbd7,0x9f5c020c,0x00000000,0x00000000}},	//   _gnis_, ruwé_, --, --, 
   {{0x212c0007,0x00000000,0x00000000,0x00000000}},	// [39bf0] _raeh_, --, --, --, 
   {{0x212c0097,0x00000000,0x00000000,0x00000000}},	//   _saeh_, --, --, --, 
   {{0x212c0438,0x02a5fbd8,0x82a4023a,0x5f741d0a}},	//   _paeh_, урам, ушае, یاتر, 
   {{0x27ec05ce,0x71f8004b,0x7dc40139,0x00000000}},	//   šenu_, ارلس_, _qısm, --, 
   {{0x307400db,0xdee407a5,0x00000000,0x00000000}},	//   йушс, аоли, --, --, 
   {{0x212c020c,0xb36402e8,0xe2f801ec,0x00000000}},	//   _waeh_, _лъск, _шегі_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4429fbd9,0x99d400f2,0x69c40171,0x00000000}},	//   _ksc_, یتجا, _čiep, --, 
   {{0x7dc470f7,0x44295644,0x60cc0309,0x35840092}},	//   _kısk, _jsc_, ñamu, _የጥቃት_, 
   {{0x44282238,0x00000000,0x00000000,0x00000000}},	//   _msc_, --, --, --, 
   {{0xd9440120,0x7dc40166,0xeec4310b,0x5dcc01ec}},	//   аени, _mısk, _ايمپ, _ﻗﺎﻣﺴ, 
   {{0x44280ac5,0x6e3c31b7,0x00000000,0x00000000}},	//   _osc_, _árba, --, --, 
   {{0x44280472,0x8d58008d,0xad242160,0x87e401e0}},	//   _nsc_, _שכני, _دىنى, аһың_, 
   {{0xeb08007b,0x7c29e88f,0x00000000,0x00000000}},	//   _مقهى_, _isgr, --, --, 
   {{0x55e43cc5,0x9994012d,0x00000000,0x00000000}},	//   робб, ęgło_, --, --, 
   {{0x3941fbda,0xc5602401,0x00000000,0x00000000}},	//   _unis_, окск, --, --, 
  
   {{0x4429fbdb,0xd7740ee8,0xe9a800ec,0xa3c8000d}},	// [39c00] _csc_, _نادع, _حدون_, _लूद_, 
   {{0xe618016c,0x7c280175,0x55e4004e,0x27ec0327}},	//   ъдӣ_, _msgr, _кооб, ġent_, 
   {{0x90c40261,0xa08801ec,0xc0d401f3,0x777c03b9}},	//   абее, ңсіз_, _ጭራሽ_, mirx, 
   {{0x63840588,0x765d4fb8,0x00000000,0x00000000}},	//   агӡа, myry, --, --, 
   {{0x4429fbdc,0x7524009f,0xfecc0183,0x00e4158b}},	//   _gsc_, meiz, _ৰাজধ, شتنی, 
   {{0x2d580548,0x7f7000d4,0x439000c0,0x00000000}},	//   _léet_, огіє, _маўс, --, 
   {{0x4429fbdd,0x00000000,0x00000000,0x00000000}},	//   _zsc_, --, --, --, 
   {{0x7525fbde,0x0fe0010b,0xebc4013d,0x00000000}},	//   neiz, _дөкү, бәкн, --, 
   {{0x8afc0c09,0x4429fbdf,0xcb44225f,0x765c00ee}},	//   _alƙa, _xsc_, ахни, hyry, 
   {{0x752403fa,0x8fa4010b,0x2d840334,0x765c010e}},	//   heiz, _тазе, snme_, kyry, 
   {{0x7c285410,0xaa95fbe0,0x7524037e,0x777c01a9}},	//   _esgr, синч, keiz, dirx, 
   {{0xdb0c025a,0x2d580de2,0x765c00ee,0x75240165}},	//   _âkîr, _céet_, dyry, jeiz, 
   {{0x2d581bce,0x75240165,0x777c025c,0x0b880108}},	//   _déet_, deiz, firx, _иски_, 
   {{0x6da40131,0xada40139,0x684400c7,0x98a00210}},	//   _тиҗа, _таҗл, анҭа, ndkę_, 
   {{0x75240007,0x765c0209,0x9940033f,0x44281587}},	//   feiz, gyry, _dół_, _ssc_, 
   {{0x442903a3,0x7c280cfd,0x2d5804e6,0x7ab80375}},	//   _psc_, _ysgr, _géet_, _בצוו, 
   {{0x6594023b,0x4429fbe1,0x7dc40139,0xa31801ec}},	// [39c10] _ҳану, _qsc_, _pısk, лжау_, 
   {{0xa0a40032,0x765dfbe2,0x00000000,0x00000000}},	//   ҙалд, byry, --, --, 
   {{0x44280009,0x7648005b,0x659400c0,0x7524bb50}},	//   _wsc_, ädyt, _гану, beiz, 
   {{0x44280354,0x2d5800e8,0x6d5c0022,0xdb18002f}},	//   _tsc_, _xéet_, _îrah, _zuwä, 
   {{0xf485fbe3,0xf7711ea4,0xd344035c,0xe2480150}},	//   _дурн, _رای_, _گیله_, _ءﻳﯩﺴ, 
   {{0x26d0033f,0x1fa8005b,0x00000000,0x00000000}},	//   nczo_, ыкли_, --, --, 
   {{0x2d58529d,0x2eb40395,0xd3440133,0x00000000}},	//   _nées_, осъс, _دیله_, --, 
   {{0x41751acc,0xc0c80798,0x00000000,0x00000000}},	//   _ئاسس, _јуве_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2d5800e8,0x00000000,0x00000000,0x00000000}},	//   _bées_, --, --, --, 
   {{0x3f84022f,0x49c401c6,0x4d8400ec,0x00000000}},	//   mnnu_, йлэн_, _گھوٽ_, --, 
   {{0x2d58226d,0x95c801b9,0x00000000,0x00000000}},	//   _dées_, ғлаб_, --, --, 
   {{0x99400034,0x7524030a,0xdd9802f0,0x765c0042}},	//   _pół_, veiz, moň_, wyry, 
   {{0x765dfbe4,0x2d5985af,0x7bd9fbe5,0x75240112}},	//   tyry, _fées_, mpuu, weiz, 
   {{0x7525fbe6,0x99d410e0,0x19f80276,0x3f84058a}},	//   teiz, _اتتا, _сэль_, innu_, 
   {{0x765c0022,0x89d401f7,0x00000000,0x00000000}},	//   ryry, _اوير_, --, --, 
   {{0x7525fbe7,0x7bd84969,0x83c010d9,0x2d580036}},	// [39c20] reiz, npuu, збуж, _kéer_, 
   {{0x7525fbe8,0xb9140055,0x2d580de2,0x765c035b}},	//   seiz, _adaḥ_, _yées_, pyry, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x50644ae6,0x1068e2cc,0xf4780220,0x4fc402d5}},	//   йтла, лией_, _көзі_, бска, 
   {{0x7bcd138e,0x674401d3,0xd43400c6,0x7f8000f1}},	//   ícul, _útjá, _اعجب, ګلون, 
   {{0x93c4054e,0xadd80024,0x152401af,0x00000000}},	//   grăş, амку_, _тєүг, --, 
   {{0xdef80953,0x5f080073,0x00000000,0x00000000}},	//   рыі_, _सार्_, --, --, 
   {{0x3f85fbe9,0x217401c0,0x2d580036,0xdb000200}},	//   annu_, _дуур, _rées_, bllë, 
   {{0x2d580036,0x00000000,0x00000000,0x00000000}},	//   _sées_, --, --, --, 
   {{0x6e3dc5a0,0x2618068f,0xbae005ac,0x00000000}},	//   _árbo, _पहली_, _মাউছ, --, 
   {{0xdc54ac42,0xdb00004a,0x2d5804e6,0x7f380375}},	//   مریک, illè, _déer_, _תעבו, 
   {{0x26d0012d,0xad2400cf,0x14d86a60,0xbdc800e5}},	//   wczo_, _گىچى, युमण, _صدمے_, 
   {{0x1cc02fb5,0x7bd804cc,0x2d580221,0x7c80014b}},	//   _ཁུག_, cpuu, _wées_, _нуше, 
   {{0x2d58002e,0x36d40107,0x478404b3,0x00000000}},	//   _géer_, зорр, сымб, --, 
   {{0x194c00b5,0xdb000200,0xc95801a9,0x00000000}},	//   _ｂｍｗ_, zllë, _бўп_, --, 
   {{0xdb000240,0x00000000,0x00000000,0x00000000}},	//   yllë, --, --, --, 
   {{0x3f840368,0x00000000,0x00000000,0x00000000}},	// [39c30] ynnu_, --, --, --, 
   {{0xe2f800d6,0x98b80055,0x00000000,0x00000000}},	//   режі_, _ãyāt_, --, --, 
   {{0x2918198f,0x6734002d,0xdb000450,0x6b8801bf}},	//   ofsa_, mdzj, rmlø, indg, 
   {{0xe70461f4,0xd498016c,0x6734045f,0xe6b410eb}},	//   _اسکی, урӣ_, ldzj, ंधीज, 
   {{0x1fb8dacb,0x60cc02d1,0x656c01ab,0x93c40356}},	//   алды_, ñamq, mhah, trăş, 
   {{0x656c0032,0x555032db,0x69d80139,0xdb00036e}},	//   lhah, _ٹھہر, _otve, rllë, 
   {{0x1cc0038f,0x67340b21,0x2d581bce,0x6614005a}},	//   _ཁུང_, idzj, _réer_, ntzk, 
   {{0x656c0c67,0x2d58002e,0x7f9c06af,0x5fa80ce0}},	//   nhah, _séer_, vêqu, _चीरल, 
   {{0x69d847c0,0xc4a40490,0x93c4054e,0x00000000}},	//   _atve, _खरोख, prăş, --, 
   {{0xdd9800ee,0x2918031c,0x6734007c,0x7bd80254}},	//   soň_, efsa_, jdzj, rpuu, 
   {{0xdd980313,0x656dfbea,0x7bd9fbeb,0x69d801ef}},	//   poň_, khah, spuu, _ctve, 
   {{0xdb0020ef,0x7bd9fbec,0x6734000f,0x98a400a7}},	//   illé, ppuu, edzj, жиме, 
   {{0x656dfbed,0x69d802d0,0xe8800023,0xb4b801f9}},	//   dhah, _etve, _ከቕርቡ_, _चणे_, 
   {{0x7bc81730,0xef84010a,0x00000000,0x00000000}},	//   _iugu, _ялĕп, --, --, 
   {{0x7bc9fbee,0x656c1682,0x7bc1fbef,0xc7a1fbf0}},	//   _hugu, fhah, _iinu, фирк, 
   {{0x7bc1fbf1,0x656dfbf2,0x6734000f,0x00000000}},	//   _hinu, ghah, adzj, --, 
   {{0x7bc09b94,0x7bc9fbf3,0x9f4c0022,0xed5800d7}},	// [39c40] _kinu, _jugu, _aveí_, _guľu_, 
   {{0x78a404ea,0x7bc1fbf4,0xdea003f9,0x2d58002e}},	//   _iyiv, _jinu, _walƙ, _léep_, 
   {{0x7bc9fbf5,0x161c0037,0x64c401e2,0x00000000}},	//   _lugu, _पहिर_, _ډيپل, --, 
   {{0x7bc07636,0xfbc46aed,0x656dfbf6,0x60cc0bc9}},	//   _linu, _يت_, chah, ñamp, 
   {{0x7bc1fbf7,0xdb00002e,0x00000000,0x00000000}},	//   _oinu, allé, --, --, 
   {{0x7bc1fbf8,0x78a586f1,0x00000000,0x00000000}},	//   _ninu, _myiv, --, --, 
   {{0xdbd006ed,0xdce801e4,0x00000000,0x00000000}},	//   qüên, sieĝ, --, --, 
   {{0x7bc0033d,0x7bc83aa2,0x78a40b6f,0x957802d3}},	//   _ainu, _bugu, _oyiv, _ከብቅዕ_, 
   {{0x7bc09b94,0x78a400ca,0x67340b21,0x768c0432}},	//   _binu, _nyiv, ydzj, _ỳyll, 
   {{0x7bc9fbf9,0x7bc1fbfa,0x656c0007,0x4ce003d4}},	//   _dugu, _cinu, zhah, _যাওঁ, 
   {{0x7a34063f,0x7bc9fbfb,0x5dcc06ba,0x8e8406c2}},	//   _ọtu, _eugu, _ﻗﺎﻳﺴ, _بلاه, 
   {{0x7bc01bb0,0x7bc8568a,0x78a40223,0x75b40490}},	//   _einu, _fugu, _byiv, ंगोळ, 
   {{0x78a40223,0x656c06d6,0xa3c8012d,0x00000000}},	//   _cyiv, vhah, _लूं_, --, 
   {{0x7bc0447c,0x656c0007,0x602002d2,0x00000000}},	//   _ginu, whah, _hámö, --, 
   {{0x69d8d961,0x656dfbfc,0x78a40921,0x7bc81196}},	//   _utve, thah, _eyiv, _zugu, 
   {{0x656dfbfd,0x7bc946c8,0x644dfbfe,0x9f5c007f}},	//   uhah, _yugu, txai, ntwò_, 
   {{0x7bc1fbff,0x7bc80009,0x63a4016d,0xb6080419}},	// [39c50] _yinu, _xugu, tlhn, teší, 
   {{0x656dfc00,0x27e9fc01,0x68ede413,0x7bc018f7}},	//   shah, _iwan_, _head, _xinu, 
   {{0x68ec15a5,0x656dfc02,0x27e84cdf,0x66140175}},	//   _kead, phah, _hwan_, qtzk, 
   {{0x27e80605,0x68ec0363,0x659428f3,0xb6440150}},	//   _kwan_, _jead, _хаму, _ﺍﺵ_, 
   {{0x657dfc03,0x68edfc04,0xb97c008f,0x802535c6}},	//   _imsh, _mead, סנדי, ترام, 
   {{0x27e815f5,0x68ed09fa,0x00000000,0x00000000}},	//   _mwan_, _lead, --, --, 
   {{0x7bc1fc05,0x7bc9fc06,0x27e81529,0x68ec031c}},	//   _rinu, _sugu, _lwan_, _oead, 
   {{0x7bc9fc07,0x68ec00c8,0x7bc1fc08,0x27e80076}},	//   _pugu, _nead, _sinu, _owan_, 
   {{0x7bc1fc09,0x6ed8038e,0x60c8000d,0x657c045a}},	//   _pinu, नुहु, _igem, _mmsh, 
   {{0x7bc97de6,0x78a40223,0x7bc00140,0x3cd80b27}},	//   _vugu, _ryiv, _qinu, _ग्रे_, 
   {{0x7bc1fc0a,0x27e84cda,0x60c816e3,0x7bc807a8}},	//   _vinu, _awan_, _kgem, _wugu, 
   {{0x68ec4ba3,0x27e9fc0b,0x7bc00477,0x7dc40166}},	//   _cead, _bwan_, _winu, _qısu, 
   {{0x7bc0a7ea,0x7bc801f7,0x68edfc0c,0x7d19fc0d}},	//   _tinu, _uugu, _dead, mfus, 
   {{0x657dfc0e,0x78a407a8,0x7c3805b8,0x7d19fc0f}},	//   _amsh, _vyiv, mvur, lfus, 
   {{0x68ec0ea3,0x27e8113c,0x7c39fc10,0xa75402e8}},	//   _fead, _ewan_, lvur, фтящ, 
   {{0x60c84ec2,0x68edfc11,0x27e8007f,0x15b8010b}},	//   _ngem, _gead, _fwan_, сыгы_, 
   {{0x78a5814b,0x27e9fc12,0x7d19fc13,0xb4cc0037}},	// [39c60] _uyiv, _gwan_, ifus, _लली_, 
   {{0x0838025f,0x60c9fc14,0x657dfc15,0x68ec0472}},	//   _פעיל, _agem, _emsh, _zead, 
   {{0x68ec0472,0x27e8002d,0x00000000,0x00000000}},	//   _yead, _zwan_, --, --, 
   {{0x4fc5510f,0x68ec056a,0x2eec0327,0x248c0024}},	//   пска, _xead, _sedf_, _žeme_, 
   {{0xdbd000f7,0xea0001fb,0x85b000d1,0x00000000}},	//   qüèn, _trầy_, _чәрч, --, 
   {{0x60c9fc16,0x00000000,0x00000000,0x00000000}},	//   _egem, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xebd868eb,0x515401a9,0x00000000,0x00000000}},	//   одиш_, _этгу, --, --, 
   {{0x68edb14f,0x7c383774,0x205406ed,0x3cf4007b}},	//   _read, gvur, _отфр, سعيد_, 
   {{0x68edfc17,0x27e9fc18,0x60c805be,0x44740375}},	//   _sead, _rwan_, _zgem, פעיל_, 
   {{0x68edfc19,0x7d18080d,0x5dd400d1,0xaa5885c0}},	//   _pead, bfus, _жючу, цину_, 
   {{0x7c38004c,0x27e802bd,0x4d743321,0x7dc40139}},	//   bvur, _pwan_, _عطار, _vıst, 
   {{0x68edfc1a,0x00000000,0x00000000,0x00000000}},	//   _vead, --, --, --, 
   {{0xb9041116,0x68ec0472,0xda6400ec,0x00000000}},	//   _प्_, _wead, _ڪاهي, --, 
   {{0x68ec033d,0x27e99a62,0xf7940006,0xa4d40816}},	//   _tead, _wwan_, харэ, добі, 
   {{0x27e9fc1b,0xc87c0e78,0xe50800f1,0x7dc408a9}},	//   _twan_, faßt_, تيرو_, _kısr, 
   {{0x27e80b45,0x973003e6,0xc2c80a11,0x349401ee}},	// [39c70] _uwan_, رکیا, مبال_, еатр, 
   {{0x7d0001e1,0xf2e800cc,0x60c80142,0x44380175}},	//   _kìrà, _পাউণ, _sgem, rvq_, 
   {{0x7c38004c,0xe6940276,0x00000000,0x00000000}},	//   zvur, _цины, --, --, 
   {{0x657c2f95,0x50a00075,0x7c387d4d,0x2508732b}},	//   _umsh, ھەلل, yvur, _بردی_, 
   {{0x91c07cdd,0x1ec8300e,0x00000000,0x00000000}},	//   тәрл, олли_, --, --, 
   {{0x25a9fc1c,0x7c39fc1d,0xf8380375,0x9c7c02b1}},	//   llal_, vvur, פנות_, kaōr, 
   {{0x7d183647,0x823406f6,0x60c804cc,0xf204023a}},	//   tfus, _عرسا, _tgem, _пято, 
   {{0x60c8b429,0x1c45b050,0x7dc40139,0x3134010b}},	//   _ugem, дним, _bısr, _песр, 
   {{0x7d19fc1e,0x9f040979,0x3ec40220,0x9c5801f4}},	//   rfus, _يورو, _есеб, юшку_, 
   {{0x7c38b3f8,0x7d000241,0x7d180240,0x25a8487e}},	//   rvur, _bìrà, sfus, hlal_, 
   {{0x7d180230,0x7de53bf2,0x25a9e2e1,0xa00c00af}},	//   pfus, _رسام, klal_, _समुझ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd0f40375,0x25a802f0,0x071c007a,0xc9d006be}},	//   ומרת_, dlal_, म्भव_, _müәy, 
   {{0x25a80076,0x4cb8011a,0x00000000,0x00000000}},	//   elal_, _ומנג, --, --, 
   {{0x64580bc9,0x46a000a7,0xf4880092,0x00000000}},	//   äwin, варв, _በመሸጥ_, --, 
   {{0x6601fc1f,0x699402d5,0xb4040137,0xdb0001e7}},	//   álka, _прых, нүмд, illí, 
   {{0x6294022e,0xf48405af,0x97b400fb,0x00000000}},	// [39c80] _axzo, راری, _осош, --, 
   {{0x91e4ed5a,0x25a89dce,0x1cc0031c,0x7dc4013d}},	//   доже, alal_, _ཁུན_, _mısq, 
   {{0x7e60005b,0xd174010b,0xb9c80092,0x00000000}},	//   jynp, мыды, _ተኛ_, --, 
   {{0x6e3c9ace,0xc87c0112,0xa3c81d34,0x00000000}},	//   _árbi, paßt_, _लूक_, --, 
   {{0x629405b1,0x2b58007c,0x00000000,0x00000000}},	//   _exzo, örck_, --, --, 
   {{0x0874010f,0x00000000,0x00000000,0x00000000}},	//   וענט_, --, --, --, 
   {{0x02c00131,0x03a0005b,0x00000000,0x00000000}},	//   _айро, _риро, --, --, 
   {{0x2b400356,0x8c6400d4,0x00000000,0x00000000}},	//   _şic_, дтод, --, --, 
   {{0xada401e0,0x00000000,0x00000000,0x00000000}},	//   маҫл, --, --, --, 
   {{0xff2000c7,0x7dc4013d,0xeb34215c,0x00000000}},	//   _имуо, _qısr, رىجد, --, 
   {{0xc3306da4,0x3339fc20,0x39e5fc21,0x00000000}},	//   דות_, _marx_, мьян_, --, 
   {{0x8f0c3105,0xde8800f2,0x00000000,0x00000000}},	//   _साँझ_, _عضله_, --, --, 
   {{0x2d85fc22,0x29040259,0x7878010b,0x7ae80174}},	//   mime_, ğla_, дйяр_, øltá, 
   {{0x29043559,0x333801b9,0x25a8062c,0x7d0001e1}},	//   şla_, _narx_, wlal_, _tìrà, 
   {{0xf99000f1,0x00000000,0x00000000,0x00000000}},	//   ابۍ_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8afc03f9,0xc3100241,0x8f0c1d8a,0x3835a4a0}},	// [39c90] _alƙi, _ajíṣ, _सांझ_, _аныр, 
   {{0x25a84ea1,0x2d85fc23,0x201800e2,0x87040014}},	//   slal_, hime_, _īsi_, _کٹھہ_, 
   {{0x2d85fc24,0xb7100724,0x02a41f99,0x466800d4}},	//   kime_, ñäşm, фрам, _єром_, 
   {{0x2d85fc25,0x25a9040a,0xc4c400ae,0x00000000}},	//   jime_, qlal_, _يتحو, --, 
   {{0x2d85fc26,0x83300022,0x83840024,0x00000000}},	//   dime_, _иҽах, _жыве, --, 
   {{0x2d840077,0x62800118,0x250800f2,0x00000000}},	//   eime_, _žlou, _برگی_, --, 
   {{0x2d85fc27,0x8f500202,0x4e0400bc,0x5dcc0150}},	//   fime_, انىش, संगै_, _ﻗﺎﻗﺴ, 
   {{0x5c55fc28,0x00000000,0x00000000,0x00000000}},	//   етоф, --, --, --, 
   {{0x7dc4723e,0x9f2000d1,0x7e603167,0x00000000}},	//   _qısq, _مۈشۈ, synp, --, 
   {{0x7e600649,0xf00001c6,0x908801d3,0xb4cc4709}},	//   pynp, _түши, _عملے_, _लल्_, 
   {{0x2d85fc29,0xdea068cf,0x1cc0031c,0x00000000}},	//   bime_, _حیثی, _ཁུམ_, --, 
   {{0x2d85fc2a,0xceb0010f,0xbf186c5a,0x00000000}},	//   cime_, _גיב_, प्रभ_, --, 
   {{0x7c640228,0x6994009d,0x00000000,0x00000000}},	//   _تاال, трэх, --, --, 
   {{0x90780375,0x75dc007f,0xdb1c0cad,0x00000000}},	//   לטרי, _lčze, _ìyàw, --, 
   {{0xba740372,0x00000000,0x00000000,0x00000000}},	//   _تاشت, --, --, --, 
   {{0x7dc400dd,0xc6c00006,0x65b801c0,0x3338031c}},	//   _műso, уйск, дуур_, _sarx_, 
   {{0x090079ac,0x09b4011a,0x00000000,0x00000000}},	// [39ca0] _спын, _אפקט_, --, --, 
   {{0x138800c6,0x64480064,0x8874011a,0x00000000}},	//   أخرى_, _šeic, _נתיב_, --, 
   {{0x2d85fc2b,0xa42c008e,0x00000000,0x00000000}},	//   yime_, _töşä_, --, --, 
   {{0x2d85fc2c,0x59b0ad78,0xe89801d3,0x28a40ebb}},	//   xime_, ीगिर, _ءمیں_, _गुडि, 
   {{0x2d85fc2d,0xa3c80401,0xb8200f4a,0x00000000}},	//   vime_, _लंच_, मझिम_, --, 
   {{0x6df400db,0x2d840548,0x248c01a8,0x00000000}},	//   نكتا, wime_, _þema_, --, 
   {{0xa3c835d7,0x60d80175,0x2214014b,0xe5cc0150}},	//   _लूट_, bcwm, _ифтр, _ﻓﺎﻟﻜ, 
   {{0x27f80076,0xb82007f7,0x308400fb,0x00000000}},	//   yssn_, मझाम_, _иҫем, --, 
   {{0xcfe8028e,0x00000000,0x00000000,0x00000000}},	//   _رفاه_, --, --, --, 
   {{0x2d85fc2e,0xfbcd0969,0x00000000,0x00000000}},	//   sime_, حتي_, --, --, 
   {{0xaa958493,0xe8f800f7,0x6e400133,0x8b6400db}},	//   тинч, үлү_, _ڕۆژم, _ۋاتم, 
   {{0x67d432b0,0xdb000798,0x998400c7,0x2d840200}},	//   кому, nolê, кәыз_, qime_, 
   {{0xc864b5f5,0x48a82d29,0x27f80036,0x00000000}},	//   хтни, ятом_, ussn_, --, 
   {{0x660000dd,0x64580054,0x28a407b7,0x00000000}},	//   álko, äwim, _गुणि, --, 
   {{0x5dcc2d40,0xb60400d4,0xdb1c01e1,0xa00c000d}},	//   _ﻗﺎﻟﺴ, лятк, _ìyáw, _सम्झ_, 
   {{0xa3c802ab,0xe9840150,0xa42c0092,0x00000000}},	//   _लूज_, _جاتۋ, _ስርጭት, --, 
   {{0x7ae401ed,0x29fc010f,0xd7e8075e,0x00000000}},	// [39cb0] űjte, lĉa_, _قويۇ_, --, 
   {{0x733802a9,0xdb000332,0xe69400ae,0x00000000}},	//   нзур_, ollá, _للخد, --, 
   {{0xf77096cb,0x71f8a32b,0x29fc010f,0xa1580063}},	//   _داي_, فرنس_, nĉa_, мажу_, 
   {{0x98b000b8,0x00000000,0x00000000,0x00000000}},	//   _hayā_, --, --, --, 
   {{0xd12c9528,0x443db2ff,0xfbe4004d,0x98b0002b}},	//   زمو_, _éu_, _chế_, _kayā_, 
   {{0x99740421,0x29fc0115,0x98b000b8,0xdb0001e3}},	//   vāō_, kĉa_, _jayā_, lmlö, 
   {{0x98b00a28,0xfe400131,0x00000000,0x00000000}},	//   _mayā_, умйү, --, --, 
   {{0x61e5fc2f,0xf1a5fc30,0xdca40075,0x27ec0118}},	//   mphl, _брун, кайи, šeny_, 
   {{0x5bb4412c,0xdfd4023a,0xc0d00023,0xfbe40208}},	//   ксоф, _розы, _ካሕሳ_, _ghế_, 
   {{0xdcf07bfb,0x0b400953,0xafc40150,0x98b0002b}},	//   ıgın, аньн, _ميقى, _nayā_, 
   {{0x3f85fc31,0x200800f3,0x61e5fc32,0xef908fde}},	//   minu_, šaid_, nphl, _دیود, 
   {{0x3f85fc33,0x69dc007b,0x00000000,0x00000000}},	//   linu_, írea, --, --, 
   {{0x8afc0c09,0xdb00007b,0x201c016b,0x28b80276}},	//   _alƙu, allá, ntwi_, еурэ_, 
   {{0x3f85fc34,0x201c004c,0x3898063f,0x69dc0115}},	//   ninu_, itwi_, ọro_, ŭrea, 
   {{0x98b0002b,0x787802d2,0x98a00064,0x00000000}},	//   _dayā_, _búvé, deką_, --, 
   {{0x3f85fc35,0x00000000,0x00000000,0x00000000}},	//   hinu_, --, --, --, 
   {{0xccf005e1,0x3f85fc36,0x79841d06,0x54c401e0}},	// [39cc0] יכן_, kinu_, _imiw, тбаб, 
   {{0xc8840730,0x2d58002e,0x98b000b8,0x166408ca}},	//   ößer_, _déey_, _gayā_, _авом, 
   {{0x3f840552,0x02c0011c,0x00000000,0x00000000}},	//   dinu_, айфо, --, --, 
   {{0xcfe403f4,0x4a580302,0x2d5800e8,0x27ec0276}},	//   _নিবন, ודעו, _féey_, ţene_, 
   {{0x3f840008,0xdb000200,0x98b000cd,0xe57401f0}},	//   finu_, golë, _yayā_, _сҷт_, 
   {{0x3f85fc37,0x6e95fc38,0x8e2401a9,0x00000000}},	//   ginu_, лилу, вфид, --, 
   {{0x6e2808a5,0x798401b3,0xdb01fc39,0x00000000}},	//   _qpdb, _omiw, molè, --, 
   {{0x2d5800e8,0xfbe401fb,0xc5f00375,0x00000000}},	//   _jéex_, _thế_, בדה_, --, 
   {{0x10a5fc3a,0x7e6c00ef,0x00000000,0x00000000}},	//   _риан, _čipš, --, --, 
   {{0x3f848265,0x7985fc3b,0xdb00004e,0xeab001d3}},	//   cinu_, _amiw, nolè, یٹک_, 
   {{0xe9f802d5,0x00000000,0x00000000,0x00000000}},	//   энні_, --, --, --, 
   {{0x7984020b,0x79a407d8,0x2d580de2,0xdb0000db}},	//   _cmiw, иряе, _néex_, holè, 
   {{0x38340209,0xdb01fc3c,0x00000000,0x00000000}},	//   аняр, kolè, --, --, 
   {{0x25741088,0x7984f1fe,0x248c0153,0xdb1801e1}},	//   _måle_, _emiw, _žemo_, _wuwò, 
   {{0xfbb40375,0xdb00004e,0x6ac00154,0x98b00055}},	//   _שפות_, dolè, _শ্রো, _vayā_, 
   {{0x6b8894ed,0x2d580de2,0x17e000fe,0x02c000cd}},	//   lidg, _péey_, _বিৰি, _वृषभ, 
   {{0x499004fb,0x2574005c,0x87040166,0x60cc0419}},	// [39cd0] _میگر, _nåle_, _ияне, žamk, 
   {{0xdb01fc3d,0x2575fc3e,0x38640267,0xe1d802dd}},	//   golè, _såld_, ämre_, еджі_, 
   {{0x69cc0295,0x2d580de2,0x00000000,0x00000000}},	//   _kiae, _féex_, --, --, 
   {{0x45a00075,0xa075e2f6,0x9f4c017a,0x3f85fc3f}},	//   _ئەرك, лгеч, _tweë_, winu_, 
   {{0x3f85fc40,0x2574049f,0x602405f5,0x41742421}},	//   tinu_, _våld_, удла, _یارس, 
   {{0x2fcc0c67,0x656dfc41,0x69cc0076,0x44282238}},	//   _cidg_, lkah, _liae, _ipc_, 
   {{0x3f85fc42,0x2d580de2,0xa19406ed,0x86280023}},	//   rinu_, _yéex_, _бавч, _ስውኣት, 
   {{0x656dfc43,0x3f85fc44,0x63a5fc45,0xdb01fc46}},	//   nkah, sinu_, lohn, molé, 
   {{0x69dc01f1,0xdb000789,0xdbc9fc47,0x44291b1c}},	//   íren, lolé, нгид_, _jpc_, 
   {{0x4428579b,0x69cc0086,0x75dc007f,0x656dfc48}},	//   _mpc_, _aiae, _lčza, hkah, 
   {{0x69cc1509,0x19888a6f,0x442804cc,0x656dfc49}},	//   _biae, ебни_, _lpc_, kkah, 
   {{0xfb50040b,0xad240075,0x63a431c5,0x46a400c5}},	//   ارکھ, _نىمى, hohn, _गड़ह, 
   {{0x63a5fc4a,0x69cc0dd4,0x656c0009,0x00000000}},	//   kohn, _diae, dkah, --, 
   {{0x2d58002e,0xdb000c6a,0x7c28035a,0x598400fb}},	//   _séex_, kolé, _ipgr, _әлиб, 
   {{0x656c3223,0xd9446f0c,0x2dd01870,0x00000000}},	//   fkah, _бейи, _ﻗﺎﻟﻤ, --, 
   {{0x656dfc4b,0x4429fc4c,0x7985fc4d,0xdb0001ef}},	//   gkah, _bpc_, _umiw, dolé, 
   {{0x3d19e570,0xd88801d9,0x23d40022,0x18680a42}},	// [39ce0] _याने_, _سپدن_, ацхр, _чапи_, 
   {{0x4429fc4e,0x656c166a,0x63a400d5,0x69cc0156}},	//   _dpc_, akah, gohn, _ziae, 
   {{0x4429fc4f,0x471800c8,0x97740124,0x2d58002e}},	//   _epc_, _אויג, _атҟә, _téex_, 
   {{0xdb019b92,0x7c282b94,0x2574003b,0x00000000}},	//   solè, _opgr, _påle_, --, 
   {{0x44280998,0x7525fc50,0x63a5fc51,0xdb00007f}},	//   _gpc_, mfiz, bohn, polè, 
   {{0xdb000098,0x257403cd,0x8898010f,0x00000000}},	//   bolé, _våle_, עבסי, --, 
   {{0x6b89fc52,0x7c2800da,0xdb011431,0x75240200}},	//   vidg, _apgr, colé, ofiz, 
   {{0x752521a9,0x6b89fc53,0x257432b8,0x7c28005a}},	//   nfiz, widg, _tåle_, _bpgr, 
   {{0x0b883849,0x4428030d,0x7524009a,0xac940220}},	//   есни_, _xpc_, ifiz, рапш, 
   {{0x69dc00ae,0x69d802db,0x20b801f4,0x00000000}},	//   íreo, _नंदी, _рысь_, --, 
   {{0x6b89fc54,0x8afc0198,0x69cc0194,0x9e645e79}},	//   ridg, _noƙe, _piae, _پالن, 
   {{0x1cdc0327,0xdb000108,0xdde801e2,0x63a40419}},	//   _ྡུར_, ellä, _شرمه_, zohn, 
   {{0x67d5e0ed,0xac180137,0x63a5fc55,0x6b89440b}},	//   рогу, _ролу_, yohn, pidg, 
   {{0x752401e2,0x4428045a,0xc6a400d8,0x00000000}},	//   efiz, _rpc_, грби, --, 
   {{0x63a5fc56,0x7525fc57,0x6d4001f5,0x656c023a}},	//   vohn, ffiz, odma, tkah, 
   {{0x63a40730,0xdb0006af,0x752401d3,0x7af40051}},	//   wohn, volé, gfiz, _ôxtr, 
   {{0x656dce2e,0x44281709,0x6b980327,0xdce8031c}},	// [39cf0] rkah, _qpc_, _kjvg, nneġ, 
   {{0xf4084d2d,0x656dfc58,0x7bddfc59,0xdb01fc5a}},	//   ايلى_, skah, _éque, tolé, 
   {{0x656c01af,0x63e4004b,0x6d4002d0,0x9f580248}},	//   pkah, _چېرې_, kdma, _ìsé_, 
   {{0xdb0002f0,0x6d41fc5b,0xf2c4024c,0x00000000}},	//   rolé, jdma, ссун, --, 
   {{0x4429fc5c,0xb97c04ac,0xdb004fc1,0x6488022e}},	//   _upc_, ענדי, solé, _qоid, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfd4c06d6,0x539804ae,0x69dc0077,0x6d4001a4}},	//   _zwiṱ, _יישו, írel, fdma, 
   {{0x6b9800b5,0x1a642c04,0x00000000,0x00000000}},	//   _ajvg, ییشی_, --, --, 
   {{0x28a426e4,0x9f5400f3,0x69dc01e4,0xdb000108}},	//   _गुलि, _квач, ŭrel, yllä, 
   {{0xdb840124,0x63a802d2,0x00000000,0x00000000}},	//   ргои, _íend, --, --, 
   {{0xafc40228,0x644800ef,0x00000000,0x00000000}},	//   _ايلى, _šeil, --, --, 
   {{0x18689dc2,0xa3d432ed,0x49c401c6,0x6d4002d0}},	//   вами_, हदा_, илэн_, cdma, 
   {{0x7c29fc5d,0x00000000,0x00000000,0x00000000}},	//   _upgr, --, --, --, 
   {{0xcb64cea2,0xcf9000c8,0x1ae5fc5e,0xa874023a}},	//   _ваше_, ַטן_, _токм, сующ, 
   {{0x7bd80ba7,0xcb10011a,0x00000000,0x00000000}},	//   lquu, _ולו_, --, --, 
   {{0x15b8dfe6,0xcfe400fe,0x1cdc0327,0xd87400f1}},	//   тыгы_, _নিসন, _ྡུས_, _ناخب, 
   {{0x31bc0316,0x7bd9fc5f,0xdd000118,0x394000c0}},	// [39d00] níze_, nquu, _štěr, _iais_, 
   {{0x39400b89,0x75240165,0xc2e40014,0x00000000}},	//   _hais_, sfiz, ٔٹٕم_, --, 
   {{0x7524a6b0,0x00000000,0x00000000,0x00000000}},	//   pfiz, --, --, --, 
   {{0x50643ced,0x3941fc60,0xa4e401b9,0xea8c010f}},	//   итла, _jais_, _гўёк, ענאָ, 
   {{0x39407086,0x00800323,0xbe3802d3,0x61e8022a}},	//   _mais_, олцо, _በርገሳ, _čele, 
   {{0x3941fc61,0x42e403b7,0x7bcc0268,0x845000db}},	//   _lais_, _вмро_, ìcul, _بۉكچ, 
   {{0x7f80021a,0x2574007c,0x40905224,0x4ca80154}},	//   تلون, _håla_, йрәт, খোঁ, 
   {{0x3941fc62,0xd17459b7,0x6d40007f,0x66001427}},	//   _nais_, _тыгы, udma, álki, 
   {{0x8b6401a9,0x7bf5fc63,0x00000000,0x00000000}},	//   لادم, аныр_, --, --, 
   {{0x2574b0aa,0xbf10767b,0x6d400589,0x316405c7}},	//   _måla_, _дүшә, sdma, _homz_, 
   {{0x31640dd4,0x394000a3,0x7bd8208d,0x28f998b7}},	//   _komz_, _bais_, aquu, лень_, 
   {{0x64480953,0x3941fc64,0xbd640063,0x00000000}},	//   _šeim, _cais_, _врше_, --, 
   {{0x3941fc65,0x7bd80014,0x2574143a,0x7c8002dd}},	//   _dais_, cquu, _nåla_, _муше, 
   {{0x3164009a,0x05d801ad,0x386401e3,0x00000000}},	//   _lomz_, _मंदब, ämra_, --, 
   {{0xc0f4044e,0x39400231,0xe8d80521,0x00000000}},	//   _ላዕሊ_, _fais_, _amụ_, --, 
   {{0x69d80483,0x3941fc66,0x224c16a3,0x00000000}},	//   _iuve, _gais_, _ček_, --, 
   {{0x68fdfc67,0x69d9d39d,0x00000000,0x00000000}},	// [39d10] masd, _huve, --, --, 
   {{0x68fdfc68,0x39400070,0x2258005b,0xc2c8cdd1}},	//   lasd, _zais_, лизы_, نبال_, 
   {{0x69d9fc69,0x3164009a,0x56f005f5,0xd460001f}},	//   _juve, _bomz_, _хүсс, _ተያይዞ_, 
   {{0x291854ba,0x31640369,0x69d9fc6a,0x68fdfc6b}},	//   ngsa_, _comz_, _muve, nasd, 
   {{0xdee40364,0x69d9fc6c,0x661401c4,0x00000000}},	//   боли, _luve, luzk, --, 
   {{0x69d9fc6d,0xd00c0046,0x6305fc6e,0x543800c8}},	//   _ouve, رلى_, _دوسل, _געשא, 
   {{0x69d9fc6f,0x3e3001ed,0x6615cbad,0xc291fc70}},	//   _nuve, تہار, nuzk, _بیاب, 
   {{0x7bd80357,0x31640dd4,0x68fc00de,0x59dc10eb}},	//   tquu, _gomz_, jasd, _नंबर, 
   {{0x394016cb,0x69d9fc71,0x5ba92aea,0x68fc29ef}},	//   _rais_, _auve, лким_, dasd, 
   {{0x3941fc72,0x69d9fc73,0x661401c4,0x25a800d8}},	//   _sais_, _buve, kuzk, hoal_, 
   {{0x3941fc74,0x69d9fc75,0xd944c23f,0x6614005a}},	//   _pais_, _cuve, бени, juzk, 
   {{0x69d9fc76,0x39400a2e,0x6614009d,0x68fc4892}},	//   _duve, _qais_, duzk, gasd, 
   {{0x3941fc77,0x7bd941ba,0xb900906f,0x69d8282c}},	//   _vais_, qquu, _तल_, _euve, 
   {{0x39402d6d,0x69d833e5,0x3e440208,0x00000000}},	//   _wais_, _fuve, _kđt_, --, 
   {{0x69d9fc78,0x39400190,0xdb00d829,0x2b1c045b}},	//   _guve, _tais_, nolí, _मातु_, 
   {{0x25a8037e,0x68fd6798,0x257403cd,0x394001c3}},	//   goal_, casd, _påla_, _uais_, 
   {{0x13040372,0x69d80730,0xdb000789,0x97340276}},	// [39d20] йзам, _zuve, holí, _лэнч, 
   {{0x8afc0198,0x69d9fc79,0x6734012d,0xdb000306}},	//   _koƙa, _yuve, cezj, kolí, 
   {{0x69d80f71,0x3e440208,0x00000000,0x00000000}},	//   _xuve, _nđt_, --, --, 
   {{0x25a80076,0xdb01fc7a,0x257401e3,0x7dc40139}},	//   coal_, dolí, _tåla_, _tısy, 
   {{0x62980112,0x2f8800fb,0xd25015b4,0x00000000}},	//   ßwor, аҙан_, _کنز_, --, 
   {{0xdb0001e7,0x527418a4,0xc5ec00f1,0x9f5801e1}},	//   allú, _лубу, _زړې_, _ìsì_, 
   {{0x31640a40,0xdb000561,0x68fc0083,0xfd600055}},	//   _tomz_, golí, yasd, _hotṛ, 
   {{0x69d9fc7b,0x8bc40131,0x69dc01e4,0x68fc2bcc}},	//   _ruve, әсид, ŭrek, xasd, 
   {{0x69d9fc7c,0x7ae000fb,0x0ca8023a,0x68fc0077}},	//   _suve, _bfnt, ытки_, vasd, 
   {{0x69d819f5,0x64480cf4,0xc4380375,0xae540451}},	//   _puve, _šeik, נתיי, _وراڻ, 
   {{0x68e86bdf,0x6934046e,0xdb000077,0x6614009d}},	//   ñedo, онну, colí, xuzk, 
   {{0x69d818f7,0xe9d80137,0x63100154,0x661401a9}},	//   _vuve, лкү_, স্পট_, vuzk, 
   {{0x68fdfc7d,0x69d8009a,0x25a80165,0x673401e4}},	//   rasd, _wuve, voal_, tezj, 
   {{0x69d8014a,0x661401c0,0x7bddfc7e,0xbb4000fd}},	//   _tuve, tuzk, _équa, _нечк, 
   {{0x6f080004,0xa5f9fc7f,0x68fc0455,0x67353fb4}},	//   _mddc, ребу_, pasd, rezj, 
   {{0x66140323,0x59dc0490,0xdb0000d8,0x68fc6064}},	//   ruzk, _नंतर, colâ, qasd, 
   {{0xf9940375,0x2908058a,0x24181507,0x661401c4}},	// [39d30] _מרק_, _idaa_, розы_, suzk, 
   {{0x66140323,0x27e8110e,0x25a82a1f,0x00000000}},	//   puzk, _itan_, soal_, --, 
   {{0xe6581f71,0xa4d402bf,0x25a8000f,0x6ea4000d}},	//   _тинч_, _моні, poal_, _चँगु, 
   {{0x6f09fc80,0x241808e2,0xdb001aa9,0x66001427}},	//   _addc, _комы_, volí, álku, 
   {{0x27e801f9,0x6f080334,0x3e4401fb,0xca78022e}},	//   _jtan_, _bddc, _sđt_, zetа, 
   {{0xdb01fc81,0x00000000,0x00000000,0x00000000}},	//   tolí, --, --, --, 
   {{0x27e807ab,0x29080ba7,0x9f5801e1,0x644800ef}},	//   _ltan_, _odaa_, _ìsí_, _šeih, 
   {{0x27e8cfb3,0xdb003a81,0x29088988,0xc17400cf}},	//   _otan_, rolí, _ndaa_, _ادست, 
   {{0x27e9fc82,0xdb010084,0x44380175,0x5de00150}},	//   _ntan_, solí, nwq_, _ﺇﻟﻬﻴ, 
   {{0x29089f02,0x1a04533f,0x31bc0306,0x3d180073}},	//   _adaa_, опом, míza_, _यावे_, 
   {{0x212c0098,0x31bc02fb,0xfa5017a5,0xdb00003b}},	//   _kbeh_, líza_, سردگ, illø, 
   {{0xae040220,0x38c4020c,0xdc7407e6,0xd8240798}},	//   _ءونى, jèré_, _мыль, одми, 
   {{0x7d1953dd,0x9138008f,0x00000000,0x00000000}},	//   mgus, בערק, --, --, 
   {{0x7d19fc83,0x7c39fc84,0x2908022f,0x27e8007f}},	//   lgus, mwur, _edaa_, _dtan_, 
   {{0x7c39fc85,0x27e8fbfb,0x99848073,0x212dfc86}},	//   lwur, _etan_, _ولتو, _obeh_, 
   {{0x27e80c86,0xacb000d1,0xaab8009f,0x00000000}},	//   _ftan_, _تەۋب, _ادهر_, --, 
   {{0x7c39fc87,0x61e809a8,0x17840022,0x7d19fc88}},	// [39d40] nwur, _čela, _мгим, igus, 
   {{0x2574049f,0x212c102c,0x3cfc0211,0xe578013e}},	//   _håll_, _abeh_, hauv_, азӣ_, 
   {{0x2b1c012c,0x7c38b915,0x63b800d7,0x00000000}},	//   _मासु_, hwur, _šanó, --, 
   {{0x27e801e6,0x7c39fc89,0x3898063f,0x46100133}},	//   _ytan_, kwur, ọru_, _کوێر, 
   {{0x4fc51376,0x7c38002d,0x32440092,0x00000000}},	//   оска, jwur, _የዚምባ, --, 
   {{0xfbc44732,0x7c393b12,0x7d19fc8a,0xdb00004e}},	//   _زت_, dwur, egus, jolà, 
   {{0x7c38002d,0x7d18002f,0xfbd40154,0xf07800fb}},	//   ewur, fgus, _দৌলত, риҙә_, 
   {{0xc0c40020,0x7c380b21,0x7d19fc8b,0x829000f7}},	//   ችልም_, fwur, ggus, _تۇمچ, 
   {{0x3b780020,0x7c3802e3,0x3d1800ab,0x09e001f9}},	//   _ብዙዎች_, gwur, _यारे_, पऱ्य, 
   {{0x7d18f4d1,0x27e801d5,0x80a0012c,0x53a80b98}},	//   agus, _rtan_, _छुटे, कविश, 
   {{0x27e9fc8c,0x3cfc0a73,0x1f58084c,0x7a34084c}},	//   _stan_, bauv_, _ушть_, опэр_, 
   {{0x7c3800ca,0x1cdc031c,0x00000000,0x00000000}},	//   bwur, _ྡུག_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb0035f5,0xbb4010fc,0x00000000,0x00000000}},	//   colà, _жељк, --, --, 
   {{0xfb842099,0x29080334,0x36d5fc8d,0xec1801af}},	//   _بدنی, _tdaa_, дорр, _теҙә_, 
   {{0x27e8005a,0xdb000e33,0xf3e400fe,0x00000000}},	//   _ttan_, molá, গঠনৰ_, --, 
   {{0x27e9fc8e,0xc2e825aa,0x76480b1a,0x4304007b}},	// [39d50] _utan_, لعام_, ådyr, قذاف, 
   {{0x7d1850bb,0x491000bc,0x00000000,0x00000000}},	//   zgus, थलको_, --, --, 
   {{0x7d18f3aa,0x35f40153,0x00000000,0x00000000}},	//   ygus, _опэр, --, --, 
   {{0x3634729b,0x7c38002f,0x248c0064,0xe73801af}},	//   _کریس, ywur, _žemu_, _теү_, 
   {{0xdb00007b,0x00000000,0x00000000,0x00000000}},	//   holá, --, --, --, 
   {{0xdb000765,0xd0041536,0x3fa80640,0x00000000}},	//   kolá, чеше_, шњем_, --, 
   {{0x212c03a2,0xd1c0001f,0x91540118,0x00000000}},	//   _tbeh_, ትሮች_, áříc, --, 
   {{0x7c38334b,0x7d19fc8f,0xf1cc0150,0xdb001aa9}},	//   twur, ugus, _ﺑﺎﻳﺘ, dolá, 
   {{0x7d19fc90,0x1c4400d4,0xad4400db,0x00000000}},	//   rgus, їном, بۉنۉ, --, 
   {{0x7d19fc91,0x7c39fc92,0x3cfc0218,0x18a40107}},	//   sgus, rwur, sauv_, ҷамм, 
   {{0x2b1c10f7,0x7c39fc93,0xd944a7c1,0xdb00c96f}},	//   _मारु_, swur, пени, rolà, 
   {{0x98a403fb,0x7c38000f,0x18a40117,0x00000000}},	//   зиме, pwur, замм, --, 
   {{0xf2b8227c,0x23bc258d,0x624c00a2,0x9f5802d2}},	//   _अर्घ, ्गाद, _ỳoly, _ísó_, 
   {{0x8c41fc94,0x4ba401ec,0xb8d4000d,0x2b180210}},	//   _чеше, _елің, _जँ_, _दाएँ_, 
   {{0x07a016a8,0x41c80b02,0x00000000,0x00000000}},	//   харн, िषास, --, --, 
   {{0x18a5fc95,0x06a800bd,0xceb00375,0x6abc17da}},	//   _найм, _গৃহি, גיל_, ürfe, 
   {{0x38c9358d,0x64580054,0x1309fc96,0x7d0803ac}},	// [39d60] _باغی_, äwip, йнай_, _mdgs, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x11d5fc97,0x69dc0115,0x148800ec,0x00000000}},	//   ستاد, ŭrev, _ڇپجي_, --, 
   {{0x7ae401d3,0xc0e00022,0x00000000,0x00000000}},	//   űjth, еоцк, --, --, 
   {{0xdb0001ed,0x7bc00306,0xc100009a,0x64480064}},	//   zolá, _ohnu, رووي, _šeiv, 
   {{0x8afc02a8,0x00000000,0x00000000,0x00000000}},	//   _roƙo, --, --, --, 
   {{0x82a0005a,0x00000000,0x00000000,0x00000000}},	//   _зарж, --, --, --, 
   {{0x7bc0101d,0xdb0004bf,0x78a40077,0xdb4c0133}},	//   _ahnu, volá, _oxiv, یێن_, 
   {{0xe7e001ad,0x5eac0154,0x00000000,0x00000000}},	//   _गंधा_, টেলে, --, --, 
   {{0xfc2c0d7a,0xfbcc04d3,0x7bc0952b,0xdb0001d3}},	//   احي_, ێتی_, _chnu, tolá, 
   {{0xddc002f0,0x6ea40da5,0xf1dc07b7,0x00000000}},	//   _oslň, _चुचु, यदिन, --, 
   {{0x0dc8084c,0xdb0001ed,0xfa840137,0xe7e005b3}},	//   _улей_, rolá, ясый_, _गंदा_, 
   {{0x6c35fc98,0xe738052f,0x78a40165,0xdb0001ed}},	//   _آفتا, ҙең_, _cxiv, solá, 
   {{0xaae001ad,0x7bc000a3,0xdb0028cb,0x00000000}},	//   _नलिक, _ghnu, polá, --, 
   {{0x78a5fc99,0x61e802fb,0x3bb8011a,0xb8d411a6}},	//   _exiv, _čelo, _המגד, _जु_, 
   {{0x63a801e4,0x79a402d5,0x00000000,0x00000000}},	//   _ƭeno, _прые, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [39d70] --, --, --, --, 
   {{0x976802dd,0xb4ec000d,0x00000000,0x00000000}},	//   _ءﯨﺲ_, _छ्ीप_, --, --, 
   {{0xcfe400fe,0x00000000,0x00000000,0x00000000}},	//   _নিগন, --, --, --, 
   {{0xb6c4008e,0x00000000,0x00000000,0x00000000}},	//   _ясый, --, --, --, 
   {{0x78a4030a,0x657c0139,0x00000000,0x00000000}},	//   _xxiv, _ilsh, --, --, 
   {{0x644dfc9a,0xffa001c0,0x6305fc9b,0x92cc03d4}},	//   mvai, эллү, _زورل, ৰৰে_, 
   {{0xb9001b4b,0x2cb800ac,0x4528031c,0x62240131}},	//   _སྔ_, ərdi_, _སྡོར_, _تىزل, 
   {{0x1be8016c,0x7bc001c3,0xdecc0023,0x644dfc9c}},	//   одии_, _shnu, _ኣጆኻ_, ovai, 
   {{0x644dfc9d,0x6284002f,0x00000000,0x00000000}},	//   nvai, lzho, --, --, 
   {{0x644dfc9e,0xdfd00fb4,0x6284005a,0x00000000}},	//   ivai, _شيا_, ozho, --, 
   {{0x6285fc9f,0x644dfca0,0x05bc58c1,0xaf040014}},	//   nzho, hvai, ्षाब, _سون٘, 
   {{0xdde80214,0x62840156,0x661400d7,0x61e80171}},	//   _هرچه_, izho, drzk, _čell, 
   {{0x45280003,0xda080490,0x2d98016b,0x80cc015b}},	//   _སྡེར_, _विकत_, ɑre_, হুর্, 
   {{0x657c01d9,0xdb00004e,0xda64004b,0x00000000}},	//   _alsh, dolç, _ياغي, --, 
   {{0x6488022e,0x644c0254,0x00000000,0x00000000}},	//   _dоim, evai, --, --, 
   {{0x78a40211,0x00000000,0x00000000,0x00000000}},	//   _txiv, --, --, --, 
   {{0x62840156,0x644c3f20,0x93441d39,0x00000000}},	// [39d80] ezho, gvai, мнае, --, 
   {{0x657dfca1,0x38c401e1,0x5fe000c5,0x00000000}},	//   _elsh, _eèrí_, _पढ़ल, --, 
   {{0x644dfca2,0x6284014b,0x657c0175,0x00000000}},	//   avai, gzho, _flsh, --, 
   {{0xdb01fca3,0x00000000,0x00000000,0x00000000}},	//   lolä, --, --, --, 
   {{0xdb00004e,0xc48002d5,0xbf300131,0x00000000}},	//   colç, _аляк, چرىغ, --, 
   {{0xdb000077,0xb9000327,0x359c04b2,0xa3c00f4a}},	//   illó, _སཔ_, _ቀለበት_, ुषण_, 
   {{0xda08c853,0xfde40116,0x80cc00eb,0xc3200a5b}},	//   _विगत_, үдәк_, হুল্, _шмрк, 
   {{0x27ec0276,0xfe6c00db,0xdb0001f4,0x00000000}},	//   ţeni_, شدى_, holä, --, 
   {{0x4f240640,0xdb00005b,0xbd84007b,0x00000000}},	//   _одаб, kolä, بنين_, --, 
   {{0x2d9800dd,0xaca401f2,0x00000000,0x00000000}},	//   őre_, _nkụz, --, --, 
   {{0x644cfa0e,0xaa59fca4,0xfbcc007b,0xdb1000ae}},	//   zvai, чину_, جتي_, ógál, 
   {{0xaca40521,0x6d600122,0x1cdc0135,0x26c400d0}},	//   _akụz, ávač, _ཡུར_, ýlom_, 
   {{0x27edfca5,0xac580395,0x8b640116,0x00000000}},	//   ëen_, _халф_, _ياتم, --, 
   {{0xdb00006a,0x6284030a,0xbd840137,0x69dd72fd}},	//   golä, yzho, _ىنەن_, íres, 
   {{0x057448c1,0x45280135,0xe7e000e1,0xf6280212}},	//   وارد, _སྡུར_, _गंवा_, міти_, 
   {{0x644dfca6,0x62840219,0xb5580276,0x00000000}},	//   tvai, vzho, мисф_, --, 
   {{0x1cdc1e81,0x644dfca7,0xc7c4013e,0x3494014b}},	// [39d90] _ཡུལ_, uvai, _осои, ватр, 
   {{0x644dfca8,0x23b41473,0x62840112,0x657dfca9}},	//   rvai, رماس, tzho, _wlsh, 
   {{0x644dfcaa,0x6284030a,0xb9a401d3,0x00000000}},	//   svai, uzho, _سمیٹ, --, 
   {{0x628403bd,0x657c02d0,0x720400ec,0x00000000}},	//   rzho, _ulsh, ئونم, --, 
   {{0x06f02d8f,0x644c0007,0x443c067c,0x628400e5}},	//   _अभाव_, qvai, _èu_, szho, 
   {{0xa2943981,0x14bc0b02,0xdfd000e5,0x00000000}},	//   _загі, ्धरण, ھيں_, --, 
   {{0x6724022e,0x5fe0000d,0x00000000,0x00000000}},	//   _mchj, _पढवल, --, --, 
   {{0x1c45b293,0x31c40124,0x2d94858f,0x4e3000ec}},	//   еним, _асув, крыс, افيء, 
   {{0x67242b1d,0x00000000,0x00000000,0x00000000}},	//   _ochj, --, --, --, 
   {{0x61e80f03,0xa3c07e2a,0xdb00007c,0x00000000}},	//   _čelj, ुषि_, kolå, --, 
   {{0x201c0943,0x7e44010a,0x00000000,0x00000000}},	//   luwi_, _юхае, --, --, 
   {{0x6725fcab,0x213c0fac,0x1278008f,0x00000000}},	//   _achj, newh_, פארע, --, 
   {{0xa3c01d27,0xdea001e4,0xdb00005b,0x201c0327}},	//   ुषा_, _malƭ, tolä, nuwi_, 
   {{0x201c0280,0xedd40150,0x98b00139,0xa8740108}},	//   iuwi_, _كيەد, _qoyı_, тующ, 
   {{0xdb000267,0xcb100375,0x8f98011a,0x46a0ca08}},	//   rolä, _עלה_, לישי, гарв, 
   {{0x1cdc0003,0x201c034c,0x13e82e36,0xf4848f52}},	//   _ཡུས_, kuwi_, змай_, پاری, 
   {{0x98a00053,0xb35c1b49,0x201c01c8,0xdde000df}},	// [39da0] rekē_, _ሰማይን_, juwi_, _ĵuŝa, 
   {{0x201c0de2,0x00000000,0x00000000,0x00000000}},	//   duwi_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x201c02b9,0x10a43160,0x64500153,0x9878010f}},	//   fuwi_, ниен, _ūkiš, ּאַט, 
   {{0x201c1c06,0xc9e401ec,0x00000000,0x00000000}},	//   guwi_, _ﺍﻟﻤﻐ, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe2b400a8,0xdce8031c,0x00000000,0x00000000}},	//   _астэ, wieġ, --, --, 
   {{0x8c65fcac,0x201c0083,0xdce8025c,0x00000000}},	//   етод, buwi_, tieġ, --, 
   {{0xdbd0000d,0x00000000,0x00000000,0x00000000}},	//   büün, --, --, --, 
   {{0xc4d0010f,0xdce8031c,0x00000000,0x00000000}},	//   נגז_, rieġ, --, --, 
   {{0xc3306da4,0xdb00004e,0xe0d001d3,0x00000000}},	//   אות_, tllò, _مزے_, --, 
   {{0x67242b1d,0x4c8406bb,0x1ea815eb,0x00000000}},	//   _schj, _плев, _غالي_, --, 
   {{0x672402f0,0x7878010b,0x00000000,0x00000000}},	//   _pchj, ейяр_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xaa582099,0x659400d8,0x00000000,0x00000000}},	//   _آلبا_, ваву, --, --, 
   {{0x3ab805d0,0xf52401a9,0x00000000,0x00000000}},	//   _ממונ, лфун, --, --, 
   {{0x68ec4ba9,0xdc880240,0x00000000,0x00000000}},	// [39db0] _ifad, _ንድሓር_, --, --, 
   {{0x6725fcad,0x67d4365f,0x00000000,0x00000000}},	//   _uchj, _шопу, --, --, 
   {{0x02a5fcae,0x225800c6,0x24f80166,0xa300012d}},	//   храм, بلاد_, _онны_, _लजीज_, 
   {{0x60985dc6,0x00000000,0x00000000,0x00000000}},	//   وناس_, --, --, --, 
   {{0x2d85860a,0x201c0280,0x68ec01c8,0x84700092}},	//   dhme_, uuwi_, _mfad, _የመሆን_, 
   {{0x7bdc2047,0x2489fcaf,0x201c0784,0x02b00107}},	//   _équi, mzam_, ruwi_, _бигӯ, 
   {{0x2489fcb0,0x201c013f,0xdce8025c,0xa2941cd0}},	//   lzam_, suwi_, nieħ, _раві, 
   {{0x9f2004a9,0x24880109,0x2d840477,0xb60400d7}},	//   _چۈشۈ, ozam_, ghme_, ýšit, 
   {{0x248800b5,0xdbd00254,0x00000000,0x00000000}},	//   nzam_, püün, --, --, 
   {{0x68edfcb1,0x200c572a,0x24881505,0x00c006ba}},	//   _afad, _ivei_, izam_, _ﺩﻭﺳﺘ, 
   {{0x27f0016b,0xc0f402d3,0x2f18074d,0xdce8031c}},	//   ɔnnɔ_, _ዋሕስ_, _чохь_, jieħ, 
   {{0x2d85175e,0xf1cc0150,0x00000000,0x00000000}},	//   chme_, _ﺑﺎﻟﺘ, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2489fcb2,0x68ec0109,0x00000000,0x00000000}},	//   dzam_, _efad, --, --, 
   {{0x3c28005c,0x7ae400e5,0x00000000,0x00000000}},	//   løv_, űjts, --, --, 
   {{0x6b8400a2,0x00000000,0x00000000,0x00000000}},	//   _įigi, --, --, --, 
   {{0x44280353,0x25a40789,0xc4e00104,0x27f400d0}},	// [39dc0] _cqc_, élla_, ржуй, čaný_, 
   {{0xfa2c0489,0xd394b392,0xd78805d9,0x36fc025c}},	//   _ཨྱོན_, тәмә_, _آندو_, _དབྲལ_, 
   {{0x200c03a5,0x44291248,0x434054ea,0x24880109}},	//   _avei_, _eqc_, рехв, azam_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6a780af2,0x2488033f,0x3c280fac,0x027c01ef}},	//   _kúfú, czam_, jøv_, _číše_, 
   {{0x0874010f,0x53a5fcb3,0x00000000,0x00000000}},	//   כענט_, _рагб, --, --, 
   {{0x200dfcb4,0x2d859046,0x00000000,0x00000000}},	//   _evei_, thme_, --, --, 
   {{0x7525fcb5,0x82a001ec,0x00000000,0x00000000}},	//   ngiz, _тасж, --, --, 
   {{0x61e805a1,0x98bc0316,0x752401f7,0xcf4464b6}},	//   _čeli, ětě_, igiz, _инай, 
   {{0x2d84067d,0x2b80067c,0x68ecdeae,0x00000000}},	//   shme_, _bòca_, _sfad, --, 
   {{0x797c06d6,0x3f9820ef,0x3d180574,0x2b80067c}},	//   _ṅwam, èque_, _याचे_, _còca_, 
   {{0xfaa000d8,0x00000000,0x00000000,0x00000000}},	//   раџо, --, --, --, 
   {{0x25743c12,0x6d41fcb6,0xdce8025c,0x0b8800d8}},	//   _målt_, mema, wieħ, _оски_, 
   {{0x75240472,0x1b18009e,0xdb000419,0xdce80135}},	//   egiz, ত্বই_, zolú, tieħ, 
   {{0x35e410f5,0xe8d8063f,0x248802c4,0x0a8800db}},	//   ицтв, _inọ_, wzam_, _تئشى_, 
   {{0x68edfcb7,0x6d400d92,0x2488004e,0xdce8025c}},	//   _ufad, nema, tzam_, rieħ, 
   {{0xdb01fcb8,0xc7a800c6,0xdce80003,0x00000000}},	// [39dd0] volú, _يدخل_, sieħ, --, 
   {{0x6d41fcb9,0x7bdc7d53,0x2488a50e,0x752400ec}},	//   hema, _èque, rzam_, agiz, 
   {{0x6d41fcba,0x24880034,0x6595fcbb,0x3688010b}},	//   kema, szam_, _бану, _асян_, 
   {{0x6d41fcbc,0x6fc40ba1,0x44280051,0xe51c000d}},	//   jema, vòca, _tqc_, _फाटि_, 
   {{0x6d41fcbd,0xd12dfcbe,0x00000000,0x00000000}},	//   dema, سمو_, --, --, 
   {{0xe8d8063f,0x6d400daa,0xdb01fcbf,0x9c2400c2}},	//   _nnọ_, eema, solú, ҳдид, 
   {{0x6d40037e,0x712400d1,0x00000000,0x00000000}},	//   fema, _ھىكم, --, --, 
   {{0xe8d800b4,0x2b80068c,0x6fc51c14,0x3c285522}},	//   _anọ_, _ròca_, ròca, tøv_, 
   {{0xc6bcfebc,0x200c0124,0x1ae400d8,0x20181d0e}},	//   _আলোচ, _uvei_, лопм, _ísi_, 
   {{0x200800da,0x9ee80597,0x6d400607,0xdfd40220}},	//   šais_, _أفضل_, aema, _созы, 
   {{0x7dc400dd,0xdbd00209,0x7de402bf,0x7ac00107}},	//   _műsz, _güýj, _різд, ринҷ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdd980209,0x7c6400cf,0x795c0166,0x00000000}},	//   miň_, _جاال, _däwе, --, 
   {{0xdd980209,0x2b80180f,0x8c1808a8,0xdb000036}},	//   liň_, _tòca_, _נוצי, inlë, 
   {{0xdbd0007d,0xba740372,0x995000d7,0x00000000}},	//   _müüj, _جاشت, ešť_, --, 
   {{0xdd989398,0x00000000,0x00000000,0x00000000}},	//   niň_, --, --, --, 
   {{0x7525fcc0,0x7985fcc1,0x53c9b4a2,0xa3c000cd}},	// [39de0] rgiz, _iliw, егам_, ुषं_, 
   {{0x6d41fcc2,0x257401e6,0x25b80450,0x752401c4}},	//   zema, _sålt_, _eksl_, sgiz, 
   {{0x6d4000b4,0x7985fcc3,0x7cd800b8,0x8778010f}},	//   yema, _kliw, _hārī, _נאטי, 
   {{0x6d4001c4,0xd468781e,0x902806a6,0x7cd824cb}},	//   xema, _зиме_, ецка_, _kārī, 
   {{0xe3b000dd,0xdd980209,0x798450d8,0x7dc401ed}},	//   صرے_, diň_, _mliw, _fűsz, 
   {{0x6d41fcc4,0x7985fcc5,0x3f848da5,0x7bcc068c}},	//   wema, _lliw, ghnu_, ïcul, 
   {{0x6d41fcc6,0x7985fcc7,0xad240131,0x409111f6}},	//   tema, _oliw, لىغى, ирәт, 
   {{0x53a4a3c3,0xdd9809a5,0x644c00af,0x63e002dd}},	//   _раҳб, giň_, _üliõ, _اۋەل, 
   {{0x64580054,0xfd0c143e,0x016000db,0x10a4d4de}},	//   äwix, سجي_, _укто, _сиан, 
   {{0x7985c63e,0x3f840c5e,0xdbd1fcc8,0x00000000}},	//   _aliw, chnu_, _tüýj, --, 
   {{0x79840a40,0x4e1804fb,0x39e44bcc,0xc3b40a7c}},	//   _bliw, _ستاد_, льян_, רליץ_, 
   {{0x79840363,0x6d4001f0,0x00000000,0x00000000}},	//   _cliw, qema, --, --, 
   {{0x1cdc1b4b,0x79840fec,0x0c742f84,0xa7480023}},	//   _ཡུག_, _dliw, _حداد, _ብምፍጻ, 
   {{0xead4cadc,0x7984974e,0x60dc0030,0x31bc0306}},	//   _коль, _eliw, _úsme, mízu_, 
   {{0xa3440214,0x00000000,0x00000000,0x00000000}},	//   یپره, --, --, --, 
   {{0x7985fcc9,0x499007d6,0xf5e402dd,0x00000000}},	//   _gliw, _چیگر, сірм, --, 
   {{0x33f40597,0x3d1c006a,0x68fc06ea,0xc9e402dd}},	// [39df0] مسلس, läwü_, mbsd, _ﺍﻟﻀﻐ, 
   {{0xdd980510,0x99500306,0xf7f405af,0x22584627}},	//   ziň_, ršť_, _اسيد, кизы_, 
   {{0x69cdfcca,0x00000000,0x00000000,0x00000000}},	//   _khae, --, --, --, 
   {{0xc0f00023,0x00000000,0x00000000,0x00000000}},	//   _ሃቦም_, --, --, --, 
   {{0x7a38025a,0x9f04868d,0x5f049a88,0x349401fc}},	//   _kätö, لوشو, азла, _гаяр, 
   {{0x88c403f4,0x656dfccb,0x2574007c,0x7a380108}},	//   _এলাক, ljah, _tåls_, _jätö, 
   {{0xd5ac00f8,0xdd9809a5,0x1cdc0135,0x69cc00b0}},	//   _رہے_, tiň_, _ཡུང_, _ohae, 
   {{0x656dfccc,0x408400ee,0x5f44004b,0x00000000}},	//   njah, _йузб, انګل, --, 
   {{0xdca5fccd,0xe7e009d9,0x0d801feb,0xdd980510}},	//   рапи, _गंगा_, ільн, riň_, 
   {{0x60c8b71f,0x69cc003e,0xdd980209,0x308400c6}},	//   _izem, _ahae, siň_, _الكف, 
   {{0x69cc01ab,0x7f41fcce,0x6f6400f1,0xdd140271}},	//   _bhae, menq, _دهلم, _نواخ, 
   {{0x69cdfccf,0x7cd9fcd0,0x31bc013a,0x00000000}},	//   _chae, _pārī, bízu_, --, 
   {{0x69cc04fb,0x656c022e,0xed1800e5,0x6d2400e4}},	//   _dhae, djah, _صفوں_, ẽháp, 
   {{0x69cc18a6,0x60c8949e,0x7f41fcd1,0x7cd81c52}},	//   _ehae, _mzem, nenq, _cārū, 
   {{0x79840770,0xc7a017a0,0x7cd800b8,0x07a07d60}},	//   _tliw, цирк, _dārū, царн, 
   {{0x69cdfcd2,0x7985c8b3,0x7f4001f0,0x60c809a8}},	//   _ghae, _uliw, henq, _ozem, 
   {{0x60c80296,0x1305fcd3,0x6fc4067c,0x00000000}},	// [39e00] _nzem, изам, fòcl, --, 
   {{0x3b040113,0x656dfcd4,0x00000000,0x00000000}},	//   _jenq_, ajah, --, --, 
   {{0x60c9fcd5,0x3e4401d3,0x4718010f,0x658000c7}},	//   _azem, _nőt_, _בויג, ñyhá, 
   {{0x3161fcd6,0x7ae001c4,0x48500214,0x69cc0200}},	//   ñiz_, _lgnt, _اپیز, _xhae, 
   {{0x60c80034,0x7f400117,0x1b1c015b,0x7054007b}},	//   _czem, fenq, ব্যে_, إنتا, 
   {{0x60c9e0c4,0x7ae06085,0x7f40014b,0x52740137}},	//   _dzem, _ngnt, genq, _кубу, 
   {{0x60c9fcd7,0xd2502088,0x82a00408,0x00000000}},	//   _ezem, _بنز_, _дарж, --, 
   {{0x8d740228,0x00000000,0x00000000,0x00000000}},	//   شاعا, --, --, --, 
   {{0x7ae001e0,0x7f41fcd8,0x69cdfcd9,0x0ca80395}},	//   _bgnt, benq, _rhae, ътки_, 
   {{0x2a780fac,0x0434010f,0x3e4400e5,0x00000000}},	//   ørbo_, סטיש_, _főt_, --, 
   {{0x69cdfcda,0x3b040369,0x6f0803ac,0xe9d8004e}},	//   _phae, _denq_, _iedc, лмоч_, 
   {{0x6f080472,0x6b88003e,0x3a70109a,0xe7a001ec}},	//   _hedc, shdg, іляр, _ﺍﻳﺘﯟ, 
   {{0x69cc06d6,0x7cd81d76,0x63a40008,0x5eac015b}},	//   _vhae, _pārū, ynhn, য়েদে, 
   {{0x69cc0053,0x6f08047e,0xaa5801ed,0xbb40600f}},	//   _whae, _jedc, _ملتا_, _мечк, 
   {{0x69cdfcdb,0x7bddbb26,0x201c0007,0x656c3f17}},	//   _thae, _èqua, zrwi_, tjah, 
   {{0x6f08009a,0x201c03a2,0x7f400117,0x69cc00d8}},	//   _ledc, yrwi_, zenq, _uhae, 
   {{0x7f41fcdc,0x656dfcdd,0x7cd800b0,0x00000000}},	// [39e10] yenq, rjah, _tārū, --, 
   {{0x656dfcde,0x6f0801f5,0x60c8012d,0xc31c0154}},	//   sjah, _nedc, _rzem, ন্নি_, 
   {{0x60c800f8,0x27e83942,0x61e80063,0x656c0b4b}},	//   _szem, _huan_, _čels, pjah, 
   {{0x7f400107,0x6488022e,0x9f9400ee,0x8ebc0154}},	//   wenq, _dоir, _düýn_, েখাগ, 
   {{0x290872dc,0x3e4401ed,0x7f41fcdf,0x6f09fce0}},	//   _meaa_, _sőt_, tenq, _bedc, 
   {{0x290803a0,0x60c809a8,0x27e80022,0x6ee400d1}},	//   _leaa_, _vzem, _muan_, يسىل, 
   {{0x13a82352,0x27e9fce1,0x7f41fce2,0x6f080010}},	//   _صنفی_, _luan_, renq, _dedc, 
   {{0x7f40016d,0x29080421,0x00000000,0x00000000}},	//   senq, _neaa_, --, --, 
   {{0x60c9fce3,0x27e9fce4,0xfd500241,0x9f940254}},	//   _uzem, _nuan_, _kodẹ, _küün_, 
   {{0x29080093,0xdca4dbf4,0x7f4001f0,0xbbb008a3}},	//   _aeaa_, _қали, qenq, ुतेक, 
   {{0x26c00218,0xdce81710,0x9f9400c5,0xe7e0012d}},	//   _nyho_, lječ, _müün_, _गंजा_, 
   {{0x27e9fce5,0x18684834,0x3b040007,0xbd54010a}},	//   _buan_, гами_, _wenq_, _тĕми, 
   {{0x27e9fce6,0xb60800f3,0xdce816a3,0x96643c1a}},	//   _cuan_, _mišš, nječ, әкбе, 
   {{0x27e9fce7,0xd629fce8,0xcc540375,0xdb0c0108}},	//   _duan_, логе_, _לבני_, äkäv, 
   {{0x27e80072,0x26780262,0xaac402dd,0x00000000}},	//   _euan_, астэ_, _وتىن, --, 
   {{0x27e80368,0x00000000,0x00000000,0x00000000}},	//   _fuan_, --, --, --, 
   {{0x27e9cf85,0x27e00076,0x98142309,0xdb000790}},	// [39e20] _guan_, _fihn_, _اببا, kolü, 
   {{0x212c7480,0x1b180154,0x00000000,0x00000000}},	//   _aceh_, ত্রই_, --, --, 
   {{0x6f080324,0xdb000077,0x27e8009d,0x00000000}},	//   _redc, loló, _zuan_, --, 
   {{0x2c180490,0x6f08002f,0x4638010f,0x6abc002f}},	//   _दिलं_, _sedc, _געטע, ürfi, 
   {{0xdb00ba4a,0xc01000d6,0x212c0036,0x27e9fce9}},	//   noló, зміщ, _dceh_, _xuan_, 
   {{0xa2c00490,0x46100133,0x63c401af,0x602800d4}},	//   _वरच्, _بوێر, _маяҡ, ріїв_, 
   {{0x52840597,0x212c0ba1,0x6f080030,0xdb000030}},	//   _الأك, _fceh_, _vedc, holó, 
   {{0xdb005f5b,0x1ea8009f,0xc27801e4,0x00000000}},	//   koló, جاهي_, _גרלי, --, 
   {{0x809c0b4c,0x12c80150,0x0161223d,0x00000000}},	//   _खेपे, _ﺒﻭﻀﻭ, _экто, --, 
   {{0xdb0120c2,0x09b0228a,0x27e9fcea,0x29089280}},	//   doló, ीत्य, _ruan_, _seaa_, 
   {{0x29080418,0xfc2c030f,0x27e9fceb,0x25ec012d}},	//   _peaa_, وحی_, _suan_, _आंधी_, 
   {{0x27e9fcec,0xe86405f5,0x00000000,0x00000000}},	//   _puan_, охгү, --, --, 
   {{0x27e9fced,0xdb01fcee,0x39440037,0x00000000}},	//   _quan_, goló, õmsa_, --, 
   {{0x27e9fcef,0x00000000,0x00000000,0x00000000}},	//   _vuan_, --, --, --, 
   {{0x2908cf1c,0xaa940276,0xc31c0154,0x00000000}},	//   _teaa_, _фийч, ন্ডি_, --, 
   {{0x27e9fcf0,0xe8d802e3,0xb11401f2,0x1b1c0154}},	//   _tuan_, _alụ_, wụny, ব্দে_, 
   {{0xdb01fcf1,0x1cdc0327,0x00000000,0x00000000}},	// [39e30] coló, _ཡུབ_, --, --, 
   {{0xdce81711,0xdb01fcf2,0x00000000,0x00000000}},	//   vječ, lolò, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc0f4069c,0xdce89455,0x09a80729,0x36880184}},	//   _ዋዕላ_, tječ, _গীতা, _ысын_, 
   {{0xa069fcf3,0xa3d4db74,0x25a9fcf4,0x602400d4}},	//   рала_, _момч, mnal_, ідка, 
   {{0x25a808cd,0xdce81711,0x645dfcf5,0x36341a4b}},	//   lnal_, rječ, _irsi, _بریس, 
   {{0x3cd8069f,0xdce81f7f,0xdb01fcf6,0x95800023}},	//   खेने_, sječ, rolü, _ዓረብን_, 
   {{0x313414b7,0x645c05da,0x1cdc025c,0xdd90165e}},	//   _неср, _krsi, _ཡུད_, ظوظ_, 
   {{0x25a80649,0xdb01fcf7,0xe298329e,0x6ff40b24}},	//   inal_, dolò, _саң_, _فسلط, 
   {{0x645c2375,0x25a9e059,0xdb79fcf8,0x00000000}},	//   _mrsi, hnal_, рсиш_, --, 
   {{0x25a9fcf9,0xd9447b98,0x00000000,0x00000000}},	//   knal_, оени, --, --, 
   {{0xdb01fcfa,0x68e80306,0xdca400d1,0x25a9fcfb}},	//   toló, žedn, _қаһи, jnal_, 
   {{0x25a8016d,0x7cc434b1,0x645c00b8,0x52c407af}},	//   dnal_, _ازام, _nrsi, _वर्स, 
   {{0xdb005923,0x50d804ae,0x25a9fcfc,0x7d08cc26}},	//   roló, יקרא, enal_, _hegs, 
   {{0x645dfcfd,0xdb01fcfe,0xaae41ec7,0x95980121}},	//   _arsi, soló, _عسوو, атау_, 
   {{0xdb01fcff,0x00000000,0x00000000,0x00000000}},	//   colò, --, --, --, 
   {{0x7d08066d,0x98b000b8,0x00000000,0x00000000}},	// [39e40] _megs, _mayī_, --, --, 
   {{0x7d0801ed,0x2b80067c,0x25a9fd00,0x645c0010}},	//   _legs, _ròck_, anal_, _drsi, 
   {{0x645dfd01,0x2b8001ab,0x7d09fd02,0xdce80030}},	//   _ersi, _dòch_, _oegs, dieľ, 
   {{0x7d09709c,0x41b0006c,0x00000000,0x00000000}},	//   _negs, وملر, --, --, 
   {{0xc31c0183,0x7ff0e9ff,0x00000000,0x00000000}},	//   ন্ধি_, وسوا, --, --, 
   {{0x2b80033b,0x7d080037,0xc5ec00f1,0x00000000}},	//   _gòch_, _aegs, _سړې_, --, 
   {{0xed50aaac,0x7d08d664,0xdd8c0075,0x518400fb}},	//   ٹھا_, _begs, گۈن_, _һуҡа, 
   {{0xfe6c05d9,0xa42c001f,0x829000d1,0x412401ee}},	//   ئدو_, _ድርጅት, _غۇنچ, _мосо_, 
   {{0x7d09fd03,0xdb00067c,0xcb4401a9,0x00000000}},	//   _degs, volò, охни, --, 
   {{0x25a82753,0x7d08198f,0xdb0178b2,0x7c2c01ab}},	//   znal_, _eegs, enlâ, àcra, 
   {{0x25a8102c,0xdb011170,0xace400fb,0x00000000}},	//   ynal_, tolò, _ебеҙ, --, 
   {{0x6fc4004e,0x809c0073,0x9f580cad,0x00000000}},	//   dòci, _खेडे, _ìsò_, --, 
   {{0xdb001e7b,0x25a93542,0x00000000,0x00000000}},	//   rolò, vnal_, --, --, 
   {{0x7d0801f5,0xc7b80108,0x412c0092,0x2d8400a2}},	//   _zegs, рём_, ተሳሰቦ, lkme_, 
   {{0x6fc521c5,0x2b80033b,0xdb01fd04,0x7d0800e8}},	//   gòci, _ròch_, polò, _yegs, 
   {{0xc4f831f6,0x645c238f,0xa8140022,0x35680228}},	//   شعرا_, _prsi, _едиш, орун_, 
   {{0x25a9fd05,0xca700014,0x2b80033b,0x2d840254}},	// [39e50] rnal_, _رچھک, _pòch_, ikme_, 
   {{0x25a9fd06,0x03c40816,0x2d840254,0x00000000}},	//   snal_, ісам, hkme_, --, 
   {{0x6fc49972,0x00000000,0x00000000,0x00000000}},	//   còci, --, --, --, 
   {{0x2b800699,0xe7040014,0xdb000162,0x85a4119e}},	//   _wòch_, _بسکی, vnlí, _фјод, 
   {{0x645dfd07,0x7d080151,0x0ddc02d3,0x64c40592}},	//   _ursi, _regs, _ሓለፋ_, _ريسل, 
   {{0x644dfd08,0x7d0997e0,0x0ddc0023,0x00000000}},	//   mwai, _segs, _ሓለፈ_, --, 
   {{0x644c03cb,0x7d0805c7,0xdce80030,0x81680334}},	//   lwai, _pegs, rieľ, _краб_, 
   {{0x3cf4068f,0x644d5f6c,0x00000000,0x00000000}},	//   ीरें_, owai, --, --, 
   {{0x7d09fd09,0x5e583e1a,0x644c03cb,0xdce800d7}},	//   _vegs, _گلاس_, nwai, pieľ, 
   {{0x5f95fd0a,0x7d08fc85,0x644c0810,0x68e80118}},	//   _علائ, _wegs, iwai, žedl, 
   {{0x644ce02e,0xaf34036b,0x7d0801a9,0x5e5801e2}},	//   hwai, _ترقت, _tegs, _دلاس_, 
   {{0x66140034,0x644dfd0b,0xed580212,0x2d840072}},	//   dszk, kwai, _моє_, ckme_, 
   {{0x66140c57,0x00000000,0x00000000,0x00000000}},	//   eszk, --, --, --, 
   {{0x644c00a9,0xddc0219b,0x19a80137,0xcc74011a}},	//   dwai, _splň, ртүп_, _מענה_, 
   {{0x1c2002ab,0x6abc002f,0x247c0092,0x00000000}},	//   _मिडल_, ürft, _የመለስ_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x04400f37,0x98a4623a,0x14245238,0x2b80068c}},	// [39e60] нетн, _хипе, ядам, _sòci_, 
   {{0x38600086,0xc31c0011,0x00000000,0x00000000}},	//   _irir_, ন্সি_, --, --, 
   {{0x87780302,0xc0f000b7,0x394006af,0xe2a8009f}},	//   _האיי, _ግራም_, _kbis_, يامن_, 
   {{0x38601529,0x644cb0d0,0x3cf40034,0x6d5c00b0}},	//   _krir_, bwai, ीरों_, ērak, 
   {{0x17280135,0x765c017a,0x53bc00cd,0x183400df}},	//   _སྐོམ_, lvry, ्तदश, פאַל_, 
   {{0xfbc51198,0xb4d848ee,0xdd00002b,0x00000000}},	//   _ست_, ाधी_, _ātāp, --, 
   {{0x765c017a,0xadd804b0,0x00000000,0x00000000}},	//   nvry, омку_, --, --, 
   {{0xdb0026b7,0x321806af,0x3940007c,0x64640139}},	//   enlà, _ivry_, _nbis_, _ütiä, 
   {{0x2c1c0490,0xfbcc00ec,0x00000000,0x00000000}},	//   _मिळू_, گتي_, --, --, 
   {{0x3941fd0c,0x53bc21b8,0x765c0ea0,0x6614012d}},	//   _abis_, ्तिश, kvry, yszk, 
   {{0x394001ab,0x1728025c,0xfbcc00c6,0x38602ce8}},	//   _bbis_, _སྐེམ_, دتي_, _arir_, 
   {{0x644c03cb,0x661400e5,0x60cc025c,0x00000000}},	//   ywai, vszk, żame, --, 
   {{0x672001d3,0x53bc043e,0xfce4027d,0x99500153}},	//   óljo, ्ताश, _عفوي_, ešų_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x39400fac,0x765c0165,0xbb38010f,0x6614012d}},	//   _fbis_, gvry, _לעגי, uszk, 
   {{0x3860003b,0x644cf77b,0x00000000,0x00000000}},	//   _frir_, twai, --, --, 
   {{0x386004cc,0x76580024,0x644c0036,0x67b40114}},	// [39e70] _grir_, _švyt, uwai, _обиђ, 
   {{0x026811ed,0x644d906c,0x661400e5,0xa5540092}},	//   йшей_, rwai, pszk, ህበራዊ, 
   {{0x65944238,0x644deb43,0xd5b8016c,0x6fc4004e}},	//   _жану, swai, ёсӣ_, nòcu, 
   {{0x15f010f7,0x00000000,0x00000000,0x00000000}},	//   _आंतर_, --, --, --, 
   {{0x3219fd0d,0xdb0001b8,0xf7700133,0x1fb801ec}},	//   _evry_, molö, _شای_, олды_, 
   {{0xdb0001b8,0x00000000,0x00000000,0x00000000}},	//   lolö, --, --, --, 
   {{0xdce800e2,0x9f440200,0x6114009b,0x00000000}},	//   pieļ, _hilë_, _одву, --, 
   {{0x9d440124,0xdb00014a,0xdd8c00d1,0x00000000}},	//   феид, nolö, گۈچ_, --, 
   {{0x39400005,0x60cc025c,0x00000000,0x00000000}},	//   _rbis_, żamb, --, --, 
   {{0x38600139,0xdb0002d2,0x00000000,0x00000000}},	//   _rrir_, fnlá, --, --, 
   {{0xdb0001b8,0x00000000,0x00000000,0x00000000}},	//   kolö, --, --, --, 
   {{0x98a5830e,0x18a4328e,0xb60801ef,0x00000000}},	//   диме, дамм, _lišá, --, 
   {{0xdb00014a,0x1728031c,0x394006be,0x00000000}},	//   dolö, _སྐུམ_, _vbis_, --, 
   {{0x3860143a,0x765c017a,0x3f8400d7,0x00000000}},	//   _vrir_, tvry, nknu_, --, 
   {{0xcd500014,0xeb54215c,0x8af8011a,0xdb0002d2}},	//   _سى۪ک, _سىيگ, _והצי, folö, 
   {{0x995002d5,0xdb00014a,0x765c0af9,0x386000cd}},	//   ršų_, golö, rvry, _trir_, 
   {{0x765c05e4,0x00000000,0x00000000,0x00000000}},	// [39e80] svry, --, --, --, 
   {{0x15e40075,0xdb000200,0x00000000,0x00000000}},	//   _ﺋﺎﺩﻩ, dilë, --, --, 
   {{0xdb00014a,0x00000000,0x00000000,0x00000000}},	//   bolö, --, --, --, 
   {{0xdce800bc,0xd468041b,0xdb000200,0x10a40798}},	//   ěněn, _диме_, filë, миен, 
   {{0x7bc0a3a0,0x9f4402bd,0x2558009d,0x00000000}},	//   _oknu, _kilè_, _эрээ_, --, 
   {{0x9f44007f,0x00000000,0x00000000,0x00000000}},	//   _jilè_, --, --, --, 
   {{0x65740092,0x8e840023,0x00000000,0x00000000}},	//   _አለብህ_, _ጠርኒፉ_, --, --, 
   {{0xdb01fd0e,0x99840118,0x00000000,0x00000000}},	//   nnlæ, dulů_, --, --, 
   {{0x7e8402d5,0xdc440374,0xdb000240,0xe570010f}},	//   _įspū, _pūāh, cilë, אַי_, 
   {{0x9f440248,0xe0491147,0xff2068eb,0xdb000162}},	//   _nilè_, _عشقه_, _амфо, tnlá, 
   {{0xe9f800d3,0x2fdc0036,0x0e5401af,0x00000000}},	//   янні_, mmvg_, _юђар, --, 
   {{0x1ea81d57,0x8d740075,0x7c440267,0x4c680117}},	//   _عالي_, _تائا, örrå, _миен_, 
   {{0xdc4404fe,0x88b401e0,0xbd8402da,0xda140133}},	//   _tūāh, ьҫир_, _زنون_, وسێک, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9f45aa3c,0xdb0001b8,0xe6952cdc,0xba7007fc}},	//   _dilè_, tolö, хивы, _لايت, 
   {{0x0ca8030d,0xdb0008a5,0x00000000,0x00000000}},	//   _утçи_, gnlæ, --, --, 
   {{0x68edfd0f,0x9f4402e2,0xdb00162a,0x3f8402f0}},	// [39e90] _igad, _filè_, rolö, yknu_, 
   {{0x69dc21e3,0xdb01fd10,0xa2941cb8,0x9f44036e}},	//   lmse, anlæ, назі, _vilë_, 
   {{0x68ec073c,0x69dc03cd,0x00000000,0x00000000}},	//   _kgad, omse, --, --, 
   {{0x60b40131,0xa5c4008e,0x25ac0166,0x65940024}},	//   ىمائ, _чөге, _ñel_, _чаму, 
   {{0x68ec0117,0x2b80180f,0x69ddfd11,0x657c0072}},	//   _mgad, _jòcs_, imse, _iosh, 
   {{0x657dfd12,0x6305fd13,0x9f4400db,0x4438010a}},	//   _hosh, _سورل, _xilè_, mtq_, 
   {{0x657dfd14,0x68ec0050,0x7bdc01e5,0x2b80068c}},	//   _kosh, _ogad, _èqui, _lòcs_, 
   {{0x68edfd15,0x9f4402fb,0xdb01fd16,0x628400b5}},	//   _ngad, _milé_, milé, myho, 
   {{0x657dfd17,0x6fc40137,0x9f4401e1,0x7ff40214}},	//   _mosh, tòct, _lilé_, _آسرا, 
   {{0x61e9fd18,0x68edfd19,0x657dfd1a,0x60c9fd1b}},	//   _hiel, _agad, _losh, _iyem, 
   {{0x61e9fd1c,0xdb000af2,0x200c003e,0x60c9fd1d}},	//   _kiel, dolô, _hwei_, _hyem, 
   {{0x63a5fd1e,0x657dfd1f,0x200c0099,0x60c80337}},	//   hihn, _nosh, _kwei_, _kyem, 
   {{0x61e9fd20,0x6fc40137,0x9f45fd21,0x62840142}},	//   _miel, mòcr, _ailé_, hyho, 
   {{0x61e811f9,0x68ec08e7,0x60c894da,0x7c39fd22}},	//   _liel, _egad, _myem, mtur, 
   {{0x657c5c81,0xdb01fd23,0x61e80069,0xcb6400c9}},	//   _bosh, vilè, _oiel, _чаще_, 
   {{0x61e9fd24,0x60c9e0e4,0x657c1368,0x9f440241}},	//   _niel, _oyem, _cosh, _dilé_, 
   {{0x60c9fd25,0x657dfd26,0x809c11b1,0xdb00e0fd}},	// [39ea0] _nyem, _dosh, _खेले, tilè, 
   {{0x61e886ed,0x657c003e,0x9f4400d8,0x68ec0034}},	//   _aiel, _eosh, _filé_, _zgad, 
   {{0x657de045,0x61e9fd27,0x60c9fd28,0x6284bde2}},	//   _fosh, _biel, _ayem, gyho, 
   {{0x60c82aed,0x657dfd29,0x5efc00e1,0xbf300131}},	//   _byem, _gosh, रुस्_, ۇرىغ, 
   {{0x4fc50b8d,0x61e9fd2a,0x63a402b4,0x60c80796}},	//   нска, _diel, bihn, _cyem, 
   {{0x35780201,0x657dfd2b,0x60c80100,0x6285fd2c}},	//   _አለበት_, _zosh, _dyem, byho, 
   {{0x657dfd2d,0x7c39fd2e,0xd04c03be,0x61e9fd2f}},	//   _yosh, etur, _ədəb, _fiel, 
   {{0x61e9fd30,0x7c39fd31,0xd0100050,0x6c88023b}},	//   _giel, ftur, _ملر_, дшоҳ_, 
   {{0x7c396e94,0x60c9fd32,0xac95fd33,0x3cd800af}},	//   gtur, _gyem, тапш, खेले_, 
   {{0x61e9fd34,0x69dc0218,0x68ec0e89,0x043400df}},	//   _ziel, wmse, _sgad, עטיש_, 
   {{0x200c09f0,0x61e9fd35,0x68ec037e,0x7c395598}},	//   _zwei_, _čelz, _pgad, atur, 
   {{0x61e802c4,0xdb0001f4,0x69dc0254,0x80d4000d}},	//   _xiel, enlä, umse, _बरमे, 
   {{0x657dfd36,0x9f440270,0xcb680063,0x6285fd37}},	//   _rosh, _silé_, _наде_, zyho, 
   {{0x6d41fd38,0x657dfd39,0x67d40351,0x3c540139}},	//   lfma, _sosh, тогу, _чишэ_, 
   {{0x657dfd3a,0x68ec05d5,0x63a41d55,0x311000dc}},	//   _posh, _tgad, vihn, ाराः_, 
   {{0x657cf476,0xdb01fd3b,0x62840122,0x05743740}},	//   _qosh, vilé, vyho, رازد, 
   {{0x61e9fd3c,0x63a5fd3d,0x657dfd3e,0xf994008f}},	// [39eb0] _riel, tihn, _vosh, _תרפ_, 
   {{0x61e9fd3f,0x6285fd40,0x60c801b2,0x657dd129}},	//   _siel, tyho, _ryem, _wosh, 
   {{0x61e9fd41,0x657dfd42,0x60c8bffa,0xe5b43d48}},	//   _piel, _tosh, _syem, _айны, 
   {{0x63a4122d,0x1c20367a,0x61e802d3,0x6285fd43}},	//   sihn, _मिलल_, _qiel, ryho, 
   {{0x61e9fd44,0x29d80597,0xdce81e31,0x63a5fd45}},	//   _viel, méad_, mjeć, pihn, 
   {{0x61e9fd46,0xdce81f7f,0x60c9fd47,0xdb00ae51}},	//   _wiel, ljeć, _vyem, pilé, 
   {{0x61e9fd48,0x6d41fd49,0x7c39fd4a,0xdb0003cd}},	//   _tiel, ffma, wtur, nnlå, 
   {{0x7c38b265,0x1c4402bf,0x60c86d1f,0x29d8007b}},	//   ttur, вним, _tyem, néad_, 
   {{0x60c80b6f,0x200c138f,0x7c385bf6,0x6fc4004e}},	//   _uyem, _uwei_, utur, ròcr, 
   {{0x3d2401e1,0x825802d3,0x6d4001a4,0xbe6002dd}},	//   _bìwà_, _ቃልስታ, afma, _مۇتي, 
   {{0xdb0000d2,0x6fc400db,0x9e7401c8,0x9d18004e}},	//   bilî, pòcr, _جهات, _жоет_, 
   {{0x7c39bb74,0x00000000,0x00000000,0x00000000}},	//   ptur, --, --, --, 
   {{0x7c380cfe,0xdce80558,0x00000000,0x00000000}},	//   qtur, djeć, --, --, 
   {{0x3d2401e1,0xb8dc01f9,0x00000000,0x00000000}},	//   _fìwà_, _ॅड_, --, --, 
   {{0xdb000267,0xd4f4005b,0x4a700592,0x00000000}},	//   rnlä, вязы, _نُور, --, 
   {{0x63b40427,0xb40400f7,0x29d8007b,0x83740092}},	//   _ajzn, лүмд, géad_, _በማወቅ_, 
   {{0xd70406bb,0x5fc1c264,0xc480008e,0x74f400db}},	// [39ec0] _изпи, शकाल, алтк, _ەۋرا, 
   {{0x8cd402ab,0xb0e8031c,0x2ba40b8f,0xe3b40154}},	//   मेटो, _སུཏེ, गोपा, _জীবব, 
   {{0xdce9fd4b,0x91e40305,0xdbcc01e1,0x967400c0}},	//   bjeć, воже, _yóòy, _рыпі, 
   {{0x29d8007b,0x54d400c7,0xa22401b9,0x016008ca}},	//   céad_, _ацгу, ارله, икхо, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x5eac03f4,0x6f18027d,0xce3001e2,0x8898123b}},	//   য়েছে, ريبآ_, لوتک, ובני, 
   {{0xf3f400bd,0x03a09c0b,0x42e4014b,0x00000000}},	//   _ছবির_, _тиро, _амро_, --, 
   {{0x8c65fd4c,0x6d400112,0x06dc00cc,0x00000000}},	//   втод, ufma, বুকি, --, 
   {{0xc0e004c2,0x90c40417,0x00000000,0x00000000}},	//   _вотк, _рбае, --, --, 
   {{0xbe30129d,0x80d4012d,0x00000000,0x00000000}},	//   _چىلب, _बरते, --, --, 
   {{0xc3306da4,0x6d40002f,0xaa4400db,0xce480150}},	//   בות_, pfma, اچتى, _ізде_, 
   {{0x6f180fb7,0xfa3022cd,0x8d18e750,0x8274010f}},	//   lavc, گرید, _آزار_, דעטע_, 
   {{0xdce88185,0x00000000,0x00000000,0x00000000}},	//   vjeć, --, --, --, 
   {{0x6f180175,0x290401e4,0x0eb4216a,0xfa3005af}},	//   navc, ŝla_, _अखाड, درید, 
   {{0xca744990,0x78ac03e3,0x00000000,0x00000000}},	//   _шуды, _ənvə, --, --, 
   {{0x2b5c01a6,0xdb000158,0x391401d9,0xb604010b}},	//   _havc_, rnlå, _پوٝز, рярк, 
   {{0x2919fd4d,0x6f181225,0xe8d801f2,0x29d800ae}},	// [39ed0] masa_, kavc, _maị_, réad_, 
   {{0xdce81f7f,0x6f180f03,0x29d8007b,0x66140050}},	//   sjeć, javc, séad_, _مژرا, 
   {{0x6f1808a4,0x29180311,0x29d8007b,0x25ec033f}},	//   davc, oasa_, péad_, _आंटी_, 
   {{0x2919fd4e,0x3264675f,0xdcf802e2,0x611407a5}},	//   nasa_, штув, _powč, удду, 
   {{0x84940020,0xe04405c2,0x9f440ffb,0x84700092}},	//   _ለመሆን_, унли, _filì_, _ከመሆን_, 
   {{0x25a9fd4f,0x2489fd50,0x00000000,0x00000000}},	//   lial_, myam_, --, --, 
   {{0x2919fd51,0x68fc074d,0x2488d05c,0xa2940d30}},	//   kasa_, kcsd, lyam_, _саві, 
   {{0x2919fd52,0x29d80098,0x5a9402a9,0x00000000}},	//   jasa_, héab_, ғроф, --, 
   {{0x2489fd53,0x6f1805a1,0x9f440418,0x1be9255e}},	//   nyam_, bavc, _hilí_, ндии_, 
   {{0x25a9fd54,0x9f440270,0x61f4022e,0x6f180419}},	//   hial_, _kilí_, _kuzl, cavc, 
   {{0x25a9fd55,0x2919fd56,0x9b4400db,0x00000000}},	//   kial_, fasa_, _ەنتو, --, 
   {{0x2919fd57,0x24880882,0x61f5fd58,0x9f4402fb}},	//   gasa_, kyam_, _muzl, _milí_, 
   {{0x25a9fd59,0x2489fd5a,0x00000000,0x00000000}},	//   dial_, jyam_, --, --, 
   {{0x29180869,0x2b5c01f5,0x1fd000fe,0xdbcc03b2}},	//   aasa_, _gavc_, াদকস, _góðy, 
   {{0x2919fd5b,0x25a9fd5c,0x63800118,0xfbcc3d1d}},	//   basa_, fial_, _míně, _सीएम, 
   {{0x6f1808a4,0xd5e4329b,0x9b6000d1,0xeab00244}},	//   zavc, ужби, _ئۆگۈ, _بعه_, 
   {{0x6f180a73,0x2489fd5d,0x9f440332,0xe7940133}},	// [39ee0] yavc, gyam_, _ailí_, _چاپک, 
   {{0x61f5fd5e,0x9f4400d2,0x25a80254,0x00000000}},	//   _buzl, _bilí_, aial_, --, 
   {{0x25a9fd5f,0x24880de2,0x6f180010,0xe9b800e5}},	//   bial_, ayam_, vavc, _سنیں_, 
   {{0x61f5fd60,0x24880211,0x9940012d,0x00000000}},	//   _duzl, byam_, _nóż_, --, 
   {{0x6f197a20,0xe475fd61,0xdb000332,0xcfa40798}},	//   tavc, _курэ, eilí, лшки, 
   {{0x9f45fd62,0x61f40007,0xdb01fd63,0x29181556}},	//   _filí_, _fuzl, filí, zasa_, 
   {{0x2919fd64,0x0fe00058,0x6f19fd65,0x6d4400e8}},	//   yasa_, _һөкү, ravc, _ñiak, 
   {{0x29180227,0x6f18f3a2,0x9940033f,0x1ae400fe}},	//   xasa_, savc, _cóż_, পুৱা, 
   {{0x6f18b7b5,0xcf2460ee,0x41240801,0x61f400d7}},	//   pavc, _مرضي, _щото_, _zuzl, 
   {{0x40900491,0x25a9fd66,0x61f43946,0xc4380375}},	//   _الكر, zial_, _yuzl, עתיי, 
   {{0x2919fd67,0xc3300375,0x3e600205,0x8e84010a}},	//   tasa_, זות_, _gıt_, _сăнч, 
   {{0x24883a09,0xdb000120,0x29d806af,0x6b800023}},	//   yyam_, gilâ, déac_, _ይፈላለ_, 
   {{0x25a9fd68,0x2919fd69,0xc31c0011,0x3e600790}},	//   vial_, rasa_, ন্টি_, _zıt_, 
   {{0x24880a28,0x80d4012d,0x00000000,0x00000000}},	//   vyam_, _बरसे, --, --, 
   {{0x2919fd6a,0x499004fb,0xf628003b,0x00000000}},	//   pasa_, _هیدر, літи_, --, 
   {{0x2489fd6b,0x2919fd6c,0x00000000,0x00000000}},	//   tyam_, qasa_, --, --, 
   {{0xe3141b88,0x61f401a9,0xe5a400ee,0xe4740798}},	// [39ef0] имањ, _suzl, гиңи, шлањ, 
   {{0x2489fd6d,0x61f5fd6e,0x7ce803e3,0x44240010}},	//   ryam_, _puzl, _hörü, čn_, 
   {{0x25a9fd6f,0x7ce800dd,0x2488a501,0x1b18015b}},	//   pial_, _körü, syam_, _দামে_, 
   {{0xdb01fd70,0xba04069d,0x201dfd71,0x61f4013d}},	//   vilí, _ጋዝ_, tswi_, _vuzl, 
   {{0x201c1ebd,0x9940012d,0x61f40139,0xa0680114}},	//   uswi_, _róż_, _wuzl, ђака_, 
   {{0x61f5fd72,0xdb01fd73,0x64a40124,0xde0461db}},	//   _tuzl, tilí, _баҭа, апки, 
   {{0x6da80a28,0xb3c81e76,0x201c04ba,0xe2c9fd74}},	//   rśan, _слёз_, sswi_, _شورو_, 
   {{0x9c2407d6,0x11840050,0xafc40220,0x7de000e5}},	//   адид, _پھٔٹ_, _ۇيقى, _nőst, 
   {{0xdb0056cf,0x0c34007b,0x3e600166,0x00000000}},	//   silí, لكية_, _wıt_, --, 
   {{0xdb001445,0xdfd401ec,0x00000000,0x00000000}},	//   nnlø, _тозы, --, --, 
   {{0x7ce875d4,0x3e6800ee,0x1a2802e8,0xdd946391}},	//   _börü, _яшан_, ъжни_, _кажы, 
   {{0x7de40046,0xeea814a3,0x5b140166,0x00000000}},	//   _сізд, _стук_, ымүт, --, 
   {{0x7ce8010e,0xacf41079,0x61440092,0x00000000}},	//   _dörü, _اسمت, _የጌታች, --, 
   {{0x7d19fd75,0x1ae5fd76,0xdb000798,0x8c18011a}},	//   laus, _колм, silâ, _סוצי, 
   {{0x9f444d74,0xdb00067c,0x49f400d8,0x2bb42c2e}},	//   _milà_, milà, _кејџ_, ुवरा, 
   {{0x7ce836b5,0x7d19fd77,0x3804016c,0x9425fd78}},	//   _görü, naus, _лоиҳ, имбе, 
   {{0xd37001f7,0x00000000,0x00000000,0x00000000}},	// [39f00] يهر_, --, --, --, 
   {{0x7794fc15,0x7d19fd79,0xd6d8008e,0x00000000}},	//   _ایسا, haus, _үтү_, --, 
   {{0x7d19fd7a,0x7ce8ea65,0x7985fd7b,0x965402e8}},	//   kaus, _yörü, _koiw, _тъпч, 
   {{0x7d18e720,0xd0081d83,0x9f44068c,0xe3b02002}},	//   jaus, веде_, _ailà_, يرە_, 
   {{0x7985fd7c,0x7d19fd7d,0xe6b401b9,0x909800ae}},	//   _moiw, daus, _نلیگ, خضار_, 
   {{0x8e24fd1b,0x7d180112,0x4ea400ee,0x1ea80214}},	//   афид, eaus, ирйа, گاهي_, 
   {{0x7d19fd7e,0x9f440268,0x91e40261,0xe81c00e1}},	//   faus, _dilà_, _вове, _बौना_, 
   {{0x9f440589,0x7d19fd7f,0x21740354,0x00000000}},	//   _pilã_, gaus, _луур, --, 
   {{0x9f45fd80,0xdb00004e,0xd7c40073,0xd1380092}},	//   _filà_, filà, लकाच, _የምታው, 
   {{0xdb001e7b,0x798402d0,0x9f440798,0x53c407b6}},	//   gilà, _aoiw, _vilã_, वविश, 
   {{0x7d19fd81,0x6a48013f,0xe91800d3,0xcee800ec}},	//   baus, _bɛfa, лоні_, _شرطن_, 
   {{0x8c443339,0x7d18ebd8,0xfc1401d5,0x7ce806be}},	//   _веде, caus, _چقنب_, _qörü, 
   {{0x798455ef,0xebc40139,0x614000e5,0x00000000}},	//   _doiw, _гәнн, láló, --, 
   {{0x0a6817a0,0x9f440419,0x00000000,0x00000000}},	//   _арии_, _kilá_, --, --, 
   {{0x614000dd,0xf1b81a2a,0x7ce9fd82,0x99d40183}},	//   náló, ेकान, _törü, _সংৰক, 
   {{0x9f440306,0xb594023a,0xda640fb4,0x78ac0254}},	//   _milá_, оисш, _داهي, ülvä, 
   {{0x69cc5bae,0xc7b8023b,0x21680131,0x614000e5}},	// [39f10] _ikae, _аён_, ғили_, háló, 
   {{0x7d184a52,0x33740354,0x26c4025c,0x0eb413e0}},	//   zaus, огур, żloq_, _अखंड, 
   {{0x7d19fd83,0xdb000450,0x41b00037,0x1754011a}},	//   yaus, rnlø, ंचलस, _הסתר_, 
   {{0xf650066d,0xdb00004e,0x00000000,0x00000000}},	//   _کئی_, zilà, --, --, 
   {{0x557400c8,0x7d18822d,0x69cc009f,0xdb000784}},	//   _הערן_, vaus, _mkae, hilá, 
   {{0x645dfd84,0x7d18949e,0x8234c9f0,0xe1ec0150}},	//   _issi, waus, _پرسا, _اﻳﯩﻨ, 
   {{0x7d19fd85,0x22940491,0x1ec9fd86,0x69cdfd87}},	//   taus, _الأس, ылки_, _okae, 
   {{0x69cc013b,0x2ba4000d,0x00000000,0x00000000}},	//   _nkae, गोसा, --, --, 
   {{0x7d18d108,0xdca40131,0xad4400cf,0x705800f3}},	//   raus, сапи, تۉنۉ, _катр_, 
   {{0x69cdfd88,0x6140f126,0x7d19fd89,0x645c009f}},	//   _akae, báló, saus, _mssi, 
   {{0x7d189b4c,0x798400b0,0x645dfd8a,0xafc402dd}},	//   paus, _poiw, _lssi, _بيلى, 
   {{0x645dfd8b,0x9f4c0086,0xef1800ef,0x00000000}},	//   _ossi, _iteñ_, _zeļ_, --, 
   {{0x8d580302,0x1c200037,0x00000000,0x00000000}},	//   _תכני, _मिटल_, --, --, 
   {{0x69cc0428,0x79840036,0x9b4401f7,0x00000000}},	//   _ekae, _woiw, _طنبو, --, 
   {{0x645dfd8c,0x69cc0093,0x07a00408,0xdb016f14}},	//   _assi, _fkae, чарн, cilá, 
   {{0x29d9fd8d,0x00000000,0x00000000,0x00000000}},	//   léan_, --, --, --, 
   {{0xa3e8098a,0x33840107,0x614000e5,0x00000000}},	// [39f20] मगढ_, оваҳ, záló, --, 
   {{0x29d8003e,0x00000000,0x00000000,0x00000000}},	//   néan_, --, --, --, 
   {{0x645dfd8e,0x4fe80220,0xcb10011a,0x00000000}},	//   _essi, ңмен_, פלא_, --, 
   {{0x29d9fd8f,0x614001d3,0x00000000,0x00000000}},	//   héan_, váló, --, --, 
   {{0x29d80438,0x9f440270,0x6d9c00ae,0xfbc417c6}},	//   kéan_, _silá_, _héag, रकाम, 
   {{0xdb000393,0xa03000db,0x614000e5,0x00000000}},	//   lilæ, بۉكت, táló, --, 
   {{0x29d9fd90,0x0b8801d5,0x00000000,0x00000000}},	//   déan_, ҳсни_, --, --, 
   {{0x8afc03f9,0xdb01fd91,0x2bd05a30,0xa460001f}},	//   _maƙe, vilá, हत्थ, ፈልጉት, 
   {{0x6d9c01e7,0x0c84013d,0xabb40124,0x00000000}},	//   _léag, сыйм, ҩақә, --, 
   {{0x29d9fd92,0x69cc0156,0xdb0028d1,0x00000000}},	//   géan_, _skae, tilá, --, 
   {{0x64d5fd93,0x6d9c06af,0x8d285990,0xa9783ee9}},	//   _दर्श, _réaf, _боев_, айну_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x29d80098,0xaa5801ed,0xdb01fd94,0x00000000}},	//   béan_, _چلتا_, silá, --, 
   {{0x645dfd95,0xdb0002fb,0x29d8003e,0xaa9413d6}},	//   _rssi, pilá, céan_, _милч, 
   {{0x60cc00e2,0x94dc06be,0xdb001427,0x45480798}},	//   ļami, _içək_, nnlý, лчам_, 
   {{0x69cdfd96,0xa2b800dc,0x6d9c007b,0x28e0000d}},	//   _ukae, ्थस्, _déag, _नरपि, 
   {{0x66e4010b,0xe85800fb,0x00000000,0x00000000}},	// [39f30] соңа, _тапш_, --, --, 
   {{0x6d9c00ae,0x00000000,0x00000000,0x00000000}},	//   _héad, --, --, --, 
   {{0xdb00037e,0xa5f8026a,0x6d9c01e7,0x7b3400a2}},	//   bilæ, _њему_, _géag, lşuñ, 
   {{0x8f6801ed,0x00000000,0x00000000,0x00000000}},	//   یلنے_, --, --, --, 
   {{0x6d9c0597,0x645dfd97,0x1b1800fe,0x00000000}},	//   _méad, _ussi, _দাসে_, --, 
   {{0x0cb00c58,0x8afc0198,0x6d9c01e7,0x00000000}},	//   _চৰ্ত, _yaƙe, _léad, --, 
   {{0xfeb856e1,0xa15812fa,0x5de4020f,0xa1945dbe}},	//   داشت_, _каву_, ожка, _давч, 
   {{0x29d85d69,0x00000000,0x00000000,0x00000000}},	//   wéan_, --, --, --, 
   {{0xa2b84614,0x39940124,0x29d8003e,0x27e001e1}},	//   ्थव्, _sãso_, téan_, _ohhn_, 
   {{0x5ba9fd98,0xbec400ef,0x00000000,0x00000000}},	//   рком_, ezīš, --, --, 
   {{0x2fc0007b,0x29d9fd99,0x5e581d0a,0x00000000}},	//   éige_, réan_, _خلاس_, --, 
   {{0x6d9dc806,0x9ca800ec,0xdb01050a,0x5c74009b}},	//   _réag, _پهتل_, kilç, _млет, 
   {{0x6d9c0332,0x29d8003e,0x2bd401f9,0x00000000}},	//   _déad, péan_, _ठीका, --, 
   {{0x60cc0209,0x6d9c6bd3,0x00000000,0x00000000}},	//   ýamy, _péag, --, --, 
   {{0xba740502,0x6d9c0597,0xd94402af,0xb90004c5}},	//   _داشت, _féad, _дейи, _তল_, 
   {{0x29d800c6,0x6e3c0158,0xdce81710,0x6d4400e8}},	//   néal_, _årbe, ljeđ, _ñiat, 
   {{0x92d42f8b,0x9f440598,0x8afc0198,0x6a48013f}},	// [39f40] _হলে_, _kilä_, _waƙe, _yɛfo, 
   {{0x38601bf2,0x29d8007b,0x6d9c01e7,0x00000000}},	//   _isir_, héal_, _téag, --, 
   {{0xdb000716,0x27ec0ea0,0x00000000,0x00000000}},	//   milä, ïene_, --, --, 
   {{0xdb01fd9a,0x38600327,0x59c804e4,0x00000000}},	//   lilä, _ksir_, रविर, --, 
   {{0x3860003d,0x25a477d0,0x29d800c6,0x50b8bb13}},	//   _jsir_, ëlle_, déal_, جداد_, 
   {{0xdb01a325,0x394001ab,0x68e80213,0x602800d4}},	//   nilä, _lcis_, ümdə, сіїв_, 
   {{0xefd002d3,0x38600327,0x59c9c44f,0x29d80332}},	//   _እከይ_, _lsir_, रवार, féal_, 
   {{0xdb00005b,0x00000000,0x00000000,0x00000000}},	//   hilä, --, --, --, 
   {{0x6d9c00c6,0x3860031c,0xdb001611,0x85980677}},	//   _réad, _nsir_, kilä, ישקו, 
   {{0x0b8978ad,0x31640369,0x0a69fd9b,0x3940005f}},	//   рсии_, _hamz_, арми_, _acis_, 
   {{0x3861fd9c,0xdb0029ef,0xd1cc00b7,0x9f44013d}},	//   _asir_, dilä, _እለት_, _dilä_, 
   {{0x29d8007b,0x2d80000d,0xda6c00ec,0xdcf80210}},	//   céal_, _õie_, اڏو_, _pową, 
   {{0x92d403f4,0x31640109,0xdce81e31,0x09b807f7}},	//   _হলো_, _mamz_, bjeđ, _उदीय, 
   {{0x31640007,0xdb00000d,0x00000000,0x00000000}},	//   _lamz_, gilä, --, --, 
   {{0x0575be94,0x29d81063,0x38600bbc,0xaa9401c6}},	//   يارد, léam_, _esir_, _хийч, 
   {{0x3941fd9d,0x6d9c003e,0x9f4400fd,0x2ca0013a}},	//   _gcis_, _héab, _zilä_, _židy_, 
   {{0xb9c40491,0xdb0148ac,0x32180076,0x00000000}},	// [39f50] _تقيي, bilä, _awry_, --, 
   {{0x26c00218,0x4309fd9e,0xdb000139,0x02680108}},	//   _txho_, рхам_, cilä, ишей_, 
   {{0x31640007,0xe7f80574,0x6d9c0332,0x9f88032e}},	//   _bamz_, ंदवा_, _méab, dúð_, 
   {{0x35f80066,0x00000000,0x00000000,0x00000000}},	//   _گرید_, --, --, --, 
   {{0xa068145a,0x31640369,0xf99402e4,0x8ca805d7}},	//   сала_, _damz_, ורף_, _जेलो, 
   {{0x35f803e6,0xf83804ae,0x00000000,0x00000000}},	//   _درید_, קנות_, --, --, 
   {{0xfe5400dd,0xdb00007c,0xc29002f2,0x00000000}},	//   تیاب_, nilå, _تیاب, --, 
   {{0x41743ed0,0xa13c00e4,0xc175497a,0x00000000}},	//   _باسس, _omŷi, _بدست, --, 
   {{0x29d9fd9f,0x9f880321,0x00000000,0x00000000}},	//   réal_, búð_, --, --, 
   {{0x394016b8,0x290c01c6,0x5f800150,0x9f440139}},	//   _scis_, ñean_, _سۇبە, _qilä_, 
   {{0x3860003d,0x29d8007b,0xdce80841,0xdb000108}},	//   _ssir_, péal_, rjeđ, vilä, 
   {{0x29d8020c,0xed056546,0x60cc0327,0x00000000}},	//   béam_, _قومپ, żamu, --, 
   {{0xdb00e9b1,0x1a643c5b,0xdc080132,0xef1800de}},	//   tilä, زیکی_, _اقتو_, _soļi_, 
   {{0xceb80198,0x6d44002e,0xef180171,0x4ac4012d}},	//   laƙa_, _ñiar, _poļi_, _रुकव, 
   {{0x70b8375c,0xdb00088b,0xfa5001b9,0x4b78011a}},	//   _अश्ल, rilä, _آرتگ, _לאסו, 
   {{0xdb01fda0,0x38608451,0x39400276,0xe9a8007b}},	//   silä, _tsir_, _ucis_, _ودين_, 
   {{0xba04044e,0x8afc02a8,0x3165fda1,0x3861fda2}},	// [39f60] _ወረ_, _haƙa, _ramz_, _usir_, 
   {{0x8afc0198,0xe7f8ad78,0xee4c01af,0x733400f7}},	//   _kaƙa, ंदरा_, _баhа_, بۉسا, 
   {{0xaf64084c,0x362400e5,0x51f419c5,0x00000000}},	//   _хеyд, _توجہ, سسار, --, 
   {{0xc6901a4c,0x8afc02a8,0xb35800e5,0x00000000}},	//   _נאר_, _maƙa, _ڈیرا_, --, 
   {{0x8afc02a8,0x6d9c007b,0x6e380477,0x00000000}},	//   _laƙa, _léac, wuvb, --, 
   {{0xae001fb0,0x00e4cbbd,0x8fd018c7,0x35800092}},	//   _लंदन_, ستنی, хәбә, _የሙቀት_, 
   {{0x8afc02a8,0x6d9c00c6,0x804400cf,0x00000000}},	//   _naƙa, _réab, _ۉركۅ, --, 
   {{0xfe6dfda3,0x6d9c0332,0x00000000,0x00000000}},	//   ادو_, _séab, --, --, 
   {{0xf0440405,0x6e380455,0xebc40166,0x00000000}},	//   _تعزی, suvb, мәкн, --, 
   {{0x8afc02a8,0x29d80c6a,0xaa9428e8,0x00000000}},	//   _baƙa, réam_, диоч, --, 
   {{0xfba80034,0x6d9c01e7,0xa93438a9,0x6e38014f}},	//   टोधम, _céac, менш, quvb, 
   {{0xcd340150,0x6d9c01e7,0x9e641fb8,0xe8f80137}},	//   _ءراب, _déac, _زامن, өлү_, 
   {{0x2614216a,0x00000000,0x00000000,0x00000000}},	//   _फौजी_, --, --, --, 
   {{0x6d9c0491,0xc7b80a89,0x00000000,0x00000000}},	//   _féac, сём_, --, --, 
   {{0xf6740006,0x1ba800e5,0x00000000,0x00000000}},	//   нгрэ, _بانٹ_, --, --, 
   {{0x22440724,0x7ab8011a,0x36d4014b,0x00000000}},	//   _älki_, _לצוו, хоср, --, 
   {{0x2908198f,0x4cc8015b,0x870447f9,0x2a6c0076}},	// [39f70] _ifaa_, াইকু, _няне, lvdb_, 
   {{0x8afc02a8,0xceb803f9,0x7d00032e,0xa29401ca}},	//   _yaƙa, zaƙa_, _kíró, мазі, 
   {{0xceb80198,0x00000000,0x00000000,0x00000000}},	//   yaƙa_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2908013f,0x75e4010b,0x356801c6,0x00000000}},	//   _mfaa_, _чәрҗ, _эрэн_, --, 
   {{0x44380bf1,0xceb803f9,0xd00c027d,0x2d84036e}},	//   muq_, waƙa_, جلو_, ejme_, 
   {{0x4439fda4,0x29080418,0x6f0803ac,0xdb1001e1}},	//   luq_, _ofaa_, _dfdc, _ìgék, 
   {{0x6d9c20ef,0xaad000e1,0x6e282963,0x7ff435b6}},	//   _réac, _हड़क, _dvdb, _فسطا, 
   {{0x44383209,0x8afc0198,0x29d80098,0x9f4400d7}},	//   nuq_, _saƙa, méah_, _milú_, 
   {{0x29093053,0x200c2654,0x7d0001ed,0x69c401e4}},	//   _afaa_, _itei_, _bíró, _ĉiea, 
   {{0xa3b401ad,0x29d80098,0x956002d3,0x44380978}},	//   _जगन_, céak_, _ወጻእተ, huq_, 
   {{0x44380bf1,0x200c003a,0x6e3c05ac,0x1de000dc}},	//   kuq_, _ktei_, _årba, _पठित, 
   {{0x8afc02a8,0x00000000,0x00000000,0x00000000}},	//   _waƙa, --, --, --, 
   {{0x7c39fda5,0x6d9c0597,0x8afc0b45,0x200c01f7}},	//   muur, _téac, _taƙa, _mtei_, 
   {{0x7c39fda6,0x29080a55,0x44380097,0xd5b000c6}},	//   luur, _ffaa_, euq_, نفس_, 
   {{0x212c0109,0x44380327,0xdcf80210,0x00000000}},	//   _ndeh_, fuq_, _powę, --, 
   {{0x200c0085,0x7c39fda7,0x70dc0034,0x628000d8}},	// [39f80] _ntei_, nuur, _बरेल, _àloj, 
   {{0x212c05b1,0x9fa000e8,0xe578013e,0x00000000}},	//   _adeh_, _dëël_, озӣ_, --, 
   {{0xd1b04d20,0x200c8b77,0x57d80073,0x230800f1}},	//   نیسک, _atei_, णतीह, ستلي_, 
   {{0x7c39fda8,0x4439fda9,0xdbd8013d,0x00000000}},	//   kuur, buq_, lçäl, --, 
   {{0x4fc42685,0x7525fdaa,0x7c38b6a5,0x8fa422ed}},	//   мска, maiz, juur, маде, 
   {{0x09b90457,0x7c39fdab,0xdbd80724,0x7525fdac}},	//   _उद्य, duur, nçäl, laiz, 
   {{0x43402095,0x200c00e4,0x00000000,0x00000000}},	//   _шерв, _etei_, --, --, 
   {{0x7c39fdad,0x9f440268,0x16fc031c,0x7525fdae}},	//   fuur, _milù_, _དུའམ_, naiz, 
   {{0x7d003e33,0x0ba800d1,0xef180171,0x26c403e0}},	//   _síró, قادى_, _soļu_, üloz_, 
   {{0x75240851,0x0ba92374,0x290800e4,0xef1800e2}},	//   haiz, تابى_, _sfaa_, _poļu_, 
   {{0x7525fdaf,0x3f98004a,0x7a340276,0xfe40146a}},	//   kaiz, êque_, мпэр_, _анхо, 
   {{0x4439fdb0,0x7c39fdb1,0x752401fa,0xf990009f}},	//   yuq_, buur, jaiz, لبُ_, 
   {{0x4ba40228,0x7c3803d9,0x02d8012c,0xbdc81c3b}},	//   _жөнү_, cuur, _भर्न, _بدلے_, 
   {{0x4438100f,0x6d403fc1,0x00000000,0x00000000}},	//   vuq_, lgma, --, --, 
   {{0x8afc03f9,0x9f440077,0x752405da,0x6d400b4f}},	//   _haƙo, _pilú_, faiz, ogma, 
   {{0x6d41fdb2,0x4439fdb3,0x752401c4,0x85b80014}},	//   ngma, tuq_, gaiz, زازس_, 
   {{0xc764278f,0x6594013e,0x6d400009,0x66240064}},	// [39f90] _قادى, _ҷану, igma, _šukė, 
   {{0x8afc03f9,0xc7c40212,0x00000000,0x00000000}},	//   _maƙo, _іспи, --, --, 
   {{0x4439fdb4,0x7525efff,0xaad405f9,0x659456cd}},	//   suq_, baiz, _ठुमक, _зану, 
   {{0x59f81a4c,0x7c380014,0x4438636d,0x202c0023}},	//   פּעד, yuur, puq_, _ብደሞክ, 
   {{0x44384f08,0x6d4001e4,0x7c38058a,0xdb0001e3}},	//   quq_, dgma, xuur, mnlö, 
   {{0xdee463e6,0x6d400d47,0x7c39fdb5,0x6d9c003e}},	//   ноли, egma, vuur, _réaa, 
   {{0x442801f5,0x29d80c6a,0x02c04709,0x00000000}},	//   _hvc_, péah_, _शशिभ, --, 
   {{0x8afc03f9,0x44280223,0x6d41fdb6,0x212c0263}},	//   _baƙo, _kvc_, ggma, _udeh_, 
   {{0x49f86d7e,0x200c0649,0x7de000e5,0xa2b800cd}},	//   _དངུལ_, _utei_, _kősz, ्थक्, 
   {{0x7c380050,0xdaa84d87,0x6d4001f5,0x1a640214}},	//   ruur, звод_, agma, فیتی_, 
   {{0xd9442dc1,0x7c398337,0x75240099,0xe1f800c0}},	//   нени, suur, yaiz, _kių_, 
   {{0x3f840989,0x98a44712,0x44280010,0x7c386775}},	//   ljnu_, еиме, _ovc_, puur, 
   {{0xb90852be,0x7525fdb7,0xe9800220,0x7c383a73}},	//   _भर_, vaiz, рқын, quur, 
   {{0x7524004c,0x57d80073,0xbb1401d9,0xe1f80153}},	//   waiz, णतेह, _کٲژا_, _lių_, 
   {{0x44281497,0x7525fdb8,0x6d9dfd16,0x95984827}},	//   _avc_, taiz, _méan, птау_, 
   {{0x6d9dfdb9,0x4429fdba,0x79e801ed,0xb4040209}},	//   _léan, _bvc_, _توبہ_, күмд, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [39fa0] --, --, --, --, 
   {{0x6d9dfdbb,0x442800ad,0x7525fdbc,0x00000000}},	//   _néan, _dvc_, saiz, --, 
   {{0x442801a4,0x0eac0073,0xe1f80064,0xc20c01d9}},	//   _evc_, _झेंड, _bių_, مٔل_, 
   {{0x11d410fe,0x442963b2,0xd13004fb,0xd4680276}},	//   رتاد, _fvc_, امش_, _еиме_, 
   {{0x44280010,0x7de001ed,0x6d9c0129,0x09b4010f}},	//   _gvc_, _fősz, _béan, עפנט_, 
   {{0x6d9c0597,0x1ee804d3,0xbf0874f6,0x479800df}},	//   _céan, ژووی_, सुलभ_, ּיקס, 
   {{0x6d9c06d5,0xa3b41431,0x7c29fdbd,0x8afc02a8}},	//   _déan, _जगत_, _avgr, _saƙo, 
   {{0xcfa81547,0x7bc001e4,0xdbd000f1,0xf0b000e5}},	//   _کارم_, _ajnu, یښود, _پیتھ, 
   {{0xdb0004e6,0xcb4401c6,0x9e0400cf,0x00000000}},	//   chlë, нхни, нчөл, --, 
   {{0x7ae000fb,0x6d9dfdbe,0x1fb42850,0x6e3c0623}},	//   _bznt, _géan, _исхр, _årbo, 
   {{0x8afc02a8,0x1fb40022,0x00000000,0x00000000}},	//   _waƙo, _рстр, --, --, 
   {{0xbae002d5,0xda151e01,0x2ba401f9,0x7e980115}},	//   ыцый, کسیک, गोजा, _מסבו, 
   {{0xc7c40432,0xc1700375,0xbd84009f,0x7c900338}},	//   есви, אחר_, _سنون_, _مشوا, 
   {{0x499001ed,0x442801f5,0x8b644e85,0xfa30552d}},	//   ئیکر, _rvc_, _ساتم, خرید, 
   {{0x4429fdbf,0x98b400e2,0xdb00143a,0xba714655}},	//   _svc_, īgām_, vilø, _مايت, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4429fdc0,0xdb00450f,0xe1f800c0,0xf4340105}},	// [39fb0] _qvc_, rnlö, _rių_, летэ, 
   {{0x69dc0013,0x73d816ab,0xe1f800c0,0x998400c0}},	//   llse, едур_, _sių_, bulų_, 
   {{0x6d9d9f61,0x4428009a,0x29180ba7,0x69ddfdc1}},	//   _réan, _wvc_, obsa_, olse, 
   {{0x442800f7,0x6d9dc806,0x6594d6c2,0xd1cc02d3}},	//   _tvc_, _séan, _раму, _እፈቱ_, 
   {{0x657dfdc2,0x34940323,0x69c400c8,0x69ddfdc3}},	//   _insh, _баяр, _ĉiel, ilse, 
   {{0x644dfdc4,0x656dfdc5,0xd4c06215,0x69dc0112}},	//   mtai, ldah, _төск, hlse, 
   {{0x644dfdc6,0x8fa01301,0x6d9c0789,0x656c0014}},	//   ltai, раще, _véan, odah, 
   {{0x644dfdc7,0xdb00007b,0x628400f1,0x3f8405ac}},	//   otai, mhlé, mxho, sjnu_, 
   {{0x644ddebf,0x61e81a56,0xa3b45e8d,0x6d9dfdc8}},	//   ntai, _ihel, _जगा_, _téan, 
   {{0x644dfdc9,0xace40184,0x69ddfdca,0x7ff4007b}},	//   itai, ыбыҙ, else, _أسرا, 
   {{0x644da813,0x61e9fdcb,0x657c02d0,0xfe7400f7}},	//   htai, _khel, _onsh, _чүй_, 
   {{0x61e8020c,0x656d4325,0x69dc0217,0x00000000}},	//   _jhel, jdah, glse, --, 
   {{0x656c6bb3,0x61e87c8d,0x6d9c01e7,0x00000000}},	//   ddah, _mhel, _méal, --, 
   {{0x657dfdcc,0x644dfdcd,0x69dc007d,0xdb007978}},	//   _ansh, dtai, alse, khlé, 
   {{0x644dfdce,0x9f4400c6,0x61e9fdcf,0x29180327}},	//   etai, _chlé_, _ohel, bbsa_, 
   {{0x656dfdd0,0x58940022,0x61e80327,0x6d9c01e7}},	//   gdah, _ашоу, _nhel, _néal, 
   {{0x81c403d4,0xdb00067c,0xdce80003,0x60c80200}},	// [39fc0] উতা_, thlè, ddeċ, _nxem, 
   {{0x657dfdd1,0x61e9fdd2,0x63a40076,0x656c0067}},	//   _ensh, _ahel, ghhn, adah, 
   {{0x644dfdd3,0x61e8a4ed,0x62840472,0x6d9c007b}},	//   atai, _bhel, gxho, _béal, 
   {{0x644dfdd4,0x656c0009,0x74f402dd,0x6fa400c5}},	//   btai, cdah, _مۋزا, _कतहू, 
   {{0x61e9fdd5,0x644dfdd6,0x41240137,0x98b00205}},	//   _dhel, ctai, точо_, _kayı_, 
   {{0x61e801d9,0xdb00007b,0x00000000,0x00000000}},	//   _ehel, bhlé, --, --, 
   {{0x61e81aa1,0xdb015a19,0x2f880184,0x657c062c}},	//   _fhel, chlé, _үҙен_, _ynsh, 
   {{0x61e9fdd7,0xfe6c0dd8,0x00000000,0x00000000}},	//   _ghel, زدى_, --, --, 
   {{0x50c42e1e,0x0fe000f7,0xfc4050d8,0x69dc005c}},	//   _वशिष, _көкү, لپيپ, vlse, 
   {{0x61e8036e,0x656c03e0,0x00000000,0x00000000}},	//   _zhel, zdah, --, --, 
   {{0x644dfdd8,0x6d9c0332,0x3b50084c,0x656da15c}},	//   ztai, _héam, шкэр, ydah, 
   {{0x61e8044e,0x644dfdd9,0x9f4402fb,0x656dfdda}},	//   _xhel, ytai, _milý_, xdah, 
   {{0x69ddfddb,0x656d572e,0x98b00139,0x6284009a}},	//   rlse, vdah, _bayı_, zxho, 
   {{0xfbcc3530,0x9f4400c6,0x98b00166,0xfce00212}},	//   _وتو_, _phlé_, _cayı_, _точо, 
   {{0x6d9c0597,0xdb000209,0xb605fddc,0x98b03361}},	//   _léam, nilý, иятк, _dayı_, 
   {{0x644dfddd,0xa3b409fd,0x656c058a,0x49900345}},	//   ttai, _जगह_, udah, _ئیحر, 
   {{0x6d9dfdde,0x644dfddf,0x61e818f7,0x657c004d}},	// [39fd0] _réal, utai, _rhel, _vnsh, 
   {{0x644dfde0,0x62845693,0x61e9fde1,0x6d9c00ae}},	//   rtai, txho, _shel, _séal, 
   {{0x61e9fde2,0xe6940184,0x644dfde3,0x60c9fde4}},	//   _phel, _сины, stai, _sxem, 
   {{0x644dfde5,0x656c074d,0x657dfde6,0x61e9fde7}},	//   ptai, qdah, _unsh, _qhel, 
   {{0x644c0357,0x61e9fde8,0x5f943e64,0xf4840408}},	//   qtai, _vhel, лидт, _курн, 
   {{0x61e81590,0x998801e4,0x6d9c06af,0x66040010}},	//   _whel, _ĉaŭ_, _déam, _kuhk, 
   {{0x61e9fde9,0x6d9c00c6,0x29d8007b,0x6604000d}},	//   _thel, _téal, néas_, _juhk, 
   {{0x61e9fdea,0x672403a2,0x60c801c4,0x66040108}},	//   _uhel, _lehj, _txem, _muhk, 
   {{0x6604020c,0x629001f2,0x9f44008e,0x60c803ac}},	//   _luhk, ̣kọ, _kilü_, _uxem, 
   {{0x92d40183,0xdb00c50d,0x00000000,0x00000000}},	//   াইৰ_, bilý, --, --, 
   {{0x1e14330e,0xa2e005b3,0x66040037,0xd354011a}},	//   _смея, _करोड़_, _nuhk, איתי_, 
   {{0x98b00cc1,0x62800129,0x6abc0332,0x00000000}},	//   _sayı_, _àlou, úrfa, --, 
   {{0x7d186985,0x672417b8,0x98b006b9,0x2d98013b}},	//   mbus, _behj, _payı_, ɔre_, 
   {{0x7d19fdeb,0x9b882f19,0x9f44014a,0xcb64010b}},	//   lbus, _سنبل_, _nilü_, _баше_, 
   {{0x7d1861ad,0x41d018cc,0x46a00212,0x6724036e}},	//   obus, तवास, барв, _dehj, 
   {{0xceb00bd9,0x7c38257c,0x660400cd,0x958410de}},	//   צין_, orur, _duhk, ылбе, 
   {{0x29d8dac8,0x7c380005,0x7d18ebe6,0x13e893fb}},	// [39fe0] réat_, nrur, ibus, емай_, 
   {{0x6d9c0597,0xdb20025a,0x7d1886da,0x29d8003e}},	//   _réam, _âtäp, hbus, béas_, 
   {{0x6d9c007b,0x7d19fdec,0x29d86de2,0x95c40271}},	//   _séam, kbus, méar_, _ميده, 
   {{0x7d18588d,0xb9d80092,0x29d9ee6c,0x733400ec}},	//   jbus, _ጽኑ_, léar_, _چڱائ, 
   {{0xf3f80724,0x9f44004e,0x0ce0095f,0x00000000}},	//   _аңа_, _niló_, _परेम, --, 
   {{0x6a48013f,0x7c38005a,0x6604037e,0x3e4802d3}},	//   _mɛfr, drur, _yuhk, _ዘይኮይ, 
   {{0x98bc0210,0x00000000,0x00000000,0x00000000}},	//   ętę_, --, --, --, 
   {{0xdb0009a5,0x6d9c0597,0x7d19fded,0x9f440548}},	//   rilý, _téam, gbus, _biló_, 
   {{0x8afc0b45,0x7c38079b,0x29040210,0x00000000}},	//   _haƙi, grur, ślak_, --, 
   {{0xd1d4001f,0x7d18598c,0xfe6c00f7,0x00000000}},	//   ሬዎች_, abus, زدۉ_, --, 
   {{0x7d19fdee,0x7c38014c,0x67240455,0x7dc007d6}},	//   bbus, arur, _rehj, شقین, 
   {{0xdb01fdef,0x8afc02a8,0x7c386ea9,0x6d9c0c6a}},	//   filó, _maƙi, brur, _méak, 
   {{0x7c3800a8,0x660400af,0xc4bc0154,0x3d280133}},	//   crur, _suhk, _আর্জ, _ستنی_, 
   {{0x6604793d,0x2fc000ae,0x00000000,0x00000000}},	//   _puhk, éigh_, --, --, 
   {{0x9f440268,0x8af400ac,0x6d9c0129,0x6724005b}},	//   _kilò_, şəbb, _réaj, _vehj, 
   {{0xdb0004d4,0x29d9fdf0,0x44380175,0x99540171}},	//   biló, réas_, trq_, _aļņi_, 
   {{0xdb0000d2,0x3915fdf1,0x29d800ae,0x00000000}},	// [39ff0] ciló, _умыр, séas_, --, 
   {{0x6d9c0c6a,0x6604b6a5,0x9f440241,0x29d80332}},	//   _béak, _tuhk, _lilò_, céar_, 
   {{0x8afc0b45,0x4438013c,0x76b839b8,0xe8d8010e}},	//   _baƙi, srq_, _блэр_, _toỳ_, 
   {{0x6a480134,0x7c38d36f,0x60180108,0x00000000}},	//   _yɛfr, yrur, водя_, --, 
   {{0x8afc02a8,0x25a9fdf2,0x00000000,0x00000000}},	//   _daƙi, mhal_, --, --, 
   {{0x645c0483,0x9f44067c,0x25a9fdf3,0x98a033fb}},	//   _ipsi, _ailò_, lhal_, nakā_, 
   {{0xdce809a8,0x1ec800a7,0xdb000254,0x709401a9}},	//   rdeč, ълки_, rilü, _қафф, 
   {{0x25a9fdf4,0x7c39fdf5,0x9f440270,0x7d19fdf6}},	//   nhal_, trur, _piló_, ubus, 
   {{0x98a0170b,0xdb010520,0x7c380099,0x28e0033f}},	//   kakā_, dilò, urur, _नरगि, 
   {{0x81c44251,0x7d19fdf7,0x7c39fdf8,0x9f44067c}},	//   _উঠি_, sbus, rrur, _viló_, 
   {{0x25a800e8,0x8afc0b45,0xceb803f9,0x7d1800db}},	//   khal_, _maƙw, yaƙi_, pbus, 
   {{0x645dfdf9,0xdb01fdfa,0x7c38a986,0x1c380150}},	//   _opsi, mhlí, prur, _азды_, 
   {{0x81c40729,0x25a9fdfb,0x29d9fdfc,0xac18014b}},	//   _উঠা_, dhal_, téar_, _бочу_, 
   {{0xceb80198,0x25a809e2,0xdb01fdfd,0xcc38010f}},	//   waƙi_, ehal_, riló, _יענט, 
   {{0x645dfdfe,0xa3d823ef,0x25a8003e,0xdb00ed6d}},	//   _apsi, ावन_, fhal_, bilò, 
   {{0x25a9fdff,0x6d9c5d69,0x29d9fe00,0x65b801c6}},	//   ghal_, _réak, séar_, гуур_, 
  
   {{0x8afc0198,0x29d800c6,0x248801e2,0x57e800d1}},	// [3a000] _baƙw, péar_, gxam_, _идим_, 
   {{0x6d9c00e4,0x2bc80aa2,0x98a000b8,0x00000000}},	//   _péak, िचया, cakā_, --, 
   {{0x645dfe01,0x25a84695,0x9f440332,0x24880de2}},	//   _epsi, bhal_, _chlí_, axam_, 
   {{0xd2e40abd,0x9f44007b,0xdb0000ae,0xfc24007b}},	//   _करीब_, _dhlí_, dhlí, _وح_, 
   {{0x2bc8012c,0x645c0254,0xd7b80073,0x00000000}},	//   िचमा, _gpsi, _उगाच, --, 
   {{0x087400c8,0x29d80098,0x8e74007b,0x9d640014}},	//   יענט_, héap_, لاعض, ۅنى۪, 
   {{0x8afc0198,0xc05c0023,0xdb0001e7,0xb14800f2}},	//   _taƙi, _መግረፍ, ghlí, _میام_, 
   {{0x645c0395,0xaa5800d1,0x00000000,0x00000000}},	//   _ypsi, қиму_, --, --, 
   {{0x06880131,0x25a4036e,0x8bc421f3,0x80440137}},	//   _ﻗﯧﻠﯩ, ëlli_, исод, _ەرۅۅ, 
   {{0x6d9c0332,0x71a401ec,0xdb0000ae,0x00000000}},	//   _méai, _тағз, bhlí, --, 
   {{0xc3310b71,0x2378008f,0xdb000216,0x25a800d7}},	//   חות_, אָרמ, chlí, yhal_, 
   {{0xfd400064,0x00000000,0x00000000,0x00000000}},	//   _дэшн, --, --, --, 
   {{0x2488102c,0xec14036b,0x98a400fb,0x39e80166}},	//   xxam_, _اوتد, бурҙ, рьэн_, 
   {{0xe69459b7,0x6d9c003e,0xc7b81f39,0x25a80076}},	//   бигы, _séah, тём_, whal_, 
   {{0x3d280133,0xc0340240,0x00000000,0x00000000}},	//   _ستۆی_, _ኣይትወ, --, --, 
   {{0x8afc0198,0xdb00002d,0x645c0175,0x9fbc00d7}},	//   _saƙw, chlâ, _ppsi, _mňá_, 
   {{0x25a9fe02,0x9f44007b,0x24880007,0x383400c7}},	// [3a010] rhal_, _shlí_, uxam_, _дныр, 
   {{0x25a9fe03,0x2488022e,0x20180064,0x00000000}},	//   shal_, rxam_, _įsi_, --, 
   {{0x25a8e1bf,0xe1a00092,0xa2d42dd0,0x00000000}},	//   phal_, _ገምግሞ_, حيات, --, 
   {{0x3570044e,0x24880054,0x45a00b38,0x00000000}},	//   _ትጽቢት_, pxam_, _بەرك, --, 
   {{0xd12dc3bd,0x00000000,0x00000000,0x00000000}},	//   رمو_, --, --, --, 
   {{0x8afc02a8,0x021559f2,0x94f40375,0xf0a84f32}},	//   _haƙu, _نظرد, _לצרף_, шкіл_, 
   {{0x25b80109,0x9f4400bc,0x00000000,0x00000000}},	//   _kmsl_, _uhlí_, --, --, 
   {{0xde3c02d3,0x00000000,0x00000000,0x00000000}},	//   _ከይከው, --, --, --, 
   {{0xbf20052f,0x8afc03f9,0x9e700131,0xdd9402dd}},	//   _һүҙҙ, _maƙu, غۇچت, _қады, 
   {{0x61b00137,0x00000000,0x00000000,0x00000000}},	//   _بەچا, --, --, --, 
   {{0x20380020,0x9e7479af,0x29d8003e,0xbd54010a}},	//   _አልቀረ, _دهات, téap_, _кĕни, 
   {{0x1ae4040d,0xdbd87cd9,0x00000000,0x00000000}},	//   _қойм, lçül, --, --, 
   {{0xfc3c0332,0x00000000,0x00000000,0x00000000}},	//   áíd_, --, --, --, 
   {{0xc0340023,0x00000000,0x00000000,0x00000000}},	//   _ኣይተወ, --, --, --, 
   {{0x8afc03f9,0x46a000c2,0x7a10054e,0x0a2c0092}},	//   _baƙu, парв, _băte, _ሱፐርቫ, 
   {{0x6d9c00e4,0x8a00010b,0xca34011a,0xe5600241}},	//   _péai, _эзъе, _הנקה_, _àmìì, 
   {{0x7985fe04,0xae0001ad,0xdbd803b9,0x00000000}},	// [3a020] _iniw, _लंघन_, kçül, --, 
   {{0xdee40b82,0x25b8000d,0x00000000,0x00000000}},	//   ምርን_, _emsl_, --, --, 
   {{0xc76c044e,0x798404e6,0xa300010b,0x00000000}},	//   _ብምዃኑ_, _kniw, дүре, --, 
   {{0x7a10054e,0xe87400f2,0x00000000,0x00000000}},	//   _găte, _انیگ, --, --, 
   {{0xe3b0066d,0x7984009f,0x00000000,0x00000000}},	//   سرے_, _mniw, --, --, 
   {{0xfbc5fe05,0x8afc03f9,0xe08400c6,0xa524031c}},	//   _رت_, _zaƙu, تجمي, _འབོག_, 
   {{0x8afc0198,0x79840ca8,0x00000000,0x00000000}},	//   _yaƙu, _oniw, --, --, 
   {{0x79840770,0x15f8084a,0x32181c06,0x6c143c18}},	//   _nniw, ्दिर_, _itry_, одиф, 
   {{0xfd0dfe06,0x8c64036b,0x00000000,0x00000000}},	//   رجي_, ётид, --, --, 
   {{0x79840134,0x9ce401c6,0x00000000,0x00000000}},	//   _aniw, өцөл, --, --, 
   {{0xa3d82a05,0x3860ad43,0xaa585716,0x15f86b9b}},	//   ावत_, _apir_, шину_, ्दार_, 
   {{0xc278008f,0x00000000,0x00000000,0x00000000}},	//   ארטי, --, --, --, 
   {{0x8afc02a8,0xac9400a7,0x7a100356,0x00000000}},	//   _raƙu, _фалш, _răte, --, 
   {{0x7985fe07,0x32180109,0x2574063f,0x7a100311}},	//   _eniw, _otry_, _ụl_, _săte, 
   {{0x3860f840,0xbb440150,0x443c0115,0xdb0001ab}},	//   _epir_, _الىن_, _ŭu_, chlà, 
   {{0xc76400cf,0x16c000c7,0x00000000,0x00000000}},	//   جاڭى, ьӡын, --, --, 
   {{0x321805da,0xdb0000c6,0x81c40154,0xe3b80661}},	// [3a030] _atry_, mhlá, _উঠল_, алач_, 
   {{0x68edfe08,0x69cc01bf,0x79840210,0x00000000}},	//   _izad, _hjae, _zniw, --, 
   {{0x6594eb44,0x00000000,0x00000000,0x00000000}},	//   _дану, --, --, --, 
   {{0xa1588dc4,0x6b840198,0x00000000,0x00000000}},	//   раду_, _ɗiga, --, --, 
   {{0xbb38001f,0x5f04709d,0x443dfe09,0xdfd4009d}},	//   _በጠቅላ, озла, _íu_, ооды, 
   {{0xf494030d,0x00000000,0x00000000,0x00000000}},	//   _хăшн, --, --, --, 
   {{0x35f81060,0x31c40014,0x00000000,0x00000000}},	//   _خرید_, _کۅنہ, --, --, 
   {{0x68ec09a8,0xf1a4005b,0x9c5800c7,0xdbd80205}},	//   _ozad, _ерун, ашоу_, sçül, 
   {{0x5ba9fe0a,0xdbd80209,0x216800d1,0x46d800c5}},	//   иким_, pçül, _йиңи_, _मुसह, 
   {{0x69cc0108,0x82240023,0xa3d80b02,0x7e2800d4}},	//   _ajae, _ስነሓሳ, ावि_, _біда_, 
   {{0x68edfe0b,0x1988f46c,0x3861fe0c,0x00000000}},	//   _azad, абни_, _spir_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa3d852f2,0xbb54037e,0xd7e80166,0x68ec0210}},	//   ावा_, _exeは_, имме_, _czad, 
   {{0x68edfe0d,0x6aa40198,0xa5240327,0x97d8005b}},	//   _dzad, _ƙift, _འབུག_, рьму_, 
   {{0x99d4ec1d,0x68ec8263,0xd629fe0e,0xdb0001e7}},	//   _وتبا, _ezad, робе_, bhlá, 
   {{0x7985811e,0x386001aa,0xdb0000c6,0x142400a7}},	//   _uniw, _tpir_, chlá, ждам, 
   {{0x2904012c,0x321805e4,0x7ae00240,0x6d9c01e7}},	// [3a040] ělat_, _stry_, _hynt, _téav, 
   {{0x7ae0138f,0x16643fef,0x838400d4,0x47c00108}},	//   _kynt, _двом, обув_, _обыв, 
   {{0x68ec0337,0x00000000,0x00000000,0x00000000}},	//   _zzad, --, --, --, 
   {{0x7ae0138f,0x25a404e6,0xdb00000d,0x8934010f}},	//   _mynt, ëllt_, bilö, ַרצע_, 
   {{0x7ae00652,0x98a00064,0x2f18e643,0x00000000}},	//   _lynt, baką_, боль_, --, 
   {{0xdb000037,0x00000000,0x00000000,0x00000000}},	//   lilõ, --, --, --, 
   {{0x59c80da5,0xdb000489,0x00000000,0x00000000}},	//   ाचार, sklê, --, --, 
   {{0x874c0020,0x8d75fe0f,0x6d9c00ae,0x0160022e}},	//   ንቀሳቀ, زاعا, _néat, _оксо, 
   {{0xc5f10b71,0x0b8823b3,0x7ae00213,0x261002e5}},	//   ודה_, асни_, _aynt, _दूनी_, 
   {{0x7ae0138f,0x69cc002d,0x68ec0034,0x6d9c0129}},	//   _bynt, _sjae, _rzad, _réau, 
   {{0x7ae00cfd,0x6cb81aa1,0x6d9c06af,0xdb01fe10}},	//   _cynt, _ṱoḓ, _béat, kilõ, 
   {{0x7ae0002d,0x69c401e4,0x6d9c007b,0x2bc80116}},	//   _dynt, _ĉies, _céat, рлүп_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc6a4f01f,0xdb01fe11,0x68ec0122,0x3204007f}},	//   орби, shlá, _vzad, _limy_, 
   {{0x7ae000a9,0xa3d8cead,0x69ccecf1,0xe694005b}},	//   _gynt, ावस_, _tjae, чивы, 
   {{0x6b99fe12,0x846402d3,0xdb008234,0x00000000}},	//   _hovg, _ስርርዕ_, gilõ, --, 
   {{0x69ddfe13,0x68edfe14,0x6d9c00c6,0x29080009}},	// [3a050] mose, _uzad, _héas, _igaa_, 
   {{0x69ddfe15,0x6da80a28,0x693401d3,0xdb000821}},	//   lose, rśay, _بکھر, rilö, 
   {{0xe8d800b4,0xdb006935,0x7ae00129,0x2908002f}},	//   _mbọ_, silö, _xynt, _kgaa_, 
   {{0x69ddfe16,0x6b984c2e,0xa524031c,0xd00c01f7}},	//   nose, _lovg, _འབིག_, گلو_, 
   {{0x2908089c,0x32040170,0x95140302,0x6d9c007b}},	//   _mgaa_, _dimy_, _מקרא_, _léas, 
   {{0xd00c00aa,0x6b99fe17,0x6234adc0,0xdb00007f}},	//   دلو_, _novg, _негу, bklè, 
   {{0x69ddfe18,0x29080014,0xdb000221,0x201c0100}},	//   kose, _ogaa_, rklë, spwi_, 
   {{0x7ae00649,0x69ddfe19,0xe8d80248,0x2909fe1a}},	//   _rynt, jose, _abọ_, _ngaa_, 
   {{0x7ae1fe1b,0xdfd000b2,0x00000000,0x00000000}},	//   _synt, _ٻيا_, --, --, 
   {{0x5ba8ace6,0x2909fe1c,0x7ae1fe1d,0x212c0429}},	//   ском_, _agaa_, _pynt, _heeh_, 
   {{0x69ddfe1e,0x212c011f,0x7a100276,0x6d9c00ae}},	//   fose, _keeh_, _băta, _céas, 
   {{0x2005fe1f,0x27e00998,0xae0417de,0x69ddfe20}},	//   _hili_, _akhn_, _قولى, gose, 
   {{0x2005fe21,0x7ae18ca7,0x27e00051,0x7bb000db}},	//   _kili_, _wynt, _bkhn_, _жөну, 
   {{0x2908198f,0x2005fe22,0x212c102c,0xe8d80ca8}},	//   _egaa_, _jili_, _leeh_, _gbọ_, 
   {{0xcb100302,0xcf90010f,0xb4c4012d,0xdb000254}},	//   _אלו_, ײטן_, एप्_, tilõ, 
   {{0x2cb0046c,0x212c0548,0x63a40ba7,0x6d9c01e7}},	//   _öldü_, _neeh_, ekhn, _héar, 
   {{0x20040069,0xddc0005f,0x6e480023,0xdb000254}},	// [3a060] _oili_, _aplū, _ዘይንኽ, rilõ, 
   {{0x212c003e,0x2005fe23,0x6b840198,0x3204002d}},	//   _aeeh_, _nili_, _ɗigo, _simy_, 
   {{0x479804ac,0x51849ab7,0x6d9c007b,0x55e4014b}},	//   _הייס, зула, _méar, _нооб, 
   {{0x2005fe24,0x6d9c0597,0xdb00003e,0x8290075e}},	//   _aili_, _léar, gklé, رۇقچ, 
   {{0x212c06d1,0x4dcc02dd,0xc48000d4,0x85580633}},	//   _deeh_, _ﯗﺯﯨﻨ, _зляк, _اشپز_, 
   {{0x2004693c,0x69ddfe25,0x200c1570,0xbf300075}},	//   _cili_, zose, _duei_, ىرىغ, 
   {{0x2004c267,0xa3d9fe26,0x6df402dd,0x7524005a}},	//   _dili_, ावर_, وكتا, obiz, 
   {{0x6b999875,0x752401c0,0x6d9c00c6,0x212c011f}},	//   _sovg, nbiz, _réas, _geeh_, 
   {{0x2005fe27,0x6d9c00c6,0x69dcf111,0x29080e14}},	//   _fili_, _béar, vose, _rgaa_, 
   {{0x0b88169c,0x20040429,0x6d9c00ae,0x69dc060f}},	//   ссии_, _gili_, _céar, wose, 
   {{0x46d80c2e,0x6d9c00c6,0xfb3001c0,0x200c01c6}},	//   _मुंह, _déar, энээ, _zuei_, 
   {{0x20040925,0x6d9dfe28,0x75240135,0xb3c404c5}},	//   _zili_, _véas, jbiz, ্তিজ, 
   {{0x2004006c,0x6d9c00ae,0x7a100356,0x00000000}},	//   _yili_, _féar, _văta, --, 
   {{0x69ddfe29,0x200401d9,0xe8d8063f,0x6d9c007b}},	//   sose, _xili_, _nnụ_, _géar, 
   {{0x69dd1808,0x0e500023,0x7a10054e,0x27540023}},	//   pose, _ዘይኣም, _tăta, _ዝዝረበ, 
   {{0xe8d800b4,0x1c1002ab,0x61f80175,0x752401d3}},	//   _anụ_, _डूडल_, xmwl, gbiz, 
   {{0xa3d8033d,0x2814bd96,0x98a00064,0x00000000}},	// [3a070] ावल_, _توخس, kakę_, --, 
   {{0x3375fe2a,0x212c0548,0x00000000,0x00000000}},	//   нгур, _seeh_, --, --, 
   {{0x2005fe2b,0xdb000730,0x45a0005e,0x21740b01}},	//   _rili_, chlä, _كەسك, дулр, 
   {{0x2005fe2c,0x200dfe2d,0xe58400db,0x00000000}},	//   _sili_, _puei_, _تۅرۉ_, --, 
   {{0x2005fe2e,0x200c1675,0xdb0004e6,0x61f80042}},	//   _pili_, _quei_, rklé, rmwl, 
   {{0xdee4305d,0x44280ee9,0x1fa9fe2f,0x212c0548}},	//   моли, _iwc_, юкли_, _weeh_, 
   {{0x3cfc0490,0x6d9cad72,0xd3440133,0x00000000}},	//   शेने_, _réar, _زینه_, --, 
   {{0x2005fe30,0x6d9c007b,0x4429fe31,0x31c4003b}},	//   _wili_, _séar, _kwc_, _зсув, 
   {{0x2005fe32,0x6d9c48f4,0x9f5400f3,0x00000000}},	//   _tili_, _péar, _овач, --, 
   {{0x2005cd4a,0x1bb8007b,0x7524072d,0x00000000}},	//   _uili_, تابع_, zbiz, --, 
   {{0xd945fe33,0x442803cb,0x6d9c00ae,0x00000000}},	//   мени, _lwc_, _véar, --, 
   {{0x7525fe34,0x4428020c,0x00000000,0x00000000}},	//   xbiz, _owc_, --, --, 
   {{0x4429fe35,0xed046886,0x6d9c0597,0xdea03c73}},	//   _nwc_, _كومپ, _téar, _سیکی, 
   {{0x75241eff,0x65700092,0x1ec8030d,0x00000000}},	//   wbiz, ስጠበቅ_, _улçи_, --, 
   {{0x1db01d8a,0x38b40241,0x7525fe36,0x103c0240}},	//   _जतात, _búré_, tbiz, _ኣይትመ, 
   {{0x4429fe37,0x75240337,0x00000000,0x00000000}},	//   _bwc_, ubiz, --, --, 
   {{0x75242710,0xa3d853b7,0xe9a8005e,0x00000000}},	// [3a080] rbiz, ावं_, _ءدىن_, --, 
   {{0x442807ab,0x77b00724,0x3ddc0d27,0x994804f2}},	//   _dwc_, _bäxe, houw_, _الکل_, 
   {{0x27ec0c09,0x7c280007,0x38b401e1,0xdce816a3}},	//   ɓen_, _lwgr, _fúré_, bdeć, 
   {{0x6d9c020c,0x7c280857,0x7dd400e4,0xfd043226}},	//   _néap, _owgr, pãsy, _لج_, 
   {{0x44280998,0x3ddd8e3a,0xd434007b,0xd7d007d0}},	//   _gwc_, douw_, _تعجب, _सदाच, 
   {{0xa3d80882,0x2ab401e1,0x77b00166,0x44440014}},	//   ावः_, _jùbé_, _fäxe, _کرێہ, 
   {{0x7c2800a9,0xb8e0025c,0x28c41152,0x515401ec}},	//   _awgr, _གཟ_, _लेनि, _отау, 
   {{0xbdf45713,0x32340408,0x00000000,0x00000000}},	//   وريا_, ăхĕс, --, --, 
   {{0xfc3c02fb,0x65680124,0x442801f4,0x00000000}},	//   šín_, _ñehe, _xwc_, --, 
   {{0x7c280007,0x7d09fe38,0xcfa841e8,0x00000000}},	//   _dwgr, _eggs, _بارم_, --, 
   {{0x3ddc0936,0x65b00158,0x7c28035a,0x00000000}},	//   bouw_, _håhe, _ewgr, --, 
   {{0x9e64066d,0xceb40131,0xc86418cd,0x00000000}},	//   _سامن, _нәқ_, мтги, --, 
   {{0xa9b40323,0xe86c00ee,0xd72400eb,0x00000000}},	//   _үйлч, _düşý, _বাড়া_, --, 
   {{0xead44566,0x2cb00bcc,0x103c0023,0x4428045a}},	//   _поль, ıldı_, _ኣይተመ, _rwc_, 
   {{0x261401e4,0x44280009,0xa5f801ca,0xd7e800db}},	//   _eĥon_, _swc_, зеву_, سوفۇ_, 
   {{0xfaa4d4c3,0xa02008a5,0xf56800db,0x00000000}},	//   _تجهی, _þögg, мшук_, --, 
   {{0xdce805a1,0x4428020c,0xf4340276,0x229400f2}},	// [3a090] rdeć, _qwc_, кетэ, کلاس, 
   {{0x291800e5,0x00000000,0x00000000,0x00000000}},	//   lcsa_, --, --, --, 
   {{0xe53465cb,0x11380023,0x3d0c00c5,0x56f1a662}},	//   _пень, _ከምዝዓ, _डलले_, _бүрс, 
   {{0x77b004f3,0x673444f3,0x44280120,0x628001d3}},	//   _växe, lazj, _twc_, _álom, 
   {{0x656dfe39,0x6d9c004a,0xe70479f8,0x4429fe3a}},	//   meah, _réap, _تسکی, _uwc_, 
   {{0x67340e5e,0x656c06d6,0x77b0b691,0xe3740724}},	//   nazj, leah, _täxe, _ялгы, 
   {{0x644dfe3b,0xfa080003,0x9ea9fe3c,0xc29003e6}},	//   luai, _གཤེན_, явка_, _جیاب, 
   {{0x25a9fe3d,0x656dfe3e,0xd12c00aa,0xb0c00073}},	//   nkal_, neah, _هڅه_, _शेवग, 
   {{0x3dddfe3f,0x644dfe40,0x25a8005a,0x67340135}},	//   rouw_, nuai, ikal_, kazj, 
   {{0x656dfe41,0x25a8022e,0x67351c88,0xbea40108}},	//   heah, hkal_, jazj, _ошей, 
   {{0x25a9fe42,0x644dfe43,0x2b58068c,0xf8c80412}},	//   kkal_, huai, òrca_, रप्प, 
   {{0x644dfe44,0x186924f9,0x25a9fe45,0x7d09fe46}},	//   kuai, пами_, jkal_, _uggs, 
   {{0xec74035b,0x67340327,0x644dfe47,0x88800108}},	//   _аҿы_, fazj, juai, гляж, 
   {{0x644dfe48,0x25a8011f,0xd7f000c6,0x291801c3}},	//   duai, ekal_, اكس_, acsa_, 
   {{0x8b54010f,0xa6a8007b,0xc6d4004e,0x00000000}},	//   _ניקס_, وافق_, естө, --, 
   {{0x644dfe49,0x06044855,0x25a800d5,0x9f4400ae}},	//   fuai, енск_, gkal_, _chlú_, 
   {{0x644dfe4a,0x18a40661,0x3940003a,0x98a4030d}},	// [3a0a0] guai, _чапм, _idis_, _чипе, 
   {{0x39400472,0x65b00158,0xca300131,0xdb00007b}},	//   _hdis_, _råhe, ﺭﯗﺵ_, dhlú, 
   {{0xd2500150,0x644c01ab,0xcb10010f,0x00000000}},	//   انص_, auai, אלב_, --, 
   {{0x25a80076,0xc0d802d3,0x65b0143a,0x765dfe4b}},	//   ckal_, _ንዘሎ_, _påhe, mtry, 
   {{0x644c2a1f,0x39400051,0xfc3c01e7,0x00000000}},	//   cuai, _mdis_, áíl_, --, 
   {{0x7bcdfe4c,0x04280327,0xc0d40092,0x00000000}},	//   écul, _སྦྲམ_, _ርካሽ_, --, 
   {{0x765dfe4d,0x39400793,0x78b806be,0x69c00037}},	//   ntry, _odis_, _əvva, _लगली, 
   {{0xc6909b62,0x39400455,0x80b804af,0x00000000}},	//   ראה_, _ndis_, _शेके, --, 
   {{0x6441fe4e,0x0ca840da,0xdb000332,0x1b2000cc}},	//   _ālik, ятки_, chlú, _ময়ে_, 
   {{0xdcb0525b,0x765c068f,0x3941fe4f,0x161400e1}},	//   شىپ_, ktry, _adis_, _दूभर_, 
   {{0x656c1682,0x7c915a4c,0x25a9fe50,0x765c00b5}},	//   yeah, نشیا, ykal_, jtry, 
   {{0x765c5629,0xb3100135,0x25a881ed,0x6734012d}},	//   dtry, _ཏུའང_, xkal_, wazj, 
   {{0xfbccae59,0x644c10ba,0xe7842c10,0x291801ed}},	//   شتی_, xuai, پلزپ, rcsa_, 
   {{0x39400471,0x765dfe51,0x644c7820,0x00000000}},	//   _edis_, ftry, vuai, --, 
   {{0x765c4bc1,0xc98402bf,0x25a9fe52,0x656dfe53}},	//   gtry, _зупи, tkal_, teah, 
   {{0x644dfe54,0xc62002f5,0x656c00d8,0x67340327}},	//   tuai, _ফিদা_, ueah, sazj, 
   {{0x656dfe55,0x25a81368,0x261044ab,0xa3bc05d7}},	// [3a0b0] reah, rkal_, _दूरी_, इफल_, 
   {{0x25a9fe56,0x644d53a2,0x656c0943,0x39400010}},	//   skal_, ruai, seah, _zdis_, 
   {{0x9f4401ab,0x41c4036b,0x25a85a54,0x656dfe57}},	//   _ghlù_, нёда, pkal_, peah, 
   {{0x644c1140,0x6b9c002d,0xc32c0014,0x00000000}},	//   puai, örgj, شٕچ_, --, 
   {{0x77b00780,0x644c3046,0x00000000,0x00000000}},	//   _häxa, quai, --, --, 
   {{0x10a1fe58,0x7a10054e,0xc3e00139,0x443800e4}},	//   ришн, _sătm, _сөбһ, msq_, 
   {{0x611402d5,0x00000000,0x00000000,0x00000000}},	//   _адбу, --, --, --, 
   {{0xfc3c0232,0x91c00116,0xa3d8007a,0x00000000}},	//   ším_, _кәчл, ावक_, --, 
   {{0x394000d8,0x77b001e3,0x00000000,0x00000000}},	//   _rdis_, _läxa, --, --, 
   {{0x3941fe59,0x765c33b8,0x00000000,0x00000000}},	//   _sdis_, ytry, --, --, 
   {{0x394000d2,0x44380175,0x9e340108,0x00000000}},	//   _pdis_, hsq_, _рееч, --, 
   {{0x765c3be7,0x98a400fd,0x3ea40158,0xab5c00ef}},	//   vtry, виме, mynt_, biļo, 
   {{0xe9800220,0x3ea403cb,0x39400200,0x7d19fe5a}},	//   сқын, lynt_, _vdis_, mcus, 
   {{0x7d19fe5b,0xe8f40184,0x765c5243,0x3e38001f}},	//   lcus, ыһы_, ttry, _አይኖር, 
   {{0x7bc190f1,0x7c39fe5c,0xfa080003,0x3ea400a9}},	//   _imnu, lsur, _གཤིན_, nynt_, 
   {{0xceb006a9,0x3941fe5d,0xb2440032,0x3ea400ad}},	//   ביל_, _udis_, ҫмаһ, iynt_, 
   {{0xc69802d3,0x7c389583,0xb0c00490,0x3ea40142}},	// [3a0c0] ፈላለያ_, nsur, _शेंग, hynt_, 
   {{0x7c39fe5e,0x7d18010a,0x3ea4045f,0xc480010b}},	//   isur, hcus, kynt_, шлук, 
   {{0x7c3805b1,0x00000000,0x00000000,0x00000000}},	//   hsur, --, --, --, 
   {{0x3ea40cfd,0x7c39fe5f,0xd4f5fe60,0x248c110c}},	//   dynt_, ksur, _аягы, _šeme_, 
   {{0x7bc0014b,0x7c3800f3,0x3ea40363,0x7d180175}},	//   _omnu, jsur, eynt_, dcus, 
   {{0x35c805f9,0x3ea4002d,0x80a000d1,0xb40473b5}},	//   _रगड़, fynt_, شمىن, _сүзд, 
   {{0x3ea4168c,0x7c380204,0x91e400c7,0xc7b0011a}},	//   gynt_, esur, _аове, שבו_, 
   {{0x7d18037e,0x00000000,0x00000000,0x00000000}},	//   gcus, --, --, --, 
   {{0x7c39fe61,0x3ea400ad,0xebc4013d,0x00000000}},	//   gsur, aynt_, ләкн, --, 
   {{0x3ea4002d,0x2018020c,0x7d183159,0xbf1012b9}},	//   bynt_, _ésia_, acus, _күшә, 
   {{0x261401e4,0x7c392446,0x7d180334,0xa934a1a1}},	//   _eĥoj_, asur, bcus, ленш, 
   {{0x7d18dcb7,0x9f44033b,0x8c18188d,0xe9442099}},	//   ccus, _aklè_, _قيصر_, دردی, 
   {{0x9d5000cf,0x7c90027d,0xc1700375,0x77b00166}},	//   _اچىت, _نشوا, בחר_, _säxa, 
   {{0x920000b8,0x00000000,0x00000000,0x00000000}},	//   _śāle, --, --, --, 
   {{0x7b84113e,0xfaa000d8,0x00000000,0x00000000}},	//   _جانە, _вајо, --, --, 
   {{0x77b001e6,0x62800077,0xf525fe62,0x248c031c}},	//   _växa, _áloi, ифун, _ġemb_, 
   {{0x442c0ba1,0x7879fe63,0x00000000,0x00000000}},	// [3a0d0] èg_, _айыр_, --, --, 
   {{0x68ec0d62,0x02a400d6,0x98bc054e,0xa294109a}},	//   _iyad, крем, ştă_, лазі, 
   {{0x68edfe64,0xc1d80150,0x00000000,0x00000000}},	//   _hyad, _ﺃﻓﺭﺍ, --, --, 
   {{0x7d189103,0x7c380368,0x68ec0337,0xdb000cde}},	//   xcus, ysur, _kyad, nklá, 
   {{0x657c0652,0x3ea40368,0xb1440816,0x00000000}},	//   _iash, wynt_, рніл, --, 
   {{0x657dfe65,0x68ec0cf9,0xfc3c03c6,0x1ea80a12}},	//   _hash, _myad, šík_, فاعي_, 
   {{0x657dfe66,0x7d180083,0x68edfe67,0x7c390996}},	//   _kash, tcus, _lyad, wsur, 
   {{0x657c069c,0x7c39fe68,0x3ea4377c,0xd24c0330}},	//   _jash, tsur, rynt_, _رچم_, 
   {{0x7c38fe46,0x61e814dc,0x3ea4369d,0xdb000118}},	//   usur, _ikel, synt_, dklá, 
   {{0x657dfe69,0x7c39fe6a,0x7d19fe6b,0x3ea41477}},	//   _lash, rsur, scus, pynt_, 
   {{0x68edfe6c,0x657c00ad,0x9d5400e5,0x00000000}},	//   _ayad, _oash, _منات, --, 
   {{0x657c47a7,0x68ec046a,0x7c381cd4,0x61e8025c}},	//   _nash, _byad, psur, _jkel, 
   {{0x68ecd953,0x00000000,0x00000000,0x00000000}},	//   _cyad, --, --, --, 
   {{0x657c9fbe,0x7bc0016c,0xaac413f9,0x65b00194}},	//   _aash, _umnu, اتین, _råha, 
   {{0x657dfe6d,0x61e9fe6e,0x68ec513c,0x645c0139}},	//   _bash, _okel, _eyad, _aqsi, 
   {{0x657dfe6f,0x61e9fe70,0x68ec0b45,0xceb005d0}},	//   _cash, _nkel, _fyad, זיל_, 
   {{0x68ec0399,0x657dfe71,0x00000000,0x00000000}},	// [3a0e0] _gyad, _dash, --, --, 
   {{0x61e9fe72,0x657ce6d5,0x9c5002dd,0x00000000}},	//   _akel, _eash, _ﻛﻪﻟﯟ_, --, 
   {{0x6b9cc9df,0x1148010a,0x77b0007c,0x69ddb094}},	//   örgi, епей_, _häxo, éreg, 
   {{0x657dfe73,0x7a100356,0x00000000,0x00000000}},	//   _gash, _căti, --, --, 
   {{0x8fa5fe74,0x4fc43529,0x100821ef,0x00000000}},	//   ладе, лска, ىتتى_, --, 
   {{0x61e9fe75,0x657dfe76,0xdb0000bc,0x906000cf}},	//   _ekel, _zash, zklá, _ۇچتۇ, 
   {{0x0bcc005e,0x62800024,0x77b00267,0x63c401e0}},	//   ﺗﻮﻧﻮ, _šlov, _läxo, _тарҡ, 
   {{0x91e5f0a6,0x7a100311,0x657c11f2,0x00000000}},	//   _собе, _găti, _xash, --, 
   {{0x161400af,0xdb006a47,0x6aa80042,0x00000000}},	//   _दूसर_, nklæ, wydf, --, 
   {{0x68edfe77,0x99840006,0x77b00724,0xc0140375}},	//   _ryad, kslų_, _säxn, _עקבו_, 
   {{0x68ec3b24,0xbf1001e2,0x00000000,0x00000000}},	//   _syad, _اومب, --, --, 
   {{0x2eb0084a,0xdb0008ce,0x68ec002b,0x6aa80142}},	//   जनीत, kklæ, _pyad, rydf, 
   {{0x657dfe78,0xab940212,0xac581d0f,0xd8340022}},	//   _rash, _вилі, _ралф_, аҿыц_, 
   {{0x657dfe79,0xdb01fe7a,0x68ec00cd,0xc76400db}},	//   _sash, dklæ, _vyad, داحى, 
   {{0x657dfe7b,0x957c0023,0xdb000162,0x6d5c00e5}},	//   _pash, _ብጽቡቕ_, pklá, őrau, 
   {{0x657dfe7c,0xb5a40006,0x88c40fba,0x69dc0165}},	//   _qash, бруй, _متخل, éred, 
   {{0x657dfe7d,0x68ec0921,0x645c010a,0x34942c31}},	// [3a0f0] _vash, _uyad, _qqsi, батр, 
   {{0x657dfe7e,0x61e9fe7f,0x00000000,0x00000000}},	//   _wash, _skel, --, --, 
   {{0x657dfe80,0x7a100276,0x77b00166,0x25d801c6}},	//   _tash, _păti, _mäxl, _амны_, 
   {{0x657dfe81,0x00000000,0x00000000,0x00000000}},	//   _uash, --, --, --, 
   {{0xdcf8031c,0x67540023,0x00000000,0x00000000}},	//   _vawċ, _ዝምዕብ, --, --, 
   {{0x644d9035,0xf8380375,0x6280013a,0x00000000}},	//   mrai, ננות_, _šlou, --, 
   {{0xf774008f,0x61e00194,0x644c37a8,0x7a100311}},	//   מקס_, _íllo, lrai, _tăti, 
   {{0x1c45fe82,0x61e9fe83,0x644c327f,0x5f9400ec}},	//   аним, _ukel, orai, _ھلائ, 
   {{0x644dfe84,0x20180311,0x63b400d7,0x5f95fe85}},	//   nrai, _îsi_, _klzn, _پلائ, 
   {{0x644dfe86,0x5ba885c0,0x20080649,0x7ff400c6}},	//   irai, тком_, ïaid_, _إسرا, 
   {{0x644d8963,0xbf200184,0x00000000,0x00000000}},	//   hrai, _күҙҙ, --, --, 
   {{0x644dfe87,0xdb0000bc,0x7db00133,0x00000000}},	//   krai, chlý, _دڵتا, --, 
   {{0x92000055,0x00000000,0x00000000,0x00000000}},	//   _śāke, --, --, --, 
   {{0x644dfe88,0xdb0001bf,0xccf000d9,0x00000000}},	//   drai, vklæ, _וכד_, --, 
   {{0x628402fb,0x644dfe89,0x9604007b,0x00000000}},	//   jvho, erai, لبرم, --, 
   {{0x644d1f44,0x248dfe8a,0x6d9c7dec,0x6b9c0008}},	//   frai, _šema_, _béay, örgv, 
   {{0x644c679d,0xb40400db,0x00000000,0x00000000}},	// [3a100] grai, йүмд, --, --, 
   {{0xdb0012ed,0xcb1000c8,0x00000000,0x00000000}},	//   rklæ, ַלד_, --, --, 
   {{0x98b0007f,0xdb01fe8b,0x63b400d0,0x425001d5}},	//   _meyč_, sklæ, _dlzn, قنلر, 
   {{0xd10850e9,0x77b000fd,0xdb0001e3,0x4638010f}},	//   نقاه_, _mäxm, mklä, _בעטע, 
   {{0x644c4ba3,0xdb000267,0x00000000,0x00000000}},	//   crai, lklä, --, --, 
   {{0xce68013e,0x00000000,0x00000000,0x00000000}},	//   врид_, --, --, --, 
   {{0x2eb000e1,0xdb0026bc,0xa02002d2,0xcdd80798}},	//   जनेत, nklä, _þöng, књи_, 
   {{0xef1800da,0xc2780375,0x8c64030d,0x60d000e5}},	//   _daļa_, _ברלי, атод, ákmá, 
   {{0x3860022e,0x7a10054e,0xdce805d1,0x9f4400ae}},	//   _nqir_, _mătu, rdeğ, _chló_, 
   {{0x7a100356,0x0ba5fe8c,0x32180210,0x00000000}},	//   _lătu, ршим, _kury_, --, 
   {{0xdb000730,0x77b001e6,0x3338003a,0x98a002b1}},	//   chlü, _växl, _merx_, kakē_, 
   {{0x644dfe8d,0xdb000267,0x65b00fac,0x32185f0b}},	//   yrai, dklä, _råho, _mury_, 
   {{0x98b0007f,0x0574208f,0x0c75fe8e,0xedc400f1}},	//   _feyč_, یارد, _خداد, _پېښي_, 
   {{0x644c2047,0x32180ba1,0xdb01fe8f,0x6d9c020c}},	//   vrai, _oury_, fklä, _réay, 
   {{0x7a100276,0x6b9c0008,0x644c03cb,0x65940261}},	//   _bătu, örgu, wrai, баву, 
   {{0x644dfe90,0x48a9fe91,0x38600003,0x69340262}},	//   trai, _атом_, _fqir_, _униу, 
   {{0x644dfe92,0xdb0000c6,0x63b40308,0x77b00166}},	// [3a110] urai, bhló, _plzn, _zäxm, 
   {{0x644c8ef7,0x3219fe93,0xdb0000ae,0x68e8642b}},	//   rrai, _bury_, chló, üedu, 
   {{0x644dfe94,0x3219fe95,0xdb003b52,0x7a100356}},	//   srai, _cury_, cklä, _fătu, 
   {{0x2eb0084a,0x32191a1c,0xa4d400d4,0x00000000}},	//   जनैत, _dury_, _гомі, --, 
   {{0xa0695139,0x5d6801d5,0x00000000,0x00000000}},	//   уала_, ҳийм_, --, --, 
   {{0x20180048,0xa2943981,0x32180f85,0x33a802e8}},	//   _ésim_, _лагі, _fury_, _късо_, 
   {{0x9d440220,0x321800ee,0x72d43bcd,0xeff80092}},	//   бейд, _gury_, _дорф, ገሪያ_, 
   {{0x9f440192,0x77b00724,0x98b002bd,0xdb000728}},	//   _chlò_, _räxm, _seyč_, nklå, 
   {{0xa2900092,0x213c0327,0x60d40677,0x00000000}},	//   _የሚጠጋ_, mawh_, _הוּא_, --, 
   {{0x213c0369,0xc960009d,0x00000000,0x00000000}},	//   lawh_, үвэй, --, --, 
   {{0x1ae401a9,0x00000000,0x00000000,0x00000000}},	//   сонм, --, --, --, 
   {{0x7e740133,0x85400153,0x213c0327,0x00000000}},	//   _ماڵئ, žėju, nawh_, --, 
   {{0xdb000332,0xa9f8009d,0x00000000,0x00000000}},	//   thló, рхэх_, --, --, 
   {{0x7a100311,0xe86c010b,0xdb0001e3,0x00000000}},	//   _sătu, _müňý, tklä, --, 
   {{0x98a002b5,0x7a10054e,0x77b0007c,0x4b34011a}},	//   takē_, _pătu, _häxk, _הרצל_, 
   {{0xdb00342e,0x09e000a7,0x3218033f,0x213c031c}},	//   rklä, _нощн, _rury_, jawh_, 
   {{0x3219441f,0xdb005df7,0xc9b4011a,0x97d842f4}},	// [3a120] _sury_, sklä, _להקת_, _مبدأ_, 
   {{0x77b00724,0xccf008a8,0x7cc800e2,0x6280025c}},	//   _mäxk, לכן_, mērī, _ġlor, 
   {{0xdd100327,0x94840032,0x98a002b5,0x2b580ba1}},	//   _ażżm, шыңд, pakē_, òrci_, 
   {{0x213c031c,0xdb0001e3,0x8678011a,0x1138007b}},	//   gawh_, cklå, _ערכו, اثاث_, 
   {{0x7f440075,0x2eb016d1,0x00000000,0x00000000}},	//   ڭلىق_, जन्त, --, --, 
   {{0xe86c00a2,0xa2b00248,0x00000000,0x00000000}},	//   _düňý, _kọ́l, --, --, 
   {{0x8778008f,0xb1480133,0x00000000,0x00000000}},	//   ראצי, _نیام_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x77b0049f,0x3a24003e,0x2b5c062c,0x068800d1}},	//   _växj, _atnp_, _pcvc_, _ﺗﯧﻠﯩ, 
   {{0x4f648971,0x7f4011ed,0xd0080c75,0x00000000}},	//   _دارف, _неуж, _сезе_, --, 
   {{0xc33004ae,0x8d844713,0x620403b2,0xceac00ec}},	//   הות_, _гулд, _útlú, _ڪڙڇ_, 
   {{0xbc640214,0x4e04013d,0x99980066,0x00000000}},	//   جمین_, _узеб, لپپر_, --, 
   {{0x9990007f,0xe81801c6,0x0ae801d5,0x98a0012d}},	//   _miyň_, рогч_, ضرگي_, ybką_, 
   {{0x7bcc4aee,0x261000ab,0x00000000,0x00000000}},	//   écut, _दूजी_, --, --, 
   {{0x499003e6,0x0af001c0,0x7d24003e,0x28c400af}},	//   _فیدر, _хүнэ, _éssé, _लइकि, 
   {{0x2d85fe96,0xa2b001f2,0xfcd000db,0x77b001e3}},	//   ndme_, _dọ́l, _بيۇج, _läxh, 
   {{0x3495fe97,0xdb0005ac,0xc0b80092,0x57e002dd}},	// [3a130] патр, rklå, ሳቁስ_, _ﺍﻳﯩﺮ, 
   {{0x85c000e5,0x00000000,0x00000000,0x00000000}},	//   _کےرو, --, --, --, 
   {{0x56f042c6,0x627405d9,0xa5f806a6,0x213c0327}},	//   _жүрс, تهائ, _вену_, tawh_, 
   {{0x98b00055,0xb6040064,0x00000000,0x00000000}},	//   _heyā_, _няяк, --, --, 
   {{0x213c0135,0xd5840244,0x00000000,0x00000000}},	//   rawh_, _بێقه_, --, --, 
   {{0x62340364,0x7a100356,0x24880978,0xf3180024}},	//   _мегу, _mătr, mvam_, _горш_, 
   {{0x24880978,0xd00c7cbc,0x7a100356,0xde040395}},	//   lvam_, خلو_, _lătr, опки, 
   {{0x9c2401d5,0x00000000,0x00000000,0x00000000}},	//   одид, --, --, --, 
   {{0x3a240175,0x2488016d,0x00000000,0x00000000}},	//   _stnp_, nvam_, --, --, 
   {{0x2d84000d,0xaf3402da,0xfe7401af,0x00000000}},	//   adme_, _فرمت, _гүк_, --, 
   {{0x30240241,0x24880978,0xef1800e2,0x00000000}},	//   _iṣọp, hvam_, _zaļo_, --, 
   {{0x7a100276,0xbb4c00b5,0x67249574,0x2489fe98}},	//   _bătr, _dllの_, _afhj, kvam_, 
   {{0x7a1000a8,0xdb01fe99,0x06880131,0xdca40e58}},	//   _cătr, nklú, _ﺗﯧﻤﯩ, _фали, 
   {{0x25b8089c,0x2488016d,0x64400055,0x00000000}},	//   _alsl_, dvam_, _ālip, --, 
   {{0x59c40e5a,0xdecc044e,0x98b000b8,0x2488244f}},	//   _ويتك, _እዚኣ_, _deyā_, evam_, 
   {{0x28c41b4c,0x57e002dd,0x00000000,0x00000000}},	//   _लेकि, _ﺍﺳﯩﺮ, --, --, 
   {{0x53c9fe9a,0x2018065c,0x2dc00241,0x77b00254}},	// [3a140] агам_, _ésih_, _jùlọ_, _läxi, 
   {{0x7985fe9b,0xab5c0171,0x00000000,0x00000000}},	//   _haiw, biļu, --, --, 
   {{0x7985fe9c,0x24888ab9,0x00000000,0x00000000}},	//   _kaiw, avam_, --, --, 
   {{0x2488047e,0x00000000,0x00000000,0x00000000}},	//   bvam_, --, --, --, 
   {{0x7985fe9d,0x92a8015b,0x6e280175,0x183400df}},	//   _maiw, গছে_, _stdb, קאַל_, 
   {{0x79841682,0x77b00166,0x8e246c00,0xe3b40150}},	//   _laiw, _bäxi, офид, _еұу_, 
   {{0x6280022c,0xfae402da,0x718801fe,0x00000000}},	//   _álop, _آث_, _лавҳ_, --, 
   {{0x7985fe9e,0x7525fe9f,0xfd0c0451,0xbd65fea0}},	//   _naiw, nciz, ھجي_, орье_, 
   {{0x0ba813ef,0x75240200,0x00000000,0x00000000}},	//   لادى_, iciz, --, --, 
   {{0x7984002d,0x75240007,0xded4001f,0x20c80451}},	//   _aaiw, hciz, _ይላኩ_, _طبقي_, 
   {{0x7985fea1,0xe91802bf,0x2ef8022c,0x0ac4034b}},	//   _baiw, йоні_, _árf_, ющим, 
   {{0xdcf800b0,0x798401a4,0x7bcc6c80,0xbe1038eb}},	//   _wawā, _caiw, écur, _قولع, 
   {{0x28c40fe6,0x7a140276,0xdcf800b0,0xac942360}},	//   _लेखि, _pătr, _tawā, _халш, 
   {{0x6d41fea2,0xaa5c02dd,0x2488016d,0x77b00166}},	//   lama, _бекi, vvam_, _yäxi, 
   {{0x65940209,0x69c40327,0x2488016d,0x85a41d39}},	//   паву, _ċief, wvam_, ојад, 
   {{0x6d41fea3,0x2489fea4,0x7525fea5,0x637002d2}},	//   nama, tvam_, gciz, _oðnæ, 
   {{0x6d406679,0x00000000,0x00000000,0x00000000}},	// [3a150] iama, --, --, --, 
   {{0x6d41fea6,0x2489fea7,0x00000000,0x00000000}},	//   hama, rvam_, --, --, 
   {{0x6d41fea8,0x2508dbb4,0x7985fea9,0x2488016d}},	//   kama, _گردی_, _yaiw, svam_, 
   {{0xa15901be,0x2fcc0109,0x6d417aef,0xbbc40073}},	//   саду_, _amdg_, jama, _लष्क, 
   {{0x6d41feaa,0x69cc0770,0x77b00724,0x24880978}},	//   dama, _mmae, _säxi, qvam_, 
   {{0x64a4035b,0x00000000,0x00000000,0x00000000}},	//   _даҭа, --, --, --, 
   {{0x6d41feab,0x69ccb6a5,0xd24c31f6,0x442862e4}},	//   fama, _omae, _مچن_, _htc_, 
   {{0x4429feac,0x00000000,0x00000000,0x00000000}},	//   _ktc_, --, --, --, 
   {{0x7985fead,0x77b00139,0x00000000,0x00000000}},	//   _raiw, _wäxi, --, --, 
   {{0x69dc2047,0x798402a8,0x69cdfeae,0x6d403851}},	//   éren, _saiw, _amae, aama, 
   {{0x442801e0,0x9ee97b5e,0x7985feaf,0x6d41feb0}},	//   _ltc_, _افضل_, _paiw, bama, 
   {{0x6d41feb1,0xad242dfc,0x3f8403f2,0x9298011a}},	//   cama, _قىمى, ldnu_, צירת, 
   {{0xe9800046,0x7984006f,0xe0d800eb,0x00000000}},	//   тқын, _vaiw, _তরুন, --, 
   {{0x79840751,0x69cc49d1,0x3f85feb2,0xdb0003cd}},	//   _waiw, _emae, ndnu_, kklø, 
   {{0xcf9000c8,0x00000000,0x00000000,0x00000000}},	//   עטל_, --, --, --, 
   {{0x69cc0770,0x4429feb3,0xdb01feb4,0x00000000}},	//   _gmae, _btc_, dklø, --, 
   {{0x75258ce8,0x442808e5,0x00000000,0x00000000}},	// [3a160] rciz, _ctc_, --, --, 
   {{0x6d4025bf,0x4428005c,0xd1c81945,0x28c407f7}},	//   zama, _dtc_, әлде_, _लेटि, 
   {{0x6d41feb5,0x4429feb6,0x69cc015d,0x3f84025c}},	//   yama, _etc_, _ymae, ddnu_, 
   {{0x6d41feb7,0x44280f85,0x3f847fb6,0xd4680da9}},	//   xama, _ftc_, ednu_, _лиме_, 
   {{0x6d41feb8,0x4429feb9,0x6734002d,0x9f4400d0}},	//   vama, _gtc_, _ôfjû, _sklá_, 
   {{0x98a00006,0x00000000,0x00000000,0x00000000}},	//   sakė_, --, --, --, 
   {{0x7c2800da,0x00000000,0x00000000,0x00000000}},	//   _atgr, --, --, --, 
   {{0x8d74e62a,0xdef84077,0x3f84208d,0x6d400418}},	//   ساعا, цыі_, adnu_, uama, 
   {{0x6d41feba,0x4428282c,0x00000000,0x00000000}},	//   rama, _xtc_, --, --, 
   {{0x69cc08cd,0x7ae001e0,0x83000327,0xfe6c00db}},	//   _smae, _bxnt, _མཛཉུ_, ئگە_, 
   {{0xdb00020c,0x00000000,0x00000000,0x00000000}},	//   njlè, --, --, --, 
   {{0x6d401bb7,0x00000000,0x00000000,0x00000000}},	//   qama, --, --, --, 
   {{0x7c280998,0xebc402dd,0xe7943a56,0x00000000}},	//   _gtgr, _жәнн, واسک, --, 
   {{0x4429febb,0x47840022,0x00000000,0x00000000}},	//   _rtc_, чымб, --, --, 
   {{0x4429febc,0xc5f8007b,0x00000000,0x00000000}},	//   _stc_, معرض_, --, --, 
   {{0x69cc009f,0xfaf4011a,0x3f8400d7,0x00000000}},	//   _umae, _מצוי_, zdnu_, --, 
   {{0x69dc00cc,0x3f8403b2,0xf55401c4,0x00000000}},	// [3a170] mnse, ydnu_, эвтэ, --, 
   {{0x4428001e,0x00000000,0x00000000,0x00000000}},	//   _vtc_, --, --, --, 
   {{0x22942aa5,0x69dc0363,0xe86c00a2,0x6b88015d}},	//   بلاس, onse, _müōý, iddg, 
   {{0x69ddfebd,0x4429febe,0xdb00f8c6,0x20d400db}},	//   nnse, _ttc_, rklø, وقاس, 
   {{0x4429febf,0xc5f8c881,0x656dfec0,0xa2d800e1}},	//   _utc_, ्षीय_, mfah, _मशक्, 
   {{0x69dc0eef,0xdfd000c6,0x656dfec1,0xf6d401d5}},	//   hnse, ضيع_, lfah, _آزید, 
   {{0x656c009f,0xdb084a98,0x3f8404a7,0x69dd4914}},	//   ofah, ünün, rdnu_, knse, 
   {{0x69ddfec2,0x656c03fa,0x00000000,0x00000000}},	//   jnse, nfah, --, --, 
   {{0x656cb5f6,0x656800e4,0x00000000,0x00000000}},	//   ifah, _ñehu, --, --, 
   {{0x69ddfec3,0x656dfec4,0x00000000,0x00000000}},	//   ense, hfah, --, --, 
   {{0x7f41fec5,0xf1c437e3,0x656dfec6,0x77b00139}},	//   manq, लोकन, kfah, _mäxt, 
   {{0x7f41fec7,0x69dc939d,0xae0408b0,0xceb0011a}},	//   lanq, gnse, _كولى, _שיא_, 
   {{0x7c29fec8,0x656c03fa,0xa3dc0073,0x00000000}},	//   _utgr, dfah, तचा_, --, 
   {{0x69ddfec9,0x77b00036,0x7f400986,0xda6402dd}},	//   anse, _näxt, nanq, _قاعي, 
   {{0x656c0428,0x7ae001ab,0x2b580210,0x00000000}},	//   ffah, _uxnt, órce_, --, 
   {{0x7f41feca,0x656c0e78,0xee5c0ad9,0x00000000}},	//   hanq, gfah, óðið_, --, 
   {{0x394000a3,0x7f419909,0x77b00166,0xb91400cd}},	// [3a180] _ieis_, kanq, _bäxt, _nyaḥ_, 
   {{0x656c05da,0x39415b60,0xf424009d,0x00000000}},	//   afah, _heis_, _үзнү, --, 
   {{0x3941fecb,0x777ca7b1,0xb91400b8,0x98a00374}},	//   _keis_, merx, _ayaḥ_, kakī_, 
   {{0x200480bb,0x765c0516,0x65b00158,0xe35401c6}},	//   _ahli_, mury, _båhu, _үтрэ, 
   {{0x765dfecc,0x3941fecd,0x26dc0134,0x65b0332e}},	//   lury, _meis_, _ɛwom_, _påhv, 
   {{0x3941fece,0x200401c3,0x7f40401f,0x777c0005}},	//   _leis_, _chli_, ganq, nerx, 
   {{0x69ddfecf,0x422000c0,0x71c401f0,0x00000000}},	//   ynse, _адсв, _завҷ, --, 
   {{0x2005fed0,0x3941fed1,0x248c0cf4,0x6b880042}},	//   _ehli_, _neis_, _šemi_, wddg, 
   {{0x765dfed2,0x7f41fed3,0x69ddfed4,0xb32c0327}},	//   hury, banq, érem, _ཧྥོང_, 
   {{0x0a69fed5,0x7f400009,0x77b0013d,0x69ddfed6}},	//   орми_, canq, _mäxs, wnse, 
   {{0x39400221,0x765c127b,0x69ddfed7,0xcd280166}},	//   _beis_, jury, tnse, _джее_, 
   {{0x39400048,0x69dd991e,0x765dfed8,0xfa300efc}},	//   _ceis_, unse, dury, کرید, 
   {{0x3941fed9,0x69ddfeda,0x2ab401e1,0xceb401af}},	//   _deis_, rnse, _búbú_, _хәҙ_, 
   {{0xbe600023,0xdb0000a2,0x765c02d2,0x00000000}},	//   _ወይጦታ, lklý, fury, --, 
   {{0x765c0986,0x3941fedb,0x656c03fa,0xb32c031c}},	//   gury, _feis_, tfah, _ཧྥེང_, 
   {{0x656cc822,0x00000000,0x00000000,0x00000000}},	//   ufah, --, --, --, 
   {{0x656dfedc,0x7f4087b1,0x00000000,0x00000000}},	// [3a190] rfah, yanq, --, --, 
   {{0x765dfedd,0x656c3262,0x63a40218,0x91c000c7}},	//   bury, sfah, ujhn, қәсл, 
   {{0x77b0049f,0x33f401e6,0x61e80115,0x656c0112}},	//   _växt, växt_, _ĉelb, pfah, 
   {{0x397c008f,0x7f400986,0x24180064,0x00000000}},	//   ַטונ, wanq, _номы_, --, 
   {{0x660dfede,0x248c0798,0x2ca000a3,0x00000000}},	//   mmak, _éem_, _àidh_, --, 
   {{0x660dfedf,0x9fc801ca,0xef1800de,0x00000000}},	//   lmak, ягла_, _zaļi_, --, 
   {{0x7f41de09,0xd345e273,0x660d189a,0xf3140024}},	//   ranq, _سینه_, omak, _адрэ, 
   {{0x660dfee0,0x7f4003f0,0x00000000,0x00000000}},	//   nmak, sanq, --, --, 
   {{0x3f808bc6,0x7f41fee1,0x77b0008e,0x00000000}},	//   _ағла, panq, _mäxr, --, 
   {{0x3941fee2,0x660dfee3,0x5ac801ca,0x7f400986}},	//   _seis_, hmak, злом_, qanq, 
   {{0x3941fee4,0x777c0005,0xdd940024,0x00000000}},	//   _peis_, verx, _пажы, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x394004c4,0x660dfee5,0x777d0f19,0x765dfee6}},	//   _veis_, dmak, terx, wury, 
   {{0x394001cf,0x765dfee7,0x1ae40108,0xdb240108}},	//   _weis_, tury, _полм, äpät, 
   {{0x3941fee8,0x660c0270,0x00000000,0x00000000}},	//   _teis_, fmak, --, --, 
   {{0x765dfee9,0x660da786,0xd5b04667,0x3940067c}},	//   rury, gmak, دفر_, _ueis_, 
   {{0x765dfeea,0xb32c031c,0xef1800ef,0x00000000}},	// [3a1a0] sury, _ཧྥུང_, _vaļi_, --, 
   {{0xd1b004d3,0xb4e00490,0x23600268,0x660c6a24}},	//   گیرک, _तशी_, gghj_, amak, 
   {{0x660c0158,0x77b000fd,0x00000000,0x00000000}},	//   bmak, _fäxr, --, --, 
   {{0xdb01feeb,0x51f41eeb,0x61e801e4,0xda001b76}},	//   lkló, رسار, _ĉelc, ोषित_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00e43016,0x00000000,0x00000000,0x00000000}},	//   رتنی, --, --, --, 
   {{0xa3dc00af,0xc7b00375,0x00000000,0x00000000}},	//   तचर_, רבו_, --, --, 
   {{0x77b0013d,0x00000000,0x00000000,0x00000000}},	//   _mäxq, --, --, --, 
   {{0xc0e1280d,0xfc2c130e,0xdb0000e8,0x00000000}},	//   _ботк, یحی_, kkló, --, 
   {{0x660dfeec,0xd1f0001f,0x8c940220,0xdb000306}},	//   zmak, ሌዎች_, _үрді, sklý, 
   {{0x660dfeed,0x201804cc,0xa93432e1,0x00000000}},	//   ymak, _èsia_, кенш, --, 
   {{0xf1c4012a,0x660c0332,0x00000000,0x00000000}},	//   लोचन, xmak, --, --, 
   {{0xc4d804c5,0xa2e000cc,0x00000000,0x00000000}},	//   _দর্জ, _ভৰাও, --, --, 
   {{0xaa58084c,0x660cb77d,0x77b00139,0x00000000}},	//   _жику_, wmak, _säxr, --, 
   {{0x660dfeee,0x00000000,0x00000000,0x00000000}},	//   tmak, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x24700023,0x442c0036,0x00000000,0x00000000}},	// [3a1b0] _ስርሒት_, ëg_, --, --, 
   {{0xa2940212,0x00000000,0x00000000,0x00000000}},	//   казі, --, --, --, 
   {{0x660dfeef,0xdb0000db,0x00000000,0x00000000}},	//   pmak, lklò, --, --, 
   {{0xa2d42413,0x248c110c,0xa11577bc,0x3a34010f}},	//   _येण्, _šemu_, نوات, גראם_, 
   {{0xf3940184,0xc8b01b76,0xa06801ee,0x00000000}},	//   _өҫтө, ुनिट, фала_, --, 
   {{0x25a9fef0,0x247002d3,0x8658010c,0xf48401d5}},	//   ljal_, _ስርሓት_, _ጆሃንስ, _суюн, 
   {{0xb32c0327,0x00000000,0x00000000,0x00000000}},	//   _ཧྥིང_, --, --, --, 
   {{0x8d900131,0xdb002ca8,0x3ab000fb,0xdcf80210}},	//   للىش, rklü, ҫәкт, _zawę, 
   {{0x70587d9f,0xdb0000ac,0xa2d40073,0x116800f2}},	//   _патр_, sklü, _येत्, _تلقی_, 
   {{0x6295fef1,0x25a800af,0x39640107,0x80b400eb}},	//   _krzo, hjal_, ӣноҳ, _আইপ্, 
   {{0x25a9fef2,0x2b58012d,0x1ae4329e,0x00000000}},	//   kjal_, órca_, тонм, --, 
   {{0x62940cf4,0x25a9fef3,0x5cf4004e,0xdb0801e1}},	//   _mrzo, jjal_, _иялу, _àníj, 
   {{0xef1800da,0x09e0013e,0x25a80731,0xdb840353}},	//   _daļu_, роян, djal_, _агли, 
   {{0x62940356,0xc4d800cc,0x00000000,0x00000000}},	//   _orzo, _দৰ্জ, --, --, 
   {{0x07a08fdf,0x267800a8,0xc7a00454,0x00000000}},	//   шарн, нстэ_, ширк, --, 
   {{0xef1800e2,0x62800162,0xb9080154,0xabe40150}},	//   _gaļu_, _áloy, _ভর_, _ﺍﳌﻘﺎ, 
   {{0x6295fef4,0x088400fd,0xf4840214,0x97c400db}},	// [3a1c0] _arzo, _абый_, دازی, _айпе, 
   {{0x212c013f,0x25a800c5,0x61e800df,0x41b001b9}},	//   _afeh_, ajal_, _ĉela, یملر, 
   {{0xd26401ec,0x00000000,0x00000000,0x00000000}},	//   ткей, --, --, --, 
   {{0x25a815f1,0x629405d6,0x7ff003c7,0x00000000}},	//   cjal_, _drzo, یسوا, --, 
   {{0x8fa5fef5,0x62949841,0x41502626,0xe164a521}},	//   каде, _erzo, рвіс, ادمي, 
   {{0xa4c4013d,0x00000000,0x00000000,0x00000000}},	//   läşü_, --, --, --, 
   {{0xd1b139ea,0x82a00228,0x0364448c,0xe194009d}},	//   _پیشک, _карж, _ширк_, _өртэ, 
   {{0x0eb800c7,0x2019a982,0x00000000,0x00000000}},	//   зуҩы_, _èsin_, --, --, 
   {{0x256c02ea,0x3d240241,0x00000000,0x00000000}},	//   lóló_, _síwó_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfbcc20d3,0x0ba80a2c,0x6c54ca3b,0x25a80010}},	//   صتی_, _ياتى_, _склу, vjal_, 
   {{0x3d2401e1,0xf1c80150,0x00000000,0x00000000}},	//   _tíwó_, _ﻓﻠﻴﺘ, --, --, 
   {{0x85b801d9,0xfa84004e,0x25a9fef6,0x00000000}},	//   وارس_, _асый_, tjal_, --, 
   {{0x3ce00c58,0x00000000,0x00000000,0x00000000}},	//   _পৰিৱ, --, --, --, 
   {{0x25a9fef7,0xb90800fe,0x00000000,0x00000000}},	// [3a1d0] rjal_, _ভৰ_, --, --, 
   {{0x248c01fa,0x62940034,0x25a80254,0x00000000}},	//   _šems_, _przo, sjal_, --, 
   {{0xa2d40592,0x6b9c01d3,0xe880013d,0x25a8025c}},	//   ديات, örgy, _yäşü, pjal_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x661dfef8,0x6294012d,0xb5a5ca20,0x5574010f}},	//   _iisk, _wrzo, _трэй, _גערן_, 
   {{0x644dfef9,0x661cb73c,0xdee446e0,0x6294012d}},	//   msai, _hisk, лоли, _trzo, 
   {{0x661dfefa,0x2f5400d6,0x00000000,0x00000000}},	//   _kisk, ртіс, --, --, 
   {{0x661dfefb,0x644dfefc,0x3209fefd,0x8e74007b}},	//   _jisk, osai, _ахун_, اميذ_, 
   {{0x644c17e3,0xd24c0014,0x9f34753d,0x00000000}},	//   nsai, _وۆے_, _безі, --, 
   {{0xfce022f7,0x18a42c1d,0xdaa88040,0x661dfefe}},	//   лоқо, ҳамм, евод_, _lisk, 
   {{0xd944016a,0xda652a2a,0x661c023a,0x62840098}},	//   лени, ывни, _oisk, nwho, 
   {{0x644dfeff,0xbf0c00af,0x98a5ff00,0x00000000}},	//   ksai, ाधीन_, гиме, --, 
   {{0x644dbc84,0x256c00e5,0x00000000,0x00000000}},	//   jsai, zóló_, --, --, 
   {{0x661dfc60,0x644dff01,0x420c00cd,0x00000000}},	//   _aisk, dsai, िषुः_, --, 
   {{0x9599ff02,0x7bc0008e,0x644c5106,0xd6d800f2}},	//   нтау_, _ilnu, esai, رورش_, 
   {{0x661dff03,0x6abc03cd,0xd26801ec,0x00000000}},	//   _cisk, ørfe, рiнш, --, 
   {{0x966402dd,0x644dff04,0x00000000,0x00000000}},	// [3a1e0] _өкпе, gsai, --, --, 
   {{0x661c0ade,0xf7700451,0xdec80023,0x893000e5}},	//   _eisk, _ڏاڍ_, ጽርን_, _پٹیا, 
   {{0x661dff05,0x644dff06,0x50d45ab7,0x1fd80154}},	//   _fisk, asai, گزار, দকাস, 
   {{0x661dff07,0x00000000,0x00000000,0x00000000}},	//   _gisk, --, --, --, 
   {{0x7bc0033d,0x644dff08,0x93580640,0x00000000}},	//   _olnu, csai, _прву_, --, 
   {{0x661dff09,0xb405ff0a,0x0874010f,0x100800db}},	//   _zisk, _түзд, רעסט_, رتشى_, 
   {{0x91e4022e,0x00000000,0x00000000,0x00000000}},	//   _бове, --, --, --, 
   {{0x661c6f68,0x765c00ad,0xadb4009d,0x00000000}},	//   _xisk, irry, рбиш, --, 
   {{0xc9841955,0x28b8000d,0xe944072d,0x00000000}},	//   қуни, _उअधि, یرحی, --, 
   {{0x2ca00327,0xaa740063,0x00000000,0x00000000}},	//   _ġidd_, агољ, --, --, 
   {{0x7bc00175,0x00000000,0x00000000,0x00000000}},	//   _dlnu, --, --, --, 
   {{0x644caa8d,0x8c4494f2,0x7bc1ff0b,0xe4980023}},	//   ysai, _беде, _elnu, _ወጺእካ_, 
   {{0x6fb80490,0xaf8c0b82,0x765c0129,0x00000000}},	//   _अवां, _መሬትና_, erry, --, 
   {{0x661dff0c,0xa63410da,0x644dc472,0xed600092}},	//   _sisk, ингі, vsai, _ተቀባይ_, 
   {{0xba702e6f,0x4af00124,0x9a8800fb,0x00000000}},	//   _هايت, _ыҟоу, _ашыҡ_, --, 
   {{0x644dff0d,0xb0c40c70,0xa534010b,0x61e8008f}},	//   tsai, वनाग, рнач, _ĉelo, 
   {{0x661dff0e,0x2454034c,0x69dc004a,0x765c00ad}},	// [3a1f0] _visk, شناس, éreu, arry, 
   {{0x644dff0f,0x661dff10,0x2908022f,0x68ec004e}},	//   rsai, _wisk, _izaa_, _ixad, 
   {{0x644dff11,0x661dff12,0x628401f5,0x00000000}},	//   ssai, _tisk, uwho, --, 
   {{0x644dff13,0xa1180597,0x6595ff14,0x661dff15}},	//   psai, نقاط_, _таму, _uisk, 
   {{0xa0a5ff16,0x068800d1,0x00000000,0x00000000}},	//   ралд, _ﺗﯧﻜﯩ, --, --, 
   {{0x290801f7,0x00000000,0x00000000,0x00000000}},	//   _mzaa_, --, --, --, 
   {{0x8c0800bd,0xc2900214,0xc4c400cc,0x00000000}},	//   রদান_, _دیاب, _এশিঙ, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x68ec0472,0x61e9ff17,0x0c200d0e,0xbf64b1d7}},	//   _nxad, _ijel, омын, _مداو, 
   {{0x61e8a1e9,0x1a6426f0,0x22500421,0x24982a1f}},	//   _hjel, لیتی_, _kvzk_, _mrsm_, 
   {{0x61e9ff18,0x2909ff19,0xfe75ff1a,0x68ec0014}},	//   _kjel, _azaa_, _сүй_, _axad, 
   {{0x7e60008f,0x09e00137,0xfe800153,0x00000000}},	//   munp, жоюн, grįš_, --, 
   {{0x61e9ff1b,0x7e604432,0x1ca40133,0x9138010f}},	//   _mjel, lunp, _ڕێکی_, כערק, 
   {{0x61e800f3,0x00000000,0x00000000,0x00000000}},	//   _ljel, --, --, --, 
   {{0x29080472,0xd6280a93,0x7e601c06,0x61e9f283}},	//   _ezaa_, тобе_, nunp, _ojel, 
   {{0x61e9ff1c,0x09e062b8,0xceb00302,0x69dc01ed}},	//   _njel, _мощн, חיל_, éret, 
   {{0x9345ff1d,0x7e6002d1,0xd9b401d9,0x5fc401f9}},	// [3a200] инае, hunp, _مٔژھ, वसाल, 
   {{0x61e9ff1e,0x7e613c91,0x00000000,0x00000000}},	//   _ajel, kunp, --, --, 
   {{0x61e82804,0x3a20d547,0x7e602acf,0x24700023}},	//   _bjel, _kiip_, junp, _ኣዋልድ_, 
   {{0x61e81f7f,0x7e604432,0x2498032e,0x00000000}},	//   _cjel, dunp, _frsm_, --, 
   {{0x61e8036f,0x249802fa,0xcfa5ff1f,0x68ec0221}},	//   _djel, _grsm_, ишки, _xxad, 
   {{0xac50067d,0x61e9ff20,0x8f740220,0x4e9407fc}},	//   ዚኣብሄ, _ejel, руді, لشعر, 
   {{0x61e8a1e9,0xd5a80210,0x00000000,0x00000000}},	//   _fjel, _चचाज, --, --, 
   {{0x61e9ff21,0x91e400c2,0x7ee02374,0x814000db}},	//   _gjel, _тобе, تكىن, _ۇچۇن, 
   {{0xbc640597,0x00000000,0x00000000,0x00000000}},	//   لمين_, --, --, --, 
   {{0xc5e0802b,0x7e60037e,0xe7e401ec,0x00000000}},	//   _गद्य_, bunp, _ﺍﻳﺎﻟ, --, 
   {{0x9990007f,0xfba40c98,0x3a200fac,0xfbcc49f4}},	//   _miyņ_, ртый_, _biip_, بتي_, 
   {{0xbc64114f,0x00000000,0x00000000,0x00000000}},	//   دمین_, --, --, --, 
   {{0x6c35ff22,0x2d85ff23,0x6e280e96,0x00000000}},	//   _افتا, meme_, _hudb, --, 
   {{0x61e80115,0x6e280009,0x659400c7,0x00000000}},	//   _ĉelm, _kudb, әаау, --, 
   {{0x69ddff24,0x00000000,0x00000000,0x00000000}},	//   éres, --, --, --, 
   {{0x2d85ff25,0xfa3012e3,0x68edc867,0x1da8687b}},	//   neme_, _برود, _txad, कायत, 
   {{0x69dc0d92,0x2d8401af,0x600c2760,0x6e2828b5}},	// [3a210] mise, ieme_, lúme, _ludb, 
   {{0x61e8eaf5,0x69dc0d92,0x7e61ff26,0x6e280549}},	//   _sjel, lise, yunp, _oudb, 
   {{0xe6940491,0x2d85ff27,0x6724026c,0x600c0008}},	//   _الجد, keme_, _ighj, núme, 
   {{0x69dc2935,0x25ac000d,0x61e80200,0x56c400fb}},	//   nise, _õel_, _qjel, _ышыҡ, 
   {{0x349410e0,0x2d85ff28,0x61e80023,0x6e2800b8}},	//   _даяр, deme_, _vjel, _audb, 
   {{0x44380204,0x24880223,0x61e944c3,0x6e28bb54}},	//   mpq_, mwam_, _wjel, _budb, 
   {{0x61e81f7f,0x2d85ff29,0x2488009a,0x6e28058a}},	//   _tjel, feme_, lwam_, _cudb, 
   {{0x63b5ff2a,0x2d841dc9,0x69ddff2b,0x6e28014f}},	//   _hozn, geme_, jise, _dudb, 
   {{0x69ddff2c,0x67240c95,0x63b4110c,0x61f80034}},	//   dise, _oghj, _kozn, mowl, 
   {{0x6e29ff2d,0x7e60034c,0x6724265a,0x3a20008b}},	//   _fudb, punp, _nghj, _siip_, 
   {{0x69ddff2e,0x6e280a81,0x63b4fd90,0x3a21ff2f}},	//   fise, _gudb, _mozn, _piip_, 
   {{0x69ddff30,0x67240ba3,0x2d85ff31,0x61f9ff32}},	//   gise, _aghj, ceme_, nowl, 
   {{0x37c801d5,0x00000000,0x00000000,0x00000000}},	//   иғим_, --, --, --, 
   {{0x69ddff33,0x600dff34,0x61f80009,0x18a400c7}},	//   aise, lúmb, howl, _ҳаим, 
   {{0x7c39ff35,0xe8d800a2,0x6e29ff36,0xdcf80166}},	//   lpur, _baỳ_, _xudb, _yawğ, 
   {{0x6725ff37,0x69ddff38,0x00000000,0x00000000}},	//   _eghj, cise, --, --, 
   {{0x61f8068f,0x7c39ff39,0x6fb80490,0x63b48c52}},	// [3a220] dowl, npur, _अवलं, _bozn, 
   {{0xb9e4001f,0x2d85ff3a,0x7c380124,0x00000000}},	//   _ያም_, zeme_, ipur, --, 
   {{0x63b5ff3b,0x2d85ff3c,0x24880de2,0xa80400e8}},	//   _dozn, yeme_, awam_, señë, 
   {{0x7c394a3d,0x6f040118,0x00000000,0x00000000}},	//   kpur, řick, --, --, 
   {{0x6e281505,0x2d84180f,0x7c380585,0xbfc800d1}},	//   _sudb, veme_, jpur, گانە_, 
   {{0x69ddff3d,0x2d848683,0x087400c8,0x63b40165}},	//   zise, weme_, מענט_, _gozn, 
   {{0x2d85ff3e,0x61f802d0,0x6e280014,0xff4c0472}},	//   teme_, bowl, _qudb, رخو_, 
   {{0x63b40038,0x600c0085,0xfc4c02d3,0x2d840086}},	//   _zozn, gúmb, _መቐጸል, ueme_, 
   {{0x7c381c04,0x63b401d5,0xbc346e92,0x14dc0073}},	//   gpur, _yozn, یسیا_, _नेमण, 
   {{0x2d85ff3f,0x69ddff40,0x0b89ff41,0xebd81cf2}},	//   seme_, wise, усии_, рдош_, 
   {{0x69ddff42,0x4b280201,0x2d8402fb,0x248801f5}},	//   tise, _ተናግረ, peme_, zwam_, 
   {{0x67240ffb,0x2b4c0433,0x61e80115,0x7c380098}},	//   _sghj, sadc_, _ĉelk, bpur, 
   {{0x600c2760,0x7d200214,0xeff0069d,0x93f80073}},	//   súme, _عفون, _ልማድ_, ्ताच_, 
   {{0x69dc4ec2,0x6d41815a,0x5bf401e2,0x00000000}},	//   sise, lbma, _وغوړ, --, 
   {{0x7bd80302,0x63b5ff43,0x7b843e52,0x25f401ad}},	//   _תקוו, _rozn, _دانە, ंवली_, 
   {{0x4438074d,0x2488016b,0x69dc0548,0x63b41180}},	//   tpq_, twam_, qise, _sozn, 
   {{0xf99006f6,0x6f0400bc,0x6d400112,0x00000000}},	// [3a230] _سبي_, řich, ibma, --, 
   {{0x672408e5,0x0808027d,0x00000000,0x00000000}},	//   _ughj, _حزبي_, --, --, 
   {{0x63b44d3c,0x7c3801c6,0xe2340798,0x43080108}},	//   _vozn, zpur, цнењ, ухам_, 
   {{0x63b5ff44,0x7c39ff45,0x00000000,0x00000000}},	//   _wozn, ypur, --, --, 
   {{0xb9f0044e,0x5ff40137,0x7c3801c4,0x61f9ff46}},	//   _ነዛ_, озду, xpur, rowl, 
   {{0x44280194,0x8fa19c44,0xddcc00b0,0xf6740345}},	//   _iuc_, даше, ākōk, _بایخ, 
   {{0x4429ff47,0x4420003a,0x7dc420a9,0x6d40007f}},	//   _huc_, _iij_, _añsa, fbma, 
   {{0x44203a0e,0xb8fc1b4b,0x7c3800dc,0x2ca000f3}},	//   _hij_, _རྟ_, tpur, _šida_, 
   {{0x4421ff48,0x44280784,0x657c0200,0xc0c9ff49}},	//   _kij_, _juc_, _mbsh, _суве_, 
   {{0x4429ff4a,0x4421ff4b,0x69ddff4c,0x6d400009}},	//   _muc_, _jij_, èren, abma, 
   {{0x44200460,0x4429ff4d,0x7c380bcd,0x6d400250}},	//   _mij_, _luc_, spur, bbma, 
   {{0x3f85ff4e,0x4421ff4f,0xc6000073,0x00000000}},	//   lenu_, _lij_, लतोय_, --, 
   {{0x4420090c,0x4429ff50,0x7c380309,0xdea00133}},	//   _oij_, _nuc_, qpur, _ریکی, 
   {{0x44200385,0x657c509f,0x3f842b1d,0x7c29bece}},	//   _nij_, _absh, nenu_, _iugr, 
   {{0x7c202784,0x44280334,0xdb100e78,0x7c2801a8}},	//   _iinr, _auc_, ßgän, _hugr, 
   {{0x4429ff51,0x7c21ff52,0x7c286f46,0x3f840ffb}},	//   _buc_, _hinr, _kugr, henu_, 
   {{0x442045eb,0x3f85ff53,0x7c21ff54,0x26d0f518}},	// [3a240] _bij_, kenu_, _kinr, azzo_, 
   {{0x3f842804,0x44200097,0x7c29ff55,0x7c20037e}},	//   jenu_, _cij_, _mugr, _jinr, 
   {{0x4421ff56,0x3f85ff57,0x7c200263,0x4429ff58}},	//   _dij_, denu_, _minr, _euc_, 
   {{0x4421ff59,0x7c29ff5a,0xd4680209,0x42040107}},	//   _eij_, _ougr, _киме_, онхо_, 
   {{0x7c29ff5b,0x4421ff5c,0x44280205,0x00000000}},	//   _nugr, _fij_, _guc_, --, 
   {{0x44200207,0x7c2002d1,0x6e9421c3,0x00000000}},	//   _gij_, _ninr, зику, --, 
   {{0x7c29ff5d,0x00000000,0x00000000,0x00000000}},	//   _augr, --, --, --, 
   {{0x44200460,0x7c29ff5e,0xbdf431ed,0x7c20119f}},	//   _zij_, _bugr, يريا_, _ainr, 
   {{0x3f85ff5f,0x7c200ca8,0x442001d4,0x4f58038b}},	//   benu_, _binr, _yij_, _نجاد_, 
   {{0x3f840c95,0x44200070,0xd009ff60,0x61e801e4}},	//   cenu_, _xij_, _тезе_, _ĉeli, 
   {{0xc3300bd4,0x7c280064,0x5f1800cd,0x00000000}},	//   וות_, _eugr, येद्_, --, 
   {{0x7c21ff61,0x7c280007,0x9e6400aa,0x00000000}},	//   _einr, _fugr, _رامن, --, 
   {{0x7c206fa8,0x7c2800a2,0xc7b8022e,0x00000000}},	//   _finr, _gugr, аёв_, --, 
   {{0x290505bd,0x7c200c67,0x4429ff62,0x628001b8}},	//   āla_, _ginr, _ruc_, _älog, 
   {{0xc958006c,0x4421ff63,0x7c29ff64,0xaa580137}},	//   _кўп_, _rij_, _zugr, _البا_, 
   {{0x4421ff65,0x442815f5,0x6b89c5d7,0xa4d402bf}},	//   _sij_, _puc_, ledg, побі, 
   {{0x4420dba6,0x3f84009f,0x7c21ff66,0x61300248}},	// [3a250] _pij_, yenu_, _yinr, _lóló, 
   {{0x4429ff67,0x44200978,0x6b89ff68,0x2914033f}},	//   _vuc_, _qij_, nedg, ądać_, 
   {{0x4421ff69,0xcfc002f5,0x07d81e2f,0x600c0022}},	//   _vij_, ্চান, _مذھب_, júma, 
   {{0x4421ff6a,0x45a03baf,0x4429af10,0x3f85c58d}},	//   _wij_, _تەرك, _tuc_, wenu_, 
   {{0x4421ff6b,0x3f85ff6c,0x442804cc,0xf0e80b38}},	//   _tij_, tenu_, _uuc_, يىمى_, 
   {{0x656dff6d,0x7c280098,0x94b80302,0x4ac8078a}},	//   lgah, _rugr, _המשת, ानाव, 
   {{0x7c29ff6e,0x7c21ff6f,0xdb1406ea,0x656c058a}},	//   _sugr, _rinr, _ábøt, ogah, 
   {{0x3f85ff70,0xe3ac0c58,0x7c201fa8,0x3e700022}},	//   senu_, _গতিব, _sinr, rãt_, 
   {{0x3ddc334b,0x3f840093,0x7c200086,0x4c8007d8}},	//   riuw_, penu_, _pinr, елыв, 
   {{0xb2e801d9,0x7c200194,0x7c2801a6,0x00000000}},	//   _اٹہٕ_, _qinr, _vugr, --, 
   {{0x656dff71,0x7c204836,0xdae8009f,0x484800b8}},	//   kgah, _vinr, صفحو_, _āyuṃ_, 
   {{0x7c21ff72,0x7c28abb6,0x9cb400db,0xceb00677}},	//   _winr, _tugr, _ىمات, _ריא_, 
   {{0xdca424ca,0x7df00311,0xacb00150,0x656dff73}},	//   _хали, găse, _لەيب, dgah, 
   {{0x4c9804ae,0x656c058a,0x7c2003ac,0x6b8802d0}},	//   _לבנו, egah, _uinr, cedg, 
   {{0xc42800d1,0x76440022,0x00000000,0x00000000}},	//   ەتمە_, ьҭна, --, --, 
   {{0x656dff74,0x25b80036,0xbfb0031c,0x6abc1196}},	//   ggah, _cosl_, དྡྷྰ, ärfe, 
   {{0x2ea82e05,0x8a000354,0x00000000,0x00000000}},	// [3a260] _कप्त, _язъе, --, --, 
   {{0x7dc40165,0xf75403e6,0xd7880472,0xd394013d}},	//   _oñso, _زۆرج, _اندو_, чәмә_, 
   {{0xd1840209,0x91e431e2,0x00000000,0x00000000}},	//   злей, поже, --, --, 
   {{0x6b8803ac,0x656c06be,0x9584010a,0x00000000}},	//   zedg, cgah, _элме, --, 
   {{0xd009ff75,0x8598011a,0x6130032e,0x00000000}},	//   беде_, _השכו, _sóló, --, 
   {{0x613001d3,0x52740454,0x600c0332,0x00000000}},	//   _póló, _нубу, túma, --, 
   {{0x6b89ff76,0x3e540356,0x60e403b9,0x00000000}},	//   vedg, găt_, _ərmə, --, 
   {{0x8c64004e,0x6b880165,0x600c00c7,0x00000000}},	//   птод, wedg, rúma, --, 
   {{0x69dce365,0x0ba80879,0x6b88127b,0x7e6001a4}},	//   èrem, مادى_, tedg, arnp, 
   {{0x600c004e,0x656c083c,0x613001e1,0x00000000}},	//   lúmn, zgah, _tóló, --, 
   {{0x7f380302,0x6b89ff77,0x8f08021f,0x3e540356}},	//   _העבו, redg, _اياق_, căt_, 
   {{0x2fcc00e3,0x00000000,0x00000000,0x00000000}},	//   _hldg_, --, --, --, 
   {{0x1da81cc3,0x3d28028e,0x6b88035a,0xab7c010a}},	//   कारत, _اتمی_, pedg, _кӳнĕ_, 
   {{0xfbcc00c6,0x7df00311,0xfa3012ea,0x86f802dd}},	//   _متى_, răse, برید, _ﺎل_, 
   {{0x25b86517,0x00000000,0x00000000,0x00000000}},	//   _posl_, --, --, --, 
   {{0xca7400c7,0x00000000,0x00000000,0x00000000}},	//   _дуҩы, --, --, --, 
   {{0x291c0ca8,0x00000000,0x00000000,0x00000000}},	// [3a270] _àwa_, --, --, --, 
   {{0x656c1c04,0x00000000,0x00000000,0x00000000}},	//   sgah, --, --, --, 
   {{0x69cc62f1,0x7df0054e,0x00000000,0x00000000}},	//   _klae, născ, --, --, 
   {{0xe8d83127,0x00000000,0x00000000,0x00000000}},	//   _ndị_, --, --, --, 
   {{0x69cc0368,0x2fcc0f85,0xf4844ae5,0xb9280588}},	//   _mlae, _bldg_, _пурн, tevẽ_, 
   {{0x10a1ff78,0xe8d800b4,0x69cc0368,0x5f0401d5}},	//   тишн, _adị_, _llae, мзла, 
   {{0xdd9000f8,0x69cc01c4,0x1da877d7,0x00000000}},	//   ہوں_, _olae, कालत, --, 
   {{0xf1944e87,0x00000000,0x00000000,0x00000000}},	//   _пись, --, --, --, 
   {{0x1f7401b9,0xdd9001d3,0xbd4000f1,0x00000000}},	//   _олая, فوں_, ونډي, --, 
   {{0x69cdff79,0x3e540276,0x00000000,0x00000000}},	//   _alae, păt_, --, --, 
   {{0x69cc9a8e,0x19881f91,0x8d9007d6,0x533400d9}},	//   _blae, обни_, رلیش, ונתן_, 
   {{0x69cdff7a,0x4ef80375,0x00000000,0x00000000}},	//   _clae, _והעו, --, --, 
   {{0xad241066,0x00000000,0x00000000,0x00000000}},	//   _كىمى, --, --, --, 
   {{0x69cc03d1,0x81e0015b,0xd6287160,0x00000000}},	//   _elae, নকি_, жове_, --, 
   {{0x69cc00a9,0xdca400d1,0x9aa40066,0x00000000}},	//   _flae, _хаһи, _آمبو, --, 
   {{0x69cdff7b,0x00000000,0x00000000,0x00000000}},	//   _glae, --, --, --, 
   {{0x81e002f5,0x142479b2,0x00000000,0x00000000}},	// [3a280] নকা_, ддам, --, --, 
   {{0x19580124,0x00000000,0x00000000,0x00000000}},	//   _уаҩы_, --, --, --, 
   {{0x35c4013e,0x00000000,0x00000000,0x00000000}},	//   _занҳ, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x61e80115,0x00000000,0x00000000,0x00000000}},	//   _ĉelt, --, --, --, 
   {{0xfbc404d3,0x2f1402d5,0x1aac0b4c,0x00000000}},	//   _شت_, ндлё, टमाथ, --, 
   {{0xda0c0490,0x1da80a59,0xfe6c007b,0x00000000}},	//   सतात_, कांत, لدي_, --, 
   {{0x644c06af,0x91840214,0x00000000,0x00000000}},	//   _éniè, _تجسم, --, --, 
   {{0x0b89835b,0x8b6416ac,0xc1b00022,0x00000000}},	//   осни_, وادم, _шәфы, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69cdff7c,0x00000000,0x00000000,0x00000000}},	//   _plae, --, --, --, 
   {{0x8c440220,0x3da0035b,0x7ae401d3,0xdce80115}},	//   _жеде, _аршб, újta, lfeĝ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7df00356,0x0ae800ec,0x00000000,0x00000000}},	//   măsa, _ورثي_, --, --, 
   {{0x69cc01ee,0xdce800df,0x00000000,0x00000000}},	//   _tlae, rdeĥ, --, --, 
   {{0x6b99caf0,0xc98400f3,0x00000000,0x00000000}},	//   _havg, _цуки, --, --, 
   {{0x6b9803ee,0x045400cf,0x00000000,0x00000000}},	// [3a290] _kavg, بئزد, --, --, 
   {{0x2909ff7d,0x442402f6,0xa7440150,0x00000000}},	//   _iyaa_, ön_, _سۋرە_, --, 
   {{0x2a6c151c,0x27e0005a,0x6f1c0332,0xfa400092}},	//   nudb_, _imhn_, _úrch, _የተስማ, 
   {{0x2908020b,0x6b98072b,0x00000000,0x00000000}},	//   _kyaa_, _lavg, --, --, 
   {{0x6b99ff7e,0x00000000,0x00000000,0x00000000}},	//   _oavg, --, --, --, 
   {{0xe8d8063f,0x1e95f3be,0x6b980175,0xd17c0213}},	//   _ndọ_, ерир, _navg, əşmə_, 
   {{0x6f080142,0x7e900213,0xb65c010f,0x1ec803c5}},	//   _cydc, _kəpə, ַדזש, ялки_, 
   {{0xe8d801f2,0x2c14032c,0x63b00219,0x629401d3}},	//   _adọ_, _नीबू_, šenč, _iszo, 
   {{0x5f80005e,0x2908013b,0x0d80424c,0x00000000}},	//   _مۇشە, _nyaa_, улын, --, 
   {{0xdea04f6f,0x3ec40107,0x7e9003b9,0x7e2800d4}},	//   _میتی, _осеб, _ləpə, _діда_, 
   {{0x29087fc5,0x20041c06,0x9b44004b,0xee747d60}},	//   _ayaa_, _ikli_, ونکو, _алхь, 
   {{0x6abc0267,0x17f81fc4,0x00000000,0x00000000}},	//   ärfa, ृत्व_, --, --, 
   {{0x6c54013d,0x00000000,0x00000000,0x00000000}},	//   _акчу, --, --, --, 
   {{0x4cb8011a,0x62940210,0xaa6400db,0x00000000}},	//   _מזנו, _oszo, رچۉۉ, --, 
   {{0x212c003e,0x2364023a,0x8b74011a,0x00000000}},	//   _ogeh_, _öljy_, _נתקע_, --, 
   {{0x212c047e,0x00000000,0x00000000,0x00000000}},	//   _ngeh_, --, --, --, 
   {{0x2908016b,0x7985ff7f,0x53a400db,0x00000000}},	// [3a2a0] _gyaa_, _ibiw, нааб, --, 
   {{0x78a5ff80,0xfa400020,0x9948065f,0xdb1409e8}},	//   _iriv, _የተሰማ, _بلکل_, _ábót, 
   {{0x82286d7e,0x78a40419,0xd60c030d,0x600c02d2}},	//   _སྤྱི_, _hriv, _дlаб, gúmm, 
   {{0x5048044e,0x2005ff81,0x4638010f,0x00000000}},	//   _ዝተረኽ, _akli_, _מעטע, --, 
   {{0xd00937d6,0x65c00220,0x7985ff82,0x673000bc}},	//   педе_, _тұта, _mbiw, řejň, 
   {{0x80a000aa,0x00000000,0x00000000,0x00000000}},	//   امون, --, --, --, 
   {{0x8e25ff83,0x6b9805d5,0x79841418,0x00000000}},	//   нфид, _ravg, _obiw, --, 
   {{0x2005ff84,0x8228025c,0x6b98e187,0x1ea80592}},	//   _ekli_, _སྤྲི_, _savg, باهي_, 
   {{0x20040270,0xfd0c0451,0x00000000,0x00000000}},	//   _fkli_, ٽجي_, --, --, 
   {{0x7985ff85,0xc0e00139,0x00000000,0x00000000}},	//   _abiw, _соук, --, --, 
   {{0x78a5ff86,0x6b9803b2,0x00000000,0x00000000}},	//   _ariv, _vavg, --, --, 
   {{0x78a5ff87,0x7df00356,0x00000000,0x00000000}},	//   _briv, păsa, --, --, 
   {{0x78a5124b,0x00000000,0x00000000,0x00000000}},	//   _criv, --, --, --, 
   {{0x79842252,0x7ae801ed,0x6b9808fb,0x7e9003e3}},	//   _ebiw, áltá, _uavg, _səpə, 
   {{0x78a5ff88,0x2b400051,0x00000000,0x00000000}},	//   _eriv, _đich_, --, --, 
   {{0x78a42d75,0xf5e4109a,0x2c14012d,0x00000000}},	//   _friv, гіум, _नीतू_, --, 
   {{0xa8144a2f,0xd5d00037,0x00000000,0x00000000}},	// [3a2b0] _идиш, _सतरज, --, --, 
   {{0x337417cd,0x00000000,0x00000000,0x00000000}},	//   лгур, --, --, --, 
   {{0x648801e4,0xd0b003e3,0xa1940212,0x7e9003e3}},	//   _oɾig, _işəg, кажч, _təpə, 
   {{0x7de4020c,0x200403cd,0x56f1ff89,0x00000000}},	//   _mèsè, _skli_, _түсс, --, 
   {{0x660d91ae,0x2ca00332,0x00000000,0x00000000}},	//   mlak, _áidh_, --, --, 
   {{0x660dff8a,0xdee415ed,0xf8380375,0x00000000}},	//   llak, коли, ענות_, --, 
   {{0xd00d19b2,0x660dff8b,0xe134004e,0x629400e5}},	//   غلى_, olak, _анбы, _uszo, 
   {{0x4ce000bd,0x660dff8c,0x00000000,0x00000000}},	//   _পড়ু, nlak, --, --, 
   {{0x660dff8d,0x79e800e5,0x80dc00eb,0x00000000}},	//   ilak, ہودہ_, _ফুর্, --, 
   {{0x660dff8e,0x7de4020c,0x7ae401ed,0x78a4031c}},	//   hlak, _bèsè, újto, _rriv, 
   {{0x78a5ff8f,0x660dff90,0xbea4fa84,0xd9453be9}},	//   _sriv, klak, _яшай, кени, 
   {{0x78a5ff91,0x660c0989,0x645dff92,0x00000000}},	//   _priv, jlak, _ovsi, --, 
   {{0x660dff93,0x1a65c4c3,0x64c400c0,0x00000000}},	//   dlak, ریکی_, nčią, --, 
   {{0x660dff94,0x48000395,0xab84009b,0x00000000}},	//   elak, ипяв, _бућк, --, 
   {{0x07a007fa,0x7de400f2,0x660dff95,0x7dc40165}},	//   јасн, _gèsè, flak, _añsi, 
   {{0x660d0161,0x7984009a,0xc56033ac,0x00000000}},	//   glak, _ubiw, икск, --, 
   {{0x78a453f4,0x61e801e4,0x69dc00e8,0x00000000}},	// [3a2c0] _uriv, _ĉelp, ëree, --, 
   {{0xe618013e,0x22a00153,0x00000000,0x00000000}},	//   ддӣ_, _bėk_, --, --, 
   {{0x660dff96,0x645c1cce,0x835001d5,0x7df00356}},	//   blak, _evsi, شپنا, văsn, 
   {{0xfd05ff97,0x660c0c6a,0x504406ed,0x22a00064}},	//   _نج_, clak, ведб, _dėk_, 
   {{0x62800793,0x92b00154,0x765c943a,0x00000000}},	//   _älon, টনে_, lsry, --, 
   {{0x43408739,0xc0e057c6,0x00000000,0x00000000}},	//   _верв, шочк, --, --, 
   {{0x765c0af9,0xea000208,0x00000000,0x00000000}},	//   nsry, _quẫy_, --, --, 
   {{0x7d0800fe,0x765c0108,0x10a41513,0x20c800db}},	//   _bygs, isry, _иибн, ببۅي_, 
   {{0xd024f53b,0x2f8801af,0x00000000,0x00000000}},	//   _амай, _зәйн_, --, --, 
   {{0x660dff98,0xa3b4000d,0x7de401e1,0x7d09191f}},	//   zlak, झाय_, _pèsè, _dygs, 
   {{0x660dff99,0x9e642172,0x6fd400db,0x7d080174}},	//   ylak, _مانن, _càce, _eygs, 
   {{0x765c050a,0x00000000,0x00000000,0x00000000}},	//   dsry, --, --, --, 
   {{0xc86400a7,0x00000000,0x00000000,0x00000000}},	//   ътни, --, --, --, 
   {{0x6fd4026c,0x8aa43500,0x0ba82a8b,0x660dff9a}},	//   _fàce, _арид, _زاتى_, wlak, 
   {{0x660dff9b,0x27ec0bb8,0xbb8000cf,0x9f48003e}},	//   tlak, đen_, _ئلىي, ékék_, 
   {{0x27ec01ed,0xe5b41b15,0xba700345,0x00000000}},	//   ően_, ыйбы, _ئاوت, --, 
   {{0x660cdede,0x08f8007b,0x2e3801e1,0x21a401d5}},	// [3a2d0] rlak, _ترغب_, _léf_, ғилм, 
   {{0xe58400db,0x00000000,0x00000000,0x00000000}},	//   _өтмү, --, --, --, 
   {{0xa3b400bc,0x00000000,0x00000000,0x00000000}},	//   झाब_, --, --, --, 
   {{0xa11400c6,0x645c022e,0x00000000,0x00000000}},	//   هوات, _tvsi, --, --, 
   {{0x600c0998,0xa068bcf8,0x75e48595,0x00000000}},	//   lúmi, хала_, _тәрҗ, --, 
   {{0x7d08037e,0xf4840137,0x828800d4,0xc340030d}},	//   _rygs, _туюн, _осбб_, _тĕк_, 
   {{0xc290034c,0x2eb40801,0x8c080c58,0xd148001f}},	//   _خیاب, исъс, ৰদান_, ኘታቸው, 
   {{0x2e380694,0xf1a50c9d,0xb1e400d1,0x8d900131}},	//   _déf_, _крун, _кәчқ, ملىش, 
   {{0xdb100209,0xb034082d,0x00000000,0x00000000}},	//   şgün, _внуш, --, --, 
   {{0x24980ac5,0x00000000,0x00000000,0x00000000}},	//   _mssm_, --, --, --, 
   {{0xfc7400b5,0x00000000,0x00000000,0x00000000}},	//   _wロ_, --, --, --, 
   {{0x18683f51,0xceb000c8,0x765c0158,0x7d08d026}},	//   нами_, _ליב_, vsry, _tygs, 
   {{0x8d580375,0x765c015d,0x398804b2,0x00000000}},	//   _נכסי, wsry, ፕሎማሲ_, --, 
   {{0xd70810e0,0xaae4034c,0x765c0ea0,0x6fac012d}},	//   енге_, اسیو, tsry, चाएं, 
   {{0x249918a7,0xcb540375,0x00000000,0x00000000}},	//   _assm_, _עסקה_, --, --, 
   {{0x6fd400e8,0x765c7c1d,0x69dc1e54,0x00000000}},	//   _kàcc, rsry, èret, --, 
   {{0x63200154,0x985401d5,0x98a5ff9c,0xb8b401ec}},	// [3a2e0] _প্লট_, _ётиш, _сипе, _төні, 
   {{0x6fd40de2,0x24980334,0x7b8802dd,0x600c08a5}},	//   _màcc, _dssm_, _ﺒﺤﺯﺏ_, búmi, 
   {{0x8b5400c8,0x249805c7,0x6fd4002e,0xef9401b9}},	//   ריעס_, _essm_, _làcc, ییرد, 
   {{0xc6901a4c,0x2e39ff9d,0x38600158,0x00000000}},	//   _פאר_, _réf_, _kvir_, --, 
   {{0x183400c8,0x39400327,0xea000208,0xc974011a}},	//   נאַל_, _mfis_, _quẩy_, רגני_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3941ff9e,0xe8d801f2,0x7f8000f1,0x7f4400d1}},	//   _ofis_, _ibụ_, صلين, دلىق_, 
   {{0x3861ff9f,0xd31401af,0xbb140150,0x00000000}},	//   _ovir_, _аяғө, _ﺳﯟﻯ_, --, 
   {{0xdce80419,0x60d403b9,0xc22000e5,0x00000000}},	//   adeľ, _əzmk, _اکلو, --, 
   {{0xdcb007a7,0x6fd4026c,0x3940054e,0xd010007b}},	//   زىپ_, _dàcc, _afis_, _الط_, 
   {{0x8d840348,0xe8d800b4,0xa3b400af,0x2ca0031c}},	//   _булд, _mbụ_, झात_, _ġidu_, 
   {{0x394001ab,0x6fd47a70,0x2ca0009b,0xfbcc0014}},	//   _cfis_, _fàcc, _šidu_, ٲتی_, 
   {{0x6fd40de2,0x00000000,0x00000000,0x00000000}},	//   _gàcc, --, --, --, 
   {{0x394001fa,0x3860002b,0x24980356,0x41a80037}},	//   _efis_, _dvir_, _rssm_, _घोनस, 
   {{0x38600165,0x26c400d2,0x69dccd9f,0xe6940108}},	//   _evir_, âlo_, ères, шивы, 
   {{0xe8d800b4,0x249805b1,0x85b801d9,0x600c0bcd}},	//   _abụ_, _pssm_, رازس_, rúmi, 
   {{0x7dc40165,0x6fd400e8,0xdce800d0,0x2f10022e}},	// [3a2f0] _iñst, _xàcc, zdeľ, 鼠ga_, 
   {{0xf1e0002e,0x6fa40073,0xb35400cf,0x00000000}},	//   _j斡f_, _गोलं, йкуш, --, 
   {{0x06bc03f4,0x82a41064,0x38600433,0x56f001c0}},	//   _উইকি, ышае, _zvir_, _дүрс, 
   {{0x38601125,0x62800793,0x00000000,0x00000000}},	//   _yvir_, _älom, --, --, 
   {{0xb2840046,0x1fb400f0,0x00000000,0x00000000}},	//   _қырк, искр, --, --, 
   {{0x622415bf,0xae2c01ec,0xd0b006be,0x00000000}},	//   _چىسل, _ﺷﺎﺭﯞ_, nşəc, --, 
   {{0xd34404d3,0x6fd40de2,0xd0640023,0x2f550086}},	//   _ئیمه_, _sàcc, _ትደልዩ_, стіс, 
   {{0x2d95ffa0,0x6fd40de2,0x1d08004e,0x00000000}},	//   брьс, _pàcc, кейи_, --, 
   {{0x661c022e,0xa2e402dd,0xe1f80064,0x00000000}},	//   _mhsk, _соңд, _ijų_, --, 
   {{0xfe7491cb,0x9bc00137,0x00000000,0x00000000}},	//   _бүк_, تەتۉ, --, --, 
   {{0xa3ac00e1,0x6fd40694,0x3860143a,0x00000000}},	//   _कफन_, _wàcc, _svir_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x204c0023,0xab5c00ef,0x00000000,0x00000000}},	//   _ዚነበረ, ekļu, --, --, 
   {{0x661c0784,0x69dc06af,0x7c38058a,0x00000000}},	//   _ahsk, èrer, mqur, --, 
   {{0xd944fea5,0x7bc1ffa1,0x7c380784,0x599c0023}},	//   _кейи, _ionu, lqur, ፍሽፍሽ_, 
   {{0x7bc1ffa2,0x34480075,0xd2680150,0x00000000}},	//   _honu, лүми_, сiнш, --, 
   {{0x7bc1ffa3,0x7c39ffa4,0x6fd40ffb,0xd87400d1}},	// [3a300] _konu, nqur, _làca, _ئابب, 
   {{0x27ec004a,0x7bc0affe,0x76d80117,0x00000000}},	//   éent_, _jonu, _бумӣ_, --, 
   {{0xa3e48153,0x44380194,0xe7840150,0x7ae400e5}},	//   बोध_, aqq_, _الپپ, újth, 
   {{0x7bc00270,0x98a00c3c,0xe19401c6,0x00000000}},	//   _lonu, lakı_, йрчэ, --, 
   {{0x600c00d2,0x461004d3,0xe8e0004d,0x9f9801e1}},	//   húmu, _گوێر, _địu_, _kèè_, 
   {{0x7bc00483,0x80a00075,0xe1f80153,0xbf3000d1}},	//   _nonu, زمىن, _ejų_, يرىغ, 
   {{0xd1741de1,0x2abc006a,0xda040490,0xa13c010e}},	//   _вызы, _mâbë_, रवात_, _baŷd, 
   {{0xb628037e,0x7bc1ffa5,0x7dc00145,0x00000000}},	//   _ｖｉ_, _aonu, ققىن, --, 
   {{0x0ba80e5a,0x200002b5,0x41240902,0x00000000}},	//   نادى_, ōhia_, _вото_, --, 
   {{0x7bc1ffa6,0x8bc5ffa7,0x00000000,0x00000000}},	//   _conu, рсид, --, --, 
   {{0x1fb4165d,0x98a003be,0xbea0023b,0xe8940124}},	//   _устр, dakı_, _мафк, әагь, 
   {{0xbf10ae53,0x00000000,0x00000000,0x00000000}},	//   _بومب, --, --, --, 
   {{0x7bc00924,0xc7c401d5,0x6d4003ac,0x98a003e0}},	//   _fonu, асви, mcma, fakı_, 
   {{0x7bc1ffa8,0x00000000,0x00000000,0x00000000}},	//   _gonu, --, --, --, 
   {{0x6ec8013f,0x3bb8011a,0x00000000,0x00000000}},	//   bɛbe, _במגד, --, --, 
   {{0x6d41df27,0x7dc40bc9,0xa5342d1f,0x00000000}},	//   ncma, _uñst, снач, --, 
   {{0x27ec06af,0x7bc02bcc,0x24700092,0x6d4003ac}},	// [3a310] éens_, _yonu, _ድክመት_, icma, 
   {{0x73d9ffa9,0x7bc0022e,0xe58400db,0xa7740108}},	//   адур_, _xonu, _گۅرۉ_, _улоч, 
   {{0xd8f404d3,0x6fa40037,0x659441e5,0x5f4400d1}},	//   _نزیک, _गोइं, _лану, ەنتل, 
   {{0xa2940046,0x36340344,0x6fd401ab,0xc4440014}},	//   _қабі, _گریس, _ràca, _نیرن_, 
   {{0xa0a4ad36,0xd00c7ee4,0x00000000,0x00000000}},	//   салд, کلو_, --, --, 
   {{0x657c062c,0x00000000,0x00000000,0x00000000}},	//   _hcsh, --, --, --, 
   {{0x249447af,0xfe90036b,0xc1380092,0x00000000}},	//   şamı_, تیاج, _እጠይቃ, --, 
   {{0x7bc1ffaa,0xa3b42db8,0x7c398fe8,0x00000000}},	//   _sonu, झाव_, tqur, --, 
   {{0x7bc1ffab,0x61e9ffac,0xdd9001ed,0xbf640133}},	//   _ponu, _imel, قوں_, _نداو, 
   {{0x7bc0506c,0x1a64036b,0x69dc0373,0x5bb40868}},	//   _qonu, میتی_, ëren, ссиф, 
   {{0x7bc1ffad,0x48d4015b,0x9f9801e1,0x99d4007b}},	//   _vonu, সপোর, _rèè_, متحا, 
   {{0x7bc00161,0x29041b0d,0x79c801b9,0x600c1427}},	//   _wonu, ğlan_, рқиб_, rúmu, 
   {{0x7bc1ffae,0x61e9ffaf,0x95c8036b,0x9f9801e1}},	//   _tonu, _mmel, қлаб_, _pèè_, 
   {{0x2a8c013f,0x7bc00270,0xdb000036,0xb8d0000d}},	//   _sɛbe_, _uonu, ndlë, _ऐछ_, 
   {{0x98a07236,0x3f840ba7,0x00000000,0x00000000}},	//   rakı_, ifnu_, --, --, 
   {{0x61e801bf,0x6fa4000d,0x00000000,0x00000000}},	//   _nmel, _गोईं, --, --, 
   {{0x3a20079b,0x7a1801e1,0x7df00311,0x00000000}},	// [3a320] _ihip_, _e̟tó, găsi, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x47980bd9,0x3f840327,0x00000000,0x00000000}},	//   _גייס, dfnu_, --, --, 
   {{0x657c02c4,0x71741e87,0x3f84031c,0x6abc01e3}},	//   _gcsh, تۇرا, efnu_, ärfi, 
   {{0x4fc47274,0xe50800ec,0x00000000,0x00000000}},	//   йска, _نيٽو_, --, --, 
   {{0x04402205,0xd3b80212,0x8f7401ec,0x6d4002d0}},	//   _херн, _сумі_, суді, wcma, 
   {{0x8fa40efb,0xa3b40254,0x6d40058a,0x4ea401a9}},	//   _қаже, झार_, tcma, срла, 
   {{0xfe6c0222,0x3a200208,0x7bc401e3,0x00000000}},	//   ردى_, _nhip_, öjun, --, 
   {{0xea0001fb,0x6f7800d1,0x6d4001ab,0xbc64007b}},	//   _quậy_, _نەشر_, rcma, ممين_, 
   {{0x61e80427,0x00c400cf,0x00000000,0x00000000}},	//   _zmel, _улук_, --, --, 
   {{0x8fd00184,0xfba4023a,0x40900014,0x61e8cff7}},	//   _мәҫә, стый_, _ولہر, _ymel, 
   {{0x3a21ffb0,0x9f980ca8,0x600c032e,0x00000000}},	//   _chip_, _rèé_, búms, --, 
   {{0xeea80131,0x657dffb1,0xe80401f9,0x48d400eb}},	//   _ﺋﯧﻼﻥ_, _rcsh, ळवला_, সপ্র, 
   {{0xead46c6b,0x9f980241,0x60dc00fd,0x00000000}},	//   _моль, _pèé_, _üsme, --, 
   {{0x657c0998,0x0f140154,0xd1cc069d,0x00000000}},	//   _pcsh, াশকঃ_, ባሳት_, --, 
   {{0x24f80137,0xa4d40212,0x00000000,0x00000000}},	//   анбы_, ообі, --, --, 
   {{0x69dc327f,0x9f9801e1,0x3f840042,0xa6e00154}},	// [3a330] mhse, _wèé_, yfnu_, _মুখট, 
   {{0x7df00276,0x61e8ed0e,0x69dc03b9,0x00000000}},	//   răsi, _smel, lhse, --, 
   {{0xe5342075,0x2b58033f,0x7b8801ec,0x00000000}},	//   _мень, órcy_, _ﺒﺤﺴﺏ_, --, 
   {{0xe5780228,0xb88400dd,0x32640212,0x69dc0208}},	//   _өзү_, _بلیٹ, ятув, nhse, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x1ec8f610,0x1ea8007b,0xfc3c1155,0xdbf003b9}},	//   илли_, لاعي_, íím_, məçi, 
   {{0x644dffb2,0x61e802fb,0x2bdc07b6,0x69dc0009}},	//   lpai, _tmel, यसना, khse, 
   {{0x6285ffb3,0x61e9ffb4,0x63a400a3,0x644c01f4}},	//   mtho, _umel, ldhn, opai, 
   {{0x644dffb5,0x6285ffb6,0x5ff400c7,0x69dc01c3}},	//   npai, ltho, _дзау, dhse, 
   {{0x7ff51320,0x3a214d80,0x6284371a,0x3b9c001f}},	//   _اسرا, _ship_, otho, ግሌዎች_, 
   {{0x6285ffb7,0x3a2005b1,0x63a40e89,0x00000000}},	//   ntho, _phip_, idhn, --, 
   {{0x644c0357,0x62840368,0x3e0413f3,0xdb0001c7}},	//   kpai, itho, _уязв, ndlé, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3a21ffb8,0x6285c74b,0xdbf003be,0x00000000}},	//   _whip_, ktho, dəçi, --, 
   {{0x6285ffb9,0x644c00e4,0x69dc952b,0xd55800f0}},	//   jtho, epai, bhse, ијаш_, 
   {{0x69ddffba,0x6285ffbb,0xd1cc044e,0xd4f40b30}},	//   chse, dtho, ባታት_, оязы, 
   {{0x62840cfd,0x13e9ffbc,0x644c1089,0xb4b401ad}},	// [3a340] etho, амай_, gpai, झमे_, 
   {{0xc2e8009e,0xa3e403e5,0x29fc01e4,0x7df00356}},	//   _কড়ি_, बोल_, nĉan_, măsu, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x63a40013,0x00000000,0x00000000,0x00000000}},	//   adhn, --, --, --, 
   {{0x6285ffbd,0x6600737d,0x26c40fac,0x3ddc00fe}},	//   atho, élke, ølov_, বচাল, 
   {{0x6285ffbe,0xce681069,0x69dc0165,0xadec0037}},	//   btho, арид_, zhse, _जगहन_, 
   {{0xb3243ae9,0xb8cc2fb5,0x6285ffbf,0xcdd810fc}},	//   _འཛིང_, _པན_, ctho, ињи_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6ea801ed,0x00000000,0x00000000,0x00000000}},	//   _گناہ_, --, --, --, 
   {{0x7ddc01e1,0xfe6c0228,0x00000000,0x00000000}},	//   _pàsù, ردۉ_, --, --, 
   {{0x2a8c013b,0x29044a4a,0x69ddffc0,0xda040073}},	//   _bɛba_, ğlam_, thse, रवंत_, 
   {{0x644c0f12,0x8b64249f,0xbe3000f7,0x00000000}},	//   ypai, حاکم, _قىلب, --, 
   {{0x62800793,0x63a40009,0x090400d4,0x00000000}},	//   _älov, ydhn, ючом, --, 
   {{0x6284d522,0x0ae83cc6,0x00000000,0x00000000}},	//   ytho, _پرتي_, --, --, 
   {{0x05e8013e,0xaa4802dd,0x69dc03b2,0x3e440051}},	//   афаи_, _استە_, phse, _vđtg_, 
   {{0xe7397187,0xb90c01f2,0x6abc002f,0x00000000}},	//   рең_, ọrịt, ärfu, --, 
   {{0x62840649,0x83640137,0x644c0254,0x00000000}},	// [3a350] wtho, قدال, upai, --, 
   {{0x644dffc1,0x6285ffc2,0xa3e40034,0xdbf000ac}},	//   rpai, ttho, बों_, rəçi, 
   {{0xe5b5ffc3,0x644dffc4,0x2a8c013f,0x00000000}},	//   _ейны, spai, _yɛba_, --, 
   {{0x6285ffc5,0x644d9997,0x7df0084c,0x56980677}},	//   rtho, ppai, năst, _פירצ, 
   {{0x6285ffc6,0x644dffc7,0x660dffc8,0x55b8011a}},	//   stho, qpai, moak, _המרו, 
   {{0x660dffc9,0x6284a21f,0x7df00356,0x389c0a7c}},	//   loak, ptho, hăst, יידנ, 
   {{0xd3440133,0x6284025c,0x00000000,0x00000000}},	//   _رینه_, qtho, --, --, 
   {{0x660dffca,0x600c003a,0xd1bc0092,0x00000000}},	//   noak, rúmq, _ተጠቂ_, --, 
   {{0x2b5c0010,0x44200208,0xe5c000de,0x00000000}},	//   _bevc_, _khj_, _zāģē, --, 
   {{0x660c1311,0x00000000,0x00000000,0x00000000}},	//   hoak, --, --, --, 
   {{0xe8e007ae,0x2fe4007b,0xdd940064,0x00000000}},	//   _đều_, _تكلف, _нажы, --, 
   {{0x2360020c,0x44200334,0x660c00f2,0x00000000}},	//   hahj_, _lhj_, joak, --, 
   {{0x660c3a97,0xdd981d55,0x9f44008e,0x8658002b}},	//   doak, meň_, _imlâ_, _ānuṣ, 
   {{0xdd99ffcb,0xb8e4012d,0x44200208,0x7ae400e5}},	//   leň_, _एप_, _nhj_, újts, 
   {{0x660dffcc,0xa3b4772c,0x7df00356,0x5018011a}},	//   foak, झाई_, băst, מושו, 
   {{0x660dffcd,0x9b5801ee,0xdd980432,0x00000000}},	//   goak, _тиҫт_, neň_, --, 
   {{0x99900024,0x00000000,0x00000000,0x00000000}},	// [3a360] ūzų_, --, --, --, 
   {{0x4421ffce,0xd1480133,0xdd9907d3,0x00000000}},	//   _chj_, ڕشتن_, heň_, --, 
   {{0x8c180302,0x660dffcf,0xfbc000dc,0x44201ef7}},	//   צועי, boak, _वचनम, _dhj_, 
   {{0x660c0194,0xdd9800ee,0x00000000,0x00000000}},	//   coak, jeň_, --, --, 
   {{0x64400418,0xdd980216,0x63e000d1,0x00000000}},	//   _ōliv, deň_, رۋېل, --, 
   {{0x6e94dcd7,0x442019f5,0x22c401f2,0x00000000}},	//   дику, _ghj_, ịkal_, --, 
   {{0xcf240491,0xc7b00375,0x00000000,0x00000000}},	//   أرشي, תבו_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x29040205,0x61b014fb,0xc0e0022e,0x00000000}},	//   ğlak_, _جەنا, _зотк, --, 
   {{0x660c03d1,0xcf24027d,0xa3b4023e,0x00000000}},	//   zoak, _فرضي, झाए_, --, 
   {{0xdd980306,0x660c037e,0x00000000,0x00000000}},	//   beň_, yoak, --, --, 
   {{0x3ddc0196,0x26c40793,0x660c005a,0x6b8c031c}},	//   chuw_, älom_, xoak, _żogħ, 
   {{0x8d19ffd0,0x660c1311,0x7df0054e,0x00000000}},	//   _ازار_, voak, răst, --, 
   {{0x628003cd,0x660c020c,0x00000000,0x00000000}},	//   _ålog, woak, --, --, 
   {{0x7df00356,0x00000000,0x00000000,0x00000000}},	//   păst, --, --, --, 
   {{0x44200092,0xe94407d6,0x41a805f9,0x4b500244}},	//   _shj_, _غربی, _घोंस, _تێگر, 
   {{0x660dffd1,0x3495ffd2,0x4421ffd3,0x00000000}},	// [3a370] roak, натр, _phj_, --, 
   {{0xdd99ffd4,0x660dffd5,0x26d00109,0xc6a40a5b}},	//   zeň_, soak, pyzo_, _ерми, 
   {{0xaadc05b7,0x660dffd6,0x754801ed,0x44200af9}},	//   मनिक, poak, észí, _vhj_, 
   {{0x9f5008a5,0xa18800d4,0x00000000,0x00000000}},	//   _íbúi_, ібла_, --, --, 
   {{0xdd9803c6,0x25a80a64,0x4420004d,0xa0681c6c}},	//   veň_, mdal_, _thj_, цала_, 
   {{0x24891a4e,0x25a9ffd7,0x94b8011a,0x00000000}},	//   mtam_, ldal_, _ומשת, --, 
   {{0x24881637,0x6fd401ab,0x25a9709b,0xdfd000e5}},	//   ltam_, _màch, odal_, ٹيں_, 
   {{0x25a97437,0x7c2001ab,0x8d900131,0x428004b2}},	//   ndal_, _shnr, نلىش, ሮኒክስ_, 
   {{0xdd9801f1,0x6ec8013f,0x5908025c,0x25a850eb}},	//   reň_, bɛbo, _གཙེས_, idal_, 
   {{0xdd98fbd7,0x628001b8,0xa274001f,0x2489ffd8}},	//   seň_, _älos, _ያግኙን_, itam_, 
   {{0x25a9ffd9,0xdd9983d1,0x25b80204,0x2489ffda}},	//   kdal_, peň_, _onsl_, htam_, 
   {{0x2489ffdb,0x29fc0115,0x5cf40166,0x00000000}},	//   ktam_, lĉaj_, _оялу, --, 
   {{0x09e022e9,0xdca405f5,0xe8e0004d,0xef300022}},	//   тоян, _цали, _đểu_, _иҭәы, 
   {{0x62940196,0x248800dd,0x29fc01e4,0x00000000}},	//   _opzo, dtam_, nĉaj_, --, 
   {{0x25a93e11,0x2489ffdc,0x00000000,0x00000000}},	//   fdal_, etam_, --, --, 
   {{0xcb100302,0x6fd401ab,0x2488011f,0x25a8143a}},	//   _שלה_, _eàch, ftam_, gdal_, 
   {{0x224c0bb8,0x798400ca,0x53c884da,0x29fc01e4}},	// [3a380] _čeka_, _iciw, огам_, kĉaj_, 
   {{0x78a40928,0x25a800a3,0x7bc4000d,0x96b8026b}},	//   _isiv, adal_, öjuh, _думу_, 
   {{0x64400270,0xea0001fb,0x25a9ffdd,0x24886bab}},	//   _ōlit, _quầy_, bdal_, atam_, 
   {{0x24880548,0x25a8058a,0xe3b001d3,0x00000000}},	//   btam_, cdal_, پرے_, --, 
   {{0x2489ffde,0xd0580220,0x100810a8,0x1c0c02a0}},	//   ctam_, ірді_, يتتى_, हवाल_, 
   {{0x78a4009f,0xdb00002d,0x798406af,0x00000000}},	//   _msiv, idlâ, _lciw, --, 
   {{0xc24028a8,0x59dc1223,0x00000000,0x00000000}},	//   _анск, मसार, --, --, 
   {{0x78a40306,0xd344315b,0xeb380107,0x00000000}},	//   _osiv, _ریچه_, ӯзиш_, --, 
   {{0x6fd400db,0x518401af,0xc1900240,0x00000000}},	//   _làci, _нуҡа, _መምሃሪ_, --, 
   {{0xa27402d3,0x79840042,0x50640220,0x4e943b44}},	//   _ካልእን_, _aciw, _неғұ, _يشار, 
   {{0x78a4ca38,0x25a8022c,0x248801ed,0x03740375}},	//   _asiv, ydal_, ztam_, ותית_, 
   {{0xc3310b71,0x2489ffdf,0xdd980150,0x00000000}},	//   כות_, ytam_, _нші_, --, 
   {{0x25a84098,0x6038033b,0xac94010b,0x24880381}},	//   vdal_, _kňma, _чалш, xtam_, 
   {{0x798402d0,0x25b8032e,0x25a80142,0xfaec552d}},	//   _eciw, _snsl_, wdal_, اثی_, 
   {{0x78a4124c,0xfaa080fd,0x2488bdb8,0x25a889c2}},	//   _esiv, _ашын, wtam_, tdal_, 
   {{0x2489ffe0,0x79840944,0x25a8020c,0x2bdc61ef}},	//   ttam_, _gciw, udal_, यसवा, 
   {{0x25a8037f,0x69cc0093,0x291c0296,0x24881fde}},	// [3a390] rdal_, _ioae, _áwa_, utam_, 
   {{0x2489ffe1,0x6fd41daa,0x25a9ffe2,0x603802e2}},	//   rtam_, _fàci, sdal_, _nňma, 
   {{0xbb380020,0x69cc02b5,0x25a9ffe3,0x97540375}},	//   _አጠቃላ, _koae, pdal_, _איתו_, 
   {{0x6038010e,0x45a00137,0x9f4801e1,0x00000000}},	//   _aňma, _جەرك, _òkúu_, --, 
   {{0x2489ffe4,0xae4801ec,0x00000000,0x00000000}},	//   qtam_, _ﻗﺎﺭﯞ_, --, --, 
   {{0x03640014,0xe5e401d5,0x20000254,0x00000000}},	//   _زٔری_, _آزگی, õhi_, --, 
   {{0x9d440395,0x29fc01e4,0xa158551b,0x60d806be}},	//   нейд, rĉaj_, _наву_, _şamı, 
   {{0x407000d1,0xc1b80736,0x5c5402e8,0x6234026b}},	//   _ағду, _باسط_, нтоф, _чебу, 
   {{0x603802e2,0xdb0c01e1,0x00000000,0x00000000}},	//   _fňma, _èkúr, --, --, 
   {{0xfe74516c,0x8d9001b9,0x60e00205,0x00000000}},	//   _жүк_, پلیش, ızmı, --, 
   {{0x80a41fbc,0x78a404ba,0x5d7402a9,0x645c0042}},	//   चिके, _ssiv, _зулф, _lwsi, 
   {{0x69cc0381,0x645dffe5,0x204c0023,0x8e54011a}},	//   _coae, _owsi, _ዝተቐየ, _נינג_, 
   {{0x69cc003e,0x1bd402bf,0x00000000,0x00000000}},	//   _doae, _подя, --, --, 
   {{0x69cc0086,0x9f480066,0x00000000,0x00000000}},	//   _eoae, èkèk_, --, --, 
   {{0x645c0113,0xd6290261,0x2bdc07f7,0x8c18010f}},	//   _awsi, зове_, यसरा, _צוצי, 
   {{0x79840481,0x78a5ffe6,0xc6c00006,0x0cac01e1}},	//   _uciw, _tsiv, ыйск, _ìṣẹ_, 
   {{0x1424188b,0xea0001fb,0xae1002e5,0x00000000}},	// [3a3a0] едам, _quấy_, ावतन_, --, 
   {{0x085406a9,0x6fd4004e,0x645c015d,0x8544009d}},	//   _רבים_, _tàci, _dwsi, _үзэв_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x425000f2,0xfbc40133,0x00000000,0x00000000}},	//   اننر, _ڵت_, --, --, 
   {{0x92b00011,0xa14000c7,0xf38801af,0x00000000}},	//   য়নে_, рҭуе, _оҙай_, --, 
   {{0x4ea51aff,0x2f181b04,0x00000000,0x00000000}},	//   ериа, моль_, --, --, 
   {{0xfe6ca521,0x3dac08b0,0x91e40414,0x204c0023}},	//   مدي_, ﻳﻠﯩﻘ, _зове, _ዝደልይ, 
   {{0x8d742ba5,0xbef400c6,0xdb0c0241,0x00000000}},	//   راعا, عروض_, _èkùr, --, 
   {{0xdd8c0075,0xf1e0002e,0x2bdc012c,0x9f300055}},	//   تۈن_, _j斡m_, यसला, _aṇīy, 
   {{0x8afc02a8,0x7c900ada,0x00000000,0x00000000}},	//   _leƙe, اشيا, --, --, 
   {{0x8d180014,0xa3e4072a,0x00000000,0x00000000}},	//   _کٲشر_, बोट_, --, --, 
   {{0x2d8003cd,0xf0540023,0x8c440354,0x09e400fe}},	//   _øie_, _ዝተሰም, _зеде, _নৱজা, 
   {{0x69cc06d9,0xf96801c0,0xdde8015e,0x00000000}},	//   _voae, эрэй_, _ترله_, --, 
   {{0x645c03cb,0x0a68014b,0x00000000,0x00000000}},	//   _rwsi, _ерии_, --, --, 
   {{0x7dc400a2,0x03f800cc,0xb6a401d5,0x06240064}},	//   _añsy, ্তমী_, лиёл, ефам, 
   {{0x236401fa,0xe98401ec,0x645c0142,0x6608e8e6}},	//   _žlj_, _شابۋ, _pwsi, čeko, 
   {{0x5908025c,0xe5a4010b,0xa53436da,0x00000000}},	// [3a3b0] _གཙགས_, ниңи, тнач, --, 
   {{0x2904002f,0xb1e4035b,0x00000000,0x00000000}},	//   ßlau_, қәсқ, --, --, 
   {{0xb9e036bc,0xc87c03fa,0x623406ed,0xae10098a}},	//   _ቤቱ_, luß_, вежу, ावान_, 
   {{0x645c01ab,0xd654011a,0x00000000,0x00000000}},	//   _twsi, _שירת_, --, --, 
   {{0xf9940302,0xa0a4e95e,0x27e0009f,0xc87c0112}},	//   טרף_, талд, _klhn_, nuß_, 
   {{0x54400131,0x1e9401f4,0x00000000,0x00000000}},	//   _ئۆلك, врир, --, --, 
   {{0x5f0400a7,0xc87c0112,0x00000000,0x00000000}},	//   ъзка, huß_, --, --, 
   {{0x5f800131,0x00000000,0x00000000,0x00000000}},	//   _چۇشە, --, --, --, 
   {{0x24980ac5,0xf20402d5,0xe0600345,0x00000000}},	//   _jpsm_, _сяро, _ئێتی, --, 
   {{0x1a645ec2,0x6fd4004e,0xdea0036b,0x00000000}},	//   نیتی_, _bàcu, _نیتی, --, 
   {{0x2004014f,0x0c21ffe7,0x2908058a,0x9f3401ec}},	//   _ijli_, рмэн, _axaa_, _режі, 
   {{0x186855ee,0xc87c0112,0x00000000,0x00000000}},	//   мами_, fuß_, --, --, 
   {{0x88c40212,0x69a0012d,0xed34586a,0x00000000}},	//   вляв_, गज़ी, _йэшэ, --, 
   {{0xbc05ffe8,0xf84801c0,0x81d40154,0x00000000}},	//   _ячей, _үүнд_, াফি_, --, 
   {{0x3ab000d1,0x7bc4000d,0x00000000,0x00000000}},	//   _сәпт, öjuu, --, --, 
   {{0x98bcb753,0xeab042b5,0x69dc036e,0x9974010a}},	//   ştı_, _دعه_, ëret, _рукш, 
   {{0x3941ffe9,0x0440399f,0xe54000e5,0xc7a400f2}},	// [3a3c0] _igis_, иетн, ágáé, رگیل_, 
   {{0x77940133,0xd7880214,0x00000000,0x00000000}},	//   _حیسا, _کنگو_, --, --, 
   {{0x03a1eaf7,0x29040790,0x5185ffea,0x00000000}},	//   рихо, şlat_, вула, --, 
   {{0x3860009a,0x2004009f,0x6fd400cf,0x00000000}},	//   _kwir_, _ajli_, _làct, --, 
   {{0x4da800cc,0x004400ec,0x00000000,0x00000000}},	//   কামূ, نڌلي_, --, --, 
   {{0xdbc8000d,0x61e80003,0x8f74753d,0x00000000}},	//   _kõõl, _ċele, туді, --, 
   {{0x39401028,0x4ea456f6,0x931403b6,0x38600066}},	//   _ogis_, трла, _شورش, _lwir_, 
   {{0xd17444cc,0x32040419,0xaa9401a9,0x00000000}},	//   _шыгы, _ujmy_, қимч, --, 
   {{0xc5f0025f,0xdb014608,0xef942b09,0xac980451}},	//   ידה_, ndlæ, _میشد, رندا_, 
   {{0x3941ffeb,0xcef4009b,0x00000000,0x00000000}},	//   _agis_, _ичењ, --, --, 
   {{0x38600227,0xe9f84dba,0x0d84b46b,0xfaa01f10}},	//   _awir_, енні_, _ален, ашян, 
   {{0x386007a8,0x394000ca,0x648801e4,0x9fc40022}},	//   _bwir_, _cgis_, _kɾit, _аҳәа_, 
   {{0xab94005e,0x6fd400db,0x394001bf,0x00000000}},	//   _билі, _fàct, _dgis_, --, 
   {{0x3941ffec,0x8b6400db,0x6eb807d0,0xc87c002f}},	//   _egis_, _شاتم, ्मपु, ruß_, 
   {{0x2908058a,0x69dca82b,0x9210012d,0xdb5001c8}},	//   _wxaa_, ëres, तवाड़_, _اَٺ_, 
   {{0x1dc4190c,0x2d85ffed,0x224c0135,0x00000000}},	//   वायत, ngme_, _ċek_, --, 
   {{0x3861ffee,0xf1e0002e,0x3ca00116,0x24540137}},	// [3a3d0] _gwir_, _t斡j_, _шидﯤ_, انئس, 
   {{0x3494bbb8,0x00000000,0x00000000,0x00000000}},	//   рафр, --, --, --, 
   {{0x386007ab,0x69dc023a,0x00000000,0x00000000}},	//   _zwir_, okse, --, --, 
   {{0xdd00041a,0xe3c44530,0x00000000,0x00000000}},	//   _žučn, _өргү, --, --, 
   {{0xdfd5cee5,0x3164030a,0x69dc77f3,0xd12800d1}},	//   лоды, _demz_, ikse, ىقمۇ_, 
   {{0x69dc03a2,0x5f0401c0,0xfdd801f9,0x00000000}},	//   hkse, лзла, बस्फ, --, 
   {{0x2b4c030d,0x69dc4699,0x00000000,0x00000000}},	//   dcdc_, kkse, --, --, 
   {{0x69dc01a4,0x91a40150,0x00000000,0x00000000}},	//   jkse, _مۇمك_, --, --, 
   {{0x3134bf66,0xdfd000b2,0xbfa802bf,0x00000000}},	//   _ветр, _ٿيا_, _отже_, --, 
   {{0x69dda261,0x5ac8ef62,0x31640165,0xaa3c0092}},	//   ekse, елом_, _zemz_, _ከተማዋ, 
   {{0x386002b9,0x64880115,0xfe900133,0x00000000}},	//   _swir_, _kɾis, _ئیعج, --, 
   {{0x61f80280,0x1a645b2c,0x00000000,0x00000000}},	//   niwl, پیکی_, --, --, 
   {{0x6fd40137,0x6e3c1f3f,0x00000000,0x00000000}},	//   _tàct, _èrba, --, --, 
   {{0x69dc02f6,0x2a6c01f9,0x61f8010e,0xc840003b}},	//   akse, bsdb_, hiwl, серй, 
   {{0x39400280,0xd9440131,0x6eb81100,0x2bb01fd2}},	//   _tgis_, _йейи, ्मयु, जयरा, 
   {{0x2904494d,0xb8b402dd,0x69dc6fb0,0x18a48c2b}},	//   ğlar_, _көгі, ckse, _баим, 
   {{0x61f803cb,0x244801f7,0xe8a801ee,0x2bf800fe}},	// [3a3e0] diwl, نجلي_, _абыҙ_, ুতৰে_, 
   {{0x6fd40ffb,0x93446aa8,0xe61801f0,0x6eb82314}},	//   _làcr, унже, едӣ_, ्ममु, 
   {{0x4250036b,0x11d402e8,0x670004b3,0x66280037}},	//   منلر, людя, _дүрб, äskü, 
   {{0x0678008f,0xfd0400e3,0x867808a8,0xc32c0014}},	//   _אנטל, _هج_, _ארטו, سٕن_, 
   {{0x8a140375,0xdb0026bc,0x4638010f,0xb3740066}},	//   נחנו_, ldlä, _רעכע, _نگاش, 
   {{0x303401f4,0x00000000,0x00000000,0x00000000}},	//   шелё, --, --, --, 
   {{0x69dc049b,0xdb00049f,0xd06000ac,0x316405c7}},	//   ykse, ndlä, _ərəf, _temz_, 
   {{0x61f8377c,0x2bdc262c,0x3c28fcf4,0x00000000}},	//   ciwl, यस्थ, høvd_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x0ba455da,0x0b880107,0x2a6c0332,0x00000000}},	//   ушим, хсии_, tsdb_, --, 
   {{0xaa95ffef,0x6bd8179e,0x69dc01f4,0x00000000}},	//   шинч, فوکس_, tkse, --, 
   {{0x69dc0664,0x5f4400d1,0xd1bc00b7,0x6fd401ab}},	//   ukse, _йүән_, _ሰበብ_, _tàcs, 
   {{0x69ddfff0,0x00000000,0x00000000,0x00000000}},	//   rkse, --, --, --, 
   {{0x69ddfff1,0x8aa41422,0x0ba800db,0x00000000}},	//   skse, _брид, _ساتى_, --, 
   {{0xbb8000cf,0xf748027d,0x00000000,0x00000000}},	//   _الىي, الفي_, --, --, 
   {{0x057401e0,0x2bdc00bc,0xe5541fbe,0x00000000}},	//   ыҙмы_, यसका, ркањ, --, 
   {{0xf9900597,0xc6a42b17,0x99647f7a,0x00000000}},	// [3a3f0] _ربي_, _өрни, _өтөл, --, 
   {{0x4308041b,0x60cc01f4,0xa6f401f4,0x00000000}},	//   нхем_, äamm, _взош, --, 
   {{0x6594363c,0x648801e4,0x349400c7,0xe214009d}},	//   _кану, _pɾis, _қарр, амжы, 
   {{0x81a91147,0xa19532c6,0x00000000,0x00000000}},	//   عطاف_, радч, --, --, 
   {{0x29fc01e4,0x3c2821e3,0x1b0400cc,0x00000000}},	//   lĉas_, løve_, _উৰাই_, --, 
   {{0xd478008f,0x6fd400a3,0x61f80042,0x00000000}},	//   _באשל, _sàcr, siwl, --, 
   {{0xdee4036b,0xd00dfff2,0xcee402bf,0x3c280fac}},	//   ройи, بلو_, идше_, nøve_, 
   {{0x60380100,0xdb006130,0x00000000,0x00000000}},	//   _kňmk, ndlå, --, --, 
   {{0xdb0006ed,0x3c280b1a,0x0dc400fd,0x443001ab}},	//   celê, høve_, рлый_, omx_, 
   {{0xb0340b3b,0xd9dc3507,0x44300332,0x00000000}},	//   _гнуш, मस्ट, nmx_, --, 
   {{0x1a04d413,0x443000e4,0xdb000200,0x00000000}},	//   ипом, imx_, melë, --, 
   {{0x1d189416,0x3f8401c4,0x3c2801bf,0x3ea40042}},	//   _июль_, lgnu_, døve_, mwnt_, 
   {{0x3ddc013f,0x9aa400f1,0x81b400fe,0x00000000}},	//   mkuw_, _چمتو, _চকা_, --, 
   {{0x3f85fff3,0xdb000023,0xcf90010f,0x95740023}},	//   ngnu_, nelë, ֿטן_, ርዓትን_, 
   {{0x29049033,0x44300204,0x3c2803cd,0x9974013d}},	//   şlap_, dmx_, røvd_, _купш, 
   {{0x06044a20,0x44300097,0xdb000200,0x00000000}},	//   анск_, emx_, helë, --, 
  
   {{0x18a440b6,0x29fc0115,0xd46857e5,0xdb00036e}},	// [3a400] _тапм, aĉas_, тизе_, kelë, 
   {{0x83c02077,0xc0c80023,0xdb00036e,0x00000000}},	//   обуж, _በሰላ_, jelë, --, 
   {{0x27ec0b45,0x877802e4,0x3ddc0de2,0xdb00036e}},	//   ɗen_, _באיי, kkuw_, delë, 
   {{0xc20c0014,0x00000000,0x00000000,0x00000000}},	//   ؤل_, --, --, --, 
   {{0x4fc40a70,0x6744012b,0xe4e40064,0x00000000}},	//   иска, _átjá, _ліён, --, 
   {{0xdb0001c7,0x00000000,0x00000000,0x00000000}},	//   gelë, --, --, --, 
   {{0x9e701e4a,0x3e642309,0x5ed80154,0x923400db}},	//   كۇلت, ашын_, _ভেবে, _نىسش, 
   {{0xdb004ceb,0x00000000,0x00000000,0x00000000}},	//   melè, --, --, --, 
   {{0xdb000240,0x8238010f,0xdc544605,0x224c00ef}},	//   belë, _יעלצ, یریک, _čeki_, 
   {{0xdcb012b7,0x6608098d,0x23c82e1e,0x7bc4007c}},	//   سىپ_, čeki, रायद, öjup, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe86405f5,0x245c0241,0x35a4001f,0x82480023}},	//   йхгү, _jámò_, ገኝበት_, _ንነብሶ, 
   {{0xfbcc9a5a,0x23c86d58,0x6c540120,0x00000000}},	//   ستی_, रामद, _уклу, --, 
   {{0x3c280158,0x245c01e1,0x2905fff4,0x7e6c01f4}},	//   tøve_, _lámò_, ăla_, _äipä, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3c280e38,0x29fc008f,0x48640408,0x78ac007c}},	//   røve_, rĉas_, _къоб, älvä, 
   {{0x4b0001d9,0x44300327,0xdb004cab,0x00000000}},	// [3a410] _دِژٕ, tmx_, rdlå, --, 
   {{0x9f440548,0xdb00007f,0xdd9800a2,0x00000000}},	//   _ellê_, felè, miňe_, --, 
   {{0xdb01fff5,0xa2780276,0xe1240131,0xc6a41d39}},	//   gelè, убеу_, әмли, _трпи, 
   {{0x81dc00cc,0x00000000,0x00000000,0x00000000}},	//   ধোন_, --, --, --, 
   {{0x661dfff6,0x245c01e1,0x60f8084c,0xdb000200}},	//   _iksk, _dámò_, ындя_, telë, 
   {{0x656dfff7,0x33580276,0x00000000,0x00000000}},	//   laah, _варэ_, --, --, 
   {{0xd00dea27,0x212801a2,0x3f8401fa,0xdb001762}},	//   على_, ťah_, rgnu_, celè, 
   {{0x63a5fff8,0x69dc05e4,0x00000000,0x00000000}},	//   lehn, êrel, --, --, 
   {{0xfec405d9,0xdb01fff9,0x7f380092,0x00000000}},	//   ابڙو_, melé, ጠናዎች, --, 
   {{0x656dfffa,0x63a41dd4,0x49f00135,0xdb0149ed}},	//   haah, nehn, _བཏུལ_, lelé, 
   {{0x656c0325,0xae7800d6,0x6285fffb,0x3dac00fe}},	//   kaah, _всіх_, nuho, কাবল, 
   {{0x656c0050,0x661c0472,0x98a400a7,0x63a5fffc}},	//   jaah, _nksk, биме, hehn, 
   {{0x62840069,0x91b80375,0x656c0014,0xae140a11}},	//   huho, אמרי, daah, _بذلت, 
   {{0x6285fffd,0x661c017a,0x87e401e0,0xec6804b4}},	//   kuho, _aksk, йһың_, _өрәк_, 
   {{0x6728038e,0xdb0000dd,0x95983d58,0x63a417da}},	//   řejn, kelé, лтау_, dehn, 
   {{0x6285fffe,0x656dffff,0xdb000ba1,0x00000000}},	//   duho, gaah, velè, --, 
   {{0x62840051,0x94a81f0d,0x00000000,0x00000000}},	// [3a420] euho, دازِ_, --, --, 
   {{0x60380100,0xdb020000,0x6284031c,0xb60800d7}},	//   _fňmi, telè, fuho, _blšá, 
   {{0x62860001,0x656d9393,0x96b91416,0x0ea4012d}},	//   guho, baah, _супу_, _कैंड, 
   {{0xdb01b16c,0x765c089c,0x656cf32c,0x20080332}},	//   gelé, mpry, caah, éain_, 
   {{0x7bc01125,0x765c05e4,0x63a60002,0xdb00020c}},	//   _onnu, lpry, behn, selè, 
   {{0x62860003,0x80a00131,0xdb00007f,0xd1c80139}},	//   buho, سمىن, pelè, _өлге_, 
   {{0xd1740209,0x765c17b5,0x6370035b,0x661c1057}},	//   _гызы, npry, _ẽngu, _yksk, 
   {{0x9f440240,0xdb002d16,0xa6d40154,0x00000000}},	//   _yllë_, celé, _হেঁট, --, 
   {{0xcb447125,0x00000000,0x00000000,0x00000000}},	//   йхни, --, --, --, 
   {{0x656c022f,0x8bc60004,0x765d4034,0x201400f1}},	//   zaah, ссид, kpry, _وښود_, 
   {{0x441800c8,0x656c0067,0xc330010f,0x00000000}},	//   רויס, yaah, ּור_, --, 
   {{0x7bc20005,0xf40000bd,0x63a403fa,0x6ec8013f}},	//   _ennu, ্তির_, zehn, bɛbr, 
   {{0x62860006,0xd1bc001f,0x765c0ea0,0x7a280165}},	//   zuho, _ሰአት_, epry, añto, 
   {{0x656c00b4,0xdb0000dd,0x6284022f,0x765c0ea0}},	//   waah, zelé, yuho, fpry, 
   {{0x656e0007,0xf40000bd,0xfa3401b9,0x765c0ea0}},	//   taah, ্তার_, ترید, gpry, 
   {{0x62840306,0x2bb00bae,0x63a4003e,0xdb00002e}},	//   vuho, जयका, wehn, xelé, 
   {{0x656c331f,0xdb0000dd,0x6284003c,0x81b400cc}},	// [3a430] raah, velé, wuho, _চকল_, 
   {{0x244c02d2,0x6b9c031e,0x73d801a9,0x00000000}},	//   _vþm_, еrgi, бдур_, --, 
   {{0xdb0000dd,0x656c166a,0x63a60008,0x8614014b}},	//   telé, paah, rehn, _генӣ_, 
   {{0x62860009,0x63a6000a,0x00000000,0x00000000}},	//   ruho, sehn, --, --, 
   {{0xdb0000dd,0xb97c0bd9,0x6286000b,0xf486000c}},	//   relé, רנדי, suho, _нурн, 
   {{0x66080552,0x6284316f,0x64a40022,0xdb02000d}},	//   čeku, puho, _лаҭа, selé, 
   {{0xf1e0002e,0xdb02000e,0xb7dc00c8,0x6284031c}},	//   _c斡s_, pelé, רקוי, quho, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x61ea000f,0xdb0000b5,0x1bea0010,0x1d099591}},	//   _ilel, ldlø, идии_, репи_, 
   {{0x61e9591a,0x9f44004e,0x765ccce0,0x9f3400d4}},	//   _hlel, _ollé_, ypry, _дезі, 
   {{0x61e80066,0xdb00365a,0x93f8011a,0xdcb000d1}},	//   _klel, ndlø, שלתי, سىھ_, 
   {{0x9d180137,0x00000000,0x00000000,0x00000000}},	//   _коет_, --, --, --, 
   {{0x9f460011,0xdc6805f5,0x61ea0012,0xe6d401c6}},	//   _allé_, _талд_, _mlel, үцсэ, 
   {{0xe8f4052f,0x7bc20013,0x61ea0014,0xac740220}},	//   яһы_, _unnu, _llel, _ءانش, 
   {{0x61e84774,0x7fb400bc,0x00000000,0x00000000}},	//   _olel, _आफैँ, --, --, 
   {{0xceb0008d,0x61e80521,0xf49402d3,0x765c17b5}},	//   ויל_, _nlel, _ዝርርብ_, rpry, 
   {{0x765c3ec8,0x3a200e4f,0x6ac40137,0x00000000}},	// [3a440] spry, _ikip_, _وقۇم, --, 
   {{0x61e9ba50,0x9984fb65,0x765c017a,0xaab0000d}},	//   _alel, _الکو, ppry, _जनमक, 
   {{0xdcf8013d,0xafdc00a2,0x15456671,0xd628010a}},	//   _mawı, _niĸa, _менм, _воне_, 
   {{0x61ea0015,0xea8c008f,0x00000000,0x00000000}},	//   _clel, רנאָ, --, --, 
   {{0x61e802b9,0xf1e0002e,0x00000000,0x00000000}},	//   _dlel, _b斡r_, --, --, 
   {{0x61ea0016,0xd3720017,0x88b8008f,0x00000000}},	//   _elel, _زهر_, יזני, --, 
   {{0xfe6ca7a7,0x3a20f974,0x1dc40073,0x04400c5c}},	//   ندي_, _okip_, वांत, _церн, 
   {{0x61e8020c,0x217401c6,0xdb000022,0x00000000}},	//   _glel, _нуур, telî, --, 
   {{0xdcf80166,0xae440014,0xc0f40240,0x00000000}},	//   _bawı, _کھتو, ላቐል_, --, 
   {{0x3a200194,0xcf880014,0x3c280158,0x00000000}},	//   _akip_, _خضرن_, tøva_, --, 
   {{0xdcf8013d,0x61e8023a,0x8d440408,0x7a0400e5}},	//   _dawı, _ylel, _мĕнш, zőte, 
   {{0x3c2800cc,0x8c4400f3,0x00000000,0x00000000}},	//   røva_, _деде, --, --, 
   {{0xc1700375,0x25fc012d,0x00000000,0x00000000}},	//   וחר_, रोफी_, --, --, 
   {{0x3a220018,0x69ac07f7,0x00000000,0x00000000}},	//   _ekip_, _जसवी, --, --, 
   {{0x23c80d41,0x3a20008b,0xc5f803b7,0xbb500133}},	//   रासद, _fkip_, аѓа_, _تۆپب, 
   {{0xe944179e,0x3c2806ea,0x3b8000fb,0xe858010a}},	//   _عربی, nøvn_, _еләг, _лаиш_, 
   {{0x34947377,0xdcf8008e,0xd24800d1,0x00000000}},	// [3a450] матр, _yawı, ەكمۇ_, --, 
   {{0x61e85b3c,0x00000000,0x00000000,0x00000000}},	//   _slel, --, --, --, 
   {{0x61e81509,0x613401d3,0xe69400ec,0x224c0171}},	//   _plel, külé, _علحد, _čeks_, 
   {{0xbbd40254,0xdb005522,0x00000000,0x00000000}},	//   _ढक्क, rdlø, --, --, 
   {{0xf7f45175,0xf1e0002e,0x1fb83452,0x00000000}},	//   _رسید, _p斡r_, йлды_, --, 
   {{0x24880200,0xa34400f2,0x00000000,0x00000000}},	//   muam_, _رپره, --, --, 
   {{0x61ea0019,0x248a001a,0x8f50009f,0x00000000}},	//   _tlel, luam_, رنيش, --, 
   {{0x25a80013,0x63b5f9d0,0xfd78001f,0xdcf8008e}},	//   neal_, _hazn, _ተቀምጦ_, _sawı, 
   {{0x248a001b,0x212c0cf4,0x0d8006a6,0x00000000}},	//   nuam_, _uzeh_, хлын, --, 
   {{0x25aa001c,0xdcf8013d,0x00000000,0x00000000}},	//   heal_, _qawı, --, --, 
   {{0x63b6001d,0x248a001e,0x25a8030a,0x672401f4}},	//   _mazn, huam_, keal_, _nyhj, 
   {{0x63b405a1,0x6abc00b5,0x24880240,0xdd947aa6}},	//   _lazn, ærfa, kuam_, _хады, 
   {{0x25aa001f,0xdcf80724,0x2488036e,0xdb000118}},	//   deal_, _tawı, juam_, melí, 
   {{0x248a0020,0x6294022e,0x9f5020b2,0x00000000}},	//   duam_, _oqzo, _özä_, --, 
   {{0x25a803f9,0x22942dba,0xec3400f7,0x1ae4009d}},	//   feal_, jåk_, _تووگ, _хойм, 
   {{0x25aa0021,0xceb00bd4,0x60380100,0x3a200072}},	//   geal_, עין_, _kňms, _ukip_, 
   {{0x248a0022,0x63b400da,0x94460023,0x00000000}},	// [3a460] guam_, _bazn, سپان, --, 
   {{0xdb00002d,0x613401d3,0x63b40356,0xead00241}},	//   melâ, zülé, _cazn, _tẹti_, 
   {{0x25aa0024,0x63b53c8d,0x66080010,0xf0e41a4e}},	//   beal_, _dazn, čekr, कन्द_, 
   {{0x25a9d9b0,0x24881d9e,0xead001e1,0x84740b82}},	//   ceal_, buam_, _kẹri_, ርሃምን_, 
   {{0x5ed8045e,0x63b48c2c,0x248a0025,0xead00241}},	//   _ভেলে, _fazn, cuam_, _jẹri_, 
   {{0x78a40851,0x63b60026,0x00000000,0x00000000}},	//   _mpiv, _gazn, --, --, 
   {{0xe81c2e04,0x00000000,0x00000000,0x00000000}},	//   पकता_, --, --, --, 
   {{0xdb00045f,0xf1d05d9c,0x201803b2,0x1ea8310b}},	//   kelâ, _सचिन, _ísin_, تاهي_, 
   {{0x613401ed,0xdb00000f,0x63b4008e,0x00000000}},	//   rülé, jelâ, _yazn, --, 
   {{0x25a803bd,0x3c28022c,0xdd9800d0,0x613401d3}},	//   zeal_, søvn_, riňa_, sülé, 
   {{0x78a40270,0x613400dd,0x2488036e,0x7c901e4b}},	//   _apiv, pülé, zuam_, وشیا, 
   {{0x80b00034,0x24880218,0xdb0000d8,0x00000000}},	//   _इनमे, yuam_, felâ, --, 
   {{0xdb000b21,0x25a8011a,0xfc2c6a0e,0x24880200}},	//   gelâ, veal_, ضحی_, xuam_, 
   {{0x61d80882,0xead00241,0xec1407d6,0x24880200}},	//   _भक्ष, _dẹri_, _توتد, vuam_, 
   {{0x25aa0027,0x78a402e2,0xb8f400cd,0x6b9c0037}},	//   teal_, _epiv, _सॊ_, õrgu, 
   {{0x63b40bb8,0x248a0028,0x6a14177b,0x25a80076}},	//   _sazn, tuam_, _імпу, ueal_, 
   {{0xe7387c51,0x63b585cb,0x5eac0131,0xb97c0375}},	// [3a470] сең_, _pazn, ﻳﻐﯘﺭ, _הנחי, 
   {{0x25aa0029,0x6724049b,0xaab00316,0x248a002a}},	//   seal_, _tyhj, _जनाक, ruam_, 
   {{0x25aa002b,0x24880070,0x7a44020c,0xf1c80073}},	//   peal_, suam_, mètè, ळांन, 
   {{0x2296002c,0x24880381,0x63b4012d,0x00000000}},	//   råk_, puam_, _wazn, --, 
   {{0x24880de4,0xb9d8069c,0x660e002d,0x31600005}},	//   quam_, _ሽዑ_, mnak, ñiza_, 
   {{0x645e002e,0x9e5815d1,0x8fa0074d,0xe2f801ec}},	//   _itsi, ориф_, ваше, _дегі_, 
   {{0x44200066,0x660d83f9,0xdb0000bc,0xc0c80092}},	//   _ikj_, onak, telí, _በደም_, 
   {{0x4420020b,0x645e002f,0x62847acd,0x9d44247f}},	//   _hkj_, _ktsi, mrho, мейд, 
   {{0x660e0030,0x69c00421,0x71440137,0x35c400bc}},	//   inak, ēlel, _كۉمۅ, _लोफ़, 
   {{0x645c055a,0x62840942,0xdb020031,0x78a400e2}},	//   _mtsi, orho, selí, _rpiv, 
   {{0x26c00457,0x99840137,0x657c00b5,0x660de256}},	//   _nrho_, ولدو, _odsh, knak, 
   {{0x645e0032,0xdb000b21,0x660d1f86,0x44200200}},	//   _otsi, telâ, jnak, _lkj_, 
   {{0x660c041a,0x645c0b89,0x26c20033,0x442001d3}},	//   dnak, _ntsi, _arho_, _okj_, 
   {{0x660e0034,0x657c02d0,0x9f44003a,0xdb00002d}},	//   enak, _adsh, _illâ_, relâ, 
   {{0x645e0035,0x65b000e4,0xc84000ee,0x6284031c}},	//   _atsi, _ẽhai, терй, jrho, 
   {{0x660e0036,0xdb020037,0x62840042,0x00000000}},	//   gnak, melà, drho, --, 
   {{0x62840327,0x25fc28d4,0x985407d6,0x657c0334}},	// [3a480] erho, रोधी_, _ўтиш, _ddsh, 
   {{0x9f44cd48,0x660e0038,0x7a48020c,0x657c035a}},	//   _allí_, anak, bètè, _edsh, 
   {{0x645e0039,0x44207dec,0xfbb400cc,0x8c18011a}},	//   _etsi, _dkj_, জাপত, קועי, 
   {{0xda0c0574,0x8be402f5,0x657c0334,0x64a4035b}},	//   ाचित_, গোপন_, _gdsh, ьаӡа, 
   {{0x628400db,0x92bc00fe,0x00000000,0x00000000}},	//   arho, ইহে_, --, --, 
   {{0x44215128,0xdb00022c,0x00000000,0x00000000}},	//   _gkj_, ndló, --, --, 
   {{0xb8d02fb5,0xbea0041b,0x00000000,0x00000000}},	//   _ནར_, вајк, --, --, 
   {{0x1dc46b26,0x657c0009,0xc0c800d1,0x20c800cf}},	//   वागत, _xdsh, ﺑﺒﻪﺗ, تبۅي_, 
   {{0x2d98000f,0x00000000,0x00000000,0x00000000}},	//   ęre_, --, --, --, 
   {{0x9b741e0e,0x61e80327,0x7c380023,0x00000000}},	//   ىڭىز_, _ċeli, _ብብርቱ, --, 
   {{0x660e003a,0xc0c80092,0x00000000,0x00000000}},	//   ynak, _በደሙ_, --, --, 
   {{0xcd0401b9,0x2be0228d,0x00000000,0x00000000}},	//   _очли, _पकवा, --, --, 
   {{0x6e22003b,0x660c01a2,0x6eb80833,0x34c817c6}},	//   momb, vnak, ्मकु, रमोद, 
   {{0x62840036,0x26c00427,0x660c0784,0x645e003c}},	//   yrho, _prho_, wnak, _rtsi, 
   {{0x660e003d,0xfb30010b,0xd1e00023,0x00000000}},	//   tnak, _иншэ, _ሞጎት_, --, 
   {{0x62840122,0x660e003e,0x7ae4037e,0xfb8400fb}},	//   vrho, unak, øjte, _ебәк_, 
   {{0x660d4365,0x6e2000ec,0xdb02003f,0xe5a40131}},	// [3a490] rnak, iomb, pelã, миңи, 
   {{0x6e220040,0x660e0041,0x999000a2,0xc3041176}},	//   homb, snak, _ajyň_, وباو, 
   {{0x660e0042,0x6284257c,0x44200254,0x26c00108}},	//   pnak, urho, _vkj_, _urho_, 
   {{0x6e220043,0xdb000122,0x61140220,0x660c0113}},	//   jomb, nelá, ндеу, qnak, 
   {{0xa06900fc,0x6e220044,0x645e0045,0x25b8009a}},	//   чала_, domb, _utsi, _iasl_, 
   {{0x6e20009f,0xa2940816,0x00000000,0x00000000}},	//   eomb, _пагі, --, --, 
   {{0x6e220046,0x00000000,0x00000000,0x00000000}},	//   fomb, --, --, --, 
   {{0x6e215016,0xca141884,0x00000000,0x00000000}},	//   gomb, ﺳﯩﺮ_, --, --, 
   {{0xdb006b07,0x1c460047,0x25b800a2,0x00000000}},	//   delá, нним, _masl_, --, 
   {{0xaab0012c,0xdb0000db,0xb034eb51,0x00000000}},	//   _जनशक, telà, _ануш, --, 
   {{0x6e220048,0xdd90009a,0x00000000,0x00000000}},	//   bomb, _موا_, --, --, 
   {{0xae700058,0x61f82917,0x4cd41c82,0x25b9b7f9}},	//   _ئۇيغ, _çalı, _তেওঁ, _nasl_, 
   {{0x1c380962,0xdca49674,0x394401e6,0x7c2000b5}},	//   _езды_, _чали, äms_, _tknr, 
   {{0xcc7425f9,0x8edc00fb,0xda00000d,0x00000000}},	//   _טענה_, hын_, _लगवत_, --, 
   {{0xdb013800,0x25b8032e,0x00000000,0x00000000}},	//   belá, _basl_, --, --, 
   {{0xdb0002f0,0x99d40244,0x00000000,0x00000000}},	//   celá, _ستبا, --, --, 
   {{0x13e8151a,0x00000000,0x00000000,0x00000000}},	// [3a4a0] пмай_, --, --, --, 
   {{0x6e220049,0x25b801e4,0x779400e5,0x00000000}},	//   zomb, _easl_, _جیسا, --, 
   {{0x6e22004a,0x386000a3,0x25fc141f,0x25b801a9}},	//   yomb, _htir_, रोही_, _fasl_, 
   {{0x386007ab,0xf8a401ad,0x00000000,0x00000000}},	//   _ktir_, _ओहाय, --, --, 
   {{0x9f4400f7,0x6e2005da,0x38600327,0x69d001f9}},	//   _allà_, vomb, _jtir_, धाती, 
   {{0xd25001d9,0xdb000194,0x6e22004b,0x0874010f}},	//   _منس_, melæ, womb, געסט_, 
   {{0xdb005b47,0xcfb002f5,0x03a000d4,0x00000000}},	//   lelæ, চালন, _щиро, --, 
   {{0x386000b0,0xc32008e2,0x6e20009f,0xfe6c004b}},	//   _otir_, _смск, uomb, حدو_, 
   {{0xdb0001bf,0x00000000,0x00000000,0x00000000}},	//   nelæ, --, --, --, 
   {{0x6e22004c,0x23c800e1,0xe04801b9,0x00000000}},	//   somb, राएद, _قشله_, --, 
   {{0x6e22004d,0x38602166,0x270402f5,0xdb000e33}},	//   pomb, _atir_, _শুনো_, telá, 
   {{0x6ae40220,0x6e200117,0x9e640a11,0x00000000}},	//   ежүз, qomb, _شامن, --, 
   {{0x38601529,0xdb02004e,0x6d5c0118,0xfaa001ec}},	//   _ctir_, jelæ, ěrad, _ұшын, 
   {{0xdb0012ed,0xca380150,0x00000000,0x00000000}},	//   selá, _ﻓﺭﺩ_, --, --, 
   {{0x2fcc003e,0x2cb800e2,0xdb02004f,0x00000000}},	//   _mndg_, ārdu_, pelá, --, 
   {{0x38615715,0x4b5003e6,0x0948094f,0xc7640137}},	//   _ftir_, _جێگر, _эчки_, باڭى, 
   {{0x69ce0050,0x291c025a,0xdb000ac8,0x28f8005b}},	// [3a4b0] _inae, _âwa_, gelæ, _цепь_, 
   {{0x69cc002d,0x16000574,0x00000000,0x00000000}},	//   _hnae, रोबर_, --, --, 
   {{0xa5fa0051,0x69cc26be,0x25b80010,0x80b000e1}},	//   _жену_, _knae, _tasl_, _इनहे, 
   {{0xdb0000b5,0x00000000,0x00000000,0x00000000}},	//   belæ, --, --, --, 
   {{0xba0402d3,0x69cc1541,0x386001a9,0x557400df}},	//   _ግዳ_, _mnae, _xtir_, _בערן_, 
   {{0x9f44204e,0x248803a2,0x00000000,0x00000000}},	//   _allá_, mram_, --, --, 
   {{0xdd90036b,0x80b0012d,0x4cd800eb,0x00000000}},	//   لوغ_, _इनवे, _বইগু, --, 
   {{0x69cc0083,0x8d580137,0x248a0052,0xdfd000ec}},	//   _nnae, үшөт_, oram_, _ھيا_, 
   {{0x00d836fe,0xdfd000b2,0x248803a2,0x00000000}},	//   _عبرت_, _پيا_, nram_, --, 
   {{0x69ce0053,0x248806ed,0xce840137,0x00000000}},	//   _anae, iram_, ردۉۉ, --, 
   {{0xbe84cea8,0x7de40212,0x38602b00,0x00000000}},	//   _سجاو, _підд, _stir_, --, 
   {{0x2489d800,0xdd1c0276,0x69cc003a,0xaf040395}},	//   kram_, _câţi, _cnae, _счук, 
   {{0x24884e81,0xdb000790,0x69940124,0x00000000}},	//   jram_, kelç, ырэх, --, 
   {{0x69ce0054,0x248a0055,0x81d4015b,0xdb000158}},	//   _enae, dram_, িসি_, velæ, 
   {{0x248a0056,0xd628f7e0,0xdb0000a2,0x1a640244}},	//   eram_, дове_, delç, _جیجی_, 
   {{0x248a0057,0x69ce0058,0x65b801c0,0x25fc43d1}},	//   fram_, _gnae, нуур_, रोली_, 
   {{0x248a0059,0x69640f13,0xb3a405a2,0x00000000}},	// [3a4c0] gram_, _صديق, ллаһ, --, 
   {{0xdb00037e,0x9f440393,0x23e4003b,0x00000000}},	//   relæ, _illæ_, лієв, --, 
   {{0x248a005a,0x958400fd,0x69cc03ac,0xdb0012e8}},	//   aram_, _илне, _ynae, selæ, 
   {{0x248a005b,0xdb00ae83,0xd08401af,0x00000000}},	//   bram_, melä, выки, --, 
   {{0x2489f737,0xdb02005c,0x25fc0490,0x61e8031c}},	//   cram_, lelä, रोळी_, _ċelt, 
   {{0xe70801d5,0x4ea41df6,0xff4c00be,0x00000000}},	//   _آتین_, вриа, يخى_, --, 
   {{0x60c40a28,0xdb015515,0x59b0012d,0x3dac0116}},	//   āhma, nelä, ज़ार, ﺳﻠﯩﻘ, 
   {{0x7dc04d2d,0xdd8c0131,0x4cd80154,0xadb400f3}},	//   لقىن, كۈم_, _বেগু, убиш, 
   {{0x2b5c00db,0x8eb005a9,0x00000000,0x00000000}},	//   _pfvc_, _چەتت, --, --, 
   {{0xdb02005d,0x69cc0072,0x8eb00150,0x20080129}},	//   kelä, _snae, _نەتت, éait_, 
   {{0xdb00d026,0x00000000,0x00000000,0x00000000}},	//   jelä, --, --, --, 
   {{0x1ea81564,0x9f44011f,0xdb02005e,0x69cc003a}},	//   _سامي_, _ullá_, delä, _qnae, 
   {{0x2cb800e2,0x24880009,0x00000000,0x00000000}},	//   ārds_, xram_, --, --, 
   {{0x69cc00a9,0x248a005f,0xaa94013d,0xc050010f}},	//   _wnae, vram_, _бикч, יזש_, 
   {{0xdb020060,0x3204009f,0x26c40005,0x248a0061}},	//   gelä, _ommy_, ílo_, wram_, 
   {{0x248a0062,0x69ce0063,0x57b00220,0xafdc00a2}},	//   tram_, _unae, _құст, _diĸi, 
   {{0x24881bce,0x26c4008f,0xa53590ee,0x00000000}},	// [3a4d0] uram_, ŭlo_, унач, --, 
   {{0x248a0064,0x4424001e,0x32060065,0xdb0040fc}},	//   rram_, ôn_, _ammy_, belä, 
   {{0x248800cd,0xdb000139,0x00000000,0x00000000}},	//   sram_, celä, --, --, 
   {{0xf65000f8,0xa5f8402e,0x248a0066,0x1e94039b}},	//   _گئی_, _чему_, pram_, ҳрир, 
   {{0x1fa82bbd,0x24887d0f,0xa0a4021f,0x00000000}},	//   екли_, qram_, уалд, --, 
   {{0x3204045a,0x0f7001d5,0xc340030d,0xdd98010e}},	//   _emmy_, йғур, _кĕл_, miňi_, 
   {{0x27e0739c,0x72d4512b,0x4244eb44,0xdd98010e}},	//   _mohn_, _корф, _ахаб, liňi_, 
   {{0xe8d805db,0x27e032e9,0xdb000fac,0x81d40154}},	//   _afọ_, _lohn_, nelå, িসহ_, 
   {{0xdd10e35c,0xdd90066d,0x9990010e,0xdb000267}},	//   _düşm, لوں_, _akyş_, ndlö, 
   {{0x224e0067,0x92d403d4,0x49c4010b,0x6ec000cd}},	//   _hiek_, িনৰ_, ңлэн_, विशु, 
   {{0x224c0953,0x32040270,0x200466d4,0x2e28000f}},	//   _kiek_, _ymmy_, _imli_, tûft_, 
   {{0x6ec01b2b,0x212c020c,0xdb000108,0x5d78010f}},	//   विरु, _kyeh_, velä, _װאַק, 
   {{0x27e00589,0x3dcc009a,0x224e0068,0xdb007c1d}},	//   _bohn_, _ingw_, _miek_, delå, 
   {{0xdb020069,0x224cad89,0xdd24002e,0xdd9800a2}},	//   telä, _liek_, _lëŋk, diňi_, 
   {{0x3ab0cc0d,0x224c01c4,0x212c01e7,0x00000000}},	//   _тәпт, _oiek_, _lyeh_, --, 
   {{0xdb02006a,0x4cd80c58,0x224e006b,0x212c01e1}},	//   relä, _বেটু, _niek_, _oyeh_, 
   {{0x25e401d9,0xfbb40642,0xdb02006c,0x1cb00003}},	// [3a4e0] _ऐवरी_, _असाम, selä, _ཞགས_, 
   {{0x224c01c4,0x131800d1,0xc68c0014,0x9990010e}},	//   _aiek_, ىتاغ_, تِہ_, _ykyş_, 
   {{0x51851421,0x03a0fba5,0x224c0b83,0xc7b000d9}},	//   гула, сихо, _biek_, _הבת_, 
   {{0x54680108,0x00000000,0x00000000,0x00000000}},	//   _памм_, --, --, --, 
   {{0xd00a006d,0x7f8000d1,0x00000000,0x00000000}},	//   неде_, ڭلىن, --, --, 
   {{0x8c645026,0xb4c05c0b,0xceb80640,0xdb000254}},	//   қтид, ंटी_, ељи_, ldlõ, 
   {{0x212c013f,0x224c05b1,0x79840241,0xac9800ec}},	//   _eyeh_, _fiek_, _odiw, ھندا_, 
   {{0x79842bc8,0xfce0001f,0xbea40451,0x11d800c6}},	//   _ndiw, _ዝግጁ_, اهين_, _ثورة_, 
   {{0x9f440036,0x7ae400b5,0x2eb40014,0x016000db}},	//   _allä_, øjtn, _چێتھ_, _ыкто, 
   {{0x7986006e,0x224c0196,0x50441d37,0x00e0010b}},	//   _adiw, _ziek_, _сезб, _ужун, 
   {{0x0d840021,0xc3f800c8,0x0e6498cc,0xf1e000e8}},	//   _блен, גליש, _скен, _s斡y_, 
   {{0x75f80316,0x27e00730,0xe86401c0,0x00000000}},	//   _jízd, _sohn_, ихгү, --, 
   {{0x79840cfd,0x7d78008f,0x850001ad,0xdb00005c}},	//   _ddiw, _טראג, _रेंट_, velå, 
   {{0x160000bc,0x00000000,0x00000000,0x00000000}},	//   रोसर_, --, --, --, 
   {{0xaa9441b9,0x85a400d8,0x00000000,0x00000000}},	//   _тийч, лјад, --, --, 
   {{0xb4c05e8d,0x27e00e78,0x00000000,0x00000000}},	//   ंटू_, _wohn_, --, --, 
   {{0xd1cc001f,0x224e006f,0xdb00007c,0x00000000}},	// [3a4f0] ጢአት_, _riek_, relå, --, 
   {{0x224e0070,0x9f44023a,0xca140ed1,0xdb020071}},	//   _siek_, _yllä_, ﺳﯩﺰ_, jelû, 
   {{0x41e4dbe2,0x224c057b,0x212ccb21,0xa2b4004e}},	//   ліда, _piek_, _syeh_, рбеч, 
   {{0x45a002dd,0x5be00210,0x00000000,0x00000000}},	//   _دەرك, _फव्व, --, --, 
   {{0x656c0b0b,0x3af801e1,0x69dc01f5,0xbec400e2}},	//   mbah, _kápé_, ijse, itīš, 
   {{0x656e0072,0x9f5003be,0x224c0034,0x256c022e}},	//   lbah, _özü_, _wiek_, _hоl_, 
   {{0x224d8833,0xf42805f5,0xdd5002d3,0xdd2400e8}},	//   _tiek_, _соёл_, _መሳርሒ, _tëŋk, 
   {{0x656e0073,0xfbb4006d,0x3af801e1,0x3aec01f4}},	//   nbah, _असहम, _lápé_, höpö_, 
   {{0x212c0098,0x256c022e,0xdb006de2,0x5f94009d}},	//   _uyeh_, _mоl_, mflé, _визт, 
   {{0x60ca0074,0x356c02d3,0x2004025c,0xcd24010a}},	//   _irem, ዳቤታት_, _umli_, ржье_, 
   {{0x656c05d1,0xa3bc121d,0xdb020075,0xd1bc0092}},	//   kbah, _आसन_, lelú, _ደበበ_, 
   {{0xcfa81d4c,0xd9441efc,0xdb0006af,0x00000000}},	//   _গোপন, иени, nflé, --, 
   {{0x656c002b,0x00000000,0x00000000,0x00000000}},	//   dbah, --, --, --, 
   {{0x60c80451,0x98c00213,0xe8e80014,0x00000000}},	//   _mrem, çqın_, ارَو_, --, 
   {{0x75f800d2,0x9598008e,0x656c0e78,0xd5b001f7}},	//   _líze, ктау_, fbah, يفس_, 
   {{0x656de964,0x60c814dc,0x798401c8,0x8d480092}},	//   gbah, _orem, _udiw, _መታቀዱ, 
   {{0x60c8020c,0xb4c00c4c,0x00000000,0x00000000}},	// [3a500] _nrem, ंटे_, --, --, 
   {{0x656c01d9,0xddc001e4,0x00000000,0x00000000}},	//   abah, _rulŝ, --, --, 
   {{0xdb011746,0x656c5f39,0x00000000,0x00000000}},	//   fflé, bbah, --, --, 
   {{0x60ca0076,0x6720002d,0x656c058a,0x160001ad}},	//   _brem, ûlje, cbah, रोशर_, 
   {{0x76440c09,0xf8b8007d,0x6600017a,0x00000000}},	//   mmiy, ेटिय, ëlke, --, 
   {{0x76460077,0x60ca0078,0x00900276,0x75f801d3}},	//   lmiy, _drem, цишэ, _díze, 
   {{0x76440a81,0x60ca0079,0x74c400cd,0x00000000}},	//   omiy, _erem, रिवृ, --, 
   {{0x764405d1,0x777c022e,0x00000000,0x00000000}},	//   nmiy, harx, --, --, 
   {{0x7644011f,0xbc740b7e,0xc22001b9,0x00000000}},	//   imiy, абых_, _بکلو, --, 
   {{0x81a802f5,0xebd801d5,0x656c0205,0x00000000}},	//   _কোপ_, удош_, zbah, --, 
   {{0x4dd6007a,0x60c923a5,0x656df226,0x7646007b}},	//   _پتاس, _zrem, ybah, kmiy, 
   {{0x69dc0218,0x14d4012c,0xc8640440,0x656c0369}},	//   ujse, ठमाण, итги, xbah, 
   {{0x656c01b9,0xb4c017cb,0x76442d7c,0x777c4f40}},	//   vbah, ंटो_, dmiy, farx, 
   {{0xbec400e2,0x5fd80073,0x63a40175,0x777c344a}},	//   stīš, ढायल, xfhn, garx, 
   {{0xc9840cb9,0x656e007c,0x0cb42982,0x99d00154}},	//   _купи, tbah, _अनुम, াসড়ক, 
   {{0x81a80d42,0x76440d04,0xbad808a8,0xe5541fbe}},	//   _কোন_, gmiy, _יקות, скањ, 
   {{0xe73a007d,0x85440276,0xa4b406be,0x777c022e}},	// [3a510] тең_, рэве, _döşü_, barx, 
   {{0x656cd565,0xf9f40135,0x76442f1d,0x60ca007e}},	//   sbah, _བཞོན_, amiy, _rrem, 
   {{0x60c8e108,0xdb000036,0x41740145,0x342400d4}},	//   _srem, tflé, لاشس, іфув, 
   {{0x76440205,0xa194022e,0x2a500092,0x68400ca8}},	//   cmiy, садч, _መቃብሮ, bádù, 
   {{0x660e007f,0xdb000036,0x00000000,0x00000000}},	//   miak, rflé, --, --, 
   {{0x75f801d3,0x00000000,0x00000000,0x00000000}},	//   _víze, --, --, --, 
   {{0x2be80183,0x60c800a2,0x6444002f,0x00000000}},	//   টোৱে_, _wrem, mmhi, --, 
   {{0x660e0080,0x60c81da7,0xdb0008cb,0x75f801d3}},	//   niak, _trem, melø, _tíze, 
   {{0x60ca0081,0x0dc4088b,0xdb000ac8,0x00000000}},	//   _urem, слый_, lelø, --, 
   {{0x660e0082,0x64441552,0x2360026c,0x777c00cf}},	//   hiak, nmhi, nchj_, xarx, 
   {{0x660e0083,0xdb0011aa,0xddc000a2,0x6444952b}},	//   kiak, nelø, _gulş, imhi, 
   {{0x644401ab,0x660e0084,0x99800118,0x76440067}},	//   hmhi, jiak, roků_, xmiy, 
   {{0x660c2f2b,0xae040014,0x201800d8,0x764405d1}},	//   diak, _بونى, _ísis_, vmiy, 
   {{0x764401d9,0xdb000b34,0x96b8004e,0x3c28005c}},	//   wmiy, kelø, лубу_, røvs_, 
   {{0x660e0085,0x76445a71,0xb4c000e1,0xdb0005ac}},	//   fiak, tmiy, ंट्_, jelø, 
   {{0x660c6018,0x443002c4,0x6a640597,0xdb000627}},	//   giak, elx_, _بطول, delø, 
   {{0x76460086,0xd468010a,0x26c4007c,0x00000000}},	// [3a520] rmiy, уизе_, ålor_, --, 
   {{0x76460087,0xdb00022c,0x777d65a0,0x660c0037}},	//   smiy, felø, qarx, aiak, 
   {{0x660e0088,0xdb001600,0x75f801ed,0xa4b4013d}},	//   biak, gelø, _vízb, _töşü_, 
   {{0x635400bc,0xb59803e6,0x81a800cc,0x7644022e}},	//   třní, _خێرا_, _কোব_, qmiy, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb001088,0x2360026c,0x4430003a,0x644401c3}},	//   belø, cchj_, clx_, cmhi, 
   {{0xbea405d9,0xadd8292c,0x92e400cc,0x00000000}},	//   مهون_, имку_, _বেৰ_, --, 
   {{0x6fb40037,0x2174009d,0x41cc07b6,0xcb440022}},	//   _इसकू, _муур, _सोपस, ҩхои, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x660d5068,0xbe700050,0x3e600205,0xaea0022e}},	//   ziak, _کھوژ, _sıte_, _беpи, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7f3804ac,0x00000000,0x00000000,0x00000000}},	//   _געבו, --, --, --, 
   {{0xcd359644,0x660e0089,0x81a80f22,0x995400a2}},	//   _اراب, viak, _কোড_, _wüşi_, 
   {{0xe8d805db,0x660c012d,0xf7702303,0x0ae8fb25}},	//   _ndụ_, wiak, فاف_, _مربي_, 
   {{0x660e008a,0xfa64041b,0x00000000,0x00000000}},	//   tiak, _лајк_, --, --, 
   {{0xe8d801f2,0xdb000ac8,0x64440175,0xdce80427}},	//   _adụ_, velø, wmhi, zbeč, 
   {{0x660e008b,0x0458221d,0x745801d9,0xf52001ec}},	// [3a530] riak, اجرت_, ٕشمس_, ентi_, 
   {{0x660e008c,0xdb001455,0xdddc033f,0x4432008d}},	//   siak, telø, _łyżk, ulx_, 
   {{0x660e008e,0x44301d6f,0x23600ffb,0x3d0c0243}},	//   piak, rlx_, rchj_, _तेने_, 
   {{0xdb007eb1,0xa4d400d3,0x20d402dd,0x91c4000d}},	//   relø, _домі, жікс, _रोआई, 
   {{0x661c0d27,0xdb0012ed,0xfe400131,0x00000000}},	//   _ijsk, selø, үмлү, --, 
   {{0xdb00005c,0x7a0401d3,0x3e4400e5,0x9fc80166}},	//   pelø, lőtt, _lőtt_, ргка_, 
   {{0x81a802f5,0x661c00b5,0x6ec000dc,0x25a875d3}},	//   _কোণ_, _kjsk, विगु, ofal_, 
   {{0x25a80225,0x3e4401d3,0x7d0c01d3,0x36f8011a}},	//   nfal_, _nőtt_, úcso, מצום_, 
   {{0xa3bcb213,0x1168036b,0x9f44036e,0xada815eb}},	//   _आसा_, _خلقی_, _kolë_, صديق_, 
   {{0xdaa86a8b,0x6e240cf4,0x3cf00118,0x00000000}},	//   авод_, čiba, ेछौं_, --, 
   {{0x6f64301c,0xd0240046,0x75f80306,0x00000000}},	//   _رهنم, _بولۋ, _líza, --, 
   {{0x98a429ee,0x00000000,0x00000000,0x00000000}},	//   оиме, --, --, --, 
   {{0xfa5001d5,0x25a80009,0x28f8013d,0x4a4000d4}},	//   _کرتگ, dfal_, бэрэ_, ьнюв, 
   {{0x9f4400d8,0x5a94020f,0x6df400db,0xfcc001ee}},	//   _rolê_, _дриф, _وكەا, _дәүм, 
   {{0x7bc2008f,0x25a8706b,0x3e4400e5,0x2bb800ae}},	//   _ianu, ffal_, _főtt_, _دانة_, 
   {{0xf9f44933,0x75f8013d,0xea88029c,0x00000000}},	//   _བཞིན_, _bíza, _اخون_, --, 
   {{0x7bc20090,0x999002f0,0x090002e8,0x70b8012d}},	// [3a540] _kanu, _chyť_, _опън, _इनेल, 
   {{0x38a60091,0xe1f80024,0xb60800d7,0x00000000}},	//   mör_, _alų_, _bošá, --, 
   {{0xc7d4008f,0x55e4fddb,0x38a60092,0x658400ae}},	//   _וויי_, _донб, lör_, áthú, 
   {{0x7bc20093,0xcb10011a,0x00000000,0x00000000}},	//   _lanu, ולב_, --, --, 
   {{0x7bc00270,0x2f880184,0x38a60094,0x9f44036e}},	//   _oanu, йҙан_, nör_, _folë_, 
   {{0x7bc0601a,0x9f4402e2,0x4e884bf5,0x69dc0165}},	//   _nanu, _kolè_, ащим_, êrez, 
   {{0x38a5c68f,0x59c8013a,0x75f800d7,0x00000000}},	//   hör_, ियार, _zíza, --, 
   {{0x85f404ac,0x7bc20095,0x38a60096,0xbe0000e5}},	//   ַציע_, _aanu, kör_, وڈنٹ, 
   {{0x38a40008,0x9f4401e1,0x21740c60,0x00820097}},	//   jör_, _lolè_, _хуср, _олто, 
   {{0x7bc20098,0x38a60099,0xfb801bf4,0x00000000}},	//   _canu, dör_, ودپی, --, 
   {{0x7bc2009a,0x4d6402e8,0x25a80042,0x00000000}},	//   _danu, _дкев, yfal_, --, 
   {{0x38a6009b,0x7bc003ac,0x4cb00154,0x00000000}},	//   för_, _eanu, জিবু, --, 
   {{0x7bc004c9,0x38a4049f,0xc7c477a4,0x25a8022e}},	//   _fanu, gör_, осви, vfal_, 
   {{0x7bc2009c,0x9f4401e1,0x25a8002e,0x75f8013d}},	//   _ganu, _bolè_, wfal_, _ríza, 
   {{0xba700447,0x3e6003e0,0x00000000,0x00000000}},	//   _قايت, _kıta_, --, --, 
   {{0x7bc2009d,0x2c600699,0x9f4401e1,0x25a80010}},	//   _zanu, _kòd_, _dolè_, ufal_, 
   {{0x7bc2009e,0x25aa009f,0x87e46128,0xecbc2f0a}},	// [3a550] _yanu, rfal_, _дюне, ्टिफ, 
   {{0x7bc00050,0x9f4401e1,0x2c6200a0,0x6840032e}},	//   _xanu, _folè_, _mòd_, _dádý, 
   {{0x2c600d29,0xdb00010e,0x00000000,0x00000000}},	//   _lòd_, kelý, --, --, 
   {{0x26c200a1,0xa3bc01ad,0x7ae4005c,0x00000000}},	//   _isho_, _आसव_, øjti, --, 
   {{0xead001e1,0xdb00010e,0xd3f800fe,0x00000000}},	//   _jẹbi_, delý, _আদৰি_, --, 
   {{0x657e00a2,0xe2c805d9,0xd344036b,0x9f440306}},	//   _hesh, _ٿورو_, _کیمه_, _holé_, 
   {{0x645e00a3,0x657e00a4,0x9f45ec62,0x38a400dd}},	//   _husi, _kesh, _kolé_, zör_, 
   {{0x657e00a5,0x6284f7c2,0x645600a6,0x2c6200a7}},	//   _jesh, msho, _hizi, _bòd_, 
   {{0x645424be,0x657e00a8,0x645cf528,0x61e8ead8}},	//   _kizi, _mesh, _jusi, _ioel, 
   {{0x7bc200a9,0x657e00aa,0x61ea00ab,0x26c200ac}},	//   _qanu, _lesh, _hoel, _osho_, 
   {{0x7bc200ad,0x645600ae,0x645e00af,0x61ea00b0}},	//   _vanu, _mizi, _lusi, _koel, 
   {{0x645600b1,0x61ea00b2,0x7bc200b3,0x657c05b8}},	//   _lizi, _joel, _wanu, _nesh, 
   {{0x61ea00b4,0x645e00b5,0x26c02dee,0x628600b6}},	//   _moel, _nusi, _asho_, hsho, 
   {{0x628600b7,0x61e801af,0x657c007f,0x38a600b8}},	//   ksho, _loel, _aesh, rör_, 
   {{0x657e00b9,0x9f440de2,0x38a600ba,0x2c60033b}},	//   _besh, _bolé_, sör_, _zòd_, 
   {{0x628479f1,0x645e00bb,0x645600bc,0x61ea00bd}},	//   dsho, _busi, _aizi, _noel, 
   {{0x645600be,0x628600bf,0x657def0c,0x645e00c0}},	// [3a560] _bizi, esho, _desh, _cusi, 
   {{0x645e00c1,0x657c8ebb,0xd4088971,0x6454012c}},	//   _dusi, _eesh, حترم_, _cizi, 
   {{0x1dbc1a2a,0x628600c2,0x61e883c6,0x645600c3}},	//   ्यात, gsho, _boel, _dizi, 
   {{0x61ea00c4,0x645600c5,0x10a40022,0x11e40108}},	//   _coel, _eizi, зидн, яжем, 
   {{0x61ea00c6,0x645c9390,0x92bc0183,0x628403a2}},	//   _doel, _gusi, েহে_, asho, 
   {{0x628467d6,0x6455a7d6,0x657e00c7,0x3a20000f}},	//   bsho, _gizi, _zesh, _ljip_, 
   {{0x0440815c,0xfe6ca534,0x6284e539,0x645ddc5d}},	//   _черн, هدي_, csho, _zusi, 
   {{0x61ea00c8,0x645600c9,0x645e00ca,0x657c00aa}},	//   _goel, _zizi, _yusi, _xesh, 
   {{0x6454016c,0x69d80086,0x645c01d9,0x195007ad}},	//   _yizi, _òwei, _xusi, _ｎｔｔ_, 
   {{0xcfa8034c,0x3a200438,0x61ea00cb,0xdb006d37}},	//   _دارم_, _ajip_, _zoel, selý, 
   {{0xdfa4acdc,0x3940603f,0x61e801f7,0x0dc82bd4}},	//   _تحقي, _azis_, _yoel, _гули_, 
   {{0xcefc00fd,0x61e80077,0xbef4011a,0x00000000}},	//   ışın_, _xoel, _מצבו_, --, 
   {{0x657e00cc,0xc8651c4e,0x3a200b21,0x6284022e}},	//   _resh, ятни, _djip_, zsho, 
   {{0x657e00cd,0x3a20033b,0x9f457747,0x3940012d}},	//   _sesh, _ejip_, _solé_, _dzis_, 
   {{0x645e00ce,0x657e00cf,0x78540165,0x69a407f7}},	//   _susi, _pesh, _eńvo, _कापी, 
   {{0x645600d0,0x645e00d1,0xa4d400d6,0x657cb09e}},	//   _sizi, _pusi, мобі, _qesh, 
   {{0x628600d2,0x657c044e,0x61e8368d,0x645d4d2f}},	// [3a570] wsho, _vesh, _roel, _qusi, 
   {{0x628600d3,0x6454006c,0x26c200d4,0x61e8014a}},	//   tsho, _qizi, _tsho_, _soel, 
   {{0x61ea00d5,0x657e00d6,0x645e00d7,0x26c051b0}},	//   _poel, _tesh, _wusi, _usho_, 
   {{0x645e00d8,0x645600d9,0x628600da,0xcfa802f5}},	//   _tusi, _wizi, rsho, _গোলন, 
   {{0x645c0664,0x6455ed8c,0x61e9c72a,0x00000000}},	//   _uusi, _tizi, _voel, --, 
   {{0x61e80b4f,0x9f440008,0x50a00131,0x238401d9}},	//   _woel, _ellý_, ئەلل, _زٔرِ, 
   {{0x61ea00db,0xe2c97ea3,0x5e440014,0x6284022e}},	//   _toel, _بوزو_, ونتٕ, qsho, 
   {{0xdb0000fd,0xf1a40276,0x3ea4037e,0x81a800eb}},	//   relü, _прун, rtnt_, _কোর_, 
   {{0xdb000a9c,0x1c44003b,0x00000000,0x00000000}},	//   selü, мним, --, --, 
   {{0x20100209,0xfac4002e,0xdb00007f,0x3ea40208}},	//   _özi_, _mis斡, delò, ptnt_, 
   {{0x0c205fd0,0x7e280024,0x00000000,0x00000000}},	//   тмэн, _ліда_, --, --, 
   {{0x6600017a,0x00000000,0x00000000,0x00000000}},	//   ëlkl, --, --, --, 
   {{0xb4bc068f,0x48e09842,0xdd980419,0x00000000}},	//   _आने_, вояв, chňa_, --, 
   {{0x1dbc17c6,0xdc34010f,0xecbc0709,0x00000000}},	//   ्यवत, _קאַט_, ्टरफ, --, 
   {{0xa3d003f8,0x46a000a7,0x3a2000ef,0x00000000}},	//   वयन_, карв, _tjip_, --, 
   {{0xb8e4009e,0x75f80518,0xceb002e4,0xdb0003b2}},	//   _এপ_, _vízo, כיל_, seló, 
   {{0x3940008f,0x13e9e143,0xdb000789,0x08c0104e}},	// [3a580] _uzis_, омай_, peló, _абын, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x03a00aa5,0x91e478cd,0x386009d7,0x516400db}},	//   тихо, може, _huir_, дүбү_, 
   {{0x80c40729,0x386001e4,0x288803e6,0x00000000}},	//   লমন্, _kuir_, _بڵێی_, --, 
   {{0x38600048,0x50b82824,0x10480117,0x9878010f}},	//   _juir_, تداد_, ояки_, קאַט, 
   {{0x386200dc,0x00000000,0x00000000,0x00000000}},	//   _muir_, --, --, --, 
   {{0xb8f00135,0x38600076,0x4ea600dd,0x00000000}},	//   _ུན_, _luir_, фрла, --, 
   {{0x9f4400db,0xef18005f,0x4340030d,0xfe6c009a}},	//   _alló_, _ceļa_, _ресв, جدو_, 
   {{0x386004cc,0x0634008f,0xea780092,0x00000000}},	//   _nuir_, ונקט_, _የተያዘ_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x1fb5335d,0x91f00037,0x6a141f39,0x3a70013d}},	//   _ястр, _अकाज_, емну, клэр, 
   {{0x1ea80220,0xe8103d1d,0xef1800ef,0x00000000}},	//   _ءالي_, डोना_, _geļa_, --, 
   {{0x386200de,0x2d8600df,0x8d181410,0xb4e800c5}},	//   _cuir_, mame_, _بزار_, बहो_, 
   {{0x2d8600e0,0x38600204,0x00000000,0x00000000}},	//   lame_, _duir_, --, --, 
   {{0xdb000561,0xfbd800bc,0x7ae4005c,0x6fac00cc}},	//   selò, बारम, øjtt, _টোৱে, 
   {{0x2d8600e1,0x3860004a,0x2d54001f,0x00000000}},	//   name_, _fuir_, _መታሰቢ, --, 
   {{0x386200e2,0x390800db,0x29140066,0x00000000}},	// [3a590] _guir_, _жээн_, _سودآ, --, 
   {{0x69a401f9,0x00000000,0x00000000,0x00000000}},	//   _काडी, --, --, --, 
   {{0x2d8600e3,0x87040953,0x82a435c7,0x3358004e}},	//   kame_, _цяпе, ьшае, дүрө_, 
   {{0x2d8600e4,0x015000e5,0x00000000,0x00000000}},	//   jame_, نٹاگ, --, --, 
   {{0xb06800c6,0x00000000,0x00000000,0x00000000}},	//   وصول_, --, --, --, 
   {{0x8fa02c32,0xd47800df,0x00000000,0x00000000}},	//   гаше, _מאשל, --, --, 
   {{0x248a00e5,0x9f4400f7,0x4420a3a3,0x2d8600e6}},	//   lsam_, _allò_, _ijj_, fame_, 
   {{0x2d8600e7,0x2489446f,0x00000000,0x00000000}},	//   game_, osam_, --, --, 
   {{0xfd6400e4,0xef1800de,0x00000000,0x00000000}},	//   _karẽ, _veļa_, --, --, 
   {{0x248a00e8,0x5baa00e9,0x386004cc,0xef9800db}},	//   isam_, чком_, _ruir_, _окуш_, 
   {{0x2d8600ea,0x3e602e95,0x3d0c0034,0x7a2800ac}},	//   bame_, _uñt_, _तेरे_, yıtd, 
   {{0x2d8600eb,0x38600c3a,0x600c012d,0x00000000}},	//   came_, _puir_, dźmi, --, 
   {{0xe0bc1c82,0x442200ec,0x9f440137,0x24880218}},	//   _আপুন, _ojj_, _molí_, jsam_, 
   {{0xb8e80316,0x9f440270,0xb6c801ed,0x24892bbf}},	//   _ईन_, _lolí_, وازے_, dsam_, 
   {{0xaae4009f,0xe7d401f9,0x00000000,0x00000000}},	//   _لسيو, दाजप, --, --, 
   {{0x442200ed,0x18a416a8,0x6d5c0882,0x386200ee}},	//   _ajj_, _заим, śrav, _tuir_, 
   {{0x248a00ef,0xead001e1,0x69a400fb,0x00000000}},	// [3a5a0] gsam_, _jẹni_, _рлыҡ, --, 
   {{0xead001e1,0x00000000,0x00000000,0x00000000}},	//   _mẹni_, --, --, --, 
   {{0x4420090c,0x248a00f0,0x9f440122,0x2d8600f1}},	//   _djj_, asam_, _bolí_, yame_, 
   {{0x2d8600f2,0x24880369,0xdb00007c,0x8b54010f}},	//   xame_, bsam_, mflä, גיעס_, 
   {{0x2d8600f3,0x24896df9,0xdb005df7,0x1138007b}},	//   vame_, csam_, lflä, أثاث_, 
   {{0x6e9403b7,0x2d8600f4,0x4420007c,0x4f642b9f}},	//   вику, wame_, _gjj_, راتف, 
   {{0x2d8600f5,0x75f80232,0x1dbcbd11,0xdb00b83f}},	//   tame_, _nízk, ्यंत, nflä, 
   {{0x433804ac,0xb14800dd,0xbd840372,0x61b00150}},	//   _זעלב, _قیام_, ىنىن_, _نەما, 
   {{0x2d8600f6,0x1aec00bd,0xd0240816,0xe16801f7}},	//   rame_, _ছেলে_, _змай, _آصفه_, 
   {{0x2d8600f7,0xead001e1,0xdb00007c,0x00000000}},	//   same_, _dẹni_, kflä, --, 
   {{0x2d8600f8,0x0dc402d3,0x00000000,0x00000000}},	//   pame_, ጽሑፍ_, --, --, 
   {{0xaca402e3,0x24880548,0x2d8600f9,0xe91802bf}},	//   _abụz, ysam_, qame_, домі_, 
   {{0xdb00002d,0x00000000,0x00000000,0x00000000}},	//   nglê, --, --, --, 
   {{0xdb0040fc,0x99540432,0x24884cab,0x00000000}},	//   fflä, _müňi_, vsam_, --, 
   {{0xdb00002f,0x0a681180,0x00000000,0x00000000}},	//   gflä, _эрли_, --, --, 
   {{0x7be00022,0x442200fa,0x6e2001ab,0x49c821f3}},	//   _ажәж, _sjj_, nnmb, _хукм_, 
   {{0xdbf8006d,0xf9903b6c,0x442031e5,0x9f44022a}},	// [3a5b0] _głów, _طبي_, _pjj_, _rolí_, 
   {{0x9f44022a,0xdb00002f,0x466000db,0x00000000}},	//   _solí_, bflä, _مۇسق, --, 
   {{0x248a00fb,0x1cd8003d,0x9f4402fb,0x659400c7}},	//   ssam_, ོའོ_, _polí_, _иану, 
   {{0xf770415f,0x9f440139,0xf994010f,0x00000000}},	//   _پای_, _qolí_, ָרס_, --, 
   {{0x9f440306,0x273401ec,0x44200254,0x24880003}},	//   _volí_, _سىڭس, _tjj_, qsam_, 
   {{0xe8d8004d,0xef1800de,0xead001e1,0xdb001577}},	//   _ngọ_, _ceļo_, _rẹni_, melö, 
   {{0x443200fc,0xd00c00aa,0xdea0036b,0xdee401d5}},	//   mox_, تلو_, شیشی, тойи, 
   {{0xe8d80248,0x41756a15,0xd344082a,0x00000000}},	//   _agọ_, _سارس, _شینه_, --, 
   {{0x9f440589,0x4c80005b,0x802400db,0xdb0001e3}},	//   _bolã_, алыв, _كرئم, nelö, 
   {{0x9f440589,0xa3d000dc,0x28d400cd,0x00000000}},	//   _colã_, वयि_, दिनि, --, 
   {{0x6e951bf5,0xdbf8033f,0x9ee8007b,0x62800240}},	//   _биху, _słów, _تفضل_, _çlod, 
   {{0xe8d8063f,0x9f44011f,0x99d802a9,0x4430022e}},	//   _egọ_, _tolâ_, ффоф_, hox_, 
   {{0xa3d00b9c,0x63b48185,0xeab80220,0xdb0001ed}},	//   वया_, _obzn, _үйі_, jelö, 
   {{0x3f8600fd,0xdb0200fe,0xade400c7,0x626401ab}},	//   nanu_, nglë, _ацәк, _pėol, 
   {{0x3f8600ff,0xe0bc0c58,0xddc000c0,0x00000000}},	//   ianu_, _আপোন, _nulū, --, 
   {{0x3f860100,0xdb020101,0x00000000,0x00000000}},	//   hanu_, rflä, --, --, 
   {{0x44320102,0x3f860103,0xfaa000c2,0xdb00e6f0}},	// [3a5c0] fox_, kanu_, _рақо, sflä, 
   {{0x3f8534bc,0x798400b5,0x5274010b,0x75480205}},	//   janu_, _heiw, вуду, _ırzı, 
   {{0x3f860104,0x79860105,0xe7440cef,0x27940022}},	//   danu_, _keiw, _бүре_, _сшыр, 
   {{0x3f840042,0xdb00b35a,0x2da002dd,0x23340108}},	//   eanu_, belö, _ﺍﻋﺎﺵ_, ухур, 
   {{0x3f85ef51,0x7984bc50,0xd0081982,0x44320106}},	//   fanu_, _meiw, меде_, box_, 
   {{0x79840a40,0x44320107,0xdb00a1bc,0xffd000d1}},	//   _leiw, cox_, rglê, لغىد, 
   {{0xbea40451,0xd2501291,0x2608000d,0x00000000}},	//   نهون_, _ننس_, _सतमी_, --, 
   {{0x79860108,0x9f460109,0xefcc0023,0xf3e403d4}},	//   _neiw, _solã_, ኣናዮ_, _গতিৰ_, 
   {{0x81a802f5,0x75f801d3,0x9a980055,0x46380115}},	//   _কোক_, _vízh, _ũāpā, ועקע, 
   {{0x69a405ba,0x3f86010a,0x75f80798,0x8fa400d8}},	//   _काही, canu_, _dízi, _јаже, 
   {{0x7986010b,0x1cd80135,0x20080b45,0x28d400dc}},	//   _beiw, ོའུ_, ɗai_, दिभि, 
   {{0xc3303d99,0x443000b5,0x00000000,0x00000000}},	//   יות_, zox_, --, --, 
   {{0xac941f10,0x7986010c,0xd7dc2274,0xdb0001bf}},	//   _салш, _deiw, मांच, vflå, 
   {{0xc038001f,0xf77025ef,0x67f801e1,0x3ce401ad}},	//   ስፈልግ, قاف_, _kìji, _जपते_, 
   {{0x4430e63d,0x6596010d,0x3bb8011a,0x6b887155}},	//   vox_, лаву, _חמוד, madg, 
   {{0x3f86010e,0x798401c7,0x6b8a010f,0x59a81a4e}},	//   zanu_, _geiw, ladg, _कायर, 
   {{0x69cc0093,0x3f860110,0xf5e40220,0xdb005522}},	// [3a5d0] _iaae, yanu_, шірм, rflå, 
   {{0x33760111,0x6b8a0112,0x69cc0099,0x3f840014}},	//   игур, nadg, _haae, xanu_, 
   {{0x44320113,0x3f860114,0xf3660115,0x69cc0098}},	//   rox_, vanu_, ртун, _kaae, 
   {{0x3f8403f0,0xdb0057c6,0x443001ef,0x00000000}},	//   wanu_, melô, sox_, --, 
   {{0x3f860116,0x656c0014,0x9f4400cf,0x69ce0117}},	//   tanu_, mcah, _solà_, _maae, 
   {{0x656ca775,0x9eaa0118,0x69ce0119,0x6b880810}},	//   lcah, евка_, _laae, jadg, 
   {{0x3f86011a,0x6b8a011b,0x69cc0418,0xdb140158}},	//   ranu_, dadg, _oaae, _åbøt, 
   {{0x3f86011c,0x9d45ccb4,0xe8d801fb,0x63a40332}},	//   sanu_, лейд, _ngỏ_, lghn, 
   {{0x3f850d83,0x05a80fc8,0x01340f1c,0x7986011d}},	//   panu_, _छानब, _شعرد, _reiw, 
   {{0x60c81248,0x6b8a011e,0x63a40226,0x7986011f}},	//   _isem, gadg, nghn, _seiw, 
   {{0x69a49856,0x63a47ea6,0x00000000,0x00000000}},	//   _काशी, ighn, --, --, 
   {{0x69cc4e13,0x63a40332,0x632400eb,0x00000000}},	//   _caae, hghn, _ভরাট_, --, 
   {{0x6b880050,0x798403b4,0x619402d3,0x69cc0076}},	//   badg, _veiw, መሳሳሊ_, _daae, 
   {{0x60ca0120,0x79860121,0x79940135,0x00000000}},	//   _msem, _weiw, _żewġ, --, 
   {{0x69cc04c9,0x79860122,0xdca40131,0x63a40332}},	//   _faae, _teiw, _раһи, dghn, 
   {{0x60c9e115,0x69cc12e8,0x7a2803e0,0x00000000}},	//   _osem, _gaae, bıta, --, 
   {{0x1cd86d7e,0x60ca0123,0xd5a80b98,0x8cd4033f}},	// [3a5e0] ོའི_, _nsem, ङ्गज, बियो, 
   {{0x656c0009,0xdb000254,0x00000000,0x00000000}},	//   acah, selõ, --, --, 
   {{0x977400c7,0x656c0067,0x16a80395,0x00000000}},	//   _итҟә, bcah, _явни_, --, 
   {{0x63a400ad,0x55e40063,0x656c0334,0x4718010f}},	//   aghn, _сомб, ccah, _טויג, 
   {{0x60c801ed,0x00000000,0x00000000,0x00000000}},	//   _csem, --, --, --, 
   {{0x9f440789,0x2f1916db,0xb60400bc,0x87b4010f}},	//   _solá_, коль_, _diář, ָלקס_, 
   {{0x69a4d639,0xd17400c0,0x00000000,0x00000000}},	//   _काली, _бызы, --, --, 
   {{0xb7fc045e,0x2df421f3,0x00000000,0x00000000}},	//   ুচিত_, рзиё, --, --, 
   {{0x320405b1,0x9f442b57,0xa0c800c6,0x6b8a0124}},	//   _ilmy_, _volá_, _لذلك_, tadg, 
   {{0x8bc410cf,0xd6f41b76,0x073c0150,0x00000000}},	//   усид, ीनाथ_, _ﺑﺎﯞ_, --, 
   {{0x69cc0093,0x6b887155,0x1ea8007b,0xa52000dc}},	//   _paae, radg, _لاني_, _यश्च_, 
   {{0x80b800af,0x6b887155,0x69a401f9,0x00000000}},	//   _एहमे, sadg, _काळी, --, 
   {{0x69cc0421,0x60c805b1,0xc7b80c69,0x00000000}},	//   _vaae, _xsem, нёв_, --, 
   {{0x69cdfb6c,0xac1802dd,0x00000000,0x00000000}},	//   _waae, _шолу_, --, --, 
   {{0x7a2805d1,0xc984010b,0x69cda426,0xfbcc01f7}},	//   sıta, _йупи, _taae, _رتو_, 
   {{0xc98401a9,0xd8f40133,0x7a280205,0xe50801e2}},	//   _суки, ازێک, pıta, نيزو_, 
   {{0x656c2ebc,0xf99404ae,0x3d0400e1,0xe5a40116}},	// [3a5f0] rcah, _פרץ_, ाईये_, лиңи, 
   {{0x3204020c,0x00000000,0x00000000,0x00000000}},	//   _almy_, --, --, --, 
   {{0x63a60125,0x60c91017,0x48c00022,0x00000000}},	//   rghn, _ssem, _тәҟа, --, 
   {{0xe8120126,0xa4540598,0x60c8017a,0xdb000129}},	//   डोरा_, ınıñ_, _psem, uglé, 
   {{0xdb00000c,0x6600017a,0x7a28013d,0x00000000}},	//   rglé, ëlku, kıtn, --, 
   {{0x60c8151c,0xdfd012e3,0x1e960127,0xf1a40166}},	//   _vsem, زيع_, арир, арән, 
   {{0x27e10160,0x5de5392a,0x6edc0356,0x31c401d9}},	//   _mnhn_, ижка, _năbă, _گۅنہ, 
   {{0x60ca0128,0xdb00143a,0x9d3c0092,0x9db80006}},	//   _tsem, mflø, _አሳይቷ, тыку_, 
   {{0xdd90066d,0x3fa60129,0x9f44387a,0xcc84005b}},	//   موں_, _مصاف, _allô_, абые_, 
   {{0xb9280022,0xaf040139,0x00000000,0x00000000}},	//   pavẽ_, рчәк, --, --, 
   {{0xd9c839db,0x2006012a,0x320409a5,0x1cd8031c}},	//   ষাসম, _illi_, _ylmy_, ོའང_, 
   {{0x18689dc2,0x224c020c,0xa3d007f7,0x9f500432}},	//   ками_, _jhek_, वयँ_, _ýañy_, 
   {{0x6fac0154,0x00000000,0x00000000,0x00000000}},	//   _টোয়ে, --, --, --, 
   {{0xa86401e0,0xdb001924,0xcb6400f3,0x00000000}},	//   серҙ, kflø, _каше_, --, 
   {{0x9f440137,0x00000000,0x00000000,0x00000000}},	//   _dolç_, --, --, --, 
   {{0x395c0023,0x00000000,0x00000000,0x00000000}},	//   ጌሳውያ, --, --, --, 
   {{0xa3d2012b,0xdc7c0020,0x2006012c,0xab5c00e2}},	// [3a600] वयं_, _የነበረ_, _olli_, meļa, 
   {{0x779403e6,0x97a415bf,0x9346012d,0x00000000}},	//   _دیسا, _өрүл, анзе, --, 
   {{0x51853739,0x75fa012e,0x9358022e,0x00000000}},	//   аула, _sízu, трау_, --, 
   {{0x2006012f,0x224e0130,0x3dcc0142,0x00000000}},	//   _alli_, _chek_, _nagw_, --, 
   {{0x224c0214,0x00000000,0x00000000,0x00000000}},	//   _dhek_, --, --, --, 
   {{0x224c009d,0xceb80114,0x75fa0131,0x00000000}},	//   _ehek_, вљи_, _vízu, --, 
   {{0x32040270,0x00000000,0x00000000,0x00000000}},	//   _tlmy_, --, --, --, 
   {{0x20040ba3,0x00000000,0x00000000,0x00000000}},	//   _elli_, --, --, --, 
   {{0x3e60002d,0x4fa40212,0xee3000ec,0xab5c00ef}},	//   _rűte_, _визв, يٽڪ_, deļa, 
   {{0x9e700137,0x00000000,0x00000000,0x00000000}},	//   زۇۇت, --, --, --, 
   {{0x3940009a,0x03d4008d,0x3f641d5b,0x0e64004e}},	//   _ayis_, בוים_, _тихо_, _ткен, 
   {{0x224c0200,0xbea000d8,0xbd64009b,0x00000000}},	//   _xhek_, _фацк, _крше_, --, 
   {{0x200402d3,0x49448e21,0x2c7401c8,0x00000000}},	//   _ylli_, рэнб, _اُتس, --, 
   {{0x6edc0356,0xd7dc041c,0x8b6400d1,0x26081b51}},	//   _tăbă, मागच, _ئاشم, _सतही_, 
   {{0x15d40075,0x00000000,0x00000000,0x00000000}},	//   ﻟﻠﯩﻐ, --, --, --, 
   {{0x7a282fbe,0x05741eeb,0xba7001d9,0xab5c00e2}},	//   nıtl, شارد, _باوت, ceļa, 
   {{0x39400055,0x21680116,0x00000000,0x00000000}},	// [3a610] _gyis_, қили_, --, --, 
   {{0x224e0132,0x91c001e0,0x0ec4000d,0x68e801f4}},	//   _shek_, үәтл, लबाड, äedu, 
   {{0x224c009a,0x7a28456f,0x41c401b9,0x28d400cd}},	//   _phek_, kıtl, иёда, दिवि, 
   {{0xdb0028b3,0x00000000,0x00000000,0x00000000}},	//   rflø, --, --, --, 
   {{0x8385640a,0x68fdeed1,0x75f801d3,0xdb001924}},	//   _выбе, nysd, _vízt, sflø, 
   {{0x25aa0133,0xee3801d3,0x24180166,0x00000000}},	//   lgal_, یقوں_, _согы_, --, 
   {{0xe06003e6,0x25a998f6,0x8fa00108,0x00000000}},	//   _کێتی, ogal_, чаще, --, 
   {{0x25aa0134,0x2ca40334,0x41cc0037,0xa15801f4}},	//   ngal_, fumd_, _सोचस, _бабу_, 
   {{0xe29802dd,0x61ec0108,0x3ce401f9,0x00000000}},	//   _шаң_, öalu, जमधे_, --, 
   {{0x20060135,0x9b44f237,0x5ac83225,0x68fc010e}},	//   _ulli_, ینکو, глом_, dysd, 
   {{0xca740330,0xddb8009d,0x198801a9,0x25a80432}},	//   یمیش_, _булш_, лбни_, kgal_, 
   {{0xfbd40037,0x00000000,0x00000000,0x00000000}},	//   _भोरम, --, --, --, 
   {{0x3d90010b,0x25a80009,0x00000000,0x00000000}},	//   _гиҗр, dgal_, --, --, 
   {{0x59a8069f,0x7a280205,0x7bc4000d,0x00000000}},	//   _कावर, mıtm, õjud, --, 
   {{0x1a640066,0x00000000,0x00000000,0x00000000}},	//   _دیجی_, --, --, --, 
   {{0xd1cc0023,0x9fbc012d,0x92b400eb,0x00000000}},	//   ኣታት_, ołów_, জিৎ_, --, 
   {{0x39400472,0x7a281b0d,0xd5480006,0x00000000}},	// [3a620] _uyis_, nıtm, упае_, --, 
   {{0x25a80597,0x7a2803e0,0x00000000,0x00000000}},	//   agal_, zıtl, --, --, 
   {{0xa3b84c21,0x7a280365,0x8c180375,0xef1800ef}},	//   _अउर_, yıtl, נועי, _teļi_, 
   {{0x99800024,0x75f801d3,0xc32c0050,0xb9f40092}},	//   mokų_, _vízs, رٕن_, _ምኑ_, 
   {{0x76460136,0x9554004b,0x69c001d3,0x00000000}},	//   mliy, _دخدا, őleg, --, 
   {{0xfc247158,0x22780133,0xaaa8024a,0x75f800e5}},	//   _رح_, الۆگ_, _कमलक, _tízs, 
   {{0x7644058a,0xc5ec00f1,0xdb0c0241,0xdcfc0055}},	//   oliy, _غړې_, _ìkèr, _āyāh, 
   {{0x764447af,0x926800fb,0xa2d41bd6,0xdb00032e}},	//   nliy, _арҡа_, णिर्, gglí, 
   {{0x76460137,0xdcac004b,0xc5f8000d,0xfd40009d}},	//   iliy, نډو_, _एकसठ_, зээн, 
   {{0x7a2805d1,0x76460138,0x2ca4003a,0xbfc800db}},	//   sıtl, hliy, rumd_, _مامە_, 
   {{0x764560a5,0x9fbc033f,0xc4380375,0x68fc017a}},	//   kliy, ałów_, רתיי, wysd, 
   {{0x68fc0158,0x25a8058a,0x00000000,0x00000000}},	//   tysd, xgal_, --, --, 
   {{0x2eb80764,0x764400ac,0xab5c00e2,0x00000000}},	//   _आहुत, dliy, ceļn, --, 
   {{0x68fcdf99,0x7e84387a,0x7644058a,0xa8481e2f}},	//   rysd, _éspè, eliy, شلزم_, 
   {{0x76460139,0x3ad40051,0x2c74009f,0x00000000}},	//   fliy, _găp_, _اُڪس, --, 
   {{0x7646013a,0x25a800ad,0x00000000,0x00000000}},	//   gliy, ugal_, --, --, 
   {{0x8366013b,0xdd9800d7,0x00000000,0x00000000}},	// [3a630] مدال, chňu_, --, --, 
   {{0x76441af4,0x00000000,0x00000000,0x00000000}},	//   aliy, --, --, --, 
   {{0x7646013c,0x25a802f0,0x9fbc0210,0x75f800e5}},	//   bliy, pgal_, złów_, _vízr, 
   {{0xddc000a8,0x7a2800ac,0x7646013d,0x407001ec}},	//   _mulţ, yıtm, cliy, зғау, 
   {{0x660ddea9,0x20542d3c,0xf994011a,0x00000000}},	//   mhak, откр, פרס_, --, 
   {{0xd0043529,0xe2c805d9,0x303401f4,0x00000000}},	//   жеше_, _پورو_, печё, --, 
   {{0x59a8bd93,0x64440076,0xa2940816,0xab5c00ef}},	//   _कालर, mlhi, _фабі, deļo, 
   {{0x6ec42033,0x660cf085,0x26c058a1,0x6446013e}},	//   ستىق, nhak, _mpho_, llhi, 
   {{0x660c0270,0xbec40171,0x00000000,0x00000000}},	//   ihak, drīš, --, --, 
   {{0x7646013f,0x71240046,0x0c34007b,0x00000000}},	//   zliy, _عىلم, يكية_, --, 
   {{0x660e0140,0x26c00218,0x7644b018,0x9fbc033f}},	//   khak, _npho_, yliy, słów_, 
   {{0x3ea5dd4d,0xef1800da,0x660c0200,0x59a801f9}},	//   munt_, _ceļu_, jhak, _काळर, 
   {{0x26c0021a,0x660e0141,0x3ea41730,0x1868024c}},	//   _apho_, dhak, lunt_, раги_, 
   {{0xab5c00e2,0xd7080a93,0x51580375,0x3ea40334}},	//   ceļo, анге_, יכרו, ount_, 
   {{0x3ea60142,0x76460143,0xdb000e78,0x817c01f3}},	//   nunt_, tliy, nflü, ከታተሉ_, 
   {{0x660e0144,0xdc389c13,0x6444067c,0x18a60145}},	//   ghak, mçıl, elhi, _даим, 
   {{0x76440cc1,0x3ea4bd05,0x629401a9,0xdc38467d}},	// [3a640] rliy, hunt_, _avzo, lçıl, 
   {{0xc8c40014,0x660c05da,0x76460146,0x87c00327}},	//   _بوٝن_, ahak, sliy, _ཞིགཡ, 
   {{0x660d1fcf,0xdc38a090,0x76457fdb,0x3ea40137}},	//   bhak, nçıl, pliy, junt_, 
   {{0x660e0147,0x3ea40de4,0x764403be,0xc690008f}},	//   chak, dunt_, qliy, _קאר_, 
   {{0x3ea4003a,0x60cc013d,0xdc382791,0x00000000}},	//   eunt_, _ğomü, hçıl, --, 
   {{0xdc383bc2,0x3ea60148,0x9f44017a,0x00000000}},	//   kçıl, funt_, _inlê_, --, 
   {{0x3ea41730,0x9f4401e1,0x4ea41cb8,0xdb00002f}},	//   gunt_, _kolù_, ірка, gflü, 
   {{0xd1843e38,0xdc380dde,0x8cd40709,0x00000000}},	//   _флай, dçıl, बिलो, --, 
   {{0xd7c80490,0x3ea404cc,0xddc800e2,0x00000000}},	//   ाजाच, aunt_, kmeņ, --, 
   {{0xdcb00447,0x60ce0149,0x3ea40483,0x660c07a9}},	//   رىپ_, çame, bunt_, zhak, 
   {{0x3ea40483,0x8e7007d6,0xfb3001c0,0xef180171}},	//   cunt_, _ўқиш, днээ, _peļu_, 
   {{0x660c4242,0xab5c00e2,0x7f380115,0xddc800ef}},	//   xhak, seļo, _דעבו, emeņ, 
   {{0xfbcc1482,0x660e014a,0x62800327,0xdb2401d5}},	//   رتی_, vhak, _ħlom, قویی, 
   {{0x6e22014b,0x660c0325,0xdc380f77,0x00000000}},	//   limb, whak, bçıl, --, 
   {{0x660e014c,0x6e20009f,0x36d6014d,0xaa58a30d}},	//   thak, oimb, морр, _лику_, 
   {{0x97280020,0x660c5318,0xddc025ad,0x7e9800df}},	//   ደሚያስ, uhak, _kulš, יסלו, 
   {{0x660e014e,0x6e200099,0x3ea407de,0x644499ef}},	// [3a650] rhak, iimb, zunt_, tlhi, 
   {{0x6e22014f,0x660c5d12,0xd7b00574,0x00000000}},	//   himb, shak, _जायच, --, 
   {{0x6e220150,0x3ea40393,0x64441368,0xe4a401d5}},	//   kimb, xunt_, rlhi, ўрғо, 
   {{0xdce80640,0x6e20de21,0x9f460151,0x660e0152}},	//   zbeđ, jimb, _tolú_, qhak, 
   {{0x6e220153,0xa0695d37,0xc32c01d9,0x2508fc20}},	//   dimb, щала_, رٕچ_, _طرحی_, 
   {{0x3ea60154,0xdb000e78,0x00000000,0x00000000}},	//   tunt_, tflü, --, --, 
   {{0x60ce0155,0x6e205bf8,0x661c0fac,0x5f040024}},	//   çamb, fimb, _kmsk, язка, 
   {{0x3ea4c51b,0xf1a47b38,0xddc000f3,0x8d9003cc}},	//   runt_, _орун, _bulš, ىلىش, 
   {{0x3ea41730,0x99c800bd,0xdb0003fa,0xdc3800fd}},	//   sunt_, ষাৎক, sflü, wçıl, 
   {{0x3ea49045,0xdc3845a5,0x46c828e1,0x6e200099}},	//   punt_, tçıl, ाबाह, aimb, 
   {{0x6e220156,0x2b160157,0x95800023,0x00000000}},	//   bimb, дьяр, ሓስብን_, --, 
   {{0x6e21999e,0xdc382523,0x00000000,0x00000000}},	//   cimb, rçıl, --, --, 
   {{0xddc00171,0xdc39e494,0x00000000,0x00000000}},	//   _gulš, sçıl, --, --, 
   {{0x661e0158,0x913800c8,0xd7f0007b,0xdc387aa0}},	//   _amsk, מערק, ركز_, pçıl, 
   {{0xa3c012eb,0xddc8005f,0x1cd8025c,0xdc389c13}},	//   ्जन_, rmeņ, ོའམ_, qçıl, 
   {{0x8af80375,0x598400f7,0x99d401af,0x00000000}},	//   _להצי, _элиб, _хікј, --, 
   {{0x66d40118,0x00000000,0x00000000,0x00000000}},	// [3a660] týká, --, --, --, 
   {{0x77944ccb,0xe8d8001e,0x661c0156,0xef1c000d}},	//   _زیرا, _ngộ_, _emsk, _भइलऽ_, 
   {{0x6e220159,0xe74402dd,0x00000000,0x00000000}},	//   yimb, _жүре_, --, --, 
   {{0x6e200117,0xd2500c4f,0x00000000,0x00000000}},	//   ximb, رنش_, --, --, 
   {{0x6e22015a,0x31600221,0x00000000,0x00000000}},	//   vimb, äiz_, --, --, 
   {{0x6e216cfd,0x80a003cc,0xdc700023,0x00000000}},	//   wimb, رمىن, _ባሃላይ_, --, 
   {{0x6e22015b,0x661e015c,0x00000000,0x00000000}},	//   timb, _ymsk, --, --, 
   {{0x6aa839c3,0x6e205a50,0xbea00063,0x00000000}},	//   vudf, uimb, хаћк, --, 
   {{0x6e22015d,0xdb001427,0x00000000,0x00000000}},	//   rimb, nglæ, --, --, 
   {{0x6e201d2b,0xe0540a81,0xac180212,0x39b8009d}},	//   simb, _ہیۆت_, іону_, үлээ_, 
   {{0x6e22015e,0xcd3403e6,0xaa581734,0x7c2c06af}},	//   pimb, _کراب, жину_, écra, 
   {{0x6e2001f0,0x6aa8005c,0x00000000,0x00000000}},	//   qimb, rudf, --, --, 
   {{0x9f440699,0xaae40133,0x6aa801bf,0xe78800f1}},	//   _anlè_, ستگۆ, sudf, يږدي_, 
   {{0xba70034c,0x661c0306,0xe81801c0,0xdb0001bf}},	//   بایت, _smsk, цогч_, dglæ, 
   {{0x98bc0061,0x3bb804ae,0xa6c800f1,0x00000000}},	//   ātā_, _המוד, غورل_, --, 
   {{0xb9b400db,0xc76400db,0x6fc800eb,0x00000000}},	//   _كۅپع, تاڭى, লায়ে, --, 
   {{0x5c3001d5,0x276801d5,0x00000000,0x00000000}},	// [3a670] _سکیز, _وشدی_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x02a4109a,0xd8f42bef,0x00000000,0x00000000}},	//   ярам, _فزیک, --, --, 
   {{0x661e015f,0x6d5c0882,0x00000000,0x00000000}},	//   _umsk, śray, --, --, 
   {{0xa2ccb1e3,0xb64801ec,0x00000000,0x00000000}},	//   _धैर्, _ﻋﺒ_, --, --, 
   {{0x9ac40083,0x00000000,0x00000000,0x00000000}},	//   loŋŋ, --, --, --, 
   {{0x670c01ad,0x00000000,0x00000000,0x00000000}},	//   सनिक_, --, --, --, 
   {{0xc0f0001f,0x00000000,0x00000000,0x00000000}},	//   ግሯል_, --, --, --, 
   {{0x61ea0160,0x3f6401af,0x00000000,0x00000000}},	//   _inel, _етеб, --, --, 
   {{0x61e80295,0x0c2000ee,0x5f94072d,0x00000000}},	//   _hnel, кмын, _آلائ, --, 
   {{0x61e83b4d,0xbe841ec7,0x9ac40083,0xff50007b}},	//   _knel, _رجاو, koŋŋ, _أخذ_, 
   {{0xa3c0069f,0x9d542885,0x0dd800f1,0x00000000}},	//   ्जड_, _قنات, _وانګ_, --, 
   {{0x7a28000f,0x00000000,0x00000000,0x00000000}},	//   jűte, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x61ea0161,0xab845476,0xe89800e5,0x00000000}},	//   _onel, _чучк, _ہميں_, --, 
   {{0x61e84d11,0x249805b1,0x00000000,0x00000000}},	//   _nnel, _bvsm_, --, --, 
   {{0x98560162,0xaa080150,0x00000000,0x00000000}},	// [3a680] _отош, _ءزىل_, --, --, 
   {{0xdb020163,0xae940241,0x00000000,0x00000000}},	//   rglæ, bẹhi, --, --, 
   {{0xdb001b25,0x6b9c00d8,0x4c3800df,0xa2d4cad6}},	//   sglæ, órgi, קגעצ, णिग्, 
   {{0x61e80109,0xe8d8004d,0x00000000,0x00000000}},	//   _cnel, _ngớ_, --, --, 
   {{0x05757f37,0xdb0001e3,0x76a801e1,0x00000000}},	//   _تاپد, lglä, bèyì, --, 
   {{0x60ce0164,0xc22000f2,0x00000000,0x00000000}},	//   çama, _یکنو, --, --, 
   {{0xdb0029ef,0x04400f5c,0x60cc031c,0x37e000cc}},	//   nglä, _рерн, ħama, _নকাৰ, 
   {{0x61e8002e,0x7f4400d1,0x00000000,0x00000000}},	//   _gnel, بلىق_, --, --, 
   {{0xf1a8004b,0x412400db,0x00000000,0x00000000}},	//   _واړه_, _жото_, --, --, 
   {{0x9f440306,0x3a220165,0xbfc0004e,0xdb00007c}},	//   _holý_, _amip_, _ибук, kglä, 
   {{0xa3c002e5,0x61e8002d,0x2ec400db,0xddc80432}},	//   ्जत_, _ynel, _чөлм, kleň, 
   {{0x3a20009a,0x1ea8007b,0x00000000,0x00000000}},	//   _cmip_, _رامي_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3a2056f8,0xdb0004e6,0x00000000,0x00000000}},	//   _emip_, fglä, --, --, 
   {{0xc5f803b7,0xdb000267,0x00000000,0x00000000}},	//   оѓа_, gglä, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x34940107,0x2ab80118,0xdd3003e3,0xb500002b}},	// [3a690] катр, léb_, _məşv, _īṣad, 
   {{0x61e8deef,0xe9901a59,0x2a6801d4,0x9f6402fb}},	//   _snel, _جۇڭگ, _hiab_, _štít_, 
   {{0x2a680070,0xd73401c0,0x65942524,0x00000000}},	//   _kiab_, _зүрх_, _пану, --, 
   {{0x84900020,0xc6440137,0x00000000,0x00000000}},	//   ውቃለን_, _زئجى, --, --, 
   {{0x6454009b,0x61e80010,0x682800d7,0x00000000}},	//   _thzi, _vnel, ažde, --, 
   {{0x2a680457,0x23840014,0xc30403d4,0x61e8015d}},	//   _liab_, _سٔرِ, লছবি_, _wnel, 
   {{0x61e80327,0xab5c0171,0x00000000,0x00000000}},	//   _tnel, beļi, --, --, 
   {{0x2a6801d4,0x63ac0276,0xdd9001ed,0x31c598a4}},	//   _niab_, şină, چوں_, _исув, 
   {{0xdd9000f8,0xf194023a,0xdb020166,0x00000000}},	//   نوں_, _шить, nflö, --, 
   {{0xdb00007c,0x00000000,0x00000000,0x00000000}},	//   yglä, --, --, --, 
   {{0x7a280724,0x2a680174,0x2ab8002e,0x00000000}},	//   kıtt, _biab_, géb_, --, 
   {{0x2a6801d4,0x98a41faf,0xdd94010b,0xd9a802db}},	//   _ciab_, ниме, _чады, कलेट, 
   {{0xa3c00b26,0xed500d83,0x2a6a0167,0x2a3422cb}},	//   ्जा_, _پھٹ_, _diab_, тээр, 
   {{0x25a8004b,0xdb020168,0x31440240,0x00000000}},	//   ېدلي_, dflö, _ንዓበይ, --, 
   {{0x7bc031e5,0xa8640184,0x2a68011c,0x96540640}},	//   _ibnu, терҙ, _fiab_, еђај, 
   {{0xdb020169,0x9f440270,0x2a680165,0xeb540150}},	//   rglä, _holó_, _giab_, _جىىگ, 
   {{0x9f440093,0xdb02016a,0x00000000,0x00000000}},	// [3a6a0] _koló_, sglä, --, --, 
   {{0x2a6801d4,0x94447c8a,0x00000000,0x00000000}},	//   _ziab_, رپان, --, --, 
   {{0xa2a40490,0x9f4401e1,0xa3c0033f,0x00000000}},	//   _चटण्, _moló_, ्ज़_, --, 
   {{0xa2d444eb,0x2a680211,0x11d40244,0xd468014b}},	//   णिज्, _xiab_, عتاد, _ниме_, 
   {{0x7bc00393,0xc0e01e76,0x3ea40036,0x75440124}},	//   _obnu, лоцк, ernt_, _рҽаз, 
   {{0x2ab8066d,0xe8d80016,0x7ae099b9,0x00000000}},	//   yéb_, _ngờ_, _ornt, --, 
   {{0x9f440790,0x4ea401b9,0x7a28236c,0x00000000}},	//   _golü_, хрла, nıts, --, 
   {{0x7bc2016b,0x3f84208d,0x1fcc05ac,0x434000f3}},	//   _abnu, abnu_, লাগস, _сесв, 
   {{0x7bc00175,0x2a680098,0x7ae05f0a,0x8fe001af}},	//   _bbnu, _riab_, _arnt, _бәйҙ, 
   {{0x2a680b89,0x7ae000fb,0x9f440789,0x8e740354}},	//   _siab_, _brnt, _coló_, _зудч, 
   {{0x2a680218,0x7ae001ab,0xdd300213,0xbea0030d}},	//   _piab_, _crnt, _təşv, _бахк, 
   {{0xc3300302,0x2aba016c,0x00000000,0x00000000}},	//   טות_, réb_, --, --, 
   {{0x7ae2016d,0x00000000,0x00000000,0x00000000}},	//   _ernt, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2a680211,0x05840640,0x91b00073,0x7a280139}},	//   _tiab_, еузм, ीभाई, gıts, 
   {{0x9f440790,0x00000000,0x00000000,0x00000000}},	//   _rolü_, --, --, --, 
   {{0xdb000e78,0x7a280205,0x00000000,0x00000000}},	// [3a6b0] uflö, rıtt, --, --, 
   {{0x73d80853,0xdb020166,0x6aa81654,0x3ea40363}},	//   ндур_, rflö, ordf, yrnt_, 
   {{0x56f00598,0x7a280205,0x00000000,0x00000000}},	//   _күрс, pıtt, --, --, 
   {{0x7a280724,0x60cc0120,0xdb00002f,0xfddc000d}},	//   qıtt, çamo, pflö, _खोंस_, 
   {{0x69de016e,0x2919131a,0xb9fc0092,0x00000000}},	//   idse, nzsa_, _ሄዱ_, --, 
   {{0x63b40034,0x00000000,0x00000000,0x00000000}},	//   _uczn, --, --, --, 
   {{0x3f84031c,0x316800c7,0xf4340064,0x00000000}},	//   rbnu_, мшәо_, _серэ, --, 
   {{0x4420020c,0x7ce80008,0x9d441411,0x69dc7c1b}},	//   _hmj_, jörð, кейд, jdse, 
   {{0x6286016f,0x5c54829d,0x442005b1,0x69dc032e}},	//   lpho, ктоф, _kmj_, ddse, 
   {{0x62860170,0x60c8004b,0x44201ada,0x69dc2ad4}},	//   opho, _ipem, _jmj_, edse, 
   {{0x9f440789,0x62860171,0x9db80220,0x75f801d3}},	//   _voló_, npho, _жылу_, _vízz, 
   {{0x62860172,0x69dd21ca,0xf4000356,0x7ce808a5}},	//   ipho, gdse, ăţit_, görð, 
   {{0xa3c02208,0x62860173,0x6aa855ad,0xab5c00de}},	//   ंभा_, hpho, ardf, deļu, 
   {{0x60ca0174,0x7e68079b,0x69dc009a,0x60dc0252}},	//   _mpem, _higp, adse, _ásmu, 
   {{0x80b002ab,0x7ae0127b,0x279400ee,0x7ce802d2}},	//   उंडे, _urnt, ышяр, börð, 
   {{0xd78800b2,0x60ca0175,0x442000d8,0x62860176}},	//   _ڪندو_, _opem, _amj_, dpho, 
   {{0x62860177,0x5468013e,0x4420253c,0x00000000}},	// [3a6c0] epho, даам_, _bmj_, --, 
   {{0x4420c2ff,0x6284010a,0x657c0076,0x7e680430}},	//   _cmj_, fpho, _efsh, _ligp, 
   {{0x60ca0178,0x442001a6,0xab5c00ef,0x00000000}},	//   _apem, _dmj_, beļu, --, 
   {{0xd7b00f44,0xab5c00ef,0x00000000,0x00000000}},	//   _जाँच, ceļu, --, --, 
   {{0x62860179,0x6f180175,0x764401d5,0x00000000}},	//   apho, wzvc, moiy, --, 
   {{0x44200ac5,0x9f6401f1,0x6284037e,0x7054158b}},	//   _gmj_, _štát_, bpho, دنتا, 
   {{0x7e682b92,0x69dc037e,0x60c8005a,0x62849835}},	//   _bigp, ydse, _epem, cpho, 
   {{0xd1ca017a,0x7644022e,0x6c880818,0x00000000}},	//   _تبسم_, noiy, ншоҳ_, --, 
   {{0x7ce8008c,0x7e68017a,0xebc40032,0xd7b000ce}},	//   vörð, _digp, гәйн, _जांच, 
   {{0x9f440100,0x7d04032e,0x998001ef,0x00000000}},	//   _volò_, _sérú, fiků_, --, 
   {{0x764400b5,0xc0ec010c,0x7d0401e1,0x00000000}},	//   koiy, _ቀደሙ_, _pérú, --, 
   {{0x7e68089c,0x69dcaf7f,0x00000000,0x00000000}},	//   _gigp, udse, --, --, 
   {{0x69de017b,0xddb000db,0x764401a9,0xddc86465}},	//   rdse, _اڭىب, doiy, lmeş, 
   {{0x6286017c,0x291800e5,0x00000000,0x00000000}},	//   ypho, rzsa_, --, --, 
   {{0x62840a40,0x290c110c,0x44200fac,0x466a017d}},	//   xpho, šea_, _rmj_, драм_, 
   {{0x44201730,0xb63418fd,0xdb100332,0x00000000}},	//   _smj_, لعقت, _ógái, --, 
   {{0x6286017e,0x442005b1,0xe554041b,0x997403b9}},	// [3a6d0] wpho, _pmj_, укањ, _həşr_, 
   {{0x836438eb,0x9990010b,0x4ab46620,0x68280064}},	//   ندال, _alyň_, _अमाव, bžda, 
   {{0x466034b1,0x60ca017f,0x36880116,0x76460180}},	//   _نۇسق, _spem, _исян_, boiy, 
   {{0x1e840853,0x62840afa,0x611402dd,0x6720089f}},	//   қлим, rpho, лдеу, úlju, 
   {{0x660e0181,0xa0c40206,0x855400dd,0x62860182}},	//   mkak, ايتو, _شیئر_, spho, 
   {{0x7e6800c6,0x660e0183,0x44200007,0x628462a5}},	//   _sigp, lkak, _umj_, ppho, 
   {{0x64460184,0x997400ac,0xd24c0f01,0x09a800eb}},	//   mohi, _nəşr_, _کچل_, গ্যা, 
   {{0x64460185,0xa3c06c95,0xdd908079,0x3358084c}},	//   lohi, ंभव_, حوظ_, _расэ_, 
   {{0x60ca0186,0x660e0187,0x1c441583,0x4430003e}},	//   _upem, ikak, лним, onx_, 
   {{0x64460188,0xe8d801fb,0x998000bc,0x660cdd2c}},	//   nohi, _ngố_, tiků_, hkak, 
   {{0x660e0189,0x7e6851e2,0xdb02018a,0x1a287136}},	//   kkak, _tigp, nglø, ежни_, 
   {{0x644423db,0x9d185232,0xeea85477,0x03cc015b}},	//   hohi, _поет_, _штук_, রায়ণ, 
   {{0x6446018b,0xdca446b2,0x764401b9,0x660c007c}},	//   kohi, _сали, voiy, dkak, 
   {{0x660dd99e,0x644401a9,0x7d18ccef,0xdd9800ee}},	//   ekak, johi, mzus, laň_, 
   {{0x8c180302,0x1b4802bf,0x64440072,0x7d181f96}},	//   _רוצי, _язки_, dohi, lzus, 
   {{0x660d563b,0x44300399,0xdd9a018c,0x3ddc00e8}},	//   gkak, enx_, naň_, nduw_, 
   {{0x7d1a018d,0x644405da,0x13ea018e,0xf8a800e1}},	// [3a6e0] nzus, fohi, нмай_, _कटिय, 
   {{0x764404ba,0x7d180112,0x6446018f,0xdd9800a2}},	//   soiy, izus, gohi, haň_, 
   {{0x91e40d5c,0x660c020c,0x7d180e78,0xdd980432}},	//   ложе, bkak, hzus, kaň_, 
   {{0x644400b0,0xa2a41414,0x00000000,0x00000000}},	//   aohi, _चटर्, --, --, 
   {{0x8598025f,0x64460190,0x9f440109,0xc5f0011a}},	//   _אשכו, bohi, _anlà_, _הדר_, 
   {{0x644400b5,0x4f948087,0x00000000,0x00000000}},	//   cohi, урду, --, --, 
   {{0x7d1a0191,0xa3c002ab,0xc7b0011a,0x00000000}},	//   ezus, ंभर_, צבה_, --, 
   {{0xddc80724,0x7d180e78,0x53a40b01,0xdd98010e}},	//   rmeş, fzus, _шаҳб, gaň_, 
   {{0x9f44180f,0x4fb40f2b,0xd150004b,0xc0e06be2}},	//   _enlà_, _مصار, _اکاډ, _лотк, 
   {{0x660c8440,0xc4d0011a,0x00000000,0x00000000}},	//   zkak, צגת_, --, --, 
   {{0x660e0192,0xd9bc00fe,0xdd98010e,0x3a700166}},	//   ykak, ইজনম, baň_, йлэр, 
   {{0x64460193,0xcce43229,0x660c01c4,0x00000000}},	//   zohi, _مستي, xkak, --, 
   {{0x64460194,0xac9402dd,0xebc40139,0x5d740818}},	//   yohi, _талш, _кәнн, _тухф, 
   {{0x628006af,0x660c0784,0xfbcc007b,0x00000000}},	//   _élog, wkak, _فتى_, --, 
   {{0x64440851,0x660e0195,0xe694005a,0x00000000}},	//   vohi, tkak, рибы, --, 
   {{0x64460196,0xe94404fb,0x7ab8008d,0x7aec02f0}},	//   wohi, _پربی, _נצחו, šitý, 
   {{0x660e0197,0xfa340cbe,0x6280025c,0x97280092}},	// [3a6f0] rkak, _درود, _ħloq, ደሚወስ, 
   {{0x660e0198,0x39141411,0xdb000158,0x00000000}},	//   skak, _ымыр, tglø, --, 
   {{0x64441f4c,0x660d4e1c,0x7c2c06af,0xf4840fc0}},	//   rohi, pkak, écri, _ҳусн, 
   {{0xf364c74a,0x64441c06,0xdb000623,0x85440139}},	//   стун, sohi, rglø, _бэге, 
   {{0x64460199,0xc0c8001f,0xf77007d2,0xdd980100}},	//   pohi, _አደራ_, _باۋ_, chňy_, 
   {{0x248a019a,0x7d18f7c0,0x5f04a2d8,0xdb000158}},	//   mpam_, vzus, изла, pglø, 
   {{0x248a019b,0xf2e400d6,0x2178010b,0x1cbc031c}},	//   lpam_, _люто, _айбы_, _ཆཱང_, 
   {{0x82340491,0x7d180e78,0x70380131,0xdcf4007b}},	//   _إرسا, tzus, پسۇس_, لأخب, 
   {{0xdd992024,0x3ddc0de2,0x9c5802e8,0xb2e400a2}},	//   raň_, rduw_, кшоу_, _öñrä, 
   {{0x7d1a019c,0x9c24013e,0x00000000,0x00000000}},	//   rzus, рдод, --, --, 
   {{0x7d1803fa,0xc0c8001f,0x6282019d,0x3a440107}},	//   szus, _አደሩ_, _élod, ймоҳ, 
   {{0xaf040137,0xe8d80051,0x00000000,0x00000000}},	//   _учук, _ngồ_, --, --, 
   {{0x81dc0183,0xae4400e5,0x6b84013d,0x00000000}},	//   তাপ_, _اپنو, _şige, --, 
   {{0xeb300228,0x00000000,0x00000000,0x00000000}},	//   تۉۉد, --, --, --, 
   {{0xd62887b7,0xdca40131,0x78740451,0xec340133}},	//   вове_, _саһи, _گڏجا, _دووگ, 
   {{0x65b8009d,0x95840166,0x00000000,0x00000000}},	//   луур_, рлае, --, --, 
   {{0xc3201c82,0x2488089c,0x0ef001ad,0x94240166}},	// [3a700] _বুলি_, gpam_, _अप्स_, амае, 
   {{0x85000014,0x838400d4,0x3cb400cc,0x81dc00eb}},	//   زڈُن, ибув_, _অনাৱ, তাফ_, 
   {{0x81dc09bd,0x96f800c0,0x00000000,0x00000000}},	//   তান_, _рэпу_, --, --, 
   {{0x55e4fd1b,0x626400db,0x00000000,0x00000000}},	//   _томб, مانق, --, --, 
   {{0x00d4009a,0x00000000,0x00000000,0x00000000}},	//   لبوت_, --, --, --, 
   {{0x4ea430c4,0x09d00a28,0x63c40118,0x00000000}},	//   ариа, _तस्य, ětný, --, 
   {{0xfeb6019e,0xb8f82b88,0x82a0672a,0xe1f01a59}},	//   لايت_, _ོག_, _марж, تسە_, 
   {{0xadf6019f,0x00000000,0x00000000,0x00000000}},	//   спиш, --, --, --, 
   {{0xd1480014,0x0b881a92,0x53c4043e,0x257c00e5}},	//   _ششرن_, ксни_, र्थश, _háló_, 
   {{0x46c40cbf,0x7b8000d1,0x00000000,0x00000000}},	//   _लहलह, ياپە, --, --, 
   {{0x1ea85de1,0x3204009a,0x03740375,0x9ba01183}},	//   _ماني_, _komy_, יתית_, سەيى, 
   {{0x24880113,0x00000000,0x00000000,0x00000000}},	//   ypam_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7e84033b,0x0b2401d9,0xcce40451,0x3204013a}},	//   _èspè, _پرتَ, _مسڪي, _lomy_, 
   {{0x062400c0,0x24880784,0x18180a81,0x245c00e4}},	//   афам, wpam_, ارُک_, nìme_, 
   {{0x248a01a0,0xdb0005f7,0xc98401d5,0x00000000}},	//   tpam_, nglý, _туки, --, 
   {{0x81dc015b,0x6b980205,0x00000000,0x00000000}},	// [3a710] তাম_, _kevg, --, --, 
   {{0x4ad8033d,0x44240086,0x6b9a01a1,0x83698398}},	//   _बनाव, òn_, _jevg, نصاف_, 
   {{0x24886d15,0x978400fb,0x00000000,0x00000000}},	//   spam_, _утыҙ, --, --, 
   {{0x24881574,0x6b9807de,0x27e06040,0x128840bf}},	//   ppam_, _levg, _hahn_, امنی_, 
   {{0x846406bb,0x3204489c,0x00000000,0x00000000}},	//   _въве, _domy_, --, --, 
   {{0x3494020a,0x53c43f2c,0x10a09b4e,0x1e940d08}},	//   _фарр, र्दश, чишн, брир, 
   {{0x27e201a2,0x630407d6,0xef780023,0x81dc0154}},	//   _mahn_, _اوزل, _ኣቀዲሙ_, তাব_, 
   {{0x27e201a3,0xf0b80214,0x207400c0,0x00000000}},	//   _lahn_, _چالش_, _глаў, --, 
   {{0x4c802f6a,0x224e01a4,0xddc00153,0x6dc400db}},	//   плыв, _ikek_, _tulž, تۅنۅ, 
   {{0x9f340064,0x00000000,0x00000000,0x00000000}},	//   _лезі, --, --, --, 
   {{0x9cf80d42,0x26c00218,0x20040472,0x9f98014b}},	//   েছেন_, _nqho_, _ioli_, _авҷу_, 
   {{0x200601a5,0x00000000,0x00000000,0x00000000}},	//   _holi_, --, --, --, 
   {{0x200601a6,0x27e00730,0x224c01fa,0x4dd802e4}},	//   _koli_, _bahn_, _mkek_, _תחנו, 
   {{0x200601a7,0x6b9801fa,0xe8d80208,0xcf90010f}},	//   _joli_, _gevg, _ngổ_, ּטן_, 
   {{0x200601a8,0xdb000e78,0x267800a8,0x9aa416ac}},	//   _moli_, nglü, истэ_, _امبو, 
   {{0x200601a9,0x9ce8009e,0x54d4004e,0x00000000}},	//   _loli_, গহীন_, йцзу, --, 
   {{0x6b98818a,0x79840ca8,0x53c800cf,0x20040009}},	// [3a720] _yevg, _ifiw, лгам_, _ooli_, 
   {{0x200601aa,0x224c0165,0xe87401b9,0x78a41833}},	//   _noli_, _akek_, _گنیگ, _iviv, 
   {{0xe80c006d,0x93580276,0xd628041b,0xdce803e0}},	//   _सकता_, урау_, _боне_, yceğ, 
   {{0x78a400cc,0x27e00112,0xb3d8009e,0x20040254}},	//   _kviv, _zahn_, সাইজ, _aoli_, 
   {{0x200601ab,0xd00a01ac,0x27e00618,0x9878010f}},	//   _boli_, леде_, _yahn_, נאַט, 
   {{0xdb016bde,0x78a401f7,0x20042f7f,0xfbc4475c}},	//   ngló, _mviv, _coli_, _عت_, 
   {{0x200601ad,0x91e4721f,0x6b9804cc,0x78a40115}},	//   _doli_, _лове, _revg, _lviv, 
   {{0x6b992bb2,0x200403a0,0x78a40a93,0xab680135}},	//   _sevg, _eoli_, _oviv, _jiżż, 
   {{0x200601ae,0xab680003,0x39400200,0xdce803e0}},	//   _foli_, _miżż, _nxis_, rceğ, 
   {{0x79840248,0xab380086,0x60100008,0x62800129}},	//   _afiw, dùòñ_, rðmæ, _éloc, 
   {{0xe9f83bb3,0x78a601af,0x0dc800d6,0x394201b0}},	//   анні_, _aviv, _були_, _axis_, 
   {{0x200601b1,0x786001e6,0x27e001ab,0xab680135}},	//   _zoli_, hövd, _sahn_, _niżż, 
   {{0x2005d227,0x8c443e4f,0x092801f7,0x00000000}},	//   _yoli_, _леде, اسجي_, --, 
   {{0x78a405b4,0x3d287f05,0x200601b2,0xaa94030d}},	//   _dviv, _حتمی_, _xoli_, _дикч, 
   {{0x78a601b3,0xab68003d,0x81dc0183,0x7b702d4b}},	//   _eviv, _biżż, তাত_, _عطوا, 
   {{0xd0f81098,0x27e02305,0x5a780092,0x00000000}},	//   ्हाण_, _wahn_, _አሰቃቂ_, --, 
   {{0x6294011c,0x3940002e,0x69cc009d,0x00000000}},	// [3a730] _swzo, _gxis_, _ibae, --, 
   {{0x68ee01b4,0x224c03b2,0x2eec01e3,0xb38c0051}},	//   _irad, _skek_, _ordf_, _đểnh, 
   {{0x200601b5,0x68ee01b6,0xe8d8063f,0x78a405b8}},	//   _roli_, _hrad, _ozị_, _zviv, 
   {{0x200601b7,0x09a803f4,0x3ab800c8,0x7ab8011a}},	//   _soli_, গ্রা, רמאנ, רצאו, 
   {{0x09e003f4,0x69cc0097,0x78a40156,0x00000000}},	//   যাপা, _mbae, _xviv, --, 
   {{0xa29404db,0x68ec05d9,0x200419a2,0x24188c6c}},	//   _магі, _mrad, _qoli_, _тогы_, 
   {{0x200601b8,0x69cdd8cb,0x2eec06be,0x88cc0154}},	//   _voli_, _obae, _crdf_, িটিক, 
   {{0x786001e6,0xc0a80933,0x2004f52d,0xdb000b70}},	//   möve, _مائل_, _woli_, rglü, 
   {{0x200601b9,0x2eed7fa8,0x78600fe7,0x53c4085c}},	//   _toli_, _erdf_, löve, र्वश, 
   {{0x69cc0a49,0x00000000,0x00000000,0x00000000}},	//   _abae, --, --, --, 
   {{0x68ec5397,0x2eec0048,0x09e00eac,0x7b800131}},	//   _arad, _grdf_, যানা, ياھە, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x78600628,0x68ec2517,0x7bc4000d,0x00000000}},	//   höve, _crad, õjus, --, 
   {{0x68ee01ba,0x786001ed,0x78a404ba,0x69cc0037}},	//   _drad, köve, _vviv, _ebae, 
   {{0x68ee01bb,0xdb2400d0,0xe58800d7,0x786000e5}},	//   _erad, ápät, _dážď, jöve, 
   {{0x68ee01bc,0x78a48fa2,0x394201bd,0xa9c00137}},	//   _frad, _tviv, _txis_, _كۅپۉ, 
   {{0x78a5c86f,0xd77400ae,0x00000000,0x00000000}},	// [3a740] _uviv, _وادع, --, --, 
   {{0xab680327,0xe6180107,0x96b800f3,0x00000000}},	//   _wiżż, адӣ_, _куму_, --, 
   {{0x68ec02fb,0xab68025c,0x7860007c,0xa2b0012d}},	//   _zrad, _tiżż, göve, आंग्, 
   {{0x708400c7,0x00000000,0x00000000,0x00000000}},	//   зҳаз, --, --, --, 
   {{0x50647676,0x67280115,0x3ce0012d,0x50d406c2}},	//   отка, ĝeje, कटों_, تزار, 
   {{0x4fc41fe2,0x00000000,0x00000000,0x00000000}},	//   ісла, --, --, --, 
   {{0xd9b002f5,0x02c04f41,0xddc80210,0x00000000}},	//   ট্যম, _ойро, kleń, --, 
   {{0xfe040131,0x00000000,0x00000000,0x00000000}},	//   ققىي_, --, --, --, 
   {{0xfd4001c0,0x09e0015b,0xbc74005b,0xd7380092}},	//   дээн, যামা, обых_, _የድህነ, 
   {{0x68ec02d3,0x69cc0368,0x00000000,0x00000000}},	//   _rrad, _sbae, --, --, 
   {{0x88cc045e,0x68ee01be,0x00000000,0x00000000}},	//   িয়াক, _srad, --, --, 
   {{0x68ee01bf,0xa2cc043e,0x6d5c00ac,0xfcf0001f}},	//   _prad, _सहस्, əran, ውጣጡ_, 
   {{0x69cc0421,0x786001d3,0x9ba401d9,0x9f5001e3}},	//   _vbae, zöve, _کلى۪, äböj_, 
   {{0x68ec00ad,0xc61000cd,0x786001f4,0x00000000}},	//   _vrad, ठस्य_, yöve, --, 
   {{0x6594167f,0x68ee01c0,0x786001e3,0x09e000eb}},	//   забу, _wrad, xöve, যাবা, 
   {{0x9ba000d1,0x7860007c,0xeb9801af,0x00000000}},	//   _قەۋى, vöve, _тиҫ_, --, 
   {{0x68ed3d2a,0x2d8400ae,0x38b008a5,0x00000000}},	// [3a750] _urad, icme_, _vörð_, --, 
   {{0x7860088f,0xa0a4010b,0x69c001f9,0xf3f800cf}},	//   töve, җакд, _वाडी, онуш_, 
   {{0x601c0100,0x81dc015b,0x02a4022e,0x00000000}},	//   _jème, তাস_, юрам, --, 
   {{0x63e400aa,0x786001e3,0x31c400e5,0x98bc0210}},	//   _ډېرې_, röve, vézó_, łtą_, 
   {{0xf1c8470b,0x786201c1,0x00000000,0x00000000}},	//   تونى_, söve, --, --, 
   {{0xe8d802e3,0xdee4013e,0x1e94a15c,0xd0045211}},	//   _nzọ_, зоки, прир, зеше_, 
   {{0xa19410f5,0x69c00073,0x41840023,0x68280064}},	//   _навч, _वाढी, _ዝጠፍእ_, gždi, 
   {{0xc21800c6,0xe8d801f2,0x09e0015b,0xdb2000e4}},	//   _тєг_, _azọ_, যাডা, _ëtép, 
   {{0x7ff406c2,0x00000000,0x00000000,0x00000000}},	//   _وسطا, --, --, --, 
   {{0x49c405f5,0xbfb806f6,0xefdc0092,0x00000000}},	//   үлэн_, _خطرا_, ኔታው_, --, 
   {{0x59740137,0x00000000,0x00000000,0x00000000}},	//   зыгу, --, --, --, 
   {{0xd94601c2,0x2d856923,0x69c004e4,0x00000000}},	//   земи, ccme_, _वाणी, --, 
   {{0xae040952,0x186801f4,0x00000000,0x00000000}},	//   _تونى, йами_, --, --, 
   {{0x601c0699,0x6288110c,0xb90407f7,0x18680117}},	//   _fème, _čeon, _नन_, саги_, 
   {{0x601c007f,0xf8b0036b,0x45380092,0x00000000}},	//   _gème, رکک_, _በመከበ, --, 
   {{0xea8800f2,0x00000000,0x00000000,0x00000000}},	//   _بخون_, --, --, --, 
   {{0x601c0066,0x2eb80c70,0x00000000,0x00000000}},	// [3a760] _mèmb, _इम्त, --, --, 
   {{0x601c020c,0xab2000a2,0x00000000,0x00000000}},	//   _lèmb, _öòün, --, --, 
   {{0x5184dc3f,0x87780302,0x00000000,0x00000000}},	//   пула, _לאיי, --, --, 
   {{0xe2a830bf,0xa2cca786,0x64480aab,0x00000000}},	//   زامن_, _सहर्, _íein, --, 
   {{0x77600213,0xd3c400cf,0x47dc00eb,0xc4800153}},	//   əmxa, _ىتسى, মারী, _пляк, 
   {{0xff382440,0x75240165,0x45240327,0x00000000}},	//   _ድንጋጌ, mziz, _ལྟིར_, --, 
   {{0x877800c8,0x3cec0175,0x7f8201c3,0x2d840200}},	//   זאצי, _argv_, رلين, tcme_, 
   {{0x81b00154,0xca380150,0x00000000,0x00000000}},	//   জ্ব_, _ﺒﻜﺎ_, --, --, 
   {{0x7524a03f,0xdcb00131,0x601c0129,0xd0240dab}},	//   nziz, پىپ_, _sème, _емай, 
   {{0x0ba407d8,0x9f440455,0x601c02e2,0x752404ba}},	//   чшим, _malê_, _pème, iziz, 
   {{0x81dc03f4,0xbf1025aa,0xeee4034c,0xfbcc00dd}},	//   তার_, _كوكب, _تغذی, ھتی_, 
   {{0x0e6428b6,0x601d096b,0x75240ac5,0xfbce01c4}},	//   _экен, _gèmb, kziz, پتی_, 
   {{0x5e240d28,0xbc64028e,0x6e200332,0xc98401f0}},	//   _تعلق, تمین_, mhmb, жуҳи, 
   {{0x75250ed2,0xe8d8063f,0x601c0ba1,0xc95801b9}},	//   dziz, _uzọ_, _tème, _қўй_, 
   {{0x47dc00cc,0xdc2816ac,0x00000000,0x00000000}},	//   মালী, _بسنه_, --, --, 
   {{0xe8d801f2,0x6e200097,0xc320015b,0x35e40aa8}},	//   _afụ_, nhmb, _বুঝি_, нцув, 
   {{0x06380092,0x682800c0,0x00000000,0x00000000}},	// [3a770] _የእውነ, dždv, --, --, 
   {{0xdb00006a,0x35f801d9,0x00000000,0x00000000}},	//   dalê, _ہرُد_, --, --, 
   {{0x752601c5,0xc32003d4,0x00000000,0x00000000}},	//   aziz, _বুজি_, --, --, 
   {{0xe8da01c6,0x20d402dd,0xb7640139,0xc32c0014}},	//   _efụ_, дікс, _ятый, پٕچ_, 
   {{0x81dc09bd,0x661e01c7,0xe7b001ad,0x78600108}},	//   তাল_, _ilsk, _जयाप, löva, 
   {{0x601c067c,0xefd0001f,0x9c8400a2,0xca3801ec}},	//   _sèmb, _ቦታው_, _jeōō, _ﺒﻜﺔ_, 
   {{0x443201c8,0x72d42c28,0x00000000,0x00000000}},	//   mix_, _порф, --, --, 
   {{0x4174004b,0x31c43f72,0x9f440200,0x5c8801a9}},	//   _رارس, _псув, _halë_, ойим_, 
   {{0x78600267,0x21a40116,0x443000db,0xdb0044b3}},	//   höva, _ниңм, oix_, nglö, 
   {{0x443201c9,0xdaa8b149,0x5cc40116,0x7860005b}},	//   nix_, овод_, псүз, köva, 
   {{0x7524f0d6,0x661c007c,0x1a641888,0x00000000}},	//   zziz, _olsk, ویتی_, --, 
   {{0xdcf89717,0x443201ca,0x786001e3,0x00000000}},	//   _وفات_, hix_, döva, --, 
   {{0x4430094a,0xb60800d7,0x80b019cc,0x00000000}},	//   kix_, _lašá, उंटे, --, 
   {{0x661c1427,0x443000b5,0xdb000200,0x3f8400d7}},	//   _alsk, jix_, nalë, ncnu_, 
   {{0x59c405ba,0x443201cb,0x8c4201cc,0x996400fb}},	//   _वापर, dix_, _шеше, ятүл, 
   {{0x443201cd,0x752401c0,0x00000000,0x00000000}},	//   eix_, tziz, --, --, 
   {{0x9f44145e,0x75240083,0x67280115,0xdb0201ce}},	// [3a780] _balë_, uziz, ĝeja, gglö, 
   {{0x77943b93,0xdb0201cf,0x75240165,0xe1f80064}},	//   _سیرا, valê, rziz, _anų_, 
   {{0x9f4402d3,0xfbcc1944,0x7ae0003e,0x16640640}},	//   _dalë_, त्यम, _jsnt, _овом, 
   {{0x958402dd,0xc6900375,0x2dcc0150,0xb86400f1}},	//   _ілге, _שאר_, _ﺒﺄﻋﻤ, _غاښو, 
   {{0x4430002e,0x9f4402d3,0x59c400dc,0xe6080014}},	//   bix_, _falë_, _वानर, _رزَو_, 
   {{0x9f440cad,0xe194009d,0x00000000,0x00000000}},	//   _kalè_, _үртэ, --, --, 
   {{0x9f4401e1,0x42c4005b,0x6e200200,0x00000000}},	//   _jalè_, _огрн_, thmb, --, 
   {{0x9f4402bd,0xdb00067c,0x00000000,0x00000000}},	//   _malè_, malè, --, --, 
   {{0x7bc201d0,0x7ae003ac,0xdb01e395,0x9f4401e1}},	//   _bcnu, _asnt, lalè, _lalè_, 
   {{0x7ae001e0,0x6e20036e,0xbc643592,0x69c01546}},	//   _bsnt, shmb, ومين_, _वाही, 
   {{0xaa58ef62,0x83b40375,0x562c0092,0x00000000}},	//   зину_, ופיע_, _ተገንብ, --, 
   {{0x4430317d,0x9ff80154,0x5c74004e,0x00000000}},	//   zix_, _অতএব_, млөт, --, 
   {{0xdb0000f2,0x22940241,0x4430002e,0x00000000}},	//   halè, _kúkò_, yix_, --, 
   {{0x4f2c0201,0x443201d1,0x9f440ca8,0x786033b4}},	//   _እንዳይ, xix_, _balè_, töva, 
   {{0x9f44180f,0xf77201d2,0x3bb8011a,0x3d2001e1}},	//   _calè_, لاف_, _ומוד, _tèwé_, 
   {{0x59c419e5,0x443201d3,0x9f4401e1,0x78600267}},	//   _वायर, wix_, _dalè_, röva, 
   {{0x69de01d4,0x4430094a,0x601c0066,0x9f440023}},	// [3a790] mese, tix_, _lèma, _palë_, 
   {{0xc864e540,0x9f4401e1,0x73d80e46,0x245403e6}},	//   _تطبي, _falè_, мдур_, رناس, 
   {{0x4430a860,0x601c0066,0x9f440023,0xdb0201d5}},	//   rix_, _nèma, _valë_, galè, 
   {{0x443004ce,0x661c0113,0x85e00220,0xb60801ef}},	//   six_, _ulsk, _جۋرن, _vašá, 
   {{0xf4840124,0x69de01d6,0x00000000,0x00000000}},	//   _аусн, iese, --, --, 
   {{0x81dc02a6,0x69de01d7,0x44300054,0xdb0201d8}},	//   তাই_, hese, qix_, balè, 
   {{0x69de01d9,0x63a5c5f1,0xdb0201da,0x9f440241}},	//   kese, mahn, calè, _kalé_, 
   {{0x63a43fa0,0x601c007f,0xe0ac04c5,0x225801a8}},	//   lahn, _dèma, _গহীন, _ósk_, 
   {{0x9f440232,0x61e80069,0x60b4014d,0xdb0201db}},	//   _malé_, _iael, _سمائ, malé, 
   {{0x61ea01dc,0x63a601dd,0x60c8016c,0x601c0100}},	//   _hael, nahn, _iqem, _fèma, 
   {{0x61ea01de,0x69de01df,0x628601e0,0xac842e14}},	//   _kael, fese, nqho, нгөл, 
   {{0x69de01e1,0x61ea01e2,0x63a46085,0xdb009432}},	//   gese, _jael, hahn, nalé, 
   {{0x61e800b2,0x63a44694,0xdb000699,0x6454009d}},	//   _mael, kahn, zalè, _okzi, 
   {{0x63a601e3,0x61ea01e4,0x69dc0618,0x657e01e5}},	//   jahn, _lael, aese, _agsh, 
   {{0x63a45df1,0x8c180302,0x61e801ee,0x9f45c0bf}},	//   dahn, _מוסי, _oael, _balé_, 
   {{0x69de01e6,0x9f4601e7,0x61ea01e8,0x645601e9}},	//   cese, _valè_, _nael, _akzi, 
   {{0x63a601ea,0x2edd07de,0x9f440429,0x3a2000a2}},	// [3a7a0] fahn, _मन्त, _dalé_, _ilip_, 
   {{0x63a601eb,0x3a20030a,0xa49004fb,0x9f456a41}},	//   gahn, _hlip_, شیفت, _talè_, 
   {{0x61ea01ec,0x9f4403a0,0x657c0113,0x6284009a}},	//   _bael, _falé_, _fgsh, gqho, 
   {{0x645601ed,0x61e80de4,0xfbcc0a28,0xdb0201ee}},	//   _ekzi, _cael, त्तम, galé, 
   {{0x63a4c6e0,0x61ea01ef,0x6b8001f2,0x601c4ce5}},	//   bahn, _dael, ịgid, _sèma, 
   {{0x69de01f0,0x63a601f1,0x3a200113,0xefbc001f}},	//   zese, cahn, _llip_, _ታድያ_, 
   {{0x69de01f2,0x61e80f8b,0x60c801f0,0xdb0201f3}},	//   yese, _fael, _eqem, balé, 
   {{0x61e8047c,0x6aa84a1f,0xadf4147e,0xdb009d74}},	//   _gael, vsdf, тпиш, calé, 
   {{0x69dc93ce,0x66080428,0xc8dc033f,0x1e0800f1}},	//   vese, _òeke, _पैंट, بډلی_, 
   {{0x69de01f4,0x601c068c,0x61ea01f5,0x00000000}},	//   wese, _tèma, _zael, --, 
   {{0x69de01f6,0x61e91a02,0x7b1001c0,0x3a20045a}},	//   tese, _yael, гдэх, _blip_, 
   {{0x3a2201f7,0x63a57fc4,0x628000b8,0x00000000}},	//   _clip_, zahn, _ũlok, --, 
   {{0x63a4c453,0x09e000bd,0x48bc015b,0x78600267}},	//   yahn, যালা, ইব্র, rövn, 
   {{0x69de01f8,0x9f4414a9,0x3a20004d,0x786001e3}},	//   sese, _salé_, _elip_, sövn, 
   {{0x63a601f9,0xc984009b,0x6728008f,0x786001e3}},	//   vahn, _пупи, ĝejo, pövn, 
   {{0x63a4122d,0x3a2201fa,0xdb0000e8,0xc76400d1}},	//   wahn, _glip_, xalé, _ۋادى, 
   {{0x645402fa,0x61ea01fb,0x63a601fc,0xdb0201fd}},	// [3a7b0] _pkzi, _rael, tahn, valé, 
   {{0x61e80421,0xdb0000e8,0x9730429e,0x20c800c7}},	//   _sael, walé, اکیا, vúi_, 
   {{0x63a45df1,0x61ea01fe,0x2a680211,0xb444ce9f}},	//   rahn, _pael, _khab_, уэтк, 
   {{0x62840113,0x657c03ac,0x786001e3,0xf204117e}},	//   rqho, _ugsh, hövl, лячо, 
   {{0x61ea01ff,0xdb00e586,0x35f400c0,0x00000000}},	//   _vael, ralé, _спяр, --, 
   {{0xdb011a82,0x61ea0200,0x63a4014f,0x2d94010b}},	//   salé, _wael, qahn, ңрыс, 
   {{0x61e99d96,0x2a6805da,0xdb000c6a,0x6284031c}},	//   _tael, _ohab_, palé, qqho, 
   {{0xe8d80016,0x3ab0804b,0x00000000,0x00000000}},	//   _ngữ_, ңәйт, --, --, 
   {{0xa0742347,0xd24c00ec,0x00000000,0x00000000}},	//   _агач, _بچل_, --, --, 
   {{0x3a220201,0x2a680652,0x00000000,0x00000000}},	//   _slip_, _ahab_, --, --, 
   {{0x3a20007f,0x5dd493fc,0x00000000,0x00000000}},	//   _plip_, _لقائ, --, --, 
   {{0x81dc03d4,0x2a68047e,0xdd940953,0x7e28007b}},	//   তাক_, _chab_, _рады, _عساف_, 
   {{0x2a6801d9,0xb4e0000d,0x88a000fb,0x4a4011f7}},	//   _dhab_, _दने_, ағыһ, рняв, 
   {{0x24b800cc,0x7860007c,0x00000000,0x00000000}},	//   ুবাহ, rövo, --, --, 
   {{0x07a012e2,0xc7a02850,0xa3e402a0,0x91d000cd}},	//   расн, риск, भजन_, ण्डै, 
   {{0x2a6a0202,0x00000000,0x00000000,0x00000000}},	//   _ghab_, --, --, --, 
   {{0x45820203,0x6b8400a2,0x00000000,0x00000000}},	// [3a7c0] ргув, _şigi, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x786004cc,0x00000000,0x00000000,0x00000000}},	//   növm, --, --, --, 
   {{0xd1b802d3,0x6fc40490,0xf4840133,0x53c4012d}},	//   _ታሕቲ_, _राहू, _ماسی, र्जश, 
   {{0xc0cc0092,0x524c0240,0x00000000,0x00000000}},	//   ጣጣሪ_, _ንኣፍሪ, --, --, 
   {{0xc4d0011a,0xe4740064,0x00000000,0x00000000}},	//   _דגש_, _бусэ, --, --, 
   {{0x067c0ed1,0xd9e00ebb,0xbea0013d,0x00000000}},	//   _ﻣﺎﻟﯩ, गजात_, ашый, --, 
   {{0x03643580,0x2ebc0316,0x4340010b,0xfbcc102f}},	//   _риск_, ्झौत, _тесв, त्सम, 
   {{0xfe6c345f,0xc0e20204,0x786000ac,0x8c6400cf}},	//   ڭگە_, _котк, tövl, ктод, 
   {{0x2a6a0205,0x4fe800d4,0x5fc809b2,0x09d800cd}},	//   _shab_, _імен_, _रायल, यज्य, 
   {{0x6d440038,0x2a680211,0xf3f40183,0xb2e400a2}},	//   _žiad, _phab_, _আকাৰ_, _öñdä, 
   {{0x2a6801d4,0x3a740166,0x00000000,0x00000000}},	//   _qhab_, илэр, --, --, 
   {{0xbb4400dd,0x5fc81b51,0x0eb800c7,0xebc401e0}},	//   فلین_, _रामल, _хуҷы_, _йәнн, 
   {{0xa40c0349,0xdb000142,0x00000000,0x00000000}},	//   _শষ্য_, calï, --, --, 
   {{0x2a68c8ff,0xd7d001bc,0xf1b400cd,0x00000000}},	//   _thab_, द्धच, ुलान, --, 
   {{0x628007ea,0xc608015b,0x28140133,0x00000000}},	//   _éloi, রসভা_, _ڕوخس, --, 
   {{0xfbcc726e,0x4ad00037,0x00000000,0x00000000}},	// [3a7d0] त्वम, _तहँव, --, --, 
   {{0x601c004e,0x291800a2,0x00000000,0x00000000}},	//   _rèmo, mysa_, --, --, 
   {{0x291a0206,0x9f44011c,0xe8d8063f,0xdcf80135}},	//   lysa_, _calì_, _oyị_, _mewġ, 
   {{0x9f44011c,0x2918022f,0x00000000,0x00000000}},	//   _dalì_, oysa_, --, --, 
   {{0x25aa0207,0xe135519d,0x2918089c,0xd00c004b}},	//   maal_, ынды, nysa_, ړلو_, 
   {{0xe8d8063f,0x25a80050,0x1ec834da,0x8fa00104}},	//   _ayị_, laal_, елки_, баше, 
   {{0xdd98007f,0x24880139,0x00000000,0x00000000}},	//   tbň_, lqam_, --, --, 
   {{0x601c007f,0xdc980334,0x00000000,0x00000000}},	//   _tèmo, нтош_, --, --, 
   {{0x442001f5,0x248a0208,0x00000000,0x00000000}},	//   _klj_, nqam_, --, --, 
   {{0x25aa0209,0x2fc00198,0xdab80953,0x5ea401f0}},	//   haal_, ɗigo_, нымі_, _будҷ, 
   {{0x29185f39,0xc4cc0154,0x9f4402d2,0x44200171}},	//   eysa_, রিয়জ, _kalí_, _mlj_, 
   {{0x4422020a,0x25aa020b,0x6cdc0150,0x00000000}},	//   _llj_, jaal_, _ﺃﻴﺩﻴ, --, 
   {{0x9f46020c,0x25aa020d,0x442009a8,0xdb013383}},	//   _malí_, daal_, _olj_, malí, 
   {{0x59c40574,0x00000000,0x00000000,0x00000000}},	//   _वावर, --, --, --, 
   {{0x25aa020e,0xb5e80241,0x00000000,0x00000000}},	//   faal_, bẹ̀r, --, --, 
   {{0x25a9c760,0xfbcd07de,0x4421be9d,0xd1cc02d3}},	//   gaal_, त्रम, _alj_, ጣታት_, 
   {{0x9f44011c,0x9b4400f1,0xfbb43156,0x69a401af}},	// [3a7e0] _salì_, _جنګو, _आयाम, _тлыҡ, 
   {{0x9f4404cc,0x88980a1e,0xdb0002f0,0x53a4007b}},	//   _palì_, _רביי, halí, اماك, 
   {{0x25aa020f,0xdb01b2c5,0x9f4402f0,0xd29400d4}},	//   baal_, kalí, _balí_, урзь, 
   {{0x25aa0210,0xdb0004d4,0xe74402dd,0x65c001ec}},	//   caal_, jalí, _түсе_, _мұса, 
   {{0x9f445cca,0x66080086,0x76460211,0x99800024}},	//   _dalí_, _òeka, mniy, likų_, 
   {{0x4cbc04c5,0x76445431,0x6e9421b5,0x5ddc01ec}},	//   ্বমু, lniy, аику, _ﺃﻤﻨﻴ, 
   {{0xdb020212,0x99800153,0x8d840209,0x7644058a}},	//   falí, nikų_, лупд, oniy, 
   {{0x76460213,0xdb005793,0x9f460214,0xe18402dd}},	//   nniy, galí, _balâ_, _көше_, 
   {{0x7e6801fb,0x76440014,0x7c9005f8,0x29180009}},	//   _dhgp, iniy, یشیا, xysa_, 
   {{0x76460215,0x25a80d27,0xcbe40c56,0x00000000}},	//   hniy, zaal_, уции, --, 
   {{0x25a80a81,0x764403f0,0xdb0002f0,0xbfc80150}},	//   yaal_, kniy, balí, _سالە_, 
   {{0xc3310b71,0xdb0004d4,0xbf10247f,0x99800024}},	//   מות_, calí, _دومب, dikų_, 
   {{0xddc845e3,0x25aa0216,0x76440309,0x3e50009f}},	//   lleş, vaal_, dniy, _اَنز, 
   {{0x25aa0217,0x764531eb,0x99800064,0x00000000}},	//   waal_, eniy, fikų_, --, 
   {{0x25aa0218,0x1f340201,0x4668ba46,0xddc8e03b}},	//   taal_, _እንደም, ерам_, nleş, 
   {{0x5eb809bd,0x6ab40327,0x76440009,0x291839cb}},	//   _আহমে, _དྷརྨ, gniy, pysa_, 
   {{0x7648020c,0x00000000,0x00000000,0x00000000}},	// [3a7f0] édya, --, --, --, 
   {{0x25aa0219,0xddc80365,0x764436b7,0x9f442e27}},	//   saal_, kleş, aniy, _salí_, 
   {{0x25a89ed4,0x9f440004,0x24880986,0x76440009}},	//   paal_, _malã_, sqam_, bniy, 
   {{0x09e000bd,0x25a801d9,0x76440009,0xa3e005dc}},	//   যাকা, qaal_, cniy, _दसक_, 
   {{0x26d001c6,0x660e021a,0x24880941,0x9f46021b}},	//   ltzo_, mjak, qqam_, _valí_, 
   {{0x660e021c,0x50a000d1,0xa0680063,0xddc80790}},	//   ljak, تەكل, њака_, fleş, 
   {{0x9f440418,0x26d001c6,0x64440208,0xdea0036b}},	//   _talí_, ntzo_, mnhi, زیشی, 
   {{0x660e021d,0xe8d80241,0x27f001ab,0x4f500b82}},	//   njak, _ayọ_, hdzn_, _ምንዝር, 
   {{0x81a82baf,0xdb02021e,0x9c2406b3,0x64440784}},	//   _খাপ_, ralí, идид, onhi, 
   {{0xdb02021f,0x9f34005e,0x660c16b5,0xb2e80014}},	//   salí, _кезі, hjak, _جٹہٕ_, 
   {{0x9f460220,0x76440bf1,0x660e0221,0xdb000f91}},	//   _walâ_, yniy, kjak, palí, 
   {{0xdb00006a,0x5cf40276,0x660c2252,0xd3540375}},	//   talâ, _вяку, jjak, ייתי_, 
   {{0x660e0222,0x41d40b7c,0x63b43e8f,0xb4c40037}},	//   djak, ण्यस, _odzn, _एमे_, 
   {{0x99800006,0x09e0015b,0x9f440798,0xdb00002d}},	//   tikų_, যাগা, _galã_, ralâ, 
   {{0x81a811ba,0xcc3800c8,0x7d180946,0x22b00210}},	//   _খান_, _בעסט, lyus, jąk_, 
   {{0x660e0223,0x6445cc0e,0x6abc0008,0x6ed847ac}},	//   gjak, enhi, árfe, _महसु, 
  
   {{0x76460224,0xddc8aa4a,0xfaa00364,0x629401c6}},	// [3a800] rniy, zleş, _тақо, _atzo, 
   {{0x76460225,0x64460226,0x660c25e4,0x68e82e11}},	//   sniy, gnhi, ajak, çede, 
   {{0x79840770,0x7d180230,0xdb0006d9,0x660c0243}},	//   _kgiw, hyus, nalà, bjak, 
   {{0x78a60227,0x7d1a0228,0x76440986,0x64460229}},	//   _kwiv, kyus, qniy, anhi, 
   {{0xc20400f7,0xdb0006d9,0x85980375,0x85442d29}},	//   شقون_, halà, _בשכו, _взяв_, 
   {{0x9f440109,0x78a4556c,0xddc841b5,0x7d1a022a}},	//   _balà_, _mwiv, tleş, dyus, 
   {{0x9f4419f5,0x79841418,0x91e5be87,0xfae400c6}},	//   _calà_, _ogiw, _кове, _بث_, 
   {{0xddc846b3,0xfe6c3092,0x7986022b,0x9f440109}},	//   rleş, ودي_, _ngiw, _dalà_, 
   {{0xddc80209,0xb4c4012d,0x00000000,0x00000000}},	//   sleş, _एमो_, --, --, 
   {{0x7986022c,0xddc809a5,0x9f4419f5,0xe8d801fb}},	//   _agiw, pleş, _falà_, _ngỡ_, 
   {{0x9f4401e5,0x6bd8034c,0x28a80037,0xab382ff5}},	//   _galà_, نوکس_, _कबहि, упну_, 
   {{0x78a400ca,0x9f440589,0x7f380375,0x9db00150}},	//   _bwiv, _walã_, _בעבו, _ﭼﻴﯖﺸ, 
   {{0x4aa58005,0x8c440e76,0x9f44e28c,0x81a804c5}},	//   _कौरव, _кеде, _ialá_, _খাম_, 
   {{0x9f4403a0,0x79840337,0x0ba81075,0x00000000}},	//   _halá_, _egiw, _شاتى_, --, 
   {{0x660e022d,0x85a4399f,0x41d408df,0x5fc803ce}},	//   tjak, ијад, ण्डस, _रासल, 
   {{0x6d5c4953,0x2eec0472,0x26d00120,0xe6940220}},	//   ğraf, _msdf_, rtzo_, _қимы, 
   {{0x9f46022e,0x69cc004e,0x78a40165,0x32e8010e}},	// [3a810] _malá_, _icae, _gwiv, _aşy_, 
   {{0xdb0000e7,0x00000000,0x00000000,0x00000000}},	//   lalá, --, --, --, 
   {{0x81a80729,0x78a41aa1,0x2bd80be7,0x41940131}},	//   _খাব_, _zwiv, ब्या, لماڭ_, 
   {{0x97540375,0x672c00e2,0xdb0001d3,0x7d180de2}},	//   _לשתף_, ģijā, nalá, yyus, 
   {{0x68ec0327,0x64bc054e,0x6018ea13,0x2bf800cd}},	//   _jsad, _băiş, лодя_, ्ञां_, 
   {{0x09e000bd,0x9f442e69,0x68ee022f,0xb97c0a1e}},	//   যাটা, _palà_, _msad, דנדי, 
   {{0xdb0003f7,0x68ec01b9,0x6294005c,0x9ef4007b}},	//   kalá, _lsad, _utzo, إستش, 
   {{0x7d1a0230,0x5fc80db3,0x59c40210,0x9094013d}},	//   tyus, _रावल, _वाइर, швәт_, 
   {{0xdb0001ed,0x68ec0083,0x7094b159,0xdea001d5}},	//   dalá, _nsad, _матф, _کیبی, 
   {{0x78a40223,0x69ce0231,0xdb004b84,0x7d1a0232}},	//   _rwiv, _acae, talà, ryus, 
   {{0x68ee0233,0x7d18037e,0x78a42c7f,0x8d9001d5}},	//   _asad, syus, _swiv, غلیش, 
   {{0xdb0000dd,0x78a4007f,0x2bd807af,0x7d180477}},	//   galá, _pwiv, ब्बा, pyus, 
   {{0xdb0005da,0x00000000,0x00000000,0x00000000}},	//   salà, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb000cad,0x68ee0234,0xd6283d65,0xdca40daf}},	//   balá, _esad, гове_, _таһи, 
   {{0x601c007f,0x68ec031c,0x78a60235,0xbbb4af6c}},	//   _dèmi, _fsad, _twiv, _आयुक, 
   {{0xc480940c,0x78a400ca,0x00000000,0x00000000}},	// [3a820] злук, _uwiv, --, --, 
   {{0x601e0236,0x00000000,0x00000000,0x00000000}},	//   _fèmi, --, --, --, 
   {{0xe7a801c6,0x4c3800df,0x00000000,0x00000000}},	//   _өвөл_, נגעצ, --, --, 
   {{0x58f40003,0xc61c03d4,0x00000000,0x00000000}},	//   _བློས_, নোবা_, --, --, 
   {{0x2eec0014,0x09e0015b,0xd4f405a2,0x00000000}},	//   _ssdf_, যাচা, _уяны, --, 
   {{0x9f44003a,0x98a0033f,0x20b8d2e8,0x0d2001c6}},	//   _malæ_, czką_, рыць_, үүжү, 
   {{0x03a01b74,0x61100055,0xdb0001d3,0x1ee802f2}},	//   _хисо, _aślā, yalá, لووی_, 
   {{0xc2401a5c,0xdee4007b,0x00000000,0x00000000}},	//   _енск, تأهي, --, --, 
   {{0xfba401c0,0xc5f00375,0x64bc0356,0xeb200e85}},	//   өтэй_, לדה_, _tăiş, मन्त_, 
   {{0x69cc16b8,0x7c90007b,0xec3400d4,0x7f1401c8}},	//   _scae, أشيا, іннь, _گيمز_, 
   {{0xdb01e46b,0x9f44043b,0x1ea805d4,0x68ec2252}},	//   talá, _talá_, _ناني_, _ssad, 
   {{0xaa580131,0x00000000,0x00000000,0x00000000}},	//   риму_, --, --, --, 
   {{0xfdf40302,0xdb00fdf7,0xc7b80108,0xfce0009d}},	//   _לצאת_, ralá, лёв_, _ноцо, 
   {{0x68ec1b5c,0x601c033b,0xdb020237,0x25aca7ab}},	//   _vsad, _pèmi, salá, _žel_, 
   {{0x68ec033f,0xc0b80092,0x6d5c0205,0xdb00072d}},	//   _wsad, ሰለሰ_, şrad, palá, 
   {{0xe8d807ae,0x68ec0c09,0xdb00011f,0x224c0115}},	//   _ngủ_, _tsad, qalá, _ĉeko_, 
   {{0x68ec1a36,0xd5a4006c,0x19a80cab,0xdb00032e}},	// [3a830] _usad, زللی, _өтөп_, galæ, 
   {{0x4424629e,0x601daa3c,0x00000000,0x00000000}},	//   ón_, _tèmi, --, --, 
   {{0x64880010,0x13a801b9,0x00000000,0x00000000}},	//   _ožig, شننی_, --, --, 
   {{0xa5f99964,0x71f80133,0x98a0033f,0x00000000}},	//   _тему_, یرۆس_, szką_, --, 
   {{0x1fa9d528,0x6fc40073,0x63e400f1,0x00000000}},	//   акли_, _राखू, _وېرې_, --, 
   {{0x1e95fbf0,0x249801e4,0x32040076,0x9ac41418}},	//   орир, _itsm_, _enmy_, liŋŋ, 
   {{0xa1940107,0xdb0003b9,0xd00c2dd0,0x00000000}},	//   _мавч, malç, ضلي_, --, 
   {{0x62243ee0,0x24980109,0x82340691,0x4f300023}},	//   _بىرل, _ktsm_, _طرزا, _ክንዝክ, 
   {{0x224c0066,0x64880cf4,0x999000ee,0x628006af}},	//   _ijek_, _džig, _alyş_, _éloq, 
   {{0x5ba81734,0xdb020238,0xdea007d6,0x2c70002e}},	//   шком_, nalç, _قیتی, jàdd_, 
   {{0x249800f1,0x9ac40083,0x200400a2,0x4be401b9}},	//   _ltsm_, kiŋŋ, _inli_, زکوپ_, 
   {{0x6b9c7bfb,0x58f4031c,0x9f4401bf,0x7860007c}},	//   ırga, _བླུས_, _palæ_, hövt, 
   {{0x9f44004e,0x224c0023,0x9ac404ba,0xdb002b24}},	//   _balç_, _mjek_, diŋŋ, kalç, 
   {{0x9f44381a,0x224c0841,0x2bd800dc,0xdb0003b2}},	//   _calç_, _ljek_, ब्दा, valæ, 
   {{0x224cef64,0x68e00311,0x366800f1,0xdb00371e}},	//   _ojek_, ălda, مشرۍ_, dalç, 
   {{0x94e00134,0x224c0de2,0x20040334,0xd94400ee}},	//   kɔɔ_, _njek_, _lnli_, _мейи, 
   {{0x9f4400db,0xd8740127,0xaaec01e1,0xb6480092}},	// [3a840] _falç_, _واخب, _òwòó_, _የእውቀ, 
   {{0x224c020c,0x934406ed,0x09dc00cc,0xdb020239}},	//   _ajek_, онзе, _বোপা, ralæ, 
   {{0x5184a90c,0x00000000,0x00000000,0x00000000}},	//   оула, --, --, --, 
   {{0x2006023a,0xdb02023b,0x425001b9,0x00000000}},	//   _anli_, malä, ونلر, --, 
   {{0x601c004e,0x9f440166,0xdb000958,0x00000000}},	//   _lèmu, _lalä_, lalä, --, 
   {{0x224c0a2e,0x64880e3c,0xdb000120,0x2fc003fa}},	//   _ejek_, _džid, calç, ßig_, 
   {{0x786001e3,0xdb004268,0x00000000,0x00000000}},	//   lövs, nalä, --, --, 
   {{0x7f440075,0x25b8003e,0x94e00134,0xd174010b}},	//   تلىق_, _xdsl_, bɔɔ_, _дызы, 
   {{0x648809a8,0xd7a843d1,0x2de8004b,0x25ac000d}},	//   _vžig, कराच, لوژۍ_, _õele_, 
   {{0xbfc014b7,0xdb0000fd,0xcf5800f3,0x00000000}},	//   _обук, kalä, _креч_, --, 
   {{0x37d0015b,0xdb0001f4,0xc3f800df,0x9e642bef}},	//   াজার, jalä, בליש, _کالن, 
   {{0xdb0001b8,0xd9e000e1,0xbea0b971,0x00000000}},	//   dalä, गजगत_, _цацк, --, 
   {{0xeb34581f,0xdb02023c,0xdb8000c7,0xc2780a7c}},	//   زىڭد, nblê, мҳәи, ירטי, 
   {{0xe8da023d,0x601c1186,0x00000000,0x00000000}},	//   _ngụ_, _fèmu, --, --, 
   {{0xdb00013d,0x00000000,0x00000000,0x00000000}},	//   galä, --, --, --, 
   {{0xe8d80521,0xdb00000f,0x092801c8,0x00000000}},	//   _agụ_, kblê, _نسخي_, --, 
   {{0x98bc00a8,0x0576023e,0xba744fe0,0x9ac404ba}},	// [3a850] ătă_, زارد, _تاوت, riŋŋ, 
   {{0x224c002d,0x0464187f,0x00000000,0x00000000}},	//   _sjek_, ітам, --, --, 
   {{0x2c700561,0x2004e456,0x224c0200,0xba84010b}},	//   càde_, _rnli_, _pjek_, _üçüs, 
   {{0x94e0013f,0x24980010,0x00000000,0x00000000}},	//   tɔɔ_, _ttsm_, --, --, 
   {{0xd5e4025c,0x6304036b,0xf1940276,0x49500023}},	//   _སྒྲག, _کوزل, фичь, _ዘንበብ, 
   {{0xdb0003cd,0x389c011a,0x48e0000d,0x00000000}},	//   lalå, סיונ, _ओहनो_, --, 
   {{0xd00d0151,0x224c019b,0x00000000,0x00000000}},	//   الى_, _tjek_, --, --, 
   {{0x7862023f,0xdb00143a,0xa4400133,0xa194009d}},	//   növr, nalå, _تێڕو, _хаач, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb000598,0x20060240,0x98a00034,0xd94400ee}},	//   yalä, _unli_, czkę_, җеги, 
   {{0xa3dc7df0,0x0524015b,0x23dc0b7c,0xda081cc7}},	//   थ्य_, _যশোর_, न्यद, ميده_, 
   {{0xbef407f7,0xdb0001f4,0xaec40150,0x00000000}},	//   ंटीन_, valä, _ібіл, --, 
   {{0x601c0100,0x1cc4025c,0x9aa46a72,0x00000000}},	//   _fèmt, _ཎའི_, _کمبو, --, 
   {{0xe8780020,0xdb0001b8,0x6ac80162,0x5158011a}},	//   _በቅርቡ_, talä, ðsfø, מכרו, 
   {{0x5fc80892,0x00000000,0x00000000,0x00000000}},	//   _राईल, --, --, --, 
   {{0xdb000793,0x59c40456,0x00000000,0x00000000}},	//   ralä, _वाटर, --, --, 
   {{0xdb001572,0x00000000,0x00000000,0x00000000}},	// [3a860] salä, --, --, --, 
   {{0x58f4031c,0x44600120,0xe4fc000d,0xc4c800d1}},	//   _བླགས_, евув, _उछरि_, _ﻗﻪﺗﺌ, 
   {{0x225c0204,0xec100051,0x00000000,0x00000000}},	//   fowk_, _hếch_, --, --, 
   {{0x64884ca5,0xec100051,0x00000000,0x00000000}},	//   _džib, _kếch_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa0880220,0xe3b001d9,0xdb00000f,0x00000000}},	//   ісіз_, _لرِ_, rblê, --, 
   {{0xdb00000f,0xe2b60241,0xec100051,0x00000000}},	//   sblê, _остэ, _lếch_, --, 
   {{0x26c40989,0x11d80597,0xdb020242,0x98a0033f}},	//   šlog_, _دورة_, mblè, szkę_, 
   {{0xd738001f,0x0b880dab,0x8fe001af,0x00000000}},	//   _ከድህነ, йсни_, _зәйҙ, --, 
   {{0x7ae000fb,0x7e8000e5,0x6abc00e5,0x00000000}},	//   _bpnt, _főpo, árfo, --, 
   {{0xfd0cae59,0x7e9401b9,0xca3001ec,0x3ba00092}},	//   نجی_, _فنلر_, _ﺭﺒﺢ_, ለትዮሽ_, 
   {{0x58f4081f,0xdee4007b,0x00000000,0x00000000}},	//   _བླངས_, _تأكي, --, --, 
   {{0xdb0000b5,0x03f00011,0x8b6403ff,0x00000000}},	//   valå, ঘাতী_, _کاشم, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4b0401c0,0x65960243,0x3688004e,0x7bd8011a}},	//   _хялб, дабу, зсун_, _הקוו, 
   {{0x2bd817c6,0x9ba00150,0xc6080154,0x00000000}},	//   ब्रा, _كەۋى, রস্থ_, --, 
   {{0x78600267,0xa8540395,0x00000000,0x00000000}},	// [3a870] rövr, _окич, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x37e979e2,0x3d200248,0x2bd4193d,0x26c400e5}},	//   _སྲིད, _kéwú_, _दाना, álod_, 
   {{0xf1c818fd,0xe73801ee,0x00000000,0x00000000}},	//   كومى_, _геү_, --, --, 
   {{0x69dc0140,0xec100051,0x9f9400c7,0x00000000}},	//   ifse, _xếch_, ҿықә, --, 
   {{0xd0060244,0xdee40305,0x00000000,0x00000000}},	//   деше_, доки, --, --, 
   {{0xde4402d3,0xef180171,0x00000000,0x00000000}},	//   _ንህይወ, _ogļu_, --, --, 
   {{0x69dc0196,0xd34402f2,0x00000000,0x00000000}},	//   jfse, _تیمه_, --, --, 
   {{0xdb020245,0x63a401ab,0x20d04a76,0x8114007b}},	//   mblé, obhn, _समिध, _عذرا, 
   {{0x69dc0373,0x92c00c58,0x9f460246,0xdb020247}},	//   efse, ্বৰ_, _malú_, malú, 
   {{0x69de0248,0x63a40e9e,0x00000000,0x00000000}},	//   ffse, ibhn, --, --, 
   {{0xd9460249,0x27e000a3,0x81a80154,0x00000000}},	//   деми, _abhn_, _খাঁ_, --, 
   {{0xa3cc0490,0xa3bc00dc,0x00000000,0x00000000}},	//   ळला_, _इयं_, --, --, 
   {{0x69dc508f,0xdb000036,0x2bd49417,0xef180171}},	//   afse, hblé, _दाया, _egļu_, 
   {{0x27e001c4,0xcc540375,0x00000000,0x00000000}},	//   _dbhn_, _קבצי_, --, --, 
   {{0xcff404c5,0xec100051,0x00000000,0x00000000}},	//   চায়_, _tếch_, --, --, 
   {{0x2bd40c2e,0x7e780810,0x67340135,0x61f80142}},	// [3a880] _दामा, imup, azzj, ddwl, 
   {{0xd7c8034c,0x6d4401f1,0xdb0115c1,0xd8740150}},	//   _بوده_, _žiak, dalú, _تابب, 
   {{0xdb00000f,0x00000000,0x00000000,0x00000000}},	//   valû, --, --, --, 
   {{0x63a80960,0x63a401e7,0x41e00816,0x00000000}},	//   _đene, abhn, віша, --, 
   {{0x5fc810f7,0x7646024a,0x9f440332,0xcf900014}},	//   _राखल, miiy, _galú_, ن٘ش_, 
   {{0x7526024b,0x76440a56,0x6fb51f54,0x00000000}},	//   myiz, liiy, رمبا, --, 
   {{0xb900025c,0x69dc017a,0x436400d8,0x908002dd}},	//   _ཤཱ_, yfse, _жарн_, _ﺨﺎﺼﺔ_, 
   {{0x64882220,0xe3b000aa,0x7644300b,0x1ce00327}},	//   _užic, _لرې_, niiy, _ྦྱང_, 
   {{0x75242f99,0x01d48d1a,0x0ba802dd,0x409008de}},	//   nyiz, _توقع_, يادى_, _للقر, 
   {{0x92c00729,0x7e780421,0x76440067,0x00000000}},	//   ্বী_, amup, hiiy, --, 
   {{0x75240230,0x7645687a,0x00000000,0x00000000}},	//   hyiz, kiiy, --, --, 
   {{0x27e00280,0xfe40d74f,0x75240369,0x69dc0112}},	//   _sbhn_, _инхо, kyiz, ufse, 
   {{0x69dc008c,0x7646024c,0x87e0031c,0x1f800032}},	//   rfse, diiy, _སིདྡ, _иҫән, 
   {{0x601c0066,0x68fc9e56,0x00000000,0x00000000}},	//   _jèmp, rvsd, --, --, 
   {{0x290c00a8,0x601c04fb,0x36d4ec45,0x76440009}},	//   ţea_, _mèmp, корр, fiiy, 
   {{0x601c00f2,0x76450074,0x5dac00fe,0x00000000}},	//   _lèmp, giiy, _গাৱঁ, --, 
   {{0xe3c40184,0x06380092,0x00000000,0x00000000}},	// [3a890] ереү, _ከእውነ, --, --, 
   {{0x81a82158,0x9f440093,0x601c00f2,0xdb000789}},	//   _খাই_, _valú_, _nèmp, valú, 
   {{0x648802d5,0x7646024d,0x463c001f,0x7524a6af}},	//   _džia, biiy, _ተገልጿ, ayiz, 
   {{0xdb02024e,0x75240796,0x76440009,0xeaec0037}},	//   talú, byiz, ciiy, _जनैत_, 
   {{0xdb000a40,0x75240526,0x661c00a2,0x9f4401e7}},	//   rblé, cyiz, _iosk, _ualú_, 
   {{0x661c5e52,0xdb000221,0x9f4401bf,0xc3e0104e}},	//   _hosk, sblé, _kalø_, _шөбһ, 
   {{0x661c0664,0x21281fe6,0x87e0031c,0x00000000}},	//   _kosk, šah_, _སིནྡ, --, 
   {{0x6446024f,0x661c049b,0x7e780421,0x6d5c1432}},	//   lihi, _josk, umup, ğran, 
   {{0x6444023a,0xad5801c6,0xdb0003b2,0xd7381ef7}},	//   oihi, дрэх_, lalø, _ከድሕነ, 
   {{0x64460250,0x6288062c,0x1a640214,0x76460251}},	//   nihi, _hieo, کیبی_, ziiy, 
   {{0x661ce7d9,0xf9d4022e,0x76440a49,0x00000000}},	//   _oosk, _qog双, yiiy, --, 
   {{0x64460252,0x661d4d5b,0x4ef8011a,0x7644058a}},	//   hihi, _nosk, _מהעו, xiiy, 
   {{0x64460253,0x1d085c25,0xae040220,0x3e540356}},	//   kihi, _хели_, _جونى, găte_, 
   {{0x64460254,0x752400ca,0xdb000162,0x00000000}},	//   jihi, vyiz, kalø, --, 
   {{0x64448e5f,0x75240007,0x2bd5c44f,0x76460255}},	//   dihi, wyiz, _दाता, tiiy, 
   {{0x62880034,0x2b1c0316,0x958438ab,0xa3dc01ad}},	//   _nieo, महरु_, елбе, थ्स_, 
   {{0x64460256,0x661c7726,0xf48443fb,0x76460257}},	// [3a8a0] fihi, _dosk, ناطی, riiy, 
   {{0x64460258,0x62880421,0x76460259,0xe8e8009f}},	//   gihi, _aieo, siiy, _آريو_, 
   {{0x752400ca,0x9f4403b2,0x5fc80210,0x94c801e2}},	//   syiz, _galø_, _राजल, غاړې_, 
   {{0x09c43fae,0x601c0268,0x76440a63,0x672103bd}},	//   ষ্ঠা, _sèmp, qiiy, älje, 
   {{0x47b06569,0x6446025a,0x92c00eac,0x6288017a}},	//   _জাতী, bihi, ্বে_, _dieo, 
   {{0x661c0030,0x6446025b,0xc100009a,0xa4900345}},	//   _zosk, cihi, اووي, _ئیلت, 
   {{0x62880093,0x3e540356,0xe1ec010a,0x00000000}},	//   _fieo, zăte_, _кӳ_, --, 
   {{0x0d3c02d3,0x00000000,0x00000000,0x00000000}},	//   _ክትፈል, --, --, --, 
   {{0x601e025c,0xed5001ed,0x2bd40a8a,0x1d8403e6}},	//   _tèmp, جھا_, _दादा, نگهێ, 
   {{0x217401f0,0x00000000,0x00000000,0x00000000}},	//   _руср, --, --, --, 
   {{0xaa590aff,0x64880010,0x2ca00327,0x00000000}},	//   дину_, _ožin, _ħidu_, --, 
   {{0x6446025d,0xadf439a1,0xb7d000eb,0xc0cc0092}},	//   zihi, _आसिन_, াজোট, ጣጣም_, 
   {{0x661e025e,0x64440a81,0x00000000,0x00000000}},	//   _rosk, yihi, --, --, 
   {{0x661c06a3,0x6446025f,0x00000000,0x00000000}},	//   _sosk, xihi, --, --, 
   {{0x661c23e2,0xadf409d9,0x64460260,0x00000000}},	//   _posk, _आसान_, vihi, --, 
   {{0x661c8bd2,0x64460261,0xdb000162,0x4430031c}},	//   _qosk, wihi, valø, whx_, 
   {{0x03c60262,0x3b800166,0x44300fac,0xb60400d7}},	// [3a8b0] есем, _иләг, thx_, ášat, 
   {{0x661e0263,0x6f040051,0x00000000,0x00000000}},	//   _wosk, ́ica, --, --, 
   {{0x64460264,0x00000000,0x00000000,0x00000000}},	//   rihi, --, --, --, 
   {{0xf36400f7,0x3e7000e4,0x65940139,0xa5c42f89}},	//   утун, kãta_, _шаму, _шөге, 
   {{0x25aa0265,0x64460266,0x44300175,0x99900419}},	//   mbal_, pihi, phx_, _umyť_, 
   {{0x25aa0267,0x628801a4,0xe37400f7,0x64440067}},	//   lbal_, _wieo, _алгы, qihi, 
   {{0x645401f5,0x25a800a3,0x628801f4,0x33580064}},	//   _ijzi, obal_, _tieo, _зарэ_, 
   {{0xf1d81b76,0xa0c400e3,0xa3dc00cd,0x254401e1}},	//   _डायन, _ليرو, थ्र_, _ńgẹṣ, 
   {{0x60f80108,0xa2cc00cd,0x00000000,0x00000000}},	//   _юная_, दूर्, --, --, 
   {{0x0d203baf,0x0c200276,0x69d800a2,0x80a000f1}},	//   рүшү, имын, _öwej, _لمړن, 
   {{0xc0b802d3,0x25aa0268,0x4aa40139,0x3eb000e4}},	//   ደፈራ_, kbal_, ккэн_, ñatĩ_, 
   {{0x25a802fb,0x0dd800f1,0x2c700ca8,0x00000000}},	//   jbal_, _يانګ_, bàdo_, --, 
   {{0x25a9511b,0x91b80375,0xb7b400db,0x00000000}},	//   dbal_, ומרי, лөнч, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x1a64f061,0x25a8017a,0x648803ef,0x108807d2}},	//   _لیدی_, fbal_, _ažio, _ﺗﻮﺯﯨ, 
   {{0x25a945fe,0xab840cc9,0x00000000,0x00000000}},	//   gbal_, _сучк, --, --, 
   {{0xdb0001e7,0x00000000,0x00000000,0x00000000}},	// [3a8c0] iblí, --, --, --, 
   {{0x64880006,0x25aa0269,0xfa0400eb,0xc1c801ec}},	//   _džio, abal_, _উকিল_, _ﻗﺩﺭﺍ, 
   {{0x2bd429da,0x25aa026a,0xddc80010,0x59b4012d}},	//   _दासा, bbal_, dmež, _अजार, 
   {{0x64881050,0x10a410ae,0x2f1412d7,0xdb000118}},	//   _užin, видн, ғдиё, jblí, 
   {{0x3a200120,0x00000000,0x00000000,0x00000000}},	//   _moip_, --, --, --, 
   {{0x03a2026b,0x00000000,0x00000000,0x00000000}},	//   _виро, --, --, --, 
   {{0x0442026c,0x6d5c5775,0x6e9401e2,0x00000000}},	//   _терн, ğram, دلبا, --, 
   {{0x2bd40316,0x9e94036b,0xadf4009b,0x37b800eb}},	//   _दाहा, داوچ, упиш, _জাফর, 
   {{0x9f480122,0xfe6c02ef,0x3cb06c15,0x9d640014}},	//   čkám_, غدى_, айыр, ُنى۪, 
   {{0xe0d00014,0xadf407f7,0x25a86b92,0xcf78cfad}},	//   _دزِ_, _आसवन_, zbal_, _قصاص_, 
   {{0x25aa026d,0x69d8010e,0xd5b000cd,0xabac0150}},	//   ybal_, _öwek, जराज, _ﺳﯘﻋﺎ, 
   {{0x7b6008e2,0x3a200363,0x6d440024,0x2bd41100}},	//   ртье, _coip_, _žiau, _दावा, 
   {{0x9f440232,0xdb000306,0x00000000,0x00000000}},	//   _malý_, malý, --, --, 
   {{0x25a801f5,0x00000000,0x00000000,0x00000000}},	//   wbal_, --, --, --, 
   {{0xdb2403e6,0x648800ef,0x0ae8009f,0x00000000}},	//   _مووی, _džil, _آرتي_, --, 
   {{0xb5a6026e,0xdb00cbae,0x32dc011f,0x25a801c7}},	//   ируй, nalý, díy_, ubal_, 
   {{0x25aa026f,0xc7c40139,0x61fc032e,0x00000000}},	// [3a8d0] rbal_, _исни, _ósli, --, 
   {{0x23b4005e,0x25aa0270,0x00000000,0x00000000}},	//   اماس, sbal_, --, --, 
   {{0x25a84fa5,0xf485be87,0xdb0005b6,0x00000000}},	//   pbal_, рутн, kalý, --, 
   {{0x26d20271,0x25a9da91,0x00000000,0x00000000}},	//   muzo_, qbal_, --, --, 
   {{0x26d20272,0xdb0000a2,0x00000000,0x00000000}},	//   luzo_, dalý, --, --, 
   {{0x2a6801e3,0x00000000,0x00000000,0x00000000}},	//   _lkab_, --, --, --, 
   {{0x9f0403e6,0x2eb4010b,0xca640092,0xdb00013a}},	//   اوبو, асыс, ደለንም_, falý, 
   {{0x2a68009a,0xaf3c0023,0x7e7c00d1,0xdb000432}},	//   _nkab_, _ክንምለ, _ﺧﺎﺗﺎ_, galý, 
   {{0x26d06ca0,0x712407d2,0x21540153,0x00000000}},	//   huzo_, _پىلم, _скаў, --, 
   {{0x62960273,0x26d20274,0x2a6a0275,0x63b40219}},	//   _kuzo, kuzo_, _akab_, _jezn, 
   {{0x2bd60276,0x9b45988a,0x63b5738a,0x193c02d3}},	//   _दारा, انجو, _mezn, _ኣስመሮ, 
   {{0x62960277,0x63b40369,0x26d0013e,0x6f1c01ab}},	//   _muzo, _lezn, duzo_, _àrca, 
   {{0x62960278,0x4a404316,0x26c400e5,0xdb0000a2}},	//   _luzo, сняв, álon_, lalü, 
   {{0x26d05936,0x62940489,0xdde000d7,0x00000000}},	//   fuzo_, _ouzo, _šuňa, --, 
   {{0xdb0000c5,0x26d00a1d,0x1ae52632,0x00000000}},	//   nalü, guzo_, _сойм, --, 
   {{0x67203894,0x9f4402f0,0x6489f0df,0x00000000}},	//   älja, _haló_, _džim, --, 
   {{0x63b40598,0x629405f5,0x9f44011f,0x1a640517}},	// [3a8e0] _bezn, _auzo, _kaló_, _لیگی_, 
   {{0x26d08cdb,0x6294dfec,0x63b40960,0x91e4037e}},	//   buzo_, _buzo, _cezn, _chのs, 
   {{0xd62813dc,0x26d0da30,0x63b4054e,0x81a800cc}},	//   _зоне_, cuzo_, _dezn, _খাজ_, 
   {{0x78a41529,0x62940165,0xab9c001f,0xc1a401ec}},	//   _ktiv, _duzo, ወስደው_, _ﺷﯩﺮﺍ, 
   {{0xf4841b8f,0xdb000122,0x2bd402e5,0xddc80030}},	//   _ناسی, valý, _दाला, mieň, 
   {{0xd4681e35,0xdb0003b2,0x17c400fe,0x00000000}},	//   _чиге_, naló, শ্ৰি, --, 
   {{0x62960279,0xd370038b,0x3e540083,0x64880306}},	//   _guzo, _طهر_, wăta_, _ožij, 
   {{0x7bc00381,0x067c005e,0x78a40857,0x00000000}},	//   _adnu, _ﺣﺎﻟﯩ, _otiv, --, 
   {{0x8fa481a0,0x78a6027a,0x9f45d0ac,0x63b40007}},	//   _базе, _ntiv, _baló_, _yezn, 
   {{0x2a68037e,0x09bc42e3,0x9f445a8b,0x26d000ca}},	//   _skab_, ्ल्य, _caló_, yuzo_, 
   {{0x78a6027b,0x26d0009a,0x6a1457c6,0xaa5414b3}},	//   _ativ, xuzo_, амну, ивош, 
   {{0x26d0cf3e,0x7bc0003e,0x1ea886bf,0x3e54054e}},	//   vuzo_, _ednu, _شامي_, păta_, 
   {{0xe8940124,0x26d00161,0xdb02027c,0x00000000}},	//   рагь, wuzo_, faló, --, 
   {{0x26d2027d,0x63a8009b,0xdb0003b2,0x00000000}},	//   tuzo_, _đeno, galó, --, 
   {{0x27f0083a,0x78a6027e,0x63b46517,0x9f4400a3}},	//   rezn_, _etiv, _rezn, _halò_, 
   {{0x63b6027f,0x62960280,0x26d20281,0x2a680589}},	//   _sezn, _ruzo, ruzo_, _ukab_, 
   {{0x9f460282,0x26d20283,0xa4d4187f,0xe8680092}},	// [3a8f0] _jalò_, suzo_, розі, ደረግም_, 
   {{0x68ee0284,0x290a0285,0xdb000a90,0x9f4405d5}},	//   _ipad, _iraa_, caló, _palü_, 
   {{0x64880006,0x29080363,0x9f4401e1,0x6388013e}},	//   _užim, _hraa_, _lalò_, траҳ_, 
   {{0x68ec0a2e,0xa4d4160b,0x9f4404cc,0xdb0124b2}},	//   _kpad, _комі, _valü_, valü, 
   {{0x6f0a0286,0x63b40010,0xe3e800ec,0x55b8011a}},	//   _ardc, _tezn, _لکان_, _במרו, 
   {{0x62960287,0x68ec04ba,0xb3cc0154,0x648801ef}},	//   _tuzo, _mpad, র্বজ, _mžik, 
   {{0x44200354,0xdb0005da,0x00000000,0x00000000}},	//   _ioj_, halò, --, --, 
   {{0x44220288,0x9f440137,0x8f500131,0x8d9000d1}},	//   _hoj_, _saló_, تنىش, يلىش, 
   {{0x44200e37,0x61ea0289,0x5c54040e,0x9f44c7cc}},	//   _koj_, _ibel, итоф, _calò_, 
   {{0x442004b9,0x1c46028a,0x61e80165,0xe8d801fb}},	//   _joj_, рном, _hbel, _ngự_, 
   {{0x4420d2e7,0x9f4477d6,0x2909c913,0xdb0001ed}},	//   _moj_, _való_, _araa_, való, 
   {{0x44219456,0x9f440395,0x290800ad,0x61e80327}},	//   _loj_, _falò_, _braa_, _jbel, 
   {{0x61ea028b,0x26c006d6,0xdb02028c,0x6720049f}},	//   _mbel, _avho_, taló, äljn, 
   {{0x44200190,0x290849dc,0x7bc00254,0x00000000}},	//   _noj_, _draa_, _udnu, --, 
   {{0x61ea028d,0x68ec0086,0x2908062c,0x7c209a14}},	//   _obel, _epad, _eraa_, _ionr, 
   {{0x61e801f2,0x290a028e,0x64880308,0x78a41418}},	//   _nbel, _fraa_, _užij, _ttiv, 
   {{0x09dc0729,0x78a6028f,0x29082a84,0xe9a80451}},	// [3a900] _বোকা, _utiv, _graa_, _صدين_, 
   {{0x44200190,0x7c200407,0x2ca000ae,0x00000000}},	//   _coj_, _jonr, _éide_, --, 
   {{0x44220290,0xe3b00014,0x55e4004e,0x61e801ef}},	//   _doj_, سرٕ_, _конб, _bbel, 
   {{0x27ec04b9,0x91e57264,0xdcf4012c,0xddc801e4}},	//   đene_, роде, íběh, fleŭ, 
   {{0x2eec2165,0x6f086b07,0x442001e4,0x61e801c7}},	//   _spdf_, _srdc, _foj_, _dbel, 
   {{0x61ea0291,0x44200007,0x7c220292,0x2d98012c}},	//   _ebel, _goj_, _nonr, ěrem_, 
   {{0x9f460293,0xdc2c0342,0x1ce00327,0xc1dc0150}},	//   _salò_, _sığd, _སཱུ_, _ﺇﻋﺩﺍ, 
   {{0x44200211,0x7c2036f4,0x61e90d3f,0x940801f9}},	//   _zoj_, _aonr, _gbel, _होतच_, 
   {{0x7c220294,0x44219dcb,0xe8189f23,0x06340a1e}},	//   _bonr, _yoj_, दामा_, ינקט_, 
   {{0x29080ba7,0x2eec009f,0x4420002e,0x61e8022e}},	//   _rraa_, _tpdf_, _xoj_, _zbel, 
   {{0x68ee0295,0x64880fcf,0x29041a5a,0x2eed8de2}},	//   _spad, _džih, ālam_, _updf_, 
   {{0x8d860296,0x29080115,0x26c47448,0xdb0035b2}},	//   _кулд, _praa_, álom_, talò, 
   {{0x6f0000d2,0x00000000,0x00000000,0x00000000}},	//   bábá, --, --, --, 
   {{0x26c40552,0x290a0297,0x68ec19d6,0xc7b8005b}},	//   šlom_, _vraa_, _vpad, ъём_, 
   {{0x44220298,0x68ec0034,0xbc780375,0x99900432}},	//   _roj_, _wpad, _שנות, _onyň_, 
   {{0x44220299,0x290802a4,0x00000000,0x00000000}},	//   _soj_, _traa_, --, --, 
   {{0x68ec08ec,0x44200457,0x290991f8,0x67d41c90}},	// [3a910] _upad, _poj_, _uraa_, _лопу, 
   {{0x61e806df,0x601c0100,0x99900432,0x8e3c01a9}},	//   _sbel, _fèmy, _anyň_, _istе_, 
   {{0x4422029a,0xe4b80220,0xa5c40209,0x2c7008c2}},	//   _voj_, _әлгі_, _гөзе, ràdh_, 
   {{0x4422029b,0x25ac010b,0x00000000,0x00000000}},	//   _woj_, _ýel_, --, --, 
   {{0x4422029c,0x181805ae,0x00000000,0x00000000}},	//   _toj_, _شریک_, --, --, 
   {{0x02a400d8,0x00000000,0x00000000,0x00000000}},	//   _врам, --, --, --, 
   {{0x24980ac5,0x7c200129,0x61e80327,0x3eb00ba1}},	//   _husm_, _ronr, _tbel, èxt_, 
   {{0x7c22029d,0x61ea029e,0x24900205,0x00000000}},	//   _sonr, _ubel, _hizm_, --, 
   {{0xdd92029f,0x1c4602a0,0x00000000,0x00000000}},	//   _ہوا_, йним, --, --, 
   {{0x5ba87cf4,0xdfd00220,0xddc80311,0x7c20047e}},	//   ыком_, _ءيا_, fleţ, _qonr, 
   {{0x26c408ad,0xfe7429db,0x7c200156,0x1b482ccd}},	//   šloj_, _күк_, _vonr, узни_, 
   {{0x25b8013a,0x00000000,0x00000000,0x00000000}},	//   _nesl_, --, --, --, 
   {{0x1ce0031c,0x48e05cfa,0x5d84007b,0xdca40150}},	//   _སཱི_, появ, _الشل, _уали, 
   {{0x07a02505,0xc7a009a5,0x7d1801d4,0xddc80356}},	//   зарн, зирк, mxus, bleţ, 
   {{0xf1d8060e,0x24980112,0xfb8402d5,0x7d1801a9}},	//   _डालन, _ausm_, _тыдн, lxus, 
   {{0x249000ef,0xe7ec0037,0x00000000,0x00000000}},	//   _aizm_, _चउथा_, --, --, 
   {{0x7d18016c,0x00000000,0x00000000,0x00000000}},	// [3a920] nxus, --, --, --, 
   {{0xdce8005f,0xe8180073,0xdb008ecc,0xdb0c01e1}},	//   dceļ, दाणा_, rblæ, _ńkùs, 
   {{0x52753443,0xd8750d6c,0xc0b80b82,0xdb00005c}},	//   буду, _پاکب, _ሳህለ_, sblæ, 
   {{0x6838026c,0x7d080166,0x8714011a,0xdb00002f}},	//   _vìde, _orgs, _הקטע_, mblä, 
   {{0x10482d29,0xd25001d3,0xdb00002f,0x00000000}},	//   ляки_, _ہنس_, lblä, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe8183174,0xd25001d9,0x7d0803ac,0xdb000e78}},	//   दाता_, _فنس_, _args, nblä, 
   {{0x25b80139,0x00000000,0x00000000,0x00000000}},	//   _xesl_, --, --, --, 
   {{0x09dc015b,0xd024a9c2,0xdb000112,0x90c401af}},	//   _বোঝা, _лмай, hblä, _ыбае, 
   {{0x26c40e33,0x2fd80162,0x0eb847c5,0x12c000d1}},	//   álok_, _ørg_, _буды_, ﺯﮔﻪﺭ, 
   {{0x7d081af3,0x98ac0607,0x00000000,0x00000000}},	//   _ergs, _āfā_, --, --, 
   {{0xc3300bd4,0xcce443f3,0x6a580115,0xf1d82314}},	//   פור_, _هستي, rĉfo, डलिन, 
   {{0x9e640597,0x09481679,0x648805ce,0xac18074d}},	//   _بالن, учни_, _iživ, _волу_, 
   {{0x6d5c0e78,0xddc818e2,0x00000000,0x00000000}},	//   ßrau, mleš, --, --, 
   {{0x6d40002f,0xdb00002f,0xc674007b,0x6fe0000d}},	//   lzma, gblä, مطرب, _नानं, 
   {{0x39645f5e,0x00000000,0x00000000,0x00000000}},	//   éssé_, --, --, --, 
   {{0x6d4202a1,0x6fc80490,0xe5541fbe,0x34941b0a}},	// [3a930] nzma, रणां, цкањ, заур, 
   {{0xaca401f2,0xdb005b00,0x10e002dd,0x648801ef}},	//   _adịz, bblä, _ﺍﺴﺘﺨ, _lživ, 
   {{0x6d40020c,0x37a82cc8,0xe1d801ec,0x00000000}},	//   hzma, _утын_, иджі_, --, 
   {{0x622400d1,0xee8c07d2,0x63aa02a2,0x00000000}},	//   غىشل, _ﺗﺎﻻﻥ_, _şend, --, 
   {{0x22a00024,0x7d180548,0x21680063,0xa1580107}},	//   _dėka_, xxus, јили_, шаду_, 
   {{0x9ea8ae46,0x1ef800c6,0xf7700046,0xb97c0a7c}},	//   авка_, لعبة_, _تاۋ_, אנדי, 
   {{0x623405cc,0x7d0804cc,0xd24c01ed,0x6304bd96}},	//   _деву, _srgs, رچہ_, _بوزل, 
   {{0x823602a3,0xb8fc031c,0x7d1801c4,0xde2801c0}},	//   _ارسا, _ལྀ_, txus, ржид_, 
   {{0xddc8151c,0x9f4404cc,0x614000db,0x648a02a4}},	//   gleš, _nalö_, _تۉشە, _dživ, 
   {{0x7d1a02a5,0xeea800d1,0x00000000,0x00000000}},	//   rxus, штәк_, --, --, 
   {{0xee3801c6,0xdb000254,0x00000000,0x00000000}},	//   рнө_, halö, --, --, 
   {{0xdb001876,0x198801d5,0xddc80171,0x00000000}},	//   kalö, ибни_, bleš, --, 
   {{0xdd98007f,0xdb00007c,0x6d40012d,0xfbc00154}},	//   ndňm_, dblå, czma, ্ভবত, 
   {{0xed880022,0xdb00002f,0x00000000,0x00000000}},	//   _усхк_, tblä, --, --, 
   {{0x9aa40345,0x00000000,0x00000000,0x00000000}},	//   _بمبو, --, --, --, 
   {{0x27ec04b9,0x443001f5,0xdb000112,0xf1d8216a}},	//   đena_, ekx_, rblä, _डाइन, 
   {{0x142602a6,0x9424fc32,0x657c0306,0xd3981fbe}},	// [3a940] одам, омае, _czsh, ањеш_, 
   {{0x26d007f5,0x64880064,0x69d8010e,0x00000000}},	//   brzo_, _ožiu, _öwer, --, 
   {{0x6d406637,0xdb0001e3,0x4c38010f,0x00000000}},	//   zzma, bblå, סגעצ, --, 
   {{0x6d4202a7,0x63a80139,0x00000000,0x00000000}},	//   yzma, _ğene, --, --, 
   {{0x09c40729,0x63a9ec65,0xc75c0092,0xdb00000d}},	//   ষ্কা, _şene, _ደስተኛ_, malõ, 
   {{0x4ea602a8,0x4430282c,0xdb000037,0xf424009d}},	//   ориа, ckx_, lalõ, _эзгү, 
   {{0x290c1682,0xb8dc025c,0xf1d81b87,0x6d400210}},	//   ̭ea_, _ཅས_, _डाऊन, wzma, 
   {{0xc0b82295,0x64880006,0x6d4202a9,0x60cc7a23}},	//   ደለም_, _džiu, tzma, šama, 
   {{0x648909de,0x6d40007f,0x00000000,0x00000000}},	//   _vživ, uzma, --, --, 
   {{0x7ae000fb,0x0b88277c,0x6d4202aa,0xbc6400c6}},	//   _bqnt, исни_, rzma, يمين_, 
   {{0x7a380165,0x6d401790,0x1ea83592,0x8fd001ee}},	//   _sãta, szma, _هاني_, _еҙҙә, 
   {{0x64888d7b,0x3c384aee,0xaa580131,0x7a380165}},	//   _uživ, _rêve_, симу_, _pãta, 
   {{0x320602ab,0x00000000,0x00000000,0x00000000}},	//   _mamy_, --, --, --, 
   {{0x320602ac,0xdb000254,0x6e440066,0x00000000}},	//   _lamy_, valö, _بنچم, --, 
   {{0x26c602ad,0x8b643378,0x00000000,0x00000000}},	//   élo_, _باشم, --, --, 
   {{0x26cc04b9,0xdb0202ae,0xc60800fe,0x00000000}},	//   čeo_, talö, ৰস্থ_, --, 
   {{0x98a0068f,0x6a7c0077,0x4430037e,0xdb005794}},	// [3a950] tyką_, céfa, tkx_, rblå, 
   {{0xf1d87df0,0xdb0202af,0x69de02b0,0x63a800ee}},	//   _डाउन, ralö, lgse, _şenb, 
   {{0x27e0004e,0xfd480882,0xdb0202b1,0x44300582}},	//   _ichn_, _droṇ, pblå, rkx_, 
   {{0x3204d4dd,0xd5ac0014,0xdb0000d8,0x201801d3}},	//   _camy_, _مہِ_, calõ, _ősi_, 
   {{0x69dc01ab,0x32045f0b,0x00000000,0x00000000}},	//   igse, _damy_, --, --, 
   {{0xa0680640,0xdfd0007b,0xe04400d1,0x61ec00cd}},	//   љака_, ريع_, янли, _śilā, 
   {{0xd00c038b,0x21344dd9,0xf2c4011c,0x00000000}},	//   طلي_, _şahı_, _остн, --, 
   {{0xe29804a9,0xb2e801d9,0x1d240d45,0x63a40210}},	//   _ваң_, _گٹہٕ_, змим, lchn, 
   {{0x63a401c3,0x00000000,0x00000000,0x00000000}},	//   ochn, --, --, --, 
   {{0x63a602b2,0x69de02b3,0x9f44004d,0x5f8002dd}},	//   nchn, egse, _balô_, _كۇشە, 
   {{0x63a4fac1,0x20040607,0x4be40271,0xef1800d8}},	//   ichn, _iali_, سکوپ_, _ммѕ_, 
   {{0x200602b4,0xae040075,0x69dcb499,0x6a7c0098}},	//   _hali_, _يولى, ggse, téfa, 
   {{0x200602b5,0xed00035b,0xdb000254,0x8e5400df}},	//   _kali_, _аҟын, valõ, _צינג_, 
   {{0x200602b6,0xfbd1ba2b,0x69dc257c,0x79a002dd}},	//   _jali_, _آتش_, agse, _ﺍﯞﯨﺰ_, 
   {{0x63a40306,0x9c7c002e,0xe7ec0037,0x00000000}},	//   dchn, ltōo, _चउरा_, --, 
   {{0x200602b7,0x63a40221,0x60d80083,0x6a7c06af}},	//   _lali_, echn, kuwm, péfa, 
   {{0x4a540375,0x6bd40046,0x32040210,0x3e54054e}},	// [3a960] _משקל_, _ءتۇر, _ramy_, găti_, 
   {{0x32041311,0x200602b8,0x224c0ac5,0xdb00000d}},	//   _samy_, _nali_, _amek_, salõ, 
   {{0xe4d42544,0x60d801f5,0x479808a8,0x53e00d2e}},	//   كتەب, euwm, _לייס, _पाठश, 
   {{0x200602b9,0x61f806a3,0xd18400ee,0x63a41554}},	//   _aali_, gewl, плей, achn, 
   {{0x20049bbe,0x26c401f1,0xdb00067c,0x41c00050}},	//   _bali_, álov_, sclè, رٲوِ, 
   {{0x200602ba,0x94240372,0x224e02bb,0xceb800ea}},	//   _cali_, _эмге, _emek_, бљи_, 
   {{0x200602bc,0x320403d1,0x648802f0,0x520800ec}},	//   _dali_, _tamy_, _vžit, _ٿيءُ_, 
   {{0x7dc004a9,0xc3200a89,0x672001f4,0x00000000}},	//   ىقىن, _ямск, älji, --, 
   {{0x4f9402dd,0x00000000,0x00000000,0x00000000}},	//   _ереу, --, --, --, 
   {{0x200602bd,0x6488b949,0x41000212,0x224c00a2}},	//   _gali_, _užit, _язув, _zmek_, 
   {{0xe9f802bf,0x3b50084c,0xdb1401e1,0x00000000}},	//   онні_, екэр, _èbìt, --, 
   {{0x200602be,0x4dd402dd,0x27e00036,0x9e0400d4}},	//   _zali_, _ءتاس, _schn_, _очіл, 
   {{0x200602bf,0x69de02c0,0xeb341b92,0x68fc01f5}},	//   _yali_, rgse, سىڭد, uwsd, 
   {{0x27ec0bb8,0x200401a9,0x61f8033f,0x7c80026b}},	//   đeno_, _xali_, zewl, _пуще, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf4a803f4,0x3e540356,0x63a40042,0x00000000}},	//   _ওয়েব, tăti_, wchn, --, 
   {{0x6a7c28f2,0x69ce02c1,0x78b002fb,0x224c00a2}},	// [3a970] léfo, _idae, čivý, _rmek_, 
   {{0x387801ab,0x224c007c,0x63a4002f,0x9f4c0419}},	//   clrr_, _smek_, uchn, čnúc_, 
   {{0x200602c2,0x63a400a9,0x7f400175,0x9424075e}},	//   _rali_, rchn, xznq, بولۇ, 
   {{0x63a602c3,0x69cc0369,0x26c40306,0x6154431a}},	//   schn, _jdae, álou_, ونائ, 
   {{0x200602c4,0x69cd965c,0x61f80142,0x63a4012d}},	//   _pali_, _mdae, rewl, pchn, 
   {{0x2004102c,0xfc04015b,0xdb00004a,0x60d80309}},	//   _qali_, _লক্ষ_, sclé, ruwm, 
   {{0x200602c5,0x224c022e,0x9f4c03e0,0x4244010a}},	//   _vali_, _tmek_, _ünün_, _ехаб, 
   {{0x20042e95,0x69cc0207,0x6a7c0268,0x224e02c6}},	//   _wali_, _ndae, défo, _umek_, 
   {{0x200602c7,0xf1c81183,0xb28400cf,0x1d083e4f}},	//   _tali_, _رولى_, _чырк, цепи_, 
   {{0x20040421,0x69ce02c8,0x5ac8050b,0x60c80e04}},	//   _uali_, _adae, олом_, _ivem, 
   {{0x7d080066,0x00000000,0x00000000,0x00000000}},	//   _گزاف_, --, --, --, 
   {{0x999000a2,0x60c806be,0x9d1801f4,0x00000000}},	//   _alyš_, _kvem, _моет_, --, 
   {{0x69cc00a9,0xe8f40032,0xb4cc000d,0xaac40133}},	//   _ddae, еһы_, _रटे_, وتێن, 
   {{0x7bc4008c,0xdb0003b2,0x4c98011a,0x00000000}},	//   ðjud, kblø, _ובסו, --, 
   {{0xc7a202c9,0x3d000034,0x9694009b,0x07a16a45}},	//   тиск, _वनडे_, драш, тасн, 
   {{0x60c80c8c,0x3ddc0086,0xb904015b,0x98a0033f}},	//   _ovem, nguw_, _নন_, zykę_, 
   {{0x09000006,0x63a803e0,0x00000000,0x00000000}},	// [3a980] _апын, _şena, --, --, 
   {{0xe6180364,0x69cc039a,0x1ce0031c,0x973400c0}},	//   одӣ_, _zdae, _སཱན_, _жэмч, 
   {{0x60c80c95,0x98a00024,0xdb000162,0xd629394b}},	//   _avem, vykę_, gblø, _доне_, 
   {{0x47d00154,0x00000000,0x00000000,0x00000000}},	//   দ্দী, --, --, --, 
   {{0x98a00034,0x46440139,0xddc8012d,0x00000000}},	//   tykę_, _цзян_, kieł, --, 
   {{0x60c8151c,0xe3b00014,0x69d40b27,0x00000000}},	//   _dvem, _مرِ_, _भयभी, --, 
   {{0xd37202ca,0x60c832bc,0xda0c52f2,0x926400f1}},	//   _شهر_, _evem, ियात_, _قدرم, 
   {{0x3ddc00e8,0x00000000,0x00000000,0x00000000}},	//   gguw_, --, --, --, 
   {{0xab5c00da,0xed5000dd,0xac94035b,0xfd40009d}},	//   daļa, دھا_, наиш, вээн, 
   {{0x60dc0fac,0xddca02cb,0x00000000,0x00000000}},	//   _åsma, gieł, --, --, 
   {{0xda1803f3,0x60c80e8a,0x03d40375,0x274400e8}},	//   धांत_, _zvem, ווים_, _mëné_, 
   {{0x37b80154,0x9e6418fd,0x33840150,0xabc80150}},	//   _জাগর, _كانن, _ﺩﺍﻤﻲ_, _ﻓﻘﻬﺎ, 
   {{0x3e680f31,0xcd3447e7,0x999002f0,0xebc401ec}},	//   _بجلی_, _تراب, _plyš_, _пәнн, 
   {{0xddc80306,0x00000000,0x00000000,0x00000000}},	//   rleť, --, --, --, 
   {{0x48f8000d,0x00000000,0x00000000,0x00000000}},	//   _लईको_, --, --, --, 
   {{0xe78408ca,0x00000000,0x00000000,0x00000000}},	//   дуғо, --, --, --, 
   {{0x2904005f,0x00000000,0x00000000,0x00000000}},	// [3a990] ālas_, --, --, --, 
   {{0xc6a40276,0xdb00072b,0x00000000,0x00000000}},	//   _орми, tblø, --, --, 
   {{0x60c804b9,0x6489f0f8,0xd9e40073,0xe3c401c6}},	//   _svem, _džip, _कामत_, _үргү, 
   {{0xdb00942c,0x26c40153,0x20d402d2,0x67200254}},	//   rblø, šlos_, _núið_, älju, 
   {{0xf1940212,0xdb0003b2,0xe508009f,0x00000000}},	//   виць, sblø, _عيسو_, --, 
   {{0x9f040597,0xc0c8001f,0xd00413d6,0x25a803e0}},	//   فوتو, _ቢኖር_, ееше_, lcal_, 
   {{0x20d4008c,0x25a8011f,0x6fe00412,0x00000000}},	//   _búið_, ocal_, _नारं, --, 
   {{0x60c802d2,0x00000000,0x00000000,0x00000000}},	//   _tvem, --, --, --, 
   {{0x60c80117,0x25a80076,0x6a7c0129,0x2dac0150}},	//   _uvem, ical_, réfl, _ﺴﺘﻌﻤ, 
   {{0x0d801388,0x25a801ab,0x00000000,0x00000000}},	//   ылын, hcal_, --, --, 
   {{0xab5c005f,0x2eb400c0,0x00000000,0x00000000}},	//   taļa, _асіс, --, --, 
   {{0x65c000d0,0x6734012d,0x00000000,0x00000000}},	//   náhľ, dyzj, --, --, 
   {{0x64480024,0x7e7a02cc,0x61fc0a87,0xb7b400db}},	//   _įein, mlup, _ðslu, көнч, 
   {{0x7e788dbd,0xe3d400bd,0x6734000f,0xec740124}},	//   llup, স্তব, fyzj, _иҿы_, 
   {{0x966410fc,0xcc38010f,0x7ea40139,0x673400a2}},	//   екве, _מעסט, _yıpa, gyzj, 
   {{0x7e795863,0xd1f82440,0x00000000,0x00000000}},	//   nlup, ጋቢት_, --, --, 
   {{0x2c140490,0x7e795953,0xfe6401ec,0x6fe023ef}},	// [3a9a0] _थोडं_, ilup, _ەد_, _नालं, 
   {{0x7e791ca2,0x79840117,0xdebc001f,0x25a96e6d}},	//   hlup, _iziw, _ሳጥን_, acal_, 
   {{0x6734068f,0x76c801d9,0x25a8011f,0xb914002b}},	//   cyzj, _تُجہ_, bcal_, _apaḥ_, 
   {{0x25a81368,0x518602cd,0xc95407d6,0xddc8012d}},	//   ccal_, нула, _آلیش_, nień, 
   {{0x76440004,0x7e78014b,0x3f1001ec,0x00000000}},	//   mhiy, dlup, ғдыс, --, 
   {{0x7984009a,0xfc2400c6,0xab04002b,0x80a02073}},	//   _mziw, _صح_, _chṛṇ, دمون, 
   {{0x7644022f,0xd9e40073,0x0364014b,0x00000000}},	//   ohiy, _काढत_, _зирк_, --, 
   {{0x7e7a02ce,0x527458f0,0x764602cf,0x79846ca2}},	//   glup, _чугу, nhiy, _oziw, 
   {{0x798404ba,0x752401a9,0x00000000,0x00000000}},	//   _nziw, nxiz, --, --, 
   {{0x7e78011c,0xab04002b,0x25a98933,0x76440205}},	//   alup, _ghṛṇ, zcal_, hhiy, 
   {{0x764602d0,0x798438f3,0x25a8bff9,0xfb3001c6}},	//   khiy, _aziw, ycal_, гнээ, 
   {{0x67340a85,0x7e7a02d1,0x8d28299f,0xddc8054e}},	//   vyzj, clup, _ноев_, mneş, 
   {{0x764602d2,0xddc80311,0xfd0c00ec,0x6f6c00d1}},	//   dhiy, lneş, _هجو_, ﺴﯩﻐﺎ_, 
   {{0x798602d3,0xc170011a,0x00000000,0x00000000}},	//   _dziw, רחש_, --, --, 
   {{0x63a829ef,0x798602d4,0xddc8033f,0x25a80334}},	//   _şeno, _eziw, bień, tcal_, 
   {{0x76441c06,0xf60801c0,0xddc8012d,0x00000000}},	//   ghiy, нхуй_, cień, --, 
   {{0x25aa02d5,0x7524009a,0x768402dd,0xddc80356}},	// [3a9b0] rcal_, gxiz, уырж, hneş, 
   {{0x7e78009b,0x76440067,0x00000000,0x00000000}},	//   zlup, ahiy, --, --, 
   {{0x7e7a02d6,0x76446a74,0x79840083,0x00000000}},	//   ylup, bhiy, _zziw, --, 
   {{0x764602d7,0xd5f801ec,0x5f0000ab,0xe8180118}},	//   chiy, _قىپش_, _वैष्_, दाका_, 
   {{0x661e02d8,0x660c51c8,0x00000000,0x00000000}},	//   _insk, mdak, --, --, 
   {{0x660e02d9,0x47d000bd,0x10a001b9,0x00000000}},	//   ldak, দ্রী, шишн, --, 
   {{0x7e7a02da,0x22580108,0x00000000,0x00000000}},	//   tlup, _живы_, --, --, 
   {{0x660e02db,0x7e7a02dc,0x00000000,0x00000000}},	//   ndak, ulup, --, --, 
   {{0x660d10ac,0x01c002dd,0x00000000,0x00000000}},	//   idak, _ﺯﻩﻳﻨ, --, --, 
   {{0x70580124,0x7644004c,0x7c800032,0x7e7a02dd}},	//   _заур_, zhiy, ыҫла, slup, 
   {{0x661c0660,0x660c0209,0x62880561,0xa3e803ce}},	//   _onsk, kdak, _kheo, _यान_, 
   {{0x98a4f1d1,0x628805b1,0xae04198a,0x661c05ac}},	//   киме, _jheo, _مومى, _nnsk, 
   {{0x1d087413,0x660e02de,0x76441640,0x62881cf8}},	//   _цели_, ddak, vhiy, _mheo, 
   {{0x661e02df,0x7644009f,0x5c78010f,0x18682cdd}},	//   _ansk, whiy, _קאַה, фаги_, 
   {{0x76440028,0x62880022,0x7bc00356,0xdb000112}},	//   thiy, _oheo, _ienu, nblü, 
   {{0x497044fc,0x7bc202e0,0x660e02e1,0x76440009}},	//   ụtụ_, _henu, gdak, uhiy, 
   {{0x76453a4f,0x7bc202e2,0x7984009f,0x00000000}},	// [3a9c0] rhiy, _kenu, _uziw, --, 
   {{0x7bc202e3,0x660c01e4,0x6444037e,0x6fe000e1}},	//   _jenu, adak, ghhi, _नाइं, 
   {{0x7bc202e4,0x62887ea6,0x660c3a09,0xd20801c0}},	//   _menu, _bheo, bdak, дэлд_, 
   {{0x764602e5,0x78a4102e,0x628a02e6,0xfbc400ec}},	//   qhiy, _kuiv, _cheo, _ھت_, 
   {{0x62881552,0x78a439b2,0x7bc0003a,0xdb00007b}},	//   _dheo, _juiv, _oenu, obló, 
   {{0x7bc079ac,0x2d80038f,0xa3e80b7d,0x78a41c1d}},	//   _nenu, _ġie_, _याय_, _muiv, 
   {{0x661c1b3c,0x2d80b700,0xa490036b,0x628953a2}},	//   _ynsk, _šie_, _ایلت, _fheo, 
   {{0xfe6c819a,0x27ec1326,0x628a02e7,0x7bc1aa3d}},	//   يدي_, đeni_, _gheo, _aenu, 
   {{0x7bc202e8,0x78a40421,0x10a407b5,0x814001d9}},	//   _benu, _nuiv, _ризн, _پنٕن, 
   {{0xe1f000aa,0x7bc202e9,0x660c9c11,0x8af400ac}},	//   _پسې_, _cenu, zdak, _çəkd, 
   {{0x78a40607,0x6a7e02ea,0x660d27bf,0x6aa400f3}},	//   _auiv, léfi, ydak, _čifs, 
   {{0x7bc00af9,0x78a602eb,0xbea00114,0x3b500395}},	//   _eenu, _buiv, _ђачк, ркюр, 
   {{0x6a7c7c92,0x7bc202ec,0x78a602ed,0x660c0254}},	//   néfi, _fenu, _cuiv, vdak, 
   {{0x78a602ee,0x7bc202ef,0xa8843ed0,0x00000000}},	//   _duiv, _genu, السى, --, 
   {{0x660c0209,0x661c0af9,0x8a68036b,0xdd980030}},	//   tdak, _pnsk, _ошиб_, meňa_, 
   {{0x7bc202f0,0x78a602f1,0x660e02f2,0xf64402bf}},	//   _zenu, _fuiv, udak, ахун, 
   {{0x660c30a8,0x62880f7b,0x78a407dd,0x7bc15832}},	// [3a9d0] rdak, _rheo, _guiv, _yenu, 
   {{0x628a02f3,0x29080a4d,0x68ee02f4,0x2e3807ea}},	//   _sheo, _isaa_, _iqad, _défi_, 
   {{0x62880e89,0x78a40196,0x61d8010b,0x36d801c6}},	//   _pheo, _zuiv, емея_, _идээ_, 
   {{0x661cb0e8,0x26c0009a,0xdb00056a,0x660c2994}},	//   _unsk, _iwho_, nclá, qdak, 
   {{0x68ec025c,0xcbe0012c,0x8544c38a,0xf204011c}},	//   _jqad, पलाञ, _рэне, ряхо, 
   {{0x62880374,0xab5c005f,0x290801c3,0x68ee02f5}},	//   _wheo, taļl, _msaa_, _mqad, 
   {{0x9ef400c6,0x7ea40139,0x00000000,0x00000000}},	//   استش, _vıpo, --, --, 
   {{0x2908049b,0x7bc202f6,0xa0c42091,0x6f08010a}},	//   _osaa_, _senu, _ميرو, _dsdc, 
   {{0x7bc037bd,0x417403e6,0x68ec0327,0x7ea40790}},	//   _penu, _شارس, _nqad, _zıpl, 
   {{0x78a602f7,0x61e80165,0x7bc00240,0x3cf0000d}},	//   _ruiv, _hcel, _qenu, _अहीं_, 
   {{0x78a42047,0x290800b4,0x61e8037e,0x68ec0166}},	//   _suiv, _asaa_, _kcel, _aqad, 
   {{0x7bc202f8,0xcf5402e4,0x657c022e,0x1d9c0092}},	//   _wenu, _גבעת_, _oysh, _ሀሳቦች_, 
   {{0x64541cdf,0x78a602f9,0xaa6401e0,0x657c00a2}},	//   _omzi, _quiv, реяһ, _nysh, 
   {{0x7bc202fa,0x1ae45a52,0xded40092,0x78a40051}},	//   _uenu, _бокм, _ራሴን_, _vuiv, 
   {{0x68ed289a,0x2908009a,0xe8182871,0x61ea02fb}},	//   _eqad, _esaa_, दाजा_, _ocel, 
   {{0x78a602fc,0x657c0158,0x645602fd,0x00000000}},	//   _tuiv, _bysh, _amzi, --, 
   {{0xab740014,0xddc800e2,0xcb8800db,0x147400ec}},	// [3a9e0] _مۅیا_, pieņ, _قمۇۇ_, هائج, 
   {{0x61ea02fe,0x657c044e,0xa3e86c95,0x6744002d}},	//   _acel, _dysh, _याण_, útjû, 
   {{0xddc81326,0x3a201af3,0x657c00ad,0xd75801c8}},	//   dlež, _knip_, _eysh, _سجدا_, 
   {{0x645602ff,0x61e86bbf,0x03a0023b,0x10a400d8}},	//   _emzi, _ccel, _ҳиро, гидн, 
   {{0x657c010e,0xe8180073,0x41e400f1,0xc0d00092}},	//   _gysh, दाचा_, ازمې, _የቃል_, 
   {{0x61ea0300,0x03a0013e,0xddc80427,0x00000000}},	//   _ecel, _гиро, glež, --, 
   {{0xa3e80574,0xe8d801f2,0x61e8003a,0xfeb416ac}},	//   _यात_, _izụ_, _fcel, هايت_, 
   {{0x7bc409f3,0x6a7c004a,0x00000000,0x00000000}},	//   ðjun, péfi, --, --, 
   {{0x4f24005e,0x51640953,0x200c01f4,0x00000000}},	//   _әдеб, _сваб, ökiä_, --, 
   {{0x61e80316,0x3cf4007b,0x68ee0301,0x00000000}},	//   _zcel, اعيد_, _rqad, --, 
   {{0x29080194,0x15f400e1,0x63a80205,0xdd980419}},	//   _ssaa_, ुजार_, _şenk, reňa_, 
   {{0xaa581782,0x7b60023a,0x80d84e6d,0xeae40073}},	//   тиму_, стье, _निमे, _कमीत_, 
   {{0xcb440209,0xdb012a61,0x00000000,0x00000000}},	//   _әхли, rclá, --, --, 
   {{0x657c0240,0x25ac012d,0xdb000332,0xdb240133}},	//   _rysh, _żel_, sclá, _چووی, 
   {{0x657c0200,0x6aa80327,0x00000000,0x00000000}},	//   _sysh, qqdf, --, --, 
   {{0xe8d800b4,0x290a0302,0x443c03a2,0x657c00ad}},	//   _azụ_, _tsaa_, _œu_, _pysh, 
   {{0x290a0303,0xa3e809fd,0x67d40209,0x68ec2f0f}},	// [3a9f0] _usaa_, _याद_, _копу, _uqad, 
   {{0x61ea0304,0xf990004b,0x657c3be3,0xa3d40212}},	//   _scel, _ژبی_, _vysh, рожч, 
   {{0x657c0660,0x61e82804,0xf4840006,0x6d5c1b0d}},	//   _wysh, _pcel, сутн, ğray, 
   {{0x27ec098d,0x727c0092,0xab2001e1,0x00000000}},	//   đenu_, _እባክህ_, _yóòò_, --, 
   {{0x6454009a,0x61e802fb,0x625000d0,0xe124defb}},	//   _tmzi, _vcel, kťov, рмли, 
   {{0x64540912,0x44ec0793,0xc87c002f,0x00000000}},	//   _umzi, mü_, buße_, --, 
   {{0x44ee0305,0xf838011a,0xa2940816,0x61e80205}},	//   lü_, רנות_, _ваві, _tcel, 
   {{0x61e82747,0x22580267,0xa1140451,0x00000000}},	//   _ucel, _ösk_, _پوئت, --, 
   {{0x44ee0306,0x1c460307,0x7d2401d3,0x7ea403e0}},	//   nü_, иним, ازعہ_, _kıpk, 
   {{0x2a6a0308,0x16f4031c,0xdb940212,0x00000000}},	//   _ajab_, _བྱའམ_, ишнь, --, 
   {{0x3f650a1b,0xff501f3c,0x5dd40f47,0x44ec0205}},	//   _стаб, _اخذ_, _نقائ, hü_, 
   {{0x44ee0309,0x60ce030a,0x84f400bc,0x00000000}},	//   kü_, šamu, ुबाट_, --, 
   {{0x98a6030b,0x2a680100,0x64880cf4,0x18a5b8ec}},	//   риге, _djab_, _džiz, рагм, 
   {{0x44ec07c5,0xc5f000cc,0x7c8001ee,0x00000000}},	//   dü_, _চোলা_, _ыҫпа, --, 
   {{0x66d8dddc,0xddc8025c,0x00000000,0x00000000}},	//   льтр_, kleż, --, --, 
   {{0x3a200798,0x00000000,0x00000000,0x00000000}},	//   _unip_, --, --, --, 
   {{0x13ea030c,0x1a640214,0x25a83346,0x00000000}},	// [3aa00] кмай_, _میگی_, ادفي_, --, 
   {{0x7d080502,0x61fc05d1,0x00000000,0x00000000}},	//   _msgs, _ısla, --, --, 
   {{0x86b0005e,0x38780200,0x00000000,0x00000000}},	//   _мәті, morr_, --, --, 
   {{0x44ec014a,0xd9e46b9b,0xd5a80037,0x5f182d93}},	//   bü_, कलित_, _कलिज, भिन्_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc4800801,0x38780921,0x2e380036,0xd4680108}},	//   _мляк, norr_, _léft_, _риге_, 
   {{0xd9e402ab,0x3cf0000d,0x00000000,0x00000000}},	//   _कांत_, _अहॉं_, --, --, 
   {{0x7d08007f,0x036402bf,0xddc80034,0x38783b64}},	//   _bsgs, _тиск_, mieś, horr_, 
   {{0xd7c40574,0xfe6c1359,0x63a80205,0x810800f1}},	//   वराच, بدو_, _şeni, _لرلې_, 
   {{0x80d807af,0x00000000,0x00000000,0x00000000}},	//   _निते, --, --, --, 
   {{0xddc80034,0x38780165,0xa3e87347,0x625000d7}},	//   nieś, dorr_, _यास_, rťov, 
   {{0x625001a2,0xdde801f7,0x00000000,0x00000000}},	//   sťov, _مرهه_, --, --, 
   {{0xc9849080,0x2ec40116,0x00000000,0x00000000}},	//   руни, _төһм, --, --, 
   {{0x38780086,0x44ec0c86,0x69240588,0xb86800d8}},	//   gorr_, vü_, амҭа, ајсе_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x44ec2045,0xadf84721,0x00000000,0x00000000}},	//   tü_, ्जिन_, --, --, 
   {{0x3878007c,0xab5c00ef,0x00000000,0x00000000}},	// [3aa10] borr_, daļi, --, --, 
   {{0x44ee030d,0x60dc0fac,0xc7640ef6,0x00000000}},	//   rü_, _åsmi, _ناجى, --, 
   {{0xa2f53ba9,0x44ee030e,0x99940014,0xadf81a4e}},	//   спеч, sü_, _پھێر_, ्जान_, 
   {{0x80d81533,0xb9100521,0x44ee030f,0x1b74010b}},	//   _निदे, _nanị_, pü_, _üýşü, 
   {{0xe3e82172,0x7ea405d1,0x44ec067c,0x00000000}},	//   _مکان_, _tıpk, qü_, --, 
   {{0xb714036b,0xdb00007c,0xa444009f,0x00000000}},	//   _ابیش, mblö, _اَسو, --, 
   {{0x72d493f9,0x41e43334,0x4420058a,0x8bfc0eac}},	//   _морф, _віза, _inj_, ্ঞান_, 
   {{0x7d08089c,0x442003b2,0x00000000,0x00000000}},	//   _psgs, _hnj_, --, --, 
   {{0xb06401d9,0xdb020166,0xdb140ca8,0x387803e0}},	//   _ژھى۪, nblö, _èbút, yorr_, 
   {{0x1c44e542,0xad240075,0x60cc01fa,0x00000000}},	//   сном, زىپى, šams, --, 
   {{0x442003f9,0x38780200,0xda080472,0x00000000}},	//   _mnj_, vorr_, هيده_, --, 
   {{0xd354011a,0xc8d001f9,0x2b18000d,0x80a80118}},	//   מיתי_, _तिखट, _बछरु_, _चढाइ, 
   {{0x44200007,0x387a0310,0xc320015b,0xae700131}},	//   _onj_, torr_, পনটি_, _تۇيغ, 
   {{0xb8d00073,0x6cb400f1,0xdb005804,0x00000000}},	//   _ओढ_, _بلوڅ, dblö, --, 
   {{0x7c206066,0x2ca004cc,0x18a4020a,0x00000000}},	//   _innr, _èida_, раҳм, --, 
   {{0x44200100,0xd1f00023,0x957404f0,0xdb00032e}},	//   _anj_, ጃታት_, бызч, fblö, 
   {{0x442000ad,0xddc80034,0xab5c005f,0x558a0311}},	// [3aa20] _bnj_, wieś, vaļi, убам_, 
   {{0x44220312,0xb4e800bc,0x9814007b,0x80a800c5}},	//   _cnj_, _यमी_, _طبخا, _चढ़इ, 
   {{0x03a1bd80,0xa3e80c70,0x00000000,0x00000000}},	//   чихо, _यार_, --, --, 
   {{0x44200240,0xf1b801e0,0x91e40580,0x00000000}},	//   _enj_, рҡа_, соде, --, 
   {{0xe77801ed,0xc0e00138,0x00000000,0x00000000}},	//   _ملیں_, зочк, --, --, 
   {{0xd250006c,0x6a7c0098,0x670c00e1,0xa0a401ec}},	//   _کنر_, néfr, हिचक_, ішіл, 
   {{0x7ff00597,0x6e940276,0x25b001f4,0x90600137}},	//   سسوا, оику, _ällö_, _ۉچتۇ, 
   {{0x7c2000a3,0x44200240,0x54680b01,0x124401c8}},	//   _annr, _znj_, _раҳм_, _ائسٽ, 
   {{0xfe6c00ae,0x00000000,0x00000000,0x00000000}},	//   عدى_, --, --, --, 
   {{0x6d9c00d0,0x6c541cd0,0x00000000,0x00000000}},	//   jťaž, ікну, --, --, 
   {{0xe3d402f5,0x00000000,0x00000000,0x00000000}},	//   স্কব, --, --, --, 
   {{0xc3306da4,0x16f40489,0x7c200036,0x614000c7}},	//   לות_, _བྱེམ_, _ennr, _хҵәа, 
   {{0x46680b01,0x00000000,0x00000000,0x00000000}},	//   ҳрам_, --, --, --, 
   {{0xc98407d6,0xc86400d8,0xe3cc00eb,0x00000000}},	//   _қуйи, стми, _লাভব, --, 
   {{0x466909f1,0x44200327,0x00000000,0x00000000}},	//   грам_, _rnj_, --, --, 
   {{0x44204653,0xdb0069a9,0x00000000,0x00000000}},	//   _snj_, tblö, --, --, 
   {{0x4421103e,0x6d9c00d7,0x00000000,0x00000000}},	// [3aa30] _pnj_, bťaž, --, --, 
   {{0xdb00f985,0x00000000,0x00000000,0x00000000}},	//   rblö, --, --, --, 
   {{0xe9f807ae,0x983800aa,0xc2e800c6,0xe9740214}},	//   _giả_, _ختيځ_, طعام_, _دهکد, 
   {{0x86040014,0x1aec02f5,0x00000000,0x00000000}},	//   _ابدٕ, _জনমে_, --, --, 
   {{0xd00c004b,0xfdfc0327,0x00000000,0x00000000}},	//   ږلو_, _ཙིཏྟ_, --, --, 
   {{0x02a60313,0x44200263,0xdff400d3,0x9f04036b}},	//   _грам, _unj_, іяль, قوتو, 
   {{0x80d813da,0x8eb0132f,0x00000000,0x00000000}},	//   _निवे, وموش, --, --, 
   {{0xa3e80456,0x00000000,0x00000000,0x00000000}},	//   _याँ_, --, --, --, 
   {{0xf7800327,0x6d9c00d7,0x00000000,0x00000000}},	//   ħħix_, yťaž, --, --, 
   {{0xdfd016ef,0x00000000,0x00000000,0x00000000}},	//   _آيا_, --, --, --, 
   {{0x1a28311b,0x2d80143a,0x00000000,0x00000000}},	//   ажни_, _øien_, --, --, 
   {{0xb51c0fc8,0xdd90129e,0xb0e00b02,0xda580454}},	//   निमय_, _قوا_, _निमग, ррош_, 
   {{0x7e780b91,0xdb020314,0xa2c80b7c,0xa3e8d013}},	//   moup, nclú, हीत्, _यां_, 
   {{0x7e7a0315,0x60dc08fb,0xaac4004b,0x61f80142}},	//   loup, _åsmu, _کتون, hfwl, 
   {{0x07a20316,0xc7a0059f,0x6a7c0098,0xc6100154}},	//   дарн, дирк, réfr, হানা_, 
   {{0x6d9c0419,0x00000000,0x00000000,0x00000000}},	//   sťaž, --, --, --, 
   {{0x80d84d21,0x3da8009e,0x53c828e8,0x95981468}},	// [3aa40] _निषे, _গজাল, игам_, ртву_, 
   {{0x79860317,0x224c0003,0x67540014,0x8400010b}},	//   _iyiw, _ċeka_, _کیفس_, мпуж, 
   {{0x7e780316,0x27e40034,0x1309bced,0x64480153}},	//   koup, ólne_, рней_, _įeit, 
   {{0xd1841436,0x63a803e0,0x00000000,0x00000000}},	//   олей, _şent, --, --, 
   {{0x7e780077,0xd0084b1c,0x998002b5,0x76440009}},	//   doup, иеде_, kekō_, mkiy, 
   {{0x76460318,0x80d84709,0x52080451,0x00000000}},	//   lkiy, _निरे, _ھيءُ_, --, 
   {{0xb8cc025c,0x60cc009b,0x520805d9,0x7e78030a}},	//   _ཕང_, šamp, _پيءُ_, foup, 
   {{0x7984054c,0x76460319,0x7f800131,0xccf80063}},	//   _oyiw, nkiy, بلىن, аћо_, 
   {{0xc6901203,0x7986031a,0x4638008f,0xf8dc012c}},	//   ואה_, _nyiw, שעפע, _बिषय, 
   {{0x7644debb,0x01340375,0xfd0c0451,0xab040055}},	//   hkiy, _ורמת_, ئجي_, _jiṇṇ, 
   {{0x7986031b,0x7646031c,0x7e780ea0,0xcf5806ed}},	//   _ayiw, kkiy, boup, _трач_, 
   {{0x7e7a031d,0x2fcc01fa,0xfe40016c,0x00000000}},	//   coup, _hedg_, _онхо, --, 
   {{0xbe300c75,0x76440067,0xac1832b0,0x00000000}},	//   _تىنب, dkiy, _голу_, --, 
   {{0x79840564,0xf8dc0412,0x6d4003ac,0x00000000}},	//   _dyiw, _बिरय, myma, --, 
   {{0x6d42031e,0x79852590,0x7644058a,0x2918054e}},	//   lyma, _eyiw, fkiy, svsa_, 
   {{0x2d7c00d1,0xfa34007b,0x80d84f76,0x00000000}},	//   ﺧﺸﺎﺵ_, _يريد, _निले, --, 
   {{0x6d42031f,0xe5540798,0x00000000,0x00000000}},	// [3aa50] nyma, чкањ, --, --, 
   {{0xe85402f2,0x64480064,0x00000000,0x00000000}},	//   _رنجد, _įeis, --, --, 
   {{0x7644058a,0x63a82ca8,0x00000000,0x00000000}},	//   bkiy, _şens, --, --, 
   {{0x6d4002d5,0x9f440395,0xddc80356,0x224800e5}},	//   kyma, _oblò_, dieş, óak_, 
   {{0x69cc003a,0x68e801ab,0x7e7a0320,0x27683267}},	//   _meae, àedh, voup, _خشکی_, 
   {{0x6d420321,0x69cce9e3,0xb97c010f,0xd24c0014}},	//   dyma, _leae, בנדי, پچہ_, 
   {{0x7e7862bb,0x64460322,0x8fa01a39,0x00000000}},	//   toup, mkhi, наше, --, 
   {{0x6444014b,0xa4f8025c,0xde28036b,0x69cc7021}},	//   lkhi, _ཕྱོག_, сжид_, _neae, 
   {{0x6d420323,0x11d00451,0x1ea80451,0xdd9001d3}},	//   gyma, _سڪند, جاڻي_, ڈوں_, 
   {{0x64460324,0x79841446,0x69ce0325,0x76460326}},	//   nkhi, _ryiw, _aeae, zkiy, 
   {{0x60c80433,0x79848075,0x7e7921f7,0x62980549}},	//   _hwem, _syiw, poup, omwo, 
   {{0x60c936a8,0x6d420327,0xdd1c0356,0x64444709}},	//   _kwem, byma, câşt, hkhi, 
   {{0x6d4020a2,0x69ce0328,0x76442a87,0xad2400d1}},	//   cyma, _deae, vkiy, _يىمى, 
   {{0x60c8806e,0x79841446,0x7d1a0329,0x628002d2}},	//   _mwem, _vyiw, mvus, _ílof, 
   {{0xcb640d84,0x60c8a6bd,0x7d198259,0x69cc0076}},	//   _наше_, _lwem, lvus, _feae, 
   {{0x69cc01c7,0x60c90592,0x6446032a,0x629801a4}},	//   _geae, _owem, ekhi, jmwo, 
   {{0x76445531,0x7984014b,0x7d180477,0xe4e400d4}},	// [3aa60] rkiy, _uyiw, nvus, дієн, 
   {{0x7646032b,0x00000000,0x00000000,0x00000000}},	//   skiy, --, --, --, 
   {{0x7d18007d,0x6d40068f,0x60c8d773,0x764403e0}},	//   hvus, zyma, _awem, pkiy, 
   {{0x64440649,0x60c90494,0x00000000,0x00000000}},	//   akhi, _bwem, --, --, 
   {{0x6d4079ab,0xc0e401d9,0xf7800327,0x00000000}},	//   xyma, ۪کہٕ_, ħħux_, --, 
   {{0x62990c2c,0x7d1800c5,0x93441d00,0x6d4000c7}},	//   amwo, dvus, _енге, vyma, 
   {{0x60c86ca2,0x6e940c4f,0x7d180254,0x13b80073}},	//   _ewem, ولتا, evus, ेरीभ, 
   {{0x6d42032c,0xdcf80412,0x03a2032d,0x00000000}},	//   tyma, ्बंध_, _чисо, --, 
   {{0x60ca032e,0xc0e01b88,0x69cc0393,0x7d1803b2}},	//   _gwem, _потк, _reae, gvus, 
   {{0x6d42032f,0x8eb008c9,0x8060177b,0x00000000}},	//   ryma, _كەتت, _звуж, --, 
   {{0x60c80936,0x6d420330,0x7d1a0331,0x8d1801ed}},	//   _zwem, syma, avus, _گزار_, 
   {{0x6d420332,0x5f1800cd,0xf1cc190c,0x00000000}},	//   pyma, भिर्_, ारिन, --, 
   {{0x61fc013d,0x00000000,0x00000000,0x00000000}},	//   _ösle, --, --, --, 
   {{0xac9801d3,0x7ea403e0,0x00000000,0x00000000}},	//   _بنتا_, _tıpt, --, --, 
   {{0xf1cc206b,0xb8d408e9,0x00000000,0x00000000}},	//   ारान, _जू_, --, --, 
   {{0xa4f80ad3,0x644403a2,0x9ba40014,0x7ea403b9}},	//   _ཕྱུག_, wkhi, _تلى۪, _kıpr, 
   {{0x6444020c,0x381c00fe,0x494401af,0x00000000}},	// [3aa70] tkhi, _নকৰো_, _хэйб, --, 
   {{0x60c88293,0x64440009,0x00000000,0x00000000}},	//   _rwem, ukhi, --, --, 
   {{0x64460333,0x60c80660,0x442400fd,0xd5ac0014}},	//   rkhi, _swem, ın_, _چہِ_, 
   {{0x6444f063,0x60ca0334,0xd5ac01d9,0xa02000ee}},	//   skhi, _pwem, _نہِ_, _çözg, 
   {{0x6298286e,0x60c8014b,0x389000a2,0x1fa801a9}},	//   rmwo, _qwem, _ańry_, окли_, 
   {{0xf7700ef6,0x00000000,0x00000000,0x00000000}},	//   _جاۋ_, --, --, --, 
   {{0xd00c16ac,0x349401f0,0x0c780092,0x00000000}},	//   شلي_, _чарр, _አባሎች_, --, 
   {{0x7d18007d,0x6ee40075,0x6224581f,0x60ca0335}},	//   tvus, رسىل, _تىرل, _twem, 
   {{0x60c827d7,0x224c0327,0xe2986b62,0xdea0036b}},	//   _uwem, _ilek_, _гаң_, _ییتی, 
   {{0x5ee40034,0x7d1a0336,0x3ce00116,0x00000000}},	//   _टिप्_, rvus, _ﺋﻪﺧﻤ, --, 
   {{0x7d18b6a5,0x1df80024,0x1b4800d4,0x00000000}},	//   svus, _межы_, ізми_, --, 
   {{0x9f800092,0x00000000,0x00000000,0x00000000}},	//   _ይሄዳሉ_, --, --, --, 
   {{0x80cc015b,0x224c0139,0x9938ede6,0x656802f0}},	//   হূর্, _mlek_, цяну_, _žehn, 
   {{0x0c200124,0x1ae400f7,0x25b802d2,0x224c0139}},	//   _амшн, _жокм, _afsl_, _llek_, 
   {{0x224e0337,0x27e44579,0x00000000,0x00000000}},	//   _olek_, ólna_, --, --, 
   {{0x224c0166,0x00000000,0x00000000,0x00000000}},	//   _nlek_, --, --, --, 
   {{0x1be0007d,0x7ea405d1,0x00000000,0x00000000}},	// [3aa80] _खयाल_, _yıpr, --, --, 
   {{0x9404f5f9,0x00000000,0x00000000,0x00000000}},	//   ظواه, --, --, --, 
   {{0x38b60338,0x224e0339,0xc7b0011a,0xa2c80a8a}},	//   _här_, _blek_, _בבת_, हील्, 
   {{0x224c003e,0x51843849,0x38b6033a,0x279400ee}},	//   _clek_, мула, _kär_, _яшыр, 
   {{0x38b40036,0x00000000,0x00000000,0x00000000}},	//   _jär_, --, --, --, 
   {{0x38b6033b,0x224e033c,0xceb80640,0xd04001e4}},	//   _mär_, _elek_, ољи_, stoɾ, 
   {{0x38b442a4,0x224cac66,0x3dcc0142,0xe1e801d9}},	//   _lär_, _flek_, _begw_, زى۪و_, 
   {{0x224c3743,0xb640019b,0x7dd80139,0x51d401f7}},	//   _glek_, _ｃｃ_, _näsı, _آگاھ_, 
   {{0x38b49c56,0x53b01df0,0x42040a4a,0xa3b40709}},	//   _när_, _जलाश, _інфо_, छुक_, 
   {{0x7ea40139,0x86380092,0x00000000,0x00000000}},	//   _qıpr, _የወንድ, --, --, 
   {{0x765800c0,0x00000000,0x00000000,0x00000000}},	//   _įvyn, --, --, --, 
   {{0x38b40624,0x00000000,0x00000000,0x00000000}},	//   _bär_, --, --, --, 
   {{0x25b801e3,0x795804b3,0xbea000f3,0x00000000}},	//   _rfsl_, дияр_, _рацк, --, 
   {{0x38b6033d,0x6fe003d4,0x7de00241,0xac1801f0}},	//   _där_, প্ৰে, _tìsà, _хоку_, 
   {{0x9e240050,0xe3cc00eb,0x00000000,0x00000000}},	//   _زى۪و, _লালব, --, --, 
   {{0x38b41f65,0x47a401ec,0x00000000,0x00000000}},	//   _fär_, зығұ, --, --, 
   {{0x38b6033e,0xc7c4026a,0x39140124,0x38c80474}},	// [3aa90] _gär_, _осни, _амыр, _оуэн_, 
   {{0x224c0158,0x83640b24,0x00000000,0x00000000}},	//   _slek_, ودال, --, --, 
   {{0x224e033f,0x38b40036,0x250800f2,0x00000000}},	//   _plek_, _zär_, _کرجی_, --, 
   {{0x81cc015b,0x4668119e,0xc61000eb,0x00000000}},	//   _শাহ_, _фром_, হাহা_, --, 
   {{0x3858136e,0x660c55f1,0x00000000,0x00000000}},	//   _رشید_, meak, --, --, 
   {{0x660e0340,0xd56402d3,0xa43801b9,0x00000000}},	//   leak, _ተመሃሮ_, _эзгу_, --, 
   {{0x224c013d,0x660c00e4,0x00000000,0x00000000}},	//   _tlek_, oeak, --, --, 
   {{0x660e0341,0x3394014b,0x00000000,0x00000000}},	//   neak, _расё, --, --, 
   {{0x7ea406be,0x99800210,0x00000000,0x00000000}},	//   _qıpq, zekł_, --, --, 
   {{0x660c193f,0x3f800184,0x9b880014,0x4ce00022}},	//   heak, _иғла, ۪نگل_, ыжьб, 
   {{0x660e0342,0xda641631,0x65680122,0x38b401e3}},	//   keak, евни, _žehl, _sär_, 
   {{0xfbbc05cd,0x38b40267,0x660c03cd,0x2480014f}},	//   _श्रम, _pär_, jeak, hohm_, 
   {{0x660e0343,0x28b80276,0x00000000,0x00000000}},	//   deak, дусэ_, --, --, 
   {{0xccf002e4,0x260401ad,0xada400c0,0x00000000}},	//   _עכו_, _हॉबी_, _раіл, --, 
   {{0x38b43365,0x969408e0,0x660c0093,0xd62a0344}},	//   _wär_, ераш, feak, пове_, 
   {{0x660c525e,0x38b43648,0x00000000,0x00000000}},	//   geak, _tär_, --, --, 
   {{0x14260345,0x999c0024,0xd9440cb6,0x80d806e3}},	// [3aaa0] ндам, ėtų_, _чепи, _निगे, 
   {{0x45807e7e,0xd90c00e5,0x00000000,0x00000000}},	//   угув, _پیڑ_, --, --, 
   {{0x660c150a,0xe2a40051,0x11e520d9,0x63a0032e}},	//   beak, _thự_, ежем, _úlnl, 
   {{0xdb002137,0x660d3ac3,0x00000000,0x00000000}},	//   lcló, ceak, --, --, 
   {{0xa3e80574,0xf3f809a5,0x24940064,0x83d00150}},	//   _याच_, _оңа_, _šamų_, _ﺟﯘﺭﺳ, 
   {{0x3cf0012d,0x41200066,0x00000000,0x00000000}},	//   ंढने_, افوق, --, --, 
   {{0x91e40e91,0xc610015b,0xa3b400c5,0x00000000}},	//   _пове, হারা_, छुओ_, --, 
   {{0xa34801e1,0x229403cd,0x7f44007b,0xe1f00c75}},	//   _mọ́t, tåke_, عليق_, _ەسە_, 
   {{0xfd400323,0x6ecc0c2e,0x20c800ae,0x00000000}},	//   гээн, _सबकु, _يبكي_, --, 
   {{0x8fa435f2,0x9e6403e6,0x660c005a,0x01600395}},	//   _зазе, _یانن, zeak, _скуо, 
   {{0x660c02e3,0xe9f80208,0xdb140248,0x00000000}},	//   yeak, _giẻ_, _òbìr, --, 
   {{0x224c031c,0x00000000,0x00000000,0x00000000}},	//   _ċekk_, --, --, --, 
   {{0x8c44dc3f,0x660c0daa,0x00000000,0x00000000}},	//   _педе, veak, --, --, 
   {{0xa3480241,0x660c02b5,0x7f0001e1,0x2c040117}},	//   _bọ́t, weak, _òṣùk, _рӯим, 
   {{0x660e0346,0xb6e40a89,0x00000000,0x00000000}},	//   teak, лютк, --, --, 
   {{0x660c03a0,0xe3cc0eac,0xdb0001e7,0x00000000}},	//   ueak, _লাইব, acló, --, 
   {{0xd5840116,0x00000000,0x00000000,0x00000000}},	// [3aab0] вәрл_, --, --, --, 
   {{0x660e0347,0x68e8025c,0x00000000,0x00000000}},	//   seak, ġedd, --, --, 
   {{0x660e0348,0xc7643baf,0x68fc62a2,0xdb0035f5}},	//   peak, _سادى, ltsd, lclò, 
   {{0x290801f2,0x45a01823,0x67200267,0x8284007b}},	//   _kpaa_, _مەزك, ålju, رجال, 
   {{0x68fc127b,0xdb0000db,0x00000000,0x00000000}},	//   ntsd, nclò, --, --, 
   {{0xd0046565,0x68fc0112,0xa068d842,0x00000000}},	//   веше_, itsd, ьала_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa29402d5,0x4ad81098,0x68fe0349,0x00000000}},	//   _рабі, _भिजव, ktsd, --, 
   {{0x290801e1,0xc0c80107,0x00000000,0x00000000}},	//   _npaa_, _хубе_, --, --, 
   {{0x1c46034a,0x26c03f06,0x00000000,0x00000000}},	//   тном, _otho_, --, --, 
   {{0x290a034b,0x26c0052f,0x9cf0015b,0x68fc0036}},	//   _apaa_, _ntho_, ঝবেন_, etsd, 
   {{0xb6c801ed,0x59740166,0x0f34010f,0x2ca8004e}},	//   ہارے_, выгу, _ברעט_, мкөп_, 
   {{0x26c000dc,0x59740220,0xf4cc0eac,0x68fc12e8}},	//   _atho_, тыну, _লম্ব, gtsd, 
   {{0x26c001af,0xdb844164,0x8c40030d,0xd708004e}},	//   _btho_, _игли, _веше, мнге_, 
   {{0x68fc4d25,0x7b6400d4,0x00000000,0x00000000}},	//   atsd, _ятде, --, --, 
   {{0xd1280023,0x68fc51a0,0xb8d800fe,0xdb0001e7}},	//   ተቐበል, btsd, _চব_, scló, 
   {{0x20041529,0x26c10664,0xa9040133,0x68fc0857}},	// [3aac0] _obli_, _etho_, _یبین, ctsd, 
   {{0xd7c87380,0x5744014b,0xba081ef7,0x00000000}},	//   _توده_, _аноб, _ገሩ_, --, 
   {{0xfa10031c,0x00000000,0x00000000,0x00000000}},	//   _ཏྲོན_, --, --, --, 
   {{0x20042819,0x91e41fb7,0xf48403e6,0x68ea034c}},	//   _abli_, тоде, _ڕازی, šede, 
   {{0x85ba034d,0x6f080077,0x9f440332,0xe2a81e2f}},	//   _تاپس_, _spdc, _gclú_, رامن_, 
   {{0xe9f8110e,0xdcf4012c,0x74b400fb,0x130400d8}},	//   _diẹ_, ůběh, _аҡҡу, _изгм, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x20054df4,0x52740276,0xd1b002f2,0x71880117}},	//   _ebli_, _ругу, _ئیشک, _забҳ_, 
   {{0x6e043b5f,0x829000d1,0x3cd000db,0x00000000}},	//   _ەستە, _ئۇنچ, ажыс, --, 
   {{0x224c031c,0xf8dc10fa,0x00000000,0x00000000}},	//   _ċeki_, _बिजय, --, --, 
   {{0x8fa40276,0x3d140034,0x290a034e,0x00000000}},	//   _раже, _बैठे_, _spaa_, --, 
   {{0x68fc014a,0x4d48041b,0x26c000cd,0xcd0400f3}},	//   ttsd, _опен_, _rtho_, _ачки, 
   {{0xcd3428ee,0x26c0002b,0x68fc02d0,0x00000000}},	//   _جراب, _stho_, utsd, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x0b580209,0x4b500133,0xbb400798,0x00000000}},	//   _юрды_, _ڕێگر, _вејк, --, 
   {{0x68fc03ac,0xddc80210,0x00000000,0x00000000}},	//   ptsd, cheń, --, --, 
   {{0x87e42cc8,0xe4741d39,0xdb2001e1,0x00000000}},	// [3aad0] _июне, глањ, _ìtòp, --, 
   {{0x6aac03d1,0x222800e5,0x00000000,0x00000000}},	//   _hiaf, کزئی_, --, --, 
   {{0x6aac0451,0x26c0379d,0x00000000,0x00000000}},	//   _kiaf, _utho_, --, --, 
   {{0x6aac0109,0x00000000,0x00000000,0x00000000}},	//   _jiaf, --, --, --, 
   {{0x6aac0170,0x9f4c00d7,0x00000000,0x00000000}},	//   _miaf, čníc_, --, --, 
   {{0x661e034f,0x6aae0350,0xe2f800c0,0x00000000}},	//   _hask, _liaf, _пегі_, --, 
   {{0x02a60351,0x6aac037e,0x91d003d4,0x00000000}},	//   _арам, _oiaf, _হাৰ্, --, 
   {{0x76580953,0x661ce475,0x6aac03d1,0x5bbc00dc}},	//   _įvyk, _jask, _niaf, ोर्व, 
   {{0x661e0352,0xdbcc0789,0x6d5c0115,0xad58009d}},	//   _mask, _añád, ŝran, врэх_, 
   {{0x661e0353,0x6aac0607,0x00000000,0x00000000}},	//   _lask, _aiaf, --, --, 
   {{0x6aae0354,0xddc80356,0x00000000,0x00000000}},	//   _biaf, gneţ, --, --, 
   {{0xceb00d65,0x1cb80491,0x661e0355,0x6aac0ffb}},	//   _היא_, _كاتب_, _nask, _ciaf, 
   {{0xddc80165,0x1d088d2c,0x28f80139,0x49cc00e4}},	//   rheń, _чели_, кэрэ_, ñetỹ_, 
   {{0x661c0014,0xe7a42432,0xb8ec007d,0xddc8030a}},	//   _aask, _गृहप, _लऽ_, sheń, 
   {{0x6aac096b,0x628a0356,0x661e0357,0x1aec015b}},	//   _fiaf, _okeo, _bask, _জনকে_, 
   {{0x661e0358,0x6aac0268,0xe3cc00bd,0x628802e3}},	//   _cask, _giaf, _লাগব, _nkeo, 
   {{0xf9880451,0x3cfc01a9,0x00000000,0x00000000}},	// [3aae0] _ڳنڍي_, ntuv_, --, --, 
   {{0x661c0b21,0x6288035a,0xe618013e,0x31cc00dc}},	//   _eask, _akeo, ндӣ_, ार्ध, 
   {{0x661e0359,0x9344084c,0x3cfc000d,0x00000000}},	//   _fask, ынже, htuv_, --, 
   {{0x661c3142,0xd7c801b9,0x229403cd,0x00000000}},	//   _gask, _توگه_, tåka_, --, 
   {{0x506400cf,0x00000000,0x00000000,0x00000000}},	//   лтка, --, --, --, 
   {{0x628808e7,0x229400fe,0x661d5a9b,0x62800a87}},	//   _ekeo, råka_, _zask, _ílon, 
   {{0x7526035a,0x661c4e40,0x00000000,0x00000000}},	//   lviz, _yask, --, --, 
   {{0x63a801e4,0x661c058a,0x00000000,0x00000000}},	//   _ŝeng, _xask, --, --, 
   {{0x6aac9608,0xacb4026a,0x7526035b,0x21740aac}},	//   _riaf, јбољ, nviz, _куфр, 
   {{0x10a49098,0x6aae035c,0x527401fe,0x00000000}},	//   _сизн, _siaf, _руҳу, --, 
   {{0xaa5a035d,0x01d4009e,0x0434008f,0xf1a801e2}},	//   вину_, _হাতদ, אטיש_, _ساړه_, 
   {{0xc3300302,0x00000000,0x00000000,0x00000000}},	//   צור_, --, --, --, 
   {{0x661e035e,0x6aac1570,0x0c84010b,0x3f98003a}},	//   _rask, _viaf, _йыкм, ęque_, 
   {{0x661e035f,0x59700137,0x00000000,0x00000000}},	//   _sask, تگىز, --, --, 
   {{0x661e0360,0x6aac799b,0xbb4421ec,0x4ae401a9}},	//   _pask, _tiaf, _ملون_, _сўла, 
   {{0xf748b745,0x661c0429,0x6e200455,0xa6140120}},	//   دلفي_, _qask, ndmb, јмач, 
   {{0x752401d3,0xba74015e,0x00000000,0x00000000}},	// [3aaf0] gviz, _داوت, --, --, 
   {{0x661e0361,0x628800ad,0x69c0012d,0x492001f0}},	//   _wask, _skeo, śled, _кӯҳҳ, 
   {{0x75260362,0x66080022,0xb58801d9,0x9f400205}},	//   aviz, _ñeko, نپہٕ_, ühü_, 
   {{0x661c01f7,0x63a80115,0x3cfc0175,0x00000000}},	//   _uask, _ĝend, ytuv_, --, 
   {{0xaf7c001f,0xb60400d7,0x00000000,0x00000000}},	//   ንዘብና_, íšet, --, --, 
   {{0x657c022e,0x7d080175,0x60242cdd,0x00000000}},	//   _ixsh, _rpgs, рдка, --, 
   {{0x64560363,0x00000000,0x00000000,0x00000000}},	//   _ilzi, --, --, --, 
   {{0x81cc02a6,0x657c01a9,0xa0c41ff7,0x00000000}},	//   _শাক_, _kxsh, _نيرو, --, 
   {{0x16d20364,0x64540419,0xdc9a0365,0x1a640244}},	//   _तब्ब, _klzi, ктош_, ییتی_, 
   {{0x40851ed9,0x9b04e846,0x63a80205,0x83cc0150}},	//   _субб, азод, _şeny, _ﺗﻘﺪﻳ, 
   {{0x752405b8,0x8fc400cf,0x3cfe0366,0xa2c80073}},	//   zviz, _ئممۇ, stuv_, हीच्, 
   {{0x657c2f3b,0x0b400153,0x3fa0025c,0x00000000}},	//   _oxsh, інян, ħruġ_, --, 
   {{0x6454004e,0x32dc01e1,0x3dd800cc,0x00000000}},	//   _olzi, _káyá_, _ধাপল, --, 
   {{0x8d580375,0xe9f80208,0x1a6402f2,0x00000000}},	//   _בכני, _tiế_, _چیدی_, --, 
   {{0x9f900295,0x0a3c001f,0x657c06be,0x00000000}},	//   _kùñi_, _ይጨምራ, _axsh, --, 
   {{0x64560367,0xc87c0e78,0x4b7800df,0x00000000}},	//   _alzi, wußt_, _באצו, --, 
   {{0x75240165,0x00000000,0x00000000,0x00000000}},	// [3ab00] uviz, --, --, --, 
   {{0x75260368,0x3eac0936,0x00000000,0x00000000}},	//   rviz, _ligt_, --, --, 
   {{0x3a204077,0x07a0030d,0x00000000,0x00000000}},	//   _kaip_, _маьн, --, --, 
   {{0x6454002d,0x3a2005b1,0x3eac0810,0x114804b3}},	//   _elzi, _jaip_, _nigt_, кпей_, 
   {{0x63a804ac,0xa490006c,0x3a200142,0x61ec00e5}},	//   _ĝene, _کیلت, _maip_, óala, 
   {{0x3a202af2,0x91c404c5,0x931404f2,0x00000000}},	//   _laip_, শৃংখ, _پورش, --, 
   {{0xdbd40428,0x27e401d3,0x8f7401ec,0xe7b80037}},	//   jùñi, ólni_, шуді, _आलसप, 
   {{0x3a2008cd,0xd25004fb,0x4ea401b9,0xddc80153}},	//   _naip_, _بنر_, шрла, tneš, 
   {{0xbea41b45,0x3eac00b5,0x7cd40c75,0xfbc40154}},	//   جهين_, _digt_, амыр_, _শয়ত, 
   {{0x28b401ad,0xddc85d74,0x00000000,0x00000000}},	//   ंदसि, rneš, --, --, 
   {{0xddc800e2,0x00000000,0x00000000,0x00000000}},	//   sneš, --, --, --, 
   {{0x0d84ac18,0x3eacd379,0x00000000,0x00000000}},	//   _клен, _gigt_, --, --, 
   {{0xe9f80051,0x81b80154,0x8c340117,0x00000000}},	//   _giẽ_, _আজম_, _волӣ_, --, 
   {{0x27ec09f0,0x3cf00073,0x2f180051,0x8b640116}},	//   ßen_, ंढरे_, _kũg_, _پاتم, 
   {{0x67d4a3c3,0x27ecca2c,0x00000000,0x00000000}},	//   _қону, ğen_, --, --, 
   {{0x27ee0369,0xfd48002b,0x645402f0,0x3a2003b9}},	//   şen_, _apoṇ, _slzi, _gaip_, 
   {{0x26c40006,0x2a680254,0xa3a800dc,0x00000000}},	// [3ab10] ūlo_, _imab_, खेन_, --, 
   {{0x2a680211,0x03c50809,0x39140050,0x03a81046}},	//   _hmab_, рсам, _بوٝز, نداو_, 
   {{0x81b80154,0x83a81188,0x69dc5e56,0x483000f1}},	//   _আজব_, ттаб_, oase, _هوکړ, 
   {{0x69de036a,0x29180009,0xf41400eb,0x656801ef}},	//   nase, owsa_, সাগর_, _žehu, 
   {{0x69de036b,0x3eac8007,0x657c01d5,0xe7d800fe}},	//   iase, _rigt_, _uxsh, তলীয, 
   {{0xe2d805d3,0x3eac037e,0xf4840139,0x00000000}},	//   _مارچ_, _sigt_, _дусн, --, 
   {{0x69dd54a3,0x2a6800c5,0x2f18004d,0x00000000}},	//   kase, _omab_, _cũg_, --, 
   {{0x69de036c,0xd34403e6,0xd1b00014,0x00000000}},	//   jase, _دیمه_, _ٹیوک, --, 
   {{0x69de036d,0x3a20bb36,0x3eac032e,0x00000000}},	//   dase, _raip_, _vigt_, --, 
   {{0x3a200093,0x69dc009a,0x00000000,0x00000000}},	//   _saip_, ease, --, --, 
   {{0x69dc1ebd,0x5f953d55,0x3a22036e,0x98a800e2}},	//   fase, _الائ, _paip_, ākļu_, 
   {{0x69de036f,0x61f80368,0xae4400f1,0x00000000}},	//   gase, ngwl, _وپلو, --, 
   {{0x68e808a4,0x3a20000d,0x5da400fe,0x00000000}},	//   šedn, _vaip_, _গ্ৰু, --, 
   {{0x2a68007f,0x98a41e35,0x69dc0869,0x00000000}},	//   _emab_, сиге, aase, --, 
   {{0x69dd167c,0x3a204077,0xa3a80037,0x99f40024}},	//   base, _taip_, खेम_, _ляпі, 
   {{0x69dd102d,0x69c0012c,0xaac42f84,0x00000000}},	//   case, ělec, _بتون, --, 
   {{0x3ae01248,0x261801ad,0x93b4007b,0x49c405a2}},	// [3ab20] lıp_, _पसरी_, محاض, _улын_, 
   {{0x28b402ab,0x00000000,0x00000000,0x00000000}},	//   ंदरि, --, --, --, 
   {{0x3ae1677c,0x2ae0007d,0x657006be,0x00000000}},	//   nıp_, _किछु_, _ədhə, --, 
   {{0xb80406b1,0x53a400c7,0x77340023,0xc1c80ef6}},	//   श्रम_, _ҳагб, _ኣመሓደ, _ﺗﯩﺮﺍ, 
   {{0x7bc18791,0x3ae00205,0x3d14012d,0x00000000}},	//   _ofnu, hıp_, _बैले_, --, 
   {{0x69de0370,0x3ae003ee,0xd46801e0,0x7ae001bf}},	//   zase, kıp_, _сиге_, _ovnt, 
   {{0x69de0371,0x71c4016c,0x2fdc03b2,0x6f580818}},	//   yase, _мавҷ, ravg_, райё_, 
   {{0x7bc0dd6d,0x69de0372,0x3ae00205,0xfe6c01e2}},	//   _afnu, xase, dıp_, ېدی_, 
   {{0x41260373,0x7ae002d0,0x00000000,0x00000000}},	//   _лото_, _avnt, --, --, 
   {{0x69de0374,0x7ae001e0,0xa6480240,0x00000000}},	//   wase, _bvnt, _ዘገደደ, --, 
   {{0x3ae000fd,0x6a160375,0x644001ab,0xa9280153}},	//   gıp_, омну, _òlie, _mažų, 
   {{0x7bc001a8,0x5c7400cf,0x00000000,0x00000000}},	//   _efnu, йлөт, --, --, 
   {{0x7ae20376,0x69de0377,0xc98401f0,0xa8980116}},	//   _evnt, rase, суни, икму_, 
   {{0x9f44007b,0x68e800f3,0x3ae000fd,0x00000000}},	//   _gcló_, šedo, bıp_, --, 
   {{0x28d800bc,0x8b9401c4,0x00000000,0x00000000}},	//   _बौरि, _урдч, --, --, 
   {{0x69de0378,0x29180175,0x00000000,0x00000000}},	//   qase, pwsa_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3ab30] --, --, --, --, 
   {{0xe8b40073,0x8880114f,0x00000000,0x00000000}},	//   ंदीच, _ریزن, --, --, 
   {{0xc444001f,0x628002d2,0x2378114f,0x00000000}},	//   _የከፍተ, _ílok, جماد_, --, 
   {{0xa3c8032c,0x00000000,0x00000000,0x00000000}},	//   ैरह_, --, --, --, 
   {{0x3ae070f7,0xe9f80051,0x712400be,0xb594014b}},	//   zıp_, _nhậ_, كرول, _ниюш, 
   {{0x3ae0a493,0x1ec817a2,0x61f80042,0xddc80055}},	//   yıp_, алки_, sgwl, bheś, 
   {{0x8fa07336,0x4420010f,0x4fa00114,0x00000000}},	//   маше, _iaj_, мишв, --, 
   {{0x44220379,0xc254004b,0x6440004e,0x39a4020c}},	//   _haj_, _اخست, _òlib, nèsé_, 
   {{0x4422037a,0x61ea037b,0x80d000db,0x9f4401ef}},	//   _kaj_, _idel, _رماچ, _mdlé_, 
   {{0x44200842,0x3ae12e53,0x81b80183,0x60ca037c}},	//   _jaj_, tıp_, _আজি_, _item, 
   {{0xe51809ab,0x70a801c8,0x00000000,0x00000000}},	//   नौति_, _اهلِ_, --, --, 
   {{0x4422037d,0x3ae1677c,0x60c8008b,0x1a64036b}},	//   _laj_, rıp_, _ktem, تیبی_, 
   {{0x3ae0456f,0xa3a88687,0x3ddc0086,0x4420316e}},	//   sıp_, खेत_, mauw_, _oaj_, 
   {{0x4422037e,0x60c8f7f4,0x3ddc0d27,0x9b440691}},	//   _naj_, _mtem, lauw_, _ونشو, 
   {{0x61ea037f,0x96ba0380,0x7c2005da,0x60c80083}},	//   _odel, ругу_, _ianr, _ltem, 
   {{0x7c200936,0x44220381,0x61ea0382,0x60c83024}},	//   _hanr, _aaj_, _ndel, _otem, 
   {{0x60ca0383,0x44220384,0x7c220385,0x63a8010f}},	// [3ab40] _ntem, _baj_, _kanr, _ĝena, 
   {{0x61ea0386,0x44220387,0x7c220388,0x29040311}},	//   _adel, _caj_, _janr, ălat_, 
   {{0x44220389,0x60c8b7ee,0xb7240502,0x7c22038a}},	//   _daj_, _atem, _عکسه, _manr, 
   {{0x61e80048,0xe2aa038b,0x7c22038c,0xd628026a}},	//   _cdel, مانن_, _lanr, _томе_, 
   {{0x4422038d,0x7c20dcf5,0x61e800a9,0x60c8004e}},	//   _faj_, _oanr, _ddel, _ctem, 
   {{0xd1dc069c,0x61e947af,0x44200097,0x7c22038e}},	//   _ሓንቲ_, _edel, _gaj_, _nanr, 
   {{0x60ca038f,0xcf2400c6,0x09a407b7,0xe1ec030d}},	//   _etem, ترشي, _गण्य, _пӳ_, 
   {{0x44200190,0x7c220390,0x3ddc01a4,0xbea01fbe}},	//   _zaj_, _aanr, gauw_, мајк, 
   {{0x7c220391,0x4420dd32,0x212c9ae3,0x61b000db}},	//   _banr, _yaj_, _greh_, _كەما, 
   {{0x44220392,0x61e809a8,0x7c200368,0x00000000}},	//   _xaj_, _zdel, _canr, --, 
   {{0x61e804ce,0x7c220393,0xaa9477da,0xe9f8004d}},	//   _ydel, _danr, зинч, _nhả_, 
   {{0x7c2001c3,0x00000000,0x00000000,0x00000000}},	//   _eanr, --, --, --, 
   {{0xbb445035,0x7c20007c,0x4d7400ae,0x00000000}},	//   ملین_, _fanr, _بطار, --, 
   {{0x7c2000a9,0x00000000,0x00000000,0x00000000}},	//   _ganr, --, --, --, 
   {{0x466a0394,0xe9f80016,0x7b6007d8,0xbca00338}},	//   арам_, _chả_, _отъе, _تموي, 
   {{0x44220395,0x39b00093,0x7c20007f,0x229403cd}},	//   _saj_, _sēsū_, _zanr, råkk_, 
   {{0x44220396,0x61e921fa,0xecf80349,0x7c220397}},	// [3ab50] _paj_, _rdel, _অনুস_, _yanr, 
   {{0x1cd80135,0x44200023,0x212c0240,0x39a40066}},	//   _འཆལ_, _qaj_, _rreh_, sèsé_, 
   {{0x44220398,0x60c800ed,0xd5b8016c,0x466007d2}},	//   _vaj_, _stem, рсӣ_, _قۇسق, 
   {{0x442003f0,0x171808a8,0x212c0200,0x00000000}},	//   _waj_, _פורע, _preh_, --, 
   {{0x44201326,0xe135ea2a,0xd6540375,0x61e8388a}},	//   _taj_, янды, _זירת_, _vdel, 
   {{0xd12c25a7,0x44200218,0x94b80302,0x60c80327}},	//   امو_, _uaj_, _למשת, _vtem, 
   {{0x7c220399,0xafdc00a2,0x3394022e,0x00000000}},	//   _ranr, _goĸm, _жарё, --, 
   {{0x212e039a,0x8234468e,0x7c22039b,0x61ea039c}},	//   _treh_, _برسا, _sanr, _udel, 
   {{0x7c20ab21,0x72040372,0x4dac00cc,0xdb1401e1}},	//   _panr, _توقم, ছুসং, _òbúr, 
   {{0xb11401d5,0x00000000,0x00000000,0x00000000}},	//   _юмуш, --, --, --, 
   {{0x7c22039d,0x69c00316,0xaf8401ee,0x00000000}},	//   _vanr, ělen, _оҡша_, --, 
   {{0x7c200652,0x69c00034,0x00000000,0x00000000}},	//   _wanr, ślen, --, --, 
   {{0x7c22039e,0x00000000,0x00000000,0x00000000}},	//   _tanr, --, --, --, 
   {{0xe9f8004d,0x88a001e0,0x00000000,0x00000000}},	//   _phả_, нғыһ, --, --, 
   {{0x07a00b3e,0x15d00ef6,0x26c40115,0xdb240108}},	//   еарн, _ﭘﻪﺭﺩ, ŭlon_, öpär, 
   {{0x6b9c942f,0x7b300124,0x7e7a039f,0x00000000}},	//   ürge, _g̃ua, nnup, --, 
   {{0x959893c0,0x7e780421,0x186800c2,0x38a459d6}},	// [3ab60] ству_, inup, _гапи_, jörg_, 
   {{0xe9f8001e,0x7e7803fa,0x00000000,0x00000000}},	//   _thả_, hnup, --, --, 
   {{0x694450b5,0x7e7877d0,0x13080958,0xf664004e}},	//   _فضیل, knup, сней_, _женү, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc5f005e1,0xc20400db,0x00000000,0x00000000}},	//   _אדר_, سقون_, --, --, 
   {{0x76440a63,0x85980375,0x7e780254,0x00000000}},	//   ljiy, _לשכו, enup, --, 
   {{0x76440009,0x69c80de2,0x53a41798,0x00000000}},	//   ojiy, ñeek, _хавб, --, 
   {{0x764603a0,0xdb155380,0xc7b00a1e,0x798400d7}},	//   njiy, _òbùr, עבה_, _oxiw, 
   {{0x7984009a,0x7644058a,0xe9f80051,0x00000000}},	//   _nxiw, ijiy, _nhạ_, --, 
   {{0xfd0c215e,0xdd98941b,0x7e7800cf,0x99d80150}},	//   اجي_, өшө_, anup, _ﺃﺩﺍﺅ, 
   {{0x4f659b21,0x8e087d11,0x8e8401ec,0x00000000}},	//   _عاطف, _гнев_, _егже, --, 
   {{0x7f380302,0x7644011f,0xcce4027d,0x38a401e3}},	//   _לעבו, jjiy, _فستي, hörd_, 
   {{0x38a40267,0xe9f80051,0x00000000,0x00000000}},	//   körd_, _chạ_, --, --, 
   {{0x22940158,0x76440009,0x628000d7,0x7d3400df}},	//   råki_, ejiy, _ílov, _מנדב_, 
   {{0x63a800df,0x6d400213,0x1cd80327,0xe6940108}},	//   _ĝeno, lxma, _འཆོ_, дивы, 
   {{0x271c2c35,0x63a801e4,0x00000000,0x00000000}},	//   _पनीर_, _ŝeno, --, --, 
   {{0x6d41ebfb,0x38a40267,0xfc6402f2,0x00000000}},	// [3ab70] nxma, förd_, _بخۆی, --, 
   {{0x76440009,0xe2f80212,0x00000000,0x00000000}},	//   ajiy, жежі_, --, --, 
   {{0x33580137,0x00000000,0x00000000,0x00000000}},	//   пүрө_, --, --, --, 
   {{0x066446c6,0x454000d1,0x00000000,0x00000000}},	//   _راجپ, _كۆزق, --, --, 
   {{0x660c6580,0x1cd8031c,0x38a401e3,0xa020010e}},	//   mfak, _འཆེ_, börd_, _çökg, 
   {{0x660c0a55,0x6d4002c4,0x20000254,0x00000000}},	//   lfak, dxma, ühi_, --, 
   {{0x660c0270,0x7e7803b2,0x81b401af,0x00000000}},	//   ofak, tnup, _еңер_, --, 
   {{0x7e7801f4,0x00000000,0x00000000,0x00000000}},	//   unup, --, --, --, 
   {{0xa3a80316,0x7e792a08,0x66080022,0x38a40254}},	//   खेर_, rnup, _ñeku, löre_, 
   {{0x64440564,0x660c007c,0x69c00210,0x7e7a03a1}},	//   njhi, hfak, ślel, snup, 
   {{0x6298009a,0x4b84010b,0xefe80023,0x660c0200}},	//   olwo, дйэн_, _መንዩ_, kfak, 
   {{0x683c0020,0xe9f80051,0xdb140248,0xbb300116}},	//   _ኢየሱስ, _phạ_, _àbís, ﺮﺳﻰ_, 
   {{0x660e03a2,0x38a40e78,0x6b8402dd,0xa3cc0073}},	//   dfak, höre_, _ۋشىل, रडा_, 
   {{0x660c0093,0x62980112,0x00000000,0x00000000}},	//   efak, hlwo, --, --, 
   {{0x660d2d25,0x7644003c,0x38a40139,0x00000000}},	//   ffak, tjiy, jöre_, --, 
   {{0x80d00154,0x9f4401e7,0x7644058a,0xa6940063}},	//   _সিন্, _ndlí_, ujiy, еруј, 
   {{0x142603a3,0x38a40267,0xdc900023,0x7644622e}},	// [3ab80] мдам, törd_, _ምእሳር_, rjiy, 
   {{0x62980076,0x660c31e5,0x38a403e0,0x00000000}},	//   elwo, afak, före_, --, 
   {{0x660c00df,0x38a40267,0xa3a8a202,0x00000000}},	//   bfak, rörd_, खेल_, --, 
   {{0x27a8010f,0x00000000,0x00000000,0x00000000}},	//   _מסתּ, --, --, --, 
   {{0xfbe00154,0x6d400327,0x00000000,0x00000000}},	//   _মানত, xxma, --, --, 
   {{0x2c600100,0x6298257c,0xfe6c004b,0x00000000}},	//   _kòde_, alwo, یدي_, --, 
   {{0x6e948d20,0xdde00e04,0x98a80024,0x1cd8031c}},	//   нику, _šuša, škės_, _འཆུ_, 
   {{0x03a1a954,0x68e80f8b,0x2c6035b2,0xddc80311}},	//   _рисо, šedi, _mòde_, vieţ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x31c8025a,0x2d980882,0x60cc0789,0x6d400213}},	//   bïzï_, āre_, íame, rxma, 
   {{0x2c600100,0xef100137,0x69c0012d,0x1ea800f1}},	//   _nòde_, _сүйө, ślem, _ځاني_, 
   {{0x1ea87427,0xddc80311,0x660c007c,0x00000000}},	//   _فاني_, rieţ, xfak, --, 
   {{0xb82804c5,0xad240131,0x00000000,0x00000000}},	//   মানত_, _سىغى, --, --, 
   {{0xddca03a4,0x80d00154,0xe5cc0150,0xa3a80118}},	//   mieš, _সিম্, _ﺑﯩﻴﻜ, खेँ_, 
   {{0x2c602508,0x8b6408b0,0x660e03a5,0xddc800e2}},	//   _còde_, _تاشم, tfak, lieš, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xddc800da,0x644603a6,0x660e03a7,0xc7b8004e}},	// [3ab90] nieš, tjhi, rfak, _мён_, 
   {{0x2c601ed9,0x81b80154,0x38a40790,0xfdb80210}},	//   _fòde_, _আজই_, töre_, _उल्फ, 
   {{0xa3a814cf,0x660e03a8,0x68fc047e,0x00000000}},	//   खें_, pfak, lusd, --, 
   {{0xa4d400d6,0xf1a80133,0x67240200,0x68fc02d0}},	//   _помі, ژاوه_, _ishj, ousd, 
   {{0x27e00036,0x38a58c3c,0x00000000,0x00000000}},	//   _kehn_, söre_, --, --, 
   {{0x27e000ad,0x26c00427,0x78fc0375,0xddc800de}},	//   _jehn_, _kuho_, קלופ, dieš, 
   {{0xd00cbd0e,0x26c203a9,0x6ee603aa,0x68fc03cd}},	//   صلي_, _juho_, پسىل, husd, 
   {{0x26c203ab,0x290830ca,0x68fe03ac,0x1d241d39}},	//   _muho_, _oqaa_, kusd, емим, 
   {{0x200803f9,0x26c203ad,0x68fd0bd5,0xab640210}},	//   ƙai_, _luho_, jusd, óżny, 
   {{0x224c2e96,0x68fe03ae,0x672403ac,0x00000000}},	//   _hoek_, dusd, _oshj, --, 
   {{0x224e03af,0xddc80010,0x26c40115,0x00000000}},	//   _koek_, mnež, ŭloj_, --, 
   {{0x224c0076,0xddc8b78d,0x2c6001e1,0x68fc0857}},	//   _joek_, lnež, _ròde_, fusd, 
   {{0xddc80029,0x224e03b0,0x27e203b1,0x68fe03b2}},	//   cieš, _moek_, _behn_, gusd, 
   {{0x26c203b3,0x224e03b4,0x2c6001e1,0xb8d801f9}},	//   _buho_, _loek_, _pòde_, _छळ_, 
   {{0x5a9403b7,0xcf90008f,0x4ac44f3c,0x3e800064}},	//   _приф, ָטן_, _रूपव, pūtę_, 
   {{0x68fe03b5,0x3ab400fb,0x00000000,0x00000000}},	//   busd, _шәпт, --, --, 
   {{0x200401e4,0xee5c06ea,0xd5a801ad,0xd5b00127}},	// [3aba0] _ocli_, øðið_, चेंज, افذ_, 
   {{0x224c030a,0x27e00e78,0xddc80010,0x85000014}},	//   _aoek_, _gehn_, jnež, اوٕن, 
   {{0x224e03b6,0x779603b7,0x26c203b8,0xddc936f5}},	//   _boek_, _شیرا, _guho_, dnež, 
   {{0x20054b72,0x224c05be,0x27e00730,0x1544010b}},	//   _acli_, _coek_, _zehn_, _земм, 
   {{0x224c0399,0x628001e4,0x95740137,0xb4b4008e}},	//   _doek_, _ƭlor, _чынч, _җиңә, 
   {{0xf41404fb,0xddc84ffc,0xe9f80051,0x00000000}},	//   _בפֿ_, vieš, _thầ_, --, 
   {{0x03a203b9,0xb8cc031c,0xe1e80014,0x00000000}},	//   _биро, _ྗེ_, سى۪و_, --, 
   {{0x224c0399,0x2004025c,0xddc8005f,0xbf3030d1}},	//   _goek_, _ecli_, tieš, اروغ, 
   {{0xddc80427,0x00000000,0x00000000,0x00000000}},	//   bnež, --, --, --, 
   {{0x224c0460,0xddc9e67d,0x2cb8049f,0x68fd2fa3}},	//   _zoek_, rieš, örd_, vusd, 
   {{0x224c0369,0x27e203ba,0x00000000,0x00000000}},	//   _yoek_, _rehn_, --, --, 
   {{0x8d85eaf7,0x26c004a7,0xddc83d4f,0x27e00e78}},	//   _пулд, _ruho_, pieš, _sehn_, 
   {{0x26c02866,0xeb341473,0x1cd8025c,0xe9f80051}},	//   _suho_, رىڭد, _འཆག_, _nhấ_, 
   {{0x26c003a0,0x68fe03bb,0x00000000,0x00000000}},	//   _puho_, rusd, --, --, 
   {{0x68fe03bc,0x9f48456f,0x443c01fb,0x00000000}},	//   susd, ğaç_, _đu_, --, 
   {{0x6934fbd3,0xddc8310a,0x00000000,0x00000000}},	//   _аниу, znež, --, --, 
   {{0x224c0399,0xc7c81064,0x00000000,0x00000000}},	// [3abb0] _roek_, _ныне_, --, --, 
   {{0x224c0591,0x68ee03bd,0xaaa4242e,0x26c00108}},	//   _soek_, _ivad, _गीतक, _tuho_, 
   {{0x224c0438,0x68ec0388,0xddc80219,0x7bd8010f}},	//   _poek_, _hvad, vnež, פקאו, 
   {{0x2fcc01c7,0x4668c6e2,0xe0d40063,0x00000000}},	//   _afdg_, _хром_, водњ, --, 
   {{0xe1084b3e,0xddc88256,0x182c0023,0x00000000}},	//   фелд_, tnež, _ብምእዛ, --, 
   {{0xd12c0116,0x00000000,0x00000000,0x00000000}},	//   زمى_, --, --, --, 
   {{0x26c40306,0xf8380375,0xddc80010,0xefe800f7}},	//   íloh_, תנות_, rnež, رعوو_, 
   {{0x68ee03be,0x6224005e,0xddc960c7,0x00000000}},	//   _ovad, _جىرل, snež, --, 
   {{0xb28406d3,0xc0a84028,0x38a40267,0x00000000}},	//   _сырк, _فائل_, höra_, --, 
   {{0x69ce03bf,0x61ec0436,0x60b458c5,0x6d5c01e4}},	//   _afae, ðalf, _شمائ, ĝrap, 
   {{0x68ee03c0,0x5ba8117e,0x00000000,0x00000000}},	//   _avad, ьком_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8d90004b,0x68ec0356,0xec340133,0x00000000}},	//   _پلوش, _cvad, _ڕووگ, --, 
   {{0x38a4049f,0x81e402f5,0xe9f80051,0x00000000}},	//   föra_, পলি_, _khẻ_, --, 
   {{0x68ee03c1,0x38a401e6,0x5ac8036b,0x69cc015d}},	//   _evad, göra_, _ўлим_, _ffae, 
   {{0x7c800023,0x69c800e8,0x00000000,0x00000000}},	//   _ይብሃል_, ñeet, --, --, 
   {{0x68ec0115,0x81e40154,0x00000000,0x00000000}},	// [3abc0] _gvad, পলা_, --, --, 
   {{0x44600cfc,0x05a40580,0x425007d6,0x13b44710}},	//   авув, твуй_, ینلر, نصاح, 
   {{0x68ec0433,0xe4d400d1,0x16a8014b,0x00000000}},	//   _zvad, نتەب, _овои_, --, 
   {{0x90e4034c,0x2c60068c,0xe9f80051,0xe2b4009d}},	//   نستن, _mòda_, _thấ_, гсчэ, 
   {{0x5064004e,0x00000000,0x00000000,0x00000000}},	//   ктка, --, --, --, 
   {{0x75240230,0x2db40150,0x38780200,0x15e80073}},	//   mwiz, _ﯼﺪﻨﻤ, nirr_, टणकर_, 
   {{0x487802d3,0x752603c2,0xe9f8004d,0xac9402dd}},	//   _ኣብሪሁ_, lwiz, _chẻ_, ғанш, 
   {{0x38781196,0x628006ea,0xddc8010e,0x00000000}},	//   hirr_, _ílop, njeň, --, 
   {{0xac080952,0x63a800df,0x75240b21,0xd02400a7}},	//   ىردە_, _ĝeni, nwiz, _имай, 
   {{0x3fc82ab4,0xbfc800db,0x8d540139,0x00000000}},	//   _قدمی_, _قامە_, етүч, --, 
   {{0x6fd806e3,0x68ee03c3,0x2c60067c,0x752603c4}},	//   _न्यू, _svad, _còda_, hwiz, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6e2203c5,0x6e6401d9,0x3e680f01,0xdcf400ec}},	//   memb, _لۅژِ_, _تجلی_, _مينڌ, 
   {{0x752603c6,0x38a40267,0x00000000,0x00000000}},	//   dwiz, töra_, --, --, 
   {{0x8aa414fb,0x2fc00210,0x00000000,0x00000000}},	//   _ирид, śigw_, --, --, 
   {{0x80d000bd,0x69cc01c7,0x38a401e3,0x68ec00dc}},	//   _সিস্, _ufae, röra_, _tvad, 
   {{0x752603c7,0x3944049f,0x6e20020c,0x68ecf61c}},	// [3abd0] gwiz, ämst_, iemb, _uvad, 
   {{0x6e210a19,0x07e800dd,0x65940032,0x6b5801e1}},	//   hemb, _کرکٹ_, _ҡану, _gúgú, 
   {{0x62340261,0xc4600092,0xb9ec0092,0x43084130}},	//   лежу, _ለከፍተ, _ኖት_, ьхам_, 
   {{0x752401b2,0xd73408a8,0xdee41086,0x00000000}},	//   bwiz, _עטרת_, ҳоки, --, 
   {{0x6e2203c8,0x1e9400d1,0x00000000,0x00000000}},	//   demb, һрир, --, --, 
   {{0xf7701d00,0xd00402dd,0x00000000,0x00000000}},	//   _داۋ_, геше_, --, --, 
   {{0x6e2203c9,0x81b80154,0xf2c40108,0x00000000}},	//   femb, _আজও_, _всун, --, 
   {{0x05a449f1,0x38a4e4c3,0x2c60068c,0x2cbc01a4}},	//   _खराब, jörn_, _ròda_, _aivd_, 
   {{0xdfd400fd,0xace401e0,0x00000000,0x00000000}},	//   _бозы, абыҙ, --, --, 
   {{0xe9f80016,0x1c44361e,0x9c647286,0x00000000}},	//   _thẻ_, уном, اهدو, --, 
   {{0x6e2203ca,0x98a400d1,0x6b580241,0x00000000}},	//   bemb, ғиве, _rúgú, --, 
   {{0x7c680092,0x3878002f,0x00000000,0x00000000}},	//   _ሽፈራው_, wirr_, --, --, 
   {{0xdea11e01,0x387801c3,0x00000000,0x00000000}},	//   _پیکی, tirr_, --, --, 
   {{0x2cbc0048,0x8c401b2e,0x997400fb,0x00000000}},	//   _givd_, _геше, _ҡупш, --, 
   {{0x38a401a8,0x7524002d,0x00000000,0x00000000}},	//   börn_, wwiz, --, --, 
   {{0x752603cb,0x787400ac,0x97c41219,0x00000000}},	//   twiz, _müvə, _әйне, --, 
   {{0xe9f80016,0x46a000f3,0x00000000,0x00000000}},	// [3abe0] _nhẹ_, сатв, --, --, 
   {{0x6e2203cc,0x752603cd,0xb4e4134e,0x00000000}},	//   zemb, rwiz, _नबी_, --, 
   {{0xe74457aa,0x7524000f,0x787403b9,0xe2a80014}},	//   _күре_, swiz, _nüvə, چانن_, 
   {{0x518477de,0x75240100,0xe2a95d8f,0x233408ca}},	//   лула, pwiz, نانن_, шхур, 
   {{0xf1b80184,0x80c400eb,0x4a7800df,0x00000000}},	//   тҡа_, রীস্, ערנב, --, 
   {{0x6e2203ce,0xb4c016f0,0x1834008f,0xab04002b}},	//   wemb, ँदी_, ראַל_, _jiṣṇ, 
   {{0xda080490,0xa3cc06b1,0x00000000,0x00000000}},	//   _वाढत_, _ष्ट_, --, --, 
   {{0xe3c0538f,0x4ea52281,0x00000000,0x00000000}},	//   ğış_, ырла, --, --, 
   {{0x6e2203cf,0x4250c5ff,0x61ec0008,0x10a42c31}},	//   remb, _انقر, ðale, _биан, 
   {{0xab0400b8,0x00000000,0x00000000,0x00000000}},	//   _niṣṇ, --, --, --, 
   {{0x6e2203d0,0xac092374,0x8fa437ed,0x78740213}},	//   pemb, ىرگە_, _саже, _güvə, 
   {{0x6e20016c,0xaa9603d1,0xfba4023a,0x63a00158}},	//   qemb, римч, ытый_, _ølne, 
   {{0x248c0020,0x2a780421,0x95e8015b,0x3a74109a}},	//   ናገሩት_, risb_, গলাম_, сляр, 
   {{0x38a4007c,0x00000000,0x00000000,0x00000000}},	//   sörn_, --, --, --, 
   {{0xddc800d7,0x00000000,0x00000000,0x00000000}},	//   sieť, --, --, --, 
   {{0x9f4405e4,0xaa0801ed,0xa5d42d1f,0xbb38011a}},	//   _belê_, _شعبے_, ржаш, _טעוי, 
   {{0x6aad4f39,0x1cd8031c,0xfd840131,0x69dc036e}},	// [3abf0] _ihaf, _འཆབ_, ﺭﻏﺎﻥ_, mbse, 
   {{0x225c2889,0x35b4e37d,0x7ea80432,0x69dc3fd6}},	//   wkwk_, сбур, _köpý, lbse, 
   {{0x6aae03d2,0x00000000,0x00000000,0x00000000}},	//   _khaf, --, --, --, 
   {{0x60ce03d3,0x41e400ec,0xf3700023,0x00000000}},	//   íamo, اساف, በርካዮ_, --, 
   {{0x6144da45,0x9f440660,0x2d8001f1,0x63a80115}},	//   рела, _gelê_, _žien_, _ĝenu, 
   {{0x9f0471a8,0x656c002f,0x61ec0413,0x00000000}},	//   لوتو, mzah, ðalb, --, 
   {{0x02a4fba7,0x656c03fa,0x27e4012d,0x68fc0112}},	//   _брам, lzah, ólny_, hrsd, 
   {{0x1cd8003d,0xd344107f,0x337401c0,0x6aac1d06}},	//   _འཆད_, _خیمه_, _угср, _nhaf, 
   {{0x656e03d4,0x2d9801e0,0x68fc01bf,0xc1d000fb}},	//   nzah, лөшө_, jrsd, _көҙә, 
   {{0x6aac0851,0xdc200135,0x98b000bc,0x69dc0112}},	//   _ahaf, _iċċi, _pryč_, ebse, 
   {{0x6aae03d5,0x68fd5779,0x656c03fa,0xafc402dd}},	//   _bhaf, ersd, hzah, _ايمى, 
   {{0x94f4025c,0x656c0e78,0x00000000,0x00000000}},	//   _བྷའི_, kzah, --, --, 
   {{0x6aac1f6d,0x1d08041b,0x00000000,0x00000000}},	//   _dhaf, _рели_, --, --, 
   {{0x656c0084,0x7e797b41,0x9f4400d8,0x00000000}},	//   dzah, liup, _relê_, --, 
   {{0xab040882,0x7bc019f5,0x68fc05e4,0x62880022}},	//   _viṣṇ, _ignu, arsd, _ojeo, 
   {{0x6aae03d6,0x7e78013c,0x212801f1,0xdc20031c}},	//   _ghaf, niup, ťahy_, _oċċi, 
  
   {{0x1b5c037e,0xb4c0012c,0x7ae00042,0x699400c0}},	// [3ac00] _ｃａｆé_, ँदे_, _hwnt, _грэх, 
   {{0xd7c807d6,0x7e78409c,0xc8c401d9,0xe9f801fb}},	//   _جوده_, hiup, _خوٝن_, _khế_, 
   {{0x7e7975f3,0xdc200135,0x13089b81,0x87f8008f}},	//   kiup, _aċċi, тней_, _בליץ, 
   {{0x29740020,0x6aac0023,0x63a8010f,0x9f4400d8}},	//   _አንፃር_, _xhaf, _ĝent, _telê_, 
   {{0x7bc203d7,0x7ae00770,0xb1182160,0xd13203d8}},	//   _ognu, _lwnt, اقتا_, تمش_, 
   {{0xb6080306,0x7ae0127b,0x00000000,0x00000000}},	//   _fešá, _ownt, --, --, 
   {{0x53a811b1,0xdc200135,0x7e78013c,0x2d800311}},	//   _करिश, _eċċi, fiup, _ţie_, 
   {{0xd174e88a,0x628802d3,0x7bc18b99,0x7e78013c}},	//   _кызы, _gjeo, _agnu, giup, 
   {{0x90443fff,0x6aae03d9,0x00000000,0x00000000}},	//   _پناه, _rhaf, --, --, 
   {{0x7ae001e0,0x7e780421,0x6aad8d16,0x4ea400fb}},	//   _bwnt, aiup, _shaf, ырһа, 
   {{0xe9f807ae,0x656e03da,0x7e780010,0x6aac0142}},	//   _chế_, zzah, biup, _phaf, 
   {{0xc330025f,0xb9e40046,0x6aac0117,0x7bc0022c}},	//   קור_, жіри, _qhaf, _egnu, 
   {{0x6aac0084,0xac1a03db,0x6cd410e0,0x69dc75ee}},	//   _vhaf, _болу_, _اقتا, rbse, 
   {{0x7c900592,0xb4c000bc,0x00000000,0x00000000}},	//   _وشوا, ँदो_, --, --, 
   {{0xb4c0038e,0xe9f80016,0x4ae407d6,0xa5f81b04}},	//   ँदै_, _ghế_, _тўла, леву_, 
   {{0x9f44033b,0x6aac13b8,0x656c03fa,0x3bb8011a}},	//   _delè_, _uhaf, tzah, _במוד, 
   {{0x18740092,0x00000000,0x00000000,0x00000000}},	// [3ac10] _አህጉር_, --, --, --, 
   {{0x656e03dc,0x73d80075,0x6288017a,0x26c40077}},	//   rzah, идур_, _sjeo, ílos_, 
   {{0x656c03fa,0x7ae00109,0xb7180166,0xe758003b}},	//   szah, _xwnt, _коэф_, _сині_, 
   {{0x09b803f4,0x46603818,0x00000000,0x00000000}},	//   _অ্যা, _بۇرق, --, --, 
   {{0x7e7a03dd,0x6fd800cd,0xfa78123b,0x00000000}},	//   viup, नुभू, סעדת_, --, 
   {{0xe2c86ea9,0xddc806be,0x00000000,0x00000000}},	//   _موسو_, fkeş, --, --, 
   {{0x645603de,0x6234c134,0x7e795a27,0xc9780023}},	//   _iozi, _леву, tiup, _ብኸፊል_, 
   {{0x6454006c,0xa0c498f0,0x00000000,0x00000000}},	//   _hozi, _هيرو, --, --, 
   {{0x629a03df,0x7e780eda,0x7bc00175,0x61e800de}},	//   mowo, riup, _pgnu, _ieel, 
   {{0x62982f99,0x212c00f2,0xac1800d6,0x6454195a}},	//   lowo, _iseh_, ацює_, _jozi, 
   {{0x645603e0,0x61e8033d,0xf4580375,0x7ae00455}},	//   _mozi, _keel, ייזר_, _qwnt, 
   {{0x60c203e1,0x645603e2,0x629a03e3,0x61ea03e4}},	//   _hilm, _lozi, nowo, _jeel, 
   {{0x61ea03e5,0x60c203e6,0x60c8020c,0x645603e7}},	//   _meel, _kilm, _juem, _oozi, 
   {{0xe9f801dc,0x645603e8,0x7bc008e5,0x60c83024}},	//   _thế_, _nozi, _ugnu, _muem, 
   {{0x629a03e9,0x60ca03ea,0x60c203eb,0x3ab400d1}},	//   kowo, _luem, _milm, _мәмт, 
   {{0x61ea03ec,0x629a03ed,0x9f44031d,0x60c203ee}},	//   _neel, jowo, _celé_, _lilm, 
   {{0x629a03ef,0x645603f0,0x9f440241,0xceb00375}},	// [3ac20] dowo, _bozi, _delé_, ליל_, 
   {{0x645403b7,0x9f44026c,0x4430009a,0x63a8010f}},	//   _cozi, _telè_, gdx_, _ĝenr, 
   {{0x61e8a6e7,0x645603f1,0x212c0548,0x629a03f2}},	//   _beel, _dozi, _aseh_, fowo, 
   {{0x61ea03f3,0x60c0538c,0x9f440158,0x66ec00e1}},	//   _ceel, _ailm, _gelé_, _जबतक_, 
   {{0x60c16eeb,0x61e94c79,0x86340302,0x645603f4}},	//   _bilm, _deel, _הרכב_, _fozi, 
   {{0x60c00050,0x60c802e8,0x70541ec7,0x00000000}},	//   _cilm, _duem, تنتا, --, 
   {{0x60c203f5,0xe9f800e4,0x61e8f7a5,0x629a03f6}},	//   _dilm, _ahẽ_, _feel, bowo, 
   {{0x61e809c8,0x60c203f7,0x6298068f,0x645449e1}},	//   _geel, _eilm, cowo, _zozi, 
   {{0x6454006c,0xc0e0531d,0x60ca03f8,0xe9f801fb}},	//   _yozi, _нотк, _guem, _chẽ_, 
   {{0x61ea03f9,0x645401b9,0xdcac0372,0x6af400f3}},	//   _zeel, _xozi, نۉن_, озоф, 
   {{0x61ea03fa,0xfd0c0403,0x00000000,0x00000000}},	//   _yeel, وجی_, --, --, 
   {{0x61e801d9,0x628801e4,0xaf40001f,0x60c0022e}},	//   _xeel, _ĉeok, ተደረገ, _zilm, 
   {{0x9f44db27,0x60c013f8,0xcd341e4b,0xebc42de5}},	//   _relé_, _yilm, _دراب, _мәнн, 
   {{0x9f444a16,0x6298cf6d,0x60c001b9,0x00000000}},	//   _selé_, zowo, _xilm, --, 
   {{0x645603fb,0x9f440798,0x6298055a,0xa634003b}},	//   _rozi, _pelé_, yowo, онві, 
   {{0x64545c45,0x2348029e,0xe694104e,0x00000000}},	//   _sozi, یسای_, цибы, --, 
   {{0xa3e40562,0x6b840055,0x00000000,0x00000000}},	// [3ac30] नरल_, _śigh, --, --, 
   {{0x2a680211,0x629a03fc,0x03c603fd,0x60c80007}},	//   _hlab_, wowo, ссам, _ruem, 
   {{0x61ea03fe,0x6454b832,0x60ca03ff,0x383440ad}},	//   _peel, _vozi, _suem, _энэр, 
   {{0x60c20400,0x60c819f5,0x61e866db,0x4cdc009e}},	//   _silm, _puem, _qeel, _মিনু, 
   {{0x629a0401,0x60ca0402,0x61ea0403,0x645404ba}},	//   rowo, _quem, _veel, _tozi, 
   {{0x212c0fb7,0x60c20404,0x61ea0405,0x629a0406}},	//   _vseh_, _qilm, _weel, sowo, 
   {{0x61e8ad1a,0x661c003e,0x2a680098,0x60c800d8}},	//   _teel, _kbsk, _olab_, _wuem, 
   {{0x3cfc1529,0x2a68036b,0x60c8d408,0xa1580139}},	//   truv_, _nlab_, _tuem, _кабу_, 
   {{0x60c20407,0x60c800af,0x80d00011,0x9f780092}},	//   _tilm, _uuem, _সিক্, _እንዲሉ_, 
   {{0x2a681c06,0x00000000,0x00000000,0x00000000}},	//   _alab_, --, --, --, 
   {{0x661e0408,0x2a68e615,0x00000000,0x00000000}},	//   _obsk, _blab_, --, --, 
   {{0x9db8008e,0x00000000,0x00000000,0x00000000}},	//   _кылу_, --, --, --, 
   {{0x660800c7,0xdc080451,0x38a4000d,0x00000000}},	//   _ñeky, _نقشو_, löri_, --, 
   {{0x2a6800af,0x9f78001f,0x1ae4010b,0x91b8011a}},	//   _elab_, _እንዳሉ_, _докм, ימרי, 
   {{0x2a6804cc,0xe1f80064,0x69c0012d,0x00000000}},	//   _flab_, _odų_, ślep, --, 
   {{0x2a680280,0x00000000,0x00000000,0x00000000}},	//   _glab_, --, --, --, 
   {{0x13ea0409,0xaa0800cf,0x15b81f39,0x00000000}},	// [3ac40] имай_, _ازىل_, рывы_, --, 
   {{0x2a6801b9,0x661c02d0,0x00000000,0x00000000}},	//   _zlab_, _ebsk, --, --, 
   {{0x2a6807d6,0xd1c80276,0x3494030d,0x00000000}},	//   _ylab_, алее_, çатр, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe63401c6,0x00000000,0x00000000,0x00000000}},	//   _эхээ, --, --, --, 
   {{0xa3e400cd,0xddc80064,0xd468b3f0,0x00000000}},	//   नरः_, giež, _тиге_, --, 
   {{0xed5000dd,0x03a05aa2,0x00000000,0x00000000}},	//   کھا_, _жиро, --, --, 
   {{0x4220009b,0x4cdc00cc,0x00000000,0x00000000}},	//   _одсв, _মিবু, --, --, 
   {{0xd00815ed,0x9f440109,0x2a6801a9,0x00000000}},	//   _везе_, _helì_, _rlab_, --, 
   {{0x09e070b0,0x2c6001e1,0x2a680f85,0xab7400db}},	//   पर्य, _kòdi_, _slab_, згош, 
   {{0x2a6a040a,0x2c6002bd,0x4e2806ed,0xe1f80064}},	//   _plab_, _jòdi_, _воен_, _ydų_, 
   {{0x2a6801a9,0x00000000,0x00000000,0x00000000}},	//   _qlab_, --, --, --, 
   {{0x17e000bd,0xdb100086,0x00000000,0x00000000}},	//   _বাড়ি, ògòm, --, --, 
   {{0x6e240de2,0x80c40154,0x00000000,0x00000000}},	//   _ñibb, রীক্, --, --, 
   {{0x2a68022e,0x00000000,0x00000000,0x00000000}},	//   _tlab_, --, --, --, 
   {{0xfb8404fb,0x2a6801a9,0x00000000,0x00000000}},	//   _بدهی, _ulab_, --, --, 
   {{0x661c00e3,0xe738f49b,0x00000000,0x00000000}},	// [3ac50] _vbsk, шең_, --, --, 
   {{0x8366040b,0x2c600100,0x7b0401ef,0x00000000}},	//   يدال, _bòdi_, _ústí, --, 
   {{0x2c60068c,0xddc80030,0x61ec0162,0x00000000}},	//   _còdi_, viež, ðalo, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf0e804a9,0x64c40220,0x00000000,0x00000000}},	//   قىنى_, _ءيسل, --, --, 
   {{0x55b80302,0x9f440268,0x660c3496,0x00000000}},	//   _למרו, _felì_, lgak, --, 
   {{0x660c073c,0xff52040c,0xddc800e2,0x4ac4cd66}},	//   ogak, بخش_, riež, _रंगव, 
   {{0x38a4000d,0x00000000,0x00000000,0x00000000}},	//   röri_, --, --, --, 
   {{0xddc80024,0x660e040d,0x5f942b9f,0x00000000}},	//   piež, igak, _کلائ, --, 
   {{0x9f440270,0x3f807c2e,0xb82000cc,0x00000000}},	//   _helí_, _оғла, _ফোনত_, --, 
   {{0x660e040e,0x9f14031c,0x00000000,0x00000000}},	//   kgak, _ཊཱིཀ_, --, --, 
   {{0xd354011a,0x00000000,0x00000000,0x00000000}},	//   ליתי_, --, --, --, 
   {{0x6ef001e1,0x00000000,0x00000000,0x00000000}},	//   _tóbá, --, --, --, 
   {{0x660c0158,0x95f41fd2,0x15ec012d,0x00000000}},	//   egak, ेल्ट_, _ज़हर_, --, 
   {{0x2b140124,0x41c81777,0x00000000,0x00000000}},	//   _жьыр, िशास, --, --, 
   {{0xc6c00410,0xa3c00073,0x04000154,0x95c83532}},	//   ейск, ुशन_, র্মী_, слаб_, 
   {{0x2c600ba1,0x7e900311,0x3a200332,0x00000000}},	// [3ac60] _sòdi_, căpe, _ibip_, --, 
   {{0x660e040f,0x2c60068c,0x9984004b,0x69a400fb}},	//   agak, _pòdi_, _ولګو, _юлыҡ, 
   {{0x39400165,0xe00441d8,0x53a4007b,0x00000000}},	//   _hris_, _राजद_, أماك, --, 
   {{0x39420410,0x3a20003a,0x9f4402f0,0x00000000}},	//   _kris_, _jbip_, _celí_, --, 
   {{0x463800c8,0x394004cc,0x3034023a,0x10a400d8}},	//   _העכע, _jris_, делё, пидн, 
   {{0x7e68000d,0x3940045a,0x00000000,0x00000000}},	//   _algp, _mris_, --, --, 
   {{0x91e60411,0x9f44004e,0xddd80100,0x7ff004f2}},	//   _нове, _felí_, _kowň, رسوا, 
   {{0x39420412,0x787001e6,0x62644c2d,0xddc80210}},	//   _oris_, _hävd, _قاقق, cież, 
   {{0x39400218,0xfbe00183,0x7174215c,0x32f8033b}},	//   _nris_, _মাজত, _تۇشا, lčy_, 
   {{0xf04477c2,0x9f440118,0x84680023,0x660c0718}},	//   _تعری, _zelí_, _ቡዙሓን_, zgak, 
   {{0x09b4543b,0xaa946d60,0x0dc8011c,0x7b10009d}},	//   ृश्य, динч, _лули_, ндэх, 
   {{0x39420413,0x6fd83599,0x00000000,0x00000000}},	//   _bris_, नुरू, --, --, 
   {{0x8c45e511,0x7e7401f5,0x00000000,0x00000000}},	//   _неде, ëxpe, --, --, 
   {{0xddc8033f,0x32f80100,0x00000000,0x00000000}},	//   zież, kčy_, --, --, 
   {{0xbc360414,0x3940d507,0x15d80521,0xd5d8063f}},	//   _رسوا_, _eris_, _ọbụl, _ọrụr, 
   {{0x443d0a1d,0x39420415,0x2f3c01e4,0x32f8007f}},	//   _şu_, _fris_, _mĉg_, dčy_, 
   {{0x8d80044e,0x660e0416,0x61ec01a8,0x6fcc0a59}},	// [3ac70] _ክትብል_, rgak, ðalm, ाशां, 
   {{0x2918bbf3,0xddc83af2,0x00000000,0x00000000}},	//   mtsa_, wież, --, --, 
   {{0xaca401f2,0x291801c6,0x9f4400d8,0xc76403cc}},	//   _ngọz, ltsa_, _pelí_, _رادى, 
   {{0x291a0417,0x00000000,0x00000000,0x00000000}},	//   otsa_, --, --, --, 
   {{0x291a0418,0xaca401f2,0x9fc8011b,0x80d00154}},	//   ntsa_, _agọz, огла_, _সিঙ্, 
   {{0xf99404ac,0x32980150,0xc25402f2,0x29180166}},	//   ערס_, _ﺘﻌﻜﺱ_, _کخست, itsa_, 
   {{0x291800c5,0xddc8033f,0x5edc03d4,0x00000000}},	//   htsa_, pież, _যিহে, --, 
   {{0x291802d1,0xb9140055,0x38a4007c,0xedf400d1}},	//   ktsa_, _tvaḥ_, lört_, ىيىگ, 
   {{0x9f440589,0x291a0419,0x78712d5f,0x00000000}},	//   _belã_, jtsa_, _häve, --, 
   {{0x787002f6,0x1c442c25,0x39400200,0x00000000}},	//   _käve, фном, _rris_, --, 
   {{0x2918d4fa,0x9f440589,0x0400015b,0x1a284961}},	//   etsa_, _delã_, র্থী_, ожни_, 
   {{0x38a40639,0x4a400212,0x8f98011a,0x00000000}},	//   hört_, внюв, _ויעי, --, 
   {{0x78700037,0x3d24010a,0x00000000,0x00000000}},	//   _läve, _хьев, --, --, 
   {{0x8c400022,0x0400015b,0x3e800248,0x660800e2}},	//   _аеше, র্তী_, _fètè_, _ķeka, 
   {{0x3940000d,0x787001e3,0xc7a00a0e,0x38a40205}},	//   _wris_, _näve, вирк, dört_, 
   {{0x38a40008,0xd9f0ecd9,0x785801d3,0x78700166}},	//   vöru_, _अजित_, _کیسز_, _sävd, 
   {{0x9f4405da,0x38a401e6,0x00000000,0x00000000}},	// [3ac80] _lelà_, fört_, --, --, 
   {{0xb9cc001f,0x787001e3,0x32f80100,0x88800153}},	//   _ሰሚ_, _bäve, tčy_, _альж, 
   {{0xf6e80327,0x527400d1,0x7870007c,0x00000000}},	//   _འཆིང, муду, _vävd, --, 
   {{0x7870008e,0x32f802e2,0xd184010b,0x00000000}},	//   _däve, rčy_, млей, --, 
   {{0x6a6c002d,0x00000000,0x00000000,0x00000000}},	//   _jûfa, --, --, --, 
   {{0xe3b001d3,0x00000000,0x00000000,0x00000000}},	//   ئرے_, --, --, --, 
   {{0x9f44004a,0x00000000,0x00000000,0x00000000}},	//   _celà_, --, --, --, 
   {{0x9f44a5c3,0xc24000a8,0x29197723,0x00000000}},	//   _delà_, _инск, ytsa_, --, 
   {{0xd71809bd,0x00000000,0x00000000,0x00000000}},	//   ডিয়া_, --, --, --, 
   {{0xace80022,0x628001e1,0x00000000,0x00000000}},	//   омҩа_, _ìlor, --, --, 
   {{0xda082017,0xb81403d4,0x38a4002f,0x1ea800f1}},	//   वलंत_, াজাত_, hörs_, _کالي_, 
   {{0x3e800100,0x78700139,0xd1c40023,0xcfe400cc}},	//   _vètè_, _nävb, _ሽመት_, _নাটন, 
   {{0x291a041a,0x3a7463da,0x7d70009f,0xc198010f}},	//   utsa_, тляр, _لاوط, ַשלי, 
   {{0x291a041b,0x9d640014,0x25ac031c,0x3e800cad}},	//   rtsa_, _سنى۪, _ġel_, _tètè_, 
   {{0x25ae041c,0xdc545035,0x291a041d,0x61ec0413}},	//   _šel_, _سروک, stsa_, ðalk, 
   {{0x78700724,0x38a401e6,0xfaa400c7,0x9990013a}},	//   _räve, förs_, _ишын, _gayů_, 
   {{0x38a6041e,0x787008ae,0x69cc007b,0x85b801d9}},	// [3ac90] görs_, _säve, _igae, زارس_, 
   {{0x6abe041f,0x68ec0cad,0x691400ee,0x76400162}},	//   lmsf, _iwad, _eýeç, _ómyn, 
   {{0x69cc01e0,0x68ec006f,0x27685533,0x38a401e3}},	//   _kgae, _hwad, _رشدی_, rört_, 
   {{0x68ee0420,0x0b7002d3,0x224801c6,0x38a4fb94}},	//   _kwad, _ብጉዳይ_, ñak_, börs_, 
   {{0x602517e8,0x6d4402d5,0x9f440109,0x6abc0158}},	//   едла, _šian, _selà_, imsf, 
   {{0x68ee0421,0x7870007c,0x00000000,0x00000000}},	//   _mwad, _täve, --, --, 
   {{0x8fa20422,0x68ec0107,0x69cc0618,0x9f4400d0}},	//   лаше, _lwad, _ogae, _belá_, 
   {{0x69ce0423,0x68ee0424,0x9f440232,0xdd0001fa}},	//   _ngae, _owad, _celá_, žučk, 
   {{0x68ec063f,0x72040137,0x32c80022,0x9f4400d7}},	//   _nwad, _جوقم, _цыро_, _delá_, 
   {{0x69cc0b23,0xd34400e5,0x80c808a3,0x31340114}},	//   _agae, _تفہی, ादीं, _јефр, 
   {{0x68ee0425,0x442005b1,0xddc80311,0x5ba8115c}},	//   _awad, _mbj_, gheţ, яком_, 
   {{0x44201140,0x68ee0426,0xaae40214,0x00000000}},	//   _lbj_, _bwad, کسیو, --, 
   {{0x44210237,0x68edc450,0x38a401e3,0x00000000}},	//   _obj_, _cwad, dörr_, --, 
   {{0x69cc0810,0x7d181bb6,0x18686777,0x6abc017a}},	//   _egae, mtus, чаги_, amsf, 
   {{0x68ee0427,0x7c200ac5,0x7d1a0428,0x28760429}},	//   _ewad, _ibnr, ltus, тыяр, 
   {{0xda080574,0x4422042a,0xddc80356,0xf98401d5}},	//   _वाटत_, _abj_, cheţ, _аҳмо, 
   {{0x68ee042b,0x44200477,0x8d80001f,0x69940153}},	// [3aca0] _gwad, _bbj_, _ክትትል_, _арэх, 
   {{0x7d18049b,0x38a40267,0xf40800eb,0x00000000}},	//   itus, rörs_, র্নর_, --, 
   {{0x44200048,0x7d1800af,0x16a800d8,0x38a4007c}},	//   _dbj_, htus, _нвои_, sörs_, 
   {{0x644002d2,0x00000000,0x00000000,0x00000000}},	//   _ólin, --, --, --, 
   {{0x4420020c,0x7d1a042c,0x86400153,0x00000000}},	//   _fbj_, jtus, _сняж, --, 
   {{0x8141328f,0x7d18005c,0x9f4402d2,0x00000000}},	//   انون, dtus, _selá_, --, 
   {{0x7d1a042d,0x00000000,0x00000000,0x00000000}},	//   etus, --, --, --, 
   {{0x7d1a042e,0x4824001f,0x03a0014b,0x00000000}},	//   ftus, _ቴዎድሮ, _сисо, --, 
   {{0x7d1a042f,0xda0801f9,0x00000000,0x00000000}},	//   gtus, _वाजत_, --, --, 
   {{0x68ee0430,0x69cc005a,0x20ca0431,0x00000000}},	//   _rwad, _sgae, _قبلي_, --, 
   {{0x68ee0432,0x7d1800af,0x05a400e1,0x9f4400d0}},	//   _swad, atus, _कुनब, _telá_, 
   {{0x68ee0433,0x00000000,0x00000000,0x00000000}},	//   _pwad, --, --, --, 
   {{0xac180372,0x7d1a0434,0x61ec05f7,0x9e642e0b}},	//   _жолу_, ctus, ðali, _جالن, 
   {{0x68ec0100,0xc7c4004e,0x00000000,0x00000000}},	//   _vwad, есби, --, --, 
   {{0x6d4017b8,0xda080073,0x4668b971,0xda140133}},	//   lvma, _वाचत_, прам_, رسێک, 
   {{0x68ec193f,0x44200051,0x00000000,0x00000000}},	//   _twad, _sbj_, --, --, 
   {{0x68ee0435,0x4404040e,0xa3d4005b,0x399c013a}},	// [3acb0] _uwad, ечеб, возч, _pásů_, 
   {{0x6d40000d,0x00000000,0x00000000,0x00000000}},	//   ivma, --, --, --, 
   {{0xf9901632,0xe69400c7,0x6d440030,0xf408015b}},	//   _نبی_, _аины, _šial, র্ভর_, 
   {{0x44200066,0x7d180fac,0x9b2c0092,0x6e200200}},	//   _wbj_, ytus, ዲሰጣቸ, jfmb, 
   {{0x7d180227,0x7870007c,0xa1580022,0x00000000}},	//   xtus, _häva, ьаду_, --, 
   {{0x9990012d,0xa3d400f0,0xb97c00df,0x00000000}},	//   _abyś_, _јовч, הנדי, --, 
   {{0xd00dea72,0x3494f42e,0x50a000d1,0x1e942377}},	//   زلي_, _сарр, جەلل, крир, 
   {{0x7d1a0436,0x7c203223,0x040000eb,0x00000000}},	//   ttus, _sbnr, র্শী_, --, 
   {{0x44ec3d79,0x7d194090,0x7c200175,0xfe7401c0}},	//   nż_, utus, _pbnr, _үүл_, 
   {{0x7d1832ff,0xad24215e,0x9f44005c,0x5fa8000d}},	//   rtus, اريو, _relæ_, _चँपल, 
   {{0x7d1a0437,0x9f3402dd,0x7871489f,0x6d420438}},	//   stus, _шежі, _näva, avma, 
   {{0x7d1a0439,0xa3b832ed,0x7de4007b,0xcf8c0244}},	//   ptus, _चरन_, _أسام, _بژه_, 
   {{0x3ebc0af5,0x6fd807d0,0x4e78008f,0x97d8005b}},	//   mmut_, नुकू, _קאנצ, дьбу_, 
   {{0x3ebe043a,0xcd74008f,0x7870007c,0x88e000d4}},	//   lmut_, _בענק_, _bäva, ржре, 
   {{0x44ec006d,0x224c009d,0x00000000,0x00000000}},	//   eż_, _onek_, --, --, 
   {{0x3ebc0d04,0x78700724,0x00000000,0x00000000}},	//   nmut_, _däva, --, --, 
   {{0x3ebc0869,0x9f440790,0x461001b9,0xc560004e}},	// [3acc0] imut_, _felç_, شولر, актк, 
   {{0x224c9c2f,0x3ebe043b,0x98a0012d,0x00000000}},	//   _anek_, hmut_, ywkę_, --, 
   {{0xa30000ee,0xf98801f7,0x00000000,0x00000000}},	//   йүре, _آنڌي_, --, --, 
   {{0x5186043c,0x6d4402d5,0x95840835,0x03a01069}},	//   кула, _šiam, _алме, шихо, 
   {{0xe7d8012d,0xb0480022,0x00000000,0x00000000}},	//   बुकप, нҷаз_, --, --, 
   {{0xc01000d6,0x224d1efc,0x9404009f,0xf0b4008e}},	//   иміщ, _enek_, _جوآه, ыйль, 
   {{0xb4c0d857,0xceb8026a,0xe7c403d4,0x2ab8398f}},	//   ुदी_, мљи_, ্ৰীয, lébe_, 
   {{0x4ea4036b,0x7e409d5c,0x00000000,0x00000000}},	//   ърла, ахье, --, --, 
   {{0x90c401af,0x0fe0004e,0x8fe001ee,0x00000000}},	//   _абае, _көйү, _кәйҙ, --, 
   {{0x3ebc7e99,0xa3b82366,0x9f4400fd,0x4de00d26}},	//   amut_, _चरम_, _belä_, _ट्रै_, 
   {{0x3cb00209,0x4cd800fe,0x88dc00eb,0x00000000}},	//   рйэр, _দিওঁ, _ভয়ংক, --, 
   {{0x0d840cef,0xaa5804a9,0x7870712c,0xf3700023}},	//   _илен, химу_, _räva, በርናዮ_, 
   {{0xbc340424,0x7c340024,0x787001e3,0x2ab800e5}},	//   رسیا_, _šarū, _säva, jébe_, 
   {{0xdbd0010e,0x290414b2,0xac18004e,0x00000000}},	//   _küýk, čla_, _чоку_, --, 
   {{0x8b640f87,0xc6a42c31,0x44ec0327,0xdee00023}},	//   _جاشم, враи, wż_, _ዓብን_, 
   {{0x0576043d,0xdce8009b,0x49909831,0x7870007c}},	//   پارد, uzeć, _نیجر, _väva, 
   {{0x5fa8000d,0x00000000,0x00000000,0x00000000}},	// [3acd0] _चुनल, --, --, --, 
   {{0x224e043e,0x69dc01d3,0x7870007c,0xa3c01428}},	//   _snek_, lcse, _hävn, ुशल_, 
   {{0x3ebc0194,0xa5f826b1,0x00000000,0x00000000}},	//   ymut_, _пену_, --, --, 
   {{0x69dc00dd,0xf5e40212,0x35e400d8,0x00000000}},	//   ncse, _вірм, _вцрв, --, 
   {{0xe125e1f2,0x69dc0332,0x68fc0162,0x00000000}},	//   умли, icse, nssd, --, 
   {{0xd12c0075,0x3fc40b28,0x00000000,0x00000000}},	//   سمى_, نگای_, --, --, 
   {{0xdca404a9,0x7e7401a4,0x3ebc0129,0xa29400c0}},	//   ғани, ëxpo, tmut_, _баві, 
   {{0x3ebc0eda,0x224d37b0,0x9f4401e3,0xf1d492fe}},	//   umut_, _unek_, _relä_, _көшө, 
   {{0x3ebce396,0xc0a85024,0x3134135c,0x80c40183}},	//   rmut_, _قائل_, _кетр, ৰীষ্, 
   {{0x3ebc00db,0x61fa043f,0xdca400d8,0x00000000}},	//   smut_, lawl, ѓани, --, 
   {{0x20d80ba1,0x2ab801d3,0xe04401ee,0x00000000}},	//   _hèi_, zébe_, _инҡи, --, 
   {{0x3ebc0357,0x99143334,0x69dc01d3,0xfd44014b}},	//   qmut_, льгі, gcse, _аҷик_, 
   {{0xe8f40831,0x3f400139,0x68340023,0x00000000}},	//   аһы_, _hıu_, _ብምምስ, --, 
   {{0x20da0440,0x61fa0441,0xdd900451,0xc0dc0023}},	//   _mèi_, hawl, _پوڻ_, _ዓቅሚ_, 
   {{0xd629ddfd,0x61fa0442,0x20d80ba1,0xdbd000c5}},	//   нове_, kawl, _lèi_, _müük, 
   {{0x69dc01ed,0x7c8002d3,0xfbdc18cc,0x1ab003d4}},	//   ccse, _ክብሃል_, पुरम, _ঘূৰা, 
   {{0xd9460443,0x142568e8,0x61f84e57,0x00000000}},	// [3ace0] _сепи, лдам, dawl, --, 
   {{0x2ab801d3,0x57e801f4,0x00000000,0x00000000}},	//   rébe_, _ядом_, --, --, 
   {{0xa3b81d8a,0x1b2000cc,0x2ab800e5,0x00000000}},	//   _चरण_, যিকে_, sébe_, --, 
   {{0x20d8068c,0x51f5a7d9,0x7e7401f5,0x61f80327}},	//   _bèi_, اسار, ëxpl, gawl, 
   {{0xdbd0010e,0x845000db,0x00000000,0x00000000}},	//   _süýk, _گۉلچ, --, --, 
   {{0x20da0444,0x53a400db,0x00000000,0x00000000}},	//   _dèi_, _багб, --, --, 
   {{0xcf24a5d1,0x00000000,0x00000000,0x00000000}},	//   ارتي, --, --, --, 
   {{0xa3b829da,0x61ec0321,0x00000000,0x00000000}},	//   _चरत_, ðalt, --, --, 
   {{0xa2a04966,0x101512cd,0x00000000,0x00000000}},	//   गकर्, _مباد, --, --, 
   {{0x7ae001ee,0xdbd00432,0x71a40150,0x00000000}},	//   _btnt, _tüýk, _бағз, --, 
   {{0xae5405d9,0xcc0801d5,0xf9ec0154,0xff040408}},	//   _پراڻ, وزگن_, _কাজল_, _бехк_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6c5403b7,0x78700267,0x68fc01c7,0x69dc01d3}},	//   _вклу, _vävn, ussd, rcse, 
   {{0x9180004d,0x7d78011a,0x00000000,0x00000000}},	//   _mềm_, _אנדו, --, --, 
   {{0xefe80201,0x7bd80375,0x04640220,0x00000000}},	//   _ዘንድ_, _אקוו, қтам, --, 
   {{0x61f800e8,0x00000000,0x00000000,0x00000000}},	//   xawl, --, --, --, 
   {{0x787001e3,0xe55400f0,0xa934004e,0x36d40150}},	// [3acf0] _kävl, шкањ, _тепш, _қояр, 
   {{0x7870049f,0x20d8180f,0x61f80327,0x00000000}},	//   _jävl, _rèi_, wawl, --, 
   {{0x20d80ba1,0x61fa0445,0x7dc8010e,0x00000000}},	//   _sèi_, tawl, _kösü, --, 
   {{0x7f740184,0xdbd0000d,0x270000c0,0x00000000}},	//   ңҡар_, _süük, mėn_, --, 
   {{0x61fa0446,0x94400014,0x27000064,0x00000000}},	//   rawl, _ژھٔن, lėn_, --, 
   {{0xd0040c56,0xe0440116,0xf194010a,0x00000000}},	//   аеше_, рнки, щичь, --, 
   {{0x6fcc06ab,0xd3440424,0x20d801c7,0x27000024}},	//   ाशगं, _پینه_, _wèi_, nėn_, 
   {{0x61ec005a,0xa2940212,0x61f8047e,0x9e640117}},	//   ñald, _табі, qawl, рвид, 
   {{0x20d81497,0x00000000,0x00000000,0x00000000}},	//   _uèi_, --, --, --, 
   {{0x0dc40724,0x9990010e,0xe9f801e1,0xa3b800bc}},	//   шлый_, _abyş_, _ikẹ_, _चरा_, 
   {{0x200401ab,0x78700166,0x9f440241,0x00000000}},	//   _idli_, _dävl, _lelú_, --, 
   {{0x787029ef,0xd9440395,0x00000000,0x00000000}},	//   _pävo, аеми, --, --, 
   {{0x98b000cd,0x999c00bc,0x443110de,0xc0dc02d3}},	//   _asyā_, ětů_, kex_, _ናህሪ_, 
   {{0x7870049f,0x95ec05d7,0x44300327,0x99381171}},	//   _gävl, जर्ट_, jex_, няҳу_, 
   {{0x44320447,0xe7e445bf,0x387801c7,0x3cfc01a9}},	//   dex_, कड़ा_, rhrr_, lsuv_, 
   {{0x6d4402d5,0xc7a20448,0x787001b8,0x00000000}},	//   _šiai, циск, _tävo, --, 
   {{0x44320449,0x9f4401f1,0x95c8020a,0x2004015d}},	// [3ad00] fex_, _celú_, тлаб_, _odli_, 
   {{0xb9dc1e38,0x44303c36,0x27000153,0x00000000}},	//   _ጢሞ_, gex_, bėn_, --, 
   {{0x212c5204,0x2278210e,0x00000000,0x00000000}},	//   _apeh_, گلنگ_, --, --, 
   {{0x2006044a,0x3cfc0254,0x00000000,0x00000000}},	//   _adli_, ksuv_, --, --, 
   {{0x20040334,0x90c42826,0xd0102d4b,0x6e2400e8}},	//   _bdli_, абде, قلش_, _ñibi, 
   {{0x4432044b,0x00000000,0x00000000,0x00000000}},	//   cex_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3ddc009a,0xb64804ce,0x5276044c,0x0dc91a8f}},	//   gcuw_, _ｊａ_, _тугу, купи_, 
   {{0x61ed0df4,0xc0e02bbd,0x00000000,0x00000000}},	//   ñale, _мотк, --, --, 
   {{0x8c66044d,0xcee800d6,0x3d4001e1,0x00000000}},	//   ртид, _адже_, _ọwó_, --, 
   {{0x8fa6044e,0x00000000,0x00000000,0x00000000}},	//   _таже, --, --, --, 
   {{0xbd845a76,0x0a682c31,0x44300332,0xa3b804aa}},	//   انین_, трои_, zex_, _चरस_, 
   {{0x787004f3,0x00000000,0x00000000,0x00000000}},	//   _tävl, --, --, --, 
   {{0x9ba401d9,0x44300135,0x8704013d,0x00000000}},	//   _گلى۪, xex_, иябе, --, 
   {{0x443089cc,0x00000000,0x00000000,0x00000000}},	//   vex_, --, --, --, 
   {{0xaa2c02f6,0x2ab800d2,0x9f440241,0x44300210}},	//   ämää_, béba_, _pelú_, wex_, 
   {{0x6aae044f,0x4431d897,0x00000000,0x00000000}},	// [3ad10] _ikaf, tex_, --, --, 
   {{0xc3c800c6,0xf5040014,0x978000f2,0x00000000}},	//   نظام_, زِمُ, _کیفه, --, 
   {{0x44320450,0x389c10df,0x05a44ed3,0x4e1400bc}},	//   rex_, _ביזנ, _कुरब, णलाई_, 
   {{0xf6d404fb,0x05d800bc,0x00000000,0x00000000}},	//   _گزید, _भलिब, --, --, 
   {{0x61441583,0x6aac01f7,0xd3f403d4,0xd13c0092}},	//   села, _mkaf, _চাৰি_, _ባይቻል, 
   {{0x6aacb24f,0x61ec00e4,0x7084003b,0x00000000}},	//   _lkaf, ñalb, огіз, --, 
   {{0x33941b74,0x656c01d9,0x335800c0,0x00000000}},	//   _дарё, lyah, _карэ_, --, 
   {{0x6aac00ca,0x2ab80085,0x656c0009,0x3cfc0254}},	//   _nkaf, yéba_, oyah, tsuv_, 
   {{0x656e0451,0x628a0452,0xddd8033f,0xdbd000a2}},	//   nyah, _imeo, _powł, _süñk, 
   {{0x6aacb514,0x0d8128a1,0x5c541606,0x656d4a01}},	//   _akaf, ялын, стиф, iyah, 
   {{0x2ab800d2,0x5ac8490c,0x00000000,0x00000000}},	//   wéba_, ллом_, --, --, 
   {{0x3d90013d,0xd354011a,0x00000000,0x00000000}},	//   _һиҗр, צירי_, --, --, 
   {{0x656c0796,0x628801f7,0x1d08854b,0xe7b40150}},	//   jyah, _mmeo, _сели_, _ﺼﺭﺍﻟ, 
   {{0x6aac02ea,0x656e0453,0xec780212,0x7e78002f}},	//   _ekaf, dyah, _кпі_, lhup, 
   {{0x6aac03a0,0x628992ba,0x9f44011c,0x656c0014}},	//   _fkaf, _omeo, _pelù_, eyah, 
   {{0x6aac020c,0xaae442b5,0x656c058a,0x00000000}},	//   _gkaf, _بسوو, fyah, --, 
   {{0x656e0454,0x00000000,0x00000000,0x00000000}},	// [3ad20] gyah, --, --, --, 
   {{0x628a0455,0x06e4015b,0x7eb400c7,0x00000000}},	//   _ameo, _ফিরি, kãpo, --, 
   {{0x7e7a0456,0x656ce2e6,0x130a0457,0xd20801c6}},	//   khup, ayah, уней_, гэлд_, 
   {{0x656e0458,0xd9f81d8a,0x6aac031c,0x626400d1}},	//   byah, ्णित_, _xkaf, يانق, 
   {{0x656c01aa,0x5064dfe6,0x66080086,0x76460459}},	//   cyah, йтка, _ôeka, mdiy, 
   {{0x764403be,0x10081216,0x752401f7,0x32f000a2}},	//   ldiy, اتشى_, mtiz, _aşyň_, 
   {{0xa4f40327,0x7646045a,0x91e4026b,0x00000000}},	//   _བསོག_, odiy, _гобе, --, 
   {{0x7646045b,0x75242622,0x7e7a045c,0xd344158b}},	//   ndiy, otiz, ghup, _پیچه_, 
   {{0x7524524a,0x016001af,0x76440009,0x00000000}},	//   ntiz, _екто, idiy, --, 
   {{0x6aae045d,0x8538008d,0x7526045e,0x7646045f}},	//   _skaf, נגיי, itiz, hdiy, 
   {{0x7e786327,0xae20375c,0x76440213,0x06e00150}},	//   bhup, _यापन_, kdiy, _ﻋﺎﻫﺩ, 
   {{0x6d440953,0x7e7a0460,0x06e40eac,0x75260461}},	//   _šiau, chup, _ফিলি, ktiz, 
   {{0x05a406ab,0x656c0067,0x00000000,0x00000000}},	//   _कुंब, xyah, --, --, 
   {{0x0a680116,0x76440067,0x291401d9,0xa3b8000d}},	//   _әрки_, ediy, ٕہکھ_, _चरल_, 
   {{0x4990030f,0x6aa40150,0x76440067,0x80c403d4}},	//   تیکر, _وشبە, fdiy, ৰীক্, 
   {{0x656e0462,0x6aac9ea8,0x7645501d,0xd954001f}},	//   tyah, _ukaf, gdiy, ገራችን, 
   {{0xf77001ed,0xcfbc03d4,0x00000000,0x00000000}},	// [3ad30] واہ_, ইখিন, --, --, 
   {{0x656e0463,0x764401d9,0x628800a3,0x00000000}},	//   ryah, adiy, _smeo, --, 
   {{0x57b00046,0x57f80375,0x76460464,0x7e780124}},	//   _жұрт, _דלתו, bdiy, yhup, 
   {{0x656e0465,0x75240295,0x73c400c6,0x76440014}},	//   pyah, btiz, سينم, cdiy, 
   {{0x128807d6,0xf64401c6,0x656c0009,0xdce80139}},	//   جمنی_, _эхэн, qyah, dzeğ, 
   {{0xd34402f2,0x00000000,0x00000000,0x00000000}},	//   _ژیله_, --, --, --, 
   {{0x64560466,0x7e7a0467,0x644401f7,0x3cf80073}},	//   _inzi, thup, mdhi, लीने_, 
   {{0x644562d1,0x628800ec,0x7eb400e4,0x00000000}},	//   ldhi, _umeo, rãpo, --, 
   {{0x6444b3ae,0x7e7801f4,0x00000000,0x00000000}},	//   odhi, rhup, --, --, 
   {{0x64460468,0x7e7a0469,0x9b043e08,0x62980175}},	//   ndhi, shup, озод, lnwo, 
   {{0x76440cc1,0x64440013,0x5f942586,0x7524009d}},	//   ydiy, idhi, _بلائ, ztiz, 
   {{0x629a046a,0xbb4c2e56,0x9d541eeb,0x5cf402bf}},	//   nnwo, ﺎﺳﻰ_, _ونات, _дяку, 
   {{0x6456046b,0x78701059,0x7644afeb,0x64440066}},	//   _onzi, _hävi, vdiy, kdhi, 
   {{0x787002f6,0xe63401c6,0x76440009,0xe9f80051}},	//   _kävi, үхтэ, wdiy, _tkế_, 
   {{0x764448d3,0x6446046c,0x7870007c,0x81c000ef}},	//   tdiy, ddhi, _jävi, _žēlu, 
   {{0x6456046d,0x7526046e,0x6446046f,0x76456e6b}},	//   _anzi, ttiz, edhi, udiy, 
   {{0x76460470,0x645401fa,0x7870023a,0x60c0cba3}},	// [3ad40] rdiy, _bnzi, _lävi, _ohlm, 
   {{0x629a0471,0x3cf80073,0x00000000,0x00000000}},	//   enwo, लीये_, --, --, 
   {{0x1c20007d,0xd62a0472,0x13a401d5,0x00000000}},	//   _मानल_, _коне_, زچسی_, --, 
   {{0x6454b23d,0x75260473,0x64460474,0xe9f80124}},	//   _enzi, ptiz, adhi, _okẽ_, 
   {{0x61ee0475,0x64460476,0x10a457e5,0x3cf800af}},	//   ñala, bdhi, оидн, लीमे_, 
   {{0x39400fac,0x64441ee5,0x60c00419,0x6478004e}},	//   _msis_, cdhi, _chlm, _лёсс_, 
   {{0x25e0069f,0x80a0004b,0x78700139,0xd1dc0023}},	//   _कलमी_, بمون, _cävi, _ናዕቢ_, 
   {{0x39420477,0x3a200332,0x2d74007f,0x3ff01884}},	//   _osis_, _ncip_, t̀e_, ككۇر, 
   {{0x3940269e,0x60c003ac,0x0678010f,0xbae00220}},	//   _nsis_, _fhlm, ינקל, _ﺍﻟﺨﺎ, 
   {{0x63b80784,0x14a80073,0x3a200205,0x2d980356}},	//   _ñanñ, कविण, _acip_, ăre_, 
   {{0x39420478,0xfb809c36,0x2d800135,0x00000000}},	//   _asis_, дыян, _żied_, --, 
   {{0x0dc8180b,0x3a200129,0x6f180455,0x8ce400cf}},	//   _кули_, _ccip_, muvc, _ۇقچۇ, 
   {{0x8c44476d,0x6f1807d6,0xfe980a1e,0x39400332}},	//   _меде, luvc, _דיאמ, _csis_, 
   {{0xfbcc2444,0x1cb8031c,0x8ea400db,0x64440067}},	//   عتی_, _ཙེར_, _الچۇ, xdhi, 
   {{0x6f1807d6,0x394004d4,0x9f440ea0,0x3b6001d9}},	//   nuvc, _esis_, _aflê_, _ہێیہ, 
   {{0x2cac0368,0x64440009,0x47bc0154,0x66080171}},	//   lodd_, wdhi, ্ডলী, _ķeks, 
   {{0x39400280,0xddd8007f,0xe4d410de,0x2a680381}},	// [3ad50] _gsis_, _fowņ, سقاد, _ioab_, 
   {{0x291a0479,0x2cac00a9,0x6444efd2,0x6910008e}},	//   musa_, nodd_, udhi, _cıeş, 
   {{0x291a047a,0x6446047b,0xdee002d3,0x00000000}},	//   lusa_, rdhi, _ናብኡ_, --, 
   {{0x9f4403c6,0x2a6a047c,0x2cac0368,0xa4d402bf}},	//   _celý_, _joab_, hodd_, _номі, 
   {{0x29181dd4,0x2a6a047d,0x629a047e,0xa5c40209}},	//   nusa_, _moab_, rnwo, _хөве, 
   {{0x3e440208,0x22840014,0xe374013d,0x6444058a}},	//   _ốt_, _کٔرف, _елгы, qdhi, 
   {{0x291a047f,0x2cac0cfd,0x26c80069,0x6f1801d5}},	//   husa_, dodd_, omao_, guvc, 
   {{0x26c80522,0x2a68010a,0xceac00ec,0x00000000}},	//   nmao_, _noab_, هڙن_, --, 
   {{0x2cac0cfd,0x291a0480,0x3a200618,0x64400162}},	//   fodd_, jusa_, _rcip_, _ólis, 
   {{0x291a0481,0x2cac00a9,0x787001b8,0x3a20003a}},	//   dusa_, godd_, _tävi, _scip_, 
   {{0x9f042354,0x291804cc,0x7e90054e,0x040000fe}},	//   _روشو, eusa_, făpt, ৰ্থী_, 
   {{0x291834fe,0x3940020b,0x9cf80154,0x00000000}},	//   fusa_, _psis_, _আমীন_, --, 
   {{0x291a0482,0x4dd80375,0xcdf4011a,0x2cad157c}},	//   gusa_, _החנו, _זמני_, bodd_, 
   {{0x95980032,0x7e90054e,0x040003d4,0x6c54004e}},	//   ҡтау_, răpu, ৰ্তী_, _окчу, 
   {{0xf8b80032,0x29180254,0x186a0483,0x00000000}},	//   йөү_, ausa_, _ғани_, --, 
   {{0x291a0484,0x39400e37,0xb6740020,0x1c20033f}},	//   busa_, _tsis_, _የወያኔ_, _माडल_, 
   {{0x6f1807d6,0xbae00220,0xceb0011a,0x00000000}},	// [3ad60] zuvc, _ﺍﻟﺠﺎ, תין_, --, 
   {{0x3d120485,0x1cb8025c,0x2a68002d,0x9f44008e}},	//   _दिने_, _ཙེས_, _zoab_, _belü_, 
   {{0x9f44e20f,0x2a680098,0xf15403e6,0xd775908a}},	//   _meló_, _yoab_, ژێرد, _رادع, 
   {{0x6f1831c5,0x46bc3ec5,0x00000000,0x00000000}},	//   vuvc, ्षणह, --, --, 
   {{0x6f180477,0xc32400d1,0x2cac0042,0xa3cc01f9}},	//   wuvc, قكەن_, yodd_, शेब_, 
   {{0x6f18006c,0xa5040006,0x087400df,0x00000000}},	//   tuvc, _ўяўл, ּעקט_, --, 
   {{0x03a00818,0x29181172,0xa3b8000d,0x00000000}},	//   _зиро, zusa_, _चरए_, --, 
   {{0x6f18006c,0x2cac0368,0x291a0486,0xff4c00f1}},	//   ruvc, wodd_, yusa_, اخو_, 
   {{0x29183e09,0x6f1a0487,0x2cac015d,0xa3cc01f9}},	//   xusa_, suvc, todd_, शेठ_, 
   {{0x291a0488,0x9f440793,0x6f18014f,0x2cac0042}},	//   vusa_, _yelü_, puvc, uodd_, 
   {{0xc0cc044e,0x2cac00a9,0xddc805be,0x6f1801b9}},	//   _ብኹሉ_, rodd_, rkeš, quvc, 
   {{0x291a0489,0x2cac0368,0xcd280214,0x37c40154}},	//   tusa_, sodd_, _هستن_, ্ডার, 
   {{0x1eaa048a,0x9f440093,0x3d100034,0x291804ba}},	//   _بالي_, _feló_, _दिये_, uusa_, 
   {{0x291a048b,0x00000000,0x00000000,0x00000000}},	//   rusa_, --, --, --, 
   {{0x29180028,0x671c06ab,0x38900023,0x1c20000d}},	//   susa_, बंधक_, _ናእሽቱ_, _मातल_, 
   {{0xfbb4025f,0x67d4013e,0x00000000,0x00000000}},	//   _מפות_, зоҳу, --, --, 
   {{0x26c8008f,0x29180481,0xa4d812fa,0x00000000}},	// [3ad70] rmao_, qusa_, іджу_, --, 
   {{0x68ee048c,0x00000000,0x00000000,0x00000000}},	//   _itad, --, --, --, 
   {{0x87049528,0x61ee048d,0x00000000,0x00000000}},	//   _عبدل, ñalo, --, --, 
   {{0x63b40232,0xf7d000d1,0xb28400db,0x00000000}},	//   _vyzn, _ﻛﯜﻧﺪ, нычк, --, 
   {{0xa06a048e,0xf0e80075,0x63b40034,0xa3b801ad}},	//   жала_, كىنى_, _wyzn, _चरक_, 
   {{0x68ec009f,0x2d8400d0,0x9c7c007f,0x00000000}},	//   _mtad, dzme_, npōt, --, 
   {{0x44202a1f,0x1ec96273,0x9c7c00b0,0x229400a7}},	//   _icj_, олки_, ipōt, _живя, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x68ee048f,0x61ea0490,0x8ae40220,0x00000000}},	//   _ntad, _ifel, _ﺍﻟﻨﻅ, --, 
   {{0xad240075,0x6aa40793,0x442001c7,0xaf2c0092}},	//   رىپى, _ĉifa, _jcj_, ደተመለ, 
   {{0x29080664,0x68ee0491,0x46bc35e0,0xd378008f}},	//   _avaa_, _atad, ्षाह, ַרשט, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x5d684712,0x61ea0492,0x98f4013d,0x9f460493}},	//   _филм_, _mfel, ьянч, _teló_, 
   {{0x7d18c8f5,0x4420045a,0x00000000,0x00000000}},	//   muus, _ncj_, --, --, 
   {{0x61e8043b,0x68ee0494,0x7d19efce,0x29080270}},	//   _ofel, _etad, luus, _evaa_, 
   {{0x4420007f,0x7d000241,0x61ec0077,0x00000000}},	//   _acj_, _gìrá, ñall, --, 
   {{0x68ec092e,0x7d1a0495,0x44200109,0x00000000}},	// [3ad80] _gtad, nuus, _bcj_, --, 
   {{0x61ea0496,0x44220497,0x787001b8,0x00000000}},	//   _afel, _ccj_, _pävu, --, 
   {{0x7e681a7c,0x7d1a0498,0xd24401c0,0x86f40014}},	//   _oogp, huus, дэли, _ٲکِس_, 
   {{0x7d1a0499,0xa3cc9129,0xc04c01d9,0x00000000}},	//   kuus, शेध_, یٖن_, --, 
   {{0xc0e1099b,0x7d1a049a,0x68ec01d5,0x80bc0037}},	//   вочк, juus, _xtad, _लीहे, 
   {{0x61ea049b,0x7d1a049c,0x244c00e5,0x614000c7}},	//   _efel, duus, tómű_, ыҵуа, 
   {{0x7e68037e,0x61e80042,0x787001e3,0x3cf80037}},	//   _bogp, _ffel, _hävs, लीसे_, 
   {{0x941c084a,0x7d191b78,0xbea000d8,0x6e0400cf}},	//   _पाँच_, fuus, кајк, رسبە, 
   {{0x7d003306,0x2d840552,0x7d1a049d,0x787001e3}},	//   نِيه, uzme_, guus, _jävs, 
   {{0x5fa80490,0x68ec01b9,0x8ae40150,0x00000000}},	//   _चुकल, _rtad, _ﺍﻟﻭﻅ, --, 
   {{0x7c2001ab,0x0e08010b,0x2ab8002e,0x50a000d1}},	//   _dcnr, _дэли_, lébi_, _كەچل, 
   {{0x7d1a049e,0x00000000,0x00000000,0x00000000}},	//   buus, --, --, --, 
   {{0x941c09d9,0x1ea81c4e,0x7d1804ba,0xbea800db}},	//   _पांच_, _عامي_, cuus, _بئلە_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8aa40311,0xaa942472,0x0ba800f7,0x44200356}},	//   _орид, _пикч, _باشى_, _rcj_, 
   {{0x6e200399,0x00000000,0x00000000,0x00000000}},	//   ngmb, --, --, --, 
   {{0x19c004a9,0x61e80162,0xe4d8029c,0x00000000}},	// [3ad90] _бәрг, _rfel, سوات_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x61ea049f,0x91c00032,0x7d1804ba,0xc2e800cf}},	//   _pfel, ғәтл, zuus, زعام_, 
   {{0x5fa801ad,0x7d189bfd,0x00000000,0x00000000}},	//   _चुगल, yuus, --, --, 
   {{0x7d180014,0x50a00131,0xd00c2d40,0x00000000}},	//   xuus, گەلل, ڭلى_, --, 
   {{0x26da04a0,0x7d18023a,0x20880116,0x00000000}},	//   _hiso_, vuus, яйли_, --, 
   {{0x7e680270,0x26da04a1,0xd00c00c6,0x00000000}},	//   _pogp, _kiso_, حلى_, --, 
   {{0x7d1a04a2,0x05c00c2e,0x823604a3,0x61e8379d}},	//   tuus, _शराब, _ترسا, _ufel, 
   {{0x26d81aac,0x316001c7,0xbae002dd,0x00000000}},	//   _miso_, äizt_, _ﺍﻟﺸﺎ, --, 
   {{0x0d8002d5,0x26da04a4,0x7d180749,0x1c45b8dd}},	//   ульн, _liso_, ruus, хном, 
   {{0x7d181c09,0x7e680450,0x93f80a7c,0xf40c03d4}},	//   suus, _togp, הלתי, স্কৰ_, 
   {{0x26d80fb7,0xd1dc0023,0x7d181577,0xef180006}},	//   _niso_, _ናዕታ_, puus, _імі_, 
   {{0xceb00375,0x07a001b9,0xad2400d1,0x7d1891e9}},	//   _גיא_, ҳарн, _لىنى, quus, 
   {{0x8c4204a5,0x2d94033f,0x787001e3,0x88a000fb}},	//   _беше, ódeł_, _rävs, лғыһ, 
   {{0x26d82173,0x07a204a6,0x7870007c,0x00000000}},	//   _biso_, гарн, _bävr, --, 
   {{0x7bc00989,0x2ab802ea,0x18a4013e,0x00000000}},	//   _iznu, yébi_, фаҳм, --, 
   {{0x26da04a7,0x00000000,0x00000000,0x00000000}},	// [3ada0] _diso_, --, --, --, 
   {{0x49c604a8,0x17c80139,0x7870007c,0x00000000}},	//   _ялын_, _нгпи_, _vävs, --, 
   {{0x26da04a9,0x7ae80276,0x00000000,0x00000000}},	//   _fiso_, _întă, --, --, 
   {{0x26d80115,0x91e4048a,0x910400ee,0xd1c80108}},	//   _giso_, ходе, епде, плее_, 
   {{0x941c069f,0xf1b80032,0xbae00220,0x25700e56}},	//   _पाऊच_, фҡа_, _ﺍﻟﺴﺎ, _پۇلس, 
   {{0xe3b000f8,0x26d8006f,0x8f44329b,0x7bc00205}},	//   ارے_, _ziso_, ехид, _oznu, 
   {{0xefd0044e,0x26da04aa,0x92dc00fe,0x00000000}},	//   ብርዎ_, _yiso_, _দৌৰ_, --, 
   {{0x26d80548,0x6aa4010f,0x00000000,0x00000000}},	//   _xiso_, _ĉifo, --, --, 
   {{0x3cf8012c,0x8fe001e0,0x6d400247,0x10a40166}},	//   लीले_, _йәйҙ, uwma, _зиан, 
   {{0xc0e049c4,0x00000000,0x00000000,0x00000000}},	//   _софк, --, --, --, 
   {{0x6ad80729,0x1c2000af,0x606401ee,0x00000000}},	//   _ভৌগো, _मारल_, _шефҡ, --, 
   {{0xc3300375,0x439800df,0x00000000,0x00000000}},	//   נור_, לביג, --, --, 
   {{0x26da04ab,0x3a7551a5,0xcfb02cc5,0x688c0023}},	//   _riso_, уляр, টেশন, _ሓለይቲ_, 
   {{0xac942d31,0xf77003e6,0x26da04ac,0xdb2000c7}},	//   _шалш, ڕاق_, _siso_, ñuãi, 
   {{0x26d81d62,0x61ec002e,0xbb40119e,0x00000000}},	//   _piso_, ñalk, _бејк, --, 
   {{0x24900109,0x26d80014,0x00000000,0x00000000}},	//   _smzm_, _qiso_, --, --, 
   {{0x26da04ad,0x3338004e,0x33c801ec,0x00000000}},	// [3adb0] _viso_, _aprx_, _ﺩﺍﺭﻣ, --, 
   {{0x6abc0250,0x26d80112,0x00000000,0x00000000}},	//   llsf, _wiso_, --, --, 
   {{0x26da04ae,0xbb38010f,0x67d40798,0x00000000}},	//   _tiso_, ּעדי, _јону, --, 
   {{0xa3cc2ce6,0x26d8003a,0x291a04af,0x181801d3}},	//   शेष_, _uiso_, orsa_, _ٹریک_, 
   {{0xdcec005f,0x6abc017a,0x87d000d1,0x41c8012d}},	//   ējīg, ilsf, _ﻛﯜﭼﻠ, ़ेंस, 
   {{0x22481326,0x908800e5,0x00000000,0x00000000}},	//   žak_, ومنے_, --, --, 
   {{0xd3440344,0xa3cc3f7e,0x00000000,0x00000000}},	//   _لیله_, शेश_, --, --, 
   {{0x291807f5,0x3f840e04,0x1cb80327,0x57dc1b87}},	//   krsa_, rznu_, _ཙེང_, _मल्ह, 
   {{0x0e60d7dc,0x7bc0033f,0xa3cc5219,0x61f80042}},	//   ркын, _sznu, शेर_, mbwl, 
   {{0x6abc017a,0x25ac00dc,0x5c5407a5,0x00000000}},	//   elsf, _kāṣṭ, ттиф, --, 
   {{0x5f780502,0x78bc074d,0x29180381,0x3d10041c}},	//   _تماس_, vlrv, ersa_, _दिवे_, 
   {{0x2d940220,0x8d9204b0,0x9ac41418,0x00000000}},	//   _өріс, الیش, keŋŋ, --, 
   {{0x7e7a04b1,0x00000000,0x00000000,0x00000000}},	//   mkup, --, --, --, 
   {{0xd7f000c6,0x7e780e03,0x6abc02d0,0x61f80142}},	//   شكر_, lkup, alsf, hbwl, 
   {{0x7e7a04b2,0x291822a9,0xd628d4b0,0x25ac002b}},	//   okup, arsa_, мове_, _nāṣṭ, 
   {{0x7e7a04b3,0x20c8007b,0x7ae001ab,0x291801ab}},	//   nkup, lúid_, _iunt, brsa_, 
   {{0x7ae204b4,0x7e7802b1,0xe4e40212,0x6618012d}},	// [3adc0] _hunt, ikup, гієн, ówka, 
   {{0x7ae204b5,0x7e78012c,0xc4800124,0x00000000}},	//   _kunt, hkup, алук, --, 
   {{0x7ae204b6,0x7e7a04b7,0x25ac002b,0xa3cc0027}},	//   _junt, kkup, _cāṣṭ, शेल_, 
   {{0x55e44990,0x6f180175,0xf1d000cd,0x00000000}},	//   _шомб, vrvc, तेऽन, --, 
   {{0x7ae204b8,0x7e780427,0x998000b0,0x00000000}},	//   _lunt, dkup, kakō_, --, 
   {{0x7ae014dc,0x6f1800f3,0x7e7806c6,0xb8780092}},	//   _ount, trvc, ekup, _ያወጣው_, 
   {{0x7ae204b9,0x6e942b5a,0x1fd40011,0x63c401af}},	//   _nunt, лику, _স্বস, _барҡ, 
   {{0x7e7a04ba,0x03a02c25,0x00000000,0x00000000}},	//   gkup, _тисо, --, --, 
   {{0x7ae204bb,0xc6900302,0x7d2016ac,0xefd00023}},	//   _aunt, יאה_, لفين, ብክዎ_, 
   {{0x82bc003d,0x7e780810,0xc32c0014,0xa0c800c6}},	//   _མཚོའ, akup, _دٕہ_, _كذلك_, 
   {{0x7ae204bc,0x441800c8,0xff2400f2,0x00000000}},	//   _cunt, וויס, _لبنی, --, 
   {{0x09c40729,0x7ae204bd,0xbb90005b,0xdb080118}},	//   _এলবা, _dunt, рающ, ínán, 
   {{0x32042f5b,0x61ec0724,0x7ae141c1,0x00000000}},	//   _memy_, ñali, _eunt, --, 
   {{0x7ae204be,0x320402f0,0x291800a3,0x00000000}},	//   _funt, _lemy_, rrsa_, --, 
   {{0xb6e40139,0x00000000,0x00000000,0x00000000}},	//   иютк, --, --, --, 
   {{0x82bc025c,0x9ac40083,0x25ac00cd,0x00000000}},	//   _མཚེའ, teŋŋ, _rāṣṭ, --, 
   {{0xb6041b2e,0x36d604bf,0x7ae204c0,0x9f457846}},	// [3add0] ряск, ротр, _zunt, _helô_, 
   {{0x7ae204c1,0x2aba04c2,0xd4640023,0x00000000}},	//   _yunt, rébu_, _ተቛውሞ_, --, 
   {{0x7ae036ed,0xa3cc0034,0x9990010b,0x7e7803f0}},	//   _xunt, शें_, _adyň_, ykup, 
   {{0x3d100574,0xafdc00a2,0x09d40154,0x25ac0055}},	//   _दिले_, _haĸw, _থ্যা, _vāṣṭ, 
   {{0x32041529,0x00000000,0x00000000,0x00000000}},	//   _demy_, --, --, --, 
   {{0xb97c0375,0x9fca04c3,0x60240064,0xae2000bc}},	//   ונדי, нгла_, удка, _याउन_, 
   {{0x7e7a04c4,0xd00c05d9,0x44300204,0x34949afe}},	//   tkup, سلي_, mfx_, _тарр, 
   {{0x7ae204c5,0xdd90066d,0xdb2400dd,0x3204fedb}},	//   _runt, یوں_, épít, _gemy_, 
   {{0x7ae204c6,0x62980472,0xc10000fb,0x00000000}},	//   _sunt, miwo, _түлл, --, 
   {{0xcfb0045e,0x224c0093,0x629a04c7,0x0dc40474}},	//   টেইন, _haek_, liwo, ылый_, 
   {{0x7e781c06,0x2005eaad,0x7ae194c2,0x98a0012d}},	//   pkup, _ieli_, _qunt, ntką_, 
   {{0x200604c8,0x7ae018f7,0xddd80209,0x7e79e5a3}},	//   _heli_, _vunt, _gowş, qkup, 
   {{0x200604c9,0xad641547,0x7ae204ca,0x224e04cb}},	//   _keli_, _ناوه, _wunt, _maek_, 
   {{0x7ae204cc,0x3ebc0664,0x200407f5,0x629977dc}},	//   _tunt, llut_, _jeli_, hiwo, 
   {{0x7ae204cd,0x629a04ce,0x9b0401d5,0x3ebc01f4}},	//   _uunt, kiwo, _ёзид, olut_, 
   {{0x200604cf,0x224e04d0,0x3ebe04d1,0xcf90008f}},	//   _leli_, _naek_, nlut_, צטן_, 
   {{0x7d1a04d2,0xee5c066a,0x3ebc02f6,0x6298002e}},	// [3ade0] nrus, æðið_, ilut_, diwo, 
   {{0x200604d3,0x3204002d,0x7d1a04d4,0x443001e7}},	//   _neli_, _semy_, irus, gfx_, 
   {{0x224e04d5,0x3ebc06ea,0x3204007f,0x52740798}},	//   _baek_, klut_, _pemy_, луду, 
   {{0x224c0369,0x2004003a,0xd184010b,0x57a40124}},	//   _caek_, _aeli_, ллей, _ашҭа, 
   {{0x200604d6,0x224e04d7,0x68a800aa,0x7d19a37c}},	//   _beli_, _daek_, _سایټ_, jrus, 
   {{0x200604d8,0xf8b445bf,0x7d1a04d9,0x224c321a}},	//   _celi_, ंकिय, drus, _eaek_, 
   {{0x200604da,0x224c000f,0x3ebcb188,0x7d1a04db}},	//   _deli_, _faek_, flut_, erus, 
   {{0x7d1a04dc,0x80440137,0x62980210,0x00000000}},	//   frus, _ۅرمۅ, ciwo, --, 
   {{0xf8b406ab,0x7d1800ee,0x200604dd,0x80bc0210}},	//   ंकाय, grus, _feli_, _लीके, 
   {{0x200604de,0x0b898e4a,0xace80022,0xac9800ec}},	//   _geli_, есми_, нмҩа_, ئندا_, 
   {{0x7d180eda,0x224c0226,0x3ebcd6d1,0xbf1000f1}},	//   arus, _yaek_, blut_, _هولب, 
   {{0x7d1a04df,0x27e00005,0x3ebc004a,0xaca40241}},	//   brus, _sghn_, clut_, _ikọy, 
   {{0x2004004b,0x8d7405d9,0x02e8000d,0x00000000}},	//   _yeli_, _ڄاڻا, _जूनह_, --, 
   {{0xac1810f5,0x20040de2,0xac981f0d,0x629a04e0}},	//   _року_, _xeli_, _جنتا_, ziwo, 
   {{0x629a04e1,0xae1802e5,0x6618012d,0xab0401ec}},	//   yiwo, _धयान_, ówko, _тілқ, 
   {{0x6298017a,0x49900133,0x00000000,0x00000000}},	//   xiwo, _هیجر, --, --, 
   {{0x224c0369,0x629802bd,0x00000000,0x00000000}},	// [3adf0] _raek_, viwo, --, --, 
   {{0x224c0399,0x888004fb,0x62980295,0x00000000}},	//   _saek_, _ایسن, wiwo, --, 
   {{0xaca40521,0x200417fa,0x03c40408,0x62980134}},	//   _azịz, _reli_, усам, tiwo, 
   {{0x7d1a04e2,0x623604e3,0x55500014,0x00000000}},	//   yrus, реду, _ژھلر, --, 
   {{0x200604e4,0x629a04e5,0x98a0033f,0x3ebc0076}},	//   _peli_, riwo, stką_, vlut_, 
   {{0x20041908,0x224c039a,0x556000db,0x7d189016}},	//   _qeli_, _waek_, _بۇكك, vrus, 
   {{0x3ebcdd9d,0x00000000,0x00000000,0x00000000}},	//   tlut_, --, --, --, 
   {{0x200604e6,0xceb802a8,0x7d18e52d,0xa2c40116}},	//   _weli_, tuƙa_, trus, _тәзк, 
   {{0x7d1a04e7,0x200604e8,0xe2980046,0x6f0407f5}},	//   urus, _teli_, _заң_, ćica, 
   {{0x3ebc04f3,0x7d1a04e9,0x200604ea,0xb5c802dd}},	//   slut_, rrus, _ueli_, _ﺫﺭﻴﻌ, 
   {{0x3ebe04eb,0x5ac940c2,0xee3802dd,0x7d18017a}},	//   plut_, клом_, _әні_, srus, 
   {{0x7d183ed8,0xc0c00116,0x25e001ad,0x00000000}},	//   prus, _тәҗи, _कलगी_, --, 
   {{0x7d1802d1,0x81b400eb,0x4aa4011c,0x00000000}},	//   qrus, ঙের_, ркян_, --, 
   {{0x1a640345,0x00000000,0x00000000,0x00000000}},	//   ایکی_, --, --, --, 
   {{0x969604ec,0x82fc031c,0x6e3c01d3,0xfbd01c43}},	//   араш, ཝེསུ_, őrbe, _اتش_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd9440075,0x98a400d4,0x15b80006,0x7bc40003}},	// [3ae00] _тепи, _випе, тывы_, żjud, 
   {{0x446010f5,0x6aa40115,0x00000000,0x00000000}},	//   овув, _ĉifi, --, --, 
   {{0x93440104,0x11e4516a,0xb9d40023,0x16a800f3}},	//   рнее, ажем, _ሸላ_, _авни_, 
   {{0xc2140212,0x64a400c7,0xfd04e7e1,0x02c15fdb}},	//   аєш_, ааӡа, _وج_, ойхо, 
   {{0x76440295,0x13a801b9,0xe3b00014,0xb7ec03d4}},	//   meiy, رنچی_, _ہرِ_, কৰণত_, 
   {{0x752401a4,0x9324bfb2,0x764400ad,0xdd9800e8}},	//   muiz, _پرسن, leiy, naňu_, 
   {{0x752604ed,0x0364022e,0x00000000,0x00000000}},	//   luiz, _кирк_, --, --, 
   {{0x76440428,0xcbe000cc,0x75700092,0x00000000}},	//   neiy, _য়েছ, _በራስዎ_, --, 
   {{0x22580008,0x752404cc,0xb180063f,0x829000d1}},	//   _óska_, nuiz, ọọnụ_, _بۇنچ, 
   {{0x804400cf,0x00000000,0x00000000,0x00000000}},	//   _ۅرۅۅ, --, --, --, 
   {{0x752604ee,0x4f941536,0x7644037e,0xdff40166}},	//   huiz, _трау, keiy, _ыять, 
   {{0x752604ef,0x76440198,0xff78008f,0x00000000}},	//   kuiz, jeiy, _שטאמ, --, 
   {{0x75240798,0x20c80393,0x18180014,0x00000000}},	//   juiz, lúia_, گرُک_, --, 
   {{0x7524c42a,0x7a3c00b5,0x328c0150,0x00000000}},	//   duiz, _påtæ, _ﻓﻠﻴﺱ_, --, 
   {{0x2cbc00ef,0x760800d7,0xc6d49cba,0x98a00210}},	//   _ikvd_, kézľ, لترت, ntkę_, 
   {{0x81bc03d4,0x5ba400d4,0x882400eb,0x00000000}},	//   ুখত_, _уріз, য়েছ_, --, 
   {{0x752604f0,0xb9c401ec,0xe50800f1,0xb81c03d4}},	// [3ae10] guiz, _وقىي, ايطو_, দ্ধত_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x752401f5,0x00000000,0x00000000,0x00000000}},	//   buiz, --, --, --, 
   {{0x660e04f1,0xf0e804a9,0x75240204,0xe33801ec}},	//   maak, لىنى_, cuiz, _ءﺳﯩﻤ, 
   {{0xdee4119e,0xb9e427a6,0xe04400d8,0x00000000}},	//   боки, _गल्फ_, снки, --, 
   {{0x644604f2,0x1e940107,0xf1a4013d,0x00000000}},	//   mehi, йрир, йрән, --, 
   {{0x644604f3,0x9e6428e8,0x5e4800f3,0x35800092}},	//   lehi, свид, упим_, _የመብት_, 
   {{0x660c0270,0xb7ec00fe,0x00000000,0x00000000}},	//   iaak, কৰিত_, --, --, 
   {{0x644604f4,0x660e04f5,0x707400c6,0xf0e80131}},	//   nehi, haak, _والذ, _ئىلى_, 
   {{0x660e04f6,0x5f797976,0x9088066d,0x75240451}},	//   kaak, _حماس_, _حملے_, zuiz, 
   {{0x644604f7,0x660e04f8,0xb91400b8,0x00000000}},	//   hehi, jaak, _ktaḥ_, --, 
   {{0x6445ed6e,0x764604f9,0x660e04fa,0x75240005}},	//   kehi, veiy, daak, xuiz, 
   {{0x5bf4040b,0x76440428,0x644604fb,0x6ee40137}},	//   _آغا, weiy, jehi, _اسەل, 
   {{0x660e04fc,0x7644037e,0x9b0801b9,0x9a6807fc}},	//   faak, teiy, _ёниб_, _ممثل_, 
   {{0x07a10ee8,0x752430c7,0x660e04fd,0xc7a00798}},	//   часн, tuiz, gaak, чиск, 
   {{0x764604fe,0x644604ff,0x1fdc0154,0x3cf80073}},	// [3ae20] reiy, fehi, ডডিস, लीचे_, 
   {{0x39420500,0x7524037e,0x7644037e,0x98a00210}},	//   _ipis_, ruiz, seiy, ytkę_, 
   {{0x660c2252,0xe9f80241,0x93597187,0xb91400dc}},	//   baak, _ajẹ_, ырау_, _ataḥ_, 
   {{0x75240356,0x92dc0154,0x5184004e,0x660e0501}},	//   puiz, _দৌড়_, йула, caak, 
   {{0x64460502,0x752404d4,0x00000000,0x00000000}},	//   behi, quiz, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3940020b,0x6f0401a6,0xf7b400d1,0xcfa800f2}},	//   _lpis_, ćico, _ﭼﺎﻏﺪ, داشم_, 
   {{0x39420503,0xd24c0014,0x3d10033f,0x98a0012d}},	//   _opis_, _سۆت_, _दिखे_, rtkę_, 
   {{0x39420504,0x98a0033f,0xd185c9b6,0xc1e451ae}},	//   _npis_, stkę_, _улай, _اکمل_, 
   {{0x660c2252,0x8c660505,0x20c8007b,0x0574011a}},	//   zaak, стид, lúin_, צגים_, 
   {{0x660d3959,0x39420506,0xd1c00023,0x3b5000ee}},	//   yaak, _apis_, _ትካቦ_, пкэр, 
   {{0x660c01d9,0xab0400b8,0x20c8007b,0x64440036}},	//   xaak, _akṣṇ, núin_, zehi, 
   {{0x660e0507,0x64447c6f,0x0b880131,0x78700108}},	//   vaak, yehi, _әсли_, _hävy, 
   {{0x660e0508,0x787001f4,0xfbcc179e,0x20c80332}},	//   waak, _kävy, ظتی_, húin_, 
   {{0x39420509,0x95140003,0x6446050a,0x660e050b}},	//   _epis_, ྲེའི_, vehi, taak, 
   {{0x6446050c,0xfaa4147e,0x00000000,0x00000000}},	//   wehi, _најо, --, --, 
   {{0x660c0761,0x6aac0248,0x20c80332,0xcfb000fe}},	// [3ae30] raak, _ijaf, dúin_, টেচন, 
   {{0x660e050d,0x69cc01c0,0x00000000,0x00000000}},	//   saak, _izae, --, --, 
   {{0x660e050e,0x6aae050f,0xe7dc16ae,0xb914002b}},	//   paak, _kjaf, _मणिप, _staḥ_, 
   {{0xaac8330a,0x64460510,0x660e0511,0x1798011a}},	//   रतिक, sehi, qaak, _כיתב, 
   {{0x21682c9d,0x6aac044e,0x6444166a,0xe8d801f2}},	//   рили_, _mjaf, pehi, _nrị_, 
   {{0xb9d4001f,0x64440548,0xddc8012d,0x00000000}},	//   _ሸዋ_, qehi, ydeł, --, 
   {{0xe8d801f2,0xaac80892,0x92c80183,0x656c0067}},	//   _arị_, रताक, োৱে_, lxah, 
   {{0x6aac002e,0x69cc01c4,0x20c80332,0x00000000}},	//   _njaf, _ozae, cúin_, --, 
   {{0x628801e1,0xdbd0008e,0x8cc8033f,0x7fb01208}},	//   _ileo, _küçk, _सीहो, _کلاچ, 
   {{0x6aac0241,0x82e4025c,0x301485a8,0x95e4000d}},	//   _ajaf, _སྤོའ, _ндур, _कल्ट_, 
   {{0x39420512,0x69cc02b9,0xdaa8023a,0x68fc0b4f}},	//   _spis_, _azae, ивод_, epsd, 
   {{0xa3b001ad,0x00000000,0x00000000,0x00000000}},	//   _ओशन_, --, --, --, 
   {{0x6aac0de2,0x1d0800fd,0x00000000,0x00000000}},	//   _djaf, _тели_, --, --, 
   {{0x62880f7b,0xc0bc044e,0x6aac01b8,0x3940151c}},	//   _lleo, _ትማሊ_, _ejaf, _vpis_, 
   {{0x628a0513,0x39400034,0x00000000,0x00000000}},	//   _oleo, _wpis_, --, --, 
   {{0x6aac0008,0x95840b87,0x82e40327,0x00000000}},	//   _gjaf, олбе, _སྤེའ, --, 
   {{0x3940098d,0x3b040399,0xe6c4007b,0x00000000}},	// [3ae40] _upis_, _hwnq_, ستفي, --, 
   {{0x7bc20514,0x628a0515,0x7ae60516,0x00000000}},	//   _kynu, _aleo, _hiit, --, 
   {{0x7ae60517,0x78be0518,0xe9a804d3,0x62882b60}},	//   _kiit, morv, _ندین_, _bleo, 
   {{0x7ae41574,0x7bc0017a,0xc95401b9,0x78bc0076}},	//   _jiit, _mynu, _الیش_, lorv, 
   {{0x66080086,0x62880156,0x7bc00072,0x7870023a}},	//   _õeka, _dleo, _lynu, _sävy, 
   {{0x7ae4077e,0x78bc4299,0x7bc09d25,0xc0b81ee0}},	//   _liit, norv, _oynu, _ሲቪል_, 
   {{0x20c800ae,0x00000000,0x00000000,0x00000000}},	//   múil_, --, --, --, 
   {{0x7ae40664,0x628a0519,0x22140276,0x78bdf9c9}},	//   _niit, _gleo, _нфур, horv, 
   {{0x78be051a,0x2b5c0230,0x7bc18a28,0xb1c804b4}},	//   korv, _srvc_, _aynu, _уңда_, 
   {{0x7ae6051b,0x6aae051c,0x7bc003b2,0x20c8007b}},	//   _aiit, _sjaf, _bynu, núil_, 
   {{0x7bc00cfd,0x78be051d,0xaa580556,0x20c80332}},	//   _cynu, dorv, бину_, iúil_, 
   {{0xe8d807ae,0x8d8412b9,0x20c8007b,0x7bc174a6}},	//   _trị_, _мулд, húil_, _dynu, 
   {{0x7ae6051e,0x78bc0ac8,0x7bc00213,0xc21000d9}},	//   _diit, forv, _eynu, והר_, 
   {{0x48b8009e,0x78bc01d3,0x00000000,0x00000000}},	//   ূদ্র, gorv, --, --, 
   {{0x7ae6051f,0x7bc00368,0x20c800c6,0x6aac0267}},	//   _fiit, _gynu, dúil_, _tjaf, 
   {{0x7ae40548,0xe8d80241,0x68fc3402,0x00000000}},	//   _giit, _irọ_, ppsd, --, 
   {{0x614002d2,0x20c80332,0x00000000,0x00000000}},	// [3ae50] _málö, fúil_, --, --, 
   {{0x78bd3ef8,0x2908063f,0x67d4ff23,0x7ae4216b}},	//   corv, _iwaa_, _нопу, _ziit, 
   {{0x2908020c,0x68ee0520,0x628a0521,0x7ae4002e}},	//   _hwaa_, _huad, _pleo, _yiit, 
   {{0x6abc1c69,0x68ee0522,0x290801f2,0x7ae46b24}},	//   nosf, _kuad, _kwaa_, _xiit, 
   {{0x68ec2a1f,0xc4440014,0xc0bc0023,0x00000000}},	//   _juad, _ویرن_, _ትማል_, --, 
   {{0x68ee0523,0x68e4047e,0x91c01cd1,0x6abc0142}},	//   _muad, _jihd, хәсл, hosf, 
   {{0x68ec464c,0xe8d802e3,0x63040150,0x6288030a}},	//   _luad, _nrọ_, _ءورل, _tleo, 
   {{0x6d5c0325,0x68ec025a,0x628801f0,0x78bc022e}},	//   āran, _ouad, _uleo, zorv, 
   {{0xa0c4188d,0x7ae4049b,0xe8d802e3,0xdca60524}},	//   _فيرو, _riit, _arọ_, запи, 
   {{0x7ae60525,0x7bc003a2,0x64560526,0x68e4014f}},	//   _siit, _pynu, _jazi, _nihd, 
   {{0x2908063f,0x61e8657a,0x7ae60527,0x6aa400df}},	//   _awaa_, _kgel, _piit, _ĉifr, 
   {{0x6abe0528,0x68ee0529,0x61e80327,0x7bc2052a}},	//   gosf, _buad, _jgel, _vynu, 
   {{0x7ae6052b,0x68ec95fc,0x68e4014f,0xe8d801e1}},	//   _viit, _cuad, _bihd, _erọ_, 
   {{0x68ec03b4,0x61e801bf,0x8d58011a,0xd70841e5}},	//   _duad, _lgel, _לכני, йнге_, 
   {{0x7ae6052c,0x68e40097,0x68ec0381,0xac7400cf}},	//   _tiit, _dihd, _euad, _تانش, 
   {{0x61ea052d,0x68ec7ea6,0x6454022f,0x7ae40270}},	//   _ngel, _fuad, _aazi, _uiit, 
   {{0x18a431de,0x78bc011c,0x290a052e,0x20c800c6}},	// [3ae60] _наим, porv, _gwaa_, túil_, 
   {{0x6ad0febc,0x6456052f,0x61ea0530,0xd774f8df}},	//   _সংযো, _cazi, _agel, _فاجع, 
   {{0x6454c375,0x20c800c6,0x03a0040e,0x68ec0798}},	//   _dazi, rúil_, нифо, _zuad, 
   {{0x25ac04b9,0x20c80491,0x64540083,0x11d800c6}},	//   _žele_, súil_, _eazi, موضة_, 
   {{0x64560531,0x61e80036,0x20c80332,0x41e01cd0}},	//   _fazi, _dgel, púil_, ніша, 
   {{0x61ea0532,0x00000000,0x00000000,0x00000000}},	//   _egel, --, --, --, 
   {{0x43402405,0x6abc0158,0x3cfc0254,0x00000000}},	//   _перв, yosf, epuv_, --, 
   {{0x6454be56,0x00000000,0x00000000,0x00000000}},	//   _zazi, --, --, --, 
   {{0xfe6cfd47,0x6abc00df,0x29cc01a9,0x00000000}},	//   ادى_, vosf, nоat_, --, 
   {{0x75260533,0x645401b9,0x68ec0192,0xe1643cc6}},	//   iriz, _xazi, _ruad, _تدفي, 
   {{0x68ee0534,0x29080223,0x75260535,0xfc10009d}},	//   _suad, _swaa_, hriz, эмээ, 
   {{0x68ec0c6a,0x2908009f,0x7eb400e4,0x00000000}},	//   _puad, _pwaa_, kãpy, --, 
   {{0xac1807d5,0x68ee0536,0x2908009a,0x68e5219d}},	//   _долу_, _quad, _qwaa_, _pihd, 
   {{0x75260537,0x68ecbfef,0xe8d8001e,0x68e40455}},	//   driz, _vuad, _trọ_, _qihd, 
   {{0xddc81f7f,0x6abe0538,0x68e55b85,0x68ec0036}},	//   mješ, posf, _vihd, _wuad, 
   {{0x64560539,0xddc8a068,0x68e4020b,0x68ee053a}},	//   _sazi, lješ, _wihd, _tuad, 
   {{0xc864b1c2,0x00000000,0x00000000,0x00000000}},	// [3ae70] _етни, --, --, --, 
   {{0x2a680070,0x6456053b,0xddc80cf4,0xbb3002dd}},	//   _hnab_, _qazi, nješ, _ﺯﻤﻥ_, 
   {{0x6456053c,0x2a6a053d,0x69c09c11,0x69d80709}},	//   _vazi, _knab_, şled, नेरी, 
   {{0x645555b4,0x7526053e,0x7af40998,0x7d000241}},	//   _wazi, briz, _éxte, _jírò, 
   {{0x75253506,0x661c127b,0xa0b800db,0x00000000}},	//   criz, _idsk, огду_, --, 
   {{0x26c8937c,0x70840220,0x23680220,0xf958011a}},	//   llao_, нгіз, _وڭاي_, פסות_, 
   {{0x37ec0327,0x50a000d1,0xddc801ef,0x00000000}},	//   _ཡུལད, خەلل, dješ, --, 
   {{0x61ea053f,0x00000000,0x00000000,0x00000000}},	//   _ugel, --, --, --, 
   {{0x399401e1,0x00000000,0x00000000,0x00000000}},	//   _músé_, --, --, --, 
   {{0x2a68003e,0x13a801ed,0x26c801e7,0x5ba8003b}},	//   _anab_, _انہی_, hlao_, жком_, 
   {{0x5bb4003b,0x00000000,0x00000000,0x00000000}},	//   ьсиф, --, --, --, 
   {{0xa3b400af,0x2fc00112,0x2f1802d5,0x3cfc000d}},	//   _जखन_, ßige_, _хоць_, ppuv_, 
   {{0xdf00002e,0x26c8009a,0xddc8009b,0x394400db}},	//   _doŋŋ_, dlao_, bješ, ïms_, 
   {{0x3ebc0dd4,0x661e0540,0x48e000a7,0x75240010}},	//   lout_, _adsk, кояв, vriz, 
   {{0x48e000c0,0x00000000,0x00000000,0x00000000}},	//   торв, --, --, --, 
   {{0x3ebe0541,0x2a680048,0xb6740092,0x7af000de}},	//   nout_, _gnab_, _ከወያኔ_, ēgtā, 
   {{0xcad400d9,0x00000000,0x00000000,0x00000000}},	// [3ae80] _קופת_, --, --, --, 
   {{0x75240323,0x3ebe0542,0x49c40daf,0xc9500a7c}},	//   rriz, hout_, _юлын_, _ימח_, 
   {{0x3ebc217e,0x75240a2e,0x7d080399,0x2a6801b9}},	//   kout_, sriz, _lwgs, _ynab_, 
   {{0x3ebc07e4,0xd1c81301,0x656873d0,0x61ec09a8}},	//   jout_, олее_, _šehe, žaln, 
   {{0x3ebe0543,0xc32483c9,0x752401a9,0x00000000}},	//   dout_, ككەن_, qriz, --, 
   {{0x32e803ee,0xe194009d,0x00000000,0x00000000}},	//   _eşya_, эрхэ, --, --, 
   {{0xddc822c1,0x6d5c0882,0x20b80953,0x3ebe0544}},	//   vješ, āram, чыць_, fout_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xddc80841,0x3f80025c,0x7d0001e1,0x00000000}},	//   tješ, _żjut_, _rírò, --, 
   {{0xa3b401f9,0x00000000,0x00000000,0x00000000}},	//   _जखम_, --, --, --, 
   {{0x3ebe0545,0xddc870b1,0xaa582bbd,0x00000000}},	//   bout_, rješ, пину_, --, 
   {{0x0d860546,0x3ebe0547,0x5978001f,0xff2400f2}},	//   _олен, cout_, _ብላችሁ_, _آبلی, 
   {{0x6f18074d,0xddc822c1,0x6f0401e1,0x2ac40131}},	//   lsvc, pješ, _fìbò, _җәнв, 
   {{0x5828081f,0x4af00588,0xb4b8012c,0x98a01da6}},	//   _སྐྱོ_, _иҟоу, ङको_, tukā_, 
   {{0xbc643df2,0x5970036b,0x2d840051,0xc6e4003b}},	//   _زمين_, نگیز, lyme_, діап, 
   {{0x2a6a0548,0x6b9c0798,0xe8d8004d,0xbb4401f7}},	//   _unab_, úrgu, _trỏ_, _آلين_, 
   {{0x26c82165,0x2d860549,0xc5e40154,0xb6e4010a}},	// [3ae90] rlao_, nyme_, গুনা_, тюрк, 
   {{0x3ebc03bd,0x2918022f,0xc76402dd,0xf484011c}},	//   zout_, mssa_, _قاجى, кухн, 
   {{0x3ebda681,0x00000000,0x00000000,0x00000000}},	//   yout_, --, --, --, 
   {{0x661d54de,0x3ebc02fa,0x291802f6,0x2d840153}},	//   _udsk, xout_, ossa_, kyme_, 
   {{0x29180664,0xa068ee8d,0xe045bffa,0x3ebc03bd}},	//   nssa_, зала_, енли, vout_, 
   {{0x291a054a,0x3ebe054b,0x2d8400c0,0x00000000}},	//   issa_, wout_, dyme_, --, 
   {{0xbfe00588,0xa2940845,0x00000000,0x00000000}},	//   тәаҩ, _заві, --, --, 
   {{0xad2404a9,0x32640014,0x29180010,0x00000000}},	//   ھىپى, _لۆمہ, kssa_, --, 
   {{0xc0ca054c,0x3ebe054d,0x21380240,0x00000000}},	//   _дуже_, rout_, _ësh_, --, 
   {{0x3ebe054e,0x9b04013e,0x00000000,0x00000000}},	//   sout_, нзод, --, --, 
   {{0x291a054f,0x3ebc0489,0x00000000,0x00000000}},	//   essa_, pout_, --, --, 
   {{0x2d840407,0x9ed8004e,0x00000000,0x00000000}},	//   byme_, _эмет_, --, --, 
   {{0xd7e81c3e,0x7e6a0550,0x9d4400db,0xb3b000cc}},	//   змге_, _ingp, _челд, _কৰাজ, 
   {{0x6b841165,0x97c404b3,0x00000000,0x00000000}},	//   _ńige, ейге, --, --, 
   {{0x2918049b,0x00000000,0x00000000,0x00000000}},	//   assa_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd9dc09bd,0x3a20010e,0x85b135da,0x00000000}},	// [3aea0] _ভ্রম, _idip_, гәрч, --, 
   {{0xe8d80208,0x683800ae,0x69a401af,0x00000000}},	//   _trề_, rúdó, _шлыҡ, --, 
   {{0x2d860551,0x7e6a0552,0xc7a0010a,0x00000000}},	//   zyme_, _ongp, _биэк, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc1e434d8,0x95c400ec,0x00000000,0x00000000}},	//   ньше_, _ڊيگه, --, --, 
   {{0x7e6a0553,0x626401b9,0x183400df,0x00000000}},	//   _angp, _یاقق, גאַל_, --, 
   {{0x76ac00a2,0x00000000,0x00000000,0x00000000}},	//   gşyg, --, --, --, 
   {{0x291a0554,0x4338008f,0x2d840153,0xa0200154}},	//   yssa_, _מעלב, tyme_, প্লব_, 
   {{0x70e40022,0xa2a400cd,0x9984010e,0x00000000}},	//   _абаҕ, _कषत्, _ýoň_, --, 
   {{0x4f943169,0x7e68509b,0xebc402d9,0x6ac8090a}},	//   _преу, _engp, кәйн, रत्र, 
   {{0x7b1001c0,0xaa94030d,0x027c0118,0x2d85f2c0}},	//   лдэх, винч, žíše_, syme_, 
   {{0x2d84035b,0x29180472,0x62800129,0x12d00131}},	//   pyme_, tssa_, _îlot, ﯘﺭﻻﺭ, 
   {{0x29196e0a,0x3e841064,0x6c540124,0x0ae800e5}},	//   ussa_, _яйцо_, _аклу, _کرتي_, 
   {{0x3a20fa01,0xa8bc00ee,0x672001d3,0xbb80004b}},	//   _edip_, _ösüş_, áljo, _څلوي, 
   {{0xab9402dd,0x00000000,0x00000000,0x00000000}},	//   _шикі, --, --, --, 
   {{0x672016a3,0x7af409c2,0x59dc012c,0x00000000}},	//   šljo, _éxta, नेहर, --, 
   {{0xddc800dc,0x00000000,0x00000000,0x00000000}},	// [3aeb0] ddeś, --, --, --, 
   {{0x6d5c3b37,0xa6f400f3,0x00000000,0x00000000}},	//   ārah, _изош, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x57b00220,0xe63800ec,0x76ac010b,0x171873cd}},	//   _тұст, _کيڏڻ_, gşyd, _קורע, 
   {{0x61f80142,0xd24c0472,0x00000000,0x00000000}},	//   rcwl, زنو_, --, --, 
   {{0x999002e2,0xf77003e6,0x00000000,0x00000000}},	//   _deyň_, _ئای_, --, --, 
   {{0x62340276,0x00000000,0x00000000,0x00000000}},	//   _иеву, --, --, --, 
   {{0xf2c400db,0x98a00064,0x00000000,0x00000000}},	//   _бсун, muką_, --, --, 
   {{0x7bcc003a,0x2054004e,0x00000000,0x00000000}},	//   ęcum, _икая, --, --, 
   {{0x44300226,0x00000000,0x00000000,0x00000000}},	//   ngx_, --, --, --, 
   {{0x3a2001f9,0x98a00153,0xab1800d4,0x9078011a}},	//   _pdip_, nuką_, нцях_, _קטעי, 
   {{0xb37800b5,0x3f8400c0,0x00000000,0x00000000}},	//   mでto, mynu_, --, --, 
   {{0xad243955,0x3f860555,0xceb00115,0x00000000}},	//   _مىنى, lynu_, _דיא_, --, 
   {{0x7d1a0556,0xd0580213,0x8c4403b9,0xdca60557}},	//   msus, _bitə, _coşğ, _шали, 
   {{0x7d1a0558,0x8cc8033f,0x3f840064,0x00000000}},	//   lsus, _सीटो, nynu_, --, 
   {{0x61ec07f5,0x656805be,0xf48403e6,0xddd8033b}},	//   žalj, _šeha, گاری, _pawň, 
   {{0x7d1a0559,0x3f84015d,0x95c801a9,0x59dc0d2e}},	// [3aec0] nsus, hynu_, флаб_, नेशर, 
   {{0xf4843837,0x7d194049,0x3f8402f0,0x00000000}},	//   داری, isus, kynu_, --, 
   {{0x7d1a055a,0x5240001f,0xc32c01d9,0x00000000}},	//   hsus, _የፌዴሬ, قٕل_, --, 
   {{0x7d183110,0xd184bef7,0xe8d80051,0x3f840064}},	//   ksus, клей, _trể_, dynu_, 
   {{0xd01001b9,0xf1b801e0,0xb406055b,0x00000000}},	//   للش_, хҡа_, _бүзд, --, 
   {{0x7d182042,0x934403f6,0x3f840142,0x4f68117e}},	//   dsus, _инге, fynu_, дшим_, 
   {{0x15d80150,0x7d19ad8b,0x00000000,0x00000000}},	//   _ﺃﻭﺠﺩ, esus, --, --, 
   {{0xc7b00375,0x53a4014b,0x63c401af,0xdd980432}},	//   יבו_, _заҳб, _сасҡ, laňy_, 
   {{0x7d1810c7,0x00000000,0x00000000,0x00000000}},	//   gsus, --, --, --, 
   {{0x01340375,0x3f840142,0x00000000,0x00000000}},	//   _ברמת_, bynu_, --, --, 
   {{0xeff80020,0x7d1820ac,0x00000000,0x00000000}},	//   ለያየ_, asus, --, --, 
   {{0xc3300bd4,0x00000000,0x00000000,0x00000000}},	//   סור_, --, --, --, 
   {{0x44300204,0x987c08a9,0xb9542077,0xd05803b9}},	//   ygx_, _açıl_, авящ, _sitə, 
   {{0xe75801ec,0x00000000,0x00000000,0x00000000}},	//   нигі_, --, --, --, 
   {{0xfbcc01ec,0x25ac0356,0xf770007b,0xd0580213}},	//   _وتى_, _ţel_, ياف_, _qitə, 
   {{0xeff82295,0x44300175,0x00000000,0x00000000}},	//   ለያዩ_, wgx_, --, --, 
   {{0x35f6055c,0x61ec0030,0x281401b9,0x3f84012d}},	// [3aed0] рпур, žalk, _یوکس, zynu_, 
   {{0xa856055d,0x98a07502,0x03a80133,0xa7740229}},	//   _скоч, tuką_, وداو_, _блоч, 
   {{0x69cc0998,0xc766055e,0xe32402dd,0x3f840009}},	//   _hyae, _شادى, _ءﺑﯩﻠ, xynu_, 
   {{0xe214977c,0xf3651b24,0x7d19d486,0x00000000}},	//   умды, штун, ysus, --, 
   {{0xe37401ec,0x7d1a055f,0x602401c0,0x8c4406be}},	//   _ءﺳﯩﺰ, xsus, гдла, _zoşş, 
   {{0x69cc0369,0x7d1800c5,0xf484010a,0x3f844f7e}},	//   _myae, vsus, _кусн, tynu_, 
   {{0xd34455cb,0x69cc0393,0x00000000,0x00000000}},	//   _میله_, _lyae, --, --, 
   {{0x7d1a0560,0x720400c6,0xe2d80014,0x3f860561}},	//   tsus, _نوفم, _سازچ_, rynu_, 
   {{0x69ce0562,0x5c147798,0x7d1820ac,0x442001e4}},	//   _nyae, льну, usus, _kdj_, 
   {{0x9f440548,0xd6ec00cc,0x00000000,0x00000000}},	//   _eglá_, টীয়া_, --, --, 
   {{0x7d1832ff,0xdfd1d3f7,0x69cc30b5,0x2b549fa2}},	//   ssus, _ايا_, _ayae, لیود_, 
   {{0x69cc0007,0x7d1800af,0x9db82401,0x00000000}},	//   _byae, psus, _пылу_, --, 
   {{0x44200117,0x69c062c7,0x00000000,0x00000000}},	//   _odj_, şlen, --, --, 
   {{0x7e78098d,0x69cc0175,0xb6c800e5,0x00000000}},	//   ljup, _dyae, چارے_, --, 
   {{0x7c220563,0x6b5800ee,0x1ca403e6,0xb8dc1a75}},	//   _idnr, _ашыр_, _لێکی_, _अद_, 
   {{0x44220564,0x9984ca3e,0xdca42cc8,0xa6940063}},	//   _adj_, _ملبو, _шаһи, аруј, 
   {{0x69cc0226,0x5468e753,0x20c801e7,0x1868011c}},	// [3aee0] _gyae, наам_, núis_, _запи_, 
   {{0xc480651a,0x59a8033f,0x7e7a0565,0x81e400cc}},	//   блук, _चेयर, hjup, _ম্ভ_, 
   {{0x7e78020c,0x20c801e7,0x13080108,0x8838011a}},	//   kjup, húis_, хней_, _אתיו, 
   {{0x4420009a,0x00000000,0x00000000,0x00000000}},	//   _edj_, --, --, --, 
   {{0x44200548,0x764403f9,0x7e782d62,0xd24c0014}},	//   _fdj_, mfiy, djup, ٲنڈ_, 
   {{0x76460566,0xe8d801fb,0x00000000,0x00000000}},	//   lfiy, _trễ_, --, --, 
   {{0xb4e01dd1,0x76440014,0x00000000,0x00000000}},	//   दगी_, ofiy, --, --, 
   {{0x442065d2,0x91e40be5,0xdbd0002f,0x76442681}},	//   _zdj_, _бобе, _süßk, nfiy, 
   {{0xed5016d5,0x0ca81f87,0x20c80332,0x0c84013d}},	//   تھا_, етни_, gúis_, гынм, 
   {{0x7c207ea4,0xef100137,0x6b88017a,0x7e7a0567}},	//   _cdnr, _дүкө, tydg, ajup, 
   {{0x69cc06d1,0xa2d80490,0x76440205,0xfe6c1e4a}},	//   _syae, _फीड्, kfiy, تگە_, 
   {{0xf1b81b0c,0x20c8007b,0xbb90034b,0x8e74072d}},	//   _अशान, búis_, сающ, _حائض, 
   {{0x32e8010b,0x00000000,0x00000000,0x00000000}},	//   _aşyk_, --, --, --, 
   {{0x65680fcf,0x69cc009f,0xef280112,0x20c801e7}},	//   _šeho, _vyae, _grüß_, lúir_, 
   {{0x44200109,0x7644773e,0xaa94010a,0x46680108}},	//   _rdj_, ffiy, _вийч, нрам_, 
   {{0x61ec07f5,0xe5b46315,0x6d4113c5,0xddc9c3e8}},	//   žali, айбы, otma, ndeş, 
   {{0x6d420568,0x1fe01b61,0xf1a40034,0xfa3400cf}},	// [3aef0] ntma, _पण्ड, _खेलन, _ارىد, 
   {{0x6d4003ac,0x76448c88,0x20c800ae,0x00000000}},	//   itma, afiy, húir_, --, 
   {{0x6d400c8c,0xe2c801d9,0x7e7800e4,0xddc80432}},	//   htma, پوشو_, yjup, kdeş, 
   {{0xc2c80244,0xdf600241,0x76440009,0x00000000}},	//   ربال_, _lẹ́è, cfiy, --, 
   {{0x058400d1,0x6d4000bc,0x20c801e7,0xe29800c7}},	//   _сунм, jtma, dúir_, наҧ_, 
   {{0x660cfbe0,0x6d420569,0x5f044d7a,0x44200107}},	//   lbak, dtma, азка, _udj_, 
   {{0x6d407731,0x1e96056a,0x660e056b,0xf1a436e1}},	//   etma, ирир, obak, ирән, 
   {{0x6d42056c,0x660e056d,0x7e780194,0x12940014}},	//   ftma, nbak, ujup, _پھمب_, 
   {{0xdf600248,0x7e7a056e,0x6d4000b5,0xc5e40154}},	//   _bẹ́è, rjup, gtma, গুরা_, 
   {{0x5ca40c69,0x644412ef,0x20c8007b,0x00000000}},	//   риоб, nfhi, rúis_, --, 
   {{0x660e056f,0x7644f7c0,0x6d403c6a,0xde940063}},	//   kbak, yfiy, atma, _кажњ, 
   {{0xfc3c038e,0x7644036b,0x7e78014f,0x644436f4}},	//   ří_, xfiy, qjup, hfhi, 
   {{0x660e0570,0x19b825ec,0x62980099,0x00000000}},	//   dbak, тунь_, ihwo, --, 
   {{0x6d5c0882,0x660c1418,0xcdb4011a,0xd704001b}},	//   ārat, ebak, _דפנה_, изги, 
   {{0x660c017a,0x76440bfa,0x96c801d9,0xcba0014b}},	//   fbak, tfiy, نبرِ_, _машй, 
   {{0x660e0571,0xcf9000c8,0x6bb40212,0x00000000}},	//   gbak, קטן_, _усіє, --, 
   {{0x62980066,0xe50431b1,0x49b002dd,0x461001d5}},	// [3af00] dhwo, مبلي, _дәру, زولر, 
   {{0x39400135,0x660c6cee,0x76456e02,0x00000000}},	//   _iqis_, abak, sfiy, --, 
   {{0x660e0572,0x769801e1,0xc5e40154,0x6844009f}},	//   bbak, _aíye, গুলা_, _اَپل, 
   {{0x6d4099e5,0x660c058a,0x64440332,0x6440010e}},	//   ytma, cbak, afhi, _ölin, 
   {{0x6d400784,0x95740228,0x3940025c,0x515401ec}},	//   xtma, _тынч, _jqis_, ртеу, 
   {{0x644408c2,0x92d40154,0x98a03d44,0x00000000}},	//   cfhi, সদে_, tukę_, --, 
   {{0xd3709eec,0xac500020,0x20c800c6,0xddc800ee}},	//   _ظهر_, ዚአብሄ, túir_, tdeş, 
   {{0x629a0573,0x212801fa,0xe8d8004d,0x9f500432}},	//   chwo, šaha_, _trệ_, _çaýy_, 
   {{0xddc82c44,0x39400457,0x6d4070d8,0x09a80154}},	//   rdeş, _nqis_, utma, _গুনা, 
   {{0x6d4178b9,0x67201068,0x8fa465cb,0x20c8007b}},	//   rtma, šlji, _казе, súir_, 
   {{0x9990007f,0x3b50084c,0xcd28141b,0xd1240092}},	//   _deyō_, окэр, رسکن_, ሰጣቸው, 
   {{0xe2f40156,0x69c051bb,0x7f3800d9,0xf3e805ac}},	//   _བཤལཔ_, şlem, _יעבו, _ওভাৰ_, 
   {{0x6d5c00dc,0x660c01bf,0x14c417c6,0xbb4c0116}},	//   āras, vbak, ववाण, ﻏﻠﻰ_, 
   {{0xac1884dc,0x701400cc,0x00000000,0x00000000}},	//   _соку_, _সাঁজ_, --, --, 
   {{0x660e0574,0x23a40034,0x25e800ab,0x2cac03cd}},	//   tbak, _गेंद, चेनी_, midd_, 
   {{0x660e0575,0xfaa40b3e,0x2cac01c7,0x854400fb}},	//   ubak, _мајо, lidd_, иэзе, 
   {{0xc958036b,0xa834009b,0x00000000,0x00000000}},	// [3af10] _рўй_, _лепљ, --, --, 
   {{0x660d4484,0x2cac002e,0x44044adb,0x00000000}},	//   sbak, nidd_, рчаб, --, 
   {{0x629820a2,0x21f40a2c,0x4ab8000d,0x660d99d6}},	//   thwo, مكاس, _उदाव, pbak, 
   {{0x6234147e,0x2cac04e6,0xe19401c6,0x64440332}},	//   седу, hidd_, йрлэ, sfhi, 
   {{0xaca40241,0xe8d802e3,0xddd802e2,0x67346f39}},	//   _ajọy, _nsị_, _pawō, luzj, 
   {{0x6298232c,0x26c8166a,0xd12c5734,0x846402e8}},	//   shwo, loao_, رمى_, _тъме, 
   {{0xe3e403f4,0xe8d80521,0x23840014,0x2cac0162}},	//   _প্রব, _asị_, _أزِ, didd_, 
   {{0x26c800b0,0x2ee40175,0xdc004721,0x2cac0142}},	//   noao_, gmmf_, ोर्ड_, eidd_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x26c80374,0x06e00131,0x2cac0009,0xf1dc012d}},	//   hoao_, _ﺋﺎﺑﺪ, gidd_, _बरतन, 
   {{0x26ca0576,0x6b58010b,0xcb2400f1,0x6f580117}},	//   koao_, ашяр_, مړيو_, _вахё_, 
   {{0x6d5c0b3a,0x2cac0368,0x67340327,0x61ec0427}},	//   ārar, aidd_, duzj, žalu, 
   {{0xddc81727,0x290c084c,0x38c89528,0x2cac01c7}},	//   ljež, ţean_, لاسی_, bidd_, 
   {{0xddd800a2,0x59dc00bc,0x9b44027d,0x76ac010b}},	//   _gowš, नेगर, _هنتو, gşyn, 
   {{0xd6280b80,0x8ca001ec,0xddc800f3,0x1ae4013d}},	//   лове_, _ءەپو, njež, _локм, 
   {{0x39400135,0x46a00395,0x00000000,0x00000000}},	//   _tqis_, пасв, --, --, 
   {{0x18a400ee,0x14260577,0x94240024,0x00000000}},	// [3af20] _гапм, йдам, ймае, --, 
   {{0x26c854bb,0x6bd400db,0x67340327,0xc4800798}},	//   aoao_, _اتۇر, buzj, плук, 
   {{0x8c180302,0x93443d6c,0x26ca0578,0xdfc4009f}},	//   רועי, снее, boao_, _آڊ_, 
   {{0x1544040e,0x490c012c,0x7014015b,0xb20800c7}},	//   _лемм, तीको_, _সাইজ_, рҵаз_, 
   {{0xc32453f0,0x626418fd,0x5f540092,0xea8c010f}},	//   لكەن_, تالق, _መርከቦ, כנאָ, 
   {{0xfa000729,0x2bd80118,0xbb2c02dd,0x00000000}},	//   ্ণিল_, _डरला, _ﺩﻋﻡ_, --, 
   {{0x2cac39c3,0xe8080574,0x57d407c1,0x10140137}},	//   vidd_, वडता_, _धरोह, _ۇباد, 
   {{0x8c400724,0x8778008f,0x00000000,0x00000000}},	//   _äğza, טאצי, --, --, 
   {{0xe048d712,0x2cac0036,0x00000000,0x00000000}},	//   _چشمه_, tidd_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2cae0579,0x4f946550,0x4e280a0e,0x00000000}},	//   ridd_, _урау, _боен_, --, 
   {{0x59a83eaf,0x2cac04e6,0xac9825e8,0x00000000}},	//   _चेहर, sidd_, انگا_, --, 
   {{0x4dd402de,0x0c84008e,0x7c901888,0xed50009f}},	//   _اتاس, _гыйм, زشیا, _آپت_, 
   {{0x50b801bc,0x6736057a,0x00000000,0x00000000}},	//   ेविष, tuzj, --, --, 
   {{0x6fb80034,0x76ac00ee,0x26c804ba,0x4b040137}},	//   इपिं, rşyn, toao_, _уялб, 
   {{0xe8d80241,0x9f4c06af,0x00000000,0x00000000}},	//   _isọ_, înée_, --, --, 
   {{0x387400e4,0x381800cc,0x00000000,0x00000000}},	// [3af30] ñarã_, _তাৰো_, --, --, 
   {{0x290a057b,0x76ac0432,0x00000000,0x00000000}},	//   _itaa_, lşyl, --, --, 
   {{0x26c80421,0x00000000,0x00000000,0x00000000}},	//   poao_, --, --, --, 
   {{0xddc81f7f,0x672001d3,0x8c1c0154,0x00000000}},	//   vjež, álju, _দাফন_, --, 
   {{0x31240220,0x7a4401ed,0x00000000,0x00000000}},	//   здіг, lító, --, --, 
   {{0xa0691b4a,0xf0e804a9,0x29080451,0xd0044727}},	//   рака_, مىنى_, _mtaa_, оеше_, 
   {{0x44fc025a,0xe8d800b4,0xa2941cd0,0x7a44398f}},	//   _hî_, _nsọ_, _даві, nító, 
   {{0x29080ba7,0x2f5400d4,0x00000000,0x00000000}},	//   _otaa_, ятіс, --, --, 
   {{0xe8d801f2,0x2908013f,0xe3240046,0x00000000}},	//   _asọ_, _ntaa_, _ءﺗﯩﻠ, --, 
   {{0x44fc003a,0x4f8400fb,0x7a4400e5,0x61ec0419}},	//   _mî_, стәҡ, kító, žals, 
   {{0x44fc145e,0x290a057c,0x3f640552,0xdb1403e0}},	//   _lî_, _ataa_, _uđu_, _öbür, 
   {{0x44fc0588,0xe8d8004d,0x3ec40022,0x76ac00ee}},	//   _oî_, _trớ_, _усзб, gşyl, 
   {{0x44fc05bb,0x6abc3eba,0x224c00f2,0x041c0183}},	//   _nî_, érfa, _mbek_, _পানী_, 
   {{0xd7085c48,0x3cfc014f,0xdc440153,0x98a41d39}},	//   инге_, mquv_, _kūči, циге, 
   {{0x290a057d,0x6e380428,0x224c022e,0xca7801a9}},	//   _etaa_, _ñabû, _obek_, putа, 
   {{0x2908007f,0x224c01c4,0xa2d823ff,0x65a8022e}},	//   _ftaa_, _nbek_, _फील्, _sоha, 
   {{0x2908074d,0x00000000,0x00000000,0x00000000}},	// [3af40] _gtaa_, --, --, --, 
   {{0x769801e1,0x224c4c91,0x20040254,0x14240212}},	//   _díya, _abek_, _nfli_, ідем, 
   {{0xa9040344,0x98800171,0xdce800ef,0x00000000}},	//   _وبین, _mīļu_, dzeļ, --, 
   {{0x2006057e,0xc20c01d9,0x7e100b4c,0x00000000}},	//   _afli_, نٔم_, ठरोग_, --, 
   {{0x6f080789,0x3cfc047e,0x41e000d4,0x25ac8256}},	//   _stdc, jquv_, міша, _želv_, 
   {{0x7526057f,0xdc440024,0xe5700a7c,0x70581d39}},	//   msiz, _būči, _אַל_, сакр_, 
   {{0xfbc553cb,0x44fc006a,0x752596f5,0x1798008f}},	//   _آت_, _zî_, lsiz, ייַב, 
   {{0x656a0580,0xb8dc025c,0x2004032e,0x76980241}},	//   _šehi, _ཇམ_, _efli_, _yíya, 
   {{0x75260581,0x00000000,0x00000000,0x00000000}},	//   nsiz, --, --, --, 
   {{0x224c006c,0x75260582,0x23b000db,0x7a4401d3}},	//   _zbek_, isiz, _تۅۅس, yító, 
   {{0x290a0583,0x75260584,0x0ba80150,0xc3f8008f}},	//   _staa_, hsiz, شادى_, יליש, 
   {{0x75260585,0x0dc94355,0x8a180014,0x00000000}},	//   ksiz, _клей_, گتھس_, --, 
   {{0x6e220586,0x76ac010b,0xc8640aa8,0x3eb0180f}},	//   mamb, rşyl, отви, èxte_, 
   {{0x44fc025a,0x7524263e,0x7a4401d3,0x0ba800db}},	//   _rî_, dsiz, tító, _پاتى_, 
   {{0x44fc145e,0x6e2001f7,0x75260587,0x941c06be}},	//   _sî_, oamb, esiz, _ötə_, 
   {{0x6e2003d1,0x8ca402ab,0x7a4401ed,0x44fc0142}},	//   namb, टोरो, rító, _pî_, 
   {{0x6e200451,0x6aac0bd7,0x29080418,0x7a4401ed}},	// [3af50] iamb, _imaf, _utaa_, sító, 
   {{0x7a4401d3,0x8704072d,0x00000000,0x00000000}},	//   pító, _وبجل, --, --, 
   {{0x6e220588,0x67d4016c,0x39b801f2,0xe65803f6}},	//   kamb, _хону, ọst_, _линч_, 
   {{0x44fe0589,0x6e22058a,0x752401b9,0x622400d1}},	//   _tî_, jamb, bsiz, سىتل, 
   {{0x6e22058b,0x661c4ffc,0xc6140fc8,0xe0d40114}},	//   damb, _iesk, तरीय_, подњ, 
   {{0x661e058c,0x6e20003a,0xe7cc03d4,0x00000000}},	//   _hesk, eamb, লধীয, --, 
   {{0x661da500,0x6e22058d,0x6aaccdc8,0xd00c00ae}},	//   _kesk, famb, _omaf, دلى_, 
   {{0x6e22058e,0x224c008b,0x661e058f,0xdd9096b4}},	//   gamb, _ubek_, _jesk, فوع_, 
   {{0x661e0590,0x98800171,0x6edc000d,0xa114e3a3}},	//   _mesk, _pīļu_, _पठरु, _روات, 
   {{0x6aae0591,0x6e200280,0x1c4501eb,0xddd8033f}},	//   _amaf, aamb, чном, _pawł, 
   {{0x6e2053ff,0x661c02d0,0x5ac8234c,0x75242bcc}},	//   bamb, _oesk, йлом_, zsiz, 
   {{0x661e0592,0x7524036b,0xef18003b,0x00000000}},	//   _nesk, ysiz, _ємі_, --, 
   {{0x628a0593,0xed5802bf,0x75242577,0x3cfc0455}},	//   _moeo, _мої_, xsiz, qquv_, 
   {{0x6aac13c4,0xcdd8008f,0xe8d80208,0x7524749b}},	//   _emaf, _פֿאר, _trờ_, vsiz, 
   {{0x661e0594,0x96960595,0x2c00012d,0x8c1800d9}},	//   _besk, праш, लुओं_, _הוצי, 
   {{0x62880295,0x7525e8ef,0x661e0596,0x2bd009ab}},	//   _noeo, tsiz, _cesk, _हडता, 
   {{0x661e0597,0x7ae401b2,0x1fd002f5,0x75240337}},	// [3af60] _desk, _ihit, াধিস, usiz, 
   {{0x661c00af,0x18a4010a,0x00000000,0x00000000}},	//   _eesk, _хаом, --, --, 
   {{0x6e220598,0x7ae42e95,0x628a0599,0x7526059a}},	//   yamb, _khit, _boeo, ssiz, 
   {{0x661c0591,0x7526059b,0x32e80432,0x25e80073}},	//   _gesk, psiz, _aşyr_, चेही_, 
   {{0x6e22059c,0xb4040e76,0x7ae4efd2,0x62880142}},	//   vamb, _жүзд, _mhit, _doeo, 
   {{0x5778044e,0x661e059d,0x7ae41418,0x2ed40b7c}},	//   _ኣመንቲ_, _zesk, _lhit, दत्त, 
   {{0xb4d83eaf,0x7ae58a6d,0x7f80b524,0x661e059e}},	//   ाती_, _ohit, فلون, _yesk, 
   {{0x4ea6059f,0x6e2001f7,0x03b8011a,0xcb44009d}},	//   ярла, uamb, _הצלל, үхни, 
   {{0x6e207752,0x81d0015b,0xfd40009d,0x00000000}},	//   ramb, হেব_, нээн, --, 
   {{0x7ae605a0,0xc19804ae,0xc98400d1,0xeff80092}},	//   _ahit, _השמי, җуми, ወያያ_, 
   {{0x6e2205a1,0x7ae40876,0x00000000,0x00000000}},	//   pamb, _bhit, --, --, 
   {{0x7ae605a2,0x6e21d38e,0xb4d800dc,0xfba4005b}},	//   _chit, qamb, ातु_, ятый_, 
   {{0x661c0699,0x7ae605a3,0x7bc007de,0x00000000}},	//   _resk, _dhit, _exnu, --, 
   {{0x7ae4033d,0xf9901b45,0x661e05a4,0x53bc07b7}},	//   _ehit, ابَ_, _sesk, ्थाश, 
   {{0x661e05a5,0x7ae605a6,0x3fcc2d40,0x15d802dd}},	//   _pesk, _fhit, ﺗﻘﺎﻧ, _ﺃﺭﺍﺩ, 
   {{0x7ae40842,0x6aae05a7,0x389605a8,0x36880116}},	//   _ghit, _umaf, _ağrı_, псун_, 
   {{0x661d0813,0x3908009d,0x00000000,0x00000000}},	// [3af70] _vesk, _нээн_, --, --, 
   {{0x661e05a9,0xa7740276,0x7ae4fb4b,0x54780092}},	//   _wesk, _жлоч, _zhit, _ተዛማጅ_, 
   {{0x6abe05aa,0x62880254,0xe7043cc4,0x22a40107}},	//   onsf, _poeo, _تسخی, мудҳ, 
   {{0xded80020,0xb1840232,0x6abc03a1,0x661c11b0}},	//   ሮችን_, _šťas, nnsf, _uesk, 
   {{0xf19402bf,0x45700724,0xdb000036,0x61442cdb}},	//   ниць, _яңар, tzlë, фела, 
   {{0x32dc00d2,0x7d080037,0x656da1e3,0x00000000}},	//   bíyo_, _rtgs, mvah, --, 
   {{0x62880607,0x25e8445f,0x02a400c0,0x00000000}},	//   _toeo, चेरी_, _ерам, --, 
   {{0x656c0254,0x00000000,0x00000000,0x00000000}},	//   ovah, --, --, --, 
   {{0x0e6050c0,0xdca40131,0x7ae403cb,0x656dae44}},	//   ткын, дапи, _rhit, nvah, 
   {{0x7ae605ab,0x9b04136b,0x00000000,0x00000000}},	//   _shit, мзод, --, --, 
   {{0x7ae605ac,0x5f940592,0x656c0037,0x2fc00112}},	//   _phit, _تلائ, hvah, ßigt_, 
   {{0x7ae40227,0x656c0093,0x63a40165,0x6abc0413}},	//   _qhit, kvah, izhn, gnsf, 
   {{0x9980166a,0x7ae40099,0xea94009d,0x09e0004e}},	//   makū_, _vhit, хшээ, коюн, 
   {{0x7ae605ad,0x6abc000f,0xacc801ec,0x2ba8000d}},	//   _whit, ansf, _егіз_, _छेका, 
   {{0x9b0407d6,0x1a6401ed,0xdc4400de,0x00000000}},	//   _ўзид, _قیدی_, _mīļi, --, 
   {{0x7ae605ae,0xe8d807ae,0x00000000,0x00000000}},	//   _uhit, _trở_, --, --, 
   {{0x17f800c6,0xbb30001f,0x656c0175,0x95981cd0}},	// [3af80] _وردة_, _በተቃዋ, gvah, цтву_, 
   {{0xb4d8687b,0x32dc00d2,0x32e80432,0x3a200142}},	//   ाते_, tíyo_, _aşyp_, _heip_, 
   {{0x99800093,0x69c005d1,0x00000000,0x00000000}},	//   kakū_, şlet, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xba4802d5,0xbef40316,0xfbcc37e3,0x6628012c}},	//   _grįž, ँदैन_, _सुसम, řský, 
   {{0xcf9810fc,0x00000000,0x00000000,0x00000000}},	//   жји_, --, --, --, 
   {{0x30840032,0x6abc12ed,0x0440030d,0x00000000}},	//   _үҫем, ynsf, _шерн, --, 
   {{0xd130004b,0x3a2001ab,0x00000000,0x00000000}},	//   _لمر_, _neip_, --, --, 
   {{0x90e42e0b,0x6abe05af,0x00000000,0x00000000}},	//   _قسطن, vnsf, --, --, 
   {{0xe57000c8,0x00e000a8,0x6abc0042,0x00000000}},	//   אַט_, _ажун, wnsf, --, 
   {{0x656d6c5c,0xaab40953,0x81d00154,0x8e08009b}},	//   zvah, ейні, হেদ_, _днев_, 
   {{0xbb901de1,0x3a2205b0,0x6abe05b1,0x656c03b2}},	//   тающ, _ceip_, unsf, yvah, 
   {{0x6abc0250,0x3a200042,0x4c84009d,0x00000000}},	//   rnsf, _deip_, _олдв, --, 
   {{0xb4da05b2,0xdc4400b0,0xeff8001f,0x656c0254}},	//   ातो_, _tūāi, ለጫው_, vvah, 
   {{0xfbcc0451,0xe7944e5c,0x7c38011a,0x988000ef}},	//   _پتو_, راسک, _ותוס, _līķu_, 
   {{0x3a200048,0xf9900133,0x00000000,0x00000000}},	//   _geip_, ابێ_, --, --, 
   {{0x7af8004e,0xe4980166,0x00000000,0x00000000}},	// [3af90] _èxta, пкач_, --, --, 
   {{0x2a680441,0x656e05b3,0xe4d408b0,0xded8001f}},	//   _haab_, rvah, رقاد, ሮችና_, 
   {{0x656c793d,0x2a6a05b4,0xdb0001c7,0xe69401af}},	//   svah, _kaab_, tzlé, _зины, 
   {{0x9990007f,0x2a680254,0xe58400f7,0x00000000}},	//   _deyņ_, _jaab_, _كۅزۉ_, --, 
   {{0x2128003e,0xe2d80014,0x20d402dd,0x00000000}},	//   éah_, _ہارچ_, нікс, --, 
   {{0x2a684ab0,0x98800171,0xdb0000e5,0x00000000}},	//   _laab_, _dīķu_, szlé, --, 
   {{0x998000b0,0x00000000,0x00000000,0x00000000}},	//   takū_, --, --, --, 
   {{0x2a680218,0xf9fc0327,0xfbcc03ba,0x00000000}},	//   _naab_, _དཔེན_, _सुषम, --, 
   {{0x3a200381,0x02d80073,0x00000000,0x00000000}},	//   _reip_, बतीन, --, --, 
   {{0x31785220,0x5ba854ea,0x51640116,0x3a2205b5}},	//   _تحفظ_, зком_, _чүшү_, _seip_, 
   {{0x2a68a6ec,0x998000b0,0x62980083,0x1e1406a6}},	//   _baab_, pakū_, okwo, _змея, 
   {{0xdce80010,0x00000000,0x00000000,0x00000000}},	//   mveč, --, --, --, 
   {{0x2a680009,0xc0e80023,0xfbcccbb5,0x00000000}},	//   _daab_, ቅጽል_, _सुरम, --, 
   {{0x2a68005a,0xddd80100,0xac840220,0x3ebc0f85}},	//   _eaab_, _pawņ, _игіл, lnut_, 
   {{0x3a2205b6,0x3ebc0548,0x7ac400c7,0xac7426d4}},	//   _teip_, onut_, _аҩна, _جانش, 
   {{0x3ebe05b7,0xb4d81161,0x2a680067,0x629801f5}},	//   nnut_, ात्_, _gaab_, jkwo, 
   {{0x69c03b13,0x3ebe05b8,0x8ca43507,0x00000000}},	// [3afa0] şler, inut_, टोको, --, 
   {{0x6298057b,0x3ebc0419,0xd8a801c8,0xf3f402f2}},	//   ekwo, hnut_, _رهجو_, نتاک, 
   {{0x3ebe05b9,0xdce80fb7,0xf484020e,0x2a6801d9}},	//   knut_, jveč, _یاسی, _yaab_, 
   {{0x2a680218,0xe2aa05ba,0xdce863e4,0x00000000}},	//   _xaab_, وانن_, dveč, --, 
   {{0x3ebc3858,0x00000000,0x00000000,0x00000000}},	//   dnut_, --, --, --, 
   {{0x62980083,0x3ebc0ba1,0x00000000,0x00000000}},	//   akwo, enut_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3ebc0b91,0x62982278,0x00000000,0x00000000}},	//   gnut_, ckwo, --, --, 
   {{0xfd0dc2cd,0x8ff85263,0x2a699dcf,0x2cb0022e}},	//   یجی_, _فرار_, _raab_, аldа_, 
   {{0x2a68033d,0xc5f004ac,0x3ebce80c,0x00000000}},	//   _saab_, נדז_, anut_, --, 
   {{0x2a680694,0xccc000f7,0x00000000,0x00000000}},	//   _paab_, _ۅڭدۉ, --, --, 
   {{0x2a688c8a,0x3ebd190a,0x00000000,0x00000000}},	//   _qaab_, cnut_, --, --, 
   {{0xbb4465dc,0x00000000,0x00000000,0x00000000}},	//   ولین_, --, --, --, 
   {{0x2a682878,0x00000000,0x00000000,0x00000000}},	//   _waab_, --, --, --, 
   {{0x67d43e2e,0x2a680009,0x00000000,0x00000000}},	//   тову, _taab_, --, --, 
   {{0x7bd806a9,0xe8d80051,0x93580023,0x00000000}},	//   _מקוו, _prồ_, ጀክትታ, --, 
   {{0xdce80419,0x85880108,0x6b9c03b2,0x00000000}},	// [3afb0] zveč, чёва_, ørgf, --, 
   {{0x4784084c,0x3ebc16a3,0xb5d40063,0x00000000}},	//   _зымб, znut_, ужуј, --, 
   {{0xe2f40dd4,0x6d5c0882,0xefc01772,0x3ebc0548}},	//   _བཤདཔ_, āray, _ስጋዊ_, ynut_, 
   {{0x21f40075,0xe8d80208,0xb284004e,0xf364013d}},	//   نكاس, _trồ_, лычк, ытун, 
   {{0x62980430,0x310802dd,0xf5e605bb,0x00000000}},	//   rkwo, еніп_, _бірм, --, 
   {{0x629879c9,0xf4240154,0x00000000,0x00000000}},	//   skwo, _পাথর_, --, --, 
   {{0x9f5000ac,0x33580276,0x25aa05bc,0xa304014b}},	//   _üzü_, _парэ_, lzal_, _рӯзе, 
   {{0x442205bd,0x3ebe05b8,0x7e60035b,0x15ec01f9}},	//   _hej_, unut_, уеиҧ, चेवर_, 
   {{0x25a80048,0x3ebcc203,0xc05800d6,0x442205be}},	//   nzal_, rnut_, _ніж_, _kej_, 
   {{0x44202344,0x11681f7e,0x90a000cf,0x00000000}},	//   _jej_, _زلمی_, _ۅڭۉم, --, 
   {{0x44200842,0x3ebc0306,0x1ae400cf,0x00000000}},	//   _mej_, pnut_, коом, --, 
   {{0x442205bf,0x2ecc043e,0x5dd40137,0x25a8a47f}},	//   _lej_, ावृत, _июлу, kzal_, 
   {{0x64541326,0x81d02aab,0xc96000a7,0xdfc800cd}},	//   _obzi, হের_, авяй, _kṣīṇ, 
   {{0x442205c0,0x25a80419,0x00000000,0x00000000}},	//   _nej_, dzal_, --, --, 
   {{0x7c20045f,0xefe40023,0xe7ec0037,0x98240014}},	//   _ienr, _ዝኸደ_, छेला_, ى۪کہ_, 
   {{0x645605c1,0xc6c0e29b,0x7e680af9,0x25a801a9}},	//   _abzi, айск, _jagp, fzal_, 
   {{0x442205c2,0x7e68778b,0x7c2003bd,0x25a8022e}},	// [3afc0] _bej_, _magp, _kenr, gzal_, 
   {{0x7e68079b,0x44201100,0x97d8007b,0x2ee00327}},	//   _lagp, _cej_, _يبدأ_, ċifi_, 
   {{0x44200190,0x7c200a2e,0x25a919eb,0x7628014b}},	//   _dej_, _menr, azal_, _пенҳ_, 
   {{0x7e696ad4,0x1dc000af,0xefe402d3,0x25a801d5}},	//   _nagp, शपात, _ዝኸዱ_, bzal_, 
   {{0xb3841cd1,0x86b00220,0x80c8009e,0x442205c3}},	//   _әһел, _тәрі, িতন্, _fej_, 
   {{0x4421ea9c,0x61ec09a5,0x212c0fb7,0x764605c4}},	//   _gej_, ýala, _dveh_, lgiy, 
   {{0x7e6a05c5,0x81d00154,0x7644022e,0x37d400cc}},	//   _bagp, হেল_, ogiy, _ধৃতৰ, 
   {{0x764605c6,0x44200070,0x00000000,0x00000000}},	//   ngiy, _zej_, --, --, 
   {{0x7e681e48,0x7c2205c7,0x442205c8,0xdb080118}},	//   _dagp, _benr, _yej_, ěným, 
   {{0x7c2205c9,0x4420031c,0x00000000,0x00000000}},	//   _cenr, _xej_, --, --, 
   {{0x25aa05ca,0x7e6a05cb,0x7c212b83,0x2e4401ed}},	//   zzal_, _fagp, _denr, _مفاہ, 
   {{0x7c20257c,0xdfc80055,0x8ca407f7,0x00000000}},	//   _eenr, _iṣūṇ, टोजो, --, 
   {{0x98a00024,0x00000000,0x00000000,0x00000000}},	//   nukė_, --, --, --, 
   {{0x25a802fb,0x76440009,0x8bb400ae,0x00000000}},	//   vzal_, egiy, _لإعا, --, 
   {{0x6d4205cc,0xf42800bd,0x92205219,0x0ba800db}},	//   luma, মলার_, मराज_, _تاشى_, 
   {{0x442205cd,0x25aa05ce,0x7c2004ce,0x6d4000b5}},	//   _sej_, tzal_, _zenr, ouma, 
   {{0x6d4205cf,0x44200070,0x25a8030a,0x00000000}},	// [3afd0] numa, _pej_, uzal_, --, 
   {{0x7c200005,0xdecc02d3,0x6d4130ac,0x44218667}},	//   _xenr, _ኢየን_, iuma, _qej_, 
   {{0x6d4205d0,0x4420105c,0x76ac010b,0x25a87ddf}},	//   huma, _vej_, gşys, szal_, 
   {{0x44200842,0xf2e400d4,0x00000000,0x00000000}},	//   _wej_, аючо, --, --, 
   {{0x442205d1,0x6d4205d2,0xdf600241,0x26d80115}},	//   _tej_, juma, _bé̟è, _ikso_, 
   {{0x6d4205d3,0xf0e80075,0x630605d4,0xe8d801fb}},	//   duma, نىنى_, _موسل, _trổ_, 
   {{0x7e68417f,0x6d40ccf3,0x7c20d468,0x6444014f}},	//   _pagp, euma, _renr, mghi, 
   {{0x6d4205d5,0x660c3e39,0x7c2205d6,0x9e6401b9}},	//   fuma, ncak, _senr, увид, 
   {{0x6d4205d7,0x41b406ab,0x7c2205d8,0x660c0a73}},	//   guma, _अधिस, _penr, icak, 
   {{0x64453a24,0x7e68017a,0x76440790,0x00000000}},	//   nghi, _wagp, zgiy, --, 
   {{0x7c200f71,0x7e68c9e7,0x64440013,0x26d8020c}},	//   _venr, _tagp, ighi, _okso_, 
   {{0x7c20017a,0xad240228,0x644605d9,0x00000000}},	//   _wenr, _چىنى, hghi, --, 
   {{0x6d4205da,0x7c20a7b1,0x76441ae4,0xad2407d2}},	//   cuma, _tenr, vgiy, _نىنى, 
   {{0x91b80302,0xdd9809a5,0x26d8010f,0xf8b010e5}},	//   תמשי, myň_, _akso_, تکب_, 
   {{0xdd9809a5,0x07a205db,0xcb940014,0xb8dc1f5e}},	//   lyň_, барн, _منوش_, _आग_, 
   {{0x6b9cb59a,0x6444011c,0x660c0fec,0x07a00212}},	//   ørge, eghi, gcak, щасн, 
   {{0xdd98f2bd,0x764605dc,0x64440175,0x95c801a9}},	// [3afe0] nyň_, rgiy, fghi, хлаб_, 
   {{0x644605dd,0x26da05de,0x6ba8010e,0x186800d8}},	//   gghi, _ekso_, _ösgü, _џани_, 
   {{0x6d41103a,0xd62806bb,0x660c0072,0x3dcc00cc}},	//   zuma, _поне_, bcak, াইটল, 
   {{0x6d414e08,0x9149063f,0x64442d33,0x15b80166}},	//   yuma, ечка_, aghi, _зыгы_, 
   {{0x76ac0209,0x6d4205df,0x6444031c,0x15ba05e0}},	//   bşyr, xuma, bghi, _чыны_, 
   {{0xdd9809a5,0x10080e8e,0xc9500375,0x1cbc0327}},	//   dyň_, رتتى_, צמו_, ཆོས_, 
   {{0x6d40013b,0x660c01f4,0x7df800ef,0xb4d00073}},	//   wuma, _älkö, _lāsī, शवी_, 
   {{0x81d000fe,0xdd98010e,0x00000000,0x00000000}},	//   হেই_, fyň_, --, --, 
   {{0xdd9809a5,0x71740131,0x7df86991,0x00000000}},	//   gyň_, _خۇشا, _nāsī, --, 
   {{0x6d4205e1,0x8c647577,0x00000000,0x00000000}},	//   ruma, утид, --, --, 
   {{0x6d4205e2,0x660d8bba,0x00000000,0x00000000}},	//   suma, ycak, --, --, 
   {{0x0dc8c439,0xdd9800ee,0x6444020c,0x00000000}},	//   _пули_, byň_, zghi, --, 
   {{0x7df8002b,0x6d4205e3,0x64459ea8,0xdd8c01d3}},	//   _cāsī, quma, yghi, _ہڈی_, 
   {{0x2a6c0316,0xfbcc05d7,0x7df8002b,0x64440175}},	//   žeb_, _सुकम, _dāsī, xghi, 
   {{0x660c06f2,0x2490012d,0x00000000,0x00000000}},	//   tcak, _rozm_, --, --, 
   {{0xa6140228,0x25ac00a2,0xe978014b,0x00000000}},	//   рмач, _ýelk_, _абиш_, --, 
   {{0x660e05e4,0x6444054e,0x53740092,0x19c060c6}},	// [3aff0] rcak, tghi, _የሚወድ_, _дәрг, 
   {{0x29180054,0xe8d8063f,0x26148a4f,0x644400ad}},	//   mpsa_, _mpị_, _फ्री_, ughi, 
   {{0xdd9809a5,0x64448947,0x3f840327,0x09a800cc}},	//   zyň_, rghi, xxnu_, _গুচা, 
   {{0x29180161,0xd5b80107,0x00000000,0x00000000}},	//   opsa_, хсӣ_, --, --, 
   {{0x21683967,0x6025783d,0x00000000,0x00000000}},	//   тили_, адла, --, --, 
   {{0xa3640014,0x10a00063,0x7df80171,0x22486e4a}},	//   _پُرو, жишн, _jāsū, żak_, 
   {{0xe8d801f2,0xdd9809a5,0xd344315b,0xcf8c0014}},	//   _apị_, wyň_, _نیله_, ٘ژن_, 
   {{0xdd980209,0xceac0451,0x118400e5,0x98a00210}},	//   tyň_, وڙن_, _چھوٹ_, mską_, 
   {{0x31580597,0x98a0033f,0xc04400ae,0x00000000}},	//   _مجلة_, lską_, _مخاو, --, 
   {{0xdd9a05e5,0x61ea05e6,0x2918009a,0xefc00023}},	//   ryň_, _izel, dpsa_, _ድላዩ_, 
   {{0xfbcc00dc,0xdd9800ee,0x4c800212,0x3a280166}},	//   _सुखम, syň_, ілюв, ленү_, 
   {{0x7f4205e7,0x00000000,0x00000000,0x00000000}},	//   munq, --, --, --, 
   {{0x7f4205e8,0x787c0267,0x00000000,0x00000000}},	//   lunq, _nåvä, --, --, 
   {{0x8c4205e9,0xddc800df,0xc0cc069d,0x7df800b8}},	//   _деше, ndeŭ, ባበሩ_, _vāsī, 
   {{0xd628049d,0x4cb80302,0x69cc0381,0x1ca403e6}},	//   кове_, _במסג, _exae, _مێکی_, 
   {{0x61ea05ea,0x00000000,0x00000000,0x00000000}},	//   _ozel, --, --, --, 
  
   {{0x61e83d81,0x94240a8f,0x7f4205eb,0x1424546a}},	// [3b000] _nzel, имае, hunq, идам, 
   {{0xc48205ec,0x7f4205ed,0xb4d00073,0xd70835c7}},	//   олук, kunq, शवे_, _иное_, 
   {{0x61ea05ee,0x522605ef,0x98a002b5,0x7f400477}},	//   _azel, афла, hukī_, junq, 
   {{0x86b00220,0x78be05f0,0x8b54010f,0x13e4000d}},	//   _дәуі, lirv, ייעס_, _करीह_, 
   {{0x3b040113,0x61e8033f,0x7cec0fac,0x116401d5}},	//   _lunq_, _czel, mørf, شلغی_, 
   {{0x61e800da,0x78bc0882,0x7f400472,0x3b00058a}},	//   _dzel, nirv, funq, _liiq_, 
   {{0x3b04070d,0x61ea05f1,0x7f40209c,0x4ea46bfd}},	//   _nunq_, _ezel, gunq, ириа, 
   {{0x78be05f2,0x2d80031c,0x7cec5522,0x00000000}},	//   hirv, _ġieb_, nørf, --, 
   {{0x3b040407,0x78be05f3,0x1ba00023,0x504400d8}},	//   _aunq_, kirv, _ዝመረጸ_, _везб, 
   {{0x7f400921,0xc0cc00b7,0x00000000,0x00000000}},	//   bunq, ባበር_, --, --, 
   {{0x7f4205f4,0x78bc0579,0xe47800c8,0x00000000}},	//   cunq, dirv, אָרש, --, 
   {{0x6b880175,0x7df800b8,0x00000000,0x00000000}},	//   rxdg, _sāsū, --, --, 
   {{0x3b00be73,0x6f0893e0,0x78bc01a8,0xec3401d5}},	//   _diiq_, _hudc, firv, _هوشگ, 
   {{0xdb0001ed,0x29197f98,0xc7c401b9,0x25ac010e}},	//   szlá, rpsa_, асби, _ýeli_, 
   {{0x787c049f,0x3b000014,0x2b5dbbe0,0x5fc80118}},	//   _såvä, _fiiq_, _upvc_, िपयल, 
   {{0x6f084146,0xfaa400c7,0x787c0267,0x76a801d5}},	//   _mudc, _мшын, _påvä, атув_, 
   {{0x4428301d,0x78bc0077,0x98a0033f,0x4404005b}},	// [3b010] вцем_, birv, wską_, ачеб, 
   {{0x44240597,0xe8d801f2,0x6abe05f5,0x78be05f6}},	//   ún_, _kpọ_, lisf, cirv, 
   {{0xc7640058,0x61e800dd,0x290a034b,0x6f08047e}},	//   _ئاخى, _szel, _huaa_, _nudc, 
   {{0x6abe05f7,0x7f400395,0xddc80311,0x2908035b}},	//   nisf, vunq, ndeţ, _kuaa_, 
   {{0x290008f5,0x7f400921,0x00000000,0x00000000}},	//   _kiha_, wunq, --, --, 
   {{0x29000b45,0x61e809a8,0x7f4002d1,0x27e001bf}},	//   _jiha_, _vzel, tunq, _kyhn_, 
   {{0x290205f8,0xd00c037b,0x6abc05f7,0xddc801e4}},	//   _miha_, رلي_, kisf, rdeŭ, 
   {{0x1e856347,0x290205f9,0x29080418,0x6f080477}},	//   слим, _liha_, _ouaa_, _dudc, 
   {{0x6abe05fa,0x77e404fa,0x3b040113,0xdfd001ed}},	//   disf, _गर्क_, _sunq_, _کيا_, 
   {{0x290205fb,0x7f400309,0x98a000b0,0x00000000}},	//   _niha_, punq, rukī_, --, 
   {{0x29080270,0x6f080067,0x6abc007f,0x2004036e}},	//   _auaa_, _gudc, fisf, _igli_, 
   {{0x2908013f,0x3b00058a,0x6b9d6c1e,0x6abc08ce}},	//   _buaa_, _qiiq_, ørga, gisf, 
   {{0x290205fc,0x7cec0158,0xee78785c,0x0e705085}},	//   _biha_, jørg, _خصلت_, _رُوح, 
   {{0x7d1a05fd,0x2908013f,0x4e8800c7,0x29000055}},	//   mpus, _duaa_, _ашәҭ_, _ciha_, 
   {{0x290051e2,0x29080270,0x78bc0008,0x7d19d2dd}},	//   _diha_, _euaa_, rirv, lpus, 
   {{0x290872dc,0x598402bf,0x29000022,0x78be05fe}},	//   _fuaa_, _глиб, _eiha_, sirv, 
   {{0x7d1a05ff,0x29020600,0x20040548,0x00000000}},	// [3b020] npus, _fiha_, _ogli_, --, 
   {{0x29000223,0x20060601,0x7cec0158,0x7d1a0602}},	//   _giha_, _ngli_, sørf, ipus, 
   {{0x0fd400af,0x7d180205,0x00000000,0x00000000}},	//   _ढुंढ, hpus, --, --, 
   {{0x200406bb,0x2900337a,0xd184113e,0x25ac012d}},	//   _agli_, _ziha_, йлей, _żele_, 
   {{0x29000526,0x6f08cfc4,0xddd80139,0x65c001ec}},	//   _yiha_, _sudc, _rawş, _жұта, 
   {{0x987800c8,0x224c194f,0x7d1802f0,0xcee803e6}},	//   ראַט, _ecek_, dpus, گرتن_, 
   {{0x7d1a0603,0xb4d4c59b,0x38b803b9,0x936c0092}},	//   epus, हकी_, _cürə_, _ባልሆነ_, 
   {{0x20051aa8,0x6f080455,0xcee80014,0x6abc8c58}},	//   _egli_, _vudc, درتن_, xisf, 
   {{0x0af0152d,0x7d198ca2,0x9e7000d1,0xadb80066}},	//   үүлэ, gpus, بۇنت, شهدا_, 
   {{0x7cec5792,0xab68031c,0xfc38001f,0x2cba0604}},	//   jørd, _lażż, _በአገል, òrd_, 
   {{0x29020605,0x2908016b,0x8e4800c6,0xddd80166}},	//   _riha_, _suaa_, _ملاك_, _tawş, 
   {{0x29088cae,0xe8d80016,0x29018cf9,0x81d000cc}},	//   _puaa_, _trừ_, _siha_, হেও_, 
   {{0x29013de1,0x6abc022c,0x7d1800e2,0x98a0033f}},	//   _piha_, risf, cpus, lskę_, 
   {{0xac1a055d,0x6abc03ac,0x7cec03b2,0x00000000}},	//   _току_, sisf, vørg, --, 
   {{0x49900502,0xc6a60606,0x29003110,0x29080036}},	//   زیگر, браи, _viha_, _wuaa_, 
   {{0x59d83c20,0x6d4150d7,0x290a0607,0x290000ca}},	//   _युवर, orma, _tuaa_, _wiha_, 
   {{0x6d40083a,0x00000000,0x00000000,0x00000000}},	// [3b030] nrma, --, --, --, 
   {{0x29001132,0x1cbc0327,0xadf0012d,0x64a40022}},	//   _uiha_, ཆོག_, _चरनन_, әаҧа, 
   {{0x7d18132c,0x6d420608,0x7cec072b,0xd7200023}},	//   zpus, hrma, sørg, ታቶርነ, 
   {{0x7cec28b3,0xab680327,0x22585016,0x0584014b}},	//   pørg, _gażż, риды_, _лугм, 
   {{0x7cec5522,0x38b803b9,0x00000000,0x00000000}},	//   løre, _sürə_, --, --, 
   {{0xb60803c6,0x6d401050,0xcacc0154,0x00000000}},	//   _vyšš, drma, রতিফ, --, 
   {{0xd00c2aa5,0x26ca0609,0x7cec32b8,0xa4e40073}},	//   خلى_, onao_, nøre, कतीच_, 
   {{0x82340214,0x26c892de,0x7d1805d5,0x20040208}},	//   _درسا, nnao_, tpus, _wgli_, 
   {{0x6d40089c,0x7cec0627,0x26c803d1,0x80240133}},	//   grma, høre, inao_, _هرام, 
   {{0xdc982097,0x7cec3986,0x2004022e,0x20105c01}},	//   ртиш_, køre, _ugli_, _üzi_, 
   {{0xda64bcf2,0x6d42060a,0x5ac852d8,0x7cec2c95}},	//   овни, arma, илом_, jøre, 
   {{0x7d1a060b,0x7cec1477,0x4fd4008f,0x657c035a}},	//   ppus, døre, _וועב_, _orsh, 
   {{0xdce80bb8,0x3ebc0af5,0xae680014,0xab680327}},	//   jveć, miut_, _دٕنن_, _rażż, 
   {{0x7cec708a,0x3ebe060c,0x25dc09bb,0xd13c0023}},	//   føre, liut_, _खड़ी_, _ኣይበል, 
   {{0x657e060d,0x7d0a060e,0x7cec019b,0x7d00198f}},	//   _arsh, _hugs, gøre, _iins, 
   {{0x7d02060f,0x7d0a0610,0x3ebd71eb,0x657c0076}},	//   _hins, _kugs, niut_, _brsh, 
   {{0x7d020611,0x54360612,0x7cec005c,0x00000000}},	// [3b040] _kins, قرار, mørb, --, 
   {{0x7d020613,0x26c803d1,0xb4d400af,0x27ec00bc}},	//   _jins, anao_, हके_, řena_, 
   {{0x7d020614,0x779404d3,0x3ebe0615,0x7d080ea0}},	//   _mins, _عیرا, kiut_, _lugs, 
   {{0x6d4009a5,0xa3000184,0x51840276,0x11e40815}},	//   yrma, еүсе, жука, ожем, 
   {{0x93880032,0x7d014531,0x3ebd3dca,0x00000000}},	//   ысҡа_, _oins, diut_, --, 
   {{0x7d020616,0x00000000,0x00000000,0x00000000}},	//   _nins, --, --, --, 
   {{0x7d080029,0x6d400009,0xcc0801b9,0x3ebc0200}},	//   _augs, wrma, یزدن_, fiut_, 
   {{0x7d020617,0x7d0a0618,0x7cec03cd,0x6d400477}},	//   _ains, _bugs, jørb, trma, 
   {{0x7d020619,0x6d42061a,0xd1b003e6,0xfd4001c6}},	//   _bins, urma, _تیشک, мээн, 
   {{0x26c80bb8,0x7d002e90,0x7d080050,0x6d42061b}},	//   znao_, _cins, _dugs, rrma, 
   {{0x7d02061c,0x5c3028b1,0x7d0808c2,0xddc801a6}},	//   _dins, رکوز, _eugs, rdeš, 
   {{0x7d02061d,0xddc80024,0x6d40003e,0x7cec072b}},	//   _eins, sdeš, prma, vøre, 
   {{0x7d02061e,0x26c80e3c,0xded801f7,0x00000000}},	//   _fins, vnao_, _اُنڙ_, --, 
   {{0x7d02061f,0x7cec95a0,0xb4d4012c,0x02b40b02}},	//   _gins, tøre, हको_, _आग्न, 
   {{0x7d09e5da,0x23d81b76,0xd13c0023,0x201806be}},	//   _zugs, _बुंद, _ኣይብል, _əsi_, 
   {{0x7d020620,0x7cec7eb1,0x36880228,0x657c0200}},	//   _zins, røre, осун_, _prsh, 
   {{0x7cec0627,0x390841b9,0x00000000,0x00000000}},	// [3b050] søre, _мээн_, --, --, 
   {{0x7d012065,0xa4e40490,0x3ebc036e,0xa3d400cf}},	//   _xins, कतेच_, ziut_, позч, 
   {{0xdce80bb8,0x04c400aa,0x26c80109,0x0d3c0240}},	//   sveć, موړي_, pnao_, _ተነፊግ, 
   {{0x217525e5,0xe73801af,0x00000000,0x00000000}},	//   зукр, _кеү_, --, --, 
   {{0xbbc402a0,0x657c311d,0x3ebc0200,0x9f5801e1}},	//   _लश्क, _ursh, viut_, _ńsà_, 
   {{0x7d092acc,0x5f740aa0,0x236c01fa,0xa0680a31}},	//   _rugs, كابر, _ćejf_, сака_, 
   {{0x656e0621,0x7d0a0622,0x53a00137,0xdca400d1}},	//   lwah, _sugs, _كۅكك, җани, 
   {{0x7d020623,0x656cb3ae,0xe2c801e2,0xd24c0133}},	//   _sins, owah, _اورو_, _مچه_, 
   {{0x7d020624,0x656e0625,0x3ebc044e,0x2cbc0139}},	//   _pins, nwah, riut_, _bmvd_, 
   {{0x656c0069,0x3ebe0626,0x7d00047e,0x60b45821}},	//   iwah, siut_, _qins, _عمائ, 
   {{0x7d00a5e5,0x3ebc089c,0x656e0627,0xe9f80cad}},	//   _vins, piut_, hwah, _ilẹ_, 
   {{0x656c37ea,0xae5800d4,0x00000000,0x00000000}},	//   kwah, _мріє_, --, --, 
   {{0x7d020628,0xd1f4044e,0x00000000,0x00000000}},	//   _tins, _ጎይታ_, --, --, 
   {{0x23bc255c,0x656c1682,0x83a8012d,0x98a60629}},	//   ्पाद, dwah, चनाआ, чиге, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6b9c33a3,0x6b8401d5,0x656c0036,0x8b38011a}},	//   ärge, _آشول, fwah, _התקצ, 
   {{0x656e062a,0x00000000,0x00000000,0x00000000}},	// [3b060] gwah, --, --, --, 
   {{0x897802e4,0x00000000,0x00000000,0x00000000}},	//   _פריצ, --, --, --, 
   {{0x656c3b5b,0xd2640108,0x00000000,0x00000000}},	//   awah, зкей, --, --, 
   {{0x656c01b2,0xe9f80ca8,0x00000000,0x00000000}},	//   bwah, _alẹ_, --, --, 
   {{0xab0400b8,0xd1e80092,0xe92c0064,0x00000000}},	//   _anṛṇ, ህፍት_, _įtūž, --, 
   {{0x81400131,0x3e6400c7,0x00000000,0x00000000}},	//   رنىن, ҧшын_, --, --, 
   {{0x5eec00b8,0x00000000,0x00000000,0x00000000}},	//   _ṣaḍi, --, --, --, 
   {{0x877800c8,0xd17400c7,0x6b9c365a,0x00000000}},	//   מאצי, _нызы, ørgm, --, 
   {{0x504402d5,0x2dd4702f,0x41240902,0x00000000}},	//   _неаб, ьжир, _ното_, --, 
   {{0xd0440150,0x32d8010e,0x76ac0432,0x00000000}},	//   _ءپاي, _düyş_, gşyz, --, 
   {{0x656c0230,0x8bc4036b,0xead4026b,0x00000000}},	//   zwah, ясид, донь, --, 
   {{0x61ec0210,0x00000000,0x00000000,0x00000000}},	//   żale, --, --, --, 
   {{0xc984016c,0x656c058a,0x6b9c007c,0x00000000}},	//   чуни, xwah, ärgb, --, 
   {{0xfbcc13f9,0xbd8400db,0xe7f80d79,0x29046b56}},	//   ئتی_, _رنىن_, ंधला_, öla_, 
   {{0xc6a40120,0x7c9002da,0x46a4004e,0x00000000}},	//   праи, _سشوا, пшаб, --, 
   {{0xe8d80016,0x656d4ba2,0x27ec00bc,0xe81c44d0}},	//   _trữ_, twah, řeno_, _ब्रा_, 
   {{0xba74c43b,0x6aae062b,0x7cec0158,0x67340175}},	// [3b070] _سايت, _ilaf, løra, sszj, 
   {{0x656e062c,0x6aac00fb,0x870402d5,0x00000000}},	//   rwah, _hlaf, _няме, --, 
   {{0x656e062d,0x6aac1f53,0x7cedc7a6,0x2d8000d0}},	//   swah, _klaf, nøra, _šiel_, 
   {{0x656c014f,0x00000000,0x00000000,0x00000000}},	//   pwah, --, --, --, 
   {{0x6aac009f,0x20d401ce,0x6b9c00cc,0xdc4400ef}},	//   _mlaf, мікс, ørgj, _pūļi, 
   {{0x6aae062e,0xf978011a,0x00000000,0x00000000}},	//   _llaf, פגוש_, --, --, 
   {{0x4432062f,0x00000000,0x00000000,0x00000000}},	//   max_, --, --, --, 
   {{0x7cec3619,0x45280327,0x00000000,0x00000000}},	//   døra, _སྦོར_, --, --, 
   {{0x20540209,0x628801c3,0xa1582bbd,0x00000000}},	//   _окая, _ineo, _фазу_, --, 
   {{0x44320630,0x7ceccefd,0x00000000,0x00000000}},	//   nax_, føra, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x44320631,0x6aac9096,0xb608013a,0x00000000}},	//   hax_, _claf, _myšá, --, 
   {{0x44302e95,0xae04049e,0x00000000,0x00000000}},	//   kax_, _كومى, --, --, 
   {{0x44300054,0x6aac014a,0x20dcbddc,0x4528031c}},	//   jax_, _elaf, यविध, _སྦེར_, 
   {{0x6289aecd,0x44300050,0x48060632,0x6aadb748}},	//   _oneo, dax_, дерн_, _flaf, 
   {{0x6aac0356,0x00000000,0x00000000,0x00000000}},	//   _glaf, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3b080] --, --, --, --, 
   {{0x44320633,0x53a479e4,0x98800171,0x00000000}},	//   gax_, мазб, _rūķu_, --, 
   {{0x7ae4009a,0xf8b83769,0x2d800327,0x00000000}},	//   _kkit, _дөң_, _ġiem_, --, 
   {{0x2d80005f,0x15b8004e,0x988000ef,0xd67c0116}},	//   _šiem_, _дыгы_, _pūķu_, ﻧﻠﻪﺭ_, 
   {{0x44320634,0x7ae60635,0xd01001b9,0x00000000}},	//   bax_, _mkit, نلش_, --, 
   {{0x1de009d9,0x6288f454,0x443016b8,0xf0d401c0}},	//   _पड़त, _eneo, cax_, эжлэ, 
   {{0x7ae60636,0x80a015bf,0x19e800cc,0x00000000}},	//   _okit, ئمىن, _গলোঁ_, --, 
   {{0x7ae60637,0x627000cf,0x7cec03b2,0x00000000}},	//   _nkit, _مۇمئ, vøra, --, 
   {{0xfe6c3738,0x4598010f,0x00000000,0x00000000}},	//   شدي_, ַסטע, --, --, 
   {{0x7ae60638,0x6aae0639,0x7cedb76e,0x8c654da1}},	//   _akit, _slaf, tøra, фтид, 
   {{0x60de063a,0x00000000,0x00000000,0x00000000}},	//   _ísma, --, --, --, 
   {{0xa2a006ab,0x4430ff42,0x7cec00fe,0x00000000}},	//   कॉप्, zax_, røra, --, 
   {{0x4432063b,0xb9e402bf,0x7cec3619,0xf770ace5}},	//   yax_, віри, søra, یاف_, 
   {{0x7ae6063c,0x44300548,0xdb0006af,0xe8d80051}},	//   _ekit, xax_, hylè, _trử_, 
   {{0x4430a06c,0x248c0016,0x00000000,0x00000000}},	//   vax_, _đem_, --, --, 
   {{0x6aae063d,0x4528025c,0x6596063e,0x7cec01bf}},	//   _ulaf, _སྦུར_, набу, nørn, 
   {{0x4432063f,0xd5840116,0x00000000,0x00000000}},	// [3b090] tax_, нәрл_, --, --, 
   {{0x62880a85,0xa7740957,0x00000000,0x00000000}},	//   _sneo, _злоч, --, --, 
   {{0x44320640,0x321c02e3,0x68e40009,0x6b9c0162}},	//   rax_, _ịnụ_, _ikhd, ørgh, 
   {{0x4430094a,0x7cecf5b8,0x6594c9fd,0xa15923a6}},	//   sax_, jørn, _заму, заду_, 
   {{0x4430094a,0x38b40221,0x855400f1,0x35b40024}},	//   pax_, _därf_, _زیار_, _абяр, 
   {{0xf48400c7,0x44313aa8,0x3fc40133,0x00000000}},	//   _иусн, qax_, وگای_, --, 
   {{0xd0060641,0xdee42143,0x00000000,0x00000000}},	//   неше_, ноки, --, --, 
   {{0x62880a27,0x63b005ce,0xa158004e,0x1ea800ec}},	//   _uneo, đenč, _набу_, ڪاڻي_, 
   {{0xc0581ed2,0xa0c410fe,0x00000000,0x00000000}},	//   _між_, _كيرو, --, --, 
   {{0x5f800131,0xdd9400c7,0x00000000,0x00000000}},	//   _مۇتە, даҩы, --, --, 
   {{0x61e8020b,0x7cec392f,0x212c030a,0x70941086}},	//   _hyel, børn, _hweh_, _шафф, 
   {{0x68e4020c,0x212c0066,0x61e8806e,0x6b9d5407}},	//   _akhd, _kweh_, _kyel, ärga, 
   {{0x645404cc,0x38b4000d,0xbda4007b,0x3eac0171}},	//   _oczi, _järg_, _تحاو, _ilgt_, 
   {{0x7e781125,0x38b40037,0x00000000,0x00000000}},	//   ldup, _märg_, --, --, 
   {{0x60c0009a,0x61e8a2d3,0x7e7800c0,0x00000000}},	//   _mmlm, _lyel, odup, --, 
   {{0x7e7a0642,0xcf9000c8,0x64541570,0x7ae60643}},	//   ndup, נטן_, _aczi, _ukit, 
   {{0x61ea0644,0x60c00083,0xceb002e4,0x33b400d1}},	// [3b0a0] _nyel, _omlm, אין_, ھەرر, 
   {{0x2d800006,0x79860645,0xe5780107,0x00000000}},	//   _šiek_, _iriw, ӯзӣ_, --, 
   {{0x03a052ea,0x61ea0646,0x212c00f2,0x31a80882}},	//   лифо, _ayel, _aweh_, कन्ध, 
   {{0xe8d807ae,0x61e806e4,0x60c001ab,0x758400b1}},	//   _trợ_, _byel, _amlm, _иңба, 
   {{0x7e78c6c4,0xf8a40073,0xda000d0d,0x7cec5522}},	//   ddup, _ऐकाय, ोशित_, vørn, 
   {{0x61ea0647,0x75240170,0x4528025c,0x79840076}},	//   _dyel, mpiz, _སྦིར_, _mriw, 
   {{0x212ddd42,0x75260648,0xdb0006af,0x4ea402dd}},	//   _eweh_, lpiz, pylè, ерпа, 
   {{0x38b4049f,0x79840374,0x27e401d3,0xdb0002f0}},	//   _färg_, _oriw, ülni_, bylé, 
   {{0x61e80369,0x80c8009e,0x7cec0158,0x75240fac}},	//   _gyel, িতজ্, rørn, npiz, 
   {{0xe08400c6,0xc0cc0092,0xcb44009d,0x00000000}},	//   _لجمي, ባበል_, нхми, --, 
   {{0x79860649,0x7e78003a,0xfb30009d,0x8e080395}},	//   _ariw, bdup, лнээ, _енев_, 
   {{0x79853330,0x3fc807d6,0x68e40208,0x38b4007c}},	//   _briw, _عدلی_, _skhd, _lärd_, 
   {{0x7986064a,0x9f440139,0x8c180b24,0xdb248863}},	//   _criw, _ezlä_, _فيشر_, _یووی, 
   {{0x798404d1,0xf4c42baf,0x2d80031c,0xac940063}},	//   _driw, ্তুব, _ġieh_, _јакш, 
   {{0x7986064b,0xaa5c02dd,0x9c840066,0x00000000}},	//   _eriw, _дейi, _جشنه, --, 
   {{0x63a42b57,0x7984b5fd,0x6abc017a,0x00000000}},	//   vyhn, _friw, ërfd, --, 
   {{0x7984852a,0x00000000,0x00000000,0x00000000}},	// [3b0b0] _griw, --, --, --, 
   {{0xb6040276,0x6fb03042,0x7cec06ea,0x6aa8007c}},	//   уяск, जनां, jørl, öeff, 
   {{0x61e805b1,0x7e780113,0x38b40254,0x9fb40118}},	//   _syel, ydup, _särg_, třím_, 
   {{0x61e80522,0x7ec4020c,0xdb02064c,0x38b40254}},	//   _pyel, _mèpè, tylé, _pärg_, 
   {{0x7ec404fb,0x7cec1924,0x38b40267,0x7e7800d7}},	//   _lèpè, førl, _färd_, vdup, 
   {{0x7cec0162,0x00000000,0x00000000,0x00000000}},	//   vøro, --, --, --, 
   {{0x814004d3,0xe2d82169,0xf48401b9,0x61e8012d}},	//   _ڕۆشن, _قارچ_, _суян, _wyel, 
   {{0x212c016b,0x61e800f1,0x74c40154,0x3d240248}},	//   _tweh_, _tyel, ্তঃউ, _níwò_, 
   {{0x38b401c7,0x6b9c00c5,0x61ea064d,0x71440228}},	//   _häre_, ärgn, _uyel, _مۉنۅ, 
   {{0xefd002d3,0x38b6064e,0x4c800024,0x00000000}},	//   እይዎ_, _käre_, альв, --, 
   {{0x7986064f,0x2b14855f,0x661e0650,0x5f941e2f}},	//   _sriw, льяр, _ofsk, _جلائ, 
   {{0x75240204,0x00000000,0x00000000,0x00000000}},	//   ypiz, --, --, --, 
   {{0xdd942e9a,0x38b4008e,0x00000000,0x00000000}},	//   _шады, _läre_, --, --, 
   {{0x661e0651,0x6d5c0311,0x79840363,0xe81c07f7}},	//   _afsk, ărat, _vriw, बुला_, 
   {{0x7ec40066,0x7cec00b5,0x6298003a,0x9b4401e2}},	//   _gèpè, nørm, kjwo, _ړنګو, 
   {{0x798425a9,0xdc4400de,0x02d801f9,0xc7a00798}},	//   _triw, _pūķi, यकोन, шиск, 
   {{0x79860652,0x38b404e6,0x6b9c0f0a,0x6abc036e}},	// [3b0c0] _uriw, _pärd_, ørgv, ërfe, 
   {{0x752401c6,0xe8d80051,0x00000000,0x00000000}},	//   rpiz, _trỡ_, --, --, 
   {{0x75260653,0x38b4049f,0x8c400205,0x00000000}},	//   spiz, _värd_, _öğen, --, 
   {{0x38b404e6,0x0cbc07d0,0x00000000,0x00000000}},	//   _wärd_, _ऊष्म, --, --, 
   {{0x515402dd,0x61ec033f,0x7cec0fac,0x754800f1}},	//   ттеу, żaln, tørl, _سیاف_, 
   {{0xd37000ec,0x00000000,0x00000000,0x00000000}},	//   _پهر_, --, --, --, 
   {{0x7bc5c86d,0x38b404e6,0x6ec80118,0x7cec003b}},	//   újul, _gäre_, děbr, rørl, 
   {{0xdce8009b,0x00000000,0x00000000,0x00000000}},	//   dveđ, --, --, --, 
   {{0x38b40036,0x82a001c4,0x00000000,0x00000000}},	//   _zäre_, _татж, --, --, 
   {{0x8ff82b3c,0x25f40490,0x8fa400c7,0xd7400023}},	//   _قرار_, ्धती_, _иазе, _ንግስነ, 
   {{0xaa59dac8,0x0b800023,0x00000000,0x00000000}},	//   нину_, _ሕያዋይ_, --, --, 
   {{0x8aa40262,0xef500023,0xbd3000cf,0x00000000}},	//   трод, _ጂሃዳው, _چىنع, --, 
   {{0x2f180c6a,0x00000000,0x00000000,0x00000000}},	//   _hég_, --, --, --, 
   {{0x18b001e0,0x3d2401e1,0x00000000,0x00000000}},	//   йҙыр, _wíwò_, --, --, 
   {{0x2f1800e5,0x00000000,0x00000000,0x00000000}},	//   _jég_, --, --, --, 
   {{0x2f1800f8,0x161c1b87,0xaa540305,0x6b9c6066}},	//   _még_, युलर_, _свиш, ørgu, 
   {{0x26180cb4,0x00000000,0x00000000,0x00000000}},	// [3b0d0] युगी_, --, --, --, 
   {{0x2f180332,0x70dc02c3,0xc7c400f3,0xa8740153}},	//   _oég_, मकोल, _асми, _слоі, 
   {{0x2f18002e,0xe37402dd,0xa0a40220,0x12880ee8}},	//   _nég_, _ءﺑﯩﺰ, ғайд, کمنی_, 
   {{0x38b4000d,0xe13801ec,0x04f00154,0x0cdc66c0}},	//   _väre_, езді_, জদের_, नकुम, 
   {{0x38b40639,0x26c805da,0x7abc0375,0xa0680305}},	//   _wäre_, miao_, וצאו, еала_, 
   {{0x2f181bce,0xfc440030,0x25a8007f,0x7cec2b96}},	//   _bég_, číky_, myal_, tørm, 
   {{0x25aa0654,0xc0cc044e,0x2f1801ed,0xa2c401ee}},	//   lyal_, _እኹል_, _cég_, _йәдк, 
   {{0x2f1a0655,0x26c98e26,0x20fc00a2,0x00000000}},	//   _dég_, niao_, _eňip_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x26c802b5,0x7cecb3f8,0x00000000,0x00000000}},	//   hiao_, mørk, --, --, 
   {{0x26c90b15,0x9b040107,0x00000000,0x00000000}},	//   kiao_, лзод, --, --, 
   {{0x6d5c0276,0x25a80280,0x26c907d7,0x00000000}},	//   ărar, kyal_, jiao_, --, 
   {{0x38ca0656,0x9d44d9de,0x26c80165,0xe9700131}},	//   ناسی_, _селд, diao_, قۇيد, 
   {{0xd7e8e17f,0x2f180de2,0x25a8007f,0xab6400ef}},	//   емге_, _yég_, dyal_, _baļč, 
   {{0x213c0369,0x2918198f,0x768c0139,0x1be800a7}},	//   hswh_, aqsa_, _böyе, _ядки_, 
   {{0x26c99895,0xd39400d1,0x19940798,0x15b8004e}},	//   giao_, қәгә_, _бјор, нызы_, 
   {{0x958411db,0x38b40793,0xdb0001ed,0x25a801d3}},	// [3b0e0] ылае, _värb_, szló, gyal_, 
   {{0xf4c411ba,0x257c00d2,0x98542f5c,0x00000000}},	//   ্ত্ব, wâlá_, _стиш, --, 
   {{0x3940501b,0xd24405f5,0x92688ed2,0x25a80de2}},	//   _hvis_, гэли, ерла_, ayal_, 
   {{0x26c80395,0x25a8007f,0x2f1801d3,0xc3240145}},	//   ciao_, byal_, _rég_, چكەن_, 
   {{0xc1e47724,0x10a42c08,0xf1943f36,0xc6900a1e}},	//   льше_, лидн, риль, _האר_, 
   {{0xc0e00cb9,0xe9f8004d,0x425000c7,0x7cec01bf}},	//   бочк, _hoả_, атәт, sørj, 
   {{0x7cec0158,0x394001f4,0x00000000,0x00000000}},	//   pørj, _lvis_, --, --, 
   {{0x39411065,0xe8d8063f,0xd7440092,0x00000000}},	//   _ovis_, _irụ_, _ኤክስፐ, --, 
   {{0xadd40114,0x71c401f0,0x00000000,0x00000000}},	//   ропљ, _тааҷ, --, --, 
   {{0x71440e26,0x3a220657,0x8d840184,0x2f1800e8}},	//   _مۉچۅ, _afip_, _ҡулд, _tég_, 
   {{0x39420658,0x7b1001c6,0x00000000,0x00000000}},	//   _avis_, йдэх, --, --, 
   {{0x25aa0659,0x00000000,0x00000000,0x00000000}},	//   yyal_, --, --, --, 
   {{0x1ea800e3,0x0c8400fb,0x6d342901,0x00000000}},	//   _جالي_, _быйм, _телф, --, 
   {{0x6b9c105c,0xe8d8063f,0x394000b8,0xfd540375}},	//   ørgs, _orụ_, _dvis_, _עשוי_, 
   {{0x213c0007,0xabb40022,0x39400200,0x00000000}},	//   zswh_, _әақә, _evis_, --, 
   {{0x25a90516,0x8f3c001f,0x443c00b8,0x00000000}},	//   tyal_, _አይነቶ, _śu_, --, 
   {{0xe8d805db,0x2a68003e,0x26c802b1,0x7cec0fac}},	// [3b0f0] _arụ_, _ibab_, riao_, førh, 
   {{0x26c800d8,0x47d400cc,0x00000000,0x00000000}},	//   siao_, _ধৰণী, --, --, 
   {{0x26c800d8,0xe28400c7,0x352800d1,0x00000000}},	//   piao_, _ẽñem, نسەپ_, --, 
   {{0xc2ea065a,0x7cec1477,0xa5c4008e,0x26c8031c}},	//   رعام_, tørk, _көзе, qiao_, 
   {{0xd6540375,0x38b4007c,0x8c4406be,0x00000000}},	//   _דירת_, _hära_, _kaşğ, --, 
   {{0xa0698bcc,0x38b55403,0x67240023,0x00000000}},	//   така_, _kära_, _kthj, --, 
   {{0xf0b800f2,0x00000000,0x00000000,0x00000000}},	//   دانش_, --, --, --, 
   {{0x2eb4026f,0xcc8403e6,0x7cec143a,0x38b4000d}},	//   йсыс, یۆنه_, møri, _mära_, 
   {{0x38b4049f,0x7cec0fac,0x2fc00115,0x3e480064}},	//   _lära_, løri, ĝiga_, _rėtį_, 
   {{0x2a680428,0xa2a056e9,0x39400585,0x2d80003d}},	//   _abab_, कॉर्, _rvis_, _ġiet_, 
   {{0xdfd2065b,0x38b404f3,0x9aa40aa0,0x2480007b}},	//   _بيا_, _nära_, لمدو, idhm_, 
   {{0x2a680175,0xefc80137,0x1ae401d5,0x4a400212}},	//   _cbab_, _суук_, ромм, онюв, 
   {{0x7cec4453,0x6abc0200,0x6b9c03b2,0x00000000}},	//   høri, ërfa, ørgr, --, 
   {{0x38b401e6,0x6f00002b,0x2bc802dd,0x5fa80bae}},	//   _bära_, _iṣṭa_, _өліп_, _कथाल, 
   {{0xac74faed,0x7cece73f,0x7d180113,0x3e480064}},	//   _دانش, jøri, lqus, _tėtį_, 
   {{0x7a0c00da,0x7cec077b,0x3940005c,0x35c4013e}},	//   _pētī, døri, _tvis_, бабҳ, 
   {{0x39411a96,0x7d1802d1,0x7cec01bf,0x98f40153}},	// [3b100] _uvis_, nqus, tørh, _вянч, 
   {{0x99800153,0xb36c010e,0x7a0c00ef,0xf3e400cc}},	//   sakų_, _öñkü, _vētī, _কৃষৰ_, 
   {{0xe9f8004d,0x7d180477,0x7cec01bf,0x00000000}},	//   _toả_, hqus, gøri, --, 
   {{0xd186065c,0xe9f801fb,0xc7f40677,0x00000000}},	//   илей, _hoạ_, _כזית_, --, 
   {{0x411400ec,0xe7d40214,0x7a400064,0x00000000}},	//   لينج_, _نمیگ, _ištį, --, 
   {{0x4f688ed7,0xe8d80016,0x8c440139,0x8f440117}},	//   вшим_, _trụ_, _kaşş, ахид, 
   {{0xd2500050,0x434000c7,0x53a4039b,0x6f0000cd}},	//   _ونس_, _мерв, _тавб, _aṣṭa_, 
   {{0x8c440205,0x23081913,0x00000000,0x00000000}},	//   _maşş, _متقي_, --, --, 
   {{0x11e83b6c,0x7d180472,0xac180063,0x00000000}},	//   _شعري_, gqus, лопу_, --, 
   {{0x8e3000c7,0x2a6a065d,0x60cc01e7,0x00000000}},	//   _аyп_, _sbab_, éamt, --, 
   {{0xd0083b78,0x7d180869,0x81c800eb,0xe4f821f6}},	//   _реже_, aqus, _রুপ_, ्गति_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x79a4035b,0x0ca002d3,0x094800a7,0x38b42bd5}},	//   орре, _ዝገልጽ_, ъчни_, _sära_, 
   {{0x6d404a21,0x38b40254,0x8c440166,0x00000000}},	//   msma, _pära_, _qaşğ, --, 
   {{0x6d42065e,0xeb38036b,0xe9f8004d,0x0ba80137}},	//   lsma, _ёзиш_, _doạ_, _جاشى_, 
   {{0x85b81169,0xa614365f,0xfbb4011a,0x9f4c06af}},	//   پارس_, смач, _כפות_, énée_, 
   {{0xe94426a6,0x00000000,0x00000000,0x00000000}},	// [3b110] _اربی, --, --, --, 
   {{0x6d42065f,0x7cec0194,0x00000000,0x00000000}},	//   isma, tøri, --, --, 
   {{0x96880882,0x8234007b,0x6d400857,0x98a00064}},	//   ṇāḥ_, لرشا, hsma, eskė_, 
   {{0xe6942961,0x6d420660,0xf7720661,0x7ced22c5}},	//   _الحد, ksma, _کای_, røri, 
   {{0x6d420662,0x7cec03b2,0x00000000,0x00000000}},	//   jsma, søri, --, --, 
   {{0x10a000c2,0x657c037e,0x5f4401b9,0xcacc03d4}},	//   зишн, _issh, منتل, ৰতিফ, 
   {{0x6d420663,0xb4540014,0xd34400aa,0x43081ca9}},	//   esma, _بخُش, _هیله_, _ахам_, 
   {{0x41742614,0x4420032e,0xf2c4004e,0xdb00002f}},	//   _پارس, _hfj_, _дсун, lzlö, 
   {{0x61d80395,0x00000000,0x00000000,0x00000000}},	//   _смая_, --, --, --, 
   {{0x7d1a0664,0x00000000,0x00000000,0x00000000}},	//   rqus, --, --, --, 
   {{0x6d420665,0xef1800e2,0x7d18058a,0x00000000}},	//   asma, _guļ_, squs, --, 
   {{0x6d40fea3,0x34d400e1,0xcff40375,0xef240244}},	//   bsma, _दद्द, _הצעה_, _بژوێ, 
   {{0x7d180af5,0x6d40219a,0x2258032e,0xdb0000e5}},	//   qqus, csma, _ösku_, gylá, 
   {{0x8c44010e,0xcd2400ec,0x00000000,0x00000000}},	//   _paşş, _اڳين_, --, --, 
   {{0x291c0066,0xd7f000c6,0x9b4427dc,0x1ca403e6}},	//   _éwan_, سكر_, _انبو, _نێکی_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe9f8004d,0x154400fd,0x46a002e8,0x54684572}},	// [3b120] _toạ_, сезм, чатв, лаам_, 
   {{0x9990038e,0x44200223,0xd7c800aa,0x8c440205}},	//   _když_, _cfj_, _موخه_, _taşş, 
   {{0x6d420666,0x657c02d0,0xe79402d2,0x44f400fe}},	//   zsma, _essh, _díóð, _অংশক_, 
   {{0x6b9c007d,0x00000000,0x00000000,0x00000000}},	//   ärgi, --, --, --, 
   {{0x442163b2,0x6d400175,0x4a580677,0x00000000}},	//   _ffj_, xsma, רדנו, --, 
   {{0x6d420667,0xc0e05aa2,0x6ab40d2c,0x506401b9}},	//   vsma, почк, _ंत्र, ётла, 
   {{0x6d420668,0x20c80597,0xbee00490,0x2fc0010f}},	//   wsma, جبني_, खवून_, ĝigo_, 
   {{0x6d420669,0x03d4011a,0xff4c33d2,0x00000000}},	//   tsma, _הולם_, رخى_, --, 
   {{0x10a6066a,0x6d42066b,0x0c846566,0x1aa800fe}},	//   _лиан, usma, бынм, খোৱা, 
   {{0x6d42066c,0x01a40228,0x00000000,0x00000000}},	//   rsma, _укук_, --, --, 
   {{0x38b40037,0x00000000,0x00000000,0x00000000}},	//   _pärn_, --, --, --, 
   {{0x15f83806,0x3b0001b9,0x7cec03b2,0xaa580131}},	//   ्धार_, _chiq_, døru, шиму_, 
   {{0xe9183334,0xdb000ac8,0x7cec06ea,0x38b4007c}},	//   рогі_, kylæ, vørv, _värn_, 
   {{0x7cec06ea,0xdb0002fb,0x48c400fe,0x00000000}},	//   føru, rylá, লক্ৰ, --, 
   {{0x38b4000d,0x44200200,0x7cec0162,0xddc801ef}},	//   _tärn_, _rfj_, tørv, dgeř, 
   {{0x3b000978,0x25d8941b,0x442005ac,0xe81c3c71}},	//   _ghiq_, амбы_, _sfj_, बुजा_, 
   {{0xf778038f,0xf8b84ecc,0xf4082160,0x38b401e3}},	// [3b130] ħħa_, рөө_, ەيلى_, _kärl_, 
   {{0x6d5c0227,0x7cec05ac,0x35b40107,0x00000000}},	//   ńraw, sørv, чбур, --, 
   {{0x442003b2,0xd5ac0d62,0x7cec005c,0x27ec0112}},	//   _vfj_, _یہِ_, mørt, ßend_, 
   {{0x65940046,0xdef40020,0xded80092,0x7cec12ed}},	//   _даму, ሎችን_, ኮችን_, lørt, 
   {{0x657c003e,0x4420003a,0x61440024,0x7a7c0677}},	//   _ussh, _tfj_, цела, טראס, 
   {{0xb9f0067d,0x1fa97722,0x442001c4,0x9ac40083}},	//   _ነዚ_, икли_, _ufj_, maŋŋ, 
   {{0x3f800327,0xd00c4f4e,0x00000000,0x00000000}},	//   _ġjus_, پلي_, --, --, 
   {{0x3f8400bc,0x7cec072b,0x66f8353b,0x00000000}},	//   rvnu_, hørt, ंतिक_, --, 
   {{0x9ac40083,0x7cec005c,0xf1d400cf,0xee5c0162}},	//   naŋŋ, kørt, _нөшө, áðað_, 
   {{0x7cecfb06,0x3b00036b,0x1ca402f2,0xc1d000fb}},	//   jørt, _shiq_, تێتی_, _мөҙә, 
   {{0x3ee5be80,0x2258007c,0xefc8117e,0x00000000}},	//   _людв, _ösks_, _луцк_, --, 
   {{0x290005b1,0xacb00150,0x7cec06ea,0x00000000}},	//   _ahha_, _ۋەيب, vøru, --, 
   {{0x7cec3c12,0x394401c7,0xdb0000a2,0x00000000}},	//   ført, éms_, hylç, --, 
   {{0x7cec0162,0x00000000,0x00000000,0x00000000}},	//   tøru, --, --, --, 
   {{0x81bc02f5,0x5ac401d9,0x569401e0,0x00000000}},	//   ঁপি_, _وقتٕ, ҙаҡт, --, 
   {{0x6abe066d,0x2900009d,0x56297fd5,0xdb20010e}},	//   chsf, _ehha_, ржам_, _çuñl, 
   {{0x38b40254,0x7cec03b2,0x6b9c007c,0x00000000}},	// [3b140] _härm_, søru, ärgv, --, 
   {{0x7cec5c04,0x1ce00327,0x9f44005b,0x81bc00eb}},	//   mørs, _ྩམས_, _kylä_, ঁপা_, 
   {{0x3878bd71,0x52840276,0x00000000,0x00000000}},	//   merr_, жгеб, --, --, 
   {{0x387a066e,0x8f080055,0x25e4012d,0x230800ae}},	//   lerr_, _kṛśe, _झुकी_, متني_, 
   {{0x7cec08fb,0x38b512c5,0x90e400f1,0x27ec0205}},	//   nørs, _lärm_, يستن, ğene_, 
   {{0x9408013f,0x27ec00fd,0x60cc06af,0x3878020c}},	//   _bobɔ_, şene_, éamp, nerr_, 
   {{0x7cec0450,0x23b00137,0x00000000,0x00000000}},	//   hørs, _كۅكس, --, --, 
   {{0x7cec037e,0x6e9a066f,0x387823ac,0x91e45348}},	//   kørs, свир_, herr_, _добе, 
   {{0x4124b062,0x3879a71e,0xe2b405f5,0x7cec143a}},	//   _мото_, kerr_, _эсрэ, jørs, 
   {{0x387802d3,0x0b8801b9,0x7cec072b,0xdb0001f4}},	//   jerr_, асми_, dørs, hylä, 
   {{0x38780023,0xdb00c6cb,0x6fa800fe,0x92cc00fe}},	//   derr_, kylä, _কেৰে, ৱতী_, 
   {{0xaca40241,0x9ac404ba,0xbf10030c,0x6a14024c}},	//   _ilọy, yaŋŋ, _قولب, ямму, 
   {{0x99900034,0x101c05f9,0xf1bc0b33,0x7cec0b1a}},	//   _gdyż_, _पलाश_, ्छिन, tørt, 
   {{0x38b40036,0x8f080055,0x00000000,0x00000000}},	//   _färm_, _dṛśe, --, --, 
   {{0x7cec1477,0x9ac404ba,0x00000000,0x00000000}},	//   rørt, waŋŋ, --, --, 
   {{0x7cec0627,0x370402bf,0x9ac40083,0x38b401f4}},	//   børs, дчув, taŋŋ, _järj_, 
   {{0xddd80113,0x6514027a,0xc958036b,0x387805c7}},	// [3b150] _kawš, سوائ, _тўй_, berr_, 
   {{0x08400014,0xdef4001f,0x44280024,0x3878036e}},	//   _زۆرُ, ሎችና_, рцам_, cerr_, 
   {{0xe6940022,0x9ac40083,0x00000000,0x00000000}},	//   _еины, saŋŋ, --, --, 
   {{0x22580150,0x00000000,0x00000000,0x00000000}},	//   сиды_, --, --, --, 
   {{0x71241f7e,0x00000000,0x00000000,0x00000000}},	//   ورول, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x61180100,0x4430010a,0xf83805d0,0x623401ca}},	//   _sňld, mbx_, חנות_, _неву, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9f200131,0xdc98ccc1,0x38b42bf2,0x61ec000d}},	//   _كۈتۈ, стиш_, _pärm_, üalu, 
   {{0xf0e82a8b,0xafc40150,0x00000000,0x00000000}},	//   _بىلى_, _قيكى, --, --, 
   {{0x38b401e3,0x6440000d,0xc0e00023,0x539800d9}},	//   _värm_, _õlif, ምዎም_, צירו, 
   {{0x3ebc01f5,0x00000000,0x00000000,0x00000000}},	//   mhut_, --, --, --, 
   {{0x7ceca934,0x3ebe0670,0x00000000,0x00000000}},	//   rørs, lhut_, --, --, 
   {{0xb8d430fd,0x7cec5522,0x44300175,0xd6281985}},	//   _झक_, sørs, dbx_, йове_, 
   {{0x3ebc067c,0x7cec168c,0x38780165,0x46a000d1}},	//   nhut_, pørs, serr_, насв, 
   {{0xcb100302,0x54340131,0x38b40037,0xdb0001f4}},	// [3b160] _אלה_, كرار, _järk_, rylä, 
   {{0xf8e02aa1,0x38b42771,0x00000000,0x00000000}},	//   _नदिय, _märk_, --, --, 
   {{0xb9f8069c,0x3ebe0671,0xdb00005b,0xd7886af3}},	//   _ዘላ_, khut_, pylä, _انجو_, 
   {{0x95860672,0x51845e0c,0x981400f2,0x3ebc036e}},	//   _елме, зука, _وبگا, jhut_, 
   {{0xc0d8044e,0x3ebc0214,0x7d000857,0x4430031c}},	//   _ሕማም_, dhut_, _ohns, bbx_, 
   {{0x92bc00bd,0x00000000,0x00000000,0x00000000}},	//   ীকে_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3ebc02b4,0x7d00009a,0x00000000,0x00000000}},	//   ghut_, _ahns, --, --, 
   {{0x7cec005c,0x00000000,0x00000000,0x00000000}},	//   vørr, --, --, --, 
   {{0xc1b80302,0xb4ec0073,0x00000000,0x00000000}},	//   _הממש, जकिय_, --, --, 
   {{0x7cec2759,0x2a7800d8,0x2f140022,0xff0800fe}},	//   tørr, tesb_, _ẽgua_, রৱেশ_, 
   {{0xbf98010f,0x3ebe0673,0x00000000,0x00000000}},	//   _ליבש, chut_, --, --, 
   {{0x6440000d,0xedd400f1,0xa02000a2,0x00000000}},	//   _õlig, _کيږد, _įözg, --, 
   {{0x6b9c712c,0x00000000,0x00000000,0x00000000}},	//   ärgs, --, --, --, 
   {{0x67d402a9,0x7cec003b,0x00000000,0x00000000}},	//   фову, pørr, --, --, 
   {{0xe818012c,0x6594004e,0x00000000,0x00000000}},	//   _दलका_, мабу, --, --, 
   {{0x27ec0034,0x00000000,0x00000000,0x00000000}},	// [3b170] łen_, --, --, --, 
   {{0x44240c86,0xd97401c8,0x00000000,0x00000000}},	//   ùn_, _آئيڊ, --, --, 
   {{0x237805c6,0x44300175,0x00000000,0x00000000}},	//   تماد_, rbx_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x71240131,0x4430010a,0x3688009d,0x00000000}},	//   ۈرۈل, pbx_, _эсэн_, --, 
   {{0xf48406bb,0xd12c05d9,0x63540209,0xa0c409a6}},	//   _пусн, جمو_, _овгу, بيتو, 
   {{0x38b400c5,0xd00439c6,0x3ebc0066,0x81c80154}},	//   _särk_, меше_, thut_, _রুশ_, 
   {{0xd24c08dc,0xceb4013d,0x00000000,0x00000000}},	//   _نچه_, мәч_, --, --, 
   {{0x224c00fd,0x291c034c,0x3ebe0674,0x2cbc6fe8}},	//   _idek_, _éwah_, rhut_, _blvd_, 
   {{0x3ebe0675,0x38b42bea,0x64400037,0x9b442bef}},	//   shut_, _värk_, _õlid, ونخو, 
   {{0x3ebc0113,0x38b40254,0x00000000,0x00000000}},	//   phut_, _wärk_, --, --, 
   {{0xd94400ee,0x5dd400db,0x00000000,0x00000000}},	//   меми, _оюлу, --, --, 
   {{0x7e7801f7,0x00000000,0x00000000,0x00000000}},	//   meup, --, --, --, 
   {{0xe64400c6,0xa3be0676,0x38b60677,0xece801ec}},	//   _ĵŏỷ_, इना_, _käri_, _еділ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf4860678,0x212c0198,0x224c0214,0x00000000}},	//   کاری, _oteh_, _ndek_, --, 
   {{0x2fc000df,0x00000000,0x00000000,0x00000000}},	// [3b180] ĝigi_, --, --, --, 
   {{0x79851cff,0x224c85dc,0x2fc00115,0x00000000}},	//   _isiw, _adek_, ŝigi_, --, 
   {{0x7e78b284,0xe8d806d9,0x212ce0fa,0x38b40254}},	//   keup, _erỳ_, _ateh_, _näri_, 
   {{0x212c0175,0x00000000,0x00000000,0x00000000}},	//   _bteh_, --, --, --, 
   {{0x76460679,0x7e780c6a,0x6abc036e,0x98a00064}},	//   maiy, deup, ërfi, nskį_, 
   {{0x38b40209,0x798400ec,0x76449e0e,0x224e067a}},	//   _bäri_, _msiw, laiy, _edek_, 
   {{0x212c0c6a,0x75240240,0x7cec0162,0x00000000}},	//   _eteh_, lqiz, vørp, --, 
   {{0xb9000003,0x7646067b,0x7984009a,0x7e78020c}},	//   _ཧམ_, naiy, _osiw, geup, 
   {{0xd18401e0,0xde4401d9,0x7cec5522,0x02600133}},	//   _юлай, ریوو_, tørp, _شێوێ, 
   {{0x7646067c,0xc1b000c7,0x904400f2,0x98a0013d}},	//   haiy, _шәхы, _آناه, kukı_, 
   {{0x7986067d,0x403000d6,0x764419a2,0x47d0009e}},	//   _asiw, _реєс, kaiy, _দুনী, 
   {{0x7e780c6a,0x76443a97,0x24b40150,0x98a00210}},	//   ceup, jaiy, _ﺼﻠﺤﻬ, mpkę_, 
   {{0x7646067e,0xa2b00b8f,0x0c84004e,0x00000000}},	//   daiy, _अकस्, _жыйм, --, 
   {{0xfbcd30d6,0x79840129,0xddc8010e,0x00000000}},	//   اتی_, _dsiw, lgeş, --, 
   {{0x7986067f,0x764405d1,0x0ae8007b,0x5eb00154}},	//   _esiw, faiy, _وربي_, _জগতে, 
   {{0x76440198,0xddc80311,0xc3100248,0xa3bc00ce}},	//   gaiy, ngeş, _oríṣ, इनस_, 
   {{0x7524676c,0x224c0139,0x61180432,0x00000000}},	// [3b190] gqiz, _rdek_, _oňla, --, 
   {{0x6aac0109,0x80b0142d,0x59940375,0x00000000}},	//   _hoaf, _अवधे, _נכתב_, --, 
   {{0x6aac27be,0x212e0680,0x67d45e0c,0xdb0000d7}},	//   _koaf, _steh_, _чону, vylú, 
   {{0x61180209,0x224c01a9,0x6304036b,0x622400d1}},	//   _aňla, _qdek_, روشل, رىتل, 
   {{0x6aac1a83,0x224c0240,0x38b4000d,0x7e7802d0}},	//   _moaf, _vdek_, _säri_, veup, 
   {{0x6aadbd30,0x38b421c6,0x00000000,0x00000000}},	//   _loaf, _päri_, --, --, 
   {{0x64460681,0x7e7800d5,0xd4c02f89,0x00000000}},	//   mahi, teup, _сөтк, --, 
   {{0x6aac0109,0x38b402f6,0x224c022e,0x00000000}},	//   _noaf, _väri_, _udek_, --, 
   {{0x7e783386,0xb55c001f,0x61544028,0x6444009f}},	//   reup, _ውክፐድ, _سنائ, oahi, 
   {{0x64460682,0x628959a5,0x3134084c,0x7e7800d5}},	//   nahi, _haeo, _рефр, seup, 
   {{0x6aae0683,0x76460684,0x7e78b73c,0x62880086}},	//   _boaf, yaiy, peup, _kaeo, 
   {{0x64460685,0x1a64cef2,0x6aac084c,0x38b400c5}},	//   hahi, ریخی_, _coaf, _järv_, 
   {{0x64460686,0x62887089,0x6aac0175,0xc8480023}},	//   kahi, _maeo, _doaf, _ንምምሕ, 
   {{0x76460687,0x1cb80327,0x9cb4007b,0x00000000}},	//   waiy, _ངཞི_, _سمعت, --, 
   {{0x76440d04,0x6aac1140,0xd7f000c6,0xf8e00825}},	//   taiy, _foaf, اكز_, _नदीप, 
   {{0x79840198,0x6aac030a,0x38b4000d,0x96b8004e}},	//   _tsiw, _goaf, _närv_, чугу_, 
   {{0xe8e800b2,0x76460688,0x7ae40428,0x79860689}},	// [3b1a0] _ڪريو_, raiy, _ijit, _usiw, 
   {{0x64455b0b,0x62884e12,0x7ae40b21,0x661c05e4}},	//   gahi, _aaeo, _hjit, _egsk, 
   {{0x7ae6068a,0x62880086,0x7646068b,0xd628e753}},	//   _kjit, _baeo, paiy, _ноне_, 
   {{0xd252068c,0x62880042,0x64440009,0x81c800eb}},	//   انش_, _caeo, aahi, _রুই_, 
   {{0x64440537,0x7ae43231,0xa2b000dc,0x62880142}},	//   bahi, _mjit, _अकर्, _daeo, 
   {{0x644404fb,0x62880428,0x70580798,0x00000000}},	//   cahi, _eaeo, факр_, --, 
   {{0x7ae6068d,0x80a00aaf,0xddc800ee,0xc04c0023}},	//   _ojit, امىن, tgeş, መሓላል, 
   {{0x7ae6056b,0x62886729,0x30d000fe,0xa3bc2e05}},	//   _njit, _gaeo, াকেস, इनर_, 
   {{0xfd4001c6,0x91e41fbe,0x00000000,0x00000000}},	//   лээн, _џозе, --, --, 
   {{0x7ae6068e,0x6aac0109,0x38b400c5,0x8fa4584f}},	//   _ajit, _soaf, _käru_, _пазе, 
   {{0x1cb85078,0xaa5a068f,0x00000000,0x00000000}},	//   ངྒེ_, мину_, --, --, 
   {{0x7ae401ab,0x9f78039b,0x7ea400e4,0x5f400131}},	//   _cjit, _юсуф_, _oñpy, _ئۆيل, 
   {{0x6aac0851,0x7ae60690,0x2fc001e4,0xe3e000cc}},	//   _voaf, _djit, ĝigu_, _ভৰাব, 
   {{0x26f85345,0x212806d6,0x6aac016b,0x6b75a85b}},	//   ंत्र_, ̭aho_, _woaf, _алку, 
   {{0x6aac1f4a,0x9ee401d3,0x26c400e8,0xa2b011bc}},	//   _toaf, _سہیل_, ëloo_, _अकल्, 
   {{0x7ae407db,0x64460691,0x18180014,0x368a0692}},	//   _gjit, wahi, برُک_, нсун_, 
   {{0xa61401d5,0x6abc0200,0x00000000,0x00000000}},	// [3b1b0] тмач, ërfu, --, --, 
   {{0xa3bc2db8,0x62880165,0x245400db,0x00000000}},	//   इनल_, _saeo, ئناس, --, 
   {{0x62883113,0x3204010e,0xe0d00244,0x00000000}},	//   _paeo, _azmy_, یزت_, --, 
   {{0x48f80316,0xd0b006be,0x80b009b2,0x00000000}},	//   ोगको_, _işəd, _अवहे, --, 
   {{0x6444da76,0x62880618,0xf19402bf,0x38b400c5}},	//   pahi, _vaeo, лиць, _värv_, 
   {{0x656e0693,0x7b1800a2,0x00000000,0x00000000}},	//   mtah, _aţul, --, --, 
   {{0x656e0694,0x628a0695,0xa3d40063,0x00000000}},	//   ltah, _taeo, _ровч, --, 
   {{0x656c00b0,0xf79c0375,0xceac00ec,0x82340633}},	//   otah, לבומ, يڙن_, _سررا, 
   {{0xdca40131,0x38b60696,0x7ae400b8,0xf7780003}},	//   вапи, _kärt_, _rjit, ħħi_, 
   {{0x61ea0697,0x9c2402f4,0x7ae60698,0x656c150c}},	//   _ixel, ъдод, _sjit, itah, 
   {{0x656c0842,0xfe7405f5,0x60c1ccac,0x38b40037}},	//   htah, _зүй_, _illm, _märt_, 
   {{0x656e0699,0x38b401e6,0x6b9c01bf,0x9e3401f4}},	//   ktah, _lärt_, årga, _редч, 
   {{0x656c0978,0x3eac4bc1,0x98d402bf,0xdedc0092}},	//   jtah, _iogt_, вівщ, _ናሙና_, 
   {{0x7ae4002d,0x656c016d,0xdca416a4,0x2d800135}},	//   _wjit, dtah, _јаки, _ġiex_, 
   {{0x656c05e4,0x7ae4000f,0x3eac00b5,0xd1500023}},	//   etah, _tjit, _kogt_, _ኣይትግ, 
   {{0xcf9004ac,0x7ae6069a,0x61ea069b,0x15b800ee}},	//   סטן_, _ujit, _oxel, мызы_, 
   {{0x656e069c,0x61e8014b,0xceb00bd4,0xee5c0436}},	// [3b1c0] gtah, _nxel, בין_, áðið_, 
   {{0x39400113,0x3eac01f5,0x200401a9,0x00000000}},	//   _iwis_, _logt_, _ozli_, --, 
   {{0x61ea069d,0x3eac0d27,0x38b4013d,0x656cb80c}},	//   _axel, _oogt_, _därt_, atah, 
   {{0x60c00628,0x3942069e,0x656c016d,0x35c4014b}},	//   _allm, _kwis_, btah, _бамҳ, 
   {{0x80b00ce0,0x200405b1,0x38b401c7,0x86340375}},	//   _अवशे, _azli_, _färt_, _ברכב_, 
   {{0x30d0045e,0x69080008,0x1fac009e,0x00000000}},	//   াক্স, rþeg, _কেইস, --, 
   {{0x61ea069f,0x3eac002d,0xb8240c58,0xdb00002e}},	//   _exel, _bogt_, _বজাত_, axlé, 
   {{0x3a20014f,0x60c002d0,0x25b001e1,0x00000000}},	//   _ngip_, _ellm, _ánlè_, --, 
   {{0x51640b59,0x2f08000f,0x2004008e,0xeb3c0092}},	//   _шваб, jûge_, _ezli_, _የተጫወ, 
   {{0x3a2206a0,0x00000000,0x00000000,0x00000000}},	//   _agip_, --, --, --, 
   {{0x39408851,0x60cc002d,0xead80212,0x8fa4007b}},	//   _awis_, ëame, емні_, _جماه, 
   {{0x656e06a1,0x9e640214,0x68e40175,0x28d407af}},	//   ytah, _ماهن, _sjhd, डोनि, 
   {{0x1dd8012c,0x394003cb,0x00000000,0x00000000}},	//   _बेपत, _cwis_, --, --, 
   {{0x3a2051bc,0x1cb80327,0x656c016d,0xa78c0150}},	//   _egip_, ངྒཱ_, vtah, _ﻐﻴﺭﺓ_, 
   {{0x6abc0240,0xaa940137,0x656c014f,0x7b0800e5}},	//   ërfs, _бийч, wtah, üsté, 
   {{0x656e06a2,0x39400309,0x38b401e3,0xaa88007b}},	//   ttah, _fwis_, _bärs_, _أنظم_, 
   {{0xe8d802e3,0xdb000209,0x2a6a06a3,0x656e06a4}},	// [3b1d0] _asụ_, nylý, _icab_, utah, 
   {{0x656e06a5,0x6abe06a6,0x38b40036,0x00000000}},	//   rtah, lksf, _därs_, --, 
   {{0x656e06a7,0x68f606a8,0x38b4049f,0x611402dd}},	//   stah, mozd, _värt_, ңдеу, 
   {{0xdef40201,0x38b606a9,0x656c0978,0xa5c40724}},	//   ዎችን_, _wärt_, ptah, _йөзе, 
   {{0xc8a402ab,0x71240131,0xa5c400ee,0x656c0978}},	//   खापट, لىنم, _сөве, qtah, 
   {{0xdce8003d,0xdb000209,0x38b401c7,0x61e8003a}},	//   rteċ, dylý, _härr_, _vxel, 
   {{0x38b4007c,0xf484927f,0x51a400cf,0xe5b801e1}},	//   _kärr_, _туян, _ەگىپ_, _ńtẹ̀, 
   {{0x2a680218,0x61ea06aa,0x6abc01a4,0x24800254}},	//   _ncab_, _txel, jksf, lehm_, 
   {{0x61e800f1,0x68f41ab0,0xdb0000a2,0x00000000}},	//   _uxel, kozd, gylý, --, 
   {{0x60c00597,0x2a69118d,0x71240075,0x24803262}},	//   _ullm, _acab_, _ئىلم, nehm_, 
   {{0x68f401fa,0x3940033b,0x3eac01bf,0x672401f4}},	//   dozd, _swis_, _togt_, _nuhj, 
   {{0x39401529,0x2e380276,0x66e40024,0xdb0002f0}},	//   _pwis_, _апць_, dėko, bylý, 
   {{0x99d40f1b,0x68f401a9,0xfe9000e5,0x00000000}},	//   اتجا, fozd, _میںج, --, 
   {{0xdce80cf4,0x68f40427,0x7c841d39,0x00000000}},	//   oteč, gozd, _јуде, --, 
   {{0x2cba06ab,0x6b84009f,0x81740150,0x00000000}},	//   örde_, _نشيل, _ﺼﻔﻴﺔ_, --, 
   {{0x29240597,0x394206ac,0x6abc007c,0x78bc39ae}},	//   úpaí_, _twis_, cksf, skrv, 
   {{0xceb01203,0x68f4151c,0x39400214,0x1dd813f5}},	// [3b1e0] זין_, bozd, _uwis_, _बेमत, 
   {{0x54440150,0x48e0030d,0x00000000,0x00000000}},	//   اناك, _гоьв, --, --, 
   {{0x38b40bac,0x80a40210,0x00000000,0x00000000}},	//   _wärs_, चाने, --, --, 
   {{0x588400c7,0x64400254,0x745400e5,0x00000000}},	//   _рыҩа, _õlin, _چھائ, --, 
   {{0x5f380092,0xf7780003,0x00000000,0x00000000}},	//   _ጥቅማቸ, ħħu_, --, --, 
   {{0xf4780150,0x00000000,0x00000000,0x00000000}},	//   _шөбі_, --, --, --, 
   {{0x6abcbcec,0x00000000,0x00000000,0x00000000}},	//   yksf, --, --, --, 
   {{0x3ec04445,0xb8d0031c,0x00000000,0x00000000}},	//   йсыб, _ྒོ_, --, --, 
   {{0xcd340214,0x66e40024,0x68f401a9,0x00000000}},	//   درعب, dėkl, yozd, --, 
   {{0x6b7444c1,0xdb000209,0x2a688048,0xac18a30d}},	//   алоу, rylý, _scab_, копу_, 
   {{0x4f5806a0,0x68f425e6,0x20240419,0xdce80171}},	//   _سجاد_, vozd, ápiť_, cteč, 
   {{0x0dca06ad,0x8aa5284c,0x68f4033f,0x672401f4}},	//   _плей_, урод, wozd, _ruhj, 
   {{0x69c401e0,0xddc80356,0x68f4022e,0x00000000}},	//   рөйб, rfeţ, tozd, --, 
   {{0x67240f23,0x6f0003ac,0xe89400c7,0x00000000}},	//   _puhj, llmc, шагь, --, 
   {{0x68f41e7a,0x41d801ad,0x0af0009d,0xdb0000e5}},	//   rozd, _मेनस, _гүнэ, gyló, 
   {{0xf1c42bf1,0x67d401f0,0x00000000,0x00000000}},	//   वनान, гоҳу, --, --, 
   {{0xcb140022,0x68f40419,0xdce802f0,0x00000000}},	// [3b1f0] _ифҩы, pozd, zteč, --, 
   {{0xdef40020,0x81bc045e,0xdce8012c,0xf99002dd}},	//   ዎችና_, ুপম_, yteč, _ءبي_, 
   {{0xc7a8007b,0xbd640023,0x00000000,0x00000000}},	//   _أدخل_, ቲኣቶም_, --, --, 
   {{0x225817b4,0x00000000,0x00000000,0x00000000}},	//   тиды_, --, --, --, 
   {{0xe0446287,0xd04803be,0x21a606ae,0x61140a93}},	//   анли, lifə, рилм, адду, 
   {{0x657e06af,0xf770eb7d,0x26c80798,0x238401d9}},	//   _ipsh, _بای_, lhao_, _پٔرِ, 
   {{0x645606b0,0x25a806be,0xd04806be,0x00000000}},	//   _idzi, lxal_, nifə, --, 
   {{0x26c80798,0xdce802f0,0x00000000,0x00000000}},	//   nhao_, rteč, --, --, 
   {{0xd0480cc1,0x442002c4,0xb8d80003,0xdce802fd}},	//   hifə, _kgj_, _ཚྭ_, steč, 
   {{0x657c000a,0x1c44016c,0x06c004c5,0x1d080640}},	//   _mpsh, шном, ্কটি, ђени_, 
   {{0x64540bd7,0x0c70036b,0xaec4004e,0x00000000}},	//   _mdzi, تگند, рбөл, --, 
   {{0x4dd4065f,0x657e06b1,0x00000000,0x00000000}},	//   اویح_, _opsh, --, --, 
   {{0x9d440b65,0x645606b2,0x3f840a73,0x44200158}},	//   _телд, _odzi, lwnu_, _ogj_, 
   {{0x645406e4,0x3ebe06b3,0x7b300356,0xc840010b}},	//   _ndzi, lkut_, _răuf, жерй, 
   {{0x7c20009a,0x657c02d0,0x25a800e8,0xcc840133}},	//   _ignr, _apsh, exal_, _ئۆپه_, 
   {{0x3ebc06a3,0x645606b4,0xc6c148db,0xd5e400a7}},	//   nkut_, _adzi, ойск, ажби, 
   {{0xd4340f1b,0x7ae8004b,0xd9840873,0xfaa42cdd}},	// [3b200] لعاب, _ټوکې_, ﻪﻧﺪﻩ_, _вақо, 
   {{0x26c80069,0x3ebe06b5,0xafdc00a2,0x5434104e}},	//   ahao_, hkut_, _beĸl, рхау, 
   {{0x3ebce396,0x657c0023,0x38881a14,0x3100033f}},	//   kkut_, _epsh, ātrī_, _लीगः_, 
   {{0x645606b6,0x3ebd9f2c,0x479800df,0x00000000}},	//   _edzi, jkut_, _סיכס, --, 
   {{0xf19464cf,0x00000000,0x00000000,0x00000000}},	//   силь, --, --, --, 
   {{0x6454006d,0x2f080086,0x89940375,0xe8e0004d}},	//   _gdzi, dûga_, יכנס_, _địt_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3ebc3e36,0x6454033f,0xa02002d2,0x00000000}},	//   gkut_, _zdzi, _þönd, --, 
   {{0xd04803be,0x7e680175,0x7b300311,0x27ec05d1}},	//   zifə, _dcgp, _lăud, ğeni_, 
   {{0x27ee06b7,0x26c818f8,0x7e6802d0,0x3ebc0254}},	//   şeni_, zhao_, _ecgp, akut_, 
   {{0x4ba40137,0xac9400c7,0xaa94010a,0x26c800e4}},	//   рөлү_, _ҳалш, бинч, yhao_, 
   {{0x1fb40588,0xbea007d5,0xe86401c0,0x3ebc0200}},	//   _усур, _махк, өхгү, ckut_, 
   {{0xa3dc0a28,0x25a8011f,0x81bc00fe,0x6d3400f2}},	//   _तेन_, xxal_, ুপথ_, _افتض, 
   {{0x7d780375,0x26c80374,0x00000000,0x00000000}},	//   _סרוג, whao_, --, --, 
   {{0x4669be28,0x66e40024,0x26c801fb,0x00000000}},	//   крам_, sėkm, thao_, --, 
   {{0x442003f9,0x25a8005a,0xa93400c7,0x31bc00eb}},	//   _sgj_, txal_, _леиш, _আইনশ, 
   {{0x38c82ea3,0xe29a06b8,0x44200789,0x85440166}},	// [3b210] _چاپی_, ғал_, _pgj_, рэбе, 
   {{0x35e402d5,0x00000000,0x00000000,0x00000000}},	//   іцтв, --, --, --, 
   {{0x6440000d,0xc1ac0303,0x00000000,0x00000000}},	//   _õlim, जङ्ग, --, --, 
   {{0x611800ee,0x6454033f,0x17980a7c,0x09a8000d}},	//   _iňli, _wdzi, _עירב, _चपाठ, 
   {{0x657c039a,0xd24c2688,0x44200158,0x8168509d}},	//   _upsh, رنو_, _tgj_, треб_, 
   {{0x645606b9,0x26d82b52,0xc0f4001f,0x5560215c}},	//   _udzi, _hmso_, ፈጻሚ_, _رۇمك, 
   {{0x3ebe06ba,0x02a606bb,0xa2941cd0,0xbfe00022}},	//   tkut_, _крам, _лаві, цәаҩ, 
   {{0x2490c459,0x7e600022,0x3ebc0108,0x00000000}},	//   _hazm_, цеиҧ, ukut_, --, 
   {{0x3ebe06bc,0xd24c05d3,0x00000000,0x00000000}},	//   rkut_, _سچن_, --, --, 
   {{0x3ebe06bd,0x249001a9,0x00000000,0x00000000}},	//   skut_, _jazm_, --, --, 
   {{0x3ebc0d04,0x5f940608,0x2cb801e6,0x92d803d4}},	//   pkut_, _دلائ, örda_, ঠকৰ_, 
   {{0xddd80003,0x00000000,0x00000000,0x00000000}},	//   _kawż, --, --, --, 
   {{0x39440ba1,0xdef800e8,0x09e001f0,0x6ea404e4}},	//   èms_, moŋ_, зоян, कारु, 
   {{0x249001a9,0xddc002dd,0xdef800e8,0x00000000}},	//   _nazm_, _мұқи, loŋ_, --, 
   {{0x279411eb,0x00000000,0x00000000,0x00000000}},	//   оштр, --, --, --, 
   {{0x6b9c00b5,0x64400254,0x00000000,0x00000000}},	//   ærge, _õlij, --, --, 
   {{0x249001a9,0x6118010e,0x26d8402f,0x00000000}},	// [3b220] _bazm_, _eňli, _dmso_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7794c21e,0x00000000,0x00000000,0x00000000}},	//   _بیزا, --, --, --, 
   {{0x55e42e80,0x00000000,0x00000000,0x00000000}},	//   _гомб, --, --, --, 
   {{0xfd48063f,0x15ba06be,0x415000d4,0x65540395}},	//   ranị, _сыны_, звіс, _мърф, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xef1800de,0x00000000,0x00000000,0x00000000}},	//   _apļa_, --, --, --, 
   {{0x1dd809d9,0xeeb8010b,0xe8e00208,0x47980677}},	//   _बेहत, рлиш_, _đọt_, ריקס, 
   {{0xc6900302,0x00000000,0x00000000,0x00000000}},	//   לאה_, --, --, --, 
   {{0x057802d3,0x809c3c71,0x90e4143e,0x2490022e}},	//   _ኣጋባብ_, _गोपे, _اسرن, _xazm_, 
   {{0xdef8002e,0x09b007b6,0xd008009b,0x00000000}},	//   boŋ_, ुन्य, _сеже_, --, 
   {{0x2a6c0086,0x33380200,0x4418010f,0x00000000}},	//   üeb_, _mtrx_, טויס, --, 
   {{0x6b9c01bf,0x00000000,0x00000000,0x00000000}},	//   ærgb, --, --, --, 
   {{0xac1a06bf,0x66e40006,0x2a6c0327,0x00000000}},	//   _колу_, mėki, żeb_, --, 
   {{0x66e40024,0xbc64129d,0x249001a9,0x00000000}},	//   lėki, _امىن_, _razm_, --, 
   {{0x36d439c9,0xbb3800c8,0x00000000,0x00000000}},	//   поср, _געהי, --, --, 
   {{0xeb046611,0x66e40153,0x6440000d,0x442400ae}},	// [3b230] रतीत_, nėki, _õlik, مراف, 
   {{0xfb7000e5,0x00000000,0x00000000,0x00000000}},	//   _بھیگ, --, --, --, 
   {{0xdef80694,0x00000000,0x00000000,0x00000000}},	//   yoŋ_, --, --, --, 
   {{0x26d803fa,0x66e40024,0xddd8031c,0x1b500023}},	//   _umso_, kėki, _pawż, _መደበራ, 
   {{0x6024a543,0x00000000,0x00000000,0x00000000}},	//   одла, --, --, --, 
   {{0x10a018ec,0x66e40006,0xb97c010f,0x00000000}},	//   дишн, dėki, טנדי, --, 
   {{0x9ea810ae,0xdef800e8,0x00000000,0x00000000}},	//   ивка_, toŋ_, --, --, 
   {{0x41e41cd0,0xbec000ef,0x00000000,0x00000000}},	//   _ліза, _šībr, --, --, 
   {{0xdef80de2,0x2d940006,0x00000000,0x00000000}},	//   roŋ_, прэс, --, --, 
   {{0x7b300356,0xdef81bce,0x3b400092,0x00000000}},	//   _năuc, soŋ_, _የተጨመ, --, 
   {{0xa3e80882,0xdef80de2,0x7c4000d7,0x00000000}},	//   मपि_, poŋ_, _ďurď, --, 
   {{0x66e40153,0x93f8011a,0x00000000,0x00000000}},	//   bėki, ילתי, --, --, 
   {{0x5278010f,0x00000000,0x00000000,0x00000000}},	//   סנשא, --, --, --, 
   {{0x1868a8c9,0x52b444ab,0xa3140574,0x3e400014}},	//   јави_, _अक्स, तगुज_, _بێکٲ, 
   {{0xd7f000c6,0x00000000,0x00000000,0x00000000}},	//   ذكر_, --, --, --, 
   {{0x46a00006,0xcf90011a,0x00000000,0x00000000}},	//   масв, וטל_, --, --, 
   {{0xaac40150,0x0b14007b,0x00000000,0x00000000}},	// [3b240] _ءتىن, _بقية_, --, --, 
   {{0x8c34010f,0x00000000,0x00000000,0x00000000}},	//   ַטנס_, --, --, --, 
   {{0x93440046,0x00000000,0x00000000,0x00000000}},	//   інде, --, --, --, 
   {{0xd1380022,0x00000000,0x00000000,0x00000000}},	//   ахк_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xea980a28,0xdce80118,0x27f001e7,0xd24c01d3}},	//   _kiṃ_, čněn, _íonú_, رنڈ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x0caa06c0,0x80b005d7,0x9f3400e5,0x00000000}},	//   атни_, _अवचे, _ہولڈ, --, 
   {{0x66e40153,0x00000000,0x00000000,0x00000000}},	//   rėki, --, --, --, 
   {{0xaa945026,0xff080c58,0x8eb00131,0x1ee80214}},	//   пинч, ৰৱেশ_, _يەتت, شویی_, 
   {{0xf3ec0d42,0xdd9000b2,0xbe3002de,0xefcc236c}},	//   _করার_, _ڳوٺ_, _قىمب, ışığ, 
   {{0xea9800b8,0x32040108,0x00000000,0x00000000}},	//   _aiṃ_, _jymy_, --, --, 
   {{0x32040051,0xc7c40395,0xab780066,0x00000000}},	//   _mymy_, осби, _همتا_, --, 
   {{0xefdc0023,0x00000000,0x00000000,0x00000000}},	//   _ዕላዊ_, --, --, --, 
   {{0xa534a6bb,0xc98401a9,0x00000000,0x00000000}},	//   знач, _дуои, --, --, 
   {{0xf8b801c0,0x47d000fe,0x442800f3,0x00000000}},	// [3b250] сөө_, _দুখী, ацем_, --, 
   {{0xa774005b,0x27ec002f,0xbb400092,0x3b400092}},	//   _елоч, ßens_, _የተበላ, _የተጠመ, 
   {{0xc2c8004b,0x83a82b61,0x00000000,0x00000000}},	//   ټبال_, штаб_, --, --, 
   {{0x98b00055,0x48f000bc,0x04e800eb,0xd7f8011a}},	//   _ityā_, ंकको_, কতের_, _להתל, 
   {{0x25ac500d,0xa0a46e47,0xf1a80345,0x614400d8}},	//   _çel_, залд, قاوه_, чела, 
   {{0xd12c2966,0x55b80302,0x81bc00cc,0x00000000}},	//   دمو_, _המשו, ুপল_, --, 
   {{0x387c01e6,0x46bc08a3,0x00000000,0x00000000}},	//   _övre_, _एकाह, --, --, 
   {{0x32646c49,0x00000000,0x00000000,0x00000000}},	//   _отув, --, --, --, 
   {{0x2900055a,0x2cb8022e,0x8d90009f,0x00000000}},	//   _okha_, аrd_, فليش, --, 
   {{0xf0ba06c1,0x290206c2,0x00000000,0x00000000}},	//   _والش_, _nkha_, --, --, 
   {{0x224e06c3,0x212c3012,0xfe7606c4,0x6d454065}},	//   _keek_, _hueh_, _дүй_, _çian, 
   {{0x29011825,0x2124068c,0x224c00e8,0x212e06c5}},	//   _akha_, _hilh_, _jeek_, _kueh_, 
   {{0x7e780161,0x20040162,0x99140006,0x00000000}},	//   mfup, _hyli_, зьві, --, 
   {{0x224e06c6,0xa3bc06e3,0x38b404e6,0xed000022}},	//   _leek_, ेना_, _härz_, _иҟын, 
   {{0x07a206c7,0x21240ba1,0x38b40036,0x00000000}},	//   нарн, _milh_, _kärz_, --, 
   {{0xcf901a4c,0x2900014b,0x996001b8,0x20043ee4}},	//   עטן_, _ekha_, _jɔŋ_, _myli_, 
   {{0x38b518ea,0x29001132,0xc95400ec,0x186821d7}},	// [3b260] _märz_, _fkha_, _فليش_, _лапи_, 
   {{0x79840099,0xf48407d6,0x461001b9,0x00000000}},	//   _ipiw, باری, رولر, --, 
   {{0x224e06c8,0x31c41bd6,0x00000000,0x00000000}},	//   _beek_, वन्ध, --, --, 
   {{0x224c00e8,0xc7b00bd9,0x212c0789,0x758401ec}},	//   _ceek_, _טבת_, _bueh_, _оңба, 
   {{0x2124003e,0x224c4c86,0xf8b000dc,0x74f401ec}},	//   _bilh_, _deek_, ञापय, _قۋرا, 
   {{0x200447d0,0xfd0405d9,0x764606c9,0x629c08ce}},	//   _byli_, _سج_, lbiy, _óson, 
   {{0x76440a81,0x224c1bce,0x845000db,0x00000000}},	//   obiy, _feek_, _سۉنچ, --, 
   {{0x76445a86,0x224d4314,0x79840142,0xa3e80037}},	//   nbiy, _geek_, _opiw, मपर_, 
   {{0x2124180f,0x76440067,0x66e40064,0x00000000}},	//   _filh_, ibiy, mėkt, --, 
   {{0x0ca927dd,0x0a6804a9,0x862c0023,0x66e400c0}},	//   стии_, әрни_, ዳስነት, lėkt, 
   {{0x798606ca,0x7644009f,0x224c0694,0xf8b017c6}},	//   _apiw, kbiy, _yeek_, ञानय, 
   {{0xbf1000db,0xbb90005b,0xa9782401,0x64400037}},	//   _كولب, хающ, ойму_, _õliv, 
   {{0x764401d9,0x00000000,0x00000000,0x00000000}},	//   dbiy, --, --, --, 
   {{0x76440009,0xe79402f2,0x38b401f4,0x6ea41100}},	//   ebiy, وازک, _käry_, काकु, 
   {{0x798427be,0x6d4206cb,0x00000000,0x00000000}},	//   _epiw, lpma, --, --, 
   {{0x764606cc,0x6d41158c,0x370606cd,0x00000000}},	//   gbiy, opma, ечув, --, 
   {{0x224e06ce,0xea980055,0x6d4206cf,0xc4282761}},	// [3b270] _reek_, _ciṅ_, npma, مثال_, 
   {{0x764606d0,0x224c0c18,0xea980055,0x7b080784}},	//   abiy, _seek_, _diṅ_, yñuk, 
   {{0x764606d1,0x7b30054e,0x224c17c7,0x81740150}},	//   bbiy, _lăun, _peek_, _ﺼﻔﻘﺔ_, 
   {{0x2124003e,0x76440067,0xa634003b,0x00000000}},	//   _silh_, cbiy, _інгі, --, 
   {{0x224c0076,0x6d4001f5,0x200401f4,0x00000000}},	//   _veek_, jpma, _syli_, --, 
   {{0x224e06d2,0xdce801a6,0x00000000,0x00000000}},	//   _week_, mteć, --, --, 
   {{0x644606d3,0x7e78192e,0x224c01a4,0x6d40017a}},	//   mbhi, tfup, _teek_, epma, 
   {{0xd3440214,0x644412ef,0xa2b40006,0xe2c80472}},	//   _آینه_, lbhi, _ўбач, _بورو_, 
   {{0x62980134,0x80246112,0x21246785,0x6d4002d0}},	//   mdwo, _فرام, _tilh_, gpma, 
   {{0x629938eb,0x764405d1,0x7b300311,0x644606d4}},	//   ldwo, zbiy, _dăun, nbhi, 
   {{0x7645c731,0x798606d5,0x644437a8,0x7e780433}},	//   ybiy, _spiw, ibhi, pfup, 
   {{0x629825a5,0x00000000,0x00000000,0x00000000}},	//   ndwo, --, --, --, 
   {{0x629800ad,0xbdf80214,0x00000000,0x00000000}},	//   idwo, _ارضا_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa3dc11d7,0x64440882,0xd70402bf,0x99cc015b}},	//   _तेल_, dbhi, дзви, রপেক, 
   {{0x64440472,0x809c0037,0x00000000,0x00000000}},	//   ebhi, _गोसे, --, --, 
   {{0x7644e501,0xd01404c5,0x80d0015b,0x798402d0}},	// [3b280] rbiy, াশয়_, _তদন্, _upiw, 
   {{0x764401d9,0x6298493a,0x09e400fe,0x00000000}},	//   sbiy, edwo, _নৰকা, --, 
   {{0x6b68013f,0xb6c4151e,0x629801f5,0x3fcc00fe}},	//   _bɛgy, _зинһ, fdwo, িপুষ, 
   {{0x6d40022c,0x64446c35,0x1cac025c,0x764481f1}},	//   ypma, abhi, _པོའ_, qbiy, 
   {{0xc17003e6,0xc0d8044e,0x7d0000b5,0x64453682}},	//   ندوت, _ዕማም_, _okns, bbhi, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd4980588,0x7b30054e,0x60dc0064,0x00000000}},	//   _урҭ_, _păun, _įsme, --, 
   {{0x6d4057cb,0x8c880063,0x00000000,0x00000000}},	//   upma, ољна_, --, --, 
   {{0x6d40cdf0,0x64400037,0x4ebc0154,0xc1b8011a}},	//   rpma, _õlit, ইফেল, _וממש, 
   {{0x6b68016b,0x4f942a9d,0x00000000,0x00000000}},	//   _yɛgy, _юрау, --, --, 
   {{0x6d4206d6,0x0354008f,0xa06800c7,0x66d001e3}},	//   ppma, ויטש_, _маӡа_, _kåke, 
   {{0x7c900799,0x00000000,0x00000000,0x00000000}},	//   رشیا, --, --, --, 
   {{0x1cac1b4b,0x6f00ff83,0x26f881e9,0x66d0143a}},	//   _པོར_, lomc, ूत्र_, _måke, 
   {{0xa3dd2126,0x67d402bf,0x0cc802ab,0x09e400fe}},	//   _तें_, хову, िसीम, _নৰখা, 
   {{0x6f000117,0x2ee4004e,0x4e001b97,0x3688010a}},	//   nomc, nimf_, _लडाई_, мсун_, 
   {{0x66d005ac,0x00000000,0x00000000,0x00000000}},	// [3b290] _nåke, --, --, --, 
   {{0x6f00022e,0x00000000,0x00000000,0x00000000}},	//   homc, --, --, --, 
   {{0xdce8098d,0x644606d7,0x1cac025c,0x64a400fb}},	//   steć, rbhi, _པོལ_, маҡа, 
   {{0x217402bf,0x2f080086,0x2cbc0158,0x6f0000d0}},	//   еукр, bûgi_, _lovd_, jomc, 
   {{0x629a06d8,0x00000000,0x00000000,0x00000000}},	//   rdwo, --, --, --, 
   {{0x26ca06d9,0x656c7851,0x00000000,0x00000000}},	//   lkao_, muah, --, --, 
   {{0x656e06da,0xceac00ec,0x00000000,0x00000000}},	//   luah, ڍڙن_, --, --, 
   {{0x273404f3,0x26c803d1,0x809c37cc,0x00000000}},	//   _mån_, nkao_, _गोरे, --, 
   {{0x656e06db,0x64400037,0x00000000,0x00000000}},	//   nuah, _õlis, --, --, 
   {{0x656c00d8,0x00000000,0x00000000,0x00000000}},	//   iuah, --, --, --, 
   {{0x656e06dc,0x273404f3,0xb0ac0254,0x6f00014f}},	//   huah, _nån_, चारग, bomc, 
   {{0x656c18a6,0x04e8015b,0x26c8107d,0x6f0000d8}},	//   kuah, _কঠোর_, jkao_, comc, 
   {{0x07a012d7,0x3a240036,0x49c436ca,0x00000000}},	//   қатн, ämp_, елян_, --, 
   {{0x830c031c,0x656c0254,0x00000000,0x00000000}},	//   _ཏེའུ_, duah, --, --, 
   {{0x97c40345,0x00000000,0x00000000,0x00000000}},	//   رتسم, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x656c0588,0x00000000,0x00000000,0x00000000}},	// [3b2a0] guah, --, --, --, 
   {{0x1cac038f,0x394206dd,0x6f000944,0x66d00158}},	//   _པོས_, _itis_, zomc, _råke, 
   {{0x6f00009f,0x1cac031c,0x2734007c,0xd264030c}},	//   yomc, _ྔོན_, _gån_, екей, 
   {{0x26c805a1,0x656d7f52,0x7b30054e,0xea980055}},	//   ckao_, buah, _răul, _viṇ_, 
   {{0x3fcc05ac,0x6f0001a9,0x00000000,0x00000000}},	//   িপোষ, vomc, --, --, 
   {{0x66d01445,0x3940003a,0x7b300356,0xab040055}},	//   _våke, _mtis_, _păul, _koṣṇ, 
   {{0x777c01e0,0x3940003e,0x6f0188b4,0x03a001b9}},	//   ntrx, _ltis_, tomc, _йиро, 
   {{0x394206de,0x42507405,0xc7b006a9,0x7f800c8b}},	//   _otis_, _منفر, רבה_, الين, 
   {{0x394206df,0x6f007bb9,0x8d844bb6,0xadd40114}},	//   _ntis_, romc, хуйд, топљ, 
   {{0xbd400075,0x6f00004e,0x26c8009d,0x48b800fe}},	//   اھنى, somc, zkao_, _উগ্ৰ, 
   {{0x394206e0,0x6f00009f,0x1fb40e92,0x3b500276}},	//   _atis_, pomc, _исцр, лкэр, 
   {{0xe8d801f2,0x273401e6,0x4b500133,0x6f00022e}},	//   _mpụ_, _rån_, پێکر, qomc, 
   {{0x2734049f,0x394041ec,0x3d0800c5,0x7959035c}},	//   _sån_, _ctis_, _ठीके_, нияр_, 
   {{0x290606e1,0xe81801c6,0xdde800f2,0xc9840818}},	//   ôla_, догч_, _ترمه_, муҳи, 
   {{0x394206e2,0xab0400b8,0xef180171,0x2d0c0073}},	//   _etis_, _coṣṇ, _apļi_, हतील_, 
   {{0xab0400b8,0x656e06e3,0x3b5002e8,0x3b080120}},	//   _doṣṇ, tuah, _скър, _пејо_, 
   {{0x6aac5ff2,0xe8d802e3,0xdce80276,0x26c80e3c}},	// [3b2b0] _inaf, _apụ_, _înăl, rkao_, 
   {{0x3b400020,0x26c808a4,0x656e06e4,0xbb400092}},	//   _የተጀመ, skao_, ruah, _የተቀላ, 
   {{0xeff836d7,0x656c0798,0x6aac0010,0x26c816a3}},	//   ገራዊ_, suah, _knaf, pkao_, 
   {{0x656e06e5,0xc3040244,0xddc8054e,0xbb38010f}},	//   puah, رباو, ngeţ, פעדי, 
   {{0x6aac00ec,0xb0ac06ab,0xc85c0023,0x60e0022e}},	//   _mnaf, चांग, _ንምንጋ, аzmа, 
   {{0x77a801d9,0xe414035b,0xa068bbb8,0xc64400cf}},	//   _تێہہ_, _адгь, фака_, _تئگى, 
   {{0x6aac225e,0x00b40032,0x00000000,0x00000000}},	//   _onaf, _үҫеш_, --, --, 
   {{0x6aac0337,0xf778031c,0x00000000,0x00000000}},	//   _nnaf, ħħx_, --, --, 
   {{0xf1ac052f,0xf5040050,0x00000000,0x00000000}},	//   _уҡ_, _شِہُ, --, --, 
   {{0x6aae06e6,0xa2bc02ab,0x00000000,0x00000000}},	//   _anaf, वॉर्, --, --, 
   {{0x394001e4,0x7e7004d3,0x7b080113,0xbf640244}},	//   _stis_, _مناڵ, kñut, _سداو, 
   {{0x6aac0142,0x4b2000a8,0x00000000,0x00000000}},	//   _cnaf, имэв, --, --, 
   {{0x1ce00327,0x1dd8012d,0xab040055,0xdb080241}},	//   སོད_, _बेचत, _soṣṇ, _àník, 
   {{0x6aac0083,0x39400219,0x1be8009b,0x00000000}},	//   _enaf, _vtis_, _одли_, --, 
   {{0x480400a8,0xd8741888,0xd70400ae,0x00000000}},	//   верн_, _یادب, نظري, --, 
   {{0x39400e14,0xa3d445c7,0x6aae06e7,0x00000000}},	//   _ttis_, ाईन_, _gnaf, --, 
   {{0x98f48fa3,0x394000ef,0x00000000,0x00000000}},	// [3b2c0] _аянч, _utis_, --, --, 
   {{0x321805da,0x5a88063f,0x7ae40165,0x5fd00892}},	//   _ąry_, _ụlọọ, _hmit, तनाल, 
   {{0xb9dc02d3,0x7ae40216,0x966401af,0x00000000}},	//   _ኣል_, _kmit, _икне, --, 
   {{0x25ac151c,0xa2bc134e,0x00000000,0x00000000}},	//   _šele_, वॉल्, --, --, 
   {{0x7ae606e8,0xfeb4009e,0xee440022,0x00000000}},	//   _mmit, জসাধ, ҳҭеи, --, 
   {{0x044206e9,0x7ae40334,0x6440000d,0x62240014}},	//   _верн, _lmit, _õlip, ھى۪ل, 
   {{0xc60400bd,0x66d001e6,0x84e04d75,0xfbc400f7}},	//   লেদা_, _håka, _торж, _ئت_, 
   {{0x0cc86b26,0x00000000,0x00000000,0x00000000}},	//   िस्म, --, --, --, 
   {{0xc278011a,0xdd9000e5,0xfe6c216b,0x00000000}},	//   _קרמי, موٹ_, زدي_, --, 
   {{0x6cd59170,0x6aac307c,0xdbc8000d,0x00000000}},	//   اقدا, _snaf, _lõõm, --, 
   {{0xf1a800aa,0x2fd800b5,0x00000000,0x00000000}},	//   _غاړه_, _årg_, --, --, 
   {{0x8d6606ea,0x499004f2,0x00000000,0x00000000}},	//   _авде, لیبر, --, --, 
   {{0x7ae40dde,0x4cb800bd,0xddc8054e,0x00000000}},	//   _dmit, ইসবু, rgeţ, --, 
   {{0x2f08006a,0xfce206eb,0x3cc40798,0x00000000}},	//   rûgu_, _кочо, _илчо_, --, 
   {{0x19c00075,0x6aac045a,0xd2680354,0x4de4000d}},	//   _һәрг, _tnaf, _гiиш, _जेतै_, 
   {{0x6aae06ec,0xa3dc01ad,0x659400d8,0xfbb4011a}},	//   _unaf, _तेग_, лабу, _יפות_, 
   {{0xa61606ed,0xc8642f0d,0x19c0588a,0x69c4ca0f}},	// [3b2d0] умач, _итни, _ләрг, _сөнб, 
   {{0x245606ee,0xddc80010,0x080808f0,0x156402dd}},	//   اناس, ngeš, _يزدي_, _ﺷﻪﺷﯩ, 
   {{0x692407dd,0x442402f6,0x68e400a3,0x6b9c01bf}},	//   _имҩа, än_, _imhd, ærgh, 
   {{0xe8e00016,0xdec00023,0x00000000,0x00000000}},	//   _đột_, ትታን_, --, --, 
   {{0x20880364,0x216a06ef,0x00000000,0x00000000}},	//   ейли_, хили_, --, --, 
   {{0xe354293c,0x00000000,0x00000000,0x00000000}},	//   _معرک, --, --, --, 
   {{0xd00606f0,0x2f5454be,0xdee56eec,0xa3d401d5}},	//   леше_, атыс, локи, _совч, 
   {{0xdd91920b,0x645606f1,0x909400d1,0xceb4013d}},	//   موع_, _hezi, ввәт_, ләч_, 
   {{0x6454fee1,0x60f84ced,0x7ae4002f,0xdca475a2}},	//   _kezi, _зная_, _rmit, гапи, 
   {{0x62a40419,0x00000000,0x00000000,0x00000000}},	//   štoľ, --, --, --, 
   {{0x645606f2,0x9e741541,0xef1800ef,0x4aac0073}},	//   _mezi, _مهات, _apļu_, टांव, 
   {{0x60c206f3,0xd94418ec,0x68e40332,0x657e06f4}},	//   _holm, леми, _amhd, _oqsh, 
   {{0x60c02053,0xdbc800af,0x3ead729c,0x2d5800a8}},	//   _kolm, _rõõm, _ingt_, _аичь_, 
   {{0x645606f5,0x8d580302,0x66d03953,0x8c41532b}},	//   _nezi, _טכני, _råka, _леше, 
   {{0x60c206f6,0x66d06ab9,0x657c036b,0xe1e40451}},	//   _molm, _såka, _aqsh, _ڀڳ_, 
   {{0x7ae40e05,0x60c001d5,0x2fd82641,0x00000000}},	//   _umit, _lolm, _ürge_, --, 
   {{0x60c00ba7,0x0af44f4e,0x5b240022,0x7b080784}},	// [3b2e0] _oolm, _حفيظ_, _иьҩа, sñus, 
   {{0x77945a76,0xbf0c0073,0x60c00205,0xb78801af}},	//   _پیرا, ातुन_, _nolm, _иҙге_, 
   {{0x645606f7,0x00000000,0x00000000,0x00000000}},	//   _dezi, --, --, --, 
   {{0xb24407dd,0x60c003ac,0x645606f8,0x00000000}},	//   рҭад, _aolm, _eezi, --, 
   {{0x60c00510,0x00000000,0x00000000,0x00000000}},	//   _bolm, --, --, --, 
   {{0x645606f9,0x20d80036,0xcf980063,0x41240137}},	//   _gezi, _lèif_, еји_, гочо_, 
   {{0x60c206fa,0xbf0c05ba,0x7f8026c0,0x3eac0263}},	//   _dolm, ातून_, ملون, _bngt_, 
   {{0x64548cdb,0x71c4014b,0xff040798,0x00000000}},	//   _zezi, _кабҷ, лејк_, --, 
   {{0x64549e6f,0x50442424,0x60c1dd5f,0x00000000}},	//   _yezi, _безб, _folm, --, 
   {{0x60c008a4,0x859400c8,0x3eac04e6,0xe084009f}},	//   _golm, נדיג_, _engt_, _نجمي, 
   {{0xcf44300e,0xaab400d3,0x24840bbc,0xfb30009d}},	//   _сней, айні, _ölme_, йнээ, 
   {{0xa3d40073,0x9e641888,0x00000000,0x00000000}},	//   ाईत_, _ناهن, --, --, 
   {{0x60c06a37,0x00000000,0x00000000,0x00000000}},	//   _yolm, --, --, --, 
   {{0x1cac031c,0x60c001b9,0x00000000,0x00000000}},	//   _པོག_, _xolm, --, --, 
   {{0x64542d5b,0x7c38011a,0xbb400798,0xd8540139}},	//   _rezi, _אגוז, _лејк, ресө, 
   {{0x645606fb,0x00000000,0x00000000,0x00000000}},	//   _sezi, --, --, --, 
   {{0xa3dc09d9,0xf8b830af,0x645606fc,0xc9840454}},	// [3b2f0] _तेज_, төө_, _pezi, _суйи, 
   {{0x2bb80d01,0xb0a402ab,0xdce800df,0x22580419}},	//   इमपा, _गोलग, treĉ, _žsk_, 
   {{0x60c206fd,0x657c007f,0x281490b2,0xe2340798}},	//   _rolm, _wqsh, _خودس, анењ, 
   {{0x60c206fe,0x645606ff,0x349402a9,0x062401ec}},	//   _solm, _wezi, _қаср, _مۋزي_, 
   {{0x60c20700,0x64560701,0x69de0702,0x66d0168c}},	//   _polm, _tezi, nzse, _håko, 
   {{0x656e0703,0x60c007d6,0x3eac31e5,0xd5ac01ed}},	//   mrah, _qolm, _sngt_, _کہے_, 
   {{0x60c05dfa,0xa3dc0574,0x50a015bf,0x00000000}},	//   _volm, _तेच_, تەلل, --, 
   {{0x8c0803f4,0x60c20704,0x656c0067,0x9ea80022}},	//   রধান_, _wolm, orah, твиа_, 
   {{0x656e0705,0x60c20706,0xc6040154,0xfe1c012d}},	//   nrah, _tolm, লেরা_, मेंस_, 
   {{0x656e0707,0xdb84035b,0x5ba831d5,0x69dc01d3}},	//   irah, агои, вком_, dzse, 
   {{0x5f942586,0x3eac004d,0x00000000,0x00000000}},	//   _خلائ, _tngt_, --, --, 
   {{0x656e0708,0x3eae0709,0x68f40399,0x3f500356}},	//   krah, _ungt_, enzd, mţu_, 
   {{0x656e070a,0x2f180276,0x62880332,0x3f500356}},	//   jrah, _соць_, _mbeo, lţu_, 
   {{0xa3b42d2c,0x4dd80375,0xd7b803e3,0x1ca40345}},	//   जमा_, _בחנו, _çəkə_, _ئێدی_, 
   {{0x66d02c95,0x62880115,0x973401c0,0x656c035b}},	//   _våkn, _obeo, рэгч, erah, 
   {{0x99d4009a,0x00000000,0x00000000,0x00000000}},	//   _نتخا, --, --, --, 
   {{0x656e070b,0x59740137,0x6b9c01bf,0x997400db}},	// [3b300] grah, _тыйу, ærgv, _туйш, 
   {{0x628a070c,0x00000000,0x00000000,0x00000000}},	//   _abeo, --, --, --, 
   {{0x656e070d,0xa88404b3,0x90e450bc,0x00000000}},	//   arah, _الپى, یستن, --, 
   {{0x656e070e,0xd1c80276,0x00000000,0x00000000}},	//   brah, клее_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd388004e,0x8a14011a,0x22480205,0xd468586a}},	//   _ийге_, בחנו_, ıaka_, _шиге_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3de4015b,0x8e480051,0x3fc40108,0x61f000e5}},	//   _পড়ল, _sốbá, рышн_, áklá, 
   {{0x912801b9,0x50940063,0x00000000,0x00000000}},	//   _ажаб_, _вређ, --, --, 
   {{0x00e022d7,0x6b74084c,0x0ca80107,0x00000000}},	//   _джун, блоу, ттии_, --, 
   {{0xaa5852d8,0xdce803ee,0x656d2d22,0x0434010f}},	//   лину_, steğ, zrah, יטיש_, 
   {{0x69dc0112,0x656c0113,0x66d0072b,0x7e940372}},	//   tzse, yrah, _råko, _ۅنۅر_, 
   {{0xc984842e,0x69dc0007,0x66d003cd,0x00000000}},	//   шуни, uzse, _såko, --, 
   {{0x66d03402,0xfbcc004b,0xac1807d5,0x656c61cf}},	//   _påko, ستۍ_, _йолу_, vrah, 
   {{0x656c0009,0x00000000,0x00000000,0x00000000}},	//   wrah, --, --, --, 
   {{0x656e070f,0xa3d41fd2,0x00000000,0x00000000}},	//   trah, ाईस_, --, --, 
   {{0x656c0014,0x170801fd,0x00000000,0x00000000}},	// [3b310] urah, افقی_, --, --, 
   {{0xf991c9a5,0x00000000,0x00000000,0x00000000}},	//   _آبي_, --, --, --, 
   {{0x83641b06,0x33380175,0xa06801d5,0x00000000}},	//   شدال, _curx_, ҳала_, --, 
   {{0x656d7228,0x2a78002f,0x051400eb,0x00000000}},	//   prah, ngsb_, ়দের_, --, 
   {{0xa06a0710,0x21a401d5,0x656c031c,0xfd540055}},	//   гала_, силм, qrah, bhaṣ, 
   {{0xdce8031c,0x7124027d,0x00000000,0x00000000}},	//   rreċ, يرول, --, --, 
   {{0x1d080116,0x00000000,0x00000000,0x00000000}},	//   ғени_, --, --, --, 
   {{0xb9dc044e,0x77f802e4,0x13a801d3,0x3f500356}},	//   _ኣፍ_, ימוד_, _حنفی_, rţu_, 
   {{0x7b30054e,0xefdc01f3,0x00000000,0x00000000}},	//   _lăut, _ንዋይ_, --, --, 
   {{0x66d20711,0x6eb000bc,0xdc9801a9,0x00000000}},	//   _såkl, झाउँ, утиш_, --, 
   {{0x66d00ac8,0x1fe4015b,0xdca412d7,0x1be82b97}},	//   _påkl, _পুরস, _ҳали, удни_, 
   {{0x44fc0c58,0x00000000,0x00000000,0x00000000}},	//   ্গিক_, --, --, --, 
   {{0xdca60712,0x09c80154,0x5ca400d8,0xc0f00092}},	//   _гали, _লেবা, _гилб, ቃጠል_, 
   {{0x7b300276,0x3ebc0254,0x00000000,0x00000000}},	//   _băut, ljut_, --, --, 
   {{0xb8f006bc,0x7b3000a8,0xfaa4036b,0x225c0327}},	//   _शव_, _căut, _ҳақо, kawk_, 
   {{0x3ebc15a5,0x66d003cd,0x225c031c,0xa6b40108}},	//   njut_, _håkj, jawk_, осущ, 
   {{0x99840597,0x225c0327,0x00000000,0x00000000}},	// [3b320] _الخو, dawk_, --, --, 
   {{0xdce80153,0x9854254f,0xe2a80133,0x3ebc01f4}},	//   kreč, _утиш, یانن_, hjut_, 
   {{0xf1e0000d,0xb6c401ee,0x00000000,0x00000000}},	//   _खेज़_, _динһ, --, --, 
   {{0xa3b800c5,0x00000000,0x00000000,0x00000000}},	//   _अऊर_, --, --, --, 
   {{0xf1b8052f,0x00000000,0x00000000,0x00000000}},	//   шҡа_, --, --, --, 
   {{0xa3d4069f,0x24481371,0xc950011a,0x00000000}},	//   ाईश_, _نجفي_, למד_, --, 
   {{0x9344084c,0x3ebc025c,0xdce800c0,0x00000000}},	//   _ынве, fjut_, greč, --, 
   {{0x1cac031c,0x00000000,0x00000000,0x00000000}},	//   _པོཔ_, --, --, --, 
   {{0x5274016c,0x00000000,0x00000000,0x00000000}},	//   _вуҷу, --, --, --, 
   {{0x3ebc0357,0x7cd404b4,0x246c0023,0xdce8560e}},	//   ajut_, ймыр_, _ኣምጺኡ_, breč, 
   {{0xac1a0713,0xbb4401d3,0x8fa405af,0x00000000}},	//   рону_, یلین_, _دماه, --, 
   {{0x7b300311,0x2b18012d,0x4f240395,0x00000000}},	//   _răut, _यीशु_, _удеб, --, 
   {{0x1ea85706,0xff241bf3,0x5cc402dd,0x00000000}},	//   _خالي_, _ابلی, ссөз, --, 
   {{0x7d78008f,0x00000000,0x00000000,0x00000000}},	//   _ענוו, --, --, --, 
   {{0x2d860714,0x00000000,0x00000000,0x00000000}},	//   ltme_, --, --, --, 
   {{0xfbcc10fe,0x2b4001ef,0x00000000,0x00000000}},	//   _ستى_, _čich_, --, --, 
   {{0x63440953,0x2a680472,0xfaf814a5,0x66d003cd}},	// [3b330] _mėne, _idab_, _دروغ_, _håkk, 
   {{0x1cac0327,0xa3d4023e,0x156401ec,0x00000000}},	//   _པོབ_, ाईल_, _ﺷﻪﺗﯩ, --, 
   {{0x2d860715,0x2248009d,0xca840023,0xa6340150}},	//   htme_, ñako_, _ንማንም_, _мнні, 
   {{0x623400e4,0xdce8892f,0x00000000,0x00000000}},	//   цеду, vreč, --, --, 
   {{0x41680640,0x225c025c,0x00000000,0x00000000}},	//   ујем_, rawk_, --, --, 
   {{0x661c0029,0x9fca0716,0x25a9fc39,0xdce80010}},	//   _izsk, игла_, mval_, treč, 
   {{0x25a80a40,0x9f060717,0x3ebde812,0x66d003cd}},	//   lval_, يوتو, tjut_, _nåkk, 
   {{0x2a6800e8,0x25a802f0,0x00000000,0x00000000}},	//   _ndab_, oval_, --, --, 
   {{0x25aa0718,0x1cac0003,0xdce80fb7,0xdfd000b2}},	//   nval_, _པོད_, sreč, _ڪيا_, 
   {{0x2a6a0719,0xdcea071a,0x6f042230,0x3ebc045f}},	//   _adab_, preč, čica, sjut_, 
   {{0x25a81cff,0x752004e6,0xdfd04609,0x80ac0154}},	//   hval_, _ëmze, _تيا_, জউদ্, 
   {{0x66d00217,0x25a8733a,0xff28036b,0x1a280e58}},	//   _dåkk, kval_, _сўзи_, ижни_, 
   {{0xa3d4012c,0x25a84361,0x00000000,0x00000000}},	//   ाईँ_, jval_, --, --, 
   {{0x26da071b,0x25aa071c,0x2a680009,0x7e78000d}},	//   _also_, dval_, _edab_, lgup, 
   {{0xddd8007f,0x25aa071d,0xc7a16848,0x00000000}},	//   _sewň, eval_, мирк, --, 
   {{0x25a827bb,0x5914031c,0xda0001ad,0x00000000}},	//   fval_, _ྲེམས_, _लखपत_, --, 
   {{0x54c4084c,0x25a8017a,0x95980640,0x7b34054e}},	// [3b340] обаб, gval_, штву_, _făur, 
   {{0xa3d41b77,0x7b34054e,0xd468005b,0x26d800e5}},	//   ाईं_, _găur, риже_, _elso_, 
   {{0x3985680e,0x661c0165,0x1cac0327,0x25a8000d}},	//   lös_, _ezsk, _པོན_, aval_, 
   {{0x91483849,0x1308656c,0x2d84007f,0x00000000}},	//   ачка_, шней_, ytme_, --, 
   {{0x7646071e,0x39842ac9,0x41500212,0x15b871fe}},	//   mciy, nös_, двіс, _тыны_, 
   {{0x8f44404e,0x3d00033f,0x7646071f,0x4f681c00}},	//   охид, रकों_, lciy, ашим_, 
   {{0x398401d3,0x76440009,0x04400024,0x00000000}},	//   hös_, ociy, _цесн, --, 
   {{0x76460720,0xeeb84358,0x3984df4c,0x2d840083}},	//   nciy, слиш_, kös_, ttme_, 
   {{0x016098cc,0x2d84010a,0x3984007c,0x00000000}},	//   _окто, utme_, jös_, --, 
   {{0x7e780113,0x2d840bbc,0x398400e5,0xc1980a7c}},	//   agup, rtme_, dös_, _דשמי, 
   {{0x25a81f48,0x2d84a1bc,0x634400b0,0xd0080063}},	//   zval_, stme_, _tėne, _теже_, 
   {{0xe8e0001e,0x25a80334,0x398442a9,0x20d401ec}},	//   _đốt_, yval_, fös_, _وتەج, 
   {{0x2a680d27,0xcce406f6,0x6c5400c7,0x76440009}},	//   _vdab_, _وستي, _еклу, dciy, 
   {{0x25aa0721,0xddc80166,0x00000000,0x00000000}},	//   vval_, laeş, --, --, 
   {{0x76440198,0x25a8e9a7,0x2d400208,0x0a680798}},	//   fciy, wval_, _hòe_, _крпи_, 
   {{0x25aa0722,0x2a68009a,0x398401b8,0xf77000c6}},	//   tval_, _udab_, bös_, ضاف_, 
   {{0x25a86f8c,0x00000000,0x00000000,0x00000000}},	// [3b350] uval_, --, --, --, 
   {{0x76440014,0x00000000,0x00000000,0x00000000}},	//   aciy, --, --, --, 
   {{0x25aa0723,0x76445be5,0x2d400208,0x7e78007c}},	//   sval_, bciy, _lòe_, ygup, 
   {{0x76440c09,0xa5f800f3,0xb1700240,0x00000000}},	//   cciy, _гему_, _ኣይኮነ_, --, 
   {{0x661c0029,0x20d4109a,0x00000000,0x00000000}},	//   _uzsk, зійс, --, --, 
   {{0xd76402f2,0x00000000,0x00000000,0x00000000}},	//   _بنێی, --, --, --, 
   {{0x64460724,0x398401ed,0xdcec00e2,0xb5080137}},	//   mchi, zös_, ākļi, _بۉلۅ_, 
   {{0x64460725,0x398401d3,0x9f2000d1,0x00000000}},	//   lchi, yös_, رۈشۈ, --, 
   {{0x4d4418e3,0x5e580c75,0x7e7a0726,0x3d040118}},	//   ппын_, _ۇلاس_, rgup, सकले_, 
   {{0x62987506,0x64460727,0x7e784250,0x398400e5}},	//   lewo, nchi, sgup, vös_, 
   {{0x64460728,0x6b9c01bf,0x00000000,0x00000000}},	//   ichi, ærgp, --, --, 
   {{0x6444036b,0x39860729,0x1cac0327,0x00000000}},	//   hchi, tös_, _པོམ_, --, 
   {{0x6446072a,0x9d441f10,0xb1140408,0x69d8010e}},	//   kchi, _эелд, _амăш, _üwel, 
   {{0xdca603fd,0x62982959,0x17f80597,0x6446072b}},	//   _хаки, hewo, مرأة_, jchi, 
   {{0x3f8405ce,0x6446072c,0xdb2401a8,0x62984ebd}},	//   ntnu_, dchi, ípós, kewo, 
   {{0x6446072d,0x6298033f,0x7644058a,0x00000000}},	//   echi, jewo, uciy, --, 
   {{0x629a072e,0x7646072f,0x2d4001fb,0x7e680009}},	// [3b360] dewo, rciy, _xòe_, _mdgp, 
   {{0x985407d6,0xe50410fe,0x3f841050,0x64460730}},	//   _этиш, وبلي, ktnu_, gchi, 
   {{0xa9c44013,0x629a0731,0x64480356,0x7644022e}},	//   _فزیو, fewo, _şeic, pciy, 
   {{0x64440a4d,0x62982923,0x15b80166,0xab0400b8}},	//   achi, gewo, _лыгы_, _vaṇṇ, 
   {{0x6445433a,0x3f840171,0x00000000,0x00000000}},	//   bchi, etnu_, --, --, 
   {{0x64460732,0x3a200010,0x3f840e04,0x00000000}},	//   cchi, _mzip_, ftnu_, --, 
   {{0x629928bb,0x0838010f,0x00000000,0x00000000}},	//   bewo, זעצל, --, --, 
   {{0x6f041674,0x00000000,0x00000000,0x00000000}},	//   čico, --, --, --, 
   {{0x69200356,0x6d400009,0x00000000,0x00000000}},	//   lţeş, uqma, --, --, 
   {{0xa0c80597,0x7b080113,0x8fa42c90,0x4fa400f3}},	//   _وذلك_, mñuy, _назе, _низв, 
   {{0x6d40074d,0xa3d407f7,0x2b58067c,0x6920054e}},	//   sqma, ाईए_, èrc_, nţeş, 
   {{0x3a20009a,0x6d400113,0x4f2400ee,0x64460733}},	//   _bzip_, pqma, _эдеб, zchi, 
   {{0x64460734,0x20d80036,0xbea400ec,0xdee41622}},	//   ychi, _mèin_, _رهون_, _تألي, 
   {{0x6298068f,0x3a200cf4,0x644525f2,0x6da40116}},	//   zewo, _dzip_, xchi, _ниҗа, 
   {{0x64440517,0x46685c9c,0x629a0735,0x3a2056f8}},	//   vchi, йрам_, yewo, _ezip_, 
   {{0x6298002e,0x26f800bc,0x64440142,0x25d80108}},	//   xewo, ्केर_, wchi, омбы_, 
   {{0xf6740323,0x64460736,0x3a200208,0xa534f3f0}},	// [3b370] эгтэ, tchi, _gzip_, днач, 
   {{0x64460737,0x62980337,0x00000000,0x00000000}},	//   uchi, wewo, --, --, 
   {{0x62987713,0x64450944,0x29d400ec,0x06b400f2}},	//   tewo, rchi, _ريگس, _فندک_, 
   {{0x64441948,0x04fc015b,0x00000000,0x00000000}},	//   schi, ্গের_, --, --, 
   {{0x629a0738,0xa0a40323,0x64460739,0x6ec061b8}},	//   rewo, далд, pchi, वानु, 
   {{0x6298016b,0x644407d6,0x55b8011a,0x00000000}},	//   sewo, qchi, _ומשו, --, 
   {{0x629a073a,0x29000327,0x2bac01ef,0x00000000}},	//   pewo, _mjha_, _něc_, --, 
   {{0xdd903b07,0x3f841050,0x00000000,0x00000000}},	//   نوع_, rtnu_, --, --, 
   {{0x2902073b,0x3f86073c,0xa3d40073,0x3af401e1}},	//   _ojha_, stnu_, ाईक_, _lúpè_, 
   {{0xdb000306,0x7bc40108,0x00000000,0x00000000}},	//   dvlá, äjuo, --, --, 
   {{0x09c800cc,0x7e68013d,0x00000000,0x00000000}},	//   _লেলা, _tdgp, --, --, 
   {{0x2900020b,0x3f4003f0,0x9cfc03d4,0xdea0072d}},	//   _ajha_, _iñu_, ঁতেন_, _شیخی, 
   {{0xad887f51,0xdc6801c0,0x00000000,0x00000000}},	//   _فضول_, _далд_, --, --, 
   {{0x7c8402f6,0x00000000,0x00000000,0x00000000}},	//   _худе, --, --, --, 
   {{0xab94010a,0x4c90009b,0x00000000,0x00000000}},	//   _пăрк, _ријс, --, --, 
   {{0x9408013f,0xcf900a1e,0x7b080113,0x6ec008df}},	//   _mabɔ_, כטל_, yñuy, वायु, 
   {{0x3a206584,0x00000000,0x00000000,0x00000000}},	// [3b380] _uzip_, --, --, --, 
   {{0xb4e800af,0xf4bc00eb,0x00000000,0x00000000}},	//   यफे_, ঃস্ব, --, --, 
   {{0x3940bbd7,0xe3b401ec,0x00000000,0x00000000}},	//   _huis_, нұр_, --, --, 
   {{0x777c022e,0xd548868d,0x4e1c000d,0x00000000}},	//   murx, _ولجو_, _परलई_, --, 
   {{0x39400151,0x3f400113,0x777c0005,0x2004022e}},	//   _juis_, _añu_, lurx, _axli_, 
   {{0x3942073d,0x10c80150,0x00000000,0x00000000}},	//   _muis_, _ﺒﻠﺒﻨ, --, --, 
   {{0xdb000122,0x7f8001e2,0x00000000,0x00000000}},	//   zvlá, نلون, --, --, 
   {{0x39400393,0xb8d0031c,0x93242f84,0xdb00072b}},	//   _ouis_, _ནལ_, _آرسن, lvlæ, 
   {{0x394008cd,0x7c34016b,0x00000000,0x00000000}},	//   _nuis_, ɛbrɛ, --, --, 
   {{0x02000022,0x00000000,0x00000000,0x00000000}},	//   _рзун, --, --, --, 
   {{0x39400393,0xc47402e4,0x00000000,0x00000000}},	//   _auis_, ותיו_, --, --, 
   {{0x3942073e,0x2bac012c,0x00000000,0x00000000}},	//   _buis_, _věc_, --, --, 
   {{0x22480227,0x394008c2,0x9e640131,0xbea000c0}},	//   ñaki_, _cuis_, _سانن, _шацк, 
   {{0x39400483,0x0928007b,0x3d900117,0x00000000}},	//   _duis_, تسجي_, _ришр, --, 
   {{0x39400438,0xb64c01f2,0xe69407d8,0xbc78011a}},	//   _euis_, _ọtịt, нивы, _ונות, 
   {{0x3942073f,0x236c00df,0xa6340220,0xfa900208}},	//   _fuis_, _ĉej_, енбі, _hẫng_, 
   {{0x290000fb,0x394000e8,0x00000000,0x00000000}},	// [3b390] _tjha_, _guis_, --, --, 
   {{0x65149f21,0x39140022,0xdd3003e3,0x00000000}},	//   روائ, _имыр, _məşu, --, 
   {{0x68f60740,0x29120741,0x00000000,0x00000000}},	//   mizd, moza_, --, --, 
   {{0x29105809,0xdef4001f,0xe85410ef,0x27000064}},	//   loza_, ፎችን_, _تنگد, mėno_, 
   {{0x672e0742,0x27000064,0x00000000,0x00000000}},	//   mmaj, lėno_, --, --, 
   {{0x29120743,0x672e0744,0x68f443eb,0x60260745}},	//   noza_, lmaj, nizd, ндла, 
   {{0xcafc01f9,0x22584627,0x00000000,0x00000000}},	//   _उदंड_, _нивы_, --, --, 
   {{0xf8380d65,0x672e0746,0x942415bf,0x7bc40108}},	//   ונות_, nmaj, _سوقۇ, äjum, 
   {{0x291002ce,0x44200048,0xc0a83fe2,0x672c000d}},	//   koza_, _hzj_, _وائل_, imaj, 
   {{0x39420747,0x672ca057,0x29100810,0xa28001ed}},	//   _ruis_, hmaj, joza_, _شیڈو, 
   {{0x39420748,0xf0e8425b,0x29120749,0xdfd10748}},	//   _suis_, _تىلى_, doza_, _حيا_, 
   {{0x3942074a,0x672ded43,0x2ef402e8,0x6ec017ee}},	//   _puis_, jmaj, _изхр, वाणु, 
   {{0x3942074b,0x2910013e,0x19b80276,0x5cf40064}},	//   _quis_, foza_, чунь_, _пяку, 
   {{0x2912074c,0x777c056a,0x394005e4,0x68f401a9}},	//   goza_, turx, _vuis_, gizd, 
   {{0xd7040114,0x780400d1,0x00000000,0x00000000}},	//   езви, түна, --, --, 
   {{0x3942074d,0x777c056a,0xbbc800bc,0x672c010e}},	//   _tuis_, rurx, ाहीक, gmaj, 
   {{0x2912074e,0x777c0005,0x06040022,0x69a401af}},	// [3b3a0] boza_, surx, ентк_, _алыҡ, 
   {{0x9346074f,0x29120750,0x464401c6,0xc4800209}},	//   енже, coza_, _үзэн_, ллук, 
   {{0x672c01e4,0x777c0009,0x00000000,0x00000000}},	//   bmaj, qurx, --, --, 
   {{0xc7b002e4,0x672c00db,0x52260751,0x6378030d}},	//   _עבר_, cmaj, нфла, ьсур_, 
   {{0xc69000c8,0xa904036b,0xe6340153,0x00000000}},	//   _גאר_, _سبین, _ахрэ, --, 
   {{0x6aa82f8b,0xdb00007c,0xf424009d,0x814001e2}},	//   গাযো, lvlä, _азгү, دنون, 
   {{0xfe6c2ba5,0x00000000,0x00000000,0x00000000}},	//   ڭدى_, --, --, --, 
   {{0x29101459,0xb8ec025c,0x238800bc,0x14745f32}},	//   zoza_, _ྲོ_, žují_, _تاڭج, 
   {{0x29120752,0xfe6c40bb,0xa2dc00cd,0x00000000}},	//   yoza_, حدى_, पसर्, --, 
   {{0x29100472,0x00000000,0x00000000,0x00000000}},	//   xoza_, --, --, --, 
   {{0x672e0753,0x2910041a,0x68f5225e,0x7bf400c0}},	//   ymaj, voza_, vizd, енэр_, 
   {{0x7d000115,0x6b7c001f,0x29100a49,0x00000000}},	//   _ejns, _ተደረገ_, woza_, --, 
   {{0x2910f320,0xaca4063f,0x7ae80023,0xc5f80154}},	//   toza_, _arụz, ëjta, _আর্থ_, 
   {{0xddc802fb,0xdb000166,0x00000000,0x00000000}},	//   dceň, evlä, --, --, 
   {{0x672e0754,0x6f0002d0,0xab9c0092,0x32f800c0}},	//   tmaj, onmc, ሂደዋል_, nčys_, 
   {{0x29100796,0xe8d8110e,0x27000153,0x76a801d5}},	//   soza_, _iwọ_, rėno_, нтув_, 
   {{0x672e0755,0x2910f177,0x68f42230,0xe73825a2}},	// [3b3b0] rmaj, poza_, pizd, зең_, 
   {{0x29100944,0x672c912a,0xf3ec00fe,0x00000000}},	//   qoza_, smaj, _জুইৰ_, --, 
   {{0x672c014f,0x00000000,0x00000000,0x00000000}},	//   pmaj, --, --, --, 
   {{0xf40852c8,0xe8d002e5,0x672c0455,0x00000000}},	//   رينى_, _सकुच, qmaj, --, 
   {{0x21a447b3,0xf0b800f2,0x00000000,0x00000000}},	//   тилм, کانش_, --, --, 
   {{0x26c808ad,0xba0402d3,0x442001e3,0xddc8031c}},	//   ljao_, _ግዲ_, _tzj_, rgeż, 
   {{0xe8d801e1,0xdb00007c,0xd0040121,0xaf980108}},	//   _nwọ_, lvlå, кеше_, етых_, 
   {{0x26c80b91,0x8eb0104b,0xceb400fd,0xdea0036b}},	//   njao_, لمىش, кәч_, شیتی, 
   {{0xe8d80cad,0x2d0c01f9,0x00000000,0x00000000}},	//   _awọ_, सकूल_, --, --, 
   {{0xdc9867d7,0xf1080372,0x00000000,0x00000000}},	//   фтиш_, _كۉنۉ_, --, --, 
   {{0x2d980276,0x5e9400c6,0xef745024,0xad24143e}},	//   ărea_, _للاط, _مدنظ, دريو, 
   {{0x63b40fcf,0xdce8098d,0x9d2000bd,0xd94400db}},	//   _mrzn, kreć, নদেন_, кеми, 
   {{0x26c83421,0xfe2400c7,0x00000000,0x00000000}},	//   djao_, _џьен, --, --, 
   {{0x8c40c7f2,0xa3e01062,0x5fa4012c,0xc5f800cc}},	//   _кеше, धना_, _खनाल, _আৰ্থ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb0240051,0x00000000,0x00000000,0x00000000}},	//   ngườ, --, --, --, 
   {{0x66d03c12,0x63b60756,0x27ec00df,0x55880108}},	// [3b3c0] _påkr, _arzn, ĝena_, ьбам_, 
   {{0x5744023b,0x6f0400f3,0x09c800fe,0x00000000}},	//   _иноб, čici, _লেকা, --, 
   {{0x99d403e6,0x7bc40108,0x00000000,0x00000000}},	//   _ستکا, äjuh, --, --, 
   {{0x63b40219,0x00000000,0x00000000,0x00000000}},	//   _drzn, --, --, --, 
   {{0x6ec01d03,0x427002dd,0x66d0005c,0x00000000}},	//   वासु, ргіс, _tåkr, --, 
   {{0x224ca324,0xc9500302,0xc3240075,0xe3b001d3}},	//   _efek_, סמו_, ىكەن_, جرے_, 
   {{0x6fb438eb,0x80a00451,0x3f6108d1,0x836001b9}},	//   امبا, شمين, атыб, _نگنل, 
   {{0x753c01fa,0x52760757,0xebe00208,0x00000000}},	//   _hirz, _шугу, _ngườ_, --, 
   {{0x753c0036,0xd18402e8,0x6b980112,0x21740107}},	//   _kirz, _шлай, _spvg, _бухр, 
   {{0x8f7402bf,0x925801af,0x00000000,0x00000000}},	//   _ауді, _хаҡт_, --, --, 
   {{0x753e0758,0x4ea60759,0xb6900023,0x00000000}},	//   _mirz, _арла, _ምጽንሑ_, --, 
   {{0x753c030a,0x50f002e5,0xdc8000c7,0x00000000}},	//   _lirz, _अगुआ_, ақәо, --, 
   {{0xcd052aea,0xac9592b3,0xf1b46611,0x00000000}},	//   _ички, _балш, ूमिन, --, 
   {{0xfd0c00f2,0xc7b808ca,0x753c00ef,0x6ec02d81}},	//   _وجو_, мёб_, _nirz, वावु, 
   {{0x09c86569,0xcb0805f5,0xdd300213,0xfba4008e}},	//   _লেখা, _охид_, ləşi, _атый_, 
   {{0xdce816a3,0xd1e40092,0x00000000,0x00000000}},	//   treć, ማሁት_, --, --, 
   {{0x6aae075a,0xdd300213,0x00000000,0x00000000}},	// [3b3d0] _iaaf, nəşi, --, --, 
   {{0x6aae075b,0x35b40107,0x3b400092,0x00000000}},	//   _haaf, шбур, _ከተጀመ, --, 
   {{0xdce804b9,0x753e075c,0x6aaca1b1,0x67d6075d}},	//   sreć, _dirz, _kaaf, _сону, 
   {{0x6aae075e,0xdce8009b,0x71f80014,0xaf880092}},	//   _jaaf, preć, ھرنس_, ኙነትና_, 
   {{0x753d79ec,0x99740213,0xf03c0023,0x00000000}},	//   _firz, _məşq_, _ኣቀማም, --, 
   {{0x6aae075f,0x656e0760,0x753c05c7,0xe2c800f1}},	//   _laaf, msah, _girz, _ګورو_, 
   {{0x661e0761,0x673c7e9e,0xdca401d5,0x00000000}},	//   _hysk, _kisj, қани, --, 
   {{0x6aae0762,0x8c080c58,0xc1b00139,0xdb000036}},	//   _naaf, ৰধান_, _вәкы, rwlë, 
   {{0x656e0763,0x673e0764,0x661cee5a,0x712404da}},	//   nsah, _misj, _jysk, _چىقم, 
   {{0x661ccce0,0x656e0765,0x673e0766,0xdd100432}},	//   _mysk, isah, _lisj, _düşj, 
   {{0x9f541cb6,0x6aae0767,0x656e0768,0x004400ec}},	//   _свеч, _baaf, hsah, _ٻڌڻي_, 
   {{0x6aade5b7,0x3ab46d45,0x673e0769,0x656c0821}},	//   _caaf, рәкт, _nisj, ksah, 
   {{0x6dc4dd55,0x6aac01d9,0xdef8002e,0x00000000}},	//   _نزول, _daaf, miŋ_, --, 
   {{0x358c0f7c,0x656c0455,0x261c000d,0x00000000}},	//   ንደበት_, dsah, _मरजी_, --, 
   {{0x6aac2f06,0x661c06be,0xb8ed3f6b,0x9694024c}},	//   _faaf, _aysk, _रच_, лраш, 
   {{0x6aac0a4d,0x661e076a,0x656c003e,0xdef8002e}},	//   _gaaf, _bysk, fsah, niŋ_, 
   {{0x7ae6076b,0x673e076c,0x656e076d,0x753c0205}},	// [3b3e0] _ilit, _disj, gsah, _pirz, 
   {{0x661c068f,0x7ae400d2,0x0574007b,0x6aae076e}},	//   _dysk, _hlit, املة_, _zaaf, 
   {{0x656c8b14,0x753e076f,0x6aae0770,0x673e0771}},	//   asah, _virz, _yaaf, _fisj, 
   {{0x6aac331f,0x656e0772,0x7ae4020c,0x92c400b5}},	//   _xaaf, bsah, _jlit, _icるt, 
   {{0x7ae45a50,0x6fb800b8,0x753e0773,0x00000000}},	//   _mlit, ्मभू, _tirz, --, 
   {{0x7ae4038a,0x673c01c4,0x6acc00cc,0x044036dd}},	//   _llit, _zisj, াসযো, _герн, 
   {{0xfbc60774,0x7ae60775,0x661e0776,0xee440124}},	//   _ات_, _olit, _zysk, аҭеи, 
   {{0x7ae40066,0x6288007b,0xea98002b,0xaed40107}},	//   _nlit, _gceo, _dhṛ_, роиш, 
   {{0x6aad4e47,0x00000000,0x00000000,0x00000000}},	//   _raaf, --, --, --, 
   {{0x7ae60777,0x6aae0778,0xfd94009f,0x00000000}},	//   _alit, _saaf, ائيت_, --, 
   {{0x7ae60779,0x656c0232,0x447800c8,0x6aac0023}},	//   _blit, zsah, ענטע, _paaf, 
   {{0x7ae6077a,0x6aac102c,0xc9840aa8,0x656d8061}},	//   _clit, _qaaf, луги, ysah, 
   {{0x6aac0607,0x8d547825,0x7ae4007b,0x673c036e}},	//   _vaaf, _стеч, _dlit, _risj, 
   {{0x6aac2264,0x661ca9e3,0x7ae6077b,0x673e077c}},	//   _waaf, _rysk, _elit, _sisj, 
   {{0x661e077d,0x673c000f,0x6aae077e,0x27ec00df}},	//   _sysk, _pisj, _taaf, ĝeno_, 
   {{0x656e077f,0x661e0780,0x7b701365,0x49000228}},	//   tsah, _pysk, _اطوا, рүүг, 
   {{0x656d0601,0x673d161c,0x64a40032,0x69c42f89}},	// [3b3f0] usah, _visj, һаҡа, _төнб, 
   {{0x656e0781,0x661e0782,0x7ae40427,0x6288e048}},	//   rsah, _vysk, _zlit, _sceo, 
   {{0x7ae402f6,0x3494035b,0x661c033f,0x673c0135}},	//   _ylit, сахр, _wysk, _tisj, 
   {{0x661c00ed,0x82344667,0x656c023a,0xa15a0783}},	//   _tysk, هرشا, psah, ваду_, 
   {{0x656c0067,0x00000000,0x00000000,0x00000000}},	//   qsah, --, --, --, 
   {{0xc64400f7,0xdb000036,0x00000000,0x00000000}},	//   _جئگى, rwlé, --, --, 
   {{0xa3d47a16,0xc2b005a2,0xdef8002e,0x00000000}},	//   _товч, _гөлш, tiŋ_, --, 
   {{0x1d940107,0x6d500248,0x00000000,0x00000000}},	//   ароё, _ẹlẹw, --, --, 
   {{0x7ae40004,0x225c0399,0x41e41cb8,0x00000000}},	//   _rlit, mbwk_, _сіва, --, 
   {{0x7ae417c0,0xdd940124,0x00000000,0x00000000}},	//   _slit, гаҩы, --, --, 
   {{0x7ae60784,0x9b04188b,0x5ab80327,0xe51c000d}},	//   _plit, изод, _བོདམ, _बीछि_, 
   {{0xde5802bf,0x9df80580,0x00000000,0x00000000}},	//   _раді_, _инет_, --, --, 
   {{0xd9460785,0x7ae40010,0x5d78010f,0x00000000}},	//   реги, _vlit, _סאַק, --, 
   {{0x3c4405f5,0x7ae4b918,0x3eac03b2,0x00000000}},	//   _сэдв, _wlit, _hagt_, --, 
   {{0x7ae60786,0x1ae4014b,0x00000000,0x00000000}},	//   _tlit, _войм, --, --, 
   {{0x3eac04ce,0x00000000,0x00000000,0x00000000}},	//   _jagt_, --, --, --, 
  
   {{0x3eac037e,0x0aa401ec,0x787008a5,0x00000000}},	// [3b400] _magt_, _тұяқ_, góví, --, 
   {{0xa3e00b7c,0x3a200432,0x75440022,0x00000000}},	//   धनं_, _iyip_, _ҳҽаз, --, 
   {{0x3a2093fc,0xba48010e,0xd7083cc5,0x00000000}},	//   _hyip_, _geįý, _анне_, --, 
   {{0x96960787,0xe8e001fb,0x5275a804,0x3eac00ee}},	//   _трош, _đứt_, ружу, _nagt_, 
   {{0xdce800d7,0x00000000,0x00000000,0x00000000}},	//   eseč, --, --, --, 
   {{0xd3940131,0x9878010f,0x00000000,0x00000000}},	//   _вәдә_, דאַט, --, --, 
   {{0x3eae0788,0x4fc60789,0x8ea00131,0x4ea50335}},	//   _bagt_, рсла, قلغۇ, арпа, 
   {{0x14740150,0x74c400cd,0xd1740024,0x93140244}},	//   _حاڭج, रावृ, _выжы, _ئورش, 
   {{0x04f803d4,0x00000000,0x00000000,0x00000000}},	//   ্তৰৰ_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3a22078a,0x00000000,0x00000000,0x00000000}},	//   _ayip_, --, --, --, 
   {{0xc4d002c3,0x00000000,0x00000000,0x00000000}},	//   _दक्ख, --, --, --, 
   {{0x5ab402dd,0x00000000,0x00000000,0x00000000}},	//   сқыр_, --, --, --, 
   {{0x2d86078b,0x3a2022d0,0xcb440354,0x67d400cf}},	//   mume_, _dyip_, _кхии, богу, 
   {{0x8b6400d1,0x7bc401f4,0x4b8c010a,0x00000000}},	//   _ئاتم, äjut, _цιен_, --, 
   {{0x20d8180f,0x7c38011a,0xb6c42639,0x00000000}},	//   _hèit_, _בתוס, осуй, --, 
   {{0x2d86078c,0x68e40770,0x612c00d2,0xfc4400bc}},	// [3b410] nume_, _tlhd, lúle, říň_, 
   {{0x69dc2a8a,0x2a68003e,0x478400f7,0x2d84067c}},	//   myse, _heab_, _кымб, iume_, 
   {{0x2d85b85a,0x34492269,0xe7b41291,0x82a401d5}},	//   hume_, рчун_, _امجد, ишде, 
   {{0x20d8067c,0x3fc40244,0x6594010a,0x00000000}},	//   _lèit_, یگای_, _ламу, --, 
   {{0x2d84faf7,0xdafc0004,0x3eac002f,0xf1a93ecd}},	//   jume_, tãºb, _ragt_, لاوه_, 
   {{0x2d8461b5,0x2a680e89,0x25a80af9,0xf48401a9}},	//   dume_, _leab_, mwal_, _мусн, 
   {{0x25a80067,0x6e2c013f,0xe9f80022,0x69dc017a}},	//   lwal_, ɑnbɑ, _raẽ_, hyse, 
   {{0x2d86078d,0x6306078e,0x00000000,0x00000000}},	//   fume_, _اورل, --, --, 
   {{0x2d86078f,0x25aa0790,0x31640399,0xdafc0589}},	//   gume_, nwal_, _gwmz_, pãºb, 
   {{0x3eac09a5,0xb3240003,0x25a800e8,0x5ba80108}},	//   _wagt_, _འཚོང_, iwal_, гком_, 
   {{0x2d841497,0x25a800b5,0xdce800df,0x3f8000e4}},	//   aume_, hwal_, creĝ, _êju_, 
   {{0x2d860791,0x2a680076,0x25a802a8,0x69dc0fac}},	//   bume_, _ceab_, kwal_, fyse, 
   {{0x2d860792,0x2a680076,0xddd8007f,0xdd90004b}},	//   cume_, _deab_, _sewņ, _روغ_, 
   {{0x25a96a05,0x612c00d2,0x3c800014,0x1d083da1}},	//   dwal_, búle, _بیدٲ, _щели_, 
   {{0x69dc0076,0xacf458c5,0x25a800e8,0xb7f800cc}},	//   ayse, _بسنت, ewal_, _আঁহত_, 
   {{0x973401c0,0x4c900139,0xd1480055,0x9c800116}},	//   сэгч, _диәс, _lṅa_, _بۇگۈ, 
   {{0x63440006,0xceb0008f,0x56280798,0x69c80108}},	// [3b420] _mėnu, הין_, ужам_, äeet, 
   {{0xf4843c46,0x3a8401d9,0x95b40124,0x00000000}},	//   تاری, _اُکہ, ирҕә, --, 
   {{0x4938025f,0x20d80ba1,0x3ce4005a,0x03a00c60}},	//   _תגיו, _lèis_, _mlnv_, зихо, 
   {{0xd5486f33,0xd20801c0,0x25a80083,0x2d8404ce}},	//   _مجسم_, лэлд_, bwal_, yume_, 
   {{0x527400c2,0x2d855a00,0xf4840345,0x00000000}},	//   _ҳузу, xume_, _واسی, --, 
   {{0xfd060793,0x2d840028,0xdec002d3,0xc6a40014}},	//   _رج_, vume_, ድዳእ_, _پگہٕ_, 
   {{0x22481225,0x2d8506cc,0x3f640063,0x5274004e}},	//   žaka_, wume_, бијо_, _гузу, 
   {{0x2d860794,0xdce801e4,0x00000000,0x00000000}},	//   tume_, rreĝ, --, --, 
   {{0xe1ec00b2,0x2d840200,0xdd8c00e5,0x86780677}},	//   _لڳو_, uume_, نڈو_, ארפו, 
   {{0x2d860795,0x2a680037,0x69dd5aa6,0x6b7400fb}},	//   rume_, _seab_, vyse, олоу, 
   {{0x2a68033d,0x69dd3cd6,0x2d85bd10,0x005404ae}},	//   _peab_, wyse, sume_, _השבת_, 
   {{0x69de0796,0x612c008c,0x2d8402ce,0xbb900c9e}},	//   tyse, rúle, pume_, чающ, 
   {{0x2d840944,0x20d8067c,0x2a680037,0x25a8002e}},	//   qume_, _gèis_, _veab_, xwal_, 
   {{0xc6a40372,0x20d80ba1,0x25a8007f,0x20340023}},	//   өрби, _uèit_, vwal_, _ብሕብረ, 
   {{0x25aa0797,0x2a6800af,0x3cf80375,0x00000000}},	//   wwal_, _teab_, _תלונ, --, 
   {{0x25aa0798,0x00000000,0x00000000,0x00000000}},	//   twal_, --, --, --, 
   {{0x84444630,0x862402d5,0x00000000,0x00000000}},	// [3b430] مخال, сьве, --, --, 
   {{0xf99000c6,0xd1dc001f,0x03c4c502,0x34941cd0}},	//   _أبي_, ናነት_, йсем, зафр, 
   {{0x25a84cd3,0x4cb00154,0xdce80135,0x00000000}},	//   swal_, জাপু, nteġ, --, 
   {{0x2bb01a22,0x68e0553f,0x00000000,0x00000000}},	//   _जनना, öldf, --, --, 
   {{0xe044006c,0x7ae802d3,0xa06a0799,0x611400db}},	//   онли, ëjti, аала_, одду, 
   {{0xf77004d3,0x20d8068c,0x6b28025c,0x00000000}},	//   _تای_, _rèis_, _ལེའོ_, --, 
   {{0x1ec85332,0x9f640213,0xb07400ec,0xa51401f9}},	//   илки_, _ötür_, سپيڪ, तकीच_, 
   {{0x4ce000eb,0x00000000,0x00000000,0x00000000}},	//   _পদগু, --, --, --, 
   {{0x80880592,0x44200240,0x4cb00154,0x00000000}},	//   _مضاف_, _hyj_, জানু, --, 
   {{0x6298017a,0x00000000,0x00000000,0x00000000}},	//   lfwo, --, --, --, 
   {{0x4422079a,0xaf040014,0x00000000,0x00000000}},	//   _jyj_, _کون٘, --, --, 
   {{0x629802e2,0xdce803e0,0x9af8009b,0xa3a0002b}},	//   nfwo, breğ, рхоф_, _śaśī_, 
   {{0x3f86079b,0x64540036,0x00000000,0x00000000}},	//   lunu_, _ofzi, --, --, 
   {{0x4420005b,0xad240137,0xcc640372,0x00000000}},	//   _oyj_, _ىروو, _ۇنۇۋ, --, 
   {{0x3f86079c,0x80b400bc,0x00000000,0x00000000}},	//   nunu_, _आफैं, --, --, 
   {{0x7c280640,0x64540d27,0x2b580118,0xea9800b8}},	//   đorđ, _afzi, írce_, _viṣ_, 
   {{0x3f84013b,0x7c20138f,0x95c807d6,0x7e69b048}},	// [3b440] hunu_, _hynr, шлаб_, _megp, 
   {{0x3f86079d,0x7c2006a3,0x3ddc0086,0x188856e0}},	//   kunu_, _kynr, iyuw_, _өсүп_, 
   {{0x6298030d,0x3f86079e,0xe8e8004b,0x926a079f}},	//   ffwo, junu_, _دريو_, арла_, 
   {{0x3f8607a0,0x7c200363,0xd1b00d73,0xdce80790}},	//   dunu_, _mynr, ویزک, yreğ, 
   {{0x44200174,0x7c2207a1,0x2bb017ee,0x68e05f47}},	//   _eyj_, _lynr, _जनभा, öldg, 
   {{0x3f8607a2,0xc0e0ef04,0x44200175,0xdce803e0}},	//   funu_, мочк, _fyj_, vreğ, 
   {{0x3f8607a3,0x44200789,0x20d8068c,0xdce800f3}},	//   gunu_, _gyj_, _pèir_, jređ, 
   {{0xdce81b24,0xa2c00118,0xaee40055,0x00000000}},	//   dređ, _रोप्, daṃp, --, 
   {{0xddc80276,0xd1480055,0x60cc012d,0x7e6800de}},	//   rbeş, _iṅo_, _łomż, _degp, 
   {{0x7c2006a3,0x7e6802b9,0x8fa607a4,0xdd9207a5}},	//   _bynr, _eegp, _мазе, روپ_, 
   {{0x3f8607a6,0x7c2000a9,0xac180117,0x98bc033f}},	//   cunu_, _cynr, сону_, एएनए, 
   {{0xdce80327,0x00000000,0x00000000,0x00000000}},	//   rteġ, --, --, --, 
   {{0x6f00014f,0x4cb000cc,0x7e98011a,0xdce80327}},	//   mimc, জাবু, _כסאו, steġ, 
   {{0x6f0207a7,0x61fc00a2,0xf1d800cc,0x67d400cf}},	//   limc, _ýsle, _দেৱভ, погу, 
   {{0x46680a83,0x7c200368,0x7e680810,0x612c0332}},	//   ирам_, _gynr, _yegp, núla, 
   {{0x6f00036b,0xca7800d1,0x44200210,0x00000000}},	//   nimc, ﻣﻤﻪﺩ_, _ryj_, --, 
   {{0x3f8607a8,0x6b8800b5,0x612c00ae,0x00000000}},	// [3b450] zunu_, ludg, húla, --, 
   {{0x6f000c09,0xb9a400dd,0x612c022c,0x3f84029f}},	//   himc, _کمیٹ, kúla, yunu_, 
   {{0x3f8607a9,0x6b882283,0x6f000166,0x00000000}},	//   xunu_, nudg, kimc, --, 
   {{0x612c00ae,0x00000000,0x00000000,0x00000000}},	//   dúla, --, --, --, 
   {{0x7e6801e4,0xdce8009b,0xdb100c6a,0x4ae01a04}},	//   _regp, zređ, égél, _पवनव, 
   {{0x3f8607aa,0x26da07ab,0xd58403e6,0x00000000}},	//   tunu_, _hoso_, _رێمه_, --, 
   {{0x26d9dab5,0x6b88036b,0x612c0005,0x442000a2}},	//   _koso_, judg, gúla, _uyj_, 
   {{0xdce8026a,0x3f8607ac,0x26d801a6,0x6f00004e}},	//   vređ, runu_, _joso_, gimc, 
   {{0x26da07ad,0x3f8607ae,0x7c200652,0x7e682dba}},	//   _moso_, sunu_, _synr, _vegp, 
   {{0x26d8014c,0x7c200652,0x5c146afe,0xc0b80131}},	//   _loso_, _pynr, зьму, ﻠﻠﻪﺗ, 
   {{0x6f0004b9,0xdce82804,0x612ce851,0x7e680477}},	//   bimc, uređ, cúla, _tegp, 
   {{0x26da07af,0x7c20062c,0x6f000205,0x15880116}},	//   _noso_, _vynr, cimc, _ﻗﻪﺑﯩ, 
   {{0xaee40882,0x3f740311,0x7c2062f1,0xdce816a3}},	//   saṃp, lău_, _wynr, sređ, 
   {{0xdce8597f,0x26d80b23,0x7c2006a3,0xe8e0001e}},	//   pređ, _aoso_, _tynr, _đợt_, 
   {{0x26da07b0,0xb8e4000b,0x01c004c5,0x3f740276}},	//   _boso_, _एफ_, ্নিদ, nău_, 
   {{0x26d90cdc,0x2bb00316,0x3f7400e4,0x4b78011a}},	//   _coso_, _जनता, g̃ui_, _האקו, 
   {{0x26da07b1,0x00000000,0x00000000,0x00000000}},	// [3b460] _doso_, --, --, --, 
   {{0x5fbc1b2b,0x644800ac,0x6f0076b7,0xd468010b}},	//   ्माल, _şeir, zimc, сиже_, 
   {{0x779607b2,0x26d80270,0x68e1377a,0x6f00009a}},	//   _تیزا, _foso_, ölde, yimc, 
   {{0x6f0207b3,0x27e40158,0x8b54010f,0x3f740356}},	//   ximc, ølne_, ליעס_, dău_, 
   {{0xf19607b4,0xa650105d,0xd9a800bc,0x415000d4}},	//   филь, _شێلت, _छनोट, евіс, 
   {{0x612e07b5,0x26d80356,0x92bc0154,0x4f680108}},	//   túla, _zoso_, েসে_, бшим_, 
   {{0x6f0207b6,0x26d8007f,0x620403b9,0x00000000}},	//   timc, _yoso_, _ərlə, --, 
   {{0x74c40f4c,0xc7b00302,0x044056ac,0x612c007b}},	//   राकृ, תבה_, _чесн, rúla, 
   {{0x6f0207b7,0x612d36e8,0x520801f7,0x00000000}},	//   rimc, súla, _ايءُ_, --, 
   {{0x612c00d2,0x3f740356,0x6b8801bf,0xfc6207b8}},	//   púla, bău_, tudg, нъюн, 
   {{0x3f740276,0x6f000205,0x00000000,0x00000000}},	//   cău_, pimc, --, --, 
   {{0x6b89f35f,0x6f00047e,0x00000000,0x00000000}},	//   rudg, qimc, --, --, 
   {{0x26da07b9,0x6b8800b5,0xdce8031c,0x00000000}},	//   _roso_, sudg, xteħ, --, 
   {{0x26da07ba,0x7d540302,0x7d7800d9,0x00000000}},	//   _soso_, _ציוד_, _פרוג, --, 
   {{0x26d8df1a,0xaa5c02dd,0x00000000,0x00000000}},	//   _poso_, _кейi, --, --, 
   {{0xf7702ad5,0x26d801e0,0x0ae8009f,0x36d42901}},	//   طاف_, _qoso_, _درتي_, носр, 
   {{0xf65207bb,0x26d81709,0x3f740276,0x2b5c0051}},	// [3b470] ائف_, _voso_, zău_, _htvc_, 
   {{0x2d8400ae,0x26d80241,0x74c41a47,0x00000000}},	//   irme_, _woso_, रागृ, --, 
   {{0x26da07bc,0x00000000,0x00000000,0x00000000}},	//   _toso_, --, --, --, 
   {{0xe2980212,0xf0e800d1,0xf31401c4,0x00000000}},	//   іал_, ۋىنى_, ндхэ, --, 
   {{0xe8d800b4,0x25ac07c5,0x20d402bf,0xc5f400cc}},	//   _ntị_, _èel_, дійс, _অঁকা_, 
   {{0x10a0119e,0x3f740356,0x60243dad,0x00000000}},	//   вишн, tău_, мдла, --, 
   {{0x2d8404d4,0xd24c01d3,0x2b1c00c5,0xa4640023}},	//   erme_, اچہ_, नवाँ_, _ጎስጓስ, 
   {{0x3f740311,0xd344006c,0x71f80066,0x00000000}},	//   rău_, _قیله_, _کرفس_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfa542099,0x00000000,0x00000000,0x00000000}},	//   کردگ, --, --, --, 
   {{0x2d8607bd,0x8eb001ed,0x307800c6,0xdfd207be}},	//   arme_, رمیش, _رحلة_, _جيا_, 
   {{0xcf441884,0xcf9000df,0x00000000,0x00000000}},	//   _قىلۋ, _יטב_, --, --, 
   {{0x3da40815,0x00000000,0x00000000,0x00000000}},	//   _хреб, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8cb00073,0x00000000,0x00000000,0x00000000}},	//   _असतो, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xcb10025f,0x63a801fa,0xdd98007f,0xcb34010f}},	// [3b480] _שלח_, _ćena, ntň_, _קאפי_, 
   {{0xc48002e8,0x00000000,0x00000000,0x00000000}},	//   клук, --, --, --, 
   {{0x48e001f9,0x00000000,0x00000000,0x00000000}},	//   _ऐकतो_, --, --, --, 
   {{0x81d402f5,0x27ec01e4,0x55e401d5,0x2bb02072}},	//   ানন_, ĝent_, _жомб, _जनसा, 
   {{0x758458ae,0x6fc0072e,0xdecc0023,0x00000000}},	//   _سیام, विभू, እኑን_, --, 
   {{0x572402dd,0x8838001f,0x00000000,0x00000000}},	//   _ءىڭك, _በስብሰ, --, --, 
   {{0xd2500214,0x00000000,0x00000000,0x00000000}},	//   _لنز_, --, --, --, 
   {{0x8778008f,0x02c001a9,0x00000000,0x00000000}},	//   קאפי, _ийсо, --, --, 
   {{0x6458068f,0x0ca822ff,0x2d84030a,0x0c8404b4}},	//   świe, отни_, urme_, мынм, 
   {{0x0080724a,0x2d84036e,0x00000000,0x00000000}},	//   _алфо, rrme_, --, --, 
   {{0xaa95ccc0,0x1ee81888,0x00000000,0x00000000}},	//   нинч, زویی_, --, --, 
   {{0xe8540092,0x00000000,0x00000000,0x00000000}},	//   ዋዕትነ, --, --, --, 
   {{0x2bb0060c,0x8fa40022,0x00000000,0x00000000}},	//   _जनवा, _хаҵе, --, --, 
   {{0x3cf4007b,0x00000000,0x00000000,0x00000000}},	//   _يعود_, --, --, --, 
   {{0x5e3001d3,0x57a401e0,0xad240145,0x2cac0042}},	//   _لڑیا, нытҡ, _قىچى, medd_, 
   {{0x2cae07bf,0xe8d8063f,0x00000000,0x00000000}},	//   ledd_, _itọ_, --, --, 
   {{0x2cac0cfd,0x057404fb,0xa5351740,0x19c00075}},	// [3b490] oedd_, بازد, енач, _йәрг, 
   {{0x2cac00a9,0x4428009b,0x00000000,0x00000000}},	//   nedd_, оцем_, --, --, 
   {{0x29000790,0x3494004e,0x91c00131,0x00000000}},	//   _imha_, тахр, қәтл, --, 
   {{0x2cac0cfd,0xc6a407d6,0x00000000,0x00000000}},	//   hedd_, _ўрни, --, --, 
   {{0x21686baf,0x29000098,0xa0a5106d,0x56f00139}},	//   чили_, _kmha_, еалд, _сүтс, 
   {{0x2cac168c,0x2b4807de,0x1fb42d3c,0x98b80153}},	//   jedd_, _liac_, есир, _tipą_, 
   {{0x2cac0368,0xdfd03b89,0x5f440131,0x2b480356}},	//   dedd_, ايع_, ىنتل, _oiac_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe8d805db,0x2cac0368,0x7fb006be,0x1d0800d4}},	//   _atọ_, fedd_, _məqə, зепи_, 
   {{0x0d80652e,0x2cacf281,0x71f80014,0x7fb00213}},	//   ыльн, gedd_, _کرہس_, _ləqə, 
   {{0xad24009f,0x543800df,0x00000000,0x00000000}},	//   خريو, ּערא, --, --, 
   {{0x290207c0,0x7fb006be,0xcf54011a,0xa3ac0037}},	//   _amha_, _nəqə, _טבעת_, _कनई_, 
   {{0x38c82be7,0x2b48030a,0x690805be,0x2cae07c1}},	//   واسی_, _diac_, džeb, bedd_, 
   {{0xdce80063,0x80bc015b,0x3f8419f5,0x4dd800d9}},	//   dseć, ্সক্, ornu_, _מחנו, 
   {{0x07a207c2,0x2b4805d5,0xc7a00022,0x68e001a8}},	//   ларн, _fiac_, лирк, ölda, 
   {{0x224c97a8,0x2900003e,0x2b48004d,0xac10030d}},	//   _ngek_, _emha_, _giac_, _тĕсе_, 
   {{0x3f8413d5,0xd5480330,0x00000000,0x00000000}},	// [3b4a0] hrnu_, سلاو_, --, --, 
   {{0x224c020c,0x7bc0022e,0x3f84020c,0x5f1400cc}},	//   _agek_, _krnu, krnu_, াতিও_, 
   {{0x7fb003e3,0x245401e1,0x52840304,0x00000000}},	//   _fəqə, _súmó_, егеб, --, 
   {{0xe3b001d3,0x00000000,0x00000000,0x00000000}},	//   گرے_, --, --, --, 
   {{0x7544035b,0x29000142,0x2cac03cb,0x00000000}},	//   _аҽаз, _ymha_, yedd_, --, 
   {{0xab680327,0x7bc000ee,0x00000000,0x00000000}},	//   _heżż, _ornu, --, --, 
   {{0xbfa40108,0x00000000,0x00000000,0x00000000}},	//   етые_, --, --, --, 
   {{0x2cac0cfd,0x81ac00bd,0x43406c00,0x00000000}},	//   wedd_, _ওপর_, _бесв, --, 
   {{0x10a5776b,0x3f8405a1,0xcd04bf77,0xab68031c}},	//   _пиан, arnu_, ечни, _meżż, 
   {{0x3f8408a4,0x00000000,0x00000000,0x00000000}},	//   brnu_, --, --, --, 
   {{0x2cacc460,0x2b4801d3,0xfd9400f2,0x00000000}},	//   redd_, _piac_, وئیت_, --, 
   {{0x0dc40020,0x2cacc460,0x388002d3,0xe8c800cd}},	//   ጽሐፍ_, sedd_, _ክምለሱ_, िञ्च, 
   {{0x2b483351,0x7bc020ac,0x7fb000ac,0x1ee803e6}},	//   _viac_, _ernu, _rəqə, _زووی_, 
   {{0xdecc0023,0xf99001f7,0x7fb006be,0xbed00051}},	//   _እምነ_, حبَ_, _səqə, _từch, 
   {{0xab680327,0x9418013f,0x612c002d,0xfc5401e4}},	//   _beżż, repɛ_, fúlj, _אבוש_, 
   {{0x81d42158,0xfaa400f3,0x00000000,0x00000000}},	//   ানত_, _баћо, --, --, 
   {{0x06b00154,0x651401d3,0x7bc00055,0x00000000}},	// [3b4b0] ঙালি, پوائ, _zrnu, --, 
   {{0x6abe07c3,0x290207c4,0x3f840008,0x34944eb1}},	//   ldsf, _umha_, yrnu_, лаур, 
   {{0x291000ca,0xfa340517,0xa714109a,0x00000000}},	//   mnza_, _لرید, _амні, --, 
   {{0x64400407,0x6568ed17,0xdef40092,0x00000000}},	//   _úlim, _çeho, ጎችን_, --, 
   {{0x672e07c5,0x6abc0b4f,0xa3ac0c6f,0xf6e40006}},	//   mlaj, idsf, _कनक_, _сцэн, 
   {{0x91e1e887,0x291000ca,0xa2c007f7,0xb0e802dd}},	//   роше, nnza_, _रोर्, ндіз_, 
   {{0x02a40953,0x291004ba,0xf43607c6,0x672e07c7}},	//   _прам, inza_, _берэ, olaj, 
   {{0x672e07c8,0xe2c81129,0xdecc02d3,0x6abc037e}},	//   nlaj, _تورو_, _እምኒ_, jdsf, 
   {{0x3f8401fa,0x657c00b5,0x6abc9596,0x00000000}},	//   srnu_, _jvsh, ddsf, --, 
   {{0x7bc001fa,0x81c4005f,0x6abc017a,0x672e07c9}},	//   _prnu, rvēģ, edsf, hlaj, 
   {{0x672e07ca,0x28d48004,0x00000000,0x00000000}},	//   klaj, दानि, --, --, 
   {{0x291207cb,0x00000000,0x00000000,0x00000000}},	//   enza_, --, --, --, 
   {{0x6b88022e,0x672c33c8,0x00000000,0x00000000}},	//   ardg, dlaj, --, --, 
   {{0x7bc00010,0x672c0210,0x00000000,0x00000000}},	//   _trnu, elaj, --, --, 
   {{0x7bc207cc,0x7bc4003a,0x969607cd,0x83d000d1}},	//   _urnu, æjud, краш, ﯟﯦﺮﺳ, 
   {{0x2911181f,0xa2c00316,0x80bc0154,0x00000000}},	//   anza_, _रोल्, ্সট্, --, 
   {{0x657c003e,0x7f4801b3,0x2910009a,0xa2d400dc}},	// [3b4c0] _cvsh, _migq, bnza_, णान्, 
   {{0x81d403f4,0x657c02c4,0x7f482d2f,0x446206cd}},	//   ানা_, _dvsh, _ligq, ивув, 
   {{0x672e07ce,0x1fbc0034,0x38792fde,0x00000000}},	//   blaj, ्मोड, marr_, --, 
   {{0x7f480921,0x672c04cf,0x518607cf,0x1dd039c5}},	//   _nigq, claj, вука, तमात, 
   {{0x51f607d0,0x6458068f,0x7d0005ac,0xc6900a7c}},	//   خسار, świa, _omns, _דאר_, 
   {{0x28d42efd,0x00000000,0x00000000,0x00000000}},	//   दायि, --, --, --, 
   {{0x6abc005c,0xc0e000f0,0x00000000,0x00000000}},	//   ydsf, ројк, --, --, 
   {{0x30c40154,0x387801e7,0x00000000,0x00000000}},	//   ্সেস, harr_, --, --, 
   {{0x6abc45a7,0x7de401e1,0x00000000,0x00000000}},	//   vdsf, _résú, --, --, 
   {{0x3878036e,0x0ca801f0,0x00000000,0x00000000}},	//   jarr_, фтии_, --, --, 
   {{0x09c800dc,0x672c467c,0x4f940798,0x00000000}},	//   ाम्य, ylaj, _шрау, --, 
   {{0x6abc0036,0x4e0400d8,0xc0cc0092,0x4e78114f}},	//   udsf, _изеб, ጣጠረ_, _آحاد_, 
   {{0x6abc4cab,0x29100083,0x00000000,0x00000000}},	//   rdsf, tnza_, --, --, 
   {{0x7f484242,0x291207d1,0xac183660,0x387a07d2}},	//   _zigq, unza_, _полу_, garr_, 
   {{0x2f282776,0x7f480b6f,0x6eb81b61,0x672e07d3}},	//   _gïgî_, _yigq, ्यपु, tlaj, 
   {{0x6608008c,0x368a07d4,0x2cbc75f9,0x8660074d}},	//   _þekk, ксун_, _havd_, рнаç, 
   {{0xe7380184,0x672e07d5,0xd730001f,0x3879168d}},	// [3b4d0] дең_, rlaj, _በእምነ, barr_, 
   {{0x672e07d6,0xa7b80124,0x387801ab,0xdecc0023}},	//   slaj, _злоу_, carr_, _እዝን_, 
   {{0x672cd033,0x2cbc0076,0xb4ac033f,0x00000000}},	//   plaj, _mavd_, कड़े_, --, 
   {{0x657ca949,0xfbc000dc,0x672c10f2,0x94240137}},	//   _tvsh, षितम, qlaj, دومۇ, 
   {{0x6eb800dc,0xaaa4197c,0x00000000,0x00000000}},	//   ्यनु, ग्यक, --, --, 
   {{0x7f486e0e,0x00000000,0x00000000,0x00000000}},	//   _sigq, --, --, --, 
   {{0x4ac01fbc,0x645003e0,0x00000000,0x00000000}},	//   षयाव, ğdiğ, --, --, 
   {{0x387a07d7,0xf838025f,0x25b803b2,0x00000000}},	//   zarr_, כנות_, _kssl_, --, 
   {{0x2f28145e,0x1d2428e5,0x00000000,0x00000000}},	//   _sïgî_, лмим, --, --, 
   {{0x612c06ea,0x3ba01171,0x00000000,0x00000000}},	//   kúli, алоҳ, --, --, 
   {{0xf0e80a52,0x92b40183,0x6f740451,0x6dc401d5}},	//   _جىلى_, জাৰ_, _نانء, هزیل, 
   {{0x22482f61,0x38780295,0xb4e00950,0x00000000}},	//   žaku_, warr_, _तव्_, --, 
   {{0xdca49fc7,0x5ca40228,0xc0cc0020,0x387a07d8}},	//   _бали, _билб, ጣጠር_, tarr_, 
   {{0x7d000117,0x394c0267,0x3ebe07d9,0x00000000}},	//   _umns, öds_, ldut_, --, 
   {{0x387801ab,0x3ebc0254,0x1ce000e5,0x00000000}},	//   rarr_, odut_, _نےکہ, --, 
   {{0x3804013e,0x25b802d2,0x76440022,0x00000000}},	//   гоҳҳ, _bssl_, иҭна, --, 
   {{0x80b0032c,0xda08c1d7,0x3ebc005b,0xfaa4059f}},	// [3b4e0] ंजाइ, _سيده_, idut_, _бақо, 
   {{0x690a07da,0x9964008e,0x38780135,0x3ebc01f4}},	//   lžen, _итүл, qarr_, hdut_, 
   {{0x6eb800cd,0x7ad80073,0x00000000,0x00000000}},	//   ्यमु, यापॅ, --, --, 
   {{0x3ebe07db,0x00000000,0x00000000,0x00000000}},	//   jdut_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb40559a3,0x3ebc01f4,0x7ae001e3,0x00000000}},	//   _күзд, edut_, ömtj, --, 
   {{0xcfa41a51,0x00000000,0x00000000,0x00000000}},	//   ушли, --, --, --, 
   {{0x660805be,0x1475a7d9,0x00000000,0x00000000}},	//   _žeki, _جاڭج, --, --, 
   {{0x1fa40323,0x69080cf4,0x4ea40220,0x118800e5}},	//   грөг, džen, _ұрла, _سپاٹ_, 
   {{0x8f7410f5,0xdce801a2,0x9b2400b8,0x00000000}},	//   _буді, ateľ, _ṣṭāk, --, 
   {{0xac18e78a,0x0ba842c6,0xdecc02d3,0x68e001a8}},	//   тону_, رادى_, _እዝኒ_, öldm, 
   {{0xaa9407d6,0x249c013f,0x1ea80451,0x7800012d}},	//   шимч, ɑwmu_, _لاهي_, ोपैक_, 
   {{0xa2d4243c,0xdce80115,0x2bb000cd,0x80b8000d}},	//   णात्, lseĝ, _जनका, _एसमे, 
   {{0x25b80810,0x612c0798,0x290607dc,0xa2700023}},	//   _rssl_, túli, òla_, ብትናን_, 
   {{0x8ae40064,0x00000000,0x00000000,0x00000000}},	//   _біпл, --, --, --, 
   {{0x612c022c,0x260c01e4,0x888001e0,0x9b940244}},	//   rúli, _pɾo_, шғүл, _ئاوڵ, 
   {{0x65952042,0x28d400dc,0xe498008e,0x7d1000e4}},	// [3b4f0] разу, दादि, ккач_, _ñesã, 
   {{0x753c1afd,0xdce801e4,0xa77607dd,0x6fb40073}},	//   _chrz, kseĝ, _клоч, ंबां, 
   {{0x67d40075,0x3ebc0205,0x00000000,0x00000000}},	//   _тону, ydut_, --, --, 
   {{0x659402d5,0x00000000,0x00000000,0x00000000}},	//   _каму, --, --, --, 
   {{0x983c0020,0xb6c607de,0x3ebc0135,0x00000000}},	//   _በስተቀ, _усэй, vdut_, --, 
   {{0xc05800d6,0x6704016c,0xdd0001f1,0x00000000}},	//   хід_, _сӯҳб, _ľuďo, --, 
   {{0x3ebc089c,0xdce801e4,0x14d000dc,0x66e8000d}},	//   tdut_, gseĝ, सारण, _टकाक_, 
   {{0x3ebc0108,0x753c01ef,0x00000000,0x00000000}},	//   udut_, _zhrz, --, --, 
   {{0x3ebe07df,0xa1583e2e,0x81e0015b,0xdce800d0}},	//   rdut_, _разу_, _ফের_, rteľ, 
   {{0x47b802f5,0xdce80030,0x70947b28,0x3ddc00fe}},	//   _উপনী, steľ, _гафф, _বেউল, 
   {{0x5eb46150,0x00000000,0x00000000,0x00000000}},	//   _вйет, --, --, --, 
   {{0x3ab42751,0x6908012c,0x00000000,0x00000000}},	//   сәкт, užen, --, --, 
   {{0x7e7a07e0,0xa13c0022,0x69083974,0x7de4030f}},	//   maup, _apŷi, ržen, _حسام, 
   {{0x7e7a07e1,0xe8f40184,0xee3802bf,0x1a64dc96}},	//   laup, йһы_, _сні_, دیکی_, 
   {{0xdddc0210,0x00000000,0x00000000,0x00000000}},	//   żyńs, --, --, --, 
   {{0x958607e2,0x166607e3,0x9664030d,0x00000000}},	//   илбе, рвам, ркае, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3b500] --, --, --, --, 
   {{0x690803c6,0x7ae4db6d,0xd4683c1f,0x7e7a07e4}},	//   nžel, _hoit, тиже_, haup, 
   {{0x7e78023a,0x7ae607e5,0x1da80037,0x00000000}},	//   kaup, _koit, _कहऽत, --, 
   {{0x7ae4049b,0x8778008f,0x8f44002b,0x00000000}},	//   _joit, _באטי, _kṛśa, --, 
   {{0x7ae607e6,0x7e7a07e7,0x00000000,0x00000000}},	//   _moit, daup, --, --, 
   {{0x7ae40f71,0xc5ec15fa,0x753c03fa,0x612c041e}},	//   _loit, _کړې_, _uhrz, kúlu, 
   {{0x7e7877ae,0xa2c0012c,0x69098682,0x7ae48007}},	//   faup, _रोक्, džel, _ooit, 
   {{0x7ae607e8,0x7e7a07e9,0x661c007c,0x1dd0012d}},	//   _noit, gaup, _yxsk, तमंत, 
   {{0x11486f78,0x50b402bf,0x31640010,0xbed400c0}},	//   _апай_, _всеу, _utmz_, рдых_, 
   {{0x7ae4bcf0,0xc19800d9,0x660800ee,0x612c02d2}},	//   _aoit, _בשמי, _ýeke, fúlu, 
   {{0x7ae45118,0x8c34013e,0x7e781196,0x00000000}},	//   _boit, ронӣ_, baup, --, 
   {{0x7ae607ea,0x4ae800d4,0x00000000,0x00000000}},	//   _coit, тьом_, --, --, 
   {{0x7ae607eb,0x0ba8215c,0x9b2400b8,0x00000000}},	//   _doit, راگى_, _ṣṭāb, --, 
   {{0x7ae402d0,0xdb00002d,0x1cb4031c,0x8f44002b}},	//   _eoit, ntlê, _ཝིར_, _dṛśa, 
   {{0x7ae607ec,0x612e07ed,0xc68c01e2,0x00000000}},	//   _foit, púlv, وېد_, --, 
   {{0x7ae401c6,0xddca07ee,0xfd600055,0x31a002bd}},	//   _goit, nceş, _attṛ, kòz_, 
   {{0xa2d401bc,0x8d740092,0x00000000,0x00000000}},	// [3b510] णास्, _በሲቪል_, --, --, 
   {{0x7e780219,0x03c40408,0x9b240055,0x17e400cc}},	//   zaup, исем, _ṣṭāc, _নধৰি, 
   {{0x7ae607ef,0x1cb4031c,0xe1340150,0x00000000}},	//   _yoit, _ཝིལ_, ұнды, --, 
   {{0xc6a607f0,0x68e4014f,0xdce803e0,0xa29400d4}},	//   _трои, _hohd, kseğ, саді, 
   {{0x68e40664,0xf994008f,0x177c0023,0xd12c0ee8}},	//   _kohd, ַרק_, _ንግዜኡ_, کمو_, 
   {{0x68e55bd9,0x25b47a0e,0x69080064,0x00000000}},	//   _johd, ğalı_, kžem, --, 
   {{0x7e782f06,0x68e607f1,0x9b24002b,0x25b40b97}},	//   taup, _mohd, _ṣṭād, şalı_, 
   {{0x38180302,0x2bb02cce,0x68e607f2,0x69080064}},	//   יקום_, _जनजा, _lohd, džem, 
   {{0x7e7a07f3,0x7ae40332,0xc0a801f7,0x00000000}},	//   raup, _roit, _لاال_, --, 
   {{0x7ae607f4,0x629805e4,0x68e4014f,0x7e79dc1a}},	//   _soit, lgwo, _nohd, saup, 
   {{0x7ae607f5,0x690802d5,0x71247a32,0x7e7a07f6}},	//   _poit, ržel, _بىلم, paup, 
   {{0x60c207f7,0xdd9409a5,0x62982278,0x5e58005b}},	//   _halm, _гады, ngwo, _сидя_, 
   {{0x7ae607f8,0x60c207f9,0x68e5b3b6,0x6454022e}},	//   _voit, _kalm, _bohd, _ogzi, 
   {{0x60c0ebf1,0x7ae45b9a,0xad2403e6,0x612c0005}},	//   _jalm, _woit, _وروو, cúlt, 
   {{0x60c207fa,0x7ae607fb,0x1ae40209,0x9b9400c6}},	//   _malm, _toit, _гойм, _العت, 
   {{0x60c207fc,0x645421d8,0x70a40092,0x9a9c030d}},	//   _lalm, _agzi, _መጽሐፉ_, _чукi, 
   {{0x3bf403e3,0x00000000,0x00000000,0x00000000}},	// [3b520] dəqə_, --, --, --, 
   {{0x60c1f122,0x458000d4,0x00000000,0x00000000}},	//   _nalm, ягув, --, --, 
   {{0xcc7800c8,0x28d46211,0x9b48069d,0x65c000e4}},	//   רװער, दारि, _መሃንዲ, tâhá, 
   {{0x64547550,0xe9f80ca8,0x91840597,0x79840083}},	//   _egzi, _abẹ_, مجتم, _kviw, 
   {{0x68e457a0,0x4a980bd9,0xfbc607fd,0x6908ebf6}},	//   _yohd, רינג, _کت_, džej, 
   {{0x86340302,0x798401e2,0x158824ae,0x00000000}},	//   _לרכב_, _mviw, _ﺗﻪﺳﯩ, --, 
   {{0x68e0c756,0xa0880220,0x4fc47df9,0xfbc402dd}},	//   öldi, рсіз_, ссла, _ةت_, 
   {{0x93145516,0x798401e2,0x764002fb,0x60c0035a}},	//   _اورش, _oviw, _úmys, _ealm, 
   {{0x60c207fe,0xa2d406ff,0x2eb80882,0xd1840228}},	//   _falm, णार्, _आसीत, _ылай, 
   {{0x60c207ff,0xe9f80241,0xac983cc6,0xdce80205}},	//   _galm, _gbẹ_, جندا_, rseğ, 
   {{0x79860800,0xead80212,0x00000000,0x00000000}},	//   _aviw, амні_, --, --, 
   {{0x612c0077,0x68e4047e,0x69080153,0x00000000}},	//   súlt, _sohd, ržem, --, 
   {{0x68e60801,0xf4000154,0x00000000,0x00000000}},	//   _pohd, ্থির_, --, --, 
   {{0xa2d40574,0x02cc0034,0x60c01180,0x61fc03e0}},	//   णाऱ्, _सोनभ, _xalm, _üsle, 
   {{0x6e3c9f20,0x79857ccb,0x68e40455,0x37f800a8}},	//   ərba, _eviw, _vohd, берэ_, 
   {{0xf4000154,0x00000000,0x00000000,0x00000000}},	//   ্থার_, --, --, --, 
   {{0x6aae0802,0x690828b5,0x68e56da5,0x00000000}},	// [3b530] _ibaf, nžek, _tohd, --, 
   {{0x69cc5931,0xe41402d5,0xa2c000bc,0x612c01e7}},	//   _irae, одзь, _रोज्, húlr, 
   {{0x23b60803,0x7984006f,0xaadc6b26,0x69ce0804}},	//   تماس, _zviw, यापक, _hrae, 
   {{0x69ce0805,0x21f401ec,0x61600023,0xe23400d8}},	//   _krae, يكاس, _ንሰይጣ, онењ, 
   {{0x018807d8,0x6aad0494,0x6298257c,0xf1a80133}},	//   ущей_, _mbaf, rgwo, ماوه_, 
   {{0x656e0806,0x60c20807,0xdf00002e,0x796800d1}},	//   mpah, _qalm, _meŋŋ_, ﻳﺪﯨﺰ_, 
   {{0x60c20808,0xfe560809,0x6aac238e,0x656e080a}},	//   _valm, میاب_, _obaf, lpah, 
   {{0x69cc1028,0x9f06080b,0x50f005a2,0xdb000036}},	//   _orae, توبو, ззәт, rtlë, 
   {{0x60c2080c,0x656c0ecf,0xf1ac0032,0x69080010}},	//   _talm, npah, _яҡ_, ržej, 
   {{0x5ba831d5,0x63a445c0,0x60c02f48,0xdb84010a}},	//   аком_, othn, _ualm, огои, 
   {{0x6aac2255,0x656c008b,0x63a40649,0x69ce080d}},	//   _bbaf, hpah, nthn, _arae, 
   {{0x63a4379c,0x69cc26df,0x656c020b,0x5398008d}},	//   ithn, _brae, kpah, סירו, 
   {{0x81d4045e,0xdb02080e,0x69dc0369,0x6eb80b98}},	//   ানক_, ntlé, gxse, ्यरु, 
   {{0x69ce080f,0xa3d832ed,0x515800df,0xdb000332}},	//   _drae, ़मा_, יכשו, itlé, 
   {{0x69ce0810,0x8cd4033f,0xd6d0009f,0x79400432}},	//   _erae, बारो, وقس_, jöwe, 
   {{0x69ce0811,0x6aacf3a4,0x3a20005a,0xdb00020c}},	//   _frae, _gbaf, _txip_, ktlé, 
   {{0x69ce0812,0x656c89f7,0x7984004b,0xaab82e05}},	// [3b540] _grae, gpah, _uviw, ेयरक, 
   {{0x628a0813,0xd2a40064,0x00000000,0x00000000}},	//   _adeo, _вiль, --, --, 
   {{0x6efc20ef,0x03a20814,0x00000000,0x00000000}},	//   _hébe, дихо, --, --, 
   {{0x68e20815,0xd1c8008e,0xaadc012c,0x81b00eac}},	//   öldv, илее_, यायक, টিন_, 
   {{0x63a40597,0x62880042,0xc6b4011a,0x672000e5}},	//   athn, _ddeo, _והכי_, élje, 
   {{0xc5f0025f,0x6efe0816,0x63a401ab,0x00000000}},	//   _חדש_, _mébe, bthn, --, 
   {{0x7cfc030a,0xe8d80208,0xc8d808a8,0xaadc3156}},	//   _kêrf, _quỉ_, יקסט, यामक, 
   {{0x2ec400dc,0x27300092,0x00000000,0x00000000}},	//   वयेत, _ሰብስበ, --, --, 
   {{0x2aac022e,0x00000000,0x00000000,0x00000000}},	//   vоb_, --, --, --, 
   {{0x69cc27be,0x6aac0ffb,0xf1a804d3,0x50440276}},	//   _rrae, _sbaf, _ناڕه_, _дезб, 
   {{0x3ce401fa,0x656c009d,0x2aac022e,0x00000000}},	//   _donv_, zpah, tоb_, --, 
   {{0x69ce0817,0x6efc4a85,0xdf00002e,0xdde80424}},	//   _prae, _bébe, _peŋŋ_, _گرمه_, 
   {{0x9e6424c5,0xbd4000ec,0x00000000,0x00000000}},	//   _رانن, _ڪنوي, --, --, 
   {{0x6efc172e,0x69cd9e37,0x63a40368,0x92b40154}},	//   _débe, _vrae, ythn, জায়_, 
   {{0xbd40082e,0x6d4a0818,0x00000000,0x00000000}},	//   _تنوي, mmda, --, --, 
   {{0x69ce0819,0x656da294,0x6aae081a,0x6d485bc6}},	//   _trae, tpah, _ubaf, lmda, 
   {{0x7cfc0a85,0x2d8401f9,0xbb4801c8,0xc974072d}},	// [3b550] _dêrf, nsme_, _بلين_, _باعث, 
   {{0x656e081b,0x2d86081c,0xd8b80156,0x8880034c}},	//   rpah, isme_, _བིརི, _زیرن, 
   {{0x2912081d,0x656e081e,0x68e00008,0x3ca403d4}},	//   miza_, spah, öldu, _কোঁৱ, 
   {{0x63a40cfd,0x2d8400da,0xa0c400aa,0x6efc002e}},	//   rthn, ksme_, ړيتو, _lébb, 
   {{0x656c0d04,0xa06a081f,0x672e0820,0x81b00011}},	//   qpah, бала_, moaj, টিভ_, 
   {{0x29120821,0x6304141b,0x672c023a,0xf0e804da}},	//   niza_, _کورل, loaj, يىنى_, 
   {{0xdb020822,0xa0c400db,0xdce80003,0x92b800cc}},	//   stlé, _ۉيرو, speċ, _অচৰ_, 
   {{0x29102dab,0x7cfc0165,0x3358084c,0x81b000cc}},	//   hiza_, _kêrg, _фатэ_, টিব_, 
   {{0xa1940354,0x2d8425ad,0x00000000,0x00000000}},	//   _хазч, gsme_, --, --, 
   {{0x24800221,0x291000ec,0x6efc74fd,0x6d480857}},	//   nahm_, jiza_, _rébe, gmda, 
   {{0x2911b85a,0x2d860823,0x672d3481,0x81d400eb}},	//   diza_, asme_, koaj, ানও_, 
   {{0x6d4a0824,0x672c0588,0x5e58007b,0x00000000}},	//   amda, joaj, _الإس_, --, 
   {{0x291005be,0x3ce40076,0x00000000,0x00000000}},	//   fiza_, _tonv_, --, --, 
   {{0xdd980432,0x00000000,0x00000000,0x00000000}},	//   muň_, --, --, --, 
   {{0xdd9800ee,0x672c0254,0x31b808df,0x00000000}},	//   luň_, foaj, _इन्ध, --, 
   {{0x15b8516c,0x59840276,0x4b78008f,0xa3c01d68}},	//   йызы_, _елиб, _פאפו, ्टन_, 
   {{0xdd9809a5,0x8af80375,0x6efc002e,0x2480022e}},	// [3b560] nuň_, _להקי, _yébb, fahm_, 
   {{0x29120825,0x2eb807b7,0x7cfc0b21,0x0c640240}},	//   ciza_, _आस्त, _wêrf, _ተሓጺሩ_, 
   {{0xd3340953,0x672c00c7,0x62100037,0xdd98010b}},	//   пэды, boaj, _देबौ_, huň_, 
   {{0x2d85e2b9,0xdce80010,0x6d4801d5,0x00000000}},	//   ysme_, dpeč, zmda, --, 
   {{0x5ee000bd,0x7cfc0165,0xaadc44eb,0x00000000}},	//   বসাই, _kêrd, यातक, --, 
   {{0x4638010f,0xdd98010b,0x00000000,0x00000000}},	//   _לעכע, duň_, --, --, 
   {{0x2ec405f5,0x656803e0,0x00000000,0x00000000}},	//   дөлм, _çehr, --, --, 
   {{0x29102c36,0x3dcc030a,0x2d860826,0x2dd41422}},	//   ziza_, _brgw_, tsme_, джир, 
   {{0x291117e4,0xfe6c0075,0x27f00034,0x6ac4009e}},	//   yiza_, ددى_, zyzn_, ষামো, 
   {{0x2d8400e2,0x69080427,0x6d48014f,0x61ec01f4}},	//   rsme_, lžev, umda, äale, 
   {{0x2d84070d,0xaa960827,0x672e0828,0x29118f54}},	//   ssme_, минч, yoaj, viza_, 
   {{0x29120829,0x4e9401ec,0x69080427,0x6d48aa24}},	//   wiza_, _ءشار, nžev, smda, 
   {{0x672c0109,0x00000000,0x00000000,0x00000000}},	//   voaj, --, --, --, 
   {{0xa3c0121d,0x1cb40327,0xe8940022,0x7ae0007c}},	//   ्टम_, _ཝིག_, ьагь, ömtr, 
   {{0x291043c4,0x3d2800dd,0xfbcc31ed,0x672e082a}},	//   riza_, _اتنی_, _متي_, toaj, 
   {{0x2910a21d,0xb8f40aff,0x81b04251,0xdbcc0166}},	//   siza_, _सो_, টিত_, _sıçe, 
   {{0xdce80745,0x29107f83,0x69080fcf,0x68e2082b}},	// [3b570] zpeč, piza_, džev, ölds, 
   {{0xe945ca23,0x672c01c8,0x7cfc0165,0x29100173}},	//   _تربی, soaj, _gêrd, qiza_, 
   {{0xe8d801f2,0xc7a800c6,0x248004cc,0x672cd64c}},	//   _juọ_, _ادخل_, rahm_, poaj, 
   {{0xe8da082c,0x28d40401,0xb5e400cc,0x00000000}},	//   _muọ_, दाकि, _নেওচ, --, 
   {{0x26da082d,0x6f0000c6,0x7cfc0156,0x21a4022e}},	//   _inso_, dhmc, _hêre, филм, 
   {{0x25aa082e,0xf7703e58,0x7cfe082f,0x00000000}},	//   mtal_, _جای_, _kêre, --, 
   {{0x25a941f8,0x63040150,0xdee401b9,0x00000000}},	//   ltal_, _قوسل, дойи, --, 
   {{0x26ca0830,0x25a9f77e,0x8c4403b9,0x6f0002d0}},	//   ndao_, otal_, _meşğ, ghmc, 
   {{0x25aa0831,0xf19407d8,0x2cac010a,0x7cfc0165}},	//   ntal_, _пить, ffdd_, _lêre, 
   {{0x2a68007f,0x25aa0832,0xb11400d3,0x26d80171}},	//   _afab_, ital_, _змуш, _lnso_, 
   {{0x1c442164,0x25aa0833,0x7cfc05e4,0x81e000cc}},	//   ьном, htal_, _nêre, _ফেচ_, 
   {{0x25aa0834,0x26d8013f,0x15882d40,0x00000000}},	//   ktal_, _nnso_, _ﺗﻪﺑﯩ, --, 
   {{0x5fc400dc,0x3f840158,0xdca500b4,0x186801b9}},	//   विकल, lsnu_, _жали, жаги_, 
   {{0x26da0835,0xf8a401c0,0x7cfc017a,0xcaa002dd}},	//   _anso_, эггү, _bêre, _ﺃﻋﻼﻩ_, 
   {{0x07a09785,0xe8d8063f,0x25a812fb,0x6efc0c6a}},	//   карн, _guọ_, etal_, _héba, 
   {{0x7cfc000f,0x25aa0836,0x3f840ba7,0x9b443c4b}},	//   _dêre, ftal_, isnu_, _تنبو, 
   {{0x25aa0837,0xe8d8063f,0x69080010,0x00000000}},	// [3b580] gtal_, _zuọ_, vžev, --, 
   {{0x3f860838,0x7cfc030a,0x6efc0de2,0x26da0839}},	//   ksnu_, _hêrb, _méba, _enso_, 
   {{0x78be083a,0x25a88d81,0x6efe083b,0x7cfc0156}},	//   merv, atal_, _léba, _kêrb, 
   {{0x25a800a3,0xbec000e2,0x2794013d,0x26c80051}},	//   btal_, _šūna, _яшьр, cdao_, 
   {{0x914819a5,0x6efc7dec,0xfd60002b,0x69080010}},	//   очка_, _néba, _gauḍ, ržev, 
   {{0x2fc400ee,0xdb000356,0x4f68a2b6,0x00000000}},	//   ериң, ntlâ, ошим_, --, 
   {{0x78bc0d49,0x8c44010e,0x1834008f,0x00000000}},	//   ierv, _keşş, ואַל_, --, 
   {{0x6efc5f14,0x78be083c,0x0442083d,0x37c00154}},	//   _béba, herv, _ресн, _উপার, 
   {{0x78be083e,0x7bc00309,0xd25000c6,0xaadc66c0}},	//   kerv, _asnu, _شنط_, यासक, 
   {{0x6efc5efe,0x690802fb,0x78bd59b0,0xdce80327}},	//   _déba, nžet, jerv, treġ, 
   {{0x25a801d3,0x00000000,0x00000000,0x00000000}},	//   ztal_, --, --, --, 
   {{0x25a87e54,0x6efc1bce,0xdce80003,0x00000000}},	//   ytal_, _féba, rreġ, --, 
   {{0x7cfc0b21,0xac940124,0x26c807f5,0x25a800e8}},	//   _dêrb, _залш, vdao_, xtal_, 
   {{0x78bc1b25,0x25a8049f,0x7cfc0ea0,0x34c806ff}},	//   gerv, vtal_, _pêre, रयोद, 
   {{0x690a083f,0x6d5a0840,0x8c44236c,0x00000000}},	//   džet, _iiva, _beşş, --, 
   {{0x6d5a0841,0x25aa0842,0x7cfc05c7,0x00000000}},	//   _hiva, ttal_, _gêrb, --, 
   {{0x6d5a0843,0x7cfc0591,0x26ca0844,0x25aa0845}},	// [3b590] _kiva, _wêre, rdao_, utal_, 
   {{0x6abe0846,0x78bd0965,0x6d5a0847,0x660800a2}},	//   lesf, cerv, _jiva, _ýekm, 
   {{0x6d581311,0x873c0092,0x00000000,0x00000000}},	//   _miva, _በጥልቀ, --, --, 
   {{0x6abe0848,0xdecc1772,0x25aa0849,0x81b00154}},	//   nesf, ቢትን_, ptal_, টিস_, 
   {{0xa06a084a,0x6d5a084b,0x46300022,0x25a80477}},	//   пала_, _oiva, _рҭар, qtal_, 
   {{0x6d5a084c,0xa06a084d,0x98c405a1,0x99840327}},	//   _niva, чака_, ćući_, _ġoż_, 
   {{0x6efe084e,0x6abc1f53,0xa29402d5,0x02a6084f}},	//   _séba, kesf, _паві, _орам, 
   {{0x6d5a0850,0xd05802ea,0x623409a5,0x3f8400f3}},	//   _aiva, _kotɛ, _зебу, rsnu_, 
   {{0x6d5a0851,0x6abe0852,0x690802f0,0xb82000cc}},	//   _biva, desf, nžes, _ধৰাত_, 
   {{0x62000ba5,0xd0580085,0x6d59cded,0xf42000fe}},	//   ızlı, _motɛ, _civa, _ভৰিৰ_, 
   {{0xa3c1f8b8,0xdb020853,0xdb8401c0,0x6abc003a}},	//   ्टि_, stlí, эгни, fesf, 
   {{0x6d5a0854,0x657c0c8c,0xcf441df2,0x3db400fe}},	//   _eiva, _owsh, _كىلۋ, জিবল, 
   {{0x6d581311,0x99d46e9a,0x2dc40046,0x72980023}},	//   _fiva, رتحا, _ақын_, _ቍጠባዊ_, 
   {{0xa3c035e0,0x6d5a0855,0x7cfc0b21,0x69d83012}},	//   ्टा_, _giva, _wêrb, _šwec, 
   {{0x7bc10816,0x657c0241,0x0ea405f9,0x67280118}},	//   _usnu, _awsh, क्कड, čejn, 
   {{0x1cb40327,0x3cf401ad,0x6abc0857,0x00000000}},	//   _ཝིཌ_, एसके_, cesf, --, 
   {{0x699401c0,0x3b0001b9,0x6d5a0856,0x85b0070e}},	// [3b5a0] _ирэх, _iliq_, _yiva, ләрч, 
   {{0x6d5807a9,0x78bc0200,0x09e0030d,0x00000000}},	//   _xiva, qerv, _соьн, --, 
   {{0x657c02d0,0x17c8010b,0x8c4403e0,0x00000000}},	//   _ewsh, _эгни_, _teşş, --, 
   {{0x55e60857,0xd73402bf,0x2308027d,0x690800c0}},	//   _зомб, _їхнь, وتني_, bžes, 
   {{0xe8d80051,0x68ec0241,0x00000000,0x00000000}},	//   _huề_, _òodù, --, --, 
   {{0xc0e0a3fa,0x4fc40139,0x6abc03ac,0x61ec0108}},	//   лочк, есиа, zesf, äala, 
   {{0x6d5a0858,0x04400598,0x00000000,0x00000000}},	//   _riva, _берн, --, --, 
   {{0xd2507fc5,0x03d40375,0xaed401f0,0x00000000}},	//   _منز_, _אולם_, тоиш, --, 
   {{0x6d5a0859,0x00000000,0x00000000,0x00000000}},	//   _piva, --, --, --, 
   {{0x81b000bd,0x3b00003a,0x6d5801a9,0x00000000}},	//   টিশ_, _aliq_, _qiva, --, 
   {{0x6abe085a,0xa2d41fbc,0xebc491cb,0xaadc024a}},	//   tesf, णाच्, тәлн, यालक, 
   {{0x81b003f4,0x3b0006af,0x6d58047e,0x1ea816ac}},	//   টির_, _cliq_, _wiva, _ياني_, 
   {{0x6d5a085b,0x6abc0c8c,0xdc5401d3,0xcd200133}},	//   _tiva, resf, ٹریک, _مژدی, 
   {{0xdd9802dd,0x6d580108,0x6abcc724,0x00000000}},	//   _іші_, _uiva, sesf, --, 
   {{0xad2449c6,0x07440354,0x657c0142,0x00000000}},	//   _كىچى, ехам, _swsh, --, 
   {{0x490000f7,0x3b0001a9,0x657c0142,0xcb4401d5}},	//   түүг, _gliq_, _pwsh, _яхли, 
   {{0x7cfc030a,0xa534010b,0xdddc0055,0x00000000}},	// [3b5b0] _hêra, внач, _āyūh, --, 
   {{0x7cfc05c7,0xf77000e5,0xdecc1954,0x00000000}},	//   _kêra, شاہ_, ቢትና_, --, 
   {{0x2902085c,0x6efc056a,0x2b48001e,0x3b00022e}},	//   _ilha_, _nébo, _khac_, _yliq_, 
   {{0x2900020c,0x00000000,0x00000000,0x00000000}},	//   _hlha_, --, --, --, 
   {{0x2b4814d0,0xa0a405c2,0x290002b9,0x97000131}},	//   _mhac_, валд, _klha_, _ئېقى, 
   {{0x25b98d66,0xb9fc001f,0xaadc012c,0x53a000db}},	//   _ipsl_, _ሄደ_, याँक, _چۅلك, 
   {{0x2902085d,0x6efe085e,0xc2b00220,0xff1c04ce}},	//   _mlha_, _cébo, _бөлш, _rayを, 
   {{0xd00c021a,0x6efdd53e,0x2b48001e,0x25b805b1}},	//   غلي_, _débo, _nhac_, _kpsl_, 
   {{0x29000261,0x1cb40327,0x215400c0,0x00000000}},	//   _olha_, _ཝིད_, _акаў, --, 
   {{0xfc3c012c,0x2b480427,0x9d440063,0x00000000}},	//   řím_, _ahac_, ђенд, --, 
   {{0xaadc1ab2,0x2b483e7c,0x8cd40034,0x6efc6085}},	//   यांक, _bhac_, बाजो, _kébl, 
   {{0xdd9400c7,0x2b486ec0,0xba9400ec,0x24e40150}},	//   _аады, _chac_, دادڪ, _ﺍﻷﺴﻬ, 
   {{0x3ebc00d5,0x2b4801d9,0xfdb0013d,0xd8b801ec}},	//   meut_, _dhac_, _сәйя, _ﺸﻤﻭﻟ, 
   {{0x7c841ea2,0x290001ab,0x3ebc00d5,0x6cc400fb}},	//   _чуде, _clha_, leut_, _бишҡ, 
   {{0xdb000005,0x2b4800a3,0x7cfc030a,0x290000d7}},	//   atlá, _fhac_, _gêra, _dlha_, 
   {{0x3ebe085f,0x07a003b7,0x2b48031c,0x00000000}},	//   neut_, јатн, _ghac_, --, 
   {{0x49c60860,0xc8c400e5,0x00000000,0x00000000}},	// [3b5c0] _алын_, رڈین_, --, --, 
   {{0x3ebcd875,0xdce80115,0x09f4011a,0xae140037}},	//   heut_, breĥ, _סמים_, _तइसन_, 
   {{0x1cb40d46,0x3ebc1dd4,0x25b8014b,0x940471f1}},	//   _ཝིན_, keut_, _epsl_, خواه, 
   {{0x3ebd0bc6,0x52740114,0x9584db2e,0x00000000}},	//   jeut_, тужу, _илме, --, 
   {{0x6efc07ea,0x6ecc033f,0xd14802f2,0x00000000}},	//   _débl, _दोगु, وشتن_, --, 
   {{0x81b02f8b,0xb4041719,0x00000000,0x00000000}},	//   টিং_, _йүзд, --, --, 
   {{0x3ebc0200,0xde540055,0x00000000,0x00000000}},	//   feut_, _śāpā_, --, --, 
   {{0xa3c0023e,0x3ebc0438,0xbd840214,0x2a780175}},	//   ्टर_, geut_, چنين_, xbsb_, 
   {{0x41bc25c9,0xcd041bbc,0xd1c801af,0x00000000}},	//   _एनएस, вчни, _юлае_, --, 
   {{0x4f9494c9,0x2b480009,0xdb0001bf,0x00000000}},	//   _арду, _shac_, ntlæ, --, 
   {{0x3ebe0861,0x31640399,0x69080cf4,0x00000000}},	//   beut_, _humz_, džep, --, 
   {{0x2a6c0428,0x3b54084c,0xdb00148b,0x00000000}},	//   ùeb_, икэр, ttlá, --, 
   {{0xc330025f,0x7bd40005,0xdb002d8b,0xc278011a}},	//   שור_, _áxun, ktlæ, ורכי, 
   {{0xe9456414,0x21380240,0xdb020862,0x6608010e}},	//   انسپ, _ësht_, jtlæ, _ýeki, 
   {{0x31640399,0xc6a4209b,0x7cfc0165,0xdb0000b5}},	//   _lumz_, краи, _kêrn, dtlæ, 
   {{0x37053ae6,0xd73401c6,0x9c440006,0x00000000}},	//   ачув, гдсө, _схіл, --, 
   {{0xa4d80046,0xf8b805f5,0x29000978,0xdb000feb}},	// [3b5d0] ндау_, хөө_, _tlha_, ftlæ, 
   {{0x6efc003e,0xe944006c,0x3ebc0240,0xdb00005c}},	//   _sébl, _حربی, zeut_, gtlæ, 
   {{0x62240131,0xfa34179e,0xaca4010e,0x3ebc0c6a}},	//   گىشل, _مرید, _haỳy, yeut_, 
   {{0xdc780023,0xf1a84dc1,0x00000000,0x00000000}},	//   ኣሳሰር_, چاوه_, --, --, 
   {{0xe214f7da,0xf1a804d3,0xf5e50575,0xd2480131}},	//   ымды, ناوه_, _кірм, ىكمۇ_, 
   {{0x6efc003e,0x1fa800ee,0x602401c0,0x3ebc0098}},	//   _wébl, екки_, лдла, weut_, 
   {{0x3e8c0023,0xaca4010e,0x3ebcb89a,0x81b00154}},	//   _ሓበረታ_, _laỳy, teut_, টিই_, 
   {{0x98b800b0,0x3ebc003e,0xfc3c0118,0x69d80327}},	//   _pipī_, ueut_, řík_, _ġwen, 
   {{0x3ebe0863,0x7cfc0a85,0x31640369,0xdfd06f04}},	//   reut_, _dêrn, _gumz_, _گيا_, 
   {{0x3ebc00d5,0x0c640092,0x00000000,0x00000000}},	//   seut_, _ተናገሩ_, --, --, 
   {{0xdfd0489b,0xde040116,0x4b840209,0xde940798}},	//   _ديا_, _әпли, лйэн_, _баењ, 
   {{0x1398008f,0x6e240427,0x00000000,0x00000000}},	//   עברע, _žibe, --, --, 
   {{0xe9a80014,0x7de42e0b,0x00000000,0x00000000}},	//   پدُن_, _جسام, --, --, 
   {{0x17c807d6,0x47b802f5,0x00000000,0x00000000}},	//   нгги_, _উপজী, --, --, 
   {{0x7cfc0165,0x00000000,0x00000000,0x00000000}},	//   _hêro, --, --, --, 
   {{0x261401ad,0xca680150,0x00000000,0x00000000}},	//   _नेही_, _ﺳﯩﺒﻪ_, --, --, 
   {{0xb484052f,0x612c01ed,0xdb0001a8,0xaca400a2}},	// [3b5e0] икаһ, súly, ttlæ, _gaỳy, 
   {{0x31640399,0xa3c00882,0xc480004e,0x00000000}},	//   _rumz_, ्टं_, йлук, --, 
   {{0xdb00037e,0x5064036b,0x48f00210,0x00000000}},	//   rtlæ, қтла, ुसरो_, --, 
   {{0xdb020864,0xaadc012c,0x51841cd0,0x522401a9}},	//   stlæ, याएक, гука, лфла, 
   {{0xdb007a45,0x00000000,0x00000000,0x00000000}},	//   mtlä, --, --, --, 
   {{0x8afc0b45,0x09b4010f,0xab9c0092,0xdb003453}},	//   _muƙa, רפסט_, _ጉባዔው_, ltlä, 
   {{0x52760865,0xa3c000dc,0x00000000,0x00000000}},	//   _бузу, ्टः_, --, --, 
   {{0x02020866,0x130401d5,0xdb001f65,0x00000000}},	//   рзән, _ёзам, ntlä, --, 
   {{0x8d7412a1,0x0ca84358,0x0c854530,0x00000000}},	//   داعا, нтни_, лынм, --, 
   {{0x7cfc0b21,0x00000000,0x00000000,0x00000000}},	//   _dêro, --, --, --, 
   {{0x3e8c069c,0xdb00499c,0xaca400a2,0x7e7a0867}},	//   _ሓበሬታ_, ktlä, _saỳy, bbup, 
   {{0x8afc0c09,0xbb90034b,0x42780092,0x00000000}},	//   _buƙa, щающ, _ጤንነት_, --, 
   {{0xbdf41867,0x00000000,0x00000000,0x00000000}},	//   _مروا_, --, --, --, 
   {{0xc234123b,0x00000000,0x00000000,0x00000000}},	//   טרכו_, --, --, --, 
   {{0x81b00154,0xdb00007c,0x83e001ec,0x3cf8011a}},	//   টিএ_, ftlä, _ﺍﻧﺎﺳ, _אלגנ, 
   {{0xaca400a2,0xdb00002f,0x34940022,0x84440116}},	//   _taỳy, gtlä, ҩатр, ۇخال, 
   {{0xdb00af58,0xe7380139,0x3a7401ee,0x00000000}},	// [3b5f0] kulê, еең_, _улыр, --, 
   {{0x98a80311,0x4429ab5b,0xdb000139,0x00000000}},	//   robă_, нцем_, atlä, --, 
   {{0x627400b2,0xdb00017a,0x00000000,0x00000000}},	//   لهائ, dulê, --, --, 
   {{0xc7940022,0x00000000,0x00000000,0x00000000}},	//   _ирҭы, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9f9407d6,0x00000000,0x00000000,0x00000000}},	//   ашиш, --, --, --, 
   {{0xd058016b,0x3d180241,0xd0045211,0xb4440024}},	//   _botɑ, _láwè_, иеше_, _гэтк, 
   {{0xe2ca0868,0x660c05da,0xdea00244,0x9e64003b}},	//   _جورو_, ozak, زیتی, швид, 
   {{0x7e780158,0xd3440345,0xaac828f0,0x00000000}},	//   rbup, _ئینه_, िजनक, --, 
   {{0x5f9406bb,0x660c92de,0x69d801bc,0x9cf400db}},	//   _вижт, izak, मिनी, рчиш, 
   {{0x7cfc0a85,0x660c02c4,0x3ab40032,0x00000000}},	//   _wêro, hzak, бәпт, --, 
   {{0x660c0c09,0xdb0001e3,0xaadc1a4e,0x00000000}},	//   kzak, xtlä, यागक, --, 
   {{0x49c4c74a,0x660c0010,0xdb00c902,0x261401f9}},	//   алян_, jzak, jtlå, _नेली_, 
   {{0x660e0869,0xdea007d6,0x00000000,0x00000000}},	//   dzak, _ایکی, --, --, 
   {{0xdb005df7,0x660ca6a4,0x6efc0332,0x394400e2}},	//   ttlä, ezak, _bébh, ēms_, 
   {{0x3d180ca8,0x660c01a4,0xfd600055,0x6bd400f1}},	//   _fáwè_, fzak, _sutṛ, _دتهر, 
   {{0xdb017057,0x660e086a,0x6efc01e7,0x8b38011a}},	// [3b600] rtlä, gzak, _débh, _בתקצ, 
   {{0x79840086,0xdb02086b,0x48e0030d,0x00000000}},	//   _iwiw, stlä, _доьв, --, 
   {{0x37c0015b,0x2b580118,0xd264004e,0x00000000}},	//   _উপকর, ůrce_, акей, --, 
   {{0x79844242,0x00000000,0x00000000,0x00000000}},	//   _kwiw, --, --, --, 
   {{0xdb0000d8,0x660c012d,0x7ae0007c,0x00000000}},	//   tulê, czak, ömty, --, 
   {{0xdd180003,0x245002f2,0x00000000,0x00000000}},	//   għżl, _کۆمس, --, --, 
   {{0x7b240b91,0x798402c4,0xdb000240,0x80a0009a}},	//   rđuj, _lwiw, gulë, زمين, 
   {{0x82a007d6,0x7cfc0a85,0x6efc0129,0xee74010b}},	//   _масж, _dêrm, _kébi, щлиь, 
   {{0x10a410f5,0xdb02086c,0x798402b9,0x99900210}},	//   _визн, pulê, _nwiw, _czyż_, 
   {{0xdb00eda4,0x9034074d,0xac980133,0x8c6401d5}},	//   lulè, _кхеч, دندا_, штид, 
   {{0x79840227,0x660e086d,0xe8d801fb,0x00000000}},	//   _awiw, zzak, _huệ_, --, 
   {{0x79840223,0x1ea897b5,0x00000000,0x00000000}},	//   _bwiw, _ماهي_, --, --, 
   {{0x753c0210,0xc864009b,0xdb0001e3,0x035400df}},	//   _okrz, итви, xtlå, ייטש_, 
   {{0x290400fc,0x79846085,0xfcd006f6,0x660c3421}},	//   óla_, _dwiw, _وينج, vzak, 
   {{0xdb000669,0xab9468e1,0x00000000,0x00000000}},	//   kulè, _البغ, --, --, 
   {{0x27ec0bb8,0x660c0323,0x6efc3e3b,0x3d1801e1}},	//   ćen_, tzak, _bébi, _táwè_, 
   {{0x0465ee2f,0x798423db,0x6aac009a,0xc7640131}},	// [3b610] атем, _gwiw, _icaf, _ھادى, 
   {{0x660e086e,0x6efd9a7b,0xc7641823,0x245800fd}},	//   rzak, _débi, _پادى, газь_, 
   {{0x660c00dd,0xdb0093e0,0xdce80960,0x79840036}},	//   szak, stlå, speć, _zwiw, 
   {{0x660c01f5,0x69d8025c,0x98a83d44,0x00000000}},	//   pzak, _ġwej, robą_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe8d8004d,0x00000000,0x00000000,0x00000000}},	//   _duệ_, --, --, --, 
   {{0x3210016b,0x23840014,0x656c0113,0x5ea4007b}},	//   _ɑnyɑ_, _دٔزِ, lqah, ممثل, 
   {{0xdb02086f,0x69cc009d,0x257c01e1,0x1eca0870}},	//   culè, _osae, _gálò_, улии_, 
   {{0xf1ac052f,0x2000000a,0x7cfc045f,0x656c0113}},	//   _юҡ_, šhi_, _wêrm, nqah, 
   {{0x79860871,0x6aac00f3,0xdb020872,0xbaac0154}},	//   _rwiw, _acaf, mulé, গড়াছ, 
   {{0x63a433cb,0x69ce0873,0x673c00af,0x79860874}},	//   nuhn, _asae, _oksj, _swiw, 
   {{0x9f55a8e5,0x6288062c,0x00000000,0x00000000}},	//   _увеч, _jeeo, --, --, 
   {{0xdb020875,0x628800ad,0x63a4003e,0xae0400db}},	//   nulé, _meeo, huhn, _وومى, 
   {{0xcd740302,0x673e0876,0xed4400d6,0x61fc3535}},	//   _העסק_, _aksj, _дніп, _üslu, 
   {{0x69cc530f,0x63a40098,0xa8180131,0x96960877}},	//   _esae, juhn, ۇتېر_, йраш, 
   {{0x37240020,0x753d0204,0x79840564,0x62880472}},	//   _ተወካዮ, _skrz, _twiw, _neeo, 
   {{0xcd500014,0x98a42f34,0x63a4003e,0xeb5400db}},	// [3b620] _بى۪ک, _липе, euhn, _بىيگ, 
   {{0x673e0878,0xdb004e01,0x7ae60879,0x00000000}},	//   _eksj, dulé, _hnit, --, 
   {{0x7ae6087a,0x63a415a5,0x62880076,0xf6640166}},	//   _knit, guhn, _beeo, _менү, 
   {{0x7ae40327,0xddc80030,0x00000000,0x00000000}},	//   _jnit, dbež, --, --, 
   {{0xddc80030,0x3e5c00b8,0xdb02087b,0xe8d80051}},	//   ebež, _jātī_, gulé, _quệ_, 
   {{0x63a44237,0x2fcc0005,0x2ba841ac,0x69d828e0}},	//   buhn, _psdg_, _कमला, मिती, 
   {{0x7ae6087c,0xdb0000f2,0x114802dd,0x8cd03c71}},	//   _onit, pulè, _ұпай_, _भोगो, 
   {{0xe8d8001e,0x7ee00075,0xdb0c0241,0xc32000f3}},	//   _tuệ_, ككىن, _ìjèb, _емск, 
   {{0xdb02087d,0x7a1c0f40,0x00000000,0x00000000}},	//   culé, nātī, --, --, 
   {{0x7ae6087e,0x6aae087f,0xd9bc0183,0x00000000}},	//   _anit, _scaf, ইটাম, --, 
   {{0x62880472,0xd0456a15,0x90440633,0x8c340107}},	//   _yeeo, _اپاي, _اناه, сонӣ_, 
   {{0x69cc0077,0x7ae401ab,0x00000000,0x00000000}},	//   _psae, _cnit, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7ae60880,0x92b4015b,0x81b000cc,0x8d5427a8}},	//   _enit, ড়ায়_, টিচ_, _утеч, 
   {{0x7ae4007c,0x00000000,0x00000000,0x00000000}},	//   _fnit, --, --, --, 
   {{0x69cc8f49,0x7ae60881,0xdee402d3,0x3688001b}},	//   _tsae, _gnit, _ዝኮነ_, йсун_, 
   {{0x63a5bb70,0xddc81aff,0x69cc004c,0x62880363}},	// [3b630] wuhn, zbež, _usae, _reeo, 
   {{0x63a60882,0x656c058a,0x48a82f5c,0x00000000}},	//   tuhn, rqah, _стим_, --, 
   {{0x7cfc000f,0x6288062c,0x68e402d0,0x81b00183}},	//   _dêrh, _peeo, _inhd, টিছ_, 
   {{0xdb020883,0x00000000,0x00000000,0x00000000}},	//   tulé, --, --, --, 
   {{0x63a60884,0x2089b665,0xe13591fe,0x3e5c00b0}},	//   suhn, айли_, онды, _kātū_, 
   {{0x28ac0882,0x63a60885,0x7cfc0165,0x3e5c0055}},	//   ञ्चि, puhn, _gêrh, _jātū_, 
   {{0x3e5c0421,0x62880037,0x068402dd,0xdce800d7}},	//   _mātū_, _teeo, _ﺩﻩﯕﮕ, treľ, 
   {{0xdb019ff6,0xddc80841,0xdc78001f,0xaad87220}},	//   pulé, rbež, _የበላይ_, _बोलक, 
   {{0x7cfc0489,0x6efc73a0,0xa0c60886,0xc0a80137}},	//   _hêri, _nébu, _ويرو, _ماال_, 
   {{0x7cfc0dd4,0x224c030a,0x70941d5e,0xdb000b1a}},	//   _kêri, _izek_, _науф, ltlø, 
   {{0x796001e1,0x00000000,0x00000000,0x00000000}},	//   _láwì, --, --, --, 
   {{0x6b9c3eba,0x3e5c02b5,0x68e60887,0xdb005f03}},	//   árga, _pātī_, _anhd, ntlø, 
   {{0x7ae40316,0x6d8401d9,0x00000000,0x00000000}},	//   _vnit, _ٹۅپہ_, --, --, 
   {{0x6efc0231,0xb4e800ab,0x00000000,0x00000000}},	//   _débu, _मचे_, --, --, 
   {{0xdb0000ed,0x00000000,0x00000000,0x00000000}},	//   ktlø, --, --, --, 
   {{0x2614007d,0x224c0427,0xdb0001bf,0x00000000}},	//   _नइखी_, _ozek_, jtlø, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3b640] --, --, --, --, 
   {{0xd05802ea,0x3a840014,0x7a1c1c52,0xd774007b}},	//   _kotɔ, _بُکہ, rātī, _واجع, 
   {{0x6efc020c,0x93582ec9,0x53c9a0b0,0xdb0003cd}},	//   _zébu, арду_, ргем_, ftlø, 
   {{0x7cfc002d,0x55e46a94,0x6efc020c,0xdb0012e8}},	//   _wêrh, _домб, _yébu, gtlø, 
   {{0x224e0888,0x644003b2,0x00000000,0x00000000}},	//   _czek_, _ølin, --, --, 
   {{0x224c8bbb,0xcf980640,0x9878010f,0x00000000}},	//   _dzek_, аји_, באַט, --, 
   {{0x224e0889,0x7cfc0156,0x044006ed,0xa4901079}},	//   _ezek_, _gêri, _жерн, _سینت, 
   {{0x98a8012d,0x59c800bc,0xadf4011c,0x00000000}},	//   robę_, िबार, зпиш, --, 
   {{0xd1315145,0xef1000cf,0x941c01f9,0x00000000}},	//   _قمر_, _үүлө, _येतच_, --, 
   {{0x6efc50f2,0xd0580085,0xe8d802e3,0xe80c00bc}},	//   _rébu, _botɔ, _kwụ_, सनमा_, 
   {{0x0f70036b,0x3e5c02b1,0x2fd801f5,0x6efc0129}},	//   _ўғир, _rātū_, _érg_, _sébu, 
   {{0xdfa41541,0x00000000,0x00000000,0x00000000}},	//   _رحمي, --, --, --, 
   {{0x3e5c02b1,0x00000000,0x00000000,0x00000000}},	//   _pātū_, --, --, --, 
   {{0x98b00724,0x6cd400f2,0x2614012d,0x00000000}},	//   _buyı_, _رقبا, _नेगी_, --, 
   {{0x7d340375,0x69d82ef1,0x00000000,0x00000000}},	//   _ונגב_, मिही, --, --, 
   {{0x3e5c02b1,0x7cfc0ea0,0x81b000eb,0xdd980432}},	//   _wātū_, _rêri, য়িত_, lyňa_, 
   {{0xc4cc0011,0xdb00332e,0x057400cf,0x443c00ef}},	// [3b650] রাসঙ, vtlø, تازد, _ņu_, 
   {{0x7cfe088a,0x224c0210,0x00000000,0x00000000}},	//   _dêrw, _rzek_, --, --, 
   {{0xdb0008fb,0x89d401c8,0x00000000,0x00000000}},	//   ttlø, _اوڌر_, --, --, 
   {{0xdb00002d,0x672800f3,0xd9940133,0x05180154}},	//   erlê, čejs, _بچێت_, তকের_, 
   {{0xdb005c04,0x21684d75,0xdd9a088b,0x98a801ef}},	//   rtlø, щили_, kyňa_, jobě_, 
   {{0x98a8012c,0xdb0122c5,0xddc80cf4,0x397c08a8}},	//   době_, stlø, jceš, סטונ, 
   {{0xe8d8063f,0x7cfc030a,0x25a8030a,0xdd980432}},	//   _gwụ_, _kêrv, lual_, dyňa_, 
   {{0x224c026c,0x2a68047e,0x26c800b0,0x25a80165}},	//   _tzek_, _ngab_, neao_, oual_, 
   {{0xb3640801,0x25a9a167,0x224c009a,0x720801d9}},	//   _църк, nual_, _uzek_, _وہمہ_, 
   {{0xdd982f5d,0x7cfc0165,0x2a6a088c,0x61ec005b}},	//   gyňa_, _lêrv, _agab_, äalu, 
   {{0x26c9fb6c,0x25aa088d,0x0c2063bb,0x1c447a9c}},	//   keao_, hual_, емэн, яном, 
   {{0x25a8005a,0xa2c80210,0x00000000,0x00000000}},	//   kual_, _रसोई, --, --, 
   {{0x25aa088e,0xd7e92d0e,0xd058016b,0x26ca088f}},	//   jual_, әмбе_, _wotɔ, deao_, 
   {{0x4dd80375,0xcdf40375,0x2d580108,0x00000000}},	//   _לחנו, _ממני_, _дичь_, --, 
   {{0x8c420890,0x26c83495,0xa8640032,0x2cb84079}},	//   _пеше, feao_, дерҙ, òrde_, 
   {{0x7bc00ffb,0x6efe0891,0x05d40073,0x00000000}},	//   _ipnu, _hébr, ठिंब, --, 
   {{0xd99800e5,0x1dbc00cd,0x00000000,0x00000000}},	// [3b660] _اخبا_, ्बित, --, --, 
   {{0x98b0008e,0xd174010b,0xa9c401f7,0x00000000}},	//   _tuyı_, җыды, _آزيو, --, 
   {{0xc9500302,0x12e40220,0x7cfc000f,0xdb00d4dd}},	//   _רמת_, зілг, _wêrw, mulâ, 
   {{0x25a95ed3,0x7cfc0165,0x2bdc00dc,0x6edc01e1}},	//   bual_, _gêrv, यिता, _ḿbú, 
   {{0xd04400ac,0xcb10008f,0xdb0001c7,0x00000000}},	//   əmən, עלד_, erlë, --, 
   {{0x7bc20892,0x931407d6,0xdb00498f,0x00000000}},	//   _opnu, _کورش, dulí, --, 
   {{0x94840220,0xfc24007b,0x546801fe,0x00000000}},	//   _мыңд, _أح_, _ваҳм_, --, 
   {{0x93c801d3,0x22480210,0x00000000,0x00000000}},	//   _پاڑہ_, żaka_, --, --, 
   {{0x99bc00fe,0x7bc000c0,0x61ec0108,0xdb0002d2}},	//   ইটুক, _apnu, äalt, gulí, 
   {{0xd1d40020,0x48d4015b,0x98a800bc,0x62640150}},	//   ካባቢ_, _সক্র, robě_, _زاقق, 
   {{0x0e64005e,0x6efc07ea,0x7db03321,0x78bc0334}},	//   _екен, _débr, وصیا, dfrv, 
   {{0xad841e87,0xcb0a0893,0xbd840214,0xdb0002f0}},	//   _قاتۇ, сход_, _کنون_, bulí, 
   {{0x26c80b23,0x25aa0894,0x6efc73a0,0xdb0002f0}},	//   veao_, xual_, _fébr, culí, 
   {{0x80bc00cd,0x00000000,0x00000000,0x00000000}},	//   ल्पे, --, --, --, 
   {{0x26c800b0,0x6d48022e,0x00000000,0x00000000}},	//   teao_, mlda, --, --, 
   {{0x6efc0129,0xbb4400d8,0xa5c40139,0x3f7800df}},	//   _zébr, _пејк, мөге, מאלס, 
   {{0x6d4a0895,0xdb020896,0x26c80374,0xaa5401d5}},	// [3b670] olda, bulâ, reao_, _ювиш, 
   {{0xf67401c6,0x00000000,0x00000000,0x00000000}},	//   _үгээ, --, --, --, 
   {{0x6d4a0897,0x25aa0898,0xdb000306,0x68f40175}},	//   ilda, sual_, zulí, mjzd, 
   {{0x80bc012c,0x6d48022e,0x00000000,0x00000000}},	//   ल्ने, hlda, --, --, 
   {{0x25aa0899,0x09ac02f5,0x672c22da,0xa068084c}},	//   qual_, _চৈতা, mnaj, оала_, 
   {{0x657e089a,0x69dc00af,0x91e000f3,0x672c00de}},	//   _itsh, ivse, тоше, lnaj, 
   {{0x672e089b,0x00000000,0x00000000,0x00000000}},	//   onaj, --, --, --, 
   {{0x6abc0d27,0x672e089c,0x2f55c675,0xdb0001c7}},	//   jfsf, nnaj, нтыс, rrlë, 
   {{0x6efc0438,0x672e089d,0xa03000db,0x00000000}},	//   _pébr, inaj, رۉچت, --, 
   {{0x69dc0fb7,0x657c4b2a,0x00000000,0x00000000}},	//   dvse, _mtsh, --, --, 
   {{0x6abc3b52,0x29100200,0xe8d80051,0x00000000}},	//   ffsf, dhza_, _quờ_, --, 
   {{0x6d4a089e,0xdb000789,0x672c0115,0x657e089f}},	//   alda, pulí, jnaj, _otsh, 
   {{0x657e08a0,0x672cb984,0x6d49987c,0xbe4800f2}},	//   _ntsh, dnaj, blda, _اشام_, 
   {{0x6abc0036,0x7f580dd0,0x672c0254,0xdb0000ae}},	//   afsf, lmuq, enaj, irlé, 
   {{0x657e08a1,0x7cfc0b21,0x7bc002f0,0x672e08a2}},	//   _atsh, _dêrt, _upnu, fnaj, 
   {{0x672e08a3,0xcba0013e,0x657c01bf,0x63a402f0}},	//   gnaj, _раъй, _btsh, drhn, 
   {{0xceb00375,0xb8e40eac,0x85b0010b,0x00000000}},	// [3b680] כין_, _এফ_, кәрч, --, 
   {{0x80bc0034,0x672c005b,0x9a640023,0x059802dd}},	//   ल्मे, anaj, ተዘየለ_, _ﺟﻪﺗﭙ, 
   {{0x657d4b80,0xdb000036,0x985401d5,0x0d38010f}},	//   _etsh, erlé, _ютиш, קגעב, 
   {{0xfe6401d9,0xaac0197c,0xe9b801d3,0xe3b00a81}},	//   _لد_, ष्पक, _بنیں_, ارٕ_, 
   {{0xc69006a9,0x6d4a08a4,0x24040022,0x86b001ec}},	//   _באר_, ylda, _ҧҽуи_, _шәрі, 
   {{0x60c08e96,0xc0e000f3,0x00000000,0x00000000}},	//   _cblm, кочк, --, --, 
   {{0x52740137,0xd9c800bc,0x00000000,0x00000000}},	//   _жузу, िबुट, --, --, 
   {{0x4ea40798,0x6d48172c,0x00000000,0x00000000}},	//   фрка, wlda, --, --, 
   {{0xc2400372,0xc84c0092,0x6d48022e,0x00000000}},	//   _антк, _በድንጋ, tlda, --, 
   {{0x672c08ad,0x6d480254,0x00000000,0x00000000}},	//   znaj, ulda, --, --, 
   {{0x672c033f,0x6d480267,0x99bc009e,0x00000000}},	//   ynaj, rlda, ইটোক, --, 
   {{0x6abc0e78,0x6d48022e,0x8d600092,0x8ae400d4}},	//   ufsf, slda, _ሰጣቸው_, фіол, 
   {{0x6abc008c,0x2910009b,0x672c1151,0xdd980100}},	//   rfsf, thza_, vnaj, nyňl_, 
   {{0x7cfc000f,0x657c009a,0x67d4e1b5,0xab94026a}},	//   _dêrs, _rtsh, ногу, _закљ, 
   {{0xdb004d74,0xfbcc02dd,0x00000000,0x00000000}},	//   bulà, _ەتۋ_, --, --, 
   {{0x63a40122,0x7cfc0b21,0xf9900133,0x672c01f4}},	//   vrhn, _wêrt, دبێ_, unaj, 
   {{0x672e08a5,0xdb0009c2,0x80bc20f0,0x00000000}},	// [3b690] rnaj, atló, ल्डे, --, 
   {{0xdb005ced,0x63a402fb,0xe4d450e7,0x38c80330}},	//   mulá, trhn, عقاد, _قاپی_, 
   {{0x7cfc006a,0x39140276,0x00000000,0x00000000}},	//   _kêrr, _рмэр, --, --, 
   {{0x60c00263,0xd5c8012d,0x82341bf4,0x00000000}},	//   _sblm, _सैकड़, ورشا, --, 
   {{0x657c0928,0xaac18874,0xdb0001ed,0x7cfc017a}},	//   _utsh, ष्यक, nulá, _mêrr, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x26d9145c,0xac800092,0x00000000,0x00000000}},	//   _kaso_, _የሠላም_, --, --, 
   {{0x26d805f5,0xdb006362,0xdea07983,0xaac01157}},	//   _jaso_, kulá, ایشی, ष्मक, 
   {{0x26da08a6,0x0dc473c7,0x60c00175,0xdb0208a7}},	//   _maso_, елый_, _tblm, rtlü, 
   {{0x26da08a8,0xdb0208a9,0x7f580784,0x5ba80452}},	//   _laso_, dulá, smuq, пком_, 
   {{0x2cb8067c,0xd13c012d,0xdca401f0,0x0cac01e1}},	//   òrda_, żąca_, _ҷали, _ńṣẹ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdca4863f,0xdb0003da,0x1868ab39,0xe8d80051}},	//   _зали, gulá, заги_, _quở_, 
   {{0x26d80067,0x386c0158,0xeea801e0,0x1cb800ae}},	//   _aaso_, ødr_, _етәк_, _راتب_, 
   {{0x26da08aa,0x7cfc000f,0xdb00067c,0xd94400d1}},	//   _baso_, _wêrs, pulà, _җени, 
   {{0xdb0208ab,0x8c180375,0x6e240024,0x1aa8000d}},	//   bulá, _מוצי, _žibi, _काटथ, 
   {{0x26da08ac,0xdb0000d8,0x00000000,0x00000000}},	// [3b6a0] _daso_, culá, --, --, 
   {{0xaac0038e,0x8afc02a8,0x26d8009d,0xa484065f}},	//   ष्ठक, _duƙu, _easo_, نجمن, 
   {{0x292801f1,0x23e40212,0x51f4872f,0x00000000}},	//   ýtať_, кіїв, کسار, --, 
   {{0x26da08ad,0x8778010f,0x00000000,0x00000000}},	//   _gaso_, _מאטי, --, --, 
   {{0x76440124,0x00000000,0x00000000,0x00000000}},	//   _рҭаа, --, --, --, 
   {{0x44f400c6,0x26d81cdf,0x41500816,0xe3b000d1}},	//   _gا_, _zaso_, гвіс, ارە_, 
   {{0x26d80028,0xdb0000e5,0x00000000,0x00000000}},	//   _yaso_, zulá, --, --, 
   {{0x3ebc00f3,0xdb0001d3,0x3f640798,0x00000000}},	//   gfut_, yulá, нијо_, --, 
   {{0xb16400fb,0xdb140241,0x4d240798,0x00000000}},	//   _анаһ, _ìbùs, еќна, --, 
   {{0x21740063,0x2490008e,0xdb0208ae,0xc19800d9}},	//   _јутр, _xezm_, nulæ, _משמי, 
   {{0xac184d15,0x00000000,0x00000000,0x00000000}},	//   фону_, --, --, --, 
   {{0xdb0208af,0xf1d407b7,0x00000000,0x00000000}},	//   tulá, _धनान, --, --, 
   {{0xdb005b47,0xc3300302,0x3d28a268,0x1ea8009f}},	//   kulæ, רור_, _کتنی_, _زاني_, 
   {{0x26d86985,0x2d8405da,0xe858009d,0xc864004e}},	//   _saso_, mpme_, дагш_, етби, 
   {{0x3cf48546,0x26da08b0,0x6d594dc1,0xdb01bf4b}},	//   _سعود_, _paso_, _ihva, dulæ, 
   {{0xf770a012,0xdb001ab0,0x26d80009,0x0a68ae1a}},	//   صاف_, pulá, _qaso_, _эрки_, 
   {{0x6d580165,0xaac02894,0xa4d801ec,0xc7640116}},	// [3b6b0] _khva, ष्णक, мдау_, _ۋاجى, 
   {{0x6fe010f7,0xdb001455,0xaab0c6cd,0x26d8e163}},	//   पटां, gulæ, _झाँक, _waso_, 
   {{0x26da08b1,0x641400c6,0x69d854cb,0x00000000}},	//   _taso_, خواط, मिकी, --, 
   {{0x26d80421,0x8afc03f9,0x179800d9,0x00000000}},	//   _uaso_, _tuƙu, _קירב, --, 
   {{0x6d58047e,0xd2a40408,0x81c00022,0x00000000}},	//   _ohva, _гiоь, уалҧ, --, 
   {{0x25aa08b2,0xd34401d5,0x7e7801ec,0x00000000}},	//   mral_, _ییله_, _ﺤﻘﻘﺕ_, --, 
   {{0xaab005f9,0x2d500327,0x00000000,0x00000000}},	//   _झांक, tàen_, --, --, 
   {{0x645608b3,0x6d5a08b4,0x00000000,0x00000000}},	//   _izzi, _ahva, --, --, 
   {{0x200800da,0x3ebc1529,0x6d5800b8,0x9b88004b}},	//   ņai_, rfut_, _bhva, ژندل_, 
   {{0x25aa08b5,0xac80001f,0x6d580306,0x70944965}},	//   iral_, _የአለም_, _chva, _бафф, 
   {{0x25a801f1,0x6d580882,0xbf8804fb,0xaec40220}},	//   hral_, _dhva, _رئال_, _әбіл, 
   {{0x25a8e3f1,0x92a4012d,0x6d5806be,0x00000000}},	//   kral_, _gołę, _ehva, --, 
   {{0x7e7a08b6,0xee840024,0x00000000,0x00000000}},	//   mcup, _сыхо, --, --, 
   {{0x64542b1d,0xdca4189d,0xa3d000cd,0xed580064}},	//   _ozzi, _раки, _वनं_, _зоі_, 
   {{0xdca42cc8,0x25aa08b7,0xdb0003b2,0x48e000d8}},	//   _заһи, eral_, vulæ, јосв, 
   {{0x7e781730,0x6d597a98,0x1da401f9,0x00000000}},	//   ncup, _zhva, _गटात, --, 
   {{0x645608b8,0x16643b2e,0x966400d8,0x00000000}},	// [3b6c0] _azzi, твам, ткае, --, 
   {{0x1b4c0201,0x3b000007,0xc4800452,0xdb0000ae}},	//   _ማህበራ, _hoiq_, илук, irlí, 
   {{0xd1e80125,0x7e78020c,0x25aa08b9,0xdb0000a2}},	//   _መደቡ_, kcup, aral_, gulç, 
   {{0x130812c4,0x03a000f3,0xdb0003b2,0x00000000}},	//   ьней_, рицо, sulæ, --, 
   {{0xdb0208ba,0x25aa08bb,0x64541418,0x161802ab}},	//   pulæ, cral_, _ezzi, _नेचर_, 
   {{0x3dd4045e,0xdb00005b,0xb1480330,0xf57401af}},	//   তমাল, lulä, ریام_, _аҫҡы, 
   {{0xf2c40131,0xdb00004e,0x6498010b,0x2b580118}},	//   _бөли, erlí, _ятяр_, ůrci_, 
   {{0x6d5804b9,0x7e783d1a,0x7ee016a0,0x2d840129}},	//   _shva, gcup, لكىن, tpme_, 
   {{0xdcb008c9,0x80bc0073,0xca7002f2,0x00000000}},	//   ڭىپ_, ल्हे, یندک, --, 
   {{0xbd842a60,0x2d840205,0xe8043174,0x00000000}},	//   کنین_, rpme_, रहमा_, --, 
   {{0xac740201,0xdb00cac9,0x7e78003e,0xaa9608bc}},	//   _በዓለም_, kulä, bcup, линч, 
   {{0x7e7a08bd,0xdb00002d,0xbb90023a,0x6e240153}},	//   ccup, erlâ, шающ, _žibu, 
   {{0x3b000226,0x80bcdc75,0xdb00fb94,0x00000000}},	//   _doiq_, ल्वे, dulä, --, 
   {{0x6d580bb8,0x25a90616,0xaca4063f,0xfbcc04fb}},	//   _uhva, vral_, _kpọz, حتی_, 
   {{0xd1e876e2,0x00000000,0x00000000,0x00000000}},	//   _መደብ_, --, --, --, 
   {{0xdb003f5b,0x25a85c66,0x316c00e2,0x00000000}},	//   gulä, tral_, _lidz_, --, 
   {{0x25aa08be,0xabb4035b,0xa2e4329e,0x00000000}},	// [3b6d0] ural_, _рақә, ғолд, --, 
   {{0x77241b49,0x25aa08bf,0xd5a4006c,0x24196d0b}},	//   _ተወልደ, rral_, اللی, нозы_, 
   {{0x046608c0,0x25a87e54,0xdb00007c,0x7b0800a2}},	//   ттам, sral_, bulä, _örtý, 
   {{0x25aa08c1,0x290047f8,0xf7700133,0x91c000d1}},	//   pral_, _hoha_, _گای_, әәтл, 
   {{0x290208c2,0xa0a46131,0xf8c0194b,0x36d4013d}},	//   _koha_, галд, श्वय, _тояр, 
   {{0xf7701c93,0xdedc010c,0x9580033f,0xc32c0014}},	//   _دای_, ንሳኤ_, żące, حٕچ_, 
   {{0x290003c1,0x645608c3,0x0d8002dd,0xc64400cf}},	//   _moha_, _uzzi, ұлын, _سئڭى, 
   {{0x290208c4,0x7e7800d8,0xdf480133,0xdb00007c}},	//   _loha_, ucup, رڤان_, ltlö, 
   {{0x629a08c5,0xde04d073,0x2900062c,0x332401af}},	//   mawo, уппи, _ooha_, _тєрб, 
   {{0x290208c6,0x629a08c7,0x224c009a,0x7e7a08c8}},	//   _noha_, lawo, _iyek_, scup, 
   {{0x907c1ee0,0x30f001bc,0x00000000,0x00000000}},	//   ዮጵያዊ_, चारः_, --, --, 
   {{0x62989614,0xdd943004,0x00000000,0x00000000}},	//   nawo, _бады, --, --, 
   {{0x290208c9,0x236e08ca,0xdb005b00,0xfdb000d1}},	//   _boha_, _miej_, ktlö, _тәйя, 
   {{0x7c84a68e,0x00000000,0x00000000,0x00000000}},	//   _руде, --, --, --, 
   {{0x629a08cb,0x290208cc,0xfce00032,0x1ae41171}},	//   kawo, _doha_, _боҙо, _бойм, 
   {{0x629a08cd,0x236c068f,0x224d6cfb,0x00000000}},	//   jawo, _niej_, _oyek_, --, 
   {{0x290003c1,0x224c79b8,0x629a08ce,0xdb00007c}},	// [3b6e0] _foha_, _nyek_, dawo, ftlö, 
   {{0x79840943,0xdb00023a,0x00000000,0x00000000}},	//   _itiw, sulä, --, --, 
   {{0xdb0208cf,0x224c009a,0x52a8010b,0x88b8010f}},	//   pulä, _ayek_, евем_, _אזיי, 
   {{0xf8c00882,0x1b4c0020,0x629a08d0,0x239801d3}},	//   श्रय, _ማኅበራ, gawo, ئمنگ_, 
   {{0x236c0200,0x914800d8,0x00000000,0x00000000}},	//   _diej_, нчка_, --, --, 
   {{0x80bcdaf5,0x6fb4007b,0x00000000,0x00000000}},	//   ल्ले, لمتا, --, --, 
   {{0x3d0402f8,0x4fc608d1,0x629a08d2,0xa0a40046}},	//   ाउने_, усла, bawo, ршіл, 
   {{0x3f800003,0x316c0210,0x00000000,0x00000000}},	//   _ħjut_, _widz_, --, --, 
   {{0x7984015c,0xdb000254,0xcd04009d,0x00000000}},	//   _ntiw, ntlõ, гчни, --, 
   {{0x020208d3,0x236c0200,0xaf540124,0x00000000}},	//   _узун, _ziej_, ынқә, --, 
   {{0x798608d4,0xbfe00022,0x29018bad,0x6c547705}},	//   _atiw, _гәыҩ, _roha_, ркну, 
   {{0x290208d5,0x00000000,0x00000000,0x00000000}},	//   _soha_, --, --, --, 
   {{0x290208d6,0xca2401d5,0x00000000,0x00000000}},	//   _poha_, уфни, --, --, 
   {{0x629a08d7,0x2f18002e,0x14c400dc,0x00000000}},	//   zawo, _bégg_, र्मण, --, 
   {{0x7984063f,0x290001a9,0x00000000,0x00000000}},	//   _etiw, _voha_, --, --, 
   {{0x2f181574,0x62981bce,0x22480210,0x7bc4031c}},	//   _dégg_, xawo, żaki_, ħjut, 
   {{0x290208d8,0x2bdc2894,0x62980810,0xdb0208d9}},	// [3b6f0] _toha_, यिका, vawo, ttlö, 
   {{0x236c06a3,0x629a08da,0xeab001d3,0xdd0c06be}},	//   _siej_, wawo, _اٹک_, _mışd, 
   {{0x629a08db,0x224c07ab,0x236c007f,0xdb00007c}},	//   tawo, _syek_, _piej_, rtlö, 
   {{0xdb0208dc,0x236c0240,0x34483e27,0x6b5c00e5}},	//   stlö, _qiej_, учун_, ségf, 
   {{0x629a08dd,0x5bd001bc,0xe80c0550,0x00000000}},	//   rawo, _तन्व, सनका_, --, 
   {{0x69cc0134,0x62980107,0x2f1800e8,0x2dc00116}},	//   _mpae, sawo, _yégg_, _ﻣﻪﻫﻤ, 
   {{0xdb0000d2,0x629a08de,0x5eb80154,0xa29400c0}},	//   gulû, pawo, _আসবে, _вабі, 
   {{0x224c1529,0x69cce02f,0xb6040419,0x4fc4010a}},	//   _tyek_, _opae, ťšes, ăсла, 
   {{0x224c003e,0x6b840219,0x00000000,0x00000000}},	//   _uyek_, _čiga, --, --, 
   {{0xdca4147e,0x61ea08df,0x1be80107,0xbff00117}},	//   јани, _irel, вдои_, _гӯиш, 
   {{0x69ce08e0,0x798608e1,0x61ea08e2,0x2d1800f2}},	//   _apae, _stiw, _hrel, دکنک_, 
   {{0xda643b76,0x61e80171,0x201803e3,0x00000000}},	//   ивни, _krel, _əsil_, --, 
   {{0x6b5c0098,0x4a4000a7,0xe98001ec,0x00000000}},	//   dégd, жняв, пқын, --, 
   {{0x61e8020c,0x00000000,0x00000000,0x00000000}},	//   _mrel, --, --, --, 
   {{0x61e8089c,0x7d0208e3,0x69cc00b0,0x9694c5fa}},	//   _lrel, _ions, _epae, ираш, 
   {{0x61ea08e4,0x7d0208e5,0x2bc800d8,0x4c38011a}},	//   _orel, _hons, _суљо_, _שתקב, 
   {{0x7d0208e6,0xdb0000d2,0x98a4447e,0x18a4013d}},	// [3b700] _kons, kulú, _кипе, _капм, 
   {{0xf84805f5,0x4484390e,0x00000000,0x00000000}},	//   _бүгд_, ибун_, --, --, 
   {{0x77943ef3,0x61e8349c,0x9344272a,0x7d017ccf}},	//   _دیزا, _arel, анже, _mons, 
   {{0x7d00055a,0x51840124,0x0838011a,0x11e42bbd}},	//   _lons, аука, _יעיל, ижем, 
   {{0x61e82d33,0x6b5c01ed,0x77642ab9,0x27ec00b0}},	//   _crel, ségg, mmix, āene_, 
   {{0x2fcc0077,0xdb0000d2,0xc20405a9,0x7d002517}},	//   _ppdg_, gulú, شقىن_, _nons, 
   {{0x6b5c7ca0,0x35ac09bb,0xd2a40354,0x00000000}},	//   lége, _चिड़, _гiаь, --, 
   {{0x61ea08e7,0x3ec02f45,0x7d000332,0xd1840305}},	//   _frel, осьб, _aons, _влай, 
   {{0x61ea08e8,0x7d005f23,0x64400162,0xdd0c03e3}},	//   _grel, _bons, _ølir, _qışd, 
   {{0x8fa41789,0xbd40007b,0xc1b8011a,0x00000000}},	//   _важе, ينيي, _בממש, --, 
   {{0x7d000579,0x69cc1c1d,0x6c3400c6,0x776401e3}},	//   _dons, _spae, صفحا, kmix, 
   {{0x7d00b4b7,0x35ac0210,0x00000000,0x00000000}},	//   _eons, _चिढ़, --, --, 
   {{0x7d015768,0x0c84807e,0x88d800cc,0x2f1800e5}},	//   _fons, _кыйм, দাসক, _cége_, 
   {{0x7d01e21c,0xebc40139,0xdd9800d7,0x6c84c009}},	//   _gons, _ләмн, gyňu_, _الغم, 
   {{0x9e240050,0x5eb80154,0xaa94030d,0x00000000}},	//   _پى۪و, _আসতে, _лийч, --, 
   {{0x6d4a08e9,0x7d000925,0x36880131,0x48e400bc}},	//   loda, _zons, исун_, _छोरो_, 
   {{0x7d0208ea,0x6b5c003e,0x6d48062c,0x00000000}},	// [3b710] _yons, régd, ooda, --, 
   {{0x6d4a08eb,0xe39002d3,0x61e80124,0xdb140241}},	//   noda, _ዝቐረበ_, _rrel, _ìbòs, 
   {{0x61e808ad,0x57b002dd,0x7764002f,0x69c4012d}},	//   _srel, _нұрт, bmix, ाझवी, 
   {{0x6d4a08ec,0x6b5cc00f,0x776400b5,0x21740107}},	//   hoda, légb, cmix, букр, 
   {{0x672c05d9,0x75440100,0xe80410fa,0x0594030d}},	//   miaj, ètzè, रहवा_, _тăлм, 
   {{0x61e82625,0x672e08ed,0x660e08ee,0x6d485bf7}},	//   _vrel, liaj, myak, joda, 
   {{0x6d4891e4,0x7d000731,0xaf980eed,0x68540023}},	//   doda, _rons, атых_, _መስሪት, 
   {{0x7d0208ef,0xf83806a9,0x672e08f0,0xd00c0f17}},	//   _sons, ינות_, niaj, علي_, 
   {{0x7d0208f1,0x6d4800a9,0xd34412e1,0x61ea08f2}},	//   _pons, foda, _اینه_, _urel, 
   {{0x6d4a08f3,0x660c1c06,0x672c00c5,0x77640306}},	//   goda, iyak, hiaj, zmix, 
   {{0x660e08f4,0x92d81c82,0x672c00ec,0x7d016310}},	//   hyak, ়াৰ_, kiaj, _vons, 
   {{0x7d0208f5,0x672c01f7,0x660e08f6,0x6d4801ab}},	//   _wons, jiaj, kyak, aoda, 
   {{0x6d4a08f7,0x672e08f8,0x5d840597,0xf8b00214}},	//   boda, diaj, _التل, وکد_, 
   {{0x2f1801ed,0x6d481be1,0x97d825ec,0x660e08f9}},	//   _vége_, coda, льбу_, dyak, 
   {{0x31d409ae,0x672e08fa,0x00000000,0x00000000}},	//   _धन्ध, fiaj, --, --, 
   {{0x6b5c20ef,0x672e08fb,0x69cc0037,0x00000000}},	//   tége, giaj, äleõ, --, 
   {{0x776608fc,0x660e08fd,0xdce800e2,0xd1f80b82}},	// [3b720] rmix, gyak, kseļ, ላባት_, 
   {{0x2ed419e5,0x56940184,0x6b5c0129,0x672c0254}},	//   _दस्त, раҡт, rége, aiaj, 
   {{0x6b5c00f8,0x660e08fe,0x672e08ff,0x2cb8068c}},	//   sége, ayak, biaj, òrdi_, 
   {{0x672c008f,0x660e0900,0x00000000,0x00000000}},	//   ciaj, byak, --, --, 
   {{0x6d4a0901,0x660c0230,0xc2940953,0xf0780116}},	//   yoda, cyak, скіх_, қиқә_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d4a0902,0x95600198,0x0874008f,0x6b860903}},	//   voda, ttمf, זעצט_, _čigo, 
   {{0x6d4a0904,0x00000000,0x00000000,0x00000000}},	//   woda, --, --, --, 
   {{0x6d494821,0xd20400cf,0x50b82f84,0x10a4022e}},	//   toda, _ابزى, _مداد_, _гизн, 
   {{0xdb000e78,0x29100175,0x672e0905,0x21760906}},	//   hrlä, xkza_, ziaj, _футр, 
   {{0x1ea805d9,0x3ed42586,0x00000000,0x00000000}},	//   _چاهي_, _گونج_, --, --, 
   {{0x6d4a0907,0x660c3142,0x1ea800b2,0x00000000}},	//   soda, yyak, _ناهي_, --, 
   {{0x672c2cf4,0x6d4a0908,0xf74c001f,0x00000000}},	//   viaj, poda, _መሥዋዕ, --, 
   {{0x672c068f,0x29042242,0xdf745a05,0x660e0909}},	//   wiaj, ðla_, _ادەب, vyak, 
   {{0x672c252b,0xe8d802e3,0x660c0784,0x7e840129}},	//   tiaj, _ntụ_, wyak, _éspé, 
   {{0x660e090a,0x6b5c01ed,0x37040798,0x00000000}},	//   tyak, ségb, пчув, --, 
   {{0x672e090b,0xe8d800b4,0x6e200399,0x660c0810}},	// [3b730] riaj, _atụ_, nzmb, uyak, 
   {{0x660e090c,0x672e090d,0x00000000,0x00000000}},	//   ryak, siaj, --, --, 
   {{0x660e090e,0x3e6c70e3,0x8cc8bc82,0x672c0698}},	//   syak, _kötü_, त्यो, piaj, 
   {{0x7cfc0b21,0x00000000,0x00000000,0x00000000}},	//   _dêry, --, --, --, 
   {{0x673c0d27,0x06641a69,0x660c0309,0x23800064}},	//   _ijsj, _دادپ, qyak, _dėja_, 
   {{0x216913dc,0xb0c40950,0x00000000,0x00000000}},	//   шили_, ल्लग, --, --, 
   {{0xdbf00316,0xaaa801ad,0x229c0153,0x23800153}},	//   _přít, कणाक, eškų_, _fėja_, 
   {{0x22480254,0x00000000,0x00000000,0x00000000}},	//   üaks_, --, --, --, 
   {{0x23c800bc,0xf1940108,0x14c400cd,0x00000000}},	//   _रहँद, _нить, र्वण, --, 
   {{0x2b90004b,0xc0d00092,0xa158003b,0x00000000}},	//   ډیوس, ሩትም_, _тазу_, --, 
   {{0xef180137,0xdbf001ef,0x00000000,0x00000000}},	//   рмө_, _třít, --, --, 
   {{0x1b4801a9,0x28740124,0x00000000,0x00000000}},	//   рзми_, ҧыср, --, --, 
   {{0xdca6090f,0x7de4e37b,0x5ca4d202,0xe1900023}},	//   _дали, _دسام, _дилб, _ዚነበሩ_, 
   {{0xdc68084c,0x9be80107,0x00000000,0x00000000}},	//   _калд_, _вмкб_, --, --, 
   {{0x18698bc7,0x5d8401f7,0x00000000,0x00000000}},	//   рави_, _الڪل, --, --, 
   {{0x26c8003e,0x3e6c0790,0xc68c0014,0x9f4401ef}},	//   gfao_, _götü_, ہِہ_, _orlí_, 
   {{0x7ae60910,0xdb000267,0xd874121a,0xda642abb}},	// [3b740] _iait, rrlä, _وادب, _باغي, 
   {{0x7ae60911,0x2f1a0912,0x6b5c0129,0x238000c0}},	//   _hait, _méga_, méga, _sėja_, 
   {{0x7ae60913,0x6b5c07ea,0x14c41221,0xd3b800d4}},	//   _kait, léga, र्षण, рузі_, 
   {{0x7ae60914,0x0cc000d1,0x00000000,0x00000000}},	//   _jait, ﯩﻴﯘﺗ, --, --, 
   {{0x7ae60915,0x6b5ca51c,0x7cfc045f,0xf194bdf1}},	//   _mait, néga, _wêry, чиль, 
   {{0x7ae60916,0x753c012d,0x00000000,0x00000000}},	//   _lait, _ujrz, --, --, 
   {{0xea00001e,0x7f81c59e,0x6b5e0917,0xdb00017a}},	//   _đậu_, ولون, héga, rslê, 
   {{0x7ae60918,0x0ee80108,0x877800df,0x00000000}},	//   _nait, рьки_, סאפי, --, 
   {{0x10a4299f,0x0d20004e,0x00000000,0x00000000}},	//   _миан, мүдү, --, --, 
   {{0xb0c4004b,0x7ae4017a,0x85f4008f,0x6b5c003e}},	//   _رښتي, _aait, קציע_, déga, 
   {{0x7ae60919,0xe0d00014,0x9f3400e5,0x00000000}},	//   _bait, _سزٕ_, _کونڈ, --, 
   {{0x9e66091a,0x7ae6091b,0x53d01b76,0x00000000}},	//   _کامن, _cait, _सहनश, --, 
   {{0x7ae6091c,0x6b5c003e,0xdbd8010e,0x7e241cb8}},	//   _dait, géga, _içýa, _міша_, 
   {{0xdb00010e,0x00000000,0x00000000,0x00000000}},	//   mulý, --, --, --, 
   {{0x7ae6091d,0x80bc1025,0x61ec01e4,0xdb000162}},	//   _fait, ल्टे, ĥali, lulý, 
   {{0x7ae6091e,0x6b5c003e,0x00000000,0x00000000}},	//   _gait, béga, --, --, 
   {{0xdb000122,0x59b000c5,0x00000000,0x00000000}},	// [3b750] nulý, _जियर, --, --, 
   {{0x7ae6091f,0x6abe0920,0xdb00007c,0x6fbc01f9}},	//   _zait, lgsf, rrlå, ्झां, 
   {{0x7ae405ba,0x44260921,0x2294007b,0x00000000}},	//   _yait, àn_, كلاس, --, 
   {{0x8cc80e7d,0x6aac015b,0x7ae4022e,0x02a402dd}},	//   त्तो, ট্রো, _xait, ірем, 
   {{0x68e4049b,0x5eb8015b,0xa15821b5,0x00000000}},	//   _kahd, _আসলে, баду_, --, 
   {{0x68e60922,0xdbd800ee,0xc0c8e36e,0xe2c8132f}},	//   _jahd, _açýa, руде_, _گورو_, 
   {{0xa2950ee8,0x02a60923,0x68e60924,0x50300023}},	//   _наві, _мрам, _mahd, _ክንረኽ, 
   {{0x657daef9,0x68e60925,0x657604cb,0xe2ca0926}},	//   _kush, _lahd, _hizh, _دورو_, 
   {{0x7ae60927,0x00280020,0x657405c7,0x657c0200}},	//   _rait, _እንዲኖ, _kizh, _jush, 
   {{0x7ae60928,0x657e0929,0xdef801e0,0x5f80237e}},	//   _sait, _mush, рыҫ_, _كۇتە, 
   {{0x657c0084,0x7ae6092a,0x6574004c,0xe9f80241}},	//   _lush, _pait, _mizh, _idẹ_, 
   {{0x657403bd,0x2f18525e,0x6abc1061,0x657c00b5}},	//   _lizh, _téga_, ggsf, _oush, 
   {{0x7ae6092b,0x657e092c,0x68e6092d,0x1fbc0154}},	//   _vait, _nush, _bahd, _আনিস, 
   {{0x65740656,0x7ae6092e,0x6b5c06af,0x68e42988}},	//   _nizh, _wait, réga, _cahd, 
   {{0x7ae6092f,0x657c441b,0x68e40098,0xdca4134b}},	//   _tait, _aush, _dahd, _даһи, 
   {{0x657c81fb,0x7ae60930,0x9c140588,0xab2801f7}},	//   _bush, _uait, _мчқә, _وسيل_, 
   {{0x68e60931,0x65757a98,0x64540166,0x00000000}},	// [3b760] _fahd, _bizh, _ayzi, --, 
   {{0x68e40076,0x068001c0,0x63a40200,0x00000000}},	//   _gahd, _үгэн, fshn, --, 
   {{0x65740156,0x64540393,0x238000c0,0xdedc0023}},	//   _dizh, _cyzi, _dėjo_, ንሳን_, 
   {{0x657e0932,0xe3b0040b,0x65740489,0x6454d033}},	//   _fush, کرے_, _eizh, _dyzi, 
   {{0x657e0933,0x2f1804cc,0x68e4045d,0xaac01d27}},	//   _gush, _bégn_, _yahd, ष्टक, 
   {{0x64540232,0x65740369,0xf8c033ff,0x0ce400cc}},	//   _fyzi, _gizh, श्चय, _পক্ত, 
   {{0x04409785,0xb4b805b3,0x6b5c003e,0xdb0001d3}},	//   _зерн, छली_, dégn, nuló, 
   {{0x657e0934,0xadf60935,0xdb000209,0x657405c7}},	//   _yush, дпиш, tulý, _zizh, 
   {{0x434005c5,0x657c3089,0xbb5800b5,0xdb0000e5}},	//   _четв, _xush, mのhd, cslé, 
   {{0xdb01b094,0x6b5c0098,0x71a40117,0x00000000}},	//   kuló, gégn, _нағз, --, 
   {{0xdbf00316,0x68e4e3db,0xdb020936,0xead828f6}},	//   _přát, _rahd, juló, омні_, 
   {{0x68e4102c,0xaa592a59,0xdbd80432,0xdb0000e5}},	//   _sahd, жиму_, _uçýa, duló, 
   {{0x68e40455,0x39580175,0x69dc282c,0x2cb80ba1}},	//   _pahd, flrs_, uwse, òrds_, 
   {{0x61ec0cc1,0x67d489ed,0x657ccebf,0xac18dd4c}},	//   çilə, могу, _rush, _молу_, 
   {{0x68e60937,0x2f18002e,0x65740156,0xdb000d12}},	//   _vahd, _jégo_, _rizh, guló, 
   {{0x443c04b9,0x68e40003,0x65740dd4,0x657e0938}},	//   _ću_, _wahd, _sizh, _push, 
   {{0x68e60939,0x6aae093a,0x65740489,0x657e093b}},	// [3b770] _tahd, _idaf, _pizh, _qush, 
   {{0x04641e80,0xdb00baa9,0x657e093c,0x2b58002f}},	//   птем, buló, _vush, llsc_, 
   {{0x23800024,0xdb02093d,0x6b5c06af,0x2f180129}},	//   _vėjo_, culó, négo, _négo_, 
   {{0x657e093e,0xdedc02d3,0xb9e802d3,0x3d2001e1}},	//   _tush, ንታን_, _ይቲ_, _kéwù_, 
   {{0x65740dd4,0x657e093f,0x2f1805d5,0xdb000036}},	//   _tizh, _uush, _pégn_, uslé, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd0040801,0xe2d80014,0xdb000036,0x6aae0940}},	//   деще_, _وارچ_, sslé, _odaf, 
   {{0x6aae0941,0x80e00154,0x70540408,0x41e412fa}},	//   _ndaf, পাধ্, хĕсе, _ніза, 
   {{0x6289791b,0x00000000,0x00000000,0x00000000}},	//   _ifeo, --, --, --, 
   {{0x6aae0942,0x5ba8673b,0x22a8004b,0x714400f7}},	//   _adaf, оком_, _دنړۍ_, _كۉنۅ, 
   {{0x6dc4411c,0xdb000205,0xfbcc00ec,0x00000000}},	//   وزیل, pulü, اڪت_, --, 
   {{0xdd94113e,0x6b5c01d3,0x00000000,0x00000000}},	//   _жады, ségn, --, --, 
   {{0x6aac015d,0x04080051,0x00000000,0x00000000}},	//   _ddaf, tượn, --, --, 
   {{0x3ebe0943,0x3d2001e1,0x6aae0944,0x00000000}},	//   lgut_, _déwù_, _edaf, --, 
   {{0x102c069c,0xb2e400fd,0x1ae40150,0xcc8402f2}},	//   _እንተዘ, _äñgä, _жойм, _تۆپه_, 
   {{0x3ddc0086,0x3ce405c7,0x9aa4a9f1,0xa75427a8}},	//   owuw_, _hanv_, _غمخو, етущ, 
   {{0x3ce40165,0x3ebc067c,0x8cc8d0f6,0xaae56a15}},	// [3b780] _kanv_, igut_, त्वो, _سسيو, 
   {{0xb4b8068f,0x62880421,0x3ce60945,0x34d800ab}},	//   छले_, _afeo, _janv_, ड़ेद, 
   {{0x18683eeb,0x98140f1c,0x48e4012c,0x3ce40055}},	//   _фани_, _آبخا, _छोटो_, _manv_, 
   {{0x95847232,0x0cd828b8,0x3ce40489,0x00000000}},	//   _олме, _भस्म, _lanv_, --, 
   {{0x754400c7,0xd14808f0,0x00000000,0x00000000}},	//   _зҽаз, يشتن_, --, --, 
   {{0x2f180098,0x3ce400cd,0x00000000,0x00000000}},	//   _pégo_, _nanv_, --, --, 
   {{0x8898011a,0x4fc401d5,0x28b00f4a,0x00000000}},	//   קבקי, фсла, _जयसि, --, 
   {{0x3ebc00d5,0xef1800ef,0xee44035b,0x00000000}},	//   ggut_, _buļa_, нҭеи, --, 
   {{0xc20c0014,0x302800f1,0x5c300023,0x61b00116}},	//   _پٔل_, تيژۍ_, _ኣንጾክ, _مەنا, 
   {{0x6b5e0946,0x3ebccad7,0x5dbc00d1,0x25f00456}},	//   tégo, agut_, _ﻣﻪﻗﺴ, ीमती_, 
   {{0x3ebc002f,0xdff40153,0x00000000,0x00000000}},	//   bgut_, _пяць, --, --, 
   {{0x6b5c0129,0x2ec400db,0xe79400e5,0x00000000}},	//   régo, _чөкм, ہارک, --, 
   {{0xff240502,0xa27802d3,0x1ee803e6,0xa3e409bb}},	//   _تبلی, ኮንኩን_, _رووی_, _बैन_, 
   {{0xfc2c1060,0x00000000,0x00000000,0x00000000}},	//   احی_, --, --, --, 
   {{0x4b504732,0x70dc012c,0x3d280214,0x00000000}},	//   _لێدر, _यसैल, _بتنی_, --, 
   {{0x8cca0947,0x6aae0948,0x36d455f3,0x00000000}},	//   त्रो, _udaf, коср, --, 
   {{0xf6503ccf,0x89a40014,0xbb4800f1,0xf8b860a1}},	// [3b790] لئك_, _تھجہ_, _تلين_, чөө_, 
   {{0x04200014,0x00000000,0x00000000,0x00000000}},	//   پہرُ, --, --, --, 
   {{0xa774ee8b,0xe85801c0,0x00000000,0x00000000}},	//   _плоч, _ханш_, --, --, 
   {{0x65940b96,0xa3e400c5,0xe5083bd7,0x00000000}},	//   _паму, _बईठ_, _کيسو_, --, 
   {{0xa15a0949,0x4570008e,0x00000000,0x00000000}},	//   паду_, _аңар, --, --, 
   {{0x25aa094a,0xdedc010c,0xd5980375,0x00000000}},	//   msal_, ንዳን_, _מבשל, --, 
   {{0x25aa094b,0x3ebe094c,0xa0c40150,0x00000000}},	//   lsal_, tgut_, _ۋيرو, --, 
   {{0xf36400a8,0x3ebc0869,0x3e340023,0x25aa094d}},	//   _атун, ugut_, _ክትከይ, osal_, 
   {{0x3ebe094e,0x3d18012c,0x6b5c0129,0x31c4030d}},	//   rgut_, यसले_, régl, _асхв, 
   {{0x25aa094f,0x3ebc236c,0xcd24030d,0x0e601ee1}},	//   isal_, sgut_, ежье_, ыкын, 
   {{0x25a847af,0x98a80356,0xdbdc00e4,0xa3e4000d}},	//   hsal_, hibă_, tãñe, _बैम_, 
   {{0x25a80342,0x6e240135,0x00000000,0x00000000}},	//   ksal_, _żibe, --, --, 
   {{0x7f5806be,0x00000000,0x00000000,0x00000000}},	//   mluq, --, --, --, 
   {{0x7f5a0950,0x25a9292e,0xdcf8dc06,0x00000000}},	//   lluq, dsal_, _رفعت_, --, 
   {{0xc84000ee,0xdb000174,0xe75800b8,0x00000000}},	//   герй, lslí, _ṅgaṃ_, --, 
   {{0x25a803e0,0xcba01171,0x70dc09ab,0x7f580213}},	//   fsal_, _саъй, _यस्ल, nluq, 
   {{0xea0001dc,0xdb00022c,0x25a804fb,0x2774005b}},	// [3b7a0] _đầu_, nslí, gsal_, тырё, 
   {{0x77960951,0x20180213,0x7f5801a9,0x2904007c}},	//   _لیسا, _əsir_, hluq, ölat_, 
   {{0xd7e80372,0x14c400dc,0x25a9074b,0x00000000}},	//   _эмне_, र्गण, asal_, --, 
   {{0xfe640cd2,0x96b89717,0xdb00002d,0x969437fb}},	//   _مد_, _عاجز_, lslâ, _ярош, 
   {{0xa3e40c2e,0x25a830f9,0xe2803500,0x7f5803b9}},	//   _बैठ_, csal_, рғун, dluq, 
   {{0xdb020952,0xe45001d3,0x00000000,0x00000000}},	//   nslâ, اضے_, --, --, 
   {{0xa4900133,0x00000000,0x00000000,0x00000000}},	//   _ئیمت, --, --, --, 
   {{0x2dd4022e,0x7ff0f5f9,0xdb00032e,0x00000000}},	//   вжир, اسوا, fslí, --, 
   {{0xdb000252,0xdd90004b,0x00000000,0x00000000}},	//   gslí, ټوپ_, --, --, 
   {{0xd17400fd,0xeb182cfd,0x22580162,0xa3e4012d}},	//   _чыбы, दस्त_, _øska_, _बैड_, 
   {{0xe570008f,0xdb00002d,0x71440137,0xdcb015bf}},	//   יַט_, dslâ, _كۉچۅ, جىپ_, 
   {{0xa4fc000b,0x25a93e46,0xbd849a87,0x3eac0051}},	//   _उच्च_, ysal_, بنین_, _gdgt_, 
   {{0x80e0015b,0x6b840010,0x00000000,0x00000000}},	//   পার্, _čigu, --, --, 
   {{0xfbcc0ec9,0x00000000,0x00000000,0x00000000}},	//   جتی_, --, --, --, 
   {{0xfbcc00b2,0xe758003b,0x06683769,0x00000000}},	//   _هتي_, диві_, ﻳﯩﻨﯩ, --, 
   {{0xb3b8015b,0x7bcc033f,0xdce80135,0xe76c02dd}},	//   ীবাজ, ńcuc, mpeġ, _ﺳﺎﺗﯟ, 
   {{0x25aa0953,0x7eb80166,0x00000000,0x00000000}},	// [3b7b0] usal_, läpü, --, --, 
   {{0xf9909f9c,0xd04400ac,0x3e840241,0x00000000}},	//   _ابي_, şmən, _kító_, --, 
   {{0x25aa0954,0x66b44eca,0x00000000,0x00000000}},	//   ssal_, _ибну, --, --, 
   {{0x25a80316,0x45a00075,0x627402eb,0x6b9c01d3}},	//   psal_, _مەرك, نهائ, árgy, 
   {{0x6594041b,0x4ad00303,0xbb340150,0x00000000}},	//   _јагу, ध्यव, _ﺭﺃﻴ_, --, 
   {{0xe8d806d9,0xd05806be,0x64c401c8,0x00000000}},	//   _itỳ_, _hatə, _جيسل, --, 
   {{0xd12c765c,0x229400c6,0x09b80327,0x7f58031c}},	//   تمو_, _للأس, _ངའྀ_, tluq, 
   {{0x942400db,0xdb000413,0x00000000,0x00000000}},	//   _شوقۇ, tslí, --, --, 
   {{0xdb00334b,0x629800ca,0xd05803e3,0xe50400cd}},	//   yslâ, mbwo, _matə, रापि_, 
   {{0xe2980184,0x6b5c0332,0x00000000,0x00000000}},	//   _хаҡ_, légh, --, --, 
   {{0x70940117,0x00000000,0x00000000,0x00000000}},	//   _сахф, --, --, --, 
   {{0x09d804c5,0xde940640,0x7f587caa,0xd05803e3}},	//   দিনা, _радњ, qluq, _natə, 
   {{0xdb020955,0x0b40177b,0x1a640344,0x986806be}},	//   tslâ, рнян, کیکی_, _bığa_, 
   {{0x18680517,0x6fd8032c,0x7f780150,0x91b873cd}},	//   даги_, _महमू, _ﺍﻭل_, ומשי, 
   {{0xea0007ae,0xfbc40046,0xe8d806d9,0xdb00000f}},	//   _đấu_, _яғни_, _atỳ_, rslâ, 
   {{0x290401e3,0x00000000,0x00000000,0x00000000}},	//   ölar_, --, --, --, 
   {{0x06820956,0x9408013f,0x2a3401c6,0x248c03e0}},	// [3b7c0] ргун, _rebɑ_, _бээр, _şema_, 
   {{0xe6c82804,0x178400f3,0x00000000,0x00000000}},	//   čašć, _игом, --, --, 
   {{0xe8d806d9,0x79860957,0xa3e40037,0x00000000}},	//   _etỳ_, _huiw, _बैद_, --, 
   {{0x64420958,0xd0102be7,0x79851e79,0xa3c005f9}},	//   _žlic, یلش_, _kuiw, ंढ़_, 
   {{0xa9046b18,0x986803b9,0x00000000,0x00000000}},	//   _شبین, _yığa_, --, --, 
   {{0x415001ce,0x85440024,0x62980083,0xd05803b9}},	//   авіс, _plėš, abwo, _zatə, 
   {{0x03a20959,0x5ebc0011,0xdd98010e,0x00000000}},	//   _висо, ্জনে, myňy_, --, 
   {{0x0440d0e2,0xff4c035d,0x6b5c003e,0xd05803b9}},	//   _тесн, يخي_, régk, _xatə, 
   {{0x3f84022f,0x6b5c01d3,0xdd8c0116,0x00000000}},	//   aqnu_, ségk, كۈن_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2f19b94d,0x6b5e095a,0x6b74026b,0xdb000254}},	//   _légi_, légi, ллоу, hulõ, 
   {{0x79844d11,0xdb00002f,0x3e84032e,0x00000000}},	//   _buiw, zulö, _vító_, --, 
   {{0x79840175,0x7dec01ed,0x20c807c1,0xdb000254}},	//   _cuiw, rősö, _रामध, julõ, 
   {{0x79840660,0xa13c0142,0x61fc03b2,0x95880023}},	//   _duiw, _gwŷd, _ásle, ዛእትን_, 
   {{0x7aec023a,0x7f84008e,0x7d780a7c,0xecd80412}},	//   öltä, _nıql, _קרוג, _बॉयफ, 
   {{0x0af005f5,0x27ec01e4,0xf4080154,0x3c74011a}},	//   _түмэ, ĉen_, লনার_, _בתום_, 
   {{0x79840c09,0x57b00046,0xe944030f,0x00000000}},	// [3b7d0] _guiw, _құтт, _مردی, --, 
   {{0x5eb80154,0xdd98010b,0x00000000,0x00000000}},	//   _আসছে, gyňy_, --, --, 
   {{0xf4847bb3,0xa0a6095b,0xe2b401c6,0xdb000174}},	//   руун, қайд, гслэ, lslá, 
   {{0x798400b5,0xb9ec001f,0x15cc00d1,0xdef00023}},	//   _yuiw, _ንቁ_, _ﻗﻪﺩﻩ, ቂትን_, 
   {{0x22480598,0x6d58151c,0x2f1801e1,0xdd98010e}},	//   çak_, _okva, _gégi_, byňy_, 
   {{0x9fc90b85,0x3494bc6c,0x6b5c01d3,0x74b833ae}},	//   егка_, _варр, ségh, _لطفآ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6b88074d,0xfbd8045e,0x6b5c019f,0x4270010a}},	//   dqdg, ধিমত, bégi, _кӳлс, 
   {{0x9e6401d5,0xdb0000d0,0x00000000,0x00000000}},	//   داغن, jslá, --, --, 
   {{0x798427c4,0x61ea095c,0x6d58010a,0xc0c400f1}},	//   _ruiw, _isel, _ckva, _شېبه_, 
   {{0x79840660,0xf0b800cf,0x5f946c66,0x00000000}},	//   _suiw, _جاقش_, _сиет, --, 
   {{0x6d5a095d,0x5e5825aa,0x79840069,0xfa840116}},	//   _ekva, _كلاس_, _puiw, шқим, 
   {{0x6d581132,0x61e8031c,0x00000000,0x00000000}},	//   _fkva, _jsel, --, --, 
   {{0x2f1800dd,0x61e8009f,0x00000000,0x00000000}},	//   _régi_, _msel, --, --, 
   {{0xdb000332,0x2f180241,0x00000000,0x00000000}},	//   aslá, _ségi_, --, --, 
   {{0x61e9a439,0x7986095e,0x2fd800af,0x142402dd}},	//   _osel, _tuiw, _ärge_, ңдам, 
   {{0x61ea095f,0x166473b8,0x18a4010b,0x96651846}},	// [3b7e0] _nsel, увам, _йапм, укае, 
   {{0x64400419,0x2f1800e5,0x00000000,0x00000000}},	//   _žlia, _végi_, --, --, 
   {{0x17c82de5,0x779402f2,0xdb000254,0x00000000}},	//   _ягни_, _خیزا, sulõ, --, 
   {{0x6b5db1cd,0xd2440323,0x23f40107,0xab0400b8}},	//   tégi, лэли, шчуё, _veṇṇ, 
   {{0x61e8795e,0x00000000,0x00000000,0x00000000}},	//   _csel, --, --, --, 
   {{0xe5040882,0x61e80036,0x7f8403e3,0x261000bc}},	//   राणि_, _dsel, _tıql, णहरी_, 
   {{0x61e89b6c,0x6b5c01d3,0xc0cc0023,0xdb0001bf}},	//   _esel, ségi, _ባጤራ_, mslæ, 
   {{0x7ee00952,0x61e80327,0x09d8009e,0xa2c00166}},	//   مكىن, _fsel, দিতা, _дәшк, 
   {{0x61e80129,0x90b4009b,0x00000000,0x00000000}},	//   _gsel, _бљеш, --, --, 
   {{0x3b0007d6,0x2d50004e,0x561003d4,0x6d341b0a}},	//   _aniq_, làez_, _সেৱক_, реоф, 
   {{0x1ee804fb,0x61e801d3,0x8538011a,0xe5046a60}},	//   رویی_, _zsel, תגיי, राति_, 
   {{0x61e80857,0x4e2987de,0xbea00114,0xdb0003b2}},	//   _ysel, _поен_, _гацк, tslá, 
   {{0x61e80175,0xdb013539,0x0c8401ee,0x506401af}},	//   _xsel, kslæ, _йыйм, _ртҡа, 
   {{0x6d58151c,0xac9400cf,0x2bc4466d,0x87e468eb}},	//   _ukva, _такш, लंदा, любе, 
   {{0x203402d3,0xdb00005c,0xdc541bf4,0x60d403e0}},	//   _እንተረ, dslæ, _پروک, _özme, 
   {{0x7bcc0276,0x28b002ab,0x00000000,0x00000000}},	//   ăcut, _जयकि, --, --, 
   {{0xa5360960,0xdb0002d2,0x00000000,0x00000000}},	// [3b7f0] анач, fslæ, --, --, 
   {{0x98a80064,0xdb01390f,0x00000000,0x00000000}},	//   kibę_, gslæ, --, --, 
   {{0x61e890d8,0x290000a2,0x57b001ec,0xf990085b}},	//   _ssel, _inha_, _мұрт, _وبی_, 
   {{0x61e80254,0x6d200118,0x00000000,0x00000000}},	//   _psel, यसँग_, --, --, 
   {{0xa0a47bb3,0xe1880046,0xa3e40dad,0x860401d9}},	//   аалд, төбе_, _बैर_, _صبحٕ, 
   {{0x1fb60961,0xb5241e76,0x61ea0962,0x61440640}},	//   асир, _льск, _vsel, јека, 
   {{0x6b5c07ea,0x2af405f9,0x5f040395,0x00000000}},	//   légu, इयाँ_, изка, --, 
   {{0x61e82d32,0xf838011a,0x00000000,0x00000000}},	//   _tsel, טנות_, --, --, 
   {{0x290018f7,0x4f060963,0x61ea0964,0x0d820965}},	//   _onha_, рнын_, _usel, олын, 
   {{0x71f801d9,0x23cc0150,0x6ffc054e,0xb65c010f}},	//   _حرفس_, _ءﯨﻨﻰ_, _băcă, עדזש, 
   {{0x30840491,0x236c0211,0x2a6a0966,0x6ffc0356}},	//   _المف, _khej_, _azab_, _căcă, 
   {{0xbf6521cf,0x2f18002e,0x9b34074d,0x00000000}},	//   _صداو, _bégu_, рхош, --, 
   {{0xd3540375,0xba04015b,0x6b5c00e4,0x02d41d03}},	//   שירי_, উন্ড_, jégu, ण्यभ, 
   {{0x7c848046,0x2b4806af,0x6ffc054e,0x00000000}},	//   _суде, _ejac_, _făcă, --, 
   {{0xa3e48919,0x64400010,0x00000000,0x00000000}},	//   _बैल_, _žlin, --, --, 
   {{0x9408016b,0x6fd8924b,0x29000098,0xe1f80024}},	//   _mebɔ_, _महसू, _enha_, _orų_, 
  
   {{0xaac40eff,0x6ffc0356,0x6b5c00e4,0x27e40327}},	// [3b800] _اتىن, _zăcă, gégu, ħlna_, 
   {{0x461001d5,0x831401d5,0x94940816,0x00000000}},	//   غولر, یقلر_, ршач, --, 
   {{0x395a0967,0xe1f80153,0xdb00bc85,0x6a6801a9}},	//   mors_, _arų_, rslæ, vоfi, 
   {{0x236c0455,0x6b5c01ed,0x395a0968,0x15d40014}},	//   _chej_, ségv, lors_, _ٖگاں_, 
   {{0x290000ee,0xdb000267,0x00000000,0x00000000}},	//   _ynha_, mslä, --, --, 
   {{0x395a0969,0xdb015408,0x6fb4007b,0x00000000}},	//   nors_, lslä, ممتا, --, 
   {{0x0442096a,0xbfa4023a,0xa0a402dd,0xa08801ec}},	//   _дерн, атые_, сшіл, усіз_, 
   {{0x395a096b,0xdb007a45,0x00000000,0x00000000}},	//   hors_, nslä, --, --, 
   {{0x395a096c,0xcd06096d,0xdb00d811,0x00000000}},	//   kors_, ачни, islä, --, 
   {{0x3958e793,0x2b4806a3,0x6ffc0276,0x625802bf}},	//   jors_, _sjac_, _păcă, _срср_, 
   {{0x39595e88,0x9e700092,0x6c540108,0xdb0001e3}},	//   dors_, _ብድርና_, скну, kslä, 
   {{0x6ffc054e,0x37cc00fe,0x70b801af,0x00000000}},	//   _văcă, াবাৰ, _шѳғѳ_, --, 
   {{0x395871dd,0xdb005b00,0x2b4800d7,0xab5c0171}},	//   fors_, dslä, _vjac_, guļa, 
   {{0x228c110e,0xfce03cc5,0x6b5c0124,0x00000000}},	//   _kókó_, _мочо, végu, --, 
   {{0x228c01e1,0x7c30010b,0x2cacc990,0x98a80118}},	//   _jókó_, _мешх, madd_, libě_, 
   {{0x3706096e,0x26d80e14,0xdb0001e6,0x2cac0368}},	//   очув, _qbso_, gslä, ladd_, 
   {{0x395a096f,0xa4d8005e,0x228c01e1,0x35f40835}},	// [3b810] bors_, лдау_, _lókó_, оптр, 
   {{0x2901b48e,0x395a0970,0x6b5e0971,0x236c0200}},	//   _unha_, cors_, régu, _shej_, 
   {{0x236c0218,0x6b5c00c7,0x24540137,0x6b5400e4}},	//   _phej_, ségu, حناس, ỹgua, 
   {{0x2b5a0972,0x9408013f,0xa7440150,0xb384496f}},	//   nosc_, _rebɔ_, _اۋرە_, іліл, 
   {{0xc764afa0,0x2cac03cd,0xed5800d7,0xd00c00e5}},	//   _ماڭى, kadd_, koľ_, ہلو_, 
   {{0x602405f5,0x10a0275b,0xf7f4141d,0x2cac0162}},	//   йдла, пишн, _اسید, jadd_, 
   {{0x26c80421,0xd00c3229,0xdb001f53,0x236c0200}},	//   ogao_, فلو_, lslå, _thej_, 
   {{0x26ca0973,0x24880006,0x6fd800e1,0x395a0974}},	//   ngao_, šimą_, _महरू, zors_, 
   {{0xdb0013ce,0xf3c402dd,0x395a0975,0xf194020f}},	//   nslå, _ءﻧﻮﻣ, yors_, _мить, 
   {{0x0d810ee8,0x00000000,0x00000000,0x00000000}},	//   яльн, --, --, --, 
   {{0x395a0976,0x38c86bef,0xcb941550,0x4b8400ee}},	//   vors_, یاسی_, ینیش_, ййэн_, 
   {{0x395805e4,0xdb00a3d3,0x2b580210,0x00000000}},	//   wors_, kslå, gosc_, --, 
   {{0x395a0977,0x5a3c02d3,0xdb0001e6,0x2cac0009}},	//   tors_, _ኣድራሻ, vslä, badd_, 
   {{0xdea000f2,0x2a40035b,0x00000000,0x00000000}},	//   _بیکی, ьҭым, --, --, 
   {{0x7d020978,0x2b590baf,0x8c40280b,0xc7a00261}},	//   _inns, bosc_, _неше, зиск, 
   {{0xdc38038f,0x395908b1,0x26c82aa4,0x2d800221}},	//   _aħħa, sors_, ggao_, _éier_, 
   {{0xdb00cc6e,0x45800798,0x00000000,0x00000000}},	// [3b820] gslå, згув, --, --, 
   {{0x6b5c01d3,0xdb014e32,0x66fc002b,0xdff83517}},	//   ségt, sslä, _rākų, ्माद_, 
   {{0x26c80175,0x0d38010f,0x73780107,0x66fc0055}},	//   bgao_, נגעב, ардӣ_, _sākų, 
   {{0x6b5e0979,0x35c41086,0xdb0001bf,0xd2a8010b}},	//   légr, _қаҳҳ, bslå, укде_, 
   {{0xe5040456,0x2cac0009,0x00000000,0x00000000}},	//   राशि_, yadd_, --, --, 
   {{0x7766097a,0x93a80133,0x2b58012d,0x8fd0013d}},	//   llix, _مارف_, zosc_, зәдә, 
   {{0xed5800d0,0x00000000,0x00000000,0x00000000}},	//   voľ_, --, --, --, 
   {{0x7d02097b,0x2cac0042,0x938801ee,0x00000000}},	//   _anns, wadd_, _асҡа_, --, 
   {{0x0c844137,0x0ca8033a,0x00000000,0x00000000}},	//   йынм, лтни_, --, --, 
   {{0x5046097c,0x2b58012d,0x20b80064,0x8fa4009b}},	//   _лезб, wosc_, _выць_, _гаже, 
   {{0x6284012c,0x2cac0368,0x6b5c39b4,0x04d8008f}},	//   ěhov, radd_, dégr, נקטל, 
   {{0x09bc00bd,0x8e8400c6,0x6b8000b4,0x7d007421}},	//   েবসা, _الإه, _ịgba, _enns, 
   {{0xc330025f,0x2cac037e,0xed5800d7,0x00000000}},	//   פוש_, padd_, poľ_, --, 
   {{0x7c2c00ee,0x200c012d,0x9e64009f,0x0cd400fe}},	//   çirý, ślił_, _بامن, _থোৰত, 
   {{0x7764876a,0x6d4a097d,0xb9340114,0x00000000}},	//   flix, mnda, черј, --, 
   {{0xf7711386,0x26c83341,0x9f441ca9,0x77640005}},	//   فاق_, ugao_, _islã_, glix, 
   {{0x6d4814dc,0x26c80656,0x63700267,0xe7382cc8}},	// [3b830] onda, rgao_, lång, гең_, 
   {{0x6d4a097e,0xdb0012ed,0x00000000,0x00000000}},	//   nnda, rslå, --, --, 
   {{0x6d4a097f,0xdb000158,0x776401e3,0x6370007c}},	//   inda, sslå, blix, nång, 
   {{0x6d4a0980,0x6b980998,0x362401d9,0x00000000}},	//   hnda, _mtvg, _کڈِہ, --, 
   {{0x2178005e,0x6d4803cd,0x217400d4,0x00000000}},	//   айды_, knda, оукр, --, 
   {{0x660c0921,0x6d480007,0x855401d3,0x63700267}},	//   mxak, jnda, _ایئر_, kång, 
   {{0xa06899fd,0x48d80b98,0xd9b41df0,0x660c013d}},	//   шака_, ख्यो_, _अट्ट, lxak, 
   {{0x6d4a0981,0x672c3142,0x9f44007b,0xdb080205}},	//   enda, nhaj, _tslí_, önül, 
   {{0x6d48008c,0x660c07a9,0xa3c0012d,0x00000000}},	//   fnda, nxak, ंढक_, --, 
   {{0x6d4a0982,0x1c44021b,0x63700267,0x80e0009e}},	//   gnda, жном, fång, পাঙ্, 
   {{0x5fdc6bcf,0xdc680aa5,0x637004f3,0x64401e31}},	//   _महिल, ранд_, gång, _žlij, 
   {{0x6d4a0983,0x2f5401ec,0x00000000,0x00000000}},	//   anda, _етіс, --, --, 
   {{0x6b5c0231,0x672e0984,0x1d08c2d8,0x49c4763d}},	//   tégr, dhaj, _вели_, олян_, 
   {{0x7d020985,0x7f580120,0xdb00cca2,0x5fdc62be}},	//   _unns, louq, nslú, _महाल, 
   {{0x6b5c004a,0xd5440208,0x00000000,0x00000000}},	//   régr, _lện, --, --, 
   {{0x672c0978,0x6b5c01ed,0x3ae82e07,0x63700fac}},	//   ghaj, ségr, _طبعی_, nånd, 
   {{0x660c004b,0x4b78008f,0xe8d80208,0xef180171}},	// [3b840] gxak, _דאקו, _luỹ_, _guļu_, 
   {{0x637032b8,0x280400bc,0xeb3401d9,0x795403e6}},	//   hånd, ásný_, _وى۪د, _رێزا, 
   {{0x672e0986,0x13e9e8f5,0x77640327,0x00000000}},	//   bhaj, рмей_, plix, --, 
   {{0xc7b0008d,0x6d480007,0xd544004d,0x83520987}},	//   _קבר_, znda, _bện, وپلا, 
   {{0x6d4a0988,0xdee41772,0x6370005c,0x00000000}},	//   ynda, ማንን_, dånd, --, 
   {{0xa3e4060c,0xdb00002d,0x53a4013d,0x00000000}},	//   _बैक_, tslû, _магб, --, 
   {{0x6d49490b,0xfbc60989,0x4fc43981,0x00000000}},	//   vnda, _تت_, іска, --, 
   {{0x3f6000f7,0x6d483978,0x52743a47,0x63703e04}},	//   мтыб, wnda, _дузу, gånd, 
   {{0x628c0cf4,0x62840118,0x50b80214,0x6d48022e}},	//   žaoc, ěhot, _نداد_, tnda, 
   {{0x6d4a098a,0x71a4d3a5,0x61ec00db,0x63700267}},	//   unda, _мағз, çale, tång, 
   {{0x6d4941ab,0x0e8c0521,0x63704e9b,0x21746ee2}},	//   rnda, _dịrị_, bånd, _хутр, 
   {{0x8ae40212,0x64400010,0x6d48127b,0x637001e3}},	//   ціол, _žlik, snda, rång, 
   {{0x6d480589,0x63700267,0x753c02f0,0x8e7001a9}},	//   pnda, sång, _omrz, _юқиш, 
   {{0x0e8c063f,0x6d480007,0x2906098b,0x6e2000c7}},	//   _gịrị_, qnda, ñla_, mymb, 
   {{0x29040598,0x672e098c,0x0b3401d9,0x6e200165}},	//   ıla_, thaj, _وقتک_, lymb, 
   {{0x660c009d,0xa3e405b3,0x659400c7,0xe9e00210}},	//   txak, _बैग_, заау, ęźby_, 
   {{0x672e098d,0x6aac0618,0x6564016d,0x6e2001bf}},	// [3b850] rhaj, _ieaf, tlhh, nymb, 
   {{0x672d5877,0x0464040e,0x6aac0100,0x660c0009}},	//   shaj, отем, _heaf, rxak, 
   {{0x6e20030a,0x00000000,0x00000000,0x00000000}},	//   hymb, --, --, --, 
   {{0x672c009a,0x7bd800d9,0x00000000,0x00000000}},	//   qhaj, שקאו, --, --, 
   {{0x6aae098e,0x673c0327,0x9f6406af,0x41e806ed}},	//   _meaf, _imsj, _étés_, рфем_, 
   {{0x6aae098f,0xdee402d3,0xc06c0023,0x00000000}},	//   _leaf, ማዕን_, _ብሕግን_, --, 
   {{0x6370049f,0xd3440799,0xe8d8001e,0x0e8c063f}},	//   tånd, _کینه_, _quỹ_, _rịrị_, 
   {{0x6aae0990,0x753c1f48,0x0e8c0521,0xf2c4e4ae}},	//   _neaf, _zmrz, _sịrị_, _осун, 
   {{0x6288014b,0xdb002ab7,0xd13400d1,0x00000000}},	//   _igeo, mslø, تكۈش_, --, 
   {{0xdb0028b3,0x7100035b,0x6aac0042,0x00000000}},	//   lslø, _аҧша, _aeaf, --, 
   {{0x6aac13a5,0x673c000f,0x46c80316,0x00000000}},	//   _beaf, _omsj, िलाह, --, 
   {{0xdc6816c3,0x6aac054e,0xd99401ec,0x00000000}},	//   _қайд_, _ceaf, _ﻛﻮﺭﻩ_, --, 
   {{0x6aac14e0,0x6ed000e0,0x00000000,0x00000000}},	//   _deaf, _धातु, --, --, 
   {{0x673c02d0,0x22580162,0x6b5c00e5,0x00000000}},	//   _amsj, _øsku_, ségp, --, 
   {{0x6aac0e39,0xdb007dfa,0xf03c0023,0x00000000}},	//   _feaf, kslø, _ክንሰም, --, 
   {{0x753c1b24,0x62880086,0x6aac26be,0xdaa80b3e}},	//   _smrz, _ngeo, _geaf, _увид_, 
   {{0xeb540228,0x2a3400db,0xca7400cf,0xbbd800cd}},	// [3b860] _تىيگ, _жээр, _ىمىش_, _बहुक, 
   {{0x9aa40345,0x00000000,0x00000000,0x00000000}},	//   _بمکو, --, --, --, 
   {{0x6aae0991,0x649000d7,0x00000000,0x00000000}},	//   _yeaf, džič, --, --, 
   {{0x94a80032,0xdb0012ed,0x518413d6,0x89d400f2}},	//   ртҡа_, gslø, пука, _بویر_, 
   {{0x8778010f,0x16b800bc,0x00000000,0x00000000}},	//   _לאטי, ेलीब, --, --, 
   {{0x62880944,0x753e0992,0xc0d00023,0xcf2400f1}},	//   _egeo, _umrz, _ኩቱር_, ګرتي, 
   {{0xaf4c0023,0x00000000,0x00000000,0x00000000}},	//   _ዝህልወ, --, --, --, 
   {{0x53a41b74,0x0ee82d30,0xee440022,0x6e200022}},	//   _маҳб, ськи_, мҭеи, tymb, 
   {{0x6aae0993,0x7f840139,0xfeb50bd3,0x2214011c}},	//   _reaf, _sıqt, سايت_, _оффр, 
   {{0x6aae0994,0x6e2016c9,0xc198025d,0x6288022e}},	//   _seaf, rymb, _לשמי, _zgeo, 
   {{0x4ea40fae,0x6aae0995,0x0fe000db,0x00000000}},	//   _ерла, _peaf, _чөлү, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc3300302,0x6aac0099,0xbea0f8cf,0xcfbc00cc}},	//   תור_, _veaf, _чачк, _আহিন, 
   {{0x6aae0996,0x673c01a4,0xff2400db,0x87d80014}},	//   _weaf, _smsj, _وكەي_, ٝبرس_, 
   {{0x2cbc0b6f,0x6aae0997,0x00000000,0x00000000}},	//   _idvd_, _teaf, --, --, 
   {{0x6490151c,0x00000000,0x00000000,0x00000000}},	//   zžič, --, --, --, 
   {{0xdb0008fb,0x2bc4449f,0xa3e4012d,0x00000000}},	// [3b870] vslø, लंका, _बैज_, --, 
   {{0xf994159d,0x628801c3,0xe94401d3,0x00000000}},	//   _ארץ_, _sgeo, _زرخی, --, 
   {{0x4424fc2d,0xdb003c02,0x03c400c0,0x00000000}},	//   án_, tslø, ясам, --, 
   {{0x673c066a,0xdecc0023,0x442c012d,0xb4cc0210}},	//   _umsj, ኢትን_, ąg_, _रफ़ी_, 
   {{0xdb00942c,0x4424310a,0x20880395,0x00000000}},	//   rslø, šn_, ойли_, --, 
   {{0xe4c42ab4,0x31240220,0xc0ca0998,0xdb00143a}},	//   _تصحی, ндіг, суде_, sslø, 
   {{0xdb0008fb,0x64900010,0xa3e40210,0x4abc2802}},	//   pslø, ržič, _बैच_, ्लाव, 
   {{0x62240075,0x62882798,0x6304006c,0x850001d3}},	//   _قىزل, _ugeo, _تورل, _توڑن, 
   {{0xb0280075,0xdca4010a,0x00000000,0x00000000}},	//   يكۇم_, мапи, --, --, 
   {{0xc0d402d3,0x00000000,0x00000000,0x00000000}},	//   ሪቦም_, --, --, --, 
   {{0x2bc45d4f,0x00000000,0x00000000,0x00000000}},	//   लंगा, --, --, --, 
   {{0x2f18030d,0xbb5400d1,0x00000000,0x00000000}},	//   _нохь_, ﺋﯩﻢ_, --, --, 
   {{0x7c7c0092,0x00000000,0x00000000,0x00000000}},	//   ከትላል_, --, --, --, 
   {{0x3eac002f,0x75f800e5,0x00000000,0x00000000}},	//   _hegt_, húzá, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3b880] --, --, --, --, 
   {{0x3eae0999,0x53a439c1,0x186a099a,0x00000000}},	//   _legt_, дажб, _мапи_, --, 
   {{0xb9e802d3,0x93582a20,0x399404e6,0xd7e0d9e5}},	//   _ክሲ_, орду_, _häs_, _पहिच, 
   {{0x2324177b,0x399400a2,0x660800ef,0x00000000}},	//   нфіг, _käs_, _šeke, --, 
   {{0x32000548,0x2fd80055,0x00000000,0x00000000}},	//   íiy_, _ūrg_, --, --, 
   {{0xcf9815ed,0x61ed119e,0x39940724,0x00000000}},	//   оји_, çala, _mäs_, --, 
   {{0x3996099b,0x3eac0064,0x61ec025c,0x160401e1}},	//   _läs_, _begt_, ħala, _ọ̀bẹ_, 
   {{0xadf40261,0xf00401c0,0xd344006c,0x7f840139}},	//   епиш, _үүди, _کیچه_, _sıqr, 
   {{0xdcb0278f,0x4340010a,0x399401e3,0x3eac00ef}},	//   گىپ_, _ретв, _näs_, _degt_, 
   {{0xca7004d3,0x6370cbaf,0x00c4004e,0x00000000}},	//   ێندک, måna, _олук_, --, 
   {{0xdb000798,0x63700267,0x8c340107,0x3eac3bba}},	//   mplê, låna, фонӣ_, _fegt_, 
   {{0x2cbc0036,0x399420a9,0xfbcc1079,0x3eac02d2}},	//   _wdvd_, _bäs_, گتی_, _gegt_, 
   {{0x9f440af9,0xa08000c7,0x7f840139,0x00000000}},	//   _oplê_, _иқәк, _tıqr, --, 
   {{0x3eac0936,0xfbcc53e2,0x39940036,0x00000000}},	//   _zegt_, دتی_, _däs_, --, 
   {{0xc1d80b33,0x37f80276,0xdb000162,0x6370007c}},	//   _मङ्ग, мерэ_, lslý, håna, 
   {{0x8d4401c6,0x7c2401bf,0x4900009d,0x00000000}},	//   _хүүг_, øjre, хүүг, --, 
   {{0x79f400c7,0xe8940108,0x00000000,0x00000000}},	// [3b890] _азых, _папь, --, --, 
   {{0xab5c00ef,0x00000000,0x00000000,0x00000000}},	//   duļi, --, --, --, 
   {{0xf96403e6,0x04640117,0x248c0bbc,0x00000000}},	//   _شۆفێ, фтам, _şems_, --, 
   {{0xc7640014,0xb374158b,0xdb000162,0xc3400408}},	//   _زاجى, ندنش, kslý, тĕм_, 
   {{0x3eac2caa,0xdb2401d3,0xf1940108,0xab5c00ef}},	//   _regt_, épés, вичь, guļi, 
   {{0x3ead4154,0xc32c0014,0xd5a4872f,0x3ce00154}},	//   _segt_, دٕچ_, _سلفی, _কোন্_, 
   {{0x2a6804ba,0x00000000,0x00000000,0x00000000}},	//   _lyab_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2a680457,0xe9f8035b,0x3eae099c,0xdb0003b2}},	//   _nyab_, _peẽ_, _vegt_, gslý, 
   {{0xe13517ea,0x39940139,0xf084129d,0x00000000}},	//   _янзы, _räs_, رگەۋ, --, 
   {{0x2a68022e,0x71240137,0x00000000,0x00000000}},	//   _ayab_, _جىلم, --, --, 
   {{0xdd940209,0x88a00032,0x7f8406be,0x00000000}},	//   _зады, ңғыһ, _tıqq, --, 
   {{0x29d401d5,0x4b200395,0x6d4c0d12,0x00000000}},	//   кўрс, умяв, ðlað, --, 
   {{0x2a68033b,0x00000000,0x00000000,0x00000000}},	//   _dyab_, --, --, --, 
   {{0xab5c00e2,0xac100408,0x1ae51c3d,0x00000000}},	//   zuļi, _кĕре_, _зойм, --, 
   {{0x2a6802e2,0x2c1c012c,0xd6ac009e,0x7bcc033f}},	//   _fyab_, महरू_, গল্প, ńcus, 
   {{0x7ae40537,0x00000000,0x00000000,0x00000000}},	// [3b8a0] _ibit, --, --, --, 
   {{0x637001e6,0x32e80327,0x7ae4013a,0x00000000}},	//   våna, _ལིངྐ, _hbit, --, 
   {{0x20c87674,0x2a680166,0x03a001f0,0xd7080354}},	//   _राजध, _zyab_, гихо, _енне_, 
   {{0xa3c0012d,0x61ec031c,0x00000000,0x00000000}},	//   ूढ़_, ħaln, --, --, 
   {{0x7ae6099d,0x2a6801d4,0xd2500214,0xdb001427}},	//   _mbit, _xyab_, دنش_, lsló, 
   {{0x2570005e,0xf0040131,0x63704cab,0x00000000}},	//   _نۇقس, күзи, råna, --, 
   {{0x4fc49a58,0xfbc4121a,0x7ae6099e,0xdb000252}},	//   хсла, _حت_, _obit, nsló, 
   {{0x324400c7,0xe1ec00ec,0x00000000,0x00000000}},	//   _иҵег, _ڀڳو_, --, --, 
   {{0xdb02099f,0xa13400bc,0x00000000,0x00000000}},	//   mplè, _šňůr, --, --, 
   {{0xe7b00034,0xd12c00db,0xdb0003b2,0xc24036ca}},	//   _जबलप, _دۅت_, ksló, _снук, 
   {{0x7ae401ab,0x63540109,0x6c5416ab,0x00000000}},	//   _bbit, ląna, ткну, --, 
   {{0x7ae400a3,0xdb00033b,0x00000000,0x00000000}},	//   _cbit, nplè, --, --, 
   {{0x9ce405f5,0x63540109,0x7f380115,0x00000000}},	//   хцөл, nąna, _צעדו, --, 
   {{0x7ae42f99,0x2a6807ab,0xdb0008a5,0x00000000}},	//   _ebit, _vyab_, fsló, --, 
   {{0xc6a609a0,0xdb000174,0xab5c00ef,0x00000000}},	//   ерзи, gsló, duļv, --, 
   {{0x2734007c,0x00000000,0x00000000,0x00000000}},	//   _mång_, --, --, --, 
   {{0x273404f3,0x2a680004,0xe8d801fb,0xc4c4007b}},	// [3b8b0] _lång_, _uyab_, _quỳ_, فتاو, 
   {{0x69dc13c4,0x48a834d8,0x7ae609a1,0x04b000cf}},	//   mtse, _этим_, _zbit, الاڭ, 
   {{0x320609a2,0xba741ef1,0x7ae801d3,0x60d40139}},	//   _army_, _لایت, ődte, _özmi, 
   {{0x836400f7,0xe8d801fb,0x69de09a3,0x00000000}},	//   ردال, _tuỳ_, otse, --, 
   {{0x69de09a4,0x00000000,0x00000000,0x00000000}},	//   ntse, --, --, --, 
   {{0x69de09a5,0xf9940bd9,0x2734007c,0xd5ac0050}},	//   itse, ארס_, _bång_, _گہے_, 
   {{0xdbd80205,0x69dc3f17,0xd00d1147,0x00000000}},	//   _içça, htse, قلو_, --, 
   {{0x69ddd180,0x00000000,0x00000000,0x00000000}},	//   ktse, --, --, --, 
   {{0x69de09a6,0xa1940801,0x31c401d9,0x60f40640}},	//   jtse, _разч, _مۅنہ, _изађ, 
   {{0xdb0209a7,0x273609a8,0x7ae405d5,0x61ea09a9}},	//   mplé, _hånd_, _sbit, _ipel, 
   {{0x273404f3,0x69de09aa,0x2f1801ed,0xcef40244}},	//   _gång_, etse, _légy_, رفیش_, 
   {{0x69dc9f0f,0x61e80066,0x60c00175,0x20053c8a}},	//   ftse, _kpel, _hdlm, _irli_, 
   {{0x2f1801ed,0x69dccca3,0x7ae40327,0x2734248f}},	//   _négy_, gtse, _vbit, _månd_, 
   {{0x61ea09ab,0xa02000af,0x9d44010a,0x7bc4025c}},	//   _mpel, _ööse, _шелд, ġjub, 
   {{0x69dc0460,0x25ac025c,0x576401d9,0x00000000}},	//   atse, _ħela_, ندرِ, --, 
   {{0xc6c0165d,0xcf9000c8,0x69dc0218,0xcba0013e}},	//   ийск, שטן_, btse, _таъй, 
   {{0x69dc010a,0xa8180131,0x4b780a7c,0xab5c00ef}},	// [3b8c0] ctse, وتېر_, _קאפו, guļu, 
   {{0x61ec003d,0x582400c7,0x77954db6,0x34cc0f4a}},	//   ħall, _амоб, _میسا, ालेद, 
   {{0x27344e9b,0x6b5c01ed,0xa504035b,0x00000000}},	//   _bånd_, végz, ыҵра_, --, 
   {{0xfe640272,0xd62801b9,0x8c18008f,0xd2440276}},	//   _ند_, _жоме_, וועי, кэли, 
   {{0x273401e6,0x776400db,0x20040254,0x00000000}},	//   _sång_, moix, _arli_, --, 
   {{0xf48609ac,0x25ac0240,0x16b0012d,0x626400cf}},	//   _مازی, _çela_, _ज़ुब, دامق, 
   {{0x8fd000fd,0x011001d5,0xd2a4074d,0x00000000}},	//   рәзә, شبوخ, _бiаь, --, 
   {{0x20040010,0x69dc5e40,0x2ef440c5,0x00000000}},	//   _drli_, ytse, узир, --, 
   {{0xd1852fdd,0xe35468cc,0x200400a2,0x69dcaa3d}},	//   _алай, _стрэ, _erli_, xtse, 
   {{0x27340267,0xd17609ad,0xbdf4009f,0x00000000}},	//   _tång_, _рыбы, ئريا_, --, 
   {{0x20042375,0x8d8403e6,0x776400b5,0x273401bf}},	//   _grli_, _یشتن, koix, _håne_, 
   {{0x0dc80f06,0x4dd800ae,0x00000000,0x00000000}},	//   _жуки_, _يوضح_, --, --, 
   {{0x61e805b1,0x3b54010b,0x00000000,0x00000000}},	//   _xpel, ркяр, --, --, 
   {{0x2734383d,0x67d406d4,0xdc5401ed,0x00000000}},	//   _måne_, логу, ئریک, --, 
   {{0x69ddd4ed,0x27340e38,0x06680046,0xe7d00154}},	//   stse, _låne_, ﺳﯩﻨﯩ, াব্য, 
   {{0x6d4a09ae,0x69de09af,0x776400cf,0x2fd8000d}},	//   lida, ptse, goix, _ärgu_, 
   {{0x6d480076,0xd7640066,0x00000000,0x00000000}},	// [3b8d0] oida, انقی, --, --, 
   {{0x6b8002e3,0x6b8c00ad,0xc5140691,0x00000000}},	//   _ịgha, _hiag, خبرت, --, 
   {{0x61ea09b0,0x6b8c0194,0x6d480014,0x61ec031c}},	//   _spel, _kiag, iida, ħalm, 
   {{0xf2c43306,0x63a40649,0x776400db,0xe23406ed}},	//   لْمُ, rphn, coix, лнењ, 
   {{0x6d4a09b1,0x6b8c2819,0x672d9563,0xa5740592}},	//   kida, _miag, mkaj, _مُحت, 
   {{0x6d4a09b2,0x672c00c8,0xe4f8008f,0xa8040005}},	//   jida, lkaj, _אפֿש, coñé, 
   {{0x6b8c0076,0x60c00175,0x504001e0,0x998000bc}},	//   _oiag, _vdlm, йешб, zyků_, 
   {{0x6b8e09b3,0xdb0020ef,0x672e09b4,0x656609b5}},	//   _niag, pplé, nkaj, lohh, 
   {{0x6d4a09b6,0x61ea09b7,0x65640280,0x0dc609b8}},	//   fida, _upel, oohh, глый_, 
   {{0x6d4a09b9,0x5ba913dc,0x9cf40276,0x6b8e09ba}},	//   gida, нком_, учиш, _aiag, 
   {{0x6b8e09bb,0x672d58a8,0x200609bc,0xe8d8004d}},	//   _biag, kkaj, _urli_, _huỷ_, 
   {{0x672e09bd,0x6d493f5b,0x65640455,0x6b8c033f}},	//   jkaj, aida, hohh, _ciag, 
   {{0x6b8d30e5,0xddc49bf1,0x0b400212,0x776406af}},	//   _diag, _сбли, снян, voix, 
   {{0x6d481a36,0xae1407d6,0x3d2400c7,0x02dc0037}},	//   cida, _خذمت, _шьев, नभुन, 
   {{0x26d801ee,0x00000000,0x00000000,0x00000000}},	//   _bcso_, --, --, --, 
   {{0x6b8e09be,0x00000000,0x00000000,0x00000000}},	//   _giag, --, --, --, 
   {{0xca740046,0x77640077,0x00000000,0x00000000}},	// [3b8e0] _бәрі_, roix, --, --, 
   {{0x6b8c030a,0xd3b802dd,0x569401e0,0x672c8c2a}},	//   _ziag, еуді_, таҡт, akaj, 
   {{0xd18400ee,0x00000000,0x00000000,0x00000000}},	//   ңлей, --, --, --, 
   {{0x6d494d7b,0x00000000,0x00000000,0x00000000}},	//   zida, --, --, --, 
   {{0x03a03461,0x6d4a09bf,0xa804056a,0xc6840014}},	//   _ҳисо, yida, poñé, _مێٲن_, 
   {{0xc204038b,0x98a80064,0x00000000,0x00000000}},	//   اقون_, ribė_, --, --, 
   {{0x6d485fd9,0x63a80558,0x06680ae5,0x50d400db}},	//   vida, _čeng, ﺳﯩﻠﯩ, _ۅزار, 
   {{0x637800d8,0xb1c801af,0x6d4a09c0,0xe2a800ae}},	//   _асур_, _аңда_, wida, _لاكن_, 
   {{0x6d4a09c1,0x50d56414,0x6b8c0013,0x91d00183}},	//   tida, _مزار, _riag, _দৈৰ্, 
   {{0x33dc01ec,0x6d48003a,0x3ce40051,0xc22000f1}},	//   _ءﯨﺸﻰ_, uida, _cbnv_, _دکمو, 
   {{0x409006d5,0x6b8e09c2,0x672c44ef,0x4fa4014b}},	//   _المر, _piag, ykaj, _сиев, 
   {{0x6d493c82,0x359402d3,0x0a68a229,0x8aa402d5}},	//   sida, ማኖታት_, ерги_, ырод, 
   {{0x8d9c01f2,0x672d3e29,0xa9080014,0x80d80b02}},	//   _fọọm_, vkaj, پٲزٕ_, _नामे, 
   {{0x6d4807d6,0x660873d0,0x672c0113,0xa6b000fe}},	//   qida, _šeko, wkaj, _ছাইট, 
   {{0x26d80004,0x6b8e09c3,0x672e09c4,0x9f58013a}},	//   _pcso_, _tiag, tkaj, _čsú_, 
   {{0x672e09c5,0x6b8c0607,0x67d4024c,0x00000000}},	//   ukaj, _uiag, лоҳу, --, 
   {{0xf7707e89,0x672e09c6,0xa61400ee,0x19c001e0}},	// [3b8f0] ساف_, rkaj, шмач, _мәрг, 
   {{0x672e09c7,0x6d5800b8,0xf4d8010b,0x00000000}},	//   skaj, _jjva, лмуш_, --, 
   {{0x38c8fb04,0x65640112,0x00000000,0x00000000}},	//   _суын_, rohh, --, --, 
   {{0x656609c8,0x25ac0200,0x34940818,0x92a40210}},	//   sohh, _çelo_, _ҳарр, _nałę, 
   {{0x97000075,0xe8d8001e,0x862402d5,0x3c3801d3}},	//   _بېقى, _quỷ_, _сьне, _kávé_, 
   {{0x3494b592,0x60245ab0,0x00000000,0x00000000}},	//   _гарр, идла, --, --, 
   {{0x25a80280,0xdb00c9df,0xb55801f0,0x00000000}},	//   lpal_, mslö, _сирф_, --, 
   {{0x6d580fcf,0x26082232,0xdb00007c,0xde4c0023}},	//   _ajva, सिपी_, lslö, _ክትከፍ, 
   {{0x25a80280,0xc10000d1,0x60f80108,0x00000000}},	//   npal_, _гүлл, _иная_, --, 
   {{0x70380075,0xdb0209c9,0x9d44234c,0x00000000}},	//   خسۇس_, nslö, реод, --, 
   {{0x25a8020c,0x5f9401ec,0x9ed801a9,0x00000000}},	//   hpal_, _тиет, _амет_, --, 
   {{0x8f980375,0xdce00427,0x92a4012d,0xace81046}},	//   _סיני, molč, _gałę, پریل_, 
   {{0x3da4094c,0x3f8c01d9,0x61ec0120,0xbb5400b5}},	//   _среб, _iigu_, çalh, _piaセ_, 
   {{0xdca609ca,0xdb0209cb,0x26083599,0x28f80166}},	//   _таки, mplí, सिनी_, лэсэ_, 
   {{0x1868055f,0xdb000267,0x8c4209cc,0xdce00419}},	//   тави_, dslö, _меше, nolč, 
   {{0x15cc0873,0x3f8c0135,0xd6d07245,0x00000000}},	//   _ﺗﻪﺭﻩ, _jigu_, تقر_, --, 
   {{0x59740c9e,0x9974030d,0xdb0002d2,0x00000000}},	// [3b900] _выну, _вунш, fslö, --, 
   {{0x3f8c08a4,0x54c40022,0xdb0036b2,0x00000000}},	//   _ligu_, рбжб, gslö, --, 
   {{0x78bce9dd,0xdce00219,0xd395e39d,0x69d800fd}},	//   marv, jolč, рәгә_, _äwer, 
   {{0x78be09cd,0x5224036b,0xb7340014,0x3f8e09ce}},	//   larv, ифла, _چِھک, _nigu_, 
   {{0x63a82a4f,0x4a9808a8,0xd7740150,0x25a801ef}},	//   _čene, דינג, _ماڭع, cpal_, 
   {{0x78be09cf,0x4fc40124,0x3f8c06af,0x409001e0}},	//   narv, асиа, _aigu_, ҙрәт, 
   {{0x3f8c0198,0x81406883,0x2734007c,0x1834010f}},	//   _bigu_, تنون, _håna_, יאַל_, 
   {{0x78be0909,0x3b000369,0x0ee802bf,0xadd80116}},	//   harv, _naiq_, тьки_, гмиу_, 
   {{0x3f8e09d0,0x78be09d1,0x0ca8de5f,0x6f000205}},	//   _digu_, karv, ктни_, rdmc, 
   {{0x78be09d2,0xdce009a8,0x3f8c0008,0x92a4033f}},	//   jarv, bolč, _eigu_, _wałę, 
   {{0x273400bf,0x78be09d3,0x80d81804,0x4ad801ad}},	//   _låna_, darv, _नाते, _भादव, 
   {{0x25aa09d4,0x3b000399,0x63a001d3,0xcb440022}},	//   ypal_, _caiq_, _élne, рхои, 
   {{0x3b000097,0x78bcdca8,0xaa9401d5,0x00000000}},	//   _daiq_, farv, _қипч, --, 
   {{0x3a240267,0xbb300131,0x6d580200,0x00000000}},	//   ämpa_, ﻨﻜﻰ_, _ujva, --, 
   {{0x3b0209d5,0x25a80113,0x0745be03,0x25f8000d}},	//   _faiq_, wpal_, ахам, _उनही_, 
   {{0x3b000226,0x78bc0037,0x201000d0,0x25a80356}},	//   _gaiq_, aarv, _ázie_, tpal_, 
   {{0xdb00049f,0x78bdc7cf,0x6abc0d81,0xe29a09d6}},	// [3b910] tslö, barv, masf, қал_, 
   {{0x25aa09d7,0xdb000d16,0x613003b2,0xe974029e}},	//   rpal_, uslö, iðlæ, _دهخد, 
   {{0x68f609d8,0x33240369,0x758835dd,0xdb000267}},	//   mezd, _bomx_, рств_, rslö, 
   {{0x25aa09d9,0xadf82e1e,0xb9e002d3,0x1fa8010b}},	//   ppal_, ्टान_, _እባ_, ңкли_, 
   {{0x290209da,0xa0a41c3e,0x05680798,0x9f9c0200}},	//   _kaha_, балд, _ајви_, pçën_, 
   {{0x290209db,0x6abc2679,0x68f40427,0xdce00010}},	//   _jaha_, hasf, nezd, tolč, 
   {{0x3f8c75e3,0x00000000,0x00000000,0x00000000}},	//   _pigu_, --, --, --, 
   {{0x29000c11,0x78be09dc,0x4aa4012c,0xd1b056a7}},	//   _laha_, zarv, _क्लव, _کیوک, 
   {{0x78be09dd,0x68f400dd,0x3b000007,0x6abc00d8}},	//   yarv, kezd, _raiq_, dasf, 
   {{0x290209de,0x68f609df,0x3b000007,0x78bd1b9c}},	//   _naha_, jezd, _saiq_, xarv, 
   {{0xad2405d9,0x3f8e09e0,0x68f609e1,0x00000000}},	//   تريو, _tigu_, dezd, --, 
   {{0x05c40490,0x29004e40,0x5e94007b,0x78bc002d}},	//   _लिंब, _aaha_, _الإط, warv, 
   {{0x78be09e2,0x290209e3,0x3b000399,0xea980055}},	//   tarv, _baha_, _vaiq_, _soṃ_, 
   {{0x290000ca,0x21240ba1,0x68f400fd,0x2e6802dd}},	//   _caha_, _jolh_, gezd, _тиіп_, 
   {{0x290209e4,0x78be09e5,0x236e09e6,0x273401e6}},	//   _daha_, rarv, _okej_, _såna_, 
   {{0x78be09e7,0x00000000,0x00000000,0x00000000}},	//   sarv, --, --, --, 
   {{0x3bc15f1e,0x78be09e8,0x290209e9,0x68f400fd}},	// [3b920] lıq_, parv, _faha_, bezd, 
   {{0x78bc3209,0x934418ce,0x29000ba7,0x236c0030}},	//   qarv, әнде, _gaha_, _akej_, 
   {{0x3bc07a0e,0x0454007b,0x4cb8010f,0x71ec0154}},	//   nıq_, ملكة_, רמעג, ওয়াচ_, 
   {{0x29008793,0x55e42e39,0xdb1002c1,0x00000000}},	//   _zaha_, _ломб, _ägäi, --, 
   {{0x58f40003,0x21240010,0x91480fbe,0x290209ea}},	//   _བྲོས_, _bolh_, лчка_, _yaha_, 
   {{0x7bc003b2,0x9f4401a8,0xd4680121,0xed800092}},	//   _ovnu, _osló_, _биге_, _የባቡር_, 
   {{0xf2c40131,0x7e4000c7,0x00000000,0x00000000}},	//   _дөли, ҧхье, --, --, 
   {{0xe3b00583,0x3bc0887f,0x01a400d1,0x934473b5}},	//   _زرِ_, dıq_, шкәк_, _унбе, 
   {{0x6b9801b9,0x6abce6a1,0x68f609eb,0x00000000}},	//   _suvg, vasf, yezd, --, 
   {{0xccf8026a,0x27340158,0xefb0036b,0x45f8011a}},	//   ући_, _nånn_, _قیتگ, נהיג, 
   {{0x290209ec,0x3fc86f43,0x68f40dd4,0x613c02e2}},	//   _raha_, _مدنی_, vezd, _bèlf, 
   {{0x290209ed,0x5c740137,0x4474010f,0xdef8002e}},	//   _saha_, өлөт, מעיל_, yoŋi_, 
   {{0x29004774,0x6abe09ee,0x613c7d47,0x7bc006ea}},	//   _paha_, rasf, _dèlf, _evnu, 
   {{0x63700ac8,0x29000548,0x68e801fa,0x4ad8185d}},	//   råni, _qaha_, đedo, _भावव, 
   {{0x290209ef,0x3bc00213,0x6abc004e,0x68f609f0}},	//   _vaha_, cıq_, pasf, rezd, 
   {{0x290209f1,0x2b48014b,0x660802d2,0x00000000}},	//   _waha_, _umac_, _áekk, --, 
   {{0x290209f2,0x7b940014,0x7d240174,0x7bc000d7}},	// [3b930] _taha_, _پھۯس_, _ársø, _zvnu, 
   {{0x236c5a1e,0x7a38004e,0x87e401f4,0x00000000}},	//   _skej_, _ыпыр_, _люме, --, 
   {{0xe2840131,0xdb0003b2,0x98b800cf,0x6b9c0332}},	//   ﺭﺩﻩﻡ_, lplá, _өлөт_, írgh, 
   {{0x7bd8010f,0x6f040332,0x00000000,0x00000000}},	//   רקאו, _óich, --, --, 
   {{0x3bc06b8e,0x21240427,0x2be40154,0xdb0003b2}},	//   zıq_, _polh_, গিয়ে_, nplá, 
   {{0xdce0005f,0x3bc0467d,0x00000000,0x00000000}},	//   kolā, yıq_, --, --, 
   {{0x91600208,0x25c80153,0xd12c00db,0x00000000}},	//   _xử_, žulį_, ئمى_, --, 
   {{0xf83806a9,0x80d82208,0x50d80882,0x9f440332}},	//   מנות_, _नावे, āyāṃ_, _bplá_, 
   {{0xd34403e6,0xdb0000d7,0x00000000,0x00000000}},	//   _بینه_, jplá, --, --, 
   {{0x3bc11e7f,0x613c0100,0xdb0002f0,0xb0e001f9}},	//   tıq_, _sèlf, dplá, _नायग, 
   {{0x40741411,0xaef80154,0x81b80154,0x00000000}},	//   _الاڭ_, _আচরণ_, _অমি_, --, 
   {{0x2734174e,0x613c56ed,0x3bc1ef66,0xdd949c36}},	//   _sånn_, _bèlg, rıq_, _дады, 
   {{0x3ebe09f3,0x4a408dce,0x58f4025c,0x916001fb}},	//   maut_, дняв, _བྲུས_, _sử_, 
   {{0x613c007f,0x7880032e,0x3bc006be,0x00000000}},	//   _wèlf, _náví, pıq_, --, 
   {{0x7d000004,0xc7a0228c,0x1ae400ee,0x07a09731}},	//   _ians, диск, _дойм, дасн, 
   {{0x3ebe09f4,0x279800a8,0x15d00220,0xbc5000f1}},	//   naut_, стрэ_, _ﺟﻪﺭﺩ, _ورګډ, 
   {{0x15b80220,0xe3fc0150,0xaae41410,0x63a80064}},	// [3b940] рыбы_, _ءﺟﯩﺘ, _رسيو, _čena, 
   {{0x3ebc0730,0x9160004d,0xe9a800e3,0x00000000}},	//   haut_, _tử_, _ادين_, --, 
   {{0x3ebe09f5,0xd14811fc,0x0d38008f,0x5ed00154}},	//   kaut_, یشتن_, סגעב, থ্যে, 
   {{0x7d0209f6,0x3ebe09f7,0x00000000,0x00000000}},	//   _lans, jaut_, --, --, 
   {{0x7d0209f8,0x3ebe09f9,0x51f45734,0x13a96658}},	//   _oans, daut_, تسار, انچی_, 
   {{0x7d000605,0x7f48014b,0xfbac015b,0x00000000}},	//   _nans, _amgq, _কিনত, --, 
   {{0xe80c00ab,0x3ebe09fa,0xb9e00092,0x80d8121d}},	//   हिया_, faut_, _እጣ_, _नारे, 
   {{0xb8dc1b4b,0x7d0209fb,0x3ebe09fc,0xcf243592}},	//   _ཆབ_, _aans, gaut_, ترتي, 
   {{0x7d0209fd,0xdb0001bf,0x00000000,0x00000000}},	//   _bans, oplæ, --, --, 
   {{0x7f4801f0,0xe80c2ecf,0x00000000,0x00000000}},	//   _emgq, हिमा_, --, --, 
   {{0x7d0209fe,0x3ebe09ff,0x637001e3,0x00000000}},	//   _dans, baut_, rånv, --, 
   {{0x3ebe0a00,0x7d0014dc,0x20100030,0x3fc801b9}},	//   caut_, _eans, _ázia_, _ضدمی_, 
   {{0x7d020a01,0x00000000,0x00000000,0x00000000}},	//   _fans, --, --, --, 
   {{0x7d0017c0,0x8c34013e,0x637012e8,0x3d9001ec}},	//   _gans, _молӣ_, lånt, _жиір, 
   {{0xdb00c4d8,0x00000000,0x00000000,0x00000000}},	//   splá, --, --, --, 
   {{0x7d000699,0x2cbc55c2,0xe69802e8,0x25d8004e}},	//   _zans, _hevd_, сваш_, ймбы_, 
   {{0x7d020a02,0x3d0c0574,0x80d82208,0x00000000}},	// [3b950] _yans, _थोडे_, _नाले, --, 
   {{0x7d000009,0xdce00356,0x00000000,0x00000000}},	//   _xans, molă, --, --, 
   {{0x58f41efe,0xa2f410f5,0xe3fc01ec,0xa7144eb1}},	//   _བྲིས_, зпеч, _ءﺑﯩﺘ, _емні, 
   {{0x659577bd,0x2cbc168c,0x00000000,0x00000000}},	//   _наму, _levd_, --, --, 
   {{0xa0a410de,0x00000000,0x00000000,0x00000000}},	//   палд, --, --, --, 
   {{0x1fb40276,0xf2c40075,0x312401ec,0x7bc401d3}},	//   псир, псән, мдіг, ájuk, 
   {{0x3ebe0569,0x8fa06c48,0x613c0100,0xaf982401}},	//   taut_, наще, _rèld, отых_, 
   {{0xdea007d6,0xdef80de2,0x9f041d0a,0x00000000}},	//   ریتی, yoŋu_, سوخو, --, 
   {{0x3ebe0a03,0x7d020a04,0x00000000,0x00000000}},	//   raut_, _pans, --, --, 
   {{0x1c44bc5a,0x613c0100,0x7d004091,0x3ebe0a05}},	//   зном, _bèle, _qans, saut_, 
   {{0x7d020a06,0xdc68a848,0x613c00cf,0x3ebc003e}},	//   _vans, санд_, _cèle, paut_, 
   {{0x7d020159,0x7f480944,0xdef800e8,0x2f180354}},	//   _wans, _umgq, toŋu_, _мохь_, 
   {{0x63700ac8,0x1d080108,0x7a400064,0x00000000}},	//   låns, _гели_, kštū, --, 
   {{0x7d0014f5,0xdb5801c6,0x98a80064,0x00000000}},	//   _uans, рюү_, ribį_, --, 
   {{0xdef800e8,0x00000000,0x00000000,0x00000000}},	//   soŋu_, --, --, --, 
   {{0x030805f9,0x05c4007d,0xdb380214,0xcb640395}},	//   _सोलह_, _लिखब, _دستش_, _наще_, 
   {{0xdce0054e,0x59c4007b,0xdb0001bf,0x00000000}},	// [3b960] colă, _عيدك, tplæ, --, 
   {{0x21e40150,0x7a400064,0x00000000,0x00000000}},	//   _ﺍﺴﺘﻭ, gštū, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe3c80407,0xf8dc4ca3,0xdb140139,0x00000000}},	//   _soñé_, _बाँय, _übär, --, 
   {{0xdb00319f,0xdef8002e,0xfd0400ec,0x50c80166}},	//   pplæ, deŋ_, _ٻج_, быйм_, 
   {{0xdb000793,0x86780375,0x2608000d,0x6440031c}},	//   lplä, _לרכו, सिरी_, _żlie, 
   {{0x80a20a07,0x2cbc0083,0xd2a40354,0x00000000}},	//   رمين, _revd_, _жiаь, --, 
   {{0xe80c1b6e,0xdb000e78,0x81b80154,0x14e00073}},	//   हिता_, nplä, _অমর_, _पाडण, 
   {{0x76460a08,0xf8dc007d,0x00000000,0x00000000}},	//   nziy, _बांय, --, --, 
   {{0x613daca2,0xc0e08d33,0xdb00002f,0x0200013d}},	//   _pèle, _поук, hplä, _язун, 
   {{0x2cbc03cd,0x00000000,0x00000000,0x00000000}},	//   _vevd_, --, --, --, 
   {{0x6440000d,0x00000000,0x00000000,0x00000000}},	//   _ülie, --, --, --, 
   {{0xc984460c,0x58f40327,0x00000000,0x00000000}},	//   зуви, _བྲངས_, --, --, 
   {{0xfbcc5311,0x6e200007,0x76460a09,0x6c5400d8}},	//   ختی_, mxmb, dziy, _оклу, 
   {{0x63a800f3,0x550800e1,0xdb000112,0x00000000}},	//   _čeno, _होइए_, fplä, --, 
   {{0xcfbc03d4,0xda6400ec,0xdb00002f,0x37041d0d}},	//   _ইমান, _ڪاٺي, gplä, нчув, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3b970] --, --, --, --, 
   {{0x81b802f5,0xe9840150,0x00000000,0x00000000}},	//   _অমল_, _تابۋ, --, --, 
   {{0x25f8006d,0x7f580113,0x25ac0135,0xf4140107}},	//   _उनकी_, ynuq, _ħelu_, нҷрӯ, 
   {{0x764401a9,0xa254029e,0x00000000,0x00000000}},	//   bziy, وپاش, --, --, 
   {{0x673c0072,0x00000000,0x00000000,0x00000000}},	//   _ilsj, --, --, --, 
   {{0xdb00007c,0x00000000,0x00000000,0x00000000}},	//   mplå, --, --, --, 
   {{0x660d9495,0xdb00007c,0x61ec025c,0x00000000}},	//   lvak, lplå, ħalq, --, 
   {{0x44300ac5,0x613c0100,0x660c06d9,0x64440200}},	//   myx_, _bèlc, ovak, mzhi, 
   {{0x44320a0a,0x39843b52,0x8024004b,0xdb00007c}},	//   lyx_, löse_, _ډرام, nplå, 
   {{0x660c0357,0xdbca0a0b,0x32000790,0x80240137}},	//   ivak, огод_, çiye_, _ىرام, 
   {{0x64440943,0x44300793,0x660e0a0c,0x203527e0}},	//   nzhi, nyx_, hvak, _تفاس, 
   {{0x76460a0d,0x64440156,0xdb000267,0x00000000}},	//   yziy, izhi, kplå, --, 
   {{0x25fc1d15,0x660c01f5,0x00000000,0x00000000}},	//   _रैली_, jvak, --, --, 
   {{0x673e0a0e,0x6ab40124,0x39840205,0x00000000}},	//   _alsj, _ҧсых, köse_, --, 
   {{0x39440006,0xad2403e6,0x660c01a4,0xdb003b52}},	//   ėms_, _سروو, evak, tplä, 
   {{0x64441682,0x660c017a,0x92c00183,0x7644005a}},	//   dzhi, fvak, ্ভৱ_, tziy, 
   {{0x7ae52799,0x64440dd4,0xdb019342,0x2a34009d}},	// [3b980] _icit, ezhi, rplä, _зээр, 
   {{0x76460a0d,0x673c017a,0xdb000e78,0x3e7c0092}},	//   rziy, _elsj, splä, _የዳሰሳ_, 
   {{0x660e0a0f,0x130811ed,0x64440165,0xdb000267}},	//   avak, жней_, gzhi, pplä, 
   {{0x660e0a10,0x00000000,0x00000000,0x00000000}},	//   bvak, --, --, --, 
   {{0x64440dd6,0x660c0306,0x7ae40051,0x00000000}},	//   azhi, cvak, _mcit, --, 
   {{0xe0082232,0x4430002d,0xe2b401c6,0x00000000}},	//   विंद_, byx_, _үстэ, --, 
   {{0xfbc60a11,0x80a000d1,0x00000000,0x00000000}},	//   _جت_, خمىن, --, --, 
   {{0xd24c0050,0x00000000,0x00000000,0x00000000}},	//   _پۆت_, --, --, --, 
   {{0x10a54dac,0xf99401e4,0x6ce402de,0x6e18007b}},	//   _жизн, _esɨi_, ىزدە, سيدس_, 
   {{0x7ae60a12,0x8d740eff,0x81f400ae,0x00000000}},	//   _acit, باعا, _تفكر_, --, 
   {{0x660c0e8a,0x0e8c00b4,0x00000000,0x00000000}},	//   zvak, _gịnị_, --, --, 
   {{0xbf10009a,0x00000000,0x00000000,0x00000000}},	//   _لومب, --, --, --, 
   {{0x7ae40175,0xbea0403b,0xbf10eaaa,0x23b40ca8}},	//   _dcit, _рачк, _جونب, _kújò_, 
   {{0x613c0066,0x7ae4035a,0x320401a9,0xa87402dd}},	//   _kèla, _ecit, _msmy_, елгі, 
   {{0x44300354,0x660c01a4,0xbc000733,0x00000000}},	//   xyx_, wvak, _ачый, --, 
   {{0x660e0a13,0xdce00109,0x2d8e0a14,0xe69400c7}},	//   tvak, rolą, lmde_, еибы, 
   {{0x660c0cfe,0x2d8c0430,0x00000000,0x00000000}},	// [3b990] uvak, omde_, --, --, 
   {{0x69de0a15,0x660e0a16,0xc9847427,0x64440112}},	//   muse, rvak, _تشبي, tzhi, 
   {{0x69de0a17,0x320400b8,0x68e401d5,0x2d8c01f5}},	//   luse, _asmy_, _ichd, imde_, 
   {{0x490402f8,0x644403bd,0x443004ce,0x660e0a18}},	//   िएको_, rzhi, ryx_, pvak, 
   {{0x69de0a19,0xf1a80133,0xf2e400fb,0x00000000}},	//   nuse, واوه_, тюхо, --, 
   {{0x613c2561,0x3a24023a,0x2d8c01f5,0xa0c4a864}},	//   _bèla, ämpi_, jmde_, ريبو, 
   {{0x69de0a1a,0x9f940184,0x00000000,0x00000000}},	//   huse, ншиш, --, --, 
   {{0x69dc2ffc,0x2d8c2595,0x387e0a1b,0x4ad80263}},	//   kuse, emde_, _øvre_, _भागव, 
   {{0x68e60a1c,0x69de0a1d,0x7ae400b8,0x00000000}},	//   _ochd, juse, _rcit, --, 
   {{0x69dc0fe3,0x7ae60a1e,0x61e8004b,0xb2846b01}},	//   duse, _scit, _iqel, _рыск, 
   {{0x11682b3c,0x69de0a1f,0xe9f80ca8,0x00000000}},	//   _علمی_, euse, _ifẹ_, --, 
   {{0x60c20a20,0x2d8c0b21,0x68e400a3,0x69de0a21}},	//   _helm, amde_, _achd, fuse, 
   {{0x69dc033d,0x60c20a22,0xb8b402dd,0x00000000}},	//   guse, _kelm, көні, --, 
   {{0x60c20a23,0x8e5408a8,0x00000000,0x00000000}},	//   _jelm, _אינג_, --, --, 
   {{0x60c20a24,0x80a407f7,0xfc301867,0xa0200254}},	//   _melm, _चलने, _جحش_, _ööde, 
   {{0x14e00574,0x60c00455,0x68e4d2e1,0xe3e40154}},	//   _पाहण, _lelm, _echd, নবাব, 
   {{0xcf9005e1,0x98a49332,0x9584034b,0x69de0a25}},	// [3b9a0] רטן_, _пипе, елае, cuse, 
   {{0x60c20a26,0x20040010,0x80d84c9f,0x1fc40154}},	//   _nelm, _osli_, _नागे, _এমনস, 
   {{0xccf00375,0xdebc0b82,0xa5d800d1,0x88b8011a}},	//   רכב_, ሰሩን_, كبەر_, _מזיי, 
   {{0xe9f80241,0xd264010b,0x23d002e5,0x14e001f9}},	//   _afẹ_, нкей, _हिरद, _पावण, 
   {{0x60c20a27,0x2d8c03d4,0x21e80429,0x69c801a6}},	//   _belm, ymde_, gúh_, šeev, 
   {{0x60c000de,0x92c00154,0x00000000,0x00000000}},	//   _celm, ্ভে_, --, --, 
   {{0x60c20a28,0x61e801b3,0x69de0a29,0x9160004d}},	//   _delm, _eqel, zuse, _cứ_, 
   {{0x60c0007d,0x80001de1,0x2d880131,0x69dc0472}},	//   _eelm, учше, ﺮﯨﻨﻰ_, yuse, 
   {{0x60c0129b,0x9160001e,0x200400ee,0x69dc000d}},	//   _felm, _từ_, _esli_, xuse, 
   {{0x69de0a2a,0x60c03b13,0x3f500311,0x20040356}},	//   vuse, _gelm, lţul_, _fsli_, 
   {{0x69de0a2b,0x2d8e0a2c,0x68e401a9,0x63a802f0}},	//   wuse, rmde_, _rchd, _čenk, 
   {{0x69dc367a,0xaa580075,0x3f500276,0x2ee00fac}},	//   tuse, диму_, nţul_, _øif_, 
   {{0x69dc0eda,0x6fa8015b,0x68e402d0,0x60c000a2}},	//   uuse, _গিয়ে, _pchd, _yelm, 
   {{0x69de0a2d,0xe80c0574,0x60c20a2e,0x00000000}},	//   ruse, हिला_, _xelm, --, 
   {{0x69de0a2f,0x248c0115,0x1af40154,0xb8680120}},	//   suse, _ĝemo_, ইয়ে_, ејте_, 
   {{0xfbcc1129,0x69de0a30,0x68e40472,0x443c1e27}},	//   _اتو_, puse, _wchd, _āu_, 
   {{0x69de0a31,0xb0e06859,0x6aad6bfb,0x5f1000cd}},	// [3b9b0] quse, _नांग, _ifaf, थयत्_, 
   {{0x0464288a,0x68e60a32,0x29cc00d7,0x00000000}},	//   нтем, _uchd, mľa_, --, 
   {{0x60c01529,0x0464917c,0x5994011a,0x00000000}},	//   _relm, хтам, _שכתב_, --, 
   {{0x60c1d78e,0xe2340120,0x00000000,0x00000000}},	//   _selm, кнењ, --, --, 
   {{0xa2cc543b,0x3984049f,0x60c20a33,0xf1c802ef}},	//   दृष्, lösa_, _pelm, فونى_, 
   {{0x60c0047e,0x00000000,0x00000000,0x00000000}},	//   _qelm, --, --, --, 
   {{0x60c00300,0x6aac0093,0xb8140c5a,0x25fc0037}},	//   _velm, _ofaf, डियम_, रौरी_, 
   {{0x69cc00e4,0x60c02694,0xa2cc00dc,0x850000e5}},	//   _ovae, _welm, दृश्, _جوڑن, 
   {{0x60c0753f,0x1e841b74,0xf1ac01e0,0xf364119e}},	//   _telm, ълим, _ыҡ_, _стрн, 
   {{0x29cc0038,0x6aae0a34,0xf1c8007b,0x5ba89c9d}},	//   dľa_, _afaf, _أولى_, мком_, 
   {{0x69ce0a35,0xd11c6c95,0x29cc0030,0x0d8001c0}},	//   _avae, पारण_, eľa_, рлэн, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8f34011a,0x00000000,0x00000000,0x00000000}},	//   _שאנו_, --, --, --, 
   {{0x23d00d5f,0x613c0066,0x6e9400d1,0xee380212}},	//   _हिंद, _mèlo, _сичу, _яні_, 
   {{0x8c40165d,0x69ce0a36,0xa8640032,0x6aac03cb}},	//   _веще, _evae, герҙ, _ffaf, 
   {{0xe1f80064,0x9b880271,0x00000000,0x00000000}},	//   _opų_, _تنبل_, --, --, 
   {{0xd9445822,0x25fc05d7,0x967402d5,0xd4a40116}},	// [3b9c0] _аепи, रौली_, тыві, визй, 
   {{0x14e00490,0x613c007f,0xb4cc0490,0x00000000}},	//   _पाळण, _sèln, ळणे_, --, 
   {{0xd7c97fe0,0x15fc367a,0x69cc004c,0x6964007b}},	//   _توجه_, _उनकर_, _zvae, _حديق, 
   {{0x8d7c001f,0x6aac031c,0x00000000,0x00000000}},	//   _ካፒታል_, _xfaf, --, --, 
   {{0xcb1025f9,0x3f500311,0x9160004d,0x6440000d}},	//   ילא_, rţul_, _nữ_, _ülin, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x237c01d4,0xa0a40220,0xa1240050,0x9878010f}},	//   blwj_, ушіл, اوى۪, ואַט, 
   {{0x3ce40100,0x3f40002e,0x5f188b95,0xee4400c7}},	//   _acnv_, _añub_, भाग्_, лҭеи, 
   {{0x90c400f7,0x2b202d3b,0xf4e40154,0x8778010f}},	//   _абзе, यासँ_, নজীব, ואקי, 
   {{0x6aac0327,0xc18001d9,0x91600208,0x00000000}},	//   _sfaf, _پۯى۪, _dữ_, --, 
   {{0x6aae0a37,0x6c544ea5,0x395807c5,0x00000000}},	//   _pfaf, укну, dirs_, --, 
   {{0x99ac00bd,0x20540eba,0x005402e4,0x00000000}},	//   _কয়েক, _стур, _בשבת_, --, 
   {{0x69cc003a,0x6f0001f7,0x68380023,0x00000000}},	//   _qvae, memc, _ጥልመት, --, 
   {{0x6f0003ee,0x273400ed,0x3959f2b8,0x00000000}},	//   lemc, _lånt_, girs_, --, 
   {{0x3cf80375,0x2d9c00bb,0x3ce802f0,0x80d80118}},	//   _חלונ, _iive_, živý_, _नाघे, 
   {{0x6aac0451,0x2a680218,0x6f017ccb,0x7b1400a7}},	//   _ufaf, _txab_, nemc, _вдъх, 
   {{0x2d9e0a38,0xf7940006,0x39580064,0xb0b47239}},	// [3b9d0] _kive_, ратэ, birs_, ुराग, 
   {{0xc7c42310,0x6f00014f,0x2d9c045a,0x2b58d95e}},	//   _исми, hemc, _jive_, lisc_, 
   {{0x2d9c00e4,0xc7a800c6,0xc86400a8,0xba740244}},	//   _mive_, _تدخل_, _штии, _مایت, 
   {{0x6f0002fb,0x2b580356,0x20100419,0x00000000}},	//   jemc, nisc_, _ázii_, --, 
   {{0xa158013e,0xdc00015b,0x6f00ec0f,0x00000000}},	//   наду_, এমএস_, demc, --, 
   {{0x2d9c13fd,0x64400037,0x00000000,0x00000000}},	//   _nive_, _ülio, --, --, 
   {{0xdb0008fb,0x25a8058a,0x00000000,0x00000000}},	//   pplø, lqal_, --, --, 
   {{0x2d9c0433,0x26ca0a39,0x395801b8,0x25a8011f}},	//   _aive_, naao_, zirs_, oqal_, 
   {{0x2d9c1556,0x2b58eed2,0x26083b90,0x6e500023}},	//   _bive_, disc_, सिटी_, _ንትግባ, 
   {{0x2d9c5da1,0x39580129,0x00000000,0x00000000}},	//   _cive_, xirs_, --, --, 
   {{0x26c91a99,0x395a0a3a,0x2d9e0a3b,0x2b58031c}},	//   kaao_, virs_, _dive_, fisc_, 
   {{0x27340267,0x25a801a9,0x00000000,0x00000000}},	//   _måns_, kqal_, --, --, 
   {{0x2d9c0c3e,0x98b800b8,0x395a0a3c,0x273401bf}},	//   _five_, _alpā_, tirs_, _låns_, 
   {{0x2d9c0302,0x25a80429,0x98740640,0x00000000}},	//   _give_, dqal_, губљ, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x395a0a3d,0x2d9c05a1,0xa6b407d8,0x2b58009a}},	//   sirs_, _zive_, исущ, cisc_, 
   {{0x5589b897,0x25a800f1,0x00000000,0x00000000}},	// [3b9e0] ебам_, ندلي_, --, --, 
   {{0x27360a3e,0xd87400f7,0x613c02e2,0x2d9c06af}},	//   _sånt_, _ماجب, _bèlm, _xive_, 
   {{0x77942ea3,0x25a80548,0x0d38008f,0x6f0001f7}},	//   _نیسا, aqal_, עגעב, yemc, 
   {{0xd1c80b65,0x7e9800b0,0x613c02e2,0x32000205}},	//   елде_, _kāpī, _dèlm, çiyo_, 
   {{0x6f000455,0xf1240166,0x00000000,0x00000000}},	//   vemc, иякү, --, --, 
   {{0xc50405d9,0xf4860a3f,0x6f00014f,0xf1940229}},	//   _مڪمل_, _نازی, wemc, шиль, 
   {{0x2d9c11c1,0x6f020a40,0x99800006,0xfc260a41}},	//   _rive_, temc, lykų_, _اح_, 
   {{0x2d9e0a42,0x2dd4a5b1,0x62080598,0x7764022e}},	//   _sive_, ажир, äplä, nnix, 
   {{0xd2660a43,0x6f000205,0x7e9800b8,0xd1840395}},	//   _скай, remc, _nāpī, _блай, 
   {{0xbdf486bf,0x60300943,0xd17478da,0x6f0099a6}},	//   اريا_, ṱaṱi, _сыбы, semc, 
   {{0x2d9e0a44,0x3dcc0109,0xaca40521,0x05740375}},	//   _vive_, _evgw_, _ntụz, רגים_, 
   {{0x2d9c0204,0xe9f801fb,0x0d8400ee,0x7e680175}},	//   _wive_, _ngả_, _өлен, _fxgp, 
   {{0x2d9e0a45,0x2b5a0a46,0xfc40034c,0x7e9800b8}},	//   _tive_, risc_, لپیپ, _cāpī, 
   {{0xdc5404d3,0x2b580113,0x8a200124,0xac94004e}},	//   اریک, sisc_, азҭҵ, _калш, 
   {{0x6d4814d0,0x613c02e2,0x96b001f2,0x26c80083}},	//   mhda, _bèlj, _ọfọd, taao_, 
   {{0x8b640214,0x0b8a0a47,0x6d48047e,0x862401ee}},	//   _حاتم, _ясли_, lhda, льзе, 
   {{0x613c0d29,0x6b8e0a48,0xe69800a7,0xc4d80063}},	// [3b9f0] _sèlm, _ihag, тваш_, еђе_, 
   {{0x6d4a0a49,0xc6a400d1,0x25a80009,0xa8540798}},	//   nhda, _әрни, rqal_, _вкоч, 
   {{0x6b8c0084,0x26c80421,0x77640393,0xe37404b3}},	//   _khag, paao_, bnix, алжы, 
   {{0x7e9802b5,0x69dc20ac,0x644000c5,0xaab402ab}},	//   _hāpū, orse, _ülim, ंडिक, 
   {{0x6d4a0a4a,0x29100810,0x6b8e0a4b,0x63a800ef}},	//   khda, odza_, _mhag, _čenu, 
   {{0x2912015b,0x69dccfd4,0x672c8e70,0x6b8c0363}},	//   ndza_, irse, ljaj, _lhag, 
   {{0x3f400022,0x29120a10,0x6b8c00b5,0x69dc0112}},	//   _añua_, idza_, _ohag, hrse, 
   {{0x613c02bd,0x6d480009,0x623441e5,0x9f8400d8}},	//   _kèlk, ehda, _кебу, јгид, 
   {{0x3f800029,0x0dc4013d,0x672c009a,0x47bc0327}},	//   ēju_, алый_, ijaj, _མཆྀམ, 
   {{0x6d480978,0x6b8c0516,0x291001fa,0x613c0100}},	//   ghda, _ahag, jdza_, _mèlk, 
   {{0x6b8c1161,0x69de0a4c,0xdc68a848,0x77640227}},	//   _bhag, erse, танд_, ynix, 
   {{0x6b8e0a4d,0x672c2252,0x29120a4e,0x6d4801d9}},	//   _chag, jjaj, edza_, ahda, 
   {{0x6b8d6282,0x672c4dfc,0x7f580194,0x6d4803d5}},	//   _dhag, djaj, miuq, bhda, 
   {{0x6d4a0a4f,0x7f586018,0x6b8c0124,0x672c01e2}},	//   chda, liuq, _ehag, ejaj, 
   {{0x1ad407d6,0x5c78008f,0x6b8c3e7c,0x69de0a50}},	//   _кўпр, _באַה, _fhag, arse, 
   {{0x6b8e0a51,0x672c998f,0x291000d7,0x966400db}},	//   _ghag, gjaj, adza_, акбе, 
   {{0x4b78010f,0x7b084424,0x62880198,0x77640005}},	// [3ba00] _באקו, āstī, _nzeo, rnix, 
   {{0x7f580357,0x613c02e2,0x18880116,0x1ddc000d}},	//   hiuq, _dèlk, _үсүп_, _मिनत, 
   {{0x628a0a52,0xdb0002f0,0x0574007b,0x00000000}},	//   _azeo, zplý, جملة_, --, 
   {{0xd1b001b9,0x6b8c0200,0x63a80419,0x6d48467e}},	//   قیرک, _xhag, _čent, zhda, 
   {{0x15b802dd,0x00000000,0x00000000,0x00000000}},	//   _шыны_, --, --, --, 
   {{0x415000d6,0x3448010b,0x154401b9,0x7bc0010b}},	//   овіс, _йүзи_, _тегм, _ownu, 
   {{0x4f680da9,0x00000000,0x00000000,0x00000000}},	//   кшим_, --, --, --, 
   {{0xd1140490,0x69dc2d62,0xc7b0011a,0x272c00e5}},	//   _धोरण_, yrse, חבה_, _tűnő_, 
   {{0x6b8c0f7b,0x6d4a0a53,0x50d40330,0x0e44010b}},	//   _rhag, thda, _نزار, рэйм, 
   {{0x6b8e0a54,0x69dc0b91,0xe9f80051,0xc5f0011a}},	//   _shag, vrse, _ngạ_, קדת_, 
   {{0x6b8e0a55,0x672cfbfe,0xa3c8353b,0x3f40005a}},	//   _phag, yjaj, लीप_, _iñun_, 
   {{0x6d48006c,0x6b8c00aa,0xdb0009f3,0x2910033f}},	//   shda, _qhag, pplý, wdza_, 
   {{0x69de0a56,0x6b8c06d6,0x7bc0031c,0x6abc0e78}},	//   urse, _vhag, _ewnu, rbsf, 
   {{0x69de0a57,0x291005b8,0x8af406be,0x2a6c0003}},	//   rrse, udza_, _şədd, ħeb_, 
   {{0x6d5801aa,0x6b8c1549,0x29100210,0x7e980055}},	//   _imva, _thag, rdza_, _vāpū, 
   {{0x6b8c2da1,0xa3c80c2e,0xfd4c010e,0x442402cb}},	//   _uhag, लीफ_, ksiỳ, یراف, 
   {{0x672e0a58,0x35b5ca33,0xa3c80fe3,0x29100810}},	// [3ba10] rjaj, жбур, लीन_, pdza_, 
   {{0x6440007d,0x672c04a7,0x8b640451,0x38c800db}},	//   _ülik, sjaj, _حاڪم, _куюн_, 
   {{0xdb000ba1,0x38c801ec,0xe28400d1,0x00000000}},	//   mplò, _туын_, әлли, --, 
   {{0xe1f0e636,0x613c02e2,0x20000076,0x91d0000d}},	//   كست_, _tèlk, çhim_, _सिखई, 
   {{0x6d5a0a59,0x613c0f87,0x2368010f,0xb0b401f9}},	//   _omva, _hèli, ĵaj_, ुरंग, 
   {{0xa06a0a5a,0x2bac0316,0x613c0066,0xb4b86449}},	//   лала_, _něco_, _kèli, _نافذ_, 
   {{0xb90c02e3,0x00000000,0x00000000,0x00000000}},	//   _achụ_, --, --, --, 
   {{0x6d5830f5,0x320c01f4,0x00000000,0x00000000}},	//   _amva, ähyä_, --, --, 
   {{0x6d5802d2,0xb0e028fe,0x2ae02052,0x00000000}},	//   _bmva, _नाचग, _काजु_, --, 
   {{0x1d080063,0x417438b5,0x00000000,0x00000000}},	//   ћени_, _ئارس, --, --, 
   {{0xdca40131,0x00000000,0x00000000,0x00000000}},	//   _һали, --, --, --, 
   {{0xa3c82dc5,0x00000000,0x00000000,0x00000000}},	//   लीय_, --, --, --, 
   {{0x3da60a5b,0x3ebc7cba,0x8f9804ae,0x8d9007d6}},	//   _треб, mbut_, _עיני, تلیش, 
   {{0x4e7804ac,0x3ebd2b55,0x1278010f,0x00000000}},	//   _גאנצ, lbut_, ראשע, --, 
   {{0x613c381a,0xa3c858fc,0xd6f80408,0x64400037}},	//   _cèli, लीम_, лхаш_, _ülih, 
   {{0x3ebc089c,0x9b8828ee,0xe80c03e5,0xf7200092}},	//   nbut_, _حنبل_, हिजा_, _ትሬዲን, 
   {{0x2a349bb1,0x99d60a5c,0x00000000,0x00000000}},	// [3ba20] _дээр, _اتبا, --, --, 
   {{0x998404fb,0x613c5c17,0x395c07c5,0x00000000}},	//   _دلخو, _fèli, _övs_, --, 
   {{0xa5dc0034,0x613c004e,0xb81c0037,0x9664010a}},	//   _पिथौ, _gèli, _पछिम_, _ӳкме, 
   {{0x2b200034,0xd0580115,0xd3943c1a,0xd77400db}},	//   याएँ_, _patɾ, сәгә_, _چاڭع, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd2500a81,0x14e00073,0x00000000,0x00000000}},	//   _ہنز_, _पाटण, --, --, 
   {{0x7ff00046,0xc3240116,0x00000000,0x00000000}},	//   كسيا, شكۈن_, --, --, 
   {{0xadb60a5d,0xea2401e1,0x00000000,0x00000000}},	//   обиш, _ẹ̀sẹ, --, --, 
   {{0xdd8c0058,0x63a0020c,0x160c0307,0x00000000}},	//   چۈن_, _èlna, सिटर_, --, 
   {{0x3ebc2819,0x6e240135,0x64680309,0x00000000}},	//   abut_, _ġibd, špiš, --, 
   {{0xf9f41efe,0xef100137,0x00000000,0x00000000}},	//   _བདུན_, _жүйө, --, --, 
   {{0x613c007f,0x622000db,0xd04803e0,0x00000000}},	//   _rèli, _رۉۉل, ışız_, --, 
   {{0x44260a5e,0xff24edfb,0x07440220,0x00000000}},	//   ̣n_, _دبلی, ұхам, --, 
   {{0x6d582939,0x613c0ba1,0xac1800c0,0x00000000}},	//   _umva, _pèli, _воку_, --, 
   {{0xa8983334,0xad2400f1,0x00000000,0x00000000}},	//   ркву_, _هرډو, --, --, 
   {{0x64400254,0x00000000,0x00000000,0x00000000}},	//   _ülii, --, --, --, 
   {{0xa534055f,0xbb480451,0x2b4a0a5f,0xf8b83a49}},	// [3ba30] онач, _دلين_, _ilac_, шөө_, 
   {{0x3ebc0781,0x2b4805c7,0x00000000,0x00000000}},	//   zbut_, _hlac_, --, --, 
   {{0x2b480ac5,0x635402bf,0x4424004d,0xa2d49d62}},	//   _klac_, овжу, ãn_, قيات, 
   {{0xe2f8005e,0x942400cf,0x00000000,0x00000000}},	//   реді_, تومۇ, --, --, 
   {{0x65960a60,0x2b4801a6,0x00000000,0x00000000}},	//   _маму, _mlac_, --, --, 
   {{0x2b4a0a61,0x661c8ead,0x1fb40107,0x6ab40d79}},	//   _llac_, _irsk, осир, ंडुर, 
   {{0x3ebc089c,0x661c1674,0x00000000,0x00000000}},	//   tbut_, _hrsk, --, --, 
   {{0xd00c5de1,0xcf8c01d9,0xa06800fb,0xa34400f2}},	//   ئلي_, نژن_, лаһа_, _بپره, 
   {{0x3ebe0a62,0x82360a63,0xf1e0095f,0x3300033b}},	//   rbut_, _ارزا, _नियन, _dčyč_, 
   {{0x661c0b94,0xc0d40023,0xa40c0037,0x8d906ea9}},	//   _mrsk, ኪቦም_, _सनाप_, وليش, 
   {{0x2b4855e9,0x6e24025c,0x00000000,0x00000000}},	//   _blac_, _ġibe, --, --, 
   {{0xa3e019e5,0x6e260a64,0xa2cc8bb5,0x661c1e00}},	//   _दिन_, _šibe, दृच्, _orsk, 
   {{0xa3c80574,0x81a80154,0x398401f4,0x00000000}},	//   लीत_, কীর_, lösi_, --, 
   {{0x26d805ac,0x3a4800ef,0x32002ca8,0x00000000}},	//   _adso_, _čupā_, çiyi_, --, 
   {{0x6b4c000f,0x7c940150,0xdca400d1,0x661dfa90}},	//   _bûgd, _اششا, _лаһи, _arsk, 
   {{0x661c0f72,0x236c151c,0x2b4a0a65,0x1784177b}},	//   _brsk, _njej_, _glac_, ігам, 
   {{0x99740107,0x00000000,0x00000000,0x00000000}},	// [3ba40] _муош, --, --, --, 
   {{0x661c0552,0xf1e0a3c6,0x613c020c,0x8960010b}},	//   _drsk, _निबन, _kèlu, _окыж, 
   {{0x661dd794,0xdebc01f3,0xa5d80116,0x00000000}},	//   _ersk, ደሩን_, لبەر_, --, 
   {{0x649a0a66,0x613c020c,0x70b40b3c,0x437001d5}},	//   стур_, _mèlu, ुर्ल, وهلر, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8134185e,0x00000000,0x00000000,0x00000000}},	//   قسىز_, --, --, --, 
   {{0xf48403e6,0x00000000,0x00000000,0x00000000}},	//   _راسی, --, --, --, 
   {{0xb8cc4933,0x236c044e,0x6b4c000f,0xe3b05285}},	//   _བུ_, _gjej_, _kûge, _سرِ_, 
   {{0xcd04524d,0xc0b8001f,0xfe6c01d3,0x11d4003b}},	//   очни, ደሉም_, ہدی_, _фібр, 
   {{0x2b4801ab,0xf3f80327,0x0ca80107,0x62580212}},	//   _slac_, _པྱོད_, штии_, _урср_, 
   {{0x2b48fefe,0x613c004e,0x3fc80133,0x09d00073}},	//   _plac_, _pèlv, _ندنی_, तळ्य, 
   {{0x8cb8194b,0xbf1000d1,0x0e44009d,0x00000000}},	//   _श्रो, _يولب, _мэлм, --, 
   {{0xfd0c0b29,0x64400037,0x1fc400eb,0x00000000}},	//   رجی_, _üliv, _এমএস, --, 
   {{0x1cd80003,0x00000000,0x00000000,0x00000000}},	//   _འཇར_, --, --, --, 
   {{0x78b002fb,0x6bd80691,0x25b80205,0x661c0419}},	//   _živý, _اوبس_, _stsl_, _srsk, 
   {{0x661c1591,0x6b4c002d,0x49000137,0x00000000}},	//   _prsk, _bûge, чүүг, --, 
   {{0x5a00014b,0x00000000,0x00000000,0x00000000}},	// [3ba50] _пӯрв, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfa346646,0xe194009d,0x92a40210,0x00000000}},	//   _فرید, үрлэ, _obłę, --, 
   {{0x6b4c0a85,0x661c08a4,0x25b800ad,0x00000000}},	//   _fûge, _trsk, _ttsl_, --, 
   {{0x20d40845,0xe12401b9,0x3cd8000d,0x00000000}},	//   пійс, змли, _गएले_, --, 
   {{0x8cb807b7,0x7bc40327,0x39840108,0x00000000}},	//   _श्लो, ġjuz, tösi_, --, 
   {{0xd12cf629,0x236c049f,0x660e0a67,0x63c80014}},	//   امى_, _tjej_, lwak, _دِزِ_, 
   {{0x3f400d04,0x660c01f7,0x00000000,0x00000000}},	//   _iñuk_, owak, --, --, 
   {{0x613cbe6d,0x802400dd,0x660e0a68,0xa3e00073}},	//   _bèlt, _ڈرام, nwak, _दिड_, 
   {{0x80260a69,0x613c068c,0x660d0814,0x9f9c06be}},	//   _ورام, _cèlt, iwak, lçün_, 
   {{0x660e0a6a,0x613c067c,0x00000000,0x00000000}},	//   hwak, _dèlt, --, --, 
   {{0xd434011a,0x9f9c03e3,0x00000000,0x00000000}},	//   לטתי_, nçün_, --, --, 
   {{0x4a400801,0x98a400cf,0x00000000,0x00000000}},	//   еняв, зиге, --, --, 
   {{0x660d6591,0x6b4c000f,0xdce0005f,0xd94400f7}},	//   dwak, _rûge, rolē, чеги, 
   {{0x1a649eb2,0x613c004e,0x6b4c002d,0xdea001b9}},	//   تیکی_, _hèls, _sûge, _تیکی, 
   {{0xcc3804ac,0x660c00d2,0x9a280117,0x5ac801a9}},	//   _לעצט, fwak, _гоиб_, _улим_, 
   {{0xa3c85345,0x660e0a6b,0xbbd800af,0xf1e02a67}},	// [3ba60] लीस_, gwak, _मटुक, _निधन, 
   {{0x3a200113,0x45800261,0xe748002b,0x260c00ef}},	//   _irip_, егув, _kāśī, _džo_, 
   {{0x660c04ba,0x49380375,0x00000000,0x00000000}},	//   awak, _הגיו, --, --, 
   {{0x3a220a6c,0x660e0a6d,0x00000000,0x00000000}},	//   _krip_, bwak, --, --, 
   {{0x3b000399,0x660c009a,0x613c007f,0xe2a803e6}},	//   _mbiq_, cwak, _nèls, زانن_, 
   {{0x2ce80327,0x31340120,0x829000db,0xc2041d37}},	//   _འཐེབ, ќекр, رۇلچ, سقىن_, 
   {{0xca7c022e,0x57d800ab,0xe7480055,0x79500166}},	//   _loqа, _बटोह, _nāśī, _täwf, 
   {{0x66241248,0x8eb023f6,0x613c0100,0xdcf000b8}},	//   _ütkä, رەتت, _bèls, _āgām, 
   {{0x8d8446e5,0x0ca82c11,0xcd2801b9,0x050c03d4}},	//   зунд, йтни_, مسدن_, সাৰৰ_, 
   {{0xb3e005f9,0x6ab40807,0xe3b0004b,0xc1b8011a}},	//   _पटाख, ंड्र, _سرې_, _לממש, 
   {{0x660e0a6e,0x8c6447b3,0x3a207cd8,0xe7480055}},	//   zwak, ятид, _arip_, _cāśī, 
   {{0x660e0a6f,0x3a200204,0x613c007f,0xdb1401e1}},	//   ywak, _brip_, _wèlt, _àbìr, 
   {{0x3a20003a,0x00000000,0x00000000,0x00000000}},	//   _crip_, --, --, --, 
   {{0x660c003c,0x79a4235c,0xe89400c7,0x9e6433d2}},	//   vwak, ерсе, дагь, _تامن, 
   {{0x660e0a70,0xddc80210,0x67d400d4,0x00000000}},	//   wwak, czeł, ьову, --, 
   {{0x660e0a71,0x1cd80003,0x1dd002e5,0x8d740244}},	//   twak, _འཇོ_, _दौडत, _باڤا, 
   {{0x4ac023c1,0x3a202517,0xe7380417,0x45380092}},	// [3ba70] _व्यव, _grip_, бең_, _በማክበ, 
   {{0x660e0a72,0x79500166,0xd5ac0a81,0x4428117e}},	//   rwak, _cäwd, شہِ_, йцем_, 
   {{0x660e0a73,0xa2f42081,0x27380064,0x00000000}},	//   swak, дпеч, _дзнь_, --, 
   {{0x1ddc068f,0xc7640220,0x9990010e,0x6d940241}},	//   _मिलत, _ءادى, _asyň_, bàag, 
   {{0xdb0001e6,0x79500139,0x660c0309,0x21740107}},	//   pplö, _fäwd, qwak, мукр, 
   {{0x2bac012c,0x181827a1,0x63780724,0x7950008e}},	//   _těch_, _اریک_, _sänğ, _gäwd, 
   {{0xf1f405f5,0xd00dea7f,0x613c0100,0x29000055}},	//   _үзсэ, للو_, _sèls, _mbha_, 
   {{0x39849577,0x2f5429c3,0x6e248c2c,0x5dd91b52}},	//   löst_, етьс, _šiba, офор_, 
   {{0x1ddc0574,0x290000a3,0xc8bc530e,0x00000000}},	//   _मिळत, _obha_, ्राट, --, 
   {{0x1c460a74,0x644000c5,0x3a20036e,0x3984007c}},	//   дном, _ülis, _rrip_, nöst_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x5f80215c,0x71240150,0x3a200419,0x20040205}},	//   _جۇبە, _يرەل, _prip_, _ipli_, 
   {{0x49c44ea5,0x999000a2,0x3a2003b9,0x02a80037}},	//   млян_, _ysyň_, _qrip_, _छलैन, 
   {{0x200405b1,0x31bc0ae5,0x30980023,0x310000cd}},	//   _kpli_, ﻧﺪﯨﻜ, _ቅንጣብ_, ल्पः_, 
   {{0x2ce80022,0x3984007c,0x00000000,0x00000000}},	//   _хьчо_, döst_, --, --, 
   {{0x79500724,0x00000000,0x00000000,0x00000000}},	//   _säwd, --, --, --, 
   {{0x3a200502,0xd4d806c2,0x1d700092,0x398402d2}},	// [3ba80] _urip_, قباض_, _ድብደባ_, föst_, 
   {{0x3ddc03d4,0x70ac00c5,0x00000000,0x00000000}},	//   _বঙাল, _चलेल, --, --, 
   {{0xa3c80574,0xf485308c,0xf1e000cd,0x00000000}},	//   लील_, راطی, _निहन, --, 
   {{0x27e40038,0x91e4cd8d,0xd629001e,0x795000fd}},	//   álne_, доде, _доме_, _däwe, 
   {{0x20060a75,0x1b2c0020,0x2bac012c,0x79500166}},	//   _apli_, _እየተካ, _věci_, _täwd, 
   {{0xdce000c8,0x7764208d,0x00000000,0x00000000}},	//   bilĉ, liix, --, --, 
   {{0x20041529,0x7950010e,0x76440009,0x398401e3}},	//   _cpli_, _gäwe, lyiy, löss_, 
   {{0x1cd8003d,0x753cbb75,0xda0c0490,0x3f6092fe}},	//   _འཇུ_, _horz, िबात_, ктыб, 
   {{0x753c006d,0xb640037e,0x76445141,0x6ce40131}},	//   _korz, _ｂｓ_, nyiy, ۈزگە, 
   {{0x753c01c7,0x2cb801ab,0x1fa401c6,0xddc8012d}},	//   _jorz, ùrd_, мрөг, dzeń, 
   {{0x753e0a76,0xddd0005f,0x7950013d,0x07640092}},	//   _morz, ēgša, _xäwe, _ተፈጠረ_, 
   {{0xa3e051a5,0x290001ab,0x7950013d,0xdce000c0}},	//   _दिस_, _sbha_, _näwb, kolė, 
   {{0xc3300bd4,0x753c0cf9,0x76440223,0x77640009}},	//   דור_, _oorz, jyiy, diix, 
   {{0x753c03bd,0x2ce8025c,0x00000000,0x00000000}},	//   _norz, _འཐིབ, --, --, 
   {{0x1af40183,0x7644058a,0x499001d3,0x6d4802d0}},	//   েয়ে_, eyiy, ٹیگر, mkda, 
   {{0x79500724,0x6d4a0a77,0xd734009d,0x00000000}},	//   _räwe, lkda, ндсө, --, 
   {{0x6aae0a78,0xddc80034,0x753e0a79,0x398404cc}},	// [3ba90] _igaf, czeń, _borz, töst_, 
   {{0x69cc123c,0x6d4a0a7a,0x753d072d,0xc8b04d2f}},	//   _iwae, nkda, _corz, _جلدک, 
   {{0xa3c8d59c,0x6aac657a,0x69ce0a7b,0x8881b1d2}},	//   लीं_, _kgaf, _hwae, _شیرن, 
   {{0x69ce0a7c,0x76455cf3,0x00000000,0x00000000}},	//   _kwae, byiy, --, --, 
   {{0x76440223,0x29cc6c3c,0x6b9c05ac,0x69cc0175}},	//   cyiy, nža_, imsg, _jwae, 
   {{0xf1e070bb,0x673c0083,0x753e0a7d,0x69cc007f}},	//   _निरन, _hosj, _gorz, _mwae, 
   {{0x6aacb398,0x673c00f3,0xa18401e0,0x00000000}},	//   _ogaf, _kosj, мыҫл, --, 
   {{0x6aae0a7e,0x61fc014a,0x6564192e,0x673c7566}},	//   _ngaf, _äslo, lihh, _josj, 
   {{0x673c08fb,0x44300072,0x00000000,0x00000000}},	//   _mosj, lxx_, --, --, 
   {{0x63aa0a7f,0x29ce0a80,0x44200263,0x79500139}},	//   _hien, dža_, _krj_, _mäwc, 
   {{0x63a81f21,0x69cc016b,0x44320a81,0x6288020b}},	//   _kien, _awae, nxx_, _hyeo, 
   {{0x6d493c19,0x77646928,0x63aa0a82,0x6288020b}},	//   akda, xiix, _jien, _kyeo, 
   {{0x4420020b,0xed5001d3,0x00000000,0x00000000}},	//   _lrj_, _چھپ_, --, --, 
   {{0x63aa0a83,0x764407a8,0x69cc000f,0x6288020b}},	//   _lien, vyiy, _dwae, _myeo, 
   {{0x69cc0069,0xb8d8007d,0x442014a9,0x673c0d27}},	//   _ewae, _छल_, _nrj_, _bosj, 
   {{0x63aa0a84,0x753c005a,0x68340036,0x5ac8519b}},	//   _nien, _sorz, _südë, _элим_, 
   {{0x753e0a85,0x628801e0,0x69cc00a9,0x673e0a86}},	// [3baa0] _porz, _nyeo, _gwae, _dosj, 
   {{0x63aa0a87,0x06800228,0xdce00006,0x77640014}},	//   _aien, угун, rolė, siix, 
   {{0x63aa0a88,0x1308467b,0x753c0730,0x62880241}},	//   _bien, зней_, _vorz, _ayeo, 
   {{0x63aa0a89,0x628800b5,0x673de752,0x753c0076}},	//   _cien, _byeo, _gosj, _worz, 
   {{0x63aa0a8a,0x6d4800ee,0x44200036,0x7644009a}},	//   _dien, ykda, _erj_, qyiy, 
   {{0x63aa0a8b,0x6e2401fa,0x00000000,0x00000000}},	//   _eien, _šibo, --, --, 
   {{0x63aa0a8c,0x93580262,0x4430003a,0xd24c01ed}},	//   _fien, _ерау_, cxx_, ؤنڈ_, 
   {{0x63aa0a8d,0x03a04545,0xdd9001d3,0x00000000}},	//   _gien, _бисо, یوٹ_, --, 
   {{0x6288020c,0xfeb400f7,0x613c020c,0xbf3000d1}},	//   _gyeo, رايت_, _tèlp, ارىغ, 
   {{0x63a805f5,0x69cc0810,0x6aac0042,0x29cc8a8a}},	//   _zien, _rwae, _sgaf, vža_, 
   {{0x6d4a0a8e,0xbdf5c31c,0x63a80207,0x69cc05e4}},	//   rkda, وریا_, _yien, _swae, 
   {{0x63aa0a8f,0xddc800e2,0xbf1016ac,0x81a800cc}},	//   _xien, dzeņ, _مومب, কীও_, 
   {{0x673e0a90,0x656459fc,0x64440369,0x6b9c0162}},	//   _rosj, yihh, zyhi, rmsg, 
   {{0xa3e009fd,0x673e0a91,0x29ce0a92,0x4430002d}},	//   _दिल_, _sosj, rža_, yxx_, 
   {{0x673c036f,0x693400f2,0x2d8c00a2,0x00000000}},	//   _posj, _یکسر, mlde_, --, 
   {{0x2d8c049f,0x6aae0a93,0x69ce0a94,0x44200076}},	//   llde_, _ugaf, _twae, _rrj_, 
   {{0x63aa0a95,0x4420009b,0x673c01f5,0x2d8c0af9}},	// [3bab0] _rien, _srj_, _vosj, olde_, 
   {{0x63aa0a96,0x628a0a97,0x44200263,0x6444004b}},	//   _sien, _ryeo, _prj_, tyhi, 
   {{0x6e24110c,0x2d8c01a4,0xca7c022e,0x6564014f}},	//   _šibl, ilde_, _voqе, rihh, 
   {{0x443000b5,0x2d8c009a,0x65660a98,0xe8f80166}},	//   rxx_, hlde_, sihh, _элү_, 
   {{0x63aa0a99,0x26ca0a9a,0x644400ca,0xa1582ec9}},	//   _vien, mbao_, syhi, маду_, 
   {{0x63aa0a9b,0x26ca0a9c,0x64440b7e,0x79520a9d}},	//   _wien, lbao_, pyhi, _käwa, 
   {{0x63aa0a9e,0x3494016c,0xb2740220,0x44200100}},	//   _tien, _барр, _ұлтш, _urj_, 
   {{0x2d8c2595,0x1cd80135,0x63a801f5,0x26ca0a9f}},	//   elde_, _འཇང_, _uien, nbao_, 
   {{0x81b800bd,0x60f802e8,0x26c80051,0x13e400cc}},	//   _আটক_, _оная_, ibao_, _নহয়, 
   {{0xdca60aa0,0x2d8c05ac,0x8e8000c7,0x9c2401d5}},	//   капи, glde_, ргье, вдод, 
   {{0x3ba4039b,0x6b5c00e4,0x00000000,0x00000000}},	//   ллоҳ, hũgu, --, --, 
   {{0x2d8e0aa1,0xe4e005d7,0x1034011a,0x00000000}},	//   alde_, गृति_, _בטעם_, --, 
   {{0x3f9c22a9,0x3b38001f,0x98d402bf,0x2b580200}},	//   mmuu_, _እየጨመ, ківщ, ërca_, 
   {{0x3f9c208d,0x00000000,0x00000000,0x00000000}},	//   lmuu_, --, --, --, 
   {{0x3f9c0ba7,0x79500166,0x858802dd,0x2bd001f9}},	//   omuu_, _cäwa, _ﺒﻬﺫﺍ_, थीदा, 
   {{0x27e401a2,0x79500724,0xddc8005f,0xc6080154}},	//   álna_, _däwa, rzeņ, রিনা_, 
   {{0x6b4c045f,0xc7a00353,0x2bac0055,0x1a98010f}},	// [3bac0] _mûgl, ритк, _iśca_, _קיִע, 
   {{0x26c804cc,0xdce000ef,0x70d0000d,0x00000000}},	//   abao_, dolī, _सजेल, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd39429db,0xdce00010,0x660800a2,0x26c80208}},	//   тәгә_, dilč, _ţeke, cbao_, 
   {{0x2d8c2b96,0xa3e000c5,0x1dd002db,0x00000000}},	//   ylde_, _दिअ_, _दौलत, --, 
   {{0xdb24145e,0x3f9c0ba7,0x7f81328f,0x41242db7}},	//   äpêr, emuu_, یلون, кочо_, 
   {{0xcf9803b7,0x7ff000c6,0xc9500375,0xb4c00c6e}},	//   мји_, لسيا, שמו_, ीरी_, 
   {{0xa2c000d1,0xdce000ef,0x00000000,0x00000000}},	//   _ләшк, bolī, --, --, 
   {{0x2d8c0770,0x00000000,0x00000000,0x00000000}},	//   tlde_, --, --, --, 
   {{0xfe6c74bb,0x3f9c0ba7,0xdbcc0055,0xa2240214}},	//   تدى_, amuu_, _aññe, _حرفه, 
   {{0xc0f802d3,0x8ff8460e,0xead50326,0x00000000}},	//   ሊኦም_, _زرار_, лонь, --, 
   {{0x0e640348,0xd5e07f1a,0x795000b0,0xcb4400c7}},	//   _икен, _पिंज, _räwa, тхои, 
   {{0xbd8400db,0x00000000,0x00000000,0x00000000}},	//   رچۇن_, --, --, --, 
   {{0x644000cf,0x00000000,0x00000000,0x00000000}},	//   _àlig, --, --, --, 
   {{0x26c8004d,0x81c400de,0xfce00798,0x7d34011a}},	//   tbao_, mmēš, _тојо, _בנגב_, 
   {{0x81c400e2,0x6e24025c,0x6b5c00e4,0x4ae401d5}},	//   lmēš, _ġibj, tũgu, _рўка, 
   {{0x26c8110c,0x6e240010,0xc95801a9,0x00000000}},	// [3bad0] rbao_, _šibj, _жўн_, --, 
   {{0x69dc12ed,0x6b5c0124,0xe4d400cf,0x95e400db}},	//   msse, rũgu, اقاد, ايلۇ, 
   {{0x29100537,0x69dc6a0d,0x7588011b,0x00000000}},	//   meza_, lsse, тств_, --, 
   {{0x29120aa2,0x69de0aa3,0xdce16185,0x48fc012c}},	//   leza_, osse, vilč, श्रो_, 
   {{0x69dc8bab,0x65a800d7,0x00000000,0x00000000}},	//   nsse, _užho, --, --, 
   {{0x69de0aa4,0xd5f8025f,0x98c408ad,0x68f40226}},	//   isse, _אפשר, čući_, ngzd, 
   {{0xdce000e2,0xf4341999,0x68f40153,0x00000000}},	//   solī, _керэ, igzd, --, 
   {{0x29105975,0x9730001f,0x91d00183,0xdce00010}},	//   heza_, _አወዳድ, _সমৰ্, rilč, 
   {{0x29120aa5,0x69de0aa6,0x63b40198,0x3f9c8ebb}},	//   keza_, jsse, _huzn, rmuu_, 
   {{0x29120aa7,0x69dc1347,0x63b60aa8,0x81640150}},	//   jeza_, dsse, _kuzn, _جەتك_, 
   {{0x69de0aa9,0x29120aaa,0x63b408ad,0xdcf80139}},	//   esse, deza_, _juzn, _quwı, 
   {{0x63b40399,0xa2c80073,0xa3e000bc,0x00000000}},	//   _muzn, _ह्म्, _दिई_, --, 
   {{0x29120aab,0x1ddc06e3,0x00000000,0x00000000}},	//   feza_, _मिटत, --, --, 
   {{0x29120aac,0x6d940109,0x28a41df0,0x38c807d6}},	//   geza_, làan, _गृहि, ضاسی_, 
   {{0x63b42630,0x00000000,0x00000000,0x00000000}},	//   _nuzn, --, --, --, 
   {{0xefe402d3,0x2b980118,0xdb0c1577,0x00000000}},	//   _ዞባዊ_, téce_, ökäs, --, 
   {{0x29120aad,0x7ae60aae,0xceb006a9,0xd94401a9}},	// [3bae0] beza_, _idit, מין_, _бепи, 
   {{0x63b406f2,0xb4c02a09,0x291000ca,0x6e2409a8}},	//   _buzn, ीरे_, ceza_, _šibk, 
   {{0xd37003e6,0x12e402dd,0x00000000,0x00000000}},	//   مێسک, гілг, --, --, 
   {{0x63b40097,0x7ae40204,0x03a008ca,0xe7442a9d}},	//   _duzn, _jdit, бихо, _күсе_, 
   {{0x6b4c002d,0x7ae4009a,0x5ea80154,0xfbc4e750}},	//   _bûgj, _mdit, ছুতে, _گت_, 
   {{0xca78008f,0xd0182d3c,0x00000000,0x00000000}},	//   ענסט, ефи_, --, --, 
   {{0xa3e02068,0x7ae60aaf,0xfbc55a4b,0x2ca00115}},	//   _दिए_, _odit, _دت_, _ĝido_, 
   {{0x69de0ab0,0x29120ab1,0x7ae60ab2,0xd37019be}},	//   ysse, zeza_, _ndit, _اهر_, 
   {{0x80d003f4,0x29103824,0x4538001f,0xa5dc0037}},	//   _সার্, yeza_, _በማኅበ, _पिछौ, 
   {{0x7ae60ab3,0x291001e2,0x69dc2dba,0xd76c001f}},	//   _adit, xeza_, vsse, _በገበያ_, 
   {{0x291134aa,0xfe6c036b,0x69dc0334,0xc20c0050}},	//   veza_, قدی_, wsse, _ؤہ_, 
   {{0x29120ab4,0xa3c806ab,0x644000db,0x2ec41e4a}},	//   weza_, लीट_, _àlie, _төкм, 
   {{0x2910e657,0x69de0ab5,0x6abc074d,0x5fa00132}},	//   teza_, usse, rcsf, _بەيم, 
   {{0x27e400d0,0xee380166,0xfbcc3bd7,0xb4c02429}},	//   álno_, _пнҗ_, _کتو_, ीरो_, 
   {{0x67d60ab6,0xab940150,0x00000000,0x00000000}},	//   робу, _кикі, --, --, 
   {{0x69dc143a,0xcc3400c7,0x00000000,0x00000000}},	//   psse, _ахҩы, --, --, 
   {{0x29101813,0x00000000,0x00000000,0x00000000}},	// [3baf0] peza_, --, --, --, 
   {{0x1cd80135,0x291127b7,0x61fc0793,0x7ae40010}},	//   _འཇབ_, qeza_, _äsli, _zdit, 
   {{0x4424498d,0x7ea837be,0x80d0015b,0x48a93095}},	//   ín_, _köpü, _সাল্, _ятим_, 
   {{0x6f040784,0x63b40166,0x00000000,0x00000000}},	//   _ñich, _vuzn, --, --, 
   {{0xa3c80d5f,0x6e2400ae,0x00000000,0x00000000}},	//   लीज_, _áibh, --, --, 
   {{0xa0689d7e,0x98b80029,0x63b408a4,0xe0446d8c}},	//   кала_, _kopā_, _tuzn, инли, 
   {{0x68e401a9,0x00000000,0x00000000,0x00000000}},	//   _mdhd, --, --, --, 
   {{0xddc80034,0x2d9c0254,0x5f28011c,0x00000000}},	//   cześ, _ahve_, тоим_, --, 
   {{0x1cd80327,0x00000000,0x00000000,0x00000000}},	//   _འཇད_, --, --, --, 
   {{0x1d080063,0x00000000,0x00000000,0x00000000}},	//   њени_, --, --, --, 
   {{0x79500598,0xa3c80490,0x2bd0012c,0x2d9c0055}},	//   _däwl, लीच_, थीला, _dhve_, 
   {{0x68e402d0,0x39b000a2,0x80d001ad,0x00000000}},	//   _adhd, _ańsa_, डरवे, --, 
   {{0x1a642352,0xfde80108,0xd04803b9,0x00000000}},	//   شیدی_, _чьей_, dafə, --, 
   {{0xdca60ab7,0x01d4045e,0x5ca40352,0xdce000e2}},	//   _кали, _সমাদ, _килб, bilā, 
   {{0x7bc00a2e,0x613c0100,0x98a60ab8,0x18a406ed}},	//   _utnu, _bèlz, риве, равм, 
   {{0x7ae60ab9,0x3ebe0aba,0x6e240558,0x06e4040e}},	//   _udit, ncut_, _šibi, имск_, 
   {{0xa2d800cd,0x00000000,0x00000000,0x00000000}},	// [3bb00] मरन्, --, --, --, 
   {{0xa3e0033f,0x89d80375,0x00000000,0x00000000}},	//   _दिख_, _שחיי, --, --, 
   {{0xdd0000bc,0xd7c80214,0x98b800b8,0x00000000}},	//   _štěp, _جوجه_, _gopā_, --, 
   {{0x60c002d2,0x00000000,0x00000000,0x00000000}},	//   _aflm, --, --, --, 
   {{0xddc8033f,0xe87401d5,0x2b980165,0x98d817ee}},	//   rześ, _ننیگ, néca_, _बजाए, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2b980066,0x79500432,0xc2400139,0x00000000}},	//   kéca_, _säwl, снәк, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x20b80953,0xd1740137,0x6e04030c,0x3f740356}},	//   _быць_, _тыбы, _ۇستە, lăul_, 
   {{0xd0480213,0x00000000,0x00000000,0x00000000}},	//   yafə, --, --, --, 
   {{0xac940220,0x3f740356,0x61ece126,0x00000000}},	//   _қайш, năul_, šale, --, 
   {{0xee9468cf,0x6d9400db,0x7950013d,0xfbe40051}},	//   _اداک, làam, _täwl, _huế_, 
   {{0xc98464e1,0xcc2800d8,0x3d9001ec,0x00000000}},	//   руми, _ацид_, _диір, --, 
   {{0x4ae407d6,0xe7940103,0x3d2801ed,0x908c0023}},	//   _кўпа, مارک, _جتنی_, _ምዕባሌ_, 
   {{0xbb8416ac,0xfbd0011a,0x00000000,0x00000000}},	//   _ولوي, _ותק_, --, --, 
   {{0x6b8c0bd5,0xe6981e2d,0x8d8802d3,0x290400c5}},	// [3bb10] _ikag, уваш_, _ምእታው_, õlas_, 
   {{0xa2c8038e,0xe4d801f6,0xd0480213,0x290401ab}},	//   हुन्, اوات_, safə, òlad_, 
   {{0xb97c011a,0x00000000,0x00000000,0x00000000}},	//   _בנזי, --, --, --, 
   {{0x6b4c000f,0x6d94026c,0x00000000,0x00000000}},	//   _bûgi, dàam, --, --, 
   {{0x3ebc03ee,0x6b8c00ec,0x00000000,0x00000000}},	//   vcut_, _mkag, --, --, 
   {{0x26d80184,0x6b4c0086,0x6b8c022e,0x661e0abb}},	//   _heso_, _dûgi, _lkag, _issk, 
   {{0x26da0abc,0x6b8e0abd,0x83a801d5,0x00000000}},	//   _keso_, _okag, _атаб_, --, 
   {{0x26d88c42,0x6b8cf2d8,0xefb401d9,0x850000e5}},	//   _jeso_, _nkag, زیٖگ, _دوڑن, 
   {{0xdee4136b,0x3ebc2278,0x00000000,0x00000000}},	//   _ғоли, rcut_, --, --, 
   {{0x3ebe0abe,0x26d85c2e,0x25b002e2,0xdb140ca8}},	//   scut_, _leso_, _jizl_, _àbúr, 
   {{0x5ba96562,0x26d8257c,0x9ee800e3,0x3ebc0042}},	//   лком_, _oeso_, _مفضل_, pcut_, 
   {{0x1cd808ea,0x26da0abf,0x25b08060,0x00000000}},	//   _འཇམ_, _neso_, _lizl_, --, 
   {{0x5ea400bd,0xddc471fe,0x1d088a6b,0x9ff803d4}},	//   _গ্রে, _убли, _бели_, _আনিব_, 
   {{0x61fc014a,0x41cc02ab,0xd99830cd,0x6b8e0ac0}},	//   _äslu, सीएस, انست_, _ekag, 
   {{0x26da0ac1,0x661cb44a,0x6b8c0093,0x25b80395}},	//   _beso_, _assk, _fkag, _ausl_, 
   {{0xdca400fd,0x00000000,0x00000000,0x00000000}},	//   _каһи, --, --, --, 
   {{0x26d80066,0x9914109a,0xbda00023,0xfbc0009f}},	// [3bb20] _deso_, _льні, _ወዲቖም_, _ايڊٽ, 
   {{0x7f580113,0xd3b803de,0x00000000,0x00000000}},	//   hhuq, гуді_, --, --, 
   {{0x26d804c9,0x59bc05f9,0x7f580309,0x25b00010}},	//   _feso_, _एंडर, khuq, _dizl_, 
   {{0xf7540345,0x03a001f4,0x00000000,0x00000000}},	//   _بۆرج, пихо, --, --, 
   {{0x661c03b2,0x69c00115,0x3f740356,0x270000cc}},	//   _gssk, ĉleg, răul_, _লোকো_, 
   {{0x3ce400f3,0x26d801e2,0xfd0435e6,0x6d94026c}},	//   _ndnv_, _zeso_, _عج_, tàam, 
   {{0x26da0ac2,0x100812b7,0x5ea402f5,0x50d40137}},	//   _yeso_, اتتى_, _গ্লে, _ۇزار, 
   {{0x26d80005,0xc7b00375,0x661c017a,0x660c01ed}},	//   _xeso_, הבה_, _yssk, _önké, 
   {{0x50d4d349,0x03a0e096,0xd7040183,0xed8400d1}},	//   _هزار, _хито, _লোৱা_, оңди, 
   {{0x6b8cab69,0x0ae805d9,0x61ec0219,0x6f800150}},	//   _skag, گردي_, šalc, _ﺩﻓﻬﺎ_, 
   {{0x57600882,0x7f582798,0x0ca8023a,0xc4d008c3}},	//   ṣṭā_, bhuq, ытии_, הגת_, 
   {{0x0ae81e5a,0x7f58e689,0x00000000,0x00000000}},	//   دردي_, chuq, --, --, 
   {{0x26da0ac3,0x795000b0,0x0a6959e3,0x3a740139}},	//   _reso_, _käwh, урни_, зляр, 
   {{0x26da0ac4,0x3e680b43,0xddc80356,0x25b808a5}},	//   _seso_, _حجمی_, lzeş, _rusl_, 
   {{0x26da0ac5,0xc794027d,0x0df40092,0x35b40107}},	//   _peso_, مشرب, _ገለፀ_, ҷбур, 
   {{0x6b8e0ac6,0xdce00276,0x98b80356,0x00000000}},	//   _ukag, pilă, _popă_, --, 
   {{0xc9857104,0xf77112cd,0x248c005f,0x35b4fd06}},	// [3bb30] _гуни, راف_, _ņem_, збур, 
   {{0x26da0ac7,0x7e98011a,0x00000000,0x00000000}},	//   _weso_, רסמו, --, --, 
   {{0x26d969b1,0xf99406a9,0x2b98387a,0x7f58022e}},	//   _teso_, _מרץ_, néco_, yhuq, 
   {{0x26d801af,0x0df4001f,0x2b580036,0x661c0139}},	//   _ueso_, _ገለፁ_, ërch_, _tssk, 
   {{0x6d58066d,0x614461ff,0x661c030a,0xe0d801ec}},	//   _olva, жела, _ussk, авл_, 
   {{0x79500166,0x3fe0009e,0x00000000,0x00000000}},	//   _cäwh, _মহৌষ, --, --, 
   {{0x5edc015b,0x10a0130f,0x7f580051,0xd5840244}},	//   _যাবে, мишн, thuq, _بێله_, 
   {{0x6d5a0ac8,0x33580276,0xd34400f1,0x00000000}},	//   _alva, _ласэ_, _ویله_, --, 
   {{0x7f58009a,0xa2c80073,0x8bf000eb,0x00000000}},	//   rhuq, हुण्, _জনগন_, --, 
   {{0x80d011ba,0x79500139,0x7f58b70b,0x6e240327}},	//   _সাক্, _gäwh, shuq, _ġibt, 
   {{0x7f58014b,0xafc40150,0xda880023,0x00000000}},	//   phuq, _فيلى, _መንጎና_, --, 
   {{0x6d5a0ac9,0x7f580921,0x3ce401c7,0x8af406be}},	//   _elva, qhuq, _wdnv_, _şərd, 
   {{0x98b80064,0x00000000,0x00000000,0x00000000}},	//   _lopą_, --, --, --, 
   {{0x0df4001f,0xceb0010f,0x0a68010a,0x00000000}},	//   _ገለፃ_, _חיד_, ăрни_, --, 
   {{0xdd980100,0xa65c0092,0x00000000,0x00000000}},	//   ntňm_, _ለመወሰ, --, --, 
   {{0x5b3400a8,0x2c440023,0x00000000,0x00000000}},	//   _фэку, ሕግጋዝ, --, --, 
   {{0xca740220,0x6d583602,0x00000000,0x00000000}},	// [3bb40] _дәрі_, _ylva, --, --, 
   {{0x3a21a3dc,0xf9640133,0x9494005b,0x1868014b}},	//   _isip_, _رنجێ, ошеч, _ваои_, 
   {{0x4cdc015b,0x06a80154,0x98a41149,0xdec81954}},	//   _মামু, গুলি, _фине, በላን_, 
   {{0x95c405d9,0x00000000,0x00000000,0x00000000}},	//   _ويجه, --, --, --, 
   {{0x795000b0,0xca340131,0x00000000,0x00000000}},	//   _päwh, ﯖﻐﺎ_, --, --, 
   {{0xea980882,0xc29402d5,0x8678011a,0x4fc401f0}},	//   _haṃ_, цкіх_, _כרכו, осиа, 
   {{0xea9800dc,0x1c180037,0x840000f3,0x24500116}},	//   _kaṃ_, _फैलल_, _опрж, _كۆكس, 
   {{0x3f8c05b1,0x61ee0aca,0x27e47448,0x3a2007f5}},	//   _ckgu_, šala, álni_, _osip_, 
   {{0x2b980098,0xea98002b,0x553c0023,0x00000000}},	//   wéco_, _maṃ_, _ተማሕጺ, --, 
   {{0x0ca81f91,0x8d740e76,0xcd4801c0,0x7950013d}},	//   итни_, تاعا, рчид_, _fäwi, 
   {{0x3a20020b,0xab940212,0x00000000,0x00000000}},	//   _asip_, зині, --, --, 
   {{0xfbcc26f0,0xea98002b,0xefc80092,0x00000000}},	//   کتی_, _naṃ_, በኛው_, --, 
   {{0xda201152,0x60d800e4,0x00000000,0x00000000}},	//   मिगत_, _ñamõ, --, --, 
   {{0x61fc143a,0xac1800f3,0x00000000,0x00000000}},	//   _åsle, _гоку_, --, --, 
   {{0x2d8e0acb,0xa8984ea8,0xd2f00408,0x1d88009f}},	//   mode_, скву_, _гiир, _ائني_, 
   {{0x27ec7e96,0x2d8e0acc,0x6ad40183,0xa65c001f}},	//   čen_, lode_, _থাকো, _ለመውሰ, 
   {{0xe81c007d,0xea98002b,0x9f400066,0xc9840107}},	// [3bb50] _पनवा_, _daṃ_, éhé_, _муои, 
   {{0x2d8e0acd,0x2b4801fb,0xe2980032,0xabb400c7}},	//   node_, _hoac_, ҙал_, _ьақә, 
   {{0x29020ace,0xf77001ed,0xe89499fa,0xe3140114}},	//   _icha_, راہ_, _хань, змењ, 
   {{0x2d8cef6b,0xe2f80220,0x79520acf,0x2900005a}},	//   hode_, седі_, _räwi, _hcha_, 
   {{0x97000075,0x3324031c,0x2900022e,0x00000000}},	//   _سېلى, _damx_, _kcha_, --, 
   {{0x2d8e0ad0,0xe8b837d0,0xb1441cd0,0x55b8011a}},	//   jode_, _आलोच, мніл, _למשו, 
   {{0xea980882,0xd12c035d,0x290001c8,0x3494036b}},	//   _yaṃ_, طمي_, _mcha_, _жарр, 
   {{0xd00c501f,0x00000000,0x00000000,0x00000000}},	//   الي_, --, --, --, 
   {{0x0dc46c31,0x29020ad1,0x236c001f,0x5edc015b}},	//   плый_, _ocha_, _imej_, _যাদে, 
   {{0x29020ad2,0x2b480472,0x3e800064,0x00000000}},	//   _ncha_, _aoac_, _rūtą_, --, 
   {{0x60994537,0x00000000,0x00000000,0x00000000}},	//   _اناس_, --, --, --, 
   {{0x29020ad3,0x2b4800db,0x9f0400f2,0x00000000}},	//   _acha_, _coac_, _روتو, --, 
   {{0xea9800b8,0x00000000,0x00000000,0x00000000}},	//   _raṃ_, --, --, --, 
   {{0xea9800cd,0x3a220ad4,0xf064030d,0x00000000}},	//   _saṃ_, _vsip_, _икĕп, --, 
   {{0x2900f6a7,0x2124003e,0x60300241,0xb4e800dc}},	//   _dcha_, _malh_, _ḿmo, _ययौ_, 
   {{0x29020ad5,0x3a200109,0xda5800c0,0x61f8010e}},	//   _echa_, _tsip_, _грош_, kuwl, 
   {{0xded40020,0x290001ab,0xacf402dd,0x166402e8}},	// [3bb60] _የጤና_, _fcha_, _ءسۇت, чвам, 
   {{0x33240211,0x00000000,0x00000000,0x00000000}},	//   _samx_, --, --, --, 
   {{0xea980a28,0xe9a8765c,0xd25004fb,0xc68c01d9}},	//   _taṃ_, _بدين_, کنش_, نِہ_, 
   {{0x2d8c0b91,0x09200eac,0xc0c40023,0x6d940248}},	//   zode_, মাণু_, _ጽላለ_, bàaw, 
   {{0x61ec151c,0x20048b17,0x2124010e,0x03a001c6}},	//   šaln, _aqli_, _balh_, хицо, 
   {{0x813408c9,0x00000000,0x00000000,0x00000000}},	//   كسىز_, --, --, --, 
   {{0x2d8c0bb8,0x21240165,0x493c02d3,0x4f68034b}},	//   vode_, _dalh_, _ኣገባብ, йшим_, 
   {{0x4cdc045e,0x7ee00075,0x6448f725,0xdce00327}},	//   _মাধু, ىكىن, çmiş, volġ, 
   {{0x2d8e0ad6,0xefb001d5,0x00000000,0x00000000}},	//   tode_, _ییتگ, --, --, 
   {{0x2cba0ad7,0xa2440014,0x00000000,0x00000000}},	//   ørd_, _تیٖل_, --, --, 
   {{0xac980345,0xc0f80023,0x00000000,0x00000000}},	//   تندا_, ዊኦም_, --, --, 
   {{0x29001570,0x2d8c6eee,0x21240165,0xeab80137}},	//   _scha_, sode_, _zalh_, өйү_, 
   {{0x2b9804c4,0x2d8c7d9b,0xbdc00150,0x9b640137}},	//   léck_, pode_, _كەيۋ, بەيم_, 
   {{0xf6e8031c,0xdce000c0,0x00000000,0x00000000}},	//   _འཇུང, kilę, --, --, 
   {{0xfc2c31ed,0x2b980036,0x7d20bd5e,0x00000000}},	//   _محي_, néck_, _سفين, --, 
   {{0x6af401a9,0x00000000,0x00000000,0x00000000}},	//   _ўзпф, --, --, --, 
   {{0x2900fa6d,0x2b9804e6,0xca7002f2,0x00000000}},	// [3bb70] _tcha_, héck_, _سندک, --, 
   {{0x29020ad8,0x69cc00ec,0x256c03e3,0x236c00ef}},	//   _ucha_, _itae, _kölə_, _smej_, 
   {{0x2124067c,0xea9800cd,0x00000000,0x00000000}},	//   _ralh_, _daṅ_, --, --, 
   {{0x27e401f1,0x21240066,0xfbd005d0,0x00000000}},	//   álnu_, _salh_, תתף_, --, 
   {{0xc0c402d3,0x0574742b,0xd2f00408,0x00000000}},	//   _ጽላል_, _فاسد, _гiор, --, 
   {{0xd24c04a9,0x69cc01f7,0xea98002b,0x0584010a}},	//   شنى_, _mtae, _gaṅ_, _хумм, 
   {{0x0a100154,0x00000000,0x00000000,0x00000000}},	//   িটিং_, --, --, --, 
   {{0x44210a33,0x69cc444e,0x212405c7,0xf83802e4}},	//   _isj_, _otae, _walh_, לנות_, 
   {{0x2124067c,0x5cf40a89,0x2fc001e4,0xa19400db}},	//   _talh_, мяну, ĉiga_, _жаач, 
   {{0x61ea0ad9,0x9e0428b6,0x2b980221,0xa2c984cd}},	//   _ivel, пчүл, léch_, हुर्, 
   {{0x69ce0ada,0x61e91818,0x0d800139,0x00000000}},	//   _atae, _hvel, тлэн, --, 
   {{0x61e81a82,0x44220adb,0x00000000,0x00000000}},	//   _kvel, _msj_, --, --, 
   {{0x4a404316,0x00000000,0x00000000,0x00000000}},	//   вняв, --, --, --, 
   {{0x61e80084,0xe9800046,0x98a60adc,0x00000000}},	//   _mvel, лқын, диге, --, 
   {{0x69ce0add,0x46c800b4,0x256c03b9,0x61e801f4}},	//   _etae, _ụtọ_, _gölə_, _lvel, 
   {{0x61ea0ade,0x2b04a5cd,0xfed8015b,0xd70802d5}},	//   _ovel, _वायु_, _ধাঁধ, ўнае_, 
   {{0x25f40034,0x5984024c,0x00000000,0x00000000}},	// [3bb80] एंगी_, _олиб, --, --, 
   {{0x442005b1,0x7f480472,0x00000000,0x00000000}},	//   _bsj_, _logq, --, --, 
   {{0x61ea0adf,0x7f4800f1,0x442004e6,0x61edf8ec}},	//   _avel, _oogq, _csj_, šall, 
   {{0x61e81aa1,0x7f482d2f,0x7c200175,0xf6e8031c}},	//   _bvel, _nogq, _msnr, _འཇིང, 
   {{0x61e8009b,0x4cdc015b,0x51860ae0,0x69cc01a9}},	//   _cvel, _মাসু, мука, _xtae, 
   {{0x61ea0ae1,0xe2a87c25,0x2b9804e6,0x4420002f}},	//   _dvel, سانن_, téck_, _fsj_, 
   {{0x7f48009a,0x8eb00075,0x61e86460,0xcfa45211}},	//   _bogq, ھەتت, _evel, мшии, 
   {{0xb90049a6,0x2b9804c4,0x61f001bf,0x8eb01884}},	//   _སབ_, réck_, åklæ, پەتت, 
   {{0x7d00004e,0x8d841586,0x44200076,0xb81400cc}},	//   _bcns, дунд, _zsj_, াটিত_, 
   {{0x61fc143a,0x7ec001e1,0x00000000,0x00000000}},	//   _åsla, _pípó, --, --, 
   {{0x69ce0ae2,0xdb14033b,0x2b99c88d,0xc0e13092}},	//   _stae, _kiyè, léci_, _рохк, 
   {{0x61ea0ae3,0x7d00035a,0x61400124,0x00000000}},	//   _yvel, _ecns, _аҵәа, --, 
   {{0xdb1402e2,0xe7e0000d,0x00000000,0x00000000}},	//   _miyè, गीना_, --, --, 
   {{0x7f4801e2,0xf1b80327,0x00000000,0x00000000}},	//   _zogq, _jiġ_, --, --, 
   {{0xf6cc01f2,0x7f4800f1,0xd9ec00c5,0xac580818}},	//   _ọpịp, _yogq, _जिअत_, _хайф_, 
   {{0x44200e02,0x0ba8568c,0x00000000,0x00000000}},	//   _rsj_, _باتى_, --, --, 
   {{0xf8d00882,0x69cc00ec,0x93f80de2,0xeaac0183}},	// [3bb90] _त्वय, _utae, _w胃ll, _ক্ৰম, 
   {{0xc7c4119e,0x44220ae4,0x00000000,0x00000000}},	//   _осми, _psj_, --, --, 
   {{0x61e9e78e,0xdb1404fb,0xa2f40902,0x6e200042}},	//   _svel, _biyè, епеч, hwmb, 
   {{0xdb14002e,0x61e80165,0xe9441968,0x00000000}},	//   _riyë, _pvel, _آرکی, --, 
   {{0x442096a0,0x2b9804e6,0x1fa800ee,0x00000000}},	//   _wsj_, réch_, үкли_, --, 
   {{0xa0a46b28,0x44200789,0x7f480472,0xf2c53bff}},	//   налд, _tsj_, _sogq, нсән, 
   {{0x1fb43aeb,0xd00c1e95,0xdb14007f,0x75680014}},	//   нсир, ملو_, _fiyè, _تیلہ_, 
   {{0xa2941fe2,0x26c8be70,0x9f043fb8,0x00000000}},	//   _забі, ncao_, روخو, --, 
   {{0x61ea0ae5,0x26c800d8,0x00000000,0x00000000}},	//   _uvel, icao_, --, --, 
   {{0xe3c800e8,0x7f48009a,0x1c4402bf,0x7c2001c4}},	//   _gañé_, _wogq, еном, _psnr, 
   {{0x9724010b,0x00000000,0x00000000,0x00000000}},	//   _äşgä, --, --, --, 
   {{0x7950013d,0x00000000,0x00000000,0x00000000}},	//   _näwr, --, --, --, 
   {{0x4cdc0154,0x00000000,0x00000000,0x00000000}},	//   _মারু, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x160000c5,0xc60800fe,0x00000000,0x00000000}},	//   _लमहर_, ৰিফা_, --, --, 
   {{0xf8d00882,0x39588bbb,0x95c801b9,0x98a40107}},	//   _त्रय, skrs_, злаб_, диҳе, 
   {{0x61ec56c0,0xdb140100,0x682001f3,0x00000000}},	// [3bba0] šalj, _riyè, _ትውልድ, --, 
   {{0x4aa49033,0x26c800d8,0xa2b402db,0x00000000}},	//   _якын_, acao_, ेशन्, --, 
   {{0xdb140248,0xe3c8002e,0x799c0042,0x00000000}},	//   _aiyé, _rañé_, mlrw, --, 
   {{0xdb140066,0x26c80798,0x91e40120,0x00000000}},	//   _biyé, ccao_, еоде, --, 
   {{0xb9fc0201,0xf1b801e0,0xf36401d5,0x799c03cb}},	//   _ሆኖ_, дҡа_, _یئری, olrw, 
   {{0x7764036e,0x00000000,0x00000000,0x00000000}},	//   lhix, --, --, --, 
   {{0x814007a7,0xb4dcb577,0x76440009,0x2fc000df}},	//   انىن, ठरी_, lxiy, ĉigo_, 
   {{0x6b8401e4,0x91600051,0xa2c001af,0xc1c80220}},	//   _ĉigo, _bự_, _кәшк, _ﻗﻮﺩﺍ, 
   {{0xa1980150,0xdce00139,0x00000000,0x00000000}},	//   _ﺘﻬﺩﻑ_, ellı, --, --, 
   {{0xceb40032,0x9160004d,0x62640132,0x00000000}},	//   мәҙ_, _dự_, _شاقق, --, 
   {{0x3f100046,0x776402b9,0x8fa51e06,0x0574011a}},	//   _әдіс, khix, _заже, תגים_, 
   {{0xe9780092,0xdb0801e1,0x00000000,0x00000000}},	//   _አቅራቢ_, _ènìk, --, --, 
   {{0xc33006a9,0x994400d0,0xdce003b9,0x00000000}},	//   אור_, _kôň_, allı, --, 
   {{0xe794c734,0xac9400c7,0x494401c6,0x7644013d}},	//   چارک, _иалш, хэмб, dxiy, 
   {{0x6d480097,0xb880001f,0xe894034b,0xe794f237}},	//   mjda, _የትግል_, тавь, نارک, 
   {{0xf77066a3,0x7c9825f9,0x2904003d,0x6d4800f3}},	//   ماق_, _משוג, żla_, ljda, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3bbb0] --, --, --, --, 
   {{0x6b9e0ae6,0x61ec09a8,0x6d480097,0xc7b8034b}},	//   llsg, šalk, njda, _нём_, 
   {{0x26c801fa,0x67d409a5,0x76440009,0x7950013d}},	//   pcao_, _шону, axiy, _täwr, 
   {{0x77660ae7,0x276801d5,0x181801d3,0xc60803d4}},	//   chix, _آشدی_, _کریک_, ৰিবা_, 
   {{0x6b8401e4,0x49280023,0x673c0267,0x672cc5a6}},	//   _ĉigl, _ብምትእ, _insj, mdaj, 
   {{0x660e0ae8,0x672e0ae9,0x1168141b,0x0f300ee8}},	//   mtak, ldaj, ولنی_, یکند, 
   {{0x660c4098,0x916001fb,0xf4840902,0x00000000}},	//   ltak, _sự_, _бутн, --, 
   {{0x672e0aea,0x660e0aeb,0x349400c7,0x64460aec}},	//   ndaj, otak, _саср, mxhi, 
   {{0x63aa0aed,0x338405f5,0xcf400830,0x64440200}},	//   _ihen, _сурв, рный, lxhi, 
   {{0xb2749fb7,0x660e0aee,0xa2d84ea9,0x6b9c01a4}},	//   _слуш, itak, मरक्, elsg, 
   {{0x63aa0aef,0x660e0af0,0x672c0497,0x64460af1}},	//   _khen, htak, kdaj, nxhi, 
   {{0x63a80784,0x916001fb,0x672ccc23,0xbf680338}},	//   _jhen, _tự_, jdaj, _عصام_, 
   {{0x660e0af2,0x77640564,0x63aa0af3,0x1d080640}},	//   jtak, vhix, _mhen, _жели_, 
   {{0x660c7a1e,0x673c031c,0x63a80076,0x7f580200}},	//   dtak, _ansj, _lhen, lkuq, 
   {{0x7764021a,0x660c0323,0x63a971c9,0x59bc00e1}},	//   thix, etak, _ohen, _एंकर, 
   {{0x660e0af4,0x63aa0af5,0x7f5802d1,0x76442d00}},	//   ftak, _nhen, nkuq, txiy, 
   {{0x660e0af6,0x7ae400a9,0x7bc20af7,0x9a880014}},	// [3bbc0] gtak, _ieit, _hunu, _زندٕ_, 
   {{0x7bc20af8,0x63aa0af9,0x7ae4bf06,0x673c4f3b}},	//   _kunu, _ahen, _heit, _ensj, 
   {{0x660e0afa,0x7bc20afb,0x63aa0afc,0x77640bc9}},	//   atak, _junu, _bhen, phix, 
   {{0x63aa0afd,0x7ae60afe,0x660e0aff,0xeae000cc}},	//   _chen, _jeit, btak, _ভাৱম, 
   {{0x7ae60b00,0x63aa0b01,0x660e0b02,0x7bc20b03}},	//   _meit, _dhen, ctak, _lunu, 
   {{0x63a806e4,0x7f58009a,0xae1c0307,0x00000000}},	//   _ehen, ekuq, _बैगन_, --, 
   {{0x7bc20b04,0xfbc49a12,0x63a801ab,0x673c045f}},	//   _nunu, _خت_, _fhen, _ynsj, 
   {{0x53a4270f,0x63aa0b05,0x7ae60b06,0x00000000}},	//   _рабб, _ghen, _neit, --, 
   {{0x7bc00607,0x9f400118,0x00000000,0x00000000}},	//   _aunu, éhá_, --, --, 
   {{0x7bc20b07,0x63aa0b08,0x6d494043,0xebd8036b}},	//   _bunu, _zhen, ujda, ндош_, 
   {{0x7ae491e1,0x7bc20b09,0x660e0b0a,0x63a80254}},	//   _beit, _cunu, ztak, _yhen, 
   {{0x7ae60b0b,0x660e0b0c,0x7bc20b0d,0xbf105155}},	//   _ceit, ytak, _dunu, _نومب, 
   {{0x7ae60b0e,0x7bc174ab,0x660c1571,0x672d5b35}},	//   _deit, _eunu, xtak, vdaj, 
   {{0xbea15d25,0x7bc20b0f,0x660e0b10,0xab740131}},	//   _тачк, _funu, vtak, _әгиш, 
   {{0x7ae60b11,0x7bc20b12,0xc06c00b8,0x0ba60b13}},	//   _feit, _gunu, _bāṇa_, _ишим, 
   {{0x61ed79ed,0x00000000,0x00000000,0x00000000}},	//   šali, --, --, --, 
   {{0x63aa0b14,0x672e0b15,0x7bc00c09,0xba760b16}},	// [3bbd0] _rhen, rdaj, _zunu, _پايت, 
   {{0x63aa0b17,0x7ae4d0fe,0x7bc029ef,0x672c014f}},	//   _shen, _zeit, _yunu, sdaj, 
   {{0x7ae4dba4,0x660e0b18,0x63aa0b19,0x92b00131}},	//   _yeit, stak, _phen, ەڭلا, 
   {{0x7ae40f71,0xe1f02264,0x4ae02f2e,0x63a80113}},	//   _xeit, مست_, परिव, _qhen, 
   {{0x660e0b1a,0x63a80084,0x21744c6b,0x6444036e}},	//   qtak, _vhen, лукр, sxhi, 
   {{0x68e40327,0x63aa0b1b,0xd048013f,0xdd980419}},	//   _jehd, _when, yafɔ, kuňa_, 
   {{0x68e60b1c,0x7f580d04,0x64400024,0x63aa0b1d}},	//   _mehd, tkuq, _šlif, _then, 
   {{0x7bc20b1e,0x63aa0b1f,0x68e4049b,0xa2b407b7}},	//   _runu, _uhen, _lehd, ेशद्, 
   {{0x7bc20b20,0xb0640139,0xc0c8001f,0x1e9400c7}},	//   _sunu, _ayäğ, ሠራር_, ыркр, 
   {{0x7ae60b21,0x7bc20b22,0x14a80490,0xc0a800db}},	//   _seit, _punu, _करमण, _قاال_, 
   {{0x7ae60b23,0x7bc20b24,0x3cf00d2e,0x64e00210}},	//   _peit, _qunu, _आयीं_, _फ़ैश, 
   {{0x7bc20b25,0x70580107,0x1e241291,0x00000000}},	//   _vunu, _шахр_, _مفصّ, --, 
   {{0x7ae60b26,0x68e55b35,0x7bc000e8,0x06c4005e}},	//   _veit, _behd, _wunu, _ﯨﺴﺘﻪ, 
   {{0x7ae60b27,0x7bc13677,0x1d0a0b28,0x68e4020c}},	//   _weit, _tunu, _чеки_, _cehd, 
   {{0x7ae60b29,0x7bc0022f,0x9b4409a6,0x1868014b}},	//   _teit, _uunu, _منثو, хави_, 
   {{0x8ca000db,0x3f9c01f4,0x8c18011a,0x00000000}},	//   _دەپو, nluu_, _נופי, --, 
   {{0x68e40086,0xc79453f0,0x07a0a678,0x59bc0412}},	// [3bbe0] _fehd, اپقا_, сатн, _एंटर, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf8a8038e,0x00000000,0x00000000,0x00000000}},	//   _गरिय, --, --, --, 
   {{0x60c007c5,0x779404d3,0x00000000,0x00000000}},	//   _aglm, _ئیرا, --, --, 
   {{0x603001e1,0x50c8008e,0xd92c0240,0xcb1000d9}},	//   _ḿmu, ныйм_, _ብምድዋ, מלא_, 
   {{0x902800c7,0x31344294,0x3f9c0270,0xf8b80490}},	//   ециа_, рекр, eluu_, _आणाय, 
   {{0x80a000ec,0x06e400eb,0x00000000,0x00000000}},	//   ٽمين, _ফাতি, --, --, 
   {{0x3f610b59,0x3f9c01e4,0xadf41d0f,0x601802d2}},	//   йтыб, gluu_, апиш, _súmö, 
   {{0x835000cf,0x3e540210,0x00000000,0x00000000}},	//   _اپقا, jętą_, --, --, 
   {{0x98b8007f,0x3f9c198f,0x2d980af9,0xe7f800bc}},	//   _anpč_, aluu_, ôre_, ौंमा_, 
   {{0x2cb8049f,0x64400ffb,0x3f9c0254,0x20c801f7}},	//   ärd_, _àlit, bluu_, _شبلي_, 
   {{0x0ba97f3c,0x68e4011f,0xab9400d4,0xcb440022}},	//   عادى_, _sehd, римі, ухои, 
   {{0x2dc80220,0x49700bd6,0x7f38010f,0xff78010f}},	//   _شاشۋ_, йһис, _רעדו, _אטאמ, 
   {{0x68e4014f,0x85001bf9,0x64400174,0x4cdc00cc}},	//   _qehd, _लाइट_, _álig, _মাকু, 
   {{0x68e5512b,0x3cf42088,0x00000000,0x00000000}},	//   _vehd, _صعود_, --, --, 
   {{0x68e4014b,0x940c0073,0x88ac00ef,0x00000000}},	//   _wehd, _सहजच_, _ķēķi, --, 
   {{0x68e60b2a,0x00000000,0x00000000,0x00000000}},	// [3bbf0] _tehd, --, --, --, 
   {{0x04643b5f,0xa2b4102f,0x2ee00825,0x00000000}},	//   лтем, ेशस्, नरुत, --, 
   {{0xa2d407f2,0x8248e218,0x98e401af,0x00000000}},	//   ليات, کشاف_, _тсыһ, --, 
   {{0xe2f80046,0x64400327,0xe75800d4,0x00000000}},	//   теді_, _ġlid, _римі_, --, 
   {{0x81c400da,0x05d80034,0x3a38008f,0xe7e000ab}},	//   klēš, मीखब, ָרום_, गीरा_, 
   {{0x661c0857,0x3cf00210,0x00000000,0x00000000}},	//   _ipsk, _आयें_, --, --, 
   {{0xf958011a,0xa0a401a9,0xdd0000d7,0x00000000}},	//   רסות_, шакд, íučk, --, 
   {{0x3f9c0093,0x2ba407f7,0x63060b2b,0x20100139}},	//   uluu_, _गीला, _خورل, _äzim_, 
   {{0x3f9c0140,0x2e5801c0,0xaf4800db,0x208c0240}},	//   rluu_, гшээ_, اشىل_, _ኣዳምጹ_, 
   {{0x64415368,0x3f9c01f4,0x00000000,0x00000000}},	//   _àlis, sluu_, --, --, 
   {{0xdb840124,0x9b74027d,0x85001b87,0x5ca41606}},	//   игои, لاحص, _लाईट_, ринб, 
   {{0x661e0b2c,0x61ec0153,0xd2f0074d,0xdb1401e1}},	//   _opsk, šalu, _гiер, _tiyí, 
   {{0x81c400ef,0x00000000,0x00000000,0x00000000}},	//   blēš, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x661c5914,0xe7e004fa,0xa8640032,0x977400d8}},	//   _apsk, गीला_, берҙ, аѓај, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
  
   {{0x9b4400f1,0x2fc000df,0x06c4009d,0x00000000}},	// [3bc00] _منګو, ĉigi_, ргуй_, --, 
   {{0x589400d8,0xb35802f2,0x00000000,0x00000000}},	//   _вшму, گیرا_, --, --, 
   {{0xa5d804a9,0x18681cc9,0x142556aa,0x00000000}},	//   نبەر_, _рани_, рдем, --, 
   {{0xdb1401e1,0xc42800d1,0x00000000,0x00000000}},	//   _jiyà, ختكە_, --, --, 
   {{0x64400003,0x96b80063,0x00000000,0x00000000}},	//   _ġlie, _јуну_, --, --, 
   {{0x3ce405c7,0xd018023b,0x813406ba,0xdb040254}},	//   _nenv_, вфи_, لسىز_, lmkä, 
   {{0xcf8800d8,0xfc247286,0xa5040006,0x00000000}},	//   ксид_, _بح_, _уяўл, --, 
   {{0x03d40302,0xc05402dd,0x5274004e,0x00000000}},	//   _כולם_, ріш_, _кузу, --, 
   {{0x60cc0882,0x64400129,0xe9f80051,0x98b800de}},	//   śama, _àlir, _dzẻ_, _kopē_, 
   {{0x1104004b,0xd07800d8,0x8ff8014b,0x00000000}},	//   _خبرپ, _исеч_, _ахду_, --, 
   {{0x30a40014,0xabb8010b,0xac940150,0x00000000}},	//   _الاہ, лгоф_, санш, --, 
   {{0x64400077,0x20540137,0x3d1421f2,0xdce00171}},	//   _álie, _утур, ब्बे_, filē, 
   {{0xfba805f5,0x6dd41063,0xbea00153,0x0eb80153}},	//   ртэй_, _اقتض, _дацк, _ружы_, 
   {{0x3ce4030a,0x7cd80055,0x00000000,0x00000000}},	//   _genv_, _pārũ, --, --, 
   {{0x67d43cb4,0x00000000,0x00000000,0x00000000}},	//   собу, --, --, --, 
   {{0xdb140100,0x67d42f0d,0x661c03b2,0xc6a46b2a}},	//   _giyà, _қому, _ppsk, арзи, 
   {{0x79f40022,0x39a401d9,0xf99000ec,0xda6400ec}},	// [3bc10] _дзых, _ژیُہ, _ڪبي_, _هاٿي, 
   {{0x61fc33b8,0xb0b8012d,0x97240139,0x00000000}},	//   _åsli, ेखाग, _äşnä, --, 
   {{0x317c7a78,0xba7547c8,0xf990007b,0x34942377}},	//   divz_, _هایت, _تبي_, оафр, 
   {{0x33840801,0x00000000,0x00000000,0x00000000}},	//   оучв, --, --, --, 
   {{0x661c2296,0xa15a0b2d,0xf1c824ae,0xdb1401e1}},	//   _upsk, ладу_, لونى_, _jiyá, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2d9c01e4,0x33580276,0x339400c0,0x00000000}},	//   _akve_, _касэ_, _дасё, --, 
   {{0x4cdc03d4,0x3358084c,0x00000000,0x00000000}},	//   _মাজু, _татэ_, --, --, 
   {{0x27f00472,0x00000000,0x00000000,0x00000000}},	//   kszn_, --, --, --, 
   {{0x9b44e25a,0xdc740108,0x00000000,0x00000000}},	//   مندو, сыпь, --, --, 
   {{0xdca41955,0x186808ca,0xd378010f,0x00000000}},	//   _қайи, қаби_, ָרשט, --, 
   {{0xdd94040e,0x00000000,0x00000000,0x00000000}},	//   _лады, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x98a44f6d,0x4cdc00cc,0x00000000,0x00000000}},	//   сиве, _মাচু, --, --, 
   {{0xe07802d3,0x96b800db,0xd6287938,0x00000000}},	//   _ክንድዚ_, гузу_, лобе_, --, 
   {{0x70a400bc,0x41a407b7,0x00000000,0x00000000}},	// [3bc20] _ओर्ल, गतास, --, --, 
   {{0xca34011a,0x91c400bc,0x00000000,0x00000000}},	//   _פניה_, ादसै, --, --, 
   {{0xb6c40bd6,0x98147aaf,0xd788216b,0x00000000}},	//   _минһ, _ابخا, _مندو_, --, 
   {{0x644000f3,0x2bbc00cd,0xe5540023,0x00000000}},	//   _šlic, ोदया, _ዘየፍቅ, --, 
   {{0x2904655d,0xe57001d3,0xd1f40023,0x00000000}},	//   ólag_, سطے_, ለፈት_, --, 
   {{0xefcc0020,0xbdfc045e,0x00000000,0x00000000}},	//   _ባለው_, ্বাদ_, --, --, 
   {{0xcf9806ed,0xd4682377,0xb3581291,0x00000000}},	//   лји_, _сиве_, _پیشا_, --, 
   {{0x2d9c0ac5,0x7ff0007b,0xfa540023,0x2dd4022e}},	//   _skve_, أسوا, _ዝጸንሑ, ожир, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd17401af,0x00000000,0x00000000,0x00000000}},	//   _уыбы, --, --, --, 
   {{0x3a2095ca,0x459800c8,0x7950013d,0x00000000}},	//   _apip_, רסיע, _fäwz, --, 
   {{0x0c840046,0x6a140124,0xdcb0107b,0x00000000}},	//   _қылм, омму, بىپ_, --, 
   {{0xbc653bdb,0x3a200589,0x00000000,0x00000000}},	//   لمین_, _cpip_, --, --, 
   {{0xfbcc5311,0xc985a40b,0x2fc001e4,0x00000000}},	//   بتی_, суми, ĉigu_, --, 
   {{0xfbcc17c6,0x3a2000a2,0x37c400f0,0xe0780092}},	//   _संयम, _epip_, зљуб, _እንደሚ_, 
   {{0x28d80412,0x443c04a7,0xdb140548,0x97240166}},	//   _ब्रि, _ču_, _tiyá, _äşlä, 
   {{0x443c04fe,0x29040013,0x6b8e0b2e,0xb4e40406}},	// [3bc30] _ōu_, òlas_, _ijag, गरूप_, 
   {{0x69de0b2f,0x6aae0b30,0xc6a40124,0x00000000}},	//   mpse, _izaf, арҷи, --, 
   {{0x24780092,0x00000000,0x00000000,0x00000000}},	//   _በጸሎት_, --, --, --, 
   {{0xc2e81f7a,0x6b8c0083,0x69dc0bd7,0xe8b401f9}},	//   اعام_, _jjag, opse, ंधीच, 
   {{0xe29814b7,0x79500139,0x00000000,0x00000000}},	//   јал_, _räwz, --, --, 
   {{0x6b8c0e3c,0x69dc01c7,0xc32c01d9,0x5fd4033a}},	//   _ljag, ipse, بٕچ_, оциф, 
   {{0xd00d308c,0x6b8e0b31,0x2458009d,0x00000000}},	//   نلو_, _ojag, _тавь_, --, 
   {{0x27e401a2,0x6b8e0b32,0x6aac005a,0x811427dc}},	//   álny_, _njag, _ozaf, _گذرا, 
   {{0x13dc2baf,0x6aac0223,0x69dc01f5,0x00000000}},	//   _ডিয়, _nzaf, jpse, --, 
   {{0x6b8e0b33,0x3d00000d,0xf3200092,0x00000000}},	//   _ajag, ललें_, _ሰምተና, --, 
   {{0x3a220b34,0x6aae0b35,0x1b4a0b36,0xe2980184}},	//   _spip_, _azaf, азни_, _саҡ_, 
   {{0xe519351b,0xdce89d5d,0x06dc0154,0x00000000}},	//   न्ति_, ının, বৃতি, --, 
   {{0x09e00364,0x6b8c07b0,0x6e9400c7,0x5398011a}},	//   моян, _djag, _еицу, שירו, 
   {{0x6aae0b37,0x6b8c1418,0x61fd715c,0x3a20031c}},	//   _dzaf, _ejag, _åslu, _vpip_, 
   {{0x6aac4005,0x6b8c0334,0xd05803b9,0x69dc0254}},	//   _ezaf, _fjag, _betə, apse, 
   {{0x8ea40228,0xa3cc00ab,0x290401ab,0xc4bc00cc}},	//   _الۇۇ, रदन_, òlar_, ইডাঙ, 
   {{0xd5740124,0xc4f801ef,0x00000000,0x00000000}},	// [3bc40] оужь, _čůrá, --, --, 
   {{0x7bc400af,0xc600023a,0x644013aa,0x00000000}},	//   _hiiu, ьзуй, _šlia, --, 
   {{0x799c4d11,0xe5180864,0x00000000,0x00000000}},	//   morw, न्धि_, --, --, 
   {{0x799c83fb,0x00000000,0x00000000,0x00000000}},	//   lorw, --, --, --, 
   {{0x42c40b65,0x9148368e,0x27ec0989,0xd8b803e6}},	//   әгән_, ичка_, ćene_, _حدکا_, 
   {{0x799e0b38,0xd5b001ed,0x7764005a,0x7ee000d1}},	//   norw, _آفس_, lkix, ۈكىن, 
   {{0xa0205fea,0xd0580213,0x61ec0024,0x4f6a0b39}},	//   _çöld, _yetə, šalp, ишим_, 
   {{0xc3206d2b,0x799e0b3a,0x7764031c,0x11d8007b}},	//   _омск, horw, nkix, _نورة_, 
   {{0xc7b06da4,0x799c633d,0x7444001f,0xbd00002b}},	//   ובה_, korw, _የሚጠብ, _āũra, 
   {{0x7bc40418,0x0678008d,0x799c00ca,0x6b8c03b2}},	//   _aiiu, ינפל, jorw, _sjag, 
   {{0x4f660b3b,0x6aac5ff8,0x7bc55275,0x6b8c025c}},	//   _واصف, _szaf, _biiu, _pjag, 
   {{0xdb14ba3d,0x9528025c,0xdce00153,0x69dc045a}},	//   _niyä, _ཤིའི_, kilė, tpse, 
   {{0x7bc40381,0x6b8e0b3c,0x69dc0108,0xf4200154}},	//   _diiu, _vjag, upse, নটির_, 
   {{0x7bc4003a,0x799e0b3d,0x7c3406ea,0x00000000}},	//   _eiiu, gorw, ðarí, --, 
   {{0xf7720b3e,0x2fcc007f,0xb83401f4,0x00000000}},	//   چاق_, _judg_, мерщ, --, 
   {{0xf770d265,0x6d5a0b3f,0x6b8c013c,0xf7c002dd}},	//   ناق_, _hova, _ujag, _ﺣﺎﻧﺪ, 
   {{0x6d5a0b40,0x799e0b41,0x6aac0526,0x6b9c0077}},	// [3bc50] _kova, borw, _uzaf, mosg, 
   {{0x6d582220,0x799d1869,0xc4da0b42,0x6b9c015d}},	//   _jova, corw, рђа_, losg, 
   {{0x6d5a0b43,0x69c40472,0x69cc00d8,0x764008ce}},	//   _mova, _iihe, _huae, _ámyn, 
   {{0x69c60b44,0x69cc0270,0x6b9c022e,0x00000000}},	//   _hihe, _kuae, nosg, --, 
   {{0x69c60b45,0x6d580270,0x61460b46,0xe6a40116}},	//   _kihe, _oova, зела, _хунү, 
   {{0x6d5889d4,0x69c4016d,0x2fcc0327,0x6b9cb8e9}},	//   _nova, _jihe, _budg_, hosg, 
   {{0x69c60b47,0x69cc0421,0x6b9c25d7,0x5c640092}},	//   _mihe, _luae, kosg, _ጎርጎር, 
   {{0x69c60b48,0x6d580109,0x44220b49,0x799c006f}},	//   _lihe, _aova, _ipj_, zorw, 
   {{0x6b9c0005,0x82347092,0x7bc400af,0x69c60b4a}},	//   dosg, _برزا, _riiu, _oihe, 
   {{0x69c60b4b,0x61e920dc,0x7bc60b4c,0x4420020b}},	//   _nihe, _iwel, _siiu, _kpj_, 
   {{0x61ea0b4d,0x6d5a0b4e,0x69cc0421,0x44200092}},	//   _hwel, _dova, _auae, _jpj_, 
   {{0x61ea0b4f,0x69c40664,0x44200023,0x799c006f}},	//   _kwel, _aihe, _mpj_, worw, 
   {{0x799e0b50,0x61ea0b51,0x69c422bd,0x6d58014a}},	//   torw, _jwel, _bihe, _fova, 
   {{0x6d5a0b52,0x69c60b53,0x61ea0b54,0x44220b55}},	//   _gova, _cihe, _mwel, _opj_, 
   {{0x61ea0b56,0x69c60b57,0x799e0b58,0x442000d8}},	//   _lwel, _dihe, rorw, _npj_, 
   {{0x6d5a0b59,0x799e0b5a,0x5ee803d4,0x63b80369}},	//   _zova, sorw, _গাঁও_, jmwn, 
   {{0x61ea0b5b,0x69c40851,0x799c01c8,0x6d58004b}},	// [3bc60] _nwel, _fihe, porw, _yova, 
   {{0x69c4015c,0x6d58022e,0x63b80142,0x00000000}},	//   _gihe, _xova, emwn, --, 
   {{0x61ea0b5c,0x77640227,0x3d10448b,0x44200009}},	//   _awel, pkix, _दाने_, _cpj_, 
   {{0x69c60b5d,0x61e874ed,0xc7d40375,0xd7754f62}},	//   _zihe, _bwel, _מוטי_, _راجع, 
   {{0x61e85d63,0x44200158,0x6441ad4d,0xe51800af}},	//   _cwel, _epj_, _álin, न्हि_, 
   {{0x69c418f7,0xc5e4025c,0x61e82bab,0x00000000}},	//   _xihe, _སྦྲི, _dwel, --, 
   {{0x6d5a0b5e,0x6b2c031c,0xa3c40490,0xd24c00e5}},	//   _rova, _ཧྲའོ_, _उंच_, ئنڈ_, 
   {{0x6d5a0b5f,0x46400014,0x7f4400d1,0xd25000ae}},	//   _sova, _تھہِ, كلىق_, _كنز_, 
   {{0x61ea0b60,0x6d5987f1,0xb2440118,0x6450054e}},	//   _gwel, _pova, áždě, ădiş, 
   {{0x10a40022,0xcd4a0b61,0xe2440b73,0x6d5803e3}},	//   _еизн, счид_, _تخفي, _qova, 
   {{0x69c60b62,0x6d5a0b63,0x61ea0b64,0x69cc0393}},	//   _rihe, _vova, _zwel, _suae, 
   {{0x6d5a0b65,0xac8400db,0x4f941925,0x00000000}},	//   _wova, згүл, _эрзу, --, 
   {{0x69cc0de4,0x6d5a0b66,0x69c60b67,0x6b9e0b68}},	//   _quae, _tova, _pihe, rosg, 
   {{0x61fc01bf,0x69c4036e,0x6b9c022e,0x00000000}},	//   _æsle, _qihe, sosg, --, 
   {{0x69c60b69,0x2d8e0b6a,0x97380240,0x26c401e1}},	//   _vihe, mnde_, _ብኽያት, _ńlo_, 
   {{0x2d8c03fa,0x69cd3ca8,0x69c60b6b,0x7bd8010f}},	//   lnde_, _tuae, _wihe, _פקחו, 
   {{0x2d8e0b6c,0x69c4badd,0x4420020b,0x2b480f91}},	// [3bc70] onde_, _tihe, _spj_, _inac_, 
   {{0x61ea0b6d,0x2d8e0b6e,0x442005b1,0xe1f00133}},	//   _rwel, nnde_, _ppj_, ۆست_, 
   {{0x2d8e0b6f,0xf99000c6,0x61ea0b70,0x00000000}},	//   inde_, _حبي_, _swel, --, 
   {{0xe1f20b71,0x61e802ea,0xf48401c6,0x2d8c002f}},	//   نست_, _pwel, хуун, hnde_, 
   {{0x2b4800db,0x34940107,0x64a400c7,0x00000000}},	//   _mnac_, _ҷарр, чаҧа, --, 
   {{0x2d8c0196,0xa0202a9b,0x00000000,0x00000000}},	//   jnde_, _çökd, --, --, 
   {{0xd12c188d,0x34943075,0x2b48005a,0x61e80327}},	//   شمي_, _зарр, _onac_, _wwel, 
   {{0x2d8e0b72,0x6d5d3b7a,0x5f749eec,0x417475f5}},	//   ende_, öran, باتر, _کارس, 
   {{0x61e920e6,0x00000000,0x00000000,0x00000000}},	//   _uwel, --, --, --, 
   {{0x2b480798,0x0d808715,0x999000d7,0x00000000}},	//   _anac_, клын, _kryť_, --, 
   {{0x26d801f5,0xc60803d4,0x236cd8f7,0x00000000}},	//   _ofso_, ৰিটা_, _klej_, --, 
   {{0x2d8d790d,0x2cb803b2,0x1098011a,0x00000000}},	//   ande_, ýrda_, _ובעב, --, 
   {{0xeff80092,0xe0600133,0xfe24030d,0x00000000}},	//   ለየው_, _سێکی, _хьен, --, 
   {{0xd82401c6,0x00000000,0x00000000,0x00000000}},	//   мдги, --, --, --, 
   {{0x236c9637,0x2b4929ce,0x3f9c0810,0x7c20009d}},	//   _olej_, _fnac_, oouu_, _upnr, 
   {{0x98b800b0,0x68e02ed0,0x3f9c0418,0x00000000}},	//   _hopī_, ılda, nouu_, --, 
   {{0x27ec04b9,0x07a0b6f8,0x98b800b0,0x69d4443a}},	// [3bc80] ćena_, татн, _kopī_, _यूपी, 
   {{0x236e0b73,0x4610036b,0xfd6000dc,0x052400f3}},	//   _alej_, ئولر, _pitṝ, моук_, 
   {{0x3dc4007f,0x236c0023,0x3f9c00b5,0x26e8030a}},	//   _minw_, _blej_, kouu_, ñtoù_, 
   {{0xdb14004a,0x66200118,0xd394013d,0x00000000}},	//   écèd, ízký, фәгә_, --, 
   {{0x236c0218,0x2d8e0b74,0xdb140309,0xb99c00b8}},	//   _dlej_, ynde_, _biyú, _ṛṣim, 
   {{0x86b00220,0x00000000,0x00000000,0x00000000}},	//   _рәсі, --, --, --, 
   {{0x7ff006b6,0x236c036e,0x2d8c0150,0x69d4012d}},	//   نسيا, _flej_, _ﮔﯘﻟﻰ_, _यूनी, 
   {{0x236c151c,0x93248198,0x3f9c05b1,0x0ee80212}},	//   _glej_, _ترسن, gouu_, цьки_, 
   {{0xa2c00032,0xdce00171,0x00000000,0x00000000}},	//   _йәшк, cilī, --, --, 
   {{0x2d8e0b75,0x3d100073,0x236c00d0,0x7de001e1}},	//   unde_, _दाणे_, _zlej_, _sísò, 
   {{0x2d8e0b76,0x00000000,0x00000000,0x00000000}},	//   rnde_, --, --, --, 
   {{0x0e6400db,0x2d8c0205,0x00000000,0x00000000}},	//   _окен, snde_, --, --, 
   {{0x41a40408,0x00000000,0x00000000,0x00000000}},	//   _авăн_, --, --, --, 
   {{0x3e300014,0x8fbc00b8,0x98b8002b,0x00000000}},	//   _شہپر, _dṛśi, _gopī_, --, 
   {{0x81dc015b,0x3d100073,0x00000000,0x00000000}},	//   _দয়া_, _दाते_, --, --, 
   {{0x2b4801a6,0x00000000,0x00000000,0x00000000}},	//   _unac_, --, --, --, 
   {{0x2bd400e1,0x00000000,0x00000000,0x00000000}},	// [3bc90] _ठंडा, --, --, --, 
   {{0x95280135,0x236c0219,0x00000000,0x00000000}},	//   _ཤྲཱི_, _slej_, --, --, 
   {{0x236c1a4c,0x68f45556,0x69d800d8,0x00000000}},	//   _plej_, mazd, _éweb, --, 
   {{0xe2b4009d,0x68f400c0,0x00000000,0x00000000}},	//   нслэ, lazd, --, --, 
   {{0xdb140231,0x672d3948,0xd00c2033,0xe1253758}},	//   écéd, meaj, ەلى_, емли, 
   {{0x660e0b77,0x6d5c01e6,0x672d2f90,0x291001d4}},	//   muak, öral, leaj, ngza_, 
   {{0x10a03b0e,0x660e0b78,0x25a000bc,0xe3e83f32}},	//   лишн, luak, mohl_, _رکان_, 
   {{0x50a00075,0x68f40342,0x236c036e,0x672c6a51}},	//   دەمل, hazd, _ulej_, neaj, 
   {{0x660e0b79,0x80240451,0x00000000,0x00000000}},	//   nuak, _ڊرام, --, --, 
   {{0x12882fee,0x68f60b7a,0xc1c8033f,0x672c0037}},	//   _عملی_, jazd, ादीग, heaj, 
   {{0x660e0b7b,0x672c01c8,0x3f9c0418,0xaf34082a}},	//   huak, keaj, pouu_, رویژ, 
   {{0x660e0b7c,0x3dc4090c,0x25a00036,0x00000000}},	//   kuak, _winw_, hohl_, --, 
   {{0x7f48d059,0xfbcc0d2c,0xee340022,0x672c054e}},	//   _ingq, _सूरम, _аҽы_, deaj, 
   {{0x68f401ed,0x660c003e,0x98a40022,0xdb04000d}},	//   gazd, duak, еиге, lmkü, 
   {{0xd7bc0574,0xdc68011c,0x00000000,0x00000000}},	//   ्दलच, _хайд_, --, --, 
   {{0x660c0093,0x07a20b7d,0xc7a006ed,0x00000000}},	//   fuak, гасн, гиск, --, 
   {{0x660e0b7e,0x7f48017a,0xfbac02ab,0x00000000}},	// [3bca0] guak, _mngq, _टीएम, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x130403b7,0x7f48ba22,0xded000b7,0x672c036e}},	//   езем, _ongq, ኩሉን_, beaj, 
   {{0x660deef3,0xd7040116,0x00000000,0x00000000}},	//   buak, _язми, --, --, 
   {{0x57bc1d8a,0x660c009a,0x5ea400fe,0xe3b001d9}},	//   ्दीह, cuak, খেতে, جرٕ_, 
   {{0x7f4a0b7f,0xc2041473,0x957400cf,0x00000000}},	//   _angq, رقىن_, _чымч, --, 
   {{0x1dd400e1,0x4fc40117,0x6d5c0037,0x00000000}},	//   _डूबत, нсиа, öram, --, 
   {{0xbea400ec,0x3b00036e,0x2e880124,0xa3cc07af}},	//   ڙهين_, _ndiq_, мҩеи_, रदर_, 
   {{0x11d8007b,0x68f49f9f,0x00000000,0x00000000}},	//   _روضة_, yazd, --, --, 
   {{0x7f4a0b80,0x1b1c0183,0xa2440014,0xd0101867}},	//   _engq, _বোলে_, _جیٖل_, _ملط_, 
   {{0x660c043b,0xfe6c0517,0x68f401fa,0x12d0015b}},	//   zuak, لدی_, vazd, ারীদ, 
   {{0x660c020c,0x61f80139,0x8aa4004e,0x00000000}},	//   yuak, _äblä, ергд, --, 
   {{0x69c00209,0x672c26bb,0x00000000,0x00000000}},	//   ňlem, veaj, --, --, 
   {{0x660c0333,0xc4c80eac,0xad240046,0xfd7c0023}},	//   vuak, _লজ্জ, _شىعى, _ትፈልጦ_, 
   {{0x27ec04b9,0x07442b61,0x672e0b81,0x00000000}},	//   ćeno_, нхам, teaj, --, 
   {{0x660e0b82,0x25a00639,0xd0440213,0x61f80042}},	//   tuak, wohl_, çməl, yswl, 
   {{0x672c00ad,0xfb38010f,0xa4d41cd0,0x00000000}},	// [3bcb0] reaj, _טאהש_, возі, --, 
   {{0x660e0b83,0x6d9c510c,0x672c0254,0x00000000}},	//   ruak, _uçağ, seaj, --, 
   {{0x44255b4e,0x660c0134,0x9f4403b2,0x29020b84}},	//   ïn_, suak, _avlý_, _idha_, 
   {{0x660d7294,0xdb14007f,0x27e001ab,0x996000e2}},	//   puak, _chyè, _ithn_, _cīņu_, 
   {{0x660e0b85,0x21740a93,0xb7640479,0x00000000}},	//   quak, кукр, _стэй, --, 
   {{0x91000063,0x6594b96f,0xe6c8010e,0x00000000}},	//   апше, _рагу, _çuññ, --, 
   {{0x29020b86,0x91c1412a,0xd5ac0d62,0x50a000d1}},	//   _mdha_, рәтл, _بہٕ_, لەكل, 
   {{0x5dd800f0,0xd3441046,0x0b100154,0xd9e000eb}},	//   мфор_, _لیمه_, িজুল_, _বিসম, 
   {{0x2900c1e5,0xd24ca675,0xd3440244,0x00000000}},	//   _odha_, _وچه_, _جینه_, --, 
   {{0x1c45f97b,0x29020b87,0x7f480007,0x10280137}},	//   вном, _ndha_, _wngq, ستۉۉ_, 
   {{0xe9f80241,0x1ae4004e,0x00000000,0x00000000}},	//   _iyẹ_, конм, --, --, 
   {{0x7f480912,0x3d1002a0,0x00000000,0x00000000}},	//   _ungq, _दावे_, --, --, 
   {{0x3b0002d3,0x00000000,0x00000000,0x00000000}},	//   _vdiq_, --, --, --, 
   {{0xdca400c7,0xdce0005f,0x09e067ba,0x845c0023}},	//   _иали, bklā, рорн, ሰርሕን_, 
   {{0x98a60b88,0x29002de1,0x18a40798,0x00000000}},	//   тиве, _ddha_, тавм, --, 
   {{0x2900198f,0x57bc1d27,0x81e403d4,0x9a6800c6}},	//   _edha_, ्देह, _ভিন_, _يمثل_, 
   {{0xd7d00073,0x95c801a9,0x00000000,0x00000000}},	// [3bcc0] _दूरच, длаб_, --, --, 
   {{0xd46800ee,0xa3cc00cd,0x00000000,0x00000000}},	//   мизе_, रदं_, --, --, 
   {{0x80c400bd,0x1c0811b1,0xd7060b89,0x00000000}},	//   রুত্, _विफल_, _изни, --, 
   {{0xd26401e8,0x91e421fa,0xdce000a2,0x5fccb071}},	//   ккей, воде, kilį, _ﻗﺎﭘﺘ, 
   {{0x823000c6,0x6d5c1284,0x38bc01e1,0x00000000}},	//   لروا, örak, báré_, --, 
   {{0x50c800fd,0x00000000,0x00000000,0x00000000}},	//   мыйм_, --, --, --, 
   {{0xa3cc00cd,0x996000de,0x35d8000d,0x00000000}},	//   रदः_, _tīņu_, _भंड़, --, 
   {{0x753e0b8a,0x00000000,0x00000000,0x00000000}},	//   _harz, --, --, --, 
   {{0x753e0b8b,0x00000000,0x00000000,0x00000000}},	//   _karz, --, --, --, 
   {{0x753c012d,0xdce000de,0x00000000,0x00000000}},	//   _jarz, tklā, --, --, 
   {{0x753e0b8c,0x2174be12,0x0cd001ad,0x290000b8}},	//   _marz, _сутр, _सलीम, _rdha_, 
   {{0x753c14ed,0xdce000da,0xfaf000e3,0x00000000}},	//   _larz, rklā, يثُ_, --, 
   {{0x80c403f4,0x70000521,0x2900020c,0x7d24007c}},	//   রুদ্, _ịche, _pdha_, ärså, 
   {{0x753c068f,0x212405b1,0x69340276,0x44300175}},	//   _narz, _xblh_, ынгу, ywx_, 
   {{0x29001161,0xe8d004ce,0xe7940ee8,0xc1c807d2}},	//   _vdha_, _mm軸_, هارک, _ﺗﻮﺯﺍ, 
   {{0x753e0b8d,0xd734009d,0xe514000d,0x99e000fe}},	//   _aarz, лдсө, _ढाहि_, _বিৰক, 
   {{0x753c03bd,0xc6a4009b,0x00000000,0x00000000}},	// [3bcd0] _barz, трви, --, --, 
   {{0x29020b8e,0x6aad1cab,0x1c08375c,0x04640046}},	//   _udha_, _iyaf, _विमल_, ктем, 
   {{0x753e0b8f,0x02c81fe5,0x00000000,0x00000000}},	//   _darz, िश्न, --, --, 
   {{0x21240a2e,0x6aac6f41,0x386c11aa,0xb6040064}},	//   _sblh_, _kyaf, ødre_, _įšvi, 
   {{0x753c07d6,0x40f00124,0xc1c80220,0x00000000}},	//   _farz, иҧар, _ﺗﻮﺭﺍ, --, 
   {{0x673cb3f8,0x6aac0ea0,0x00000000,0x00000000}},	//   _hasj, _myaf, --, --, 
   {{0x673e0b90,0x6aac0a49,0x03c60b91,0x69d407f7}},	//   _kasj, _lyaf, _асам, _यूसी, 
   {{0x753e0b92,0x673c0d27,0x349401c0,0xc0c00166}},	//   _zarz, _jasj, _таср, гәҗи, 
   {{0x6aae0b93,0x63aa0b94,0x5cf518cd,0x753e0b95}},	//   _nyaf, _iken, ляну, _yarz, 
   {{0x673c09a8,0x63a8030a,0xdfd40024,0x00000000}},	//   _lasj, _hken, _божы, --, 
   {{0xdc685ffa,0x6aae0b96,0x63a80083,0x7094024c}},	//   ханд_, _ayaf, _kken, _кафф, 
   {{0x6aae0b97,0x673e0b98,0x00000000,0x00000000}},	//   _byaf, _nasj, --, --, 
   {{0x6aac0230,0x63a801c8,0x29340023,0x9e6400ec}},	//   _cyaf, _mken, _ብምዝማ, _ڄاڻن, 
   {{0x6aac007f,0xdef800e8,0xd9440063,0x7f5801a9}},	//   _dyaf, laŋ_, ћеви, ljuq, 
   {{0x63a860d7,0x6aad0db9,0x673c53b9,0x7d0002d0}},	//   _oken, _eyaf, _basj, _idns, 
   {{0x753dd619,0x63aa0b99,0x36e4016c,0x7d000455}},	//   _sarz, _nken, рбаҳ, _hdns, 
   {{0x753e0b9a,0x6aad4b2a,0x7e780112,0x00000000}},	// [3bce0] _parz, _gyaf, nzup, --, 
   {{0x63aa0b9b,0x491806ab,0x753c44f0,0x00000000}},	//   _aken, _बायो_, _qarz, --, 
   {{0x753e0b9c,0x63a801ee,0x1308e1b8,0x673c33b8}},	//   _varz, _bken, еней_, _fasj, 
   {{0x63a80295,0x753c0034,0x673e0b9d,0xdef800e8}},	//   _cken, _warz, _gasj, jaŋ_, 
   {{0xd1b004fb,0x51860b9e,0x941000ac,0x00000000}},	//   میرک, лука, _ədəd_, --, 
   {{0x673c1711,0x76440526,0x7e7800ef,0x00000000}},	//   _zasj, mviy, dzup, --, 
   {{0xdb140166,0x7644023a,0xfbcc0c6e,0x00000000}},	//   _biyü, lviy, _संगम, --, 
   {{0xb4c01533,0xee440588,0xf2c400d1,0x52740209}},	//   ँधी_, иҭеи, _көли, _йузу, 
   {{0xdb140139,0x5274010b,0x4ea60b9f,0x7644007f}},	//   _diyü, _суву, ырка, nviy, 
   {{0x6aac2dab,0xfde4004b,0x3fcc02dd,0x00000000}},	//   _ryaf, اکنو_, _ﻗﯟﺍﻧ, --, 
   {{0x4ac4069f,0x6aad97d9,0x7d00095c,0xc0d001c8}},	//   रेनव, _syaf, _ddns, _ايمب, 
   {{0xdd040a28,0x63a805b1,0x7d0002d0,0x6aac0100}},	//   āpār, _xken, _edns, _pyaf, 
   {{0xc330025f,0x673c653a,0x7e78033f,0x764401b9}},	//   זור_, _rasj, czup, jviy, 
   {{0x6aae0b1f,0x98b806be,0x00000000,0x00000000}},	//   _vyaf, _alpı_, --, --, 
   {{0x673e0ba0,0xec140131,0x69d4012d,0x00000000}},	//   _pasj, _ئوبد, _यूरी, --, 
   {{0x673cfb50,0x49000137,0x00000000,0x00000000}},	//   _qasj, шүүг, --, --, 
   {{0xe73821bf,0xc9860ba1,0x673ca8a1,0x676002d3}},	// [3bcf0] нең_, _буни, _vasj, _ተኻይዱ_, 
   {{0x63aa0ba2,0x673c01f5,0x3a7401ee,0x00000000}},	//   _sken, _wasj, _ылыр, --, 
   {{0x673e0ba3,0xdef8002e,0x00000000,0x00000000}},	//   _tasj, yaŋ_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe1343e64,0xa1580b3b,0xddc80210,0x00000000}},	//   инды, каду_, rzeź, --, 
   {{0x660e0ba4,0x63a80a73,0x6145dd1f,0xdb1402d2}},	//   mrak, _wken, река, _ábör, 
   {{0x660e0ba5,0x46bc00bc,0xdb043bba,0x2bd400bc}},	//   lrak, ्शकह, mmkö, _ठूला, 
   {{0x63a80450,0x644402c4,0x660e0ba6,0x7e78005a}},	//   _uken, mvhi, orak, tzup, 
   {{0x660e0ba7,0x38bc0ca8,0xdef80de2,0x4ac408f2}},	//   nrak, _kárí_, raŋ_, रेमव, 
   {{0x38bc0241,0x5bac00dc,0xdef800e8,0x9c240798}},	//   _járí_, घत्व, saŋ_, адод, 
   {{0x7644006f,0x7e785380,0x999001ef,0x00000000}},	//   zviy, szup, _pryž_, --, 
   {{0x660e0ba8,0x00000000,0x00000000,0x00000000}},	//   krak, --, --, --, 
   {{0xdd960ba9,0x660e0baa,0xdb040200,0x00000000}},	//   _кады, jrak, lokë, --, 
   {{0x660e0bab,0x1d0858f0,0x00000000,0x00000000}},	//   drak, _реки_, --, --, 
   {{0x97c60bac,0x660e0bad,0x52b074f6,0x1ae60bae}},	//   لترم, erak, _जर्स, _койм, 
   {{0x7644c645,0x9b94d712,0x8c1800d9,0x6d5c26bb}},	//   tviy, _خلعت, _סופי, örav, 
   {{0x95840364,0x54d416a4,0x6b9c00e5,0x00000000}},	// [3bd00] алае, ацеу, érge, --, 
   {{0x76443bfe,0x3a0801d3,0x00000000,0x00000000}},	//   rviy, _لکڑی_, --, --, 
   {{0x38bc0241,0xb4c01524,0xdb0c0241,0xdd240171}},	//   _dárí_, ँधे_, _àkóp, _tīņi, 
   {{0x77942dcd,0xe5c80150,0xbd800023,0x2cb80174}},	//   _ایرا, _ﺒﺎﻹﺜ, _ክጥቀም_, ýrdi_, 
   {{0x38bc01e1,0x660c1b98,0x07a0667a,0xd3e4036b}},	//   _fárí_, crak, _фаян, اقچی, 
   {{0x98b80100,0x31344705,0xe2a81e24,0x00000000}},	//   _lapč_, секр, دامن_, --, 
   {{0x0014009f,0x013000cf,0x00000000,0x00000000}},	//   لغيث_, زعود, --, --, 
   {{0x7f4404a9,0x3ead6545,0xd3720baf,0x931435e6}},	//   للىق_, _bygt_, _بهر_, _خورش, 
   {{0x27ec0bb8,0xc32c0014,0xd1740137,0x2228007b}},	//   ćeni_, _زٕل_, _кыжы, _مثلي_, 
   {{0x6e9407d6,0x3eac03b2,0xb18800d7,0x2d9800e4}},	//   _қилу, _dygt_, _deťú, õre_, 
   {{0x2cb81506,0x64401f60,0x10a400d6,0x660c2e29}},	//   ård_, _álit, _тижн, zrak, 
   {{0x660e0bb0,0xbb940b32,0x503c0092,0xaa5800d1}},	//   yrak, жающ, _በርሳች, гиму_, 
   {{0x4918007d,0x92c80183,0xdb080332,0x00000000}},	//   _बादो_, োৰৰ_, ónál, --, 
   {{0x9e660bb1,0xac18242f,0x29042776,0xe81801c0}},	//   _دامن, _боку_, ûla_, логч_, 
   {{0xb8688fad,0x37f8084c,0x660e0bb2,0xf8a4000d}},	//   ајте_, иерэ_, wrak, _खुआय, 
   {{0x660e0bb3,0x8b646680,0x290c054e,0x8d44009d}},	//   trak, _خاتم, şea_, _сүүг_, 
   {{0x2d8c057b,0xb91c0521,0x660e0bb4,0x38bc0241}},	// [3bd10] oide_, nazụ_, urak, _párí_, 
   {{0x2d8e0bb5,0x05740aa0,0x2bc401f2,0x49b800db}},	//   nide_, جارد, _ịcha_, _جاعد_, 
   {{0x660e0bb6,0xa2d4188d,0x7ebc0024,0x0cdc0248}},	//   srak, ميات, _išpū, _wẹwẹ_, 
   {{0x660e0bb7,0x2d8e0bb8,0x29dc01fb,0xf1a80133}},	//   prak, hide_, _kìa_, یاوه_, 
   {{0x2d8e0bb9,0xb6046345,0x855401ed,0x660c0784}},	//   kide_, _мярк, _پیار_, qrak, 
   {{0x2d8c51f7,0xdb04036e,0x00000000,0x00000000}},	//   jide_, tokë, --, --, 
   {{0x2d8e0bba,0x3495a40f,0x29dc004d,0x3eac00b5}},	//   dide_, _дарр, _lìa_, _sygt_, 
   {{0x2d8e0bbb,0x66080fac,0xdb040200,0x823400e5}},	//   eide_, _åeks, rokë, _پررا, 
   {{0x2d8e0bbc,0xeb6802d3,0x1b1c00eb,0x00000000}},	//   fide_, _ዝረጋገ, _বোঝে_, --, 
   {{0x2d8e0bbd,0x01140214,0x64411b7a,0x00000000}},	//   gide_, _خبرخ, _ális, --, 
   {{0x29dc026c,0x5ca43740,0xde440150,0xdbc8009d}},	//   _aìa_, синб, _گراۋ, лгод_, 
   {{0x2d8e0bbe,0x29dc001e,0x1df8b40e,0x6f6401d5}},	//   aide_, _bìa_, _беды_, _وهلم, 
   {{0x2d8c0323,0x139800c8,0x9d4409a5,0x00000000}},	//   bide_, רברע, _гелд, --, 
   {{0x6d5c00c5,0x0fd409bb,0x48e0005b,0x29dc0051}},	//   örat, _ढूँढ, зорв, _dìa_, 
   {{0xdee80201,0x4805471c,0xcd5801d9,0xdd380165}},	//   _መሆን_, йерн_, _حسنچ_, płłs, 
   {{0x2cb9d0dd,0x00000000,0x00000000,0x00000000}},	//   ürde_, --, --, --, 
   {{0x7ae60bbf,0x29dc04cc,0x9b4400f1,0x4c9001ee}},	// [3bd20] _ifit, _gìa_, _ننګو, _миәс, 
   {{0x79540345,0x4a5800df,0x00000000,0x00000000}},	//   _بێسا, _עדיו, --, --, 
   {{0x18680075,0x29de0bc0,0x0fd4033f,0x942407c6}},	//   _сани_, _zìa_, _ढूंढ, смее, 
   {{0x2d8dbab1,0x7ae40135,0xfd3c00b5,0x00000000}},	//   zide_, _jfit, _st第_, --, 
   {{0x7ae60bc1,0x2d8c0790,0x745401d3,0xdee001ec}},	//   _mfit, yide_, _ڈھائ, _ﺍﺸﺘﺒ, 
   {{0x813420ea,0xdb0426bc,0x3d1000e1,0x00000000}},	//   مسىز_, llkä, _दागे_, --, 
   {{0x7ae60bc2,0x2d8e0bc3,0x92c80154,0x00000000}},	//   _ofit, vide_, োরে_, --, 
   {{0x2d8e0bc4,0x7ae60bc5,0xdb040306,0x00000000}},	//   wide_, _nfit, boké, --, 
   {{0x2d8e0bc6,0x90460bc7,0x51186f04,0xdee80092}},	//   tide_, _گناه, _مزاح_, _መሆኗ_, 
   {{0x86780d65,0x7ae60bc8,0xfe6c2781,0x29dc0208}},	//   טרפו, _afit, عدي_, _rìa_, 
   {{0xc0f80023,0x00000000,0x00000000,0x00000000}},	//   ፊኦም_, --, --, --, 
   {{0x2d8e0bc9,0x205473d3,0xcae002ab,0x00540375}},	//   side_, _ьтур, कुंड_, _לשבת_, 
   {{0x2d8e0bca,0xfba801c0,0x7dc007d6,0x46a40037}},	//   pide_, стэй_, تقین, _कुंह, 
   {{0x7ae40851,0x67d401b9,0x00000000,0x00000000}},	//   _efit, жову, --, --, 
   {{0x7ae40368,0xebc400d1,0xe63001e1,0x3cf801e4}},	//   _ffit, _мәмн, _ótúú, _גלונ, 
   {{0xc6a40120,0x2cb803b2,0x3ff800df,0x00000000}},	//   брзи, ýrdu_, טפלע, --, 
   {{0xf1a94a01,0xfa280154,0x69dc031c,0x00000000}},	// [3bd30] गवान, মিউল_, qqse, --, 
   {{0x67d402d5,0xdb040254,0x00000000,0x00000000}},	//   _sąju, alkä, --, --, 
   {{0xe4360bcb,0xdee80201,0x66d40214,0x6388035b}},	//   تفاد, _መሆኑ_, _ويدئ, аӡам_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x27ec05ce,0x6d1807f7,0x17180115,0x00000000}},	//   ćenu_, _दांग_, _דורע, --, 
   {{0xa068b32d,0xdb0428d1,0x9f90013a,0x00000000}},	//   иала_, roké, _vší_, --, 
   {{0xdb056e40,0x98b80171,0x00000000,0x00000000}},	//   soké, _kapā_, --, --, 
   {{0x92c80183,0x6aa404af,0x00000000,0x00000000}},	//   োৰে_, _गु्र, --, --, 
   {{0x9f9002fb,0x00000000,0x00000000,0x00000000}},	//   _uší_, --, --, --, 
   {{0x61ea0bcc,0x98b800da,0x7ae486ed,0x224c00fd}},	//   _itel, _lapā_, _sfit, _irek_, 
   {{0x61e856c0,0x224c0165,0x44200076,0xb5cc0150}},	//   _htel, _hrek_, _jqj_, _ﺒﺎﻴﻌ, 
   {{0x224d78b2,0x6d5c01e6,0x2004003a,0x9f3400d4}},	//   _krek_, örar, _ivli_, _феді, 
   {{0x224c0098,0x61e8025c,0xdea01a4b,0x7eac0ca8}},	//   _jrek_, _jtel, _زیدی, bẹẹk, 
   {{0x61ea0bcd,0xd7e82309,0x224c0254,0x69d001e1}},	//   _mtel, имге_, _mrek_, _ìje̟, 
   {{0x7ae4038f,0x7c602440,0xc84001e0,0x6e2400ef}},	//   _tfit, ልግሎቱ, мерй, _ģibi, 
   {{0x7ae60bce,0x224db5b5,0xdce0025c,0x00000000}},	//   _ufit, _orek_, filħ, --, 
   {{0x61ea0bcf,0xd9459190,0x558a0bd0,0x0cdc0ca8}},	// [3bd40] _ntel, _депи, абам_, _tẹtẹ_, 
   {{0x3c2005c7,0xb4e40073,0x00000000,0x00000000}},	//   oñv_, नडे_, --, --, 
   {{0x224c52ce,0x93440798,0x00000000,0x00000000}},	//   _arek_, жнее, --, --, 
   {{0xfe650969,0x224e0bd1,0xd7c8009f,0xdce00135}},	//   _قد_, _brek_, _خوجه_, bilħ, 
   {{0x224c0687,0x20040427,0xdce1372f,0x00000000}},	//   _crek_, _avli_, sklę, --, 
   {{0x224c79d7,0x8fe400f3,0x61e800d7,0xf48402f2}},	//   _drek_, оцид, _dtel, _فازی, 
   {{0x61ea0bd2,0x224e0bd3,0xa5941b0a,0x3d10000d}},	//   _etel, _erek_, _хрящ, _दाजे_, 
   {{0x224e0bd4,0x00000000,0x00000000,0x00000000}},	//   _frek_, --, --, --, 
   {{0x61e92fc8,0x224e0bd5,0x20042fbe,0x491808ec}},	//   _gtel, _grek_, _evli_, _बालो_, 
   {{0x10546449,0x23d8012d,0xd5a807b7,0xd008009b}},	//   _وضاح, _बूँद, कविज, _веже_, 
   {{0x0cdc0248,0x224c01c7,0x61e8022e,0x04d80115}},	//   _bẹrẹ_, _zrek_, _ztel, יקיל, 
   {{0x61ea0bd6,0x657802b1,0xbc640014,0x1fa401ec}},	//   _ytel, īwhi, زمُن_, _еріг, 
   {{0x4e960bd7,0x6f00ad47,0xfe4001c6,0xdd9800a2}},	//   _بشار, mamc, _онцо, huňy_, 
   {{0x6f020bd8,0x27340016,0x7f800132,0x00000000}},	//   lamc, _ấn_, _ىلەن, --, 
   {{0x47893ecf,0x98b802b1,0x0cdc0248,0x23d809bb}},	//   асам_, _papā_, _fẹrẹ_, _बूंद, 
   {{0x5ec02158,0x6f0001f7,0x00000000,0x00000000}},	//   _ষ্টে, namc, --, --, 
   {{0x6b8e0bd9,0xc4d80640,0x98b800b8,0xaa9401a9}},	// [3bd50] _imag, ађе_, _vapā_, _хипч, 
   {{0x66e001e1,0x6f006118,0xa9c00228,0xc51402da}},	//   _bákó, hamc, _سۅزۉ, تبرت, 
   {{0x6f0001f7,0x98ba0bda,0x224c003e,0x6b8c022e}},	//   kamc, _tapā_, _srek_, _kmag, 
   {{0x224e0bdb,0x61e80538,0x6f000841,0x00000000}},	//   _prek_, _ptel, jamc, --, 
   {{0x6b8e0bdc,0x6f020bdd,0x3ad000b0,0xc51406c2}},	//   _mmag, damc, _tēpū_, _وبست, 
   {{0xd24e0bde,0x6b8c07d6,0x224c05e4,0x23840050}},	//   انو_, _lmag, _vrek_, _کٔرِ, 
   {{0x6b8e0bdf,0xddc8068f,0xf99404ae,0xd9e000fe}},	//   _omag, rzeż, ורס_, _বিছম, 
   {{0x61e9da39,0x6b8c01a9,0x224c0e21,0x6f002e93}},	//   _ttel, _nmag, _trek_, gamc, 
   {{0x61ea0be0,0xf1ac0184,0x224e0be1,0x00000000}},	//   _utel, _аҡ_, _urek_, --, 
   {{0x0d802607,0x41760be2,0x40a8030d,0x6d5c4268}},	//   ельн, _بارس, _къен_, örap, 
   {{0x26d805ac,0x6b8c0334,0x5ba865cb,0xff5000c6}},	//   _ogso_, _bmag, йком_, _يخص_, 
   {{0x26d8022e,0x00000000,0x00000000,0x00000000}},	//   _ngso_, --, --, --, 
   {{0x6fdc00e4,0x34b80146,0xda700014,0x61ec01e4}},	//   _aĩch, _अर्द, رُس_, ŭalf, 
   {{0x6b8e0be3,0xad2400d1,0x00000000,0x00000000}},	//   _emag, _يىنى, --, --, 
   {{0xa8180451,0x08c00063,0xdea00066,0x00000000}},	//   يڪٽر_, ебрн, _زیگی, --, 
   {{0x2904066a,0x6b8c01ab,0x66e0998d,0x88a800eb}},	//   ólar_, _gmag, _rákó, _গৃহক, 
   {{0xe81c0210,0x4b78011a,0x00000000,0x00000000}},	// [3bd60] बूबा_, _לאקו, --, --, 
   {{0x6b8c6c4f,0x6f0001f0,0x00000000,0x00000000}},	//   _zmag, zamc, --, --, 
   {{0x6f000117,0x6b8e0be4,0x69d401ad,0xddc800d7}},	//   yamc, _ymag, _यूटी, rveň, 
   {{0x03a15400,0xd62800f3,0x00000000,0x00000000}},	//   нихо, _ломе_, --, --, 
   {{0x7bc400a3,0xd4f40024,0x00000000,0x00000000}},	//   _mhiu, _нявы, --, --, 
   {{0x7bc40363,0x6f00680c,0x45d00024,0x00000000}},	//   _lhiu, wamc, _поўс, --, 
   {{0x50d400dd,0x6f020be5,0x7bc4005a,0x00000000}},	//   _ہزار, tamc, _ohiu, --, 
   {{0x5ea403f4,0x77640009,0x2618012d,0x00000000}},	//   খেছে, njix, यूवी_, --, 
   {{0x6f020be6,0x6b8c01b9,0x03a057c6,0x00000000}},	//   ramc, _rmag, _чито, --, 
   {{0x6b8e0be7,0x7bc40093,0xc2404d56,0xc5f00375}},	//   _smag, _ahiu, _янук, עדת_, 
   {{0xe6b8db71,0xfd7001c6,0x6e2400ef,0xf0440633}},	//   _आर्ज, хлээ, _ģibu, _تعذی, 
   {{0x7bc60be8,0x1f54fdad,0x6f00014f,0xaa940166}},	//   _chiu, _отчё, qamc, димч, 
   {{0x3a740d44,0x7bc40192,0x7ac51518,0xfe6c00ec}},	//   еляр, _dhiu, есре, _مدو_, 
   {{0x827404ac,0x7c341709,0x07e40108,0x7d040210}},	//   לעכע_, ñarí, зцам, ójst, 
   {{0x6d5a0be9,0x7bc4464c,0x6b8c01a9,0xbd4000db}},	//   _inva, _fhiu, _tmag, _سپيى, 
   {{0x6b8e0bea,0x7bc60beb,0x98b80356,0x00000000}},	//   _umag, _ghiu, _sapă_, --, 
   {{0x98b8054e,0x6d49c8a7,0xeb0801f9,0x00000000}},	// [3bd70] _papă_, odda, वणीत_, --, 
   {{0x6d4a0bec,0x35b40816,0xf9fc011a,0x7bc40064}},	//   ndda, ебур, _ההזמ, _zhiu, 
   {{0x6b9e0bed,0x6d4a0bee,0x76400142,0x00000000}},	//   onsg, idda, _âmyn, --, 
   {{0x6b9e0bef,0x2295158b,0xe2b401c0,0x42d8015b}},	//   nnsg, ولاس, мслэ, দর্শ, 
   {{0x61451cc4,0x21695dc7,0x6d58bc15,0x6b9c0158}},	//   дела, жили_, _onva, insg, 
   {{0x6d4801f5,0x20d400d4,0x00000000,0x00000000}},	//   jdda, мійс, --, --, 
   {{0x10a001d5,0x3218002b,0x9fc804b4,0xf4340153}},	//   кишн, _ārye_, огка_, _перэ, 
   {{0x6d5a0bf0,0x672e0bf1,0x6d4a0bf2,0x6b9c01f5}},	//   _anva, nfaj, edda, jnsg, 
   {{0x3f800153,0x0cdc0ca8,0x00000000,0x00000000}},	//   ėju_, _pẹpẹ_, --, --, 
   {{0x7bc60bf3,0x6b9c01bf,0xdb0412e8,0x7204007b}},	//   _shiu, ensg, llkø, _أولم, 
   {{0x7bc401c3,0x672c8294,0x671c00e1,0x80c40154}},	//   _phiu, kfaj, _फांक_, রুজ্, 
   {{0x3e80020c,0x6d4a0bf4,0x69c40254,0xafc40150}},	//   _cèté_, adda, _ahhe, _كيلى, 
   {{0x1d08b2bd,0x1c085b82,0x6d48cff7,0x63b80142}},	//   _дели_, _विकल_, bdda, ilwn, 
   {{0x7bc404fe,0x6b9c53f9,0x98b800c0,0x290400e5}},	//   _whiu, ansg, _lapą_, ólap_, 
   {{0x7bc401ab,0x672c005b,0x99800118,0x48e0156e}},	//   _thiu, ffaj, stků_, тосв, 
   {{0x69c401ed,0x5bc4007b,0x7bc60bf5,0xdb04005c}},	//   _ehhe, _تقبل, _uhiu, jlkø, 
   {{0xab28038b,0x6d591cef,0xd5b01424,0xae0009ab}},	// [3bd80] _رسيل_, _ynva, نفر_, लीपन_, 
   {{0x3b000007,0xdb040109,0x9f800022,0x98a8012d}},	//   _heiq_, lokà, kóï_, zebę_, 
   {{0xe3b001d9,0x00000000,0x00000000,0x00000000}},	//   گرٕ_, --, --, --, 
   {{0x63b80007,0xdb040109,0xa0200139,0x6d480946}},	//   glwn, nokà, _çöyd, zdda, 
   {{0x6d4a0bf6,0x6440025a,0xe3b00050,0x42d800fe}},	//   ydda, _âlin, درٕ_, দৰ্শ, 
   {{0xc69004ac,0x63a80115,0x00000000,0x00000000}},	//   _יאר_, _ĉene, --, --, 
   {{0xd24c01d3,0xd2f00354,0x00000000,0x00000000}},	//   انڈ_, _бiар, --, --, 
   {{0x6d48015d,0xe6080244,0x00000000,0x00000000}},	//   wdda, _بزێو_, --, --, 
   {{0x6d58009d,0x2dd4cb42,0xc7b000d9,0x6b9c3bb6}},	//   _pnva, нжир, כבה_, vnsg, 
   {{0x6d4a0bf7,0x00000000,0x00000000,0x00000000}},	//   udda, --, --, --, 
   {{0x6d4a0bf8,0x672c01d3,0x7db0007b,0x00000000}},	//   rdda, yfaj, خصيا, --, 
   {{0x3b000097,0x2c4c0118,0x6b9c04e6,0x6d49846b}},	//   _ceiq_, _věd_, unsg, sdda, 
   {{0x4d29f041,0x6b9d452f,0x8d64041b,0xff2400f2}},	//   _дюйм_, rnsg, _овде, _آبمی, 
   {{0x6d580dd4,0x00000000,0x00000000,0x00000000}},	//   _unva, --, --, --, 
   {{0x2c740cad,0xdb0406d9,0x48bc03d4,0x316c0051}},	//   _dúdú_, bokà, ্ড্ৰ, _modz_, 
   {{0x3b000399,0x316e0bf9,0x00000000,0x00000000}},	//   _geiq_, _lodz_, --, --, 
   {{0x672c4a36,0xfcf4001f,0x69c40334,0xc98426ef}},	// [3bd90] rfaj, _ዉስጥ_, _thhe, _жуни, 
   {{0x332401ab,0x2c7401e1,0xe1f000d1,0xae0047b8}},	//   _acmx_, _gúdú_, ۇست_, लीयन_, 
   {{0x672c00df,0x628401e4,0x58f4010f,0xe3140a5b}},	//   pfaj, ĝhom, _אמתע_, емењ, 
   {{0x29000270,0x00000000,0x00000000,0x00000000}},	//   _heha_, --, --, --, 
   {{0x29020bfa,0xc6a410f3,0xb5f41214,0x27e00b70}},	//   _keha_, _црни, _изящ, _huhn_, 
   {{0x27e0b44b,0x2b480de2,0xfa78011a,0x00000000}},	//   _kuhn_, _laac_, ועדת_, --, 
   {{0x290000b0,0xd564044e,0x5fd4084c,0xb9cc0092}},	//   _meha_, _ተማሃሮ_, нциф, _ታዬ_, 
   {{0x29020bfb,0xdb040085,0x27e0003e,0x525800db}},	//   _leha_, koká, _muhn_, تسۅڭ_, 
   {{0x9f440004,0xdea0029e,0x9db80139,0x00000000}},	//   _atlã_, دیشی, зыну_, --, 
   {{0x29020bfc,0x316c068f,0xdb040122,0x3b000097}},	//   _neha_, _godz_, doká, _seiq_, 
   {{0x236c01fa,0x2b480009,0x1be80395,0x00000000}},	//   _koej_, _baac_, ядни_, --, 
   {{0x2b48004e,0x25bc00dc,0xdb056f14,0x00000000}},	//   _caac_, ्गुण, foká, --, 
   {{0x29020bfd,0x3f9c022f,0x2b480009,0x09e00395}},	//   _beha_, mnuu_, _daac_, лоян, 
   {{0x29020bfe,0xdca42ff5,0x551c2e05,0x00000000}},	//   _ceha_, _пали, _पाइए_, --, 
   {{0x2b48011c,0xad241ec7,0x29020bff,0x0d140375}},	//   _faac_, _شروو, _deha_, _טקסט_, 
   {{0x98a40724,0x3f9cf0b0,0xdb040022,0x00000000}},	//   _җиме, nnuu_, boká, --, 
   {{0x29000418,0x3f9d61d4,0x07a0a705,0x9974009d}},	// [3bda0] _feha_, inuu_, уатн, _зунш, 
   {{0x290007c5,0x46100f1c,0xd9440f5c,0xb93800db}},	//   _geha_, اولر, _џени, _تۋسا_, 
   {{0x3f9c208d,0x80c40c58,0x25e4012d,0x2b4a0c00}},	//   knuu_, ৰুত্, _झूठी_, _yaac_, 
   {{0x2900005a,0x69d80036,0x93b59a3f,0x69c80306}},	//   _zeha_, _éwer, رحاض, čleň, 
   {{0x290001e2,0x754400c7,0xcb1008a8,0xf504014b}},	//   _yeha_, _иҽаз, רלד_, _аҷзо, 
   {{0x3f9c300b,0x3fd402dd,0x00000000,0x00000000}},	//   enuu_, _ﺟﺎﺭﻧ, --, --, 
   {{0x3f9c208d,0xc0e4d55f,0x00000000,0x00000000}},	//   fnuu_, رفين_, --, --, 
   {{0xcfa401c6,0x00000000,0x00000000,0x00000000}},	//   эшли, --, --, --, 
   {{0x2b480014,0x82a0009d,0x31440117,0x00000000}},	//   _raac_, _батж, _идаҳ, --, 
   {{0xdb0403f7,0x3f9e0c01,0x2b493d3b,0xe194009d}},	//   voká, anuu_, _saac_, _ирхэ, 
   {{0x2cb931fc,0x3f9c0ba7,0x2b48002e,0x00000000}},	//   ærd_, bnuu_, _paac_, --, 
   {{0x29020c02,0xab95fa4e,0xdb040518,0x2b480009}},	//   _seha_, тимі, toká, _qaac_, 
   {{0x29020c03,0xbe10113e,0x80c403d4,0x00000000}},	//   _peha_, _مونع, ৰুদ্, --, 
   {{0xec340022,0x2b48e16b,0xcd2a0c04,0x65740092}},	//   _анкь, _waac_, _رستن_, _በፊትህ_, 
   {{0x7dc000aa,0x29000055,0x161c0b27,0x00000000}},	//   _حقون, _veha_, यूसर_, --, 
   {{0x2b4800ca,0xf7700451,0xdb040022,0x00000000}},	//   _uaac_, ٽاف_, poká, --, 
   {{0x2900033d,0x98b8033f,0x00000000,0x00000000}},	// [3bdb0] _teha_, _mapę_, --, --, 
   {{0x49180316,0x62840115,0x98b800c0,0xae18000d}},	//   _बाटो_, ŝhok, _lapę_, _दिनन_, 
   {{0x3f9c022f,0x3cf8010f,0x321800cd,0x00000000}},	//   ynuu_, פלאנ, _ārya_, --, 
   {{0x38c801e0,0xa2d410f8,0xb3640395,0xb60801ef}},	//   _яуын_, نيات, лъчк, _sušš, 
   {{0xc7640132,0x00000000,0x00000000,0x00000000}},	//   _قاڭى, --, --, --, 
   {{0xd24c04a9,0xe50805d4,0x00000000,0x00000000}},	//   زنى_, _زيرو_, --, --, 
   {{0x3f9c0270,0x8ff801ed,0xa3b40006,0x00000000}},	//   tnuu_, ورٹر_, _абві, --, 
   {{0x3f9e0c05,0x6454025c,0x00cc00d1,0x00000000}},	//   unuu_, _irzi, ﻗﯘﺗﻘ, --, 
   {{0x4e0000fb,0x62340114,0x00000000,0x00000000}},	//   азыб, _језу, --, --, 
   {{0x7b980014,0xb5cc02dd,0x9e0400cf,0x00000000}},	//   کھتس_, _ﺒﺎﻟﻌ, нчүл, --, 
   {{0x5ca407a5,0xb5e800cc,0x81c40171,0x00000000}},	//   тинб, _পিছচ, gnēš, --, 
   {{0x6454098d,0x59d8033f,0x9f04009f,0x290403f2}},	//   _mrzi, _यूजर, _شوتو, ðlan_, 
   {{0x4a400801,0xfe74008e,0xd6e000fe,0x4fc80055}},	//   аняв, _чүп_, বৰুপ, _uṣṇo, 
   {{0x6454ed7b,0xdb05401a,0xd9440114,0x3da40395}},	//   _orzi, llkü, њеви, _яреб, 
   {{0x7f4800f1,0x7d020c06,0x00000000,0x00000000}},	//   _kagq, _iens, --, --, 
   {{0x7d020c07,0xdca40116,0x8c18025d,0x07a0009d}},	//   _hens, _паһи, _חוקי, аасн, 
   {{0x64543142,0x7f485693,0xdb0475ee,0x00000000}},	// [3bdc0] _arzi, _magq, ilkü, --, 
   {{0x7d020c08,0x645404b9,0x7f480472,0x63a80115}},	//   _jens, _brzi, _lagq, _ĉena, 
   {{0x7d013d0a,0x130424fc,0x17c80107,0x00000000}},	//   _mens, взем, _огои_, --, 
   {{0x7d020c09,0x645439e2,0x64980107,0x72a80b01}},	//   _lens, _drzi, хтур_, нбеҳ_, 
   {{0x64560c0a,0x925801d9,0x81c800bd,0x6b9e0c0b}},	//   _erzi, بشار_, রআন_, érgi, 
   {{0x2abcc00f,0xe2aa0c0c,0x813416a0,0x8400009b}},	//   lábú_, رانن_, نسىز_, žđar, 
   {{0x70541075,0x7f481cdf,0xd370168d,0x98b80393}},	//   انبا, _bagq, _پێشک, _papę_, 
   {{0x61f00af2,0x76440548,0x59e00c00,0xdb0401f4}},	//   óhlô, owiy, पदार, nokä, 
   {{0x7d000537,0x4ea40801,0x91e60c0d,0x76460c0e}},	//   _bens, ърка, _розе, nwiy, 
   {{0xe7e40034,0x7d01e8e8,0x0db80736,0xf044179e}},	//   कदमा_, _cens, باعث_, _معصی, 
   {{0xfe6c0b29,0x76440009,0x4f2400db,0x98b800c0}},	//   مدی_, hwiy, _адеб, _tapę_, 
   {{0x7644151f,0x7d020c0f,0xe89400c7,0x00000000}},	//   kwiy, _eens, ҳагь, --, 
   {{0x7d020c10,0xfba805f5,0x50640032,0x76440113}},	//   _fens, ттэй_, _ятҡа, jwiy, 
   {{0x7d020c11,0x6e220c12,0x7c920c13,0x7f4801e2}},	//   _gens, mumb, اشیا, _zagq, 
   {{0x8bc5fe0a,0x7f4801b3,0x6e220c14,0x3cc00150}},	//   _исид, _yagq, lumb, _ﺭﺍﺳﻤ, 
   {{0x0ae8ab80,0x0ba80a2c,0x6e20009f,0x00000000}},	//   _غربي_, _تاتى_, oumb, --, 
   {{0x7d020c15,0x787c0793,0x645401a6,0x76740276}},	// [3bdd0] _yens, tävö, _srzi, алтф, 
   {{0x6e207805,0xe7e000cc,0x00000000,0x00000000}},	//   iumb, _ববীয, --, --, 
   {{0x6e220c16,0x98b8012c,0x76440009,0x44280eed}},	//   humb, _mapě_, awiy, ьцам_, 
   {{0x76460c17,0x671c1889,0x6454310a,0x00000000}},	//   bwiy, _फाटक_, _vrzi, --, 
   {{0x6e220c18,0x7644b034,0xb6040006,0x00000000}},	//   jumb, cwiy, _вяск, --, 
   {{0x660e0c19,0xf1c9ea53,0x7f480fec,0xa5c80014}},	//   msak, نونى_, _sagq, _سوزٕ_, 
   {{0x7d020c1a,0x64560c1b,0x1fb45e5b,0x50a00131}},	//   _rens, _urzi, лсир, مەكل, 
   {{0x2f54169c,0x6e2165c3,0x7f48011f,0x660e0c1c}},	//   атьс, fumb, _qagq, osak, 
   {{0xd9340023,0x00000000,0x00000000,0x00000000}},	//   _ኣጻብዕ, --, --, --, 
   {{0x7f4800aa,0x660e0c1d,0x644402b1,0x816801b9}},	//   _wagq, isak, owhi, _ўраб_, 
   {{0x9b4416ac,0x660e0c1e,0x64460c1f,0xa02000eb}},	//   هندو, hsak, nwhi, _ভৈরব_, 
   {{0x660e0c20,0x7d020c21,0x644400b0,0x4c800212}},	//   ksak, _wens, iwhi, слюв, 
   {{0x9914177b,0x6e201948,0x0cdc01e1,0x64460c22}},	//   льві, cumb, _lẹyẹ_, hwhi, 
   {{0x660c78d0,0x644402b9,0xdd9001d3,0x7644007f}},	//   dsak, kwhi, _ھوں_, vwiy, 
   {{0x47bc015b,0x7644022f,0x660c00e2,0xdb040821}},	//   ্দনী, wwiy, esak, tokä, 
   {{0x7644556c,0x64450a47,0xcfe42b1b,0x660c0af9}},	//   twiy, dwhi, _গৌড়_, fsak, 
   {{0x660c286b,0xdb0401b8,0x07b4007b,0x3218002b}},	// [3bde0] gsak, rokä, اهقة_, _āryo_, 
   {{0x76460c23,0x64440072,0x77e8024c,0x00000000}},	//   rwiy, fwhi, _илоҳ_, --, 
   {{0x660c0588,0x6e220c24,0x76460c25,0xdb04005b}},	//   asak, zumb, swiy, pokä, 
   {{0x6e220c26,0x91e42e91,0x76440100,0x00000000}},	//   yumb, годе, pwiy, --, 
   {{0xf1b80032,0x64440374,0x942402dd,0x66dc01bf}},	//   вҡа_, awhi, _әмбе, rækø, 
   {{0x6e220c27,0x24500014,0xcad4011a,0x59b400cd}},	//   vumb, _ژۆلس, אונת_, ृतिर, 
   {{0x6e20b04c,0x64440204,0xd09400ee,0x00000000}},	//   wumb, cwhi, ышды, --, 
   {{0x6e220c28,0x4fc60c29,0x161c01ad,0xce685211}},	//   tumb, ысла, यूअर_, ерод_, 
   {{0x15e8000d,0xb0340022,0xcd040798,0x00000000}},	//   _झूमर_, умқә, лчни, --, 
   {{0x6e220c2a,0x01d60c2b,0x26180c2e,0x0cdc0241}},	//   rumb, _موقع_, यूटी_, _yẹyẹ_, 
   {{0x660e0c2c,0x91e4013e,0x217402e8,0x00000000}},	//   zsak, _роҷе, _тутр, --, 
   {{0xdcb0278f,0x6e220c2d,0x660e0c2e,0x00000000}},	//   تىپ_, pumb, ysak, --, 
   {{0x6e20e765,0xbc641075,0x98b80055,0x7d2401e3}},	//   qumb, _ەمىن_, _āyāt_, årså, 
   {{0x29060c2f,0x2b4c1b5c,0x9e6417b9,0x660e0c30}},	//   úla_, žec_, _خامن, vsak, 
   {{0x4cd000bd,0x660c0986,0x81740375,0xfbd07eee}},	//   _দ্রু, wsak, נגלס_, تتی_, 
   {{0x660e0c31,0x63a800df,0x64440334,0xa6f60c32}},	//   tsak, _ĉeno, vwhi, рзаш, 
   {{0x660e0c33,0xc6a401c6,0x03a40588,0x00000000}},	// [3bdf0] usak, урви, ҳәаҩ_, --, 
   {{0x660e0c34,0x057473c5,0x64440175,0xb6780139}},	//   rsak, دارد, twhi, _şäñg, 
   {{0x660e0c35,0x64440374,0x00000000,0x00000000}},	//   ssak, uwhi, --, --, 
   {{0x660e0c36,0xc304009a,0x00000000,0x00000000}},	//   psak, اباو, --, --, 
   {{0x934002dd,0x62647fa5,0x00000000,0x00000000}},	//   інше, рвла, --, --, 
   {{0x64440334,0xf2042401,0xdcec00de,0xc32c0050}},	//   pwhi, сяцо, ājīg, تٕچ_, 
   {{0x6e240115,0x2000020c,0xa06800ee,0xa3d43425}},	//   _ĥiba, èhi_, тайа_, _вовч, 
   {{0xcf8e0c37,0x9f200116,0xdec400c7,0x00000000}},	//   وژن_, زۈتۈ, қәҵо, --, 
   {{0x63aa0c38,0x1ec80107,0x00000000,0x00000000}},	//   _ijen, ълии_, --, --, 
   {{0x63a80268,0xb27402ec,0xb60801ef,0x00000000}},	//   _hjen, _улуш, _hušá, --, 
   {{0x63a81a84,0x00000000,0x00000000,0x00000000}},	//   _kjen, --, --, --, 
   {{0x63a804ba,0x00000000,0x00000000,0x00000000}},	//   _jjen, --, --, --, 
   {{0x63aa0c39,0x00000000,0x00000000,0x00000000}},	//   _mjen, --, --, --, 
   {{0x998006c8,0x63a80841,0x7e79060b,0x00000000}},	//   mukū_, _ljen, myup, --, 
   {{0x7e7802d1,0x6aac035a,0x63aa0c3a,0xe81c06b1}},	//   lyup, _exaf, _ojen, बंगा_, 
   {{0x63a8124c,0x21dc00d7,0xcc38010f,0xb9e800ec}},	//   _njen, _oňho_, _יעצט, _مڙسن_, 
   {{0x7ae60c3b,0x46e40228,0x61ec0077,0x00000000}},	// [3be00] _igit, рдун_, íall, --, 
   {{0x1da40490,0xdb0400e4,0x00000000,0x00000000}},	//   गचित, jokú, --, --, 
   {{0x7ae401af,0x998410ac,0x63a80200,0x13080108}},	//   _kgit, _ملکو, _bjen, вней_, 
   {{0x63a81711,0x799c2f99,0x7e780784,0x998002b5}},	//   _cjen, lirw, kyup, kukū_, 
   {{0x63aa0c3c,0x7ae4020c,0x996000e2,0xd25000f2}},	//   _djen, _mgit, _mūžu_, تنش_, 
   {{0x63aa0c3d,0x799c8293,0xdce00166,0x00000000}},	//   _ejen, nirw, kilı, --, 
   {{0x50660c3e,0x7ae60c3f,0x63a8037e,0x161c02ab}},	//   ртла, _ogit, _fjen, यंकर_, 
   {{0x63aa0c40,0x7ae60c41,0x799e0c42,0xdce0d673}},	//   _gjen, _ngit, hirw, oklė, 
   {{0x799ca996,0x9f440248,0x6e940120,0xdce000c0}},	//   kirw, _mulè_, сипу, nklė, 
   {{0x63a80841,0x7ae40d63,0x9f440241,0x00000000}},	//   _zjen, _agit, _lulè_, --, 
   {{0x799e0c43,0x7ae406df,0xac9896ec,0xebd8611f}},	//   dirw, _bgit, انجا_, лдош_, 
   {{0x63a8003d,0x81c8015b,0x2fc000ae,0x7e780055}},	//   _xjen, _রূপ_, _óig_, byup, 
   {{0xc3300302,0x799c0433,0x2bc800bc,0x7e780055}},	//   חור_, firw, रतबा, cyup, 
   {{0x7ae4152d,0x799e0c44,0xcbe40276,0x1ce4031c}},	//   _egit, girw, _кции, _ཨུར_, 
   {{0x87d4007b,0xec1400f1,0xfbd000ec,0x0b889665}},	//   لغرا, _اوبد, _ڪتو_, _аспи_, 
   {{0x799c0810,0xc9240154,0x996000ef,0x00000000}},	//   airw, য়েত_, _gūžu_, --, 
   {{0x799c44c8,0x6b9e0c45,0x9f440200,0x00000000}},	// [3be10] birw, misg, _sulë_, --, 
   {{0x63a81505,0x6b9e0c46,0x799c0230,0xb6080118}},	//   _sjen, lisg, cirw, _sušá, 
   {{0x63a81b24,0x04660c47,0x7ae4003e,0x48a8084c}},	//   _pjen, штам, _ygit, _штим_, 
   {{0x6b9e0c48,0x9f44036e,0x00000000,0x00000000}},	//   nisg, _vulë_, --, --, 
   {{0x63aa0c49,0xf99016d0,0x161c000d,0x00000000}},	//   _vjen, _ربی_, _पियर_, --, 
   {{0x69d544a6,0x6b9e0c4a,0x61441b14,0x0cdc0ca8}},	//   nmze, hisg, сека, _gẹgẹ_, 
   {{0x63aa0c4b,0xd34407d6,0x6b9c1427,0xdb0400d7}},	//   _tjen, _گینه_, kisg, rokú, 
   {{0x65760c4c,0x1f64beef,0x63aa0c4d,0x6b9c0ffb}},	//   _hozh, ским, _ujen, jisg, 
   {{0x799cf324,0x6b9c7197,0x657405c7,0x68e40455}},	//   yirw, disg, _kozh, _oghd, 
   {{0x63ba0c4e,0x7ae40013,0x224e0c4f,0x5928025c}},	//   lown, _sgit, _isek_, ྣུབས_, 
   {{0x61ea0c50,0x44320c51,0x61e00194,0x65740cf4}},	//   _huel, ntx_, _iill, _mozh, 
   {{0x61ea0c52,0x6b9e0c53,0x63ba0c54,0xdce00006}},	//   _kuel, gisg, nown, yklė, 
   {{0x799e0c55,0x61e20c56,0x2da808e7,0x61e8005c}},	//   tirw, _kill, òweò_, _juel, 
   {{0x61e08ba9,0x60c002f6,0xad5800a7,0xedf4d712}},	//   _jill, _kylm, _връх_, _بيوگ, 
   {{0x63b814cf,0x7ae60c57,0x61e8f36f,0x15b80ed0}},	//   kown, _tgit, _luel, ңызы_, 
   {{0x61e051dc,0x7ae42dab,0x799e0c58,0x61e80156}},	//   _lill, _ugit, sirw, _ouel, 
   {{0x63ba0c59,0x9f460c5a,0x61ea0c5b,0x57a40032}},	// [3be20] down, _vulè_, _nuel, ашҡа, 
   {{0x61e20c5c,0xd46a0c5d,0x645800b0,0xb4b401e0}},	//   _nill, лизе_, āwin, ҡиҡә, 
   {{0x61ea0c5e,0x224c007f,0xdce00006,0x63b8025c}},	//   _auel, _asek_, rklė, fown, 
   {{0x61e20c5f,0x61ea0c60,0x96b800f7,0x2ab4063f}},	//   _aill, _buel, _бугу_, ụbe_, 
   {{0x61e20c61,0x61ea0c62,0x20040327,0xd9f807af}},	//   _bill, _cuel, _awli_, ्ठित_, 
   {{0x61ea0c63,0x61e20c64,0x20040042,0x50c800fd}},	//   _duel, _cill, _bwli_, лыйм_, 
   {{0x44318589,0x01300491,0x224e0c65,0x63ba0c66}},	//   ctx_, سعود, _esek_, bown, 
   {{0x61ea0c67,0x7f4404a9,0x63b8068f,0x61e20c68}},	//   _fuel, ملىق_, cown, _eill, 
   {{0x61ea0c69,0x61e20c6a,0x224c07ab,0xbdf5e5ea}},	//   _guel, _fill, _gsek_, یریا_, 
   {{0x61e20c6b,0xfb3405f5,0x20040142,0x10a400d8}},	//   _gill, үнээ, _fwli_, _лизн, 
   {{0x6440006a,0x6b9dad57,0x61ea0c6c,0xe08400c6}},	//   _âlit, tisg, _zuel, _وجمي, 
   {{0x61e80198,0x5184074d,0x6608010e,0xbb940108}},	//   _yuel, _куçа, _çekg, зающ, 
   {{0x61e0006c,0x6b9e0c6d,0x753c2634,0x3ea800d0}},	//   _yill, risg, _obrz, čitú_, 
   {{0x61e09a05,0xe81c06ab,0x63b8033f,0xcdd40114}},	//   _xill, _फिदा_, zown, _уцењ, 
   {{0x65740745,0x9f440098,0x2d8c9a14,0x63b80009}},	//   _rozh, _sulé_, mhde_, yown, 
   {{0x9f440418,0x0a684727,0x00000000,0x00000000}},	//   _pulé_, _брои_, --, --, 
   {{0xe81c02e5,0x65760c6e,0x36d41b0a,0x00000000}},	// [3be30] बूजा_, _pozh, зотр, --, 
   {{0x9f44026c,0x61e8557b,0x68e60c6f,0x090455a8}},	//   _vulé_, _ruel, _ughd, _учим, 
   {{0x61ea0c70,0x02a41cd1,0x63ba0c71,0x2d8c0108}},	//   _suel, әрем, town, ihde_, 
   {{0x61e20c72,0x61ea0c73,0x224c01c4,0xf4840137}},	//   _sill, _puel, _psek_, чуун, 
   {{0x61e81948,0x63b8068f,0x7dcc4e9b,0x61e20c74}},	//   _quel, rown, løse, _pill, 
   {{0x61e96c2a,0x61e14cc0,0x161c000d,0x63b8033f}},	//   _vuel, _qill, _पितर_, sown, 
   {{0x61e804e6,0x397c025d,0x00000000,0x00000000}},	//   _wuel, רטונ, --, --, 
   {{0x61e85bae,0x61e20c75,0x224c356c,0x238401d9}},	//   _tuel, _will, _tsek_, _بٔرِ, 
   {{0x61e14abb,0x66080209,0x224c020c,0x61e800c5}},	//   _till, _çekd, _usek_, _uuel, 
   {{0x161c1533,0x61e12ac9,0x2d8c0597,0x00000000}},	//   यूटर_, _uill, ghde_, --, 
   {{0x5baa0c76,0x7dcc0217,0x673c127b,0x6e2001bf}},	//   иком_, jøse, _obsj, armb, 
   {{0x0cdc0248,0xdb9402bf,0x9d080154,0x00000000}},	//   _bẹbẹ_, ішнь, ললেন_, --, 
   {{0x6441713d,0x8a100014,0x00000000,0x00000000}},	//   _älif, وَِت, --, --, 
   {{0x451c02f5,0x3f9c03a0,0x2d8c8a45,0x00000000}},	//   ন্তক_, liuu_, chde_, --, 
   {{0x9a68036b,0xa3b8012c,0x48e00108,0x977400d8}},	//   _چمبل_, घका_, дорв, оѓај, 
   {{0x3f9c0270,0xb17c00df,0x0c400014,0x6c7421f3}},	//   niuu_, _miĥa, _کھیَ, _хушх, 
   {{0xd62844e2,0x07a129be,0xab2810e0,0x27ec01e4}},	// [3be40] розе_, фатн, _اسىل_, ĉena_, 
   {{0x7c7c1e38,0xdd240024,0x779450f0,0x9f94010e}},	//   _ይመስል_, _lūži, _کیرا, lýäs_, 
   {{0x186a0c77,0x92e807d8,0xd2a400d4,0x00000000}},	//   _тани_, адеб_, _кiль, --, 
   {{0xd628026a,0xdce000e2,0x2d8c036e,0x03a00117}},	//   _коме_, eklī, zhde_, михо, 
   {{0x451c009e,0x00000000,0x00000000,0x00000000}},	//   ন্ধক_, --, --, --, 
   {{0x753c0bb8,0x1139097f,0x2d8c0240,0x41e000d4}},	//   _ubrz, ряды_, xhde_, міща, 
   {{0x651000d1,0xb6240150,0xfc25053e,0x00000000}},	//   _سۈنئ, _ﺭﻉ_, _تح_, --, 
   {{0x2d8c0369,0xd344036b,0x00000000,0x00000000}},	//   whde_, _گیچه_, --, --, 
   {{0x8d680b3e,0xdd2400c0,0x9f94010e,0x161c012d}},	//   ајна_, _dūži, dýäs_, यूचर_, 
   {{0x66082c44,0x63a801e4,0x50440982,0x2174030d}},	//   _çeke, _ĉeni, _мезб, _нухр, 
   {{0x60cc03f9,0x8ff88971,0x3cb0010b,0x98b80171}},	//   ƙama, _ضرار_, дйэр, _mapē_, 
   {{0xdd240064,0x9980013a,0x00000000,0x00000000}},	//   _gūži, fuků_, --, --, 
   {{0x7fd430fb,0x67d40364,0x0dc81d4a,0x49b80b24}},	//   _וואס_, ҷову, _куки_, لاسد_, 
   {{0x7dcd2264,0x00000000,0x00000000,0x00000000}},	//   tøse, --, --, --, 
   {{0x67d44bf5,0x00000000,0x00000000,0x00000000}},	//   зову, --, --, --, 
   {{0x6d4a0c78,0x491402f8,0xddc80118,0x36e80116}},	//   leda, _भएको_, dveř, ەرەپ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3be50] --, --, --, --, 
   {{0x6d4a0c79,0x2bc80c70,0x48640395,0x00000000}},	//   neda, रतवा, _дъмб, --, 
   {{0x2910a781,0x6d48017a,0x88800271,0x00000000}},	//   maza_, ieda, _غیرن, --, 
   {{0x2910325f,0x6d4a0c7a,0x872415b0,0xed800023}},	//   laza_, heda, _بعدم, _ይገበር_, 
   {{0x6d4a0c7b,0x672c003e,0x823400f2,0x93101eeb}},	//   keda, mgaj, ترضا, رووش, 
   {{0x88dcfebc,0x6d481326,0x994400d0,0x672e0c7c}},	//   _ব্যক, jeda, _kôš_, lgaj, 
   {{0x6d4a0c7d,0x25a00165,0xc20c01d9,0x00000000}},	//   deda, mihl_, رٔژ_, --, 
   {{0x6234f64e,0x2d9c02ce,0x00000000,0x00000000}},	//   _небу, _amve_, --, --, 
   {{0x60b400dd,0x6d480165,0x00000000,0x00000000}},	//   _کمائ, feda, --, --, 
   {{0x6d4a0c7e,0x8d7404a9,0x29120c7f,0x3f9c0093}},	//   geda, كاپا, jaza_, siuu_, 
   {{0x29120c80,0x116801d5,0x02ec00af,0x9f4401ef}},	//   daza_, _دللی_, _छलाह_, _hulí_, 
   {{0x2910084c,0x98680139,0x6d4800c5,0xdb040306}},	//   eaza_, _añğa_, aeda, boký, 
   {{0x29120c81,0xdea15a4c,0x15c00ed1,0x69cc00af}},	//   faza_, _سیدی, ﯩﻼﺭﺩ, _दीही, 
   {{0x29120c82,0x6d4a0c83,0x8df8011a,0x672c0210}},	//   gaza_, ceda, _ההסת, egaj, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe81c04fa,0x2ab40521,0x186808ca,0xdb040254}},	//   _फिरा_, ụba_, _ғами_, nokü, 
   {{0x29103dd4,0xbac801d9,0x00000000,0x00000000}},	// [3be60] baza_, _گژھن_, --, --, 
   {{0x291068d7,0x672e0c84,0xd9d00136,0x00000000}},	//   caza_, agaj, _سەزگ, --, 
   {{0xd78a0c85,0x58d800fe,0x59d0000d,0x00000000}},	//   _هندو_, _ব্ৰী, _दीयर, --, 
   {{0x6d4a0c86,0x55e40107,0xd1cc0092,0x00000000}},	//   zeda, _номб, ብዎት_, --, 
   {{0xed80044e,0x6d489fe0,0x98b80618,0x5928025c}},	//   _ይገብር_, yeda, _tapē_, _སྐོས_, 
   {{0xd468223e,0xc690008f,0x395800e2,0xdb040306}},	//   _лиге_, _טאר_, ndrs_, voký, 
   {{0x6d4a0c87,0x04420c88,0x3958005f,0x63a800e8}},	//   veda, _перн, idrs_, _ňene, 
   {{0x29120c89,0x9f44003a,0x6d4a0c8a,0x6fb40b6c}},	//   zaza_, _aulâ_, weda, بمبا, 
   {{0x6d4a0c8b,0x291044c8,0xdb040419,0xfe6c0133}},	//   teda, yaza_, hokó, ۆدی_, 
   {{0xdb04457c,0x6d4a0c8c,0x29100117,0x37c4015b}},	//   roký, ueda, xaza_, ্দির, 
   {{0xfe6e0c8d,0xdb04d830,0x2bc83cbe,0x00000000}},	//   ندی_, soký, रतला, --, 
   {{0x29120c8e,0xb17c0115,0xdb040210,0x395800de}},	//   waza_, _kiĥo, dokó, edrs_, 
   {{0x29120c8f,0x6d4a0c90,0x8d84010b,0x5fa000db}},	//   taza_, peda, _нукд, _جەيم, 
   {{0x2d9c6df0,0x6d4a0c91,0x00000000,0x00000000}},	//   _umve_, qeda, --, --, 
   {{0x29117d2d,0xf990038b,0x1ce40327,0x27ec00df}},	//   raza_, ابُ_, _ཨུག_, ĉeno_, 
   {{0x2911614b,0x37c416a4,0x3ff8010f,0x830400eb}},	//   saza_, ељуб, מפלע, _লঞ্চ_, 
   {{0x672c23db,0x6b8e0c92,0xfb38007b,0xeaf80073}},	// [3be70] rgaj, _ilag, _رأيت_, ंडीत_, 
   {{0x6b8c000a,0x29100472,0xdb0400e4,0x98680139}},	//   _hlag, qaza_, bokó, _uñğa_, 
   {{0xc8f8107c,0xb7c80116,0x00000000,0x00000000}},	//   ्रीम_, زبېك_, --, --, 
   {{0x2b580295,0xd6d8013e,0x00000000,0x00000000}},	//   ndsc_, стӣ_, --, --, 
   {{0xa2280d30,0x45a03e52,0x64b4022e,0x00000000}},	//   іжка_, _كەرك, nхiz, --, 
   {{0x6b8c4a2f,0xf19407d8,0xa06801ca,0x50a000d1}},	//   _llag, ничь, жака_, چەكل, 
   {{0x6b8c096b,0xdb0457d9,0x00000000,0x00000000}},	//   _olag, tokü, --, --, 
   {{0xdee407d6,0x6b8c01f2,0x00000000,0x00000000}},	//   мойи, _nlag, --, --, 
   {{0xefb40014,0x00000000,0x00000000,0x00000000}},	//   ریٖگ, --, --, --, 
   {{0x6b8e0c93,0xa1140214,0xc0c40092,0x0dc4008e}},	//   _alag, _آوات, _ችጋር_, млый_, 
   {{0x1b4a0c94,0x69c00073,0x00000000,0x00000000}},	//   озни_, लकनी, --, --, 
   {{0x6b8e0c95,0x4c8000d4,0x00000000,0x00000000}},	//   _clag, тлюв, --, --, 
   {{0x5928025c,0x00000000,0x00000000,0x00000000}},	//   _སྐུས_, --, --, --, 
   {{0x57b40574,0x2d5800a8,0x09e06e1e,0xdb043903}},	//   ंव्ह, _ничь_, коян, tokó, 
   {{0xdea00ec9,0xc31004c5,0x6b8c2b00,0xa8640032}},	//   _سیگی, _হানি_, _flag, нерҙ, 
   {{0x290409cc,0xdb04e475,0x0b40022e,0x00000000}},	//   ðlar_, rokó, _анън, --, 
   {{0x7bc40eda,0x9f44004e,0x00000000,0x00000000}},	// [3be80] _ikiu, _mulà_, --, --, 
   {{0xdb04fd89,0x6b8e0c96,0x00000000,0x00000000}},	//   pokó, _zlag, --, --, 
   {{0x7bc404ba,0x6b8c01b9,0xb17c0115,0x00000000}},	//   _kkiu, _ylag, _siĥo, --, 
   {{0xd244010b,0x00000000,0x00000000,0x00000000}},	//   дэки, --, --, --, 
   {{0x7bc401f7,0x8230114f,0x00000000,0x00000000}},	//   _mkiu, نروا, --, --, 
   {{0xf0d405f5,0x6608cae1,0x80bc000d,0x00000000}},	//   нжлэ, _çeka, _लुहे, --, 
   {{0x9f4419f5,0x7bc56887,0x00000000,0x00000000}},	//   _bulà_, _okiu, --, --, 
   {{0x9f4408e5,0x226800bc,0x04401d39,0xed5800d7}},	//   _culà_, átký_, _шесн, doľa_, 
   {{0x03a20c97,0x02c20c98,0x91a4063f,0x6b8c022e}},	//   _рито, _айто, gwọ_, _rlag, 
   {{0x6b8c00ed,0x7bc60c99,0x644001b8,0x6e0001e2}},	//   _slag, _akiu, _älic, پېژن, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x0a6a0c9a,0x7dcc0158,0x00000000,0x00000000}},	//   орги_, røsa, --, --, 
   {{0x6b8e0c9b,0xfe6e0c9c,0xebc40d52,0x3e68129e}},	//   _vlag, _ندو_, _җәнн, _وجهی_, 
   {{0x7dcc17c1,0x7bc40083,0xc8f847b8,0x00000000}},	//   løsn, _ekiu, ्रेम_, --, 
   {{0x6b8d5d79,0x7af41ebd,0x6d5a0c9d,0x07e406a6}},	//   _tlag, _šetš, _iava, дцам, 
   {{0x6d5a0c9e,0x98b800c0,0xab64012d,0x00000000}},	//   _hava, _lapė_, ęższ, --, 
   {{0x6d5a0c9f,0x4ad0069f,0x3cf81a04,0xe69802e8}},	// [3be90] _kava, _सरिव, लुवे_, чваш_, 
   {{0x6d5a0ca0,0x36d4084c,0xf9fc011a,0x996000ef}},	//   _java, тоур, _והזמ, _tīšu_, 
   {{0x69c60ca1,0xdedc044e,0xf804010b,0xc31000fe}},	//   _ikhe, _ሓዘን_, _ичян, _হাবি_, 
   {{0xc79401ed,0x63a80115,0x87040592,0x4ad01fc4}},	//   _کھڑا_, _ĉens, _تبدل, _सराव, 
   {{0x2169c9c2,0x6d840428,0x6d599c86,0x9f440241}},	//   зили_, _eòai, _oava, _nulá_, 
   {{0x6d5a0ca2,0x20544358,0x9f900051,0x00000000}},	//   _nava, етир, _vơí_, --, 
   {{0x69c5c8ba,0x208802e8,0xd5bc80ee,0x00000000}},	//   _mkhe, яйки_, ्तरज, --, 
   {{0x6d5a0ca3,0x1ce40327,0x3328010a,0x645400e5}},	//   _aava, _ཨུཏ_, _оцун_, _iszi, 
   {{0x6d5a0ca4,0x69c4d146,0x9f4419f5,0xfd6400a2}},	//   _bava, _okhe, _vulà_, _girỳ, 
   {{0x7bc40c86,0x69c60ca5,0xc8f802ab,0xed580419}},	//   _skiu, _nkhe, ्रोम_, toľa_, 
   {{0x6d5a0ca6,0xdc6834ac,0x7dcc01bf,0x4c80009d}},	//   _dava, чанд_, bøsn, глэв, 
   {{0x6d58035a,0x00000000,0x00000000,0x00000000}},	//   _eava, --, --, --, 
   {{0xbe84b991,0x6d5a0ca7,0x3f8c2672,0x6f6414af}},	//   _تجاو, _fava, _ilgu_, _جهنم, 
   {{0x64560ca8,0x0cdc01e1,0xd1000709,0x7f5803e3}},	//   _oszi, _kẹlẹ_, रुपण_, lduq, 
   {{0xd7f0007b,0x69940108,0x00000000,0x00000000}},	//   اكر_, трях, --, --, 
   {{0x6d5a0ca9,0x7bc4e396,0x69c54b80,0x7f591b31}},	//   _zava, _ukiu, _ekhe, nduq, 
   {{0x6d5a0caa,0xcf9000c8,0x69c41132,0x4b20005b}},	// [3bea0] _yava, אטן_, _fkhe, _смыв, 
   {{0x6d584aed,0x00000000,0x00000000,0x00000000}},	//   _xava, --, --, --, 
   {{0x98a495fa,0x3f8d96a4,0x63a801e4,0x5344009b}},	//   _чине, _olgu_, _ĉenr, ехла, 
   {{0xd05801e4,0x9f49aa3c,0x8cb4010f,0x0874010f}},	//   _petɾ, _òkès_, תּמא_, _נעכט_, 
   {{0x6b9c00db,0xd774113e,0x6455b962,0x1db01025}},	//   èrgi, _قاڭع, _eszi, ीकात, 
   {{0x3f8e0cab,0x826000f1,0x00000000,0x00000000}},	//   _algu_, اهون, --, --, 
   {{0x6d5a0cac,0x8fe401af,0x00000000,0x00000000}},	//   _rava, нцид, --, --, 
   {{0x6d580839,0x00000000,0x00000000,0x00000000}},	//   _sava, --, --, --, 
   {{0x6d58a6b1,0x6454010a,0x0dc873c3,0x98b80064}},	//   _pava, _zszi, зуни_, _tapė_, 
   {{0x6d5a0cad,0x50940063,0xeff80092,0x00000000}},	//   _qava, _пређ, ፈረው_, --, 
   {{0x6d5a0cae,0x0ca8016c,0x69c40589,0x7f58058a}},	//   _vava, ятии_, _rkhe, bduq, 
   {{0x6d585553,0x69c406a3,0xd5bc033f,0x7dcc072b}},	//   _wava, _skhe, ्तुओ, løsl, 
   {{0x9e9407d6,0x00000000,0x00000000,0x00000000}},	//   _لاوچ, --, --, --, 
   {{0x3a2400e5,0x9f8001e1,0x00000000,0x00000000}},	//   ámpa_, bóó_, --, --, 
   {{0xac945cf3,0x00000000,0x00000000,0x00000000}},	//   _шакш, --, --, --, 
   {{0x6b9c017a,0xbb440114,0x00000000,0x00000000}},	//   ërgd, _бећк, --, --, 
   {{0xc5080150,0x00000000,0x00000000,0x00000000}},	// [3beb0] كتال_, --, --, --, 
   {{0x69c4136f,0x645401ed,0x00000000,0x00000000}},	//   _ukhe, _pszi, --, --, 
   {{0xe8942075,0xf99012fc,0x7b080162,0x00000000}},	//   _рань, _دبي_, _ístí, --, 
   {{0x970000d1,0x660a0caf,0x00000000,0x00000000}},	//   _نېفى, _çeko, --, --, 
   {{0x66e40073,0x161c28fe,0x00000000,0x00000000}},	//   _कणिक_, _पिएर_, --, --, 
   {{0x6145df03,0x25a4008c,0xa0a60cb0,0x64541180}},	//   тека, _öll_, калд, _tszi, 
   {{0xd12c774e,0xdb04006a,0x1fb475a2,0xf2c4104e}},	//   زمي_, mokö, ксир, ксән, 
   {{0x20e40b45,0x3994008e,0xd00c007b,0x1f64011b}},	//   rɓi_, _iäse_, آلي_, тким, 
   {{0x236c0030,0x66200166,0x00000000,0x00000000}},	//   _inej_, _üzkı, --, --, 
   {{0x661c0113,0x1ce4025c,0x3995efd2,0xdb040793}},	//   _mvsk, _ཨུད_, _käse_, nokö, 
   {{0x80240214,0x236c036e,0x6298002f,0x00000000}},	//   _سرام, _knej_, lzwo, --, 
   {{0x661e0cb1,0x6fcc002d,0xdb040023,0x399400d7}},	//   _ovsk, jûch, mikë, _mäse_, 
   {{0x62980036,0x0cdc01e1,0xdd940124,0xdb040240}},	//   nzwo, _jẹjẹ_, _иады, likë, 
   {{0x7f580150,0xacac00ef,0x62980139,0x00000000}},	//   _ﺩﻴل_, _šķeļ, izwo, --, 
   {{0x661c0efa,0xdb040023,0xa3c04ca3,0x9f800784}},	//   _avsk, nikë, ँवा_, lóñ_, 
   {{0x98b800b0,0x6ce402bf,0x5a640117,0x00000000}},	//   _hapī_, _січе, _акиб, --, 
   {{0x66096898,0x6b9c13eb,0xdb04036e,0xa8840150}},	// [3bec0] _çekl, ërge, hikë, _ەلپى, 
   {{0x62980034,0x236e0cb2,0x98b800b8,0xdb040200}},	//   dzwo, _anej_, _japī_, kikë, 
   {{0xdb040240,0x6fcc0129,0x00000000,0x00000000}},	//   jikë, bûch, --, --, 
   {{0x24b82586,0x1ce40327,0xdb04036e,0xc3440395}},	//   رننگ_, _ཨུན_, dikë, вяше_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x86b00046,0x4a98008f,0xdb0570fd,0x236d3fb4}},	//   _тәсі, וינג, fikë, _enej_, 
   {{0x5314016c,0xf04401ed,0x7f4415bf,0x00000000}},	//   _афзу, اعتی, چلىق_, --, 
   {{0x7f440075,0x00000000,0x00000000,0x00000000}},	//   نلىق_, --, --, --, 
   {{0x11e4022e,0x00000000,0x00000000,0x00000000}},	//   _ажам, --, --, --, 
   {{0x10d801d5,0xddc8054e,0x39940139,0x4234011a}},	//   _قباغ_, rveş, _yäse_, _בנמל_, 
   {{0xdc4400b0,0x00000000,0x00000000,0x00000000}},	//   tūāt, --, --, --, 
   {{0xbfc804b3,0xdb04033b,0x6f38030d,0x00000000}},	//   _قانە_, nikè, _чӳкĕ, --, 
   {{0x2fc4342f,0x9b742ba5,0x8d740a11,0x0cdc0ca8}},	//   momg_, اڭىز_, _لاغا, _kẹkẹ_, 
   {{0x8c640e46,0x9f800252,0xe7742737,0xdd040356}},	//   _атид, lóð_, _kıçı, ăpăr, 
   {{0x62980334,0xc310015b,0x5dd8010f,0x00000000}},	//   zzwo, _হাসি_, _אַקס, --, 
   {{0x2fc40770,0x3c740a1e,0x39940139,0x37042773}},	//   nomg_, _יתום_, _räse_, ичув, 
   {{0xdb0402d3,0x2b88000f,0xf65000cf,0x6b9c068c}},	// [3bed0] zikë, _rûch_, يئك_, èrgu, 
   {{0x660845e3,0x2d8c00a2,0x00000000,0x00000000}},	//   _çekm, nkde_, --, --, 
   {{0x60cc02a8,0x42940208,0xeab001d3,0x00000000}},	//   ƙami, _đựơc_, _خٹک_, --, 
   {{0x9f80008c,0x2bc8033f,0x629801c7,0x3994007c}},	//   jóð_, रतटा, tzwo, _väse_, 
   {{0x26c820d3,0x62980e78,0x00000000,0x00000000}},	//   _سطحی_, uzwo, --, --, 
   {{0xdb04044e,0xd24c0131,0x20d401ce,0x32b800c6}},	//   tikë, سنى_, лійс, خدمة_, 
   {{0x10a01638,0x9fc8013d,0x20c40166,0x00000000}},	//   йишн, нгка_, ыйкм, --, 
   {{0xdb0402d3,0x236c020b,0x21280bbc,0x9f800d12}},	//   rikë, _unej_, şah_, góð_, 
   {{0x98b802b5,0xdb040240,0x00000000,0x00000000}},	//   _papī_, sikë, --, --, 
   {{0x9f440004,0xdb04036e,0xe7740205,0x00000000}},	//   _sulä_, pikë, _fıçı, --, 
   {{0xdb060cb3,0x21f8020c,0xe7740139,0xad5807e6}},	//   liké, _hèh_, _gıçı, трых_, 
   {{0xe81c00e1,0x00000000,0x00000000,0x00000000}},	//   _फिजा_, --, --, --, 
   {{0x9d44c011,0x290407c4,0x98b800b0,0xf9c42ab4}},	//   _белд, ılan_, _tapī_, لحسی, 
   {{0x21f804fb,0x99d42688,0x684002d3,0xceb0011a}},	//   _mèh_, اقست, _ኣካላት, _פיג_, 
   {{0x21f80066,0xdb04007f,0x66080432,0x7e980150}},	//   _lèh_, yikè, _çekj, _ﺘﻁﻠﻕ_, 
   {{0xc7a00021,0xb8dc02e5,0xdb04000d,0x00000000}},	//   биск, _आख_, tokõ, --, 
   {{0x48e00131,0x16642401,0x9664005b,0xbc840133}},	// [3bee0] _қоюв, ывам, ыкае, _سمکۆ_, 
   {{0x4a980a1e,0xb9380150,0x00000000,0x00000000}},	//   _נייג, _جۋسا_, --, --, 
   {{0x54359f66,0x775c001f,0x0d14008f,0x94242bb6}},	//   طرار, ህበረሰ, רקעט_, умее, 
   {{0x813400d1,0xdb04035b,0x00000000,0x00000000}},	//   ۇسىز_, pokõ, --, --, 
   {{0x696450b5,0xdb04033b,0xe7740205,0x00000000}},	//   _صدیق, rikè, _sıçı, --, 
   {{0x645800b0,0xe77403e3,0xc0dc0b82,0x00000000}},	//   āwir, _pıçı, _ናሆም_, --, 
   {{0xdd401418,0x85380375,0xe7745043,0x8fd00166}},	//   _eŋŋi, _רגלי, _qıçı, бәдә, 
   {{0x7dcc20e4,0x0838008f,0x3b00025c,0xdce80118}},	//   løsh, געקל, _nfiq_, žněn, 
   {{0x2fc40770,0xdb140100,0x8d843be4,0xdb04005b}},	//   romg_, _ijyè, гунд, inkä, 
   {{0x3b020cb4,0x91e60cb5,0x80bc00bc,0x4090008e}},	//   _afiq_, _созе, _लुके, ррәт, 
   {{0x3a200077,0x0574011a,0x9df800db,0x00000000}},	//   _avip_, אגים_, ннөт_, --, 
   {{0x81c80183,0x2b4c01e4,0x0c8400fb,0x00000000}},	//   _ৰূপ_, ĵeco_, _ҡыйм, --, 
   {{0xbea000f3,0x00000000,0x00000000,0x00000000}},	//   _лацк, --, --, --, 
   {{0xdb04005b,0x00000000,0x00000000,0x00000000}},	//   enkä, --, --, --, 
   {{0x074400ee,0x3cf8011a,0x7b080332,0x00000000}},	//   лхам, _אלונ, ísté, --, 
   {{0x8cc81fc4,0xdb0400e5,0x00000000,0x00000000}},	//   _सुयो, yiké, --, --, 
   {{0x3cf823e9,0xe9d8014b,0x00000000,0x00000000}},	// [3bef0] लुके_, _имич_, --, --, 
   {{0x21f80066,0xc6d401ec,0xdb0401f4,0x00000000}},	//   _rèh_, _ەتست, ankä, --, 
   {{0x320405b1,0x21f8020c,0xdc240023,0x046443a2}},	//   _atmy_, _sèh_, _ተሰሚዑ, ытам, 
   {{0x2a6a0cb6,0xdb05247e,0x9878008f,0x644000a2}},	//   _krab_, tiké, _סארט, _älim, 
   {{0x2b4801e7,0x00000000,0x00000000,0x00000000}},	//   _mbac_, --, --, --, 
   {{0x94240075,0x65960cb7,0x7dcc1924,0x00000000}},	//   _ھوقۇ, _тагу, røsk, --, 
   {{0x9f941f71,0xd5ac7fc5,0x2b4800cf,0x21f8020c}},	//   ишиш, _تہٕ_, _obac_, _wèh_, 
   {{0xd3440722,0x44320cb8,0x9f84f6e1,0x21f80214}},	//   _نیمه_, mux_, ргид, _tèh_, 
   {{0x399404f3,0x290006d6,0x2a680070,0x7dcc0fac}},	//   _läsa_, _ofha_, _nrab_, løsi, 
   {{0x224e0cb9,0x1c460cba,0x8d743004,0x3b00025c}},	//   _ipek_, аном, لاپا, _sfiq_, 
   {{0x2a6a0cbb,0x44307636,0x39940267,0x9f540212}},	//   _arab_, nux_, _näsa_, _ввеч, 
   {{0x29001682,0xda64330e,0x2b4803cb,0xa3d400dc}},	//   _afha_, авми, _cbac_, हति_, 
   {{0xafc40c75,0x2a680e21,0x4430025c,0x8f6800e5}},	//   _اينى, _crab_, hux_, _جلنے_, 
   {{0x3a200a2e,0x44300227,0x2a683a4b,0xdbd000a2}},	//   _vvip_, kux_, _drab_, küçl, 
   {{0xa3d4107c,0x2a6954cd,0x380401f0,0xdd2400ef}},	//   हता_, _erab_, собҳ, cīšu, 
   {{0x44300003,0xcc3800c8,0x3a200194,0x224e0cbc}},	//   dux_, _סעפט, _tvip_, _opek_, 
   {{0x2a6a0cbd,0x44320cbe,0xca7401ec,0x2610000d}},	// [3bf00] _grab_, eux_, _кәрі_, दीली_, 
   {{0x8cc801ad,0x2004022e,0xd468010b,0x44300135}},	//   _सुडो, _otli_, кизе_, fux_, 
   {{0xc8c40014,0xdbd00205,0x00000000,0x00000000}},	//   _نوٝن_, güçl, --, --, 
   {{0x21243223,0xb17c0115,0xd26401c4,0x00000000}},	//   _adlh_, _liĥt, икей, --, 
   {{0x44320cbf,0x200405f7,0x00000000,0x00000000}},	//   aux_, _atli_, --, --, 
   {{0x44320cc0,0x00000000,0x00000000,0x00000000}},	//   bux_, --, --, --, 
   {{0x224e0cc1,0xdde00213,0x7f800451,0x00000000}},	//   _epek_, _şuşa, ڪلين, --, 
   {{0x9f440077,0x7f800131,0x99440030,0x027800bc}},	//   _zulú_, قلىن, _nôž_, _šíře_, 
   {{0x3f6406ed,0x20042ba3,0x59c421b8,0x2b4898a1}},	//   рињо_, _etli_, लकार, _rbac_, 
   {{0x10a401d5,0xd5c41157,0x6d0000bc,0x00000000}},	//   _кизн, वविज, लुंग_, --, 
   {{0x9f44011c,0x00000000,0x00000000,0x00000000}},	//   _lulù_, --, --, --, 
   {{0x80bc11b1,0x0ba402bf,0x2a68560d,0x00000000}},	//   _लुटे, ршом, _prab_, --, 
   {{0x37cc00bd,0xbc640214,0x00000000,0x00000000}},	//   লগার, همین_, --, --, 
   {{0x6608ec90,0x1ea89b78,0x00000000,0x00000000}},	//   _çeki, _حامي_, --, --, 
   {{0x44300548,0x3cf00306,0x56400023,0x00000000}},	//   xux_, ňavé_, _ይርከብ, --, 
   {{0x2a680135,0x8aa44d75,0x66f40150,0x00000000}},	//   _trab_, _врод, спау, --, 
   {{0x9f440270,0x5928025c,0x2a680098,0xa93557f6}},	// [3bf10] _pulú_, _སྐམས_, _urab_, _лепш, 
   {{0x4430be3f,0x09c80451,0x7dcc03b2,0xa3a8134e}},	//   tux_, _جذبي_, tøsi, गोन_, 
   {{0x224e0cc2,0xc2f80154,0x00000000,0x00000000}},	//   _spek_, আরসি_, --, --, 
   {{0x44320cc3,0xc7640075,0xdb14010e,0x386c005c}},	//   rux_, _ئادى, _okyý, ædre_, 
   {{0x44320cc4,0x00000000,0x00000000,0x00000000}},	//   sux_, --, --, --, 
   {{0x7dcc0174,0x00000000,0x00000000,0x00000000}},	//   pøsi, --, --, --, 
   {{0x2c4c0134,0xdb1400a2,0x24e40eac,0x4430025c}},	//   _yɛde_, _akyý, _প্রহ, qux_, 
   {{0xf8b8011a,0xa29412fa,0x00000000,0x00000000}},	//   יפוי_, _лабі, --, --, 
   {{0x63aa0cc5,0x645001e4,0xfe740139,0x00000000}},	//   _imen, ŭdiĝ, рүл_, --, 
   {{0x63a80334,0x00000000,0x00000000,0x00000000}},	//   _hmen, --, --, --, 
   {{0x2004003d,0x63a819b3,0x44220cc6,0x07140d79}},	//   _utli_, _kmen, _jvj_, तराव_, 
   {{0x63a8012c,0x6e2005b1,0xdc6800fb,0xbbb400bc}},	//   _jmen, bsmb, _ҡалд_, ीवेक, 
   {{0x63a9b9ed,0x69c00122,0xde040114,0x4a400395}},	//   _mmen, člen, _упли, пняв, 
   {{0x63aa0cc7,0x44220cc8,0xd9440063,0x99d4007b}},	//   _lmen, _ovj_, љеви, إتحا, 
   {{0xb9020cc9,0xcd74011a,0x00000000,0x00000000}},	//   _तर_, _לעסק_, --, --, 
   {{0x07a012b4,0x63a80a73,0xc7a08046,0x4bf80375}},	//   пасн, _nmen, писк, _גלקס, 
   {{0x7e7802b9,0x442001b9,0x00000000,0x00000000}},	// [3bf20] nxup, _avj_, --, --, 
   {{0x63aa0cca,0x44200208,0x00000000,0x00000000}},	//   _amen, _bvj_, --, --, 
   {{0x130800a8,0x63a8010a,0x986401c8,0x00000000}},	//   гней_, _bmen, _اُجه, --, 
   {{0x7794006c,0x63aa0ccb,0x00000000,0x00000000}},	//   _بیرا, _cmen, --, --, 
   {{0x63a8031c,0xe1e401a9,0x7d00032e,0x00000000}},	//   _dmen, da波i_, _ofns, --, 
   {{0x399401f1,0x76454972,0x776426ef,0x7c2001bf}},	//   _mäso_, mtiy, ldix, _ovnr, 
   {{0x50660ccc,0x63a85c74,0x7e680254,0x764403e0}},	//   стла, _fmen, _argp, ltiy, 
   {{0x77660ccd,0x4341cc35,0x63a80036,0x932405af}},	//   ndix, _несв, _gmen, _درسن, 
   {{0xa3d409d9,0x8778008f,0x7e780472,0x76b406be}},	//   हतर_, ראפי, gxup, bəyş, 
   {{0x63a80038,0x604001f2,0x7645fb5b,0xdb040109}},	//   _zmen, _ịmet, itiy, sikì, 
   {{0xe6d42d8f,0x76460cce,0x8fa40e92,0x799c0175}},	//   _दर्ज, htiy, _лаже, dhrw, 
   {{0x7d000115,0x63a80175,0xcb080024,0xdb0401e1}},	//   _efns, _xmen, ыход_, bikí, 
   {{0x8d8517ea,0x77640327,0x37c003d4,0x9ba08e98}},	//   _гуйд, ddix, ্ষাৰ, بەيى, 
   {{0xb17c01e4,0x776416b8,0x0b8800d1,0xac9401ec}},	//   _ziĥr, edix, _әски_, _малш, 
   {{0xe7380184,0xbc6404fb,0x00000000,0x00000000}},	//   һең_, _همون_, --, --, 
   {{0x7c8007d6,0x6d4a0ccf,0x76460cd0,0x00000000}},	//   _хуше, lfda, ftiy, --, 
   {{0xaa5987e6,0x63a80ab0,0x76460cd1,0x44200b9d}},	// [3bf30] _типу_, _rmen, gtiy, _svj_, 
   {{0x63a88a1c,0x44200e02,0x6d4801d5,0x00000000}},	//   _smen, _pvj_, nfda, --, 
   {{0x490c038e,0x44200113,0x7dcc037e,0x63a80334}},	//   _त्यो_, _qvj_, møst, _pmen, 
   {{0x69d584a8,0x7dcc26ff,0x76440067,0x06c800fe}},	//   llze, løst, btiy, লেষি, 
   {{0x9fb40270,0x3d28013b,0xb604013a,0x00000000}},	//   _tāú_, _wɔwɔ_, _psář, --, 
   {{0x216a0cd2,0x6d4801f5,0xdd98033b,0x00000000}},	//   рики_, jfda, npňt_, --, 
   {{0x660e0cd3,0xf434c38a,0x63aa0cd4,0x69d4002f}},	//   lpak, _нерэ, _tmen, ilze, 
   {{0x644488fe,0xdfd00491,0x63aa0cd5,0x69d403fa}},	//   mthi, بيع_, _umen, hlze, 
   {{0x64440013,0x660e0cd6,0x6d49372b,0x7dcc03b2}},	//   lthi, npak, ffda, køst, 
   {{0x64460cd7,0x5bd0085c,0xb65c010f,0x6608036e}},	//   othi, सत्व, רדזש, _çeku, 
   {{0x61e0a061,0x660c2796,0x7dcc00b5,0x764401c4}},	//   _ihll, hpak, døst, ztiy, 
   {{0x64460cd8,0x660e0cd9,0x69d56836,0x7e6801fa}},	//   ithi, kpak, elze, _trgp, 
   {{0x64460cda,0xdb04025a,0x76441571,0x660d2169}},	//   hthi, tikâ, xtiy, jpak, 
   {{0x657406d6,0x64460cdb,0x660c1cf1,0xa2b01025}},	//   _nnzh, kthi, dpak, _आइन्, 
   {{0x61e001ab,0x6444bd71,0x65646a7d,0x23c80303}},	//   _mhll, jthi, ddhh, िकाद, 
   {{0x76440cfe,0x65745e39,0x69d40165,0x6b9c1196}},	//   ttiy, _anzh, alze, chsg, 
   {{0x660c7004,0x64460cdc,0x77660cdd,0x7dcc12e8}},	// [3bf40] gpak, ethi, rdix, bøst, 
   {{0x76450616,0x69a401af,0x644402d2,0x00000000}},	//   rtiy, _нлыҡ, fthi, --, 
   {{0x395a0cde,0x76460cdf,0x64440175,0x660c00f2}},	//   mers_, stiy, gthi, apak, 
   {{0x61e16094,0x76440986,0xdb0402e2,0x660c01bf}},	//   _ahll, ptiy, nikà, bpak, 
   {{0x39580204,0x76457cfc,0x64452403,0x00000000}},	//   oers_, qtiy, athi, --, 
   {{0x902807dd,0xdb040113,0x60c000d7,0x00000000}},	//   ациа_, hikà, _bxlm, --, 
   {{0xcf9815ed,0x39582543,0x61e001ab,0x64440208}},	//   ији_, iers_, _dhll, cthi, 
   {{0x395a0ce0,0x26102871,0x61e0062c,0xa37c0042}},	//   hers_, दीकी_, _ehll, _phŵe, 
   {{0x39582f75,0x660803ee,0xdb040109,0x2f2c0024}},	//   kers_, _çekt, dikà, jėgų_, 
   {{0x2d98006d,0x39580003,0x3dc400ec,0x00000000}},	//   óre_, jers_, يويٽ_, --, 
   {{0x395a0ce1,0x61ec03a2,0x6b9c54fb,0x8cc80b02}},	//   ders_, ïale, thsg, _सुशो, 
   {{0xbb940b32,0x660e0ce2,0xaa580116,0xfbd001f7}},	//   дающ, ypak, биму_, َتَ_, 
   {{0x395a0ce3,0x00000000,0x00000000,0x00000000}},	//   fers_, --, --, --, 
   {{0x64460ce4,0x60cc75c0,0x00000000,0x00000000}},	//   ythi, şame, --, --, 
   {{0x7dcc2ab7,0x660e0ce5,0xb868041b,0xed5800d7}},	//   røst, wpak, ојте_, meľ_, 
   {{0x660e0ce6,0x7dce0ce7,0x64440218,0xdbd00205}},	//   tpak, søst, vthi, _rüçh, 
   {{0x2b5800a8,0x64460ce8,0x660cdfad,0xa9540220}},	// [3bf50] mesc_, wthi, upak, _екпі, 
   {{0x395a0ce9,0x64460cea,0x660e0ceb,0x2b5a0cec}},	//   cers_, tthi, rpak, lesc_, 
   {{0x660e0ced,0xdb051bcc,0x64445461,0x61e00042}},	//   spak, liká, uthi, _rhll, 
   {{0x64460cee,0x2b5800a8,0x660e0cef,0x61e20cf0}},	//   rthi, nesc_, ppak, _shll, 
   {{0x27ea0cf1,0x64460cf2,0x660c3209,0xdb060cf3}},	//   mman_, sthi, qpak, niká, 
   {{0x27e82178,0x6b9c02d3,0x64440174,0xa504010a}},	//   lman_, ërgj, pthi, _хӏал, 
   {{0x27ea0cf4,0x6444009a,0xed5800d7,0x5f2800db}},	//   oman_, qthi, deľ_, бойм_, 
   {{0x27ea0cf5,0x2b580311,0x0ec40037,0x1e84005b}},	//   nman_, jesc_, _लडखड, злим, 
   {{0x27ea0cf6,0x2b5a0cf7,0x395887c4,0x50f0008e}},	//   iman_, desc_, yers_, мзәт, 
   {{0x27ea0cf8,0xdb041a09,0x61e0062c,0xed580419}},	//   hman_, diká, _uhll, geľ_, 
   {{0x27ea0cf9,0x3959a167,0x44300175,0xe7bc521a}},	//   kman_, vers_, nrx_, ्काप, 
   {{0x27ea0cfa,0xdb060cfb,0x395a0cfc,0x7e7400aa}},	//   jman_, fiká, wers_, _ولاړ_, 
   {{0x395a0cfd,0xd9c000cc,0xed5800d7,0xada803c7}},	//   ters_, োগসম, beľ_, صدیق_, 
   {{0xdca50275,0x395a0cfe,0x2d580276,0x996000e2}},	//   _нали, uers_, _мичь_, _būšu_, 
   {{0x27ea0cff,0x2b58084c,0xa8640184,0x44300175}},	//   fman_, besc_, мерҙ, jrx_, 
   {{0x2b580276,0x3f9c013f,0x225c020c,0xdb040cde}},	//   cesc_, nhuu_, kwwk_, biká, 
   {{0x41c841ac,0x395a0d00,0xa3c19e1e,0xc7a01de6}},	// [3bf60] िवास, pers_, ुवन_, хитк, 
   {{0x27ea0d01,0x3f9c0270,0x25a8004b,0x7c7c0023}},	//   aman_, hhuu_, يدلي_, _ክመስል_, 
   {{0x27ea0d02,0x3f9c022f,0x39940267,0x7894179e}},	//   bman_, khuu_, _läsk_, _غیرض, 
   {{0x27e8c843,0x966400f3,0xd394013d,0x00000000}},	//   cman_, _екме, чәгә_, --, 
   {{0x3f9c0a55,0x443027ac,0x00000000,0x00000000}},	//   dhuu_, arx_, --, --, 
   {{0xf0d405f5,0x2b580276,0x60400521,0xdb14003b}},	//   мжлэ, zesc_, _ịmat, _åbær, 
   {{0x8248069c,0x9f440793,0xdb0403f7,0x9878008f}},	//   _ሓይልታ, _fulü_, ziká, מאַט, 
   {{0x9f4401b8,0x6624013d,0x2334014b,0x00000000}},	//   _gulü_, _ätkä, _охур, --, 
   {{0xed580038,0x2b580276,0xdb0402fb,0x99800024}},	//   teľ_, vesc_, xiká, nukų_, 
   {{0x27e8662e,0xd9c402ab,0x00000000,0x00000000}},	//   zman_, लकोट, --, --, 
   {{0x27ea0d03,0x2b58084c,0x6440025a,0x9f440548}},	//   yman_, tesc_, _älit, _culó_, 
   {{0x27ea0d04,0x3f9c8928,0xdb0428cb,0x4fe87e32}},	//   xman_, chuu_, tiká, _умен_, 
   {{0x27ea0d05,0x2b5800a8,0xdfa426a0,0xed5800d0}},	//   vman_, resc_, _تحلي, peľ_, 
   {{0xdb060d06,0x2b5800a8,0x5cc402dd,0x6441715c}},	//   riká, sesc_, ясөз, _ålig, 
   {{0xfce0026a,0x2b580311,0x27e9cd87,0x67d60d07}},	//   _пољо, pesc_, tman_, дову, 
   {{0x27ea0d08,0xb7640cef,0x00000000,0x00000000}},	//   uman_, нтуй, --, --, 
   {{0x27e888c4,0x00000000,0x00000000,0x00000000}},	// [3bf70] rman_, --, --, --, 
   {{0x27ea0d09,0xc86444b2,0xe858010a,0x05d01896}},	//   sman_, _етми, _даош_, رماڭ, 
   {{0x44260d0a,0x27e83462,0x6fcc0a59,0x12d40150}},	//   én_, pman_, ावां, _ﺘﻜﻨﻭ, 
   {{0x27ea0d0b,0x998000c0,0x00000000,0x00000000}},	//   qman_, bukų_, --, --, 
   {{0xefcc044e,0x2d9c00cc,0xc20c0014,0x00000000}},	//   _ኣለዋ_, _olve_, ھٔژ_, --, 
   {{0x7124278f,0x00000000,0x00000000,0x00000000}},	//   ىرىل, --, --, --, 
   {{0x3f9c0099,0x764001f4,0x00000000,0x00000000}},	//   thuu_, _ämyr, --, --, 
   {{0x2d9c045f,0x389c0bd9,0xa3a805f9,0xf4200183}},	//   _alve_, מיונ, गोश_, মূহৰ_, 
   {{0x021401d9,0xdb041e0c,0x9fb400b8,0x261001f9}},	//   _رٹاں_, likç, _tāþ_, दीची_, 
   {{0xa3d4068f,0x3f9e0d0c,0x644001b8,0xa3a8447d}},	//   हतक_, shuu_, _älis, गोर_, 
   {{0xefcc069c,0x3f9c0ba7,0xdca401a9,0x313408ca}},	//   _ኣለዉ_, phuu_, фани, _чехр, 
   {{0x2d9e0d0d,0xdea01ae5,0x00000000,0x00000000}},	//   _elve_, _لیبی, --, --, 
   {{0x9d44113e,0x399400a2,0x9fb400b8,0x8ba00131}},	//   _желд, _häsi_, _māü_, тияж, 
   {{0x64560d0e,0x3994b6a5,0xadbc010a,0x00000000}},	//   _opzi, _käsi_, _лачi, --, 
   {{0xc30003d4,0x00000000,0x00000000,0x00000000}},	//   _উজনি_, --, --, --, 
   {{0xdca404a9,0xdb0405d1,0x99800153,0x5fdc0118}},	//   _наһи, dikç, tukų_, मतिल, 
   {{0x6454143f,0x558a0d0f,0x98bc05d1,0x19c40063}},	// [3bf80] _apzi, обам_, ıtı_, _обим, 
   {{0xfe641272,0xca340302,0xdb040112,0x00000000}},	//   _ید_, _קניה_, hnkü, --, 
   {{0x28760d10,0x93440153,0xaa580092,0x00000000}},	//   _зыяр, днее, ያደርጋ, --, 
   {{0xefcc069c,0xb20800c7,0x998000c0,0x00000000}},	//   _ኣለዎ_, зҵаз_, pukų_, --, 
   {{0x92587c3c,0xed80044e,0xdb055898,0x00000000}},	//   تشار_, _ክገብር_, mikä, --, 
   {{0xdb060d11,0x32340023,0x00000000,0x00000000}},	//   likä, _ኣይረኣ, --, --, 
   {{0xa3d809fd,0xefcc044e,0x61ec03a2,0x00000000}},	//   _ठीक_, _ኣለው_, ïala, --, 
   {{0x7f580369,0xdb04023a,0x662801a8,0x9fb40055}},	//   geuq, nikä, _óskö, _gāü_, 
   {{0xeff002d3,0xc7d4011a,0x9980013a,0x00000000}},	//   _ግዝየ_, ווקי_, jsků_, --, 
   {{0x60ccf725,0xdb048234,0x86780375,0xc0d80023}},	//   şama, hikä, קריו, ቕሞም_, 
   {{0xfe6c6694,0xdb040108,0x207400c0,0x00000000}},	//   هدی_, kikä, _пуцё, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9f440268,0xc4d80316,0xbfc801ec,0x3fc8872f}},	//   _tulò_, _भर्ख, _بالە_, _بدلی_, 
   {{0x2d9c005c,0x291401d9,0xb9e400d4,0x00000000}},	//   _ulve_, ڈہکھ_, віси, --, 
   {{0x47880a8f,0x4bd800c6,0x4794fe18,0x29140014}},	//   осам_, _وبعد_, وجرس, وہکھ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3bf90] --, --, --, --, 
   {{0xdb040790,0xc4d80063,0x00000000,0x00000000}},	//   tikç, ође_, --, --, 
   {{0x7bc8004a,0xe3540166,0xdb05549b,0x00000000}},	//   éjug, етлэ, bikä, --, 
   {{0xa3a8006d,0xdb0403ee,0x6b8c0158,0xa5f8fcc3}},	//   गों_, rikç, _joag, _нему_, 
   {{0x6b8e0d12,0x25a00334,0xdd2400c0,0x00000000}},	//   _moag, phhl_, _lūši, --, 
   {{0x6b8e0d13,0xe044b3ef,0xa068e8a7,0x26d801a9}},	//   _loag, енки, зака_, _iyso_, 
   {{0x7f5805da,0x9fb4002b,0x5f2800db,0x00000000}},	//   teuq, _tāü_, пойм_, --, 
   {{0x9e64e169,0x661c00b5,0x6b8cf272,0x3994000d}},	//   евид, _kwsk, _noag, _väsi_, 
   {{0xdb040267,0x7204ecfe,0x934400db,0x00000000}},	//   nikå, _لوقم, _سىلۇ, --, 
   {{0x6b8c0421,0x5fe0000d,0x3bc40166,0x00000000}},	//   _aoag, _पठवल, dıqa_, --, 
   {{0x6b8c5bae,0x0c205d9f,0x00000000,0x00000000}},	//   _boag, лмэн, --, --, 
   {{0x6b8e0d14,0x661e0d15,0x27fa0d16,0x4c8002bf}},	//   _coag, _owsk, _nisn_, улюв, 
   {{0x661c0218,0x45e00248,0x6b8c00ad,0xdd9426ee}},	//   _nwsk, _díẹ̀_, _doag, _пады, 
   {{0x9d44086f,0x82fc031c,0x00000000,0x00000000}},	//   _чекд, _ཞུའུ_, --, --, 
   {{0xa3c20d17,0x6b8c0607,0x26d80009,0x3804013e}},	//   ुवा_, _foag, _ayso_, тобҳ, 
   {{0x1ae60d18,0x7bc8004a,0xdbd00037,0xdb040210}},	//   _пойм, éjud, nüül, rnkó, 
   {{0x29040abc,0xdb042045,0x27f8067c,0x7bc4009f}},	// [3bfa0] ılar_, rikä, _disn_, _ijiu, 
   {{0x7ae48cdb,0x6b8c011c,0xdb041073,0x00000000}},	//   _izit, _zoag, sikä, --, 
   {{0xdb040821,0x64a40022,0x00000000,0x00000000}},	//   pikä, ҭаӡа, --, --, 
   {{0x8c180302,0x03a1fbc7,0xddc800d0,0x00000000}},	//   פוני, лихо, steň, --, 
   {{0x0ecc0401,0x051c00fe,0x8230009a,0x00000000}},	//   _हुंड, _পাৰৰ_, هروا, --, 
   {{0x7ae400ec,0x67c40024,0x35c401f0,0x00000000}},	//   _mzit, mėja, _рагҳ, --, 
   {{0x84e20d19,0x67c40006,0x00000000,0x00000000}},	//   _борж, lėja, --, --, 
   {{0x7ae4180e,0xdd240006,0x22640724,0xbfa4005b}},	//   _ozit, _rūši, äpkä_, етье_, 
   {{0x7ae60d1a,0x03a0016c,0x67c40006,0x6b8e0d1b}},	//   _nzit, _сито, nėja, _roag, 
   {{0x7bc400ec,0x6b8c9663,0x39940037,0x00000000}},	//   _ajiu, _soag, _käsu_, --, 
   {{0x7ae419f8,0xef1000f7,0x6b8e0d1c,0x8cc8020d}},	//   _azit, _күйө, _poag, _सुखो, 
   {{0x67c40006,0x3994b306,0x06c80154,0x4fe800db}},	//   kėja, _mäsu_, লেটি, _эмен_, 
   {{0x7bc40098,0x6b8c06d9,0x7ae60d1d,0xbe3002dd}},	//   _djiu, _voag, _czit, _مىنب, 
   {{0x7ae43dc1,0x67c402d5,0x6c542cb9,0x6b8c016b}},	//   _dzit, dėja, _акку, _woag, 
   {{0x7ae449d6,0x6b8e0d1e,0x75f40213,0x00000000}},	//   _ezit, _toag, cüzə, --, 
   {{0x7bc40200,0x9fb40055,0x67c400c0,0x00000000}},	//   _gjiu, _yāñ_, fėja, --, 
   {{0x67c40006,0x27f8007c,0x66f401ec,0x6b9c0200}},	// [3bfb0] gėja, _visn_, тпау, ërgu, 
   {{0x27f80204,0xdb04143a,0xa3a80210,0x00000000}},	//   _wisn_, rikå, गोई_, --, 
   {{0x34941171,0x00000000,0x00000000,0x00000000}},	//   лафр, --, --, --, 
   {{0x67c40024,0xe704036b,0x12880133,0x83640966}},	//   bėja, _جسدی, ژمنی_, عدال, 
   {{0x216831d5,0x614407fb,0xc66800fd,0xe2980798}},	//   дили_, вела, _эшне_, ќал_, 
   {{0x236805ce,0x63a80083,0x0188034b,0x00000000}},	//   žaj_, _ŋend, ящей_, --, 
   {{0xe7c4045e,0x84700020,0x9ac41418,0xc44401d3}},	//   ্ষীয, _የሚሆን_, muŋŋ, _سیشن_, 
   {{0x3994049f,0x9ac40337,0xcf8c01e2,0x00000000}},	//   _häst_, luŋŋ, يژن_, --, 
   {{0xfe18033f,0xdbd00037,0x00000000,0x00000000}},	//   पींस_, rüül, --, --, 
   {{0x69c40564,0x9ac404ba,0x39940267,0x00000000}},	//   _njhe, nuŋŋ, _jäst_, --, 
   {{0x7ae401d3,0xe0440124,0xdbd00254,0x00000000}},	//   _szit, _шьаҿ, püül, --, 
   {{0x399404f3,0xdcb80075,0x8eb002f2,0x9fb4002b}},	//   _läst_, згүч_, امیش, _tāñ_, 
   {{0x9ac42252,0x79580107,0x00000000,0x00000000}},	//   kuŋŋ, нявӣ_, --, --, 
   {{0x67c40006,0x3f8c0100,0x399401e6,0xdb0402fb}},	//   vėja, _hogu_, _näst_, nikú, 
   {{0x3f8c007d,0xdca5a2bc,0x7bc4003e,0xeac001ec}},	//   _kogu_, _шаки, _tjiu, _ғұрп, 
   {{0x5a945411,0x67c40006,0x7bc401f7,0x9aa4708e}},	//   _ароф, tėja, _ujiu, _لمبو, 
   {{0x3f8c1326,0x7ae60905,0x399404f3,0xa3d400af}},	// [3bfc0] _mogu_, _uzit, _bäst_, सकन_, 
   {{0x67c402d5,0x3f8e0d1f,0x9ac40083,0x9704074d}},	//   rėja, _logu_, guŋŋ, гiуш_, 
   {{0x499804ae,0x69c009a8,0xdb0402fb,0x67c40024}},	//   _חשיב, člet, dikú, sėja, 
   {{0x3f8c071b,0x30160d20,0x67c40153,0x00000000}},	//   _nogu_, қдир, pėja, --, 
   {{0xc2200f1c,0x60ce0d21,0x39940267,0x1278007b}},	//   لکلو, şaml, _fäst_, بحاث_, 
   {{0x3994049f,0x68e800bc,0xea980055,0x00000000}},	//   _gäst_, řede, _heṃ_, --, 
   {{0x3f8c05a1,0x39940a40,0x4fc40166,0x2ee00010}},	//   _bogu_, _häss_, ксиа, _šif_, 
   {{0x6a881574,0x35c400c7,0xf8f403d4,0x3f8c03e0}},	//   _jëfë, _раҳҳ, _অভাৱ_, _cogu_, 
   {{0xa3c04802,0x3f8e0d22,0x0dc8016c,0x00e401b9}},	//   ुवर_, _dogu_, дуни_, _یتمی, 
   {{0x33240327,0x3994000d,0x54e42e05,0x814000f7}},	//   _hemx_, _mäss_, _कराए_, _ەنەن, 
   {{0xeff8001f,0xbd64005b,0xab940150,0x41240117}},	//   ገረው_, трые_, гині, _рохо_, 
   {{0x32040270,0x316c01fa,0x3f8c054e,0x2fc0002e}},	//   _kumy_, _hadz_, _gogu_, _ñig_, 
   {{0x5fa01b56,0xee9404fb,0x1a1001d5,0xdb2000e5}},	//   _دەيم, _حداک, یژیس, étáz, 
   {{0x3f8c0023,0xa2d80a8a,0x00000000,0x00000000}},	//   _zogu_, _फुफ्, --, --, 
   {{0x316e0d23,0xcbe40276,0x87d401d5,0x3f8c0139}},	//   _madz_, _иции, نغرا, _yogu_, 
   {{0xddd8007f,0x5cf4004e,0x00000000,0x00000000}},	//   _apwň, _сячу, --, --, 
   {{0x69c4052f,0x6a880de2,0x2b48004e,0xe55400d8}},	// [3bfd0] _tjhe, _dëfë, _icac_, лкањ, 
   {{0x6b9d15e1,0x316c04e6,0x00000000,0x00000000}},	//   lksg, _nadz_, --, --, 
   {{0x2a68070d,0x29000521,0x399401e6,0xe89400c0}},	//   _hsab_, _igha_, _väst_, _сань, 
   {{0x9990010b,0x32040332,0x67c40024,0xe2140214}},	//   _atyň_, _bumy_, mėjo, هبتع, 
   {{0x6b9c0196,0xf991f37c,0x67c40153,0x39944268}},	//   iksg, _طبی_, lėjo, _gäss_, 
   {{0x69d60d24,0x3f8c19f5,0x2a68022e,0xa4d400d4}},	//   noze, _sogu_, _msab_, _богі, 
   {{0xd12e0d25,0xe05400c6,0x3f8e0d26,0x555001d9}},	//   سمي_, اختب, _pogu_, _چھۅر, 
   {{0x69d60d27,0x6d5c00c5,0x6b9c01f5,0xa3d60d28}},	//   hoze, õran, jksg, _собч, 
   {{0x69d60d29,0x2a6807ab,0x32042320,0x29020d2a}},	//   koze, _nsab_, _gumy_, _ogha_, 
   {{0x63ba0d2b,0x236c0007,0x6b9c0d27,0x67c40006}},	//   liwn, _haej_, eksg, kėjo, 
   {{0x629862af,0x2a6801d5,0x41dc03ba,0x67c40064}},	//   lywo, _asab_, _पीएस, jėjo, 
   {{0x290005db,0x29cc01a2,0x2b4806d9,0x67c40024}},	//   _agha_, hľad_, _ccac_, dėjo, 
   {{0x20060d2c,0x539804ac,0xdce003ee,0x62980368}},	//   _huli_, גירו, rklı, nywo, 
   {{0x20060d2d,0x186806bb,0xcae4052f,0x69d60d2e}},	//   _kuli_, наги_, ығыҙ_, goze, 
   {{0x2b48004e,0x21240327,0x7c84013e,0x67c40064}},	//   _fcac_, _melh_, _шуде, gėjo, 
   {{0x29000098,0x236c0109,0x39940036,0x6824023a}},	//   _egha_, _naej_, _päss_, рьёз, 
   {{0x20060d2f,0x69d60d30,0x00000000,0x00000000}},	// [3bfe0] _luli_, boze, --, --, 
   {{0x20060d31,0xfe180d0a,0x67c40024,0x69d40356}},	//   _ouli_, पीएस_, bėjo, coze, 
   {{0x200404fb,0x6298030d,0x32042344,0xea980055}},	//   _nuli_, eywo, _sumy_, _teṃ_, 
   {{0x320402f0,0xdb04002f,0x00000000,0x00000000}},	//   _pumy_, ankö, --, --, 
   {{0x75840502,0x20060d32,0x236c0399,0x212401fa}},	//   _پیام, _auli_, _daej_, _belh_, 
   {{0x20040c8a,0xc690011a,0x00000000,0x00000000}},	//   _buli_, _האש_, --, --, 
   {{0x2124067c,0x6b9c2112,0x63b803cb,0x818400db}},	//   _delh_, yksg, biwn, انىق_, 
   {{0x20060d33,0x236c0097,0x63b80034,0x6298017a}},	//   _duli_, _gaej_, ciwn, bywo, 
   {{0x200401c4,0x69d60d34,0x00000000,0x00000000}},	//   _euli_, yoze, --, --, 
   {{0x20060d35,0xadb4024c,0x0ca80166,0x00000000}},	//   _fuli_, рбош, етми_, --, 
   {{0x20060d36,0x2a6801e6,0x69d60d37,0xdb040036}},	//   _guli_, _ssab_, voze, chkë, 
   {{0x69d49464,0xbfc800db,0x707c0092,0x00000000}},	//   woze, _كانە_, ተደረጉ_, --, 
   {{0x69d60d38,0x6b9d9d06,0x20040161,0xa3a80412}},	//   toze, rksg, _zuli_, गोट_, 
   {{0x200423db,0x1ea84609,0xad2400d1,0x32340023}},	//   _yuli_, _جامي_, _ئىغى, _ኣይሰኣ, 
   {{0x69d60d39,0x6d580099,0x2a6800d5,0x6298033f}},	//   roze, _ibva, _wsab_, zywo, 
   {{0x69d40eb4,0x2a680457,0xe7c40f22,0x2d8c01e6}},	//   soze, _tsab_, ্ষ্য, ljde_, 
   {{0x9b24052f,0x2a6822b9,0x69d60d3a,0xc3840248}},	// [3bff0] _өфөл, _usab_, poze, _gẹ̀ẹ, 
   {{0xe534656c,0x236c0007,0x2900063f,0xd8b401ed}},	//   режь, _saej_, _ugha_, اگیا_, 
   {{0x58fc025c,0x2d8c01f5,0xdb04007c,0x00000000}},	//   _དུགས_, ijde_, rnkö, --, 
   {{0xae04c881,0x21240561,0x6298033f,0x20060d3b}},	//   रदान_, _selh_, tywo, _ruli_, 
   {{0x20060d3c,0xe1242310,0x6d5a0d3d,0x63b8062c}},	//   _suli_, амли, _obva, riwn, 
   {{0x20060d3e,0x0584defb,0x6298152c,0xa5c46943}},	//   _puli_, _сумм, rywo, _төбе, 
   {{0xa0a45540,0xd00c021a,0x20042f3b,0x62980356}},	//   райд, ولو_, _quli_, sywo, 
   {{0x20060d3f,0x6d5a0d40,0xddca0d41,0xa2940845}},	//   _vuli_, _abva, dveš, _кабі, 
   {{0xdb04069c,0x44200457,0x6d5801c4,0x00000000}},	//   shkë, _hwj_, _bbva, --, 
   {{0x32943306,0x20060d42,0x442001d4,0x21240ba1}},	//   _الْأ, _tuli_, _kwj_, _uelh_, 
   {{0xdb84593c,0x20060d43,0xa2d828fe,0x00000000}},	//   агни, _uuli_, _फुत्, --, 
   {{0x6d58014f,0x5bb4011c,0x00000000,0x00000000}},	//   _ebva, рсоф, --, --, 
   {{0x44200070,0x58fc0135,0x8f980302,0xfe740032}},	//   _lwj_, _དུངས_, _שיני, _сүп_, 
   {{0x3f9c0014,0xd9440640,0x44d00165,0x98a400c7}},	//   lkuu_, јеви, _oχ_, аиге, 
   {{0xa3d426d9,0xd70464e1,0x44200218,0x7d00127b}},	//   सका_, изви, _nwj_, _igns, 
   {{0x3f9d8ab3,0x8bd001d5,0xc7a00d1d,0xc38401e1}},	//   nkuu_, _وقوش, оиск, _tẹ̀ẹ, 
  
   {{0x3f9c0093,0x00000000,0x00000000,0x00000000}},	// [3c000] ikuu_, --, --, --, 
   {{0x458013d6,0x63a8031c,0xfd800023,0x3f9c0108}},	//   огув, _ċena, _ክወሃቦ_, hkuu_, 
   {{0x44200070,0x3f9e0d44,0x9f500432,0x00000000}},	//   _cwj_, kkuu_, _şaýy_, --, 
   {{0x6d5c0030,0x00000000,0x00000000,0x00000000}},	//   ôraz, --, --, --, 
   {{0x776400cf,0xf6f40214,0xa2d800ab,0x3f9c0067}},	//   meix, _دزدگ, _फुद्, dkuu_, 
   {{0x442001d4,0x764405d9,0x77640137,0x3f9c022f}},	//   _fwj_, muiy, leix, ekuu_, 
   {{0x3f9c058a,0xb64001ec,0x6d5ce523,0xd08401f4}},	//   fkuu_, _ﺍﻉ_, õram, рыли, 
   {{0x77640372,0x9324107f,0x4fc40261,0x00000000}},	//   neix, _خرسن, јска, --, 
   {{0x44200218,0x7c200076,0xd1860d45,0x8d8417a0}},	//   _zwj_, _awnr, _клай, аунд, 
   {{0x44200070,0x3f9c198f,0x409005a2,0x91e4013d}},	//   _ywj_, akuu_, срәт, _тозе, 
   {{0x44200218,0x3f9c058a,0xfc2c009f,0x2d8c007c}},	//   _xwj_, bkuu_, وحَ_, rjde_, 
   {{0x7d00005c,0x00000000,0x00000000,0x00000000}},	//   _egns, --, --, --, 
   {{0x764400c6,0x776400f7,0x00000000,0x00000000}},	//   juiy, deix, --, --, 
   {{0x79a4030d,0x57a401e0,0xcd280214,0xe89400c7}},	//   орсе, ҡытҡ, _شستن_, багь, 
   {{0x776400cf,0x6d480175,0xac5801fe,0x00000000}},	//   feix, mgda, _сайф_, --, 
   {{0x77660d46,0x44200218,0x3cf80302,0xf77000c6}},	//   geix, _rwj_, _בלונ, واق_, 
   {{0x76460d47,0xf1b80327,0xe7383007,0x21e800e4}},	// [3c010] guiy, _omġ_, кең_, húha_, 
   {{0x6d4a0d48,0x60cc0205,0x00000000,0x00000000}},	//   ngda, şami, --, --, 
   {{0x442001d4,0x776400cf,0x67d400ee,0xdce001e4}},	//   _qwj_, beix, _гону, telĉ, 
   {{0x442001d4,0x76440086,0x33d812fa,0x2910012d}},	//   _vwj_, buiy, афію_, lcza_, 
   {{0x4df40dad,0x672c4c8e,0x00000000,0x00000000}},	//   ँगाई_, maaj, --, --, 
   {{0x672cab33,0x44200070,0x660c0309,0x02b49201}},	//   laaj, _twj_, mqak, _अधीन, 
   {{0x6d48089c,0x3f9c02f6,0x7d000077,0x9d440032}},	//   dgda, tkuu_, _rgns, ҙенд, 
   {{0x64460d49,0x672e0d4a,0xaf98023a,0x6d480af9}},	//   muhi, naaj, итых_, egda, 
   {{0x64460d4b,0x660e0d4c,0x3f9e0d4d,0x1d081c7b}},	//   luhi, nqak, rkuu_, лепи_, 
   {{0x3f9c049b,0x6d4a0723,0x1c460814,0x672d8ab3}},	//   skuu_, ggda, бном, haaj, 
   {{0x64460d4e,0x672c6a5d,0x660c0113,0x7644009f}},	//   nuhi, kaaj, hqak, zuiy, 
   {{0x672c0a4d,0x7764004e,0x2910012d,0x00000000}},	//   jaaj, xeix, ecza_, --, 
   {{0x644418a6,0x65640093,0xdb040793,0x7e68007f}},	//   huhi, kehh, mikü, _usgp, 
   {{0x64460d4f,0xdb040793,0x394c6f7b,0x7d000267}},	//   kuhi, likü, üds_, _ugns, 
   {{0x77660d50,0xc05c1540,0x68e80316,0x95980046}},	//   teix, _ሰይጣን_, ředn, қтау_, 
   {{0x81bc2f8b,0xdb04f717,0x64460d51,0x672e0d52}},	//   ীতি_, nikü, duhi, gaaj, 
   {{0x77640228,0xd94510b0,0x54c41cd1,0x660c0472}},	// [3c020] reix, _лепи, әбеб, gqak, 
   {{0x76440d04,0x6444b44a,0xdb040037,0x00000000}},	//   ruiy, fuhi, hikü, --, 
   {{0x64448b14,0xd7ca0d53,0xdb0401b8,0x7764021c}},	//   guhi, _موده_, kikü, peix, 
   {{0x823402d3,0x660c0548,0x9f5c0241,0xdb040210}},	//   _ብተመሳ, bqak, _fiwé_, mikó, 
   {{0x6d480579,0xdb060d54,0x91e41f87,0x6564003e}},	//   ygda, dikü, боде, behh, 
   {{0x64460d55,0x1ae800cc,0x21e80022,0x00000000}},	//   buhi, _গলাই_, túha_, --, 
   {{0xdb060d56,0x61440131,0x0440030d,0xe1e80014}},	//   nikó, زىيە, _нерн, گى۪و_, 
   {{0xef9a0d57,0xdb04d03e,0x7f800131,0xd36c5f32}},	//   ркиш_, gikü, كلىن, _سۇت_, 
   {{0xa3d403f3,0xdb040022,0xe1e801d9,0x74b81408}},	//   सकर_, hikó, دى۪و_, ्पवृ, 
   {{0xd0080114,0x00000000,0x00000000,0x00000000}},	//   _беже_, --, --, --, 
   {{0xdb060d58,0x3d14012d,0x00000000,0x00000000}},	//   bikü, फड़े_, --, --, 
   {{0x2910033f,0x6d48ea00,0x660c0309,0x672c0067}},	//   wcza_, sgda, yqak, xaaj, 
   {{0x644404ce,0x672e0d59,0x6d340b96,0x6e940798}},	//   zuhi, vaaj, _делф, _филу, 
   {{0x64460d5a,0x67c40006,0x29060d5b,0xfe3400c8}},	//   yuhi, mėji, øla_, _פרוי_, 
   {{0x672e0d5c,0x67c40006,0x29101afd,0x499003e6}},	//   taaj, lėji, rcza_, قیکر, 
   {{0x8aa402d5,0x68e8012c,0x6564014b,0x63a80327}},	//   _грод, ředo, wehh, _ċeno, 
   {{0x67c402d5,0x672e0d5d,0x29d4c852,0x64460d5e}},	// [3c030] nėji, raaj, _ويبس, wuhi, 
   {{0x64440325,0x672e0d5f,0x644000d4,0x660c03f0}},	//   tuhi, saaj, _ålik, rqak, 
   {{0x660c1bb7,0x672e0d60,0x82340023,0x6564014f}},	//   sqak, paaj, _ኣይሁዳ, rehh, 
   {{0x67c402d5,0x6564e970,0x672e0d61,0xe944552d}},	//   kėji, sehh, qaaj, _ارکی, 
   {{0xe1f05d35,0x660de94e,0x64460d62,0xdb04d03e}},	//   وست_, qqak, suhi, vikü, 
   {{0xf2d20d63,0x64460d64,0x67c40006,0x634c00e5}},	//   رآن_, puhi, dėji, dőnő, 
   {{0xdb0429ef,0xa2d89e51,0x91c0013d,0x00000000}},	//   tikü, _फुर्, фәтл, --, 
   {{0x2d9a0d65,0x36340244,0x29040205,0x5058030d}},	//   ören_, _برێس, ılay_, ăрлă, 
   {{0x63aa0d66,0xdb060d67,0x67c40024,0xfe7401e0}},	//   _ilen, rikü, gėji, сүл_, 
   {{0x63aa0d68,0x31358d4b,0xdb04162a,0x00000000}},	//   _hlen, _неур, sikü, --, 
   {{0x63a8b429,0xdb060d69,0x693c037e,0x4430037e}},	//   _klen, pikü, _ｆeri, nsx_, 
   {{0x67c40006,0x06f80034,0x5e5858d5,0x63a8525e}},	//   bėji, ्शाव_, _видя_, _jlen, 
   {{0x63aa0d6a,0xdea001d5,0xd3540375,0x75f00166}},	//   _mlen, _آیخی, חירי_, läze, 
   {{0x63aa0d6b,0x6e2406be,0x5ca400f3,0x00000000}},	//   _llen, _çiba, _милб, --, 
   {{0x63aa0d6c,0x18680107,0x2dd8007b,0x00000000}},	//   _olen, шави_, _ابنة_, --, 
   {{0xc0480023,0x27940075,0x36380092,0x00000000}},	//   _ዘይተወ, пшур, _እርግማ, --, 
   {{0xa2d80da5,0x9b88004b,0x4430031c,0x00000000}},	// [3c040] _फुल्, _منګل_, esx_, --, 
   {{0xfaa480e2,0x63aa0d6d,0x7ae60d6e,0x9b442ab4}},	//   _мақо, _alen, _iyit, _انکو, 
   {{0x9424005e,0x130a0d6f,0x5468f99a,0x63a8e4f5}},	//   імде, аней_, раем_, _blen, 
   {{0xdce001a6,0x83800108,0x00000000,0x00000000}},	//   jelč, дыше, --, --, 
   {{0xa6c80451,0xdce00219,0x00000000,0x00000000}},	//   _هوٽل_, delč, --, --, 
   {{0x7ae40230,0x67c40006,0x98b80790,0x00000000}},	//   _myit, vėji, _hapı_, --, 
   {{0xf8be0d70,0x63aa0d71,0xe57004ac,0x98b803ee}},	//   ोपिय, _flen, _אַן_, _kapı_, 
   {{0x63aa0d72,0x7ae4849d,0x44180375,0x7ff016ac}},	//   _glen, _oyit, _כולס, وسيا, 
   {{0x7ae60d73,0x00c4010b,0x00000000,0x00000000}},	//   _nyit, йләк_, --, --, 
   {{0xfe6c00ec,0x67c40024,0xf8bc00cd,0x00000000}},	//   ئدي_, rėji, ोपाय, --, 
   {{0x7ae60d74,0x01d41411,0x63a827a8,0x67c40153}},	//   _ayit, _بولع_, _ylen, sėji, 
   {{0x7ae40796,0x67c40006,0x63a8031c,0xbda000c7}},	//   _byit, pėji, _xlen, зқәҩ, 
   {{0x7ae401aa,0xd1dc001f,0xc330011a,0x00000000}},	//   _cyit, _ንረት_, וור_, --, 
   {{0x7ae402c4,0x2fe800db,0xf1bc102f,0x00000000}},	//   _dyit, _ئىچپ_, ्चिन, --, 
   {{0x7ae60d75,0xdb04033b,0x00000000,0x00000000}},	//   _eyit, rikò, --, --, 
   {{0xa61400d8,0x00000000,0x00000000,0x00000000}},	//   змач, --, --, --, 
   {{0xf1bc00dc,0x00000000,0x00000000,0x00000000}},	// [3c050] ्चान, --, --, --, 
   {{0xa4d401ca,0x44300332,0x00000000,0x00000000}},	//   позі, tsx_, --, --, 
   {{0x63aa0d76,0x98b80139,0x44244bc7,0x00000000}},	//   _plen, _fapı_, èn_, --, 
   {{0x67d54397,0x44300072,0x00000000,0x00000000}},	//   _хому, rsx_, --, --, 
   {{0x4430031c,0x63aa0d77,0xd00401e0,0xc2c8007b}},	//   ssx_, _vlen, үеше_, جبال_, 
   {{0x2d980790,0x216a0d78,0x00000000,0x00000000}},	//   örel_, сики_, --, --, 
   {{0x63aa0d79,0x98b803ee,0x81bc009e,0x0ddc0023}},	//   _tlen, _yapı_, ীতল_, _ሓሊፋ_, 
   {{0x63a8055a,0x65740165,0x00000000,0x00000000}},	//   _ulen, _hazh, --, --, 
   {{0xdd90e0cb,0x657405b8,0x0e600276,0x245403cd}},	//   فوظ_, _kazh, екын, låm_, 
   {{0xc058090b,0x7ae401b2,0x67c40024,0x00000000}},	//   _від_, _ryit, mėju, --, 
   {{0x61e00309,0x7ae4023a,0x67c40024,0x4a280055}},	//   _ikll, _syit, lėju, _āyuṣ_, 
   {{0x65740dd4,0xece801c6,0x60cc3c7a,0x14b4010f}},	//   _lazh, өдөл_, şams, פּיר_, 
   {{0x0ddc044e,0x61e000b5,0x7f58009a,0x67c40024}},	//   _ሓሊፉ_, _kkll, mfuq, nėju, 
   {{0x7ae407a8,0xceb000c8,0x65740286,0xc4a8033f}},	//   _vyit, _איד_, _nazh, चनाओ, 
   {{0x7e78008c,0xdca40b01,0x00000000,0x00000000}},	//   lvup, _хайи, --, --, 
   {{0x4c380302,0xdca49dd6,0x67c40024,0x98b80213}},	//   _התקב, _маһи, kėju, _qapı_, 
   {{0x7ae54f29,0x6575d16e,0x57a401e0,0xd1dc0092}},	// [3c060] _uyit, _bazh, ошҡа, _ንረቱ_, 
   {{0x67c40006,0x1fd000cc,0x00000000,0x00000000}},	//   dėju, াতিস, --, --, 
   {{0x65760d7a,0x499800d9,0x00000000,0x00000000}},	//   _dazh, _השיב, --, --, 
   {{0x61e00986,0x67c400c0,0x00000000,0x00000000}},	//   _akll, fėju, --, --, 
   {{0x65740165,0x91e522d1,0x07a0094e,0x67c40153}},	//   _fazh, поде, _чаян, gėju, 
   {{0x65740165,0x5bbc05db,0x76440009,0x50c80139}},	//   _gazh, ọchị_, mriy, йыйм_, 
   {{0x753c0055,0x152401af,0x00000000,0x00000000}},	//   _idrz, _мєңг, --, --, 
   {{0x5274baa7,0x6574009f,0xb4d813f7,0x67c40153}},	//   _нузу, _zazh, ाथी_, bėju, 
   {{0x83501374,0x4ea5f862,0x67c40064,0x00000000}},	//   _سپلا, ярка, cėju, --, 
   {{0x7644058a,0x00000000,0x00000000,0x00000000}},	//   iriy, --, --, --, 
   {{0x76460d7b,0x9f5c011f,0x41140592,0xddc800e2}},	//   hriy, _diwâ_, _رينج_, kteņ, 
   {{0x76460d7c,0x68e80316,0x9200005f,0x4fb42f84}},	//   kriy, ředk, žāda, _عصار, 
   {{0x76460d7d,0x1e7002dd,0x6d5c01a9,0xa3dc483e}},	//   jriy, _ағыс, еrat, डवत_, 
   {{0x76460d7e,0xe6b80598,0x00000000,0x00000000}},	//   driy, läçä, --, --, 
   {{0x76460d7f,0x9718063f,0x65760d80,0xbd5808c3}},	//   eriy, _ọdụd, _razh, _הכוש, 
   {{0x65740007,0x76460d81,0x00000000,0x00000000}},	//   _sazh, friy, --, --, 
   {{0xc508129d,0x9db404d3,0x6574036e,0xbb3c00d9}},	// [3c070] متال_, _رگیز_, _pazh, _התחז, 
   {{0xda700014,0x67c40024,0x75f000d7,0x00000000}},	//   _شُپ_, vėju, väzc, --, 
   {{0x65760d82,0x7644e381,0x6aa80b1a,0x76480055}},	//   _vazh, ariy, øeff, _ādye, 
   {{0x76460d83,0x61e00023,0x6574030a,0x2130107d}},	//   briy, _skll, _wazh, _žzh_, 
   {{0x27ea0d84,0x9dcc0150,0xf99000f2,0x00000000}},	//   mlan_, _ﮔﯘﯕﺸ, _شبی_, --, 
   {{0x27ea0d85,0xfa780302,0x67c40024,0x661c03ac}},	//   llan_, פעות_, rėju, _itsk, 
   {{0x27e8c62b,0x67c40024,0x7f580240,0x1fb400c0}},	//   olan_, sėju, tfuq, дспр, 
   {{0x27ea0d86,0x238401d9,0xdb060d87,0x753c0010}},	//   nlan_, _تٔرِ, mikö, _zdrz, 
   {{0xdb060d88,0x27ea0d89,0x6e200810,0x7f580240}},	//   likö, ilan_, gpmb, rfuq, 
   {{0x27ea0d8a,0x5ca58ce1,0x61e00113,0x661c0165}},	//   hlan_, диоб, _ukll, _mtsk, 
   {{0x9b440e26,0x27ea0d8b,0xdb040793,0x673c39ca}},	//   وندو, klan_, nikö, _odsj, 
   {{0xfc3c278a,0x7645380f,0x54780302,0xc0d4001f}},	//   čí_, yriy, קטרו, ክክር_, 
   {{0x5f0407d6,0x27ea0d8c,0x64440198,0x76441444}},	//   _ўзла, dlan_, hrhi, xriy, 
   {{0x76460d8d,0x673c0158,0x27e80804,0x68140210}},	//   vriy, _adsj, elan_, _sąda, 
   {{0x661c47c0,0x27ea0d8e,0x38c80214,0xa3dc43d1}},	//   _atsk, flan_, ساسی_, डवा_, 
   {{0x76460d8f,0xdb040793,0xdce000ef,0x00000000}},	//   triy, dikö, celā, --, 
   {{0x76460d90,0x6444000f,0x6d5c08c2,0x9f4c01f4}},	// [3c080] uriy, erhi, òrag, mmeä_, 
   {{0xddc800e2,0x39940166,0x95488370,0xdb04007c}},	//   steņ, _näsx_, تشرق_, fikö, 
   {{0x27ea0d91,0xdb040793,0x76460d92,0xb4d800dc}},	//   blan_, gikö, sriy, ाथे_, 
   {{0x7645d78e,0x27ea0d93,0x96b8009b,0x03a001f0}},	//   priy, clan_, _дугу_, кихо, 
   {{0x64460d94,0x00000000,0x00000000,0x00000000}},	//   arhi, --, --, --, 
   {{0xd01a0d95,0x29cc01f1,0x753c0306,0x9f4c005b}},	//   офи_, eľaj_, _udrz, hmeä_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x24842af5,0x661c01e3,0xd37001c8,0x39940108}},	//   _álma_, _ytsk, _جهر_, _väsy_, 
   {{0xe6b80724,0x8d68147e,0xb8e00327,0x238800bc}},	//   räçä, ојна_, _ཀཿ_, šují_, 
   {{0x27ea0d96,0x68e8012c,0x0f240154,0xdb040037}},	//   zlan_, ředi, _যাওঃ_, nikõ, 
   {{0x27ea0d97,0x8fd00184,0x4f960d98,0x00000000}},	//   ylan_, _үҙҙә, _орду, --, 
   {{0xaab40220,0xe2480150,0xe2180150,0x00000000}},	//   еймі, _ۇﻋﯩﺴ, _ۇﻋﯩﻤ, --, 
   {{0x27ea0d99,0x6d5c00c5,0x2fc40175,0xdb0401d3}},	//   vlan_, õras, mimg_, zikö, 
   {{0x1ea810fe,0x27ea0d9a,0xddc8012c,0x2fc40334}},	//   _عاني_, wlan_, kteř, limg_, 
   {{0x27ea0d9b,0xdce0a9df,0x2d9c0381,0x98a800e2}},	//   tlan_, pelā, _iove_, tabā_, 
   {{0xbc64bd0e,0x2d9cd412,0x2fc40354,0xdb0401b8}},	//   _آمين_, _hove_, nimg_, vikö, 
   {{0x2d9c0a73,0x3a760d9c,0x00000000,0x00000000}},	// [3c090] _kove_, _алыр, --, --, 
   {{0x2d9c1daa,0xdb060d9d,0xe4140276,0x2fc40334}},	//   _jove_, tikö, еджь, himg_, 
   {{0x2d9c0c30,0x64440373,0x9f64013a,0x00000000}},	//   _move_, urhi, _štír_, --, 
   {{0xa2d42dc3,0x2d9e0d9e,0x78a808d7,0xdb04aa88}},	//   ىيات, _love_, ødve, rikö, 
   {{0x661cb78b,0x2fc4010a,0xdb060d9f,0x6444009a}},	//   _utsk, dimg_, sikö, srhi, 
   {{0x2d9e0da0,0x018800c9,0xdb040254,0x26f400cc}},	//   _nove_, ющей_, pikö, _অলপো_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd00c2781,0x2fc4010a,0x0ec800af,0x6814033f}},	//   حلي_, gimg_, ापंड, _lądo, 
   {{0x2d9d1de8,0xb3546103,0x00000000,0x00000000}},	//   _bove_, _شیوا_, --, --, 
   {{0x9f5c011f,0x2d9c123b,0x9c240107,0x00000000}},	//   _diwá_, _cove_, ндод, --, 
   {{0xdca4b6e8,0x2d9c3003,0x31c41f39,0x1be80395}},	//   хани, _dove_, _рств, здни_, 
   {{0xdea00214,0xa3d40073,0x63b80166,0x00000000}},	//   _میبی, सकट_, _çanı, --, 
   {{0x1a660da1,0x2d9c003a,0xe0600133,0x9d44009b}},	//   ریدی_, _fove_, _شێکی, _зелд, 
   {{0x17f86a60,0x00000000,0x00000000,0x00000000}},	//   ्द्व_, --, --, --, 
   {{0xdb040037,0x00000000,0x00000000,0x00000000}},	//   vikõ, --, --, --, 
   {{0x2d9c1326,0xb90800af,0x00000000,0x00000000}},	//   _zove_, _बड_, --, --, 
   {{0xd78801ed,0x9b04144d,0xcb10010f,0xdb040254}},	// [3c0a0] _ہندو_, _язид, _גלח_, tikõ, 
   {{0x2d9c1709,0x3a21294f,0xdce00356,0x06c401c6}},	//   _xove_, _itip_, celă, хгуй_, 
   {{0xe898066d,0x2fc4030d,0x23680115,0xdb040254}},	//   _ہمیں_, yimg_, ĵajn_, rikõ, 
   {{0xf484006c,0x260c02f0,0xfd4800e4,0xcb1000df}},	//   _یازی, _džob_, temỹ, ָלג_, 
   {{0xdde00115,0x2be066c0,0xdb04000d,0x46a00024}},	//   _ŝuŝa, नवता, pikõ, _баяв, 
   {{0x8134278f,0xb58801d9,0x2fc40334,0x90280022}},	//   ىسىز_, _تھرٕ_, wimg_, пциа_, 
   {{0x2fc4030d,0x64bc1df0,0x75f00139,0x00000000}},	//   timg_, ्पृश, läzo, --, 
   {{0x2d9e0da2,0xedc85168,0x6014031c,0x3a200219}},	//   _sove_, िच्छ, _iġml, _otip_, 
   {{0x2d9e0da3,0x2fc40334,0xa3dc0073,0x00000000}},	//   _pove_, rimg_, डवर_, --, 
   {{0xa2d81b90,0x2fc40334,0x50b40114,0x29cc0419}},	//   _फुट्, simg_, _псеу, cľah_, 
   {{0x3a220da4,0x2fc4010a,0x2d9c0124,0x4f24118b}},	//   _atip_, pimg_, _vove_, _здеб, 
   {{0x2d9c0204,0x6814033f,0x829000db,0x1e800075}},	//   _wove_, _sądo, _جۇۇچ, уһәм, 
   {{0x2d9cbefd,0xfba805f5,0x75f00030,0x2d59495f}},	//   _tove_, хтэй_, väzn, _жиль_, 
   {{0xddd8007f,0x35c400cc,0x00000000,0x00000000}},	//   _apwņ, ্তুহ, --, --, 
   {{0xbd140375,0x3a20010e,0x768402dd,0x2904055e}},	//   _אחוז_, _etip_, қытж, äla_, 
   {{0x443c04ac,0x105002d3,0x05744973,0x00000000}},	//   _ĉu_, _ዘይተመ, کارد, --, 
   {{0x6b8e0da5,0xaa9400d8,0x00000000,0x00000000}},	// [3c0b0] _inag, _рипч, --, --, 
   {{0x6b8c020c,0xddc80cf4,0x68e00037,0x00000000}},	//   _hnag, zvež, ülds, --, 
   {{0x6b8c5c02,0x046400c0,0x00000000,0x00000000}},	//   _knag, этам, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa56400dd,0x88e003d4,0x6b8c009f,0xdb042305}},	//   _لگان, _মণিক, _mnag, chkä, 
   {{0x7668004b,0xb6040024,0x00000000,0x00000000}},	//   _سیمې_, _бяск, --, --, 
   {{0x6b8e0da6,0xddc800de,0x00000000,0x00000000}},	//   _onag, tvež, --, --, 
   {{0x6b8e0da7,0x2a68030a,0x9f4c0205,0x00000000}},	//   _nnag, _opab_, _önül_, --, 
   {{0x2a680211,0xddc84a52,0x3ea800bc,0x0f3001d5}},	//   _npab_, rvež, áct_, شکند, 
   {{0x0d820da8,0x6b8e0da9,0x0dc400fd,0x3a200139}},	//   альн, _anag, клый_, _rtip_, 
   {{0x3a220daa,0xac8000b7,0xc044103c,0x408400fb}},	//   _stip_, ንግሊዝ_, _سخاو, _яуаб, 
   {{0x6b8c12ef,0xdb04005b,0x00000000,0x00000000}},	//   _cnag, yhkä, --, --, 
   {{0x6b8c0083,0xa6540092,0x6d5c0e89,0x00000000}},	//   _dnag, ምፒዩተ, òrac, --, 
   {{0x6b8e0dab,0x3a2002fb,0x186a0dac,0x75f000d0}},	//   _enag, _vtip_, маги_, väzo, 
   {{0x29ccb0e8,0xa86401e0,0x98a80064,0x00000000}},	//   džad_, лерҙ, kabą_, --, 
   {{0x6b8c1511,0x3a20031c,0x3d14012c,0x00000000}},	//   _gnag, _ttip_, _नलडे_, --, 
   {{0x7bc40140,0x00000000,0x00000000,0x00000000}},	// [3c0c0] _imiu, --, --, --, 
   {{0xca340302,0x69940138,0x00000000,0x00000000}},	//   _שניה_, _брюх, --, --, 
   {{0x6b8c01b9,0xd78800e5,0x00000000,0x00000000}},	//   _ynag, _ہنگو_, --, --, 
   {{0x999000a2,0x00000000,0x00000000,0x00000000}},	//   _suyň_, --, --, --, 
   {{0x63a8038f,0x86400ee1,0xd13002da,0x27ec031c}},	//   _ċent, _княж, لمش_, ċent_, 
   {{0x415000d6,0xf0d401c0,0x35c401f0,0x00000000}},	//   ивіс, лжлэ, _сагҳ, --, 
   {{0xddc80034,0xd34001ed,0x628400b0,0x7bc402d0}},	//   steś, _نہای, āhoa, _omiu, 
   {{0x7f800075,0x7bc401ab,0x03a00c69,0x00000000}},	//   للىن, _nmiu, _кисо, --, 
   {{0x03a20dad,0x6b8c1b32,0x00000000,0x00000000}},	//   _тито, _rnag, --, --, 
   {{0x6b8c1326,0x7bc40194,0x00000000,0x00000000}},	//   _snag, _amiu, --, --, 
   {{0x6b8c0280,0x6c540500,0x00000000,0x00000000}},	//   _pnag, ыкну, --, --, 
   {{0xa3d410fa,0x320c0109,0x6b8c011f,0x2248110c}},	//   िचय_, _hidy_, _qnag, šake_, 
   {{0x3a740153,0x00000000,0x00000000,0x00000000}},	//   аляр, --, --, --, 
   {{0x7bc4127b,0x6b8c037e,0xe0880427,0x93540092}},	//   _emiu, _wnag, ščeč_, ቀሳቀሳ, 
   {{0x91e4037e,0x6d5803ac,0x76ec00cc,0x00000000}},	//   _asにs, _icva, _কলগছ_, --, 
   {{0x6b8d6b3a,0x320c01f5,0x8aa60dae,0x97c40139}},	//   _unag, _lidy_, _арод, груһ, 
   {{0xa6f41086,0x00000000,0x00000000,0x00000000}},	// [3c0d0] узаш, --, --, --, 
   {{0x27b40032,0x35b4014b,0xda7001f7,0x00000000}},	//   тәүс, абур, _اُٿ_, --, 
   {{0x69c4b2f8,0x63880022,0x00000000,0x00000000}},	//   _imhe, нӡам_, --, --, 
   {{0xf4841c13,0x6d580334,0x63a80135,0xd6d80107}},	//   шуун, _lcva, _ċens, фтӣ_, 
   {{0x320c06d9,0x626407d6,0x76b80209,0x6144e2db}},	//   _bidy_, увла, _аляр_, гела, 
   {{0x1e9401d5,0x27100051,0x63c40055,0x00000000}},	//   ғрир, _ễnh_, _śunī, --, 
   {{0x320c0851,0x3494efb8,0x4405d34e,0x00000000}},	//   _didy_, _карр, _ачаб, --, 
   {{0x6d580276,0x44212151,0x630401b9,0xdff402d5}},	//   _acva, _itj_, _موزل, ыяль, 
   {{0x69c46b67,0x320c06d9,0x7bc4013c,0x00000000}},	//   _omhe, _fidy_, _rmiu, --, 
   {{0x7bc405d5,0x41b48153,0xc1006ef4,0xcd240408}},	//   _smiu, _अतिस, _күлл, лжье_, 
   {{0x9e04004e,0xc0b00116,0x00000000,0x00000000}},	//   кчүл, ﻻﻣﻪﺗ, --, --, 
   {{0x69c40368,0x00000000,0x00000000,0x00000000}},	//   _amhe, --, --, --, 
   {{0x29cc0b4b,0x3f8e0daf,0x3ab4013d,0x00000000}},	//   džab_, _ingu_, рәйт, --, 
   {{0x9d5410e8,0x99d40597,0x2d995403,0x5bc40075}},	//   _صنعت, اتحا, öret_, _әйиб, 
   {{0x4dd80375,0x00000000,0x00000000,0x00000000}},	//   _אחסו, --, --, --, 
   {{0x7bc60db0,0xd708004e,0x5b3400c0,0x00000000}},	//   _umiu, енбе_, _сэку, --, 
   {{0x99d42088,0x4b20005b,0x00000000,0x00000000}},	// [3c0e0] _متدا, _умыв, --, --, 
   {{0x053802d3,0x00000000,0x00000000,0x00000000}},	//   _ኣዝማሪ, --, --, --, 
   {{0x98a50543,0x13694541,0x3f8d4e17,0x518474f0}},	//   _сине, ешли_, _ongu_, ғула, 
   {{0x3f8c1682,0xd25801f4,0x00000000,0x00000000}},	//   _nngu_, ецк_, --, --, 
   {{0x4420069c,0x320c0109,0x69c40368,0x8b5408a8}},	//   _etj_, _pidy_, _ymhe, רינס_, 
   {{0x3f8e0db1,0xdb2401e1,0x00000000,0x00000000}},	//   _angu_, _ńpìt, --, --, 
   {{0xc9500302,0x320c03d1,0x25e00034,0x50660db2}},	//   צמה_, _vidy_, कवरी_, утла, 
   {{0x320e0db3,0x77660db4,0x35c401f0,0x00000000}},	//   _widy_, nfix, _саҳҳ, --, 
   {{0x4e9401d5,0x320c0f85,0x80440137,0x00000000}},	//   اشعر, _tidy_, _ۅرنۅ, --, 
   {{0x3f8e0db5,0x7c200175,0x7764005c,0x442001f4}},	//   _engu_, _btnr, hfix, _ytj_, 
   {{0xfc1005f5,0xd010007b,0x8d8401d5,0xd02403c5}},	//   ймээ, _الص_, نشگن, _смей, 
   {{0x69c60db6,0x00000000,0x00000000,0x00000000}},	//   _smhe, --, --, --, 
   {{0x9e94168d,0x8d840b83,0x0dc800f3,0x9ba038eb}},	//   _ناوچ, _буйд, _пуки_, تەيى, 
   {{0x7c2005c7,0x77640381,0xb4f401ad,0xf7702d40}},	//   _ftnr, efix, _अरूप_, ۋاق_, 
   {{0x77660db7,0x47882e26,0x9ba40014,0xa8340063}},	//   ffix, нсам_, _چلى۪, ребљ, 
   {{0x44200254,0x00000000,0x00000000,0x00000000}},	//   _rtj_, --, --, --, 
   {{0x260c0063,0x44220db8,0x4548a5c1,0xddca0db9}},	// [3c0f0] _džon_, _stj_, ечем_, nteş, 
   {{0x69c60dba,0x44220dbb,0x6e240023,0x229400f2}},	//   _umhe, _ptj_, _çibu, یلاس, 
   {{0xddc803ee,0xe89401c0,0x647402dd,0xe3140114}},	//   hteş, _тань, ргеу, амењ, 
   {{0x9f4c0af9,0x7764045a,0x00000000,0x00000000}},	//   rleë_, cfix, --, --, 
   {{0x420c00dc,0x00000000,0x00000000,0x00000000}},	//   ादेः_, --, --, --, 
   {{0x216a0dbc,0x6025a993,0x69d40730,0xa0a41ab9}},	//   тики_, адка, nnze, иалд, 
   {{0x44200227,0x69d60dbd,0x1fb60dbe,0x00000000}},	//   _utj_, inze, исир, --, 
   {{0xddc80356,0xf41001d3,0x69d4002f,0x00000000}},	//   fteş, _رؤف_, hnze, --, 
   {{0xaac4000d,0x00000000,0x00000000,0x00000000}},	//   _लेलक, --, --, --, 
   {{0x628a0dbf,0x75f00030,0x4f0400f7,0x272c022e}},	//   _ireo, väzk, шнын_, _lоn_, 
   {{0x72041fcc,0x628891fa,0x00000000,0x00000000}},	//   _اولم, _hreo, --, --, 
   {{0x62884af6,0x3f8e0dc0,0x2d98049f,0x69d407c5}},	//   _kreo, _ungu_, örer_, enze, 
   {{0x672c5eb2,0x62980076,0x3a240036,0x00000000}},	//   dbaj, nxwo, ëmp_, --, 
   {{0xd824010b,0xacc80150,0x00000000,0x00000000}},	//   идги, _өгіз_, --, --, 
   {{0x7764031c,0x63b80007,0xa3d40490,0x00000000}},	//   tfix, khwn, िचा_, --, 
   {{0x628a0dc1,0x672c9399,0x69d40112,0x00000000}},	//   _oreo, gbaj, anze, --, 
   {{0x77b80077,0xd9440b38,0x159c0220,0xd7080006}},	// [3c100] _níxe, _кепи, _ﺍﻷﺭﺽ_, тнае_, 
   {{0x672c0083,0x77660dc2,0x00000000,0x00000000}},	//   abaj, sfix, --, --, 
   {{0x628a0dc3,0xd8740075,0x97c4bb12,0x672e0dc4}},	//   _areo, _ئاخب, _نقدو, bbaj, 
   {{0x628a0dc5,0xd2a80474,0x522401f0,0x00000000}},	//   _breo, ккее_, афка, --, 
   {{0x628a0dc6,0x786c01b8,0x662802fb,0x644003b2}},	//   _creo, _fövö, čský, _ælin, 
   {{0x77b80005,0x628801e7,0x68e805d2,0x2a6c0205}},	//   _díxe, _dreo, şede, çebi_, 
   {{0x63b80007,0x628a0dc7,0x044049c4,0xc17000db}},	//   bhwn, _ereo, _мерн, زدوت, 
   {{0x6288428b,0x22480b91,0x77b80005,0xbfa4023a}},	//   _freo, šaka_, _fíxe, итые_, 
   {{0x628a0dc8,0xab781e4a,0x69d401a4,0x00000000}},	//   _greo, ۇمدا_, ynze, --, 
   {{0xcd05c0cf,0x504407fa,0xadb8143e,0x6fb803d4}},	//   ични, _вежб, اهدا_, ুকেই, 
   {{0xddc90d8f,0x681400c0,0x672c0419,0x9f4c00a2}},	//   steş, _tądi, ybaj, lmeý_, 
   {{0x161510af,0x8d7400d1,0x8bc401d5,0x00000000}},	//   तदार_, _چاغا, рсод, --, 
   {{0xd9640023,0x00000000,0x00000000,0x00000000}},	//   _ምምዝጋ, --, --, --, 
   {{0x63b80007,0x69d4006f,0x672c0003,0x3df00153}},	//   zhwn, unze, wbaj, _дзіс, 
   {{0x69d60dc9,0x4500031c,0xdd9000e5,0x00000000}},	//   rnze, _མཛེར_, _روٹ_, --, 
   {{0xe668044e,0x248c1d35,0x63b80369,0x2cac0042}},	//   _ምርግጋ, _čem_, xhwn, mydd_, 
   {{0x2cac0cfd,0x60140006,0x094801a9,0x00000000}},	// [3c110] lydd_, _išme, _ични_, --, 
   {{0x59180327,0x00000000,0x00000000,0x00000000}},	//   _ྱུགས_, --, --, --, 
   {{0x2cac0cfd,0x8880036b,0x63b8009a,0x628801ab}},	//   nydd_, _بیزن, thwn, _sreo, 
   {{0xe2b4152d,0x77ba0dca,0x96c003f3,0x052400eb}},	//   йслэ, _píxe, _रेकॉ, মণের_, 
   {{0x27ea0dcb,0x2cac03cb,0x05e80107,0x00000000}},	//   moan_, hydd_, _афви_, --, 
   {{0xd24c0058,0xa294005e,0x27ea0dcc,0x2cac049f}},	//   رنى_, _қазі, loan_, kydd_, 
   {{0xa0a4f889,0x00000000,0x00000000,0x00000000}},	//   сайд, --, --, --, 
   {{0x27ea0dcd,0x628a0dce,0x2cac00a9,0xc2b00046}},	//   noan_, _treo, dydd_, _мөлш, 
   {{0x6ad039de,0x27e801c4,0xb3c801c6,0xa2b46dac}},	//   सपोर, ioan_, _турж_, _убач, 
   {{0x27ea0dcf,0x2cac00a9,0x60140153,0x31340798}},	//   hoan_, fydd_, _ašme, _меур, 
   {{0x27e80323,0x2cac00a9,0x00000000,0x00000000}},	//   koan_, gydd_, --, --, 
   {{0xc0d40020,0xc0f00023,0xca3401ec,0x00000000}},	//   ክክል_, ልክል_, _ﻗﯘﺱ_, --, 
   {{0x27ea0dd0,0xfe7457d7,0x5d68010b,0x75f802e3}},	//   doan_, _түп_, _билм_, ụzir, 
   {{0x2cac03cb,0x3f9c01f4,0x68140210,0x6de400f2}},	//   bydd_, ljuu_, _lądu, _وثوق, 
   {{0xdc6831a8,0x27ea0dd1,0x00000000,0x00000000}},	//   _сайд_, foan_, --, --, 
   {{0x27ea0dd2,0x2794828a,0x25a800f1,0x00000000}},	//   goan_, ошур, یدلي_, --, 
   {{0x07a13ffc,0xc7a0bd80,0x00000000,0x00000000}},	// [3c120] чатн, читк, --, --, 
   {{0x29cc09a8,0x00000000,0x00000000,0x00000000}},	//   lžan_, --, --, --, 
   {{0x27ea0dd3,0x0d38008f,0xcc38010f,0xa2cc0118}},	//   boan_, רגעב, ָענט, _देब्, 
   {{0x3f9c022f,0x27e93be6,0x00000000,0x00000000}},	//   jjuu_, coan_, --, --, 
   {{0xe3b00050,0xf1c82bcb,0x00000000,0x00000000}},	//   برٕ_, ақай_, --, --, 
   {{0x5274144d,0xd9f828d4,0x2cac015d,0x46100066}},	//   _қубу, ूषित_, yydd_, _روفر, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2cac0f7b,0xa3d48bb7,0x29cc05a1,0xe7f81d94}},	//   wydd_, िचर_, džan_, ंतता_, 
   {{0x27ea0dd4,0x2cae0dd5,0xc690011a,0xc0d40092}},	//   zoan_, tydd_, פאת_, ክርም_, 
   {{0x27e87bc3,0x20b80276,0x6b757528,0xfeb442c0}},	//   yoan_, _кыць_, олну, لایت_, 
   {{0x2cac0cfd,0x27ea0dd6,0x00000000,0x00000000}},	//   rydd_, xoan_, --, --, 
   {{0x27e80170,0x2cac00a9,0xcb00eb47,0x00000000}},	//   voan_, sydd_, रेंड_, --, 
   {{0x27e80a85,0x2cac0042,0xf1d82c30,0x00000000}},	//   woan_, pydd_, भचिन, --, 
   {{0x074463ed,0xfdf40375,0x00000000,0x00000000}},	//   йхам, _הצגת_, --, --, 
   {{0x9f5c007f,0x9f6400d0,0x00000000,0x00000000}},	//   _chwè_, _štúr_, --, --, 
   {{0x27ea0dd7,0x2cc80024,0x628402b5,0xd5ac0a81}},	// [3c130] roan_, žudė_, āhok, ھہِ_, 
   {{0x27ea0dd8,0x2b48045a,0xd5ac0014,0x69d803e0}},	//   soan_, _hdac_, پہِ_, öceğ, 
   {{0x44260dd9,0x27ea0dda,0xd00401d9,0xcfd401ec}},	//   ën_, poan_, _ٲل_, _ﺀﺳﺎﺗ, 
   {{0xd004a321,0xa2f400f5,0xe6940108,0x00000000}},	//   _زل_, опеч, _димы, --, 
   {{0xc2c80214,0x00000000,0x00000000,0x00000000}},	//   دبال_, --, --, --, 
   {{0xa2cc2413,0x16700131,0x629da61b,0xd4980022}},	//   _देण्, _юқур, _àsom, ырӡ_, 
   {{0x3c140356,0x00000000,0x00000000,0x00000000}},	//   _tăvi_, --, --, --, 
   {{0x3ebc005a,0x2b480200,0x00000000,0x00000000}},	//   tzut_, _ndac_, --, --, 
   {{0x3f9c005b,0xc1b0008e,0xa1580f06,0x82343dbb}},	//   rjuu_, _нәкы, _вазу_, _درزا, 
   {{0x2b4a0ddb,0xddc402bf,0x3ebc012d,0x00000000}},	//   _adac_, ібни, rzut_, --, 
   {{0xdc680364,0xdca44fdb,0x9990010e,0xa0c44cdb}},	//   шанд_, цани, _atyş_, _بيضو, 
   {{0x2b48070d,0x3f8000e2,0xda6400d4,0x00000000}},	//   _cdac_, ējus_, овми, --, 
   {{0x29cc2ce2,0x236c0399,0x7f580fec,0x9d4404b3}},	//   ržan_, _mbej_, mguq, _делд, 
   {{0x1d09f46e,0x25a00175,0x00000000,0x00000000}},	//   _кели_, jjhl_, --, --, 
   {{0x5bc42885,0x29cc0427,0x00000000,0x00000000}},	//   _وقتل, mžal_, --, --, 
   {{0x7f580912,0x260c01a6,0x00000000,0x00000000}},	//   nguq, _užoj_, --, --, 
   {{0xd5b000c6,0x95c80fc0,0x00000000,0x00000000}},	// [3c140] وفر_, алаб_, --, --, 
   {{0xfb5401d3,0x00000000,0x00000000,0x00000000}},	//   _بھگد, --, --, --, 
   {{0x7e781196,0xd7c80633,0x00000000,0x00000000}},	//   hwup, _نوده_, --, --, 
   {{0x77b80005,0x61fc00e2,0x75f000d0,0x00000000}},	//   _fíxa, _īsla, väzu, --, 
   {{0xf194011b,0x91e40798,0x80a00116,0x00000000}},	//   зиль, ооде, ېمىن, --, 
   {{0xc0e04be7,0x236c0327,0x76460ddc,0xa680013d}},	//   _ምላሽ_, _ebej_, msiy, _яһуд, 
   {{0x29cc01fa,0xdb04c6cb,0x61440c50,0x76460ddd}},	//   džal_, lkkä, سىيە, lsiy, 
   {{0x753e0dde,0x7f580d04,0x4fc40953,0xce682401}},	//   _herz, gguq, ўска, арод_, 
   {{0x753c03bd,0x6814033f,0xdb04005b,0xcdd8041b}},	//   _kerz, _jądr, nkkä, ињо_, 
   {{0x753ca728,0x6814033f,0x22580267,0x76460ddf}},	//   _jerz, _mądr, _åska_, isiy, 
   {{0x753e0de0,0x76440bbc,0xe194009d,0x00000000}},	//   _merz, hsiy, _эртэ, --, 
   {{0x753c56f8,0xc0f00092,0x00000000,0x00000000}},	//   _lerz, ልክም_, --, --, 
   {{0xaac60de1,0x601402d5,0x76440113,0xdb04002f}},	//   _लेखक, _išma, jsiy, chkü, 
   {{0x29cc0b91,0x1ea84130,0x753c0489,0x76460de2}},	//   ržao_, _دامي_, _nerz, dsiy, 
   {{0x52b4012c,0x76441418,0xfbc400ec,0x00000000}},	//   अनुस, esiy, _ڊيوٽ, --, 
   {{0x2e200100,0x76443a73,0x753c0112,0x2b481100}},	//   _kòf_, fsiy, _aerz, _udac_, 
   {{0x753e0de3,0x764401d9,0x4dfc216a,0x00000000}},	// [3c150] _berz, gsiy, _उठाई_, --, 
   {{0x85b80014,0x00000000,0x00000000,0x00000000}},	//   جارس_, --, --, --, 
   {{0x753e0de4,0x76460de5,0x31d00011,0xb90000cc}},	//   _derz, asiy, াকাশ, _তৰ_, 
   {{0x987804ac,0x76440014,0x00000000,0x00000000}},	//   _פארט, bsiy, --, --, 
   {{0x753e0de6,0x76440014,0xdb041ba6,0x00000000}},	//   _ferz, csiy, ckkä, --, 
   {{0xe7f8069f,0x753e0de7,0x673e0de8,0x601400ef}},	//   ंतवा_, _gerz, _hesj, _ašma, 
   {{0x661cfb11,0x91c00cef,0x673c00a2,0x00000000}},	//   _husk, хәтл, _kesj, --, 
   {{0x661e0de9,0x66140323,0x753c910c,0xd1280372}},	//   _kusk, _hizk, _zerz, لقۇۇ_, 
   {{0x64460dea,0x661e0deb,0x673e0dec,0x6615cbad}},	//   lshi, _jusk, _mesj, _kizk, 
   {{0x63a80226,0x2e200100,0x64460ded,0x7e780810}},	//   _hoen, _dòf_, oshi, rwup, 
   {{0x63aa0dee,0x661e0def,0x661602c6,0x673c0af9}},	//   _koen, _lusk, _mizk, _oesj, 
   {{0x63aa0df0,0x76441dcd,0x673e0df1,0xdb0402f6}},	//   _joen, ysiy, _nesj, ykkä, 
   {{0x6444036b,0x661e0df2,0x764448d3,0x2e2002e2}},	//   hshi, _nusk, xsiy, _gòf_, 
   {{0x63aa0df3,0x76460df4,0x64460df5,0x66160df6}},	//   _loen, vsiy, kshi, _nizk, 
   {{0x673c334b,0x661e0df7,0x64440023,0x98a400a7}},	//   _besj, _ausk, jshi, чиве, 
   {{0x64460df8,0x76460df9,0x753c23ee,0xc7a20dfa}},	//   dshi, tsiy, _serz, ниск, 
   {{0x753c07e4,0x66140323,0x6444f4dd,0x673e0dfb}},	// [3c160] _perz, _bizk, eshi, _desj, 
   {{0x7ae40054,0x661e0dfc,0x64460dfd,0xd9381cd9}},	//   _ixit, _dusk, fshi, _учиш_, 
   {{0x661c4e90,0x76458dfc,0x63aa0dfe,0x661405f5}},	//   _eusk, ssiy, _boen, _dizk, 
   {{0x63a80097,0x661c3142,0x76460dff,0x6614009a}},	//   _coen, _fusk, psiy, _eizk, 
   {{0x63a80226,0x753c61a5,0x76460e00,0x66153680}},	//   _doen, _terz, qsiy, _fizk, 
   {{0x64460e01,0x6614e59f,0x673c01f5,0x248c0022}},	//   bshi, _gizk, _zesj, _ņeme_, 
   {{0x63aa0e02,0x64460e03,0x661c01e4,0xd3940116}},	//   _foen, cshi, _zusk, _нәдә_, 
   {{0x63a80226,0x7ae40077,0x4fc43334,0x661401c0}},	//   _goen, _oxit, ясла, _zizk, 
   {{0x7ae402d3,0x661c01d9,0xa654001f,0xb52002c3}},	//   _nxit, _xusk, ምፒውተ, _बलाय_, 
   {{0xfe6c2998,0x63a80196,0x52740117,0x00000000}},	//   ادي_, _zoen, _муҷу, --, 
   {{0x7ae60e04,0x63aa0e05,0x27ec0327,0x00000000}},	//   _axit, _yoen, ċenz_, --, 
   {{0x9f5c0241,0x00000000,0x00000000,0x00000000}},	//   _diwó_, --, --, --, 
   {{0xf0b000dd,0x673c002d,0xbf106a87,0x00000000}},	//   _سیکھ, _resj, _كومب, --, 
   {{0x673d9e8d,0x9f5c0241,0xc984010b,0x6c5400cf}},	//   _sesj, _fiwó_, чуми, _жкку, 
   {{0x661e0e06,0x7ae60e07,0x644407d6,0x66143e39}},	//   _susk, _exit, xshi, _rizk, 
   {{0x77b8056a,0x37a8abd4,0x64460e08,0xb8140063}},	//   _díxo, птун_, vshi, едсј, 
   {{0x63a80226,0x64460e09,0x6614a2e1,0x673c0477}},	// [3c170] _roen, wshi, _pizk, _vesj, 
   {{0x64460e0a,0x63aa0e0b,0x77b81709,0xe9447ba2}},	//   tshi, _soen, _fíxo, _کرکی, 
   {{0x673c0ffb,0xe99001ec,0x6444d64c,0x00000000}},	//   _tesj, _كۇڭگ, ushi, --, 
   {{0x661e0e0c,0x64460e0d,0x69c828fe,0x00000000}},	//   _tusk, rshi, होरी, --, 
   {{0x644568b6,0x63aa0e0e,0xb22402dd,0x0268005b}},	//   sshi, _voen, еміл, сшей_, 
   {{0x63a90769,0x644407d6,0xb8d4970b,0x29cc05be}},	//   _woen, pshi, _آتیش, džak_, 
   {{0x63aa0e0f,0x64460e10,0xa3d400d4,0x00000000}},	//   _toen, qshi, _жовч, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x60b40451,0x816800f3,0x00000000,0x00000000}},	//   _ڪمائ, _греб_, --, --, 
   {{0x9c243edf,0xc0581cb8,0x00000000,0x00000000}},	//   мдод, _гід_, --, --, 
   {{0x61e00309,0xbb5c00b5,0x9f4c017a,0xa3b001f9}},	//   _ijll, _rayオ_, noeë_, _ओवा_, 
   {{0x601402d5,0x249001a6,0x00000000,0x00000000}},	//   _išmo, _mrzm_, --, --, 
   {{0x6e94035b,0x00000000,0x00000000,0x00000000}},	//   _пицу, --, --, --, 
   {{0xceb004ae,0x9e08007b,0x00000000,0x00000000}},	//   _ביד_, _بيتك_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9b44034c,0x7ae4009d,0x4c38011a,0x00000000}},	//   _کنکو, _txit, _ותקב, --, 
   {{0x99e400c9,0xa2cc0dad,0x9b0401b9,0xca80008e}},	// [3c180] _ожид, _देल्, _юзид, _агый, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x306c01ec,0x00000000,0x00000000,0x00000000}},	//   _ﺴﻴﺎﺴ_, --, --, --, 
   {{0x61e20e11,0xf3f413f9,0x3a2024d1,0x00000000}},	//   _ajll, رتاک, _kuip_, --, 
   {{0xf1b80032,0x60140064,0x07a13e2f,0x11e8020c}},	//   пҡа_, _ašmo, _раян, يعتي_, 
   {{0x3a2005b1,0x1598007b,0x230816ac,0xe2a8007b}},	//   _muip_, _بنسخ_, ستني_, ثامن_, 
   {{0x93440014,0x506401d5,0xe194009d,0x00000000}},	//   _ٲخرم, фтла, эрцэ, --, 
   {{0xd2a4030d,0x00000000,0x00000000,0x00000000}},	//   _пiаь, --, --, --, 
   {{0xb64004ce,0xead80154,0x00000000,0x00000000}},	//   _ｃｄ_, _সর্ম, --, --, 
   {{0x020000c7,0x00000000,0x00000000,0x00000000}},	//   _азун, --, --, --, 
   {{0x2cba0e12,0xdce000e2,0x7f80187c,0x00000000}},	//   árd_, delē, رلین, --, 
   {{0xbb940b32,0x40e40014,0x00000000,0x00000000}},	//   вающ, _غزلہ, --, --, 
   {{0x98b80100,0xc33006a9,0x3a2001ab,0xfe40013e}},	//   _depč_, כור_, _cuip_, _анчо, 
   {{0xad860e13,0x80d000bc,0x9f5801e3,0x29cc0153}},	//   _ساتۇ, _भेडे, ösö_, ožai_, 
   {{0xff240133,0xbd58011a,0x00000000,0x00000000}},	//   _ربۆی, _וכוש, --, --, 
   {{0x3a200332,0x22480010,0x00000000,0x00000000}},	//   _fuip_, šaki_, --, --, 
   {{0x443e0e14,0xa9281075,0xe3bc05ac,0xdce000e2}},	// [3c190] _ňu_, _ىزدە_, _অদলব, belē, 
   {{0x057424a4,0xe5f400db,0x79f40124,0xe0880010}},	//   بارد, ركاد, _изых, ščič_, 
   {{0x69d60e15,0x60060e16,0xd5a43fe6,0x00000000}},	//   mize, lóme, علمی, --, 
   {{0x69d60e17,0x29cc56ce,0x00000000,0x00000000}},	//   lize, džai_, --, --, 
   {{0x600409ff,0x2248003e,0xe194010b,0x9754011a}},	//   nóme, éak_, ерйэ, _אירו_, 
   {{0x7204104c,0x00000000,0x00000000,0x00000000}},	//   نونم, --, --, --, 
   {{0x1fb4084c,0x11f401d5,0x00000000,0x00000000}},	//   еспр, رتهگ, --, --, 
   {{0x69d60e18,0x1e854f14,0x2a68009a,0x4adc012c}},	//   hize, елим, _oqab_, नपाव, 
   {{0x69d60e19,0x2a680218,0x00000000,0x00000000}},	//   kize, _nqab_, --, --, 
   {{0x69d43421,0x61e003f0,0x600402d2,0x00000000}},	//   jize, _ujll, dóme, --, 
   {{0xf1c872ca,0x2a68009a,0x3a208002,0x00000000}},	//   _تولى_, _aqab_, _suip_, --, 
   {{0x3a200421,0x00000000,0x00000000,0x00000000}},	//   _puip_, --, --, --, 
   {{0x69d401ed,0xdce00265,0x99742c68,0x200c04e6}},	//   fize, telē, нувш, mmei_, 
   {{0x69d60e1a,0x629c06af,0x00000000,0x00000000}},	//   gize, _àsou, --, --, 
   {{0xa864052f,0x25f40b67,0x3ba4014b,0x89d40066}},	//   керҙ, ्तनी_, _алйҳ, روفر_, 
   {{0x200e0e1b,0x6004068c,0x2cb800cc,0x00000000}},	//   nmei_, lómb, ørde_, --, 
   {{0x69d43aa0,0x60040789,0x6d5cc32c,0x00000000}},	// [3c1a0] bize, cóme, órag, --, 
   {{0x600400e4,0x9f4c01f4,0x06800108,0xc56000d8}},	//   nómb, lleä_, ыгун, лкук, 
   {{0x7c28054e,0x00000000,0x00000000,0x00000000}},	//   _înră, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x60040085,0xa3b0033f,0x317c0010,0x00000000}},	//   kómb, _ओवर_, tevz_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9878008f,0xa490150e,0xdb040112,0x84940023}},	//   לאַט, _پینت, chkö, _መፋርቕ_, 
   {{0xb4ac1094,0x7f440c50,0x29cc0024,0x62843a2f}},	//   गही_, ىلىق_, ržai_, āhor, 
   {{0x69d60e1c,0x8b00012d,0x7054072d,0x877800df}},	//   yize, łęzi, رنکا, לאקי, 
   {{0x69d4005a,0x98b0033f,0xadb401b9,0x80080014}},	//   xize, ीनाए, тбош, _ہرنہ_, 
   {{0x69d60e1d,0x00000000,0x00000000,0x00000000}},	//   vize, --, --, --, 
   {{0x69d60e1e,0x20540816,0x6004ec23,0x00000000}},	//   wize, _штур, tóme, --, 
   {{0x12bc04c5,0x69d527e5,0x25f4146b,0x6d5c08c2}},	//   _অশুদ, tize, ्तमी_, òras, 
   {{0x60040615,0x69d40156,0x6d5e0e1f,0x4ddc00cc}},	//   róme, uize, órad, _নীৰৱ, 
   {{0x2d9c003a,0x9a78001f,0xbd84007b,0x2d8c0042}},	//   _inve_, ራተኛው_, _سنين_, mdde_, 
   {{0x69d60e15,0x9f5c00d2,0x3cf80302,0x2d8c0d27}},	//   size, _khwá_, _מלונ, ldde_, 
   {{0x2d8c4b21,0x693400d8,0x00000000,0x00000000}},	// [3c1b0] odde_, _инпу, --, --, 
   {{0x2d8d2fd6,0x69d401f0,0x99a4054e,0x00000000}},	//   ndde_, qize, ăuţi_, --, 
   {{0x2d8c03d4,0xddc800ef,0x00000000,0x00000000}},	//   idde_, breņ, --, --, 
   {{0x62360e20,0x200c00b5,0x38c800f1,0x00000000}},	//   веду, xmei_, _ساپی_, --, 
   {{0x4430010a,0x290401b8,0xdd00107d,0x57b00150}},	//   spx_, ülaf_, _čuča, _тұтт, 
   {{0x26c80109,0x2d8c01f5,0xdec00023,0x00000000}},	//   mzao_, jdde_, _ትኾኑ_, --, 
   {{0xa0a410a8,0x200c04e6,0x00000000,0x00000000}},	//   тайд, tmei_, --, --, 
   {{0xd00c511e,0x442000c8,0x2d9caf7a,0x2d8c01a4}},	//   يلو_, _iuj_, _anve_, edde_, 
   {{0x200e0e21,0x26c80451,0x4420016d,0xdb100793}},	//   rmei_, nzao_, _huj_, ögük, 
   {{0x44200190,0x98b80421,0x224c4b16,0x200db617}},	//   _kuj_, _lepā_, _ivek_, smei_, 
   {{0x44220e22,0x116801d5,0x3f5c037e,0x31340454}},	//   _juj_, _آلمی_, 用usb_, _сехр, 
   {{0x44220e23,0x2d9c68e8,0x2d8c198f,0x1a6401d5}},	//   _muj_, _enve_, adde_, پیدی_, 
   {{0x4420dd3d,0x9f5c01e1,0x00000000,0x00000000}},	//   _luj_, _ghwá_, --, --, 
   {{0xaf0400d6,0x44200109,0x26c80810,0x3e6803b2}},	//   _спіл, _ouj_, dzao_, møt_, 
   {{0x4420dd32,0x3e680162,0x6d5c03b2,0x00000000}},	//   _nuj_, løt_, órae, --, 
   {{0x96b800db,0x00000000,0x00000000,0x00000000}},	//   музу_, --, --, --, 
   {{0x4421ee48,0x7c200009,0x27e40098,0xa3c40dba}},	// [3c1c0] _auj_, _hunr, élna_, एसन_, 
   {{0x7c220e24,0x44220e25,0x27ecba81,0x58240395}},	//   _kunr, _buj_, čena_, _имоб, 
   {{0x224e0e26,0x44220e27,0x00000000,0x00000000}},	//   _avek_, _cuj_, --, --, 
   {{0x7c220e28,0x44220e29,0x7795272b,0x999802e2}},	//   _munr, _duj_, _حیرا, _sipň_, 
   {{0x2d8c0183,0x7c2001e4,0x3e6a0e2a,0x224cb9b7}},	//   ydde_, _lunr, jøt_, _cvek_, 
   {{0xe8480014,0x00000000,0x00000000,0x00000000}},	//   _تجین_, --, --, --, 
   {{0x0440747d,0x44200399,0x7c2005d5,0xdce00153}},	//   _весн, _guj_, _nunr, melė, 
   {{0x77640107,0x2d8c04ba,0xdce00153,0x00000000}},	//   ngix, wdde_, lelė, --, 
   {{0x71742e56,0x44200070,0xd1845c6e,0x6ae004af}},	//   _مۇشا, _zuj_, _илай, _पखेर, 
   {{0x68e800a8,0x7c220e2b,0x77b80005,0x44200211}},	//   şedi, _bunr, _díxi, _yuj_, 
   {{0x7c207d90,0x44200218,0x224c05be,0x1068084c}},	//   _cunr, _xuj_, _zvek_, _цией_, 
   {{0x7c202b7b,0xaa580075,0x8f0800db,0x7e840108}},	//   _dunr, ниму_, _قياق_, ärpä, 
   {{0x7c200263,0xdce00024,0x00000000,0x00000000}},	//   _eunr, kelė, --, --, 
   {{0x7c200cad,0xfd9802d3,0xdce000c0,0xe7940066}},	//   _funr, _ንፈልጦ_, jelė, گاسک, 
   {{0x290478d0,0xdce00006,0xacf81cd0,0x8bc4014b}},	//   åla_, delė, _янку_, _аспд, 
   {{0xf7700aaf,0x44220e2c,0xfbd0082e,0x77b800b5}},	//   ياق_, _ruj_, _وتي_, _yíxi, 
   {{0x44207e84,0x600400e4,0x00000000,0x00000000}},	// [3c1d0] _suj_, nóma, --, --, 
   {{0x26c80e3c,0x44220e2d,0x88804c8b,0x7c200241}},	//   rzao_, _puj_, _پیرن, _yunr, 
   {{0x6b8e0e2e,0x6d4805d5,0x44200978,0x224c0267}},	//   _kaag, iada, _quj_, _svek_, 
   {{0x6d4924b7,0x6b8e0e2f,0xa3cc0034,0x60040022}},	//   hada, _jaag, षों_, kóma, 
   {{0x6d4a0e30,0xa2cc0316,0x36380276,0x600401a8}},	//   kada, _देख्, _изяэ_, jóma, 
   {{0x6b8e0e31,0x44220e32,0x77b8056a,0x60140006}},	//   _laag, _tuj_, _ríxi, _išmi, 
   {{0xf4852247,0x601826c7,0x5f28004e,0x00000000}},	//   _кутн, нцир_, нойм_, --, 
   {{0x672e0e33,0xa50400d1,0x3e6800d4,0x224c01c4}},	//   ncaj, _аяғл, tøt_, _tvek_, 
   {{0x224c56c0,0x6d4a0e34,0x7c220e35,0x5f740133}},	//   _uvek_, fada, _sunr, ناکر, 
   {{0x6d4a0e36,0x4f060e37,0x65640097,0x628a0e38}},	//   gada, ынын_, nghh, _iseo, 
   {{0x6b8e0e39,0x60b400e5,0xbfa8011c,0x00000000}},	//   _baag, _حمائ, _отде_, --, 
   {{0x6b8e0e3a,0xde942732,0x7c2000ad,0x6d480009}},	//   _caag, _مجتب, _vunr, aada, 
   {{0x6d486fc3,0x6b8e0e3b,0xee383334,0x6d5c00ae}},	//   bada, _daag, _ані_, órac, 
   {{0x201c0374,0x38c87e2c,0x29cc2672,0x2d9402e8}},	//   _hiwi_, نازی_, džas_, _връс, 
   {{0x6b8e0e3c,0x29cc00e2,0xdce00153,0x1c4401b9}},	//   _faag, ežas_, velė, _ёним, 
   {{0x6b8e0e3d,0x201c002e,0xc0500023,0x8ea400db}},	//   _gaag, _jiwi_, _ከይተፈ, _جلۇۇ, 
   {{0x7bc60e3e,0xdce00006,0xd9440131,0x29280841}},	// [3c1e0] _iliu, telė, _йепи, _štaš_, 
   {{0x59860e3f,0x6b8e0e40,0xb8b40046,0x201ce4a3}},	//   _слоб, _zaag, _көбі, _liwi_, 
   {{0x201c166a,0x29ce0e41,0x628a0e42,0x6b8e0e43}},	//   _oiwi_, ržat_, _aseo, _yaag, 
   {{0x92680a70,0x6b8c0429,0x934466be,0xdce00006}},	//   ерка_, _xaag, унде, selė, 
   {{0x6d4a0e44,0x7bc45a50,0xdce00153,0x00000000}},	//   yada, _mliu, pelė, --, 
   {{0x7bc40228,0xd37000b2,0x6d4a0e45,0xdb140166}},	//   _lliu, _گهر_, xada, _ilyä, 
   {{0x6d4a0e46,0x201c0161,0x6288010f,0x7bc60e47}},	//   vada, _biwi_, _eseo, _oliu, 
   {{0x600430e2,0x55e4016c,0x68140034,0x62641e4a}},	//   tóma, _роҳб, _sądz, _چالق, 
   {{0x6b8e0e48,0x201c226d,0x11d8007b,0xed840075}},	//   _raag, _diwi_, _كورة_, иңди, 
   {{0x7bc60e49,0xf1b88153,0x6b8e0e4a,0xc278008f}},	//   _aliu, _अविन, _saag, _ארמי, 
   {{0x7bc60e4b,0x6b8e0e4c,0x672c00d0,0x6ed40d0d}},	//   _bliu, _paag, ycaj, _बेरु, 
   {{0x7bc60e4d,0x6b8d741c,0x60060e4e,0x629c0005}},	//   _cliu, _qaag, lómn, _ásoc, 
   {{0x6d4a0e4f,0x6b8e0e50,0x7bc400a3,0xce300517}},	//   pada, _vaag, _dliu, _اوتک, 
   {{0x6b8e0e51,0x7cd40046,0x6d4877f0,0x7bc4478b}},	//   _waag, _өмір_, qada, _eliu, 
   {{0x6b8e0e52,0x7bc4047c,0x201c0de2,0x00000000}},	//   _taag, _fliu, _yiwi_, --, 
   {{0x0ba80132,0x7bc60e53,0xddc81be1,0x00000000}},	//   _سابى_, _gliu, kreś, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3c1f0] --, --, --, --, 
   {{0x603002b1,0x29cc1039,0x672e0e54,0x00000000}},	//   _hāme, ržas_, scaj, --, 
   {{0xb6042164,0x69c43c3c,0x628805b1,0x60310e84}},	//   сятк, _ilhe, _sseo, _kāme, 
   {{0x603000e2,0xd6d801f0,0xe79401af,0x00000000}},	//   _jāme, хтӣ_, _тимњ, --, 
   {{0x2168024d,0xe1f05c8a,0xe2160e55,0x603033fb}},	//   вили_, يست_, амды, _māme, 
   {{0x20560e56,0x201e0e57,0xe4349528,0x66c8022e}},	//   атир, _siwi_, _نظرک, _dоkt, 
   {{0x201c0113,0x02c40116,0x00000000,0x00000000}},	//   _piwi_, _әқли_, --, --, 
   {{0x628a0e58,0x603000cd,0x48d003d4,0x00000000}},	//   _tseo, _nāme, _দুৱৰ, --, 
   {{0xdee60e59,0x69c406ed,0x00000000,0x00000000}},	//   ропи, _olhe, --, --, 
   {{0x201e0e5a,0x7bc800da,0x69c401ee,0x7bc60e5b}},	//   _wiwi_, ījum, _nlhe, _sliu, 
   {{0x7bc40006,0x201e0e5c,0xdb0400c5,0xd12012eb}},	//   _pliu, _tiwi_, skkü, मशरण_, 
   {{0x69c60e5d,0x4090036b,0xae3400fb,0x9ed800d8}},	//   _alhe, _پلچر, шүәт_, _имет_, 
   {{0x3ab4f8fb,0x8ba401e0,0xc5e800cc,0x00000000}},	//   сәйт, рҙыҡ_, _কঠনা_, --, 
   {{0x3f8d9cdb,0x69c40437,0x00000000,0x00000000}},	//   _hagu_, _clhe, --, --, 
   {{0x7bc400a3,0x4dd80375,0x60043afd,0x3f8e0e5e}},	//   _tliu, _בחסו, nómo, _kagu_, 
   {{0x7bc60e5f,0x69c4b363,0x3f8c00c5,0x5b34084c}},	//   _uliu, _elhe, _jagu_, _тэку, 
   {{0x3f8e0e60,0x603000cd,0x00000000,0x00000000}},	// [3c200] _magu_, _jāmb, --, --, 
   {{0x3f8e0e61,0xb8dc009e,0x99640145,0x60140153}},	//   _lagu_, _অধ_, _өтүл, _išmu, 
   {{0x98a60e62,0x546a0e63,0x53440124,0x603000b8}},	//   _тине, таем_, ахла, _yāme, 
   {{0x3f8e0e64,0x78a800c5,0x78bc03cd,0x69d801e1}},	//   _nagu_, ädvu, myrv, _ìwer, 
   {{0xdb141e00,0x69c507d2,0x60300055,0xdce00171}},	//   _flyå, _ylhe, _nāmb, felī, 
   {{0x42041d73,0xd1760e65,0xc87c0205,0x00000000}},	//   анчо_, рыды, ışve_, --, 
   {{0x25f426d9,0x3f8e0e66,0x84e001c0,0xc9500375}},	//   ्तरी_, _bagu_, _дорж, קמה_, 
   {{0xf1b80135,0x00000000,0x00000000,0x00000000}},	//   _diġa_, --, --, --, 
   {{0x3f8d3bd5,0x6030e261,0x2dd4702f,0xdce000ef}},	//   _dagu_, _cāmb, йжир, belī, 
   {{0x3f8c0086,0x60300055,0xdce000ef,0x600401e1}},	//   _eagu_, _dāmb, celī, bómo, 
   {{0x3f8e0e67,0x60042b76,0x61ee0e68,0x3b0001a9}},	//   _fagu_, cómo, éale, _ayiq_, 
   {{0x78bc062c,0x00000000,0x00000000,0x00000000}},	//   dyrv, --, --, --, 
   {{0x9e9403e6,0x6030002b,0xdc700092,0xaa4400db}},	//   _هاوچ, _gāmb, _እያልክ_, حچبى, 
   {{0x3ea401d9,0x78bc12e8,0x094802e8,0x6fa401f9}},	//   _خشمہ, fyrv, ъчми_, कावू, 
   {{0x2ee800bd,0x9d6401d9,0xe75802bf,0x07440a93}},	//   _পরিষ, _انى۪, ливі_, ихам, 
   {{0x3f8c011f,0x69c4003e,0x5fa81af8,0x00000000}},	//   _xagu_, _wlhe, कायल, --, 
   {{0x69c60e69,0x23281086,0x8b00012d,0x600400d7}},	// [3c210] _tlhe, қоли_, łębi, zómo, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x442401dc,0xe4740a16,0xe4d8007b,0x6abc007c}},	//   ên_, слењ, دوات_, lysf, 
   {{0xb928063f,0x600402d2,0x00000000,0x00000000}},	//   kwuọ_, góml, --, --, 
   {{0x3f8e0e6a,0xddc80276,0xdce000e2,0x66f0000d}},	//   _ragu_, nteţ, telī, _अँटक_, 
   {{0x3f8cb59b,0x2b4845bc,0x71246073,0x290000c7}},	//   _sagu_, _leac_, يرىل, _kyha_, 
   {{0xf1a80133,0xd12c724c,0x603000b8,0x00000000}},	//   شاوه_, رمي_, _sāmb, --, 
   {{0xdce00029,0x6d5e0e6b,0x600400d0,0xc10000ec}},	//   selī, óran, rómo, ٽوڊي, 
   {{0x5fa80034,0x3f8c16a3,0x9998007f,0x236c01bf}},	//   काबल, _vagu_, _sipō_, _icej_, 
   {{0xdee402af,0x3f8c0066,0x0dc400fd,0xfc3400c7}},	//   _қоли, _wagu_, йлый_, аҭк_, 
   {{0x7094f87a,0x27ec0427,0xf0b89717,0xd65c01ec}},	//   _мафф, čenj_, _پالش_, зiлд, 
   {{0x92a81c82,0x2b480356,0x6030002b,0x00000000}},	//   খনৰ_, _ceac_, _tāmb, --, 
   {{0x29000784,0x2b499aa2,0x5018011a,0x6fa4086b}},	//   _ayha_, _deac_, _עונו, कारू, 
   {{0x290005b1,0x186846e0,0xf8a401c0,0x00000000}},	//   _byha_, лаги_, оггү, --, 
   {{0x6a7c0267,0xddc8054e,0x00000000,0x00000000}},	//   _påfö, ateţ, --, --, 
   {{0x236c0211,0x2cba0e6c,0x2ee80183,0xdbf001ef}},	//   _ncej_, ärde_, _পৰিষ, _křís, 
   {{0x29000477,0x12e000cc,0xddc80356,0x601401ef}},	// [3c220] _eyha_, _বর্দ, cteţ, _ušmu, 
   {{0x998406d5,0xe8f80107,0x19880108,0x00000000}},	//   _الدو, улӣ_, _сбои_, --, 
   {{0x290000e4,0xd3b801ec,0x292800d7,0x00000000}},	//   _gyha_, луді_, átať_, --, 
   {{0x64981eec,0x3d0c0210,0x00000000,0x00000000}},	//   штур_, _डरने_, --, --, 
   {{0x1db800e1,0x96b8004e,0x40cc01e1,0x00000000}},	//   ेसात, _суну_, bẹkọ_, --, 
   {{0xca780a7c,0x00000000,0x00000000,0x00000000}},	//   רנסט, --, --, --, 
   {{0xf8c96ee9,0x00000000,0x00000000,0x00000000}},	//   रनिय, --, --, --, 
   {{0x42c49151,0xd3c401ec,0xd3b400c7,0x38980118}},	//   ргән_, _اتسى, _усгь, _mčr_, 
   {{0x2b480477,0xfbcc102f,0x389801ef,0x00000000}},	//   _reac_, ासनम, _lčr_, --, 
   {{0x2b4800a3,0x389800d7,0x6c5400d8,0x6450013d}},	//   _seac_, _očr_, окоу, _äkiä, 
   {{0xfe6ce7c8,0x2b4801ab,0x6abc0368,0x00000000}},	//   ودی_, _peac_, wysf, --, 
   {{0x92a802f5,0x6abc033f,0x8bc49665,0x00000000}},	//   খনী_, tysf, ссод, --, 
   {{0x15f844ab,0x2b48054e,0x3898013a,0x9f4c010b}},	//   ्तार_, _veac_, _ačr_, nleý_, 
   {{0x60309388,0x2b1400dc,0x225800b5,0x2900005c}},	//   _hāma, नेषु_, _æske_, _pyha_, 
   {{0x60300882,0x2b480076,0x6d5a0e6d,0xddc80311}},	//   _kāma, _teac_, _idva, steţ, 
   {{0x60300318,0xf77001ed,0x19e002dd,0x85b801d9}},	//   _jāma, ٹاف_, _ﺍﺳﭙﺎ, گارس_, 
   {{0x60320e6e,0xddca0e6f,0x5fa80073,0xc984020f}},	// [3c230] _māma, lteš, कातल, _луни, 
   {{0x60300055,0x85b8007b,0x00000000,0x00000000}},	//   _lāma, دارس_, --, --, 
   {{0x7d780a1e,0x0ae800f1,0xfa340633,0xf1ac77d7}},	//   רנבו, _جرګي_, _ورید, चानन, 
   {{0x78a90d41,0x60300882,0x3cf8010f,0xd24c00d1}},	//   ådve, _nāma, נלאנ, ھنى_, 
   {{0x27ea0e70,0xd24c0075,0x6d580b9b,0xddc801fa}},	//   mnan_, پنى_, _odva, hteš, 
   {{0xa0a406f7,0x6d5c0174,0xfa780375,0x273400db}},	//   жакд, óral, צעות_, _دىڭس, 
   {{0x27ea0e71,0x1fa801d5,0x63ac007c,0x00000000}},	//   onan_, икки_, öans, --, 
   {{0x27ea0e72,0xdbf002f8,0x6d58db22,0x603000cd}},	//   nnan_, _přís, _adva, _cāma, 
   {{0x27ea0e73,0x600400d2,0x7204485f,0x60301c52}},	//   inan_, lómk, _کولم, _dāma, 
   {{0x41760e74,0x6d580175,0x5164010b,0x27e80108}},	//   _دارس, _cdva, _дүшү_, hnan_, 
   {{0x1d081d83,0x27ea0e75,0x9b44188d,0x1ca404d3}},	//   рени_, knan_, يندو, ڵێکی_, 
   {{0x27e800df,0xdbf00118,0xca3401ec,0x6ed4000d}},	//   jnan_, _třís, _ﺗﯘﺱ_, _बेकु, 
   {{0x4a420e76,0x95280135,0x27ea0e77,0xdd960e78}},	//   мняв, _སྔའི_, dnan_, _мады, 
   {{0x27ea0e79,0x1ea80451,0xa3c400c5,0x38980118}},	//   enan_, _ماڻي_, एसँ_, _pčr_, 
   {{0x27ea0e7a,0x603000cd,0x3ebe0e7b,0x00000000}},	//   fnan_, _yāma, lyut_, --, 
   {{0x27ea0e7c,0x1ae406a6,0xc7a00261,0x07a20e7d}},	//   gnan_, _мойм, миск, масн, 
   {{0x3ebc2ebc,0x7d000b21,0x2a3401c0,0x00000000}},	// [3c240] nyut_, _hyns, _нээр, --, 
   {{0x7d020e7e,0x27ea0e7f,0x7c24cd74,0x3ebc0d04}},	//   _kyns, anan_, _hiir, iyut_, 
   {{0x7c260e80,0x7d01b783,0x27ea0e81,0xb0640139}},	//   _kiir, _jyns, bnan_, _kräş, 
   {{0x7d00138f,0x13060e82,0x3ebc1c06,0x7f4801e2}},	//   _myns, озем, kyut_, _negq, 
   {{0x7c260e83,0xc7b01203,0x60300882,0x7d0094fc}},	//   _miir, _חבר_, _rāma, _lyns, 
   {{0x4a9800c8,0x60300882,0x7c2558e0,0x6ed4012d}},	//   יינג, _sāma, _liir, _बेगु, 
   {{0x61ed94f9,0x7f48401f,0x316003ee,0x60301da6}},	//   éala, _begq, ğiz_, _pāma, 
   {{0x7c260e84,0xddca0e85,0x31600790,0x88b8011a}},	//   _niir, treş, şiz_, יזצי, 
   {{0x11e447ba,0x7d000363,0x9f5c007f,0x27e401ed}},	//   _джам, _ayns, _mkwè_, élni_, 
   {{0x7d000649,0x27ea0e86,0xf2c418ce,0x7c240810}},	//   _byns, znan_, _мөһи, _aiir, 
   {{0x60313e12,0x27ea0e87,0x7d000042,0xc5f000df}},	//   _tāma, ynan_, _cyns, ודז_, 
   {{0x7d0000ad,0xddc80311,0x7c240014,0x80d013f7}},	//   _dyns, preş, _ciir, _भेटे, 
   {{0x7c260e88,0x27e8022c,0x7d0001a9,0xe28800d1}},	//   _diir, vnan_, _eyns, ﻮﻧﻮﻡ_, 
   {{0x6d5a0e89,0x7d020e8a,0x27e80198,0x7f480472}},	//   _udva, _fyns, wnan_, _zegq, 
   {{0x61fe0e8b,0x7c246267,0x27ea0e8c,0x7f4801e2}},	//   _ísle, _fiir, tnan_, _yegq, 
   {{0x27ea0e8d,0x7c260e8e,0xaa540276,0x3d0c012d}},	//   unan_, _giir, _евиш, _डरते_, 
   {{0xae740598,0xfba81c15,0x603000dc,0xe738013d}},	// [3c250] _çığa, गारम, _nāmn, иең_, 
   {{0x27ea0e8f,0x64540ac5,0x7c260e90,0xd00400ec}},	//   snan_, _pvzi, _ziir, _ڳل_, 
   {{0x27ea0c53,0x92a803d4,0xd76401d3,0x7c260e91}},	//   pnan_, খনো_, _کاپٹ, _yiir, 
   {{0xd00494b9,0x7c258681,0xc76407d2,0x3ebc011f}},	//   _سل_, _xiir, _بادى, yyut_, 
   {{0x80d0006d,0x21a4036b,0x60300055,0xd734011a}},	//   _भेजे, зилм, _cāmn, _מטרת_, 
   {{0x603000b8,0x248c0171,0x00000000,0x00000000}},	//   _dāmn, _ņemu_, --, --, 
   {{0xd00c00ec,0x00000000,0x00000000,0x00000000}},	//   گلي_, --, --, --, 
   {{0x8f50185e,0x1fa800c7,0x7d020e92,0xf36400cf}},	//   ىنىش, скии_, _ryns, _отун, 
   {{0x60042d7b,0x7d020e93,0xd00d5c93,0x3ebc0357}},	//   nómi, _syns, دلي_, uyut_, 
   {{0x7c260e94,0x7d00138f,0x00000000,0x00000000}},	//   _siir, _pyns, --, --, 
   {{0x7c257701,0xdca45882,0x3ebc0280,0x0d200137}},	//   _piir, чани, syut_, нүшү, 
   {{0x60300374,0x3ebc03a2,0x7c240014,0x2cb801e6}},	//   _hāmo, pyut_, _qiir, ärda_, 
   {{0x6031fe4e,0xdb140085,0x7c260e95,0x7d003c6a}},	//   _kāmo, _koyé, _viir, _wyns, 
   {{0x7c260e96,0x9f4c0789,0x7d0008fb,0xae0402dd}},	//   _wiir, pleó_, _tyns, _قونى, 
   {{0x7c260e97,0xdb140085,0x603002b1,0x00000000}},	//   _tiir, _moyé, _māmo, --, 
   {{0xdb140085,0xd6d80214,0x00000000,0x00000000}},	//   _loyé, موزش_, --, --, 
   {{0x1665c34b,0xa3c402a0,0x95c801b9,0xe3e000cc}},	// [3c260] явам, एसई_, блаб_, যকাব, 
   {{0x4a98008d,0xdb1406af,0xea640014,0x6030002b}},	//   _פייג, _noyé, _کھێی, _nāmo, 
   {{0x25dc0037,0x49b8011a,0x603000cd,0x6fe801ef}},	//   _गगरी_, _המיס, _sāmn, běch, 
   {{0x2cb80579,0xb9f80b82,0xdb040254,0x9f4c010e}},	//   ørdi_, _ዘሌ_, skkõ, kleñ_, 
   {{0xdb1402ea,0xf1944d15,0xd05403be,0x6d5c00dd}},	//   _boyé, диль, əcək, órak, 
   {{0x84340075,0x60300055,0x00000000,0x00000000}},	//   زكۇر_, _cāmo, --, --, 
   {{0x09d8025c,0x6030002b,0xfbcc215d,0x4dcc01ec}},	//   _རཏྣ_, _dāmo, ासाम, _ﯗﺭﯨﻨ, 
   {{0xce68156c,0x00000000,0x00000000,0x00000000}},	//   брод_, --, --, --, 
   {{0x2eb8043e,0x00000000,0x00000000,0x00000000}},	//   ेनेत, --, --, --, 
   {{0x225800c4,0x41b0007b,0x40900304,0x3b78009d}},	//   _æska_, _كمقر, фрәт, үйээ_, 
   {{0x4f24010b,0x505800db,0xfba801f9,0xac181513}},	//   _едеб, _ышая_, गांम, жону_, 
   {{0xa3c43d1d,0xdbf0013a,0x00000000,0x00000000}},	//   एसए_, _přás, --, --, 
   {{0x5fa83daa,0xfba805f5,0x1ea8143e,0x00000000}},	//   कारल, чтэй_, _واهي_, --, 
   {{0xb32c0135,0x64b4012c,0xdee45230,0x00000000}},	//   _སུའང_, _hřiš, _تأمي, --, 
   {{0x290409cc,0x64b400bc,0x6bd80014,0x9e240014}},	//   æla_, _křiš, _ووتس_, _کى۪و, 
   {{0x60041de4,0xec14036b,0xd7b803b9,0xdbf0013a}},	//   tómi, _توبد, _şərə_, _třás, 
   {{0x0584656c,0x00000000,0x00000000,0x00000000}},	// [3c270] зуем, --, --, --, 
   {{0x6d5c1427,0x78a800d7,0x00000000,0x00000000}},	//   órah, ťdva, --, --, 
   {{0x6fe8012c,0x4cdc009e,0x600429d3,0x67d400f7}},	//   pěch, _নুতু, sómi, _жону, 
   {{0x60301140,0xbb78010f,0x248c0171,0x00000000}},	//   _sāmo, ִעוו_, _ņems_, --, 
   {{0x603000b0,0xdb14002e,0x76840276,0x61ec00ae}},	//   _pāmo, _poyé, _пырж, éalo, 
   {{0x27ec05ce,0xfe080210,0x00000000,0x00000000}},	//   čenu_, _सींस_, --, --, 
   {{0x64b40118,0x603000b8,0x00000000,0x00000000}},	//   _břiš, _vāmo, --, --, 
   {{0xdb140432,0x33940024,0xf1240124,0x00000000}},	//   _alyý, _пасё, хьчо, --, 
   {{0xdb140085,0x64dc0d2c,0x603002b1,0x00000000}},	//   _toyé, _मधुश, _tāmo, --, 
   {{0xf1a426d9,0x00000000,0x00000000,0x00000000}},	//   _गोपन, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x5ff401d5,0x00000000,0x00000000,0x00000000}},	//   _ўзду, --, --, --, 
   {{0x63aa0e98,0xdce00034,0xd65c02dd,0x8d700092}},	//   _mnen, dglą, зiнд, ባታቸው_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x63aa0e99,0xc92401c0,0x97c400f1,0x00000000}},	//   _onen, дорж_, وترم, --, 
   {{0x63aa0e9a,0x7bc800e2,0x454400d1,0x00000000}},	//   _nnen, ījus, ېرنې, --, 
   {{0xd9b800ee,0x4430031c,0x1db000cd,0x00000000}},	// [3c280] _дынч_, eqx_, जापत, --, 
   {{0xab081c4e,0xade001f9,0x00000000,0x00000000}},	//   _عتيق_, गोपन_, --, --, 
   {{0x63a806a3,0x6d5c00c6,0x14881c3e,0x00000000}},	//   _bnen, órai, تپاي_, --, 
   {{0x838000c9,0x73341e4a,0xf6b400cf,0x00000000}},	//   выше, رىتا, _كۅزج, --, 
   {{0x63a801a6,0x8c1800d9,0xd13002c9,0x00000000}},	//   _dnen, קוני, نمش_, --, 
   {{0x63aa0e9b,0xcad4011a,0x00000000,0x00000000}},	//   _enen, וונת_, --, --, 
   {{0xf1b8038f,0x64b40316,0x70a807f7,0x9f9001e1}},	//   _jiġi_, _přiš, कमेल, _káè_, 
   {{0x7f8000d1,0x603000ef,0x637000e5,0x00000000}},	//   نلىن, _kāmj, tűnő, --, 
   {{0xf1b8038f,0xc1c40150,0x00000000,0x00000000}},	//   _liġi_, _ﺒﻠﺩﺍ, --, --, 
   {{0x63a801f1,0x600409f3,0x47c40154,0xd1c81888}},	//   _znen, dómu, রোপী, _ببرم_, 
   {{0x61fe0e9c,0xf1b8025c,0x63a80076,0x4598010f}},	//   _ísla, _niġi_, _ynen, קסטע, 
   {{0xecc400db,0xd65c0150,0x00000000,0x00000000}},	//   _үшкү, зiмд, --, --, 
   {{0x6ac401b9,0xdc540133,0x600403b2,0x9f4c002f}},	//   رقسم, ورێک, gómu, ließ_, 
   {{0xe8940124,0xbea401c8,0x09e400eb,0x00000000}},	//   нагь, _آهون_, পকভা, --, 
   {{0x2d8e0e9d,0x64dc00bc,0x44300076,0x00000000}},	//   mede_, _मधेश, xqx_, --, 
   {{0x2d8e0e9e,0x0cc81d27,0x2cb8022c,0x6eb40034}},	//   lede_, ानीम, ørdu_, ेहपु, 
   {{0xa6140f5c,0x9f4c002f,0xf4140154,0x00000000}},	// [3c290] емач, hieß_, িদার_, --, 
   {{0x1db000dc,0xa4d400d4,0x00000000,0x00000000}},	//   जायत, нозі, --, --, 
   {{0x5f04038e,0xa4380212,0xb604003b,0x00000000}},	//   _हुन्_, їзду_, тятк, --, 
   {{0x2d8e0e9f,0xa9280220,0x67d60ea0,0x00000000}},	//   hede_, _وزگە_, _чому, --, 
   {{0x2d8cf63c,0x2c78003e,0x1db0012c,0x56f04530}},	//   kede_, héd_, जामत, _бүтс, 
   {{0x2d8e0ea1,0x2c78ae51,0xb22400d4,0x3d0c0118}},	//   jede_, kéd_, вміл, _डरले_, 
   {{0x44300327,0x9d440022,0x00000000,0x00000000}},	//   qqx_, ҭеид, --, --, 
   {{0x2c78003e,0xa2940006,0xa3c407af,0x00000000}},	//   déd_, _пабі, एसओ_, --, 
   {{0x2d8e0ea2,0x00000000,0x00000000,0x00000000}},	//   fede_, --, --, --, 
   {{0x2d8e0ea3,0x1c44d3a6,0x713801b9,0x00000000}},	//   gede_, нном, _قسمآ_, --, 
   {{0x2c792ad4,0x224c05c7,0x9f9001e1,0x00000000}},	//   géd_, _hwek_, _láé_, --, 
   {{0x224d32a1,0xf0440006,0x00000000,0x00000000}},	//   _kwek_, _рэфо, --, --, 
   {{0x2d8e0ea4,0xf1a401d9,0x00000000,0x00000000}},	//   bede_, _गोडन, --, --, 
   {{0x7e7817fa,0x603000e2,0x60041427,0x00000000}},	//   mtup, _rāmj, rómu, --, 
   {{0xdca401d5,0xfe08012d,0x69c00254,0x7e787c46}},	//   _чайи, _सीएस_, ölea, ltup, 
   {{0x224c2252,0x7e78009f,0x6d5c0174,0xb908000d}},	//   _owek_, otup, órav, _मइ_, 
   {{0x7e7a0ea5,0x95c807d6,0xbbcc00bc,0x87e400db}},	// [3c2a0] ntup, плаб_, ासीक, رتفە, 
   {{0xf1b8038f,0x7e79c1d7,0x99980100,0x8af8011a}},	//   _tiġi_, itup, _sipņ_, _מהפי, 
   {{0x224c0092,0x8ca0033f,0x7e780037,0x00000000}},	//   _awek_, गियो, htup, --, 
   {{0xe9f801dc,0x7e7a0ea6,0x2d8e0ea7,0x77941fcb}},	//   _trả_, ktup, zede_, _جیرا, 
   {{0x2d8e0ea8,0x07a20ea9,0x224c020b,0x91e60eaa}},	//   yede_, _саян, _cwek_, ноде, 
   {{0x799e0eab,0xcb1000c8,0x2d8c00b5,0x00000000}},	//   ndrw, אלד_, xede_, --, 
   {{0x60040008,0x4fc48ab1,0x506401b9,0x2be0000d}},	//   jóms, еспа, хтла, _पगला, 
   {{0x2d8e0eac,0x76460ead,0x60040321,0x90c000db}},	//   wede_, opiy, dóms, _ۅڭبۅ, 
   {{0x2d8c60ec,0x7e79fc4d,0x76460eae,0x2c78003e}},	//   tede_, gtup, npiy, wéd_, 
   {{0x9f4c002f,0x7bc069a9,0x93c800e5,0x00000000}},	//   pieß_, ömun, _باڑہ_, --, 
   {{0x2d8e0eaf,0x7e781c06,0x799c015d,0x600403b2}},	//   rede_, atup, ddrw, góms, 
   {{0x2c787c70,0x76440113,0xbb94034b,0xaa580116}},	//   réd_, kpiy, гающ, миму_, 
   {{0x2d8e0eb0,0x895c0023,0x7e78002f,0x37c803d4}},	//   pede_, _ንምውጻ, ctup, ৰচাৰ, 
   {{0xa0200209,0x2d8c013e,0x2c7a0eb1,0x3d9001c6}},	//   _ýöre, qede_, péd_, _бишр, 
   {{0x36d4016c,0x4cdc015b,0x1ae00154,0x60300171}},	//   ҳотр, _নুরু, _গুদে_, _rāmk, 
   {{0x60d42e11,0x6d4869a1,0xd1d40092,0x6d5c03f2}},	//   _üzme, lbda, ያበቃ_, ðraf, 
   {{0xb90912e7,0x7644356c,0x36d40114,0x00000000}},	// [3c2b0] _मे_, gpiy, готр, --, 
   {{0xd05403be,0xcfd400eb,0x00000000,0x00000000}},	//   şbəx, তচিন, --, --, 
   {{0xf1b8038f,0x00000000,0x00000000,0x00000000}},	//   _jiġu_, --, --, --, 
   {{0xa28c044e,0x6dc4010f,0xf51807d6,0x91a4012d}},	//   _መልክዕ_, lĉaĵ, رتلش_, _टोबै, 
   {{0x6b9c2ad4,0x7e7839fe,0x00000000,0x00000000}},	//   idsg, xtup, --, --, 
   {{0x603002b1,0x5eb804c5,0x2168c48f,0x6d480334}},	//   _hāmi, ইনমে, фики_, jbda, 
   {{0xf1b80135,0x6d4a0eb2,0x603000cd,0x00000000}},	//   _niġu_, dbda, _kāmi, --, 
   {{0x64460eb3,0x7e7a0eb4,0x6b9e0eb5,0xe42400f1}},	//   mphi, ttup, jdsg, _شکاي, 
   {{0x64460eb6,0x603000da,0x7e78009f,0x69d40129}},	//   lphi, _māmi, utup, khze, 
   {{0x644422a9,0x7e7a0eb7,0x62880472,0x2b140118}},	//   ophi, rtup, _ipeo, नेछु_, 
   {{0xef840220,0x7bc00108,0x673ce934,0x60b41f0d}},	//   _әліп, ömuo, _ofsj, _جمائ, 
   {{0x6b9c45a7,0x76440784,0x600400d0,0x7e78164b}},	//   gdsg, ypiy, róms, ptup, 
   {{0x6ec46dd9,0x7e780113,0x6d48007c,0x200c03b2}},	//   _متوق, qtup, bbda, mlei_, 
   {{0xdce00034,0x6d4800a3,0x69d414bb,0x6d5c20d2}},	//   zglę, cbda, ghze, órat, 
   {{0x38c86824,0xdc7406a6,0xe4e00ce0,0xfb24004e}},	//   راسی_, _рыль, _गेलि_, _өпкү, 
   {{0x628a0eb8,0x6030002b,0x64440165,0x9a680066}},	//   _opeo, _cāmi, dphi, _قمبل_, 
   {{0x8c180375,0x200cde2b,0xc6c000cf,0x6d5c0162}},	// [3c2c0] _קופי, ilei_, айтк, ðrag, 
   {{0x69d60eb9,0x200e0eba,0x7645277c,0x2f0c00ae}},	//   chze, hlei_, rpiy, lógú_, 
   {{0x395a0ebb,0x60301132,0x76460ebc,0x200e0ebd}},	//   mars_, _fāmi, spiy, klei_, 
   {{0x3958fcbd,0x7644102c,0x6030002b,0x00000000}},	//   lars_, ppiy, _gāmi, --, 
   {{0x200e0ebe,0x00000000,0x00000000,0x00000000}},	//   dlei_, --, --, --, 
   {{0x3958d4f9,0x200c1497,0xda0004fa,0x00000000}},	//   nars_, elei_, लकित_, --, 
   {{0x6288014b,0x644400a3,0xd01800d8,0x39580142}},	//   _epeo, cphi, мфи_, iars_, 
   {{0x395a0ebf,0x42040014,0x200c0064,0x00000000}},	//   hars_, _یسلہ, glei_, --, 
   {{0x395a0ec0,0x0cc800dc,0x00000000,0x00000000}},	//   kars_, ान्म, --, --, 
   {{0x270001fb,0x200c0356,0xadb400d8,0x00000000}},	//   ỗng_, alei_, убош, --, 
   {{0x200c0649,0x395a0ec1,0x6d480006,0xab7816a0}},	//   blei_, dars_, rbda, ىمدا_, 
   {{0x9f900241,0x6b9c01f5,0x6d48022e,0x0c7c0092}},	//   _jáì_, udsg, sbda, _እያለች_, 
   {{0x39589263,0x6b9e0ec2,0x603000de,0x69c400cf}},	//   fars_, rdsg, _rāmi, гөнб, 
   {{0x64460ec3,0x395a0ec4,0x60320ec5,0xf1b8031c}},	//   yphi, gars_, _sāmi, _tiġu_, 
   {{0x603006c8,0x61ee0ec6,0x13c80011,0x6dc401e4}},	//   _pāmi, éali, লোয়, rĉaĵ, 
   {{0x2d9e0ec7,0x5f1800dc,0x290c0374,0x00000000}},	//   _have_, _परम्_, āea_, --, 
   {{0x395a0ec8,0x2b5a0ec9,0x69d4009a,0x09480e58}},	// [3c2d0] bars_, masc_, phze, _очни_, 
   {{0x3958b189,0x2d9c07dd,0x2b5804cc,0xb5d40063}},	//   cars_, _jave_, lasc_, ажуј, 
   {{0x2d9e0eca,0x644400d2,0x60301da6,0xb595a350}},	//   _mave_, uphi, _tāmi, рихш, 
   {{0x2d9e0ecb,0x2b580332,0x00000000,0x00000000}},	//   _lave_, nasc_, --, --, 
   {{0xe2860ecc,0xa1886ca7,0xb60400bc,0x200c05e4}},	//   улли, ебла_, _svář, vlei_, 
   {{0x64460ecd,0x59c402a0,0x6e2400a3,0x9e6401b9}},	//   pphi, रॉपर, _èibh, қвод, 
   {{0xdb14e4d9,0x27e8005a,0xd3440133,0xa4d40212}},	//   _moyá, oian_, _ڕینه_, _сові, 
   {{0x2d9cc5e7,0x66060ece,0x3958bab4,0x200c003e}},	//   _aave_, lohk, zars_, ulei_, 
   {{0x200e0ecf,0x7cd000ac,0x26c8232d,0xde2801c6}},	//   rlei_, mərə, nyao_, нжид_, 
   {{0x27ea0ed0,0x7cd003be,0xd24c04d3,0x200cff68}},	//   hian_, lərə, _رچه_, slei_, 
   {{0x27ea0ed1,0x1be81b10,0x200c1509,0xf1c80046}},	//   kian_, едни_, plei_, _جولى_, 
   {{0x27e82f2b,0x2b5a0ed2,0x6d5e0ed3,0x7cd00213}},	//   jian_, gasc_, órar, nərə, 
   {{0x27ea0ed4,0xd37800c8,0x6440020c,0x395a0ed5}},	//   dian_, ערשט, _élif, tars_, 
   {{0x2d9e0ed6,0x3f9c022f,0x3d24013f,0x3958a573}},	//   _gave_, lduu_, pɑw_, uars_, 
   {{0xd7f0495f,0x660450f9,0x39586d88,0x27ea0ed7}},	//   مكس_, dohk, rars_, fian_, 
   {{0xb8dc14cf,0x27e9b4b1,0x395a0ed8,0x3f9c198f}},	//   _आप_, gian_, sars_, nduu_, 
   {{0x395a0ed9,0x3ab40ae5,0x26c80280,0x2d9e0eda}},	// [3c2e0] pars_, _тәнт, gyao_, _yave_, 
   {{0x60300374,0x27e82a1f,0x2d9c02b9,0x3958013c}},	//   _hāmu, aian_, _xave_, qars_, 
   {{0x27ea0edb,0x60307bc9,0x938832eb,0x7cd003b9}},	//   bian_, _kāmu, есла_, fərə, 
   {{0x27ea0edc,0x2cb80209,0x95842758,0x7cd006be}},	//   cian_, ärdi_, _өлме, gərə, 
   {{0x3f9cbfa3,0x66054c3c,0x603007d7,0x47c40154}},	//   dduu_, bohk, _māmu, রোহী, 
   {{0x26b00150,0x00000000,0x00000000,0x00000000}},	//   _بەكز, --, --, --, 
   {{0x2d9e0edd,0x9028035b,0x7cd003e3,0x00000000}},	//   _rave_, нциа_, bərə, --, 
   {{0x2d9cda09,0x3f9c208d,0x603000b8,0xf1a4000d}},	//   _save_, gduu_, _nāmu, _गोरन, 
   {{0x2d9e0ede,0x644002d3,0xc20c01d9,0xdd1003e3}},	//   _pave_, _çlir, _کٔل_, _püşk, 
   {{0x27ea0edf,0xc6900302,0x3f9c0ba7,0x6fb410e5}},	//   zian_, צאת_, aduu_, امکا, 
   {{0x2d9e0ee0,0x3f9c198f,0xe7f800bc,0x27e800e5}},	//   _vave_, bduu_, ्कमा_, yian_, 
   {{0x27ea0ee1,0x2d9c0c18,0x6030002b,0x8b6417a5}},	//   xian_, _wave_, _cāmu, دادم, 
   {{0x2d9e0ee2,0x2b5822e8,0xe9a801b9,0xee94136e}},	//   _tave_, rasc_, نگدن_, _خداک, 
   {{0x644129ce,0x26c8009f,0xbe60009f,0x00000000}},	//   _élig, vyao_, _اهوي, --, 
   {{0x248c04b9,0x7cd000ac,0x1db00764,0x00000000}},	//   _ćemo_, yərə, जारत, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x660403a2,0xfbd00150,0x81c400e2,0xe554399f}},	// [3c2f0] tohk, _ءتى_, ldēš, икањ, 
   {{0xddc80427,0x12dc0150,0x29040254,0x00000000}},	//   ztež, _ﺃﺒﻘﻭ, ülas_, --, 
   {{0x38c804a9,0x7cd000ac,0x66060ee3,0x291404f2}},	//   _буян_, tərə, rohk, _خودآ, 
   {{0x3f9c0009,0x386c00d7,0x00000000,0x00000000}},	//   xduu_, ádre_, --, --, 
   {{0xa56404d3,0x7cd000ac,0xbb3c010f,0x00000000}},	//   _نگان, rərə, געדי, --, 
   {{0x21a60ee4,0x846c001f,0xa5f80276,0xe0441a92}},	//   рикм, ብሔርን_, _регу_, анки, 
   {{0x38d0031c,0x3158007b,0x245801c6,0x7cd003e3}},	//   ུགརྒ, اجهة_, _шавь_, pərə, 
   {{0x9e64022e,0x69c0007c,0x00000000,0x00000000}},	//   авид, ölej, --, --, 
   {{0xdea00517,0x603000ef,0x6f18013d,0x81c400ef}},	//   تیشی, _rāmu, _ğacä, edēš, 
   {{0x0d800ec6,0xddc80e04,0x5de41173,0x6030002b}},	//   ольн, stež, ржоа, _sāmu, 
   {{0x603002b5,0x5f944727,0x25a000a3,0x2480003b}},	//   _pāmu, _виет, idhl_, nthm_, 
   {{0xb7c004c5,0x00000000,0x00000000,0x00000000}},	//   _ইষ্ট, --, --, --, 
   {{0x201c047e,0x60300055,0x00000000,0x00000000}},	//   _ihwi_, _vāmu, --, --, 
   {{0xdca42c1d,0x603002b5,0x9f900241,0xa154010f}},	//   _ваки, _wāmu, _háà_, יבֿה_, 
   {{0x97c55f28,0x60301da6,0x983402d5,0x9f900248}},	//   айве, _tāmu, рэгі, _káà_, 
   {{0x966400db,0x00000000,0x00000000,0x00000000}},	//   икбе, --, --, --, 
   {{0x2b4c172e,0x9f900ca8,0xd5b0007b,0x60dc03b9}},	// [3c300] ñece_, _máà_, يفر_, _əsma, 
   {{0x7bc400c5,0xd9440640,0x9f900241,0x00000000}},	//   _hoiu, _њени, _láà_, --, 
   {{0x7f5803b4,0x7bc4005a,0x00000000,0x00000000}},	//   kauq, _koiu, --, --, 
   {{0x9f900570,0x201c013f,0x13a801d5,0x843000d4}},	//   _náà_, _nhwi_, کنچی_, ініє, 
   {{0xdb140139,0x95940114,0x00000000,0x00000000}},	//   _doyç, _крвљ, --, --, 
   {{0x5064d74f,0x7bc4c7bf,0x90640114,0x1544010a}},	//   атиа, _loiu, ањил, _тĕкр, 
   {{0x9f900241,0x93585c25,0x1c040764,0x09b40677}},	//   _báà_, _арзу_, रवाल_, יפסט_, 
   {{0xbfa40a8f,0x201c0368,0xcfa4033a,0xc0c4009b}},	//   атье_, _chwi_, ршки, руше_, 
   {{0x932401b9,0xc7d4011a,0xaf54035b,0x91940114}},	//   _ضررن, יוקי_, анқә, _вјеш, 
   {{0x7bc40093,0x61ec0597,0x4cdc05ac,0x00000000}},	//   _aoiu, éalt, _নুগু, --, 
   {{0x12e402dd,0x7dc002f2,0x00000000,0x00000000}},	//   _сіңг, ڵقێن, --, --, 
   {{0x7bc401ab,0xcee8005b,0xfeb40133,0xd01000ae}},	//   _coiu, _идее_, _چاوت_, _بلص_, 
   {{0x3a74021b,0x0a68ff38,0xdb14008e,0x98b80064}},	//   оляр, ърни_, _noyä, _kepė_, 
   {{0x24820ee5,0xa2b8078a,0x1dac0073,0xd1cc0092}},	//   ythm_, ्हत्, _झोपत, ጥፎች_, 
   {{0x6d5800da,0x1e0401f7,0x00000000,0x00000000}},	//   _ieva, _ابنٽ, --, --, 
   {{0x6d5a0ee6,0xa4d80046,0x78a8037e,0x9f900248}},	//   _heva, ңдау_, ædva, _káá_, 
   {{0x6d5a0ee7,0xc9860ee8,0x9f90032e,0x00000000}},	// [3c310] _keva, _куни, _jáá_, --, 
   {{0x6d5a0ee9,0x6a140262,0x35b401f4,0x39a80139}},	//   _jeva, _ымпу, обур, gísı_, 
   {{0x69c4569b,0x6d5a0eea,0x61fc007b,0x9f900241}},	//   _iohe, _meva, _ísli, _láá_, 
   {{0x69c60eeb,0xdafc0589,0x320c010e,0x00000000}},	//   _hohe, vãºc, _akdy_, --, 
   {{0x69c60eec,0x21688540,0x61460eed,0xf4780150}},	//   _kohe, гили_, бела, _ءﻣﻮﻟ, 
   {{0x69c60eee,0x201c00ca,0x6d5a0eef,0xa758005f}},	//   _johe, _shwi_, _neva, šķīg, 
   {{0x69c60ef0,0x7f580d04,0xddc80327,0x00000000}},	//   _mohe, tauq, rteż, --, 
   {{0x69c60ef1,0x6d584add,0x9f9001e1,0xc2e4036b}},	//   _lohe, _aeva, _báá_, _кўзи, 
   {{0x7f580333,0xdee4998c,0x69c49da5,0x7bc4486b}},	//   rauq, сопи, _oohe, _roiu, 
   {{0x6d580ab7,0x69c5db91,0x6454009a,0x7bc43c57}},	//   _ceva, _nohe, _kwzi, _soiu, 
   {{0x72060ef2,0x201c014b,0x7bc402b5,0x9f900241}},	//   _بولم, _thwi_, _poiu, _táà_, 
   {{0xe9f807ae,0x6d5a0ef3,0x00000000,0x00000000}},	//   _trẻ_, _eeva, --, --, 
   {{0x6d5a0ef4,0x9f9001e1,0x320c00a2,0x00000000}},	//   _feva, _gáá_, _ykdy_, --, 
   {{0x6d58bbd7,0x8eb000db,0x225808a5,0x2f180108}},	//   _geva, _رمىش, _æsku_, _точь_, 
   {{0x69c40a40,0x7bc4054e,0x09e0187f,0x00000000}},	//   _dohe, _toiu, чорн, --, 
   {{0x6d58013e,0x9f9001e1,0x00000000,0x00000000}},	//   _zeva, _yáá_, --, --, 
   {{0x69c40270,0x6d5805b8,0x2a3400f7,0x2fc00e89}},	// [3c320] _fohe, _yeva, _мээр, _òige_, 
   {{0x69c60ef5,0x00000000,0x00000000,0x00000000}},	//   _gohe, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69c40526,0x8c34008f,0x00000000,0x00000000}},	//   _zohe, צטנס_, --, --, 
   {{0x69c40530,0x00000000,0x00000000,0x00000000}},	//   _yohe, --, --, --, 
   {{0x4a9808a8,0x518401c6,0x63800332,0xd4d40024}},	//   טינג, ёула, tánó, _лібэ, 
   {{0x6d5a0ef6,0x69c199c0,0x9f9001a8,0x64580210}},	//   _reva, ölei, _sáá_, ćwic, 
   {{0x6d5a0ef7,0x603000b8,0xe4e00037,0x00000000}},	//   _seva, _sāmr, _गेटि_, --, 
   {{0x6d5a0ef8,0x0dc8c99b,0x00000000,0x00000000}},	//   _peva, гуни_, --, --, 
   {{0x6d58014f,0x918400f1,0x9f90032e,0xa2441699}},	//   _qeva, _دجرم, _váá_, _بیول_, 
   {{0x69c60ef9,0x6d5a0efa,0xce307c91,0x9f900cad}},	//   _rohe, _veva, _کوتک, _wáá_, 
   {{0x69c60efb,0x6d5805b8,0xddc80311,0x9f9001e1}},	//   _sohe, _weva, pseş, _táá_, 
   {{0x69c60efc,0x0ae87427,0xac98e4c4,0x603000cd}},	//   _pohe, ارجي_, _چنتا_, _tāmr, 
   {{0x69c40200,0x2cb8007c,0x00000000,0x00000000}},	//   _qohe, ärds_, --, --, 
   {{0x999801ed,0x9f4c00d8,0x61fc01ab,0x69c4002f}},	//   _cipő_, _énão_, _ìsle, _vohe, 
   {{0x69c60efd,0xd2f0074d,0x00000000,0x00000000}},	//   _wohe, _кiир, --, --, 
   {{0x6b8e0efe,0x00000000,0x00000000,0x00000000}},	// [3c330] _ibag, --, --, --, 
   {{0x6aae0eff,0xa2b8043e,0xbb481291,0x00000000}},	//   _iraf, ्हस्, _پلین_, --, 
   {{0x6b8c020c,0x6aae0f00,0x3494299f,0x00000000}},	//   _kbag, _hraf, захр, --, 
   {{0x6b8c00ca,0xe3140063,0x1acc00fe,0x27ec0166}},	//   _jbag, омењ, ৰপৰা, _öen_, 
   {{0x6b8e0f01,0xc6a55fe4,0xe2f802dd,0xf1a80133}},	//   _mbag, _урни, шеді_, ڵاوه_, 
   {{0x6b8c0083,0x00000000,0x00000000,0x00000000}},	//   _lbag, --, --, --, 
   {{0x602402d5,0x6b8c877b,0x86f8015b,0x397c01e4}},	//   одка, _obag, _আরিফ_, אטונ, 
   {{0x7a20049f,0x6aae0f02,0x6b8e0f03,0x60300055}},	//   möte, _oraf, _nbag, _cāmp, 
   {{0xd00c28fa,0x7a220f04,0x9f4c0ea0,0x00000000}},	//   خلي_, löte, lieë_, --, 
   {{0x6b8c51a9,0x27ec012c,0x00000000,0x00000000}},	//   _abag, čeny_, --, --, 
   {{0x6aacc6c2,0x6b8c04ba,0x9f4c017a,0x0d20004e}},	//   _araf, _bbag, nieë_, мүшү, 
   {{0x547804ae,0x00000000,0x00000000,0x00000000}},	//   סטרו, --, --, --, 
   {{0x6b8c020c,0x2b4c98fa,0x9f0400f7,0x6aad13e4}},	//   _dbag, ñeca_, _بوشو, _craf, 
   {{0x6aae0f05,0x7a2036bf,0x6b8c3eda,0x211c0073}},	//   _draf, köte, _ebag, _फराळ_, 
   {{0x6aac12ce,0x7a20007c,0x00000000,0x00000000}},	//   _eraf, jöte, --, --, 
   {{0x6b8cacd9,0x6aae0f06,0x9f4c0af9,0xdb1401e1}},	//   _gbag, _fraf, dieë_, _moyú, 
   {{0x6aacffe4,0x7bc001f4,0x00000000,0x00000000}},	// [3c340] _graf, ömuu, --, --, 
   {{0x9f4c0af9,0x2b440118,0x00000000,0x00000000}},	//   fieë_, ělce_, --, --, 
   {{0x9f4c05e4,0x7a200432,0x00000000,0x00000000}},	//   gieë_, göte, --, --, 
   {{0xccf00375,0x69c026bb,0x138800ae,0x00000000}},	//   וכב_, ölev, شخصى_, --, 
   {{0xe7f8b1e3,0x96b81887,0x23b401e1,0x00000000}},	//   ्करा_, _туну_, _ẹjá_, --, 
   {{0x81341b56,0x3dc40100,0x9f4c017a,0x7a2001e3}},	//   يسىز_, _nonw_, bieë_, böte, 
   {{0xfd04066d,0xcf980798,0xe194009d,0x00000000}},	//   _آج_, ајп_, ярцэ, --, 
   {{0xd2a4030d,0x00000000,0x00000000,0x00000000}},	//   _нiаь, --, --, --, 
   {{0x6fdc0231,0x3878036e,0x00000000,0x00000000}},	//   _néce, hurr_, --, --, 
   {{0x6b8c8ea9,0x7ddc002d,0x0f40001f,0x38780086}},	//   _sbag, _lêsf, _የጀመረ, kurr_, 
   {{0x6aac0114,0xed5001e2,0x00000000,0x00000000}},	//   _sraf, وپک_, --, --, 
   {{0x6aadebf7,0x6fe8033f,0x387800a3,0xcbe400d4}},	//   _praf, kści, durr_, іцни, 
   {{0x6fe8068f,0x6aac00ac,0x8d84010b,0x2ee00fac}},	//   jści, _qraf, _дуйд, _åif_, 
   {{0x6fdc0231,0x9e6402dd,0xbe1001ec,0x6aac036e}},	//   _déce, _ءانن, _قونع, _vraf, 
   {{0x6fe8033f,0xe9180212,0x6b8d24c3,0x02b400cd}},	//   eści, сові_, _tbag, _आप्न, 
   {{0x6b8dc61f,0x00000000,0x00000000,0x00000000}},	//   _ubag, --, --, --, 
   {{0x6aae0f07,0x9e2401d9,0x00000000,0x00000000}},	// [3c350] _uraf, _بى۪و, --, --, 
   {{0x05740a52,0x29000211,0x7a21560d,0x45480107}},	//   تارد, _txha_, töte, рчам_, 
   {{0x6514007b,0x00000000,0x00000000,0x00000000}},	//   أوائ, --, --, --, 
   {{0x9f4c0660,0x3cf800c8,0x27ec00bc,0x7a20002f}},	//   rieë_, סלאנ, émně_, röte, 
   {{0xd3440214,0x978001d5,0x057400e3,0x9f4c0ea0}},	//   سیله_, _سیله, _واسد, sieë_, 
   {{0xf1c80efb,0x614438a7,0xfa780302,0xf364151e}},	//   يونى_, чека, קעות_, птән, 
   {{0x241809a5,0xe0d06fd4,0xf958011a,0x96e001e1}},	//   _говы_, عزت_, חסות_, _ò̟rà, 
   {{0xe3c405f5,0x3dc40100,0x78fc010f,0x1f6433d2}},	//   _эргү, _sonw_, יפוו, чким, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6fdc0231,0x38780083,0x00000000,0x00000000}},	//   _réce, yurr_, --, --, 
   {{0x1d0a0f08,0x6fdc7c6e,0x80d001c8,0x00000000}},	//   сени_, _séce, _تماچ, --, 
   {{0x6fe8033f,0x69d401e4,0x7ff40066,0x00000000}},	//   yści, ekze, _بسطا, --, 
   {{0x1ca404d3,0x200e0f09,0x00000000,0x00000000}},	//   زێکی_, moei_, --, --, 
   {{0xaec43981,0x200cd71c,0x1ea80451,0x6db400cf}},	//   _юбіл, loei_, _ناڻي_, _ойчу, 
   {{0xd8247579,0xc0e4002b,0x00000000,0x00000000}},	//   здви, _pāṇi_, --, --, 
   {{0x75e20f0a,0x200ccd9c,0x00000000,0x00000000}},	//   _közg, noei_, --, --, 
   {{0x7c260f0b,0x3eac0175,0xddc8054e,0x3878007c}},	// [3c360] _ihir, _jrgt_, creţ, surr_, 
   {{0x69d60f0c,0x3ebc00db,0x6fe8033f,0x920000e2}},	//   ckze, ixut_, rści, ļāka, 
   {{0xc950159d,0x7c260f0d,0x200e0f0e,0x00000000}},	//   _אמת_, _khir, koei_, --, 
   {{0x73fc000e,0x3eae0f0f,0x7c2400b5,0x6fdc002e}},	//   েষ্ট_, _orgt_, _jhir, _mécc, 
   {{0x64408851,0x7c240433,0x200c005a,0xebac010f}},	//   _élin, _mhir, doei_, יסאָ, 
   {{0x7c240280,0xabe40150,0x00000000,0x00000000}},	//   _lhir, _ﻏﻠﻤﺎ, --, --, 
   {{0x7c260f10,0x3eac007c,0x2ed400cd,0x00000000}},	//   _ohir, _argt_, धन्त, --, 
   {{0x7ddc002d,0x200c01c4,0x7c240042,0x03a068eb}},	//   _lêsd, goei_, _nhir, _писо, 
   {{0xe9f800c7,0xb4ac05f9,0xdd100432,0xe7d49f9f}},	//   _arẽ_, _कछु_, _hüňk, _lığı, 
   {{0x7c260f11,0x80d000db,0x00000000,0x00000000}},	//   _ahir, بۅۅچ, --, --, 
   {{0x2b4c0407,0xfc600032,0x7c260f12,0x200e0f13}},	//   ñeco_, нъян, _bhir, boei_, 
   {{0xddc80276,0xdfa8088c,0xdd10010e,0x1fa400d4}},	//   treţ, _وطنه_, _müňk, _оріг, 
   {{0x7c260f14,0x6e9401b9,0x75e20f15,0x0dc80117}},	//   _dhir, _آلتا, _gözg, _гуйи_, 
   {{0x7c24d32a,0x6860010c,0xb9c401b9,0xe7d406be}},	//   _ehir, _ገብረስ, нёси, _bığı, 
   {{0x7c240084,0x69d60f16,0xe7d403b9,0xa8480035}},	//   _fhir, rkze, _cığı, تلزم_, 
   {{0x2d8c292b,0x7c260f17,0xbd14011a,0xddc80356}},	//   lfde_, _ghir, _מחוז_, preţ, 
   {{0x2d8c0926,0x69c00254,0x00000000,0x00000000}},	// [3c370] ofde_, öles, --, --, 
   {{0x2a6800f3,0x24f81e76,0x200c009d,0x7a20002f}},	//   _ivab_, онзы_, zoei_, rötc, 
   {{0xdb14033b,0x7c2400b5,0x249833ae,0x00000000}},	//   _anyè, _yhir, تناد_, --, 
   {{0xf1b80327,0x7c240023,0x7a2001e6,0x200c01c4}},	//   _anġ_, _xhir, möta, xoei_, 
   {{0x21a4086f,0x5ed00c58,0x248c0841,0xc6a46be1}},	//   дилм, _তেনে, _ćemu_, _эрни, 
   {{0xe7d4b6d6,0x2d8c0196,0xd00c6f5d,0xd24c0472}},	//   _yığı, jfde_, یلو_, جنو_, 
   {{0x34940fc0,0x200c009d,0x10a185fb,0x75e02ca8}},	//   _парр, toei_, вищн, _dözd, 
   {{0x2d8c1af3,0x7ddc0120,0xd3440424,0x6fdc1bce}},	//   efde_, _mêse, _قیمه_, _récc, 
   {{0x200e0f18,0x236c151c,0x00000000,0x00000000}},	//   roei_, _idej_, --, --, 
   {{0x1c460f19,0x7c260f1a,0xe9e40589,0x75e09e1c}},	//   мном, _shir, åºle_, _gözd, 
   {{0x7c260f1b,0x2b480175,0x2a6800c5,0xd00c136e}},	//   _phir, _bfac_, _avab_, طلی_, 
   {{0x2d8c6e1c,0x3078e591,0x3eac0175,0x2cb80267}},	//   afde_, _رحمة_, _trgt_, årda_, 
   {{0x7c24004c,0xe7d406b9,0x6fdc002e,0x75e0008e}},	//   _vhir, _sığı, _wécc, _yözd, 
   {{0x7c240325,0x75e0066d,0xae040075,0xdb0401ed}},	//   _whir, _köze, _كونى, ndké, 
   {{0x7c260f1c,0x236c0010,0x2b480142,0x6fdc0129}},	//   _thir, _odej_, _ffac_, _héca, 
   {{0x7c260f1d,0x6fdca507,0x224c0489,0x236c0200}},	//   _uhir, _kéca, _otek_, _ndej_, 
   {{0x224c7cda,0x7e780607,0xdb14003e,0x95c80276}},	// [3c380] _ntek_, nuup, _onyé, олаб_, 
   {{0x6fdc20ef,0xf1d8009e,0xc68c0014,0xe7d4008e}},	//   _méca, _তদ্ভ, شِم_, _tığı, 
   {{0x799e0f1e,0x224c0113,0xd2a40064,0x49b8011a}},	//   merw, _atek_, _мiль, _ומיס, 
   {{0x7e7a0f1f,0x799e0f20,0x75e102ea,0x68f801d3}},	//   kuup, lerw, _sözd, őadó, 
   {{0x91e47111,0xddc8596b,0x7e780140,0x7764005a}},	//   моде, zreš, juup, maix, 
   {{0x7ddc000f,0x98a80aba,0x77660f21,0xdd040118}},	//   _lêsb, labı_, laix, ápět, 
   {{0x224d80f0,0x61440131,0xa49007d6,0x76445431}},	//   _etek_, رىيە, _میلت, lqiy, 
   {{0x77640137,0x799c6adb,0x6fde0f22,0x75e0010e}},	//   naix, herw, _béca, _döze, 
   {{0x799e0f23,0x7e7a0f24,0xd18401d5,0xdce00205}},	//   kerw, guup, _олай, delı, 
   {{0xddc810bf,0x236c09a8,0x77660f25,0x98a81432}},	//   treš, _zdej_, haix, habı_, 
   {{0x428c069c,0x75e20f26,0x05740302,0x799e0f27}},	//   _ሓርነት_, _göze, וגים_, derw, 
   {{0x6fdd2e45,0x00000000,0x00000000,0x00000000}},	//   _féca, --, --, --, 
   {{0x6fdc02ea,0x799e0f28,0x0dc83f36,0x753c0034}},	//   _géca, ferw, _муки_, _ogrz, 
   {{0x799e0f29,0xddca0f2a,0x7a20023a,0x245401e1}},	//   gerw, preš, töta, _júmò_, 
   {{0x290405d1,0x77640798,0x6d4803ac,0xdce00205}},	//   çla_, faix, mcda, belı, 
   {{0x2904003d,0x6e380455,0x2b4804cc,0x7764005a}},	//   ħla_, _hivb, _ufac_, gaix, 
   {{0x799e0f2b,0x6b9e0f2c,0x7644009a,0x4c9001b9}},	// [3c390] berw, mesg, gqiy, _чиқс, 
   {{0x6b9e0f2d,0x799c127b,0xe820000d,0x6d4a0f2e}},	//   lesg, cerw, _मठवा_, ncda, 
   {{0x7765c587,0x7644058a,0x6d48611a,0x98a8afe3}},	//   baix, aqiy, icda, babı_, 
   {{0x77660f2f,0x644007ea,0x6b9e0f30,0xf4080150}},	//   caix, _élim, nesg, ويلى_, 
   {{0x4630035b,0x224c0327,0x75e018ca,0x00000000}},	//   _аҭар, _qtek_, _söze, --, 
   {{0x6fdc004a,0x6e38014f,0x7a7c011a,0x224c00c0}},	//   _réca, _nivb, קרוס, _vtek_, 
   {{0x656442c9,0x6b9c78d0,0x6fdcb0f7,0x7a2000e5}},	//   mahh, kesg, _séca, kötn, 
   {{0x44282508,0x6b9e0f31,0x799e0f32,0x7e7a0f33}},	//   _òc_, jesg, zerw, tuup, 
   {{0x6b9e0f34,0x6e380477,0x799e0f35,0x224c82af}},	//   desg, _bivb, yerw, _utek_, 
   {{0x63a80226,0x75e00598,0x7e7a0f36,0xf1b40032}},	//   _haen, _töze, ruup, _аҡш_, 
   {{0x63aa0f37,0x7e7820ac,0x6e380334,0x799c6460}},	//   _kaen, suup, _divb, verw, 
   {{0xff50fbe5,0x799e0f38,0x63a8020b,0x7e7a0f39}},	//   _شخص_, werw, _jaen, puup, 
   {{0x799e0f3a,0x63aa0f3b,0x98a80259,0x22885f5b}},	//   terw, _maen, vabı_, núk_, 
   {{0x63aa0f3c,0x69c000af,0x799c0112,0x98a40395}},	//   _laen, ölep, uerw, ниге, 
   {{0x98a90b83,0x64440218,0x6b9c3203,0x290c054e}},	//   tabı_, jqhi, besg, şean_, 
   {{0x63a80226,0x07a20f3d,0x799e0f3e,0x76440cfe}},	//   _naen, ласн, serw, tqiy, 
   {{0x64440472,0x6e38047e,0x799c5337,0x98a80ab5}},	// [3c3a0] eqhi, _yivb, perw, rabı_, 
   {{0x9f5c063f,0x63aa0f3f,0x98a81d89,0x7764005a}},	//   _akwü_, _aaen, sabı_, saix, 
   {{0x63a80207,0x64440472,0x76440ba7,0x776400d8}},	//   _baen, gqhi, sqiy, paix, 
   {{0x63a80226,0x1304bbf6,0x65660f40,0xd3704957}},	//   _caen, нзем, aahh, اهش_, 
   {{0x63a80207,0x64440cfe,0x764407d6,0x91bc0d0d}},	//   _daen, aqhi, qqiy, _एचआई, 
   {{0x7be00227,0x64440218,0x26280165,0x39580327}},	//   _ŋqul, bqhi, rïoù_, nbrs_, 
   {{0x63aa0f41,0xc9500302,0x68040024,0xf2e8004b}},	//   _faen, נמה_, lėda, _ښکته_, 
   {{0x63a80097,0x6e380455,0x6b9c009a,0xdb1403b9}},	//   _gaen, _sivb, xesg, _boyü, 
   {{0x8d8484dd,0xb17c0115,0x68040024,0x6e38014f}},	//   нунд, _alĥe, nėda, _pivb, 
   {{0x63aa0f42,0x6e38014f,0x6b9c0472,0x6d480067}},	//   _zaen, _qivb, wesg, ucda, 
   {{0x63a80097,0x6b9e0f43,0x50b5a3a0,0x6e3801e4}},	//   _yaen, tesg, _ясау, _vivb, 
   {{0xdb140793,0x7ddc05d5,0x6e38047e,0x68040024}},	//   _foyü, _pêsc, _wivb, kėda, 
   {{0x6b9e0f44,0x6e38047e,0x6d4803ac,0x00000000}},	//   resg, _tivb, pcda, --, 
   {{0x6b9e0f45,0xa2c00490,0x68040024,0x64440113}},	//   sesg, लमत्, dėda, yqhi, 
   {{0xdb140085,0xae040131,0xe6a92e16,0x6b9e0f46}},	//   _boyó, _كوچى, _köçä, pesg, 
   {{0x65640a2e,0x0df016cb,0x7c801cc9,0x6fdc4056}},	//   wahh, _جيڪڏ, _суше, _méco, 
   {{0xb8c811b1,0xdef4044e,0x63aa0f47,0x0f1c07f7}},	// [3c3b0] _खै_, _ጎደና_, _raen, _परोस_, 
   {{0x63aa0f48,0x39540316,0x6440020c,0x60300055}},	//   _saen, časí_, _élik, _dāmy, 
   {{0xe1f02ad9,0x63aa0f49,0x64440cfe,0x6fdc0005}},	//   یست_, _paen, uqhi, _néco, 
   {{0x7ddc0165,0x68040153,0x65643178,0x00000000}},	//   _mêsa, bėda, sahh, --, 
   {{0x63aa0f4a,0x36d40d97,0xa2c02e3b,0x74540131}},	//   _vaen, _бояр, लमध्, نپەئ, 
   {{0x63aa0f4b,0x22895f41,0xf99400c8,0x656401a9}},	//   _waen, rúk_, ָרק_, qahh, 
   {{0x63aa0f4c,0x91e024ab,0x756801d3,0xdce0031c}},	//   _taen, роще, _سینہ_, ralċ, 
   {{0x6fdc2047,0xdb1401b8,0x6030002b,0xf10800db}},	//   _déco, _poyü, _yāmy, رۉنۉ_, 
   {{0x6fdc74c3,0xdee42a1c,0xa3000184,0x442cb85b}},	//   _técn, топи, _әүҙе, mmg_, 
   {{0x6fdc004a,0x442c0e89,0x1cac0327,0x75e000e5}},	//   _féco, lmg_, _པླུ_, _köza, 
   {{0x2d940022,0x70580117,0x00000000,0x00000000}},	//   урыс, _захр_, --, --, 
   {{0x1e944b36,0x442c020c,0x7a200108,0x00000000}},	//   _аркр, nmg_, töto, --, 
   {{0x442c010a,0x3254030d,0x00000000,0x00000000}},	//   img_, _ывăр, --, --, 
   {{0x3f9c0270,0xddc8012d,0x00000000,0x00000000}},	//   leuu_, speł, --, --, 
   {{0xdca49faf,0x442c01d9,0x603000cd,0x00000000}},	//   _райи, kmg_, _sāmy, --, 
   {{0xdce00010,0x442c01e7,0x00000000,0x00000000}},	//   nalč, jmg_, --, --, 
   {{0xa3d402f8,0x4aa400f7,0x07a001f4,0x00000000}},	// [3c3c0] ाउन_, _акын_, шатн, --, 
   {{0x680402d5,0xdb0401ed,0x00000000,0x00000000}},	//   rėda, ndkí, --, --, 
   {{0x0f1c0f4a,0xb4ac9e3f,0x00000000,0x00000000}},	//   _पर्स_, कटे_, --, --, 
   {{0xb9dc067d,0x6fde0f4d,0xdce00427,0x603000b8}},	//   _ኣሎ_, _réco, jalč, _tāmy, 
   {{0x6fdc0231,0xdce00427,0x5fc40b98,0xc7a000db}},	//   _décl, dalč, वानल, _тияк, 
   {{0x82903baf,0x23080c8b,0xa56401b9,0xcad40375}},	//   شۇمچ, رتني_, _مدفن, כונת_, 
   {{0x80a08b4d,0x75e003ee,0x00000000,0x00000000}},	//   لمون, _göza, --, --, 
   {{0x70800020,0x0874008f,0xe05400f2,0xdce00419}},	//   _የክልሉ_, דעקט_, اینت_, galč, 
   {{0xc241a427,0xb64400b5,0x0e080139,0x1f5400db}},	//   _внук, _ｎｚ_, дэни_, دعىڭ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc20c0050,0xcfa400d1,0x00000000,0x00000000}},	//   _بٔل_, _ашли, --, --, 
   {{0x40a8e66f,0x8fa403b7,0x7ddc0165,0x8b6400ae}},	//   _زخمی_, _јаде, _vêsa, خادم, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x442c0354,0xc3300302,0x290c0356,0x00000000}},	//   zmg_, יור_, şeam_, --, 
   {{0x39e86b2f,0xac94009d,0xeda40117,0x00000000}},	//   тьян_, _сайш, _ашқо, --, 
   {{0x5fc40490,0xdce0005f,0x93380023,0xf99001d9}},	//   वायल, zglī, እስትታ, ٝبہ_, 
   {{0x6fdc5725,0x75e0399d,0x00000000,0x00000000}},	// [3c3d0] _récl, _söza, --, --, 
   {{0xa3e400e1,0xc8660f4e,0x69c40ce8,0xdce0007f}},	//   _फतह_, _итми, _сөмб, zalč, 
   {{0x335001f2,0x442e0f4f,0xdb080793,0xbd740092}},	//   _ịsọm, tmg_, ünöl, _በአቅም_, 
   {{0x2fc001c3,0x62240131,0x77380145,0x00000000}},	//   _òigh_, گىتل, ركەز_, --, 
   {{0x68040024,0x442c00d8,0x02c00137,0x212400d0}},	//   lėdo, rmg_, рилү, _szlh_, 
   {{0x20882ae3,0xbbd00b03,0x442c00d8,0x00000000}},	//   ейки_, _हक्क, smg_, --, 
   {{0x25a00112,0x75e20f50,0x00000000,0x00000000}},	//   mehl_, _közn, --, --, 
   {{0x1e8400f3,0x9ea800d8,0x00000000,0x00000000}},	//   глим, евиа_, --, --, 
   {{0xdb14022c,0xdce10454,0x8168009b,0x00000000}},	//   _noyð, ralč, _жреб_, --, 
   {{0x41b400e1,0x623439b8,0x5ca401a9,0x00000000}},	//   _आफिस, _сезу, гиоб, --, 
   {{0x229c0241,0x00000000,0x00000000,0x00000000}},	//   bákò_, --, --, --, 
   {{0x50d8010f,0xf0e800d1,0x92d403d4,0x60c4002f}},	//   _אקעא, _جىمى_, াছৰ_, ähmu, 
   {{0x7f5801f0,0x7a20007c,0x00000000,0x00000000}},	//   mbuq, sötm, --, --, 
   {{0xdb14022c,0x38c803e6,0x1d080b7e,0x7e78014f}},	//   _doyð, پاسی_, _пели_, mrup, 
   {{0x48e000d8,0x00000000,0x00000000,0x00000000}},	//   борв, --, --, --, 
   {{0x7ae800aa,0x2cb8353e,0x00000000,0x00000000}},	//   _لوبې_, ærde_, --, --, 
   {{0x25a02ba9,0xc6c80131,0x7e78daaa,0xb4ac000d}},	// [3c3e0] fehl_, ىدكە_, nrup, कट्_, 
   {{0x80b00c2e,0xab280150,0xc560004e,0x00000000}},	//   ंटाइ, _جسىل_, йкук, --, 
   {{0x7e78047e,0x2874013d,0xe63401c6,0x675400e5}},	//   hrup, _кыяр, рхтэ, _چیفس_, 
   {{0x13095e19,0x75e000a2,0x7e7a0f51,0x00000000}},	//   нней_, _gözn, krup, --, 
   {{0xa3b402ab,0x7e78047e,0x25a001ef,0x00000000}},	//   _जफर_, jrup, behl_, --, 
   {{0x7e7a0f52,0xf484030f,0xd9f40d2e,0x00000000}},	//   drup, _پاسی, ुचित_, --, 
   {{0x7e7a0f53,0x75e0008e,0x73c4586a,0x00000000}},	//   erup, _yözn, _вәле, --, 
   {{0x75e001d3,0x7e798607,0x6e9801d5,0x00000000}},	//   _közo, frup, ввир_, --, 
   {{0xe2a801d9,0x4ee00154,0xf10800cf,0x00000000}},	//   _لالن_, মপ্ল, رۉچۉ_, --, 
   {{0xdb140162,0xadf53eab,0xa02000ee,0x00000000}},	//   _royð, рпош, _ýöne, --, 
   {{0x7e780140,0xfe6d1cc1,0x2c4c01ef,0x00000000}},	//   arup, يدی_, _běda_, --, 
   {{0x92d42b1b,0x0ba8215c,0x6fdc01c7,0x7e78047e}},	//   াছী_, راجى_, _méck, brup, 
   {{0x6fdc04e6,0x644000d8,0xdef8002e,0xa3d40037}},	//   _léck, _éliv, yaŋi_, ाउत_, 
   {{0x3da000a7,0x23ac00c0,0x00000000,0x00000000}},	//   _гръб, _iųjų_, --, --, 
   {{0xe91802bf,0x6fdc01c7,0xa934023a,0xfc300244}},	//   тові_, _néck, ревш, تحی_, 
   {{0x6a14013e,0x61d17ef5,0x00000000,0x00000000}},	//   умҳу, _तक्ष, --, --, 
   {{0x5fc40574,0x3b5400fd,0x00000000,0x00000000}},	// [3c3f0] वातल, _укыр, --, --, 
   {{0x6fdc01c7,0xeb5000cf,0xc98421f3,0x00000000}},	//   _béck, _دۉڭگ, _суии, --, 
   {{0xc340074d,0x00000000,0x00000000,0x00000000}},	//   йĕн_, --, --, --, 
   {{0x836483bd,0x6fdc0221,0x25a0009a,0x7e780113}},	//   ادال, _déck, sehl_, yrup, 
   {{0x27ea0f54,0x75e20f55,0x00000000,0x00000000}},	//   mhan_, _közl, --, --, 
   {{0x27ea0f56,0x6fdc0221,0x7e78047e,0x00000000}},	//   lhan_, _héch, vrup, --, 
   {{0xdb1400d2,0x27ea0f57,0x7e7825de,0x00000000}},	//   _mnyá, ohan_, wrup, --, 
   {{0x27ea0f58,0x645401c6,0x1e940fc0,0x201800d2}},	//   nhan_, _itzi, арор, ôsi_, 
   {{0x6fdc59c6,0x6440011c,0xdce00f40,0x443c01f7}},	//   _méch, _èlib, dalā, _iiu_, 
   {{0x443e0f59,0x6fdc004a,0x27e8003e,0xc6e80327}},	//   _hiu_, _léch, hhan_, _ལྟབུ, 
   {{0x443c30fb,0x7e7a0f5a,0x1d081515,0x31c407b5}},	//   _kiu_, srup, тени_, _уств, 
   {{0x443e0f5b,0x6d5c0579,0x6fdc0036,0xdb1401ed}},	//   _jiu_, ðrar, _néch, _anyá, 
   {{0x27ea0f5c,0x443e0f5d,0xddc407d8,0x2c4c00bc}},	//   dhan_, _miu_, _вбли, _věda_, 
   {{0x443e0f5e,0x657407a9,0x27e80014,0x26c8005a}},	//   _liu_, _ndzh, ehan_, dxao_, 
   {{0x7a200639,0x443e0f5f,0xa3b4b305,0x6fdcaa1d}},	//   nöti, _oiu_, जया_, _béch, 
   {{0x27ea0f60,0x443e0f61,0x6fdc0a40,0xd7040c56}},	//   ghan_, _niu_, _réck, азби, 
  
   {{0x6fddc6b2,0x64560f62,0x6b840046,0x8c18011a}},	// [3c400] _déch, _atzi, _اشىل, _שופי, 
   {{0x75e054de,0x443c06a3,0x779404d3,0x0564012c}},	//   _gözl, _aiu_, _گیرا, říně_, 
   {{0x443c23e0,0x27ea0f63,0x00000000,0x00000000}},	//   _biu_, bhan_, --, --, 
   {{0x27ea0f64,0x443e0f65,0x65759bd7,0xfe660f66}},	//   chan_, _ciu_, _edzh, _ود_, 
   {{0xe9f80248,0x645430ab,0xf4c802dd,0x6fdc0036}},	//   _asẹ_, _etzi, _ءﺳﻮﺯ, _wéck, 
   {{0x443c0c95,0x823056e8,0x6fdc0036,0x75e001d3}},	//   _eiu_, يروا, _zéch, _közm, 
   {{0x443e0f67,0x7a200086,0x21640220,0xbfac00cc}},	//   _fiu_, röth, стіг, কানঘ, 
   {{0x443e0f68,0x5274036b,0x0440e564,0x00000000}},	//   _giu_, _вужу, _фетн, --, 
   {{0x25b40332,0xdb0401bf,0x00000000,0x00000000}},	//   _éaló_, ldkæ, --, --, 
   {{0x27ea0f69,0x443c2b1d,0xebb80055,0x2d98035b}},	//   zhan_, _ziu_, _viḍ_, ýre_, 
   {{0x443c0007,0x27e94c76,0x64420f6a,0x2cb803b2}},	//   _yiu_, yhan_, _élit, írd_, 
   {{0x75e09e1c,0xaa58711b,0xe4f89201,0x443c0051}},	//   _sözl, лиму_, ्पति_, _xiu_, 
   {{0x27e82b92,0x6fde0f6b,0x6d5c1918,0xaca40241}},	//   vhan_, _réch, ırab, _irọy, 
   {{0x6fde0f6c,0x27ea0f6d,0xce3001d5,0x9f9001a8}},	//   _séch, whan_, _بوتک, _háð_, 
   {{0x27ea0f6e,0x6c860f6f,0x6fde0f70,0x4789cb6a}},	//   than_, _العم, _péch, ксам_, 
   {{0x27e89487,0xb17c01e4,0x75e02a9b,0x37c41f5a}},	//   uhan_, _olĥo, _dözm, ољуб, 
   {{0x443e0f71,0x6fdd0b13,0x6b8de7c0,0xa3d42356}},	// [3c410] _riu_, _céci, _icag, ाउस_, 
   {{0x443e0f72,0x6fde0f73,0x9f4c0589,0x6aadace6}},	//   _siu_, _déci, mieå_, _isaf, 
   {{0x443c4ef6,0xfa35eb45,0x75e10ddf,0xf56801d3}},	//   _piu_, _بريد, _gözm, شمنٹ_, 
   {{0xd004004e,0x9f900008,0x8d880092,0x00000000}},	//   _رل_, _náð_, ናቀቃል_, --, 
   {{0xe29a0f74,0x6aac0327,0xf6c800f7,0xd36c143e}},	//   уал_, _jsaf, _кырк_, رهو_, 
   {{0x6aac0451,0xa18a0f75,0x7a20005b,0x75e00166}},	//   _msaf, убка_, töti, _yözm, 
   {{0x443c1a4c,0x645401c0,0x6b8e0f76,0x03c400d8}},	//   _tiu_, _utzi, _ocag, _ксам, 
   {{0x6aac02ce,0x443e0f77,0x6f060e6f,0x5f2800f7}},	//   _osaf, _uiu_, _žica, лойм_, 
   {{0xa158e9fa,0x6aac013f,0x9f9002d2,0x00000000}},	//   _базу_, _nsaf, _dáð_, --, 
   {{0x3f500a28,0x6b8dab1d,0x3f74001e,0xf424031c}},	//   ṣu_, _acag, ểu_, _འཚོད_, 
   {{0x6aac013b,0x64420f78,0x6b8c0076,0xdca40416}},	//   _asaf, _élis, _bcag, щани, 
   {{0xdca40fc0,0xb44c0023,0x9f90032e,0x2cb803b2}},	//   _ҳаки, _ብኣህጉ, _gáð_, ærda_, 
   {{0x201c0472,0xdb4c03e6,0x6e960f79,0x75e08021}},	//   _ikwi_, وێژ_, _мицу, _sözm, 
   {{0x6fde0f7a,0x6d5c046c,0x87e41b56,0x9f4c00fd}},	//   _réci, ırac, ەتكە, mneñ_, 
   {{0x6aac209c,0x7ddc002d,0x9f4c0724,0xc7740137}},	//   _esaf, _lêsk, lneñ_, өттө, 
   {{0x57440b7e,0x999800bc,0xf4240327,0x9f50007f}},	//   снаб, _tipů_, _འཚེད_, èbèk_, 
   {{0x7bc60f7b,0x915c004d,0x00000000,0x00000000}},	// [3c420] _iniu, _lắm_, --, --, 
   {{0x27f80175,0xd1f801f3,0x00000000,0x00000000}},	//   _emsn_, ላበት_, --, --, 
   {{0x201c06c5,0x27f80175,0x915c0051,0x64a400c7}},	//   _okwi_, _fmsn_, _nắm_, ҩаӡа, 
   {{0x201c1dc9,0x9f4c0724,0x6aac01a9,0x973401c6}},	//   _nkwi_, kneñ_, _ysaf, _гэгч, 
   {{0x9f902242,0x25b05063,0x8c18025d,0x427001ec}},	//   _ráð_, _fazl_, נוני, згіс, 
   {{0xb9f00020,0x201c0fec,0xd468e3e8,0x9f902507}},	//   _ነኝ_, _akwi_, _محرم_, _sáð_, 
   {{0xd01801fe,0x915c0051,0xdb0401e3,0x9358009b}},	//   лфи_, _cắm_, ldkä, _брзу_, 
   {{0xdb140166,0xafd828eb,0xd2a4010a,0x9f4c013d}},	//   _knyä, рдиф_, _мiаь, fneñ_, 
   {{0xd254036b,0x7a2199c0,0xff4c131e,0xdb04fb94}},	//   _ایتش_, lötu, رخي_, ndkä, 
   {{0x7bc404fb,0x6b8e0f7c,0x201c01e2,0x644006af}},	//   _aniu, _scag, _ekwi_, _élir, 
   {{0xfbc40574,0x1da805b5,0xddc8238f,0x4598008f}},	//   षांम, _कसरत, brež, נסטע, 
   {{0xac180dbb,0x8e7000d1,0x6aac00d8,0xc4d0011a}},	//   рому_, _еқиш, _psaf, לגת_, 
   {{0x6b8c0076,0xff002401,0x5fc4012c,0xbea20f7d}},	//   _vcag, _няшн, वारल, _нацк, 
   {{0x629c29ef,0x201c009a,0x7bc403ac,0x00000000}},	//   _äsoe, _zkwi_, _eniu, --, 
   {{0xeff00201,0x2d9c0810,0xbd840372,0x68040024}},	//   _ልምድ_, _ibve_, _انىن_, lėdi, 
   {{0xf770027a,0x6aac8e22,0x7bc400c0,0x6b8c0205}},	//   ّال_, _tsaf, _gniu, _ucag, 
   {{0x6aad284d,0x0a680107,0x75e20f7e,0xe9444ea7}},	// [3c430] _usaf, _ёрии_, _közh, _وردی, 
   {{0xf4240327,0xddc90449,0x257800c7,0xa5580023}},	//   _འཚུད_, zrež, рбжь_, _ልዑላዊ, 
   {{0x9f4c1248,0x67d54d0c,0x69c60f7f,0x962400de}},	//   zneñ_, _дону, _inhe, diņā, 
   {{0xc6740023,0x00000000,0x00000000,0x00000000}},	//   ርሃልካ_, --, --, --, 
   {{0x3abc008f,0xe21402dd,0x915c0208,0xd24c31f6}},	//   ָמונ, омды, _sắm_, نچل_, 
   {{0x25a400ae,0x290c0356,0x85e400e5,0x6ecc00cd}},	//   _úll_, şeau_, _اِسے_, तमनु, 
   {{0x238401d9,0xddc80427,0x80b0012d,0x7a20007c}},	//   _ؤسِ, trež, ंटें, mött, 
   {{0x2d9c004c,0xb06851ad,0x9f4c0724,0x7a220f80}},	//   _abve_, حصول_, tneñ_, lött, 
   {{0xb1c801d9,0xb3640395,0x680400c0,0x8174014b}},	//   _گِلن_, _хъск, gėdi, _газӣ_, 
   {{0x9f4c0598,0x7a220f81,0xdb0401e3,0x7bc40064}},	//   rneñ_, nött, ndkå, _sniu, 
   {{0x5ed00c58,0xb1c80050,0xddc800d0,0x7a400ca8}},	//   _তেখে, _دِلن_, prež, _látì, 
   {{0x69c60f82,0x8d240184,0xa3e800dc,0x7a2001f4}},	//   _anhe, өнөң_, यसि_, hött, 
   {{0x7bc40381,0x00000000,0x00000000,0x00000000}},	//   _vniu, --, --, --, 
   {{0x6fdc06af,0x7a2001d3,0xdb040240,0xa3d400bc}},	//   _décu, jött, lekë, ाउँ_, 
   {{0x186a0244,0xa3e8043e,0x2cb8005c,0x00000000}},	//   раби_, यसा_, årdt_, --, 
   {{0x7bc60f83,0x69c4ec5d,0x6fdc06af,0xd7080107}},	//   _uniu, _enhe, _fécu, анбе_, 
   {{0x2fc000c6,0x75e00432,0x7a2001e3,0x00000000}},	// [3c440] _óige_, _hözi, fött, --, 
   {{0x6fdc3a6c,0x75e001ed,0x7a220f80,0x9984742b}},	//   _héct, _közi, tötu, _بلدو, 
   {{0x53455190,0xd8747f51,0x962400e2,0x13680063}},	//   охла, _باخب, viņā, ашли_, 
   {{0x81b0015b,0xdb040240,0x00000000,0x00000000}},	//   টাফ_, jekë, --, --, 
   {{0x69c46c03,0x00000000,0x00000000,0x00000000}},	//   _ynhe, --, --, --, 
   {{0x6fdc003a,0x64400066,0x831404da,0xe9f8035b}},	//   _léct, _èlin, ڭقۇر_, _osẽ_, 
   {{0x257005a9,0x00000000,0x00000000,0x00000000}},	//   _سۇنس, --, --, --, 
   {{0x7f4408c9,0xaed4013e,0xeff002d3,0xdb040036}},	//   يلىق_, зоиш, _ልምዲ_, gekë, 
   {{0xa0880046,0xe9f800c7,0x3eac01fb,0x0dc801d5}},	//   асөз_, _asẽ_, _csgt_, ауни_, 
   {{0x6fdc20ef,0xdb04020c,0xcdd80640,0x10a401a9}},	//   _récu, mekè, рњи_, _мизн, 
   {{0x6fde0f84,0x69c401ab,0x6c544166,0x321c02fb}},	//   _sécu, _rnhe, якну, movy_, 
   {{0x6fdc5eb5,0x7a220f85,0x321e0f86,0xaa5c01ec}},	//   _pécu, zött, lovy_, лемi, 
   {{0x6e04005e,0x7a20005b,0x00000000,0x00000000}},	//   _ىستە, yött, --, --, 
   {{0x9e640502,0x321c0122,0x2d9cbb1f,0x6fdc004a}},	//   _راهن, novy_, _ubve_, _vécu, 
   {{0x57b80131,0x75e0010e,0x316c00ef,0x00000000}},	//   ﻧﻠﯩﺮ, _gözi, _medz_, --, 
   {{0x2d8e0f87,0x4900499d,0x321c02f0,0xd6d400fe}},	//   lgde_, зүүг, hovy_, _সেইয, 
   {{0x2d8c2a28,0x321c0122,0x7a2001ed,0x4548afd9}},	// [3c450] ogde_, kovy_, tött, ачем_, 
   {{0x2d8c00ed,0x69c60f88,0x316c00e2,0x321c02f0}},	//   ngde_, _unhe, _nedz_, jovy_, 
   {{0x321c0232,0x2d8e0f89,0x7a220f8a,0xdb04036e}},	//   dovy_, igde_, rött, yekë, 
   {{0x2a68009a,0x00000000,0x00000000,0x00000000}},	//   _kwab_, --, --, --, 
   {{0x2a68020b,0x7a200108,0x00000000,0x00000000}},	//   _jwab_, pött, --, --, 
   {{0x81c407d8,0xd24c00f1,0x321c02f0,0x00000000}},	//   ющее, دنو_, govy_, --, 
   {{0xdb080122,0x9838004b,0x316c00d8,0xf1a81056}},	//   čném, _ختیځ_, _dedz_, زاوه_, 
   {{0xa2940826,0xfe6c85c2,0x2d8c0373,0x4ac8090a}},	//   _набі, نگت_, egde_, ामाव, 
   {{0x321c0f55,0xdb040c5b,0x6d5db056,0x75e0010e}},	//   bovy_, rekë, ıran, _sözi, 
   {{0x2d8c01e6,0x2b48496e,0x321c0306,0x6fdc01d3}},	//   ggde_, _agac_, covy_, _bécs, 
   {{0x236c0211,0x6fdc0048,0x2a68020c,0x9f041077}},	//   _keej_, _péct, _awab_, توکو, 
   {{0x2d8cbdd0,0x2b48056a,0x224c05b1,0xe0380276}},	//   agde_, _cgac_, _kuek_, _узеч_, 
   {{0x236c0457,0xd9448087,0x2244000d,0x00000000}},	//   _meej_, зеги, _kilk_, --, 
   {{0xceb01775,0x236c0b89,0x985400d6,0x75e0008e}},	//   _ניו_, _leej_, зташ, _tözi, 
   {{0x75e000dd,0x22442517,0x00000000,0x00000000}},	//   _közv, _milk_, --, --, 
   {{0x236c0190,0x2244045f,0x321def11,0x68e07e78}},	//   _neej_, _lilk_, zovy_, ølda, 
   {{0x88d0025c,0x00000000,0x00000000,0x00000000}},	// [3c460] ཌཱུར, --, --, --, 
   {{0x20bc29d9,0x224401ab,0x8af8011a,0xdb04398f}},	//   ्माध, _nilk_, _להפי, jeké, 
   {{0x89d806a9,0xdb0401ed,0x224c01c4,0x316c00e2}},	//   _החיי, deké, _auek_, _redz_, 
   {{0x224c0007,0x316c00de,0x00000000,0x00000000}},	//   _buek_, _sedz_, --, --, 
   {{0x224e0f8b,0x22440072,0x321cc62f,0x41c40a59}},	//   _cuek_, _bilk_, tovy_, लांस, 
   {{0x6fdc004a,0x00000000,0x00000000,0x00000000}},	//   _nécr, --, --, --, 
   {{0x321e0f8c,0x224402d2,0x7ddc0051,0x00000000}},	//   rovy_, _dilk_, _jêsu, --, 
   {{0x236c0694,0x321c82a1,0x77649d49,0xb4e86620}},	//   _geej_, sovy_, nbix, यनी_, 
   {{0x224c0097,0x321c0022,0xdcec0055,0xd1844c79}},	//   _guek_, povy_, _īkār, _нлай, 
   {{0x2d8cf498,0x236c0211,0xdb04003e,0x6fdc01ed}},	//   ugde_, _zeej_, ceké, _pécs, 
   {{0x236c0b89,0x6fdc0231,0x2d8c2a28,0xfd7005f5}},	//   _yeej_, _décr, rgde_, элээ, 
   {{0x236c1bce,0x78bc0010,0x77640135,0x00000000}},	//   _xeej_, dvrv, jbix, --, 
   {{0x77640014,0xbfc800db,0x799c015d,0x2c4c013a}},	//   dbix, _دالە_, ffrw, _mědi_, 
   {{0x77640175,0x00000000,0x00000000,0x00000000}},	//   ebix, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2a6800f2,0x81b000fe,0xdb042cda,0x9f4c005c}},	// [3c470] _uwab_, টাত_, yeké, rieø_, 
   {{0x236c0211,0x3f800024,0x6b9c69a9,0xe58400cf}},	//   _seej_, ėjui_, lfsg, بۅسۉ_, 
   {{0x236e0f8d,0x224c0399,0x7764102c,0x6abc0158}},	//   _peej_, _suek_, bbix, lvsf, 
   {{0x236c01d4,0x22440e21,0x6edc012c,0x00000000}},	//   _qeej_, _silk_, यहाँ, --, 
   {{0xae0cd9e5,0x22460f8e,0xdb0401d3,0x00000000}},	//   िचान_, _pilk_, teké, --, 
   {{0xa0a41620,0x41c41fd2,0x00000000,0x00000000}},	//   дакд, लाइस, --, --, 
   {{0x236c0211,0x6d5c456f,0x7ddc002d,0xf4850514}},	//   _teej_, ıral, _mêst, _путн, 
   {{0x7ddc0225,0x6fdce1b9,0x6d5808f7,0x6b9c0d27}},	//   _lêst, _sécr, _afva, jfsg, 
   {{0x6fdc9ec6,0x2244000d,0x799c015d,0x00000000}},	//   _pécr, _tilk_, yfrw, --, 
   {{0x1b040f22,0x7ddc000f,0x22440076,0x00000000}},	//   রথমে_, _nêst, _uilk_, --, 
   {{0x75e056f8,0x62980072,0x6b9c002f,0x7764058a}},	//   _gözu, ltwo, ffsg, ybix, 
   {{0x7ddc025a,0x62980ea0,0x656401ab,0x7764058a}},	//   _rêsu, otwo, hbhh, xbix, 
   {{0x62985093,0x200e0f8f,0x0f54025f,0x7ddc0a85}},	//   ntwo, mnei_, _חינם_, _bêst, 
   {{0x1ea800b2,0x63b80007,0x62980112,0x37c000fe}},	//   _هاڻي_, hdwn, itwo, _একধৰ, 
   {{0x200ca7a4,0x98040116,0x00000000,0x00000000}},	//   onei_, җяңд, --, --, 
   {{0x07a20f90,0x200c054e,0xc7a0d0e2,0x629802bd}},	//   касн, nnei_, киск, ktwo, 
   {{0x7c260f91,0x7ddc0a85,0x77640050,0xcf9004ac}},	// [3c480] _ikir, _fêst, rbix, כטן_, 
   {{0x200c0221,0x9b8801d3,0x00000000,0x00000000}},	//   hnei_, _انکل_, --, --, 
   {{0xb4e8813f,0x7c240a49,0xa3e8043e,0x00000000}},	//   यने_, _kkir, यसं_, --, 
   {{0x62981ef9,0x7764058a,0x1304003b,0x00000000}},	//   ftwo, qbix, мзем, --, 
   {{0x7c2401f7,0x200e0f92,0x75e045d8,0x27940166}},	//   _mkir, dnei_, _sözu, _яшэр, 
   {{0x7c24022e,0x200c3f1b,0xc32c0014,0x00000000}},	//   _lkir, enei_, ٕؔن_, --, 
   {{0x7c260f93,0x4dd40183,0x92cc015b,0x8fd0013d}},	//   _okir, ধসমূ, শনে_, кәдә, 
   {{0x7c2400b4,0x200c07de,0x6d5c495b,0x4ee400d4}},	//   _nkir, gnei_, ıram, діоз, 
   {{0x8d860f94,0x8eb000d1,0x629815c0,0x00000000}},	//   мунд, ئەتت, ctwo, --, 
   {{0x7c260f95,0x200e0f96,0x75e005d2,0x90c421fa}},	//   _akir, anei_, _gözt, _обзе, 
   {{0x6e28009f,0x7ddc0b21,0xbdf47da6,0x00000000}},	//   rldb, _rêst, بريا_, --, 
   {{0xdb14007f,0x75e001ed,0x6b9c0112,0xc0e001d5}},	//   _kayè, _közs, ufsg, _шохк, 
   {{0x6b9cdcce,0x00000000,0x00000000,0x00000000}},	//   rfsg, --, --, --, 
   {{0x6abc0579,0x7c240c8a,0xdb140100,0xdc54a054}},	//   rvsf, _ekir, _mayè, بریک, 
   {{0x26c40421,0x67f00158,0xdb14007f,0x6298012d}},	//   _ōlo_, _låje, _layè, ztwo, 
   {{0xdd3003b9,0x00000000,0x00000000,0x00000000}},	//   _həşt, --, --, --, 
   {{0x629800a3,0xe58400fb,0x00000000,0x00000000}},	// [3c490] xtwo, етеү, --, --, 
   {{0xd6c40f1c,0x7ae07a45,0x80ac0037,0x68040064}},	//   عملی, ämte, _अईले, gėdr, 
   {{0x200e0f97,0xe75802bf,0x39140006,0xc5fc0171}},	//   ynei_, _нині_, _амэр, _ķēdi_, 
   {{0x6298101d,0xdb14007f,0x7c2405b1,0x00000000}},	//   ttwo, _bayè, _xkir, --, 
   {{0x27e815a5,0xe945483d,0xb60400bc,0x81b0015b}},	//   mkan_, _ترکی, _stář, টাস_, 
   {{0x27ea0f98,0xdb14007f,0x629826bd,0x200c009a}},	//   lkan_, _dayè, rtwo, wnei_, 
   {{0x27ea0f99,0x66060f9a,0x200c00e2,0xd12c00ec}},	//   okan_, mihk, tnei_, ٽمي_, 
   {{0x66048a67,0x5f74027d,0x200c054e,0x6298002f}},	//   lihk, رابر, unei_, ptwo, 
   {{0x27ea0f9b,0x200e0f9c,0xdea00517,0x75e000a2}},	//   ikan_, rnei_, ایتی, _gözs, 
   {{0x27e84020,0x200e0f9d,0x6605a8d4,0x7c260f9e}},	//   hkan_, snei_, nihk, _skir, 
   {{0x27ea0f9f,0x7ddc025a,0x7c240280,0x0d200228}},	//   kkan_, _sêss, _pkir, лүшү, 
   {{0x66048581,0x27e80db7,0x7ddc0798,0x00000000}},	//   hihk, jkan_, _pêss, --, 
   {{0x27ea0fa0,0x644a0fa1,0x3db400fe,0x00000000}},	//   dkan_, _miei, জাবল, --, 
   {{0x27e89279,0x644a0fa2,0x3f9c022f,0xdb1401e1}},	//   ekan_, _liei, lfuu_, _jayé, 
   {{0x27e833cb,0x66042831,0xa3c004e4,0xdb140085}},	//   fkan_, dihk, ्ञा_, _mayé, 
   {{0x644a0fa3,0xca441870,0x00000000,0x00000000}},	//   _niei, ﭘﺎﺕ_, --, --, 
   {{0xb4e80882,0x3f9c022f,0x2c4c01ef,0x00000000}},	// [3c4a0] यन्_, ifuu_, _dědu_, --, 
   {{0x644806c8,0x27e86355,0xdb1402ea,0x66060fa4}},	//   _aiei, akan_, _nayé, gihk, 
   {{0x27e85088,0x6448a3dc,0xd7c81ec7,0x75e048e7}},	//   bkan_, _biei, _فوده_, _sözs, 
   {{0x27ea0fa5,0x2cb8037e,0x68e1b6e8,0xdb140100}},	//   ckan_, ærdi_, älde, _payè, 
   {{0xdb160fa6,0x6605966d,0xf19437fb,0x7644035b}},	//   _bayé, bihk, виль, _аҭаа, 
   {{0xf4860fa7,0x644804e6,0x61440131,0xa49001d5}},	//   _لاری, _eiei, ھىيە, _چیلت, 
   {{0x644a0fa8,0x21640220,0x3f9c022f,0x00000000}},	//   _fiei, ттіг, ffuu_, --, 
   {{0x64480493,0x044040c5,0xefb001d5,0x80a1e34e}},	//   _giei, _бесн, شیتگ, امين, 
   {{0xdb14002e,0xd28400f1,0xb24401af,0xd72000fe}},	//   _fayé, _سټاي, _амаһ, পেৰা_, 
   {{0x27e88a39,0x3f9c0ba7,0x4638008f,0x06940375}},	//   zkan_, afuu_, ּעטע, עדים_, 
   {{0x4ac005ba,0x27ea0fa9,0xe7e00316,0x3ebc013c}},	//   शिभव, ykan_, _नवलप, avut_, 
   {{0x27e801c4,0x8ff800e3,0xea8802dd,0x7dc00137}},	//   xkan_, _عرار_, _ﺑﻪﺭﯞ, _ەقون, 
   {{0x81b00d42,0x6db401c6,0x3f640a0e,0x00000000}},	//   টার_, _айлу, _чичо_, --, 
   {{0x27e81f75,0x00000000,0x00000000,0x00000000}},	//   wkan_, --, --, --, 
   {{0x27e84020,0x66060faa,0x00000000,0x00000000}},	//   tkan_, vihk, --, --, 
   {{0x27ea0fab,0x66040098,0xba040137,0xa3d40118}},	//   ukan_, wihk, _ۅسپۉ, ाउछ_, 
   {{0x27ea0fac,0x66043223,0x6449f4d2,0x659400c7}},	// [3c4b0] rkan_, tihk, _riei, каау, 
   {{0x27e85088,0x25089a87,0x644a0fad,0x6604003e}},	//   skan_, ورای_, _siei, uihk, 
   {{0x27e85088,0x6604020b,0xdb1406af,0xe8800023}},	//   pkan_, rihk, _rayé, _ክፍጽም_, 
   {{0x66045dff,0x98780bd9,0x7ddc002d,0x27e805b1}},	//   sihk, _קארט, _lêsp, qkan_, 
   {{0x644a0fae,0x9f5c07a8,0xdb15033c,0x66060faf}},	//   _viei, _umwé_, _payé, pihk, 
   {{0x622400d1,0x970000d1,0x00000000,0x00000000}},	//   خىتل, _ئېكى, --, --, 
   {{0x81b000bd,0xb63801ec,0x00000000,0x00000000}},	//   টাল_, _ﭘﺎ_, --, --, 
   {{0x442801fb,0xdb1400e8,0x00000000,0x00000000}},	//   _óc_, _wayé, --, --, 
   {{0x75e000dd,0xa1580046,0x7ce801ed,0xdb1401e1}},	//   _közp, _жазу_, körö, _tayé, 
   {{0x128800f2,0x3ebc031c,0x00000000,0x00000000}},	//   _آملی_, rvut_, --, --, 
   {{0x7ce82776,0xa3e405f9,0x9b8800f1,0x00000000}},	//   dörö, _पका_, وندل_, --, 
   {{0x3f800006,0x5fb4012c,0x64c40841,0xa2c401ef}},	//   ėjus_, _अघिल, mčić, háčů_, 
   {{0x6ee60fb0,0x38c800e4,0x64c404a7,0x00000000}},	//   _مسول, _oírô_, lčić, --, 
   {{0x7e785804,0x2d9400a7,0x7ce800e5,0x7f585043}},	//   msup, _бръс, görö, lcuq, 
   {{0x7e7a0fb1,0x64c4098d,0xd5b004fb,0x6fb80490}},	//   lsup, nčić, یفر_, _आसमं, 
   {{0x98340006,0x9b8800f1,0x7f5806be,0x00000000}},	//   тэгі, _ځنګل_, ncuq, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3c4c0] --, --, --, --, 
   {{0xb9081c82,0x38ac08e7,0x64c405be,0xe88002d3}},	//   _মই_, gòrò_, kčić, _ክፍጸም_, 
   {{0x64c40e04,0x7e78929f,0x00000000,0x00000000}},	//   jčić, hsup, --, --, 
   {{0x7e7a0fb2,0x130a0fb3,0xa484036b,0x367400cf}},	//   ksup, мней_, اجلن, _مۇرز, 
   {{0x7e780115,0x00000000,0x00000000,0x00000000}},	//   jsup, --, --, --, 
   {{0x7e7801e3,0x00000000,0x00000000,0x00000000}},	//   dsup, --, --, --, 
   {{0xc9500302,0x7e7a0fb4,0x81b000fe,0xc32000cc}},	//   סמה_, esup, টাং_, বেলি_, 
   {{0xeeba0fb5,0x93a8bab9,0x53a401a9,0x7e78032e}},	//   елиш_, _تاسف_, _шабб, fsup, 
   {{0x7e7889f7,0x43418f3b,0x527401c0,0x00000000}},	//   gsup, _ветв, _шуву, --, 
   {{0xdbd40248,0xff4c01d9,0x8fc000c7,0x2ba42802}},	//   _gùús, ٝخی_, уаҩҵ, ग्ना, 
   {{0x7e7a0fb6,0x00000000,0x00000000,0x00000000}},	//   asup, --, --, --, 
   {{0x4ea41cd6,0x81e4009e,0x7e7821ad,0x4478010f}},	//   _арка, মোদ_, bsup, ונטע, 
   {{0x7ce801d3,0x7e7a0fb7,0x00000000,0x00000000}},	//   törö, csup, --, --, 
   {{0xac960fb8,0x7ae00267,0xe89400c7,0xdb1400e5}},	//   _бакш, ämta, лагь, _anyó, 
   {{0x6fb8185d,0xa8e400f1,0x00000000,0x00000000}},	//   ्यपू, اړخي, --, --, 
   {{0x7c809c0b,0x64409ec6,0x0eb404fa,0x2cb803b2}},	//   _туше, _élix, _अनाड, ærdu_, 
   {{0xc984084c,0x70800023,0xa614024c,0x00000000}},	// [3c4d0] _иуни, _ከይህሉ_, гмач, --, 
   {{0xfedc0154,0xdb04012d,0xcfcc03d4,0xfb1c0a7c}},	//   _বেঁধ, adkó, িঘটন, _קוזמ, 
   {{0x80b4009e,0x46600137,0xf62800d4,0x00000000}},	//   _অপভ্, _چۇرق, тіти_, --, 
   {{0x7e780309,0x64c405ce,0x466006ba,0xdb041de4}},	//   ysup, včić, _نۇرق, leká, 
   {{0x2ba4590f,0x7e78003a,0x490001ec,0xb38401ec}},	//   ग्या, xsup, _сүңг, рліл, 
   {{0x80b40011,0x7e78007c,0x80ac01f9,0x00000000}},	//   _অপব্, vsup, ंबले, --, 
   {{0x7e780113,0xe4e401c6,0xdce006be,0x2d7c1954}},	//   wsup, _ёсгү, dalğ, _ኮሎራዶ_, 
   {{0x657403f9,0xdb140241,0x64c4041a,0xdca4023b}},	//   _hezh, _bayì, rčić, қами, 
   {{0x65740263,0x6454696c,0xe314026a,0xf4080150}},	//   _kezh, _huzi, _смањ, _شيكى_, 
   {{0x64c407f5,0xf238013d,0x9f4c0165,0x442e0fb9}},	//   pčić, _апуш_, rieñ_, llg_, 
   {{0x7e7a0fba,0x65760fbb,0x5f959ffd,0x1c4439a5}},	//   ssup, _mezh, _ملائ, лном, 
   {{0x61e20fbc,0x6574e68b,0x7e7a0fbd,0x442e0fbe}},	//   _holl, _lezh, psup, nlg_, 
   {{0x61e20fbf,0x442c37a8,0x6e9400f3,0x00000000}},	//   _koll, ilg_, _вичу, --, 
   {{0x61e20fc0,0x65757463,0x64560fc1,0x1ae401e0}},	//   _joll, _nezh, _ouzi, _ҡойм, 
   {{0x64546933,0xdca5e23c,0x8d900228,0xad240133}},	//   _nuzi, _сайи, _الىش, _پروو, 
   {{0x65740156,0x442c0158,0x61e00d92,0x67f000b8}},	//   _aezh, jlg_, _loll, _påja, 
   {{0x64560fc2,0x65749007,0x61e08ebb,0x95c8036b}},	// [3c4e0] _auzi, _bezh, _ooll, нлаб_, 
   {{0x61e1137d,0x442c0731,0x657400d0,0xf48401b9}},	//   _noll, elg_, _cezh, لاصی, 
   {{0x657407e4,0x64560fc3,0x442c01ab,0xe9f80241}},	//   _dezh, _cuzi, flg_, _npẹ_, 
   {{0x7794dd55,0xf8d00073,0x00000000,0x00000000}},	//   _خیرا, हमीप, --, --, 
   {{0x91e55f9e,0x65740165,0x6080001f,0xe7d018cc}},	//   лоде, _fezh, ረጃጀት_, हारप, 
   {{0x61e20fc4,0x442e0fc5,0xdedc0023,0xe1f4992f}},	//   _coll, alg_, _ኔርካ_, аҳу_, 
   {{0x64560fc6,0x61e20fc7,0xd24c4732,0xdb1401e1}},	//   _guzi, _doll, _کۆت_, _sayì, 
   {{0xd25140cc,0x68e00579,0x2b4c01a6,0xa3c000dc}},	//   _هنر_, øldi, žeci_, ्ञः_, 
   {{0x65740ad3,0x61e0771c,0x64560fc8,0xadf400f0}},	//   _yezh, _foll, _zuzi, ипиш, 
   {{0x61e10de7,0x6454036b,0x2d99a073,0x68e801e4}},	//   _goll, _yuzi, üre_, ĝedz, 
   {{0xc220034c,0x7ae00267,0x81e4009e,0xdb04005c}},	//   _اکنو, ämtn, মোহ_, nekæ, 
   {{0xbb940108,0xebc4008e,0x00000000,0x00000000}},	//   бающ, рәкн, --, --, 
   {{0x61e06f30,0xdb0401f1,0x8034008f,0x0f340276}},	//   _yoll, teká, _ענדע_, _сэжя, 
   {{0xdb1400d2,0x61e20fc9,0xe51c00c5,0x2cb801bf}},	//   _gayí, _xoll, _बुझि_, ærds_, 
   {{0xdb042def,0xac960fca,0x442c0076,0x9f4c0332}},	//   reká, _тайш, ylg_, mheá_, 
   {{0x645530cd,0x65740369,0xdb046dc9,0x90940023}},	//   _ruzi, _sezh, seká, _ዘይደሊ_, 
   {{0x645522d4,0x2ba40490,0x65740489,0x36d40107}},	// [3c4f0] _suzi, ग्णा, _pezh, ботр, 
   {{0x7a2001f4,0x00000000,0x00000000,0x00000000}},	//   köty, --, --, --, 
   {{0xdb14025a,0x65760fcb,0xe49800fd,0x651415b0}},	//   _gayâ, _vezh, ткеч_, جوائ, 
   {{0x6454030a,0x65760fcc,0xc76400f7,0x2fc00332}},	//   _vuzi, _wezh, _حادى, _óigh_, 
   {{0x645404ba,0x6fb80327,0x65740205,0x86e401d5}},	//   _wuzi, _དལྟའ, _tezh, _сўнд, 
   {{0x61e20fcd,0x64560fce,0xaca40ca8,0x6aac00ca}},	//   _qoll, _tuzi, _asọy, _mpaf, 
   {{0x1fb40124,0x61e20fcf,0x20b80a89,0x442caa3d}},	//   аспр, _voll, тыль_, plg_, 
   {{0x6aac0770,0x61e20fd0,0x8f5000d1,0xd48c01c8}},	//   _opaf, _woll, ينىش, _آڀل_, 
   {{0x61e20fd1,0x63aa0fd2,0xdb0400ee,0x225801af}},	//   _toll, _iben, mekç, _ризы_, 
   {{0xdb047bfb,0x61e005b1,0xe7d00034,0xdca400c7}},	//   lekç, _uoll, हाँप, ааои, 
   {{0x6aac090c,0xa28001ed,0x64400066,0x69d804e4}},	//   _apaf, _ایڈو, _èlis, मानी, 
   {{0x69c02776,0xdb040205,0xaffc030d,0x3e500055}},	//   ôlen, nekç, _похi, _ṛtur_, 
   {{0x63aa0fd3,0x6aac0ffb,0x2ba401bc,0xbd840014}},	//   _mben, _cpaf, ग्धा, _یچھن_, 
   {{0x9d460fd4,0x81b0045e,0x81e400eb,0x00000000}},	//   _келд, টাক_, মোর_, --, 
   {{0x63aa0fd5,0xd9460fd6,0xb17c01e4,0xe7d002ab}},	//   _oben, реви, _joĥa, हांप, 
   {{0x5ac8cdd2,0x63a814bb,0x1ae40117,0x00000000}},	//   _алим_, _nben, _воим, --, 
   {{0xa66456e6,0xc6c0004e,0x00000000,0x00000000}},	// [3c500] مطلو, ойтк, --, --, 
   {{0xb8dc0f22,0xca780677,0x4a780a7c,0x7a200108}},	//   _আপ_, _שניט, _שריב, yöty, 
   {{0x63aa0fd7,0xbb3c0150,0xdb040205,0x00000000}},	//   _bben, _ﺒﺎﻥ_, fekç, --, 
   {{0x63a80076,0x53a43cb4,0xdb0401bf,0xe8340092}},	//   _cben, радб, rekæ, _በብዙዎ, 
   {{0x23680227,0xc32c0050,0x00000000,0x00000000}},	//   ñaja_, وٕم_, --, --, 
   {{0xdb060fd8,0xcb340a7c,0x7a200108,0x00000000}},	//   mekä, באני_, töty, --, 
   {{0xdb060fd9,0xd018014b,0x00000000,0x00000000}},	//   lekä, кфи_, --, --, 
   {{0x4fc60fda,0x63aa0fdb,0x23d40276,0x81e40183}},	//   рска, _gben, _лцур, মোল_, 
   {{0xe2a801d9,0xdb0416ca,0x00000000,0x00000000}},	//   _مالن_, nekä, --, --, 
   {{0x63a80356,0xadf401f4,0x651800fd,0x7a2002fc}},	//   _zben, спош, _çäçü_, pöty, 
   {{0x6aae0fdc,0xddc80010,0xdb040821,0x0634010f}},	//   _spaf, bsež, hekä, שניט_, 
   {{0xb4b400bc,0x317c0010,0xdb0401f4,0x00000000}},	//   _झनै_, lavz_, kekä, --, 
   {{0xbea1aedc,0x67f0007c,0xdb04007c,0xfba8009d}},	//   _мацк, _såjo, jekä, штэй_, 
   {{0xdce20fdd,0xdb040036,0x00000000,0x00000000}},	//   galē, dekä, --, --, 
   {{0xb8e80a93,0x6e2a0fde,0xfcd001f7,0x67d46885}},	//   афте_, modb, _ويهج, бову, 
   {{0x25ac01e4,0x00000000,0x00000000,0x00000000}},	//   _ŝel_, --, --, --, 
   {{0x8cbc0ebb,0xdce000ef,0x00000000,0x00000000}},	// [3c510] षिको, balē, --, --, 
   {{0x63a80a2e,0xc7640075,0x6e28bc3e,0xddc80219}},	//   _sben, _ھاجى, nodb, zsež, 
   {{0x2d9c0334,0xc76400d1,0x00000000,0x00000000}},	//   _mcve_, _پاجى, --, --, 
   {{0xdb140789,0xdb043bba,0xe0d80107,0x68e006ea}},	//   _hayá, bekä, ғви_, øldu, 
   {{0xdb140113,0xdb041918,0x62340261,0x00000000}},	//   _kayá, rekç, беду, --, 
   {{0xa4d40845,0x91e0023a,0x317c037e,0x00000000}},	//   _логі, зоше, gavz_, --, 
   {{0xd00c00aa,0xdb140022,0x63a80327,0x71f80133}},	//   کلي_, _mayá, _tben, گرۆس_, 
   {{0x63a80912,0x1e94014b,0xdb04002f,0x00000000}},	//   _uben, брор, mdkö, --, 
   {{0x443e0fdf,0x6e2800b5,0x0e60121c,0x00000000}},	//   _ihu_, fodb, пкын, --, 
   {{0x6e28bc2c,0x00000000,0x00000000,0x00000000}},	//   godb, --, --, --, 
   {{0x443c07ae,0x31c60fe0,0xdb060fe1,0x9c240107}},	//   _khu_, _ьств, ndkö, йдод, 
   {{0xee3801c6,0xad2400d1,0x00000000,0x00000000}},	//   лнө_, تىپى, --, --, 
   {{0xdb14043b,0x200e0fe2,0x6d5c06b9,0x443e0fe3}},	//   _bayá, miei_, ırar, _mhu_, 
   {{0x200c0a27,0x237d2600,0x443c003e,0xaf34088c}},	//   liei_, hawj_, _lhu_, _برمت, 
   {{0x443e0fe4,0xfd4405f5,0xdce000e2,0xdb040450}},	//   _ohu_, _тэдн, ralē, dekå, 
   {{0x200e0fe5,0x443d3fa4,0xdb0426bb,0x00000000}},	//   niei_, _nhu_, tekä, --, 
   {{0xe7e805f9,0x1ae400fe,0x00000000,0x00000000}},	// [3c520] _टकरा_, _পেৰা, --, --, 
   {{0x443e0fe6,0x996801d9,0xcb100375,0x200c97c7}},	//   _ahu_, _حمدٕ_, _מלח_, hiei_, 
   {{0x66740dd8,0x200e0fe7,0x75e001ed,0x443c0055}},	//   مدەر, kiei_, _közz, _bhu_, 
   {{0x443e0fe8,0xdb04000d,0x4c98011a,0x00000000}},	//   _chu_, pekä, טבעו, --, 
   {{0x200e0fe9,0x81b00f22,0x317c01f5,0xb208035b}},	//   diei_, য়ান_, tavz_, аҵаз_, 
   {{0x443e0fea,0x527407d6,0x5eac009e,0x200c0036}},	//   _ehu_, _ҳужу, কটাই, eiei_, 
   {{0x200c0276,0x69d823e9,0x00000000,0x00000000}},	//   fiei_, माती, --, --, 
   {{0x443c0842,0x200d5d44,0x5274010b,0x03a02a62}},	//   _ghu_, giei_, _гужу, _нисо, 
   {{0x6e2a0feb,0x73c401af,0x00000000,0x00000000}},	//   todb, _гәһе, --, --, 
   {{0x628e0fec,0x80f4b494,0x200c0356,0x80d000cf}},	//   šaoc, рхәт_, aiei_, تۅۅچ, 
   {{0x6e29a56a,0x443c00f1,0x200c0311,0x69c00129}},	//   rodb, _yhu_, biei_, ôlem, 
   {{0x200e0fed,0x6e2a0fee,0x7b6402e8,0xbb94005b}},	//   ciei_, sodb, зтре, пающ, 
   {{0x6e28151c,0x0dc8967a,0x6e040150,0x00000000}},	//   podb, _буйи_, _وستە, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb140789,0xdb0408fb,0x237c0399,0x00000000}},	//   _vayá, vekå, yawj_, --, 
   {{0xbc6432e8,0x237c01d4,0x5fbc00cd,0x00000000}},	//   _امين_, xawj_, ्ययल, --, 
   {{0x36d4b6c2,0x0a200b82,0x00000000,0x00000000}},	// [3c530] потр, ተማርያ, --, --, 
   {{0x443e0fef,0x200d724d,0x68e006ea,0x7f38010f}},	//   _shu_, ziei_, ølds, רעמו, 
   {{0x2bdc06ab,0x443e0ff0,0x81b0015b,0x2a6801a9}},	//   यापा, _phu_, য়াম_, _htab_, 
   {{0x200e0ff1,0xdb0401e3,0x00000000,0x00000000}},	//   xiei_, rdkö, --, --, 
   {{0x443c1aa1,0x200c0bd0,0xaac806b1,0x00000000}},	//   _vhu_, viei_, िटिक, --, 
   {{0x237c0218,0x200c016b,0x2a680175,0x116800f2}},	//   sawj_, wiei_, _mtab_, للهی_, 
   {{0x443e0ff2,0x200c00a8,0x26c800d8,0xe0441422}},	//   _thu_, tiei_, lvao_, онки, 
   {{0x9e642bd4,0x443e0ff3,0xdfe8016c,0x24180220}},	//   овид, _uhu_, рдид_, _тобы_, 
   {{0x200c8159,0x2bdca22b,0x2a6801d4,0xcee4023a}},	//   riei_, याना, _ntab_, ждые_, 
   {{0x200c0a27,0x26c80607,0x5574010f,0x00000000}},	//   siei_, ivao_, ֿערן_, --, 
   {{0x200e0ff4,0x2a6a0ff5,0x68040024,0xdb1400fd}},	//   piei_, _atab_, sėdy, _kayç, 
   {{0x1b48768b,0xbe8035e3,0x2ba421b8,0x00000000}},	//   изни_, _еңил, ग्ला, --, 
   {{0x201ca045,0x7cfc0241,0xdee46349,0xdb0400d0}},	//   _ijwi_, _báré, _фоли, lekú, 
   {{0x2a6804ce,0x26c80165,0x00000000,0x00000000}},	//   _dtab_, dvao_, --, --, 
   {{0x2a6801c0,0x9c640e4a,0x75e0029f,0x7cfc01e7}},	//   _etab_, _بهبو, _gözy, _dáré, 
   {{0x2a680175,0x3db800cc,0x00000000,0x00000000}},	//   _ftab_, _অচিল, --, --, 
   {{0x38b0006a,0x2a68020b,0x2904022c,0x15e002dd}},	// [3c540] _börö_, _gtab_, úlar_, _ﺍﻷﺭﺩ, 
   {{0x7bc4009f,0x7cfc0241,0xb78801e0,0x75e0008e}},	//   _haiu, _gáré, шәүе_, _yözy, 
   {{0x7bc60ff6,0x2a68070d,0xd9460ff7,0x26c80109}},	//   _kaiu, _ztab_, _фени, avao_, 
   {{0x2bdc07b7,0x99980024,0x799c0142,0x00000000}},	//   याया, _tipų_, lgrw, --, 
   {{0x2a6801b9,0x799c03cb,0x7cec01e1,0x7ae0002f}},	//   _xtab_, ogrw, _yòrú, ämth, 
   {{0x799c0649,0x7bc400af,0x50660ff8,0xc22001e2}},	//   ngrw, _laiu, отиа, وکلو, 
   {{0x2bdcb2b5,0xc205d4c3,0x799c0142,0xdce000c0}},	//   यामा, تقون_, igrw, malė, 
   {{0x7bc41c04,0xdb1403f0,0xc95002e4,0xdce00024}},	//   _naiu, _kayä, ומו_, lalė, 
   {{0xcf2400c6,0xaf54035b,0x00000000,0x00000000}},	//   غربي, онқә, --, --, 
   {{0x50d4f6c4,0x7bc4562f,0x2a68022e,0x2bdc043e}},	//   _وزار, _aaiu, _rtab_, याभा, 
   {{0x26c80bb8,0x7bc44ff3,0x8fa41d0f,0x00000000}},	//   zvao_, _baiu, _маже, --, 
   {{0x0a68036b,0xfc30009f,0x0b8800d8,0x00000000}},	//   ирги_, َحَ_, јсни_, --, 
   {{0x2bdc000b,0x9508031c,0xdce000c0,0x00000000}},	//   याबा, _གཟའི_, kalė, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7bc40607,0x67d47927,0x7be80162,0x00000000}},	//   _faiu, пову, øruú, --, 
   {{0xcb0a0ff9,0x7bc60ffa,0xdb140139,0x00000000}},	//   _вход_, _gaiu, _bayä, --, 
   {{0x7cec01e1,0x9f6c0150,0x00000000,0x00000000}},	// [3c550] _tòrú, _ﺴﺘﻴﺞ_, --, --, 
   {{0xdce002d5,0x26c803f6,0x6d44010f,0x19c000ee}},	//   galė, rvao_, _ĝiaj, _пәсг, 
   {{0x7bc40099,0x6d44010f,0xded402d3,0xdb142b24}},	//   _yaiu, _ŝiaj, _ክውን_, _payç, 
   {{0x69c60ffb,0xdb1521fb,0xfdb400cd,0xa7b8030d}},	//   _hahe, _qayç, _अस्फ, _улму_, 
   {{0x69c60ffc,0xdce00153,0x00000000,0x00000000}},	//   _kahe, balė, --, --, 
   {{0x69c40588,0x72041dd8,0x00000000,0x00000000}},	//   _jahe, وونم, --, --, 
   {{0xdb140139,0x74680120,0x00000000,0x00000000}},	//   _tayç, _мртв_, --, --, 
   {{0x69c60ffd,0x6d580165,0x6b9c01f5,0x84c00139}},	//   _lahe, _agva, jgsg, _нәҗд, 
   {{0x7bc60ffe,0x62740451,0xa29401ec,0x1dd8007b}},	//   _raiu, _رهائ, _хазі, مبدع_, 
   {{0x69c60fff,0x65640227,0x4f042e5d,0x62985963}},	//   _nahe, nchh, янын_, muwo, 
   {{0x72045f32,0x0d8001c0,0x62980098,0x65641196}},	//   _تولم, элэн, luwo, ichh, 
   {{0x69c55617,0x22bc0100,0x60c0757e,0x6b9c143a}},	//   _aahe, _kňk_, _islm, ggsg, 
   {{0x7bc61000,0xdb04037e,0x2ec00124,0x629892d6}},	//   _vaiu, nekø, _аҩым, nuwo, 
   {{0x69c61001,0xee381ed2,0x2d980086,0x7bc4ae54}},	//   _cahe, _дні_, òret_, _waiu, 
   {{0x69c5ceb3,0x6298006f,0x7bc61002,0x18681188}},	//   _dahe, huwo, _taiu, саби_, 
   {{0x65640b21,0xb8e41ab2,0x6298714b,0x8c4107e2}},	//   echh, _एन_, kuwo, _пеще, 
   {{0x69c40851,0xdce00006,0x62980295,0x19b800a8}},	// [3c560] _fahe, talė, juwo, _лунь_, 
   {{0x0b41b676,0x69c61003,0x62980428,0xd944a15c}},	//   _янын, _gahe, duwo, _непи, 
   {{0x69d811a0,0x22bc010e,0x6d440115,0xdce00024}},	//   मारी, _aňk_, _ĝiak, ralė, 
   {{0x63b80649,0x629802c4,0x656401ab,0x93440353}},	//   gewn, fuwo, achh, пнее, 
   {{0x69c61004,0x629a1005,0x2bdc00dc,0x628c0331}},	//   _yahe, guwo, याता, šaon, 
   {{0x22bc007f,0xab0400b8,0x2c4c01ef,0x945800f3}},	//   _dňk_, _avṛṇ, _dědy_, _грађ_, 
   {{0x6b9c0ea0,0x00000000,0x00000000,0x00000000}},	//   ygsg, --, --, --, 
   {{0x7f8008c9,0x22bc02bd,0x629866b0,0x68e03400}},	//   ىلىن, _fňk_, buwo, äldi, 
   {{0x0dc803f6,0x8c3401f0,0x877800df,0x00000000}},	//   буни_, ҷонӣ_, זאפי, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69c61006,0xd00886de,0xbd500022,0x00000000}},	//   _rahe, _леже_, нҭшә, --, 
   {{0x8fa40124,0xaab8012c,0x00000000,0x00000000}},	//   _хаде, इबलक, --, --, 
   {{0x6abc63de,0x6b9c01e3,0x3cb00220,0xaa5c0150}},	//   uwsf, rgsg, _үйір, регi, 
   {{0xac940e26,0x22580699,0x69c5ae61,0x63b8033f}},	//   _жакш, _èske_, _qahe, zewn, 
   {{0x69c61007,0x2bdc72c0,0x61e403fa,0x478a1008}},	//   _vahe, यादा, öhli, йсам_, 
   {{0x69c61009,0x62980295,0xe80c0490,0x49007c3f}},	//   _wahe, yuwo, _सगळा_, дүүг, 
   {{0x69c4193f,0x6b8e100a,0x81e4015b,0x00000000}},	// [3c570] _tahe, _idag, মোট_, --, 
   {{0x69c400d8,0xe5dc008e,0x27b40139,0x00000000}},	//   _uahe, _ülüç, чәүс, --, 
   {{0x6566100b,0x6b8c022e,0xe1f003e6,0x63ba100c}},	//   rchh, _kdag, ێست_, tewn, 
   {{0xdef0044e,0x60200069,0x629a100d,0x6564ce44}},	//   _ውግእ_, kēma, tuwo, schh, 
   {{0x6f0400e4,0x81b00011,0x00000000,0x00000000}},	//   _ýich, য়াস_, --, --, 
   {{0x629a100e,0x04587353,0xdb0400b5,0x6b8c01d5}},	//   ruwo, _هجرت_, rekø, _ldag, 
   {{0x63b8068f,0x629a100f,0x6b8e1010,0xdb0400b5}},	//   pewn, suwo, _odag, sekø, 
   {{0xa0083bdd,0x6b8d3464,0x00000000,0x00000000}},	//   تقبل_, _ndag, --, --, 
   {{0x6224b071,0x00000000,0x00000000,0x00000000}},	//   _قىرل, --, --, --, 
   {{0x6b8e1011,0x6d5c02f0,0x02b800cd,0xf2040024}},	//   _adag, žran, ोटीन, _пяхо, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xffc00014,0xefe40023,0x00000000,0x00000000}},	//   _سٍتێ, ምታይ_, --, --, 
   {{0x6b8e1012,0x9f0401b9,0xfec82d56,0x00000000}},	//   _ddag, _توشو, _دباو_, --, 
   {{0x442e1013,0x6b8e1014,0xd94406d3,0x00000000}},	//   hog_, _edag, деги, --, 
   {{0x442c04b9,0xdc080014,0x00000000,0x00000000}},	//   kog_, _وقتو_, --, --, 
   {{0x442e1015,0xdb142760,0x785c0270,0x3f9e1016}},	//   jog_, _mayú, _nōve, nguu_, 
   {{0x442e1017,0x3f9c0e14,0x656803e0,0x00000000}},	// [3c580] dog_, iguu_, _şeha, --, 
   {{0x3f9c00ca,0x3dc40100,0x85b00131,0x6b8c022e}},	//   hguu_, _janw_, кәсч, _zdag, 
   {{0xdce00029,0x442e1018,0x628801fa,0x09f40302}},	//   dalī, fog_, _aveo, _חמים_, 
   {{0x3dc40042,0x00000000,0x00000000,0x00000000}},	//   _lanw_, --, --, --, 
   {{0xdce00171,0x00000000,0x00000000,0x00000000}},	//   falī, --, --, --, 
   {{0x442c0421,0x3dc40142,0x00000000,0x00000000}},	//   aog_, _nanw_, --, --, 
   {{0x442d2f43,0x80a0030f,0x00000000,0x00000000}},	//   bog_, نمون, --, --, 
   {{0x442e1019,0x3f9c2878,0xc0e4007b,0x22880419}},	//   cog_, gguu_, ظفين_, bĺk_, 
   {{0x2bdc2d6c,0x3dc40142,0x6b8e101a,0x0678010f}},	//   यासा, _banw_, _rdag, ֿנטל, 
   {{0x3dc40042,0xfbac0562,0xdce00055,0x00000000}},	//   _canw_, ट्सम, calī, --, 
   {{0x3dc4007f,0xe7740139,0x742000eb,0x00000000}},	//   _danw_, _uñçı, বতীয়_, --, 
   {{0xaa94c0bb,0x3ebc0295,0x9014072d,0x00000000}},	//   нимч, bwut_, _غذاؤ, --, 
   {{0x81b003f4,0x6ab805d7,0x8d741955,0xcb4400c7}},	//   য়ার_, इबेर, _قاغا, ьхои, 
   {{0xfd0c30c0,0x442ce08f,0x2bdc9a2c,0x693400cf}},	//   اجی_, zog_, याहा, енгу, 
   {{0x442c92e1,0xc0d4025c,0x00000000,0x00000000}},	//   yog_, ġġgħ, --, --, 
   {{0x6b8cbf7c,0x442c17b7,0xdb0c0306,0xdb040306}},	//   _udag, xog_, škát, leký, 
   {{0x442c0bb8,0xe69817a1,0x85a40114,0x00000000}},	// [3c590] vog_, яваш_, дјед, --, 
   {{0x2bdc1b6e,0x442c0368,0x81b00eac,0xc866101b}},	//   यावा, wog_, _জোন_, _отми, 
   {{0x628808ad,0x75889849,0xdce01a14,0x3f9c0009}},	//   _sveo, ьств_, valī, yguu_, 
   {{0x68f40209,0xdb0400c7,0x442c0042,0x978000f2}},	//   myzd, heký, uog_, _میفه, 
   {{0xc1b40150,0x00000000,0x00000000,0x00000000}},	//   _ﺤﻤﺭﺍ, --, --, --, 
   {{0x216a101c,0x442c4511,0x61442081,0xa0c40be2}},	//   чики_, sog_, нела, فيتو, 
   {{0x2056101d,0x442c1225,0x81b000bd,0xba0802d3}},	//   нтир, pog_, য়াল_, _ወዮ_, 
   {{0x3dc5bb14,0x6d5c02f0,0x442c022e,0xf95800d9}},	//   _sanw_, žral, qog_, וסות_, 
   {{0x28d00490,0xdce000e2,0x5f741f70,0x628802d0}},	//   हिडि, palī, واکر, _uveo, 
   {{0xc05800d4,0x00000000,0x00000000,0x00000000}},	//   _дід_, --, --, --, 
   {{0x9b040198,0xdc682360,0xae04215c,0x00000000}},	//   ɗuƙi_, яанд_, ئوپى, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9af410fe,0x53980375,0x5018008f,0x3dc40100}},	//   ركست, הירו, _צונו, _tanw_, 
   {{0x38c83bdb,0x1d081fb5,0xdb057c31,0x65680205}},	//   وازی_, _нели_, mekü, _şehn, 
   {{0xd824ee8b,0xdb06101e,0xb7f4000d,0x2bdc08a3}},	//   едви, lekü, _इकदम_, याशा, 
   {{0x59dc0b98,0xcba0014b,0x7bc00254,0x7ae001e3}},	//   माहर, _баъй, õmud, ämts, 
   {{0x7c252d9e,0x2bdc1a4e,0xdb0401ed,0x55f44421}},	// [3c5a0] _ijir, यारा, nekü, нчжу, 
   {{0x7c240225,0xfbac2e1e,0x00000000,0x00000000}},	//   _hjir, ट्रम, --, --, 
   {{0xdb04007d,0x7c24002d,0x17f8007b,0x00000000}},	//   hekü, _kjir, _فرحة_, --, 
   {{0xff44021a,0x7c240083,0x59dc09fa,0x649a101f}},	//   _مخ_, _jjir, मावर, ьтур_, 
   {{0x7c24090c,0xc7b00302,0x324800aa,0x00000000}},	//   _mjir, _גבר_, وستۍ_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7c258af3,0x1fbc3885,0xdb040419,0x00000000}},	//   _ojir, ्यूड, veký, --, 
   {{0x7c261020,0xe3b00014,0x00000000,0x00000000}},	//   _njir, _پرِ_, --, --, 
   {{0xfe6c58ae,0xdb0403fa,0x0dca1021,0x82900145}},	//   یدی_, gekü, пуни_, _مۇنچ, 
   {{0x7c2405d9,0xdb0400e4,0x8b641e4b,0x425006c2}},	//   _ajir, hekó, کادم, _منقر, 
   {{0x6ac801d9,0x7c24000f,0x2bdcd04e,0x6ab86495}},	//   िट्र, _bjir, याला, इब्र, 
   {{0x68f402d5,0xdb061022,0xac8400cf,0x00000000}},	//   vyzd, bekü, нгүл, --, 
   {{0xce480108,0x00000000,0x00000000,0x00000000}},	//   _езде_, --, --, --, 
   {{0x7c2400b4,0x9f5c0100,0x00000000,0x00000000}},	//   _ejir, _alwè_, --, --, 
   {{0x7c240a85,0xddc80311,0xa9340108,0x00000000}},	//   _fjir, speţ, тевш, --, 
   {{0x7c24ba5e,0xdb040022,0x00000000,0x00000000}},	//   _gjir, gekó, --, --, 
   {{0xc9840063,0x661001a9,0xfaa4009b,0x00000000}},	// [3c5b0] _пуни, аhkа, _бањо, --, 
   {{0xfb1c011a,0x00000000,0x00000000,0x00000000}},	//   _מוחמ, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4cc80729,0x00000000,0x00000000,0x00000000}},	//   িমপু, --, --, --, 
   {{0x312402dd,0x994803e0,0xc4cc00e5,0x00000000}},	//   ңдіг, _kışa_, _گےا_, --, 
   {{0xdb040254,0x00000000,0x00000000,0x00000000}},	//   vekü, --, --, --, 
   {{0x785c0270,0x27e8005b,0xc4cc00e5,0x00000000}},	//   _kōva, ojan_, _دےا_, --, 
   {{0x81b00183,0xdb05815a,0x1fb40798,0x2cac0051}},	//   য়াই_, tekü, тскр, dtdd_, 
   {{0x27ea1023,0x6448a9e9,0x525800db,0x00000000}},	//   ijan_, _ihei, سسۇڭ_, --, 
   {{0x7c261024,0x27e8a94d,0x644800a3,0x9b440133}},	//   _sjir, hjan_, _hhei, ێندو, 
   {{0x64480652,0xd00c006c,0x7a3800d2,0x27ea1025}},	//   _khei, صلی_, _lútî, kjan_, 
   {{0x64480036,0x785c16a3,0x629a1026,0x27e8a8ce}},	//   _jhei, _očvr, orwo, jjan_, 
   {{0x64491f38,0xddc61027,0xaa6401e0,0x00000000}},	//   _mhei, _абли, леяһ, --, 
   {{0x64480731,0xdedc02d3,0x7c24000f,0x27e80789}},	//   _lhei, _ኔርና_, _wjir, ejan_, 
   {{0x7c2408c8,0x6448023a,0x99480790,0x28b8084c}},	//   _tjir, _ohei, _dışa_, нутэ_, 
   {{0x644a1028,0x27ea1029,0x7c26102a,0x7bb000cc}},	//   _nhei, gjan_, _ujir, _জোৰো, 
   {{0x68e00267,0x95c801b9,0xdb040588,0x9734009d}},	// [3c5c0] äldr, млаб_, rekó, тэвч, 
   {{0x644a102b,0x27e802f6,0xc68c01d9,0x1dd000cd}},	//   _ahei, ajan_, زِم_, तयित, 
   {{0x64483c65,0x667412b7,0x62980036,0x9f4c023a}},	//   _bhei, ندەر, erwo, lkeä_, 
   {{0x644953af,0x8230034d,0x27e8220e,0x68e00267}},	//   _chei, یروا, cjan_, ålde, 
   {{0x64483c5d,0x91e4c70f,0xf196102c,0x9f4c023a}},	//   _dhei, коде, гиль, nkeä_, 
   {{0xf484c11e,0x2708022e,0x2bd82e04,0x00000000}},	//   _ماری, _sўng_, _बोना, --, 
   {{0x64487e9f,0x62980076,0x84e0117e,0x9f4c0108}},	//   _fhei, arwo, _корж, hkeä_, 
   {{0x765c2da1,0x644a102d,0xce680276,0x00000000}},	//   _hiry, _ghei, мрод_, --, 
   {{0x765e102e,0xed5801f1,0x00000000,0x00000000}},	//   _kiry, deľa_, --, --, 
   {{0xe3b0021a,0x27e8025c,0x765c090e,0xd24c03e6}},	//   _پرې_, zjan_, _jiry, _بۆت_, 
   {{0x765e102f,0x4fc61030,0x50a400dc,0xc04c00d3}},	//   _miry, _асла, _गमिष, _ві_, 
   {{0x765e1031,0x09c8078a,0x27e80076,0x660800a2}},	//   _liry, ाय्य, xjan_, _įekm, 
   {{0xddc97c96,0x6e9473d6,0x765c0076,0x27e80010}},	//   speš, _силу, _oiry, vjan_, 
   {{0x765e1032,0xaa440c50,0x994803b9,0xab2800c7}},	//   _niry, انسى, _qışa_, доҭа_, 
   {{0x27ea1033,0x02bc000d,0xac180117,0x00000000}},	//   tjan_, _एन्न, _поку_, --, 
   {{0xada40184,0x765c035a,0x57a40032,0xf804cde5}},	//   _раҫл, _airy, лыуҡ, ачун, 
   {{0x27ea1034,0x644a1035,0x765cba21,0x2c68045f}},	// [3c5d0] rjan_, _rhei, _biry, _hûd_, 
   {{0x27ea1036,0x644a1037,0x00000000,0x00000000}},	//   sjan_, _shei, --, --, 
   {{0x644a1038,0x765c03cb,0x27ea1039,0x651400ae}},	//   _phei, _diry, pjan_, دوائ, 
   {{0x7b0836b5,0x765e103a,0xc76410de,0xdb1400a2}},	//   _örtü, _eiry, _جادى, _layý, 
   {{0xe29a103b,0x02a56e01,0x644a103c,0x2c680b21}},	//   хал_, трем, _vhei, _lûd_, 
   {{0x785c07f5,0x765c00ee,0x644a103d,0x20d00327}},	//   _učvr, _giry, _whei, _pġi_, 
   {{0x64480c30,0xc51402e1,0x673c02d2,0x03c4022e}},	//   _thei, _شبست, _hysj, _исам, 
   {{0x644a103e,0x44d02375,0x765e103f,0x21f8020c}},	//   _uhei, _ić_, _ziry, _mèhi_, 
   {{0x765c337a,0x63aa1040,0xed580419,0x00000000}},	//   _yiry, _icen, veľa_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xed5801a2,0x25a4008c,0x673c0ffb,0x5f94b8d1}},	//   teľa_, _öllu_, _lysj, _биет, 
   {{0x63a8004e,0x9f4c023a,0x673c02d0,0x6e44004e}},	//   _jcen, tkeä_, _oysj, леөз, 
   {{0x673c03cd,0x290408c2,0x6cb4009d,0x3a240022}},	//   _nysj, ùlan_, гөөт, émpo_, 
   {{0x98a61041,0x9f4c02f6,0xdca61042,0x5ca402d9}},	//   лиге, rkeä_, _баки, _бикб, 
   {{0x63aa1043,0x765c07a8,0x246000b0,0xed5800d0}},	//   _ocen, _riry, _kėmu_, peľa_, 
   {{0x63a87dcd,0x00000000,0x00000000,0x00000000}},	//   _ncen, --, --, --, 
   {{0x765c0309,0x00000000,0x00000000,0x00000000}},	// [3c5e0] _piry, --, --, --, 
   {{0x63a92423,0x673ca934,0x8a780375,0xb6a401d5}},	//   _acen, _dysj, _ראית, лиғл, 
   {{0x531404fb,0x765d12b3,0x00000000,0x00000000}},	//   گذار, _viry, --, --, 
   {{0x673c002d,0x765c0e02,0x8380010a,0x3674129d}},	//   _fysj, _wiry, быше, _نۇرز, 
   {{0x765e1044,0x8c180375,0x753c0034,0xd3880220}},	//   _tiry, עוני, _wyrz, _үйге_, 
   {{0x63aa1045,0x2fc00055,0x00000000,0x00000000}},	//   _ecen, _źig_, --, --, 
   {{0xc65000dd,0x6ae000dc,0x00000000,0x00000000}},	//   _اہلک, _पप्र, --, --, 
   {{0xb4d00574,0xcfa5b5a9,0xdb140790,0x00000000}},	//   वटी_, ушки, _bayü, --, 
   {{0x8d861046,0x2d980005,0x9194009b,0x95740240}},	//   лунд, óreo_, _бјеш, _ርሑቕን_, 
   {{0x60cc033f,0x54400116,0x23680419,0x00000000}},	//   łama, _ئۆچك, ľaje_, --, 
   {{0x0ce02f8b,0x236804b9,0x4598008f,0x06340a7c}},	//   মন্ত, žaje_, עסטע, רניט_, 
   {{0xac18224f,0x4ea40f5c,0x00000000,0x00000000}},	//   тому_, _брка, --, --, 
   {{0xfbd001f7,0x4fc401ee,0x00000000,0x00000000}},	//   ستَ_, _асһа, --, --, 
   {{0xc330025f,0x673c0eef,0x00000000,0x00000000}},	//   מור_, _rysj, --, --, 
   {{0xdb04002f,0x00000000,0x00000000,0x00000000}},	//   efkä, --, --, --, 
   {{0x29302e56,0xdb1400f2,0x8ae402bf,0x673c0fac}},	//   ﺭﯨﭗ_, _obyè, _біол, _pysj, 
   {{0xa614086f,0xf674009d,0x00000000,0x00000000}},	// [3c5f0] амач, йгтэ, --, --, 
   {{0x2bdc1cb7,0x65961047,0x2b480841,0x00000000}},	//   याका, ражу, _izac_, --, 
   {{0x63a8e8e8,0xe3c40137,0x888000f2,0x00000000}},	//   _pcen, ирдү, _دیزن, --, 
   {{0x67d47ef7,0x673c03b2,0xc3c8007b,0x00000000}},	//   _тому, _tysj, عظام_, --, 
   {{0xa2e48068,0x490000fb,0x3494e73b,0x24600064}},	//   ролд, _түңг, _қатр, _rėmu_, 
   {{0x25a41125,0x66140472,0x6b48022e,0xb6046a10}},	//   _øll_, _umzk, gоgi, _ляск, 
   {{0x44d001a6,0xdb1401e1,0x69ac3996,0x60221048}},	//   _uć_, _jayò, _जानी, lēmi, 
   {{0xdb040793,0xdb14007f,0x2b480165,0x1f6400d1}},	//   mekö, _mayò, _ozac_, шким, 
   {{0xd00c774e,0xdb0455e1,0x4fe61049,0x9e644c70}},	//   بلي_, lekö, рмын_, јвод, 
   {{0x81b0015b,0x5f9401ed,0x06a00116,0x00000000}},	//   _জোর_, _چلائ, _ﻏﻪﻟﯩ, --, 
   {{0x9d46104a,0x61e04eba,0x23c800cd,0xdb04007c}},	//   ренд, _inll, _रसाद, nekö, 
   {{0x26da104b,0x81b00729,0x2bdc01bc,0x2a780334}},	//   _orso_, য়াও_, यागा, fpsb_, 
   {{0xdb140789,0x00000000,0x00000000,0x00000000}},	//   _rayó, --, --, --, 
   {{0x6020005f,0x00000000,0x00000000,0x00000000}},	//   dēmi, --, --, --, 
   {{0x18686161,0xdca41607,0x61e001ab,0x26d80427}},	//   таби_, _тайи, _mnll, _arso_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x61e000f3,0xdb14032b,0xb6c801d3,0xb8280137}},	// [3c600] _onll, _obyé, دازے_, _ۅيدۅ_, 
   {{0xdb040036,0xfbe80154,0x09e00354,0x00000000}},	//   rfkä, _পতিত, _доьн, --, 
   {{0x6d5c02fb,0x26d8000d,0x00000000,0x00000000}},	//   žrav, _erso_, --, --, 
   {{0x61e2104c,0xdb140986,0x59dc0404,0x81b000cc}},	//   _anll, _hayñ, माकर, _জোল_, 
   {{0x1dc40073,0x59c8012c,0xefe40023,0x00000000}},	//   _वसंत, ाजपर, ምታዊ_, --, 
   {{0xdb140113,0x00000000,0x00000000,0x00000000}},	//   _jayñ, --, --, --, 
   {{0x4fc50575,0xdb140309,0x90280022,0xa77402d2}},	//   аспа, _mayñ, кциа_, _áöðr, 
   {{0x61e2104d,0x03a0136b,0xdb04000d,0x6608010e}},	//   _enll, _мисо, lekõ, _įeki, 
   {{0x65680365,0xb8d8025c,0xbea405d9,0x81b0015b}},	//   _şehi, _ཛཱ_, لهين_, য়াজ_, 
   {{0x9f5a104e,0xfa1c0183,0xdb040037,0xcdd80063}},	//   ósá_, _দীঘল_, nekõ, тњи_, 
   {{0x3a382595,0xc18001d9,0xa5d8008f,0x00000000}},	//   dorp_, _بۯى۪, אַרי, --, 
   {{0x321cc628,0xebc43ad0,0x8c340107,0x2c080633}},	//   livy_, сәкн, ромӣ_, اعدی_, 
   {{0xcb46104f,0xdb040214,0xb3d800cc,0x00000000}},	//   рхни, ngkè, _থকাজ, --, 
   {{0xdb040790,0x59dc6620,0x26d80210,0xe9181cd0}},	//   yekö, मागर, _rrso_, гогі_, 
   {{0x2d8e1050,0x257c0421,0x2cbc067c,0xa4f40490}},	//   made_, _lâlâ_, _upvd_, _इथेच_, 
   {{0x2d8e1051,0x26d802f0,0x00000000,0x00000000}},	//   lade_, _prso_, --, --, 
   {{0x321c03d1,0xdb14033b,0x36d41d5b,0x00000000}},	// [3c610] kivy_, _wayò, оотр, --, 
   {{0x3a3a1052,0xdb040254,0x00000000,0x00000000}},	//   corp_, gekõ, --, --, 
   {{0x2a680190,0x321c0306,0x35680209,0x00000000}},	//   _huab_, divy_, ррун_, --, 
   {{0x2a6801d4,0x2d98068f,0xa424015b,0x3ad000b5}},	//   _kuab_, órej_, বত্য_, やpc_, 
   {{0x2d8e1053,0x26da1054,0x2a680218,0x36d4117e}},	//   kade_, _urso_, _juab_, _дояр, 
   {{0x2d8e1055,0x2a680b89,0xb8d401b9,0x00000000}},	//   jade_, _muab_, _اتیش, --, 
   {{0x2d8e1056,0x2a6801d4,0xa3d4a234,0x349489c3}},	//   dade_, _luab_, _ловч, _марр, 
   {{0x1e861057,0xf48412e7,0xf4340276,0x44fc00cc}},	//   блим, _фурн, _десэ, ্পদক_, 
   {{0x2d8e1058,0xa194022e,0x00000000,0x00000000}},	//   fade_, _газч, --, --, 
   {{0x82340137,0x61e21059,0x2d940cc9,0x00000000}},	//   _ئررا, _unll, орюс, --, 
   {{0x26c883c6,0x00000000,0x00000000,0x00000000}},	//   hwao_, --, --, --, 
   {{0x2a6805d5,0x26c84793,0xdbd40241,0x3a3801a4}},	//   _buab_, kwao_, _gùìs, worp_, 
   {{0x44fc02a6,0x2a680457,0x3a3801e6,0x2d8e105a}},	//   ্পিক_, _cuab_, torp_, bade_, 
   {{0x2a680190,0xdb06105b,0x5d840597,0x7e781b86}},	//   _duab_, ngké, _الثل, mpup, 
   {{0xd944146a,0x02b0012d,0x00000000,0x00000000}},	//   севи, ंझुन, --, --, 
   {{0x5ba847ce,0x7e780421,0xdb140784,0x321c02f0}},	//   _ским_, opup, _wayñ, zivy_, 
   {{0x7e7a105c,0x7c7c001f,0x44e4013f,0x26c8009f}},	// [3c620] npup, _የተባለ_, eε_, gwao_, 
   {{0xe8183d4d,0x7e780618,0x2c6401f2,0xd1cc0023}},	//   नोबा_, ipup, ịdee_, ኤታት_, 
   {{0x69ac62a8,0x09f40302,0x602000e2,0x2bdc041c}},	//   _जाती, _המים_, lēmu, याचा, 
   {{0x2d8e105d,0x2a680218,0x26c80083,0x67280010}},	//   zade_, _yuab_, bwao_, _žeje, 
   {{0x2d8d9582,0x2a6801d4,0x321c00bc,0x2d98012d}},	//   yade_, _xuab_, tivy_, órek_, 
   {{0x2d8e105e,0x65680790,0x00000000,0x00000000}},	//   xade_, _şehv, --, --, 
   {{0x23681326,0x2d8e105f,0x0fe0004e,0xdce000c0}},	//   žaja_, vade_, зөлү, mblė, 
   {{0x4fc405cc,0x321c06d9,0x2d8c058a,0x6e982377}},	//   сска, sivy_, wade_, авир_, 
   {{0x2d8e1060,0x7e79563b,0xe2aa1061,0x130406a6}},	//   tade_, gpup, _نالن_, _узам, 
   {{0xea00001e,0x272401fb,0x0200004e,0x00000000}},	//   _đắt_, ặng_, _езун, --, 
   {{0x2d8c202b,0x2a680457,0x2d800092,0xa3dc0073}},	//   rade_, _suab_, _የአርሶ_, _थोड_, 
   {{0x2d8e1062,0x2a680070,0xcc0801d5,0x00000000}},	//   sade_, _puab_, ازدن_, --, 
   {{0x2d8e1063,0x2a6801d4,0x00000000,0x00000000}},	//   pade_, _quab_, --, --, 
   {{0x2a680218,0x2bd8b213,0x44e4013f,0x9a8801a9}},	//   _vuab_, _बोरा, yε_, риёғ_, 
   {{0x629c33b8,0x2bb000bc,0x00000000,0x00000000}},	//   _åsov, _झापा, --, --, 
   {{0x9f5c00d2,0x2a680211,0x26c801c8,0xf8d8033f}},	//   _hlwá_, _tuab_, twao_, डि़य, 
   {{0xfbd05713,0x00000000,0x00000000,0x00000000}},	// [3c630] _ستي_, --, --, --, 
   {{0x26c827be,0xdb04045f,0x00000000,0x00000000}},	//   rwao_, rekô, --, --, 
   {{0x26c8000a,0x69d61064,0x6e2801bf,0x45480120}},	//   swao_, mdze, indb, учам_, 
   {{0x291001fa,0x44e40134,0x69d5c58e,0x00000000}},	//   mzza_, rε_, ldze, --, 
   {{0xa18998a4,0x9f540205,0x00000000,0x00000000}},	//   абла_, ügün_, --, --, 
   {{0x69d61065,0x291005d5,0x91e0490c,0x00000000}},	//   ndze, ozza_, доше, --, 
   {{0xe3e801d9,0xe10848d4,0x23680115,0x311c00cd}},	//   _پکان_, рейд_, ɾajn_, _भेदः_, 
   {{0x2bda1066,0x9f5c0548,0x29100083,0x7e780112}},	//   _बोला, _alwá_, izza_, tpup, 
   {{0x443e1067,0x7e780421,0x00000000,0x00000000}},	//   _iku_, upup, --, --, 
   {{0x443c0270,0xf5040014,0x69d5c3c0,0x00000000}},	//   _hku_, _بِہُ, jdze, --, 
   {{0x443c0083,0xdb04072b,0x59dc1b51,0x00000000}},	//   _kku_, lfkø, माघर, --, 
   {{0xc0580046,0x63b80007,0x443e1068,0x7e7a1069}},	//   _сіз_, nfwn, _jku_, ppup, 
   {{0x2910011c,0x443c009f,0x69d401f5,0x82480023}},	//   ezza_, _mku_, fdze, _ፖሊስታ, 
   {{0x63b80369,0x200c0120,0x00000000,0x00000000}},	//   hfwn, lhei_, --, --, 
   {{0x443cd497,0x7e684511,0x83e40150,0x394c12e8}},	//   _oku_, _hugp, _ﺍﺗﺎﻳ, åds_, 
   {{0x200c06ed,0x443e106a,0x63b80369,0x7e600332}},	//   nhei_, _nku_, jfwn, _hinp, 
   {{0x291086ed,0x7e600327,0x7e68036e,0x5588022e}},	// [3c640] azza_, _kinp, _jugp, ибам_, 
   {{0x443e106b,0x7e680099,0x19a8049e,0xa2dc6a60}},	//   _aku_, _mugp, _өтүп_, पिन्, 
   {{0x200c0649,0x7e609c67,0x443c0158,0x7e680af9}},	//   khei_, _minp, _bku_, _lugp, 
   {{0x7e6007ab,0x443c07ab,0x63b80399,0xfe64cbdb}},	//   _linp, _cku_, gfwn, _يد_, 
   {{0x443c0066,0xd1ca106c,0x7e6001c4,0xe7b000cf}},	//   _dku_, илде_, _oinp, _سۅلد, 
   {{0x443e106d,0x7e601937,0x59b002ab,0x6f000248}},	//   _eku_, _ninp, _जाफर, _lábú, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7e600857,0x200e106e,0x6f000162,0xea000208}},	//   _ainp, ghei_, _nábú, _đật_, 
   {{0x7e604cdf,0xb358072d,0x37dc00cc,0x00000000}},	//   _binp, _ایشا_, _যকাৰ, --, 
   {{0x6e2857cf,0x7e609e77,0xd2540014,0xbfa00051}},	//   undb, _cinp, _بیتش_, _hiề, 
   {{0x81b004c5,0x443c0784,0x021001ec,0xbfa00051}},	//   _জোক_, _yku_, _تٸلد, _kiề, 
   {{0x7e6041ba,0x200ce08d,0x9f4c0770,0x69ac0490}},	//   _einp, chei_, theô_, _जाही, 
   {{0x7e62106f,0x7b661070,0xbfa00208,0x00000000}},	//   _finp, дтре, _miề, --, 
   {{0x7e604ba8,0x69d400da,0xce3007d6,0xbfa00208}},	//   _ginp, udze, _توتک, _liề, 
   {{0x29061071,0x478833d2,0x69d61072,0x7e68002f}},	//   ála_, исам_, rdze, _zugp, 
   {{0x63b80007,0x7e621073,0xbfa00208,0x637002d2}},	//   xfwn, _zinp, _niề, _mónó, 
   {{0x7e60014f,0x443c022e,0xf42000fe,0x9f4c010e}},	// [3c650] _yinp, _rku_, যকাৰ_, kkeý_, 
   {{0x2bb1600d,0x6b8c00c6,0x7e60005a,0x443c045a}},	//   _झाडा, _heag, _xinp, _sku_, 
   {{0x6b8c37bd,0xdb14025a,0xd4c00137,0xfa34007b}},	//   _keag, _gbyâ, нөтк, _تريد, 
   {{0x64400093,0x6b8c0072,0x443c01a9,0x394c0254}},	//   _īlis, _jeag, _qku_, üdse_, 
   {{0x6b8e1074,0x200c0943,0x236809a8,0x7994000f}},	//   _meag, vhei_, žajo_, _ôfwê, 
   {{0x7e680953,0x824802d3,0x6b8e1075,0xbb3c008f}},	//   _rugp, _ፖሊሲታ, _leag, בעדי, 
   {{0x443c0093,0x7e621076,0x7e6a1077,0x200e1078}},	//   _tku_, _rinp, _sugp, thei_, 
   {{0x443e1079,0x7e62107a,0x6b8c084c,0x1e840d57}},	//   _uku_, _sinp, _neag, плим, 
   {{0x7e62107b,0xe164221d,0x00000000,0x00000000}},	//   _pinp, _فضای, --, --, 
   {{0x6b8c0618,0x27f80036,0x00000000,0x00000000}},	//   _aeag, _losn_, --, --, 
   {{0x7e62107c,0x116801d5,0x6b8c0afa,0x200c4593}},	//   _vinp, _المی_, _beag, phei_, 
   {{0x6288a0a5,0x6b8c0363,0x6604003e,0x00000000}},	//   _kweo, _ceag, hkhk, --, 
   {{0xdee44148,0x6b8c0192,0x201c0295,0x3dd004c5}},	//   _холи, _deag, _imwi_, ়াবল, 
   {{0x6b8c00ad,0x00000000,0x00000000,0x00000000}},	//   _eeag, --, --, --, 
   {{0x6b8e107d,0x62880472,0x6f0001e1,0x00000000}},	//   _feag, _lweo, _tábú, --, 
   {{0x4c980302,0x6b8c0af9,0x59c800bc,0x6ac401e3}},	//   _השקע, _geag, ाजहर, ötfå, 
   {{0x8ce40228,0xfce001d5,0xdb200108,0x00000000}},	// [3c660] _وقۇۇ, _хоқо, ätäy, --, 
   {{0x656803ee,0x6d5d9f53,0x645801f5,0xdb0c00d0}},	//   _şehr, ýrag, emwi, škót, 
   {{0x6b8c0421,0xd94400ee,0x00000000,0x00000000}},	//   _yeag, _хени, --, --, 
   {{0x68e004ce,0x27f80cf4,0x97c400ee,0xb4bc0037}},	//   ælde, _gosn_, _эйме, _अही_, 
   {{0xaad4302b,0xc2940006,0x427001ec,0x00000000}},	//   दिएक, зкіх_, егіс, --, 
   {{0xa5c00022,0x00000000,0x00000000,0x00000000}},	//   _иҩуе, --, --, --, 
   {{0xbfa001fb,0xd018434b,0x201c002f,0xe8180210}},	//   _tiề, йфи_, _bmwi_, नोवा_, 
   {{0x845000db,0x6f0002d0,0x00000000,0x00000000}},	//   _كۉلچ, tymc, --, --, 
   {{0x6b8e107e,0xa2dc0c00,0x62884e18,0x69ac0401}},	//   _reag, पिण्, _gweo, _जाली, 
   {{0x6b8e107f,0x201c0086,0x62642dfc,0x6f0002d0}},	//   _seag, _emwi_, _قالق, rymc, 
   {{0x6b8c00af,0x629c0158,0x8ed9af88,0x25ec07f7}},	//   _peag, _åsor, _گذار_, घाती_, 
   {{0x1014446a,0x00000000,0x00000000,0x00000000}},	//   _عباد, --, --, --, 
   {{0x34c80b02,0x6b8c0731,0x81b00154,0x1fb00022}},	//   रबुद, _veag, _জোট_, _рҩыџ, 
   {{0xe8040d2c,0x6b8c0b21,0xa2dc17c6,0x69ac01f9}},	//   रस्थ_, _weag, पित्, _जाळी, 
   {{0x6b8c3c60,0x64400174,0x00000000,0x00000000}},	//   _teag, _ílig, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc5682f84,0x320c010e,0xdc540244,0x44280205}},	// [3c670] محال_, _oldy_, _تروک, _ıc_, 
   {{0x62880099,0x60cc0210,0x00000000,0x00000000}},	//   _rweo, łami, --, --, 
   {{0xf9fc0302,0x9f5800ae,0x59b000cd,0x00000000}},	//   _להזמ, ósú_, _जातर, --, 
   {{0xd004511e,0x320c00ee,0xc88401af,0x00000000}},	//   _شل_, _aldy_, _мәғд_, --, 
   {{0x216870b2,0x64580549,0x04fc015b,0xe298702f}},	//   оили_, rmwi, ্পের_, цал_, 
   {{0xe818069f,0xa9240030,0x61444eb6,0xa3dc482a}},	//   नोरा_, poľč, мела, _थोर_, 
   {{0xdb1400e4,0x20541eec,0xdfd001d3,0x712400e5}},	//   _mbyá, мтир, ہيں_, ٹرول, 
   {{0x1fa80022,0x90bc0408,0x00000000,0x00000000}},	//   цкии_, ăхлă_, --, --, 
   {{0xf4340262,0x00000000,0x00000000,0x00000000}},	//   _четэ, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xea000016,0x201e1080,0x00000000,0x00000000}},	//   _đạt_, _umwi_, --, --, 
   {{0xed5801f1,0x67280427,0xd2f0074d,0x320c00a2}},	//   deľu_, _žejn, _пiер, _yldy_, 
   {{0x18681b88,0xee3802dd,0xdca4022e,0x00000000}},	//   жави_, _ені_, _жаки, --, 
   {{0x2bd87039,0x00000000,0x00000000,0x00000000}},	//   _बोका, --, --, --, 
   {{0x3f8c00c0,0x00000000,0x00000000,0x00000000}},	//   _jegu_, --, --, --, 
   {{0x3f8c037e,0x86b002dd,0x166400a7,0xac10010a}},	// [3c680] _megu_, кәрі, двам, _сĕте_, 
   {{0x3f8e1081,0x00000000,0x00000000,0x00000000}},	//   _legu_, --, --, --, 
   {{0x136802ee,0xb3a40139,0x00000000,0x00000000}},	//   ошли_, елеһ, --, --, 
   {{0x3f8e1082,0x2bc00bca,0xf7780022,0x981428f4}},	//   _negu_, ष्पा, _хҧа_, _آبدا, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3f8c0037,0x00000000,0x00000000,0x00000000}},	//   _aegu_, --, --, --, 
   {{0x3f8e1083,0xebb800b8,0x9b8000d1,0x00000000}},	//   _begu_, _hiḥ_, ﯩﻨﭽﻰ_, --, 
   {{0x3f8c19a2,0x7f980139,0x00000000,0x00000000}},	//   _cegu_, _näqı, --, --, 
   {{0xb8e0003d,0xb8d049a6,0x3f8c01c4,0x28d40210}},	//   _གད_, _ནའ_, _degu_, _डैनि, 
   {{0x3f8c198f,0xacf40114,0x42f808c3,0x00000000}},	//   _eegu_, епољ, _והמס, --, 
   {{0x3f8e1084,0xb4bc412f,0x8c340107,0xdd900137}},	//   _fegu_, _अहो_, донӣ_, دوپ_, 
   {{0x3f8c01e1,0x8fa4030d,0x00000000,0x00000000}},	//   _gegu_, _цаде, --, --, 
   {{0xebb8002b,0x0a680395,0x00000000,0x00000000}},	//   _niḥ_, юрни_, --, --, 
   {{0x2574c00f,0xae040220,0x00000000,0x00000000}},	//   _múló_, _سوعى, --, --, 
   {{0xbb300075,0xebb80055,0x7f980139,0xa2d41be1}},	//   ﯨﻜﻰ_, _aiḥ_, _fäqı, _मैन्, 
   {{0x23dc05ba,0x846c001f,0x00000000,0x00000000}},	//   _नोंद, _እነሱን_, --, --, 
   {{0x2cac007c,0x00000000,0x00000000,0x00000000}},	// [3c690] ludd_, --, --, --, 
   {{0xa2dc00e1,0xe2980209,0x45480108,0x00000000}},	//   पिस्, җак_, очем_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc6a61085,0x79240124,0x00000000,0x00000000}},	//   _орги, _шьыж, --, --, 
   {{0xc2c8adb0,0x2bc0a96d,0x3f8e1086,0x2cac015d}},	//   تبال_, ष्या, _regu_, hudd_, 
   {{0xa2f80bb2,0x2cace73f,0x624c0077,0x3f8e1087}},	//   ्नौज_, kudd_, cúol, _segu_, 
   {{0xd12c0014,0x2cac007c,0x00000000,0x00000000}},	//   ٝمو_, judd_, --, --, 
   {{0x2bc01a3e,0x2cac6729,0x70540408,0x00000000}},	//   ष्मा, dudd_, вĕсе, --, 
   {{0x442e1088,0x3f8e1089,0xe234026a,0xdee40212}},	//   mng_, _vegu_, _знањ, хопи, 
   {{0x62981362,0xddd800a2,0x2cac0042,0x0d800108}},	//   mswo, _duwş, fudd_, лльн, 
   {{0x3f8e108a,0x629837d9,0x2cac0221,0x1cb4031c}},	//   _tegu_, lswo, gudd_, _ཝཱཎ_, 
   {{0x442e108b,0x6298017a,0x20d0010e,0x80240127}},	//   nng_, oswo, _iši_, _غرام, 
   {{0x442e108c,0x629a108d,0x00000000,0x00000000}},	//   ing_, nswo, --, --, 
   {{0x442e108e,0x1a6444e7,0x62980373,0xdc9801b9}},	//   hng_, ژیکی_, iswo, _етиш_, 
   {{0x442c8106,0xaa640032,0x98540408,0x00000000}},	//   kng_, терһ, еташ, --, 
   {{0x236c014f,0x80a41fca,0x62980af9,0x442da4d9}},	//   _ngej_, _घटने, kswo, jng_, 
   {{0x7bc40120,0x2bd80073,0x2fc00254,0x00000000}},	// [3c6a0] _ibiu, _बोटा, _öige_, --, 
   {{0x442e108f,0x2bc070b0,0x7ae40323,0xebb80055}},	//   eng_, ष्ठा, _irit, _viḥ_, 
   {{0x546a1090,0x6298017a,0xe4740006,0xd7e800db}},	//   чаем_, eswo, вучэ, _емне_, 
   {{0x442e1091,0x6298017a,0x00000000,0x00000000}},	//   gng_, fswo, --, --, 
   {{0x6298017a,0x20d000ef,0xa2dc00cd,0xbba801ec}},	//   gswo, _aši_, पिष्, _ﻋﺩﻤﻪ_, 
   {{0x7ae46e48,0x442e1092,0x4a98008d,0xcc7c0131}},	//   _mrit, ang_, לינג, ﻠﻪﺭﮔ, 
   {{0x50647ffa,0x442c359a,0x78bc01e0,0x7bc40381}},	//   нтиа, bng_, ntrv, _obiu, 
   {{0x7ae61093,0x629802d0,0x00000000,0x00000000}},	//   _orit, bswo, --, --, 
   {{0xcf240491,0x7ae401f2,0x03a00719,0xc7d4011a}},	//   عربي, _nrit, _щито, תופי_, 
   {{0xfe6c0347,0x7bc40393,0x601403b2,0xc32002e8}},	//   حدي_, _abiu, _námf, _смук, 
   {{0x7ae61094,0xdb0401bf,0x00000000,0x00000000}},	//   _arit, ngkæ, --, --, 
   {{0x2cae1095,0x20c8007b,0xa2d40210,0x00000000}},	//   rudd_, _تبكي_, _मैड्, --, 
   {{0xddc00100,0x3a761096,0x00000000,0x00000000}},	//   kolň, лляр, --, --, 
   {{0x7ae61097,0x78bc0334,0x00000000,0x00000000}},	//   _drit, ftrv, --, --, 
   {{0x9e643c4b,0x07e421d0,0x442e1098,0xaad40118}},	//   _شاهن, нцам, yng_, दिङक, 
   {{0x236870b1,0x3ce802f0,0x7bc00254,0x00000000}},	//   žaji_, šivý_, õmut, --, 
   {{0x7ae571f0,0x2bc07922,0xab68025c,0x6a146e27}},	// [3c6b0] _grit, ष्णा, _bużż, _ампу, 
   {{0x442e1099,0x35b44143,0x00000000,0x00000000}},	//   wng_, лбур, --, --, 
   {{0x442c08cd,0x69c4c28e,0x6abe109a,0xbb48001f}},	//   tng_, _ibhe, ltsf, _ማስተዋ, 
   {{0x7ae40664,0x442d3dfd,0x97000131,0x6298045a}},	//   _yrit, ung_, _ھېلى, tswo, 
   {{0x442c4aa5,0x6abdf05f,0x68e40175,0x7798010b}},	//   rng_, ntsf, _hrhd, _якяр_, 
   {{0x442e109b,0x629a109c,0x6abcba17,0xc7640ef6}},	//   sng_, rswo, itsf, _ياڭى, 
   {{0xd24ca482,0x62989229,0x69c6109d,0x24640124}},	//   غنى_, sswo, _mbhe, _ахаҳ, 
   {{0x6abc5243,0xa2d400e1,0x387c01d3,0x6298017a}},	//   ktsf, _मैथ्, _évre_, pswo, 
   {{0x69c6109e,0xdd9800f7,0x60a40014,0x00000000}},	//   _obhe, үшү_, رٕکٔ, --, 
   {{0x7ae4069c,0x7bc40268,0x69ac09ab,0x1d080107}},	//   _rrit, _sbiu, _जागी, деои_, 
   {{0xa2d4eec7,0x7ae402d5,0x6abc01c7,0xdfb400d8}},	//   _मैत्, _srit, etsf, _абењ, 
   {{0x69c6109f,0x6abe10a0,0x908800e5,0x00000000}},	//   _abhe, ftsf, _آمنے_, --, 
   {{0x1ca4168d,0x68e0037e,0x6abc037e,0x9f040137}},	//   رێکی_, ældn, gtsf, _جوشو, 
   {{0xf1c40b9a,0x60140248,0x7ae610a1,0x4a40a5cb}},	//   ल्पन, _bámg, _vrit, иняв, 
   {{0x7ae610a2,0x6abe10a3,0x7bc000c5,0xd944009b}},	//   _writ, atsf, õmus, теви, 
   {{0xea0007ae,0x69c4cf3e,0xc7a210a4,0x7bc4003a}},	//   _đất_, _ebhe, ииск, _ubiu, 
   {{0x7c2610a5,0xcf9004ac,0xaac401b9,0xddc00419}},	// [3c6c0] _imir, יטן_, _یتین, tolň, 
   {{0x68e4010a,0x45801985,0x589610a6,0x892000e5}},	//   _frhd, игув, _ишму, اڑیو, 
   {{0x7c2405be,0x69c000df,0x68e0007c,0x00000000}},	//   _kmir, ĵlet, åldt, --, 
   {{0x1cb40489,0xff440214,0xdb0401bf,0x00000000}},	//   _ཝཱན_, _نخ_, rgkæ, --, 
   {{0x7c2610a7,0xc7b01203,0x386210a8,0xab68025c}},	//   _mmir, _דבר_, mmir_, _tużż, 
   {{0x386003be,0x313610a9,0x957418bc,0x00000000}},	//   lmir_, лелр, _шымч, --, 
   {{0x73c610aa,0xa3dc87ee,0x7c240248,0x00000000}},	//   _бәле, _थोक_, _omir, --, 
   {{0xb9ec067d,0x386210ab,0x4fc47411,0x9f5c020c}},	//   _ሕጂ_, nmir_, тска, _kowè_, 
   {{0xb8f40dd4,0xd9a802a6,0x9e94001f,0xdb040037}},	//   _ེར_, খ্যম, _ግብርና_, ngkä, 
   {{0x7c2610ac,0xacf8084c,0x386002c1,0xed500066}},	//   _amir, еноу_, hmir_, یپک_, 
   {{0x0c640092,0x386003b9,0xab9400d4,0x00000000}},	//   ተፈጠሩ_, kmir_, лині, --, 
   {{0x7c241529,0x6abc2ff9,0x2fc000a3,0x38601753}},	//   _cmir, ttsf, _ùig_, jmir_, 
   {{0x7c240135,0x601406ea,0x2ec43e1f,0xead00154}},	//   _dmir, _dámd, _сөйм, াম্ম, 
   {{0x7c2610ad,0x0ca90404,0x1ea83cc6,0x68e001bf}},	//   _emir, _قطبي_, _ساهي_, ældo, 
   {{0x69c44fde,0x89d402dd,0xe9180212,0xa5200073}},	//   _vbhe, ніңш, хові_, _मधेच_, 
   {{0x6e280552,0x37a800f7,0x38600334,0x383403f6}},	//   lidb, ктун_, gmir_, анср, 
   {{0x09d80011,0x1df4136e,0x00000000,0x00000000}},	// [3c6d0] দাবা, _شکیب_, --, --, 
   {{0x69c41717,0x6e28e3eb,0x00000000,0x00000000}},	//   _ubhe, nidb, --, --, 
   {{0x601408ce,0x00000000,0x00000000,0x00000000}},	//   _háme, --, --, --, 
   {{0x764009f3,0x601400bc,0x6e2801a9,0x00000000}},	//   _ímyn, _káme, hidb, --, 
   {{0x21a48fa3,0xbc1c010f,0x00000000,0x00000000}},	//   гилм, וואש, --, --, 
   {{0x26d80cfc,0x6e2a10ae,0x1718010f,0x00800139}},	//   _isso_, jidb, _טורע, аккү, 
   {{0x601402f0,0x10a0011c,0x6024004e,0x00000000}},	//   _láme, бищн, лдка, --, 
   {{0xdb0401e3,0x00000000,0x00000000,0x00000000}},	//   mfkö, --, --, --, 
   {{0x2f549dc2,0x6448123c,0x601401f1,0x9f5c034c}},	//   итьс, _ikei, _náme, _kowé_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x386210af,0xd00cdffc,0xdb04002f,0x0d2000cf}},	//   ymir_, زلی_, nfkö, йүшү, 
   {{0x601402ea,0x26d84727,0x9f5a10b0,0xde940640}},	//   _báme, _osso_, ósó_, _бадњ, 
   {{0x601445a7,0x8f980302,0x200c0280,0x0c200395}},	//   _cáme, _ניסי, mkei_, смян, 
   {{0xad24dc9d,0x3ebc0194,0x200c01f4,0x6e28002b}},	//   اریو, mtut_, lkei_, cidb, 
   {{0x1cac025c,0x386210b1,0x644860bd,0x3ebc07de}},	//   _ཕའི_, tmir_, _okei, ltut_, 
   {{0x601610b2,0x200e10b3,0x2a780175,0x38780327}},	//   _hámb, nkei_, bqsb_, rqrr_, 
   {{0x60140789,0x200c037e,0x48e00b01,0xf1c41cd2}},	// [3c6e0] _gáme, ikei_, _ғояв, ल्डन, 
   {{0x644a10b4,0x6378044e,0x3ebc0140,0xebb800b8}},	//   _akei, _ብሓፈሻ_, itut_, _kiḿ_, 
   {{0x26d80801,0x60140232,0xb465e698,0x38600455}},	//   _esso_, _záme, لگره, pmir_, 
   {{0x3ebc3209,0xf38457aa,0x6e280e04,0x00000000}},	//   ktut_, рғам, zidb, --, 
   {{0xc344011c,0x00000000,0x00000000,0x00000000}},	//   ляше_, --, --, --, 
   {{0x644808e7,0xf4840cbb,0x3dc401ab,0x154610b5}},	//   _ekei, _ناری, _nbnw_, _бегм, 
   {{0x6e2a10b6,0x64480093,0x00000000,0x00000000}},	//   vidb, _fkei, --, --, 
   {{0x6448fd74,0xce8801c6,0x5274004e,0x00000000}},	//   _gkei, нёол_, _бужу, --, 
   {{0x09d8015b,0x20c401c0,0x00000000,0x00000000}},	//   দাতা, гсөг, --, --, 
   {{0x60151a7f,0x0c8401ec,0x00000000,0x00000000}},	//   _cámb, лымм, --, --, 
   {{0x85f404ac,0x3ebc20ac,0x6e2a10b7,0x765c0368}},	//   אציע_, atut_, ridb, _mhry, 
   {{0x6e2808a4,0x200c42a9,0x92d400fe,0x7bc0000d}},	//   sidb, ckei_, িমী_, õmup, 
   {{0x6060129d,0x765c02f0,0x30e400d1,0xbea000d4}},	//   _بۇيل, _ohry, _ﺋﯧﻼﻧ, _гачк, 
   {{0x765c0042,0x6e28014f,0x00000000,0x00000000}},	//   _nhry, qidb, --, --, 
   {{0x7d78008f,0x00000000,0x00000000,0x00000000}},	//   _אנוו, --, --, --, 
   {{0x60144a1f,0x765c00a2,0x80d40a59,0x00000000}},	//   _táme, _ahry, _मनसे, --, 
   {{0x0a680104,0x65940022,0x66f400d8,0x00000000}},	// [3c6f0] _прои_, иаау, шпау, --, 
   {{0x644a10b8,0x765c4ebd,0x200c01c4,0x764003b2}},	//   _skei, _chry, zkei_, _ímyl, 
   {{0xc82c0092,0x00000000,0x00000000,0x00000000}},	//   _በፈረን, --, --, --, 
   {{0x3ebe10b9,0x1e000574,0x9f5c002e,0x57b002dd}},	//   ytut_, _लक्ष_, _wowé_, _мұст, 
   {{0xa9281fd6,0x00000000,0x00000000,0x00000000}},	//   _سزگە_, --, --, --, 
   {{0x765c0076,0x6d580306,0x3d180241,0x7a7c00df}},	//   _ghry, _ozva, _jáwé_, ערוס, 
   {{0xd5840272,0x6d580099,0xa3d449c4,0xa2d40210}},	//   _ئێمه_, _nzva, _ковч, _मैर्, 
   {{0x3ebc31ec,0x64480b6f,0x601400d2,0x200c19a2}},	//   ttut_, _ukei, _sámb, ukei_, 
   {{0x6d58006f,0xb364001f,0x200c04ef,0x69d8013f}},	//   _azva, ቻቸውን_, rkei_, _ɔwer, 
   {{0x3ebc0680,0x200e10ba,0x00000000,0x00000000}},	//   rtut_, skei_, --, --, 
   {{0x3ebe10bb,0xa2dc0141,0xc0a800db,0x0fc00073}},	//   stut_, पिक्, _ساال_, व्हढ, 
   {{0x6d580099,0x2d8c022f,0x00000000,0x00000000}},	//   _dzva, abde_, --, --, 
   {{0x3ebc6018,0x6d58006f,0xdcf41b0d,0xdea000f2}},	//   qtut_, _ezva, ıcıd, _بیخی, 
   {{0x5ebc045e,0x95240135,0x1dd80574,0xd65c02dd}},	//   ্টদে, _རྟའི_, _बघित, гiнд, 
   {{0x7e780309,0x3e780208,0x06cc0154,0x00000000}},	//   lqup, _hêt_, রিফি, --, 
   {{0x17847d60,0x5a9400f0,0xbc1400f1,0x3e780051}},	//   ргам, _кроф, _دستګ, _kêt_, 
   {{0xdce02c70,0x765e10bc,0xa3b800af,0x3d1801e1}},	// [3c700] malı, _phry, चलन_, _fáwé_, 
   {{0x49b004a9,0xdce067ab,0x00000000,0x00000000}},	//   _мәсу, lalı, --, --, 
   {{0x799e10bd,0x661400d0,0x00000000,0x00000000}},	//   marw, _dlzk, --, --, 
   {{0xdce00bfc,0x799e10be,0xc40801e1,0x00000000}},	//   nalı, larw, _àíló, --, 
   {{0xe7180724,0xd6683229,0x765e10bf,0x2d8c0450}},	//   mäğä, _لمحو_, _thry, ybde_, 
   {{0x799c23db,0x2cac00a9,0xdce01b0d,0x765c00d7}},	//   narw, yrdd_, halı, _uhry, 
   {{0xdce08eb9,0xe4300583,0xf2700014,0x4638010f}},	//   kalı, _کہند, _کێتھ, _סעלע, 
   {{0x799e10c0,0x601404bf,0x04402082,0x6d5d7eaf}},	//   harw, _rámc, _десн, ýram, 
   {{0x799e10c1,0x2cac00a9,0x3e780042,0xdce067ab}},	//   karw, wrdd_, _cêt_, dalı, 
   {{0x59b01fe5,0x799c4a16,0x00000000,0x00000000}},	//   _जागर, jarw, --, --, 
   {{0x799e10c2,0x05740375,0xfc4210c3,0x32c0033b}},	//   darw, יגים_, čín_, lòy_, 
   {{0x3e780042,0xc87c0790,0x6ce40132,0xdce0013d}},	//   _fêt_, üşme_, _ۇزبە, galı, 
   {{0x799c0cfd,0x8d854ada,0xe3b8002d,0x32c0007f}},	//   farw, _куйд, _sműk_, nòy_, 
   {{0x799e10c4,0x06cc0154,0x00000000,0x00000000}},	//   garw, রিমি, --, --, 
   {{0x6d5800da,0xdce02fbe,0x6014066a,0xa9540d30}},	//   _uzva, balı, _háma, скві, 
   {{0xdce00598,0x60140162,0x32c0007f,0xa774dd58}},	//   calı, _káma, kòy_, слач, 
   {{0x799e10c5,0x6b9e10c6,0x60140022,0x47c80183}},	// [3c710] barw, masg, _jáma, ৱালী, 
   {{0x6b9e10c7,0x35f4084c,0x228c01e1,0xb9080014}},	//   lasg, опур, _lókò_, دٲہم_, 
   {{0x69d610c8,0x60140306,0x92d40154,0x846c0092}},	//   meze, _láma, িমো_, _እነማን_, 
   {{0xe71800fd,0x6b9c00e2,0x06cc0eac,0x7e7802d1}},	//   cäğä, nasg, রিবি, yqup, 
   {{0xd24c00aa,0x601402fb,0x46300022,0x32c00100}},	//   کنو_, _náma, _дҭар, gòy_, 
   {{0x69d610c9,0xdce00724,0xb9100241,0x6b9e10ca}},	//   neze, zalı, _ninọ_, hasg, 
   {{0x6b9e10cb,0xdce01ae6,0x1a6001e1,0x3e780142}},	//   kasg, yalı, _jẹṣu_, _sêt_, 
   {{0x69d610cc,0x799e10cd,0x32c00100,0xdce00213}},	//   heze, zarw, bòy_, xalı, 
   {{0x601426c8,0x799c23db,0x6b9e10ce,0xdce02a15}},	//   _cáma, yarw, dasg, valı, 
   {{0x6014022c,0x69d610cf,0x7e7802d1,0x00000000}},	//   _dáma, jeze, rqup, --, 
   {{0x69d610d0,0xdce00bfc,0x9d440598,0x61e00efa}},	//   deze, talı, сенд, _iall, 
   {{0x6b9e10d1,0x69d610d2,0x799c23db,0x63ba10d3}},	//   gasg, eeze, warw, ngwn, 
   {{0x799e10d4,0xdce03e67,0x20c001ed,0xdb0400b5}},	//   tarw, ralı, lói_, ngkø, 
   {{0x69d610d5,0x61e210d6,0xdce08eac,0x63b80007}},	//   geze, _jall, salı, hgwn, 
   {{0x799c1625,0x20c0035b,0xdce06d5b,0x6b9e10d7}},	//   rarw, nói_, palı, basg, 
   {{0x61e210d8,0x799e10d9,0x8c40010b,0x6b9c08c2}},	//   _lall, sarw, _неще, casg, 
   {{0x69d60ae5,0x95c807d6,0x4b840184,0x61e000ad}},	// [3c720] beze, ллаб_, _уйын_, _oall, 
   {{0x20c08310,0x61e210da,0x69d41901,0x942400fb}},	//   kói_, _nall, ceze, әмде, 
   {{0x0b4c001f,0xd0580213,0x20c000c7,0x00000000}},	//   _ማስተማ, _ertə, jói_, --, 
   {{0x61e210db,0x2d9809c2,0xf38801e0,0x20c001d3}},	//   _aall, órez_, рҙай_, dói_, 
   {{0xa3a8012c,0x228c0248,0x00000000,0x00000000}},	//   _गएर_, _rókò_, --, --, 
   {{0xe1f40fc0,0x6014c469,0x32c0007f,0x00000000}},	//   оҳу_, _ráma, ròy_, --, 
   {{0x61e210dc,0x85980302,0x601406ea,0x10e400a7}},	//   _dall, _תשלו, _sáma, сюлм, 
   {{0x69d5ef54,0x68e210dd,0x61e210de,0x6b9c01c4}},	//   zeze, ældi, _eall, xasg, 
   {{0x69d610df,0xadd80640,0x91b8007b,0xcee802f2}},	//   yeze, ампу_, _مطار_, اربن_, 
   {{0x2d9a10e0,0x61e210e1,0xc2780375,0x6b9c015d}},	//   úre_, _gall, _ערבי, wasg, 
   {{0x69d610e2,0x59b0012c,0x6b9c0ffb,0xc5f80a7c}},	//   veze, _जाजर, tasg, אפיט, 
   {{0x69d610e3,0x0fe210e4,0x61e210e5,0x601401ed}},	//   weze, _хөкү, _zall, _táma, 
   {{0x61e210e6,0x6b9e10e7,0xd1f4001f,0xd1500023}},	//   _yall, rasg, _ፈንታ_, _ምቕባል, 
   {{0x69d40dd4,0x61e210e8,0x7f38008f,0x6b9dbc42}},	//   ueze, _xall, _געדו, sasg, 
   {{0x69d610e9,0x00000000,0x00000000,0x00000000}},	//   reze, --, --, --, 
   {{0x69d610ea,0xc864016c,0xf8040276,0xa71400d4}},	//   seze, стги, пчун, омбі, 
   {{0x69d40925,0x20c001d3,0x00000000,0x00000000}},	// [3c730] peze, zói_, --, --, 
   {{0xdb140248,0x00000000,0x00000000,0x00000000}},	//   _ìbár, --, --, --, 
   {{0xe4d43918,0xd4c000f7,0x28f85184,0xd1dc0092}},	//   تقاد, мөтк, _тень_, ናናት_, 
   {{0x61e210eb,0x20c00124,0x13a801b9,0x00000000}},	//   _sall, vói_, لنمی_, --, 
   {{0xc76610ec,0xe9440330,0x00000000,0x00000000}},	//   _دادى, _درکی, --, --, 
   {{0x20880801,0x20c001ed,0x7d043c38,0xdb0401bf}},	//   айки_, tói_, øjsk, rgkø, 
   {{0x61e00afa,0x61ec03f9,0x1fb454d9,0x60180114}},	//   _vall, ɓall, оспр, ицир_, 
   {{0x20c210ed,0x600809f7,0x61e210ee,0x74680139}},	//   rói_, рним_, _wall, _грув_, 
   {{0x442e10ef,0xd5c46b9b,0xdb082e00,0x20c06293}},	//   mig_, र्वज, önüm, sói_, 
   {{0x442e10f0,0x61e210f1,0xfc400122,0x291c0198}},	//   lig_, _uall, čím_, _ƙwal_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x442e10f2,0xe06004d3,0x63a80327,0xd9b000ab}},	//   nig_, _تێبی, _jden, जल्ट, 
   {{0x3f9c72dc,0x290401e6,0x3ab40075,0x63a9cbb6}},	//   mauu_, älan_, чәйт, _mden, 
   {{0x3f9c03a0,0x6014022a,0x5d6801af,0x00000000}},	//   lauu_, _kámo, _килм_, --, 
   {{0xa3b819ec,0x442e10f3,0x63aa10f4,0x5fdd22aa}},	//   चला_, kig_, _oden, _मसाल, 
   {{0x63a82173,0x601610f5,0x442e10f6,0x3f9c03a0}},	//   _nden, _mámo, jig_, nauu_, 
   {{0x56287694,0x7c7c001f,0x601401ef,0x9aa40345}},	// [3c740] ажам_, _ከተባለ_, _lámo, _بمخو, 
   {{0x3f9c0418,0x442e10f7,0x00000000,0x00000000}},	//   hauu_, eig_, --, --, 
   {{0x442e10f8,0x2bc006ff,0x6288120f,0x60140308}},	//   fig_, ष्का, _ateo, _námo, 
   {{0x442e10f9,0xd1dc0023,0x6d5c0327,0x00000000}},	//   gig_, ናዓት_, żrag, --, 
   {{0x63a9c138,0xfe640014,0x0cb4121d,0xd1b800d1}},	//   _dden, _ٲد_, _अम्म, لاغا_, 
   {{0x60140085,0xfe6441ff,0x59c800dc,0x442e10fa}},	//   _bámo, _زد_, िभिर, aig_, 
   {{0x442cae45,0xd0181b74,0x62893a3b,0x92e800cc}},	//   big_, ифи_, _eteo, মহে_, 
   {{0x442d455c,0x60156274,0xa2d40034,0x00000000}},	//   cig_, _dámo, _मैक्, --, 
   {{0x628800ad,0xe2a801c8,0x59c86a60,0x00000000}},	//   _gteo, _هالن_, िभार, --, 
   {{0x63a80306,0x00000000,0x00000000,0x00000000}},	//   _zden, --, --, --, 
   {{0x217405f5,0x63a803ac,0x2da40092,0x00000000}},	//   _хуур, _yden, _ለአርሶ_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x60142b57,0xef10004e,0x00000000,0x00000000}},	//   _zámo, _чүпө, --, --, 
   {{0x442e10fb,0xbb5800d4,0x00000000,0x00000000}},	//   zig_, іарх_, --, --, 
   {{0x442e10fc,0xfbd04251,0x2ebc04c5,0x2d9c0327}},	//   yig_, িয়ত, _অনিষ, _ieve_, 
   {{0x2d9e10fd,0x442e10fe,0x601401ef,0x00000000}},	//   _heve_, xig_, _náml, --, 
   {{0x442e10ff,0x2d9e1100,0xd15002d3,0xa3b80037}},	// [3c750] vig_, _keve_, _ምዕብል, चलस_, 
   {{0x442e1101,0x2d9e1102,0xa2d40456,0xd5c495d6}},	//   wig_, _jeve_, _मैग्, र्लज, 
   {{0x63a80649,0x6288a66a,0x2d9c035b,0x24540fac}},	//   _pden, _steo, _meve_, låmi_, 
   {{0x2d9e1103,0x29100209,0x60141ab0,0x68e0041e}},	//   _leve_, myza_, _rámo, ældu, 
   {{0x442e1104,0xb17c01e4,0x60159da4,0x784401c0}},	//   rig_, _saĥa, _dáml, _цээж, 
   {{0x442e1105,0x854400c0,0x00000000,0x00000000}},	//   sig_, _дэбе, --, --, 
   {{0x442e1106,0x21691e13,0xe5081c36,0x3f9d024c}},	//   pig_, щики_, _ايزو_, tauu_, 
   {{0x63aa1107,0x201a1108,0xfc402b57,0x25a0009a}},	//   _uden, ósi_, čík_, lahl_, 
   {{0x2d9e1109,0x443c0521,0x6288332c,0x22940150}},	//   _beve_, _iju_, _uteo, _رلاس, 
   {{0x601400dd,0x443c009b,0xe2980032,0x25a00158}},	//   _támo, _hju_, _ваҡ_, nahl_, 
   {{0x2d9e110a,0x3f9c54bb,0x443c00f3,0x00000000}},	//   _deve_, pauu_, _kju_, --, 
   {{0xee380228,0x401c000d,0x00000000,0x00000000}},	//   йнө_, _बतिआ_, --, --, 
   {{0xb17c01e4,0x2d9e110b,0x32540354,0xeb74004e}},	//   _maĥn, _feve_, _авăр, дырэ, 
   {{0x443c0b21,0x2d9c000f,0xbf04000d,0x00000000}},	//   _lju_, _geve_, षहीन_, --, 
   {{0x443c110e,0x8df80375,0x29100432,0x00000000}},	//   _oju_, _להסת, gyza_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x25a00112,0xe8e80139,0x4610187c,0x138800d1}},	// [3c760] fahl_, _töşе, کولر, ەختى_, 
   {{0x443e110c,0x2d9c0005,0x43480023,0x60cc0210}},	//   _aju_, _xeve_, _ንሓዋሩ, łamy, 
   {{0x68e000b5,0xda0800f1,0x00000000,0x00000000}},	//   ældt, _نيکه_, --, --, 
   {{0x8b3000e5,0x00000000,0x00000000,0x00000000}},	//   _آفیش, --, --, --, 
   {{0x2bc0085c,0x443cfd3d,0x1dbc041c,0x00000000}},	//   ष्टा, _dju_, ्भात, --, 
   {{0x443e110d,0xf8b0fa4a,0x06cc00eb,0x00000000}},	//   _eju_, _जटाय, রিশি, --, 
   {{0x2d9e110e,0x0cb40729,0xf004009d,0x73c40150}},	//   _reve_, _জন্ত, мүжи, _жәле, 
   {{0x2d9e110f,0x853802e4,0x2ef40305,0x9424094e}},	//   _seve_, _הגלי, дзир, _эмбе, 
   {{0x04400f14,0x2d9c0588,0x4ea40092,0x29100210}},	//   _четн, _peve_, _ማደራጃ_, zyza_, 
   {{0x443c0427,0x71740ed1,0xa2d4012d,0x20c801e2}},	//   _zju_, _قۇشا, _मैट्, _ژبني_, 
   {{0x2d9e1110,0x443c035b,0x10a40798,0x00000000}},	//   _veve_, _yju_, _ѕидн, --, 
   {{0x25a00730,0xbb940a8f,0x8078011a,0x00000000}},	//   zahl_, нающ, _הנאצ, --, 
   {{0x2d9c03b7,0x7b642377,0x7c90001f,0xca740023}},	//   _teve_, етре, _የደርግ_, በረኮም_, 
   {{0xb17c01e4,0x00000000,0x00000000,0x00000000}},	//   _maĥo, --, --, --, 
   {{0x7e480014,0x00000000,0x00000000,0x00000000}},	//   _اسنہ_, --, --, --, 
   {{0x25a03262,0x00000000,0x00000000,0x00000000}},	//   wahl_, --, --, --, 
   {{0x68440020,0x25a21111,0x443c002d,0x36d4009b}},	// [3c770] _የእርስ, tahl_, _rju_, нотр, 
   {{0x443c1121,0xf7700451,0xe7ec4ed3,0xfb1c011a}},	//   _sju_, طاق_, _चोरा_, _לוחמ, 
   {{0xefd40020,0xf6502961,0x25a00732,0x443e1112}},	//   ካሄድ_, ائق_, rahl_, _pju_, 
   {{0x25a003cd,0x00000000,0x00000000,0x00000000}},	//   sahl_, --, --, --, 
   {{0x443c009b,0x60140174,0x25a0009a,0x3f88002e}},	//   _vju_, _fámj, pahl_, ñcum_, 
   {{0x27ea1113,0xf5e40064,0x00000000,0x00000000}},	//   ldan_, _пісм, --, --, 
   {{0x443c0023,0xa0681bc4,0xdb04007f,0x27e8058a}},	//   _tju_, оака_, ngkò, odan_, 
   {{0x27ea1114,0x443e1115,0xbbdc0316,0x26c80109}},	//   ndan_, _uju_, _बसेक, otao_, 
   {{0x26ca1116,0x27ea1117,0x627801f1,0xa2d432ed}},	//   ntao_, idan_, _dňoc, _मैच्, 
   {{0x27ea1118,0x645a1119,0xe16453f3,0x0d80013d}},	//   hdan_, llwi, _قضای, кльн, 
   {{0x27e89794,0x1d08b7f6,0xb17c01e4,0xa1140736}},	//   kdan_, цени_, _maĥl, _توات, 
   {{0x0ea60364,0x26c804a7,0xe7ec0456,0x00000000}},	//   _खिचड, ktao_, _चोला_, --, 
   {{0x27ea111a,0x645a111b,0x201c0455,0x7e600098}},	//   ddan_, ilwi, _ilwi_, _thnp, 
   {{0x6458789a,0x27e80009,0x00000000,0x00000000}},	//   hlwi, edan_, --, --, 
   {{0x6458014b,0x27ea111c,0x69cc93cb,0x28f8084c}},	//   klwi, fdan_, द्धी, пэтэ_, 
   {{0x27ea111d,0x1dbc1157,0x09d800eb,0x00000000}},	//   gdan_, ्भवत, দাগা, --, 
   {{0x64591a81,0x290400cc,0x9b445ce9,0x00000000}},	// [3c780] dlwi, ølar_, _زندو, --, 
   {{0x7ae4547a,0x69cc0cb4,0x6458004b,0x27ea111e}},	//   _isit, द्दी, elwi, adan_, 
   {{0xd9447737,0x27ea111f,0x201c0477,0x26c801c8}},	//   _цени, bdan_, _olwi_, atao_, 
   {{0x27e830a1,0x2e3401e1,0x7ae40055,0xed5800d7}},	//   cdan_, _kùfè_, _ksit, ngľa_, 
   {{0x926814f0,0x78bc05b1,0x03a21120,0x00000000}},	//   орка_, lurv, тичо, --, 
   {{0x201c7f0b,0x7ae40451,0xdb0403a2,0x6620033f}},	//   _alwi_, _msit, ngkñ, ązkó, 
   {{0x291c03f9,0xefd4001f,0x7bc40381,0xc48000f0}},	//   _ƙwai_, ካሄዱ_, _ociu, _алск, 
   {{0x7ae61121,0xc02400f1,0x28e0000d,0x00000000}},	//   _osit, وړنه_, _पनसि, --, 
   {{0x60140232,0x7ae61122,0x78be1123,0x03a067d7}},	//   _zámk, _nsit, hurv, _шито, 
   {{0x27ea1124,0x78be1125,0x60140597,0x7bc61126}},	//   zdan_, kurv, _lámh, _aciu, 
   {{0x45b4025f,0x7de00022,0xfe6c3997,0x00000000}},	//   ופיל_, _sãsõ, جدي_, --, 
   {{0x320c5fd3,0x27e93979,0x78bc08ce,0xb17c0115}},	//   _hody_, xdan_, durv, _maĥm, 
   {{0x320c6b7e,0x27ea1127,0x3c44009d,0x42d800df}},	//   _kody_, vdan_, тээв, ֿקלע, 
   {{0x7ae40770,0x320c0170,0x27ea1128,0x27f80109}},	//   _dsit, _jody_, wdan_, _snsn_, 
   {{0x27e98716,0x320e1129,0x07e6112a,0x67d6112b}},	//   tdan_, _mody_, мцам, нову, 
   {{0x7ae40334,0x320e112c,0x6014013a,0x00000000}},	//   _fsit, _lody_, _rámk, --, 
   {{0x6014007b,0x6d583626,0x00000000,0x00000000}},	// [3c790] _dámh, _hyva, --, --, 
   {{0xea0007ae,0x27ea112d,0x320c0170,0x26ca112e}},	//   _đặt_, sdan_, _nody_, rtao_, 
   {{0x26c83ad4,0x69c6112f,0x27ea1130,0x78bc3113}},	//   stao_, _iche, pdan_, curv, 
   {{0x27e8f7c0,0x320c0109,0x68e61131,0x8cd409bb}},	//   qdan_, _aody_, _ishd, _बहनो, 
   {{0x7ae402fa,0x320e1132,0xe2982c0b,0x6abc0250}},	//   _xsit, _body_, чал_, nusf, 
   {{0x320e1133,0xe53407dd,0x2240000d,0xbbdc01f9}},	//   _cody_, _зегь, õhk_, _बस्क, 
   {{0x69c51d94,0xe0d06e9a,0x03c40b3e,0x201c007f}},	//   _mche, ازت_, _осам, _plwi_, 
   {{0x8c440213,0x73d800d8,0x00000000,0x00000000}},	//   _yuşş, _одср_, --, --, 
   {{0x69c61134,0x320c0170,0x6abc002d,0x6d58495b}},	//   _oche, _fody_, jusf, _ayva, 
   {{0x69c400b4,0x7bc61135,0x78be1136,0x68e4036b}},	//   _nche, _sciu, yurv, _oshd, 
   {{0x60142b76,0xd24c05d9,0x7ae40083,0xdb140241}},	//   _lámi, _اچن_, _ssit, _ìbúr, 
   {{0x69c61137,0x7ae400e4,0x9cf40046,0x05cc66c0}},	//   _ache, _psit, _үзді, स्तब, 
   {{0x60161138,0x68e403ac,0x6d581ae4,0x6abe1139}},	//   _námi, _ashd, _eyva, gusf, 
   {{0xdca4cb30,0x68e40161,0x7cf401e1,0x7ae4003a}},	//   _заки, _bshd, _ẹra, _vsit, 
   {{0x6d580006,0x69c4593b,0x186800d8,0x6abc002f}},	//   _gyva, _dche, зави_, ausf, 
   {{0x69c6113a,0x7ae6113b,0x60140241,0xb17c01e4}},	//   _eche, _tsit, _bámi, _raĥm, 
   {{0x96641064,0x78be113c,0x16640c5c,0x68e4010e}},	// [3c7a0] екае, surv, евам, _eshd, 
   {{0x601403b2,0x6d5800e4,0xdebc00d1,0x3ce0000d}},	//   _dámi, _yyva, _ﻣﻪﺟﺒ, _औनाइ_, 
   {{0x320c00a3,0x6014c560,0x68e4036e,0x00000000}},	//   _rody_, _támh, _gshd, --, 
   {{0x9814007b,0x320c07f7,0x00000000,0x00000000}},	//   _أبدا, _sody_, --, --, 
   {{0x087400c8,0x320c0109,0x69cc15e0,0x601402d2}},	//   _רעכט_, _pody_, द्वी, _gámi, 
   {{0x7738001f,0x05c40d79,0x00000000,0x00000000}},	//   _በመሳሰ, _लायब, --, --, 
   {{0x320c03c6,0x60140306,0x69c001ab,0x59d000cd}},	//   _vody_, _zámi, òlei, द्यर, 
   {{0xaa0c0316,0x320c068f,0x6d5805ac,0x23d40022}},	//   _सक्छ_, _wody_, _ryva, _ицур, 
   {{0x320c03d1,0x6d5800a2,0x00000000,0x00000000}},	//   _tody_, _syva, --, --, 
   {{0x7ed000c6,0x5276113d,0x6abc0037,0x00000000}},	//   ازيا, _чубу, vusf, --, 
   {{0x4e040724,0x00000000,0x00000000,0x00000000}},	//   _үзеб, --, --, --, 
   {{0x6d580122,0x6abc00c5,0xc4d0011a,0x5ebc00cc}},	//   _vyva, tusf, נגר_, ্টজে, 
   {{0x69c402fa,0xfba805f5,0x0dc402d3,0x68e40009}},	//   _pche, этэй_, ጽሓፍ_, _sshd, 
   {{0x601400d0,0x68e40240,0xa124010b,0xd6e0012d}},	//   _rámi, _pshd, _öňüs, _miłą_, 
   {{0x248c0841,0x60140162,0xfce00063,0x6278010e}},	//   _čemo_, _sámi, _бојо, _oňon, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69c6113e,0xfc40012c,0x6b8c0241,0xabb400c7}},	// [3c7b0] _tche, čít_, _ifag, _зақә, 
   {{0x69c6113f,0x3ea80118,0x65961140,0x888015b4}},	//   _uche, ácti_, тажу, _میسن, 
   {{0x853001d5,0x68e402d0,0xf1c400bc,0xe894a10d}},	//   دواچ, _ushd, ल्छन, _шань, 
   {{0x69ce1141,0x60140005,0xf96800fd,0x22942678}},	//   द्री, _támi, _ярый_, видя, 
   {{0x862402d5,0x045801d3,0xa2e61142,0x752006be}},	//   _зьве, _ہجرت_, толд, _əmzi, 
   {{0x26d80483,0x00000000,0x00000000,0x00000000}},	//   _ipso_, --, --, --, 
   {{0xf1a8168d,0x6b8c0607,0xd00c05d9,0xc7640220}},	//   راوه_, _ofag, ڪلي_, _زاڭى, 
   {{0xd00c5f2e,0x6aac05ac,0x87380092,0x00000000}},	//   قلى_, _ovaf, _በመስቀ, --, 
   {{0xd00c1b4d,0x4fe5e34a,0x6d5c07de,0x3ea80118}},	//   تلي_, тмын_, üran, éct_, 
   {{0x6b8d246e,0x63ac022c,0x1ca403e6,0xa3b800c5}},	//   _afag, ðanf, نێتی_, चलक_, 
   {{0x9d4430cb,0x6aae1143,0x6b8c0332,0xdb0426bc}},	//   тенд, _avaf, _bfag, ngkö, 
   {{0xdeb61144,0x00000000,0x00000000,0x00000000}},	//   _абды, --, --, --, 
   {{0x5de405f5,0xdb040240,0x6e945e0c,0xcfa40022}},	//   _ажла, makë, _бичу, _рыхҩ, 
   {{0xe3d42aab,0x3e680b8d,0xaf361145,0x3ebd1c2f}},	//   _সোমব, _эшен_, _حرمت, muut_, 
   {{0x3ebe1146,0x2b48009a,0x6aac0099,0x6b8c03cb}},	//   luut_, _exac_, _evaf, _ffag, 
   {{0xdb04036e,0x00000000,0x00000000,0x00000000}},	//   nakë, --, --, --, 
   {{0x3ebc2595,0x00000000,0x00000000,0x00000000}},	// [3c7c0] nuut_, --, --, --, 
   {{0xdb040200,0x998400e5,0x00000000,0x00000000}},	//   hakë, _جلدو, --, --, 
   {{0x26da1147,0x6aac004c,0x601402d2,0xd6e0012d}},	//   _epso_, _zvaf, _hámu, _siłą_, 
   {{0x3ebc3fb5,0xdb040200,0x98740114,0x00000000}},	//   kuut_, jakë, _шупљ, --, 
   {{0x79340020,0x3ebe1148,0x15d401d9,0x5fa40412}},	//   _አስቀድ, juut_, _لگاں_, _गज़ल, 
   {{0x3a380142,0x00000000,0x00000000,0x00000000}},	//   nirp_, --, --, --, 
   {{0x601401e1,0xe19401c6,0x00000000,0x00000000}},	//   _lámu, урчэ, --, --, 
   {{0xb17c01e4,0x00000000,0x00000000,0x00000000}},	//   _maĥi, --, --, --, 
   {{0x3ebc0869,0xbea40451,0x601409e8,0x32640117}},	//   guut_, نهين_, _námu, _беаҳ, 
   {{0x6b8c011c,0xdb043040,0xe3b80107,0xc0dc0023}},	//   _sfag, makè, _обӣ_, ቒሶም_, 
   {{0xe1ec00b2,0x10a40276,0xdb04eda4,0x25a400c5}},	//   _رڳو_, _риен, lakè, _õlle_, 
   {{0x3ebe1149,0xdb040200,0xaa9421ee,0x601400e5}},	//   buut_, cakë, лимч, _bámu, 
   {{0x3fc9589e,0x1cd8031c,0xe7ec000d,0xa81400d1}},	//   _آدمی_, ོསུ_, _चोगा_, қдаш, 
   {{0x601403b2,0x00000000,0x00000000,0x00000000}},	//   _dámu, --, --, --, 
   {{0x59d00146,0x26d801c3,0xdd90009f,0x8c64022e}},	//   द्धर, _spso_, _اوٺ_, _итид, 
   {{0xfc32048a,0xe7ec00af,0x6014003a,0x6b8e114a}},	//   _وحي_, _चोखा_, _fámu, _ufag, 
   {{0xa6f40220,0x6014032e,0xdef801f3,0x0a680117}},	// [3c7d0] ызаш, _gámu, _ፈጥኖ_, _орои_, 
   {{0x9af80375,0xdb04036e,0x36d40117,0x00000000}},	//   _נפתח, zakë, рофр, --, 
   {{0x67280135,0x601400d7,0xe0bc0154,0x7bc00162}},	//   _żejd, _zámu, _আন্ন, ómug, 
   {{0xa37c02ce,0xe3a400f2,0x00000000,0x00000000}},	//   _kaŵi, اشای, --, --, 
   {{0x6f040e89,0xdef00092,0x00000000,0x00000000}},	//   _àich, ቃቅን_, --, --, 
   {{0x21683967,0x61458828,0xb59400f0,0xc0f00092}},	//   нили_, лела, _вирш, ፌዲሪ_, 
   {{0x2056114b,0xa3d400a7,0x3ebc002e,0xdb04036e}},	//   лтир, _йовч, wuut_, takë, 
   {{0x63ac05a4,0x3ebe114c,0x05cc07f8,0xc0f40092}},	//   ðand, tuut_, स्रब, _ፈፅሞ_, 
   {{0xdb040023,0x3ce402d2,0x00000000,0x00000000}},	//   rakë, _ssnv_, --, --, 
   {{0x3ebe114d,0xdb040240,0x6014f7b3,0x00000000}},	//   ruut_, sakë, _rámu, --, 
   {{0xdb06114e,0x3ebc20ac,0x60146316,0x06cc015b}},	//   maké, suut_, _sámu, রিটি, 
   {{0xdb05e76e,0x9ef400c6,0xb06401d9,0x3ebc1e70}},	//   laké, _مستش, _پھى۪, puut_, 
   {{0x19500092,0x00000000,0x00000000,0x00000000}},	//   _መስመሮ, --, --, --, 
   {{0x46a40118,0x00000000,0x00000000,0x00000000}},	//   गठनह, --, --, --, 
   {{0x7bc00083,0x69a4012d,0x00000000,0x00000000}},	//   òmus, _क़री, --, --, 
   {{0xdb0410e8,0x7a3403be,0x1ae40868,0x624c03b2}},	//   haké, _mütə, _боим, rúoy, 
   {{0x7c26114f,0xdb0410e8,0xdb08d398,0x268801e2}},	// [3c7e0] _ilir, kaké, änäl, نخلي_, 
   {{0xdb0483a8,0x69a400cd,0x00000000,0x00000000}},	//   jaké, करणी, --, --, 
   {{0x5185fc9b,0x280800d0,0xd4149684,0x37b00154}},	//   қула, ätnú_, льды, ঙ্গর, 
   {{0xdb040066,0xd2a80209,0x00000000,0x00000000}},	//   takè, екде_, --, --, 
   {{0x7c25c6ba,0x38621150,0x638400fb,0x2798009d}},	//   _mlir, mlir_, рҡум_, _штээ_, 
   {{0x38621151,0x799c030d,0x7c24004e,0x00000000}},	//   llir_, nbrw, _llir, --, 
   {{0x601431ac,0x7c261152,0x2558084c,0xfd04e0f9}},	//   _náms, _olir, _артэ_, _اج_, 
   {{0x3dbc0156,0xc3210a6d,0x321c02fb,0x6d5c04cc}},	//   _མཐུན, рмәк, skvy_, üram, 
   {{0x0dc87075,0xa3d01025,0x386003b2,0xe8e011a0}},	//   нуни_, वभर_, ilir_, _पन्च, 
   {{0xd7100183,0x06cc0154,0x00000000,0x00000000}},	//   _সেৱা_, রিচি, --, --, 
   {{0x38621153,0x7c2401ab,0x7e7001ef,0x84740023}},	//   klir_, _blir, _řepí, ክህሉን_, 
   {{0x601403c6,0x7c261154,0xac841eec,0x00000000}},	//   _dáms, _clir, лгүл, --, 
   {{0x2ec429db,0x7c24036e,0x38600042,0x0050009f}},	//   _төйм, _dlir, dlir_, _اَنج, 
   {{0x7c261155,0xad840075,0xe89400c7,0x00000000}},	//   _elir, _ئاشۇ, иагь, --, 
   {{0x7dc03b5f,0xdce801e0,0x38621156,0x00000000}},	//   _اقىن, _ауыҙ_, flir_, --, 
   {{0x38621157,0x7c2475d3,0x60141de4,0xdb0400e5}},	//   glir_, _glir, _hámr, zaké, 
   {{0xfbd0143e,0x6b9c03b2,0x00000000,0x00000000}},	// [3c7f0] _رتي_, mbsg, --, --, 
   {{0x386003b2,0x19c00166,0x2904007c,0x00000000}},	//   alir_, _мәсг, älas_, --, 
   {{0x38621158,0x67d61159,0xd5a401b9,0x7c240108}},	//   blir_, _кону, شلنی, _ylir, 
   {{0x3e6803a1,0x08400014,0x6abc05b1,0x69d428dc}},	//   møte_, _اۆرُ, orsf, lfze, 
   {{0xcfa8015b,0x9f4c0af9,0x3e68143a,0x69d40036}},	//   ওলান, rdeë_, løte_, ofze, 
   {{0xd05811a9,0x970004a9,0x0576115a,0xa0c4004b}},	//   _istə, _بېكى, _مازد, ليتو, 
   {{0x392402d3,0x2bf405f9,0x6abc0112,0x3494013d}},	//   ደፋውያ, इयां_, hrsf, _гаср, 
   {{0xd1f401f3,0xb97c010f,0xdb0400e5,0x00000000}},	//   _ገንቢ_, ענהי, saké, --, 
   {{0x94240058,0x644808e7,0x672e115b,0xdb0400d5}},	//   _ئوقۇ, _ijei, nzaj, paké, 
   {{0x7c2404fb,0x672c009f,0xb2751cbc,0x6b9c0112}},	//   _slir, izaj, _глуш, ebsg, 
   {{0x7c26115c,0x1c44220f,0x5f7400aa,0x6abc2694}},	//   _plir, ином, داګر, ersf, 
   {{0x6abc03cd,0x7c24036e,0x2cb80f47,0x00000000}},	//   frsf, _qlir, árda_, --, 
   {{0x20d00016,0xde0400d6,0x50180302,0x53980375}},	//   _hơi_, _впли, _שונו, כירו, 
   {{0x672e115d,0x7c380882,0x20f402b1,0x7c240066}},	//   dzaj, _śarī, _kāi_, _wlir, 
   {{0x98a6115e,0x6abc002d,0x26082366,0x64480588}},	//   рибе, arsf, सानी_, _ojei, 
   {{0x7c26115f,0xd1e40092,0x20d00208,0x38600142}},	//   _ulir, ሚንቶ_, _mơi_, ulir_, 
  
   {{0xdb040227,0x1ae4036b,0x95c801b9,0x20d0004d}},	// [3c800] makï, _топм, клаб_, _lơi_, 
   {{0x64491d9e,0x00000000,0x00000000,0x00000000}},	//   _ajei, --, --, --, 
   {{0x20d007ae,0x38621160,0xb17c0115,0xcdb4011a}},	//   _nơi_, plir_, _jaĥt, שפעה_, 
   {{0x59d004e4,0x18680a5b,0x00000000,0x00000000}},	//   द्रर, _јами_, --, --, 
   {{0xf1961161,0x672c068f,0xe2801955,0xa49001d3}},	//   биль, czaj, зғун, _ہیلت, 
   {{0x20d0001e,0x644800e4,0xf48453b6,0xd13000e3}},	//   _bơi_, _ejei, _هاری, يمش_, 
   {{0xc0e59be3,0xa49004fb,0x20d00208,0x2e2001e1}},	//   لفون_, _فیلت, _cơi_, _sòfo_, 
   {{0x7f8156c1,0xf4780220,0x20d0004d,0x64482a5b}},	//   يلىن, _сөзі_, _dơi_, _gjei, 
   {{0x2904a63c,0x00000000,0x00000000,0x00000000}},	//   ̣la_, --, --, --, 
   {{0x20f40421,0xd24e10ec,0x260803f8,0x00000000}},	//   _fāi_, _تۆت_, सायी_, --, 
   {{0xac1a1162,0x672c025c,0x00000000,0x00000000}},	//   гону_, zzaj, --, --, 
   {{0xa3a82871,0x6cd400f7,0x00000000,0x00000000}},	//   _खड़ा_, _ۇقتا, --, --, 
   {{0x6e95a291,0x8eb00131,0xc87c002f,0x765c012d}},	//   _التا, _بەخت, _riß_, _okry, 
   {{0xdd9001ed,0x69d40112,0xadb808f0,0x672c00d7}},	//   _ٹوٹ_, ufze, _صهبا_, vzaj, 
   {{0x20d0004d,0x69d4324c,0x672c012d,0x69cc090a}},	//   _xơi_, rfze, wzaj, द्गी, 
   {{0x7c9024e0,0xb138001f,0x7d7808a8,0x7aec005b}},	//   _بشوا, _እንድታ, _ברוג, ältä, 
   {{0x672c009f,0x69d40112,0x06b401d3,0x68600092}},	// [3c810] uzaj, pfze, شناک_, _ለእርስ, 
   {{0x27b40184,0x60161163,0x644806ea,0x672e1164}},	//   шәүс, _lámp, _sjei, rzaj, 
   {{0xba741178,0x672c0034,0xe3640131,0xe9181cd0}},	//   _بايت, szaj, әкли, _соні_, 
   {{0x20d00016,0x00000000,0x00000000,0x00000000}},	//   _rơi_, --, --, --, 
   {{0xadf81b87,0xc2906112,0xc7640131,0x7dd4063f}},	//   ्ञान_, زیاب, _خادى, ụsik, 
   {{0x20f402b5,0x2ff801ed,0x62980083,0x2368010f}},	//   _pāi_, یڈنگ_, rpwo, ĥaj_, 
   {{0x26082d6c,0x64480fac,0xd24c007b,0x00000000}},	//   साठी_, _tjei, عنى_, --, 
   {{0x13a80a98,0x601409c2,0x6614009d,0x20d001fb}},	//   _منفی_, _cámp, _hozk, _vơi_, 
   {{0x200c2dba,0x645a1165,0x661401c4,0x6e38002f}},	//   rjei_, mowi, _kozk, _bmvb, 
   {{0x645a1166,0x63aa1167,0x20d0004d,0x66140f91}},	//   lowi, _heen, _tơi_, _jozk, 
   {{0x63aa1168,0x62821169,0x200808e7,0xbb58037e}},	//   _keen, _iilo, _òaio_, _oneモ_, 
   {{0x6282116a,0x6458006d,0x63aa116b,0xddc00139}},	//   _hilo, nowi, _jeen, bolş, 
   {{0x63aa116c,0xdb040bc9,0xd00c00aa,0x05c40490}},	//   _meen, rakï, _سلو_, _लांब, 
   {{0x63aa116d,0x64585675,0x6282116e,0x3f9c058a}},	//   _leen, howi, _jilo, lbuu_, 
   {{0x645a116f,0x63a8003a,0xb138001f,0x2da80131}},	//   kowi, _oeen, _እንደታ, _ﺋﯘﻧﻰ_, 
   {{0x63aa1170,0x62821171,0x64585675,0x765e1172}},	//   _neen, _lilo, jowi, _skry, 
   {{0x66161173,0x6458068f,0x3ebc03a2,0x44f4031c}},	// [3c820] _bozk, dowi, nrut_, _aħ_, 
   {{0x62821174,0x59e40050,0x3ebc0472,0x3a3c0112}},	//   _nilo, _آدم, irut_, _övp_, 
   {{0x3ebc03a2,0x6614005a,0x2678084c,0x64587def}},	//   hrut_, _dozk, рстэ_, fowi, 
   {{0x62821175,0x3ebe1176,0x63aa1177,0x6d5c05d5}},	//   _ailo, krut_, _ceen, ürai, 
   {{0x6280271e,0x63a8092e,0x6d5c6b07,0x63ac0ad9}},	//   _bilo, _deen, ýraz, ðana, 
   {{0x765e1178,0x3f9c208d,0x628801bf,0x9f5c0241}},	//   _ukry, ebuu_, _dueo, _lowó_, 
   {{0x6288019f,0x63aa1179,0x44f4025c,0x64581afd}},	//   _eueo, _feen, _għ_, bowi, 
   {{0x0c800020,0x62800a8b,0x3ebc025c,0xf2e8cf73}},	//   _ከተሞች_, _eilo, frut_, _نکته_, 
   {{0xb138001f,0x3ebc002d,0x4364010b,0xdb0400e4}},	//   _እንዲታ, grut_, _гатн_, hakâ, 
   {{0x63aa117a,0x3f9c198f,0x422000d8,0x00000000}},	//   _zeen, abuu_, _едув, --, 
   {{0x63aa117b,0x3ebc20ac,0x3f9c0a55,0x8658008d}},	//   _yeen, arut_, bbuu_, רדיי, 
   {{0x80d8009e,0x3ebc7dec,0xa03400f1,0x00000000}},	//   ভিশ্, brut_, _وړيا_, --, 
   {{0x6282117c,0x3ebdfbfa,0xfbd001c8,0x00000000}},	//   _yilo, crut_, رتَ_, --, 
   {{0x6282117d,0x6aa8f712,0x645884c9,0x1830001f}},	//   _xilo, _कबीर, zowi, _አብዛኞ, 
   {{0x20180395,0x6614489c,0x9f5c0ca8,0x645801f7}},	//   _ègià_, _rozk, _fowó_, yowi, 
   {{0x3e6805ac,0x37a85735,0x250800f2,0x00000000}},	//   møta_, йтун_, یرای_, --, 
   {{0x9e2401d9,0x98a8005f,0xa61406ed,0x44f40327}},	// [3c830] _دى۪و, ākās_, омач, _sħ_, 
   {{0x09b01d4c,0x63aa117e,0x645a117f,0x058400c7}},	//   ঞ্জা, _seen, wowi, суам, 
   {{0xdb14007f,0x628a1180,0x645a1181,0x6281537f}},	//   _adyè, _sueo, towi, _rilo, 
   {{0x63a8198f,0xdb0401d3,0x3ebc6164,0x3f9c058a}},	//   _qeen, zakí, yrut_, xbuu_, 
   {{0x645a1182,0x63aa1183,0x248c0b9b,0x260800ab}},	//   rowi, _veen, _čemu_, सादी_, 
   {{0x63aa1184,0x628001b9,0xf6280212,0x645a1185}},	//   _ween, _qilo, _ліси_, sowi, 
   {{0x645814cf,0x62821186,0x63aa1187,0xc3d802dd}},	//   powi, _vilo, _teen, _бөлi, 
   {{0x6288003a,0x62821188,0x3ebe1189,0x63a80857}},	//   _tueo, _wilo, trut_, _ueen, 
   {{0x3f9dfb42,0xb2640014,0x00000000,0x00000000}},	//   rbuu_, _کُلى, --, --, 
   {{0xb8dc003d,0x628160a3,0x230405d9,0x3ebd7c60}},	//   _ངྷ_, _uilo, _هڪڙي_, rrut_, 
   {{0x5f96118a,0x3ebc1509,0x3e68022c,0x9f5c01e1}},	//   _диет, srut_, gøta_, _powó_, 
   {{0x24840438,0x3f9c0009,0x6b880010,0xee38009d}},	//   _élmu_, qbuu_, žegn, инө_, 
   {{0x62780030,0xe80c5d4f,0x67280327,0x99f400d4}},	//   _dňov, हाना_, _żejn, ояві, 
   {{0x20dc227c,0xdca5fcae,0x00000000,0x00000000}},	//   _महाध, _даки, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x57e80261,0x00000000,0x00000000,0x00000000}},	//   јдам_, --, --, --, 
   {{0xdb040124,0x00000000,0x00000000,0x00000000}},	// [3c840] sakâ, --, --, --, 
   {{0x959a118b,0x63ac066a,0xcff000eb,0x00000000}},	//   ртау_, ðann, ঝায়_, --, 
   {{0x186802e8,0xd30074c8,0x89d8123b,0x00000000}},	//   _вани_, लम्ब_, _דחיי, --, 
   {{0x04400b3b,0x03a00063,0x627801ef,0x00000000}},	//   мехн, дицо, _mňou, --, 
   {{0x7cf4063f,0xf1940cc9,0x00000000,0x00000000}},	//   _ịru, пиль, --, --, 
   {{0x236c00f3,0x00000000,0x00000000,0x00000000}},	//   _dzej_, --, --, --, 
   {{0x9028035b,0x4fc40229,0x00000000,0x00000000}},	//   ициа_, оспа, --, --, 
   {{0xc0541b45,0xc0c80023,0x00000000,0x00000000}},	//   يشيا_, በረላ_, --, --, 
   {{0x11d43334,0xb8fc0327,0x43407696,0x00000000}},	//   _міжр, _རད_, _жетв, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7cf402e3,0xc2780375,0xdb040124,0x05cc0f4a}},	//   _ọru, _כרמי, yakã, स्टब, 
   {{0xbb94023a,0x4ea40120,0x528802dd,0x00000000}},	//   мающ, _дрка, _ﻗﻮﯕﯩ, --, 
   {{0x447800c8,0xdde80424,0xfb840022,0x37b000fe}},	//   ינטע, _گرنه_, дырн, টলাৰ, 
   {{0xc0c8044e,0x7f7000f1,0xe81c00c5,0x00000000}},	//   በረሉ_, _غږيږ, _नवहा_, --, 
   {{0xdde8004b,0x95900023,0x00000000,0x00000000}},	//   _درنه_, ውንትን_, --, --, 
   {{0x6d5c05d5,0x7a300267,0x00000000,0x00000000}},	//   ürau, _nätf, --, --, 
   {{0xc9840b14,0x36d54c24,0xabb4035b,0x27e80010}},	// [3c850] _муни, мотр, _дақә, _činč_, 
   {{0x49e000db,0xdb04035b,0x00000000,0x00000000}},	//   _تۋسق, sakã, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x58f8008f,0x88011f2d,0xdb0401d3,0x00000000}},	//   _פּינ, _تېرو, laká, --, 
   {{0xfbb000fe,0xd6640014,0x00000000,0x00000000}},	//   _কামত, _کۅلو_, --, --, 
   {{0x27ea118c,0x26c8166a,0x17180a1e,0x00000000}},	//   lean_, muao_, _הושע, --, 
   {{0xdb040109,0x00000000,0x00000000,0x00000000}},	//   zakà, --, --, --, 
   {{0x27ea118d,0x600900ed,0x52101206,0xd71003d4}},	//   nean_, сним_, ддәт, _সেয়া_, 
   {{0x26c99fb7,0x27e87ea4,0xdb040f52,0x4f04008e}},	//   nuao_, iean_, kaká, знын_, 
   {{0x27e80876,0xdb0446dc,0x00000000,0x00000000}},	//   hean_, jaká, --, --, 
   {{0x27ea118e,0x00000000,0x00000000,0x00000000}},	//   kean_, --, --, --, 
   {{0x26c802b5,0x442c003e,0x7a300166,0x00000000}},	//   kuao_, nhg_, _xätf, --, 
   {{0x27ea118f,0x26c801f7,0x4b2000a7,0x442c003e}},	//   dean_, juao_, емяв, ihg_, 
   {{0x4ef80375,0xdb0400e4,0x00000000,0x00000000}},	//   _להנו, rakà, --, --, 
   {{0xdb0405da,0x27ea1190,0x6d5e1191,0x00000000}},	//   sakà, fean_, ürat, --, 
   {{0x27ea1192,0xdb0400e4,0x5ba80798,0x2bac07b7}},	//   gean_, aaká, _уким_, चरणा, 
   {{0x3878001f,0xe81c0490,0x442c007b,0x7a30007c}},	// [3c860] _በእርሱ_, _नवरा_, dhg_, _nätg, 
   {{0x7ae61193,0x3b000113,0xdb0400d2,0x27e801ab}},	//   _ipit, _iriq_, caká, aean_, 
   {{0x27ea1194,0xec3400f2,0x00000000,0x00000000}},	//   bean_, _رویگ, --, --, 
   {{0x54680b30,0x0574007b,0xded80150,0x4cb8010f}},	//   щаем_, سمنة_, _ﺃﺴﺎﺒ, ממעג, 
   {{0x683000b5,0xe794036b,0xd1b8710e,0x83803b8f}},	//   _bådf, _تاپک, ماغا_, ныше, 
   {{0x7ae41311,0xfe6447e7,0x33940023,0x6dc400d7}},	//   _mpit, _سد_, _ዝጠመተ_, _kňaž, 
   {{0x53a42c1d,0x26080b7d,0x442c002f,0xd174010b}},	//   _навб, सारी_, bhg_, чыды, 
   {{0x6e9800a7,0x3b00022e,0x442c0112,0xdb0401d3}},	//   овир_, _oriq_, chg_, zaká, 
   {{0x52757233,0x00000000,0x00000000,0x00000000}},	//   _فائز, --, --, --, 
   {{0x27e805f5,0x4718008f,0x07340375,0x1b1000fe}},	//   zean_, צויג, פאים_, হনাই_, 
   {{0x7ae61195,0x3b021196,0xdb0400d2,0xfe6d8f31}},	//   _apit, _ariq_, vaká, ددي_, 
   {{0x27e805f5,0x7ae40332,0x2174009d,0x00000000}},	//   xean_, _bpit, _цуур, --, 
   {{0x27ea1197,0x69c00789,0x387c0129,0xdb0402f0}},	//   vean_, óleo, _évry_, taká, 
   {{0x27e97fa7,0xcf2c046c,0x7a310903,0xead00248}},	//   wean_, ığım_, _nätd, _bẹru_, 
   {{0x7ae61198,0x27ea1199,0xdb06119a,0xd79802e3}},	//   _epit, tean_, raká, _ọpụr, 
   {{0xdb06119b,0x7990013f,0x26c9dbdf,0x27e814c5}},	//   saká, _ɔkwɑ, tuao_, uean_, 
   {{0x27ea119c,0xb0640166,0x2608121d,0x6b740166}},	// [3c870] rean_, _itäğ, साली_, _юлиу, 
   {{0x27e9d506,0x8b6400aa,0x26c800b0,0x4669b868}},	//   sean_, _واکم, ruao_, ёрам_, 
   {{0xe858020a,0x68304836,0x00000000,0x00000000}},	//   _маош_, _rådf, --, --, 
   {{0x2900003e,0x26c80421,0x7d780a7c,0x00000000}},	//   _irha_, puao_, זנבו, --, 
   {{0xddc00100,0x22580108,0xa1880024,0x62346206}},	//   bilň, оиды_, обла_, меду, 
   {{0x442c036b,0x7a30007c,0x00000000,0x00000000}},	//   shg_, _vätg, --, --, 
   {{0xf1b000c6,0x20f801ad,0x683001bf,0x442c0076}},	//   اءه_, ्मेश_, _vådf, phg_, 
   {{0x29000010,0x442c0175,0x20180162,0x00000000}},	//   _mrha_, qhg_, ðsi_, --, 
   {{0x443e119d,0xa2d4021a,0x44ec015b,0x7a300036}},	//   _imu_, _زيات, _টপিক_, _häte, 
   {{0x7a3016b5,0x443e119e,0xf5040014,0xdb0405d2}},	//   _käte, _hmu_, _تِہُ, lakç, 
   {{0xa2c861b8,0x1be8ee8b,0x443e119f,0x7a3002f6}},	//   हूर्, одни_, _kmu_, _jäte, 
   {{0x7a3211a0,0x7ae40083,0x443c0076,0xe9f80248}},	//   _mäte, _ppit, _jmu_, _iwẹ_, 
   {{0x443c4d11,0x290002a8,0x68300267,0x7a30007c}},	//   _mmu_, _arha_, _mådd, _läte, 
   {{0xceb0010f,0x7ae40010,0xdde8d712,0x00000000}},	//   _ייד_, _vpit, _گرچه_, --, 
   {{0x443e11a1,0x7a3004f3,0x41dc00dc,0x61e00200}},	//   _omu_, _näte, प्यस, _mbll, 
   {{0x443e11a2,0x6832002c,0x3b00003d,0x7ae4031c}},	//   _nmu_, _nådd, _triq_, _tpit, 
   {{0x7ae41505,0xdb040139,0x00000000,0x00000000}},	// [3c880] _upit, dakç, --, --, 
   {{0x443e11a3,0x7a300139,0x58940137,0x99880153}},	//   _amu_, _bäte, _ошму, ribų_, 
   {{0x938a11a4,0x443c002f,0x00000000,0x00000000}},	//   осла_, _bmu_, --, --, 
   {{0x683011c0,0xddc001f1,0x18687d9f,0xdb040162}},	//   _rådg, silň, _фами_, rakæ, 
   {{0x443c0140,0x662843e5,0x00000000,0x00000000}},	//   _dmu_, áskó, --, --, 
   {{0x443e11a5,0x386211a6,0xf6640137,0xdb0426bb}},	//   _emu_, loir_, _чегү, makä, 
   {{0xc0e0a8c9,0xdb04cc24,0x443c01e7,0x00000000}},	//   војк, lakä, _fmu_, --, 
   {{0x4fc5e602,0x2ef4a401,0xdc38013d,0x443c4e3c}},	//   фска, езир, _oçın, _gmu_, 
   {{0xdb040bc9,0x7a303648,0xdc380139,0x04409d9f}},	//   nakä, _mätb, _nçın, _ретн, 
   {{0x386000a3,0x443c01d5,0x2d9848bf,0xb0040055}},	//   hoir_, _zmu_, ùre_, daḥp, 
   {{0x7a300724,0xdc382737,0xdb04340f,0xc5f0011a}},	//   _xäte, _açın, hakä, דדת_, 
   {{0x260403ce,0x7a300267,0x443c0165,0x7f8001b9}},	//   _होनी_, _nätb, _xmu_, علین, 
   {{0xe80c1524,0xdb040e03,0x3b640395,0x00000000}},	//   हासा_, jakä, върв, --, 
   {{0x683004ce,0x1ea80ccb,0x29000427,0xdb04496e}},	//   _måde, _راهي_, _prha_, dakä, 
   {{0x7994cf08,0x386000a3,0xcce408f0,0xdb040205}},	//   тисф, foir_, _آستي, yakç, 
   {{0xc6a40cfc,0xe69800a7,0x7a30008e,0x7a1803e0}},	//   држи, зваш_, _räte, _aştı, 
   {{0x6b8e11a7,0x443e11a8,0x7a3211a9,0xdb05fecc}},	// [3c890] _igag, _rmu_, _säte, gakä, 
   {{0xf77211aa,0x443ca324,0x7a3211ab,0x6aad1a99}},	//   شاق_, _smu_, _päte, _iwaf, 
   {{0x6aadc4f5,0x6b8c0770,0xb5ac002e,0x443c2a18}},	//   _hwaf, _kgag, _j斡yy, _pmu_, 
   {{0x6aac3926,0x6830037e,0x443c020b,0x7a303468}},	//   _kwaf, _både, _qmu_, _väte, 
   {{0x6b8c1e92,0xdb0611ac,0x683000b5,0x7a3002b1}},	//   _mgag, rakç, _vådd, _wäte, 
   {{0x7a3211ad,0x6aae11ae,0x443c0083,0x27f8011a}},	//   _täte, _mwaf, _wmu_, _hasn_, 
   {{0x22481505,0x6b8e11af,0x69440fcf,0x6aac8263}},	//   đak_, _ogag, _učeć, _lwaf, 
   {{0x443e11b0,0x6b8e11b1,0x6aac0944,0x68300158}},	//   _umu_, _ngag, _owaf, _fåde, 
   {{0xa3e406ab,0x6aac0198,0xdc68016c,0x1e840e46}},	//   _बॉय_, _nwaf, ҷанд_, нлим, 
   {{0x6b8e11b2,0xb274ca0f,0x26040d2c,0x7a3001c7}},	//   _agag, _алуш, _होमी_, _mätc, 
   {{0x1d08329b,0xdc68013e,0xdfd0216b,0xefc801c6}},	//   чени_, занд_, _ميا_, члөл_, 
   {{0x6aac2252,0xde940063,0x6830007c,0x92e003d4}},	//   _bwaf, _задњ, _lådb, ধিৰ_, 
   {{0x38603d24,0xdee419ba,0x7a3033fe,0xddc433e2}},	//   voir_, _чоли, _nätc, _збли, 
   {{0x6b8c0086,0x6e280309,0xdb040821,0x25b001ef}},	//   _egag, ckdb, vakä, _nezl_, 
   {{0x6aae11b3,0x386211b4,0x201c0098,0x27f80042}},	//   _ewaf, toir_, _kowi_, _basn_, 
   {{0x6b8c04ba,0x41dc00dc,0xb778004e,0xdb040847}},	//   _ggag, प्तस, дөгу_, takä, 
   {{0x9b45df0c,0x386007ea,0x6aac0a49,0x1b4401d9}},	// [3c8a0] _سندو, roir_, _gwaf, _سپدُ, 
   {{0x6b8e11b5,0x3860004a,0xa3e402ab,0x7d000010}},	//   _zgag, soir_, _बॉब_, _krns, 
   {{0x386211b6,0xd94611b7,0xdb0611b8,0xe1c88bb7}},	//   poir_, _чени, sakä, _राजघ, 
   {{0x8898011a,0x201c012d,0x96b800db,0xdb0c02d2}},	//   _מבטי, _nowi_, _нугу_, _íkóp, 
   {{0xe80c00ce,0x87b4011a,0x48000006,0x96c0010a}},	//   हारा_, _אלכס_, _спяв, _сăлу_, 
   {{0xb17c0115,0xd0a8004e,0x7d00035a,0x6830072b}},	//   _abĥa, птид_, _orns, _våde, 
   {{0x6abc0034,0xd7741411,0x00000000,0x00000000}},	//   _ऍट्र, _زاڭع, --, --, 
   {{0x201ce0de,0x626401d5,0x98a8012d,0x160c01f9}},	//   _cowi_, _یالق, czbą_, सावर_, 
   {{0xef1000f7,0x13042235,0x00000000,0x00000000}},	//   рүлө, _язам, --, --, 
   {{0x6aac62f9,0x6b8ce775,0xfbb003d4,0x00000000}},	//   _rwaf, _sgag, _কাষত, --, 
   {{0x6aae11b9,0xc04e11ba,0x320c045a,0x3cb00209}},	//   _swaf, _бі_, _indy_, лйэр, 
   {{0x201c010e,0x00000000,0x00000000,0x00000000}},	//   _gowi_, --, --, --, 
   {{0x3ea005f5,0xbea110b0,0x63ac2833,0x320c0109}},	//   _бичг, _бачк, ðani, _kndy_, 
   {{0x0eb801e0,0x6fa80154,0xaa5801f4,0x00000000}},	//   _дуҫы_, _গায়ে, фигу_, --, 
   {{0x6b8c074d,0xe80c0574,0x00000000,0x00000000}},	//   _tgag, हाला_, --, --, 
   {{0x0b88c0bb,0x6aac8a0b,0x6b8c058a,0x6d5a11bb}},	//   _эски_, _twaf, _ugag, _ixva, 
   {{0xfbd00202,0x6aae11bc,0x37e003d4,0x00000000}},	// [3c8b0] _اتى_, _uwaf, _পোহৰ, --, 
   {{0x27f80375,0xe81c00c5,0x00000000,0x00000000}},	//   _wasn_, _नवका_, --, --, 
   {{0xbc698fbc,0x599400d9,0x25b0013a,0x00000000}},	//   _زمین_, _בכתב_, _vezl_, --, 
   {{0x320c2517,0x33d401ec,0x00000000,0x00000000}},	//   _andy_, гішт, --, --, 
   {{0xc9840acb,0xc764113e,0x56f03004,0x972001d3}},	//   _تشکي, _ساحى, _күтс, _پہلو, 
   {{0x216a11bd,0x6144d394,0x7a3002b5,0x26c803f9}},	//   мили_, кела, _käta, mrao_, 
   {{0x7a3000af,0xdfd04c1c,0x00000000,0x00000000}},	//   _jäta, ليغ_, --, --, 
   {{0x260611be,0x7a3211bf,0x3e68022c,0x260802ab}},	//   _होती_, _mäta, møti_, साकी_, 
   {{0xa29402bf,0x6d5802d0,0x26c80208,0xfbb000fe}},	//   _разі, _axva, nrao_, _কালত, 
   {{0x26c805a1,0x9f4c0036,0x71b400d8,0x0ec0134e}},	//   irao_, leeë_, _ббфф, _शिरड, 
   {{0x7a3211c0,0x06cc0183,0x7c20007c,0x00000000}},	//   _näta, ৰিটি, ömro, --, 
   {{0x26c8110c,0xd9a828fe,0xae8800cf,0x00000000}},	//   krao_, कर्ट, мбөз_, --, 
   {{0x3f8c013c,0x6d580789,0x00000000,0x00000000}},	//   _iggu_, _exva, --, --, 
   {{0x5e440014,0x26ca11c1,0x7d009830,0x9f4c007c}},	//   _جنتٕ, drao_, _trns, gdeå_, 
   {{0x1868299f,0x7d000857,0x30a40354,0x00000000}},	//   дави_, _urns, _ырăв, --, 
   {{0x9f4c04e6,0xc2e400cc,0x00000000,0x00000000}},	//   jeeë_, _গছনি_, --, --, 
   {{0x3f8c0a2e,0x26c80989,0xdb0400c7,0xfa5400f2}},	// [3c8c0] _mggu_, grao_, hakú, _مردگ, 
   {{0x8ab40375,0x00000000,0x00000000,0x00000000}},	//   _שהיו_, --, --, --, 
   {{0x26c801e4,0xab0801b9,0x97c611c2,0x9b440101}},	//   arao_, _قتیق_, _ийне, _سنگو, 
   {{0xdce003e3,0x00000000,0x00000000,0x00000000}},	//   nclı, --, --, --, 
   {{0xb2080022,0x00000000,0x00000000,0x00000000}},	//   нҵаз_, --, --, --, 
   {{0x3f8c013c,0xddc00270,0x41b00131,0x799c0142}},	//   _aggu_, filō, қсәт, ncrw, 
   {{0x2bc40a59,0xca34011a,0x00000000,0x00000000}},	//   वणमा, כנסה_, --, --, 
   {{0xc9500375,0x799c02d0,0x00000000,0x00000000}},	//   ימו_, hcrw, --, --, 
   {{0x0dc8013e,0xdb0401d3,0x528400cf,0x11e8007b}},	//   муни_, bbké, _агаб, _يعطي_, 
   {{0xd3d00354,0x63ac1427,0x00000000,0x00000000}},	//   _гiур, ðanv, --, --, 
   {{0x683001e6,0x8c340107,0x7e7001c6,0x6e0400db}},	//   _låda, вонӣ_, ргэх, _ەسبە, 
   {{0x8fa43dc8,0x7a3176f2,0x4fa40139,0xac180815}},	//   _раде, _räta, _ридв, хому_, 
   {{0x6830007c,0x00000000,0x00000000,0x00000000}},	//   _nåda, --, --, --, 
   {{0x7a3002b1,0xb9c401a9,0x3d900117,0x00000000}},	//   _päta, иёси, _кишр, --, 
   {{0x290611c3,0x06cc03d4,0xedd400f1,0x00000000}},	//   íla_, ৰিছি, _ليږد, --, 
   {{0x26c80851,0x2c740014,0x683001e3,0xe864009d}},	//   trao_, _حُبس, _båda, ухгү, 
   {{0xa77611c4,0x290400df,0x7b140108,0x00000000}},	// [3c8d0] улач, ŭla_, _вдых, --, 
   {{0x26c800d8,0x7a3211c5,0x6b9c0175,0x2368031c}},	//   rrao_, _täta, lcsg, żajk_, 
   {{0x46c800d1,0xf8ac01f9,0x00000000,0x00000000}},	//   _ﺗﻪﮬﺮ, टीआय, --, --, 
   {{0xd36c16cb,0x7a3000c5,0x2c7800e8,0x00000000}},	//   ڻهو_, _jätn, béde_, --, 
   {{0x7a3001e6,0x69c0033f,0x6abc01f5,0xd24c01e2}},	//   _mätn, ólew, nssf, ګنو_, 
   {{0x69d611c6,0x1fbc141f,0x00000000,0x00000000}},	//   ngze, ोल्ड, --, --, 
   {{0xa06a11c7,0x50a00131,0xddc000e2,0x00000000}},	//   нака_, مەلل, solū, --, 
   {{0xd00d19b2,0x8bbc74f6,0xdb0400e4,0x00000000}},	//   كلى_, ्लोअ, rakú, --, 
   {{0x63ba11c8,0x4fe4da9f,0x9f8400ee,0xd24d0abe}},	//   mawn, умын_, ыгид, _کچن_, 
   {{0x248e11c9,0x999800b0,0x63ba11ca,0x5fd401f9}},	//   _hiem_, _popō_, lawn, _धावल, 
   {{0x248e11cb,0x3f8c31e5,0x0d800139,0x9d44013d}},	//   _kiem_, _tggu_, йльн, уенд, 
   {{0x229811c1,0x41dc08dd,0x248c0003,0x3f8c0009}},	//   _kèk_, प्रस, _jiem_, _uggu_, 
   {{0x270c0574,0x98540aac,0xa3e40b98,0x35780023}},	//   समोर_, ҳташ, ब्य_, ኽቦታት_, 
   {{0xa3e434ef,0x6830a0c4,0x63ba11cc,0x2298007f}},	//   _बॉस_, _råda, hawn, _mèk_, 
   {{0x683211cd,0x22980066,0x63ba11ce,0x28b80276}},	//   _såda, _lèk_, kawn, кутэ_, 
   {{0x248e11cf,0x1868014b,0x464401a9,0x63b80210}},	//   _niem_, хаби_, ҳзун_, jawn, 
   {{0x63b9b024,0x22980214,0x7bc40fac,0x2604000d}},	// [3c8e0] dawn, _nèk_, _idiu, _होही_, 
   {{0x6830007c,0x00000000,0x00000000,0x00000000}},	//   _våda, --, --, --, 
   {{0x248e11d0,0x53c829e1,0x260801ad,0x67280003}},	//   _biem_, егем_, साजी_, _żejt, 
   {{0x229802e2,0x981400c6,0x24b85285,0x63b80327}},	//   _bèk_, _إبدا, ئننگ_, gawn, 
   {{0x248e11d1,0x229800f2,0x93440276,0xb24400c7}},	//   _diem_, _cèk_, ынде, аҭад, 
   {{0x2298020c,0x7a3211d2,0xd9c400eb,0x00000000}},	//   _dèk_, _mäto, শ্রম, --, 
   {{0x90e425f4,0x7bc611d3,0x63b8033f,0x00000000}},	//   استن, _odiu, bawn, --, 
   {{0x248c0048,0xc0e611d4,0x7bc4a238,0x229802bd}},	//   _giem_, افين_, _ndiu, _fèk_, 
   {{0x22980066,0xd334084c,0x26080073,0x2d5800a8}},	//   _gèk_, _сэвы, साची_, ӂинь_, 
   {{0x7bc611d5,0x6fa45345,0x316c0210,0x248c0210}},	//   _adiu, _ग्रं, _tydz_, _ziem_, 
   {{0x51540276,0x10a54f72,0x7a3000d0,0x2d5800a8}},	//   _стау, _сиен, _pätn, тинь_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x683001bf,0xaa9401c6,0x6abc0036,0x15f40dba}},	//   _bådn, ригч, ussf, ीयार_, 
   {{0x6934a7a1,0x7bc4127b,0xbb6400b5,0xcd3400ae}},	//   ангу, _ediu, _barケ_, _مرعب, 
   {{0x3e6806ea,0x7a300267,0x68400118,0x69d4002f}},	//   gøtu_, _tätn, _lídř, rgze, 
   {{0x7a30af45,0x7bc003b2,0x00000000,0x00000000}},	//   _fäto, ómut, --, --, 
   {{0x248c0373,0xfc300150,0x24840100,0x7a300641}},	// [3c8f0] _riem_, _ءحى_, _èlmi_, _kätl, 
   {{0x248c06a3,0x229802e2,0xbb3c010f,0x35b4205a}},	//   _siem_, _rèk_, _רעזי, йбур, 
   {{0x69c611d6,0x236c007f,0x248c00e2,0x2298033b}},	//   _idhe, _syej_, _piem_, _sèk_, 
   {{0x7a3000c5,0x236c0100,0x3569ed84,0x26041414}},	//   _lätl, _pyej_, урун_, _होरी_, 
   {{0x63ba11d7,0x248c01f1,0x6f0400e4,0x659400f3}},	//   rawn, _viem_, _áich, _вагу, 
   {{0x248e11d8,0xe1242310,0x236c0100,0x3e6803cd}},	//   _wiem_, имли, _vyej_, nøtt_, 
   {{0x248c00da,0x63b80649,0xa0a406b3,0x69c40200}},	//   _tiem_, pawn, шайд, _mdhe, 
   {{0x63ae11d9,0x6009fa86,0x6024ae0b,0x22980100}},	//   ñand, тним_, рдиа, _tèk_, 
   {{0x68300267,0x7a300166,0x3358f355,0x00000000}},	//   _lådo, _bätl, _батэ_, --, 
   {{0x69c404fb,0x7a317f9d,0x7bc401ab,0x1d94023b}},	//   _ndhe, _räto, _sdiu, шриё, 
   {{0x683000b5,0x00000000,0x00000000,0x00000000}},	//   _rådn, --, --, --, 
   {{0x69c611da,0x9f5c00e8,0x5bb401e0,0x40841d39}},	//   _adhe, _jawë_, шсоф, _сузб, 
   {{0x3e680158,0x00000000,0x00000000,0x00000000}},	//   føtt_, --, --, --, 
   {{0xa2cc0d2b,0x26042aa1,0x3ebc014f,0x00000000}},	//   _सिन्, _होली_, msut_, --, 
   {{0xd7f000c6,0x69c40055,0x60c00171,0x0a3c0023}},	//   يكس_, _ddhe, _jvlm, _ኣእምራ, 
   {{0xfbb00183,0xa3e406ab,0x7a311a73,0x3ebc0194}},	//   _কাকত, _बॉल_, _täto, osut_, 
   {{0x44f4007f,0x7c2400a3,0x3ebc05d5,0x00000000}},	// [3c900] _aŧ_, _ioir, nsut_, --, 
   {{0x3ebc0af5,0x69c40240,0x7c24952b,0x7a3211db}},	//   isut_, _gdhe, _hoir, _kätm, 
   {{0x7c2611dc,0x1ddc0d5f,0x7a3000af,0x26040073}},	//   _koir, _मानत, _jätm, _होळी_, 
   {{0x3ebc02f6,0x1304337e,0x84840023,0x7a30007c}},	//   ksut_, изем, _ምባልን_, _mätm, 
   {{0x7c2611dd,0x69c0066a,0x82f40214,0xa3e46c5a}},	//   _moir, ðleg, لروز_, ब्ध_, 
   {{0x7c2611de,0x3ebc0455,0x00000000,0x00000000}},	//   _loir, dsut_, --, --, 
   {{0x00d4092f,0x7c2400ad,0x442c0175,0x245003e6}},	//   لبيت_, _ooir, bkg_, _کۆنس, 
   {{0x7c2611df,0x442c0036,0xa3e436c3,0x00000000}},	//   _noir, ckg_, ब्द_, --, 
   {{0x7eb400cf,0x15b800d1,0x63adc8b0,0x00000000}},	//   агыс_, _ﺧﯘﺩﺩ, ñane, --, 
   {{0xc0e40020,0x7c241cf8,0x8e2611e0,0x00000000}},	//   ዚህም_, _aoir, рфид, --, 
   {{0x7c25315a,0x3ebc32ff,0x20c8a2f2,0x7a300139}},	//   _boir, asut_, _مبني_, _cätm, 
   {{0x7c2611e1,0x3f9c0ba7,0xdec40023,0x00000000}},	//   _coir, ccuu_, ጺእካ_, --, 
   {{0x7c2611e2,0x3ebc02c4,0xdb140100,0x9f5c0100}},	//   _doir, csut_, _jeyè, _nawè_, 
   {{0x9d6401d9,0x7bc00bcd,0x00000000,0x00000000}},	//   _گنى۪, ómur, --, --, 
   {{0x7c2611e3,0x442c0175,0x3e683ad2,0x00000000}},	//   _foir, ykg_, røtt_, --, 
   {{0x7c240013,0x2c780264,0x6830005c,0xfd0c00ec}},	//   _goir, béda_, _vådo, _آجو_, 
   {{0x69c40175,0x7798460c,0x69c211e4,0x442c0175}},	// [3c910] _tdhe, ркур_, óles, vkg_, 
   {{0x69c611e5,0x160c07af,0x7c24022e,0xa2cc72c0}},	//   _udhe, सागर_, _zoir, _सिब्, 
   {{0x3ebc04cc,0x38c8008e,0x0a3c0023,0xa3e4000d}},	//   zsut_, _куян_, _ኣእሙራ, _बउआ_, 
   {{0x537005d9,0xa3d421f3,0x7a300432,0x00000000}},	//   ڻهوء, содч, _nätj, --, 
   {{0x01dc2158,0x9f5c0066,0x21a40107,0x00000000}},	//   _যোগদ, _gawè_, билм, --, 
   {{0xdb1402e2,0xdb040308,0xe7fc0073,0x057611e6}},	//   _deyè, jaký, _उघडा_, _نازد, 
   {{0x672e11e7,0x05900150,0x3ebc0042,0x00000000}},	//   lyaj, _ﯗﻻﺳﭙ, wsut_, --, 
   {{0x3ebc0af5,0x9f5c0c6a,0x92e40183,0x39580375}},	//   tsut_, _hawé_, _বছৰ_, ישום_, 
   {{0x672e11e8,0x3ebc0eda,0x644a11e9,0x7c2402b5}},	//   nyaj, usut_, _imei, _roir, 
   {{0x7c260c5f,0x3ebc0af5,0xc0c8084c,0x00000000}},	//   _soir, rsut_, _ауде_, --, 
   {{0x7c2611ea,0x3ebe11eb,0xf1a400a8,0xdb140100}},	//   _poir, ssut_, _фрун, _zeyè, 
   {{0x3ebe11ec,0x9f5c0098,0x683000b5,0x38c802f2}},	//   psut_, _lawé_, _bådm, یازی_, 
   {{0x7c255e6a,0x644801f7,0x248404fb,0x6830007c}},	//   _voir, _mmei, _èlmu_, _vådl, 
   {{0x9f5c1446,0x7c2400ad,0x2c78003e,0xdb04000d}},	//   _nawé_, _woir, réda_, makü, 
   {{0x7c240ea3,0xa2840023,0x7a300108,0x8ccc12eb}},	//   _toir, _ምዃነን_, _hätk, _थियो, 
   {{0x9f5c007f,0x7a300f23,0xccf000d9,0x2c7800d7}},	//   _pawè_, _kätk, _זכה_, péda_, 
   {{0x7a30793d,0x290545fb,0x9f4c022f,0x2c1402ab}},	// [3c920] _jätk, ålar_, leeâ_, धारू_, 
   {{0x644a11ed,0xdb140699,0x9f5c00f2,0xa3e425fe}},	//   _amei, _reyè, _cawé_, ब्स_, 
   {{0xc68c01d9,0x7a30005b,0xdb040254,0x00000000}},	//   رِم_, _lätk, hakü, --, 
   {{0x64480472,0xa28402d3,0xd87400f1,0x4d78010f}},	//   _cmei, _ምዃኑን_, _داخب, אָדא, 
   {{0x672c00ca,0xfd045022,0x7a3001e3,0xdb0611ee}},	//   cyaj, _کج_, _nätk, makó, 
   {{0x644a11ef,0x9f5c5f14,0x46a074a5,0xdb04f5f4}},	//   _emei, _gawé_, _харв, lakó, 
   {{0x73c40046,0x53a40139,0x63acd01b,0x20cc02d2}},	//   _дәле, _габб, ñanc, _róið_, 
   {{0x7a30013d,0xa49001d5,0x6448002f,0xdb0611f0}},	//   _bätk, _قیلت, _gmei, nakó, 
   {{0xdb040037,0x932400f2,0x3f1001ec,0x71c401f0}},	//   gakü, _ارزن, здыс, _ҳаҷҷ, 
   {{0x68300623,0x64480356,0xa2cc190c,0x00000000}},	//   _rådm, _zmei, _सित्, --, 
   {{0x5ed8015b,0xdd800014,0x00000000,0x00000000}},	//   _বৈদে, ٘یوٝ, --, --, 
   {{0xdb0611f1,0x7a300139,0x00000000,0x00000000}},	//   jakó, _fätk, --, --, 
   {{0x606000db,0x7a300b70,0xdb040210,0x00000000}},	//   _تۇيل, _käth, dakó, --, 
   {{0x25ac0e04,0xa2840240,0x00000000,0x00000000}},	//   _đelo_, _ምዃናን_, --, --, 
   {{0x28d80d5f,0x48740597,0x9f5c0066,0xb1640023}},	//   बंधि, مدرس, _rawé_, _ድሕሪዚ_, 
   {{0x672c00dc,0x00000000,0x00000000,0x00000000}},	//   tyaj, --, --, --, 
   {{0xa2cc090a,0xf1c80a94,0xc6a40063,0x00000000}},	// [3c930] _सिध्, रणान, срби, --, 
   {{0x644a11f2,0x7a300267,0x28d801ad,0x08400050}},	//   _smei, _näth, बंदि, _کۆرُ, 
   {{0x27ec00e4,0xdb04b750,0xdee80240,0x00000000}},	//   _ñeno_, zakü, ዚብና_, --, 
   {{0xa2cc4de3,0x25a00112,0xdb04007f,0x940803b9}},	//   _सिद्, schl_, makò, _kubə_, 
   {{0x2be003e5,0x00000000,0x00000000,0x00000000}},	//   _कानू_, --, --, --, 
   {{0x27e80cfd,0x97000131,0x77a80014,0x7a300166}},	//   lfan_, _زېمى, _نێہہ_, _rätk, 
   {{0x661496c0,0xcf8c04d3,0x09e0009e,0x68300267}},	//   _inzk, ۆژه_, য়পা, _rådj, 
   {{0x27e864d3,0x1eca11f3,0x644800ec,0x9f186d6c}},	//   nfan_, алии_, _umei, لآخر_, 
   {{0x94140490,0xc0cc0023,0x66040009,0x00000000}},	//   णारच_, _ባእሲ_, odhk, --, 
   {{0xdb0611f4,0x5e480064,0xa3e4197c,0x27e803cb}},	//   kakò, рпом_, ब्र_, hfan_, 
   {{0x6280789a,0x61540d28,0x389800b0,0x660401d9}},	//   _ihlo, _بنائ, _kōre_, idhk, 
   {{0x6459635f,0xdc6801c0,0x7a30007c,0x00000000}},	//   nnwi, рамд_, _tätk, --, 
   {{0xa3e02052,0x27e80368,0x645826bd,0x87d80327}},	//   _दान_, dfan_, inwi, ྲུནཡ, 
   {{0x7a306d59,0x6458002f,0x1d080d1d,0x00000000}},	//   _käti, hnwi, _веки_, --, 
   {{0x27ea11f5,0x62801cdf,0x7a30005b,0xc0e00150}},	//   ffan_, _mhlo, _jäti, _ﺍﻛﻪﺗ, 
   {{0x67042017,0x645801f5,0x7a3211f6,0x6604058a}},	//   रिंक_, jnwi, _mäti, edhk, 
   {{0x7a302045,0x628211f7,0xddc00356,0xdb0611f8}},	// [3c940] _läti, _ohlo, colţ, rakó, 
   {{0x6281e84d,0x27e92207,0x3b0006be,0xdb049cc6}},	//   _nhlo, afan_, _isiq_, sakó, 
   {{0x7a300598,0xd4c400c6,0x27e800b5,0xdb04012d}},	//   _näti, تغذي, bfan_, pakó, 
   {{0x6281058c,0x13087d03,0x5468034b,0x66040067}},	//   _ahlo, иней_, шаем_, adhk, 
   {{0x63ae11f9,0x62809883,0x3ae401b8,0x838018d9}},	//   ñana, _bhlo, nöp_, мыше, 
   {{0x628150da,0x64580048,0x154400ee,0x94a80014}},	//   _chlo, anwi, _дегм, _نارِ_, 
   {{0x80a211fa,0x628211fb,0x00000000,0x00000000}},	//   ومون, _dhlo, --, --, 
   {{0x62800173,0x3ae611fc,0x7ae484d3,0x61f403e0}},	//   _ehlo, köp_, _oqit, _ızle, 
   {{0x2be005b3,0x628012ef,0x7a3001e3,0x5274010a}},	//   _काबू_, _fhlo, _täth, _дужу, 
   {{0x3ae429ef,0x628211fd,0xdd90297d,0x00000000}},	//   döp_, _ghlo, کوپ_, --, 
   {{0x09e00c58,0xa3e01533,0xc220034c,0x7ae4013c}},	//   য়মা, _दाम_, _تکنو, _aqit, 
   {{0x09d005ba,0x1ee804fb,0x00000000,0x00000000}},	//   तल्य, جویی_, --, --, 
   {{0xfad80801,0xacb401b9,0x66040067,0x3ae400a2}},	//   одящ_, _کمبغ, ydhk, göp_, 
   {{0xa2cc1ab2,0x205c1b49,0x1950037e,0xdb040100}},	//   _सिस्, _ዌብሳይ, _ｎｈｋ_, takò, 
   {{0x2604006d,0x7ae40869,0x6459b35a,0x7a300166}},	//   _होगी_, _eqit, ynwi, _xäti, 
   {{0x3ae40793,0xdb04007f,0xbc6800db,0x00000000}},	//   böp_, rakò, _ومون_, --, 
   {{0x27ea11fe,0x09e0045e,0x7ae4004b,0x3950013b}},	// [3c950] rfan_, য়বা, _gqit, _ɛnsɛ_, 
   {{0x35f43ab9,0x2604033d,0x6604058a,0x64580142}},	//   мпур, _होखी_, udhk, wnwi, 
   {{0x27e800b5,0x00000000,0x00000000,0x00000000}},	//   pfan_, --, --, --, 
   {{0x62811fb8,0x290211ff,0x7a321200,0x00000000}},	//   _shlo, _isha_, _räti, --, 
   {{0x68307a1e,0x62821201,0x7a321202,0x21a401b9}},	//   _rådh, _phlo, _säti, пилм, 
   {{0x629c00d8,0x7a321203,0x25ac06be,0xd5e006e3}},	//   _ésom, _päti, _şelf_, _पायज, 
   {{0x2be00073,0x855400f2,0x10a00395,0xa2cc01f9}},	//   _काढू_, _بیار_, нищн, _सिव्, 
   {{0x7a300166,0x1ddc07f7,0x83840064,0x00000000}},	//   _fätw, _माहत, _дызе, --, 
   {{0x62821204,0xa2b4000d,0x6ed4009d,0x41e41cd0}},	//   _thlo, _उबट्, мцэх, _міжа, 
   {{0x62800028,0x7a300730,0x3ae401b8,0x7ae401b9}},	//   _uhlo, _täti, vöp_, _rqit, 
   {{0x29000223,0x5f942586,0xddc21205,0x1288072d}},	//   _nsha_, _فلائ, golš, _املی_, 
   {{0x6b8002e3,0xe9f80241,0x65740200,0x00000000}},	//   _ịgan, _itẹ_, _myzh, --, 
   {{0x7ae40408,0x7a30007c,0x00000000,0x00000000}},	//   _qqit, _mätv, --, --, 
   {{0xf8b80032,0xddc00010,0x00000000,0x00000000}},	//   ҙөү_, bolš, --, --, 
   {{0x61e00198,0x00000000,0x00000000,0x00000000}},	//   _mcll, --, --, --, 
   {{0x7a30049f,0xb8f447d0,0xb90415e0,0x68e40009}},	//   _nätv, _हट_, _नम_, _dqhd, 
   {{0x95c85950,0x7ae4022e,0xcc38010f,0x00000000}},	// [3c960] йлаб_, _uqit, _לעקט, --, 
   {{0x95980046,0x63ac0113,0x290002d2,0x00000000}},	//   стау_, ñann, _fsha_, --, 
   {{0x1868201d,0xdb1401e1,0xd5dc0073,0x00000000}},	//   _гани_, _meyí, मलबज, --, 
   {{0xdb140241,0x6a8002d2,0x00000000,0x00000000}},	//   _leyí, _táfý, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa2cc6495,0x6831f99c,0x0bac01ec,0x201401e2}},	//   _सिर्, _rådi, _ﺳﯩﻠﻮ, ېښود_, 
   {{0x490cd054,0x537802d3,0x4638008f,0x829000d1}},	//   डियो_, ጦንዮስ_, _פעלע, رۇمچ, 
   {{0x8f4406bb,0x53a44ed4,0x1544014b,0x00000000}},	//   зход, _хааб, _деҳм, --, 
   {{0xa3e401ad,0xa3e0044b,0x00000000,0x00000000}},	//   _बॉट_, _दात_, --, --, 
   {{0x2d98e863,0x7bc0008c,0x60cc0227,0x6d361206}},	//   øre_, ðmun, ņama, деоф, 
   {{0x1ddc2232,0x7a300108,0x00000000,0x00000000}},	//   _मारत, _jätu, --, --, 
   {{0x2fc000fc,0x7a3002b1,0x0fe00116,0x00000000}},	//   _þig_, _mätu, _чөкү, --, 
   {{0xdb1401e1,0x528802dd,0x00000000,0x00000000}},	//   _feyí, _ﺗﻮﯕﯩ, --, --, 
   {{0xddc00427,0x00000000,0x00000000,0x00000000}},	//   polš, --, --, --, 
   {{0xfd0c0375,0x7a3001e3,0x827400df,0x00000000}},	//   _مجي_, _nätu, פעלע_, --, 
   {{0xa2cc04af,0x6830007c,0xf804030d,0x00000000}},	//   _सिल्, _lådv, нчун, --, 
   {{0x499000f2,0x00000000,0x00000000,0x00000000}},	// [3c970] بیگر, --, --, --, 
   {{0x29000dc9,0x6aae1207,0xc5880108,0x00000000}},	//   _tsha_, _itaf, бщее_, --, 
   {{0x29021208,0xe4b80046,0x12e40131,0xa3e01b87}},	//   _usha_, ілді_, ﺎﻧﻼﺭ, _दाद_, 
   {{0x61e00165,0x00000000,0x00000000,0x00000000}},	//   _scll, --, --, --, 
   {{0xc76401ec,0x6aac031c,0x1ddc0825,0x04fc0154}},	//   _ءاجى, _jtaf, _मालत, ূহের_, 
   {{0x6aae1209,0xb6040024,0x00000000,0x00000000}},	//   _mtaf, _пяск, --, --, 
   {{0x20882564,0xe508027d,0xd04806be,0x00000000}},	//   ойки_, _بيزو_, lufə, --, 
   {{0xd00dea53,0x7a32120a,0x6aae120b,0x724403e6}},	//   للى_, _hätt, _otaf, وپۆل, 
   {{0x7a30007d,0x63a851c3,0x1f649e78,0x2c20412f}},	//   _kätt, _ifen, ьким, यानं_, 
   {{0x7a32120c,0x00000000,0x00000000,0x00000000}},	//   _jätt, --, --, --, 
   {{0x6aae120d,0xefcc02d3,0x7a311d73,0x9d4412b9}},	//   _ataf, ጣንያ_, _mätt, фенд, 
   {{0x7a3004f3,0x3ec400d1,0x00000000,0x00000000}},	//   _lätt, _еқим_, --, --, 
   {{0x63a8009f,0x3cdc0037,0x00000000,0x00000000}},	//   _mfen, _कमवे_, --, --, 
   {{0x7a303f64,0x44e400c7,0x00000000,0x00000000}},	//   _nätt, kõ_, --, --, 
   {{0x6aac97b3,0x00000000,0x00000000,0x00000000}},	//   _etaf, --, --, --, 
   {{0xdb04420d,0xbd8401d9,0x20d4000d,0x00000000}},	//   dakö, _وچھن_, _धिनध, --, 
   {{0x7a300628,0x2fc0007d,0x67640032,0x5a64020a}},	// [3c980] _bätt, _õige_, ентҡ, _окиб, 
   {{0x63aa120e,0x7a30014a,0xaae4007b,0xdb05ec50}},	//   _afen, _pätu, _أسيو, fakö, 
   {{0x683005ac,0xca34011a,0xe4a4003b,0x00000000}},	//   _rådv, _חניה_, еріо, --, 
   {{0x7d000175,0x6830005c,0xdb0c0241,0x1be417ee}},	//   _msns, _bådu, _ìkóp, _काफल_, 
   {{0x59d02699,0x63a80036,0x7a30008e,0xa2c029d9}},	//   _तयार, _dfen, _fätt, _रौद्, 
   {{0x63aa120f,0x999800bc,0x00000000,0x00000000}},	//   _efen, _popř_, --, --, 
   {{0x63a92ddf,0x7a30007c,0x92dc0154,0xdb040254}},	//   _ffen, _häts, তবে_, makõ, 
   {{0xf48411fc,0x490c045b,0xf1e00073,0x7a3001f4}},	//   _سازی, डितो_, _नावन, _käts, 
   {{0x7a3025c6,0x7d0000ef,0x00000000,0x00000000}},	//   _jäts, _asns, --, --, 
   {{0x7a300724,0x2c780098,0xdb04000d,0x00000000}},	//   _xätt, médi_, nakõ, --, 
   {{0x6aae1210,0x6c540f5c,0xda2001ad,0x00000000}},	//   _staf, екну, मानत_, --, 
   {{0x3cdc0034,0x800801ed,0xb30c031c,0xdb040254}},	//   _कमरे_, _ورنہ_, _གློང_, hakõ, 
   {{0xa3e000e1,0x7d0002d0,0xa2c06c52,0x7a321211}},	//   _दास_, _esns, रीप्, _näts, 
   {{0x2fc401af,0x389802b5,0x7aa40fc0,0xdb061212}},	//   lamg_, _rōra_, тиёз, jakõ, 
   {{0x7a3196fa,0x8c6447bf,0x06681c5c,0x6d5c00c6}},	//   _rätt, _отид, ﻳﻮﻧﯩ, úrad, 
   {{0x7a321213,0x629c011c,0x6aac031c,0x59940092}},	//   _sätt, _èsog, _ttaf, _ሆናችሁ_, 
   {{0x6aac05d9,0x7a321214,0xf771003d,0x63ac02d1}},	// [3c990] _utaf, _pätt, لاك_, ñanm, 
   {{0xb30c1f21,0x7a300036,0x63aa1215,0xdb061216}},	//   _གླེང_, _däts, _sfen, takö, 
   {{0x63aa1217,0x7a300267,0x6830005c,0x494c0092}},	//   _pfen, _vätt, _bådt, _አስቆጥ, 
   {{0xdb061218,0xdb14007f,0x5f1000dc,0x683001bf}},	//   rakö, _idyò, तिम्_, _pådu, 
   {{0x1608068f,0x2c78003e,0x7a302bd5,0x44e400c7}},	//   _होकर_, gédi_, _tätt, sõ_, 
   {{0xa3e0098a,0x26c80051,0x1ddc00bc,0x91e00114}},	//   _दाव_, msao_, _माइत, гоше, 
   {{0x7a300254,0xa3d400d4,0xf1e00210,0x00000000}},	//   _kätr, _повч, _नारन, --, 
   {{0x5f040139,0x63aa0e90,0x201a1219,0x92ac05ac}},	//   езиа, _ufen, ñsi_, _কিৰ_, 
   {{0x443e121a,0x26c80120,0x7a3004ab,0x00000000}},	//   _ilu_, nsao_, _mätr, --, 
   {{0x0e62121b,0x443c01f0,0x26c8001e,0x7a300108}},	//   лкын, _hlu_, isao_, _lätr, 
   {{0x443e121c,0xc1000131,0x02dc2ce6,0xc0dc0023}},	//   _klu_, _рүйл, _नमुन, ዒቶም_, 
   {{0xe3b80165,0x443c5b3c,0x26c816a3,0x7a3001e3}},	//   _goűt_, _jlu_, ksao_, _nätr, 
   {{0x6f00009a,0x2be0000d,0x9ea80354,0x00000000}},	//   cwmc, _कारू_, _эвла_, --, 
   {{0x443e121d,0x7a32121e,0x0f540375,0x7d02121f}},	//   _llu_, _räts, _אינם_, _tsns, 
   {{0x443e1220,0x295400a7,0x7d0002d0,0xa3c009b2}},	//   _olu_, вътр, _usns, ूणा_, 
   {{0x02dc1b37,0x24e4015b,0x7a300641,0x443e1221}},	//   _नमून, নবাহ, _päts, _nlu_, 
   {{0xdb061222,0xf1e03c71,0xa2c0298e,0x769406be}},	// [3c9a0] gakô, _नालन, रीम्, lüyə, 
   {{0x443e1223,0x7a3001e6,0x9f5c011f,0x6a64007f}},	//   _alu_, _väts, _xawá_, _pčfņ, 
   {{0x26c80421,0x09e000fe,0xab280066,0x00000000}},	//   asao_, য়শা, _فسیل_, --, 
   {{0x7a3040fc,0x1868013e,0xead00248,0x947400f7}},	//   _täts, _хами_, _mẹnu_, رداا, 
   {{0x443e1224,0x389802b1,0x386009f3,0xa3e0a4cd}},	//   _dlu_, _hōro_, mnir_, _दार_, 
   {{0x443e1225,0x2c7877aa,0x38601427,0xd5740108}},	//   _elu_, rédi_, lnir_, _зубь, 
   {{0x443d618d,0xa2c00d2c,0x3eac004d,0x2be007f7}},	//   _flu_, रीब्, _atgt_, _कालू_, 
   {{0x38621226,0x301400ee,0x2ef50519,0x4fc4e44f}},	//   nnir_, тдир, взир, хска, 
   {{0x386008a7,0x04402d1f,0xcfa801d3,0x00000000}},	//   inir_, _сетн, _ہاشم_, --, 
   {{0x443c05a1,0xead001e1,0x3eac0175,0x9e6c04b2}},	//   _zlu_, _bẹnu_, _dtgt_, _አባልና_, 
   {{0x38602242,0x443c030d,0x2bc83baf,0x50d400f2}},	//   knir_, _ylu_, үлүп_, _سزار, 
   {{0xead00241,0xdb1400a2,0x00000000,0x00000000}},	//   _dẹnu_, _adyñ, --, --, 
   {{0xbb94e498,0x3860022c,0x3eac01fb,0xe048036b}},	//   лающ, dnir_, _gtgt_, _تشله_, 
   {{0xead001e1,0x7a3001e3,0x297400d1,0x478800c7}},	//   _fẹnu_, _sätr, ﺸﯩﭽﻪ_, ҧсам_, 
   {{0xa3e00307,0x63ac241c,0x38621227,0xd06006be}},	//   _दाल_, ñank, fnir_, _şuər, 
   {{0x38621228,0xc6a4cf02,0x4288001f,0x26c80109}},	//   gnir_, ержи, _ሕፃናት_, tsao_, 
   {{0xe9f8004d,0xf99001d3,0xe6980395,0x00000000}},	// [3c9b0] _cuả_, لبہ_, дваш_, --, 
   {{0x443e1229,0x26c80798,0x6d480311,0x6a1400c7}},	//   _slu_, rsao_, ozda, _рмоу, 
   {{0x443e122a,0x26c80120,0x6d480399,0xc95801b9}},	//   _plu_, ssao_, nzda, _хўп_, 
   {{0xa5655f54,0x6830005c,0x00000000,0x00000000}},	//   _یگان, _våds, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x443c020c,0xa0c41671,0xa5c80014,0x6d4802d0}},	//   _wlu_, نيتو, _زورٕ_, kzda, 
   {{0xa2cc3b90,0xd24c00aa,0x443e122b,0xa068936a}},	//   _सिक्, تنو_, _tlu_, мака_, 
   {{0x443e122c,0x6d4800e2,0x349407a5,0x8d9c02dd}},	//   _ulu_, dzda, _баср, _ﺍﺯﺍﺕ_, 
   {{0x9e66122d,0x06e00f22,0x13e80150,0x6d486872}},	//   квид, _নৈতি, _توقۋ_, ezda, 
   {{0x7a3001e6,0xb3540fac,0xf1a400d8,0xdfd000ec}},	//   _nätp, _скуш, _брцн, _چيا_, 
   {{0x0d807724,0xdc680aa5,0xf1c8fd47,0xd24d93ed}},	//   ильн, данд_, _سونى_, _بچن_, 
   {{0x8f5003e6,0x9ee8007b,0x98a800c0,0x00000000}},	//   انیش, _يفضل_, nybą_, --, 
   {{0xde05667e,0x201c06d6,0xdee6122e,0x38600579}},	//   _апли, _inwi_, _роли, vnir_, 
   {{0x63b80097,0x38980374,0x6d5d36e8,0x200e122f}},	//   hbwn, _pōro_, úrac, ldei_, 
   {{0xa2c0543b,0x38600ad9,0x98a40139,0x98a80153}},	//   रीत्, tnir_, тибе, kybą_, 
   {{0x200e1230,0x386001a8,0x4d78011a,0x98a800c0}},	//   ndei_, unir_, _קרקע, jybą_, 
   {{0x38610412,0xe9f801dc,0x07a0cb80,0x7bc416b8}},	// [3c9c0] rnir_, _quả_, раун, _ieiu, 
   {{0x7bc40393,0x38600252,0x00000000,0x00000000}},	//   _heiu, snir_, --, --, 
   {{0x69d804ac,0x201c02c4,0xd94401af,0x6830005c}},	//   _אַרו, _onwi_, _рени, _vådr, 
   {{0x77941c67,0x15440107,0x200c054e,0x00000000}},	//   _میزا, неҷм, jdei_, --, 
   {{0x200e1231,0x814001d3,0x00000000,0x00000000}},	//   ddei_, یچمن, --, --, 
   {{0x201c18f7,0x7bc400af,0xf424010b,0x1ddc0073}},	//   _anwi_, _leiu, _өзгү, _मागत, 
   {{0x2bb402ab,0xc1000b6c,0xc0e40131,0x94940f15}},	//   ंडमा, لووي, نفون_, _ашач, 
   {{0x8fd00184,0x6d482b57,0x7bc61232,0x27ec1bce}},	//   рәжә, vzda, _neiu, _ñent_, 
   {{0xb8e40327,0xa2c00404,0x2c2000cd,0x00000000}},	//   _ཌས_, रीद्, यासं_, --, 
   {{0x200e1233,0x201c03cb,0x6d480112,0x00000000}},	//   adei_, _enwi_, tzda, --, 
   {{0x320c0109,0x7bc4054e,0x9cc801e0,0xaaa4000d}},	//   _iady_, _beiu, нъяҡ_, _गंहक, 
   {{0x320c0109,0x00000000,0x00000000,0x00000000}},	//   _hady_, --, --, --, 
   {{0x320c05da,0x63ac0bc9,0x7bc4003a,0x629c06af}},	//   _kady_, ñani, _deiu, _ésot, 
   {{0x3a75fc28,0x320c010e,0xfe6c029c,0x00000000}},	//   иляр, _jady_, _ودو_, --, 
   {{0x7bc40421,0x320c01c7,0x683001bf,0xfe98011a}},	//   _feiu, _mady_, _bådp, _קיומ, 
   {{0x320c74da,0x8aa4039b,0xa3e0302b,0x00000000}},	//   _lady_, _ирод, _दाइ_, --, 
   {{0xf1b400b8,0xddc0010e,0x00000000,0x00000000}},	// [3c9d0] ुरान, nilş, --, --, 
   {{0x0a8800cf,0x2c200073,0xdb140139,0x200c0356}},	//   _تئبى_, यावं_, _seyç, zdei_, 
   {{0xfa343c4b,0x98a80024,0xa4d40a5b,0x00000000}},	//   _خريد, tybą_, ужељ, --, 
   {{0xf48401f4,0x00000000,0x00000000,0x00000000}},	//   аучн, --, --, --, 
   {{0x69c61234,0x6234768e,0x320df399,0x0520015b}},	//   _kehe, леду, _bady_, পনের_, 
   {{0x69c61235,0x200c0649,0x00000000,0x00000000}},	//   _jehe, wdei_, --, --, 
   {{0x69c61236,0x320cc8d0,0x200c0649,0x101c05d7}},	//   _mehe, _dady_, tdei_, भांश_, 
   {{0x69c61237,0xead00570,0xdfe8059f,0x00000000}},	//   _lehe, _pẹlu_, хдид_, --, 
   {{0x200c0385,0x320c03d1,0x645a1238,0xe8e001fb}},	//   rdei_, _fady_, miwi, _ướp_, 
   {{0x69c61239,0x645a123a,0x200cb5db,0x7bc6123b}},	//   _nehe, liwi, sdei_, _seiu, 
   {{0x6ed804fa,0x7bc40381,0x1be93285,0x00000000}},	//   _मिथु, _peiu, ндни_, --, 
   {{0x645a123c,0x9f04637b,0x201c02c4,0x320c0209}},	//   niwi, _موصو, _unwi_, _zady_, 
   {{0xa3e0c6cd,0x7bc419a2,0x69c44a5a,0x320c0882}},	//   _दाई_, _veiu, _behe, _yady_, 
   {{0x645a123d,0xdea004fb,0x69c4029f,0x00000000}},	//   hiwi, _پیگی, _cehe, --, 
   {{0x645a123e,0x69c6123f,0xdee40075,0x7bc4054e}},	//   kiwi, _dehe, _роһи, _teiu, 
   {{0x2b54034c,0x69c61240,0xa7b40640,0x6458003e}},	//   ایید_, _eehe, исуј, jiwi, 
   {{0x64599335,0x69c61241,0x1784f7a6,0x166497d0}},	// [3c9e0] diwi, _fehe, угам, гвам, 
   {{0x69c45093,0x1a040577,0xceb00375,0x645801f5}},	//   _gehe, _спом, ציב_, eiwi, 
   {{0x320ca3f5,0x9e7802d3,0xa2c02894,0xd7040116}},	//   _rady_, _ርእስና_, रीस्, _өзни, 
   {{0x320c1311,0xda2000c5,0x69c42016,0x64580098}},	//   _sady_, मावत_, _zehe, giwi, 
   {{0x320e1242,0x69c61243,0x705404fb,0x2bb401f9}},	//   _pady_, _yehe, ینتا, ंडता, 
   {{0x69c401c0,0x7424009e,0xc2c0007b,0x9594009b}},	//   _xehe, পসেট_, حيوي, _брбљ, 
   {{0x320c5fd3,0x69c0066a,0x64580c6a,0xca78010f}},	//   _vady_, ðlei, biwi, ענצט, 
   {{0x0440355a,0xb03421ee,0x320c033f,0x645a1244}},	//   _лесн, рниш, _wady_, ciwi, 
   {{0x320c0316,0x8c34016c,0x4364014b,0x00000000}},	//   _tady_, ҳонӣ_, _батн_, --, 
   {{0x52761245,0x00000000,0x00000000,0x00000000}},	//   _субу, --, --, --, 
   {{0x69c56cb2,0x2d98eabc,0x7e7001c6,0x00000000}},	//   _rehe, äre_, сгэх, --, 
   {{0x69c61246,0x8fa44d87,0xab380116,0x228800e4}},	//   _sehe, _саде, впму_, rúke_, 
   {{0x69c61247,0x98a802d5,0x69c0000d,0x0a6a07e3}},	//   _pehe, mybę_, वरली, ерви_, 
   {{0x645a1248,0x98a80024,0x5f1000dc,0x2be00073}},	//   ziwi, lybę_, तिर्_, _काकू_, 
   {{0x69c61249,0x61f445e3,0x645a124a,0x2bb401ad}},	//   _vehe, _özle, yiwi, ंडदा, 
   {{0x69c6124b,0x645818f7,0x98a80024,0x00000000}},	//   _wehe, xiwi, nybę_, --, 
   {{0x69c6124c,0x64580564,0x44200208,0x66d51b9d}},	// [3c9f0] _tehe, viwi, _đj_, شيائ, 
   {{0x69c4186a,0x4e18012c,0x645a124d,0x00000000}},	//   _uehe, बाटै_, wiwi, --, 
   {{0x645a124e,0x23b47a32,0x98a80024,0xa2cc095f}},	//   tiwi, لماس, kybę_, _सिङ्, 
   {{0x99300014,0xe3140640,0x7cf80108,0x00000000}},	//   _بہِت, имењ, _härö, --, 
   {{0x645a124f,0x46300022,0x98a800c0,0x00000000}},	//   riwi, _лҭар, dybę_, --, 
   {{0x645a1250,0xa2c21251,0xe80c0316,0x862402d5}},	//   siwi, रीष्, ाएका_, _сьме, 
   {{0x90c08656,0x64580054,0x60240108,0x6144010b}},	//   обще, piwi, идка, рейа, 
   {{0x9f0400f7,0xd12c3c19,0x645a1252,0x98a80024}},	//   لوبو, ظمي_, qiwi, gybę_, 
   {{0x6d5e1253,0xa2c007d0,0x00000000,0x00000000}},	//   úran, रीश्, --, --, 
   {{0x38bc01e1,0xe0d41f5a,0x00000000,0x00000000}},	//   _jàrò_, _вожњ, --, --, 
   {{0x248c0487,0x88a8009e,0x00000000,0x00000000}},	//   _khem_, গীতক, --, --, 
   {{0x5c561254,0x5e440014,0x25ac8021,0x1f740108}},	//   ртоф, انگٕ, _şell_, _клея, 
   {{0x4c65670d,0x00000000,0x00000000,0x00000000}},	//   риян_, --, --, --, 
   {{0x3e68008e,0xdb1c01e1,0x00000000,0x00000000}},	//   _яшен_, _èyít, --, --, 
   {{0x5d7804ac,0x389804fe,0x98547503,0x00000000}},	//   _באַק, _hōri_, аташ, --, 
   {{0x09e0015b,0xe80c033f,0xa3e01b51,0x3dc4015d}},	//   য়গা, ाएगा_, _दाग_, _henw_, 
   {{0x7cf826bc,0x644000c0,0x00000000,0x00000000}},	// [3ca00] _färö, _įlip, --, --, 
   {{0x389800b0,0x59740006,0xe8f80107,0x5edc000d}},	//   _mōri_, _выму, ълӣ_, _खिन्_, 
   {{0x89d80302,0x95980046,0x3dc40100,0xa3e000ab}},	//   _בחיי, ттау_, _menw_, _दाख_, 
   {{0x248c011a,0xe7d40139,0x24b81e2f,0x6fe401ec}},	//   _chem_, _iñğı, اننگ_, _ﺍﻋﺎﺷ, 
   {{0xddc0151c,0x248d041e,0x98a80024,0x96b8010b}},	//   dolž, _dhem_, vybę_, _шуну_, 
   {{0x78a80af2,0x00000000,0x00000000,0x00000000}},	//   ídvw, --, --, --, 
   {{0x3d1c0034,0xfd042e0b,0xd9ec00af,0x100401b9}},	//   यमों_, _بج_, _जानत_, аяпм, 
   {{0x63ad2c7d,0x248e1255,0x00000000,0x00000000}},	//   ñant, _ghem_, --, --, 
   {{0x91e61256,0x9eb000d1,0xd37002f2,0x00000000}},	//   _возе, كەنغ, _بێشک, --, 
   {{0x98a80153,0x00000000,0x00000000,0x00000000}},	//   sybę_, --, --, --, 
   {{0x10a4008e,0x92ac03d4,0x00000000,0x00000000}},	//   _тиен, _কিয়_, --, --, 
   {{0xdb0401d3,0x7cf83b22,0x248c0200,0xd0080114}},	//   bbkü, _särö, _xhem_, _једе_, 
   {{0x63ac0024,0xce4800db,0x228800d7,0xaa9400cf}},	//   žang, _изде_, lúka_, йимч, 
   {{0x6b8c03e0,0x00000000,0x00000000,0x00000000}},	//   _ılgı, --, --, --, 
   {{0x6cd42586,0x228801a2,0xac945663,0xdb0c0306}},	//   _اقبا, núka_, _лакш, čkáv, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x248c03a2,0xc608015b,0x23ac0241,0x0a68011c}},	// [3ca10] _rhem_, রাসা_, _lójó_, _арни_, 
   {{0x248c0652,0xd9ec00af,0x39a40014,0x2bb41b87}},	//   _shem_, _जायत_, _ویُہ, ंडवा, 
   {{0x248c0457,0xdb0c0108,0x00000000,0x00000000}},	//   _phem_, äkös, --, --, 
   {{0x08400014,0x22880174,0x00000000,0x00000000}},	//   _بۆرُ, dúka_, --, --, 
   {{0x77640c04,0x2ee42220,0x6f0400c7,0xfc180375}},	//   _държ, jumf_, _âich, יקאי_, 
   {{0x27ea1257,0xf1a400fb,0x228800d7,0x00000000}},	//   lgan_, ҙрән, fúka_, --, 
   {{0x248e1258,0x66043223,0x2054b106,0x27ea1259}},	//   _them_, mehk, йтир, ogan_, 
   {{0x6605338c,0xe2c80451,0x1be400af,0xa3e00073}},	//   lehk, _مورو_, _काइल_, _दाट_, 
   {{0x2be01431,0xf1e01414,0x63ac00d7,0x00000000}},	//   _काजू_, _नाचन, ľand, --, 
   {{0x22882d95,0x27e801b9,0x660563da,0x325428e8}},	//   búka_, hgan_, nehk, _двур, 
   {{0xa114168d,0x80246449,0x27e800a2,0x00000000}},	//   _دوات, _پرام, kgan_, --, 
   {{0x4084004e,0x660401f4,0x27e80205,0xfc380022}},	//   _тузб, hehk, jgan_, рҭи_, 
   {{0x27e80656,0x66040ac5,0x3dc4007f,0x707400c6}},	//   dgan_, kehk, _tenw_, _بالذ, 
   {{0x4c640220,0x27e80014,0x66040098,0x00000000}},	//   _қиын_, egan_, jehk, --, 
   {{0x7a300112,0x27e80142,0x6604e3db,0x6e3ccc72}},	//   _kätz, fgan_, dehk, örbe, 
   {{0x27ea125a,0x6db801e4,0x00000000,0x00000000}},	//   ggan_, rĝaŭ, --, --, 
   {{0x7c26125b,0x2bb403e5,0xd6a86bcc,0x00000000}},	// [3ca20] _inir, ंडरा, ادرم_, --, 
   {{0x27e80013,0x5dd80c58,0xb54800c7,0x00000000}},	//   agan_, ব্ৰু, аҧга_, --, 
   {{0xd708013d,0x00000000,0x00000000,0x00000000}},	//   _өнне_, --, --, --, 
   {{0x2c201533,0x6ed80dba,0x53447125,0x228800d7}},	//   याएं_, _मिलु, йхла, vúka_, 
   {{0x82f411ec,0x6604003e,0x4dd00150,0x00000000}},	//   مروز_, behk, _ﻛﯘﯕﻨ, --, 
   {{0xfe66125c,0x58f4003d,0x629c0395,0x6604b8ff}},	//   _رد_, _བྱོས_, _èsol, cehk, 
   {{0x7c26125d,0x00000000,0x00000000,0x00000000}},	//   _onir, --, --, --, 
   {{0x6d5e125e,0x94a801e0,0x7c240055,0x22880162}},	//   úram, _атҡа_, _nnir, rúka_, 
   {{0xe4300050,0xc4740214,0x6e94009f,0x76900166}},	//   _تہند, _اینچ_, يلبا, gäyg, 
   {{0x27ea125f,0x7c261260,0x07340302,0x1ee80214}},	//   zgan_, _anir, צאים_, گویی_, 
   {{0x27ea1261,0x78bc0316,0x3b000263,0xae9401e1}},	//   ygan_, jprv, _apiq_, bẹnu, 
   {{0x58f4003d,0x1ee804fb,0x78bc0010,0xebc40022}},	//   _བྱེས_, دویی_, dprv, цәкн, 
   {{0x7c24005a,0x27e801b9,0xf1ac7039,0xc0ec001f}},	//   _dnir, vgan_, _चलान, ቀየር_, 
   {{0x7c261262,0x27ea1263,0x7a3001f4,0x00000000}},	//   _enir, wgan_, _käty, --, 
   {{0x27e80517,0x66040108,0x00000000,0x00000000}},	//   tgan_, vehk, --, --, 
   {{0xa7ba1264,0x7c261265,0xe7b84ae5,0x27ea1266}},	//   рлау_, _gnir, ргаш_, ugan_, 
   {{0xe7945da7,0x27ea1267,0x7a3001f4,0x66042f3b}},	// [3ca30] زارک, rgan_, _läty, tehk, 
   {{0x6b8e1268,0x27ea1269,0xa3e00316,0x31b421f6}},	//   _izag, sgan_, _दाङ_, ुरोध, 
   {{0x6606126a,0x27e8036b,0x9f4c00ae,0x00000000}},	//   rehk, pgan_, ifeá_, --, 
   {{0x2902126b,0x48c00184,0x6e240198,0xd0047aaf}},	//   _ipha_, _мәға, _ɗiba, _غل_, 
   {{0x232a126c,0x7a300036,0x6604003e,0x63ac0784}},	//   роли_, _rätz, pehk, ñanq, 
   {{0xe2981b14,0x41e400d6,0x7a303262,0x97000131}},	//   шал_, сіда, _sätz, _تېكى, 
   {{0x9f4c0332,0x00000000,0x00000000,0x00000000}},	//   dfeá_, --, --, --, 
   {{0x2902126d,0x6ad801ad,0x6b8c0166,0x28e00807}},	//   _mpha_, _भटूर, _ozag, _फिनि, 
   {{0x6b8e126e,0x644a126f,0xe9f8004d,0x7690008e}},	//   _nzag, _ilei, _quẻ_, bäyd, 
   {{0xc0c8ab7e,0x3f8000da,0x29006ca0,0x644885fa}},	//   _буде_, āju_, _opha_, _hlei, 
   {{0x644a1270,0x6b8e1271,0xd00dabf6,0x228800d2}},	//   _klei, _azag, رلی_, lúko_, 
   {{0x6b8c00ca,0x9c580124,0x00000000,0x00000000}},	//   _bzag, ршоу_, --, --, 
   {{0x2900021a,0xf4280327,0x644802d2,0x6e3c002f}},	//   _apha_, _རོལད_, _mlei, örbc, 
   {{0x58f45078,0x644a1272,0x6b8c004c,0x98a40faa}},	//   _བྱུས_, _llei, _dzag, живе, 
   {{0x644a1273,0x6b8c0323,0xd9461274,0x00000000}},	//   _olei, _ezag, цеви, --, 
   {{0x7c25f90b,0x1ae4be59,0x9f4c0139,0x00000000}},	//   _unir, _доим, leeñ_, --, 
   {{0x29000066,0x95c8036b,0x00000000,0x00000000}},	// [3ca40] _epha_, илаб_, --, --, 
   {{0x76900139,0x00000000,0x00000000,0x00000000}},	//   käye, --, --, --, 
   {{0xc8c40014,0x69c00de2,0x00000000,0x00000000}},	//   _ووٝن_, ñlee, --, --, 
   {{0x644a1275,0x63ac0784,0x31b4043e,0xc5840014}},	//   _clei, ñanp, ुर्ध, تھُم_, 
   {{0x64480036,0x38600014,0x7690005b,0x00000000}},	//   _dlei, miir_, täyd, --, 
   {{0x644a1276,0x46100014,0x3860002e,0x00000000}},	//   _elei, _ٲڈٕر, liir_, --, 
   {{0x644923ba,0xf484006c,0xfcd00092,0x11280108}},	//   _flei, _فاری, ያወጣ_, рюли_, 
   {{0x09b56da3,0x644a1277,0xefb0036b,0x7a300108}},	//   _अभ्य, _glei, ریتگ, _väty, 
   {{0x7a3000fd,0x63ac4b16,0xe708008e,0x00000000}},	//   _fätx, žanc, _möğä, --, 
   {{0x91e401b9,0x683001bf,0x38621278,0xe7080139}},	//   _фоже, _dådy, hiir_, _löğä, 
   {{0x64480664,0xac181b94,0x6b8c01d3,0x38612d5e}},	//   _ylei, бону_, _szag, kiir_, 
   {{0x61382928,0xe1643090,0x38600009,0x9f4c0332}},	//   _учур_, _عدلي, jiir_, sfeá_, 
   {{0x0b8a1279,0x3862127a,0x620000a2,0x8eb000d1}},	//   рсни_, diir_, _ýylç, _تەخت, 
   {{0x6abe127b,0x8ac401b9,0x00000000,0x00000000}},	//   rpsf, йёҳл, --, --, 
   {{0x3862127c,0xa9340114,0x00000000,0x00000000}},	//   fiir_, чевш, --, --, 
   {{0xf8040364,0x765c0cfd,0x2c200034,0x6e3a127d}},	//   мчун, _amry, याओं_, _hovb, 
   {{0x6b8e127e,0x644803b2,0xfbd0009a,0x3b540395}},	// [3ca50] _uzag, _rlei, _شتي_, _окър, 
   {{0x644802a4,0x672c0067,0xf6747cda,0x00000000}},	//   _slei, rxaj, والخ, --, 
   {{0xba7522db,0x6aac1132,0x2900014b,0x3862127f}},	//   _تايت, _huaf, _upha_, biir_, 
   {{0x58f4038f,0x6aae1280,0x6e385b47,0x672c0227}},	//   _བྱིས_, _kuaf, _lovb, pxaj, 
   {{0x644a1281,0x0698034c,0xe13802dd,0xa06800c7}},	//   _vlei, _نخست_, өзді_, ҩала_, 
   {{0x6aae1282,0x68301477,0x64480368,0x6e3a1283}},	//   _muaf, _rådy, _wlei, _novb, 
   {{0x644801ee,0x6aaca53b,0xc0c802d3,0x661401c6}},	//   _tlei, _luaf, _በቶም_, _iazk, 
   {{0x6448084c,0x661401c0,0x1ec8d7ba,0x92a80183}},	//   _ulei, _hazk, блии_, _খবৰ_, 
   {{0x63aa1284,0x66161285,0xb388001f,0x6e3801bf}},	//   _igen, _kazk, ማቸውን_, _bovb, 
   {{0x5bb4085c,0x320c0003,0x661409a8,0x3ea00267}},	//   ूर्व, _གྲྭར_, _jazk, öjt_, 
   {{0x6614006c,0x62821286,0x6aac0607,0x63aa1287}},	//   _mazk, _iklo, _auaf, _kgen, 
   {{0x66147a0c,0xa158014b,0x00000000,0x00000000}},	//   _lazk, _каҷу_, --, --, 
   {{0x63a80451,0x6aac04cc,0x6280031c,0x3f98002e}},	//   _mgen, _cuaf, _kklo, _àqu_, 
   {{0x3ebc4aa5,0x25fc03f8,0x6aadc66e,0x6614009d}},	//   mput_, र्मी_, _duaf, _nazk, 
   {{0x63aa1288,0x6280e161,0x3ebc30b5,0x38621289}},	//   _ogen, _mklo, lput_, tiir_, 
   {{0x63a84b26,0x6aac096b,0x1be400c5,0x00000000}},	//   _ngen, _fuaf, _काटल_, --, 
   {{0x3ebe128a,0x38600050,0x661405f5,0x6aac05d5}},	// [3ca60] nput_, riir_, _bazk, _guaf, 
   {{0x386001d9,0xda080035,0x00000000,0x00000000}},	//   siir_, _ايده_, --, --, 
   {{0x2c200574,0xe9f8001e,0xd824048a,0x6614005a}},	//   याचं_, _huế_, _едни, _dazk, 
   {{0x63a80077,0x6282128b,0x6d5c007b,0x9f5e128c}},	//   _cgen, _aklo, úrai, _jawó_, 
   {{0x3ebc3733,0xdb140793,0x93788b29,0x848402d3}},	//   jput_, _neyü, حصار_, _ዝኣምን_, 
   {{0x63aa128d,0x765c00ca,0x9f5c01e1,0x3ebc01bf}},	//   _egen, _umry, _lawó_, dput_, 
   {{0x2bec0574,0x63a80175,0x63ac73d5,0x00000000}},	//   _झालं_, _fgen, žana, --, 
   {{0x63a80083,0x6280010f,0x6e38016d,0x9f5c0241}},	//   _ggen, _eklo, _sovb, _nawó_, 
   {{0x62801132,0x1be41889,0x60cc0227,0x6e38014f}},	//   _fklo, _काजल_, ņamp, _povb, 
   {{0x62800076,0x00000000,0x00000000,0x00000000}},	//   _gklo, --, --, --, 
   {{0xc04c10f5,0x6aac096b,0x41b80302,0x7d00020b}},	//   _зі_, _suaf, _הצבע, _cpns, 
   {{0xf0450d73,0x6e380455,0x00000000,0x00000000}},	//   _تعطی, _wovb, --, --, 
   {{0x6aae128e,0x6e38be97,0x25fc0401,0xf1d0012d}},	//   _quaf, _tovb, र्डी_, _सजान, 
   {{0x58f4031c,0x7ae001d3,0xa2c001ad,0x00000000}},	//   _བྱངས_, ámta, रीट्, --, 
   {{0x66140fb7,0x8ca4033f,0x28b000d1,0x00000000}},	//   _razk, _घंटो, _ﻳﺎﺷﻠ, --, 
   {{0x6aac04c9,0x66140118,0x00000000,0x00000000}},	//   _tuaf, _sazk, --, --, 
   {{0xb8f41889,0x6614009d,0xcbc0102f,0xaa88007b}},	// [3ca70] _सौ_, _pazk, _व्यञ, _ونعم_, 
   {{0x9f9c06ed,0x2cbc0165,0x63a80042,0x00000000}},	//   lção_, _ktvd_, _sgen, --, 
   {{0x661406be,0x792400c0,0x00000000,0x00000000}},	//   _vazk, _зьяж, --, --, 
   {{0x9f9c0cfc,0x27ed706a,0x66140139,0x66b401f4}},	//   nção_, _øen_, _wazk, _обму, 
   {{0x6616128f,0x9f9c0261,0xc7640046,0x00000000}},	//   _tazk, ição_, _راحى, --, 
   {{0xb374158b,0x78f80244,0x00000000,0x00000000}},	//   ردنش, _بعیس_, --, --, 
   {{0x25fc0574,0x628009a8,0x63aa1290,0x3ebc01f5}},	//   र्णी_, _vklo, _tgen, wput_, 
   {{0x63a9fdea,0x78b801ed,0xf994008f,0x00000000}},	//   _ugen, _évve, ערק_, --, 
   {{0x3ebc013c,0x9f5c01e1,0xc340010a,0x7690008e}},	//   uput_, _rawó_, _чĕп_, läya, 
   {{0x3ebc0680,0x62800bb8,0x9f5c01e1,0x0e600137}},	//   rput_, _uklo, _bawò_, ккын, 
   {{0x386002d3,0x9f5c0248,0x26d800c0,0x2ba40171}},	//   _ተወሊዱ_, _pawó_, _lvso_, _līcī_, 
   {{0x3ebc32ff,0x25fc2052,0xd9c405f9,0xe504000d}},	//   pput_, र्ती_, वर्ट, _रहनि_, 
   {{0x3ebc0d04,0xa2c00490,0xe9f801fb,0x6b88033f}},	//   qput_, रीच्, _quế_, żegn, 
   {{0x9f9c03b7,0x76921291,0x84fc00bc,0x00000000}},	//   ação_, käya, ैबाट_, --, 
   {{0x3ea40fec,0x3eac022c,0xfeb80244,0x00000000}},	//   _iint_, _hugt_, _ئاڵت_, --, 
   {{0x9f9c0261,0xe9f80208,0x68e00bcd,0xddc00064}},	//   cção_, _tuế_, álda, kilū, 
   {{0x999800b0,0x3ea61292,0x00000000,0x00000000}},	// [3ca80] _kopū_, _kint_, --, --, 
   {{0x3eac00ee,0x00000000,0x00000000,0x00000000}},	//   _mugt_, --, --, --, 
   {{0x3ea43945,0x25fc8bb7,0x3eac00b5,0xf200033f}},	//   _mint_, र्धी_, _lugt_, ल्फ़_, 
   {{0x3ea61293,0x59c40a59,0xd9ec0037,0x00000000}},	//   _lint_, वरकर, _जाँत_, --, 
   {{0x16a0035b,0x00000000,0x00000000,0x00000000}},	//   _аҳаҭ, --, --, --, 
   {{0x25fc0d2c,0xda0d01e5,0xf19407d8,0x07a16aa8}},	//   र्दी_, ाजित_, ниль, _шаян, 
   {{0x3eac00de,0x00000000,0x00000000,0x00000000}},	//   _augt_, --, --, --, 
   {{0x8f4463d5,0x3ea41570,0x3eaca945,0xddc00024}},	//   дход, _aint_, _bugt_, bilū, 
   {{0x3ea61294,0xda0c0490,0xadd40114,0x00000000}},	//   _bint_, ाजात_, нопљ, --, 
   {{0x9f5c007f,0x00000000,0x00000000,0x00000000}},	//   _pawò_, --, --, --, 
   {{0x3ea61295,0xac197c2b,0x7e7001c6,0x7ec001e1}},	//   _dint_, пону_, тгэх, _pípò, 
   {{0x3eac00b5,0x3ea403b2,0xac1802bf,0xcf440276}},	//   _fugt_, _eint_, чому_, _оней, 
   {{0x9f9c0261,0xbb94023a,0xae6800db,0xd8c401ec}},	//   rção_, кающ, _ىشتە_, _ﺩﺨﻭﻟ, 
   {{0x3ea4002d,0x33bc0131,0xfe421296,0x00000000}},	//   _gint_, _ﺧﯩﺰﻣ, _инчо, --, 
   {{0x9f9c0261,0xfd0c1b45,0x290406af,0x02a800bc}},	//   pção_, _نجي_, ïla_, _चढ्न, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x672801fa,0x3ea401e2,0x36d40c17,0x7b146219}},	// [3ca90] _šejb, _yint_, котр, _адых, 
   {{0x2caa1297,0x00000000,0x00000000,0x00000000}},	//   _hiad_, --, --, --, 
   {{0x69d61298,0x2ca803a2,0x67d41b6b,0xda640451}},	//   maze, _kiad_, _пону, _ساٿي, 
   {{0x2ca80098,0xe2f80220,0x63ac0419,0x00000000}},	//   _jiad_, зеді_, ľano, --, 
   {{0xba74ae59,0x2288043b,0x2ca800a3,0xa2e4dddf}},	//   _سایت, lúki_, _miad_, холд, 
   {{0x2caa1299,0x76900309,0x6e3c007c,0x00000000}},	//   _liad_, päya, örbl, --, 
   {{0x3ea6129a,0x999800b0,0x02cc185d,0x00000000}},	//   _rint_, _ropū_, _सौरभ, --, 
   {{0x3ea60154,0x69d6129b,0x2ca80218,0xe2f800d4}},	//   _sint_, haze, _niad_, _небі_, 
   {{0x69d6129c,0xdb1409cc,0x9f06129d,0x3ea42517}},	//   kaze, _neyð, رودو, _pint_, 
   {{0x69d6129e,0xd9ec007d,0x3eac34b9,0x2ca80037}},	//   jaze, _जाइत_, _vugt_, _aiad_, 
   {{0x69d4090c,0x7690adae,0x9d4401af,0x61550b6a}},	//   daze, käyn, хенд, _ثنائ, 
   {{0x3ea6129f,0x2ca80e89,0x63b80007,0x3eac03b2}},	//   _wint_, _ciad_, ncwn, _tugt_, 
   {{0x3ea41c1d,0x9f540598,0x69d468ba,0x5f280a89}},	//   _tint_, ägän_, faze, _холм_, 
   {{0x69d612a0,0xdb140579,0x200c01c0,0x63b80007}},	//   gaze, _deyð, leei_, hcwn, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x63b80007,0x16001f13,0x25fc1df1,0x200e12a1}},	//   jcwn, र्नर_, र्सी_, neei_, 
   {{0x69d40928,0xe3e40f22,0x109000d1,0xd6d0007b}},	// [3caa0] baze, নভাব, _ﯞﻩﺯﯨ, اقط_, 
   {{0x69d4d059,0x200c0093,0x959801ec,0xc5e000eb}},	//   caze, heei_, птеу_, ন্সপ, 
   {{0x200c005a,0xd4040108,0x00000000,0x00000000}},	//   keei_, еяли, --, --, 
   {{0x63b80369,0x76900139,0x9fb4013a,0x00000000}},	//   gcwn, cäyn, fřík_, --, 
   {{0x200c01c0,0x838212a2,0x25fc000d,0xe50400c5}},	//   deei_, лыше, र्ही_, _रहथि_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x95c800ee,0xd9ec0037,0x0fe07c3f,0x00000000}},	//   _муңа_, _जाईत_, гөлү, --, 
   {{0x69d612a3,0x649013ce,0x200c01c4,0x25a41941}},	//   zaze, låin, geei_, _úlla_, 
   {{0x25fd1901,0xa49004d3,0x69d612a4,0x2caa12a5}},	//   र्वी_, _ئینت, yaze, _riad_, 
   {{0x2ca80491,0x28e0b340,0xdb140436,0x649005ac}},	//   _siad_, _फिलि, _reyð, nåin, 
   {{0xdb1408a7,0x8274008f,0x200c009d,0x69d51308}},	//   _seyð, _טעמע_, beei_, vaze, 
   {{0x69d407ab,0x321c01e3,0x00000000,0x00000000}},	//   waze, ldvy_, --, --, 
   {{0xfe6c932b,0x39580175,0xef10004e,0x69c400cf}},	//   شدی_, ezrs_, _түпө, көнб, 
   {{0x63ad4692,0x629c011c,0x16001d8a,0x63b80399}},	//   ñanz, _èsot, र्मर_, zcwn, 
   {{0x69d612a6,0x67d4276f,0x2ca80165,0x00000000}},	//   raze, кову, _tiad_, --, 
   {{0x69d612a7,0x22880162,0x00000000,0x00000000}},	//   saze, rúki_, --, --, 
   {{0x8aa43580,0x160011b1,0x69d406ed,0xf77000c6}},	// [3cab0] _прод, र्भर_, paze, ماك_, 
   {{0xb71400c9,0x64900217,0x200c005a,0xd9ec00c5}},	//   ыдущ, gåin, zeei_, _जाएत_, 
   {{0x09bc08a3,0x33240175,0x24180212,0x25fc29d7}},	//   ्रीय, _armx_, ділю_, र्षी_, 
   {{0x9fb4012c,0xd6d8013e,0x200c01c4,0x6e3c007c}},	//   třík_, ятӣ_, xeei_, örbj, 
   {{0x225a12a8,0x68e0000f,0x7bdc00df,0x766801e2}},	//   миды_, âldf, לקאו, _ګیلې_, 
   {{0x98bc0006,0x6d10000d,0xa188009b,0x00000000}},	//   štą_, ़बाग_, мбла_, --, 
   {{0x200c009d,0x2eb401ec,0xa4d4003b,0x00000000}},	//   teei_, қсыс, _шові, --, 
   {{0xf48431ee,0x25fc01ad,0x71241f7e,0x00000000}},	//   _буун, र्री_, ارول, --, 
   {{0x443cb1c5,0x1e952eab,0x200c5c71,0x6ed4009d}},	//   _iou_, крор, reei_, лцэх, 
   {{0x443e12a9,0x200c005a,0x338402d5,0xafc400db}},	//   _hou_, seei_, _сусв, _ەينى, 
   {{0xc1000372,0x76900139,0x9f04277d,0x00000000}},	//   _сүйл, däyl, روگو, --, 
   {{0x443e12aa,0x2d945e18,0x38c801ed,0x00000000}},	//   _jou_, ырыс, ہاری_, --, 
   {{0x443c0924,0x629c011c,0xfa8406b3,0xd0240150}},	//   _mou_, _èsos, лқим, _جونۋ, 
   {{0x443e12ab,0x1a64030f,0x76900139,0x00000000}},	//   _lou_, ئیدی_, gäyl, --, 
   {{0x443d189c,0x00000000,0x00000000,0x00000000}},	//   _oou_, --, --, --, 
   {{0x443cc79a,0x98bc510c,0x00000000,0x00000000}},	//   _nou_, çtı_, --, --, 
   {{0x649003d4,0x228800d7,0x00000000,0x00000000}},	// [3cac0] tåin, lúku_, --, --, 
   {{0x443e12ac,0x61e00472,0x25fc47b8,0x00000000}},	//   _aou_, _ndll, र्ली_, --, 
   {{0x443e12ad,0x17c8005b,0xa504035b,0x00000000}},	//   _bou_, _огни_, лҵра_, --, 
   {{0x443e12ae,0x9998033b,0x0d38010f,0x2c0400cd}},	//   _cou_, _rapň_, וגעב, ष्पं_, 
   {{0x443e12af,0x60c00083,0x61e00175,0x25fc01ad}},	//   _dou_, _atlm, _bdll, _रॉकी_, 
   {{0xfe640611,0x443c0036,0x68e0002d,0x910401d5}},	//   _ضد_, _eou_, âldg, вчид, 
   {{0x50643306,0x443e12b0,0xd46809f7,0x60c00175}},	//   َابِ, _fou_, _живе_, _ctlm, 
   {{0x443e12b1,0x1cc00156,0x228800d2,0x301612b2}},	//   _gou_, གེན_, dúku_, удир, 
   {{0x03a090b1,0xe05401b9,0x80a000ec,0xe4740139}},	//   _вито, دینت_, جمين, _сурэ, 
   {{0x443e12b3,0xd9ec069f,0xc0ec001f,0x90c400c7}},	//   _zou_, _जागत_, ቀረም_, _абже, 
   {{0x443c3d99,0x0fe01586,0xc5f00375,0x7690023a}},	//   _you_, _көпү, בדת_, väyl, 
   {{0x98a802d5,0x443c00db,0x7e6003ac,0x8eb000db}},	//   mybė_, _xou_, _emnp, _پەدت, 
   {{0x0ba9236f,0x7b6612b4,0x98a80024,0x7f8000f1}},	//   بادى_, атре, lybė_, _پلون, 
   {{0x09bc39c5,0x6a14010b,0x228800d7,0x00000000}},	//   ्रेय, ымгу, búku_, --, 
   {{0x98a80024,0x2b4cba81,0x00000000,0x00000000}},	//   nybė_, šec_, --, --, 
   {{0xe7d00154,0x6d4a12b5,0x00000000,0x00000000}},	//   িল্য, myda, --, --, 
   {{0x443e12b6,0x63ac8841,0x6d4a12b7,0xe698180b}},	// [3cad0] _rou_, žank, lyda, еваш_, 
   {{0x443e12b8,0xf77212b9,0x6b8c0a81,0x98a80006}},	//   _sou_, زاق_, _iyag, kybė_, 
   {{0x443c21a5,0x6d4a12ba,0x68e0000f,0x6b8c002b}},	//   _pou_, nyda, âldd, _hyag, 
   {{0x443c0481,0x6b8e12bb,0x98a800c0,0x88800345}},	//   _qou_, _kyag, dybė_, _ئیرن, 
   {{0x443e12bc,0xd1d00020,0x386c0494,0x045401d5}},	//   _vou_, ረጉት_, èdre_, _یئرد, 
   {{0x443e12bd,0x6b8c0083,0x6d488ed1,0x27f80208}},	//   _wou_, _myag, kyda, _hcsn_, 
   {{0x443c45b4,0x81a800bd,0x6b8c0337,0x98a80024}},	//   _tou_, কুন_, _lyag, gybė_, 
   {{0x6d484157,0x6b8e12be,0x2c0400cd,0x00000000}},	//   dyda, _oyag, ष्मं_, --, 
   {{0x6b8e12bf,0x6d48058a,0xdfd01075,0x5dd40064}},	//   _nyag, eyda, _ۇيا_, люну, 
   {{0xc0c8084c,0x91c8033f,0x6d4881f0,0xbef0012d}},	//   _жуде_, _स्पै, fyda, _आमीन_, 
   {{0x6b8e12c0,0xdfd0092f,0x6d4a12c1,0x60c00419}},	//   _ayag, _هيا_, gyda, _utlm, 
   {{0x6b8e12c2,0x6728025c,0xe73000ee,0x228800e4}},	//   _byag, _ġejn, _söýü, rúku_, 
   {{0xdee612c3,0x6b8c0796,0x5ff40022,0x00000000}},	//   _соли, _cyag, _азҵу, --, 
   {{0x201e12c4,0x6b8c02e2,0x6d4a12c5,0x00000000}},	//   _hawi_, _dyag, byda, --, 
   {{0x201e12c6,0x2d940801,0x6b8c0a49,0x6d48a787}},	//   _kawi_, _кръс, _eyag, cyda, 
   {{0x201c0502,0x1a6401d3,0x34e0012d,0x91c8012d}},	//   _jawi_, ئیگی_, _पटौद, _स्नै, 
   {{0x29041395,0x6b8c0097,0x201ce88c,0x5ba800d6}},	// [3cae0] çlar_, _gyag, _mawi_, _яким_, 
   {{0x2d6c0134,0x201d791b,0x2c0400dc,0x769001f4}},	//   _yɛe_, _lawi_, ष्ठं_, mäyk, 
   {{0xd94612c7,0x13e80262,0x779400f2,0x380401f0}},	//   _сени, емей_, _چیزا, _конҳ, 
   {{0x201c0a2e,0x68e00a85,0x98a80024,0x779403e6}},	//   _nawi_, âlde, vybė_, _نیزا, 
   {{0x6d480034,0x81a80eac,0x91e001e0,0x7f580175}},	//   zyda, কুম_, йҙаһ, jzuq, 
   {{0x98a80006,0x00000000,0x00000000,0x00000000}},	//   tybė_, --, --, --, 
   {{0x6d4a12c8,0x6600002f,0x201e12c9,0x00000000}},	//   xyda, _ölka, _bawi_, --, 
   {{0x201c0a73,0x6d490be8,0x649800c7,0x7690023a}},	//   _cawi_, vyda, _атур_, käyk, 
   {{0x2d6c016b,0x201c0978,0x6d480368,0x98a80153}},	//   _sɛe_, _dawi_, wyda, sybė_, 
   {{0x6d4a12ca,0x6b8c01b2,0xc18001d9,0x43646f86}},	//   tyda, _ryag, _گۯى۪, _саун_, 
   {{0x81a8045e,0x6b8c003a,0xc0fc004d,0x00e401b9}},	//   কুব_, _syag, _mướt_, _متنی, 
   {{0x6d4a12cb,0x201cca60,0x09bc4c83,0xc0fc001e}},	//   ryda, _gawi_, ्र्य, _lướt_, 
   {{0x6d4a12cc,0x67280327,0xabb400c7,0xaa940108}},	//   syda, _ġejo, лаҟә, иимч, 
   {{0xc984228e,0x6b8c5975,0xe5040037,0x00000000}},	//   губи, _vyag, _रहलि_, --, 
   {{0x201c2819,0x1ea876e1,0x63ac00d0,0xac9612cd}},	//   _yawi_, _شاهي_, ľani, _какш, 
   {{0x6b8e12ce,0x7690081d,0x00000000,0x00000000}},	//   _tyag, läyh, --, --, 
   {{0xed90069c,0x6b8c4ec2,0x28e000c5,0x68e0045f}},	// [3caf0] _ማሕበር_, _uyag, _फिकि, âldb, 
   {{0xc6a612cf,0xc4440066,0x00000000,0x00000000}},	//   урби, گیرن_, --, --, 
   {{0x6f04054e,0xe894ce59,0x00000000,0x00000000}},	//   _ţicl, _вань, --, --, 
   {{0xf4841149,0x00000000,0x00000000,0x00000000}},	//   бучн, --, --, --, 
   {{0x201dc6b5,0x83659170,0x7088044e,0x041404c5}},	//   _rawi_, ددال, _ምህላዉ_, ণালী_, 
   {{0x2168baa7,0x201c46a3,0x61440032,0xe2981f5a}},	//   кили_, _sawi_, иела, њак_, 
   {{0x20547e81,0x201cbf25,0x26c800d8,0x25a41bce}},	//   итир, _pawi_, lpao_, _àll_, 
   {{0xa3e800dc,0x201c0009,0xd8700051,0x00000000}},	//   _मयि_, _qawi_, ếtvề_, --, 
   {{0xe730010e,0xdee400d8,0xb3880092,0x00000000}},	//   _köñü, шопи, ዛቸውን_, --, 
   {{0x201cb5f6,0x399c0248,0x9e6450da,0x6458047e}},	//   _wawi_, _jásí_, рвод, lhwi, 
   {{0xa1143595,0xa3e80a28,0x201e12d0,0x672805be}},	//   _خوات, _मया_, _tawi_, _šejl, 
   {{0x64580564,0x26c83743,0xdc6801c6,0x399c02d2}},	//   nhwi, kpao_, тамд_, _lásí_, 
   {{0x30840597,0x5438008f,0xdee40114,0x00000000}},	//   _النف, דערא, _ђоки, --, 
   {{0x7690005b,0x00000000,0x00000000,0x00000000}},	//   räyk, --, --, --, 
   {{0x645881b3,0x7690005b,0x18681d39,0xdc740108}},	//   khwi, säyk, вави_, _выпь, 
   {{0x97c41eeb,0xc0fc0051,0x769001f4,0x00000000}},	//   شترم, _sướt_, päyk, --, 
   {{0x64580014,0x00000000,0x00000000,0x00000000}},	// [3cb00] dhwi, --, --, --, 
   {{0x3f8c0042,0x00000000,0x00000000,0x00000000}},	//   _mygu_, --, --, --, 
   {{0x81a803d4,0x3f8c0064,0x00000000,0x00000000}},	//   কুত_, _lygu_, --, --, 
   {{0x6458016d,0x99980165,0x534401c6,0x00000000}},	//   ghwi, _japō_, ихла, --, 
   {{0x78a612d1,0x59d8515b,0x38bc01ed,0x764400c7}},	//   mmiv, _बजार, _hír_, _лҭаа, 
   {{0x78a425e4,0x4204010a,0x15b800db,0xd5e801e1}},	//   lmiv, инчо_, _шымы_, _òǹs, 
   {{0x3f8c0009,0x78a40254,0x84e0026b,0xd1740166}},	//   _aygu_, omiv, _морж, шыды, 
   {{0x645a12d2,0x38be12d3,0x999800b0,0x80a00691}},	//   chwi, _mír_, _napō_, يمون, 
   {{0x25fc089a,0x0dca12d4,0x52a80131,0x78a40022}},	//   र्की_, куни_, _авам_, imiv, 
   {{0x38be12d5,0x5274094e,0xa0880220,0x98bc0118}},	//   _oír_, _тубу, ксөз_, átě_, 
   {{0x2d9800cc,0x45b4008f,0x3f8c06ea,0xc04c1ac3}},	//   åre_, יפיל_, _eygu_, _ді_, 
   {{0x98bc038e,0x3f8c0042,0x00000000,0x00000000}},	//   ště_, _fygu_, --, --, 
   {{0x38bc0142,0x8fa40452,0x00000000,0x00000000}},	//   _aír_, _таде, --, --, 
   {{0x3b00025c,0xbea00006,0x6db4519b,0x6458030a}},	//   _dqiq_, _дачк, _уйку, zhwi, 
   {{0x6e3c049f,0x3f000327,0xc7b800c0,0x2d9800e5}},	//   örbu, _མདོའ_, вёз_, üred_, 
   {{0x645800f1,0x4900004e,0x00000000,0x00000000}},	//   xhwi, бүүг, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3cb10] --, --, --, --, 
   {{0xa3c80490,0x38bc0332,0x16001025,0xde340092}},	//   लुन_, _fír_, र्लर_, _እወዳለ, 
   {{0x26c808ad,0x25fc04fa,0x38bc08a5,0xd00400e5}},	//   spao_, र्गी_, _gír_, _ٹل_, 
   {{0xe3540323,0x68f4fccc,0x29000477,0xf1b8031c}},	//   йтлэ, muzd, _iqha_, _raġa_, 
   {{0x6600002f,0xc6a40a5b,0x00000000,0x00000000}},	//   _ölko, _врви, --, --, 
   {{0x25fc00ab,0x36d4005a,0x00000000,0x00000000}},	//   र्खी_, _форр, --, --, 
   {{0x999800da,0x68f5487f,0xa188005b,0xc444179e}},	//   _kopš_, nuzd, ыбка_, _پیشن_, 
   {{0x6728003d,0x64580fec,0x00000000,0x00000000}},	//   _ġejj, qhwi, --, --, 
   {{0x9998007f,0x248c013a,0x9e641436,0x00000000}},	//   _rapō_, _ikem_, йвид, --, 
   {{0x98c405a1,0x3b000327,0x00000000,0x00000000}},	//   _žuči_, _rqiq_, --, --, 
   {{0x29000218,0x00000000,0x00000000,0x00000000}},	//   _nqha_, --, --, --, 
   {{0x2244a46e,0x2098010b,0x5c5400d8,0x28e0098a}},	//   _holk_, _ёкды_, стоф, _फिजि, 
   {{0x68f40369,0x22440427,0x85680023,0xdca404a9}},	//   euzd, _kolk_, _ተኸፊቱ_, _һаки, 
   {{0xd9442de0,0x53980a1e,0x6d5c08c2,0xceb000df}},	//   беги, טירו, ùrac, _זיג_, 
   {{0xdca43b2e,0x2244a3e1,0x5ca4da2d,0x248e12d6}},	//   _лаки, _molk_, _ликб, _okem_, 
   {{0x248c01f2,0x99980270,0xa3c8098a,0x8d900769}},	//   _nkem_, _uapō_, लुम_, _عليش, 
   {{0x78a612d7,0xd3c41ee2,0xc7a0b4d8,0x290025de}},	// [3cb20] rmiv, ەتتى, зитк, _eqha_, 
   {{0xcf9004ac,0x38bc0597,0x78a612d8,0x7ae612d9}},	//   לטן_, _tír_, smiv, _ivit, 
   {{0x7ae400d6,0x18691535,0x7690005b,0x39500356}},	//   _hvit, _бани_, käyv, ânsă_, 
   {{0x981427e9,0xdc900020,0x7ae612da,0x248c0208}},	//   _ابدا, _ማኅበረ_, _kvit, _ckem_, 
   {{0x224612db,0x00000000,0x00000000,0x00000000}},	//   _bolk_, --, --, --, 
   {{0x941403be,0x46a000d6,0x7ae612dc,0xc7a00798}},	//   _əgər_, _наяв, _mvit, _ѕирк, 
   {{0x7bc4067c,0x00000000,0x00000000,0x00000000}},	//   _ofiu, --, --, --, 
   {{0xc5600eed,0x9205120a,0x8cd0c8bf,0x7ae409a8}},	//   _экск, _گذرن, _भौगो, _ovit, 
   {{0x2245cbda,0x1b0c03d4,0x91e40209,0x68f416a3}},	//   _folk_, িয়তে_, _гозе, zuzd, 
   {{0x7bc612dd,0xc0d0001f,0x41cc3be5,0xe24400ae}},	//   _afiu, _ረጅም_, _स्पस, _وخلي, 
   {{0x25fc11b1,0x63ad3160,0x515401ee,0x00000000}},	//   र्टी_, žant, _утау, --, 
   {{0x68f612de,0xf9f40327,0xab94cea4,0x00000000}},	//   vuzd, _བཐུན_, жимі, --, 
   {{0x7ae428b5,0x3f6402f6,0xe08400ec,0x2244045a}},	//   _cvit, _лицо_, _بجلي, _yolk_, 
   {{0x7ae40882,0x60e00139,0x693612df,0x21980150}},	//   _dvit, _äymä, онгу, _ﺘﻭﻅﻴ_, 
   {{0x07e56993,0xa2940023,0x827400df,0x41b800df}},	//   йцам, ግብኦን_, צעלע_, רצלע, 
   {{0x2d9c0427,0x47840137,0x68f45d1d,0x00000000}},	//   _izve_, бызб, ruzd, --, 
   {{0x248c0166,0x651400ec,0x00000000,0x00000000}},	// [3cb30] _rkem_, ڪوائ, --, --, 
   {{0xd70800d1,0x98bc0356,0x248c0200,0x85a40063}},	//   شىمۇ_, âtă_, _skem_, бјед, 
   {{0x7ae405b8,0x69c40327,0xf65000db,0x00000000}},	//   _zvit, _ifhe, رئك_, --, 
   {{0x25fc0c5a,0x3cf800c8,0x320c010b,0xdb2407d6}},	//   र्जी_, רלאנ, _abdy_, _اویی, 
   {{0x6f0400c7,0x2244045a,0xa2e4c184,0x00000000}},	//   _ãich, _polk_, цолд, --, 
   {{0x2d9c0306,0xa228005b,0xa4d40006,0xb6040024}},	//   _ozve_, ржка_, _могі, _няск, 
   {{0x224612e0,0x6728b0e8,0xd24c215c,0xe2c8c530}},	//   _volk_, _šejh, ئنى_, _چورو_, 
   {{0xe2c8021a,0x22441a78,0x9f4c0e2d,0xdcf400e2}},	//   _نورو_, _wolk_, ngeç_, ūcīg, 
   {{0x9e7802d3,0x5ea405d9,0x91c83abc,0x5f44036b}},	//   _ይብለና_, يمبل, _स्वै, زندل, 
   {{0x7bc40268,0x25fc0141,0x76900139,0x00000000}},	//   _sfiu, र्ची_, bäyu, --, 
   {{0x1d082e58,0x9d440395,0x00000000,0x00000000}},	//   шени_, ценд, --, --, 
   {{0x69c612e1,0x7690081d,0x78b80158,0x6e3cccbf}},	//   _afhe, läyt, _évvi, örbr, 
   {{0x69c40332,0x68e0000f,0x00000000,0x00000000}},	//   _bfhe, âldn, --, --, 
   {{0x76900723,0x9e780023,0xdb1c01e1,0x00000000}},	//   näyt, _ይብሉና_, _òyír, --, 
   {{0xd82407d8,0x81a800bd,0xceb008a8,0xaf3400db}},	//   одви, কুর_, _קיו_, _ورۇت, 
   {{0x7ae612e2,0xe7cc04a2,0x7bc47eb8,0x28b8084c}},	//   _tvit, _ﺑﯩﺮﻟ, _ufiu, сурэ_, 
   {{0x7c24c1c2,0x7690049b,0x7ae433b8,0x7ba800fe}},	// [3cb40] _iair, käyt, _uvit, _ক্ৰো, 
   {{0x7c2487c4,0x20e400b0,0x7690023a,0x75b80107}},	//   _hair, kēi_, jäyt, стаӣ_, 
   {{0xaac4158b,0x14244130,0x69b800cd,0x00000000}},	//   _وتین, ждем, ्डरी, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7c2612e3,0x0364586a,0x3ebc014f,0x6d5c02f0}},	//   _mair, оицк_, jqut_, úraz, 
   {{0xa90485d4,0x7c240c3a,0x7760001f,0x981401d5}},	//   _ببین, _lair, _ለመሳተ, _ابگا, 
   {{0x6b5001e1,0x67280327,0xf40c00fe,0x550c000d}},	//   _kógú, _ġeji, _সোণৰ_, _सहिए_, 
   {{0xf4840b28,0x6b5008a5,0x672800de,0x00000000}},	//   _رازی, _jógú, _šeji, --, 
   {{0x81a811ba,0x6b500241,0x23b000db,0xe4680108}},	//   কুল_, _mógú, _كۅمس, _ушёл_, 
   {{0x9f4c05d1,0xe7300037,0x6b500ca8,0x0734011a}},	//   zgeç_, _tööü, _lógú, קאים_, 
   {{0x7c2612e4,0x3ebc011f,0x62200228,0xac940150}},	//   _bair, aqut_, _سۉيل, занш, 
   {{0x7c2612e5,0x2ff402dd,0xb3280327,0xebc4013d}},	//   _cair, _ءتاڭ, _རློང_, чәкн, 
   {{0x7c2612e6,0x2e8800ee,0x69b892c1,0x8b64280f}},	//   _dair, _гөни_, ्डली, زاحم, 
   {{0xfe6c00c6,0x7c241523,0x88dc02f5,0x68e0045f}},	//   _لدى_, _eair, বংসক, âldo, 
   {{0x7c2612e7,0x6b5001e1,0xefb001b9,0x00000000}},	//   _fair, _bógú, _تیکگ, --, 
   {{0x7c2612e8,0x7690005b,0xa7b80bd6,0x00000000}},	//   _gair, käys, слау_, --, 
   {{0x6b500ca8,0xf770240f,0x76900108,0x2bd00b6d}},	// [3cb50] _dógú, ناك_, jäys, _थ्या, 
   {{0x7c2612e9,0x68e0066a,0x7c84001f,0x3a740166}},	//   _zair, álds, ነገረው_, _олыр, 
   {{0x7c2612ea,0x04000154,0x76900108,0x00000000}},	//   _yair, _রোগী_, väyt, --, 
   {{0xd5ac01d3,0x7d78011a,0x00000000,0x00000000}},	//   اہِ_, סנאו, --, --, 
   {{0x769002f6,0x23281086,0xf2c400fb,0xa29400d4}},	//   täyt, соли_, үсән, паді, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa3d40640,0x7690248c,0x00000000,0x00000000}},	//   _новч, räyt, --, --, 
   {{0x397c10df,0x769008b9,0xb97c0375,0xf48400cf}},	//   יטונ, säyt, ינוי, _жуун, 
   {{0x7c2612eb,0x64481140,0x335800a8,0xd00c01ed}},	//   _rair, _ioei, _датэ_, ھلی_, 
   {{0x7c2612ec,0x644801f5,0xd9d87aec,0x00000000}},	//   _sair, _hoei, _बजेट, --, 
   {{0x7c2612ed,0x64481af3,0x68e0000f,0xdfb40798}},	//   _pair, _koei, âldl, _ебењ, 
   {{0xafc40220,0xf1a400db,0x00000000,0x00000000}},	//   _قيمى, _црун, --, --, 
   {{0x7c244115,0x64487890,0x3ebc20ac,0xfc380092}},	//   _vair, _moei, qqut_, _እየፈለ, 
   {{0x7c240325,0x64480489,0x8518012c,0x38c807d6}},	//   _wair, _loei, नबाट_, قاری_, 
   {{0x7c2612ee,0xd9443db7,0x98a413d6,0x76900108}},	//   _tair, чеви, зиве, käyr, 
   {{0x7c2435b8,0x6448003e,0xf7880213,0x769001f4}},	//   _uair, _noei, _heçə_, jäyr, 
   {{0xf78803e3,0x69c003e0,0x00000000,0x00000000}},	// [3cb60] _keçə_, ıler, --, --, 
   {{0xd9d0ba84,0xa3c87c33,0x76900108,0x00000000}},	//   _سەرگ, लुस_, väys, --, 
   {{0x6b5001e1,0x00000000,0x00000000,0x00000000}},	//   _tógú, --, --, --, 
   {{0xb3281b4b,0x64483756,0xd32402bf,0xd7c812ea}},	//   _རླུང_, _coei, зьки, _دوحه_, 
   {{0x38601552,0x644801f5,0x845000db,0x00000000}},	//   mhir_, _doei, رۉكچ, --, 
   {{0xf78803be,0x7690023a,0x3860068c,0xf1940958}},	//   _neçə_, räys, lhir_, миль, 
   {{0xf4844354,0x46a00075,0x6448017a,0x765c01e1}},	//   _قاری, _чарв, _foei, _ilry, 
   {{0xdb14066d,0x644a12ef,0x50641751,0x2a700083}},	//   _egyé, _goei, ятла, zizb_, 
   {{0xa4104952,0x38600198,0x59bc012c,0xc68c0014}},	//   lığı_, ihir_, ्डार, _شِہ_, 
   {{0x644800d8,0x8d84094f,0x91e4004e,0x0320004e}},	//   _zoei, зумд, _хоже, _ядун, 
   {{0x386015a5,0xac1800f7,0xd9e0009e,0xa4100342}},	//   khir_, оону_, বলাম, nığı_, 
   {{0x6ab45345,0x00b80302,0x68e0002d,0x00000000}},	//   ंद्र, _המאמ, âldm, --, 
   {{0x386212f0,0xcfa8015b,0x0a280023,0x40a800f1}},	//   dhir_, _গ্রন, _ብምርካ, _اخلی_, 
   {{0xab0400b8,0x2d5a12f1,0xa4100205,0x00000000}},	//   _auṣṇ, _миль_, kığı_, --, 
   {{0x2904025a,0x38604a43,0x2ba400b8,0x7e98011a}},	//   îla_, fhir_, _sūcī_, _הסגו, 
   {{0xa4100baf,0x386212f2,0x32000198,0x00000000}},	//   dığı_, ghir_, ɗiye_, --, 
   {{0x6449cd4b,0x06b43a25,0xf4f00150,0x6e3801f5}},	// [3cb70] _roei, سناک_, _ءﺟﻮﻧ, _knvb, 
   {{0x386056f2,0x64480072,0x00000000,0x00000000}},	//   ahir_, _soei, --, --, 
   {{0x386212f3,0x644a12f4,0x4e0c00dc,0x67d400db}},	//   bhir_, _poei, त्यै_, _оону, 
   {{0x386212f5,0x765c04ba,0x69d40e78,0x6e28003e}},	//   chir_, _elry, lbze, hddb, 
   {{0x7dec016b,0x4a28025c,0x8c240eac,0x00000000}},	//   _wɔsɔ, _སྣོལ_, যাপন_, --, 
   {{0x672e12f6,0xc29004fb,0xf5480023,0xa4105043}},	//   mvaj, ریاب, ዘይኮነ, bığı_, 
   {{0x644a12f7,0x672e12f8,0x2d780131,0xa41003e0}},	//   _toei, lvaj, ﻼﺭﻧﻰ_, cığı_, 
   {{0x1eca12f9,0x349612fa,0x92f005d1,0xf78803e3}},	//   олии_, _заср, üğüm, _seçə_, 
   {{0x2d9a12fb,0x63ac0209,0xd020013d,0x00000000}},	//   üren_, ýand, тмый, --, 
   {{0xb3280327,0xa3c801ad,0x00000000,0x00000000}},	//   _རླིང_, लुर_, --, --, 
   {{0x1600228d,0x4a28031c,0x672c2d3b,0x6154072d}},	//   र्टर_, _སྣེལ_, hvaj, _تنائ, 
   {{0xf0e801ec,0x672c010f,0xd0240131,0x9f54c3cd}},	//   _ءىنى_, kvaj, _يولۋ, _овеч, 
   {{0x0b4002bf,0xcf2000c7,0x00000000,0x00000000}},	//   внян, _аҿық, --, --, 
   {{0x672e12fc,0x00000000,0x00000000,0x00000000}},	//   dvaj, --, --, --, 
   {{0x386212fd,0x672c0030,0xab0400b8,0x5fd00118}},	//   thir_, evaj, _puṣṇ, _सभाल, 
   {{0x69d40218,0x776401c4,0x59bc0b98,0x2c0405c0}},	//   abze, tzix, ्डहर, _वायू_, 
   {{0x672e12fe,0x160002ab,0x99d400f7,0x55e40d99}},	// [3cb80] gvaj, र्झर_, _оюнч, дозб, 
   {{0xa4106648,0x200c0007,0x6280020c,0x07a00139}},	//   tığı_, hfei_, _njlo, таун, 
   {{0x6728b0e8,0xd1cc001f,0xe6b401d5,0xab0400b8}},	//   _šejt, _ጥላቻ_, رلمگ, _tuṣṇ, 
   {{0x628001e4,0xb17c01e4,0xf48407d6,0x16000c4c}},	//   _ajlo, _jeĥe, راضی, र्जर_, 
   {{0x6e2a12ff,0x228800d7,0x99980210,0x96740153}},	//   yddb, lúky_, _wapń_, _жыві, 
   {{0x84540724,0xf1d8012d,0xa4100205,0x765c01ef}},	//   зрәт_, डरइन, pığı_, _ulry, 
   {{0x200dc2c1,0x628000d8,0x00c401e0,0xc10007fc}},	//   ffei_, _djlo, үләк_, نووي, 
   {{0x7730044e,0xf1b80135,0xd36c15bf,0x6d5c00a3}},	//   _ሰራሕተ, _maġi_, _پۇت_, ùram, 
   {{0x41cc08ec,0x00000000,0x00000000,0x00000000}},	//   _स्वस, --, --, --, 
   {{0xd24c168d,0x68e00b21,0xbea401f7,0x00000000}},	//   _خۆت_, âldk, وهين_, --, 
   {{0x672e1300,0x85f4008f,0x321c00d7,0x00000000}},	//   zvaj, וציע_, mevy_, --, 
   {{0x321e1301,0x672c46dc,0x00000000,0x00000000}},	//   levy_, yvaj, --, --, 
   {{0x65640098,0x6fac03d4,0x00000000,0x00000000}},	//   zzhh, _ট্ৰে, --, --, 
   {{0x90ac0882,0x68380092,0x00000000,0x00000000}},	//   _dṛśy, _አለመስ, --, --, 
   {{0x72980020,0x98680166,0x00000000,0x00000000}},	//   ግሥታዊ_, _añın_, --, --, 
   {{0x672e1302,0x200808e7,0x81a80154,0x290c031c}},	//   tvaj, _ñait_, কুক_, ċea_, 
   {{0x7c84f3e5,0x321c00c7,0x00000000,0x00000000}},	// [3cb90] _шуше, kevy_, --, --, 
   {{0x672c0882,0x321c45bb,0x6bd84bcf,0xc5f800c6}},	//   rvaj, jevy_, _بوکس_, تعرض_, 
   {{0x3de000bd,0xba74113e,0x672e1303,0x00000000}},	//   _মামল, _جايت, svaj, --, 
   {{0xb5a402bf,0x4e0c00bc,0x92b000d1,0x00000000}},	//   труй, त्तै_, ۇڭلا, --, 
   {{0x43b00184,0x38c400e4,0x39580419,0x00000000}},	//   тҡар, _tèrã_, česť_, --, 
   {{0xe2840323,0x21a4086f,0x00000000,0x00000000}},	//   элли, нилм, --, --, 
   {{0x8554d902,0x205410f3,0x2d9805d1,0x68e0002d}},	//   _تیار_, етпр, ürel_, âldh, 
   {{0x10a21304,0x2754001f,0x00000000,0x00000000}},	//   лищн, _የመስጠ, --, --, 
   {{0xe8100574,0x91c8033f,0x9f5804cc,0x00000000}},	//   ड्या_, _स्कै, üsà_, --, 
   {{0x130802dd,0x645801f5,0x00000000,0x00000000}},	//   _ءىلۋ_, lkwi, --, --, 
   {{0x645801f7,0x00000000,0x00000000,0x00000000}},	//   okwi, --, --, --, 
   {{0x645a1305,0x60c001ab,0xd12c01e2,0x22880419}},	//   nkwi, _iulm, _دڅه_, vúky_, 
   {{0x61e21306,0x60c1457f,0x1cb8dbec,0x64580099}},	//   _kell, _hulm, _کاتب_, ikwi, 
   {{0x60c21307,0x61e21308,0x00000000,0x00000000}},	//   _kulm, _jell, --, --, 
   {{0x61e21309,0xcfe002f5,0x60c2130a,0xb17c01e4}},	//   _mell, _যাতন, _julm, _teĥe, 
   {{0x21240a2e,0x645801a4,0xda0800f1,0x00000000}},	//   _mslh_, jkwi, _کيده_, --, 
   {{0x61e0009a,0x60c0d6ff,0xe1e400ec,0x00000000}},	// [3cba0] _oell, _lulm, _پڳ_, --, 
   {{0x61e0156b,0x999802e2,0x64580af9,0x00000000}},	//   _nell, _rapņ_, ekwi, --, 
   {{0x60c02112,0x321e06e1,0x89d802e4,0xe5f0010e}},	//   _nulm, vevy_, _מחיי, _ädýä, 
   {{0x5ed400bd,0x61e00165,0x00000000,0x00000000}},	//   _দিনে, _aell, --, --, 
   {{0x61e0b77d,0x2c040882,0x321c0030,0x00000000}},	//   _bell, ष्टं_, tevy_, --, 
   {{0x60c0b753,0x61e00fa9,0x64580810,0xc2c019bc}},	//   _bulm, _cell, akwi, ديوي, 
   {{0x61e2130b,0x8c240f22,0x321e130c,0x3ec00150}},	//   _dell, যাতন_, revy_, қсыб, 
   {{0x68e00a85,0x60c06bb3,0x61e2130d,0x645a130e}},	//   âldi, _dulm, _eell, ckwi, 
   {{0x61e055fd,0x00000000,0x00000000,0x00000000}},	//   _fell, --, --, --, 
   {{0x61e2130f,0x60c21310,0x638000c7,0xdde801e2}},	//   _gell, _fulm, _әҳәа, ورپه_, 
   {{0x2d986ab9,0xe3b001ed,0xf1ac1d68,0xe810033f}},	//   ære_, _مرے_, टेशन, ड्डा_, 
   {{0x61e21311,0x320002a8,0x1b180eac,0x00000000}},	//   _zell, ɗiya_, দিনে_, --, 
   {{0x60c096c4,0x61e21312,0xf1ac02c3,0x3fc80133}},	//   _zulm, _yell, टेरन, _ردنی_, 
   {{0x61e149e0,0x7f380a1e,0xe9180006,0x64580210}},	//   _xell, _מעדו, могі_, zkwi, 
   {{0xfd0c00b2,0x25ac01e4,0x7d1002f0,0x5ec40154}},	//   _هجي_, _ĝelo_, česá, লীদে, 
   {{0x91e40183,0x25ac010f,0xf8040354,0xe810012d}},	//   নলিখ, _ŝelo_, лчун, ड्ढा_, 
   {{0xeb340116,0x00000000,0x00000000,0x00000000}},	// [3cbb0] _شىدد, --, --, --, 
   {{0x23b403e6,0x058428e8,0x494400c0,0x00000000}},	//   ۆماس, нуем, _зэмб, --, 
   {{0x61e05e06,0x2ca8058a,0x38c80354,0x00000000}},	//   _rell, _khad_, _пуян_, --, 
   {{0x60c21313,0x61e21314,0x2ca803a2,0x99980316}},	//   _rulm, _sell, _jhad_, _např_, 
   {{0x60c0044e,0x645a1315,0xb9a400e5,0x00000000}},	//   _sulm, rkwi, _لمیٹ, --, 
   {{0x61e21316,0x68e0000f,0x64594dab,0x1780010a}},	//   _qell, âldw, skwi, _тӳсм, 
   {{0x60c0047e,0x00000000,0x00000000,0x00000000}},	//   _qulm, --, --, --, 
   {{0x9f0400db,0x61e21317,0x5ed4015b,0x60c0bdb6}},	//   نوبو, _well, _দিবে, _vulm, 
   {{0x1e840075,0xf4847c40,0x4f040166,0xa2b51c3d}},	//   клим, _сурн, внын_, _абач, 
   {{0x2ca86678,0x61e21318,0xabc40032,0x60c21319}},	//   _ahad_, _uell, ғарҙ, _tulm, 
   {{0x2ca808c2,0x60c0022f,0x81e400fe,0x91c8033f}},	//   _bhad_, _uulm, _ভাপ_, _स्टै, 
   {{0x2ca91521,0x00000000,0x00000000,0x00000000}},	//   _chad_, --, --, --, 
   {{0x4c66131a,0x2ca800a3,0x290403d1,0x4c8001ca}},	//   тиян_, _dhad_, àlan_, рляв, 
   {{0x2ca801fa,0xd65c02dd,0x69c000d0,0x3fa00327}},	//   _ehad_, нiнд, žlen, ġruħ_, 
   {{0x2ca814d0,0x09e0300e,0xd76401d3,0x00000000}},	//   _fhad_, росн, ھارٹ, --, 
   {{0x249c0190,0x2caa131b,0x81e4009e,0xd76401d3}},	//   jlwm_, _ghad_, ভলি_, پارٹ, 
   {{0xb17c010f,0x47c00212,0xd70802d5,0x00000000}},	// [3cbc0] _meĥa, рбув, ьнае_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x09f40375,0xdbdc0241,0x00000000,0x00000000}},	//   _במים_, _ṣùg, --, --, 
   {{0x97d8007b,0x6d5c08c2,0x00000000,0x00000000}},	//   _تبدأ_, ùrai, --, --, 
   {{0x27fc033f,0xf1a4000d,0x00000000,0x00000000}},	//   ówne_, _ओरहन, --, --, 
   {{0xdce800bc,0xd138014b,0x2d982093,0x00000000}},	//   áněn, дхи_, ürek_, --, 
   {{0x0524fbd3,0x00000000,0x00000000,0x00000000}},	//   _иорк_, --, --, --, 
   {{0xc950025f,0x6600002f,0xbd780092,0x00000000}},	//   שמה_, _ölkr, _ጥያቄም_, --, 
   {{0xa490304e,0x2ca800a9,0x4ea400f5,0x00000000}},	//   _اینت, _rhad_, кроа, --, 
   {{0x2ca892b7,0xdb7802d3,0x9e78069d,0x00000000}},	//   _shad_, _ኣትዮም_, _ክብርና_, --, 
   {{0xa3c80fc8,0xa2805d95,0xddc000de,0x00000000}},	//   लुक_, _دیوو, bilž, --, 
   {{0x217405f5,0x05a407af,0xe1f000e5,0x395800a2}},	//   _суур, केटब, _پسے_, dyrs_, 
   {{0xfe6c5aa3,0xd65c0150,0x00000000,0x00000000}},	//   صدی_, нiмд, --, --, 
   {{0xb17c0115,0x39580142,0xfcf40092,0x00000000}},	//   _zeĥa, fyrs_, ላለጽ_, --, 
   {{0x2caa131c,0x644c005b,0x6f02131d,0x00000000}},	//   _thad_, öaik, lumc, --, 
   {{0x4e0c0316,0x5ed40154,0x00000000,0x00000000}},	//   त्रै_, _দিতে, --, --, 
   {{0x2d9e131e,0xa61558b4,0x9f4c00a2,0x00000000}},	// [3cbd0] _hyve_, лмач, kgeý_, --, 
   {{0x2d9c00e4,0xfaa416a4,0x00000000,0x00000000}},	//   _kyve_, _кањо, --, --, 
   {{0x6f02131f,0x25740066,0x00000000,0x00000000}},	//   humc, دهاس, --, --, 
   {{0x6f021320,0x74a40120,0x00000000,0x00000000}},	//   kumc, ајче, --, --, 
   {{0x27ea1321,0xe374e95e,0x6f0001b9,0xb17c0115}},	//   maan_, ылды, jumc, _reĥa, 
   {{0x65961322,0x91e00107,0x00000000,0x00000000}},	//   _багу, боше, --, --, 
   {{0xf2040212,0x00000000,0x00000000,0x00000000}},	//   рячо, --, --, --, 
   {{0xa3c80d62,0x27ea1323,0x9f5c011f,0x60247ffa}},	//   लुख_, naan_, _acwá_, удиа, 
   {{0x443e1324,0x6f021325,0x00000000,0x00000000}},	//   _inu_, gumc, --, --, 
   {{0x27ea1326,0x3de000cc,0x00000000,0x00000000}},	//   haan_, _মাহল, --, --, 
   {{0x27ea1327,0x443caa77,0xa3000032,0x66040175}},	//   kaan_, _knu_, _түҙе, ighk, 
   {{0x27ea1328,0x6f007dcd,0x443c0076,0x2d9c0240}},	//   jaan_, bumc, _jnu_, _dyve_, 
   {{0x443e1329,0xdb780023,0x00000000,0x00000000}},	//   _mnu_, _ኣድያም_, --, --, 
   {{0x443c0158,0x1a6407d6,0x39640107,0xed5800d7}},	//   _lnu_, ایدی_, ангҳ, byľ_, 
   {{0x443e132a,0x8cc83711,0x27e98253,0x2d9c0064}},	//   _onu_, _संयो, faan_, _gyve_, 
   {{0x443c5bd4,0xdb1401ed,0x6ee001f2,0x0b1000cc}},	//   _nnu_, _egyá, ịbeg, িয়েল_, 
   {{0x8c24015b,0xab2801e0,0x28b80262,0xf120024a}},	// [3cbe0] যাশন_, _аныҡ_, турэ_, _मन्द_, 
   {{0x443e132b,0xd1cc001f,0x8cc806ff,0x00000000}},	//   _anu_, _ጥፋት_, _संमो, --, 
   {{0x27e9cd00,0x443c002e,0xde50004d,0x68e0002d}},	//   baan_, _bnu_, _đặc_, âldt, 
   {{0x27ea132c,0x443c1529,0x6f000790,0x00000000}},	//   caan_, _cnu_, yumc, --, 
   {{0x8cc80f90,0x00000000,0x00000000,0x00000000}},	//   _संभो, --, --, --, 
   {{0x443d2595,0x910401c0,0xf664013d,0x6f00014f}},	//   _enu_, гчид, _тегү, vumc, 
   {{0x6f000b6f,0x443c0158,0x442c003e,0xc0e010fc}},	//   wumc, _fnu_, bdg_, бојк, 
   {{0x8cc804fa,0x2ef551ea,0x6f000b45,0xf8b413f5}},	//   _संबो, азир, tumc, ंगिय, 
   {{0x2d9c0023,0x620801e3,0x99980064,0xe474d673}},	//   _syve_, äslö, _kopų_, _турэ, 
   {{0x27ea132d,0x7cd00311,0x8318008f,0x8e2401d5}},	//   zaan_, _mărf, _אומז, уфид, 
   {{0x27ea132e,0xf8b40490,0x069404ae,0x6f00e3eb}},	//   yaan_, ंगाय, רדים_, sumc, 
   {{0x27e80d62,0xdd90004e,0x6f00014f,0x2c0401f9}},	//   xaan_, توپ_, pumc, _वाळू_, 
   {{0x81e42158,0x27ea132f,0x6f000455,0x4090007b}},	//   _ভাত_, vaan_, qumc, _النر, 
   {{0x27ea1330,0xa0200afb,0x2d9e1331,0x0dc800d8}},	//   waan_, _çöre, _tyve_, _џули_, 
   {{0x48a8d0e2,0x00000000,0x00000000,0x00000000}},	//   етам_, --, --, --, 
   {{0x6d480007,0xddc00153,0x6568013a,0x00000000}},	//   mxda, bilų, _řeho, --, 
   {{0xa7b8053f,0x38bc00df,0x443c01ab,0xda64004b}},	// [3cbf0] тлау_, _eŭro_, _rnu_, _چاپي, 
   {{0xf7700533,0x68e0045f,0xda64678e,0x00000000}},	//   ساق_, âlds, _ناپي, --, 
   {{0x27ea1332,0x443e1333,0x6d480007,0x97500023}},	//   paan_, _pnu_, nxda, _ዘዘውት, 
   {{0x27e9d0d3,0x6d480007,0x888020d4,0xd00400c6}},	//   qaan_, ixda, _ایرن, _ظل_, 
   {{0x291005f5,0x232826c7,0xaad800bc,0x201000e5}},	//   ltza_, толи_, बीचक, őzik_, 
   {{0x2910009d,0x442c004e,0xe81060c7,0xa5f80150}},	//   otza_, sdg_, ड्रा_, _шегу_, 
   {{0x2910152d,0xe044de5f,0x3e780248,0xa06800f3}},	//   ntza_, инки, _látè_, кака_, 
   {{0x443e1334,0x291005f5,0xb17c010f,0x65940117}},	//   _unu_, itza_, _teĥn, _баҳу, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x63aa1335,0x00000000,0x00000000,0x00000000}},	//   _izen, --, --, --, 
   {{0xc05810f5,0xdc680aa5,0x6f1c084c,0x7cd00311}},	//   _під_, ванд_, ărca, _mărg, 
   {{0x7cd0054e,0x9c580120,0x5f9401ec,0x00000000}},	//   _lărg, тшоу_, _киет, --, 
   {{0xdee55c7d,0xcae40032,0x7e740116,0x291001c4}},	//   _толи, ағыҙ_, _бәнт_, etza_, 
   {{0x63a9eb7b,0x20d00135,0xb0c400e1,0xdb1c0241}},	//   _mzen, _iġib_, _लूँग, _àyís, 
   {{0xdca41c65,0xaf340133,0x97c401a9,0x00000000}},	//   _каки, _پرۆت, ийве, --, 
   {{0x8cc80d5f,0x298000c7,0x7a3c01e3,0x7690013d}},	//   _संतो, _ẽkõi_, _båtä, läyx, 
  
   {{0x27fc068f,0x291005f5,0x63ac0209,0x63a82a22}},	// [3cc00] ówna_, atza_, ýanl, _nzen, 
   {{0x7df035e8,0x7ae40086,0xb17c01e4,0x00000000}},	//   _आयोग_, _iwit, _beĥl, --, 
   {{0x98a61336,0xb0c400e1,0x7ae40489,0xca780023}},	//   _вине, _लूंग, _hwit, _ኣብኦም_, 
   {{0x7ae61337,0x63a8013a,0x0d3800df,0x00000000}},	//   _kwit, _bzen, כגעב, --, 
   {{0x63a81529,0x7ae40327,0x99980064,0x38600213}},	//   _czen, _jwit, _topų_, mkir_, 
   {{0x63aa1338,0x7ae61339,0x7f580309,0x00000000}},	//   _dzen, _mwit, dyuq, --, 
   {{0x63a80944,0x7bc40083,0xe72c0024,0x35c4059f}},	//   _ezen, _ogiu, _iššū, _ваҳҳ, 
   {{0x38600bc9,0x7bc40c6a,0x09c01223,0x7ae402d0}},	//   nkir_, _ngiu, _शल्य, _owit, 
   {{0x63a8107d,0xca7c01a9,0x91c00131,0xd9e4466d}},	//   _gzen, _orqа, _һәқл, करात_, 
   {{0x7bc6133a,0xaf540588,0x52b000cf,0x38602d7c}},	//   _agiu, инқә, _بەتئ, hkir_, 
   {{0x7ae6133b,0x3862133c,0x2c68000f,0x8d8400ee}},	//   _awit, kkir_, _lûde_, рупд, 
   {{0x7ae401aa,0x50b85821,0x9ce801d9,0x6d487708}},	//   _bwit, _شداد_, دوَے_, rxda, 
   {{0x201003be,0x80bc00e1,0x4ea40798,0x00000000}},	//   əzi_, _लूटे, _крка, --, 
   {{0x29100356,0xcb700023,0xfe6c0b24,0x00000000}},	//   ttza_, _ኣድለየ_, _يدو_, --, 
   {{0x07e5c20e,0x7ae6133d,0xded4001f,0x29100356}},	//   ицам, _ewit, _የሥነ_, utza_, 
   {{0x38600073,0xf7700014,0x7ae40161,0x291001c0}},	//   gkir_, ژال_, _fwit, rtza_, 
   {{0x2910010a,0x7ae40156,0x320c0076,0x00000000}},	// [3cc10] stza_, _gwit, _ocdy_, --, 
   {{0xda1400e1,0x38600009,0x8a4002f2,0x00000000}},	//   द्दत_, akir_, _بێسن, --, 
   {{0x7ae41aa1,0x63aa133e,0xe895b105,0x69c40c8c}},	//   _zwit, _szen, _гань, _ighe, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69c401af,0x225a133f,0xfd640432,0x00000000}},	//   _kghe, лиды_, _berỳ, --, 
   {{0x5ed409bd,0xb6040276,0x69c4054e,0xd72c1ef7}},	//   _দিলে, _мяск, _jghe, _ብርሃነ, 
   {{0x25a400dd,0xfd64010e,0x7f580113,0x00000000}},	//   _áll_, _derỳ, wyuq, --, 
   {{0x6adc03f4,0x63a80589,0x68e40369,0x201a1340}},	//   _বিনো, _tzen, _mwhd, ýsi_, 
   {{0x63aa1341,0x69c61342,0xdec802d3,0x7cd00311}},	//   _uzen, _oghe, _በለኒ_, _măre, 
   {{0x69c61343,0xcf8c105d,0x7ae40230,0x5e49f996}},	//   _nghe, رژن_, _rwit, упом_, 
   {{0x7ae61344,0x38600252,0xc0c80107,0x31340117}},	//   _swit, ykir_, _рузе_, _мефр, 
   {{0x69c61345,0x7f580784,0x3860031c,0x28cc0150}},	//   _aghe, pyuq, xkir_, _ﻓﺎﺸﻠ, 
   {{0x8eb0036b,0xdee400d8,0x1ec801f4,0x00000000}},	//   تمیش, _ѓоки, _ёлки_, --, 
   {{0xfbd813da,0x1d080116,0x7ae40175,0x2e6802dd}},	//   _भ्रम, _беки_, _vwit, _киіп_, 
   {{0x7ae40175,0x68e0002d,0x9c5801af,0xa3c85b99}},	//   _wwit, âldp, _бшпу_, ोडा_, 
   {{0x69c401f2,0xb8d1b550,0x7cd00276,0x2c68002d}},	//   _eghe, _ओठ_, _căre, _pûde_, 
   {{0x7ae40516,0x38621346,0x15c801ec,0x00000000}},	// [3cc20] _uwit, rkir_, _ﯗﻻﺭﺩ, --, 
   {{0x1a04016a,0x38621347,0x9a28005b,0xda6400ec}},	//   _упом, skir_, _сооб_, _چاھي, 
   {{0xda661348,0x85b0013d,0x86740166,0x60cc0220}},	//   _ناھي, зәтч, сөяр_, _ﻗﺎﻻﺷ, 
   {{0x3b78001f,0x8cc809ab,0x00000000,0x00000000}},	//   _አንዳች_, _संसो, --, --, 
   {{0xa3c809d9,0x78a48fee,0xded4001f,0x00000000}},	//   ोड़_, mliv, _የእኔ_, --, 
   {{0x7cd00356,0xc1e401d3,0x6adc0154,0x00000000}},	//   _zăre, مکمل_, _বিমো, --, 
   {{0x8678008f,0x6350002b,0x527400d1,0x7584104c}},	//   _ערלו, _aśnā, _һужу, _بیام, 
   {{0x78a61349,0x09ac0327,0x70580395,0x00000000}},	//   nliv, ནྟྲ_, раир_, --, 
   {{0x78a41057,0x81e40154,0x73c401af,0x00000000}},	//   iliv, _ভার_, _ләһе, --, 
   {{0x78a40232,0x7ed000c6,0x1fa401c0,0x10880046}},	//   hliv, أزيا, өрөг, _ﯗﺯﺩﯨ, 
   {{0x78a4e30c,0xc0d00592,0x869808d8,0x56780092}},	//   kliv, _فيلب, רייז, _በከንቱ_, 
   {{0x7cd0084c,0x8c640364,0x69c4c7cc,0x78a401bf}},	//   _bărb, стод, _sghe, jliv, 
   {{0x78a40122,0x7cd00311,0x3b6402e8,0x518401e0}},	//   dliv, _cărb, първ, _туҡа, 
   {{0x27ec012c,0x7cd00311,0x00000000,0x00000000}},	//   _žen_, _săre, --, --, 
   {{0x7cd0084c,0x7e48040b,0xe73000ac,0x00000000}},	//   _păre, _حسنہ_, _köçü, --, 
   {{0x78a4b804,0x00000000,0x00000000,0x00000000}},	//   gliv, --, --, --, 
   {{0x85c4007b,0x66d400ae,0x00000000,0x00000000}},	// [3cc30] مغام, زيائ, --, --, 
   {{0x69c6134a,0xc986134b,0x78a40821,0xa5f80212}},	//   _ughe, _гуми, aliv, режу_, 
   {{0x35e428f6,0x00000000,0x00000000,0x00000000}},	//   яцтв, --, --, --, 
   {{0x2418b690,0x78a6134c,0x00000000,0x00000000}},	//   роды_, cliv, --, --, 
   {{0x7eac03a1,0xc7a00014,0x837000d1,0x35e800cc}},	//   løpe, _رٔسی, чқач, _পাৰহ, 
   {{0x85b80014,0xa8ec07f7,0x36d40108,0x1fd00210}},	//   _مازس_, _जबाफ_, _хорр, सड्ड, 
   {{0x7cd00276,0xa3d40212,0xd00c00f1,0x71580395}},	//   _mărc, _мовч, ږلي_, йръс_, 
   {{0x27700020,0xd12c1371,0x1f6400d4,0x00000000}},	//   _ለመስጠ, ئمي_, жким, --, 
   {{0x248c0d51,0x6d5c168c,0x00000000,0x00000000}},	//   _ijem_, øran, --, --, 
   {{0x248d0721,0x8cc87688,0x78a413d5,0x31680124}},	//   _hjem_, _संशो, zliv, ршәо_, 
   {{0x248c0c58,0x7cd0084c,0x7eac2c95,0x5c8802bf}},	//   _kjem_, _sărb, jøpe, ийом_, 
   {{0x26da134d,0xe7300209,0x78a40fac,0x5ec40154}},	//   _otso_, _göçü, xliv, লীগে, 
   {{0x26d801d4,0x2d9a134e,0x7cd0054e,0xd00c00f1}},	//   _ntso_, ürer_, _bărc, _شلو_, 
   {{0x9408013f,0x78a41f06,0x00000000,0x00000000}},	//   _ɔbɑ_, wliv, --, --, 
   {{0x78a402fb,0x673c6838,0x26d8005a,0x98540d34}},	//   tliv, _arsj, _atso_, оташ, 
   {{0x248e134f,0x78a61350,0x26d80205,0x00000000}},	//   _njem_, uliv, _btso_, --, 
   {{0x07a21351,0x98bc0024,0x7cd00356,0x00000000}},	// [3cc40] датн, štį_, _fărc, --, 
   {{0x6d5c000d,0x4644004e,0x00000000,0x00000000}},	//   ärag, озун_, --, --, 
   {{0x7954168d,0x78a61352,0x26d801e0,0x81e400cc}},	//   _عێرا, pliv, _etso_, _ভাং_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x248c0023,0xb7b4009d,0xfd0400ec,0x00000000}},	//   _djem_, _хөвч, _ڪج_, --, 
   {{0x248c00ee,0xfbe000fe,0x00000000,0x00000000}},	//   _ejem_, ভণিত, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb17c01e4,0x813415c3,0x248c0fac,0xba040092}},	//   _jeĥi, زسىز_, _gjem_, _ሌጦ_, 
   {{0xc47401d3,0xdb1400e5,0xd9d80037,0xd3700345}},	//   _بینچ_, _egyú, _भभूट, _تێشک, 
   {{0x0200765f,0x248c7881,0x63780153,0xd7d83f7e}},	//   _озун, _zjem_, _усср_, युतच, 
   {{0x40900131,0x00000000,0x00000000,0x00000000}},	//   ярәт, --, --, --, 
   {{0x32d00051,0xac1800d4,0xae88004e,0x00000000}},	//   _kày_, щому_, рбүз_, --, 
   {{0x008001b9,0x00000000,0x00000000,0x00000000}},	//   _ўлчо, --, --, --, 
   {{0x32d00016,0x66e00248,0xd5a80073,0xfe400117}},	//   _mày_, _lákò, _करंज, _ончо, 
   {{0x6e28282d,0x6d5d39c3,0xb5e800cc,0x32d00208}},	//   medb, ärad, _পাংচ, _lày_, 
   {{0x6e28219a,0x2c040073,0x7eac03cd,0x00000000}},	//   ledb, _वाटू_, røpe, --, 
   {{0x32d0431d,0xc7b9e145,0x00000000,0x00000000}},	// [3cc50] _này_, рёв_, --, --, 
   {{0x6e291bc6,0x494401c6,0x271c00fe,0x248c01ef}},	//   nedb, _дэмб, নিলো_, _sjem_, 
   {{0x1bf006ab,0x69d4033f,0x67d401d5,0x30d00150}},	//   _अजमल_, mcze, _нону, _ﻗﺎﻻﻧ, 
   {{0x81e403f4,0x32d00016,0x08400014,0x69d4f2c5}},	//   _ভাই_, _bày_, _تۆرُ, lcze, 
   {{0x32d001fb,0x6e280857,0xba7404fb,0x7cd00356}},	//   _cày_, kedb, _رایت, _măra, 
   {{0x32d0001e,0x6e281711,0xe2980640,0x672e1353}},	//   _dày_, jedb, љак_, mwaj, 
   {{0xd24c0e8e,0x6e280857,0x248c0200,0x00000000}},	//   انى_, dedb, _tjem_, --, 
   {{0xded4001f,0x672c01f7,0x00000000,0x00000000}},	//   _የእኛ_, owaj, --, --, 
   {{0xbb5c0020,0x672c020c,0x4fe401c6,0x5f4401b9}},	//   ልክተዋ, nwaj, чмын_, سندل, 
   {{0x32640801,0x22bc00a2,0x6e287c9a,0x69d4012d}},	//   _отхв, _oňki_, gedb, jcze, 
   {{0xdca4dcc4,0x672c0099,0x69d40034,0xb65c008f}},	//   зани, hwaj, dcze, ידזש, 
   {{0x69d4068f,0x672e1354,0x3de0015b,0x7cd0054e}},	//   ecze, kwaj, _মাওল, _căra, 
   {{0x02c80882,0x20d21355,0x6e28937d,0x5ed40154}},	//   ादिभ, _hái_, bedb, _দিকে, 
   {{0x20d21356,0x9cf43500,0x672d8415,0x1ca40133}},	//   _kái_, _ечиш, dwaj, غێکی_, 
   {{0x672c033f,0x2c040073,0xfcf40092,0x00000000}},	//   ewaj, _वाचू_, ዋወጫ_, --, 
   {{0x20d21357,0x200e1358,0x69d4012d,0x18680395}},	//   _mái_, ngei_, acze, щаби_, 
   {{0x672e1359,0x20d00016,0xdd9001d3,0x051803d4}},	// [3cc60] gwaj, _lái_, _توں_, নটোৰ_, 
   {{0x20d0004d,0x362401d3,0x32d00051,0xe8e000a2}},	//   _oái_, ظواہ, _rày_, guỳy_, 
   {{0x14241c3e,0x18a40107,0x4a580375,0x20d001a8}},	//   здем, _наом, _הדיו, _nái_, 
   {{0x672c770e,0x136802bf,0x6e2800e5,0x00000000}},	//   bwaj, йшли_, zedb, --, 
   {{0x1b18015b,0x672c3302,0x88380375,0xd258010b}},	//   দিকে_, cwaj, _התכו, йцк_, 
   {{0xc324581f,0x20d001fb,0x48e0012c,0x8af803b9}},	//   سكىن_, _bái_, टीको_, lməç, 
   {{0x20d001dc,0x6e2824dd,0x00000000,0x00000000}},	//   _cái_, vedb, --, --, 
   {{0x69d6135a,0x25700220,0x32d0004d,0x20d20cc6}},	//   zcze, _جۇمس, _tày_, _dái_, 
   {{0x6e28ee88,0x69d40034,0xdb08020c,0x3de000fe}},	//   tedb, ycze, _ènèh, _মাজল, 
   {{0x20d02833,0x7cd00276,0x66c80153,0x03a00798}},	//   _fái_, _săra, _užke, _џифо, 
   {{0x20d007ae,0x6e2804b9,0x672c4532,0x3320003d}},	//   _gái_, redb, zwaj, ħixu_, 
   {{0x6e2a135b,0x672c0034,0x69d4033f,0x6fc400c7}},	//   sedb, ywaj, wcze, _ҵаҵҕ, 
   {{0x7cd00356,0x00000000,0x00000000,0x00000000}},	//   _văra, --, --, --, 
   {{0xfe6c00c6,0x7ac47cee,0x8e7400db,0xf1cc00cd}},	//   _مدى_, ессе, _رەجئ_, ाशिन, 
   {{0x69d42957,0x67d558ef,0xac18010a,0x00000000}},	//   rcze, добу, _дойу_, --, 
   {{0x672c015c,0x00000000,0x00000000,0x00000000}},	//   twaj, --, --, --, 
   {{0x7eac00fe,0xf1cc043e,0x06340092,0x00000000}},	// [3cc70] løpa, ाशान, _የማይነ, --, 
   {{0x672c1de9,0xdb240cb8,0x200c0007,0x36d40229}},	//   rwaj, _کویی, zgei_, хофр, 
   {{0xc4c6135c,0x200c020c,0x672c012d,0xe5340124}},	//   ستاو, ygei_, swaj, ьежь, 
   {{0x672c009f,0x20d00051,0x00000000,0x00000000}},	//   pwaj, _rái_, --, --, 
   {{0x20d000c7,0x9f58046c,0xd4c00166,0x00000000}},	//   _sái_, üsü_, төрк, --, 
   {{0xa020f3aa,0x6594f8cf,0xa30c0037,0x00000000}},	//   _çöze, _жагу, _समीज_, --, 
   {{0x200c1570,0xfa2804c5,0x7eac05ac,0xd12c0f2b}},	//   tgei_, মাচল_, jøpa, لمو_, 
   {{0x42743ee6,0xf48401c0,0x5ef834ae,0x20d00208}},	//   _کارآ, _зуун, охор_, _vái_, 
   {{0x200d261a,0x33580276,0x644a135d,0xdf48109a}},	//   rgei_, _еатэ_, _inei, ізод_, 
   {{0x20d00016,0x35440014,0x644a135e,0xd24c4dc1}},	//   _tái_, _تنہٲ, _hnei, _پچه_, 
   {{0x64483bbe,0x9d38016b,0xe47c01e1,0x00000000}},	//   _knei, ɛyɛɛ_, _ìtó̟, --, 
   {{0xaec45bc9,0x00000000,0x00000000,0x00000000}},	//   мбөл, --, --, --, 
   {{0xafc40150,0xacb0215c,0x00000000,0x00000000}},	//   _كيمى, دەيب, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x644a135f,0x7cd00356,0xae3400f1,0x98a43b8f}},	//   _onei, _zărn, _سويډ, диве, 
   {{0x64480770,0x6adc00bd,0x8c3803fa,0x00000000}},	//   _nnei, _বিরো, toße, --, 
   {{0x4fb8010f,0x00000000,0x00000000,0x00000000}},	// [3cc80] ַזעצ, --, --, --, 
   {{0x644a1360,0x8c380112,0xbab400db,0xda082dd0}},	//   _anei, roße, _سۅزب, _بيده_, 
   {{0xd7c802f2,0x00000000,0x00000000,0x00000000}},	//   _ووده_, --, --, --, 
   {{0x64480042,0x00000000,0x00000000,0x00000000}},	//   _cnei, --, --, --, 
   {{0xaa3402d3,0xc95401ed,0x81dc00fe,0x656801ef}},	//   _ብምህላ, _فلیش_, _থয়_, _řeht, 
   {{0xfe641060,0x644876e4,0x2ba40d0d,0x00000000}},	//   _شد_, _enei, _गुफा, --, 
   {{0x2ba4084a,0x765c02d0,0xd46800f3,0x00000000}},	//   _गुना, _iory, _диве_, --, 
   {{0x765e1361,0x91e400cc,0x00000000,0x00000000}},	//   _hory, _নাওখ, --, --, 
   {{0xd42400ac,0x03a00166,0x63ac0d12,0x00000000}},	//   ışdı_, _аито, ýant, --, 
   {{0x7cd00276,0x6adc03d4,0x8d851b47,0x644800d7}},	//   _căro, _বিলো, думд, _znei, 
   {{0x6448002d,0x765e1362,0xfa2c0327,0xfd5000b8}},	//   _ynei, _mory, _སྲེན_, _kheṭ, 
   {{0x765c07ab,0x008025ee,0xdd900451,0x53b005c0}},	//   _lory, _илхо, اوٽ_, _जराश, 
   {{0x8cc8ad78,0x2c740248,0x0ba8005e,0x66ec00e1}},	//   _संको, _aúdù_, تادى_, _चौंक_, 
   {{0xe7e0216a,0x8934009a,0x00000000,0x00000000}},	//   गुना_, وعزا, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe50c00dc,0xc60423e9,0xf80400db,0x3cf8011a}},	//   ांसि_, शल्य_, кчун, _ולהנ, 
   {{0x94080134,0x6e3a1363,0x00000000,0x00000000}},	// [3cc90] _ɔbɔ_, _kavb, --, --, 
   {{0x644a1364,0x765e1365,0x6e380455,0x2ba40037}},	//   _snei, _cory, _javb, _गुया, 
   {{0xaf9402d3,0x765d98a6,0x644800de,0x00000000}},	//   _ውድብና_, _dory, _pnei, --, 
   {{0x05dc9201,0x765c127b,0x6e3a1366,0xa3d61367}},	//   _प्रब, _eory, _lavb, ходч, 
   {{0x58280003,0x765e1368,0x2ba428f5,0x46300124}},	//   _སྒྲོ_, _fory, _गुमा, _иҭар, 
   {{0x6e38b106,0x765e1369,0x64480368,0x00000000}},	//   _navb, _gory, _wnei, --, 
   {{0x44291d9e,0x8cc8033d,0x6594cea6,0x00000000}},	//   _ºc_, _संगो, _чаву, --, 
   {{0x644a136a,0x4428001e,0x81e400cc,0x1184035b}},	//   _unei, _úc_, _ভাও_, хәуп_, 
   {{0x7cd00356,0x765c6873,0x00000000,0x00000000}},	//   _păro, _yory, --, --, 
   {{0x27280156,0x63aa136b,0x02c80882,0x765c0009}},	//   ཤསཧཨ_, _iyen, ादीन, _xory, 
   {{0x63aa136c,0xf15003e6,0x628019b6,0xa6e400cc}},	//   _hyen, _نێود, _imlo, _ফটফট, 
   {{0x63a88378,0x601800a7,0x628000d0,0x116812e9}},	//   _kyen, _ходя_, _hmlo, _علنی_, 
   {{0x63a80526,0xfa2c025c,0xbf644a2a,0x6614033f}},	//   _jyen, _སྲུན_, _تداو, _oczk, 
   {{0x63a90129,0xd65c01ec,0x00000000,0x00000000}},	//   _myen, мiнд, --, --, 
   {{0xd8240abe,0x765d181f,0x63aa136d,0x62800175}},	//   ндви, _rory, _lyen, _mmlo, 
   {{0x63aa136e,0x22bc007f,0x6614012d,0x1c080073}},	//   _oyen, _kňks_, _aczk, _वाटल_, 
   {{0x63aa136f,0x7c240537,0x765c762b,0x62821370}},	// [3cca0] _nyen, _ibir, _pory, _omlo, 
   {{0x765c0014,0x920c07c1,0xd76400f1,0x3964014b}},	//   _qory, _साइज_, ونځی, _аноҳ, 
   {{0x63a8eea6,0x7c24038f,0x765c007f,0xceb0011a}},	//   _ayen, _kbir, _vory, ניב_, 
   {{0x63a86424,0x6280d522,0x00000000,0x00000000}},	//   _byen, _amlo, --, --, 
   {{0x7c261371,0x765cfb29,0x63a80796,0xb6c4035b}},	//   _mbir, _tory, _cyen, _аҩад, 
   {{0x63aa1372,0x5804030c,0x84548383,0xe7e0000d}},	//   _dyen, _توڭك, дрәт_, गुठा_, 
   {{0xfd040152,0x63a8376b,0x7c261373,0x506579cc}},	//   _حج_, _eyen, _obir, етпа, 
   {{0x62800163,0x63a804ce,0xc9500375,0x6e3a1374}},	//   _emlo, _fyen, רמה_, _savb, 
   {{0x63aa1375,0x00000000,0x00000000,0x00000000}},	//   _gyen, --, --, --, 
   {{0x8eb00075,0x6e380477,0x7eb4004e,0x5f0001f9}},	//   دەتت, _qavb, нгыс_, _शिर्_, 
   {{0xdb14066d,0x7c242252,0x6e380477,0x7eac03b2}},	//   _együ, _bbir, _vavb, møpl, 
   {{0x7c241529,0x6e38014f,0xead4005b,0x00000000}},	//   _cbir, _wavb, комь, --, 
   {{0x6e3801b9,0x6280062c,0x2fc001ab,0x7e7c00d1}},	//   _tavb, _ymlo, _àig_, ﻧﺌﻪﺕ_, 
   {{0x7c240c8a,0x2ba4543b,0x6e3803cd,0x00000000}},	//   _ebir, _गुणा, _uavb, --, 
   {{0xa84800f1,0x00000000,0x00000000,0x00000000}},	//   ولسم_, --, --, --, 
   {{0x19c000c7,0x00000000,0x00000000,0x00000000}},	//   шәыг, --, --, --, 
   {{0x779807ee,0xa6143e1f,0x00000000,0x00000000}},	// [3ccb0] ектр_, кмач, --, --, 
   {{0x7c24341a,0x63a88458,0x6aa40175,0x00000000}},	//   _zbir, _ryen, _ukhf, --, 
   {{0xfa2c2fb5,0x63a86129,0xa020008e,0x00000000}},	//   _སྲིན_, _syen, _çöge, --, 
   {{0x62800316,0x63a800c7,0x64900115,0xb5a4010b}},	//   _smlo, _pyen, rĥio, уруй, 
   {{0x27ea1376,0x261805dc,0x47851dbc,0xaa340023}},	//   mban_, _पापी_, _чынб, _ብምሕላ, 
   {{0x63a8c611,0x27ea1377,0xe5b50743,0x7cd0054e}},	//   _vyen, lban_, _айгы, _sărm, 
   {{0x16643769,0x3a38011a,0x00000000,0x00000000}},	//   _جەلپ_, גרום_, --, --, 
   {{0x27ea1378,0x27540092,0x00000000,0x00000000}},	//   nban_, _ከመስጠ, --, --, 
   {{0x442e1379,0x6d5d9fac,0x8cc82793,0x6280037e}},	//   meg_, äran, _संजो, _tmlo, 
   {{0x442e137a,0x7c26137b,0x62800912,0x27ea137c}},	//   leg_, _sbir, _umlo, hban_, 
   {{0x27e8066d,0x261822e3,0x442c05c7,0x271c00cc}},	//   kban_, _पानी_, oeg_, নিটো_, 
   {{0x442c0ad3,0x645800ca,0x22480b45,0x27ea137d}},	//   neg_, njwi, ɓaka_, jban_, 
   {{0x90780302,0x27e81893,0x2ba40034,0x93f80375}},	//   _קטני, dban_, _गुदा, ולרי, 
   {{0x442e137e,0x27ea137f,0x00000000,0x00000000}},	//   heg_, eban_, --, --, 
   {{0x442c0dd4,0xdc9801d5,0x1a640345,0x00000000}},	//   keg_, _отиш_, فیکی_, --, 
   {{0x442c04b9,0x99980053,0x7c25ce19,0x27e800dd}},	//   jeg_, _hapū_, _ubir, gban_, 
   {{0x442e1380,0x2ee1f29d,0x6d5c0fac,0xae18216a}},	// [3ccc0] deg_, _çift_, ørav, _दामन_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x27ea1381,0x3a840014,0xd54801d5,0x92cc0154}},	//   bban_, _لُکہ, بلاو_, _শবে_, 
   {{0x25404077,0x442c9ded,0x27e800e5,0x66c80153}},	//   _dėl_, geg_, cban_, _užkn, 
   {{0x78a61382,0x00000000,0x00000000,0x00000000}},	//   moiv, --, --, --, 
   {{0x78a61383,0x442ca084,0x80a113e2,0x26180b03}},	//   loiv, aeg_, یمون, _पायी_, 
   {{0x442e1384,0xe2aa1385,0x463800df,0x00000000}},	//   beg_, راهن_, _קעלע, --, 
   {{0x442c0b91,0x78a51af5,0xb0344f20,0x4fc40108}},	//   ceg_, noiv, униш, кспа, 
   {{0x92f005f5,0x0e08010b,0x4418010f,0xadd40114}},	//   _түлх, мэни_, _קומס, лопљ, 
   {{0x91b8006c,0x27e801ed,0x78a40208,0xcce00150}},	//   _قطار_, zban_, hoiv, _ﻁﻭﺍل_, 
   {{0x78a45e1d,0x27e9b048,0xac1a1386,0x2d980790}},	//   koiv, yban_, нону_, çre_, 
   {{0xcfa404a9,0x7f80036b,0x0fe000d1,0xd00800d8}},	//   _ишли, الین, _төкү, _цеде_, 
   {{0xbb5801ca,0xcef400d8,0x00000000,0x00000000}},	//   ваях_, _рчењ, --, --, 
   {{0x442e1387,0x27e80042,0xf3700240,0x00000000}},	//   zeg_, wban_, ቢልናዮ_, --, 
   {{0x442e1388,0x27e8066d,0x2ba40307,0x00000000}},	//   yeg_, tban_, _गँवा, --, 
   {{0x27ea1389,0x7878022c,0x6d5c0158,0x442e138a}},	//   uban_, _lívf, ørau, xeg_, 
   {{0x442e138b,0x2ca8071b,0xcaa4007b,0x92a40210}},	// [3ccd0] veg_, _ikad_, _لصدي, odłą, 
   {{0x27ea138c,0xe5f4007b,0x00000000,0x00000000}},	//   sban_, اكاد, --, --, 
   {{0x442e138d,0x27e801ed,0x212042e3,0x28140330}},	//   teg_, pban_, _महेश_, _یوگس, 
   {{0x254002d5,0x2912138e,0x78a40129,0x442c0489}},	//   _vėl_, muza_, coiv, ueg_, 
   {{0x442e138f,0x1cb0025c,0xe73c012c,0xc6a401c6}},	//   reg_, _ཐེལ_, _kříž, _арви, 
   {{0x02680108,0x63ac0210,0x76580108,0xdebc0240}},	//   ьшей_, żano, övyt, _ተኪኤ_, 
   {{0x2911daab,0xe73c00bc,0x6d5cff6c,0x00000000}},	//   nuza_, _mříž, äral, --, 
   {{0x291004ba,0x5210ecb2,0x00000000,0x00000000}},	//   iuza_, адәт, --, --, 
   {{0x29100516,0x2d980295,0xc2b002dd,0x2f5402d5}},	//   huza_, ûren_, _көкш, атэс, 
   {{0x29121390,0x22a400c2,0x00000000,0x00000000}},	//   kuza_, _субҳ, --, --, 
   {{0x78a4009f,0x29121391,0xa2d801ad,0x5d840956}},	//   yoiv, juza_, _फंड्, الجل, 
   {{0x29121392,0x2ba4146b,0x9b4405d9,0x26c0014f}},	//   duza_, _गुहा, هنجو, hmho_, 
   {{0x7cd0084c,0x78a61393,0x05c0012c,0x4c80a517}},	//   _mări, voiv, वेतब, сляв, 
   {{0x29120591,0x2ca80295,0x6cb401c0,0x00000000}},	//   fuza_, _ekad_, лөөт, --, 
   {{0x29105137,0x78a55953,0x09e0cd61,0x00000000}},	//   guza_, toiv, сосн, --, 
   {{0x2ba4121d,0x00000000,0x00000000,0x00000000}},	//   _गुवा, --, --, --, 
   {{0x78780174,0x78a61394,0xe7f4009d,0x00000000}},	// [3cce0] _lívg, roiv, рчсэ, --, 
   {{0x29113890,0x261805ba,0x78a61395,0x66c80006}},	//   buza_, _पाणी_, soiv, _užkl, 
   {{0x29100230,0x1868013e,0xd4682bbd,0x78a400c7}},	//   cuza_, _зани_, ниже_, poiv, 
   {{0x7ae400f3,0x65b801c0,0x00000000,0x00000000}},	//   _ktit, туур_, --, --, 
   {{0x7cd00356,0xd2500014,0xd5d432f7,0x00000000}},	//   _dări, ٝنش_, _متأث, --, 
   {{0xd13870bf,0x7ae61396,0x00000000,0x00000000}},	//   ехи_, _mtit, --, --, 
   {{0x261845bf,0x0fe000f7,0x00000000,0x00000000}},	//   _पाती_, бөлү, --, --, 
   {{0x7ae4ec74,0x6d5c00af,0xf48403e6,0x7cd0054e}},	//   _otit, äram, _ئاسی, _gări, 
   {{0x7ae61397,0xdbd00112,0x425001b9,0x01a40116}},	//   _ntit, _süßi, _گنلر, ккәк_, 
   {{0x7054082a,0x073406a9,0x29106466,0x7cd00356}},	//   انکا, נאים_, yuza_, _zări, 
   {{0xfeb5f6c7,0x6c559bc2,0x8678011a,0xfe6c007b}},	//   دايت_, акну, גריו, ثدي_, 
   {{0x21740e26,0x29121398,0x7ae61399,0x00000000}},	//   _туур, vuza_, _btit, --, 
   {{0xfe6c0cb8,0x2912139a,0x7ae6139b,0x7bf800ee}},	//   زدی_, wuza_, _ctit, ыняр_, 
   {{0x8d746fb7,0x291025ca,0x6d5d43ae,0x7ae6139c}},	//   _ماعا, tuza_, øras, _dtit, 
   {{0x7ae6139d,0x2ba4146c,0xa9340212,0xfce000d8}},	//   _etit, _गुरा, шевш, _лојо, 
   {{0x291179de,0x7ae4615e,0x787803b2,0xdd380356}},	//   ruza_, _ftit, _nívd, lăşe, 
   {{0x7c94bf30,0xbb480451,0x29100337,0x78ec00e4}},	// [3ccf0] _دشوا, _ملين_, suza_, _ẽatý, 
   {{0x7cd00276,0x2b48cdfb,0x0b980023,0x00000000}},	//   _sări, _irac_, ለጉዛይ_, --, 
   {{0x7cd0084c,0x29100117,0xa536139e,0x2b4802f0}},	//   _pări, quza_, рнеч, _hrac_, 
   {{0xa40402a6,0x29000943,0x2b48030a,0x68e4127b}},	//   োজ্য_, _ivha_, _krac_, _ithd, 
   {{0x427001b9,0x6d5c0f23,0x62340108,0x00000000}},	//   бҳас, äraj, иеду, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb60402fb,0x7cd00311,0xc76402dd,0xf2040212}},	//   íšer, _tări, _شاڭى, сячо, 
   {{0x2019b25c,0x5f049bf1,0xd65c02dd,0x84b401a9}},	//   üsi_, азиа, мiзд, _ёғду_, 
   {{0x443e139f,0xcf8c619c,0x2ba40d5f,0x7eace73f}},	//   _iau_, وژه_, _गुला, løpi, 
   {{0x443e13a0,0x29000943,0xbcc400fb,0x1d240117}},	//   _hau_, _ovha_, әҡил, амом, 
   {{0x443e13a1,0x2b480429,0x787801d3,0x00000000}},	//   _kau_, _arac_, _híve, --, 
   {{0x443e13a2,0x2b4a13a3,0x7ae613a4,0x61e00076}},	//   _jau_, _brac_, _ptit, _hfll, 
   {{0x443e13a5,0x290006d6,0x6d5cd2d2,0x68e4007b}},	//   _mau_, _avha_, ørar, _athd, 
   {{0x443e13a6,0x2b4a13a7,0x7ae4003a,0x17ec05b3}},	//   _lau_, _drac_, _vtit, जर्व_, 
   {{0xd1800055,0x787803b2,0xd94400ea,0x7600013a}},	//   _bāṇī_, _líve, јеби, hází, 
   {{0x443e13a8,0x1b480b30,0x7e6004ce,0xe6f40327}},	//   _nau_, _азии_, _honp, _བསྡན_, 
   {{0x7e6032a9,0x787803b7,0x7ae613a9,0x2900a79a}},	// [3cd00] _konp, _níve, _utit, _evha_, 
   {{0x443e13aa,0x7e600477,0x8af8d16f,0x2fc00e89}},	//   _aau_, _jonp, _שהיי, _ùige_, 
   {{0x443e13ab,0x7e6213ac,0x9b8835b6,0x00000000}},	//   _bau_, _monp, _سنگل_, --, 
   {{0x499813e2,0x7e600477,0x0af613ad,0x18680fac}},	//   _ישיב, _lonp, _حفیظ_, _рами_, 
   {{0x443e13ae,0x787a13af,0xe7e00073,0x00000000}},	//   _dau_, _cíve, गुळा_, --, 
   {{0x7e6213b0,0x443e13b1,0x78780118,0x6d5c16ca}},	//   _nonp, _eau_, _díve, ärak, 
   {{0x443e13b2,0xf0e802de,0x00000000,0x00000000}},	//   _fau_, دىعى_, --, --, 
   {{0x443e13b3,0x85380375,0xcfa400d8,0x2ef40114}},	//   _gau_, _בגלי, ишпи, бзир, 
   {{0xb8f807e4,0x7e6213b4,0x7cd00311,0x0874008f}},	//   _ོང_, _bonp, _măru, יעקט_, 
   {{0x443e13b5,0x7e601730,0xe6f40135,0x73c401af}},	//   _zau_, _conp, _བསྣན_, _кәһе, 
   {{0x443e13b6,0x7e6004c4,0xd720015b,0xdd380311}},	//   _yau_, _donp, নিয়া_, răşe, 
   {{0x443e13b7,0x4fa44d75,0x2b488864,0xbb2c001f}},	//   _xau_, _киев, _prac_, _እላችኋ, 
   {{0x7b6535e7,0xdd380311,0x7c2008c2,0x4f580244}},	//   отре, păşe, òmra, _ججاد_, 
   {{0x2b49cc5c,0xe918de10,0x649001e4,0x00000000}},	//   _vrac_, логі_, rĥii, --, 
   {{0x753c0841,0x2b48f047,0x6f00004e,0x88840120}},	//   _nsrz, _wrac_, lsmc, аѓал, 
   {{0x7cd0084c,0x2c4c0153,0x9f9400a2,0x00000000}},	//   _căru, _bėdų_, lýár_, --, 
   {{0x443e13b8,0x7cd00276,0xc6a613b9,0xd4240724}},	// [3cd10] _rau_, _dăru, аржи, ışlı_, 
   {{0x443e13ba,0x63ac033f,0xbab40014,0x00000000}},	//   _sau_, żank, _ؤٹک, --, 
   {{0x443e13bb,0x29001682,0x6d5c005b,0x787802d2}},	//   _pau_, _uvha_, ärah, _síve, 
   {{0x443e13bc,0x38c8179e,0xf408007b,0x27ec00a2}},	//   _qau_, _پاپی_, ليمى_, _ýen_, 
   {{0x443e13bd,0x01f40022,0xd1f40092,0x00000000}},	//   _vau_, иҭаш_, ለጉት_, --, 
   {{0x443e13be,0x673c0327,0x787a13bf,0x962400ef}},	//   _wau_, _issj, _víve, _piņņ, 
   {{0x443e13c0,0x26da13c1,0x20d0031c,0xb0b40073}},	//   _tau_, _huso_, _aġir_, ुषंग, 
   {{0x26d213c2,0x26d8124c,0x7cd00276,0xf48405f5}},	//   _hizo_, _kuso_, _mărt, _дуун, 
   {{0xdc680364,0x27f802ce,0x7e6213c3,0x26d213c4}},	//   ҳанд_, _mesn_, _ponp, _kizo_, 
   {{0x26d8052f,0x7e60014f,0x61e00076,0x934c0118}},	//   _muso_, _qonp, _ufll, ářeč, 
   {{0x26d86e19,0x26d213c5,0x7e6004cc,0xdc6a13c6}},	//   _luso_, _mizo_, _vonp, ганд_, 
   {{0x26d00077,0x26d800d8,0xdb080118,0x00000000}},	//   _lizo_, _ouso_, řník, --, 
   {{0x7e6007c5,0x26da13c7,0x902000ec,0x00000000}},	//   _tonp, _nuso_, _رڙيو, --, 
   {{0x26d213c8,0x7cd00311,0x00000000,0x00000000}},	//   _nizo_, _săru, --, --, 
   {{0x38c81416,0x26d88c04,0x7cd00311,0x673e13c9}},	//   لاری_, _auso_, _păru, _assj, 
   {{0x26da13ca,0x26d00099,0x2c4c0024,0x00000000}},	//   _buso_, _aizo_, _pėdų_, --, 
   {{0x7d000477,0x5628c6be,0x7cd0054e,0x00000000}},	// [3cd20] _hvns, лжам_, _văru, --, 
   {{0x26d00198,0x00000000,0x00000000,0x00000000}},	//   _cizo_, --, --, --, 
   {{0x261837d0,0x18a46d7d,0x673e13cb,0x787801ef}},	//   _पारी_, _ганм, _essj, _cívc, 
   {{0xbdfc02a6,0xb3d40184,0x7878013a,0x00000000}},	//   ্ভিদ_, әйҙә, _dívc, --, 
   {{0x8c180bd4,0x28b406ab,0x26d213cc,0x335800a8}},	//   רוני, ंतरि, _fizo_, ралэ_, 
   {{0x26d00c09,0x27f8004c,0x7d00143a,0x386213cd}},	//   _gizo_, _zesn_, _ovns, ljir_, 
   {{0x26d80354,0xdce00064,0x00000000,0x00000000}},	//   _zuso_, mzlė, --, --, 
   {{0x26d000f1,0xc950011a,0x00000000,0x00000000}},	//   _zizo_, למו_, --, --, 
   {{0x26d00107,0x26d80014,0x779403b9,0x00000000}},	//   _yizo_, _xuso_, bəxş, --, 
   {{0x62640597,0x290400e5,0x00000000,0x00000000}},	//   _والق, álak_, --, --, 
   {{0x649001e4,0x386003b2,0x7cd4009d,0xec3400d4}},	//   rĥiv, kjir_, ймэр_, оннь, 
   {{0xac1800d6,0x38600327,0x8598010f,0x5fd0012d}},	//   шому_, jjir_, רשטו, _हलचल, 
   {{0xef980032,0x0b894163,0x261801ad,0x38600009}},	//   _әйҙә_, усни_, _पाली_, djir_, 
   {{0x7cd0054e,0x63ac0254,0x00000000,0x00000000}},	//   _părt, üani, --, --, 
   {{0x26da13ce,0x26d213cf,0x66c80024,0xcce40b61}},	//   _suso_, _rizo_, _užki, _استي, 
   {{0x26da13d0,0x1cb0081f,0x26d213d1,0x63ac0034}},	//   _puso_, _ཐེག_, _sizo_, żani, 
   {{0xebc4b392,0x6d48fa6f,0x26d00115,0x36d40124}},	// [3cd30] _фәнн, lvda, _pizo_, зоур, 
   {{0x26d80a73,0x6628001f,0x7cd00356,0x26180073}},	//   _vuso_, _ሻምፒዮ, _tărt, _पाळी_, 
   {{0x387409c2,0x26d0a8a1,0x38600009,0x00000000}},	//   ñará_, _vizo_, bjir_, --, 
   {{0x26d8598c,0x161c0037,0x291003b9,0x00000000}},	//   _tuso_, _पाथर_, mrza_, --, 
   {{0x7f580429,0xe8b40073,0x73040212,0x8c38002f}},	//   xxuq, ंतीच, зпіз, roßh, 
   {{0xf9906112,0xe2980e92,0x00000000,0x00000000}},	//   _آبی_, јак_, --, --, 
   {{0x161c00c5,0x00000000,0x00000000,0x00000000}},	//   _पातर_, --, --, --, 
   {{0xa0680022,0x00000000,0x00000000,0x00000000}},	//   раиа_, --, --, --, 
   {{0x09bc04c5,0xc1e000db,0x6d48022e,0xcf4001af}},	//   _আলফা, _فۋشي, evda, дный, 
   {{0x1cb0025c,0x7eac03cd,0x78780118,0x00000000}},	//   _ཐེང_, jøpt, _míva, --, 
   {{0x69c00209,0x78784e00,0x00000000,0x00000000}},	//   ýlel, _líva, --, --, 
   {{0x1b49a2f8,0xc0c8d463,0x29100b67,0x00000000}},	//   азми_, _сузе_, drza_, --, 
   {{0x543800c8,0x787803b2,0x2910033f,0xc0c80092}},	//   בערא, _níva, erza_, _አሶሳ_, 
   {{0x63ac09a5,0x3e7807ea,0x8f980a1e,0x3ec40024}},	//   ýany, _bête_, _דיני, _усеб, 
   {{0x7cd00311,0x6dc40228,0x48e0156e,0x3861def1}},	//   _vărs, _ىزىل, досв, tjir_, 
   {{0x57ea13d2,0xef9001b9,0x69d80166,0x00000000}},	//   рдам_, _آیید, _şwet, --, 
   {{0x16642a30,0x386009f3,0x6e380428,0x779414a5}},	// [3cd40] овам, rjir_, _ñabù, سیسا, 
   {{0x3e7a13d3,0x20c000c6,0xa3cc0490,0x7878219b}},	//   _fête_, lóid_, रधन_, _díva, 
   {{0x9f940510,0x1ae00729,0x7eac168c,0x00000000}},	//   lýär_, _বিয়া, løps, --, 
   {{0x136a13d4,0x3a380869,0x20c001e7,0x00000000}},	//   ишли_, lerp_, nóid_, --, 
   {{0x9f940209,0xded4001f,0xdef8001f,0x96740024}},	//   nýär_, _ከእኔ_, _ለእኔ_, _дыві, 
   {{0x3a380194,0x20c00332,0x6d480162,0x00000000}},	//   nerp_, hóid_, yvda, --, 
   {{0x787800d7,0xb3580066,0x00000000,0x00000000}},	//   _zíva, _گیشا_, --, --, 
   {{0x3a380196,0x104a13d5,0x9f94010b,0x53a4022e}},	//   herp_, ряки_, kýär_, _дабб, 
   {{0x6d480211,0x7eac168c,0x3a384e1b,0x60cc00df}},	//   wvda, jøps, kerp_, ĉamp, 
   {{0x9f940209,0xcdd8026a,0x3a380fac,0xbea401c8}},	//   dýär_, шњи_, jerp_, يهين_, 
   {{0x98b802e2,0x3a3800d8,0x20c000ae,0x00000000}},	//   _aspč_, derp_, fóid_, --, 
   {{0x20c000ae,0x6d48022e,0x71c4014b,0x1ae000eb}},	//   góid_, rvda, _даҷҷ, _বিড়া, 
   {{0x9f940432,0x00000000,0x00000000,0x00000000}},	//   gýär_, --, --, --, 
   {{0x29100034,0x787803b2,0x09bc0011,0x321c0051}},	//   trza_, _ríva, _আলবা, ngvy_, 
   {{0x290613d6,0x98b8007f,0x20c001e7,0x7878032e}},	//   éla_, _espč_, bóid_, _síva, 
   {{0x20c00332,0x6d5c01f4,0x00000000,0x00000000}},	//   cóid_, ärau, --, --, 
   {{0xcce40451,0xc7c807e6,0x20c00332,0x00000000}},	// [3cd50] _اسڪي, рыве_, sóig_, --, 
   {{0x454a13d7,0x3e78e365,0x00000000,0x00000000}},	//   ичем_, _tête_, --, --, 
   {{0xebb80055,0x00000000,0x00000000,0x00000000}},	//   _doḥ_, --, --, --, 
   {{0xdb24006c,0x34940408,0x787801d3,0x00000000}},	//   _بویی, махр, _hívn, --, 
   {{0xe6f40135,0x00000000,0x00000000,0x00000000}},	//   _བསྲན_, --, --, --, 
   {{0x92b00075,0xebb800b8,0x7d041155,0xbb3c0677}},	//   ىڭلا, _goḥ_, ájsk, יעדי, 
   {{0xd24c082e,0x9f9400ee,0x00000000,0x00000000}},	//   طني_, zýär_, --, --, 
   {{0xd12c2085,0x1ad4045e,0x1f64b68c,0x00000000}},	//   امي_, তীয়া, зким, --, 
   {{0xa0207aa0,0xebb80055,0x00000000,0x00000000}},	//   _çöme, _yoḥ_, --, --, 
   {{0x19d80150,0xb35400f2,0x42181e24,0x00000000}},	//   _ﺃﺯﻋﺠ, _آیوا_, _خزرج_, --, 
   {{0x66c80024,0x00000000,0x00000000,0x00000000}},	//   _užku, --, --, --, 
   {{0x2244fa01,0x3a385b5e,0x7cd40356,0x5574010f}},	//   _halk_, werp_, _cărp, פערן_, 
   {{0x60ca13d8,0x224613d9,0x3a3a13da,0x20c000c6}},	//   mmem, _kalk_, terp_, róid_, 
   {{0x9f9409a5,0x60ca13db,0x20c0007b,0x00000000}},	//   rýär_, lmem, sóid_, --, 
   {{0x6d5c007d,0x3a3801af,0x248c05da,0x5d78008f}},	//   ärat, rerp_, _omem_, _לאַק, 
   {{0x60ca13dc,0x09a8015b,0x76800166,0x3a38017a}},	//   nmem, _গৃহা, _köyg, serp_, 
   {{0xdb240108,0x8c18011a,0x60c801f4,0x00000000}},	// [3cd60] öpäp, _הופי, imem, --, 
   {{0x248c55a5,0x60c953d8,0x00000000,0x00000000}},	//   _amem_, hmem, --, --, 
   {{0x89d806a9,0x1d9c02d3,0x60c853b5,0x00000000}},	//   _לחיי, _ዓንቀጽ_, kmem, --, 
   {{0x60c9189e,0x18a46bdd,0x98a484df,0x161c0abd}},	//   jmem, _хамм, _химе, _पावर_, 
   {{0x224613dd,0x60ca13de,0xf2e8036b,0x248c045a}},	//   _balk_, dmem, تکزه_, _dmem_, 
   {{0x60c80472,0x959402dd,0x4270155b,0x09bc0154}},	//   emem, _ешбі, нгіс, _আলতা, 
   {{0x22440591,0xc6900a1e,0x60c80115,0xd9b80210}},	//   _dalk_, _טאש_, fmem, _इरोट, 
   {{0x044213df,0x60c81c04,0x8134005e,0x859802e4}},	//   _песн, gmem, سسىز_, _השלו, 
   {{0xd51000f1,0x24500345,0x00000000,0x00000000}},	//   _زېږد, _جۆنس, --, --, 
   {{0x69c009a5,0xe244007b,0x60c800d7,0x00000000}},	//   ýlek, _يخلي, amem, --, 
   {{0x60c95033,0x7878068c,0x320d245f,0x2ba41df1}},	//   bmem, _nívo, _iddy_, _गुजा, 
   {{0xfe6c00aa,0x101401ec,0x60ca13e0,0x8594008f}},	//   ندۍ_, _ءباد, cmem, לדיג_, 
   {{0x768213e1,0x620000fd,0x4ae40006,0x00000000}},	//   _köyd, _öylä, яўна, --, 
   {{0x6d5c00af,0x1ee803e6,0x224401a9,0x20c00332}},	//   äras, _بووی_, _xalk_, cóib_, 
   {{0x79a4f778,0x9e6407d2,0xad8400db,0x39a4041b}},	//   ерте, _تانن, _تاشۇ, ештв, 
   {{0x7680049b,0x00000000,0x00000000,0x00000000}},	//   _löyd, --, --, --, 
   {{0x7af00122,0xd7e800cf,0x7b140064,0x00000000}},	// [3cd70] čitý, توقۇ_, _здых, --, 
   {{0xfbd00491,0x60c800a8,0xf77042f4,0x248c9ae3}},	//   _حتى_, zmem, داف_, _smem_, 
   {{0x60c84d29,0x76840150,0x00000000,0x00000000}},	//   ymem, хытж, --, --, 
   {{0x2244070d,0x1cb0025c,0x30d01df2,0x00000000}},	//   _salk_, _ཐེབ_, _ﺗﺎﻻﻧ, --, 
   {{0x22445fec,0x60c80790,0x33d402dd,0xfce002dd}},	//   _palk_, vmem, нішт, _ﺍﻟﻤﺫ, 
   {{0xf3ec04a9,0x78780174,0xc4d800f3,0x00000000}},	//   _әң_, _lívl, _гђа_, --, 
   {{0xa020a697,0x224482b8,0xa0a405bc,0xa2d802ab}},	//   _çöke, _valk_, макд, _फंक्, 
   {{0x248e13e2,0x224613e3,0xdef8001f,0xb97c011a}},	//   _umem_, _walk_, _ለእኛ_, מנוי, 
   {{0x60ca13e4,0x2244a67a,0x9e0400f7,0xded4001f}},	//   rmem, _talk_, үчүл, _ከእኛ_, 
   {{0x3e787f70,0x76800213,0x9db80006,0x00000000}},	//   _bêta_, _göyd, жыму_, --, 
   {{0x23e007f7,0x1cb0031c,0x2018067c,0xe1340006}},	//   _फलाद, _ཐེད_, òsis_, _інды, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d5e13e5,0x4c800395,0x00000000,0x00000000}},	//   ärar, тляв, --, --, 
   {{0xaec400d6,0x787804d4,0x3ec400f7,0x76800166}},	//   _збіл, _pívo, _эсеб, _köye, 
   {{0x2d9406bb,0x09e001f4,0x64d801f9,0x00000000}},	//   _пръс, тосн, _बंगळ, --, 
   {{0xa3cc77d7,0x00000000,0x00000000,0x00000000}},	//   रधा_, --, --, --, 
   {{0x7c2613e6,0x0b4213e7,0xe7ec05f9,0x261800af}},	// [3cd80] _icir, _анын, जड़ा_, _पाखी_, 
   {{0x997400f7,0xff444e10,0x787a13e8,0x00000000}},	//   _жумш, _یخ_, _tívo, --, 
   {{0x18684c2c,0x290401ed,0x4a58011a,0x00000000}},	//   _дани_, álat_, _ודיו, --, 
   {{0x768213e9,0x00000000,0x00000000,0x00000000}},	//   _söyd, --, --, --, 
   {{0x1cb00135,0x7680023a,0x00000000,0x00000000}},	//   _ཐེན_, _pöyd, --, --, 
   {{0xdba0001f,0x768000fd,0xa90402f2,0x00000000}},	//   _ወንድም_, _böye, _تبین, --, 
   {{0x7c2613ea,0xfd0413ea,0x787806ea,0xd5b01f7e}},	//   _ocir, _جج_, _lívm, _شفر_, 
   {{0x7c2402c4,0x05543b7a,0x66c80024,0x68e003f2}},	//   _ncir, _تلفظ_, _užkr, íldi, 
   {{0x7eac0162,0x00000000,0x00000000,0x00000000}},	//   tøpp, --, --, --, 
   {{0xdc4400b0,0x4ce40220,0x813400cf,0x00000000}},	//   _rūāw, _ﺍﻟﻭﻻ, سسۉز_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdc4402b5,0x7eac03cd,0x20c00332,0xc0f40023}},	//   _pūāw, søpp, róic_, ለኹም_, 
   {{0x3ce00220,0x00000000,0x00000000,0x00000000}},	//   _ﺍﻟﺼﺤ, --, --, --, 
   {{0x7c2613eb,0xfe6c007b,0xaa94009d,0x00000000}},	//   _ecir, _ندى_, хигч, --, 
   {{0x7c24003a,0x09bc0154,0xac980150,0x283c069d}},	//   _fcir, _আলহা, _ىنتا_, _ቢሮክራ, 
   {{0x787801ed,0xdc4402b5,0x49000137,0x67d40114}},	//   _hívj, _tūāw, нүүг, еобу, 
   {{0x20c000d8,0xaf2800fd,0x00000000,0x00000000}},	// [3cd90] nóia_, _çığu, --, --, 
   {{0xf77001d3,0xd1c00023,0x290613ec,0x00000000}},	//   گاہ_, ስርት_, álas_, --, 
   {{0x69c00790,0x00000000,0x00000000,0x00000000}},	//   üled, --, --, --, 
   {{0xf9fc0003,0xd5a401b9,0xf7700583,0x00000000}},	//   _དབོན_, رلنی, داہ_, --, 
   {{0x27ea13ed,0xfdb802ab,0x768000fd,0x57a401af}},	//   mcan_, _उर्फ, _söye, _зырҡ, 
   {{0x659613ee,0x6384004a,0x057402dd,0x26185d9c}},	//   _загу, _aîné, _قازد, _पाटी_, 
   {{0x66043fa0,0xf20402bf,0x27e8058a,0xd12c06c2}},	//   mahk, тячо, ocan_, ممو_, 
   {{0x6606088e,0x600900ed,0x768000a2,0x00000000}},	//   lahk, чним_, _göyb, --, 
   {{0x64a4005e,0x64480418,0xd4241918,0x27ea13ef}},	//   _жаңа, _iaei, ıştı_, ican_, 
   {{0x7c2613f0,0x9f5c019f,0xf9fc0003,0x64481c1d}},	//   _scir, _jewé_, _དབེན_, _haei, 
   {{0x64480069,0x6d5c0821,0x27e803e0,0xc8d8000d}},	//   _kaei, ärap, kcan_, _मंगट, 
   {{0x66040113,0x20c000d8,0xdb84010b,0x76800205}},	//   hahk, bóia_, егми, _köyc, 
   {{0x660487d3,0x644a13f1,0x7c240327,0x442c00a3}},	//   kahk, _maei, _vcir, ifg_, 
   {{0x660441d0,0x1cb00135,0xd94406d3,0x9f5c007f}},	//   jahk, _ཐེམ_, неги, _rewè_, 
   {{0x660613f2,0x64480428,0x985613f3,0xd1c0069d}},	//   dahk, _oaei, нташ, ስርቶ_, 
   {{0x7c2613f4,0xe10000cc,0x2b9000f2,0x00000000}},	//   _ucir, _এমাহ_, اییس, --, 
   {{0x6b440022,0x29042200,0x60d8047e,0xdd9001d3}},	// [3cda0] _адыҕ, álar_, _miwm, _جوں_, 
   {{0x27ea13f5,0x6605c5f6,0x7bc40064,0x00000000}},	//   acan_, gahk, _iziu, --, 
   {{0x27e80014,0x00000000,0x00000000,0x00000000}},	//   bcan_, --, --, --, 
   {{0x27ea13f6,0x6448056a,0x53a40131,0x60d8015d}},	//   ccan_, _caei, ىماك, _niwm, 
   {{0xf484168d,0x6604f7b2,0x644a13f7,0x787803b2}},	//   _یاری, bahk, _daei, _lívk, 
   {{0xfe6613f8,0x6604122d,0x7bc40998,0xd1c00023}},	//   _صد_, cahk, _mziu, ስርቱ_, 
   {{0x46a213f9,0x442c0204,0x60d8a4fd,0x765c229b}},	//   _сарв, bfg_, _biwm, _inry, 
   {{0x644806d5,0x442c0334,0xf48453b2,0x00000000}},	//   _gaei, cfg_, _شازی, --, 
   {{0x03a053fe,0x60d80142,0x768006be,0x91e001af}},	//   _бито, _diwm, _göyc, _йәйһ, 
   {{0x27ea13fa,0x644801c7,0xe7c401ad,0xdc540014}},	//   zcan_, _zaei, लेटप, ۆرُک, 
   {{0x27e89f20,0xfd7005f5,0x0e640daf,0xac18b4da}},	//   ycan_, глээ, _үкен, мону_, 
   {{0x66043223,0x7878012c,0xce300133,0xac9613fb}},	//   zahk, _dívk, _ڕوتک, тамш, 
   {{0x9f48427e,0x660481be,0xcfa84735,0x765c017a}},	//   _það_, yahk, _عاصم_, _onry, 
   {{0x7bc613fc,0x20c00332,0x787800e5,0x00000000}},	//   _dziu, nóin_, _hívh, --, 
   {{0x27e81bc5,0x9f5c01e1,0x7bc40064,0x6605799f}},	//   tcan_, _rewé_, _eziu, vahk, 
   {{0xfd0c0137,0x765c00a2,0x27ea13fd,0x66040c6a}},	//   _اجو_, _anry, ucan_, wahk, 
   {{0x27ea13fe,0x660402b4,0x7764009a,0x69c00790}},	// [3cdb0] rcan_, tahk, gxix, üleb, 
   {{0x27e85a58,0x06b47c12,0x644800da,0xe6bc05d7}},	//   scan_, رناک_, _saei, ्गेज, 
   {{0x66047807,0x20c00332,0x644a13ff,0x442c0327}},	//   rahk, dóin_, _paei, tfg_, 
   {{0x66048590,0x69c4030a,0x756801ed,0x765c035a}},	//   sahk, _izhe, ریقہ_, _enry, 
   {{0x20c0007b,0x62900022,0x23280818,0x442c0112}},	//   fóin_, аҳаӡ, фоли_, rfg_, 
   {{0x672e1400,0x660405b1,0x06b82b1b,0x644831cf}},	//   mtaj, qahk, _অংকি, _waei, 
   {{0x672e1401,0x644a1402,0x659401f0,0x00000000}},	//   ltaj, _taei, _раву, --, 
   {{0x62200075,0xd9dc023e,0x672c01f7,0xdb0c036e}},	//   _چۈشە, _मल्ट, otaj, ëkët, 
   {{0x672e1403,0x765c00ad,0x00000000,0x00000000}},	//   ntaj, _ynry, --, --, 
   {{0x672e1404,0x63a8004e,0x76800166,0xa15800f3}},	//   itaj, _ixen, _köya, _оазу_, 
   {{0x62821405,0x672c0d77,0x615003e6,0x60d80042}},	//   _illo, htaj, _ڕۆژئ, _tiwm, 
   {{0x672e1406,0x1ae61407,0x77640548,0x00000000}},	//   ktaj, комм, yxix, --, 
   {{0x0b400209,0xdcf02737,0x6280036e,0xa2c400cd}},	//   анян, ıgım, _kllo, ितप्, 
   {{0xe6f41e81,0x672c009b,0x8f9800df,0x00000000}},	//   _བསྟན_, dtaj, _קיסי, --, 
   {{0xc7ec0521,0xa3c402ab,0x672c0356,0x23e00073}},	//   _ụbụr, ॉइड_, etaj, _फलंद, 
   {{0x69c41aa1,0x63aa1408,0x776401c4,0x672e1409}},	//   _dzhe, _oxen, txix, ftaj, 
   {{0x6282140a,0x63a818be,0x69c6140b,0x55e5526e}},	// [3cdc0] _ollo, _nxen, _ezhe, возб, 
   {{0x06800aac,0x62800055,0x39580023,0xb20000fb}},	//   агун, _nllo, ጉራውያ, _таhи, 
   {{0x63a80f71,0x7ae6140c,0x787a140d,0x672c00c7}},	//   _axen, _huit, _lívi, ataj, 
   {{0x7ae6140e,0xd7043117,0x6282140f,0x161c05f9}},	//   _kuit, _изми, _allo, _पाकर_, 
   {{0x6280044e,0x7ae40286,0xf53401ec,0x78780174}},	//   _bllo, _juit, _ءﺳﻮﻳ, _nívi, 
   {{0x7ae61410,0xc7b0025f,0x765c0042,0x00000000}},	//   _muit, _כבר_, _unry, --, 
   {{0x7ae61411,0x63a809ff,0x4a9800c8,0x20c10ca1}},	//   _luit, _exen, ויסג, róin_, 
   {{0x62821412,0x93581ee3,0x73c40032,0x7ae40165}},	//   _ello, _орзу_, _йәле, _ouit, 
   {{0x7ae61413,0x787a1414,0x6280036e,0xcce402dd}},	//   _nuit, _cívi, _fllo, _ﺍﻟﺸﻔ, 
   {{0x787a1415,0x9f4c0086,0x7cd40311,0x6280036e}},	//   _dívi, taeò_, _gărz, _gllo, 
   {{0xfe6c0597,0x7ae61416,0x2fd401e0,0x8d84010b}},	//   تدي_, _auit, _өҫкө_, тупд, 
   {{0x7ae61417,0xa1100050,0x6b68002e,0x672c21ed}},	//   _buit, _اڈوت, _nëgë, ytaj, 
   {{0x62800142,0x672c0327,0x0b8801a9,0x00000000}},	//   _yllo, xtaj, фсни_, --, 
   {{0x7ae46404,0xb4c000cd,0x00000000,0x00000000}},	//   _duit, ीषु_, --, --, 
   {{0xfce0026a,0x7ae4003a,0x6d361418,0x9e6402dd}},	//   _којо, _euit, _сейф, _حانن, 
   {{0x672c0664,0x7ae61419,0x76800213,0x778c0165}},	//   ttaj, _fuit, _röya, p̓x̣, 
   {{0x6b681574,0x7ae53722,0x672e141a,0x81e403d4}},	// [3cdd0] _dëgë, _guit, utaj, পৰি_, 
   {{0xabb4035b,0xfcec0092,0x00000000,0x00000000}},	//   _иақә, _ቀረጥ_, --, --, 
   {{0x84640408,0xf5e40212,0xe896141b,0x9f4802d2}},	//   къде, ріум, _бань, _þaö_, 
   {{0x672e141c,0x628002d3,0x81e40183,0x7ae4037e}},	//   ptaj, _sllo, পৰা_, _yuit, 
   {{0x7ae4bb92,0x6280036e,0xcce401ec,0x00000000}},	//   _xuit, _pllo, _ﺍﻟﺴﻔ, --, 
   {{0x787803b2,0x76800716,0xb22400d4,0x00000000}},	//   _rívi, _töya, иміл, --, 
   {{0x68e4016d,0x6b6800e8,0x7682141d,0xd1f40023}},	//   _juhd, _yëgë, _köyn, _ወቕቲ_, 
   {{0x5ef94479,0xe6f4025c,0x63a8009d,0xdf494d3e}},	//   нхор_, _བསྙན_, _txen, езид_, 
   {{0xc340074d,0x5f0400cf,0x6d5c248f,0x00000000}},	//   _тĕп_, ызпа, åran, --, 
   {{0x7ae40e7a,0x62800af5,0x290002b5,0x78781ada}},	//   _ruit, _ullo, _owha_, _vívi, 
   {{0x7ae5f0bb,0x3b000369,0x61e00194,0x2b4800b8}},	//   _suit, _swiq_, _igll, _asac_, 
   {{0x7ae41e89,0xeff8001f,0x60cc0337,0x00000000}},	//   _puit, _ወስዶ_, ŋamb, --, 
   {{0x290002b5,0x7ae6141e,0xbf64484d,0xfa840131}},	//   _awha_, _quit, _جداو, иқим, 
   {{0x7ae6141f,0x1d0800c7,0x8f980a1e,0x6e942d4f}},	//   _vuit, _зеки_, _איני, _кичу, 
   {{0x6e3400e5,0x00000000,0x00000000,0x00000000}},	//   égbő, --, --, --, 
   {{0x7ae61420,0x787803b2,0x00000000,0x00000000}},	//   _tuit, _lívv, --, --, 
   {{0x9b447b63,0xb6440092,0x00000000,0x00000000}},	// [3cde0] _صندو, _የማውቀ, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x68e40007,0xb7d80133,0x00000000,0x00000000}},	//   _guhd, روڕا_, --, --, 
   {{0x76804e7e,0x00000000,0x00000000,0x00000000}},	//   _göyn, --, --, --, 
   {{0x68e61421,0x61e00142,0xe744ca0f,0x20c001e7}},	//   _zuhd, _bgll, _күте_, róil_, 
   {{0x20c00332,0x00000000,0x00000000,0x00000000}},	//   sóil_, --, --, --, 
   {{0xd77400db,0x128807d6,0x212800f1,0x78a40037}},	//   _شاڭع, ومچی_, نيوی_, oniv, 
   {{0x10080137,0x00000000,0x00000000,0x00000000}},	//   رتبى_, --, --, --, 
   {{0x20d000c0,0x78a40254,0xf2c4004e,0x0838010f}},	//   _ašis_, iniv, _көки, געפל, 
   {{0x2b480334,0x6e9400c7,0x73c401af,0x00000000}},	//   _rsac_, риоу, _йәһе, --, 
   {{0x78a51bd3,0xc04e1422,0x00000000,0x00000000}},	//   kniv, _лі_, --, --, 
   {{0x68e61423,0x78a40200,0x00000000,0x00000000}},	//   _ruhd, jniv, --, --, 
   {{0x68e402f6,0x78a61424,0xaa480240,0x00000000}},	//   _suhd, dniv, _ብምልጋ, --, 
   {{0x68e61425,0x78a61426,0x753c012d,0xbea00354}},	//   _puhd, eniv, _oprz, _лачк, 
   {{0x787803b2,0x8274008f,0xa2c400dc,0x645c148b}},	//   _lívu, נעלע_, ितत्, _ósig, 
   {{0x6d580e02,0x78a61427,0xf804004e,0x00000000}},	//   _irva, gniv, йчун, --, 
   {{0x6d58071b,0x2ca80428,0x78780162,0x25e80037}},	// [3cdf0] _hrva, _ijad_, _nívu, _जलदी_, 
   {{0x78a61428,0x68e5cebb,0xc984dee8,0xa5f8009b}},	//   aniv, _tuhd, _буми, тежу_, 
   {{0x2d8c0007,0x29000374,0x78a401e4,0x76800139}},	//   nzde_, _uwha_, bniv, _töyn, 
   {{0x24198232,0x3cf8008f,0x76801611,0x00000000}},	//   тоды_, גלאנ, _höyl, --, 
   {{0x7680ca2c,0xe3657881,0x00000000,0x00000000}},	//   _köyl, ркли, --, --, 
   {{0x787802d2,0xe19400ee,0x20080064,0x00000000}},	//   _dívu, ирйэ, _žai_, --, 
   {{0x20180798,0xfa780375,0x20c01463,0x00000000}},	//   ósio_, רעות_, sóim_, --, 
   {{0x1fb61429,0x7680005b,0x26c00327,0x00000000}},	//   испр, _löyl, llho_, --, 
   {{0x4f05308b,0x6d5a142a,0x1e86142b,0x787803b2}},	//   анын_, _arva, илим, _gívu, 
   {{0x78a6142c,0x2ca800c5,0x337400ee,0x8eb02f84}},	//   zniv, _ajad_, _угур, يميش, 
   {{0xddc6142d,0x6d5805be,0x2ca80327,0x70840228}},	//   рбни, _crva, _bjad_, ргөз, 
   {{0x673e142e,0x43c00150,0x00000000,0x00000000}},	//   _opsj, _ﺩﻭﯕﺪ, --, --, 
   {{0x6d589b80,0x76800ab7,0x69c003ee,0x78a489d4}},	//   _erva, _böyl, ülen, vniv, 
   {{0x787803b2,0xd65c01ec,0xd354011a,0x00000000}},	//   _lívt, лiнд, בישי_, --, 
   {{0xd946142f,0x26c000d0,0x78a61430,0x6aa80de2}},	//   шеви, dlho_, tniv, éefa, 
   {{0x66140263,0x78a61431,0x26c000d8,0x1ae4014b}},	//   _adzk, univ, elho_, _коим, 
   {{0x753c14cf,0x5ac8049e,0x9a1800db,0x629c01e1}},	// [3ce00] _sprz, _илим_, _июну_, _ìsow, 
   {{0x3ce0009a,0x787803b2,0x76800213,0xd1dc0023}},	//   _hiiv_, _rívu, _göyl, ቕርብ_, 
   {{0x9200005f,0x661400ef,0x00000000,0x00000000}},	//   šāka, _ddzk, --, --, 
   {{0xe4a400d4,0x00000000,0x00000000,0x00000000}},	//   бріо, --, --, --, 
   {{0xf2e85d28,0x8c34010f,0x00000000,0x00000000}},	//   اکره_, שטנס_, --, --, 
   {{0x3e7800d2,0x8b5400c8,0x7d000c8c,0xddc000d0}},	//   _fêti_, יינס_, _owns, pelň, 
   {{0x753c0034,0xf2040150,0x00000000,0x00000000}},	//   _uprz, аяқо, --, --, 
   {{0x3ce001c4,0x00000000,0x00000000,0x00000000}},	//   _niiv_, --, --, --, 
   {{0x61ec0882,0x7d009ff5,0x0874008f,0x4fc43d89}},	//   śala, _awns, שעפט_, шска, 
   {{0x6d581883,0x00000000,0x00000000,0x00000000}},	//   _prva, --, --, --, 
   {{0x104800d1,0x3e653f3c,0x7d00015d,0x9f68013e}},	//   _аяли_, ршын_, _cwns, врӯз_, 
   {{0x768012ca,0xc1980302,0x00d402dd,0x00000000}},	//   _söyl, _בשבי, _ﺟﺎﺳﻘ, --, 
   {{0x78780579,0x2f18e834,0xfe6c01b9,0x7d0002d0}},	//   _lívs, _соль_, سدی_, _ewns, 
   {{0x6d58278a,0x8d761432,0xfd942ab4,0x7f38010f}},	//   _trva, _ناعا, ائیت_, _סעוו, 
   {{0x6d5a1433,0xe81805f5,0x7d0003cb,0xd1dc0023}},	//   _urva, ловч_, _gwns, ቕርቦ_, 
   {{0x673c0066,0x76800213,0x37a800cc,0xddc4009f}},	//   _ppsj, _döym, _খৰধৰ, _اآهي, 
   {{0x26c09e60,0x7990013f,0x6d480009,0xa6161434}},	// [3ce10] tlho_, _ɑkwɑ, lwda, ймач, 
   {{0xc61c00bd,0x6d48058a,0x00000000,0x00000000}},	//   ন্না_, owda, --, --, 
   {{0xa2c400dc,0x45480395,0x00000000,0x00000000}},	//   ितस्, ъчам_, --, --, 
   {{0x8880006c,0x5dd8008f,0x74a41fbe,0x2258010e}},	//   _بیرن, אַנס, ојче, _şsk_, 
   {{0xc7640131,0x29100210,0x00000000,0x00000000}},	//   _ئاجى, lsza_, --, --, 
   {{0xa2286c20,0x6a780241,0x00000000,0x00000000}},	//   ужка_, _tìfu, --, --, 
   {{0x29100210,0x00000000,0x00000000,0x00000000}},	//   nsza_, --, --, --, 
   {{0xd00c2e51,0xd5a4429e,0x5f04035b,0x81e40154}},	//   ىلى_, _الفی, бзиа, পরই_, 
   {{0x249c03cb,0x00000000,0x00000000,0x00000000}},	//   miwm_, --, --, --, 
   {{0x1e84c4b4,0xbe8001d5,0x249c0042,0x1ae40154}},	//   слом, юқли, liwm_, _কবলে_, 
   {{0x29104579,0x5ec80154,0x3ce00220,0x128801e2}},	//   jsza_, রদলে, _ﺍﻟﺒﺤ, _حملی_, 
   {{0xa2c40882,0x249c0368,0x78794875,0xdca61435}},	//   ितव्, niwm_, _lívr, сами, 
   {{0x200c0381,0x6d4870d4,0xc61c0011,0x76821436}},	//   maei_, awda, ন্যা_, _söym, 
   {{0x200cfeec,0xad2400ec,0x00000000,0x00000000}},	//   laei_, _ڀريو, --, --, 
   {{0x7e60168c,0x76800139,0x00000000,0x00000000}},	//   _innp, _qöym, --, --, 
   {{0x200e1437,0x63ac0210,0x00000000,0x00000000}},	//   naei_, żany, --, --, 
   {{0x237c0369,0x249c03cb,0x00000000,0x00000000}},	// [3ce20] jywj_, diwm_, --, --, 
   {{0xd05c013f,0x200c0381,0x7680013d,0x2910012d}},	//   _ɑyɑy, haei_, _töym, bsza_, 
   {{0x795403e6,0x76800108,0xd70801ec,0x00000000}},	//   _بێزا, _höyk, _әнге_, --, 
   {{0x98680276,0x23d815e0,0x2bd4466d,0x768001f4}},	//   _симб_, _बृहद, ठेवा, _köyk, 
   {{0x200c16b8,0x96540395,0x00000000,0x00000000}},	//   daei_, _лъвч, --, --, 
   {{0x76800108,0x00000000,0x00000000,0x00000000}},	//   _möyk, --, --, --, 
   {{0xc75c001f,0x00000000,0x00000000,0x00000000}},	//   _ሰራተኛ_, --, --, --, 
   {{0x200c003a,0x2ef5ff9c,0xb6180150,0x4fc400c0}},	//   gaei_, озир, _ﹼﻙ_, йспа, 
   {{0xb1e40058,0xdeb8001f,0x93a801ed,0x0e08010b}},	//   _һәққ, _ታማኝ_, _صارف_, лэни_, 
   {{0x187c001f,0xa0a400db,0x29100210,0x00000000}},	//   _የገጠር_, йшөл, ysza_, --, 
   {{0xc20c0050,0x200c0393,0x6d4801a4,0x02c00108}},	//   _سٔن_, baei_, uwda, _эйфо, 
   {{0x69c00365,0x7e6015df,0x200c0393,0x99980024}},	//   ülem, _ennp, caei_, _lapų_, 
   {{0x17200156,0x2910033f,0xbf3003ff,0xbb480014}},	//   ོངསམ_, wsza_, _فروغ, ٕلُن_, 
   {{0x5f4003e6,0xba280014,0x29112e75,0xc33000df}},	//   _کۆیل, ٝسِم_, tsza_, הוש_, 
   {{0xc61c015b,0x2904180f,0xfe6c31b1,0x00000000}},	//   ন্ডা_, èla_, _سدو_, --, 
   {{0x2910033f,0x76800108,0x00000000,0x00000000}},	//   rsza_, _höyh, --, --, 
   {{0x2910066d,0xe71805d4,0x768002f6,0xe6980e58}},	// [3ce30] ssza_, شيات_, _köyh, аваш_, 
   {{0x29100034,0xb714005b,0x00000000,0x00000000}},	//   psza_, ядущ, --, --, 
   {{0x768001f4,0x00000000,0x00000000,0x00000000}},	//   _möyh, --, --, --, 
   {{0xecc8c853,0x76800108,0x00000000,0x00000000}},	//   रतिफ, _löyh, --, --, 
   {{0x200c0421,0xa2c40490,0x194c00b5,0x249c015d}},	//   vaei_, ितल्, _ｃｓｖ_, riwm_, 
   {{0x65940323,0xd76400cf,0x249c0042,0x823400ae}},	//   _дагу, _بەكى_, siwm_, إرشا, 
   {{0x8554df89,0x200c7691,0xdcf4005f,0xd12c27b4}},	//   _دیار_, taei_, ēcīg, نمو_, 
   {{0xdb14010e,0xf4340276,0x9375be71,0x69d0000d}},	//   _azyý, _несэ, сбәт_, _धरनी, 
   {{0x33580276,0x200e1438,0x50900451,0x3ce00046}},	//   _латэ_, raei_, بليء, _ﺍﻟﺘﺤ, 
   {{0x200e1439,0xd05803b9,0x768001f4,0x439000fb}},	//   saei_, _mutə, _röyk, _дағс, 
   {{0xdc69a7d1,0xc61c02f5,0x200c0393,0x76806656}},	//   аанд_, ন্থা_, paei_, _söyk, 
   {{0xdc98030d,0x64bc00b8,0x00000000,0x00000000}},	//   ртош_, _ṇija, --, --, 
   {{0x94b80115,0x00000000,0x00000000,0x00000000}},	//   שמרת, --, --, --, 
   {{0xa86400fb,0x71700116,0x00000000,0x00000000}},	//   үерҙ, _زۇۋا, --, --, 
   {{0x38c95e2f,0x09e0cb42,0xf41400fe,0x00000000}},	//   ماری_, дорн, ণ্টৰ_, --, 
   {{0x3e7806af,0x76800108,0x00000000,0x00000000}},	//   _vêtu_, _töyk, --, --, 
   {{0xdb1400a2,0x00000000,0x00000000,0x00000000}},	// [3ce40] _yzyý, --, --, --, 
   {{0xd62400c6,0x3e7806af,0x76800205,0x00000000}},	//   تعري, _têtu_, _köyi, --, 
   {{0x53e40d30,0x569401e0,0x13e80354,0x00000000}},	//   оцла, баҡт, амей_, --, 
   {{0x7414029e,0x25700e56,0x00000000,0x00000000}},	//   سوتا, رۇقس, --, --, 
   {{0xc61c045e,0x92683e4f,0x00000000,0x00000000}},	//   ন্ধা_, ирка_, --, --, 
   {{0xdce8012c,0xda0823ff,0x3e780142,0x00000000}},	//   íněn, वरित_, _mêts_, --, 
   {{0x7bc403a2,0x7680005b,0x00000000,0x00000000}},	//   _lyiu, _röyh, --, --, 
   {{0xc61c0f22,0xdce00024,0xc32000d1,0x3014010b}},	//   ন্দা_, mylė, чмәк, чдир, 
   {{0x03a2143a,0x7bc54dbe,0x41a40131,0x76800108}},	//   _жито, _nyiu, йвән_, _pöyh, 
   {{0x69c2143b,0x4220223e,0xb62c019b,0xdc300171}},	//   ülek, _одув, _ｔｖ_, _eļļi, 
   {{0xcf2400ec,0x00000000,0x00000000,0x00000000}},	//   _ڀرتي, --, --, --, 
   {{0x2cac000d,0x629c01e1,0x00000000,0x00000000}},	//   õed_, _ìsor, --, --, 
   {{0x320c01a2,0x09e000dc,0x768001f4,0x00000000}},	//   _kedy_, पश्य, _töyh, --, 
   {{0x320c02f0,0xc98400f3,0xdce000c0,0x00000000}},	//   _jedy_, оуби, kylė, --, 
   {{0x320c02f0,0xd05806be,0x00000000,0x00000000}},	//   _medy_, _sutə, --, --, 
   {{0x320c3166,0x00000000,0x00000000,0x00000000}},	//   _ledy_, --, --, --, 
   {{0x342c0092,0x00000000,0x00000000,0x00000000}},	// [3ce50] ተዳደሪ, --, --, --, 
   {{0x69340276,0x45c4005b,0x20c000e5,0x00000000}},	//   _еноу, ощеб, lóit_, --, 
   {{0xdb14010e,0x00000000,0x00000000,0x00000000}},	//   _eyyä, --, --, --, 
   {{0xd380040d,0xf49404fb,0xf4840fcb,0x00000000}},	//   ﯩﻠﯩﻖ_, وشند, мучн, --, 
   {{0x320c06d9,0x29e002a8,0x69c40200,0x6264009b}},	//   _bedy_, lɗa_, _hyhe, звла, 
   {{0x09dc8961,0xe1f1252c,0xa1880474,0x2174084c}},	//   _ব্যা, رست_, йбла_, зуир, 
   {{0x91e00d5c,0x320c3132,0x29e00198,0x69c4062c}},	//   ноше, _dedy_, nɗa_, _jyhe, 
   {{0xc3d801ec,0x00d40220,0x659401f0,0x00000000}},	//   _көлi, _ﺟﺎﺗﻘ, _даҳу, --, 
   {{0x69c6143c,0x00000000,0x00000000,0x00000000}},	//   _lyhe, --, --, --, 
   {{0x443c002d,0x320c3c75,0xff2400b5,0x00000000}},	//   _hbu_, _gedy_, _phpを, --, 
   {{0x69c40654,0x9f5c145e,0x443c01bf,0x326401d5}},	//   _nyhe, _sewä_, _kbu_, _ўтув, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x443e143d,0x69c402d0,0xdcb800d1,0xf0b802da}},	//   _mbu_, _ayhe, игүч_, _بالش_, 
   {{0x69c4000f,0x443c0066,0x2ec00022,0x00000000}},	//   _byhe, _lbu_, _иҩым, --, 
   {{0x443d2d9a,0x18682875,0xdcf804fb,0x69d0085c}},	//   _obu_, бави_, _ارتش_, _धरणी, 
   {{0x443e143e,0x48e11fcd,0x69c4996f,0xe758032e}},	//   _nbu_, еосв, _dyhe, _eþíó, 
   {{0x46e400f7,0x20c001e7,0x4b200064,0x00000000}},	// [3ce60] здун_, lóis_, _змыв, --, 
   {{0x443e143f,0xdce00153,0x69c4036e,0x00000000}},	//   _abu_, tylė, _fyhe, --, 
   {{0x443c0083,0x20c0007b,0x4a78011a,0x00000000}},	//   _bbu_, nóis_, _הריב, --, 
   {{0x443e1440,0x320c1155,0x69d0121d,0x00000000}},	//   _cbu_, _sedy_, _धरती, --, 
   {{0x443e1441,0x00000000,0x00000000,0x00000000}},	//   _dbu_, --, --, --, 
   {{0x443e1442,0xe8e800f1,0x645c02d2,0xd6d00066}},	//   _ebu_, _دریو_, _ósin, _سقز_, 
   {{0x320c0030,0x443ccc31,0x75840244,0x00000000}},	//   _vedy_, _fbu_, _تیام, --, 
   {{0x443e1443,0x69c001d3,0x320c0142,0x66d002d2}},	//   _gbu_, ülei, _wedy_, _tóký, 
   {{0x320c0316,0xaed40364,0xe0540214,0xcce40046}},	//   _tedy_, моиш, بینت_, _ﺍﻟﺘﻔ, 
   {{0x9f4c004e,0x629c0248,0x82a001f4,0x00000000}},	//   cceí_, _ìsop, _зауж, --, 
   {{0x20c000e5,0xfe200124,0xe81c000d,0x00000000}},	//   tóit_, хьын, _बएला_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x20f4166a,0x7b661444,0x20c000ae,0xa8b001e1}},	//   _iāia_, нтре, róit_, _ìfé̟_, 
   {{0xdfa40491,0x0af001c0,0xd1c00023,0x7eb401ec}},	//   _تحمي, _үүнэ, _ድሩት_, _егіс_, 
   {{0x20c1776a,0x0d6402e8,0x00000000,0x00000000}},	//   cóis_, _хълм, --, --, 
   {{0x29e00198,0x20c0007b,0x69c41155,0x4900004e}},	//   rɗa_, lóir_, _vyhe, мүүг, 
   {{0x20f404fe,0x443c0263,0x09280451,0xefe40092}},	// [3ce70] _māia_, _rbu_, _ڏسجي_, _ማዘዣ_, 
   {{0x443c017d,0x9738044e,0x20c000c6,0x00000000}},	//   _sbu_, እሰያት, nóir_, --, 
   {{0xfbd002f2,0x00000000,0x00000000,0x00000000}},	//   _لتی_, --, --, --, 
   {{0x16944be7,0x20c00597,0x20f400b0,0x00000000}},	//   _መጨረሻ_, hóir_, _nāia_, --, 
   {{0x20c000d8,0xdb1400a2,0x0ae800eb,0xa2940150}},	//   zóis_, _yzyñ, _কবুল_, маді, 
   {{0x6144084c,0xa1c61445,0x21680108,0x768003b9}},	//   дека, мблд, жики_, _böyu, 
   {{0x20c000c6,0xd24c0451,0x443d6f4c,0x629c0064}},	//   dóir_, شني_, _tbu_, _įsod, 
   {{0x443e1446,0x1f640229,0x00000000,0x00000000}},	//   _ubu_, дким, --, --, 
   {{0x248c154a,0x1cb80327,0x00000000,0x00000000}},	//   _ilem_, ྙོལ_, --, --, 
   {{0x645a1447,0x20c00597,0xb3540f06,0x00000000}},	//   ldwi, góir_, _якуш, --, 
   {{0x248c131f,0x645a1448,0xc0d00092,0x00000000}},	//   _klem_, odwi, _ያገር_, --, 
   {{0x645a1449,0x20c1bd2b,0x768001f4,0xd65c0150}},	//   ndwi, róis_, _höyt, кiлд, 
   {{0x60ca144a,0xda64082e,0xb7f400c5,0x768001f4}},	//   mlem, واسي, _अलबम_, _köyt, 
   {{0xd94606ef,0x0e602eca,0xb9ec015b,0x1d0800f3}},	//   меги, _акшн, কর্ড_, _деки_, 
   {{0x248c08cd,0x60ca144b,0x1dd03af4,0x00000000}},	//   _olem_, olem, _हरित, --, 
   {{0x76800664,0x60c80365,0x645801f5,0xa8540063}},	//   _löyt, nlem, jdwi, нтуј, 
   {{0x07a2144c,0xc7a00b7b,0x60c8023a,0x64580142}},	// [3ce80] ватн, витк, ilem, ddwi, 
   {{0x60ca144d,0x248e144e,0x645a144f,0x442c34c2}},	//   hlem, _alem_, edwi, egg_, 
   {{0x60ca1450,0x248e1451,0x201c0455,0x6458017a}},	//   klem, _blem_, _odwi_, fdwi, 
   {{0x201e1452,0x248e1453,0x98a40c56,0x6b880158}},	//   _ndwi_, _clem_, _циме, øegg, 
   {{0x20f400b0,0x69c000c5,0x78a61454,0x768000fd}},	//   _rāia_, ülev, miiv, _söyu, 
   {{0x78a61455,0x64593f5b,0x9f5c01e1,0x248dac56}},	//   liiv, adwi, _fewú_, _elem_, 
   {{0x248c1570,0x20f402b1,0x60c80790,0x3af400fd}},	//   _flem_, _pāia_, flem, _läp_, 
   {{0x60ca1456,0x248c4e9b,0x78a61457,0x00d4009f}},	//   glem, _glem_, niiv, وبيت_, 
   {{0x20c000c6,0xc47407d6,0x00000000,0x00000000}},	//   tóir_, _تینچ_, --, --, 
   {{0x60ca1458,0x78a425c6,0x11d41d93,0x0dc801b9}},	//   alem, hiiv, _قتاد, жуми_, 
   {{0x20f404fe,0x20c000c6,0x78a49abd,0x7680005b}},	//   _tāia_, róir_, kiiv, _höys, 
   {{0x101466df,0x60ca1459,0x76802ecb,0x20c0007b}},	//   _آباد, clem, _köys, sóir_, 
   {{0x78a40641,0xfe6c00f1,0x00000000,0x00000000}},	//   diiv, _ږدي_, --, --, 
   {{0x5a281b4b,0x8d7519b2,0x3af400ee,0x6d5c0267}},	//   _སྐྱེ_, _ياغا, _däp_, åras, 
   {{0x442ca823,0x768002f6,0x201c0042,0x79a40120}},	//   ygg_, _löys, _ydwi_, врте, 
   {{0x78a40869,0x48bc0183,0xeda401b9,0x478401ec}},	//   giiv, ্দ্ৰ, _ошқо, мызб, 
   {{0x3b56145a,0x3af40166,0x442c26bd,0x57a400fb}},	// [3ce90] _акыр, _gäp_, vgg_, ныфҡ, 
   {{0x60ca145b,0x248c06a3,0xd7080131,0xbb481079}},	//   zlem, _slem_, سىمۇ_, _کلین_, 
   {{0x60ca145c,0x60cc0337,0x768003b9,0x8b6401e2}},	//   ylem, ŋami, _röyt, _راکم, 
   {{0x78a401e4,0x23b42160,0x00000000,0x00000000}},	//   ciiv, ىماس, --, --, 
   {{0x836577bc,0x645a145d,0xd12c0efb,0x768002f6}},	//   بدال, rdwi, ەمى_, _pöyt, 
   {{0x672c01f7,0x442c0077,0x768006be,0x00000000}},	//   muaj, sgg_, _döys, --, 
   {{0x60ca145e,0x26c2145f,0x672e1460,0x00000000}},	//   tlem, moho_, luaj, --, 
   {{0x60ca1461,0x26c21462,0x02480014,0x248e1463}},	//   ulem, loho_, _ژجاو_, _ulem_, 
   {{0x60c83107,0xe2c800dd,0x672c009f,0x768001f4}},	//   rlem, _فورو_, nuaj, _töyt, 
   {{0x60ca1464,0x26c21465,0x7680023a,0x78a43dd9}},	//   slem, noho_, _höyr, ziiv, 
   {{0x60c9e5d2,0x78a405b1,0x672c02d1,0xdca4146a}},	//   plem, yiiv, huaj, еани, 
   {{0x201c014b,0x672e1466,0x5f961467,0x00000000}},	//   _udwi_, kuaj, _пиет, --, 
   {{0x26c21468,0x672e1469,0x6d5c3953,0x78a6146a}},	//   koho_, juaj, årar, viiv, 
   {{0x78a4009a,0x26c0037e,0x672e146b,0x53980a7c}},	//   wiiv, joho_, duaj, לירו, 
   {{0x78a57701,0xdca6146c,0x26c00c6a,0xdbd00254}},	//   tiiv, _паки, doho_, lüüm, 
   {{0xc028001f,0x672c009f,0x7680023a,0x3af420b2}},	//   _ተቀብለ, fuaj, _nöyr, _täp_, 
   {{0x672e146d,0xdbd000c5,0x2b9001d9,0x78a40337}},	// [3cea0] guaj, nüüm, _نیَس, riiv, 
   {{0x78a6146e,0x26c00099,0x47c05232,0x6b880fac}},	//   siiv, goho_, убув, øege, 
   {{0x69c0066d,0x4a98008f,0x94246d66,0x142431e2}},	//   ület, _זייג, емее, едем, 
   {{0x78a40194,0x672c009f,0x23680115,0x768001f4}},	//   qiiv, buaj, ĥajn_, _pöys, 
   {{0x26c2146f,0x672c0789,0x8c18011a,0x00000000}},	//   boho_, cuaj, פוסי, --, 
   {{0xc3241b56,0x26c00419,0x00000000,0x00000000}},	//   ركىن_, coho_, --, --, 
   {{0xd5b06bcc,0x3b00022e,0xa2c4206b,0x20c001e7}},	//   _صفر_, _ltiq_, ितज्, tóip_, 
   {{0x81421470,0x76800108,0x6d5c01bf,0x73c401af}},	//   انين, _töys, æram, _иәле, 
   {{0xc1380051,0x20c00332,0x00000000,0x00000000}},	//   _kướp_, róip_, --, --, 
   {{0x03540116,0x91940063,0x236800ec,0x4798011a}},	//   _чүшә_, _пјеш, _تحفي_, פייס, 
   {{0x3b021471,0xc6900302,0xc138004d,0xac942d3c}},	//   _atiq_, ראת_, _mướp_, ванш, 
   {{0x26c002b9,0x235c0023,0x6ad8043e,0x16bc1777}},	//   zoho_, _ተልእኾ_, णग्र, ्तुब, 
   {{0x7cfc0276,0x0c840166,0x9f3400e5,0x601401af}},	//   vârş, _җыйм, _لونڈ, _рєхє, 
   {{0x1ea805d9,0xfe6c007b,0x672c036e,0xff0400d8}},	//   _ٺاهي_, _هدى_, vuaj, _џејк_, 
   {{0x9e661472,0x26c003d1,0xc0d00092,0xe91800d4}},	//   _جانن, voho_, _ያለህ_, ьові_, 
   {{0xe7940014,0x67d40212,0x00000000,0x00000000}},	//   پارک, вобу, --, --, 
   {{0x16bc0e7d,0x26c21473,0x9f4c02e2,0x0a6801b9}},	// [3ceb0] ्तूब, toho_, aceæ_, _ерни_, 
   {{0xc1380016,0x69c12c4a,0x672c9718,0x2b480175}},	//   _cướp_, üles, ruaj, _ipac_, 
   {{0x09dc03f4,0x26c21474,0x672c00ec,0x645c0162}},	//   _ব্রা, roho_, suaj, _ósik, 
   {{0x29021475,0x26c001fa,0x672d2f90,0x00000000}},	//   _itha_, soho_, puaj, --, 
   {{0x26c21476,0x672c0023,0xdd000e04,0x47dc0154}},	//   poho_, quaj, _čučn, _ফ্রী, 
   {{0x290006a3,0x21a43298,0x00000000,0x00000000}},	//   _ktha_, килм, --, --, 
   {{0x52500451,0x768001f4,0xd60000d1,0x00000000}},	//   شنيء, _töyr, _ئېمپ, --, 
   {{0x44f44a98,0xa4d41ed2,0x5ef8aeb2,0x29000200}},	//   _iç_, _робі, мхор_, _mtha_, 
   {{0x3f8801a2,0x3495b02e,0xe21400c7,0x5f040395}},	//   ácu_, _сатр, _амзы, ъзпа, 
   {{0x29021477,0x3b00022e,0x01e00154,0x9f4801e1}},	//   _otha_, _rtiq_, নুষদ, _àkís_, 
   {{0x290006d6,0x2b480083,0x3f8839ae,0xdbd0000d}},	//   _ntha_, _apac_, šcu_, süüm, 
   {{0xdca61478,0x5f740c8b,0xbd6000db,0x00000000}},	//   тами, _لاتر, _ۅپتۉ, --, 
   {{0x29021479,0x44f6147a,0x09dc015b,0x00000000}},	//   _atha_, _lç_, _ব্লা, --, 
   {{0x2b4800ca,0xddc40209,0x44f40166,0x7c440055}},	//   _dpac_, _ибли, _oç_, _śurā, 
   {{0x2b4802ce,0x18a406ed,0x44f427ac,0x00000000}},	//   _epac_, вавм, _nç_, --, 
   {{0xa2a01b61,0xa9f801c6,0x999c00e5,0x00000000}},	//   कोत्, _үхэх_, ütő_, --, 
   {{0x69c0509e,0x44f6147b,0x3b000309,0x2900176d}},	// [3cec0] üler, _aç_, _utiq_, _etha_, 
   {{0x5984014b,0x00000000,0x00000000,0x00000000}},	//   _алоб, --, --, --, 
   {{0xd82403b7,0x00000000,0x00000000,0x00000000}},	//   _идни, --, --, --, 
   {{0x52c800dc,0x2b480024,0x94243004,0x44f403e3}},	//   ित्स, _ypac_, тмде, _dç_, 
   {{0x44f40166,0xe7d400d4,0xb634179e,0x00000000}},	//   _eç_, _бірю, _مکاش, --, 
   {{0x43800075,0x00000000,0x00000000,0x00000000}},	//   شلىق, --, --, --, 
   {{0x765c035a,0x46a0d021,0x95ec012d,0x00000000}},	//   _iary, _тарв, जशीट_, --, 
   {{0x765e147c,0x60d803cb,0x85540375,0xc32400f7}},	//   _hary, _chwm, _בשלב_, ركۉن_, 
   {{0x70440e76,0xb4c036c7,0x00000000,0x00000000}},	//   _ەرتە, ुती_, --, --, 
   {{0x6e940e26,0x765c1e0b,0x73c401af,0x20c400db}},	//   الدا, _jary, _иәһе, ксөг, 
   {{0x765e147d,0x91e4aabd,0xc04c24d8,0xd09400c7}},	//   _mary, _роже, _кі_, _ишды, 
   {{0x765e147e,0x38780020,0x6abcbc82,0x389c001f}},	//   _lary, _አገሪቱ_, ोत्र, _ሀገሪቱ_, 
   {{0x765c02d0,0x2900002b,0x00000000,0x00000000}},	//   _oary, _stha_, --, --, 
   {{0x765e147f,0xbea11b69,0xa9340212,0x00000000}},	//   _nary, _качк, легш, --, 
   {{0x3ea81497,0x0d4811e6,0x00000000,0x00000000}},	//   ècte_, _آشتي_, --, --, 
   {{0x2aac353f,0x6d59ccf7,0xb8b4007b,0x44f40139}},	//   džbe_, _isva, لإقت, _rç_, 
   {{0x765e1480,0xc87c002f,0x5ca40023,0xc7c401f4}},	// [3ced0] _bary, _voß_, ለኻኽታ_, тсви, 
   {{0x765e1481,0x44f4f71d,0x49a40a5b,0x05840395}},	//   _cary, _pç_, _ајма, куем, 
   {{0x765e1482,0x29021483,0x91a00037,0x00000000}},	//   _dary, _utha_, _केलै, --, 
   {{0x765c14dc,0xa318034b,0x02d800cd,0x00000000}},	//   _eary, ежду_, यग्न, --, 
   {{0x765e1484,0x8370036b,0x232801fe,0x2248008e}},	//   _fary, шқач, холи_, епли_, 
   {{0x6d581050,0x765c0209,0x215806ed,0x60d80042}},	//   _osva, _gary, ејиќ_, _shwm, 
   {{0x81c803f4,0x44f61485,0x60d80142,0x65961486}},	//   রেন_, _uç_, _phwm, _саву, 
   {{0x765e1487,0x66161488,0x00000000,0x00000000}},	//   _zary, _hezk, --, --, 
   {{0x6d5a1489,0x661401c0,0xaf98009d,0x00000000}},	//   _asva, _kezk, втэх_, --, 
   {{0xfd8002d3,0x00000000,0x00000000,0x00000000}},	//   _ዝመልኦ_, --, --, --, 
   {{0x273d0013,0x6616148a,0x6d580055,0x6282148b}},	//   hìn_, _mezk, _csva, _iolo, 
   {{0x6282148c,0x661412cb,0x9c5800c7,0x00000000}},	//   _holo, _lezk, хшоу_, --, 
   {{0x6d5a148d,0x59d4772c,0x00000000,0x00000000}},	//   _esva, _धरहर, --, --, 
   {{0x62801bce,0x661400bc,0x38c82421,0xdb800092}},	//   _jolo, _nezk, چاری_, _ይኸውም_, 
   {{0x628201ec,0x9d442e9a,0x673c0175,0x38c92766}},	//   _molo, _сейд, _aqsj, ناری_, 
   {{0x6282148e,0x765e148f,0x661401c4,0x5e600131}},	//   _lolo, _sary, _aezk, _ئۆگە, 
   {{0x765e1490,0x7c240491,0x62821491,0xcd500014}},	// [3cee0] _pary, _idir, _oolo, _نى۪ک, 
   {{0x62821492,0x55e40212,0xd5180208,0x765e1493}},	//   _nolo, гозб, _nặn, _qary, 
   {{0x765e1494,0x98a61495,0x7c2400a2,0xca5400d9}},	//   _vary, _бине, _kdir, _גייז_, 
   {{0xb4c21496,0x62821497,0x765dbca8,0xa2a07ef5}},	//   ुते_, _aolo, _wary, कोस्, 
   {{0x62821498,0x765e1499,0x3862149a,0x81c809bd}},	//   _bolo, _tary, mdir_, রেম_, 
   {{0x6282149b,0x3862149c,0x7c2407d6,0x2904004e}},	//   _colo, ldir_, _ldir, ílag_, 
   {{0x6282149d,0xfd05f6c7,0x7c24003a,0x81400b24}},	//   _dolo, _دج_, _odir, منون, 
   {{0x3862149e,0x7c26149f,0x6280035a,0x931402f2}},	//   ndir_, _ndir, _eolo, _مورش, 
   {{0x628214a0,0x386214a1,0x7d00037e,0x4fc614a2}},	//   _folo, idir_, _atns, ыска, 
   {{0x7d00010a,0x3861f520,0x7eb400db,0x00000000}},	//   _btns, hdir_, лгыс_, --, 
   {{0x386214a3,0x7c24010e,0x4124010a,0x3d0c00bc}},	//   kdir_, _bdir, _бохо_, थीले_, 
   {{0x628214a4,0x6e9400cf,0x386001a9,0x41b8011a}},	//   _zolo, الگا, jdir_, _אצבע, 
   {{0x386214a5,0x628214a6,0x7c2614a7,0x5c7401e0}},	//   ddir_, _yolo, _ddir, рҙыр_, 
   {{0x7c240cc1,0x6d5a14a8,0x628214a9,0x00000000}},	//   _edir, _tsva, _xolo, --, 
   {{0x6d580b91,0x6615b560,0x7c2614aa,0x386214ab}},	//   _usva, _rezk, _fdir, fdir_, 
   {{0x386214ac,0x273c0309,0xb4c008df,0x7d00009f}},	//   gdir_, tìn_, ुतो_, _اِيه, 
   {{0xa6149d46,0x661401e4,0xa5f80063,0x00000000}},	// [3cef0] имач, _pezk, везу_, --, 
   {{0x386214ad,0x7c24022e,0x8c38002f,0xd9580023}},	//   adir_, _zdir, wißh, _ቅልዉላ, 
   {{0x628214ae,0x386048d3,0x09dc00cc,0x7c2401d5}},	//   _rolo, bdir_, বুজা, _ydir, 
   {{0x81c8015b,0xa878008f,0x386003b9,0x00000000}},	//   রেড_, _סאָר, cdir_, --, 
   {{0x661614af,0x4784273e,0x00000000,0x00000000}},	//   _tezk, _сынб, --, --, 
   {{0x628214b0,0x672e14b1,0xe508027d,0x00000000}},	//   _qolo, mraj, _ليسو_, --, 
   {{0x672c0edc,0x630400f1,0x205400f3,0xa2a007b7}},	//   lraj, _چورل, атпр, कोष्, 
   {{0x628214b2,0x672c013c,0x5f74950f,0xd00e14b3}},	//   _wolo, oraj, لاخر, ولى_, 
   {{0x64487545,0x672e14b4,0x7c24009a,0x62342bbd}},	//   _ibei, nraj, _rdir, _везу, 
   {{0x672c1050,0x7c2405b1,0xaf4800e3,0x628214b5}},	//   iraj, _sdir, اشيل_, _uolo, 
   {{0x672e14b6,0x386214b7,0xa1580075,0x00000000}},	//   hraj, ydir_, _шажу_, --, 
   {{0x9f5c0100,0xa2a00764,0x0d8000d4,0x5c14035b}},	//   _dewò_, कोर्, ілян, шьоу, 
   {{0x64480491,0x200e14b8,0x672e14b9,0x7c240010}},	//   _mbei, mbei_, jraj, _vdir, 
   {{0xd958044e,0x8f980375,0x64480076,0x200c002f}},	//   _ቅልውላ, _ביני, _lbei, lbei_, 
   {{0x386214ba,0x644a14bb,0x672e14bc,0x394c0129}},	//   tdir_, _obei, eraj, ïds_, 
   {{0x7c2614bd,0x200e14be,0x672c054e,0x38600129}},	//   _udir, nbei_, fraj, udir_, 
   {{0x672e14bf,0xdd901893,0xe80415e0,0x00000000}},	// [3cf00] graj, _دوں_, षुधा_, --, 
   {{0x644a14c0,0x386214c1,0x7764003a,0xb4c00303}},	//   _abei, sdir_, rvix, ुत्_, 
   {{0x386009a5,0x3e200020,0x644801c3,0x672e14c2}},	//   pdir_, _ተጠናክ, _bbei, araj, 
   {{0x38608216,0x644801ab,0x4a000327,0x200c054e}},	//   qdir_, _cbei, _མཅོལ_, jbei_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x644a14c3,0x65880332,0x2b4c0205,0x00000000}},	//   _ebei, íphá, çeci_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8f443bb3,0x224808ad,0x50641e49,0x3ea40327}},	//   аход, đaka_, ртка, _amnt_, 
   {{0xef1000f7,0x09c03c20,0x92ea14c4,0x6e440127}},	//   чүлө, _षड्य, _адаб_, منظم, 
   {{0xdbd00086,0x00000000,0x00000000,0x00000000}},	//   _nüñi, --, --, --, 
   {{0x85f4008f,0x321c0306,0xac1a14c5,0x3ea8180f}},	//   יציע_, mavy_, лону_, ècta_, 
   {{0x2aac3879,0x321c0122,0x9d5000d1,0x672cfe52}},	//   džba_, lavy_, سچىت, yraj, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x672c0882,0x6e940424,0x72140c58,0x321e14c6}},	//   vraj, _دلتا, _সাঁচ_, navy_, 
   {{0x2904025a,0x25680150,0x8274010f,0x00000000}},	//   ëla_, _ءﻭﺭﺕ, סעלע_, --, 
   {{0x321c05da,0x7d78008f,0x2d8c003a,0x561400cc}},	//   havy_, _ינוו, myde_, ালোক_, 
   {{0x321e14c7,0x80c405f9,0x290572ce,0x2d8c01bf}},	// [3cf10] kavy_, ावते, ūla_, lyde_, 
   {{0x672c0323,0x321cdc99,0x2ca80165,0x22980241}},	//   rraj, javy_, _hmad_, _kèke_, 
   {{0xa2c614c8,0x672e14c9,0x200c0024,0x321c1155}},	//   ाकस्, sraj, ybei_, davy_, 
   {{0x672e14ca,0xe2f801ec,0x00000000,0x00000000}},	//   praj, геді_, --, --, 
   {{0x2d8cf8d2,0x2ca801f2,0x672c0455,0xe3640108}},	//   hyde_, _mmad_, qraj, скли, 
   {{0x2ca80175,0x0584010b,0x2d8c01bf,0x66d80241}},	//   _lmad_, _кубм, kyde_, bìka, 
   {{0x2ca877a6,0x4f0402dd,0x85540214,0x2d8c01bf}},	//   _omad_, ұнын_, _خیار_, jyde_, 
   {{0x212809a8,0x644803ac,0xd5840133,0x236801e4}},	//   čah_, _ubei, _دێمه_, ƭaj_, 
   {{0x200e14cb,0x321e14cc,0x1ec8016c,0x2d980428}},	//   rbei_, bavy_, ллии_, ùren_, 
   {{0x63b001af,0x00000000,0x00000000,0x00000000}},	//   _мәҙх, --, --, --, 
   {{0x2ca80076,0xdff400d3,0xad5856cd,0x2d8c01bf}},	//   _bmad_, _ляль, арях_, gyde_, 
   {{0x2298007f,0x9ed800fd,0x718c010f,0x00000000}},	//   _dèke_, _өмет_, _שװאַ, --, 
   {{0x60ca14cd,0x9f0614ce,0x5f0614cf,0x00000000}},	//   moem, _اوتو, _узла, --, 
   {{0x3ea614d0,0xd378008f,0x2caa14d1,0x2eb400dc}},	//   _umnt_, ארשט, _emad_, ुवृत, 
   {{0x87e404a9,0x35ac05f9,0x2d8c0005,0x1a640133}},	//   ەتلە, _टेढ़, cyde_, لیکی_, 
   {{0x60c83441,0x2aac0122,0x15b802dd,0x6c7407d5}},	//   noem, ržba_, қызы_, _дуьх, 
   {{0x3ce00fec,0xd70a14d2,0x15f4221c,0x676401e0}},	// [3cf20] _ihiv_, унзе_, مساح, онтҡ, 
   {{0x60ca14d3,0x3cdc0490,0x628401e3,0x00000000}},	//   hoem, _गीते_, öhol, --, 
   {{0x321c1311,0x3ce001d4,0x98a80356,0xd4680114}},	//   vavy_, _khiv_, gubă_, лиже_, 
   {{0x0d3800df,0x00000000,0x00000000,0x00000000}},	//   טגעב, --, --, --, 
   {{0x60c89b34,0xcc38008f,0x3dcc00fe,0xfcf40092}},	//   doem, רענט, ৰশিল, ጋለጠ_, 
   {{0x66d805da,0xd9f8007a,0x00000000,0x00000000}},	//   pìka, ्डित_, --, --, 
   {{0x321c278a,0x81c800bd,0xd1480e4a,0x60c80789}},	//   ravy_, রেস_, اشتن_, foem, 
   {{0xd174005e,0x321c03d1,0x044214d4,0x60c80327}},	//   _қызы, savy_, _несн, goem, 
   {{0x1cb80135,0xdb14020c,0x0874008f,0x2298033b}},	//   ྙོན_, _ècèn, מעקט_, _sèke_, 
   {{0xd0400134,0x2d8cbd94,0x2ca8045a,0xfcf40092}},	//   _ahoɔ, tyde_, _smad_, ጋለጡ_, 
   {{0x60ca14d5,0xa2c44407,0x626614d6,0x6c5417a0}},	//   boem, ाकर्, _باقق, окну, 
   {{0x2d8d912b,0x3ce00457,0x00000000,0x00000000}},	//   ryde_, _chiv_, --, --, 
   {{0x40e40050,0x2f1801c0,0xc87c002f,0x00000000}},	//   _ازلہ, _толь_, _mißt_, --, 
   {{0xdb08022c,0x6d5ca303,0x00000000,0x00000000}},	//   ðnám, æras, --, --, 
   {{0x2a60022e,0xc8d4007b,0xcd0401d5,0xbd640024}},	//   _vahb_, مزرع, _учли, _грые_, 
   {{0x2a608913,0x2ca80067,0x00000000,0x00000000}},	//   _wahb_, _umad_, --, --, 
   {{0xbb4801c8,0x00000000,0x00000000,0x00000000}},	// [3cf30] _هلين_, --, --, --, 
   {{0x39900125,0x6c3454db,0x24640051,0x00000000}},	//   ሞክራሲ_, _افکا, _ồm_, --, 
   {{0x25b80338,0x628401f4,0x00000000,0x00000000}},	//   جهاد_, öhom, --, --, 
   {{0x6f9c01ec,0x00000000,0x00000000,0x00000000}},	//   _ﻀﻐﻁﺎ_, --, --, --, 
   {{0xc76400db,0x0a480023,0x60c80165,0x47880798}},	//   _ااجى, _ምምሕያ, voem, _сснм_, 
   {{0xb928002b,0xfcf40092,0x2be00055,0x3f9c0205}},	//   _amuṃ_, ጋለጥ_, _नरना, vzuu_, 
   {{0x91e0f55e,0x60ca14d7,0xa0a614d8,0x00000000}},	//   моше, toem, жайд, --, 
   {{0x20196ba2,0xc60000ef,0xb97c00df,0xe0d800d8}},	//   úsi_, _dzēš_, רנהי, јви_, 
   {{0x60c8bdd0,0x81c4005f,0x443c045a,0x00000000}},	//   roem, dzēš, _icu_, --, 
   {{0x3ce003a2,0x60c8f917,0xdea001b9,0x1d241b0a}},	//   _shiv_, soem, بیتی, омом, 
   {{0x3ce00218,0x443c05be,0x72043d93,0x60ca14d9}},	//   _phiv_, _kcu_, _رونم, poem, 
   {{0x25e02aa1,0x1be869bd,0x7b840131,0x236c0200}},	//   _करनी_, идни_, зғид, _krej_, 
   {{0x443c02c4,0x6d5ccade,0x81c80154,0x00000000}},	//   _mcu_, ærar, রেশ_, --, 
   {{0xdea02be7,0x2c000139,0x00000000,0x00000000}},	//   _آیدی, _җүрм, --, --, 
   {{0x81c80d42,0x443c098d,0x3ce00211,0x1d18b7bb}},	//   রের_, _ocu_, _thiv_, _тюль_, 
   {{0x7e6214da,0x443e14db,0x09e000f5,0x00000000}},	//   _hanp, _ncu_, фосн, --, 
   {{0x7e6214dc,0xa4f4031c,0x81c00171,0x00000000}},	// [3cf40] _kanp, _བཤུག_, _žēls, --, 
   {{0x443c0491,0x7e6214dd,0xf8b80032,0xd6280cb9}},	//   _acu_, _janp, рөү_, роже_, 
   {{0xab040014,0x948404b3,0xdc38294f,0x00000000}},	//   _وظیٖ, жылд, lçık, --, 
   {{0x7e6214de,0xf1b80184,0x443c0268,0x9388147e}},	//   _lanp, ҡҡа_, _ccu_, исла_, 
   {{0x7e600a85,0x66094c9c,0x443e14df,0xd7dc012c}},	//   _oanp, _şeke, _dcu_, _मरिच, 
   {{0x236c780b,0xf4844c12,0x443c0f85,0xc87c002f}},	//   _drej_, _کاسی, _ecu_, _wißt_, 
   {{0x05240276,0x00000000,0x00000000,0x00000000}},	//   _морк_, --, --, --, 
   {{0x7e603441,0x236d1c8c,0xc0e412fc,0xdc380205}},	//   _aanp, _frej_, يفون_, kçık, 
   {{0x236c1ed1,0x81c8015b,0x7e6214e0,0x7680010e}},	//   _grej_, রেল_, _banp, _söyy, 
   {{0x7e6214e1,0x91e40a5b,0x25e0000d,0x443c01ef}},	//   _canp, _дозе, _करमी_, _zcu_, 
   {{0x7e600585,0x504400ee,0x80c5147c,0x00000000}},	//   _danp, _межб, ावशे, --, 
   {{0x7e6002d0,0x20c402dd,0x03bc03d4,0x00000000}},	//   _eanp, _есіг, েধৰণ, --, 
   {{0xbd840403,0xa2a120ed,0x4fb4117d,0x98bc0118}},	//   منین_, कोक्, _بصار, ůtě_, 
   {{0x7e616213,0x3ae40b8b,0xaa94009d,0x6d5c0327}},	//   _ganp, höpf_, чигч, ħrab, 
   {{0xac9614e2,0x7ee0007b,0x888406ed,0xac18014b}},	//   _накш, _تكون, оѓал, _лойу_, 
   {{0x7e609979,0xfcf4001f,0xcce401c8,0x4ba4004e}},	//   _zanp, ጋገጫ_, _بستي, _дөгү_, 
   {{0x7e6214e3,0xf7700f78,0xe718399c,0x249c0218}},	// [3cf50] _yanp, پاق_, صيات_, vhwm_, 
   {{0x443c1570,0x2f000100,0x7e6001c4,0xaa581c3e}},	//   _scu_, _mòg_, _xanp, _الدا_, 
   {{0xc958036b,0x80a80b4c,0x00000000,0x00000000}},	//   _тўп_, _जगले, --, --, 
   {{0x236e14e4,0x680001e1,0x00000000,0x00000000}},	//   _prej_, _dájó, --, --, 
   {{0x443c6035,0x98780a1e,0xe3740132,0x00000000}},	//   _vcu_, _הארט, ялды, --, 
   {{0x236c0356,0xd36c9bfe,0xf6c80024,0x328800ec}},	//   _vrej_, اهو_, _дыск_, يننٽ_, 
   {{0x7e605079,0xa4f40003,0x443e14e5,0xd12c50a3}},	//   _ranp, _བཤིག_, _tcu_, همو_, 
   {{0x7e6214e6,0x2f00067c,0x69c005d1,0x443e14e7}},	//   _sanp, _bòg_, üley, _ucu_, 
   {{0x7e6214e8,0x942400f7,0x623400f3,0x4f0400db}},	//   _panp, _رولۇ, _неау, пнын_, 
   {{0x645a14e9,0x660614ea,0x2f000428,0x35d00cb4}},	//   lewi, nchk, _dòg_, _तुड़, 
   {{0xdc6a14eb,0x27f80077,0x00000000,0x00000000}},	//   банд_, _ogsn_, --, --, 
   {{0x7e60398e,0x645907f1,0xdd9400c7,0xf1c407f7}},	//   _wanp, newi, _ҭады, _लुटन, 
   {{0x7e6044bf,0x69c0006a,0x2f000100,0x64580175}},	//   _tanp, ûlen, _gòg_, iewi, 
   {{0x13ac00eb,0x00000000,0x00000000,0x00000000}},	//   _ছুড়, --, --, --, 
   {{0x645a14ec,0x99d401d5,0x00000000,0x00000000}},	//   kewi, سقرت, --, --, 
   {{0x201c0009,0x645a14ed,0x9f4001e1,0x00000000}},	//   _jewi_, jewi, _ńhù_, --, 
   {{0x645a14ee,0xdec80020,0xc17c0064,0xa26c0023}},	// [3cf60] dewi, _አለን_, _šėls_, ኣምንን_, 
   {{0xddc000dd,0x201e14ef,0x00000000,0x00000000}},	//   lelő, _lewi_, --, --, 
   {{0xe90000c7,0x6458010e,0x3d0c01f9,0x00000000}},	//   _аҧси, fewi, थीचे_, --, 
   {{0x64599513,0x6ba00365,0x27f8003e,0x201c0042}},	//   gewi, _özgü, _ggsn_, _newi_, 
   {{0xd7f00597,0x22980100,0x00000000,0x00000000}},	//   _سكس_, _sèka_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x645a14f0,0xddc001d3,0xd46800f3,0x00000000}},	//   bewi, kelő, _ливе_, --, 
   {{0x25e0068f,0x645a14f1,0x2f0001c3,0xc9500375}},	//   _करती_, cewi, _pòg_, גמה_, 
   {{0x201e14f2,0xfcf40092,0x00000000,0x00000000}},	//   _dewi_, ጋገጠ_, --, --, 
   {{0xff4d14ed,0x62640131,0x81c8015b,0x00000000}},	//   اخي_, _يالق, রেই_, --, 
   {{0x3d2000fd,0x00000000,0x00000000,0x00000000}},	//   ньяв, --, --, --, 
   {{0x201c00f2,0xddc001ed,0x0ca801b9,0xb0c401e2}},	//   _gewi_, gelő, ётни_, _تښتي, 
   {{0x7bc400e8,0xa0c800c6,0x8d7400d1,0x59d00037}},	//   _cxiu, _بذلك_, زاھا, _दुबर, 
   {{0x64580034,0x27f8003e,0x4350001f,0x37c40154}},	//   zewi, _sgsn_, _መግባባ, ্ধার, 
   {{0x1ea8082e,0x7bc40393,0xa2a000cd,0x628401f4}},	//   _باني_, _exiu, कोट्, öhoi, 
   {{0x201c002e,0x00000000,0x00000000,0x00000000}},	//   _xewi_, --, --, --, 
   {{0xb9043eaf,0x66040204,0x6d485512,0x383614f3}},	// [3cf70] _पी_, tchk, ltda, энтр, 
   {{0x6594084c,0x64580428,0x6d4801a9,0xeaf801f9}},	//   мазу, wewi, otda, ंदीत_, 
   {{0x6d4a14f4,0x660614f5,0x00000000,0x00000000}},	//   ntda, rchk, --, --, 
   {{0x69c40944,0x6605549a,0x23b614f6,0x6d480549}},	//   _ixhe, schk, وماس, itda, 
   {{0x201e14f7,0x6264009b,0x6d4a14f8,0x27ec0129}},	//   _rewi_, двла, htda, _àen_, 
   {{0x64589ef7,0x6d4a14f9,0x201c020c,0xddc001ed}},	//   sewi, ktda, _sewi_, zelő, 
   {{0xddc001ed,0x0594030d,0x00000000,0x00000000}},	//   yelő, _хăйм, --, --, 
   {{0x6d4805ac,0x9f040133,0x00000000,0x00000000}},	//   dtda, ووبو, --, --, 
   {{0x284c067d,0xe2980032,0xddc001d3,0xf2b801d9}},	//   _ምኽንያ, _һаҡ_, velő, _کھنڈ_, 
   {{0xfcf4001f,0x9ea80212,0x00000000,0x00000000}},	//   ጋገጥ_, івна_, --, --, 
   {{0x6d487760,0x201c0142,0xddc000e5,0xe29801ee}},	//   gtda, _tewi_, telő, _лаҡ_, 
   {{0x80a001d9,0x00000000,0x00000000,0x00000000}},	//   _سۅخن, --, --, --, 
   {{0x69c4f7b1,0x46bc07b7,0xddc001d3,0x6d49029c}},	//   _axhe, ्वाह, relő, atda, 
   {{0xddc001ed,0x6d480857,0x00000000,0x00000000}},	//   selő, btda, --, --, 
   {{0x6d480c8c,0x247c0092,0xdd2400c0,0x00000000}},	//   ctda, _ኦገስት_, lūžt, --, 
   {{0x48e08cff,0x00000000,0x00000000,0x00000000}},	//   восв, --, --, --, 
   {{0x69c46a97,0x594001d9,0x77940345,0x00000000}},	// [3cf80] _exhe, رکھہ, ریسا, --, 
   {{0x46e41b94,0x9aa41f0d,0x00000000,0x00000000}},	//   ддун_, _آمدو, --, --, 
   {{0x54682f6a,0x98a40166,0xe634009d,0x8a78123b}},	//   жаем_, _жине, эхтэ, _ואית, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf4240137,0xb9cc0092,0x00000000,0x00000000}},	//   _үзгү, _ሳር_, --, --, 
   {{0x6d4a14fa,0xfa24031c,0x7d040064,0x68e80003}},	//   ytda, འཛིན_, _kūrę, ċede, 
   {{0x6d4a14fb,0xf3f801ee,0x00000000,0x00000000}},	//   xtda, _еңе_, --, --, 
   {{0xebb800b8,0x73c402dd,0x8898010f,0x6498022e}},	//   _haḥ_, _пәле, ַשיצ, _етур_, 
   {{0x2ef614fc,0xdec80020,0xebb800dc,0x3c4801d3}},	//   нзир, _አለኝ_, _kaḥ_, zívó_, 
   {{0x6d48713c,0xb8d00327,0xa37c015d,0x52b000cf}},	//   ttda, _དཏ_, _ngŵy, _جەتئ, 
   {{0x2d9a14fd,0x8c34016c,0x6d4803cd,0xebb80055}},	//   áre_, монӣ_, utda, _maḥ_, 
   {{0x6d4a14fe,0x00000000,0x00000000,0x00000000}},	//   rtda, --, --, --, 
   {{0x4ea614ff,0xa74c01ec,0x00000000,0x00000000}},	//   _орка, _ﺟﻴﺎﯓ_, --, --, 
   {{0x6d48c506,0xebb800dc,0x00000000,0x00000000}},	//   ptda, _naḥ_, --, --, 
   {{0xa2b02db8,0x6d4801b9,0x48640107,0x00000000}},	//   _अगस्, qtda, мъаб, --, 
   {{0x81c800bd,0xdb040165,0xfcf80023,0x52c81810}},	//   রেক_, izkê, ጋገጾ_, ाकुस, 
   {{0x98a80118,0xe6980395,0x603406be,0x8d840240}},	// [3cf90] lubě_, пваш_, ləmç, _ንመበል_, 
   {{0x69c40190,0x66d405d9,0xbbe80014,0xebb800b8}},	//   _txhe, ريائ, _تر٘م_, _caḥ_, 
   {{0xfcf8044e,0x69c40472,0xebb800b8,0xfbd02a9f}},	//   ጋገጽ_, _uxhe, _daḥ_, _متی_, 
   {{0x2aac05ce,0x64c807af,0xdb243047,0x21680107}},	//   džbi_, िकेश, _تویی, ҷики_, 
   {{0x68ee1500,0x290002b1,0xf1b80135,0x00000000}},	//   mmad, _huha_, _reġa_, --, 
   {{0x216a1501,0xebb80055,0x6ab401e4,0xa6c800f1}},	//   зики_, _gaḥ_, nizf, _روزل_, 
   {{0x29021502,0x50a00075,0x241802d5,0x68ee1503}},	//   _juha_, گەنل, _новы_, omad, 
   {{0x29021504,0x00000000,0x00000000,0x00000000}},	//   _muha_, --, --, --, 
   {{0x2901563b,0xebb80a28,0x68ee1505,0x32d400d1}},	//   _luha_, _yaḥ_, imad, رزۇس, 
   {{0x29021506,0x68ee1507,0x248c143a,0x00000000}},	//   _ouha_, hmad, _hoem_, --, 
   {{0x2900001f,0x68ee1508,0x2244030d,0xb2a80014}},	//   _nuha_, kmad, _iclk_, _تُلم_, 
   {{0x802540cc,0xfcf802d3,0x2fc00010,0x31c400c7}},	//   _آرام, ጋገጺ_, _žige_, _рсув, 
   {{0x290003c1,0x68ece018,0x248c022e,0x3ec401d5}},	//   _auha_, dmad, _moem_, _оқим_, 
   {{0x29021509,0x68ec0037,0xda700014,0x1a640066}},	//   _buha_, emad, دُس_, ریجی_, 
   {{0x22440334,0x07a001a9,0x00000000,0x00000000}},	//   _mclk_, ҳатн, --, --, 
   {{0x2902150a,0x68ec0a81,0x248c9ed4,0xd70a150b}},	//   _duha_, gmad, _noem_, знае_, 
   {{0xace804fb,0xbd840014,0x07a2150c,0x987400ef}},	// [3cfa0] _ترول_, _رچھن_, гатн, _aļģu_, 
   {{0x68ee150d,0xfcf802d3,0x290000d7,0xa2b000bc}},	//   amad, ጋገጸ_, _fuha_, _अगष्, 
   {{0x2902150e,0x7d080276,0xebb800dc,0x00000000}},	//   _guha_, _însă, _vaḥ_, --, 
   {{0x248c011c,0x936c02d3,0x68ece7a4,0x53440354}},	//   _coem_, _በልክዎ_, cmad, ехка, 
   {{0x248c017a,0xaac40133,0xebb8002b,0x00000000}},	//   _doem_, _ستین, _taḥ_, --, 
   {{0x42700046,0x00000000,0x00000000,0x00000000}},	//   лгіс, --, --, --, 
   {{0x00d404f2,0xfcf80023,0xa2b000cd,0x00000000}},	//   کبوت_, ጋገጹ_, _अगर्, --, 
   {{0x81346923,0x78a401e4,0x00000000,0x00000000}},	//   رسىز_, nhiv, --, --, 
   {{0x59d005ba,0xb4cc17e6,0x22440175,0xb4dc0073}},	//   _दुसर, रकी_, _fclk_, डती_, 
   {{0x2ef8008c,0x68ee150f,0x248c017a,0x0dc929be}},	//   örf_, zmad, _zoem_, зуми_, 
   {{0x78a40d04,0x68ed6879,0xc01c03d4,0x00000000}},	//   khiv, ymad, _ধাৰণ_, --, 
   {{0x29021510,0x68ee1511,0x25a40037,0x101416ac}},	//   _ruha_, xmad, _ülle_, _أباد, 
   {{0x78a40882,0x29006b48,0xe048036b,0x68ec2681}},	//   dhiv, _suha_, _آشمه_, vmad, 
   {{0x29021512,0xc9841b6d,0x81c8015b,0x59d005f9}},	//   _puha_, нуби, রেও_, _दुहर, 
   {{0x1ee80345,0x00000000,0x00000000,0x00000000}},	//   _تووی_, --, --, --, 
   {{0x68ee1513,0x6d58035a,0xab7400fb,0x4cdc0154}},	//   umad, _ipva, _агиш, _নূরু, 
   {{0x248e1514,0x3fc000d1,0xaa5801d3,0x78b48af3}},	// [3cfb0] _roem_, ﺭﻏﺎﻧ, _ہلکا_, _şevç, 
   {{0x248c2b92,0x290047f8,0x78a403d1,0x81c8015b}},	//   _soem_, _tuha_, ahiv, রেট_, 
   {{0x248e1515,0x68ec1e0c,0x78a400dc,0x00000000}},	//   _poem_, pmad, bhiv, --, 
   {{0x78a61516,0xf4848cff,0x68ec6140,0xb4540133}},	//   chiv, лучн, qmad, ێخۆش, 
   {{0x33d401ec,0x00000000,0x00000000,0x00000000}},	//   лішт, --, --, --, 
   {{0xc61803f4,0x970004a9,0x6d5a1517,0x00000000}},	//   _ঢাকা_, _ئېلى, _opva, --, 
   {{0x248c0109,0xdb0c01ed,0xfa78011a,0x81c800fe}},	//   _toem_, ókúr, תעות_, ৰেন_, 
   {{0x397c008d,0x63ac0077,0xb9cc0092,0x00000000}},	//   לטונ, úans, _ሳይ_, --, 
   {{0x6d581d64,0x4f20717e,0xa2f41111,0xb7c8054e}},	//   _apva, адыб, _апач, miţâ, 
   {{0x82349767,0x26c0013f,0x9f400241,0x00000000}},	//   _سرطا, nnho_, _ńhó_, --, 
   {{0xdca43c55,0x26c006ed,0x81c80154,0xf13400cf}},	//   вани, inho_, রেজ_, _مةنة, 
   {{0x224816a3,0x66080365,0x6d580798,0xf0e8215c}},	//   đaku_, _şekl, _dpva, _كىلى_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfeb8007b,0x5d84007b,0x6e44007b,0x00000000}},	//   _عاشت_, _للتل, _منهم, --, 
   {{0x78a40882,0xdea06e92,0x59d0000d,0x8eb02e0b}},	//   thiv, _میکی, _दुशर, _خموش, 
   {{0x2aac1e31,0x00000000,0x00000000,0x00000000}},	//   džbu_, --, --, --, 
   {{0x65740489,0x5ac89477,0x7c24037e,0x9a180137}},	// [3cfc0] _arzh, _олим_, _ieir, _оюну_, 
   {{0x78a61518,0x65740165,0x7c24b76c,0x6d480210}},	//   shiv, _brzh, _heir, łmań, 
   {{0x7c261519,0x7d02151a,0x95840801,0x78a4014b}},	//   _keir, _juns, ълже, phiv, 
   {{0x7d02151b,0x78a6151c,0xb4dc0412,0x7c240363}},	//   _muns, qhiv, डते_, _jeir, 
   {{0x7c2408d2,0x7d02151d,0x04401318,0x3862151e}},	//   _meir, _luns, речн, meir_, 
   {{0x38600192,0x32dc145e,0x43900209,0x7d00127b}},	//   leir_, dâyê_, рашс, _ouns, 
   {{0x7d02151f,0x7c240798,0xfd040472,0x00000000}},	//   _nuns, _oeir, _خج_, --, 
   {{0x7c261520,0x38621521,0x70cc00af,0x6d5cf77f}},	//   _neir, neir_, ावेल, çram, 
   {{0x7d021522,0x48f00490,0x4fc400a7,0x63c400fb}},	//   _auns, ंगतो_, ъска, _батҡ, 
   {{0x38621523,0x15e40c70,0x60cc00f3,0xd130007b}},	//   heir_, _करार_, čama, _نمط_, 
   {{0x506429e1,0x7c261524,0x7d021525,0x06940375}},	//   _атла, _beir, _cuns, דדים_, 
   {{0x7c261526,0x776401e2,0x50b80133,0x00000000}},	//   _ceir, kwix, _غداد_, --, 
   {{0x7c261527,0x7d00020b,0x3860cfda,0xbdf400e5}},	//   _deir, _euns, deir_, ٹریا_, 
   {{0x7d021528,0x7c24062c,0x7ac4c752,0xbfc00139}},	//   _funs, _eeir, ассе, _әбәк, 
   {{0x7c261529,0x7d008b35,0xb938001f,0x38600174}},	//   _feir, _guns, ርጣሪዎ, feir_, 
   {{0xb4cc02f8,0x7c26152a,0x3860d4ca,0xfd0c004b}},	//   रको_, _geir, geir_, _بجو_, 
   {{0xa77450d5,0x7764025c,0xb884010b,0xb4cd9274}},	// [3cfd0] ылач, gwix, шурй, रकै_, 
   {{0xce3c0020,0x7c24037e,0x6e28014f,0x00000000}},	//   _በአጠቃ, _zeir, nadb, --, 
   {{0x38603948,0xc98403fb,0x7c24062c,0xa43800a8}},	//   beir_, _рупи, _yeir, езеу_, 
   {{0x2cb8037e,0x7c253f85,0x2aac0122,0x0576152b}},	//   nisd_, _xeir, ržbu_, _یازد, 
   {{0x68fc16b8,0xa2940212,0xdb040419,0xa0a401e0}},	//   _iisd, ладі, tzké, ҫалд, 
   {{0x672d4df7,0x68fc003a,0x38c0013d,0x00000000}},	//   msaj, _hisd, lärе_, --, 
   {{0x65740dd4,0x672da1fe,0x6e28002b,0x68fe152c}},	//   _urzh, lsaj, dadb, _kisd, 
   {{0x7d02152d,0x2fc2152e,0x22980100,0xdb0401d3}},	//   _runs, _žiga_, _mèki_, szké, 
   {{0x672c0d42,0x7c26152f,0x68fe1530,0x7d021531}},	//   nsaj, _reir, _misd, _suns, 
   {{0x7c24387b,0x68fc780b,0x4fe4a654,0x7d021532}},	//   _seir, _lisd, ымын_, _puns, 
   {{0x7c261533,0xd00ca695,0x7d004091,0xa24400f1}},	//   _peir, غلی_, _quns, _لیږل_, 
   {{0xf1a61534,0x672e1535,0x68fc014f,0x7d0000ad}},	//   _трун, ksaj, _nisd, _vuns, 
   {{0x7c261536,0x7d01c002,0x6e28040b,0x64480076}},	//   _veir, _wuns, badb, _mcei, 
   {{0xd9461537,0x7d021538,0x68fc00a3,0x7c242517}},	//   леги, _tuns, _aisd, _weir, 
   {{0x7c261539,0x69940022,0x68fcab89,0x7d00198f}},	//   _teir, артх, _bisd, _uuns, 
   {{0x1c440b96,0x68fc002e,0x7c2401ab,0x200e153a}},	//   _сним, _cisd, _ueir, ncei_, 
   {{0x68fe153b,0x6110002d,0x38604312,0x200c0356}},	// [3cfe0] _disd, _hāld, reir_, icei_, 
   {{0x6448af16,0xda654032,0x5a66153c,0x68fe153d}},	//   _acei, _свои, _скоб, _eisd, 
   {{0x3ae401b8,0x672c04ba,0x59740b7e,0x3862153e}},	//   löpo_, asaj, _сыпу, peir_, 
   {{0x672c003d,0xebb80055,0x94240120,0x53c86031}},	//   bsaj, _jaḿ_, умде, нгем_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x644814dc,0x200c00de,0x00000000,0x00000000}},	//   _ecei, ecei_, --, --, 
   {{0x6e29774c,0x249c0218,0x100401b9,0x00000000}},	//   vadb, bkwm_, ляпм, --, 
   {{0x64480597,0x68fc0009,0x25a40254,0xa49000e5}},	//   _gcei, _xisd, _ülla_, _ویلت, 
   {{0x316009a5,0x6e28a501,0x0490007b,0x37c400eb}},	//   ňiz_, tadb, _القح, ্ধকর, 
   {{0x6e9823b3,0xd34401d5,0x8d8400db,0x00000000}},	//   твор_, _لیچه_, гумд, --, 
   {{0xac18548e,0x6e2a153f,0x672c0369,0x9044007b}},	//   кону_, radb, zsaj, _مناه, 
   {{0x6e2a1540,0xbd84034c,0x672c035b,0x61e61541}},	//   sadb, چنین_, ysaj, ühle, 
   {{0x68fe1542,0x2cb8003a,0xad840137,0x506401af}},	//   _risd, risd_, _چابۇ, _атһа, 
   {{0x68fe1543,0x6e280455,0x3ff8011a,0x00000000}},	//   _sisd, qadb, _נפגע, --, 
   {{0xfe6c03e6,0xc278008f,0x2905c978,0x672c0784}},	//   _ردو_, ערלי, êla_, wsaj, 
   {{0x8af800ac,0x68fc01a9,0xac580166,0x68e80135}},	//   fiəç, _qisd, _раиф_, ċedo, 
   {{0x68fe1544,0x672c005b,0x39a40014,0x00000000}},	// [3cff0] _visd, usaj, لییہ, --, 
   {{0x672c008f,0x64480597,0x00000000,0x00000000}},	//   rsaj, _scei, --, --, 
   {{0x68fe1545,0x672e1546,0x6111eeb5,0xebb800b8}},	//   _tisd, ssaj, _kāle, _yaḿ_, 
   {{0xc864722e,0x48640c04,0x69c006af,0x68fc01c3}},	//   _стои, _съоб, ûleu, _uisd, 
   {{0x6f040588,0xd040016b,0x25640142,0x63861547}},	//   _éich, _nkoɑ, _wŷl_, ргла, 
   {{0x61100421,0x8234473f,0x33180214,0x83c001ec}},	//   _lāle, ارشا, ازند_, _құлж, 
   {{0x21a40212,0xd0b006be,0x00000000,0x00000000}},	//   рийм, lşən, --, --, 
   {{0x64480077,0x28bc2e1e,0x00000000,0x00000000}},	//   _ucei, ्कटि, --, --, 
   {{0x2d986ab9,0x200e1548,0x66d000c7,0xa2cc00cd}},	//   øren_, rcei_, ẽkur, _तदप्, 
   {{0x1e953953,0x00000000,0x00000000,0x00000000}},	//   ррир, --, --, --, 
   {{0x62821549,0x611024b8,0x2034059e,0x00000000}},	//   _inlo, _bāle, _نفاس, --, 
   {{0x60180395,0x00000000,0x00000000,0x00000000}},	//   _родя_, --, --, --, 
   {{0x6110002d,0xd00cbbed,0x70f401d3,0x0b400108}},	//   _wāld, _غلو_, _اسلئ, онян, 
   {{0xdfd016cb,0xdab80006,0x00000000,0x00000000}},	//   _ٿيڻ_, тымі_, --, --, 
   {{0x61100270,0xa2cc00dc,0x9d443004,0x31340092}},	//   _fāle, _तदन्, _тейд, _አይታይ, 
   {{0x97c4ee17,0xfeb80345,0x00000000,0x00000000}},	//   айбе, _تاڵت_, --, --, 
  
   {{0x6282154a,0x3d08012d,0x00000000,0x00000000}},	// [3d000] _onlo, _ठंडे_, --, --, 
   {{0x6110005f,0x95980220,0xd1cc001f,0x06800137}},	//   _zāle, ктеу_, ባሰብ_, огун, 
   {{0xc68c1291,0x00000000,0x00000000,0x00000000}},	//   بِل_, --, --, --, 
   {{0x6280062c,0xb1180145,0xb7c40154,0x00000000}},	//   _anlo, ۇقتا_, _শরীয়, --, 
   {{0x657802b1,0x3358084c,0x94a801d9,0x244805af}},	//   āwha, уалэ_, _یارِ_, اجمي_, 
   {{0x6f0400ae,0x00000000,0x00000000,0x00000000}},	//   _éici, --, --, --, 
   {{0x518413c6,0x5064e093,0x799c0223,0x05240500}},	//   рула, атпа, nyrw, _воск_, 
   {{0x6282154b,0x136400b2,0x41c00075,0x04402082}},	//   _enlo, _پارٽ, تقىق, _месн, 
   {{0x66090fe6,0x799c0142,0x036401af,0xc438011a}},	//   _şeki, hyrw, _китк_, _שתמי, 
   {{0x628001c3,0x611000b8,0x00000000,0x00000000}},	//   _gnlo, _dālb, --, --, 
   {{0xd084005b,0x61100a88,0x00000000,0x00000000}},	//   _выли, _pāle, --, --, 
   {{0x229801e1,0x9ed800f7,0xa9a400d1,0x41b8011a}},	//   _dèku_, кмөт_, ەمسى, _בצבע, 
   {{0x6280334b,0x92c8009e,0x00000000,0x00000000}},	//   _ynlo, োষী_, --, --, 
   {{0x799c00a9,0xbd8401d5,0xe8b04709,0x7ed0621e}},	//   fyrw, _چنون_, ीच्च, _وزوا, 
   {{0x9e6509dc,0xac940166,0x61100a88,0xdce0013d}},	//   _دانن, _гайш, _tāle, aylı, 
   {{0x61100270,0x764c013f,0x7bc805d1,0x00000000}},	//   _uāle, ɑnyɛ, ğdur, --, 
   {{0xa3b4000d,0xb7140108,0x00000000,0x00000000}},	// [3d010] _छें_, ждущ, --, --, 
   {{0xd0b000ac,0x6b9c0368,0x2298020c,0x29040077}},	//   rşən, mysg, _yèku_, ílas_, 
   {{0xe29a154c,0xe3c401e0,0x6b9c0042,0x00000000}},	//   ғай_, әреү, lysg, --, 
   {{0xd1dc0020,0xdd380311,0xf504003b,0x00000000}},	//   ዕክት_, lăţe, ізіо, --, 
   {{0x6b9c0368,0x47841411,0x00000000,0x00000000}},	//   nysg, _тынб, --, --, 
   {{0x21a4036b,0xdd38054e,0x2248234c,0xe694007b}},	//   йилм, năţe, упки_, _الآد, 
   {{0x62800a73,0x6b9c015d,0x00000000,0x00000000}},	//   _vnlo, hysg, --, --, 
   {{0x64c4d91c,0x55500014,0x00000000,0x00000000}},	//   _ايرل, _ژھۆر, --, --, 
   {{0x9424215c,0x704400db,0x00000000,0x00000000}},	//   _دوقۇ, زئيك, --, --, 
   {{0x26e44d53,0x6b9c00a9,0x0ea4008e,0x61100171}},	//   _कठोर_, dysg, йкый_, _vālb, 
   {{0xdd38054e,0x00000000,0x00000000,0x00000000}},	//   dăţe, --, --, --, 
   {{0x6b9c00a9,0xc7ac00e8,0x611000ef,0x00000000}},	//   fysg, ccёg_, _tālb, --, 
   {{0x54780375,0xacb000db,0x6b9c722a,0x00000000}},	//   אטרו, بەيب, gysg, --, 
   {{0x61e2154d,0x799c0649,0xdd38054e,0x5cc4008e}},	//   _kyll, tyrw, găţe, рсүз, 
   {{0x61e0138f,0x2d940801,0x1ca40133,0x00000000}},	//   _jyll, _мръс, _هێدی_, --, 
   {{0x61e2154e,0x09c4015b,0x00000000,0x00000000}},	//   _myll, _এরশা, --, --, 
   {{0x57ea154f,0x8c18011a,0x00000000,0x00000000}},	// [3d020] удам_, _גופי, --, --, 
   {{0x61e00113,0x799c0223,0xdd380356,0xe9d80107}},	//   _oyll, pyrw, căţe, укӣ_, 
   {{0x61e006a3,0x9404007b,0x00000000,0x00000000}},	//   _nyll, مواه, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x61e07fc0,0x288007d6,0x00000000,0x00000000}},	//   _ayll, _ўқув, --, --, 
   {{0x61e006a3,0x20180165,0x516400db,0x00000000}},	//   _byll, ñsin_, йүзү_, --, 
   {{0x61e000a9,0x00000000,0x00000000,0x00000000}},	//   _cyll, --, --, --, 
   {{0x5064fcad,0x61e21550,0xf4861551,0x2f1402a9}},	//   стка, _dyll, _باسی, одиё, 
   {{0xa4902832,0x61e00784,0xa2b000dc,0x81c803d4}},	//   _تینت, _eyll, _अगच्, ৰেল_, 
   {{0x61e03402,0x12c400e5,0x00000000,0x00000000}},	//   _fyll, _اترپ, --, --, 
   {{0x61e21552,0xdb0800d0,0xac9a1553,0x2d580276}},	//   _gyll, ľným, لندا_, шинь_, 
   {{0xdb0802fb,0xd0080114,0x6b9c015d,0x00000000}},	//   žným, _седе_, tysg, --, 
   {{0xdd38084c,0x61ec03f9,0x765c0866,0x61e004e6}},	//   tăţe, ƙalc, _obry, _zyll, 
   {{0x611006c8,0xcef41b88,0xe1f001ed,0x61e0010b}},	//   _hāla, _учењ, _ءسے_, _yyll, 
   {{0x61121554,0xdd380311,0xb33c001f,0xac18004e}},	//   _kāla, răţe, _አውጥተ, _койу_, 
   {{0x61100b13,0xf7703c5a,0xdd9000e5,0x00000000}},	//   _jāla, کاف_, _آوٹ_, --, 
   {{0x61121555,0x41dc16d1,0x00000000,0x00000000}},	// [3d030] _māla, _पुनस, --, --, 
   {{0x6111fe4e,0xbb180046,0x2ca80306,0x0ae81d57}},	//   _lāla, _ازيا_, _hlad_, _حربي_, 
   {{0x2ca829ef,0xe8944166,0xd3080055,0x00000000}},	//   _klad_, _дань, _rṇa_, --, 
   {{0x611000cd,0x00000000,0x00000000,0x00000000}},	//   _nāla, --, --, --, 
   {{0x80b0009e,0x61e21556,0x3cfc0115,0x00000000}},	//   ুকম্, _syll, אלאנ, --, 
   {{0x61e21557,0x236c151c,0x00000000,0x00000000}},	//   _pyll, _vsej_, --, --, 
   {{0x20881e84,0x611000dc,0x229802bd,0x7ebc01e1}},	//   ийки_, _bāla, _sèks_, _lápè, 
   {{0x611000cd,0x6ab400fe,0x00000000,0x00000000}},	//   _cāla, ংকটো, --, --, 
   {{0x61e205c7,0x99880295,0x4f052043,0x00000000}},	//   _wyll, rabũ_, онын_, --, 
   {{0x61e0138f,0x645a1558,0x2ca990b9,0x9e040137}},	//   _tyll, lfwi, _alad_, өчүл, 
   {{0x61e00986,0xdbd00139,0x442e1559,0xd4980107}},	//   _uyll, _küçi, oag_, _ёрӣ_, 
   {{0x442c1085,0x229a155a,0x224803f9,0x6110002b}},	//   nag_, _tèks_, ɗaka_, _gāla, 
   {{0x60c9ce50,0xda641564,0x442c0076,0x95e401ad}},	//   mnem, ياسي, iag_, _कर्ट_, 
   {{0x442e155b,0x60ca155c,0x2ca80ef5,0x93f800d9}},	//   hag_, lnem, _elad_, ילרי, 
   {{0x442c94da,0x60c80393,0x2ca8a51f,0x1a640424}},	//   kag_, onem, _flad_, میکی_, 
   {{0x60ca155d,0x442e155e,0x2caa155f,0x645801a4}},	//   nnem, jag_, _glad_, jfwi, 
   {{0x60c8666b,0x765c00b5,0x3f9e1560,0x96184369}},	// [3d040] inem, _pbry, nyuu_, لغار_, 
   {{0x60c8217c,0x645a026d,0x442d709b,0x00000000}},	//   hnem, efwi, eag_, --, 
   {{0x7d061561,0x442e1562,0x64582305,0xd4040108}},	//   _kiis, fag_, ffwi, ояли, 
   {{0x7d061563,0x442e1564,0x60ca09a1,0x3f9c037e}},	//   _jiis, gag_, jnem, kyuu_, 
   {{0x7d061565,0xfd4c0051,0x78a40037,0xeff40023}},	//   _miis, _phjề, mkiv, _ጌርዎ_, 
   {{0x7d061566,0x765c014b,0xd138d9ff,0x60c800c5}},	//   _liis, _ubry, ахи_, enem, 
   {{0x60c801f5,0x442c4d57,0xaee40055,0x999800bc}},	//   fnem, bag_, _hiṇy, _pepř_, 
   {{0x60ca1567,0x7d04102e,0x442e1568,0x78a574c0}},	//   gnem, _niis, cag_, nkiv, 
   {{0x7bc0315a,0x78a61569,0x6112156a,0x999801ef}},	//   úmul, ikiv, _vāla, _vepř_, 
   {{0x7d06156b,0xc2413ad2,0x8eb00b38,0x2ca801e7}},	//   _aiis, _онук, بەتت, _slad_, 
   {{0x691001e4,0x86780bd9,0x7d06156c,0x78a47b86}},	//   _aĥen, בריו, _biis, kkiv, 
   {{0x7d045272,0x00000000,0x00000000,0x00000000}},	//   _ciis, --, --, --, 
   {{0xfe6c5000,0x7d04602e,0x80a2156d,0x2caa156e}},	//   ردی_, _diis, _زمون, _vlad_, 
   {{0x442e156f,0x2ca800a9,0x7d040083,0xf0e80131}},	//   zag_, _wlad_, _eiis, _ئىچى_, 
   {{0x442e1570,0x7d061571,0xa2cc00cd,0x00000000}},	//   yag_, _fiis, _तदस्, --, 
   {{0x6d4a1572,0x7d061573,0x2ca8025b,0xdb0401d3}},	//   muda, _giis, _ulad_, szká, 
   {{0x442e1574,0x00000000,0x00000000,0x00000000}},	// [3d050] vag_, --, --, --, 
   {{0x442c778b,0xc9861575,0x8aa61576,0x7d040472}},	//   wag_, _думи, _фрид, _ziis, 
   {{0x442e1577,0x6d4a1578,0x7d0404ba,0x60ca1579}},	//   tag_, nuda, _yiis, ynem, 
   {{0x7d04cd24,0x3f9c22a9,0xc4446786,0x442c062c}},	//   _xiis, yyuu_, تیرن_, uag_, 
   {{0x6d4a157a,0x60ca157b,0x64580582,0x83640101}},	//   huda, vnem, rfwi, تدال, 
   {{0x48f000bc,0x26100073,0x60c880c1,0x00000000}},	//   ंगको_, दुखी_, wnem, --, 
   {{0x442cbcc3,0x6d4a157c,0x60c8eab6,0x26c0037e}},	//   pag_, juda, tnem, miho_, 
   {{0x26c2157d,0x60c80472,0x3f9c00b5,0x00000000}},	//   liho_, unem, tyuu_, --, 
   {{0x7d06157e,0xddc0012c,0x6d4801ab,0xa2b400d8}},	//   _riis, telů, euda, _ебач, 
   {{0x7d06157f,0x26c21580,0x60c80427,0x6d4808a5}},	//   _siis, niho_, snem, fuda, 
   {{0x6d4a1581,0x7d061582,0x60c881ec,0x9f054d83}},	//   guda, _piis, pnem, _کوتو, 
   {{0x5f9484c8,0x61107343,0x7d040548,0x60c80369}},	//   _ниет, _hālo, _qiis, qnem, 
   {{0x7d04246f,0x26c071d3,0x78a400c5,0x6110002b}},	//   _viis, kiho_, vkiv, _kālo, 
   {{0x7d061583,0xde04001b,0x15b800d1,0x00000000}},	//   _wiis, _эпки, ﻠﻼﺭﺩ, --, 
   {{0x7d061584,0xdca473d6,0x6d48df47,0x6110a09f}},	//   _tiis, _наки, cuda, _mālo, 
   {{0x2fc00010,0xaee40055,0xd1500023,0x38c800e5}},	//   _žigi_, _piṇy, _ዘይበል, زازی_, 
   {{0x78a48e4c,0x00000000,0x00000000,0x00000000}},	// [3d060] rkiv, --, --, --, 
   {{0x78a56859,0x61100055,0x6bd401f7,0x00000000}},	//   skiv, _nālo, _آڪٽر, --, 
   {{0x18680261,0x9484b1f7,0x79540345,0x00000000}},	//   _лани_, зылд, _تێزا, --, 
   {{0x0d38008f,0x2368031c,0x00000000,0x00000000}},	//   מגעב, ħajn_, --, --, 
   {{0x1ddc0574,0x6d4a1585,0x61100055,0x03a00063}},	//   _नुसत, zuda, _bālo, ницо, 
   {{0x3958090c,0x611000b8,0xcb10011a,0x26c00c5e}},	//   otrs_, _cālo, עלו_, ciho_, 
   {{0x395800da,0x82300d28,0xa2cc102f,0x958400fb}},	//   ntrs_, رروا, _तदर्, _элве, 
   {{0x6d4a1586,0xdb04002f,0x8538011a,0x00000000}},	//   vuda, lzkä, _לגלי, --, 
   {{0x520805d9,0x6d4a1587,0x00000000,0x00000000}},	//   _هيءُ_, wuda, --, --, 
   {{0x6d4a1588,0x61440075,0x1c0002ab,0x00000000}},	//   tuda, سىۋە, ोशनल_, --, 
   {{0x626400f7,0x61400022,0x6d4801ab,0x00000000}},	//   _زالق, _ҧҵәа, uuda, --, 
   {{0x6d4a1589,0x0caa158a,0x26c2158b,0x5f440131}},	//   ruda, стои_, ziho_, чүән_, 
   {{0x6d4a158c,0x8e8401a9,0x00000000,0x00000000}},	//   suda, _нгде, --, --, 
   {{0xd1f0001f,0x7bf8010b,0x00000000,0x00000000}},	//   _ውሸት_, яняр_, --, --, 
   {{0x997c0276,0x2fd8004b,0x6d4801a9,0x00000000}},	//   văţa_, _اوږد_, quda, --, 
   {{0x26c00526,0x00000000,0x00000000,0x00000000}},	//   wiho_, --, --, --, 
   {{0xe7180597,0x26c106f1,0xd15002d3,0x37f8084c}},	// [3d070] زيات_, tiho_, _ዘይብል, зетэ_, 
   {{0x61ec03be,0xda6401ec,0xf67400c0,0x6e3c01e7}},	//   şilə, _قاپي, нгуэ, órbh, 
   {{0x26c00516,0xf1d407d2,0x997c0356,0x64540114}},	//   riho_, _ﭘﺎﻛﺘ, răţa_, двеђ, 
   {{0x7d040066,0x26c1909c,0x611000b8,0x00000000}},	//   lèrè, siho_, _sālo, --, 
   {{0xe299b2b5,0x611006c8,0x26c02819,0x776400a7}},	//   жал_, _pālo, piho_, _пърж, 
   {{0x68e8038f,0xa56422ad,0xd76400cf,0xe858009f}},	//   ċedu, _يگان, _تەكى_, _اسھڻ_, 
   {{0xcf8c11fc,0x24180953,0x611000ef,0x00000000}},	//   یژه_, _мовы_, _vālo, --, 
   {{0x7d040214,0x00000000,0x00000000,0x00000000}},	//   hèrè, --, --, --, 
   {{0x2d9a158d,0x61ec03f9,0x611024cb,0x00000000}},	//   ären_, ƙalo, _tālo, --, 
   {{0x69100115,0x7d04020c,0x611000e8,0x00000000}},	//   _aĥem, jèrè, _yāll, --, 
   {{0x7d040214,0xd1b00014,0x3f880356,0x00000000}},	//   dèrè, _لیوک, ţcu_, --, 
   {{0xdea0168d,0xdca43f07,0x4c800212,0x611000b8}},	//   _ڤیدی, фами, влюв, _jālm, 
   {{0x2a60070d,0x7d04020c,0x3ae40267,0x00000000}},	//   _bbhb_, fèrè, köpt_, --, 
   {{0xddc596fd,0x7d04020c,0x6e9400f3,0x00000000}},	//   _обли, gèrè, _пичу, --, 
   {{0x09e0713a,0xbdf802dd,0x00000000,0x00000000}},	//   ворн, _ارشا_, --, --, 
   {{0xa2bc08ec,0x00000000,0x00000000,0x00000000}},	//   वोत्, --, --, --, 
   {{0x395800da,0x656805be,0x2cb8017a,0xdb040036}},	// [3d080] strs_, _ćeha, ërde_, tzkä, 
   {{0xadc40248,0x59841fdf,0x195400b5,0x2b140124}},	//   _ayẹy, _жлоб, _ｊｑｇ_, _џьыр, 
   {{0xd8249dc2,0x46bc0037,0x00000000,0x00000000}},	//   _одни, _एगरह, --, --, 
   {{0x9f940166,0x13e801af,0x7414009a,0xcd94011a}},	//   _küäm_, омей_, روتا, ודעת_, 
   {{0x41c01d8a,0x20100118,0x00000000,0x00000000}},	//   _वेबस, ězil_, --, --, 
   {{0x61ec0198,0x5fe000c5,0x61100171,0x00000000}},	//   ƙall, _पड़ल, _tāll, --, 
   {{0x8d840150,0x914812fa,0x00000000,0x00000000}},	//   _ﯗﻳﺎﺕ_, ічка_, --, --, 
   {{0xe19401c0,0xa774032e,0x00000000,0x00000000}},	//   эрчэ, _íöðr, --, --, 
   {{0xb4bc0574,0x3ae401b8,0x934402bf,0x4f680212}},	//   ेची_, nöps_, _інже, ішим_, 
   {{0x0dc0001f,0x69c000d2,0xce30072d,0x00000000}},	//   _ትርፍ_, úlek, خودک, --, 
   {{0xfeb6158e,0x550c0118,0x00000000,0x00000000}},	//   بايت_, िदिए_, --, --, 
   {{0x4b5003e6,0x3ae4007c,0x00000000,0x00000000}},	//   پێدر, köps_, --, --, 
   {{0x8ae402bf,0x657804fe,0x00000000,0x00000000}},	//   дівл, āwhi, --, --, 
   {{0x3ae429ef,0xc3300375,0x27ec0327,0x81c803d4}},	//   döps_, כוש_, _ġen_, ৰেও_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2d5a158f,0x6d58014f,0x00000000,0x00000000}},	//   mée_, _iqva, --, --, 
   {{0x2d5a1590,0x3cf8007b,0xb8e801d5,0x00000000}},	// [3d090] lée_, _تعود_, ффре_, --, 
   {{0x05e80a16,0x7d0802e2,0x81c803d4,0x8cb8012d}},	//   офеи_, pèrè, ৰেট_, शोरो, 
   {{0x2d5a1591,0xabd40014,0x25081888,0x00000000}},	//   née_, _زٲگت, سرای_, --, 
   {{0x248a1592,0x320c00a2,0xdc1003e3,0xe35400b1}},	//   ñam_, _agdy_, _məğr, еткэ, 
   {{0x2d5a1593,0x33d40046,0x62661594,0x6110002b}},	//   hée_, кішт, евла, _vālm, 
   {{0x6d440374,0x2d5a1595,0x9754010f,0x93109aeb}},	//   _āian, kée_, _אישו_, دووش, 
   {{0x91e21596,0xbd08031c,0x60140174,0x2d593e03}},	//   лоше, _གཤེཊ_, _nýmó, jée_, 
   {{0x2d5a1597,0x2aac02fb,0x00000000,0x00000000}},	//   dée_, ržby_, --, --, 
   {{0x443c05ce,0x41dc06e3,0x6d5806be,0x7afc02d0}},	//   _idu_, _पुरस, _aqva, ymrt, 
   {{0x2d59a607,0x443c0618,0x9ea800d4,0xca3400d1}},	//   fée_, _hdu_, ївна_, ﺗﯧﺮ_, 
   {{0x2d5a1598,0x443e1599,0x2bc40034,0x61100171}},	//   gée_, _kdu_, _लेबा, _mālk, 
   {{0xb1c801d9,0x443c00bc,0x3084007b,0xad2400e5}},	//   _تِمن_, _jdu_, _للمف, کریو, 
   {{0x443c0369,0xf0b80066,0xe8000118,0x7fa00244}},	//   _mdu_, _تالش_, लेमा_, _جلشۆ, 
   {{0x7f580227,0x2d5874fd,0x00000000,0x00000000}},	//   mtuq, bée_, --, --, 
   {{0x2d983c12,0x2d58cb54,0x6aa00008,0x7f59097d}},	//   øret_, cée_, ölfa, ltuq, 
   {{0x7afc08a4,0x443e159a,0x3ae401b8,0xddc0005f}},	//   smrt, _ndu_, töps_, celš, 
   {{0x1ae5835b,0x7f5a159b,0x36e401b9,0x00000000}},	// [3d0a0] _поим, ntuq, вбаҳ, --, 
   {{0x443e159c,0x944400f1,0x00000000,0x00000000}},	//   _adu_, ځپان, --, --, 
   {{0x98a4f7ec,0x7f580023,0x443c0213,0xca54008f}},	//   _зине, htuq, _bdu_, _אייז_, 
   {{0x7f583209,0xb4bc0574,0x00000000,0x00000000}},	//   ktuq, ेचे_, --, --, 
   {{0x07a03769,0xb9cc0020,0x443c0368,0x370400c7}},	//   _баян, _ዳር_, _ddu_, _аҿаг, 
   {{0x2d58be41,0x29180086,0x443e159d,0x81c80183}},	//   yée_, _ôeaô_, _edu_, ৰেছ_, 
   {{0x443e159e,0x9106159f,0x2d585f0e,0x86b002dd}},	//   _fdu_, нчид, xée_, _сәті, 
   {{0x2d580231,0x0f2402bf,0x443c03e3,0xf0e80c75}},	//   vée_, ньом, _gdu_, بىعى_, 
   {{0x2d580036,0xcec402e8,0x6e9400d4,0x00000000}},	//   wée_, ещни, випу, --, 
   {{0x2d580231,0x4338010f,0x00000000,0x00000000}},	//   tée_, _מעמב, --, --, 
   {{0xc20c0050,0x443c0810,0x7f58003a,0x2d580129}},	//   _أم_, _ydu_, atuq, uée_, 
   {{0x2d582047,0xac1800d6,0x00000000,0x00000000}},	//   rée_, ьому_, --, --, 
   {{0x2d5a15a0,0x7b65afeb,0x7f580381,0xc4d0011a}},	//   sée_, лтре, ctuq, רגר_, 
   {{0x2d98f940,0x2d58b7a1,0x628c0618,0xddc000d7}},	//   øres_, pée_, ēaog, selš, 
   {{0x386215a1,0x656801fa,0x48a863bb,0x6d580455}},	//   ffir_, _ćeho, птам_, _uqva, 
   {{0x61e403fa,0x00000000,0x00000000,0x00000000}},	//   ühli, --, --, --, 
   {{0x443c02fa,0xfc6400a7,0x2368031c,0x00000000}},	// [3d0b0] _rdu_, _същн, ħajk_, --, 
   {{0x443e15a2,0x6d48e25f,0x6e28003e,0xf1b0072e}},	//   _sdu_, orda, nbdb, जनान, 
   {{0xfbd00133,0x41dc00dc,0x2bc402c3,0x99780023}},	//   _نتی_, _पुंस, _लेता, _ብፍርሒ_, 
   {{0x6d49e60f,0x7f580309,0x443c0166,0x00000000}},	//   irda, ytuq, _qdu_, --, 
   {{0x68ee15a3,0x443c0024,0x6d487155,0x98c001c6}},	//   mlad, _vdu_, hrda, _төрж, 
   {{0x216849c6,0xd6e00034,0x443c009a,0x6d4801b9}},	//   дики_, _całą_, _wdu_, krda, 
   {{0xd24c45d7,0x68ee15a4,0x7f580227,0xfa780375}},	//   زني_, olad, wtuq, געות_, 
   {{0xd00c08c9,0x443e15a5,0x7f5a15a6,0xd4c215a7}},	//   يلى_, _udu_, ttuq, _көчк, 
   {{0x68ee15a8,0x611215a9,0x00000000,0x00000000}},	//   ilad, _māli, --, --, 
   {{0xb5880014,0x7f58dd5e,0x611000b8,0x8e800022}},	//   _تپہٕ_, rtuq, _lāli, агье, 
   {{0x68ec2d2a,0x7f58c52e,0x386001a8,0x00000000}},	//   klad, stuq, yfir_, --, 
   {{0x68ee15aa,0x6110002b,0xa2bc1fe7,0x00000000}},	//   jlad, _nāli, वोर्, --, 
   {{0x2d9895a0,0x68ee15ab,0x7f580cfe,0x6e28003e}},	//   ører_, dlad, qtuq, bbdb, 
   {{0xf9c405f5,0x6d4a15ac,0x68ee15ad,0x23680327}},	//   гагү, brda, elad, ħajh_, 
   {{0x68ee15ae,0x248e15af,0xceb0008d,0x9854e2b0}},	//   flad, _onem_, _דיג_, кташ, 
   {{0x61101c52,0xef900244,0x96b800e5,0x00000000}},	//   _cāli, _ئیید, ڈائز_, --, 
   {{0x38609829,0x96b800c6,0x611000de,0xd7080006}},	// [3d0c0] rfir_, وائز_, _dāli, днае_, 
   {{0x68ee15b0,0x248e15b1,0x386215b2,0x00000000}},	//   alad, _anem_, sfir_, --, 
   {{0x56940184,0x201c02e2,0xbb4801ec,0x00000000}},	//   наҡт, _ofwi_, _ﺇﺫﻥ_, --, 
   {{0x68ec0aef,0xb73400dd,0x98a408b7,0x18a4f8fb}},	//   clad, _مہرب, _риме, _рамм, 
   {{0x248e15b3,0x00000000,0x00000000,0x00000000}},	//   _dnem_, --, --, --, 
   {{0x248e15b4,0x753c00bc,0x3a396e25,0x611000de}},	//   _enem_, _tvrz, narp_, _zāli, 
   {{0x81341a59,0x30e400d1,0x2ec40116,0x00000000}},	//   پسىز_, лсиң, һөкм, --, 
   {{0x3a380726,0x90e403e6,0x96e80022,0x6d4801d5}},	//   harp_, خستن, _хьҭа_, vrda, 
   {{0x130412cd,0x3a380254,0xd5180051,0x00000000}},	//   _азам, karp_, _hằn, --, 
   {{0x0dca15b5,0xd30800b8,0x68ec123d,0xa2440014}},	//   думи_, _aṇv_, zlad, _میٖل_, 
   {{0x6d480d47,0x6ef4004e,0x00000000,0x00000000}},	//   urda, gàba, --, --, 
   {{0x68ee15b6,0x10a40902,0x00000000,0x00000000}},	//   xlad, _шиен, --, --, 
   {{0x6d4801a9,0x00000000,0x00000000,0x00000000}},	//   srda, --, --, --, 
   {{0x68ec0d62,0x797c06d6,0x1ddc0574,0x3a392f80}},	//   wlad, _ṅwah, _नुकत, garp_, 
   {{0x79a55b43,0x68ee15b7,0x1ea83a16,0x6d5c0e89}},	//   арте, tlad, _ثاني_, àrad, 
   {{0x91d8000d,0x00000000,0x00000000,0x00000000}},	//   _पुछै, --, --, --, 
   {{0xf7711fdc,0x6110002b,0x00000000,0x00000000}},	// [3d0d0] ياك_, _vāli, --, --, 
   {{0x68ee15b8,0x248c138f,0x3a3a15b9,0xd51801fb}},	//   slad, _snem_, carp_, _bằn, 
   {{0x68ee15ba,0x61ec03f9,0xd7080131,0x6111171f}},	//   plad, ƙali, رىمۇ_, _tāli, 
   {{0x24182f45,0x68ec2cae,0x00000000,0x00000000}},	//   ходы_, qlad, --, --, 
   {{0xe364ddf8,0x916402d3,0x00000000,0x00000000}},	//   укли, _መርገጺ, --, --, 
   {{0xe1f819c3,0xd3448d24,0x81d4015b,0x6f040022}},	//   нгл_, ایله_, _সরব_, _èich, 
   {{0xdee4a3c3,0xb5940116,0xb605b060,0x00000000}},	//   ғони, _кирш, _вятк, --, 
   {{0x224902a5,0x248c0798,0x6728025c,0xf48400db}},	//   şak_, _unem_, _ħejj, _куун, 
   {{0x0fc8068f,0xd345be04,0xd30800b8,0x63ac0158}},	//   ापगढ, _مینه_, _aṇu_, øand, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3a3809cc,0x6054ad2d,0x315800c6,0xddc4b68c}},	//   varp_, _مناط, _لجنة_, убни, 
   {{0x61e40e78,0x602401b9,0xab64012d,0xa038010f}},	//   ühlu, _ёдла, ężny, _װײַז, 
   {{0x60ca15bb,0x9f5a15bc,0xa0a40022,0xcf440150}},	//   miem, äsä_, _иаҧд, _مىنۋ, 
   {{0x5d84006c,0xd5180051,0x6dc4072d,0x00000000}},	//   _ملتل, _lắn, ازیل, --, 
   {{0xdc680aa5,0x1a6417a5,0xdb0400dd,0xdea00f01}},	//   _зайд_, نیکی_, nyké, _نیکی, 
   {{0xd5180208,0x00000000,0x00000000,0x00000000}},	//   _rằn, --, --, --, 
   {{0xb8dd3df4,0x96640108,0x1664011c,0x00000000}},	// [3d0e0] _अत_, лкае, лвам, --, 
   {{0x3a38013c,0xf7640023,0x00000000,0x00000000}},	//   qarp_, _ምክፍፋ, --, --, 
   {{0x60ca15bd,0x611000b8,0x00000000,0x00000000}},	//   kiem, _kālu, --, --, 
   {{0xb8b402dd,0x60ca15be,0xbec000cd,0x00000000}},	//   _төгі, jiem, _śūla, --, 
   {{0x60ca15bf,0x04401789,0x6110b1c5,0x33940006}},	//   diem, сечн, _mālu, ралё, 
   {{0xc5b405f5,0x96b83ce7,0x55e401fe,0x00000000}},	//   _өрсө, _чуму_, _богб, --, 
   {{0x60ca15c0,0xa2a41b6e,0x00000000,0x00000000}},	//   fiem, _कवर्, --, --, 
   {{0x60ca15c1,0x8934008f,0xc3203d09,0xc38401e1}},	//   giem, ארקע_, шмәк, _lẹ́ẹ, 
   {{0x045400c6,0x00000000,0x00000000,0x00000000}},	//   _حلقة_, --, --, --, 
   {{0x41b09e04,0x60c808c8,0x63ac0158,0x00000000}},	//   рсәт, aiem, øane, --, 
   {{0x61100055,0x8c340107,0x3e640661,0x61e4002f}},	//   _bālu, лонӣ_, ушын_, ühlt, 
   {{0x60ca15c2,0xdcb0185e,0xc198011a,0x00000000}},	//   ciem, قىپ_, _רשאי, --, 
   {{0xc3840248,0x6e9615c3,0x7f4000ee,0x2a70005a}},	//   _bẹ́ẹ, _вилу, _гечж, tezb_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9e640116,0xc86424fc,0xbb1c00d1,0x00000000}},	//   _خانن, лтаи, ﺴﻤﻰ_, --, 
   {{0x611215c4,0x31440023,0x00000000,0x00000000}},	//   _gālu, _ከይተር, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3d0f0] --, --, --, --, 
   {{0x60ca15c5,0xc8640116,0x38c801e0,0xca70028e}},	//   ziem, _өтми, _ҡуян_, _اندک, 
   {{0x60c8d6f8,0xfbd001ec,0x6ae0012d,0x00000000}},	//   yiem, _وتۋ_, पकीर, --, 
   {{0x60c86e7d,0x00000000,0x00000000,0x00000000}},	//   xiem, --, --, --, 
   {{0x60ca15c6,0xd5180208,0x00000000,0x00000000}},	//   viem, _vắn, --, --, 
   {{0xae0412eb,0x634002d3,0xc87c002f,0x60c80210}},	//   रधान_, _ኣይገበ, _haß_, wiem, 
   {{0x60ca15c7,0x756801d3,0xd5840133,0x1b1c00eb}},	//   tiem, _میلہ_, _پێنه_, বীপে_, 
   {{0xdb080030,0x6aa0002f,0x118400c7,0x00000000}},	//   ľném, ölfj, шәуп_, --, 
   {{0x60c8c0db,0x22954eef,0xc87c03fa,0x3fc403e6}},	//   riem, _پلاس, _maß_, دگای_, 
   {{0x60ca15c8,0x61e40e78,0xc87c0e78,0x00000000}},	//   siem, ühls, _laß_, --, 
   {{0x611006c8,0x60ca15c9,0x859c0150,0x00000000}},	//   _pālu, piem, _ﺍﻧﺪﺍ_, --, 
   {{0xf1a615ca,0x2124014f,0x5f74015e,0xc87c002f}},	//   _урун, _itlh_, _ناتر, _naß_, 
   {{0x7cc401ed,0x2590063f,0x6110002b,0x81d400eb}},	//   nőri, ịdịị_, _vālu, _সরি_, 
   {{0x6d5c08c2,0x2da801e7,0x00000000,0x00000000}},	//   àrac, íteá_, --, --, 
   {{0x61ec02a8,0x8110015b,0xda7800d1,0x61100a2f}},	//   ƙalu, _সবুজ_, няң_, _tālu, 
   {{0x5824094f,0x68fc002f,0xd8245ab8,0x00000000}},	//   рмаб, _chsd, рдаи, --, 
   {{0xe8008fa7,0xc87c0639,0x00000000,0x00000000}},	// [3d100] लेला_, _daß_, --, --, 
   {{0xda6615cb,0x2124014f,0xf8b80032,0xd5180208}},	//   _твои, _otlh_, төү_, _nẵn, 
   {{0x21240798,0xc87c002f,0x00000000,0x00000000}},	//   _ntlh_, _faß_, --, --, 
   {{0x2b4c0427,0x00000000,0x00000000,0x00000000}},	//   šece_, --, --, --, 
   {{0x2124014f,0x8c18011a,0x7cc400e5,0x00000000}},	//   _atlh_, דוני, gőri, --, 
   {{0xc0e55e0f,0x43800131,0x00000000,0x00000000}},	//   یفون_, زلىق, --, --, 
   {{0x765c0117,0x41702a8b,0x63400023,0x7584179e}},	//   _icry, قايس, _ኣይግበ, _دیام, 
   {{0xd0840474,0x92d4015b,0xe3b00050,0x20180165}},	//   рыки, সতে_, _کرِ_, ñsip_, 
   {{0x236a15cc,0x656801fa,0x2124016d,0x3e780024}},	//   _محلي_, _ćehi, _etlh_, kštė_, 
   {{0x6ef4004e,0xbf1001d9,0x23680327,0x00000000}},	//   ràbo, توٝب, ħajt_, --, 
   {{0x3ef401c6,0x00000000,0x00000000,0x00000000}},	//   рнээ_, --, --, --, 
   {{0x13a80eac,0x00000000,0x00000000,0x00000000}},	//   _খেয়, --, --, --, 
   {{0x2ff41411,0x00b80375,0xa2bc00dc,0x4ed00354}},	//   _اتاڭ, _במאמ, वोक्, _дιав, 
   {{0x61ec0198,0xc87c0e78,0x00000000,0x00000000}},	//   ƙalt, _saß_, --, --, 
   {{0xe894034b,0xccf80063,0xc87c002f,0x00000000}},	//   бавь, _ићи_, _paß_, --, 
   {{0x6e38014f,0xa81400d1,0xf77000ec,0x1a7401ec}},	//   _hevb, сдаш, ڀال_, _құсы_, 
   {{0xbc240014,0x862400ae,0x00000000,0x00000000}},	// [3d110] _بر٘ى, لةال, --, --, 
   {{0xf77004fb,0xfaa40114,0x00000000,0x00000000}},	//   باف_, _мањо, --, --, 
   {{0x641400c6,0x6e38047e,0x236c00ef,0xbec000b8}},	//   مواط, _mevb, _spej_, _śūka, 
   {{0x67d40598,0x765c035a,0xa43800f7,0x8af803e3}},	//   _гому, _ecry, узду_, bhəç, 
   {{0x212401f9,0x4ab804fa,0x224402e2,0x0a480023}},	//   _stlh_, _उताव, _pdlk_, _ንምስራ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x21240455,0x27b400d1,0x22f80014,0x00000000}},	//   _qtlh_, _тәңс, ن٘چھ_, --, 
   {{0x6aa4002f,0x9d4401e0,0xa6b800fe,0x61100171}},	//   _lohf, ҙемд, _আদিয়, _sāls, 
   {{0x645a15cd,0x442c003e,0x00000000,0x00000000}},	//   mgwi, mbg_, --, --, 
   {{0x66f8086b,0x442c0175,0x64580142,0x00000000}},	//   ्गिक_, lbg_, lgwi, --, 
   {{0x628215ce,0xf288021a,0x6e380477,0x2124047e}},	//   _ialo, _خپلو_, _devb, _utlh_, 
   {{0x628187f7,0x3e48043b,0x70941ee3,0x442c2c28}},	//   _halo, _mɔtɔ_, _махф, nbg_, 
   {{0x628215cf,0xdca407d6,0x8b640116,0x5ff4d63e}},	//   _kalo, _ҳайи, бияв_, _узду, 
   {{0x6ee44072,0x6aa4007f,0x2d6c016b,0x8fa0b3bc}},	//   _وسول, _cohf, _sɛee_, _хаше, 
   {{0x6281b12a,0x442c579d,0x2d99cff3,0xe5c800a2}},	//   _malo, kbg_, äret_, _çiňň, 
   {{0x628215d0,0xad247092,0x765c1368,0x6ae002ab}},	//   _lalo, _بروو, _scry, पकॉर, 
   {{0x7c2615d1,0x628005da,0x442c0334,0xcc54011a}},	// [3d120] _ifir, _oalo, dbg_, _הספק_, 
   {{0xc5b405f5,0x645801a4,0x442c0334,0x00000000}},	//   өрхө, egwi, ebg_, --, 
   {{0x99840491,0xdb0615d2,0x4a780a7c,0xe1e401c8}},	//   _الجو, szkó, _גריב, _آڳ_, 
   {{0x64580135,0x442c007c,0x00000000,0x00000000}},	//   ggwi, gbg_, --, --, 
   {{0x7c240134,0xdef4069d,0xe4e800ae,0x00000000}},	//   _mfir, ለምን_, جعله_, --, 
   {{0xfe64ad99,0x845454a2,0x645823e8,0x00000000}},	//   _عد_, арәт_, agwi, --, 
   {{0x91840597,0x7c2615d3,0x626400db,0x77640077}},	//   إجتم, _ofir, تانق, ltix, 
   {{0x2368038f,0xd58404d3,0x628003ac,0x7c2615d4}},	//   ħajr_, _پێچه_, _ealo, _nfir, 
   {{0x628215d5,0xeeb805c2,0x7765b310,0x1b1c015b}},	//   _falo, илиш_, ntix, বীতে_, 
   {{0x8778008f,0x628215d6,0x11380024,0x00000000}},	//   נאיי, _galo, _бяды_, --, 
   {{0x6aa615d7,0x776401a9,0x00000000,0x00000000}},	//   _rohf, htix, --, --, 
   {{0x6281ec7b,0x6aa40036,0x25a400e8,0x6ae018cc}},	//   _zalo, _sohf, _àlle_, पक्र, 
   {{0x628215d8,0x6e3a15d9,0x611000da,0x00000000}},	//   _yalo, _tevb, _tālr, --, 
   {{0x7c2615da,0x6280ed29,0x2d9875ee,0x00000000}},	//   _efir, _xalo, äres_, --, 
   {{0x7c240135,0x61ec05d1,0x6ce40220,0x61100055}},	//   _ffir, ğalg, _وزبە, _kālp, 
   {{0x7764003d,0x442c01c7,0xa92400d7,0x00000000}},	//   ftix, xbg_, vaľč, --, 
   {{0x6fb805f9,0x442c0175,0x611000de,0xa7140150}},	// [3d130] इनिं, vbg_, _mālp, імжі, 
   {{0x6b8e15db,0x442c0334,0x66c803e3,0x00000000}},	//   _irag, wbg_, _kökə, --, 
   {{0x628215dc,0x7c2400fc,0x442c010a,0x6b8c00ad}},	//   _ralo, _yfir, tbg_, _hrag, 
   {{0x6b8e15dd,0x62809a62,0x23b40ed1,0x1288035c}},	//   _krag, _salo, يماس, یمنی_, 
   {{0x628215de,0x442c0334,0x6b9c0c6a,0x6458002f}},	//   _palo, rbg_, nxsg, rgwi, 
   {{0x628215df,0x6b8c020c,0x6458014b,0x00000000}},	//   _qalo, _mrag, sgwi, --, 
   {{0x672e15e0,0x442c0334,0x66c803b9,0x00000000}},	//   lpaj, pbg_, _nökə, --, 
   {{0x6b8e15e1,0x611000b8,0x6ef401ab,0x672c00df}},	//   _orag, _cālp, làbh, opaj, 
   {{0x628215e2,0x644a15e3,0xdbf00316,0x65640c8c}},	//   _talo, _idei, _přír, lthh, 
   {{0x628215e4,0x672e15e5,0x7c240311,0xb77c00df}},	//   _ualo, ipaj, _sfir, ראזש, 
   {{0x65640618,0x7c240112,0x776401c4,0x38bc01d3}},	//   nthh, _pfir, ztix, _híre_, 
   {{0x6b8e15e6,0x5f9615e7,0xd00c2263,0x61ec719a}},	//   _brag, _ولائ, علی_, ğald, 
   {{0x6b8c1368,0x2d98049f,0x672c0784,0x61ec274a}},	//   _crag, ärer_, jpaj, şald, 
   {{0x6b8e15e8,0x9f0408a2,0x38bc00ae,0xddc00064}},	//   _drag, _بوتو, _míre_, melž, 
   {{0x6b8c0323,0x644806ed,0xdca58c92,0x4ab80490}},	//   _erag, _odei, _маки, _उतरव, 
   {{0x644a15e9,0x6b8c998b,0x3ea615ea,0x7764be3f}},	//   _ndei, _frag, _hont_, ttix, 
   {{0x3ea5bc20,0xc31c11ba,0xd1e00023,0x00000000}},	// [3d140] _kont_, নীতি_, ዝሞተ_, --, 
   {{0x64480cfd,0x3ea40165,0x77640005,0x0b400139}},	//   _adei, _jont_, rtix, _юньн, 
   {{0x3ea615eb,0x776615ec,0x18687c45,0x64480327}},	//   _mont_, stix, _кани_, _bdei, 
   {{0x672c0218,0x3958005f,0x3ea40549,0xf4d800fe}},	//   bpaj, murs_, _lont_, তত্ব, 
   {{0x61e00784,0x39580c86,0x64480368,0x81d403d4}},	//   _axll, lurs_, _ddei, _সৰল_, 
   {{0x6448db83,0xa6c800f1,0x00000000,0x00000000}},	//   _edei, _هوټل_, --, --, 
   {{0x395804cc,0x00000000,0x00000000,0x00000000}},	//   nurs_, --, --, --, 
   {{0x8f444834,0x6448009b,0xe800012c,0x35c4013e}},	//   оход, _gdei, लेका_, _даҳҳ, 
   {{0x8269a399,0x3ea615ed,0x66c806be,0x61100055}},	//   _چشمہ_, _bont_, _sökə, _vālp, 
   {{0x3ea40262,0x6b8c27be,0x91940114,0x00000000}},	//   _cont_, _rrag, _мјеш, --, 
   {{0x3ea615ee,0xac1a15ef,0x6b8e15f0,0x395800b5}},	//   _dont_, йону_, _srag, jurs_, 
   {{0x39581570,0x3ea405c7,0x672e15f1,0xe570008f}},	//   durs_, _eont_, ypaj, ײַט_, 
   {{0x3ea48c75,0x2bc405ba,0x395820ef,0xfb84760c}},	//   _font_, _लेखा, eurs_, мырн, 
   {{0x6b8c207e,0x3ea403bd,0xe1f00014,0x672c0218}},	//   _vrag, _gont_, _آسے_, vpaj, 
   {{0x395a15f2,0x6b8e15f3,0x672c02d1,0x6cd411dc}},	//   gurs_, _wrag, wpaj, _ىقتا, 
   {{0x3ea615f4,0x00000000,0x00000000,0x00000000}},	//   _zont_, --, --, --, 
   {{0x6b8e15f5,0x3ea4039a,0x31d000cc,0xaa5800f3}},	// [3d150] _urag, _yont_, িথিশ, _липу_, 
   {{0x395a15f6,0xe800068f,0x2ca80156,0x6448005a}},	//   burs_, लेगा_, _hoad_, _sdei, 
   {{0x09040491,0x672c89b9,0x0ddc044e,0x2ca80489}},	//   _мчмм, spaj, _ሓላፊ_, _koad_, 
   {{0xa87800c8,0x2ca8000f,0x656402d0,0x672c0e03}},	//   _פאָר, _joad_, rthh, ppaj, 
   {{0x29088928,0x68ec01b9,0x2b5805d5,0xc764075e}},	//   mmaa_, moad, nusc_, _باجى, 
   {{0x2909f7f8,0x2caa15f7,0x3f9806af,0x38bc00d7}},	//   lmaa_, _load_, _àqui_, _víre_, 
   {{0x290a15f8,0x3ea615f9,0x64480175,0xdb0400e5}},	//   omaa_, _ront_, _tdei, nyká, 
   {{0x3ea49083,0x38bc0597,0x2caa15fa,0x68ed1704}},	//   _sont_, _tíre_, _noad_, noad, 
   {{0x3ea615fb,0x29093de0,0x00000000,0x00000000}},	//   _pont_, imaa_, --, --, 
   {{0x68edcceb,0x3374036b,0x32540209,0xddc40276}},	//   hoad, _югур, _овур, збои, 
   {{0x3ea615fc,0x68ee15fd,0x29080037,0x00000000}},	//   _vont_, koad, kmaa_, --, 
   {{0x68ee15fe,0x39581570,0x2ca81368,0xdb045380}},	//   joad, vurs_, _coad_, nzkö, 
   {{0x68ec01f9,0x3ea615ff,0x2ca80076,0x2908fc3d}},	//   doad, _tont_, _doad_, dmaa_, 
   {{0x395a1600,0xe3b8000f,0x290987ca,0x999802b5}},	//   turs_, _afűk_, emaa_, _uepū_, 
   {{0x3f9c208d,0x8a0000f3,0x1d0850ce,0xdb0401d3}},	//   lxuu_, езре, _леки_, gyká, 
   {{0x68ec002d,0x2ca805c7,0x395804cc,0x29080009}},	//   goad, _goad_, rurs_, gmaa_, 
   {{0x395a1601,0x7d061602,0xfa18004b,0x63ac0217}},	// [3d160] surs_, _ihis, _وردګ_, øanl, 
   {{0x29090ff0,0x068103dd,0xcd4001d3,0x395a1603}},	//   amaa_, нгун, _تھیٹ, purs_, 
   {{0x68ee1604,0x7d061605,0x29080009,0xda081410}},	//   boad, _khis, bmaa_, _ديده_, 
   {{0x68ec04d4,0x045400c6,0x3a240134,0x8bd001d5}},	//   coad, كلمة_, ɛmpa_, _آقیش, 
   {{0x7d061606,0xe8b40205,0x78a61607,0x00000000}},	//   _mhis, _hışı, mjiv, --, 
   {{0xa3a4012c,0x7d041368,0xe8b4247e,0xd13821b5}},	//   nářů_, _lhis, _kışı, бхи_, 
   {{0x3f8deb50,0x7d0404fd,0x9fb400bc,0x00000000}},	//   _argu_, _ohis, _dřív_, --, 
   {{0x78a404b9,0x3ce00010,0xd6bc00fe,0xdbd8010e}},	//   njiv, _njiv_, _আদিয, _sçýo, 
   {{0x2caa1608,0x0874010f,0x5ea400cc,0x00d41291}},	//   _road_, לעקט_, গোছে, ثبوت_, 
   {{0x2ca80225,0xe2a801d9,0xac8802d3,0x2908022f}},	//   _soad_, _والن_, _ንኹሎም_, zmaa_, 
   {{0x3f8c208d,0x6c545899,0x7d061609,0x68ec009f}},	//   _ergu_, мкну, _bhis, yoad, 
   {{0x7d06160a,0xfe6c323b,0x290800e8,0x9df80137}},	//   _chis, پدی_, xmaa_, өнөт_, 
   {{0x7d06160b,0x78a40b91,0x3f8c01fa,0x68ee160c}},	//   _dhis, djiv, _grgu_, voad, 
   {{0x2b58fc40,0x7d055d1a,0x2ca9018a,0xbea02218}},	//   rusc_, _ehis, _woad_, _пачк, 
   {{0x7d040084,0x290a160d,0x2ca89721,0x00000000}},	//   _fhis, tmaa_, _toad_, --, 
   {{0x7d06160e,0xe8b40365,0xfdf4008d,0x29082337}},	//   _ghis, _dışı, _מצות_, umaa_, 
   {{0x290914f3,0x68ee160f,0x7cd801d9,0xfc313042}},	// [3d170] rmaa_, road, _روٝز_, _صحي_, 
   {{0x68ee1610,0x290a1611,0xb6f40063,0xe53401f4}},	//   soad, smaa_, езуј, дежь, 
   {{0x68ec009f,0x2908002e,0x2b486b41,0x7d040254}},	//   poad, pmaa_, _hvac_, _yhis, 
   {{0x290803d9,0xa3d4005b,0xd5ac0050,0xdb04007c}},	//   qmaa_, моеч, جہِ_, uzkö, 
   {{0xc6a400f3,0x99880064,0x00000000,0x00000000}},	//   _ерви, babų_, --, --, 
   {{0xdb0401ed,0x00000000,0x00000000,0x00000000}},	//   szkö, --, --, --, 
   {{0xa0a484c8,0x91e1f022,0x00000000,0x00000000}},	//   дайд, коше, --, --, 
   {{0x2b48eaf4,0x00000000,0x00000000,0x00000000}},	//   _ovac_, --, --, --, 
   {{0x443d29df,0x7ce80724,0x7d061612,0x3f9c0009}},	//   _ieu_, lırg, _rhis, uxuu_, 
   {{0x7d061613,0x443e1614,0x38bc0118,0xc224074d}},	//   _shis, _heu_, _míra_, _хьай, 
   {{0x7d061615,0x443e1616,0xb9e802a6,0x320003f9}},	//   _phis, _keu_, _খণ্ড_, ƙiya_, 
   {{0x443e1617,0x3f8c341a,0x7d044f6b,0xe8b40139}},	//   _jeu_, _trgu_, _qhis, _rışı, 
   {{0x443e1618,0x3f80005f,0x3f9c0e14,0x3f8cd27e}},	//   _meu_, ājus_, qxuu_, _urgu_, 
   {{0x443e1619,0x7d045ffb,0xe8b40166,0x7f580067}},	//   _leu_, _whis, _pışı, muuq, 
   {{0x443c01af,0xd946161a,0xd1c402d3,0x7f58058a}},	//   _oeu_, ьеви, _ጹቡቕ_, luuq, 
   {{0x443e161b,0x7d04f714,0x38c83c5b,0x7ce862c7}},	//   _neu_, _uhis, سازی_, dırg, 
   {{0x7f580309,0xb8280137,0x574800c0,0x16a801f0}},	// [3d180] nuuq, _ۉيدۅ_, юзам_, оваи_, 
   {{0x443c0207,0xe8b4013d,0x38bc0118,0xdb0400a2}},	//   _aeu_, _tışı, _díra_, dykç, 
   {{0x443e161c,0x38bc00c7,0x94840cdd,0xd5b0007b}},	//   _beu_, _eíra_, дылд, خفض_, 
   {{0x443e161d,0x65b8009d,0xb20800c7,0x00000000}},	//   _ceu_, чуур_, ҧҵаз_, --, 
   {{0x443c1f40,0x04401318,0x93782761,0x38bc02d2}},	//   _deu_, течн, تصار_, _gíra_, 
   {{0x443c0660,0x38602833,0x7ce83bc1,0x8230132f}},	//   _eeu_, lgir_, lırd, پروا, 
   {{0x443e161e,0x862001b9,0x38600142,0x00000000}},	//   _feu_, _شکلل, ogir_, --, 
   {{0x443e161f,0x7ce81ae4,0x38bc0248,0xdb0401f4}},	//   _geu_, nırd, _yíra_, lykä, 
   {{0x4fc43c1b,0x61ec0e98,0x63c401ee,0x00000000}},	//   ьска, ğala, _затҡ, --, 
   {{0x443e1620,0x61ee1621,0xb8e0031c,0xdb0401f4}},	//   _zeu_, şala, _ཀཾ_, nykä, 
   {{0x443c001e,0x7ce862c7,0x867802e4,0x62641178}},	//   _yeu_, kırd, חריו, _سالق, 
   {{0xe57000c8,0x40900597,0x6380035b,0xdb0401f4}},	//   אַך_, _للمر, _рҳәа, hykä, 
   {{0x7ce80e98,0x3860003b,0xbb480014,0xdb0401f4}},	//   dırd, dgir_, ولَن_, kykä, 
   {{0x4ea400d3,0xead40022,0x753c0210,0x00000000}},	//   _ірла, хогь, _owrz, --, 
   {{0x48a802d5,0x3ea40014,0x7ce81432,0x2be023ef}},	//   отам_, _تشنہ, fırd, _पखवा, 
   {{0x6d4a1622,0xe8640323,0x38601f60,0x6f18014f}},	//   msda, эхгү, ggir_, _hivc, 
   {{0x6d49d9af,0x443e1623,0x2b480cf4,0xe71a1624}},	// [3d190] lsda, _reu_, _uvac_, سيات_, 
   {{0x443c4f7b,0x6f180477,0x6d4a1625,0x38bc4158}},	//   _seu_, _jivc, osda, _víra_, 
   {{0x443c388b,0x6d482778,0xdd101b0d,0x7ce80205}},	//   _peu_, nsda, nüşl, bırd, 
   {{0x7ce918fe,0x6d48119f,0x00000000,0x00000000}},	//   rırg, isda, --, --, 
   {{0xe298b979,0x443e0d50,0x291a1626,0xd24c0075}},	//   зал_, _veu_, _iisa_, ڭنى_, 
   {{0x291a1627,0x6d4a1628,0x443e1629,0x6f18014f}},	//   _hisa_, ksda, _weu_, _nivc, 
   {{0x443e162a,0x291a162b,0x26d001b9,0x0466162c}},	//   _teu_, _kisa_, _imzo_, _отам, 
   {{0x6d480ac8,0x7f580d04,0x9f840830,0x443c009d}},	//   dsda, tuuq, егид, _ueu_, 
   {{0x6d498663,0x2d980267,0x828001d5,0x00000000}},	//   esda, åren_, _ақлд, --, 
   {{0x7ce803be,0x4f06162d,0x291a162e,0x6f1a162f}},	//   zırd, ннын_, _lisa_, _civc, 
   {{0x7f5801d9,0x6f1a1630,0x7ce87236,0x38621631}},	//   suuq, _divc, yırd, ygir_, 
   {{0x291a1632,0xdca40e4e,0x5ca61633,0x00000000}},	//   _nisa_, хами, химб, --, 
   {{0x7f580050,0x6d480e89,0x3864010b,0x09e0024c}},	//   quuq, asda, _ömri_, ҳорн, 
   {{0x29190994,0x6d4a1634,0x3860030a,0x5f04013d}},	//   _aisa_, bsda, wgir_, _язла, 
   {{0x291a1635,0x7ce8e945,0x673c03ac,0x386005d5}},	//   _bisa_, tırd, _awsj, tgir_, 
   {{0x29190232,0x6f182630,0x00000000,0x00000000}},	//   _cisa_, _zivc, --, --, 
   {{0x2918069c,0x38621636,0xb908098a,0x7ce83bc1}},	// [3d1a0] _disa_, rgir_, _बद_, rırd, 
   {{0x598520f2,0x291a1637,0x7ce862c7,0x6ef426b7}},	//   _злоб, _eisa_, sırd, làbr, 
   {{0x291a1638,0x38601445,0x56940032,0x673c03ac}},	//   _fisa_, pgir_, маҡт, _ewsj, 
   {{0x9344181b,0x291a1639,0x201c0085,0xd404011b}},	//   енде, _gisa_, _ngwi_, няли, 
   {{0x6d4801d3,0xdb040108,0x00000000,0x00000000}},	//   zsda, pykä, --, --, 
   {{0x29191a91,0x6d485991,0xdd103535,0x00000000}},	//   _zisa_, ysda, yüşl, --, 
   {{0x291806e4,0x6d48022e,0x59b000cd,0x870400d4}},	//   _yisa_, xsda, ीनिर, _черв_, 
   {{0x291a163a,0x0fe000f7,0x6f183733,0x26040490}},	//   _xisa_, лөлү, _sivc, _वरती_, 
   {{0x6d4a163b,0x6f1a163c,0x662801f4,0x00000000}},	//   wsda, _pivc, _äskö, --, 
   {{0x59b000af,0x201c007f,0xc7b00375,0x6f18022e}},	//   ीनार, _egwi_, טבח_, _qivc, 
   {{0x6d4a163d,0x6eb40034,0x6f1801e4,0x6ef400db}},	//   usda, ेसबु, _vivc, fàbr, 
   {{0xdd10ec86,0x6f180455,0xc0e00354,0x00000000}},	//   rüşl, _wivc, _йохк, --, 
   {{0x291a163e,0x6d4a163f,0x6f18014f,0xdb240248}},	//   _risa_, ssda, _tivc, _òpìt, 
   {{0x291a1640,0xc8f81fe7,0x00000000,0x00000000}},	//   _sisa_, ्ष्म_, --, --, 
   {{0x1ea8495f,0x291a1641,0x0904005b,0x68400419}},	//   _تاني_, _pisa_, ечам, hádž, 
   {{0x29187885,0x6110002b,0x68e801a6,0x7ce808a9}},	//   _qisa_, _bāly, čedo, tıre, 
   {{0x291a1642,0x38bc00d8,0x611000b8,0x00000000}},	// [3d1b0] _visa_, _eíro_, _cāly, --, 
   {{0x65961643,0x291a1644,0x3f98056a,0x2604000d}},	//   казу, _wisa_, _áque_, _वरदी_, 
   {{0x291a1645,0x00000000,0x00000000,0x00000000}},	//   _tisa_, --, --, --, 
   {{0xa8042374,0x291a1646,0x64bc01ad,0xbb4801e2}},	//   _үзүл, _uisa_, ्फेश, _تلین_, 
   {{0x6fd0134e,0x62240131,0x970000d1,0xca4c0150}},	//   _तेलं, نىشل, _چېقى, _ﺎﻻﺕ_, 
   {{0x26d0014b,0x248a1647,0x80d002ab,0xbb3c04ae}},	//   _umzo_, žam_, बोने, לעדי, 
   {{0x97640b82,0xa6e80051,0xc0380092,0x61ec0205}},	//   _ውርደት, thươ, _የቀረው, ğalo, 
   {{0xba04044e,0x7125207f,0x27ec00b5,0xb50800cf}},	//   _ግደ_, درول, _øens_, _كۉلۅ_, 
   {{0xcf4007ee,0x7ce80205,0xbf181b51,0x00000000}},	//   аный, yırb, नदेन_, --, 
   {{0x1e9417a2,0x26dc003e,0xf1a405a2,0xe13400db}},	//   трир, éwoh_, трән, _анжы, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x38bc0248,0x00000000,0x00000000,0x00000000}},	//   _ríro_, --, --, --, 
   {{0xd10c05d7,0x30d8008f,0x00000000,0x00000000}},	//   ागरण_, _אַװע, --, --, 
   {{0x1d94014b,0x00000000,0x00000000,0x00000000}},	//   _ариё, --, --, --, 
   {{0x186a1648,0x00000000,0x00000000,0x00000000}},	//   мави_, --, --, --, 
   {{0x611000b8,0x00000000,0x00000000,0x00000000}},	//   _pāly, --, --, --, 
   {{0x16643246,0x4b8528a1,0x9b04130f,0x38bc01e1}},	// [3d1c0] квам, _айын_, _изид, _wíro_, 
   {{0x38bc48bf,0x00000000,0x00000000,0x00000000}},	//   _tíro_, --, --, --, 
   {{0x5469b868,0xddc00093,0xca54010f,0x00000000}},	//   даем_, kalō, _בייז_, --, 
   {{0x38c801e1,0x61ed2d65,0xe79000a2,0x00000000}},	//   _dìrù_, ğall, _göįü, --, 
   {{0x61ec3630,0xc5ec00f1,0x99d402f2,0x00000000}},	//   şall, مړې_, _ستگا, --, 
   {{0x1dc0090a,0x16080118,0x00000000,0x00000000}},	//   शनात, _वरपर_, --, --, 
   {{0x518420db,0xb1181a59,0x942400a8,0x26dc013f}},	//   тула, ىقتا_, _амбе, ɑwo_, 
   {{0x2b4c0114,0xb63c0220,0x00000000,0x00000000}},	//   šeci_, _ﺇﻟ_, --, --, 
   {{0x6fb4104c,0x80000108,0x00000000,0x00000000}},	//   امخا, ичье, --, --, 
   {{0x20e400b0,0xea9800b8,0xcee80956,0x00000000}},	//   rēia_, _muṃ_, بربن_, --, 
   {{0x8658011a,0x00000000,0x00000000,0x00000000}},	//   ודיי, --, --, --, 
   {{0xc5f00302,0x7ce80790,0x00000000,0x00000000}},	//   ידת_, vırc, --, --, 
   {{0x6fb000cc,0x8fa4010a,0x00000000,0x00000000}},	//   _জেৰে, _шаде, --, --, 
   {{0xdee8044e,0x7b180166,0x7ce80205,0x00000000}},	//   _መጻኢ_, кояр_, tırc, --, 
   {{0xac9401c0,0xea980055,0xbac800fb,0xf1c01870}},	//   _байш, _auṃ_, тыяж_, ﺭﺍﻛﺘ, 
   {{0x48c0015b,0x38c400d4,0x00000000,0x00000000}},	//   ্ক্র, ащув, --, --, 
   {{0xc6680108,0x00000000,0x00000000,0x00000000}},	// [3d1d0] дшее_, --, --, --, 
   {{0x67780023,0xdb98011a,0x7ce80213,0x00000000}},	//   _ከካይዱ_, _נסתר, mıra, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xde14008f,0x00000000,0x00000000,0x00000000}},	//   אַנץ_, --, --, --, 
   {{0x61edb056,0x7ce80213,0x38c80139,0xf4845bc6}},	//   ğalm, nıra, _руэн_, рухн, 
   {{0xf99061f4,0x61ec4a98,0x1f640107,0x38c801e1}},	//   _ابی_, şalm, ҳким, _tìrù_, 
   {{0xfa783d99,0xd24cf7d1,0x71653637,0x36d4cf02}},	//   דעות_, سني_, لايك, _торр, 
   {{0x6fd40cb4,0x1f64234c,0x4428e400,0x7ce8c8d8}},	//   _बेहू, гким, _üc_, kıra, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x248c0007,0x7ce86f38,0xfe74f229,0x5fd800c5}},	//   _haem_, dıra, түк_, _बइठल, 
   {{0xdc680aa5,0x248c045f,0xddc00418,0x63b80175}},	//   нанд_, _kaem_, palō, lywn, 
   {{0x248c004e,0x5574010f,0x00000000,0x00000000}},	//   _jaem_, נערן_, --, --, 
   {{0xa2b860d3,0x248c3743,0x22461649,0x63b804ba}},	//   ्सप्, _maem_, _kelk_, nywn, 
   {{0xf9c40323,0x7cc400dd,0x248c0139,0x8f50552d}},	//   аагү, nőrz, _laem_, _انوش, 
   {{0x2246164a,0x5d7800c8,0xdd9000b2,0x2124068c}},	//   _melk_, _טאַק, _چوڻ_, _julh_, 
   {{0xef9001d5,0xea9800b8,0x4df8010f,0xad640133}},	//   _ایید, _puṃ_, _אפצא, _ئاوه, 
   {{0xc7a05622,0x07a007a5,0x00000000,0x00000000}},	// [3d1e0] битк, батн, --, --, 
   {{0x8c180375,0x22440254,0x6d5d9cf9,0x00000000}},	//   _אופי, _nelk_, árag, --, 
   {{0x248c0c36,0xb4b40032,0xd94410d9,0x7f580327}},	//   _baem_, ғиҙә, _щени, hruq, 
   {{0x136802d7,0x248c0798,0x98a6164b,0x7f580472}},	//   ешки_, _caem_, _симе, kruq, 
   {{0x248c0399,0x22440165,0xcc38008f,0x3c740116}},	//   _daem_, _belk_, גענט, ﻻﺗﺘﻰ_, 
   {{0x7cc401d3,0x22440306,0x7f5806be,0x00000000}},	//   gőrz, _celk_, druq, --, 
   {{0x248e164c,0x8cc40073,0x7ce80213,0x130402dd}},	//   _faem_, ासमो, zıra, _ұзам, 
   {{0x248c0369,0xceb80198,0x5066164d,0x7ce800ac}},	//   _gaem_, _miƙe_, утка, yıra, 
   {{0xceb80198,0x7ce80213,0xaee400b8,0xbf3001d5}},	//   _liƙe_, xıra, _niṣy, یریغ, 
   {{0xe3b001d9,0x22440327,0x5344035b,0xc20c0050}},	//   _برِ_, _gelk_, _ахҧа, _کٔم_, 
   {{0x248c0007,0x2b900030,0x6fd407f7,0xf1a802c3}},	//   _yaem_, _môcť_, _बेरू, _कपिन, 
   {{0x7ce90b83,0x00000000,0x00000000,0x00000000}},	//   tıra, --, --, --, 
   {{0x4fb6164e,0xd01006b6,0x7dc001b9,0x00000000}},	//   _حصار, _الش_, لقین, --, 
   {{0xaa9405f5,0xc985ea38,0x7ce89c13,0x59d4ad78}},	//   шигч, луби, rıra, _डेहर, 
   {{0x63b8033f,0x6d5cc90f,0x7ce80205,0xe51c0037}},	//   zywn, árad, sıra, _बूझि_, 
   {{0xbb387a32,0x7ebc0af9,0x25a4002e,0x7ce806be}},	//   ﮕﻪﻥ_, _lêpl, _àlli_, pıra, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3d1f0] --, --, --, --, 
   {{0x248e164f,0x00000000,0x00000000,0x00000000}},	//   _saem_, --, --, --, 
   {{0xa5d41fbe,0x00000000,0x00000000,0x00000000}},	//   јжеш, --, --, --, 
   {{0x63b8006d,0x7f586eb3,0x224400a2,0xfa34104c}},	//   tywn, yruq, _selk_, _پرید, 
   {{0x2124155d,0x22440d01,0x7ce80139,0x00000000}},	//   _sulh_, _pelk_, kırn, --, 
   {{0x65941999,0x7f58022e,0x855400e5,0xdec001f3}},	//   _кагу, vruq, _میئر_, ስቱን_, 
   {{0xd12c7ffb,0x248c2af2,0xe2c8c73b,0x63b8033f}},	//   ومو_, _taem_, _یورو_, sywn, 
   {{0x22440cf9,0x248c0789,0xd34505bf,0xb97c008f}},	//   _welk_, _uaem_, _چینه_, גנהי, 
   {{0x2018ef95,0x2244000d,0x38bc0166,0xd3440133}},	//   äsi_, _telk_, _sírk_, _نینه_, 
   {{0x7f580429,0xe63c001f,0xaee400b8,0xea980055}},	//   rruq, _ይቀጥላ, _riṣy, _yuṅ_, 
   {{0xd24c01b9,0x7f58025c,0xdca4009d,0x00000000}},	//   _آچه_, sruq, аани, --, 
   {{0xceb80b45,0x30e40006,0xaee40055,0xc0e00092}},	//   _riƙe_, _лічб, _piṣy, ኞችም_, 
   {{0x9154168d,0x9b04273e,0x4b8402f4,0x01e4015b}},	//   _مرۆڤ, измд, айян_, _ফরিদ, 
   {{0x60ca1650,0x13b8008f,0x1a640330,0xaee40055}},	//   lhem, דזשע, جیدی_, _viṣy, 
   {{0xd8240e58,0xf0500092,0x00000000,0x00000000}},	//   идви, _መቀጠሉ, --, --, 
   {{0x60ca1651,0xaee4002b,0xb7b4009d,0x7c8401af}},	//   nhem, _tiṣy, бөгч, _уҫма, 
   {{0x7c261652,0xdb840952,0xd6288f3a,0x588400fb}},	// [3d200] _igir, ﻪﻧﺪﻯ_, возе_, лыҡа, 
   {{0x60c8014b,0x06c4009d,0x00000000,0x00000000}},	//   hhem, агуй_, --, --, 
   {{0x4a580302,0x7c2401e0,0x320003f9,0x38bc03b2}},	//   _בדיו, _kgir, ƙiyi_, _líri_, 
   {{0x82f40b43,0x00000000,0x00000000,0x00000000}},	//   یروز_, --, --, --, 
   {{0x60ca1653,0x7c2401f7,0x00000000,0x00000000}},	//   dhem, _mgir, --, --, 
   {{0x69c00158,0x7ce80205,0x96b811eb,0x00000000}},	//   øleg, kıro, _руму_, --, 
   {{0x776400cf,0x7c260d75,0x00000000,0x00000000}},	//   luix, _ogir, --, --, 
   {{0x60c88a31,0x7ce8a75a,0x00000000,0x00000000}},	//   ghem, dıro, --, --, 
   {{0x4ea61654,0xa8040789,0x00000000,0x00000000}},	//   арна, muñé, --, --, 
   {{0x7c261655,0x45000135,0x752001fa,0x8eb01e87}},	//   _agir, _མཚོར_, _himz, تەتت, 
   {{0x2d9a1656,0x06940302,0x60ca1657,0x7520009f}},	//   íre_, בדים_, bhem, _kimz, 
   {{0x60ca1658,0xdcb00131,0x9fc40022,0x00000000}},	//   chem, كىپ_, рҳәа_, --, 
   {{0x2d9800c8,0x10140137,0x9f4801a8,0x7e68005b}},	//   ŭre_, _ئباد, _áað_, ämpö, 
   {{0x7ce8e945,0x7c261659,0x77640137,0x7ac4a3f8}},	//   lırl, _egir, duix, оссе, 
   {{0x7c240ffb,0x442c010a,0xbdf497d1,0xfd100451}},	//   _fgir, ycg_, _پروا_, _ڪجو_, 
   {{0x7ce83e67,0x4500025c,0xb3bc0154,0x67d4004e}},	//   nırl, _མཚེར_, _আইনজ, бобу, 
   {{0xdcf0003d,0x8af40213,0x77644a2e,0x49000137}},	// [3d210] _żgħi, şəqa, guix, йүүг, 
   {{0x6b8e165a,0xca180873,0x7c240356,0x61ec03e0}},	//   _isag, ﻴﻪﺕ_, _zgir, şali, 
   {{0x7ce871d5,0xc8bc012c,0x69c02f48,0x60c80108}},	//   kırl, _एकपट, øled, yhem, 
   {{0x776400f7,0x66080115,0x7c240327,0x6b8e165b}},	//   buix, _ŝeks, _xgir, _ksag, 
   {{0x7ce847af,0x60c800ca,0x7522165c,0x9878010f}},	//   dırl, vhem, _dimz, _גארט, 
   {{0x6b8c3948,0xa5f81e76,0xa6c400f7,0x7ce803e0}},	//   _msag, _бегу_, _اقسى, yıro, 
   {{0x60ca165d,0x846400a7,0x6b8c01a9,0x7ce80342}},	//   them, _възе, _lsag, fırl, 
   {{0x6b8e165e,0xe4e40014,0x7ce8008e,0x24180108}},	//   _osag, _آرَ, gırl, _бобы_, 
   {{0x60ca165f,0x68fc0263,0x6b8e1660,0x6564003e}},	//   rhem, _mksd, _nsag, luhh, 
   {{0x60ca1661,0x26c00925,0x64480072,0xddb400c6}},	//   shem, nkho_, _heei, محجب, 
   {{0x60c9de90,0x6b8e1662,0x7ce862c7,0x64481368}},	//   phem, _asag, bırl, _keei, 
   {{0x60c8d57e,0x64480363,0x23f8010f,0x00000000}},	//   qhem, _jeei, ָפֿמ, --, 
   {{0xfeb0eabc,0x64481368,0x7e7400d1,0x6564014f}},	//   _дөнь, _meei, _кәнт_, huhh, 
   {{0x6d5d2285,0x68fc2d8b,0x656459fc,0x644a1663}},	//   árac, _aksd, kuhh, _leei, 
   {{0x6b8e1664,0x7c241570,0x68fc020b,0x7ce8ae47}},	//   _esag, _tgir, _bksd, lırm, 
   {{0x7c2531f3,0xdc68522c,0x26c0009a,0x656430b5}},	//   _ugir, _саид_, ekho_, duhh, 
   {{0xc7a061ff,0x672c01f0,0x9b880cd6,0x07a00120}},	// [3d220] питк, gqaj, _صندل_, патн, 
   {{0x7ce841d5,0x75208967,0x45000135,0x7764004e}},	//   zırl, _simz, _མཚུར_, ruix, 
   {{0x644a1665,0x7ce8046c,0x9598839a,0x00000000}},	//   _beei, yırl, ытау_, --, 
   {{0xceb80b45,0x53c82519,0x4df8008f,0x69c00fac}},	//   _miƙa_, лгем_, אפעא, ølee, 
   {{0xa8041709,0x6448039a,0xceb80198,0x7ce80790}},	//   ruñé, _deei, _liƙa_, vırl, 
   {{0x95483bbf,0x7ce86f38,0xd549b99b,0x43800131}},	//   _مشرق_, dırm, _مجرم_, سلىق, 
   {{0xf4861666,0x7ce81ae6,0x6448062c,0x130801ec}},	//   _واری, tırl, _feei, _ұнай_, 
   {{0x64480730,0x73c401e0,0x660001bf,0x8554011a}},	//   _geei, _мәле, _ølka, _לשלב_, 
   {{0xef9435cd,0x7ce84674,0x28c8012d,0xd0441411}},	//   تیشد, rırl, रसति, _ۇپاي, 
   {{0x7ce870f7,0xd344006c,0x237800c5,0x91e400a7}},	//   sırl, _نیچه_, _äsja_, _лозе, 
   {{0x32180851,0x6b8e1667,0x6448062c,0x3ef4009d}},	//   _àry_, _ssag, _yeei, снээ_, 
   {{0xac1a1668,0x61e40419,0x00000000,0x00000000}},	//   иону_, úhle, --, --, 
   {{0xc4d00375,0x7ce80205,0x7f9000d4,0x00000000}},	//   פגש_, cırm, _наїх, --, 
   {{0x38bc012c,0xefd55097,0x00000000,0x00000000}},	//   _míru_, ይነይ_, --, --, 
   {{0x59b000cd,0x00000000,0x00000000,0x00000000}},	//   ीनगर, --, --, --, 
   {{0x6b8e1669,0x320c0122,0x2d9d0fb2,0xac5800c7}},	//   _tsag, _mzdy_, _irve_, _таиф_, 
   {{0xf771319d,0x6eac166d,0x6b8e166a,0x644a166b}},	// [3d230] فال_, जापु, _usag, _reei, 
   {{0xc624015b,0x64480c30,0x2d9c00bc,0xf1a8c976}},	//   যর্থ_, _seei, _krve_, कमान, 
   {{0x64489e85,0x672c0113,0x24f8010b,0x6566166c}},	//   _peei, sqaj, анжы_, uuhh, 
   {{0x26c2166d,0x2d9c01a6,0x7ce80c3c,0x6564003e}},	//   skho_, _mrve_, yırm, ruhh, 
   {{0x672c0869,0x320c010e,0x64481368,0x00000000}},	//   qqaj, _azdy_, _veei, --, 
   {{0xe298742c,0x04f8015b,0x7ce80793,0x644806fd}},	//   рак_, েদের_, vırm, _weei, 
   {{0xcf8c168d,0x644a166e,0x3abc011a,0x7abc010f}},	//   ێژه_, _teei, רמונ, רצוו, 
   {{0x7ce82c70,0x64c419b6,0xceb80b45,0x00000000}},	//   tırm, _بيرل, _riƙa_, --, 
   {{0x2d983c12,0x1ec870b2,0x2d9deb86,0x00000000}},	//   æren_, илии_, _arve_, --, 
   {{0x38bc01d3,0x00000000,0x00000000,0x00000000}},	//   _hírt_, --, --, --, 
   {{0x2d9c0e04,0xdb040034,0x7ce80205,0x00000000}},	//   _crve_, zykó, sırm, --, 
   {{0x60d800ca,0xc0a83dca,0x6e3c03e0,0xcdcc01e2}},	//   _umwm, _حائل_, ırba, خښه_, 
   {{0x2d9e166f,0x7ce805d1,0xff506ea9,0x0b4011f7}},	//   _erve_, lırk, _رخش_, мнян, 
   {{0x3f8c0067,0x61ec0356,0x6e940108,0x00000000}},	//   _isgu_, şalu, _ничу, --, 
   {{0x5d6805f5,0x7ce803ee,0xcd500014,0xdb040210}},	//   _тийм_, nırk, _ہى۪ک, wykó, 
   {{0xdb040034,0x00000000,0x00000000,0x00000000}},	//   tykó, --, --, --, 
   {{0xace801e2,0x00000000,0x00000000,0x00000000}},	// [3d240] _درول_, --, --, --, 
   {{0x7ce805d1,0xdb04012d,0x2b10000d,0x7b0001f4}},	//   kırk, rykó, _दीपु_, töuu, 
   {{0x7afc55fd,0x4aa402c3,0xc62403d4,0xdee80023}},	//   mort, खारव, যৰ্থ_, _መኻን_, 
   {{0x7afe1670,0xdce002f0,0x9424010b,0x85000014}},	//   lort, kulč, цмде, ووٕن, 
   {{0xc34409ac,0x6eac03ce,0x00000000,0x00000000}},	//   ояще_, जामु, --, --, 
   {{0x7afe1671,0x38bc58bb,0x6fd4012d,0x00000000}},	//   nort, _víru_, _बेगू, --, 
   {{0x705801d5,0x50640902,0x00000000,0x00000000}},	//   байр_, отпа, --, --, 
   {{0x7afe1672,0xd0440085,0x320c0313,0x453000d1}},	//   hort, ɛmɛl, _vzdy_, _زىكر, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7afe1673,0x73c400fb,0x00000000,0x00000000}},	//   jort, _мәһе, --, --, 
   {{0xa2b80303,0x7afe1674,0x5ec00154,0xfeb40137}},	//   ्सर्, dort, ষোভে, تايت_, 
   {{0x61ec0bcc,0x00000000,0x00000000,0x00000000}},	//   ğalt, --, --, --, 
   {{0x7afcbb99,0x61ec029f,0xa028007b,0x00000000}},	//   fort, şalt, _اسمك_, --, 
   {{0x7afe1675,0xb7e400fe,0x00000000,0x00000000}},	//   gort, _মৰ্ট, --, --, 
   {{0x2d9dfc88,0x1ee80133,0xbea00798,0x00000000}},	//   _urve_, _دووی_, _цајк, --, 
   {{0xde08009f,0x00000000,0x00000000,0x00000000}},	//   _اآهن_, --, --, --, 
   {{0x7afe1676,0x7ce80213,0xdb80010a,0x00000000}},	// [3d250] bort, zırk, _пӳри, --, 
   {{0x7afc0afa,0xd5ac0050,0x466000cf,0x59d4000d}},	//   cort, گہِ_, بۇسق, _डेकर, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7ce80790,0x2008025c,0xd3441046,0x00000000}},	//   tırk, _ġai_, سیمه_, --, 
   {{0x2008005f,0x00000000,0x00000000,0x00000000}},	//   _šai_, --, --, --, 
   {{0x257507f4,0x7afe1677,0x7ce80790,0x00000000}},	//   mål_, zort, rırk, --, 
   {{0x6d5ca56b,0x2d8c01f5,0x7ce80205,0x00000000}},	//   áran, ewde_, sırk, --, 
   {{0x04c400f1,0x7afc0009,0xae5800d4,0x81a46a87}},	//   _اوړي_, xort, орює_, _وحال, 
   {{0x7afe1678,0x00000000,0x00000000,0x00000000}},	//   vort, --, --, --, 
   {{0x7afe1679,0x7124185e,0xbfb4bf4e,0xc1080209}},	//   wort, _قىلم, _وحشت, _тэзе_, 
   {{0x7afe167a,0x2b480042,0x25740267,0x2d982dba}},	//   tort, _cwac_, hål_, årer_, 
   {{0x8f98008f,0x3898063f,0x9ec80014,0x2f180c9e}},	//   _ליני, _ọr_, _دِتم_, _дочь_, 
   {{0x3ea6167b,0xc1d40055,0xa9c40066,0x1ea800ec}},	//   _innt_, _pāṇy_, وزفو, _پاڇي_, 
   {{0x69c002bf,0x7afe167c,0x23bc00dc,0x1fb40154}},	//   ølea, sort, ्नाद, _জেএস, 
   {{0x81dc00eb,0x00000000,0x00000000,0x00000000}},	// [3d260] _ধুম_, --, --, --, 
   {{0x7afe167d,0x5a64004e,0x86b001ec,0x00000000}},	//   qort, _экоб, нәсі, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x27ec04b9,0x43c000d1,0xd46800f3,0x00000000}},	//   _žene_, ﯩﻠﯩﺪ, сиде_, --, 
   {{0x8898011a,0xc7a0014b,0x00000000,0x00000000}},	//   _הבכי, _зияк, --, --, 
   {{0xceb80198,0x8b5408a8,0x257412e8,0x26040073}},	//   _riƙo_, לינס_, bål_, _वरची_, 
   {{0xc5b405f5,0x81dc00cc,0x00000000,0x00000000}},	//   _ертө, _ধুব_, --, --, 
   {{0x15441d56,0x3ea5d038,0xf4848a54,0xe3ac05d9}},	//   _меҳм, _annt_, _تاسی, _چڱو_, 
   {{0x4fc4166f,0x53c800db,0x00000000,0x00000000}},	//   яска, _угам_, --, --, 
   {{0x3f10516c,0x3ea401ab,0x4338010f,0x00000000}},	//   ндыс, _cnnt_, _לעמב, --, 
   {{0x2d8c24d1,0x776401a9,0x638002d2,0xd0242bb7}},	//   uwde_, hrix, _tánö, _емей, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfbe00154,0x63ac01e4,0xc4d0011a,0x765c4d8c}},	//   _যুবত, ĥang, תגר_, _odry, 
   {{0x765c067d,0x753c006d,0x80a001ec,0x7764035a}},	//   _ndry, _otrz, _يمەن, drix, 
   {{0x183800b4,0xac940026,0x7e7805d0,0x00000000}},	//   _ọmụm, _жайш, _האוז, --, 
   {{0xddea167e,0x6d58100c,0x77653f85,0x25747944}},	//   _برهه_, _ivva, frix, vål_, 
   {{0x6d5c025a,0x2ca8679e,0xaa5c0150,0x00000000}},	// [3d270] âraf, _inad_, _кепi, --, 
   {{0x383401c0,0xe5e40101,0xf74800ae,0x00000000}},	//   _үнэр, وزای, سلمي_, --, 
   {{0xa4d8177b,0x765c03cb,0xb8840118,0x00000000}},	//   оджу_, _ddry, _smíř, --, 
   {{0x765c0cfd,0x00000000,0x00000000,0x00000000}},	//   _edry, --, --, --, 
   {{0x68ee167f,0x20d00332,0x29080076,0x2574005c}},	//   mnad, _háig_, mlaa_, sål_, 
   {{0x29088a96,0x26c4025a,0x68ee1680,0x00000000}},	//   llaa_, _ôlo_, lnad, --, 
   {{0x68eca896,0x6d5e1681,0x2908c7e9,0xd24c0a11}},	//   onad, áral, olaa_, جنى_, 
   {{0x68ee1682,0xdce00aed,0x69d40268,0x3ea4003a}},	//   nnad, kulā, izze, _snnt_, 
   {{0x6d5a1683,0x68ee1684,0x63ac03d4,0x290a0f57}},	//   _avva, inad, åand, ilaa_, 
   {{0x2caa1685,0x68ee1686,0x45280135,0x4f04760c}},	//   _anad_, hnad, _སྤོར_, мнын_, 
   {{0x68ee1687,0x62800472,0xb8e0025c,0x29086db8}},	//   knad, _iblo, _ཁྭ_, klaa_, 
   {{0x656000cc,0x68ec010f,0x776401d5,0xdb0400e5}},	//   _ålhu, jnad, yrix, nykö, 
   {{0x6d5a1688,0x3ea401fa,0xdce0005f,0x29080014}},	//   _evva, _tnnt_, gulā, dlaa_, 
   {{0x32000365,0x2908198f,0x2ca8011f,0x5f04036b}},	//   şiye_, elaa_, _enad_, _юзла, 
   {{0x62821689,0x9cf60b39,0xf9c44c9a,0x7ce80205}},	//   _mblo, _очиш, رحسی, dırv, 
   {{0x7766168a,0xd7f80184,0x2ca80051,0x290a168b}},	//   trix, ҡуҡ_, _gnad_, glaa_, 
   {{0x62801151,0x753c84c9,0x69d42b1d,0x8c140137}},	// [3d280] _oblo, _strz, azze, _ۉيۉر_, 
   {{0x68ee168c,0x2909651c,0x7766168d,0x2ca80210}},	//   anad, alaa_, rrix, _znad_, 
   {{0x673c03ac,0x29089d12,0x2ca80042,0x77640009}},	//   _etsj, blaa_, _ynad_, srix, 
   {{0x29080014,0x7d04025c,0xcdb40375,0xdb0401d3}},	//   claa_, _jkis, ופעה_, gykö, 
   {{0x62800327,0x7d05033d,0xc32c0014,0x00000000}},	//   _bblo, _mkis, لٕن_, --, 
   {{0xd13a168e,0x628001ab,0x69c2168f,0x765c00b5}},	//   охи_, _cblo, äleg, _udry, 
   {{0x7d061690,0x753c0034,0x62807baa,0x00000000}},	//   _okis, _utrz, _dblo, --, 
   {{0x6d5e1691,0x62821692,0x7d041aac,0x673c000f}},	//   áram, _eblo, _nkis, _ytsj, 
   {{0x62800175,0x00000000,0x00000000,0x00000000}},	//   _fblo, --, --, --, 
   {{0x7d061693,0x2ca80316,0x628000a3,0x6e94035b}},	//   _akis, _snad_, _gblo, хиоу, 
   {{0x68ee1694,0xad841e4a,0x29080548,0x50b400ee}},	//   ynad, رادۇ, ylaa_, _осду, 
   {{0xdce21695,0x5fd801ad,0x3cf400d0,0x20d001e7}},	//   tulā, _बेकल, _ľavé_, _ráig_, 
   {{0x68edee4c,0xfeb4034c,0x5fa02309,0x00000000}},	//   vnad, سایت_, _مەيم, --, 
   {{0x8d741dc8,0x7d040c8a,0x69d40112,0x29080009}},	//   _قاعا, _ekis, tzze, wlaa_, 
   {{0x6d583209,0x7d040270,0x68ee1696,0x2ca806a3}},	//   _uvva, _fkis, tnad, _tnad_, 
   {{0x68ec1570,0xdce04424,0x2908022f,0x69d40e78}},	//   unad, pulā, ulaa_, rzze, 
   {{0x29080194,0xc04c0092,0xd6c401d5,0x2018022e}},	// [3d290] rlaa_, _ማጠቃለ, کملی, оsiy_, 
   {{0x68ee1697,0x45280135,0x8cc40d2c,0x29081dd0}},	//   snad, _སྤུར_, ासको, slaa_, 
   {{0x68ee1698,0x7d0402d0,0x29080108,0x00000000}},	//   pnad, _ykis, plaa_, --, 
   {{0x62813ae9,0x7d0405b1,0xdce0054e,0x29080067}},	//   _sblo, _xkis, mulă, qlaa_, 
   {{0x673e1699,0x6d5e169a,0xe2849bcd,0x00000000}},	//   _utsj, áraj, елли, --, 
   {{0xdb040f12,0x7ce80205,0x00000000,0x00000000}},	//   sykö, lırt, --, --, 
   {{0xb604004e,0x00000000,0x00000000,0x00000000}},	//   _аятк, --, --, --, 
   {{0x1fb4f7f2,0x7ce80205,0x00000000,0x00000000}},	//   есор, nırt, --, --, 
   {{0x7d040589,0x00000000,0x00000000,0x00000000}},	//   _rkis, --, --, --, 
   {{0xee380372,0x7d041061,0x00000000,0x00000000}},	//   үнө_, _skis, --, --, 
   {{0x1d080697,0x69c032b8,0x5f744c8b,0x7ce81bc5}},	//   зени_, ølel, ذاکر, kırt, 
   {{0x8d740f78,0x55d800c8,0xd00c01b9,0x425001d3}},	//   راپا, פֿינ, ؤلی_, _سنچر, 
   {{0x60c801f7,0xd0240150,0x7ce81ea0,0x00000000}},	//   mkem, _كومۋ, dırt, --, 
   {{0x60ca169b,0x3f9c0099,0x00000000,0x00000000}},	//   lkem, mvuu_, --, --, 
   {{0x38c85a76,0x2d96169c,0x7d059e14,0xad240451}},	//   واری_, _арыс, _tkis, _ڌريو, 
   {{0x60ca169d,0x7d06169e,0x39580120,0x7ce80790}},	//   nkem, _ukis, rsrs_, gırt, 
   {{0x3958045a,0x60c969f6,0x00000000,0x00000000}},	// [3d2a0] ssrs_, ikem, --, --, 
   {{0x60ca169f,0x48006acd,0x00000000,0x00000000}},	//   hkem, упув, --, --, 
   {{0xdce0054e,0x00000000,0x00000000,0x00000000}},	//   culă, --, --, --, 
   {{0x20d000ae,0x7ce8453a,0x69c001f4,0x00000000}},	//   _láib_, cırt, älee, --, 
   {{0x03a057ab,0x7ce88eb9,0xf1d81d15,0x33940006}},	//   лицо, lırs, _भेजन, талё, 
   {{0x6d5e16a0,0x60ca16a1,0xdb040022,0x439000fb}},	//   árak, ekem, pykõ, уашс, 
   {{0x7ce80259,0x00000000,0x00000000,0x00000000}},	//   nırs, --, --, --, 
   {{0xfbd027c6,0xefc00240,0x00000000,0x00000000}},	//   हनाम, _ድልው_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7ce803e0,0x614400d1,0x00000000,0x00000000}},	//   kırs, رىۋە, --, --, 
   {{0x8ff897d1,0x50a00131,0x626585d1,0x7e640210}},	//   _کرار_, _مەغل, _جاقق, ójpa, 
   {{0xdcb008c9,0x629c0134,0x7ce87a0e,0x69c00fac}},	//   لىپ_, _ɔsom, dırs, ølem, 
   {{0xddc001e4,0x7ce80205,0x00000000,0x00000000}},	//   malŝ, vırt, --, --, 
   {{0x51700023,0x7f38010f,0x00000000,0x00000000}},	//   _ሸሞንተ_, _צעוו, --, --, 
   {{0xfd100451,0x8d84001b,0xf99000e5,0x00000000}},	//   _ڏجي_, _чулд, یبہ_, --, 
   {{0xddc001e4,0xdce00356,0x270807b7,0x00000000}},	//   nalŝ, rulă, वत्र_, --, 
   {{0x7c8409fe,0xdc5400f1,0x93c00356,0xdb0c00d7}},	// [3d2b0] _суще, _شريک, _ţănd, žkár, 
   {{0x7ce80e2d,0xdce00356,0x00000000,0x00000000}},	//   bırs, pulă, --, --, 
   {{0x65d4007b,0x7ce80205,0x00000000,0x00000000}},	//   خياط, pırt, --, --, 
   {{0xdb0400e4,0x00000000,0x00000000,0x00000000}},	//   sykô, --, --, --, 
   {{0xe298ae8f,0x60c809a8,0x00000000,0x00000000}},	//   дал_, vkem, --, --, 
   {{0x6f18013f,0xc32c0050,0xe688007b,0xf0300092}},	//   _nhvc, لٕچ_, _تنسى_, _በታማኝ, 
   {{0x60c816ca,0x20d00332,0x00000000,0x00000000}},	//   tkem, _ráib_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x60ca16a2,0x7dc8014a,0x3f80267c,0x2f5401c6}},	//   rkem, kösö, уғла, лтэс, 
   {{0x7ce83bc1,0x2ff801d3,0xd020064e,0x00000000}},	//   yırs, رڈنگ_, шмый, --, 
   {{0xdc68d176,0xd1b07611,0xc1000116,0x60c8000f}},	//   манд_, _نیوک, _йүкл, pkem, 
   {{0x4c800212,0x249c03cb,0x00000000,0x00000000}},	//   алюв, ndwm_, --, --, 
   {{0x5fd800ab,0x00000000,0x00000000,0x00000000}},	//   _बेचल, --, --, --, 
   {{0x29180083,0xef1802bf,0x7ce867ab,0xdea00133}},	//   _ahsa_, _змі_, tırs, _ئیدی, 
   {{0x7f58003a,0xc0380092,0x00000000,0x00000000}},	//   lsuq, _ተሳትፈ, --, --, 
   {{0x26d084b9,0xceb80198,0x7ce83535,0x2918022e}},	//   _alzo_, _riƙi_, rırs, _chsa_, 
   {{0x7f58003a,0xd704014b,0xa2b800cd,0x7ce80205}},	// [3d2c0] nsuq, взаи, ्सञ्, sırs, 
   {{0x19c40022,0x86401214,0x7ce803b9,0x00000000}},	//   _абом, инуж, pırs, --, 
   {{0xd94416a8,0x00000000,0x00000000,0x00000000}},	//   _шени, --, --, --, 
   {{0x6d5c0491,0x09f406a9,0x9388764a,0x487001ec}},	//   árai, _ימים_, дска_, _ەگەس, 
   {{0x8c400790,0x00000000,0x00000000,0x00000000}},	//   _öğel, --, --, --, 
   {{0x52bc0764,0x958400f7,0x6d5c1039,0x78f4014b}},	//   ्सेस, _илге, šrai, _рӯҳу, 
   {{0x41700d1f,0xddc000df,0x63ac0115,0x4e0412eb}},	//   لايس, talŝ, ĥana, _सँधै_, 
   {{0x2c0400dc,0xc9500375,0xb05400d1,0x80a015bf}},	//   रथमं_, במה_, اھات, لمىن, 
   {{0xddc00115,0xd39401af,0x00000000,0x00000000}},	//   ralŝ, _шәжә_, --, --, 
   {{0x4ea616a3,0x32d00241,0x317c00d8,0x69c00fac}},	//   триа, _fàya_, ptvz_, ølek, 
   {{0xe16426c0,0x6c541064,0x7f580014,0x00000000}},	//   _مدني, лкну, asuq, --, 
   {{0x2a60070d,0x13c400bd,0x23680552,0xcf2405d9}},	//   _sdhb_, _শেয়, šaje_, _ڌرتي, 
   {{0xa2b80073,0x810800f1,0x00000000,0x00000000}},	//   ्सच्, _غرمې_, --, --, 
   {{0x27ee16a4,0xc0580023,0xc98400f3,0x00000000}},	//   _ženo_, _ፍትሓው, куби, --, 
   {{0xb9c401b9,0xe79003e0,0xdf140153,0x00000000}},	//   аёти, _böğü, _сьць, --, 
   {{0x7ce80139,0x00000000,0x00000000,0x00000000}},	//   bırq, --, --, --, 
   {{0x64a44d50,0xe7900205,0xa81616a5,0xebc401ec}},	// [3d2d0] ғала, _döğü, удаш, _сәнн, 
   {{0xd76407d6,0x2d980327,0x00000000,0x00000000}},	//   انلی, ħref_, --, --, 
   {{0x7f6401ec,0xa2c40022,0x00000000,0x00000000}},	//   _ﺑﯘل_, қәак, --, --, 
   {{0xe79003ee,0x332c0334,0xe454010b,0x67d401f0}},	//   _göğü, _aidx_, укды, _бому, 
   {{0x43b0052f,0xfd5001f2,0x638533d7,0xb46402dd}},	//   шҡар, _begị, угла, ркіл, 
   {{0x04f00154,0x24500051,0x00000000,0x00000000}},	//   জতের_, ạm_, --, --, 
   {{0x332c0175,0x69c00fac,0xc1e00118,0x00000000}},	//   _didx_, øleh, _केशब_, --, 
   {{0x320c03cb,0xa2b800cd,0x00000000,0x00000000}},	//   _dydy_, ्सङ्, --, --, 
   {{0x645a16a6,0x443e16a7,0x4ff40882,0x7f58003a}},	//   mawi, _ifu_, kṣuṣ, usuq, 
   {{0x645a16a8,0x1e947696,0x45780220,0x7f580393}},	//   lawi, урир, _ءﯨﺮﻯ_, rsuq, 
   {{0x5de40c98,0x443c03cd,0x7f58735c,0xf194010a}},	//   ужна, _kfu_, ssuq, _вихь, 
   {{0x645a16a9,0x00000000,0x00000000,0x00000000}},	//   nawi, --, --, --, 
   {{0x443c770e,0xdcb00116,0x00000000,0x00000000}},	//   _mfu_, لىھ_, --, --, 
   {{0x645a16aa,0xe79062c7,0x1c1802ab,0x1a6410e8}},	//   hawi, _söğü, नेगल_, دیدی_, 
   {{0x645a16ab,0x443e16ac,0x2d981088,0x993404fb}},	//   kawi, _ofu_, æret_, افرت, 
   {{0x645a16ad,0x443cce07,0x5bc4007b,0x69b40118}},	//   jawi, _nfu_, _مقبل, _उपरी, 
   {{0xab940354,0x6d5c0022,0x00000000,0x00000000}},	// [3d2e0] _кăтк, árav, --, --, 
   {{0x443c20d6,0xd9b800c7,0x0bb400d9,0x46e400db}},	//   _afu_, _зымч_, _עלים_, гдун_, 
   {{0x4a7800c8,0x443c0fac,0x85b000d1,0xca7c022e}},	//   _אריב, _bfu_, бәтч, _yuqо, 
   {{0x645a16ae,0x443e16af,0x3804014b,0x00000000}},	//   gawi, _cfu_, _вомҳ, --, 
   {{0x6e6c0092,0x00000000,0x00000000,0x00000000}},	//   _ተጠብቆ_, --, --, --, 
   {{0x443c00b4,0x81dc00fe,0x00000000,0x00000000}},	//   _efu_, _ধুই_, --, --, 
   {{0x5184ab76,0x91840597,0x443e16b0,0x35c4020a}},	//   уула, اجتم, _ffu_, _тавҳ, 
   {{0x443c0998,0xc9500375,0x69c003cd,0xefc800fb}},	//   _gfu_, זמה_, ølei, кһел_, 
   {{0x527400cf,0xd3440271,0xb4d0a786,0xa9840023}},	//   _مااز, _صیغه_, षसी_, _ምፍታኑ_, 
   {{0x443c0099,0xe3c01b0d,0x320c0042,0x00000000}},	//   _zfu_, çış_, _tydy_, --, 
   {{0x443c000d,0xd0840108,0x7bc001f4,0x00000000}},	//   _yfu_, _были, ämun, --, 
   {{0x7f8008cf,0xfe6c00f1,0x00000000,0x00000000}},	//   جلین, يدۍ_, --, --, 
   {{0x92d4009e,0x20d00174,0x7c3401ef,0x00000000}},	//   াচী_, _káin_, _šerá, --, 
   {{0x64580034,0x2d982142,0xbdf400e5,0x00000000}},	//   zawi, æres_, ئریا_, --, 
   {{0x48a9bd20,0x1ea8774e,0x6458094a,0x3da00024}},	//   нтам_, _جاني_, yawi, _грыб, 
   {{0x6d48180f,0x20d00332,0x6458002e,0x00000000}},	//   mpda, _láin_, xawi, --, 
   {{0x466a16b1,0x6458004c,0x6d4a16b2,0xab94d5d9}},	// [3d2f0] ерем_, vawi, lpda, _типі, 
   {{0x645a16b3,0x6b8e16b4,0x888004fb,0x6d480d27}},	//   wawi, _ipag, _گیرن, opda, 
   {{0x645a16b5,0x443c33b8,0x85440262,0x00000000}},	//   tawi, _pfu_, уэзе, --, 
   {{0x6b8c02e3,0xc50a16b6,0xc8b03fe6,0xf77001d9}},	//   _kpag, رتال_, _الحک, تاہ_, 
   {{0x645a16b7,0x443c007c,0x63ac0115,0xb384007b}},	//   rawi, _vfu_, ĥano, مجوه, 
   {{0x645a16b8,0x2169375b,0x6b8c00b4,0x20d0007b}},	//   sawi, вики_, _mpag, _cáin_, 
   {{0x645a16b9,0x97000131,0x443e16ba,0x20d216bb}},	//   pawi, _بېلى, _tfu_, _dáin_, 
   {{0x6b8e16bc,0x443e16bd,0x64582e95,0x32d001e1}},	//   _opag, _ufu_, qawi, _fàyo_, 
   {{0x20d001e7,0x6b8c002f,0x6d4802d0,0x0ea40037}},	//   _fáin_, _npag, epda, _कोहड, 
   {{0x63aa16be,0xde0401a9,0x38bc0118,0x9b4400f2}},	//   _iren, иппи, _díry_, ینجو, 
   {{0x63a879d7,0xa0c516e4,0x00000000,0x00000000}},	//   _hren, _پيشو, --, --, 
   {{0x6b8c0175,0x7bc00108,0x254000c0,0x5574010f}},	//   _bpag, ämuo, _gėle_, סערן_, 
   {{0x2d987eb1,0x63a91aca,0x69c216bf,0xbbd0473c}},	//   ærer_, _jren, älen, हनेक, 
   {{0x63aa16c0,0x6b8c0113,0xf9c401c6,0x6fb400bc}},	//   _mren, _dpag, багү, ेहरू, 
   {{0xed5001d9,0x985400d8,0x6d5e16c1,0x00000000}},	//   _ٹھپ_, иташ, árat, --, 
   {{0x6b8c030d,0x1d08010b,0x5ba94c5b,0x28a800cd}},	//   _fpag, _шейи_, _аким_, _चोदि, 
   {{0x63a80066,0x93780150,0x07a0022e,0x00000000}},	// [3d300] _nren, _ﹼﻔﺎﻗ_, оатн, --, 
   {{0x9974004e,0x00000000,0x00000000,0x00000000}},	//   _кумш, --, --, --, 
   {{0x63aa16c2,0x569401e0,0x94441870,0xf98800ec}},	//   _aren, лаҡт, لپان, _ڌنڌي_, 
   {{0x63aa16c3,0x98a40ce8,0x534616c4,0x18a40d34}},	//   _bren, _тиме, ахка, _тамм, 
   {{0x07a00209,0xcc38008f,0x69c01445,0x68e001c7}},	//   _даян, דענט, ølev, ëlde, 
   {{0xda180037,0x00000000,0x00000000,0x00000000}},	//   _धरात_, --, --, --, 
   {{0x63aa16c5,0xd5b0c69a,0x38bc02f0,0x24940014}},	//   _eren, _ظفر_, _síry_, _گۆند_, 
   {{0x23680989,0x63aa16c6,0x05600882,0xdce0002d}},	//   šaja_, _fren, ṃjñā, pulę, 
   {{0xac98167e,0x2ec400f7,0x20d00332,0x940801af}},	//   ۇندا_, йөкм, _táin_, _реаб_, 
   {{0x6b8c022e,0x20d00332,0x91e4026b,0x0dc80107}},	//   _rpag, _háil_, _козе, вуми_, 
   {{0x6b8e16c7,0x63a80640,0xac9805d9,0x87140375}},	//   _spag, _zren, هندا_, שקיע_, 
   {{0x4fea16c8,0x0ea40490,0x63a8667b,0x81dc0154}},	//   _имен_, _कोरड, _yren, _ধুক_, 
   {{0x20d001e7,0xebc4134b,0x00000000,0x00000000}},	//   _máil_, сәйн, --, --, 
   {{0x6d495802,0x6d5e16c9,0x00000000,0x00000000}},	//   ppda, áras, --, --, 
   {{0x0dc80cfc,0x39a40b3e,0x00000000,0x00000000}},	//   _јули_, оштв, --, --, 
   {{0xfce4147e,0x6b8c0113,0x6f0809a8,0x00000000}},	//   _мојо, _tpag, lodc, --, 
   {{0x61353d32,0x99840131,0x6b8c00dc,0x7b0803b2}},	// [3d310] _išle, _қәрз_, _upag, úrtø, 
   {{0x63a802d3,0x85a40640,0x6f080477,0x25f40db3}},	//   _rren, ијед, nodc, ्थली_, 
   {{0xe3c40372,0x63a804fb,0x2d9c00e4,0xe8940eba}},	//   өрдү, _sren, _jsve_, _лань, 
   {{0x65943461,0x20d000c6,0xf990006c,0x846402e8}},	//   _қабу, _cáil_, _کبی_, ръже, 
   {{0x68ee16ca,0x20d216cb,0x63aa16cc,0x2908005b}},	//   miad, _dáil_, _qren, moaa_, 
   {{0x68ee16cd,0x0574350a,0x63a84312,0x29087844}},	//   liad, _پاسد, _vren, loaa_, 
   {{0x20d00491,0xf99400c8,0x71582758,0x63a80f85}},	//   _fáil_, ַרץ_, арыс_, _wren, 
   {{0x68ee16ce,0x29097ffe,0x59b800dc,0x5dd801d5}},	//   niad, noaa_, _उपसर, ғфор_, 
   {{0xd3442c04,0x00000000,0x00000000,0x00000000}},	//   _هینه_, --, --, --, 
   {{0x68edda56,0x201000e2,0x29095953,0x1eb421f3}},	//   hiad, āzi_, hoaa_, ссиё, 
   {{0xdca410f6,0x68ee16cf,0x29095953,0xfbe00118}},	//   бани, kiad, koaa_, _पेजम, 
   {{0x3074010b,0x68ee01f5,0xdb0c00bc,0x2908005b}},	//   _душс, jiad, ějíc, joaa_, 
   {{0x68ec0f7b,0x8f6801ed,0x6d5e16d0,0xd0f40f4a}},	//   diad, _ملنے_, árar, ुकरण_, 
   {{0x644800ac,0x6e944965,0x14180677,0x00000000}},	//   əmiş, _мичу, טורב, --, 
   {{0x68ec0cfd,0x80d847d0,0x29080093,0xfa8002d3}},	//   fiad, _बताइ, foaa_, _ይዝከር_, 
   {{0x68ee16d1,0xb9140882,0x7bc00158,0xeb900220}},	//   giad, nnaḥ_, ømus, _ﺑﻴﯩﻞ_, 
   {{0xbd4005d9,0x1ae4010b,0x59b8041c,0x59d400bc}},	// [3d320] _انڊي, _гопм, _उपवर, ठनहर, 
   {{0x20d00332,0x00000000,0x00000000,0x00000000}},	//   _sáil_, --, --, --, 
   {{0x941003be,0x68ee16d2,0x2908016b,0x20d00332}},	//   ədən_, biad, boaa_, _páil_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd9fc000d,0x00000000,0x00000000,0x00000000}},	//   _उखडत_, --, --, --, 
   {{0xd5d4b78a,0x78a616d3,0x96ba16d4,0x0ea41098}},	//   _любы, ldiv, _суму_, _कोंड, 
   {{0x6f0911a6,0x78a61409,0x20d00332,0x6d4400ef}},	//   vodc, odiv, _táil_, _čiao, 
   {{0x78a616d5,0x27ec098d,0x00000000,0x00000000}},	//   ndiv, _ženi_, --, --, 
   {{0xf2c40bd6,0x6f080477,0x78a4000d,0x4ea40958}},	//   _мөки, todc, idiv, брна, 
   {{0x68ec03bd,0xcd50001f,0x079808a8,0x00000000}},	//   ziad, _የተከፈ, נסיל, --, 
   {{0xc04c4dba,0xb80009bd,0x78a40165,0x15f821bd}},	//   _ні_, ্ধিত_, kdiv, ्थिर_, 
   {{0x68ec172e,0xcfaa16d6,0x78a4047e,0x6ad00882}},	//   xiad, _ماتم_, jdiv, हस्र, 
   {{0x68ec1a36,0x78a616d7,0x101616d8,0x80a19b65}},	//   viad, ddiv, _اباد, _رمون, 
   {{0x68ee16d9,0x78a4003a,0xace80022,0x00000000}},	//   wiad, ediv, умҭа_, --, 
   {{0x290a16da,0x68ec0cfd,0x78a401e4,0x00000000}},	//   toaa_, tiad, fdiv, --, 
   {{0x78a4bde6,0x67d400cf,0xc7b85aae,0x61340118}},	//   gdiv, ообу, лёз_, _ušle, 
   {{0x68ee16db,0xf7705821,0xca7c01d5,0xa7b82cc8}},	// [3d330] riad, ّام_, _fuqа, шлау_, 
   {{0x68ec733d,0x2b4a16dc,0x69c05545,0x98bc0aed}},	//   siad, _itac_, øles, ītā_, 
   {{0x78a616dd,0x67240450,0xd1240014,0x98a00153}},	//   bdiv, rmhj, _ٲم_, _likę_, 
   {{0xd1240103,0x00000000,0x00000000,0x00000000}},	//   _زم_, --, --, --, 
   {{0x987800c8,0x91b402ab,0x68fc6d6d,0x54180131}},	//   _דארט, _अपॉइ, _ijsd, ۇرۇڭ_, 
   {{0x2368151c,0x16700075,0xdec80023,0x00000000}},	//   šajo_, _оқур, ኽበን_, --, 
   {{0xa4d400d6,0xe12435a2,0x00000000,0x00000000}},	//   _дові, омки, --, --, 
   {{0x2b480bb8,0x20d000c6,0xdce0005f,0x7bc0005b}},	//   _otac_, _táim_, rtlī, ämuk, 
   {{0x2b48009f,0x00000000,0x00000000,0x00000000}},	//   _ntac_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2b4a16de,0x78a616df,0xb0640050,0x6d5c00c7}},	//   _atac_, ydiv, _کھى۪, árap, 
   {{0x1d086bed,0x9f3402dd,0xe0600133,0x78a40076}},	//   реми_, _деді, _کێکی, xdiv, 
   {{0x78a40122,0x2b48004e,0xf8b8004d,0x70380214}},	//   vdiv, _ctac_, _đĩ_, _اسمس_, 
   {{0x201e16e0,0x78a40175,0xaf0400d4,0x00000000}},	//   _izwi_, wdiv, _епіл, --, 
   {{0x78a616e1,0x2b4800dc,0xad2490b2,0x00000000}},	//   tdiv, _etac_, تریو, --, 
   {{0x78a40393,0x00000000,0x00000000,0x00000000}},	//   udiv, --, --, --, 
   {{0x3990145e,0x629c013b,0x69c008cb,0x68e0017a}},	// [3d340] _bösö_, _ɔsor, øler, ëlda, 
   {{0x78a4501a,0x248c011f,0x3200029f,0x254000c0}},	//   sdiv, _abem_, şiyi_, _sėla_, 
   {{0x75200175,0x1bec000d,0x7ce806be,0x00000000}},	//   _phmz, _चेतल_, dırz, --, 
   {{0x201c02ea,0x26c001e4,0xd874552d,0x00000000}},	//   _ozwi_, ajho_, _بادب, --, 
   {{0x386216e2,0x799c0083,0x6d440064,0x00000000}},	//   mair_, lwrw, _čiam, --, 
   {{0x60d8015d,0x8c180375,0x62a00248,0xa5640137}},	//   _alwm, בוני, _ìwò, زدۅن, 
   {{0x201e16e3,0x814000aa,0x60d80142,0x765c02d0}},	//   _azwi_, ونون, _blwm, _iery, 
   {{0x386216e4,0x765c9d36,0xcf8801f0,0x00000000}},	//   nair_, _hery, асод_, --, 
   {{0x765c030a,0x77640077,0x386001ab,0x1ea800f1}},	//   _kery, nsix, iair_, څاپي_, 
   {{0x3861d75f,0x27ec09a5,0x201c02c4,0x69c00724}},	//   hair_, _ýene_, _dzwi_, älek, 
   {{0x201e16e5,0x25a401ed,0xe2b40105,0x0694011a}},	//   _ezwi_, _állt_, _эстэ, חדים_, 
   {{0x2b4a16e6,0x753e16e7,0x00000000,0x00000000}},	//   _ptac_, _murz, --, --, 
   {{0x386216e8,0x613402d5,0x753c01c6,0x765c0042}},	//   dair_, _išla, _lurz, _oery, 
   {{0x765e16e9,0x32d00de2,0xbf1002dd,0x00000000}},	//   _nery, _bàyi_, _قونب, --, 
   {{0x386216ea,0x753c0166,0xac5910a0,0x63ac010f}},	//   fair_, _nurz, _лайф_, ĥani, 
   {{0x765e16eb,0x386216ec,0x6d58014f,0x63ac00d0}},	//   _aery, gair_, _iwva, ťani, 
   {{0x26c216ed,0x399001f4,0x00000000,0x00000000}},	// [3d350] tjho_, _pösö_, --, --, 
   {{0x765c03cb,0x684001e7,0x00000000,0x00000000}},	//   _cery, _bádó, --, --, 
   {{0x765e16ee,0xc56929f5,0x753e0565,0x386216ef}},	//   _dery, شحال_, _curz, bair_, 
   {{0x386216f0,0x753c641a,0x765c02d0,0x00000000}},	//   cair_, _durz, _eery, --, 
   {{0x6aa402b4,0x765e16f1,0xd8b80375,0xe12400d1}},	//   _kahf, _fery, _הצרכ, үмли, 
   {{0x765e16f2,0xe2986418,0x753e16f3,0x6d5802d0}},	//   _gery, сак_, _furz, _owva, 
   {{0xd24c3009,0x753c23db,0x6aa5af2a,0x248c0798}},	//   دنى_, _gurz, _mahf, _tbem_, 
   {{0x673e16f4,0x765c00a2,0x00000000,0x00000000}},	//   _kusj, _zery, --, --, 
   {{0x753e16f5,0x673c0477,0x6d5802d0,0x765c05d1}},	//   _zurz, _jusj, _awva, _yery, 
   {{0x386216f6,0x765c0014,0x6aa4031c,0x4f203004}},	//   zair_, _xery, _nahf, ндыб, 
   {{0x628216f7,0x386000dc,0x6734031c,0x20d001e1}},	//   _iclo, yair_, _mizj, _láii_, 
   {{0x38600221,0x69b406ff,0xdca401a9,0x201806ea}},	//   xair_, _उपजी, чами, ýsis_, 
   {{0x386216f8,0x77640227,0x201c0230,0x65640270}},	//   vair_, xsix, _uzwi_, hshh, 
   {{0x6734d7fe,0x8fa0d99b,0x3861eb6b,0xdce00139}},	//   _nizj, _чаше, wair_, bulğ, 
   {{0x386216f9,0x69c00fac,0x2bdc00bc,0x00000000}},	//   tair_, ølep, नैबा, --, 
   {{0x765e16fa,0x673c0d27,0x386000a3,0x673400ef}},	//   _sery, _busj, uair_, _aizj, 
   {{0x386216fb,0x765e16fc,0x96950275,0xad25f8bd}},	// [3d360] rair_, _pery, зреш, _تروو, 
   {{0x386216fd,0x753e16fe,0x673c119a,0x644c0428}},	//   sair_, _purz, _dusj, ñain, 
   {{0x80d822e3,0x765e16ff,0x38621700,0x00000000}},	//   बसाइ, _very, pair_, --, 
   {{0x765e1701,0x62821702,0x673deaec,0x753c05c7}},	//   _wery, _aclo, _fusj, _vurz, 
   {{0x765e1703,0xaae4034c,0x753c03fa,0x673c16a3}},	//   _tery, _رسیو, _wurz, _gusj, 
   {{0x753e1704,0x628001ab,0x765c035a,0x25400064}},	//   _turz, _cclo, _uery, _gėlo_, 
   {{0x673e1705,0x29040008,0x661400a2,0x925800db}},	//   _zusj, élag_, _gyzk, _ۇشار_, 
   {{0x69c00108,0x00000000,0x00000000,0x00000000}},	//   älei, --, --, --, 
   {{0x21640228,0xe3b001d9,0x00000000,0x00000000}},	//   птөг, _لرٕ_, --, --, 
   {{0x612401a8,0x6280007b,0x257000f7,0x00000000}},	//   jólf, _gclo, _سۇۇس, --, 
   {{0x2018041e,0x7afc0175,0xd1740961,0x00000000}},	//   ýsir_, dnrt, _хызы, --, 
   {{0x434002d3,0x6aa4022e,0xac1884dc,0xc15400df}},	//   _ንሰብኣ, _sahf, жому_, _זשאו_, 
   {{0x6b9c0196,0x613402f0,0xeec40150,0x6280035a}},	//   uwsg, _ušla, _يحتۋ, _yclo, 
   {{0x61240008,0x673c03b2,0x00000000,0x00000000}},	//   gólf, _rusj, --, --, 
   {{0x673e1706,0xbd844c84,0x68e0017a,0xae0400d1}},	//   _susj, _فنون_, ëldo, _توغى, 
   {{0x673c014f,0x66140432,0x00000000,0x00000000}},	//   _pusj, _ryzk, --, --, 
   {{0x6aa40092,0x67340789,0x00000000,0x00000000}},	// [3d370] _tahf, _pizj, --, --, 
   {{0x65645ad8,0xb7140108,0x678c2829,0x00000000}},	//   tshh, едущ, _ሕይወቱ_, --, 
   {{0xddcc0006,0x67361707,0xe9440214,0x00000000}},	//   _įkūr, _vizj, _ترخی, --, 
   {{0x66140316,0x62821708,0x673e1709,0x6734033f}},	//   _vyzk, _sclo, _tusj, _wizj, 
   {{0x673c01f4,0x00000000,0x00000000,0x00000000}},	//   _uusj, --, --, --, 
   {{0x610000ef,0x00000000,0x00000000,0x00000000}},	//   dēla, --, --, --, 
   {{0xb594014b,0x043401ee,0x00000000,0x00000000}},	//   _пирш, _еүеш_, --, --, 
   {{0x814001d3,0x00000000,0x00000000,0x00000000}},	//   ونڈن, --, --, --, 
   {{0x64499463,0xd12c05d4,0xdee40a0e,0x63042dce}},	//   _ifei, جمي_, допи, _قورل, 
   {{0x1e9417a0,0x00000000,0x00000000,0x00000000}},	//   фрир, --, --, --, 
   {{0x130801ec,0xddc0f14f,0x00000000,0x00000000}},	//   _بىلۋ_, malū, --, --, 
   {{0x612403f2,0x613400c0,0x2bf800cc,0x00000000}},	//   dólg, _išlo, _ঘৰেই_, --, 
   {{0x64480270,0x9e6400e5,0x00000000,0x00000000}},	//   _mfei, _ہاںن, --, --, 
   {{0xddc00024,0x9f04020c,0x00000000,0x00000000}},	//   nalū, _توتو, --, --, 
   {{0x64481132,0x3ea40165,0xdca40116,0x1868dba2}},	//   _ofei, _iant_, _жайи, жаби_, 
   {{0x3ea6170a,0xa3bc0ebb,0x00000000,0x00000000}},	//   _hant_, इमा_, --, --, 
   {{0x59b866eb,0x9b44823e,0xddc00153,0x07e40014}},	// [3d380] _उपकर, _تنخو, kalū, ٘زلێ, 
   {{0x64480a8b,0x3ea6170b,0x61240008,0xddc00064}},	//   _afei, _jant_, bólg, jalū, 
   {{0x2000013f,0x3ea6170c,0x25640014,0xddc06e98}},	//   _ɛhia_, _mant_, فانُ, dalū, 
   {{0x3ea6170d,0x92c80c58,0x3f9c02e3,0x00000000}},	//   _lant_, _লগে_, kwuu_, --, 
   {{0x3ea6170e,0x64480036,0x932400f1,0x94180134}},	//   _oant_, _dfei, ورتن, ɛpɛ_, 
   {{0x644803b7,0x3ea40ba3,0x6100005f,0xed6000d0}},	//   _efei, _nant_, vēla, úžky_, 
   {{0x644800a9,0x20180c48,0x00000000,0x00000000}},	//   _ffei, üsin_, --, --, 
   {{0x3ea4282c,0xd37000ec,0xd6280107,0x00000000}},	//   _aant_, _لهر_, _гоҳе_, --, 
   {{0x3ea6170f,0x3014084c,0x93441291,0xaed40114}},	//   _bant_, эдир, _آخرم, еопш, 
   {{0x03221710,0xb640037e,0x3ea61711,0x61f801d3}},	//   _адун, _ｍｊ_, _cant_, áblá, 
   {{0x13a404d3,0x3ea61712,0x3f9c0ba7,0x8af400ac}},	//   _رۆژی_, _dant_, awuu_, şəka, 
   {{0x3ea46f89,0x00000000,0x00000000,0x00000000}},	//   _eant_, --, --, --, 
   {{0x3ea400d6,0x00e4179e,0x2fc000ee,0x0fe000cf}},	//   _fant_, _تتلی, _çig_, _шөкү, 
   {{0x3ea40ad3,0x537c02d3,0x00000000,0x00000000}},	//   _gant_, _የግዳስ_, --, --, 
   {{0xdce0005f,0xac9401ce,0x3da0955d,0x00000000}},	//   gulē, _зайш, _арыб, --, 
   {{0x3ea61713,0x236805ce,0xcd2804fb,0xfbd00133}},	//   _zant_, šaji_, _بستن_, اتێ_, 
   {{0x3ea4094a,0x4ae407d6,0x66b61714,0x00000000}},	// [3d390] _yant_, _жўна, нбау, --, 
   {{0x61340309,0x2caa1715,0x20d0007b,0xd6840115}},	//   _ašll, _haad_, _háit_, _sukϲ, 
   {{0x2caa1716,0x644a1717,0xd5c000a2,0x00000000}},	//   _kaad_, _pfei, _ėāé_, --, 
   {{0x2ca80067,0x7bc003cd,0x69c001f4,0x00000000}},	//   _jaad_, åmug, äleu, --, 
   {{0xc76413ef,0x2caa1718,0x69d5f592,0x2fc000a3}},	//   _تاجى, _maad_, lyze, _àigh_, 
   {{0x2caa1719,0xd2a40046,0x04ec0154,0x00000000}},	//   _laad_, екше_, টকের_, --, 
   {{0x3ea40585,0x3f9c208d,0xddc00153,0x69d400e5}},	//   _rant_, wwuu_, ralū, nyze, 
   {{0x3a38025f,0xa6c00183,0x2ca81b9d,0x64493270}},	//   ורום_, _এতিয়, _naad_, _ufei, 
   {{0x6b840421,0xddc00064,0x00000000,0x00000000}},	//   nōgā, palū, --, --, 
   {{0x249c0142,0xe50c09ab,0x63ac00d7,0xd020013d}},	//   lewm_, िकवि_, ťans, ымый, 
   {{0x2caa171a,0x3ea6171b,0xe0380276,0xa0740124}},	//   _baad_, _vant_, _езеч_, _зылш, 
   {{0x3ea6171c,0x2ca84589,0x20d001e7,0x69d6171d}},	//   _want_, _caad_, _cáit_, dyze, 
   {{0x2caa171e,0x212c0978,0x00000000,0x00000000}},	//   _daad_, mmeh_, --, --, 
   {{0x212c0978,0x00000000,0x00000000,0x00000000}},	//   lmeh_, --, --, --, 
   {{0x69d401ed,0x2ca801c7,0x212c011f,0x8b2000d8}},	//   gyze, _faad_, omeh_, удре, 
   {{0x2ca80009,0x212c0978,0xc0d80023,0x7bc026bb}},	//   _gaad_, nmeh_, _ዕምሪ_, ämus, 
   {{0x7d06171f,0x212c011f,0x030c584e,0x311000cd}},	// [3d3a0] _ijis, imeh_, िवाह_, ावतः_, 
   {{0x7c261720,0x3ce00218,0x212c0842,0x2caa1721}},	//   _izir, _hliv_, hmeh_, _zaad_, 
   {{0x69c000af,0x212c0548,0x2ca86ed8,0x610000e2}},	//   älet, kmeh_, _yaad_, vēln, 
   {{0x20d06bf8,0x2ca80014,0x212c0978,0xd514dabc}},	//   _máis_, _xaad_, jmeh_, رباغ, 
   {{0x8838025f,0x981436e7,0x6d5c01d3,0x212c016d}},	//   _מתכו, _سبحا, áraz, dmeh_, 
   {{0x7c2401f7,0x69c0143a,0xc1740092,0xc32c0014}},	//   _mzir, åleg, _አክራሪ_, مٕن_, 
   {{0x3ce21722,0xdecc044e,0x610000e2,0x7d061723}},	//   _oliv_, ብናን_, rēln, _ojis, 
   {{0x7c240fb7,0x7d046aac,0x3ce00267,0x212c047e}},	//   _ozir, _njis, _nliv_, gmeh_, 
   {{0x2ca83112,0x7c241d66,0xd2500491,0xff4d3ecd}},	//   _raad_, _nzir, _منذ_, یخی_, 
   {{0x7d061724,0x2caa1725,0xaf580020,0x20d0007b}},	//   _ajis, _saad_, _ያደረገ, _báis_, 
   {{0x3ce0019b,0x7c2425ca,0x2ca80b21,0x20d000ae}},	//   _bliv_, _azir, _paad_, _cáis_, 
   {{0x217405f5,0x2ca801d9,0x69d400d0,0xf3540023}},	//   _шуур, _qaad_, vyze, _ዝተተሓ, 
   {{0x6e240115,0x6d440153,0x2ca83735,0xbd8426a6}},	//   _ĝibu, _čiau, _vaad_, ونین_, 
   {{0x7c25e0c4,0x2ca80050,0x7d0401a6,0x69d61726}},	//   _dzir, _waad_, _ejis, tyze, 
   {{0x61245b84,0x7c242252,0x9f5c0548,0x20d0007b}},	//   sóle, _ezir, _ixwá_, _gáis_, 
   {{0x0c8548dc,0x3ce00010,0xad241c3e,0x20d0032e}},	//   _чыкм, _gliv_, _جىعى, _háir_, 
   {{0x7c24025c,0x2d8c01c7,0x047400e5,0x00000000}},	// [3d3b0] _gzir, ltde_, ہلاک_, --, 
   {{0x7d040316,0x69c21727,0xea9800b8,0x212dcb72}},	//   _zjis, äles, _duṣ_, zmeh_, 
   {{0x9ce801d3,0x212c016d,0x00000000,0x00000000}},	//   _رویے_, ymeh_, --, --, 
   {{0x3ce00381,0x610000e2,0x20d000ae,0x00000000}},	//   _xliv_, vēlo, _láir_, --, 
   {{0x212c0978,0xd24c00f1,0x00000000,0x00000000}},	//   vmeh_, ښنو_, --, --, 
   {{0x610000e2,0x27ea1728,0x212c047e,0x20d1195a}},	//   tēlo, mzan_, wmeh_, _náir_, 
   {{0xefd002d3,0xa0a532b1,0x212c016d,0x27ea1729}},	//   ብኣዊ_, вайд, tmeh_, lzan_, 
   {{0xd12c5789,0x212c0369,0x27e94e89,0x20d00332}},	//   يمو_, umeh_, ozan_, _ráis_, 
   {{0x645a172a,0x443e172b,0x600802bf,0x212c016d}},	//   mbwi, _igu_, ьним_, rmeh_, 
   {{0xb9f81540,0x212c0978,0x443c020b,0x27e80cd9}},	//   _ዘፍ_, smeh_, _hgu_, izan_, 
   {{0x1d0a172c,0x3ce00218,0x27e80ac5,0xaf58001f}},	//   дени_, _pliv_, hzan_, _ያደርገ, 
   {{0x2368098d,0x645800ca,0x212c0978,0x00000000}},	//   šaju_, nbwi, qmeh_, --, 
   {{0x3ce0012c,0x20d00ad9,0x2d9402dd,0x443c00a2}},	//   _vliv_, _fáir_, _ұрыс, _mgu_, 
   {{0x443c0c67,0x7c240810,0x20d00332,0x00000000}},	//   _lgu_, _vzir, _gáir_, --, 
   {{0x443e172d,0xd94400f7,0x27e85440,0x60c80083}},	//   _ogu_, теби, ezan_, ojem, 
   {{0x7e6000d5,0x3ce005d5,0x38ca172e,0x7d06172f}},	//   _henp, _uliv_, رازی_, _ujis, 
   {{0x7c261730,0x69c21731,0xad2402e9,0x8cbc09b2}},	// [3d3c0] _uzir, äler, _حروو, षारो, 
   {{0x60c808cb,0x7e60013a,0x00000000,0x00000000}},	//   hjem, _jenp, --, --, 
   {{0xb908045e,0x7e6001c0,0x60c803a1,0x27ea1732}},	//   _বদ_, _menp, kjem, azan_, 
   {{0x7e621733,0x443e1734,0x60c85ffe,0x6ef801e1}},	//   _lenp, _cgu_, jjem, _kùbè, 
   {{0xfe6471f1,0x443d24fb,0xefd00023,0x27e80210}},	//   _پد_, _dgu_, ብባዕ_, czan_, 
   {{0x7e621735,0x64580161,0x60c80210,0x00000000}},	//   _nenp, abwi, ejem, --, 
   {{0xb9e0044e,0x6458019f,0x443c0477,0x236c0037}},	//   _ብኡ_, bbwi, _fgu_, _evej_, 
   {{0xa1a40032,0x60c87c79,0xdce0ec01,0x6ea4000d}},	//   уышһ, gjem, yslā, _कसहु, 
   {{0x03a0a3c3,0x7e621736,0x00000000,0x00000000}},	//   _кито, _benp, --, --, 
   {{0x59d01524,0x7f8001ed,0x443c195a,0x2edc00dc}},	//   सहार, گلین, _zgu_, यसेत, 
   {{0x27e81570,0x7e621737,0x86780302,0x6d4401f1}},	//   zzan_, _denp, וריו, _čias, 
   {{0x27ea1738,0x7e60a1eb,0xf414010f,0x00000000}},	//   yzan_, _eenp, ָפֿ_, --, 
   {{0xe0d00014,0x2d8d1d00,0x7bc00113,0x6e9548a6}},	//   _دزٕ_, stde_, ämup, _билу, 
   {{0x7e60005c,0xc0cc0092,0xdce000c0,0x00000000}},	//   _genp, ብዳል_, kulė, --, 
   {{0x48a8b8d2,0x8d8439af,0xdce00064,0x00000000}},	//   мтам_, _рулд, julė, --, 
   {{0x27e805f5,0x7e600100,0x00000000,0x00000000}},	//   tzan_, _zenp, --, --, 
   {{0x6124007b,0x69c00158,0x6d48263e,0x4b0404b3}},	// [3d3d0] nóla, åleb, lqda, _аянб, 
   {{0x27e85fae,0x2d482776,0x443e1739,0xe7189f9c}},	//   rzan_, _kûe_, _sgu_, ريات_, 
   {{0xcfd4015b,0xf6441503,0xdce00153,0x6d4806be}},	//   _তেমন, рхун, gulė, nqda, 
   {{0x6124008c,0x6458090c,0x6d480369,0x25a801ec}},	//   kóla, ubwi, iqda, _ۋگاي_, 
   {{0xe2f80046,0x291801e4,0x612401a8,0x64580a06}},	//   неді_, _iksa_, jóla, rbwi, 
   {{0x61340006,0x05740594,0xdce00024,0xa1882401}},	//   _išli, _لارد, bulė, ебка_, 
   {{0x443c05b1,0x60ca173a,0xc32c0014,0xb2840166}},	//   _tgu_, tjem, مٕچ_, рычк, 
   {{0x443c0d62,0x7e62173b,0xa3640014,0x776c0166}},	//   _ugu_, _senp, _مُرو, _älxä, 
   {{0x60c87cba,0x26d0354a,0xc3480006,0x23780b24}},	//   rjem, _kozo_, _цябе_, _سماد_, 
   {{0x60c803a1,0x26d0e64e,0x6d440030,0x6e2400df}},	//   sjem, _jozo_, _čiar, _ĝibr, 
   {{0x26d2173c,0x6b8db921,0x291826bb,0xb8d00327}},	//   _mozo_, _aqag, _oksa_, _ྒྲ_, 
   {{0x7e602960,0x6ee4067c,0x2d480129,0x4c800212}},	//   _wenp, _ròbe, _dûe_, блюв, 
   {{0x7e62173d,0x6d480009,0x98b80356,0x612400ae}},	//   _tenp, aqda, _lupă_, cóla, 
   {{0x2d48006a,0xdea0006c,0x63a8009f,0x29047cd8}},	//   _fûe_, _ایدی, _msen, élan_, 
   {{0x09e005c5,0x41b001ad,0x5d741eed,0x69c00254}},	//   борн, ंटिस, _сулф, älep, 
   {{0x63aa173e,0x17c80137,0xa8540063,0x00000000}},	//   _osen, нгби_, итуј, --, 
   {{0x63aa173f,0x26d00296,0xccf00a1e,0xb8dc07c1}},	// [3d3e0] _nsen, _bozo_, _לכה_, _आफ_, 
   {{0x2918010f,0x3ab43ad0,0x00000000,0x00000000}},	//   _eksa_, _тәмт, --, --, 
   {{0x63aa1740,0x795404d3,0xd628023a,0x26d21741}},	//   _asen, _خێزا, хоже_, _dozo_, 
   {{0x98b80262,0x93880d08,0xd4041c03,0x29180af9}},	//   _după_, еска_, ляли, _gksa_, 
   {{0x63a801ed,0x958402dd,0xd25006c2,0x00000000}},	//   _csen, _әлбе, منش_, --, 
   {{0x26d21742,0x76d80107,0xdce00064,0x00000000}},	//   _gozo_, _румӣ_, pulė, --, 
   {{0x63aa1743,0x4171b755,0x87040276,0x55e4030d}},	//   _esen, مايس, _серв_, _совб, 
   {{0x26d21744,0x6ad01025,0x2edc7509,0x61261745}},	//   _zozo_, _सक्र, यस्त, tóla, 
   {{0x13084705,0xe50800dc,0x3d180037,0x20400023}},	//   _знай_, _वदति_, नवने_, _ቐዳመይ, 
   {{0x6124fdf7,0x2ef41f67,0x4ea61746,0x00000000}},	//   róla, рзор, уриа, --, 
   {{0xa9840023,0x63a801d3,0x6cd40d2f,0x8d74d9dc}},	//   _ዝፍትኑ_, _zsen, لقدا, ھاھا, 
   {{0xc5f00375,0x63a803ac,0x6d48263e,0x00000000}},	//   מדת_, _ysen, rqda, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe3b801d3,0x2b4c00df,0xeff00092,0x00000000}},	//   _szűk_, ŭeco_, ልነው_, --, 
   {{0x26d1a21a,0x6e9400d1,0x6d4806be,0x00000000}},	//   _rozo_, _биһу, qqda, --, 
   {{0x09480116,0x98b8054e,0x00000000,0x00000000}},	//   _үчни_, _rupă_, --, --, 
   {{0x26d00cc3,0xf77000c6,0xebc54d65,0x25500213}},	// [3d3f0] _pozo_, كال_, _тәнн, _işlə_, 
   {{0xe9447c12,0x056806ed,0x0ae83cc6,0xf1c400cd}},	//   _پردی, ејди_, _سرخي_, वमान, 
   {{0x63a82f99,0x2ba807b7,0x00000000,0x00000000}},	//   _ssen, _चैता, --, --, 
   {{0x29180054,0xdb14007f,0x63a8110c,0xddc00276}},	//   _uksa_, _aryè, _psen, lalţ, 
   {{0x26d21747,0x62661748,0xb4654012,0xe7380116}},	//   _tozo_, авла, скіл, _җең_, 
   {{0xb18c069c,0xe29a1749,0x6124068f,0x26d2174a}},	//   _ዘይኮነ_, так_, góln, _uozo_, 
   {{0x63a80af2,0x61000265,0x3abc011a,0x00000000}},	//   _wsen, lēli, תמונ, --, 
   {{0x63a81a89,0xdfd00491,0x6d4401f1,0x61ec01e4}},	//   _tsen, قيع_, _čiap, ŝalo, 
   {{0x63aa174b,0x8285dacf,0xfe74192c,0x3fc440ec}},	//   _usen, _مجال, гүл_, ادعی_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf2c6174c,0x00000000,0x00000000,0x00000000}},	//   _устн, --, --, --, 
   {{0x61240a90,0x1fb4023a,0x201c015d,0xef18717e}},	//   mólo, _вскр, _tywi_, кмө_, 
   {{0x61240005,0x8e3c01a9,0xfc380022,0x00000000}},	//   lólo, sitа_, ыҭи_, --, 
   {{0x8f5000f2,0x61000171,0x40e40244,0x00000000}},	//   _بنوش, dēli, _جوڵێ_, --, 
   {{0x61243a64,0x18682b97,0x9b441a90,0x98b80210}},	//   nólo, кави_, _ھندو, _lupą_, 
   {{0xdd94052f,0xdea001b9,0x612400e5,0x2d980327}},	//   _баҫы, _ایگی, zóln, ħret_, 
  
   {{0x16643dc8,0x96640c9e,0xfb842d77,0x98340006}},	// [3d400] ивам, икае, _ادعی, рэві, 
   {{0xa3e802c3,0x61340064,0x00000000,0x00000000}},	//   मनन_, _išlu, --, --, 
   {{0x546a174d,0x7afe174e,0xfee4009e,0xd7f8010b}},	//   ваем_, mirt, _পদাধ, хуң_, 
   {{0x7afc0ab7,0x61245b84,0x38040117,0x031401e2}},	//   lirt, dólo, _гомҳ, یتوت_, 
   {{0x78a41c1d,0x610000e2,0x7afc0332,0x4cb800fe}},	//   meiv, cēli, oirt, _উকমু, 
   {{0x78a6174f,0x00000000,0x00000000,0x00000000}},	//   leiv, --, --, --, 
   {{0x06640131,0x59a407f7,0x00000000,0x00000000}},	//   _ﺷﯘﻧﯩ, खबिर, --, --, 
   {{0xc950159d,0x257001ec,0x78a4aca2,0x644c0022}},	//   חמה_, _ءۇنس, neiv, ñait, 
   {{0xb4b4053f,0x6124068f,0x00000000,0x00000000}},	//   _киңә, póln, --, --, 
   {{0x7afe1750,0x78a61751,0x2eb000dc,0xe2a800e3}},	//   jirt, heiv, जयेत, _مامن_, 
   {{0x7afcdc86,0x10a40aa8,0x78a4541b,0xc04ce6c3}},	//   dirt, _виен, keiv, _мі_, 
   {{0x6ee40428,0x24a002d3,0x78a47523,0x8c340107}},	//   _dòba, _ግዱሳት_, jeiv, ионӣ_, 
   {{0x78a40c86,0x7afc6226,0x2904f578,0x09dc00cd}},	//   deiv, firt, élam_, नन्य, 
   {{0x7afe1752,0x6e946061,0xbdf44a23,0xbea0214f}},	//   girt, _طلبا, اریا_, _мачк, 
   {{0x78a40270,0x8934007b,0x20180254,0x00000000}},	//   feiv, لعرا, üsiv_, --, 
   {{0x7afc7ea1,0x78a61753,0x98a00064,0x38c468eb}},	//   airt, geiv, _mikė_, ощув, 
   {{0x612401ed,0xa7b8adb6,0xddc00d4c,0xc66835c7}},	// [3d410] zólo, ылау_, malš, вшее_, 
   {{0xc9840364,0x7afe1754,0x81bc00cc,0x00000000}},	//   _куми, cirt, ুনত_, --, 
   {{0xc50a1755,0x61240789,0xfbd002f2,0x00000000}},	//   پتال_, xólo, _فتی_, --, 
   {{0x78a509fa,0x7544e747,0x98b80210,0x00000000}},	//   ceiv, ініз, _pupą_, --, 
   {{0x27ec005c,0x972000e5,0x00000000,0x00000000}},	//   _åen_, _کہلو, --, --, 
   {{0x216a1756,0x612409c2,0x6144bc51,0xdfe80fc0}},	//   гики_, tólo, бека, ғдод_, 
   {{0xd24d8fc0,0xfa7802e4,0x2b493e26,0x00000000}},	//   رني_, בעות_, _luac_, --, 
   {{0x27ec03c6,0x612425e6,0x00000000,0x00000000}},	//   _ženy_, cóll, --, --, 
   {{0x248c0010,0x71240131,0xddc00010,0x6d5c00e4}},	//   _icem_, غرىل, dalš, ãran, 
   {{0x61243a6c,0x78a61757,0x644c0024,0x7afc0009}},	//   pólo, zeiv, žaid, xirt, 
   {{0xdc6855a7,0xddc002f0,0xbbd000dc,0x00000000}},	//   ланд_, falš, सङ्क, --, 
   {{0x2b40007f,0x7afda70d,0x9f4c025a,0xddc033e9}},	//   _aihc_, wirt, nzeë_, galš, 
   {{0xfe740348,0x78a61758,0x7afe1759,0x2b480005}},	//   _күп_, veiv, tirt, _cuac_, 
   {{0x78a40a73,0x7f58b70b,0x7c280213,0xf8e007d0}},	//   weiv, mpuq, ədrl, नस्प, 
   {{0x7afc00fc,0x78a6175a,0x09e04533,0x248c05ce}},	//   rirt, teiv, порн, _ocem_, 
   {{0x7afe175b,0x2ba800cd,0x00000000,0x00000000}},	//   sirt, _चैवा, --, --, 
   {{0x81bc0c58,0x78a6175c,0x7afe175d,0x98a40184}},	// [3d420] ুনি_, reiv, pirt, _һине, 
   {{0x78a6175e,0x2a94001f,0xdaa800f3,0x248d126b}},	//   seiv, ዜጠኞች_, _свод_, _acem_, 
   {{0x9446175f,0x98a61760,0xd4d80220,0x78a61761}},	//   مپان, _лине, льді_, peiv, 
   {{0x13e80220,0x244c02d2,0x00000000,0x00000000}},	//   лмей_, _rómó_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x39b94251,0x248c03e0,0x00000000,0x00000000}},	//   _kčs_, _ecem_, --, --, 
   {{0x39b8007f,0x00000000,0x00000000,0x00000000}},	//   _jčs_, --, --, --, 
   {{0x38612cc8,0x39b80100,0x00000000,0x00000000}},	//   nbir_, _mčs_, --, --, 
   {{0x38600798,0x39b8007f,0x0ca801d5,0x00000000}},	//   ibir_, _lčs_, қтни_, --, 
   {{0xe3b00014,0x3860003e,0x0dc8011c,0x00000000}},	//   _ترِ_, hbir_, гуми_, --, 
   {{0x38605e03,0x2904003e,0x1afc00cc,0x00000000}},	//   kbir_, élak_, ংকাই_, --, 
   {{0x63ac0798,0x0f700131,0xd024010b,0xdde800f1}},	//   çang, _еғир, _лмей, شرپه_, 
   {{0x38621762,0xddc03421,0x2b48003a,0x8fe000fb}},	//   dbir_, ralš, _quac_, _хәйҙ, 
   {{0x941802ea,0x00000000,0x00000000,0x00000000}},	//   ɛpɔ_, --, --, --, 
   {{0xac943d89,0x42d8010f,0xfd9401e2,0x00000000}},	//   _дайш, נקלע, _هئيت_, --, 
   {{0xcce47434,0x5c18063f,0x6d5a1763,0x291c030a}},	//   _دستي, ọdụi, _itva, ôwa_, 
   {{0x610000de,0x00000000,0x00000000,0x00000000}},	// [3d430] cēlu, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3860003d,0xbb3c008f,0x248c0129,0x84900023}},	//   bbir_, _געזי, _pcem_, _ዘምርሕ_, 
   {{0x6d580998,0x48a8030d,0x386005d2,0x00000000}},	//   _mtva, _стом_, cbir_, --, 
   {{0x68ee1764,0x29083d68,0x02c0004e,0x71580150}},	//   mhad, mnaa_, зилү, ұрыс_, 
   {{0x6d581326,0x68ee1765,0x290931eb,0x39b8007f}},	//   _otva, lhad, lnaa_, _yčs_, 
   {{0x290a1766,0x23840014,0x68ec01ab,0xd24c00d1}},	//   onaa_, _ژٔرِ, ohad, خنى_, 
   {{0xb9f12762,0x68ee1767,0x29080a4d,0xe0d8f138}},	//   _ናይ_, nhad, nnaa_, рви_, 
   {{0x63adbae8,0x6d584ffc,0x290a1768,0x28e01d68}},	//   çand, _atva, inaa_, _नवनि, 
   {{0x2909dfb9,0x68ee1769,0x7f580309,0x6ab40334}},	//   hnaa_, hhad, rpuq, jdzf, 
   {{0x68ee176a,0x290a176b,0xdca400f3,0x00000000}},	//   khad, knaa_, оани, --, 
   {{0xf1d401c0,0x39b802e2,0x8f6801ed,0x3862176c}},	//   _хөшө, _rčs_, _چلنے_, xbir_, 
   {{0x68ee176d,0x8026176e,0x290801d9,0xa3e800dc}},	//   dhad, _ارام, dnaa_, मनि_, 
   {{0x290918b7,0x68ec00a3,0xd944049d,0x00000000}},	//   enaa_, ehad, жеви, --, 
   {{0x68ec0084,0x7f42176f,0x6ee40ba1,0x2908300b}},	//   fhad, _iinq, _mòbl, fnaa_, 
   {{0x68ec65f2,0x290a1770,0xa3e85b99,0x7f484242}},	//   ghad, gnaa_, मना_, _kugq, 
   {{0x38616be2,0x63b80369,0x00000000,0x00000000}},	// [3d440] rbir_, jvwn, --, --, 
   {{0x7c261771,0x612409cc,0x7f4a1772,0x29080a55}},	//   _iyir, fólk, _mugq, anaa_, 
   {{0x29086419,0x7c24013f,0x1dc80b9c,0x7f4801b3}},	//   bnaa_, _hyir, िमित, _lugq, 
   {{0x68ec0571,0x7f40ba8b,0xff440d2f,0x14261773}},	//   chad, _linq, _يخ_, одем, 
   {{0xd2a80209,0x00000000,0x00000000,0x00000000}},	//   икде_, --, --, --, 
   {{0x61240579,0x7c240223,0x7f421774,0xd1b802de}},	//   bólk, _myir, _ninq, لاعا_, 
   {{0xb3d80011,0x54a42ed7,0x00000000,0x00000000}},	//   _দেশজ, _وحرف, --, --, 
   {{0x7f480fec,0x7c2402e3,0xcf9800f0,0xc20466a3}},	//   _bugq, _oyir, ајо_, تقىن_, 
   {{0x6d58098d,0x7c261775,0x4ea61776,0x7f400007}},	//   _stva, _nyir, орна, _binq, 
   {{0x7f410ea2,0x63ae1777,0x6f080354,0x68ec0dd4}},	//   _cinq, çane, undc, zhad, 
   {{0x290889fe,0x7c261778,0x7f400a55,0x68ec95ca}},	//   ynaa_, _ayir, _dinq, yhad, 
   {{0x7c240526,0xe3b000aa,0x68ede871,0x7f40002f}},	//   _byir, _ترې_, xhad, _einq, 
   {{0x7c240230,0x68ec06d6,0x7f421779,0x00000000}},	//   _cyir, vhad, _finq, --, 
   {{0x290a177a,0x6d590833,0x00000000,0x00000000}},	//   wnaa_, _ttva, --, --, 
   {{0x68ee177b,0x6d592a67,0x7c24009a,0x63b80007}},	//   thad, _utva, _eyir, zvwn, 
   {{0x02b402f8,0x7f401cdf,0xb18c02d3,0x7c24032e}},	//   _आफ्न, _zinq, _ዘይኰነ_, _fyir, 
   {{0x68ec27ed,0x7c256383,0x290a177c,0x7f42177d}},	// [3d450] rhad, _gyir, rnaa_, _yinq, 
   {{0x68ee177e,0x290a177f,0xbb48179e,0x00000000}},	//   shad, snaa_, _گلین_, --, 
   {{0x68ee1780,0x69c00ac7,0x00000000,0x00000000}},	//   phad, æled, --, --, 
   {{0xd12422be,0xe3b0fc68,0x29080014,0x00000000}},	//   _سم_, فرت_, qnaa_, --, 
   {{0x6ee41497,0x68fc0fac,0x98b80118,0xd004007b}},	//   _pòbl, _imsd, _lupě_, _أل_, 
   {{0x61444538,0xefdc0023,0x00000000,0x00000000}},	//   пека, _ዕልዋ_, --, --, 
   {{0xd5ac01d9,0x290400e8,0x7f419ef2,0xba9c010f}},	//   _مہٕ_, élaw_, _rinq, יסגי, 
   {{0x7f421781,0xe50806c5,0xb6440150,0x00000000}},	//   _sinq, _ايرو_, _ﺎﺝ_, --, 
   {{0x7f40debb,0x61245b84,0xd12e1782,0xc2180037}},	//   _pinq, nóli, دمي_, _पुरब_, 
   {{0x7c24337a,0x7f400784,0x00000000,0x00000000}},	//   _ryir, _qinq, --, --, 
   {{0x7c247807,0xe164034c,0x6125ab60,0x3d1817e6}},	//   _syir, _رضای, hóli, नवले_, 
   {{0x612401a8,0xd00c2a9f,0x00000000,0x00000000}},	//   kóli, ئلی_, --, --, 
   {{0x7f421783,0x00000000,0x00000000,0x00000000}},	//   _tinq, --, --, --, 
   {{0x7c241446,0x68fc02d0,0x7f4003ac,0x00000000}},	//   _vyir, _amsd, _uinq, --, 
   {{0x6448005a,0x60d80432,0x27ec00ef,0x00000000}},	//   _ogei, _kowm, _ļena_, --, 
   {{0x644a1784,0xa3bc0316,0x61261785,0x68fc022e}},	//   _ngei, ेमा_, fóli, _cmsd, 
   {{0x7c240526,0x07a21786,0x17844f55,0x00000000}},	// [3d460] _uyir, натн, ягам, --, 
   {{0x68fc7421,0xc720005b,0x00000000,0x00000000}},	//   _emsd, едуй, --, --, 
   {{0x64480036,0x5eac00cc,0x00000000,0x00000000}},	//   _bgei, _কচাই, --, --, 
   {{0x6448009a,0x6124748d,0x60d80175,0x00000000}},	//   _cgei, bóli, _nowm, --, 
   {{0x6124057f,0x64480334,0x88b8011a,0x00000000}},	//   cóli, _dgei, _הזכי, --, 
   {{0x43804da8,0x64480428,0xd04403be,0x6d5c00e4}},	//   رلىق, _egei, əməl, ãrak, 
   {{0x60d80b1d,0x63e00075,0x00000000,0x00000000}},	//   _bowm, ىۋېل, --, --, 
   {{0x60d80076,0x00000000,0x00000000,0x00000000}},	//   _cowm, --, --, --, 
   {{0x40500491,0x60d800a2,0x13e84530,0x60dc007c}},	//   رئيس, _dowm, _умай_, ösma, 
   {{0x612400d2,0x69c00158,0x23680115,0x00000000}},	//   kólw, ålek, ɨaj_, --, 
   {{0x10a405b0,0x0694025f,0xdcb01823,0x6448029f}},	//   _нижн, הדים_, چىپ_, şmiş, 
   {{0xdcb01a59,0x60d94ad2,0x00000000,0x00000000}},	//   نىپ_, _gowm, --, --, 
   {{0x81bc0154,0x00b8011a,0x50740023,0x00000000}},	//   ুনঃ_, _למאמ, _ፍስሓጽ, --, 
   {{0x3f78008f,0xbf1001ec,0x8fd001af,0x68fc01ef}},	//   _פאוס, _كونب, _жәүә, _smsd, 
   {{0xfe9804ae,0x60d80009,0x7e98011a,0x00000000}},	//   _היומ, _yowm, _לסגו, --, 
   {{0x61242cd7,0x94100213,0x7db0007b,0x00000000}},	//   tóli, şdən_, _أصوا, --, 
   {{0xc64840bb,0x6d5c0115,0x00000000,0x00000000}},	// [3d470] مجال_, ŭrad, --, --, 
   {{0xac9800dd,0x64480e89,0x02d800cd,0x9aa800db}},	//   _اچھا_, _sgei, _भवेन, _ۇنۋە_, 
   {{0x612409c2,0x44280427,0xa4d40212,0x80bc00dc}},	//   sóli, _šc_, можі, वयमे, 
   {{0x6fdc0034,0x68fc03ac,0x00000000,0x00000000}},	//   यहां, _umsd, --, --, 
   {{0xd8b80375,0x22480902,0x00000000,0x00000000}},	//   _וצרכ, опли_, --, --, 
   {{0x60d80432,0x37c803d4,0xa5f80117,0x00000000}},	//   _sowm, _ৰেকৰ, _дегу_, --, 
   {{0x644807c5,0xc32c0050,0x69c001bf,0x71240633}},	//   _tgei, نٕچ_, åleh, کرول, 
   {{0x60d80014,0x644803cb,0x00000000,0x00000000}},	//   _qowm, _ugei, --, --, 
   {{0x9f880428,0x4428001e,0x60d80076,0xa2a80014}},	//   _añòg_, _ác_, _vowm, _وُرٕ_, 
   {{0x8234009a,0x00000000,0x00000000,0x00000000}},	//   _فرضا, --, --, --, 
   {{0x60d80204,0xa3a82c06,0x1ce00014,0x00000000}},	//   _towm, गौर_, َےتہ, --, 
   {{0x6ee401ab,0xa0c50496,0x00000000,0x00000000}},	//   _lòbh, _زيتو, --, --, 
   {{0x9f8808e7,0x28d01cba,0x00000000,0x00000000}},	//   _eñòg_, हानि, --, --, 
   {{0x4fa00c68,0x61240162,0x4ec04965,0xef18155b}},	//   _ришв, gólv, _айшв, _емі_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x52d8007d,0x5fd00073,0x1ea800f1,0x00000000}},	//   _बक्स, तमपल, _داچي_, --, 
   {{0xeb541e87,0xf0300023,0x57440064,0x00000000}},	// [3d480] _كىيگ, _ብትሕዝ, днаб, --, 
   {{0x9a880014,0x00000000,0x00000000,0x00000000}},	//   _بندٕ_, --, --, --, 
   {{0x6ee400a3,0x9ac000db,0x13c400cd,0xdbdc0022}},	//   _dòbh, _كۅڭۈ, लम्भ, pâóp, 
   {{0x644c4a97,0x35c80107,0x29040129,0xa3e800cd}},	//   žain, оҳҳо_, élat_, मनं_, 
   {{0x25ac0cf4,0x00000000,0x00000000,0x00000000}},	//   _ćele_, --, --, --, 
   {{0x6ee400a3,0x1cac0327,0xf31401c6,0x8c18011a}},	//   _gòbh, _པིའ_, эдлэ, חוני, 
   {{0x249c0218,0x417000cf,0x94aa1787,0xc17001e2}},	//   bfwm_, نايس, _وارِ_, نديت, 
   {{0x612401a8,0x28d0000d,0x03a400ec,0x00000000}},	//   kólu, हायि, _ڊگهو_, --, 
   {{0x98bc0006,0xa3e800dc,0xbbb807f7,0x9315c96b}},	//   ūtė_, मनः_, इटोक, _قورش, 
   {{0x1dc80764,0x00000000,0x00000000,0x00000000}},	//   िमंत, --, --, --, 
   {{0x61241dec,0xac940022,0x00000000,0x00000000}},	//   vólv, нанш, --, --, 
   {{0x6ee40228,0xa3b4007d,0x0fb40cb4,0x41000801}},	//   _mòbi, _जनम_, _अनपढ, _изхв, 
   {{0x61ec0115,0x8af803b9,0x00000000,0x00000000}},	//   ŝalt, jdəç, --, --, 
   {{0x28e00ce0,0x6e9401a9,0x00000000,0x00000000}},	//   _नवहि, _чику, --, --, 
   {{0x26cc001e,0x09d4009e,0xbea01d39,0x61240162}},	//   _đeo_, সনভা, _рајк, rólv, 
   {{0x1cac025c,0x2d8e1788,0x61261789,0x6ee400a3}},	//   _པིར_, mude_, sólv, _sòbh, 
   {{0xf772178a,0xab786ea9,0x00000000,0x00000000}},	// [3d490] لال_, _عمدا_, --, --, 
   {{0x6ee400db,0x2d8c0129,0x28e080a0,0x00000000}},	//   _bòbi, oude_, _नववि, --, 
   {{0x2d8c0bb8,0x290404cc,0xe8200037,0x00000000}},	//   nude_, élas_, _मडवा_, --, 
   {{0x290c08e7,0x06a00150,0x61240332,0xe374013d}},	//   _ñea_, _ﺍﯕﻨﯩ, nólt, елды, 
   {{0x2d8e178b,0xb4640220,0xf1a801ec,0x00000000}},	//   hude_, ткіл, _ﺴﻴﻨﺘ, --, 
   {{0x2d8d68d5,0x6596178c,0x6ee400db,0x00000000}},	//   kude_, _пагу, _fòbi, --, 
   {{0x2d8e178d,0x9bb8025c,0x2498007c,0xd3440330}},	//   jude_, _བླློ, _ösmo_, ریمه_, 
   {{0x2d8e178e,0xd58403e6,0x0e60010b,0x00000000}},	//   dude_, _سێهه_, ңкын, --, 
   {{0x6458014b,0x6304515c,0x2d8c0af9,0x60091486}},	//   mcwi, _كورل, eude_, яним_, 
   {{0x2d8c04ba,0x612400d8,0xdce0025c,0x00000000}},	//   fude_, vólu, dulġ, --, 
   {{0x2d8c007d,0xf19400c7,0x00000000,0x00000000}},	//   gude_, _аихь, --, --, 
   {{0x64580472,0x717000d1,0x00000000,0x00000000}},	//   ncwi, _ئۇيا, --, --, 
   {{0x1868016c,0x00000000,0x00000000,0x00000000}},	//   ҷаби_, --, --, --, 
   {{0x2d8e178f,0x00000000,0x00000000,0x00000000}},	//   bude_, --, --, --, 
   {{0x98a4dd0e,0x6124022c,0x2d8d5005,0x18a406ed}},	//   ниве, bólt, cude_, навм, 
   {{0x2da000d0,0x6d5c01e4,0x236c0210,0x00000000}},	//   áreň_, ŭrac, _owej_, --, 
   {{0xb908146b,0xa0640023,0xfba400c5,0x1c44003b}},	// [3d4a0] _भव_, _ግድነታ, _ओहिम, _яним, 
   {{0x7bc41730,0x8c180302,0x5a640cc9,0x00000000}},	//   _iriu, _מופי, _якоб, --, 
   {{0xcb100375,0xc6740023,0x00000000,0x00000000}},	//   _תלת_, _ኣዝመራ_, --, --, 
   {{0x645801e2,0x1cac031c,0x7bc48938,0x63ac025c}},	//   gcwi, _པིས_, _kriu, ħann, 
   {{0xdce00598,0xd3244294,0xba000023,0x69c00158}},	//   ntlı, ньки, _ቂሐ_, ålev, 
   {{0x77640bc9,0x2d8c0113,0xdb080100,0x84400014}},	//   mpix, yude_, ènèl, ھى۪ۆ, 
   {{0x799e1790,0x51843de2,0x7764031c,0x00000000}},	//   ntrw, хула, lpix, --, 
   {{0xd3721791,0x7bc61792,0x85980302,0x2d8e1793}},	//   _مهر_, _oriu, _משלו, vude_, 
   {{0x2d8c01f2,0x1cac0327,0x00000000,0x00000000}},	//   wude_, _པྲེ_, --, --, 
   {{0xa3000598,0x3f100150,0x8d8400cf,0x00000000}},	//   _күче, лдыс, нумд, --, 
   {{0xe2a840ab,0x7bc003b2,0x2d9800e4,0xd0840150}},	//   _زالن_, æmun, îre_, _зыли, 
   {{0x7bc61794,0x00000000,0x00000000,0x00000000}},	//   _briu, --, --, --, 
   {{0x7bc44cff,0xa07400c7,0xf1a80150,0xe20401e1}},	//   _criu, _рыхш, _ﺴﻴﻠﺘ, _óóre_, 
   {{0x7bc61795,0x2d8c00b5,0x612402d2,0x00000000}},	//   _driu, pude_, bóls, --, 
   {{0x0dc8074d,0xe3e000eb,0x00000000,0x00000000}},	//   _хули_, _মোব, --, --, 
   {{0x7bc61796,0x61f400dd,0x765c033f,0x2d7c01e4}},	//   _friu, _üzle, _afry, mĉe_, 
   {{0x7bc42e18,0x2d7c00df,0xcaa4007b,0x00000000}},	// [3d4b0] _griu, lĉe_, _كصدي, --, 
   {{0xda700451,0xdb140200,0x00000000,0x00000000}},	//   _پُٽ_, _rryç, --, --, 
   {{0x6b9cc31f,0x236c033f,0x2d7c00df,0x799c015d}},	//   ltsg, _swej_, nĉe_, ctrw, 
   {{0x69c401ab,0xa878008f,0x765c0042,0x6b9c02d0}},	//   _irhe, _קאָר, _efry, otsg, 
   {{0x6b9c1401,0x765c03cb,0xdde0012d,0xe2f801ec}},	//   ntsg, _ffry, _żużl, меді_, 
   {{0x6b9c03fa,0x2d7c01e4,0xa634187f,0x6608002b}},	//   itsg, kĉe_, _ангі, _śeku, 
   {{0x61bc00dc,0x2f5401ec,0x00000000,0x00000000}},	//   ्मेष, қтыс, --, --, 
   {{0x6b9c78d0,0x925400d1,0x81d80154,0x00000000}},	//   ktsg, наәт_, _ঢেউ_, --, 
   {{0x6ee4004e,0xa3b400c5,0xe3e80214,0x15b00137}},	//   _lòbu, _जनि_, _تکان_, _مەەس, 
   {{0x3f8054ff,0x69c61797,0x22a4039b,0x6b9c00b5}},	//   čju_, _orhe, _шубҳ, dtsg, 
   {{0x7bc40006,0x63a805c7,0x62800129,0x6b9c01c7}},	//   _sriu, _hpen, _idlo, etsg, 
   {{0x7bc61798,0x63a8145e,0xa3b432b7,0x6aa403ac}},	//   _priu, _kpen, _जना_, _abhf, 
   {{0x69c16da4,0x212c0098,0x63a80129,0x644c0113}},	//   ælen, mleh_, _jpen, ñaiy, 
   {{0x63aa1799,0x212e179a,0x7bc4180f,0x29041e93}},	//   _mpen, lleh_, _vriu, èlan_, 
   {{0x6b9c1f9e,0x6281e265,0x7bc4000f,0x8a0000f3}},	//   atsg, _mdlo, _wriu, азре, 
   {{0x212e179b,0x1ea805d9,0x6ba40267,0x29040309}},	//   nleh_, _راڻي_, åtgä, élap_, 
   {{0x62800f72,0x69c40730,0x212c0ac5,0x799c0368}},	// [3d4c0] _odlo, _erhe, ileh_, strw, 
   {{0x212c03a2,0x6282179c,0x7d040327,0x7764324c}},	//   hleh_, _ndlo, _hmis, rpix, 
   {{0x63aa179d,0x212e179e,0xceb00302,0x69c003cd}},	//   _apen, kleh_, שיב_, ålet, 
   {{0x6b881ebd,0x6282179f,0x63a805c7,0x7d04003d}},	//   šege, _adlo, _bpen, _jmis, 
   {{0x394217a0,0x7d0617a1,0x212c016d,0x00000000}},	//   mmis_, _mmis, dleh_, --, 
   {{0x394217a2,0x6da8016b,0x7d04036b,0x61340024}},	//   lmis_, _yɛad, _lmis, _išly, 
   {{0x7d0617a3,0x63aa17a4,0x39400006,0xd13801c0}},	//   _omis, _epen, omis_, мхи_, 
   {{0x628003ac,0x2d80008f,0x63a8058a,0x394217a5}},	//   _edlo, _ĉie_, _fpen, nmis_, 
   {{0x044001fe,0x394000ae,0x142401d5,0x934468eb}},	//   _ветн, imis_, _рдам, _анае, 
   {{0x212c06a3,0x883805d0,0x00000000,0x00000000}},	//   aleh_, ותפו, --, --, 
   {{0xac9813d7,0x212c4091,0x394003e0,0xa9800023}},	//   ىندا_, bleh_, kmis_, _ክፍትሑ_, 
   {{0x6b9c713c,0x63a801f5,0x2d7c0115,0x62802438}},	//   ttsg, _ypen, rĉe_, _zdlo, 
   {{0x63a805b1,0x7d04000d,0x28d0578b,0x39400254}},	//   _xpen, _dmis, हासि, dmis_, 
   {{0x394217a6,0x00000000,0x00000000,0x00000000}},	//   emis_, --, --, --, 
   {{0x6b9c035a,0x3a74011c,0x00000000,0x00000000}},	//   stsg, рлср, --, --, 
   {{0x6f080784,0x3914009d,0x00000000,0x00000000}},	//   lidc, амср, --, --, 
   {{0x0a684ee3,0x6d4c0009,0x1cac0327,0xe738011c}},	// [3d4d0] _орни_, _iiaa, _པྲི_, епач_, 
   {{0xa47c044e,0x0af005f5,0xb6f40640,0x7d040427}},	//   _ከምዘሎ_, _түгэ, азуј, _zmis, 
   {{0x69c40f3b,0x7d041125,0x6d4e17a7,0x63aa17a8}},	//   _urhe, _ymis, _kiaa, _spen, 
   {{0xdb14be6d,0x6d4c603f,0x7d042972,0x212c0009}},	//   _asyè, _jiaa, _xmis, xleh_, 
   {{0x290a17a9,0x3cfc010f,0x349400d8,0x00000000}},	//   miaa_, ולאנ, рачр, --, 
   {{0x27e88d34,0x68ee17aa,0x290a17ab,0x63a80219}},	//   myan_, lkad, liaa_, _vpen, 
   {{0x27ea17ac,0xa0a617ad,0x68ec0156,0x6f0893c1}},	//   lyan_, гайд, okad, didc, 
   {{0x6d4e17ae,0xc5ec0490,0x29085979,0x672401f4}},	//   _niaa, चनीय_, niaa_, lohj, 
   {{0x63aa17af,0x27ea17b0,0x212c0067,0x6d5e17b1}},	//   _upen, nyan_, rleh_, íran, 
   {{0x628217b2,0x27e80c67,0x81a80183,0x290a17b3}},	//   _udlo, iyan_, খিব_, hiaa_, 
   {{0x29081132,0xde0617b4,0x69c000b5,0x27ea17b5}},	//   kiaa_, упни, ælel, hyan_, 
   {{0x27e9649a,0x68ee17b6,0x2d9800db,0x6724047e}},	//   kyan_, jkad, àrea_, hohj, 
   {{0x68ec01af,0x7d04003e,0x29080108,0x27e8fa6d}},	//   dkad, _vmis, diaa_, jyan_, 
   {{0x68ec01d9,0x94040134,0x3f9c0a55,0x67240240}},	//   ekad, mfoɔ_, mtuu_, johj, 
   {{0x290a17b7,0x3f9e17b8,0x6d4c0607,0x7d0597c9}},	//   fiaa_, ltuu_, _fiaa, _tmis, 
   {{0x27ea17b9,0x6d4c0589,0x68ee17ba,0x394000c5}},	//   fyan_, _giaa, gkad, umis_, 
   {{0x27ea17bb,0x3f9e17bc,0x69c01347,0xfd540055}},	// [3d4e0] gyan_, ntuu_, åler, _ahaḥ, 
   {{0x68ec34f3,0x3f9d500e,0x00000000,0x00000000}},	//   akad, ituu_, --, --, 
   {{0x4a9804ac,0x3f9c049b,0x27e80e14,0x9485476e}},	//   _אייג, htuu_, ayan_, гылд, 
   {{0x68ec04f3,0x27ea17bd,0x6da8013f,0x3f9cbf74}},	//   ckad, byan_, _yɛab, ktuu_, 
   {{0xb9140882,0xdb1400e4,0x78a4014b,0x28d02802}},	//   dhaḥ_, _asyé, mfiv, हारि, 
   {{0x29e003f9,0x1cac0327,0x67240175,0x78a4000d}},	//   iɗan_, _པིཀ_, cohj, lfiv, 
   {{0x6f08281f,0x7df006be,0xf484072d,0x00000000}},	//   vidc, bəsə, _پازی, --, 
   {{0x3ea40120,0x7df000ac,0x3f9c198f,0x461000f1}},	//   _abnt_, cəsə, ftuu_, _اوفر, 
   {{0x2ef4355a,0x6d4e17be,0x7f800691,0x3f9c0009}},	//   изир, _riaa, ملين, gtuu_, 
   {{0x68ee17bf,0x90c43419,0x6d4d13f4,0xc7b0011a}},	//   zkad, _әбде, _siaa, צבת_, 
   {{0x6d4c0eda,0x3f9e17c0,0x2908013f,0x6f080175}},	//   _piaa, atuu_, yiaa_, ridc, 
   {{0x27ea17c1,0x61e617c2,0x3f9c058a,0xe184013d}},	//   yyan_, ähle, btuu_, _төше_, 
   {{0xaed617c3,0xe3b801d3,0xbb58010a,0x29080108}},	//   _волш, _szűz_, лаях_, viaa_, 
   {{0x7f8217c4,0x8c6400d1,0x0e5402e8,0xe9f40022}},	//   _الون, _өтид, _съдя, апгь, 
   {{0xc330025f,0x290a17c5,0x3dc41529,0x6d4c954c}},	//   מוש_, tiaa_, _grnw_, _tiaa, 
   {{0x1cad0d57,0x27ea17c6,0x683000d7,0x00000000}},	//   _པིག_, tyan_, _lódž, --, 
   {{0x290a17c7,0x6724005c,0x27e80098,0x2ca803b9}},	// [3d4f0] riaa_, tohj, uyan_, _ibad_, 
   {{0x68ee17c8,0x27ea17c9,0x2d8cf498,0x290a17ca}},	//   skad, ryan_, orde_, siaa_, 
   {{0x27ea17cb,0x67240023,0x7df00213,0x290a17cc}},	//   syan_, rohj, təsə, piaa_, 
   {{0xd1242df0,0x2d8c00c6,0x672402f6,0x3f9c011f}},	//   _ذم_, irde_, sohj, ytuu_, 
   {{0x672402f6,0x2ca80327,0x7df000ac,0x98780a1e}},	//   pohj, _mbad_, rəsə, _בארט, 
   {{0x057617cd,0x3af40254,0x23280107,0x22a40107}},	//   _مارد, _käpa_, ъоли_, рудҳ, 
   {{0xb9140a28,0x2ca801a6,0x81c400e2,0x929007b5}},	//   thaḥ_, _obad_, ktēš, цајц, 
   {{0x3f9cc7f7,0x9f84036b,0x50a000d1,0x00000000}},	//   ttuu_, агид, قەمل, --, 
   {{0x2d8c1aa7,0x3f9c02f6,0x6d5c01e4,0x61e4002f}},	//   erde_, utuu_, ŭral, ählb, 
   {{0x2ca8a507,0x26c217ce,0x3f9e17cf,0x6ee435f5}},	//   _abad_, ndho_, rtuu_, _sòbr, 
   {{0x3f9d81a4,0xabc40184,0x26c00067,0xdc6a17d0}},	//   stuu_, ҙарҙ, idho_, канд_, 
   {{0xdfd016cb,0x1d0a17d1,0x4c800212,0x5bc400db}},	//   _ويا_, теми_, олюв, аймб, 
   {{0x5fa80316,0x3f64c43a,0x63ac0798,0xd1200118}},	//   _कहिल, _стеб, çanh, मवरण_, 
   {{0x2ca8014b,0x7a4000dd,0xcb6400a8,0x201c0327}},	//   _ebad_, játé, раре_, _ixwi_, 
   {{0x26c00882,0x00000000,0x00000000,0x00000000}},	//   ddho_, --, --, --, 
   {{0x6b88000a,0x213cd9f5,0x3f580016,0x5fa8b340}},	//   šega, _jhwh_, _kêu_, _कहाल, 
   {{0x81d80154,0x78a617d2,0x00000000,0x00000000}},	// [3d500] ডনি_, rfiv, --, --, 
   {{0x8ca40034,0x4b780a7c,0x00000000,0x00000000}},	//   ट्ठो, _שטיג, --, --, 
   {{0x98a410f6,0xc87c0e78,0x78a40175,0x3f580208}},	//   _кине, _soße_, pfiv, _lêu_, 
   {{0x26d217d3,0x9388368e,0x26c0058a,0x293c0150}},	//   _enzo_, вска_, adho_, _ﯞﻻﭖ_, 
   {{0x3f58001e,0x26c217d4,0x96740006,0xa3b400cd}},	//   _nêu_, bdho_, _выбі, _जनः_, 
   {{0x2d8c03d4,0x6700063f,0xe7b4010f,0x7a40013a}},	//   yrde_, ịkro, _פּרץ_, cáté, 
   {{0x55e45e7f,0x63c400fb,0x00000000,0x00000000}},	//   _товб, _һатҡ, --, --, 
   {{0x386217d5,0x2d8c0e3c,0x81412093,0x3f580208}},	//   ncir_, vrde_, ينون, _bêu_, 
   {{0x38600332,0x63c401af,0x00000000,0x00000000}},	//   icir_, _латҡ, --, --, 
   {{0xe4640008,0x38610b3a,0x50d4ba15,0x00000000}},	//   _þörf_, hcir_, _ھزار, --, 
   {{0x07340302,0x2d8cbdd0,0x39b8003a,0xfe200276}},	//   שאים_, urde_, _nōs_, жьян, 
   {{0xc20c0050,0x8fa40c56,0x3860017a,0x4fc4005b}},	//   _تٔم_, _ваде, jcir_, _вска, 
   {{0x81c4005f,0x0b8802e8,0x26c0058a,0xe7f80139}},	//   rtēš, ъсни_, ydho_, däşä, 
   {{0x39b8007f,0x81c4005f,0xdce00024,0x63ac0023}},	//   _bōs_, stēš, kslė, çani, 
   {{0x213e17d6,0x09045223,0x8e3c022e,0x7f3805d0}},	//   _yhwh_, ачам, chtа_, _שעוו, 
   {{0x3f5801dc,0xa855b6c0,0x6d581730,0x2ca80014}},	//   _yêu_, скач, _iuva, _ubad_, 
   {{0x6d5a17d7,0x00000000,0x00000000,0x00000000}},	// [3d510] _huva, --, --, --, 
   {{0x6d5a17d8,0x39b802e2,0x3860058a,0xdce000e2}},	//   _kuva, _fōs_, acir_, mplā, 
   {{0x6d5a17d9,0x24542cc0,0x26c00014,0x00000000}},	//   _juva, مناس, rdho_, --, 
   {{0x6d5a17da,0x00000000,0x00000000,0x00000000}},	//   _muva, --, --, --, 
   {{0x6d5a17db,0x6d5c0118,0x00000000,0x00000000}},	//   _luva, íraj, --, --, 
   {{0x21740e92,0x6d5800e4,0x3f58004d,0x6ab40165}},	//   буир, _ouva, _rêu_, nezf, 
   {{0x454a17dc,0x6d5c0115,0xbba40037,0xa5f8014b}},	//   _ачам_, ŭraj, _ओह्क, _севу_, 
   {{0x7f580d04,0x34940c60,0x80e4010b,0xd5a400f2}},	//   tquq, _маср, ргиң_, _دلفی, 
   {{0x6d581140,0x1fb40107,0xf4842377,0x4fe40395}},	//   _auva, ёсир, _фусн, ймън_, 
   {{0x6d5a17dd,0x5ea47677,0x7f5802d1,0x5f040a89}},	//   _buva, حمدل, rquq, ёзна, 
   {{0x6d59d82f,0x7f580309,0x609800f1,0x5fa8000d}},	//   _cuva, squq, _مناس_, _कहवल, 
   {{0x6d5a17de,0x00000000,0x00000000,0x00000000}},	//   _duva, --, --, --, 
   {{0xca3c76b9,0x6d580810,0x7f580194,0x60dc0108}},	//   _ﺑﺎﺭ_, _euva, qquq, ösmu, 
   {{0x6d5a17df,0x543800c8,0x19b80108,0x00000000}},	//   _fuva, טערא, лубь_, --, 
   {{0x5d840491,0x6d58014a,0x7e9400ec,0xf41805ac}},	//   _البل, _guva, _منڇر_, _তৰাৰ_, 
   {{0x97d8023a,0x38600129,0x00000000,0x00000000}},	//   льзу_, ucir_, --, --, 
   {{0x386217e0,0x6d5a17e1,0x00000000,0x00000000}},	// [3d520] rcir_, _zuva, --, --, 
   {{0x6d59f6dd,0x46e400db,0x00000000,0x00000000}},	//   _yuva, бдун_, --, --, 
   {{0x546a17e2,0x386035f5,0x65c002dd,0x77940133}},	//   гаем_, pcir_, мұра, _ژیرا, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7e6002d2,0x00000000,0x00000000,0x00000000}},	//   _ofnp, --, --, --, 
   {{0xa9c401d5,0xd62857c6,0x25bc01f4,0xcc3800df}},	//   _ازیو, _боге_, äylä_, נעסט, 
   {{0x613802d3,0x230800e3,0x06880150,0x00000000}},	//   _ብህዝባ, جتني_, _ﻗﯘﻧﯩ, --, 
   {{0x6d5a17e3,0x2d9800db,0x344801f0,0x00000000}},	//   _ruva, àrem_, _кӯли_, --, 
   {{0x6d5a17e4,0x00000000,0x00000000,0x00000000}},	//   _suva, --, --, --, 
   {{0x6d5a17e5,0xbcf4031c,0x257000db,0xf42801d5}},	//   _puva, _བཞུཊ_, _رۇۇس, _боғл_, 
   {{0x6d58358d,0x6ab4030a,0x00000000,0x00000000}},	//   _quva, vezf, --, --, 
   {{0x6d5a17e6,0x48d003d4,0x26f4012d,0x00000000}},	//   _vuva, _সত্ৰ, _इत्र_, --, 
   {{0x6d580b6f,0x103404b3,0x6ab406af,0xab3800d1}},	//   _wuva, _اعاج, tezf, ипму_, 
   {{0x6d5a17e7,0x6b880552,0x81a8015b,0x6ab4030a}},	//   _tuva, šego, খির_, uezf, 
   {{0x6d580194,0x1ea811f0,0x89341867,0x6ab400d7}},	//   _uuva, _خاني_, معرا, rezf, 
   {{0x6da80134,0x225000d0,0x00000000,0x00000000}},	//   _yɛan, _úzke_, --, --, 
   {{0x795801ec,0x46681c56,0x31b400cd,0x47dc00cc}},	// [3d530] _қияр_, грем_, ंबुध, _নেজী, 
   {{0xf7700a2c,0x7afc013a,0x00000000,0x00000000}},	//   عاق_, chrt, --, --, 
   {{0xfaf8e1e1,0xf8c400cd,0x00000000,0x00000000}},	//   _دريغ_, _लोकय, --, --, 
   {{0x67d5f304,0xdce00311,0x00000000,0x00000000}},	//   _дому, mplă, --, --, 
   {{0xc7c41bb8,0x44249e18,0xa2e404b3,0x754400d4}},	//   _усни, حراف, жолд, їніз, 
   {{0xf41805ac,0x00000000,0x00000000,0x00000000}},	//   _তৰহৰ_, --, --, --, 
   {{0xa3b44244,0x09d404c5,0xd24c16ef,0x97000131}},	//   _जनक_, সনকা, پني_, _تېلى, 
   {{0x7a402833,0x60ea17e8,0x1f6617e9,0xf4847c3f}},	//   _hátí, рмим_, оким, _нуун, 
   {{0xc44401ed,0x407402dd,0x7a40032e,0x02a404c2}},	//   _ایشن_, _ۇلاڭ_, _kátí, _грем, 
   {{0x9e5812d7,0x644c0024,0x5f040212,0x20080153}},	//   шриф_, žais, ізна, _žais_, 
   {{0x3af401e3,0x7a4001e1,0xd11c0092,0x5ed40066}},	//   _säpo_, _mátí, ቶቻቸው, متگز, 
   {{0x614000db,0x80d00154,0x00000000,0x00000000}},	//   _تۉبە, _ততক্, --, --, 
   {{0x316001e4,0xa2dc1d03,0x00000000,0x00000000}},	//   ĉize_, पाप्, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x13b00729,0xdc681086,0xdca40354,0x00000000}},	//   চিয়, _кайд_, _дайи, --, 
   {{0x28d005f9,0x00000000,0x00000000,0x00000000}},	//   हागि, --, --, --, 
   {{0x07a217ea,0x656801fa,0xc7a00139,0xd7080006}},	// [3d540] матн, _čeha, митк, анае_, 
   {{0x57b8038e,0xe8f80364,0xeb9000c8,0xdce000e2}},	//   _उनीह, алӣ_, _אָט_, kslī, 
   {{0xa2dc37e3,0x779400f1,0x00000000,0x00000000}},	//   पान्, _ډیزا, --, --, 
   {{0x136a17eb,0x86500165,0xbb3007d2,0x00000000}},	//   ашки_, _xaʔi, _ﺩﺍﻥ_, --, 
   {{0x56940046,0x1cac0135,0xba480055,0x7a40032e}},	//   _қаңт, _པིན_, _dhįų, _fátí, 
   {{0xcc38010f,0x00000000,0x00000000,0x00000000}},	//   בענט, --, --, --, 
   {{0x6f000241,0x00000000,0x00000000,0x00000000}},	//   _lábù, --, --, --, 
   {{0x89d80375,0xa78402f2,0x00000000,0x00000000}},	//   שחקי, _بشێو, --, --, 
   {{0x4364085a,0x63ac044e,0xcee8006c,0xe4742e80}},	//   _матн_, çant, لردن_, _хусэ, 
   {{0x0dc800f0,0x00000000,0x00000000,0x00000000}},	//   ауми_, --, --, --, 
   {{0x865802e4,0x00000000,0x00000000,0x00000000}},	//   ידיי, --, --, --, 
   {{0xcd0410f5,0x00000000,0x00000000,0x00000000}},	//   ічни, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x273c0109,0x7cf800b8,0x00000000,0x00000000}},	//   kìna_, _vãra, --, --, 
   {{0x7d280ffb,0x79a400d8,0x00000000,0x00000000}},	//   èssè, мрте, --, --, 
   {{0x273c06d9,0x6f0001e1,0x7cf80055,0x6600010e}},	//   dìna_, _fábù, _tãra, _ýlki, 
   {{0x6fbc4614,0xdce0054e,0x8b640244,0x00000000}},	// [3d550] ्टिं, splă, _بابم, --, 
   {{0x8ca41ab2,0x466834bb,0xc6680006,0x00000000}},	//   ट्रो, ррам_, ршае_, --, 
   {{0xbb3c010f,0xa9340266,0x49440064,0x00000000}},	//   _דעזי, _неош, _мэмб, --, 
   {{0xb8d00729,0x6fbc1df0,0x00000000,0x00000000}},	//   _টো_, ्टां, --, --, 
   {{0x7a400162,0x5fa8000d,0x00000000,0x00000000}},	//   _tátí, _कहइल, --, --, 
   {{0x273c0109,0xe2c800ec,0x00000000,0x00000000}},	//   bìna_, صوبو_, --, --, 
   {{0x78b401ed,0x00000000,0x00000000,0x00000000}},	//   _üdvö, --, --, --, 
   {{0xdce000de,0x00000000,0x00000000,0x00000000}},	//   rslī, --, --, --, 
   {{0x712416ac,0x4ac807b6,0x63ac0003,0x00000000}},	//   برول, ायाव, ħans, --, 
   {{0x443c00b4,0x91e404ce,0xcf402f23,0x00000000}},	//   _izu_, _itのr, нный, --, 
   {{0xc0e80092,0x00000000,0x00000000,0x00000000}},	//   ቅሳል_, --, --, --, 
   {{0x443c0dd4,0xee3a17ec,0x249c0042,0x6c84211f}},	//   _kzu_, өнө_, ngwm_, ولپم, 
   {{0x443c05be,0xafc001af,0x00000000,0x00000000}},	//   _jzu_, _аҡыд, --, --, 
   {{0x212c02ea,0x656801fa,0xbf341374,0x05b86d65}},	//   loeh_, _čehn, _برصغ, ईबाब, 
   {{0x6da8013f,0xd94410d6,0x00000000,0x00000000}},	//   _yɛam, зеви, --, --, 
   {{0x443e17ed,0x48e03f72,0x00000000,0x00000000}},	//   _ozu_, носв, --, --, 
   {{0x443c0516,0x9aa400db,0x00000000,0x00000000}},	// [3d560] _nzu_, _ىچسە_, --, --, 
   {{0x7dd401e1,0x00000000,0x00000000,0x00000000}},	//   _ẹse, --, --, --, 
   {{0x443c0521,0x20bc1b61,0x4a580375,0xdb040036}},	//   _azu_, ्याध, _לדיו, htkë, 
   {{0x273c0109,0x14c401f9,0x00000000,0x00000000}},	//   rìna_, _रोखण, --, --, 
   {{0x3f880998,0x273c06d9,0xca3c0131,0xdb040200}},	//   ácul_, sìna_, _ﺑﺎﺵ_, jtkë, 
   {{0x443c0334,0xd1b80228,0xcc38010f,0x02a00395}},	//   _dzu_, ماعا_, זענט, еръм, 
   {{0x443c0521,0xe2a80531,0x00000000,0x00000000}},	//   _ezu_, تانن_, --, --, 
   {{0x7c24006c,0x212c020c,0xf4843bdb,0x00000000}},	//   _oxir, goeh_, _زاری, --, 
   {{0x7c240023,0x2cb800e5,0x00000000,0x00000000}},	//   _nxir, vesd_, --, --, 
   {{0xa50849a6,0xe3b001d9,0x6264030c,0xa2dc01bc}},	//   _གཏོག_, _جرِ_, _قامق, पाण्, 
   {{0xac9617ee,0x7c2617ef,0x0b88010b,0x15e40150}},	//   манш, _axir, әсми_, _ﺍﻧﺪﻩ, 
   {{0x6600aa4a,0xcfa80133,0x22500419,0x00000000}},	//   _ülke, _هاتم_, _úzka_, --, 
   {{0x2eb40014,0x2cb801d3,0x5eb000eb,0x00000000}},	//   _ہێکھ_, resd_, জয়ে, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa2dc2bf1,0xb4bc0490,0x7c2416b8,0xbea43090}},	//   पात्, _असू_, _exir, _رهين_, 
   {{0x67d400d4,0x00000000,0x00000000,0x00000000}},	//   мобу, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3d570] --, --, --, --, 
   {{0x98b0005f,0xac9801d3,0x69c001bf,0x00000000}},	//   ībās_, _انکا_, æles, --, 
   {{0x25b823bb,0x2904068c,0xe8580835,0x00000000}},	//   تهاد_, èlas_, _манш_, --, 
   {{0xefdc0020,0xdb1401a8,0x443e17f0,0x00000000}},	//   _ንግድ_, _hryð, _pzu_, --, 
   {{0x249c0142,0x00000000,0x00000000,0x00000000}},	//   rgwm_, --, --, --, 
   {{0xd36c05d9,0xd12c3c45,0x212c0066,0xc87c002f}},	//   جهو_, یمو_, woeh_, _heß_, 
   {{0xd5ac0d62,0x525000ec,0x00000000,0x00000000}},	//   _نہٕ_, پنيء, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x248e17f1,0x443e17f2,0xa2dc00dc,0xca3c0046}},	//   _idem_, _uzu_, पाद्, _ﺑﺎﺱ_, 
   {{0xdd8a17f3,0x212c0098,0x00000000,0x00000000}},	//   обод_, soeh_, --, --, 
   {{0x57b8c725,0x802617f4,0x68fc00cc,0xd12c0214}},	//   _उन्ह, _کرام, _olsd, طمی_, 
   {{0xd00c9d03,0x31c40212,0x236c0200,0x248c01ef}},	//   الی_, _ясув, _ktej_, _jdem_, 
   {{0x6da80134,0xdb1402d2,0x3a3c0c5e,0x00000000}},	//   _yɛak, _bryð, _švp_, --, 
   {{0x68fc28dc,0x00000000,0x00000000,0x00000000}},	//   _alsd, --, --, --, 
   {{0x248c0b91,0x60c8003a,0x18a40120,0x00000000}},	//   _odem_, odem, мавм, --, 
   {{0xb4bc2413,0x03f0045e,0x248e17f5,0x7c2405f5}},	//   _असे_, _আইনী_, _ndem_, _txir, 
   {{0x236c0190,0x3af402f6,0x6128013d,0x7c240009}},	// [3d580] _ntej_, _läpi_, _gölş, _uxir, 
   {{0xa508003d,0x7bc617f6,0x86b00220,0x68fe17f7}},	//   _གཏུག_, _isiu, кәсі, _elsd, 
   {{0x60c82929,0x3af40254,0x95840a89,0xdce00139}},	//   kdem, _näpi_, флее, lulı, 
   {{0x799c1e8d,0x60c86041,0x30d800cc,0x06a00150}},	//   murw, jdem, _তত্স, _ﺍﯕﻘﯩ, 
   {{0x60c91205,0x836001d5,0x799c0042,0x48000064}},	//   ddem, نگلل, lurw, _апяв, 
   {{0x58fc025c,0xe9a82c26,0x7bc564fe,0x00000000}},	//   ྟིམས_, _بدین_, _msiu, --, 
   {{0x799e17f8,0x2f00002e,0x7764198f,0xd46800ee}},	//   nurw, _jòge_, lqix, _миве_, 
   {{0x60ca17f9,0x94d401e2,0xbb300150,0xdce00139}},	//   gdem, _تيرش, _ﺩﺍﻱ_, kulı, 
   {{0x61fc00ac,0x799e17fa,0x6fb40244,0x00000000}},	//   _əsli, hurw, رمدا, --, 
   {{0x799c8293,0x6da80134,0x41b063b8,0x60c8a121}},	//   kurw, _yɛah, хсәт, adem, 
   {{0x06940302,0x7bc617fb,0x90c41333,0x00000000}},	//   ודים_, _asiu, _обже, --, 
   {{0xb4bc0574,0x799e17fc,0x60ca17fd,0x00000000}},	//   _असो_, durw, cdem, --, 
   {{0xefdc02d3,0x765c349b,0x84600092,0x80a0009f}},	//   _ንግዲ_, _ogry, ድትሆን_, _شمون, 
   {{0x799e17fe,0xba8800aa,0x6d5c2d37,0x765c355f}},	//   furw, وږپه_, íras, _ngry, 
   {{0x799c0516,0x7bc617ff,0x257401e1,0x00000000}},	//   gurw, _esiu, _múlò_, --, 
   {{0x765e1800,0x6d5c01e4,0x86540023,0x00000000}},	//   _agry, ŭras, _ምሳኻት, --, 
   {{0x248c0139,0xdb1402d2,0x00000000,0x00000000}},	// [3d590] _rdem_, _tryð, --, --, 
   {{0x799e1801,0x6b9e1802,0x60ca1803,0x00000000}},	//   burw, musg, zdem, --, 
   {{0x236c1028,0x6b9e1804,0x60ca1805,0x7d242099}},	//   _stej_, lusg, ydem, _سفین, 
   {{0x69c61806,0x765c0142,0x6604030a,0x60c80175}},	//   _ishe, _egry, rzhk, xdem, 
   {{0x60c801e4,0xd004007b,0x00000000,0x00000000}},	//   vdem, _إل_, --, --, 
   {{0x69c40055,0x00000000,0x00000000,0x00000000}},	//   _kshe, --, --, --, 
   {{0x6b9e1077,0x248c03a2,0xe8bc0135,0xb284e78b}},	//   husg, _tdem_, _ཕྲོག, тычк, 
   {{0x69c61807,0x6b9e1808,0xdedc0092,0x6aa4007c}},	//   _mshe, kusg, ንዱን_, _lchf, 
   {{0x799c0223,0x6aa402d0,0x92540075,0x00000000}},	//   zurw, _ochf, маәт_, --, 
   {{0x60ca1809,0x69c6180a,0x4f201411,0x799c0230}},	//   sdem, _oshe, лдыб, yurw, 
   {{0x69c52c87,0x6280005f,0x60c80158,0xe29800fb}},	//   _nshe, _ielo, pdem, _маҡ_, 
   {{0x6282180b,0x799c0230,0x6e3e180c,0x619c0023}},	//   _helo, vurw, ürba, _ወርሓዊ_, 
   {{0x6282180d,0x799c00ca,0x6b9c0098,0x69c46460}},	//   _kelo, wurw, gusg, _ashe, 
   {{0x799e180e,0xb4bc4466,0x8fa017a0,0x00000000}},	//   turw, _अस्_, _саше, --, 
   {{0x4ef80375,0x69c40175,0x6b9c0112,0x2f1401e1}},	//   _מהסו, _cshe, ausg, _wùgè_, 
   {{0x6280644f,0x799c1d66,0x0d8006bb,0x69c4009a}},	//   _lelo, rurw, _слън, _dshe, 
   {{0x7bc51b84,0x63a801e0,0x6282180f,0x6b9c42bc}},	// [3d5a0] _usiu, _nqen, _oelo, cusg, 
   {{0x69c4044e,0xd7bc002e,0x06c401c0,0x799e1810}},	//   _fshe, _f胃nn_, нгуй_, purw, 
   {{0x63a8009a,0x1868c78c,0x8a78011a,0x00000000}},	//   _aqen, _нани_, _מאית, --, 
   {{0x62800cfd,0xe8100574,0x14261811,0x765c012d}},	//   _aelo, _ठेवा_, ндем, _wgry, 
   {{0x62821812,0x7de0016b,0x2368010f,0xcfac0046}},	//   _belo, mɑsu, ŭajn_, _ﺳﻴﺎﻗ, 
   {{0x62821813,0x765c7d19,0x80a000d1,0x00000000}},	//   _celo, _ugry, ۇمىن, --, 
   {{0x62821814,0x63a8013e,0x1aac0c58,0x29e002a8}},	//   _delo, _eqen, _ছোৱা, lɗar_, 
   {{0x62800037,0x8fe4234c,0x649800db,0x6600010e}},	//   _eelo, ецод, _отур_, _ülka, 
   {{0x62821815,0x93145cb5,0x92589010,0x21649c10}},	//   _felo, _كورش, _فشار_, нтөг, 
   {{0x6281db3b,0xbfb02834,0x91e421fa,0xb8ec031c}},	//   _gelo, احيت, _позе, _ྲི_, 
   {{0xac9a1816,0xe1a40022,0x6264030c,0x3ef401c6}},	//   وندا_, _алхҩ, _شالق, хнээ_, 
   {{0x62821817,0x6b9e1818,0xac180845,0x114800ee}},	//   _zelo, tusg, дому_, _эпей_, 
   {{0x62821819,0xc4d0011a,0x00000000,0x00000000}},	//   _yelo, אגר_, --, --, 
   {{0x6b9e181a,0x69c40240,0x6e94010a,0xb51c1cd2}},	//   rusg, _pshe, _рику, पचुप_, 
   {{0x318c012c,0xe8bc031c,0x6b9c97d2,0x3af4000d}},	//   něz_, _ཕྲུག, susg, _näpu_, 
   {{0x8d780020,0x61e40e78,0x00000000,0x00000000}},	//   ካባቢው_, ähli, --, --, 
   {{0xf772181b,0xa856181c,0x00000000,0x00000000}},	// [3d5b0] مال_, ткач, --, --, 
   {{0x6b8c0618,0xd7bc002e,0x00000000,0x00000000}},	//   _ivag, _t胃nn_, --, --, 
   {{0x6282181d,0x69c6181e,0x6b8c0162,0x20d000e4}},	//   _relo, _ushe, _hvag, _ỹimi_, 
   {{0x6282181f,0x23a82af5,0xd04400ac,0x6b8c01bf}},	//   _selo, túj_, şməl, _kvag, 
   {{0xa2dc0316,0x638801f0,0x00000000,0x00000000}},	//   पाल्, фреҳ_, --, --, 
   {{0xe6940598,0x6b8c00ca,0xe299a69f,0x00000000}},	//   _шигы, _mvag, фак_, --, 
   {{0x65941f5a,0x00000000,0x00000000,0x00000000}},	//   _јабу, --, --, --, 
   {{0x6b8c0357,0x62821820,0x00000000,0x00000000}},	//   _ovag, _welo, --, --, 
   {{0xdee40314,0x63a801e2,0x3f8806af,0x3af4002f}},	//   вопи, _uqen, écu_, _käpt_, 
   {{0x62800381,0x2bd4215d,0x9e64665a,0x6e2400b8}},	//   _uelo, दिना, ъвод, _śiba, 
   {{0x6b8e1821,0x9f940124,0x9d440798,0x00000000}},	//   _avag, хықә, кеод, --, 
   {{0x1fb40064,0x00000000,0x00000000,0x00000000}},	//   _аскр, --, --, --, 
   {{0xd9c80243,0xd0f40375,0x6d5c01e4,0xe8112b81}},	//   ाट्ट, _שמנת_, ŭrap, _ठेला_, 
   {{0x8140004b,0x53980677,0x9d2000eb,0x00000000}},	//   _شپږم, וישו, নতেন_, --, 
   {{0x6b8d2b2a,0x273c0051,0x00000000,0x00000000}},	//   _evag, mình_, --, --, 
   {{0xa3e00316,0x05100154,0xb6c80014,0x00000000}},	//   धमा_, িকুর_, کارے_, --, 
   {{0xccf00302,0x00000000,0x00000000,0x00000000}},	// [3d5c0] _ככה_, --, --, --, 
   {{0x29e00198,0x7de0013f,0x1dd400cd,0x00000000}},	//   rɗar_, sɑsu, धिपत, --, 
   {{0xe1e400b2,0x2f00068c,0x6b8c006f,0xd7f80116}},	//   _اڳ_, _jòga_, _zvag, чуң_, 
   {{0x3dc40354,0x318c012c,0x6b8c0022,0x273c0051}},	//   _msnw_, věz_, _yvag, hình_, 
   {{0x78a4072b,0x2bd40f90,0x8ca43f7e,0x00000000}},	//   mgiv, दिया, ट्टो, --, 
   {{0x78a43b35,0x318c00bc,0xc7b00375,0x00000000}},	//   lgiv, těz_, _דבש_, --, 
   {{0x41c001d9,0x78a40254,0x00000000,0x00000000}},	//   لٲوِ, ogiv, --, --, 
   {{0xd37016a2,0x6e940066,0x00000000,0x00000000}},	//   _نهر_, گلدا, --, --, 
   {{0x614403cc,0x656800e2,0xa2cc076e,0x53a400cf}},	//   دىيە, _čehi, _धोक्, _шааб, 
   {{0xb8f407e4,0xc270001f,0x00000000,0x00000000}},	//   _ེལ_, ከናወነ_, --, --, 
   {{0xe2a89cc8,0x420405c5,0x8698010f,0x00000000}},	//   _سالن_, _инфо_, וייז, --, 
   {{0x2f00068c,0x63ac002e,0xebc400c7,0xb38c0092}},	//   _dòga_, àang, гӡои, መጣውን_, 
   {{0x78a61822,0xfd440323,0xdbd40248,0xac9800e5}},	//   dgiv, рээн, _kùùr, ونگا_, 
   {{0x7f9000c2,0x00000000,0x00000000,0x00000000}},	//   _ташх, --, --, --, 
   {{0x3ea82b57,0xbb58030d,0x7e40010a,0x00000000}},	//   žitý_, тарх_, _кхъе, --, 
   {{0x78a61823,0xfd10131e,0x80b400dc,0x6b8c002b}},	//   ggiv, _وجي_, ्जये, _tvag, 
   {{0x6b8c0140,0x66b40bd6,0x2ca8453a,0x00000000}},	// [3d5d0] _uvag, лбау, _icad_, --, 
   {{0x78a40083,0x2d8c0af9,0xa5c4004e,0x00000000}},	//   agiv, osde_, лөбе, --, 
   {{0x2d8c6ff3,0x00000000,0x00000000,0x00000000}},	//   nsde_, --, --, --, 
   {{0x47f00724,0x2d8e1824,0x4ac86a60,0x00000000}},	//   _күбр, isde_, ायकव, --, 
   {{0xfd5802e3,0x2ca8007f,0xdbd40ca8,0x3cb000cc}},	//   _akaụ, _mcad_, _sùúr, _জোঁৱ, 
   {{0x6da8016b,0x0510015b,0x1dd41408,0xf6740244}},	//   _yɛat, িকের_, धिमत, _نافخ, 
   {{0x26c21825,0x27e80276,0x2d8c0d27,0xdbd40241}},	//   meho_, ţină_, jsde_, _dùùr, 
   {{0x26c21826,0x7afc0427,0x9fc800c7,0x00000000}},	//   leho_, zkrt, егиа_, --, 
   {{0x2d8c057b,0x02a4a19b,0xbe800075,0x02c421f3}},	//   esde_, _арем, ақли, _ақли_, 
   {{0x2f00067c,0x2ca80f85,0x1ce40327,0x9f04032f}},	//   _pòga_, _acad_, _ྫོང_, اودو, 
   {{0x273c0051,0x533400df,0x00000000,0x00000000}},	//   rình_, _ענען_, --, --, 
   {{0x26c21827,0x61e40e78,0xbbb400c7,0x00000000}},	//   heho_, ählu, аӡош, --, 
   {{0x78a411c0,0xfeb030cb,0x26c21828,0x69c003ee}},	//   vgiv, _көнь, keho_, çlen, 
   {{0x26c001aa,0x25a0009a,0x2ca800d8,0x9414008f}},	//   jeho_, kuhl_, _ecad_, אַלד_, 
   {{0xceb00302,0x78a61829,0x6608012c,0x00000000}},	//   _היו_, tgiv, _řekn, --, 
   {{0x2ca8015d,0x00000000,0x00000000,0x00000000}},	//   _gcad_, --, --, --, 
   {{0x7d06182a,0x6b884beb,0x3ce0007f,0x57494f72}},	// [3d5e0] _ilis, šegr, _iniv_, езам_, 
   {{0x78a6182b,0x26c00526,0x4b7804ae,0xc79400d1}},	//   sgiv, geho_, _ראיו, اپلا_, 
   {{0x7d06182c,0x78a487c9,0x07a000d1,0xd4f4005b}},	//   _klis, pgiv, _һаян, ляды, 
   {{0xd3880220,0xd76401d3,0x81c803d4,0x00000000}},	//   ейде_, _ماسٹ, ৰঙা_, --, 
   {{0x7d0461b5,0x26c039a2,0x6da8016b,0x20180419}},	//   _mlis, beho_, _yɛas, úsil_, 
   {{0x3942182d,0x7d040372,0x26c001a2,0x2bd400dc}},	//   llis_, _llis, ceho_, दिता, 
   {{0x7d06182e,0x2f00007f,0x76580030,0x3942182f}},	//   _olis, _bògn_, ľvys, olis_, 
   {{0x39421830,0x95b401af,0xbb300150,0xca2001ec}},	//   nlis_, _ирғә, _ﺩﺍﻑ_, _ﺸﻌﺏ_, 
   {{0x39421831,0x799c02d0,0x11e401ec,0x00000000}},	//   ilis_, hrrw, _әжем, --, 
   {{0x7d0416cb,0x3ce01529,0x3940e3af,0x2caa1832}},	//   _alis, _aniv_, hlis_, _scad_, 
   {{0x3941f3c3,0x073404ae,0x7d041605,0xc2780375}},	//   klis_, ראים_, _blis, _נראי, 
   {{0x26c001aa,0x39410bb6,0x7d061833,0x6c55f2a0}},	//   zeho_, jlis_, _clis, икну, 
   {{0x26c0a183,0x7d0400ae,0x2d8e1834,0x24980419}},	//   yeho_, _dlis, ssde_, _ôsme_, 
   {{0xe1f0066d,0x39421835,0x2d8c00cc,0x61e4007c}},	//   _اسے_, elis_, psde_, åhlg, 
   {{0x7d061836,0xe91800d6,0x26c21837,0x39421838}},	//   _flis, вові_, veho_, flis_, 
   {{0x26c02da1,0x39421839,0xe5e476d3,0x2ca80098}},	//   weho_, glis_, یزای, _ucad_, 
   {{0x26c2183a,0x6d4e183b,0x2a6000a2,0x00000000}},	// [3d5f0] teho_, _ihaa, _tghb_, --, 
   {{0x6d4e183c,0x3942183d,0x25a00112,0xe6940022}},	//   _hhaa, alis_, tuhl_, рижы, 
   {{0x26c2183e,0x3942183f,0x6d4c7644,0x2f00068c}},	//   reho_, blis_, _khaa, _lògo_, 
   {{0xba742814,0x26c01311,0x05740133,0xd5ac01d9}},	//   _پایت, seho_, ناڵد, بہِ_, 
   {{0xe284e827,0x26c00184,0x3af61840,0x68ee1841}},	//   алли, peho_, _käpp_, mjad, 
   {{0x68ec69df,0x6d4c003e,0xc6e40d30,0x86e401b9}},	//   ljad, _lhaa, _сімп, _сўмд, 
   {{0x68ec009f,0xa22800a7,0x6b9c0112,0x27ea1842}},	//   ojad, ъжка_, hrsg, lxan_, 
   {{0x68ec7020,0xe0d84afa,0x6d4d661b,0x2908023a}},	//   njad, тви_, _nhaa, nhaa_, 
   {{0x7d0404fb,0x27e80077,0x1f6406ed,0x68ec00d8}},	//   _rlis, nxan_, јком, ijad, 
   {{0x6d4e1843,0x7d051906,0x443e1844,0x27e8005a}},	//   _ahaa, _slis, _iyu_, ixan_, 
   {{0x1d081b10,0x39421845,0x6d4e1846,0xefc801c0}},	//   вени_, ylis_, _bhaa, влөл_, 
   {{0x6d4e1847,0x443e1848,0x68ee1849,0x9ed8151e}},	//   _chaa, _kyu_, jjad, хмүт_, 
   {{0x290a184a,0x6d4d6282,0x68ee184b,0xdee4519f}},	//   dhaa_, _dhaa, djad, _воли, 
   {{0x6d4c009d,0xbcf00115,0x64483545,0x443c04fd}},	//   _ehaa, _miɩi, _mzei, _myu_, 
   {{0x7d059149,0x6d4c01ab,0x907c001f,0xad2403e6}},	//   _tlis, _fhaa, _የቀበሌ_, _گروو, 
   {{0x68ec0579,0x06cc015b,0x6d4c0363,0x2908063f}},	//   gjad, রাফি, _ghaa, ghaa_, 
   {{0x3942184c,0x200e184d,0xad2404d3,0x96a8023b}},	// [3d600] rlis_, nzei_, _دروو, ккаб_, 
   {{0x3942184e,0x290a184f,0x5a943e4f,0x200c005a}},	//   slis_, ahaa_, _триф, izei_, 
   {{0x39413197,0x443e1850,0xd9461851,0x644806ed}},	//   plis_, _ayu_, _вени, _azei, 
   {{0x443e1852,0x290a1853,0xe8100c70,0x00000000}},	//   _byu_, chaa_, _ठेका_, --, 
   {{0x443e1854,0x00000000,0x00000000,0x00000000}},	//   _cyu_, --, --, --, 
   {{0x200c0dc6,0x2688ea80,0x644803ec,0xd1b81dc8}},	//   dzei_, _مخفي_, _dzei, ناعا_, 
   {{0x644a1855,0x910401b9,0x00000000,0x00000000}},	//   _ezei, ичид, --, --, 
   {{0x33480166,0x00000000,0x00000000,0x00000000}},	//   _өҗем_, --, --, --, 
   {{0x443e1856,0x2f0004cc,0x6d4c0129,0x52080451}},	//   _gyu_, _fògl_, _rhaa, _ڌيءُ_, 
   {{0x6d4c6ed6,0x00000000,0x00000000,0x00000000}},	//   _shaa, --, --, --, 
   {{0x6d4c6d78,0x3af40254,0x200c054e,0x29080009}},	//   _phaa, _räpp_, azei_, yhaa_, 
   {{0x2f00067c,0x443c0083,0x7c8421fa,0x41d000dc}},	//   _tògo_, _yyu_, журе, थिरस, 
   {{0x6d4c1682,0x68ec09a8,0x27e8011f,0x6b9c0ea0}},	//   _vhaa, vjad, xxan_, ursg, 
   {{0x6d4e1857,0x68ec0014,0x7ed00014,0x290800b0}},	//   _whaa, wjad, _وٲنا, whaa_, 
   {{0x6d4e1858,0x68ee1859,0x48a93521,0x06cc00bd}},	//   _thaa, tjad, ктам_, রামি, 
   {{0x27e82ec5,0x0ea40dba,0x29080108,0xbb300150}},	//   txan_, _खाँड, uhaa_, _ﺩﺍﻙ_, 
   {{0x68ee185a,0x290802f6,0x3af4000d,0xdb0402f0}},	// [3d610] rjad, rhaa_, _täpp_, stká, 
   {{0x29087361,0x27ea185b,0x68ec00c5,0x64480112}},	//   shaa_, rxan_, sjad, _rzei, 
   {{0x200c011c,0x29080a55,0xe29a185c,0xa9340064}},	//   zzei_, phaa_, ҳал_, _генш, 
   {{0xd126185d,0x443c00e4,0xe3b0007b,0x00000000}},	//   _رم_, _pyu_, كرت_, --, 
   {{0xe2f8005e,0xe29a185e,0x2f0004cc,0x27e8022f}},	//   леді_, гал_, _pògl_, qxan_, 
   {{0x057404d3,0xa348010b,0x443c0055,0x00000000}},	//   _نارد, ызла_, _vyu_, --, 
   {{0x256400a2,0x9f594b4b,0x3d1800ab,0xb5940b01}},	//   _bŷle_, ásí_, _पगले_, _мирш, 
   {{0x1dd40a28,0x26d00851,0xf4840228,0x6f1802d0}},	//   धिसत, _hazo_, _муун, _amvc, 
   {{0x443c7752,0x26d2185f,0x291804cc,0x64483be3}},	//   _uyu_, _kazo_, _mmsa_, _uzei, 
   {{0x26d21860,0x200db3a2,0x4f05964a,0x00000000}},	//   _jazo_, rzei_, йнын_, --, 
   {{0x26d21861,0x20ba1862,0xdb8401c6,0x200c00e5}},	//   _mazo_, _быль_, өгни, szei_, 
   {{0x26d00921,0x9f040133,0x1d080395,0x00000000}},	//   _lazo_, _گوتو, уеми_, --, 
   {{0x38c83135,0x26d0a8a1,0x0c2002e8,0x00000000}},	//   یاری_, _oazo_, змян, --, 
   {{0x291823db,0xcb64a99b,0xf21c00e1,0x5f04010b}},	//   _amsa_, саре_, _भेड़_, _ызла, 
   {{0x2d940153,0x00000000,0x00000000,0x00000000}},	//   _дрыс, --, --, --, 
   {{0x2918009f,0x225000d7,0x00000000,0x00000000}},	//   _cmsa_, _úzku_, --, --, 
   {{0x999800bc,0x1dd45a17,0x00000000,0x00000000}},	// [3d620] _typů_, धिवत, --, --, 
   {{0x2bd40157,0x26d00407,0x3f9c0ba7,0x2618000d}},	//   दिरा, _cazo_, iruu_, _येही_, 
   {{0x779401ed,0x26d00064,0xd4980798,0x00000000}},	//   _ڈیزا, _dazo_, грл_, --, 
   {{0x3f9c00ca,0x77940214,0x7fb4000d,0xc8dc0073}},	//   kruu_, _ویزا, _अहूँ, _पोपट, 
   {{0x26d21863,0xb11820d3,0x543400c6,0xc5ec004b}},	//   _fazo_, یقتا_, حرار, وړې_, 
   {{0x3f9c022f,0x0440005b,0x26d00064,0xdb0401bf}},	//   druu_, чечн, _gazo_, stkæ, 
   {{0xd13a1864,0x3f9c208d,0x29180162,0x70240154}},	//   лхи_, eruu_, _ymsa_, _পরেও_, 
   {{0x26d00912,0x06cc015b,0xf8a809bb,0x8594011a}},	//   _zazo_, রাণি, गलिय, _לדלג_, 
   {{0x26d21865,0x249800d7,0x3f6400d8,0x00000000}},	//   _yazo_, _ôsma_, бињо_, --, 
   {{0x8fa401d5,0x2d9800e4,0x00000000,0x00000000}},	//   _ҳаде, áreo_, --, --, 
   {{0xe1ec00b2,0x3f9c0a55,0x91e000fb,0x00000000}},	//   _لڳي_, aruu_, _хәлһ, --, 
   {{0x7f8000aa,0x8fa61866,0xc5f00302,0x3f9c0ba7}},	//   _کلون, _гаде, לדת_, bruu_, 
   {{0xa2dc0490,0x8ff803e6,0x06cc0154,0x92a800cc}},	//   पाच्, _حرار_, রাতি, গজী_, 
   {{0x9ff000cc,0x291815c0,0x00000000,0x00000000}},	//   _জেকব_, _smsa_, --, --, 
   {{0x26d00005,0xaa580107,0x00000000,0x00000000}},	//   _razo_, риву_, --, --, 
   {{0x26d01cdf,0xdb0401f4,0xac080137,0x00000000}},	//   _sazo_, etkä, _ەرگە_, --, 
   {{0x26d0172e,0xa6f421fe,0xdb04007c,0x00000000}},	// [3d630] _pazo_, озаш, ftkä, --, 
   {{0x26d001b9,0x00000000,0x00000000,0x00000000}},	//   _qazo_, --, --, --, 
   {{0x26d21867,0x693400d8,0xf1800150,0x00000000}},	//   _vazo_, _мноу, _едiм_, --, 
   {{0x26d07ab0,0x2918198f,0x3f9c208d,0x06cc0154}},	//   _wazo_, _umsa_, yruu_, রাধি, 
   {{0x62661868,0x26d21869,0x78b401ee,0x00000000}},	//   овла, _tazo_, _эйяф, --, 
   {{0xaaac00dc,0x00a00150,0xe1f8009b,0xfbb8011a}},	//   ञ्चक, _ﺍﻋﺘﻤ_, игл_, צפות_, 
   {{0x2906186a,0x06cc015b,0xe29800d1,0x659400f3}},	//   ūlau_, রাদি, гаһ_, _фабу, 
   {{0x3f9e186b,0xa2dc0303,0x00000000,0x00000000}},	//   truu_, पाङ्, --, --, 
   {{0xf486186c,0xa3ac0fe6,0x9f64010e,0x00000000}},	//   _хусн, _कमि_, _ötüp_, --, 
   {{0xdcc0ff88,0x3f9c0a55,0x00000000,0x00000000}},	//   षज्ञ, rruu_, --, --, 
   {{0x3254030d,0xdb0401e3,0x81c400ef,0x00000000}},	//   _евфр, ntkå, frēš, --, 
   {{0xa3ac76f8,0x81c40171,0x00000000,0x00000000}},	//   _कमा_, grēš, --, --, 
   {{0x1b4807d6,0xdb041611,0x92bc00fe,0x00000000}},	//   изми_, ytkä, োৰ_, --, 
   {{0xdee401f4,0x00000000,0x00000000,0x00000000}},	//   _фоки, --, --, --, 
   {{0xab183334,0x6aa02131,0x81c40171,0x00000000}},	//   сцях_, ólfa, brēš, --, 
   {{0x48e024c3,0x3c8401d5,0xef900345,0x00000000}},	//   мосв, _экиҳ, _تیید, --, 
   {{0xdb043468,0x00000000,0x00000000,0x00000000}},	// [3d640] ttkä, --, --, --, 
   {{0x4b20005b,0x6e2400cd,0x46e400db,0x00000000}},	//   _омыв, _śibi, одун_, --, 
   {{0x95840046,0xdb0400fd,0x0f3400df,0x00000000}},	//   ілде, rtkä, קרעט_, --, 
   {{0xd944a44d,0xd4c4007b,0xdb043bba,0x00000000}},	//   _феми, تغطي, stkä, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xf00401c0,0xdb04036e,0x00000000,0x00000000}},	//   үүжи, dukë, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x92a800eb,0x68340ca8,0x00000000,0x00000000}},	//   গজে_, _ẹdin, --, --, 
   {{0xc9500302,0xcec402e8,0xb62401ec,0x00000000}},	//   ומה_, ощни, _ﺩﻱ_, --, 
   {{0x7b100639,0xd1b001d3,0x00000000,0x00000000}},	//   _häuf, _ہیڈک, --, --, 
   {{0x9f581aac,0x7b1003fa,0x00000000,0x00000000}},	//   ásá_, _käuf, --, --, 
   {{0x71c4014b,0x00000000,0x00000000,0x00000000}},	//   _маҷҷ, --, --, --, 
   {{0xfc6400a7,0x00000000,0x00000000,0x00000000}},	//   дърн, --, --, --, 
   {{0x7b100639,0xdfd00451,0x9cc40014,0x00000000}},	//   _läuf, _سيٺ_, _ہمى۪, --, 
   {{0x59cc13b4,0xa95400d4,0xff0400d8,0x2d98009f}},	//   _हैदर, зкві, _фејк_, _اَبد_, 
   {{0xf770297d,0x2f0000a3,0x2ac0032e,0x25a00118}},	//   چال_, _sògh_, _bæbæ_, vrhl_, 
   {{0xf77152b7,0x466a0a74,0x7d0001e3,0x00000000}},	// [3d650] نال_, арем_, ömse, --, 
   {{0x3f7800c8,0x3f980393,0x00000000,0x00000000}},	//   יאמס, _æque_, --, --, 
   {{0x19380092,0xb0bc1db2,0xdb04007c,0xb288030d}},	//   _የቴሌኮ, ्जाग, utkå, _таiа, 
   {{0xa9341180,0xd36c00ec,0x00000000,0x00000000}},	//   _хемш, گهو_, --, --, 
   {{0x3b640014,0x316c00ef,0x27ec2347,0xdb04007c}},	//   _رێہہ, _audz_, _çen_, stkå, 
   {{0x65940364,0x216a0d78,0xc8a83f6f,0x00000000}},	//   _нагу, бики_, _छाँट, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x60e8013e,0xdb040200,0x00000000,0x00000000}},	//   смим_, tukë, --, --, 
   {{0x0fc001e0,0x4fe4761e,0x92a800eb,0x00000000}},	//   ейын, змын_, গড়ে_, --, 
   {{0x248d1cc9,0x00000000,0x00000000,0x00000000}},	//   _heem_, --, --, --, 
   {{0x9d450bf3,0x248c0218,0xc8a80034,0x236c036e}},	//   зенд, _keem_, _छांट, _huej_, 
   {{0x248cb881,0x236400f3,0x00000000,0x00000000}},	//   _jeem_, _hilj_, --, --, 
   {{0x80240491,0x248c0457,0x60c82252,0x236c0200}},	//   _برام, _meem_, meem, _juej_, 
   {{0x60ca186d,0xb06401d9,0x236c0200,0x5438010f}},	//   leem, _تھى۪, _muej_, מערא, 
   {{0x2366186e,0x6f18f3bb,0xe06002f2,0x00000000}},	//   _milj_, _بزنس_, _تێکی, --, 
   {{0x248e186f,0x60ca1870,0x5c8801a9,0x00000000}},	//   _neem_, neem, _уйим_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3d660] --, --, --, --, 
   {{0x60c8ae3d,0x7bc4013c,0xdaa80063,0xe8f80107}},	//   heem, _ipiu, _увод_, блӣ_, 
   {{0x248d1cc9,0x60ca1871,0x8af8011a,0xd94400f3}},	//   _beem_, keem, _הפיק, _неои, 
   {{0x248c0211,0x60c80a49,0x5fbc3156,0x00000000}},	//   _ceem_, jeem, ्बाल, --, 
   {{0x248c092e,0x645c0216,0x60c8982e,0x72d400d8}},	//   _deem_, _úsil, deem, долф, 
   {{0xff4401d9,0xa3ac05b3,0x92e800eb,0x00000000}},	//   _سخ_, _कमर_, মস্_, --, 
   {{0x248e1872,0x51840372,0x60c8058a,0x7b10002f}},	//   _feem_, чула, feem, _täuf, 
   {{0x7bc61873,0x248c7ea2,0x85980302,0xe01c0034}},	//   _opiu, _geem_, _לשלו, _बेहद_, 
   {{0x03a03c85,0xf07800d1,0xcee9808a,0x53a4030d}},	//   _пито, биқә_, مردن_, _хазб, 
   {{0x0dc81789,0xb17c00df,0x248c0211,0x0ca80075}},	//   буми_, _arĥe, _zeem_, әтни_, 
   {{0x248c0190,0x90880597,0x7bc4003a,0x60ca1874}},	//   _yeem_, _هناك_, _apiu, beem, 
   {{0x248c0457,0x60c80429,0x8c34013e,0x00000000}},	//   _xeem_, ceem, зомӣ_, --, 
   {{0x50580014,0x8ae402bf,0x00000000,0x00000000}},	//   _أشس_, півл, --, --, 
   {{0x7b661875,0x3af40108,0x00000000,0x00000000}},	//   етсе, _käpy_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa3ac19e5,0xbb5000b5,0x00000000,0x00000000}},	//   _कमल_, _comゲ_, --, --, 
   {{0x38361876,0x248d4311,0x00000000,0x00000000}},	// [3d670] ентр, _reem_, --, --, 
   {{0x248e1877,0x60ca1878,0x36d401f4,0x00000000}},	//   _seem_, zeem, ноур, --, 
   {{0x28f87724,0x248c01d4,0x7b100ade,0x60ca1879}},	//   _день_, _peem_, _säug, yeem, 
   {{0x69c4bda2,0x60c8011f,0xf65040bb,0xa8740961}},	//   _iphe, xeem, ائك_, _ілгі, 
   {{0x248e187a,0x60c804ba,0x855400e5,0xa3ac01f9}},	//   _veem_, veem, _ہیئر_, _कमळ_, 
   {{0x2244000f,0x248c04e6,0xcfd0009e,0x60ca187b}},	//   _pylk_, _weem_, ়মান, weem, 
   {{0x248d4797,0x60ca187c,0xc44400e5,0x00000000}},	//   _teem_, teem, _کیشن_, --, 
   {{0x69c6187d,0xe50886bf,0x60081363,0xa2cc0154}},	//   _mphe, _بيرو_, жним_, লাইও, 
   {{0x60ca187e,0xa2b406bb,0x9ea82069,0x338400d4}},	//   reem, _обач, овпа_, _зухв, 
   {{0x69c6187f,0x60c88432,0xd34410c4,0x80cc012d}},	//   _ophe, seem, _قینه_, _दसवे, 
   {{0x7bc61880,0x60c80108,0x5ca4fb90,0xf2c41d4d}},	//   _spiu, peem, минб, _ястн, 
   {{0x60c80548,0xcc900ae5,0x00000000,0x00000000}},	//   qeem, _ﻛﯩﺮﮔ, --, --, 
   {{0x69c40028,0x212c04cc,0x2bd48b95,0xd494011a}},	//   _aphe, mneh_, दिगा, וכרת_, 
   {{0x69c40055,0x9f0400cf,0xca6401a9,0x2fd800e5}},	//   _bphe, _زوبو, tijа, üggő_, 
   {{0x1a64036b,0xd944119e,0x00000000,0x00000000}},	//   بیدی_, деви, --, --, 
   {{0x212c06a3,0x629c03a2,0x6910037e,0x00000000}},	//   nneh_, _œsol, _nåed, --, 
   {{0x69c61881,0x7bc40b6f,0x36e40107,0x00000000}},	// [3d680] _ephe, _upiu, нбаҳ, --, 
   {{0x61e00368,0x0b400276,0xbc6801d9,0x1dd000e1}},	//   _orll, _инын, _وۅگن_, _तनात, 
   {{0x1869b8dd,0xc68c0014,0x00000000,0x00000000}},	//   _мани_, شِن_, --, --, 
   {{0x142402dd,0x00000000,0x00000000,0x00000000}},	//   мдем, --, --, --, 
   {{0x39421882,0x61e21883,0xdb0401bf,0x00000000}},	//   mois_, _arll, ftkø, --, 
   {{0x39421884,0xdb0401bf,0x69c402d0,0x00000000}},	//   lois_, gtkø, _yphe, --, 
   {{0xdecc0023,0xdee81954,0x00000000,0x00000000}},	//   እናን_, ህናን_, --, --, 
   {{0x39421885,0x212c011f,0x62840008,0xf4843413}},	//   nois_, gneh_, ðhor, _ساری, 
   {{0x6e9455c3,0x61e00076,0x044000c7,0x00000000}},	//   нипу, _erll, _аетн, --, 
   {{0x3940a952,0x212c0548,0x91e40137,0xdde00010}},	//   hois_, aneh_, _оозе, _šušl, 
   {{0x2d9a1886,0x6da8016b,0x212c0548,0x39400108}},	//   ére_, _yɛay, bneh_, kois_, 
   {{0x394001e4,0x2d980022,0x00000000,0x00000000}},	//   jois_, ĩre_, --, --, 
   {{0x69c61887,0x394006af,0x7ed07611,0x70bc0709}},	//   _sphe, dois_, رزیا, ्जील, 
   {{0x3f980393,0x27e400d0,0x00000000,0x00000000}},	//   _æqua_, _čln_, --, --, 
   {{0x39404aee,0xdb2410e5,0x6a2462a9,0x00000000}},	//   fois_, روفی, رفرم, --, 
   {{0x38c8009d,0x00000000,0x00000000,0x00000000}},	//   муун_, --, --, --, 
   {{0x6d5c00c5,0x7b100112,0x00000000,0x00000000}},	// [3d690] mmsa, _säue, --, --, 
   {{0x6d5c3400,0x5db00183,0x691001bf,0xf99000e5}},	//   lmsa, জবৰু, _såed, طبہ_, 
   {{0x69c4136f,0x39421888,0x6b8c0810,0x6d5e1889}},	//   _uphe, bois_, _hwag, omsa, 
   {{0x3942188a,0x00000000,0x00000000,0x00000000}},	//   cois_, --, --, --, 
   {{0xc3c856b0,0x6b8c0036,0x9878008f,0xecc0033f}},	//   تظام_, _jwag, _מארט, ष्यफ, 
   {{0x290a188b,0x6b8e188c,0x68fc016d,0x0576188d}},	//   lkaa_, _mwag, _hosd, _يازد, 
   {{0x614508fc,0x6b8e188e,0x68fc017a,0x63b80368}},	//   нека, _lwag, _kosd, stwn, 
   {{0x290a188f,0x68fc0477,0xdb0412e8,0x74a400f0}},	//   nkaa_, _josd, stkø, _ајфе, 
   {{0x6b8e1890,0x68e80086,0x2909fb3c,0x212c020c}},	//   _nwag, _òedu, ikaa_, rneh_, 
   {{0x64480295,0x6d5c0ba7,0x68fc047e,0x212c0548}},	//   _iyei, emsa, _losd, sneh_, 
   {{0x290a1891,0x6b8e1892,0xd12c55b2,0x6568023a}},	//   kkaa_, _awag, شمی_, _kieh, 
   {{0x6b8c51a9,0x65680135,0x68fc016d,0x39400129}},	//   _bwag, _jieh, _nosd, xois_, 
   {{0x656a1893,0x39421894,0x290801d9,0x7b100e78}},	//   _mieh, vois_, dkaa_, _räub, 
   {{0x656a1895,0x60d80309,0x68fc3e7c,0x6d5c0e14}},	//   _lieh, _hawm, _aosd, amsa, 
   {{0x39421896,0x68fe1897,0x1d0a1898,0x6b8e1899}},	//   tois_, _bosd, _неки_, _ewag, 
   {{0x65692680,0x68fc01ab,0x60d8f1f5,0x0d8000ee}},	//   _nieh, _cosd, _jawm, _ёлын, 
   {{0x07a132bd,0x6b8e189a,0x60d977e1,0x69c2189b}},	// [3d6a0] латн, _gwag, _mawm, çler, 
   {{0x60da189c,0x68fc16b8,0x290a189d,0x39404a85}},	//   _lawm, _eosd, akaa_, sois_, 
   {{0x3942189e,0x64480248,0x29080014,0x6b8c282c}},	//   pois_, _ayei, bkaa_, _zwag, 
   {{0x64480083,0x68fc08a5,0x00000000,0x00000000}},	//   _byei, _gosd, --, --, 
   {{0x656a189f,0xc950011a,0xf47c0240,0xdce000ef}},	//   _dieh, _תמר_, _ብዓረብ_, eplī, 
   {{0x644a18a0,0xb17c00df,0xb914002b,0x6568017a}},	//   _dyei, _arĥa, _ahaḿ_, _eieh, 
   {{0x656803a0,0x60d80139,0xe0d8009e,0xdb040036}},	//   _fieh, _bawm, থানভ, erkë, 
   {{0x60d80218,0x41701617,0x68fc6064,0x70bc28df}},	//   _cawm, داوس, _xosd, ्जेल, 
   {{0x60d85ccf,0x2d58002e,0xcf24007b,0x00000000}},	//   _dawm, léeg_, فردي, --, 
   {{0x6b8c1389,0x65680730,0x03a400b2,0x6d5c0218}},	//   _rwag, _zieh, _سگهو_, wmsa, 
   {{0x6b8e18a1,0xd344315b,0x7ff0335b,0xb9140055}},	//   _swag, _قیچه_, نسیا, bjaḥ_, 
   {{0x60d80198,0xc0d005d9,0x6b8c01f7,0x6568031c}},	//   _gawm, _ميمب, _pwag, _xieh, 
   {{0x6d5e18a2,0x290801f5,0x00000000,0x00000000}},	//   rmsa, vkaa_, --, --, 
   {{0x68fe18a3,0x7b1017da,0x6d5c03ac,0x6df4007b}},	//   _sosd, _räuc, smsa, _لكتا, 
   {{0x68fc047e,0x2908049b,0x60da18a4,0xa2a800af}},	//   _posd, tkaa_, _yawm, _घाघ्, 
   {{0x6b8c51a9,0x68fc0455,0x60d80de2,0x2d580036}},	//   _twag, _qosd, _xawm, déeg_, 
   {{0x2908423f,0x6b8e18a5,0x0ae81671,0x6568023a}},	// [3d6b0] rkaa_, _uwag, _فردي_, _rieh, 
   {{0x65680639,0x290a18a6,0xf1e0150d,0x00000000}},	//   _sieh, skaa_, पटान, --, 
   {{0x68fe18a7,0x644997d9,0xfb1c0375,0x2d58002e}},	//   _tosd, _syei, _מוזמ, réef_, 
   {{0x48a8169c,0x9f5801d3,0x68fc02d0,0xc68c0014}},	//   _этом_, ású_, _uosd, شِچ_, 
   {{0xc6a4a8c9,0x656947af,0x60d9db5f,0x6724014f}},	//   _први, _vieh, _rawm, pihj, 
   {{0x60d80db4,0xc6a618a8,0x65680003,0xa6c8193a}},	//   _sawm, _ярми, _wieh, _توسل_, 
   {{0x656a18a9,0x60d80455,0x647400db,0xf6e40024}},	//   _tieh, _pawm, _агбу, _сцян, 
   {{0xf994159d,0x60da18aa,0x50a000d1,0x91c0013d}},	//   ארק_, _qawm, لەمل, рәфл, 
   {{0x1fbc7039,0xf3ec29db,0xd0f01b76,0xa29400c0}},	//   ्बेड, _уң_, _आचरण_, _аазі, 
   {{0x73c40150,0x2d580036,0xf1540133,0xf0e800db}},	//   _حيكم, héed_, نکۆک, _ۋىلى_, 
   {{0x60d80218,0x00000000,0x00000000,0x00000000}},	//   _tawm, --, --, --, 
   {{0x715800d4,0x00000000,0x00000000,0x00000000}},	//   _зріс_, --, --, --, 
   {{0xc5fc00eb,0x00000000,0x00000000,0x00000000}},	//   ্পটা_, --, --, --, 
   {{0xd24c00cf,0x0b410946,0x8fa00395,0x00000000}},	//   _اچۇ_, инян, _таше, --, 
   {{0xcb6400a8,0x9500025c,0x1a6400f2,0x00000000}},	//   таре_, _ཚྭའི_, ضیحی_, --, 
   {{0x9d440209,0xb7b401c6,0xdb04000d,0x00000000}},	//   _шейд, лөгч, ltkü, --, 
   {{0xd9d00075,0x81d40eac,0xdb7801b9,0x00000000}},	// [3d6c0] _ھەرگ, ামি_, _ўсиш_, --, 
   {{0x068002bf,0x1a0400f3,0x00000000,0x00000000}},	//   игун, _апом, --, --, 
   {{0xda5801b9,0x3f8c0142,0x27ec025c,0x00000000}},	//   _юриш_, _lwgu_, _ġene_, --, 
   {{0x81d40eac,0xdbcc0174,0x00000000,0x00000000}},	//   ামা_, rðæt, --, --, 
   {{0xdce0c6da,0x07a00166,0x1fbc12eb,0xc0d001f3}},	//   nslı, _каян, ्बोड, ራንስ_, 
   {{0x02c08c75,0x8c1802e4,0x814000f1,0x301408ca}},	//   ийчо, ווני, ینون, ғдор, 
   {{0x3f8c7e91,0x82900145,0x00000000,0x00000000}},	//   _awgu_, شۇنچ, --, --, 
   {{0xb3940014,0x35c400c7,0xe3b001d9,0x7d00007c}},	//   _مُرژ, _иаҳҳ, _گرِ_, ömsl, 
   {{0x9408016b,0x24880086,0xc0900131,0xac94151e}},	//   _ɛbɛ_, ñame_, ججىت, һанш, 
   {{0xe3b0040b,0x2ef4016c,0x00000000,0x00000000}},	//   _درِ_, узор, --, --, 
   {{0xd174741d,0xac944130,0x00000000,0x00000000}},	//   _рызы, ланш, --, --, 
   {{0xd02618ab,0x4fc5132c,0x21751c3d,0x459800df}},	//   _имей, _аска, _суфр, וסטע, 
   {{0x7ff028ee,0x00000000,0x00000000,0x00000000}},	//   _نسوا, --, --, --, 
   {{0x6e94022e,0x00000000,0x00000000,0x00000000}},	//   _сику, --, --, --, 
   {{0xbea00640,0xdb2000e4,0x00000000,0x00000000}},	//   _тајк, ñuáv, --, --, 
   {{0x67d43df4,0x27ec0135,0xdb0400e4,0x00000000}},	//   лобу, _ġenb_, aukà, --, 
   {{0x60cc00e8,0xa854011c,0x00000000,0x00000000}},	// [3d6d0] _ñame, укач, --, --, 
   {{0xe694021f,0x59cc032c,0x24540131,0x1da8041c}},	//   الاد, _हैकर, ۇناس, _किमत, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb040af2,0x8728022e,0x00000000,0x00000000}},	//   luká, _жўва_, --, --, 
   {{0xe29a18ac,0x6ab40007,0x161c000d,0x00000000}},	//   хак_, ngzf, _येकर_, --, 
   {{0xb5940801,0xdb0400d0,0x068801ec,0x3d04000d}},	//   _висш, nuká, _ﺗﯘﻗﯩ, _लवलइ_, 
   {{0xdfd00597,0xd1e80092,0x46b00e49,0x00000000}},	//   ميع_, _ሆነች_, ुभवह, --, 
   {{0x6576045e,0xdb0400e4,0x9fe00154,0x44280139}},	//   _huzh, huká, মঙ্গ, _äc_, 
   {{0x657618ad,0xc1a400d8,0x799c0142,0x00000000}},	//   _kuzh, _ајди, ysrw, --, 
   {{0x80d8009e,0xdb0400c7,0x8e0401c6,0x00000000}},	//   ভাব্, juká, гнэв_, --, 
   {{0x657618ae,0xdb0618af,0x3074013d,0x00000000}},	//   _muzh, stkü, _кушс, --, 
   {{0x65745e39,0xb05401d9,0x00000000,0x00000000}},	//   _luzh, _پھٹت, --, --, 
   {{0x8f9a18b0,0x657407e4,0x682801d5,0x60cc0588}},	//   _װיקי, _ouzh, _mоdd, _ñamb, 
   {{0x98a618b1,0x6b9c0036,0x00000000,0x00000000}},	//   ливе, assg, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb040022,0x09e001d5,0x00000000,0x00000000}},	// [3d6e0] auká, _ғоян, --, --, 
   {{0x657618b2,0x7b100112,0x5638033a,0xdb040210}},	//   _buzh, _zäun, нџер_, rtkó, 
   {{0x316000ee,0xdb040210,0x00000000,0x00000000}},	//   ňizi_, stkó, --, --, 
   {{0x22500419,0x00000000,0x00000000,0x00000000}},	//   _úzky_, --, --, --, 
   {{0x65740156,0x06cc015b,0x48040209,0xb9d00092}},	//   _euzh, রাজি, _беян_, _ድሃ_, 
   {{0x65740007,0x00000000,0x00000000,0x00000000}},	//   _fuzh, --, --, --, 
   {{0x88d400bd,0x657618b3,0x691001e3,0x00000000}},	//   হারক, _guzh, _måen, --, 
   {{0x80a400cc,0x255800c0,0xa6500244,0x00000000}},	//   ক্স্, _аруэ_, _بێمت, --, 
   {{0xf47c0023,0x00000000,0x00000000,0x00000000}},	//   _ብሓሳብ_, --, --, --, 
   {{0x65758036,0x86340023,0xdb0401d3,0x515402dd}},	//   _yuzh, _ጸላእት, yuká, _өтеу, 
   {{0x10a401c0,0xfd7001c0,0xd18401f4,0x00000000}},	//   _биен, йлээ, _слей, --, 
   {{0xe3b0021a,0x25a40165,0xeb0c02c3,0x01f8011a}},	//   _درې_, _ælle_, हस्त_, _רפאל, 
   {{0x2ec40116,0x6b9c01c7,0x29d400d7,0xc0cc0023}},	//   _көнм, ussg, _sťa_, ባኦም_, 
   {{0x80d802f5,0xf1b9ddc6,0x0a681999,0x00000000}},	//   ভাণ্, _इमान, ерби_, --, 
   {{0x0dca18b4,0x06cc00fe,0x068802dd,0x8ad400e5}},	//   _чули_, ৰামি, _ﺗﯘﻟﯩ, نگھڑ_, 
   {{0x657618b5,0xdd9001d3,0xdb0400c7,0x9e640244}},	//   _ruzh, _بوٹ_, ruká, _ئاهن, 
   {{0x65742f1b,0x00000000,0x00000000,0x00000000}},	// [3d6f0] _suzh, --, --, --, 
   {{0x691017f9,0xb8ec01ad,0x76b80354,0xdb04035b}},	//   _gåen, _शॉ_, ллур_, puká, 
   {{0x4424c41a,0x7b10002f,0xa5d40395,0x00000000}},	//   گراف, _mäul, ржеш, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x65740327,0x321c00d7,0x00000000,0x00000000}},	//   _wuzh, ezvy_, --, --, 
   {{0xd2a44c04,0xa2e4059f,0xe3640139,0x00000000}},	//   акше_, рокд, шкли, --, 
   {{0x82345439,0xa4d400c0,0x7d0001e3,0x00000000}},	//   درشا, _кові, ömsk, --, 
   {{0xd24e18b6,0x6024010b,0xa23400c7,0x60e8013d}},	//   بنى_, идйа, льқә, тмим_, 
   {{0x02a464e1,0xa3a8000d,0xaf98009d,0x00000000}},	//   _брем, _खटि_, лтэх_, --, 
   {{0xdb040205,0x4f04004e,0x00000000,0x00000000}},	//   mukç, инын_, --, --, 
   {{0x628218b7,0x20d80262,0xc10001c0,0x9e58020a}},	//   _iflo, _афлэ_, _гүйл, ъриф_, 
   {{0x9d4402d9,0x00000000,0x00000000,0x00000000}},	//   ремд, --, --, --, 
   {{0x7b10002f,0x00000000,0x00000000,0x00000000}},	//   _fäul, --, --, --, 
   {{0x9f0541ec,0x3f9c0a55,0xf1dc0118,0x00000000}},	//   _خوتو, msuu_, _मनमन, --, 
   {{0x8a00415e,0xaf340133,0x00000000,0x00000000}},	//   озре, _دووژ, --, --, 
   {{0x3f9c022f,0xdb040274,0x00000000,0x00000000}},	//   osuu_, kukç, --, --, 
   {{0x3f9c3219,0x00000000,0x00000000,0x00000000}},	// [3d700] nsuu_, --, --, --, 
   {{0x7d04232c,0x3ce00457,0xdb040365,0x3f9c22a9}},	//   _hois, _haiv_, dukç, isuu_, 
   {{0x7d0618b8,0xfb5401d3,0x06880150,0x00000000}},	//   _kois, _پرکھ, _ﺗﯘﻛﯩ, --, 
   {{0xd4045026,0x7d04049b,0x6280d4ee,0x3f9e18b9}},	//   ияли, _jois, _aflo, ksuu_, 
   {{0x3ce00457,0x248a18ba,0x8454035f,0xd3940352}},	//   _maiv_, ñama_, һрәт_, рәбә_, 
   {{0x0cd01161,0x7d0618bb,0x3ce00211,0x69c000cf}},	//   _तस्म, _lois, _laiv_, àleg, 
   {{0x3f9c0ba7,0x7d04062c,0x7b1000a2,0xd138030d}},	//   esuu_, _oois, _näum, кхи_, 
   {{0x7d0618bc,0x3ce218bd,0x62810659,0x7b100e78}},	//   _nois, _naiv_, _eflo, _säul, 
   {{0x3f9c208d,0x6280015d,0xc48003f6,0xdb040205}},	//   gsuu_, _fflo, _флук, cukç, 
   {{0x7d0618be,0x7b1003fa,0xdb040254,0x00000000}},	//   _aois, _bäum, nukä, --, 
   {{0x7d0618bf,0x3f9c36c6,0x00000000,0x00000000}},	//   _bois, asuu_, --, --, 
   {{0x7d0618c0,0x3ce00070,0x3f9c198f,0x63ac0dfe}},	//   _cois, _caiv_, bsuu_, šane, 
   {{0x3ce00218,0x7d041711,0x1ee804d3,0x60ce18c1}},	//   _daiv_, _dois, _ڕووی_, _ñama, 
   {{0x6e9406d5,0x7d0402d0,0x7f8006c2,0x00000000}},	//   _الثا, _eois, _بلون, --, 
   {{0x3ce01509,0xba080801,0xe9180212,0xdb040037}},	//   _faiv_, ахте_, гові_, dukä, 
   {{0x7d05485d,0xa3e80243,0x00000000,0x00000000}},	//   _gois, यिम_, --, --, 
   {{0x6d4e18c2,0xc864311c,0x00000000,0x00000000}},	// [3d710] _ikaa, ртви, --, --, 
   {{0x8aa40ff1,0x6d4c020c,0xfbd02a93,0x7d040219}},	//   _трид, _hkaa, _آتي_, _zois, 
   {{0x3ce00218,0x6d4e18c3,0xe298d265,0x466884da}},	//   _yaiv_, _kkaa, қай_, трам_, 
   {{0x3ce00457,0x28f98f3b,0x81c400e2,0x7d78011a}},	//   _xaiv_, _семь_, nsēš, דנאו, 
   {{0x6d4c01c8,0x82e8031c,0x00000000,0x00000000}},	//   _mkaa, _ཡོདའ, --, --, 
   {{0xe19618c4,0x20d00208,0x3f9c0254,0x00000000}},	//   бриэ, _ại_, vsuu_, --, 
   {{0x6d4c3699,0xdb0c003e,0xd12c00f1,0xfd8c0150}},	//   _okaa, ékés, کمي_, _ﺒﺈﺫﻥ_, 
   {{0xe0da18c5,0x7b100730,0xba380375,0x6d4c0a49}},	//   уви_, _räum, יטוח_, _nkaa, 
   {{0x7d040731,0x7125041c,0x3f9c022f,0x7b100112}},	//   _rois, ترول, usuu_, _säum, 
   {{0x6d4e18c6,0x7d040192,0x443c026c,0x628001f0}},	//   _akaa, _sois, _ixu_, _uflo, 
   {{0x1d0a18c7,0x3ce00218,0x7d04b15e,0xdee4036b}},	//   гени_, _paiv_, _pois, _ҳоли, 
   {{0x7b84036b,0xd2540375,0xdb0401e3,0x27ec025c}},	//   оғид, _השעה_, ntkö, _ġenn_, 
   {{0x7d0618c8,0x3ce005d5,0x3f9c0ba7,0x212c0327}},	//   _vois, _vaiv_, qsuu_, mieh_, 
   {{0x212c0652,0x249c0070,0x6d4e18c9,0x7d0618ca}},	//   lieh_, hawm_, _ekaa, _wois, 
   {{0x7d0618cb,0x6d4c0418,0x249c0218,0x2d5a18cc}},	//   _tois, _fkaa, kawm_, méen_, 
   {{0x443c03be,0x212e18cd,0x6d4c0076,0x2d5a18ce}},	//   _oxu_, nieh_, _gkaa, léen_, 
   {{0x443c01e2,0x200e18cf,0xd7e80006,0xdb0426bb}},	// [3d720] _nxu_, nyei_, ымае_, tukä, 
   {{0x2d5a18d0,0x00000000,0x00000000,0x00000000}},	//   néen_, --, --, --, 
   {{0x94843b5f,0x8a840a81,0xdb0469a9,0x443c01f4}},	//   былд, _چھہِ_, ftkö, _axu_, 
   {{0x443c031c,0xdb1400e4,0x2d580036,0xf1f802f2}},	//   _bxu_, _ipyñ, héen_, یکاش_, 
   {{0x443c00e8,0xded402d3,0x98b0007f,0x00000000}},	//   _cxu_, ራስን_, nnyč_, --, 
   {{0x200c0099,0x2d5801c7,0x11d4007b,0xc34000a2}},	//   dyei_, jéen_, متعد, _ěŕé_, 
   {{0x443cbabe,0x8c380112,0xd1c801c6,0x00000000}},	//   _exu_, maße, уулд_, --, 
   {{0x443c025c,0x257004b3,0x0320010b,0x3ea40051}},	//   _fxu_, _قۇلس, ждән, _adnt_, 
   {{0x200c01ed,0xb368001f,0x8af800ac,0xc53802dd}},	//   gyei_, ችለውን_, ngəç, _сірә_, 
   {{0x6d4e18d1,0x6e980c60,0x2d581574,0x00000000}},	//   _skaa, швор_, géen_, --, 
   {{0xbd8411fc,0x1afc00fe,0xdb040254,0xacf8117e}},	//   ینین_, ঁসাই_, ntkõ, анну_, 
   {{0x7c8400c7,0xe1f001d3,0x4638010f,0x00000000}},	//   зуре, _کسے_, רעטע, --, 
   {{0x443c002e,0x2d581bce,0xce484990,0x00000000}},	//   _xxu_, béen_, _өзде_, --, 
   {{0xf1dc4614,0x6d5c019f,0xb17c010f,0xc87c03fa}},	//   _मनान, îrab, _arĥi, _maße_, 
   {{0x80d8015b,0xc3300375,0x8d840137,0x00000000}},	//   ভার্, לוש_, _уулд, --, 
   {{0x6d4e18d2,0x249c0070,0x2d8c068c,0x00000000}},	//   _ukaa, xawm_, mpde_, --, 
   {{0x2ca80004,0xe6982763,0xc76400d1,0x00000000}},	// [3d730] _idad_, иваш_, مائى, --, 
   {{0x47840220,0x00000000,0x00000000,0x00000000}},	//   _қымб, --, --, --, 
   {{0x443c02c4,0x249c01d4,0x248804d4,0x55c001e0}},	//   _sxu_, tawm_, ñamo_, мәтз, 
   {{0xa3b8012f,0xe4c400d4,0x57d001ec,0x00000000}},	//   لاتر_, ійли, _ﺟﻴﯩﺮ, --, 
   {{0x291813fd,0xe298a6e6,0x443c0113,0x03c4030d}},	//   _ilsa_, аал_, _qxu_, ссем, 
   {{0xded4693c,0x249c0218,0xdb0410ee,0x65940006}},	//   ራትን_, sawm_, stkö, _магу, 
   {{0x27ea18d3,0x572000f7,0xf1a8aca6,0x212c4324}},	//   lvan_, _تۉلك, مايه_, tieh_, 
   {{0x9f84ec1b,0x2caa18d4,0x27e806d9,0x443c01c4}},	//   огид, _ndad_, ovan_, _txu_, 
   {{0x29180649,0x27ea18d5,0x212d1098,0x2d5a18d6}},	//   _mlsa_, nvan_, rieh_, téen_, 
   {{0xde440020,0x27e80c86,0x2caa18d7,0x200c0810}},	//   _ማንኛው, ivan_, _adad_, ryei_, 
   {{0x291a18d8,0x27e8a7a9,0x22c4063f,0x2d5a18d9}},	//   _olsa_, hvan_, _ịkwu_, réen_, 
   {{0x2918009a,0x2ca80789,0xdc6814a8,0x27e8010f}},	//   _nlsa_, _cdad_, ианд_, kvan_, 
   {{0x2d5820ef,0x2ca80142,0x0c2017a1,0x27180037}},	//   péen_, _ddad_, дмян, _धतूर_, 
   {{0x2caa18da,0x27ea18db,0x291a18dc,0x2d5800e8}},	//   _edad_, dvan_, _alsa_, léel_, 
   {{0x6ee618dd,0x5d840050,0x81d402f5,0x2ca80334}},	//   _رسول, _بلبل, ামক_, _fdad_, 
   {{0x60ca18de,0x2d58002e,0xd94457c6,0x00000000}},	//   nfem, néel_, цеби, --, 
   {{0x27e940a4,0xd7040352,0x60c8009a,0x9b4402f2}},	// [3d740] gvan_, озаи, ifem, _ونبو, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8c380730,0x15b81411,0x27ea18df,0x2d58002e}},	//   raße, рызы_, avan_, kéel_, 
   {{0x2918070d,0x938a18e0,0x13e8084c,0x317801d3}},	//   _glsa_, аска_, имей_, _érzi_, 
   {{0x934618e1,0x9f58025a,0x2d580de2,0x03a0180b}},	//   онде, âsû_, déel_, дичо, 
   {{0x1da88bb5,0x60c8004e,0x65b00022,0x00000000}},	//   _किंत, efem, _ẽhet, --, 
   {{0xc324007b,0x00000000,0x00000000,0x00000000}},	//   تكون_, --, --, --, 
   {{0x63ac11f9,0x7bc40175,0xa1400022,0x00000000}},	//   šana, _oqiu, нҭхе, --, 
   {{0xe2f801d3,0xb0340454,0x96940241,0x00000000}},	//   _گولڈ_, яниш, _è̟sì, --, 
   {{0xcf240597,0x51f405d9,0x00000000,0x00000000}},	//   تربي, _وسار, --, --, 
   {{0x27e9f335,0xdb040022,0xbfa00208,0x8678011a}},	//   zvan_, bukú, _hiế, יריו, 
   {{0x27ea18e2,0xbfa001fb,0x00e40133,0xe468010a}},	//   yvan_, _kiế, _وتنی, _ешĕл_, 
   {{0x4ae40953,0xe1681e95,0xcf241e5a,0xfb8400c7}},	//   оўва, _اصله_, _ورتي, дысн, 
   {{0x291803a2,0x63bc1f53,0x3f645211,0x27e80455}},	//   _slsa_, _åsne, _дичо_, vvan_, 
   {{0x090618e3,0xaa5923a6,0x2d5800e8,0xaa0400bc}},	//   очам, сиву_, léem_, रहेछ_, 
   {{0x2caa18e4,0x8c380112,0x27e8cb1d,0x7bc40200}},	//   _udad_, raßb, tvan_, _fqiu, 
   {{0x27ea18e5,0x00000000,0x00000000,0x00000000}},	// [3d750] uvan_, --, --, --, 
   {{0x27ea18e6,0x00000000,0x00000000,0x00000000}},	//   rvan_, --, --, --, 
   {{0xcfc00eac,0x2d580036,0x27e996b0,0x05680120}},	//   ্টিন, héem_, svan_, ајди_, 
   {{0x69c42d2f,0xbfa001fb,0x79a477cf,0x291800a2}},	//   _iqhe, _biế, _юрье, _ulsa_, 
   {{0x27e9512b,0x60c80165,0xdb0400e4,0x00000000}},	//   qvan_, vfem, vukú, --, 
   {{0x2d593e03,0xdbd403b2,0xcfc000eb,0xfbb800d9}},	//   déem_, _møða, ্টান, קפות_, 
   {{0xa0a618e7,0xdbd403b2,0x60c9ce0b,0x2d58002e}},	//   пайд, _løða, tfem, téel_, 
   {{0x69c4014b,0x556013ef,0xb5c80014,0x65940117}},	//   _mqhe, _كۇلك, _گوہم_, _маҳу, 
   {{0x60ca18e8,0xc6200c58,0xf48401c0,0xe3e9ee47}},	//   rfem, _বঁটা_, _цусн, _دکان_, 
   {{0x69c401e2,0xef14004e,0x00000000,0x00000000}},	//   _oqhe, мүчө, --, --, 
   {{0x69c40218,0xdb040124,0x00000000,0x00000000}},	//   _nqhe, pukú, --, --, 
   {{0xa0c401c8,0xf1940212,0x00000000,0x00000000}},	//   _ريتو, _циць, --, --, 
   {{0x69c44b2a,0xefe80092,0x00000000,0x00000000}},	//   _aqhe, ሚቴው_, --, --, 
   {{0xaf480372,0xdee4039b,0x7e9400ec,0xdb0403b2}},	//   _وشول_, _хоки, _ڇنڇر_, nukø, 
   {{0x811c033f,0x2b0c000d,0x00000000,0x00000000}},	//   _बताओ_, _ठकरु_, --, --, 
   {{0xdbd403b2,0x17841768,0x63b800a2,0xa04c0240}},	//   _føða, згам, kuwn, _ምስንዳ, 
   {{0x69c4676c,0x4cb8011a,0x00000000,0x00000000}},	// [3d760] _eqhe, _המפג, --, --, 
   {{0x63b801f5,0x61e00200,0x00000000,0x00000000}},	//   duwn, _osll, --, --, 
   {{0x948618e9,0x49b001ec,0xceb0011a,0x00000000}},	//   пылд, _пәту, תיב_, --, 
   {{0xd94618ea,0x00000000,0x00000000,0x00000000}},	//   _хеми, --, --, --, 
   {{0x61e1bd8f,0x2d995017,0xf3f401d5,0x00000000}},	//   _asll, árez_, بتاک, --, 
   {{0xbfa001fb,0x00000000,0x00000000,0x00000000}},	//   _viế, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbfa0001e,0x80a01b56,0x2d5800e8,0x463800df}},	//   _tiế, ىمىن, téem_, _העלע, 
   {{0x61e0004e,0xb4d801ad,0x00000000,0x00000000}},	//   _esll, ़जी_, --, --, 
   {{0x61e00327,0x91e406ed,0xdbd406ea,0x27ec6b92}},	//   _fsll, _нозе, _røða, _šenk_, 
   {{0x2d998156,0xac9800b2,0x00000000,0x00000000}},	//   ère_, يندا_, --, --, 
   {{0xe80000bc,0x00000000,0x00000000,0x00000000}},	//   ोहमा_, --, --, --, 
   {{0xc10000ec,0x00000000,0x00000000,0x00000000}},	//   _سووي, --, --, --, 
   {{0x81cc015b,0x34c809b2,0x0e4400c0,0x00000000}},	//   শির_, रभुद, _нэйм, --, 
   {{0x48a84941,0x2d58002e,0x00000000,0x00000000}},	//   йтам_, néek_, --, --, 
   {{0xdb04002f,0xc6200154,0x00000000,0x00000000}},	//   erkä, _বুঝা_, --, --, 
   {{0xdb040165,0x37f8084c,0xfbd1af6a,0x00000000}},	// [3d770] iskê, петэ_, _یتی_, --, 
   {{0xf77045d7,0x94080134,0x00000000,0x00000000}},	//   هال_, _ɛbɔ_, --, --, 
   {{0x69c40944,0xc62000fe,0x00000000,0x00000000}},	//   _uqhe, _বুজা_, --, --, 
   {{0xa3e80037,0x00000000,0x00000000,0x00000000}},	//   यिल_, --, --, --, 
   {{0x2a6001a6,0xb38402dd,0xa2e401c6,0x870401a9}},	//   _hzhb_, еліл, долд, _еяве, 
   {{0x63ae18eb,0x6b8c01c8,0xe2980153,0xd7f808c3}},	//   šano, _mtag, цак_, _והשל, 
   {{0x6144016c,0x63ba117f,0x00000000,0x00000000}},	//   мека, suwn, --, --, 
   {{0x6b8e18ec,0x7b101196,0xdfd0007b,0x00000000}},	//   _otag, _häut, نيع_, --, 
   {{0x6b8e18ed,0x00000000,0x00000000,0x00000000}},	//   _ntag, --, --, --, 
   {{0x63aa18ee,0x3f88005f,0x5f0400d4,0x00000000}},	//   _iven, īcu_, єзна, --, 
   {{0x9d45b4d8,0x63a80008,0x797c00b0,0x46cc012c}},	//   денд, _hven, _kōwe, स्यह, 
   {{0x63a8008c,0x7b101196,0x272c03e3,0x00000000}},	//   _kven, _läut, _dönə_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x63a82776,0x6b8c00c6,0xa3b4000d,0x46cc00cd}},	//   _mven, _dtag, _झिन_, स्मह, 
   {{0x1d081515,0xdcb400bc,0x00000000,0x00000000}},	//   _меки_, _आएपछ, --, --, 
   {{0x63aa18ef,0x797c00b0,0x8c380e78,0xbd4400ec}},	//   _oven, _nōwe, maßn, _ڪنڊي, 
   {{0x63a8013f,0xcecc001e,0xd78803e6,0xc7a218f0}},	// [3d780] _nven, _mộng_, زناو_, китк, 
   {{0xe8f8016c,0xcecc01fb,0x0bb4011a,0xca440150}},	//   олӣ_, _lộng_, _קלים_, _ﺘﻌﺩ_, 
   {{0x8af800d9,0x00000000,0x00000000,0x00000000}},	//   _והיי, --, --, --, 
   {{0x63a80099,0x34c800dc,0xd874007b,0x00000000}},	//   _bven, रभेद, _ياحب, --, 
   {{0x136956f3,0x78a618f1,0x63a80129,0x6b8c01d5}},	//   ошки_, maiv, _cven, _xtag, 
   {{0x41c00014,0x25a80137,0x00000000,0x00000000}},	//   چٲوِ, زدۅي_, --, --, 
   {{0x63a94102,0x7b100730,0xda0c8687,0x4b340375}},	//   _even, _häus, सहित_, ורסל_, 
   {{0xcecc07ae,0x78a618f2,0x81cc00eb,0x00000000}},	//   _cộng_, naiv, শিং_, --, 
   {{0x63a80007,0xcecc004d,0x00000000,0x00000000}},	//   _gven, _dộng_, --, --, 
   {{0x78a618f3,0x7b100e78,0x63bc08fb,0x0440084c}},	//   haiv, _mäus, _åsna, _реун, 
   {{0x78a618f4,0x63a805b8,0x6b8c3003,0x7b10324c}},	//   kaiv, _zven, _stag, _läus, 
   {{0x9db40131,0x63a8007f,0xd0180798,0x00000000}},	//   رگىز_, _yven, _мфл_, --, 
   {{0x1014473f,0x06941c5c,0x78a5e0bd,0xfd4401c6}},	//   _تباد, _ﺟﯘﯕﮕ, daiv, тээн, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x78a41f4a,0x00000000,0x00000000,0x00000000}},	//   faiv, --, --, --, 
   {{0xa2d406ab,0x7b1012ce,0x6b8c0066,0x78a47e2b}},	//   _मॉन्, _bäus, _ttag, gaiv, 
   {{0x6b8e18f5,0xa7b8e17f,0xa6f40108,0x00000000}},	// [3d790] _utag, ялау_, нзаш, --, 
   {{0x63a81529,0x78a400c7,0x00000000,0x00000000}},	//   _rven, aaiv, --, --, 
   {{0x63a839c3,0xc984742b,0x78a618f6,0xa4d801ec}},	//   _sven, _تشخي, baiv, здеу_, 
   {{0x7b102305,0xe944179e,0x236402d2,0x78a400cd}},	//   _fäus, _سرجی, _shlj_, caiv, 
   {{0xcecc0016,0x27ec0a40,0xc7c4036b,0x87700220}},	//   _rộng_, _éen_, _ўсми, _ағаш, 
   {{0x63a8615e,0x04fc0154,0x00000000,0x00000000}},	//   _vven, ংসের_, --, --, 
   {{0x797c00b0,0x26c0a621,0x6d4401e4,0xeb0c00c5}},	//   _tōwe, mgho_, _ĉian, _सकैत_, 
   {{0x63aa18f7,0xfa780bd4,0x6008bbc9,0xa0c42764}},	//   _tven, ועות_, зним_, ريخو, 
   {{0x201800dd,0x63a812ed,0xdb0404e6,0x00000000}},	//   ási_, _uven, uskë, --, 
   {{0x26c218f8,0x78a40109,0x00000000,0x00000000}},	//   ngho_, zaiv, --, --, 
   {{0x78a40882,0x26c00115,0x0dc404b4,0x00000000}},	//   yaiv, igho_, нлэй_, --, 
   {{0xf0e804a9,0xdb040308,0x00000000,0x00000000}},	//   _يىلى_, mské, --, --, 
   {{0xdb040232,0x92e003d4,0x70a801c8,0x00000000}},	//   lské, ধাৰ_, _آههِ_, --, 
   {{0x7b1001c7,0x78a4004c,0x00000000,0x00000000}},	//   _räus, waiv, --, --, 
   {{0x78a618f9,0xdb0403c6,0xd944cffb,0x00000000}},	//   taiv, nské, ееви, --, 
   {{0xcbcc0154,0x48e0009b,0xdb04000d,0x5ba800d8}},	//   িয়েছ, лосв, lukü, _еким_, 
   {{0x63ac49ad,0x78a618fa,0x0df002d3,0xd1e002d3}},	// [3d7a0] šanj, raiv, ግደፍ_, _ዑደት_, 
   {{0x78a618fb,0xbd4400b2,0x46e400f7,0x9b4618fc}},	//   saiv, _سنڌي, ндун_, _سنجو, 
   {{0xdb040122,0x98a40354,0xb7c000cc,0x362401d3}},	//   jské, _пине, উবেট, خواہ, 
   {{0xdb0618fd,0x7b103f5b,0x5468005b,0xb8b401ec}},	//   dské, _täus, паем_, _шөгі, 
   {{0x394218fe,0xd4680026,0xdb04000d,0x00000000}},	//   mnis_, чиде_, kukü, --, 
   {{0x394218ff,0xdb040037,0x96540395,0x00000000}},	//   lnis_, jukü, _зъбч, --, 
   {{0x39421900,0xdb04000d,0x00000000,0x00000000}},	//   onis_, dukü, --, --, 
   {{0x6d4400df,0x00000000,0x00000000,0x00000000}},	//   _ĉiao, --, --, --, 
   {{0x93461901,0xdb0400e8,0x00000000,0x00000000}},	//   _знае, nukó, --, --, 
   {{0x39421902,0x09d404c5,0x80140597,0xdb061903}},	//   hnis_, হিতা, عزيز_, bské, 
   {{0x39421904,0xf1d4007d,0x07340375,0xdb0401d3}},	//   knis_, _दहिन, תאים_, cské, 
   {{0x39421905,0xd13096b4,0x809001ee,0x00000000}},	//   jnis_, _حمص_, _баїє, --, 
   {{0x39421906,0xa2d4007d,0x0b880801,0xdb0403f2}},	//   dnis_, _मॉड्, ясни_, jukó, 
   {{0x39421907,0x7b100e78,0x3f78010f,0x00000000}},	//   enis_, _säur, _זאגס, --, 
   {{0x39421908,0x26c00477,0xa93400f3,0x00000000}},	//   fnis_, vgho_, вевш, --, 
   {{0x39421909,0xca340069,0x67d6190a,0x691000d4}},	//   gnis_, naʝi_, кобу, _råes, 
   {{0xdb0435e4,0x6d5c02d0,0x00000000,0x00000000}},	// [3d7b0] zské, mlsa, --, --, 
   {{0x6d5e190b,0x3942190c,0x46680262,0x6a140124}},	//   llsa, anis_, прем_, _амоу, 
   {{0x3942190d,0x6d5de1c5,0xdb1003b2,0x26c1f9c9}},	//   bnis_, olsa, _úgáv, rgho_, 
   {{0xdb06190e,0x7b100086,0x26c001ab,0xd5ac0050}},	//   vské, _häup, sgho_, تہِ_, 
   {{0x68ee190f,0xdb0402f0,0xc7c400d4,0x00000000}},	//   mdad, wské, _ясни, --, 
   {{0xdb040122,0x290a1910,0x6d5c002f,0x978002f2}},	//   tské, ljaa_, hlsa, _ئیله, 
   {{0x797c04fe,0x2908dc19,0x68ec0192,0x00000000}},	//   _kōwa, ojaa_, odad, --, 
   {{0x68ee1911,0xdb040232,0x290a1912,0x63bc007c}},	//   ndad, rské, njaa_, _åsno, 
   {{0x65680117,0x797c02b1,0x68ec5f36,0xdea0006c}},	//   _iheh, _mōwa, idad, لیشی, 
   {{0x39421913,0x656a1914,0x68ec0876,0x6d5c7421}},	//   znis_, _hheh, hdad, elsa, 
   {{0xa3e83174,0x656a1772,0x39421915,0x8024004b}},	//   यिक_, _kheh, ynis_, _ګرام, 
   {{0x40840801,0x6d5c1cf3,0xbd0400bc,0x68eca19a}},	//   _чужб, glsa, kléř, jdad, 
   {{0x68ee1916,0x65680564,0xe8d8063f,0xdee400c7}},	//   ddad, _mheh, alị_, _аоли, 
   {{0x68ee1917,0x6d5c0c8c,0x68fe1918,0x6568062c}},	//   edad, alsa, _ansd, _lheh, 
   {{0x39421919,0x68ec0926,0x69100fac,0x18a40120}},	//   tnis_, fdad, _råer, кавм, 
   {{0x68ee191a,0x39400a55,0x6568013f,0xdcf40100}},	//   gdad, unis_, _nheh, _kiyč, 
   {{0xdb14066a,0x00000000,0x00000000,0x00000000}},	// [3d7c0] ðbót, --, --, --, 
   {{0x394200ce,0x65696c60,0x68ee191b,0x795403e6}},	//   snis_, _aheh, adad, _ڕێزا, 
   {{0x6448172e,0x3942191c,0x27ec0427,0x68ee191d}},	//   _axei, pnis_, _šent_, bdad, 
   {{0x656a191e,0x63b800a9,0x68ec01d9,0x3940016d}},	//   _cheh, frwn, cdad, qnis_, 
   {{0xded41772,0x656a191f,0x2d580036,0x06cc03d4}},	//   ያስን_, _dheh, méet_, ৰাজি, 
   {{0x6d44010f,0x2d5805ac,0x248c0205,0x62a00241}},	//   _ĉiam, léet_, _efem_, _àwó, 
   {{0x7b7801ec,0x00000000,0x00000000,0x00000000}},	//   _ﺼﺎﺤﺏ_, --, --, --, 
   {{0xf05402d3,0x656801f5,0x63b8015d,0x73c4abba}},	//   _ምስልም, _gheh, brwn, _бәке, 
   {{0xceb803f9,0x777c3df1,0x3a3c0010,0x765caa6c}},	//   _alƙa_, _kirx, _žvpl_, _hyry, 
   {{0x8d84e91b,0x765c0022,0xd36c2a8b,0xb9140055}},	//   кумд, _kyry, _بۇت_, _ekaḿ_, 
   {{0x68ee1842,0xc0e401ed,0x2d5801c7,0x777c5b7f}},	//   ydad, رفین_, kéet_, _mirx, 
   {{0x65680023,0x6d5c058a,0x68ec0009,0x4080004e}},	//   _xheh, ulsa, xdad, _кушб, 
   {{0xaed61920,0x765c000f,0x68ec3453,0x2d581bce}},	//   _болш, _lyry, vdad, déet_, 
   {{0x68ec1741,0x68fc00b5,0x765c00ad,0xdce400e2}},	//   wdad, _snsd, _oyry, rmkā, 
   {{0x987c27a7,0x765c0158,0xba745821,0x290801f4}},	//   _açık_, _nyry, لافت, tjaa_, 
   {{0x63ad6be8,0x68ee1921,0x797c02b5,0xfd480724}},	//   šani, udad, _pōwa, _үзәк_, 
   {{0x68ec748d,0x290802f6,0x777c01a9,0x765cdccc}},	// [3d7d0] rdad, rjaa_, _birx, _ayry, 
   {{0x656a1922,0x68ee1923,0x2624059f,0x00000000}},	//   _sheh, sdad, лчеҳ, --, 
   {{0x65680032,0xfdf800e1,0x6d4400df,0x777c0009}},	//   _pheh, एमएस_, _ĉiaj, _dirx, 
   {{0x99f4025f,0x2d5807ea,0x765e1924,0x797c02b5}},	//   _עזרה_, mées_, _dyry, _tōwa, 
   {{0xd005abd3,0x2d584aee,0x777d6fd1,0x34383e1a}},	//   _ال_, lées_, _firx, پسند_, 
   {{0xded41e38,0x656801f5,0xdcf4007f,0x00000000}},	//   ያትን_, _wheh, _riyč, --, 
   {{0x65680184,0x2d580231,0x765c010b,0xdee401a9}},	//   _theh, nées_, _gyry, қони, 
   {{0xd09c01e4,0x6448004e,0x069401ed,0x11d4007b}},	//   _eŭɾo, _txei, _ساڑھ, اوية_, 
   {{0x2d5807ea,0x96c802ab,0xa2941cd0,0xdca400d1}},	//   hées_, स्कॉ, _базі, һани, 
   {{0xd24e1925,0x3ea001ed,0x777c0014,0x64440790}},	//   _کچه_, újt_, _xirx, şhis, 
   {{0xdca61926,0x20d402dd,0x62821927,0x5ca4322b}},	//   лани, _білс, _iglo, линб, 
   {{0x2d5807ea,0xed580419,0x00000000,0x00000000}},	//   dées_, tuľa_, --, --, 
   {{0x6aa4016b,0x71700075,0x00000000,0x00000000}},	//   _behf, _بۇيا, --, --, 
   {{0x2d580129,0x90880092,0x00000000,0x00000000}},	//   fées_, _በታዳጊ_, --, --, 
   {{0x2d58ff0c,0xcb640108,0x00000000,0x00000000}},	//   gées_, уаре_, --, --, 
   {{0xa2d402ab,0xbae42b1b,0x8d90027d,0x28940063}},	//   _मॉस्, মাইছ, _اليش, ијус, 
   {{0x96940faa,0x765e1928,0x5b340276,0xb344008e}},	// [3d7e0] греш, _syry, _бэну, _hiçş, 
   {{0x2d5a1929,0x62800214,0xd6282bbd,0x6aa4002f}},	//   bées_, _nglo, нозе_, _gehf, 
   {{0x777c172e,0x2d5a192a,0xd6e4015b,0x779468be}},	//   _virx, cées_, নালয, _چیرا, 
   {{0x79540272,0x6d4401e4,0x77940050,0x14247a7a}},	//   _ئێرا, _ĉiak, _نیرا, лдем, 
   {{0xf77800c7,0x04140011,0xd4340b24,0x765c37b0}},	//   _аҧа_, _দেবী_, دعاب, _wyry, 
   {{0x628007ab,0x765c837c,0x00000000,0x00000000}},	//   _cglo, _tyry, --, --, 
   {{0x154406ed,0x84540166,0x00000000,0x00000000}},	//   _бевм, крәт_, --, --, 
   {{0x6282192b,0xb11433cc,0xdb04002d,0x6d5c00bc}},	//   _eglo, рмиш, nskâ, ůraz, 
   {{0x62800334,0x64440205,0x00000000,0x00000000}},	//   _fglo, şhir, --, --, 
   {{0x2d5807ea,0x62800327,0x2dd40410,0x248800d7}},	//   yées_, _gglo, ажор, ľame_, 
   {{0x6aa405da,0x2d5a0c1a,0x248a192c,0x00000000}},	//   _rehf, xées_, žame_, --, 
   {{0xd9fc069f,0xd174b0d5,0xac181830,0x6280098d}},	//   _उपजत_, _сызы, вому_, _zglo, 
   {{0x2d5a192d,0x217400fd,0xafc40075,0xc0d0001f}},	//   féer_, _туфр, _тәйй, ያንም_, 
   {{0x2d5820ef,0x6e9401d5,0x00000000,0x00000000}},	//   tées_, _тику, --, --, 
   {{0xaa5a0a74,0x00000000,0x00000000,0x00000000}},	//   тиву_, --, --, --, 
   {{0x2d5820ef,0x38c805f5,0x7db042f4,0x051c00fe}},	//   rées_, луун_, _اصوا, _ভদ্ৰ_, 
   {{0x2d5a192e,0x0ba401d5,0x7d7c010f,0x00000000}},	// [3d7f0] sées_, _ёшим, _אנהו, --, 
   {{0x2d5807ea,0x00000000,0x00000000,0x00000000}},	//   pées_, --, --, --, 
   {{0xdc54168d,0x636c00d2,0x36d40108,0x00000000}},	//   _مریک, lúng, сохр, --, 
   {{0xded41772,0xa4d40212,0x6280015d,0xdcf400b8}},	//   ያትና_, роді, _sglo, _kiyā, 
   {{0xe3740a52,0x0b580023,0x00000000,0x00000000}},	//   алды, _ሃብተማ, --, --, 
   {{0x27f80129,0x87040006,0x53a000db,0x00000000}},	//   _irsn_, _сяме, تۅكك, --, 
   {{0x22480801,0x636c0077,0xf18c0131,0x4ca80011}},	//   ъпки_, húng, _ﻗﺎﻧﯘ, _কানু, 
   {{0xa2d403f3,0x636c00e4,0x00000000,0x00000000}},	//   _मॉर्, kúng, --, --, 
   {{0xa2cc37cc,0xdcf4002b,0x00000000,0x00000000}},	//   _साप्, _niyā, --, --, 
   {{0xe80c19e5,0x6282192f,0x04c400f1,0x249c0042}},	//   _सपना_, _uglo, _جوړي_, lbwm_, 
   {{0x60b4a55b,0x31241c13,0x96c80d79,0x00000000}},	//   _نمائ, рдөг, स्टॉ, --, 
   {{0x63ac01fa,0x2074792b,0x00000000,0x00000000}},	//   šanu, _кулё, --, --, 
   {{0x60cc0309,0x2d5801bf,0x5f0401f4,0x00000000}},	//   _ñamq, téer_, _взла, --, 
   {{0xa2cc012d,0x00000000,0x00000000,0x00000000}},	//   _साफ्, --, --, --, 
   {{0x2d5a1930,0xa2ccc2fc,0x20180793,0xdb040254}},	//   réer_, _सान्, äsif_, kukö, 
   {{0x3ea61931,0x00000000,0x00000000,0x00000000}},	//   _hent_, --, --, --, 
  
   {{0x3ea61932,0xdb04002d,0x00000000,0x00000000}},	// [3d800] _kent_, rskâ, --, --, 
   {{0x3ea42f2f,0x75f001d3,0x00000000,0x00000000}},	//   _jent_, józá, --, --, 
   {{0xc7740cab,0xdb04032e,0x00000000,0x00000000}},	//   рттө, fukö, --, --, 
   {{0xf1b80184,0x24880054,0x0b580023,0x3ea475c6}},	//   ҫҡа_, ñamp_, _ሃብታማ, _lent_, 
   {{0xf3f87626,0x4ca802f5,0x3ea4030a,0xc32c01d9}},	//   ыңа_, _কামু, _oent_, ڈٕن_, 
   {{0x8c18025f,0x3ea4009a,0xc7a21933,0x07a08740}},	//   כוני, _nent_, _фирк, _фарн, 
   {{0xdcc42ecf,0x645c0162,0x99600171,0x00000000}},	//   _वांछ, _øsin, _mūžs_, --, 
   {{0x3ea455e9,0x00000000,0x00000000,0x00000000}},	//   _aent_, --, --, --, 
   {{0x3ea61934,0x636c00d2,0x5065b868,0x80d000db}},	//   _bent_, fúnd, штка, تۅنچ, 
   {{0x11d400d6,0x636d7d3e,0x3ea61935,0xe3b001d3}},	//   _відр, gúnd, _cent_, _ڈرے_, 
   {{0x63ae1936,0xd18401c6,0xe1d800ec,0x00000000}},	//   šant, _тлей, _مُلڪ_, --, 
   {{0x3ea40a40,0x60cc0784,0x22143cd7,0xdcf40055}},	//   _eent_, _ñamp, _уфур, _piyā, 
   {{0x3ea61937,0xa3c80490,0x6f94007b,0xe0843cc6}},	//   _fent_, लंय_, _التض, _اجمي, 
   {{0x3ea61938,0x636c003a,0xe1f001d3,0xdcf400b8}},	//   _gent_, cúnd, _بسے_, _viyā, 
   {{0x0dc8566d,0x49746f04,0xc986014d,0xfe043cc6}},	//   _рули_, لدرآ, руги, _نقوي_, 
   {{0x3ea40156,0xdb04000d,0xfd10007b,0x92e00154}},	//   _zent_, dukõ, _يجي_, ধায়_, 
   {{0x3ea40165,0x636c00d0,0x2d8c0455,0x00000000}},	// [3d810] _yent_, lúne, lqde_, --, 
   {{0x2caa1939,0x321c0306,0x00000000,0x00000000}},	//   _head_, kyvy_, --, --, 
   {{0xa3c805ba,0x368803cc,0xb17c01e4,0x59704d2f}},	//   लून_, рсун_, _esĥi, تگیز, 
   {{0x67043874,0x1e1c1ee0,0x2fc4063f,0x5e78008f}},	//   राहक_, ስልጣና, kumg_, אָנד, 
   {{0x75f001ed,0x37e402d5,0xdd000841,0x2caa193a}},	//   tózá, _доўг, šući, _mead_, 
   {{0x27ea193b,0x2caa193c,0xa5c4010b,0x85b8030f}},	//   mwan_, _lead_, _гөде, _لارس_, 
   {{0x27ea193d,0x3ea43d4a,0x8c38002f,0xe3c400eb}},	//   lwan_, _rent_, maßu, _শৈশব, 
   {{0x3ea6193e,0x27e8022f,0x2ca8679d,0x60e8084c}},	//   _sent_, owan_, _nead_, умим_, 
   {{0x3ea40903,0x27ea193f,0xbe80036b,0x33944965}},	//   _pent_, nwan_, оқли, _матё, 
   {{0x27ea1940,0x3ea40200,0x00000000,0x00000000}},	//   iwan_, _qent_, --, --, 
   {{0x2ca8b0e7,0x27ea1941,0x2d8c0097,0x62880421}},	//   _bead_, hwan_, gqde_, āloā, 
   {{0x3ea547a0,0x2ca865f2,0x27ea1942,0x9d4476d0}},	//   _went_, _cead_, kwan_, семд, 
   {{0x27ea1943,0x2008180f,0x442c01a6,0xdca400d1}},	//   jwan_, _çai_, nzg_, _һайи, 
   {{0x60ca1944,0x27ea1945,0x1a64030f,0xdb0402d2}},	//   lgem, dwan_, ییکی_, fská, 
   {{0x2ca80afe,0xdca40075,0xa3c80073,0x9db8008e}},	//   _fead_, _лайи, लंड_, _сылу_, 
   {{0x27ea1946,0xdb04012d,0xcdb4011a,0xf18c02dd}},	//   fwan_, trkó, _הפקה_, _ﻗﺎﺴﻡ_, 
   {{0x7d061947,0xa3c81533,0x27e82b92,0x60c82bad}},	// [3d820] _inis, लूम_, gwan_, igem, 
   {{0x60c80732,0x7d040306,0x00000000,0x00000000}},	//   hgem, _hnis, --, --, 
   {{0x7d04038f,0x27ea1948,0xdb0401ed,0x60c8017a}},	//   _knis, awan_, cská, kgem, 
   {{0x27e803f9,0x7d040327,0x60c801a4,0x799c0142}},	//   bwan_, _jnis, jgem, mprw, 
   {{0x60ca1949,0xd87400f1,0xd7f0007b,0x333c0327}},	//   dgem, _دادب, _عكس_, tivx_, 
   {{0x60c801f7,0x00000000,0x00000000,0x00000000}},	//   egem, --, --, --, 
   {{0x248805a1,0x7d06194a,0xd62a194b,0x60c81196}},	//   žama_, _onis, _сове_, fgem, 
   {{0xa4902c6c,0x60c894fc,0x7d04013f,0x50641075}},	//   _قیمت, ggem, _nnis, йтпа, 
   {{0x2caa194c,0x03a02218,0xdb048ecc,0xdfcc00ec}},	//   _read_, _нито, mskæ, نڊو_, 
   {{0x7d06194d,0x2caa194e,0xdb053dea,0x60c803ac}},	//   _anis, _sead_, lskæ, agem, 
   {{0x2ca8007d,0x27e80ac5,0xa2cc1c9e,0x780401ad}},	//   _pead_, zwan_, _सात्, रमुक_, 
   {{0xac8400f7,0x867802e4,0x2d58084c,0x27e80986}},	//   өгүл, טריו, римь_, ywan_, 
   {{0xaa9405f5,0x2ca800c5,0x5b440092,0x00000000}},	//   жигч, _vead_, _የህዝቡ, --, 
   {{0x2ca80142,0xa3c801f9,0x00000000,0x00000000}},	//   _wead_, लंत_, --, --, 
   {{0x797c0053,0x2caa194f,0x428c044e,0x27e80a4d}},	//   _kōwh, _tead_, _ሓጢኣት_, wwan_, 
   {{0x7d061950,0x8c38002f,0x27e8eef1,0xa8980139}},	//   _gnis, faßt, twan_, ркау_, 
   {{0x636d19c7,0xc8640d5c,0x6d4c22a9,0xdb04037e}},	// [3d830] núnc, стви, _ijaa, dskæ, 
   {{0xa2cc07b6,0x7d040034,0x6b9e1951,0xff240092}},	//   _साध्, _znis, mpsg, _ስለሚመ, 
   {{0x27ea1952,0x4669cb14,0x7d04002d,0x60ca1953}},	//   swan_, урам_, _ynis, ygem, 
   {{0x442c0784,0x6b9c01f5,0x6d4c002b,0x27e80100}},	//   tzg_, opsg, _jjaa, pwan_, 
   {{0x69d4152d,0x6184044e,0xe2861954,0x27e803f0}},	//   ltze, _ሓባራዊ_, олли, qwan_, 
   {{0x69d401c6,0x636c0077,0x442c01a6,0x28d409b2}},	//   otze, dúnc, rzg_, ड्रि, 
   {{0x69d4152d,0x04140011,0x754801d3,0x6d4c005b}},	//   ntze, _দেশী_, ószá, _ojaa, 
   {{0x69d405f5,0x6d4c1574,0x60c8030a,0xa3c80c70}},	//   itze, _njaa, ugem, लंद_, 
   {{0x69d4c08d,0x60ca1955,0x7d040295,0x04140154}},	//   htze, rgem, _rnis, _দেরী_, 
   {{0x60c89e35,0x3cdc0316,0x6d4e1956,0x7a3001d3}},	//   sgem, ग्ने_, _ajaa, _jóté, 
   {{0x60ca1957,0x6d4c0158,0x128801ed,0x6b9c0373}},	//   pgem, _bjaa, _ضمنی_, epsg, 
   {{0x69d40112,0x00000000,0x00000000,0x00000000}},	//   dtze, --, --, --, 
   {{0xf0e8425b,0x69d40036,0x7d04003a,0x4ad800dc}},	//   _دىنى_, etze, _vnis, म्भव, 
   {{0x6d4dcb45,0xdea001d5,0x212c0076,0x69d42ad7}},	//   _ejaa, _تیدی, lheh_, ftze, 
   {{0x1a6401b9,0x7d04025c,0x00000000,0x00000000}},	//   تیدی_, _tnis, --, --, 
   {{0x212c03a2,0x797c02b5,0x799c0368,0x4ad8012a}},	//   nheh_, _kōwi, rprw, म्बव, 
   {{0x69d60c6c,0xdb0401bf,0x00000000,0x00000000}},	// [3d840] atze, vskæ, --, --, 
   {{0x7e6003a2,0x212e1958,0x0b401031,0x200c00d8}},	//   _kynp, hheh_, _онын, ixei_, 
   {{0xdb04005c,0x31640205,0x94a801a9,0x00000000}},	//   tskæ, ylmz_, атла_, --, 
   {{0xd57402bf,0x7e6000ad,0xc87c0e78,0x00000000}},	//   цузь, _mynp, _paßt_, --, 
   {{0x61e00113,0x39421959,0xdb0400b5,0x212d4f68}},	//   _apll, miis_, rskæ, dheh_, 
   {{0x3942195a,0x96f80006,0xdb04005c,0x71780131}},	//   liis_, _тэму_, sskæ, әбир_, 
   {{0xc204282b,0x797c04fe,0x745401ed,0xdb04055e}},	//   ققون_, _pōwh, _کھائ, mskä, 
   {{0x3942195b,0x30144eca,0xdb040621,0xc32000d1}},	//   niis_, здир, lskä, змәк, 
   {{0x6d4c0e14,0x69d4005a,0x8f08e255,0xe7e8008e}},	//   _rjaa, ztze, ахна_, _möşä, 
   {{0x3942195c,0x6d4c923a,0xdb06195d,0x00000000}},	//   hiis_, _sjaa, nskä, --, 
   {{0x3941c2fa,0x797c02b5,0xc6900375,0x212c020c}},	//   kiis_, _tōwh, ואת_, bheh_, 
   {{0xc0c5c20e,0x629c016b,0x212c0113,0x6d4400df}},	//   _душе_, _ɑsom, cheh_, _ĉias, 
   {{0x3942195e,0xdb0401e6,0x7c847b38,0x636c01e7}},	//   diis_, kskä, дуре, lúna, 
   {{0x6b9e195f,0x7e603c6a,0xbdc00131,0x69d40732}},	//   rpsg, _fynp, سەۋۋ, ttze, 
   {{0x636c00c6,0x69d401c0,0xdb0401e6,0x39421960}},	//   núna, utze, dskä, fiis_, 
   {{0x69d44e90,0x6d4c0af5,0x39421961,0xcbe400c7}},	//   rtze, _ujaa, giis_, _дцои, 
   {{0xcd295f54,0x6f1801fa,0x4ad00073,0x8bc80166}},	// [3d850] _مسکن_, _kovc, _तापव, _тыйб_, 
   {{0x6d5e1962,0x6b8c0076,0xdb0401e3,0xa3c801f9}},	//   losa, _iuag, gskä, लंस_, 
   {{0x6b8e1963,0x3941ace5,0x6d5db966,0x6f1803b9}},	//   _huag, biis_, oosa, _movc, 
   {{0x39421964,0x6f19e3c8,0x6b8c46bc,0x636c00c6}},	//   ciis_, _lovc, _kuag, dúna, 
   {{0x6b840270,0xe29a1965,0x3cfc0bd9,0xa8489b26}},	//   _kihg, бал_, ילאנ, _طلسم_, 
   {{0x6f1804b9,0x6d5e1966,0x6b8e1967,0x291a1968}},	//   _novc, hosa, _muag, _hosa_, 
   {{0x291a1969,0x6d5e196a,0x6b8e196b,0xf62800d6}},	//   _kosa_, kosa, _luag, _діти_, 
   {{0x797c00b0,0x200c005a,0x2918a986,0xc8c828d4}},	//   _pōwi, txei_, _josa_, िलिट, 
   {{0x6d5e196c,0x29180032,0x6b8c4aee,0x7e6112cb}},	//   dosa, _mosa_, _nuag, _synp, 
   {{0x7e600652,0x636c2833,0x6b84014f,0x212c75c3}},	//   _pynp, búna, _nihg, sheh_, 
   {{0x6d5e196d,0x63a80433,0x6d4401e4,0xdb04369d}},	//   fosa, _hwen, _ĉiar, nskå, 
   {{0x29180f71,0x6d5cb941,0x6b8c0139,0x305c00b4}},	//   _nosa_, gosa, _buag, ịlụ_, 
   {{0x63a811c1,0x0c22196e,0x6b8e196f,0x394154e3}},	//   _jwen, емян, _cuag, viis_, 
   {{0x63aa1970,0x6b8c94ed,0xdb061971,0x291801e7}},	//   _mwen, _duag, kskå, _aosa_, 
   {{0x6d5e1972,0x291a1973,0x63a9c844,0x39421974}},	//   bosa, _bosa_, _lwen, tiis_, 
   {{0x2918f5e9,0x63aa1975,0x6b8e1976,0xdb042611}},	//   _cosa_, _owen, _fuag, dskå, 
   {{0x29184460,0x39421977,0x63aa1978,0x6b8c19f5}},	// [3d860] _dosa_, riis_, _nwen, _guag, 
   {{0x6b840007,0x4bf8008f,0x69c00118,0xa2cc4a76}},	//   _gihg, _פליס, álec, _साष्, 
   {{0xceb00302,0x291a1979,0x3942197a,0x63a8527e}},	//   גיב_, _fosa_, piis_, _awen, 
   {{0x63a83c2a,0x291a197b,0x6b8c0218,0x6e3c0120}},	//   _bwen, _gosa_, _yuag, úrbi, 
   {{0x78a6197c,0x63a8020c,0xc0c8001f,0xb4bc02a0}},	//   mbiv, _cwen, _በስራ_, _आयी_, 
   {{0x6d5e197d,0x63a80134,0x78a40254,0x636c0332}},	//   zosa, _dwen, lbiv, túna, 
   {{0xa2cc26e4,0x6d5e197e,0x29180333,0x63aa197f}},	//   _सार्, yosa, _yosa_, _ewen, 
   {{0x63a8fa45,0x636c022c,0x6d5e1259,0x6f18f5a0}},	//   _fwen, rúna, xosa, _sovc, 
   {{0x6d5e1980,0x63aa1981,0x636c00c6,0xb4b80490}},	//   vosa, _gwen, súna, चणी_, 
   {{0xb4bc11b1,0x61f00724,0x6d5e1982,0x6b8c0afe}},	//   _आयु_, äklä, wosa, _ruag, 
   {{0x63aa1983,0xd040016b,0x6b8c0618,0x6b840270}},	//   _zwen, _aboɔ, _suag, _rihg, 
   {{0x6b8c0218,0x6b840007,0x6f180455,0xa2cc0073}},	//   _puag, _sihg, _wovc, _साऱ्, 
   {{0x6b8e1984,0x9e6c02d3,0x7f80004b,0x00000000}},	//   _quag, _ባዕልና_, _ګلون, --, 
   {{0x6b8c0218,0x6b840455,0x00000000,0x00000000}},	//   _vuag, _qihg, --, --, 
   {{0x291a1985,0x6b840007,0x6d5e1986,0x00000000}},	//   _posa_, _vihg, posa, --, 
   {{0x2919c40e,0x6b8c04c9,0x60cc002f,0x6d5e1987}},	//   _qosa_, _tuag, _öamt, qosa, 
   {{0x2918601a,0xdb04000f,0xc0c80023,0xa2cc08f2}},	// [3d870] _vosa_, nskû, _በትሪ_, _साल्, 
   {{0x9f4e1988,0xc98400a8,0x63a80433,0x8aa401a9}},	//   rveç_, _нуми, _rwen, _эрид, 
   {{0x63aa1989,0x29180579,0x38c8b4a9,0xe3b001d5}},	//   _swen, _tosa_, _کاپی_, چرت_, 
   {{0xd12480c2,0x59040135,0x38740120,0xdb041654}},	//   _شم_, _ངོགས_, çará_, rskå, 
   {{0xdb040267,0x27ec05d5,0xbfa0004d,0x98a000b8}},	//   rrkö, _èen_, _chế, _ulkā_, 
   {{0x65780048,0xdb040fac,0xadec012d,0x00000000}},	//   smwh, pskå, जबान_, --, 
   {{0xe1f800cd,0x00000000,0x00000000,0x00000000}},	//   ्मेण_, --, --, --, 
   {{0x63a84724,0x00000000,0x00000000,0x00000000}},	//   _twen, --, --, --, 
   {{0x63aa198a,0x3f9c0069,0x60080212,0x2294022e}},	//   _uwen, upuu_, іном_, _жизя, 
   {{0x3f9c0254,0x636c00d7,0x00000000,0x00000000}},	//   rpuu_, múno, --, --, 
   {{0x9f4c017a,0xa3c804aa,0x3f9c000d,0x00000000}},	//   lweë_, लूर_, spuu_, --, 
   {{0x3f9c32cb,0x23d000dc,0x80d80154,0xc0cc0092}},	//   ppuu_, _समाद, _মোর্, ጥታም_, 
   {{0x9f4c05e4,0x2d58011f,0x00000000,0x00000000}},	//   nweë_, néey_, --, --, 
   {{0x1dc411a6,0x00000000,0x00000000,0x00000000}},	//   _विपत, --, --, --, 
   {{0x3f8d7805,0xcb64013e,0x9f4c005b,0xdb1c0cad}},	//   _hugu_, фаре_, rveä_, _ìyís, 
   {{0x3f86198b,0x3f8c0050,0xb4bc49fc,0x48e002e8}},	//   _hinu_, _kugu_, _आये_, косв, 
   {{0x1c4400d4,0x5e6000d1,0x6ab80332,0x106400d1}},	// [3d880] _іном, _سۆڭە, éafó, ﺷﯩﺪﯨ, 
   {{0x3f8c0579,0x8c400730,0x46e400f7,0x9178004d}},	//   _mugu_, ößer, мдун_, _mấy_, 
   {{0x3f86198c,0x3f8e198d,0x59e073ca,0x9178004d}},	//   _minu_, _lugu_, _पहिर, _lấy_, 
   {{0x3f86198e,0xed580030,0x9f4c017a,0x9446198f}},	//   _linu_, buľu_, fweë_, وپان, 
   {{0x38c40241,0x3f8c4397,0x9f4c017a,0x60cc0124}},	//   _eèrà_, _nugu_, gweë_, _ñamy, 
   {{0x3f840570,0x80d8015b,0x4dac00cc,0x59e001f9}},	//   _ninu_, _মোল্, _কমসং, _पहार, 
   {{0x3f8e1990,0x201802f6,0x5f1000dc,0x65c002dd}},	//   _augu_, äsin_, तान्_, _бұха, 
   {{0x3f8e1991,0x2d9c4c25,0x70c80490,0xdb0403b2}},	//   _bugu_, _rtve_, ळलेल, gskú, 
   {{0x3f861992,0x3f8c16a3,0xbb5800b5,0x2d9c02f0}},	//   _binu_, _cugu_, mのfb, _stve_, 
   {{0x3f8c0323,0xdb04000f,0x02c198eb,0x00000000}},	//   _dugu_, rskû, _айфо, --, 
   {{0x3f861993,0x809c05d7,0x7bc02bb4,0xed5800d7}},	//   _dinu_, _ग्वे, ámun, zuľu_, 
   {{0x3f84008c,0x3f8e1994,0xb4bc012c,0xc2340375}},	//   _einu_, _fugu_, _आयो_, _קראו_, 
   {{0x3f8e1995,0x3f861996,0xfc6400a7,0xe28000fb}},	//   _gugu_, _finu_, върн, _иғән, 
   {{0x1d5406d5,0x3f8403f9,0xaee4002b,0x00000000}},	//   _ᴇᴇʟ_, _ginu_, _koṭy, --, 
   {{0x2d9c003a,0x20080129,0x1dc4687b,0x00000000}},	//   _utve_, _àair_, _वियत, --, 
   {{0x3f861997,0xc1f4123b,0x00000000,0x00000000}},	//   _zinu_, ומלץ_, --, --, 
   {{0x2d88bfc1,0x3f8400e8,0xa77618e0,0x257401bf}},	// [3d890] _iiae_, _yinu_, елач, nåle_, 
   {{0x466819ba,0x3f840327,0x00000000,0x00000000}},	//   орем_, _xinu_, --, --, 
   {{0x80ac045e,0x38640092,0x3cdc1fd2,0x00000000}},	//   _টাস্, ዲመለሱ_, ग्वे_, --, 
   {{0x2574005c,0x92ac0011,0x00000000,0x00000000}},	//   kåle_, কলো_, --, --, 
   {{0xe29a1998,0x5f100a28,0x68ee1999,0x88800271}},	//   пал_, ताम्_, mead, _شیطن, 
   {{0x68ee199a,0xe29a199b,0x2d880b23,0x3f8c0198}},	//   lead, чак_, _liae_, _rugu_, 
   {{0x3f8e199c,0x9f5a199d,0xe0d00491,0x3f8401ab}},	//   _sugu_, ísí_, هزة_, _rinu_, 
   {{0x3f86199e,0x68ee199f,0x636c09d7,0x3f8c01f7}},	//   _sinu_, nead, múnm, _pugu_, 
   {{0x3f8619a0,0x248c0472,0xdb04022c,0x9f842592}},	//   _pinu_, _igem_, rskú, нгид, 
   {{0x68ee19a1,0x809c0f4a,0xdb04022c,0x3f84067c}},	//   head, _ग्रे, sskú, _qinu_, 
   {{0x3f842b1d,0x80d40073,0x802400ec,0xdb041924}},	//   _vinu_, _यापे, _ڪرام, mskø, 
   {{0x68ee19a2,0x3f84020c,0xdb04005c,0x4dd400f7}},	//   jead, _winu_, lskø, رتپس, 
   {{0x68ee19a3,0x69c00232,0x3f859f65,0x236405b1}},	//   dead, álen, _tinu_, _kklj_, 
   {{0xdb0402ed,0x5018011a,0xc0c80092,0x2be0228d}},	//   nskø, _מונו, _በድሩ_, _फहरा, 
   {{0x68ec00c6,0x69c0012c,0x63b80007,0x09e0a20e}},	//   fead, šlen, hswn, лорн, 
   {{0x68ee19a4,0x38c94652,0x248c014f,0xd9b80124}},	//   gead, باسی_, _ngem_, _ҭынч_, 
   {{0xdb04005c,0x80d407b7,0x00000000,0x00000000}},	// [3d8a0] kskø, _याने, --, --, 
   {{0x248e19a5,0x3cdc06ff,0xdb0401bf,0xdb1c0241}},	//   _agem_, ग्रे_, jskø, _ìyàs, 
   {{0xaee400b8,0xb9380150,0xdb04005c,0x48f82314}},	//   _hoṣy, _قۋسا_, dskø, _लोको_, 
   {{0x68ee19a6,0x6134008c,0x9389b07a,0x809c2ecf}},	//   cead, _hálf, пска_, _ग्ले, 
   {{0x88800050,0x613401a8,0x9424010b,0x2448009f}},	//   _میٲن, _kálf, эмде, وجهي_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x613409f3,0xdbf8012d,0x00000000,0x00000000}},	//   _málf, _kłót, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb4cc7662,0x2d88003a,0x00000000,0x00000000}},	//   लली_, _riae_, --, --, 
   {{0x68ec03bd,0x2d8802e8,0x25742b96,0x0838011a}},	//   zead, _siae_, råle_, פעיל, 
   {{0xceb80198,0x2d880381,0x80ac015b,0x25740fac}},	//   _noƙe_, _piae_, _টার্, såle_, 
   {{0x68ecf466,0x25740158,0xbb480014,0xb04401ee}},	//   xead, påle_, ہلُن_, _имеҙ, 
   {{0x48f80918,0x68ee19a7,0x2d88bfc1,0xaee40055}},	//   _लोगो_, vead, _viae_, _coṣy, 
   {{0x68ec1418,0x00000000,0x00000000,0x00000000}},	//   wead, --, --, --, 
   {{0x68ee19a8,0x63b80007,0x2d88003a,0x0e0800ee}},	//   tead, zswn, _tiae_, _хэли_, 
   {{0x2d880393,0x248a19a9,0x8a74013e,0x68ec00a3}},	//   _uiae_, žami_, диҳӣ_, uead, 
   {{0x68ee19aa,0x3cf8fefb,0x0cbc19cc,0xab74004e}},	// [3d8b0] read, _سعيد_, ्लीम, _игиш, 
   {{0x68ee19ab,0x3f9810ba,0x00000000,0x00000000}},	//   sead, _éque_, --, --, 
   {{0x68ee19ac,0x6eda19ad,0x5f1000dc,0xb6040006}},	//   pead, _मानु, तात्_, ляцк, 
   {{0x63b85ba7,0x888012e1,0xb6040208,0x68ec01d5}},	//   tswn, _میزن, ương, qead, 
   {{0xdb0475f9,0x02c000db,0x00000000,0x00000000}},	//   tskø, гилү, --, --, 
   {{0xb9ec001f,0x613403b2,0x00000000,0x00000000}},	//   _ዕቃ_, _kálg, --, --, 
   {{0xdb044c5d,0x23640427,0xe2980116,0x970000d1}},	//   rskø, _vklj_, паһ_, _خېلى, 
   {{0xd24c04a9,0xa2cc4433,0x60090aff,0x63b80007}},	//   تنى_, _साक्, дним_, pswn, 
   {{0x63b80007,0xe2c82364,0x00000000,0x00000000}},	//   qswn, _يورو_, --, --, 
   {{0x236401a6,0xf3f93f92,0xdcf403e0,0x337c01ec}},	//   _uklj_, _януш_, _ıcın, _ﺠﺎﻓﻲ_, 
   {{0x61340008,0xe3d000af,0xceb4010b,0xc10041b9}},	//   _nálg, _समुझ, тәч_, _бүйл, 
   {{0xd24c034c,0x9d45b4a5,0xceb803f9,0x61340008}},	//   _بچه_, темд, _roƙe_, _sálf, 
   {{0x61341315,0x69c00118,0x00000000,0x00000000}},	//   _pálf, šlel, --, --, 
   {{0x787800d2,0xe8043507,0x1c6c110e,0x00000000}},	//   _lúví, रिना_, _ṣiṣẹ_, --, 
   {{0x7f40009a,0xdbf8012d,0x1bec000d,0xf1a4030d}},	//   _imnq, _płót, _छनकल_, _ырăн, 
   {{0xa630001f,0xa3d00073,0xe57803cb,0x23d0033f}},	//   _በሚያደ, वढा_, _nhŷ_, _समंद, 
   {{0x36e40b01,0xaa280014,0xbd4400f1,0x81e40154}},	// [3d8c0] лбаҳ, وسہٕ_, _لنډي, যটি_, 
   {{0xd6280006,0xa2cc07b7,0x98b00205,0x00000000}},	//   мозе_, _साग्, ıcın_, --, 
   {{0x629c013f,0x09e06e1e,0x613408a5,0x49c4009d}},	//   _ɑsot, _коэн, _gálg, _илэн_, 
   {{0xb4ce19ae,0xf4b404fb,0x09e006d3,0x81e400eb}},	//   लले_, اشاگ, _тоюн, যটা_, 
   {{0x7f4001f0,0x61341427,0x3dd400cc,0x6ac8032e}},	//   _omnq, _máld, তবিল, _ísfó, 
   {{0x04404ec1,0xcc38010f,0x00000000,0x00000000}},	//   шечн, וענט, --, --, 
   {{0x6b480010,0x00000000,0x00000000,0x00000000}},	//   nžga, --, --, --, 
   {{0x7f400b6f,0x2d9a19af,0x2b500175,0xcf9800d8}},	//   _amnq, írem_, znzc_, мјо_, 
   {{0xe80410f7,0x655402e8,0x4ea40114,0x45300116}},	//   रिया_, _сърф, крна, _ئىقر, 
   {{0x25742d62,0x75200156,0x216400cf,0x628400d7}},	//   måla_, _homz, ктөг, ľhor, 
   {{0x752003bd,0x20180162,0x00000000,0x00000000}},	//   _komz, øsir_, --, --, 
   {{0x7f400921,0xd2d0d9e5,0x50657b67,0xe804190c}},	//   _emnq, _साँझ, _итла, रिमा_, 
   {{0x7520017a,0x61343e33,0x25745794,0x7d540395}},	//   _momz, _dáld, nåla_, рвях, 
   {{0x31640375,0x752219b0,0x69c00122,0x636c0077}},	//   lomz_, _lomz, šlem, gúnh, 
   {{0x752003ac,0x2574007c,0x38980248,0x00000000}},	//   _oomz, håla_, _ọra_, --, 
   {{0x752219b1,0x61340789,0xdb04219b,0x2efc01a9}},	//   _nomz, _gáld, mský, _havf_, 
   {{0xdb0402fd,0x363413f9,0xd2d013f5,0xf770004b}},	// [3d8d0] lský, یرمس, _सांझ, ښام_, 
   {{0x2cb80198,0x61340a87,0x6f1c002f,0x4ca800eb}},	//   lasd_, _tálg, örch, _কাটু, 
   {{0xdb0403c6,0x752219b2,0x61340321,0x3164030a}},	//   nský, _bomz, _hále, komz_, 
   {{0x75200007,0xe794dbc3,0x613401e1,0x00000000}},	//   _comz, _ماسک, _kále, --, 
   {{0xe4b80220,0x752024e7,0x68fc02d0,0x636c00d8}},	//   _үлгі_, _domz, _iasd, lúni, 
   {{0x6134008c,0x68fc61bd,0xf990297d,0x27f8011a}},	//   _mále, _hasd, _دبی_, _issn_, 
   {{0x21689dc2,0x68fc02d5,0xdb040122,0xd5ac0014}},	//   ники_, _kasd, jský, _فہٕ_, 
   {{0xdb040122,0x75200489,0x68fc04ce,0xe0da19b3}},	//   dský, _gomz, _jasd, хви_, 
   {{0x61340232,0xdea00cb8,0x1f6619b4,0x65680248}},	//   _nále, میشی, лким, _ikeh, 
   {{0x75201cdf,0x68fd44d5,0x6ed80490,0xd12c0014}},	//   _zomz, _lasd, _माणु, ٲمی_, 
   {{0xd12ce43b,0x75204242,0xe8051487,0x68fc0334}},	//   زمی_, _yomz, रिडा_, _oasd, 
   {{0x02dc084d,0x613401e1,0x249c0042,0x6ed80950}},	//   प्रभ, _bále, ncwm_, _माथु, 
   {{0xdee619b5,0x61340077,0x00000000,0x00000000}},	//   _боли, _cále, --, --, 
   {{0x7f4219b6,0x68fc4f82,0xdb0402fb,0x6134498f}},	//   _umnq, _aasd, bský, _dále, 
   {{0x68fe19b7,0x27f80b0e,0x636c004e,0x6ed800dc}},	//   _basd, _assn_, gúni, _मातु, 
   {{0x656a19b8,0x68fc0077,0xef9007d6,0xbef00073}},	//   _nkeh, _casd, _دیید, _असुन_, 
   {{0x68fe19b9,0xa9d0015b,0xb8fc098a,0x613408a5}},	// [3d8e0] _dasd, াবগঞ, _ठा_, _gále, 
   {{0x656a19ba,0x75201cdf,0x59040135,0x68fc16b8}},	//   _akeh, _somz, _ངོམས_, _easd, 
   {{0x6135908c,0x68fc01c3,0x212c102c,0xe6b407d6}},	//   _zále, _fasd, kkeh_, شلنگ, 
   {{0x68fca8b6,0x1cb00327,0xb5ec0432,0x00000000}},	//   _gasd, _ཟབས_, _öýmü, --, 
   {{0xbef00574,0x98140214,0xca7401d5,0xdb0619bb}},	//   _असून_, _صبحا, _لمیش_, zský, 
   {{0x6ed86c8e,0x656800b0,0x7520676c,0x25744bc1}},	//   _माधु, _ekeh, _womz, råla_, 
   {{0x65680093,0x384c001f,0x68fcccb5,0x68ec01d3}},	//   _fkeh, _በመቀጠ, _yasd, _üldö, 
   {{0xdb0440cf,0x908c02d3,0x68fc1e02,0x9d140154}},	//   vský, _መዳያዊ_, _xasd, াসুন_, 
   {{0x50645b0f,0x2cb801d3,0xa2cc202e,0x2ef402e8}},	//   ытка, vasd_, _साच्, азпр, 
   {{0x13880597,0xdb040122,0x4ad01d8a,0xa0342002}},	//   _أخرى_, tský, _ताइव, شىپت, 
   {{0x2cb801ed,0x6134013a,0x69c00327,0x00000000}},	//   tasd_, _sále, ġlek, --, 
   {{0xdb0619bc,0x61340122,0x6e28017a,0xbd8803e6}},	//   rský, _pále, rydb, ێنین_, 
   {{0x68fe19bd,0x2cba19be,0xd01000f2,0x00000000}},	//   _rasd, rasd_, _دلش_, --, 
   {{0xa3c8069f,0x6134012c,0xdb0619bf,0x68fc0076}},	//   लूट_, _vále, pský, _sasd, 
   {{0xe3d0038e,0x68fc0023,0x5f100073,0xec1401f7}},	//   _सम्झ, _pasd, तार्_, _چوبد, 
   {{0x68fc0978,0x2cb801d5,0x61340248,0x00000000}},	//   _qasd, qasd_, _tále, --, 
   {{0x2d840943,0x68fc047e,0x67d43fd7,0xb5ec010b}},	// [3d8f0] _ṋewa_, _vasd, розу, _öýjü, 
   {{0x6e4802d3,0x68fe19c0,0x656800b5,0x8c140451}},	//   _ብመንጽ, _wasd, _skeh, _ليڊر_, 
   {{0x68fc07d6,0x00000000,0x00000000,0x00000000}},	//   _tasd, --, --, --, 
   {{0x67d619c1,0xc56a19c2,0xa7b83edf,0xa2cc18cc}},	//   _кому, رحال_, _илму_, _साङ्, 
   {{0x248801b8,0xdb0400e5,0x490001ec,0x00000000}},	//   äam_, cskó, _күңг, --, 
   {{0xbef001f9,0x00000000,0x00000000,0x00000000}},	//   _असेन_, --, --, --, 
   {{0x4ad007f7,0x69c00419,0x00000000,0x00000000}},	//   _ताईव, áleh, --, --, 
   {{0xceb80198,0x65682293,0x94400014,0xdb04007f}},	//   _roƙa_, _ukeh, _ژھون, nskò, 
   {{0x09dc0327,0x9424215c,0xdb04000d,0x00000000}},	//   _ལཱྀ_, _پولۇ, tskü, --, 
   {{0x80d40490,0xdb040112,0x00000000,0x00000000}},	//   _यावे, uskü, --, --, 
   {{0x62840232,0x613468b1,0x5d7619c3,0xb3541291}},	//   ýhod, _cálc, иумф, _دیوا_, 
   {{0x613401ef,0x00000000,0x00000000,0x00000000}},	//   _dálc, --, --, --, 
   {{0x8024006c,0xc1d00032,0xa3c80073,0x6134950c}},	//   _حرام, _төҙә, लूच_, _tálb, 
   {{0xd00e19c4,0x1ca403e6,0x9d140154,0x00000000}},	//   _آلو_, دێکی_, াসেন_, --, 
   {{0x5ca400db,0xdca4030d,0x00000000,0x00000000}},	//   _кийб, _кайи, --, --, 
   {{0xe0e4067c,0x18a499fa,0x8c6400b4,0x00000000}},	//   _çòde_, раам, ụmọd, --, 
   {{0x5745cc4c,0x969619c5,0x2cac0077,0x7c8401ee}},	// [3d900] анаб, ареш, ñede_, _ыҫма, 
   {{0xdb040008,0xb5ec0432,0x1ae44530,0x00000000}},	//   rskó, _öýkü, _тоом, --, 
   {{0xdb040008,0x6ed800bc,0x8d740092,0x20d40210}},	//   sskó, _मासु, ረገችው_, _धांध, 
   {{0x2c1c015b,0x7794082a,0x27ec0356,0xa3d00073}},	//   _পেয়ে_, _هیرا, _ţene_, वढं_, 
   {{0xfbe4009e,0x798619c6,0xd5a41550,0x00000000}},	//   মিকত, mmiw, الچی, --, 
   {{0x399c0241,0x79840142,0x03c4030d,0x00000000}},	//   _kís_, lmiw, ăсем, --, 
   {{0x399c0241,0x636c03b2,0x8290129d,0x00000000}},	//   _jís_, júnu, زۇنچ, --, 
   {{0x32cc0241,0x5185bb9d,0x6ed997aa,0x00000000}},	//   _bóyà_, шула, _माहु, --, 
   {{0xd0e006e3,0x03a0094c,0xef1000f7,0x399c01e1}},	//   क्षण_, _мито, зүлө, _lís_, 
   {{0x257404f3,0xdcb08337,0x7984d6ff,0x613400e5}},	//   håll_, ۋىپ_, hmiw, _pálc, 
   {{0x399c0ca8,0x00000000,0x00000000,0x00000000}},	//   _nís_, --, --, --, 
   {{0x613400bc,0x8fd001e0,0xd174004e,0xac18117e}},	//   _válc, _һәүә, _тызы, гому_, 
   {{0x7bf80209,0x4f94023a,0x79840042,0xac9401ec}},	//   аняр_, _треу, dmiw, _қапш, 
   {{0x6d5cf20f,0x399c1941,0x636c1427,0x613400e5}},	//   érab, _bís_, búnu, _tálc, 
   {{0x613619c7,0xff78008f,0x23ac01e1,0x00000000}},	//   _hála, _שטומ, _kójò_, --, 
   {{0x636c007b,0x399cfdef,0x613400d7,0x67d400cf}},	//   lúnt, _dís_, _kála, йобу, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3d910] --, --, --, --, 
   {{0x61341d1d,0xdc5424a2,0x399c007b,0x33e0067c}},	//   _mála, _چریک, _fís_, dòx_, 
   {{0xd005bbc0,0xe8040243,0xe37401ec,0x00000000}},	//   _کل_, रिहा_, ұлды, --, 
   {{0x69d619c8,0xdcf400dc,0xa50800d8,0x00000000}},	//   muze, _khyā, ѓела_, --, 
   {{0x69d619c9,0x61340646,0xd00400cf,0x00000000}},	//   luze, _nála, _ةل_, --, 
   {{0x27f4ae47,0x490c00bc,0x00000000,0x00000000}},	//   ğanı_, डाको_, --, --, 
   {{0xd00400c6,0x27f52d8c,0x69d401e4,0x51f400e5}},	//   _שل_, şanı_, nuze, مسٹر, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdee4721f,0xc2e800c6,0x69d619ca,0xf4340064}},	//   бопи, _لعام_, huze, _детэ, 
   {{0x69d43e44,0x636c09ff,0x41e402d5,0x613400ae}},	//   kuze, gúnt, _віда, _dála, 
   {{0x37a800bd,0xaee40882,0x6ed83e8c,0xdee401b9}},	//   _ওয়ার, _saṃy, _मारु, _ғойи, 
   {{0x69d40bb8,0x613619cb,0x61e00113,0x21e0011f}},	//   duze, _fála, _iqll, móh_, 
   {{0xdb8405f5,0x21e0011f,0xdcf40055,0x399c0ca8}},	//   йгми, lóh_, _chyā, _sís_, 
   {{0xdcf40a28,0x69d619cc,0xaf0401d9,0x3e8400fd}},	//   _dhyā, fuze, _وون٘, _килү_, 
   {{0x69d4646e,0x23d02366,0x8e381893,0x98a40116}},	//   guze, _समझद, _مسٹر_, йиве, 
   {{0x399c1125,0x798401f7,0x00000000,0x00000000}},	//   _vís_, umiw, --, --, 
   {{0x21e0011f,0x28b8084c,0x79856257,0xdce006be}},	// [3d920] hóh_, русэ_, rmiw, qqlı, 
   {{0x61e00784,0x399e19cd,0x7984000d,0x00000000}},	//   _oqll, _tís_, smiw, --, 
   {{0xf3ec00bd,0xceb0008d,0x69d559e0,0xd5745aa2}},	//   ওয়ার_, פיא_, cuze, будь, 
   {{0x93a800c6,0x21e00429,0x7bc4005c,0x49780092}},	//   هاتف_, dóh_, _kviu, _በጥቂቱ_, 
   {{0x6ed81889,0x61e0fb5e,0xe50400c6,0x00000000}},	//   _मालु, _aqll, تبلي, --, 
   {{0xceb803f9,0xe96c001f,0x07a001c6,0x23ac0241}},	//   _roƙo_, _ሰብሳቢ_, _харн, _sójò_, 
   {{0x613408a7,0x11e832e8,0x21e0011f,0xb0dd4eb8}},	//   _sála, اعتي_, góh_, _यादग, 
   {{0x7bc40381,0x6134362f,0xb03400d8,0x23b000db}},	//   _oviu, _pála, жниш, سۅۅس, 
   {{0x69d619ce,0x3d1c2413,0x7454066d,0xac980133}},	//   zuze, याने_, _بھائ, یندا_, 
   {{0x613455b4,0x21e00429,0x11d40845,0x69d40083}},	//   _vála, bóh_, _гідр, yuze, 
   {{0x2d98d904,0x7bc619cf,0x21e0011f,0x65840413}},	//   êre_, _aviu, cóh_, _úthú, 
   {{0xd7fc01dc,0x69d619d0,0xd6dc015b,0x636c00c6}},	//   _đăng_, vuze, ড়িয, súnt, 
   {{0xe1640be2,0x7f819c37,0x69d401b3,0x613421dd}},	//   _بدلي, تلین, wuze, _uála, 
   {{0x8d5400fd,0xc01801e1,0x00000000,0x00000000}},	//   ртүч, _níṣe_, --, --, 
   {{0x613619d1,0x0dc8a9c2,0xd6dc015b,0x00000000}},	//   _máln, _сули_, ড়ায, --, 
   {{0xad840131,0x2018007c,0x00000000,0x00000000}},	//   _باتۇ, åsig_, --, --, 
   {{0x69d40083,0xcbc4009f,0x00000000,0x00000000}},	// [3d930] suze, _ازبي, --, --, 
   {{0x69d4116e,0xcaf4009f,0x00000000,0x00000000}},	//   puze, _اِدڙ_, --, --, 
   {{0x7bc405b8,0x21e00548,0x69d4004b,0xe49800cf}},	//   _zviu, xóh_, quze, акеч_, 
   {{0xaa4401ee,0x3d1c5843,0x00000000,0x00000000}},	//   _геүл, याये_, --, --, 
   {{0x320e19d2,0x2458c133,0x36e800d1,0x3cfc010f}},	//   _ardy_, шадь_, شرەپ_, טלאנ, 
   {{0xdcb496e9,0x85ba19d3,0x21e0011f,0x28a40dba}},	//   _अज्ञ, _مارس_, tóh_, गुरि, 
   {{0x6134012c,0xd7640c75,0x00000000,0x00000000}},	//   _dáln, _بەلى_, --, --, 
   {{0x80ac015b,0x21e0102c,0xb82005ac,0x00000000}},	//   _টাঙ্, róh_, _নেটত_, --, 
   {{0x320c0280,0x21e00429,0xf3ec0131,0x00000000}},	//   _erdy_, sóh_, _яң_, --, 
   {{0x63aa19d4,0xdb0609c9,0xdf48059f,0xd7d80073}},	//   _iten, lskö, рзод_, यंतच, 
   {{0xb8fc0135,0x7bc4c1a8,0x61e00309,0x442c4f7c}},	//   _རྐ_, _sviu, _uqll, lyg_, 
   {{0xdb04049f,0x20180108,0xd00c00f1,0x00000000}},	//   nskö, äsis_, رلۍ_, --, 
   {{0x69c54ff1,0x2cade11f,0xde54005f,0x61351003}},	//   _avhe, ñeda_, _šādā_, _hálo, 
   {{0x63a85053,0x613401e1,0x00000000,0x00000000}},	//   _mten, _kálo, --, --, 
   {{0xdb0401e6,0x442c03cb,0x699422c3,0x69d001e1}},	//   kskö, hyg_, зрух, _ìkẹ, 
   {{0x89d531f7,0x63a8ad35,0x61340122,0x28a4448b}},	//   توفر_, _oten, _málo, गुलि, 
   {{0x63a9a9e2,0x7d0619d5,0x57493a48,0x69c402c4}},	// [3d940] _nten, _iais, азам_, _evhe, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x613492f5,0x2b1400c7,0x00000000,0x00000000}},	//   _nálo, _хьыр, --, --, 
   {{0x63a80649,0x18687724,0x7d0619d6,0x442c0142}},	//   _bten, _вами_, _jais, fyg_, 
   {{0x25ac0122,0x69c0012c,0xd3886ee2,0x480402e8}},	//   _čele_, šlet, айде_, _деян_, 
   {{0x613619d7,0xe61400db,0x3dac00eb,0x00000000}},	//   _bálo, تكۅگ, _কিনল, --, 
   {{0x63aa19d8,0xd139c0be,0x1dc4227c,0x78a4004e}},	//   _eten, ихи_, _विगत, ociv, 
   {{0x78a619d9,0x442c00a9,0x63a80175,0xe01400e1}},	//   nciv, byg_, _ften, तमंद_, 
   {{0x442c0175,0xb4b401af,0x9988013a,0x00000000}},	//   cyg_, _миңә, hybů_, --, 
   {{0x7d0619da,0x61340077,0x7f8032e8,0xe8d802e3}},	//   _aais, _fálo, ولين, mmụ_, 
   {{0x3f9c0ba7,0x10a400ee,0x613403b2,0x320c0432}},	//   aquu_, _диен, _gálo, _urdy_, 
   {{0x7d0619db,0x25a40077,0x21640150,0x00000000}},	//   _cais, _élle_, _етіг, --, 
   {{0x7d0619dc,0x6135908c,0x80a000f1,0xf1a80244}},	//   _dais, _zálo, _غمون, _ئاڕه_, 
   {{0x7d040363,0x613403b2,0x78a400d8,0x00000000}},	//   _eais, _láll, eciv, --, 
   {{0x7d0619dd,0xb9e402bf,0xe9180845,0x7f8000f1}},	//   _fais, міти, бові_, _تلون, 
   {{0x7d0619de,0x9f5c02bd,0x29c400e2,0x3d1c08a3}},	//   _gais, _aswè_, rķa_, याणे_, 
   {{0x6d4e19df,0x2d9e19e0,0xc7b80117,0xbd88007b}},	// [3d950] _imaa, _huve_, рёб_, _بنين_, 
   {{0x7d0408ad,0x2d9c0433,0xbb4806f6,0x63a811a8}},	//   _zais, _kuve_, _ولين_, _rten, 
   {{0x7d0619e1,0x2d9e19e2,0x442e19e3,0x613403b2}},	//   _yais, _juve_, wyg_, _báll, 
   {{0x442c0628,0x78a56769,0x2d9e19e4,0x613400c7}},	//   tyg_, cciv, _muve_, _cáll, 
   {{0x6d4d0587,0x2d9e19e5,0x613619e6,0xdb0619e7}},	//   _mmaa, _luve_, _dáll, rskö, 
   {{0x2d9e19e8,0xa634005e,0x442e19e9,0x63a8003a}},	//   _ouve_, _енгі, ryg_, _vten, 
   {{0x26c1d1ac,0x6d4cdde5,0x613400e4,0x81f41893}},	//   maho_, _omaa, _fáll, تہار_, 
   {{0x26c219ea,0x613619eb,0x63a8f0d6,0x6d4c01e1}},	//   laho_, _válo, _tten, _nmaa, 
   {{0x63aa19ec,0x2d9c0421,0x7d0619ed,0x02a41a92}},	//   _uten, _auve_, _rais, _дрем, 
   {{0x7d0619ee,0x6d4e19ef,0x26c219f0,0x6d5e19f1}},	//   _sais, _amaa, naho_, éran, 
   {{0x1d08713a,0x2d9c516d,0x26c000b0,0x8ec0004b}},	//   бени_, _cuve_, iaho_, رښوو, 
   {{0x2d9c2b1d,0x26c219f2,0x7d0405b1,0x613401d3}},	//   _duve_, haho_, _qais, _kálm, 
   {{0x7d0619f3,0x26c219f4,0xc0f402d3,0x78a403e0}},	//   _vais, kaho_, ላዕለ_, vciv, 
   {{0x6d4e19f5,0x2d9c004c,0x613405f7,0xdb0401f1}},	//   _emaa, _fuve_, _málm, jskô, 
   {{0x2d9c0585,0xd3540375,0x00000000,0x00000000}},	//   _guve_, לישי_, --, --, 
   {{0x7d0619f6,0xaee4002b,0x00000000,0x00000000}},	//   _uais, _paṇy, --, --, 
   {{0x26c006d9,0x69c00194,0x49b000d1,0x00000000}},	// [3d960] faho_, áler, _җәсу, --, 
   {{0x26c219f7,0x78a619f8,0x2b1c22e3,0x9b4408f0}},	//   gaho_, sciv, माणु_, _رنجو, 
   {{0x4a9800c8,0x98a52b9b,0x61343168,0x8ca0000d}},	//   _לייג, _нине, _páll, _गलमो, 
   {{0xdbf000bc,0xb93802dd,0x699402e8,0xd40401af}},	//   hřív, _بۋرا_, _орях, зяки, 
   {{0x26c219f9,0x6134066d,0x65c40952,0x28e001ad}},	//   baho_, _váll, ﺯﮔﯩﻠ, _फाति, 
   {{0x61340077,0x26c00526,0x39400254,0xaa080244}},	//   _dálm, caho_, lhis_, _ازیل_, 
   {{0x363400aa,0x00000000,0x00000000,0x00000000}},	//   _غورځ, --, --, --, 
   {{0x2d9d6611,0x30141086,0xd4a40116,0x6134032e}},	//   _ruve_, ддир, _хиай, _fálm, 
   {{0xa4f00c02,0x2d9e19fa,0x394003f9,0x614405a9}},	//   lışı_, _suve_, ihis_, بىيە, 
   {{0x6d4d9822,0x6e3c00a3,0x394219fb,0xc438011a}},	//   _smaa, ùrbo, hhis_, _התמי, 
   {{0x6d4c089c,0x2cac9936,0xa4f06d5b,0xacf80212}},	//   _pmaa, ñedo_, nışı_, онну_, 
   {{0x26c1779e,0xc27825f9,0x50d402dd,0x065408a8}},	//   zaho_, _פראי, _ءزار, לייך_, 
   {{0x26c219fc,0x394219fd,0x7c8619fe,0x00000000}},	//   yaho_, dhis_, еуре, --, 
   {{0x2d9e19ff,0xa4f005d1,0x3ea40334,0x00000000}},	//   _tuve_, kışı_, _gfnt_, --, 
   {{0x26c001aa,0xbe9421ec,0x6d4c022f,0x00000000}},	//   vaho_, _عضوا_, _tmaa, --, 
   {{0x26c21a00,0x6d4e1a01,0x39421a02,0xa3cc02ab}},	//   waho_, _umaa, ghis_, _शटल_, 
   {{0x7798301f,0x26c21a03,0x6d5c0117,0x2caa1a04}},	// [3d970] зкур_, taho_, mnsa, _ifad_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x26c21a05,0x6d5e1a06,0xf770282b,0xdb040a85}},	//   raho_, onsa, ااق_, rskô, 
   {{0x6d5c0876,0x26c006d6,0x24547092,0x6135267e}},	//   nnsa, saho_, وناس, _pálm, 
   {{0x291a1a07,0xdce4005f,0x6d5e1a08,0x6b840208}},	//   _insa_, nokā, insa, _khhg, 
   {{0xdef8693c,0x27ea1a09,0x68ee1a0a,0x29080a55}},	//   ላትን_, mtan_, lfad, ldaa_, 
   {{0xe8040b9a,0x2eec010a,0xa18921d9,0x27ea1a0b}},	//   रिका_, dfdf_, обка_, ltan_, 
   {{0x290a1a0c,0x20d43334,0x68ee1a0d,0x6d5e1a0e}},	//   ndaa_, фікс, nfad, éral, 
   {{0x69d40639,0x29180004,0x9f640724,0xdea1b563}},	//   hrze, _mnsa_, _şuña_, نیشی, 
   {{0x27ea1a0f,0x6d5e1a10,0x29088c88,0x6135192c}},	//   itan_, ensa, hdaa_, _kálk, 
   {{0x27ea1a11,0x29180280,0x69d40034,0x98a00b13}},	//   htan_, _onsa_, jrze, _lokā_, 
   {{0x628005ce,0x27ea1a12,0x69d61a13,0x39400218}},	//   _izlo, ktan_, drze, xhis_, 
   {{0x68ec0597,0x290a1a14,0x27ea1a15,0xefcc0020}},	//   dfad, ddaa_, jtan_, _በብዙ_, 
   {{0x291a1a16,0x6d5e1a17,0x68ec208d,0xa4f006b9}},	//   _ansa_, ansa, efad, yışı_, 
   {{0xfe74152d,0x39421a18,0x27e80323,0x68ee1a19}},	//   _хүн_, this_, etan_, ffad, 
   {{0xceb803f9,0x291801c3,0x2908208d,0x95140055}},	//   _roƙi_, _cnsa_, gdaa_, _iṅgy, 
   {{0x27ea1a1a,0x69d61a1b,0x200c0369,0x69c001a6}},	// [3d980] gtan_, arze, nvei_, šlep, 
   {{0x39421a1c,0x290a1a1d,0x3d1c0574,0xa4f00259}},	//   shis_, adaa_, यावे_, tışı_, 
   {{0x27ea1a1e,0xd9442e91,0x39401fba,0x200c0007}},	//   atan_, _жени, phis_, hvei_, 
   {{0x7afe1a1f,0x27ea1a20,0xa4f0538f,0x290801d9}},	//   lert, btan_, rışı_, cdaa_, 
   {{0x9388b3ef,0x03a06c48,0x53f8007b,0x942401ec}},	//   оска_, вичо, تراح_, ьмде, 
   {{0x7afc32ff,0x613401a8,0x200e1a21,0x00000000}},	//   nert, _fálk, dvei_, --, 
   {{0x7afe1a22,0x6d5e1a23,0xda0c07f7,0x6280012d}},	//   iert, ynsa, ाटित_, _czlo, 
   {{0x7afe1a24,0x107c00d1,0x73c40150,0x00000000}},	//   hert, _ﮬﻪﺭﯨ, _зәке, --, 
   {{0x6d5e1a25,0x6134c469,0x28e007f7,0x8da001ec}},	//   éram, _málh, _फासि, _ﺍﻟﺸﻕ_, 
   {{0x69d40589,0xdce4005f,0xadb40b01,0x6d5c00e4}},	//   yrze, vokā, нбош, ĩram, 
   {{0x68ec0365,0x290836c6,0x27e801c6,0x7afc8b32}},	//   yfad, ydaa_, ztan_, dert, 
   {{0x27e80978,0xf40c003d,0x6d5c0a55,0x29080014}},	//   ytan_, _གློད_, unsa, xdaa_, 
   {{0x6d5e1a26,0x6fe8003d,0x27ea1a27,0x2574072b}},	//   rnsa, _འདྲའ, xtan_, målt_, 
   {{0x69d4006d,0x2908581e,0x98a000de,0x00000000}},	//   trze, wdaa_, _rokā_, --, 
   {{0x27ea1a28,0x68ec0112,0x69d401a4,0xe91800d4}},	//   wtan_, tfad, urze, пові_, 
   {{0x68ec01ab,0x69d4002f,0x2574007c,0x00000000}},	//   ufad, rrze, nålt_, --, 
   {{0x68ee1a29,0x27ea1a2a,0x2e3401e1,0x29088ebb}},	// [3d990] rfad, utan_, _fúfú_, rdaa_, 
   {{0x27ea1a2b,0x69d4006d,0x7afd1137,0x61340306}},	//   rtan_, prze, cert, _pálk, 
   {{0x200c004c,0x68ec002f,0x85440139,0x00000000}},	//   zvei_, pfad, мэде, --, 
   {{0x291822b9,0x6134012c,0x29080014,0x67240fac}},	//   _unsa_, _válk, qdaa_, sjhj, 
   {{0x27ea1a2c,0x628001ed,0x1cdc0327,0x00000000}},	//   qtan_, _szlo, _ཤྐས_, --, 
   {{0x61343b7b,0xa3480395,0x00000000,0x00000000}},	//   _tálk, язла_, --, --, 
   {{0xa4d410f5,0xa0a61a2d,0x61361a2e,0x45a00150}},	//   _пові, найд, _háli, _شەشك, 
   {{0x7afe1a2f,0x1fb48271,0x659400f7,0x62800175}},	//   zert, нсор, _чабу, _vzlo, 
   {{0x7afc016d,0x200c0369,0x63c00118,0x00000000}},	//   yert, uvei_, ávně, --, 
   {{0x61341bb0,0x200e1a30,0x7afc10d8,0x13e801ec}},	//   _máli, rvei_, xert, _ءولۋ_, 
   {{0x7afe1a31,0x1b0c2158,0x613400d2,0x1d080aa8}},	//   vert, _সকলে_, _láli, пени_, 
   {{0x7afc8644,0x00000000,0x00000000,0x00000000}},	//   wert, --, --, --, 
   {{0x7afc3077,0x9f340a4a,0x61342507,0xdc3400d1}},	//   tert, _педі, _náli, رىسخ, 
   {{0x7afe1a32,0xdbd000c5,0xa260069d,0x00000000}},	//   uert, müüj, _ድንኳን_, --, 
   {{0x7afe1a33,0xcb64030d,0xad4000cf,0x00000000}},	//   rert, харе_, _چۉپۉ, --, 
   {{0x61350e2f,0xdea00345,0x00000000,0x00000000}},	//   _báli, _جیگی, --, --, 
   {{0x7afc122d,0x6135a6a3,0x17861a34,0x00000000}},	// [3d9a0] pert, _cáli, егам, --, 
   {{0xe20407ae,0x7afc0eda,0xe804feb4,0x8f980375}},	//   _đóng_, qert, रिजा_, פיעי, 
   {{0x2b1c00c5,0x00000000,0x00000000,0x00000000}},	//   मारु_, --, --, --, 
   {{0x9484425c,0x53e6181c,0xd944004e,0x2c8400c0}},	//   нылд, ецка, _чеми, būdį_, 
   {{0x6134682a,0x00000000,0x00000000,0x00000000}},	//   _gáli, --, --, --, 
   {{0x3f88068c,0x2b1807f7,0x55e4022e,0x00000000}},	//   ïcul_, दाएँ_, _погб, --, 
   {{0x61340122,0x35c4013e,0xe7e000e1,0x6d5c0098}},	//   _záli, _шавҳ, गूठा_, érak, 
   {{0xb11401a9,0x00000000,0x00000000,0x00000000}},	//   тмиш, --, --, --, 
   {{0x1944037e,0x25740158,0x3e380092,0x2ba43337}},	//   _ｙｏｕ_, rålt_, _ይመከር, _गंधा, 
   {{0x6e940276,0x70640092,0x7ff09f9c,0x2574007c}},	//   кипу, _ልጆቻቸ, اسيا, sålt_, 
   {{0x11d59b10,0x35d80456,0xa24415b4,0x00000000}},	//   _ستاد, _डिफ़, _لیول_, --, 
   {{0x8fa61760,0x7e400022,0x00000000,0x00000000}},	//   _заде, ухье, --, --, 
   {{0xc0c80023,0xfc640395,0xf0040117,0x00000000}},	//   በኩም_, гърн, _рӯйи, --, 
   {{0xf8b80016,0xbfc80150,0x67f000c7,0x00000000}},	//   _đĩa_, _ءانە_, _ẽjov, --, 
   {{0x6134041e,0xbd880133,0x00000000,0x00000000}},	//   _sáli, بنێن_, --, --, 
   {{0x61341aa9,0xabb400c7,0x8274010f,0xba7400e5}},	//   _páli, _ҧақә, געלע_, چاہت, 
   {{0xa7740640,0x8c34013e,0xe7e006e3,0x00000000}},	// [3d9b0] влач, _чопӣ_, गंधा_, --, 
   {{0x61361a35,0xade4f712,0x062c0092,0x0df81ef7}},	//   _váli, _कमान_, _በላይነ, ላጥፍ_, 
   {{0x2d8806d6,0x659400d4,0x00000000,0x00000000}},	//   _khae_, важу, --, --, 
   {{0x61340579,0xa4d402bf,0xfa8800fd,0x2c840024}},	//   _hálv, тоді, _ясый_, pūdį_, 
   {{0x10881c5c,0x613608ae,0x2d880270,0xa2e401b9}},	//   ﻗﯩﺮﯨ, _kálv, _mhae_, волд, 
   {{0x33940108,0x2bd803ce,0xa1f40a5b,0x00000000}},	//   гачё, _भटना, вџиј, --, 
   {{0x26d00433,0x7a3c02f6,0x613409f3,0x2168c88d}},	//   _idzo_, mätö, _málv, мики_, 
   {{0xd24c3092,0xd11c08f2,0x00000000,0x00000000}},	//   غني_, भाषण_, --, --, 
   {{0x0fc0f7da,0x33f45dda,0xd12c188d,0x7124167e}},	//   айын, _مسلس, تمي_, ارىل, 
   {{0x62340474,0x27f80100,0x00000000,0x00000000}},	//   _иезу, _mpsn_, --, --, 
   {{0x8e8004b4,0x00000000,0x00000000,0x00000000}},	//   игье, --, --, --, 
   {{0x2d8a1a36,0xc0c8023a,0x71f80014,0xc20c01d9}},	//   _chae_, _хуже_, _سرمس_, _پٔچ_, 
   {{0x5f061a37,0x43dc00cd,0x00000000,0x00000000}},	//   _азла, _नमोऽ, --, --, 
   {{0x26d018f7,0xdde80214,0x7a3c01f4,0x5e14022e}},	//   _ndzo_, _قرعه_, jätö, _афиф, 
   {{0xceb0011a,0x00000000,0x00000000,0x00000000}},	//   _דיו_, --, --, --, 
   {{0x26d0006f,0xa3c002db,0x00000000,0x00000000}},	//   _adzo_, ंठा_, --, --, 
   {{0x661403f9,0x3d1800ab,0x07a00e4e,0x00000000}},	// [3d9c0] _arzk, _बोये_, иатн, --, 
   {{0x6fd43bec,0x613430de,0x3ce80490,0x66140118}},	//   _दिसं, _gálv, _झाडे_, _brzk, 
   {{0x198802f6,0x613403b2,0x00000000,0x00000000}},	//   _обои_, _hálu, --, --, 
   {{0x26d21a38,0xb11c04c5,0x97c40209,0x61340248}},	//   _edzo_, _তত্ব_, _ийме, _kálu, 
   {{0x5ed800bd,0x6d5e1a39,0x66140036,0xdb04007c}},	//   ব্যে, érai, _erzk, ppkä, 
   {{0x61341f60,0x00000000,0x00000000,0x00000000}},	//   _málu, --, --, --, 
   {{0xe2b4009d,0x959401af,0x00000000,0x00000000}},	//   усчэ, _араљ, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x53a409ed,0xc9501203,0x613400dd,0x50640395}},	//   _разб, ימה_, _nálu, ътка, 
   {{0x0dc80724,0x2d880204,0x6628032e,0x00000000}},	//   муми_, _shae_, _ískö, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x61361a3a,0x00000000,0x00000000,0x00000000}},	//   _sálv, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2d8a1a3b,0x7b640354,0x27f8013a,0x6b75a9f5}},	//   _whae_, атсе, _rpsn_, улгу, 
   {{0xeb34185e,0x61361a3c,0x2ba40c2e,0x2d881c1d}},	//   نىڭد, _válv, _गंवा, _thae_, 
   {{0x291c0054,0x7c300162,0x00000000,0x00000000}},	//   ñwa_, ðiró, --, --, 
   {{0x64a40efb,0x38340024,0xd7d80490,0x9e240014}},	// [3d9d0] қала, антр, यंगच, _لى۪و, 
   {{0x9200000d,0x98a00064,0x00000000,0x00000000}},	//   लबाज_, _roką_, --, --, 
   {{0x57a40032,0x61340306,0xaa59022b,0xf7703b44}},	//   _ҡырҡ, _zálu, _чину_, زاك_, 
   {{0xb33c0327,0x7a3c005b,0x17b000fe,0x00000000}},	//   _jiħf, sätö, _চিৰি, --, 
   {{0x4ab404e4,0x61361a3d,0x63780139,0xe45400ee}},	//   _अभाव, _mált, нскр_, ыкды, 
   {{0x98a00064,0xf36400fb,0xa5c40150,0x00000000}},	//   _voką_, ҫтән, _бөде, --, 
   {{0x972001d3,0x00000000,0x00000000,0x00000000}},	//   _دہلو, --, --, --, 
   {{0x600a1a3e,0x00000000,0x00000000,0x00000000}},	//   еним_, --, --, --, 
   {{0x34950af1,0xc2b001af,0x00000000,0x00000000}},	//   _ватр, _көйш, --, --, 
   {{0x5f442942,0x69d800b0,0xcf40013d,0xb1a40022}},	//   اندل, _āwen, йный, ышәк, 
   {{0x61361a3f,0xe0440116,0xe0d40798,0x02b00117}},	//   _bált, _әнли, _боењ, _биҷӯ, 
   {{0xf1d4052f,0x36541e38,0xad240131,0x00000000}},	//   _төшө, _ጋዜጠኛ, لىپى, --, 
   {{0x60c818a6,0x61340332,0x00000000,0x00000000}},	//   maem, _dált, --, --, 
   {{0x60ca1a40,0x1ca403e6,0x00000000,0x00000000}},	//   laem, خێکی_, --, --, 
   {{0x613619cb,0xfe4400c7,0x00000000,0x00000000}},	//   _fált, _рҟни_, --, --, 
   {{0x2d961a41,0x60c800c5,0x9f5c007f,0x6e3c00d4}},	//   _крыс, naem, _grwò_, ørbe, 
   {{0x613409f3,0x2c7c0332,0xbd4401e2,0xe12400fe}},	// [3d9e0] _háls, rádú_, _منډي, _বতাহ_, 
   {{0x60c80399,0x46e400f7,0x6d5c00c7,0x00000000}},	//   haem, лдун_, érav, --, 
   {{0x60ca1a42,0x85b00131,0x2ae800dc,0x97c401ec}},	//   kaem, йәтч, _जातु_, _әйге, 
   {{0x613426b8,0x5468f99a,0xc68c0014,0x00000000}},	//   _máls, наем_, سِن_, --, 
   {{0x60c816b8,0x4da8009e,0x00000000,0x00000000}},	//   daem, _কিছূ, --, --, 
   {{0x46a21a43,0x2d98056a,0xfbdc9129,0x00000000}},	//   _гарв, írez_, _बिनम, --, 
   {{0x26780276,0xdbf80154,0x00000000,0x00000000}},	//   _астэ_, ইটিস_, --, --, 
   {{0x60c80607,0x51840032,0x00000000,0x00000000}},	//   gaem, ыула, --, --, 
   {{0x3d18045b,0x3200002e,0x00000000,0x00000000}},	//   _बोधे_, ňiy_, --, --, 
   {{0xb11400b4,0x613424c8,0xdce40064,0x00000000}},	//   _gụny, _báls, mokę, --, 
   {{0x60c804c4,0xf1c812eb,0x00000000,0x00000000}},	//   baem, _रबिन, --, --, 
   {{0xdcb05841,0x61b004d3,0x60ca1a44,0x70546e0d}},	//   يىپ_, _بڕوا, caem, _پنتا, 
   {{0x6134066d,0xcf2423bb,0x7d0000c5,0x00000000}},	//   _vált, _مرثي, õmsa, --, 
   {{0x6e94023b,0x15f407f7,0x35c000fe,0x00000000}},	//   _килу, ीबार_, _উমৈহ, --, 
   {{0xaa9401c0,0x00000000,0x00000000,0x00000000}},	//   ривч, --, --, --, 
   {{0x5ed800eb,0x00000000,0x00000000,0x00000000}},	//   ব্দে, --, --, --, 
   {{0x4ae407d6,0xdc54004b,0x7cd800c7,0x70980023}},	// [3d9f0] _йўна, _پريک, _смыр_, _ሓሓሊፉ_, 
   {{0x60ca1a45,0xb33c031c,0x00000000,0x00000000}},	//   zaem, _jiħd, --, --, 
   {{0x57f4025c,0x60c80369,0x61340d12,0x466a1a46}},	//   _པདྨོ_, yaem, _málr, храм_, 
   {{0x60c801ab,0x19c00166,0x00000000,0x00000000}},	//   xaem, _фәрг, --, --, 
   {{0xd004e65b,0x60c80270,0xe7940133,0x240801d5}},	//   _بل_, vaem, _ناسک, тнли_, 
   {{0x97313115,0x60c800b0,0x63ac01e4,0x00000000}},	//   _وکلا, waem, ŭano, --, 
   {{0x60ca1a47,0xe1261a48,0xd36c143e,0x66040175}},	//   taem, имки, بهو_, qwhk, 
   {{0xb11401f2,0xf1a803e6,0xe5080592,0x69c003b2}},	//   _wụny, داوه_, _جيرو_, áley, 
   {{0xb11401f2,0x6568035b,0x6134659a,0x00000000}},	//   _tụny, _ijeh, _bálr, --, 
   {{0x6134066a,0x00000000,0x00000000,0x00000000}},	//   _páls, --, --, --, 
   {{0x09a80729,0xd12d271c,0xdd8821f3,0x60c803b2}},	//   গীতা, سمی_, кбод_, paem, 
   {{0x613401ed,0x5ff4005b,0xdef800c7,0x00000000}},	//   _váls, _взду, хыҩ_, --, 
   {{0x6568353f,0x212c2630,0x61340332,0xb91400b8}},	//   _mjeh, mjeh_, _fálr, _imaḿ_, 
   {{0x613402d2,0x2fc00139,0x7c4400de,0x00000000}},	//   _táls, _çiga_, _čurā, --, 
   {{0x656807dd,0x9d442502,0x00000000,0x00000000}},	//   _ojeh, _вейд, --, --, 
   {{0x6d5e158f,0x656a1a49,0x38c83267,0x00000000}},	//   érat, _njeh, طاری_, --, 
   {{0x37a801d3,0x582428e5,0x00000000,0x00000000}},	// [3da00] ائری_, шмаб, --, --, 
   {{0x656a1a4a,0xe6c400c6,0x8c1800d9,0x00000000}},	//   _ajeh, متمي, _יופי, --, 
   {{0x9f4c026c,0x00000000,0x00000000,0x00000000}},	//   rteè_, --, --, --, 
   {{0x7bc40472,0x00000000,0x00000000,0x00000000}},	//   _kwiu, --, --, --, 
   {{0x212c1e31,0x00000000,0x00000000,0x00000000}},	//   djeh_, --, --, --, 
   {{0x656800e4,0x4aac0b98,0xd25006c2,0x00000000}},	//   _ejeh, _ज्ञव, ينش_, --, 
   {{0x5224036b,0x2ae800af,0x95980993,0x438000d1}},	//   рфла, _जासु_, _атау_, غلىق, 
   {{0x39421a4b,0x80a09498,0x6568036e,0x613408a5}},	//   nkis_, يمىن, _gjeh, _sálr, 
   {{0x98640023,0x394000c0,0x00000000,0x00000000}},	//   _ተመሪሑ_, ikis_, --, --, 
   {{0x8df40107,0x394026bb,0x00000000,0x00000000}},	//   амоӣ_, hkis_, --, --, 
   {{0x39403110,0x8d857ab1,0xff4c007b,0x00000000}},	//   kkis_, иумд, بخي_, --, 
   {{0xaa440533,0x2ae8000d,0x00000000,0x00000000}},	//   ەنسى, _जाहु_, --, --, 
   {{0x2d84005f,0xb33c0327,0x00000000,0x00000000}},	//   ēle_, _tiħd, --, --, 
   {{0x0eba1a4c,0x39400153,0x00000000,0x00000000}},	//   _руды_, ekis_, --, --, 
   {{0x6d5c0077,0x3d18000d,0x00000000,0x00000000}},	//   éras, _बोवे_, --, --, 
   {{0x39421a4d,0xfe980375,0x00000000,0x00000000}},	//   gkis_, _ביומ, --, --, 
   {{0x61340174,0xc6a40124,0xac1800db,0x27fc0142}},	// [3da10] _málp, ареи, _сопу_, ïwn_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3d1c05ba,0x656801fa,0x39400211,0x6aa4003e}},	//   याचे_, _pjeh, bkis_, _ighf, 
   {{0x84b40046,0x39421a4e,0x4da001ec,0x00000000}},	//   рғау_, ckis_, _ﺍﻟﯟﯨ, --, 
   {{0x65680023,0x6d5c0194,0x320c00a2,0x00000000}},	//   _vjeh, iisa, _asdy_, --, 
   {{0x6d5e1a4f,0xfbb80302,0xdef802d3,0xdfe8020a}},	//   hisa, ספות_, ዋትን_, ҳдид_, 
   {{0x3ce805ba,0x656801ee,0xdcf40064,0x248800d7}},	//   _झाले_, _tjeh, _skyč, ťam_, 
   {{0x65680aa5,0xb33c0327,0x10a00395,0x00000000}},	//   _ujeh, _riħe, пиън, --, 
   {{0x201a1a50,0xd00c05d4,0x67342a3f,0xdb040158}},	//   ísi_, فلي_, _kozj, ppkø, 
   {{0x69c403ac,0x65780857,0x3ea0005c,0x00000000}},	//   _owhe, lowh, øjt_, --, 
   {{0x6d5e1a51,0x63aa1a52,0x212c1f7f,0x69c4013f}},	//   fisa, _huen, pjeh_, _nwhe, 
   {{0x63aa1a53,0x6d5c32ff,0x6aa40327,0x6e3c143a}},	//   _kuen, gisa, _aghf, ørba, 
   {{0x69c40374,0x63aa1a54,0x63a00024,0x7170a67e}},	//   _awhe, _juen, _kiln, _تۇيا, 
   {{0x63aa1a55,0x6d5e1a56,0x6578c403,0x00000000}},	//   _muen, érar, howh, --, 
   {{0x63aa1a57,0x63a21a58,0x657804fe,0x39421a59}},	//   _luen, _miln, kowh, tkis_, 
   {{0x6280b7ad,0x63aa1a5a,0x63a21a5b,0x83240327}},	//   _mylo, _ouen, _liln, _ཡོའུ_, 
   {{0x39421a5c,0x63a80097,0x6578011c,0x673407f5}},	// [3da20] rkis_, _nuen, dowh, _bozj, 
   {{0x39421a5d,0xdb0c049b,0x673400a2,0xcc540375}},	//   skis_, äkär, _cozj, _לספק_, 
   {{0x39400227,0x63aa1a5e,0xdb640092,0x00000000}},	//   pkis_, _auen, ተኛውም_, --, 
   {{0x63aa1a5f,0x63a0035a,0xa8b8084c,0xdff85d4f}},	//   _buen, _ailn, _вырф_, ्बाद_, 
   {{0x63aa1a60,0x63a21a61,0x6280035a,0x6ba0083c}},	//   _cuen, _biln, _aylo, _üzgü, 
   {{0x63aa1a62,0x79861a63,0x62800006,0x657802b5}},	//   _duen, lliw, _bylo, aowh, 
   {{0x63a21a64,0x63aa1a65,0x613410d8,0xf0e800d1}},	//   _diln, _euen, _pálp, لىغى_, 
   {{0x63aa1a66,0x3d184284,0x6d5e1a67,0x7984074d}},	//   _fuen, _बोले_, xisa, nliw, 
   {{0x63aa1a68,0x63a21a69,0x6fd80490,0x7985a46a}},	//   _guen, _filn, _मिळू, iliw, 
   {{0x6d5c094a,0x7985d063,0x8f08009d,0x24880037}},	//   wisa, hliw, ухиа_, üame_, 
   {{0x8778008d,0x52840597,0x63a805f5,0x81400ec9}},	//   ראיי, _الاك, _zuen, زنین, 
   {{0x63a000a8,0x63a80369,0xe6c40b8f,0x6d5e1a6a}},	//   _ziln, _yuen, _लज्ज, uisa, 
   {{0x79861a6b,0x63a007d6,0x10146d42,0xc0e000d8}},	//   dliw, _yiln, _دباد, _хочк, 
   {{0x6b80063f,0xe084007b,0x63a00009,0x69cc00e1}},	//   _ịgbo, _بجمي, _xiln, _तबदी, 
   {{0x628000b5,0x67354faf,0x6fb40451,0x9d640014}},	//   _xylo, _rozj, _امڪا, _ژنى۪, 
   {{0x79861a6c,0x6d5e1a6d,0x9f5c02e2,0xebc40166}},	//   gliw, qisa, _apwè_, _мәгн, 
   {{0xfd10009f,0x00000000,0x00000000,0x00000000}},	// [3da30] _سجي_, --, --, --, 
   {{0x63aa1a6e,0x79840337,0xbd040118,0x8b640133}},	//   _ruen, aliw, riéř, _دابم, 
   {{0x63aa1a6f,0x69c400b0,0x657802b5,0x046405a2}},	//   _suen, _uwhe, towh, әтем, 
   {{0x63a06b4d,0x63a8524a,0xdef8044e,0xa30017e6}},	//   _siln, _puen, ዋትና_, लज्ज_, 
   {{0x63a21a70,0x25ac05a1,0x65780053,0x63aa1a71}},	//   _piln, _čelu_, rowh, _quen, 
   {{0x62821a72,0x63a80226,0x074401d9,0x63a11eb2}},	//   _pylo, _vuen, _آسی_, _qiln, 
   {{0x63a21a73,0x26c21a74,0x657802b5,0x63a8002f}},	//   _viln, mbho_, powh, _wuen, 
   {{0x63aa1a75,0xdb140100,0x628002fd,0x3688010b}},	//   _tuen, _etyè, _vylo, _ысян_, 
   {{0x63a0b545,0x63a8007d,0x2ba41d34,0xa069491b}},	//   _tiln, _uuen, _गंगा, рапа_, 
   {{0x248c00f3,0x62801c1e,0x7984033f,0x00000000}},	//   _izem_, _tylo, zliw, --, 
   {{0x79840368,0xf20400c0,0x00000000,0x00000000}},	//   yliw, _няцо, --, --, 
   {{0x6d5e1a76,0x25a4026c,0xc0f002d3,0x31342b2e}},	//   érap, _éllu_, ሃቦም_, _нехр, 
   {{0x5ae40327,0x6d2400c7,0x5f4402cb,0x00000000}},	//   _སྐུམ, _ẽháp, _ونصل, --, 
   {{0x7984015d,0x00000000,0x00000000,0x00000000}},	//   wliw, --, --, --, 
   {{0x79861a77,0x999c00bc,0xcb647af6,0x26c00055}},	//   tliw, átů_, царе_, dbho_, 
   {{0x79861a78,0x201c0034,0x248c010b,0x00000000}},	//   uliw, _krwi_, _ozem_, --, 
   {{0x79861a79,0x3dc40042,0x0d80109a,0xe7e028d4}},	// [3da40] rliw, _hwnw_, _ільн, गंगा_, 
   {{0x79861a7a,0x00000000,0x00000000,0x00000000}},	//   sliw, --, --, --, 
   {{0x98a61a7b,0x9a880014,0x248d3143,0x99d41541}},	//   _мине, _خندٕ_, _azem_, _بتخا, 
   {{0x201c047e,0x92a4033f,0x75dc054e,0x3a0800e5}},	//   _orwi_, zyłą, văză, _پکڑی_, 
   {{0xd6d800f2,0x00000000,0x00000000,0x00000000}},	//   _پوزش_, --, --, --, 
   {{0xb33c0327,0x8c180302,0x00000000,0x00000000}},	//   _biħa, יוני, --, --, 
   {{0x07a0074d,0xd5b035b6,0x00000000,0x00000000}},	//   _царн, _آفر_, --, --, 
   {{0xb0345267,0x201c012d,0x35c4014b,0x00000000}},	//   зниш, _brwi_, _маҳҳ, --, 
   {{0xd37022e0,0xe1e801d9,0x63c401af,0x4abc00cd}},	//   _قهر_, لى۪و_, _натҡ, ्रमव, 
   {{0xb8cc031c,0x656801e4,0x6e3c072b,0x00000000}},	//   _པཔ_, _ĉehi, ørbo, --, 
   {{0x32180216,0x6b5001e1,0x44e80142,0x4718010f}},	//   _éry_, _lógù, _yո_, בויג, 
   {{0x8fa53e76,0x4abc00cd,0xc2780677,0x4124030d}},	//   _даде, ्रभव, _דרבי, _мохо_, 
   {{0xa6d400bd,0x4598008f,0x0f70036b,0x4c7001e0}},	//   স্টট, יסטע, _оғир, ьҫир, 
   {{0x0a682069,0xfbdc07f7,0x00000000,0x00000000}},	//   арби_, _बिरम, --, --, 
   {{0x6f08127b,0x68fc01ab,0xb33c031c,0x0dc87995}},	//   medc, _pbsd, _xiħa, _тули_, 
   {{0x6f080c8c,0x50640408,0x00000000,0x00000000}},	//   ledc, _утçа, --, --, 
   {{0x2ca801d9,0x00000000,0x00000000,0x00000000}},	// [3da50] _igad_, --, --, --, 
   {{0x6f08127b,0xfe4c00a2,0x2d98000d,0xccb80150}},	//   nedc, _öçük_, lmse_, _ﺸﺎﺅل_, 
   {{0x2d9a1a7c,0x248c01ed,0x88c41095,0x00000000}},	//   omse_, _szem_, _وتحل, --, 
   {{0x02b00316,0xb33c0327,0x6f0a0ade,0x69d401d3}},	//   ँड्न, _riħa, hedc, msze, 
   {{0x68ee1a7d,0x69d45642,0x2d9a1a7e,0x6f080857}},	//   mgad, lsze, imse_, kedc, 
   {{0x290a1a7f,0x27e872e2,0x85b801d9,0x6f080427}},	//   leaa_, muan_, _نارس_, jedc, 
   {{0x27ea1a80,0x3f98011c,0x69d42605,0x2ca80165}},	//   luan_, _èqui_, nsze, _ogad_, 
   {{0x2ca80589,0x20561a81,0x27e80076,0x69d40112}},	//   _ngad_, зтор, ouan_, isze, 
   {{0x27ea1a82,0x68ee1a83,0x6f080076,0x00000000}},	//   nuan_, igad, fedc, --, 
   {{0x2caa1a84,0x29095a6f,0xa0680046,0x69d400dd}},	//   _agad_, heaa_, _қала_, ksze, 
   {{0x27ea1a85,0x68ec073c,0x290802f6,0x69d40034}},	//   huan_, kgad, keaa_, jsze, 
   {{0x27ea1a86,0x69d45642,0x31140845,0x00000000}},	//   kuan_, dsze, _офіс, --, 
   {{0x27e82c3e,0x68ee1a87,0x201c014f,0x69d4012d}},	//   juan_, dgad, _urwi_, esze, 
   {{0x27e98c4e,0x2d9a1a88,0x200c0649,0x68ec1163}},	//   duan_, amse_, mwei_, egad, 
   {{0x69d400dd,0x200e1a89,0x68ec01ab,0x3264030d}},	//   gsze, lwei_, fgad, _ртăв, 
   {{0x6e3e1a8a,0x2c7402e3,0x27ea1a8b,0x00000000}},	//   ärbe, ụda_, fuan_, --, 
   {{0x200e1a8c,0xb9040da0,0x00000000,0x00000000}},	// [3da60] nwei_, _नय_, --, --, 
   {{0x96940b3b,0x69d61a8d,0x00000000,0x00000000}},	//   преш, bsze, --, --, 
   {{0x200d31fd,0x2b140073,0x62840254,0xd76400e5}},	//   hwei_, _फोटु_, ühol, _ہاسٹ, 
   {{0x27e84460,0x200e1a8e,0x0b7802d3,0x186a1a8f}},	//   buan_, kwei_, _ራብዓይ_, _гами_, 
   {{0x27e83a97,0x6f08035a,0x044000d8,0x00000000}},	//   cuan_, yedc, нецн, --, 
   {{0x200c000f,0xe9a81056,0x6f080334,0xd6d800f2}},	//   dwei_, _ددین_, xedc, _دوسش_, 
   {{0x6f0a1a90,0x200c002d,0xb0280150,0x213801b9}},	//   vedc, ewei_, _روﻟﯩ, аsh_, 
   {{0x6fb40b24,0x2bec0073,0x00000000,0x00000000}},	//   ومبا, _जमलं_, --, --, 
   {{0x6f0814dc,0x69d4295f,0x6d5c180f,0x99880064}},	//   tedc, zsze, èram, lybų_, 
   {{0x69d59742,0x68ee1a91,0xf1b80135,0x00000000}},	//   ysze, zgad, _erġa_, --, 
   {{0x68ee1a92,0x6f080c8c,0x27ea1a93,0x200c002d}},	//   ygad, redc, zuan_, awei_, 
   {{0x27ea1a94,0x6f08127b,0x00000000,0x00000000}},	//   yuan_, sedc, --, --, 
   {{0x69d4068f,0x29080093,0xb33c0327,0x27ea1a95}},	//   wsze, veaa_, _jiħo, xuan_, 
   {{0x69d5ecea,0x27e8036e,0xfe6c00f2,0x7bd80055}},	//   tsze, vuan_, ئدی_, _āvut, 
   {{0x68ee1a96,0x69d61a97,0x2bd81889,0x290a1a98}},	//   tgad, usze, _भटका, teaa_, 
   {{0x27ea1a99,0x69d61a9a,0xb30c0327,0x68ec0165}},	//   tuan_, rsze, _གིའང_, ugad, 
   {{0x6d4e1a9b,0x69d400dd,0x6b740022,0xa9a4010b}},	// [3da70] _ilaa, ssze, _олиу, зиңд, 
   {{0x68ee1a9c,0x69d41b7a,0x4420013a,0x0a68119e}},	//   sgad, psze, _čj_, _грми_, 
   {{0x6d4e1a9d,0x27ea1a9e,0x290a1a9f,0xe8d801f2}},	//   _klaa, suan_, peaa_, elụ_, 
   {{0x27ea1aa0,0x200c0421,0x5fdc00af,0xba08030d}},	//   puan_, ywei_, _मिलल, _эхье_, 
   {{0x27e80428,0xe1f00502,0x6d4c0072,0x39b8007f}},	//   quan_, چسب_, _mlaa, _včse_, 
   {{0x6d4c01d9,0x00e40150,0x4abc00cd,0xe1f000ae}},	//   _llaa, _ﺍﻋﺘﻘ, ्रिव, نسب_, 
   {{0x6d4c0a55,0xc2c800cf,0xa2940240,0x00000000}},	//   _olaa, _ۇبال_, _ቅንጸላ_, --, 
   {{0xa0a43a13,0x60251bf5,0x05740532,0x200cfeeb}},	//   майд, ддиа, _رازد, twei_, 
   {{0x4abc07f8,0x02a61aa1,0xa2f400ea,0xd9d82713}},	//   ्राव, _ерем, _опач, _बट्ट, 
   {{0x200e1aa2,0x2ae80073,0x00000000,0x00000000}},	//   rwei_, _जागु_, --, --, 
   {{0x6d4cc4c1,0xc1000323,0x200c1983,0x1d080aa8}},	//   _blaa, _зүйл, swei_, оени_, 
   {{0x6d4d44e1,0x00000000,0x00000000,0x00000000}},	//   _claa, --, --, --, 
   {{0x7bd800b8,0x00000000,0x00000000,0x00000000}},	//   _āvus, --, --, --, 
   {{0x2f1802f6,0x6d4c0ba7,0x8ba176cb,0x6ee40150}},	//   _ночь_, _elaa, кияж, _كسىل, 
   {{0x6d4e1aa3,0x8ba03946,0x3208074d,0x00000000}},	//   _flaa, тирж, _яхăн_, --, 
   {{0x6d4e1aa4,0x00000000,0x00000000,0x00000000}},	//   _glaa, --, --, --, 
   {{0xd760036b,0x00000000,0x00000000,0x00000000}},	// [3da80] نچسی, --, --, --, 
   {{0x6d4c01fa,0x99880024,0xdc4400ef,0x00000000}},	//   _zlaa, tybų_, _mīļv, --, 
   {{0x81b003d4,0x00000000,0x00000000,0x00000000}},	//   জীত_, --, --, --, 
   {{0x94841ac1,0x99880024,0xc68c01d9,0xd40401ee}},	//   мылд, rybų_, جِم_, дяки, 
   {{0x06e00729,0x3d0053b7,0x67480162,0x00000000}},	//   ন্ধি, ष्ये_, ásjó, --, 
   {{0xff440b24,0xfbd000dc,0x2fc000a2,0x6cc001ec}},	//   _شخ_, तीयम, _çigi_, _ﺣﯩﺠﻴ, 
   {{0x6d5c020c,0x00000000,0x00000000,0x00000000}},	//   èrak, --, --, --, 
   {{0x09a8009e,0xb33c0327,0x301401e5,0x613401d3}},	//   গীকা, _tiħo, едир, _kály, 
   {{0xc4800276,0x00000000,0x00000000,0x00000000}},	//   _алтк, --, --, --, 
   {{0x6d4e1aa5,0xc4380375,0x91780051,0x1c2003ce}},	//   _slaa, _ותמי, _bậy_, मिनल_, 
   {{0x6d4de1c2,0xceb400d1,0x91780051,0x63ac010f}},	//   _plaa, пәқ_, _cậy_, ŭant, 
   {{0x50661aa6,0x50d5120a,0x61e4022a,0x91780051}},	//   _отла, _آزار, áhle, _dậy_, 
   {{0x6d4e1aa7,0xb30c08ea,0xe570008f,0x6fd801f9}},	//   _vlaa, _གྲོང_, אַם_, _मिटू, 
   {{0xc0b82295,0x6d4c0009,0x628c0694,0xa2c03599}},	//   ተዋል_, _wlaa, _ñooñ, रुप्, 
   {{0x6d4c0032,0xa6cc009e,0x00000000,0x00000000}},	//   _tlaa, _লালট, --, --, 
   {{0x6d4c198f,0xac961aa8,0x7b380166,0x35d8033f}},	//   _ulaa, _пайш, _aşuı, _डिज़, 
   {{0x6f180427,0x79a4035b,0x3d1801f9,0x00000000}},	// [3da90] _kavc, трре, _बोटे_, --, 
   {{0x3d0053b7,0x6a140022,0x47880024,0x78300092}},	//   ष्ठे_, _змоу, ісам_, _ተጫዋቾ, 
   {{0x6f180010,0x46680022,0x00000000,0x00000000}},	//   _mavc, црам_, --, --, 
   {{0xa83415ed,0xaa900022,0xa2c018cc,0x00000000}},	//   _земљ, _аҳҳә, रुन्, --, 
   {{0x291a1aa9,0x232894d6,0xfa4000cd,0xd3443829}},	//   _iasa_, золи_, _eṣām_, کیله_, 
   {{0xb3e010f7,0x291800b2,0x6f1931db,0x00000000}},	//   _निरख, _hasa_, _navc, --, 
   {{0x291a1aaa,0x236804b9,0xe3b8000f,0x05761aab}},	//   _kasa_, đaj_, _grűn_, _قارد, 
   {{0x291908b5,0x6f1803ac,0x63ac056a,0xe0d80cb6}},	//   _jasa_, _aavc, íans, чви_, 
   {{0x291a1aac,0x6f180010,0x00000000,0x00000000}},	//   _masa_, _bavc, --, --, 
   {{0x291a1aad,0x4dc40131,0x26d00427,0xdb04007c}},	//   _lasa_, ﯩﻘﯩﻨ, _jezo_, lpkö, 
   {{0x26d0008f,0xdee40364,0x291805d5,0x6f180010}},	//   _mezo_, _ҷоли, _oasa_, _davc, 
   {{0x26d007cf,0x6e3e1aae,0x917801fb,0x291a1aaf}},	//   _lezo_, ärba, _vậy_, _nasa_, 
   {{0x6f180327,0xdee61ab0,0x0ddc0023,0x00000000}},	//   _favc, _золи, ሓለፈ_, --, 
   {{0x2919e01c,0x26d0004b,0x5dd802e8,0x66147ddf}},	//   _aasa_, _nezo_, _ефир_, _oszk, 
   {{0x291a1ab1,0x68400092,0x00000000,0x00000000}},	//   _basa_, _የመለስ, --, --, 
   {{0x613400dd,0xa3c005f9,0x7c2400c7,0x6f180427}},	//   _pály, ूठा_, _азиҧ, _zavc, 
   {{0x7d040537,0x291a1ab2,0x57e80024,0xac10010a}},	// [3daa0] _ibis, _dasa_, ядам_, _кĕте_, 
   {{0x7c261ab3,0x06e009bd,0x29184a43,0x3164007f}},	//   _irir, ন্সি, _easa_, zimz_, 
   {{0x291a1ab4,0x26d21ab5,0xf9841621,0x7c240165}},	//   _fasa_, _dezo_, _аҳво, _hrir, 
   {{0x291a1ab6,0xa69400ea,0x00000000,0x00000000}},	//   _gasa_, труј, --, --, 
   {{0x7d061ab7,0x661400dd,0xb30c0135,0x26d001e4}},	//   _mbis, _eszk, _གྲུང_, _fezo_, 
   {{0x291a1ab8,0x7d040327,0x9f4c005b,0x6d5c0129}},	//   _zasa_, _lbis, nteä_, éraz, 
   {{0x7d061ab9,0x291a1aba,0x06880150,0x3ce001ef}},	//   _obis, _yasa_, _ﺒﺭﻓﺽ_, _odiv_, 
   {{0x9f4c02f6,0x7d0401f2,0x7c240521,0x26d21abb}},	//   hteä_, _nbis, _orir, _zezo_, 
   {{0xb3a5b1fb,0x213c05b1,0x26d001e2,0x1424010b}},	//   _алаһ, _dowh_, _yezo_, _ядам, 
   {{0x461001ed,0x00000000,0x00000000,0x00000000}},	//   _جوہر, --, --, --, 
   {{0x6f180455,0xbed401c6,0x00000000,0x00000000}},	//   _vavc, эдэх_, --, --, 
   {{0x7c240240,0x00000000,0x00000000,0x00000000}},	//   _brir, --, --, --, 
   {{0x29183aad,0x8d740150,0x1b180154,0x00000000}},	//   _rasa_, _ۋاعا, দানে_, --, 
   {{0x291a1abc,0x7d061abd,0x7c247afe,0x81300124}},	//   _sasa_, _ebis, _drir, _ахәц, 
   {{0xb9e410f5,0x26d21abe,0x7c261abf,0x00000000}},	//   літи, _rezo_, _erir, --, 
   {{0x291881f1,0x26d074c2,0x7c24005c,0x2d9c110e}},	//   _qasa_, _sezo_, _frir, _òwe_, 
   {{0x291a1ac0,0x26d0c9d5,0xc0ec02d3,0x7c261ac1}},	// [3dab0] _vasa_, _pezo_, _ቀትሪ_, _grir, 
   {{0x291a1ac2,0x7d040010,0x00000000,0x00000000}},	//   _wasa_, _zbis, --, --, 
   {{0x26d068b5,0x8aa46610,0x5ed40154,0x2c1800cd}},	//   _vezo_, _ярид, _দামে, दिकं_, 
   {{0x59b438bf,0xbc6850b5,0x5570016c,0x26d0009a}},	//   _आंतर, _آمین_, аҳст, _wezo_, 
   {{0x26d21ac3,0xf82401af,0x00000000,0x00000000}},	//   _tezo_, _йєрм, --, --, 
   {{0x27e8ca3c,0xba7402dd,0x63840395,0x00000000}},	//   mran_, _جاۋت, ъгла, --, 
   {{0x66140034,0x778412c4,0x21740276,0x6da80055}},	//   _uszk, _слёз, куир, _rśan, 
   {{0x27e80428,0x659491e4,0x54b001af,0xe518000d}},	//   oran_, _рабу, _кәшф, _नोचि_, 
   {{0x27ea1ac4,0x8738001f,0xe3141f5a,0x00000000}},	//   nran_, _በማስቀ, _имањ, --, 
   {{0x27ea1ac5,0x7c24025a,0x4f2000c9,0xdb0c025a}},	//   iran_, _rrir, адьб, äkür, 
   {{0x64581543,0xa2c001bc,0x93440137,0x00000000}},	//   lzwi, रुण्, _جىلۇ, --, 
   {{0x27ea1ac6,0xd00cd653,0x25e81889,0x7d040327}},	//   kran_, حلی_, _चटनी_, _qbis, 
   {{0x60ca1ac7,0x64580e8a,0x118401ed,0x7d061ac8}},	//   mbem, nzwi, _جھوٹ_, _vbis, 
   {{0x27ea1ac9,0x9f4c049f,0xdee61aca,0x5928031c}},	//   dran_, fteå_, _роки, _ཤོངས_, 
   {{0x27ea1acb,0xc1b80ed1,0x7d04025c,0x81b00154}},	//   eran_, _ﻧﺎﺯﺍ, _tbis, জীর_, 
   {{0x7d061acc,0x01e002a6,0xa2c00c00,0x27ea1acd}},	//   _ubis, _মহাদ, रुत्, fran_, 
   {{0x7c24aaa6,0x2be800af,0x108800d1,0x00000000}},	// [3dac0] _urir, _जियू_, ﺗﯩﺪﯨ, --, 
   {{0x77941291,0x64580210,0x00000000,0x00000000}},	//   ایسا, dzwi, --, --, 
   {{0x27ea1ace,0x9984007b,0xb3a401e0,0x00000000}},	//   aran_, _للدو, ңлеһ, --, 
   {{0xd945590a,0x546a1acf,0x33bc0116,0x00000000}},	//   _реми, маем_, _ﻧﻮﺭﻣ, --, 
   {{0xc1b81df2,0x3f840427,0x27e9a0f0,0x60c8143a}},	//   _ﻧﺎﺭﺍ, _oknu_, cran_, dbem, 
   {{0x60c80083,0x00000000,0x00000000,0x00000000}},	//   ebem, --, --, --, 
   {{0xca2c0075,0xa2c00a94,0x95861ad0,0x00000000}},	//   ﯩﻐﺎ_, रुध्, _алве, --, 
   {{0x60c8f126,0xdce402d5,0x79840099,0x660c01d3}},	//   gbem, mokė, noiw, őnké, 
   {{0xcee80424,0x00000000,0x00000000,0x00000000}},	//   وردن_, --, --, --, 
   {{0xa2c01c15,0x03200166,0x00000000,0x00000000}},	//   रुद्, _кдун, --, --, 
   {{0x60c9a537,0x79861ad1,0x03a0014b,0xe81803ba}},	//   bbem, koiw, _тифо, _नैना_, 
   {{0x27ea1ad2,0xd20001af,0x00000000,0x00000000}},	//   yran_, _бүҫк, --, --, 
   {{0xf00401f0,0x00000000,0x00000000,0x00000000}},	//   _сӯйи, --, --, --, 
   {{0x2bb40034,0xaee400b8,0x31b801d3,0x00000000}},	//   ंदबा, _kaṭy, _kéz_, --, 
   {{0x27ea1ad3,0xaa584f0c,0xdce400c0,0x00000000}},	//   wran_, хиву_, jokė, --, 
   {{0x27ea1ad4,0x6e3c4606,0x38c40212,0x8274010f}},	//   tran_, ørbu, ищув, דעלע_, 
   {{0x27ea1ad5,0x603002ea,0x2d88009f,0x98a00153}},	// [3dad0] uran_, tɛmɛ, _ikae_, _mokė_, 
   {{0x27ea1ad6,0xe71a1ad7,0x66d40451,0x4668013d}},	//   rran_, عيات_, ايائ, мрем_, 
   {{0x27e84870,0xc6a400c9,0x31b801ed,0x6594a23f}},	//   sran_, траи, _néz_, гажу, 
   {{0x27ea1ad8,0x64580732,0x87d4013e,0x00000000}},	//   pran_, tzwi, _илмӣ_, --, 
   {{0xa2e45229,0x2d8801f7,0x645805c7,0x108800d1}},	//   голд, _mkae_, uzwi, ﺗﯩﺮﯨ, 
   {{0x31b8030a,0x645a1ad9,0xb3840024,0x57a400fb}},	//   _béz_, rzwi, аліл, _бысҡ, 
   {{0x2d880086,0x6da80055,0x6458b29b,0x6e3c007c}},	//   _okae_, _aśam, szwi, ärbl, 
   {{0xd12c0075,0x2d88016b,0xf5240166,0x16380092}},	//   كمى_, _nkae_, _кфун, _አሸባሪ, 
   {{0x60c8061f,0xe4740640,0x6da80055,0x1fa80107}},	//   rbem, _слањ, _cśam, нкии_, 
   {{0x25ae1ada,0x248c003e,0x2d88b926,0x79840810}},	//   _hiel_, _iyem_, _akae_, zoiw, 
   {{0x25ac30fb,0x248c013f,0x798401f7,0x9f0401e2}},	//   _kiel_, _hyem_, yoiw, نوکو, 
   {{0x25ac29ef,0x81a4027d,0xdfd43f1b,0x00000000}},	//   _jiel_, _شحال, _боды, --, 
   {{0x63b8009a,0x798402d0,0x5fdc01f9,0x00000000}},	//   nqwn, voiw, _मिटल, --, 
   {{0x2d880428,0x9b94a675,0xabc401e0,0xaaa40404}},	//   _ekae_, الست, рарҙ, _गृहक, 
   {{0xdea21adb,0xe3b8002d,0xc5f80011,0x05ac0118}},	//   _دیدی, _brűk_, ীয়তা_, _जंगब, 
   {{0x25ae1adc,0x9f200131,0x00000000,0x00000000}},	//   _niel_, _ئۈگۈ, --, --, 
   {{0x2a680020,0x248c0457,0x271c015b,0x23b802e2}},	// [3dae0] ደሚገባ_, _nyem_, নানো_, _nèj_, 
   {{0x34cc2e35,0x8c18011a,0xb5880014,0x00000000}},	//   ार्द, _טופי, چھرٕ_, --, 
   {{0x248e1add,0x798406c8,0x8af8008d,0x25e80490}},	//   _ayem_, poiw, _אפיק, _चटणी_, 
   {{0x25ae1ade,0x23b8007f,0xa2c01cb7,0xdce40153}},	//   _ciel_, _bèj_, रुस्, rokė, 
   {{0x98680201,0x93884712,0x25ae1adf,0x9f58006a}},	//   _በመሆኑ_, нска_, _diel_, ïsû_, 
   {{0x31b807de,0x4cbc02f5,0x00000000,0x00000000}},	//   _péz_, ্ণযু, --, --, 
   {{0x248c020c,0x941003e3,0xd1ba1ae0,0x00000000}},	//   _eyem_, _ədəb_, راغا_, --, 
   {{0x25ae1ae1,0x7bc61ae2,0xc21400d4,0xc204d5d8}},	//   _giel_, _otiu, уєш_, اقين_, 
   {{0x81341dc8,0x854401d5,0xcfa4035b,0x02500003}},	//   اسىز_, _ёзув_, лшои, ħħaħ_, 
   {{0x25ae1ae3,0xb19400c7,0x42500166,0xe044010a}},	//   _ziel_, ылқә, ртәт, ăнпи, 
   {{0x7bc61ae4,0x6e94468b,0x248c02e2,0x6d9c01e7}},	//   _atiu, рину, _zyem_, néag, 
   {{0xc278159d,0x2b421ae5,0x00000000,0x00000000}},	//   _ארבי, _sohc_, --, --, 
   {{0x248c01d4,0x60dc05f7,0xff4c179e,0x00000000}},	//   _xyem_, ðsme, زخی_, --, 
   {{0xdb14004d,0x409000c6,0xdde000d0,0x6ac401b9}},	//   _huyê, _الهر, žuši, شقرم, 
   {{0xdb14019f,0x2c14009e,0x7bc44632,0x478401ec}},	//   _kuyê, ামেই_, _etiu, ңызб, 
   {{0x7bc400a3,0x2d8801f7,0xf7700873,0x2488012d}},	//   _ftiu, _ukae_, ۋال_, żami_, 
   {{0x7d7420d4,0x9e240014,0x00000000,0x00000000}},	// [3daf0] _داوط, _مى۪و, --, --, 
   {{0x25ae1ae6,0x1c2002ab,0xdb14004d,0x28b0033f}},	//   _siel_, मिरल_, _luyê, _झलकि, 
   {{0x25ae1ae7,0xb33c031c,0xf7708344,0x85440166}},	//   _piel_, _jiħu, ساك_, лэде, 
   {{0x69c61ae8,0x368800f7,0x248c0100,0x23b8007f}},	//   _ithe, усун_, _pyem_, _pèj_, 
   {{0x25ae1ae9,0x6d9c00c6,0x6da800dc,0x271c00eb}},	//   _viel_, méad, _aśak, নাবো_, 
   {{0x69c4044e,0x25ac5be4,0xceb80b45,0x61e40118}},	//   _kthe, _wiel_, _yaƙe_, áhlo, 
   {{0x25ac04ac,0xa2c00b7c,0x6da80055,0x00000000}},	//   _tiel_, रुष्, _cśak, --, 
   {{0x69c61aea,0x6008d328,0x248c1529,0xe2984eac}},	//   _mthe, вним_, _tyem_, наһ_, 
   {{0xdb14001e,0x69c40076,0xf4840022,0xa318008e}},	//   _duyê, _lthe, _луфн, _ижау_, 
   {{0x69c61aeb,0x6d9c007b,0xde0400c7,0xa2c0043e}},	//   _othe, héad, апои, रुश्, 
   {{0x7bc61aec,0x69c4055a,0x53980375,0x8d740092}},	//   _stiu, _nthe, _סיעו, ከፈተው_, 
   {{0xdca4084c,0x61e00175,0xa2c000cd,0x201801bf}},	//   иани, _ivll, रुर्, æsis_, 
   {{0x69c47ec8,0x6e3c143a,0xee3800e5,0xfbd001f9}},	//   _athe, ørbr, نقیں_, तींम, 
   {{0x69c403a2,0x00000000,0x00000000,0x00000000}},	//   _bthe, --, --, --, 
   {{0x6d9c0597,0x69c4015d,0x2a340276,0xd945981f}},	//   féad, _cthe, бэтр, аеви, 
   {{0x1c4425f2,0xdb140016,0x69c000c6,0xd1b80092}},	//   _вним, _xuyê, ílea, _ታወቀ_, 
   {{0xceb803f9,0x7bc45686,0x7f421aed,0x69c61aee}},	// [3db00] _waƙe_, _utiu, _konq, _ethe, 
   {{0x7f421aef,0x00000000,0x00000000,0x00000000}},	//   _jonq, --, --, --, 
   {{0xa2d80c2e,0xb8fc015b,0x7f4003e3,0x00000000}},	//   _नज़्, _ঠা_, _monq, --, 
   {{0x7f406b2c,0x6d9c01e7,0xaac40066,0x00000000}},	//   _lonq, réag, _پتین, --, 
   {{0x61e00200,0x5de000cc,0x00000000,0x00000000}},	//   _avll, _বহোঁ, --, --, 
   {{0x7f421af0,0x96b8aa97,0x69c402d0,0x23e400d4}},	//   _nonq, _шуму_, _ythe, сіїв, 
   {{0x877808a8,0xcb340a7c,0xd4f40153,0x00000000}},	//   _סאלי, ינסק_, _вязы, --, 
   {{0xdb14001e,0x00000000,0x00000000,0x00000000}},	//   _quyê, --, --, --, 
   {{0x7f411990,0x00000000,0x00000000,0x00000000}},	//   _bonq, --, --, --, 
   {{0x4ea40408,0x7f803c19,0x8f4401a9,0x00200241}},	//   ирна, يلين, рхид, _ọlọ́, 
   {{0xdb140016,0x7f421af1,0xd17400f7,0x75221af2}},	//   _tuyê, _donq, _кыды, _kamz, 
   {{0x69c61af3,0x206801ec,0x00000000,0x00000000}},	//   _rthe, _өшіп_, --, --, 
   {{0x752005da,0x7f41011d,0x6d9c007b,0xdcf4013d}},	//   _mamz, _fonq, véad, _ciyı, 
   {{0x7f400369,0xb33c031c,0x3f64014b,0xbdf41291}},	//   _gonq, _tiħu, _кичо_, دریا_, 
   {{0xe81805f9,0x6ecc00cd,0x3eb000d7,0x00000000}},	//   नौना_, _द्यु, ňaté_, --, 
   {{0x7f4001e2,0x752000fd,0x3cd402e8,0x00000000}},	//   _zonq, _namz, _джъс, --, 
   {{0x7f400472,0x3c4401c0,0x79a401ec,0x6d9c01e7}},	// [3db10] _yonq, _дээв, ірсе, réad, 
   {{0x7f415dbc,0x0a6801c6,0xf77001d9,0x6d9c00ae}},	//   _xonq, _арми_, ٘ام_, séad, 
   {{0x69c481b3,0x7520014b,0x6da800b8,0x6d9c007b}},	//   _uthe, _bamz, _aśai, péad, 
   {{0x3a740166,0xdcf40139,0x00000000,0x00000000}},	//   _флюр, _yiyı, --, --, 
   {{0x7520715a,0x68fc035a,0x240801d5,0xd72400cc}},	//   _damz, _icsd, унли_, _মকৰা_, 
   {{0x5fd0000d,0x00000000,0x00000000,0x00000000}},	//   _दौगल, --, --, --, 
   {{0x216a1af4,0x75200369,0xb638490c,0x00000000}},	//   лики_, _famz, _кпрф_, --, 
   {{0xd24caf57,0xb33c025c,0x7f421af5,0x752065f7}},	//   عني_, _biħs, _sonq, _gamz, 
   {{0x656a1af6,0x7f400789,0x26c00789,0x3e540213}},	//   _imeh, _ponq, ocho_, mətə_, 
   {{0x26c21af7,0x7f421af8,0x61e0003a,0x6d5c0de2}},	//   ncho_, _qonq, _tvll, ëran, 
   {{0x22955d3f,0x26c0006f,0x7520009f,0x2f540212}},	//   _الاس, icho_, _yamz, ітьс, 
   {{0x313402a9,0x752049f0,0x6b580248,0x6d5c00e4}},	//   _мехр, _xamz, _nìgb, èrap, 
   {{0x656800b4,0x7f421af9,0x69c0012c,0x40840b3e}},	//   _mmeh, _tonq, ílen, _тужб, 
   {{0x60d80455,0x83cc012d,0x3e5403e3,0x00000000}},	//   _hewm, सीएआ, hətə_, --, 
   {{0x65680c8c,0x26c15d4a,0x9d461afa,0x1b1800cc}},	//   _omeh, dcho_, _гейд, দালে_, 
   {{0x38c81482,0x6568063f,0xdcf40139,0x274401ef}},	//   شاری_, _nmeh, _tiyı, _líně_, 
   {{0x75221afb,0xceb80198,0x6b580241,0x39b802e2}},	// [3db20] _ramz, _haƙa_, _dìgb, _mčsi_, 
   {{0x6568c44f,0xe8f80364,0x75217e4b,0x5928031c}},	//   _ameh, ллӣ_, _samz, _ཤོམས_, 
   {{0x75200161,0x6b5801e1,0x3e540213,0x00000000}},	//   _pamz, _fìgb, fətə_, --, 
   {{0x26c03545,0x201c047e,0x26080118,0x00000000}},	//   acho_, _oswi_, _सहरी_, --, 
   {{0x75200006,0x85005a16,0x28740022,0x2d7c01e4}},	//   _vamz, سوون, _дырр, nĉea_, 
   {{0x656a1afc,0x8c180302,0x75221afd,0xf6640116}},	//   _emeh, טוני, _wamz, _дегү, 
   {{0x201c0564,0x752005da,0x6d9c007b,0xcb1002e4}},	//   _aswi_, _tamz, néac, פלה_, 
   {{0xdb140c6a,0x7520009f,0x00000000,0x00000000}},	//   _duyé, _uamz, --, --, 
   {{0x60dc1f60,0x38621afe,0x60d80135,0x6d9c00ae}},	//   ðsma, nzir_, _dewm, héac, 
   {{0x0dc800d1,0x3860009f,0x65680427,0x9f4801e1}},	//   луми_, izir_, _zmeh, _ìkìs_, 
   {{0x394034fe,0x201c0455,0x4cbc00cc,0x00000000}},	//   kjis_, _eswi_, ্ণসু, --, 
   {{0x069404ae,0x386005b1,0x26c004cc,0x14cc07b7}},	//   מדים_, kzir_, zcho_, _ह्मण, 
   {{0x06e011ba,0x4598010f,0xe8d80051,0x2cac0254}},	//   ন্টি, טסטע, giờ_, äed_, 
   {{0x0eba1aff,0x6d9c01e7,0x6b5801e1,0x1ea800ec}},	//   _суды_, féac, _sìgb, _ڦاهي_, 
   {{0x6d9dca14,0x60cc054e,0x2bd807f7,0x62fc0154}},	//   réab, _înmâ, _बौरा, _এসময়_, 
   {{0x6d9c0129,0x3940036e,0x66000166,0xc8a80166}},	//   séab, gjis_, _älki, гъзе_, 
   {{0x26c0007f,0xd1e80020,0x6d5e1b00,0x65680076}},	// [3db30] tcho_, መረቀ_, mhsa, _rmeh, 
   {{0x26c21b01,0x65687e96,0x1bec000d,0x6b7400d8}},	//   ucho_, _smeh, _जितल_, _флоу, 
   {{0x26c11c6b,0xdce41991,0x6b580248,0x00000000}},	//   rcho_, likā, _tìgb, --, 
   {{0x6d5e1b02,0x26c21b03,0x24561b04,0xa92800cf}},	//   nhsa, scho_, يناس, _ئزدە_, 
   {{0xdce41991,0x2908d879,0x60d98eda,0x00000000}},	//   nikā, mfaa_, _rewm, --, 
   {{0x29080ba7,0x26c00309,0x7bdc0677,0x00000000}},	//   lfaa_, qcho_, נקוו, --, 
   {{0x29098cf9,0xdce400dc,0x6d5dea02,0xe29a1b05}},	//   ofaa_, hikā, khsa, шак_, 
   {{0x656a1b06,0x29080ba7,0x672401e3,0x00000000}},	//   _umeh, nfaa_, ldhj, --, 
   {{0xceb803f9,0x6d5e1b07,0xe5a4010b,0x00000000}},	//   _saƙa_, dhsa, _гиңи, --, 
   {{0x67242d75,0x9f4c0589,0xdce40aed,0x2d8001e4}},	//   ndhj, dueã_, dikā, _ĉiea_, 
   {{0xe8d844fc,0x802452d4,0xa15a1b08,0x60d8025c}},	//   ghị_, _گرام, _кажу_, _tewm, 
   {{0xdce400da,0x6d5e1b09,0x9f54006a,0x628001b9}},	//   fikā, ghsa, ägâo_, _ixlo, 
   {{0x80261b0a,0xdee61b0b,0x201c02c4,0x65780c8c}},	//   _درام, _доли, _uswi_, inwh, 
   {{0x9a941772,0x6d5c0067,0x67240200,0x13b8010f}},	//   _መትከል_, ahsa, jdhj, יזשע, 
   {{0x6d5c7ea1,0x29080a55,0x9d4409a5,0xe8d800b4}},	//   bhsa, ffaa_, _мекд, chị_, 
   {{0x6d5e1b0c,0x67340003,0xae784dba,0x6d9c007b}},	//   chsa, _anzj, _усіх_, réac, 
   {{0x57461b0d,0x97d8005b,0x394001f4,0xead800cc}},	// [3db40] онаб, рьбу_, rjis_, _তাৰম, 
   {{0x63a002c4,0x969403b7,0x29088ebb,0x7958008e}},	//   _nhln, ореш, afaa_, _díwa, 
   {{0x80bc015b,0x1c2028d4,0xcb34011a,0x00000000}},	//   _এজন্, मिकल_, _ואיי_, --, 
   {{0x25a800c6,0x85b402dd,0x00000000,0x00000000}},	//   مدني_, іліс_, --, --, 
   {{0x6280036b,0x9f4cb69f,0xf98805d9,0x77940344}},	//   _axlo, nteó_, _ننڍي_, _فیرا, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x98a00006,0x39b8007f,0xdce4005f,0x3860001f}},	//   _kokį_, _fōse_, zikā, _ለመቀበ, 
   {{0xf8b80da0,0x98a00064,0x4638010f,0x00000000}},	//   _अलोप, _jokį_, _דעלע, --, 
   {{0x62821b0e,0xb0a40034,0x6d5c5e63,0x225803e3}},	//   _exlo, खेंग, ëram, _əski_, 
   {{0x63a001ab,0xd36c8e98,0xe8d80051,0x00000000}},	//   _ghln, _جۇت_, thị_, --, 
   {{0x2e0c016b,0x6d5e1b0f,0x8140015e,0x00000000}},	//   _bɛfa_, thsa, سنین, --, 
   {{0xdce40aed,0xac1a1b10,0x6d5c00d8,0xd0080212}},	//   tikā, бому_, uhsa, _веде_, 
   {{0xa2c01db2,0xe8d801f2,0x08d00150,0x67240200}},	//   रुक्, shị_, _ﺘﺘﻨﺯ, ydhj, 
   {{0xdce4198e,0x6d5e1b11,0x7afc0076,0xef1800e2}},	//   rikā, shsa, ggrt, toļu_, 
   {{0xceb803f9,0x6280002d,0x6d5c0857,0xa93414b3}},	//   _haƙo_, _xxlo, phsa, певш, 
   {{0x6e3c0112,0x29080009,0x00000000,0x00000000}},	//   ärbu, ufaa_, --, --, 
   {{0x29080067,0x3b1806be,0xe7b40137,0x00000000}},	// [3db50] rfaa_, berq_, سماد, --, 
   {{0x4e1c06bc,0xdcf400b8,0xed5001f7,0x00000000}},	//   _बनाई_, _ijyā, _آھھ_, --, 
   {{0x6724044e,0xd00400aa,0xdb0c0158,0x2d7c0115}},	//   rdhj, _ګل_, åkår, nĉeo_, 
   {{0x63a001ab,0x660402d0,0x00000000,0x00000000}},	//   _shln, rthk, --, --, 
   {{0x3d0000dc,0x09d8000d,0x00000000,0x00000000}},	//   ष्टे_, _बबुय, --, --, 
   {{0xe85c001f,0x66c40588,0x6d5c0200,0x00000000}},	//   ዲያገኝ_, _хәаж, ëraj, --, 
   {{0x2d800115,0xa4d40845,0x21741214,0x60dc0162}},	//   _ĉien_, _нові, зупр, ðsmo, 
   {{0xceb803f9,0xa00800c6,0xe50800ec,0x6d48000d}},	//   _baƙo_, مقبل_, _ديرو_, öeal, 
   {{0x69c000bc,0xe0d1cce1,0x00000000,0x00000000}},	//   ílej, وزک_, --, --, 
   {{0xf8b8cead,0x96a0012d,0x72d401d5,0x00000000}},	//   _अल्प, केकॉ, _жофф, --, 
   {{0x6280022e,0x96ac0166,0x00000000,0x00000000}},	//   _uxlo, _íğtí, --, --, 
   {{0x070823ef,0xf1ac01ec,0x160c000d,0x00000000}},	//   स्तव_, _ﺷﺎﻳﻘ, _सहसर_, --, 
   {{0x9fc82d3d,0x9f3402bf,0xe8d80521,0x6da80055}},	//   _угла_, _неді, ghọ_, _aśas, 
   {{0xef18005f,0x6d9c0098,0xfeb802f2,0x00000000}},	//   ceļ_, réaa, _ئاشت_, --, 
   {{0xcb661b12,0x6d9e1b13,0xde3401c6,0xfd6401ec}},	//   чаре_, méan, _хэль, _онкү, 
   {{0x1868b94f,0x6d9e1b14,0x499402d3,0x0634001f}},	//   баби_, léan, _መብርሂ_, _የሚያነ, 
   {{0xe8d80521,0x69e0002b,0x00000000,0x00000000}},	// [3db60] chọ_, _āveś, --, --, 
   {{0x6d9cbda7,0xc720518e,0x00000000,0x00000000}},	//   néan, ндуй, --, --, 
   {{0x14c802f6,0x98a00006,0xe1e40451,0x6b84007b}},	//   были_, _tokį_, _جڳ_, _تشيل, 
   {{0xc68c0014,0x6d9da692,0xf4847c91,0xfa800092}},	//   دِم_, héan, واشی, _የስኳር_, 
   {{0x999c0024,0x6d9c0c6a,0x00000000,0x00000000}},	//   štų_, kéan, --, --, 
   {{0x795801e1,0xd7581532,0x1b1800eb,0x9f4c0139}},	//   _kíwo, _الست_, দাকে_, kteñ_, 
   {{0xceb802a8,0x201923f5,0x6d9e1b15,0x07a002d5}},	//   _saƙo_, çsin_, déan, _чарн, 
   {{0xf8dc07f7,0xb0340063,0x24f400db,0x8678011a}},	//   बरिय, дниш, _очур, _הרלו, 
   {{0x745401d3,0x6d9c01e7,0x601002d2,0x23b000cf}},	//   _تھائ, féan, _rómö, رۅۅس, 
   {{0x6d9d4938,0xe7d40150,0x00000000,0x00000000}},	//   géan, _ﺘﻨﺯﻟ, --, --, 
   {{0x2a98001f,0xc20c01d9,0x79580241,0xdcfc00b8}},	//   _መስኮች_, _مٔل_, _níwo, _śyāv, 
   {{0x6ecc06ff,0x6da8002b,0x4fc4533f,0x869808a8}},	//   _द्रु, _aśar, _еска, מייז, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d9c0332,0x00000000,0x00000000,0x00000000}},	//   céan, --, --, --, 
   {{0xe8d801f2,0x601008a5,0x00000000,0x00000000}},	//   shọ_, _tómö, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3db70] --, --, --, --, 
   {{0xb8f409d9,0x64d407f8,0x2d980192,0x59d8012c}},	//   _स्_, दर्श, llse_, यीहर, 
   {{0x2d99db55,0x00000000,0x00000000,0x00000000}},	//   olse_, --, --, --, 
   {{0xdb14006a,0xfaa400ee,0xda14030f,0x00000000}},	//   _guyâ, _яшын, _کسیک, --, 
   {{0x2d8000df,0x2d99b4d1,0x00000000,0x00000000}},	//   _ĉiel_, ilse_, --, --, 
   {{0x26c40037,0x00000000,0x00000000,0x00000000}},	//   _ülo_, --, --, --, 
   {{0xd345af6a,0x00000000,0x00000000,0x00000000}},	//   بیله_, --, --, --, 
   {{0xd12e1b16,0x6d9c8616,0x9fc800c7,0x00000000}},	//   لمى_, wéan, огиа_, --, 
   {{0x6d9c00d5,0x4429aaea,0xdb200139,0x00000000}},	//   téan, _éc_, _çuçk, --, 
   {{0x2d9a1b17,0x337401ce,0x15b000cf,0x00000000}},	//   else_, _згур, _كەەس, --, 
   {{0x6d9e1b18,0xdb140139,0x00000000,0x00000000}},	//   réan, _quyí, --, --, 
   {{0x6d9c27b9,0x00000000,0x00000000,0x00000000}},	//   séan, --, --, --, 
   {{0x6d9c003e,0x92c003d4,0x2bd800bc,0x6e3c01e3}},	//   péan, ্ণৰ_, बीला, ärbr, 
   {{0x2d9a1b19,0xa2c0043e,0x6d9dc7a2,0x00000000}},	//   alse_, रुच्, léal, --, 
   {{0x9f4c0789,0x7ebc0419,0xa3dc2ce6,0x00000000}},	//   nreí_, _ešpé, थीत_, --, 
   {{0x6d9e1b1a,0x5da40014,0xceb0011a,0x66e400dc}},	//   néal, _تمبٕ, _ביו_, _āśaṅ, 
   {{0x7d061b1b,0x60dc008c,0x2e0c013f,0x0c221b1c}},	// [3db80] _icis, ósmy, _yɛfo_, _амын, 
   {{0x7c261b1d,0x3ce00217,0x6d9c3226,0x00000000}},	//   _isir, _heiv_, héal, --, 
   {{0xe5c40212,0xd5b0007b,0x2874013d,0x00000000}},	//   есіо, نفط_, _җыяр, --, 
   {{0x7c240327,0x97c401ec,0x00000000,0x00000000}},	//   _ksir, _ойме, --, --, 
   {{0x7c240003,0xd3880212,0x6d9c00ae,0xc89400db}},	//   _jsir, ойде_, déal, _журө, 
   {{0x7c261b1e,0x990801d9,0x3ce21b1f,0x00000000}},	//   _msir, _اتھِ_, _leiv_, --, 
   {{0x7d0408ad,0x705403e6,0xdb1401e1,0x6d9c00ae}},	//   _ocis, کۆشا, _muyà, féal, 
   {{0x3ce00c86,0x7d0400ca,0x46a21b20,0x6d9c01e7}},	//   _neiv_, _ncis, _расв, géal, 
   {{0x02cc07f8,0x7c261b21,0xa2c0095f,0x00000000}},	//   _स्वभ, _nsir, रुङ्, --, 
   {{0x7d061b22,0xce0400ae,0x00000000,0x00000000}},	//   _acis, وذجي, --, --, 
   {{0x7c261b23,0x8c10015b,0x00000000,0x00000000}},	//   _asir, িয়ান_, --, --, 
   {{0xae0002a0,0x6d9c00ae,0x00000000,0x00000000}},	//   लंबन_, céal, --, --, 
   {{0x7d040334,0x7c2401ed,0x2d98017a,0xf1c40073}},	//   _dcis, _csir, rlse_, _लंडन, 
   {{0xfe6c9057,0xe1f000dd,0xdb14004e,0x7d042c16}},	//   ادی_, _جسے_, _cuyà, _ecis, 
   {{0x7c261b24,0x685c0092,0x1bec000d,0x00000000}},	//   _esir, _ለመመስ, _जिअल_, --, 
   {{0x7d04007b,0xc98400f3,0x00000000,0x00000000}},	//   _gcis, фуги, --, --, 
   {{0x6d9c86c1,0xbd8800ec,0x0ba4f3dd,0x00000000}},	// [3db90] néam, _تنين_, _ошом, --, 
   {{0x6d4c166a,0x0af001c6,0x00000000,0x00000000}},	//   _hoaa, _шүгэ, --, --, 
   {{0x6d4c03a0,0x6d9c0332,0x7c2400e5,0xf74801e2}},	//   _koaa, héam, _zsir, بللي_, 
   {{0x67d4412c,0xda6446f5,0x00000000,0x00000000}},	//   _пому, _ساپي, --, --, 
   {{0x6d4c01af,0xdb14007f,0x00000000,0x00000000}},	//   _moaa, _ityò, --, --, 
   {{0x27ea1b25,0x6d4c0069,0xdb140784,0x39b801a6}},	//   msan_, _loaa, _kuyá, _hčsp_, 
   {{0x27ea1b26,0x6d4c0009,0x00000000,0x00000000}},	//   lsan_, _ooaa, --, --, 
   {{0x6024f35c,0x6d4c03a0,0xdb0800bc,0x00000000}},	//   едиа, _noaa, ěnéh, --, 
   {{0x27ea1b27,0x6d9e1b28,0x3ce005ac,0xdee401f4}},	//   nsan_, réal, _reiv_, нопи, 
   {{0x7d061b29,0x6d4c0418,0x27ea1b2a,0x3ce007c5}},	//   _scis, _aoaa, isan_, _seiv_, 
   {{0x27ea1b2b,0x7c24b61a,0x00000000,0x00000000}},	//   hsan_, _ssir, --, --, 
   {{0x27ea1b2c,0x6d4c0005,0xd00c1d10,0x00000000}},	//   ksan_, _coaa, جلی_, --, 
   {{0x6d4c05b1,0x27e801e6,0x98a00100,0x3ce00fac}},	//   _doaa, jsan_, _pakč_, _veiv_, 
   {{0x5f44021a,0x27ea1b2d,0x442c04cc,0x7d04033f}},	//   _سنبل, dsan_, ivg_, _wcis, 
   {{0x27ea1b2e,0x1d94023a,0x6d4c0356,0x00000000}},	//   esan_, _приё, _foaa, --, 
   {{0x7c261b2f,0x60ca1b30,0x7d061b31,0x27ea1b32}},	//   _tsir, ncem, _ucis, fsan_, 
   {{0x27ea1b33,0x7c261b34,0x8ea400db,0x00000000}},	// [3dba0] gsan_, _usir, _قلۇۇ, --, 
   {{0x1ae8015b,0x6d5c0023,0x00000000,0x00000000}},	//   ঞ্জে_, ërav, --, --, 
   {{0x79e800dd,0x6d4c0083,0x60ca1b35,0x00000000}},	//   _توجہ_, _yoaa, kcem, --, 
   {{0x27ea1b36,0xb93802dd,0x00000000,0x00000000}},	//   bsan_, _تۋرا_, --, --, 
   {{0x27e86bb3,0x88b8025d,0xab6800e5,0x47f0014b}},	//   csan_, _מזכי, _رحیق_, _бӯхр, 
   {{0x087400c8,0x60c803ac,0x00000000,0x00000000}},	//   _װעלט_, ecem, --, --, 
   {{0x46a21b37,0x00000000,0x00000000,0x00000000}},	//   _барв, --, --, --, 
   {{0x82306d42,0x60c80117,0x2d7c01e4,0x301401d5}},	//   اروا, gcem, rĉek_, вдир, 
   {{0xceb80198,0x4f28187f,0x00000000,0x00000000}},	//   _haƙi_, пінг_, --, --, 
   {{0xc774001f,0x9ef00124,0x636c012d,0x60c800d7}},	//   _በከተማ_, аҧшц, yźni, acem, 
   {{0x27e8137e,0xc0b80b82,0xdce40153,0x634800f1}},	//   zsan_, ሰላም_, likę, _تړنې_, 
   {{0x27ea1b38,0x60ca1b39,0x8678011a,0xd0840108}},	//   ysan_, ccem, לריו, _пыли, 
   {{0x27ea1b3a,0x7c85c30d,0x6d4c0170,0x00e439b1}},	//   xsan_, гуре, _voaa, _ستنی, 
   {{0xc0b8001f,0xcf2541e7,0x6d4c0036,0x00000000}},	//   ሰዋል_, _سرتي, _woaa, --, 
   {{0x6d4c0607,0x27ea1b3b,0x06dc0154,0x00000000}},	//   _toaa, wsan_, _ঢালি, --, 
   {{0xceb80198,0xfe980375,0x00000000,0x00000000}},	//   _naƙi_, _מיומ, --, --, 
   {{0x2b4401d3,0xa7b80304,0x00000000,0x00000000}},	// [3dbb0] ölcs_, длау_, --, --, 
   {{0xfbd000b2,0xd8d40150,0x60c80205,0x00000000}},	//   _اتي_, _ﺘﻘﻼﻟ, zcem, --, 
   {{0x27ea1b3c,0xceb80b45,0xf74885e2,0x3a740432}},	//   ssan_, _baƙi_, علمي_, _блэр, 
   {{0x442c172e,0x27e801a9,0xa3d4023a,0x69d40165}},	//   tvg_, psan_, водч, mpze, 
   {{0x27ea1b3d,0x67d40f5c,0x2fc04230,0x232801f0}},	//   qsan_, _јогу, _éigh_, доли_, 
   {{0x2bd809bb,0x442c107d,0x00000000,0x00000000}},	//   _बौछा, rvg_, --, --, 
   {{0xc0ec0020,0x6d9c0c6a,0xe28402e8,0x6594009d}},	//   _ቀድሞ_, géak, ълки, _ааву, 
   {{0x94402832,0xb9fc001f,0x3d2000ce,0xdecc01f3}},	//   _چھون, _ሄዶ_, _बसें_, ቢያን_, 
   {{0x98a0f987,0x00000000,0x00000000,0x00000000}},	//   _kakā_, --, --, --, 
   {{0x60c91956,0xceb80198,0x23b404fb,0x6d9c0c6a}},	//   scem, _zaƙi_, _شماس, béak, 
   {{0x98a00383,0xceb80c09,0x6cdc0150,0x00000000}},	//   _makā_, _yaƙi_, _ﺃﺩﺒﻴ, --, 
   {{0x5ff40116,0x271c00fe,0x6e3c01e3,0x00000000}},	//   _азду, নাটো_, årba, --, 
   {{0x0d8087b7,0x1ca403e6,0x4c800212,0x0c200024}},	//   рлян, کێکی_, илюв, амян, 
   {{0x93f80d65,0xda640fb4,0xd9a80404,0x00000000}},	//   ולשי, نازي, कष्ट, --, 
   {{0x200e1b3e,0x09e002e8,0x00000000,0x00000000}},	//   ltei_, иорн, --, --, 
   {{0x212c0109,0x6d5c0240,0xbd8800ec,0xf1ac02dd}},	//   ndeh_, ërat, _ڪنڊن_, _ﺷﺎﻟﻘ, 
   {{0x200e1b3f,0x08c0010b,0x00000000,0x00000000}},	// [3dbc0] ntei_, рбун, --, --, 
   {{0x200e1b40,0x212c00d5,0xe8d80051,0x7d001427}},	//   itei_, hdeh_, thể_, ómsf, 
   {{0x7bc40de4,0x644c005b,0x69c00216,0x6b880036}},	//   _huiu, äain, ílet, éege, 
   {{0x7bc524c8,0xceb002e4,0x3d20033f,0xd2500214}},	//   _kuiu, ביב_, _बसों_, ینش_, 
   {{0xa3dc0574,0x93881d83,0xc0c8001f,0x74143bea}},	//   थील_, мска_, _አስራ_, اوتا, 
   {{0x7bc4b137,0x6d9c003e,0x00000000,0x00000000}},	//   _muiu, téak, --, --, 
   {{0xd5b112cd,0xceb80198,0x200c8e50,0xdd0000bc}},	//   _نفس_, _taƙi_, etei_, ítěz, 
   {{0x42c423c9,0x7bc44e12,0x200c0311,0x6d9c525e}},	//   нгән_, _ouiu, ftei_, réak, 
   {{0x6fb9c021,0x200c0036,0x6d9c003e,0x70561b41}},	//   нгир_, gtei_, séak, انخا, 
   {{0x63c401e0,0x3cdc03d4,0x446000d8,0x00000000}},	//   _сафҡ, _ভাগৱ, _твув, --, 
   {{0x7bc4003a,0xadb43be4,0x212c03e3,0x1ee802f2}},	//   _auiu, лбош, bdeh_, ژویی_, 
   {{0x7bc61b42,0xdb14066a,0x9f4c0005,0x200c0036}},	//   _buiu, _styð, rreá_, btei_, 
   {{0x7bc40de4,0x6d9c004a,0x200c0356,0x0c861b43}},	//   _cuiu, néai, ctei_, тынм, 
   {{0x7bc5925d,0x00000000,0x00000000,0x00000000}},	//   _duiu, --, --, --, 
   {{0xe91800d6,0xb9c4036b,0xfb861b44,0x6d5c036e}},	//   нові_, иёти, рыян, ëras, 
   {{0x25a800e8,0x8bc42cdd,0x00000000,0x00000000}},	//   ηal_, _исод, --, --, 
   {{0x7bc40004,0xdb0c020c,0xfd7401d3,0x7bc001e4}},	// [3dbd0] _guiu, kmbè, _خدوخ, ŭmur, 
   {{0xf7721b45,0x332c002e,0x0ba80132,0x69d40036}},	//   يال_, _nadx_, _تابى_, ppze, 
   {{0x3a84467b,0xe8d802e3,0xaad837c8,0x6aa40175}},	//   _выяв, nkị_, _ब्यक, _uzhf, 
   {{0x6d5e1b46,0x792c0023,0xdb0c00e8,0x00000000}},	//   nksa, _ትጽቢት, ymbë, --, 
   {{0x24880261,0x6d5e1b47,0x69c52f86,0xb4240137}},	//   çam_, iksa, _huhe, لعوو, 
   {{0x69c61b48,0x6d5c03a2,0x6b9402ce,0xb46402bf}},	//   _kuhe, hksa, nozg, шкіл, 
   {{0x69c400af,0xc0c8001f,0x6d5c2147,0x6d9c003e}},	//   _juhe, _አስር_, kksa, péah, 
   {{0x200e1b49,0x69c61b4a,0xa0a61b4b,0x6b961b4c}},	//   ttei_, _muhe, лайд, hozg, 
   {{0x69c61b4d,0x200c005a,0x20180ba1,0x212c0009}},	//   _luhe, utei_, ïsi_, rdeh_, 
   {{0x200e1b4e,0x6d5c954c,0x5e4831d5,0xfe744575}},	//   rtei_, eksa, епом_, күл_, 
   {{0x200d74a0,0x69c40564,0x1d0a1b4f,0x212c03a2}},	//   stei_, _nuhe, нени_, pdeh_, 
   {{0x657804fe,0x200e1b50,0x7bc61b51,0x00000000}},	//   niwh, ptei_, _puiu, --, 
   {{0xff50034c,0x69c418a6,0xe8d8063f,0x7bc40393}},	//   _پخش_, _auhe, akị_, _quiu, 
   {{0x69c61b52,0xdee40364,0x0ff00014,0x6d5c0b4f}},	//   _buhe, _соки, _آوس, ërar, 
   {{0x65780374,0x64580142,0x00000000,0x00000000}},	//   kiwh, hywi, --, --, 
   {{0x69c4067d,0x6d5e1b53,0x7bc4ea98,0xdd900244}},	//   _duhe, cksa, _tuiu, _دوع_, 
   {{0x999c00dd,0xb8ec000d,0x97c479af,0x38040107}},	// [3dbe0] ítő_, _लल_, اترم, розҳ, 
   {{0x6458068f,0x75cc013d,0x00000000,0x00000000}},	//   dywi, _ağza, --, --, 
   {{0x69c40516,0x9f4c003a,0x69c00115,0x00000000}},	//   _guhe, preæ_, ŭler, --, 
   {{0xd944f5e2,0x64580368,0x4a78010f,0x25a84029}},	//   _семи, fywi, _טריב, ندني_, 
   {{0x4d7800c8,0x61e003f0,0x94740a2c,0x69c4002f}},	//   ערנע, _awll, دداا, _zuhe, 
   {{0x61e0015d,0xc1b800d1,0x9f4c01f4,0x02cc07b7}},	//   _bwll, _ﺧﺎﺭﺍ, nreä_, सुलभ, 
   {{0x9664188c,0x6d5c037e,0xed600216,0x659400db}},	//   _скве, yksa, ážky_, دجەر, 
   {{0x41c05713,0x9f4c023a,0x7984addf,0x645400ac}},	//   حقيق, hreä_, nniw, _əziz, 
   {{0xc950011a,0x79861b54,0xffd001d5,0x6b9401a9}},	//   ממה_, iniw, یغید, yozg, 
   {{0x7ad40073,0x0c840150,0x00000000,0x00000000}},	//   _ब्लॅ, ғымм, --, --, 
   {{0xa24400aa,0x798401c7,0x6b940010,0xd17401af}},	//   _نیول_, kniw, vozg, _йыды, 
   {{0x69c61b55,0x6d9c0332,0xc0e00024,0x9fc4035b}},	//   _ruhe, héav, _гоцк, ыҳәа_, 
   {{0x6d5e1b56,0x69c61b57,0xe8d801f2,0x6b961b58}},	//   rksa, _suhe, skị_, tozg, 
   {{0x69c40664,0x0700068f,0x6d5c0656,0x79840142}},	//   _puhe, _लाइव_, sksa, eniw, 
   {{0x69c4044e,0x6458068f,0x6b961b59,0x00000000}},	//   _quhe, zywi, rozg, --, 
   {{0x69c40dd4,0xdc5404d3,0xb9c40107,0xbe38010f}},	//   _vuhe, ارێک, сёри, _טעות, 
   {{0xa7761b5a,0xfd100592,0xbd8800c6,0x00000000}},	// [3dbf0] алач, _رجي_, _حنين_, --, 
   {{0x69c61b5b,0x7984009f,0x00000000,0x00000000}},	//   _tuhe, aniw, --, --, 
   {{0x65780053,0xe4d40740,0xfbd02c80,0x7984009a}},	//   tiwh, لقاد, _وتی_, bniw, 
   {{0x64593100,0xdef8069d,0x995400ef,0x798401ef}},	//   tywi, ፋትና_, _aļņu_, cniw, 
   {{0x65780053,0x29180a55,0x27ec04cc,0x61e0015d}},	//   riwh, _ibsa_, _ìen_, _swll, 
   {{0x645a1b5c,0x61e003cb,0xa1f41fbe,0x00000000}},	//   rywi, _pwll, аџиј, --, 
   {{0x291805be,0x645400ac,0x657802b1,0x21684a0b}},	//   _kbsa_, _əziy, piwh, кики_, 
   {{0x2d8801e3,0x545000d1,0xa438010a,0x00000000}},	//   _njae_, свәт, _избу_, --, 
   {{0x4fe4e48e,0x84640c04,0x29180ac5,0x25ac0158}},	//   амын_, _съве, _mbsa_, _ihel_, 
   {{0x6d5c05c7,0x00000000,0x00000000,0x00000000}},	//   êran, --, --, --, 
   {{0x2ca803be,0x29180ba7,0x25ac002e,0x070000e1}},	//   _azad_, _obsa_, _khel_, _लाईव_, 
   {{0xa3a819e5,0x318c0118,0x26cc010e,0x00000000}},	//   _गीत_, těze_, _şeol_, --, 
   {{0x26d00cf9,0xff1000b5,0xe50c5d4f,0xf0c0030d}},	//   _ofzo_, _exeは, _हानि_, _хιуь, 
   {{0x291a1b5d,0x98a00034,0x79840142,0x7d000174}},	//   _absa_, _jaką_, wniw, ómsb, 
   {{0x0f780bd9,0x79840810,0xdb1c036e,0x69c00f53}},	//   _ברסל, tniw, _hipë, ílep, 
   {{0xa640001f,0x29180171,0x98a00064,0x81e400cc}},	//   _የሚያሰ, _cbsa_, _laką_, _বমা_, 
  
   {{0xe74401e0,0x79840142,0x6d9c00e4,0x00000000}},	// [3dc00] әүсе_, rniw, téav, --, 
   {{0x25ae1b5e,0x94440345,0x00000000,0x00000000}},	//   _ahel_, یپان, --, --, 
   {{0x25ac0076,0x248c0381,0xdce401e4,0x66740014}},	//   _bhel_, _axem_, zikĝ, مگٲر, 
   {{0x25ae1b5f,0x25d8109c,0x79840784,0x041c00fe}},	//   _chel_, اهنگ_, qniw, পিনী_, 
   {{0xdb1c036e,0xf434010b,0x98a00064,0x00000000}},	//   _nipë, селэ, _baką_, --, 
   {{0x3dc002d1,0x8c340a1e,0x25ac0067,0x07a00137}},	//   _liiw_, יטנס_, _ehel_, _маян, 
   {{0x201c02e2,0xc32401ec,0x248d056c,0x3dc40af9}},	//   _apwi_, شكين_, _exem_, _nunw_, 
   {{0x25ac014f,0xe1e80014,0x00000000,0x00000000}},	//   _ghel_, چى۪و_, --, --, 
   {{0x69b80073,0xdb1c0200,0xe1e801d9,0xb2100162}},	//   ्दती, _cipë, نى۪و_, óðbø, 
   {{0x53a47fa5,0x461001d3,0x96a800bc,0x0dc82d57}},	//   _тазб, _دوہر, _कराउ, куми_, 
   {{0x201c033b,0x6e9400f3,0x382c0092,0x25ac0254}},	//   _epwi_, сину, ስተባበ, _yhel_, 
   {{0xdb1c004e,0x2d8000df,0xd0180818,0x25ac0240}},	//   _hipè, _ĉies_, _афк_, _xhel_, 
   {{0x63ac006a,0xff4c0214,0x00000000,0x00000000}},	//   îang, سخی_, --, --, 
   {{0x2ca80306,0x7b640117,0x00000000,0x00000000}},	//   _vzad_, отсе, --, --, 
   {{0x6df4db35,0x26d00114,0x2d8801bf,0x23a800e5}},	//   _اكبا, _rfzo_, _tjae_, núja_, 
   {{0x1cc40135,0x644c02f6,0x00000000,0x00000000}},	//   _ཏུར_, äaik, --, --, 
   {{0x2d9a1b60,0x00000000,0x00000000,0x00000000}},	// [3dc10] mose_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x64a40588,0xaa59022b,0x2d98062c,0x248c03b9}},	//   әала, _сину_, oose_, _sxem_, 
   {{0x6d9ce0ff,0x98a000c0,0x39e401ee,0x00000000}},	//   méas, _saką_, _фәрғ, --, 
   {{0x68edab2b,0x2d980a73,0x29080194,0x6d9c007b}},	//   maad, iose_, mgaa_, léas, 
   {{0x68ec19a7,0x2d9a1b61,0x2908208d,0xdb1c0023}},	//   laad, hose_, lgaa_, _ripë, 
   {{0xdb1e1b62,0x6d9e1b63,0x25ac0066,0x67242dba}},	//   _sipë, néas, _thel_, mehj, 
   {{0x290a1b64,0x68ee1b65,0x25ac0dd4,0x2d98979d}},	//   ngaa_, naad, _uhel_, jose_, 
   {{0x2d9a1b66,0x66061b67,0x98a0d591,0x2908198f}},	//   dose_, luhk, _taką_, igaa_, 
   {{0x1f661b68,0x68ec3431,0x3dc00694,0x672437c5}},	//   ском, haad, _siiw_, nehj, 
   {{0x68ee1b69,0x6605c6b5,0xe6a4032c,0x33b004b3}},	//   kaad, nuhk, _करोड़, _تەور, 
   {{0x2d9a1b6a,0x67240240,0x6d9c0129,0x00000000}},	//   gose_, hehj, déas, --, 
   {{0x68ee1b6b,0x201c0204,0x67242c95,0xdb1c00c7}},	//   daad, _upwi_, kehj, _hipé, 
   {{0x66042948,0x6724037e,0x29080014,0x00000000}},	//   kuhk, jehj, egaa_, --, 
   {{0x2d9a1b6c,0x68ec36b7,0x672400b5,0x6604003e}},	//   bose_, faad, dehj, juhk, 
   {{0x68ee1b6d,0x290822a9,0x66061b6e,0xdea175f6}},	//   gaad, ggaa_, duhk, _ویکی, 
   {{0xdb1c00c6,0x6d9cfbcd,0x66040c6a,0x672401bf}},	// [3dc20] _lipé, réat, euhk, fehj, 
   {{0x290a1b6f,0x6d9c0098,0x672412ed,0x46e40137}},	//   agaa_, béas, gehj, йдун_, 
   {{0x660487d3,0x68ec7348,0x8b54010f,0x57a400c7}},	//   guhk, baad, _הייס_, ашҧа, 
   {{0x546a1b70,0xdb1c0699,0x29080998,0x68ec0014}},	//   лаем_, _sipè, cgaa_, caad, 
   {{0x672400b5,0x00000000,0x00000000,0x00000000}},	//   behj, --, --, --, 
   {{0x6604920d,0x6d9c007b,0x8c1805d0,0x2d9a1b71}},	//   buhk, néar, רוסי, zose_, 
   {{0x66043132,0xdb1c9096,0x2d9a1b72,0xf1f80244}},	//   cuhk, _vipè, yose_, شکاش_, 
   {{0x2d981709,0xdb1c255a,0x6d9c00c6,0x00000000}},	//   xose_, _dipé, héar, --, 
   {{0x2d9a1b73,0x70542c26,0x0ee80251,0x3cec01ad}},	//   vose_, زندا, льни_, चरने_, 
   {{0x2d98556c,0x08540375,0x68ee1b74,0x00000000}},	//   wose_, צבים_, zaad, --, 
   {{0x2d9a1b75,0x68ee1b76,0x479827af,0x6d9c0332}},	//   tose_, yaad, רייס, déar, 
   {{0x68ec0050,0x2d9802d5,0xbb4801d9,0x2018025c}},	//   xaad, uose_, ۅلُن_, ħsir_, 
   {{0x2d9a1b77,0x68ee1b78,0x903413ea,0x645c07c5}},	//   rose_, vaad, _دراص, _üsit, 
   {{0x68ec3431,0x2d9a1b79,0x6d9da727,0x2908058a}},	//   waad, sose_, téas, wgaa_, 
   {{0x2d987d6a,0x75cc06be,0x16d40037,0x00000000}},	//   pose_, _qğzl, _ढ्ेब, --, 
   {{0x6d9c00c6,0xb644001f,0x29097f67,0xbdf401e2}},	//   réas, _የሚያቀ, ugaa_, _اروا_, 
   {{0x68ee1b7a,0x67242188,0x2908198f,0x6d9c056a}},	// [3dc30] raad, tehj, rgaa_, séas, 
   {{0x66061b7b,0x29080165,0x6d9c0332,0x00000000}},	//   tuhk, sgaa_, céar, --, 
   {{0x68ee1b7c,0x67242b96,0xe8d801f2,0xe918177b}},	//   paad, rehj, enụ_, _коні_, 
   {{0xd1260414,0x66044460,0xe7ec03f3,0x68ec36b7}},	//   _غم_, ruhk, _चौथा_, qaad, 
   {{0xd0041041,0x6604285e,0x67240158,0x00000000}},	//   _تل_, suhk, pehj, --, 
   {{0x6224104b,0x660400c5,0xe364c3ff,0xc1b000dc}},	//   قىتل, puhk, юкли, ुद्ग, 
   {{0x78c801d3,0xc44400e5,0xa4d40153,0xf1d00150}},	//   _ásvá, _گیشن_, _мові, _ﻗﺎﻧﻘ, 
   {{0x88e40f22,0xe5081913,0x00000000,0x00000000}},	//   _ফাঁক, _خيرو_, --, --, 
   {{0x5f7401ed,0x65687c80,0x6ab402a0,0x00000000}},	//   قادر, _ileh, ंधुर, --, 
   {{0x65680117,0xdcfc0205,0x00000000,0x00000000}},	//   _hleh, _ıyıs, --, --, 
   {{0xd12c5b2c,0xe0d40261,0x9ea873ea,0x2f540212}},	//   رمی_, _доењ, рвна_, їтьс, 
   {{0xdca61b7d,0x35d0033f,0x60180395,0x671821f6}},	//   жами, _तूफ़, _водя_, न्तक_, 
   {{0x9f3402bf,0x6d9c00ae,0x5f747b8f,0x77b00166}},	//   _меді, téar, _واتر, läxe, 
   {{0x68e8010f,0x59bc01ad,0xe284030d,0x9020009f}},	//   _ĵeda, ्दभर, _улçи, _آڙيو, 
   {{0x9e961b7e,0xdee8001f,0x8f9800df,0x00000000}},	//   _باشچ, _ሙስና_, _דיסי, --, 
   {{0x38ca1b7f,0xb4e805f9,0x6d9c0332,0xc2f000eb}},	//   صاری_, _मजे_, séar, চ্চি_, 
   {{0x9f4cc5e5,0x6d9c0332,0xdddc0210,0x00000000}},	// [3dc40] queó_, méap, łyńs, --, 
   {{0xbf8401dc,0x81dc00bd,0x65680170,0xe3a40451}},	//   _điện_, _তিন_, _aleh, _سڱ_, 
   {{0x5628084c,0x67189f23,0xee8c0023,0x4ef800df}},	//   ржем_, न्धक_, _ዓንሰባ_, שלעג, 
   {{0x96d813b4,0x16a82a27,0x00000000,0x00000000}},	//   _प्रॉ, _करीब, --, --, 
   {{0xc2f000bd,0xca7405af,0x00000000,0x00000000}},	//   চ্ছি_, _همیش_, --, --, 
   {{0x47c00c04,0x656a1b80,0xda1c0073,0xcc38008f}},	//   _обяв, _eleh, _पहात_, יענט, 
   {{0x65680086,0x200002b1,0x12b80154,0x00000000}},	//   _fleh, _āhia_, ুর্দ, --, 
   {{0x6568000d,0xd0180454,0x00000000,0x00000000}},	//   _gleh, афо_, --, --, 
   {{0x38621b81,0x00000000,0x00000000,0x00000000}},	//   nyir_, --, --, --, 
   {{0xa03412b7,0xd24c0050,0x7d000174,0x6568013a}},	//   سىپت, _لۆت_, ómsn, _zleh, 
   {{0x386000ca,0xd1c800d8,0x705400f2,0x77b00139}},	//   hyir_, _тлее_, زنگا, cäxe, 
   {{0x3860013f,0x504401f0,0x00000000,0x00000000}},	//   kyir_, _мееб, --, --, 
   {{0x0ca97a22,0x1ae0015b,0x016001d9,0xb4e8000d}},	//   ртни_, _বাড়া, _زُوَ, _मजै_, 
   {{0x96d852f2,0x2ca4002d,0x2b440165,0xef1800de}},	//   _प्लॉ, āld_, ñlc_, biļa_, 
   {{0x0eba1b82,0x7ed05821,0xc0b8001f,0x49b8009a}},	//   _туды_, _غزوا, ደዋል_, لارد_, 
   {{0xac9400d4,0x00000000,0x00000000,0x00000000}},	//   _найш, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3dc50] --, --, --, --, 
   {{0x656814b2,0x862400c7,0x00000000,0x00000000}},	//   _sleh, жьде, --, --, 
   {{0x65690c91,0xb4d80521,0xaa5c01ec,0x00000000}},	//   _pleh, _ịzụt, _сенi, --, 
   {{0xd83c0010,0x77b001e3,0x00000000,0x00000000}},	//   ščad_, växe, --, --, 
   {{0x44246640,0x44281bf6,0x24080108,0x00000000}},	//   تراف, рцем_, ёнки_, --, 
   {{0xc5d8b23e,0x23281b10,0x77b001b8,0xd8b80375}},	//   _نظرا_, соки_, täxe, _לצרכ, 
   {{0x62661b83,0x656801ee,0xdcf40118,0xb1d400ec}},	//   явка, _tleh, _smyč, وٽوڪ, 
   {{0x656a1b84,0x00000000,0x00000000,0x00000000}},	//   _uleh, --, --, --, 
   {{0x229455b2,0x44280ba1,0xb97c010f,0x00000000}},	//   _کلاس, _èc_, ינהי, --, 
   {{0x443e1b85,0x35d000c5,0xefcc0092,0x00000000}},	//   _iru_, _तूड़, _አብዲ_, --, 
   {{0x443c0232,0x69d800b0,0x6d4000de,0x673400ef}},	//   _hru_, _ōwen, ēlan, _mazj, 
   {{0x443c2b92,0x67340427,0x6e3c143a,0x00000000}},	//   _kru_, _lazj, ærba, --, 
   {{0xf1c4012d,0x6d9c00e4,0x00000000,0x00000000}},	//   _लूटन, réap, --, --, 
   {{0xd00c0597,0x443e1b86,0x6734031c,0x00000000}},	//   _صلى_, _mru_, _nazj, --, 
   {{0xd9440cb6,0x38600142,0x00000000,0x00000000}},	//   певи, wyir_, --, --, 
   {{0x443e1b87,0x6734045f,0x00000000,0x00000000}},	//   _oru_, _aazj, --, --, 
   {{0x443c038f,0x00000000,0x00000000,0x00000000}},	// [3dc60] _nru_, --, --, --, 
   {{0x7c261b88,0xf524025c,0x2ddc01ec,0x00000000}},	//   _ipir, _ལིངྒ_, _ﺃﻨﻅﻤ, --, 
   {{0x443e1b89,0x386031e5,0x67340135,0x00000000}},	//   _aru_, syir_, _dazj, --, 
   {{0x443e1b8a,0x7c24005a,0x994800c6,0xdce4005f}},	//   _bru_, _kpir, _الحل_, jokļ, 
   {{0xdce40029,0x443c1184,0xb9fc02d3,0xdb1c021c}},	//   dokļ, _cru_, _ቆረ_, _lipí, 
   {{0x7c261b8b,0x443e1b8c,0xe8e8031c,0x67340139}},	//   _mpir, _dru_, _འབོག, _gazj, 
   {{0x443d56fa,0x59280003,0x55e61b8d,0x00000000}},	//   _eru_, _སྒོས_, _хобб, --, 
   {{0x7c261b8e,0x443c1654,0x59bc1bd6,0xd1b001d5}},	//   _opir, _fru_, ्दिर, ریشک, 
   {{0x443e1b8f,0x5edc009e,0x50640006,0xdb140205}},	//   _gru_, _ময়ে, ятка, _buyü, 
   {{0x138800c6,0xd34402f2,0x00000000,0x00000000}},	//   _اخرى_, _ریعه_, --, --, 
   {{0x7c261b90,0x59bdc264,0x064002dd,0xdb1c0332}},	//   _apir, ्दार, _ءﺩﺍﺳ, _cipí, 
   {{0x443c0124,0x258400b5,0xe8740092,0x00000000}},	//   _yru_, のlte_, በልጥም_, --, 
   {{0x25a4011f,0x59280327,0xe3b01c3b,0xc0e000cf}},	//   _êlle_, _སྒེས_, _سرے_, _чочк, 
   {{0xe08400c6,0x4030005b,0x81dc05ac,0x00000000}},	//   _تجمي, _чешс, _তিত_, --, 
   {{0x7c243865,0xe50c00af,0x0e4401c6,0xe9441e2f}},	//   _epir, _हालि_, _хэлм, ونسپ, 
   {{0x7c24003a,0x39a406ed,0x6e3c007c,0x00000000}},	//   _fpir, ешув, årbu, --, 
   {{0xcb4433d2,0x21d402b5,0x67340003,0x1cc40327}},	// [3dc70] _ехни, _māha_, _pazj, _ཏུག_, 
   {{0x443cdcc8,0xdb0c08ce,0x00000000,0x00000000}},	//   _rru_, embæ, --, --, 
   {{0xdc5518aa,0xe7ec01ad,0x67340200,0xc0f40023}},	//   _فریک, _चौरा_, _vazj, ለጸሉ_, 
   {{0x443c2440,0x9f9c067c,0x7c2400d8,0x09280ccb}},	//   _pru_, nçòl_, _ypir, _اسدي_, 
   {{0x240800d6,0x443d518f,0x00000000,0x00000000}},	//   інки_, _qru_, --, --, 
   {{0x443e1b91,0x00000000,0x00000000,0x00000000}},	//   _vru_, --, --, --, 
   {{0xb6a401b9,0x66c400c7,0x443c0142,0xb6040eed}},	//   _зиёл, _цәаж, _wru_, _пятк, 
   {{0x443e1b92,0x21d4002b,0x18180244,0x00000000}},	//   _tru_, _cāha_, _ارێک_, --, 
   {{0x443e1b93,0x7d00022c,0xd00c8fae,0xd5a401b9}},	//   _uru_, ómsm, للي_, _آلقی, 
   {{0xd00db97c,0x9e64064d,0x8af400ac,0x00000000}},	//   گلی_, двод, _şənb, --, 
   {{0x442e1099,0x1cc40003,0xe1342e9a,0xf1d00150}},	//   lwg_, _ཏུང_, _онжы, _ﻗﺎﻳﻘ, 
   {{0xd00cff4e,0xb33c025c,0x7c240083,0x00000000}},	//   دلی_, _ikħa, _ppir, --, 
   {{0x60d800b5,0x38b40241,0x442e1b94,0x00000000}},	//   _ifwm, _múrí_, nwg_, --, 
   {{0xe8e80327,0x00000000,0x00000000,0x00000000}},	//   _འབུག, --, --, --, 
   {{0x442c0369,0x1d940107,0x00000000,0x00000000}},	//   hwg_, _ориё, --, --, 
   {{0x57e80801,0x2d940953,0x00000000,0x00000000}},	//   ждам_, _прыс, --, --, 
   {{0x7c245049,0x3ea403cb,0x00000000,0x00000000}},	// [3dc80] _upir, _hynt_, --, --, 
   {{0x4b840046,0x442c0369,0x59bc012c,0x3ea403b2}},	//   _ойын_, dwg_, ्दहर, _kynt_, 
   {{0x8f98011a,0xeff80023,0x00000000,0x00000000}},	//   קיעי, ጋህደ_, --, --, 
   {{0x3ea61b95,0xdb1c004e,0xb21003b2,0x00000000}},	//   _mynt_, _hipà, óðmø, --, 
   {{0x79861b96,0x59d002c3,0xba0401f3,0x00000000}},	//   miiw, _दूतर, _ጎማ_, --, 
   {{0x798490ae,0x00000000,0x00000000,0x00000000}},	//   liiw, --, --, --, 
   {{0x21d400b0,0xdb0c0112,0x00000000,0x00000000}},	//   _pāha_, mmbä, --, --, 
   {{0x32000998,0xb0361b97,0x70580166,0x00000000}},	//   čiy_, ениш, заир_, --, 
   {{0xdce40006,0x3bd400fd,0x53a400db,0x21d40055}},	//   likė, _näq_, _жааб, _vāha_, 
   {{0x798406d6,0x3ea4000f,0x03200124,0x27ec2ac2}},	//   hiiw, _bynt_, _идун, _çene_, 
   {{0xdec802d3,0x79861b98,0x3ea4015d,0x51540d1d}},	//   በልካ_, kiiw, _cynt_, _отду, 
   {{0x79840a55,0x625801b9,0x00000000,0x00000000}},	//   jiiw, _эрур_, --, --, 
   {{0x7984300b,0x00000000,0x00000000,0x00000000}},	//   diiw, --, --, --, 
   {{0x3ea40b21,0x0a696e66,0x6e94033a,0x2ee006be}},	//   _fynt_, орби_, _пилу, _şiff_, 
   {{0x3ea40368,0x7984208d,0xc27800df,0x00000000}},	//   _gynt_, fiiw, ַרמי, --, 
   {{0x442c0070,0x79861b99,0x3da40124,0xdce40153}},	//   ywg_, giiw, _ирыб, dikė, 
   {{0x442c01d4,0xe50c00af,0x212800e4,0xdec80023}},	// [3dc90] xwg_, हलसि_, _ñahe_, በልኩ_, 
   {{0x77b00227,0xdce40064,0x00000000,0x00000000}},	//   täxa, fikė, --, --, 
   {{0x79840ba7,0x00000000,0x00000000,0x00000000}},	//   biiw, --, --, --, 
   {{0x46dc143b,0xa4d400d6,0x442e1b9a,0xe8e8025c}},	//   _प्रह, ході, twg_, _འབིག, 
   {{0xd8d80375,0xf10c012d,0x00000000,0x00000000}},	//   _מקרר, _सफ़ेद_, --, --, 
   {{0x442c0368,0xa5f80114,0x00000000,0x00000000}},	//   rwg_, _негу_, --, --, 
   {{0x442c01d4,0x21a401b9,0x7d001427,0x00000000}},	//   swg_, никм, ómsk, --, 
   {{0xe1961b9b,0x20546d9a,0xd12c33d2,0x00000000}},	//   эрлэ, етор, ممى_, --, 
   {{0x3ea61b9c,0x2ca8002b,0x98a00166,0xf59c02d2}},	//   _synt_, _nyad_, _yokı_, _þúað_, 
   {{0x3ea4d4da,0x23787660,0x798404ba,0x9424215c}},	//   _pynt_, _عماد_, ziiw, _سومۇ, 
   {{0x2caa1b9d,0x00000000,0x00000000,0x00000000}},	//   _ayad_, --, --, --, 
   {{0xf1c9ea53,0x3bd40166,0x00000000,0x00000000}},	//   _قولى_, _päq_, --, --, 
   {{0x21d402b5,0x212c0548,0xfb840214,0x3ea403cb}},	//   _kāho_, meeh_, ندسی, _wynt_, 
   {{0x2ca80589,0x3ea408fb,0x212c0429,0x200c005a}},	//   _dyad_, _tynt_, leeh_, muei_, 
   {{0xabc4052f,0xda64027d,0x7b2000e4,0x6e3400c7}},	//   тарҙ, راسي, _aġuí, _ахых, 
   {{0x212c102c,0x00000000,0x00000000,0x00000000}},	//   neeh_, --, --, --, 
   {{0x212c0085,0x200c68ba,0xa640001f,0x7984afb9}},	// [3dca0] ieeh_, nuei_, _የሚወሰ, riiw, 
   {{0x212e1b9e,0xdce402d5,0x79841d2b,0x7ae801e2}},	//   heeh_, tikė, siiw, _تودې_, 
   {{0x212c0066,0xdb0c002f,0x00000000,0x00000000}},	//   keeh_, rmbä, --, --, 
   {{0x200c0086,0x7984022f,0x7d000174,0x00000000}},	//   kuei_, qiiw, ómsh, --, 
   {{0xd3c413ef,0x212c011f,0x21d4002b,0xdce40024}},	//   ىتتى, deeh_, _bāho_, sikė, 
   {{0x200c01c4,0xd25802e8,0x00000000,0x00000000}},	//   duei_, зци_, --, --, 
   {{0xcb10011a,0x2138022e,0x5fd40037,0x77b0013d}},	//   אלו_, оsh_, _डूबल, läxo, 
   {{0x212c0429,0x46a00640,0x00000000,0x00000000}},	//   geeh_, _сасв, --, --, 
   {{0x59d0534e,0x200e1b9f,0x00d4143e,0x318c0118}},	//   _दूसर, guei_, ربيت_, nězi_, 
   {{0xd2a80276,0x2caa1ba0,0xd36c0e56,0x00000000}},	//   _екзе_, _ryad_, _دۇت_, --, 
   {{0x212c0548,0x4e880cc9,0x6e9400f0,0x3ef401c6}},	//   beeh_, ящим_, тину, энээ_, 
   {{0x200c013f,0x212c0429,0x29d44cab,0x00000000}},	//   buei_, ceeh_, _råa_, --, 
   {{0x200c068c,0xe1640592,0xcfc803d4,0x7bf80139}},	//   cuei_, _جدلي, লীজন, нняр_, 
   {{0xbf100b61,0xdb1c00e5,0x00000000,0x00000000}},	//   _موهب, _pipá, --, --, 
   {{0x064001ec,0xe9180212,0x00000000,0x00000000}},	//   _ءﺭﺍﺳ, мові_, --, --, 
   {{0x6c8400c6,0xcfa80244,0x00000000,0x00000000}},	//   _للعم, _باڵم_, --, --, 
   {{0x6d4e1ba1,0xfd1000f7,0x6b7400cf,0xac9a1ba2}},	// [3dcb0] _inaa, _اجى_, _алпу, _زندا_, 
   {{0x29d403cd,0xf1d0012c,0x7b840150,0xdb1c0241}},	//   _tåa_, हदान, _ماپە, _tipá, 
   {{0x6d4c2ad4,0x200c005a,0xdb140241,0x00000000}},	//   _knaa, zuei_, _àbáp, --, 
   {{0x212c0548,0xdb0e1ba3,0xdcec002b,0x00000000}},	//   xeeh_, rmbå, _ākīr, --, 
   {{0x21d40374,0x6d4e1ba4,0xa3b9c489,0x69d80374}},	//   _pāho_, _mnaa, واتر_, _ōweh, 
   {{0x66b400c0,0x00000000,0x00000000,0x00000000}},	//   _абгу, --, --, --, 
   {{0x6d4e1ba5,0x212c0429,0x61ec0e04,0xd76400db}},	//   _onaa, teeh_, ćalo, _جەلى_, 
   {{0x200c85f2,0x6d4e1ba6,0xc0c8001f,0xa0a41ee1}},	//   tuei_, _nnaa, _አትም_, кайд, 
   {{0xa3d402bf,0x201800d2,0x212c0548,0x1fb4bbb8}},	//   _розч, îsi_, reeh_, ксор, 
   {{0x6d4e1ba7,0xa08800f7,0x212c0548,0x1f640f32}},	//   _anaa, зсүз_, seeh_, тком, 
   {{0x200c01c4,0xde0402e8,0x9f9c06be,0x00000000}},	//   suei_, ъпни, kçöl_, --, 
   {{0xd2540302,0x212c0548,0xa27c0023,0xfc3800c7}},	//   _בשעה_, qeeh_, _ንሕናን_, еҭи_, 
   {{0x200e1ba8,0x61e00334,0x30c8a67e,0x00000000}},	//   quei_, _htll, _كومپ_, --, 
   {{0x6d4c9748,0x9ef40214,0x6d5c00e4,0x2db40116}},	//   _enaa, _شستش, êrar, _ﭼﯩﻘﻤ, 
   {{0xdce41c52,0x00000000,0x00000000,0x00000000}},	//   nikī, --, --, --, 
   {{0x6d4c8988,0x9bd400c7,0x00000000,0x00000000}},	//   _gnaa, _ицош, --, --, 
   {{0x1c1487ee,0x1ce00327,0x00000000,0x00000000}},	// [3dcc0] _तमिल_, _ཧྥར_, --, --, 
   {{0x1bb897b5,0xda640107,0x5a641188,0x00000000}},	//   _تابع_, _авои, _акоб, --, 
   {{0x61e001af,0x6d4c02d0,0xe1e400ec,0x27e400d7}},	//   _ntll, _ynaa, _دڳ_, _člne_, 
   {{0x1868036b,0x9484481c,0x1c1401ad,0xdce40aea}},	//   _жами_, кылд, _तमाल_, dikī, 
   {{0x61e00200,0x77b00166,0x00000000,0x00000000}},	//   _atll, läxm, --, --, 
   {{0x1cc40135,0xdb1c0205,0x75cc03e0,0x00000000}},	//   _ཏུན_, _dipç, _eşza, --, 
   {{0x61e001ab,0xfe64072d,0xc7b0011a,0x00c80150}},	//   _ctll, _ئد_, _כבש_, _ﻗﺭﺭﺘ, 
   {{0x301407a5,0x00000000,0x00000000,0x00000000}},	//   гдир, --, --, --, 
   {{0x1b0800bd,0xdb1c01b8,0x321c02fb,0xd4a40131}},	//   শ্যই_, _kipä, stvy_, _риай, 
   {{0x6d4c0660,0xb4c00490,0x00000000,0x00000000}},	//   _snaa, ीशी_, --, --, 
   {{0x77b001e6,0x09e4009e,0xdce4002b,0x00000000}},	//   växl, _ফিভা, cikī, --, 
   {{0x2018004e,0xc27808a8,0x00000000,0x00000000}},	//   àsic_, _קראי, --, --, 
   {{0x7c844640,0x21280124,0x3d9401f0,0x00000000}},	//   ауре, _ñaha_, рияр, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xffb40375,0xadf401b9,0x26f000cc,0x83c80150}},	//   _שלוש_, _ёпиш, _চালো_, _ﺗﻮﺯﺳ, 
   {{0x6d4e1ba9,0x090800fe,0xa8340114,0x8c64022e}},	//   _unaa, হ্নু_, лебљ, _атод, 
   {{0x682801e4,0xeac40011,0xbd882372,0x00000000}},	// [3dcd0] _oɾde, ্রেম, _جنين_, --, 
   {{0x1b0800cc,0xa3d401d5,0x7d000d12,0x00000000}},	//   শ্বই_, ҳодч, ómsv, --, 
   {{0x28f93cc6,0xefcc02d3,0x8994013e,0x77b00139}},	//   _пень_, _አብዚ_, _айнӣ_, cäxm, 
   {{0xbcf001e4,0xdb1c005b,0x69c80115,0x00000000}},	//   _poɩi, _eipä, ĉees, --, 
   {{0x05740517,0x7d7c011a,0x00000000,0x00000000}},	//   _یارد, ונאו, --, --, 
   {{0x4aa40073,0x221408ca,0xef1800de,0x00000000}},	//   _गडाव, гфир, biļi_, --, 
   {{0xdce80208,0x65961baa,0x00000000,0x00000000}},	//   ̣nđo, _баву, --, --, 
   {{0x05740424,0xa5c4013d,0xefcc1ef7,0x00000000}},	//   _شازد, _сөзе, _አብዛ_, --, 
   {{0x6e3a1bab,0x29180208,0xf43400cf,0x00000000}},	//   _asvb, _mcsa_, _кетэ, --, 
   {{0x9f0401e2,0x00000000,0x00000000,0x00000000}},	//   دودو, --, --, --, 
   {{0x29180113,0xa11403e6,0x2f540220,0x8c400032}},	//   _ocsa_, _موات, ртыс, ҙере, 
   {{0x29180048,0x6b841db0,0x4aa400ab,0x27ec0327}},	//   _ncsa_, _amhg, _गड़व, _ħenn_, 
   {{0x0d80bef7,0x00000000,0x00000000,0x00000000}},	//   слян, --, --, --, 
   {{0x201c047e,0x213c031c,0x9f0401ed,0x00000000}},	//   _iqwi_, _hawh_, _صوبو, --, 
   {{0x9d4470bd,0x1cc4031c,0xf1d00ef6,0x00000000}},	//   _бейд, _ཏུམ_, _ﻗﺎﻟﻘ, --, 
   {{0x98a40212,0xa3d8000d,0x9f4c01f4,0x5cf40064}},	//   гибе, _ठंढ_, sseä_, _сяку, 
   {{0x7d061bac,0x7d0003b2,0x00000000,0x00000000}},	// [3dce0] _idis, ómsu, --, --, 
   {{0x7d040175,0x00000000,0x00000000,0x00000000}},	//   _hdis, --, --, --, 
   {{0x98a002b5,0x1ce0031c,0xa3c8503c,0xfb8401d3}},	//   _pakē_, _ཧྥོ_, ोदन_, _مدھی, 
   {{0x64441da6,0x54d4009d,0x00000000,0x00000000}},	//   āhin, уцжу, --, --, 
   {{0x7d040175,0x394030b5,0x44f00d30,0xf38401ec}},	//   _mdis, mdis_, спіс, ағам, 
   {{0x39421bad,0x7d0403b2,0xdb0c020c,0x59bc197c}},	//   ldis_, _ldis, èjèd, ्दकर, 
   {{0x98a000b0,0x52254d00,0x3940897c,0xd20801c6}},	//   _takē_, уфла, odis_, хэлд_, 
   {{0x7d061bae,0xa020008e,0x00000000,0x00000000}},	//   _ndis, _ğöre, --, --, 
   {{0x04421baf,0x1ce00003,0x39421bb0,0xa0200139}},	//   _летн, _ཧྥེ_, idis_, _şöre, 
   {{0x62640131,0x7ccc00e2,0x2018004e,0xb0c0095f}},	//   _ھالق, _mērī, àsia_, शेषग, 
   {{0x213c0399,0x3940007f,0x835000f1,0x00000000}},	//   _fawh_, kdis_, _دپلا, --, 
   {{0x7d0420ef,0x39415b39,0x28c407f7,0x318c0118}},	//   _cdis, jdis_, लेडि, tězu_, 
   {{0x39421bb1,0x7d053453,0x00000000,0x00000000}},	//   ddis_, _ddis, --, --, 
   {{0x7d061bb2,0xa3c80d2e,0x39421bb3,0x3d9401ec}},	//   _edis, ोदय_, edis_, _қиыр, 
   {{0x394002d2,0x00000000,0x00000000,0x00000000}},	//   fdis_, --, --, --, 
   {{0x39406066,0x7d000ad9,0x9d6401d9,0x00000000}},	//   gdis_, ómst, _ننى۪, --, 
   {{0xa8561bb4,0x0ca80212,0xa6f5b551,0xab940212}},	// [3dcf0] шкач, _ятки_, изаш, _випі, 
   {{0x39421bb5,0x7d04013a,0x00000000,0x00000000}},	//   adis_, _zdis, --, --, 
   {{0x8588036b,0x39403343,0x24c03769,0x00000000}},	//   нёда_, bdis_, ﺭﺩﻩﻣ, --, 
   {{0x6d5c0007,0xb5c8027d,0x00000000,0x00000000}},	//   njsa, هولم_, --, --, 
   {{0x68ee1bb6,0x213c031c,0x64a40f5c,0x44041422}},	//   mbad, _rawh_, јала, учеб, 
   {{0x27ea1bb7,0x21d40053,0x68ee1bb8,0x23287d03}},	//   mpan_, _hāhi_, lbad, токи_, 
   {{0xe0d00491,0x21d402b5,0x68ee1bb9,0x3e7801d3}},	//   يزة_, _kāhi_, obad, _máté_, 
   {{0xd1d4069c,0x6594dacb,0x85b80050,0x3e780241}},	//   _ካብቲ_, _табу, _سازس_, _láté_, 
   {{0x26100c2e,0x21d400b0,0x7a2c01ed,0x2ee00e2d}},	//   दूरी_, _māhi_, _kötö, _şifa_, 
   {{0x64495cce,0x5f040b3e,0x7d040175,0x27e8003e}},	//   _irei, јзна, _sdis, ipan_, 
   {{0x644a1bba,0x1ce00135,0x27ea1bbb,0x81dc009e}},	//   _hrei, _ཧྥུ_, hpan_, _তিক_, 
   {{0x644a1bbc,0x27e8ca53,0x21d46661,0x25fc000d}},	//   _krei, kpan_, _nāhi_, _लबनी_, 
   {{0x68ec01d9,0xd1d402d3,0x27e80784,0x7d040023}},	//   dbad, _ካብታ_, jpan_, _vdis, 
   {{0x27e8409c,0x7a300086,0x644a1bbd,0x68ec017a}},	//   dpan_, jòtò, _mrei, ebad, 
   {{0x27e400d7,0x68ec25a8,0x7d0006ea,0x00000000}},	//   _člna_, fbad, ómss, --, 
   {{0x644a1bbe,0x7d04860c,0x68ee1bbf,0x39421bc0}},	//   _orei, _udis, gbad, udis_, 
   {{0x39421bc1,0x17861bc2,0x27e8089c,0x200c138f}},	// [3dd00] rdis_, агам, gpan_, nrei_, 
   {{0x68ee1bc3,0xdb1c00d2,0x39421bc4,0x9b4400db}},	//   abad, _lipú, sdis_, _ئندو, 
   {{0x7afe1bc5,0x27e82ebc,0x68ee1bc6,0x644a1bc7}},	//   mart, apan_, bbad, _arei, 
   {{0x644a1bc8,0xd9461bc9,0x39421bca,0x546a1bcb}},	//   _brei, _теми, qdis_, каем_, 
   {{0x644a1bcc,0xd7c80517,0x27e801e4,0xb4040137}},	//   _crei, _لوحه_, cpan_, сүзд, 
   {{0x644a1bcd,0x200e1bce,0x7afe1bcf,0x93400137}},	//   _drei, drei_, nart, زىعۇ, 
   {{0x644a1bd0,0x7afc0869,0xcad40375,0x0cc000cd}},	//   _erei, iart, בוצת_, _षण्म, 
   {{0x644a1bd1,0x7afe1bd2,0x200c0730,0x65780175}},	//   _frei, hart, frei_, chwh, 
   {{0x644a0bee,0x7afe1bd3,0xeca40490,0xc1700212}},	//   _grei, kart, _गुंफ, ільщ, 
   {{0x7afe1bd4,0xcec412e7,0x68ec9e11,0xd3b80064}},	//   jart, ищни, zbad, _рубі_, 
   {{0x7afe1bd5,0x68ece45a,0x200c054e,0x644805c7}},	//   dart, ybad, arei_, _zrei, 
   {{0x200e1bd6,0x68ec0014,0x61e40306,0x10a400fd}},	//   brei_, xbad, íhle, _киен, 
   {{0x7afe1bd7,0xd24c04d3,0xdb0802fb,0x3e6c00b0}},	//   fart, _رۆک_, šným, tötö_, 
   {{0x7afe1bd8,0xc90c3bca,0x9e6000b7,0x68eccd1e}},	//   gart, िल्म_, ስልምና_, wbad, 
   {{0x21d43e16,0x27ea11cc,0x7a2c0108,0x9f500208}},	//   _pāhi_, wpan_, _rötö, _ýcác_, 
   {{0x68edbff3,0x7afc0869,0x2c6c01e7,0x6e3c0158}},	//   ubad, aart, _códú_, ærbu, 
   {{0x7afe1bd9,0x27ea1bda,0x1ce00135,0x2d88003a}},	// [3dd10] bart, upan_, _ཧྥི_, _imae_, 
   {{0x21d41f4c,0x68ee1bdb,0x0ba80150,0x46680798}},	//   _wāhi_, sbad, _جابى_, крем_, 
   {{0x27ea1bdc,0x68ec0e14,0xe4d4007b,0x644812ef}},	//   span_, pbad, مقاد, _srei, 
   {{0x644a1bdd,0x27ea1bde,0x200c0204,0xd124642c}},	//   _prei, ppan_, yrei_, _عم_, 
   {{0x2d8a1bdf,0x27e80784,0x200c00b5,0x00000000}},	//   _mmae_, qpan_, xrei_, --, 
   {{0xe2990003,0x200e1be0,0x644a1be1,0xb3840024}},	//   лал_, vrei_, _vrei, оліл, 
   {{0x6449b32a,0x2d89a5e2,0xbb78010f,0xb6a401fe}},	//   _wrei, _omae_, שעוו_, _диёл, 
   {{0x200e1be2,0x7afe1be3,0x068c0131,0xfa98011a}},	//   trei_, zart, ﻛﯜﻣﯩ, ידוש_, 
   {{0x7afe1be4,0x25ac003d,0x644a1be5,0x200ca178}},	//   yart, _ikel_, _urei, urei_, 
   {{0x200e1be6,0x2d880b23,0x7afe1be7,0x2b4001c7}},	//   rrei_, _amae_, xart, _nahc_, 
   {{0x7afc0a28,0x25ac0548,0x9d461be8,0xdb8002d3}},	//   vart, _kkel_, бенд, _ካብዞም_, 
   {{0x200e1be9,0xd6540375,0x21d40055,0x00000000}},	//   prei_, צירת_, _bāhv_, --, 
   {{0xdd100135,0xa0c4143e,0x2c6c01e7,0x50d8010f}},	//   _iżżi, _ايشو, _ródú_, _עקסא, 
   {{0x2d8808cd,0x3f842d2f,0x7afc013c,0xb80c0210}},	//   _emae_, _umnu_, uart, िंघम_, 
   {{0x7afe1bea,0x26c42b57,0xeb9802e8,0x98bc0208}},	//   rart, _úloh_, ртящ_, _đtđ_, 
   {{0x7afc32ff,0x25ac0295,0x2f1000d1,0x5b24035b}},	//   sart, _nkel_, _فېۋر, шьҭа, 
   {{0x7afc24b6,0xa3c806b1,0x57d00825,0x00000000}},	// [3dd20] part, ोदा_, तदेह, --, 
   {{0x7afc0680,0x77952766,0x0b4000c0,0x59c40118}},	//   qart, زیزا, _еньн, लगहर, 
   {{0x21d40374,0x637c01e1,0x0b40009d,0x00000000}},	//   _kāhu_, _kènf, _энэн, --, 
   {{0xdb1c0268,0x637c007f,0x00000000,0x00000000}},	//   _ripù, _jènf, --, --, 
   {{0x23640f72,0x938823b3,0x21d402b5,0x00000000}},	//   _bolj_, лска_, _māhu_, --, 
   {{0x98a002d5,0x47d02abb,0x25ac002f,0x2a780ca8}},	//   _sakė_, _ريفر, _ekel_, _àgbè_, 
   {{0x23640276,0xc0d00092,0x00000000,0x00000000}},	//   _dolj_, _የቆመ_, --, --, 
   {{0x96e80022,0x00000000,0x00000000,0x00000000}},	//   _шьҭа_, --, --, --, 
   {{0x2bb800e1,0x00000000,0x00000000,0x00000000}},	//   _इठला, --, --, --, 
   {{0xf28800ec,0x00000000,0x00000000,0x00000000}},	//   _پھتو_, --, --, --, 
   {{0x1ce0031c,0x21d4002b,0x2d983822,0xfe2001af}},	//   _ཧྥང_, _bāhu_, éreo_, пьян, 
   {{0x02b4010f,0xd01801a9,0x7d000174,0x00000000}},	//   _פלאך_, _бфк_, ómsp, --, 
   {{0x2b40004e,0x8fa440c5,0x00000000,0x00000000}},	//   _pahc_, _ладе, --, --, 
   {{0x62000724,0x00000000,0x00000000,0x00000000}},	//   _äylä, --, --, --, 
   {{0x42d8008f,0x7ac468eb,0x00000000,0x00000000}},	//   רקלע, зсте, --, --, 
   {{0xeba002dd,0xac940150,0x00000000,0x00000000}},	//   _ﺍﺳﯩﻞ_, _майш, --, --, 
   {{0x2d98007f,0x644c0115,0x00000000,0x00000000}},	// [3dd30] mnse_, ĥaik, --, --, 
   {{0x25ae1beb,0x2d9a1bec,0x00000000,0x00000000}},	//   _skel_, lnse_, --, --, 
   {{0x2d980bd7,0xf7721bed,0x6588022e,0x00000000}},	//   onse_, راك_, аshа, --, 
   {{0x2d9a1bee,0x637c0066,0x00000000,0x00000000}},	//   nnse_, _kèng, --, --, 
   {{0x637c00f2,0x23657604,0x2d9a1bef,0x28c44f4b}},	//   _jèng, _polj_, inse_, लेशि, 
   {{0xc5f87146,0x637e1bf0,0x2d9801e7,0x00000000}},	//   _معرض_, _mèng, hnse_, --, 
   {{0xdb1c069c,0x637c0066,0xd344006c,0x00000000}},	//   _shpë, _lèng, تیله_, --, 
   {{0x2d980196,0xe2981f0e,0x25ac020c,0xfa7802e4}},	//   jnse_, лаһ_, _ukel_, מעות_, 
   {{0xd58403e6,0x3dc0015d,0x21d40055,0xf55401c6}},	//   _بێنه_, _rhiw_, _rāhu_, _эвтэ, 
   {{0x443e1bf1,0xd34439b1,0xdea0015e,0xde280b01}},	//   _isu_, _وینه_, ویشی, ажод_, 
   {{0x443e1bf2,0x42b40150,0x22945207,0x00000000}},	//   _hsu_, _اناڭ_, _بلاس, --, 
   {{0x443c06a3,0x637c0066,0x326401b9,0x760001d3}},	//   _ksu_, _bèng, _этув, _házá, 
   {{0x443c03a2,0x637c0066,0x7600013a,0xc04401e2}},	//   _jsu_, _cèng, _kázá, _دخاو, 
   {{0x2d9a1bf3,0x8af403b9,0x00000000,0x00000000}},	//   anse_, _şərb, --, --, 
   {{0x09e034cd,0x7f40d829,0x21d402b5,0x443e1bf4}},	//   досн, _ianq, _tāhu_, _lsu_, 
   {{0x443e1bf5,0x7f421bf6,0x760001d3,0x00000000}},	//   _osu_, _hanq, _lázá, --, 
   {{0x443c0134,0x7f401bb7,0x637c020c,0x28c4353b}},	// [3dd40] _nsu_, _kanq, _kènd, लेलि, 
   {{0x7c240a73,0x47c000d6,0x7f40002e,0x3c24014a}},	//   _iqir, дбув, _janq, möv_, 
   {{0x7f421bf7,0x443e1bf8,0x95861bf9,0x98a004fe}},	//   _manq, _asu_, олже, _kakī_, 
   {{0x443e1bfa,0x29d401e4,0x7f40ac19,0x7c240200}},	//   _bsu_, _eĥas_, _lanq, _kqir, 
   {{0x443e1bfb,0x3c24014a,0x54340633,0x00000000}},	//   _csu_, növ_, ترار, --, 
   {{0x7f421bfc,0x443c01bf,0xcc38010f,0xd5e800ec}},	//   _nanq, _dsu_, שעסט, _نعرن_, 
   {{0x443e1bfd,0x2d9805e4,0x00000000,0x00000000}},	//   _esu_, ynse_, --, --, 
   {{0x443e1bfe,0x8cc806b1,0x00000000,0x00000000}},	//   _fsu_, सेडो, --, --, 
   {{0x705410fe,0x7f421bff,0x443c02b9,0x2d9a1c00}},	//   سندا, _banq, _gsu_, érem_, 
   {{0x637c020c,0x7f400784,0x4f68fb98,0x0854011a}},	//   _cènd, _canq, ршим_, קבים_, 
   {{0x7f421c01,0x7c240009,0xa3c81d34,0xdcf40205}},	//   _danq, _aqir, ोदर_, _akyı, 
   {{0x2d9a1c02,0x637c04fb,0x4638008f,0x443c0042}},	//   unse_, _pèng, בעטע, _ysu_, 
   {{0xb3280003,0x7f4000e8,0x7024031c,0xcb4400d4}},	//   _ལྡོང_, _fanq, _འདྲུ_, охви, 
   {{0x35cc00e1,0x27ec0432,0xcdd80114,0x28c40022}},	//   ़गड़, _çeni_, _књи_, ҧшаҳ, 
   {{0xfe200022,0x00000000,0x00000000,0x00000000}},	//   _жьын, --, --, --, 
   {{0x7f400921,0x7c24025c,0x3c2401b8,0x637c020c}},	//   _zanq, _fqir, böv_, _tèng, 
   {{0x7f421c03,0x7c2400f1,0xa775063f,0xac940063}},	// [3dd50] _yanq, _gqir, плач, _хапш, 
   {{0x7f418d27,0x443e1c04,0x6f1c08c2,0x9f4c0432}},	//   _xanq, _rsu_, òrch, kseý_, 
   {{0x443c2b1d,0x77b001e6,0xb328025c,0xf99001ed}},	//   _ssu_, växt, _ལྡེང_, ربہ_, 
   {{0x67d61c05,0x637c5f72,0x443c0f85,0xda6400f1}},	//   _ному, _mène, _psu_, _راپي, 
   {{0x68fc035a,0x66fc00e2,0xa2e61c06,0x00000000}},	//   _iesd, tākļ, полд, --, 
   {{0x68fc047e,0x63861c07,0x443c4ff3,0x93400212}},	//   _hesd, ягла, _vsu_, енше, 
   {{0x443c0198,0x637c020c,0x97000131,0x7f421c08}},	//   _wsu_, _rènd, _سېنى, _ranq, 
   {{0x443e1c09,0x68fc089c,0x27f80ac5,0x3c2401b8}},	//   _tsu_, _jesd, _kwsn_, yöv_, 
   {{0x443e1c0a,0x7f405d55,0x1b200183,0x68fe1c0b}},	//   _usu_, _panq, য়তে_, _mesd, 
   {{0x6568028c,0x68fe1c0c,0x7f40016d,0x1e847257}},	//   _hoeh, _lesd, _qanq, злом, 
   {{0x2f5410f5,0x656803c1,0x9d4400a8,0x7f421c0d}},	//   єтьс, _koeh, пенд, _vanq, 
   {{0xd00c073e,0xdca54ff7,0x7f421c0e,0x656928ca}},	//   خلی_, зами, _wanq, _joeh, 
   {{0x6568316f,0x644400b0,0x5fd4000d,0xe7bc243c}},	//   _moeh, āhiw, _डंटल, ्गाप, 
   {{0x68fcda87,0x629c0134,0x656801ab,0x9e582218}},	//   _aesd, _ɛson, _loeh, _гриф_, 
   {{0x637e1c0f,0x68fc010b,0x3c240793,0x66040200}},	//   _gène, _besd, söv_, jshk, 
   {{0x2d940046,0xd7f000c6,0xdcf40064,0x00000000}},	//   _орыс, فكر_, _klyč, --, 
   {{0x68fcbae7,0x38c96657,0x6604009a,0x3ba4059f}},	// [3dd60] _desd, زاری_, eshk, _олиҳ, 
   {{0x75200175,0xae8000ee,0x70d828fe,0x00000000}},	//   _scmz, _öñün, _डल्ल, --, 
   {{0xada400d0,0x60d80142,0x15b80137,0xd6d11fdc}},	//   spĺň, _ogwm, быды_, رقص_, 
   {{0x68fc0113,0x6568000f,0x94241c3e,0xdec81772}},	//   _gesd, _coeh, змде, በልና_, 
   {{0x656801af,0x85021c10,0x6604058a,0x00000000}},	//   _doeh, روون, ashk, --, 
   {{0x68fc0d27,0x66040200,0x23e400d4,0x00000000}},	//   _zesd, bshk, фіїв, --, 
   {{0x877804ac,0xdb1c68b1,0x6568005a,0x68fdd9af}},	//   _פאלי, _hipó, _foeh, _yesd, 
   {{0x9f4c0ffb,0x958409a5,0x518420b0,0xd138035b}},	//   lpeè_, _элбе, яула, схк_, 
   {{0x38600005,0x637c033b,0xd14801b9,0x00000000}},	//   nxir_, _sène, لشکن_, --, 
   {{0x13a805d9,0x386000db,0xd24c0050,0xb9140055}},	//   _اٿئي_, ixir_, _مۆت_, _enaḿ_, 
   {{0xe8b8a3a7,0x00000000,0x00000000,0x00000000}},	//   _आर्च, --, --, --, 
   {{0x0694025f,0x637e1c11,0x2d580276,0xe24435f9}},	//   לדים_, _vène, цимь_, _زخمي, 
   {{0x0ca806bb,0x68fe1c12,0xdb1c04d4,0x00000000}},	//   стни_, _resd, _nipó, --, 
   {{0x68fe1c13,0x27f80175,0xbdf401d3,0x66040009}},	//   _sesd, _rwsn_, _کروا_, yshk, 
   {{0xdb1c0124,0x68fe1c14,0x00000000,0x00000000}},	//   _aipó, _pesd, --, --, 
   {{0x3da402d5,0xa0200139,0x00000000,0x00000000}},	//   _прыб, _ğöze, --, --, 
   {{0x42781b49,0x68fe1c15,0xfc308d3c,0x00000000}},	// [3dd70] ባልነት_, _vesd, _یحی_, --, 
   {{0x65691a3b,0x637c020c,0x66042edd,0x68fc5cc9}},	//   _soeh, _mènc, tshk, _wesd, 
   {{0x637c0137,0x68fe1c16,0xeb5000db,0x6604058a}},	//   _lènc, _tesd, _كۉڭگ, ushk, 
   {{0x6604044e,0x68fc0857,0xf65000cf,0x00000000}},	//   rshk, _uesd, دئك_, --, 
   {{0xd005b565,0x442a1c17,0x00000000,0x00000000}},	//   _جل_, сцем_, --, --, 
   {{0xdb1c0137,0x6568013f,0x1ce0025c,0x51f401ed}},	//   _hipò, _woeh, _ཧྥན_, ڈسٹر, 
   {{0x65680b4f,0x00000000,0x00000000,0x00000000}},	//   _toeh, --, --, --, 
   {{0x241801f4,0xdfe801c4,0x00000000,0x00000000}},	//   _мобы_, одид_, --, --, 
   {{0xdec80092,0x8de40220,0x00000000,0x00000000}},	//   በውን_, _ﺍﻟﺨﻁ, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb3280003,0x00000000,0x00000000,0x00000000}},	//   _ལྡིང_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa0680261,0x0d800024,0x3860025c,0x81dc00cc}},	//   _фала_, тлян, xxir_, _থবি_, 
   {{0x4de402dd,0x9e6433d2,0xd9c400cd,0x00000000}},	//   _ﺍﻟﯩﻨ, _ياغن, वष्ट, --, 
   {{0x9d4402dd,0xdb0c0162,0x64dc0073,0x6ad000eb}},	//   _жейд, glbá, यशाळ, _ত্বো, 
   {{0x1ea80451,0x00000000,0x00000000,0x00000000}},	//   _ٿاڻي_, --, --, --, 
   {{0xdb1c0137,0xcc8401ee,0x9f4c00a2,0x00000000}},	// [3dd80] _dipò, _объе_, lseñ_, --, 
   {{0x63a00472,0x38600077,0x00000000,0x00000000}},	//   _njln, rxir_, --, --, 
   {{0x212c062c,0xc7ac007b,0x19c4117e,0xbbbc06b1}},	//   kfeh_, جّل_, _обом, ोगीक, 
   {{0xdb1db12f,0x00000000,0x00000000,0x00000000}},	//   _tipó, --, --, --, 
   {{0xd72400c7,0x38600327,0x44f001ec,0x2d9803df}},	//   _оҭаҧ_, qxir_, тпіс, érei_, 
   {{0x637c020c,0xa6ac03d4,0x69e802d2,0xe8800139}},	//   _rènc, কেইট, _óseð, läşü, 
   {{0x212c0205,0x00000000,0x00000000,0x00000000}},	//   ffeh_, --, --, --, 
   {{0x3d18033f,0x45cc0220,0x28c46d65,0x00000000}},	//   थलों_, _ﺑﺎﻳﻼ, लेकि, --, 
   {{0x77440020,0xef100137,0x2184074d,0x00000000}},	//   _የማስተ, гүлө, хăтр, --, 
   {{0x637c00cf,0x92582bc0,0x00000000,0x00000000}},	//   _vènc, _وشار_, --, --, 
   {{0xd1f80020,0x4e880b32,0x8140006c,0x81f400ae}},	//   ጊቶች_, ющим_, رنین, _يفكر_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x321c01f1,0xdb1c067c,0x3da402d5,0xf204012d}},	//   luvy_, _ripò, трэб, _रबड़_, 
   {{0xdb1c02bd,0x00000000,0x00000000,0x00000000}},	//   _sipò, --, --, --, 
   {{0xdb1c007f,0xa9340b3b,0x0e4401c6,0x16400092}},	//   _pipò, невш, _цэлм, _የፋብሪ, 
   {{0xf7720bcb,0x637c00f2,0xbea01d39,0x00000000}},	//   یال_, _mèna, _шајк, --, 
   {{0x611406be,0x00000000,0x00000000,0x00000000}},	// [3dd90] ləlç, --, --, --, 
   {{0xe7b5f30b,0xbc38a706,0x321c00c7,0xe50800ec}},	//   رماد, _آسيا_, kuvy_, ڳيتو_, 
   {{0x6b9407d6,0xaa9400a8,0xdb1c004e,0x6514fe06}},	//   mizg, _чинч, _tipò, فوائ, 
   {{0x6b961c18,0x00000000,0x00000000,0x00000000}},	//   lizg, --, --, --, 
   {{0x69ce1c19,0x09e4009e,0xa878010f,0xfa2c0327}},	//   mmae, _ফিটা, _זאָר, _སཱོན_, 
   {{0x637c0100,0x69cc05c7,0x6b961c1a,0x6305f8f5}},	//   _bèna, lmae, nizg, روبل, 
   {{0x10cc0150,0x00000000,0x00000000,0x00000000}},	//   _ﻗﺭﺍﻨ, --, --, --, 
   {{0x69cc2f50,0xe04401f4,0x00000000,0x00000000}},	//   nmae, ении, --, --, 
   {{0xd00d1413,0x6b961c1b,0xf1a803e6,0x644c01e4}},	//   ملي_, kizg, باوه_, ĥais, 
   {{0x9e642826,0x69ce1c1c,0xdb0ceda4,0xd24c07d6}},	//   евод, hmae, cobè, _گچه_, 
   {{0x69cd3433,0x6b961c1d,0x42440354,0x00000000}},	//   kmae, dizg, _юхаб, --, 
   {{0x61e00140,0x69cc0369,0x65780175,0x9f9400c7}},	//   _iull, jmae, nkwh, ьықә, 
   {{0x61e06852,0x6b94022e,0x69cc0142,0x5574010f}},	//   _hull, fizg, dmae, גערן_, 
   {{0x61e21c1e,0x69cc731b,0x00000000,0x00000000}},	//   _kull, emae, --, --, 
   {{0x61e21c1f,0x00000000,0x00000000,0x00000000}},	//   _jull, --, --, --, 
   {{0x2d9405f5,0x57ea1c20,0x69cd3b67,0x00000000}},	//   _арьс, здам_, gmae, --, 
   {{0x02c809b2,0x6b940139,0x00000000,0x00000000}},	// [3dda0] ाधुन, bizg, --, --, 
   {{0x61e21c21,0x7ac40022,0xdb0c003e,0x69cc01f4}},	//   _oull, _аҩга, kobé, amae, 
   {{0x61e21c22,0x69cc08e5,0x00000000,0x00000000}},	//   _null, bmae, --, --, 
   {{0x09e400bd,0xceb00a1e,0xdb0c02fb,0x1614012d}},	//   _ফিচা, ניא_, dobé, दूगर_, 
   {{0x61e00cfe,0xc6680092,0x00000000,0x00000000}},	//   _aull, _በዋርካ_, --, --, 
   {{0x7984e94c,0x8c180375,0xdb0c0129,0x638000c7}},	//   lhiw, פוצי, fobé, аҳуа, 
   {{0x61e21c23,0x07a21c24,0xc7a0422d,0xdb0c020c}},	//   _cull, _сарн, _сирк, robè, 
   {{0x61e21c25,0x28080724,0x79840099,0x637c007f}},	//   _dull, _ätnä_, nhiw, _vèna, 
   {{0x321c0306,0x41c015eb,0xc42800cf,0x00000000}},	//   suvy_, دقيق, _ىتكە_, --, 
   {{0x61e008a5,0x2fd80008,0x637c0ffb,0x28c44721}},	//   _full, örg_, _tèna, लेटि, 
   {{0x61e19d28,0x637c0036,0x00000000,0x00000000}},	//   _gull, _kènn, --, --, 
   {{0x7984014b,0x69cc0007,0x86980a1e,0xc0e05211}},	//   jhiw, xmae, לייז, _боцк, 
   {{0x61e00936,0x798405d9,0x6b95dd12,0xeb9800ee}},	//   _zull, dhiw, tizg, җиң_, 
   {{0x61e00598,0xa020013d,0x00000000,0x00000000}},	//   _yull, _şöge, --, --, 
   {{0x61e21c26,0x798406d6,0x69cc05ac,0x3eb002f0}},	//   _xull, fhiw, tmae, čaté_, 
   {{0x8d761c27,0x79843fed,0x318c0118,0x6b94022e}},	//   _ساعا, ghiw, tězy_, sizg, 
   {{0x69cc39c2,0x9a7c0020,0xc0c40023,0x2d9800db}},	// [3ddb0] rmae, ከላከል_, _ጽልሚ_, éreu_, 
   {{0x69ce05de,0x00000000,0x00000000,0x00000000}},	//   smae, --, --, --, 
   {{0x27e400d7,0x39e80108,0x00000000,0x00000000}},	//   _člnu_, _пьян_, --, --, 
   {{0x79861c28,0x69cc0369,0x64a40022,0x00000000}},	//   chiw, qmae, ҭаҧа, --, 
   {{0x61e21c29,0xb9541830,0x320c00a2,0x09bc63a5}},	//   _sull, _свящ, _avdy_, ्षीय, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x61e00dfd,0x85ba1c2a,0xb3080116,0x00000000}},	//   _qull, _فارس_, رغول_, --, 
   {{0x20561c2b,0x61e21c2c,0xdb0dac9e,0x846400a7}},	//   втор, _vull, robé, _пъзе, 
   {{0x61e01c1d,0xf3ec6518,0xdb0d14a3,0x9fc80022}},	//   _wull, _ың_, sobé, мгиа_, 
   {{0x61e01033,0xca4c02dd,0x34940150,0x00000000}},	//   _tull, _ﺍﺗﺎ_, _саур, --, 
   {{0x61e21c2d,0x2ca80014,0x0fc000ee,0x4b2405ac}},	//   _uull, _axad_, рйэн, য়াগ_, 
   {{0x798402c4,0xf1c802dd,0x00000000,0x00000000}},	//   xhiw, _كولى_, --, --, 
   {{0x798406d6,0xfeb8130e,0xee380220,0x00000000}},	//   vhiw, _کاشت_, _үні_, --, 
   {{0x79840053,0x8c400640,0x699407a5,0x00000000}},	//   whiw, јере, ҳрух, --, 
   {{0x79861c2e,0xabc40184,0x8a000640,0xdb0c005c}},	//   thiw, уарҙ, изре, jlbå, 
   {{0x4db40124,0x2d998da2,0xf9c41291,0x00000000}},	//   _ирыӡ, éret_, احسی, --, 
   {{0x798418f7,0x5ca400db,0x00000000,0x00000000}},	// [3ddc0] rhiw, _шииб, --, --, 
   {{0x79841935,0x99e407d6,0x637c0ffb,0x9b8800ec}},	//   shiw, _ижод, _sènn, _آندل_, 
   {{0x7d061c2f,0x7984aef6,0xdb0c05ac,0x00000000}},	//   _keis, phiw, glbå, --, 
   {{0x7d04009d,0x00000000,0x00000000,0x00000000}},	//   _jeis, --, --, --, 
   {{0x637c0268,0xf31401c0,0xca7c0092,0xd7c800ae}},	//   _vènn, гдлэ, _ከሆነም_, _يوجه_, 
   {{0x30141d56,0x39421c30,0x7d061c31,0xd2580e58}},	//   қдор, leis_, _leis, дци_, 
   {{0x637c026c,0xcb100375,0xd2440276,0x00000000}},	//   _tènn, בלו_, тэли, --, 
   {{0x7d061c32,0x39421c33,0x46a21c34,0xb17c01e4}},	//   _neis, neis_, _тасв, _buĥa, 
   {{0x637c642b,0x93440120,0x00000000,0x00000000}},	//   _gèno, _инае, --, --, 
   {{0x39421c35,0x7d0400ae,0x00000000,0x00000000}},	//   heis_, _aeis, --, --, 
   {{0x7d061c36,0x471800c8,0x39400024,0x3f621c37}},	//   _beis, וויג, keis_, ртыб, 
   {{0xac181830,0x7d059a8f,0x765802f6,0x39400789}},	//   ному_, _ceis, ävyy, jeis_, 
   {{0x7d061c38,0x39421c39,0xbb64037e,0xcfa44fac}},	//   _deis, deis_, _snsで_, _ишки, 
   {{0x5f1802f5,0x7d04062c,0xc4d0011a,0x00000000}},	//   ত্বও_, _eeis, יגר_, --, 
   {{0x2d9a1c3a,0x6f080810,0x394001f5,0x7d046b41}},	//   éres_, madc, feis_, _feis, 
   {{0x7d061c3b,0x2ca80f87,0x3941c978,0xcbe40124}},	//   _geis, _txad_, geis_, _ицои, 
   {{0x2d98367a,0xe6961c3c,0xac9801c8,0x00000000}},	// [3ddd0] mise_, گلاد, _سندا_, --, 
   {{0x6f0a1c3d,0x7d05faf5,0x2d980d92,0x9f4c0120}},	//   nadc, _zeis, lise_, mpeã_, 
   {{0x39421c3e,0x2d9a1c3f,0xb924063f,0x7d061c40}},	//   beis_, oise_, _jesụ_, _yeis, 
   {{0x6f0a1c41,0x39421c42,0xa97800c8,0x00000000}},	//   hadc, ceis_, _נאָכ, --, 
   {{0x69dc004b,0x68ec0014,0x6f0801e4,0xe3741952}},	//   _iise, mcad, kadc, ллды, 
   {{0x2d98b544,0x69de1c43,0x637c067c,0xa2281d5b}},	//   hise_, _hise, _vèno, ежка_, 
   {{0x69de1c44,0x2d9853ff,0x6f0830de,0x27ea1c45}},	//   _kise, kise_, dadc, lqan_, 
   {{0x29d40115,0x685402d3,0x637c068c,0x67240268}},	//   _aĥaz_, _መራሕት, _tèno, lghj, 
   {{0x7d061c46,0x69de1c47,0xdb0802fb,0xdee4119e}},	//   _reis, _mise, šném, лопи, 
   {{0x69de1c48,0x67240ba3,0xc2c80214,0x644a1c49}},	//   _lise, nghj, _قبال_, _isei, 
   {{0x7d061c4a,0x2d985975,0x3ec00364,0x6724026c}},	//   _peis, fise_, ринҳ, ighj, 
   {{0x69de1c4b,0x63ac0597,0x2d9a1c4c,0x67240ffb}},	//   _nise, éanf, gise_, hghj, 
   {{0x39421c4d,0x7d04601a,0x442c1570,0x637c02bd}},	//   veis_, _veis, ntg_, _lènm, 
   {{0x7d061c4e,0x69de1c4f,0x3941113c,0x2d9a1c50}},	//   _weis, _aise, weis_, érer_, 
   {{0x7d061c51,0x69de1c52,0x39401497,0x68ee1c53}},	//   _teis, _bise, teis_, fcad, 
   {{0x69de1c54,0x644a1c55,0x672419f5,0x9f4c0ffb}},	//   _cise, _osei, eghj, lpeà_, 
   {{0x200e1c56,0x64480327,0x09e001ec,0xeab001e2}},	// [3dde0] nsei_, _nsei, _қоян, معې_, 
   {{0x69de1c57,0x68ee1c58,0x39421c59,0x200e1c5a}},	//   _eise, acad, seis_, isei_, 
   {{0x69de1c5b,0x39421c5c,0x200c0369,0x27e835a3}},	//   _fise, peis_, hsei_, aqan_, 
   {{0x69de1c5d,0x68ee1c5e,0x672408e5,0x644800b5}},	//   _gise, ccad, aghj, _bsei, 
   {{0x200c0369,0xf8b800e1,0x69b00073,0x00000000}},	//   jsei_, _आडिय, ंवरी, --, 
   {{0x2d980028,0x69dd39b3,0xf1f4010b,0x6f080009}},	//   zise_, _zise, азкэ, xadc, 
   {{0xfe65cc9c,0x64499a09,0x442e1c5f,0xe7b000db}},	//   _اد_, _esei, atg_, _بۅلد, 
   {{0x69de1c60,0x637c0100,0xdb0c02fb,0x2d980fec}},	//   _xise, _jènj, dobí, xise_, 
   {{0xf48404d3,0x442c906a,0x73c40417,0x4f28187f}},	//   _ئازی, ctg_, _кәке, нінг_, 
   {{0x2d9804d1,0x91e61c61,0xdb0c01a8,0x0f1c0c70}},	//   wise_, _боже, albú, पलेस_, 
   {{0x2d9a1c62,0x200e1c63,0xdb0c00d2,0x6f082a5c}},	//   tise_, asei_, gobí, radc, 
   {{0x27e80986,0x2d98654d,0xf04401d3,0xaf3400f1}},	//   yqan_, uise_, _نعتی, ارښت, 
   {{0x69de1c64,0x80140014,0x3d94013e,0x27e80113}},	//   _rise, _مٲنز_, сияр, xqan_, 
   {{0x09bc1a3e,0xc0c40023,0xaed4013d,0x6f080455}},	//   ्ष्य, _ጽፍሒ_, _колш, qadc, 
   {{0xf0b000f8,0x637c020c,0x442c05d5,0x68ec44b6}},	//   _دیکھ, _bènj, ztg_, tcad, 
   {{0x2d9a1c65,0x442c011c,0x27e80724,0xdb1c007f}},	//   qise_, ytg_, tqan_, _sipô, 
   {{0x69dc08d7,0x8cc80034,0x27e80009,0x00000000}},	// [3ddf0] _vise, सेखो, uqan_, --, 
   {{0x27e81bb7,0xe71a1c66,0x7af80419,0x00000000}},	//   rqan_, ئيات_, čatí, --, 
   {{0x69de1c67,0x27e80bf1,0x45a02e56,0x6b8407c5}},	//   _tise, sqan_, مەسك, _ilhg, 
   {{0x637c0066,0x69dc0c3a,0x6724026c,0xe4d8007b}},	//   _gènj, _uise, sghj, نوات_, 
   {{0x2328cbbe,0x27ea1c68,0x6b4802d3,0xe3b1e34e}},	//   воли_, qqan_, _ብምቕጻ, يرت_, 
   {{0x442c07de,0x2214cfae,0x00000000,0x00000000}},	//   rtg_, афир, --, --, 
   {{0x442c1570,0x200c0a73,0x00000000,0x00000000}},	//   stg_, wsei_, --, --, 
   {{0x200c007d,0xa5c40598,0x644a1c69,0xb17c01e4}},	//   tsei_, _төзе, _tsei, _duĥo, 
   {{0x64480664,0x9f84006c,0xa3000184,0x3cf406ab}},	//   _usei, игид, _һүҙе, ंडसे_, 
   {{0x200e1c6a,0xa29454be,0x2d9a1c6b,0x3f80002e}},	//   rsei_, _казі, èren_, óju_, 
   {{0x200e1c6c,0x02a421ca,0x637c01c7,0xa2d40137}},	//   ssei_, _срам, _lènk, _ئيات, 
   {{0x200c0276,0xdb0c02fb,0x425011e6,0x00000000}},	//   psei_, robí, _پنچر, --, 
   {{0x0c2131bb,0x26040490,0xdb0c219b,0xdcb0215c}},	//   омян, हीती_, sobí, زىس_, 
   {{0x7df00311,0x00000000,0x00000000,0x00000000}},	//   _răsf, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x52e006b1,0xf1d09c97,0x00000000,0x00000000}},	//   _पल्स, _ﺗﺎﻟﻘ, --, --, 
   {{0xa2d400dc,0x00000000,0x00000000,0x00000000}},	// [3de00] येत्, --, --, --, 
   {{0x25ac00df,0x00000000,0x00000000,0x00000000}},	//   _ĉela_, --, --, --, 
   {{0x55061c6d,0x7b840116,0x00000000,0x00000000}},	//   ачла, _ناھە, --, --, 
   {{0x958400d8,0x00000000,0x00000000,0x00000000}},	//   јлде, --, --, --, 
   {{0x93446f32,0xc424005b,0x93881e35,0x00000000}},	//   инде, ающе_, кска_, --, 
   {{0x70440222,0x00000000,0x00000000,0x00000000}},	//   ەردە, --, --, --, 
   {{0x46a21c6e,0x35c421f3,0xcb10011a,0x00000000}},	//   _дарв, _гавҳ, קלה_, --, 
   {{0x4ee000cc,0x59b401f9,0x00000000,0x00000000}},	//   _য়েল, ंविर, --, --, 
   {{0x42c447da,0x321c0175,0x6fb86741,0x90800150}},	//   лгән_, srvy_, лгир_, _ﺨﻁﺒﺔ_, 
   {{0xc3243cd9,0x2019a579,0xc834010f,0x00000000}},	//   _ەكەن_, ásia_, סטיץ_, --, 
   {{0xa2d400dc,0x59b41116,0xadb400db,0x00000000}},	//   येद्, ंवार, йбош, --, 
   {{0xed640213,0xc278011a,0x016000d8,0x01d40ef6}},	//   _şöbə_, _שראי, _мкхо, _ﺟﺎﻳﻨ, 
   {{0x8fa61c6f,0x637c020c,0xe9780075,0x00000000}},	//   _каде, _bènh, қбаш_, --, 
   {{0x2cac038f,0x49b85439,0x6f180014,0x6d9c00e4}},	//   ħed_, چارد_, _صٲبس_, tĩas, 
   {{0x49b815f6,0x0904fda6,0xe91802bf,0xfbd0009f}},	//   نارد_, ичам, лові_, بتَ_, 
   {{0x91c803d4,0x00000000,0x00000000,0x00000000}},	//   ৰৱৰ্, --, --, --, 
   {{0x26c41d35,0x00000000,0x00000000,0x00000000}},	// [3de10] _šlo_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbac80014,0xe4c400d1,0x00000000,0x00000000}},	//   _نژٲن_, әйли, --, --, 
   {{0xe9448117,0xfe34011a,0x25088f52,0x00000000}},	//   _اردی, שראי_, ارای_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x637c0066,0x26c40421,0x00000000,0x00000000}},	//   _jèni, _álo_, --, --, 
   {{0xfd680432,0x0584023b,0xe2980116,0x35280137}},	//   _durỳ, _тугм, каһ_, _ەسەپ_, 
   {{0x637c004e,0xdb0c01ed,0x7df00356,0xe2f801ec}},	//   _lèni, őkés, _măse, _безі_, 
   {{0xa0a4183c,0x443e1c70,0x9f8448d4,0xed600419}},	//   _қалд, _ipu_, сгод, ížny_, 
   {{0x1d0a1c71,0x3cf40073,0x7cd801e1,0x64a401ee}},	//   лени_, ंडले_, _o̟rò, _таҡа, 
   {{0x443e1c72,0xdb0c0646,0x00000000,0x00000000}},	//   _kpu_, dobá, --, --, 
   {{0x443c0263,0xdb080118,0xdee401f4,0x00000000}},	//   _jpu_, šním, _лоли, --, 
   {{0x443e1c73,0x1b4801f4,0x00000000,0x00000000}},	//   _mpu_, ызги_, --, --, 
   {{0x7df0084c,0x87e40131,0xdb0c00db,0xfce400d1}},	//   _băse, ەتمە, robà, _һоқо, 
   {{0x9f200075,0x637c04fb,0x443e1c74,0x6aa001e7}},	//   _بۈگۈ, _dèni, _opu_, úlfa, 
   {{0x443cf321,0x00000000,0x00000000,0x00000000}},	// [3de20] _npu_, --, --, --, 
   {{0x18a40fab,0x637c4b84,0x00000000,0x00000000}},	//   _ҳамм, _fèni, --, --, 
   {{0x443e1c75,0x637c00db,0x9f4c0108,0x00000000}},	//   _apu_, _gèni, mpeä_, --, 
   {{0x18a46d2b,0x3e340020,0x94856190,0x7df0084c}},	//   _гамм, _እያደረ, йылд, _găse, 
   {{0xd7c803e6,0xe4e402bf,0x443c6302,0x3f840254}},	//   _موحه_, цієн, _cpu_, _olnu_, 
   {{0x26040574,0xc0bc001f,0xd704010b,0x33580276}},	//   हीही_, ዶክስ_, _ызги, ракэ_, 
   {{0x443e1c76,0x637c00db,0x645c032e,0x823000ae}},	//   _epu_, _xèni, _ásin, كريا, 
   {{0x443c07ab,0x70452374,0x765c062c,0xf1d40046}},	//   _fpu_, ەرگە, _irry, _ﺟﺎﻗﺘ, 
   {{0x77600201,0x63ac59c6,0xc9500375,0xdb0c01ed}},	//   _ለማስተ, éanc, למה_, zobá, 
   {{0x9344084c,0x3e540051,0x66100166,0x00000000}},	//   _ынзе, _băt_, _äkkä, --, 
   {{0x94840046,0x3e540311,0x00000000,0x00000000}},	//   _тыңд, _căt_, --, --, 
   {{0x443c05b1,0xd0080b3b,0x50c801af,0x00000000}},	//   _ypu_, _беде_, _йылм_, --, 
   {{0x5fc008b0,0x637c00cf,0x00000000,0x00000000}},	//   ﺮﯨﭙﺘ, _sèni, --, --, 
   {{0x31240020,0x765c7ae4,0x3e540356,0x7df00356}},	//   _ተቀባይ, _orry, _făt_, _săse, 
   {{0xae0401ec,0x00000000,0x00000000,0x00000000}},	//   _بوعى, --, --, --, 
   {{0x637e1c77,0xdb0e1c78,0x25ac010f,0x00000000}},	//   _vèni, robá, _ĉelo_, --, 
   {{0x765c7ae4,0x0ba800db,0xdb0e1c79,0x7d7cb8b4}},	// [3de30] _arry, _مادى_, sobá, _תנחו, 
   {{0x637c0066,0xe99801d5,0x765c0200,0x7d0003e0}},	//   _tèni, _چندغ_, _brry, ımse, 
   {{0x4a00025c,0x2d88017a,0x443e1c7a,0xaadc07d0}},	//   _མཆིལ_, _klae_, _spu_, _मणिक, 
   {{0x443e1c7b,0xfa88004e,0x6fac01f9,0xc50800db}},	//   _ppu_, _ысый_, ीकडू, اتال_, 
   {{0xa2e400f7,0x765c7a55,0x67d40137,0xe4c40131}},	//   оолд, _erry, _мому, әйһи, 
   {{0xdb1c006a,0xfa347735,0xcaf8012d,0x443c0064}},	//   _akpê, _برید, ्रिड_, _vpu_, 
   {{0xcfcc015b,0x66740214,0x765c0200,0x260401f9}},	//   রদান, _بگذر, _grry, हीशी_, 
   {{0xa2d428e1,0xc51408cf,0xd24c0592,0x201800d8}},	//   येष्, _دبست, ئني_, ásio_, 
   {{0x443c096b,0xd00e1c7c,0x4fe5201c,0x3f8400d7}},	//   _upu_, نلي_, омын_, _plnu_, 
   {{0x66140618,0x7df0084c,0x27f8020b,0x2d88213c}},	//   _kvzk, _născ, _mtsn_, _alae_, 
   {{0xa119920b,0x25ac000f,0x3f840306,0x0c6c0092}},	//   _نقاط_, _kjel_, _vlnu_, _ትላለች_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x29180327,0x7df00356,0xaae418fd,0x00000000}},	//   _adsa_, _căsc, كسفو, --, 
   {{0xfdf40451,0x9f4c01f4,0x7ff40244,0x00000000}},	//   _ابتڙ_, rpeä_, _ئسڵا, --, 
   {{0x3ea00184,0x28b400c5,0xdca4af86,0xdb0c002f}},	//   _миҙг, _अँखि, _майи, llbü, 
   {{0xb4c80406,0x9f4c01f4,0x00000000,0x00000000}},	// [3de40] _उरे_, ppeä_, --, --, 
   {{0x291a1c7d,0xe8f8013e,0x25ac0254,0xdebc0023}},	//   _edsa_, илӣ_, _ajel_, _ተራን_, 
   {{0xa3cc00af,0x9b8801d9,0xa0200790,0x27f803b9}},	//   रतन_, _منکل_, _şöle, _etsn_, 
   {{0x9b44bf30,0x27f806d9,0x00000000,0x00000000}},	//   _انگو, _ftsn_, --, --, 
   {{0x20180122,0x79861c7e,0x13685a41,0x00000000}},	//   ásil_, mkiw, ишки_, --, 
   {{0x92580597,0x79840036,0x932400f1,0x00000000}},	//   لشعر_, lkiw, څرګن, --, 
   {{0x63ac06d5,0x765e1c7f,0x1cd8025c,0x798404ba}},	//   éana, _urry, _འཛའ_, okiw, 
   {{0x798433c1,0xdb0c0036,0xca78010f,0x25adc2eb}},	//   nkiw, lobä, ינצט, _gjel_, 
   {{0x53a400cf,0x00000000,0x00000000,0x00000000}},	//   _дааб, --, --, --, 
   {{0x3dc00054,0x2d880ea0,0x79840c6a,0x644c0129}},	//   _akiw_, _slae_, hkiw, çaie, 
   {{0x41b02e47,0x7df00311,0x2d880ea0,0x0dca1c80}},	//   ясәт, _răsc, _plae_, иуми_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xff4c0067,0x16080490,0x2d880ea0,0x00000000}},	//   رخی_, हीतर_, _vlae_, --, 
   {{0x33f000cf,0x6e9421f3,0x01d401ec,0x00000000}},	//   _màx_, _нилу, _ﺟﺎﯕﻌ, --, 
   {{0x7ac61c81,0xfe6c0338,0x8fd001ee,0x00000000}},	//   дсте, _لدي_, _нәүә, --, 
   {{0xbdf402f2,0x00000000,0x00000000,0x00000000}},	//   _بروا_, --, --, --, 
   {{0x1cd8025c,0x67e80427,0x6e2801bf,0x8ae400d4}},	// [3de50] _འཛར_, _ožje, ludb, _мінл, 
   {{0x637c0066,0x25ae1c82,0x79840083,0x386401a6}},	//   _jènt, _sjel_, akiw, _šmrc_, 
   {{0x6e280f72,0x637c020c,0x2918000d,0xa02000fd}},	//   nudb, _mènt, _tdsa_, _ğöme, 
   {{0x798401c7,0x261400df,0x9a8801af,0x00000000}},	//   ckiw, rĥo_, _ышыҡ_, --, 
   {{0xdb0c01b8,0xe3640395,0x25ad8ec0,0xb50800db}},	//   bobä, зкли, _vjel_, زۉلۅ_, 
   {{0x7df0084c,0x33f000e8,0xefe8001f,0x201800d7}},	//   _lăsa, _dàx_, _መለያ_, ásim_, 
   {{0x855401ed,0x6e28e3eb,0xe7f0107c,0x00000000}},	//   _ویئر_, judb, _अंडा_, --, 
   {{0x25ac488c,0x60087b17,0x63b00427,0x00000000}},	//   _ujel_, бним_, _šenč, --, 
   {{0x637c04fb,0x04540372,0x00000000,0x00000000}},	//   _bènt, _بئزد, --, --, 
   {{0x20e41682,0x637cda98,0x6e2805be,0x5f44007b}},	//   ḓi_, _cènt, fudb, أندل, 
   {{0x637c020c,0x798402d1,0x6e28058a,0xf36401d5}},	//   _dènt, ykiw, gudb, _ўтун, 
   {{0x637c068c,0x5bb40b7c,0x5238010f,0xdef800c7}},	//   _vènu, ृत्व, _לײענ, шыҩ_, 
   {{0x4c8000a7,0x6f7400ec,0x00000000,0x00000000}},	//   еляв, _ڪانء, --, --, 
   {{0x637c588b,0xaf0800cf,0xdce40205,0x6e288b23}},	//   _gènt, _ۇقۇم_, rikı, budb, 
   {{0x6720049b,0x1ca404d3,0x7984009f,0x6e28062c}},	//   _öljy, تێکی_, tkiw, cudb, 
   {{0x1ea800b2,0x212e1c83,0xdb0c03cd,0x00000000}},	//   _پاڻي_, ngeh_, dobå, --, 
   {{0x637c0066,0x25bc0175,0x7984002e,0xdca4010a}},	// [3de60] _yènt, dowl_, rkiw, _хапи, 
   {{0x79861c84,0x637c004e,0x47c206cd,0x212c0c6a}},	//   skiw, _mèns, ебув, hgeh_, 
   {{0xc5e43ae9,0x25bc232c,0x637c04fb,0x21f13fdb}},	//   _སྤྱི, fowl_, _lèns, _náh_, 
   {{0x63ac00c6,0x00000000,0x00000000,0x00000000}},	//   éann, --, --, --, 
   {{0x14b8007b,0x93600022,0x00000000,0x00000000}},	//   حداث_, нҭаҧ, --, --, 
   {{0xcc3800c8,0x2d9807ea,0x00000000,0x00000000}},	//   מענט, érez_, --, --, 
   {{0x637c2a4a,0xa2b01b61,0xed6000bc,0xc3080154}},	//   _rènt, _अखण्, ížky_, _রাশি_, 
   {{0xc5e4081f,0x637c0066,0x6e2839c3,0xefe80240}},	//   _སྤྲི, _bèns, vudb, _መለይ_, 
   {{0x7df0054e,0xcee8006c,0x8de402dd,0x00000000}},	//   _răsa, یرگن_, _ﺍﻟﺘﻁ, --, 
   {{0x4f680b7e,0xd7bc041c,0x6e2801bf,0x00000000}},	//   сшим_, ्तिच, tudb, --, 
   {{0x7df00356,0x910401a9,0x6e9400b1,0x00000000}},	//   _păsa, _ечлд, фину, --, 
   {{0x6e2872ab,0x00000000,0x00000000,0x00000000}},	//   rudb, --, --, --, 
   {{0x6e2a1c85,0x637c0066,0xd7bc28e0,0xe7f01414}},	//   sudb, _tènt, ्ताच, _अंधा_, 
   {{0x7d000790,0x25bc0076,0xce68011c,0x00000000}},	//   ımsa, zowl_, _грид_, --, 
   {{0xa9340108,0x2df401a9,0x00000000,0x00000000}},	//   мевш, _ўзиё, --, --, 
   {{0xc984022e,0x00000000,0x00000000,0x00000000}},	//   чуги, --, --, --, 
   {{0x87040150,0xabb400c7,0x00000000,0x00000000}},	// [3de70] كبال, _ҭақә, --, --, 
   {{0xc668005b,0x466812b9,0xa020008e,0x6f1c00ae}},	//   йшее_, йрем_, _şöke, órch, 
   {{0x1cd8031c,0x00000000,0x00000000,0x00000000}},	//   _འཛོ_, --, --, --, 
   {{0x04b00145,0x00000000,0x00000000,0x00000000}},	//   ىلاڭ, --, --, --, 
   {{0x63ac25e6,0x9f58036e,0x87040024,0x00000000}},	//   éano, ësë_, _няве, --, 
   {{0x97000075,0xbcf001e4,0xed6406be,0x4810030d}},	//   _لېكى, _maɩa, _şölə_, ăмĕс, 
   {{0x637c0214,0xd24c004b,0xc8800139,0xf1a801e2}},	//   _sèns, لنو_, biğí_, ګاوه_, 
   {{0x26d0011c,0x637c020c,0xb5a61c86,0x27e400d0}},	//   _izzo_, _pèns, _зруй, _člny_, 
   {{0x34941fdf,0x656a1c87,0x26d03a4a,0xf4840276}},	//   _затр, _ineh, _hzzo_, _пуфн, 
   {{0x65b8013d,0x160801f9,0x00000000,0x00000000}},	//   _dähş, हीवर_, --, --, 
   {{0x656803cd,0x00000000,0x00000000,0x00000000}},	//   _kneh, --, --, --, 
   {{0xdca61c88,0x65680327,0x00000000,0x00000000}},	//   дами, _jneh, --, --, 
   {{0x5f7405d4,0x656829b3,0x00000000,0x00000000}},	//   _ياتر, _mneh, --, --, 
   {{0x7de40066,0x2b400142,0xfcf80092,0xe1b801f7}},	//   gèsè, _cbhc_, _ጉራጌ_, _اَچڻ_, 
   {{0x656a1c89,0x9e940137,0xb51001ad,0x00000000}},	//   _oneh, _تاشچ, ारमय_, --, 
   {{0xb33c025c,0x00000000,0x00000000,0x00000000}},	//   _imħe, --, --, --, 
   {{0x38c89a87,0x26d21c8a,0xdb140162,0x00000000}},	// [3de80] ساری_, _azzo_, úbót, --, 
   {{0x656a1c8b,0x00000000,0x00000000,0x00000000}},	//   _aneh, --, --, --, 
   {{0x9b600075,0x6f1c0120,0x7df0054e,0x99d4007b}},	//   _كۆڭۈ, órci, _măso, _يتجا, 
   {{0x18680902,0xe6b4036b,0xa2b0012d,0x00000000}},	//   _дами_, رلنگ, _अख़्, --, 
   {{0xdb0c00d0,0xe63401c6,0x6fd00210,0x00000000}},	//   dobú, _үхсэ, हतमं, --, 
   {{0x65680b6f,0xb33c0327,0x96b800f3,0x00000000}},	//   _eneh, _omħe, _дубу_, --, 
   {{0x670005f5,0xc7b0011a,0x00000000,0x00000000}},	//   _сүхб, _יבש_, --, --, 
   {{0xc56001d5,0x136400ec,0x00000000,0x00000000}},	//   _икск, _ڪارٽ, --, --, 
   {{0x777c006c,0xcf242088,0x00000000,0x00000000}},	//   _korx, وردي, --, --, 
   {{0xa0342e51,0x656802fb,0x7bdc0200,0x00000000}},	//   رىپت, _zneh, jmru, --, 
   {{0x1cd8031c,0xd7a401ad,0x00000000,0x00000000}},	//   _འཛུ_, _गगनच, --, --, 
   {{0x7de8033b,0x701c00b8,0x00000000,0x00000000}},	//   vèsè, _ṅkuś, --, --, 
   {{0x3d940075,0xd1dc0023,0x00000000,0x00000000}},	//   тияр, _ሓለቓ_, --, --, 
   {{0xcf2414a5,0xe8d801f2,0x777c022e,0xcf4002dd}},	//   _آرشي, nkụ_, _norx, _شىعۋ, 
   {{0xaa942ec5,0x00000000,0x00000000,0x00000000}},	//   хивч, --, --, --, 
   {{0x26d0009b,0x7df00311,0x47f00131,0x00000000}},	//   _rzzo_, _măsl, күмр, --, 
   {{0x0ae81564,0x777c02d3,0x2e3a0372,0x00000000}},	// [3de90] _وردي_, _borx, léf_, --, 
   {{0x656a1c8c,0x00000000,0x00000000,0x00000000}},	//   _sneh, --, --, --, 
   {{0xbcf001e4,0x160801ad,0x2e3800e8,0x6db800df}},	//   _maɩn, हीलर_, néf_, rĉaf, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x777c056a,0x320c010e,0x38ca1c8d,0x28b400df}},	//   _forx, _awdy_, _журн_, _נפֿש_, 
   {{0x777c01cb,0x6db801e4,0x224402f0,0x00000000}},	//   _gorx, lĉad, _pplk_, --, 
   {{0xdb0d7628,0x65961c8e,0x248a1c8f,0x65684fa3}},	//   tobú, _заву, šam_, _tneh, 
   {{0x656a1c90,0x2e380085,0x36d41def,0x6db800df}},	//   _uneh, déf_, _роср, nĉad, 
   {{0x201800dd,0x99a40327,0x00000000,0x00000000}},	//   ési_, _ġużi_, --, --, 
   {{0xdb1001d3,0xdb0c01e3,0x00000000,0x00000000}},	//   égük, llbö, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb0803c6,0xdbc806be,0xcf4400db,0x00000000}},	//   čník, _kеçi, _ۋىنۋ, --, 
   {{0xc0a800cf,0x0d800815,0xa068b6d4,0x00000000}},	//   _باال_, улян, _хала_, --, 
   {{0xbe8008ca,0x00000000,0x00000000,0x00000000}},	//   _ақои, --, --, --, 
   {{0xd9461c91,0x1a646112,0x6b800008,0xfeb8030f}},	//   неви, ریحی_, ölga, _باشت_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x1cd80135,0x777c00cf,0x00000000,0x00000000}},	// [3dea0] _འཛི_, _porx, --, --, 
   {{0x777c03be,0xb8e800ab,0x00000000,0x00000000}},	//   _qorx, _ऊँ_, --, --, 
   {{0x779401d9,0x00000000,0x00000000,0x00000000}},	//   _ییرا, --, --, --, 
   {{0x07a000fb,0x00000000,0x00000000,0x00000000}},	//   _ҡаян, --, --, --, 
   {{0xf4c02158,0x777c00db,0x3940002e,0x5fb0013a}},	//   েশ্ব, _torx, mfis_, ीकाल, 
   {{0xded00023,0x3860003a,0x7e6003ac,0x39421c92}},	//   ኩላን_, mvir_, _ornp, lfis_, 
   {{0x00c81c5c,0x60e403be,0x3940022f,0xe63401c0}},	//   ﻗﯩﺘﺘ, ərmə, ofis_, _ихтэ, 
   {{0xf51800ec,0x463800df,0x00000000,0x00000000}},	//   _آڪاش_, _מעלע, --, --, 
   {{0xcfa4d77e,0x39400ba7,0x77440092,0x00000000}},	//   ешни, ifis_, _ከማስተ, --, 
   {{0xbcf001e4,0x0fcc0eac,0x386004d4,0x76480142}},	//   _baɩo, রদ্ধ, ivir_, _âdys, 
   {{0x6d8c002d,0x3940017a,0x91e000fb,0x00000000}},	//   _dûan, kfis_, _йәиһ, --, 
   {{0xac185e3e,0x6fd4026c,0x57bc012c,0x2e3801a8}},	//   мому_, fàcc, ्तुह, réf_, 
   {{0xef5400c7,0xc0c400f3,0x00000000,0x00000000}},	//   _акль, _пуше_, --, --, 
   {{0x63a00408,0x7e600175,0xbdf40244,0x00000000}},	//   _xmln, _frnp, بریا_, --, 
   {{0x2d991fb4,0x16400092,0x00000000,0x00000000}},	//   ères_, _ከፋብሪ, --, --, 
   {{0x79a400d8,0x00000000,0x00000000,0x00000000}},	//   груе, --, --, --, 
   {{0x3860022c,0x1cd8025c,0x6db8008f,0x6d5c02d0}},	// [3deb0] gvir_, _འཛག_, rĉad, mdsa, 
   {{0x39400ba7,0x6e28017a,0x4cd400cc,0x00000000}},	//   afis_, ordb, _ধলপু, --, 
   {{0xf7703e43,0x6d5c03ac,0x25780022,0xaa94009d}},	//   حاق_, odsa, мбжь_, _ринч, 
   {{0x6d5e1c93,0xe8d801f2,0x85c402ef,0xc6100154}},	//   ndsa, ndị_, رغام, াংলা_, 
   {{0x6d5c0b1e,0x290a1c94,0x69cd2851,0xdb0c01bf}},	//   idsa, mbaa_, mlae, tobø, 
   {{0x69ce1c95,0x2efe1c96,0x290a1c97,0xd465baa5}},	//   llae, _nfvf_, lbaa_, тише_, 
   {{0x69cc00a9,0x29080449,0xf6280212,0x36d4014b}},	//   olae, obaa_, _піти_, _борр, 
   {{0x29086243,0x69ce1c98,0x85b801d9,0x6d5df459}},	//   nbaa_, nlae, _رازس_, jdsa, 
   {{0xd00c005e,0x290a1c99,0x6e28017a,0x6d5c143a}},	//   ەلۋ_, ibaa_, erdb, ddsa, 
   {{0x442c0694,0x644801af,0x6d5e1c9a,0x69cc0097}},	//   mug_, _ipei, edsa, hlae, 
   {{0x442e1c9b,0x69cc0399,0x68fc05ac,0xd378008f}},	//   lug_, klae, _ofsd, _קרעט, 
   {{0xb33c003d,0x69cc0369,0x386006ea,0xe46801e1}},	//   _imħa, jlae, yvir_, _àkó̟, 
   {{0x442e1c9c,0x69cc0cfd,0x1fb41d1c,0x557400c8}},	//   nug_, dlae, _искр, דערן_, 
   {{0x29080a63,0x6d5c058a,0x442c01ab,0x69cc9092}},	//   ebaa_, adsa, iug_, elae, 
   {{0x442e1c9d,0x2908058a,0x98f4005b,0xa2d4078a}},	//   hug_, fbaa_, вязч, येच्, 
   {{0x78040598,0x644a1c9e,0x69cc0007,0x39421c9f}},	//   лүма, _opei, glae, ufis_, 
   {{0x09e21ca0,0x442e1ca1,0x39421ca2,0x57e8da96}},	// [3dec0] ротн, jug_, rfis_, ддам_, 
   {{0x442e1ca3,0x2908198f,0x4294001f,0x39421ca4}},	//   dug_, abaa_, ጅመንት_, sfis_, 
   {{0x290822a9,0x69cc0007,0x38621ca5,0x9f4c0407}},	//   bbaa_, blae, svir_, lpeó_, 
   {{0x442cec9d,0x8ab40375,0x201c016d,0x644801e7}},	//   fug_, _יהיו_, _ovwi_, _bpei, 
   {{0x64480005,0xa3cc01bc,0x442d8a02,0x00000000}},	//   _cpei, रतं_, gug_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x201c016d,0x823000c6,0x64480393,0x6fd40268}},	//   _avwi_, لريا, _epei, jàca, 
   {{0x442e1ca6,0x200000b0,0x45300131,0xd5480066}},	//   bug_, _ōhia_, _پىكر, _تجسم_, 
   {{0x27ec01c7,0x442d6008,0x00000000,0x00000000}},	//   _éent_, cug_, --, --, 
   {{0xd3461ca7,0xa3cc00dc,0x69cc0007,0x00000000}},	//   _شیعه_, रतः_, zlae, --, 
   {{0x6448005a,0x7afc1710,0x29080067,0x00000000}},	//   _zpei, dcrt, ybaa_, --, 
   {{0x80a08a41,0x69cc0369,0x6d5e1ca8,0xd1840148}},	//   امین, xlae, udsa, _шлей, 
   {{0x2018038e,0x3b1801b9,0xfd44009d,0x00000000}},	//   ásit_, farq_, шээн, --, 
   {{0x7de80241,0x29080009,0x6d5c02d0,0xaed4010a}},	//   _pèsì, wbaa_, sdsa, _йолш, 
   {{0x442c0730,0x290a1ca9,0x69ce1caa,0x63ac73a0}},	//   zug_, tbaa_, tlae, éani, 
   {{0x69cc030a,0x442da0ef,0xdcf4002b,0x00000000}},	//   ulae, yug_, _toyā, --, 
   {{0x98a00cc1,0x29086a03,0x69ce1cab,0x442c1bce}},	// [3ded0] _bakı_, rbaa_, rlae, xug_, 
   {{0x69ce1cac,0xe4d40131,0x29080067,0x442e1cad}},	//   slae, ۇقاد, sbaa_, vug_, 
   {{0x644a1cae,0xd0051f04,0x98a00213,0x69cd2b89}},	//   _spei, _گل_, _dakı_, plae, 
   {{0x442e1caf,0x69cc0007,0x2908058a,0x2b50012d}},	//   tug_, qlae, qbaa_, lezc_, 
   {{0xd004943c,0xef1800da,0xa3491ea9,0xb8d803d4}},	//   _دل_, kaļ_, езла_, _ছৰ_, 
   {{0x954000ac,0xe8d8063f,0xf56804b4,0x47840150}},	//   əşmə, ndọ_, ешәк_, _рымб, 
   {{0x442e1cb0,0x05b8413a,0x21a401d5,0x85b80244}},	//   sug_, _قدرت_, ликм, _قارس_, 
   {{0x442e100f,0xdb0c02fb,0x00000000,0x00000000}},	//   pug_, dobý, --, --, 
   {{0x64480588,0x11440b7e,0xded0001f,0x442c002e}},	//   _upei, упый_, ኩዋን_, qug_, 
   {{0xbe801f71,0x2d9a1cb1,0x02a45409,0x66f401ad}},	//   иқли, ëren_, _ирем, ेडिक_, 
   {{0x222803e6,0xa3000032,0xc10002dd,0x27e001c3}},	//   _سزای_, _күҙе, _күйл, imhn_, 
   {{0xd00c0608,0x20b8005b,0x6fd408c2,0x48ec000d}},	//   _کلو_, _пыль_, ràca, _अलगो_, 
   {{0x7afc05be,0xc68c0092,0x3034014b,0x00000000}},	//   tcrt, _መኩሪያ_, _вечё, --, 
   {{0xff0400f5,0x00000000,0x00000000,0x00000000}},	//   _рядн, --, --, --, 
   {{0x3ab40075,0x98a00790,0xaae4009a,0x00000000}},	//   рәпт, _rakı_, لسفو, --, 
   {{0xdb0c01b8,0x9b040131,0x69940500,0x00000000}},	//   lobü, _өзид, арух, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3dee0] --, --, --, --, 
   {{0xb8cc00af,0xd7c831b1,0x00000000,0x00000000}},	//   _कइ_, رواه_, --, --, 
   {{0x99d40736,0x7df0054e,0x62842d8b,0x41c009b2}},	//   _متحا, _băsi, øhol, शवास, 
   {{0x321c00b5,0x00000000,0x00000000,0x00000000}},	//   vsvy_, --, --, --, 
   {{0xd875ece5,0x98a005d1,0xc3080154,0x2874004e}},	//   _صاحب, _takı_, _রাজি_, _кырр, 
   {{0x93252221,0xd259363d,0xdb0c033f,0xd824007f}},	//   ارشن, еци_, mobó, ryٍd_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7df0084c,0x00000000,0x00000000,0x00000000}},	//   _găsi, --, --, --, 
   {{0xf8b40034,0xdb0c0254,0x00000000,0x00000000}},	//   ंपिय, fobü, --, --, 
   {{0x71740722,0xb33c031c,0xc4800137,0x638000c7}},	//   اهکا, _imħo, _улук, _ҳҳәа, 
   {{0x3f621cb2,0x82280327,0x2b5005c7,0x479800d9}},	//   стыб, སྤྱི_, vezc_, גייס, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xaca40521,0x4fc40064,0x00000000,0x00000000}},	//   knụz, _йска, --, --, 
   {{0xdb0cb2fe,0x7f5401ee,0x00000000,0x00000000}},	//   dobó, _башс_, --, --, 
   {{0xe91800d6,0x00000000,0x00000000,0x00000000}},	//   кові_, --, --, --, 
   {{0xfe6c1b06,0x687c02d3,0x50280092,0x00000000}},	//   _ردى_, _ከመይሲ_, _ተነሳሽ, --, 
   {{0x2d980597,0x3d340150,0xebd83be4,0xa9a4010b}},	// [3def0] mhse_, _اعىس, _идиш_, гиңд, 
   {{0x442001e4,0x994c022a,0x00000000,0x00000000}},	//   _ĉj_, _výš_, --, --, 
   {{0xb8cc6398,0x5b140032,0x00000000,0x00000000}},	//   _के_, _өмөт, --, --, 
   {{0x954000ac,0x65940120,0x19e400d1,0x00000000}},	//   əşkə, јаду, _ﺋﺎﻳﻠ, --, 
   {{0x0ae80fa2,0x1cd80327,0x55501888,0x00000000}},	//   _ترکي_, _འཛབ_, زپور, --, 
   {{0xe2846cc7,0x2d9801ab,0xba740133,0xe79401af}},	//   илли, hhse_, _ئایت, _тигњ, 
   {{0x2d980009,0x00000000,0x00000000,0x00000000}},	//   khse_, --, --, --, 
   {{0x6024b15a,0x00000000,0x00000000,0x00000000}},	//   адиа, --, --, --, 
   {{0x1fb4016c,0x0044004b,0x2d9801e7,0xdb0c002f}},	//   исор, ایتي_, dhse_, tobü, 
   {{0x69dc0175,0x3afc01e1,0x00000000,0x00000000}},	//   _lhse, _màpó_, --, --, 
   {{0x69dc0194,0x1d080137,0x026801d5,0x00000000}},	//   _ohse, кени_, _яшай_, --, 
   {{0x1cd80135,0x9ec400f1,0xa3cc05dc,0x00000000}},	//   _འཛད_, هېږم_, रतक_, --, 
   {{0xefc40023,0x00000000,0x00000000,0x00000000}},	//   _ኸለዉ_, --, --, --, 
   {{0x69dc5244,0x1ec8030d,0x00000000,0x00000000}},	//   _ahse, _илли_, --, --, 
   {{0x2d987ea6,0x63ac01e4,0x00000000,0x00000000}},	//   bhse_, ɩant, --, --, 
   {{0x2d98c08d,0x443c022e,0x81c000cc,0x00000000}},	//   chse_, _oqu_, _এওঁ_, --, 
   {{0x443c923b,0xccb0013d,0xbb280014,0x00000000}},	// [3df00] _nqu_, _дәрь, _یتھے_, --, 
   {{0xdb0c033f,0x6db800df,0x2c00009d,0xac04009f}},	//   robó, nĉan, _хүрм, _اذيو, 
   {{0x443d953b,0xd9444235,0xdb0c033f,0x00000000}},	//   _aqu_, _кени, sobó, --, 
   {{0x998400db,0x1544167f,0x00000000,0x00000000}},	//   _ئلحو, редм, --, --, 
   {{0x443c0113,0x11d404fb,0x660995fe,0xb4c000bc}},	//   _cqu_, یتعد, _čeke, ँथे_, 
   {{0x46400014,0x52240022,0x95b40124,0x00000000}},	//   _ژھنِ, афиа, ырҕә, --, 
   {{0x443c0327,0x0cd0012c,0x00000000,0x00000000}},	//   _equ_, _सर्म, --, --, 
   {{0x443c0113,0x6fd400db,0x765e1cb3,0xc4802abf}},	//   _fqu_, tàco, _isry, сләк, 
   {{0x7df0084c,0x29040213,0x326401ed,0x2d980036}},	//   _măsu, _əla_, _گناہ, ërem_, 
   {{0x63ac0597,0xeaf40073,0xceb400d1,0x00000000}},	//   éant, _आलेत_, һәқ_, --, 
   {{0x2d980240,0xdb0c0100,0x3fd4009d,0x00000000}},	//   thse_, yobò, рмээ_, --, 
   {{0xceb40116,0xaed402dd,0x00000000,0x00000000}},	//   ләқ_, _қойш, --, --, 
   {{0xc3080183,0x7c8402e8,0x00000000,0x00000000}},	//   _ৰাতি_, оуре, --, --, 
   {{0x94f4038f,0xefe8069c,0x637c00f2,0x00000000}},	//   _བུའི_, _መገዲ_, _bèny, --, 
   {{0xc0f4001f,0xc4d00b4c,0xba7414af,0x00000000}},	//   ፈጸም_, _तर्ख, يافت, --, 
   {{0x637c0d29,0x6f180455,0x7df00311,0xb510190e}},	//   _dèny, _hevc, _căsu, ारोप_, 
   {{0x6f1801d4,0x765c0432,0xed5800d7,0x00000000}},	// [3df10] _kevc, _asry, ôžu_, --, 
   {{0xe7180491,0x18280ec9,0x6f180010,0x451000cc}},	//   ايات_, اقلی_, _jevc, _হাইক_, 
   {{0x6f180365,0x23281171,0x00000000,0x00000000}},	//   _mevc, ҳоли_, --, --, 
   {{0x6f180010,0x00000000,0x00000000,0x00000000}},	//   _levc, --, --, --, 
   {{0x232800f3,0x79580166,0xb9a80139,0xf96402f2}},	//   голи_, _тияр_, _тәрҗ_, _بۆقێ, 
   {{0x291a1cb4,0xb3c80826,0x67e80010,0x00000000}},	//   _hesa_, аліз_, _ožji, --, 
   {{0x2918079b,0xe6940597,0x6b84014f,0x27f80718}},	//   _kesa_, _الأد, _mohg, _husn_, 
   {{0x291a1cb5,0x78b805a1,0xb5a40153,0x00000000}},	//   _jesa_, šavš, _друй, --, 
   {{0x443c8e5b,0x63ac0005,0x6f18005c,0x7988002d}},	//   _uqu_, éans, _bevc, êdwi, 
   {{0x291a1cb6,0x3f8009f3,0x6f1800f3,0x442c01fa}},	//   _lesa_, ðju_, _cevc, mrg_, 
   {{0xd3e4806b,0xa2d61cb7,0x7df00311,0xa11400c6}},	//   _اقلی, _ايات, _năst, _هوات, 
   {{0x291a1cb8,0x442e1cb9,0x6458022f,0x00000000}},	//   _nesa_, org_, owwi, --, 
   {{0x51580302,0x200803a2,0x7df00311,0x442c01ab}},	//   _תכנו, _ïai_, _răsu, nrg_, 
   {{0xc0f41e38,0x291a1cba,0x9e580120,0x442e11e1}},	//   ፈጸመ_, _aesa_, _бриф_, irg_, 
   {{0x291a1cbb,0xfe74021f,0x00000000,0x00000000}},	//   _besa_, _түн_, --, --, 
   {{0x291825e6,0x442ddef7,0x76fc03d4,0x6f180205}},	//   _cesa_, krg_, ইৰাছ_, _zevc, 
   {{0x7d061cbc,0x27f21cbd,0x48e0509d,0x98740063}},	// [3df20] _ifis, _bizn_, зотв, љубљ, 
   {{0x6b840007,0x29180e14,0x7c2421b5,0x2bc80490}},	//   _gohg, _eesa_, _ivir, ळवणा, 
   {{0x442c0a40,0x291a1cbe,0x26d000b5,0x7c24af73}},	//   erg_, _fesa_, _cyzo_, _hvir, 
   {{0x4a58025f,0x2918207a,0x7d040003,0x7c240162}},	//   _עדכו, _gesa_, _jfis, _kvir, 
   {{0xfe640502,0x7d061cbf,0x00000000,0x00000000}},	//   _کد_, _mfis, --, --, 
   {{0x7c2482f6,0x29185745,0x7d0400e4,0xd794007b}},	//   _mvir, _zesa_, _lfis, _السخ, 
   {{0x442e1cc0,0x6458011f,0x2918022e,0x63ac01c3}},	//   arg_, awwi, _yesa_, èana, 
   {{0x7c24151c,0x27f40428,0x7d040135,0x6f180205}},	//   _ovir, _òanò_, _nfis, _sevc, 
   {{0x7c241529,0x6f1809a8,0x00000000,0x00000000}},	//   _nvir, _pevc, --, --, 
   {{0x7d061cc1,0x0320010b,0x2f1402d5,0x04400798}},	//   _afis, _ндун, ўднё, _хефн, 
   {{0x7c261cc2,0xdcec00dc,0x00000000,0x00000000}},	//   _avir, _ākār, --, --, 
   {{0x7d041529,0x7c24e4a3,0xc690008f,0x7df00276}},	//   _cfis, _bvir, פאר_, _răst, 
   {{0x291a1cc3,0x01600014,0x0ca807b5,0x50d46e0d}},	//   _resa_, _رُوَ, утни_, _ازار, 
   {{0x291a1cc4,0x7d061cc5,0x7c261cc6,0x7df0084c}},	//   _sesa_, _efis, _dvir, _păst, 
   {{0x291a1cc7,0x6db800c8,0x47888d51,0xaa580868}},	//   _pesa_, lĉam, қсам_, шиву_, 
   {{0x29180a73,0xa81402e8,0x00000000,0x00000000}},	//   _qesa_, ждаш, --, --, 
   {{0x291a1cc8,0x6d4e1cc9,0x6db80115,0x26d000d7}},	// [3df30] _vesa_, _ibaa, nĉam, _syzo_, 
   {{0x2918014b,0x00000000,0x00000000,0x00000000}},	//   _wesa_, --, --, --, 
   {{0x291a1cca,0x7c241cbd,0x4668b5ff,0x28d400e1}},	//   _tesa_, _zvir, ырам_, _दरकि, 
   {{0x7c241125,0x442c0334,0x00000000,0x00000000}},	//   _yvir, trg_, --, --, 
   {{0x442e1ccb,0x6d4d2ddd,0x7c24003a,0x645801f5}},	//   urg_, _mbaa, _xvir, uwwi, 
   {{0x970004a9,0x6db801e4,0x7af0010e,0x00000000}},	//   _يېقى, dĉam, _ýitý, --, 
   {{0x6d4c74e0,0x65961ccc,0xdb0c03b2,0x00000000}},	//   _obaa, _даву, nnbá, --, 
   {{0x6d4c01e1,0xa1880022,0x00000000,0x00000000}},	//   _nbaa, рбиа_, --, --, 
   {{0xdb0c0793,0x7d040076,0x6ab401bc,0x27700092}},	//   mobö, _rfis, ःपुर, _ለማስጠ, 
   {{0x6d4e1ccd,0xd00cf6c4,0x7d061cce,0x5e48050b}},	//   _abaa, کلی_, _sfis, апом_, 
   {{0x7c241326,0x7d061ccf,0x6d4c0a49,0x2258009f}},	//   _svir, _pfis, _bbaa, _خلاد_, 
   {{0xdb0c01b8,0x6db801e4,0x6fd401ab,0x00000000}},	//   nobö, lĉaj, hàch, --, 
   {{0x399c01e1,0x0d800153,0x00000000,0x00000000}},	//   _jíse_, флян, --, --, 
   {{0x200e1cd0,0x6d4e1cd1,0x26f401ad,0x6ab40a59}},	//   mpei_, _ebaa, ेडोर_, ःपूर, 
   {{0x9d448a5b,0x7d04003d,0x6ee40132,0x1d0801d5}},	//   _дейд, _tfis, _ىسىل, _кейи_, 
   {{0x7d061cd2,0x7c2402d5,0x6d4c27dd,0x3f861cd3}},	//   _ufis, _tvir, _gbaa, _honu_, 
   {{0x3f861cd4,0x7c261cd5,0x178465cb,0x200c037e}},	// [3df40] _konu_, _uvir, огам, npei_, 
   {{0xdaa807d8,0x200d5db3,0x3f861cd6,0x00000000}},	//   _ввод_, ipei_, _jonu_, --, 
   {{0x3f841132,0xd1dc02d3,0x6db801e4,0xa2a80bae}},	//   _monu_, _ዓገብ_, zĉam, _झेल्, 
   {{0x3f856ab6,0x1dc806ff,0x00000000,0x00000000}},	//   _lonu_, रवित, --, --, 
   {{0xd7c80214,0x53e51828,0x3f84058a,0x2d980036}},	//   _نوحه_, оцка, _oonu_, ërei_, 
   {{0xb9e81540,0x3f861cd7,0xf78401c6,0x6db801e4}},	//   _ሮማ_, _nonu_, _эвгү, vĉam, 
   {{0x2d980383,0x1dc8041c,0x1a9800df,0x00000000}},	//   ūrei_, रवात, ייַע, --, 
   {{0x399c007b,0x33e00ba1,0x6fd4642b,0x3014010b}},	//   _físe_, dòxe_, màci, пдир, 
   {{0x3f8408e5,0x6fd4004e,0xf4843224,0x00000000}},	//   _bonu_, làci, _عاری, --, 
   {{0xe2f80489,0x3f8547dc,0xdb0c006a,0x9f440100}},	//   _ཕུརཔ_, _conu_, sibê, nmlè_, 
   {{0x3f861cd8,0x6db800df,0xd25000f2,0xa24410e8}},	//   _donu_, sĉam, _زنش_, _فیول_, 
   {{0xdb0e1cd9,0x00000000,0x00000000,0x00000000}},	//   libè, --, --, --, 
   {{0x3f8403c1,0xf0b001ed,0x6db801e4,0x63740cad}},	//   _fonu_, _سیدھ, lĉak, _ẹnik, 
   {{0x81dc009e,0xf41c00cc,0x00000000,0x00000000}},	//   _ধূপ_, _নমাৰ_, --, --, 
   {{0x6d4c002e,0xdb0c01d3,0x61ec01e4,0xc4b40073}},	//   _tbaa, ójáb, ʈalo, _आख्ख, 
   {{0x6d4c9ad5,0x6fd435f5,0x00000000,0x00000000}},	//   _ubaa, dàci, --, --, 
   {{0xdb0c014a,0x53c800dc,0x3f84002e,0x0ba8007b}},	// [3df50] vobö, ाकाश, _yonu_, _نادى_, 
   {{0xe9443821,0x4668e4ae,0x399c01e7,0x00000000}},	//   _کردی, ирем_, _ríse_, --, 
   {{0x2d8801e0,0x2b40009a,0xbd882be7,0x6fd400a3}},	//   _koae_, _ichc_, _طنین_, ràch, 
   {{0xbc683cc4,0x6d8c002d,0x200c003a,0x00000000}},	//   _امین_, _gûat, ypei_, --, 
   {{0x2d8806c8,0x79800086,0xa878010f,0xa3d41422}},	//   _moae_, _òmwa, _האָר, подч, 
   {{0x69cc00fb,0x6fd400db,0x221427a8,0xd7f8011a}},	//   loae, bàci, пфир, _להשל, 
   {{0x6fd40137,0x6db801e4,0x3f840ca8,0x249406be}},	//   càci, rĉaj, _ronu_, _şamı_, 
   {{0xd24ca534,0x3f861cda,0x057557a8,0x00000000}},	//   اني_, _sonu_, _باسد, --, 
   {{0x25ae1cdb,0x3f861cdc,0xe5a4010b,0xf1a81046}},	//   _imel_, _ponu_, _диңи, تاوه_, 
   {{0x249c6b8e,0x33580137,0xdb0c0200,0x00000000}},	//   ızmı_, _мүчө_, ribë, --, 
   {{0x200c1570,0x2d88013f,0x3f840333,0xde0400d1}},	//   spei_, _boae_, _vonu_, япни, 
   {{0x200c037e,0x3f84df8a,0x00000000,0x00000000}},	//   ppei_, _wonu_, --, --, 
   {{0x3f861cdd,0x61e80ff7,0x1cb8708e,0xdb0c004a}},	//   _tonu_, mmel, صاحب_, libé, 
   {{0x61ea1cde,0x2d88003a,0x660802f0,0x2b400051}},	//   lmel, _eoae_, _čekn, _cchc_, 
   {{0x61e827be,0x25ae1cdf,0x00000000,0x00000000}},	//   omel, _omel_, --, --, 
   {{0x9b442756,0x5cf61ce0,0x00000000,0x00000000}},	//   _کندو, _эяку, --, --, 
   {{0x61ea1ce1,0x96f80220,0xdb0c0129,0x00000000}},	// [3df60] imel, معار_, hibé, --, 
   {{0xd1dc069c,0x61ea1ce2,0x3ce00010,0xa2600051}},	//   _ዓወት_, hmel, _iziv_, _đông, 
   {{0x69c0004a,0x0a5002d3,0x9618007b,0x1aa800cc}},	//   élec, _ምፍርራ, صغار_, _খুৰা, 
   {{0x6f1c0034,0x6fd44b84,0x61e801f5,0x00000000}},	//   órcz, ràci, jmel, --, 
   {{0x938a1ce3,0x61ea1ce4,0x17f800c6,0xdb0c3b9d}},	//   йска_, dmel, _درجة_, rnbæ, 
   {{0x61e80a40,0x25ae1ce5,0xaee400b8,0x03a00815}},	//   emel, _emel_, _jeṣy, ничо, 
   {{0x236415ad,0x78a425b4,0x95840276,0xdb0c180f}},	//   _dalj_, lziv, _елве, ribè, 
   {{0x61ea1ce6,0x1aa803d4,0x00000000,0x00000000}},	//   gmel, _খুৱা, --, --, 
   {{0x7df40262,0x8c44013d,0x95380092,0xe3d40150}},	//   _răsp, _mağí, _የምናደ, _ﺘﻬﺩﻓ, 
   {{0x78a4006f,0x7984003e,0x6e94447e,0xaee400cd}},	//   iziv, hjiw, диоу, _neṣy, 
   {{0xfe2000fd,0xdb0c00d8,0x77a00166,0xa3c806e3}},	//   ньян, cibé, _töxf, ईवर_, 
   {{0x7984d988,0x11e400cf,0x61e800a2,0x00000000}},	//   jjiw, _эжем, cmel, --, 
   {{0x69cc056a,0x70540214,0x6ab400dc,0x00000000}},	//   voae, _آنتا, ःप्र, --, 
   {{0x78a40e8a,0xaee400b8,0x2a600175,0xb3dc00bc}},	//   dziv, _ceṣy, _pshb_, यतिख, 
   {{0x66080114,0xbef5aed1,0xfe6c1b45,0x20080240}},	//   _čeko, _عروض_, _مدي_, _çair_, 
   {{0xb33c025c,0xf1cc1d03,0xa84800e3,0xbb3400d1}},	//   _imħu, ाविन, يلزم_, ﺯﻧﻰ_, 
   {{0x0ca805ac,0x00000000,0x00000000,0x00000000}},	// [3df70] _গুৰত, --, --, --, 
   {{0x61ea1ce7,0xade0007d,0x25ae1ce8,0x00000000}},	//   zmel, _गीतन_, _smel_, --, 
   {{0xf1cc0a94,0x61e8722a,0x28f80276,0x78a40099}},	//   ावान, ymel, _мень_, aziv, 
   {{0xe94400e5,0x00000000,0x00000000,0x00000000}},	//   _کرگی, --, --, --, 
   {{0xc864fff7,0x320c0432,0x236401a6,0x25ac01e4}},	//   _этни, _atdy_, _palj_, _vmel_, 
   {{0xf41001d3,0x5ef000cd,0xd1dc0023,0x00000000}},	//   اؤن_, ुखम्_, _ዓወቱ_, --, 
   {{0x61ea1ce9,0x25ac0306,0x23640427,0x00000000}},	//   tmel, _tmel_, _valj_, --, 
   {{0x61ea1cea,0x600a1ceb,0xdb0d0baf,0xc0c80023}},	//   umel, оним_, ribé, _ኣመል_, 
   {{0x201a1cec,0x56540092,0xd5840133,0x229400ec}},	//   èsi_, _የጋዜጠ, _تێنه_, _ڪلاس, 
   {{0x74580050,0x399e1ced,0x7f600092,0x00000000}},	//   _عشقس_, _mísa_, ግሌዎች, --, 
   {{0xdb0c1445,0x61ea1cee,0x399c08a5,0x22940472}},	//   nnbå, pmel, _lísa_, _تلاس, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4c8006bb,0x91a801ed,0x00000000,0x00000000}},	//   вляв, _بننے_, --, --, 
   {{0x9fb40cc1,0x6d4001d3,0xf84801c6,0x00000000}},	//   dəçi_, őlap, үүнд_, --, 
   {{0x7984003c,0x00000000,0x00000000,0x00000000}},	//   tjiw, --, --, --, 
   {{0x77a0013d,0x8c44013d,0x00000000,0x00000000}},	//   _möxe, _qağí, --, --, 
   {{0x79847cba,0x78a49597,0xd79401b9,0x00000000}},	// [3df80] rjiw, uziv, ولرخ, --, 
   {{0x399c1d1d,0x00000000,0x00000000,0x00000000}},	//   _dísa_, --, --, --, 
   {{0x154407d8,0xdb0c01e6,0x78a401d3,0xdad000d1}},	//   деем, gnbå, sziv, _شەرھ, 
   {{0x33e0068c,0x6fd400cf,0x00000000,0x00000000}},	//   dòxa_, làct, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x39421cef,0x00000000,0x00000000,0x00000000}},	//   lgis_, --, --, --, 
   {{0x02403306,0xf6e8025c,0x386003cb,0x00000000}},	//   نَوَ, _འཛིང, lwir_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x39416490,0x38621cf0,0xcfa800c6,0xe43001d3}},	//   igis_, nwir_, قادم_, _مہند, 
   {{0x75221cf1,0x1cac0327,0x0fcc03d4,0x00000000}},	//   _hemz, ནཌན_, ৰদ্ধ, --, 
   {{0x6fd40137,0x6db40c98,0x07340375,0xb640105c}},	//   dàct, ейну, ואים_, _ｃｆ_, 
   {{0x638007dd,0x273401e1,0x7bc00129,0xe4f400c5}},	//   _аҳәа, _kùnà_, émun, ुँचि_, 
   {{0x50e03174,0x752000df,0x814019bc,0x39400175}},	//   _परिष, _memz, _شنون, dgis_, 
   {{0x38621cf2,0x39421cf3,0x75221cf4,0x7f400051}},	//   dwir_, egis_, _lemz, _gcnq, 
   {{0xb90c01f2,0x399c01e1,0x00000000,0x00000000}},	//   _ọbịb, _sísa_, --, --, 
   {{0x75221cf5,0x39421cf6,0x6fd40268,0x38600327}},	//   _nemz, ggis_, ràcu, fwir_, 
   {{0xac9801d9,0x38600dd4,0x2d9800e2,0xdb0c00d0}},	// [3df90] _رندا_, gwir_, ūres_, škár, 
   {{0x399c2880,0x62840037,0x9fb40213,0x39400037}},	//   _vísa_, ähok, rəçi_, agis_, 
   {{0x9f5c00f2,0xa5354e66,0x7520030a,0x39400194}},	//   _duwè_, енеч, _bemz, bgis_, 
   {{0x38621cf7,0x2d98251e,0x75200789,0xd6c401d5}},	//   bwir_, nkse_, _cemz, رمنی, 
   {{0x19c00131,0x75200112,0x00000000,0x00000000}},	//   _сәрг, _demz, --, --, 
   {{0x6d5e1cf8,0x67d40228,0x29080841,0xa2e61cf9}},	//   hesa, _чогу, lcaa_, нолд, 
   {{0x6d5e1cfa,0x77a80014,0xd24caeb4,0x2908011f}},	//   kesa, _تێلہ_, منو_, ocaa_, 
   {{0x6d5ce956,0x2d980cf9,0x55607a32,0x672402f6}},	//   jesa, jkse_, _مۇمك, lahj, 
   {{0x6d5e1cfb,0xb2b40014,0xd5640023,0x00000000}},	//   desa, _ییٖژ, _ተምሃሮ_, --, 
   {{0x65691339,0x2d982595,0x9f5c0066,0x1e861cfc}},	//   _haeh, ekse_, _kuwé_, елом, 
   {{0x65681442,0x9d461cfd,0x75202959,0x68fc0857}},	//   _kaeh, ненд, _yemz, _ogsd, 
   {{0x656a1cfe,0x38600368,0x563400df,0x00000000}},	//   _jaeh, ywir_, עארע_, --, 
   {{0x656a1cff,0x672400af,0x9f5c0066,0x399c032e}},	//   _maeh, kahj, _luwé_, _bísn_, 
   {{0x2d9a1d00,0x656801ab,0x6724014f,0xdb0c0142}},	//   akse_, _laeh, jahj, ribï, 
   {{0x8f9825f9,0x6d5e1d01,0x6fd40228,0x34dc0fc8}},	//   _מיסי, besa, ràct, _बर्द, 
   {{0x6d5e1d02,0x6568002f,0x67240254,0x39400862}},	//   cesa, _naeh, eahj, ugis_, 
   {{0x75221d03,0x0f2003d4,0x38c804fb,0x61f8014f}},	// [3dfa0] _remz, _মাতৃ_, ذاری_, _miwl, 
   {{0x67240ffb,0x39421d04,0x29080009,0x31bc0303}},	//   gahj, sgis_, acaa_, _ऋद्ध, 
   {{0x38621d05,0x394002bf,0x75221d06,0x29080009}},	//   swir_, pgis_, _pemz, bcaa_, 
   {{0x290a1d07,0x9f5c0502,0x94261d08,0x25a8004b}},	//   ccaa_, _duwé_, емде, ودني_, 
   {{0x65680007,0x6db80115,0x7bdc00a3,0xdb0e1d09}},	//   _daeh, mĉat, olru, hibí, 
   {{0xceb80198,0x752000d2,0xd628223e,0x81401870}},	//   _leƙa_, _wemz, _ноге_, ۇنىن, 
   {{0x6d5e1d0a,0x75221d0b,0x438007a7,0x2d986df9}},	//   yesa, _temz, الىق, ykse_, 
   {{0x86b00046,0xdcf4007f,0x244801a8,0x6db801e4}},	//   _сәуі, _anyč, búm_, nĉat, 
   {{0x61f87cf8,0x6d5d88b4,0xd6e000eb,0x00000000}},	//   _diwl, vesa, _বলিয, --, 
   {{0x6d5e1d0c,0x6e983cf2,0x6568002f,0xdcf403e3}},	//   wesa, двор_, _zaeh, _soyğ, 
   {{0x7054034c,0x1bf801ad,0x1b2403d4,0xa2801176}},	//   رنگا, _एंजल_, বলাই_, _نیوو, 
   {{0x7bdc01a4,0x10a4c959,0xdcf40166,0x6f0803ac}},	//   elru, _пиен, _qoyğ, scdc, 
   {{0x2d9a1d0d,0x00000000,0x00000000,0x00000000}},	//   rkse_, --, --, --, 
   {{0xcf240597,0xc4d0011a,0x2d98000d,0x00000000}},	//   _أرشي, רגש_, skse_, --, 
   {{0x6d5cecee,0xdb0c6bdf,0xbb6400b5,0xc0dc001f}},	//   pesa, cibí, _bopオ_, ነዋል_, 
   {{0x2dc80132,0x6724020c,0x29080009,0x62840108}},	//   _تاتۋ_, wahj, ucaa_, ähoi, 
   {{0x9f5c04fb,0x67261d0e,0x65684c48,0x00000000}},	// [3dfb0] _suwé_, tahj, _raeh, --, 
   {{0x65680097,0x29080204,0xd1242586,0x39e401e0}},	//   _saeh, scaa_, _ھم_, _ҡәтғ, 
   {{0xac983520,0xe3b040ec,0x67261d0f,0x656a1d10}},	//   _رنگا_, یرت_, rahj, _paeh, 
   {{0x5a140a1e,0x3634004b,0x68fc0857,0x67240254}},	//   _שקרן_, ارلس, _ugsd, sahj, 
   {{0x34080131,0x84e800e1,0x6db800df,0xd0041622}},	//   ۈزۈپ_, जेंट_, lĉas, _خل_, 
   {{0x656a1d11,0x24480436,0x61f802d1,0xdd0000d0}},	//   _waeh, rúm_, _siwl, _čučo, 
   {{0x656a1d12,0x6db80115,0xb6680b01,0x00000000}},	//   _taeh, nĉas, _пиёз_, --, 
   {{0x36d407d8,0x61f80309,0x656800d8,0x9f4401e7}},	//   _соср, _qiwl, _uaeh, rmlí_, 
   {{0xdeec001f,0xd02000fd,0xa0a400ee,0xdfe80107}},	//   ቀውን_, амый, тапд, мдид_, 
   {{0x61f80142,0x00000000,0x00000000,0x00000000}},	//   _wiwl, --, --, --, 
   {{0x61f80113,0x13a801d5,0x63a21d13,0x00000000}},	//   _tiwl, _تنلی_, _illn, --, 
   {{0xaad40c2e,0xe0d4008e,0x80d00eac,0xdb0c25e6}},	//   _धड़क, _июль, দেষ্, ribí, 
   {{0x21e000d2,0xdb0c5b25,0x399c0ca8,0x00000000}},	//   lóho_, onbø, _síso_, --, 
   {{0x7bdc0d04,0xdb0c143a,0x8eb00451,0xdd940022}},	//   ulru, nnbø, _ھميش, хаҭы, 
   {{0x9e9400db,0x00000000,0x00000000,0x00000000}},	//   _جاشچ, --, --, --, 
   {{0xf1c40306,0x00000000,0x00000000,0x00000000}},	//   pešť_, --, --, --, 
   {{0x090000f3,0x63a00332,0x6db8010f,0xd6bc00cc}},	// [3dfc0] рпун, _olln, rĉat, _অৰূপ, 
   {{0x47c8004b,0x81b400eb,0x00000000,0x00000000}},	//   والۍ_, চকি_, --, --, 
   {{0x4b34008f,0x00000000,0x00000000,0x00000000}},	//   _בריל_, --, --, --, 
   {{0x63a0f985,0xdb0c0109,0xd9d000d1,0x00000000}},	//   _alln, libà, _ئەرگ, --, 
   {{0x81b404c5,0x00000000,0x00000000,0x00000000}},	//   চকা_, --, --, --, 
   {{0x6db80115,0x00000000,0x00000000,0x00000000}},	//   nĉar, --, --, --, 
   {{0x63a0010a,0xc6d4013d,0x00000000,0x00000000}},	//   _dlln, _астө, --, --, 
   {{0x55e401b9,0x63a07cab,0x65b801c6,0x59e000cd}},	//   _робб, _elln, _зуур_, पतिर, 
   {{0x66081a5c,0x335400f7,0xcfa401c6,0xb0340114}},	//   _čeki, _бүлө_, вшни, ћнош, 
   {{0x20180022,0x00000000,0x00000000,0x00000000}},	//   ãsia_, --, --, --, 
   {{0xc7b00375,0x4ea42151,0x528400ae,0x00000000}},	//   שבת_, трпа, _جلاك, --, 
   {{0x7e400022,0xf8b400cd,0x00000000,0x00000000}},	//   шхье, ूपाय, --, --, 
   {{0x4fc58f01,0x013408a8,0x69c21d14,0x0ca8a2b6}},	//   _иска, _יראת_, élem, фтни_, 
   {{0xc0e034da,0xead801ec,0x00000000,0x00000000}},	//   _точк, емгі_, --, --, 
   {{0xa93465db,0x3e6578d5,0x61ec002e,0xbea4009f}},	//   левш, _ашын_, ŋale, _لهون_, 
   {{0x39a61d15,0xe7940133,0x2b4c0118,0x00000000}},	//   ашув, گارک, řec_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3dfd0] --, --, --, --, 
   {{0xe7961d16,0x7dc803e3,0x00000000,0x00000000}},	//   دارک, mısa, --, --, 
   {{0xaa961d17,0x370402bf,0x7dc81cce,0xdb5001f7}},	//   _синч, рчув, lısa, _اَپ_, 
   {{0xe6e40137,0xa2c400c7,0x00000000,0x00000000}},	//   _ەكسپ, қәзк, --, --, 
   {{0x7dc815b7,0xb884003b,0x00000000,0x00000000}},	//   nısa, _курй, --, --, 
   {{0x224817a0,0xda1400f2,0x00000000,0x00000000}},	//   епки_, _جسیک, --, --, 
   {{0x85541e4b,0xdeec0092,0x00000000,0x00000000}},	//   _لیار_, ቀውና_, --, --, 
   {{0x601806a6,0x00000000,0x00000000,0x00000000}},	//   нцор_, --, --, --, 
   {{0xe0d80276,0x302400c7,0x7bc00419,0xdb0c00e5}},	//   эви_, азыҳ, émuk, hibá, 
   {{0x9f8428a8,0xb49c0241,0x63a0035a,0x7dc80432}},	//   угод, _mẹ́f, _ulln, dısa, 
   {{0x5f740345,0x00000000,0x00000000,0x00000000}},	//   ناگر, --, --, --, 
   {{0x399c0122,0x5f7404d3,0xb33c0327,0xdcf400dc}},	//   _písm_, _ڕابر, _ilħa, _anyā, 
   {{0x79800428,0xc05802dd,0x00000000,0x00000000}},	//   _òmwi, _іід_, --, --, 
   {{0xd00c74bb,0xdee50d14,0x4ba000fb,0x00000000}},	//   _على_, _йоли, йһың, --, 
   {{0xdb0c004e,0xd6bc0154,0x00000000,0x00000000}},	//   ribà, _অর্প, --, --, 
   {{0x9d440798,0x4e1001c8,0x00000000,0x00000000}},	//   _сеид, _اِيئ, --, --, 
   {{0x57e81d83,0x09e01309,0x4dd800df,0x00000000}},	// [3dfe0] едам_, сотн, _אַזױ, --, 
   {{0xdcf4002b,0x6db801e4,0x00000000,0x00000000}},	//   _gnyā, lĉap, --, --, 
   {{0x15b86215,0xd9440131,0x00000000,0x00000000}},	//   ныды_, _йени, --, --, 
   {{0xb8b40046,0x98a417b4,0x00000000,0x00000000}},	//   _көзі, _биме, --, --, 
   {{0x2ed000bc,0xa5040022,0x00000000,0x00000000}},	//   _हड्त, рҵуа_, --, --, 
   {{0x9585d29b,0x926800c7,0x42700150,0x00000000}},	//   _өлге, ериа_, өгіс, --, 
   {{0x39440205,0x00000000,0x00000000,0x00000000}},	//   _ömss_, --, --, --, 
   {{0xb0349a5c,0x7dc805d1,0xd01927a6,0xbc900023}},	//   аниш, yısa, нфо_, _ዝጸንሓ_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc0540879,0x00000000,0x00000000,0x00000000}},	//   اشيا_, --, --, --, 
   {{0xd06000ac,0x2ef80036,0x69c000e5,0x62840108}},	//   _ərəb, ärf_, élek, ähot, 
   {{0xd0080120,0x00000000,0x00000000,0x00000000}},	//   _зеде_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x765ce438,0x62840158,0x7dc815b7,0x00000000}},	//   _opry, åhog, rısa, --, 
   {{0x6db801e4,0xd00c01d3,0x0eb8013d,0x00000000}},	//   bĉap, _بلڈ_, _яуды_, --, 
   {{0x89a400dd,0x7dc80790,0xd6bc00cc,0x00000000}},	//   اھدہ_, pısa, _অৰ্প, --, 
   {{0x5cc005f5,0x765c062c,0x49900101,0x00000000}},	// [3dff0] _дөрв, _apry, لیگر, --, 
   {{0x46a43925,0x00000000,0x00000000,0x00000000}},	//   лшеб, --, --, --, 
   {{0x06b448dc,0x99880064,0xca7000e5,0x00000000}},	//   دناک_, gubų_, _انجک, --, 
   {{0x241a1d18,0xe8e80116,0xfaa40352,0x880000f1}},	//   воды_, _үмүд_, _ышын, _هېرو, 
   {{0xa5c401e1,0x660967e7,0xf990009f,0x00000000}},	//   _atóè, _čeku, _ربَ_, --, 
   {{0x47861d19,0x753c0171,0x00000000,0x00000000}},	//   _сымб, _ērze, --, --, 
   {{0x39540077,0x77a00166,0x972001d3,0xe69401af}},	//   _éasí_, _möxl, _ذہنو, _тивы, 
   {{0x6ed80118,0x00000000,0x00000000,0x00000000}},	//   नअनु, --, --, --, 
   {{0xb33c031c,0x00000000,0x00000000,0x00000000}},	//   _ilħn, --, --, --, 
   {{0x442c560b,0x399c02d2,0x00000000,0x00000000}},	//   msg_, _písk_, --, --, 
   {{0xdee40d99,0x4fe459e6,0xdec40131,0x00000000}},	//   рони, рмэн_, шәдо, --, 
   {{0x81a80241,0x9d440993,0x442c0142,0xa0740153}},	//   _fáwọ, шемд, osg_, _выкш, 
   {{0x442c2e13,0xb9e801e1,0x628400d7,0x00000000}},	//   nsg_, _tìẹ_, ťhod, --, 
   {{0x661402d0,0x442c0e89,0x10a000d8,0xff040064}},	//   _otzk, isg_, _фишн, _сядн, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x705003e6,0x59740137,0x699400d4,0x00000000}},	//   _بۆیا, шыгу, брух, --, 
  
   {{0x7d040537,0x765e1d1a,0x442c0009,0x00000000}},	// [3e000] _igis, _spry, jsg_, --, 
   {{0x7c261d1b,0x79540133,0x4c98011a,0x442c00a2}},	//   _iwir, _گێرا, _סביו, dsg_, 
   {{0x7d04036e,0xdb0c002f,0x00000000,0x00000000}},	//   _kgis, inbü, --, --, 
   {{0x7c240c10,0x3ce21d1c,0xdb0c0112,0x27e00051}},	//   _kwir, _kyiv_, hnbü, alhn_, 
   {{0xda604be7,0x7c240175,0x00000000,0x00000000}},	//   _ስልጠና_, _jwir, --, --, 
   {{0x7c2401b2,0xd25821ca,0x00000000,0x00000000}},	//   _mwir, вци_, --, --, 
   {{0x7d061d1d,0xd6d83c97,0x442e1d1e,0x3134004e}},	//   _ogis, _شورش_, asg_, бейр, 
   {{0x7d061d1f,0x9f5c0428,0x7c240161,0xdb0c0166}},	//   _ngis, _auwà_, _owir, libä, 
   {{0x71040124,0x00000000,0x00000000,0x00000000}},	//   аҧҵа, --, --, --, 
   {{0x4418010f,0xfde801d3,0xa2d000bc,0x00000000}},	//   _סובס, یکٹو_, _ढुक्, --, 
   {{0x7c261d20,0x11480276,0x51840408,0x3e641422}},	//   _awir, _апей_, _вула, ашян_, 
   {{0x7c261d21,0xac18e5be,0x7d040022,0x81a80241}},	//   _bwir, лому_, _cgis, _táwọ, 
   {{0x98a0007f,0x7dc80205,0x85f400df,0x00000000}},	//   _bekč_, mısl, יצטע_, --, 
   {{0x7c240134,0x53d41d7d,0x7d061d22,0x2ec4010b}},	//   _dwir, धविश, _egis, _гөмм, 
   {{0xff140302,0x7c2400b0,0xba0800a7,0xc9f400ae}},	//   _דקות_, _ewir, ихте_, لسرع, 
   {{0x442c0368,0x7c2400ad,0x7db4007b,0xdb0c032e}},	//   ysg_, _fwir, _وصيا, fnbó, 
   {{0x7c261d23,0x442c0014,0x6d4c0009,0x27e00455}},	// [3e010] _gwir, xsg_, _icaa, tlhn_, 
   {{0x7dc805d1,0x00000000,0x00000000,0x00000000}},	//   hısl, --, --, --, 
   {{0x7c261d24,0x66d40592,0x442c0042,0x7dc80205}},	//   _zwir, حيائ, wsg_, kısl, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x55516414,0x046507cf,0x3ce00218,0x69de1d25}},	//   سپور, ртем, _xyiv_, _ikse, 
   {{0xa34a1d26,0x442e1d27,0xc614211f,0x399c09e8}},	//   узка_, rsg_, _نظرث, _rísi_, 
   {{0xefe8044e,0x754801d3,0x6b8000e5,0x00000000}},	//   _ዘለዋ_, úszá, ölgy, --, 
   {{0xd12c6923,0x6d4c9508,0x00000000,0x00000000}},	//   ىمى_, _ncaa, --, --, 
   {{0x7d04022e,0x56700092,0x00000000,0x00000000}},	//   _rgis, _ለጋዜጠ, --, --, 
   {{0x7c240189,0x6d4c0072,0x399c0252,0x00000000}},	//   _rwir, _acaa, _vísi_, --, 
   {{0x7c2406e4,0x6d4c00d8,0x7d040036,0x3ce0007f}},	//   _swir, _bcaa, _pgis, _syiv_, 
   {{0xc0dc044e,0x6d4c04ba,0xdee43500,0xfc380124}},	//   _ሓጺር_, _ccaa, _қойи, аҭи_, 
   {{0xefe8069c,0x11f401d5,0xdfd40108,0x00000000}},	//   _ዘለዉ_, _اتلگ, _лоды, --, 
   {{0x69de1d28,0x212dc420,0x8ba400fb,0xb8b00092}},	//   _akse, laeh_, йҙыҡ_, _ለመጻፍ_, 
   {{0x7d0407de,0x1ae5262a,0x6ee40220,0x7dc80790}},	//   _tgis, совм, _وسىل, lısm, 
   {{0x7c2401b2,0x83040135,0x7d040526,0x1868c439}},	//   _twir, _ཅུའུ_, _ugis, лаби_, 
   {{0x7c261d29,0x249c0218,0x25bc03cb,0x7dc803e0}},	// [3e020] _uwir, jywm_, diwl_, nısm, 
   {{0x69dc0212,0x66080e3c,0x212c0007,0x00000000}},	//   _ekse, _čekr, haeh_, --, 
   {{0x69dc03a0,0x94100213,0x6700004e,0x7dc80205}},	//   _fkse, əcəm_, дүрб, yısl, 
   {{0x99840597,0x6aa0365a,0x7dc80205,0x15440cb6}},	//   _الحو, ølfe, kısm, седм, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xefe8067d,0xd5b21d2a,0x69c0004a,0x00000000}},	//   _ዘለዎ_, _کفر_, élev, --, 
   {{0x31640408,0x81340952,0x69dccf52,0xd0600213}},	//   temz_, ڭسىز_, _ykse, ərəf, 
   {{0x30146c96,0x25bc0142,0x00000000,0x00000000}},	//   одир, ciwl_, --, --, 
   {{0xefe8044e,0x4f28177b,0x013015eb,0x00000000}},	//   _ዘለው_, лінг_, سعيد, --, 
   {{0x6d4c1368,0xefb001b9,0x4f6800f3,0x00000000}},	//   _scaa, بیتگ, ушим_, --, 
   {{0x11d47724,0x2278d537,0xd9f80490,0x6e9400a8}},	//   _людя, _پلنگ_, ्दात_, цину, 
   {{0xc6900302,0xacf80815,0x867800df,0x6c5400db}},	//   לאת_, инну_, ארטו, окму, 
   {{0xe08406f6,0xd6ac00fe,0x7f800133,0x00000000}},	//   _وجهي, কপিয, زلێن, --, 
   {{0x399c013a,0xf7d41884,0x00000000,0x00000000}},	//   _mísu_, ﻘﺎﻧﺪ, --, --, 
   {{0x399c032e,0x00000000,0x00000000,0x00000000}},	//   _lísu_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x22680075,0xa7b81919,0xe7b81bc3,0x321c0175}},	// [3e030] ﻳﻐﯘﺭ_, алау_, агаш_, hpvy_, 
   {{0x7bc0003e,0xdb0c0fac,0x00000000,0x00000000}},	//   émut, tibå, --, --, 
   {{0x6b840356,0xa3b80345,0x78a803b9,0x7c380055}},	//   _inhg, یاتر_, _ədvi, _āvri, 
   {{0xe9441547,0x69dc00af,0xbb180014,0x00000000}},	//   _بردی, _ukse, _پزیا_, --, 
   {{0xdb0c002d,0x87e402e8,0x2d9800e8,0xe4c401a9}},	//   jibû, _гюве, ërey_, ўйли, 
   {{0xe2986a31,0x399c08ce,0x22144a46,0x200c01d5}},	//   иал_, _dísu_, офир, vqei_, 
   {{0xa18800c9,0x00000000,0x00000000,0x00000000}},	//   ибка_, --, --, --, 
   {{0xa4d400d4,0x00000000,0x00000000,0x00000000}},	//   _добі, --, --, --, 
   {{0xdb0c0086,0x1fa8013e,0x212c00d5,0x60080063}},	//   gibû, икии_, raeh_, јном_, 
   {{0x200c04cc,0x212c01ab,0x1f640229,0x7dc80205}},	//   rqei_, saeh_, цком, rısm, 
   {{0x02a40b14,0x98a000ef,0x00000000,0x00000000}},	//   _урам, _mekā_, --, --, 
   {{0x6b840007,0x6e3c01ed,0x21c400b0,0x399c00bc}},	//   _anhg, árba, kēhi_, _jíst_, 
   {{0x399c012c,0x00000000,0x00000000,0x00000000}},	//   _míst_, --, --, --, 
   {{0xe9240156,0x98a00029,0x399c01a8,0x4ad80037}},	//   _འབུབ_, _nekā_, _líst_, _मुहव, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x48e0587f,0x00000000,0x00000000,0x00000000}},	// [3e040] дотв, --, --, --, 
   {{0x9b461d2b,0x194c00b5,0xda64399b,0xfd240345}},	//   _بندو, _ｂａｒ_, _двои, _بوکێ, 
   {{0x7bde1d2c,0x399c00d2,0x550474df,0x00000000}},	//   moru, _sísu_, очла, --, 
   {{0x7bdc0de4,0x69c001ed,0x1dc800dc,0x77a0008e}},	//   loru, élet, ाचित, _möxi, 
   {{0xdb0c02d2,0x00000000,0x00000000,0x00000000}},	//   dibú, --, --, --, 
   {{0x7bde1d2d,0x399c01a8,0xa2d0012c,0x00000000}},	//   noru, _vísu_, _ढुङ्, --, 
   {{0xf484030f,0x7bdc0393,0xd5b090b2,0x98700092}},	//   _کازی, ioru, _قفس_, _ብርሀኑ_, 
   {{0x7bde1d2e,0x06a000f1,0x65b00419,0x00000000}},	//   horu, _کمېټ, sťhr, --, 
   {{0x7bdc0374,0x54ec0034,0x42c458c7,0x6fb80107}},	//   koru, _जरिए_, йгән_, йгир_, 
   {{0x7bde1d2f,0x00000000,0x00000000,0x00000000}},	//   joru, --, --, --, 
   {{0x7bde1d30,0xfe20030d,0xfe6c01f7,0xd174004e}},	//   doru, мьян, ندَ_, _мыды, 
   {{0x7bdc0381,0x64a40022,0x248800d7,0x00000000}},	//   eoru, _ьаӡа, ťame_, --, 
   {{0x320c013a,0x00000000,0x00000000,0x00000000}},	//   _hudy_, --, --, --, 
   {{0x7bdcf0af,0x320c0118,0xf8d8000d,0x7f540064}},	//   goru, _kudy_, _भुइय, _маіс_, 
   {{0xe91800d4,0x00000000,0x00000000,0x00000000}},	//   йові_, --, --, --, 
   {{0x21c400b0,0x3ea0005c,0xa8146741,0x00000000}},	//   tēhi_, øjte_, здаш, --, 
   {{0x7bde1d31,0x6da40032,0x320e1d32,0x00000000}},	// [3e050] boru, _миҫа, _ludy_, --, 
   {{0x7bde1d33,0x399c0008,0x683001a8,0x21c402b5}},	//   coru, _síst_, _aðdá, rēhi_, 
   {{0xf518063f,0x69c001ed,0xf7705821,0x320c3166}},	//   _ịtụp, éles, ضال_, _nudy_, 
   {{0x21c402b1,0xa87401ec,0x00000000,0x00000000}},	//   pēhi_, _елмі, --, --, 
   {{0xfbd0168d,0x638570fa,0x399c09cc,0x320d5cbc}},	//   _ستی_, згла, _víst_, _audy_, 
   {{0x987000b7,0x33e0067c,0xe944158f,0x320c15c0}},	//   _ብርሃኑ_, dòxs_, _برگی, _budy_, 
   {{0xdb0c0086,0x93101c4e,0x4e04012c,0x399c02d2}},	//   gibù, رويش, _संगै_, _tíst_, 
   {{0x7bde1d34,0xa5c80014,0x92fc015b,0x320c01ef}},	//   zoru, _اورٕ_, ুরূপ_, _dudy_, 
   {{0x7bdc079d,0xdb0e1d35,0x2018069c,0x03640014}},	//   yoru, ribú, ësi_, _ؤری_, 
   {{0x7bdc16b8,0x828402c9,0x00000000,0x00000000}},	//   xoru, _وجال, --, --, 
   {{0x7bde1d36,0xf8d8000d,0x00000000,0x00000000}},	//   voru, _भुईय, --, --, 
   {{0x7bdc019f,0x32640116,0x7204313e,0x25b4236c}},	//   woru, _ютув, _قولم, _çalı_, 
   {{0x7bde1d37,0x0d800064,0x6c7407a5,0x40c40345}},	//   toru, хлян, мурх, _بزاف, 
   {{0xe1f80006,0x7bdcbf09,0x46a80bae,0x6e4803b2}},	//   lmų_, uoru, चनाह, ðsbø, 
   {{0x7bde1d38,0x3f861d39,0x00000000,0x00000000}},	//   roru, _innu_, --, --, 
   {{0x7bde1d3a,0x7e600204,0x9f2000d1,0x00000000}},	//   soru, _ipnp, _تۈگۈ, --, 
   {{0xdb0c03b2,0x00000000,0x00000000,0x00000000}},	// [3e060] kibø, --, --, --, 
   {{0x7bdd3557,0xdec80092,0xdb0c007c,0x9f64008e}},	//   qoru, _አሉን_, enbö, _ütäp_, 
   {{0x8b9802e4,0xd6380212,0x00000000,0x00000000}},	//   _הבית, сязі_, --, --, 
   {{0xb33c031c,0x9b4407d6,0x00000000,0x00000000}},	//   _ilħi, _بنگو, --, --, 
   {{0x320c3a5a,0x3f840174,0xa3c800dc,0x00000000}},	//   _sudy_, _onnu_, ैवं_, --, 
   {{0x320c02f0,0xd24c0014,0x934000cf,0x00000000}},	//   _pudy_, ۆنڈ_, رىعۇ, --, 
   {{0x35c401a9,0x00000000,0x00000000,0x00000000}},	//   _жавҳ, --, --, --, 
   {{0x3f861d3b,0x0654010f,0xe1f80064,0x00000000}},	//   _annu_, _מילך_, gmų_, --, 
   {{0x0440e4e0,0x9358084c,0x673000a2,0x00000000}},	//   _петн, _греу_, _ökjä, --, 
   {{0xe1f80153,0x320e1d3c,0x00000000,0x00000000}},	//   amų_, _tudy_, --, --, 
   {{0xe2a8969f,0x6ac00154,0x00000000,0x00000000}},	//   _وامن_, _এডভো, --, --, 
   {{0x60cc0219,0xcae00b72,0x37c400eb,0x00000000}},	//   _žame, _गडबड_, ্তির, --, 
   {{0xfe6c0133,0x7c84292c,0x00000000,0x00000000}},	//   ندێ_, нуре, --, --, 
   {{0x7bcc0055,0x00000000,0x00000000,0x00000000}},	//   _āmuñ, --, --, --, 
   {{0x37c4015b,0x6db4010b,0x2d98000f,0x290401e1}},	//   ্তার, _ойку, êres_, _ńla_, 
   {{0xc0c40020,0xae040220,0xcd043be4,0x9f44036e}},	//   _ችግሩ_, _توعى, _эчки, yllë_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3e070] --, --, --, --, 
   {{0x6d5e1d3d,0xe1f80153,0x07080107,0x00000000}},	//   lfsa, zmų_, схаи_, --, 
   {{0xf7700145,0x363400c6,0xe1f80006,0x659444e4}},	//   داق_, فرنس, ymų_, мажу, 
   {{0x2934008f,0xa9840137,0x6d5c002f,0x00000000}},	//   _קאָן_, _تۅرۅ_, nfsa, --, 
   {{0x69cc05a1,0x2918022f,0xdb0c01e3,0x00000000}},	//   mnae, _ifsa_, rnbö, --, 
   {{0xdb1c002d,0xa2e61d3e,0x999400e5,0x00000000}},	//   _ampê, молд, _ٹھہر_, --, 
   {{0x2d880421,0x69cc003a,0x36d4014b,0xa1f400f0}},	//   _onae_, onae, _зорр, мџиј, 
   {{0x6d5c0196,0xe1f80024,0xdb0c0162,0xb5580117}},	//   jfsa, umų_, sibø, _нисф_, 
   {{0x25ac009a,0xe1f80006,0x69cc0618,0x60cc013a}},	//   _ilel_, rmų_, inae, _žamb, 
   {{0x69cc0097,0x2d8a1d3f,0xdb1c20ef,0xd9b800dc}},	//   hnae, _anae_, _empê, _इष्ट, 
   {{0x25ac00b0,0x69cc0007,0x02a400ee,0x6d5cef41}},	//   _klel_, knae, _эрам, ffsa, 
   {{0xc0c40201,0x9f461d40,0x65785a8c,0x2d8809c2}},	//   _ችግር_, illé_, ndwh, _cnae_, 
   {{0x69ce1d41,0x61ea1d42,0x67240175,0x1fb40114}},	//   dnae, mlel, kbhj, _оскр, 
   {{0x61ea1d43,0x201c014f,0x6d5c0014,0x64582c6a}},	//   llel, _itwi_, afsa, itwi, 
   {{0x61ea1d44,0x4ad80c2e,0x628000b5,0x77a000fd}},	//   olel, _मुआव, _jrlo, _möxt, 
   {{0x61ea1d45,0x69ccef15,0x25ac0139,0x00000000}},	//   nlel, gnae, _nlel_, --, 
   {{0x09e01fe2,0x61ea1d46,0xa3dc0316,0x23dc0b8f}},	// [3e080] тотн, ilel, णका_, यवाद, 
   {{0x61ea1d47,0x62821d48,0x779404d3,0xd76400e5}},	//   hlel, _orlo, ریزا, بارٹ, 
   {{0x61ea1d49,0x29180129,0x00000000,0x00000000}},	//   klel, _ffsa_, --, --, 
   {{0x645a1d4a,0x98a40166,0xceb0011a,0x657c08a5}},	//   ftwi, _жиме, כיב_, _óshl, 
   {{0x62821d4b,0x08e001ee,0x00000000,0x00000000}},	//   _arlo, _аҡтү, --, --, 
   {{0x61e84d11,0xdce402fb,0xaac401d5,0x62821d4c}},	//   elel, jekč, _آتین, _brlo, 
   {{0x628001ab,0x645c01b8,0x64580083,0x6d5e1d4d}},	//   _crlo, _äsin, atwi, yfsa, 
   {{0x62800072,0x69c01f13,0xae9401e1,0x98b00166}},	//   _drlo, रोपी, _mẹti, leyı_, 
   {{0x78a42bef,0x62821d4e,0xdce402fb,0x6458033f}},	//   nyiv, _erlo, fekč, ctwi, 
   {{0x61ea1d4f,0x201c007f,0x69cc0399,0xdec80092}},	//   alel, _dtwi_, znae, _አሉኝ_, 
   {{0x61ea1d50,0xdb1cff32,0xae940ca8,0x78a40022}},	//   blel, _impè, _nẹti, hyiv, 
   {{0x69cc0097,0x2d88003a,0x6d5c1196,0xd008009b}},	//   xnae, _qnae_, ufsa, _деде_, 
   {{0x6d5e1d51,0x53d000cd,0x00000000,0x00000000}},	//   rfsa, _तदाश, --, --, 
   {{0x09c40574,0x69cc0399,0xaed61d52,0xbb480014}},	//   रच्य, wnae, _полш, ولُن_, 
   {{0x69cc0b91,0xfe6c352e,0x6d5c002f,0x91a0000d}},	//   tnae, _ندي_, pfsa, _ओकाई, 
   {{0xb33c031c,0x2d8898df,0x69cc0165,0x8274010f}},	//   _ilħu, _unae_, unae, ועלע_, 
   {{0x69ce1d53,0x6458030d,0xdd114398,0x00000000}},	// [3e090] rnae, xtwi, lüşm, --, 
   {{0x69cc0fcf,0x61e971df,0xbc686727,0x00000000}},	//   snae, zlel, _کمین_, --, 
   {{0xdd10bd8f,0x69cc03b2,0x00000000,0x00000000}},	//   nüşm, pnae, --, --, 
   {{0xdb1c0561,0x6458f178,0x78a40526,0x9af804ae}},	//   _ampè, ttwi, byiv, _מפתח, 
   {{0xd24c5a05,0xe36409a5,0x78a400ca,0x25ac0100}},	//   ەنى_, екли, cyiv, _vlel_, 
   {{0x645a1d54,0x61e8000a,0x62821d55,0x7dc82ca8}},	//   rtwi, wlel, _prlo, lıst, 
   {{0x61ea1d56,0xc2e4015b,0x27e00036,0xae940241}},	//   tlel, গেনি_, mohn_, _mẹsi, 
   {{0xdb1c2508,0x7dc800ac,0x61ea1d57,0x628016a3}},	//   _empè, nıst, ulel, _vrlo, 
   {{0x61ea1d58,0x045401d5,0x00000000,0x00000000}},	//   rlel, _تئزد, --, --, 
   {{0x61e80518,0x660802f6,0x1f54039b,0xa2940006}},	//   slel, _hiek, хтиё, _пазі, 
   {{0x660a1d59,0x61e82ecb,0x62800034,0xdce40306}},	//   _kiek, plel, _urlo, rekč, 
   {{0xdb1d25be,0x66080003,0x93c0054e,0x69c0033f}},	//   _impé, _jiek, şăto, रोमी, 
   {{0x660a1d5a,0x201c0455,0x4c8093fb,0x7dc803b9}},	//   _miek, _utwi_, гляв, dıst, 
   {{0x660a1d5b,0x27e0f3bc,0x5f7408f0,0x78a61d5c}},	//   _liek, john_, _ساتر, vyiv, 
   {{0x66080022,0x3ab40166,0x00000000,0x00000000}},	//   _oiek, тәпт, --, --, 
   {{0x660a1d5d,0x78a4023a,0x62f0009e,0x09e003f5}},	//   _niek, tyiv, _চলায়_, госн, 
   {{0x178401c0,0xdd9001d3,0x00000000,0x00000000}},	// [3e0a0] нгам, _لوں_, --, --, 
   {{0x6608005a,0xdb0e1d5e,0x77a000fd,0xae940248}},	//   _aiek, nibü, _röxs, _tẹti, 
   {{0x66080598,0x78a61d5f,0x34a8752d,0xcb54011a}},	//   _biek, syiv, कन्द, _אסיה_, 
   {{0x6608068f,0xae940ca8,0x78a400c7,0x7dc803e0}},	//   _ciek, _kẹri, pyiv, mıss, 
   {{0xae940248,0x00000000,0x00000000,0x00000000}},	//   _jẹri, --, --, --, 
   {{0xae940ca8,0x00000000,0x00000000,0x00000000}},	//   _mẹri, --, --, --, 
   {{0x6609ffcc,0xdb0d30ee,0xd6d0007b,0x20180bcd}},	//   _fiek, dibü, _صقر_, ísin_, 
   {{0x66080007,0x8658011a,0xdd100205,0x826057fb}},	//   _giek, _מדלי, vüşm, اهين, 
   {{0xdb1e1d60,0x9444527d,0x4fc61d61,0xdb0c03b2}},	//   _empé, _سپان, есна, nibó, 
   {{0x66080936,0xdd100205,0x00000000,0x00000000}},	//   _ziek, tüşm, --, --, 
   {{0x63a4245f,0xc7b000d9,0x7dc803e0,0x7ff00472}},	//   öhne, רבת_, yıst, دسيا, 
   {{0xdd10046c,0xdd900617,0x91b918a2,0x7dc800ac}},	//   rüşm, لوپ_, _عطار_, xıst, 
   {{0x8fa40945,0x69c007ea,0xc1980375,0xcee800e5}},	//   _паде, èlem, _משאי, _کرشن_, 
   {{0xb7c404c5,0x71740451,0x1ea80451,0x6e94007b}},	//   ্তুট, _سهڪا, _ڪاهي_, _للتا, 
   {{0x4ad8041c,0x00000000,0x00000000,0x00000000}},	//   _मुखव, --, --, --, 
   {{0xfa340214,0x00000000,0x00000000,0x00000000}},	//   طرفد, --, --, --, 
   {{0x660a1d62,0x7dc800ac,0xebd806ed,0xdb0c0162}},	// [3e0b0] _riek, rıst, _одиш_, gibó, 
   {{0x660a1d63,0xb33c031c,0x7a1c02e2,0x6a140588}},	//   _siek, _joħd, _sčte, _имоу, 
   {{0x6609aa6a,0x7dc80205,0x00000000,0x00000000}},	//   _piek, pıst, --, --, 
   {{0x75f800bc,0xf5380092,0x2d980010,0x45a000db}},	//   jízd, _አዝማሚ, njse_, دەرك, 
   {{0x752404d4,0x660a1d64,0xdb0c012d,0x19c000fb}},	//   ñiza, _viek, cibó, _тәрг, 
   {{0x660a1d65,0x93421d66,0x97000075,0x67d4013e}},	//   _wiek, анше, _چېكى, _рогу, 
   {{0x660a1d67,0x00000000,0x00000000,0x00000000}},	//   _tiek, --, --, --, 
   {{0x20180120,0xefd0001f,0x7ea801f4,0xd5840133}},	//   ísio_, ብአዊ_, höpö, _لێمه_, 
   {{0x66e40116,0xd58402f2,0x00000000,0x00000000}},	//   _чоңа, _جێنه_, --, --, 
   {{0xae940241,0xa0a40166,0x00000000,0x00000000}},	//   _rẹri, ешүл, --, --, 
   {{0xdb0c5c19,0x5398010f,0x00000000,0x00000000}},	//   ribü, _קיעו, --, --, 
   {{0xe6d40724,0xdca40e46,0xdb0c0037,0x00000000}},	//   _eşçä, вами, sibü, --, 
   {{0xa0a400d8,0xdce400ef,0x00000000,0x00000000}},	//   _јалд, fekā, --, --, 
   {{0x8fa21d68,0x2d9802d3,0x1ec80117,0x4fa000d8}},	//   _ваше, ajse_, _олли_, _вишв, 
   {{0x75f8634d,0x61ec002e,0x1ae4034f,0xe6bc07af}},	//   líze, ŋalu, товм, ्पोज, 
   {{0x9f44007b,0x66e40cb4,0xae940241,0x99f400d4}},	//   illí_, _कड़क_, _tẹri, тягі, 
   {{0x38c804fb,0x61f8015d,0x69c06236,0x00000000}},	// [3e0c0] راری_, _mhwl, रोधी, --, 
   {{0x7ea801b8,0xdb8400c7,0xdb0c089f,0x9a1800db}},	//   cöpö, _ргои, ribó, _оюму_, 
   {{0x1dc41dd1,0x15b801ec,0xdb0c06ea,0x00000000}},	//   _लगात, мыды_, sibó, --, 
   {{0xc68c01d9,0x383400db,0x00000000,0x00000000}},	//   تِم_, _مۉرز, --, --, 
   {{0xdee80023,0x00000000,0x00000000,0x00000000}},	//   _መጺአ_, --, --, --, 
   {{0x4cdc03d4,0x741401e2,0x00000000,0x00000000}},	//   নেকু, پوګا, --, --, 
   {{0x8778008f,0x03a01f5a,0x00000000,0x00000000}},	//   _קאלי, ријо, --, --, 
   {{0x777c0023,0xda0007f7,0xf078010b,0x86b002dd}},	//   _harx, लगित_, ейиш_, _тәуі, 
   {{0x777c03b9,0x00000000,0x00000000,0x00000000}},	//   _karx, --, --, --, 
   {{0x6fb47484,0xdee802d3,0x94041c36,0x6e982c25}},	//   امدا, _መጺኡ_, _شواه, евор_, 
   {{0x777e1d69,0x03a015ed,0x61f80175,0xe244004b}},	//   _marx, _њихо, _fhwl, _مخني, 
   {{0x506568e7,0x23680989,0x75f8012c,0x2d8c1bce}},	//   _атка, đaje_, bíze, ñee_, 
   {{0xba740214,0xc2e403d4,0xbdd427a8,0x98a00153}},	//   یافت, গেদি_, роящ, _tekę_, 
   {{0xfe6c2e6b,0x777c036b,0x2cac0327,0xf41400cc}},	//   حدی_, _narx, ġed_, _ডবাৰ_, 
   {{0xbea0009b,0x00000000,0x00000000,0x00000000}},	//   _вајк, --, --, --, 
   {{0xac580fc0,0x6e9400ec,0x00000000,0x00000000}},	//   _заиф_, _للڪا, --, --, 
   {{0x39160814,0x777e1d6a,0xb33c0003,0xe8706cba}},	// [3e0d0] рмур, _barx, _moħb, _döşü, 
   {{0x870407d2,0x777e1d6b,0xe695a4b2,0x46a40139}},	//   نبال, _carx, лизы, кшеб, 
   {{0x39580030,0x777c2ca7,0x00000000,0x00000000}},	//   _šesť_, _darx, --, --, 
   {{0xa43a1d6c,0xa4d80220,0xdee80023,0xdd100205}},	//   езду_, ндеу_, _መጺኣ_, _müşi, 
   {{0x777c0050,0x75443334,0xc7c80006,0x00000000}},	//   _farx, рніз, _жыве_, --, 
   {{0x777c0067,0x60cc01a6,0x68440022,0x18280214}},	//   _garx, _žamo, _инҭа, _سقفی_, 
   {{0x61f80042,0x3234035b,0x229400be,0x00000000}},	//   _phwl, ахыс, العس, --, 
   {{0x777c01a9,0x75f80118,0x18180345,0x00000000}},	//   _zarx, tíze, _ترێک_, --, 
   {{0x6008021b,0x777c4cd5,0x63ac0240,0x07140073}},	//   нним_, _yarx, ëans, _तलाव_, 
   {{0x777c0372,0x443e1d6d,0xf3f801a9,0xca700092}},	//   _xarx, _ivu_, _ануш_, ችሁንም_, 
   {{0x66146b24,0x615401ed,0x61f80142,0x98b0033b}},	//   _juzk, _منائ, _thwl, vayč_, 
   {{0x63a20384,0x7a1c007f,0x443c03cd,0xdd100432}},	//   _holn, _nčta, _kvu_, _düşi, 
   {{0x63a21d6e,0xa068c9cf,0xc058030d,0x00000000}},	//   _koln, _чала_, _ціе_, --, 
   {{0x63a00c6a,0x69c002ab,0x67340306,0x105001ed}},	//   _joln, रोसी, _nezj, _اکٹھ, 
   {{0x8f5000cf,0x443c007c,0xb60801ef,0x1ea800ec}},	//   _انىش, _lvu_, _hošť, _ڪاڇي_, 
   {{0x443c1326,0x777e1d6f,0xdb1d7989,0xb6080c5e}},	//   _ovu_, _sarx, _impí, _košť, 
   {{0x443c04ba,0x777c004e,0x6734b78d,0x00000000}},	// [3e0e0] _nvu_, _parx, _bezj, --, 
   {{0x7c261d70,0x777c01d9,0x66161d71,0x63a00477}},	//   _itir, _qarx, _buzk, _noln, 
   {{0x443c030a,0x673401e4,0xe870008e,0x69c00bae}},	//   _avu_, _dezj, _töşü, रोही, 
   {{0xfe0401d9,0x63a001ab,0x795403e6,0x673402d0}},	//   रगिस_, _aoln, _خێرا, _eezj, 
   {{0x777e1d72,0xf7780588,0x661401c6,0x7c24025c}},	//   _tarx, _иҧа_, _euzk, _jtir, 
   {{0x7c2400ec,0x63a1b171,0x6734010e,0x443c002f}},	//   _mtir, _coln, _gezj, _dvu_, 
   {{0x63a012eb,0x38621d73,0x7c2401d5,0x46a0c064}},	//   _doln, ltir_, _ltir, _ларв, 
   {{0x7c240053,0x443c01bf,0xb11400ee,0x86c0009f}},	//   _otir, _fvu_, шмиш, _ايِن, 
   {{0x7c240c11,0x63a02a53,0x6614c040,0x443c002f}},	//   _ntir, _foln, _zuzk, _gvu_, 
   {{0x3860041e,0x63a21d74,0xe3b001d9,0x37c400eb}},	//   itir_, _goln, _ورٕ_, ্তকর, 
   {{0x7c261d75,0x4ea61d76,0x2dd40276,0x38606f35}},	//   _atir, урпа, ижор, htir_, 
   {{0x38621d77,0xac1966be,0x443c0124,0x6fb41410}},	//   ktir_, кому_, _yvu_, امگا, 
   {{0x7c241529,0xdb1c215a,0xfee0036b,0x0fe000ee}},	//   _ctir, _empí, _қўшм, _гөнү, 
   {{0x7c240c67,0x7a1c0100,0x8b640633,0xcf2400ae}},	//   _dtir, _sčta, داحم, _إرشي, 
   {{0x7c261d78,0x6734045f,0x38600142,0x00000000}},	//   _etir, _rezj, etir_, --, 
   {{0x386009cc,0x7c240413,0xdd0400e2,0x00000000}},	//   ftir_, _ftir, špār, --, 
   {{0x6614009d,0x38600413,0x386c013a,0x00000000}},	// [3e0f0] _suzk, gtir_, _čirý_, --, 
   {{0x661401c4,0x59c40073,0x399c0118,0x00000000}},	//   _puzk, रोबर, _mísy_, --, 
   {{0x443c0b91,0xaa941b6d,0x63a0068f,0x38602a1f}},	//   _svu_, _тинч, _roln, atir_, 
   {{0xdcf400cd,0x69c0017a,0x370417a0,0x673400a2}},	//   _hayā, ëled, счув, _wezj, 
   {{0x63a21d79,0x38621d7a,0xdcf4002b,0x7c2401a9}},	//   _poln, ctir_, _kayā, _xtir, 
   {{0x443e1d7b,0xc7b8034b,0xdcf400cd,0xb608013a}},	//   _vvu_, _чём_, _jayā, _rošť, 
   {{0xe298cdd2,0x63a16e78,0x46f002dd,0xdcf400dc}},	//   тай_, _voln, _اۋار, _mayā, 
   {{0x63a0068f,0xd12ca482,0xe0441e2d,0x21a407d8}},	//   _woln, ومى_, ании, риим, 
   {{0x443c0286,0x656800ca,0x2418023a,0x63a21d7c}},	//   _uvu_, _ibeh, _розы_, _toln, 
   {{0xb0680597,0x9e640953,0x63a00381,0x7c240135}},	//   اصيل_, авод, _uoln, _rtir, 
   {{0x75f8172e,0x7c243498,0xdb0c01b8,0x5ef80107}},	//   líza, _stir, libö, ъхир_, 
   {{0x38621d7d,0x00000000,0x00000000,0x00000000}},	//   ytir_, --, --, --, 
   {{0x65694a2c,0x75f8056a,0x5574008f,0x7c24022e}},	//   _mbeh, níza, בערן_, _qtir, 
   {{0xdcf40055,0x7c240010,0x00000000,0x00000000}},	//   _cayā, _vtir, --, --, 
   {{0x656a1d7e,0xdcf400cd,0xfe400116,0x1aec009e}},	//   _obeh, _dayā, _умйү, ছেনে_, 
   {{0x38621d7f,0x7c240083,0x13d000dc,0x212e1d80}},	//   ttir_, _ttir, _तद्भ, nbeh_, 
   {{0xa3e4007d,0x38621d81,0x57e800d8,0x00000000}},	// [3e100] नवा_, utir_, вдам_, --, 
   {{0x65682dee,0xdcf4002b,0x212c014f,0x00000000}},	//   _abeh, _gayā, hbeh_, --, 
   {{0xdb1c004e,0x00000000,0x00000000,0x00000000}},	//   _impà, --, --, --, 
   {{0x38621d82,0xb8cc015b,0x65680200,0x00000000}},	//   ptir_, _কই_, _cbeh, --, 
   {{0x38600227,0x212c0455,0xc894004e,0xdcf4002b}},	//   qtir_, dbeh_, _курө, _yayā, 
   {{0x656a1d83,0x212c0030,0xd62400ec,0x98b000b8}},	//   _ebeh, ebeh_, _نعري, cayā_, 
   {{0x9594026a,0x31b801ef,0x00000000,0x00000000}},	//   _краљ, _léze_, --, --, 
   {{0x23680bb8,0x5185a60c,0x656801e1,0x5064084c}},	//   đaja_, рука, _gbeh, атоа, 
   {{0xe5d810fc,0x54c401af,0x4f2820c8,0x00000000}},	//   _сфрј_, _тбаб, кінг_, --, 
   {{0x656a1d84,0x00000000,0x00000000,0x00000000}},	//   _zbeh, --, --, --, 
   {{0x212c011c,0xe7f818cc,0x5178030d,0xfbcc0154}},	//   bbeh_, ्गता_, _аслă, লকাত, 
   {{0xd084034b,0xdce4033f,0xdcf40055,0x08580023}},	//   _выки, zeką, _sayā, _ዲግብኤ_, 
   {{0x9f44033b,0x2d840118,0xdcf400b8,0x2d380092}},	//   kolè_, ěle_, _payā, _ጠንክረ, 
   {{0x2d840034,0xaa580c54,0x68d80241,0x00000000}},	//   śle_, лигу_, _ọmó, --, 
   {{0xfb840953,0xc4d00829,0xdcf400b8,0x00000000}},	//   цыян, _दख्ख, _vayā, --, 
   {{0xdb1c004e,0x248800d0,0xac94d62d,0x0ca8014b}},	//   _empà, ťami_, _гаиш, _атои_, 
   {{0x8725f092,0x98b00a28,0xcbc411e6,0xdcf4002b}},	// [3e110] لعام, tayā_, _نزدي, _tayā, 
   {{0x9f44007f,0x39540118,0x65680200,0x212c00d7}},	//   golè_, _časů_, _sbeh, zbeh_, 
   {{0x212c003e,0xa3e4012d,0x00000000,0x00000000}},	//   ybeh_, नवस_, --, --, 
   {{0x24180aec,0xdb1c0005,0x6258020a,0x75f80005}},	//   годы_, _impá, ҳрир_, tíza, 
   {{0xb8cc2f8b,0x24880798,0x7844084c,0x69cc003a}},	//   _কে_, íam_, _мэрж, miae, 
   {{0x75f81709,0x69cc00a9,0xdb0c34c5,0x00000000}},	//   ríza, liae, ribö, --, 
   {{0x212c0429,0xdfe80116,0x756800e5,0x1ac400fe}},	//   tbeh_, һдид_, _چیمہ_, _এডৱা, 
   {{0x22480bb8,0x69cc0cfd,0x65680450,0x9f461d85}},	//   čak_, niae, _ubeh, molé_, 
   {{0xd5a41680,0x212c0427,0xd0200661,0x00000000}},	//   _القی, rbeh_, пмый, --, 
   {{0x23b80100,0x69cdb9a9,0x212e1d86,0x94e801af}},	//   _bèje_, hiae, sbeh_, _сусҡ_, 
   {{0xdee41b74,0x1ec82f8e,0x4fe401af,0x00000000}},	//   сони, улни_, смэн_, --, 
   {{0x7a1c02e2,0x69cc030a,0x212c0455,0x80c80073}},	//   _sčto, jiae, qbeh_, _तेथे, 
   {{0x69cc00a9,0x61e80170,0xd00c01e2,0x00000000}},	//   diae, moel, _ګلو_, --, 
   {{0x61ea1d87,0x00000000,0x00000000,0x00000000}},	//   loel, --, --, --, 
   {{0x69cc4b21,0x102001d3,0x2004022e,0x76a000c0}},	//   fiae, _وکیپ, mmli_, _kšyš, 
   {{0x61ea1d88,0x69cd0b28,0x2ef80e78,0x9ca802da}},	//   noel, giae, ürfe_, _مهبل_, 
   {{0x57450ea7,0x00000000,0x00000000,0x00000000}},	// [3e120] йнаб, --, --, --, 
   {{0x61ea1d89,0x9f440129,0x63a40112,0x9aa400f2}},	//   hoel, folé_, öhnl, _همخو, 
   {{0x61ea1d8a,0x9f44b0f7,0x200400a3,0x69cc03cb}},	//   koel, golé_, imli_, biae, 
   {{0x61ea1d8b,0xfb5401d9,0x69ce1d8c,0x6ac0009e}},	//   joel, _ارکھ, ciae, _শুকো, 
   {{0x61ea1d8d,0xbd9c037e,0x7dc8002d,0x9f440100}},	//   doel, _ray化_, tűsj, polè_, 
   {{0x79861d8e,0x6ac401a8,0x75f800d0,0x200401a9}},	//   ldiw, _útfæ, cízn, jmli_, 
   {{0x61e8bb16,0xe7dc0574,0x9f461d8f,0x3ce00393}},	//   foel, _मदतप, illä_, _lxiv_, 
   {{0x61e805f5,0x75f80306,0x00000000,0x00000000}},	//   goel, mízo, --, --, 
   {{0xf4841060,0x3ce00218,0x42c404a9,0x79861d90}},	//   _بازی, _nxiv_, игән_, idiw, 
   {{0xc68c01d9,0x310400dc,0x4878008f,0x43401d5b}},	//   _تِہ_, शेषः_, נטיס, _неув, 
   {{0x61ea1d91,0xa3e42ce1,0x51861d92,0x69cc0142}},	//   boel, नवर_, _гула, yiae, 
   {{0x9f4402f6,0x604001f2,0x23b8007f,0x200401ab}},	//   ellä_, _ịmer, _vèje_, amli_, 
   {{0xac184ea5,0xdec00020,0x3ce0003a,0xb33c0003}},	//   рогу_, ስተኛ_, _cxiv_, _joħo, 
   {{0x79844d11,0x69cc00a9,0x200403e3,0x00000000}},	//   ediw, wiae, cmli_, --, 
   {{0x7f3830fb,0x75f801f1,0x69cd2132,0x7bc00200}},	//   _געוו, vízn, tiae, ëmua, 
   {{0x798422d0,0xf77001d3,0x9f440129,0x09c000cc}},	//   gdiw, ہام_, volé_, ্কভা, 
   {{0x69cc0f7b,0xb33c0135,0xbc68d712,0x1be00150}},	// [3e130] riae, _noħo, _همين_, _ﺍﻳﯩﺒ, 
   {{0x61ea1d93,0x69ccc42d,0xf7701997,0x00000000}},	//   zoel, siae, فام_, --, 
   {{0xb8f17d09,0xa634005e,0x61e800ec,0x2c20015b}},	//   _वे_, інді, yoel, _বিয়ে_, 
   {{0x4b4001d9,0x9f447c6e,0x00000000,0x00000000}},	//   _بٹھہ, rolé_, --, --, 
   {{0x3ce21d94,0x61e808f7,0x9f4420ef,0x69dc01f5}},	//   _xxiv_, voel, solé_, _ijse, 
   {{0x61e83040,0xdddc012d,0xa22801f4,0x75f81bd4}},	//   woel, _łyżw, ажка_, bízo, 
   {{0xdb0c002f,0x59c40b67,0xf3f000ae,0x00000000}},	//   chbä, रोवर, رأه_, --, 
   {{0x7ebc0241,0xe1f800d8,0x9268010a,0x00000000}},	//   _lápé, јги_, ăрла_, --, 
   {{0x61ea1d95,0x9f4402f6,0x00000000,0x00000000}},	//   roel, yllä_, --, --, 
   {{0x201000dd,0x61e801e0,0x65800014,0xb33c0003}},	//   özi_, soel, _ریڈٕ, _joħl, 
   {{0x61e93944,0xf408594c,0xb33c031c,0xae9401e1}},	//   poel, _ايلى_, _moħl, _kẹyi, 
   {{0x6d4002ea,0x1d081e2d,0x200401a9,0x00000000}},	//   ɔlak, иени_, smli_, --, 
   {{0x645c01e3,0x00000000,0x00000000,0x00000000}},	//   _åsid, --, --, --, 
   {{0x79840204,0x248c0cf4,0x69dc0841,0xb33c0327}},	//   wdiw, _mrem_, _ajse, _noħl, 
   {{0xd93823c5,0xd944010b,0x00000000,0x00000000}},	//   ичаш_, жеби, --, --, 
   {{0x3ce00b89,0x248e017f,0x75f801f1,0xe36c0150}},	//   _txiv_, _orem_, vízo, _ﺴﻤﻴﺢ_, 
   {{0x69dc002d,0x79861d96,0x26c005c7,0x1958010b}},	// [3e140] _djse, rdiw, ezho_, лаңы_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x248e1d97,0x69dc0175,0x00000000,0x00000000}},	//   _arem_, _fjse, --, --, 
   {{0x248e1d98,0x25bc003e,0x00000000,0x00000000}},	//   _brem_, ghwl_, --, --, 
   {{0x248dea84,0x044017a0,0xd40401f0,0x67280432}},	//   _crem_, дечн, ояки, _şeje, 
   {{0x248e1d99,0x522421b5,0x4390004e,0x00000000}},	//   _drem_, офиа, дашс, --, 
   {{0x248c04c4,0x00000000,0x00000000,0x00000000}},	//   _erem_, --, --, --, 
   {{0x3940617f,0x248d0721,0xc2040a2c,0x80c80406}},	//   nais_, _frem_, يقون_, _तेहे, 
   {{0x248c151c,0x7e600175,0xcf9816a4,0x00000000}},	//   _grem_, _aqnp, ајн_, --, 
   {{0x39421d9a,0xe4c800ec,0x8f0848d4,0xa3e400cd}},	//   hais_, _طبقن_, ихна_, नवः_, 
   {{0x3940367e,0x98a000b0,0x9f4404cc,0x6e9406ed}},	//   kais_, _kekē_, molì_, чину, 
   {{0x39421d9b,0xc0c4001f,0x626401ec,0xb33c031c}},	//   jais_, ችሁም_, _ءالق, _moħm, 
   {{0x39421d9c,0x50d404fb,0x7c84d112,0xad2400d1}},	//   dais_, _بزار, муре, يىھى, 
   {{0xf7d40ed1,0xca3001ec,0x00000000,0x00000000}},	//   ﺘﺎﻧﺪ, _ﺯﻩﺭ_, --, --, 
   {{0x39421d9d,0x4ea406ed,0x49c80022,0x00000000}},	//   fais_, _фрла, ауам_, --, 
   {{0x2d8400da,0x7994da45,0x00000000,0x00000000}},	//   ēles_, мисф, --, --, 
   {{0xc744007b,0xa7b80139,0xc7c4009d,0x00000000}},	// [3e150] قضاي, блау_, осжи, --, 
   {{0xc72800d6,0x249c0211,0x6d5cec93,0xae940ca8}},	//   ріал_, vxwm_, lgsa, _sẹyi, 
   {{0xfbd000b2,0x248c0114,0x6d5c0067,0x00000000}},	//   _جتي_, _srem_, ogsa, --, 
   {{0x39421d9e,0x7e98025f,0x248e1d9f,0x26c0030a}},	//   cais_, יסבו, _prem_, rzho_, 
   {{0x232a1da0,0xb33c0003,0x6d5c0009,0xf9640345}},	//   боли_, _toħl, igsa, _تۆقێ, 
   {{0x248c084c,0xbadc03d4,0x00000000,0x00000000}},	//   _vrem_, _ধৰিছ, --, --, 
   {{0x27f0014b,0x0574764c,0x00cc01ec,0x6fac03d4}},	//   _ikzn_, _وارد, _ﯗﻟﺘﻘ, টোৱে, 
   {{0x20561da1,0x248e1da2,0x6b84014f,0x6724002d}},	//   птор, _trem_, _lahg, lchj, 
   {{0xdb1c049b,0xf3ed92b9,0xc218032c,0x65780c30}},	//   _ympä, _аң_, _पूरब_, mewh, 
   {{0x6d5c0050,0x64580e1a,0x39421da3,0x672408e5}},	//   egsa, muwi, zais_, nchj, 
   {{0x6d5c074d,0x39421da4,0x645a1da5,0x29180fac}},	//   fgsa, yais_, luwi, _ogsa_, 
   {{0x62800517,0x65780374,0x71240075,0x394001d4}},	//   _islo, newh, _قىمم, xais_, 
   {{0x39421da6,0xdcb02e51,0x645a1da7,0x6b85477d}},	//   vais_, رىس_, nuwi, _bahg, 
   {{0x7e600354,0x201c1c06,0x657800b0,0x6d5c4146}},	//   _tqnp, _iuwi_, hewh, agsa, 
   {{0x39421da8,0x645964a0,0x8f980375,0x657802b5}},	//   tais_, huwi, _ליסי, kewh, 
   {{0x201c1060,0x645a1da9,0x6724045f,0x394144e4}},	//   _kuwi_, kuwi, echj, uais_, 
   {{0x57480372,0x6578013f,0x29180142,0x00000000}},	// [3e160] йзам_, dewh, _dgsa_, --, 
   {{0x39421daa,0x201c785d,0x6b840076,0x95f427c6}},	//   sais_, _muwi_, _gahg, ेष्ट_, 
   {{0x39421dab,0x645a1dac,0x9f4400db,0x62800129}},	//   pais_, euwi, jolí_, _nslo, 
   {{0x27f001f0,0x657803a2,0x2718012c,0x98680276}},	//   _ekzn_, gewh, třní_, _лимб_, 
   {{0xc95006a9,0x6458079b,0x75f80306,0x9734009d}},	//   _אמר_, guwi, lízk, _нэвч, 
   {{0x672408e5,0x9f45b6eb,0xa800014b,0x00000000}},	//   cchj, folí_, _аҷул, --, 
   {{0x201c06c8,0x6458002d,0xe7b000db,0x6d5e1dad}},	//   _auwi_, auwi, _جۅلد, ygsa, 
   {{0xcb10025f,0x645a0d2b,0x201d203e,0x247c033b}},	//   עלה_, buwi, _buwi_, _fňm_, 
   {{0x5ea800bd,0x6458020c,0x69c0547d,0x7f4c0092}},	//   _ছেলে, cuwi, रोटी, _በአፋጣ, 
   {{0x9f440306,0x201c70d4,0x6620236c,0x00000000}},	//   bolí_, _duwi_, _özkö, --, 
   {{0x20180436,0x6b840076,0xf2e80066,0x00000000}},	//   ísir_, _rahg, _بکشه_, --, 
   {{0x6b84020c,0xc0d8001f,0x6d5c0165,0x02f8010f}},	//   _sahg, ኖርም_, ugsa, _פלאמ, 
   {{0xe164143e,0x67240113,0x63100154,0x00000000}},	//   _آدمي, ychj, _স্পট_, --, 
   {{0xe8d801f2,0x6fb4065f,0x6d5c01ab,0x657802d0}},	//   ndụ_, _زمبا, sgsa, zewh, 
   {{0x645801f7,0x7f800592,0x6e9400f2,0x7aa4024c}},	//   zuwi, _سلين, _آلبا, ниёз, 
   {{0x6d5c074d,0xdcec063f,0x442c0175,0x7bdc2306}},	//   qgsa, ọrọl_, ypg_, anru, 
   {{0x6d4e1dae,0x6b84014f,0x672401f5,0xa8161daf}},	// [3e170] _idaa, _tahg, tchj, ддаш, 
   {{0x9f440589,0x00000000,0x00000000,0x00000000}},	//   molã_, --, --, --, 
   {{0x657804fe,0xf77000c6,0x6458014b,0x67242b1d}},	//   tewh, طال_, wuwi, rchj, 
   {{0xf6505167,0x64588b14,0x25a82242,0x29180c67}},	//   ائل_, tuwi, ðal_, _ugsa_, 
   {{0x657a1db0,0x6384011c,0x00000000,0x00000000}},	//   rewh, дгла, --, --, 
   {{0xe299a40b,0x64587368,0x9f440137,0x27f0014b}},	//   жак_, ruwi, tolí_, _ukzn_, 
   {{0x201c0214,0x64580134,0xb668013e,0x657800b0}},	//   _suwi_, suwi, _ниёз_, pewh, 
   {{0x64581c06,0x6d4c0694,0x9f4400cf,0xe1f03016}},	//   puwi, _ndaa, rolí_, خست_, 
   {{0x6458f063,0x7bdc0649,0x201c0309,0x7a1c007f}},	//   quwi, ynru, _quwi_, _včti, 
   {{0x6d4d1463,0x7a1c9334,0x5e480d84,0x64480064}},	//   _adaa, _hōte, опом_, _ivei, 
   {{0x6280b485,0x7a1c02b1,0xb8240c58,0x64482200}},	//   _uslo, _kōte, _পিছত_, _hvei, 
   {{0x201c0280,0x9f54006a,0xb9000135,0x644a1db1}},	//   _tuwi_, âgâo_, _སྨ_, _kvei, 
   {{0x201c22d0,0x6448014a,0x6d4c0a49,0xdb1c0005}},	//   _uuwi_, _jvei, _ddaa, _impú, 
   {{0x6d4e1db2,0x75f80118,0x00000000,0x00000000}},	//   _edaa, tízk, --, --, 
   {{0x6d4c0175,0x7bdc0267,0xe1f800c0,0x00000000}},	//   _fdaa, rnru, olų_, --, 
   {{0x3f861db3,0x7a1c02b5,0x3db80327,0xae9401e1}},	//   _hanu_, _nōte, _བཞིན, _sẹgi, 
   {{0x3f861db4,0x6448067c,0x4c6402dd,0x06a800cc}},	// [3e180] _kanu_, _nvei, _жиын_, _গেলি, 
   {{0x3f861db5,0x0900026a,0x47c800f1,0x00000000}},	//   _janu_, тпун, يالۍ_, --, 
   {{0x644a1db6,0xe1f802d5,0x6d4c0098,0x1a041d39}},	//   _avei, klų_, _ydaa, _опом, 
   {{0x3f861db7,0x31b800e8,0x9e640023,0xd8258ff1}},	//   _lanu_, _rézo_, _ጸኒሕና_, _одми, 
   {{0x7a1c00b5,0x2874010b,0x00000000,0x00000000}},	//   _dōte, _пырр, --, --, 
   {{0x3f861db8,0xc8c40014,0x00000000,0x00000000}},	//   _nanu_, _کڈہن_, --, --, 
   {{0x644a1db9,0x9f44004e,0x00000000,0x00000000}},	//   _evei, dolà_, --, --, 
   {{0x3f861dba,0xe1f80006,0x7bc00240,0xc32000d1}},	//   _aanu_, glų_, ëmuj, нмәк, 
   {{0x3015974b,0x64480007,0xe3f800ec,0x00000000}},	//   ндир, _gvei, _کولڻ_, --, 
   {{0xdb1c0137,0x3f840368,0x75f80120,0xe1f80024}},	//   _empú, _canu_, dízi, alų_, 
   {{0x3f861dbb,0x999806c8,0x03a01621,0x6448004c}},	//   _danu_, _aupō_, _шифо, _zvei, 
   {{0x3f840295,0x9e653093,0x00000000,0x00000000}},	//   _eanu_, راپن, --, --, 
   {{0x3f861dbc,0xfc640395,0xcd0400c7,0x00000000}},	//   _fanu_, кърн, ьчои, --, 
   {{0x9f461dbd,0x3f861dbe,0x60cc00ee,0x00000000}},	//   colà_, _ganu_, _ýama, --, 
   {{0x3fc8bd3a,0x00000000,0x00000000,0x00000000}},	//   _بدنی_, --, --, --, 
   {{0x23689ac0,0x3f84bc2e,0x6d4c2878,0xc0c40023}},	//   đaji_, _zanu_, _udaa, _ሽግሩ_, 
   {{0x3f861dbf,0x7a1c02b5,0xa7b82cc8,0x09c000cc}},	// [3e190] _yanu_, _rōte, плау_, ্কলা, 
   {{0xf7d408b0,0x4b440014,0x7d0130ee,0xe1f80024}},	//   ﺘﺎﻳﺪ, _زیرُ_, ümse, zlų_, 
   {{0x644a1dc0,0x7a1c02b1,0x2d8801a6,0x00000000}},	//   _svei, _pōte, _kaae_, --, 
   {{0x80b0d7bc,0x7d7c010f,0x37040798,0x00000000}},	//   ेनमे, ַנוו, тчув, --, 
   {{0x2d881132,0x23289efe,0xc86401b9,0xb46443b4}},	//   _maae_, поли_, _ўтми, ندوه, 
   {{0x9f4402ea,0x62661dc1,0x051c00eb,0x00000000}},	//   kolá_, евка, দরের_, --, 
   {{0x22161dc2,0x2b4001c7,0x9f4405d5,0x59c41cd2}},	//   нфир, _mehc_, volà_, रोकर, 
   {{0x6448394a,0x3f861dc3,0x9f4402f0,0xe7f800bc}},	//   _tvei, _sanu_, dolá_, ्गका_, 
   {{0x3f861dc4,0xe0da1dc5,0x25ac003a,0x2454009f}},	//   _panu_, яви_, _ioel_, _سناس, 
   {{0x75f8c2f1,0x25ae1dc6,0x3f859236,0x9f441132}},	//   vízi, _hoel_, _qanu_, folá_, 
   {{0x3f861dc7,0x25ac75e2,0x05d004fa,0x9f44004e}},	//   _vanu_, _koel_, _दगाब, rolà_, 
   {{0x25ac37b6,0xc0c4044e,0x3f861dc8,0x9f4400cf}},	//   _joel_, _ሽግር_, _wanu_, solà_, 
   {{0x2d8805ac,0x25ae1dc9,0x00000000,0x00000000}},	//   _daae_, _moel_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2d880607,0x2b4001c7,0xbbe035e0,0xaa6400fb}},	//   _faae_, _dehc_, _नदीक, керһ, 
   {{0x98a53ba2,0xab180816,0x271c00eb,0x00000000}},	//   нибе, ьцях_, _পড়লো_, --, 
   {{0x3dc00309,0x09e001d5,0x00000000,0x00000000}},	// [3e1a0] _iliw_, уотн, --, --, 
   {{0x7d054e22,0x00000000,0x00000000,0x00000000}},	//   _izis, --, --, --, 
   {{0xd94421fa,0x25ac96eb,0x80e00183,0x6aa00112}},	//   _пени, _boel_, _পৰম্, älft, 
   {{0x18a40a93,0x25ac0142,0x98a402e8,0x550494c9}},	//   _замм, _coel_, _зиме, нчла, 
   {{0x34bc0c00,0x98a400f0,0x00000000,0x00000000}},	//   ्छेद, _џиге, --, --, 
   {{0x3dc1fcc5,0x7d04009a,0x98a00153,0x03a21dca}},	//   _lliw_, _mzis, _sekė_, личо, 
   {{0x25adc716,0x3dc000e8,0x8230143e,0x480401af}},	//   _foel_, _oliw_, هريا, _черн_, 
   {{0x9f4402fb,0x25adcef6,0x94a80050,0x00000000}},	//   volá_, _goel_, _ٹارِ_, --, 
   {{0x7d061dcb,0x62940077,0xd37003e6,0x00000000}},	//   _nzis, _ázon, _مێشک, --, 
   {{0x3dc022d0,0x23d400c7,0x63a40112,0x2d8a1dcc}},	//   _aliw_, _ицхр, öhnt, _saae_, 
   {{0x481400c8,0xfe21007b,0x25ae1dcd,0x69c00af9}},	//   ײַזן_, льян, _yoel_, ëlek, 
   {{0x92c00e98,0x25ac0077,0x2b400036,0x3dc00142}},	//   ışın, _xoel_, _sehc_, _cliw_, 
   {{0x7d041529,0x6ad844af,0xc0d400b7,0xdfd00451}},	//   _czis, णप्र, ሬተር_, _ھيٺ_, 
   {{0x7d061dce,0xfe6c20d3,0xb9c401b9,0x00000000}},	//   _dzis, جدی_, қёси, --, 
   {{0x7d0449d6,0x7ac40108,0x00000000,0x00000000}},	//   _ezis, гсте, --, --, 
   {{0xac9400c7,0xae0401ec,0x3dc00142,0x5ea803d4}},	//   _ааиш, _جوعى, _gliw_, _ছেকে, 
   {{0x25ac5282,0x78a40117,0xe7ec0037,0x80c0000d}},	// [3e1b0] _roel_, gxiv, झवला_, ाईये, 
   {{0x25ac8e92,0x1e38001f,0x00000000,0x00000000}},	//   _soel_, _የተጠና, --, --, 
   {{0x25ac1a78,0x7d0404ba,0xdb240241,0x00000000}},	//   _poel_, _zzis, _àpát, --, 
   {{0x9f44003a,0xa4d802dd,0x6514132f,0xc98400d8}},	//   colæ_, мдеу_, نوائ, _џуни, 
   {{0x25ae033f,0xc86400d6,0xb0d06620,0x00000000}},	//   _voel_, _ятни, _तेलग, --, 
   {{0x7a1c04fe,0xfa361dcf,0x25ac0af9,0xb50800db}},	//   _hōta, _جرید, _woel_, رۉلۅ_, 
   {{0x7a1c0374,0x25acbadd,0x41cc00dc,0x344800db}},	//   _kōta, _toel_, तोऽस, _үчун_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6608511b,0x7a1c02b1,0x6008f46d,0xb92800c7}},	//   _ihek, _mōta, мним_, _pavẽ_, 
   {{0x443c05db,0x00000000,0x00000000,0x00000000}},	//   _iwu_, --, --, --, 
   {{0x660a1dd0,0x443c0395,0x09b00574,0xfe7401c6}},	//   _khek, _hwu_, ीसाठ, хүй_, 
   {{0x236804b9,0x443c01f2,0x64580b4f,0x00000000}},	//   đaju_, _kwu_, orwi, --, 
   {{0x4c821dd1,0x4f8401d9,0x38700092,0x00000000}},	//   аляв, رایہ, _አካሄዱ_, --, 
   {{0x64580099,0x9f44004e,0x1ea816ac,0x00000000}},	//   irwi, dolç_, _ياغي_, --, 
   {{0x60c80365,0x7f400007,0x6608035b,0xd9980fa2}},	//   lzem, _ienq, _ohek, ونست_, 
   {{0x443e1dd2,0x3dc00113,0x7a1c0100,0x2a90012d}},	//   _owu_, _uliw_, _sčts, _dąb_, 
   {{0x60ca1dd3,0x443e1dd4,0xdca53ba8,0x7f4003b9}},	// [3e1c0] nzem, _nwu_, _рапи, _kenq, 
   {{0x660800c7,0x7f40047e,0x47c21dd5,0x4ca800cc}},	//   _ahek, _jenq, абув, _চেকু, 
   {{0x6608016c,0x443e1dd6,0x645826be,0x7c261dd7}},	//   _bhek, _awu_, erwi, _huir, 
   {{0x660a1dd8,0x7c261dd9,0x7f40bda2,0x443c0223}},	//   _chek, _kuir, _lenq, _bwu_, 
   {{0x66080066,0x443c5cf8,0x2a900210,0x00000000}},	//   _dhek, _cwu_, _ząb_, --, 
   {{0x386006f2,0x7f421dda,0x7c261ddb,0x60ca1ddc}},	//   muir_, _nenq, _muir, dzem, 
   {{0x443cc380,0x3860dd69,0x46a21ddd,0x7c240192}},	//   _ewu_, luir_, _карв, _luir, 
   {{0x68ec8302,0x31b801d3,0x00000000,0x00000000}},	//   _ëndë, _kézi_, --, --, 
   {{0x7f421dde,0x38619409,0x443c025c,0x7c24004a}},	//   _benq, nuir_, _gwu_, _nuir, 
   {{0x61ec3306,0xca340131,0xd2b8009b,0x00000000}},	//   čala, ﮔﻪﺭ_, _оћеш_, --, 
   {{0x38621ddf,0x6fc4067c,0x51849a35,0xadd8292c}},	//   huir_, _nòce, _аула, емну_, 
   {{0x7f40009a,0x7c261de0,0x6608036e,0x93441e4a}},	//   _eenq, _buir, _xhek, _سىچۇ, 
   {{0x7c24a200,0x7f4000e8,0xdcf4013d,0x7054007b}},	//   _cuir, _fenq, _boyı, _إنتا, 
   {{0x38621de1,0x7ed004d3,0x7c25315a,0x7a1c00b0}},	//   duir_, ازیا, _duir, _rōta, 
   {{0xdb0c0e78,0x8b642a77,0x28c40107,0x49ba1de2}},	//   chbü, _یادم, ӣшаҳ, وارد_, 
   {{0x7a1c04fe,0x7c261de3,0xef18005f,0x7f402d2f}},	//   _pōta, _fuir, ceļa_, _zenq, 
   {{0x7c261de4,0x660818f7,0x7f421de5,0xa77407d5}},	// [3e1d0] _guir, _rhek, _yenq, ллач, 
   {{0x660a1de6,0x443c00ca,0xf7721de7,0x7f400327}},	//   _shek, _rwu_, قام_, _xenq, 
   {{0x60ca1de8,0x66080184,0x65941fbe,0xd7640345}},	//   zzem, _phek, лажу, انمی, 
   {{0x38621de9,0x660800fb,0x645807ab,0x81e404c5}},	//   buir_, _qhek, trwi, _মীন_, 
   {{0x645915e1,0x04650fbf,0x386087b0,0x79a4084c}},	//   urwi, ттем, cuir_, _трэе, 
   {{0x60c92777,0x660804fe,0x67d40228,0xa2e48fa3}},	//   vzem, _whek, _согу, лолд, 
   {{0xb36406bb,0x80c85b82,0x62240131,0xdb0c002f}},	//   ръчк, _तेजे, دىبل, ckbä, 
   {{0x60ca1dea,0x660807a8,0x7f404b2a,0x443c009a}},	//   tzem, _uhek, _senq, _twu_, 
   {{0x9d44052f,0x443c055a,0x7f421deb,0x60c80161}},	//   һенд, _uwu_, _penq, uzem, 
   {{0x60ca1dec,0x7f413208,0x7c2402b1,0x68fc007c}},	//   rzem, _qenq, _ruir, _mysd, 
   {{0x60ca1ded,0x7c261dee,0x98a000b0,0x68fc7fff}},	//   szem, _suir, _pekī_, _lysd, 
   {{0x7f401cdf,0x7c261def,0x9b943d93,0xdcf4008e}},	//   _wenq, _puir, گلست, _cayğ, 
   {{0xd00c3463,0x65680076,0x7f414fe9,0xdcf40139}},	//   تلی_, _mceh, _tenq, _poyı, 
   {{0x8fa02bbd,0x7c24062c,0xdcf4013d,0x98a40116}},	//   _гаше, _vuir, _qoyı, ңиве, 
   {{0x65680263,0x68fc0c8c,0xca5401c6,0x38c801d3}},	//   _oceh, _aysd, лхтө, ھاری_, 
   {{0x7c261df0,0x6fc4026c,0x23b801e1,0xb33c0135}},	//   _tuir, _vòce, _dèji_, _inħe, 
   {{0xdce404fe,0xb33c0327,0x09f4007b,0xdcf4008e}},	// [3e1e0] rekē, _moħr, افقة_, _toyı, 
   {{0xb8dc1161,0x386005d5,0x6568003e,0x00000000}},	//   _अथ_, ruir_, _aceh, --, 
   {{0x969411dc,0x4fb8010f,0x764400c7,0x00000000}},	//   ыраш, עזעצ, рҭба, --, 
   {{0xb33c0135,0x38600076,0xdb0c01e3,0x00000000}},	//   _noħr, puir_, rkbä, --, 
   {{0x7a1c0374,0x38621df1,0x68fc0432,0xdb0c01e3}},	//   _hōto, quir_, _gysd, skbä, 
   {{0x7a1c0374,0xb33c0327,0x78040166,0x00000000}},	//   _kōto, _roħs, _түза, --, 
   {{0xdb1c1e14,0x03a00063,0x61ec0427,0x64480055}},	//   _impó, сијо, čaln, _āmiś, 
   {{0xf4845b2c,0x7a1c316f,0x0fe009a0,0xd24c0050}},	//   _پاری, _mōto, өөлү, _ہۆت_, 
   {{0x6fc40ffb,0xdb1c03e0,0x937401ec,0x00000000}},	//   _nòcc, _ampü, _бұлт_, --, 
   {{0xdcf400ac,0x8f840063,0x2ef4ec41,0x6fb8009d}},	//   _sayğ, ућил, изпр, тгор_, 
   {{0xb33c0327,0xc32c0014,0x93440117,0x00000000}},	//   _foħr, _رٕن_, _анҷе, --, 
   {{0x8c34016c,0xdcf4887f,0x4f9400d1,0x1138007b}},	//   ломӣ_, _qayğ, _әрду, _أثاث_, 
   {{0x999000a2,0x00000000,0x00000000,0x00000000}},	//   mmyň_, --, --, --, 
   {{0x7b661df2,0x6e942d29,0x409000f2,0x00000000}},	//   йтсе, _вику, _دلهر, --, 
   {{0xbad804c5,0x79a4008e,0xc6bc0011,0xdcf40139}},	//   _দুবছ, әрсе, _আশ্চ, _tayğ, 
   {{0xb33c0327,0x69340958,0x999000a2,0x00000000}},	//   _moħq, рнау, nmyň_, --, 
   {{0x9fbc0210,0x00000000,0x00000000,0x00000000}},	// [3e1f0] _głów_, --, --, --, 
   {{0x39140108,0x00000000,0x00000000,0x00000000}},	//   смур, --, --, --, 
   {{0x6fc4026c,0xfc3010e5,0x0e10002b,0x00000000}},	//   _zòcc, _وحی_, _ṣṭav, --, 
   {{0x80c80183,0x68fc0183,0x645cd961,0xdb1c0798}},	//   াপত্, _tysd, _åsik, _empó, 
   {{0xb5c80214,0x00000000,0x00000000,0x00000000}},	//   دونم_, --, --, --, 
   {{0xdb1c180f,0x01e00137,0x343800f2,0x02c0004e}},	//   _impò, өйлү, اسند_, йилү, 
   {{0xd3461df3,0x7a4000d2,0xfbb80375,0x212c0115}},	//   شینه_, mátî, רפות_, tceh_, 
   {{0xaca402e3,0x05740956,0x999000a2,0x00000000}},	//   ghịz, _حاسد, gmyň_, --, 
   {{0x83640722,0x00000000,0x00000000,0x00000000}},	//   _مدال, --, --, --, 
   {{0xd00c0347,0x1fb4d47e,0xb4b415bf,0xf2c4535f}},	//   ولي_, рсир, _уйуш, рсән, 
   {{0x9fbc0034,0xb33c0003,0x5f05eb9c,0x00000000}},	//   _słów_, _toħr, рзна, --, 
   {{0xae940241,0x00000000,0x00000000,0x00000000}},	//   _tẹni, --, --, --, 
   {{0xd00c00ec,0x91b8011a,0x1dd01223,0x00000000}},	//   _ڪلو_, _שמני, दोषत, --, 
   {{0x5f780014,0x7a1e1df4,0x7a0c002f,0x06a80154}},	//   _شمعس_, _pōto, ißte, _গেছি, 
   {{0xd00cd91c,0x00000000,0x00000000,0x00000000}},	//   _تلو_, --, --, --, 
   {{0x6aa0248f,0x00000000,0x00000000,0x00000000}},	//   ålfa, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3e200] --, --, --, --, 
   {{0x23b800f2,0x7a1c02b1,0x9694ca44,0xd70407a5}},	//   _kèju_, _tōto, иреш, аззи, 
   {{0xdb1c067c,0x00000000,0x00000000,0x00000000}},	//   _empò, --, --, --, 
   {{0x7bde1df5,0x31b8043b,0x00000000,0x00000000}},	//   liru, _yézu_, --, --, 
   {{0x79861df6,0x33580166,0xd6bc0154,0x00000000}},	//   meiw, галэ_, _ইখওয, --, 
   {{0x7bde1df7,0x79861df8,0x31b8013a,0xcc38010f}},	//   niru, leiw, _lézt_, דעסט, 
   {{0x154400f5,0x8778011a,0x00000000,0x00000000}},	//   _вебм, _שאלי, --, --, 
   {{0x7bde1df9,0x79861dfa,0x454000db,0xa2980023}},	//   hiru, neiw, _ۇچۇق, ፋልካን_, 
   {{0x53a4004e,0x00000000,0x00000000,0x00000000}},	//   _кааб, --, --, --, 
   {{0x6fc400a3,0x7bde1dfb,0xa4a0067c,0x798401c7}},	//   _bòca, jiru, _çòaf, heiw, 
   {{0x7bde1dfc,0x6fc408c2,0x79840083,0x9f880241}},	//   diru, _còca, keiw, _múè_, 
   {{0xac9800b2,0x00000000,0x00000000,0x00000000}},	//   هنجا_, --, --, --, 
   {{0x7bde1dfd,0x224801a6,0xcd04009d,0x06340023}},	//   firu, ćake_, рчни, _ብዲፕሎ, 
   {{0x7bde1dfe,0x6fc401ab,0x9f8801e1,0x7ff012d3}},	//   giru, _fòca, _núè_, _وسوا, 
   {{0x0e4412cf,0xae940248,0x20180af9,0xce300345}},	//   _тэлм, _kẹmi, ïsie_, _بوبک, 
   {{0x7bdc0d04,0x39a40763,0x893408f4,0x00000000}},	//   airu, ошув, شعرا, --, 
   {{0x273c0455,0x44f00327,0x78f8007b,0x00000000}},	// [3e210] _nânâ_, _བཙེར_, لعكس_, --, 
   {{0xc60c5345,0x00000000,0x00000000,0x00000000}},	//   िष्य_, --, --, --, 
   {{0x200803f9,0x9f441132,0x6bd8028e,0x00000000}},	//   _ɗai_, tolú_, _لوکس_, --, 
   {{0x7624005e,0x79840a73,0x00000000,0x00000000}},	//   іміз, ceiw, --, --, 
   {{0xa87800c8,0xfbd01f70,0x00000000,0x00000000}},	//   _גאָר, _رتی_, --, --, 
   {{0xe290007b,0x00000000,0x00000000,0x00000000}},	//   كذب_, --, --, --, 
   {{0x64a40032,0x85540344,0xe29800b1,0x2a6401ab}},	//   раһа, _نیار_, уай_, àlbh_, 
   {{0x23d8d8a4,0x6fc491ef,0xa5fa1dff,0x00000000}},	//   _भगवद, _ròca, _себу_, --, 
   {{0xc4f8573a,0xdec8001f,0x7bde1e00,0xd5840133}},	//   _شعرا_, ጠውን_, yiru, _دێنه_, 
   {{0x248e1e01,0x6fc401c3,0xae940ca8,0x7984002f}},	//   _isem_, _pòca, _tẹli, zeiw, 
   {{0x7984009f,0x23040451,0x22944f4e,0x41e40024}},	//   yeiw, _ھڪڙي_, _دلاس, _кіда, 
   {{0x7bde1e02,0xb33c0003,0x230400ec,0x00000000}},	//   wiru, _inħa, _پڪڙي_, --, 
   {{0x248c02f8,0x7bde1e03,0x798419a2,0x7b840131}},	//   _jsem_, tiru, veiw, ياسە, 
   {{0x6fc521c5,0xb914002b,0x79840036,0x00000000}},	//   _tòca, _idaḿ_, weiw, --, 
   {{0x7984004c,0x9d461e04,0xde3536ca,0x0f34011a}},	//   teiw, _лейд, _уэль, _פרקט_, 
   {{0x7bde1569,0x248e1e05,0x3e44001f,0x5d680139}},	//   siru, _osem_, _መሰናክ, _сиим_, 
   {{0x7bdd9404,0x79861e06,0x248c0605,0x00000000}},	// [3e220] piru, reiw, _nsem_, --, 
   {{0x7bde1e07,0x4c800678,0x79840099,0xdb0c03cd}},	//   qiru, _эльв, seiw, kkbø, 
   {{0x248e1e08,0x79840099,0xdce40024,0x44f0031c}},	//   _asem_, peiw, tekė, _བཙུར_, 
   {{0xf484036b,0x0edc012d,0x00000000,0x00000000}},	//   قاتی, _फेफड, --, --, 
   {{0x39421e09,0x6ba405a4,0xdcf40313,0xe1f80165}},	//   mbis_, _útgá, _obyč, doų_, 
   {{0x39421e0a,0x00000000,0x00000000,0x00000000}},	//   lbis_, --, --, --, 
   {{0x248e1e0b,0xb0d005dc,0x00000000,0x00000000}},	//   _esem_, _तेजग, --, --, 
   {{0xb0361e0c,0x4a98008f,0xd12c0372,0xd3440517}},	//   ониш, ריקג, رۅت_, شیچه_, 
   {{0x3940007b,0x644c00f3,0x04409308,0xdb0c002f}},	//   ibis_, šair, _нетн, chbö, 
   {{0x31b805d5,0xfd7401c0,0x386000ae,0x6e540395}},	//   _pézs_, үлээ, irir_, овоф, 
   {{0x3861b494,0x39421e0d,0x2ef4ebe9,0x8778010f}},	//   hrir_, kbis_, юзор, נאטי, 
   {{0x38621e0e,0x51f400db,0x00000000,0x00000000}},	//   krir_, _اسئر, --, --, 
   {{0xa9ec0241,0x415000d4,0x00000000,0x00000000}},	//   _ìfẹ́_, _хвіс, --, --, 
   {{0x386111b1,0x39421bb0,0x2f184627,0x00000000}},	//   drir_, ebis_, _коль_, --, 
   {{0x386026b7,0x00000000,0x00000000,0x00000000}},	//   erir_, --, --, --, 
   {{0x38620f4d,0xfe34011a,0x999801ef,0xdb1403b2}},	//   frir_, _פרחי_, _kupř_, æbát, 
   {{0x386006af,0x6fac23e9,0x8724848f,0x00000000}},	// [3e230] grir_, जापू, معام, --, 
   {{0xbc387cbc,0x39421bb0,0xe75800d4,0x00000000}},	//   _اسيا_, abis_, рижі_, --, 
   {{0x38600194,0x39421e0f,0xa52000dc,0x00000000}},	//   arir_, bbis_, यश्च_, --, 
   {{0x248c0d0d,0xa5bc01ab,0x7e9800df,0x64a400c7}},	//   _psem_, _siųb, טסבו, ҩаҧа, 
   {{0x7cdc00b8,0x00000000,0x00000000,0x00000000}},	//   cārī, --, --, --, 
   {{0x69ce1e10,0x248c0fb7,0x7dd001e1,0x35680131}},	//   lhae, _vsem_, _kòsù, арән_, 
   {{0xd5ac00dd,0xe1f80165,0x7de400e5,0x00000000}},	//   رہے_, toų_, lőse, --, 
   {{0x69cc0399,0x248c01d4,0x91c00139,0x00000000}},	//   nhae, _tsem_, мәчл, --, 
   {{0x44f0025c,0x248c2852,0x69cc00b0,0x836802da}},	//   _བཙིར_, _usem_, ihae, _مصاف_, 
   {{0x69cc0007,0xae940248,0xb5ec010e,0x1e380092}},	//   hhae, _kẹhi, _üýrü, _የተገና, 
   {{0xaf98ccbc,0x657803ac,0x9f041e57,0x00000000}},	//   стых_, ofwh, تودو, --, 
   {{0x38621e11,0x69cc0399,0xbbb40764,0x62821e12}},	//   yrir_, jhae, ुस्क, _iplo, 
   {{0x61ea1e13,0xae94110e,0x9f940022,0x69cce456}},	//   mnel, _lẹhi, _ҳықә, dhae, 
   {{0x38621e14,0x69c0006a,0x39400280,0xdb1c0518}},	//   vrir_, êlen, wbis_, _alpá, 
   {{0x61e80385,0x7a1c02b5,0xab085821,0x442c0175}},	//   onel, _hōti, متفق_, hqg_, 
   {{0x38602171,0x7a1c0053,0x5f4400aa,0x628001e1}},	//   trir_, _kōti, _انګل, _mplo, 
   {{0x20400201,0x39421e15,0x20c83174,0x574873ef}},	// [3e240] _የነበረ, rbis_, िनिध, изам_, 
   {{0x7d061e16,0x61e8ec92,0x62808e0d,0x39421e17}},	//   _iyis, hnel, _oplo, sbis_, 
   {{0x62800190,0x20061e18,0x61e802d5,0xb7c00241}},	//   _nplo, illi_, knel, _aṣà, 
   {{0x98a5667e,0x1868dff0,0x38620db8,0x00000000}},	//   _диме, _ками_, prir_, --, 
   {{0x62821e19,0x61e80063,0x7a4001e1,0x20049323}},	//   _aplo, dnel, _fàtò, klli_, 
   {{0xd2591e43,0x61e96e16,0xae940241,0x62800332}},	//   аци_, enel, _fẹhi, _bplo, 
   {{0x6fc4b153,0xfe640345,0xdb1c0e78,0x644c0153}},	//   _dòcl, _تد_, _empö, šaip, 
   {{0x61e81512,0x20061e1a,0x7d05bfb1,0x6e380b4b}},	//   gnel, elli_, _oyis, _rtvb, 
   {{0x224805a1,0xdb1c315a,0x6281d594,0xf8bc07af}},	//   ćaka_, _impõ, _eplo, ोनिय, 
   {{0x61ea1e1b,0xb33c0003,0x69cc0399,0x14380023}},	//   anel, _inħo, zhae, ከኣልኩ, 
   {{0x7d061e1c,0xc9043994,0x61e8022f,0xadbc109a}},	//   _ayis, _शर्म_, bnel, ганi, 
   {{0x20061e1d,0x7d055cf3,0x10a61e1e,0x69cc0399}},	//   alli_, _byis, _миен, xhae, 
   {{0x7d040230,0x10800046,0x645c143a,0x6280013a}},	//   _cyis, ﯩﻤﺪﯨ, _åsit, _zplo, 
   {{0x7d061e1f,0x6280030d,0x06c009bd,0x69cc02b5}},	//   _dyis, _yplo, ্পতি, whae, 
   {{0x69ce1e20,0x7d04016c,0x09493ceb,0xdcac004b}},	//   thae, _eyis, ичаи_, نډی_, 
   {{0x69cc0798,0x7de401d3,0xf41000fe,0x00000000}},	//   uhae, tőse, াদিৰ_, --, 
   {{0x69ce1e21,0xef1800e2,0xa5bc0055,0xae940ca8}},	// [3e250] rhae, deļi_, _niųa, _sẹhi, 
   {{0x69ce1e22,0x7de401ed,0x61e816f6,0xd73401c0}},	//   shae, rőse, znel, зүрх_, 
   {{0x69ce1e23,0x6d4df5a4,0x858801b9,0xef1800ef}},	//   phae, _keaa, иёда_, feļi_, 
   {{0x6fc4067c,0x2b500076,0x00000000,0x00000000}},	//   _sòcl, lazc_, --, --, 
   {{0x62800f72,0x69de1e24,0x6d4c04c9,0x555046c6}},	//   _splo, _imse, _meaa, رپور, 
   {{0x6d4c2486,0x61e80175,0x62800175,0xa7b87fec}},	//   _leaa, wnel, _pplo, _улгу_, 
   {{0x7a1c0418,0xb33c0327,0xdce400b0,0xdb1c01bf}},	//   _sōti, _inħl, tekī, _elpæ, 
   {{0x7a1c04fe,0xdb1c20ef,0x6d4e1e25,0x61e85934}},	//   _pōti, _impô, _neaa, unel, 
   {{0x200400db,0x26c002f0,0xdb1c02d2,0x00000000}},	//   tlli_, lyho_, _umpö, --, 
   {{0x6d4c0093,0x7d061e26,0x20061e27,0x61e929b7}},	//   _aeaa, _ryis, ulli_, snel, 
   {{0x69de1e28,0x62821e29,0x644a1e2a,0x6d4e1e2b}},	//   _omse, _uplo, _hwei, _beaa, 
   {{0x7a1c04fe,0x64487ea0,0xf1a405f5,0xdcf400b8}},	//   _tōti, _kwei, _орчн, _abyā, 
   {{0xa0a45b7e,0x6d4c017a,0xc4b80327,0x26c00306}},	//   _халд, _deaa, མརྒྱ, hyho_, 
   {{0x69dc0cfd,0x7d041446,0x64480083,0x26c002f0}},	//   _amse, _vyis, _mwei, kyho_, 
   {{0x64480472,0xd00c00c6,0x6ee402dd,0xd94400db}},	//   _lwei, _حلو_, _يسىل, зеби, 
   {{0x64480086,0x80cc0574,0x7d044e6c,0x6d4c2494}},	//   _owei, धनपे, _tyis, _geaa, 
   {{0x7d040028,0x9f440790,0x00000000,0x00000000}},	// [3e260] _uyis, kolü_, --, --, 
   {{0x69dc5b36,0xbb5404d3,0x48000798,0x26c000d7}},	//   _emse, _زۆرب, епув, fyho_, 
   {{0x644a1e2c,0x34c40b33,0x69dc0175,0x9f4400e4}},	//   _awei, वन्द, _fmse, loló_, 
   {{0x64480086,0x00000000,0x00000000,0x00000000}},	//   _bwei, --, --, --, 
   {{0x33940006,0x6448015d,0x2d8401d3,0x00000000}},	//   далё, _cwei, őleg_, --, 
   {{0x6448282c,0x7c380e04,0x26c00419,0xa5bc00b8}},	//   _dwei, _čvrl, byho_, _viųa, 
   {{0x64480575,0x69dc015d,0x15441b0a,0x00000000}},	//   _ewei, _ymse, _невм, --, 
   {{0x9f440296,0x50640276,0x0ce400cc,0x00000000}},	//   koló_, птоа, _নৰোত, --, 
   {{0x64480f7b,0x6d4cd62e,0x05240798,0x92bc0011}},	//   _gwei, _reaa, _хоук_, ীপে_, 
   {{0x68280006,0xc68c0014,0x6d4c0076,0x7a1c0100}},	//   _užde, _جِہ_, _seaa, _včty, 
   {{0x64484124,0x7a1c0374,0x6d4e1e2d,0xfbb00882}},	//   _zwei, _hōtu, _peaa, ञानम, 
   {{0x7a1c0374,0xa2b0543b,0xdd9000f7,0x801401d9}},	//   _kōtu, _अपत्, نوپ_, _ہٲنز_, 
   {{0x4fc40a89,0xacf800d3,0x26c002f0,0xdb0c089f}},	//   _нска, інгу_, zyho_, kkbó, 
   {{0x7a1c00b0,0x920000e2,0xc01000d4,0xbc7400db}},	//   _mōtu, žādo, _зміщ, رۇپب, 
   {{0x6d4c003e,0xdb0c002f,0x00000000,0x00000000}},	//   _teaa, ckbü, --, --, 
   {{0xfe6c00c6,0x78700022,0x8d5c0092,0x3cd400cc}},	//   _صدى_, _ẽvag, ሳናቸው_, _ধুওৱ, 
   {{0xf8f4084c,0x7f7001e2,0x00000000,0x00000000}},	// [3e270] ептэ, _غږیږ, --, --, 
   {{0x6448004c,0x2d9a1e2e,0x00000000,0x00000000}},	//   _rwei, ldse_, --, --, 
   {{0x644a1e2f,0xe71800ae,0x00000000,0x00000000}},	//   _swei, آيات_, --, --, 
   {{0x69dc2935,0x2d981aa7,0xe945b97c,0xddc00276}},	//   _umse, ndse_, _تردی, mulţ, 
   {{0xef1800e2,0x2d9800a3,0x26c000d7,0x00000000}},	//   meļu_, idse_, syho_, --, 
   {{0xe3b06aff,0x26c000e4,0x72d800cd,0x00000000}},	//   ضرت_, pyho_, _śreṇ, --, 
   {{0x2214d5e9,0x9f461e30,0x973004fb,0x00000000}},	//   мфир, rolü_, _شکلا, --, 
   {{0x2d980d27,0x64480b21,0x3d0000cd,0x00000000}},	//   jdse_, _twei, रथमे_, --, 
   {{0x6448ec55,0x6fc40100,0x11d400c6,0xb9f80092}},	//   _uwei, _kòch, بوية_, _ሙዝ_, 
   {{0x2d980f49,0x9f4403a0,0x00000000,0x00000000}},	//   edse_, voló_, --, --, 
   {{0xd470069d,0xe0bc00cc,0xe13800c0,0x00000000}},	//   _ወልደጊ, ইছেন, _дзеі_, --, 
   {{0x9f461e31,0x6fc408c2,0x57b80073,0xdb0c0205}},	//   toló_, _lòch, _इव्ह, rkbü, 
   {{0x68e8041a,0x61e400d2,0xef1800e2,0x712408b0}},	//   _žedn, éhlu, deļu_, _كىمم, 
   {{0x41c00014,0x2d99e1c5,0x9f4401d3,0xdee4004e}},	//   _زٲڈِ, adse_, roló_, _ооли, 
   {{0x9f4401d3,0xc54001f3,0x091800eb,0xef180171}},	//   soló_, ከታተሉ, _ফ্লু_, feļu_, 
   {{0x9f461e32,0x98a473b5,0xf1b001f9,0x00000000}},	//   colò_, мибе, झायन, --, 
   {{0x48e026c7,0x80c800fe,0xdcf4002b,0x80c0033f}},	// [3e280] вотв, াপক্, _mayī, ाईटे, 
   {{0x2cac037e,0x9b4496d3,0xce440092,0x06dc03d4}},	//   åede_, _تندو, _የተጠቃ, _বুধি, 
   {{0x6fc40192,0xef18005f,0xddc00311,0x00000000}},	//   _dòch, beļu_, culţ, --, 
   {{0x7a1c02b1,0xe5c402bf,0xef1800e2,0x13f40073}},	//   _pōtu, нсіо, ceļu_, इव्ह_, 
   {{0xc95006a9,0x3c34007c,0x00000000,0x00000000}},	//   _שמש_, _jäv_, --, --, 
   {{0xf31401c6,0x9f880241,0xdb240cad,0x00000000}},	//   ндлэ, _núà_, _àpót, --, 
   {{0x2d980660,0x675401d9,0x92680a4a,0x64b001ec}},	//   ydse_, _سینس_, ірка_, _ەڭىر, 
   {{0xcb100302,0x6aa00158,0xe2b401c6,0x00000000}},	//   כלו_, ålfi, эсчэ, --, 
   {{0x92bc015b,0xf4b00055,0x00000000,0x00000000}},	//   ঁছে_, _kaṭī_, --, --, 
   {{0xf4b000b8,0x8d8001ec,0x06c000eb,0xb62802dd}},	//   _jaṭī_, _ﺩﻤﺸﻕ_, ্পরি, _ﺯﻭ_, 
   {{0xb8e00327,0x3ef401c4,0x00000000,0x00000000}},	//   _ཀཽ_, днээ_, --, --, 
   {{0x2d980254,0xfe244627,0xdc600241,0x00000000}},	//   udse_, кьян, _ọ́ks, --, 
   {{0x2d985bfb,0xef1800e2,0xbdd41422,0x00000000}},	//   rdse_, veļu_, тоящ, --, 
   {{0xfe6c2094,0x6fc4004e,0x6fb4004b,0xf4b00055}},	//   ددی_, _oòci, _سمبا, _naṭī_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6828010e,0x6fac0073,0x62840076,0xe7954b4f}},	//   _ažda, जावू, çhoi, کارک, 
   {{0x6fc40ba1,0xa8141b72,0x02d800cd,0x00000000}},	// [3e290] _pòch, едаш, _बध्न, --, 
   {{0x5fb00073,0x00000000,0x00000000,0x00000000}},	//   जायल, --, --, --, 
   {{0xf771a225,0xef1800e2,0x56f0004e,0x4e10000d}},	//   شال_, peļu_, гүрс, _ठठाई_, 
   {{0x25aa1e33,0x682800a2,0xc864cb42,0xdd3003b9}},	//   ñal_, _ežda, _отги, _məşr, 
   {{0x638448d9,0x6fc40100,0x91a40051,0xdcf400b8}},	//   егла, _tòch, _giỏ_, _rayī, 
   {{0xe29a1e34,0x00000000,0x00000000,0x00000000}},	//   зак_, --, --, --, 
   {{0xf2201533,0xdd3000ac,0xc6a401d5,0x00000000}},	//   मगढ़_, _nəşr, _ўрги, --, 
   {{0x35680322,0x00000000,0x00000000,0x00000000}},	//   _орун_, --, --, --, 
   {{0x60240262,0xb0f805f5,0x60e800d4,0xd1800166}},	//   ндиа, дээх_, ямим_, улый, 
   {{0x443e1e35,0x3c3401e3,0x645828dc,0x34f00139}},	//   _itu_, _räv_, mswi, _әҗәт, 
   {{0x5de61e36,0xd3e4136e,0x3c3401f4,0x00000000}},	//   ежна, _ثقلی, _säv_, --, 
   {{0x443e1e37,0x645801f5,0x326400d8,0x00000000}},	//   _ktu_, oswi, _штув, --, 
   {{0x2290107d,0xddc000ef,0x00000000,0x00000000}},	//   _hšk_, gulš, --, --, 
   {{0x443c16cb,0x645896eb,0x3c3401e3,0x00000000}},	//   _mtu_, iswi, _väv_, --, 
   {{0x64580369,0x5f0400d4,0x00000000,0x00000000}},	//   hswi, _язка, --, --, 
   {{0x443c44fc,0x17f8243c,0x229000d0,0x00000000}},	//   _otu_, ्त्व_, _mšk_, --, 
   {{0x443e1e38,0x64580196,0x6fc456ed,0xd13c0210}},	// [3e2a0] _ntu_, jswi, _sòci, _łąka_, 
   {{0x645a1e39,0x3e400020,0x090008b7,0xb9089ea0}},	//   dswi, _የተደረ, упун, _बध_, 
   {{0x443e1e3a,0x64580582,0x80c800cc,0x1c14000d}},	//   _atu_, eswi, াপট্, _दीयल_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x645806ef,0x443c037e,0xf4b00055,0x00000000}},	//   gswi, _ctu_, _taṭī_, --, 
   {{0x443c9f5c,0xa2b000dc,0xddc00118,0xb7f407af}},	//   _dtu_, _अपश्, splň, _आदिम_, 
   {{0x443c00b4,0x682802d5,0x5224016c,0x6458017a}},	//   _etu_, _užda, нфиа, aswi, 
   {{0x823128d2,0x443e1e3b,0x46280135,0xa2b009fa}},	//   دروا, _ftu_, _སྤྲས_, _अपर्, 
   {{0x443e1e3c,0x645804cc,0x00000000,0x00000000}},	//   _gtu_, cswi, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x50d400f1,0xdd0400b8,0x7de400e5,0x00000000}},	//   _ګزار, _āpāt, rősn, --, 
   {{0x443c0022,0x00000000,0x00000000,0x00000000}},	//   _ytu_, --, --, --, 
   {{0x193800b5,0xcee801b9,0x7c840395,0x00000000}},	//   _ｔｅａ_, ترکن_, луре, --, 
   {{0x20680220,0x63ac00b0,0x31b801d3,0x7f900408}},	//   _ішіп_, ēang, _nézz_, _башх, 
   {{0x499000f2,0xfc1400c7,0x6db4022e,0x00000000}},	//   هیدر, умрэ, _аййу, --, 
   {{0x3ea80306,0x6458012d,0x13bc00cd,0x00000000}},	//   šitý_, yswi, ्सुभ, --, 
   {{0x79a40124,0x00000000,0x00000000,0x00000000}},	// [3e2b0] ырре, --, --, --, 
   {{0x443e1e3d,0xeb340131,0x7798239a,0xebc401af}},	//   _rtu_, _جىدد, нкур_, _рәмн, 
   {{0x443e1e3e,0x6595a84e,0x466a1e3f,0x645a1e40}},	//   _stu_, кажу, ярам_, wswi, 
   {{0x645a1e41,0x370403b7,0x60cc0003,0x00000000}},	//   tswi, учув, _żamm, --, 
   {{0x64580036,0x443c0200,0x057400db,0xfbc80118}},	//   uswi, _qtu_, _ۋارد, _रकमम, 
   {{0x645a1e42,0xa2e400f7,0x443c00ef,0x00000000}},	//   rswi, колд, _vtu_, --, 
   {{0x6459078a,0x66f4166d,0x00000000,0x00000000}},	//   sswi, _आशिक_, --, --, 
   {{0xd24ca2f2,0x443c000d,0x1b1c015b,0xc764021f}},	//   آني_, _ttu_, বুকে_, _تاڭى, 
   {{0x443df8d3,0x25ac0276,0x00000000,0x00000000}},	//   _utu_, _inel_, --, --, 
   {{0x22900153,0x907001d5,0x4fe407ee,0x00000000}},	//   _tšk_, گهیش, кмын_, --, 
   {{0x9d44ca69,0x02a47e27,0x25ad13c5,0xa5bc0055}},	//   кенд, _ярам, _knel_, _niųk, 
   {{0x6b8401ab,0x00000000,0x00000000,0x00000000}},	//   _abhg, --, --, --, 
   {{0x7de401ed,0x5cf4034b,0xad58009d,0xa2cc00cd}},	//   sőso, тяну, эрэх_, धैर्, 
   {{0x5f061e43,0x25ac009a,0x8c40dfe7,0x6e3c01e4}},	//   _изла, _lnel_, рере, ŭrba, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x06dc0183,0xdb1c0240,0x00000000,0x00000000}},	// [3e2c0] _বুলি, _kopë, --, --, 
   {{0x25acd8b5,0x7bc80037,0x10680220,0x00000000}},	//   _anel_, ödud, _ﺳﻪﺯﯨ, --, 
   {{0xdad00116,0x00000000,0x00000000,0x00000000}},	//   _ئەزھ, --, --, --, 
   {{0xceb0159d,0x25ac00c7,0xdb1c0240,0x9f440200}},	//   ייב_, _cnel_, _lopë, filë_, 
   {{0x3a20013c,0xf38402dd,0xb38400fb,0x00000000}},	//   mmip_, лғам, лһал, --, 
   {{0x25ae1e44,0x3a20013c,0xdb1c0036,0x74140244}},	//   _enel_, lmip_, _nopë, دوتا, 
   {{0x25ac01c7,0x9f44033b,0x645c032e,0x00000000}},	//   _fnel_, milè_, _æsin, --, 
   {{0x6fc426b7,0x71783500,0x5185af84,0x9f4402e2}},	//   _lòct, хбир_, тука, lilè_, 
   {{0x142484c8,0x00000000,0x00000000,0x00000000}},	//   _адам, --, --, --, 
   {{0x0ee83f51,0xdb1c0023,0x25ac00d7,0x09bc3166}},	//   дьми_, _copë, _znel_, _एक्य, 
   {{0x932401b9,0x00000000,0x00000000,0x00000000}},	//   _شرطن, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xebc48595,0x9f4402e2,0x320400a3,0x257c01d3}},	//   гәнн, kilè_, momy_, láló_, 
   {{0x4ea61710,0xdb1c020c,0x6fc400cf,0x32061e45}},	//   _ариа, _kopè, _còct, lomy_, 
   {{0x1ae400bd,0x257dc20f,0x7f8000cf,0x7a1c02e2}},	//   _খুবই_, náló_, _ئلىن, _pōtp, 
   {{0x79680241,0xe8940108,0x00000000,0x00000000}},	//   _rèwà, лабь, --, --, 
   {{0x25ac1529,0x3834084c,0xe5a406b3,0xd7ac0490}},	// [3e2d0] _rnel_, интр, ғили, घांच, 
   {{0x25ac0460,0x9f440783,0x09bc000d,0x00000000}},	//   _snel_, vilë_, _एककठ, --, 
   {{0x32061e46,0x182801d5,0x6e2c908d,0xa75800ef}},	//   komy_, رقمی_, _kiab, _āķīg, 
   {{0x6e2e1e47,0x9f4427be,0xb33c031c,0x3204012d}},	//   _jiab, lolô_, _jaħf, jomy_, 
   {{0x69cc08cd,0x6e2e1e48,0xb33c025c,0x39e400d1}},	//   mkae, _miab, _maħf, _тәрғ, 
   {{0x6e2dac84,0x9f44003a,0xc6a43129,0x06c803d4}},	//   _liab, cilè_, _ирби, লছবি, 
   {{0xdb1d9cbd,0x69cc030a,0xf3c00055,0x257c00e5}},	//   _copè, okae, _saṃś_, gáló_, 
   {{0x6e2de415,0x9f461e49,0x25ac6115,0xb33c031c}},	//   _niab, milé_, _unel_, _naħf, 
   {{0x349578fd,0x660a1e4a,0xdb1c002e,0xf5e401af}},	//   _катр, _ikek, _popë, _тірм, 
   {{0x69cc82a9,0x942400db,0x3e400092,0x9f94022e}},	//   hkae, _موقۇ, _የተወረ, ушиш, 
   {{0x66080083,0x6e2e1e4b,0x69cc26bb,0xf0a801ec}},	//   _kkek, _biab, kkae, екөл_, 
   {{0x6e2c0395,0x00000000,0x00000000,0x00000000}},	//   _ciab, --, --, --, 
   {{0x61ea1e4c,0x660888fe,0xd12c9dc7,0x1fb005ac}},	//   miel, _mkek, _عمو_, য়োগস, 
   {{0x61ea1e4d,0x63ac03f9,0x9f4400f2,0x60ca1e4e}},	//   liel, ɓanc, kilé_, myem, 
   {{0x6608009a,0xdb1e1e4f,0xd00400a7,0x9f44020c}},	//   _okek, _kopé, _щеше_, jilé_, 
   {{0x20061e50,0x6e2c2819,0x69cc1c06,0x660a1e51}},	//   loli_, _giab, gkae, _nkek, 
   {{0x60c84828,0xdca40276,0x178401c0,0x3a221e52}},	// [3e2e0] nyem, _сапи, лгам, rmip_, 
   {{0x61ea1e53,0x20061e54,0x660a1e55,0x9f44004a}},	//   hiel, noli_, _akek, filé_, 
   {{0x60c9afc1,0x20040395,0x9f440066,0x04340023}},	//   hyem, ioli_, gilé_, _እተጻሕ, 
   {{0x20061e56,0x69ce1e57,0xdb1c0438,0x60ca1e58}},	//   holi_, ckae, _nopé, kyem, 
   {{0x9f440699,0x20061e59,0x61ea1e5a,0x60c80223}},	//   pilè_, koli_, diel, jyem, 
   {{0x660a1e5b,0x20061e5c,0x203c044e,0xc6d401c0}},	//   _ekek, joli_, _ኣሰራር, _өссө, 
   {{0x66080418,0x20040368,0x78a61e5d,0x32049337}},	//   _fkek, doli_, lviv, tomy_, 
   {{0xb3a41092,0x61e8068f,0x3f84011f,0xdb1d6106}},	//   _गोरख, giel, _abnu_, _copé, 
   {{0x6e2e1e5e,0x32061e5f,0x3ea61e60,0x60ca1e61}},	//   _riab, romy_, _arnt_, gyem, 
   {{0x20061e62,0x32042aa4,0xdb1c020c,0x6e2e1e63}},	//   goli_, somy_, _topè, _siab, 
   {{0x61ea1e64,0x6e2c003a,0x6db61e65,0x78a43110}},	//   biel, _piab, айну, hviv, 
   {{0x61ea1e66,0x60ca1e67,0x78a401e4,0x00000000}},	//   ciel, byem, kviv, --, 
   {{0x60c80230,0x1c14007d,0x3ea40129,0xdedc0023}},	//   cyem, _दीहल_, _ernt_, ሕተኛ_, 
   {{0x20040c04,0xac1800f7,0x00000000,0x00000000}},	//   coli_, тогу_, --, --, 
   {{0x6e2da6e7,0xb33c031c,0x69cd9efe,0x7985da65}},	//   _tiab, _taħf, tkae, ffiw, 
   {{0x6e2c01ab,0x2bf403d4,0x00000000,0x00000000}},	//   _uiab, ছতেই_, --, --, 
   {{0xac949891,0x0c85a766,0x69cc21c6,0x7d0001ef}},	// [3e2f0] _тапш, _сыйм, rkae, _párů, 
   {{0x61ea1e68,0xb33c003d,0xf86805d9,0x69ce1e69}},	//   ziel, _jaħd, املي_, skae, 
   {{0x2ca80122,0x60c807ab,0xb33c0003,0x0ae801c8}},	//   _hrad_, zyem, _maħd, _سردي_, 
   {{0x20061e6a,0x26f402c3,0x41a00037,0xdb0c08a5}},	//   zoli_, _आशीर_, _खोंस, _þján, 
   {{0xdb1c003e,0x2d89dcec,0x20040fc0,0x9f4400f2}},	//   _ropé, _mbae_, yoli_, silé_, 
   {{0x61e804d1,0x60ca1e6b,0x2ca80649,0x20040b6f}},	//   wiel, vyem, _mrad_, xoli_, 
   {{0x61ea1e6c,0x2ca8511b,0x291801fa,0xd5ac00aa}},	//   tiel, _lrad_, _hzsa_, _ښځه_, 
   {{0x6609d020,0x60c81085,0xa1c61e6d,0x20061e6e}},	//   _ukek, tyem, рбид, woli_, 
   {{0x20061e6f,0x2ca801d4,0x3f840263,0xa2b006ff}},	//   toli_, _nrad_, _pbnu_, _अपक्, 
   {{0x61ea1e70,0x60c9935f,0xb33c031c,0x1e852eab}},	//   siel, ryem, _caħd, алом, 
   {{0x61ea1e71,0x60c8d6a5,0x2ca8084c,0xdb1c525e}},	//   piel, syem, _arad_, _topé, 
   {{0x2004cf7b,0x9f8803b2,0xb7c4054e,0xf2c61e72}},	//   soli_, _júú_, ăţit, _усун, 
   {{0x20061e73,0x4b2003f4,0x7c3807f5,0x720420ad}},	//   poli_, _ব্লগ_, _čvrs, _اونم, 
   {{0x78a61e74,0x248c0134,0x20061e75,0x9a900092}},	//   vviv, _mpem_, qoli_, _ሜርክል_, 
   {{0x68fc020c,0x9d440220,0x798400d2,0x00000000}},	//   _axsd, _кейд, tfiw, --, 
   {{0x248c16b8,0x2ca80042,0x78a61e76,0x00000000}},	//   _opem_, _frad_, tviv, --, 
   {{0x9b461e77,0x798403cb,0x00000000,0x00000000}},	// [3e300] _پنجو, rfiw, --, --, 
   {{0x78a61e78,0xef24031c,0x7ae800f1,0xdcf4008e}},	//   rviv, _wiżż_, _موخې_, _unyı, 
   {{0x248c0134,0xa2b02a8e,0x78a401e4,0xc7ac1867}},	//   _apem_, _अपग्, sviv, ظّم_, 
   {{0xd9d008c9,0x00000000,0x00000000,0x00000000}},	//   _بەرگ, --, --, --, 
   {{0x94261e79,0x00000000,0x00000000,0x00000000}},	//   амде, --, --, --, 
   {{0x38607ea1,0x39421e7a,0x00000000,0x00000000}},	//   msir_, lcis_, --, --, 
   {{0xd5740a4a,0x394001ab,0x9f8800d7,0x38600d12}},	//   _вузь, ocis_, _fúú_, lsir_, 
   {{0x39421e7b,0xf1b00b4c,0x06dc00eb,0xdec40023}},	//   ncis_, झाइन, _বুকি, ኾነን_, 
   {{0x38621e7c,0x394171bf,0x68fc00e4,0x73c40166}},	//   nsir_, icis_, _xxsd, _гәйе, 
   {{0x38621e7d,0x4ea61e7e,0x4fc61e7f,0x9f880248}},	//   isir_, арма, рсиа, _kúù_, 
   {{0x2ca800d8,0x9f8801e1,0x073402e4,0x394001e4}},	//   _srad_, _júù_, יאים_, kcis_, 
   {{0x38613565,0xb33c038f,0x2ca8030a,0x06d80154}},	//   ksir_, _waħd, _prad_, _দশমি, 
   {{0xb33c003d,0x91a4004d,0x394001ab,0x2ca806be}},	//   _taħd, _gió_, dcis_, _qrad_, 
   {{0x394088d5,0x38600221,0xc5f00882,0xdb1c03cb}},	//   ecis_, dsir_, _अद्य_, _copï, 
   {{0x38621e80,0x00000000,0x00000000,0x00000000}},	//   esir_, --, --, --, 
   {{0x2caa1e81,0xb33c0135,0x68280064,0x00000000}},	//   _trad_, _jaħb, _iždi, --, 
   {{0x2ca825d8,0xb33c0135,0xff84004e,0x00000000}},	// [3e310] _urad_, _maħb, _сөөл_, --, 
   {{0xe8d8063f,0x07447f60,0x39400393,0xdb1c015d}},	//   laị_, рхам, acis_, _gopï, 
   {{0x6b961e82,0x248c1730,0x39400009,0x999000a2}},	//   mezg, _spem_, bcis_, klyň_, 
   {{0xd7080075,0x39400381,0xa4d80220,0x76ac01e1}},	//   دىمۇ_, ccis_, лдеу_, _e̟yo, 
   {{0x64a40aac,0xd34404d3,0x6d5c00a3,0xc5f000f1}},	//   сала, ڵینه_, iasa, مګړت, 
   {{0x6d5e1e83,0xa414045e,0xfa348d3c,0x6010022e}},	//   hasa, াদ্য_, _درید, _nаmо, 
   {{0xc290130e,0x25b80ba1,0xe81c1b57,0x48e80490}},	//   تیاب, _òslo_, _बीया_, _घेतो_, 
   {{0x6d5e1e84,0xd90c0014,0x846400a7,0x6b94036e}},	//   jasa, _آیے_, _въже, hezg, 
   {{0x60080640,0x9f461e85,0x248e1e86,0x836400db}},	//   лним_, bilì_, _upem_, _ندال, 
   {{0x1fb61e87,0x78a0006a,0x6e380455,0xe81c1df1}},	//   ссир, _âmve, _buvb, _बीमा_, 
   {{0x6d5e1e88,0x63a0409c,0xb2a801d9,0x39400393}},	//   fasa, _ialn, _پُنم_, ycis_, 
   {{0x63a21e89,0x6e383a9a,0x38621e8a,0x9f441132}},	//   _haln, _duvb, ysir_, milí_, 
   {{0x63a21e8b,0x228000dd,0xb33c0135,0x4c800064}},	//   _kaln, lók_, _waħe, пляв, 
   {{0x6d5c20ac,0x63a0054e,0x394003cb,0x6b94008e}},	//   aasa, _jaln, wcis_, gezg, 
   {{0x63a21e8c,0x228030f9,0x38600649,0x41d84ca3}},	//   _maln, nók_, wsir_, _बतास, 
   {{0x38621e8d,0x1a283b76,0x63a005da,0x6010022e}},	//   tsir_, ужби_, _laln, _zаmо, 
   {{0x6b8c0296,0x9f440418,0x9734007b,0x4dd8011a}},	// [3e320] ́ngɔ, hilí_, معاص, _תחפו, 
   {{0x63a21e8e,0x39421e8f,0x6280022e,0x79e801d3}},	//   _naln, scis_, _oqlo, _چودہ_, 
   {{0x38621e90,0xdb1c0232,0x3e6003ee,0x39400137}},	//   ssir_, _kopí, nıt_, pcis_, 
   {{0x228028c9,0xdb1c00e4,0x63a00009,0x38621e91}},	//   dók_, _jopí, _aaln, psir_, 
   {{0x7795f250,0xb6080030,0x28b8013d,0x3860571b}},	//   _ویرا, _našť, _курэ_, qsir_, 
   {{0x6d5e1e92,0x3e60825f,0x2280ba60,0x93580137}},	//   zasa, kıt_, fók_, урду_, 
   {{0x2280e183,0xb148411c,0x00000000,0x00000000}},	//   gók_, لیام_, --, --, 
   {{0x52742c1d,0x63a002d0,0x6d5e1e93,0xb33c0327}},	//   _ҳуду, _ealn, xasa, _qaħb, 
   {{0x6d5e1e94,0x6b9402ce,0x63a21e95,0xe8d80521}},	//   vasa, yezg, _faln, vaị_, 
   {{0x22801bb0,0x63a21e96,0x9f440af2,0x6e38047e}},	//   bók_, _galn, bilí_, _puvb, 
   {{0x2280011f,0xbfa4023a,0x6e38047e,0xb33c0135}},	//   cók_, стые_, _quvb, _taħb, 
   {{0x6b9402ce,0x7bc800af,0xe8d802e3,0x2bd13374}},	//   wezg, ödun, lfụ_, हस्थ, 
   {{0x63a0373d,0x6d5e1e97,0x0cd402f5,0xdb1c0f91}},	//   _yaln, rasa, সপ্ত, _dopí, 
   {{0x6d5e1e98,0x6e38014f,0x63a0058a,0x7bde1e99}},	//   sasa, _tuvb, _xaln, ghru, 
   {{0xcf24cbdb,0x6b940bd7,0x68280024,0xe8d801f2}},	//   _ارشي, rezg, _uždi, paị_, 
   {{0x6d5e1e9a,0x06dc015b,0xb7a001a9,0x601c6fca}},	//   qasa, _বুঝি, _qo壮h, rème, 
   {{0x228000dd,0x45a00131,0xc6a401c6,0x7bde1e9b}},	// [3e330] zók_, ۋەسك, өржи, bhru, 
   {{0x7bde1e9c,0x601c0100,0x00000000,0x00000000}},	//   chru, pème, --, --, 
   {{0xa9361e9d,0x06dc0183,0x2280011f,0xe69808ca}},	//   _менш, _বুজি, xók_, рвеш_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa5bc02d5,0xa87800c8,0x3e600790,0x63a00210}},	//   _siųs, _דאָר, zıt_, _paln, 
   {{0x3e602799,0x22821e9e,0x22480890,0x63a00009}},	//   yıt_, tók_, апки_, _qaln, 
   {{0x62800354,0x21741214,0x766800f1,0xdee41954}},	//   _qqlo, оупр, _هیلې_, _ምርኮ_, 
   {{0x2280d8fe,0x63a01605,0xf4080150,0xe044014b}},	//   rók_, _waln, _ۇيقى_, онии, 
   {{0x63a21e9f,0x656a1ea0,0x601c020c,0x9f4400bc}},	//   _taln, _ideh, vèmb, silí_, 
   {{0x9e64a29d,0x644a1ea1,0xdfe80107,0x24184990}},	//   овод, _itei, рдод_, _тозы_, 
   {{0xdb1c0122,0xd12c1893,0x22800548,0x4425d34c}},	//   _popí, ٹمی_, qók_, mmn_, 
   {{0x442401ab,0xe01800c5,0xe0d401af,0x920000b8}},	//   lmn_, _नीरद_, _мюль, _śāva, 
   {{0x7bde1ea2,0x44240158,0xa0680114,0x3e6003e0}},	//   thru, omn_, _ђака_, sıt_, 
   {{0x248c001f,0xe1f80024,0x64480fac,0x601c0066}},	//   _መውሰድ_, lnų_, _mtei, sèmb, 
   {{0xd00c04fb,0x3e600724,0xb33c025c,0x656800bc}},	//   _جلو_, qıt_, _jaħa, _odeh, 
   {{0x7bdc0050,0x644a1ea3,0x9f440109,0x6569662e}},	//   shru, _otei, lilà_, _ndeh, 
   {{0x57ea1ea4,0xb33c0003,0x52b462be,0x44240175}},	// [3e340] адам_, _laħa, _अप्स, kmn_, 
   {{0x656a1ea5,0x7a38010f,0xe9d80107,0xddc000c0}},	//   _adeh, _aŭte, акӣ_, kslū, 
   {{0x644a1ea6,0xb33c0003,0xe1f80153,0xd54801d5}},	//   _atei, _naħa, knų_, للاو_, 
   {{0x2a0402e3,0x00000000,0x00000000,0x00000000}},	//   ịara_, --, --, --, 
   {{0x7de401ed,0x656803cb,0x28740022,0x3dcc00fe}},	//   lőss, _ddeh, _нырр, _লগাল, 
   {{0x9268035b,0xb33c003d,0xb9d402d3,0x644800c6}},	//   ариа_, _baħa, _ኸሎ_, _dtei, 
   {{0x9f444d72,0x644a1ea7,0xcfd00150,0x2614012d}},	//   dilà_, _etei, _ﺘﺠﻨﺒ, _फीकी_, 
   {{0xb33c0003,0x644801ab,0x50641920,0x70580139}},	//   _daħa, _ftei, отоа, баир_, 
   {{0x9f4404cc,0x2b1000af,0x00000000,0x00000000}},	//   filà_, _दुनु_, --, --, 
   {{0xb62c0952,0xb33c0135,0xaf440092,0xe1f800c0}},	//   _ﮔﻪ_, _faħa, _የአመለ, anų_, 
   {{0xa2a0033f,0x656802d0,0x00000000,0x00000000}},	//   _कैप्, _ydeh, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x0fe00372,0x8fa4bb63,0xd7d80490,0x61e40036}},	//   _жөнү, _маде, णसाच, ëhle, 
   {{0x61ec01f1,0x9f440004,0x1ea80832,0x0a68004e}},	//   ďale, rilã_, _گاهي_, ирби_, 
   {{0x9f440589,0xaed401c0,0xb33c0135,0x2cac01e4}},	//   silã_, _хойш, _xaħa, ŭed_, 
   {{0xf46c001f,0xa5bc0055,0x00000000,0x00000000}},	//   ሰባሰብ_, _niųp, --, --, 
   {{0x2d9a1ea8,0x601c007f,0xa2a00456,0x7be803b2}},	// [3e350] mese_, lèma, _कैन्, øruø, 
   {{0x65680295,0x7c946ea9,0x00000000,0x00000000}},	//   _sdeh, _آشيا, --, --, 
   {{0x2d980618,0xe1f80024,0x601d35f9,0x057401d5}},	//   oese_, ynų_, nèma, قاشد, 
   {{0x1a9800c8,0x64480076,0xb33c0003,0xeb98008e}},	//   _פירע, _ptei, _raħa, _тиү_, 
   {{0x2d98f518,0xb33c0003,0x7b7401d3,0x9990010e}},	//   iese_, _saħa, _عطیا, lmyş_, 
   {{0xe0180c2e,0xe1f21ea9,0x4dc403d4,0x00000000}},	//   _नींद_, کست_, _লগোৱ, --, 
   {{0x2d9a1eaa,0x4424003a,0x601c0100,0xd1c00092}},	//   kese_, rmn_, jèma, _ድሮች_, 
   {{0x2d9a1eab,0xbbc80073,0x656801bf,0x849800ec}},	//   jese_, _रक्क, _udeh, _پئرس_, 
   {{0x2d9a1eac,0x644a1ead,0xe1f80024,0xf1a802f2}},	//   dese_, _utei, rnų_, ڕایه_, 
   {{0x33761eae,0x99980374,0x947005d9,0x2d993bd2}},	//   _огур, _pupū_, _سگها, eese_, 
   {{0x2d9a1eaf,0x68280006,0x7bc800c5,0x6d400118}},	//   fese_, _uždu, ödum, ělan, 
   {{0x2d9a1eb0,0xe3bc0729,0xef18b01b,0xdb1400bc}},	//   gese_, _অতিব, өмө_, ícíc, 
   {{0xb33c0327,0x5574008f,0x249c0142,0xe044030d}},	//   _maħn, הערן_, nwwm_, _энли, 
   {{0xdee401a9,0x2b380276,0x9f4402f0,0x00000000}},	//   _ноли, жятэ_, bilá_, --, 
   {{0x2d9a1eb1,0x8b2010d9,0x672801e4,0xa2a0033f}},	//   bese_, едре, _ŝejn, _कैम्, 
   {{0xc0e00023,0xdb1e1eb2,0x7de400e5,0x00000000}},	//   _ምልስ_, _copá, rőss, --, 
   {{0x09e111a2,0x2040001f,0xdb1c02f0,0x98a00205}},	// [3e360] хотн, _ከነበረ, _dopá, _pekı_, 
   {{0xfce407d6,0x07a00166,0x00000000,0x00000000}},	//   _ноқо, наун, --, --, 
   {{0xb33c0327,0xd5680092,0x501800d9,0xd94403c5}},	//   _baħn, _አምልኮ_, צועו, _нени, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x13a807d6,0x00000000,0x00000000,0x00000000}},	//   ینچی_, --, --, --, 
   {{0x2d980a49,0xba08001f,0xdb1c0030,0x17c969e7}},	//   zese_, _ወሬ_, _zopá, _угги_, 
   {{0x2d9a1eb3,0x6d4801c4,0x601c067c,0xbf082072}},	//   yese_, ñeak, xèma, _सुलभ_, 
   {{0x2d9a1eb4,0x7d040077,0x601c0100,0x7bc8000d}},	//   xese_, _oxis, vèma, öduj, 
   {{0x2d9a1eb5,0xf4844f6f,0x7d040023,0x920000dc}},	//   vese_, _تازی, _nxis, _śāsa, 
   {{0x2d9a1eb6,0x9f440306,0x601c02e2,0xde440014}},	//   wese_, tilá_, tèma, ڈیوو_, 
   {{0x7d040857,0x5274023b,0x00000000,0x00000000}},	//   _axis, _хузу, --, --, 
   {{0x601c033b,0x3c24007c,0x9f4403b2,0x00000000}},	//   rèma, hövd_, rilá_, --, 
   {{0x27ec0649,0x9f440270,0x41c001d9,0xdb1c00e4}},	//   _ïeng_, silá_, _سٲوِ, _ropá, 
   {{0x601c0100,0x00000000,0x00000000,0x00000000}},	//   pèma, --, --, --, 
   {{0xba0805f9,0xdb1c02fb,0x00000000,0x00000000}},	//   वकूफ_, _popá, --, --, 
   {{0x2d980240,0x14bc0825,0x2bb4002b,0x00000000}},	//   qese_, ्हाण, _ṛcā_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3e370] --, --, --, --, 
   {{0x0af005f5,0xe79497d1,0xb33c031c,0x27200154}},	//   _зүгэ, بارک, _saħn, _বলবো_, 
   {{0xdb1c01f1,0x2904012d,0x00000000,0x00000000}},	//   _topá, _ślad_, --, --, 
   {{0x7e9800c8,0xe81c033d,0xdb1c037e,0x68e800a2}},	//   מסבו, _बीरा_, _bopæ, _ýedo, 
   {{0x69de1eb7,0x2fdc01f5,0x00000000,0x00000000}},	//   _ilse, _olvg_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa22a1eb8,0xb6a40aac,0x00000000,0x00000000}},	//   ожка_, _пиёл, --, --, 
   {{0x76c4015b,0x20d400d4,0x920000cd,0xe0d800f0}},	//   _এইচএ, діос, _śāra, жви_, 
   {{0x6d4000bc,0xefdc02d3,0xb33c031c,0x5f740244}},	//   ělal, _ሒዝዎ_, _kaħl, وادر, 
   {{0x443c6fa3,0x201000d2,0xb33c031c,0x27e00051}},	//   _iuu_, ôzi_, _jaħl, nhhn_, 
   {{0x69dc271e,0x443e1eb9,0xd3e4424b,0xb33c0003}},	//   _olse, _huu_, _تقلی, _maħl, 
   {{0x443e1eba,0x645c032e,0x00000000,0x00000000}},	//   _kuu_, _æsis, --, --, 
   {{0x443e1ebb,0x00000000,0x00000000,0x00000000}},	//   _juu_, --, --, --, 
   {{0x443dab3a,0x69de1ebc,0x7a380115,0xb33c025c}},	//   _muu_, _alse, _aŭta, _naħl, 
   {{0x443e1ebd,0xfeb8034c,0xd94400db,0x80a0000d}},	//   _luu_, _داشت_, деби, _कनडे, 
   {{0x443c03a0,0x7d0401c0,0x1de000dc,0x00000000}},	//   _ouu_, _txis, _पतित, --, 
   {{0x443e1ebe,0x7d040009,0x00000000,0x00000000}},	// [3e380] _nuu_, _uxis, --, --, 
   {{0x7a380115,0x69de1ebf,0xdb1c0200,0x1ad4022e}},	//   _eŭta, _else, _nopç, _жўмр, 
   {{0x443c03a0,0xb33c0003,0x9f449226,0x3bd40139}},	//   _auu_, _daħl, milä_, _näqi_, 
   {{0x443c41c4,0x601c011c,0x63ac02a8,0x9f4401f4}},	//   _buu_, kèmo, ɓani, lilä_, 
   {{0x04401c01,0x54982be7,0x443c01fb,0xd3a40022}},	//   вечн, تضاح_, _cuu_, мҩаҧ_, 
   {{0x443e1ec0,0x439007d5,0xbb4802dd,0x9388187f}},	//   _duu_, вашс, _ﺇﻨﻪ_, ісла_, 
   {{0x443c0a73,0x645c003d,0xfe6425ef,0x00000000}},	//   _euu_, _ħsie, _جد_, --, 
   {{0x443c08f5,0x68280006,0x15e00037,0x00000000}},	//   _fuu_, _uždr, _खतिर_, --, 
   {{0x443cd578,0x9f4401f4,0x999801ef,0xc4802a9d}},	//   _guu_, kilä_, _lupů_, _илтк, 
   {{0x9358010a,0x272000eb,0x00000000,0x00000000}},	//   _фрау_, _বলতো_, --, --, 
   {{0xb33c031c,0x6d40012d,0x9f440139,0x00000000}},	//   _jaħm, ślam, dilä_, --, 
   {{0x0454044e,0x443e1ec1,0xdd900f1c,0xb33c025c}},	//   _ዝተጠቕ, _yuu_, هوپ_, _maħm, 
   {{0x7c855b43,0xb33c0327,0x3bd40139,0xdedc0023}},	//   куре, _laħm, _zäqi_, ዕተኛ_, 
   {{0x4fc43334,0x31640007,0x765c02d0,0x09d400cd}},	//   _ісла, lamz_, _owry, ठस्य, 
   {{0x49ba1ec2,0x7c34008e,0xbea0008e,0x00000000}},	//   يارد_, терх, _ашый, --, 
   {{0x69349e03,0x31640007,0x9f880321,0x00000000}},	//   енбу, namz_, _húð_, --, 
   {{0x9f44008e,0x00000000,0x00000000,0x00000000}},	// [3e390] bilä_, --, --, --, 
   {{0x443e1ec3,0x28155222,0x69dc0042,0x00000000}},	//   _ruu_, رواس, _wlse, --, 
   {{0x443e1ec4,0x3a7405f5,0xd0043cd9,0xa5bc01ab}},	//   _suu_, _илэр, _ەل_, _dhųn, 
   {{0x443c123c,0x69dc0c8c,0x6aa40857,0xe450027d}},	//   _puu_, _ulse, _ishf, هضت_, 
   {{0xb33c0003,0x443d231d,0xdb1c0205,0x99740677}},	//   _taħl, _quu_, _popç, _אתרא_, 
   {{0x2918009f,0x6b84022e,0xe28424fc,0x920000cd}},	//   _iysa_, _jchg, елки, _śāpa, 
   {{0x057404a9,0x443c41c4,0x765c03cb,0x291a1ec5}},	//   _يارد, _wuu_, _gwry, _hysa_, 
   {{0x443e1ec6,0x05b804fb,0x6d40033f,0x291801f4}},	//   _tuu_, _بدست_, ślaj, _kysa_, 
   {{0x6b8401b9,0x9f880ad9,0x9328010c,0xdb1c2ca8}},	//   _ochg, _búð_, _ትንቢታ, _topç, 
   {{0x291801e3,0x00000000,0x00000000,0x00000000}},	//   _mysa_, --, --, --, 
   {{0x02a4ab54,0x567002d3,0x2918cbaf,0xb33c025c}},	//   _юрам, _ብቐንዱ_, _lysa_, _xaħm, 
   {{0x291805d1,0x1d08c77e,0xbba8012d,0x614400ea}},	//   _oysa_, земи_, _छोड़क, _џела, 
   {{0x6aa61ec7,0xf1c807d2,0x7dd80165,0x9f44005b}},	//   _ashf, _تونى_, _hãsk, tilä_, 
   {{0x49f8025c,0xdce400e2,0x60240116,0x2b10000d}},	//   _དམུལ_, mekļ, _ядла, _दुहु_, 
   {{0x29183d20,0xb5e80248,0x5018008f,0x9f4401f4}},	//   _aysa_, _bẹ̀r, _צוצו, rilä_, 
   {{0x6b840036,0x27f00175,0x29180042,0x00000000}},	//   _echg, _amzn_, _bysa_, --, 
   {{0x48e10db5,0xdce4005f,0x6aa40857,0x9f44005b}},	// [3e3a0] готв, nekļ, _eshf, pilä_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9b340116,0x1b180154,0x00000000,0x00000000}},	//   _яхиш, _দলকে_, --, --, 
   {{0x2918015d,0xceb0011a,0x660000c7,0xda6400ec}},	//   _fysa_, טיב_, аҿса, _ٺاھي, 
   {{0xfba4547d,0x00000000,0x00000000,0x00000000}},	//   _ओसाम, --, --, --, 
   {{0xdb1c014a,0xd258b6c2,0xdce400e2,0x00000000}},	//   _topä, пци_, dekļ, --, 
   {{0xd67400ec,0x00000000,0x00000000,0x00000000}},	//   _سڄاڻ_, --, --, --, 
   {{0xd774113e,0xd5b00127,0x9f8802d2,0x00000000}},	//   _تاڭع, _حفر_, _súð_, --, 
   {{0xb33c031c,0xb3a59e1c,0xb2740124,0x2bd05347}},	//   _jaħk, _илаһ, хкқә, _सकला, 
   {{0xb33c025c,0x4f68023a,0x7104035b,0x00000000}},	//   _maħk, чшим_, нҧҵа, --, 
   {{0x11d400d6,0x3ef401c6,0x02d4007b,0x03d408c3}},	//   _підр, енээ_, _كوكب_, _רובם_, 
   {{0x6b843eb9,0x67280115,0xc69008d8,0xe1ec0451}},	//   _schg, _ŝejk, נאר_, _وڳي_, 
   {{0x7a3804ac,0xc20c0050,0xdce4005f,0x91a4004d}},	//   _aŭto, _أن_, cekļ, _nhỏ_, 
   {{0x29180022,0x00000000,0x00000000,0x00000000}},	//   _rysa_, --, --, --, 
   {{0xbea00b3e,0x50a000d1,0x8ad40137,0x00000000}},	//   _бајк, _شەھل, رتسئ, --, 
   {{0xfe6c2a29,0x60e403e3,0x00000000,0x00000000}},	//   _ادو_, _ötmü, --, --, 
   {{0x6d4e1ec8,0xa9a404a9,0xa31c00e1,0x00000000}},	// [3e3b0] _ifaa, ниңд, _फर्ज_, --, 
   {{0xb33c025c,0x6b8401d5,0x39141d5e,0x601c007f}},	//   _daħk, _uchg, умур, yèmm, 
   {{0xf77018a5,0xdce400e2,0x6aa4035a,0xc4c41e4b}},	//   صال_, zekļ, _ushf, کتاو, 
   {{0x7bc8000d,0x00000000,0x00000000,0x00000000}},	//   öduv, --, --, --, 
   {{0x25a800d0,0xc5f000f1,0x2edc00cd,0x00000000}},	//   ľal_, نګړت, मनुत, --, 
   {{0x25aa1ec9,0x58f4011a,0x00000000,0x00000000}},	//   žal_, _יצרן_, --, --, 
   {{0x6d4e1eca,0xfbb802e4,0x00000000,0x00000000}},	//   _ofaa, תפות_, --, --, 
   {{0x6d4c1418,0x65940220,0xdce400e2,0x601c0100}},	//   _nfaa, _шабу, tekļ, rèmm, 
   {{0x3c24049f,0x80d8012d,0x00000000,0x00000000}},	//   höva_, यनें, --, --, 
   {{0xd00c0bbd,0x6d4c0a4d,0x7a380115,0x5e491e06}},	//   يلي_, _afaa, _aŭtl, мпом_, 
   {{0x13e80150,0xf0880244,0x00000000,0x00000000}},	//   _تولۋ_, وئیه_, --, --, 
   {{0x3c24007c,0x00000000,0x00000000,0x00000000}},	//   döva_, --, --, --, 
   {{0x6d4c04e6,0x00000000,0x00000000,0x00000000}},	//   _dfaa, --, --, --, 
   {{0x6d4c6cee,0xefd00092,0x80040108,0x00000000}},	//   _efaa, ቦታው_, _ячее, --, 
   {{0xdee61ecb,0x6d4cafb9,0x63ac03f9,0xd00402dd}},	//   _шоки, _ffaa, ɓant, _шеше_, 
   {{0x3ea4123b,0xdb1c00d7,0xaea8007b,0x00000000}},	//   _isnt_, _kopú, _أطول_, --, 
   {{0xa3e0652f,0x60dc00a3,0x00000000,0x00000000}},	// [3e3c0] दसा_, ùsmh, --, --, 
   {{0x660801e4,0x3e40001f,0x99800064,0x00000000}},	//   _ĉeka, _ከተደረ, _pikų_, --, 
   {{0xc7a0008e,0xad2401d5,0xa2a0033f,0x07a00354}},	//   рихк, _لریو, _कैल्, рахн, 
   {{0xb33c031c,0x91a40208,0xd9447e09,0x00000000}},	//   _taħk, _thỏ_, _шеми, --, 
   {{0x3ea406d9,0xe5c801e2,0x00000000,0x00000000}},	//   _lsnt_, عظمه_, --, --, 
   {{0x7bde1ecc,0xdb0c00fc,0x78a42dab,0x00000000}},	//   nkru, _þjón, mwiv, --, 
   {{0x81a8015b,0xb33c0327,0x05a8033f,0x7bdc0af9}},	//   খান_, _jaħi, ज़ाखब, ikru, 
   {{0x7bdd0cd0,0x16180034,0x3804013e,0x6fa4000d}},	//   hkru, _फीचर_, _роҳҳ, _कसहू, 
   {{0x30140874,0x7bdc008c,0xc32004a9,0x53a40022}},	//   лдир, kkru, лмәк, _иааб, 
   {{0xdb1c0419,0x438000db,0x00000000,0x00000000}},	//   _dopú, _ەلەق, --, --, 
   {{0xd1861ecd,0x87780375,0x7bdc01ef,0x00000000}},	//   _алей, ואיי, dkru, --, 
   {{0x78a61ece,0xb33c0327,0x7bdc017a,0x32001574}},	//   kwiv, _naħi, ekru, _ñiy_, 
   {{0xc0e0147e,0xe81400bc,0x00000000,0x00000000}},	//   _коцк, तकमा_, --, --, 
   {{0x7bde1ecf,0x78a4045a,0xdb8c0023,0x68e8010b}},	//   gkru, dwiv, _ምዝዛም_, _ýedi, 
   {{0x8a1406c2,0x0dc800f3,0x00000000,0x00000000}},	//   نظرا, _жупи_, --, --, 
   {{0x6d4e1ed0,0x2720015b,0x7984002e,0xff040798}},	//   _ufaa, _বললো_, ggiw, _шејк_, 
   {{0xbb4076b9,0xe7b821d1,0xb9c408ca,0x00000000}},	// [3e3d0] ﻜﻪﻥ_, нгаш_, шёри, --, 
   {{0x7bde1ed1,0x79841418,0x2ca80037,0x00000000}},	//   ckru, agiw, _isad_, --, 
   {{0xb288010a,0xfc30007b,0xead401f4,0x00000000}},	//   _жаiа, _بحي_, _сонь, --, 
   {{0x78a400ca,0xdbd80139,0x00000000,0x00000000}},	//   bwiv, _eçäl, --, --, 
   {{0x2ca80175,0xa3d4026b,0x00000000,0x00000000}},	//   _jsad_, лодч, --, --, 
   {{0x240804b4,0x2054036b,0x232832b1,0x00000000}},	//   энли_, қтир, ноли_, --, 
   {{0xe298152d,0x22140bd6,0x00000000,0x00000000}},	//   хай_, лфир, --, --, 
   {{0x2ca84328,0x7bdd262b,0x5450013d,0x00000000}},	//   _osad_, zkru, швәт, --, 
   {{0x601d1e55,0x00000000,0x00000000,0x00000000}},	//   lèmi, --, --, --, 
   {{0x25ae1ed2,0x8170210e,0x7bdc0327,0x00000000}},	//   _hael_, _چناچ, xkru, --, 
   {{0xa2d61ed3,0x78a41682,0x25adad8b,0x601c004e}},	//   _حيات, zwiv, _kael_, nèmi, 
   {{0x2d88004e,0x7de400e5,0x00000000,0x00000000}},	//   _ccae_, lősz, --, --, 
   {{0x22461ed4,0x25ae1ed5,0xe1f80006,0x7bde1ed6}},	//   _hulk_, _mael_, mių_, tkru, 
   {{0xe1f84077,0x8c421ed7,0x22440198,0x25ac003a}},	//   lių_, сере, _kulk_, _lael_, 
   {{0x7bdda261,0x2caa1ed8,0x19940120,0xdce403e0}},	//   rkru, _esad_, лјар, rekı, 
   {{0xe1f84077,0x601c35fb,0x98a44ad0,0x22461ed9}},	//   nių_, dèmi, либе, _mulk_, 
   {{0x2244000f,0x37b800cc,0x7bc8000d,0x00000000}},	// [3e3e0] _lulk_, _আকবৰ, ödus, --, 
   {{0xb33c025c,0x23640037,0x7984db79,0xdaa80024}},	//   _waħi, _nelj_, sgiw, _звод_, 
   {{0xe1f80953,0x78a418f7,0x29d4003b,0xb33c0327}},	//   kių_, swiv, _påat_, _taħi, 
   {{0x25ac0f7b,0xf4841809,0x550401c0,0x09e000ee}},	//   _cael_, لاتی, лчла, _гоюн, 
   {{0x2364007f,0x25ac05c7,0x3a2001f5,0x3ae801d3}},	//   _belj_, _dael_, mlip_, _سبھی_, 
   {{0x3a221eda,0xf4340304,0x00000000,0x00000000}},	//   llip_, шелэ, --, --, 
   {{0xc5b401c0,0x601c00cf,0x25ac76b2,0x236400ef}},	//   _өртө, cèmi, _fael_, _delj_, 
   {{0x25ac0f7b,0xe1f80006,0x65c00220,0x522400fd}},	//   _gael_, gių_, _мұха, ыфла, 
   {{0x2edc7509,0x7a3801e4,0x3a20013c,0x55040024}},	//   मन्त, _aŭtk, ilip_, _спаб, 
   {{0xb4e00c2e,0x3dc00098,0x2ca81479,0x3a200194}},	//   दनी_, _aniw_, _rsad_, hlip_, 
   {{0x3a221edb,0x25ae1edc,0xe1f802d5,0xbed401c0}},	//   klip_, _yael_, bių_, гдэх_, 
   {{0xe1f80024,0x0734011a,0x3a2001ef,0x00000000}},	//   cių_, טאים_, jlip_, --, 
   {{0x3a201c06,0x224401a4,0x82100472,0x00000000}},	//   dlip_, _zulk_, _اونص, --, 
   {{0x4ea400c7,0x3a20013c,0x92c4009e,0x60dc143a}},	//   _бриа, elip_, উনী_, øsme, 
   {{0x2d880077,0x7f8010e0,0xbb4800ec,0x00000000}},	//   _tcae_, _الىن, الفن_, --, 
   {{0x66080115,0x3a221edd,0x8c00010b,0x2ca801e1}},	//   _ĉeko, glip_, рҗүл, _tsad_, 
   {{0x2caa1ede,0x25ac039a,0xb33c025c,0x00000000}},	// [3e3f0] _usad_, _rael_, _taħw, --, 
   {{0x24800201,0xe1f80024,0x601c02bd,0x6d5c002f}},	//   _የልማት_, zių_, tèmi, lbsa, 
   {{0x81a80729,0x6e2e1edf,0x6d5c0354,0x3a20003e}},	//   খাত_, _khab, obsa, blip_, 
   {{0xd7080075,0x65961e36,0x6e2c031c,0x601c033b}},	//   خىمۇ_, раду, _jhab, rèmi, 
   {{0xe1f80953,0xe3661ee0,0xdb1c0100,0x6e2e1ee1}},	//   vių_, акли, _anpè, _mhab, 
   {{0x987800c8,0x68ee1ee2,0x25ae1ee3,0x2244000d}},	//   _באשט, mzad, _wael_, _pulk_, 
   {{0xd24c15fa,0xfa361ee4,0x25ae1ee5,0x3cfc068f}},	//   ونو_, _خرید, _tael_, _लेने_, 
   {{0x6e2c006f,0xc7640e26,0x22440076,0x68ec030a}},	//   _nhab, _جاڭى, _vulk_, ozad, 
   {{0xe1f84077,0x68ec30cf,0x94241823,0xdb1c02e2}},	//   rių_, nzad, _چوقۇ, _enpè, 
   {{0xe1f80953,0x68ec0d19,0x6d5c0e78,0x645801f5}},	//   sių_, izad, ebsa, mpwi, 
   {{0x6e2e1ee6,0x6609723e,0x64580354,0xaf980962}},	//   _bhab, _kjek, lpwi, утых_, 
   {{0x6e2e1ee7,0xa159b3f8,0xe81c05f9,0x71980014}},	//   _chab, _раду_, _बीघा_, _منٔز_, 
   {{0x6e2e1ee8,0x6608044e,0x61e948eb,0x4c800801}},	//   _dhab, _mjek, mhel, оляв, 
   {{0x66081f7f,0x68ee1ee9,0x6d5e1eea,0x6e2c0857}},	//   _ljek, dzad, absa, _ehab, 
   {{0xd94400ee,0x61e801e0,0x66080588,0x6e2c9a14}},	//   иеви, ohel, _ojek, _fhab, 
   {{0x6e2c0ea3,0x61ea1eeb,0x660a1eec,0x69cc06fd}},	//   _ghab, nhel, _njek, gjae, 
  
   {{0xdca44951,0x60c92492,0x3a20010b,0x2004022e}},	// [3e400] _тапи, nxem, rlip_, onli_, 
   {{0x60c800f7,0x660801e1,0x47c0675f,0x61ea1eed}},	//   ixem, _ajek, обув, hhel, 
   {{0x61e88062,0x68ee1eee,0x22b4005f,0x66080cf4}},	//   khel, azad, _nāk_, _bjek, 
   {{0xdcf40365,0x61ea1eef,0xb33c0135,0x6e2c0240}},	//   _hayı, jhel, _maħt, _xhab, 
   {{0xdcf40ab7,0x61e85b4e,0xb4e0146b,0x68ed9ca8}},	//   _kayı, dhel, दने_, czad, 
   {{0x660a1ef0,0x3668004b,0x7e613e73,0x61e80108}},	//   _ejek, _مشرۍ_, _ownp, ehel, 
   {{0x61e81aa1,0xdcf44ba9,0x98b00365,0xdce40232}},	//   fhel, _mayı, mayı_, dakč, 
   {{0x61ea1ef1,0x66080c58,0x98b00365,0xdcf443dd}},	//   ghel, _gjek, layı_, _layı, 
   {{0x4fc5c48d,0x76400472,0x7e6002d0,0x6e2d2aa7}},	//   асна, _iimy, _awnp, _rhab, 
   {{0x6e2e1ef2,0x76400656,0x98b03535,0x09d00b7c}},	//   _shab, _himy, nayı_, _सव्य, 
   {{0x61ea1ef3,0x68ee1ef4,0x6e2e1ef5,0x91e48701}},	//   bhel, zzad, _phab, _коже, 
   {{0x6e2e1ef6,0x6d5e1ef7,0xc22001d3,0x9f4402f0}},	//   _qhab, ubsa, _وکٹو, milý_, 
   {{0x6e2c06d6,0x7640002d,0xdcf43e67,0x98b00790}},	//   _vhab, _mimy, _bayı, kayı_, 
   {{0x76400699,0xdcf41bc5,0xead40022,0xec3400c7}},	//   _limy, _cayı, богь, снгь, 
   {{0x6e2e1ef8,0xdcf4029f,0x98b02258,0x92000055}},	//   _thab, _dayı, dayı_, _śāya, 
   {{0x6e2e0b1e,0x68eca6e6,0x827400c8,0x764068d7}},	//   _uhab, tzad, יעלע_, _nimy, 
   {{0x98b00790,0x68ec05c7,0xc864004e,0x69cc01e4}},	// [3e410] fayı_, uzad, ртби, rjae, 
   {{0x6608174e,0x0af005f5,0xb33c0003,0xdcf44dd9}},	//   _sjek, _дүгэ, _jaħs, _gayı, 
   {{0xf7715a30,0x7640785d,0x660802d3,0xb33c025c}},	//   باق_, _bimy, _pjek, _maħs, 
   {{0x61ea1ef9,0x361810f5,0x764000ca,0xdcf403ee}},	//   xhel, ацію_, _cimy, _zayı, 
   {{0xdcf482aa,0x24f89b96,0x7640bd45,0x61e81aa1}},	//   _yayı, ынды_, _dimy, vhel, 
   {{0xb33c0003,0xa7e400db,0x61e81f06,0xa2e401e0}},	//   _naħs, _اكسى, whel, йолд, 
   {{0x61e93cb9,0x660a1efa,0x764002e2,0x00000000}},	//   thel, _tjek, _fimy, --, 
   {{0x6608014b,0x61e801ee,0x60c8005a,0x22b400cd}},	//   _ujek, uhel, txem, _vāk_, 
   {{0x61ea1efb,0x20d44dba,0x752001a4,0x60c8021c}},	//   rhel, сійс, _gymz, uxem, 
   {{0x61e8124c,0x65694229,0x4fe40046,0x764000ca}},	//   shel, _heeh, ймын_, _zimy, 
   {{0x656a1efc,0x66f820f0,0x76400526,0x626405a9}},	//   _keeh, ्पिक_, _yimy, _چاچق, 
   {{0xdcf471e1,0x61e8edcf,0xd12c6c9d,0x64480270}},	//   _sayı, qhel, ظمی_, _kuei, 
   {{0x65680363,0xdea000dd,0xdcf47236,0x98b00790}},	//   _meeh, _کیجی, _payı, yayı_, 
   {{0xdcf40cc1,0x656a032a,0xc180121e,0x64421efd}},	//   _qayı, _leeh, _ایکٹ, _jili, 
   {{0x64499519,0x98b01ae4,0x91a803d4,0x5e54009f}},	//   _luei, vayı_, কাৰ্, _ائتر, 
   {{0x64421efe,0x656a1eff,0x91a4004d,0xdb1c010e}},	//   _lili, _neeh, _khó_, _gopý, 
   {{0x64421f00,0xb33c0135,0x98b005d1,0x64480024}},	// [3e420] _oili, _jaħr, tayı_, _nuei, 
   {{0x64421f01,0x764119fb,0x5ba847ce,0x2fc003f9}},	//   _nili, _simy, _ском_, _ɗigo_, 
   {{0x98b00d9c,0x3cfc0034,0x46a0468b,0xda08129e}},	//   rayı_, _लेते_, захв, _ميده_, 
   {{0x64421f02,0x65680c6a,0x644a1f03,0x98b00790}},	//   _aili, _ceeh, _buei, sayı_, 
   {{0x644037ce,0x6568011f,0xf3f8f830,0x644a1f04}},	//   _bili, _deeh, аңа_, _cuei, 
   {{0x64421f05,0x64480c86,0x76400223,0xe7c801bc}},	//   _cili, _duei, _wimy, राणप, 
   {{0x64480270,0x76400280,0x6568f39e,0x92c405ac}},	//   _euei, _timy, _feeh, উন্_, 
   {{0x64421f06,0xb33c025c,0x644805d5,0x656803fa}},	//   _eili, _baħr, _fuei, _geeh, 
   {{0x644921dc,0x64413d74,0xc1b44b2c,0xc05401d3}},	//   _guei, _fili, слых_, یشیا_, 
   {{0x4fc4035b,0x656a1f07,0xdb1c0124,0x6fb53016}},	//   ссиа, _zeeh, _jopó, آمدا, 
   {{0xa3ac4ff1,0x644a1f08,0x035408a8,0xc20401b9}},	//   _औसत_, _zuei, _היבש_, شقین_, 
   {{0x6440c611,0xecc401c0,0x3c2403b9,0x00000000}},	//   _zili, ошгү, lövh_, --, 
   {{0x64421f09,0xb33c0003,0x00000000,0x00000000}},	//   _yili, _taħs, --, --, 
   {{0x64421f0a,0x66180210,0x00000000,0x00000000}},	//   _xili, zowk, --, --, 
   {{0x6df441c1,0x81a803f4,0x269c01ec,0x705405d9}},	//   _وكتا, খার_, _ءﺍﺭﺑ, _انڪا, 
   {{0xb33c031c,0x49b800e5,0x00000000,0x00000000}},	//   _jaħq, داسد_, --, --, 
   {{0x656800b0,0x42800092,0x00000000,0x00000000}},	// [3e430] _reeh, _የጭነት_, --, --, 
   {{0x6568102c,0x644a1f0b,0xb33c0135,0x00000000}},	//   _seeh, _ruei, _laħq, --, 
   {{0x64499a09,0x7a38010f,0x656a1f0c,0x2d980af9}},	//   _suei, _aŭtu, _peeh, ofse_, 
   {{0x64480607,0xa9c00137,0xe5840137,0xc5681291}},	//   _puei, _تۅرۉ, تۅرۉ_, احال_, 
   {{0x644a1f0d,0x6618842d,0x250804fb,0x656a1f0e}},	//   _quei, rowk, جرای_, _veeh, 
   {{0x64405c81,0xdce47683,0x64480ba1,0x6568058a}},	//   _qili, nakā, _vuei, _weeh, 
   {{0x64421f0f,0xd34403e6,0x02b004fa,0x65696a3b}},	//   _vili, زینه_, ंटेन, _teeh, 
   {{0x97000058,0x64421f10,0x93754977,0xe1f0ba4f}},	//   _تېمى, _wili, ббәт_, بست_, 
   {{0x64421f11,0xdce61f12,0xb33c0327,0xdb1c00e4}},	//   _tili, kakā, _daħq, _jopò, 
   {{0xe2f80046,0xdb1c03ee,0x64421f13,0x2d980af9}},	//   _кезі_, _popü, _uili, efse_, 
   {{0xb33c0327,0x33b000cf,0xdce400dc,0x00000000}},	//   _waħr, _سەير, dakā, --, 
   {{0xb33c003d,0x00000000,0x00000000,0x00000000}},	//   _taħr, --, --, --, 
   {{0xa06a1f14,0x00000000,0x00000000,0x00000000}},	//   _тала_, --, --, --, 
   {{0xdee61f15,0x8af403be,0x9f4404d4,0x2d980ea0}},	//   _моли, ğənn, riló_, afse_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x293c0952,0xdb1e1f16,0xdce40055,0x00000000}},	// [3e440] ﻟﻪﭖ_, _copò, bakā, --, 
   {{0x2cac2e11,0x5d840a98,0x07a00166,0x1bfc0037}},	//   çede_, _الکل, маун, _उगिल_, 
   {{0xd9444490,0x16a80395,0x47d000f2,0x00000000}},	//   _мени, рвеи_, بيلر, --, 
   {{0x9f440332,0x0e9800df,0x00000000,0x00000000}},	//   dhlí_, ישעל, --, --, 
   {{0xdb1e1f17,0xc45000b3,0x00000000,0x00000000}},	//   _topó, وضوع, --, --, 
   {{0xb33c031c,0xd1e8001f,0x00000000,0x00000000}},	//   _saħq, ሄዱት_, --, --, 
   {{0x9f440332,0x55e400d4,0x62a001e1,0x00000000}},	//   ghlí_, _довб, _ìwó, --, 
   {{0x82321f18,0x00000000,0x00000000,0x00000000}},	//   وريا, --, --, --, 
   {{0xdce40882,0xcfa61f19,0x7d0001a8,0x00000000}},	//   yakā, ошни, úmsl, --, 
   {{0x92000055,0x88980677,0x00000000,0x00000000}},	//   _śāda, סביי, --, --, 
   {{0xf2c401c6,0x9f440306,0xc16c00d4,0xc438011a}},	//   _хөли, chlí_, _ої_, _כתמי, 
   {{0xd13a1f1a,0x00000000,0x00000000,0x00000000}},	//   _кхл_, --, --, --, 
   {{0xdce40882,0xfd440105,0x1ee800f2,0xd0080120}},	//   takā, дэрн, لویی_, _кеде_, 
   {{0xf4d800cc,0x00000000,0x00000000,0x00000000}},	//   _দেৱব, --, --, --, 
   {{0xdce40882,0xdb0c000f,0x601c0066,0x00000000}},	//   rakā, edbâ, mèmp, --, 
   {{0xdce40318,0xbdf831ed,0x3cfc007d,0xa85408da}},	//   sakā, _وريا_, _लेवे_, зкач, 
   {{0xdce51bb0,0x00000000,0x00000000,0x00000000}},	// [3e450] pakā, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe7184706,0x00000000,0x00000000,0x00000000}},	//   حيات_, --, --, --, 
   {{0xdb1c00f7,0x45a0215c,0x00000000,0x00000000}},	//   _topò, بەرك, --, --, 
   {{0x6fbc0073,0xd5ac01d9,0x9f4006be,0x00000000}},	//   ्ञां, طہٕ_, _öhö_, --, 
   {{0x5f0c00dc,0x9f440332,0x00000000,0x00000000}},	//   डपम्_, thlí_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa0c4004b,0xdfd016a2,0x9f440332,0xdeec01f3}},	//   سيدو, فيظ_, shlí_, ጀውን_, 
   {{0x73c001af,0x00000000,0x00000000,0x00000000}},	//   _аҡша, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x44261f1b,0x5f280116,0xdca4022e,0x00000000}},	//   lln_, _қойм_, пами, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdee400d1,0x6ed8012c,0x00000000,0x00000000}},	//   _моһи, महरु, --, --, 
   {{0xdee402d3,0x4424020b,0x5f4400f1,0x98d400d4}},	// [3e460] _ዝርአ_, kln_, _بنګل, чівщ, 
   {{0xdb84d760,0xd54800f1,0x00000000,0x00000000}},	//   _эгои, څلاو_, --, --, 
   {{0x9f440051,0x00000000,0x00000000,0x00000000}},	//   nhlà_, --, --, --, 
   {{0x09e003d4,0x442402c1,0x00000000,0x00000000}},	//   নোবা, eln_, --, --, 
   {{0xf8e00037,0x08c000c0,0x00000000,0x00000000}},	//   _नथिय, _збян, --, --, 
   {{0xb9f807db,0x386047d8,0x44240042,0x00000000}},	//   _ዘሎ_, mpir_, gln_, --, 
   {{0x46a0085a,0xd628283c,0x00000000,0x00000000}},	//   _парв, _гове_, --, --, 
   {{0x70561f1c,0x920000b8,0xd3440066,0xbbb801f9}},	//   ونبا, _śāba, زیچه_, आयुक, 
   {{0x3cfcec91,0x3860061c,0xb0361f1d,0x601c0066}},	//   _लेले_, npir_, мниш, tèmp, 
   {{0xb4d82ce6,0x442402c4,0x00000000,0x00000000}},	//   ाही_, cln_, --, --, 
   {{0x3860003e,0x238800bc,0xdee40023,0x00000000}},	//   hpir_, ňují_, _ዝርኢ_, --, 
   {{0x7204036b,0x00000000,0x00000000,0x00000000}},	//   _کوچم, --, --, --, 
   {{0xdb1c0100,0x00000000,0x00000000,0x00000000}},	//   _anpà, --, --, --, 
   {{0x765e1f1e,0x2488026c,0xbb58030d,0xc2f003d4}},	//   _otry, àami_, зарх_, _চুটি_, 
   {{0x50540014,0x01ac0154,0xb4d8cc41,0x00000000}},	//   _بٔڈس_, কারদ, ाहु_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7d7c025d,0x765c033f,0x67dc00b8,0x7524031c}},	// [3e470] _הנחו, _atry, _nājñ, żizj, 
   {{0x7c94007b,0xe7040d23,0x00000000,0x00000000}},	//   _أشيا, وسای, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x63ac0198,0xbec00024,0x8b64136e,0xae1c28fe}},	//   ɓany, _žūkl, _باکم, नविन_, 
   {{0xfbd004d3,0x67dc00b8,0xdee40023,0x97300066}},	//   _شتی_, _cājñ, _ዝርኤ_, _یکما, 
   {{0xf77003e6,0xba749f6d,0xc0c40023,0x00000000}},	//   _ماف_, _تایت, _ኽፍሊ_, --, 
   {{0xe2986345,0x44247a45,0x00000000,0x00000000}},	//   цай_, rln_, --, --, 
   {{0x20541075,0x68e800ef,0xe8140118,0x00000000}},	//   мтор, _ļedj, तकका_, --, 
   {{0x442402f0,0x00000000,0x00000000,0x00000000}},	//   pln_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe7f4028a,0x78b8005f,0xceb806be,0x00000000}},	//   _इतना_, āvvi, _şərg_, --, 
   {{0x38600bcd,0x3c240267,0x7bc000e2,0x67dc00dc}},	//   ypir_, hövt_, ēmum, _yājñ, 
   {{0xd00c021a,0x5574010f,0xed34009d,0x00000000}},	//   الۍ_, וערן_, еэрэ, --, 
   {{0xd0240150,0x00000000,0x00000000,0x00000000}},	//   _قونۋ, --, --, --, 
   {{0x2cac031c,0x00000000,0x00000000,0x00000000}},	//   ħeda_, --, --, --, 
   {{0x9f44012c,0x81a8009e,0x00000000,0x00000000}},	//   chlá_, খাক_, --, --, 
   {{0x765cd03f,0xa3bc00af,0xe7c80073,0x00000000}},	// [3e480] _stry, इया_, रांप, --, 
   {{0x67dc0882,0xd708009b,0x00000000,0x00000000}},	//   _rājñ, онзе_, --, --, 
   {{0x38602165,0x46480023,0x00000000,0x00000000}},	//   spir_, _ንነገራ, --, --, 
   {{0x38600321,0x4d7800df,0x00000000,0x00000000}},	//   ppir_, ַרצע, --, --, 
   {{0xb4d84f3c,0x765c033f,0x3358084c,0x3860047e}},	//   ाहे_, _wtry, палэ_, qpir_, 
   {{0xd25821ca,0xd2a41cd0,0x00000000,0x00000000}},	//   оци_, _фiль, --, --, 
   {{0x765c3402,0x73c400fd,0x3c2401e3,0x00000000}},	//   _utry, _җәле, lövs_, --, 
   {{0x8c9c000d,0x2fc00139,0x00000000,0x00000000}},	//   _ओहलो, _şig_, --, --, 
   {{0xd370009f,0x00000000,0x00000000,0x00000000}},	//   _لهذ_, --, --, --, 
   {{0x999000ee,0x673403b2,0x6fb41bf4,0xef10004e}},	//   ylyş_, _ífjø, رمجا, лүлө, 
   {{0xb8e05078,0xb9000156,0x3c24049f,0x9f4401e7}},	//   _གན_, _ཧཝ_, hövs_, thlá_, 
   {{0xefd402d3,0x4e880092,0x2ab8013a,0x00000000}},	//   ርናዮ_, _በደረጃ_, hýbá_, --, 
   {{0xdb0e1f1f,0xeaf83f7e,0x32040210,0xd1e004b2}},	//   ndbæ, ृप्त_, mimy_, _ዝምታ_, 
   {{0x2d847bfb,0x3204012d,0x00000000,0x00000000}},	//   şle_, limy_, --, --, 
   {{0x7ed0007b,0x00000000,0x00000000,0x00000000}},	//   _لزيا, --, --, --, 
   {{0xbea405d9,0xf414015b,0x9f44023a,0x3204033f}},	//   _آهين_, িতির_, tilö_, nimy_, 
   {{0x3cb61f20,0xb4d82a09,0x6d4e1f21,0x0ae80451}},	// [3e490] _айыр, ाहो_, _igaa, _ڀرجي_, 
   {{0x6e3c6e95,0xc61453a5,0x8704d204,0xdb1c03e0}},	//   lmsb, तव्य_, وبال, _ropö, 
   {{0xf414015b,0xa5bc0055,0xdcf40055,0x9f44005b}},	//   িতার_, _akųa, _idyā, silö_, 
   {{0x35f80acb,0x7ae81347,0x00000000,0x00000000}},	//   ورند_, ødte, --, --, 
   {{0x69de1f22,0x79800428,0x320403d1,0x6e3c0158}},	//   _iose, _ômwa, dimy_, imsb, 
   {{0x850000e5,0x00000000,0x00000000,0x00000000}},	//   ٹوڈن, --, --, --, 
   {{0x69de1f23,0x6d4c0a81,0x3204012d,0xe858024c}},	//   _kose, _ogaa, fimy_, _фаҳш_, 
   {{0x6d4c73f4,0xf770066d,0xe0d90e16,0x05746cb7}},	//   _ngaa, _ماہ_, зви_, _زارد, 
   {{0x69de1f24,0x84946d20,0x2038001f,0xdedc0092}},	//   _mose, _تجزئ, _የዲሞክ, ንደን_, 
   {{0x69de1f25,0x6d4e1f26,0xc2c875e4,0xd6c401ed}},	//   _lose, _agaa, _وبال_, _تمہی, 
   {{0xde04334e,0xdee4020a,0x3204033f,0x69dc127b}},	//   епни, хони, bimy_, _oose, 
   {{0x69de1f27,0xdcf400cd,0x116801d3,0x3204033f}},	//   _nose, _adyā, _فلمی_, cimy_, 
   {{0x61e8021a,0x3a221f28,0xa0a400f7,0x6d4c0009}},	//   mkel, voip_, _чалд, _dgaa, 
   {{0x69dc003e,0x6d4e1f29,0x6e3e1f2a,0x2c3c0092}},	//   _aose, _egaa, amsb, _በቅርቡ, 
   {{0x20061f2b,0x69de1f2c,0xd00c021a,0x98c401a6}},	//   mili_, _bose, _دلو_, _đuđi_, 
   {{0x61ea1f2d,0x69de1f2e,0x6d4c0337,0x4fd000c7}},	//   nkel, _cose, _ggaa, _ажәт, 
   {{0x69dd8d1d,0x61ea1f2f,0xae1c00c5,0x1d0849c4}},	// [3e4a0] _dose, ikel, नवरन_, _хепи_, 
   {{0x61ea1f30,0x69dc005a,0x81a800fe,0x3204012d}},	//   hkel, _eose, খাট_, zimy_, 
   {{0x61e9447d,0x2c001b56,0x69de18de,0x795404d3}},	//   kkel, _түрм, _fose, _لێزا, 
   {{0x69de1f31,0x61e801a4,0x20061f32,0x9f440098}},	//   _gose, jkel, hili_, gklé_, 
   {{0x20061f33,0x61ea1f34,0x33940024,0x1cc40327}},	//   kili_, dkel, валё, ཎའི_, 
   {{0x20061f35,0x61e80af4,0xdb0c1088,0x69dc02ce}},	//   jili_, ekel, rdbæ, _zose, 
   {{0x61e8017a,0x69de1f36,0x26780166,0x8c18011a}},	//   fkel, _yose, _остэ_, הוסי, 
   {{0x61e9b13f,0x2fdc036b,0x69de1f37,0xc17002e8}},	//   gkel, _sovg_, _xose, глъщ, 
   {{0x20061f38,0x30140bd8,0xdb0c002f,0xc3200139}},	//   fili_, кдир, ldbä, кмәк, 
   {{0x20040ab7,0x61ea1f39,0x3204068f,0x60dcb240}},	//   gili_, akel, simy_, äsma, 
   {{0x3ea4030a,0x4798008f,0x5184074d,0xae1c0ce0}},	//   _cpnt_, הייס, _зула, नवलन_, 
   {{0x61ea1f3a,0xc3300375,0x00000000,0x00000000}},	//   ckel, _עוף_, --, --, 
   {{0x20061f3b,0x00000000,0x00000000,0x00000000}},	//   bili_, --, --, --, 
   {{0x7ff00150,0x21f00419,0x6e3c02d0,0xebc40022}},	//   _مسىا, _váhe_, smsb, тәин, 
   {{0x6d4c074d,0x7ee0007b,0x9f440216,0x00000000}},	//   _tgaa, _مكون, yklé_, --, 
   {{0x69de1f3c,0x6d4e0d4d,0x3cfc033d,0x09cc015b}},	//   _qose, _ugaa, _लेके_, রস্থ, 
   {{0x69de1f3d,0xdb0c002d,0xf3fc031c,0xa7b81de6}},	// [3e4b0] _vose, nebê, ྐྲོད_, млау_, 
   {{0x69ddf051,0x61e82574,0x2ca864a2,0xdb1c0419}},	//   _wose, zkel, _ipad_, _popô, 
   {{0x69dc0296,0x61ea1f3e,0x78642002,0xfd113d5d}},	//   _tose, ykel, ندەك, _نجی_, 
   {{0xa978010f,0x92000055,0x00000000,0x00000000}},	//   _קאָכ, _śāna, --, --, 
   {{0x20048b6a,0x61e800f3,0xdb1c0108,0x04644964}},	//   yili_, vkel, _enpä, хтем, 
   {{0x232838ac,0x200403be,0x9f4402fb,0xe3b21f3f}},	//   моли_, xili_, sklé_, شرت_, 
   {{0x61ea1f40,0x00000000,0x00000000,0x00000000}},	//   tkel, --, --, --, 
   {{0x20061f41,0x2ca800b5,0x67340327,0xb29806ea}},	//   wili_, _opad_, _izzj, óðað, 
   {{0xe3740124,0xf48401c4,0xa02c1954,0x00000000}},	//   _алзы, _бухн, _ስብከታ, --, 
   {{0x61e884da,0x20040618,0x3cfc00ab,0x00000000}},	//   skel, uili_, _लेगे_, --, 
   {{0x20061f42,0x2bd428e1,0x2ca9e7e4,0x61ea1f43}},	//   rili_, दाना, _apad_, pkel, 
   {{0x20061f44,0x1d08c2f3,0x00000000,0x00000000}},	//   sili_, деми_, --, --, 
   {{0x5ff41e80,0x3cfc3174,0x249c0042,0x7a0e1f45}},	//   _изду, _लेखे_, ntwm_, nşte, 
   {{0x2005a025,0x00000000,0x00000000,0x00000000}},	//   qili_, --, --, --, 
   {{0x2ca8655e,0x5b3400e5,0x00000000,0x00000000}},	//   _epad_, ئٹزر, --, --, 
   {{0x69940107,0xbf14054e,0x00000000,0x00000000}},	//   лрух, ăţăr, --, --, 
   {{0x6734038f,0x25bc0cfd,0xdb0c1141,0x00000000}},	// [3e4c0] _azzj, ddwl_, ddbå, --, 
   {{0xdb0c005c,0x99980064,0x00000000,0x00000000}},	//   edbå, _pupų_, --, --, 
   {{0xbec400de,0x4b7800df,0x00000000,0x00000000}},	//   _flīž, _קאטו, --, --, 
   {{0xb90804c5,0xdb0c0267,0x00000000,0x00000000}},	//   _বধ_, rdbä, --, --, 
   {{0x249c0175,0x00000000,0x00000000,0x00000000}},	//   gtwm_, --, --, --, 
   {{0xf314009d,0x2bd4084d,0x00000000,0x00000000}},	//   лдлэ, दाया, --, --, 
   {{0xfba4107c,0x959802dd,0xc0e00023,0x45300166}},	//   ख्यम, _отау_, _ዝልለ_, лхәт, 
   {{0xdce40153,0xa020000d,0x00000000,0x00000000}},	//   sakę, öönd, --, --, 
   {{0x52b00075,0x73c40961,0x2bd409fa,0x00000000}},	//   _چەتئ, _бәйе, दामा, --, 
   {{0x4fc4013e,0x6fb80107,0x00000000,0x00000000}},	//   тсиа, хгор_, --, --, 
   {{0x2ca80793,0xdb0c00d2,0x00000000,0x00000000}},	//   _spad_, sebê, --, --, 
   {{0x420612f9,0x248a1f46,0x0678008f,0xe2a86ea9}},	//   _инхо_, šame_, ונטל, _سامن_, 
   {{0x2a0402e3,0x50b4012a,0x0fd0010a,0x00000000}},	//   ịaka_, _अनिष, _кιан, --, 
   {{0x6e94013e,0x2f1814a3,0x999000a2,0x00000000}},	//   _бику, _поль_, lnyň_, --, 
   {{0x201a1f47,0x2bd47382,0xdedc001f,0x00000000}},	//   ésie_, दाबा, ንደኛ_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x27880184,0x6d5c01ed,0xa8161f48,0x999000a2}},	// [3e4d0] ереү_, mcsa, гдаш, inyň_, 
   {{0xd88427a1,0x6d5c00e5,0x920000dc,0x3cfc0210}},	//   اهلی, lcsa, _śāla, _लेटे_, 
   {{0xf7721f49,0xa87401ec,0x00000000,0x00000000}},	//   زال_, _әлгі, --, --, 
   {{0x6d5c01ed,0x80b419cc,0x26c401d3,0xe7f4000d}},	//   ncsa, ्टमे, _álom_, _इतवा_, 
   {{0x64a61f4a,0x00000000,0x00000000,0x00000000}},	//   уала, --, --, --, 
   {{0x6b940097,0xe2980276,0x00000000,0x00000000}},	//   ngzg, еак_, --, --, 
   {{0xdee400b7,0xa3d802ab,0x4904012c,0x28d0a71d}},	//   ዝቡን_, डॉग_, _सेतो_, समवि, 
   {{0xe1940276,0x7cd403b9,0x0584009d,0x9990010e}},	//   уркэ, _hərş, _шугм, gnyň_, 
   {{0x657889cb,0xc61c0490,0x00000000,0x00000000}},	//   mawh, यकीय_, --, --, 
   {{0x9f44007b,0xdb0c00db,0x6d5c0009,0x65780327}},	//   mhlú_, bebè, ecsa, lawh, 
   {{0x245a1f4b,0xdb0c180f,0x64a401e0,0x5f047546}},	//   _hèm_, cebè, _шаҡа, узна, 
   {{0x24580016,0xb8d0025c,0x657979b9,0x6d5c01d3}},	//   _kèm_, _ྒྱ_, nawh, gcsa, 
   {{0xec7407dd,0xf1c80150,0x2458033b,0x6e34009d}},	//   аҿы_, _جونى_, _jèm_, рхэх, 
   {{0x245a1f4c,0x657802b1,0xdb0c01c7,0x6d5e1f4d}},	//   _mèm_, hawh, lebé, acsa, 
   {{0x65780325,0x245a1f4e,0x8f980375,0x00000000}},	//   kawh, _lèm_, _ניקי, --, 
   {{0xdb0c0158,0x6578100c,0xc0d40023,0x2ba8000d}},	//   nebé, jawh, ርጣር_, _चउथा, 
   {{0xdb0c2833,0x65780369,0x245800f2,0x17c80117}},	// [3e4e0] ndbú, dawh, _nèm_, нгаи_, 
   {{0xb8dc2cd1,0x7e6000b5,0xce1000cf,0x00000000}},	//   _आन_, _ktnp, _پوۋة, --, 
   {{0x99900510,0x261401e4,0x7aec054e,0x0bb4011a}},	//   ynyň_, rĥon_, ântă, _גלים_, 
   {{0xd1d4044e,0xb8c801af,0x00000000,0x00000000}},	//   ርታት_, _иҫба_, --, --, 
   {{0x64580472,0x2eb01b61,0x438000d1,0xd404014b}},	//   gqwi, _जन्त, ڭلىق, ляки, 
   {{0x7bdc0007,0xd7f0007b,0xedd000dc,0x24580051}},	//   njru, _اكس_, _तच्छ, _dèm_, 
   {{0xfe661f4f,0x2bd4ed65,0x75840214,0x00000000}},	//   _دد_, दाता, _نیام, --, 
   {{0x245802bd,0xdb0c0d51,0xd77401ec,0xb1480133}},	//   _fèm_, gebé, _جاڭع, نیام_, 
   {{0x463800c8,0xd468016c,0x9f4400ae,0x00000000}},	//   _טעלע, _чизе_, chlú_, --, 
   {{0x52743b2b,0x21f00122,0x60cc0fcf,0x7e600175}},	//   _буду, _váha_, _šamc, _btnp, 
   {{0xdb0c09c2,0x94c8004b,0x948402dd,0xbfa4005b}},	//   bebé, _غاړې_, _шыңд, утые_, 
   {{0x86780375,0x245802bd,0x6d5c0009,0x00000000}},	//   ערכו, _yèm_, ucsa, --, 
   {{0xcd0439ba,0x6d5cb52b,0x00000000,0x00000000}},	//   учни, rcsa, --, --, 
   {{0xab9415ed,0x6d5c01ed,0x82280092,0xfe6c6646}},	//   јављ, scsa, _ስህተቶ, _کدو_, 
   {{0xf1b81d15,0xdb1c0042,0x478401ec,0x6d5c00e5}},	//   _आसान, _hapê, ғызб, pcsa, 
   {{0x8274008f,0x00000000,0x00000000,0x00000000}},	//   טעלע_, --, --, --, 
   {{0x47899a68,0xa7740063,0x6578031c,0x00000000}},	// [3e4f0] есем_, илач, vawh, --, 
   {{0x245801fb,0x657889cb,0xebc40139,0x00000000}},	//   _rèm_, wawh, _тәмн, --, 
   {{0x657a1f50,0x245835a4,0xf1c40b8f,0x9f440118}},	//   tawh, _sèm_, वयान, yklí_, 
   {{0x2458007f,0x9f4400ae,0x00000000,0x00000000}},	//   _pèm_, thlú_, --, --, 
   {{0x657a1f51,0xa878008f,0x00000000,0x00000000}},	//   rawh, _באָר, --, --, 
   {{0xdb0c00d2,0xc674007b,0x00000000,0x00000000}},	//   webé, _مطرب, --, --, 
   {{0x657804fe,0x6b84022e,0x00000000,0x00000000}},	//   pawh, _mdhg, --, --, 
   {{0x24580699,0x28c801ef,0x00000000,0x00000000}},	//   _tèm_, रिपि, --, --, 
   {{0x363401b9,0x00000000,0x00000000,0x00000000}},	//   _طرفس, --, --, --, 
   {{0x4fe44cb2,0xfe761f52,0xdb0e1f53,0x00000000}},	//   имын_, гүк_, sebé, --, 
   {{0x44255bbc,0x00000000,0x00000000,0x00000000}},	//   mon_, --, --, --, 
   {{0x44244219,0x3f8875c0,0x00000000,0x00000000}},	//   lon_, şcu_, --, --, 
   {{0x44261f54,0xdb0c0162,0x2dc401ec,0x00000000}},	//   oon_, ldbø, сқын_, --, 
   {{0x44261f55,0x1ef80597,0x28c8b1e3,0x00000000}},	//   non_, _لعبة_, रिनि, --, 
   {{0x44261f56,0xdb0c76f7,0x00000000,0x00000000}},	//   ion_, ndbø, --, --, 
   {{0x44261f57,0xdb1c044e,0x4904007d,0x9c580022}},	//   hon_, _hapë, _सेहो_, _ишоу_, 
   {{0x9754026a,0xdb1c0023,0x62800327,0x920000cd}},	// [3e500] атељ, _kapë, _lvlo, _śāka, 
   {{0x6280022e,0xdb1c0240,0xd774007b,0x3a5800e5}},	//   _ovlo, _japë, شائع, _میسج_, 
   {{0x44261f58,0x6280017a,0x1989d542,0x1dd8012d}},	//   don_, _nvlo, _ибни_, _बचात, 
   {{0xf48458ae,0x44261f59,0x26880691,0xdb0c0158}},	//   ماتی, eon_, اخلي_, ddbø, 
   {{0xf384ff58,0x62821f5a,0x00000000,0x00000000}},	//   йғам, _avlo, --, --, 
   {{0x44244d57,0xd1d4001f,0x00000000,0x00000000}},	//   gon_, ርዳት_, --, --, 
   {{0x35c4023b,0x6754006c,0x60cc031c,0x98a000c0}},	//   _лавҳ, _ایمس_, _ġama, _dyką_, 
   {{0x248a1f5b,0x44240076,0x1474210e,0x00000000}},	//   šama_, aon_, _نائج, --, 
   {{0x44261f5c,0x09e0009e,0x656c00e4,0x80740150}},	//   bon_, নোকা, ñahe, абыс_, 
   {{0x3dc00589,0x44261f5d,0x560401ec,0x8fe400d8}},	//   _aaiw_, con_, _соғұ, рцид, 
   {{0x20180228,0x8754008f,0x2bd42d6b,0x00000000}},	//   ésia_, יביג_, दासा, --, 
   {{0x10a40dbb,0x28c81223,0x1128013e,0xe1f800c0}},	//   _видн, रिमि, _июли_, chų_, 
   {{0x00d40d17,0x13a80154,0x2cac0af9,0xebc40166}},	//   _نبوت_, _গোয়, ïed_, бәнн, 
   {{0xdb1c4ccd,0x7bd800db,0x7f90010b,0x25a801e4}},	//   _kapè, _òvul, _дашх, ĵali_, 
   {{0x7ac4a29d,0x1ee8c26e,0xbfc80efb,0xfee001d5}},	//   осте, _مووی_, _جانە_, _мўъм, 
   {{0x44261f5e,0x8d7403e6,0x0d6400a7,0xf968005b}},	//   zon_, _ئاغا, _тъкм, ируй_, 
   {{0x6e2c0516,0xdb1c033b,0xd7d00490,0x26cc00b0}},	// [3e510] _ikab, _lapè, सांच, _ōeo_, 
   {{0x28c800af,0x24a4001f,0x2d98000d,0x00000000}},	//   रिबि, _ለልማት_, lgse_, --, 
   {{0x6e2c04ba,0xe9443e66,0x00000000,0x00000000}},	//   _kkab, _گردی, --, --, 
   {{0x2d9a1f5f,0xa3a84da1,0x7ae83262,0x6e2c025c}},	//   ngse_, ग्न_, ädte, _jkab, 
   {{0x6e2e1f60,0xe944b226,0x2d9808c2,0x00000000}},	//   _mkab, _دردی, igse_, --, 
   {{0x68ee1f61,0x442403cb,0x25a800cd,0x00000000}},	//   myad, uon_, _śilā_, --, 
   {{0x4425be93,0x68ee1f62,0x236800c8,0x6e2e1f63}},	//   ron_, lyad, ĝaj_, _okab, 
   {{0x6e2e1f64,0x68ec0050,0xdb1e1f65,0xdb0c353e}},	//   _nkab, oyad, _dapè, rdbø, 
   {{0x66083cda,0x44261f66,0xdb1c02d3,0x95e40137}},	//   _imek, pon_, _papë, _ايقۇ, 
   {{0x44261f67,0x62800998,0x2d98d37e,0x68ee1f68}},	//   qon_, _tvlo, egse_, iyad, 
   {{0x68ee1f69,0x2d98037e,0x28c801ad,0x5398011a}},	//   hyad, fgse_, रिडि, _תיעו, 
   {{0xa15a1f6a,0x68ee1f6b,0xc0e00023,0x00000000}},	//   _саду_, kyad, _ዝፍለ_, --, 
   {{0x66080521,0x6e2c0098,0x68edea52,0x72040345}},	//   _mmek, _dkab, jyad, _بونم, 
   {{0x68ee1f6c,0x6e2e1f6d,0x2d98bdd0,0xdb1c00c7}},	//   dyad, _ekab, agse_, _hapé, 
   {{0xa3a806e3,0x660a1f6e,0x5e940597,0xdb1c04fb}},	//   ग्य_, _omek, _العط, _kapé, 
   {{0x660801f2,0x68ec01d9,0x61b41b6e,0x7fb4000d}},	//   _nmek, fyad, _अघोष, _असुँ, 
   {{0x68ee1f6f,0x1784b8cd,0xdb1c00d2,0x1be801af}},	// [3e520] gyad, йгам, _mapé, _бдпи_, 
   {{0x660a1f70,0xdb0c02fb,0xa3a8033f,0x98a400fb}},	//   _amek, lebí, ग्म_, _һиме, 
   {{0x2bd438db,0x68ec0067,0x9b448e10,0x00000000}},	//   दारा, ayad, _دندو, --, 
   {{0x68ee1f71,0xd1d4001f,0x98a41d1c,0xdb1cbe6d}},	//   byad, ርዳታ_, _лиме, _rapè, 
   {{0x68ec0050,0xdb1c0066,0x2608000d,0x00000000}},	//   cyad, _sapè, _ागरी_, --, 
   {{0x660a1f72,0xdb1c068c,0x6d4000ac,0x00000000}},	//   _emek, _papè, əlad, --, 
   {{0x645c00d8,0x9f440118,0x21f001ef,0x00000000}},	//   _ésin, yklá_, _táhl_, --, 
   {{0xdb1d0ac7,0x3e540356,0xd6280114,0x00000000}},	//   _capé, _găti_, _собе_, --, 
   {{0xef942c04,0x705400f1,0x00000000,0x00000000}},	//   قیشد, غندا, --, --, 
   {{0x6e2c019b,0x28c832ed,0xd1c80220,0x00000000}},	//   _skab, रिति, _әлде_, --, 
   {{0x78a405a7,0x6db4dbb2,0x00000000,0x00000000}},	//   htiv, ойну, --, --, 
   {{0x68ec0a4d,0x3f8403b2,0x1218010b,0x00000000}},	//   yyad, _ednu_, _ёюжы_, --, 
   {{0x2d994893,0x68ec01d9,0xad2424ae,0x2bd400bc}},	//   rgse_, xyad, زىسى, दाला, 
   {{0x6e2c017a,0x9f4402fb,0x3174012d,0xdb1c0118}},	//   _wkab, sklá_, ńczą_, _zapé, 
   {{0x6e2c003d,0x76400334,0x7f8000cf,0xa5bc002b}},	//   _tkab, _ohmy, _ةلىن, _ikųv, 
   {{0x6e2c0bd5,0x68ec00dc,0xdb0c00d8,0x2d4c01e4}},	//   _ukab, tyad, cebí, pɾe_, 
   {{0x2d88003a,0xc8643129,0xa3a8012c,0x3ed000f7}},	// [3e530] _idae_, стби, ग्ड_, _وقۇر, 
   {{0x660a1f73,0x76400432,0x7ae80112,0x00000000}},	//   _smek, _ahmy, ädtc, --, 
   {{0x68ed5062,0x78a61f74,0xe718007b,0x00000000}},	//   syad, ativ, جيات_, --, 
   {{0xd2461f75,0xe7f40490,0xa535cf59,0x28c818cc}},	//   _زن_, _इतका_, онеч, रिदि, 
   {{0xd1261f76,0x68ec01d9,0x76400175,0xe79513e2}},	//   _آم_, qyad, _dhmy, _واسک, 
   {{0x248a1f77,0xdb1c034c,0x60cc1155,0xdb0c0118}},	//   šamo_, _sapé, _šamo, zebí, 
   {{0xd1f00201,0x4a240003,0xdb1c06ed,0xe94404fb}},	//   _ሌሎች_, _རྩོལ_, _papé, _درگی, 
   {{0x66097251,0x45a0581f,0x20540092,0x6fa00150}},	//   _umek, _رەتك, _ለዲሞክ, _ﺃﺫﺭﻋ_, 
   {{0x20180120,0x25ac003e,0xdecc0023,0x86f80154}},	//   ésio_, _ibel_, _እሞኸ_, _আশিফ_, 
   {{0x600a1f78,0x2d881c1d,0x644c0042,0x00000000}},	//   рном_, _adae_, ïaid, --, 
   {{0x94250393,0xdb1e1f79,0x64421f7a,0xa3a80b72}},	//   _بولۇ, _tapé, _ihli, ग्ण_, 
   {{0x20d410fe,0x9f44012c,0x05cc012c,0x00000000}},	//   _وقاس, chlý_, _सोमब, --, 
   {{0x64400652,0x00000000,0x00000000,0x00000000}},	//   _khli, --, --, --, 
   {{0x2d8808e7,0x60c8da30,0xda64007b,0xb7e400cc}},	//   _edae_, mvem, قاري, _মষ্ট, 
   {{0x60ca1f7b,0x25ae1f7c,0x64400042,0xdcf80214}},	//   lvem, _obel_, _mhli, _چرخش_, 
   {{0x78a61f7d,0x00000000,0x00000000,0x00000000}},	//   ttiv, --, --, --, 
   {{0x6440209c,0x78a40869,0xc0d4001f,0xdb0c002f}},	// [3e540] _ohli, utiv, ርባሉ_, ldbü, 
   {{0x6442124a,0x200803a2,0x60c80810,0x00000000}},	//   _nhli, _ïaid_, ivem, --, 
   {{0x8d900722,0xdb0c0e78,0x60c86775,0x98b80790}},	//   _علیش, ndbü, hvem, ıyız_, 
   {{0x60c80450,0xd9d031f0,0x00000000,0x00000000}},	//   kvem, _تەرگ, --, --, 
   {{0x644050c2,0x2a3401c6,0xf38800fb,0x656c0022}},	//   _bhli, _хээр, йҙай_, ñaha, 
   {{0x644150da,0x201a1f7e,0x60c8a40b,0x00000000}},	//   _chli, ésil_, dvem, --, 
   {{0x25ac0421,0x64404695,0xa2bc2677,0xa3a808e9}},	//   _fbel_, _dhli, _वैद्, ग्ध_, 
   {{0x64421f7f,0x24800092,0x00000000,0x00000000}},	//   _ehli, _ከግምት_, --, --, 
   {{0xef18005f,0x765c0009,0x64401cf8,0xd24c01d9}},	//   daļa_, _hury, _fhli, _یۆت_, 
   {{0x4ea56cdd,0xdb0c08a7,0x6442102d,0x00000000}},	//   орма, ndbó, _ghli, --, 
   {{0x51861f80,0x765c11ad,0xe3b001d9,0x386000ac}},	//   _дула, _jury, _سرٕ_, hqir_, 
   {{0x765e1f81,0x64400030,0xaff80ccb,0x90640137}},	//   _mury, _zhli, _گفتا_, _ۇنچۇ, 
   {{0x49b8328a,0xc0d4001f,0x60600220,0x765c010e}},	//   یارد_, ርባል_, _كۇيل, _lury, 
   {{0x765e1f82,0xc04db699,0x6254025c,0xdcac00f1}},	//   _oury, _іі_, _iġor, اډي_, 
   {{0x765e1f83,0x39500213,0x7e7000db,0x00000000}},	//   _nury, ənsə_, _قايئ, --, 
   {{0xdc5400f1,0x00000000,0x00000000,0x00000000}},	//   _کريک, --, --, --, 
   {{0x765d249a,0x38600472,0x6254025c,0xe8542051}},	// [3e550] _aury, gqir_, _jġor, سناد, 
   {{0x765c19f6,0x25ac015d,0x9f440332,0x00000000}},	//   _bury, _sbel_, chló_, --, 
   {{0x60c80e8a,0x765e1f84,0x60cc0327,0x06b401e2}},	//   zvem, _cury, _ġamm, تناک_, 
   {{0x765e1f85,0x64421f86,0x60c929f7,0x00000000}},	//   _dury, _shli, yvem, --, 
   {{0x644006a3,0x765e1f87,0x777c01a9,0x62540327}},	//   _phli, _eury, _ferx, _nġor, 
   {{0xdb1c007f,0x645c8607,0x777c0200,0x00000000}},	//   _inpò, _ésim, _gerx, --, 
   {{0x0584d729,0x765e1f88,0x201834fe,0x28c800e0}},	//   _муам, _gury, ésim_, रिवि, 
   {{0xd34403e6,0xc764313e,0xf1d4004e,0xa0c400ae}},	//   سینه_, _داڭى, дөшө, كيبو, 
   {{0x644003a2,0x60080212,0xd3f000f1,0x00000000}},	//   _thli, йним_, _ګړند, --, 
   {{0x60ca1f89,0x777e1f8a,0x26c40789,0x64421f8b}},	//   rvem, _xerx, _álos_, _uhli, 
   {{0xdb1c0ffb,0xbe4002d3,0x60c8107d,0x6154009f}},	//   _capì, _ባህግታ, svem, _فنائ, 
   {{0xa528031c,0x17e002dd,0x00000000,0x00000000}},	//   _སྙོག_, _ﺍﻷﺤﺯ, --, --, 
   {{0x290403b9,0xd83c00d7,0x00000000,0x00000000}},	//   _əlac_, účke_, --, --, 
   {{0xcb661f8c,0x8fa077f7,0x24bc00cc,0x00000000}},	//   заре_, _заше, _আপাহ, --, 
   {{0x34b80303,0x0f780375,0xdce402b5,0x00000000}},	//   _इन्द, _הרצל, takē, --, 
   {{0x09e06b9c,0x765c2c36,0x777d1b9c,0x09ac00cc}},	//   носн, _rury, _serx, _চোবা, 
   {{0x765e1f8d,0x777d1cea,0x15f00c70,0xdce400b0}},	// [3e560] _sury, _perx, _अकबर_, rakē, 
   {{0xa5280135,0x765e1f8e,0xa05402d3,0x00000000}},	//   _སྙེག_, _pury, _መባእታ, --, 
   {{0xdb1e1f8f,0x777cf024,0xe1bc00cd,0x00000000}},	//   _enpò, _verx, ्याघ, --, 
   {{0xa3a81d72,0x63a003ac,0xdb1c00e4,0x386001a9}},	//   ग्स_, _acln, _japí, pqir_, 
   {{0x765c07a8,0x3358084c,0x00000000,0x00000000}},	//   _wury, оалэ_, --, --, 
   {{0x765c068f,0x6734000f,0x28c80fe6,0xb5e40150}},	//   _tury, _fyzj, रिरि, _ﺍﺗﯩﺰ, 
   {{0x6734010b,0x00000000,0x00000000,0x00000000}},	//   _gyzj, --, --, --, 
   {{0xdb1c0038,0x00000000,0x00000000,0x00000000}},	//   _napí, --, --, --, 
   {{0xdcf40139,0x13e801af,0x00000000,0x00000000}},	//   _obyı, _лмай_, --, --, 
   {{0x2ef44a47,0xef1000cf,0xb288022e,0x00000000}},	//   дзор, күлө, _заpа, --, 
   {{0xdb0d2d11,0xf2c401c4,0x00000000,0x00000000}},	//   lebæ, _цөли, --, --, 
   {{0xdb1e1f90,0x5064006c,0x625401ee,0x00000000}},	//   _capí, _етка, _tšoa, --, 
   {{0xdb0c14f5,0x113800c6,0x62840306,0xc5f0011a}},	//   nebæ, _اثاث_, áhov, גדר_, 
   {{0xaa580f06,0x00000000,0x00000000,0x00000000}},	//   живу_, --, --, --, 
   {{0xdb0c00d0,0xbea00798,0x00000000,0x00000000}},	//   tebá, _зајк, --, --, 
   {{0x7d280129,0xdb0c005c,0x28c88497,0x00000000}},	//   éssé, kebæ, रिलि, --, 
   {{0xa8542f34,0xdb0e1f91,0x00000000,0x00000000}},	// [3e570] дкач, rebá, --, --, 
   {{0xdb1c0313,0xdb0c037e,0x39161f92,0x383402e8}},	//   _zapí, debæ, хмур, енур, 
   {{0x66d40592,0x651400e5,0x00000000,0x00000000}},	//   بيائ, ڈوائ, --, --, 
   {{0xa2bc07d0,0xa528025c,0xdcf400b8,0x2bd400cd}},	//   _वैष्, _སྙུག_, _heyā, दाका, 
   {{0x64a43ced,0x33f000e8,0xdb0c4c5d,0xd5ac0050}},	//   фала, _làxu_, gebæ, شہٕ_, 
   {{0x63ac3421,0x00000000,0x00000000,0x00000000}},	//   đano, --, --, --, 
   {{0xa2bd5597,0x2248255b,0xdcf40055,0xa5f8014b}},	//   _वैश्, опки_, _meyā, _деву_, 
   {{0xd00c004b,0x09ac03d4,0x290c08a5,0x00000000}},	//   یلي_, _চোতা, _þeas_, --, 
   {{0xd5a50b79,0x65680109,0xe0d8109a,0xdb1c0419}},	//   _تلقی, _ifeh, іво_, _rapí, 
   {{0xdb1c06ed,0xdcf400b8,0x00000000,0x00000000}},	//   _japã, _neyā, --, --, 
   {{0xdb1c6823,0x00000000,0x00000000,0x00000000}},	//   _papí, --, --, --, 
   {{0xa3a80b4c,0x00000000,0x00000000,0x00000000}},	//   ग्र_, --, --, --, 
   {{0x522804ac,0x00000000,0x00000000,0x00000000}},	//   _ווײַ, --, --, --, 
   {{0x26d00395,0xdb1c0140,0xb33c025c,0x9b94009f}},	//   _orzo_, _napã, _ibħr, بلست, 
   {{0xdb1c35f5,0xdcf4002b,0x00000000,0x00000000}},	//   _tapí, _deyā, --, --, 
   {{0x3a7400fd,0x00000000,0x00000000,0x00000000}},	//   мһүр, --, --, --, 
   {{0x7524038f,0x57e87927,0x7a0c0276,0x26d005c7}},	// [3e580] żizz, одам_, nşti, _arzo_, 
   {{0x26d004b9,0x65680134,0xdb1c0798,0x33f000e8}},	//   _brzo_, _afeh, _capã, _yàxu_, 
   {{0x05cc00ab,0xa2bc03ce,0x00000000,0x00000000}},	//   _सोहब, _वैल्, --, --, 
   {{0xdb1c00a3,0x74140344,0xdb0c0158,0x26d00208}},	//   _iapà, کوتا, tebæ, _drzo_, 
   {{0x79861f93,0x00000000,0x00000000,0x00000000}},	//   maiw, --, --, --, 
   {{0x65682486,0x79861f94,0xdb0c037e,0x92680124}},	//   _efeh, laiw, rebæ, ориа_, 
   {{0xc7a21f95,0x07a0f609,0x26780276,0x26c406ea}},	//   _ширк, _шарн, _нстэ_, _álop_, 
   {{0x79861f96,0xdb0c0b1a,0x5f1000bc,0x00000000}},	//   naiw, pebæ, दछन्_, --, 
   {{0x62540f8b,0xdb0c007c,0x00000000,0x00000000}},	//   _tšon, lebä, --, --, 
   {{0x79861f97,0xa5280327,0x00000000,0x00000000}},	//   haiw, _སྙིག_, --, --, 
   {{0xb8e00c99,0xdb0c04f3,0xa3bd0204,0x8fd00032}},	//   _ཁར_, nebä, ेयर_, еҙҙә, 
   {{0xa020000d,0xb3e000cc,0x00000000,0x00000000}},	//   öörd, _ভতিজ, --, --, 
   {{0x79861f98,0x100802dd,0xdcf400b8,0x00000000}},	//   daiw, _وتتى_, _peyā, --, 
   {{0x60dc05ac,0x6fb4007b,0xdb640092,0x00000000}},	//   åsme, _أمثا, ዳንዴም_, --, 
   {{0xc9844a7a,0x0054011a,0x3ec001af,0x24880327}},	//   дузи, _קשות_, _асыб, ġami_, 
   {{0x7984949e,0x2488bd4e,0xfd100451,0x4a7401e0}},	//   gaiw, šami_, _ھجي_, зыҡт, 
   {{0x1cac031c,0xdb1c00d8,0xb9c40fc0,0x61480129}},	// [3e590] _པཱར_, _papã, ъёри, mêlé, 
   {{0x2ca8009a,0x9f4c067c,0x00000000,0x00000000}},	//   _iqad_, ànça_, --, --, 
   {{0xf414015b,0x7984006f,0xdb0c17da,0x2fd801ed}},	//   াকার_, baiw, gebä, örgy_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x100c03ce,0x00000000,0x00000000,0x00000000}},	//   ाफाश_, --, --, --, 
   {{0x1cac0156,0xf77197a2,0xdb0c002f,0xe290009f}},	//   _པཱལ_, _ناف_, bebä, هذب_, 
   {{0xe29a1f99,0x85b80014,0x65943334,0x65680327}},	//   чай_, _وارس_, _паву, _tfeh, 
   {{0xdb1c01ed,0xf6452e03,0x00000000,0x00000000}},	//   _japá, _ахун, --, --, 
   {{0xdb1c255f,0x00000000,0x00000000,0x00000000}},	//   _mapá, --, --, --, 
   {{0xdb0c08cb,0xd02000fd,0xdb1c00e5,0x34940229}},	//   lebå, лмый, _lapá, _шаур, 
   {{0x2ca80ac5,0xdb0dcd91,0x79861f9a,0x00000000}},	//   _aqad_, ldbö, yaiw, --, 
   {{0xdb1c0232,0xf1c80131,0xdb0c12e8,0x00000000}},	//   _napá, _يولى_, nebå, --, 
   {{0xdb0c553f,0x79856611,0xed348602,0x15f0033f}},	//   ndbö, vaiw, вэрэ, _अकसर_, 
   {{0x224e1f9b,0x79861f9c,0x21f002fb,0xe1f80024}},	//   lmek_, waiw, _váhu_, lkų_, 
   {{0x79847805,0xdb0c33b8,0x8c4002e8,0x224802f0}},	//   taiw, kebå, уере, ňaku_, 
   {{0x224c1295,0xe1f80953,0x9d4409a5,0xdb0c0158}},	//   nmek_, nkų_, _пейд, jebå, 
   {{0x63ac04b9,0x224c151c,0x79861f9d,0xe1f80024}},	// [3e5a0] đanj, imek_, raiw, ikų_, 
   {{0x798402ce,0x61bc2314,0x07a0008e,0x224d850e}},	//   saiw, ्युष, лаун, hmek_, 
   {{0x224c4252,0x79840a73,0x00000000,0x00000000}},	//   kmek_, paiw, --, --, 
   {{0x09e16c1c,0x14c80a8f,0xf48408dc,0x847c0023}},	//   _боюн, зыки_, ناتی, _ሕሰምን_, 
   {{0xa3bc0882,0xb7840116,0x95840220,0x2bd40b02}},	//   ेयं_, _ағзи, _үлге, दाचा, 
   {{0xdb1c0122,0x672016a3,0x224dd7aa,0x9814007b}},	//   _zapá, _žlje, emek_, _أبحا, 
   {{0x3a200140,0xdb0c00b5,0xb3d400fb,0x00000000}},	//   onip_, bebå, ейҙә, --, 
   {{0xd1b80150,0x3a221f9e,0xaad00404,0x02d000f1}},	//   ساعا_, nnip_, हितक, اتوخ, 
   {{0x3a221f9f,0xcfa400a7,0x70bc3507,0x7ae8007c}},	//   inip_, ншни, ्टेल, ädtj, 
   {{0x2ca8025c,0x31c00014,0xa3bc00cd,0xc0c40240}},	//   _rqad_, _چۅغہ, ेयः_, _ጸብሒ_, 
   {{0x3a221fa0,0x2ec401e0,0xc6100154,0xc7b0011a}},	//   knip_, төлм, িকরা_, אבת_, 
   {{0xd08401ee,0xe1f80064,0x224d14e3,0x00000000}},	//   _зыки, ckų_, cmek_, --, 
   {{0x7ee010e0,0x55140037,0x00000000,0x00000000}},	//   _ەكىن, _देमए_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb1c03df,0x03d40375,0x41a402c3,0x00000000}},	//   _papá, עולם_, _गामस, --, 
   {{0xc0f00092,0x32040051,0x00000000,0x00000000}},	//   ፌሰሩ_, nhmy_, --, --, 
   {{0x3d9402dd,0xe8580107,0xdb0c5522,0x00000000}},	// [3e5b0] _сиыр, дааш_, vebå, --, 
   {{0x6e3e1fa1,0x224c37be,0x63ac597f,0xb2fc0327}},	//   llsb, zmek_, đank, ྐྱོང_, 
   {{0x224e1fa2,0xdb0c2d8b,0x1cac0327,0xdb1c01e1}},	//   ymek_, tebå, _པཱོ_, _tapá, 
   {{0x88800424,0xf650764c,0x659401c0,0x09ac0154}},	//   _میرن, مئن_, таду, _চোরা, 
   {{0x69cc0007,0x224c083c,0x26c0009a,0xdb0c12e8}},	//   mdae, vmek_, swho_, rebå, 
   {{0x69cc9903,0x290801c8,0x21f002f0,0x8c38002f}},	//   ldae, mzaa_, _náhr_, buße, 
   {{0x224c1295,0x9f4c4ba9,0xdebc02d3,0xa2e401b9}},	//   tmek_, ünün_, ሳብን_, тойд, 
   {{0xd24e1fa3,0x69ce1fa4,0xe1f802d5,0x61bc0882}},	//   ينو_, ndae, ukų_, ्येष, 
   {{0x224e1fa5,0x69cc039a,0xe1f80006,0x29096cf2}},	//   rmek_, idae, rkų_, nzaa_, 
   {{0x24540502,0x69cc0007,0xdea21fa6,0xe1f80024}},	//   _شناس, hdae, لیتی, skų_, 
   {{0x248d0721,0x69cc0007,0x00000000,0x00000000}},	//   _hvem_, kdae, --, --, 
   {{0xc0f000b7,0x69cc0399,0x11681bf3,0x5dd81086}},	//   ፌሰር_, jdae, _قلمی_, ффор_, 
   {{0x61ea1fa7,0x3a200140,0xdb1c013d,0xa0a457c2}},	//   mjel, vnip_, _kapç, _ралд, 
   {{0x69de1cae,0x61ea1fa8,0x69cc0295,0x09ac009e}},	//   _anse, ljel, edae, _চোলা, 
   {{0x3a200522,0x61e802f6,0x9f9400c7,0x8c380112}},	//   tnip_, ojel, _зықә, fußb, 
   {{0x69cc0007,0x69dc0076,0x248c0393,0x3a200140}},	//   gdae, _cnse, _ovem_, unip_, 
   {{0x7050168d,0x3a221fa9,0x69dccd11,0x1c4400a8}},	// [3e5c0] _خۆیا, rnip_, _dnse, _иним, 
   {{0x61ea1faa,0x7e60008f,0x69dcffe4,0xe55c00b5}},	//   hjel, _kunp, _ense, _cm巾_, 
   {{0x248e1fab,0x61e81a82,0x69cc0399,0x7e6004ce}},	//   _avem_, kjel, bdae, _junp, 
   {{0xa2d4060c,0x7e600227,0xceb002e4,0xb2740131}},	//   भिन्, _munp, שיא_, қлиш, 
   {{0x61e8036f,0x6ef80af2,0x7e6001e4,0x20040067}},	//   djel, _kúbú, _lunp, khli_, 
   {{0xdb1c0137,0x84300212,0x7e600241,0x00000000}},	//   _capç, аніє, _ounp, --, 
   {{0x61e8319f,0x69de1fac,0x7e6007de,0x200405b1}},	//   fjel, _ynse, _nunp, dhli_, 
   {{0x61ea1fad,0xb7d800e5,0x43640139,0xdebc0023}},	//   gjel, _توڑا_, наән_, ሳእን_, 
   {{0x248c031c,0x33b40131,0x249401d9,0xb034adc9}},	//   _gvem_, _مەشر, _مۆند_, лниш, 
   {{0xdb1c0793,0x69cc0226,0x7e6001e7,0x2004016d}},	//   _kapä, zdae, _bunp, ghli_, 
   {{0x7e6004cc,0x1cac025c,0xdb0c002d,0x248c0010}},	//   _cunp, _པཱུ_, rebû, _zvem_, 
   {{0x645c0395,0x61e81e31,0x69cc0399,0x80a007d6}},	//   _èsic, cjel, xdae, دمین, 
   {{0x6e3c8174,0x6ef801e1,0x70956a20,0x2e380036}},	//   rlsb, _búbú, _салф, déft_, 
   {{0x20061fae,0xd70017ee,0x00000000,0x00000000}},	//   chli_, लनाथ_, --, --, 
   {{0x7e603d19,0xdb1c01f1,0x00000000,0x00000000}},	//   _gunp, _napä, --, --, 
   {{0x63ac1326,0xfe6c212d,0x7ac41fbe,0x244800e4}},	//   đani, _بدو_, јсре, múme_, 
   {{0x69ce1faf,0x7968002e,0x69dc0051,0x00000000}},	// [3e5d0] rdae, _séwó, _vnse, --, 
   {{0x69cc0579,0x779800c2,0x61e816d9,0x00000000}},	//   sdae, ккур_, zjel, --, 
   {{0xf7721fb0,0x7ddc0139,0x4ae401d5,0xdb1c03e0}},	//   تاق_, _käsе, _рўпа, _rapç, 
   {{0x69dc09f0,0x248c0789,0x69cc0399,0xa2bc01ad}},	//   _unse, _pvem_, qdae, _वैग्, 
   {{0x61ea1fb1,0xd1b80092,0x24f82401,0xd5ac00ec}},	//   vjel, ዳንት_, энды_, سفو_, 
   {{0xb9140882,0x69240022,0xdb1c013d,0x244800e4}},	//   vyaḥ_, _амҭа, _qapç, kúme_, 
   {{0x61ea1fb2,0xa3a80254,0x3f800321,0x59a80303}},	//   tjel, ग्ग_, ðjum_, ङ्कर, 
   {{0x7ae8b83f,0xdb0c0077,0x7e621fb3,0x614400ee}},	//   ädti, tebú, _runp, лейа, 
   {{0x2054c11f,0x61e88b6f,0x28c81ab2,0xe3b8e8a7}},	//   лтор, rjel, रिटि, _плач_, 
   {{0x248800da,0x61ea1fb4,0xdb1c0793,0x6b840455}},	//   šams_, sjel, _yapä, _nehg, 
   {{0x61e81f7f,0x02a4064d,0x200501c9,0x00000000}},	//   pjel, _шрам, rhli_, --, 
   {{0x200407d6,0xdb0c03cd,0xdb1401d3,0x00000000}},	//   shli_, mebø, ábít, --, 
   {{0xdb0c11c0,0x201800d5,0x6b84036e,0x00000000}},	//   lebø, ésis_, _behg, --, 
   {{0x62700270,0x7e621fb5,0x9e040137,0x00000000}},	//   _vāof, _tunp, тчүл, --, 
   {{0xdb0c01bf,0x00000000,0x00000000,0x00000000}},	//   nebø, --, --, --, 
   {{0x62700421,0xdb0c0158,0x00000000,0x00000000}},	//   _tāof, iebø, --, --, 
   {{0x48e00801,0xdb1c0309,0x59a80303,0x00000000}},	// [3e5e0] ботв, _sapä, ङ्गर, --, 
   {{0x6b840098,0x5ac80c31,0xdb0c08fb,0x1cac0327}},	//   _gehg, _злом_, kebø, _པྱག_, 
   {{0x6254000a,0xdb0c353e,0x9f44022a,0x00000000}},	//   _tšoh, jebø, yklý_, --, 
   {{0xdb0c1600,0xaad0012c,0xd1b80092,0x9584004e}},	//   debø, हिरक, ዳንተ_, улде, 
   {{0x4e3400c8,0x628002d0,0x257000db,0x00000000}},	//   אָגן_, _awlo, تۇقس, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd25802d7,0x1da80490,0xdb0d56de,0x073c08b0}},	//   нци_, _काढत, gebø, _ﺟﺎﯓ_, 
   {{0xa78400dd,0x62800076,0x66180034,0x28c83f7e}},	//   _مشہو, _dwlo, ciwk, रिचि, 
   {{0x60cc00f3,0x62800042,0xd1b80092,0x61f800d7}},	//   _šamr, _ewlo, ዳንቱ_, _žalô, 
   {{0x301402f4,0x62800175,0x9f4402fb,0x03a006ed}},	//   рдор, _fwlo, sklý_, _гифо, 
   {{0xe3b001d9,0x6b8400e4,0x201800cf,0x3ef401c6}},	//   _ذرٕ_, _rehg, èsia_, гнээ_, 
   {{0x626400d1,0xa2c01b76,0x20180100,0xae8800cf}},	//   _ئالق, लबर्, ésir_, нбүз_, 
   {{0x6b840455,0xd01834f0,0xc0d40092,0x00000000}},	//   _pehg, _пфк_, ይባል_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3ff804ac,0x6b840369,0x63b403e0,0x39240023}},	//   _אפגע, _vehg, _özne, ቲካዊያ, 
   {{0xa2d43c16,0x00000000,0x00000000,0x00000000}},	//   भित्, --, --, --, 
   {{0xa81617e8,0x27f002fb,0xa9a400d1,0x28a407af}},	// [3e5f0] адаш, _pozn_, лиңд, गंधि, 
   {{0x4b0401c0,0x00000000,0x00000000,0x00000000}},	//   _бямб, --, --, --, 
   {{0xf7721fb6,0x074409a5,0x261400d0,0x9f44007f}},	//   سال_, ухам, sťom_, lklò_, 
   {{0xdb0c005c,0x00000000,0x00000000,0x00000000}},	//   vebø, --, --, --, 
   {{0x63861fb7,0xa2bc2356,0xc8a8016c,0xe45400ee}},	//   агла, _वैज्, _яъне_, акды, 
   {{0xe29802c6,0xdb0c00fe,0x225c0309,0x00000000}},	//   вак_, tebø, _siwk_, --, 
   {{0x26c4011c,0x66180210,0x00000000,0x00000000}},	//   _èlo_, piwk, --, --, 
   {{0xdb0c2d75,0xa3a80073,0xfe740075,0xe1f00066}},	//   rebø, ग्ज_, ңүл_, تست_, 
   {{0xf3ec005e,0xb0f805f5,0xdb0c0b1a,0xc54000e5}},	//   _ең_, гээх_, sebø, _اڑای, 
   {{0x41a406ab,0x39240023,0xa08800db,0x00000000}},	//   _गावस, ቲካዉያ, нсүз_, --, 
   {{0x3fc401d3,0xae7401d3,0x00000000,0x00000000}},	//   ندھی_, یپیڈ, --, --, 
   {{0x5f74429e,0x23b4012c,0x00000000,0x00000000}},	//   داکر, _आउँद, --, --, 
   {{0xef18005f,0xa3e84c5b,0x00000000,0x00000000}},	//   daļu_, याप_, --, --, 
   {{0x81b400cc,0x00000000,0x00000000,0x00000000}},	//   _চফি_, --, --, --, 
   {{0x49700521,0x249c0142,0xb2100162,0x8f980115}},	//   _ụtụ_, hrwm_, øðgø, _סיקי, 
   {{0x8e180588,0xef1800ef,0x00000000,0x00000000}},	//   _ахьӡ_, gaļu_, --, --, 
   {{0x3f861fb8,0x17861fb9,0x18a61fba,0x38c82444}},	// [3e600] _kenu_, игам, разм, دازی_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa3e81e61,0x3f861fbb,0xa3a80316,0xdcf82099}},	//   यान_, _menu_, ग्छ_, _سرکش_, 
   {{0x3f84b07e,0x98a61fbc,0x18a41188,0x6244002e}},	//   _lenu_, _киме, _камм, dóoo, 
   {{0x53e5d8cf,0x249c0142,0xdb1c0419,0x25a873eb}},	//   ицка, grwm_, _napú, ادمي_, 
   {{0x3f861fbd,0x78a61fbe,0x392402d3,0x7afc00ad}},	//   _nenu_, muiv, ቲካውያ, oyrt, 
   {{0x12e40046,0x03a00640,0x81cc015b,0x624400e8}},	//   рілг, цијо, শান_, róon, 
   {{0x645c020c,0x60d80142,0x625401ef,0x00000000}},	//   _èsin, _brwm, _ošou, --, 
   {{0x3f861fbf,0x78a54aa0,0x546a1fc0,0x30140982}},	//   _benu_, nuiv, _разм_, йдир, 
   {{0x60d80142,0x2d9c00ee,0x624400e5,0xe05402f2}},	//   _drwm, _öwez_, lóol, مینت_, 
   {{0x78a61fc1,0x7ff0113e,0x3f861fc2,0x00000000}},	//   huiv, تسيا, _denu_, --, 
   {{0x78a61fc3,0x3f840009,0xc330010f,0x7afc010e}},	//   kuiv, _eenu_, _ווע_, dyrt, 
   {{0xe16410fe,0x3f861fc4,0x24c41c5c,0x24480af2}},	//   _ادمي, _fenu_, ﻮﻧﻮﻣ, lúma_, 
   {{0xa3e808dd,0x3f861fc5,0x78a4a95f,0xffd005d9}},	//   याय_, _genu_, duiv, _وٺند, 
   {{0x6e961fc6,0xef1800e2,0x7afe1fc7,0xdb1c00d7}},	//   _البا, taļu_, gyrt, _zapú, 
   {{0x3f847ab0,0x256c01e1,0x00000000,0x00000000}},	//   _zenu_, _móló_, --, --, 
   {{0x478880df,0x3f85cac0,0x78a61fc8,0xa3e816ae}},	// [3e610] всем_, _yenu_, guiv, याम_, 
   {{0xace8035b,0x7afc0363,0x244800e4,0x3f8400d7}},	//   _амҩа_, byrt, kúma_, _xenu_, 
   {{0xe7180597,0x78a40421,0x32ec013f,0x8ac4005b}},	//   ديات_, auiv, bɛyi_, _тёпл, 
   {{0x78a4011c,0xebb8002b,0x249c03cb,0xa2d400cd}},	//   buiv, _duḥ_, trwm_, भिस्, 
   {{0x2d881730,0x7bc80037,0xf1700150,0x00000000}},	//   _meae_, õdug, _ﺴﺘﺘﻡ_, --, 
   {{0x5f080a28,0x23280818,0x00000000,0x00000000}},	//   ानम्_, лоли_, --, --, 
   {{0xa3e83be5,0xd36c07c0,0x00000000,0x00000000}},	//   याब_, رهي_, --, --, 
   {{0xdb0c5ebf,0x62461fc9,0xdb1c05c7,0xa62400db}},	//   ékér, cóol, _papú, _افرى, 
   {{0x03c434d8,0x25ada4f3,0x7afc036e,0x00000000}},	//   _всем, _icel_, zyrt, --, 
   {{0x63ac1326,0x2d880295,0x80b405dc,0x00000000}},	//   đans, _aeae_, _अहीं, --, 
   {{0x3f861fca,0x2d880134,0x78a401a4,0x44240072}},	//   _venu_, _beae_, zuiv, mnn_, 
   {{0x3f847ab0,0x442603d5,0xdb1c007b,0x60d80042}},	//   _wenu_, lnn_, _tapú, _trwm, 
   {{0x3f861fcb,0x4424c699,0x2d8973f6,0xe7fc0490}},	//   _tenu_, onn_, _deae_, _एवढा_, 
   {{0x60ca1fcc,0x200401d9,0x7afcfb72,0x41a400bc}},	//   mwem, _دِتِ, tyrt, _गाँस, 
   {{0x44261fcd,0x60c80a07,0x25ac219b,0x7d0001bf}},	//   inn_, lwem, _ocel_, ømsb, 
   {{0x78a61fce,0x44261fcf,0xa3e80e49,0x2ef8002f}},	//   tuiv, hnn_, याड_, ärfe_, 
   {{0x7afc03a2,0x60c800ca,0xdb0c014a,0x4424003e}},	// [3e620] syrt, nwem, lebü, knn_, 
   {{0x25ae1fd0,0x6244002e,0xd7880133,0x78a400e4}},	//   _acel_, dóom, اناو_, ruiv, 
   {{0x60ca1fd1,0xdae800b2,0x7afc02d3,0x78a61fd2}},	//   hwem, _صفحو_, qyrt, suiv, 
   {{0x60ca1fd3,0x78a61fd4,0x44261fd5,0x25ac01f7}},	//   kwem, puiv, enn_, _ccel_, 
   {{0x78a47c36,0x91a401e1,0x60c80230,0x6b8401ec}},	//   quiv, _ako̟_, jwem, _اشۋل, 
   {{0x60c8013f,0x442401ab,0x25ac03e0,0x256c01d3}},	//   dwem, gnn_, _ecel_, _póló_, 
   {{0x46a21fd6,0xaad000bc,0x00000000,0x00000000}},	//   _нарв, हिएक, --, --, 
   {{0x44242d53,0x15b00c71,0x55f4010b,0xdb0c265c}},	//   ann_, _رەتس, _учгу, debü, 
   {{0x60c898f9,0xc0e0069d,0x256c01e1,0x0dc801d5}},	//   gwem, _ሞተር_, _wóló_, қуни_, 
   {{0x8eb00533,0x6744045f,0x4424037e,0x2d88031c}},	//   كەتت, _útjû, cnn_, _seae_, 
   {{0x045494d2,0x50d61fd7,0xdb0c03fa,0xdb1c0158}},	//   _اللة_, _گزار, gebü, _gapø, 
   {{0xa2d40882,0x60ca1fd8,0xdd921fd9,0x2ea801f9}},	//   भिर्, bwem, ووپ_, _कमीत, 
   {{0x1cac025c,0x20e003b2,0x1da81116,0x00000000}},	//   _པྱད_, ræið_, _कारत, --, 
   {{0x7bd82cd7,0xfe6c06fe,0xdb0c0112,0x00000000}},	//   _óvul, بدی_, bebü, --, 
   {{0xa3e82413,0x63ac23db,0x62540006,0xdb0c0036}},	//   यात_, ɗand, _išor, cebü, 
   {{0xe97819b0,0x2bac726b,0x6608031c,0x00000000}},	//   рбаш_, ञ्जा, _ċeko, --, 
   {{0x44240731,0x6e2e1fda,0x00000000,0x00000000}},	// [3e630] ynn_, _ijab, --, --, 
   {{0x6d4c030a,0x00000000,0x00000000,0x00000000}},	//   _izaa, --, --, --, 
   {{0x60ca1fdb,0x6e2c01fa,0x4424004d,0x00000000}},	//   zwem, _kjab, vnn_, --, 
   {{0xca480150,0x00000000,0x00000000,0x00000000}},	//   _ﻁﺭﺃ_, --, --, --, 
   {{0xe3646511,0xf73402d3,0x60c801e2,0x44260172}},	//   окли, _ክዳውን, xwem, tnn_, 
   {{0x44261fdc,0xc7c40801,0x2bac16d1,0x62441bce}},	//   unn_, _усми, ञ्चा, róom, 
   {{0x44240192,0x6e2e1fdd,0x645c0268,0x201800db}},	//   rnn_, _ojab, _èsim, èsim_, 
   {{0xe1f811b5,0x6e2e1fde,0x60c80526,0x6d4c1418}},	//   рги_, _njab, twem, _ozaa, 
   {{0x660a1fdf,0xa3e8dadd,0x68ee1fe0,0x6d4c1418}},	//   _ilek, याद_, nxad, _nzaa, 
   {{0x660a1fe1,0x6e2e1fe2,0x68ed938a,0x60c82c36}},	//   _hlek, _ajab, ixad, rwem, 
   {{0x6d4c2252,0xddc46830,0x60ca1fe3,0x712407d6}},	//   _azaa, обни, swem, قریل, 
   {{0x4e2400db,0xdb0c0210,0x00000000,0x00000000}},	//   жоюн_, zebó, --, --, 
   {{0x660a1fe4,0x60c80944,0x6e2e1fe5,0x81cc015b}},	//   _mlek, qwem, _djab, শাদ_, 
   {{0x6e2c0107,0x6d4c0433,0x3ad802bd,0x68ec0009}},	//   _ejab, _dzaa, _pčp_, dxad, 
   {{0x8c421fe6,0x6608033d,0xdd9000f8,0x6d4c2252}},	//   фере, _olek, _ہوں_, _ezaa, 
   {{0x660800b4,0x68ec058a,0x09e07125,0xdc68014b}},	//   _nlek, fxad, мосн, _каид_, 
   {{0x68ec0009,0x62a001e1,0x00000000,0x00000000}},	// [3e640] gxad, _ńwò, --, --, 
   {{0x7e64bad5,0xed580306,0x15880131,0xc8a8000d}},	//   _hiip, ýže_, _ﻗﯩﺴﯩ, _चमरट, 
   {{0x6d4c1418,0x7c3e1fe7,0x7e661fe8,0x68ec2860}},	//   _zzaa, morr, _kiip, axad, 
   {{0xa780052f,0x94a8014d,0x58840022,0xa3e802c3}},	//   _үҫте, لاتِ_, _қыҭа, याऽ_, 
   {{0xb12400bd,0x8e540bd9,0x7e64013c,0x00000000}},	//   _পর্ব_, קינג_, _miip, --, 
   {{0x1cac0489,0x38b61fe9,0xd3b80220,0x7e655953}},	//   _པཱན_, mär_, руді_, _liip, 
   {{0x38b4eabc,0x660800ed,0x1da80cba,0x00000000}},	//   lär_, _flek, _कांत, --, 
   {{0x7c3e1fea,0x7e6400af,0x11e800c6,0x9580001f}},	//   horr, _niip, شعبي_, ነታችን_, 
   {{0x7c3e1feb,0x38b61fec,0x4fc428f1,0x6ecc0316}},	//   korr, när_, осна, _तनहु, 
   {{0x7e6406c8,0x6e2c057b,0x999000ee,0x7c3c0789}},	//   _aiip, _sjab, ynyş_, jorr, 
   {{0x7c3e1fed,0x38b40598,0x627000b0,0xc7d40a1e}},	//   dorr, här_, _hāon, קוטי_, 
   {{0x38b61fee,0xeff002d3,0x41a4000d,0x00000000}},	//   kär_, ልናዮ_, _गाएस, --, 
   {{0x7e661fef,0x6e2c0327,0xad2415bf,0x62540064}},	//   _diip, _vjab, سىسى, _išop, 
   {{0x38b40598,0x7c3e1ff0,0xca740131,0xace8035b}},	//   där_, gorr, قارغ, амҭа_, 
   {{0x6e2c01e3,0x00000000,0x00000000,0x00000000}},	//   _tjab, --, --, --, 
   {{0x6e2e1ff1,0x38b61ff2,0xf1bc3507,0x68ec3a49}},	//   _ujab, fär_, ्जिन, txad, 
   {{0x7c3e1ff3,0x38b61ff4,0x6d4c0083,0x6aa00008}},	// [3e650] borr, gär_, _uzaa, álfb, 
   {{0x8704db35,0x66082cb2,0x7e661ff5,0x68ee1ff6}},	//   يبال, _slek, _ziip, rxad, 
   {{0xa3e8482a,0x660958f3,0xf1bc80ea,0x68ec6140}},	//   यास_, _plek, ्जान, sxad, 
   {{0x38b61ff7,0xf65005d9,0xe29801e0,0xb6040108}},	//   bär_, نئن_, ҡал_, мячк, 
   {{0xd1240597,0x600c2760,0x98a401e0,0xfe38011a}},	//   _أم_, _húme, _нурҙ, חראי_, 
   {{0x6e3c0455,0xb12403d4,0x600c032e,0x00000000}},	//   hosb, _পৰ্ব_, _kúme, --, 
   {{0xca4c0020,0x660a1ff8,0x6e3e1ff9,0x600c03b2}},	//   _ሁኔታዎ, _tlek, kosb, _júme, 
   {{0xa3ea1ffa,0x7c3ca57b,0x660a1ffb,0x6e3c014f}},	//   याह_, zorr, _ulek, josb, 
   {{0x7e661ffc,0x600c067c,0xdb2401b8,0x6e3c5e0b}},	//   _riip, _lúme, _äpöt, dosb, 
   {{0x600a1ffd,0x26140030,0x7e661ffe,0x7c3ced0b}},	//   сном_, rťou_, _siip, xorr, 
   {{0x26140038,0xcf8c6c72,0x656801af,0x600c022c}},	//   sťou_, اژه_, _kgeh, _rúmd, 
   {{0xd12c30c0,0x7c3c1613,0x9b9400aa,0xa3e8739b}},	//   ئمی_, worr, ګلست, याव_, 
   {{0x7c3e1fff,0x7e662000,0x6440025c,0x02d0033f}},	//   torr, _viip, _kkli, थिकभ, 
   {{0x61fa2001,0x600c022c,0x63ac0198,0x38b43407}},	//   _howl, _búme, ɗanc, vär_, 
   {{0x61fa2002,0x7c3cf07f,0x3a20013c,0x9f94035b}},	//   _kowl, rorr, tiip_, _дықә, 
   {{0x656a2003,0x61f80204,0x958002d3,0x20040010}},	//   _ngeh, _jowl, ነታትን_, lkli_, 
   {{0x7c3e2004,0x64400b3d,0x61f8cf93,0x00000000}},	// [3e660] porr, _okli, _mowl, --, 
   {{0x21f00122,0x200403ee,0x38b62005,0x6568019b}},	//   _váhy_, nkli_, rär_, _ageh, 
   {{0x600c00d2,0x20041c06,0x38b40793,0x3a20915e}},	//   _kúmb, ikli_, sär_, piip_, 
   {{0x64422006,0x61f80069,0x38b40036,0x20040037}},	//   _akli, _nowl, pär_, hkli_, 
   {{0x79862007,0x2ea8012c,0xe97001ec,0x2a3401c6}},	//   mbiw, _कम्त, _شۇلد, _цээр, 
   {{0x65680b6f,0x64401529,0x44a00131,0x656c0419}},	//   _egeh, _ckli, رمىق, ľaha, 
   {{0x61fa2008,0x78a405e4,0x600c00e4,0x79840083}},	//   _bowl, lriv, _oúmb, obiw, 
   {{0x62700053,0x61f84f82,0xdb1c0124,0x78a62009}},	//   _tāon, _cowl, _hapó, oriv, 
   {{0x61fa200a,0x644003a0,0x4170278f,0x798401f7}},	//   _dowl, _fkli, رايس, ibiw, 
   {{0x6e9805c5,0xdb1e200b,0x64400036,0xc8b4008f}},	//   овор_, _japó, _gkli, פּחה_, 
   {{0xa3e84425,0x3ce064d3,0xdcf403be,0x6e3c02d0}},	//   यार_, _ariv_, _peyğ, tosb, 
   {{0x61f8003d,0xdb1c05d5,0x3f80066a,0x6608025c}},	//   _gowl, _dapü, ðjur_, _ċekk, 
   {{0x3ce004cc,0x6e3c01ed,0x4638010f,0x600c00d7}},	//   _criv_, rosb, מעטע, _súme, 
   {{0x3ce003d4,0x200403ee,0x7988016b,0x79840083}},	//   _driv_, ckli_, _ɑdwe, ebiw, 
   {{0x7ac6200c,0xcee843bb,0x61f80204,0xbfc80131}},	//   нсте, _درشن_, _yowl, _دانە_, 
   {{0x78a6200d,0x3ce121a0,0x61f80067,0x6e3c0455}},	//   friv, _friv_, _xowl, qosb, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3e670] --, --, --, --, 
   {{0xf7703918,0xdb1c29d3,0x6d400259,0x68e8031c}},	//   هام_, _capó, ğlad, _ġedd, 
   {{0xaa540261,0x78a6200e,0x79840e14,0x2cb801d3}},	//   _овош, ariv, bbiw, ltsd_, 
   {{0x6442200f,0x78a62010,0xdb1c0022,0x7984058a}},	//   _skli, briv, _eapó, cbiw, 
   {{0x78a62011,0x61f83d25,0x99f423e4,0x2cb801d3}},	//   criv, _rowl, _חזרה_, ntsd_, 
   {{0x61fa2012,0x6278059f,0x7af400a2,0x3ab80244}},	//   _sowl, осиё_, _ýetä, _بایخ_, 
   {{0x200405d1,0x52b0007b,0x61f932fc,0x00000000}},	//   vkli_, نموذ, _powl, --, 
   {{0x6569df78,0xdb1e2013,0x35d5868c,0x61f80067}},	//   _ugeh, _kapò, _посё, _qowl, 
   {{0x81cc11ba,0x61f80076,0x63c801d9,0x20d4109a}},	//   শাল_, _vowl, _وِرِ_, фійс, 
   {{0xdb1e2014,0x64422015,0x600c0162,0xd0202b95}},	//   _xapó, _ukli, _súmb, кмый, 
   {{0x828553bb,0x61f8543e,0x20062016,0xdb1c033b}},	//   _رجال, _towl, rkli_, _lapò, 
   {{0x3ce22017,0xdb1c01b8,0x63ac0198,0x20062018}},	//   _priv_, _vapü, ɗana, skli_, 
   {{0xdb1c067c,0xdea15167,0xdb0c0267,0xa2d40b7c}},	//   _napò, ریکی, nebö, भिक्, 
   {{0x78a404cc,0x79840142,0x00000000,0x00000000}},	//   vriv, wbiw, --, --, 
   {{0xcb652cee,0xdb1ca749,0x09d40154,0xd1dc0023}},	//   даре_, _rapó, হানা, ቓዕቲ_, 
   {{0x78a62019,0xa3e823fd,0x6aa2201a,0x6b800724}},	//   triv, याँ_, álfa, ılga, 
   {{0xdb1c067c,0x78a40037,0xfd240133,0x6b98007b}},	// [3e680] _papó, uriv, _سودێ, éagó, 
   {{0x07a0dddc,0x1ae422cb,0x00000000,0x00000000}},	//   каун, _жоом, --, --, 
   {{0x656c00d0,0x4e3000e5,0x00000000,0x00000000}},	//   ľahn, _سٹیز, --, --, 
   {{0x78a40bb8,0x68ea201b,0xd9d010e0,0x00000000}},	//   priv, _šede, _جەرگ, --, 
   {{0xa3e832ec,0xdb1da57b,0xdb0c014a,0xd860035b}},	//   यां_, _tapó, gebö, _аҵаҩ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x07a01614,0xfbc00882,0x00000000,0x00000000}},	//   _јасн, श्यम, --, --, 
   {{0x1da800bc,0x00000000,0x00000000,0x00000000}},	//   _कागत, --, --, --, 
   {{0xfa1c004d,0x73c401ee,0x3cf80210,0x00000000}},	//   _đất_, _зәйе, ँहों_, --, 
   {{0xa3e80a28,0x2ef5ea7b,0x8c38002f,0x00000000}},	//   याः_, езор, lußv, --, 
   {{0xb8d0025c,0x80d0012d,0x00000000,0x00000000}},	//   _དཀ_, _बैठे, --, --, 
   {{0x42040364,0x51f400db,0x01d400be,0x00000000}},	//   _онхо_, _تسئر, _يولع_, --, 
   {{0x8538010f,0x4ba400cf,0x00000000,0x00000000}},	//   ַגלי, мөнү_, --, --, 
   {{0xdb1d030a,0x213800d2,0x2f180958,0x999000a2}},	//   _rapò, ûshe_, _ноль_, lhyň_, 
   {{0x27ec0016,0x201a201c,0xaa5a201d,0x00000000}},	//   _đen_, ësie_, зиву_, --, 
   {{0xa3e404fa,0xdb1daa3c,0x3d3800b4,0xdb0c2fda}},	//   _बोन_, _papò, ọwa_, ékár, 
   {{0xa8540e67,0x600c032e,0x68e80064,0x00000000}},	// [3e690] екач, _húma, _šedb, --, 
   {{0xb4e8012c,0x87240345,0xdd140066,0x00000000}},	//   यमै_, وعام, _سوپخ, --, 
   {{0x23d81152,0x6b96201e,0x05080154,0xc72800d4}},	//   _योगद, mazg, _শখের_, ціал_, 
   {{0x6b96201f,0x64c4951b,0x00000000,0x00000000}},	//   lazg, فيصل, --, --, 
   {{0xa878008f,0x69cc003a,0xd5ac01d9,0x00000000}},	//   _מאָר, meae, صہٕ_, --, 
   {{0x6b94120f,0x69cc003a,0xb4640212,0xa3e80118}},	//   nazg, leae, вкіл, याइ_, 
   {{0x77a80014,0x600c02d2,0x13a400e5,0x3c980116}},	//   _زێنہ_, _núma, رنٹی_, ﭙﯩﺴﻰ_, 
   {{0xe8bc1e81,0x69ce2020,0xa4d40212,0x6b940139}},	//   _ཕྱོག, neae, _побі, hazg, 
   {{0x63ac0c09,0x6b962021,0xa0c4004b,0x244800e4}},	//   ɗann, kazg, ريدو, húmi_, 
   {{0x69cc0037,0x600c02d2,0x00000000,0x00000000}},	//   heae, _búma, --, --, 
   {{0x62700270,0xdb0c0295,0x24480022,0x00000000}},	//   _māok, nebô, júmi_, --, 
   {{0x6618825f,0x248c3ec4,0xa3b40490,0x999000bc}},	//   _çakı, _kwem_, _झाड_, chyň_, 
   {{0xc0f002d3,0x69cc0037,0xc0c80023,0x4f280023}},	//   ልባሽ_, deae, ቢቖም_, _ብዘይክ, 
   {{0x248c0100,0x6b9401ed,0x98a00153,0x00000000}},	//   _mwem_, gazg, _sykį_, --, 
   {{0x48bc00bd,0x6ed40124,0x37d8015b,0x00000000}},	//   উটোর, _ацых, সামর, --, 
   {{0x76580024,0xdb0dc0bf,0x69cda344,0x1da80456}},	//   įvyk, ngbé, geae, _काटत, 
   {{0x656c01f1,0xbd440451,0x6d400205,0x00000000}},	// [3e6a0] ľahl, _ڳنڍي, ğlac, --, 
   {{0x4cb8011a,0x3d0c00c5,0x2448032e,0x00000000}},	//   _צמיג, हनीं_, búmi_, --, 
   {{0xb4e81161,0xa3e81b37,0x7bdc005c,0xae34004b}},	//   यम्_, याई_, mdru, _سویډ, 
   {{0xd1f0069c,0x186a2022,0x7bdc1f60,0xd1d402d3}},	//   ልታት_, _нами_, ldru, ክታት_, 
   {{0x85400139,0xd3e40166,0x00000000,0x00000000}},	//   лэше, нһаҗ_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe8040574,0x7bdc0153,0x02a08ed1,0x438000d1}},	//   _शकता_, idru, грым, دلىق, 
   {{0x20bc006d,0x600c0321,0xa2d41d03,0xa3e800bc}},	//   ्बंध, _rúma, भिज्, याउ_, 
   {{0x600c5e94,0x7bdc8638,0x80d010fa,0xa6500345}},	//   _súma, kdru, _बैदे, _ئێنت, 
   {{0xcf980063,0x7bc8000d,0x52740117,0x98cc01ec}},	//   чји_, õdul, _зуду, _ﻗﻴﯟﻻ, 
   {{0x91e453ef,0x248c01a4,0xd184005b,0x00000000}},	//   _поже, _zwem_, _злей, --, 
   {{0x7bde2023,0x00000000,0x00000000,0x00000000}},	//   edru, --, --, --, 
   {{0x7bdc2c6a,0x69cc0254,0x00000000,0x00000000}},	//   fdru, veae, --, --, 
   {{0x645c1a44,0x69cc0428,0x7bdc057b,0x2018020c}},	//   _èsit, weae, gdru, èsit_, 
   {{0xc9840640,0xf1d4000d,0x69ce2024,0x00000000}},	//   еузи, _दसान, teae, --, 
   {{0xe8bc081f,0x7bde2025,0x6b940161,0x9ee401d9}},	//   _ཕྱུག, adru, sazg, _شہُل_, 
   {{0x69cd1ce5,0x627000b0,0x7bdc0e78,0x851c00e1}},	// [3e6b0] reae, _pāok, bdru, _मेंट_, 
   {{0x69ce2026,0x6b94022e,0x00000000,0x00000000}},	//   seae, qazg, --, --, 
   {{0x248e2027,0x69cc074d,0x63b403e0,0x00000000}},	//   _ሕቡራት_, peae, _özni, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb0c006a,0x627002b5,0x09d4015b,0x38c8074d}},	//   ngbî, _tāok, হাদা, _пурн_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x248c0810,0x93740116,0x00000000,0x00000000}},	//   _twem_, нбәт_, --, --, 
   {{0x42c004c5,0x27206620,0xa3e40037,0x2b4c0118}},	//   ্মেশ, _मधुर_, _बोथ_, řech_, 
   {{0xa2a8bebc,0x00000000,0x00000000,0x00000000}},	//   _टिप्, --, --, --, 
   {{0xb2847fb5,0x0fc0010b,0x7bdc005c,0x9f94035b}},	//   _бычк, шйэн, vdru, ныҟә, 
   {{0x4424adfe,0x62822028,0xa3e929e9,0x00000000}},	//   lin_, _itlo, याक_, --, 
   {{0x44262029,0x7bdd593e,0x224e202a,0xed3401c0}},	//   oin_, tdru, mlek_, гэрэ, 
   {{0x4426202b,0x224e202c,0x627002b5,0x7bdc0af9}},	//   nin_, llek_, _pāoh, udru, 
   {{0x224c0dd6,0x600c01a8,0x8b20026b,0x00000000}},	//   olek_, _húmo, адре, --, 
   {{0x224c0598,0x7bde202d,0x81cc0eac,0x8c380e78}},	//   nlek_, sdru, শাক_, wußt, 
   {{0x4426202e,0x224e202f,0x7bdc01f5,0x63ac01d3}},	// [3e6c0] kin_, ilek_, pdru, őany, 
   {{0x4425530c,0x6280af63,0x224c08e5,0x627000b0}},	//   jin_, _otlo, hlek_, _tāoh, 
   {{0x62822030,0xa3d404af,0x4aa411ca,0x224e2031}},	//   _ntlo, िजन_, _икэн_, klek_, 
   {{0x44262032,0x62700618,0x6ea40642,0xb60802fb}},	//   ein_, _gāoi, _किसु, _odšť, 
   {{0x44262033,0x62822034,0xcd74008f,0x224e2035}},	//   fin_, _atlo, דענק_, dlek_, 
   {{0x44262036,0xe1f802d5,0xdb0c2776,0x2449712c}},	//   gin_, ejų_, ngbï, kúmu_, 
   {{0xd258094c,0x224c020b,0x726800d1,0x00000000}},	//   мци_, flek_, нчиң_, --, 
   {{0x4424905f,0xab780020,0xc79001e1,0x224e2037}},	//   ain_, ካሄደው_, _iléṣ, glek_, 
   {{0x44262038,0x62817d74,0x644c06af,0x3d0c033f}},	//   bin_, _etlo, éniè, हनों_, 
   {{0x4424576b,0x8eb01ee2,0x224e2039,0xdb1c00c7}},	//   cin_, لەتت, alek_, _hapõ, 
   {{0xdb1c025a,0x224e203a,0x2018044e,0x8134036b}},	//   _zapö, blek_, ësia_, فسیز_, 
   {{0x6244002e,0xf3f405ac,0x00000000,0x00000000}},	//   sóor, _অতিৰ_, --, --, 
   {{0xd01a203b,0x81cc0154,0x628001ef,0x00000000}},	//   _офк_, শাখ_, _ztlo, --, 
   {{0xa2a837c8,0x00000000,0x00000000,0x00000000}},	//   _टिम्, --, --, --, 
   {{0xe1e80050,0x0a680107,0x00000000,0x00000000}},	//   _زى۪و_, драи_, --, --, 
   {{0x4426203c,0x656c00d0,0xcd0401f0,0x00000000}},	//   zin_, ľahk, _ачои, --, 
   {{0x2d9a203d,0x7cd80139,0x0b8800f3,0x00000000}},	// [3e6d0] mase_, _амыр_, _осни_, --, 
   {{0x4426203e,0x6d4e203f,0x224c0724,0x2d8c00e8}},	//   xin_, _iyaa, zlek_, ñeef_, 
   {{0x2d980276,0x6d4c020b,0xd1d401f3,0xdb1c0254}},	//   oase_, _hyaa, ሪስት_, _sapö, 
   {{0x44262040,0x6d4e2041,0x88801968,0xe2840116}},	//   win_, _kyaa, _نیرن, қлии, 
   {{0x69de2042,0x224c0af9,0x2d980077,0xfbc016d1}},	//   _iase, vlek_, iase_, श्वम, 
   {{0x69de2043,0x44262044,0x2d9a2045,0x15880131}},	//   _hase, uin_, hase_, _ﻗﯩﺘﯩ, 
   {{0x44262046,0x69de2047,0x224d374d,0x6ec8016b}},	//   rin_, _kase, tlek_, _yɛbe, 
   {{0x4424228f,0xe0da2048,0x2d9a2049,0x6d4c00ca}},	//   sin_, еви_, jase_, _oyaa, 
   {{0x224e204a,0x4426204b,0x290a204c,0x6d4e204d}},	//   rlek_, pin_, nyaa_, _nyaa, 
   {{0x44253340,0x224de484,0xdb1c05da,0x20100af2}},	//   qin_, slek_, _kapô, ózi_, 
   {{0x2d980f8b,0x6d4c0a81,0x6280052f,0x69de204e}},	//   fase_, _ayaa, _utlo, _oase, 
   {{0x2d9a204f,0x6d40708d,0x6d4c0a49,0xddd400a2}},	//   gase_, ğlan, _byaa, _diyş, 
   {{0x6d4164f0,0xa0a413c6,0x6d4c00ca,0x249c0368}},	//   şlan, _салд, _cyaa, nswm_, 
   {{0x6d4c0280,0x69de2050,0x290a0b87,0xa3e80892}},	//   _dyaa, _aase, dyaa_, याट_, 
   {{0x6d4c0337,0x13c404c5,0x29080014,0xda580408}},	//   _eyaa, _ষোড়, eyaa_, ераш_, 
   {{0xceb0025f,0xa3e402ab,0x915403e6,0xd94400db}},	//   _היה_, _बोस_, _شرۆڤ, геби, 
   {{0x69de2051,0x6d4e2052,0x57ea2053,0x0d800daf}},	// [3e6e0] _dase, _gyaa, ндам_, _улын, 
   {{0x69dc0c8c,0xb8cc045b,0x69c81574,0xe9d80107}},	//   _ease, _गि_, _ñeen, нкӣ_, 
   {{0x55e42e58,0x600c066a,0x07b400c6,0x290a2054}},	//   ложб, _rúml, اهمة_, ayaa_, 
   {{0x69de2055,0xfbc01d27,0x249c0368,0x29085f39}},	//   _gase, श्रम, fswm_, byaa_, 
   {{0x80d005f9,0x82bc0327,0x00000000,0x00000000}},	//   _बैले, _ཚཱུའ, --, --, 
   {{0x69de2056,0x2d98172e,0x00000000,0x00000000}},	//   _zase, zase_, --, --, 
   {{0x69dc124c,0x2d9a2057,0xa3e8216a,0xa2a800c5}},	//   _yase, yase_, याज_, _टिण्, 
   {{0x2d9a2058,0x20180023,0x69dc6ed5,0x00000000}},	//   xase_, ësin_, _xase, --, 
   {{0x2d9a2059,0x13b4034c,0x60d8010a,0x66040032}},	//   vase_, _مصاح, _cswm, _тотҡ, 
   {{0x2d9a205a,0x00000000,0x00000000,0x00000000}},	//   wase_, --, --, --, 
   {{0x2d9a205b,0x6d4cc85d,0xd7c41bcf,0x600c01a8}},	//   tase_, _syaa, र्यच, _gúmm, 
   {{0x90e4073e,0x29082f25,0x1cac0327,0x00000000}},	//   _مستن, yyaa_, _ནྀང_, --, 
   {{0x2d9a205c,0xa3e805ba,0x69de205d,0x29086ed5}},	//   rase_, याच_, _rase, xyaa_, 
   {{0x80a00b24,0x68e80306,0x8f7400d4,0x6d4db2d9}},	//   _امون, _šedo, _суді, _vyaa, 
   {{0x69de205e,0x2d98b496,0x00000000,0x00000000}},	//   _pase, pase_, --, --, 
   {{0x69dc23e0,0x2d9a205f,0x60d802d0,0x69362060}},	//   _qase, qase_, _yswm, анбу, 
   {{0x69de2061,0x29080d04,0xa7b80724,0x81cc02f5}},	// [3e6f0] _vase, uyaa_, клау_, শাচ_, 
   {{0x29093d3b,0xc1540375,0x60dc03b2,0x00000000}},	//   ryaa_, רשמו_, æsmi, --, 
   {{0x69de2062,0x61ec08a5,0x00000000,0x00000000}},	//   _tase, _óalg, --, --, 
   {{0x627002b5,0xc64800c6,0x7c2000e2,0x600c1d1d}},	//   _māot, رجال_, īmre, _rúmm, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x23287f16,0xdb1c05da,0xe28422e9,0xc6940b24}},	//   коли_, _tapô, алки, _مشرع, 
   {{0x0584322e,0xd5380075,0x4eb40154,0xb6e401af}},	//   _бузм, ىغۇچ_, জবুল, _лютк, 
   {{0xa3e40807,0xa2040116,0xa3e8dde9,0x00000000}},	//   _बोर_, рпид, याङ_, --, 
   {{0x944001ed,0x00000000,0x00000000,0x00000000}},	//   _ڈھون, --, --, --, 
   {{0x600902b0,0xf00000d1,0x6d4003e0,0x00000000}},	//   тном_, зүши, ğlal, --, 
   {{0x26c0052f,0x628402fb,0x620401d9,0x27e000a3}},	//   ntho_, íhod, _پوشٕ, idhn_, 
   {{0x26c00142,0x00000000,0x00000000,0x00000000}},	//   itho_, --, --, --, 
   {{0x409013f9,0x00000000,0x00000000,0x00000000}},	//   _چلچر, --, --, --, 
   {{0x17240327,0x1ec80798,0xdee41188,0x00000000}},	//   _རྟའམ_, _алки_, _воки, --, 
   {{0x19944c70,0xda6407c0,0x717000d1,0x43280240}},	//   ијар, لاري, _بۇۋا, _እንበኣ, 
   {{0x69c800e8,0xd874210e,0x4ac4000d,0x00000000}},	//   _ñeel, لائب, _लहरव, --, 
   {{0xa3d62063,0xa3b40037,0x6e3c01d3,0x26c00142}},	// [3e700] िजा_, झला_, érbe, etho_, 
   {{0xa3e40d5f,0xcfc000d1,0x00000000,0x00000000}},	//   _बोल_, ﯩﻴﺎﺗ, --, --, 
   {{0x59741e76,0x8d900150,0xddc4007f,0x00000000}},	//   _выгу, _الۋش, tokň, --, 
   {{0xb8dc1c82,0x27e008c2,0x550401b9,0x6b840133}},	//   _আন_, adhn_, ичла, _پشیل, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x26c001ee,0xf31401c6,0x00000000,0x00000000}},	//   btho_, йдлэ, --, --, 
   {{0xc7a055c3,0xfb48001f,0x59b8033f,0x46a00454}},	//   _фиск, _መድኃኒ, इलपर, _марв, 
   {{0x6aa001a8,0xb7d801d3,0xdb0c03b2,0x645c0171}},	//   álfi, _جوڑا_, lfbó, _īsie, 
   {{0x74f40150,0x0f0c0b6d,0xb194035b,0x85740150}},	//   _دۋشا, ान्स_, алқә, _ﺠﺯﺀﺍ_, 
   {{0x238800bc,0xa3e000dc,0x3014551b,0x00000000}},	//   čují_, धयः_, сдор, --, 
   {{0x0854025f,0x6d404ba9,0xb33c003d,0x600c0332}},	//   שבים_, ğlam, _idħo, _múmh, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x0ca802e8,0xef200210,0x00000000,0x00000000}},	//   ътни_, óżby_, --, --, 
   {{0x26c00368,0x09ac0490,0xfeb43c5a,0x00000000}},	//   ytho_, टल्य, دایت_, --, 
   {{0x627004fe,0x00000000,0x00000000,0x00000000}},	//   _hāor, --, --, --, 
   {{0x62701f4c,0x4cc00154,0xa2a82052,0xfeb40345}},	//   _kāor, ষয়গু, _टिस्, _ئاوت_, 
   {{0x3dc40086,0x32d801fb,0x69c800e4,0x627000ef}},	// [3e710] òmwe_, _lũy_, _ñeem, _jāor, 
   {{0x62701f4c,0x600c03b2,0xfb6c00d1,0x00000000}},	//   _māor, _rúmk, _ﻳﯜﺭﯛ, --, 
   {{0x26c00472,0x00000000,0x00000000,0x00000000}},	//   utho_, --, --, --, 
   {{0x26c00882,0x7bc80254,0x00000000,0x00000000}},	//   rtho_, õduv, --, --, 
   {{0x8b64583f,0x26c00882,0xbb4801ed,0x00000000}},	//   _حاکم, stho_, _ملین_, --, 
   {{0x87e4822f,0xd36c0451,0xe29804f0,0x00000000}},	//   _тюме, ڙهو_, гак_, --, 
   {{0x20180240,0x00000000,0x00000000,0x00000000}},	//   ësim_, --, --, --, 
   {{0xb33c0327,0x00000000,0x00000000,0x00000000}},	//   _idħl, --, --, --, 
   {{0x600e2064,0x21a40184,0xa2a80073,0xf4843e38}},	//   _húmi, _ғилм, _टिव्, _духн, 
   {{0x92e400fe,0x00000000,0x00000000,0x00000000}},	//   _পথৰ_, --, --, --, 
   {{0x5f4400c6,0x212800d7,0x00000000,0x00000000}},	//   إنجل, _ľahu_, --, --, 
   {{0x720400e5,0x600db929,0x00000000,0x00000000}},	//   _وولم, _múmi, --, --, 
   {{0xad480020,0x600c45a7,0x2084007b,0x61fc4268}},	//   _መንገዶ, _lúmi, _التّ, öslu, 
   {{0xc0d40023,0x00000000,0x00000000,0x00000000}},	//   ክኣል_, --, --, --, 
   {{0x2ef85cf5,0x34d400bc,0x00000000,0x00000000}},	//   ärft_, _धन्द, --, --, 
   {{0x5f940032,0x00000000,0x00000000,0x00000000}},	//   _тиҫт, --, --, --, 
   {{0x9ec80014,0xdc9801a9,0x00000000,0x00000000}},	// [3e720] _شِکم_, _ётиш_, --, --, 
   {{0xb9000b7d,0x00000000,0x00000000,0x00000000}},	//   _दन_, --, --, --, 
   {{0x69b40037,0xabc800fd,0x00000000,0x00000000}},	//   इलशी, _şögı, --, --, 
   {{0xceb004ac,0x59d4036b,0x98f40153,0x8ca00244}},	//   ליב_, _اغدر, _лягч, _بڕێو, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x0440cadc,0xa3e40037,0x03a000d8,0x00000000}},	//   печн, _बोआ_, пиљо, --, 
   {{0x12c8310b,0x12e402dd,0x32d80051,0x00000000}},	//   اظتي_, сілг, _qũy_, --, 
   {{0xd3c40014,0x02d000d1,0xc1700395,0x00000000}},	//   _گترى, ستىخ, плъщ, --, 
   {{0x914a2065,0x62700374,0x73c40220,0x53a41367}},	//   ычка_, _pāor, _дәйе, _газб, 
   {{0xd46800ee,0x00000000,0x00000000,0x00000000}},	//   _сизе_, --, --, --, 
   {{0xd1c973a9,0xdb1c01e1,0x4f680108,0x00000000}},	//   _булд_, _ìyèr, ышим_, --, 
   {{0xe2aa2066,0x95880240,0x00000000,0x00000000}},	//   _ضامن_, _ዝበቅዕ_, --, --, 
   {{0x627002b1,0x6ea40037,0x00000000,0x00000000}},	//   _tāor, _किकु, --, --, 
   {{0x99900209,0xb938001f,0x6e94117e,0x00000000}},	//   lkyň_, _በመካሄ, _дику, --, 
   {{0x49c80276,0x00000000,0x00000000,0x00000000}},	//   луам_, --, --, --, 
   {{0x999000ee,0x600c0ad9,0x627000ef,0xd7c401f9}},	//   nkyň_, _rúmi, _jāop, र्सच, 
   {{0xb9080014,0x00000000,0x00000000,0x00000000}},	// [3e730] ٝزٕم_, --, --, --, 
   {{0xa2a81025,0x7bc8000d,0x391401a9,0x00000000}},	//   _टिल्, õdut, чмур, --, 
   {{0xaa5876a0,0x6ec8013f,0x66d4027d,0x9b3401c6}},	//   _вину_, _mɛbo, تيائ, _дүрс_, 
   {{0x6aa0008c,0x29d40592,0xe5f8013d,0xeb0402db}},	//   álfu, _بيحس, _üsüç, रहीत_, 
   {{0xb3240327,0x84c40063,0x98a400fb,0x69c800cd}},	//   _འཟུང_, сљед, _мурҙ, ह्णी, 
   {{0xa3e80f15,0x00000000,0x00000000,0x00000000}},	//   рдка_, --, --, --, 
   {{0x28dc39de,0x457000fb,0x00000000,0x00000000}},	//   _नैति, _еңер, --, --, 
   {{0xc6e4031c,0x2030010c,0x7d0001e3,0x00000000}},	//   སའཛུ, _እብራይ, ämsk, --, 
   {{0x6ec80134,0xd7c400dc,0x00000000,0x00000000}},	//   _bɛbo, र्वच, --, --, 
   {{0xd00c009f,0xfe7400db,0x00000000,0x00000000}},	//   َلي_, бүк_, --, --, 
   {{0xa3e402e5,0x01c00154,0x02a40cab,0x00000000}},	//   _बोए_, ্যবদ, _ырам, --, 
   {{0x69c80d0a,0x5cf4016c,0x8f080354,0x00000000}},	//   _हॉली, оягу, ăхпа_, --, 
   {{0xa3ac1684,0x6e3c01bf,0x00000000,0x00000000}},	//   _कया_, érba, --, --, 
   {{0x9138010f,0x547800df,0x50a00116,0x00000000}},	//   _דענק, יטשו, _غەپل, --, 
   {{0x63ac0198,0x682803e3,0x7c340064,0x00000000}},	//   ɗant, _gödə, _įgrę, --, 
   {{0xc0f0001f,0x6dc00137,0x1a6508c4,0x19880107}},	//   ልጣል_, _كۅپۅ, تیجی_, рбаи_, 
   {{0x05180154,0x7bc80254,0x00000000,0x00000000}},	// [3e740] তপুর_, õdus, --, --, 
   {{0x80d002a6,0x00000000,0x00000000,0x00000000}},	//   তিপ্, --, --, --, 
   {{0xbb440131,0x96b8190d,0xdce40205,0x67e40241}},	//   ﯘﭼﻰ_, рузу_, makı, _ẹlòm, 
   {{0x998000b0,0x76a00241,0xdce41ae9,0xddc402b5}},	//   _kokō_, _aáyá, lakı, kokō, 
   {{0x600c00d2,0x91a401e1,0x92e400bd,0xb0d859c9}},	//   _húmu, _ajo̟_, _পথে_, _बैंग, 
   {{0x6244002e,0xdce40205,0x00000000,0x00000000}},	//   móoy, nakı, --, --, 
   {{0xff4412e3,0x00000000,0x00000000,0x00000000}},	//   _آخ_, --, --, --, 
   {{0x79840564,0x68e802fb,0x78a4000d,0x3ce001ef}},	//   nciw, _šedi, osiv, _osiv_, 
   {{0x12b800cc,0x00000000,0x00000000,0x00000000}},	//   ংবেদ, --, --, --, 
   {{0x81344d2d,0x78a4023a,0x248804d4,0x52746b01}},	//   تسىز_, isiv, íame_, _дуду, 
   {{0xdce40213,0x2bb00037,0x8778008d,0xdb0c007c}},	//   dakı, _जयबा, יטיז, ngbä, 
   {{0xd040016b,0x78a62067,0xb3840345,0x00000000}},	//   _asoɔ, ksiv, _بێژم_, --, 
   {{0x913400dd,0xfbe402f5,0x3ce00393,0x9f440af9}},	//   _براؤ, মানত, _csiv_, ndlê_, 
   {{0x224808ad,0xa3cc07d0,0x63ac0b45,0x00000000}},	//   čake_, ष्प_, ɗans, --, 
   {{0x3ce00472,0x432802d3,0x78a416b8,0x3dd000cc}},	//   _esiv_, _እንተኣ, esiv, িয়ল, 
   {{0x7984d1d6,0x7bc800c5,0x27ec2737,0x5fa000d1}},	//   gciw, õdur, _şen_, _قەۋم, 
   {{0x6e2c0bd7,0x78a62068,0xa81400d1,0xdce403e0}},	// [3e750] _imab, gsiv, пдаш, bakı, 
   {{0x6aa000fc,0x7cd801d9,0x9e2401d9,0x6bd801e2}},	//   álfs, _بوٝز_, _وى۪و, _اودس_, 
   {{0x78a62069,0x00000000,0x00000000,0x00000000}},	//   asiv, --, --, --, 
   {{0x79841730,0x37d80154,0x00000000,0x00000000}},	//   cciw, সাগর, --, --, 
   {{0x6e2e206a,0xc4d80063,0xb5c80214,0x78a401d3}},	//   _mmab, рђе_, تونم_, csiv, 
   {{0x2a6800c5,0x6e2c022e,0x00000000,0x00000000}},	//   lmab_, _lmab, --, --, 
   {{0x65940953,0x6e2e206b,0x26c40036,0xe29828e8}},	//   _наву, _omab, _ëlo_, щай_, 
   {{0x2a68005c,0x00000000,0x00000000,0x00000000}},	//   nmab_, --, --, --, 
   {{0x03a80133,0xdce42ca8,0x00000000,0x00000000}},	//   _نداو_, yakı, --, --, 
   {{0x660a206c,0x23b401ec,0x7984033f,0xb5140241}},	//   _hoek, _ءماس, zciw, _mẹ́n, 
   {{0x660a206d,0x846802d3,0x69c81bce,0x828001b9}},	//   _koek, ኽእልን_, _ñeew, _ўқид, 
   {{0x82345220,0x660a206e,0x2a690bb7,0x78a6206f}},	//   _برطا, _joek, jmab_, ysiv, 
   {{0x600c0798,0x80d001ad,0x224d655f,0x78a4022e}},	//   _súmu, _बैचे, moek_, xsiv, 
   {{0x66080399,0x6e2d1223,0x79880134,0x224e2070}},	//   _loek, _emab, _ɑdwu, loek_, 
   {{0xa3cc810b,0xdce407c4,0x1fe002f5,0x8f9802e4}},	//   ष्य_, rakı, বাদস, _היצי, 
   {{0x78a62071,0x3ce22072,0x79840286,0x66080109}},	//   tsiv, _tsiv_, uciw, _noek, 
   {{0x7e640053,0x78a40140,0x6aa001a8,0x79840142}},	// [3e760] _ihip, usiv, álfr, rciw, 
   {{0x78a432ff,0xa3cc0cb4,0x224e2073,0x600e2074}},	//   rsiv, ष्म_, hoek_, _túmu, 
   {{0x66089045,0x224e2075,0x7e662076,0x09d40011}},	//   _boek, koek_, _khip, হাজা, 
   {{0x69080008,0x78a62077,0x224c030a,0x2b0800bc}},	//   ðsdó, psiv, joek_, सहरु_, 
   {{0x66080097,0x224d6853,0x88804de2,0x68e80064}},	//   _doek, doek_, _пляж, _šedv, 
   {{0xd3b8753d,0x00000000,0x00000000,0x00000000}},	//   суді_, --, --, --, 
   {{0x6609c43a,0x224c0156,0x600c032e,0x00000000}},	//   _foek, foek_, _lúms, --, 
   {{0x66080007,0x224c009d,0xe4300014,0x7e640208}},	//   _goek, goek_, _یہند, _nhip, 
   {{0x3a200280,0x6e2c022e,0x7c3c02d0,0x4c8802dd}},	//   ihip_, _rmab, knrr, _ﺒﻨﺎﺀ_, 
   {{0x66083a0e,0x7e6402b1,0x7094001f,0x42c80154}},	//   _zoek, _ahip, _ያደረጉ_, লয়েশ, 
   {{0x224c193f,0x7e6400cd,0xa3e42052,0x813401d5}},	//   boek_, _bhip, _बोट_, قسیز_, 
   {{0xa3cd8188,0x7e662078,0xb33c0327,0x07340375}},	//   ष्ठ_, _chip, _ndħi, לאים_, 
   {{0x7e662079,0x3ea44606,0x3a20020c,0x00000000}},	//   _dhip, _evnt_, dhip_, --, 
   {{0x7e64ae45,0x2f182f89,0x4ea40022,0x6e2c0810}},	//   _ehip, _моль_, _ериа, _wmab, 
   {{0x9e9459e1,0x00000000,0x00000000,0x00000000}},	//   _قايچ, --, --, --, 
   {{0x6e2d287f,0x7e64014f,0x7f38008f,0x600c01e7}},	//   _umab, _ghip, _לעוו, _fúms, 
   {{0x66084e1b,0xa3e437d0,0x3b8c0092,0xa3ac000d}},	// [3e770] _roek, _बोझ_, ንዳዎች_, _कयल_, 
   {{0x224c0936,0x660a207a,0x2ca80254,0x25bc0142}},	//   zoek_, _soek, _ivad_, wgwl_, 
   {{0x2ca807ad,0x660808e3,0x6e3e207b,0xb33c025c}},	//   _hvad_, _poek, onsb, _jeħd, 
   {{0x3a22207c,0x6e3c0eef,0x2ca8a98d,0x224c01c4}},	//   chip_, nnsb, _kvad_, xoek_, 
   {{0x6e3c0158,0x00000000,0x00000000,0x00000000}},	//   insb, --, --, --, 
   {{0xd24d9fc8,0x6608e264,0x69cc00a9,0x68ee207d}},	//   ینو_, _woek, lfae, mvad, 
   {{0x660a207e,0xb33c0327,0x224d655f,0xa2e4024c}},	//   _toek, _neħd, toek_, фойд, 
   {{0x6e3c01a4,0x82600131,0x2d8c0de2,0x69cc015d}},	//   jnsb, رۇشن, ñeel_, nfae, 
   {{0x25ac0598,0x224e207f,0x7e662080,0x68ee2081}},	//   _idel_, roek_, _rhip, nvad, 
   {{0x6e3c57cf,0x224e2082,0xc87c0730,0x248d71fd}},	//   ensb, soek_, _muß_, _item_, 
   {{0x94242dc3,0xa3cc0f4a,0x1f6400d6,0x6440020c}},	//   _تولۇ, ष्ण_, ьком, _ijli, 
   {{0x7e647fc0,0x6e3e2083,0xdca62084,0xb0d800e1}},	//   _qhip, gnsb, мами, _बैकग, 
   {{0x61e80ec3,0x2d8805d5,0x69cc0007,0x7c3c0115}},	//   mdel, _dfae_, dfae, tnrr, 
   {{0x61e828b3,0x60ca2085,0x2d880270,0x68edb474}},	//   ldel, mtem, _efae_, dvad, 
   {{0x60ca2086,0x69ce2087,0x7e65c2d3,0x248c089c}},	//   ltem, ffae, _thip, _ltem_, 
   {{0x25ae2088,0x69ce2089,0x7e6400b0,0x248c4a41}},	//   _ndel_, gfae, _uhip, _otem_, 
   {{0x61ea208a,0x60ca208b,0x248c016b,0x68ee208c}},	// [3e780] idel, ntem, _ntem_, gvad, 
   {{0x60ca208d,0xc960075b,0x61e8049b,0x64400066}},	//   item, твуй, hdel, _njli, 
   {{0x7bdc1c85,0x60ca208e,0x6d41c771,0x248e208f}},	//   meru, htem, şlat, _atem_, 
   {{0x60c82178,0x7bde2090,0x61ea2091,0x3a200054}},	//   ktem, leru, jdel, qhip_, 
   {{0xd7f8052f,0x18684409,0x25ac0042,0xc48000ec}},	//   _һуң_, _мами_, _ddel_, نڌلي, 
   {{0x7bde2092,0xb33c0135,0x00000000,0x00000000}},	//   neru, _leħe, --, --, 
   {{0x61ea2093,0x248e2094,0x60c9f581,0x59e00406}},	//   fdel, _etem_, etem, _पसार, 
   {{0x7bde2095,0x60ca2096,0x387800ad,0xb33c031c}},	//   heru, ftem, _hirr_, _neħe, 
   {{0x30162097,0x6e3e2098,0x38780356,0x600c032e}},	//   едпр, vnsb, _kirr_, _rúmr, 
   {{0x7bde2099,0x22480bb8,0x61ea209a,0x25ac0219}},	//   jeru, čaka_, adel, _zdel_, 
   {{0x68ee209b,0x61e81e35,0x59ac0490,0x3878d13c}},	//   zvad, bdel, टणार, _mirr_, 
   {{0x60c8f31d,0x20040218,0x61e8b30b,0x68ec219b}},	//   btem, ajli_, cdel, yvad, 
   {{0x60ca209c,0x6e3e209d,0x387852d7,0x00000000}},	//   ctem, rnsb, _oirr_, --, 
   {{0x2018044e,0x09a40490,0xd1dc0023,0xc87c002f}},	//   ësit_, गण्य, ሓንቲ_, _ruß_, 
   {{0x2ca80477,0x69cc030a,0xa2c0102f,0xcf24007b}},	//   _wvad_, tfae, रूप्, _ترشي, 
   {{0x68ee209e,0x7bdc00b0,0x2ca800cd,0x00000000}},	//   tvad, aeru, _tvad_, --, 
   {{0x7d0001e6,0x69cd1043,0x387a209f,0x25ac0139}},	// [3e790] ämst, rfae, _birr_, _rdel_, 
   {{0x7bde20a0,0x61ea20a1,0xe85400db,0x2f1402d2}},	//   ceru, zdel, رناد, _gúgú_, 
   {{0x61ea20a2,0x68ee20a3,0x248e20a4,0x38780254}},	//   ydel, svad, _stem_, _dirr_, 
   {{0x60c8c97b,0x61e80789,0xb33c031c,0x00000000}},	//   ytem, xdel, _xeħe, --, 
   {{0x61ea20a5,0x24f9a965,0x387804e6,0x60c8022f}},	//   vdel, янды_, _firr_, xtem, 
   {{0x61e89add,0x60c801e4,0x628401e4,0x00000000}},	//   wdel, vtem, ŭhom, --, 
   {{0x39380092,0x00000000,0x00000000,0x00000000}},	//   _በመደራ, --, --, --, 
   {{0xd34419d4,0x92b00075,0x61ea20a6,0x25ac0687}},	//   رینه_, اڭلا, udel, _udel_, 
   {{0x61ea20a7,0x7bde20a8,0x38780204,0x248c0ac5}},	//   rdel, yeru, _yirr_, _utem_, 
   {{0x7bdc0483,0x21440374,0x600c10d8,0xb33c025c}},	//   xeru, _āwhā_, _cúmp, _seħe, 
   {{0x7bde20a9,0x61ea20aa,0x2d840118,0xa19400d8}},	//   veru, pdel, ělen_, _заеч, 
   {{0x7bde20ab,0x628003a0,0x63a02aff,0x2a780072}},	//   weru, _iulo, _heln, _nisb_, 
   {{0x628220ac,0x63a220ad,0x247c02e2,0xe1341cd1}},	//   _hulo, _keln, _fňme_, _янды, 
   {{0x7bde20ae,0xb33c031c,0xdd94035b,0x00000000}},	//   ueru, _weħe, ьаҭы, --, 
   {{0x63a220af,0x66180687,0x50180a1e,0xb33c031c}},	//   _meln, kkwk, _מוסו, _teħe, 
   {{0x7bde20b0,0x628220b1,0x09e220b2,0x6d40046c}},	//   seru, _mulo, лосн, ğlar, 
   {{0x6281702e,0x7d000158,0x97b400d8,0x387836b2}},	// [3e7a0] _lulo, åmsd, есеш, _pirr_, 
   {{0x7bde20b3,0x1ae422c3,0x628058b4,0xb60800d7}},	//   qeru, _зоом, _oulo, _mešť, 
   {{0x38780204,0xb6c40032,0xa2c001ad,0xc68c1291}},	//   _virr_, тиеһ, रूम्, مِل_, 
   {{0x2a782a1f,0x38781ba6,0x5b24035b,0x84780023}},	//   _gisb_, _wirr_, _жьҭа, _ክሰምዕ_, 
   {{0x628220b4,0x63a00477,0x38780204,0xb6080122}},	//   _aulo, _beln, _tirr_, _nešť, 
   {{0xb374006c,0x63a000ce,0x387801ab,0x69c80022}},	//   نگاش, _celn, _uirr_, _ñeer, 
   {{0x628220b5,0x63a220b6,0x1dc40490,0xc84002bf}},	//   _culo, _deln, _वाढत, _серй, 
   {{0x628220b7,0x63a0007d,0xc7ac00dd,0xd24421cb}},	//   _dulo, _eeln, _پڑے_, ээли, 
   {{0x628220b8,0x63a220b9,0x4fc4005a,0x609800e5}},	//   _eulo, _feln, нсна, ونٹس_, 
   {{0x63a00497,0x3014013e,0xb6080118,0x2ef4894f}},	//   _geln, тдор, _dešť, взор, 
   {{0x628220ba,0x80d00011,0x87b4010f,0x00000000}},	//   _gulo, তিষ্, עלטס_, --, 
   {{0x63a0013a,0xfb8401ec,0xa0800124,0x00000000}},	//   _zeln, ғырн, ықәк, --, 
   {{0x628001c6,0x2a780010,0xa3cc00dc,0x68480092}},	//   _zulo, _risb_, ष्व_, ናገሩት, 
   {{0x6280bf7c,0x00000000,0x00000000,0x00000000}},	//   _yulo, --, --, --, 
   {{0x628220bb,0xbb848b4d,0xaa5a20bc,0x00000000}},	//   _xulo, الفي, диву_, --, 
   {{0x80d00154,0x00000000,0x00000000,0x00000000}},	//   তির্, --, --, --, 
   {{0x8934072d,0x00000000,0x00000000,0x00000000}},	// [3e7b0] رعرا, --, --, --, 
   {{0xc6a620bd,0x661a20be,0x00000000,0x00000000}},	//   ерди, wkwk, --, --, 
   {{0x6bd852cb,0x63a0003e,0x81d40349,0x644400b0}},	//   _فوکس_, _reln, াযত_, ōhik, 
   {{0x361800d4,0xb6040229,0x6fdc0154,0xdb1c0241}},	//   нцію_, лячк, বায়ে, _ìyár, 
   {{0x62808de8,0xbb340201,0x63a02602,0x00000000}},	//   _sulo, _አስተዋ, _peln, --, 
   {{0x63a0047e,0x00000000,0x00000000,0x00000000}},	//   _qeln, --, --, --, 
   {{0x6280036b,0x63a01d64,0x00000000,0x00000000}},	//   _qulo, _veln, --, --, 
   {{0x6281e9e4,0x920400b0,0x63a001f5,0xd76401ec}},	//   _vulo, _ngāī, _weln, _شەنى_, 
   {{0x63a220bf,0xe0d802bf,0xa0680022,0xaa440092}},	//   _teln, єво_, маиа_, _የእስላ, 
   {{0x628220c0,0xa2c0000d,0xdb0c0200,0x00000000}},	//   _tulo, रंद्, ëkër, --, 
   {{0x62801c06,0x9e642c25,0x00000000,0x00000000}},	//   _uulo, квод, --, --, 
   {{0xa1940816,0x00000000,0x00000000,0x00000000}},	//   _радч, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9f040066,0x00000000,0x00000000,0x00000000}},	//   _لوتو, --, --, --, 
   {{0xe80419e5,0xa1f800f3,0x7d000217,0x00000000}},	//   राना_, šćuš, åmsb, --, 
   {{0x4a4220c1,0x9f440306,0x00000000,0x00000000}},	//   ансв, ndlí_, --, --, 
   {{0x38c8350a,0x20540023,0x57e808ca,0x98a46de9}},	// [3e7c0] عاری_, _ምእሳር, мдам_, тизе, 
   {{0x395c005f,0x00000000,0x00000000,0x00000000}},	//   āvs_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x77940214,0xf3f80139,0xa3ac08a3,0x00000000}},	//   _میذا, нңа_, कणं_, --, 
   {{0x656c0209,0x287401e0,0xd1f00023,0x00000000}},	//   ýaha, _быср, ውዳቕ_, --, 
   {{0x95850229,0x02a220c2,0xcc38008f,0x12e40220}},	//   _албе, арым, ועסט, тілг, 
   {{0xcb1002e4,0x00000000,0x00000000,0x00000000}},	//   שלה_, --, --, --, 
   {{0x920402b5,0x50640276,0xd344036b,0x104a20c3}},	//   _ngāū, ктоа, ریچه_, дяни_, 
   {{0xe80416ae,0x453000d1,0xdfd000ec,0x8fd0013d}},	//   राया_, _ئىكر, ٽيٽ_, рәдә, 
   {{0xa2c039de,0x2f180229,0x00000000,0x00000000}},	//   रूद्, хонь_, --, --, 
   {{0xc20c01d9,0xecc401c6,0xac94c7b0,0xe3b000e5}},	//   _ؤل_, лшгү, ламш, _پرے_, 
   {{0xe8040316,0x23c810dc,0x2cac01c7,0xd1740064}},	//   रामा_, _रामद, éed_, _рыжы, 
   {{0x09c80882,0x00000000,0x00000000,0x00000000}},	//   ाभ्य, --, --, --, 
   {{0xaed4014b,0x00000000,0x00000000,0x00000000}},	//   _сойш, --, --, --, 
   {{0xad240150,0xef340023,0x31440023,0x00000000}},	//   _مىعى, _ብመዓል, _ንቤተክ, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3e7d0] --, --, --, --, 
   {{0x7d580375,0x00000000,0x00000000,0x00000000}},	//   _ביחד_, --, --, --, 
   {{0x291c0f8b,0x9f440306,0x2508158b,0x00000000}},	//   šwa_, ydlí_, کرای_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3dc40428,0xc7c400d8,0x00000000,0x00000000}},	//   òmwi_, _исви, --, --, 
   {{0x60380100,0xf79400c0,0x00000000,0x00000000}},	//   kňma, _варэ, --, --, 
   {{0xd26000fd,0x212800d0,0x2d840118,0x00000000}},	//   әкый, _ťah_, ělej_, --, 
   {{0x26c0079b,0xc3480023,0x78ac007c,0x00000000}},	//   muho_, _ዕንክሊ, _älvä, --, 
   {{0x26c01c06,0x03c5b620,0x358c0023,0x4020010b}},	//   luho_, _асем, _ዕሱባት_, изиң, 
   {{0x1dc40490,0xd0215bc4,0x6038033b,0x6fd40212}},	//   _वाहत, ймый, fňma, ацює, 
   {{0x442408c2,0x5454010f,0xa1b80117,0x00000000}},	//   mhn_, _עסען_, _зулф_, --, 
   {{0x4424003a,0x00000000,0x00000000,0x00000000}},	//   lhn_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x26c220c4,0xa038010f,0x44240051,0x00000000}},	//   kuho_, _רײַז, nhn_, --, 
   {{0xb33c025c,0x00000000,0x00000000,0x00000000}},	//   _leħn, --, --, --, 
   {{0x44240175,0x2ef80fac,0xcb640798,0x00000000}},	//   hhn_, ærfe_, ѓате_, --, 
   {{0x442620c5,0x27e0002f,0x00000000,0x00000000}},	// [3e7e0] khn_, fehn_, --, --, 
   {{0x7794036b,0xc8c401d9,0x27e0002f,0xd9d000db}},	//   شیرا, اوٕن_, gehn_, _گەرگ, 
   {{0x26c01c06,0x442408c2,0x00000000,0x00000000}},	//   guho_, dhn_, --, --, 
   {{0x4424002f,0xd9d000d1,0x00000000,0x00000000}},	//   ehn_, _دەرگ, --, --, 
   {{0xa2c006e3,0x00000000,0x00000000,0x00000000}},	//   रूस्, --, --, --, 
   {{0x26c220c6,0x6ec8013f,0xe80401bc,0x44ac00e4}},	//   buho_, _mɛbr, राणा_, ñasẽ_, 
   {{0x26c000ca,0x51841536,0xd6280640,0xc76401c6}},	//   cuho_, лупа, _зове_, _бирж_, 
   {{0x68ec0254,0x00000000,0x00000000,0x00000000}},	//   _üldõ, --, --, --, 
   {{0x463804ac,0xc6500014,0x442400a3,0xcfa401c6}},	//   _נעמע, _اہنک, bhn_, лшни, 
   {{0x44240732,0x8eb00533,0xdb0d50ff,0xb035022b}},	//   chn_, مەتت, ngbó, рнош, 
   {{0xb33c038f,0xe80408ec,0x08540375,0x00000000}},	//   _ieħo, राता_, רבים_, --, 
   {{0x10a40323,0x27e00428,0xa224004b,0x999000a2}},	//   _бидн, zehn_, _پرمه, nkyń_, 
   {{0x50940640,0x628400d0,0x26c004ce,0xc81c00fb}},	//   _сређ, íhov, zuho_, _мөhи, 
   {{0x26c00230,0xb33c031c,0x00000000,0x00000000}},	//   yuho_, _jeħo, --, --, 
   {{0xfe700517,0xbef4774e,0xa334044e,0x27e006d9}},	//   تدی_, _مريض_, _እንተሃ, vehn_, 
   {{0xacf800c7,0x2bb009bb,0xe70435cf,0x00000000}},	//   _аниу_, _जयका, یسای, --, 
   {{0x442620c7,0x27e0002f,0x00000000,0x00000000}},	// [3e7f0] yhn_, tehn_, --, --, 
   {{0x6d4c022f,0xdb0c03b2,0x7c9468e1,0x26c1b4f5}},	//   _ixaa, ggbó, _اشيا, tuho_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x26c220c8,0x63ac03f9,0x27e12187,0xe5161b8d}},	//   ruho_, ɗany, sehn_, ифлэ, 
   {{0xe80407f7,0x442400a3,0x94c800f1,0x81e000cc}},	//   रादा_, thn_, ناوې_, _ফচল_, 
   {{0x26c00270,0x2908022f,0x4424002d,0x00000000}},	//   puho_, mxaa_, uhn_, --, 
   {{0xb9f0069c,0xa34806bb,0x00000000,0x00000000}},	//   _ዓቢ_, ъзка_, --, --, 
   {{0x57600014,0xe1f8010b,0xe0d80354,0x00000000}},	//   _بۯمِ, тги_, вви_, --, 
   {{0x61442cfe,0xaaa402ab,0x00000000,0x00000000}},	//   репа, गीतक, --, --, 
   {{0x65680944,0xa4900244,0xa0680114,0xd9e00037}},	//   _izeh, _هیچت, ђана_, _पस्ट, 
   {{0xb33c0135,0x6d4d3d3b,0xde045211,0xb2240137}},	//   _jeħl, _axaa, апни, рмөл, 
   {{0xb33c025c,0xb8d8031c,0xe0d40798,0x217407a5}},	//   _meħl, _ཛྷ_, _водњ, _кулр, 
   {{0xa0a50004,0x00000000,0x00000000,0x00000000}},	//   _талд, --, --, --, 
   {{0xe3340020,0x5ef88af9,0x656800ca,0x5574008f}},	//   _እንዳሉ, _ахир_, _mzeh, יערן_, 
   {{0x6d4c0548,0xb33c0327,0xdb1400a2,0x8c402b2e}},	//   _exaa, _neħl, _ücül, цере, 
   {{0xa3540023,0x00000000,0x00000000,0x00000000}},	//   _ምንቕቃ, --, --, --, 
  
   {{0x65680295,0x6dc41075,0x41d400dc,0xccb0008e}},	// [3e800] _nzeh, _ازىل, भ्यस, _мәрь, 
   {{0x48011f22,0x961c3f6f,0x00000000,0x00000000}},	//   опув, पस्ट_, --, --, 
   {{0x6568289d,0x7c3e20c9,0x29080009,0xeac001ec}},	//   _azeh, mirr, axaa_, _нұрп, 
   {{0x7c3c198f,0xb33c025c,0x68440124,0x2da00150}},	//   lirr, _deħl, анӡа, _ﺃﺩﻟﻰ_, 
   {{0x45b4187f,0x00000000,0x00000000,0x00000000}},	//   ргію_, --, --, --, 
   {{0x7c3c0a55,0x65680433,0x92f4007b,0x314c0b82}},	//   nirr, _dzeh, لأعض, ንጸባር, 
   {{0x3a208fe9,0x65682798,0x69ac033f,0x7c3c003e}},	//   okip_, _ezeh, _ज़मी, iirr, 
   {{0x7c3e20ca,0x3a2220cb,0x15b800db,0x00000000}},	//   hirr, nkip_, _шыгы_, --, 
   {{0xb03620cc,0x7c3c0548,0xb33c025c,0x914802e8}},	//   йниш, kirr, _teħo, ъчка_, 
   {{0x7c3c83b4,0x00000000,0x00000000,0x00000000}},	//   jirr, --, --, --, 
   {{0x7c3c09f3,0x80d004c5,0x3a20013c,0xc7b0011a}},	//   dirr, তিগ্, kkip_, חבת_, 
   {{0x2908011f,0x9fc400c7,0x82900244,0x999000a2}},	//   yxaa_, аҳәа_, _بگوڕ, lkyņ_, 
   {{0x2908011f,0x7c3cd3bc,0xa3cc7875,0x00000000}},	//   xxaa_, firr, ष्क_, --, 
   {{0x7c3c01c0,0x7ddc005c,0xcfa8072d,0x00000000}},	//   girr, _påsæ, _شاتم_, --, 
   {{0xca7404a9,0x3a2001a4,0x49a406ed,0x6d4c058a}},	//   لارغ, fkip_, ијаа, _wxaa, 
   {{0x7c3c005a,0xac940139,0x3f78011a,0x00000000}},	//   airr, _лаиш, _באוס, --, 
   {{0x7c3e20cd,0xf8f4084c,0x228400d1,0x00000000}},	// [3e810] birr, оптэ, ﺯﻛﯘﺭ_, --, 
   {{0x3ec0012c,0x7c3e20ce,0x7798013d,0x35f80214}},	//   _ústí_, cirr, икур_, یرند_, 
   {{0xa5f80452,0x6e3c03ac,0x328c0220,0x00000000}},	//   лежу_, oisb, _ﻗﺎﻻﻱ_, --, 
   {{0xd2443584,0x6e3e20cf,0xe298016c,0x64b400c6}},	//   _رن_, nisb, қаи_, محتر, 
   {{0x201001d3,0x62580116,0x24180108,0x87e4117e}},	//   özik_, һрир_, лоды_, _кюве, 
   {{0x9980033b,0xe3b024c5,0xb33c025c,0x00000000}},	//   _ankň_, سرت_, _teħl, --, 
   {{0xf7a80131,0x6e3c1d1d,0x48fc012c,0x00000000}},	//   _ﺷﯘﻧﺪ, kisb, रमको_, --, 
   {{0xd004034c,0xe8040490,0xa204216c,0xf2e400d4}},	//   _בل_, रावा_, спид, юючо, 
   {{0x6568014b,0x6e3e20d0,0x20545e0c,0x6b8402d0}},	//   _uzeh, disb, йтор, _oghg, 
   {{0x60083420,0xb33c025c,0x7c3e20d1,0xb884013a}},	//   уном_, _meħj, xirr, _upíř, 
   {{0xb33c031c,0x7c3d2b14,0xe2d00327,0x3a2002d1}},	//   _leħj, virr, _ཊཱིཀ, ykip_, 
   {{0xdee43461,0x7c3c0014,0x25fc0316,0x6e3e20d2}},	//   _ҳоки, wirr, _रोमी_, gisb, 
   {{0x7c3e20d3,0x00000000,0x00000000,0x00000000}},	//   tirr, --, --, --, 
   {{0x2d8c00e8,0xfc3800c7,0x00000000,0x00000000}},	//   ñeer_, рҭо_, --, --, 
   {{0xff5220d4,0xda6460ee,0x7c3e20d5,0x6e3c0137}},	//   _بخش_, ماري, rirr, bisb, 
   {{0x5984d75f,0x6b840477,0x7c3c198f,0x6e3c0076}},	//   слаб, _eghg, sirr, cisb, 
   {{0x6b180156,0x3a2020ac,0x5744151e,0x00000000}},	// [3e820] ུགཔོ_, rkip_, әнеб, --, 
   {{0x3a2220d6,0x9ad41cb8,0x00000000,0x00000000}},	//   skip_, _люмі, --, --, 
   {{0x3a2220d7,0x3c3800ac,0x4bf8010f,0x00000000}},	//   pkip_, _nüvə_, _עלטס, --, 
   {{0xd94620d8,0x9b882c26,0x4ea8010f,0x00000000}},	//   _геми, _جنگل_, רבײַ, --, 
   {{0x0b380020,0x682001f2,0x00000000,0x00000000}},	//   _አስተማ, _ịdek, --, --, 
   {{0x7e90054e,0xccf0011a,0xcc900150,0x00000000}},	//   _zăpe, פכו_, _ﻛﻮﺯﮔ, --, 
   {{0xd2586145,0xd70620d9,0x6e3c014b,0xc7a004b4}},	//   лци_, _узви, yisb, _хиск, 
   {{0x660c0267,0x6e3c0112,0x00000000,0x00000000}},	//   öakt, xisb, --, --, 
   {{0x3ce00115,0x518401e0,0x54683756,0x00000000}},	//   _npiv_, _һула, _баам_, --, 
   {{0x6e3c0549,0xac9800f2,0x9d6c0092,0x82900372}},	//   wisb, ینجا_, _በሕጋዊ_, زۇۇچ, 
   {{0xd1a40451,0x51840408,0xe2f800e5,0x25fc000d}},	//   _هٽاي, _лула, _پونڈ_, _रोडी_, 
   {{0x80a02756,0x87780677,0xcc9002dd,0x00000000}},	//   _کمون, טאיי, _ﻛﻮﺭﮔ, --, 
   {{0x6e3e20da,0x4638008f,0xab940212,0x7e90054e}},	//   risb, רעכע, жигі, _răpe, 
   {{0x6e3e20db,0x6ec0043e,0xc1080241,0x00000000}},	//   sisb, _विपु, _níṣu_, --, 
   {{0xa3cc7688,0x27f00427,0x7ff109a7,0x2fd8000d}},	//   ष्ट_, _razn_, _رسوا, õrgu_, 
   {{0x9e94036b,0x00000000,0x00000000,0x00000000}},	//   _باوچ, --, --, --, 
   {{0xe8040574,0x9d640014,0xa81401f0,0x1c100037}},	// [3e830] राला_, _ونى۪, одаш, _ठकचल_, 
   {{0x213800d2,0x4cdc0154,0x00000000,0x00000000}},	//   úshi_, মিদু, --, --, 
   {{0xf74800c6,0x27f001d5,0x7c940133,0x00000000}},	//   ملكي_, _vazn_, _وشیا, --, 
   {{0xf770b74d,0x00000000,0x00000000,0x00000000}},	//   رال_, --, --, --, 
   {{0x69dc0a55,0xa50a20dc,0x63855576,0x9f4405e4}},	//   _ibse, рела_, огла, gelê_, 
   {{0xe29a20dd,0xf56800c7,0x4970010a,0x00000000}},	//   аак_, tỹrã_, ĕлĕс, --, 
   {{0x6d4007c4,0xe29a20de,0x68fc037e,0x23280b01}},	//   ğlay, шай_, _hrsd, ройи_, 
   {{0x6d40e16d,0x363401d5,0x00000000,0x00000000}},	//   şlay, _فرقس, --, --, 
   {{0x9f44011f,0x20d40816,0x00000000,0x00000000}},	//   celê_, ційс, --, --, 
   {{0x225c9877,0xfe7800fb,0xa08800db,0x25fc0210}},	//   _wkwk_, әүи_, лсүз_, _रोती_, 
   {{0x5e480d84,0x3ce00076,0x5de4f99a,0x26c05dad}},	//   ипом_, _spiv_, ожна, nrho_, 
   {{0x68fc00a2,0x00000000,0x00000000,0x00000000}},	//   _orsd, --, --, --, 
   {{0xb60802f0,0xdb0c01e3,0x3cf4012d,0x7870008e}},	//   lešá, ngbö, इटें_, läve, 
   {{0x224805ce,0x9f440240,0x10280137,0x051400fe}},	//   čaku_, nelë_, _ۅتۉۉ_, _দেৱৰ_, 
   {{0x78703b22,0x00000000,0x00000000,0x00000000}},	//   näve, --, --, --, 
   {{0x9d4400ee,0xdb0c036e,0x00000000,0x00000000}},	//   _мейд, labë, --, --, 
   {{0x249c0211,0x3ea40368,0x69dc0175,0xd8782d56}},	// [3e840] jpwm_, _hwnt_, _dbse, لمرت_, 
   {{0x6ec000dc,0x69dc02d0,0x1ae40137,0x7870005b}},	//   _विमु, _ebse, _доом, käve, 
   {{0x68fc02d0,0x78703f41,0x47c800f1,0x00000000}},	//   _ersd, jäve, شالۍ_, --, 
   {{0xd49a20df,0xdb0c0240,0x3ea4015d,0x15b83c8f}},	//   арк_, habë, _mwnt_, рыжы_, 
   {{0x6ec05347,0xdb0d813f,0x00000000,0x00000000}},	//   _विभु, ggbö, --, --, 
   {{0xb9d8044e,0xb9f804b2,0x00000000,0x00000000}},	//   _ሽሕ_, _ማሳ_, --, --, 
   {{0xe7b00014,0x7870007c,0x00000000,0x00000000}},	//   _سۅند, rävd, --, --, 
   {{0xb33c025c,0xb1140640,0x1dc423e9,0xb634072d}},	//   _jeħi, змиш, _वागत, _عکاش, 
   {{0xdb0c006a,0x3cf4033f,0x9f440240,0x00000000}},	//   fabë, इटों_, belë_, --, 
   {{0xd01a20e0,0xb33c031c,0x926800fb,0xd46800db}},	//   рфи_, _leħi, ырһа_, _тизе_, 
   {{0x6e3c007f,0x00000000,0x00000000,0x00000000}},	//   èrbo, --, --, --, 
   {{0x3f84022c,0xb33c031c,0x3e8402e2,0x00000000}},	//   _egnu_, _neħi, vètè_, --, 
   {{0xdb0c0ba1,0x704400db,0x00000000,0x00000000}},	//   labè, _ىرتە, --, --, 
   {{0xdbe8002e,0x29040311,0x8aa41513,0x5ea800eb}},	//   _bёña, _ăla_, жрад, _কমরে, 
   {{0xb0240016,0x69dc00d7,0x00000000,0x00000000}},	//   _giườ, _pbse, --, --, 
   {{0xc33c02d3,0xe7dc00dc,0xcd2801c8,0x69dc0139}},	//   _ክንጥቀ, न्नप, _نسخن_, _qbse, 
   {{0x69dc93fc,0x8d7620e1,0xa7b8c2db,0x7d7801d9}},	// [3e850] _vbse, _باغا, йлау_, _وۅپر_, 
   {{0x872438eb,0xdb0c0214,0x00000000,0x00000000}},	//   يعام, kabè, --, --, 
   {{0x2ca80198,0x36d42be9,0x9f44036e,0xaa58009b}},	//   _hwad_, дохр, velë_, _гину_, 
   {{0x2ca80086,0x69d80295,0x68fc020c,0x86840023}},	//   _kwad_, òwed, _trsd, _ንነፍሲ_, 
   {{0x3db002f5,0x69cc0007,0x68fc0857,0xb0580023}},	//   _কামল, mgae, _ursd, _ምጥንቃ, 
   {{0x787033f7,0x2ca80100,0x68ec7af8,0xdb0e20e2}},	//   täve, _mwad_, mwad, fabè, 
   {{0x68ee20e3,0x2008001e,0xb9f8001f,0x6ab401d3}},	//   lwad, _đai_, _ማታ_, nszf, 
   {{0x69ce20e4,0x2d881682,0x5ea802f5,0x00000000}},	//   ngae, _ngae_, _কমলে, --, 
   {{0x68ee20e5,0x7870023a,0x9f4620e6,0x00000000}},	//   nwad, säve, melé_, --, 
   {{0x25ad8d38,0x2d8a20e7,0xc30442b5,0xdb0c02e2}},	//   _heel_, _agae_, _وباو, babè, 
   {{0x2caa20e8,0x25ae20e9,0xdb0d9bd2,0x69ce20ea}},	//   _awad_, _keel_, ngbô, kgae, 
   {{0x68ee20eb,0x69cc0007,0x224a20ec,0x2484022e}},	//   kwad, jgae, _ñak_, _hilm_, 
   {{0x25ac0a81,0x61ea20ed,0x2ca80142,0x22900306}},	//   _meel_, meel, _cwad_, _hák_, 
   {{0x61ea20ee,0x68ee20ef,0x9f4620f0,0x25ac00e8}},	//   leel, dwad, helé_, _leel_, 
   {{0x60c80369,0xcfbc0075,0x9f4620f1,0x248c003a}},	//   luem, _ﻣﯘﻧﺒ, kelé_, _luem_, 
   {{0x1dc405ba,0x61ea20f2,0x25acd909,0x247c0100}},	//   _वाटत, neel, _neel_, _dňmi_, 
   {{0x60ca20f3,0x68ee20f4,0x248c0007,0x2ca80489}},	// [3e860] nuem, gwad, _nuem_, _gwad_, 
   {{0x61ea20f5,0xdb0c02ea,0x7e900311,0x69cc005a}},	//   heel, habé, _zăpa, agae, 
   {{0x61ea20f6,0xdb0c3386,0x248c180f,0x25ac01d9}},	//   keel, kabé, _auem_, _beel_, 
   {{0x7bdc008f,0x61e822a9,0xd1d4044e,0x60ca20f7}},	//   lfru, jeel, ጭታት_, kuem, 
   {{0x25ad61e5,0x68ec2935,0x61ea20f8,0xdb0e20f9}},	//   _deel_, cwad, deel, dabé, 
   {{0x7bde20fa,0x60c80428,0x248e20fb,0xdb0c1f5d}},	//   nfru, duem, _duem_, tabè, 
   {{0x25ac8977,0x61ea20fc,0x9f440296,0x6ec00864}},	//   _feel_, feel, belé_, _विधु, 
   {{0x25ae20fd,0x61ea20fe,0x9f45ce83,0xdb0c067c}},	//   _geel_, geel, celé_, rabè, 
   {{0xd5740323,0x60c9c8b0,0x1dc40574,0x24847d6a}},	//   _хувь, guem, _वाजत, _film_, 
   {{0x2d887c3f,0x6ec00882,0x7bdcb4b6,0x7e90054e}},	//   _sgae_, _विदु, jfru, _săpa, 
   {{0x61ea20ff,0x91e5b2b5,0x7bdc00b5,0x229003b2}},	//   beel, _ноже, dfru, _gák_, 
   {{0x998002e2,0x61ea2100,0x25ac292a,0x69cc0399}},	//   _ankō_, ceel, _xeel_, xgae, 
   {{0x229002fb,0x4f6401d3,0x7bdc0135,0x68ec0067}},	//   _zák_, _کاشف, ffru, xwad, 
   {{0x69cc0399,0xd0200150,0x7bdca75f,0x68ec033b}},	//   wgae, _سوعۋ, gfru, vwad, 
   {{0x1dc40490,0x3fd80375,0x68ee2101,0x0dc89a4a}},	//   _वाचत, _הקוב, wwad, _лупи_, 
   {{0x34dc03f8,0x2ca8000f,0xa2c001ad,0x7bdc0332}},	//   _यहूद, _twad_, रूट्, afru, 
   {{0x25ae2102,0x6e2e2103,0x291c006a,0x9f462104}},	// [3e870] _reel_, _ilab, âwa_, velé_, 
   {{0x6e2e2105,0x68ee2106,0x61e9c87c,0xa7b80220}},	//   _hlab, rwad, zeel, ілеу_, 
   {{0x6e2e2107,0x25ac1590,0x9f440316,0x68ee2108}},	//   _klab, _peel_, telé_, swad, 
   {{0x22905c0c,0x69cc0097,0x24840037,0xd7080131}},	//   _rák_, qgae, _silm_, تىمۇ_, 
   {{0x248e2109,0x25ae210a,0x61e958f3,0x6e2c0117}},	//   _quem_, _veel_, veel, _mlab, 
   {{0x61ea210b,0x25ac4f7f,0x2a6a210c,0x9f4402fb}},	//   weel, _weel_, llab_, selé_, 
   {{0x6e2e210d,0x61ea210e,0x25ae210f,0x9f462110}},	//   _olab, teel, _teel_, pelé_, 
   {{0x2a68036b,0x60c91a96,0x24840421,0x85b80014}},	//   nlab_, tuem, _wilm_, _داسس_, 
   {{0x61ea2111,0xfe780323,0xdb0d8f12,0x248c00c5}},	//   reel, үүл_, rabé, _uuem_, 
   {{0x2a68006c,0x2484011c,0x6e2e2112,0xa3080014}},	//   hlab_, _uilm_, _alab, _وراے_, 
   {{0x61ea2113,0x6e2e2114,0x660a2115,0x2a6a2116}},	//   peel, _blab, _knek, klab_, 
   {{0x6e2e2117,0x442431e5,0x60c80618,0x61e8022f}},	//   _clab, lkn_, puem, qeel, 
   {{0x60c925be,0x2a68036b,0x7bdc369d,0x224c01ed}},	//   quem, dlab_, tfru, mnek_, 
   {{0x7afc0bb8,0x224d5efa,0x44262118,0xe1f80006}},	//   tvrt, lnek_, nkn_, ldų_, 
   {{0x660a2119,0x7bde211a,0x224dfaa4,0x442400cc}},	//   _onek, rfru, onek_, ikn_, 
   {{0x7bdd12c0,0x442402b4,0xe1f802d5,0x224e211b}},	//   sfru, hkn_, ndų_, nnek_, 
   {{0x7e66211c,0x44240ac5,0xe1f80024,0x224e211d}},	// [3e880] _ikip, kkn_, idų_, inek_, 
   {{0x660a211e,0x2a680280,0x76d8016c,0x7bc00153}},	//   _anek, alab_, зудӣ_, ėmus, 
   {{0x224c066d,0x2a6a211f,0x75e4007f,0xb33c003d}},	//   knek_, blab_, _lčzō, _jeħt, 
   {{0xb33c038f,0x6ec01546,0x28a812eb,0x00000000}},	//   _meħt, _विसु, _चौकि, --, 
   {{0x224c01ed,0x66080036,0x7e6401f7,0x442401c7}},	//   dnek_, _dnek, _mkip, fkn_, 
   {{0x44240a2e,0x660a2120,0x224c5440,0xe1f80024}},	//   gkn_, _enek, enek_, edų_, 
   {{0x7e662121,0xb33c025c,0x00000000,0x00000000}},	//   _okip, _neħt, --, --, 
   {{0x224e2122,0x65b801c0,0x15b00150,0x00000000}},	//   gnek_, _нуур_, _شەتس, --, 
   {{0x44240ac5,0x76404b0a,0x4fc4005a,0x00000000}},	//   bkn_, _immy, мсна, --, 
   {{0x224e2123,0x7e662124,0x44241ba6,0x2a6801b9}},	//   anek_, _akip, ckn_, zlab_, 
   {{0xb8d0f7c6,0x224c0429,0x6e2e2125,0x2a6801b9}},	//   _ནས_, bnek_, _plab, ylab_, 
   {{0x2a6801a9,0x00000000,0x00000000,0x00000000}},	//   xlab_, --, --, --, 
   {{0x7ff0034d,0xad246788,0x2a6a2126,0x63800124}},	//   رسیا, رىسى, vlab_, _иҳәа, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2a6a2127,0x7e640270,0x29040069,0x6e2e2128}},	//   tlab_, _fkip, _ōla_, _tlab, 
   {{0x6e2e2129,0x7e4400c7,0x787001f4,0x201400d7}},	//   _ulab, _ахье, väva, ĺbiť_, 
   {{0x2a68036b,0xa9540640,0x00000000,0x00000000}},	// [3e890] rlab_, хваљ, --, --, 
   {{0x2a682eb6,0x7872212a,0x224dc550,0x47c400bd}},	//   slab_, täva, znek_, র্নী, 
   {{0x224e212b,0xf9900f31,0x359c00b4,0x2a6a212c}},	//   ynek_, ابہ_, _ịbụ_, plab_, 
   {{0x2a68036b,0x78703f64,0xc8c405f9,0x2d9801d3}},	//   qlab_, räva, _लिपट, ncse_, 
   {{0x44242948,0x7870023a,0x00000000,0x00000000}},	//   tkn_, säva, --, --, 
   {{0x7642212d,0x224c005a,0x787001f4,0x00000000}},	//   _emmy, wnek_, päva, --, 
   {{0x224c00dd,0x4426212e,0x7e900356,0x6ec01df0}},	//   tnek_, rkn_, _răpo, _विषु, 
   {{0x44240ac5,0x224c153b,0xe1f80153,0x00000000}},	//   skn_, unek_, udų_, --, 
   {{0x224e212f,0xb33c025c,0x60240801,0x44242b10}},	//   rnek_, _beħs, едпа, pkn_, 
   {{0x7e662130,0x224e2131,0x6568209c,0x6ec04f3c}},	//   _skip, snek_, _iyeh, _विशु, 
   {{0xd24d5312,0x65680134,0x764002a4,0x6441a97a}},	//   شنی_, _hyeh, _ymmy, _imli, 
   {{0x6ec06236,0x644000d7,0xe5f80166,0x12f8011a}},	//   _विरु, _hmli, _üsäç, _מהעב, 
   {{0x9f440418,0x62659ecb,0x00000000,0x00000000}},	//   melí_, _قاچق, --, --, 
   {{0x61fa2132,0x9f440418,0x20d8067c,0xb33c0003}},	//   _hawl, lelí_, mèi_, _teħt, 
   {{0x61fa2133,0xdbd00037,0x00000000,0x00000000}},	//   _kawl, müük, --, --, 
   {{0x7e662134,0x61f8047e,0x9f440270,0x47c40154}},	//   _ukip, _jawl, nelí_, র্মী, 
   {{0x61fa2135,0x6568537b,0xd88807d2,0x00000000}},	// [3e8a0] _mawl, _nyeh, سپان_, --, 
   {{0x61f9ca4e,0x7d055762,0xdbd00254,0x00000000}},	//   _lawl, _iris, nüük, --, 
   {{0x7d062136,0x6568013e,0x23c844eb,0x78700267}},	//   _hris, _ayeh, _राजद, bävn, 
   {{0x4a9800c8,0x64400368,0x61fa0290,0xdb0e2137}},	//   _מיטג, _amli, _nawl, nabí, 
   {{0x64400334,0x9f441155,0x00000000,0x00000000}},	//   _bmli, delí_, --, --, 
   {{0x78a62138,0x7d040451,0x6ec00b7d,0x850000f1}},	//   mpiv, _mris, _विलु, اوون, 
   {{0x656a2139,0x61f8ea49,0xa86401af,0x78700139}},	//   _eyeh, _bawl, _рерҙ, lävo, 
   {{0x7d06213a,0x6442213b,0x61f803d9,0xd138974c}},	//   _oris, _emli, _cawl, зхо_, 
   {{0x61f80a81,0xe8040574,0x7d04020c,0xef940133}},	//   _dawl, राचा_, _nris, نیشد, 
   {{0x53a4007b,0xd24c0014,0x3db000fe,0x00000000}},	//   _أماك, _گۆب_, _কাষল, --, 
   {{0xdb0c019f,0xdb780075,0x7d06213c,0x61f80175}},	//   habâ, ﻠﯩﺮﻯ_, _aris, _fawl, 
   {{0xa2c0891e,0xd1380f06,0x61fa213d,0x00000000}},	//   _тәшк, _нхл_, _gawl, --, 
   {{0xd00802dd,0x644100d7,0x850007f7,0x7870007c}},	//   _неде_, _ymli, लियट_, vävn, 
   {{0x00f40375,0x78a400d0,0x00000000,0x00000000}},	//   _נמוך_, dpiv, --, --, 
   {{0x7d06213e,0x935002d3,0xef100137,0x61fa213f}},	//   _eris, _ዝንቀሳ, _түнө, _yawl, 
   {{0x61f80067,0x00000000,0x00000000,0x00000000}},	//   _xawl, --, --, --, 
   {{0x7d041675,0xac18005b,0xbdf8009f,0xfd4400db}},	// [3e8b0] _gris, _жопу_, _سريا_, _бээн, 
   {{0x38780bef,0xb33c031c,0x67240108,0x00000000}},	//   _chrr_, _leħq, tyhj, --, 
   {{0x656801c7,0x7d040010,0x3dc00142,0x6fd869dd}},	//   _syeh, _zris, _ydiw_, _मानू, 
   {{0xdbd001b8,0x64400175,0xc5040014,0x00000000}},	//   züük, _smli, ى۪زل_, --, 
   {{0xa31400c6,0x61fa2140,0x25083028,0x7d049f98}},	//   _ılıح_, _rawl, برای_, _xris, 
   {{0x61fa2141,0xdb0cfdbb,0xc7c4022e,0x3cfc0677}},	//   _sawl, zabí, _ясми, פלונ, 
   {{0x61f95cf1,0x6568017a,0xd34401d5,0x16000210}},	//   _pawl, _wyeh, پینه_, _रोवर_, 
   {{0x61f851ab,0x00000000,0x00000000,0x00000000}},	//   _qawl, --, --, --, 
   {{0x656800aa,0x64400334,0xf44800f1,0xdbd00254}},	//   _uyeh, _tmli, _ګټلو_, tüük, 
   {{0x64402935,0x7d052f11,0x2a780175,0xd18000fd}},	//   _umli, _rris, _lhsb_, шлый, 
   {{0x47c400bd,0x94240372,0x8eb000c7,0x9f442afb}},	//   র্থী, _جولۇ, аӡых, pelí_, 
   {{0x27000953,0x75240036,0x00000000,0x00000000}},	//   _mėn_, äizg, --, --, 
   {{0xdb0cb8a3,0x7d04022e,0x3c340254,0xc10001e0}},	//   rabí, _qris, _läve_, _сүпл, 
   {{0x7d062142,0xbb6800b5,0xda641e5a,0x6fd81be1}},	//   _vris, _newレ_, چاري, _मायू, 
   {{0xdb0d9914,0xcb65553f,0x60c83453,0xda65de9b}},	//   wabâ, варе_, lrem, ناري, 
   {{0x60ca2143,0x9f4406d9,0x78700793,0x1db40c93}},	//   orem, melà_, tävo, _अजित, 
   {{0x60ca2144,0x7d062145,0x6e3c02d3,0xdc9807d6}},	// [3e8c0] nrem, _uris, ërbe, _ўтиш_, 
   {{0x60ca2146,0x61100296,0x78a607d6,0x00000000}},	//   irem, gɛlɛ, rpiv, --, 
   {{0x3c34007c,0x1db417c6,0x787001f4,0x68e80171}},	//   _vävd_, _अजात, sävo, _ģede, 
   {{0x78a40e03,0x6aa000ae,0x00000000,0x00000000}},	//   ppiv, ílfe, --, --, 
   {{0x61100085,0xddc40100,0x281000d1,0x75040124}},	//   bɛlɛ, rikň, _گۈلس, ыҟае, 
   {{0x07a22147,0x645c007b,0xc7a0010a,0xc2e800eb}},	//   _варн, _ísil, _вирк, কিনি_, 
   {{0x60ca2148,0x25fc216a,0x00000000,0x00000000}},	//   erem, _रोकी_, --, --, 
   {{0x60ca2149,0x51849b81,0xf66400cf,0x00000000}},	//   frem, купа, _себү, --, 
   {{0xfbb800bd,0x1adc0eac,0x25aa214a,0x00000000}},	//   _জানত, ডিয়া, ñale_, --, 
   {{0x9f440109,0x9378f85d,0x2ef401f0,0x00000000}},	//   felà_, _قصار_, гзор, --, 
   {{0x60ca214b,0x9f440589,0x00000000,0x00000000}},	//   arem, velã_, --, --, 
   {{0x8142214c,0x90c40f64,0x31e000eb,0x3c6c00d1}},	//   انین, _абде, _মোরশ, ﺰﯨﺘﻰ_, 
   {{0x787001e6,0x0fe2214d,0x4ba400f7,0x00000000}},	//   tävl, _көнү, көнү_, --, 
   {{0x09c82699,0x9f440ffb,0x0b740092,0x00000000}},	//   िल्य, belà_, _በስውር_, --, 
   {{0x35d800af,0x00000000,0x00000000,0x00000000}},	//   _डाढ़, --, --, --, 
   {{0x79a434d8,0x7a3800d2,0x39a46496,0x6a140032}},	//   ируе, _lítf, ишув, ымбу, 
   {{0x25fc1df1,0x3c34007c,0x9f440419,0x00000000}},	// [3e8d0] _रोगी_, _säve_, melá_, --, 
   {{0xe7b411a4,0x38346141,0xc6a410fc,0xd76401d5}},	//   اماد, анур, врди, گنمی, 
   {{0x6e9c00e8,0x60c801d3,0xb71801f4,0x00000000}},	//   _d斡g斡, zrem, кофф_, --, 
   {{0x60ca214e,0xa5359e06,0x57a40032,0xe4b80220}},	//   yrem, лнеч, _ҡысҡ, елді_, 
   {{0x17b00183,0xc98410fc,0x5a140a7c,0x436c00d1}},	//   _চাৰি, _јуни, _עקשן_, ﺷﺘﯩﻦ_, 
   {{0x60c80552,0x87040139,0x442832eb,0x656c025c}},	//   vrem, _иябе, ьцем_, żaho, 
   {{0xe1f000c6,0x00000000,0x00000000,0x00000000}},	//   مسة_, --, --, --, 
   {{0xdee4c78a,0x00000000,0x00000000,0x00000000}},	//   қоми, --, --, --, 
   {{0x60ca214f,0x9f580118,0x8544b689,0x31140006}},	//   urem, ěsí_, _рэве, афэс, 
   {{0x60ca2150,0x6fd80574,0x3db003d4,0x75240221}},	//   rrem, _माणू, _কাইল, äize, 
   {{0x60ca2151,0x5f440597,0x4dc40116,0x00000000}},	//   srem, انجل, ﯨﺪﯦﻨ, --, 
   {{0xdca4be82,0x60c81948,0x5ca50879,0xd29800df}},	//   лами, prem, лимб, _טשעט, 
   {{0xd3f40183,0x00000000,0x00000000,0x00000000}},	//   চাৰি_, --, --, --, 
   {{0x9f040502,0x8fa000c7,0x557400c8,0x92d40183}},	//   _موتو, _лаше, טערן_, িবৰ_, 
   {{0xdee407a5,0x00000000,0x00000000,0x00000000}},	//   _сойи, --, --, --, 
   {{0x9f4402f0,0x4de00118,0x00000000,0x00000000}},	//   celá_, ट्दै_, --, --, 
   {{0x98a4d4de,0xfbdc000d,0xad5800c0,0xe0e000eb}},	// [3e8e0] уизе, _बापम, _арэх_, বিকভ, 
   {{0xb8ec74ad,0x00000000,0x00000000,0x00000000}},	//   _रट_, --, --, --, 
   {{0x8f98011a,0x00000000,0x00000000,0x00000000}},	//   תיעי, --, --, --, 
   {{0x7a380af2,0xdb0c04d7,0x7e900311,0x00000000}},	//   _sítf, cabá, _căpi, --, 
   {{0x25f40037,0x93e401d5,0x00000000,0x00000000}},	//   _एघरी_, гўйл, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x02a02401,0x26100073,0xa69400f3,0x00000000}},	//   брым, णाशी_, _вруј, --, 
   {{0xb9dc067d,0x00000000,0x00000000,0x00000000}},	//   _ኢና_, --, --, --, 
   {{0xb0341e37,0x26100574,0x25fc924b,0x9f440030}},	//   иниш, णारी_, _रोटी_, velá_, 
   {{0xf1a51269,0xdb0c01ed,0xc480041b,0x00000000}},	//   _ग्रन, zabá, _глук, --, 
   {{0xd2b401a9,0x00000000,0x00000000,0x00000000}},	//   _ёқиш_, --, --, --, 
   {{0xe2a80050,0xa074004e,0x00000000,0x00000000}},	//   _شامن_, лгөч, --, --, 
   {{0x6ec0043e,0x9f440419,0x00000000,0x00000000}},	//   _विकु, relá_, --, --, 
   {{0xcfa4036b,0x9f4402fb,0xcf2415e9,0x0b8800db}},	//   _ёшли, selá_, _مربي, есби_, 
   {{0xdb0c19ff,0x753c00ac,0x24880268,0xbea00e92}},	//   tabá, _ərza, ìami_, _лајк, 
   {{0x229001a6,0xad240150,0xac94189d,0x8ae402dd}},	//   _uške_, _نىعى, _каиш, кіұл, 
   {{0xdb0c99a0,0x7e900311,0x00000000,0x00000000}},	// [3e8f0] rabá, _răpi, --, --, 
   {{0x25fc05ba,0x8b6400db,0xdb0c31b7,0x00000000}},	//   _रोजी_, _ماجم, dabæ, --, 
   {{0xc6a62152,0x86262153,0x37cc0154,0x26101cd2}},	//   урзи, льде, র্ভর, णाली_, 
   {{0x6aa40042,0x00000000,0x00000000,0x00000000}},	//   _ithf, --, --, --, 
   {{0x998002e2,0x3c340267,0xdb0c02d2,0x00000000}},	//   _ankņ_, _häva_, gabæ, --, 
   {{0xd90c066d,0xf7940006,0x394401a8,0x37cc00eb}},	//   _کیے_, _гарэ, _ýmsa_, র্বর, 
   {{0x93740075,0xf7700345,0x638800c7,0x00000000}},	//   һбәт_, _فاف_, тӡам_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x20562154,0xdcec005f,0xd5a4249f,0x21741171}},	//   итор, ājīb, _خلقی, шукр, 
   {{0x6ec00574,0x846400a7,0x12c80228,0x00000000}},	//   _विखु, _събе, ردۉۉ_, --, 
   {{0xdee4f9c9,0x3ea00240,0x2c1800cd,0x62340798}},	//   шони, ëjt_, दानं_, _кежу, 
   {{0x2f541b0a,0xdb0c03e3,0x71340139,0x00000000}},	//   стьс, labç, рҗәт_, --, 
   {{0x6aa4007b,0x6f1c01bf,0x6e3c0200,0xed34009d}},	//   _athf, ørcr, ërba, бэрэ, 
   {{0x9138008f,0xabd401d9,0x00000000,0x00000000}},	//   _בענק, ٝزِت, --, --, 
   {{0x8b2011e5,0x7a3813db,0x004400f1,0x00000000}},	//   одре, _líte, _لیکي_, --, 
   {{0xc0f002d3,0x3c340166,0xdde8027d,0x6ec4007b}},	//   ፍጣር_, _däva_, _شرعه_, _اتوق, 
   {{0xada877a7,0x77e802a9,0x89d401d5,0x78700958}},	// [3e900] _صديق_, ллаҳ_, شولر_, lävi, 
   {{0x9f4401bf,0xf8a80133,0x00000000,0x00000000}},	//   relæ_, ندڕه_, --, --, 
   {{0x103400c8,0x5fdc4fed,0xddc400b0,0x6fd802a0}},	//   סטעם_, _मानल, hikō, _मासू, 
   {{0x7a3972bf,0x14c8034b,0x9f4407d9,0x211401f9}},	//   _bíte, выки_, melä_, तमाळ_, 
   {{0x25aa2155,0x78701577,0x7a380419,0x00000000}},	//   ñala_, hävi, _cíte, --, 
   {{0x7870005b,0x04400063,0xdb0c03f2,0x00000000}},	//   kävi, жељн, rabæ, --, 
   {{0xdb1c1d55,0xd258030d,0x00000000,0x00000000}},	//   _odpí, кци_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x100800c6,0xbb58037e,0x92d40154,0x00000000}},	//   نتدى_, zのpc, িবে_, --, 
   {{0x91a40034,0x7e90054e,0x9f44005b,0x00000000}},	//   _ट्रै, _lăpu, kelä_, --, 
   {{0x7870007c,0x00000000,0x00000000,0x00000000}},	//   rävh, --, --, --, 
   {{0x518454f2,0x52753f0f,0x43700214,0x51644bcc}},	//   _кула, _тузу, _بهمر, _квеб, 
   {{0x7d24011c,0xdb0c013d,0x00000000,0x00000000}},	//   офре, habä, --, --, 
   {{0x80a01129,0x6fb40b73,0x00000000,0x00000000}},	//   _بمون, _امثا, --, --, 
   {{0x0a68016c,0x7c280267,0x27ec01e4,0x60cc00df}},	//   враи_, ödra, _ĝen_, _ĥami, 
   {{0x0dc87724,0x27ec0115,0xe48402d3,0x7e90054e}},	//   _руки_, _ŝen_, _ምዃንካ_, _căpu, 
   {{0x5fdc534e,0xc98413b5,0x30f800cd,0x00000000}},	// [3e910] _मामल, руви, ्टिः_, --, 
   {{0x3c3401b8,0xdcb00150,0xb51c00cc,0x9f440139}},	//   _täva_, _عىپ_, থনাথ_, belä_, 
   {{0xfbdc05ba,0xf7701fe4,0x478a2156,0x69c4010b}},	//   _बातम, وام_, тсам_, _гөзб, 
   {{0x30f82314,0x857c1df2,0x00000000,0x00000000}},	//   ्टाः_, _ﺩﻭﺭﺍ_, --, --, 
   {{0x24e801b9,0x5a14011a,0x9ac0025c,0x00000000}},	//   умли_, _הקרן_, ċċed, --, 
   {{0x229001fa,0x7a38012c,0x21f0004d,0x68fc02d0}},	//   _aška_, _víte, _ạh_, _issd, 
   {{0xd24c00aa,0x68fc03ac,0xa0681219,0x20080139}},	//   کني_, _hssd, ғана_, _ğai_, 
   {{0xe1f84140,0x7a382b76,0x26c22157,0x6ec01f13}},	//   уги_, _títe, msho_, _विजु, 
   {{0x50a00075,0x26c001d9,0x9f4400fd,0xddd4010e}},	//   كەنل, lsho_, zelä_, _akyş, 
   {{0x787002f6,0xca300ed1,0xddc5513c,0x26c00009}},	//   tävi, ﺪﺍﺭ_, rikō, osho_, 
   {{0x6fd80574,0x26c22158,0x69dc062c,0x9e6402e8}},	//   _मारू, nsho_, _ocse, йвод, 
   {{0x6d40008f,0x2a680810,0x26c18cfe,0x37d003d4}},	//   ĝlan, joab_, isho_, স্পৰ, 
   {{0x224e2159,0xf1dc27a6,0x2240020c,0x7e900356}},	//   miek_, _यातन, èhku_, _răpu, 
   {{0x224e215a,0x9f440724,0x7e90054e,0x92e803d4}},	//   liek_, telä_, _săpu, মিৰ_, 
   {{0x8c42215b,0x9f94007d,0x68fc062c,0x38c804d3}},	//   чере, _müük_, _assd, ڤاری_, 
   {{0x224e215c,0x9f440598,0xd9440137,0xd9b001ad}},	//   niek_, relä_, беби, जरेट, 
   {{0x68fc014b,0x69dc010a,0x99800022,0x57e81ac1}},	// [3e920] _cssd, _dcse, _kokũ_, лдам_, 
   {{0x80cc044b,0x224e215d,0x7e90054e,0x69de215e}},	//   _दिने, hiek_, _făpt, _ecse, 
   {{0x224c5456,0x95c931b9,0x68fc035a,0x4fb8008f}},	//   kiek_, гула_, _essd, רזעצ, 
   {{0x69dc010a,0x224c0165,0x00000000,0x00000000}},	//   _gcse, jiek_, --, --, 
   {{0x6fd81533,0x26c00014,0x00000000,0x00000000}},	//   _मालू, asho_, --, --, 
   {{0x9696181c,0x26c00067,0xb4e81bbb,0x00000000}},	//   _граш, bsho_, _बही_, --, 
   {{0x224c2595,0x26c00009,0x02a00006,0x91680241}},	//   fiek_, csho_, прым, _ẹ̀_, 
   {{0x224e215f,0x644e2160,0x25bc0009,0x3a201017}},	//   giek_, éair, cawl_, njip_, 
   {{0xb4040220,0xc9c000d1,0x622400db,0x00000000}},	//   _мүдд, ﺭﯗﻟﻐ, تويە, --, 
   {{0x16140073,0xa3b80d2e,0x00000000,0x00000000}},	//   णावर_, चरण_, --, --, 
   {{0xb4e815e0,0x224c6107,0xc7b00375,0x212c013f}},	//   _बहु_, biek_, הבת_, ayeh_, 
   {{0x90e40502,0x224c5123,0xd1dc0023,0x00000000}},	//   _هستن, ciek_, ናሕቲ_, --, 
   {{0x7e9000a8,0x6264b29d,0x3a20000f,0x704402dd}},	//   _săpt, _بالق, djip_, _ورتە, 
   {{0x68fc0579,0x3940005f,0x26c00009,0x00000000}},	//   _rssd, dzis_, ysho_, --, 
   {{0x5ec803ee,0x4ea62161,0x26c00067,0x787001f4}},	//   _кöяƒ, _урла, xsho_, nävu, 
   {{0xb4e81d7d,0x69340137,0x0a681503,0xbea401f7}},	//   _बहू_, онбу, урги_, _اهين_, 
   {{0xe7b8074d,0x26c0058a,0x9f440450,0xbd6800c0}},	// [3e930] игаш_, wsho_, relå_, _грэе_, 
   {{0x26c1ed54,0x224e2162,0x00000000,0x00000000}},	//   tsho_, ziek_, --, --, 
   {{0x224c0369,0x25a804d4,0x00000000,0x00000000}},	//   yiek_, ñalo_, --, --, 
   {{0x26c22163,0x212c011f,0x224c005a,0x328c1d00}},	//   rsho_, yyeh_, xiek_, _ﺗﺎﻻﻱ_, 
   {{0x224c01f1,0xd1dc001f,0x26c0037e,0xe3b80fbe}},	//   viek_, ናንት_, ssho_, абл_, 
   {{0x66e001e4,0xe3b00d17,0x224c0034,0x290801f7}},	//   _aŭkŝ, ذرت_, wiek_, mvaa_, 
   {{0x224e2164,0x69d80086,0x7bdc08a8,0xe2840353}},	//   tiek_, òwew, אקוו, олки, 
   {{0xa4d400d6,0x6e3c0023,0x2ca81710,0x6f08037e}},	//   _мобі, ërbl, _otad_, dvdc, 
   {{0x224e2165,0x7e900356,0x2368033f,0x4ea001ec}},	//   riek_, _năpr, łaj_, _ﺍﻟﻨﻅ_, 
   {{0x224e2166,0x9980033b,0xe04402bf,0x3ea4004d}},	//   siek_, _dakň_, інни, _ptnt_, 
   {{0xdb1c0306,0x224e2167,0x2908005b,0x7a38cb1c}},	//   _odpá, piek_, hvaa_, _líta, 
   {{0x9f44ecbf,0x1d0800a7,0xa114015e,0xf38c010f}},	//   nflé_, аеми_, _ووات, _עראָ, 
   {{0x61e81125,0xdb0c00d2,0xb5540882,0x7e90054e}},	//   mfel, babû, āṇya, _căpr, 
   {{0x61ea0226,0xdb0e2168,0xdd040213,0xf06400d4}},	//   lfel, cabû, çqın, _екіп, 
   {{0x5ea42885,0x2ca80a28,0x20040472,0xa3d007f7}},	//   _بمبل, _etad_, mdli_, _वयन_, 
   {{0x6e3ce85e,0x39422169,0x7a3a216a,0x20046064}},	//   chsb, tzis_, _bíta, ldli_, 
   {{0x7a380077,0x6024012c,0x61e81a80,0xb4e80927}},	// [3e940] _cíta, _témě, ifel, _बहे_, 
   {{0x2006216b,0x39400276,0x61e80112,0xcfbc0116}},	//   ndli_, rzis_, hfel, ﻠﻤﺎﻗ, 
   {{0x29092683,0x61ea216c,0x7bde216d,0x9f45b1a6}},	//   avaa_, kfel, mgru, fflé_, 
   {{0x94a807ee,0x61e80cf9,0xd1dc0020,0x3a580214}},	//   атка_, jfel, ናንተ_, _ایرج_, 
   {{0x61ea216e,0x98a40022,0xdb0c0ac9,0x7a3801a8}},	//   dfel, _фиге, jabú, _gíta, 
   {{0x7bde216f,0xaae40014,0x61e82305,0x92a40063}},	//   ngru, _بسیو, efel, ојил, 
   {{0x7afc0142,0x07a0009d,0xc7a004c2,0x83500066}},	//   nwrt, _цасн, _циск, وپها, 
   {{0x61e8066d,0x20044d9a,0x7bdc002f,0x068802dd}},	//   gfel, edli_, hgru, _ﺑﺎﻳﯩ, 
   {{0x7bdd2b8c,0x78700108,0x7afc0142,0x9f4400d7}},	//   kgru, sävu, hwrt, celú_, 
   {{0x8f08084c,0x52b00131,0xf1dc00dc,0x00000000}},	//   ахма_, _قەتئ, _यावन, --, 
   {{0x91e62170,0x61e80004,0x59c8041c,0x6e3c03ac}},	//   _може, bfel, िणार, thsb, 
   {{0x98b0006d,0x20062171,0x2ca800b5,0x6d4001e4}},	//   czyć_, adli_, _ptad_, ŝlam, 
   {{0x7bdc0730,0x7870007c,0x00000000,0x00000000}},	//   fgru, nävs, --, --, 
   {{0x7bde2172,0x7a38032e,0x00000000,0x00000000}},	//   ggru, _ríta, --, --, 
   {{0xf3e4001e,0x0dc810ea,0x7a3800d2,0xfbddb1c8}},	//   _ۣۜ_, _купи_, _síta, _बारम, 
   {{0x3af0005b,0xeb9a2173,0x00000000,0x00000000}},	//   _söpö_, риң_, --, --, 
   {{0x3af02776,0x7bde2174,0x2908c5e7,0xfe701867}},	// [3e950] _pöpö_, bgru, uvaa_, _جدو_, 
   {{0x7a3a2175,0x2908023a,0x7b080bcd,0x9f440030}},	//   _víta, rvaa_, ðstí, velú_, 
   {{0xc178044e,0x290802f6,0xf770446a,0x61ea2176}},	//   _ብድሕሪ_, svaa_, پال_, yfel, 
   {{0x7a3802d2,0xdb0c03b2,0x00000000,0x00000000}},	//   _títa, yabú, --, --, 
   {{0xa508ef31,0x61e877e6,0xc984020f,0x00000000}},	//   села_, vfel, _фуни, --, 
   {{0x225c0175,0x00000000,0x00000000,0x00000000}},	//   _sjwk_, --, --, --, 
   {{0x68f807c4,0x61ea2177,0xdef0001f,0x228000e4}},	//   şadı, tfel, ፍቃን_, hóke_, 
   {{0x61e806ee,0x00000000,0x00000000,0x00000000}},	//   ufel, --, --, --, 
   {{0x61ea2178,0x98b0068f,0xe7380220,0x7bde2179}},	//   rfel, rzyć_, _тең_, ygru, 
   {{0x61ea217a,0x98b00034,0xdb0d2ef2,0x41a81f13}},	//   sfel, szyć_, rabú, _ट्रस, 
   {{0x61ea217b,0x20042bcc,0x22900419,0x934c0240}},	//   pfel, rdli_, _uško_, _ንሕቶታ, 
   {{0x2448033f,0xddc4012d,0x17180a7c,0x5fdc1fd2}},	//   dźmi_, wikł, צורע, _मावल, 
   {{0x02d872c0,0x99800118,0xdb0c03b2,0x00000000}},	//   _यमुन, _roků_, labø, --, 
   {{0xb0688bf0,0x628803cd,0x7bdc002f,0x00000000}},	//   _وصول_, lmeo, ugru, --, 
   {{0xd1dc044e,0xdb0c0162,0x69c00171,0x00000000}},	//   ናዕቲ_, nabø, _ēler, --, 
   {{0x62880051,0x17840022,0x00000000,0x00000000}},	//   nmeo, ҧгам, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3e960] --, --, --, --, 
   {{0x0d800bd6,0xb33c0327,0x24e402dd,0x62880332}},	//   _ялын, _teħx, _ﺍﺴﺘﻬ, hmeo, 
   {{0x7c94001f,0xad240133,0x70b80073,0xdb0c75f9}},	//   ቀየረው_, _فریو, _इब्ल, jabø, 
   {{0xceb00a7c,0x95840cc9,0x1dbc00dc,0x00000000}},	//   גיא_, плее, ्णित, --, 
   {{0xd8600124,0x7e9c01ec,0xf4846e92,0x26100a8a}},	//   _зҵаҩ, _ﺍﻟﺴﺎ_, واتی, णाजी_, 
   {{0x0440dda8,0x76b400a2,0xb9fc001f,0xd3c405a9}},	//   нечн, _aşyň, _ቄስ_, ستتى, 
   {{0xb02401fb,0x18a41086,0xe8b8031c,0xdb0c03cd}},	//   _nhườ, _фаҳм, _བསོག, gabø, 
   {{0x7586217c,0x628801e4,0x85e402e8,0x65b801c6}},	//   _قیام, gmeo, _ндсв_, _муур_, 
   {{0x7a38013a,0x00000000,0x00000000,0x00000000}},	//   _líto, --, --, --, 
   {{0x30141ee3,0xd0180107,0xdb0c0162,0x00000000}},	//   фдор, сфи_, babø, --, 
   {{0x5fdc0da8,0x26100490,0xa3b801ad,0xb024004d}},	//   _मारल, णाची_, चरर_, _chườ, 
   {{0xc1e06225,0x91e400a7,0x6fd800e1,0x5284004e}},	//   _गायब_, _ходе, _माकू, _эгеб, 
   {{0xe244f18a,0x7a380139,0xe8b8031c,0xd6a401e0}},	//   _تخلي, _aíto, _བསེག, аhын, 
   {{0x8aa4f5b3,0x7a3801ef,0x00000000,0x00000000}},	//   зрад, _bíto, --, --, 
   {{0x7b640dd8,0x7a3800c6,0x4ea41a71,0x228000e4}},	//   етте, _vítn, _эрла, sóke_, 
   {{0xad240075,0x06880046,0xb4bc012d,0x00000000}},	//   _يىغى, _ﺑﺎﻋﯩ, _आबू_, --, 
   {{0xdb240129,0xbd8800db,0x00000000,0x00000000}},	// [3e970] _épît, _ىنىن_, --, --, 
   {{0x80cc0574,0x4c8001d5,0x7a3802d2,0xf99096b4}},	//   _दिसे, _سیزق, _fíto, طبق_, 
   {{0xf1dc05ba,0xae2004af,0x00000000,0x00000000}},	//   _यांन, यापन_, --, --, 
   {{0x25a000bc,0xe91800d4,0xa9340150,0x00000000}},	//   ěhlo_, _домі_, _жемш, --, 
   {{0xa3b802ab,0x39140064,0x00000000,0x00000000}},	//   चरल_, _змяр, --, --, 
   {{0x7a380579,0x3e4800dd,0x6fd80073,0x00000000}},	//   _lítl, lőtt_, _मागू, --, 
   {{0x753c03be,0x77a801d9,0x6288000d,0x26c40ca8}},	//   _ərzi, _رێنہ_, tmeo, _ìlo_, 
   {{0xe1f800cd,0xdb0c03b2,0x00000000,0x00000000}},	//   ्येण_, rabø, --, --, 
   {{0x628a217d,0xdb0c0158,0x00000000,0x00000000}},	//   rmeo, sabø, --, --, 
   {{0xb024001e,0x045810ef,0x602402bf,0x628801a6}},	//   _phườ, _اجرت_, єдна, smeo, 
   {{0x73c45b7a,0xd3e401b9,0x7a38032e,0x80cc05c0}},	//   _سينم, _آقمی, _bítl, _दिवे, 
   {{0x5e140c60,0x00000000,0x00000000,0x00000000}},	//   ффоф, --, --, --, 
   {{0xc0e402d3,0x7a38013a,0x00000000,0x00000000}},	//   ማቶም_, _síto, --, --, 
   {{0xb02407ae,0x3c3402f6,0x00000000,0x00000000}},	//   _thườ, _kävi_, --, --, 
   {{0x5a949665,0x00000000,0x00000000,0x00000000}},	//   драф, --, --, --, 
   {{0x7a3a217e,0x00000000,0x00000000,0x00000000}},	//   _víto, --, --, --, 
   {{0xddd402f0,0x27f000c0,0x00000000,0x00000000}},	// [3e980] _chyť, _bbzn_, --, --, 
   {{0x7d040944,0x7a391c3e,0xf8a4009d,0x00000000}},	//   _isis, _títo, _үгнү, --, 
   {{0x8c1830fb,0x00000000,0x00000000,0x00000000}},	//   _וויי, --, --, --, 
   {{0xb8e411ba,0xae202e1e,0x2484007c,0x00000000}},	//   _এম_, यायन_, _ahlm_, --, 
   {{0x6e3c044e,0x4de0012c,0x3dc00036,0xd4680b3b}},	//   ërbi, ट्टै_, _meiw_, оиде_, 
   {{0x7d044180,0x3dc00221,0x38c401e1,0xf484036b}},	//   _msis, _leiw_, _eèrá_, راشی, 
   {{0x38a40624,0x998000b0,0x00000000,0x00000000}},	//   _hör_, _makō_, --, --, 
   {{0x7d06217f,0x38a62180,0x80cc0490,0x645c0248}},	//   _osis, _kör_, _दिशे, _ìsin, 
   {{0x53a442c6,0x7d062181,0x38a402d2,0x78a406be}},	//   _жазб, _nsis, _jör_, nqiv, 
   {{0x9980007f,0x38a62182,0xa3b800cd,0x8fd00166}},	//   _nakō_, _mör_, चरः_, тәдә, 
   {{0x38a4049f,0xdb1c0023,0xc7d408a8,0x78a4022e}},	//   _lör_, _depë, וויי_, hqiv, 
   {{0xd138569f,0x00000000,0x00000000,0x00000000}},	//   _мхл_, --, --, --, 
   {{0x7d062183,0x3dc00036,0xb0e80327,0xd008010a}},	//   _csis, _deiw_, _འདིེ, _меде_, 
   {{0xff4c2354,0xdb1dc821,0x7d040165,0x1ea80451}},	//   اخی_, _kepè, _dsis, _کاٻي_, 
   {{0x99800100,0xfeb421ef,0xdb1c00e4,0x7ac4648d}},	//   _dakō_, _قايت_, _jepè, ксте, 
   {{0x38a404f3,0x3dc004e6,0xdb2400e5,0x9f4400d7}},	//   _bör_, _geiw_, روقی, nelý_, 
   {{0xa8143410,0x78a402b9,0x38a40139,0xac58013d}},	// [3e990] ндаш, gqiv, _cör_, _наиф_, 
   {{0x6e2e2184,0x38a401e6,0xadec00e1,0xdb0c03b2}},	//   _hoab, _dör_, जभवन_, labý, 
   {{0x6e2e2185,0xca7000f2,0x00000000,0x00000000}},	//   _koab, _لندک, --, --, 
   {{0x38a4be3d,0x80cc0574,0x7a3800d2,0x6e2c03d1}},	//   _för_, _दिले, _lítj, _joab, 
   {{0x38a40628,0x6e2e2186,0xc7c510c7,0xe8b80327}},	//   _gör_, _moab, _осви, _བསིག, 
   {{0x63862187,0xe29a2188,0x6e2c03d1,0x5fdddc48}},	//   нгла, пак_, _loab, _माइल, 
   {{0x21a401a9,0x7c28007c,0x00000000,0x00000000}},	//   нийм, ödri, --, --, 
   {{0x6e2c0921,0xdb1c0137,0xdb0c0162,0x38a4d394}},	//   _noab, _depè, jabý, _yör_, 
   {{0x2138011f,0xe1f065dc,0xdb1c0200,0x38a40166}},	//   ásh_, نسک_, _pepë, _xör_, 
   {{0xdb1c036e,0xdfe8009d,0x27e00051,0x22a40117}},	//   _qepë, чдод_, nghn_, _зудҳ, 
   {{0x660a2189,0xb33c0003,0xdb1c02d3,0x6e2e218a}},	//   _kaek, _agħf, _vepë, _boab, 
   {{0x7d058afe,0x6e2e218b,0x66081b57,0x9f440306}},	//   _psis, _coab, _jaek, celý_, 
   {{0xdb1c044e,0x6e2c299d,0x442400c8,0x62980472}},	//   _tepë, _doab, ojn_, _iiwo, 
   {{0x660a218c,0x38a4049f,0x62980d81,0x60ca218d}},	//   _laek, _rör_, _hiwo, msem, 
   {{0x629a218e,0xdb1c0214,0x4424282c,0x38a401d3}},	//   _kiwo, _kepé, ijn_, _sör_, 
   {{0xdb24066d,0x62980a2e,0x7d06218f,0x660a2190}},	//   _épít, _jiwo, _tsis, _naek, 
   {{0x1cd80d46,0x7e662191,0x998000b0,0x629a2192}},	// [3e9a0] _ོའི_, _ijip, _takō_, _miwo, 
   {{0x60ca2193,0x629905eb,0xb9088004,0x38a408a5}},	//   isem, _liwo, _यम_, _vör_, 
   {{0x660a2194,0xdb0c014a,0x7e6408fb,0x6e2c3545}},	//   _baek, nabü, _kjip, _yoab, 
   {{0xdb1e2195,0x38a5e03f,0x629a2196,0x562800f5}},	//   _repè, _tör_, _niwo, яжем_, 
   {{0x66090d08,0x60c8037e,0x9f440030,0x78a40869}},	//   _daek, jsem, velý_, qqiv, 
   {{0x6298166a,0x7e64045f,0x660801c0,0xdb1c0066}},	//   _aiwo, _ljip, _eaek, _pepè, 
   {{0x629a2197,0x6608002d,0x2a780241,0x9f440139}},	//   _biwo, _faek, _ìgbè_, gelü_, 
   {{0x442404ac,0x62980c09,0x7a3800d2,0x7e640066}},	//   ajn_, _ciwo, _sítj, _njip, 
   {{0x6299323f,0xdb1e2198,0x764000a2,0x6e2c054e}},	//   _diwo, _depé, _ilmy, _roab, 
   {{0x6e2e2199,0xdb0c01b8,0x7e66219a,0x394401a8}},	//   _soab, fabü, _ajip, _ýmsu_, 
   {{0x60c816b5,0x6e2c0109,0x08540375,0x660904aa}},	//   asem, _poab, תבים_, _yaek, 
   {{0x62980083,0xdb1caf26,0x068806ba,0xad240131}},	//   _giwo, _gepé, _ﺑﺎﻟﯩ, پىسى, 
   {{0x7e640b21,0x0caa219b,0x6e2c06d9,0x60ca219c}},	//   _djip, ятни_, _voab, csem, 
   {{0x7e66219d,0x6299c25f,0x6e2c016b,0xb3e037f3}},	//   _ejip, _ziwo, _woab, नलिख, 
   {{0x7640062c,0x3e6405d1,0x629a219e,0x0dc40023}},	//   _olmy, sıta_, _yiwo, ጽሕፍ_, 
   {{0x629802c4,0x9d700521,0x7e640200,0xa5bc0055}},	//   _xiwo, ọlọt, _gjip, _toųi, 
   {{0x660800c5,0x7a3a219f,0x00000000,0x00000000}},	// [3e9b0] _raek, _míth, --, --, 
   {{0x6609d132,0xf77004d3,0x76406ae3,0xdb0c0d12}},	//   _saek, ڕان_, _almy, gabó, 
   {{0x660a21a0,0xe718388d,0xc7640131,0xc7c401c6}},	//   _paek, بيات_, رائى, _үсги, 
   {{0xe81013f5,0x7a380332,0x6aa003b2,0x104c0240}},	//   _डोरा_, _níth, ílfu, _ንጥቀመ, 
   {{0xdb1c07ea,0x62980810,0x248002d3,0x660800c7}},	//   _repé, _riwo, _ይቃለስ_, _vaek, 
   {{0x629a21a1,0x68ee21a2,0x660a21a3,0xdb1e21a4}},	//   _siwo, mtad, _waek, _sepé, 
   {{0x68ec1a36,0xdb1c00f2,0xf3c80133,0x60c80175}},	//   ltad, _pepé, ربوه_, wsem, 
   {{0x60ca21a5,0x68ed3625,0x3d140243,0x00000000}},	//   tsem, otad, दिमे_, --, 
   {{0x60c820ef,0x6298014f,0x246801d5,0x6145845e}},	//   usem, _viwo, _قمرپ_, тепа, 
   {{0x60c87408,0x68ee21a6,0xf0e80075,0x7e65d34a}},	//   rsem, itad, رىپى_, _sjip, 
   {{0x60ca21a7,0x68ee21a8,0x9f4400eb,0x644221a9}},	//   ssem, htad, veló_, _illi, 
   {{0x68ee21aa,0x60c800af,0xdca621ab,0xdb0e21ac}},	//   ktad, psem, ками, rabü, 
   {{0x68ec6fa8,0x00000000,0x00000000,0x00000000}},	//   jtad, --, --, --, 
   {{0x4fa00aa5,0xe810000d,0x7e640175,0x68ec01ab}},	//   _кишв, _डोला_, _wjip, dtad, 
   {{0x7e6621ad,0x7a389910,0xda700014,0x8f3000d8}},	//   _tjip, _híti, لُس_, _вејц, 
   {{0x68ee21ae,0x7e64009f,0x06880150,0x00000000}},	//   ftad, _ujip, _ﺑﺎﻛﯩ, --, 
   {{0x68ee21af,0x644221b0,0x656802d3,0xa3d000dc}},	// [3e9c0] gtad, _olli, _nxeh, _वयं_, 
   {{0x7a382815,0x25adc20a,0x22800022,0x00000000}},	//   _míti, _afel_, kóko_, --, 
   {{0x7a381c38,0xdb0c1d0e,0x65680076,0xd62a21b1}},	//   _líti, rabó, _axeh, може_, 
   {{0x644221b2,0xb33c031c,0x68ec4cb5,0x998400c6}},	//   _alli, _jgħe, btad, _للجو, 
   {{0x6440007f,0x7a3a21b3,0xb33c031c,0xdb0c0162}},	//   _blli, _níti, _mgħe, pabó, 
   {{0xd04001e4,0x5fdc202e,0x7a3801e7,0x6b980432}},	//   _spoɾ, _मागल, _síth, _ýagý, 
   {{0xa8640032,0x3c3401e3,0x9694dcc6,0x80bc09ab}},	//   _серҙ, _hävs_, _араш, लीसे, 
   {{0x22802242,0xd7e00316,0x644221b4,0x7a3801a8}},	//   sókn_, _पाँच, _elli, _bíti, 
   {{0x7a380313,0xae20000d,0x64400240,0x13e801ee}},	//   _cíti, यासन_, _flli, _омай_, 
   {{0x9f44011c,0x752404e6,0x00000000,0x00000000}},	//   velò_, äizu, --, --, 
   {{0x63e00efb,0x64a400c7,0xc204006c,0x03a061ac}},	//   _اۋىل, _ааӡа, رقین_, _тихо, 
   {{0x68ed1eff,0x20180421,0x61400124,0x8cd4000d}},	//   ytad, ēsia_, рҵәа, _बिदो, 
   {{0xd7e00807,0x64402c59,0x68ee21b5,0x1ee803e6}},	//   _पांच, _ylli, xtad, وویی_, 
   {{0x00f4011a,0x00000000,0x00000000,0x00000000}},	//   _סמוך_, --, --, --, 
   {{0xbea0009b,0x00000000,0x00000000,0x00000000}},	//   _кајк, --, --, --, 
   {{0x68ee21b6,0xcbe003f4,0x80bc05d7,0xdb0c00db}},	//   ttad, য়েছ, लीवे, tabò, 
   {{0xe5a40019,0x68ec0dd6,0xb9c401b9,0x1d8401af}},	// [3e9d0] қили, utad, рёси, _бөрй_, 
   {{0x6e3e21b7,0xdb0e21b8,0x2c18012d,0x3914022e}},	//   lksb, rabò, दाओं_, шмур, 
   {{0x6b84014b,0x3c34007c,0x00000000,0x00000000}},	//   _uzhg, _vävt_, --, --, 
   {{0x6e3c73a5,0x7a3c005c,0xd2447286,0x68d401af}},	//   nksb, råtæ, _طن_, _йомђ, 
   {{0xd1245341,0xeb3404b3,0x6e3c03b2,0x00000000}},	//   _ام_, _شىڭد, iksb, --, 
   {{0x6aa4002f,0x00000000,0x00000000,0x00000000}},	//   _kuhf, --, --, --, 
   {{0x7a3a21b9,0x6440003a,0x2a780200,0x00000000}},	//   _síti, _vlli, _kksb_, --, 
   {{0x65945bc5,0x6e3e21ba,0x25ac3336,0x00000000}},	//   _бабу, jksb, _ufel_, --, 
   {{0xe4da21bb,0x057621bc,0x64400205,0x00000000}},	//   _سوات_, _شارد, _tlli, --, 
   {{0x7a380a62,0x6e3c282c,0x44f8022e,0x00000000}},	//   _víti, eksb, mª_, --, 
   {{0x8eb0034c,0x37d01c82,0x3494013e,0xf1dc2802}},	//   یمیش, স্কৰ, _тафр, _याचन, 
   {{0xc0f00b82,0x7a3801e1,0xfbdc0210,0x00000000}},	//   ግባረ_, _títi, _बाङम, --, 
   {{0x44f8022e,0x00000000,0x00000000,0x00000000}},	//   nª_, --, --, --, 
   {{0xd004529e,0x2a7805b1,0xdee402a9,0x25a801e4}},	//   _беше_, _aksb_, _боки, ɾale_, 
   {{0xdea02172,0xcb6621bd,0xda640451,0x7054030d}},	//   _دیجی, гаре_, هاري, _тĕре, 
   {{0xfa60001f,0x00000000,0x00000000,0x00000000}},	//   _ተወካይ_, --, --, --, 
   {{0xc0f0010c,0x8e3801d3,0x09f400ae,0x00000000}},	// [3e9e0] ግባሩ_, _سسٹر_, طفلة_, --, 
   {{0x3c34007c,0x1fd40154,0x9fd403d4,0x00000000}},	//   _vävs_, ত্রস, ত্ৰগ, --, 
   {{0x1d68001f,0x00000000,0x00000000,0x00000000}},	//   _ደንቦች_, --, --, --, 
   {{0x44f800d8,0xd94421f3,0xb0d40073,0x8f98011a}},	//   fª_, _беми, _दिलग, גיעי, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x07a221be,0x3358084c,0xdb1c022a,0xe6b40133}},	//   _гарн, калэ_, _lepí, الۆگ, 
   {{0x2b0c0037,0x5fdc01f9,0x00000000,0x00000000}},	//   हिएँ_, _माजल, --, --, 
   {{0xdb1c02fb,0x80cc0034,0x752401c7,0xf66400db}},	//   _nepí, _दिखे, äizs, _тебү, 
   {{0x4fc401c6,0x49152b81,0xa6500244,0x00000000}},	//   лсна, नियो_, _بێنت, --, 
   {{0x6e3e21bf,0xaca4063f,0x2ef46d23,0xddd40419}},	//   wksb, saịz, азор, _chyž, 
   {{0x049000c6,0x7a3803b2,0xc20c00fb,0x00000000}},	//   _اللح, _hítu, _лє_, --, 
   {{0xdb1c02f0,0x00000000,0x00000000,0x00000000}},	//   _cepí, --, --, --, 
   {{0x2be8fe33,0x00000000,0x00000000,0x00000000}},	//   _जादू_, --, --, --, 
   {{0x2a7805b1,0x00000000,0x00000000,0x00000000}},	//   _sksb_, --, --, --, 
   {{0xab94026a,0x7a3a21c0,0x2b4c010f,0x00000000}},	//   рављ, _lítu, ĝeco_, --, 
   {{0x7ed221c1,0x2b4c01e4,0x00000000,0x00000000}},	//   _ازوا, ŝeco_, --, --, 
   {{0xf77000d1,0x14c40243,0xa854e4ae,0x00000000}},	// [3e9f0] ۋام_, रीमण, акач, --, 
   {{0x6aa415f6,0x67d40212,0x00000000,0x00000000}},	//   _tuhf, рожу, --, --, 
   {{0xb8681f5a,0xe46801e1,0x00000000,0x00000000}},	//   ујте_, _ìké̟, --, --, 
   {{0x7a381d1d,0x96c4000d,0x00000000,0x00000000}},	//   _bítu, _लबरउ, --, --, 
   {{0xa5095e34,0x00000000,0x00000000,0x00000000}},	//   тела_, --, --, --, 
   {{0x53b40116,0x44f801a9,0x00000000,0x00000000}},	//   иғур_, rª_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xddc401e4,0x4660004b,0x85b8009f,0x7a3802d2}},	//   fikŝ, _اپرې, _سارس_, _fítu, 
   {{0xdb1e21c2,0xd24c00c6,0xe044084c,0xe5540114}},	//   _repí, بني_, инии, _ткањ, 
   {{0xdb0c01b8,0xdb1c23ec,0x34940166,0x2918045a}},	//   mabö, _sepí, _гаур, _mrsa_, 
   {{0x9e651316,0xdb1c013a,0x00000000,0x00000000}},	//   ивод, _pepí, --, --, 
   {{0x291a21c3,0x6f180331,0x68fcc35e,0x715802dd}},	//   _orsa_, _drvc, _opsd, _өріс_, 
   {{0xb33c031c,0xf1b401e0,0x60240798,0x00000000}},	//   _igħa, _уҡы_, _вдла, --, 
   {{0x7a384a1f,0x8cd400bc,0x0d80010b,0x50d80677}},	//   _lítt, _बिरो, юлян, _יקנא, 
   {{0xdee4024c,0x00000000,0x00000000,0x00000000}},	//   _тойи, --, --, --, 
   {{0xb33c003d,0x1a04041b,0x648c00ae,0x00000000}},	//   _jgħa, јпам, lúid, --, 
   {{0x291801ab,0xb33c003d,0x3ea621c4,0x6aa801e4}},	// [3ea00] _crsa_, _mgħa, _hunt_, ĉefa, 
   {{0x3ea40460,0xb33c025c,0x3ea0007c,0x00000000}},	//   _kunt_, _lgħa, _hiit_, --, 
   {{0x3ea621c5,0x291a21c6,0x7a381427,0xd7040124}},	//   _junt_, _ersa_, _bítt, рзеи, 
   {{0x3ea000e8,0xb33c0003,0x7a3802d2,0xd7e001f9}},	//   _jiit_, _ngħa, _pítu, _पाकच, 
   {{0x3ea020ac,0xdb1c00db,0xdb0dc150,0x3ea45522}},	//   _miit_, _hepà, gabö, _lunt_, 
   {{0xb33c0003,0x3ea221c7,0x67200fcf,0xb6c81893}},	//   _agħa, _liit_, _šlje, _مارے_, 
   {{0xb33c025c,0x1bec007d,0x96b80063,0x02a153cd}},	//   _bgħa, _जानल_, _југу_, орым, 
   {{0x7a381a36,0x3ea221c8,0x8cd404fa,0x46a0039b}},	//   _títu, _niit_, _बिलो, _фатв, 
   {{0x5184063b,0x32cc0ca8,0xb33c0003,0x63ac0882}},	//   шука, _bóyá_, _dgħa, śana, 
   {{0x3ea40694,0x03a0016c,0x7870023a,0xe3b00014}},	//   _bunt_, _дифо, tävy, _فرٔ_, 
   {{0x3ea43b08,0x7a3800d8,0x3ea00254,0x923400d1}},	//   _cunt_, _jíts, _biit_, _پىشش, 
   {{0x3ea000e8,0x3ea40493,0xae200dba,0xc1e00037}},	//   _ciit_, _dunt_, याइन_, _गाएब_, 
   {{0x3ea221c9,0x8d843410,0x7a380af2,0x3ea40381}},	//   _diit_, рунд, _líts, _eunt_, 
   {{0x320621ca,0xb33c031c,0xf40403d4,0x648c00ae}},	//   lemy_, _zgħa, লাকৰ_, rúig, 
   {{0xdb1c0589,0x3ea221cb,0x3ea401f5,0x6e94011c}},	//   _repã, _fiit_, _gunt_, _лику, 
   {{0x3ea00280,0xdb1c0589,0x291a21cc,0xb33c031c}},	//   _giit_, _sepã, _prsa_, _xgħa, 
   {{0x3ea407c5,0x2d88009f,0xaa580150,0x391400f3}},	// [3ea10] _zunt_, _uzae_, _ەلجا_, омтр, 
   {{0xc2fc0729,0x32040072,0x4ae407d6,0x3d141fbc}},	//   ্মতি_, hemy_, _кўма, दिरे_, 
   {{0x67d401b9,0x3ea4002e,0x15d40131,0x66f402dd}},	//   _қову, _xunt_, ﻟﻤﯩﻐ, спеу, 
   {{0x3204006d,0xf6514494,0x29180010,0x9f4400d8}},	//   jemy_, وئن_, _trsa_, melô_, 
   {{0x320621cd,0x291a21ce,0x9f440770,0x2fcc0ac5}},	//   demy_, _ursa_, lelô_, kadg_, 
   {{0xdb1c2d3f,0xa3e825ec,0x58e00150,0x69cc0363}},	//   _hepá, удка_, _رۋمك, laae, 
   {{0xf7707431,0x2ca80280,0x290a21cf,0x7a380162}},	//   _قاف_, _luad_, lwaa_, _títt, 
   {{0x3ea621d0,0x99800100,0x2908208d,0xb33c0003}},	//   _runt_, _dakņ_, owaa_, _qgħa, 
   {{0x3ea621d1,0x3ea1e9ad,0x2ca800ae,0x29080067}},	//   _sunt_, _riit_, _nuad_, nwaa_, 
   {{0x3ea0007d,0x69cc0270,0x92b400fe,0x00000000}},	//   _siit_, haae, _জিৰ_, --, 
   {{0x69cc0053,0xb33c003d,0x3ea221d2,0x615405d9}},	//   kaae, _tgħa, _piit_, _ڏنائ, 
   {{0x290a21d3,0x9f44c917,0x2ca86678,0xdb1e21d4}},	//   kwaa_, nglé_, _buad_, _nepá, 
   {{0x61e83c13,0x69cc00ad,0x3ea0000d,0x437401af}},	//   mgel, daae, _viit_, _суҡт, 
   {{0x61ea21d5,0x3dd8038f,0x2ca8030a,0xae200316}},	//   lgel, _żewġ_, _duad_, याउन_, 
   {{0x3ea1a130,0x61e80368,0xdca402a9,0xd00c143e}},	//   _tiit_, ogel, раҳи, _سلي_, 
   {{0x61ea21d6,0x2ca001ab,0x2caa21d7,0x59740139}},	//   ngel, _eihd_, _fuad_, бызу, 
   {{0x7a3800d2,0x2ca804cc,0x6e9c002e,0x61ea21d8}},	// [3ea20] _síts, _guad_, _t斡r斡, igel, 
   {{0x61e80ade,0x7a38032e,0x3204012d,0x00000000}},	//   hgel, _píts, zemy_, --, 
   {{0x61ea21d9,0x2004084c,0x2908198f,0x69cc000d}},	//   kgel, ieli_, awaa_, baae, 
   {{0x61ea21da,0x2ca80211,0x9f4400e8,0x228003b2}},	//   jgel, _yuad_, gglé_, bóki_, 
   {{0x200621db,0x61e801d9,0x4e78008f,0x00000000}},	//   keli_, dgel, נאנצ, --, 
   {{0x200621dc,0x61e95c45,0xed5801f1,0x25a80419}},	//   jeli_, egel, úži_, ľala_, 
   {{0x320403d1,0x61e826d2,0x8c180375,0xc840010b}},	//   temy_, fgel, טוסי, _эерй, 
   {{0xb9f42295,0x7a38012c,0xf50800f1,0xf2380395}},	//   _ምን_, _zítr, _نښتي_, рпиш_, 
   {{0x320621dd,0x200621de,0x2fcc022e,0x2290013a}},	//   remy_, feli_, tadg_, _vškp_, 
   {{0xa4900050,0x00000000,0x00000000,0x00000000}},	//   _ہیۆت, --, --, --, 
   {{0x2ca805be,0x11d800c6,0x290800ca,0x47c40c58}},	//   _suad_, _موضة_, zwaa_, ৰ্কী, 
   {{0x2ca805b1,0x20040093,0x4798010f,0x00000000}},	//   _puad_, aeli_, טייס, --, 
   {{0x2ca8664a,0x69cc0618,0xdb1c1a96,0x0a680107}},	//   _quad_, vaae, _repá, ҳраи_, 
   {{0x200621df,0xdb1c25e6,0x5094026a,0xb33c0003}},	//   celi_, _sepá, _уређ, _jgħo, 
   {{0x2908198f,0xb33c0135,0xdb1c00e4,0x7ff40375}},	//   wwaa_, _mgħo, _pepá, _הזוג_, 
   {{0x290a21e0,0x7f8000c6,0x2ca805c7,0x7a3801a8}},	//   twaa_, _علين, _tuad_, _sítr, 
   {{0x648c0332,0xf988009a,0x00000000,0x00000000}},	// [3ea30] núic, منفي_, --, --, 
   {{0x61e99d57,0xb33c025c,0x29087f5b,0x69cc000d}},	//   zgel, _ngħo, rwaa_, saae, 
   {{0x61ea21e1,0x290a21e2,0x69cc02f6,0x47883d89}},	//   ygel, swaa_, paae, усам_, 
   {{0x200621e3,0xa5fa21e4,0x61e80014,0x2280012d}},	//   zeli_, реду_, xgel, póki_, 
   {{0x20046985,0x64744f41,0x61e888e5,0x2908058a}},	//   yeli_, огду, vgel, qwaa_, 
   {{0x200621e5,0x8cc800dc,0xb46401ec,0x61e80492}},	//   xeli_, तीयो, пкіл, wgel, 
   {{0x61ea21e6,0xa228054d,0xdbd40139,0x00000000}},	//   tgel, ижка_, _räüf, --, 
   {{0xe0d8e4e0,0x2a6a21e7,0x61ea21e8,0x22b40055}},	//   ави_, nnab_, ugel, _nāke_, 
   {{0x61ea21e9,0x21680131,0x00000000,0x00000000}},	//   rgel, рипи_, --, --, 
   {{0xd764066d,0x1f64234c,0xc4440133,0x2a68000d}},	//   _انہی, жком, _دیتن_, hnab_, 
   {{0x200621ea,0x61e8092e,0xde040fac,0x00000000}},	//   reli_, pgel, опни, --, 
   {{0x200621eb,0x00000000,0x00000000,0x00000000}},	//   seli_, --, --, --, 
   {{0x200621ec,0x16c401ad,0xdb1c0790,0xdbd40166}},	//   peli_, _लब्ब, _kepç, _täüf, 
   {{0xb33c003d,0x224c0af9,0xe364030d,0x200406be}},	//   _ogħl, lhek_, _укçи, qeli_, 
   {{0xfe7943f8,0xda58c719,0x8ba001d5,0xddd0012d}},	//   _гүн_, араш_, дирж, ągło, 
   {{0x224c01f5,0x00000000,0x00000000,0x00000000}},	//   nhek_, --, --, --, 
   {{0xb33c0003,0x8d9000cf,0x00000000,0x00000000}},	// [3ea40] _agħl, _ۉلۉش, --, --, 
   {{0x672007f5,0x0d8029db,0x48000120,0x98600240}},	//   _šlja, _юлын, мпув, _ተረሲዑ_, 
   {{0x224d1a00,0xd708023a,0x2a6977b7,0x95c803cf}},	//   khek_, рнее_, bnab_, аула_, 
   {{0x2a681c1d,0x75d400ec,0x95840064,0x273401e1}},	//   cnab_, سيتا, олее, _ẹnà_, 
   {{0xb33c031c,0x224c0214,0x00000000,0x00000000}},	//   _egħl, dhek_, --, --, 
   {{0x7b180084,0xd37004fb,0x7998031c,0x00000000}},	//   _ḓuv, وهش_, ħawġ, --, 
   {{0x224c017a,0x439221ed,0x960400ae,0x35c40117}},	//   fhek_, машс, _وبرم, _навҳ, 
   {{0xcad40375,0x224c0003,0x648c00e4,0x00000000}},	//   קופת_, ghek_, túic, --, 
   {{0x661c008c,0x32180316,0x182c001f,0x394013bb}},	//   _óska, ěry_, _በማንኛ, nyis_, 
   {{0x60dc0077,0x648c00e4,0x00000000,0x00000000}},	//   ásma, rúic, --, --, 
   {{0xc7b0025f,0x291c0943,0x2a68bdad,0x224c0ee8}},	//   ובת_, ̭wa_, ynab_, bhek_, 
   {{0x224e21ee,0x614400d1,0x2448012d,0x394001f4}},	//   chek_, تىۋە, dźmy_, kyis_, 
   {{0xdb1c005b,0x2a68014f,0x22b40055,0x00000000}},	//   _lepä, vnab_, _vāke_, --, 
   {{0xe19405f5,0x22b400b0,0x2d8448e1,0x00000000}},	//   _эрхэ, _wāke_, āle_, --, 
   {{0x201802ea,0x22b404fe,0x2a6801a9,0xaa940395}},	//   ɛsi_, _tāke_, tnab_, зивч, 
   {{0x42d800c8,0x2a68007f,0x00000000,0x00000000}},	//   יקלע, unab_, --, --, 
   {{0x394001ed,0x3e64008e,0x00000000,0x00000000}},	// [3ea50] gyis_, gıtu_, --, --, 
   {{0x224c03bd,0xb33c0003,0x2a680280,0x6af4034f}},	//   zhek_, _agħm, snab_, _езоф, 
   {{0x9be4025c,0x3940208d,0xdb1c06be,0x00000000}},	//   _སྐྲོ, ayis_, _repç, --, 
   {{0x224c0369,0xdb1c0432,0x2a6801a9,0x25a800d7}},	//   xhek_, _depä, qnab_, ľalo_, 
   {{0x25a90449,0xa6c801b9,0x212c011f,0x24e8005b}},	//   žalo_, _گوزل_, xxeh_, ёмки_, 
   {{0xb33c0327,0x0ed80456,0x00000000,0x00000000}},	//   _egħm, _भिंड, --, --, 
   {{0x224e21ef,0xdb1c3262,0x00000000,0x00000000}},	//   thek_, _gepä, --, --, 
   {{0x27e80276,0xdb0c0158,0x32380451,0x00000000}},	//   şină_, rbbø, يڊنگ_, --, 
   {{0xf3ec9c3a,0x935400cf,0x36040345,0x00000000}},	//   _иң_, _ۉرمچ, _زولف, --, 
   {{0x21680e46,0x00000000,0x00000000,0x00000000}},	//   _қили_, --, --, --, 
   {{0x224e21f0,0x201800bc,0xdec80023,0x437000d1}},	//   phek_, ěsi_, _ጠፊኡ_, _تۇغر, 
   {{0x3ea404f3,0x12f80375,0x3940022f,0x00000000}},	//   ömt_, _להעב, yyis_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x26e000cc,0x1fa8010a,0x00000000,0x00000000}},	//   _গৈছো_, _укки_, --, --, 
   {{0xd00c06d5,0x8b2008c1,0x00000000,0x00000000}},	//   _إلى_, ндре, --, --, 
   {{0xdb1c023a,0x00000000,0x00000000,0x00000000}},	//   _repä, --, --, --, 
   {{0xb9140882,0x3940007f,0xdb1c3626,0x00000000}},	// [3ea60] ntaḥ_, uyis_, _sepä, --, 
   {{0x7d0621f1,0xb33c031c,0x0ec00490,0x00000000}},	//   _ipis, _dgħj, वीकड, --, 
   {{0x2c140b03,0x394001f4,0xf1080118,0x00000000}},	//   _फोटू_, syis_, _वन्द_, --, 
   {{0xb9140882,0x98a400a8,0xe9a80014,0x986401d3}},	//   ktaḥ_, _ниме, _ودُن_, _کیئے_, 
   {{0xdb1c01e3,0xf8740137,0x998001ef,0x00000000}},	//   _depå, _قۇرج, _inků_, --, 
   {{0x7d0621f2,0xc2c0004b,0x00000000,0x00000000}},	//   _mpis, ډيوي, --, --, 
   {{0xd25800a7,0x00000000,0x00000000,0x00000000}},	//   йци_, --, --, --, 
   {{0x7d0621f3,0x07a221f4,0x76ac0432,0x00000000}},	//   _opis, _часн, _aşyg, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x645c02d5,0x648c007b,0xc054109a,0x52b000db}},	//   _įsig, lúin, зію_, _كەتئ, 
   {{0x228006ea,0x00000000,0x00000000,0x00000000}},	//   tókt_, --, --, --, 
   {{0x648c0597,0x7d040332,0x00000000,0x00000000}},	//   núin, _bpis, --, --, 
   {{0xae8800cf,0x00000000,0x00000000,0x00000000}},	//   йбүз_, --, --, --, 
   {{0x2ca443e5,0x22b4e762,0x648c01e7,0xe164007b}},	//   öld_, _hāka_, húin, _تدمي, 
   {{0x7d0621f5,0x22b621f6,0x3ff80302,0x00000000}},	//   _epis, _kāka_, _הפוע, --, 
   {{0x67202375,0x6e9400db,0x00000000,0x00000000}},	//   _šljo, _تلبا, --, --, 
   {{0x22b41e0d,0xa8140137,0xeb980209,0xac18004e}},	// [3ea70] _māka_, мдаш, сиң_, _допу_, 
   {{0x8bc401a9,0xdcb00210,0x00000000,0x00000000}},	//   _эсид, _इंतज़, --, --, 
   {{0x44280016,0x6b84013f,0x56f000db,0x00000000}},	//   _đc_, _uyhg, күрс, --, 
   {{0xd2461666,0xbb480014,0x7d0402d0,0x22b40055}},	//   _شن_, _رلُن_, _ypis, _nāka_, 
   {{0x1c20068f,0xc9846a7b,0x6e3c0023,0x69dc0175}},	//   माचल_, _хуни, ërby, _idse, 
   {{0x3cfc02e4,0x63840d1d,0x5dd00150,0x00000000}},	//   צלונ, мгла, _ﻛﯩﻠﻴ, --, 
   {{0x645c0024,0x7dd801d3,0x22b40171,0x661c032e}},	//   _įsid, núsí, _bāka_, _ósko, 
   {{0x26c221f7,0x65941411,0x60dc0cde,0x00000000}},	//   mpho_, _жабу, ásmo, --, 
   {{0x26c0b724,0x9f9400a2,0x00000000,0x00000000}},	//   lpho_, _küçk_, --, --, 
   {{0x2be80490,0xc6840345,0x00000000,0x00000000}},	//   _जागू_, _بێڵن_, --, --, 
   {{0x69dc8841,0x7d0621f8,0xd4340375,0xa088004e}},	//   _odse, _spis, _קטעי_, йсүз_, 
   {{0x7d0401a9,0x6d1807f7,0xf38c010f,0x00000000}},	//   _ppis, दिंग_, _פראָ, --, 
   {{0x205467b5,0x76ac03ee,0x71a400d4,0x00000000}},	//   _откр, _işye, _заїз, --, 
   {{0x69de21f9,0x7d040fb7,0x628a21fa,0x38c40248}},	//   _adse, _vpis, lleo, _lérò_, 
   {{0x7d04006d,0x9e640220,0xde8826c0,0x62880607}},	//   _wpis, _ياعن, _وضعه_, oleo, 
   {{0x69dc0334,0xb7f002c3,0x6289f323,0x00000000}},	//   _cdse, _चाहम_, nleo, --, 
   {{0x7d0404b9,0x3f840142,0x628a21fb,0x99800064}},	// [3ea80] _upis, _hynu_, ileo, _rokų_, 
   {{0x7b181682,0x69dc0455,0x628808c2,0x00000000}},	//   _ḓur, _edse, hleo, --, 
   {{0x69dc005a,0x648c00e4,0xa3c01414,0x00000000}},	//   _fdse, túin, ंडन_, --, 
   {{0xd94400f7,0xceb0010f,0x59745aae,0x00000000}},	//   _жеми, דיא_, _жыгу, --, 
   {{0xb33c025c,0x3f847a9a,0xd49875a5,0x3c34005b}},	//   _igħi, _lynu_, орк_, _sävy_, 
   {{0x22b4005f,0x62880254,0x00000000,0x00000000}},	//   _sāka_, eleo, --, --, 
   {{0x62880cfd,0x22b41d77,0xc7a00022,0x0bc81870}},	//   fleo, _pāka_, _аирк, _ﺑﯘﻳﺮ, 
   {{0xb33c038f,0x628a21fc,0x399401e1,0x00000000}},	//   _jgħi, gleo, _gúsí_, --, 
   {{0x3f840050,0x2cec0073,0x546809a0,0x22b4411e}},	//   _aynu_, _जमेल_, _даам_, _vāka_, 
   {{0x22b402b1,0x301401f0,0x00000000,0x00000000}},	//   _wāka_, хдор, --, --, 
   {{0xd2b4036b,0x60cc003d,0x22b400ef,0x110400e5}},	//   _ўқиш_, _ħame, _tāka_, سبکپ, 
   {{0xb33c003d,0x212805be,0x61300166,0x648c0332}},	//   _ngħi, _šahe_, _bοlğ, húil, 
   {{0xdc381b09,0xf40c0135,0x3f840009,0x00000000}},	//   _açıl, _གྲོད_, _eynu_, --, 
   {{0x28b402ab,0x3f840042,0x26c094e8,0x00000000}},	//   _अंबि, _fynu_, ypho_, --, 
   {{0xfe7000aa,0xcfa401b9,0x8aa621fd,0x648c00ae}},	//   ادۍ_, _ўшли, драд, dúil, 
   {{0xdb100597,0xb384001f,0x66180007,0x00000000}},	//   ógái, _ምንድን_, xdwk, --, 
   {{0xb33c031c,0x92b80154,0x8d740116,0xa3c006e3}},	// [3ea90] _dgħi, _অটো_, _تاغا, ंडम_, 
   {{0x81e40f22,0x6288005a,0xabc400db,0x60cc036e}},	//   ম্প_, zleo, _سۇرۅ_, _çame, 
   {{0x69dc0175,0xd2f00354,0x00000000,0x00000000}},	//   _tdse, _хiир, --, --, 
   {{0x69dc04ce,0x26c092ba,0x69c00356,0xdb980677}},	//   _udse, rpho_, _şlef, _מסתר, 
   {{0x2ab4037e,0x645c0024,0xdb24006c,0x438800d1}},	//   _håb_, _įsib, _قویی, ﺗﺘﯩﻦ_, 
   {{0x68ec009f,0x26c0003a,0xb33c025c,0x38c401e1}},	//   muad, ppho_, _zgħi, _wérò_, 
   {{0xdb1c0054,0x4914012c,0x466801c4,0xa3480eed}},	//   _sepú, निको_, _драм_, язка_, 
   {{0x68ec0165,0xb33c025c,0xf79400c0,0x00000000}},	//   ouad, _xgħi, _расэ, --, 
   {{0x68ee21fe,0xa0a4430d,0x2d88017a,0x648c0332}},	//   nuad, наид, _nyae_, lúim, 
   {{0x1bec10f7,0x628801c6,0x00000000,0x00000000}},	//   _जाइल_, sleo, --, --, 
   {{0x628a21ff,0x68ed4b0c,0xb3542584,0xf7cc0150}},	//   pleo, huad, _لیوا_, _ﺗﯘﻳﺪ, 
   {{0x24840280,0x531802e4,0x68ee2200,0x21740107}},	//   _hklm_, _מועצ, kuad, _пулр, 
   {{0x22b418a6,0x68ec0e20,0x9fc80166,0x648c00e4}},	//   _kāko_, juad, _егла_, húim, 
   {{0x1ca403e6,0x800800e5,0x5b34009d,0x00000000}},	//   ژێکی_, _گرچہ_, нэбу, --, 
   {{0x68ec04cc,0x00000000,0x00000000,0x00000000}},	//   euad, --, --, --, 
   {{0x25ac0240,0x2ab400b5,0x68ec01e7,0xaae00401}},	//   _ngel_, _dåb_, fuad, _फिरक, 
   {{0x68ee2201,0x2d8a2202,0x97c4084c,0x48e0355b}},	// [3eaa0] guad, _gyae_, ейзе, лотв, 
   {{0xe3e4045e,0xdc3806be,0xaf54010e,0x00000000}},	//   প্তব, _tçıl, _öñür, --, 
   {{0xb33c003d,0xd77400c6,0x68ec01ab,0x648c00ae}},	//   _tgħi, رائع, auad, rúil, 
   {{0x68ee2203,0x00000000,0x00000000,0x00000000}},	//   buad, --, --, --, 
   {{0x68ec0540,0x058000db,0x00000000,0x00000000}},	//   cuad, лушм, --, --, 
   {{0x28b40d5f,0xc6c018ce,0x25ac01f5,0x14c41fc4}},	//   _अंति, _әйтк, _egel_, रीगण, 
   {{0x7afc01e0,0x1bec0490,0x99800139,0xd7041422}},	//   ntrt, _जाईल_, _yakş_, _язви, 
   {{0x675401b9,0x00000000,0x00000000,0x00000000}},	//   _جیمس_, --, --, --, 
   {{0x81e40c58,0x914868eb,0xc1b4009a,0xa48459e1}},	//   ম্ভ_, ячка_, رايط_, رجۇن, 
   {{0xc5602077,0x7afc022e,0xa3c00073,0xc48020c8}},	//   _скук, ktrt, ंडण_, _блук, 
   {{0xc20c01d9,0x25ac0139,0x00000000,0x00000000}},	//   _گٔن_, _ygel_, --, --, 
   {{0x81e4045e,0x2ab4005c,0x00000000,0x00000000}},	//   ম্ব_, _råb_, --, --, 
   {{0xebc40724,0x68ed5113,0x3014014b,0x00000000}},	//   кәнн, xuad, _адлр, --, 
   {{0x426c001f,0xfeb425da,0x7afc0334,0x68ec0115}},	//   _ድህነት_, بایت_, ftrt, vuad, 
   {{0x25a800d0,0xa3c00073,0xeeb801a9,0x00000000}},	//   ľali_, ंडत_, _ўлиш_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6e2e2204,0x00000000,0x00000000,0x00000000}},	// [3eab0] _inab, --, --, --, 
   {{0x68ee2205,0x79a4ff02,0x25ac00a2,0xaf340023}},	//   ruad, урсе, _sgel_, _እመስለ, 
   {{0x6e2c00c8,0x68ec0483,0x66f401ec,0x00000000}},	//   _knab, suad, тпеу, --, 
   {{0xb33c031c,0x648c00e4,0x00000000,0x00000000}},	//   _jgħu, rúim, --, --, 
   {{0x68ee2206,0xf674541e,0x6e2c01f7,0xe94401b9}},	//   quad, دالخ, _mnab, _شرحی, 
   {{0x15422207,0xc0b801f3,0x00000000,0x00000000}},	//   решм, _ተፈሪ_, --, --, 
   {{0x6e2c8478,0xe5b40387,0x572000db,0xf7940153}},	//   _onab, _айбы, _پۉنك, _барэ, 
   {{0x6e2e2208,0x25ac6092,0xb33c0327,0xd36c00c6}},	//   _nnab, _ugel_, _ngħu, تهى_, 
   {{0x7bc0016b,0xd2f0074d,0x00000000,0x00000000}},	//   ɛmuf, _хiор, --, --, 
   {{0x6e2e2209,0x44f80798,0x00000000,0x00000000}},	//   _anab, mê_, --, --, 
   {{0x44fa220a,0xb33c031c,0xc0b8001f,0x00000000}},	//   lê_, _bgħu, _ተፈራ_, --, 
   {{0x2f56220b,0x69080115,0xa134036b,0xf3640351}},	//   утьс, _kɾed, _لرتش, _стун, 
   {{0x62980433,0xb33c031c,0xaf340345,0x2fc00139}},	//   _ihwo, _dgħu, نویژ, _şige_, 
   {{0x6e2e220c,0xa3c001ad,0x4c800395,0x00000000}},	//   _enab, ंडि_, иляв, --, 
   {{0xf1a43c1a,0x44f8035b,0x4f303918,0xb1a401ee}},	//   _ирән, hê_, _نفوذ, _ишәк, 
   {{0x6e2c003e,0x1d2400c7,0x44f80798,0x661c02d2}},	//   _gnab, _амим, kê_, _óskh, 
   {{0x7e65ff27,0xa3c01d72,0x23d0068f,0x60dc01e7}},	// [3eac0] _imip, ंडा_, हराद, ásmh, 
   {{0x44f80798,0x47c000d4,0x00000000,0x00000000}},	//   dê_, ибув, --, --, 
   {{0x5b340153,0x79a40354,0x00000000,0x00000000}},	//   _рэпу, ăрсе, --, --, 
   {{0x645c00c0,0x00000000,0x00000000,0x00000000}},	//   _įsia, --, --, --, 
   {{0x7e64073c,0x00000000,0x00000000,0x00000000}},	//   _mmip, --, --, --, 
   {{0x8d580302,0x76ac03ee,0xd70413dc,0x00000000}},	//   וכני, _eşya, _изги, --, 
   {{0x9cf80c58,0x7e6402ea,0xa3c00307,0x60cc031c}},	//   েটিভ_, _omip, ंड़_, _ħama, 
   {{0x44f8145e,0x2ee001e4,0x62980142,0xb88400bc}},	//   bê_, _ĉif_, _chwo, _dvíř, 
   {{0xb33c0003,0x44f80120,0x6e2c00a3,0x4fc51cbc}},	//   _agħt, cê_, _rnab, ксна, 
   {{0x7056220d,0x6e2c0628,0x7e66220e,0x67200989}},	//   اندا, _snab, _amip, _šlji, 
   {{0x7642220f,0x00000000,0x00000000,0x00000000}},	//   _komy, --, --, --, 
   {{0xdd0c0d0a,0x6298062c,0x51840022,0x2d58084c}},	//   िबंध_, _ghwo, _иула, еимь_, 
   {{0xb8840316,0x76422210,0x00000000,0x00000000}},	//   _zvíř, _momy, --, --, 
   {{0x7e662211,0x60cc2706,0x76400a07,0x00000000}},	//   _emip, _çama, _lomy, --, 
   {{0x7e64020b,0x76422212,0xb33c0327,0x44f800d8}},	//   _fmip, _oomy, _tgħu, zê_, 
   {{0xba743108,0x76422213,0x44f8006a,0x2c6c01fa}},	//   لاقت, _nomy, yê_, džde_, 
   {{0x661c0ad9,0xc98436da,0x09a800eb,0x00000000}},	// [3ead0] _óski, туви, গুনা, --, 
   {{0x44f86138,0xdb1c0022,0x60dc0005,0x00000000}},	//   vê_, _hepý, ásmi, --, 
   {{0x76419f3b,0xf7722214,0x00000000,0x00000000}},	//   _bomy, يام_, --, --, 
   {{0x764000ad,0x44f80120,0x36180212,0x6aa801e4}},	//   _comy, tê_, кцію_, ĉefs, 
   {{0x66d80241,0xfbd00150,0x764021ed,0x248002d3}},	//   _bùká, _اتۋ_, _domy, _ክቃለስ_, 
   {{0x29186938,0x6298009a,0x44fa2215,0x2a68003a}},	//   _issa_, _shwo, rê_, liab_, 
   {{0xc6a407dd,0x76422216,0x291802d2,0x46a400db}},	//   _араи, _fomy, _hssa_, _ашаб, 
   {{0x76400369,0xdb1c0030,0x44f800d8,0x1fbc166d}},	//   _gomy, _nepý, pê_, ोर्ड, 
   {{0xe0d015eb,0xddc40153,0xf1a801e2,0x366401af}},	//   حزب_, sikū, پايه_, _тњрб, 
   {{0xf484815c,0x2a680190,0x76400b6f,0xd24c0050}},	//   _кухн, hiab_, _zomy, ٲنی_, 
   {{0xd24c27a1,0x76404b2a,0x644002d0,0x00000000}},	//   زنی_, _yomy, _ioli, --, 
   {{0x291a2217,0x64422218,0xa3c02c35,0xa0bc01ec}},	//   _ossa_, _holi, ंडव_, _ешкi, 
   {{0x29180810,0xdb1c010e,0x2a68007f,0x8f5001b9}},	//   _nssa_, _depý, diab_, لنیش, 
   {{0x2ba44668,0xe3e40154,0x224c00e5,0x00000000}},	//   _गृहा, প্রব, lkek_, --, 
   {{0x291a2219,0x7a2c0139,0x80f000ab,0xda980114}},	//   _assa_, _bötе, _आमुख_, еђај_, 
   {{0x067c0952,0x224c05ea,0x76ac00a2,0x7e648a15}},	//   ﻣﺎﻧﯩ, nkek_, _aşyn, _umip, 
   {{0x0e980302,0x6442221a,0x7642221b,0x29180129}},	// [3eae0] _אשקל, _ooli, _romy, _cssa_, 
   {{0x6442221c,0x7642221d,0xd8880c50,0xdbc8005b}},	//   _noli, _somy, رپان_, _ягод_, 
   {{0x224d5db5,0x291a221e,0x7640068f,0xbb540131}},	//   kkek_, _essa_, _pomy, _ئۆزب, 
   {{0x644002d0,0x00000000,0x00000000,0x00000000}},	//   _aoli, --, --, --, 
   {{0x6442221f,0x2918511b,0x05240104,0xcb94036b}},	//   _boli, _gssa_, лоцк_, _لنیش_, 
   {{0x76400921,0x224c06d1,0x7c3c0200,0x3a222220}},	//   _womy, ekek_, njrr, ldip_, 
   {{0x80c002a6,0x969477d3,0x76422221,0x3ce22222}},	//   _শিষ্, _браш, _tomy, _lviv_, 
   {{0x3a2020ac,0x224c0098,0xe3e4015b,0xd13835c9}},	//   ndip_, gkek_, প্লব, ехо_, 
   {{0x644004b8,0x0fe000f7,0x73c40032,0x8fe00032}},	//   _foli, бөйү, _кәйе, бәйҙ, 
   {{0x224c005a,0xf4840133,0x813401b9,0xb4e001f9}},	//   akek_, _ئاری, چسیز_, थळी_, 
   {{0xa3c013b4,0xb33c031c,0x2a6801d4,0xc5d403d4}},	//   ंडर_, _egħr, yiab_, _হাতপ, 
   {{0x64422223,0x61f800d2,0xdb1c05d5,0x70562224}},	//   _zoli, _gcwl, _depü, انگا, 
   {{0x64400df9,0xd1300066,0x00000000,0x00000000}},	//   _yoli, _دمش_, --, --, 
   {{0x6440036b,0x291801c4,0x00000000,0x00000000}},	//   _xoli, _rssa_, --, --, 
   {{0x7ac402bf,0xaf540075,0xead62225,0x3d0800cc}},	//   йсте, _әнқә, робь, শিষ্_, 
   {{0x7ae85207,0x8c640116,0xc0f00023,0x00000000}},	//   ádta, _әтид, ግጣም_, --, 
   {{0x7bd403d4,0xae041b76,0x00000000,0x00000000}},	// [3eaf0] _তাৰো, ष्णन_, --, --, 
   {{0x2a680457,0x224e2226,0x00000000,0x00000000}},	//   siab_, zkek_, --, --, 
   {{0x64422227,0xdb1c1a36,0xaa962228,0xf8e40131}},	//   _roli, _depó, _винч, لسەپ, 
   {{0x64409698,0x29180770,0x224c005a,0x777c0051}},	//   _soli, _tssa_, xkek_, _dxrx, 
   {{0x2918060a,0xa3c01533,0x69cc0097,0x6d5c0007}},	//   _ussa_, ंडल_, mbae, nzsa, 
   {{0x68ee2229,0x644152ed,0x22b400b0,0x67201674}},	//   mrad, _qoli, _hāki_, _šlju, 
   {{0x648c0022,0x00000000,0x00000000,0x00000000}},	//   kúiv, --, --, --, 
   {{0x6442222a,0x68ec14d0,0xdb1de477,0x69cd5054}},	//   _woli, orad, _repü, nbae, 
   {{0x68ee222b,0xdb1c01b8,0x67240450,0x224cfbff}},	//   nrad, _sepü, lvhj, rkek_, 
   {{0xdb1c014a,0x68ee222c,0x69cc0007,0x5f040276}},	//   _pepü, irad, hbae, азоа, 
   {{0x68ec076f,0x3ce00158,0xdb1c007f,0x64a401e0}},	//   hrad, _sviv_, _lepò, _баҡа, 
   {{0x68ee222d,0x22b406c8,0x69cc0369,0xaf9807a2}},	//   krad, _nāki_, jbae, ытых_, 
   {{0x660a222e,0xf0e80131,0x661c01a8,0x7124009a}},	//   _mbek, _مىنى_, _ósku, _هرول, 
   {{0x60ca222f,0xa06a2230,0x76ac00a2,0x69cc003a}},	//   mpem, _шала_, _aşyl, ebae, 
   {{0x660a2231,0xdb1e2232,0x60ca2233,0x703801d9}},	//   _obek, _repó, lpem, _حسنس_, 
   {{0x68ee2234,0x6608a48c,0x19c43420,0x0f780375}},	//   frad, _nbek, рбам, _ברצל, 
   {{0x68eccee6,0x98e400c6,0xdb1c00c7,0x2d9801e0}},	// [3eb00] grad, شكاو, _pepó, _бөрө_, 
   {{0x60c80231,0x66083917,0x200470cd,0xdb1d90dc}},	//   ipem, _abek, nfli_, _depò, 
   {{0x68ee2235,0x69cc0007,0x690801e4,0x7cec01a8}},	//   arad, bbae, _pɾec, _förð, 
   {{0x8f980302,0x6444023a,0x7cec032e,0x00000000}},	//   דיעי, öhin, _görð, --, 
   {{0x041c02a6,0x6890066d,0x97e00588,0xb4e00490}},	//   পানী_, _کیلئ, _мҩаҧ, थळे_, 
   {{0x6608376b,0x942000db,0x00000000,0x00000000}},	//   _ebek, زوعۇ, --, --, 
   {{0x7bdce142,0xdb1c033b,0x9f4401e7,0xd99c0150}},	//   iaru, _zepò, aglú_, _ﺃﻭﺠﺩ_, 
   {{0x7bde2236,0x769800d2,0x66080248,0xc3440395}},	//   haru, bíya, _gbek, ряше_, 
   {{0x60cc0790,0x2004032e,0x00000000,0x00000000}},	//   _çaml, ffli_, --, --, 
   {{0x66085c81,0x7bde2237,0xcfa5f81f,0x69cc0007}},	//   _zbek, jaru, ишни, zbae, 
   {{0x68ec245e,0x52762238,0xd2f0074d,0x648c0124}},	//   zrad, _куду, _хiар, túiv, 
   {{0xd185007b,0x68ec00ee,0x2c6c01fa,0x69cc0369}},	//   _клей, yrad, džda_, xbae, 
   {{0x7bde2239,0x69cc02f0,0xddd400d7,0x648c00c7}},	//   faru, vbae, _mlyň, rúiv, 
   {{0x7bde0f91,0x68ee223a,0xdb1e223b,0xbfd000db}},	//   garu, vrad, _repò, _ۇيۇع, 
   {{0xc5d400bd,0xbd9800b5,0x76ac00a2,0xab947b17}},	//   _হাসপ, _sとta, _aşym, сављ, 
   {{0x645c0006,0x7bde223c,0x2458529d,0x648c00ae}},	//   _įsim, aaru, _ième_, lúit, 
   {{0x7bde223d,0x69cc4c1a,0x8c1c009e,0x9f4c0793}},	// [3eb10] baru, rbae, দাবন_, änön_, 
   {{0x7bde223e,0xc7a80132,0xec14004b,0x69cc0afc}},	//   caru, ندال_, _اودد, sbae, 
   {{0xd124bc7b,0xc6a41e37,0x68ee223f,0x69cc0007}},	//   _کم_, арди, srad, pbae, 
   {{0x68ee2240,0x245806af,0xe2c8b06d,0x6724007c}},	//   prad, _mème_, қлид_, rvhj, 
   {{0x68ed226e,0xa5087abe,0x648c00e4,0x2934010f}},	//   qrad, уела_, kúit, _האָן_, 
   {{0xbdd00115,0x00000000,0x00000000,0x00000000}},	//   _inɨe, --, --, --, 
   {{0x200401b9,0x00000000,0x00000000,0x00000000}},	//   vfli_, --, --, --, 
   {{0x7bde2241,0xd24c007b,0x4fe401e0,0x13040108}},	//   zaru, فنى_, ҡмын_, ёный_, 
   {{0x7bde2242,0x60c88da1,0x00000000,0x00000000}},	//   yaru, upem, --, --, 
   {{0x7bdc0054,0x1ab000cc,0x00000000,0x00000000}},	//   xaru, টীয়া, --, --, 
   {{0x7bde2243,0x69c0007f,0x91d403d4,0x20042f13}},	//   varu, _ğlen, _ধাৰ্, rfli_, 
   {{0x7bde2244,0x60ca2245,0xa0740145,0x00000000}},	//   waru, ppem, ргүч, --, 
   {{0x62880421,0xa0c62246,0x200404cc,0x645c0024}},	//   moeo, _ايتو, pfli_, _įsij, 
   {{0x2458007f,0x7bdc003a,0xe1f80153,0xdca62247}},	//   _fème_, uaru, lgų_, саги, 
   {{0xe1f80153,0x00000000,0x00000000,0x00000000}},	//   ogų_, --, --, --, 
   {{0x7bde2248,0xe1f802d5,0x6ec400c6,0x62880295}},	//   saru, ngų_, _بتوق, noeo, 
   {{0x7bde2249,0x5c140064,0x648c0332,0xe1f800c0}},	// [3eb20] paru, _льну, núis, igų_, 
   {{0x7bde224a,0x00000000,0x00000000,0x00000000}},	//   qaru, --, --, --, 
   {{0xbc68066d,0x3ea0079b,0x648c00c6,0xa3c005f9}},	//   _مجھے_, _khit_, húis, ंडई_, 
   {{0x54e400c6,0x00000000,0x00000000,0x00000000}},	//   مستق, --, --, --, 
   {{0x22b404fe,0xb6c8040b,0x62880086,0x3e380092}},	//   _māku_, _چارے_, doeo, _እየደረ, 
   {{0x18680a93,0xb6c80014,0x3ce0000d,0xdee40092}},	//   _саги_, _نارے_, _कबने_, ማለን_, 
   {{0x35c401b9,0x00000000,0x00000000,0x00000000}},	//   _мавҳ, --, --, --, 
   {{0x22b404fe,0x787400e5,0x00000000,0x00000000}},	//   _nāku_, _اُڑا, --, --, 
   {{0x24585eb5,0xdbd80798,0xd0a8009d,0x0fe0004e}},	//   _sème_, nçói, лтод_, пөйү, 
   {{0x3ea15b94,0xe408212d,0xe1f80006,0xd018013e}},	//   _ahit_, _نغمه_, agų_, уфи_, 
   {{0x3ea001ab,0x22b40171,0xd20801c6,0x4ea4009d}},	//   _bhit_, _bāku_, _бэлд_, йрма, 
   {{0x3ea01590,0x8778008d,0x6720002d,0x24580129}},	//   _chit_, ראטי, _âlje, _vème_, 
   {{0x8d840372,0x3ea06a7d,0x76ac0432,0x00000000}},	//   сунд, _dhit_, _aşyk, --, 
   {{0x645c0006,0x3ea00254,0x6fbc00af,0x648c01e7}},	//   _įsik, _ehit_, _ईलिं, lúir, 
   {{0x4f952fa1,0xb55001e1,0x00000000,0x00000000}},	//   _урду, _sẹ́j, --, --, 
   {{0x3ea2224b,0x648c0332,0xc278010f,0x00000000}},	//   _ghit_, núir, ָרמי, --, 
   {{0x041c009e,0x00000000,0x00000000,0x00000000}},	// [3eb30] পাতী_, --, --, --, 
   {{0x648c49ab,0x4b0400f5,0x00000000,0x00000000}},	//   húir, _лямб, --, --, 
   {{0xe1f80006,0x28b4072a,0x53c407f7,0x648c00e4}},	//   ygų_, _अंकि, _र्इश, kúir, 
   {{0x37a800f7,0xb55001e1,0x00000000,0x00000000}},	//   стун_, _tẹ́j, --, --, 
   {{0x62540051,0x24180108,0x00000000,0x00000000}},	//   _báon, иоды_, --, --, 
   {{0xa348041b,0x76ac0432,0xcd680092,0x00000000}},	//   изла_, _yşyk, _አንድና_, --, 
   {{0x22b400de,0x533000f0,0x00000000,0x00000000}},	//   _nākt_, дејт, --, --, 
   {{0xe1f802d5,0x20c40e46,0x60e8022e,0x00000000}},	//   ugų_, ойим, амим_, --, 
   {{0x937402d9,0xe1f80024,0x846402e8,0x62880142}},	//   йбәт_, rgų_, _лъже, roeo, 
   {{0x648c007b,0x22b400e2,0x3ea2224c,0x00000000}},	//   rúis, _sāku_, _shit_, --, 
   {{0x22940276,0x78a00036,0xceb400fb,0x00000000}},	//   _дижя, _ëmve, ҙҙө_, --, 
   {{0x9990012d,0xc5d400eb,0x00000000,0x00000000}},	//   gdyś_, _হাঁপ, --, --, 
   {{0x43740184,0x28b6224d,0xdb080030,0x6144011c}},	//   _туҡт, _अंगि, ľník, _фела, 
   {{0x3ea04f7f,0xdb080308,0x22b402b5,0x708401ec}},	//   _whit_, žník, _wāku_, _егіз, 
   {{0x3ea2224e,0x22b40053,0x1a641b12,0x501805d0}},	//   _thit_, _tāku_, قیدی_, _כוסו, 
   {{0x28b400c5,0x6b88002f,0x00000000,0x00000000}},	//   _अंखि, ßega, --, --, 
   {{0xdb1c01b8,0x30c80183,0x00000000,0x00000000}},	// [3eb40] _nepö, _শিৱস, --, --, 
   {{0x81dc02f5,0x7d06224f,0x6ab8031c,0x35840092}},	//   তলি_, _iqis, _żafż, ያዩበት_, 
   {{0x998000b0,0x2cac0af9,0x779400e5,0x09a80011}},	//   _kakū_, ïede_, سیرا, গুলা, 
   {{0xdb1c01b8,0x287400c7,0x00000000,0x00000000}},	//   _bepö, _ҵыср, --, --, 
   {{0x7d040135,0x98a4586a,0xf434010b,0x02b0012c}},	//   _jqis, _миме, зелэ, ँदैन, 
   {{0xd6c8ac7e,0xc950025d,0x04400063,0x38c800f1}},	//   _نظرن_, _חמש_, дељн, _پاڼی_, 
   {{0xd258ee8b,0x648c007b,0x675401d3,0x00000000}},	//   ици_, túir, _ٹینس_, --, 
   {{0x7d0401d5,0xb9f40023,0x00000000,0x00000000}},	//   _oqis, _ዝን_, --, --, 
   {{0x22b4005f,0x7d04031c,0x648c00c7,0x50c80139}},	//   _sākt_, _nqis, rúir, шыйм_, 
   {{0xca801c5c,0x80a0d675,0xcd680092,0x648c0332}},	//   ﯩﻜﺘﻪ_, ومين, _አንዱና_, súir, 
   {{0x7d04013c,0x6e94104e,0xc7b800df,0x00000000}},	//   _aqis, зину, יציט, --, 
   {{0x22b40171,0xe46801e1,0x00000000,0x00000000}},	//   _vākt_, _ìkò̟, --, --, 
   {{0xd17402f2,0x00000000,0x00000000,0x00000000}},	//   _بداغ, --, --, --, 
   {{0xb3d804c5,0x09d000cd,0x00000000,0x00000000}},	//   _সাঁজ, तर्य, --, --, 
   {{0x7d054d2b,0x0a680107,0x60cc0003,0x00000000}},	//   _eqis, араи_, _ħami, --, 
   {{0xfbd000dd,0x00000000,0x00000000,0x00000000}},	//   فتہ_, --, --, --, 
   {{0x24580ba1,0x81dc00cc,0xa85473b5,0x79c800ae}},	// [3eb50] _lèma_, _তাম_, пкач, توقف_, 
   {{0x2fdc0200,0x00000000,0x00000000,0x00000000}},	//   _jevg_, --, --, --, 
   {{0xddc4c7da,0xdbc801e0,0x7d0401a9,0xd1bc0023}},	//   likš, _утыҙ_, _zqis, ሱራት_, 
   {{0xa5f99a96,0x15cc02dd,0x00000000,0x00000000}},	//   седу_, _ﺗﯩﺮﻩ, --, --, 
   {{0x69de2250,0x00000000,0x00000000,0x00000000}},	//   _iese, --, --, --, 
   {{0x69de2251,0xd76401d3,0x1b0c0154,0x00000000}},	//   _hese, _کنفی, হিরে_, --, 
   {{0x69de2252,0xddc40113,0xe7940345,0x23a4150d}},	//   _kese, hikš, _راسک, गेंद, 
   {{0xe0d802f6,0x27e003f9,0x22b400e2,0x22581427}},	//   бви_, lahn_, _sāks_, ósk_, 
   {{0x2168566d,0xbb540150,0x00000000,0x00000000}},	//   сипи_, _ﻋﻠﻤ_, --, --, 
   {{0x69de2253,0x7d0401b9,0x22580024,0x045400f7}},	//   _lese, _rqis, ųsk_, _بئرد, 
   {{0xbdd001e4,0x998002b1,0x69dc0561,0x22b400de}},	//   _anɨa, _pakū_, _oese, _vāks_, 
   {{0x69de2254,0xe5000882,0x44240375,0x27e026bd}},	//   _nese, ोऽपि_, ldn_, hahn_, 
   {{0x91b80375,0x7d0401d5,0x128840ec,0x00000000}},	//   _המני, _qqis, _امنی_, --, 
   {{0x69de2255,0x4424a8cf,0x6618012d,0x00000000}},	//   _aese, ndn_, hewk, --, 
   {{0x69de2256,0x26c00218,0xdb1c00d0,0x442400e4}},	//   _bese, jqho_, _nepô, idn_, 
   {{0x69de2257,0x1b0c009e,0x7d04031c,0x442401ab}},	//   _cese, হিলে_, _tqis, hdn_, 
   {{0x57e82d40,0xdb1c00d8,0x38c800f1,0x6254089f}},	// [3eb60] йдам_, _repõ, تازی_, _ráol, 
   {{0x69de2258,0x4c8012c4,0xb3ac033f,0x98a00064}},	//   _eese, _плыв, टेडख, _orką_, 
   {{0x69de2259,0x442401c7,0xd70845c4,0x95c8003b}},	//   _fese, ddn_, снее_, була_, 
   {{0x69de225a,0x661803a2,0x752005b1,0xb3d80154}},	//   _gese, gewk, _psmz, _সাইজ, 
   {{0xc7a00598,0x27e2225b,0x00000000,0x00000000}},	//   _җитк, bahn_, --, --, 
   {{0x69de225c,0x33940006,0x53440022,0x02a000c7}},	//   _zese, малё, зхиа, ҽрым, 
   {{0x69de225d,0x3940dbd9,0xd628009b,0x00000000}},	//   _yese, lxis_, _лове_, --, 
   {{0xcb1002e4,0x442401ab,0x877805d0,0x00000000}},	//   גלה_, adn_, _האלי, --, 
   {{0x3dc40729,0x645c0006,0x13b41e24,0x69c00139}},	//   ্ণাল, _įsiv, _فصاح, _şlek, 
   {{0x2d840724,0x2458180f,0x394000db,0xab68025c}},	//   şlek_, _tèma_, ixis_, liżż, 
   {{0xe0840014,0x93582a9d,0x00000000,0x00000000}},	//   بێوو_, _урау_, --, --, 
   {{0xc330010f,0x479808d8,0xddc400e2,0x7860007c}},	//   _רוף_, מייס, tikš, _hövd, 
   {{0x626400f4,0x786007de,0x10a400c7,0x024001f7}},	//   _تالق, _gövg, _еидн, _سَوَ, 
   {{0x69de225e,0x6618033f,0x01600107,0x00000000}},	//   _sese, zewk, _якчо, --, 
   {{0x69dc080b,0x81dc0183,0xaa9402e8,0xbb58010b}},	//   _pese, _তাত_, дивч, парх_, 
   {{0x69dd0bce,0x7860032e,0x27e0002f,0x00000000}},	//   _qese, _lövd, wahn_, --, 
   {{0x69de225f,0x44262260,0xda1cccc0,0x3940002e}},	// [3eb70] _vese, ydn_, _पसरत_, gxis_, 
   {{0x69de2261,0x786003b9,0x00000000,0x00000000}},	//   _wese, _növd, --, --, 
   {{0xe7180486,0xc0500bd9,0x182801d3,0x6f0802d0}},	//   تيات_, עזע_, تقلی_, ntdc, 
   {{0x69dc0421,0x00000000,0x00000000,0x00000000}},	//   _uese, --, --, --, 
   {{0x999000a2,0x00000000,0x00000000,0x00000000}},	//   mdyş_, --, --, --, 
   {{0xe3b004fb,0x29080a55,0x786003b9,0x9990010b}},	//   پرت_, mtaa_, _cövd, ldyş_, 
   {{0x290a2262,0x78600790,0x00000000,0x00000000}},	//   ltaa_, _dövd, --, --, 
   {{0x44240334,0x290822a9,0x645c0153,0xe29000ae}},	//   sdn_, otaa_, _įsiu, خذت_, 
   {{0x290a1321,0x4424562c,0x36050716,0x00000000}},	//   ntaa_, pdn_, _سولف, --, 
   {{0x7860029f,0x0a000154,0x29080108,0xe04400d4}},	//   _gövd, উজিং_, itaa_, єнни, 
   {{0x2908049b,0xc06c02d3,0x2f540276,0xf4841cb8}},	//   htaa_, _ብወገን_, етяс, _чутн, 
   {{0x2909116e,0x00000000,0x00000000,0x00000000}},	//   ktaa_, --, --, --, 
   {{0x47e02158,0x39409248,0xed3401c6,0x786055ac}},	//   _পানী, xxis_, нэрэ, _höve, 
   {{0x7860066d,0x394001d4,0xd12c007b,0xdcb000d1}},	//   _köve, vxis_, _ضمى_, ئىس_, 
   {{0xa3e4130b,0x29080ba7,0xa3c4375c,0x786001ed}},	//   _भजन_, etaa_, _एलन_, _jöve, 
   {{0x290a2263,0x3940004e,0x800800e5,0x15d000d1}},	//   ftaa_, txis_, _خرچہ_, _ﺟﯩﺪﺩ, 
   {{0x290801d9,0xaa6401e0,0x48e17850,0x58262264}},	// [3eb80] gtaa_, хетһ, котв, ммаб, 
   {{0x60cc05d1,0x786001e3,0x00000000,0x00000000}},	//   _çamu, _oöve, --, --, 
   {{0x786000dd,0x290a1b6f,0x212c045d,0xdc4400de}},	//   _növe, ataa_, hveh_, _mīļu, 
   {{0x290801d9,0x78602d9a,0xc1d40b6d,0x00000000}},	//   btaa_, _sövd, ठरोग, --, 
   {{0x7afd7ee0,0x29080009,0x81b000cc,0xab68031c}},	//   lurt, ctaa_, জুত_, riżż, 
   {{0xab680327,0x00000000,0x00000000,0x00000000}},	//   siżż, --, --, --, 
   {{0x645c0006,0x7afc81ed,0xb5980133,0x00000000}},	//   _įsit, nurt, _کێشا_, --, 
   {{0xc7a0a2ed,0x07a00f14,0x78600790,0x00000000}},	//   _риск, _расн, _döve, --, 
   {{0x7afe2265,0x717800d1,0x914800f5,0xbb5402dd}},	//   hurt, ябир_, ючка_, _ﻋﻠﻴ_, 
   {{0x7afe2266,0xc05402bf,0x236801e4,0x9980013a}},	//   kurt, дію_, ŝaja_, _laků_, 
   {{0x21281e31,0x22781968,0xda1c0073,0x3ef4009d}},	//   _šaht_, _کلنگ_, _पसंत_, мнээ_, 
   {{0x7afe2267,0xc7b00375,0x290866db,0x00000000}},	//   durt, כבת_, ytaa_, --, 
   {{0x50644149,0x106800c6,0x00000000,0x00000000}},	//   _отка, _وحتى_, --, --, 
   {{0xb30c0003,0xe57000c8,0x78602632,0x00000000}},	//   _གྱོང_, אַל_, _lövb, --, 
   {{0x7afe2268,0xaa44005e,0xd5dc3599,0x4f641867}},	//   gurt, ىنسى, मराज, _تاشف, 
   {{0x290a2269,0x78600cc1,0x9738001f,0xfe100051}},	//   ttaa_, _növb, _የሚያድ, _hắng_, 
   {{0xfbd00882,0x290820ac,0xfe700c4f,0xf99000ae}},	// [3eb90] _त्वम, utaa_, _خدو_, لبك_, 
   {{0x290a226a,0x7afe226b,0x39141b74,0xdc4402b5}},	//   rtaa_, burt, ъмур, _tūāu, 
   {{0x2908426d,0x7afe226c,0x0ae8182f,0xfe1001fb}},	//   staa_, curt, _برخي_, _mắng_, 
   {{0xfe10001e,0x2c6c05be,0xa25c001f,0xaee4031c}},	//   _lắng_, dždi_, ታችንን_, སྋགོ, 
   {{0x6aac0a55,0xbb540efb,0x29080009,0x7860062d}},	//   mmaf, _ﻋﻠﻰ_, qtaa_, _söve, 
   {{0xfe100016,0x786007de,0x3cfc0a1e,0x645c0024}},	//   _nắng_, _pöve, קלונ, _įsis, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x65942a30,0xfbb80302,0xe1240353,0x3ce00037}},	//   _забу, ופות_, емии, _कबले_, 
   {{0xb0f805f5,0x7afe226d,0x60cc0003,0xe4d816d0}},	//   мээх_, zurt, _ħams, _روات_, 
   {{0x6008d979,0x7afc01b9,0x6aac0175,0x78609ab0}},	//   чном_, yurt, hmaf, _töve, 
   {{0x6304014d,0x1ec802e8,0xbac000d1,0x437000d1}},	//   _سوشل, ялни_, _ﻣﺎﺋﺎ, _جۇغر, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7afc02a8,0x212c0477,0x48e801f9,0x00000000}},	//   wurt, qveh_, _चिगो_, --, 
   {{0x7afe226e,0x786003be,0xfe10001e,0xdee4023b}},	//   turt, _mövc, _gắng_, _зоки, 
   {{0x1e9496f4,0xf1a40166,0x7afc0009,0xbb540220}},	//   _прир, _прән, uurt, _ﻋﻠﻲ_, 
   {{0x7afe226f,0xd94406d3,0x00000000,0x00000000}},	//   rurt, неби, --, --, 
   {{0x7afdc8a8,0xbf6000ec,0x998001ef,0x00000000}},	// [3eba0] surt, _سگھو, _vaků_, --, 
   {{0x7afd6457,0x6aac022f,0x00000000,0x00000000}},	//   purt, amaf, --, --, 
   {{0x95c8011c,0x00000000,0x00000000,0x00000000}},	//   пула_, --, --, --, 
   {{0x76ac0209,0xd9440075,0x55045df2,0xcf90010f}},	//   _aşyr, _земи, ечка, נטא_, 
   {{0x26c4020c,0x645c0024,0x3dc40154,0xa5c00022}},	//   _élon_, _įsir, _্যাল, рҩуе, 
   {{0x04422270,0xd3c407a7,0xb4e000e1,0x2368010f}},	//   лечн, رتتى, _दबी_, ĝajn_, 
   {{0x07a00364,0x78603535,0x439103ff,0xc7a03cc5}},	//   _барн, _tövb, лашс, _бирк, 
   {{0xa5c00046,0x60cc0003,0xfe100208,0x0560009d}},	//   _көше, _ħamr, _sắng_, _өвсн, 
   {{0xeb1c0ebb,0xd5480127,0x00000000,0x00000000}},	//   _पन्त_, _عجرم_, --, --, 
   {{0x04e000a2,0x00000000,0x00000000,0x00000000}},	//   _çüỳr, --, --, --, 
   {{0x81dc0d42,0xfe10001e,0x786003e3,0x6aac0162}},	//   _তার_, _vắng_, _zövc, ymaf, 
   {{0x5184074d,0x9fc40124,0x91e001af,0x00000000}},	//   _пула, нҳәа_, _сәкһ, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x15cc01ec,0x00000000,0x00000000,0x00000000}},	//   _ﺗﯩﺰﻩ, --, --, --, 
   {{0xab940957,0x8aa62271,0xd99c02dd,0xe04850d8}},	//   тиві, ерад, _ﺃﺭﺍﺩ_, _تشنه_, 
   {{0x6e946d20,0x4ea42b95,0x00000000,0x00000000}},	//   _جلبا, _ярла, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3ebb0] --, --, --, --, 
   {{0x67d40139,0xebc40166,0xe50000cd,0x00000000}},	//   тожу, _шәмн, ोऽसि_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfbd02ab4,0xa4d40212,0xcfc400d1,0xe3dc00fe}},	//   _پتی_, воді, ﯩﭙﺎﻗ, _ঠাইব, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x29180de4,0x06b40150,0x64b800a2,0x970000d1}},	//   _ipsa_, _اﺳﻜﻪ, _eňin, _چېلى, 
   {{0xb00400b8,0x466800c0,0x437000db,0xb3e800db}},	//   _saḿy, _ерам_, دۇار, رعول_, 
   {{0xd24c0075,0xb9140882,0xd7640116,0x00000000}},	//   قنى_, traḥ_, _جەمى_, --, 
   {{0xd24e2272,0x74f872db,0x0584010b,0x64440847}},	//   تني_, _петр_, _чувм, öhis, 
   {{0x29185617,0x3494ca0f,0xbc600092,0x00000000}},	//   _mpsa_, _баур, ቶችንና_, --, 
   {{0xd434008f,0x9f440200,0xb35402f2,0x00000000}},	//   _שרעק_, malë_, _میوا_, --, 
   {{0x29180161,0xe19401c0,0xb30c0327,0x00000000}},	//   _opsa_, _ирлэ, _གྱིང_, --, 
   {{0x60242fc3,0x00000000,0x00000000,0x00000000}},	//   _адла, --, --, --, 
   {{0x6734000f,0xdca62273,0x9f440240,0x00000000}},	//   _orzj, таги, nalë_, --, 
   {{0x8c40053f,0xda7800d1,0x2c1003ce,0x5ec0030d}},	//   шере, җяң_, द्धू_, _тιет, 
   {{0x2c6c05be,0x9400013f,0x00000000,0x00000000}},	//   dždu_, _ɔkɑ_, --, --, 
   {{0x26d005f5,0x81b0015b,0x29180332,0x9f440240}},	// [3ebc0] _atzo_, জুর_, _cpsa_, kalë_, 
   {{0x291a2274,0xfaa401b9,0x9f440200,0x00000000}},	//   _dpsa_, тағо, jalë_, --, 
   {{0x645c0006,0x9f440023,0xca74022e,0x480401af}},	//   _įsip, dalë_, _arxе, техн_, 
   {{0x29180286,0x3ce0033b,0x7860007c,0x09e000cf}},	//   _fpsa_, _kwiv_, _döva, _коюн, 
   {{0x29180048,0xd468494a,0x00000000,0x00000000}},	//   _gpsa_, миде_, --, --, 
   {{0x12c8007b,0x9f440200,0x00000000,0x00000000}},	//   وظبي_, galë_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x78bc5e22,0xa694009b,0x644401f4,0x00000000}},	//   _hirv, _бруј, öhir, --, 
   {{0x78be2275,0x73c40032,0xc0e400e3,0x00000000}},	//   _kirv, _йәйе, نفين_, --, 
   {{0x3dc00280,0x78600108,0x674802d2,0xd01801f4}},	//   _agiw_, _yöva, _ísjö, ффи_, 
   {{0x78bd4781,0x522400a8,0x81b0015b,0xa834010f}},	//   _mirv, _афла, জুল_, אָרס_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x8d8443be,0x62640046,0xc6900375,0x00000000}},	//   тунд, _حالق, שאר_, --, 
   {{0x78bc0882,0xf42800a2,0x13e40011,0x6f180064}},	//   _nirv, _fläş_, _নাড়, _tpvc, 
   {{0xefb00502,0x4ea400c7,0x3b840006,0xdc4400ef}},	//   _دیدگ, _ириа, алёг, _līķu, 
   {{0x32040354,0x2918009a,0xfe7012fc,0x1dc00209}},	//   ngmy_, _ppsa_, _ودي_, _гөрн, 
   {{0x6e2c1c06,0x78be2276,0xa816106c,0x7bc80213}},	// [3ebd0] _iaab, _birv, лдаш, ıdur, 
   {{0x78be2277,0xf77000f1,0x00000000,0x00000000}},	//   _cirv, ښان_, --, --, 
   {{0x6e2e2278,0x2bd812eb,0x78be2279,0x9f44b0c9}},	//   _kaab, _ब्या, _dirv, galè_, 
   {{0x6e2e227a,0xf6508854,0x37a80228,0x64b800a2}},	//   _jaab, يئن_, ттун_, _eňil, 
   {{0x6e2e227b,0x6abc000f,0x78bc022c,0x224801e4}},	//   _maab, _iisf, _firv, _ĵak_, 
   {{0x68ee227c,0x6e2ca1bb,0x69cc089c,0x78be227d}},	//   msad, _laab, lcae, _girv, 
   {{0xe29a227e,0x6abc01ed,0xd90c004b,0x9f440240}},	//   нак_, _kisf, _ویې_, ralë_, 
   {{0x78bc47af,0x69cd4938,0x6abc0135,0x68ee227f}},	//   _zirv, ncae, _jisf, osad, 
   {{0x9f462280,0x27240368,0x660a2281,0x24580248}},	//   malé_, _hŷn_, _icek, _lèmi_, 
   {{0x68ed878a,0x69cc0399,0xd7a846c7,0x606401b9}},	//   isad, hcae, _करमच, اهدل, 
   {{0x6e2e2282,0x3ce13197,0x5f062283,0x69cc0369}},	//   _baab, _swiv_, ызна, kcae, 
   {{0x68ee2284,0x6e2e2285,0x6abe2286,0x69cc0007}},	//   ksad, _caab, _nisf, jcae, 
   {{0x61ea2287,0x6e2c8460,0x62981028,0x27240042}},	//   mael, _daab, _ikwo, _lŷn_, 
   {{0x61e99589,0x68ec0050,0xd1e802d3,0x60c801f0}},	//   lael, dsad, _መስተ_, mqem, 
   {{0x66080b91,0x6e2e2288,0x68ec8bd2,0x9f462289}},	//   _ocek, _faab, esad, kalé_, 
   {{0x61ea228a,0x6e2dcdbc,0x660a228b,0x69cc0007}},	//   nael, _gaab, _ncek, gcae, 
   {{0x7e66228c,0x2d842c44,0x68ee228d,0x60c801f0}},	// [3ebe0] _ilip, şler_, gsad, nqem, 
   {{0x61ea228e,0x6e2c2f99,0x20c8001e,0x6abc0112}},	//   hael, _zaab, _múi_, _eisf, 
   {{0x61ea228f,0x6e2d3717,0x7e662290,0x62982f99}},	//   kael, _yaab, _klip, _okwo, 
   {{0x68ec0050,0x629801f2,0x61ea2291,0x6abc01e4}},	//   bsad, _nkwo, jael, _gisf, 
   {{0x7e640451,0x20c80016,0x68ec32db,0x60c80113}},	//   _mlip, _núi_, csad, jqem, 
   {{0x7bde0920,0x66080472,0x629a2292,0x7e652121}},	//   nbru, _ecek, _akwo, _llip, 
   {{0x61ea2293,0x9f462294,0x88b007d6,0x7e64005b}},	//   fael, balé_, _ایلچ, _olip, 
   {{0x32551fa4,0x61ea2295,0x20ca2296,0x7bde2297}},	//   рвир, gael, _búi_, hbru, 
   {{0x6e2d651c,0x7bdcdac1,0x60c8014b,0x20c801fb}},	//   _raab, kbru, gqem, _cúi_, 
   {{0x7e662298,0x200407de,0x61e80421,0x629a2299}},	//   _alip, ggli_, aael, _ekwo, 
   {{0x61ea229a,0x7bdcce46,0x6e2e229b,0xf27001d9}},	//   bael, dbru, _paab, _وێتھ, 
   {{0x7e66229c,0x6e2c0050,0x6e9400d6,0xbfa402f6}},	//   _clip, _qaab, риму, ытые_, 
   {{0x68ec01d9,0x6e2e229d,0x7bde229e,0xcd040354}},	//   xsad, _vaab, fbru, ычни, 
   {{0x7e66229f,0x6e2e22a0,0x7bdc0623,0x6abc0421}},	//   _elip, _waab, gbru, _sisf, 
   {{0x6e2e22a1,0x69cc0369,0x68ec0014,0x9f44002e}},	//   _taab, tcae, wsad, yalé_, 
   {{0x68ee22a2,0xba74278f,0x7e6622a3,0x9f4400e8}},	//   tsad, ماقت, _glip, xalé_, 
   {{0x7bde22a4,0x7afc00c6,0x6abd2815,0x9f4622a5}},	// [3ebf0] bbru, arrt, _visf, valé_, 
   {{0x68ee22a6,0x7e6401fa,0x76400076,0x26c4020c}},	//   rsad, _zlip, _anmy, _élok_, 
   {{0x68ee22a7,0x7e6402f6,0x61e801c8,0x6abce248}},	//   ssad, _ylip, yael, _tisf, 
   {{0x786222a8,0x69cc0369,0xaa58f3a6,0xa5340f5c}},	//   _fövo, qcae, _риму_, инеч, 
   {{0x68ec006c,0x61ea22a9,0x9f441bce,0x2a680205}},	//   qsad, vael, ralé_, mhab_, 
   {{0x61e99589,0xa87804ac,0x2a680218,0x76400731}},	//   wael, _יאָר, lhab_, _enmy, 
   {{0xfd5802e3,0x61ea22aa,0xe858001f,0xc6a400c7}},	//   _braụ, tael, _ወረዳዎ, _браи, 
   {{0x2ce406ab,0x786001f4,0xe72401af,0x00000000}},	//   _कबूल_, _yövo, _йєғн, --, 
   {{0x216a22ab,0x7bdc12e8,0x20c80051,0x00000000}},	//   типи_, ybru, _qúi_, --, 
   {{0x2054b979,0x7e6622ac,0x786000ac,0x69d43507}},	//   ртир, _slip, _növl, युती, 
   {{0x20050a12,0xd24c1037,0xfe78425b,0x7bdc383d}},	//   rgli_, سنی_, лүк_, vbru, 
   {{0x62985695,0x81dc0183,0x20c80016,0x2fd80724}},	//   _ukwo, _তাক_, _túi_, ırga_, 
   {{0x2a6a22ad,0x60c80455,0x224c00a2,0x00000000}},	//   dhab_, qqem, mjek_, --, 
   {{0x224e22ae,0x261401ad,0x5f744d48,0x786006be}},	//   ljek_, फ्ती_, _پاتر, _cövl, 
   {{0x786011a9,0x7bdc2278,0x00000000,0x00000000}},	//   _dövl, rbru, --, --, 
   {{0x7e6622af,0x224c7536,0x64400175,0x7c2c00e2}},	//   _ulip, njek_, _lnli, _šorī, 
  
   {{0x644222b0,0x7bdc0022,0xa40407f7,0x7db40133}},	// [3ec00] _onli, pbru, रलाप_, _دڵدا, 
   {{0x1ae40372,0x661c03e0,0x00000000,0x00000000}},	//   _коом, _ıska, --, --, 
   {{0x2a680c6a,0xd708034b,0x7d000174,0x224c0432}},	//   bhab_, тнее_, ámsf, kjek_, 
   {{0x6a800116,0x38c80133,0x2a69095c,0xec3400cf}},	//   _еһса, _ماسی_, chab_, _نوۋگ, 
   {{0xcb9404d3,0x942400f7,0x7bd800e4,0x224d6a28}},	//   _منیش_, имде, _õvus, djek_, 
   {{0x48e0d390,0xd414009d,0x00000000,0x00000000}},	//   _форв, рьды, --, --, 
   {{0x534622b1,0x77941b12,0x248800ae,0xc32400ae}},	//   рхла, _ایضا, éama_, لكون_, 
   {{0x43800075,0xd5744f88,0x644222b2,0x9574013d}},	//   تلىق, _кузь, _enli, _кызч, 
   {{0x1be405d7,0x625401e1,0x7860032e,0x00000000}},	//   कराल_, _páor, _lövm, --, 
   {{0x2a688581,0xd7a806ab,0x25200092,0x417000d1}},	//   zhab_, _कराच, _ሰልጣኞ, غايس, 
   {{0x224e22b3,0x4ea407d6,0x9fa0002e,0x9f440618}},	//   bjek_, ирма, _bëñi_, salî_, 
   {{0x70842dc3,0x2a68612d,0x425000f1,0x00000000}},	//   ргүз, xhab_, _ونلر, --, 
   {{0x64400b21,0xebc40116,0xe2440d2f,0xb0f8011c}},	//   _ynli, йәнн, _دخلي, _селф_, 
   {{0x2d8622b4,0x60cc0332,0x00000000,0x00000000}},	//   ăle_, _éama, --, --, 
   {{0x2a680007,0x00000000,0x00000000,0x00000000}},	//   thab_, --, --, --, 
   {{0xe818de66,0x786005d1,0x26c4020c,0x00000000}},	//   न्ना_, _dövm, _éloi_, --, 
   {{0xc7c400c7,0x786003b9,0xfce40114,0xe6880022}},	// [3ec10] асеи, _tövl, _доњо, ҳәак_, 
   {{0x1c140574,0x2a68036b,0x6d5c9da5,0x81b000eb}},	//   द्दल_, shab_, mysa, জুক_, 
   {{0x6d5c0c8c,0x87040139,0x9400013f,0xd1e8001f}},	//   lysa, рязе, _ɔkɔ_, መሩት_, 
   {{0x2a680369,0xe8d800b4,0x490409ab,0x00000000}},	//   qhab_, nyị_, िंदो_, --, 
   {{0x224c22c1,0x6d5e22b5,0x644001c4,0x9f9c0200}},	//   vjek_, nysa, _pnli, tçëm_, 
   {{0x2408021b,0xe28401c0,0x00000000,0x00000000}},	//   унки_, өлли, --, --, 
   {{0x224e22b6,0x2a780109,0x6d5c55e3,0x25a802f0}},	//   tjek_, _kmsb_, hysa, ťal_, 
   {{0x6d5d88b4,0x59d800cd,0x0c740092,0x00000000}},	//   kysa, युपर, ጠረጠሩ_, --, 
   {{0x224c0209,0xf3ec5aba,0x644001ab,0x7080001f}},	//   rjek_, _оң_, _tnli, _ይኖራሉ_, 
   {{0x442000f8,0x6d5c09a5,0x224c1711,0x64416886}},	//   _új_, dysa, sjek_, _unli, 
   {{0xe81a22b7,0x6d5cde2c,0xddc40139,0xdce400de}},	//   न्या_, eysa, йбни, dzkā, 
   {{0x94080134,0x33b00131,0x6d5c035a,0xf0e8215c}},	//   ɑmɑn_, _غەير, fysa, _چىنى_, 
   {{0x6d5e22b8,0xd24c2f5e,0xe13404b4,0x5f740214}},	//   gysa, _سنو_, _ынды, شاگر, 
   {{0x63a222b9,0xc1b000ab,0x00000000,0x00000000}},	//   _kyln, ँधीग, --, --, 
   {{0xe3240156,0xcb6622ba,0x63a00165,0x6d5c00ad}},	//   _རགསཔ_, баре_, _jyln, aysa, 
   {{0x6d5c005c,0x9f4402f0,0x00000000,0x00000000}},	//   bysa, nalí_, --, --, 
   {{0x08c01b2e,0x0f480023,0x2bd81428,0x6d5c03ac}},	// [3ec20] збун, _ንመሰረ, _ब्वा, cysa, 
   {{0x9f4402fb,0xf98800f1,0x00000000,0x00000000}},	//   halí_, هنځي_, --, --, 
   {{0x9954005f,0x5be0010b,0xf9f42cc5,0x09e40154}},	//   _kļūt_, _мөңң, ঙ্গল_, _ফারা, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x335800a8,0x00000000,0x00000000,0x00000000}},	//   иалэ_, --, --, --, 
   {{0x77e413f7,0x9f4402f0,0x81c00154,0x6d5e22bb}},	//   गरीक_, falí_, ্রন_, zysa, 
   {{0x325402bf,0x9f4622bc,0x58f40327,0x6d5c0108}},	//   івпр, kalâ_, _བྷོས_, yysa, 
   {{0x31348c67,0x4fc401c0,0x6d5c0076,0x2258007c}},	//   цепр, йсна, xysa, öska_, 
   {{0x2ef403a6,0x769400a2,0x2b1800e1,0x6d5c9f4e}},	//   озор, _düyş, _पहलु_, vysa, 
   {{0x88980bd9,0x9f440789,0x63a008fb,0x913401d3}},	//   רביי, balí_, _gyln, _گراؤ, 
   {{0x6d5e22bd,0x00000000,0x00000000,0x00000000}},	//   tysa, --, --, --, 
   {{0xe8181b0c,0x63ac03f9,0x09e40154,0x00000000}},	//   न्डा_, ƙanc, _ফালা, --, 
   {{0x6d5e22be,0x58f4031c,0x0c840150,0x00000000}},	//   rysa, _བྷེས_, сымм, --, 
   {{0x6d5c0210,0x00000000,0x00000000,0x00000000}},	//   sysa, --, --, --, 
   {{0x2bd83156,0x6d5c00c7,0x00000000,0x00000000}},	//   _ब्रा, pysa, --, --, 
   {{0xa85408db,0x19c00daf,0x77e4443a,0xe50c05dc}},	// [3ec30] окач, дәрг, गरूक_, _समधि_, 
   {{0x69d803f3,0x9f44043b,0x0af0009d,0x00000000}},	//   _फ्री, zalí_, _нүгэ, --, 
   {{0x628400d0,0xc6a402a9,0x786003b9,0x7e8802d2}},	//   éhok, брди, _mövh, _áspí, 
   {{0x786215b6,0xd5ac0a81,0x2a7802d2,0x05b80066}},	//   _lövh, ھہٕ_, _umsb_, هدشت_, 
   {{0x81c000bd,0x9f4402fb,0xd5ac0050,0xa3e800d8}},	//   ্রম_, valí_, پہٕ_, адла_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x4df81f14,0x3cbc0150,0x00000000,0x00000000}},	//   ्लाई_, _ﺤﺎﺴﻤ, --, --, 
   {{0xbdd001e4,0xd764136e,0x978000f2,0x6594fcad}},	//   _kaɨe, _بنفی, _تیمه, _дабу, 
   {{0x34a401d9,0xfd5800b8,0x9f0400f1,0x00000000}},	//   _کملٲ, _uraḥ, ښودو, --, 
   {{0x2bd83bca,0x25ac0dd4,0x63a00034,0x3074005b}},	//   _ब्ला, _izel_, _tyln, зуюс, 
   {{0xbba802f8,0x1fa801a9,0x00000000,0x00000000}},	//   _गरेक, ркни_, --, --, 
   {{0xe8181d0c,0x60cc007b,0xdb240241,0xa1b801fe}},	//   न्ता_, _éamo, _àpés, _кулф_, 
   {{0x442622bf,0x628a22c0,0x00000000,0x00000000}},	//   oen_, mneo, --, --, 
   {{0x25ac007f,0x786003b9,0xdee40cb6,0x00000000}},	//   _mzel_, _gövh, _доки, --, 
   {{0x7b840075,0x628800b0,0x00000000,0x00000000}},	//   ساسە, oneo, --, --, 
   {{0x442622c1,0x62898ef2,0x9f440109,0x25ae22c2}},	//   hen_, nneo, malà_, _ozel_, 
   {{0x3ea222c3,0x57e89931,0x628a22c4,0x7860007c}},	// [3ec40] _ikit_, идам_, ineo, _hövi, 
   {{0x9f440589,0xe9d8016c,0x81a800cc,0x2bd80a59}},	//   calã_, икӣ_, _খলা_, बुदा, 
   {{0x25ac01fa,0x96f8007b,0x97240b61,0x00000000}},	//   _azel_, شعار_, تفاو, --, 
   {{0xd94622c5,0x442622c6,0xcd342832,0x628807f5}},	//   _деми, een_, _آیت_, jneo, 
   {{0x442622c7,0x786055e1,0x5fc807d0,0x1d780023}},	//   fen_, _lövi, रशाल, _ኣስፊሩ_, 
   {{0xe818038e,0x18680c60,0x00000000,0x00000000}},	//   न्दा_, _таги_, --, --, 
   {{0x07a222c8,0x25ae22c9,0xc7a001b9,0x81c00183}},	//   _жарн, _ezel_, _жирк, ্ৰম_, 
   {{0x62883b17,0x00000000,0x00000000,0x00000000}},	//   gneo, --, --, --, 
   {{0x442622ca,0xa3e400e1,0x1cd00327,0x25ac0205}},	//   ben_, _भड़क_, ེ༵ས_, _gzel_, 
   {{0x442622cb,0x3ea222cc,0x7054141d,0x72d00137}},	//   cen_, _akit_, سنجا, _كەتچ, 
   {{0x3ea0079b,0x9f4622cd,0x00000000,0x00000000}},	//   _bkit_, galà_, --, --, 
   {{0x62884ba3,0x3ea00ac5,0x786005d1,0x52b000d1}},	//   cneo, _ckit_, _dövi, _تەبئ, 
   {{0x3ea0020b,0x9f440589,0x02b4011a,0xc5f005d0}},	//   _dkit_, talã_, _והאם_, ודר_, 
   {{0x35cc0cb4,0x9f44a2c7,0x0b880b01,0x814000f2}},	//   ़खड़, balà_, асби_, _آنون, 
   {{0x9f4514d7,0x81c00eac,0x00000000,0x00000000}},	//   calà_, ্রণ_, --, --, 
   {{0x442622ce,0x00000000,0x00000000,0x00000000}},	//   zen_, --, --, --, 
   {{0x9f4622cf,0x7e6001f4,0x00000000,0x00000000}},	// [3ec50] malá_, ömpe, --, --, 
   {{0x442622d0,0x9f440270,0xbe0401ed,0x38b401c7}},	//   xen_, lalá_, _ٹویٹ, härf_, 
   {{0x6f08014f,0x7c9400f1,0x00000000,0x00000000}},	//   nudc, _تشيا, --, --, 
   {{0x442622d1,0xa3dc0c70,0x81c002f5,0x9f4622d2}},	//   wen_, थुन_, ্রত_, nalá_, 
   {{0x29a40022,0x6288072b,0x00000000,0x00000000}},	//   _хынҳ, vneo, --, --, 
   {{0x442622d3,0x9f440093,0x25ac09a8,0x290a22d4}},	//   uen_, halá_, _vzel_, muaa_, 
   {{0x2908049b,0x9f4622d5,0x538802d3,0x60d80142}},	//   luaa_, kalá_, _ዕንወት_, _stwm, 
   {{0x9224003d,0x786000dd,0x6288030a,0xe1f00736}},	//   _རྒྱག_, _rövi, uneo, رسب_, 
   {{0x290803c1,0x9f440784,0x25ae22d6,0xe3c400fb}},	//   nuaa_, dalá_, _uzel_, _ереү, 
   {{0x9f440372,0x442622d7,0x3ea222d8,0xdea02f4d}},	//   talà_, qen_, _skit_, کیبی, 
   {{0x3ea00327,0x9f440306,0x2908d641,0x00000000}},	//   _pkit_, falá_, huaa_, --, 
   {{0x290803a5,0x00000000,0x00000000,0x00000000}},	//   kuaa_, --, --, --, 
   {{0xa114021a,0x614622d9,0x9f4404cc,0x2908005b}},	//   _روغت, _хела, salà_, juaa_, 
   {{0x29083185,0x6f09c988,0x5574008f,0x212c002f}},	//   duaa_, budc, לערן_, mweh_, 
   {{0xabc4052f,0x9f440085,0xcb64084c,0x8fa00108}},	//   дарҙ, balá_, паре_, _паше, 
   {{0x9f443a6c,0x3ea0356c,0x290803a0,0xd2f00408}},	//   calá_, _ukit_, fuaa_, _цiер, 
   {{0x2908013c,0x96942cc8,0x0d8002e8,0x00000000}},	// [3ec60] guaa_, үреш, _плън, --, 
   {{0x97b40276,0x00000000,0x00000000,0x00000000}},	//   псеш, --, --, --, 
   {{0x81c0015b,0x00000000,0x00000000,0x00000000}},	//   ্রি_, --, --, --, 
   {{0x4ef8010f,0x1aa800cc,0x69002ca8,0x00000000}},	//   מלעג, _খূৰা, üzdü, --, 
   {{0xe818d589,0x2bd8012c,0x81c00183,0x290800e4}},	//   न्हा_, बुवा, ্ৰত_, cuaa_, 
   {{0x81c0015b,0xf3f802dd,0x00000000,0x00000000}},	//   ্রা_, іңе_, --, --, 
   {{0x6610005b,0xdec00092,0xdb140166,0x55e401f0}},	//   ähkö, ጻለን_, _äcäl, _новб, 
   {{0x46a222da,0x1dbc0574,0x38b40267,0xe87400cf}},	//   _засв, ोशात, färg_, _ىچەگ, 
   {{0x9f440122,0x212c0098,0xe818041c,0x00000000}},	//   valá_, gweh_, न्वा_, --, 
   {{0x9f4400d2,0x00000000,0x00000000,0x00000000}},	//   walá_, --, --, --, 
   {{0x6e9400a8,0x9f4622db,0x00000000,0x00000000}},	//   дину, talá_, --, --, 
   {{0x38b4007c,0x33980150,0xdb2401e1,0x00000000}},	//   lärd_, _ﺘﻼﻓﻲ_, _òpùr, --, 
   {{0x64b8010e,0x504400d4,0x00000000,0x00000000}},	//   _iňir, _недб, --, --, 
   {{0x290801f4,0x6ac4a1f3,0x00000000,0x00000000}},	//   vuaa_, वद्र, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x290a22dc,0x38b40267,0xbea40a5b,0x00000000}},	//   tuaa_, härd_, _пајк, --, 
   {{0x5ed0015b,0xb3cc00bc,0x5c3084d2,0x00000000}},	// [3ec70] থীদে, ाशाख, رکیز, --, 
   {{0x2908013c,0x7d2801d3,0x48a8014b,0x3835e258}},	//   ruaa_, őssé, ётам_, ннур, 
   {{0x212c0223,0x29080194,0xaa580c60,0x8b640066}},	//   zweh_, suaa_, _дину_, _رادم, 
   {{0x290a22dd,0x2bd8012c,0x7e18010f,0x00000000}},	//   puaa_, बुरा, ִחוס_, --, 
   {{0x2bb40490,0x38b40267,0xd5ac0d62,0x00000000}},	//   ंधका, färd_, لہِ_, --, 
   {{0x38b40267,0xb46401ec,0x15401e35,0x00000000}},	//   gärd_, нкіл, тешм, --, 
   {{0xf79402d5,0x6a700267,0x81c003d4,0x00000000}},	//   _зарэ, _våff, ্ৰা_, --, 
   {{0xe0d93277,0x00000000,0x00000000,0x00000000}},	//   ови_, --, --, --, 
   {{0xddd400ee,0x03c4afbb,0xdc4400ef,0xc1000139}},	//   _alyş, _есем, _pūļu, хүлл, 
   {{0x1f6622de,0x00000000,0x00000000,0x00000000}},	//   дком, --, --, --, 
   {{0xd3700014,0x7bc82630,0xde04004e,0x00000000}},	//   _لێوک, žduk, мпни, --, 
   {{0xdbe40ebb,0xe73400a2,0x38b4061f,0x00000000}},	//   कर्ड_, _içäý, märe_, --, 
   {{0x38b41248,0x81c00eac,0x00000000,0x00000000}},	//   läre_, ্রহ_, --, --, 
   {{0x78600108,0xb644013d,0xfd64004e,0x248800ae}},	//   _yövu, _äüvä, _үнкү, éamh_, 
   {{0x38b519e0,0xda65bb5f,0xdea0315b,0xda5835c9}},	//   näre_, واري, _لیدی, ораш_, 
   {{0xd9440107,0x7860007c,0x00000000,0x00000000}},	//   меби, _lövt, --, --, 
   {{0x38b4cd8b,0xceb000d9,0x76b4035b,0x00000000}},	// [3ec80] häre_, _ביה_, ҵәац, --, 
   {{0x38b622df,0x00000000,0x00000000,0x00000000}},	//   käre_, --, --, --, 
   {{0x38b401e6,0x00000000,0x00000000,0x00000000}},	//   värd_, --, --, --, 
   {{0x75d622e0,0x28740022,0xcf54011a,0x38b4013d}},	//   ريتا, _ҧырр, ובעת_, däre_, 
   {{0x3a0800aa,0x00000000,0x00000000,0x00000000}},	//   _وکړی_, --, --, --, 
   {{0x38b519e0,0x7b400b4b,0xd70401b9,0xe814033f}},	//   färe_, pćuć, _озги, _ढाया_, 
   {{0x998001ef,0x38b4415b,0x00000000,0x00000000}},	//   _jakž_, gäre_, --, --, 
   {{0x8778011a,0x00000000,0x00000000,0x00000000}},	//   _ואלי, --, --, --, 
   {{0x90280120,0x00000000,0x00000000,0x00000000}},	//   оцна_, --, --, --, 
   {{0x77440092,0x38b4013d,0x9f44013d,0x00000000}},	//   _የሚስተ, bäre_, kalä_, --, 
   {{0xd9ec56e9,0x625401e1,0x786003e3,0x00000000}},	//   जरात_, _láoy, _hövs, --, 
   {{0x940c00af,0x59dc0412,0x786003b9,0x7e8400e5}},	//   _साँच_, _फ्लर, _kövs, tőpa, 
   {{0x8598010f,0x00000000,0x00000000,0x00000000}},	//   ַשלו, --, --, --, 
   {{0x70548225,0x786000ac,0x81c00c58,0xe934031c}},	//   _سنبا, _mövs, ্ৰহ_, ċiżż, 
   {{0x201811a9,0x92c004c5,0x786001e3,0x9d5001d5}},	//   əsi_, ্ঠী_, _lövs, نچیت, 
   {{0xba740046,0x5a28031c,0x4ea40354,0x00000000}},	//   ناقت, _སྒྱེ_, _юрла, --, 
   {{0xf771735c,0x940c007d,0x2f180098,0x69d40807}},	// [3ec90] یام_, _सांच_, lég_, युगी, 
   {{0x7ec8020c,0x48a80816,0xe8a801f9,0x00000000}},	//   pèpè, ітам_, कतेच, --, 
   {{0xbad401af,0x00000000,0x00000000,0x00000000}},	//   _аҡсә, --, --, --, 
   {{0x2c6c0122,0x00000000,0x00000000,0x00000000}},	//   vždy_, --, --, --, 
   {{0x2a69bfc3,0x2f18020c,0x5a28031c,0x00000000}},	//   mkab_, hég_, _སྒྲེ_, --, 
   {{0x8a180014,0x60cc0798,0x38b622e1,0x2a680254}},	//   _اتھس_, _éami, täre_, lkab_, 
   {{0x248805ce,0x2f180098,0x57200137,0x6b8000ae}},	//   đam_, jég_, _مۉلك, úlgh, 
   {{0x2a6a22e2,0x6a700158,0x2f1a22e3,0xf74801f7}},	//   nkab_, _fåfe, dég_, _تلفي_, 
   {{0x26d0010f,0xf6c802d5,0x00000000,0x00000000}},	//   _huzo_, _цырк_, --, --, 
   {{0x26d00928,0x2a680037,0x00000000,0x00000000}},	//   _kuzo_, hkab_, --, --, 
   {{0x2a6a22e4,0x2f18003e,0x78600213,0x628400d7}},	//   kkab_, gég_, _kövr, éhos, 
   {{0x26d222e5,0xbf1c000d,0xc0c00139,0x00000000}},	//   _muzo_, _बहीन_, хәҗи, --, 
   {{0xe0d8030d,0x00000000,0x00000000,0x00000000}},	//   _эвл_, --, --, --, 
   {{0x225c0204,0x51580115,0x00000000,0x00000000}},	//   _howk_, _מכנו, --, --, 
   {{0xd00c75ad,0x291a22e6,0xfe78a4d0,0xdca4008e}},	//   _الى_, _aqsa_, _жүн_, _җани, 
   {{0x2a6a22e7,0x9e640150,0x786003b9,0x00000000}},	//   gkab_, _ساعن, _növr, --, 
   {{0x26d001c0,0xaac4033f,0xdea007d6,0xd9d000db}},	// [3eca0] _auzo_, लआजक, _لیگی, _ەەرگ, 
   {{0x26d00789,0xbdd001e4,0x7860007c,0x998001ef}},	//   _buzo_, _kaɨo, _rövs, _takž_, 
   {{0x26d004cc,0xdb1c02d2,0x00000000,0x00000000}},	//   _cuzo_, _afpö, --, --, 
   {{0x26d0033f,0x786006be,0x97c401ec,0x00000000}},	//   _duzo_, _cövr, _үйме, --, 
   {{0x78600213,0x00000000,0x00000000,0x00000000}},	//   _dövr, --, --, --, 
   {{0x39400483,0x7c3c0240,0x98a400fd,0xdb24032e}},	//   mvis_, ndrr, _чиге, _ápós, 
   {{0x26d222e8,0xe5f40051,0x980401af,0x00000000}},	//   _guzo_, ừơjp, _ояңд, --, 
   {{0x3ce0092e,0x225c0204,0xf73c00b5,0x786182e7}},	//   _otiv_, _cowk_, _hでok_, _tövs, 
   {{0x394222e9,0x3ce00211,0xeaec033f,0x69d40bae}},	//   nvis_, _ntiv_, _जब्त_, युटी, 
   {{0x394222ea,0x2f1925a9,0x92c00154,0x142400d4}},	//   ivis_, tég_, ্ঠে_, _їдем, 
   {{0x394027cc,0xb35c1b49,0x225c4f7f,0xb8fc031c}},	//   hvis_, ዳውያን_, _fowk_, _ྣང_, 
   {{0x3940008f,0x786003be,0x225c0493,0x99800064}},	//   kvis_, _mövq, _gowk_, _jakų_, 
   {{0x2f18066d,0x39400114,0x26140c4c,0xc690008f}},	//   ség_, jvis_, फ्टी_, ראר_, 
   {{0x39401f53,0x291801a9,0x2a68002e,0x99800064}},	//   dvis_, _rqsa_, wkab_, _lakų_, 
   {{0x2a682bdb,0x3a20013c,0x4ea40251,0x394222eb}},	//   tkab_, ffip_, _приа, evis_, 
   {{0x26d0e30c,0x394001f5,0x00000000,0x00000000}},	//   _ruzo_, fvis_, --, --, 
   {{0x39406ab9,0x2a6a22ec,0x26d00198,0x67d40818}},	// [3ecb0] gvis_, rkab_, _suzo_, возу, 
   {{0x2a6a22ed,0x26d000e4,0x00000000,0x00000000}},	//   skab_, _puzo_, --, --, 
   {{0xfe1801d9,0xd1e80092,0xda702b9f,0x00000000}},	//   _थामस_, ዘሩት_, _چُپ_, --, 
   {{0xa25c0092,0x999000a2,0x00000000,0x00000000}},	//   ሳችንን_, kgyň_, --, --, 
   {{0xc9840364,0x6e3c2a28,0x29180113,0xc4c80b40}},	//   _чуни, idsb, _uqsa_, ादेख, 
   {{0x6aae22ee,0x26d00451,0x786000ac,0x290800ad}},	//   llaf, _tuzo_, _fövq, mraa_, 
   {{0xe29a22ef,0x6aac9eda,0xd4c07aea,0xfbd40375}},	//   мак_, olaf, рөтк, נתק_, 
   {{0x6e3c5cb7,0x290a22f0,0xe6c40451,0x38b401e3}},	//   jdsb, oraa_, _شڪاي, mära_, 
   {{0x38b4049f,0x786000ac,0x6aac0421,0x290a22f1}},	//   lära_, _zövq, ilaf, nraa_, 
   {{0x6aac0730,0x2908198f,0x82800131,0x7e8400e5}},	//   hlaf, iraa_, _әқид, tőpo, 
   {{0x1fb4136b,0x5f040801,0x38b401e6,0x6aae22f2}},	//   ъсир, ъзна, nära_, klaf, 
   {{0x29080134,0x9f44007f,0xa3dc77d7,0x00000000}},	//   kraa_, nblé_, थुर_, --, 
   {{0x61ea22f3,0x2908208d,0x9f44ea0f,0xf1c80137}},	//   mbel, jraa_, nalú_, _كومى_, 
   {{0x69de22f4,0x5f74082a,0x290a22f5,0x9174011a}},	//   _afse, _لابر, draa_, _בענף_, 
   {{0x29083e6f,0x61e8011c,0x6aac015d,0x8f500066}},	//   eraa_, obel, flaf, _ننوش, 
   {{0x61ea22f6,0x6aac0579,0x394222f7,0x2909b0e6}},	//   nbel, glaf, tvis_, fraa_, 
   {{0x61e80280,0x29090488,0x3a20013c,0x00000000}},	// [3ecc0] ibel, graa_, rfip_, --, 
   {{0x394222f8,0x6aae22f9,0x61e9729c,0x38b40267}},	//   rvis_, alaf, hbel, fära_, 
   {{0x290a22fa,0x38b40267,0x68fc02d0,0x61e81780}},	//   araa_, gära_, _evsd, kbel, 
   {{0x7bdc0381,0x99900209,0x61ea22fb,0x29080ba7}},	//   lcru, ygyň_, jbel, braa_, 
   {{0xceb006a9,0x835000f2,0x95800092,0x00000000}},	//   ביא_, یپها, _ፓርቲን_, --, 
   {{0x61ea22fc,0x38b401e6,0x00000000,0x00000000}},	//   ebel, bära_, --, --, 
   {{0x61e801a8,0x99800153,0x6e3c0728,0x00000000}},	//   fbel, _takų_, ydsb, --, 
   {{0x61ea22fd,0xe6c401f7,0xca2400d1,0x00000000}},	//   gbel, _متقي, ﻠﻐﺎ_, --, 
   {{0x823222fe,0x54c41eec,0x7bdc00d5,0xe8180709}},	//   شريا, _абаб, kcru, न्का_, 
   {{0x61e805d5,0x00000000,0x00000000,0x00000000}},	//   abel, --, --, --, 
   {{0xe4740276,0x7bdc6cf6,0xc7f4011a,0x00000000}},	//   _сутэ, dcru, כזית_, --, 
   {{0x91e464e1,0x6e3c257d,0x91040fbe,0x29080009}},	//   _роде, udsb, _апде, yraa_, 
   {{0x6e3c7943,0x32d80098,0x7bdc0175,0xcd0402e8}},	//   rdsb, _héy_, fcru, ъчни, 
   {{0x4fc4010b,0xec3400c7,0x00000000,0x00000000}},	//   _исйа, ынгь, --, --, 
   {{0x6aac3207,0x6fc01c82,0x7b640ba0,0x2908058a}},	//   tlaf, _শ্ৰে, атте, wraa_, 
   {{0x290a22ff,0x7bdc003a,0x6aacd32a,0xff00010a}},	//   traa_, acru, ulaf, _тяшн, 
   {{0x29084743,0xa3a800af,0x6aae2300,0x00000000}},	// [3ecd0] uraa_, _गुन_, rlaf, --, 
   {{0x29080a4d,0x61e977ea,0x38b401e6,0x7bdc00a3}},	//   rraa_, zbel, tära_, ccru, 
   {{0x61ea2301,0x9f440395,0x6aae2302,0xaa4c001f}},	//   ybel, falù_, plaf, _አገልጋ, 
   {{0x24f97746,0xb9e402bf,0x38b40267,0x9f440129}},	//   енды_, _віри, rära_, ublé_, 
   {{0x38b401b8,0x7bc80024,0xdc5497d1,0xf9640133}},	//   sära_, ždut, _شریک, _پۆلێ, 
   {{0x32d800e8,0x61e801f5,0x38b400c5,0xa878010f}},	//   _béy_, wbel, pära_, _טאָר, 
   {{0xa0a4b404,0x32d80de2,0x9f4400cf,0x00000000}},	//   ғанд, _céy_, salú_, --, 
   {{0xd24c0131,0x61ea2303,0x6d4000da,0x32d81bce}},	//   كنى_, ubel, ālaj, _déy_, 
   {{0xdff4109a,0x7ca40092,0x00000000,0x00000000}},	//   лянь, _መፅሀፍ_, --, --, 
   {{0x32d800e8,0x7bc000fe,0x73c400c7,0x00000000}},	//   _féy_, ্ৰয়ো, уӡӡа, --, 
   {{0x61e8127b,0x334401d9,0xfe78955d,0x389c010f}},	//   pbel, _پننِ, күк_, ויזנ, 
   {{0xb284dfe6,0x25ac002e,0x38b40267,0x84c00166}},	//   _кычк, _kyel_, järn_, _сәҗд, 
   {{0x6fc801ad,0x6288002f,0x00000000,0x00000000}},	//   _रणथं, mieo, --, --, 
   {{0x25ac1529,0x32d8003e,0x1e84abba,0x2dc401ec}},	//   _myel_, _yéy_, _әлим, шқын_, 
   {{0x6a707c1d,0x32d8002e,0xa3a809bb,0xe50c000d}},	//   _såfa, _xéy_, _गुम_, _समझि_, 
   {{0x7afc010a,0x418802dd,0x24840051,0x00000000}},	//   rsrt, _ﯗﻟﮕﯩ, _lmlm_, --, 
   {{0x25acf848,0x60c001ab,0x58241eca,0x81c00154}},	// [3ece0] _nyel_, omlm, лмаб, ্রক_, 
   {{0x26cc067c,0xbd4400ec,0x00000000,0x00000000}},	//   _aieo_, _منڊي, --, --, 
   {{0xf4848d24,0x00000000,0x00000000,0x00000000}},	//   یاتی, --, --, --, 
   {{0xda707fc5,0x32d80694,0x00000000,0x00000000}},	//   _چُھ_, _réy_, --, --, 
   {{0x628812ed,0x32d81bce,0x94840209,0x00000000}},	//   dieo, _séy_, лыкд, --, 
   {{0x62880a73,0x25ac0fac,0x94940b7e,0xc774004e}},	//   eieo, _dyel_, ышеч, _өтсө, 
   {{0x25ac020c,0x93240a8e,0x00000000,0x00000000}},	//   _eyel_, ارتن, --, --, 
   {{0x25ac0100,0x26cc01fb,0xc32400ae,0x00000000}},	//   _fyel_, _gieo_, اكين_, --, 
   {{0x32d80694,0x644c0356,0x00000000,0x00000000}},	//   _wéy_, _şniţ, --, --, 
   {{0xc5600372,0x32d80de2,0x6ed80a8a,0xbac00046}},	//   _укук, _téy_, _नंदु, _ﺣﺎﺑﺎ, 
   {{0xc4500014,0x08540375,0x03a0014b,0xe8181025}},	//   _دَلب, אבים_, _лифо, न्टा_, 
   {{0x9f4404cc,0x41e000c0,0x00000000,0x00000000}},	//   mblì_, _ліша, --, --, 
   {{0x61fc09f3,0x8d844530,0x00000000,0x00000000}},	//   ðsle, уунд, --, --, 
   {{0xa3a80bc0,0x7c8411f7,0xc10001e2,0x00000000}},	//   _गुड_, бусе, _اووي, --, 
   {{0x09bc07b6,0x20c801f7,0x00000000,0x00000000}},	//   ्श्य, _شبهي_, --, --, 
   {{0x6f0401ab,0x8aa46bce,0x25a83af2,0x00000000}},	//   _āich, ургд, żali_, --, 
   {{0x26cc05da,0x291c00d2,0x3da40153,0xac94014b}},	// [3ecf0] _rieo_, îwa_, _грэб, _вапш, 
   {{0x26cc01e0,0x940c013f,0x25ac007f,0x6fc801f9}},	//   _sieo_, kofɑ_, _ryel_, _रणां, 
   {{0x25ac02e2,0xa5d4005b,0x00000000,0x00000000}},	//   _syel_, ажеш, --, --, 
   {{0x24840ac5,0x2cb00204,0x25ac007f,0x78bc002f}},	//   _smlm_, llzd_, _pyel_, _ehrv, 
   {{0x67d40107,0x00000000,0x00000000,0x00000000}},	//   _вогу, --, --, --, 
   {{0xe3662304,0x00000000,0x00000000,0x00000000}},	//   икли, --, --, --, 
   {{0x26cc01e0,0x62881676,0xe35401c0,0x00000000}},	//   _tieo_, tieo, ртлэ, --, 
   {{0xa3a80f4a,0xaab42c33,0xe694104e,0xe3b000ec}},	//   _गुण_, ंतिक, _тибы, ٽرڪ_, 
   {{0x628821e3,0x25ac020c,0xb0f801c0,0x38b4007c}},	//   rieo, _uyel_, лээх_, kärl_, 
   {{0x516400f7,0x6288017a,0xf99401e4,0xd1c401f4}},	//   рүшү_, sieo, naɨa_, шлые_, 
   {{0xaab406e3,0x00000000,0x00000000,0x00000000}},	//   ंताक, --, --, --, 
   {{0xddc5483b,0xe3f80451,0xf36400db,0xf0a8004e}},	//   ибни, _سوچڻ_, _утун, ккөл_, 
   {{0xa07402d5,0x9ec801d9,0x00000000,0x00000000}},	//   _выйш, _یِتم_, --, --, 
   {{0x25a800ee,0x00000000,0x00000000,0x00000000}},	//   ýaly_, --, --, --, 
   {{0x1a646694,0xe81800bc,0x00000000,0x00000000}},	//   لیدی_, न्छा_, --, --, 
   {{0x99e62305,0x8f9802e4,0x78bc107d,0x00000000}},	//   ржад, _ביצי, _shrv, --, 
   {{0x9f4400c6,0x00000000,0x00000000,0x00000000}},	// [3ed00] iblí_, --, --, --, 
   {{0x7e656541,0x6a700158,0x95fc012c,0x62980175}},	//   _hoip, _fåfo, उण्ट_, _ljwo, 
   {{0x7e662306,0x00000000,0x00000000,0x00000000}},	//   _koip, --, --, --, 
   {{0x0bb406a9,0x00000000,0x00000000,0x00000000}},	//   _כלים_, --, --, --, 
   {{0x7e648967,0x78bc020b,0xceb002e4,0x38b4002f}},	//   _moip, _thrv, קיד_, lärm_, 
   {{0x7e662307,0x24880129,0x454000db,0x00000000}},	//   _loip, éamp_, زنىق, --, 
   {{0x81e402f5,0x6d40005f,0xe8680092,0x00000000}},	//   _বয়_, ālai, _ደረጃም_, --, 
   {{0x32554865,0x7e6400c7,0x46a00153,0xf238011c}},	//   свир, _noip, _дасв, упиш_, 
   {{0xe46800cf,0x34480117,0x00000000,0x00000000}},	//   ئلۉۉ_, _бӯйи_, --, --, 
   {{0x69b80574,0x506400c7,0x76422308,0x4fc41f5c}},	//   ्धती, ртиа, _hamy, исна, 
   {{0x76422309,0x7e646bf9,0x230800f2,0x00000000}},	//   _kamy, _boip, _متني_, --, 
   {{0xce680166,0x38b40086,0x7e66230a,0x7642230b}},	//   трод_, därm_, _coip, _jamy, 
   {{0x7641b328,0x9f440306,0xc278011a,0x6a70007c}},	//   _mamy, malý_, _בראי, _såfo, 
   {{0x76400bd7,0x63ac03f9,0x60cc00d8,0xd2c40055}},	//   _lamy, ƙant, _éamp, _dṛśe_, 
   {{0x7e640418,0x91f807f7,0x9e9400f2,0x201000d7}},	//   _foip, _एजाज_, _گاوچ, ózie_, 
   {{0x7642230c,0x9f440122,0xadf40063,0x00000000}},	//   _namy, nalý_, _упиш, --, 
   {{0x38b40254,0x79a400f3,0x00000000,0x00000000}},	// [3ed10] pärl_, орфе, --, --, 
   {{0x7e640bd7,0x07e40a89,0x00000000,0x00000000}},	//   _zoip, рцам, --, --, 
   {{0x7642230d,0x7e64090c,0xcaa4009f,0x00000000}},	//   _bamy, _yoip, _نصحي, --, 
   {{0x7642230e,0x36180212,0x9f4c0066,0x9ba000d1}},	//   _camy, ицію_, énéa_, _رەقى, 
   {{0xe94400f2,0x00000000,0x00000000,0x00000000}},	//   _ارجی, --, --, --, 
   {{0x76403cf7,0x00000000,0x00000000,0x00000000}},	//   _eamy, --, --, --, 
   {{0xe7ec05ba,0x76400a85,0x9f440306,0xf7940006}},	//   _च्या_, _famy, falý_, _дарэ, 
   {{0x7642230f,0x0585c4e4,0xd764113e,0xc4e4030d}},	//   _gamy, _кузм, _دەمى_, _влаç_, 
   {{0x7e6400c7,0x0574feab,0xa3a8000d,0x9f4400d7}},	//   _roip, _ئازد, _गँव_, rblí_, 
   {{0x20562310,0x76401718,0x7e6401a9,0xf3643c1a}},	//   стир, _zamy, _soip, стән, 
   {{0x7e662311,0x76422312,0x23b402dd,0x1418008d}},	//   _poip, _yamy, _اماس, _תועב, 
   {{0x6440adfe,0x4424208d,0x6f1c00a3,0x3cdc012d}},	//   _hali, lfn_, àrca, _गंदे_, 
   {{0xdd922313,0x7e662314,0xa0581d93,0x3f880034}},	//   سوس_, _voip, _مؤثر_, ńcu_, 
   {{0x64422315,0x61fa2316,0x7e640161,0x00000000}},	//   _jali, _hewl, _woip, --, 
   {{0x7e662317,0x9f040acb,0x61f8062c,0xcff4011a}},	//   _toip, _اوبو, _kewl, _הצצה_, 
   {{0x64422318,0x60d80083,0x61f8062c,0x00000000}},	//   _lali, _kuwm, _jewl, --, 
   {{0x76422319,0x1a640517,0x6a70143a,0x6440127b}},	// [3ed20] _ramy, لیگی_, _kåfj, _oali, 
   {{0x7642231a,0x6442231b,0x7d06231c,0x38b400c5}},	//   _samy, _nali, _ivis, märk_, 
   {{0x7d0530b6,0x9b44e824,0x76408021,0xbd4400ec}},	//   _hvis, _انجو, _pamy, _انڌي, 
   {{0x61f8048d,0x6442231d,0x7d04383d,0x786000a2}},	//   _newl, _aali, _kvis, _jövz, 
   {{0x78600cc1,0x9f442195,0xd468c1ef,0x75200334}},	//   _mövz, valý_, лиде_, _qqmz, 
   {{0x6442231e,0x7642231f,0x48e115b1,0x7d040200}},	//   _cali, _wamy, _хорв, _mvis, 
   {{0x76422320,0x0874008f,0x61fa2321,0x55e406d4}},	//   _tamy, _פעלט_, _bewl, _гобб, 
   {{0x7d062322,0x64422323,0x82a00022,0x00000000}},	//   _ovis, _eali, зшье, --, 
   {{0x8eb01823,0x61fa2324,0x61fc041e,0x38b4000d}},	//   ۋەتت, _dewl, ðsla, järk_, 
   {{0x64422325,0xb5080e26,0x0eea2326,0x60d800a2}},	//   _gali, _مۉچۅ_, льми_, _duwm, 
   {{0x7d0574e9,0x6a7005ac,0x6fb4104c,0xbed401c6}},	//   _avis, _dåfj, تمدا, йдэх_, 
   {{0x7d0406d6,0xc3b400c8,0x7de402dd,0x00000000}},	//   _bvis, _פלאץ_, зірд, --, 
   {{0x64422327,0x02422328,0x3d940107,0x09a4230e}},	//   _yali, _رَوَ, зияр, _कुंठ, 
   {{0x64422329,0x7d06232a,0x9f440407,0x4030109a}},	//   _xali, _dvis, galó_, _неіс, 
   {{0x7d06232b,0x7f90030d,0x00000000,0x00000000}},	//   _evis, _нашх, --, --, 
   {{0x61f8002e,0x60d8010e,0x00000000,0x00000000}},	//   _xewl, _yuwm, --, --, 
   {{0x6e2e232c,0x3cec02fb,0xe9180212,0x4424015d}},	// [3ed30] _ibab, čivý_, розі_, yfn_, 
   {{0x0ba810fe,0x9f46232d,0x6d5c02d0,0x00000000}},	//   _ماجى_, malò_, mxsa, --, 
   {{0x7d041cbd,0x6442232e,0x6d4c00ad,0x3b540276}},	//   _zvis, _rali, _hraa, _екэр, 
   {{0x6d4cf0b1,0xfa1002f5,0x6c3401d5,0x27e2232f}},	//   _kraa, হ্বল_, _افگا, schn_, 
   {{0x6e2e2330,0x61f80de2,0xe3e8872f,0x00000000}},	//   _mbab, _rewl, لکان_, --, 
   {{0x68ee2331,0x6d4c1368,0xddcc00b0,0x6d5c0009}},	//   mpad, _mraa, _ōkūr, ixsa, 
   {{0x64422332,0x68ee2333,0x6e2e2334,0xe1f000c6}},	//   _vali, lpad, _obab, وسة_, 
   {{0x64422335,0x68ec1fe8,0x626400d4,0x00000000}},	//   _wali, opad, івпа, --, 
   {{0x660a2336,0x68ee2337,0xa3a805f9,0x672401bf}},	//   _idek, npad, _गुर_, lthj, 
   {{0x64422338,0x68ed9409,0x9f44011c,0x65b401f1}},	//   _uali, ipad, dalò_, _výhľ, 
   {{0x7d062339,0x6d4e233a,0x6e2c01af,0x66080122}},	//   _svis, _araa, _bbab, _kdek, 
   {{0x6d4e233b,0x63ac2523,0x6e2e233c,0x9f440ffb}},	//   _braa, ğand, _cbab, falò_, 
   {{0x63ac0fcd,0x6e2e233d,0x9f44011c,0x7d040194}},	//   şand, _dbab, galò_, _qvis, 
   {{0x6d4c0443,0x6e2e233e,0xa0c41c4e,0x672401bf}},	//   _draa, _ebab, _بيتو, kthj, 
   {{0x6d4e233f,0xe8f4025c,0x6608037e,0x6d5c0009}},	//   _eraa, _བསུབ_, _odek, axsa, 
   {{0x6d4c3d27,0x660a2340,0x7d062341,0x6e2e2342}},	//   _fraa, _ndek, _tvis, _gbab, 
   {{0x6d4cf9f5,0x68ec3399,0x7d040623,0x2a78020b}},	// [3ed40] _graa, gpad, _uvis, _dlsb_, 
   {{0x6e2c0306,0x9a880014,0x786001f4,0xace801e2}},	//   _zbab, _چندٕ_, _yövy, _اريل_, 
   {{0x38b62343,0x68ec00c6,0xa3a8443a,0x9a880014}},	//   näri_, apad, _गुल_, _نندٕ_, 
   {{0xd62a2344,0x8f980375,0xcf900375,0x3b180213}},	//   роде_, ביעי, וטב_, murq_, 
   {{0x66081418,0x44f002d5,0x68ec00de,0x00000000}},	//   _ddek, дпіс, cpad, --, 
   {{0x660802e3,0x38b46c0f,0xe95801f7,0x00000000}},	//   _edek, käri_, _اسٽڪ_, --, 
   {{0x969418a4,0x9f440100,0x00000000,0x00000000}},	//   _драш, zalò_, --, --, 
   {{0xf4840799,0xa3a80073,0xa9040244,0x9104004e}},	//   _کاری, _गुळ_, _ببێن, очод, 
   {{0xca780a7c,0x00000000,0x00000000,0x00000000}},	//   ינקט, --, --, --, 
   {{0x6d4c5bae,0x6608220e,0x8538011a,0x09ac00fe}},	//   _rraa, _zdek, _דגמי, _কণমা, 
   {{0xb8dc2fb5,0x44440014,0x11e40251,0x6d4c01ab}},	//   _ཅེ_, _برقہ, _джем, _sraa, 
   {{0x6d4c7777,0x25700137,0x68ee2345,0x00000000}},	//   _praa, _تۇۇس, ypad, --, 
   {{0x6d5c0067,0x50640023,0x504401ec,0x2e2c022e}},	//   uxsa, _ዝገልጽ, _медб, rоf_, 
   {{0x6d4e2346,0x68ee2347,0x0ca8efaf,0xf8d8000d}},	//   _vraa, vpad, ртми_, _भूइय, 
   {{0x6d4c7bee,0xddd400a2,0x8d8c0092,0x00000000}},	//   _wraa, _onyň, መራቸው_, --, 
   {{0x6e2e2348,0x6d4e2349,0x68ec00dc,0x00000000}},	//   _ubab, _traa, tpad, --, 
   {{0x6d4e234a,0x68ee234b,0xac95d8d5,0x00000000}},	// [3ed50] _uraa, upad, _наиш, --, 
   {{0x68ec885b,0x672403cd,0x3b1803b9,0x00000000}},	//   rpad, tthj, burq_, --, 
   {{0xd24400b2,0x00000000,0x00000000,0x00000000}},	//   _ٻن_, --, --, --, 
   {{0x68ee234c,0x2c7c0ca8,0x67247fff,0x656c0158}},	//   ppad, _dìde_, rthj, øaho, 
   {{0x6608069c,0xd1240491,0x6aae234d,0x6474008e}},	//   _vdek, _ثم_, moaf, зыйф, 
   {{0x6aac0421,0xb5080137,0x00000000,0x00000000}},	//   loaf, زۉمۅ_, --, --, 
   {{0x87940014,0x61fc022c,0x00000000,0x00000000}},	//   _بێار_, ðslo, --, --, 
   {{0x6aac037e,0x38b4005b,0x66086b7a,0x766800f1}},	//   noaf, väri_, _udek, _ویلې_, 
   {{0xe1f0190f,0x00000000,0x00000000,0x00000000}},	//   وسک_, --, --, --, 
   {{0x6aac4d11,0x9f84651e,0x38b48234,0x307412c4}},	//   hoaf, згод, täri_, дуюс, 
   {{0x14c82be7,0x5f44007b,0xef1800de,0x00000000}},	//   _اهلی_, أنجل, guļ_, --, 
   {{0x71f80150,0xe2840271,0x00000000,0x00000000}},	//   _ۇرۇس_, _عطای, --, --, 
   {{0x2b400618,0x31580597,0x661c01a8,0x6aac0175}},	//   _ashc_, _وجهة_, _ösku, doaf, 
   {{0x38b402f6,0x9f06234e,0xcfc000cc,0x00000000}},	//   päri_, _فوتو, োড়ন, --, 
   {{0x6aac0618,0x5f04010b,0xd0e407d6,0x00000000}},	//   foaf, _эзйа, _وکیم_, --, 
   {{0x6aac009d,0xb6440166,0x00000000,0x00000000}},	//   goaf, _äüxä, --, --, 
   {{0x6ec4007b,0x38040107,0x7fb80037,0x2d9801ee}},	// [3ed60] _تتوق, дозҳ, _उरुँ, _дөрө_, 
   {{0xb9040c66,0x3ea00b21,0x6aac0618,0xaf040166}},	//   _पं_, _hjit_, aoaf, _эчәк, 
   {{0x9ce80156,0x3ea00649,0x96b8c417,0xd6d433d2}},	//   འེམས, _kjit_, буду_, ستاغ, 
   {{0x8d90006c,0x38b40037,0x00000000,0x00000000}},	//   _آلیش, järv_, --, --, 
   {{0x48e08af4,0x3ea0002d,0xf428031c,0xb8080011}},	//   _появ, _mjit_, _ལྡུད_, র্গত_, 
   {{0x798401c8,0xd7f000c6,0x6a7003cd,0xc0e80023}},	//   mziw, _سكر_, _råfi, _ዘብሎ_, 
   {{0xd9bc02a6,0x07a005f5,0x4364147e,0xcc38010f}},	//   _অলিম, _зарн, зајн_, מעסט, 
   {{0x35c401b9,0x00000000,0x00000000,0x00000000}},	//   _жабҳ, --, --, --, 
   {{0x7986234f,0xc0e802d3,0x2ce80327,0x59bc00dc}},	//   nziw, _ዘብል_, _འཕེབ, ्धिर, 
   {{0x3ea003a2,0x2fda2350,0x929000c7,0x00000000}},	//   _ajit_, ørg_, ьақц, --, 
   {{0x78a000d2,0x1ae002f5,0x6aac009f,0x63ac0205}},	//   _ímvu, গীতে_, yoaf, ğanc, 
   {{0x59bc44af,0x51840484,0x63ac03e0,0x00000000}},	//   ्धार, _нула, şanc, --, 
   {{0xe2a80050,0xe86802d3,0x6aac05da,0x7d0003b2}},	//   _بالن_, _ተዛሪቡ_, voaf, ámsp, 
   {{0x79862351,0x6ab40d5f,0x7e60007c,0x00000000}},	//   dziw, ंत्र, ömpr, --, 
   {{0x6aae2352,0xff4c004b,0x00b8011a,0x00000000}},	//   toaf, _مخي_, _המגמ, --, 
   {{0x3ea1b8b1,0xa9780137,0xba44009d,0xd83c00d7}},	//   _gjit_, ойбу_, нхуй, áčne_, 
   {{0xdd9001ed,0x3d9402e8,0x00000000,0x00000000}},	// [3ed70] _لوٹ_, _пиър, --, --, 
   {{0x6aacd93d,0xd83c0219,0x38b4000d,0x00000000}},	//   soaf, ščne_, käru_, --, 
   {{0xb904069f,0x00000000,0x00000000,0x00000000}},	//   _पू_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa5082991,0x494400db,0xc86400d8,0x38b40037}},	//   цела_, _ээнб, _етви, värv_, 
   {{0x3ad800b0,0x94c8004b,0x00000000,0x00000000}},	//   _hōpa_, ياوې_, --, --, 
   {{0xe6940c9e,0x53300798,0x00000000,0x00000000}},	//   _живы, вејт, --, --, 
   {{0xd24c0075,0xd5ac00dd,0x60e8117e,0x9f44007c}},	//   لنى_, اہے_, омим_, nblå_, 
   {{0xe58400db,0xf1d400db,0x00000000,0x00000000}},	//   _تۅشۉ_, нөшө, --, --, 
   {{0x3ea0045f,0x3494a5c9,0xf48431dc,0x00000000}},	//   _sjit_, _заур, _пухн, --, 
   {{0x4abcb658,0x712453b2,0x38b401e3,0xfe78009d}},	//   ्षाव, وریل, märt_, зүй_, 
   {{0x38b62353,0x00000000,0x00000000,0x00000000}},	//   lärt_, --, --, --, 
   {{0x61462354,0x00000000,0x00000000,0x00000000}},	//   _цела, --, --, --, 
   {{0x67340135,0x38b40267,0xdca62355,0x60dc0162}},	//   _opzj, närt_, фаги, ísmu, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3ea002d3,0x38b40036,0x4ef8011a,0xd2f0030d}},	//   _ujit_, härt_, _והקו, _чiер, 
   {{0x798601f5,0x6b8801e4,0x5ca4004e,0x66e40064}},	// [3ed80] uziw, ĝega, _оииб, _rėka, 
   {{0x38b401e3,0x00000000,0x00000000,0x00000000}},	//   järt_, --, --, --, 
   {{0x7c3e2356,0x779410e8,0x6d580241,0x59bc0118}},	//   merr, ریرا, _àwar, ्धहर, 
   {{0x7c3e2357,0x82e80135,0x3ce000c5,0xb9040154}},	//   lerr, _ལྕེའ, _kuiv_, _নব_, 
   {{0xc68c01d9,0x27ec0139,0x94a801f7,0xd4c401e2}},	//   جِن_, _şene_, ياتِ_, وغتي, 
   {{0x3a200194,0x38b4055e,0x86c000d1,0x00000000}},	//   lgip_, gärt_, ىيەن, --, 
   {{0x3ce00204,0x39400309,0x7c3c04e6,0x00000000}},	//   _luiv_, lwis_, ierr, --, 
   {{0x7c3e2358,0x3a21b852,0x461001f7,0x06cc01ec}},	//   herr, ngip_, _لوفر, _ﺑﺎﺳﻪ, 
   {{0x14243461,0x7c3e2359,0x39401028,0x63ac43dd}},	//   _одам, kerr, nwis_, ğana, 
   {{0x7c3c4580,0x63ac43eb,0x2ef6235a,0x8af40213}},	//   jerr, şana, нзор, çəkl, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x02d401b9,0x00000000,0x00000000,0x00000000}},	//   _قولب_, --, --, --, 
   {{0x3206235b,0x7c3c26c2,0xe2a801d9,0x3ce00332}},	//   mamy_, ferr, _عامن_, _cuiv_, 
   {{0x3205ea71,0xada400c7,0x00000000,0x00000000}},	//   lamy_, даҭл, --, --, 
   {{0x4ea6235c,0x0a68016c,0xcfa825da,0x4a28031c}},	//   _ориа, ораи_, _باشم_, _སྡུལ_, 
   {{0x3206235d,0x22a402b5,0x6e4400c6,0x38b4007c}},	//   namy_, pēke_, _أنظم, kärs_, 
   {{0x6e3c127b,0x3940b35f,0xbea800e3,0x9f44007c}},	// [3ed90] mesb, gwis_, _تهين_, rblå_, 
   {{0x7c3caf16,0x69c00115,0x1cbc0327,0xf65000e5}},	//   cerr, _ŝles, _ཇེར_, یئن_, 
   {{0x38b4049f,0x32047aaa,0x9b34010b,0x888001b9}},	//   värt_, kamy_, _пүрс_, _ییرن, 
   {{0x6e3e235e,0x6a702b96,0x38b6235f,0x32041329}},	//   nesb, _påfu, färs_, jamy_, 
   {{0x320405ff,0xcae4009e,0xd5ac0050,0x38b401e3}},	//   damy_, _ফিটফ, مہِ_, gärs_, 
   {{0x29086d78,0x6e3cde20,0x64c801ad,0x55503f6c}},	//   msaa_, hesb, िगेश, اپور, 
   {{0x32042ab1,0x6578029f,0x2909f8bb,0xa5f801f0}},	//   famy_, _şahı, lsaa_, _неву_, 
   {{0x7c3de3e7,0x32062360,0x6e3e2361,0x2908198f}},	//   zerr, gamy_, jesb, osaa_, 
   {{0x290822a9,0x6e3e2362,0x81d400bd,0x7c3c4dc9}},	//   nsaa_, desb, ়ুন_, yerr, 
   {{0x290822a9,0x1f662363,0x7c3e2364,0x69dc010a}},	//   isaa_, еком, xerr, _lgse, 
   {{0x3ce1d1e5,0x2908022f,0x4ad809bb,0x1fb400fd}},	//   _suiv_, hsaa_, _मंगव, эсир, 
   {{0x290a2365,0x7c3c0a40,0x32040034,0x6e3e2366}},	//   ksaa_, werr, camy_, gesb, 
   {{0xed000124,0x00000000,0x00000000,0x00000000}},	//   аҟын, --, --, --, 
   {{0x61ea2367,0x69dc1bce,0x7c3c0e78,0x5041d432}},	//   lcel, _agse, uerr, _бешб, 
   {{0x2005ffb4,0xdea10689,0x7c3e2368,0x2908208d}},	//   mali_, _میدی, rerr, esaa_, 
   {{0x61ea2369,0xda66236a,0x7c3e236b,0x2908208d}},	//   ncel, رازي, serr, fsaa_, 
   {{0x2908022f,0x3a200140,0x4fd00022,0x39404fa5}},	// [3eda0] gsaa_, rgip_, _ижәт, uwis_, 
   {{0x2006236c,0x3942236d,0x69dc002e,0x320486df}},	//   nali_, rwis_, _egse, zamy_, 
   {{0x29098efe,0x20040607,0x66e40006,0x61ea236e}},	//   asaa_, iali_, _dėko, kcel, 
   {{0xd9d00aaf,0x29080a55,0x7ac400c7,0x38b40112}},	//   _مەزگ, bsaa_, _рҩба, tärs_, 
   {{0x2006236f,0x61ea2370,0x860400cf,0x7b840131}},	//   kali_, dcel, رقوق_, _ساھە, 
   {{0x3205632c,0x20054ae6,0x61e80381,0x63ac0724}},	//   wamy_, jali_, ecel, ğann, 
   {{0x20062371,0x32040034,0x69dc0175,0x61e8b1ec}},	//   dali_, tamy_, _ygse, fcel, 
   {{0xcb10025f,0x61e80117,0x00000000,0x00000000}},	//   אלה_, gcel, --, --, 
   {{0x20062372,0x27540020,0x32047aaa,0x8c24015b}},	//   fali_, _የሚሰጠ, ramy_, য়তন_, 
   {{0x20062373,0x32062374,0x61e80276,0x854400ee}},	//   gali_, samy_, acel, _язув_, 
   {{0x61e84275,0xb4cc50dc,0x6e3e2375,0xdb2401e1}},	//   bcel, रगी_, tesb, _ìpèt, 
   {{0x290889fe,0xd1851535,0x6e9402bf,0xa3a80cf1}},	//   ysaa_, _плей, тиму, _गुट_, 
   {{0x2004af4f,0x4170015e,0x00000000,0x00000000}},	//   bali_, _ماوس, --, --, 
   {{0x20062376,0x6e3e2377,0x2174059f,0xb80800fe}},	//   cali_, sesb, _шухр, ৰ্তত_, 
   {{0xa2c44668,0x0ac4020f,0x4abc0073,0x6aa000e5}},	//   ागच्, ещам, ्षलव, élfo, 
   {{0x66e40006,0x290a2378,0xc98455c3,0x6e3c0455}},	//   _dėkl, tsaa_, нузи, qesb, 
   {{0x38b404f3,0x61fc041e,0x29080a55,0x49b802e9}},	// [3edb0] värr_, ðsli, usaa_, سارد_, 
   {{0x2908b7a8,0x61e83a52,0x9f4c067c,0x6b74024c}},	//   rsaa_, zcel, énça_, _алоу, 
   {{0x290a2379,0x61e84159,0x6a14084c,0xe75825ef}},	//   ssaa_, ycel, _имну, بلاغ_, 
   {{0x2004d735,0x61e8011f,0x947002f2,0x290801f4}},	//   zali_, xcel, یگلا, psaa_, 
   {{0x2006237a,0x61e8010a,0x2908022f,0x9f440129}},	//   yali_, vcel, qsaa_, rclé_, 
   {{0x200417bb,0x9f4406af,0xe3b8b2bd,0xc87c002f}},	//   xali_, sclé_, мбл_, _buße_, 
   {{0xd46400a7,0x61ea237b,0x38b4007c,0x03a40022}},	//   тище_, tcel, pärr_, хәаҩ_, 
   {{0x2006237c,0x2a6a237d,0x20fc00e8,0x00000000}},	//   wali_, njab_, tňi_, --, 
   {{0x61e86a3a,0xe8d8063f,0xa0a4004e,0x00000000}},	//   rcel, azụ_, каид, --, 
   {{0x61ea237e,0x20040607,0x2056237f,0xe3740022}},	//   scel, uali_, ттир, _илзы, 
   {{0xf4862380,0x00000000,0x00000000,0x00000000}},	//   _сутн, --, --, --, 
   {{0x1d08004e,0x00000000,0x00000000,0x00000000}},	//   меми_, --, --, --, 
   {{0xe0462381,0x66e40006,0x2a68e815,0xd83c00d0}},	//   _анли, _sėkl, djab_, áčke_, 
   {{0x20062382,0x224e2383,0x212c0429,0xe1f80024}},	//   qali_, ldek_, mteh_, lbų_, 
   {{0x2b144d15,0x212c0548,0x6a700fac,0xd83c0219}},	//   льтр, lteh_, _råfr, ščke_, 
   {{0x224d397e,0x6a70318c,0x5d8400c6,0xd1cc001f}},	//   ndek_, _såfr, _للبل, _ጥልቅ_, 
   {{0xdea004fb,0x212e2384,0x224c005a,0x09e00fc0}},	// [3edc0] _میگی, nteh_, idek_, роун, 
   {{0x224c022e,0x888028f6,0x00000000,0x00000000}},	//   hdek_, алуж, --, --, 
   {{0x2a6802fa,0x212c003e,0xdce40024,0x224ce7f1}},	//   bjab_, hteh_, vykę, kdek_, 
   {{0x63ac0bcc,0x212e2385,0x5f180b67,0x224c07f7}},	//   ğanl, kteh_, _भिन्_, jdek_, 
   {{0x63ac36b5,0x224c0429,0x5f0000dc,0xe020000d}},	//   şanl, ddek_, वीत्_, _मांद_, 
   {{0xb4cc5096,0x0fa0012c,0x44b002d5,0x224d8fbd}},	//   रगे_, _ओखलढ, абіс, edek_, 
   {{0xf7c801ec,0x00000000,0x00000000,0x00000000}},	//   _ﺩﺍﻣﻪ, --, --, --, 
   {{0xc7a22386,0x225c010a,0x224ce8eb,0x212c011f}},	//   _тиск, _cnwk_, gdek_, fteh_, 
   {{0xd43401b9,0x212c0429,0x636801c6,0x56940150}},	//   _لعاب, gteh_, дрөг_, _заңт, 
   {{0x224ca663,0xe61801f0,0x00000000,0x00000000}},	//   adek_, _одӣ_, --, --, 
   {{0x03a00fc0,0xd2442f23,0x224c022e,0x00000000}},	//   _кифо, _аэли, bdek_, --, 
   {{0xc7b006a9,0x212c0548,0xddd4012c,0x8e7001d5}},	//   יבת_, bteh_, _slyš, рқиш, 
   {{0xddd5e889,0xc2780375,0xbd880014,0x00000000}},	//   _plyš, _קרדי, ہنێن_, --, 
   {{0x66e402d5,0x2ca40037,0x00000000,0x00000000}},	//   _sėkm, õld_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfc300014,0x00000000,0x00000000,0x00000000}},	//   ٝحہ_, --, --, --, 
   {{0xd0480213,0xe8580107,0x2a68daa4,0xfeb80244}},	// [3edd0] _sifə, нааш_, rjab_, _جاوت_, 
   {{0x224e2387,0x09c002ab,0xa2c84244,0x4ac0448b}},	//   zdek_, _शरीय, _हीन्, _वीरव, 
   {{0xe1f80006,0x0ba80131,0xaa940408,0x66e40153}},	//   ybų_, _زادى_, _бинч, _tėkm, 
   {{0xf7722388,0x212c102c,0x8a180014,0xf99001d3}},	//   غال_, yteh_, _کتھس_, حبہ_, 
   {{0xa824f6ac,0xc0f4044e,0x25aa2389,0xc986238a}},	//   _مکان, _ፈጻሚ_, çal_, _руни, 
   {{0x25a8003d,0x63ac0259,0x7d7c011a,0x00000000}},	//   ħal_, şanm, ונדו, --, 
   {{0x224c0e29,0x212c011f,0xd24c004b,0x00000000}},	//   tdek_, wteh_, ړني_, --, 
   {{0x23680bb8,0x212c102c,0x224cfbff,0x6d580003}},	//   ćaj_, tteh_, udek_, _ġwan, 
   {{0x224e238b,0xe1f80006,0x00000000,0x00000000}},	//   rdek_, rbų_, --, --, 
   {{0x212dffda,0x442001bf,0x224ca19a,0x00000000}},	//   rteh_, _øj_, sdek_, --, 
   {{0xa2f6238c,0x212c0427,0x555001d9,0x224c00df}},	//   _спеч, steh_, _پھۆر, pdek_, 
   {{0xf38c008f,0x212c003e,0x2eb40276,0x224c01a9}},	//   _קראָ, pteh_, исяс, qdek_, 
   {{0x61fc09cc,0x212c0548,0xd24c14d1,0xeda401c6}},	//   ðslu, qteh_, _رنو_, ашёо, 
   {{0x27ec0139,0x7094014b,0x00000000,0x00000000}},	//   _şenn_, _качф, --, --, 
   {{0x9cc8cbf3,0x00000000,0x00000000,0x00000000}},	//   дыңа_, --, --, --, 
   {{0xd9442571,0x00000000,0x00000000,0x00000000}},	//   леби, --, --, --, 
   {{0x48fc0243,0xc4c0012d,0x19c52515,0x00000000}},	// [3ede0] शीलो_, षताओ, убам, --, 
   {{0x65780175,0x00000000,0x00000000,0x00000000}},	//   dywh, --, --, --, 
   {{0x9aa42303,0x93e401a9,0x00000000,0x00000000}},	//   _ممدو, қўлл, --, --, 
   {{0x95c9bdc3,0xa3c82d2c,0x5ea400cc,0x00000000}},	//   нула_, ोधन_, _গীতে, --, 
   {{0x5974040e,0xc0c81954,0x00000000,0x00000000}},	//   _сыну, _በሪሁ_, --, --, 
   {{0x2874013d,0x00000000,0x00000000,0x00000000}},	//   _кыср, --, --, --, 
   {{0xc87c0356,0x00000000,0x00000000,0x00000000}},	//   ăşte_, --, --, --, 
   {{0x18a4085a,0x5884035b,0xb2742f16,0x6578127b}},	//   _раҳм, _рыҭа, рлиш, bywh, 
   {{0x704400d1,0x4cd800eb,0x00000000,0x00000000}},	//   ۇرگە, _ভবঘু, --, --, 
   {{0x437000ec,0x00000000,0x00000000,0x00000000}},	//   _گهمر, --, --, --, 
   {{0x2fd801e6,0x00000000,0x00000000,0x00000000}},	//   ärg_, --, --, --, 
   {{0x91e41c65,0x7ea803e0,0x877800df,0x00000000}},	//   _соде, tıpa, גאטי, --, 
   {{0x0ca84ea0,0x00000000,0x00000000,0x00000000}},	//   етви_, --, --, --, 
   {{0x4aa4000d,0xab0400b8,0x00000000,0x00000000}},	//   _गदहव, chṛṇ, --, --, 
   {{0x80a001e2,0x00000000,0x00000000,0x00000000}},	//   _دمون, --, --, --, 
   {{0x6e940214,0x8ec003e6,0x00000000,0x00000000}},	//   _خلبا, _دڵخۆ, --, --, 
   {{0xeb980209,0x00000000,0x00000000,0x00000000}},	// [3edf0] хиң_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x82880241,0x00000000,0x00000000,0x00000000}},	//   _látọ, --, --, --, 
   {{0x44f8009e,0x00000000,0x00000000,0x00000000}},	//   ুংসক_, --, --, --, 
   {{0x99300014,0x00000000,0x00000000,0x00000000}},	//   _وہِت, --, --, --, 
   {{0x1cb00867,0x4b64001f,0x657a238d,0x66e40064}},	//   ྐོར_, _ሲሚንቶ_, rywh, _lėki, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xbb3c0a1e,0x1ae000eb,0x00000000,0x00000000}},	//   געהי, গীকে_, --, --, 
   {{0xe7d001ad,0x4425b516,0x00000000,0x00000000}},	//   थेरप, _مراف, --, --, 
   {{0xdfe802a9,0x00000000,0x00000000,0x00000000}},	//   ъдод_, --, --, --, 
   {{0xf3e401d9,0xb35404d3,0x1cb0025c,0x44e800b5}},	//   _آمُ, _هیوا_, ྐོལ_, _hø_, 
   {{0x3afc01e1,0x1cbc0327,0x00000000,0x00000000}},	//   _làpò_, _ཇེང_, --, --, 
   {{0x66e40024,0x44240162,0x628801e7,0xf19400d4}},	//   _dėki, ogn_, mheo, _лиць, 
   {{0x4426238e,0xdef402d3,0xa06807b5,0x62880165}},	//   ngn_, _ገዛኢ_, _јака_, lheo, 
   {{0x44e82b96,0x26cc0076,0x5a96238f,0x998c012d}},	//   _lø_, _oheo_, араф, łoży_, 
   {{0x25ac005a,0x442404cc,0x6f1c25e6,0x26cde612}},	//   _oxel_, hgn_, árce, _nheo_, 
   {{0x3afc01e1,0x44e8005c,0x89d490b2,0xdca4119e}},	// [3ee00] _bàpò_, _nø_, لوفر_, _вапи, 
   {{0x26cc0069,0x9754026a,0x7d062390,0x97c62391}},	//   _aheo_, итељ, _iwis, айзе, 
   {{0x3afc01e1,0x25ac8f85,0x26cc952b,0xdef40240}},	//   _dàpò_, _axel_, _bheo_, _ገዛኣ_, 
   {{0x7d04c42c,0x26ce2392,0x44ea2393,0x24840165}},	//   _kwis, _cheo_, _bø_, _allm_, 
   {{0xdef4044e,0x7d062394,0xe80005f9,0x628800ae}},	//   _ገዛእ_, _jwis, _लड़का_, dheo, 
   {{0x7d062395,0xd7f00597,0x44e84e9b,0x00000000}},	//   _mwis, _ذكر_, _dø_, --, 
   {{0xff44dff7,0x628a2396,0x7d062397,0x07a21746}},	//   _بخ_, fheo, _lwis, _дарн, 
   {{0x628a2398,0x7d0401e2,0x442405d5,0x44e8f5b8}},	//   gheo, _owis, agn_, _fø_, 
   {{0x50640953,0x7d0402b9,0x4424007f,0x44e8005c}},	//   атна, _nwis, bgn_, _gø_, 
   {{0x213c0c67,0xb6100150,0x00000000,0x00000000}},	//   _dpwh_, _ﺴﻨ_, --, --, 
   {{0x7d062399,0x3dc00227,0x8eb03ee0,0x6288007b}},	//   _awis, _ayiw_, يەتت, bheo, 
   {{0x7d06239a,0xefcc03ee,0x62882f7f,0x60c001e7}},	//   _bwis, _ışığ, cheo, allm, 
   {{0x7d040042,0x10a416a4,0x6264004b,0x14c80073}},	//   _cwis, _кидн, _دالق, ितपण, 
   {{0x7d040042,0x7ea82258,0x61fc0205,0x00000000}},	//   _dwis, lıpl, ısle, --, 
   {{0x7d040857,0x7f900fc0,0x3afc01e1,0x47a800cc}},	//   _ewis, _машх, _ràpò_, _কৰনী, 
   {{0x7d060e22,0xfe72239b,0x3fd8011a,0xc95801a9}},	//   _fwis, _يدي_, _בקוב, кўз_, 
   {{0x6e2e239c,0x7d048ddb,0x44241967,0xa814d43a}},	// [3ee10] _icab, _gwis, ygn_, йдаш, 
   {{0x6d4c8928,0x26240084,0xf7702a60,0x26ce239d}},	//   _isaa, _ḓo_, ژان_, _sheo_, 
   {{0x7d06239e,0x26cdac7f,0x44e862ad,0xac9801ed}},	//   _zwis, _pheo_, _sø_, _لنکا_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d580100,0x4424004e,0xa6c40150,0xff340092}},	//   _šwaj, tgn_, _ۇقسى, _እያስመ, 
   {{0x6d4c00b2,0xa88411dc,0x26cc02b5,0x628802b5}},	//   _msaa, _السى, _wheo_, wheo, 
   {{0x26cc01dc,0xe29821b7,0x628a239f,0x442623a0}},	//   _theo_, лак_, theo, rgn_, 
   {{0x6d4e23a1,0xe50806f6,0x6e2c020c,0x3ad800b0}},	//   _osaa, _ميرو_, _ncab, _pōpi_, 
   {{0x660a23a2,0x6d4c0337,0x68ee23a3,0x6288340f}},	//   _ieek, _nsaa, nqad, rheo, 
   {{0x21a456ff,0x34940224,0x7d046478,0x660a23a4}},	//   _қилм, _даур, _rwis, _heek, 
   {{0x7d0623a5,0x6d4e23a6,0x660a23a7,0x628a23a8}},	//   _swis, _asaa, _keek, pheo, 
   {{0x7d0445b4,0x3ad800b0,0x6608000d,0x00000000}},	//   _pwis, _tōpi_, _jeek, --, 
   {{0x660a23a9,0x6298019f,0xdb1c01c7,0xa074008e}},	//   _meek, _imwo, _typë, _гыйш, 
   {{0x660a23aa,0x6e2c0107,0x6d4c01c7,0xdb1c0165}},	//   _leek, _ecab, _dsaa, _hypé, 
   {{0x8fa049f3,0x9ef40597,0x6d4c20fc,0x1a6623ab}},	//   _наше, _استش, _esaa, میدی_, 
   {{0x4f1430fb,0x660a23ac,0x6e2e23ad,0x7d0623ae}},	//   _פֿון_, _neek, _gcab, _twis, 
   {{0x7d04b70a,0x7e6623af,0x62980083,0x00000000}},	// [3ee20] _uwis, _inip, _mmwo, --, 
   {{0x5b340276,0x7e6402d2,0x9c2400c0,0x9d5401f0}},	//   _лэму, _hnip, _удод, _кӯҳӣ_, 
   {{0x7e6623b0,0x66080a4d,0x62982f99,0x7ea862c7}},	//   _knip, _beek, _omwo, yıpl, 
   {{0x6b8017c1,0x660804ba,0x690801a8,0x6d4c003a}},	//   ølge, _ceek, úsdó, _ysaa, 
   {{0x66080bfa,0x7e64009f,0x47a80154,0xaa4801ee}},	//   _deek, _mnip, _করণী, _тояҡ_, 
   {{0x62994a5f,0xaae415b4,0x00000000,0x00000000}},	//   _amwo, _دسیو, --, --, 
   {{0x7e640605,0x660a23b1,0x2a780241,0x00000000}},	//   _onip, _feek, _àgbé_, --, 
   {{0x7e640605,0x48fc012c,0x00000000,0x00000000}},	//   _nnip, शीको_, --, --, 
   {{0x66e40153,0x614415bf,0x00000000,0x00000000}},	//   _dėku, قىيە, --, --, 
   {{0x7e6623b2,0xf48459c7,0x6e2e23b3,0x660a23b4}},	//   _anip, _باری, _scab, _zeek, 
   {{0x6d4c2f99,0x66082252,0x8fd0008e,0x00000000}},	//   _ssaa, _yeek, чәдә, --, 
   {{0x3ad800b0,0x7afc09a8,0xce680fc0,0x63e0247f}},	//   _kōpu_, dprt, урод_, _تۋىل, 
   {{0x7e649950,0x00000000,0x00000000,0x00000000}},	//   _dnip, --, --, --, 
   {{0x7e640248,0x00000000,0x00000000,0x00000000}},	//   _enip, --, --, --, 
   {{0x7b640c75,0x6d4c0009,0x6e940214,0x00000000}},	//   птте, _wsaa, _ولتا, --, 
   {{0x6d4e23b5,0x6e2c5c2e,0xbea4147e,0x7e640055}},	//   _tsaa, _ucab, _најк, _gnip, 
   {{0x660a23b6,0x66e40006,0x6d4e23b7,0xac94023b}},	// [3ee30] _reek, _lėkt, _usaa, _маиш, 
   {{0x68ec01d9,0x672406ea,0x66082517,0x47886779}},	//   rqad, tuhj, _seek, лсем_, 
   {{0x660a23b8,0xd12416cb,0x68ec022e,0xa2ac00cd}},	//   _peek, _ڪم_, sqad, ुकम्, 
   {{0x67240ac5,0xaa580063,0xd5ac0050,0xe9800354}},	//   ruhj, _тиму_, چہِ_, _жамi_, 
   {{0xd125f938,0x660800af,0x240a23b9,0xd5ac0d62}},	//   _تم_, _veek, анли_, نہِ_, 
   {{0x660a23ba,0x1cbc0135,0x75440024,0x47a800cc}},	//   _week, _ཇེབ_, яніз, _কৰণী, 
   {{0x660a23bb,0xe8c4466d,0x19d000d1,0x940c03b9}},	//   _teek, वतीच, ﻛﯩﻠﻠ, nifə_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc42856b0,0x940c0cc1,0x5ba41fad,0x7e640129}},	//   _مثال_, hifə_, _ऐश्व, _rnip, 
   {{0x600a23bc,0x00000000,0x00000000,0x00000000}},	//   шном_, --, --, --, 
   {{0xd24c9b57,0x66d0c424,0x35440014,0xdc800023}},	//   رنی_, råkf, _ونہٲ, _ሓሙሻይ_, 
   {{0x62980230,0x3f88033f,0x3f800135,0x00000000}},	//   _umwo, ącu_, ġju_, --, 
   {{0xa0680408,0x3f8024dd,0x86380092,0xe10801ee}},	//   _вала_, šju_, _በኮንስ, _телд_, 
   {{0x2b40007f,0x63ac0356,0x00000000,0x00000000}},	//   _bphc_, şanu, --, --, 
   {{0xda64082e,0x5f2801c0,0x8eb00451,0x3fd400cc}},	//   ياري, _тойм_, _ڪميش, _দ্ৰষ, 
   {{0x7e6623bd,0x66e400c0,0x00000000,0x00000000}},	//   _unip, _lėks, --, --, 
   {{0xdc740153,0x00000000,0x00000000,0x00000000}},	// [3ee40] _дынь, --, --, --, 
   {{0x3ad802b1,0x00000000,0x00000000,0x00000000}},	//   _rōpu_, --, --, --, 
   {{0xefd00023,0x8c2400fe,0x00000000,0x00000000}},	//   _ጥርዚ_, য়খন_, --, --, 
   {{0xa2c801ad,0x66e40064,0x46a02bb6,0x00000000}},	//   _हील्, _rėkt, махв, --, 
   {{0xb8081c82,0x00000000,0x00000000,0x00000000}},	//   ৰ্গত_, --, --, --, 
   {{0x9410016b,0x00000000,0x00000000,0x00000000}},	//   ɑyɛ_, --, --, --, 
   {{0x1cbc025c,0xdec80023,0x13680a5b,0x0440033a}},	//   _ཇེན_, በሎን_, ршли_, фејн, 
   {{0xd13a23be,0x3878030a,0x00000000,0x00000000}},	//   ахо_, _horr_, --, --, 
   {{0x387a23bf,0xdce800bc,0x940c0213,0x54680798}},	//   _korr_, čněj, zifə_, _каам_, 
   {{0x387a23c0,0x61fc00fd,0x8fe001e0,0xfbc0043e}},	//   _jorr_, ısla, мәйҙ, _शुभम, 
   {{0x387a23c1,0x5fd4012c,0x2ef87ad0,0xeeb8004e}},	//   _morr_, डेलल, ërf_, йлош_, 
   {{0x51840075,0x3878002e,0xa3c89543,0x66d0a075}},	//   _мула, _lorr_, ोधर_, råkg, 
   {{0x61a40714,0x0dc8cb32,0x63aceab4,0x387801ab}},	//   खपृष, руни_, şant, _oorr_, 
   {{0x387801e6,0x6ab400dc,0xefd00023,0x00000000}},	//   _norr_, ूत्र, _ጥርዙ_, --, 
   {{0xead4030d,0x60dc067c,0xef6401c6,0xe0480472}},	//   зовь, ïsme, _хэлү, _دشنه_, 
   {{0x940c0213,0xbea4013d,0x00000000,0x00000000}},	//   rifə_, _ошый, --, --, 
   {{0x387a23c2,0x66d001e3,0x00000000,0x00000000}},	// [3ee50] _borr_, nåke, --, --, 
   {{0x387a23c3,0xdd914fe4,0x0ae84f4e,0x00000000}},	//   _corr_, _سوپ_, _پردي_, --, 
   {{0x38780804,0x8a74013e,0xba480055,0x66e40064}},	//   _dorr_, _динӣ_, _spįų, _rėks, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x79583e1f,0xe3e803c7,0x00000000,0x00000000}},	//   _дияр_, مکان_, --, --, 
   {{0x3878030a,0x66d0007c,0x02d01b61,0x00000000}},	//   _gorr_, dåke, दग्न, --, 
   {{0x46680064,0x67d401a9,0x00000000,0x00000000}},	//   _крам_, _хову, --, --, 
   {{0x38780200,0x273401e3,0xaad0000d,0x00000000}},	//   _zorr_, mån_, _थीमक, --, 
   {{0x66d0dac1,0x387800e8,0x00000000,0x00000000}},	//   råkd, _yorr_, --, --, 
   {{0x63ac0112,0x00000000,0x00000000,0x00000000}},	//   ßans, --, --, --, 
   {{0x2734007c,0x00000000,0x00000000,0x00000000}},	//   nån_, --, --, --, 
   {{0xefc801c0,0x5de4009d,0x00000000,0x00000000}},	//   өлөл_, яжма, --, --, 
   {{0x81a46e9a,0x0d8223c4,0x273623c5,0x9f040345}},	//   _بحال, елян, hån_, _کوبو, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfe7805f5,0x3d182017,0x00000000,0x00000000}},	//   _дүн_, _भटके_, --, --, 
   {{0x1cb00135,0x2a7803cb,0x1cbc0327,0x6b80a98d}},	//   ྐོང_, _cosb_, _ཇེམ_, ølga, 
   {{0x38780267,0x6bd40131,0x291c0784,0x2a78002f}},	// [3ee60] _porr_, كتېر, šwan_, _dosb_, 
   {{0x3878036e,0x00000000,0x00000000,0x00000000}},	//   _qorr_, --, --, --, 
   {{0x2a78007f,0x38780200,0xda64022e,0x00000000}},	//   _fosb_, _vorr_, _евни, --, 
   {{0x3878002e,0x2a7803cb,0x6444000d,0x00000000}},	//   _worr_, _gosb_, õhin, --, 
   {{0x387a23c6,0xe4f400f1,0xc4d402dd,0x00000000}},	//   _torr_, وغوښ, _ﺘﺎﺒﻌ, --, 
   {{0xbb64037e,0x66d003cd,0x00000000,0x00000000}},	//   _impカ_, våke, --, --, 
   {{0x35d000e1,0x98b002e2,0x8c180677,0x00000000}},	//   तेज़, ntyč_, צוקי, --, 
   {{0x4380007b,0x66d003cd,0xd1d0069d,0x00000000}},	//   عليق, tåke, ከላቱ_, --, 
   {{0xccf8016b,0x764002d0,0x00000000,0x00000000}},	//   ɛɛwa_, _ibmy, --, --, 
   {{0x66d0df7a,0x040c0154,0x2ef401a9,0x00000000}},	//   råke, _সাথী_, мзор, --, 
   {{0x11e4330e,0xc3f8011a,0x66d0e752,0xa3c800cd}},	//   _ежем, _הלבש, såke, ोधः_, 
   {{0xb80800fe,0x61400022,0x00000000,0x00000000}},	//   ৰ্চত_, хҵәа, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x51840075,0x0dc801b9,0x62200228,0x0ca801d5}},	//   _муһа, _қуйи_, _كۉۉل, стми_, 
   {{0xf07801af,0x76400210,0x00000000,0x00000000}},	//   _гиҙә_, _obmy, --, --, 
   {{0x273401e6,0x00000000,0x00000000,0x00000000}},	//   vån_, --, --, --, 
   {{0x2ec800dc,0x19c00075,0xacb40063,0x00000000}},	// [3ee70] रतीत, вәрг, _обиљ, --, 
   {{0x3b980020,0x6e3e23c7,0x79f405f5,0x2734007c}},	//   ሙያዎች_, lfsb, _үзэх, tån_, 
   {{0x6d5ca76f,0x3cf8072d,0x00000000,0x00000000}},	//   lvsa, _وعید_, --, --, 
   {{0x273404f3,0xdb240133,0xaa5c01ec,0xfa940092}},	//   rån_, _کوێی, _темi, _መፈክር_, 
   {{0xdaa00150,0x6aac89b5,0x6d5c02d0,0x2734007c}},	//   _شەكپ, mnaf, nvsa, sån_, 
   {{0x273401e3,0xd464009b,0x64a4b32d,0x34840150}},	//   pån_, дише_, ьала, нгіг, 
   {{0xe299149e,0x6d58006a,0xc4700184,0x66d02a0e}},	//   жай_, _âwaf, _үҫеш, råkb, 
   {{0x6aae23c8,0x6e3c0d27,0xd7640271,0x88a00345}},	//   nnaf, jfsb, _تنفی, _تیڕۆ, 
   {{0xd12e23c9,0x6aad9fa5,0x00000000,0x00000000}},	//   لمي_, inaf, --, --, 
   {{0x291806a3,0x6e3c035a,0xd12c00f2,0x9f8400d4}},	//   _mvsa_, efsb, گمی_, дгод, 
   {{0x6e3e0168,0x6aacdb6f,0xc2ea23ca,0xf7c801ec}},	//   ffsb, knaf, _طعام_, _ﺩﺍﻟﻪ, 
   {{0xd12c5d28,0xaf99698b,0x6aac01f5,0x68fc03ac}},	//   دمی_, ятых_, jnaf, _otsd, 
   {{0xdb1c0122,0x6aac5037,0xaf340345,0xd7280092}},	//   _vypí, dnaf, وویژ, _ዳውንሎ, 
   {{0x9f042043,0x6e3c0036,0x6aad13ee,0xa06800d8}},	//   _قوتو, afsb, enaf, _фака_, 
   {{0x6441860a,0x200623cb,0x1eb41b74,0x68fc02d0}},	//   _mbli, mbli_, _осиё, _atsd, 
   {{0x6aae23cc,0x64400175,0xd1280023,0x22a400de}},	//   gnaf, _lbli, _ተቐበል, pēku_, 
   {{0x3ea223cd,0xceb000d9,0x00000000,0x00000000}},	// [3ee80] _imit_, _שיח_, --, --, 
   {{0x6aac0109,0xddc402b5,0x81cc009e,0x00000000}},	//   anaf, nekō, _শলা_, --, 
   {{0xd708005e,0x20040afe,0xe93800d1,0x00000000}},	//   інде_, ibli_, قسەت_, --, 
   {{0x644223ce,0x764044a1,0xe7080014,0x00000000}},	//   _abli, _qbmy, ستمن_, --, 
   {{0xb6c80583,0x644001ab,0x3ea00194,0xe81800d1}},	//   _ہارے_, _bbli, _mmit_, ززەت_, 
   {{0x741623cf,0xb4c8012c,0x35c40107,0x00000000}},	//   روبا, ईते_, _ҷабҳ, --, 
   {{0x3ea223d0,0x6e3c017a,0x00000000,0x00000000}},	//   _omit_, yfsb, --, --, 
   {{0x6d58006a,0x64421a38,0x02a008e2,0x35c40117}},	//   _âwag, _ebli, крым, _забҳ, 
   {{0x3e3c0092,0x64400051,0x1048022e,0x00000000}},	//   ያጠናክ, _fbli, ояни_, --, 
   {{0x3ea0066d,0xd12802d3,0x61f80142,0xef9808da}},	//   _amit_, _ተቐቢል, _efwl, зкош_, 
   {{0x93445566,0x201400aa,0x61f80042,0x42cc03d4}},	//   _інде, رښود_, _ffwl, ৰৱেশ, 
   {{0x64416df8,0xd1840104,0xb640037e,0x6d5dade9}},	//   _zbli, _олей, _ｃｇ_, tvsa, 
   {{0x20041f21,0xc0c8044e,0x6aae23d1,0xa2ac078a}},	//   bbli_, በሮም_, vnaf, ुकर्, 
   {{0x3ea223d2,0x6d5c392f,0x79840433,0x6e3c022e}},	//   _emit_, rvsa, dyiw, sfsb, 
   {{0xd12802d3,0x4f9409a5,0x3ea00200,0x8ae400d4}},	//   _ተቐባል, _юрду, _fmit_, діал, 
   {{0x3ea00332,0x49740092,0xe8f80f06,0x00000000}},	//   _gmit_, _አመርቂ_, знач_, --, 
   {{0xa98400db,0x00000000,0x00000000,0x00000000}},	// [3ee90] رۅسۅ_, --, --, --, 
   {{0x21200073,0x66d001e3,0xdce40064,0x0134011a}},	//   _मिसळ_, dåka, dykė, ורמת_, 
   {{0x22900022,0x67d41064,0x79840083,0x64440037}},	//   _háke_, хожу, ayiw, õhim, 
   {{0x2918b0e8,0xfd540055,0x6724007c,0x6440ae7e}},	//   _tvsa_, _aheṣ, rrhj, _sbli, 
   {{0xd1243669,0xa5080640,0x229000e4,0xfd5400cd}},	//   _حم_, чела_, _jáke_, _bheṣ, 
   {{0x229000d2,0xfd54002b,0xc68c0014,0x7ea808a9}},	//   _máke_, _cheṣ, دِچ_, lıpt, 
   {{0xa3d802ab,0xa52c0051,0x00000000,0x00000000}},	//   ठें_, _đểđạ, --, --, 
   {{0xd24e23d3,0xe2b405f5,0x545000d1,0x7ea80205}},	//   منى_, эслэ, ввәт, nıpt, 
   {{0x5914003d,0xddc400b0,0x3ea223d4,0x2004022e}},	//   ྲེགས_, tekō, _rmit_, tbli_, 
   {{0x644223d5,0x24982d4b,0x41d8033f,0x35b401ee}},	//   _ubli, _عناد_, मेषस, _рбур, 
   {{0x200623d6,0xddc402b5,0xfe7801c6,0x7ea80205}},	//   rbli_, rekō, дүй_, kıpt, 
   {{0xdd1c084c,0x79840de2,0x2ee801ef,0x35a40210}},	//   _câşt, yyiw, _ciaf_, _खेड़, 
   {{0x5fd07aa4,0x224cf019,0x216a23d7,0xa3c81b76}},	//   _हरवल, meek_, _хили_, ोधक_, 
   {{0x224e23d8,0x62880ac8,0x98b00882,0x2be000dc}},	//   leek_, lkeo, ktyā_, _गृहं_, 
   {{0xcb6544d4,0x2ee80421,0x60c00477,0x2f5401ec}},	//   наре_, _fiaf_, molm, _атыс, 
   {{0x60c09169,0x224e23d9,0x7984004b,0x62880fac}},	//   lolm, neek_, tyiw, nkeo, 
   {{0x628800cc,0x1cb00327,0x00000000,0x00000000}},	// [3eea0] ikeo, ྐོད_, --, --, 
   {{0x224c0196,0x7794331c,0x79840175,0xdce40153}},	//   heek_, پیرا, ryiw, vykė, 
   {{0x5914025c,0x224c0548,0x628812ed,0x4c80084c}},	//   ྲེངས_, keek_, kkeo, _слэв, 
   {{0x60c0fa72,0x798402c4,0x224c1bce,0x6b808504}},	//   holm, pyiw, jeek_, älge, 
   {{0x224e23da,0x60c01057,0xdbc800c5,0x88c40118}},	//   deek_, kolm, rõõm, _směš, 
   {{0x66d007b9,0xd3781887,0xe7080137,0x00000000}},	//   råka, зчи_, ستۅن_, --, 
   {{0x60c00502,0xcc38010f,0x66d001e3,0x02c81546}},	//   dolm, פעקט, måkn, ातून, 
   {{0x224db2e6,0x00000000,0x00000000,0x00000000}},	//   geek_, --, --, --, 
   {{0x60c00076,0x0680010b,0x00000000,0x00000000}},	//   folm, _ёгун, --, --, 
   {{0x8934008f,0x2ee800d7,0x2ec809fa,0x00000000}},	//   עריע_, _siaf_, रत्त, --, 
   {{0x6e9408e0,0x224cd710,0x1cb0025c,0x227800ec}},	//   вину, beek_, ྐོན_, _ڪلنگ_, 
   {{0x308402d3,0xc0c80092,0x00000000,0x00000000}},	//   _ዝወጽእ_, _ባዛር_, --, --, 
   {{0x60c0011c,0x2250012c,0x2ee8068c,0x1e701ac1}},	//   bolm, ánků_, _viaf_, рғыс, 
   {{0x60c223db,0x6da400c7,0xfaa401a9,0x00000000}},	//   colm, еиҭа, ҳшун, --, 
   {{0xc87c0e78,0x66d00267,0x7f80007b,0x00000000}},	//   _mußt_, dåkn, _ملون, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb1c02fb,0xe858013e,0x64440022,0x00000000}},	// [3eeb0] _vypá, мааш_, õhik, --, 
   {{0x6af40107,0x224c01c4,0x383623dc,0xac9800ec}},	//   _изоф, zeek_, лнур, _آندا_, 
   {{0x6d58145e,0xbcf00115,0xdef40023,0x6f1c0332}},	//   _âwab, _isɩa, _ገዛና_, árch, 
   {{0x224e23dd,0x60c02681,0x29d401f7,0xf74800ae}},	//   xeek_, zolm, _ليجس, علني_, 
   {{0x7cd400a2,0x9624030d,0x60c001d5,0x00000000}},	//   _ańry, _гiош_, yolm, --, 
   {{0x224e23de,0xd90c040b,0x8a180014,0xa96800c7}},	//   week_, _گیے_, _بتھس_, _еиҭа_, 
   {{0x224e23df,0x60c223e0,0x212c0098,0x37e400db}},	//   teek_, volm, wueh_, _боёг, 
   {{0x7524041a,0xd90c00dd,0x224c0165,0x60c00100}},	//   šiza, _دیے_, ueek_, wolm, 
   {{0x224e23e1,0x6b8003d4,0x60c223e2,0x6288143a}},	//   reek_, ølgj, tolm, rkeo, 
   {{0x224e23e3,0xe7c44540,0x94700451,0x1f6400d8}},	//   seek_, _वडाप, _پگها, вком, 
   {{0x60c223e4,0x547800df,0x00000000,0x00000000}},	//   rolm, _קװענ, --, --, 
   {{0xdc080141,0x60c00958,0x00000000,0x00000000}},	//   वर्ड_, solm, --, --, 
   {{0x60c0358d,0xaca801d3,0x00000000,0x00000000}},	//   polm, کھيے_, --, --, 
   {{0xa0a623e5,0x1a6401b9,0x60c001a9,0xdea002f2}},	//   _шалд, چیدی_, qolm, _چیدی, 
   {{0x1a6401b9,0x5018011a,0x00000000,0x00000000}},	//   نیدی_, _חוצו, --, --, 
   {{0xc0c80023,0xd944072c,0x00000000,0x00000000}},	//   በዮም_, кеби, --, --, 
   {{0x66d001e3,0x76b400c7,0x00000000,0x00000000}},	// [3eec0] tåkn, ҳәац, --, --, 
   {{0xdb8400c7,0xf988004b,0x480000d8,0x00000000}},	//   _агои, ونځي_, ипув, --, 
   {{0x66d0fa6f,0x8c180a7c,0xf6643947,0x00000000}},	//   råkn, _קוטי, лежү, --, 
   {{0x68ec02d5,0x0f78010f,0x9585e36c,0x95c800f3}},	//   _žodž, ורעל, клее, мула_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe8e00051,0x85000244,0x00000000,0x00000000}},	//   _đệp_, جوون, --, --, 
   {{0xb7e00183,0x00000000,0x00000000,0x00000000}},	//   _প্ৰয়, --, --, --, 
   {{0x81c80729,0xcb100302,0x838223e6,0x656c0419}},	//   লধন_, בלה_, рыше, ťaha, 
   {{0xdb1c023a,0x427007ee,0x740401f0,0x00000000}},	//   _hypä, ргыс, _бозҷ, --, 
   {{0xdb1c023a,0x00000000,0x00000000,0x00000000}},	//   _kypä, --, --, --, 
   {{0x93580166,0x00000000,0x00000000,0x00000000}},	//   _юрау_, --, --, --, 
   {{0x42040022,0xa6e80051,0x42500228,0x00000000}},	//   _анцо_, _nhự, _ۅنۅر, --, 
   {{0x41c00014,0x7d54011c,0x00000000,0x00000000}},	//   _پٲوِ, авях, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe8d801f2,0x645c00a2,0x00000000,0x00000000}},	//   nyụ_, _öziň, --, --, 
   {{0x66d0007c,0x91c40118,0x00000000,0x00000000}},	//   våko, _लडाई, --, --, 
   {{0xdb1c0309,0x291c0264,0x49b80214,0xfbd001d3}},	// [3eed0] _aypä, éwa_, ذارد_, متہ_, 
   {{0x6b740276,0x281403c7,0x00000000,0x00000000}},	//   _блоу, اواس, --, --, 
   {{0x8b659b31,0x2290e9f0,0x00000000,0x00000000}},	//   _شادم, _láka_, --, --, 
   {{0x66d0dac1,0xac9801d3,0x05b800f2,0xfb6401ee}},	//   råko, _آنگا_, ودشت_, _тњьм, 
   {{0xf62400d4,0xc568114f,0x00000000,0x00000000}},	//   рдіо, بحال_, --, --, 
   {{0xe3581cc9,0x89880023,0x00000000,0x00000000}},	//   ешиш_, _ጥርናፈ_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3cf40349,0xd76400e5,0xe8e00051,0x3f8003b2}},	//   _অবস্_, _حنفی, _độp_, øjum_, 
   {{0xddc4033f,0x660c03b2,0x60e80139,0xca680092}},	//   zekł, ðaku, нмим_, _አገናኝ_, 
   {{0x20542e91,0x661802d1,0x00000000,0x00000000}},	//   утир, lawk, --, --, 
   {{0x7c3804f3,0x9ea8554f,0xf48400d8,0xb144009d}},	//   _övri, евна_, _тутн, гнөл, 
   {{0x66180309,0x09a00037,0x00000000,0x00000000}},	//   nawk, _ऐइंठ, --, --, 
   {{0x7c281ada,0x00000000,0x00000000,0x00000000}},	//   ódro, --, --, --, 
   {{0x661a23e7,0x225c2517,0x37d400cc,0x00000000}},	//   hawk, _hawk_, _তলসৰ, --, 
   {{0x09c8045e,0x46b00073,0x661a23e8,0x00000000}},	//   লেমা, ंचाह, kawk, --, 
   {{0xda6405d9,0xdb1c0108,0x66180210,0x6b80007c}},	//   داسي, _rypä, jawk, älga, 
   {{0x66d13f8e,0x225c0986,0x661835c2,0x00000000}},	// [3eee0] råkl, _mawk_, dawk, --, 
   {{0x7d0623e9,0x09c802f5,0x888013f3,0x00000000}},	//   _itis, লেভা, блуж, --, 
   {{0xe7f405f9,0xa6e8004d,0x5629b465,0x461000f1}},	//   ेड़ा_, _thự, ежем_, څومر, 
   {{0x7d040139,0x6618012d,0xdb1c00d7,0x00000000}},	//   _ktis, gawk, _vypä, --, 
   {{0x09c8015b,0xa6aa23ea,0xa9740114,0x00000000}},	//   লেবা, خالق_, _курј, --, 
   {{0x98a40cef,0x7d040099,0x39400006,0x229003b2}},	//   _сиге, _mtis, mtis_, _ráka_, 
   {{0x394223eb,0x66180034,0xd628011c,0x00000000}},	//   ltis_, bawk, _пове_, --, 
   {{0x6b8003a1,0x394223ec,0x22900518,0xc7a002e8}},	//   ølgi, otis_, _páka_, _уиск, 
   {{0x394223ed,0x225c038f,0x7d0401b2,0xd43402da}},	//   ntis_, _dawk_, _ntis, _معاب, 
   {{0x394223ee,0xc0540111,0x30142d7f,0x52b000db}},	//   itis_, гію_, шдор, _گەبئ, 
   {{0x394000af,0xed640024,0xd24401c4,0x00000000}},	//   htis_, _mažų_, _бэли, --, 
   {{0x394223ef,0x00000000,0x00000000,0x00000000}},	//   ktis_, --, --, --, 
   {{0x394000df,0x7d240229,0x906401af,0x00000000}},	//   jtis_, йфре, _бњйл, --, 
   {{0x2ca4c375,0xf41400df,0x00000000,0x00000000}},	//   òld_, יפֿ_, --, --, 
   {{0x7d04006c,0x394223f0,0x225c020c,0xaed460a7}},	//   _etis, etis_, _yawk_, _кокш, 
   {{0x7d0404ce,0x8ad40137,0x00000000,0x00000000}},	//   _ftis, اتسئ, --, --, 
   {{0x39400006,0x7dec00e2,0xa81623f1,0x63ac002f}},	// [3eef0] gtis_, _cēsī, идаш, ßanz, 
   {{0x6d4e23f2,0x66d0dac1,0x00000000,0x00000000}},	//   _ipaa, råkm, --, --, 
   {{0x394223f3,0xed640153,0x6618033f,0xbb4801d3}},	//   atis_, _dažų_, tawk, _یلین_, 
   {{0x6d4c083a,0xa9340220,0x39402456,0xe3e803e6}},	//   _kpaa, _кемш, btis_, ۆکان_, 
   {{0x39400de4,0xc98623f4,0x225c0113,0x661a23f5}},	//   ctis_, _суни, _rawk_, rawk, 
   {{0x638623f6,0x2908049b,0x6d4c9abb,0x656c01f1}},	//   игла, mpaa_, _mpaa, ťaho, 
   {{0xe29a23f7,0xe1f00597,0x290802f6,0x00000000}},	//   как_, يسة_, lpaa_, --, 
   {{0xe1240353,0x290801f4,0x349407a5,0x5344030d}},	//   амии, opaa_, _қахр, ăхла, 
   {{0x290a23f8,0xdbe0c853,0xc4443321,0xe4741d39}},	//   npaa_, _खण्ड_, _میشن_, _клањ, 
   {{0x656a23f9,0x66e400c0,0xe8e00208,0xe7b88004}},	//   _ireh, _rėky, _đớp_, _आशाप, 
   {{0x7d0623fa,0x00000000,0x00000000,0x00000000}},	//   _stis, --, --, --, 
   {{0x394223fb,0xc2e4036b,0x65685050,0x8ee40276}},	//   ytis_, _сўзи, _kreh, имэв_, 
   {{0xdafc0589,0x394223fc,0x9db88984,0x7d0406be}},	//   cãªn, xtis_, тыну_, _qtis, 
   {{0x7d04819f,0x6568009f,0x229001e1,0xdcb00131}},	//   _vtis, _mreh, _káko_, زىز_, 
   {{0x6d4e03c4,0x6d58006a,0x8fa0074d,0x22900241}},	//   _epaa, _âwan, _маше, _jáko_, 
   {{0x394223fd,0x7d04011c,0x656a23fe,0x8e18035b}},	//   ttis_, _ttis, _oreh, _ихьӡ_, 
   {{0x7d0623ff,0x22900241,0x3940a5e3,0x17ec00bc}},	// [3ef00] _utis, _láko_, utis_, जश्व_, 
   {{0x39412634,0xd8262400,0x6d400356,0x00000000}},	//   rtis_, рджи, ălat, --, 
   {{0x212c06a3,0x6568127b,0x290801e1,0x00000000}},	//   hreh_, _areh, apaa_, --, 
   {{0x39422401,0x55041789,0x656a2402,0xd62a2403}},	//   ptis_, ачка, _breh, тоде_, 
   {{0x3afc0208,0xe87400db,0x00000000,0x00000000}},	//   _híp_, _گەلب_, --, --, 
   {{0xd7047427,0x656a2404,0x7ae40641,0x3afc01fb}},	//   _نظري, _dreh, lmit, _kíp_, 
   {{0x5914081f,0x65680c8c,0x212c011f,0x9f8c0254}},	//   ྲེམས_, _ereh, ereh_, _kõõm_, 
   {{0x7ae62405,0x65686c77,0xb2740131,0x59b802ab}},	//   nmit, _freh, слиш, _इशार, 
   {{0x65686bc8,0x7ae62406,0x212c011f,0x3afc2b73}},	//   _greh, imit, greh_, _líp_, 
   {{0x7ae62407,0x6d4c0194,0x53a62408,0x00000000}},	//   hmit, _rpaa, _казб, --, 
   {{0x6d4e2409,0x7ae6240a,0xa03400db,0x00000000}},	//   _spaa, kmit, حىپت, --, 
   {{0x7ae6240b,0x212c013f,0x6d4c1418,0x656800e4}},	//   jmit, breh_, _ppaa, _yreh, 
   {{0x7ae6240c,0x6f08054e,0x91e4030d,0x00000000}},	//   dmit, spdc, _тоде, --, 
   {{0x7ae6240d,0xc0e02c68,0x0c9c0092,0x6f1c01d3}},	//   emit, _дочк, _ሃገሮች_, árcs, 
   {{0x8aa6240e,0x7ce03b7b,0x7ae4002f,0x7b6586f8}},	//   арад, körf, fmit, отте, 
   {{0x7ae45947,0xbea41b6b,0x66d01511,0x229002f0}},	//   gmit, _мајк, råkk, _nákl_, 
   {{0x98a0236c,0x7ce00b8b,0x6d4e240f,0x00000000}},	// [3ef10] _askı_, dörf, _upaa, --, 
   {{0x29080eda,0x7ae62410,0x47880408,0x6568036e}},	//   rpaa_, amit, ксем_, _rreh, 
   {{0x29080451,0x7ce0049f,0x7ae62411,0xe5f400db}},	//   spaa_, förf, bmit, مكاد, 
   {{0xd24474bb,0x656874f4,0x290a2412,0x7ae62413}},	//   _عن_, _preh, ppaa_, cmit, 
   {{0x6aac03d1,0x29080784,0xe29801e0,0x98a003e0}},	//   miaf, qpaa_, ҫал_, _eskı_, 
   {{0xd5ac007b,0x65680200,0x55500145,0xe3d401ec}},	//   عفو_, _vreh, سپىر, _ﺘﻭﺍﻓ, 
   {{0xe7e41c82,0x65680066,0x970000d1,0x00000000}},	//   _প্ৰয, _wreh, _فېلى, --, 
   {{0x6aae2414,0xfbb806a9,0x212c011f,0x6594119e}},	//   niaf, יפות_, treh_, _лабу, 
   {{0x656801f0,0x047404fb,0x0584010b,0x68680023}},	//   _ureh, _پلاک_, _тувм, _ሰማዕቲ_, 
   {{0x7ae4d082,0x6aacc5bf,0x212e0405,0x7ce001a8}},	//   zmit, hiaf, rreh_, mörg, 
   {{0x73c00184,0x68e401e7,0x7ae40937,0x1fa801a9}},	//   _оҡша, imhd, ymit, укни_, 
   {{0x1d081e8a,0x24841924,0x212c02d3,0x00000000}},	//   леми_, _holm_, preh_, --, 
   {{0x2484007d,0x26cc01c8,0x9f8c00c5,0x66d0d007}},	//   _kolm_, _mkeo_, _rõõm_, råkh, 
   {{0x40e00014,0x7ae40175,0x3afc02d2,0xd00401af}},	//   _بٲتہ, wmit, _píp_, _леше_, 
   {{0x6aae2415,0x7ae408a1,0xdee401f0,0x7ce0002f}},	//   fiaf, tmit, _локи, hörg, 
   {{0xbb64037e,0x6d400311,0x2f1800db,0x6aae2416}},	//   _cssで_, ălar, _ئىيگ_, giaf, 
   {{0xdca407d6,0x5da40c58,0x09e001a9,0x3cf401f9}},	// [3ef20] _гапи, _গুৰু, зотн, ंदळे_, 
   {{0x3afc004d,0x00000000,0x00000000,0x00000000}},	//   _típ_, --, --, --, 
   {{0x7ae40204,0x6aac478b,0xfaa40022,0x00000000}},	//   pmit, biaf, _ҳаҟо, --, 
   {{0x6aac01e4,0xf41403d4,0x7ce0007c,0xd9440835}},	//   ciaf, _ঠাইৰ_, förg, _леми, 
   {{0x94aa2417,0x68e401ab,0x9484010b,0xceb0011a}},	//   лтка_, bmhd, йыкд, היא_, 
   {{0x26cc06d9,0x24862418,0x00000000,0x00000000}},	//   _ekeo_, _colm_, --, --, 
   {{0x7ce001e3,0x91a800c5,0x00000000,0x00000000}},	//   mörd, _जइहै, --, --, 
   {{0x7ce0007c,0x00000000,0x00000000,0x00000000}},	//   lörd, --, --, --, 
   {{0x65b8023b,0x95980114,0x00000000,0x00000000}},	//   _куфр_, _ству_, --, --, 
   {{0x7ce01876,0x00000000,0x00000000,0x00000000}},	//   nörd, --, --, --, 
   {{0x9344084c,0x4878010f,0x3ef4009d,0xc20c003b}},	//   _ынже, אטיס, йнээ_, _нє_, 
   {{0x7ce17125,0xd138495c,0x20d80ba1,0xa3cc01f9}},	//   hörd, _бхк_, rèia_, _रडत_, 
   {{0x11d41411,0x7ce00267,0x5ea000db,0x00000000}},	//   _اتاد, körd, بۅيل, --, 
   {{0x6d58006a,0x20d8067c,0x66d010d1,0x6ae00b02}},	//   _âwam, pèia_, råki, पग्र, 
   {{0x6aacf7e5,0xe0480345,0x7ce0010b,0x00000000}},	//   tiaf, _خشنه_, dörd, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7ce22419,0xfe70007b,0xe97800b1,0x00000000}},	// [3ef30] förd, _أدى_, шбаш_, --, 
   {{0x20d801c7,0x00000000,0x00000000,0x00000000}},	//   hèin_, --, --, --, 
   {{0xa7140046,0x69c00034,0xadfc05f9,0xca700066}},	//   імді, _śled, _एलान_, _فندک, 
   {{0xf770036d,0x94c8004b,0xa5d4005b,0x00000000}},	//   عال_, یاوې_, ожеш, --, 
   {{0x7ce001e6,0xe944179e,0x00000000,0x00000000}},	//   börd, _برجی, --, --, 
   {{0x69dcad8e,0xd24c0014,0x00000000,0x00000000}},	//   _izse, ێچن_, --, --, 
   {{0x22481bce,0xd24c00d1,0x00000000,0x00000000}},	//   _ñakk_, چنى_, --, --, 
   {{0xd24c3955,0xcfcc03f4,0xe1f81f10,0xe50827e3}},	//   ننى_, রধান, шги_, _نيرو_, 
   {{0xdb1c0494,0x7ce03f41,0x2484000d,0x00000000}},	//   _expè, löre, _tolm_, --, 
   {{0x7bd806ea,0x00000000,0x00000000,0x00000000}},	//   _øvug, --, --, --, 
   {{0x7ce001e6,0xdee6241a,0x00000000,0x00000000}},	//   nöre, жони, --, --, 
   {{0x7af801ed,0x539808a8,0x00000000,0x00000000}},	//   _évti, _דיעו, --, --, 
   {{0x7ce00730,0xb22400d4,0x00000000,0x00000000}},	//   höre, _хміл, --, --, 
   {{0x7ce00fe7,0x2a900208,0x00000000,0x00000000}},	//   köre, _lđbđ_, --, --, 
   {{0xe5181524,0x9f041ec7,0xda7001d9,0xa134009f}},	//   नीति_, _بوبو, وُس_, _اوڙڪ, 
   {{0xd01c015b,0x7ce001e3,0x00000000,0x00000000}},	//   _দায়_, döre, --, --, 
   {{0xbb6800b5,0x7ce2241b,0x00000000,0x00000000}},	// [3ef40] _bitバ_, törd, --, --, 
   {{0x7e66241c,0x7ce0049f,0x62980142,0x3f400de2}},	//   _haip, före, _llwo, oñu_, 
   {{0x7e66241d,0x7ce2241e,0x62982252,0x160800c6}},	//   _kaip, göre, _olwo, لياً_, 
   {{0x7e66241f,0x649c067c,0xfa24031c,0x26042052}},	//   _jaip, _lèid, _འཇིན_, हुली_, 
   {{0x7e662420,0x27ec01e4,0x660c035b,0x00000000}},	//   _maip, _ĝene_, ñaka, --, 
   {{0x3a2008cd,0x7e662421,0x629a2422,0xf1cc01ec}},	//   laip_, _laip, _alwo, _ﮔﻪﻛﺘ, 
   {{0x20d800f2,0xd3b801ec,0x00000000,0x00000000}},	//   tèin_, шуді_, --, --, 
   {{0x7e662423,0x81a80729,0x3a222424,0x00000000}},	//   _naip, _গড়_, naip_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb1c0231,0x7e640b21,0xe7b000cf,0x7ce0002f}},	//   _expé, _aaip, _تۅۅد, hörb, 
   {{0x7e662425,0x66d0c424,0x649c01c3,0x3a222426}},	//   _baip, råkv, _dèid, kaip_, 
   {{0x7e662427,0x6d582776,0x4ea41cd0,0x00000000}},	//   _caip, _âwak, ірна, --, 
   {{0x8d84035b,0x3f4000e8,0x2f140014,0x7e640051}},	//   цунд, añu_, _کِبر, _daip, 
   {{0xcce406d5,0x2ff80276,0x00000000,0x00000000}},	//   تسجي, _ункь_, --, --, 
   {{0x7e64b452,0x7ce0049f,0x6e962428,0x20c800ae}},	//   _faip, förb, _нику, _ابني_, 
   {{0xa7b80184,0x7e640205,0x3a200205,0xe8e00051}},	//   ҡлау_, _gaip, gaip_, _đốp_, 
   {{0x14c816d1,0x0c8400ee,0x693402dd,0x00000000}},	// [3ef50] ाकाण, _дынм, янау, --, 
   {{0x7ce22429,0x1cd80003,0xb92001f2,0x649c0036}},	//   töre, _འཚར_, larị_, _kèie, 
   {{0x87040046,0x7e65aef9,0x80c8033f,0x00000000}},	//   زبال, _yaip, सकते, --, 
   {{0x7ce057bb,0xb92002e3,0xf414015b,0x2d9c00a2}},	//   röre, narị_, _সাগর_, _ýwes_, 
   {{0x7ce00267,0xa4d40212,0x69dc0064,0x00000000}},	//   söre, поді, _uzse, --, 
   {{0xb92000b4,0xfaf840ec,0x64a401c6,0xdb240244}},	//   harị_, _دریغ_, яала, _بوێی, 
   {{0x1cd8081f,0xb92000b4,0xe290007b,0x00000000}},	//   _འཚལ_, karị_, فذة_, --, 
   {{0x3bbc0302,0x6726242a,0x68fc017a,0x61fc022e}},	//   ימוד, mshj, _kusd, оsla, 
   {{0xdb0803c6,0x7e66242b,0x6d58025a,0x200803f9}},	//   čnéh, _raip, _âwah, _ƙai_, 
   {{0x7e6617b7,0xd24c60b3,0xac7c0020,0x68f6242c}},	//   _saip, پنی_, ጨማሪም_, _jizd, 
   {{0x7e66242d,0x5f040953,0xaabc012c,0xdcec00e2}},	//   _paip, язна, ्काक, ākļu, 
   {{0x649c00db,0x68f42ba4,0x68fc03cd,0x7e640946}},	//   _dèie, _lizd, _ousd, _qaip, 
   {{0xdd902073,0x68fc0009,0x7c3c02d0,0x00000000}},	//   روس_, _nusd, tgrr, --, 
   {{0x7e66242e,0x649c00db,0x64409307,0x68f40205}},	//   _waip, _fèie, _jcli, _nizd, 
   {{0x7e66242f,0xd00c31ed,0x68fe2430,0x3a2002d5}},	//   _taip, _صلي_, _ausd, taip_, 
   {{0x68f400da,0x67240726,0x68fc0ea0,0x64400175}},	//   _aizd, dshj, _busd, _lcli, 
   {{0x68fc04cc,0x3a2000c6,0x17f8007b,0xceb002e4}},	// [3ef60] _cusd, raip_, مراة_, _ריח_, 
   {{0x68f40007,0x68fe2431,0x6724032e,0x20044dd9}},	//   _cizd, _dusd, fshj, ncli_, 
   {{0x68f62432,0x291800ca,0x76400175,0x200400a3}},	//   _dizd, _ewsa_, _pcmy, icli_, 
   {{0x61f803cb,0x229002d2,0x6f1c0356,0x00000000}},	//   _ngwl, _fáki_, ârci, --, 
   {{0x68fe2433,0x7b8400d1,0x00000000,0x00000000}},	//   _gusd, _راھە, --, --, 
   {{0x68f40097,0x6440e38d,0xddd400b8,0xb4c800cd}},	//   _gizd, _ccli, _anyū, ैते_, 
   {{0x6440003a,0x48e00fc0,0x97300451,0x6e3c007c}},	//   _dcli, _чорв, _سڀاڻ, ygsb, 
   {{0x64415b7d,0x674400bc,0xd1380107,0x6d5c0042}},	//   _ecli, žují, бхо_, ywsa, 
   {{0x6440030d,0x66d0e155,0x4150005b,0x00000000}},	//   _fcli, råkt, евыс, --, 
   {{0x6d58006a,0xf8cc068f,0x64416f84,0xb92002e3}},	//   _âwai, ़किय, _gcli, warị_, 
   {{0x92681d39,0x00000000,0x00000000,0x00000000}},	//   _грла_, --, --, --, 
   {{0xdfd005d9,0xa2c00032,0x649c004e,0x63e00150}},	//   ئيٽ_, _үҙәк, _vèie, _جۋىل, 
   {{0x6d5cd3e1,0x3ea402d3,0x6e3ca2ec,0x0dc80116}},	//   uwsa, ëjta_, rgsb, суни_, 
   {{0x68fe2434,0x6440030d,0x67240240,0x22900162}},	//   _rusd, _xcli, yshj, _ráki_, 
   {{0x68f40369,0xb92001f2,0x68fe2435,0x63ac01e4}},	//   _rizd, parị_, _susd, ĝang, 
   {{0x68fe2436,0x63ac01e4,0x7ce003e0,0x6f04013a}},	//   _pusd, ŝang, törc, _čich, 
   {{0x6e2e2437,0x68f62438,0x68fc047e,0x00000000}},	// [3ef70] _idab, _pizd, _qusd, --, 
   {{0x68f4263e,0x672401bf,0x00000000,0x00000000}},	//   _qizd, tshj, --, --, 
   {{0x6e2c05b1,0x68fc014f,0x7bc00112,0x660e14da}},	//   _kdab, _wusd, ßmut, ñako, 
   {{0x64422439,0x255c0100,0x68f406af,0x68fe243a}},	//   _scli, _pňl_, _wizd, _tusd, 
   {{0x2a7a243b,0x6e2c014b,0xd124572d,0x67240158}},	//   _insb_, _mdab, _جم_, sshj, 
   {{0x2a68033d,0x1cb0025c,0x255c007f,0x67240fac}},	//   ldab_, ཐོག_, _vňl_, pshj, 
   {{0x6e2c04b9,0x64400092,0x2a784fa5,0xb4240137}},	//   _odab, _vcli, _knsb_, رعوو, 
   {{0x2a68033d,0x66d02a0e,0xe195a4b3,0xb6cc010e}},	//   ndab_, råks, дроэ, _ýüpü, 
   {{0x660a243c,0x7ce001e6,0x21687eb9,0x00000000}},	//   _ifek, höra, ципи_, --, 
   {{0x6e2e243d,0xe8d844fc,0x1cd8003d,0x2a6803a2}},	//   _adab, kwọ_, _འཚེ_, hdab_, 
   {{0x200405d5,0x14c800cd,0x00000000,0x00000000}},	//   rcli_, ाकरण, --, --, 
   {{0x2a680218,0x656c0030,0x2004003a,0x00000000}},	//   jdab_, ťahu, scli_, --, 
   {{0x6608c478,0x2a6a243e,0x0d8000d4,0x00000000}},	//   _mfek, ddab_, влян, --, 
   {{0x6e2c08e7,0x7ce0049f,0x00000000,0x00000000}},	//   _edab, föra, --, --, 
   {{0xcb6400a8,0x7ce0049f,0xe8d80521,0x00000000}},	//   маре_, göra, gwọ_, --, 
   {{0x224c01c4,0x9f0400e5,0x00000000,0x00000000}},	//   nfek_, _ٹوکو, --, --, 
   {{0xbc2c001f,0x27ec0115,0x2a780064,0x00000000}},	// [3ef80] ስታወቂ, _ĝena_, _dnsb_, --, 
   {{0x660805e5,0x2a782572,0xc68c0014,0x00000000}},	//   _afek, _ensb_, یِل_, --, 
   {{0x2a680175,0x229002f0,0x76bc0100,0x00000000}},	//   bdab_, _háku_, sčym, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb1c012d,0x94842503,0x00000000,0x00000000}},	//   _typó, дыйд, --, --, 
   {{0x229001ef,0x257000db,0x674800e5,0x00000000}},	//   _máku_, دۇكس, épjá, --, 
   {{0x66d05243,0x66080337,0x224c0af9,0xed900023}},	//   råkr, _ffek, ffek_, ህርተይ_, 
   {{0xc5ec00aa,0x649c00c7,0x41ac00c5,0x00000000}},	//   اړې_, _pèic, _जेहस, --, 
   {{0x22580254,0x00000000,0x00000000,0x00000000}},	//   õska_, --, --, --, 
   {{0x6e2c0109,0x8978010f,0x00000000,0x00000000}},	//   _sdab, קריצ, --, --, 
   {{0xd244013d,0x2a6801d5,0x60900023,0xee2003de}},	//   _жэли, ydab_, _ዝወጸት_, ленi_, 
   {{0x06c00116,0x2f300092,0x00000000,0x00000000}},	//   ﻣﺎﺋﻪ, _በደፈና, --, --, 
   {{0x3034023a,0xe82000bc,0x2a680037,0x00000000}},	//   _зелё, यरमा_, vdab_, --, 
   {{0xa3e41524,0xdb1c0077,0x7ce008c5,0x00000000}},	//   _नरम_, _expí, töra, --, 
   {{0x2a7805b1,0xf0b001d9,0x3f611e70,0xaabc076e}},	//   _pnsb_, _لیکھ, _атыб, ्कलक, 
   {{0x6e2e243f,0xceea2440,0xdb0c01ed,0xbb84007b}},	//   _udab, _برتن_, ájáb, خلفي, 
   {{0x2a6a2441,0x7ed404fb,0x19c0151e,0x00000000}},	// [3ef90] rdab_, _جزوا, гәрг, --, 
   {{0xcce423bb,0x7bc0029f,0xcc2401d3,0x00000000}},	//   _تسبي, ğmur, _کرکٹ, --, 
   {{0xfb3405f5,0x6608006f,0xbea805af,0x00000000}},	//   _инээ, _pfek, _رهین_, --, 
   {{0xf534067d,0xddc40790,0x00000000,0x00000000}},	//   _ኣይኮነ, nekş, --, --, 
   {{0xdd3003be,0xb90400fe,0x6d8801e4,0x6abc258d}},	//   _məşq, _পূ_, kɾam, ्कीर, 
   {{0xd9180302,0x7ce05df7,0x00000000,0x00000000}},	//   _מושל, hörn, --, --, 
   {{0x7ce22442,0xe29a2443,0xf49410e8,0xddc40205}},	//   körn, зай_, خشند, kekş, 
   {{0x7ce0008c,0x660935c4,0x26d8056a,0x2368008f}},	//   jörn, _ufek, _óso_, ĉaj_, 
   {{0x224c05e4,0x602407a5,0x00000000,0x00000000}},	//   rfek_, ндпа, --, --, 
   {{0x9f8416a8,0x33b00131,0x6abc00dc,0x2290032e}},	//   егод, _ھەير, ्कुर, _ráku_, 
   {{0x94240228,0x38a4007c,0x7ce05f47,0x00000000}},	//   _سونۇ, _förf_, förn, --, 
   {{0xe3280dd4,0x229002f0,0x7ce04d3e,0x00000000}},	//   _ལྷགཔ_, _páku_, görn, --, 
   {{0xdb080316,0xf4d8010a,0x00000000,0x00000000}},	//   čníh, _амăш_, --, --, 
   {{0xd12c05af,0xa068014b,0x26000432,0x00000000}},	//   _امو_, _хака_, _ỳol_, --, 
   {{0x707401d5,0x7ce008a5,0x69d8031c,0x00000000}},	//   _جانذ, börn, żwel, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x38a5c143,0x00000000,0x00000000,0x00000000}},	// [3efa0] _jörg_, --, --, --, 
   {{0x38a4008c,0xd7040108,0x00000000,0x00000000}},	//   _mörg_, езжи, --, --, 
   {{0x3ea03e1d,0x96f8007b,0xd5140248,0x00000000}},	//   _klit_, سعار_, _ọ̀f, --, 
   {{0xd6d401b9,0x87e400d1,0x00000000,0x00000000}},	//   رتاغ, رتلە, --, --, 
   {{0x6d58006a,0x66d0c424,0x3ea00327,0xb82400cc}},	//   _âwat, råkp, _mlit_, _পাঠত_, 
   {{0x3ea00137,0x85022444,0x38a403e0,0x7e840150}},	//   _llit_, دوون, _sörf_, _ﺩﻗﻴﻕ_, 
   {{0xcc38008f,0x3ea0005b,0x00000000,0x00000000}},	//   לעסט, _olit_, --, --, 
   {{0x7178472b,0x94a80050,0xb27400d1,0x00000000}},	//   дбир_, _کارِ_, тлиш, --, 
   {{0x7984243b,0x46a000f3,0x00000000,0x00000000}},	//   nxiw, _сатв, --, --, 
   {{0x3ea22445,0x8fe00032,0x2368012d,0xcfa4004e}},	//   _alit_, ләйҙ, łaja_, ешми, 
   {{0x93a85821,0x7ce03653,0x649c0036,0x70442dfc}},	//   _عاطف_, törn, _kèin, ىرگە, 
   {{0x3ea22446,0x7ce00267,0x38a401e3,0x63ac0115}},	//   _clit_, föro, _hörd_, ŝanc, 
   {{0x38a548ae,0x8274010f,0x7f8010e0,0x7ce001e3}},	//   _körd_, _רעדע_, _ەلىن, rörn, 
   {{0x3ea22447,0x229002d2,0xa02006be,0x8ce0215c}},	//   _elit_, _fáks_, _şövb, اقسۇ, 
   {{0x3ea00493,0x27ec00df,0x7ce003e0,0x00000000}},	//   _flit_, _ĝeno_, mörl, --, 
   {{0x3ea001e4,0x28d860d3,0x38a4007c,0xdd9000e5}},	//   _glit_, _बीजि, _lörd_, _چوٹ_, 
   {{0x7984014b,0xdd9001ed,0x5e6000db,0x7bd80174}},	// [3efb0] gxiw, _نوٹ_, _ئچپە, _øvun, 
   {{0x1cd8025c,0x38a4f971,0x7ce07aa0,0x00000000}},	//   _འཚག_, _nörd_, nörl, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6d582776,0x7ce22448,0x00000000,0x00000000}},	//   _âwas, hörl, --, --, 
   {{0x38a4007c,0x7994014b,0x7ce000a2,0x00000000}},	//   _börd_, _бияф, körl, --, 
   {{0x49c4030d,0x00000000,0x00000000,0x00000000}},	//   ăлăн_, --, --, --, 
   {{0x753c00da,0x38a400ac,0xeac400fe,0x00000000}},	//   _ārze, _dörd_, ্ষীম, --, 
   {{0xfd5400b8,0x160800af,0xe50800f1,0xed740023}},	//   _ekeṣ, हुआर_, _ييزو_, እይቶይ_, 
   {{0x503c0020,0x7ce057bb,0x38a40267,0xf1d422fd}},	//   _በአካባ, förl, _förd_, лөшө, 
   {{0x3ea01590,0xd5840244,0x00000000,0x00000000}},	//   _slit_, _جێهه_, --, --, 
   {{0xaf98023a,0x26dc04ba,0x00000000,0x00000000}},	//   етях_, olwo_, --, --, 
   {{0xe1351eb7,0x1cd80003,0x2bd405b3,0x2ee80042}},	//   _анды, _འཚང_, _धड़ा, _chaf_, 
   {{0x61451421,0x44262449,0x38a403fa,0x2ee80067}},	//   _рела, oan_, _höre_, _dhaf_, 
   {{0x8d6016a4,0x38a6244a,0x00000000,0x00000000}},	//   јвре, _köre_, --, --, 
   {{0x4426244b,0x9ea800d8,0x00000000,0x00000000}},	//   ian_, _овка_, --, --, 
   {{0xdd904030,0x3ea08b14,0x7d0001a8,0x18183042}},	//   _نوع_, _ulit_, ímss, धर्व_, 
   {{0x798402c4,0x649c180f,0x2c2003d4,0x89d4431a}},	// [3efc0] uxiw, _rèin, _বাৰে_, پولر_, 
   {{0x649c068c,0x9b040120,0x00000000,0x00000000}},	//   _sèin, _изод, --, --, 
   {{0x7d047890,0x6d58025a,0x6289c762,0x38a401e3}},	//   _huis, _âwar, kjeo, _rörd_, 
   {{0x7d06244c,0x4426244d,0x7984094a,0x7ce00205}},	//   _kuis, ean_, pxiw, zörl, 
   {{0x7d06244e,0x4426244f,0x649c067c,0xf5b40451}},	//   _juis, fan_, _vèin, دشاھ, 
   {{0x7d062450,0x44262451,0x39422452,0x26dc0083}},	//   _muis, gan_, muis_, alwo_, 
   {{0x7d062453,0x39422454,0x96c801d9,0xdcec0024}},	//   _luis, luis_, _قبرِ_, škės, 
   {{0x44240648,0x7d062455,0x39400129,0x81b40ca8}},	//   aan_, _ouis, ouis_, _sáyẹ, 
   {{0x4424adfe,0x39422456,0x7ce1b9ad,0x7d062457}},	//   ban_, nuis_, törl, _nuis, 
   {{0x38a404f3,0x2ee80a2e,0x7ce00624,0x02d401d5}},	//   _före_, _shaf_, förm, _یولب_, 
   {{0x38a40ab7,0x39422458,0x7d040421,0x6e9500ed}},	//   _göre_, huis_, _auis, гину, 
   {{0x7d062459,0x52746bdb,0xe51802e5,0x7ce00790}},	//   _buis, _جائز, नीकि_, sörl, 
   {{0x7d06245a,0x660c0227,0x39400115,0x7d241789}},	//   _cuis, ñaki, juis_, ифре, 
   {{0x7d06245b,0x6abc41ac,0x39403f93,0xbfb0144c}},	//   _duis, ्क्र, duis_, احیت, 
   {{0x7d05ff47,0x3940003a,0xaa58013e,0x4ea43947}},	//   _euis, euis_, ниву_, _арпа, 
   {{0x4424b25b,0x7d040de4,0xe9f80046,0xfaa454a0}},	//   zan_, _fuis, енбі_, ашун, 
   {{0x7d06245c,0x3942245d,0xa856245e,0x00000000}},	// [3efd0] _guis, guis_, лкач, --, 
   {{0x4426245f,0x1ce0031c,0x6d4c058a,0xfce400f0}},	//   xan_, _ཧེར_, _iqaa, _коњо, 
   {{0x649c00a3,0xab940212,0xf8062460,0x7de80248}},	//   _dèil, _сині, рчун, _tèsí, 
   {{0x3940dba0,0x7d04037e,0x60c00175,0x00000000}},	//   buis_, _yuis, znlm, --, 
   {{0x9180004d,0x2fdc0175,0x61480240,0x3940ec36}},	//   yết_, _lyvg_, _mëlç, cuis_, 
   {{0x67d62461,0x69dc010e,0x20d80036,0xa3480108}},	//   _богу, _iyse, nèit_, езка_, 
   {{0x628a2462,0x69de2463,0xaee40055,0xa35400ae}},	//   tjeo, _hyse, _guṇy, اختص, 
   {{0x44262464,0x69de2465,0x6d4c32ff,0x2908022f}},	//   san_, _kyse, _oqaa, oqaa_, 
   {{0x69dc0af9,0x29080ba7,0x05b412eb,0x628801e3}},	//   _jyse, nqaa_, _अधिब, rjeo, 
   {{0x44262466,0x656a2467,0x7d062468,0x38a62469}},	//   qan_, _iseh, _ruis, _töre_, 
   {{0x69dc11c0,0x7ce0049f,0x6d4c0014,0x82a40209}},	//   _lyse, börj, _aqaa, _ишде, 
   {{0x66f43644,0x2d9801f5,0x00000000,0x00000000}},	//   ेदिक_, fyse_, --, --, 
   {{0x7d06246a,0xf1a803e6,0x6568031c,0x20d8067c}},	//   _quis, _لاوه_, _jseh, fèit_, 
   {{0x7d06246b,0x7ce0553f,0x29080548,0xa6b800fe}},	//   _vuis, mörk, dqaa_, ইকিয়, 
   {{0x69de246c,0x6d4c0869,0x46d036c3,0x1a641e4b}},	//   _ayse, _eqaa, तवाह, هیدی_, 
   {{0x7d06246d,0x3942246e,0x212c011f,0x69de246f}},	//   _tuis, tuis_, oseh_, _byse, 
   {{0x6d58006a,0x69de2470,0x2d980175,0xceb000d9}},	// [3efe0] _âwap, _cyse, cyse_, _ליה_, 
   {{0x69de2471,0x39422472,0xaee40a28,0xb6cc0209}},	//   _dyse, ruis_, _puṇy, _ýüzü, 
   {{0xded0044e,0x39401a56,0x656a2473,0x69dc3ce5}},	//   _ኩለን_, suis_, _aseh, _eyse, 
   {{0x39402047,0x212c0066,0x69de2474,0x87e41c3e}},	//   puis_, kseh_, _fyse, اتكە, 
   {{0x39422475,0x69de2476,0x5c24015b,0x656801d3}},	//   quis_, _gyse, বলীগ_, _cseh, 
   {{0xdc74010f,0x00000000,0x00000000,0x00000000}},	//   רײַז_, --, --, --, 
   {{0x656a2477,0xc8d80302,0x00000000,0x00000000}},	//   _eseh, _נקלט, --, --, 
   {{0x7ce00267,0x02a000f7,0x00000000,0x00000000}},	//   förk, йрым, --, --, 
   {{0x614404a9,0x10483ab8,0x26b01df2,0x4270010b}},	//   لىيە, няни_, _بەنز, сгыс, 
   {{0x7ce00267,0x2d9a2478,0x00000000,0x00000000}},	//   sörj, vyse_, --, --, 
   {{0x2d980660,0x00000000,0x00000000,0x00000000}},	//   wyse_, --, --, --, 
   {{0x2d9a2479,0xaf400092,0x7ce002d2,0x00000000}},	//   tyse_, _ተደረገ, börk, --, 
   {{0x417004d3,0x212c0548,0x09bc015b,0xa2d00709}},	//   _هاوس, cseh_, _আর্থ, डकर्, 
   {{0xf534069c,0x2d9a247a,0x69de247b,0x00000000}},	//   _ኣይኰነ, ryse_, _ryse, --, 
   {{0x447800c8,0xfb848fd9,0xebc40131,0x644401ab}},	//   ענלע, бытн, рәпн, òhii, 
   {{0xc9849088,0x6936247c,0x6a140993,0x69dc5794}},	//   лузи, инбу, рмау, _pyse, 
   {{0xcfe400fe,0x20d8067c,0x6d4c0067,0x7ce010ee}},	// [3eff0] _নলিন, mèir_, _uqaa, körh, 
   {{0x69dc02fb,0x29080ba7,0xbb38001f,0x00000000}},	//   _vyse, rqaa_, ርባቸዋ, --, 
   {{0x69de247d,0x6568031c,0xfd10f3a5,0xd5a401d5}},	//   _wyse, _sseh, _وجی_, یلمی, 
   {{0xd2440736,0x212c011f,0xd0040214,0x7ce000e5}},	//   _ظن_, yseh_, _ژل_, yörk, 
   {{0x29090901,0x7ce001e6,0xdb1c0036,0x3ea40240}},	//   qqaa_, förh, _expä, ëjti_, 
   {{0x1cd80003,0x23340798,0xf644035b,0x656801ef}},	//   _འཚབ_, ахир, ахән, _vseh, 
   {{0x63ac010f,0xe2840484,0xbc7c0115,0x00000000}},	//   ĝano, илки, תנות, --, 
   {{0x6596247e,0x656a247f,0xe80c1b90,0x63ac01e4}},	//   _кабу, _tseh, ाँका_, ŝano, 
   {{0x8444085d,0x38a4049f,0x6568401f,0x660e2480}},	//   _مخال, _höra_, _useh, ñaku, 
   {{0x38a404f3,0x212c0548,0x00000000,0x00000000}},	//   _köra_, rseh_, --, --, 
   {{0x212c0429,0x92140a8a,0xfd640116,0x3be400bc}},	//   sseh_, _ध्वज_, әнгү, _गरेँ_, 
   {{0x291c063f,0xe0e4015b,0x53180375,0xe7ec5d4f}},	//   ̣waa_, নদেন, _יועצ, _झरना_, 
   {{0xaf400092,0x7ce00037,0x00000000,0x00000000}},	//   _ተደርገ, löri, --, --, 
   {{0xd0046833,0x91380a1e,0x09bc03d4,0x00000000}},	//   _кеше_, _יענק, _আৰ্থ, --, 
   {{0x1ec80209,0xdee40902,0x7ce0b35a,0x00000000}},	//   _илки_, _коки, nöri, --, 
   {{0x1a641079,0x00000000,0x00000000,0x00000000}},	//   جیحی_, --, --, --, 
  
   {{0xd9440588,0x7ce22481,0x981400cf,0x582400c7}},	// [3f000] рези, höri, لباا, имаб, 
   {{0xbd880451,0x38a4007c,0x888000d8,0x00000000}},	//   _لنڊن_, _böra_, олуж, --, 
   {{0x1ae400d8,0x4c38011a,0x00000000,0x00000000}},	//   _вонм, _בתיב, --, --, 
   {{0xd945c74f,0x00000000,0x00000000,0x00000000}},	//   _кеми, --, --, --, 
   {{0x7ce22482,0x8e540a1e,0x94a800fd,0xa2d81546}},	//   törh, שינג_, ктка_, मवन्, 
   {{0xba04067d,0x98a43a0a,0x7ce22483,0x38a401e6}},	//   _ሎሚ_, _тиге, föri, _föra_, 
   {{0x38a40628,0xa3e400dc,0x7ce001e3,0x03a00114}},	//   _göra_, _नरः_, göri, жијо, 
   {{0xcb100302,0x660c0784,0x00000000,0x00000000}},	//   חלה_, ñakt, --, --, 
   {{0x27ec00df,0x4638010f,0x37c401af,0x00000000}},	//   _ĝeni_, _שעמע, _тәҡб, --, 
   {{0x92e40011,0xc950011a,0xdbcc0432,0x705400cf}},	//   পদে_, קמת_, _sıýa, حندا, 
   {{0xb3801b49,0x4fc40006,0x926800c0,0x00000000}},	//   ናውያን_, рспа, _арла_, --, 
   {{0xf0a81e87,0x94b40210,0x00000000,0x00000000}},	//   ткүл_, _अगुआ, --, --, 
   {{0x0dc91480,0x20d8067c,0xe2a8009f,0x00000000}},	//   туни_, rèir_, _حالن_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x38a401e6,0x3ff8025d,0x9fc400d4,0xe4ec000d}},	//   _röra_, _בפוע, _ущіл, _चीनि_, 
   {{0x39142ec9,0xe85801f0,0x00000000,0x00000000}},	// [3f010] жмур, лааш_, --, --, 
   {{0xdd9046c6,0xb924007b,0x7ce00108,0x67d40835}},	//   _روپ_, تفكي, yöri, бозу, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc985131e,0x6704016c,0xfcd80b82,0x45480229}},	//   _туни, рӯҳб, _ኮለጅ_, тчем_, 
   {{0x38a401e6,0x00000000,0x00000000,0x00000000}},	//   _hörn_, --, --, --, 
   {{0xa06801ec,0x26c40241,0x46680117,0x00000000}},	//   қана_, _ìloo_, _ирам_, --, 
   {{0x7ce22484,0x38a44a26,0x50a00131,0x36d4005b}},	//   röri, _jörn_, ۋەنل, _доср, 
   {{0xa2940220,0xe0d855c3,0x04640798,0xd18004b4}},	//   _қаді, лви_, _втем, злый, 
   {{0x693c0356,0xa0680063,0x2a4c0240,0x00000000}},	//   _găeş, ћана_, _ዝጽበዮ, --, 
   {{0xdee802d3,0x1fb412c4,0xe9f80208,0x00000000}},	//   መጽእ_, сспр, thẻ_, --, 
   {{0x9758011a,0xa2f40114,0x3be40118,0x00000000}},	//   נדרט, _упеч, _गरौँ_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdcb04d2d,0x5f740330,0x54c00150,0x00000000}},	//   سىز_, _هابر, _ﺩﻳﯚﺯ, --, 
   {{0x38a4008c,0x10a01214,0xecc807f7,0x8fc8009d}},	//   _börn_, _хищн, _रदरफ, vйч_, 
   {{0x1cd80003,0x8f980375,0x5e48020f,0x1a05533f}},	//   _འཚམ_, _תיקי, _спим_, спам, 
   {{0x753c00ef,0x2d9400c0,0x00000000,0x00000000}},	// [3f020] _ārzo, _дрэс, --, --, 
   {{0x05d800e1,0x1c44004e,0x00000000,0x00000000}},	//   _बड़ब, _уном, --, --, 
   {{0x7ce001e6,0x9aa42eac,0xbb7404b3,0x28f80139}},	//   förv, _همدو, _بۇزع, рэтэ_, 
   {{0xd6300014,0x95ca2485,0x00000000,0x00000000}},	//   سِتھ, лула_, --, --, 
   {{0x7ae4031c,0x4ed800df,0x00000000,0x00000000}},	//   mlit, אַגנ, --, --, 
   {{0x986400dd,0x394008c2,0x86c00116,0x00000000}},	//   _دیئے_, mris_, ييەن, --, 
   {{0x7ae62486,0x39400a85,0x25c003b9,0x00000000}},	//   olit, lris_, _ərlə_, --, 
   {{0x39401730,0xb1162487,0xc6c00104,0x18a402a9}},	//   oris_, омиш, _ейск, _таҳм, 
   {{0x95c8f255,0x7ae62488,0x3940000f,0x49b8010f}},	//   _слаб_, ilit, nris_, ָמיס, 
   {{0x7ae62489,0x3942248a,0x73c46518,0x660c0419}},	//   hlit, iris_, _мәйе, ľake, 
   {{0x7ae6248b,0xb4e6248c,0xdb1c0077,0x00000000}},	//   klit, नती_, _expú, --, 
   {{0xe2a80014,0x7ae6248d,0x00000000,0x00000000}},	//   _پامن_, jlit, --, --, 
   {{0xf196248e,0xd010034c,0x7ce00112,0x00000000}},	//   _филь, _فلش_, höru, --, 
   {{0x7ae6248f,0x39422490,0xd6bc00fe,0xdcf401ef}},	//   elit, dris_, ইকিয, _fryč, 
   {{0x39422491,0x8aa42390,0x80a002dd,0x6e94f946}},	//   eris_, брад, _ءمىن, _мику, 
   {{0xe82004fa,0x1dd8c853,0x4ea62492,0xea18030d}},	//   यर्थ_, _युवत, _ырла, ржаш_, 
   {{0x39422493,0xc98410fc,0x3f740356,0x38a401a8}},	// [3f030] gris_, љуби, _zău_, _vörn_, 
   {{0xc8b400f2,0x7ce0f971,0x00000000,0x00000000}},	//   حصرب, föru, --, --, 
   {{0x7ae62494,0x39422495,0x690800f3,0xaa58009b}},	//   blit, aris_, _ožeg, _кину_, 
   {{0x39422496,0x7ae62497,0x00000000,0x00000000}},	//   bris_, clit, --, --, 
   {{0x6aac0428,0x39422498,0x27ec0115,0x7d7c00df}},	//   mhaf, cris_, _ĝenu_, ָנוו, 
   {{0x291a2499,0x6aae249a,0xc86401a9,0x7ce002d2}},	//   _itsa_, lhaf, _утми, böru, 
   {{0xd34401b9,0x7ce0002f,0x00000000,0x00000000}},	//   قیله_, mört, --, --, 
   {{0xe2980364,0x970004a9,0x3f74084c,0x6aad843f}},	//   раи_, _قېلى, _rău_, nhaf, 
   {{0x3f74084c,0xa3e42d8f,0x64a401e0,0x690800ef}},	//   _său_, _नरक_, _һаҡа, _džeg, 
   {{0x6aae249b,0xa09a249c,0x7ae6249d,0x7ce001f4}},	//   hhaf, ртиф_, zlit, nört, 
   {{0x2918070d,0x7ae40429,0x6aaccdf9,0xf1a803e6}},	//   _ltsa_, ylit, khaf, لایه_, 
   {{0x1ce00dd4,0x6aac0184,0x291800af,0x7ce003fa}},	//   _ཧེང_, jhaf, _otsa_, hört, 
   {{0x1d082692,0x6aae249e,0x29180211,0x7ae405be}},	//   реги_, dhaf, _ntsa_, vlit, 
   {{0x3f7400a8,0x3940008f,0x6aac0036,0xdbcc0166}},	//   _tău_, vris_, ehaf, _sıña, 
   {{0x7ae6249f,0x3a200455,0xdfd001f7,0x6aac002f}},	//   tlit, tbip_, _تيغ_, fhaf, 
   {{0x394224a0,0x7ae624a1,0x6aae24a2,0x7ce00008}},	//   tris_, ulit, ghaf, vöru, 
   {{0x7ae624a3,0x225c0007,0x394224a4,0x7ce05df4}},	// [3f040] rlit, _mbwk_, uris_, fört, 
   {{0x23c81d03,0x7ce003fa,0x0884023a,0xfa543b93}},	//   िपाद, töru, обуй_, _کردگ, 
   {{0x29180831,0x6aae24a5,0xdd900131,0x00000000}},	//   _etsa_, bhaf, _روھ_, --, 
   {{0x6aad4989,0x96b81374,0x98b0033f,0x00000000}},	//   chaf, جائز_, kryć_, --, 
   {{0x291801ee,0xceb000df,0x00000000,0x00000000}},	//   _gtsa_, ויא_, --, --, 
   {{0xb4e409fd,0x25f005f9,0x7ce224a6,0xb82400cc}},	//   नते_, ेशजी_, pöru, _পাকত_, 
   {{0x22900306,0xd24401f4,0x00000000,0x00000000}},	//   _háky_, оэпи, --, --, 
   {{0x15ba24a7,0x32e4006a,0x6f185049,0xf4840133}},	//   _кызы_, dëyê_, _rtvc, تاڵی, 
   {{0x506624a8,0x7ce00267,0x2b100037,0x00000000}},	//   отна, nörs, _दूनु_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7ce07a45,0x6aae24a9,0x70580107,0xb4c81fd2}},	//   hörs, yhaf, _ғайр_, ोकी_, 
   {{0x6f180208,0x7ce0b35a,0x00000000,0x00000000}},	//   _vtvc, körs, --, --, 
   {{0xb1180137,0xcd040138,0x78bc00d7,0x00000000}},	//   _اقتا_, ючни, _omrv, --, 
   {{0x00805a52,0x8f08030d,0x00000000,0x00000000}},	//   _олчо, _кхиа_, --, --, 
   {{0xdd8c01d3,0x00000000,0x00000000,0x00000000}},	//   نڈی_, --, --, --, 
   {{0x7ce041b7,0x649c180f,0xfa896c9c,0x7d000241}},	//   förs, _hèit, осуй_, _párì, 
   {{0x6aae24aa,0x6e2c01ab,0x7ce224ab,0x68e40842}},	// [3f050] rhaf, _ieab, tört, tlhd, 
   {{0x26cc1e31,0x6e2e24ac,0xcc8403e6,0xb4e624ad}},	//   _sjeo_, _heab, _بۆسه_, नतो_, 
   {{0x6e2c3223,0x6aac008c,0x3cf800c6,0x7ce0002f}},	//   _keab, phaf, _بعيد_, rört, 
   {{0x7ce224ae,0x6aac0117,0xcae000ab,0xa13c00a2}},	//   börs, qhaf, _कीचड_, lyŷe, 
   {{0x6e2e24af,0x29190d1c,0x6abc03b2,0x7ce05fa3}},	//   _meab, _utsa_, _imsf, pört, 
   {{0x6e2c3c60,0xd24c17de,0xd5ac00c6,0x2a68393b}},	//   _leab, ۇنى_, طفى_, leab_, 
   {{0xd04c03be,0x998000e2,0x7bd80162,0xa0a40116}},	//   _ödən, _iekš_, _øvut, җанд, 
   {{0x2a680086,0xe5087427,0x26cc0cf4,0x6e2c0024}},	//   neab_, _هيرو_, _ujeo_, _neab, 
   {{0x05741060,0x26dc856e,0x81e0045e,0x6608143c}},	//   _بازد, mowo_, ফেন_, _igek, 
   {{0x649c00a3,0x2a6919d2,0x0f380092,0xc0dc0240}},	//   _cèit, heab_, _በተመረ, _ነገሮ_, 
   {{0xdee40b01,0x6e2c1f0c,0x2a680165,0x0fc00209}},	//   зони, _beab, keab_, ейэн, 
   {{0x26dd4a0c,0x6e2c062c,0xde0401b9,0x00000000}},	//   nowo_, _ceab, япми, --, 
   {{0x6e2e24b0,0x8f5003e6,0x7ce06b4e,0x6024010a}},	//   _deab, ونیش, dörr, _едла, 
   {{0x644c0198,0xdca624b1,0x224c017a,0x6298010e}},	//   ɗaic, чаги, lgek_, _howo, 
   {{0x6e2c0491,0x60c206a0,0x649c067c,0x46d80034}},	//   _feab, milm, _hèis, यकाह, 
   {{0x660852e6,0x224e24b2,0x6e2e24b3,0x629800f2}},	//   _ngek, ngek_, _geab, _jowo, 
   {{0x629a24b4,0x26de24b5,0xb5840116,0x00000000}},	// [3f060] _mowo, dowo_, _ﯪﻳﺎﻝ_, --, 
   {{0x629a24b6,0x660a24b7,0x4d7800c8,0x6e2d131a}},	//   _lowo, _agek, _פריע, _zeab, 
   {{0x0634044e,0x6abc05ac,0x4c98011a,0x160800c6}},	//   _ከምዝነ, _fmsf, _השיע, مياً_, 
   {{0x26de24b8,0x6298006d,0x690805be,0x6b8000b5}},	//   gowo_, _nowo, _džeb, ælge, 
   {{0x60c224b9,0x649c0ba1,0x4a780375,0xb3e000cc}},	//   kilm, _nèis, _הרכב, যোজ, 
   {{0x660a24ba,0x38a4cf5f,0xf8a803e6,0xb78401b9}},	//   _egek, _mörk_, _بگره_, _оғзи, 
   {{0x60c1b740,0x26dc25a9,0x62995305,0x660c0427}},	//   dilm, bowo_, _bowo, žaka, 
   {{0x629a24bb,0x224e24bc,0x26dc012d,0x00000000}},	//   _cowo, ggek_, cowo_, --, 
   {{0x6e2e24bd,0x15441248,0x6298068f,0xef240327}},	//   _reab, _хезм, _dowo, _meżż_, 
   {{0xf4849057,0x6e2c6328,0x649c0ba1,0x20094c85}},	//   _تاری, _seab, _dèis, _şair_, 
   {{0x629a24be,0x08540302,0x6e2c3453,0xaed55a41}},	//   _fowo, הבים_, _peab, донш, 
   {{0x629a24bf,0x60c01073,0x38a58cb0,0x00000000}},	//   _gowo, ailm, _börk_, --, 
   {{0x60c224c0,0xa2d87fd5,0x8d840137,0x2258033b}},	//   bilm, मवर्, чунд, òske_, 
   {{0x60c224c1,0x62988cd5,0x649c0ba1,0xc0d001ec}},	//   cilm, _zowo, _hèir, _كينب, 
   {{0x7b6410e0,0x62980bd7,0x26dc004c,0xc0500375}},	//   нтте, _yowo, yowo_, _נזק_, 
   {{0xe9f8035b,0x00000000,0x00000000,0x00000000}},	//   ahẽ_, --, --, --, 
   {{0x26dc004c,0x38a40432,0x2a6801e7,0x00000000}},	// [3f070] vowo_, _görk_, reab_, --, 
   {{0x26de24c2,0xb4c8047f,0x47886bb8,0xdcf40055}},	//   wowo_, ोको_, йсем_, _tryā, 
   {{0x26de24c3,0xfb84b421,0x0744177b,0xc6e400d4}},	//   towo_, _зыян, яхам, підп, 
   {{0x60c224c4,0x6abc02d0,0xf7701063,0x00000000}},	//   zilm, _umsf, طام_, --, 
   {{0xf65101c4,0x26de24c5,0x62980810,0x60c224c6}},	//   ائم_, rowo_, _rowo, yilm, 
   {{0x7b080597,0x629a24c7,0x1ce0031c,0x26de24c8}},	//   _óstá, _sowo, _ཧེབ_, sowo_, 
   {{0x26de24c9,0x629a24ca,0xd36c06f6,0xdde400b0}},	//   powo_, _powo, لهو_, _āpōt, 
   {{0x66080a40,0x00000000,0x00000000,0x00000000}},	//   _ugek, --, --, --, 
   {{0x60c224cb,0x7ce1cb70,0x200803b9,0x224e24cc}},	//   tilm, körp, _şaiq_, rgek_, 
   {{0x629a24cd,0x224c002d,0x00000000,0x00000000}},	//   _wowo, sgek_, --, --, 
   {{0x60c0344b,0x629a24ce,0x649c067c,0x1cb8031c}},	//   rilm, _towo, _fèir, ྙིལ_, 
   {{0xb8240c58,0x00000000,0x00000000,0x00000000}},	//   _পাছত_, --, --, --, 
   {{0x60c224cf,0xf2d8ba4f,0x72040328,0xb900031c}},	//   pilm, _عظمت_, _كومم, _སྩ_, 
   {{0x60c0358d,0x00000000,0x00000000,0x00000000}},	//   qilm, --, --, --, 
   {{0x1ae406ed,0x69c0012d,0x00000000,0x00000000}},	//   довм, _ślep, --, --, 
   {{0x38a40166,0x66d800fd,0x00000000,0x00000000}},	//   _törk_, _yäkş, --, --, 
   {{0x68f401fa,0x2b540214,0xddd400cd,0x9cf4004e}},	// [3f080] _bhzd, ویید_, _mayū, _очош, 
   {{0x38a4496e,0x00000000,0x00000000,0x00000000}},	//   _köri_, --, --, --, 
   {{0x38a405d5,0xda0800f1,0x00000000,0x00000000}},	//   _jöri_, _ويده_, --, --, 
   {{0x8d9c0020,0xb4c80b67,0x00000000,0x00000000}},	//   ልክቷል_, ोक्_, --, --, 
   {{0x649c0ba1,0xf4e40022,0x00000000,0x00000000}},	//   _rèir, нскҟ, --, --, 
   {{0xcdb40375,0x629c01f4,0x00000000,0x00000000}},	//   ופנה_, öson, --, --, 
   {{0x3878327f,0x649c1497,0x480000c7,0x1ce0031c}},	//   _iarr_, _pèir, _апрв, _ཧེན_, 
   {{0x38780489,0xd13a24d0,0x82f4009a,0xc7d400d9}},	//   _harr_, охо_, وريز_, _חולי_, 
   {{0x387a24d1,0x70440131,0x4610036b,0x00000000}},	//   _karr_, ۈرگە, _شولر, --, 
   {{0x94a801d9,0x38a4010e,0x8fe00032,0x4fc55246}},	//   _بارِ_, _böri_, кәйҙ, дсма, 
   {{0x38782c03,0x38a4013d,0x00000000,0x00000000}},	//   _marr_, _cöri_, --, --, 
   {{0x63ac04ac,0x387801ab,0x2af400bc,0x6db4117e}},	//   ĝant, _larr_, ्दछु_, ейму, 
   {{0xc69008a8,0x63ac010f,0x00000000,0x00000000}},	//   דאר_, ŝant, --, --, 
   {{0x38780086,0xfc6400a7,0x3d140166,0x42980150}},	//   _narr_, късн, _däw_, _ﺘﻀﻐﻁ_, 
   {{0x38a407c5,0xceb8009b,0x00000000,0x00000000}},	//   _göri_, _мљи_, --, --, 
   {{0x3fc80214,0x6b740022,0x00000000,0x00000000}},	//   _بدهی_, _ҷлоу, --, --, 
   {{0x387a16cb,0x00000000,0x00000000,0x00000000}},	// [3f090] _barr_, --, --, --, 
   {{0x6b741173,0xc7a90f5e,0x1b1c00bd,0x48bc0c58}},	//   _злоу, يدال_, _ফিরে_, ্ত্ৰ, 
   {{0x38789d12,0x00000000,0x00000000,0x00000000}},	//   _darr_, --, --, --, 
   {{0xdb1c056a,0x387801c3,0x660c0419,0xf77000ae}},	//   _expó, _earr_, ľako, ؤال_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x387a24d2,0xddd40055,0x25a80327,0x00000000}},	//   _garr_, _sayū, ġal_, --, 
   {{0x2a7807d6,0x25a8151c,0xa2e4010b,0x629c0254}},	//   _kasb_, šal_, нокд, ösoo, 
   {{0x38a4032e,0x00000000,0x00000000,0x00000000}},	//   _röri_, --, --, --, 
   {{0x3878002e,0x45a000cf,0x21680276,0x00000000}},	//   _yarr_, _جەشك, чипи_, --, 
   {{0x2054024c,0x00000000,0x00000000,0x00000000}},	//   хтир, --, --, --, 
   {{0x44240789,0xa0a40075,0x3d1400a2,0x34940fac}},	//   mbn_, _җайд, _säw_, _шафр, 
   {{0x9d44e3e7,0x2a7806be,0x00000000,0x00000000}},	//   немд, _nasb_, --, --, 
   {{0x0d803e2e,0xc1b00022,0x81a4007b,0x00000000}},	//   глян, _шәкы, _تحال, --, 
   {{0xf0e800d1,0x44240051,0x230400ec,0x00000000}},	//   _قىنى_, nbn_, _تڪڙي_, --, 
   {{0x3d140166,0x00000000,0x00000000,0x00000000}},	//   _wäw_, --, --, --, 
   {{0x7e640588,0x3d140139,0x00000000,0x00000000}},	//   _реиҧ, _täw_, --, --, 
   {{0x7e6624d3,0x44240e02,0x00000000,0x00000000}},	// [3f0a0] _ibip, kbn_, --, --, 
   {{0x3ba416c3,0x660c9a64,0x4424003e,0x00000000}},	//   _алоҳ, žakl, jbn_, --, 
   {{0x387a24d4,0xdb1c067c,0xd708023a,0x00000000}},	//   _varr_, _expò, чнее_, --, 
   {{0x387800e8,0xd7f000cf,0x00000000,0x00000000}},	//   _warr_, _ەكس_, --, --, 
   {{0x7e6624d5,0x39040022,0x387a24d6,0x00000000}},	//   _mbip, _аҟаб, _tarr_, --, 
   {{0x34bc9295,0x00000000,0x00000000,0x00000000}},	//   ्चेद, --, --, --, 
   {{0xd6280957,0x620403be,0x7e6401c4,0x00000000}},	//   _нове_, ərlə, _obip, --, 
   {{0x7e6402e3,0x00000000,0x00000000,0x00000000}},	//   _nbip, --, --, --, 
   {{0x4424013f,0xb9cc001f,0xddd400c0,0x9584010a}},	//   bbn_, _ሰኞ_, _anyž, _ялае, 
   {{0x44240223,0x7e6624d7,0x64b000db,0x00000000}},	//   cbn_, _abip, _ۅڭۉر, --, 
   {{0x690805a1,0xee380228,0xe3b001d9,0x4f641699}},	//   _ožen, үнү_, _پرٕ_, رادف, 
   {{0xd2f0030d,0x00000000,0x00000000,0x00000000}},	//   _тiар, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7e6624d8,0x00000000,0x00000000,0x00000000}},	//   _ebip, --, --, --, 
   {{0x764002f0,0xaa580107,0x00000000,0x00000000}},	//   _odmy, миву_, --, --, 
   {{0xf40403d4,0x00000000,0x00000000,0x00000000}},	//   _ৰজাৰ_, --, --, --, 
   {{0x69095966,0x7cf40139,0x8d847c47,0xa85401a9}},	// [3f0b0] _džen, _bοrı, _чуйд, ккач, 
   {{0x6d5e24d9,0x00000000,0x00000000,0x00000000}},	//   mtsa, --, --, --, 
   {{0x6d5e24da,0x44240b4b,0x00000000,0x00000000}},	//   ltsa, vbn_, --, --, 
   {{0x43b00032,0x6d5c3110,0xa2800092,0xb6cc0432}},	//   ңҡар, otsa, ናችንን_, _ýülü, 
   {{0x6d5e24db,0xe8d800b4,0x442624dc,0x09b800cc}},	//   ntsa, ntị_, tbn_, _অঁকা, 
   {{0x6d5e24dd,0x7640015d,0xd4640063,0xd5ac01d9}},	//   itsa, _edmy, више_, غہٕ_, 
   {{0xe299a55a,0x6d5c033d,0x4424020c,0xb50800db}},	//   дай_, htsa, rbn_, رۉمۅ_, 
   {{0x6d5d2b8c,0xe8d802e3,0x13a401d3,0x00000000}},	//   ktsa, ktị_, ئنٹی_, --, 
   {{0x6d5c61a7,0x4424008b,0xd1cc0023,0x00000000}},	//   jtsa, pbn_, _ብልቢ_, --, 
   {{0x656a24de,0x716400db,0x9f840212,0x3e6c0208}},	//   _ipeh, اايك, вгод, _ết_, 
   {{0x6d5e24df,0x76404e9b,0xe8d801f2,0x1fb4084c}},	//   etsa, _ydmy, etị_, тспр, 
   {{0x38a49577,0x6568006a,0x130802dd,0x00000000}},	//   _hört_, _kpeh, _قىلۋ_, --, 
   {{0x38a584e3,0x9f0525d0,0x6d5c00b5,0x69080427}},	//   _kört_, _یوتو, gtsa, _ržen, 
   {{0x65680270,0x10a00f32,0xa0c405d9,0xc0580212}},	//   _mpeh, _вишн, _جيتو, _хід_, 
   {{0x6d5e24e0,0xe8d801f2,0x64400175,0xefc80023}},	//   atsa, atị_, _mdli, ሽተይ_, 
   {{0xe7e40c2e,0x656a24e1,0x00000000,0x00000000}},	//   _कड़ा_, _opeh, --, --, 
   {{0xcb98069c,0x6d5c0c8c,0x81e0015b,0x6bd400d1}},	// [3f0c0] ፈላለየ_, ctsa, ফের_, نتېر, 
   {{0x3ea0062c,0x6440eed2,0x00000000,0x00000000}},	//   _hoit_, _ndli, --, --, 
   {{0x3ea224e2,0x6569dc1a,0x1b4801a9,0x00000000}},	//   _koit_, _apeh, _юзни_, --, 
   {{0x644224e3,0xd3000055,0xa3d40037,0xcf90011a}},	//   _adli, _kṛśa_, सपन_, יטב_, 
   {{0x7ae4426d,0x057001d5,0x3ea224e4,0x38a4032e}},	//   moit, لاود, _moit_, _söru_, 
   {{0x7ae624e5,0xb3940023,0x00000000,0x00000000}},	//   loit, _ሎሚውን_, --, --, 
   {{0x38a445e3,0x3ea0225e,0x656a24e6,0x43640120}},	//   _dört_, _ooit_, _epeh, вајн_, 
   {{0x7ae624e7,0x6d5e24e8,0x38a401a8,0x958400db}},	//   noit, ytsa, _vöru_, _илбе, 
   {{0x46a005f5,0x38a40267,0x5504064e,0x69085c9a}},	//   _татв, _fört_, _апаб, _ožel, 
   {{0x7ae4049b,0x6d5c0218,0x53a40022,0x63e00150}},	//   hoit, vtsa, _иазб, _گۋىل, 
   {{0x7ae624e9,0x2ab400b5,0x38a401e6,0x3ea0004a}},	//   koit, _håbe_, _hörs_, _boit_, 
   {{0x7ae40664,0x6d5e24ea,0x3ea224eb,0x3b000784}},	//   joit, ttsa, _coit_, jmiq_, 
   {{0x3ea224ec,0x6d5e24ed,0x7ae501bb,0xd1740121}},	//   _doit_, utsa, doit, _шыжы, 
   {{0x6d5e24ee,0xd3000055,0x00000000,0x00000000}},	//   rtsa, _dṛśa_, --, --, 
   {{0x69082f61,0x7ae4d0d8,0xe8d802e3,0x00000000}},	//   _džel, foit, stị_, --, 
   {{0x6d5e24ef,0x7ae624f0,0x3ea01368,0x6e550395}},	//   ptsa, goit, _goit_, _свиф, 
   {{0x6f0c01ab,0xa3c82ca5,0xac184627,0x00000000}},	// [3f0d0] _iiac, _लेन_, _попу_, --, 
   {{0x6f0e24f1,0x8c640276,0xcb980023,0x00000000}},	//   _hiac, _ртид, ፈላልየ_, --, 
   {{0xd124468e,0x7ae624f2,0x6f0c009f,0xbdd001e4}},	//   _گم_, boit, _kiac, _veɨe, 
   {{0x7ae4172e,0x6f0c01c8,0x38a624f3,0x0a68036b}},	//   coit, _jiac, _börs_, _ўрни_, 
   {{0xd124e647,0xe7e4069f,0x6440030d,0x6aac0198}},	//   _دم_, _कडवा_, _pdli, mkaf, 
   {{0x6f0e24f4,0x6aac0579,0x00000000,0x00000000}},	//   _liac, lkaf, --, --, 
   {{0x2ca00020,0x68e4014f,0xf7940006,0x2900025c}},	//   _mohd_, mohd, _карэ, mmha_, 
   {{0x6aae24f5,0x68e4036b,0x38a40267,0x54500116}},	//   nkaf, lohd, _förs_, авәт, 
   {{0x3ea224f6,0x38a436bf,0xdd0001a6,0x6568035b}},	//   _roit_, _görs_, _žučk, _upeh, 
   {{0x03c421bf,0x3ea224f7,0x644224f8,0x7ae405b8}},	//   _исем, _soit_, _udli, zoit, 
   {{0x1ec83173,0x6f0e24f9,0x7ae609c5,0x6aae24fa}},	//   елни_, _biac, yoit, kkaf, 
   {{0x6f0e24fb,0xd12cdcb1,0x7fb000ac,0x6aac01f5}},	//   _ciac, _کمو_, nəqə, jkaf, 
   {{0x3ea224fc,0x614624fd,0x7ae624fe,0x68e4c88d}},	//   _voit_, _села, voit, kohd, 
   {{0x6f0d059f,0x3ea00109,0x6aac0ea0,0x68e4023a}},	//   _eiac, _woit_, ekaf, johd, 
   {{0x7ae624ff,0x3ea22500,0xcb6568ab,0x6f0e2501}},	//   toit, _toit_, ларе_, _fiac, 
   {{0x6f0c8e53,0x6908b24b,0xede4063f,0x1ea80b24}},	//   _giac, _džem, ụrịm_, _ساعي_, 
   {{0x3b000113,0x6b8003cd,0x69a401e0,0x59847a71}},	// [3f0e0] rmiq_, ålgr, алтҡ, ылаб, 
   {{0x7ae45e1d,0x6f0defa6,0xdd9400c7,0x6908009b}},	//   soit, _ziac, _ааҩы, _užel, 
   {{0x9484e17f,0x7ae62502,0x38a401b8,0x964401c6}},	//   ғылд, poit, _sörs_, гэлд, 
   {{0x3b000cfe,0xd9440116,0x8bd001d5,0x6d4c01e1}},	//   qmiq_, _йеми, _چقیش, _ìlaò, 
   {{0x8e5413e2,0x38a401e6,0xfaa400c7,0xa3c800af}},	//   רינג_, _dörr_, _баҟо, _लेब_, 
   {{0x798400aa,0xd378094d,0x644c03f9,0x0d14010f}},	//   mviw, ечи_, ɗaik, אקסט_, 
   {{0x38a4049f,0x07a10865,0x7fb00213,0x28740166}},	//   _förr_, _ларн, bəqə, _тыяр, 
   {{0x47d0038b,0x38a40267,0x2ab401bf,0x00000000}},	//   _ايفر, _törs_, _tåbe_, --, 
   {{0x6f0e2503,0x3f840268,0xd54803e6,0x9254023b}},	//   _riac, _arnu_, _سلاو_, вақт_, 
   {{0x2ee80af9,0x518401e0,0x6f0c0042,0x70540592}},	//   _skaf_, _ҡула, _siac, جندا, 
   {{0x6f0e2504,0x3f840989,0x00000000,0x00000000}},	//   _piac, _crnu_, --, --, 
   {{0x91848a91,0xab680327,0x63a4002f,0x6aac007c}},	//   _مجتم, neżż, ähne, xkaf, 
   {{0x6f0c01a2,0x4ea40046,0x69089d28,0x6194004b}},	//   _viac, _ұрпа, _džej, _ناوړ, 
   {{0x8140009a,0x00000000,0x00000000,0x00000000}},	//   _انون, --, --, --, 
   {{0x6f0c01ab,0x68e4022e,0x00000000,0x00000000}},	//   _tiac, vohd, --, --, 
   {{0xf34402d3,0x6f0dadb5,0x00000000,0x00000000}},	//   _ከይተሓ, _uiac, --, --, 
   {{0xaa580214,0x00000000,0x00000000,0x00000000}},	// [3f0f0] _یلدا_, --, --, --, 
   {{0x2d8816b8,0x00000000,0x00000000,0x00000000}},	//   _irae_, --, --, --, 
   {{0x38a4007c,0xa774008e,0x00000000,0x00000000}},	//   _pörr_, рлеч, --, --, 
   {{0x2d8a2505,0x7984004c,0x69c402dd,0xff540677}},	//   _krae_, bviw, _көзб, רבאך_, 
   {{0x7fb00213,0xd6c401b9,0x95b400c7,0x00000000}},	//   rəqə, جمنی, иршә, --, 
   {{0xdb1c0798,0xb5c8027d,0xddd4012d,0xd1c4069d}},	//   _expõ, دوهم_, _abyś, ሽነት_, 
   {{0xc7a00050,0x37f8084c,0xab680327,0x466800d8}},	//   _أزی, _берэ_, beżż, _прам_, 
   {{0x2d880381,0x8554007b,0x00000000,0x00000000}},	//   _orae_, _مخطط, --, --, 
   {{0xe0d83117,0xf77032db,0x7124006c,0x00000000}},	//   кви_, _واہ_, یریل, --, 
   {{0x1f662506,0xa3c8000d,0x38a402d2,0x00000000}},	//   аком, _लेथ_, _jörp_, --, 
   {{0x94240075,0x2d88ddac,0x7984006f,0x00000000}},	//   _ئومۇ, _arae_, zviw, --, 
   {{0x2d8a2507,0xb3c801c0,0xde062508,0x12c00451}},	//   _brae_, _сууж_, ипни, _وڪيپ, 
   {{0xf1a8168d,0x2d8a2509,0xa3c800af,0xb638031c}},	//   _ماوه_, _crae_, _लेत_, żżgħ, 
   {{0x2d881a56,0x69083aed,0x330000b8,0x23a83c71}},	//   _drae_, _džek, _iṣṭe_, _कथाद, 
   {{0x2d9c0086,0x6284013f,0x2d88003a,0x3f8400ef}},	//   _àwen_, _ɔhon, _erae_, _urnu_, 
   {{0x2d88d4cf,0x00000000,0x00000000,0x00000000}},	//   _frae_, --, --, --, 
   {{0x2d880561,0xc9a53566,0x63bc03e3,0x00000000}},	// [3f100] _grae_, авте_, _əsna, --, 
   {{0x5ba800c7,0x79850488,0xad241c4e,0x7ce00108}},	//   _аком_, rviw, _اريو, yöry, 
   {{0x7c3e250a,0x69de250b,0xa64002d3,0xdb0c002f}},	//   marr, _exse, _ከምዝሰ, tzbä, 
   {{0x7c3e250c,0x95840474,0x95ca250d,0x1608007b}},	//   larr, илее, кула_, نياً_, 
   {{0xdb1c00d8,0x7c3c01c4,0x09e00137,0x38a401e3}},	//   _expô, oarr, _моюн, _förp_, 
   {{0x7c3e250e,0x39400457,0x68e801e4,0x6efc01d3}},	//   narr, msis_, _ƭede, mébe, 
   {{0x3942250f,0x6efc01ed,0x7c3c01c4,0x441001e0}},	//   lsis_, lébe, iarr, әфәт, 
   {{0x7c3e1199,0x39422510,0x3a222511,0x00000000}},	//   harr, osis_, ncip_, --, 
   {{0x7c3c152d,0x39419c3b,0xd5e81698,0xb1ca2512}},	//   karr, nsis_, _شعرن_, ыңда_, 
   {{0x7c3e2513,0x39422514,0x25a81b45,0x63a4002f}},	//   jarr, isis_, _صدقي_, ähnc, 
   {{0x7c3e2515,0x6908b0e8,0x39400790,0xd1480214}},	//   darr, _džeh, hsis_, رشکن_, 
   {{0x2d881730,0x6efc01ed,0x51844773,0x7c3c0363}},	//   _prae_, kébe, _вука, earr, 
   {{0x7c3e2516,0x2b4000b5,0x6efc01ed,0x00000000}},	//   farr, _svhc_, jébe, --, 
   {{0x7c3c152d,0x2d880151,0x394001bf,0x00000000}},	//   garr, _vrae_, dsis_, --, 
   {{0x313400d1,0x0ac402e8,0xebc40139,0x00000000}},	//   _теһр, ащам, сәпн, --, 
   {{0x2d8a2517,0xa7b8151e,0x81c000db,0x6e44007b}},	//   _trae_, ңлау_, _دەۋۇ, _انظم, 
   {{0x4a74052f,0x6e3c047e,0x6f18014f,0x7c3c1e56}},	// [3f110] лыҡт, masb, _huvc, barr, 
   {{0x4ba400f7,0x6f18022e,0x00000000,0x00000000}},	//   _көбү_, _kuvc, --, --, 
   {{0x39408f1e,0xc60c00dc,0xfb8400c0,0x00000000}},	//   asis_, िश्य_, _дыян, --, 
   {{0x39400457,0x6f18047e,0x85480023,0x00000000}},	//   bsis_, _muvc, _ብተፈጥ, --, 
   {{0x6efc068c,0x6f1801d5,0x39422518,0xe56833d2}},	//   cébe, _luvc, csis_, امتى_, 
   {{0xf64400b1,0xe79400f0,0x4a7001c8,0x00000000}},	//   бхән, _лигњ, _اُڏر, --, 
   {{0x291a2519,0x05740116,0x00000000,0x00000000}},	//   _husa_, _ھارد, --, --, 
   {{0x7c3e251a,0x291a251b,0x0576251c,0x2910009f}},	//   zarr, _kusa_, _پارد, _hiza_, 
   {{0x2910015c,0x7c3e251d,0x65140f11,0x60e85183}},	//   _kiza_, yarr, _طوائ, лмим_, 
   {{0x6f18014f,0x7c3e251e,0x649c00db,0x291001d5}},	//   _buvc, xarr, _nèix, _jiza_, 
   {{0x291a251f,0x29122520,0x14d404ae,0x6efc01d3}},	//   _lusa_, _miza_, _פועל_, zébe, 
   {{0x7c3c0225,0x6e3c51e2,0x291807ab,0x69081ebf}},	//   warr, gasb, _ousa_, _džei, 
   {{0x7c3e2521,0x2918a324,0x2910009d,0x00000000}},	//   tarr, _nusa_, _oiza_, --, 
   {{0x6efe2522,0x3a200210,0x00000000,0x00000000}},	//   vébe, wcip_, --, --, 
   {{0x7c3c0eb0,0x291a2523,0x6e3e2524,0x39400548}},	//   rarr, _ausa_, basb, wsis_, 
   {{0x7c3c95fc,0x29101311,0x6efc00dd,0x39422525}},	//   sarr, _aiza_, tébe, tsis_, 
   {{0x7c3e2526,0x29122527,0x291a0a70,0x39410bd5}},	// [3f120] parr, _biza_, _cusa_, usis_, 
   {{0x29101446,0x7c3e2528,0x6efc01ed,0x6f188e61}},	//   _ciza_, qarr, rébe, _yuvc, 
   {{0x39422529,0x291a252a,0x6efc01ed,0x1ae4010b}},	//   ssis_, _eusa_, sébe, _гонм, 
   {{0x291a252b,0x29100789,0x5614015b,0xfa540066}},	//   _fusa_, _eiza_, ার্ক_, _بردگ, 
   {{0x29180537,0x291081cb,0x8bd00046,0x14c80108}},	//   _gusa_, _fiza_, _وقۋش, лыки_, 
   {{0x2912252c,0x34b40500,0xa3c806e3,0x00000000}},	//   _giza_, юблё, _लेह_, --, 
   {{0x2918014b,0x8c18011a,0xd43400db,0x03a00114}},	//   _zusa_, נוקי, _ۇعاب, зијо, 
   {{0x2912252d,0x2918020c,0x6f1801d5,0x6e3d31fd}},	//   _ziza_, _yusa_, _ruvc, xasb, 
   {{0x636805f5,0xd9f80316,0x6e3c463e,0x29102d2f}},	//   грөг_, ्धित_, vasb, _yiza_, 
   {{0x6e3c0373,0x6f18047e,0xa3c800c5,0x044000f3}},	//   wasb, _puvc, _लेव_, _неун, 
   {{0x6f18ff51,0x6e3c017a,0x091c0154,0x00000000}},	//   _quvc, tasb, _পিছু_, --, 
   {{0xa3d405f9,0x13045476,0x629c01f4,0x00000000}},	//   सपर_, _узем, ösot, --, 
   {{0xacf80131,0x51f43346,0x00000000,0x00000000}},	//   инму_, _اسار, --, --, 
   {{0x291a252e,0x6284013f,0x6e3c01c4,0x6f18524f}},	//   _rusa_, _ɔhom, sasb, _tuvc, 
   {{0x291a252f,0xcf247874,0x29122530,0x6e3d4d1c}},	//   _susa_, _ارتي, _riza_, pasb, 
   {{0x291a2531,0x29101cdf,0xfaa40276,0x6e3c0009}},	//   _pusa_, _siza_, пшун, qasb, 
   {{0x3914010b,0x7b1801ec,0x0dc82218,0x00000000}},	// [3f130] змур, _қояр_, _щуки_, --, 
   {{0x29181682,0x291003b9,0x00000000,0x00000000}},	//   _vusa_, _qiza_, --, --, 
   {{0x2918020c,0x47884eb1,0x00000000,0x00000000}},	//   _wusa_, ысам_, --, --, 
   {{0x2918096b,0x2910010b,0x81e002f5,0x3af400c0}},	//   _tusa_, _wiza_, ফেট_, _няўс, 
   {{0x64a62532,0x291a2533,0x454844e4,0x29122534}},	//   жала, _uusa_, учем_, _tiza_, 
   {{0xfbd148ad,0x29062535,0xa5080798,0xc9840117}},	//   _آتی_, _òla_, шела_, _куҳи, 
   {{0xe29800c7,0x00000000,0x00000000,0x00000000}},	//   иак_, --, --, --, 
   {{0xc6a401c6,0xe1240353,0x0464010a,0x00000000}},	//   _урги, омии, _ӳтем, --, 
   {{0x69083306,0x00000000,0x00000000,0x00000000}},	//   _džev, --, --, --, 
   {{0xd12cc5f2,0x00000000,0x00000000,0x00000000}},	//   کمی_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2a680218,0xe4a401a9,0x9f040633,0xa19401f4}},	//   jfab_, _урғо, توجو, _маеч, 
   {{0x2a683ddd,0xdcf400dc,0x81e00154,0x86440092}},	//   dfab_, _asyā, ফেজ_, _የኮንት, 
   {{0x212c0ac5,0x00000000,0x00000000,0x00000000}},	//   mpeh_, --, --, --, 
   {{0xa06a2536,0x644c03f9,0x9cc80139,0x00000000}},	//   _баһа_, ɗait, гыңа_, --, 
   {{0xda7001d9,0x00000000,0x00000000,0x00000000}},	//   بُر_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3f140] --, --, --, --, 
   {{0x09022537,0xe51c0037,0x00000000,0x00000000}},	//   дпун, _पढ़ि_, --, --, 
   {{0x3990025a,0x6efe2538,0x2a6801d4,0xa3c8007d}},	//   _bösô_, léba, bfab_, _लेल_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3494024c,0x00000000,0x00000000,0x00000000}},	//   залр, --, --, --, 
   {{0xe97001ec,0x2a980092,0x00000000,0x00000000}},	//   _سۇمد, _መኪኖች_, --, --, 
   {{0x6efc6085,0x00000000,0x00000000,0x00000000}},	//   héba, --, --, --, 
   {{0x2aa40020,0x2bec05f9,0x660c0419,0x96b80452}},	//   _ወገኖች_, _आँसू_, ľakr, _тугу_, 
   {{0x893400df,0x00000000,0x00000000,0x00000000}},	//   ֿרטע_, --, --, --, 
   {{0x92c80f22,0xd0a8084c,0xc0e4007b,0xd0180107}},	//   লকে_, ртид_, يفين_, шфи_, 
   {{0xd2440fdc,0x6ef006be,0x00000000,0x00000000}},	//   _дэли, lıbə, --, --, 
   {{0x62840134,0x8778010f,0x00000000,0x00000000}},	//   _ɔhok, באטי, --, --, 
   {{0x11d400e5,0x00000000,0x00000000,0x00000000}},	//   _بتاد, --, --, --, 
   {{0x37c000cc,0x00000000,0x00000000,0x00000000}},	//   _এখনৰ, --, --, --, 
   {{0x8aa62539,0x425002dd,0xf40c00fe,0x0054011a}},	//   орад, _ءنۇر, _স্তৰ_, _ושות_, 
   {{0x6efc8616,0xdcac00f1,0xaee40055,0x2b4c1a48}},	//   béba, نډۍ_, _kuṭy, čec_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3f150] --, --, --, --, 
   {{0xb4e4012c,0x4788074d,0x00000000,0x00000000}},	//   फको_, исем_, --, --, 
   {{0xa3c8028a,0x8724f0a5,0x212c0810,0x24f801ec}},	//   _लें_, زعام, zpeh_, ұнды_, 
   {{0x36d40e92,0x00000000,0x00000000,0x00000000}},	//   мохр, --, --, --, 
   {{0x5a98011a,0x00000000,0x00000000,0x00000000}},	//   _השרא, --, --, --, 
   {{0x7d7c25f9,0xf4840640,0xe3b806a6,0x92c800fe}},	//   ינדו, дућн, йбл_, লকো_, 
   {{0x69080cf4,0x92c803d4,0xdb0c01bf,0x25b40205}},	//   _džet, লকৈ_, tzbø, _şalı_, 
   {{0xd36c7427,0x970004a9,0xe298016c,0x6efc0085}},	//   اهي_, _كېلى, саи_, yéba, 
   {{0xd12c7427,0x84640801,0x26cc009f,0x6ef00213}},	//   همي_, _мъже, _imeo_, cıbə, 
   {{0x25bc495b,0x00000000,0x00000000,0x00000000}},	//   ızlı_, --, --, --, 
   {{0xf1a868ff,0x212c14a6,0x00000000,0x00000000}},	//   مایه_, speh_, --, --, 
   {{0x248426cc,0x33580262,0x6efe253a,0x00000000}},	//   _halm_, _фацэ_, téba, --, 
   {{0x26cc009f,0x00000000,0x00000000,0x00000000}},	//   _mmeo_, --, --, --, 
   {{0x24840165,0x00000000,0x00000000,0x00000000}},	//   _jalm_, --, --, --, 
   {{0x26cc0170,0x995800a2,0x6efc003e,0x1ca402f2}},	//   _omeo_, _bäşe_, séba, قێکی_, 
   {{0xd00c007b,0xdb1c02d2,0x00000000,0x00000000}},	//   _حلى_, _óvíg, --, --, 
   {{0xa9c40014,0xa9700ca8,0x00000000,0x00000000}},	// [3f160] ٘زلو, _òdìè_, --, --, 
   {{0x26cd6851,0xd6f43517,0x00000000,0x00000000}},	//   _ameo_, ेष्ठ_, --, --, 
   {{0x63a40112,0x9b880035,0xdb8401d5,0xbd8801c8}},	//   ähnl, _انجل_, _эгни, _انڌن_, 
   {{0xcb980375,0xda581d39,0x69080153,0xd5b8004e}},	//   _הסטט, _урош_, _bžes, йсл_, 
   {{0x94a968e7,0xdbcc4a4a,0x00000000,0x00000000}},	//   йтка_, _bıça, --, --, 
   {{0x26cc0286,0x690a253b,0x636001f2,0x24842517}},	//   _emeo_, _džes, _ịnat, _calm_, 
   {{0x2ca6253c,0x24840a2e,0xc310015b,0x9958013d}},	//   öldi_, _dalm_, _সবজি_, _yäşe_, 
   {{0x629c023a,0xaee40055,0x00000000,0x00000000}},	//   ösop, _muṣy, --, --, 
   {{0x24840142,0x00000000,0x00000000,0x00000000}},	//   _falm_, --, --, --, 
   {{0x248401f5,0x690816a3,0xc0540a4a,0x935800c0}},	//   _galm_, _užet, пію_, _грду_, 
   {{0xa3c80dba,0x00000000,0x00000000,0x00000000}},	//   _लेऊ_, --, --, --, 
   {{0x24840d27,0x130800a8,0x7e281cd0,0xaee400b8}},	//   _zalm_, _уней_, зіра_, _tuṭy, 
   {{0x37c40154,0x00000000,0x00000000,0x00000000}},	//   ্থির, --, --, --, 
   {{0x8f440d1d,0x27800092,0x61fc05d2,0x00000000}},	//   _ехид, _የጋብቻ_, üsle, --, 
   {{0x92bc00fe,0x442806be,0xe7cc0150,0x00000000}},	//   ঁচী_, _əc_, _ﻓﻁﺎﻟ, --, 
   {{0x38a404cc,0xaee400cd,0x3fd8011a,0x00000000}},	//   _görz_, _duṣy, _לקוב, --, 
   {{0x6efc0098,0xa3c80037,0x00000000,0x00000000}},	// [3f170] lébo, _लेई_, --, --, 
   {{0x26cc17a3,0x00000000,0x00000000,0x00000000}},	//   _smeo_, --, --, --, 
   {{0xdd0007f5,0xdbcc25a8,0x00000000,0x00000000}},	//   _žućk, _rıça, --, --, 
   {{0xae001533,0xdbcc03e0,0xdc5400e5,0x42a40023}},	//   _ईरान_, _sıça, _ٹریک, ላኽነት_, 
   {{0xe9442c6c,0x690a253d,0x2484011a,0x6abc03ac}},	//   _ترجی, _džer, _palm_, _ilsf, 
   {{0x69080006,0xd5ac007b,0xbb480345,0x845000db}},	//   _ežer, شفى_, _بلێن_, رىعچ, 
   {{0x26cc005a,0xa2e401b9,0x24840108,0x5ef000cd}},	//   _tmeo_, мокд, _valm_, ीतम्_, 
   {{0xe50805d9,0x26cc009b,0xc6a43a49,0xf434009d}},	//   _ڀيرو_, _umeo_, _эрги, _үетэ, 
   {{0x2486253e,0x00000000,0x00000000,0x00000000}},	//   _talm_, --, --, --, 
   {{0x6afc025c,0x942400d1,0x38c80022,0x216400cf}},	//   _དེའོ_, _يوقۇ, mírõ_, птүг, 
   {{0xdee6253f,0x44240393,0x23b446e6,0x00000000}},	//   дони, mcn_, _تماس, --, 
   {{0xc255788e,0x9d44eee2,0x4e2407a5,0x00000000}},	//   _رخصت, мемд, моюн_, --, 
   {{0x62980e29,0x00000000,0x00000000,0x00000000}},	//   _inwo, --, --, --, 
   {{0x628a2540,0x6abd2aa7,0xaee400cd,0x44240200}},	//   ldeo, _alsf, _puṣy, ncn_, 
   {{0xbb500150,0x5ea4007b,0x00000000,0x00000000}},	//   _ﺎﻫﻲ_, _يمتل, --, --, 
   {{0x6289cbd9,0x9f04058a,0x44240051,0x00000000}},	//   ndeo, _توبو, hcn_, --, 
   {{0x20e03806,0x628801e7,0x5f7400f1,0xbd4400ec}},	// [3f180] _पदाध, ideo, _راګر, _ڪنڌي, 
   {{0x6abc0158,0x628817e3,0xaee400cd,0x00000000}},	//   _elsf, hdeo, _tuṣy, --, 
   {{0x9b04ce9e,0x629a2541,0x2c004cb2,0x4c9808c3}},	//   _озод, _onwo, _бүрм, _וביו, 
   {{0x6298013b,0x1a5800ae,0x00000000,0x00000000}},	//   _nnwo, _بشدة_, --, --, 
   {{0x62880368,0x1c2005f9,0x7e640208,0xb6440139}},	//   ddeo, _मलाल_, _mcip, _çümä, 
   {{0x6298013b,0x5724007b,0x932405af,0xc5900a5b}},	//   _anwo, _يرزق, وربن, тишј, 
   {{0xd7f000c6,0x88b001d5,0xd62802d5,0x6abc0334}},	//   _شكر_, _جیلچ, _мове_, _ylsf, 
   {{0x7e640921,0x628805ac,0x84340131,0xe0cc0154}},	//   _ncip, gdeo, ككۇر_, রকোন, 
   {{0x95840184,0x44262542,0xc0cc02d3,0x00000000}},	//   _юлае, bcn_, _ብሽም_, --, 
   {{0x629800a9,0x92bc015b,0x92dc009e,0x60c001ab}},	//   _enwo, ঁচে_, ণতে_, ghlm, 
   {{0x085406a9,0x7520009f,0xefd00023,0x3fc49c36}},	//   ובים_, _humz, _ብርዒ_, дыян_, 
   {{0x75222543,0x230801c8,0x00000000,0x00000000}},	//   _kumz, _فتني_, --, --, 
   {{0xac1800db,0x00000000,0x00000000,0x00000000}},	//   зогу_, --, --, --, 
   {{0x7520055a,0x7e662544,0x76400139,0x00000000}},	//   _mumz, _ecip, _lemy, --, 
   {{0xaed4014b,0x00000000,0x00000000,0x00000000}},	//   _покш, --, --, --, 
   {{0xbae4002b,0x00000000,0x00000000,0x00000000}},	//   _śīrṇ, --, --, --, 
   {{0x2d8400e2,0x00000000,0x00000000,0x00000000}},	// [3f190] āles_, --, --, --, 
   {{0x6d5c1d2b,0x7640003a,0x628801fa,0x00000000}},	//   musa, _aemy, zdeo, --, 
   {{0x69080989,0x6abc0204,0x76422545,0x00000000}},	//   _džep, _tlsf, _bemy, --, 
   {{0xf7705500,0x6b8407d6,0xa3c802ab,0xd0040137}},	//   شام_, _ishg, _लेग_, _ۅل_, 
   {{0x6d5e2546,0x00000000,0x00000000,0x00000000}},	//   nusa, --, --, --, 
   {{0xd0043695,0x6d5c0194,0xa6c81968,0xe364094e}},	//   _مل_, iusa, _کورل_, екки, 
   {{0xa3c86f64,0x6d5c9b94,0x76422547,0xd36c01f7}},	//   _लेख_, husa, _femy, مهو_, 
   {{0x53700451,0x38c800e4,0xf1d0000d,0x00000000}},	//   اهيء, pírõ_, _तेहन, --, 
   {{0x752000ec,0x35f4030d,0xe3ac00eb,0x00000000}},	//   _gumz, _аптр, _কেশব, --, 
   {{0x7e662548,0x6d5e2549,0x6b84aa24,0x7642254a}},	//   _scip, dusa, _oshg, _zemy, 
   {{0x31240228,0x6440005f,0x7642254b,0x75220362}},	//   ндөг, _ieli, _yemy, _zumz, 
   {{0x6d5e254c,0x6442254d,0x629a254e,0x7520037e}},	//   fusa, _heli, _unwo, _yumz, 
   {{0x6d5e254f,0x20d43334,0x6b862550,0x256800d7}},	//   gusa, _пікс, _ashg, núl_, 
   {{0x6441732e,0xdb8401b9,0x00000000,0x00000000}},	//   _jeli, нгги, --, --, 
   {{0x64422551,0x6d5e2552,0x3ea4007c,0x00000000}},	//   _meli, ausa, ömts_, --, 
   {{0x6440bbab,0x256820ab,0x00000000,0x00000000}},	//   _leli, kúl_, --, --, 
   {{0x6b8404fb,0x6d5e2553,0x764000c7,0x8d904d49}},	// [3f1a0] _eshg, cusa, _remy, _مليش, 
   {{0x64422554,0x75200007,0x76422555,0x2568007b}},	//   _neli, _rumz, _semy, dúl_, 
   {{0x76400022,0xace80592,0x00000000,0x00000000}},	//   _pemy, _تريل_, --, --, 
   {{0x64419311,0x752000ec,0x00000000,0x00000000}},	//   _aeli, _pumz, --, --, 
   {{0x64422556,0x25680548,0xdb0c01d3,0x00000000}},	//   _beli, gúl_, szbó, --, 
   {{0x64422557,0x76407294,0x06280023,0x00000000}},	//   _celi, _wemy, _ብዓይነ, --, 
   {{0x6d5e2558,0xb9cc0020,0x48e05191,0x76400790}},	//   zusa, _ደሞ_, _сорв, _temy, 
   {{0x6d5e2559,0x6441005c,0x7820033d,0x61f8015d}},	//   yusa, _eeli, _बलुक_, _bywl, 
   {{0x61440075,0xfcf8044e,0x5064a43c,0xb4840032}},	//   نىيە, ጋጊጹ_, нтна, _икаһ, 
   {{0x6442255a,0x6d5e255b,0xf4853d5d,0x61fc00c5}},	//   _geli, vusa, _جاری, üsla, 
   {{0x8248044e,0x3d9401f0,0x6728013a,0x00000000}},	//   _ሓበሬታ, ҳияр, _čejk, --, 
   {{0x6d5e255c,0xa3c802a0,0x00000000,0x00000000}},	//   tusa, _लेट_, --, --, 
   {{0x6442255d,0x6d5c0140,0x6efc0118,0x7de401ec}},	//   _yeli, uusa, lébk, гірд, 
   {{0x6442255e,0xfeb80150,0xa3c400a2,0x7c842b97}},	//   _xeli, _ۋايت_, _öōüs, лусе, 
   {{0x6d5e255f,0x6e00004b,0x00000000,0x00000000}},	//   susa, دېښن, --, --, 
   {{0x6d5d969a,0x00000000,0x00000000,0x00000000}},	//   pusa, --, --, --, 
   {{0x6d5d3d70,0xed580419,0x00000000,0x00000000}},	// [3f1b0] qusa, ážd_, --, --, 
   {{0xd24400b2,0x6d4c0194,0x63600521,0xe85400db}},	//   _ھن_, _ivaa, ịnih, ئناد, 
   {{0xd2452a5c,0x00000000,0x00000000,0x00000000}},	//   _پن_, --, --, --, 
   {{0x64422560,0x36940220,0x25687523,0x00000000}},	//   _seli, лшіс, túl_, --, 
   {{0xd124402b,0x64422561,0x09d800bd,0xe568085f}},	//   _خم_, _peli, _দরকা, филд_, 
   {{0x64422562,0x61f8015d,0x25680332,0x00000000}},	//   _qeli, _rywl, rúl_, --, 
   {{0x02cc00cd,0x00000000,0x00000000,0x00000000}},	//   तोऽभ, --, --, --, 
   {{0xd24c13f9,0xd3440345,0x00000000,0x00000000}},	//   قچه_, ئینه_, --, --, 
   {{0x64422563,0x97000075,0x6d4c1418,0x00000000}},	//   _teli, _ئېنى, _nvaa, --, 
   {{0x6e2e2564,0x64422565,0x00000000,0x00000000}},	//   _afab, _ueli, --, --, 
   {{0x60080b32,0x06280023,0x35780240,0x00000000}},	//   ьном_, _ብሓድነ, _ጽቡቓት_, --, 
   {{0x62362566,0x2f540108,0x00000000,0x00000000}},	//   _реду, ытьс, --, --, 
   {{0x0d8047c1,0xa069d94f,0xfe0c0d2e,0x00000000}},	//   алян, _жала_, सेंस_, --, 
   {{0x6e2c005a,0x6d4c2c2e,0x9f9401d5,0xd12c009a}},	//   _efab, _dvaa, _ашиш, _بمو_, 
   {{0xcb64798c,0x6d4e2567,0x6efc00d2,0x6e2e2568}},	//   каре_, _evaa, kébh, _ffab, 
   {{0xceb803f9,0x752401e4,0x00000000,0x00000000}},	//   _tuƙa_, ŭizi, --, --, 
   {{0xd0e400e5,0x00000000,0x00000000,0x00000000}},	// [3f1c0] _سکیم_, --, --, --, 
   {{0xed5804bf,0x6efc00dd,0x08c00816,0x00000000}},	//   áže_, yébk, абун, --, 
   {{0x6d4c0e8a,0x4cb800d9,0x00000000,0x00000000}},	//   _zvaa, _חזיו, --, --, 
   {{0xddc4007f,0x00000000,0x00000000,0x00000000}},	//   takň, --, --, --, 
   {{0x49c400ee,0x00000000,0x00000000,0x00000000}},	//   _алян_, --, --, --, 
   {{0x79840099,0xe3ac0183,0x738809a5,0x6ed801e4}},	//   mwiw, _কেইব, ериң_, nĉbr, 
   {{0x79862569,0xc7a198eb,0x00000000,0x00000000}},	//   lwiw, _кирк, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3f840113,0x7986256a,0xc2000022,0x00000000}},	//   _asnu_, nwiw, иџьи, --, 
   {{0x79840481,0xf5480521,0x70540424,0xc7ac00e5}},	//   iwiw, mụ_, دندا, _اڑے_, 
   {{0x7986256b,0xf54802e3,0xdc080165,0x96b42f0a}},	//   hwiw, lụ_, _ođđa, _अकाउ, 
   {{0x79840633,0x00000000,0x00000000,0x00000000}},	//   kwiw, --, --, --, 
   {{0xf54800b4,0x6e9402dd,0x00000000,0x00000000}},	//   nụ_, _ەلبا, --, --, 
   {{0xffd001d5,0x8014150e,0x00000000,0x00000000}},	//   اغید, عزیز_, --, --, 
   {{0xf54802e3,0x00000000,0x00000000,0x00000000}},	//   hụ_, --, --, --, 
   {{0x7ac40124,0x6e2c0472,0x6d4c00cd,0x6b880210}},	//   асуе, _ufab, _tvaa, łego, 
   {{0x79841c06,0x6d4c01f7,0x19c0151e,0x8d840117}},	// [3f1d0] gwiw, _uvaa, бәрг, _руйд, 
   {{0x2d8a256c,0xded01772,0xf54805db,0x6efc00d8}},	//   _isae_, _የማነ_, dụ_, débi, 
   {{0x2d9c0077,0xfd101e5a,0x0ec4012d,0x00000000}},	//   _áweb_, _بجي_, _लताड, --, 
   {{0x798401b2,0xf548063f,0xaaac02e5,0xc5b00137}},	//   bwiw, fụ_, _टकटक, ирлө, 
   {{0xf548063f,0xa5cc000d,0x6474008e,0x00000000}},	//   gụ_, _देखौ, гыйф, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9180004d,0x466a256d,0x00000000,0x00000000}},	//   yệt_, _орам_, --, --, 
   {{0x6efc02ea,0xf5480521,0x4660004b,0xa5f807a5}},	//   bébi, bụ_, _خپرې, _зебу_, 
   {{0x04640124,0xc0d0001f,0xe1f800cf,0xe194010b}},	//   _атем, _የቻለ_, эги_, урйэ, 
   {{0x3494013d,0xcfac00cc,0x00000000,0x00000000}},	//   _каур, _ছেইন, --, --, 
   {{0x2d88016b,0x7984c4b6,0x23b43037,0x00000000}},	//   _asae_, zwiw, _حماس, --, 
   {{0x074c0150,0x79840042,0x00000000,0x00000000}},	//   _ﺍﻋﯟ_, ywiw, --, --, 
   {{0xc29000e5,0x9f6400c7,0x00000000,0x00000000}},	//   _میںب, ñuâi_, --, --, 
   {{0xa068bbf1,0xc0d00092,0x00000000,0x00000000}},	//   _чака_, _የቻሉ_, --, --, 
   {{0x2d880156,0x3f840113,0xf54800b4,0x79840e14}},	//   _esae_, _usnu_, zụ_, wwiw, 
   {{0x9e6480df,0x6efc0085,0x09d80154,0x00000000}},	//   _свид, yébi, _দরজা, --, 
   {{0xad5805f5,0x1a05a8e5,0xaff401ed,0x2ab401bf}},	// [3f1e0] _ирэх_, упам, _مہیا_, _råbt_, 
   {{0x7986256e,0x3ea0032e,0x8bf000fe,0x00000000}},	//   rwiw, _hnit_, ছেইন_, --, 
   {{0x3ea2256f,0x79857e03,0x00000000,0x00000000}},	//   _knit_, swiw, --, --, 
   {{0xd6288ed7,0xf54800b4,0xd5480209,0x46240092}},	//   ходе_, tụ_, епде_, _ትናገራ, 
   {{0x3ea0020b,0xded00092,0x3b0003b9,0x00000000}},	//   _mnit_, _የኛን_, mliq_, --, 
   {{0x7ae62570,0x3b003870,0xf5480521,0x6efc06af}},	//   lnit, lliq_, rụ_, rébi, 
   {{0x7ae40037,0x6efcc17e,0x4805b3b1,0x00000000}},	//   onit, sébi, _берн_, --, 
   {{0x7ae62571,0xd13a2572,0xf54800b4,0x925800f2}},	//   nnit, нхо_, pụ_, رشعر_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7ae62573,0x970004a9,0x3ea22574,0x3d00033f}},	//   hnit, _ئېچى, _anit_, ोगों_, 
   {{0x7ae4084f,0x00000000,0x00000000,0x00000000}},	//   knit, --, --, --, 
   {{0x7ae46f10,0x70562575,0xd1640395,0x00000000}},	//   jnit, دنگا, _бъки, --, 
   {{0x7ae62576,0x3b0000ac,0x3ea00798,0xc21401af}},	//   dnit, dliq_, _dnit_, _йєш_, 
   {{0x7ae4299a,0xe1f00014,0xe3b001d3,0x4030010a}},	//   enit, _بسٔ_, _ارے_, _лешс, 
   {{0x7ae62577,0xf0e800f7,0x00000000,0x00000000}},	//   fnit, _كىچى_, --, --, 
   {{0x7ae53f5c,0x3ea007c5,0x3b002f3b,0x00000000}},	//   gnit, _gnit_, gliq_, --, 
   {{0xfe7021ec,0x6f0caf78,0x2d88003a,0xc278010f}},	// [3f1f0] _ردي_, _ihac, _usae_, ערמי, 
   {{0x7ae62578,0x387800a3,0x8c662579,0xfd540055}},	//   anit, _cbrr_, _стид, _nmeṣ, 
   {{0x7ae6257a,0x6f0e257b,0x3b000109,0x1ee81bf4}},	//   bnit, _khac, bliq_, _سویی_, 
   {{0x6d5e257c,0xaa9402bf,0x38780139,0x62040213}},	//   orsa, _тимч, _ebrr_, şrlə, 
   {{0xe5a6257d,0x6f0c35ab,0xe5840032,0x6aad2c34}},	//   рили, _mhac, ртеү, mjaf, 
   {{0x6d5c89dd,0x6aac03b2,0x00000000,0x00000000}},	//   irsa, ljaf, --, --, 
   {{0x6d5c0e78,0x00000000,0x00000000,0x00000000}},	//   hrsa, --, --, --, 
   {{0x29001f21,0xe2980364,0x6d5c1505,0xa53407d8}},	//   llha_, таи_, krsa, _внач, 
   {{0x2a780ac5,0x52a400c9,0x6aae257e,0x20c45e5a}},	//   _mbsb_, рвым_, ijaf, ийим, 
   {{0x6f0c0223,0x3ea1cf86,0x6aac026c,0x660a257f}},	//   _ahac, _snit_, hjaf, _izek, 
   {{0xfe784e90,0x6d5e2580,0x7ae62581,0x6f0e2582}},	//   гүй_, ersa, ynit, _bhac, 
   {{0x62240058,0x61d81064,0x6608005a,0x6aac0a49}},	//   _ئىشل, _имея_, _kzek, jjaf, 
   {{0x6f0e2583,0x6144b7f5,0x690a2584,0x7ae62585}},	//   _dhac, _тела, _džez, vnit, 
   {{0x1d0830af,0x66084b2a,0x69cc030a,0x720400f1}},	//   теги_, _mzek, dzae, _اوهم, 
   {{0x6d5e2586,0x6f0c4695,0x290002c4,0xabc401e0}},	//   arsa, _fhac, dlha_, барҙ, 
   {{0x6609e6d1,0x6f0c0842,0x7ae62587,0x3ea02d58}},	//   _ozek, _ghac, unit, _unit_, 
   {{0x7f400097,0x7ae62588,0x20c800c6,0x1988016c}},	// [3f200] _hwnq, rnit, _cúig_, ъбаи_, 
   {{0x3b006064,0x00000000,0x00000000,0x00000000}},	//   sliq_, --, --, --, 
   {{0x660a2589,0xd7ca258a,0x7ae4238f,0x7ae8004b}},	//   _azek, خواه_, pnit, _مودې_, 
   {{0x29000561,0x8d9001b9,0xddc400b0,0x7ae6258b}},	//   alha_, _الیش, hakō, qnit, 
   {{0x660a258c,0xddc41f1b,0x2900015d,0x57a401e0}},	//   _czek, kakō, blha_, ышҡа, 
   {{0xd378006c,0x660805b8,0x00000000,0x00000000}},	//   вчи_, _dzek, --, --, 
   {{0x660a258d,0x244801c8,0x00000000,0x00000000}},	//   _ezek, اجهي_, --, --, 
   {{0x657000e5,0x35c4014b,0x00000000,0x00000000}},	//   ékhá, _лабҳ, --, --, 
   {{0xef100228,0x3cfa258e,0x6f0c0142,0x00000000}},	//   үүлө, korv_, _rhac, --, 
   {{0x6d5c08ad,0x6f0c1e15,0x0440014b,0x00000000}},	//   vrsa, _shac, _меун, --, 
   {{0x69ce258f,0x22480161,0x6f0e2590,0x6e962591}},	//   zzae, _ŵake_, _phac, бину, 
   {{0x6f0c0309,0xe8d802e3,0x5178010a,0x9f640022}},	//   _qhac, trị_, _аскă, ñuái_, 
   {{0x68e40208,0x20c401e0,0x6e3c002f,0x8714010f}},	//   ynhd, рсөг, rbsb, יקטע_, 
   {{0x6f0c1590,0x6d5e2592,0xd7c40073,0x6da400c7}},	//   _whac, rrsa, लनाच, аиҭа, 
   {{0x6f0c9883,0xaa5a2593,0x31e8015b,0xe8d80521}},	//   _thac, ливу_, _পরিশ, nwụ_, 
   {{0x6f0c00ca,0xba740228,0x69cc005a,0xfaa4fb0f}},	//   _uhac, ياقت, tzae, ошун, 
   {{0x29022594,0x0dc82097,0x3164010a,0xc984036b}},	// [3f210] tlha_, _шуки_, numz_, шуви, 
   {{0xe8d802e3,0x66080034,0x6aac01a8,0x6efc003e}},	//   kwụ_, _rzek, sjaf, rébu, 
   {{0x660801ed,0xddd400ee,0x6efc00f2,0xab94007b}},	//   _szek, _adyň, sébu, _الجغ, 
   {{0x9d500133,0xf1b80303,0x7d240066,0x00000000}},	//   _بچێت, ेनान, _دفین, --, 
   {{0x25d80387,0x85542304,0x05846ac5,0xd5ac0050}},	//   ымды_, شیار_, руем, ٹہٕ_, 
   {{0x31640369,0xdc340139,0x2a680037,0x05d801f9}},	//   dumz_, _mäğf, lgab_, _मेणब, 
   {{0xe8d802e3,0xc6a62595,0x99540432,0x80ac00eb}},	//   gwụ_, _краи, _küşt_, টসম্, 
   {{0xd24c37f8,0x2a6803a2,0x660801c6,0x00000000}},	//   ىنى_, ngab_, _tzek, --, 
   {{0x26de2596,0xddc402b1,0x00000000,0x00000000}},	//   miwo_, takō, --, --, 
   {{0x26dc2f99,0x1f64010a,0xd0981954,0x00000000}},	//   liwo_, бком, _ገበርኩ_, --, 
   {{0x34962597,0x8ca829d9,0xddc400b0,0xe374004e}},	//   _фахр, ञानो, rakō, _ылжы, 
   {{0x26ddf977,0xf1a8168d,0xb3c8009d,0x00000000}},	//   niwo_, _چاوه_, _тууж_, --, 
   {{0xf1a8168d,0xdcf400b8,0x3cfa2098,0xdc34013d}},	//   _ناوه_, _apyā, torv_, _cäğf, 
   {{0x26dcb00f,0x224e2598,0x00000000,0x00000000}},	//   hiwo_, laek_, --, --, 
   {{0xfe780447,0x26dc0e16,0x2a6804e6,0xdea002f2}},	//   _күн_, kiwo_, fgab_, _فیدی, 
   {{0x224c092c,0x26dc0066,0x31e803d4,0xe0600244}},	//   naek_, jiwo_, _পৰিশ, _بێگی, 
   {{0x26de2599,0x3cf80158,0xfe040014,0xd65c01ec}},	// [3f220] diwo_, porv_, _گژھُ, рiнд, 
   {{0x224c030a,0x60c0007f,0x38c84d4e,0x31d40154}},	//   haek_, nklm, جاری_, _হুঁশ, 
   {{0x2c000220,0x224c030a,0x2a68552a,0x31e800fe}},	//   _жүрм, kaek_, bgab_, _পৰাশ, 
   {{0x6efe259a,0x26dc00d2,0xdc340139,0x69d8012d}},	//   lébr, giwo_, _yäğf, _नेवी, 
   {{0x224caf4c,0xd5580114,0x983400c0,0x00000000}},	//   daek_, ујеш_, _гэбі, --, 
   {{0xab7401d9,0x6efc06af,0x16a8010b,0x60c00175}},	//   _دۅہا_, nébr, _өвги_, jklm, 
   {{0x212c011f,0x26dc004b,0xf1d0000d,0x00000000}},	//   eqeh_, biwo_, _तेजन, --, 
   {{0x224ceccf,0x92683d2a,0x00000000,0x00000000}},	//   gaek_, урка_, --, --, 
   {{0x104a259b,0x00000000,0x00000000,0x00000000}},	//   ляни_, --, --, --, 
   {{0xfbc8d8a4,0x31640007,0x661c0306,0x6efc003e}},	//   रनाम, rumz_, _úska, jébr, 
   {{0x224c0007,0x41700050,0x03a021f3,0x60dc0100}},	//   baek_, _ہاوس, _нифо, èsma, 
   {{0xceb80198,0x490c0dad,0x81402c26,0x51840006}},	//   _kuƙi_, _तीनो_, _کنون, _гука, 
   {{0x41e01cd0,0xc27801e4,0x00000000,0x00000000}},	//   _ніша, _תרדי, --, --, 
   {{0x26dc02ce,0x6efcb4a2,0x00000000,0x00000000}},	//   ziwo_, gébr, --, --, 
   {{0x26de259c,0x2a68020b,0x4ae800c7,0x00000000}},	//   yiwo_, tgab_, гьам_, --, 
   {{0x7f38008f,0x8334010f,0x00000000,0x00000000}},	//   _געהו, מאלס_, --, --, 
   {{0x2a6a259d,0x26dc00aa,0x0c8401af,0x00000000}},	// [3f230] rgab_, viwo_, _лынм, --, 
   {{0x26dc0069,0x61f400ee,0x2a6801c7,0xaf3c0092}},	//   wiwo_, _ýalň, sgab_, _የተሰወ, 
   {{0xa6543306,0x26dcbc2e,0x224c030a,0x3e200023}},	//   قَات, tiwo_, yaek_, ተዘይከ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x26de259e,0xec1400db,0x00000000,0x00000000}},	//   riwo_, _دوگد, --, --, 
   {{0x2336259f,0x26de25a0,0xe358036b,0x67d625a1}},	//   охир, siwo_, ашиш_, _догу, 
   {{0xd36c05d4,0x212c011f,0x224c05c7,0x26dc033b}},	//   نهو_, wqeh_, taek_, piwo_, 
   {{0x7bdc00df,0x00000000,0x00000000,0x00000000}},	//   טקוו, --, --, --, 
   {{0x224e25a2,0x00000000,0x00000000,0x00000000}},	//   raek_, --, --, --, 
   {{0xe0da25a3,0x2d980219,0x6efc0077,0x224c0165}},	//   рво_, dvse_, xébr, saek_, 
   {{0x03c59a5a,0x00000000,0x00000000,0x00000000}},	//   _усам, --, --, --, 
   {{0x6e2800bc,0x00000000,0x00000000,0x00000000}},	//   žebn, --, --, --, 
   {{0x61ec08a4,0x212c011f,0x98a00055,0x9a780092}},	//   _žalf, qqeh_, _lukā_, _ብሎኛል_, 
   {{0xdb0c02d2,0x00000000,0x00000000,0x00000000}},	//   _íjún, --, --, --, 
   {{0x6efc004a,0x00000000,0x00000000,0x00000000}},	//   rébr, --, --, --, 
   {{0xd00c0137,0xf15003e6,0x6efc003e,0x00000000}},	//   _جلى_, _تێید, sébr, --, 
   {{0xfbd800cc,0x00000000,0x00000000,0x00000000}},	// [3f240] _দুশত, --, --, --, 
   {{0xc0d40023,0x27ec0055,0x00000000,0x00000000}},	//   ርበሉ_, _śena_, --, --, 
   {{0x562a25a4,0xe81401f9,0x00000000,0x00000000}},	//   ажем_, थेला_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x94a9f68c,0xf314009d,0x00000000,0x00000000}},	//   итка_, үдлэ, --, --, 
   {{0xb4d40210,0x00000000,0x00000000,0x00000000}},	//   हफे_, --, --, --, 
   {{0xe7e00037,0x80dc0051,0x59dc00cd,0x00000000}},	//   _गइया_, _đựợc_, _नेतर, --, 
   {{0xceb80198,0xfbe801fb,0x66d000d7,0x00000000}},	//   _tuƙi_, _đề_, sťkr, --, 
   {{0xcb104645,0xd4680414,0x00000000,0x00000000}},	//   ולה_, _визе_, --, --, 
   {{0xcf981fbe,0x2030069d,0x00000000,0x00000000}},	//   ајм_, _አበርክ, --, --, 
   {{0xc20c0014,0xd3441e4b,0x00000000,0x00000000}},	//   _یٔم_, _بیعه_, --, --, 
   {{0x7c2816a3,0x43400354,0x00000000,0x00000000}},	//   ždrl, _цецв, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x61ec02d5,0x00000000,0x00000000,0x00000000}},	//   _žalg, --, --, --, 
   {{0x80a0b261,0x00000000,0x00000000,0x00000000}},	//   _زمين, --, --, --, 
   {{0x8d84dd6b,0x00000000,0x00000000,0x00000000}},	//   _дуод, --, --, --, 
   {{0x59dc202e,0xa2cc00dc,0xeb9835e3,0xa9c000f7}},	// [3f250] _नेदर, _ततस्, шиң_, رۅسۉ, 
   {{0x98a002b5,0x6ad40327,0x39140024,0x00000000}},	//   _pukā_, ུྃཿཨ, дмур, --, 
   {{0x602c01ed,0xe1f800e1,0xda6400f1,0xa2cc0b98}},	//   _hőmé, _ूर्ण_, _کاپي, तसम्, 
   {{0xf7700075,0xf6d404fb,0x4e0c012c,0x8ae400d4}},	//   ئال_, وزند, _सराई_, _фіол, 
   {{0x1a9800df,0x00000000,0x00000000,0x00000000}},	//   _פישע, --, --, --, 
   {{0x2904041e,0x19b8011a,0x23283b9e,0x00000000}},	//   _óla_, _המשב, боки_, --, 
   {{0x60cc03a2,0xc6e40212,0x4abc145f,0xd46422c3}},	//   _ïami, _діап, _एकाव, чище_, 
   {{0x05840117,0x00000000,0x00000000,0x00000000}},	//   _музм, --, --, --, 
   {{0x2138044e,0x60dc0100,0x20d800cd,0xd2600139}},	//   ësh_, èsmo, योऽध, хкый, 
   {{0xa0680063,0xf364008e,0x00000000,0x00000000}},	//   љана_, чтән, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xefd4001f,0x00000000,0x00000000,0x00000000}},	//   _የያዘ_, --, --, --, 
   {{0xb7ec0183,0x21a401d5,0x00000000,0x00000000}},	//   _কৰাত_, _хилм, --, --, 
   {{0x5f741e95,0x40841b6b,0x91380302,0x6288022f}},	//   _فابر, _фудб, _העסק, leeo, 
   {{0xe4780092,0xda580354,0x00000000,0x00000000}},	//   _የኬንያ_, йраш_, --, --, 
   {{0x8b2225a5,0x00000000,0x00000000,0x00000000}},	//   едсе, --, --, --, 
   {{0x57e800fd,0x05d80c5a,0xefd40092,0xfd58002b}},	// [3f260] әдем_, _मेलब, _የያዙ_, _ntaḥ, 
   {{0x09000063,0x00000000,0x00000000,0x00000000}},	//   епун, --, --, --, 
   {{0xfd5800b8,0xbb7401ec,0x3a28013d,0x3cf8000d}},	//   _ataḥ, _تۇزع, _менү_, ंकीं_, 
   {{0xd7080108,0x00000000,0x00000000,0x00000000}},	//   щнее_, --, --, --, 
   {{0x86203c85,0x8500004b,0x628800ad,0xaac800bc}},	//   ньше, کوون, deeo, रसरक, 
   {{0x394225a6,0x24b80451,0x00000000,0x00000000}},	//   mpis_, يننگ_, --, --, 
   {{0x394225a7,0xa2cc00cd,0x00000000,0x00000000}},	//   lpis_, _ततश्, --, --, 
   {{0x3940003a,0x00000000,0x00000000,0x00000000}},	//   opis_, --, --, --, 
   {{0x39400bf1,0x26c0016b,0x00000000,0x00000000}},	//   npis_, ɔho_, --, --, 
   {{0xaf3c0020,0x00000000,0x00000000,0x00000000}},	//   _የተለወ, --, --, --, 
   {{0xb4e80574,0xc438011a,0x3014c1ca,0x95c801af}},	//   मची_, _התבי, ьдор, _туңа_, 
   {{0x39400309,0x61ec0427,0xb91400b8,0x00000000}},	//   kpis_, _žale, _evaḿ_, --, 
   {{0x394225a8,0x3de0015b,0x02c00108,0x00000000}},	//   jpis_, _যুবল, _яйцо, --, 
   {{0xc36c0cf9,0x01340bd9,0x7d240139,0x00000000}},	//   _b형h_, _צרות_, ефсе, --, 
   {{0x8078011a,0x00000000,0x00000000,0x00000000}},	//   _הנוצ, --, --, --, 
   {{0x59dc1b87,0xf1b00490,0xdb0c0ca8,0x7e44030d}},	//   _नेहर, _जपान, _ìjìn, _пхье, 
   {{0x3940079b,0x05d8447d,0x20c80332,0xdb1001e7}},	// [3f270] gpis_, _मेंब, _múin_, úgái, 
   {{0x20c802d2,0x00000000,0x00000000,0x00000000}},	//   _lúin_, --, --, --, 
   {{0xac180816,0x00000000,0x00000000,0x00000000}},	//   _фону_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x24f81ac1,0xa4d402bf,0x00000000,0x00000000}},	//   онды_, моді, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x20c8008c,0x00000000,0x00000000,0x00000000}},	//   _búin_, --, --, --, 
   {{0x203c001f,0xf1c801f9,0x00000000,0x00000000}},	//   _የበላይ, ाईंन, --, --, 
   {{0x61ec098d,0x20c800ae,0xded00023,0x5f44004b}},	//   _žalb, _dúin_, _ከማኻ_, ژندل, 
   {{0x629c01a2,0x24180eed,0x0584014b,0x00000000}},	//   ôsob, _дозы_, _муҷм, --, 
   {{0x3940389c,0x82340a8e,0xf00000d1,0xcf40e017}},	//   zpis_, _فرشا, лүши, кнэй, 
   {{0x39419d86,0xe5a40241,0x93f8011a,0x4270010a}},	//   ypis_, _àkọ́, _ולעי, _чӳкс, 
   {{0x6b840857,0xc1e00150,0xb91400b8,0x00000000}},	//   _aphg, _سۋدي, _tvaḿ_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x26ce25a9,0x1a640214,0x39400986,0x2d840356}},	//   _oleo_, ویدی_, wpis_, ălea_, 
   {{0x3940098d,0x69d8007d,0x00000000,0x00000000}},	//   tpis_, _नइखी, --, --, 
   {{0x09e0114b,0x57c4007d,0xb1300023,0x4adc024a}},	// [3f280] вотн, लन्ह, _ተባዕታ, _नगरव, 
   {{0x394225aa,0x26cc0851,0x00000000,0x00000000}},	//   rpis_, _aleo_, --, --, 
   {{0x394225ab,0x26cc8f78,0x00000000,0x00000000}},	//   spis_, _bleo_, --, --, 
   {{0x39402bf2,0xddd401ef,0x00000000,0x00000000}},	//   ppis_, _zbyš, --, --, 
   {{0x7ae625ac,0x20c8007b,0x39400bf1,0x98a00153}},	//   miit, _rúin_, qpis_, _auką_, 
   {{0x7ae58b71,0x26cc0618,0xb4e80574,0xed580122}},	//   liit, _eleo_, मचे_, áži_, 
   {{0x26cc2622,0x213c003e,0x657802d0,0x136800d4}},	//   _fleo_, _atwh_, atwh, ішки_, 
   {{0x7ae625ad,0xdce40122,0x78bc089e,0x26cdd34b}},	//   niit, dukč, _horv, _gleo_, 
   {{0x78be25ae,0x00000000,0x00000000,0x00000000}},	//   _korv, --, --, --, 
   {{0x7ae625af,0x814035cd,0x3cf8033f,0x61ec0427}},	//   hiit, کنین, ंकों_, _žalc, 
   {{0x20c80597,0x78be25b0,0x7ae625b1,0xb60801ef}},	//   _iúil_, _morv, kiit, _dršť, 
   {{0x7ae52755,0x75280b94,0x2368188d,0x329401d9}},	//   jiit, _hidz, _رحمي_, _سٔتر, 
   {{0x7ae625b2,0x78bc0660,0x3b000007,0xf79402d3}},	//   diit, _oorv, doiq_, _ዘጋጠመ_, 
   {{0x7c8625b3,0x00000000,0x00000000,0x00000000}},	//   кусе, --, --, --, 
   {{0x752a03d0,0x7ae625b4,0x00000000,0x00000000}},	//   _midz, fiit, --, --, 
   {{0x752a25b5,0x7ae40eda,0x20c80332,0x00000000}},	//   _lidz, giit, _lúil_, --, 
   {{0x6e2c3b02,0xfe7006f6,0x6f1c17da,0xdcec00e2}},	// [3f290] _igab, _ضدي_, mmsc, žkār, 
   {{0x752a25b6,0x7ae40433,0x6d4c0248,0xbd880214}},	//   _nidz, aiit, _iwaa, _کنین_, 
   {{0x6e2cd4fa,0x6d4c006f,0x78bc6fca,0xd24405d9}},	//   _kgab, _hwaa, _dorv, _ٽن_, 
   {{0x6d4e25b7,0xe70411fc,0x7528006f,0x7ae625b8}},	//   _kwaa, رسای, _aidz, ciit, 
   {{0x78bc7a1e,0x752a25b9,0x6e2c6e90,0x2d4c02fd}},	//   _forv, _bidz, _mgab, nže_, 
   {{0x6d4e25ba,0x78bd2bbe,0x65780810,0x20c8007b}},	//   _mwaa, _gorv, rtwh, _cúil_, 
   {{0x290225bb,0x6d4c0a49,0x65784b10,0x20c8007b}},	//   moha_, _lwaa, stwh, _dúil_, 
   {{0x290225bc,0x2d4c0e96,0x26cc0607,0x6d4c0337}},	//   loha_, kže_, _uleo_, _owaa, 
   {{0x6abe25bd,0x6d4c0521,0x339800b7,0x057400cf}},	//   _mosf, _nwaa, መሰረተ_, _تازد, 
   {{0x2d4e25be,0x290225bf,0x6e2e25c0,0x660a25c1}},	//   dže_, noha_, _agab, _iyek, 
   {{0x7ae625c2,0xd438001f,0x660a25c3,0xdee400d8}},	//   yiit, ዮጵያዊ, _hyek, еони, 
   {{0x6e2c02c4,0x660a25c4,0x7528055a,0x6d4dcc8f}},	//   _cgab, _kyek, _zidz, _bwaa, 
   {{0x6728006d,0x7ae625c5,0x290225c6,0x6608003e}},	//   _miej, viit, koha_, _jyek, 
   {{0x6d4c0385,0x6f1e25c7,0x629a25c8,0x672a25c9}},	//   _dwaa, amsc, _hawo, _liej, 
   {{0xdee4fd21,0x7ae625ca,0x6d4c0a49,0x66081418}},	//   _поки, tiit, _ewaa, _lyek, 
   {{0x78be25cb,0x67283f8e,0x660a25cc,0x6abe25cd}},	//   _sorv, _niej, _oyek, _cosf, 
   {{0x660a25ce,0xdca609ca,0x7ae625cf,0x629a25d0}},	// [3f2a0] _nyek, _запи, riit, _mawo, 
   {{0x7ae625d1,0x629a25d2,0x2900009f,0x00000000}},	//   siit, _lawo, goha_, --, 
   {{0x660805bb,0x6d4c0936,0x752a25d3,0x67280af9}},	//   _ayek, _zwaa, _ridz, _biej, 
   {{0x629a25d4,0x20c80597,0x66080337,0x752a25d5}},	//   _nawo, _súil_, _byek, _sidz, 
   {{0x290225d6,0x67290f30,0xeac00150,0x00000000}},	//   boha_, _diej, _тұтп, --, 
   {{0x66081efb,0xd6d8107f,0x629a2216,0x68e401ab}},	//   _dyek, _کورش_, _aawo, cihd, 
   {{0x629a25d7,0x6608b23d,0x7528005f,0x80c0012c}},	//   _bawo, _eyek, _vidz, ाउने, 
   {{0x7528068f,0x629a25d8,0x6e28107d,0x877805d0}},	//   _widz, _cawo, žebi, _מאלי, 
   {{0x629a25d9,0x752a25da,0x66080337,0xc23c037e}},	//   _dawo, _tidz, _gyek, _mm用_, 
   {{0x6e2e25db,0x6d4c006f,0x6729b49e,0x2d4c0427}},	//   _sgab, _rwaa, _ziej, vže_, 
   {{0x629a25dc,0x6d4c0151,0xaed40107,0x6f1c02d0}},	//   _fawo, _swaa, вонш, tmsc, 
   {{0x6d4c019f,0x629a25dd,0x6f1c002f,0x00000000}},	//   _pwaa, _gawo, umsc, --, 
   {{0x290225de,0x6f1c4431,0xc6900a7c,0x66f40064}},	//   yoha_, rmsc, נאש_, nąka, 
   {{0x2d4c1505,0x629a25df,0x6abcfb9b,0xac1800f7}},	//   rže_, _zawo, _sosf, догу_, 
   {{0x629a25e0,0x6abc0393,0x290225e1,0x2ef402e8}},	//   _yawo, _posf, voha_, _изкр, 
   {{0x6e2e25e2,0x6d4e25e3,0x2900089c,0xc23c037e}},	//   _ugab, _twaa, woha_, _cm用_, 
   {{0x290225e4,0xfe70a482,0x68e405d1,0x66f40064}},	// [3f2b0] toha_, _ادى_, tihd, jąka, 
   {{0xe4e403f8,0x67283ee4,0x66080083,0xed580f91}},	//   _औषधि_, _siej, _ryek, ážu_, 
   {{0x66080263,0x69c000ac,0x672800de,0x68e42a89}},	//   _syek, _əley, _piej, rihd, 
   {{0xb8c81fe5,0x870625e5,0xdce4166a,0x290225e6}},	//   _खो_, ربال, mukā, soha_, 
   {{0x672a25e7,0xd00625e8,0x629a25e9,0x76440784}},	//   _viej, _چل_, _rawo, ñiya, 
   {{0x629a25ea,0x2d880134,0x290001ee,0x6608009f}},	//   _sawo, _mpae_, qoha_, _vyek, 
   {{0x629a25eb,0x672a25ec,0xf8f40006,0x6608012d}},	//   _pawo, _tiej, _спрэ, _wyek, 
   {{0x2d880421,0x66082c92,0x00000000,0x00000000}},	//   _opae_, _tyek, --, --, 
   {{0x36d405cc,0x66080028,0xe53411ed,0x6298004c}},	//   _сотр, _uyek, _резь, _vawo, 
   {{0x629a25ed,0xb6040276,0x00000000,0x00000000}},	//   _wawo, _сяск, --, --, 
   {{0x629a25ee,0x2d899895,0xe81401f9,0x00000000}},	//   _tawo, _apae_, थेचा_, --, 
   {{0xdee51d84,0x00000000,0x00000000,0x00000000}},	//   томи, --, --, --, 
   {{0x2e5801c6,0xdb0c012d,0x00000000,0x00000000}},	//   эшээ_, zybó, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe7e005ba,0x5ef80364,0xfd500208,0x00000000}},	//   _गेला_, _охир_, nnhạ, --, 
   {{0x9f040137,0xaadc01f9,0x00000000,0x00000000}},	//   _جوبو, नोलक, --, --, 
   {{0x0eac02ab,0x8b2017b4,0x20c4000d,0x00000000}},	// [3f2c0] टारड, рдте, _लकाध, --, 
   {{0xdce400b8,0x00000000,0x00000000,0x00000000}},	//   bukā, --, --, --, 
   {{0xc00c01fb,0x9b4400e5,0xf03c0092,0xda64010a}},	//   _đuối_, _جنجو, _የቱሪዝ, _ивни, 
   {{0xd5e800e5,0x00000000,0x00000000,0x00000000}},	//   وٹان_, --, --, --, 
   {{0x61ece126,0x00000000,0x00000000,0x00000000}},	//   _žaln, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x48e01c56,0x065000db,0x73340137,0x00000000}},	//   _торв, انۇح, دىبا, --, 
   {{0x82a00124,0xd1384ae5,0xc6240154,0x38ac0241}},	//   ашье, мхо_, মড়া_, bórà_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9344c6a5,0x94a80014,0xd1e000b7,0x6fb800d8}},	//   _анже, _تارِ_, ምነቱ_, егор_, 
   {{0x08540302,0xe61001d3,0xd3340153,0x00000000}},	//   כבים_, _نشے_, _рэзы, --, 
   {{0xdce400da,0x2b40009a,0x42e4023a,0x00000000}},	//   vukā, _rthc_, _имхо_, --, 
   {{0xc6900a1e,0x6838032e,0x00000000,0x00000000}},	//   באר_, _júdó, --, --, 
   {{0x7eb8145e,0xc0e01999,0x00000000,0x00000000}},	//   _pûpû, _кочк, --, --, 
   {{0x9db407d6,0xddd400a2,0x28c421e2,0x00000000}},	//   نگیز_, _adyń, қшаҳ, --, 
   {{0x3b700092,0x8ca009ab,0x00000000,0x00000000}},	//   ስቲዎች_, _छोरो, --, --, 
   {{0xb33c025c,0x7c3c007f,0xf990007b,0x7ae80100}},	// [3f2d0] _orħo, bcrr, يبك_, èdta, 
   {{0xe85442c6,0x6d5c0c8c,0x2b40004d,0x0ba802dd}},	//   اناد, mssa, _tthc_, _قاجى_, 
   {{0x6d5c0c8c,0x05d8033f,0x00000000,0x00000000}},	//   lssa, _मेजब, --, --, 
   {{0x24841f29,0x4f900023,0x6e3c00e5,0x6d5c01f4}},	//   _sblm_, _ዜጋታታ_, ncsb, ossa, 
   {{0x6d5e25ef,0x3cfa25f0,0xe8d80521,0x81e40154}},	//   nssa, _سعید_, nsị_, _মুন_, 
   {{0x6d5e25f1,0x660c0210,0x00000000,0x00000000}},	//   issa, żako, --, --, 
   {{0x67d4edc4,0x6d5c02d0,0x00000000,0x00000000}},	//   _сову, hssa, --, --, 
   {{0x6d5ce6dd,0xd3440dc3,0xe8d801f2,0x00000000}},	//   kssa, اینه_, ksị_, --, 
   {{0xb6e625f2,0x00000000,0x00000000,0x00000000}},	//   _тюрк, --, --, --, 
   {{0x6d5e25f3,0xff40001f,0x00000000,0x00000000}},	//   dssa, _የተለመ, --, --, 
   {{0x6d5e25f4,0x6734022e,0x0fc8012d,0x3394014b}},	//   essa, _juzj, ानगढ, _вахё, 
   {{0x9d4594f3,0x67341050,0x62340261,0xaf3c0092}},	//   лемд, _muzj, _седу, _የደመወ, 
   {{0x6d5e25f5,0xa0691df5,0x6d48084c,0x0d807e25}},	//   gssa, _зала_, ţean, блян, 
   {{0x51580302,0x66f4012d,0xf17c00d1,0x00000000}},	//   _טכנו, kąko, _ﻣﻪﻣﯘ, --, 
   {{0x6d5c0680,0x8c4225f6,0xe8d802e3,0x92880241}},	//   assa, сесе, asị_, _àṣày, 
   {{0xd00cbd0e,0x6d5c00b5,0x3a44013e,0x95880023}},	//   _علي_, bssa, рмаҳ, _መግብን_, 
   {{0x7e6625f7,0x6d5c7cf7,0x00000000,0x00000000}},	// [3f2e0] _idip, cssa, --, --, 
   {{0xe84856a7,0x00000000,0x00000000,0x00000000}},	//   نجمن_, --, --, --, 
   {{0x2f1800dd,0xdef40092,0x00000000,0x00000000}},	//   sége_, _ለማን_, --, --, 
   {{0xdb080108,0x76440124,0x00000000,0x00000000}},	//   änäk, рҭаа, --, --, 
   {{0x7e640161,0x94840724,0x09e0022e,0x00000000}},	//   _mdip, гыйд, _гоян, --, 
   {{0x67340210,0x00000000,0x00000000,0x00000000}},	//   _fuzj, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7e650226,0x6d5c0731,0x91a40051,0x00000000}},	//   _ndip, yssa, _ngõ_, --, 
   {{0x14741b06,0x6b94012d,0xa380000d,0x22580174}},	//   _مااج, zwzg, _õõne, ðska_, 
   {{0x7e6625f8,0x6d5c050a,0x6fb4007b,0x8978011a}},	//   _adip, vssa, لمخا, עריצ, 
   {{0x2ef4df11,0x4fc40d1d,0x6d5c02d0,0x00000000}},	//   изор, успа, wssa, --, 
   {{0x6d5e07c3,0x26c406af,0x622400db,0x00000000}},	//   tssa, _îlot_, دوۋە, --, 
   {{0x6d5e25f9,0x81e40183,0x7e640042,0xa5880092}},	//   ussa, _মুঠ_, _ddip, _ማክሰኞ_, 
   {{0x6d5e25fa,0x7e640209,0x2bd00cb2,0x49c800c7}},	//   rssa, _edip, सनला, ҭуам_, 
   {{0xcb1803b7,0x7bdc00b5,0x63ac00b0,0xaa5801f0}},	//   еќа_, gzru, āang, киву_, 
   {{0x6d5c1f53,0x00000000,0x00000000,0x00000000}},	//   pssa, --, --, --, 
   {{0xa8549b7c,0x6d5c013c,0x8934034e,0x00000000}},	// [3f2f0] икач, qssa, اعرا, --, 
   {{0x764002d2,0xd9f40412,0xd6c40efc,0x00000000}},	//   _afmy, _इशरत_, یملی, --, 
   {{0xec148c1c,0x00000000,0x00000000,0x00000000}},	//   _خودد, --, --, --, 
   {{0x6aa400f7,0xf1d4215d,0xf748027d,0x61ec1da2}},	//   _ئشدە, धनान, الني_, _žalm, 
   {{0x6604041b,0x00000000,0x00000000,0x00000000}},	//   јпла, --, --, --, 
   {{0x64a625fb,0xd24c00d1,0xe3b0007b,0x00000000}},	//   рака, ۈنى_, قرب_, --, 
   {{0xe29a25fc,0xe8d801f2,0xa23400c7,0x00000000}},	//   вай_, nsọ_, қьқә, --, 
   {{0xd05803be,0xdde40374,0xd24e25fd,0x323c0092}},	//   mitə, _ōpōt, ونى_, _አቀርባ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00c80150,0x00000000,0x00000000,0x00000000}},	//   _ﯗﺭﺗﺘ, --, --, --, 
   {{0x9f500790,0x644003e3,0x80d400bc,0x6d480356}},	//   _öbür_, _ifli, यसबे, ţeal, 
   {{0x7bdc02f0,0x5f040124,0xa5380023,0x00000000}},	//   vzru, рзма, _ብሃንቀ, --, 
   {{0x224e25fe,0x20d400d6,0xd12c1291,0x00000000}},	//   mbek_, _війс, ثمی_, --, 
   {{0xa06a25ff,0x59000135,0x224e2600,0xdca421f3}},	//   _рака_, _མཉེས_, lbek_, шаги, 
   {{0x20000142,0xfe7801af,0x00000000,0x00000000}},	//   _âhi_, _йүн_, --, --, 
   {{0x38c834c9,0x224c99e5,0x7e64009a,0xbb2c0131}},	//   گاری_, nbek_, _udip, _ﺧﯩﻞ_, 
   {{0x61ec0427,0x590806ed,0xded00023,0x64422601}},	// [3f300] _žalj, веам_, _ከማና_, _ofli, 
   {{0x38ca2602,0x3ea22603,0x52d00b9c,0x224c01bf}},	//   داری_, _hait_, _तत्स, hbek_, 
   {{0x3ea22604,0x81c8015b,0x224cb73c,0x00000000}},	//   _kait_, রছি_, kbek_, --, 
   {{0x3ea00652,0x64422605,0x47305ba6,0xf48403e6}},	//   _jait_, _afli, ініс, ڵاتی, 
   {{0xa8183ed0,0x224c01b9,0x3ea22606,0x2a2801a9}},	//   پتەر_, dbek_, _mait_, _бўён_, 
   {{0x3ea22607,0xb40400f7,0x186827a8,0x34962608}},	//   _lait_, бүзд, _шаги_, сакр, 
   {{0x3ea0045f,0x9410013b,0x224c022e,0x00000000}},	//   _oait_, ɛyɛ_, fbek_, --, 
   {{0x3ea01028,0x248808a4,0x644001a8,0x224c0718}},	//   _nait_, đama_, _efli, gbek_, 
   {{0x644000a9,0x98a80100,0x00000000,0x00000000}},	//   _ffli, _libč_, --, --, 
   {{0xf48412c3,0x2bc80490,0x2f180c6a,0xcfa400d1}},	//   _داری, रहमा, déga_, ашми, 
   {{0x3ea18dc8,0x13a4168d,0x224c01ed,0x44440014}},	//   _bait_, _ڕۆژی_, bbek_, _خرقہ, 
   {{0x3ea03e7c,0x224c0010,0x921c000d,0x00000000}},	//   _cait_, cbek_, _परपज_, --, 
   {{0x8d847b38,0x3ea0d9f3,0xfd540055,0x10e400f1}},	//   шунд, _dait_, _kleṣ, _نژدی_, 
   {{0x70580276,0xa1f401d3,0x00000000,0x00000000}},	//   _сакр_, _چڑیا_, --, --, 
   {{0x3ea22609,0xbb5a260a,0x3c58084c,0x00b8011a}},	//   _fait_, иарх_, рисэ_, _במגמ, 
   {{0x3ea2260b,0x25a800d7,0x2f180241,0x00000000}},	//   _gait_, ťali_, béga_, --, 
   {{0x6f0e260c,0x99a42ca8,0x00000000,0x00000000}},	// [3f310] _ikac, ğuşu_, --, --, 
   {{0x3ea2260d,0x224e260e,0x00000000,0x00000000}},	//   _zait_, zbek_, --, --, 
   {{0x0ba80f1b,0xb80800c6,0x6f0e260f,0x224c03e0}},	//   _شادى_, ليكم_, _kkac, ybek_, 
   {{0xd05800ac,0x37a800f7,0x059001b9,0x32d801e1}},	//   ritə, штун_, قاتگ, _yéye_, 
   {{0xe5a40058,0xd05803be,0x6f0c090c,0x64404937}},	//   сили, sitə, _mkac, _pfli, 
   {{0x644002fa,0x2ca0022e,0xf42000fe,0x22900208}},	//   _qfli, _jahd_, যখনৰ_, _ạk_, 
   {{0x6f0e2610,0x2ca080be,0xd344029e,0x224c01d5}},	//   _okac, _mahd_, میله_, tbek_, 
   {{0x04e400bd,0x6f0c00ca,0xe29821fe,0x84800023}},	//   খকের_, _nkac, уаи_, ነበራን_, 
   {{0x3ea02af2,0x8480044e,0x224e2611,0x69cd0c1e}},	//   _rait_, ነበረን_, rbek_, nyae, 
   {{0x3ea22612,0x838409fe,0x6f0e2613,0x2ee80109}},	//   _sait_, _выде, _akac, _amaf_, 
   {{0x3ea22614,0xf1a84144,0x92d40183,0x69cc003e}},	//   _pait_, هایه_, _সদৰ_, hyae, 
   {{0x32d80248,0xa1580117,0x00000000,0x00000000}},	//   _péye_, _баду_, --, --, 
   {{0x216a2615,0xa0a62616,0x69cc0007,0x3ea01337}},	//   _сили_, _галд, jyae, _vait_, 
   {{0x3ea22617,0x201800ac,0x1214008f,0x848002d3}},	//   _wait_, əsin_, _פֿאר_, ነበሩን_, 
   {{0x3ea22618,0x06f400e1,0x1ca403e6,0x90b0035b}},	//   _tait_, ंचाव_, لێکی_, _хәыш, 
   {{0x6ee45706,0x3ea000c6,0x32d80de2,0x19b800d4}},	//   _وسيل, _uait_, _téye_, лузь_, 
   {{0x5d853133,0x69cc0399,0x1834007b,0x4e240395}},	// [3f320] _الخل, gyae, مراح, _лоън_, 
   {{0x6f0c0118,0x6aa8032e,0x00000000,0x00000000}},	//   _zkac, _óefn, --, --, 
   {{0x2bc80b7c,0x7794e1a2,0x9f400166,0x00000000}},	//   रहणा, غیرا, _ähä_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xb33c025c,0x2fcc0fac,0x00000000,0x00000000}},	//   _irħi, zydg_, --, --, 
   {{0xc9501203,0x79840083,0x28740022,0xd37801a9}},	//   _ממש_, mtiw, _мыср, гчи_, 
   {{0x848002d3,0x00000000,0x00000000,0x00000000}},	//   ነበሮን_, --, --, --, 
   {{0x798401f7,0x4f6801d5,0x00000000,0x00000000}},	//   otiw, қшом_, --, --, 
   {{0x79841cea,0x6f0c022e,0x20c80332,0xd1b800db}},	//   ntiw, _rkac, _núis_, ااعا_, 
   {{0x79862619,0x81e405ac,0x93580114,0x00000000}},	//   itiw, _মুহ_, _брду_, --, 
   {{0x69cc0007,0x73c4013d,0x00000000,0x00000000}},	//   zyae, _фәле, --, --, 
   {{0xe3b0066d,0x7986261a,0x2ca00548,0x21240548}},	//   _کرے_, ktiw, _sahd_, amlh_, 
   {{0x2d980196,0x20c800c6,0x00000000,0x00000000}},	//   uwse_, _cúis_, --, --, 
   {{0x0fd80271,0x00000000,0x00000000,0x00000000}},	//   _مبعث_, --, --, --, 
   {{0x75b40490,0x61ec0419,0x69cc015d,0x6f0c0210}},	//   ंमुळ, _ľali, wyae, _tkac, 
   {{0x61ed79ed,0x6f0c055a,0x2f4402e3,0x7984022f}},	//   _žali, _ukac, _ịgwa_, ftiw, 
   {{0xfbd00d83,0x798422d0,0xfd4401c0,0x20c801e7}},	// [3f330] وتہ_, gtiw, _нээн, _iúir_, 
   {{0xb33c031c,0x69cc022e,0x00000000,0x00000000}},	//   _erħi, ryae, --, --, 
   {{0x7986261b,0x2f18020c,0xf74820d4,0xdc8c0023}},	//   atiw, négo_, مللي_, _ምምሃር_, 
   {{0xd1f40023,0x00000000,0x00000000,0x00000000}},	//   ፎርት_, --, --, --, 
   {{0x2bd0007d,0x69cc0369,0x7986261c,0x7864075e}},	//   सनका, qyae, ctiw, زدەك, 
   {{0x24881050,0x72940022,0x00000000,0x00000000}},	//   đamo_, ҧшых, --, --, 
   {{0xe5a40116,0x00000000,0x00000000,0x00000000}},	//   сиһи, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe0d82b39,0x80e4010b,0x00000000,0x00000000}},	//   иви_, йгиң_, --, --, 
   {{0x1f66261d,0xa06814b7,0x60e82c9d,0x20c8007b}},	//   оком, јана_, рмом_, _rúis_, 
   {{0xdbf0038e,0x13a801d9,0xe2c80014,0x20c9195a}},	//   _příp, _پننی_, _پوشو_, _búir_, 
   {{0x20c80332,0xb9f00240,0x00000000,0x00000000}},	//   _cúir_, _ዑፍ_, --, --, 
   {{0x26dc006f,0xf1a803e6,0x71a400d4,0x00000000}},	//   ihwo_, _هاوه_, _наїз, --, 
   {{0x6288005a,0x00000000,0x00000000,0x00000000}},	//   lfeo, --, --, --, 
   {{0xda5a261e,0xca4405db,0xdea0eb48,0xdbf00118}},	//   ираш_, _ụbọc, _قیدی, _tříp, 
   {{0x25ae261f,0x79862620,0x20c80332,0xe8d80051}},	//   _orel_, ttiw, _túis_, trở_, 
   {{0x32d800e8,0xbd880022,0xd65c01ec,0xc9a4ee43}},	// [3f340] _jéya_, _уапҧ_, сiнд, овте_, 
   {{0x79862621,0x18680abe,0x8d900066,0x00000000}},	//   rtiw, ражи_, _کلیش, --, 
   {{0x79862622,0x25ac01c7,0xd7080276,0xa0580092}},	//   stiw, _arel_, анже_, _ለአንዳ, 
   {{0xb7c001e1,0x25ac017a,0xd708023a,0x4b78010f}},	//   _aṣá, _brel_, шнее_, _דאטו, 
   {{0xba480006,0xd9b800f7,0x95980150,0x00000000}},	//   grįž, _тынч_, ртеу_, --, 
   {{0xd3940139,0x136801f0,0x00000000,0x00000000}},	//   жәдә_, ашии_, --, --, 
   {{0x8500168d,0x39422623,0x25ae2624,0x6288072b}},	//   بوون, lqis_, _erel_, ffeo, 
   {{0x25ac07ab,0x32d800f2,0xc324007b,0x00000000}},	//   _frel_, _béya_, يكون_, --, 
   {{0x2c10007d,0x25ac0010,0x3940022e,0x00000000}},	//   _दुनू_, _grel_, nqis_, --, 
   {{0x13b400ae,0x00000000,0x00000000,0x00000000}},	//   _وصاح, --, --, --, 
   {{0x25ac0427,0x883800d9,0x00000000,0x00000000}},	//   _zrel_, יתיו, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xfd440323,0xc3300375,0x73c401e0,0x61ec0153}},	//   дэсн, _חוף_, _фәһе, _žalv, 
   {{0x009005f5,0xe57000c8,0x657c0158,0x99a40166}},	//   _жишэ, ײַך_, _åshe, _şuşi_, 
   {{0xac18026a,0xe1e80a81,0x0ac4234c,0x20c800ae}},	//   сову_, _پى۪و_, ощам, _túir_, 
   {{0x3940511b,0xd65c01ec,0x7ee4007b,0x00000000}},	//   fqis_, сiмд, _يكون, --, 
   {{0xb33c0135,0x4a7401e0,0x69ac01f9,0x00000000}},	// [3f350] _irħu, йыҡт, ीमधी, --, 
   {{0x25ac0295,0xac980228,0x27540023,0x98a80055}},	//   _rrel_, _اندا_, _ዝቐረበ, _pibā_, 
   {{0x25ac01c7,0x87280006,0xdc9800d9,0x8704026b}},	//   _srel_, аўда_, _הסתכ, ояде, 
   {{0xa9c00228,0x00000000,0x00000000,0x00000000}},	//   _كۅزۉ, --, --, --, 
   {{0x2bc82e37,0x00000000,0x00000000,0x00000000}},	//   रहवा, --, --, --, 
   {{0xd1e0044e,0xd5ac2834,0x6b84020c,0x00000000}},	//   ዝነት_, افو_, _kqhg, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x572000f7,0x383412fa,0x00000000,0x00000000}},	//   _كۉلك, _інтр, --, --, 
   {{0x9a80069c,0xc8fc0f22,0x4ad0000d,0x00000000}},	//   _ይኽእል_, ্গীত_, _सवनव, --, 
   {{0x657800b0,0xe0d88c21,0xb6240150,0x00000000}},	//   muwh, сво_, _ﺭﺌ_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x61eda202,0x63a00334,0x1418011a,0x00000000}},	//   _žalu, _isln, _הועב, --, 
   {{0x2910009a,0xb2e80014,0x657802b1,0xc0e8010c}},	//   _okza_, _بٹنٕ_, nuwh, _ቅጽል_, 
   {{0xa0a62625,0x33b000d1,0x6ac8012d,0x00000000}},	//   _хакд, _سەۋر, _िकॉर, --, 
   {{0x657800b0,0x39400113,0x61ec010b,0x00000000}},	//   huwh, wqis_, _ýalb, --, 
   {{0x657802b5,0x39400327,0x00000000,0x00000000}},	//   kuwh, tqis_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3f360] --, --, --, --, 
   {{0xdb841d83,0x63a00306,0x39400200,0x00000000}},	//   _егои, _osln, rqis_, --, 
   {{0x98a80276,0x657801a4,0x3f640e04,0x4c38011a}},	//   _aibă_, euwh, nđu_, _לתיב, 
   {{0xeaf817ee,0xc6a0011b,0x41d8cc41,0x00000000}},	//   ्कृत_, ерши, यनास, --, 
   {{0x39400003,0x00000000,0x00000000,0x00000000}},	//   qqis_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x85300075,0x546801d5,0x92d400fe,0x00000000}},	//   رۈمچ, _ҳазм_, _সদৌ_, --, 
   {{0x46a22626,0x91e4037e,0xd31000f1,0x00000000}},	//   _пасв, _jpでp, رګاډ, --, 
   {{0x54340cd6,0x76440113,0x00000000,0x00000000}},	//   _فرار, ñiyu, --, --, 
   {{0x2ed4752d,0xc4800120,0x33b80244,0x53a4187f}},	//   दस्त, _плук, _وخاک_, _назб, 
   {{0xb4d994ac,0x63e00150,0x61ec00c0,0x00000000}},	//   ासी_, _لۋول, _žalt, --, 
   {{0xee380372,0x00000000,0x00000000,0x00000000}},	//   өнү_, --, --, --, 
   {{0x7f8030fe,0x42040353,0x11281b0a,0xdda400c7}},	//   ولین, _енцо_, _люки_, мырҿ, 
   {{0xc0d4001f,0xef1800de,0x2bc861ef,0xdf7000db}},	//   ክበር_, itļi_, रहला, رگۉب, 
   {{0x80a02e6f,0xe8d801f2,0x6ad4015b,0x00000000}},	//   _سمين, ntụ_, ঠোফো, --, 
   {{0xb4d808f8,0xfaa42f0d,0x225c025c,0x3ff8011a}},	//   ासु_, ншун, _xewk_, _לפוע, 
   {{0xdcf40205,0x69340022,0x2d9c0248,0x00000000}},	// [3f370] _eryı, днау, _èwe_, --, 
   {{0x6d4e2627,0x3914084c,0xda7001d9,0x67d4004e}},	//   _itaa, емур, _یُپ_, мозу, 
   {{0xce3001d5,0x00000000,0x00000000,0x00000000}},	//   _توکک, --, --, --, 
   {{0xf7700720,0x657804fe,0x6d480311,0x00000000}},	//   اال_, tuwh, ţeau, --, 
   {{0x6d4c020b,0x3e8801d3,0xe79400f1,0xb4d80a8a}},	//   _jtaa, lító_, _ښارک, ासू_, 
   {{0x6d4c0451,0xe8d802e3,0x65780374,0xc0bc0023}},	//   _mtaa, ftụ_, ruwh, ስቓስ_, 
   {{0xb0b00d2c,0x3e8801d3,0xf7940024,0x9fb401ef}},	//   जयनग, nító_, _парэ, _přít_, 
   {{0x660c00af,0x6d4ca6af,0x657802b5,0xfbb8011a}},	//   üaks, _otaa, puwh, לפות_, 
   {{0x6d4e2628,0xe8d80521,0xc44401d3,0x76b80137}},	//   _ntaa, atụ_, _فیشن_, _элтр_, 
   {{0x656800ca,0xb9e402d3,0xe0d000c6,0x3e8800e5}},	//   _iveh, _ከይ_, ئزة_, kító_, 
   {{0x6d4c32ff,0x5f0400d6,0x63a0022e,0x00000000}},	//   _ataa, дзна, _usln, --, 
   {{0x3f640063,0x3e8800e5,0x00000000,0x00000000}},	//   rđu_, dító_, --, --, 
   {{0xa06a2629,0xdcb0198a,0xb33c031c,0x00000000}},	//   _дала_, پىز_, _isħa, --, 
   {{0x31080220,0x9138011a,0x40840b01,0x00000000}},	//   _еніп_, _ועסק, _худб, --, 
   {{0x6d4e262a,0x8c42262b,0x3e8801d3,0xd65c01ec}},	//   _etaa, тесе, gító_, тiлд, 
   {{0x7b3c2ce2,0xa3b4000d,0x00000000,0x00000000}},	//   _očuv, _छछन_, --, --, 
   {{0x18a428f3,0x957c0092,0x23a800bc,0xd02000cc}},	// [3f380] маам, _የፍትሕ_, किँद, _নলয়_, 
   {{0xe6c8110c,0x00000000,0x00000000,0x00000000}},	//   _čašć, --, --, --, 
   {{0x65682f05,0xe6b401d5,0x1ae4022e,0x00000000}},	//   _aveh, کلنگ, _жонм, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa2b0033f,0x4d78010f,0x00000000,0x00000000}},	//   _अफ़्, ַרקע, --, --, 
   {{0xb4d8e613,0x98640014,0x00000000,0x00000000}},	//   ासे_, _آیاے_, --, --, 
   {{0x656a262c,0x3134035b,0x00000000,0x00000000}},	//   _eveh, ҽеир, --, --, 
   {{0x439001f0,0x00000000,0x00000000,0x00000000}},	//   таъс, --, --, --, 
   {{0xcb100302,0x3136262d,0x3f840309,0x15d401d9}},	//   כלה_, неир, _aqnu_, _تگاں_, 
   {{0x6d4c0194,0x3e88559d,0xdeb80092,0xd12c00cf}},	//   _rtaa, yító_, _ዲጎኔ_, جۅت_, 
   {{0x6d4e262e,0x65680433,0x00000000,0x00000000}},	//   _staa, _zveh, --, --, 
   {{0x3e8801d3,0x00000000,0x00000000,0x00000000}},	//   vító_, --, --, --, 
   {{0x11e916e4,0x0ca84727,0xcc940220,0x90c400f5}},	//   _بعضي_, отви_, _ﺘﻤﻭﺯ_, _обде, 
   {{0x61ec00ee,0x3e8801d3,0x00000000,0x00000000}},	//   _ýala, tító_, --, --, 
   {{0x7b642309,0x8aa44109,0x4ad0000d,0x00000000}},	//   ктте, мрад, _सवदव, --, 
   {{0x6d4c0a49,0x3e8801d3,0x0af0009d,0x00000000}},	//   _ttaa, rító_, түмэ, --, 
   {{0x6d4e262f,0x3e8801ed,0x2dc80150,0x00000000}},	// [3f390] _utaa, sító_, _ءابۋ_, --, 
   {{0xb4d8752d,0x6d48054e,0xf17c0131,0x3e8801d3}},	//   ासो_, ţeas, _ﻣﻪﻟﯘ, pító_, 
   {{0x60dc0240,0xe698030d,0x656801ef,0x00000000}},	//   ësmi, звеш_, _sveh, --, 
   {{0x36d40063,0xf6501fa1,0x98a80153,0x00000000}},	//   кохр, لئه_, _ribą_, --, 
   {{0x201802ea,0xa3e007f7,0xc86428e8,0x00000000}},	//   ́si_, नैन_, _отви, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x457001af,0x00000000,0x00000000,0x00000000}},	//   _аңдр, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x34940022,0x21a400ee,0x00000000,0x00000000}},	//   _иаур, _җикм, --, --, 
   {{0x26cc00b0,0x00000000,0x00000000,0x00000000}},	//   _koeo_, --, --, --, 
   {{0xf8dc00dc,0x00000000,0x00000000,0x00000000}},	//   _यत्प, --, --, --, 
   {{0x2b40002f,0x9db80006,0x225806ea,0x00000000}},	//   _auhc_, чыну_, ðsku_, --, 
   {{0xdcb020ea,0x10a00107,0xca200150,0x00000000}},	//   دىس_, _бишн, _ﺸﺎﺸ_, --, 
   {{0x05a0000d,0x9f4801f4,0x00000000,0x00000000}},	//   _खईऽब, ökät_, --, --, 
   {{0x2fd8a248,0x00000000,0x00000000,0x00000000}},	//   ørge_, --, --, --, 
   {{0x09e22630,0x4ef8011a,0x00000000,0x00000000}},	// [3f3a0] готн, _מהקו, --, --, 
   {{0x888001d5,0xd944009d,0x00000000,0x00000000}},	//   ллуж, _үени, --, --, 
   {{0x7d1c05b1,0x81d000fe,0xb908448b,0x00000000}},	//   mlrs, _হেম_, _बत_, --, 
   {{0xd044016b,0x26cc003a,0xb4d8146b,0x2f180098}},	//   _ɑmɑn, _coeo_, ास्_, tégi_, 
   {{0x7fc800bc,0x00000000,0x00000000,0x00000000}},	//   ाहुँ, --, --, --, 
   {{0x7ae4ec88,0x26cc0109,0xd3a4010b,0x34962631}},	//   lhit, _eoeo_, ерип, такр, 
   {{0x96940cfc,0x7ae62632,0x2f1800dd,0xb4d800dc}},	//   _праш, ohit, ségi_, ासौ_, 
   {{0x7ae40ecf,0xd8740046,0x00000000,0x00000000}},	//   nhit, _تاڭب, --, --, 
   {{0x7ae4009f,0x00000000,0x00000000,0x00000000}},	//   ihit, --, --, --, 
   {{0xc0543334,0x7ae62633,0xd0840022,0x4c7c0150}},	//   нію_, hhit, хыии, _ﺩﻫﺎﺀ_, 
   {{0x7ae62634,0x32e4004d,0x9fb40118,0x61ec010e}},	//   khit, _đườ, _přát_, _ýaln, 
   {{0x7ae5f3f1,0x61400022,0x914800f3,0x00000000}},	//   jhit, ыҵәа, _ечка_, --, 
   {{0x7ae62635,0x00000000,0x00000000,0x00000000}},	//   dhit, --, --, --, 
   {{0x7ae400c5,0x63ac012d,0x00000000,0x00000000}},	//   ehit, łane, --, --, 
   {{0x6d4c00d0,0x041401e1,0x00000000,0x00000000}},	//   _žiač, _ńjẹk, --, --, 
   {{0x7ae62636,0x7cd8046c,0x3f880276,0xadb401ec}},	//   ghit, _ağrı, ăcut_, _абиш, 
   {{0x1dc0247f,0xfc3001ed,0x6f1c0036,0x7bc803b2}},	// [3f3b0] _көрн, لحہ_, mlsc, ødur, 
   {{0x6f1e2637,0x7ae4cf1c,0x00000000,0x00000000}},	//   llsc, ahit, --, --, 
   {{0x7ae62638,0xbf98010f,0x1ee8085b,0xaa58014b}},	//   bhit, ּידש, _رویی_, _оину_, 
   {{0x7ae62639,0x00000000,0x00000000,0x00000000}},	//   chit, --, --, --, 
   {{0xe5a4c6b5,0x6abc00e4,0xec140150,0x6f1e263a}},	//   тили, _insf, _سوڭد, ilsc, 
   {{0x6f1db317,0x6aac032e,0xd3440133,0x22487540}},	//   hlsc, ldaf, چیله_, _żak_, 
   {{0x7b3c00b0,0xd34401b9,0xa2e401d5,0x00000000}},	//   _kōua, نیله_, кокд, --, 
   {{0xe298016c,0x55600131,0x00000000,0x00000000}},	//   фаи_, _چۇنك, --, --, 
   {{0x03a01b74,0x67293cf5,0x270c0073,0x98a800c0}},	//   тиқо, _ihej, िकीर_, _aibę_, 
   {{0x24840789,0x6608031c,0x6f1c01e7,0xdf480aac}},	//   _uclm_, _ixek, elsc, мзод_, 
   {{0xdee54ff3,0x67280218,0x29016223,0x229447ea}},	//   вони, _khej, inha_, _للاس, 
   {{0x9d45769c,0x6728031c,0x7ae40023,0x224803e3}},	//   кемд, _jhej, xhit, _üak_, 
   {{0x6aaca019,0x7ae6263b,0xfdc000bd,0x6608031c}},	//   ddaf, vhit, উন্ড, _jxek, 
   {{0x7ae41f4c,0x61ea1abb,0x6abc14dc,0x672800ad}},	//   whit, mzel, _ansf, _lhej, 
   {{0x7ae6263c,0x5f040801,0x6728035b,0x61ea263d}},	//   thit, _изка, _ohej, lzel, 
   {{0xed500451,0x9f48033f,0x6f1c0175,0x6aae263e}},	//   _گھٽ_, łków_, clsc, gdaf, 
   {{0x3b003209,0x4a40c43a,0x7f4042b2,0xa3e00037}},	// [3f3c0] rniq_, рнув, _hunq, नैत_, 
   {{0x7ae6263f,0x7f40b00f,0x672a2640,0x7e662641}},	//   shit, _kunq, _ahej, _heip, 
   {{0x7f422642,0xcc740302,0x7e662643,0x672a2644}},	//   _junq, _בעיה_, _keip, _bhej, 
   {{0x7ae51a76,0x672a2645,0x7e640124,0xcf90008f}},	//   qhit, _chej, _jeip, שטא_, 
   {{0x61e80196,0x7f404b2a,0x7e662646,0x6729b61d}},	//   jzel, _lunq, _meip, _dhej, 
   {{0x61ea2647,0x67289f4e,0xd6e0033f,0xca2001ec}},	//   dzel, _ehej, _siłę_, _ﺸﺎﺀ_, 
   {{0x7f422648,0x660a2649,0x61ea264a,0x930400d8}},	//   _nunq, _exek, ezel, кџил, 
   {{0x7e66264b,0x61e801c7,0x00000000,0x00000000}},	//   _neip, fzel, --, --, 
   {{0x7f400895,0xb1142097,0xb33c0327,0x03ec0055}},	//   _aunq, лмиш, _isħm, _māṇe, 
   {{0x672a264c,0x7f4001fe,0x45240276,0x25b80162}},	//   _zhej, _bunq, _ажун_, _ásla_, 
   {{0x03a010f5,0x61e803bd,0x7f42264d,0x7e64002f}},	//   _вихо, azel, _cunq, _beip, 
   {{0x7f42264e,0x7e645e94,0x61e805d1,0xd334072d}},	//   _dunq, _ceip, bzel, _شعاع, 
   {{0x61e80034,0x7e66264f,0x66080327,0x6f1ced10}},	//   czel, _deip, _xxek, rlsc, 
   {{0x7ff15109,0x7f40017a,0x518400d1,0x00000000}},	//   اسیا, _funq, _ﻣﻪﺳﭽ, --, 
   {{0x7e640093,0x03ec002b,0xef10004e,0x00000000}},	//   _feip, _bāṇe, _гүнө, --, 
   {{0x7e648e5d,0x7ee400f7,0xff4c0345,0x00000000}},	//   _geip, _ۅكۉن, _بخو_, --, 
   {{0x6aae2650,0x672802c4,0x00000000,0x00000000}},	// [3f3d0] rdaf, _rhej, --, --, 
   {{0x1cc00003,0x672a2651,0x7f40568e,0x53d00210}},	//   _གོར_, _shej, _yunq, तहाश, 
   {{0x61ea2652,0x67280564,0x7f40056a,0x765002e3}},	//   zzel, _phej, _xunq, _ịkọw, 
   {{0xf7722653,0x63500053,0x6abc11b0,0x7c3802f0}},	//   زام_, _hāng, _unsf, _úvra, 
   {{0xa4d400d6,0x63500374,0x2a681bce,0x05840108}},	//   лоді, _kāng, maab_, туем, 
   {{0xd0054db7,0x61ea2654,0x0704004b,0x2a6a2655}},	//   _هل_, vzel, ريږي_, laab_, 
   {{0x1cc00d46,0x63500053,0xf486099a,0xa0a5821a}},	//   _གོལ_, _māng, ручн, қанд, 
   {{0xe8241d18,0x61ea2656,0x2a6a2657,0x672800ca}},	//   _афғо, tzel, naab_, _uhej, 
   {{0x7e65fad8,0x7f400986,0x36d4008e,0x05740eff}},	//   _reip, _sunq, _тотр, _جازد, 
   {{0x61ea2658,0x7e662659,0x7f400113,0x2a6a265a}},	//   rzel, _seip, _punq, haab_, 
   {{0x6442265b,0x7e66265c,0xd24d131c,0x61ea265d}},	//   _igli, _peip, غنی_, szel, 
   {{0x7f400369,0x61ea265e,0xde30001f,0x26dca898}},	//   _vunq, pzel, _በሕይወ, nkwo_, 
   {{0x7e66265f,0xd12e2660,0x2a685f39,0x61e8009a}},	//   _veip, تمی_, daab_, qzel, 
   {{0x7f4087b9,0x7cf400ac,0x224c03e0,0xf4980023}},	//   _tunq, _kürə, lcek_, _መኽሰብ_, 
   {{0x7e662661,0x26dc0083,0x20180024,0x7ac40022}},	//   _teip, kkwo_, ęsis_, аҩна, 
   {{0xe7f806e3,0x44f800fe,0x224e2662,0x32d802e2}},	//   ्पना_, েতিক_, ncek_, _péyi_, 
   {{0x64422663,0xd94400c6,0xd65c02dd,0xda080592}},	// [3f3e0] _ogli, ائري, тiнд, ريئه_, 
   {{0x64403e58,0x635000b8,0x38c84d4e,0x00000000}},	//   _ngli, _kānd, خاری_, --, 
   {{0x2a6a2664,0x2c0001c0,0x224c0205,0x38c8085b}},	//   baab_, _дүрм, kcek_, _یاسی_, 
   {{0x64422665,0x224c7edf,0x635000cd,0x00000000}},	//   _agli, jcek_, _mānd, --, 
   {{0x64422666,0x74540451,0x00000000,0x00000000}},	//   _bgli, لھائ, --, --, 
   {{0x1cc00867,0xd9b002ab,0x932403e6,0xd76401d3}},	//   _གོས_, ीमीट, گرتن, _مارٹ, 
   {{0x7cf403b9,0x635000b8,0x61ec00a2,0x00000000}},	//   _cürə, _nānd, _ýalj, --, 
   {{0x64422667,0x6b822668,0x00000000,0x00000000}},	//   _egli, àlgi, --, --, 
   {{0x506468ba,0xab800023,0x00000000,0x00000000}},	//   лтна, _ይውዕል_, --, --, 
   {{0xc7ac066d,0x635000cd,0x661c06ea,0x2a680009}},	//   _بڑے_, _bānd, _øska, zaab_, 
   {{0x6350f981,0x2a680014,0xc9140375,0x3d1801ad}},	//   _rāng, yaab_, רחית_, पकने_, 
   {{0x51862669,0xc20401d3,0x224c01d3,0x2a680067}},	//   _бука, ئقین_, ccek_, xaab_, 
   {{0x63500053,0x7de401ec,0xd1d401f3,0x02f800df}},	//   _pāng, бірд, ርሲቲ_, _אלאמ, 
   {{0x2a6801d9,0xa3e00882,0xcdc000c7,0xe7f800bc}},	//   waab_, नैव_, ааҭқ, ्पमा_, 
   {{0xac187b17,0x2a6a266a,0x635000cd,0x00000000}},	//   тову_, taab_, _gānd, --, 
   {{0xaa54e1c2,0x50a00131,0x00000000,0x00000000}},	//   рваш, _ئەھل, --, --, 
   {{0x63500325,0xadb804fb,0x2a680014,0xe97400c6}},	// [3f3f0] _tāng, _شهدا_, raab_, شهاد, 
   {{0x635002b1,0x270c2ecf,0x2a693d3b,0x8d5400fd}},	//   _hāne, िक्र_, saab_, _итүч, 
   {{0x6352266b,0x224c0205,0x00000000,0x00000000}},	//   _kāne, ycek_, --, --, 
   {{0x663804a9,0x8aa41c8c,0x644005d5,0x2a680014}},	//   نكاس_, _срод, _sgli, qaab_, 
   {{0x7cf403be,0xd90c00aa,0xa53401b9,0x442002f0}},	//   _sürə, سیې_, андч, _šj_, 
   {{0x81d00154,0x00000000,0x00000000,0x00000000}},	//   _হইল_, --, --, --, 
   {{0x67d401b9,0x86b005a2,0xe7480107,0x224c0205}},	//   _тову, _гөлф, _рӯзе_, tcek_, 
   {{0x6350002b,0x61ec010b,0x00000000,0x00000000}},	//   _nāne, _ýalk, --, --, 
   {{0x224e266c,0x635000b8,0x00000000,0x00000000}},	//   rcek_, _sānd, --, --, 
   {{0xe0d816a4,0xd12c1c36,0x224e266d,0x00000000}},	//   тво_, ومي_, scek_, --, 
   {{0x602454e7,0x627400c6,0x5f04013e,0x94b80375}},	//   рдна, _نهائ, изоа, _שמעת, 
   {{0x635000b8,0x2178113e,0x63ac01e4,0xdce400de}},	//   _cāne, _айды_, ցant, dskā, 
   {{0x629800ca,0x635000cd,0x0d80d56c,0x00000000}},	//   _ibwo, _dāne, олян, --, 
   {{0x28c80bae,0xdc2c06be,0x635000b8,0x00000000}},	//   राफि, _cığa, _tānd, --, 
   {{0xdc2c03b9,0xa3d4000d,0xd12c009a,0x28c807d0}},	//   _dığa, हहि_, _تمو_, रानि, 
   {{0x5f940032,0x63500055,0x80d8000d,0x00000000}},	//   _биҫт, _gāne, _पकडे, --, 
  
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3f400] --, --, --, --, 
   {{0x98541429,0x97b40276,0x08c00137,0x1b48014b}},	//   рташ, исеш, обун, _изои_, 
   {{0x629a266e,0x6350002b,0x00000000,0x00000000}},	//   _obwo, _yāne, --, --, 
   {{0x5a940a16,0x7b3c00b0,0x32d8002e,0x00000000}},	//   _троф, _kōum, _yéyu_, --, 
   {{0xdc2c03e3,0x00000000,0x00000000,0x00000000}},	//   _yığa, --, --, --, 
   {{0x62980083,0x6e280327,0x00000000,0x00000000}},	//   _abwo, żebg, --, --, 
   {{0x7bdc07a8,0x62980076,0x836001b9,0x00000000}},	//   nyru, _bbwo, قگنل, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x63501f4c,0x7984009f,0x9f4c0118,0x8678011a}},	//   _rāne, nuiw, ěným_, _שרמו, 
   {{0x6298033b,0x2fd805ac,0x63500055,0x7bdc0064}},	//   _ebwo, ørgo_, _sāne, kyru, 
   {{0x7b3c06c8,0x32d8002e,0x7984017a,0x61e40213}},	//   _pōul, _séyu_, huiw, _əhli, 
   {{0x79840ea0,0xdc2db056,0x628c0022,0xe7f86a60}},	//   kuiw, _sığa, _ñaop, ्पता_, 
   {{0x236805ce,0x85440024,0xdce40153,0xc2780677}},	//   ćaje_, plėš, nukė, _יראי, 
   {{0x79840af9,0xe3b001d3,0x8f440354,0x00000000}},	//   duiw, _برے_, _кхид, --, 
   {{0x63501da6,0xc5f001ad,0x3eb0023a,0x00000000}},	//   _tāne, _अध्य_, öltä_, --, 
   {{0x28c81d03,0x40380375,0x0d64074d,0x00000000}},	//   राभि, _בגוג, _къом, --, 
   {{0xfd1005d9,0x8d84694c,0xfd440137,0x6d58025c}},	// [3f410] _ڪجي_, _туйд, _мээн, _ħwaw, 
   {{0x657c2dba,0x00000000,0x00000000,0x00000000}},	//   _åshi, --, --, --, 
   {{0xc6a5ea38,0xfd10007b,0x00000000,0x00000000}},	//   ирди, _تجي_, --, --, 
   {{0xdc55050c,0x00000000,0x00000000,0x00000000}},	//   _پریک, --, --, --, 
   {{0x087000c7,0x00000000,0x00000000,0x00000000}},	//   _мҳаџ, --, --, --, 
   {{0x64a6266f,0xe7f8024a,0x6fb801ad,0x00000000}},	//   сака, ्पदा_, ेमां, --, 
   {{0xe29a2670,0x00000000,0x00000000,0x00000000}},	//   гай_, --, --, --, 
   {{0x05240154,0x00000000,0x00000000,0x00000000}},	//   মদের_, --, --, --, 
   {{0x80e4010b,0x58a8010e,0x00000000,0x00000000}},	//   игиң_, _ïîæā, --, --, 
   {{0x94402832,0x25ac0368,0x00000000,0x00000000}},	//   _ٹھون, _isel_, --, --, 
   {{0x798400ec,0x23b419bc,0xa5c401e1,0x00000000}},	//   zuiw, _دماس, _ṣèwe_, --, 
   {{0x62980537,0xa3e000dc,0x7bdc02f0,0x635000b8}},	//   _ubwo, नैः_, vyru, _tānb, 
   {{0x7bdc0142,0x00000000,0x00000000,0x00000000}},	//   wyru, --, --, --, 
   {{0x7bde2671,0xa06803b7,0x628a2672,0xc05800d4}},	//   tyru, _сака_, lgeo, _рід_, 
   {{0xcb016c08,0x00000000,0x00000000,0x00000000}},	//   रचंड_, --, --, --, 
   {{0x9e6409fe,0x7984009a,0x25ac6b92,0x7bdc00e4}},	//   _увид, tuiw, _osel_, ryru, 
   {{0x7bdc0124,0xe81c00bc,0x9b440066,0x00000000}},	// [3f420] syru, _बुबा_, _گنجو, --, 
   {{0x79844d37,0x7bde2673,0x7b3c02b5,0x00000000}},	//   ruiw, pyru, _kōuk, --, 
   {{0xb9000882,0x628a2674,0x25ac005a,0x79862675}},	//   _तव_, kgeo, _asel_, suiw, 
   {{0x649000bc,0x24b801d3,0x00000000,0x00000000}},	//   _lžič, یننگ_, --, --, 
   {{0x628818b0,0x64905160,0x00000000,0x00000000}},	//   dgeo, _ožič, --, --, 
   {{0x28c808ec,0x288000d1,0xf48401d5,0x00000000}},	//   राणि, _оқув, زاتی, --, 
   {{0x25ae2676,0x63980092,0x03c00139,0x00000000}},	//   _esel_, _መክፈቻ_, зсым, --, 
   {{0xa3c809fd,0x81d004c5,0x62885522,0x717a2677}},	//   _ऊपर_, _হেই_, ggeo, абир_, 
   {{0x6d480311,0xd1381d8c,0xc6c00304,0xd4f40024}},	//   ţeaz, лхо_, _эйтк, _ляжы, 
   {{0x6f748af4,0x99d400fe,0x00000000,0x00000000}},	//   огоф, _সেৱক, --, --, 
   {{0x28c80b9c,0x62880112,0x38780129,0xbf140073}},	//   राति, bgeo, _mdrr_, ठवून_, 
   {{0xceea2678,0x648001af,0x00000000,0x00000000}},	//   اردن_, _еңәб, --, --, 
   {{0x7de401ec,0x00000000,0x00000000,0x00000000}},	//   пірд, --, --, --, 
   {{0x6350123c,0x4234011a,0xf414010f,0x00000000}},	//   _hāna, _הנדל_, ַפּ_, --, 
   {{0x63522679,0xe81c17ee,0xaed4010a,0x00000000}},	//   _kāna, _बँधा_, _мокш, --, 
   {{0x658c0020,0x635000dc,0x00000000,0x00000000}},	//   _የግብፅ_, _jāna, --, --, 
   {{0xf7701973,0x6352267a,0x6f0c8a15,0xe8f800ee}},	// [3f430] ہان_, _māna, _ijac, анач_, 
   {{0x28c81715,0x6d5e267b,0x1cc00135,0xb33c0327}},	//   राधि, mpsa, _གོག_, _isħu, 
   {{0xf771120a,0x6d5e267c,0x6eac0034,0xead6267d}},	//   فان_, lpsa, ज़पु, _донь, 
   {{0x25580276,0x6d5c9df9,0x635000cd,0x00000000}},	//   аркэ_, opsa, _nāna, --, 
   {{0x28c80882,0x6d5c02d0,0x7e7c010f,0xdb2402f2}},	//   रादि, npsa, ראדז, _گوێی, 
   {{0x6e2dd65a,0x63780228,0x87e4d646,0x36880075}},	//   _mzab, асир_, _любе, асән_, 
   {{0x2eea267e,0x6f0c0e3c,0x628a267f,0x6d5c02d0}},	//   _olaf_, _ojac, tgeo, hpsa, 
   {{0x6e2ca457,0x25ac020b,0x6288014b,0x635000dc}},	//   _ozab, _tsel_, ugeo, _cāna, 
   {{0x6e2e2680,0x63500882,0x2a7805b1,0x60e80276}},	//   _nzab, _dāna, _mdsb_, имим_, 
   {{0x6f0e2681,0x2ee80ac5,0x6288716e,0x6d5c02d0}},	//   _ajac, _alaf_, sgeo, dpsa, 
   {{0x6e2e2682,0x1ec81b10,0x6350a09f,0xd00c040b}},	//   _azab, ални_, _fāna, ہلی_, 
   {{0x2ee803cb,0x635000b8,0x5ef80107,0x00000000}},	//   _claf_, _gāna, рхор_, --, 
   {{0x21687de3,0xd00c035c,0x6f0e2683,0x6e2c0139}},	//   _тили_, فلی_, _djac, _ğobä, 
   {{0x6e2e2684,0x2ee829ef,0x64903881,0x00000000}},	//   _dzab, _elaf_, _užič, --, 
   {{0x8c403352,0x1ca403e6,0x6d5c0af9,0x635000dc}},	//   дере, مێکی_, apsa, _yāna, 
   {{0xda64384b,0x2eea2685,0xdc38031c,0xdbc40037}},	//   تاسي, _glaf_, għġi, köög, 
   {{0x6ee401ec,0x6d5c035a,0x00000000,0x00000000}},	// [3f440] _ءسىل, cpsa, --, --, 
   {{0x7f440ba7,0xed5800bc,0x310c00dc,0x3c8401d5}},	//   _hiiq, íže_, िचयः_, _экоҳ, 
   {{0x7d1de59a,0x661c05ac,0x5b340024,0x00000000}},	//   mors, _øskj, _мэму, --, 
   {{0x7d1e2686,0x7f440009,0x00000000,0x00000000}},	//   lors, _jiiq, --, --, 
   {{0x6ab405f5,0x63500374,0x7f440009,0x7ae40024}},	//   _эсэх, _rāna, _miiq, mkit, 
   {{0xd37818b6,0x7d1c0c58,0x7ae62687,0x39962688}},	//   ачи_, nors, lkit, mäs_, 
   {{0x7ae62689,0x39940108,0x63500335,0x04400114}},	//   okit, läs_, _pāna, мељн, 
   {{0x7d1e268a,0x7ae6268b,0xf0040323,0x273000db}},	//   hors, nkit, үүди, _كۉلس, 
   {{0x7d1e268c,0x7ae6268d,0x23682d2b,0x3996268e}},	//   kors, ikit, ćaja_, näs_, 
   {{0x63500053,0x7d1dcfff,0x3b000009,0x7cf0007c}},	//   _wāna, jors, hiiq_, _härf, 
   {{0x6e2c066d,0x6352268f,0x73c429db,0x7f440009}},	//   _szab, _tāna, _хәле, _biiq, 
   {{0x7ae40054,0x39941b5d,0x7cf00267,0x8de801d5}},	//   jkit, käs_, _järf, афга_, 
   {{0x7f440067,0x3b000067,0x7cf00139,0x6d5c513f}},	//   _diiq, diiq_, _märf, upsa, 
   {{0x7d1e2690,0x7ae47e28,0xcee801d5,0x39940139}},	//   gors, ekit, ارگن_, däs_, 
   {{0x7f440014,0x0a68013e,0x6f0c0267,0x3b00058a}},	//   _fiiq, ираи_, _tjac, fiiq_, 
   {{0x7ae489f7,0x6f0c2798,0x6d5e2691,0x2ee801c7}},	//   gkit, _ujac, ppsa, _ulaf_, 
   {{0x6f1e2692,0x6e2c01aa,0x3d940220,0x19c0151e}},	// [3f450] mosc, _uzab, _жиыр, нәрг, 
   {{0x7d1e2693,0xa2a013b4,0x6eec0a85,0x6d4c00ad}},	//   cors, _कॉन्, _dûbe, _iuaa, 
   {{0x6d443cff,0x6d4e2694,0x7cf0007c,0x7ae42e26}},	//   _iiha, _huaa, _bärf, bkit, 
   {{0x6f1e2695,0x6d462696,0x7ae5cfb0,0x7f45b052}},	//   nosc, _hiha, ckit, _xiiq, 
   {{0x6d462697,0x7cf004f3,0x49906f43,0x63a00232}},	//   _kiha, _därf, _زیار, _spln, 
   {{0x6d462698,0xd4641789,0x6f1e2699,0x6d4e269a}},	//   _jiha, пише_, hosc, _muaa, 
   {{0x6d46269b,0x6d4e269c,0x2902269d,0xdbc400c5}},	//   _miha, _luaa, miha_, söög, 
   {{0x6d46269e,0x2902269f,0x659626a0,0x28c8694b}},	//   _liha, liha_, _набу, रावि, 
   {{0x7d1c0ab7,0x6d4626a1,0x6d4ce9a0,0x7f443a73}},	//   yors, _oiha, _nuaa, _riiq, 
   {{0x6d4626a2,0x7ae401c6,0x7f442878,0xe8d80521}},	//   _niha, zkit, _siiq, kpọ_, 
   {{0x7ae626a3,0x7d1e26a4,0x6d4c1cab,0x63a00122}},	//   ykit, vors, _auaa, _upln, 
   {{0x29000e02,0x6f1e26a5,0x656a26a6,0x7d1e26a7}},	//   hiha_, gosc, _kweh, wors, 
   {{0x6d4626a8,0x7cf0033d,0x635000b0,0x290226a9}},	//   _biha, _järg, _kāno, kiha_, 
   {{0x6d44d304,0x6d4c3386,0x7cf0007d,0x635000da}},	//   _ciha, _duaa, _märg, _jāno, 
   {{0x6d448da6,0x7d1e26aa,0x6f1e26ab,0xd0043c1f}},	//   _diha, rors, bosc, _неше_, 
   {{0x7d1e26ac,0x6f1c4d72,0x65680117,0x6d44e32f}},	//   sors, cosc, _oweh, _eiha, 
   {{0x7ae510ac,0x6d4626ad,0x3ea0b670,0x84e805d7}},	// [3f460] rkit, _fiha, _ibit_, जघाट_, 
   {{0x7ae626ae,0x6d44d9a6,0x23bc0a28,0x290051e2}},	//   skit, _giha, ्माद, giha_, 
   {{0x7ae626af,0x6568014b,0x27e00076,0x6350002b}},	//   pkit, _aweh, gyhn_, _sānn, 
   {{0xd94626b0,0x6d442dab,0x6568b1ee,0x7cf226b1}},	//   _неми, _ziha, _bweh, _bärg, 
   {{0x290226b2,0x6d4626b3,0x3ea226b4,0x28c87e2a}},	//   biha_, _yiha, _mbit_, राशि, 
   {{0x6d4407a9,0x798417fa,0xe81c2ce6,0x63500055}},	//   _xiha, mriw, _बुवा_, _vānn, 
   {{0xba080201,0xdc3400c8,0x3ea00393,0x63500055}},	//   _ወር_, האַט_, _obit_, _dāno, 
   {{0x7cf0338d,0x635000b8,0x8778011a,0x00000000}},	//   _färg, _tānn, _לאלי, --, 
   {{0x6568006a,0x6f1e26b5,0x7cf226b6,0x7984a4e6}},	//   _gweh, vosc, _kärd, nriw, 
   {{0x3ea226b7,0x261400af,0x6d4c02b5,0x201800ac}},	//   _abit_, _फुटी_, _ruaa, əsiz_, 
   {{0x6d461661,0x798404c4,0x6d4c1484,0x271006d9}},	//   _riha, hriw, _suaa, ląna_, 
   {{0x6d44730f,0x7cf0453e,0x6d4c0194,0x3dc000ad}},	//   _siha, _lärd, _puaa, _briw_, 
   {{0x6d442f2b,0x290226b8,0x3dc00368,0x271005da}},	//   _piha, yiha_, _criw_, nąna_, 
   {{0x6f1c1e0b,0xcee803e6,0x3dc00042,0x79840221}},	//   sosc, _گرتن_, _driw_, driw, 
   {{0x6d4626b9,0x6f1e26ba,0x6d4c0036,0x0fe0010b}},	//   _viha, posc, _wuaa, _чөпү, 
   {{0x6d4e26bb,0x3dc00142,0x6d454022,0x29001e91}},	//   _tuaa, _friw_, _wiha, wiha_, 
   {{0x290226bc,0x6d4626bd,0x60840150,0x7984373a}},	// [3f470] tiha_, _tiha, _ءشۇك, griw, 
   {{0x65685553,0x63ac0034,0x2d9a26be,0x6d446600}},	//   _rweh, łani, mtse_, _uiha, 
   {{0x7cf06713,0x2d9a26bf,0x24900139,0x79840241}},	//   _särg, ltse_, _özmi_, ariw, 
   {{0x2d9a26c0,0x290226c1,0x7cf0000d,0xaae000bc}},	//   otse_, siha_, _pärg, _नविक, 
   {{0x2d9a26c2,0x290226c3,0xe81c1533,0x7cf226c4}},	//   ntse_, piha_, _बुरा_, _färd, 
   {{0xd1e00020,0xd1c41e38,0x2d9a26c5,0xdb1c0129}},	//   ኝነት_, ጽነት_, itse_, _arpè, 
   {{0x2d980254,0x00000000,0x00000000,0x00000000}},	//   htse_, --, --, --, 
   {{0x656807a8,0x2d98cd88,0x7cf0f024,0x00000000}},	//   _tweh, ktse_, _iäre, --, 
   {{0x7cf226c6,0x635000b0,0xe73800ee,0x3ea013be}},	//   _häre, _tāno, _гең_, _rbit_, 
   {{0x600a26c7,0x7b3c00b0,0x2d9800ca,0x7cf226c8}},	//   жном_, _hōut, dtse_, _käre, 
   {{0x273404f3,0x7cf0033d,0x2d9a26c9,0x7b3c02b5}},	//   gång_, _järe, etse_, _kōut, 
   {{0x141800c8,0x2d99b8b1,0x7cf226ca,0x93440228}},	//   _וועב, ftse_, _märe, _قىلۇ, 
   {{0x1cc0003d,0x7cf0008e,0xaad000bc,0x6e280210}},	//   _གོད_, _läre, हानक, żebn, 
   {{0x6d4000ee,0x3dc000ad,0x25b803b2,0xed5800d0}},	//   ňlan, _vriw_, _áslu_, íža_, 
   {{0x3ea006a3,0x2d98282c,0xe81c05f9,0x2ca001ab}},	//   _tbit_, atse_, _बुला_, _dbhd_, 
   {{0x3ea08b19,0x3dc00042,0x798401c7,0x7cf03648}},	//   _ubit_, _triw_, triw, _särd, 
   {{0x798400ec,0x7cf226cb,0x6bd54060,0xad2401e2}},	// [3f480] uriw, _pärd, وتېر, _ګريو, 
   {{0x7cf15604,0x79840e14,0x2734072b,0x00000000}},	//   _bäre, rriw, hånd_, --, 
   {{0x7cf004f3,0xda64da86,0x779403e6,0x00000000}},	//   _värd, _овни, عیرا, --, 
   {{0x7cf226cc,0x6fb21141,0xc6a02424,0xe7440184}},	//   _däre, _जनसं, врши, еүсе_, 
   {{0xab68031c,0x00000000,0x00000000,0x00000000}},	//   rażż, --, --, --, 
   {{0x7cf0008e,0x00000000,0x00000000,0x00000000}},	//   _härb, --, --, --, 
   {{0x7cf226cd,0x1cc00135,0x969400a8,0x93880d30}},	//   _gäre, _གོན_, _ораш, іска_, 
   {{0x7cf0007c,0xc6c00d1d,0x2734007c,0x00000000}},	//   _järb, _ийск, vång_, --, 
   {{0xd0840262,0x7cf226ce,0x00000000,0x00000000}},	//   мыни, _zäre, --, --, 
   {{0x5434d80b,0xd4c40597,0x27340267,0xc0540111}},	//   _قرار, _تغري, tång_, мію_, 
   {{0x27344e9b,0x7cf00724,0x2564007f,0xef1800de}},	//   bånd_, _xäre, _vňlň_, zuļu_, 
   {{0x5184084c,0x2d980198,0x7cf0369a,0x27340267}},	//   _жука, ttse_, _närb, rång_, 
   {{0x2d98257c,0x61ec010b,0x273401e3,0xa020000d}},	//   utse_, _ýalp, sång_, ööre, 
   {{0x2d99989a,0x273401e3,0x00000000,0x00000000}},	//   rtse_, pång_, --, --, 
   {{0x7cf05df4,0x273400b5,0x2d9a26cf,0x00000000}},	//   _bärb, låne_, stse_, --, 
   {{0xa2a001bc,0x4ea40063,0x6e9400d8,0x00000000}},	//   क्प्, _црка, _џипу, --, 
   {{0x1cc00489,0x693400d8,0xa3b41414,0x7cf03453}},	// [3f490] _གོཝ_, енау, _चैन_, _därb, 
   {{0x7cf226d0,0x00000000,0x00000000,0x00000000}},	//   _päre, --, --, --, 
   {{0x7b3c00b0,0x7cf226d1,0x64a40022,0x00000000}},	//   _pōut, _färb, ҵала, --, 
   {{0x7cf226d2,0x26c825e6,0xe63401c6,0x00000000}},	//   _väre, ñao_, нхлэ, --, 
   {{0x7cf0097d,0x6aae26d3,0x64a41a5c,0x635000b8}},	//   _wäre, meaf, еала, _vānm, 
   {{0xa3b9850d,0x6aae26d4,0x7cf11193,0x83740092}},	//   كابر_, leaf, _täre, _አይዞህ_, 
   {{0x2734049f,0x7cf0002f,0x98a80064,0xa3e9b8ec}},	//   tånd_, _härc, _aibė_, ядка_, 
   {{0x6aae0532,0x7cf226d5,0x7b3c00b0,0xd24c675b}},	//   neaf, _xärb, _hōur, مچه_, 
   {{0x7b3c04fe,0xd1800166,0x00000000,0x00000000}},	//   _kōur, глый, --, --, 
   {{0xba08206f,0x1f64ba72,0x7cf226d6,0xe0d000c6}},	//   _ወይ_, нком, _märc, ازة_, 
   {{0x6aac0770,0x5f042bb7,0x7cf0343a,0x92ac03d4}},	//   keaf, езна, _lärc, _ওচৰ_, 
   {{0xd354010f,0x6aac005c,0x716400cf,0x00000000}},	//   _טשעק_, jeaf, راۋك, --, 
   {{0xcd3c08b0,0x6aae26d7,0xb5e801e1,0x00000000}},	//   ﻨﻨﯩﯔ_, deaf, _nẹ́r, --, 
   {{0x7cf226d8,0x661c06ea,0x6578031c,0x00000000}},	//   _särb, _øsku, iswh, --, 
   {{0x6aac0421,0x3ae80214,0x60240166,0x00000000}},	//   feaf, وبری_, _ядка, --, 
   {{0x1cc00867,0xb5e801e1,0x6aaca563,0x7cf0002f}},	//   _གོམ_, _bẹ́r, geaf, _bärc, 
   {{0x7cf0014a,0x2f1800db,0xddb400ae,0x00000000}},	// [3f4a0] _värb, _تىيگ_, _أحبب, --, 
   {{0xa2a006ab,0xd944a63b,0x6d94010e,0x00000000}},	//   _कॉस्, хези, _wýaç, --, 
   {{0x7cf00724,0x99080014,0x00000000,0x00000000}},	//   _tärb, _ہتسِ_, --, --, 
   {{0xb5e80248,0x6aac1168,0xcf900a7c,0x00000000}},	//   _fẹ́r, ceaf, רטא_, --, 
   {{0x6ed00882,0x3494020a,0x8a4001d9,0x09e226d9}},	//   धातु, валр, _مێٲن, _боян, 
   {{0x69b4000d,0x00000000,0x00000000,0x00000000}},	//   _उनती, --, --, --, 
   {{0x65780857,0xd6f8030d,0x2794022e,0x00000000}},	//   aswh, _ехаш_, _иштр, --, 
   {{0x75843007,0x657802d0,0x320800c7,0xe298030d}},	//   _аңда, bswh, мҭеи_, çак_, 
   {{0x65780175,0x257000cf,0x00000000,0x00000000}},	//   cswh, _نۇنس, --, --, 
   {{0x73c40124,0xfce80023,0x00000000,0x00000000}},	//   _аӡиа, _ዘምጾ_, --, --, 
   {{0xba08001f,0x2f180108,0x00000000,0x00000000}},	//   _ወጭ_, донь_, --, --, 
   {{0x79500023,0x6ed0012d,0x00000000,0x00000000}},	//   ማኖታት, धाधु, --, --, 
   {{0x8108004b,0x6aac005c,0x0dc91d0b,0x0560010a}},	//   _کرنې_, veaf, чуни_, _ывăн, 
   {{0x81b4011a,0x00000000,0x00000000,0x00000000}},	//   _נהוג_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7cf00e78,0x7f80007b,0x657802d0,0x00000000}},	//   _pärc, _إلين, yswh, --, 
   {{0x6aae26da,0xfeb80502,0x7b3c0053,0xdcf40030}},	// [3f4b0] reaf, _سايت_, _pōur, _zvyč, 
   {{0x6aae26db,0x00000000,0x00000000,0x00000000}},	//   seaf, --, --, --, 
   {{0xeb38010a,0x00000000,0x00000000,0x00000000}},	//   _озош_, --, --, --, 
   {{0x87241da8,0x657a26dc,0xf6507b7a,0x7cf000fd}},	//   رعام, tswh, مئه_, _tärc, 
   {{0x7cf00267,0x63500055,0xa4d400d4,0xe81c01f9}},	//   _hära, _tānk, коді, _बँका_, 
   {{0x2a6a26dd,0x64a626de,0xf484026a,0xe3b0475c}},	//   lbab_, така, гућн, لرب_, 
   {{0xc6a44712,0x7cf00254,0x6350e261,0x657802d0}},	//   _праи, _jära, _kāni, sswh, 
   {{0xd24dbd02,0x6350005f,0x7cf0bc64,0xd36c00ec}},	//   ينى_, _jāni, _mära, آهي_, 
   {{0x7cf004f3,0x26cd5005,0x6350f981,0xae000037}},	//   _lära, _ineo_, _māni, _लेलन_, 
   {{0xaba4044e,0xa2a02274,0xf994011a,0x00000000}},	//   _ህግድፍ_, _कॉर्, ארץ_, --, 
   {{0x03c53de3,0x7cf040c3,0x00000000,0x00000000}},	//   _ясам, _nära, --, --, 
   {{0x3358084c,0x6350002b,0x00000000,0x00000000}},	//   _чацэ_, _nāni, --, --, 
   {{0xa3b47aec,0x00000000,0x00000000,0x00000000}},	//   _चैत_, --, --, --, 
   {{0x7cf0348c,0x796801e1,0x23c400cd,0x602401a9}},	//   _bära, _léwò, विपद, _идла, 
   {{0x5a9412c4,0xde3c0092,0x00000000,0x00000000}},	//   краф, ተመዘገ, --, --, 
   {{0x7a382833,0x7cf001e6,0x635000cd,0xddc400db}},	//   _nútí, _dära, _cāni, _абии, 
   {{0x635000e2,0x0b8c0092,0x00000000,0x00000000}},	// [3f4c0] _dāni, _ዝውውር_, --, --, 
   {{0xa2a07922,0x7cf00139,0x2a680009,0x28c807b6}},	//   क्त्, _fära, abab_, रागि, 
   {{0x2a680b45,0x7cf00139,0x4788030d,0x00000000}},	//   bbab_, _gära, çсем_, --, 
   {{0x941c013f,0x60cc03f9,0xc0cc02d3,0x24880198}},	//   _matɔ_, _ɗama, _እኽሊ_, ɗami_, 
   {{0x8e540bd9,0x272c0023,0xf1a00150,0xa2d43711}},	//   דינג_, _ድኣምበ, _ﺃﻴﺎﻡ_, भान्, 
   {{0x26ce26df,0x7cf00784,0x28b8084c,0x09d80154}},	//   _eneo_, _yära, _пусэ_, _ঠেকা, 
   {{0xc6200154,0xcfc80150,0xc0d40023,0x7cf00166}},	//   বেলা_, _ﯗﻳﺎﺗ, ኮኑስ_, _xära, 
   {{0x78be26e0,0x00000000,0x00000000,0x00000000}},	//   _harv, --, --, --, 
   {{0xaba4067d,0x78be26e1,0x50641836,0xd62415eb}},	//   _ህግደፍ_, _karv, ктна, _شعري, 
   {{0x78be26e2,0x3f800003,0x00000000,0x00000000}},	//   _jarv, ġjun_, --, --, 
   {{0x27340158,0x78be26e3,0x673002d2,0x00000000}},	//   låna_, _marv, _áhjó, --, 
   {{0x78be26e4,0x7cf002b1,0x00000000,0x00000000}},	//   _larv, _rära, --, --, 
   {{0x7cf2258e,0x635002b1,0xc3c001c6,0x7e2800d4}},	//   _sära, _rāni, _бөөл, віра_, 
   {{0x7cf0033d,0x78bdfc88,0x4fc45822,0x958002d3}},	//   _pära, _narv, _асиа, _ናይተን_, 
   {{0x63501d77,0x01340375,0x2a68002e,0x69b400c5}},	//   _pāni, _שרות_, tbab_, _उनही, 
   {{0x78bc05ac,0x7cf000af,0x00000000,0x00000000}},	//   _aarv, _vära, --, --, 
   {{0x78be26e5,0x23681b24,0xf9904363,0x7a3808a5}},	// [3f4d0] _barv, ćaji_, قبل_, _rútí, 
   {{0x6e2c4509,0x7cf226e6,0x78be26e7,0x33240003}},	//   _iyab, _härn, _carv, homx_, 
   {{0xf77016a0,0x78be26e8,0x7cf069ee,0xaba402d3}},	//   قان_, _darv, _kärn, _ህግዲፍ_, 
   {{0x7cf0049f,0x75280810,0x78bc07c5,0x6e2c2252}},	//   _järn, _akdz, _earv, _kyab, 
   {{0x78be26e9,0x7bd80311,0x635000b8,0x9f4c0118}},	//   _farv, ăbuş, _jānv, ěném_, 
   {{0x78be26ea,0x7cf0ed6e,0x6abe26eb,0x00000000}},	//   _garv, _lärn, _hasf, --, 
   {{0x074626ec,0x6e2c0a49,0x248800ac,0x6abc030a}},	//   _ахам, _lyab, ğam_, _kasf, 
   {{0x248836b5,0x6e2e26ed,0x26cc009b,0x78bcf454}},	//   şam_, _oyab, _uneo_, _zarv, 
   {{0x6e2e26ee,0xe0d06f43,0xdee41b74,0x6abe26ef}},	//   _nyab, مزد_, ҳони, _masf, 
   {{0x2cb0012c,0x35f40276,0x440400db,0x00000000}},	//   jezd_, _тпур, _ичеб, --, 
   {{0x6e2e26f0,0xdee626f1,0x2cb064bb,0x7cf0007c}},	//   _ayab, гони, dezd_, _bärn, 
   {{0x6e2e26f2,0x6304446a,0x6abc0161,0x6728031c}},	//   _byab, _حوصل, _nasf, _jkej, 
   {{0xa0a40372,0x6e2c01aa,0xd00c07d6,0xdcf400cd}},	//   _балд, _cyab, قلی_, _avyā, 
   {{0x61ea26f3,0x6e2e26f4,0x4f840014,0x1ca40133}},	//   myel, _dyab, خایہ, چێکی_, 
   {{0x61ea26f5,0x1ca404d3,0x6e2c5a26,0xefe4001f}},	//   lyel, نێکی_, _eyab, ኝተው_, 
   {{0x78bc18e5,0x7cf004f3,0x672800b4,0xdcf4002b}},	//   _sarv, _gärn, _nkej, _dvyā, 
   {{0x78be26f6,0x6e2c2252,0xdb1c3873,0x80b401ad}},	// [3f4e0] _parv, _gyab, _arpã, _असाइ, 
   {{0x63500374,0x4a400763,0x6728e743,0x00000000}},	//   _hānu, снув, _akej, --, 
   {{0x78be26f7,0x6abc02a8,0x635002b5,0x6728031c}},	//   _varv, _fasf, _kānu, _bkej, 
   {{0x6728031c,0x2fd800c5,0x61e804ba,0x635000cd}},	//   _ckej, ärgi_, kyel, _jānu, 
   {{0x78bc05c3,0x29d4006c,0x635157ee,0xaad018cc}},	//   _tarv, _кўрс, _mānu, हारक, 
   {{0x6298011f,0x61ea26f8,0x67280ca8,0xa2a019cc}},	//   _acwo, dyel, _ekej, क्स्, 
   {{0x61e802ea,0x7cf001e6,0x27340158,0xe504007b}},	//   eyel, _läro, såna_, جبني, 
   {{0xd8740220,0x9f4402f0,0xc5600131,0x635000dc}},	//   _جاڭب, bylé_, шкәк, _nānu, 
   {{0x61e8066d,0xa804056a,0x7cf00267,0x28c80404}},	//   gyel, poñí, _näro, राचि, 
   {{0x6e2c015c,0xa3b40a28,0xa5600050,0x045447ea}},	//   _ryab, _चैव_, _بۯون, _ملكة_, 
   {{0x7cf0033d,0x6e2c0092,0x2cb001d3,0x635000b8}},	//   _pärn, _syab, vezd_, _sānv, 
   {{0x61e80564,0x635000dc,0x67280327,0x6e2c00b8}},	//   byel, _cānu, _xkej, _pyab, 
   {{0x7cf03894,0x6abe26f9,0x2124067c,0x91e402bf}},	//   _värn, _rasf, bolh_, _щоде, 
   {{0x6e2e26fa,0xe81c0307,0xeb1c3507,0x7cf001e3}},	//   _vyab, _बुझा_, भक्त_, _däro, 
   {{0x6abe26fb,0x7cf06da3,0xae0000af,0x8aa40212}},	//   _pasf, _tärn, _लइकन_, лрад, 
   {{0x6a1494fb,0x7cf0049f,0x6e2cf95d,0x79a49735}},	//   амбу, _härl, _tyab, әрте, 
   {{0x6e2c0028,0x7cf0049f,0x6abe26fc,0xaca401af}},	// [3f4f0] _uyab, _kärl, _vasf, _кѳнһ, 
   {{0x672a26fd,0x635000dc,0x7cf0007c,0x00000000}},	//   _skej, _kānt, _järl, --, 
   {{0x6abe26fe,0x63500055,0x61e802e2,0x00000000}},	//   _tasf, _jānt, zyel, --, 
   {{0xf7711d2e,0xb8ec09d9,0xf99000dd,0x7cf00267}},	//   سام_, _शो_, تبہ_, _lärl, 
   {{0xddd80156,0xa88401d9,0xd0040451,0x7cf001e3}},	//   ོདགླ, _پلزى, _ڀل_, _oärl, 
   {{0xe795b9a6,0x7cf00267,0x61ea26ff,0xe9180153}},	//   _پاسک, _närl, vyel, _рогі_, 
   {{0x629a2700,0x21262701,0x6728031c,0x635000cd}},	//   _pcwo, volh_, _tkej, _nānt, 
   {{0x61ea2702,0xf3c8030f,0xdb1c02f0,0xfa9800df}},	//   tyel, ابوه_, _krpá, ָדזש_, 
   {{0xa2a0085c,0x635000b0,0x3f800327,0x00000000}},	//   क्ष्, _rānu, ġjum_, --, 
   {{0x20562703,0x635000dc,0x60e804b0,0x00000000}},	//   штир, _sānu, тмом_, --, 
   {{0x63522704,0x7cf001b8,0x61e9f0fd,0x38640213}},	//   _pānu, _därl, syel, _əmr_, 
   {{0x7cf211c5,0x635000cd,0x2124067c,0x81740117}},	//   _päro, _dānt, solh_, _бадӣ_, 
   {{0x23680bb8,0x7cf00139,0x61e80113,0xde3402d5}},	//   ćaju_, _färl, qyel, рэнь, 
   {{0x25ac009a,0x7cf020b2,0xa2a0190c,0x1fa8010a}},	//   _mpel_, _gärl, क्र्, _акки_, 
   {{0xddd4002b,0xdb1c00d7,0x60c003ac,0x63511be1}},	//   _keyū, _arpá, mdlm, _tānu, 
   {{0x25ae2705,0xda64569c,0x50180375,0x7cf000b0}},	//   _opel_, شاري, _שוקו, _täro, 
   {{0x7cf22706,0x6f1c0077,0x998401d5,0x98542377}},	// [3f500] _härm, érce, شلاو, атеш, 
   {{0x1be8013e,0x7cf021c6,0x60c0002f,0x186857c6}},	//   _адои_, _kärm, ndlm, тажи_, 
   {{0x25ae2707,0x7cf00254,0x635000b8,0x00000000}},	//   _apel_, _järm, _māns, --, 
   {{0x6350002d,0x7cf00166,0x7c28000d,0x00000000}},	//   _lāns, _märm, üdru, --, 
   {{0x7cf01cc4,0x95980220,0xd76400e5,0x00000000}},	//   _lärm, ттеу_, _چارٹ, --, 
   {{0xed581d55,0x61ec00ee,0x00000000,0x00000000}},	//   íži_, _ýaly, --, --, 
   {{0x7cf004f3,0x25ac60d9,0x85001afc,0xb6c43c1a}},	//   _närm, _epel_, توون, _гөлд, 
   {{0x387958a2,0x6b822708,0x7cf0007c,0x635000b8}},	//   _herr_, álgi, _särl, _rānt, 
   {{0x7cf22709,0xd1383e09,0xab800023,0xb274035b}},	//   _pärl, кхо_, _ክውዕል_, акқә, 
   {{0x3879b0e2,0x4fc6270a,0xd36c0617,0x7cf00166}},	//   _jerr_, асма, _قۇت_, _bärm, 
   {{0x7cf00628,0x3878044e,0x08540302,0xd14803e6}},	//   _värl, _merr_, יבים_, _یشتن_, 
   {{0x7cf0049f,0x387a270b,0x6350002b,0x00000000}},	//   _därm, _lerr_, _vānt, --, 
   {{0xae0005ba,0x1fc40022,0x7cf020a9,0x00000000}},	//   _लेखन_, _ҳрыҳ, _tärl, --, 
   {{0x7cf2270c,0x6350002b,0x00000000,0x00000000}},	//   _härj, _tānt, --, --, 
   {{0x7cf2270d,0xead4023a,0x6fb400ec,0x00000000}},	//   _kärj, бовь, _چمڪا, --, 
   {{0x7cf005c3,0xaa540395,0x2fd80254,0x00000000}},	//   _järj, сваш, ärgu_, --, 
   {{0x38780dd4,0x80c80490,0x7cf000c5,0xac940108}},	// [3f510] _berr_, _थोडे, _märj, _лапш, 
   {{0x7cf148ae,0xc86400c7,0x00000000,0x00000000}},	//   _lärj, ртаи, --, --, 
   {{0xa6543306,0x25ad7fbb,0x387a270e,0x00000000}},	//   مَات, _spel_, _derr_, --, 
   {{0x8aa41d39,0x2a6c010e,0x00000000,0x00000000}},	//   _трод, _ýeb_, --, --, 
   {{0x387a270f,0xe29806ba,0xa2d4012a,0x65c401a9}},	//   _ferr_, қап_, भास्, сбла, 
   {{0x38780076,0x78822710,0x2a780142,0x3f8001d3}},	//   _gerr_, ráví, _hesb_, ájuk_, 
   {{0x6b9401a9,0x00000000,0x00000000,0x00000000}},	//   nuzg, --, --, --, 
   {{0x387801fa,0xfc18011a,0x63500171,0x00000000}},	//   _zerr_, יקוי_, _sāns, --, 
   {{0x387805b1,0x25ac260d,0xa0a400ee,0x7cf00108}},	//   _yerr_, _upel_, бапд, _särm, 
   {{0x7cf22711,0x9f4c012c,0x2a78adc8,0xe0d80a5b}},	//   _pärm, ěním_, _lesb_, уво_, 
   {{0xe43496d3,0x7cf001e6,0xa0c4004b,0x43700150}},	//   _افاد, _färj, ليکو, _بۇعر, 
   {{0x7cf004f3,0x1ef80597,0x613c20ef,0x2258005b}},	//   _värm, اعدة_, dèle, _сиды_, 
   {{0xd2540bd4,0x7cf00730,0x71700873,0x9d440032}},	//   _השנה_, _wärm, _قۇيا, йемд, 
   {{0x2d5c0241,0xa2d406ff,0x71247610,0x6b9401a9}},	//   _dìe_, भाव्, _ورول, fuzg, 
   {{0x7cf08fa4,0x6d5c1db9,0xd9b0190c,0xdee4022e}},	//   _härk, aqsa, ुट्ट, _гойи, 
   {{0x7cf002f6,0x387946e4,0x9ef40214,0x80b401ad}},	//   _kärk, _serr_, _دستش, _असुं, 
   {{0x387a2712,0x7cf0049b,0x9f4401ed,0x7e640248}},	// [3f520] _perr_, _järk, szló_, _ifip, 
   {{0x7cf22713,0x23a00034,0x98562714,0x98d000bc}},	//   _märk, kój_, сташ, साइए, 
   {{0x387a2715,0x2a7801a6,0x613c0129,0x7cf001e3}},	//   _verr_, _fesb_, cèle, _lärk, 
   {{0x6eec0086,0x3878020c,0x00000000,0x00000000}},	//   _dûbw, _werr_, --, --, 
   {{0x94100cc1,0x387a2716,0x63a001a9,0x7cf22717}},	//   əyə_, _terr_, _aqln, _närk, 
   {{0x7cf0340f,0x80a40154,0x00000000,0x00000000}},	//   _särj, _কোস্, --, --, 
   {{0x7e64014b,0x7cf06583,0x779401d3,0x256c0241}},	//   _ofip, _pärj, _ذیشا, _pólò_, 
   {{0x7cf062c8,0x6130022e,0x037400db,0x00000000}},	//   _bärk, _sаlо, ححوت_, --, 
   {{0xd46809a5,0x7cf0c6cb,0x8658011a,0x546807a5}},	//   _бизе_, _värj, _תדמי, _базм_, 
   {{0x7e640248,0x225800d0,0x301400cf,0x23a0012d}},	//   _afip, ľska_, ждор, bój_, 
   {{0x225802f0,0x00000000,0x00000000,0x00000000}},	//   žska_, --, --, --, 
   {{0x613c4056,0x20101de4,0x6b9401a9,0x9f4401ef}},	//   vèle, úzia_, vuzg, bylí_, 
   {{0xa2d42311,0xb800045e,0x7cf00209,0x51600248}},	//   भार्, ্থিত_, _kärh, _fọọm, 
   {{0x7e64014b,0x51600521,0x2a786490,0x0cd402f5}},	//   _efip, _gọọm, _sesb_, হস্ত, 
   {{0x7cf0013d,0x80a0009f,0x00000000,0x00000000}},	//   _zärk, _رمين, --, --, 
   {{0xb80004c5,0x2d5c01e1,0x7cf00139,0x00000000}},	//   ্থাত_, _tìe_, _yärk, --, 
   {{0x6b940bd7,0x49b80214,0x19c004b4,0x00000000}},	// [3f530] suzg, دازد_, мәрг, --, 
   {{0x7cf004f3,0x613c068c,0x6e9448dc,0x00000000}},	//   _närh, pèle, _الکا, --, 
   {{0xe7b42ed7,0xa7b802dd,0x47840137,0xf39000b8}},	//   تماد, рлеу_, сызб, _kṣud_, 
   {{0x7bc0f981,0xddc40055,0x00000000,0x00000000}},	//   āmut, cakų, --, --, 
   {{0x1a9800c8,0x85a40640,0xc588023a,0xb4c401ad}},	//   _דירע, сјед, ущее_, एयू_, 
   {{0x80b402ab,0xa3b802da,0xa3e85bc6,0x00000000}},	//   _असें, لابر_, идла_, --, 
   {{0x7cf1a379,0xf7940006,0xe29801c4,0x00000000}},	//   _särk, _нарэ, аай_, --, 
   {{0xf770315f,0x630401a9,0x23a00034,0x6595d686}},	//   _ساف_, توبل, rój_, _мабу, 
   {{0xd24c006c,0x6d58034c,0x7cf020b2,0x00000000}},	//   نچه_, _éwah, _färh, --, 
   {{0x9f8450dd,0x7cf22718,0x65695d0b,0x23a0012d}},	//   огод, _värk, _iteh, pój_, 
   {{0x660401e0,0x544000db,0x733400e5,0xd24c00e5}},	//   _упҡа, _ۉچۉك, _کرلئ, ٹنی_, 
   {{0x7cf0049b,0x2f543f51,0x3f8896c0,0xd24c072d}},	//   _tärk, ятьс, čcu_, عنی_, 
   {{0x7cf001e6,0x6f1c04d4,0x00000000,0x00000000}},	//   _häri, érca, --, --, 
   {{0xa06a2719,0x80a400bd,0x7cf02347,0xc0c80640}},	//   _така_, _কোর্, _käri, _људе_, 
   {{0xf0b821f4,0xc620015b,0x7cf016ca,0x9f040133}},	//   _دانش_, বেচা_, _järi, _ووتو, 
   {{0x7e641bb6,0x656a271a,0x7cf1a426,0x8c400166}},	//   _ufip, _oteh, _märi, фесе, 
   {{0x6568016b,0x3ea139bd,0x3afc01e1,0x00000000}},	// [3f540] _nteh, _icit_, _nípe_, --, 
   {{0x3dc0009a,0xe8d80109,0xd9440798,0x00000000}},	//   _isiw_, drỳ_, цези, --, 
   {{0x7cf14f10,0x656a271b,0x9b449e24,0x07a00114}},	//   _näri, _ateh, _ونخو, дахн, 
   {{0x4c380302,0x5018011a,0x23840171,0x00000000}},	//   _כתיב, בועו, dēj_, --, 
   {{0xd946271c,0x348800fb,0x00000000,0x00000000}},	//   _меми, йҡап_, --, --, 
   {{0x7cf0311d,0x23c42c35,0x845401e0,0xf48400f2}},	//   _bäri, विंद, ҙрәт_, ساتی, 
   {{0x334400dc,0x656a271d,0x7986271e,0x00000000}},	//   _aṣṭa, _eteh, lsiw, --, 
   {{0x6568003d,0x7cf2271f,0x44840bd6,0x00000000}},	//   _fteh, _däri, ббән_, --, 
   {{0x3dc0016b,0x798400a9,0x00000000,0x00000000}},	//   _nsiw_, nsiw, --, --, 
   {{0x7cf00724,0x1048036b,0x3ea000d8,0x81400214}},	//   _färi, ияни_, _acit_, ونين, 
   {{0x3dc00054,0x7cf00166,0x334400b8,0x635000b8}},	//   _asiw_, _gäri, _eṣṭa, _tānp, 
   {{0xb8fc003d,0x835001b9,0x7cf00166,0x7985b4dd}},	//   _འོ_, _قپلا, _kärw, ksiw, 
   {{0x79840113,0x7cf00166,0x8570010a,0x00000000}},	//   jsiw, _zäri, _рлĕх, --, 
   {{0x9f4c0118,0x00000000,0x00000000,0x00000000}},	//   ěnám_, --, --, --, 
   {{0xcf247874,0x3dc0013f,0xcb0805f5,0x26100c2e}},	//   _وربي, _esiw_, ахад_, _देनी_, 
   {{0x613c0ba1,0x658c0092,0x00000000,0x00000000}},	//   mèla, _ከግብፅ_, --, --, 
   {{0x6f0e2720,0x8d7442c6,0x79862721,0x613c5051}},	// [3f550] _imac, _باعا, gsiw, lèla, 
   {{0x2d9a2722,0x6f0c0295,0x2ee8030a,0xad4000cf}},	//   muse_, _hmac, _hoaf_, _سۉزۉ, 
   {{0x2d9a2723,0x656a2724,0x7985203e,0x613c067c}},	//   luse_, _steh, asiw, nèla, 
   {{0x2d981709,0xf1bc146b,0x3afc0241,0x8cc000bc}},	//   ouse_, ्टान, _pípe_, िएको, 
   {{0x2d98007d,0x6f0e2725,0x613c0066,0x7cf1549f}},	//   nuse_, _mmac, hèla, _säri, 
   {{0x7cf22726,0x2eea2727,0xdb1c180f,0x613c020c}},	//   _päri, _loaf_, _aspè, kèla, 
   {{0x2d9a2728,0x6f0d20c5,0x00000000,0x00000000}},	//   huse_, _omac, --, --, 
   {{0x2d9a2729,0x7cf2272a,0x85ba272b,0x2b4801f5}},	//   kuse_, _väri, _پارس_, nmac_, 
   {{0x2138019f,0x65688bbb,0x7cf000b0,0x2ca00e89}},	//   îsho_, _uteh, _wäri, _ochd_, 
   {{0x6f0e272c,0xdb1e272d,0x2d9a272e,0x7cf062d2}},	//   _amac, _espè, duse_, _härv, 
   {{0x2d9a272f,0x2ee80036,0x6f0c00b5,0x7cf15605}},	//   euse_, _boaf_, _bmac, _kärv, 
   {{0x7cf018db,0x0afc045e,0x2ca00e89,0xdea0806b}},	//   _järv, ্কুল_, _achd_, ریخی, 
   {{0x2d98007d,0x6f0c005a,0x0ca43042,0x21680395}},	//   guse_, _dmac, गभूम, _уили_, 
   {{0x6f0c192e,0x613c0561,0x7cf001f4,0x00000000}},	//   _emac, bèla, _lärv, --, 
   {{0x2ee80606,0xa02000c5,0x2ca405d5,0xabc401e0}},	//   _foaf_, ööde, òlda_, марҙ, 
   {{0x7cf1bfb8,0x3dc00086,0x2ca00036,0x2ee8030a}},	//   _närv, _tsiw_, _echd_, _goaf_, 
   {{0x1d0874be,0xad2405d9,0x2d98c90d,0x0e98011a}},	// [3f560] _гепи_, _ڪريو, cuse_, _השפל, 
   {{0xd7080b8d,0x798400a9,0xddd40118,0x63ac012d}},	//   әнде_, rsiw, _když, łany, 
   {{0x7f44014b,0x7cf033fe,0xad241913,0x00000000}},	//   _khiq, _bärv, _تريو, --, 
   {{0xdb1c003e,0x2b480066,0x7cf0013d,0x798403cb}},	//   _ospé, cmac_, _pärw, psiw, 
   {{0x7ae62730,0x7cf01f65,0x79840113,0x00000000}},	//   mjit, _därv, qsiw, --, 
   {{0x7ae41591,0xd3781638,0x3f8400f3,0xe9700137}},	//   ljit, бчи_, _ovnu_, _شۇمد, 
   {{0xdb1c7d32,0x7ae401c8,0x7cf00139,0x2d9913ab}},	//   _aspé, ojit, _färv, zuse_, 
   {{0x7ae62731,0x2d9a2732,0x613c180f,0x7cf00139}},	//   njit, yuse_, vèla, _tärw, 
   {{0x6f0c0354,0x2d98108e,0x7cf0007c,0x34a40818}},	//   _rmac, xuse_, _häru, _огаҳ, 
   {{0x6f0e2733,0x2d98007d,0x7f44003a,0x94a80050}},	//   _smac, vuse_, _ahiq, _دارِ_, 
   {{0x6f1c204e,0xdb1dc9c8,0x6e962734,0x2d9a2735}},	//   érco, _espé, ولدا, wuse_, 
   {{0x7f462736,0x2d98033d,0x613c068c,0xa3b4033f}},	//   _chiq, tuse_, rèla, _चैट_, 
   {{0x7f44198f,0x7ae42625,0x2ee8022f,0x613c0ba1}},	//   _dhiq, djit, _voaf_, sèla, 
   {{0x2d9a2737,0x613c4b84,0xc0e0023a,0x00000000}},	//   ruse_, pèla, _почк, --, 
   {{0x2d9a2738,0x7cf0000d,0x7f800a11,0x40300107}},	//   suse_, _näru, _كلون, _пешс, 
   {{0x6f0e2739,0x7ae4044e,0x2d98084c,0x7f440455}},	//   _umac, gjit, puse_, _ghiq, 
   {{0x2b4a273a,0xfe700451,0xa2a0547d,0xfc3001ed}},	// [3f570] rmac_, _صدي_, क्ट्, نحہ_, 
   {{0x2d880618,0x7cf00793,0x2ca008c2,0xac981e24}},	//   _ivae_, _särv, _uchd_, _بندا_, 
   {{0xaa5a273b,0x6f1e273c,0x6d4401f0,0x764000a2}},	//   _ولدا_, onsc, _ihha, _azmy, 
   {{0x6f1e273d,0x2d880158,0x3b000986,0x7cf00267}},	//   nnsc, _kvae_, chiq_, _däru, 
   {{0x6f1e273e,0x7cf016cd,0x49902580,0x855404d3}},	//   insc, _värv, _سیار, سیار_, 
   {{0xa88401d9,0x7cf00166,0x6f1c0112,0x3204012d}},	//   _زلرى, _färu, hnsc, dzmy_, 
   {{0xa2e40c9e,0x7cf2273f,0x29cc0419,0x00000000}},	//   дойд, _iärt, _hľa_, --, 
   {{0x7cf19293,0xe29800a7,0x6f1c01a4,0x29000455}},	//   _härt, цаи_, jnsc, lhha_, 
   {{0x6aac0421,0x05740150,0x69cc3227,0x067c02dd}},	//   ifaf, _ءارد, nvae, _ﺯﻩﻳﯩ, 
   {{0x7f462740,0x6d44037e,0x1f643129,0x29000208}},	//   _shiq, _nhha, мком, nhha_, 
   {{0x7cf22741,0x2d881140,0x26100034,0x3afc0118}},	//   _märt, _avae_, _देती_, _lípa_, 
   {{0x6d462742,0x64422743,0x6f1c03ac,0x7640010e}},	//   _ahha, _izli, gnsc, _yzmy, 
   {{0xa0a41c3e,0x6d4401ab,0xa02000c5,0x3afc110e}},	//   _жалд, _bhha, ööbe, _nípa_, 
   {{0x3e7c01dc,0x6d460e11,0x6f1e2744,0xf1bc084a}},	//   ật_, _chha, ansc, ्टरन, 
   {{0x2d892067,0xd00c78f5,0x7f440ac5,0x6aae2745}},	//   _evae_, _پلي_, _thiq, ffaf, 
   {{0x5f4401d9,0x6d44289d,0x3b000cfe,0xfccc0092}},	//   _تنبل, _ehha, uhiq_, _አሮጌ_, 
   {{0x7ae62746,0x7cf14e48,0x613c004e,0x3b00036e}},	// [3f580] rjit, _bärt, nèlo, rhiq_, 
   {{0x64402808,0x6aac0421,0x3b022747,0x7ae62748}},	//   _ozli, afaf, shiq_, sjit, 
   {{0x7cf13c88,0x6ea4a5cd,0x20062749,0x81e00f22}},	//   _därt, _कामु, nzli_, ননি_, 
   {{0xc68c0014,0x3204349b,0x00000000,0x00000000}},	//   لِم_, yzmy_, --, --, 
   {{0x6442274a,0x7cf004e6,0x6d58003e,0xb594013e}},	//   _azli, _färt, _éwat, хилш, 
   {{0x7cf2274b,0x81e0015b,0x2902274c,0x94a80212}},	//   _gärt, ননা_, chha_, ітла_, 
   {{0x2bd00d01,0x7cf0088f,0xd70419cc,0x00000000}},	//   हिया, _härs, _शतपथ_, --, 
   {{0xa2d49387,0x7cf2274d,0x200579f0,0xfbc0015b}},	//   भाग्, _kärs, dzli_, _উপাত, 
   {{0x7cf06713,0x6440013d,0x6f1c00b5,0x395a274e}},	//   _järs, _ezli, vnsc, _kirs_, 
   {{0x7cf001e3,0x6f1c0784,0x6f744eb1,0x2bd00b02}},	//   _märs, wnsc, нгоф, हिमा, 
   {{0x395a274f,0x9f44005b,0x32040210,0x00000000}},	//   _mirs_, kylä_, szmy_, --, 
   {{0x6f1db26c,0x6d4400b8,0x00000000,0x00000000}},	//   unsc, _shha, --, --, 
   {{0x6f1e2750,0x7cf00724,0x2d88003a,0x20040419}},	//   rnsc, _närs, _qvae_, azli_, 
   {{0x27340ac8,0x2028148b,0x00000000,0x00000000}},	//   lånt_, átið_, --, --, 
   {{0x7c35c59d,0xfb84008e,0x00000000,0x00000000}},	//   верх, кытн, --, --, 
   {{0xcf240bbd,0x69cc0369,0x7cf22751,0xcf400150}},	//   _ترتي, tvae, _bärs, _جىعۋ, 
   {{0x6aac23db,0x395a2752,0x2d8a2753,0x7cf0000d}},	// [3f590] rfaf, _birs_, _uvae_, _pärt, 
   {{0xf1c8001e,0x7cf179ec,0xcc8403e6,0x69ce2754}},	//   _mỡ_, _därs, _زۆره_, rvae, 
   {{0x9cb80156,0x3958f03e,0xf1c8001e,0x69ce2755}},	//   _བྲིས, _dirs_, _lỡ_, svae, 
   {{0x7cf22756,0xd1240133,0x00000000,0x00000000}},	//   _färs, _ڕم_, --, --, 
   {{0x7cf00724,0x6d5800f2,0xf1c8004d,0x6440033f}},	//   _tärt, _éwas, _nỡ_, _szli, 
   {{0x395a2757,0x7cf22758,0x36880116,0x46cc00c5}},	//   _girs_, _härr, псән_, _सोरह, 
   {{0x1cdc038f,0x29104a4a,0x7cf00520,0x6ea40490}},	//   _རོལ_, _imza_, _kärr, _काढु, 
   {{0x2b5801ab,0xf1c80208,0x613c007f,0x644000d7}},	//   _jisc_, _bỡ_, tèlo, _vzli, 
   {{0x2b5a2759,0x9f500316,0xf1c8001e,0x613c067c}},	//   _misc_, ází_, _cỡ_, bèll, 
   {{0x2006275a,0x600a275b,0x644001f7,0xf1c8004d}},	//   tzli_, зном_, _tzli, _dỡ_, 
   {{0x6440005f,0xf484074d,0x7b34010e,0x00000000}},	//   _uzli, _шутн, lşuň, --, 
   {{0x7cf00086,0xdee495b2,0x613c0100,0x9344075e}},	//   _närr, хоми, mèlm, _كىلۇ, 
   {{0xf1c8001e,0x2004033f,0x613c007f,0x127800df}},	//   _gỡ_, szli_, lèlm, _זאנע, 
   {{0xa0a4010b,0x00000000,0x00000000,0x00000000}},	//   _чакд, --, --, --, 
   {{0x7cf2275c,0x261031a0,0xdea0036b,0x613c033b}},	//   _särs, _देसी_, _ییگی, nèlm, 
   {{0x395814ff,0x7cf1714c,0x29100356,0xe06003e6}},	//   _sirs_, _pärs, _amza_, _جێگی, 
   {{0x395846aa,0x2b5a275d,0x7cf00166,0x58940150}},	// [3f5a0] _pirs_, _disc_, _därr, ешеу, 
   {{0x7cf2275e,0xdb1c00ae,0x00000000,0x00000000}},	//   _värs, _ispí, --, --, 
   {{0xb9080c2e,0x7cf1bd75,0x2a680369,0x3958143f}},	//   _मच_, _färr, bcab_, _virs_, 
   {{0x2b580048,0x95844c17,0x2a680076,0x95c80353}},	//   _gisc_, елде, ccab_, зука_, 
   {{0x395a275f,0x7cf0013d,0x00000000,0x00000000}},	//   _tirs_, _härq, --, --, 
   {{0xf1c8001e,0x1cdc025c,0xd37931b9,0xb8b401ec}},	//   _rỡ_, _རོས_, пчи_, _шөбі, 
   {{0xf1c801fb,0xc84009a5,0xccf000d9,0x03a00063}},	//   _sỡ_, _берй, רכו_, гијо, 
   {{0xc7d4025f,0x2bd04c83,0x2610023e,0xdb1c01e7}},	//   _אולי_, हिता, _देवी_, _ospí, 
   {{0x26b00075,0xc1b411db,0x36440131,0xa2d41a47}},	//   _خەنز, елых_, _شىئې, भाज्, 
   {{0xa2d40574,0xf1c8001e,0x63ac0054,0x6350002b}},	//   _मोठ्, _vỡ_, ńana, _māny, 
   {{0xae880228,0x3afc0248,0xdcf40118,0x824c0023}},	//   үбүз_, _nípo_, žbět, _ማዓልታ, 
   {{0xa3bc7db3,0x51840075,0xa020000d,0x00000000}},	//   इबर_, _зука, ööae, --, 
   {{0x2b58381a,0x63500882,0xddec04ce,0x2a680208}},	//   _risc_, _nāny, _cｈ_, vcab_, 
   {{0x2b580ac5,0x00000000,0x00000000,0x00000000}},	//   _sisc_, --, --, --, 
   {{0xa2d400bc,0xec28007b,0x7cf001f4,0x629c00e4}},	//   _मोड्, ذكرى_, _pärr, ósog, 
   {{0xfaa4086f,0xed500050,0xcf240451,0xf1c400cd}},	//   лшун, _چھس_, _ڪرڪي, _वनान, 
   {{0x7cf0049f,0x2b5a2760,0x2a68020b,0x63500882}},	// [3f5b0] _värr, _visc_, rcab_, _cāny, 
   {{0xf3fc0c99,0x7cf00036,0x2a68058a,0x613c02bd}},	//   ྐྱོད_, _wärr, scab_, yèlm, 
   {{0x7cf0013d,0xaa5c01ec,0x00000000,0x00000000}},	//   _tärr, _менi, --, --, 
   {{0x2d99018a,0x613c033b,0x7cf00108,0xb6e40f06}},	//   orse_, vèlm, _härp, лючк, 
   {{0x261003f3,0x7cf22761,0x00000000,0x00000000}},	//   _देशी_, _kärp, --, --, 
   {{0x26c8098d,0xa3bc0316,0x2d9800c6,0x7cf001e3}},	//   žao_, इबल_, irse_, _järp, 
   {{0x26102871,0x20188af8,0x86b002dd,0x00000000}},	//   _देरी_, şsiz_, _бәлі, --, 
   {{0x613c033b,0x7cf0007c,0x2734007c,0x6350002b}},	//   rèlm, _lärp, råns_, _yāny, 
   {{0xbcf001e4,0xe3b005d9,0xa0880137,0xd1801e35}},	//   _kuɩt, ارڪ_, үсүз_, алый, 
   {{0xd12c73eb,0xe3762762,0x7cf00621,0x291c0066}},	//   يمي_, _алжы, _närp, éwah_, 
   {{0xf1a803e6,0x00000000,0x00000000,0x00000000}},	//   وایه_, --, --, --, 
   {{0x28e402dd,0x00000000,0x00000000,0x00000000}},	//   _ﺍﻷﺴﻠ, --, --, --, 
   {{0x7cf03407,0x00000000,0x00000000,0x00000000}},	//   _bärp, --, --, --, 
   {{0xed3405f5,0xdfa82651,0xa2d408a3,0x00000000}},	//   гэсэ, _قطعه_, _मोत्, --, 
   {{0x2d9a2763,0x7cf00267,0x635000b8,0x00000000}},	//   arse_, _därp, _sāny, --, 
   {{0x38ca2764,0x76980241,0xf9c40139,0x00000000}},	//   کاری_, _múyà, лабү, --, 
   {{0x9d440124,0x261000c5,0x00000000,0x00000000}},	// [3f5c0] _иеид, _देली_, --, --, 
   {{0x6350002b,0x09000150,0x00000000,0x00000000}},	//   _vāny, апун, --, --, 
   {{0x98543412,0x8ccc47b8,0x00000000,0x00000000}},	//   тташ, दयरो, --, --, 
   {{0xd5b801af,0x635000cd,0x00000000,0x00000000}},	//   дск_, _tāny, --, --, 
   {{0xdb1c068c,0x46a02bb6,0x00000000,0x00000000}},	//   _ispà, рачв, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xa30000fd,0x8360006c,0x9664004e,0xd3c400cf}},	//   әүче, لگنل, _акбе, ئتتى, 
   {{0x14d00490,0x00000000,0x00000000,0x00000000}},	//   _धोरण, --, --, --, 
   {{0x546801a9,0x00000000,0x00000000,0x00000000}},	//   _жазм_, --, --, --, 
   {{0x2d982625,0xf3fc0327,0xdce4008e,0x00000000}},	//   vrse_, ྐྱུད_, kukı, --, 
   {{0x12c401b9,0x0fe00137,0x8898011a,0x100401d5}},	//   _аёлг, рөлү, וביי, тяпм, 
   {{0x7cf0007c,0x00000000,0x00000000,0x00000000}},	//   _särp, --, --, --, 
   {{0xf1944d15,0x2d9a2765,0x00000000,0x00000000}},	//   _силь, urse_, --, --, 
   {{0xdb1c00a3,0x6e0400db,0x25a8031c,0x00000000}},	//   _aspà, _ەسدە, ħalx_, --, 
   {{0x7b6492cf,0x8aa56c15,0xdde0009b,0xaa94034f}},	//   итте, крад, đuši, ливч, 
   {{0x2cac012c,0x604400c0,0x00000000,0x00000000}},	//   řed_, _схіз, --, --, 
   {{0xdb1c0077,0x7cf00e03,0x3b54447e,0x00000000}},	// [3f5d0] _arpó, _tärp, рктр, --, 
   {{0xdb1c00cf,0x00000000,0x00000000,0x00000000}},	//   _espà, --, --, --, 
   {{0xc1acb8a8,0x28141359,0x00000000,0x00000000}},	//   _जङ्ग, دواس, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x5a980375,0x00000000,0x00000000,0x00000000}},	//   _אשרא, --, --, --, 
   {{0xfbd1f0ad,0x6764117d,0x00000000,0x00000000}},	//   _اتی_, _مُسل, --, --, 
   {{0x64a40166,0x00000000,0x00000000,0x00000000}},	//   ваһа, --, --, --, 
   {{0x613c004e,0x00000000,0x00000000,0x00000000}},	//   mèli, --, --, --, 
   {{0x7888005f,0x4aa80118,0x00000000,0x00000000}},	//   būvē, _छानव, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x26cc00b0,0x2294014b,0x00000000,0x00000000}},	//   _kaeo_, _биея, --, --, 
   {{0x248448fe,0x5f04010b,0x64600205,0x00000000}},	//   _helm_, узма, şviğ, --, 
   {{0x6288003a,0x24840254,0x6ea411bc,0x20d41cb8}},	//   maeo, _kelm_, _कारु, _бійс, 
   {{0x628a2766,0x6edc012c,0x4d600a5b,0x620403e0}},	//   laeo, याउँ, скрв, ıtlı, 
   {{0x24840175,0x225800d0,0x00000000,0x00000000}},	//   _melm_, ľsku_, --, --, 
   {{0x628a2767,0x23640e3c,0x613c00db,0x2fd800b5}},	//   naeo, _mulj_, dèli, ærge_, 
   {{0x09e00a70,0xbf2000e1,0x00000000,0x00000000}},	// [3f5e0] ботн, मचीन_, --, --, 
   {{0x62880393,0xa2d42072,0x395c007c,0x00000000}},	//   haeo, _मोस्, övs_, --, 
   {{0xb8cc3174,0x62880093,0x613c26b7,0x00000000}},	//   _गा_, kaeo, gèli, --, 
   {{0x2bd005ba,0x3cac00cc,0x1ae40150,0x8c1801e4}},	//   हिरा, _চফটৱ, _сомм, _טויי, 
   {{0x628816b8,0x24840139,0x99f41cd0,0x00000000}},	//   daeo, _belm_, _сяні, --, 
   {{0x60c00664,0x236401a6,0x00000000,0x00000000}},	//   jelm, _bulj_, --, --, 
   {{0x60c22768,0x62880618,0xa0200037,0x00000000}},	//   delm, faeo, ööle, --, 
   {{0x60c00254,0x55040166,0x53440022,0x00000000}},	//   eelm, _өпбб, ыхла, --, 
   {{0x2484003e,0x646801a6,0x15440117,0x00000000}},	//   _felm_, _špiš, _беам, --, 
   {{0x60c22769,0xb114052f,0x00000000,0x00000000}},	//   gelm, рмош, --, --, 
   {{0x26cc0286,0x62880393,0xc05400d3,0x92f001c4}},	//   _yaeo_, baeo, лію_, _гүйх, 
   {{0x6288003a,0xd24401ee,0x00000000,0x00000000}},	//   caeo, _йэли, --, --, 
   {{0x60c2276a,0x00000000,0x00000000,0x00000000}},	//   belm, --, --, --, 
   {{0x6b74cdc1,0x60c003e0,0x2bd1d8b3,0x61fc01bf}},	//   илгу, celm, हिला, øsle, 
   {{0x5eb8015b,0x80a000db,0xca6401b9,0xefb00244}},	//   ইয়ে, _امىن, аmаs, _بیجگ, 
   {{0x7b6428cf,0x61f403cd,0x613c59b3,0x6e0400db}},	//   стре, _øglæ, vèli, _ەسگە, 
   {{0x6f1c0077,0xac9404f0,0x00000000,0x00000000}},	// [3f5f0] ércu, _капш, --, --, 
   {{0x6fa803f3,0x1cdc0003,0x6e2e276b,0x613e276c}},	//   _कमां, _རོག_, _ixab, tèli, 
   {{0xf770aa93,0x26cc05c7,0xa81400d8,0x00000000}},	//   كان_, _paeo_, јдеш, --, 
   {{0x1b7800c8,0x60c2276d,0x28d40254,0x613c00db}},	//   _שטרע, zelm, _डोरि, rèli, 
   {{0x60c0b496,0x62880421,0xdb1c0306,0x84b40417}},	//   yelm, vaeo, _uspá, лғау_, 
   {{0x60c00a40,0x613c19f5,0x00000000,0x00000000}},	//   xelm, pèli, --, --, 
   {{0x60c2276e,0x628a276f,0x26cc00fb,0xddc8033f}},	//   velm, taeo, _taeo_, _łoży, 
   {{0x16140c2e,0x6e2de58a,0xf9900133,0xa0200254}},	//   _देवर_, _oxab, _ببێ_, ööme, 
   {{0x60c22770,0x672a2771,0x62880cfd,0x225811ab}},	//   telm, _ijej, raeo, äsk_, 
   {{0xa2d43174,0x6728005c,0x62880381,0x00000000}},	//   _मोर्, _hjej, saeo, --, 
   {{0x60c22772,0x6e2cc245,0x62880393,0xe1f00214}},	//   relm, _axab, paeo, _ژست_, 
   {{0x60c00598,0x1cdc003d,0x67280109,0x98c4110c}},	//   selm, _རོང_, _jjej, _čuči_, 
   {{0x60c22773,0x0dc42081,0xa0740137,0x00000000}},	//   pelm, аляй_, _кыйш, --, 
   {{0xdca40b7f,0x60c0016d,0x61e800f1,0x28d40037}},	//   јави, qelm, mxel, _डोलि, 
   {{0x672807dd,0x6e2c0fec,0x2f08000f,0x9cc871c1}},	//   _ojej, _exab, _bûgd_, ныңа_, 
   {{0x6728044e,0x00000000,0x00000000,0x00000000}},	//   _njej, --, --, --, 
   {{0x61ea2774,0x7e64015c,0xe17c0020,0xc0f00020}},	// [3f600] nxel, _igip, _የነበሩ_, ፍጠር_, 
   {{0xa3d410f7,0x672a2775,0x61e8004e,0xf8e005d7}},	//   िटा_, _ajej, ixel, नाइय, 
   {{0x4c98011a,0x00000000,0x00000000,0x00000000}},	//   _בשיע, --, --, --, 
   {{0x7d1db471,0x9a480014,0xbab400db,0x69240124}},	//   lirs, _لٔجم_, _دۅرب, амӡа, 
   {{0x86c0ab80,0x7d1c007b,0x182801b9,0x4a78011a}},	//   زيون, oirs, رقچی_, _ברכב, 
   {{0x61e8005a,0x18680e92,0x672a2776,0x44f00136}},	//   dxel, _јави_, _ejej, قسىز, 
   {{0x7e640083,0x00000000,0x00000000,0x00000000}},	//   _ogip, --, --, --, 
   {{0x7e662777,0x6728044e,0x7d1e2778,0x3b000309}},	//   _ngip, _gjej, hirs, nkiq_, 
   {{0x7d1e2779,0x61e800aa,0x23680115,0x35d400f1}},	//   kirs, gxel, ĉaja_, _دښار, 
   {{0x7e66277a,0x1cdc031c,0x7d1c0009,0x1544013d}},	//   _agip, _རོཊ_, jirs, _тезм, 
   {{0x7d1e277b,0xe4c404d3,0x76409f37,0x52a800a8}},	//   dirs, _دڵنی, _hymy, _авем_, 
   {{0xb8e808ea,0x41c05516,0x77600003,0x4418011a}},	//   _ཉི_, حقیق, _jimx, _בובס, 
   {{0x7d1e277c,0x42b400cf,0x7e640356,0x76400108}},	//   firs, _ئچىڭ_, _dgip, _jymy, 
   {{0x7760009a,0x7d1e277d,0x764000a2,0x6fb41410}},	//   _limx, girs, _mymy, _همتا, 
   {{0x76400108,0x0a680120,0x6f9400ae,0x88cc00eb}},	//   _lymy, врзи_, _البض, রামক, 
   {{0x2f08000f,0x6e2c01c6,0x77600135,0x7d1c01ab}},	//   _bûge_, _txab, _nimx, airs, 
   {{0x7d1e277e,0x6f1e277f,0x6e2c0921,0xa2a81414}},	// [3f610] birs, misc, _uxab, _टास्, 
   {{0x7d1daf6d,0x0b89e23c,0x26100034,0xa2bc02ab}},	//   cirs, _исми_, _देगी_, _वॉन्, 
   {{0x7640010e,0x7d5400cf,0x753802f0,0x1ee800f2}},	//   _aymy, _بئيئ, dovz, _شویی_, 
   {{0x6f1e2780,0x6d5401f5,0x65780fac,0xd00400e5}},	//   nisc, lmza, tpwh, _ہل_, 
   {{0x261019e5,0xd004021a,0x76400368,0xfd1003e6}},	//   _देखी_, _ځل_, _cymy, _رجی_, 
   {{0x6f1e2781,0xd0040cf3,0xd5e001f2,0x7640010b}},	//   hisc, _فل_, waọ, _dymy, 
   {{0x2901f7f1,0x672804f3,0x62840134,0x6f1d281c}},	//   mkha_, _tjej, _ɑhof, kisc, 
   {{0x672880b9,0x68f40399,0x6b840007,0x61e828fc}},	//   _ujej, _hozd, _mwhg, txel, 
   {{0x7d1c03be,0x29000161,0x76407999,0x75388c05}},	//   yirs, okha_, _gymy, bovz, 
   {{0x65680270,0x29000925,0x77600472,0x60e922b4}},	//   _iueh, nkha_, _zimx, умом_, 
   {{0x68f408ad,0x6f1e2782,0x7e64089c,0x7d1e2783}},	//   _mozd, fisc, _pgip, virs, 
   {{0x6f1e2784,0x7c38fb11,0x65680124,0x68f40369}},	//   gisc, _øvri, _kueh, _lozd, 
   {{0x2f5410f5,0x7d1e2785,0x290001fa,0x64422786}},	//   ютьс, tirs, kkha_, _hyli, 
   {{0x64422787,0xd37c2220,0x6f1c00c6,0x2f08000f}},	//   _kyli, šćen_, aisc, _rûge_, 
   {{0x7d1e2788,0x65622789,0x7cf15a23,0x7950013d}},	//   rirs, _milh, _kärz, läwg, 
   {{0x6442278a,0x6f1d3696,0x7e6400ca,0x2900e381}},	//   _myli, cisc, _ugip, ekha_, 
   {{0x7d1e278b,0x68f5da50,0x0d8000fd,0x613c020c}},	// [3f620] pirs, _bozd, _елын, sèlu, 
   {{0x77600b6f,0x6440036b,0x613c0561,0x6560031c}},	//   _simx, _oyli, cèlt, _nilh, 
   {{0x64404491,0x81bc02f5,0x656876b2,0x76403deb}},	//   _nyli, ুমি_, _aueh, _symy, 
   {{0x65680076,0x6562278c,0x1cdc031c,0x2e3401f2}},	//   _bueh, _ailh, _རོཌ_, ụfe_, 
   {{0x6562278d,0x6442278e,0x76400240,0xe6b401b9}},	//   _bilh, _ayli, _qymy, تلنگ, 
   {{0x6440dde0,0x68f6278f,0x656014ae,0x76400122}},	//   _byli, _gozd, _cilh, _vymy, 
   {{0x76422790,0x65622791,0x6568003a,0x07a001c0}},	//   _wymy, _dilh, _eueh, _нарн, 
   {{0x6440c460,0x65680732,0x68f4022e,0xa9fc01e1}},	//   _dyli, _fueh, _zozd, _ńtẹ́_, 
   {{0x65622792,0x6f1db039,0x5064ce93,0x68f401b9}},	//   _filh, visc, йтна, _yozd, 
   {{0x6f1ca17d,0x6440a98d,0x61fc03cd,0x6fb80117}},	//   wisc, _fyli, øsla, агор_, 
   {{0x6f1e2793,0x7cf00139,0x64400024,0x49380375}},	//   tisc, _färz, _gyli, רגיו, 
   {{0xadda2794,0xe3b001d9,0x656803f9,0xa03416a0}},	//   амму_, _آرٕ_, _yueh, تىپت, 
   {{0x6b840097,0x64403262,0xdb1c01c7,0x644c02a8}},	//   _swhg, _zyli, _eppë, ƙaic, 
   {{0x6f1e2795,0x6ea4215d,0x7d000036,0x7cf00108}},	//   sisc, _काकु, ëmsp, _käry, 
   {{0x6f1e2796,0x68f4a3f5,0xc04e2797,0x7174009f}},	//   pisc, _rozd, _хі_, _اهڪا, 
   {{0x29000054,0x7cf0013d,0x00000000,0x00000000}},	//   wkha_, _märy, --, --, 
   {{0x29000810,0xcd28036b,0x00000000,0x00000000}},	// [3f630] tkha_, _مسدن_, --, --, 
   {{0xc86611f3,0x63ac0227,0x29022798,0x0a680166}},	//   стаи, ńani, ukha_, _әрни_, 
   {{0x68f44ca5,0xdb1c00d8,0x00000000,0x00000000}},	//   _vozd, _arpõ, --, --, 
   {{0x65681e2b,0x29022799,0xe3e83bdb,0x64400334}},	//   _pueh, skha_, یکان_, _ryli, 
   {{0x6562279a,0x65680407,0x6284013f,0x6442279b}},	//   _pilh, _queh, _ɑhod, _syli, 
   {{0xdb1e279c,0xa3d41d24,0x6442279d,0x058401a9}},	//   _appè, िटल_, _pyli, _ҳужм, 
   {{0x6562279e,0x656950d1,0x8cb8687b,0x64400200}},	//   _vilh, _wueh, श्यो, _qyli, 
   {{0x6562279f,0x69dc0cf4,0x64402b57,0x7cf00166}},	//   _wilh, _krse, _vyli, _däry, 
   {{0x644227a0,0x00000000,0x00000000,0x00000000}},	//   _wyli, --, --, --, 
   {{0x349627a1,0x6560017a,0x644227a2,0x6118007f}},	//   _наур, _uilh, _tyli, pňlm, 
   {{0x644227a3,0x00000000,0x00000000,0x00000000}},	//   _uyli, --, --, --, 
   {{0x69de27a4,0x7cf0008e,0x00000000,0x00000000}},	//   _orse, _härx, --, --, 
   {{0x6298033b,0x1cdc025c,0x82342f84,0x7950008e}},	//   _idwo, _རོད_, _ارضا, läwe, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x82c4025c,0x69dcccab,0x7cf000fd,0xd00c0769}},	//   _ཁྲོའ, _arse, _märx, _للو_, 
   {{0x1a283252,0x00000000,0x00000000,0x00000000}},	//   ажби_, --, --, --, 
   {{0x13a41bd6,0x795227a5,0x00000000,0x00000000}},	// [3f640] _गम्भ, häwe, --, --, 
   {{0xa3e8038e,0x69dc0219,0x00000000,0x00000000}},	//   ममा_, _drse, --, --, 
   {{0x629a27a6,0x69de27a7,0x17c807dd,0xd77400db}},	//   _odwo, _erse, ргеи_, زااع, 
   {{0x6298016b,0xf42400f7,0x69dc010a,0x3afc02d2}},	//   _ndwo, үздү, _frse, _pípu_, 
   {{0x644400af,0x7cf00474,0x82c40327,0x18682cc9}},	//   ühin, _bärx, _ཁྲེའ, _ваги_, 
   {{0x629811ce,0x3398007b,0x983400c0,0x2d8000d1}},	//   _adwo, منتج_, _дэбі, ﯩﺸﻨﻰ_, 
   {{0x1cdc0135,0xdb1c004a,0x689001ed,0x00000000}},	//   _རོན_, _appé, _سینئ, --, 
   {{0x69dc0267,0x614400d1,0x87780115,0x00000000}},	//   _yrse, ۋىيە, _כאלי, --, 
   {{0x80d00f22,0x7cf0008e,0xe504004b,0x629801ef}},	//   তান্, _färx, _ډبلي, _ddwo, 
   {{0x30151f7c,0x629803ac,0x86204d2f,0xe8e402dd}},	//   здор, _edwo, _تکمل, _ﺍﺷﯟﻋ, 
   {{0xa2d407b7,0x00000000,0x00000000,0x00000000}},	//   _मोक्, --, --, --, 
   {{0xb8fc0003,0x51841719,0x64a40124,0x2ed400dc}},	//   _ཡལ_, _дука, _маӡа, धयेत, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe3b001d3,0x00000000,0x00000000,0x00000000}},	//   _ترے_, --, --, --, 
   {{0xcb1803b7,0x7b2c00ac,0x80a4012d,0x00000000}},	//   аќа_, rğun, चलरे, --, 
   {{0x69dc0393,0x70540050,0xc0d80023,0x00000000}},	//   _prse, _وچھا, ዕዓል_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3f650] --, --, --, --, 
   {{0x69dc0cf4,0x00000000,0x00000000,0x00000000}},	//   _vrse, --, --, --, 
   {{0x6284013f,0xe250010c,0x00000000,0x00000000}},	//   _ɑhob, _ቅድስና, --, --, 
   {{0x69dc0a2e,0x2d8800fb,0x7cf00139,0x24b40150}},	//   _trse, _kwae_, _särx, _ﺼﻤﺘﻬ, 
   {{0x69de27a8,0x7edc008f,0x1ddc0037,0x6aae27a9}},	//   _urse, יקאצ, मियत, mgaf, 
   {{0x6aad83cd,0x88cc0154,0xf6700150,0x00000000}},	//   lgaf, রাহক, _ﺷﯩﻘﭙ, --, 
   {{0xe298f58e,0x69cc16e3,0xf77227aa,0x82c4025c}},	//   бай_, lwae, _لاق_, _ཁྲུའ, 
   {{0x16140034,0x69cc0086,0x8cb8033f,0xe7840818}},	//   _देकर_, owae, श्तो, _муғо, 
   {{0x6aac0421,0x69cc017a,0x00000000,0x00000000}},	//   igaf, nwae, --, --, 
   {{0x69cc166a,0xd37c107d,0x00000000,0x00000000}},	//   iwae, šćan_, --, --, 
   {{0x6aae27ab,0x69ccb6da,0xa0680032,0x64a400fb}},	//   kgaf, hwae, _һала_, _маҡа, 
   {{0x69cc0921,0x21f400db,0x29cc00ef,0x00000000}},	//   kwae, _ىكاس, _oža_, --, 
   {{0x91040133,0xa0684037,0x816800f3,0xd4600092}},	//   زسیۆ, _лала_, _треб_, _ማሳደጊ, 
   {{0x91f40375,0xaecc031c,0x69cc017a,0x3ad80208}},	//   _ממנו_, _ཇིཨོ, dwae, _ọp_, 
   {{0x5040013e,0xdb0c03b2,0x00000000,0x00000000}},	//   _пешб, stbí, --, --, 
   {{0x1cdc0135,0x1e8627ac,0x6aae27ad,0x8c400ce8}},	//   _རོམ_, _элим, ggaf, хесе, 
   {{0x2d88015d,0x69cc0142,0x00000000,0x00000000}},	// [3f660] _gwae_, gwae, --, --, 
   {{0x6aac0607,0xcdb40375,0x98540137,0x3c9410e8}},	//   agaf, _צפיה_, птеш, _زیرز, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x99900209,0x942429dc,0x00000000,0x00000000}},	//   yzyň_, үмде, --, --, 
   {{0x69cc0175,0x7bde27ae,0x09e0014b,0xc6980092}},	//   cwae, lvru, _зоян, ፈፀሚያ_, 
   {{0xdb1c03cd,0x00000000,0x00000000,0x00000000}},	//   _aspø, --, --, --, 
   {{0xf21405f9,0x279485c0,0x33580276,0xb6c80014}},	//   _तेज़_, _оштр, оакэ_, _وارے_, 
   {{0x82a00022,0x00000000,0x00000000,0x00000000}},	//   ншье, --, --, --, 
   {{0xd1380107,0x00000000,0x00000000,0x00000000}},	//   йхо_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7bdc05be,0x75240036,0xa2f400ec,0x5dc40150}},	//   jvru, éizu, _ڪينڪ, _ﺩﻴﻨﻴ, 
   {{0x17080156,0x7bdc0b4f,0x69cc0042,0x7bc8031c}},	//   _གཞསམ_, dvru, ywae, ħdul, 
   {{0xa2d429da,0x82c4003d,0x7b2c03be,0x7bdc01f5}},	//   _मोट्, _ཁྲིའ, rğul, evru, 
   {{0xeb043b90,0xed580006,0x41500212,0x6908032e}},	//   रस्त_, įžo_, _звіс, _aþen, 
   {{0x00b80302,0x00000000,0x00000000,0x00000000}},	//   _המומ, --, --, --, 
   {{0x2d880204,0x69ce27af,0x7f640150,0x00000000}},	//   _twae_, twae, _ﻓﺼل_, --, 
   {{0x2ee81028,0x6f0d82f7,0x69cc0175,0xfeb802c9}},	// [3f670] _inaf_, _ilac, uwae, _رايت_, 
   {{0x6f0c5667,0x69cc0575,0x6aac0142,0x00000000}},	//   _hlac, rwae, sgaf, --, 
   {{0x6f0e27b0,0x69ce0179,0x35cc00eb,0x00000000}},	//   _klac, swae, লমোহ, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6f0d129f,0x29cc16a3,0x1fd8000d,0x00000000}},	//   _mlac, _uža_, _बछ्ड, --, 
   {{0xc9841d18,0x6f0e27b1,0x1ddc024a,0x64a402a9}},	//   _муҳи, _llac, मितत, фака, 
   {{0x6f0c2799,0x2b480051,0x00000000,0x00000000}},	//   _olac, olac_, --, --, 
   {{0x36d48ed9,0x2b48017a,0x4430025c,0x00000000}},	//   _поср, nlac_, ħx_, --, 
   {{0xdcf402f0,0x046414d4,0xd2ac0073,0x00000000}},	//   _styč, _етем, _टारझ, --, 
   {{0x6f0e27b2,0xa2bc03f3,0x17080135,0x2eea27b3}},	//   _alac, _वॉर्, _གཞོམ_, _anaf_, 
   {{0x6f0da215,0x1eca27b4,0xa2340124,0x754800e5}},	//   _blac, олни_, џьқә, őszá, 
   {{0x6f0e27b5,0xe1f00128,0x2b4805be,0x942415bf}},	//   _clac, _لست_, jlac_, _تومۇ, 
   {{0x2b49c6a7,0x6f0c068f,0xd12c00f1,0x85400064}},	//   dlac_, _dlac, امۍ_, _įėju, 
   {{0x6f0e27b6,0x60240640,0xa3e02cbb,0x00000000}},	//   _elac, _одла, दिप_, --, 
   {{0x8c4227b7,0xfe7800db,0x00000000,0x00000000}},	//   вере, _нүн_, --, --, 
   {{0x7bdc0af9,0x004400f1,0x00000000,0x00000000}},	//   rvru, _ویکي_, --, --, 
   {{0x14ac0490,0x7f440213,0x7bdc0b4f,0x9f8800a2}},	// [3f680] _घालण, _ikiq, svru, _iññe_, 
   {{0x6f0e27b8,0x20000254,0x00000000,0x00000000}},	//   _zlac, _ühis_, --, --, 
   {{0x2b480129,0x00000000,0x00000000,0x00000000}},	//   blac_, --, --, --, 
   {{0xa3e000ce,0xa2bc06ab,0xa2a8012d,0x00000000}},	//   दिन_, _वॉल्, _टाग्, --, 
   {{0xf8b02e0b,0x00000000,0x00000000,0x00000000}},	//   _مکا_, --, --, --, 
   {{0xd3782826,0x00000000,0x00000000,0x00000000}},	//   очи_, --, --, --, 
   {{0x5ea400eb,0x00000000,0x00000000,0x00000000}},	//   গ্যে, --, --, --, 
   {{0x592c0327,0x00000000,0x00000000,0x00000000}},	//   ྩོམས_, --, --, --, 
   {{0x6f0c01ab,0x00000000,0x00000000,0x00000000}},	//   _rlac, --, --, --, 
   {{0x6f0e27b9,0x2ee807c5,0x2b48030a,0x61b401d9}},	//   _slac, _snaf_, zlac_, رٕپا, 
   {{0x6f0e27ba,0x2b4801d9,0xb4bc084a,0xa4f4065f}},	//   _plac, ylac_, ेजी_, _سکور_, 
   {{0x52240cfc,0x00000000,0x00000000,0x00000000}},	//   _офла, --, --, --, 
   {{0xea980882,0xc3c001c0,0x6f0c0306,0x8d840276}},	//   hiṃ_, _зөөл, _vlac, ьунд, 
   {{0x2ee8015d,0x6f0c012d,0x3204010e,0x00000000}},	//   _wnaf_, _wlac, mymy_, --, 
   {{0x6f0e27bb,0x81401d8f,0x19c0ecb2,0x506401d5}},	//   _tlac, _جنون, һәрг, _ўтла, 
   {{0xdb1c06af,0x6f0c0036,0x0dc80c60,0xc9840063}},	//   _appâ, _ulac, _дуои_, дужи, 
   {{0x19c227bc,0x2b480004,0x3204010b,0xf99031b1}},	// [3f690] ләрг, rlac_, nymy_, لبل_, 
   {{0x2b4804a7,0xba540640,0x64440037,0xa3e06a60}},	//   slac_, твуј, ühik, दिम_, 
   {{0x6d448671,0x2b4a27bd,0xaa9448e5,0xbdf8030f}},	//   _ikha, plac_, _пинч, _فریا_, 
   {{0xdcf40882,0x6f1c24bc,0x2d9a1214,0x8cb808df}},	//   _ityā, èrch, osse_, श्रो, 
   {{0xe4c627be,0x2d9a27bf,0xe5a627c0,0x628002e3}},	//   ейли, nsse_, хили, ịokw, 
   {{0x2d9a27c1,0x32040209,0xa3bc0141,0x23d627c2}},	//   isse_, dymy_, ेबल_, ецир, 
   {{0xe29a27c3,0xc61c068f,0x6d4627c4,0x24084bf5}},	//   пай_, _मेरठ_, _mkha, янки_, 
   {{0xe1f80228,0xe298016c,0xe3c401c6,0x2d980254}},	//   зги_, чаи_, _үржү, ksse_, 
   {{0x6d4449e1,0x2d982112,0xd1c4034b,0x6118007f}},	//   _okha, jsse_, елые_, kňlt, 
   {{0x6d441813,0x9f8401c0,0x44040395,0x00000000}},	//   _nkha, нгод, _очеб, --, 
   {{0x2d980a55,0xdcf4521a,0x00000000,0x00000000}},	//   esse_, _ntyā, --, --, 
   {{0xb4bc000d,0x3204010e,0x7b2c00a2,0x00000000}},	//   ेड़ी_, bymy_, mşug, --, 
   {{0xa0a4bf85,0xd00c006c,0xdcf4002b,0xf1a80133}},	//   _залд, للی_, _atyā, _قاوه_, 
   {{0xd1940302,0x1d0800f7,0x00000000,0x00000000}},	//   _טכני_, чеги_, --, --, 
   {{0x6d440649,0x21240dd4,0x2d9a27c5,0x6284016b}},	//   _dkha, milh_, asse_, _ɑhon, 
   {{0x6d442747,0x20040153,0x00000000,0x00000000}},	//   _ekha, myli_, --, --, 
   {{0x6d4403a0,0x3ea0003e,0xdcf40055,0xdb1c0174}},	// [3f6a0] _fkha, _idit_, _etyā, _uppí, 
   {{0x38c8183b,0xea980882,0x4a410475,0x2124068c}},	//   باری_, tiṃ_, унув, nilh_, 
   {{0x224800b0,0x320627c6,0x22580419,0x00000000}},	//   _ɸaka_, zymy_, ľsky_, --, 
   {{0x225800d7,0x00000000,0x00000000,0x00000000}},	//   žsky_, --, --, --, 
   {{0x6f1c00f7,0x200627c7,0x99140153,0x00000000}},	//   èrci, hyli_, _зьві, --, 
   {{0x798627c8,0xd94627c9,0xb4bc00af,0xa2bc01ad}},	//   mpiw, _чеги, ेजे_, व्स्, 
   {{0x3ea227ca,0xa49059c7,0x3958002f,0x3d08012d}},	//   _odit_, شینت, _ihrs_, _सकने_, 
   {{0x2d9a27cb,0x3ea001bf,0x2004036e,0xdb0c01bf}},	//   ysse_, _ndit_, dyli_, stbæ, 
   {{0x79840113,0x76440022,0xcb1000d9,0x7b2c0205}},	//   npiw, _рмаҷ, טלה_, mşud, 
   {{0x3ea15dcf,0x79840099,0x61fc0621,0x30e40116}},	//   _adit_, ipiw, äsla, тсиң, 
   {{0x79840455,0x03a00107,0xa2bc0073,0x61180100}},	//   hpiw, _бихо, व्ह्, vňlt, 
   {{0x2d980770,0x2124030a,0xa3b41d94,0x6d4627cc}},	//   tsse_, ailh_, _जमत_, _skha, 
   {{0x2d9a27cd,0xe2aa27ce,0xc3300bd4,0x2124030a}},	//   usse_, _زانن_, _גוף_, bilh_, 
   {{0x3ea00c3e,0x20040ebb,0x2d980037,0xfd4401c0}},	//   _edit_, byli_, rsse_, гэсн, 
   {{0x8ae4cea6,0xc074011a,0x00000000,0x00000000}},	//   ніал, _אגוז_, --, --, 
   {{0xa3e039a7,0x3958020b,0x0e685f8e,0x7c30013a}},	//   दित_, _ahrs_, _عصبي_, _širý, 
   {{0x61ec0798,0xee28009f,0x00000000,0x00000000}},	// [3f6b0] _àalt, _آڻجو_, --, --, 
   {{0x9ba004a9,0x6d442e95,0x7c3800d8,0x49440304}},	//   _ھەقى, _ukha, çarã, хэбб, 
   {{0x28152596,0x8c6627cf,0x69341079,0x00000000}},	//   خواس, _ятид, _یکطر, --, 
   {{0x2124030a,0xc7440633,0x7950008e,0x00000000}},	//   zilh_, رضاي, läwl, --, 
   {{0xdb1c067c,0xdb0c019f,0x47f00032,0x2004033f}},	//   _espó, kubê, _әүер, zyli_, 
   {{0xa969a9d7,0x7c3403ee,0x109008b0,0x20040108}},	//   _زمزم_, _çerç, ﯞﯨﺮﯨ, yyli_, 
   {{0x2910017a,0xb4bc00ab,0x00000000,0x00000000}},	//   _ilza_, ेड़े_, --, --, 
   {{0x468001b9,0xb9e00092,0x249800ef,0xb9cc0092}},	//   _ёқла, _ቤቴ_, _ēsmu_, _ዳባ_, 
   {{0x2b580129,0x2124030a,0x414064b6,0x00000000}},	//   _mhsc_, tilh_, лдиң, --, 
   {{0x60085f0d,0x3ea0020b,0x20043f05,0x212521f4}},	//   дном_, _sdit_, tyli_, uilh_, 
   {{0x61ec0006,0x73c4004b,0x212591c4,0xdb0c01bf}},	//   _šald, _ميلم, rilh_, ltbå, 
   {{0x26de27d0,0xdcc800dc,0x2124067c,0x79840309}},	//   ndwo_, ाज्ञ, silh_, ypiw, 
   {{0x00e0130e,0x2910005a,0x2124030a,0x88c4013a}},	//   _متغی, _olza_, pilh_, _zděš, 
   {{0xa3b43eaf,0xa5a805f9,0x62880d27,0x98b8e762}},	//   _जमा_, _घिनौ, lbeo, kopā_, 
   {{0xabc4052f,0xd7e00327,0xd10c0a8a,0x00000000}},	//   ларҙ, སའབྱ, िसरण_, --, 
   {{0x628801f5,0xdb0c03cd,0x00000000,0x00000000}},	//   nbeo, ktbå, --, --, 
   {{0x291000d8,0x26dc0083,0x2c000116,0x6f1c003a}},	// [3f6c0] _blza_, ddwo_, _һүрм, ërce, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x0d2227d1,0x79840784,0xdb0c007c,0x419c0116}},	//   _түрү, spiw, ttbä, _ﺋﻪﮔﯩ, 
   {{0xdb1c180f,0x291227d2,0xd708005b,0x798400e8}},	//   _espò, _elza_, ьнее_, ppiw, 
   {{0xdb1c006d,0x79840784,0xdb0c007c,0x00000000}},	//   _wspó, qpiw, rtbä, --, 
   {{0x98a40304,0x628801f5,0x97c40137,0xdb0c343a}},	//   _шиге, ebeo, _ийге, stbä, 
   {{0x75d40451,0xb6c4a654,0x00000000,0x00000000}},	//   ئيڪا, _бөлд, --, --, 
   {{0x628801e4,0x3f74054e,0x38bc01e1,0x00000000}},	//   gbeo, _păun_, bàró_, --, 
   {{0xb9cc02d3,0x00000000,0x00000000,0x00000000}},	//   _ዳኣ_, --, --, --, 
   {{0x70ac0490,0x636801c6,0x00000000,0x00000000}},	//   चलेल, мрөг_, --, --, 
   {{0x6e9627d3,0x62883c02,0x6fb40271,0xd04806be}},	//   лину, bbeo, دمجا, _yafə, 
   {{0x61ee27d4,0xc7b0011a,0x00000000,0x00000000}},	//   _šale, סבר_, --, --, 
   {{0x51f40e3f,0x00d43b93,0x91940063,0x00000000}},	//   _جسار, ربیت_, _рјеш, --, 
   {{0x25f40574,0xdbccdb5f,0xdb0c020c,0xbec400ef}},	//   ्हती_, _añña, lubè, _ņūto, 
   {{0xac1a27d5,0x00000000,0x00000000,0x00000000}},	//   хову_, --, --, --, 
   {{0x291002f0,0xfb345eb4,0x00000000,0x00000000}},	//   _slza_, ансэ, --, --, 
   {{0xaa547f49,0x3df4023a,0x00000000,0x00000000}},	// [3f6d0] уваш, _взыс, --, --, 
   {{0x20440023,0x53c00210,0x00000000,0x00000000}},	//   _ማንሃይ, _शहंश, --, --, 
   {{0x3d08006d,0x64a40e5c,0x7d0801e3,0x60980092}},	//   _सकते_, ҳала, ödse, _መጠጣት_, 
   {{0x98b8005f,0xa3e0791c,0x3a842f6a,0xa61400db}},	//   ropā_, दिस_, _вырв, лмеч, 
   {{0x64a627d6,0xc9860d20,0xdb1c066a,0x65c627d7}},	//   гала, _шуни, _uppá, убла, 
   {{0xe794a797,0x67d40251,0x754400d3,0xdb0c072b}},	//   _مارک, _йогу, аніз, rtbå, 
   {{0xdb0c5522,0x628801f5,0xd85404b4,0x15640150}},	//   stbå, tbeo, _берө, _ﺷﻮﺷﯩ, 
   {{0xca6c044e,0xd3e40137,0x61fc01f4,0x00000000}},	//   ኻትኩም_, اتوۉ, äslo, --, 
   {{0x628a27d8,0xf7d400cf,0x35d40108,0xe7380150}},	//   rbeo, _مەەڭ, _котё, _жең_, 
   {{0x5910025c,0xa6c400cc,0x51f400e5,0x00000000}},	//   _ྋཞབས_, _এফিট, اسٹر, --, 
   {{0x60241836,0x26d8056a,0xf1d8033f,0x98b80356}},	//   удна, _ósos_, _बैठन, lopă_, 
   {{0x25780100,0xdb0c067c,0xddd40432,0xd378010f}},	//   _kèl_, cubè, _yzyň, _טרעט, 
   {{0x2578007f,0xa0c400f2,0xa3e000cd,0x9b3400c7}},	//   _jèl_, _ميشو, दिव_, ҳхаш, 
   {{0x9d5442c0,0x257a27d9,0x61fc05ac,0x00000000}},	//   انست, _mèl_, øslu, --, 
   {{0xdee404a9,0x25780100,0x00000000,0x00000000}},	//   _бойи, _lèl_, --, --, 
   {{0x41b428fe,0x00000000,0x00000000,0x00000000}},	//   _आमास, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3f6e0] --, --, --, --, 
   {{0xc0f01954,0x00000000,0x00000000,0x00000000}},	//   ግበሩ_, --, --, --, 
   {{0x7b1801e1,0x2c0400cd,0x00000000,0x00000000}},	//   _níug, रहणं_, --, --, 
   {{0x257a27da,0xd5b80262,0x3f74054e,0x5ea4015b}},	//   _bèl_, еск_, _răul_, গ্রে, 
   {{0x07a0044c,0x398453e2,0x257866e5,0xb4f04721}},	//   _қатн, _ضیاف, _cèl_, चालय_, 
   {{0x25781801,0xbf100490,0x02a000fb,0xf8d8000d}},	//   _dèl_, ासुन_, ҡрым, _डसिय, 
   {{0xd3c40533,0x5344009d,0x00000000,0x00000000}},	//   اتتى, лхиа, --, --, 
   {{0x2578033b,0xb27400d1,0x70ac00bc,0x00000000}},	//   _fèl_, шлиш, चल्ल, --, 
   {{0x257a025c,0xb115a4a5,0x00000000,0x00000000}},	//   _gèl_, имиш, --, --, 
   {{0x61ec0010,0xdb1c0162,0x018400d1,0x49b80677}},	//   _šalc, _uppæ, اھنى_, עמיס, 
   {{0xbf1005ba,0x5edc00bd,0x7f800efc,0x2578033b}},	//   ासून_, যানে, یلین, _zèl_, 
   {{0xa3e00d5f,0xe8d801f2,0xdb0c002d,0x00000000}},	//   दिर_, mpụ_, rtbû, --, 
   {{0xf19465cb,0xdb0c002d,0x00000000,0x00000000}},	//   _тиль, stbû, --, --, 
   {{0xc0f01e38,0xe7f800bc,0x00000000,0x00000000}},	//   ግበር_, ूहमा_, --, --, 
   {{0x88cc00fe,0x00000000,0x00000000,0x00000000}},	//   ৰামক, --, --, --, 
   {{0x41600020,0x81b41c82,0x7f80bd5e,0x8c340107}},	//   _ግለሰቦ, _চনত_, _الين, воҳӣ_, 
   {{0xbf341129,0x48aa27db,0xd70403d4,0x2d9c0248}},	// [3f6f0] _دروغ, етем_, লোৱা_, _ìwe_, 
   {{0xa3b4b213,0xe8d80521,0x25784ceb,0xb9c4007b}},	//   _जमल_, kpụ_, _rèl_, إقلي, 
   {{0x257a27dc,0x8704005b,0x3afc013a,0x00000000}},	//   _sèl_, ляде, _lípy_, --, 
   {{0x25790a04,0x94000134,0xcc340588,0xbd880c62}},	//   _pèl_, _ɛkɔ_, _ахҭы, _جنین_, 
   {{0xd1dc0023,0x00000000,0x00000000,0x00000000}},	//   ንባብ_, --, --, --, 
   {{0x63a40316,0x0a8800cf,0x98b8054e,0xc7940472}},	//   áhno, _تئگى_, ropă_, _مشرب, 
   {{0x9990068f,0x25787704,0x555000d1,0x00000000}},	//   czył_, _wèl_, غپىر, --, 
   {{0x2578033b,0xf771695b,0x00000000,0x00000000}},	//   _tèl_, _راف_, --, --, 
   {{0x5edc015b,0x972001d3,0x525400c7,0xdb0c03b2}},	//   যামে, _بہنو, ихьӡ, ttbú, 
   {{0x644400af,0xe044094e,0xe1242143,0xa068d0e2}},	//   ühis, инпи, рмои, капа_, 
   {{0x9f0627dd,0x3e500023,0x1fa8011c,0x00000000}},	//   لودو, _መንኮር, ъкни_, --, 
   {{0x3f8000e2,0xbf1000cd,0xdb0c0174,0x93f800df}},	//   īju_, ासेन_, stbú, _בלעי, 
   {{0x4cdc0eac,0x6b85d1d2,0x00000000,0x00000000}},	//   মানু, _athg, --, --, 
   {{0x9fc80276,0xdb0c0fac,0x236801e4,0x00000000}},	//   _агка_, ltbø, ʈajn_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3d140139,0x09cc0154,0x00000000,0x00000000}},	//   _däwa_, রিনা, --, --, 
   {{0x09e20a47,0x00000000,0x00000000,0x00000000}},	// [3f700] оотн, --, --, --, 
   {{0xccb046e8,0x80d004c5,0x00000000,0x00000000}},	//   _мәсь, তাক্, --, --, 
   {{0x58d40032,0xdb0c0b1a,0x9b8801b9,0x1ddc2c30}},	//   лоҡт, ktbø, _جنجل_, मिकत, 
   {{0x99900034,0x1ae40354,0x7b2c0213,0xd6681291}},	//   rzył_, _томм, rğus, نماو_, 
   {{0x79500054,0x9990033f,0x00000000,0x00000000}},	//   häwi, szył_, --, --, 
   {{0x79500054,0xd3a40075,0x93a4023b,0x8e540a7c}},	//   käwi, арип, ашид, בינג_, 
   {{0x07a03334,0xc7a227de,0x61ec031c,0x7b1802d2}},	//   _марн, _мирк, _ġala, _tíud, 
   {{0x25a8341a,0x61ee27df,0xdb1c007c,0x5edc2cc5}},	//   šala_, _šala, _uppä, যাডে, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x910627e0,0x506492c6,0x7054030f,0x00000000}},	//   рчид, итна, ینکا, --, 
   {{0xcf242085,0xd78c044e,0xa3e000cd,0x00000000}},	//   لرحي, _ዝነበራ_, दिः_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x63a00306,0x00000000,0x00000000,0x00000000}},	//   _zvln, --, --, --, 
   {{0x644c02a8,0x25b80fac,0x41241910,0xc1700a7c}},	//   ƙait, _åsle_, _кочо_, _וחס_, 
   {{0xac940046,0x4ea40a5b,0x00000000,0x00000000}},	//   _қанш, _крпа, --, --, 
   {{0x27ec3bde,0x00000000,0x00000000,0x00000000}},	//   _čen_, --, --, --, 
   {{0x63740153,0x0ca960dc,0x09cc00eb,0x00000000}},	// [3f710] _išne, _итни_, রিভা, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7b2c05d2,0x00000000,0x00000000,0x00000000}},	//   mşun, --, --, --, 
   {{0x7528090c,0x67d404a9,0x09cc015b,0x5fa82d6b}},	//   _amdz, _қобу, রিবা, _किसल, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x69de27e1,0x7b18067c,0xb8ec0011,0xe3e80014}},	//   _isse, _víue, _শো_, ُکان_, 
   {{0x232a27e2,0xdb0c0fac,0x53700023,0x4de000cc}},	//   локи_, ttbø, _ሻባይት_, _পথোৱ, 
   {{0x752800d2,0x98b80024,0x7c2800db,0xf07001e1}},	//   _emdz, ropą_, údri, _òẹda_, 
   {{0xa0740efb,0x672a27e3,0x752801fa,0x79500227}},	//   йынш, _imej, _fmdz, wäwi, 
   {{0x69dc0c6a,0x634002b5,0x34948df2,0xdb0c0b1a}},	//   _msse, kēng, _маур, stbø, 
   {{0x245627e4,0xf77000dd,0x20119c0d,0xdee4020a}},	//   _اناس, _راہ_, ázi_, бони, 
   {{0x79500bc9,0xd78c0240,0x00000000,0x00000000}},	//   räwi, _ዝነብራ_, --, --, 
   {{0x672a27e5,0xd0e00490,0x04280023,0x9f05606c}},	//   _mmej, _कोकण_, _እንጦን, لوگو, 
   {{0xd5f802e4,0x7b8400d1,0x00000000,0x00000000}},	//   אפשר, قارە, --, --, 
   {{0x67280fb7,0x629a27e6,0x79500bc9,0xef1800ef}},	//   _omej, _kewo, qäwi, epļu_, 
   {{0x62980d29,0x00000000,0x00000000,0x00000000}},	//   _jewo, --, --, --, 
   {{0x6299368a,0x69dc0175,0x6abc0175,0x00000000}},	// [3f720] _mewo, _csse, _dcsf, --, 
   {{0x67280451,0x1868014b,0x62994dab,0x00000000}},	//   _amej, гази_, _lewo, --, 
   {{0x69de27e7,0x18a400c2,0x62980af9,0x00000000}},	//   _esse, _қавм, _oewo, --, 
   {{0x629a27e8,0x9954005f,0xb6880124,0x99f40153}},	//   _newo, _kļūs_, рҩаа_, _лягі, 
   {{0x86c06cb9,0x67280327,0xd1dc001f,0x7ae627e9}},	//   سيون, _dmej, ንባት_, mdit, 
   {{0x7ae627ea,0x672a27eb,0x6298033b,0x8e540a7c}},	//   ldit, _emej, _aewo, זינג_, 
   {{0x629a0c21,0x3a200354,0x7ae421b3,0x3f84168c}},	//   _bewo, lzip_, odit, _ntnu_, 
   {{0x69dc062c,0x3b006521,0xdb0c02f0,0x00000000}},	//   _ysse, njiq_, kubí, --, 
   {{0x3a2227ec,0x629802bd,0x3b000369,0x5fdc012d}},	//   nzip_, _dewo, ijiq_, _फैबल, 
   {{0xf8d8028a,0x7ae627ed,0xd4c40472,0xdb0c02d2}},	//   ड़िय, hdit, _دغري, dubí, 
   {{0x6298405d,0x7054484d,0xe2a800ec,0x00000000}},	//   _fewo, تندا, _چاهن_, --, 
   {{0x6299b35d,0x7ae454b0,0xe2a805d9,0xb904031c}},	//   _gewo, jdit, _ناهن_, _ྩི_, 
   {{0x7ae627ee,0xf8d805f9,0xc3c00137,0xdb0c01a8}},	//   ddit, ड़ाय, _дөөл, gubí, 
   {{0x7ae627ef,0xc0e00a89,0x634000b0,0x00000000}},	//   edit, _ночк, tēng, --, 
   {{0x8aa40228,0xef980032,0x7b2e27f0,0x629a27f1}},	//   йрад, _өйҙә_, rşun, _yewo, 
   {{0x15f83d4d,0x69dc0421,0x62981bce,0x7d7800f1}},	//   ्हार_, _psse, _xewo, شمېر_, 
   {{0x6f1c007b,0x0dc91bf5,0x7b2d679f,0xa898084c}},	// [3f730] mhsc, _суйи_, mşul, икау_, 
   {{0x672a27f2,0x7ae627f3,0x634000e2,0x2b48037e}},	//   _smej, adit, mēne, soac_, 
   {{0x7ae627f4,0x00000000,0x00000000,0x00000000}},	//   bdit, --, --, --, 
   {{0xd36627f5,0x6d5627f6,0x7b2c0213,0x00000000}},	//   _زه_, llza, nşul, --, 
   {{0xd244012f,0x69de27f7,0xe5a40c17,0x629a27f8}},	//   _آن_, _usse, цили, _rewo, 
   {{0x25aa27f9,0x2d88009f,0x629a27fa,0xd004fe06}},	//   šalo_, _mtae_, _sewo, _قل_, 
   {{0x629802e2,0x634000b0,0x6728031c,0x15640150}},	//   _pewo, hēne, _tmej, _ﺷﻮﺗﯩ, 
   {{0x672a27fb,0xdb1c00d7,0x9f540205,0x00000000}},	//   _umej, _uspô, ügüm_, --, 
   {{0x62980099,0x970000d1,0x11d4007b,0x20d400d4}},	//   _vewo, _تېنى, قوية_, оінс, 
   {{0x62982251,0x882c02d3,0xe12400d4,0xbb4c0092}},	//   _wewo, _ተኸታተ, імни, _መጥተዋ, 
   {{0x2d880421,0x5edc015b,0x629a27fc,0x7ae4005b}},	//   _atae_, যাসে, _tewo, ydit, 
   {{0x6f1e27fd,0x3f840158,0x6d5401f5,0xddc4011c}},	//   ghsc, _vtnu_, elza, обми, 
   {{0xa3e03174,0xb8fc2fb5,0x7d1c030d,0x26cc0332}},	//   दिक_, _རྒ_, thrs, _mbeo_, 
   {{0x61e85b36,0xa06a27fe,0xdb1c01a8,0x7ae40135}},	//   mvel, _кала_, _uppú, wdit, 
   {{0x61e80664,0x7ae4fe8c,0x26cc01e4,0x6f1c01e7}},	//   lvel, tdit, _obeo_, bhsc, 
   {{0x6ec02314,0x6f1e27ff,0x6d540d27,0x3a200194}},	//   _वायु, chsc, alza, tzip_, 
   {{0xda662800,0x61ea2801,0x99847ec6,0x9e640a11}},	// [3f740] زاري, nvel, زلاو, _باغن, 
   {{0x61ea2802,0x3a20010a,0x7ae62803,0x26cc0393}},	//   ivel, rzip_, sdit, _abeo_, 
   {{0x61ea2804,0xd1dc001f,0xdb1c03cd,0x61ec00de}},	//   hvel, ንባታ_, _oppø, _šall, 
   {{0x61ea2805,0x998400cf,0x68e400a3,0xc68c01d9}},	//   kvel, _ولجو, adhd, نِم_, 
   {{0x6440022e,0x7b2c03b9,0x00000000,0x00000000}},	//   _axli, nşum, --, --, 
   {{0x61e801ed,0xd7e800db,0x00000000,0x00000000}},	//   dvel, _кмге_, --, --, 
   {{0x64400393,0x47c0041b,0xd6f8010a,0x96b8003b}},	//   _cxli, _обрв, _кхаш_, _вузу_, 
   {{0x06040166,0x00000000,0x00000000,0x00000000}},	//   снәк_, --, --, --, 
   {{0xd138013e,0x61ea2806,0x79300092,0xdb0c0cd1}},	//   ихо_, gvel, _ተከታት, dtbü, 
   {{0x4fc400c9,0x255c010e,0xded40023,0x6fb81171}},	//   осма, _oňly_, _ይዀኑ_, бгор_, 
   {{0x61e89bc1,0x6f1cf207,0xdb0c01ed,0x03a001b9}},	//   avel, thsc, ntbó, _жихо, 
   {{0x61e80943,0xc42800cf,0x777ce20a,0x634000b0}},	//   bvel, _ئتكە_, _murx, tēne, 
   {{0x63740006,0x255c010e,0x7de402dd,0x0dc8144d}},	//   _išna, _aňly_, мірд, шуни_, 
   {{0x82c4031c,0x6f1c03ac,0xe81c00bc,0x00000000}},	//   _གཡོའ, shsc, पनमा_, --, 
   {{0xc04caebc,0xd45002d3,0x777c0946,0x31bc0011}},	//   _ці_, _ምዕባሌ, _nurx, _অনিশ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x29022807,0xd14c0023,0x1db0000d,0x7d2803b2}},	// [3f750] tjha_, _ምእታው, _जियत, ørsø, 
   {{0x777c022e,0xe5a40131,0xdb0c02d2,0x00000000}},	//   _burx, җики, ftbó, --, 
   {{0x61ea2808,0xe69407d2,0x5edc015b,0x00000000}},	//   zvel, كلاد, যারে, --, 
   {{0x644005b1,0x6284013f,0x61ea2809,0x61ec0153}},	//   _rxli, _ɑhos, yvel, _šalm, 
   {{0xe364d440,0x09cc00eb,0x00000000,0x00000000}},	//   үкли, রিহা, --, --, 
   {{0x63740309,0xe29800c7,0x00000000,0x00000000}},	//   _ašna, әап_, --, --, 
   {{0x777c0067,0xa6c400cf,0xb92400d1,0xd6e800cc}},	//   _gurx, _ىقسى, _تېلۋ, _ককৰা_, 
   {{0x4ac800cd,0x00000000,0x00000000,0x00000000}},	//   ाभिव, --, --, --, 
   {{0x170810e8,0xdb0c1427,0x00000000,0x00000000}},	//   _افقی_, nubá, --, --, 
   {{0x79500227,0x7b1808a5,0x61ec02d2,0x00000000}},	//   qäwt, _níun, _áalm, --, 
   {{0x61ea280a,0x777e280b,0x4ac816d1,0x352403cc}},	//   svel, _xurx, ाभाव, _تىلف, 
   {{0xd00c06f6,0x61e8257c,0xdb1c0174,0x00000000}},	//   الَ_, pvel, _uppø, --, 
   {{0x5edc015b,0xe3bc00fe,0x61e80477,0x5f741bf4}},	//   যালে, _আনিব, qvel, _کاتر, 
   {{0x3f740311,0xdb0c03b2,0xa4600023,0x61fc01f4}},	//   _băut_, dubá, _ትንታነ_, äslu, 
   {{0xd00dcab0,0x031c000d,0x00000000,0x00000000}},	//   _ملو_, _बताह_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x61ec04b9,0x25a808ad,0x777e280c,0x394c0208}},	// [3f760] _šalj, šalj_, _surx, _ưds_, 
   {{0x0e604a40,0xdc9801d5,0x00000000,0x00000000}},	//   _якын, _утиш_, --, --, 
   {{0x777d362c,0x62840134,0x7e600e78,0xaa2c0092}},	//   _qurx, _ɑhor, ümpf, _ተዘግቷ, 
   {{0x2c08012c,0x9f48007f,0x6b74012d,0x00000000}},	//   सहरू_, òkèt_, _wągr, --, 
   {{0x5fdc1dd1,0x20bc0e85,0x00000000,0x00000000}},	//   _फैसल, ्भाध, --, --, 
   {{0x82c4031c,0x777d226e,0x00000000,0x00000000}},	//   _གཡུའ, _turx, --, --, 
   {{0x777c0009,0xb3440166,0x00000000,0x00000000}},	//   _uurx, _luçş, --, --, 
   {{0xa6b434d8,0x883800d9,0x00000000,0x00000000}},	//   _осущ, _התלו, --, --, 
   {{0xcad425f9,0x1ac80183,0xd4d40006,0x00000000}},	//   לוקת_, _লোৱা, _ніжэ, --, 
   {{0x63ac0054,0x3016280d,0xc7ac00e5,0x00000000}},	//   ņana, ддор, _جڑے_, --, 
   {{0x7b2c010e,0x00000000,0x00000000,0x00000000}},	//   gşuk, --, --, --, 
   {{0xc7b00302,0x518400f3,0x7b18032e,0x00000000}},	//   עבר_, _еука, _síun, --, 
   {{0x92580046,0x00000000,0x00000000,0x00000000}},	//   _اشار_, --, --, --, 
   {{0x98b8012c,0xdb0c03b2,0x00000000,0x00000000}},	//   ropě_, vubá, --, --, 
   {{0x1b040154,0x00000000,0x00000000,0x00000000}},	//   রসনে_, --, --, --, 
   {{0xbae401c4,0x00000000,0x00000000,0x00000000}},	//   нцуй, --, --, --, 
   {{0x19c00cef,0x3da4084c,0x7b1801a8,0x00000000}},	// [3f770] кәрг, _прэб, _tíun, --, 
   {{0x61ec36dd,0x8eb0129d,0x25a80010,0x8934007b}},	//   _šalk, _تەڭت, šalk_, أعرا, 
   {{0xae040131,0x6144037e,0x00000000,0x00000000}},	//   _روھى, なleg, --, --, 
   {{0x612c0432,0x6f1c0036,0x85840150,0x00000000}},	//   _iºle, ërch, _ﻗﻮﺭﺍ_, --, 
   {{0xa508048a,0x63657d3e,0x09b40327,0xbb7c0131}},	//   жела_, lóng, _ཙཀྲ_, _ﻣﺎﯕﺎ_, 
   {{0xdcf40055,0xf65000db,0xdb0c08a5,0x4a400354}},	//   _kuyā, دئم_, gubæ, ăнăв, 
   {{0x86b01945,0xd4640209,0x00000000,0x00000000}},	//   _зөлф, мише_, --, --, 
   {{0xf77000db,0x22148404,0xd12c00f1,0xbec800ef}},	//   _ماق_, дфор, یمي_, _krīž, 
   {{0xd36c05d9,0xf3ec0209,0xa3e0012c,0xcfb40011}},	//   جهي_, _өң_, दिङ_, _জনগন, 
   {{0x9f841d0f,0x1fa80353,0x00000000,0x00000000}},	//   мгод, окои_, --, --, 
   {{0xdcf400b8,0x00000000,0x00000000,0x00000000}},	//   _nuyā, --, --, --, 
   {{0xc0c4004b,0x63a40118,0x00000000,0x00000000}},	//   _کېده_, áhnu, --, --, 
   {{0x747000c7,0xa1600124,0xd24c01c8,0x81b400cc}},	//   _иқәц, _иҭиҵ, _پنو_, _চনক_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdee407d6,0x71f800f7,0xbba801f9,0x00000000}},	//   _жойи, _ورۇس_, गळेक, --, 
   {{0x8f9823e4,0xbec8005f,0xcfb40375,0x00000000}},	//   _ויקי, _brīž, _חלקי_, --, 
   {{0x3ea006a3,0x63640005,0x98a40a5b,0x00000000}},	// [3f780] _ieit_, mónd, дизе, --, 
   {{0x3ea2280e,0x6364e4d9,0xcc840276,0xbad000fe}},	//   _heit_, bóng, _обье_, ৱাইছ, 
   {{0x3ea00dd4,0x247c02d3,0x98544009,0x00000000}},	//   _keit_, _ብሄራት_, фташ, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6ec007b7,0xdb0c03b2,0x00000000,0x00000000}},	//   _वासु, tubæ, --, --, 
   {{0x3ea2280f,0xf485be04,0xdb0c0332,0xe4c80014}},	//   _leit_, راتی, irbí, ۪بۆن_, 
   {{0x79840113,0x042800b8,0x636400e4,0x96ac010a}},	//   lqiw, _kāṇa, kónd, _гiар_, 
   {{0x3ea00a40,0xa2c001e0,0x836001d5,0xfa380092}},	//   _neit_, гәшк, نگنل, _በመስማ, 
   {{0x7984009a,0x611c0023,0x042800cd,0x8b540677}},	//   nqiw, _ስለዝኣ, _māṇa, ויקס_, 
   {{0x56940184,0x39840139,0x53f8007b,0x2d0c000d}},	//   _хаҡт, _mös_, _وراح_, _सकेल_, 
   {{0x3ea00652,0x3984ae8d,0x00000000,0x00000000}},	//   _beit_, _lös_, --, --, 
   {{0x3ea001c3,0x00000000,0x00000000,0x00000000}},	//   _ceit_, --, --, --, 
   {{0x3ea00e89,0x3984032e,0xdcf4002b,0x320003b9}},	//   _deit_, _nös_, _suyā, _çiy_, 
   {{0x3ea00076,0xed0400f2,0x00000000,0x00000000}},	//   _eeit_, روزپ, --, --, 
   {{0x3ea09045,0xead47c0c,0x8f4405f5,0x042800dc}},	//   _feit_, новь, _охид, _bāṇa, 
   {{0x61ec0953,0x3984b44b,0x636455f7,0x00000000}},	//   _šali, _bös_, cónd, --, 
   {{0x6f0e2810,0xbf140014,0xf4b000b8,0x2bdc00bc}},	// [3f790] _ioac, _شوٝب, _guṇī_, मबहा, 
   {{0x3ea0d0fe,0x7e622811,0x6f0e2812,0x8d7410de}},	//   _zeit_, ümpe, _hoac, _تاعا, 
   {{0x2eea2813,0x6f0c0165,0x6b74084c,0x636453ad}},	//   _kaaf_, _koac, _плоу, lóne, 
   {{0x6f0e2814,0x39862815,0x042800b8,0x00000000}},	//   _joac, _fös_, _gāṇa, --, 
   {{0x25aa2816,0x2ee815a5,0x39862817,0x1614bd8d}},	//   éal_, _maaf_, _gös_, थनगर_, 
   {{0x2ee9adfa,0x29040037,0x64a40354,0x00000000}},	//   _laaf_, _õla_, хака, --, 
   {{0x7d080bac,0x66181bc5,0x00000000,0x00000000}},	//   ödsi, _şakı, --, --, 
   {{0x2ee8198f,0xd76400db,0x398415b7,0x00000000}},	//   _naaf_, _كەلى_, _yös_, --, 
   {{0x26de2818,0xe1f035e6,0x3ea22819,0x72080014}},	//   mewo_, اسب_, _reit_, ٘ہنہ_, 
   {{0x3ea2281a,0x26de281b,0x2ca00099,0x6f0c02d0}},	//   _seit_, lewo_, _nehd_, _aoac, 
   {{0x3ea00652,0x6f0e281c,0x637400f3,0x00000000}},	//   _peit_, _boac, _ušno, --, 
   {{0x6f0e281d,0xe1f2281e,0x26dc898f,0x6364067c}},	//   _coac, _مست_, newo_, fóne, 
   {{0x3ea043d3,0x2ee8c990,0x236c014f,0x6ec011bc}},	//   _veit_, _daaf_, mmej_, _वारु, 
   {{0x62891de8,0x3ea174a9,0x4f840014,0x19a800d1}},	//   lceo, _weit_, بایہ, _ﺷﻪﻛﻠ, 
   {{0x8c41afde,0x26de281f,0x2ee80009,0x8d6073ea}},	//   гере, kewo_, _faaf_, увре, 
   {{0x26de2820,0x2eea2821,0x6f0c0165,0x3ea0067c}},	//   jewo_, _gaaf_, _goac, _ueit_, 
   {{0x26de2822,0xdb0c002f,0x62880332,0x00000000}},	// [3f7a0] dewo_, ktbö, iceo, --, 
   {{0x7e65ba88,0xdc98006c,0x442401f0,0xd5d8033f}},	//   _izip, _этиш_, kzn_, _मैगज, 
   {{0x2c00053f,0x236c00d7,0xefdc0092,0x00000000}},	//   _күрм, kmej_, ንፃው_, --, 
   {{0x42c00c58,0xf8b000dd,0x6f0c0005,0x5edc015b}},	//   ্যুশ, _چکا_, _xoac, যাকে, 
   {{0xceb006a9,0x9484d8d1,0xdb0c007c,0x236c0419}},	//   ריד_, ныйд, ftbö, dmej_, 
   {{0x53e461ff,0x7e64009f,0xf434010b,0x94a8009f}},	//   ециа, _mzip, келэ, ساتِ_, 
   {{0x26de2823,0x1868022e,0x6ec08109,0x00000000}},	//   bewo_, _хави_, _वालु, --, 
   {{0x7e64401f,0x7f440200,0xd704030d,0x00000000}},	//   _ozip, _njiq, _язби, --, 
   {{0x7e6401f2,0x00000000,0x00000000,0x00000000}},	//   _nzip, --, --, --, 
   {{0x6f0e2824,0x2eea2825,0x236c0419,0x1048003b}},	//   _soac, _saaf_, amej_, зями_, 
   {{0x6f0e18a0,0x7e6449e1,0x6e943f51,0x2ee804cc}},	//   _poac, _azip, кину, _paaf_, 
   {{0x2eea2826,0x636400d7,0x00000000,0x00000000}},	//   _qaaf_, tóne, --, --, 
   {{0x61ec0306,0x0fe0004e,0x6e440023,0x00000000}},	//   _šalv, _өөнү, _የንጸባ, --, 
   {{0x636400bd,0x7e640dc6,0x26dcae4b,0x5edc0154}},	//   róne, _dzip, zewo_, যাগে, 
   {{0x7e65a102,0x6f0c0311,0x7c840798,0x00000000}},	//   _ezip, _toac, ѓуре, --, 
   {{0xac9800b2,0x00000000,0x00000000,0x00000000}},	//   _ڪندا_, --, --, --, 
   {{0x7b662827,0x26dc006f,0x00000000,0x00000000}},	// [3f7b0] утре, vewo_, --, --, 
   {{0x26de2828,0x3da400a7,0xdb0c007c,0x00000000}},	//   wewo_, _сръб, xtbö, --, 
   {{0x26de2829,0x6364180f,0x06b401d3,0x236c0455}},	//   tewo_, nónc, فناک_, ymej_, 
   {{0x43b001e0,0x7b1802d2,0x659401f0,0xa61400db}},	//   ҫҡар, _níuh, ваду, кмеч, 
   {{0x26de282a,0x236c014f,0xdb0c002f,0x00000000}},	//   rewo_, vmej_, ttbö, --, 
   {{0x69cc1028,0xbc383292,0x8554141d,0x26de282b}},	//   mtae, _آسیا_, ریار_, sewo_, 
   {{0x69cc0958,0x26dd12f1,0xb3e8007b,0x236c0455}},	//   ltae, pewo_, فعيل_, tmej_, 
   {{0xd36c06f6,0x83840022,0x25d801ec,0xdb0c007c}},	//   يهو_, _ҷыде, _омбы_, stbö, 
   {{0x69ce282c,0x6288ae67,0x2258037e,0x20b8084c}},	//   ntae, rceo, æsk_, мынь_, 
   {{0x6d4406e4,0x69ce282d,0x25ac0036,0x6288007b}},	//   _njha, itae, _ivel_, sceo, 
   {{0x69ccd62e,0x349536eb,0x20100109,0xa2d4009f}},	//   htae, _сахр, âzi_, _ليات, 
   {{0x69cc1509,0xa29400d6,0x21b409a5,0x61ec0024}},	//   ktae, _раді, _айдя, _šalu, 
   {{0xd00c53e2,0x8ee00154,0xf19401c4,0x00000000}},	//   ملی_, যাংগ, _бичь, --, 
   {{0xe0d83334,0x9f9400c7,0xa0c4007b,0x00000000}},	//   _цвк_, _ҧықә, _شيبو, --, 
   {{0x6d4400b5,0x7e64009a,0x69cc5440,0x00000000}},	//   _djha, _wzip, etae, --, 
   {{0x69cc08cd,0x0b403840,0xdb0c1d0e,0x00000000}},	//   ftae, ансн, lubú, --, 
   {{0x7e640944,0x98a800b8,0xca8030ab,0xcee001ec}},	// [3f7c0] _uzip, _ambā_, ргуй, _тұяқ, 
   {{0xa3e00073,0x00000000,0x00000000,0x00000000}},	//   धबा_, --, --, --, 
   {{0x25ae282e,0x69ce282f,0x00000000,0x00000000}},	//   _avel_, atae, --, --, 
   {{0xa8540114,0x00000000,0x00000000,0x00000000}},	//   утуј, --, --, --, 
   {{0x75d40228,0x80a404c5,0x69cc0381,0xdbdc01e1}},	//   ايتا, _খান্, ctae, _ṣèb, 
   {{0xd94465cf,0x5edc015b,0x1acc012c,0x25ac02d2}},	//   _реги, যাটে, ह्रथ, _dvel_, 
   {{0x25ac07e4,0xa8640184,0x13681d0f,0x07a0688a}},	//   _evel_, _берҙ, мшии_, _васн, 
   {{0x7b2c0790,0x91a400e5,0x00000000,0x00000000}},	//   mşus, نچتے_, --, --, 
   {{0xdb0c02d2,0x7178004e,0x00000000,0x00000000}},	//   fubú, нбир_, --, --, 
   {{0x50643306,0xdb0c0413,0x4270010b,0x636400d7}},	//   َادِ, gubú, шгыс, tónc, 
   {{0x61ec56ad,0x94041ff7,0xc4980375,0x6f7401ca}},	//   _šalt, _جواه, _חשבת, лгоф, 
   {{0x69cc003a,0x00000000,0x00000000,0x00000000}},	//   ytae, --, --, --, 
   {{0x73c401ee,0xff84009d,0x00000000,0x00000000}},	//   _рәһе, нөөл_, --, --, 
   {{0xc27813e2,0x39ac00e1,0x00000000,0x00000000}},	//   _חרדי, _चिड़ि, --, --, 
   {{0x98b800b0,0x636401d3,0x74380092,0x5edc00eb}},	//   hopē_, lóna, _እንጠብ, যাজে, 
   {{0x69cc049b,0x7f900107,0xb80803d4,0x00000000}},	//   ttae, _таъх, লনাত_, --, 
   {{0x6d440032,0x61ec0077,0x69cc05c7,0x636401f6}},	// [3f7d0] _tjha, _áalt, utae, nóna, 
   {{0x69ce2830,0x0b883aeb,0x7d1c005a,0x69b800d1}},	//   rtae, _осми_, ckrs, _ﺧﻪﻧﺰ, 
   {{0x69ce2831,0x6d562832,0x80a402f5,0x25ac0165}},	//   stae, moza, _খাম্, _svel_, 
   {{0x69ce2833,0x6d54607f,0x25ac0165,0x00000000}},	//   ptae, loza, _pvel_, --, 
   {{0x6364066a,0xd6cc0372,0x5edc0154,0x00000000}},	//   jóna, سقو_, যাচে, --, 
   {{0x6594052f,0x63740024,0x636401d3,0xf56801d3}},	//   _ҡабу, _išni, dóna, نمنٹ_, 
   {{0xc6a41ee3,0x6b840455,0x6f1c03cd,0x2b580064}},	//   _арзи, _juhg, kksc, _kksc_, 
   {{0x6d562834,0x29122835,0x6f1c0d27,0x636401e7}},	//   hoza, _hoza_, jksc, fóna, 
   {{0x6d562836,0x25addcf2,0x45a000d1,0x25b809e8}},	//   koza, _uvel_, _ئەتك, _ísl_, 
   {{0x600a261d,0x6f1c01a4,0x00000000,0x00000000}},	//   еном_, eksc, --, --, 
   {{0x29122837,0xc2b00046,0x6d54eb48,0x6b840455}},	//   _moza_, _көпш, doza, _nuhg, 
   {{0x29100851,0x2004022e,0x7b2c03b9,0x00000000}},	//   _loza_, rxli_, hşur, --, 
   {{0x6d562838,0x63640332,0xdb0c0162,0x00000000}},	//   foza, cóna, mubø, --, 
   {{0x6b862839,0x29101617,0xdb0c0162,0x712400db}},	//   _buhg, _noza_, lubø, _ۅرۉل, 
   {{0x6b840369,0x00000000,0x00000000,0x00000000}},	//   _cuhg, --, --, --, 
   {{0x7d1c4beb,0x6f1c1f16,0x2910030a,0x6b8401ab}},	//   skrs, cksc, _aoza_, _duhg, 
   {{0x29100296,0x7d08007c,0x00000000,0x00000000}},	// [3f7e0] _boza_, ödss, --, --, 
   {{0x2912283a,0x6d540356,0x2d9402e8,0x00000000}},	//   _coza_, coza, _тръс, --, 
   {{0x9b461f76,0x2912283b,0x6b840007,0x948402dd}},	//   _مندو, _doza_, _guhg, қылд, 
   {{0xdad00131,0xdb0c06ea,0x9644009d,0x09cc0154}},	//   _دەرھ, jubø, лэлд, রিজা, 
   {{0x97c4053f,0x291006d9,0xfdf41d8a,0x75380cf4}},	//   _әйбе, _foza_, इटिस_, tivz, 
   {{0x2912283c,0xd7040075,0x889001a9,0x00000000}},	//   _goza_, _өзги, _гиёх, --, 
   {{0xd37a283d,0x28740c98,0xd82435c7,0x03a00063}},	//   нчи_, _вытр, _сдви, бијо, 
   {{0x6d56283e,0x2910026c,0x63643add,0xdb0c0174}},	//   zoza, _zoza_, tóna, gubø, 
   {{0x6d56283f,0xd9f405d7,0xc1b40a89,0xcb100375}},	//   yoza, ीमित_, глых_, מלה_, 
   {{0x63643ac8,0x09cc0154,0x3134117e,0x00000000}},	//   róna, রিচা, реор, --, 
   {{0x6d562840,0x82d402dd,0x6364950c,0x1db0000d}},	//   voza, _әдіс_, sóna, _जिउत, 
   {{0x6d54b0df,0x2d3c001f,0x201004cc,0x6b85310f}},	//   woza, _አቅራቢ, äzia_, _ruhg, 
   {{0x6f1e2841,0x83504028,0x00000000,0x00000000}},	//   rksc, _اپنا, --, --, 
   {{0x2eec8e70,0xada40124,0x636401e7,0x7095aa20}},	//   žef_, лаҭл, nónn, _такф, 
   {{0x2434a38c,0x6d5400dd,0x6618033f,0x4ed0010a}},	//   _እንደሚ, roza, zywk, _гιев, 
   {{0x6d562842,0x7b2c00ee,0xfb8400fd,0x291000d7}},	//   soza, wşur, сырн, _soza_, 
   {{0x6d562843,0x29122844,0x69340150,0x00000000}},	// [3f7f0] poza, _poza_, анау, --, 
   {{0x6d54014b,0x2d980f85,0x00000000,0x00000000}},	//   qoza, mpse_, --, --, 
   {{0x8b6410fe,0x29103421,0x2d980af9,0xc2e80154}},	//   _ماحم, _voza_, lpse_, কাতি_, 
   {{0x29122845,0x2d98954c,0x09cc00fe,0xe3e80133}},	//   _woza_, opse_, ৰিবা, ێکان_, 
   {{0x66062846,0x64a56e74,0x29122847,0x636401f1}},	//   рпла, аала, _toza_, fónn, 
   {{0x69de2848,0xfbd06f43,0x63422849,0x2910009f}},	//   _ipse, _بتی_, mēni, _uoza_, 
   {{0x6340005f,0xdb0c03b2,0x3cfc011a,0x00000000}},	//   lēni, tubø, תלונ, --, 
   {{0x682c0125,0xd24c004b,0x5ed80154,0xddd4012d}},	//   ተክርስ, ژني_, _বোনে, _czyś, 
   {{0x130434d8,0x86240953,0x69dc0175,0x2ba4712e}},	//   рный_, _сьве, _jpse, गीता, 
   {{0x69dc0ac5,0x358c02d3,0xdb1c032e,0xf1c40116}},	//   _mpse, _ንሰባት_, _uppö, _ﻫﻪﻗﺘ, 
   {{0x5f050f7c,0xf5040050,0x2d989e7a,0x00000000}},	//   азна, _دِلُ, epse_, --, 
   {{0x53980302,0x850000af,0x5f34283c,0x636400d7}},	//   _ייעו, लावट_, рхоф, móno, 
   {{0x21a4d175,0x63640f91,0x57d00073,0xf2ac010f}},	//   _тилм, lóno, _सह्ह, _טשאָ, 
   {{0x40841677,0xdcb00131,0x8ee00154,0x51cc01ec}},	//   _судб, غىز_, যাগগ, _ﻛﻪﻣﺸ, 
   {{0x69de284a,0x2d98017a,0x38bc01e1,0x63640419}},	//   _apse, apse_, _lárà_, nóno, 
   {{0x636402fb,0x7b18032e,0x428c0092,0x4b200108}},	//   zónn, _níut, _መኢአድ_, омсв, 
  
   {{0x3f861942,0x589402dd,0xdb0c01bf,0x6b880115}},	// [3f800] _hunu_, لجاز, jrbå, ĉega, 
   {{0x3f86284b,0x09000276,0x63640030,0x3f8000c5}},	//   _kunu_, опун, kóno, _hiiu_, 
   {{0x2ba41533,0x3f844beb,0x69dc037e,0xf984013e}},	//   गीदा, _junu_, _epse, рҳҳо, 
   {{0x3f840008,0x7a2c07ea,0xd5ba284c,0xc4f400e5}},	//   _munu_, _côté, вск_, یٹنا_, 
   {{0x69dc00c6,0xb8cc2158,0x7ae6284d,0x068030cb}},	//   _gpse, _গা_, meit, әгән, 
   {{0x7ae6284e,0x38bc0241,0x636401f1,0x3f800076}},	//   leit, _dárà_, fóno, _liiu_, 
   {{0x3f86284f,0xd404fa65,0x61ec00c0,0x636400d7}},	//   _nunu_, ряли, _šalp, góno, 
   {{0xb024431d,0x7ae62850,0x69dcef6f,0x00000000}},	//   _ngườ, neit, _ypse, --, 
   {{0x3f840607,0xd20801c6,0x74140345,0x2010000d}},	//   _aunu_, тэйд_, شوکا, äzin_, 
   {{0x3f846f30,0x7ae62851,0x629c0174,0x15880220}},	//   _bunu_, heit, ðsor, _ﻗﻮﺳﯩ, 
   {{0x93140214,0x2f180212,0x7054007b,0x00000000}},	//   _پوشش, гонь_, إنجا, --, 
   {{0x7ae62852,0x3f840694,0x00000000,0x00000000}},	//   jeit, _dunu_, --, --, 
   {{0x7ae62853,0x7b180ba1,0x3f8001ab,0xc8c41524}},	//   deit, _líus, _diiu_, _लालट, 
   {{0x2d9a2854,0x3f862855,0x7c843d2a,0xc0e0ef44}},	//   rpse_, _funu_, жуте, _мочк, 
   {{0x7ae62856,0x3f8419a2,0x8aa407d6,0x8b5806f6}},	//   feit, _gunu_, ирад, نجرس_, 
   {{0x7ae401c0,0x69dc01fa,0x609401d3,0x2d9801c7}},	//   geit, _ppse, _پچیس_, ppse_, 
   {{0x386c016b,0x63640306,0x256801e7,0xec300116}},	// [3f810] ɑkrɑ_, zóno, húla_, زۈڭگ, 
   {{0x2568022c,0x3f840de2,0x38bc0248,0x12d801ec}},	//   kúla_, _yunu_, _rárà_, _ﺃﻤﻴﺭ, 
   {{0x7ae62857,0xdb0c0419,0xe8540137,0xb95400db}},	//   beit, lubý, حناد, زئكت, 
   {{0x7ae40a62,0x2d800270,0x2d8800c7,0x2568007b}},	//   ceit, _hihe_, _kuae_, dúla_, 
   {{0x2d8073f4,0x6aae2858,0x69dc0e21,0xc79400f7}},	//   _kihe_, maaf, _upse, اپچا_, 
   {{0x63662859,0x6aae285a,0xe85805f5,0x2d88013f}},	//   tóno, laaf, _багш_, _muae_, 
   {{0x2d880076,0x2d800010,0x86b002dd,0x256801e7}},	//   _luae_, _mihe_, _дәлі, gúla_, 
   {{0x6aac22a9,0x68e4049b,0x2d880270,0x63661d09}},	//   naaf, lehd, _ouae_, róno, 
   {{0x3f843d27,0x26cdd17c,0x29cc01e4,0x6aac0194}},	//   _sunu_, _iceo_, _iɾas_, iaaf, 
   {{0x3f840986,0x6aae285b,0x7ae409a4,0x2d82285c}},	//   _punu_, haaf, zeit, _nihe_, 
   {{0x7ae4ba15,0x3f84b930,0x6aae285d,0x25680332}},	//   yeit, _qunu_, kaaf, cúla_, 
   {{0x7ae4172e,0x2d88016b,0x2d8002f6,0xb1440228}},	//   xeit, _buae_, _aihe_, йнөл, 
   {{0x2d81a82a,0x6aac3388,0x3f80026c,0x21740262}},	//   _bihe_, daaf, _viiu_, _лукр, 
   {{0x61ea285e,0x7ae6285f,0x2d881730,0x3f80037e}},	//   mwel, weit, _duae_, _wiiu_, 
   {{0x61ea2860,0x7ae62861,0xdca40075,0xdb080122}},	//   lwel, teit, _қани, šník, 
   {{0x6aad81a0,0x2d88003a,0x8c416372,0xbab80183}},	//   gaaf, _fuae_, чесе, ুজ্ঞ, 
   {{0xcb640395,0xddb400ae,0x00000000,0x00000000}},	// [3f820] сате_, _احبب, --, --, 
   {{0x2d800537,0x7ae62862,0x26cc0421,0x98a4084c}},	//   _gihe_, seit, _aceo_, сиже, 
   {{0x61ea2863,0x7ae62864,0x6aacafb9,0x63640ad9}},	//   hwel, peit, baaf, tónl, 
   {{0x61ea2865,0x6aac22a9,0x2d8000ca,0x9a28220f}},	//   kwel, caaf, _zihe_, _бомб_, 
   {{0x2d822866,0x850002a0,0x68e5f081,0x96000d2e}},	//   _yihe_, लांट_, behd, लमेट_, 
   {{0x61ea2867,0x256800c6,0x00000000,0x00000000}},	//   dwel, túla_, --, --, 
   {{0x5ae4031c,0x61e8bab7,0xb4e80cf1,0x4938011a}},	//   _སྒོམ, ewel, _बसी_, _עגלו, 
   {{0xf318016c,0x61e80368,0x26cc0332,0x733403cc}},	//   роиш_, fwel, _gceo_, تىبا, 
   {{0x61ea2868,0xc8cc1f13,0x25690ca1,0xdb0e2869}},	//   gwel, स्कट, súla_, dubü, 
   {{0x2568007b,0x80d00490,0x91041618,0xf8a80959}},	//   púla_, ब्ले, счид, गरिय, 
   {{0x2d880483,0x61ea286a,0x2d8000ca,0x5ed804c5}},	//   _suae_, awel, _rihe_, _বোধে, 
   {{0x0dc93ffc,0x6aac0050,0x61ea286b,0x5284007b}},	//   луги_, xaaf, bwel, _الإك, 
   {{0x2d88c51b,0x61e82a6c,0x2d82286c,0x4ba40137}},	//   _quae_, cwel, _pihe_, өөнү_, 
   {{0x7176286d,0x6aac2f66,0xc8c425c9,0x7f8000f1}},	//   _بهتا, waaf, _लाइट, _کلين, 
   {{0xc2e800bd,0x6aae286e,0x00000000,0x00000000}},	//   কারি_, taaf, --, --, 
   {{0x2d881730,0xdb0c01e1,0x2bbc0118,0x00000000}},	//   _tuae_, _òjìl, ौंबा, --, 
   {{0x6aae286f,0x2d822870,0x2d88003a,0x68e4005b}},	// [3f830] raaf, _tihe_, _uuae_, tehd, 
   {{0x6aae2871,0x00000000,0x00000000,0x00000000}},	//   saaf, --, --, --, 
   {{0x61e80928,0x68e62872,0x6aac013c,0x9d7400cf}},	//   zwel, rehd, paaf, _بئيچ, 
   {{0x61ea2873,0x68e402f6,0x6aac1db9,0x752800ef}},	//   ywel, sehd, qaaf, _aldz, 
   {{0xf9640133,0xff7c010f,0x00000000,0x00000000}},	//   _کۆلێ, אטאמ, --, --, 
   {{0x0a8800db,0x8500072a,0xe42400f1,0x80b4012d}},	//   _جئگى_, लाइट_, يکاي, _आयें, 
   {{0x61e80221,0xe81801c0,0x00000000,0x00000000}},	//   wwel, _товч_, --, --, 
   {{0x61ea2874,0xcb5c002e,0x2b48030a,0x636400d7}},	//   twel, _d茜gg_, nnac_, pónm, 
   {{0x61ea2875,0x2fc01140,0xc2e800fe,0x672a2876}},	//   uwel, _āiga_, কালি_, _ilej, 
   {{0x61e87585,0xd24c01d5,0x00000000,0x00000000}},	//   rwel, خچم_, --, --, 
   {{0xa0681377,0x61e853ff,0xdf4a1e7f,0x672a2877}},	//   рана_, swel, изод_, _klej, 
   {{0x61ea2878,0x2b48009b,0x00000000,0x00000000}},	//   pwel, jnac_, --, --, 
   {{0x20d402bf,0x61e82d2f,0x6728013a,0x00000000}},	//   _дійс, qwel, _mlej, --, 
   {{0x23de2879,0x6728031c,0xed340276,0x612c02d2}},	//   _महाद, _llej, пэсэ, _súlf, 
   {{0x6728489c,0xe1f80006,0x2b480129,0x9cc90e19}},	//   _olej, lvų_, fnac_, лыңа_, 
   {{0x2b48bcb5,0x5f74314e,0x612e287a,0x634002b5}},	//   gnac_, _باتر, _búlg, pēnu, 
   {{0x612c01e7,0x00000000,0x00000000,0x00000000}},	// [3f840] _cúlg, --, --, --, 
   {{0x672a287b,0x7e66287c,0x9d46287d,0xb4e83f6f}},	//   _alej, _iyip, _феод, _बसे_, 
   {{0x57ea287e,0x672a287f,0x85000c4c,0x7e6401e7}},	//   рдем_, _blej, लाईट_, _hyip, 
   {{0x2b4a2880,0x67280311,0x612c02d2,0x96b8005b}},	//   cnac_, _clej, _fúlg, ружу_, 
   {{0x672a2881,0x6fc007d0,0x5638041b,0xdb0c03b2}},	//   _dlej, _विभू, јџер_, subó, 
   {{0x672801ed,0x3494774c,0xe1f80064,0x81dc00eb}},	//   _elej, чакр, dvų_, দটা_, 
   {{0x7e64014b,0x1584001f,0x672a2882,0x00000000}},	//   _lyip, ክብካቤ_, _flej, --, 
   {{0x7e662883,0x67280427,0x00000000,0x00000000}},	//   _oyip, _glej, --, --, 
   {{0x7e6551c3,0x629c030a,0x68f800ae,0x23940055}},	//   _nyip, ñsoa, _éadó, _rāje_, 
   {{0xed0403d4,0xb0343c85,0x67290bdf,0x2b4c04a7}},	//   _উত্স_, знош, _zlej, čeci_, 
   {{0x7e6438fb,0x67280254,0xc9500677,0x00000000}},	//   _ayip, _ylej, ומז_, --, 
   {{0x63640ba1,0xc7d4011a,0x03a00a5b,0xc2e001a9}},	//   jónh, חוטי_, _цицо, _жўши, 
   {{0x8d7402dd,0x0560074d,0xfe70009f,0x239400b8}},	//   قاسا, _авăн, َدُ_, _vāje_, 
   {{0x7e640280,0xd3780055,0xac18e0d8,0xb4e804af}},	//   _dyip, _dṛśi_, богу_, _बसो_, 
   {{0x7e662884,0xcb5c002e,0x4c7001e0,0x0fd0030d}},	//   _eyip, _l茜eg_, ьҫор, _цιен, 
   {{0x28dc1a3e,0x2b48030a,0x00000000,0x00000000}},	//   न्नि, unac_, --, --, 
   {{0x214800c7,0xca740131,0x0dc80107,0x256808a5}},	// [3f850] _ñuhã_, زارغ, _туйи_, fúll_, 
   {{0xc864048a,0xd8e4031c,0x672800e2,0x61fc03cd}},	//   отеи, _ཤྲཱི, _slej, åsli, 
   {{0x672a2885,0xf771d86e,0x7d5400db,0x00000000}},	//   _plej, چان_, _تئيئ, --, 
   {{0xd3642dd2,0xe1f80024,0xf7704e85,0x63650d3f}},	//   _سه_, yvų_, پام_, rónk, 
   {{0xd24406d5,0xe5a4785a,0xf548063f,0x672a2886}},	//   _أن_, чили, wụa_, _vlej, 
   {{0xd00406d5,0x636467ac,0x7e6000af,0x00000000}},	//   _كل_, móni, ümpi, --, 
   {{0x63641de4,0x743802d3,0x6728030a,0x68f403ac}},	//   lóni, _እንገብ, _tlej, _iazd, 
   {{0x6728005c,0x7bc801ab,0x00000000,0x00000000}},	//   _ulej, àdui, --, --, 
   {{0x6364fd6f,0x68f4e92c,0xd36c1371,0xdafc00d8}},	//   nóni, _kazd, دهي_, _pãºb, 
   {{0x68f6115d,0x7e6400ca,0x2cb0773c,0xe1f80024}},	//   _jazd, _ryip, jazd_, rvų_, 
   {{0xe1f80024,0x3ec4013e,0xd00c03e6,0x00000000}},	//   svų_, минҳ, ۆلی_, --, 
   {{0x68f42e03,0x3a20247e,0xd00c07d6,0xdcf40139}},	//   _lazd, yyip_, چلی_, _buyğ, 
   {{0x63642242,0xd00e2887,0xa1583334,0x00000000}},	//   jóni, نلی_, _ладу_, --, 
   {{0x612e2888,0x1fb400ee,0xdcf40213,0xdcfc0427}},	//   _búle, _есир, _duyğ, _tipč, 
   {{0xe9f80124,0x00000000,0x00000000,0x00000000}},	//   raẽ_, --, --, --, 
   {{0x63642b76,0xb4e800bc,0x00000000,0x00000000}},	//   fóni, _बस्_, --, --, 
   {{0x7e6461d4,0x636410e6,0x9984015e,0x09e001a9}},	// [3f860] _uyip, góni, سلاو, нотн, 
   {{0x38c97c05,0x0e540bd4,0x4a401b0a,0x00000000}},	//   تاری_, _משפט_, хнув, --, 
   {{0x68f40419,0x00000000,0x00000000,0x00000000}},	//   _dazd, --, --, --, 
   {{0x63640077,0x00000000,0x00000000,0x00000000}},	//   bóni, --, --, --, 
   {{0xaad404fa,0x63640077,0xf8b80124,0x68f40205}},	//   _डॉटक, cóni, _мҩа_, _fazd, 
   {{0x68f62889,0x1ca80867,0x5f3c0521,0xd6d801d5}},	//   _gazd, _བབས_, ọghị_, _گورش_, 
   {{0x88b00d73,0x96b800f3,0xdeb80092,0x00000000}},	//   _سینچ, _гузу_, ሳመን_, --, 
   {{0xa3ac10f7,0x68f6288a,0xe7f00073,0x845000cf}},	//   _कबर_, _zazd, _घनता_, رۉنچ, 
   {{0x68f4d814,0x325450af,0x3134277c,0xd64c01f2}},	//   _yazd, ьвир, депр, gọtụ_, 
   {{0x85980302,0x6fc01a2a,0xf8cc1f13,0xded40023}},	//   _לשמו, _विदू, ालिय, _ክዀኑ_, 
   {{0x6365069d,0x63ac0e3c,0x00000000,0x00000000}},	//   zóni, ćanc, --, --, 
   {{0xd64c01f2,0x612c00ae,0xae880137,0xdb0c02d2}},	//   bọtụ_, _cúlb, өбүз_, fsbí, 
   {{0xc3300302,0x7e28109a,0x29040162,0xdcf4008e}},	//   _אוף_, піра_, _ólag_, _quyğ, 
   {{0xc16c10f5,0xefcc0201,0x2d84007d,0xe2447da6}},	//   _її_, ባለው_, öle_, _تخمي, 
   {{0x2cb00427,0x80d800d9,0x239400de,0xfbd00014}},	//   razd_, _החוז, _kāja_, ێتہ_, 
   {{0x7ff000c6,0x68f4010e,0xdcf40166,0x806408f4}},	//   _أسوا, _sazd, _tuyğ, _عميق_, 
   {{0x68f6288b,0x239400da,0x0e8001e2,0x7b2c06be}},	// [3f870] _pazd, _māja_, _سیسټ, nşuy, 
   {{0x6364d40b,0x23940055,0x68f4290f,0x00000000}},	//   róni, _lāja_, _qazd, --, 
   {{0x68f41467,0xfe700f1c,0x63640a90,0xd64c063f}},	//   _vazd, _لدی_, sóni, zọtụ_, 
   {{0x6364a92b,0xcfac015b,0x00000000,0x00000000}},	//   póni, _কমান, --, --, 
   {{0x5eb0015b,0x68f40076,0x00000000,0x00000000}},	//   _ঝামে, _tazd, --, --, 
   {{0xfdf8011a,0x00000000,0x00000000,0x00000000}},	//   פצות_, --, --, --, 
   {{0x24800036,0xd3440133,0x00000000,0x00000000}},	//   ähm_, ژیمه_, --, --, 
   {{0x98b80270,0xe1f0007b,0xb4ac033f,0x78bc00d7}},	//   mipā_, نسخ_, _कड़ी_, _zdrv, 
   {{0x290401ab,0x97000131,0x28dc7239,0xc4d800f3}},	//   _òlas_, _جېنى, न्थि, _гђе_, 
   {{0x3494041b,0xd05803b9,0x00000000,0x00000000}},	//   _зафр, letə, --, --, 
   {{0x2054005b,0x2ef803b2,0xdcfc00dc,0x00000000}},	//   ьтир, fdsf_, _nipā, --, 
   {{0x28dc1c4c,0xd64c01f2,0x239400e2,0x80cc121d}},	//   न्ति, pọtụ_, _gāja_, _दावे, 
   {{0xf54801f2,0x612c00ae,0xe6080171,0x00000000}},	//   kụl_, _cúlc, _lūžņ, --, 
   {{0xd00c1de7,0x25e402e5,0xe046288c,0x91e098e0}},	//   _چلو_, _टहनी_, _онли, _роше, 
   {{0x35940023,0x00000000,0x00000000,0x00000000}},	//   ዝብታት_, --, --, --, 
   {{0x61ec02d5,0x3b480092,0x00000000,0x00000000}},	//   _šaly, _የእመቤ, --, --, 
   {{0x5986288d,0x287400c7,0x00000000,0x00000000}},	// [3f880] длаб, ҭыхр, --, --, 
   {{0x14d00073,0x2c1c00cc,0x00000000,0x00000000}},	//   _साधण, _নধৰে_, --, --, 
   {{0x28dcf3ec,0x629a288e,0x2c0000d1,0xdb0c2268}},	//   न्धि, _ofwo, _йүрм, rsbâ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x239400dc,0x636403b2,0xdb0c02d2,0x00000000}},	//   _rāja_, nónu, fubö, --, 
   {{0x629802e2,0x28dccace,0xdb0c002f,0x94840166}},	//   _afwo, न्दि, hrbü, мыйд, 
   {{0x4cb000fe,0x7d08007c,0x00000000,0x00000000}},	//   _জামু, ödsy, --, --, 
   {{0x06e4cf10,0x81d40011,0x00000000,0x00000000}},	//   _омск_, াবন_, --, --, 
   {{0x6364008c,0x63ac0fcf,0x239400de,0xdee81954}},	//   jónu, ćana, _vāja_, ህንን_, 
   {{0x62980100,0x3015f898,0xf6940150,0x00000000}},	//   _efwo, едор, _ﺗﯩﻜﭙ, --, 
   {{0x3cc403d4,0x00000000,0x00000000,0x00000000}},	//   ষভাৱ, --, --, --, 
   {{0xf54801f2,0x00000000,0x00000000,0x00000000}},	//   zụl_, --, --, --, 
   {{0x8230f2ff,0x2efa288f,0x11d4030d,0x00000000}},	//   _لروا, rdsf_, _ціер, --, 
   {{0x1e700220,0x2c740241,0xdcfc002b,0x00000000}},	//   ығыс, _nùdí_, _pipā, --, 
   {{0x21380240,0xe2f40427,0x00000000,0x00000000}},	//   ëshe_, ščeš_, --, --, 
   {{0x91f00c2e,0x3e5800b4,0x7ac4a43c,0x00c401e0}},	//   _अनाज_, ọta_, ксуе, _еләк_, 
   {{0xfb862890,0x63655869,0xadb8143e,0x7e600254}},	// [3f890] тырн, mónt, _عهدا_, ümpt, 
   {{0x5fc41fe7,0x92e8015b,0x612e2891,0xdcfc24cb}},	//   _विमल, মায়_, _kúla, _tipā, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xcaa45706,0x7c280ac7,0x2b4c005a,0x6364007b}},	//   _تصدي, ødre, _ñec_, nónt, 
   {{0xa50a2892,0xf54801f2,0x9f540c6a,0xd00400ec}},	//   зела_, pụl_, égél_, _ڍل_, 
   {{0x67d614d4,0x293400c8,0x6364498d,0x69cc0254}},	//   _погу, _טאָן_, hónt, muae, 
   {{0xf7722893,0x636400c7,0x69cc000d,0x232801a9}},	//   _چاق_, kónt, luae, зойи_, 
   {{0xf770113e,0xe354b7e2,0x69cc0165,0x22140fac}},	//   _ناق_, этлэ, ouae, ефор, 
   {{0xe124410a,0xe73809a5,0x20d401ce,0x63640332}},	//   емпи, _дең_, нінс, dónt, 
   {{0x25ac01c7,0xd64c063f,0xb6cc029f,0x612c02d2}},	//   _iwel_, pọrụ_, _çürü, _búla, 
   {{0x25ac0156,0x69cc0798,0x612c01e7,0xdcfc0356}},	//   _hwel_, huae, _cúla, _lipă, 
   {{0x6fc009fa,0x25ac0af9,0x612c00ae,0x437000cf}},	//   _विरू, _kwel_, _dúla, _جۇعر, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x612c2507,0x69cc0037,0x00000000,0x00000000}},	//   _fúla, duae, --, --, 
   {{0x98b80276,0x1ca403e6,0xdee4020a,0x23940171}},	//   hipă_, وێکی_, _зойи, _mājo_, 
   {{0x6364056a,0x25ac003e,0x28dc28a2,0xa2ac03d4}},	//   cónt, _owel_, न्सि, _গাঁও, 
   {{0x25ac0100,0x69cc00c5,0x98a40124,0x00000000}},	// [3f8a0] _nwel_, guae, еизе, --, 
   {{0x8cd407af,0xc2e800eb,0x00000000,0x00000000}},	//   _बायो, কাটি_, --, --, 
   {{0x25ac70d4,0x9854059f,0xdc68009d,0x636400d7}},	//   _awel_, хташ, _ханд_, nóns, 
   {{0x25ac04ba,0x7bde2894,0x59000327,0x00000000}},	//   _bwel_, mtru, _ཛོམས_, --, 
   {{0x69cc003a,0x28dc15c0,0x00000000,0x00000000}},	//   cuae, न्हि, --, --, 
   {{0xb4040131,0xf4840330,0x7bdc0051,0x00000000}},	//   күзд, پاتی, otru, --, 
   {{0x25ad2ae9,0xcb5c002e,0xe4a402bf,0x63640bcd}},	//   _ewel_, _m茜ng_, тріо, jóns, 
   {{0x7bddf55f,0xe24c0023,0x63640419,0x00000000}},	//   itru, _ዝስምዓ, dóns, --, 
   {{0x28dccad6,0x7bdc02d3,0x612c01f1,0x25ae2895}},	//   न्वि, htru, _súla, _gwel_, 
   {{0x7bdc2451,0x612c00d2,0xb2740124,0xc0380023}},	//   ktru, _púla, нкқә, _ኣሕምል, 
   {{0x7bdc012d,0x3d14078a,0x41700c75,0x00000000}},	//   jtru, दाने_, دايس, --, 
   {{0xcee800c6,0x7bdc0112,0xdb0c12e8,0x81ac0154}},	//   أردن_, dtru, lsbæ, _ওমর_, 
   {{0x3d941d5e,0x636449ab,0x7bdc0064,0x00000000}},	//   лияр, rónt, etru, --, 
   {{0x7bdc4174,0xdb0c00b5,0x612c5923,0x00000000}},	//   ftru, nsbæ, _túla, --, 
   {{0xdef402d3,0x4cb00154,0x7bdd92bb,0x80a40154}},	//   _ጎድኒ_, _জাদু, gtru, _খাচ্, 
   {{0xdcfc0356,0xdb9c0023,0x69ce2896,0x00000000}},	//   _pipă, ሂብዎም_, tuae, --, 
   {{0x7bdc16b8,0xe8f800d8,0x88c400be,0x00000000}},	// [3f8b0] atru, мнач_, فتال, --, 
   {{0x6f0c0306,0xc8b00244,0x7bdc045a,0xdb0c03b2}},	//   _hnac, الاک, btru, rsbá, 
   {{0x25ac62f1,0xdb0c01bf,0x239400b8,0x69cc0254}},	//   _swel_, dsbæ, _rājo_, suae, 
   {{0xdcfc0276,0x81d4009e,0x69cc00c5,0x25ac0100}},	//   _tipă, াবত_, puae, _pwel_, 
   {{0xf7711b58,0x6f0e2897,0x69cc0381,0xdb0c02d2}},	//   حال_, _mnac, quae, fsbæ, 
   {{0x28dc0490,0xc2e80154,0xe24c0023,0x05762898}},	//   न्शि, কাছি_, _ዝስማዓ, راشد, 
   {{0x6f0e2899,0x63ac1050,0x368800d1,0x98b80356}},	//   _onac, ćano, мсән_, sipă_, 
   {{0x25ac002d,0x53300261,0x6f0c009f,0x00000000}},	//   _twel_, иејт, _nnac, --, 
   {{0x65943971,0x25ac0066,0x7bdc0115,0xbf940241}},	//   _разу, _uwel_, ztru, _ìyẹn_, 
   {{0x6f0e289a,0x6364dd18,0x00000000,0x00000000}},	//   _anac, tóns, --, --, 
   {{0x7bde289b,0x9f048688,0xe1f0431a,0x00000000}},	//   xtru, نودو, _چست_, --, 
   {{0x4426289c,0xe1f0009f,0x7bdc01bf,0x00000000}},	//   myn_, _نست_, vtru, --, 
   {{0x4426289d,0x7bdc0309,0x236c0036,0xe13401ee}},	//   lyn_, wtru, mlej_, _инды, 
   {{0x236e289e,0x63640077,0x44241368,0x201004e6}},	//   llej_, póns, oyn_, äzis_, 
   {{0x4426289f,0x6f0c06af,0x7bdc01e3,0xfbac01f9}},	//   nyn_, _fnac, utru, टींम, 
   {{0x2ca470f7,0x6f0c0268,0x442400ad,0x236c0036}},	//   ılda_, _gnac, iyn_, nlej_, 
   {{0xcb641142,0x442402a4,0x7f446ae5,0x256800d2}},	// [3f8c0] тате_, hyn_, _imiq, lúlu_, 
   {{0x98a49db8,0x442628a0,0x7bde28a1,0x778c008e}},	//   тиже, kyn_, ptru, _aşxa, 
   {{0x442628a2,0x236cf74e,0x8cd40034,0x6f0c002d}},	//   jyn_, klej_, _बातो, _ynac, 
   {{0x442628a3,0x013c0023,0xfeb00154,0x8c18011a}},	//   dyn_, _ክጥቀም, _কাঁধ, _חוטי, 
   {{0x44240731,0x63a003ac,0x998400c6,0x236c0036}},	//   eyn_, _atln, _للحو, dlej_, 
   {{0x81d42158,0x442400a9,0x778c0139,0x63740024}},	//   াবা_, fyn_, _eşxa, _išny, 
   {{0x4426289f,0xd37a28a4,0xf2c401c6,0xdb0c01bf}},	//   gyn_, мчи_, гөли, rsbæ, 
   {{0x236c0fb7,0xa7842e0b,0x00000000,0x00000000}},	//   glej_, _مشقو, --, --, 
   {{0x612c0998,0x63640113,0x44241368,0xcb1002e4}},	//   _vúln, gónq, ayn_, שלח_, 
   {{0x6f0e28a5,0x442628a6,0x1048d3a6,0x76440022}},	//   _snac, byn_, дями_, _иҭҵа, 
   {{0x44241000,0x73c40220,0xe2f40010,0x1ab001f9}},	//   cyn_, _сәле, ščaš_, जराथ, 
   {{0x612c032e,0xdb0d15d9,0xa2c00b67,0x40800139}},	//   _húll, nsbä, रृद्, шуыб, 
   {{0x612c0162,0x7e440022,0x6e440023,0x00000000}},	//   _kúll, ахре, _ከንጸባ, --, 
   {{0x7f4559e0,0x91e4037e,0x81f401d9,0x612c032e}},	//   _emiq, _auでp, _شہپر_, _júll, 
   {{0x256801ed,0x69d49f23,0xdb0c01e3,0x09c8a1f3}},	//   múlt_, यूनी, ksbä, ाढ्य, 
   {{0x6f0e28a7,0x9510031c,0x7c280158,0x612c032e}},	//   _unac, _ཉོའི_, ødra, _lúll, 
   {{0x442628a8,0x63a4025a,0xfeb80150,0xdb0c01e3}},	// [3f8d0] zyn_, âhnz, _شايت_, dsbä, 
   {{0xba740220,0x44258177,0xacf4026a,0x3da40801}},	//   شاقت, yyn_, _спољ, _тръб, 
   {{0x6d4628a9,0x00000000,0x00000000,0x00000000}},	//   _imha, --, --, --, 
   {{0x442628aa,0x855401ed,0x659628ab,0xdb0c007c}},	//   vyn_, ھیار_, гаду, gsbä, 
   {{0x442628ac,0x4b400014,0x612c02d2,0x25680419}},	//   wyn_, _مٹھہ, _búll, kúlt_, 
   {{0x442628ad,0x2b4a28ae,0x22141efd,0x6d580248}},	//   tyn_, liac_, ғфир, _ìwad, 
   {{0xe29a28af,0x29dc0bdf,0x236e28b0,0xd46628b1}},	//   най_, lìa_, tlej_, лише_, 
   {{0x4426289f,0xe1f8287a,0xe858022e,0x00000000}},	//   ryn_, еги_, _жаҳш_, --, 
   {{0x442628b2,0x29dc0268,0x612c02d2,0x236c00ef}},	//   syn_, nìa_, _fúll, rlej_, 
   {{0x236d99ea,0x442628b3,0xdb0c0fac,0x612c08ce}},	//   slej_, pyn_, msbå, _gúll, 
   {{0x9f8628b4,0xe0457881,0x349433b0,0xdb0c2142}},	//   лгод, унни, _тахр, lsbå, 
   {{0x6d4628b5,0x2b48009f,0x2294abf9,0x947000ec}},	//   _amha, jiac_, _сидя, _اگها, 
   {{0x2b4a28b6,0x2d4c05be,0x29dc026c,0xdb0c2b96}},	//   diac_, džeb_, jìa_, nsbå, 
   {{0x10a000c9,0x29dc0268,0x00000000,0x00000000}},	//   _лишн, dìa_, --, --, 
   {{0x2b4805d5,0x92d40183,0xfb8407d6,0x00000000}},	//   fiac_, াজৰ_, لدری, --, 
   {{0x6d4407a9,0xcb6628b7,0x29dc026c,0xdb0c0158}},	//   _emha, гасе_, fìa_, ksbå, 
   {{0x29dc026c,0x6ee40131,0x699400c7,0xc95401b9}},	// [3f8e0] gìa_, _ئسىل, архх, گللش_, 
   {{0x63ac04b9,0xdb0c3bb0,0x00000000,0x00000000}},	//   ćanj, dsbå, --, --, 
   {{0x09e001b9,0xb8dc6ea8,0xdb0c26bc,0x612c01a8}},	//   _қорн, _इज_, tsbä, _rúll, 
   {{0x2b4a1d71,0xe7c801f9,0x00000000,0x00000000}},	//   ciac_, ांजप, --, --, 
   {{0x29dc0268,0xdb0c0267,0x612c02d2,0x4a400064}},	//   cìa_, rsbä, _púll, _гняв, 
   {{0x7ae628b8,0xd94400f7,0x860401d5,0x3b0001a9}},	//   lfit, _сеги, اقوق_, ldiq_, 
   {{0x53e40323,0x612c0998,0x07a0188b,0x7ae628b9}},	//   уцла, _cúlm, _гасн, ofit, 
   {{0x43640cfc,0xfbac2208,0x3b0001a9,0x25c803e0}},	//   лајн_, टीएम, ndiq_, ütlü_, 
   {{0x14d418a2,0x91482bba,0xc7940588,0x877808a8}},	//   _مزاح, ечна_, _арӡы, _טאלי, 
   {{0x3ea00204,0x00000000,0x00000000,0x00000000}},	//   _afit_, --, --, --, 
   {{0x049006d5,0x12e40046,0x29dc0268,0xf2c40075}},	//   _المح, _білг, zìa_, _көпи, 
   {{0x5fc42802,0xe3b000e5,0x8cd40950,0xc7d4011a}},	//   _विरल, _گرے_, _बाहो, נוכי_, 
   {{0x3b013fc2,0x3ea0a477,0x2b480030,0x70140154}},	//   ddiq_, _dfit_, viac_, ানেও_, 
   {{0x4ba40228,0x7ae40109,0x29dc026c,0xf0e800cf}},	//   лөмү_, efit, vìa_, _شىعى_, 
   {{0x92b402f5,0x7ae628ba,0x3ea0015d,0x2b4a28bb}},	//   জলী_, ffit, _ffit_, tiac_, 
   {{0x81d40154,0xafe401af,0x00000000,0x00000000}},	//   াবর_, _боҫл, --, --, 
   {{0x2b4a1c4a,0x4ea400c7,0x1dc001c6,0x98b800c0}},	// [3f8f0] riac_, _ирҿа, _мөрн, lipę_, 
   {{0x2b4801a2,0x29dc08e5,0x61fc0194,0x8274010f}},	//   siac_, rìa_, æsli, רעמע_, 
   {{0x63ac2375,0x29dc026c,0x2b4a28bc,0x00000000}},	//   ćank, sìa_, piac_, --, 
   {{0x14d005dc,0xd364007b,0xdb0c007c,0x00000000}},	//   _साउण, _ذه_, tsbå, --, 
   {{0x6aae28bd,0x49913fba,0x5ec000cc,0x6d5402d0}},	//   mbaf, _طیار, ষ্কে, onza, 
   {{0x69cc0f7b,0xc7b6017a,0x6d543c53,0xdb0c2b96}},	//   mrae, _مصرع, nnza, rsbå, 
   {{0xc291767d,0xc6a414b7,0x6d5628be,0xdb0c05ac}},	//   میاب, _брзи, inza, ssbå, 
   {{0xa1c4267c,0xc79401e0,0x29000327,0x00000000}},	//   абид, _арҡы, ldha_, --, 
   {{0xd24c168d,0x651411c7,0x290228bf,0x6d54009a}},	//   وچه_, _پوائ, odha_, knza, 
   {{0x290228c0,0x6008ace6,0x660a28c1,0x2ee8030a}},	//   ndha_, вном_, _irek, _abaf_, 
   {{0xa2f43804,0x69ce28c2,0x290036b7,0x20540474}},	//   _впеч, hrae, idha_, ртпр, 
   {{0x660a28c3,0x6d5628c4,0x61f802b9,0x7eb001e1}},	//   _krek, enza, _tswl, _bẹẹk, 
   {{0x69cc0399,0x29101e0b,0x2900020c,0x21748388}},	//   jrae, _onza_, kdha_, _кукр, 
   {{0x69ce28c5,0x6609f414,0xa0a4cc5a,0x7204004b}},	//   drae, _mrek, _такд, _دوهم, 
   {{0x290228c6,0x8cd402ab,0xdb0c1d0e,0x00000000}},	//   ddha_, _बारो, msbú, --, 
   {{0x66080588,0x6d55911a,0x291228c7,0x3ea000ca}},	//   _orek, anza, _anza_, _ufit_, 
   {{0x69cc0007,0x7ae628c8,0x3b0001b9,0x66080241}},	// [3f900] grae, rfit, rdiq_, _nrek, 
   {{0x3b0003be,0x6aac04ba,0x97c4007b,0xdb0c03b2}},	//   sdiq_, abaf, لتصم, nsbú, 
   {{0x98a80276,0xf6a400c7,0x3b0006be,0x00000000}},	//   _albă_, булҟ, pdiq_, --, 
   {{0x29101449,0x69ce28c9,0x660a28ca,0x290228cb}},	//   _enza_, brae, _brek, adha_, 
   {{0x958416a8,0x395a28cc,0x69cc0393,0x588401e0}},	//   алде, _tjrs_, crae, уыҡа, 
   {{0x660a28cd,0xa4100139,0x00000000,0x00000000}},	//   _drek, _añıñ_, --, --, 
   {{0x44f00014,0x779400e5,0x80cc000d,0x00000000}},	//   زسوز, _ایصا, _दाजे, --, 
   {{0x660a28ce,0x81c00171,0x00000000,0x00000000}},	//   _frek, _ķērp, --, --, 
   {{0x660a28cf,0x8cd48bb5,0xc1b42401,0x427c0092}},	//   _grek, _बालो, алых_, _የታክስ_, 
   {{0xdb0e28d0,0x3134084c,0xf4b00055,0x00000000}},	//   tsbû, сеор, _kuṭī_, --, 
   {{0x66085188,0x69ce28d1,0x03a000d8,0x88b8011a}},	//   _zrek, zrae, _дихо, כזיי, 
   {{0x91e41b10,0xdb0c002d,0x660800e4,0xad240145}},	//   _воде, rsbû, _yrek, ڭىسى, 
   {{0x69cc0007,0x290228d2,0x239400b8,0x00000000}},	//   xrae, ydha_, _rāji_, --, 
   {{0x6d5407c5,0x69ce28d3,0x7f9c01ec,0xc5f0011a}},	//   unza, vrae, _ﺍﻟﯩﺲ_, חדש_, 
   {{0x69cc0369,0x6d5401f5,0xe16401f7,0x0134011a}},	//   wrae, rnza, _ادني, _דרגת_, 
   {{0x4ea410f3,0x6d54009f,0x00000000,0x00000000}},	//   _трка, snza, --, --, 
   {{0x63ac1b24,0x6aac208d,0x7f847da6,0x2394411e}},	// [3f910] ćani, rbaf, _بلين, _vāji_, 
   {{0x69ce28d4,0x66088ad5,0x29000a55,0x39142cdd}},	//   rrae, _rrek, udha_, омур, 
   {{0x69ce28d5,0x290228d6,0x398c01e1,0x00000000}},	//   srae, rdha_, _sósì_, --, 
   {{0x660813aa,0x69ce28d7,0x67380369,0x7c280267}},	//   _prek, prae, uhwj, ädre, 
   {{0x6605b16d,0x64a57a24,0xf65011fc,0x69cc0399}},	//   спла, бала, وئه_, qrae, 
   {{0x29100099,0x66080ea0,0x754400d4,0x00000000}},	//   _unza_, _vrek, оніз, --, 
   {{0x21681f71,0x237c0218,0x6608f5a3,0x92b400fe}},	//   ғини_, _phwj_, _wrek, জলৈ_, 
   {{0x660a28d8,0x612e28d9,0x00000000,0x00000000}},	//   _trek, _túlk, --, --, 
   {{0x660a28da,0x612c01b8,0x130400c9,0xe1f000c6}},	//   _urek, _húli, сный_, سسة_, 
   {{0x612ca746,0x041c0154,0x438801ec,0xe0dc00cc}},	//   _kúli, বনবী_, _ﺗﯟﯨﻦ_, _ভোজভ, 
   {{0x612c00dd,0x237c0070,0x1f64d31e,0x92b400cc}},	//   _júli, _thwj_, йком, _জাৰ_, 
   {{0x22940491,0x612c01d3,0xdb0c0162,0x00000000}},	//   _الإس, _múli, ssbú, --, 
   {{0xdb0c0ac8,0x3d1400bc,0xb3e40139,0x00000000}},	//   msbø, दाले_, _çοrı, --, 
   {{0xa0094cc3,0xdb0c12e8,0x1d080114,0x00000000}},	//   _مقتل_, lsbø, ћеви_, --, 
   {{0x612c03f2,0x6bd40451,0x00000000,0x00000000}},	//   _núli, يڪٽر, --, --, 
   {{0xdb0c5522,0x00000000,0x00000000,0x00000000}},	//   nsbø, --, --, --, 
   {{0x0ea400fd,0x82e80327,0x4b0803d4,0x00000000}},	// [3f920] _укый_, _ཡིནའ, ৰসংগ_, --, 
   {{0x3bf800e8,0x97bc02dd,0x2d4c0219,0xf4b00055}},	//   _tōq_, ердi, lžen_, _puṭī_, 
   {{0x239400e2,0x3f800051,0xca7c01d5,0x2e2c02d2}},	//   _kāju_, _khiu_, shqа, _tófú_, 
   {{0x612c03b2,0x2d4c0427,0x00000000,0x00000000}},	//   _dúli, nžen_, --, --, 
   {{0x2394005f,0x6900005b,0xdb0c21e3,0x4ab00139}},	//   _māju_, öydä, dsbø, _хөср, 
   {{0x3f80062c,0x612c02d2,0x18680108,0x00000000}},	//   _lhiu_, _fúli, _баги_, --, 
   {{0xccf0011a,0x00000000,0x00000000,0x00000000}},	//   פכה_, --, --, --, 
   {{0x3f8001fb,0x8c18008f,0xdb0c6a47,0x00000000}},	//   _nhiu_, טוצי, gsbø, --, 
   {{0x940628db,0x00000000,0x00000000,0x00000000}},	//   _گواه, --, --, --, 
   {{0x25700150,0x629c0165,0x863408c3,0x00000000}},	//   _قۇنس, ñsor, _הרמב_, --, 
   {{0x5ea800bd,0x612c00d2,0x95c8c7e0,0x28dc97ad}},	//   _কয়ে, _lúlw, _шуңа_, न्टि, 
   {{0x3f8228dc,0x00000000,0x00000000,0x00000000}},	//   _chiu_, --, --, --, 
   {{0x518628dd,0x3f800e89,0xe2a80345,0x87780677}},	//   _лука, _dhiu_, _ئامن_, טאטי, 
   {{0x9e640131,0xab940640,0x64500241,0x0dc807a5}},	//   تاپن, жављ, _ìkiú, куҳи_, 
   {{0x3f8000a3,0x7c341d83,0x2bd80073,0x4914012c}},	//   _fhiu_, перх, बंधा, नासो_, 
   {{0xccc401e0,0x239400de,0x79900150,0x2dd4011c}},	//   шғүл_, _gāju_, _ﺒﺎﺭﻉ_, _джир, 
   {{0xce30104c,0x2ec401f9,0x00000000,0x00000000}},	// [3f930] _رودک, वणीत, --, --, 
   {{0x270401fb,0x4be4004e,0x15e00150,0x3f800064}},	//   _ồn_, _люмб, _ﺍﺴﺘﺩ, _zhiu_, 
   {{0xaa94bdd4,0xac18d080,0xe69800d8,0x00000000}},	//   _минч, _тону_, авеш_, --, 
   {{0x1e0401d9,0x28dc09ab,0x0a6800fb,0xe1480240}},	//   _آیہ, न्जि, _брги_, _ብወንጌ, 
   {{0x24f801e0,0x57c00116,0xd76405a9,0x00000000}},	//   инды_, ﺯﮔﯩﺮ, زەكى_, --, 
   {{0xa5087696,0x00000000,0x00000000,0x00000000}},	//   река_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xe298013e,0x23280107,0x77540902,0x970000d1}},	//   шаи_, роии_, _ексф, _يېلى, 
   {{0x612c01ed,0xf1a803e6,0x57200137,0xdb0c5f03}},	//   _múlv, یایه_, _تۉنك, rsbø, 
   {{0x3f800731,0xdb0c0158,0x22480171,0x00000000}},	//   _shiu_, ssbø, _žaks_, --, 
   {{0x245628de,0x3f80f01e,0x79800221,0x04740244}},	//   _بناس, _phiu_, _ëmwe, _الاک_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x5fc43156,0xdca4023b,0x23940171,0xa1581606}},	//   _विकल, жаги, _vāju_, _каду_, 
   {{0x3f8004fe,0xdbd400fd,0x00000000,0x00000000}},	//   _whiu_, _täüg, --, --, 
   {{0xd11400e1,0x5fc000db,0x3f80da31,0x28dc00bc}},	//   तारण_, _تەجۅ, _thiu_, न्छि, 
   {{0x6e2c00ae,0x00000000,0x00000000,0x00000000}},	//   íobá, --, --, --, 
   {{0x9b240882,0x09e16c15,0x81d40011,0x6ee401f7}},	// [3f940] ṣṭān, мотн, াবক_, _رسيل, 
   {{0x2d4c0122,0xd64c01f2,0x183414fe,0x7f8400ec}},	//   nžel_, lọgụ_, يراح, _بلڊن, 
   {{0x2bd802ab,0x3e84020c,0x7d2800f1,0xbd4400ec}},	//   बूदा, bèté_, _نيکې_, _ونڊي, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc5ec00aa,0x612c0321,0x9560001f,0x93a41171}},	//   کړې_, _kúlu, _ሴቶችን_, ошид, 
   {{0x338400b8,0xdbd40139,0x00000000,0x00000000}},	//   _aṭṭa, _käñg, --, --, 
   {{0x78be28df,0xd6d80214,0xa9c402f2,0x00000000}},	//   _herv, _خورش_, _بزێو, --, 
   {{0x78be28e0,0xdbd400fd,0x3cf803b2,0x06e00154}},	//   _kerv, _mäñg, kerv_, _নোকি, 
   {{0x78bc0b1e,0xe7d00aff,0xd61400ec,0x00000000}},	//   _jerv, _हिमप, _هڪڙا_, --, 
   {{0x78be28e1,0x636400d2,0x3cf80156,0x8898011a}},	//   _merv, hóny, derv_, יביי, 
   {{0x752a28e2,0x78bc669e,0x00000000,0x00000000}},	//   _hodz, _lerv, --, --, 
   {{0x752805b8,0x10e46c48,0x78bc017a,0x0320010b}},	//   _kodz, _дюйм, _oerv, _юдцн, 
   {{0x8f440882,0x23681a48,0x2fc4010b,0x22480432}},	//   dṛśa, čaje_, _ериң, _ýaka_, 
   {{0x75284568,0x00000000,0x00000000,0x00000000}},	//   _modz, --, --, --, 
   {{0x752a28e3,0x31a002bd,0x78be28e4,0x7c280267}},	//   _lodz, _kòz_, _aerv, ädra, 
   {{0x88c40202,0x78be28e5,0x31a0007f,0x3e840066}},	// [3f950] قتال, _berv, _jòz_, rèté_, 
   {{0x48a89919,0x75298c96,0x0ed8012c,0x612c02d2}},	//   ртам_, _nodz, _भाँड, _fúlu, 
   {{0x2138036e,0xe2f40427,0xdb0c03b2,0x00000000}},	//   ëshi_, ščiš_, lsbý, --, 
   {{0x78bc0d47,0xf7480b24,0x00000000,0x00000000}},	//   _eerv, يللي_, --, --, 
   {{0x78bd9294,0x752a28e6,0xa3dc0490,0xe9440214}},	//   _ferv, _bodz, थून_, _فرآی, 
   {{0x78be28e7,0x2904025a,0x64a628e8,0x75280034}},	//   _gerv, _ûla_, чака, _codz, 
   {{0x0ed80574,0x6abc0205,0xdbd40139,0x752a28e9}},	//   _भांड, _kesf, _yäñg, _dodz, 
   {{0x3cf82035,0x31a00100,0xbfa001fb,0xfc5c0375}},	//   zerv_, _bòz_, _diễ, יכומ, 
   {{0xda0c02e5,0x4cd011ba,0x6abe28ea,0x78bc0477}},	//   सियत_, দ্যু, _mesf, _yerv, 
   {{0x7528006d,0x31a002e2,0x6728005c,0x5560313e}},	//   _godz, _dòz_, _hoej, _كۇنك, 
   {{0x63ac1711,0x3cf82d75,0x22943868,0x6728017a}},	//   ćans, verv_, _فلاس, _koej, 
   {{0x752a28eb,0xd64c063f,0x6abe26f9,0x26dc02e3}},	//   _zodz, bọdụ_, _nesf, ngwo_, 
   {{0x3cfa28ec,0x752802ce,0x672800b5,0x612c041e}},	//   terv_, _yodz, _moej, _súlu, 
   {{0x612c007b,0x00000000,0x00000000,0x00000000}},	//   _cúlt, --, --, --, 
   {{0x60c228ed,0x78bc003a,0x6abc0200,0x00000000}},	//   malm, _rerv, _besf, --, 
   {{0x3cfa28ee,0x6abc3040,0x2f5407d8,0x8b2001f4}},	//   serv_, _cesf, _отыс, ндсе, 
   {{0x6abd7b0c,0x78be28ef,0xd1bc001f,0xd38400b8}},	// [3f960] _desf, _perv, _ሰጥቶ_, _jṛṃb, 
   {{0x6abc127b,0xdb0c002f,0xa2f80b4c,0x00000000}},	//   _eesf, lsbü, ्युज_, --, 
   {{0x78bc400c,0x7528006d,0x6abc1509,0x67280770}},	//   _verv, _rodz, _fesf, _boej, 
   {{0x60c228f0,0x78bc0196,0x8f98008d,0x629802e3}},	//   halm, _werv, ציני, _ngwo, 
   {{0x78be28f1,0x752a28f2,0x60c0066d,0x2d4c804c}},	//   _terv, _podz, kalm, džej_, 
   {{0x3ae8066d,0x629a28f3,0x60c228f4,0x26dc0083}},	//   _ابھی_, _agwo, jalm, agwo_, 
   {{0x60c000dd,0x7528004c,0xd64c01f2,0xd0a001e1}},	//   dalm, _vodz, wọdụ_, _mẹtẹ, 
   {{0x752a28f5,0x6728002d,0x6abc004e,0x31a0033b}},	//   _wodz, _goej, _xesf, _pòz_, 
   {{0x60c076ed,0x752a28f6,0xe50400ec,0x00000000}},	//   falm, _todz, _ڊبلي, --, 
   {{0x60c228f7,0xb03500ed,0x6728007c,0xbfa00051}},	//   galm, днош, _zoej, _tiễ, 
   {{0x06e000bd,0x6728020b,0xc0543334,0x31a0007f}},	//   _নোটি, _yoej, зія_, _wòz_, 
   {{0x0ea42232,0x62980083,0x60c000af,0x08540375}},	//   कुंड, _ggwo, aalm, לבים_, 
   {{0x83880014,0x6abc8603,0x612c0332,0x8d84010b}},	//   _اصلہ_, _resf, _cúls, зувд, 
   {{0x60c228f8,0xe6b9193c,0x6abd91d1,0x5fc417ee}},	//   calm, _उज्ज, _sesf, _विचल, 
   {{0x7e6628f9,0x6abc037e,0xcfa400fd,0x2d4ccf17}},	//   _exip, _pesf, _эшли, lžek_, 
   {{0x612c02d2,0x50a000d1,0x0a680798,0x00000000}},	//   _fúls, _تەھل, брзи_, --, 
   {{0x433800c8,0x20300092,0x612c00e5,0x00000000}},	// [3f970] צעמב, _ይመሰክ, _túlt, --, 
   {{0x6728020b,0x6abc017a,0x8cd4012c,0xad840137}},	//   _soej, _wesf, _बाटो, _تابۇ, 
   {{0x6abc022f,0xdb0c148b,0x00000000,0x00000000}},	//   _tesf, gsbó, --, --, 
   {{0xf77228fa,0xd0043837,0x60c228fb,0x7fd40375}},	//   هان_, _یل_, zalm, לובס_, 
   {{0x60c01529,0x556001f2,0xdaa007d2,0xbb5801c6}},	//   yalm, wụọl, _شەلپ, _хаях_, 
   {{0x1cd00327,0x00000000,0x00000000,0x00000000}},	//   ུུག_, --, --, --, 
   {{0x60c228fc,0x67284bf0,0x798001c7,0x7940010e}},	//   valm, _toej, _ëmwa, _döwd, 
   {{0x95340ce8,0x60c00135,0x00000000,0x00000000}},	//   ззәт_, walm, --, --, 
   {{0x26ce28fd,0x2d4c0427,0x20d4e6c3,0xe0d8003b}},	//   _ideo_, ržej_, мінс, овп_, 
   {{0xe12402bf,0x25ac0474,0x79400432,0x63680139}},	//   ємни, _itel_, _göwd, _sönğ, 
   {{0xf7704ff6,0x4ce0009e,0xdb0c0112,0x629c01e4}},	//   _شاہ_, য়াঁ, tsbü, ɾson, 
   {{0xd24c34c9,0x60c228fe,0x612d0ca1,0x98a80118}},	//   انی_, salm, _cúlr, _blbě_, 
   {{0x794000ee,0x612c007b,0xd0a00241,0x6d1817ee}},	//   _höwe, _dúlr, _pẹtẹ, दांग_, 
   {{0x61ea28ff,0x25ac05be,0xdd900451,0x7940010e}},	//   mtel, _mtel_, ئوس_, _köwe, 
   {{0x82e80135,0x26cc01c4,0x93940205,0x2bd80950}},	//   _རྡོའ, _odeo_, _üşür, बूला, 
   {{0x25ae2900,0x61ea2901,0xd0a00248,0x7940324c}},	//   _otel_, otel, _fẹsẹ, _möwe, 
   {{0x82100156,0xda662902,0x4e000124,0x794008d5}},	// [3f980] ིཀྲི_, ذاري, _азыб, _löwe, 
   {{0x26cc0483,0x61ea2903,0xdb0c0413,0x00000000}},	//   _adeo_, itel, tsbó, --, 
   {{0x61e80d77,0x25ac04cc,0xd708034b,0xd0a001e1}},	//   htel, _atel_, жнее_, _kẹrẹ, 
   {{0x7bde2904,0x79400209,0x65b000c7,0x4cd00154}},	//   muru, _söwd, _ẽhar, দ্দু, 
   {{0x7bdc4237,0x82e80003,0xdb0c03b2,0x61e9cc6e}},	//   luru, _རྡེའ, ssbó, jtel, 
   {{0x7940010b,0x44f01456,0x5dc80220,0x00000000}},	//   _böwe, نسىز, _ﺑﻪﻟﺴ, --, 
   {{0x7bdc5088,0x61ea2905,0xf314010b,0x8cd4012d}},	//   nuru, etel, едйэ, _बाघो, 
   {{0x7bdc0086,0x79400432,0xa3c000e1,0x07a000d8}},	//   iuru, _döwe, _्टर_, _јатн, 
   {{0x7bde2906,0x61ea2907,0x2d4c00bc,0x660c713c}},	//   huru, gtel, užek_, åakt, 
   {{0x7bdc8a22,0x2d9c0036,0x3878032e,0xb2740022}},	//   kuru, _éwei_, _kyrr_, мкқә, 
   {{0x7bde2908,0x61ea2909,0x98b80418,0x7940010e}},	//   juru, atel, lipē_, _göwe, 
   {{0x7bde290a,0x38780142,0x61e83922,0x2d4c0064}},	//   duru, _myrr_, btel, mžei_, 
   {{0x61e800a8,0xb640019b,0x7de402dd,0xb630037e}},	//   ctel, _ｍｌ_, кірд, _ｐｓ_, 
   {{0xdc3803e0,0xc278011a,0xad241456,0x00000000}},	//   _açım, _ורדי, رىزى, --, 
   {{0x7bdd6dd9,0xd0a00241,0x3d140073,0xc04c155b}},	//   guru, _fẹrẹ, दाजे_, _рі_, 
   {{0xd0a001e1,0x00000000,0x00000000,0x00000000}},	//   _tẹsẹ, --, --, --, 
   {{0x0db87935,0x7bdc0254,0x00000000,0x00000000}},	// [3f990] _باعث_, auru, --, --, 
   {{0x7bde290b,0xbdf811e6,0x00000000,0x00000000}},	//   buru, _آريا_, --, --, 
   {{0x7bde290c,0x25ae290d,0x61ea290e,0xfe700424}},	//   curu, _stel_, ztel, _مدی_, 
   {{0x61ea290f,0xf4240154,0xdc34010f,0x00000000}},	//   ytel, বনার_, _נארט_, --, 
   {{0x6b8e2910,0xd2440491,0x79400209,0x61e94141}},	//   mmag, _إن_, _söwe, xtel, 
   {{0x6b8d3c42,0x387826b8,0x61e83df9,0x00000000}},	//   lmag, _fyrr_, vtel, --, 
   {{0x82e8031c,0x6b8c0e89,0x61e9aaf0,0x00000000}},	//   _རྡུའ, omag, wtel, --, 
   {{0x61ea2911,0x6b8c785b,0x6d54c8a0,0x25ae2912}},	//   ttel, nmag, hiza, _ttel_, 
   {{0x6d562913,0x61ea2914,0x6b8e2915,0x7bde2916}},	//   kiza, utel, imag, zuru, 
   {{0x7bde2917,0x6b8e2918,0x79400209,0x6d54ff82}},	//   yuru, hmag, _töwe, jiza, 
   {{0x61ea2919,0x6b8e291a,0x68e001a8,0x41bc01ad}},	//   stel, kmag, _öldu, _शौरस, 
   {{0x61ea291b,0x7bde291c,0x6305b8a6,0x00000000}},	//   ptel, vuru, _سوتل, --, 
   {{0x6b8c00b8,0x7bde291d,0x2010010f,0x00000000}},	//   dmag, wuru, ŭzi_, --, 
   {{0x7bde291e,0x6b8c3a11,0x63a2291f,0x612c02d2}},	//   turu, emag, _kuln, _gúlp, 
   {{0xd00c4b13,0x6b8c0008,0x63a0007c,0x00cc0220}},	//   _هلو_, fmag, _juln, _ﻛﯘﺷﺘ, 
   {{0x6b8e2920,0x2f540108,0x8f9800d9,0xcff4011a}},	//   gmag, _атьс, _ציפי, _נצפה_, 
   {{0xdca40556,0x598406bd,0x256800e5,0x00000000}},	// [3f9a0] _папи, елаб, súly_, --, 
   {{0x7bde2921,0x6d562922,0x186800a7,0x3ba412d7}},	//   puru, ciza, пази_, _илоҳ, 
   {{0x6b8e2923,0x00000000,0x00000000,0x00000000}},	//   bmag, --, --, --, 
   {{0x6b8c07de,0xd6d00127,0x8bd4011a,0x00000000}},	//   cmag, اقش_, _אוטו_, --, 
   {{0x63a0004a,0x3bf000ab,0x2f48010f,0x00000000}},	//   _auln, _चहुँ_, וראָ_, --, 
   {{0x63a001ab,0x6b640153,0x00000000,0x00000000}},	//   _buln, mėga, --, --, 
   {{0x63a0020c,0x23680010,0xe4f0000d,0x896000d8}},	//   _culn, čajn_, _आउरि_, _скрж, 
   {{0x6d552e9b,0x63a22924,0x634800f1,0x2904032e}},	//   ziza, _duln, وړنې_, _ólar_, 
   {{0x6d562925,0x612c24c8,0x00000000,0x00000000}},	//   yiza, _púlp, --, --, 
   {{0x69d81ebd,0x6b8e2926,0x63a04145,0x6d540077}},	//   šweg, zmag, _fuln, xiza, 
   {{0x6b8e2927,0x63a22928,0xd3340153,0x00000000}},	//   ymag, _guln, _пэды, --, 
   {{0x6d5480c1,0x00000000,0x00000000,0x00000000}},	//   wiza, --, --, --, 
   {{0x6d544af6,0x82309448,0x82e8031c,0x6b8cb1ab}},	//   tiza, _مروا, _རྡིའ, vmag, 
   {{0x2c0c0490,0xc908015b,0x4638008f,0x63a0008e}},	//   हिलं_, _শক্ত_, לעכע, _yuln, 
   {{0x6b8e2929,0x00000000,0x00000000,0x00000000}},	//   tmag, --, --, --, 
   {{0x6b8e292a,0xcf24004b,0xef1000db,0x00000000}},	//   umag, _سربي, _түмө, --, 
   {{0x6b8e292b,0xeb9809a5,0xd0a001e1,0x00000000}},	// [3f9b0] rmag, зиң_, _yẹpẹ, --, 
   {{0x6d5401f0,0x0ae8438b,0xc7c4010b,0xdd92292c}},	//   qiza, _کردي_, есди, _پوپ_, 
   {{0x6b8e292d,0x69d42e05,0x00000000,0x00000000}},	//   pmag, यूजी, --, --, 
   {{0xf8688b4d,0x6b8c01b9,0x6b6400c0,0x00000000}},	//   رمني_, qmag, bėga, --, 
   {{0xa5089fb7,0x660401f4,0xb4640150,0x00000000}},	//   дела_, тпла, ңкіл, --, 
   {{0x63a001b9,0xaae02d8f,0x28a802c3,0x00000000}},	//   _puln, _फाँक, _च्चि, --, 
   {{0x63a01bc1,0xd0a001e1,0x2328024c,0xe75800d4}},	//   _quln, _rẹpẹ, дойи_, _живі_, 
   {{0x23680fb7,0x67047347,0xf79400c0,0xb7942dd0}},	//   čajo_, _रसिक_, _басэ, _مؤقت, 
   {{0x1306292e,0x00000000,0x00000000,0x00000000}},	//   тный_, --, --, --, 
   {{0x63a000af,0x794000b0,0x0ce0009e,0x00000000}},	//   _tuln, _köwa, য়ুত, --, 
   {{0x63a016b8,0xaae000e1,0x8ff800ec,0xdb0c3bba}},	//   _uuln, _फांक, ورٽر_, msbö, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xd1e401ec,0x00000000,0x00000000,0x00000000}},	//   _لينۋ, --, --, --, 
   {{0xdcb01b56,0x3afc004d,0xdb0c44b3,0x10a074df}},	//   شىر_, _ập_, nsbö, _кишн, 
   {{0x396401f0,0x00000000,0x00000000,0x00000000}},	//   ҳнаҳ, --, --, --, 
   {{0xfb8401b9,0x00000000,0x00000000,0x00000000}},	//   ادسی, --, --, --, 
   {{0x9e6400d6,0x3ea00036,0x1cd00327,0xdcec0010}},	// [3f9c0] _швид, _igit_, ུུད_, lobč, 
   {{0xf1d40406,0x00000000,0x00000000,0x00000000}},	//   _दिसन, --, --, --, 
   {{0x2bc001f9,0x00000000,0x00000000,0x00000000}},	//   षीदा, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7ae40280,0x00000000,0x00000000,0x00000000}},	//   mgit, --, --, --, 
   {{0x7ae4007d,0xcdb40302,0xdb0cf17d,0x92a40210}},	//   lgit, דפסה_, gsbö, zełę, 
   {{0x03c00220,0x741405af,0xdcec0010,0xf1d400c5}},	//   асым, اوبا, jobč, _दिहन, 
   {{0xd5b06ee9,0x799e292f,0x3ea00295,0x7ae44d57}},	//   _نفر_, _hirw, _ngit_, ngit, 
   {{0x799c0230,0x7ae4010f,0x00000000,0x00000000}},	//   _kirw, igit, --, --, 
   {{0x3ea22930,0x799c0198,0x3b000399,0x7ae40194}},	//   _agit_, _jirw, heiq_, hgit, 
   {{0x3dc00227,0x799c01b2,0xdcec0427,0xc950011a}},	//   _awiw_, _mirw, gobč, שמת_, 
   {{0x799c6922,0x00000000,0x00000000,0x00000000}},	//   _lirw, --, --, --, 
   {{0x7e24f703,0x3b000226,0x7ae4020c,0x9149b8ec}},	//   لَّه, deiq_, dgit, _очка_, 
   {{0x799e2931,0xd6b8045e,0x0fe0425b,0x3ea016b8}},	//   _nirw, ুলিয, _көмү, _egit_, 
   {{0x2d4c597f,0x3b000369,0xead488d6,0x7ae40065}},	//   džet_, feiq_, ловь, fgit, 
   {{0x799c5337,0x3dc0045a,0x794000a2,0x0ce00154}},	//   _airw, _fwiw_, _röwa, য়েত, 
   {{0x3dc0015d,0x6a140961,0x00000000,0x00000000}},	// [3f9d0] _gwiw_, ымау, --, --, 
   {{0x7ae62932,0x6f0e2933,0xe89400fd,0x19280023}},	//   agit, _haac, газь, _ተማሂሮ, 
   {{0x799e2934,0x3b000007,0x6f0d6cf2,0x36b001f2}},	//   _dirw, beiq_, _kaac, _ịnọk, 
   {{0x6f0d132f,0xd64c01f2,0x799c115d,0xa88400db}},	//   _jaac, rọnụ_, _eirw, _ەلسى, 
   {{0x6f0e2935,0x799c04c4,0x6b9c009a,0x0a6807b5}},	//   _maac, _firw, _iisg, _црни_, 
   {{0x6b9e2936,0x69ce2937,0x6f0e2938,0x799c8048}},	//   _hisg, msae, _laac, _girw, 
   {{0x29022939,0xd3440ec9,0xd73401c0,0x6b9c01ed}},	//   meha_, گینه_, _өдрө, _kisg, 
   {{0x2900052f,0x6aae293a,0x799c6466,0x6b9c031c}},	//   leha_, ncaf, _zirw, _jisg, 
   {{0x6b9e293b,0x290001ee,0x799c0223,0x69ce293c}},	//   _misg, oeha_, _yirw, nsae, 
   {{0x66080944,0x2902293d,0x68e40097,0x69cc0810}},	//   _isek, neha_, nghd, isae, 
   {{0x68e4379c,0x6f0d8848,0x6b640024,0xf408007b}},	//   ighd, _baac, jėgo, _ليلى_, 
   {{0xe1f00502,0x69ce293e,0x6f0e293f,0x6b9e2940}},	//   _هست_, ksae, _caac, _nisg, 
   {{0x29022941,0x6f0e2942,0x69cc0399,0x3b000007}},	//   keha_, _daac, jsae, veiq_, 
   {{0x29001711,0x6b9c07f0,0x69cc0399,0x66083f5d}},	//   jeha_, _aisg, dsae, _msek, 
   {{0x6b9e2943,0x29000170,0x799caaa6,0x2ee8004e}},	//   _bisg, deha_, _rirw, _fcaf_, 
   {{0x660a2944,0x6b9c011c,0x27e22945,0x3ea03217}},	//   _osek, _cisg, duhn_, _ugit_, 
   {{0x799c5d55,0x660a2946,0x69cc0399,0x7f454e17}},	// [3f9e0] _pirw, _nsek, gsae, _iliq, 
   {{0x7ae40209,0x2900e7e0,0x08c0010b,0x6b9c002f}},	//   sgit, geha_, йбун, _eisg, 
   {{0x660a2947,0x799c0a40,0x7ae62948,0x6b9c0798}},	//   _asek, _virw, pgit, _fisg, 
   {{0x69cd7814,0x6aae2949,0x6b9c00e8,0x79400209}},	//   bsae, ccaf, _gisg, _göwn, 
   {{0x6609d1e1,0x799e294a,0x290001e0,0x998403af}},	//   _csek, _tirw, beha_, _ملحو, 
   {{0x7bde294b,0x27e00ac5,0x6b9c0165,0x97c4104c}},	//   orru, buhn_, _zisg, _مترم, 
   {{0xe9712374,0x6b9c009a,0xb60800bc,0x7bdc0175}},	//   _بۇلد, _yisg, dušš, nrru, 
   {{0x57a401e0,0xf3180107,0x399806be,0x24800037}},	//   _ашҡа, тоиш_, düsə_, ühma_, 
   {{0x6f0c0a81,0x14240220,0x166401ee,0xcb340677}},	//   _raac, _әдем, _свам, טאקי_, 
   {{0x7f46294c,0x6f0e294d,0x2ee80048,0x6aac00b5}},	//   _aliq, _saac, _scaf_, zcaf, 
   {{0x6f0e294e,0x4fc401ec,0x00000000,0x00000000}},	//   _paac, ыспа, --, --, 
   {{0x7f46294f,0x6f0c5283,0x7bdcdfd1,0x00000000}},	//   _cliq, _qaac, drru, --, 
   {{0x2d4c1050,0x6b9e2950,0x69cc0369,0x7bdc5d2e}},	//   džer_, _risg, xsae, erru, 
   {{0x7f444b2a,0x6f0e2951,0x7095055c,0xad240131}},	//   _eliq, _waac, _калф, جىسى, 
   {{0x6f0e2952,0xac9527dd,0x6aac01f5,0x91c000d1}},	//   _taac, равш, tcaf, _тәқл, 
   {{0x69ce2953,0x290001f7,0x6b9c022e,0x3e900023}},	//   tsae, weha_, _qisg, _ሓቤሬታ_, 
   {{0x7bdc013c,0x6b9c56ce,0x69cc030a,0x29022954}},	// [3f9f0] arru, _visg, usae, teha_, 
   {{0x69ce2955,0x6608017a,0x6b9c878f,0x00000000}},	//   rsae, _rsek, _wisg, --, 
   {{0x6d444674,0xa3a8561f,0x69cc0393,0x59f40135}},	//   _ilha, _गंध_, ssae, _པདྨེ_, 
   {{0xa6162956,0x290225e6,0x69ce2957,0x660801c4}},	//   имеч, seha_, psae, _psek, 
   {{0x29022958,0xe4c62959,0x7940010e,0x6594a8db}},	//   peha_, айли, _köwl, ааду, 
   {{0x2b48180f,0x6608151c,0x00000000,0x00000000}},	//   lhac_, _vsek, --, --, 
   {{0x79400432,0x6d4401ef,0x00000000,0x00000000}},	//   _möwl, _mlha, --, --, 
   {{0x2b4a295a,0xe1f95944,0x00000000,0x00000000}},	//   nhac_, вги_, --, --, 
   {{0x6d4403b7,0x66080028,0xdc0005f9,0x92d400cc}},	//   _olha, _usek, _लन्ड_, িভূ_, 
   {{0xfe50002e,0x59d828d4,0x30600023,0x7bdc0142}},	//   _xa鯵_, यूटर, _ትመጽእ_, yrru, 
   {{0xa06a295b,0x7f44004e,0xa2d4038b,0xd3e404fb}},	//   тана_, _pliq, _نيات, _نقلی, 
   {{0x6d440b45,0x2ba80307,0x712402dd,0xeff00092}},	//   _alha, _कढ़ा, _ۇرىل, ቃለያ_, 
   {{0x6d440218,0x2b480014,0x38ac01e1,0x22280066}},	//   _blha, dhac_, _jòró_, _جزای_, 
   {{0x114c02d3,0x9f440561,0x224c0156,0x7bdc036e}},	//   _ንብዙሓ, stlà_, mzek_, trru, 
   {{0xdea0bc28,0x79400510,0xb7b003f4,0x6d4402c4}},	//   _ویدی, _döwl, _চট্ট, _dlha, 
   {{0x6d46295c,0x7f451a7d,0xf53801e4,0xfe501bce}},	//   _elha, _uliq, _miĥa_, _sa鯵_, 
   {{0x4aa4c74a,0x6ee4516c,0x2d4c00f3,0xc9a40120}},	// [3fa00] ркун_, _اسىل, ržer_, ивте_, 
   {{0x1aec00bd,0x224c01c4,0xc03801f3,0x00000000}},	//   _চোখে_, izek_, _ይመስል, --, 
   {{0x1b0c02f5,0x59d801ad,0x2b4805e0,0xdcfc00de}},	//   হাবে_, यूजर, bhac_, _lipī, 
   {{0x38ac01e1,0x2b48012d,0x00000000,0x00000000}},	//   _bòró_, chac_, --, --, 
   {{0xd64c02e3,0xf1d4012c,0xdcfc002b,0x98a424fc}},	//   mọkụ_, _दिइन, _nipī, _виге, 
   {{0xd944d363,0xb4e062be,0x224c0210,0xb40400cf}},	//   _теги, थले_, dzek_, йүзд, 
   {{0xe8b006ba,0x224d03d1,0xc6a40014,0x3ebc0051}},	//   _رەنج, ezek_, اگہٕ_, _đvtn_, 
   {{0x38ac0241,0x93881f5a,0xd34401b9,0x72d000d1}},	//   _fòró_, њска_, گیچه_, سەتچ, 
   {{0x926802e8,0x7c3dafd4,0x0dd40092,0x7178009d}},	//   ърка_, hyrr, ክቶፕ_, лбир_, 
   {{0x09f40375,0x661c032e,0x00000000,0x00000000}},	//   סמים_, _áska, --, --, 
   {{0x9404d15a,0x130406bb,0x248803f9,0x2d4c0cf4}},	//   _خواه, _взем, ƙama_, džep_, 
   {{0x2244013d,0x00000000,0x00000000,0x00000000}},	//   рҗән_, --, --, --, 
   {{0x8d74cf38,0x224c068f,0x6d440211,0x5186295d}},	//   لاسا, czek_, _plha, _кука, 
   {{0x657c07db,0x417000f1,0x7c3e295e,0x00000000}},	//   _ësht, _واوس, fyrr, --, 
   {{0x2b48003a,0x7c3c0042,0x0ac41b0a,0xaba800f2}},	//   thac_, gyrr, ищам, اهرم_, 
   {{0x0a34001f,0x8cd00316,0xe51c4aa7,0x79400432}},	//   _የመልካ, _भएको, _योनि_, _döwm, 
   {{0x6d4419bd,0x39580175,0xfc5c001f,0xa6dc00fe}},	// [3fa10] _tlha, _bmrs_, ደሚገኙ_, ণ্ডট, 
   {{0x2368341a,0x6d440ba1,0x7c3c05ac,0x6e3c017a}},	//   čaji_, _ulha, byrr, mysb, 
   {{0x8c340116,0x6e3c0fac,0x06b443fb,0x38ac01e1}},	//   _түвр_, lysb, لناک_, _sòró_, 
   {{0xd3641af6,0x60dc0153,0xaae00073,0xe3b801f0}},	//   _ره_, ėsmi, _फाटक, қби_, 
   {{0xd6cc6bce,0x7bd8143a,0x7940010e,0xc82c0092}},	//   رقو_, _åvur, _möwj, _በዋሽን, 
   {{0x24e8bb40,0xe9441374,0xaca400a2,0x00000000}},	//   умки_, _انسپ, maỳy, --, 
   {{0x612c01d3,0x6e3c03cb,0x3cfc010f,0x69dc0bae}},	//   _túlz, hysb, דלונ, _पिडी, 
   {{0x2912295f,0x224c01c6,0xdcfc002b,0xa1c4022e}},	//   _haza_, tzek_, _pipī, ббид, 
   {{0x29122960,0x224c0489,0xdb0c06af,0xb308007b}},	//   _kaza_, uzek_, édéf, شغيل_, 
   {{0x29110669,0x224c594d,0x99b0015b,0x11440166}},	//   _jaza_, rzek_, _চিৎক, йпый_, 
   {{0x1b0c2158,0x29122961,0x224c1b7a,0xa0a5b1fb}},	//   হাতে_, _maza_, szek_, _һалд, 
   {{0x29122962,0x3ea408cb,0x69dc0490,0x00000000}},	//   _laza_, ømt_, _पिढी, --, 
   {{0x794000a2,0x6e3c0142,0xf1c818fd,0xe2146c9a}},	//   _söwm, gysb, _نونى_, _ымды, 
   {{0x29122963,0x7c3c0e38,0x00000000,0x00000000}},	//   _naza_, tyrr, --, --, 
   {{0x8c400ec4,0x00000000,0x00000000,0x00000000}},	//   пере, --, --, --, 
   {{0x2b58004e,0x13a8009e,0x7c3c0042,0x00000000}},	//   _cmsc_, _গৌড়, ryrr, --, 
   {{0x612c00dd,0x7c3c007c,0x5f9401af,0x00000000}},	// [3fa20] _súly, syrr, _киҫт, --, 
   {{0x291009ff,0x4a4003b7,0x2b58007f,0x1c4400f5}},	//   _caza_, чнув, _emsc_, _гном, 
   {{0x9b462964,0x29122965,0x00000000,0x00000000}},	//   _هندو, _daza_, --, --, 
   {{0x29100356,0x3cf000cc,0x00000000,0x00000000}},	//   _eaza_, _চফট্_, --, --, 
   {{0x991410f5,0x313c0023,0x958400db,0xd9b000cc}},	//   _льві, _ይገብር, блде, _চিকম, 
   {{0x29122966,0x00000000,0x00000000,0x00000000}},	//   _gaza_, --, --, --, 
   {{0xd3780408,0x88b00014,0x96b81f0f,0x18a42cdd}},	//   лчи_, _رینچ, _бузу_, _ваҳм, 
   {{0x29100851,0x9388034b,0x8c18011a,0x00000000}},	//   _zaza_, ысла_, רוקי, --, 
   {{0x29122967,0xd1b80137,0xcb100375,0xd5b0007b}},	//   _yaza_, داعا_, ללה_, _رفض_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdfcc05d9,0x6e3c0af9,0x48e8012c,0x00000000}},	//   نڊي_, wysb, _चासो_, --, 
   {{0x8f4475d2,0x91e467a8,0xd13c0210,0x6e3c01f4}},	//   сход, _годе, _żąda_, tysb, 
   {{0x7804012d,0xd04406be,0x00000000,0x00000000}},	//   रबुक_, _əmən, --, --, 
   {{0x2ca41125,0x6b640006,0x00000000,0x00000000}},	//   øld_, mėgi, --, --, 
   {{0x2910d552,0x6fb58811,0x853806a9,0xb938001f}},	//   _raza_, _بمبا, נגלי, _በማካሄ, 
   {{0x29122968,0x4ea40d6f,0x48e800e1,0x00000000}},	//   _saza_, _урка, _चाहो_, --, 
   {{0x794002b5,0x29100276,0x6934033a,0xadec13f7}},	// [3fa30] _köwh, _paza_, онау, _जमिन_, 
   {{0xdcec054e,0x7940010e,0x29122969,0x225803b2}},	//   robă, _jöwh, _qaza_, úski_, 
   {{0x8d8403e6,0xdcb0612e,0x98a80356,0xc98408ca}},	//   _پشکن, _تىپ_, _sobă_, _ҳуви, 
   {{0x2912296a,0xcb080c98,0x00000000,0x00000000}},	//   _waza_, _сход_, --, --, 
   {{0x2912296b,0xd7040220,0x3c180100,0xd5ac004b}},	//   _taza_, інше_, _zčv_, نځل_, 
   {{0x81b403f4,0xfbd00014,0xa8241d0a,0x25a0002f}},	//   _ছিল_, _تتی_, _وکان, öhl_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x661c08a7,0xf1d40034,0x2be02e05,0x98a80356}},	//   _ásko, _दिखन, _फिना, _tobă_, 
   {{0x6b640024,0x00000000,0x00000000,0x00000000}},	//   gėgi, --, --, --, 
   {{0x61ec00df,0xdb0c00cc,0x344800d1,0xd1800166}},	//   _ĥald, mpbå, рчән_, млый, 
   {{0x5f041d39,0x05980220,0x00000000,0x00000000}},	//   озна, _ﺟﻮﺳﭙ, --, --, 
   {{0x3c180100,0x6b640153,0x068401ec,0x00000000}},	//   _rčv_, bėgi, _ﺩﻭﯕﮕ, --, 
   {{0x8286296c,0x9f440200,0x00000000,0x00000000}},	//   _اجال, lulë_, --, --, 
   {{0x236804b9,0x7940010b,0xe4ec0456,0x00000000}},	//   čaju_, _göwh, च्चि_, --, 
   {{0xace40032,0x00000000,0x00000000,0x00000000}},	//   ябрҙ, --, --, --, 
   {{0x3c18007f,0xb33c031c,0x19c400ea,0x00000000}},	//   _včv_, _ruħk, жбам, --, 
   {{0x8d740050,0x8f980115,0x00000000,0x00000000}},	// [3fa40] _ژاپا, _דיקי, --, --, 
   {{0x09002179,0x9f44036e,0x00000000,0x00000000}},	//   мпун, kulë_, --, --, 
   {{0x48e80dad,0x97c400d4,0x00000000,0x00000000}},	//   _चारो_, ійде, --, --, 
   {{0x34b6296d,0x59e02e2a,0x00000000,0x00000000}},	//   ुर्द, _पिपर, --, --, 
   {{0x28c4033f,0x6d4001e3,0x00000000,0x00000000}},	//   _लड़कि, ölag, --, --, 
   {{0x98740063,0xdd2400c0,0x00000000,0x00000000}},	//   _дубљ, _lūžu, --, --, 
   {{0x375401d9,0x53e402d5,0x09ac00cc,0x9f440200}},	//   _ٹھاس, іцка, _চৌপা, gulë_, 
   {{0x662400bc,0x03743bd7,0xa3a80073,0x00000000}},	//   átký, يحيت_, _गूळ_, --, 
   {{0xf1c40073,0xddd4012d,0x794000a2,0xf1c800db}},	//   लींन, _czyż, _pöwh, حابۇ_, 
   {{0xd13a296e,0x2808002e,0x3f8000c0,0x660c0205}},	//   рхи_, _ñuné_, _akiu_, çake, 
   {{0xe81c1b37,0x00000000,0x00000000,0x00000000}},	//   फिया_, --, --, --, 
   {{0xd24c01d9,0x7940010e,0xd24531ca,0x00000000}},	//   _لۆب_, _döwi, _мэли, --, 
   {{0x07980bd9,0xb33c0003,0x48e801ad,0xd2500214}},	//   יסטל, _ruħh, _चालो_, _تنش_, 
   {{0xaff800ec,0xf1c80116,0x00000000,0x00000000}},	//   _هفتا_, _نوچى_, --, --, 
   {{0x2584145e,0x80b000cf,0x657c02d2,0x00000000}},	//   lêlê_, _تەپش, _íshe, --, 
   {{0x671800ab,0x00000000,0x00000000,0x00000000}},	//   _नोंक_, --, --, --, 
   {{0xaa540395,0x00000000,0x00000000,0x00000000}},	// [3fa50] чваш, --, --, --, 
   {{0x261807f7,0x161c012d,0x00000000,0x00000000}},	//   पिसी_, पिनर_, --, --, 
   {{0x2d8001e2,0x27e0007f,0x00000000,0x00000000}},	//   _ikhe_, urhn_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x98a80034,0x59e0c6cd,0x9ba0021f,0x69c400b1}},	//   _sobą_, _पियर, _سەكى, _хөбб, 
   {{0xa508680f,0xd0a00ca8,0x67d40107,0x25bc0368}},	//   сека_, _gẹgẹ, _ногу, rpwl_, 
   {{0x1b0c015b,0xe89401c6,0x240801f0,0x00000000}},	//   হারে_, _хавь, ёнии_, --, 
   {{0x23280107,0xf6e4030d,0x00000000,0x00000000}},	//   соии_, _оцун, --, --, 
   {{0x2d800472,0x00000000,0x00000000,0x00000000}},	//   _okhe_, --, --, --, 
   {{0x9f449d74,0x98a8033f,0x68e00142,0x00000000}},	//   mulé_, _tobą_, _ôldd, --, 
   {{0xf3f00597,0x25ae296f,0xdca4013e,0x9dc000d1}},	//   _لأن_, _huel_, ҷаги, ﯩﺸﯩﺸ, 
   {{0x2d80124c,0x25a44916,0x25ac0036,0x00000000}},	//   _akhe_, _hill_, _kuel_, --, 
   {{0x9f45d914,0x25ac75f9,0x25a42403,0x23b00518}},	//   nulé_, _juel_, _kill_, _háj_, 
   {{0x91b80375,0x79400432,0x225800d7,0x00000000}},	//   _המסי, _töwi, úsku_, --, 
   {{0x61ea2970,0x25ac0076,0x25a447a3,0xdc300171}},	//   luel, _luel_, _mill_, _bļāv, 
   {{0x25a41f21,0x23b0c2f1,0x2d800472,0x3f822971}},	//   _lill_, _máj_, _ekhe_, _ukiu_, 
   {{0x0dc400fd,0x25a40076,0x6b640024,0x38c83267}},	// [3fa60] _елый_, _oill_, jėgu, قاضی_, 
   {{0x9f4404fb,0x6b640064,0x00000000,0x00000000}},	//   dulé_, dėgu, --, --, 
   {{0x61ea2972,0xd0a001e1,0x0d38011a,0x23b000d7}},	//   huel, _gẹdẹ, _הגיב, _náj_, 
   {{0x61ea2973,0x25a52ac9,0x25ac0076,0x5628010b}},	//   kuel, _aill_, _buel_, йжем_, 
   {{0x61e80407,0xceb006a9,0x1dbc0882,0x25a4565d}},	//   juel, גיד_, ्ठित, _bill_, 
   {{0x25a435ab,0xa5040022,0x00000000,0x00000000}},	//   _cill_, мҵуа_, --, --, 
   {{0xb4ac0c2e,0xd8240139,0x9f44007f,0x00000000}},	//   _गली_, _эдви, pulè_, --, 
   {{0x25a62974,0x25ae2975,0x9f4467fc,0x6b640153}},	//   _eill_, _fuel_, bulé_, bėgu, 
   {{0x518485e0,0x9f44004a,0x25a62976,0x6b640153}},	//   зуна, culé_, _fill_, mėgt, 
   {{0xf48456a7,0x23b001d3,0x3ef801c6,0x00000000}},	//   _قاضی, _fáj_, үнээ_, --, 
   {{0x75281cea,0x2584006a,0x25ac0221,0x14881075}},	//   _indz, sêlê_, _zuel_, _اپاي_, 
   {{0x61ea2977,0x25a40036,0x00000000,0x00000000}},	//   buel, _zill_, --, --, 
   {{0x61ea2978,0x752802c4,0x8778008f,0x00000000}},	//   cuel, _kndz, מאטי, --, 
   {{0xc0b81e38,0x752802c4,0xac9401c6,0x00000000}},	//   ቲቫል_, _jndz, дагш, --, 
   {{0x01322979,0xe51c00dc,0x50540014,0x810800f1}},	//   _سعود, पयति_, _ژٔڈس_, _درنې_, 
   {{0x4ea407d6,0x7c282d62,0x92dc0c58,0x9f4400e8}},	//   _эрка, ådra, দ্ৰ_, yulé_, 
   {{0x88c40aa0,0x752802b9,0xbbd403e6,0xad5400c6}},	// [3fa70] كتال, _ondz, وڕێک, _ينبغ, 
   {{0x48a8cc3e,0x25ac0280,0x2d8000f1,0x39145290}},	//   стам_, _ruel_, _ukhe_, нмур, 
   {{0xf772297a,0x46681cd1,0x25ac0036,0xac981e2f}},	//   گال_, әрем_, _suel_, _گنگا_, 
   {{0x752807a9,0x25a6297b,0x25adcb96,0x9f4407ea}},	//   _andz, _sill_, _puel_, tulé_, 
   {{0x25ae297c,0xf77035ac,0x25a6297d,0x61ea297e}},	//   _quel_, دال_, _pill_, xuel, 
   {{0x61e809d7,0x59e000dc,0x9f440e07,0x23b000d7}},	//   vuel, _पितर, rulé_, _páj_, 
   {{0x25a6297f,0x25ac04c4,0x26cc01af,0x9f44020c}},	//   _vill_, _wuel_, _teeo_, sulé_, 
   {{0x25a593a7,0x752a2980,0x794000a2,0x9f4406af}},	//   _will_, _endz, _döwu, pulé_, 
   {{0x25a62981,0xf77012dd,0x672800ca,0x25ac00c5}},	//   _till_, _صاف_, _inej, _uuel_, 
   {{0x25a4a66a,0x23b000e5,0x00000000,0x00000000}},	//   _uill_, _táj_, --, --, 
   {{0xdee62982,0x67280135,0xe2f80212,0x14c8028e}},	//   мони, _knej, _межі_, _ذهنی_, 
   {{0x39940724,0xe8040034,0x61e81132,0x67281b99}},	//   mäse_, _रहना_, puel, _jnej, 
   {{0x236e2983,0x39940598,0x67280135,0xe13401ec}},	//   mnej_, läse_, _mnej, _онды, 
   {{0x236e0b7a,0xe1f80024,0x6b50007c,0x00000000}},	//   lnej_, mtų_, _lågd, --, 
   {{0xe1f80006,0x672a2984,0x236c012d,0x00000000}},	//   ltų_, _onej, onej_, --, 
   {{0x236e2985,0xe1f80024,0x92ac0183,0x00000000}},	//   nnej_, otų_, কৰী_, --, 
   {{0xe1f80953,0xdb040036,0x98d801d5,0x39940139}},	// [3fa80] ntų_, _hikë, قباز_, häse_, 
   {{0x39940724,0x672a2986,0xe1f80006,0xb4adc001}},	//   käse_, _anej, itų_, _गले_, 
   {{0x6728031c,0x236c05d6,0x00000000,0x00000000}},	//   _bnej, knej_, --, --, 
   {{0xe1f80953,0x236d8d8f,0xdb040200,0x3994013d}},	//   ktų_, jnej_, _mikë, däse_, 
   {{0x236e2987,0xdb040200,0x99d4007b,0x00000000}},	//   dnej_, _likë, _تتجا, --, 
   {{0x672a2988,0x8e540a1e,0x6b640064,0x3994008e}},	//   _enej, וינג_, bėgs, fäse_, 
   {{0x7940010e,0xdb040200,0x37d800eb,0x3994013d}},	//   _döwt, _nikë, _সহকর, gäse_, 
   {{0xcc740375,0xdcf40166,0x6b640153,0x88e000eb}},	//   ועצה_, _muyı, lėgr, ন্দক, 
   {{0xe1f80024,0x74a400d1,0x98b012eb,0x00000000}},	//   gtų_, ﻏﯘﭼﯩ, _जलाए, --, 
   {{0x752828d9,0x236c012d,0xb0340063,0x6b50007c}},	//   _undz, anej_, енош, _tågg, 
   {{0x236e2989,0xc05400d6,0xdbd400c5,0xab6400db}},	//   bnej_, дія_, _jääg, nqüè, 
   {{0x122800c9,0xb8f0025c,0x236c8763,0x794000a2}},	//   _моей_, _ུབ_, cnej_, _köws, 
   {{0xdc440374,0xdbd40254,0x867800df,0x00000000}},	//   _rūāt, _lääg, ַרלו, --, 
   {{0xdcf40598,0x77600077,0x6b50353e,0x7940010b}},	//   _buyı, _lmmx, _måge, _möws, 
   {{0x6b52298a,0xdcec00bc,0xdbd40254,0x00000000}},	//   _låge, lobě, _nääg, --, 
   {{0xe804000d,0x00000000,0x00000000,0x00000000}},	//   _रहबा_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3fa90] --, --, --, --, 
   {{0x672a298b,0x661c008c,0x236c182d,0xc02000db}},	//   _snej, _áski, znej_, _سىۋي, 
   {{0x248803f9,0xdc4402b5,0xdb0400e4,0x236c0113}},	//   ƙami_, _tūāt, _oikè, ynej_, 
   {{0xe1f80006,0x9f44026c,0x7940010e,0x6b5001e3}},	//   ytų_, julì_, _böws, _båge, 
   {{0x236c01a2,0x3e6000b0,0xba480118,0x6728013a}},	//   vnej_, pātū_, _průš, _vnej, 
   {{0xfbd015d6,0x236c0034,0x92ac0154,0xdcec013a}},	//   _حتی_, wnej_, করো_, době, 
   {{0x236cbdcd,0x6728003d,0x58000116,0x00000000}},	//   tnej_, _tnej, _مۈلك, --, 
   {{0x39940724,0x6b50049f,0x67280c8c,0xa5f9174b}},	//   räse_, _fåge, _unej, _небу_, 
   {{0x236c172a,0xdb04020c,0xefc402d3,0x79400432}},	//   rnej_, _dikè, _ጸዊዑ_, _göws, 
   {{0xdb04044e,0xe1f802d5,0x236d8d8f,0x7940010e}},	//   _pikë, rtų_, snej_, _höwr, 
   {{0xe1f80953,0x236c2344,0x00000000,0x00000000}},	//   stų_, pnej_, --, --, 
   {{0xe1f80006,0x10200f1c,0x6b504cab,0x1418011a}},	//   ptų_, اکوپ, _lågb, _מועב, 
   {{0x3ea4049f,0x79400432,0xdcf40139,0x52d4011a}},	//   ämt_, _möwr, _suyı, _נוסע_, 
   {{0xdd90f7f5,0x98a80316,0x21f80066,0x00000000}},	//   اوس_, _době_, mèh_, --, 
   {{0xfb86298c,0xdcf40724,0x2ab40521,0x21f80214}},	//   ندری, _quyı, _ụba_, lèh_, 
   {{0xdbd4007d,0x2be07347,0xdb0401d3,0x34ac00bc}},	//   _rääg, _फिरा, _kiké, _चल्द, 
   {{0x09e02c68,0x21f8034c,0x4c640139,0x00000000}},	// [3faa0] лотн, nèh_, _җиян_, --, 
   {{0x09ac04c5,0x832c031c,0xdb0401d3,0x6b500728}},	//   _চৌহা, _ཨོའུ_, _miké, _råge, 
   {{0xdb06298d,0x7940010e,0x79540014,0x6b5001e3}},	//   _liké, _böwr, _یێرا, _såge, 
   {{0x3ae8066d,0xd9d00328,0xdb04035b,0x65600042}},	//   _کبھی_, _مەرگ, _oiké, _amlh, 
   {{0x794009a5,0xa3a802ab,0x85b401ec,0x162000c7}},	//   _döwr, _गंज_, еліс_, ыҧаҟ, 
   {{0x3b0005b1,0xdb0400f2,0x3a200208,0x4dd8011a}},	//   lfiq_, _sikè, mvip_, לחנו, 
   {{0x3a20d7a2,0xdb04e622,0x9f440268,0x9ce40327}},	//   lvip_, _aiké, tulì_, _སྐབས, 
   {{0xe8041fb0,0x279405c2,0x6b5215aa,0xc7a02b97}},	//   _रहता_, _ашур, _tåge, _биск, 
   {{0xdb040c6a,0x75a400c7,0x9f440268,0x21f80066}},	//   _ciké, _алаҕ, rulì_, gèh_, 
   {{0xdb0406fd,0x09f40302,0x7d1c627e,0x00000000}},	//   _diké, עמים_, jdrs, --, 
   {{0xb4cc10dc,0xa4f42f4d,0x9f4404cc,0xdb04560d}},	//   लरी_, _شکور_, pulì_, _tikè, 
   {{0x21f8034c,0x98a8012c,0x9580033f,0xf1c800db}},	//   bèh_, _sobě_, żąda, _قاتۇ_, 
   {{0x21f80066,0x3a200455,0x28e0000d,0x00000000}},	//   cèh_, jvip_, _पयलि, --, 
   {{0x2d86298e,0x021425f9,0xc6900bd9,0x65618931}},	//   ôle_, _נחום_, טאר_, _xmlh, 
   {{0xc04d6715,0x3b00020c,0xead4023a,0x2ca40267}},	//   _сі_, ffiq_, ковь, äld_, 
   {{0x6b50007c,0x0a500092,0xf07800fb,0x00000000}},	//   _sågb, _ለመልካ, _ниҙә_, --, 
   {{0x5e140022,0x98a800bc,0x6f1c002f,0x2b480205}},	// [3fab0] _азыӡ, _tobě_, mdsc, rkac_, 
   {{0x6f1e298f,0xad8400f7,0xc668010b,0xdc2c0166}},	//   ldsc, _جابۇ, үшде_, _uñğa, 
   {{0xfe700272,0x0cbc6b26,0x3a201ada,0x6f1c01f5}},	//   _ندی_, ्रीम, avip_, odsc, 
   {{0xdc3400c8,0x21f8020c,0x3a200208,0x660c236c}},	//   _סארט_, yèh_, bvip_, çako, 
   {{0xdb04019f,0x6f1c6cbd,0xd2460868,0x6b5001e3}},	//   _kikî, idsc, _ئن_, _tågb, 
   {{0x6b8cb0ec,0x2408010b,0x00000000,0x00000000}},	//   llag, днки_, --, --, 
   {{0x21f800f2,0x6b8c0072,0x7940010b,0x00000000}},	//   wèh_, olag, _töwr, --, 
   {{0x6f1c0cf9,0x97000075,0xdb040687,0xa2040116}},	//   jdsc, _نېمى, _piké, впид, 
   {{0x6b8c1368,0x11d40597,0xe19498a4,0xd24c00f1}},	//   ilag, نوية_, кроэ, يچه_, 
   {{0x660a2990,0x6b8e2991,0x9f440004,0x21f80214}},	//   _ipek, hlag, kulã_, rèh_, 
   {{0x6b8e2992,0x9f440270,0x05d4ad78,0x6f1c01a4}},	//   klag, sulí_, _डबडब, fdsc, 
   {{0x6b8ceeb6,0xdb060816,0x21f80066,0x6f1c002f}},	//   jlag, _tiké, pèh_, gdsc, 
   {{0x6b8e2993,0x3b00022e,0x3a200051,0x00000000}},	//   dlag, vfiq_, xvip_, --, 
   {{0x6b8e2994,0x660a2995,0x91e22996,0x61e96822}},	//   elag, _mpek, _тоше, mrel, 
   {{0x69dc0267,0x61ea2997,0x06d40eac,0x9f940798}},	//   _avse, lrel, _হানি, _ишиш, 
   {{0x660a2998,0x6b8e2999,0x69dc010a,0xed5800e2}},	//   _opek, glag, _bvse, īža_, 
   {{0x660c3642,0x61ea299a,0x9f45199a,0x00000000}},	// [3fac0] çakl, nrel, mulà_, --, 
   {{0x1c458e1d,0x61e801f5,0x6b8e299b,0x6d56299c}},	//   _аном, irel, alag, chza, 
   {{0x6b8e299d,0x660a299e,0x3a206a37,0x61ea299f}},	//   blag, _apek, svip_, hrel, 
   {{0x61ea29a0,0x0bb4025f,0x6b8e29a1,0x9f4419f5}},	//   krel, _שלכם_, clag, nulà_, 
   {{0x7bdc713c,0x994400d0,0x15a80150,0x00000000}},	//   lsru, môž_, _ﺷﻮﺭﻩ, --, 
   {{0x61ea29a2,0x7bdc01e7,0x00000000,0x00000000}},	//   drel, osru, --, --, 
   {{0x66093a5a,0x7bde29a3,0x61ea29a4,0x96b800cf}},	//   _epek, nsru, erel, _жузу_, 
   {{0xb6c800dd,0x61ea29a5,0x9f440268,0x67a47138}},	//   _سارے_, frel, julà_, _محقق, 
   {{0x61ec0fac,0x86b0013d,0x660401af,0x00000000}},	//   _åall, _төхф, _йотҡ, --, 
   {{0x6b8e29a6,0x301405f5,0x7bdd75cb,0x4a98008f}},	//   zlag, гдор, ksru, ויפג, 
   {{0x61e998be,0x6b8c0731,0x6b5003d4,0x9f440268}},	//   arel, ylag, _låga, fulà_, 
   {{0x7bde29a7,0x9f451999,0x926803b0,0x82600214}},	//   dsru, gulà_, _орла_, اهین, 
   {{0x6f1e29a8,0x61ea29a9,0x6b8c33b8,0xd1cc001f}},	//   rdsc, crel, vlag, ጣቶች_, 
   {{0xac1803b7,0x64440730,0xad2410a8,0x0cbc590f}},	//   ногу_, ähig, دىسى, ्रेम, 
   {{0x7bdc0267,0x2fdc0356,0x6c841867,0x00000000}},	//   gsru, _uvvg_, الزم, --, 
   {{0x6b8e29aa,0x9f4408e5,0x6b5001e3,0x7ac428e8}},	//   ulag, culà_, _båga, исуе, 
   {{0xdb1000c6,0x9f440137,0xeb9848fb,0xbea400f3}},	// [3fad0] ágái, atló_, диң_, _каћк, 
   {{0x2919f415,0x39940227,0xfaa40640,0x7bdc005c}},	//   عقاد_, täsa_, рађо, bsru, 
   {{0x6c35c862,0x61e83858,0x3ce8206b,0x994400d7}},	//   _صفحا, zrel, _जयते_, bôž_, 
   {{0x61ea29ab,0x6b8cdab0,0xd8840214,0x290001ab}},	//   yrel, qlag, دهمی, sfha_, 
   {{0x45a01e4a,0x66043246,0xa5080798,0xf65093fc}},	//   لەرك, упла, еела_, يئه_, 
   {{0x61ea29ac,0x990000bc,0xaa400023,0x00000000}},	//   vrel, र्दछ_, _የመሓላ, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x61e80a16,0x221400f3,0x4660215c,0x00000000}},	//   trel, гфор, _پۇتق, --, 
   {{0x660a29ad,0x20d629ae,0x9f4629af,0x776400a7}},	//   _upek, лінс, vulà_, _търж, 
   {{0x7bdc2d18,0x0cbc150d,0x9ac00135,0x00000000}},	//   ysru, ्रोम, ċċie, --, 
   {{0x4ad01fbc,0x9f451cdd,0x00000000,0x00000000}},	//   तराव, tulà_, --, --, 
   {{0x69c04ea1,0x61ea29b0,0x5f34014b,0x7bdc03b2}},	//   _člen, prel, ухоф, vsru, 
   {{0x9f44026c,0xd1e401ec,0x00000000,0x00000000}},	//   rulà_, _مينۋ, --, --, 
   {{0x7bde29b1,0x9f440ffb,0x5c144a1d,0x6b50007c}},	//   tsru, sulà_, льбу, _råga, 
   {{0x6b510fd7,0x9f451cdd,0x5ed401d5,0x7bdc01f4}},	//   _såga, pulà_, _یتکز, usru, 
   {{0x7bdc9e7a,0x6b501061,0x74980092,0x00000000}},	//   rsru, _påga, _ቅንጅቱ_, --, 
   {{0x39643372,0x7bde29b2,0xb9240124,0x00000000}},	// [3fae0] анаҳ, ssru, mosẽ_, --, 
   {{0x6b50d961,0x18a417a0,0x7bdc248f,0xfd240244}},	//   _våga, газм, psru, _ئودێ, 
   {{0xdc680364,0xd7cc0073,0xb7b4009d,0x00000000}},	//   _чанд_, हींच, рөгч, --, 
   {{0x6b5001e6,0xcc38008f,0x9f4c0166,0x00000000}},	//   _tåga, _נעכט, _änäk_, --, 
   {{0x24901540,0x2a34300e,0xb4b40131,0x00000000}},	//   _ምሕረት_, _кэрр, қиқә, --, 
   {{0x6604030d,0x00000000,0x00000000,0x00000000}},	//   ăпла, --, --, --, 
   {{0x799c02d0,0x00000000,0x00000000,0x00000000}},	//   _ihrw, --, --, --, 
   {{0x6b50007c,0x00000000,0x00000000,0x00000000}},	//   _lågn, --, --, --, 
   {{0x71780b01,0x00000000,0x00000000,0x00000000}},	//   кбир_, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x893400c8,0x661c0008,0x06d4015b,0xdce800bc}},	//   אריע_, _áskr, _হাতি, žněj, 
   {{0xdb0400d7,0x59ac0037,0x644401f4,0x00000000}},	//   _bikí, _झंझर, ähie, --, 
   {{0x41701547,0x799c0112,0xc3c0004e,0x00000000}},	//   شایس, _ohrw, _көөл, --, 
   {{0xe804007d,0x799c0142,0xff8800cf,0x00000000}},	//   _रहला_, _nhrw, көөл_, --, 
   {{0xd98c02dd,0x00000000,0x00000000,0x00000000}},	//   _ﺒﻬﺫﻩ_, --, --, --, 
   {{0x799e29b3,0x9f440418,0x00000000,0x00000000}},	//   _ahrw, pulá_, --, --, 
   {{0x660c031c,0x00000000,0x00000000,0x00000000}},	// [3faf0] ħakk, --, --, --, 
   {{0xdd9000dd,0x799c0042,0x28c4ad85,0x051c00cc}},	//   _ووٹ_, _chrw, ршаҳ, _বক্ৰ_, 
   {{0x8cc86495,0xa81629b4,0x7b0a29b5,0xab94003b}},	//   _त्यो, рдеш, ístí, _вині, 
   {{0x799c002f,0xe73800ef,0x59d000bc,0x00000000}},	//   _ehrw, _bēšī, दीहर, --, 
   {{0x06d4015b,0x9f44003a,0xd0a00241,0x00000000}},	//   _হাদি, bulæ_, _sẹlẹ, --, 
   {{0xe5a5b243,0xa5083a61,0x9f44003a,0xd0a00241}},	//   шили, тека_, culæ_, _pẹlẹ, 
   {{0x6378014b,0x368804b4,0x00000000,0x00000000}},	//   ксир_, ксән_, --, --, 
   {{0x6d4001f4,0x00000000,0x00000000,0x00000000}},	//   ölaj, --, --, --, 
   {{0xe2980107,0x6b5001e3,0xe3b000ec,0x00000000}},	//   ъаи_, _lågo, حرڪ_, --, 
   {{0xd0a001e1,0x91014d06,0x00000000,0x00000000}},	//   _tẹlẹ, опье, --, --, 
   {{0x6b5001e6,0x641629b6,0x69c00751,0x442001ed}},	//   _någo, _خواط, _ōlel, _éj_, 
   {{0xd24c004b,0x6b5001e3,0x00000000,0x00000000}},	//   سنۍ_, _sågn, --, --, 
   {{0x81c000c7,0x00000000,0x00000000,0x00000000}},	//   _уалҧ, --, --, --, 
   {{0xa0a4e88a,0xdc74001f,0xacf40014,0x1fb400f3}},	//   _калд, _የስልክ_, ٝسِت, _ксир, 
   {{0xdca40faa,0xdfd00597,0x6b50037e,0x8c4000d8}},	//   рави, _بيع_, _vågn, оере, 
   {{0x1834c73b,0x799c02d0,0x1ef8007b,0xd00c0ada}},	//   یراح, _shrw, _شعبة_, _آلي_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3fb00] --, --, --, --, 
   {{0x6b50007c,0x7f440051,0x9f4400ae,0x00000000}},	//   _hågl, _hoiq, irlí_, --, 
   {{0xdb040055,0x6b60013a,0x00000000,0x00000000}},	//   _cikã, _sígř, --, --, 
   {{0xe7380368,0xd704059f,0x00000000,0x00000000}},	//   _siŵr_, рзди, --, --, 
   {{0x799ca77f,0x00000000,0x00000000,0x00000000}},	//   _thrw, --, --, --, 
   {{0x53e40588,0x6b502d62,0xe5e400c6,0x799c0112}},	//   ациа, _lågl, إثني, _uhrw, 
   {{0x6b9c0175,0xd734074d,0x18680117,0x00000000}},	//   _yhsg, _кхаь, _рави_, --, 
   {{0xc3240075,0xd324db80,0xd5d4010a,0x00000000}},	//   لكىن_, рьки, _гiам, --, 
   {{0x2f2c0024,0x31840116,0x6298012d,0x96640120}},	//   _jėgų_, йтоң, _czwo, _ткае, 
   {{0x717400c6,0x629a29b7,0xdde0013d,0x00000000}},	//   إهدا, _dzwo, _şuşm, --, 
   {{0x7f4629b8,0x629802e2,0x2abc01e1,0x161c01ad}},	//   _boiq, _ezwo, _jábó_, पिकर_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x7f440007,0xae1400cc,0x63ac00df,0x00000000}},	//   _doiq, াম্ভ_, ĉant, --, 
   {{0x8d853953,0x41c00014,0xc0d000db,0xa294009f}},	//   румд, _بٲوِ, _ۇيۇب, _اُهڙ, 
   {{0x06d400bd,0xdb0405da,0x6b5001e6,0x61ec0115}},	//   _হাসি, _bikà, _fågl, _ĥali, 
   {{0x6b500267,0x7c940092,0x00000000,0x00000000}},	//   _vågo, _ቀድመው_, --, --, 
   {{0x88c629b9,0x7f483cc6,0x00000000,0x00000000}},	// [3fb10] لتال, _خليق_, --, --, 
   {{0xba741dc8,0x6b5001e3,0x35e0012d,0x00000000}},	//   زاقت, _tågo, _निज़, --, 
   {{0x5eec0a28,0x6d441730,0x24e801a9,0x00000000}},	//   _अयम्_, _ioha, ҳмли_, --, 
   {{0x6d4629ba,0x2ef817ef,0xaa58014b,0x00000000}},	//   _hoha, ngsf_, _биму_, --, 
   {{0x6d4629bb,0x6594a0d5,0x00000000,0x00000000}},	//   _koha, баду, --, --, 
   {{0x2abc01e1,0x5dd8008f,0x23d4084c,0x00000000}},	//   _fábó_, אַקס, бцир, --, 
   {{0x6d4629bc,0x6b50cbaf,0x98a800ef,0xa2e40132}},	//   _moha, _lågm, _dobē_, бойд, 
   {{0x6d44325f,0x21294398,0x200000b0,0xe1fa29bd}},	//   _loha, _şah_, _īhi_, гги_, 
   {{0x26de29be,0x316c5101,0x6d449da5,0xa2d41411}},	//   mawo_, fidz_, _ooha, _ۇيات, 
   {{0x6d4629bf,0x26de29c0,0x76640014,0x45a00617}},	//   _noha, lawo_, _ظُلم, _بەتك, 
   {{0x7f440077,0xa06a29c1,0xd5a4072d,0x00000000}},	//   _poiq, уана_, _اللی, --, 
   {{0x6d4400b0,0x6eec013f,0x4424004d,0xa0740150}},	//   _aoha, _yεbɔ, mvn_, _қылш, 
   {{0x6d4629c2,0xfe794d9b,0x2cac0213,0xdb0401e1}},	//   _boha, рүп_, əmdə_, _niká, 
   {{0x6d4629c3,0x236c0649,0x26de29c4,0x44240450}},	//   _coha, liej_, hawo_, ovn_, 
   {{0x224c00dd,0x6d4629c5,0x26de29c6,0x442629c7}},	//   lyek_, _doha, kawo_, nvn_, 
   {{0x236c068f,0xf838040b,0x6d4400e4,0x26dc1418}},	//   niej_, یزاں_, _eoha, jawo_, 
   {{0x26dc9e6f,0x224c00dd,0x6d4629c8,0xdb040f57}},	// [3fb20] dawo_, nyek_, _foha, _ciká, 
   {{0x6d4404ce,0x22580030,0x3ec80024,0x4aa4014b}},	//   _goha, úsky_, žutę_, скун_, 
   {{0x236c006d,0x26dc0099,0x39940267,0x28b800ab}},	//   kiej_, fawo_, läsk_, ेड़ि, 
   {{0x26de29c9,0x6d4629ca,0x224c0369,0x7940010e}},	//   gawo_, _zoha, kyek_, _jöwz, 
   {{0x6d4629cb,0xd0a001e1,0x00000000,0x00000000}},	//   _yoha, _pẹkẹ, --, --, 
   {{0x6d440005,0x224c01b8,0x98a401ee,0x00000000}},	//   _xoha, dyek_, _гиге, --, 
   {{0x06d400bd,0x316c00f3,0x6d400e03,0x44240208}},	//   _হারি, vidz_, ölai, gvn_, 
   {{0x316c4baa,0x236c0034,0x26dc058a,0x0874010f}},	//   widz_, giej_, cawo_, _העלט_, 
   {{0x224c00dd,0x07a229cc,0x00000000,0x00000000}},	//   gyek_, _хатн, --, --, 
   {{0x46442ac8,0xcee805d9,0x6b50007c,0x44240208}},	//   _узун_, گردن_, _rågm, bvn_, 
   {{0x6d4629cd,0xa96c001f,0x4424004d,0x41840023}},	//   _roha, _በየቀኑ_, cvn_, _ምጥፋእ_, 
   {{0x6d44006c,0x224d0147,0x236c0034,0x434007d8}},	//   _soha, byek_, ciej_, _нехв, 
   {{0x6d4629ce,0x8d7401ec,0xdb0400b5,0x161c01ad}},	//   _poha, ماسا, _kikæ, पिटर_, 
   {{0x26de29cf,0x01f80375,0x6b50007c,0x80a40154}},	//   zawo_, _עפול, _vågm, _গভর্, 
   {{0xdb0450e2,0x6d4629d0,0x4fc629d1,0x26de29d2}},	//   _siká, _voha, _усла, yawo_, 
   {{0x27e000ca,0x6d4629d3,0x6b50007c,0x00000000}},	//   vshn_, _woha, _tågm, --, 
   {{0x6f0e29d4,0x6d4629d5,0x8d840209,0x26dc0433}},	// [3fb30] _ibac, _toha, _гунд, vawo_, 
   {{0x236c006d,0x26de29d6,0x6e2e29d7,0xdd0c03be}},	//   ziej_, wawo_, _irab, mışd, 
   {{0x6e2c0bb3,0x224c0198,0xac98004b,0xdd0c0213}},	//   _hrab, zyek_, _خندا_, lışd, 
   {{0xdb0401ef,0x00000000,0x00000000,0x00000000}},	//   _tiká, --, --, --, 
   {{0x6f0c06c2,0x26dd60ec,0xdd0c00ac,0x6e2dc41f}},	//   _mbac, rawo_, nışd, _jrab, 
   {{0x67d629d8,0x6e2c46bc,0x4424004d,0x26de29d9}},	//   _могу, _mrab, tvn_, sawo_, 
   {{0xe35805c2,0xd3840873,0x6f0d0e2e,0x26de29da}},	//   ишиш_, ﺭﻟﯩﻖ_, _obac, pawo_, 
   {{0x6e2e29db,0xa5c80014,0xa1c629dc,0x44240208}},	//   _orab, _نورٕ_, обид, rvn_, 
   {{0x2488006d,0xa3e405f9,0x6e2c020c,0x6b500158}},	//   łam_, _भटक_, _nrab, _pågj, 
   {{0x6f0c5ea5,0x60082c9d,0x4425acbd,0xe0d80454}},	//   _abac, аном_, pvn_, шво_, 
   {{0x236c068f,0x6e2c1e56,0x6f0c0142,0x73c40a8e}},	//   piej_, _arab, _bbac, _فيلم, 
   {{0x344a29dd,0x9ea81f91,0x9f440270,0x2ee80fac}},	//   _учун_, ивна_, lulú_, _cdaf_, 
   {{0xf38c008f,0xd5d4010a,0xdb240241,0x00000000}},	//   _גראָ, _гiем, _àpér, --, 
   {{0x6e2e29de,0x6f0e29df,0x1278008f,0x399401e3}},	//   _drab, _ebac, _דאנע, räsk_, 
   {{0x6e2e29e0,0x69cc3b28,0x657c02d2,0x06bc00cc}},	//   _erab, epae, _íshu, _উজনি, 
   {{0x6e2c02fa,0x6f0c02e3,0x2b580129,0x3994005b}},	//   _frab, _gbac, _clsc_, mäsi_, 
   {{0x261800e1,0x399407d9,0x200629e1,0x28740124}},	// [3fb40] _मैली_, läsi_, ltli_, ҿыцр, 
   {{0x6f0c0cf4,0x7c3c0477,0x00000000,0x00000000}},	//   _zbac, pxrr, --, --, 
   {{0x200629e2,0x69cc013f,0xdca629e3,0x6e2c15f1}},	//   ntli_, apae, _фани, _zrab, 
   {{0x95c80124,0x00000000,0x00000000,0x00000000}},	//   аука_, --, --, --, 
   {{0x644629e4,0x6b8001ed,0x313c02d3,0x200629e5}},	//   ähin, élge, _ክገብር, htli_, 
   {{0xdb04013d,0x39940f23,0x200624c6,0x0f1400cd}},	//   _bikç, käsi_, ktli_, _तस्स_, 
   {{0x399402f6,0x200400f3,0x00000000,0x00000000}},	//   jäsi_, jtli_, --, --, 
   {{0x200629e6,0x6854036b,0x399400a2,0x00000000}},	//   dtli_, _عینآ_, däsi_, --, 
   {{0xdd0c0213,0xd14801b9,0x6b50007c,0x67c400c0}},	//   xışd, لشدن_, _sågk, _vėje, 
   {{0x6f0c19f5,0x24892828,0x6e2c031c,0x12e001ec}},	//   _sbac, şama_, _rrab, _ﺍﺩﻩﺭ, 
   {{0x6e2c0066,0x200404cc,0xdb0401e3,0x53380354}},	//   _srab, gtli_, _kikä, _вулă, 
   {{0x6e2c6e46,0xb8dc0003,0xdd0c0213,0x00000000}},	//   _prab, _ངུ_, tışd, --, 
   {{0xdb0564f5,0x6e2c0135,0x200401b9,0x6f0c01e7}},	//   _mikä, _qrab, atli_, _vbac, 
   {{0xc5f00bd4,0xdd0c00ac,0x2b580009,0xcee801d5}},	//   ודש_, rışd, _slsc_, درگن_, 
   {{0x20040048,0x00000000,0x00000000,0x00000000}},	//   ctli_, --, --, --, 
   {{0xd1ec2295,0x8cc8206b,0x2ee801bf,0xdd0c03e3}},	//   _ሁኔታ_, _त्रो, _udaf_, pışd, 
   {{0x6e2df9d7,0xecf80006,0x8d8401f0,0x00000000}},	// [3fb50] _urab, _лепш_, _муод, --, 
   {{0xe7380042,0x69cc067c,0xc9841422,0x082800c7}},	//   _chŵn_, rpae, цуби, ицеи_, 
   {{0xac955e7e,0xdb0420b2,0x6d403110,0x4c0000d1}},	//   _ханш, _bikä, ölau, _تېزل, 
   {{0x6d5401f5,0x00000000,0x00000000,0x00000000}},	//   lkza, --, --, --, 
   {{0xbc68034c,0xdb049ca3,0xf77229e7,0x659400f5}},	//   _همین_, _dikä, خال_, паду, 
   {{0x6b8e29e8,0x39940724,0x20040306,0xa004031c}},	//   loag, yäsi_, ytli_, _མྱྀང_, 
   {{0x65ac1682,0x200401b9,0x94400014,0xde7c0092}},	//   ṱhog, xtli_, ٹھٕن, _የዕድሜ_, 
   {{0x6b8c096b,0x3994023a,0x23a000c7,0x00000000}},	//   noag, väsi_, kóje_, --, 
   {{0xe1f00597,0xddc4068f,0x9f440418,0xc4440014}},	//   رسة_, zykł, pulú_, _ڈیشن_, 
   {{0x6b8e29e9,0x399402f6,0x200405d5,0x34480139}},	//   hoag, täsi_, ttli_, счән_, 
   {{0x6b8e29ea,0x04741d10,0x6b5001e3,0x00000000}},	//   koag, _بلاک_, _tågh, --, 
   {{0x200629eb,0x6b8c020b,0x6d5401a4,0x3994023a}},	//   rtli_, joag, ekza, räsi_, 
   {{0x20040316,0x53980375,0x899c01e1,0x6b8c005a}},	//   stli_, _פינו, _díẹ̀, doag, 
   {{0x3994005b,0x1d080063,0x00000000,0x00000000}},	//   päsi_, љеви_, --, --, 
   {{0x6b8c096b,0x91380302,0x63aa29ec,0x200401a9}},	//   foag, _לעסק, omen, qtli_, 
   {{0x6b8c01c4,0xdedc0023,0x9e5800ea,0xcb640108}},	//   goag, ዓመኒ_, _гроф_, пасе_, 
   {{0x63aa29ed,0xdb040309,0x2fa458c5,0xd1e00092}},	// [3fb60] imen, _rikä, _تصوّ, _ሐብት_, 
   {{0xdca44149,0x63aa29ee,0x8cc802ab,0x6d541196}},	//   _напи, hmen, तुदो, ckza, 
   {{0x63aa29ef,0x6b8c009d,0x669c02d3,0x00000000}},	//   kmen, boag, _ዝሓለፋ_, --, 
   {{0x63aa29f0,0x1fbc0eac,0xd5b80c98,0x00000000}},	//   jmen, _আবাস, бск_, --, 
   {{0x63aa29f1,0x00000000,0x00000000,0x00000000}},	//   dmen, --, --, --, 
   {{0x63aa29f2,0x25ec012d,0x00000000,0x00000000}},	//   emen, _घिरी_, --, --, 
   {{0xdb0629f3,0x63a8017a,0x00000000,0x00000000}},	//   _tikä, fmen, --, --, 
   {{0x6b503b3b,0x93880063,0x87040395,0x00000000}},	//   _pågi, љска_, _несв_, --, 
   {{0xd0640213,0xd598030d,0x00000000,0x00000000}},	//   əqəs, _дiаи, --, --, 
   {{0x63aa29f4,0x461000b2,0x6b8e29f5,0x865800d9}},	//   amen, _سومر, zoag, _הדמי, 
   {{0x63aa29f6,0x13080276,0x6b8c7851,0xd14801b9}},	//   bmen, _гней_, yoag, لشگن_, 
   {{0x63a88d75,0x6b8c01c4,0x00000000,0x00000000}},	//   cmen, xoag, --, --, 
   {{0x3ea001e7,0x6b8c005a,0x91a4004d,0x00000000}},	//   _czit_, voag, _trò_, --, 
   {{0x8bc43f72,0x41240117,0x00000000,0x00000000}},	//   зсад, _ночо_, --, --, 
   {{0x6b8c04c9,0x6d540cf9,0x4fc407d6,0xab9402bf}},	//   toag, rkza, _эсла, диві, 
   {{0x6b504cab,0xdb1001e1,0x00000000,0x00000000}},	//   _lågv, _ògìs, --, --, 
   {{0x6b8d90d5,0x6d40005b,0x00000000,0x00000000}},	// [3fb70] roag, ölas, --, --, 
   {{0x6b8dd2a7,0x3994000d,0xe6d417ee,0x00000000}},	//   soag, käsu_, दर्ज, --, 
   {{0xf990a55b,0x6b8e29f7,0xba0800d1,0xb95400db}},	//   ابق_, poag, قتەك_, رئكت, 
   {{0xdcb000db,0x63a80334,0xed5800de,0x8b640472}},	//   _جىپ_, xmen, īžu_, _راجم, 
   {{0x63aa29f8,0x67c400c0,0xb5c401ec,0xdb080ca8}},	//   vmen, _dėja, ейіл, _ìnáw, 
   {{0x63a8d46b,0x38880129,0xa8a40133,0xdc300171}},	//   wmen, étré_, _قڵاو, _gļēv, 
   {{0x63aa29f9,0x7d7c011a,0x00000000,0x00000000}},	//   tmen, זנגו, --, --, 
   {{0x63aa29fa,0x06d40011,0x67c40153,0x00000000}},	//   umen, _হাকি, _gėja, --, 
   {{0x13040108,0x92a40210,0x00000000,0x00000000}},	//   фный_, jgłę, --, --, 
   {{0x63aa29fb,0x2d8002c4,0xdfe82360,0x00000000}},	//   smen, _njhe_, одод_, --, 
   {{0x24541f3c,0xdbf0012c,0xe1f0030f,0x6aa00150}},	//   _تناس, třít, رسک_, _ﺃﻭﺴﻊ_, 
   {{0x836405d3,0x39940267,0x63aa29fc,0x60cc21d8}},	//   _عدال, läst_, qmen, _şamd, 
   {{0xab6c001f,0xc17409a5,0xd09003b9,0x00000000}},	//   _በሙያው_, _нҗи_, _müəz, --, 
   {{0xdca416c3,0xa13421f4,0x91b8011a,0x3ea001ef}},	//   даги, _زرتش, _ומסי, _vzit_, 
   {{0xdbf000bc,0x6b50007c,0x44c40200,0x00000000}},	//   přít, _lågu, _mё_, --, 
   {{0x39940267,0xdea001d3,0x6d4001e3,0x00000000}},	//   häst_, _لیجی, ölar, --, 
   {{0x13d400bd,0x1ea83cc6,0x1cb846c9,0x09e229fd}},	// [3fb80] সওয়, _باغي_, _وادب_, котн, 
   {{0xdb1c0023,0x67c40153,0xeab00736,0x44c4036e}},	//   _kupë, _sėja, اعِ_, _nё_, 
   {{0xdb040085,0x00000000,0x00000000,0x00000000}},	//   _mikú, --, --, --, 
   {{0xa3c052f2,0x7d1c0d90,0x6b500267,0x00000000}},	//   ंदन_, lers, _sågv, --, 
   {{0x7ae629fe,0x67c40006,0xec3407d6,0x3994007c}},	//   mait, _vėja, _قویگ, fäst_, 
   {{0x7d1e29ff,0x7ae62a00,0x3b000357,0x18682708}},	//   ners, lait, lgiq_, _даги_, 
   {{0x7d1c01c7,0x93a401a9,0x00000000,0x00000000}},	//   iers, мшид, --, --, 
   {{0x7d1e2a01,0x7ae62a02,0x1cbc0327,0x00000000}},	//   hers, nait, _ཆུའ_, --, 
   {{0x51862a03,0x6b5001e3,0x3994007c,0x00000000}},	//   дуна, _tågv, bäst_, --, 
   {{0x399417da,0xa0400023,0x44100166,0x00000000}},	//   mäss_, ፖጋንዳ, хфәт, --, 
   {{0x7ae62a04,0xacf800d1,0x00000000,0x00000000}},	//   kait, үнму_, --, --, 
   {{0x752a2a05,0xe2a82832,0x7ae42f7e,0x7d1c0194}},	//   _hadz, _کامن_, jait, eers, 
   {{0x752a2a06,0x7ae62a07,0x7f880213,0x7e280024}},	//   _kadz, dait, dıqd, міра_, 
   {{0xf40c0135,0x6b5048bb,0x752888d8,0x00000000}},	//   _གྱོད_, _lågt, _jadz, --, 
   {{0x752a2a08,0x7ae62a09,0x7058096f,0x908401ed}},	//   _madz, fait, _хайр_, _تمغے_, 
   {{0x7ae62a0a,0x752a2a0b,0x29100472,0x27ec01e4}},	//   gait, _ladz, _sbza_, _ĉen_, 
   {{0x6f1e2a0c,0x2d8001e0,0x9f440122,0xfe70004b}},	// [3fb90] mesc, _tjhe_, nulý_, _پدي_, 
   {{0x6f1e2a0d,0x7d1dde20,0x1cbc0135,0x7ae40124}},	//   lesc, cers, _ཆུར_, aait, 
   {{0x7ae62a0e,0x9cd40302,0x2d90181f,0xa6f40276}},	//   bait, _אותה_, moze_, езеш, 
   {{0x6f1e2a0f,0x7ae62a10,0x64a40022,0x00000000}},	//   nesc, cait, ҽала, --, 
   {{0x752a2a11,0x6abc127b,0x6f1d8902,0x63ac02f0}},	//   _badz, _igsf, iesc, ňank, 
   {{0x2d922a12,0x6f1e2a13,0x7528382c,0x3dfc0375}},	//   noze_, hesc, _cadz, קלוד, 
   {{0x68e62a14,0x6f1e2a15,0x1cbc031c,0xd5ac01d9}},	//   mahd, kesc, _ཆུལ_, حہٕ_, 
   {{0x2d90a183,0x68e62a16,0x6f1c0477,0x57200228}},	//   hoze_, lahd, jesc, _مۉمك, 
   {{0x2d903064,0x7d1d6997,0x7528c6c3,0xdb1d57e1}},	//   koze_, yers, _fadz, _dupè, 
   {{0x29022a17,0x752a2a18,0x6728020b,0x7ae62a19}},	//   ngha_, _gadz, _haej, zait, 
   {{0x7ae62a1a,0x6f1e2a1b,0x6728020c,0x26080789}},	//   yait, fesc, _kaej, lúo_, 
   {{0x22947d8a,0x6d880038,0x672a2a1c,0xdb0401e1}},	//   _كلاس, hľad, _jaej, _fikù, 
   {{0x7ae62a1d,0x7d1c2238,0x752838f4,0x2d9152b8}},	//   vait, ters, _yadz, foze_, 
   {{0x61ea2a1e,0x7d1d0ed4,0x68e446ef,0x6abc035a}},	//   msel, uers, jahd, _agsf, 
   {{0x7ae62a1f,0x6f1cdbdf,0x61e90192,0x63b8183a}},	//   tait, besc, lsel, _kiwn, 
   {{0x7d1e2a20,0x6f1e2a21,0x7ae40607,0xdb1c00c7}},	//   sers, cesc, uait, _kupé, 
   {{0x7ae62a22,0x7d1e2a23,0x68e404b6,0x63b80477}},	// [3fba0] rait, pers, fahd, _miwn, 
   {{0x61ea2a24,0x7d1c0869,0x6298004d,0xdb045522}},	//   isel, qers, _mywo, _likø, 
   {{0x7ae62a25,0x752a2a26,0x629800a9,0x69dc031c}},	//   pait, _radz, _lywo, _ewse, 
   {{0x752a2a27,0x61ea2a28,0xdb040158,0x57496c20}},	//   _sadz, ksel, _nikø, язем_, 
   {{0x752a2a29,0x67280007,0x61ea2a2a,0x29000135}},	//   _padz, _daej, jsel, bgha_, 
   {{0x61e800b5,0x1cbc0003,0x6f1e2a2b,0xdb140ac8}},	//   dsel, _ཆུས_, zesc, åbær, 
   {{0x75280e8a,0x66080784,0x6298035a,0xbf200490}},	//   _vadz, _eqek, _aywo, _बसून_, 
   {{0x752a2a06,0x2d905702,0xdb1c003e,0x61e9c128}},	//   _wadz, zoze_, _bupé, fsel, 
   {{0x6f1e2a2c,0x75290ed2,0x2d922a2d,0x06d4009e}},	//   vesc, _tadz, yoze_, _হাচি, 
   {{0x6f1c0a40,0x5064147e,0x6298015d,0xb0340063}},	//   wesc, етма, _dywo, внош, 
   {{0x6f1e2a2e,0x61ea2a2f,0x62980857,0xe504d9e5}},	//   tesc, asel, _eywo, _राति_, 
   {{0x61e81d9e,0x62980042,0x2d901418,0x9f4401d3}},	//   bsel, _fywo, woze_, duló_, 
   {{0x2d922a30,0xbac401ec,0xe1f80133,0x68e40455}},	//   toze_, _ﯨﺴﺘﺎ, _قبوڵ_, yahd, 
   {{0x6b500628,0x6f1e2a31,0xac180826,0x7c38110c}},	//   _någr, sesc, могу_, _švra, 
   {{0x6f1e2a32,0xac962a33,0xef100228,0x68e4023a}},	//   pesc, тавш, _күнө, vahd, 
   {{0x2d922a34,0x40980375,0xcfa40131,0x6b5001e3}},	//   soze_, _מבוס, _яшли, _rågs, 
   {{0x2d90406e,0x2384005f,0x68e4005b,0x67280108}},	// [3fbb0] poze_, nēja_, tahd, _raej, 
   {{0xfbd0066d,0x6c540022,0x672800b5,0x2d90009a}},	//   شتہ_, _акоу, _saej, qoze_, 
   {{0x68e44702,0x5b000131,0x9f440789,0xb80800c6}},	//   rahd, _ھېكم, culó_, فيلم_, 
   {{0x68e62a35,0x6b50c424,0x2900031c,0x00000000}},	//   sahd, _vågs, sgha_, --, 
   {{0xa5c40220,0x68e4023a,0xdb240248,0x46300022}},	//   төбе, pahd, _àpár, ыҭар, 
   {{0x2b480989,0x61ea2a36,0x672805b1,0x2384005f}},	//   ljac_, vsel, _waej, dēja_, 
   {{0x61ea2a37,0xdb1c20ef,0x6728020c,0x63b8033f}},	//   wsel, _supé, _taej, _piwn, 
   {{0x61e90407,0x2b480b91,0xe3b00b24,0xc6d40fb4}},	//   tsel, njac_, جرت_, _سترت, 
   {{0xdb062a38,0x61ea2a39,0x6144010b,0x00000000}},	//   _shkë, usel, вепа, --, 
   {{0x61e92375,0x0464084c,0x63b80142,0xfa98010f}},	//   rsel, _птем, _wiwn, עדזש_, 
   {{0x62980034,0x65600857,0xa068119e,0xdb0401bf}},	//   _wywo, _illh, фана_, _tikø, 
   {{0x61ea2a3a,0x3f8400c5,0x238400e2,0x629803cb}},	//   psel, õmu_, bēja_, _tywo, 
   {{0x2b482625,0x238400e2,0xeff00023,0xe124014b}},	//   djac_, cēja_, ሃለወ_, _амли, 
   {{0x2a6a2a3b,0x63ac1418,0xa058007b,0x127800df}},	//   dzab_, ŋand, _يؤثر_, _קאסע, 
   {{0x1ae40798,0xda6400ec,0x00000000,0x00000000}},	//   ковм, ھاري, --, --, 
   {{0xda6400ec,0x9f4400e5,0x00000000,0x00000000}},	//   پاري, ruló_, --, --, 
   {{0x6b50e863,0xdd8a2a3c,0x656002d0,0xe1f800c0}},	// [3fbc0] _pågr, _обид_, _ollh, nrų_, 
   {{0xa3c02c97,0x9f462a3d,0x98540137,0x413c0023}},	//   ंदा_, culò_, ктеш, _ክወሃቦ, 
   {{0x2384005f,0xd708023a,0xdb8401af,0x6b5001e3}},	//   zēja_, днее_, _агни, _vågr, 
   {{0x6561c08c,0xe1f80024,0xa3e402e5,0xdb140267}},	//   _allh, krų_, _बौध_, åbär, 
   {{0x6b5001e3,0x00000000,0x00000000,0x00000000}},	//   _tågr, --, --, --, 
   {{0x2384005f,0xe1f80153,0x00000000,0x00000000}},	//   vēja_, drų_, --, --, 
   {{0xd7042461,0xb9ec0023,0x97b401c6,0x85b00131}},	//   _изви, _ንህ_, _асаш, рәтч, 
   {{0x65622a3e,0x238400e2,0xb1900131,0x00000000}},	//   _ellh, tēja_, әһкә, --, 
   {{0x60cdd49a,0x67900214,0x82a0035b,0xe1f80064}},	//   _şama, _اینط, ишье, grų_, 
   {{0xd5ac00f8,0x238400da,0x6b5010d1,0x41500108}},	//   _بہت_, rēja_, _lågp, ивыс, 
   {{0x2a6805b1,0x13040137,0x238400e2,0x944400ec}},	//   zzab_, _азем, sēja_, _جپان, 
   {{0x238400e2,0xe478010f,0x98a80064,0x2bd80014}},	//   pēja_, _אָנש, _lobį_, ہارک_, 
   {{0x8d762a3f,0x00000000,0x00000000,0x00000000}},	//   ناسا, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xc04d7606,0x07105690,0x2ca40267,0x00000000}},	//   _ті_, ण्डव_, åld_, --, 
   {{0x7b662a40,0x717400ec,0x00000000,0x00000000}},	//   атуе, _جهڪا, --, --, 
   {{0x2b48058a,0xad8400db,0x3a54022e,0x00000000}},	// [3fbd0] rjac_, _مادۇ, актё, --, 
   {{0x6cd47ff6,0x00000000,0x00000000,0x00000000}},	//   _حقدا, --, --, --, 
   {{0x7f880724,0xfe700b28,0xd76401d5,0x0ca80395}},	//   lıqa, _هدی_, گننی, _ютии_, 
   {{0xf40800bd,0xe504000d,0xe1f80153,0xd3641c43}},	//   লবার_, _राहि_, yrų_, _طه_, 
   {{0xd245b3eb,0xa3e42cd1,0x9aa400d1,0x00000000}},	//   _ان_, बीन_, _бурһ, --, 
   {{0x24097103,0xbf20012c,0x00000000,0x00000000}},	//   енки_, _बस्न_, --, --, 
   {{0x26c80005,0x37c406ed,0x639402e8,0x00000000}},	//   ñaos_, _вљуб, лшиф, --, 
   {{0xe1f80006,0x00000000,0x00000000,0x00000000}},	//   trų_, --, --, --, 
   {{0x65600770,0xdb040306,0x1708179e,0x11d400ae}},	//   _tllh, _niký, _سفلی_, هوية_, 
   {{0x65607209,0x00000000,0x00000000,0x00000000}},	//   _ullh, --, --, --, 
   {{0xdee444e4,0x4fe459e6,0x62640075,0x0fc000ee}},	//   лони, лмэн_, _әвла, ййэн, 
   {{0xc974001f,0xe1f80153,0x00000000,0x00000000}},	//   _በከፊል_, prų_, --, --, 
   {{0xa1580114,0x00000000,0x00000000,0x00000000}},	//   _паду_, --, --, --, 
   {{0x50a00131,0xdb0400a2,0x06bc0154,0xd00c00f1}},	//   _گەپل, _diký, আরটি, _ځلو_, 
   {{0xd00c1a73,0x06e000e1,0x00000000,0x00000000}},	//   _فلو_, खराव_, --, --, 
   {{0x15d00ed1,0x50a015bf,0x9f94000d,0x9f400248}},	//   ﻟﻪﺭﺩ, _دەپل, nüül_, _ìhà_, 
   {{0x5f741a4b,0x7f880213,0x598464cb,0x6df8009d}},	// [3fbe0] _لاکر, cıqa, глаб, _ихэс_, 
   {{0x645c00ac,0x8d7401ec,0x9f4401e7,0x00000000}},	//   _əsir, _ماپا, islí_, --, 
   {{0x6b5001e3,0xdb0401d3,0x7795904c,0x00000000}},	//   _tågp, _kikü, لیسا, --, 
   {{0x238400da,0xdb1c0c5e,0x2ca40205,0x15cc01ec}},	//   dējo_, _kupí, ülde_, _ﻗﻮﺭﻩ, 
   {{0xe50409d9,0x26c40075,0x5a5400a7,0xdb1c01ef}},	//   _राशि_, рғун_, _съну, _jupí, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0xdb1c01ef,0x00000000,0x00000000,0x00000000}},	//   _lupí, --, --, --, 
   {{0xd6dc009e,0xb3540c60,0xf4840116,0x00000000}},	//   _ডাকয, ркиш, луқн, --, 
   {{0x8b54008d,0xdb040022,0x7c3816a3,0x833001c0}},	//   טיקס_, _hikó, _švrl, сных, 
   {{0x3014a43f,0xdb1c054e,0x95940114,0x22580162}},	//   адор, _jupâ, _србљ, øska_, 
   {{0x438001d5,0xfbb40bae,0x19d00150,0x644401f4}},	//   شلیق, ंगाम, _ﺘﻨﻔﺠ, ähit, 
   {{0xa3c03a19,0x91e40124,0x8f4401f4,0x00000000}},	//   ंदर_, _боде, уход, --, 
   {{0xdb040085,0x00000000,0x00000000,0x00000000}},	//   _likó, --, --, --, 
   {{0xc690008d,0xdb062a41,0xe2a801d9,0x260401ad}},	//   מאר_, _oikó, _شانن_, हंती_, 
   {{0x85380a1e,0xdb05b4ef,0xc198011a,0x6044010a}},	//   עגלי, _nikó, _רשוי, _кĕрх, 
   {{0x7f880724,0x7ff0007b,0xdb0400a2,0x00000000}},	//   lıqn, _اسوا, _tiký, --, 
   {{0xdb0400c7,0x9f500241,0xdbb40150,0x00000000}},	// [3fbf0] _aikó, _ìbás_, ратө, --, 
   {{0xdb040296,0xa214010f,0xc7c4009d,0x00000000}},	//   _bikó, יַעס_, гсди, --, 
   {{0x1cbc031c,0x66d400ec,0x00000000,0x00000000}},	//   _ཆུག_, ليائ, --, --, 
   {{0xc7640131,0x9f4402f0,0x00000000,0x00000000}},	//   دائى, yslí_, --, --, 
   {{0xe5b410e0,0xa509fca4,0xc98401b9,0x88c4007b}},	//   айды, вела_, _буви, _متأل, 
   {{0xa3c006ab,0x2384005f,0x499001d3,0xaa400023}},	//   ंदल_, tējo_, _ایئر, _ከመሓላ, 
   {{0x232801b9,0xc8340092,0x64a49aea,0x60cc0139}},	//   войи_, _የሚሆን, шака, _şamo, 
   {{0xe29a2a42,0x986847af,0x238400e2,0x26040412}},	//   кай_, lığa_, rējo_, हंदी_, 
   {{0x26dcad0c,0xe1242c31,0xa3e402e5,0x9f94000d}},	//   mbwo_, ампи, _बौर_, rüül_, 
   {{0xdb0801f1,0xdb1c00c7,0x238400e2,0x161c00e1}},	//   ľnéh, _rupí, pējo_, _मैटर_, 
   {{0xa0a44db3,0xdb080122,0x9f85063f,0xd1e40150}},	//   ранд, žnéh, игод, _ۆينۋ, 
   {{0x83500014,0xdb1c0118,0x44240042,0xd05806be}},	//   _چھکا, _pupí, mwn_, natə, 
   {{0x1cbc0ed9,0x61462a43,0x44262a44,0xdb0400e4}},	//   _ཆུང_, _вела, lwn_, _oikò, 
   {{0x44240175,0x20541b0a,0x4e2400d8,0x00000000}},	//   own_, _втир, јорн_, --, 
   {{0xdcb09067,0x44240368,0x38ac0248,0xa069ff00}},	//   زىر_, nwn_, _mórí_, _шака_, 
   {{0x38ac110e,0x442404e6,0x6aa00150,0xff240ed8}},	//   _lórí_, iwn_, _ﺃﺭﺒﻊ_, _طبعی, 
  
   {{0x44240042,0x7cf002d2,0x00000000,0x00000000}},	// [3fc00] hwn_, górí, --, --, 
   {{0x98a40022,0xfd240244,0x00000000,0x00000000}},	//   аизе, _اودێ, --, --, 
   {{0xdb1c00d8,0x0a3c0023,0xd8240124,0x00000000}},	//   _cupã, _ሓዋርያ, рдеи, --, 
   {{0x73d82d2e,0x44262a45,0xb7b401c6,0x60cc4dd9}},	//   қдир_, dwn_, сөгч, _şaml, 
   {{0x38ac0241,0xdb1c00c7,0x44240036,0x98680139}},	//   _bórí_, _tupâ, ewn_, bığa_, 
   {{0x26dc04ba,0x44240042,0x98680205,0x6d8800d7}},	//   abwo_, fwn_, cığa_, hľan, 
   {{0x799c0472,0x44244019,0x38ac0248,0x3ea001e7}},	//   _ikrw, gwn_, _dórí_, _lyit_, 
   {{0x7f8800ac,0x3cb803d4,0x00000000,0x00000000}},	//   dıqo, _অভাৱ, --, --, 
   {{0x38ac01e1,0x44240b88,0xc4800bd6,0x3ea000e5}},	//   _fórí_, awn_, йләк, _nyit_, 
   {{0x44240399,0x6d880030,0xd13a2a46,0x98a82e05}},	//   bwn_, eľan, тхи_, _कराए, 
   {{0x56940184,0x3ea0007f,0xf2e801d5,0xe3b00050}},	//   _саҡт, _ayit_, _یککه_, _کرٕ_, 
   {{0x799c02d0,0x8350085b,0xc204072d,0x4340014b}},	//   _lkrw, _وپلا, دقین_, _мехв, 
   {{0x216400fb,0x4ea401f4,0x00000000,0x00000000}},	//   ртөг, ррна, --, --, 
   {{0x7f881565,0x61fc3b7b,0x3204010b,0x00000000}},	//   lıql, ásle, mumy_, --, 
   {{0x6d8800d7,0x32040432,0x00000000,0x00000000}},	//   bľan, lumy_, --, --, 
   {{0x799c009a,0xebc40022,0xff50009a,0x999000a2}},	//   _akrw, _ҳәан, _يخي_, ltyň_, 
   {{0x6f0cb838,0x320416b8,0xdb040100,0x44262a47}},	// [3fc10] _icac, numy_, _pikò, zwn_, 
   {{0x6e2e0f2b,0x44247e04,0xf990163e,0x7e6021e3}},	//   _isab, ywn_, وبل_, ømpe, 
   {{0xf7701973,0x38c84ecc,0xede4036b,0x8d740131}},	//   ڈان_, руун_, _тўқн, _ماھا, 
   {{0x3205ef11,0x38ac0ca8,0x60cc013d,0xe73800d8}},	//   kumy_, _sórí_, _ğamm, ѓел_, 
   {{0x3950037e,0x7f8800ac,0x6e2c031c,0x06262a48}},	//   ælsø_, dıql, _jsab, рфем, 
   {{0x6e2cc53d,0x69cc0369,0xdb1c0588,0x2eea2a49}},	//   _msab, mqae, _tupã, _leaf_, 
   {{0x6f0db7b3,0xdb1c00e4,0x87042401,0x65ac0118}},	//   _ocac, _hupá, _вязе, júhe, 
   {{0x6e2e2a4a,0xdb1400b5,0x2a6c0f91,0x44262a4b}},	//   _osab, åbør, _žeby_, rwn_, 
   {{0x6e2e2a4c,0x38ac0ca8,0x442403cb,0x9990010e}},	//   _nsab, _tórí_, swn_, ftyň_, 
   {{0x999000ee,0x2ee80042,0x799c02d0,0xd0b006be}},	//   gtyň_, _aeaf_, _xkrw, lğəm, 
   {{0x5f441291,0x7f888af3,0x00000000,0x00000000}},	//   مندل, bıql, --, --, 
   {{0xa0a62a4d,0x3204c466,0x6f0c0083,0x2ee80175}},	//   _қайд, bumy_, _ccac, _ceaf_, 
   {{0xd00d1488,0x6e2d0992,0x2ee89337,0xeb580092}},	//   ولی_, _csab, _deaf_, _ያረጋገ, 
   {{0x6f0c1cdf,0x6b9c02d0,0xa6cc00eb,0x00000000}},	//   _ecac, _aksg, ারিয়, --, 
   {{0xdee407d6,0x6e2e2a4e,0xd12c31ed,0xdca62a4f}},	//   _лойи, _esab, _سمي_, сави, 
   {{0x20062a50,0x6f0c00ca,0x2124180f,0x1ef8007b}},	//   muli_, _gcac, lelh_, _صعبة_, 
   {{0x7f462a51,0x20062a52,0xdb1c007b,0xcf9005d0}},	// [3fc20] _iniq, luli_, _cupá, _מטה_, 
   {{0x200406c8,0x6b9c0115,0x41dc02ab,0x7f8800fd}},	//   ouli_, _eksg, पीएस, zıql, 
   {{0x20041326,0xd5d40150,0x7ac40117,0x1c5403e0}},	//   nuli_, _бiлм, _минҷ, çüğü, 
   {{0x7bde2a53,0x6e2c0ffb,0x20040270,0xe7d401d5}},	//   mpru, _ysab, iuli_, زمهگ, 
   {{0x20062a54,0xa3e41715,0x6e2c05b1,0xbbb40490}},	//   huli_, बीस_, _xsab, ंगीक, 
   {{0xfd5001f2,0xf1c80051,0x799c0210,0x00000000}},	//   _rahụ, _bỡn_, _ukrw, --, 
   {{0x20062a55,0x7bdcc95e,0xf1c80051,0x18680114}},	//   juli_, npru, _cỡn_, _сави_, 
   {{0xd324090b,0xc3247a32,0x32042f5d,0xcc38008f}},	//   ськи, مكىن_, tumy_, רעקט, 
   {{0xb2740853,0x7f886656,0xe6080592,0xe7380142}},	//   юлиш, rıql, _نزلو_, _thŵr_, 
   {{0x20062a56,0x6f0e2a57,0x7f4407d6,0x71780228}},	//   fuli_, _scac, _aniq, рбор_, 
   {{0x6e2c2f99,0x0fe000f7,0x6f0c01ab,0x71440023}},	//   _ssab, чөлү, _pcac, _ንወለዶ, 
   {{0xd5bc00e2,0x7bdc0306,0x67c40153,0x88b80677}},	//   žāda_, dpru, _gėju, טזיי, 
   {{0x20040421,0x00000000,0x00000000,0x00000000}},	//   auli_, --, --, --, 
   {{0x20061b1d,0x7f44014b,0xb90c063f,0x661c023a}},	//   buli_, _eniq, rahụ_, _äske, 
   {{0x20062a58,0xd0b003be,0x9f4403b2,0x8114011a}},	//   culi_, yğəm, sslá_, _החוג_, 
   {{0x6e2e2a59,0x6f0e2a5a,0xdb1c0241,0x00000000}},	//   _tsab, _ucac, _pupá, --, 
   {{0x6e2e2a5b,0x88c464e6,0x7bdc01f5,0xbb84007b}},	// [3fc30] _usab, متال, apru, سلكي, 
   {{0x0c840209,0xdcec0064,0xc97400ae,0x00000000}},	//   _гымм, kibę, حارث, --, 
   {{0x6d462a5c,0x48aa2a5d,0xe8680092,0x00000000}},	//   _inha, утам_, ተርጎም_, --, 
   {{0xf1c8193d,0xdb1c00e4,0x00000000,0x00000000}},	//   रदान, _tupá, --, --, 
   {{0x20062a5e,0x69cc0194,0x24e801d5,0xe4c401a9}},	//   zuli_, qqae, амли_, ойли, 
   {{0x23d48937,0x74740882,0x238400e2,0x00000000}},	//   оцир, _śreṣ, mēji_, --, 
   {{0x1cbc003d,0x6d440098,0xa3483da1,0x21240ba1}},	//   _ཆུབ_, _mnha, изка_, velh_, 
   {{0xe1f92fb2,0x20062a5f,0x40cc0241,0xba04069d}},	//   аги_, vuli_, _lẹtọ_, _ዌብ_, 
   {{0x200400aa,0x6d462a60,0x67c40153,0x6d8800d7}},	//   wuli_, _onha, _vėju, eľam, 
   {{0x20062a61,0x7bdc014b,0x42a00023,0xc51400f1}},	//   tuli_, ypru, _ሊንክስ_, _دبرت, 
   {{0x4ea40020,0x2010019f,0x2124180f,0x04651d0b}},	//   _ማስረጃ_, îzi_, relh_, _утам, 
   {{0x6d462a62,0x00000000,0x00000000,0x00000000}},	//   _anha, --, --, --, 
   {{0x20062a63,0xa3e434ef,0xfe7803cc,0x1238004b}},	//   suli_, बीर_, сүп_, _پتنګ_, 
   {{0x20062a64,0x1cbc0003,0x98a8005f,0x6144a20e}},	//   puli_, _ཆུད_, _labā_, _фека, 
   {{0x20062a65,0xdb0401ed,0xdb0800bc,0xfd500055}},	//   quli_, _mikö, žníh, _mahḥ, 
   {{0x6d462a66,0xe80c05ba,0x7f462a67,0x7bdc02d2}},	//   _enha, ांना_, _uniq, rpru, 
   {{0x7bde2a68,0xcb640276,0x00000000,0x00000000}},	// [3fc40] spru, цате_, --, --, 
   {{0x7bdc0003,0x2cac012c,0x0d8012b9,0xdca400f0}},	//   ppru, ředa_, _олын, _мапи, 
   {{0x1c1c007d,0xd7082838,0x00000000,0x00000000}},	//   _पहिल_, инже_, --, --, 
   {{0x236e2a69,0xf9c4010b,0x23840171,0x00000000}},	//   jhej_, _намү, bēji_, --, 
   {{0x9b898440,0x236c02d3,0x6d44000f,0x6d880030}},	//   _منگل_, dhej_, _ynha, dľaj, 
   {{0x224c005a,0x6d8800d0,0x00000000,0x00000000}},	//   dxek_, eľaj, --, --, 
   {{0x224c01c6,0x13680107,0x04400120,0x00000000}},	//   exek_, ишии_, дејн, --, 
   {{0x39580231,0xdb0402f6,0x93881614,0x1cbc025c}},	//   _hors_, _eikö, јска_, _ཆུན_, 
   {{0x9149ae02,0x395942e6,0x67440118,0x06cc00fe}},	//   ачна_, _kors_, šují, ৱণশি, 
   {{0xdb040793,0x3958017a,0x8454151e,0x00000000}},	//   _gikö, _jors_, срәт_, --, 
   {{0x395a2a6a,0x417059c8,0x6d462a6b,0x53a56974}},	//   _mors_, بايس, _rnha, _дажб, 
   {{0x3958c735,0x236e2a6c,0x8c4c0023,0x6e945bc6}},	//   _lors_, chej_, _ኣመጻጽ, зиму, 
   {{0x39581c1d,0xc0f40023,0x2398132f,0x00000000}},	//   _oors_, _ፈሺሉ_, _امنگ_, --, 
   {{0x39580953,0x238400e2,0x66d0032e,0x00000000}},	//   _nors_, vēji_, _kókó, --, 
   {{0x7c34239a,0xb5c001ec,0x00000000,0x00000000}},	//   мерх, _ﺠﺎﻤﻌ, --, --, 
   {{0x238400e2,0xdb14007f,0x60cc0139,0x00000000}},	//   tēji_, nmyè, _ğami, --, 
   {{0x395a2a6d,0x60cd2524,0x00000000,0x00000000}},	// [3fc50] _bors_, _şami, --, --, 
   {{0x395a2a6e,0x6d44c194,0x00000000,0x00000000}},	//   _cors_, _unha, --, --, 
   {{0x395a2a6f,0x236c036e,0x29cc00d7,0x00000000}},	//   _dors_, yhej_, _kľak_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x3959c818,0x224c011f,0xdb140100,0x0ba811dc}},	//   _fors_, xxek_, dmyè, _ماڭى_, 
   {{0xe3b8053f,0xbc391cc1,0x395a2a70,0xf1c80051}},	//   әби_, _اسیا_, _gors_, _cỡm_, 
   {{0x3688804b,0x236c036e,0x00000000,0x00000000}},	//   йсән_, thej_, --, --, 
   {{0x37040640,0x224c01c6,0x00000000,0x00000000}},	//   _очув, txek_, --, --, 
   {{0xe7380220,0x66e4151e,0x2b58e031,0x00000000}},	//   _кең_, _моңа, _mosc_, --, 
   {{0x60089fc8,0x2b5806af,0x224c01c4,0x236c0240}},	//   бном_, _losc_, rxek_, shej_, 
   {{0x1ec95fe4,0x00000000,0x00000000,0x00000000}},	//   йлни_, --, --, --, 
   {{0x2584025a,0x00000000,0x00000000,0x00000000}},	//   bëlä_, --, --, --, 
   {{0x3ea40008,0x74d8687b,0x8284072d,0xf38c010f}},	//   æmt_, नुवृ, _بجال, _דראָ, 
   {{0xdb04006a,0xd25406a9,0xe3b801d3,0x00000000}},	//   _likô, _משנה_, lmű_, --, 
   {{0x2b5800f7,0x8c4010e2,0x395804cc,0x29cc00d7}},	//   _bosc_, нере, _rors_, _fľak_, 
   {{0x395a2a71,0x5ac803b7,0x2b5800c6,0xdb040109}},	//   _sors_, слам_, _cosc_, _nikô, 
   {{0x9b4400dd,0x395a2a72,0x1d083169,0x2b58012d}},	// [3fc60] _ہندو, _pors_, _лепи_, _dosc_, 
   {{0x238400e2,0x6d880419,0x00000000,0x00000000}},	//   mēju_, jľah, --, --, 
   {{0xdca62a73,0x2b5a2a74,0x3959aced,0x7e602ba9}},	//   _хани, _fosc_, _vors_, ämpf, 
   {{0x3959c817,0x95c8acf9,0x29100205,0x8bd4011a}},	//   _wors_, бука_, _ecza_, _מוטו_, 
   {{0x7ae62a75,0x395a2a76,0x98a8054e,0x4a400d30}},	//   mbit, _tors_, _babă_, _зняв, 
   {{0x7ae62a77,0x39580c86,0x44f015bf,0x00000000}},	//   lbit, _uors_, ىسىز, --, 
   {{0x7ae41559,0xa5080131,0xdb1c00e4,0xd3783612}},	//   obit, زىيە_, _tupä, йчи_, 
   {{0x07a142e5,0x7ae4dedc,0x65ac0030,0xc7a000d8}},	//   _засн, nbit, rúha, _зиск, 
   {{0x7ae44d72,0x238400e2,0x71b40798,0x00000000}},	//   ibit, jēju_, мбиф, --, 
   {{0x7ae40209,0x22580267,0x238400e2,0xc170023a}},	//   hbit, äska_, dēju_, ельщ, 
   {{0x04d80375,0x00000000,0x00000000,0x00000000}},	//   _הקבל, --, --, --, 
   {{0x61400022,0x238400ef,0x00000000,0x00000000}},	//   еҵәа, fēju_, --, --, 
   {{0x2b583b17,0x00000000,0x00000000,0x00000000}},	//   _rosc_, --, --, --, 
   {{0xe2a801d9,0x7ae62a78,0x00000000,0x00000000}},	//   _بامن_, ebit, --, --, 
   {{0x2ca62a79,0x7ae40254,0x999000a2,0x00000000}},	//   æld_, fbit, gtyō_, --, 
   {{0x7ae62a7a,0x238400e2,0x764003ac,0x6fb401d3}},	//   gbit, bēju_, _ormy, _تمبا, 
   {{0x705401d9,0x238400e2,0x0af001c6,0xa93401f0}},	// [3fc70] _رچھا, cēju_, _үүгэ, меаш, 
   {{0x6f1e2a7b,0x00000000,0x00000000,0x00000000}},	//   lfsc, --, --, --, 
   {{0x7ae62a7c,0x76422a7d,0xb9c400c6,0x6e3c0158}},	//   bbit, _army, رقمي, lvsb, 
   {{0xd3641af6,0xcb0802f6,0x32040216,0x61ed15df}},	//   _شه_, _уход_, krmy_, _çalg, 
   {{0x6b8e2a7e,0x6e3c0175,0x6f1c002f,0x00000000}},	//   mnag, nvsb, ifsc, --, 
   {{0x69de2a7f,0xdb0402f6,0xe80c0490,0x00000000}},	//   _itse, _ehkä, ांदा_, --, 
   {{0xd24c006c,0x6b8c1368,0x76408048,0x2fdc01f5}},	//   یچه_, onag, _ermy, _ntvg_, 
   {{0x6b8e2a80,0x05743ccd,0x6f1c01a4,0xc6a49607}},	//   nnag, _کارد, jfsc, _ерзи, 
   {{0x6b8e2a81,0xe3b801ed,0xc4c425ef,0x962801d3}},	//   inag, rmű_, _فتاو, _وقفے_, 
   {{0x69de2a82,0x6f1c01a4,0x2384005f,0x6b8e2a83}},	//   _mtse, efsc, vēju_, hnag, 
   {{0xa0c40220,0x046401b9,0x6f1e0168,0x68e44230}},	//   بيدو, _этам, ffsc, ibhd, 
   {{0x64422a84,0x69de2a85,0x238400e2,0x00000000}},	//   _irli, _otse, tēju_, --, 
   {{0x69de2a86,0xbf1801e1,0x13e003d4,0x64405145}},	//   _ntse, _aṣís, _যিয়, _hrli, 
   {{0xa06a25ff,0x6f1c2d3e,0x238400e2,0x6b8c1368}},	//   _мала_, afsc, rēju_, enag, 
   {{0x69de2a87,0x7ae5967e,0x6d8800a1,0x3f846c80}},	//   _atse, tbit, džad, éjus_, 
   {{0x63a8d963,0x238400e2,0x64400010,0x5ba802d5}},	//   nlen, mējs_, _mrli, ікам_, 
   {{0x7ae62a88,0x63aa2a89,0x31b005da,0x61ed2828}},	// [3fc80] rbit, ilen, làza_, _çald, 
   {{0x7ae62a8a,0x3aec001e,0x6b8c0731,0x6441732e}},	//   sbit, ếp_, anag, _orli, 
   {{0x69de2a8b,0xd7e80220,0x238400e2,0x7ae4007c}},	//   _etse, імде_, nējs_, pbit, 
   {{0x63aa2a8c,0x6b8c0076,0x68e40332,0x00000000}},	//   jlen, cnag, abhd, --, 
   {{0x69dc0998,0x63aa2a8d,0xd5ba2a8e,0x20062a8f}},	//   _gtse, dlen, оск_, hrli_, 
   {{0x63aa2a90,0x6440107d,0xa6140022,0x3cec012d}},	//   elen, _brli, хзшә, _जजों_, 
   {{0x63aa2a91,0x200405be,0x36c801e0,0x7f8806be}},	//   flen, jrli_, _еңеп_, lıqu, 
   {{0x63aa2a92,0x69dc002d,0x20062a93,0xf1c8004d}},	//   glen, _ytse, drli_, _hỡi_, 
   {{0x64422a94,0x2004011c,0xe33000d0,0x2fdc002f}},	//   _erli, erli_, áčať_, _stvg_, 
   {{0x3f822a95,0x672c0115,0x2678009d,0x200400a2}},	//   _amiu_, ĵaje, _эссэ_, frli_, 
   {{0x63aa2a96,0x6b8c0731,0x64400552,0x200407f5}},	//   blen, ynag, _grli, grli_, 
   {{0x224808ad,0x63aa2a97,0x73343256,0x6f1c0e78}},	//   _šake_, clen, _سىتا, ufsc, 
   {{0x20062a98,0x6f1c5475,0x999000d7,0x00000000}},	//   arli_, rfsc, zvyš_, --, 
   {{0x6e3e2a99,0x6b8c00ad,0x7a3800e5,0x6d880419}},	//   rvsb, wnag, zútá, hľav, 
   {{0xe57004ac,0x6b8e2a9a,0x6f1c03fa,0x69de2a9b}},	//   אַן_, tnag, pfsc, _stse, 
   {{0x6b8e2a9c,0xe9d8010b,0x00000000,0x00000000}},	//   unag, змач_, --, --, 
   {{0x6b8e2a9d,0x6d8800d7,0x00000000,0x00000000}},	// [3fc90] rnag, dľav, --, --, 
   {{0x63a841b5,0x6b8e2a9e,0x7e603672,0xf1c80051}},	//   zlen, snag, ämpe, _bỡi_, 
   {{0x63aa2a9f,0x2fc80457,0x2d8000a3,0x68e400a3}},	//   ylen, _kiag_, _imhe_, rbhd, 
   {{0x63a80408,0x2fc80218,0x6b8c022e,0xd7080116}},	//   xlen, _jiag_, qnag, كىمۇ_, 
   {{0x69dc11ad,0x63aa2aa0,0x3a754d0c,0x238400e2}},	//   _utse, vlen, _аляр, zējs_, 
   {{0x2fca2aa1,0x20062aa2,0x63aa2aa3,0x6d8801a6}},	//   _liag_, yrli_, wlen, lžab, 
   {{0x2d8005b1,0x200401d5,0x00000000,0x00000000}},	//   _mmhe_, xrli_, --, --, 
   {{0x644005a1,0x63aa2aa4,0x2fc80070,0xdb1c0077}},	//   _vrli, ulen, _niag_, _supú, 
   {{0x26cc010a,0x466000d1,0xd04803b9,0xfbe00154}},	//   _igeo_, _جۇشق, _iffə, _বয়াত, 
   {{0x3f800158,0xb5440588,0x6b8001f2,0x600808e1}},	//   _smiu_, _аҧша_, ịgha, пном_, 
   {{0x2fc81c06,0x64422aa5,0x94400451,0x60cc20b2}},	//   _biag_, _urli, _مھين, _şams, 
   {{0x20040295,0x91dc00cc,0x00000000,0x00000000}},	//   rrli_, _মিৰ্, --, --, 
   {{0x2fca2aa6,0x6d880b4b,0x9db80108,0x00000000}},	//   _diag_, džab, зыву_, --, 
   {{0x200409a8,0x22580174,0x6d880419,0xe1f80064}},	//   prli_, øsku_, zľav, msų_, 
   {{0xe1f80024,0x61ec415b,0x00000000,0x00000000}},	//   lsų_, _çalb, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9b680184,0xe1f80006,0x00000000,0x00000000}},	// [3fca0] ошҡа_, nsų_, --, --, 
   {{0x2fc801d4,0x26cc01c4,0xe1f80024,0x00000000}},	//   _ziag_, _ageo_, isų_, --, 
   {{0x2fc801d4,0x65ac0030,0xa3c00e49,0x00000000}},	//   _yiag_, rúhl, ूदा_, --, 
   {{0x65ac01f1,0x6284013f,0xe1f80153,0x95c80353}},	//   súhl, _ɛhor, ksų_, пука_, 
   {{0x6d880419,0x5bbc06ff,0x00000000,0x00000000}},	//   rľav, ्दीव, --, --, 
   {{0x5bbc0521,0xceb00375,0x42680257,0xdebc069d}},	//   _ọchị_, איד_, ታይነት_, ተርና_, 
   {{0x25640014,0xe1f80153,0x6d880419,0xdcec00de}},	//   خانُ, esų_, pľav, enbī, 
   {{0x31c802db,0x26cc0165,0x6374007b,0xd34002cb}},	//   रद्ध, _ggeo_, _lánf, افظی, 
   {{0xd5e801d9,0x38440092,0xe2300214,0x9268855f}},	//   _رٹان_, _የሚቀበ, لکوب, ярка_, 
   {{0x0ef81414,0x64300451,0x00000000,0x00000000}},	//   ्ल्स_, _چڱيء, --, --, 
   {{0xb4cc6956,0xd51000f1,0xfbe000cc,0xa068010a}},	//   रखी_, _لېږد, _বয়সত, çапа_, 
   {{0x937800f2,0x00000000,0x00000000,0x00000000}},	//   _عصار_, --, --, --, 
   {{0x2fc80354,0x5185a3a6,0xe5780142,0x6d340023}},	//   _viag_, _пука, _gwŷs_, _ብምፍር, 
   {{0xcd780240,0x00000000,0x00000000,0x00000000}},	//   _ኣብዝሓ_, --, --, --, 
   {{0x2fc80190,0x3ce00034,0xfc3001d3,0x6d8800d7}},	//   _tiag_, कड़े_, یحہ_, ežac, 
   {{0x6d8800d7,0x00000000,0x00000000,0x00000000}},	//   eľat, --, --, --, 
   {{0x4ea54bd0,0x3a980276,0x090400f0,0xadb400d8}},	// [3fcb0] _ярка, ектэ_, ечем, _ибиш, 
   {{0x3914329c,0x7ac62aa7,0xe80c0073,0x00000000}},	//   лмур, уссе, ांला_, --, 
   {{0xa02000c5,0xcb9000f2,0x7f880166,0xaa7c008e}},	//   _ööta, _مهدک, cıqs, käçä_, 
   {{0xe6103fb8,0x00000000,0x00000000,0x00000000}},	//   لشت_, --, --, --, 
   {{0xaac400cd,0x00000000,0x00000000,0x00000000}},	//   _वणिक, --, --, --, 
   {{0x637400d2,0x5928025c,0x00000000,0x00000000}},	//   _káng, _ཤིགས_, --, --, 
   {{0x2d9000ca,0x57200137,0xe0d000f2,0x79940117}},	//   inze_, _چۉمك, یزد_, _сирф, 
   {{0x637400c7,0xc7b40150,0xaa7c013d,0x00000000}},	//   _máng, _سصزع, gäçä_, --, 
   {{0xa5348ed9,0x63762aa8,0xe1f80153,0xa3e40263}},	//   _инач, _láng, usų_, बीज_, 
   {{0xe1f80006,0x00000000,0x00000000,0x00000000}},	//   rsų_, --, --, --, 
   {{0xdee62aa9,0xdebc02d3,0xc0b802d3,0x00000000}},	//   кони, ተይን_, _ሰዉራ_, --, 
   {{0x2d908dfb,0xf4841c13,0xe578015d,0x0fc0010b}},	//   enze_, _суун, _gwŷr_, ийэн, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x60240953,0xed3401c0,0x2088010b,0x75f801d3}},	//   _адка, лэсэ, _ойли_, _húzá, 
   {{0xdca4bda8,0xa3e4012c,0xddc801ed,0xf2c400fd}},	//   тави, बीच_, ínűl, _исән, 
   {{0x2d922aaa,0xbdd00115,0x5bbc00dc,0x00000000}},	//   anze_, _esɨa, ्देव, --, 
   {{0x4b2006ed,0xc0b80092,0x4de80210,0x00000000}},	// [3fcc0] јмув, ተውም_, जीआई_, --, 
   {{0x18681ca9,0x63745799,0x00000000,0x00000000}},	//   мази_, _hánd, --, --, 
   {{0x637401e1,0x3cf801bf,0x00000000,0x00000000}},	//   _gáng, marv_, --, --, 
   {{0x96640166,0xaa280014,0x3cf8007c,0x00000000}},	//   ккее, بسہٕ_, larv_, --, 
   {{0x63759396,0xd0f001e1,0x00000000,0x00000000}},	//   _mánd, _ńṣẹb, --, --, 
   {{0xb4cc0574,0x6e2803ee,0xe5e400c6,0x77b8056a}},	//   रखे_, çebi, اثني, díxe, 
   {{0x38c811fc,0x61ec031c,0x273000cf,0x28400092}},	//   _ساسی_, _ħala, _گۉنس, _የሚኖራ, 
   {{0x60cc03ee,0xdcec01f1,0x63b80042,0xd34401b9}},	//   _şamp, jobľ, _chwn, کیچه_, 
   {{0x0cac0807,0x3cf80254,0x00000000,0x00000000}},	//   _टर्म, karv_, --, --, 
   {{0x71740597,0x00000000,0x00000000,0x00000000}},	//   اهدا, --, --, --, 
   {{0x63762aab,0x77600472,0xc054177b,0x935a2aac}},	//   _bánd, _komx, вія_, _орду_, 
   {{0x63762aad,0x522401f0,0x528400fb,0x260804aa}},	//   _cánd, _афка, _игеб, _सिमी_, 
   {{0x63762aae,0x00000000,0x00000000,0x00000000}},	//   _dánd, --, --, --, 
   {{0x61ece35c,0x77600472,0x7e6001e6,0x2d900810}},	//   _çala, _lomx, ämpa, unze_, 
   {{0xed5005d9,0xdb240419,0x637400d7,0x3ad80248}},	//   لھھ_, _špár, _fánd, _ọpa_, 
   {{0x6374056a,0x7760487e,0x00000000,0x00000000}},	//   _gánd, _nomx, --, --, 
   {{0xa020000d,0x7ac40064,0x00000000,0x00000000}},	// [3fcd0] _ööra, асфе, --, --, 
   {{0x88c62aaf,0x63762ab0,0xc88801d3,0x8cb40139}},	//   نتال, _táng, وخال_, _үсүч, 
   {{0x48a8013e,0x00000000,0x00000000,0x00000000}},	//   фтам_, --, --, --, 
   {{0xaa58ef04,0x0ae80fb4,0xdb1c00a2,0x00000000}},	//   _зиму_, _تردي_, _kupý, --, 
   {{0xf7710b35,0x63b80cfd,0x49a416a4,0x370401ec}},	//   غام_, _rhwn, _ајва, рпіг, 
   {{0xf6501b06,0xa978008f,0x77a80a81,0xf66464c2}},	//   تئم_, _טאָכ, _یێلہ_, решү, 
   {{0xc7c4035b,0x787c0158,0x63b80042,0x63749247}},	//   _асаи, råvå, _phwn, _láne, 
   {{0x4908012c,0x77b8056a,0x212801e4,0x00000000}},	//   ालको_, tíxe, _ŝah_, --, 
   {{0x68f4066d,0x2a680218,0x63762ab1,0x65ac00e4}},	//   _kezd, nyab_, _ránd, húhi, 
   {{0x68f62ab2,0x77600117,0x63762ab3,0x7f6002d3}},	//   _jezd, _zomx, _sánd, _ሲቪካዊ_, 
   {{0xa06a2ab4,0x68f407de,0x77600fec,0x63b80142}},	//   хана_, _mezd, _yomx, _thwn, 
   {{0xd24c61f4,0x65622ab5,0x2a68089c,0x77b80407}},	//   آنی_, _holh, kyab_, píxe, 
   {{0x65621211,0xc1000cef,0x3cf8022c,0xfe78167e}},	//   _kolh, _күпл, tarv_, түп_, 
   {{0x5bbccace,0xdb04011f,0x65600076,0x236c0306}},	//   ्द्व, _ikké, _jolh, lkej_, 
   {{0x65622ab6,0x637425e6,0x3cf8fbd4,0x7054074d}},	//   _molh, _tánd, rarv_, _кĕре, 
   {{0x3cf805ac,0x2a680100,0x236c02f0,0xfae40139}},	//   sarv_, fyab_, nkej_, рбаү, 
   {{0xc0f4044e,0x3cf8007c,0x3ab4008e,0x00000000}},	// [3fce0] _ፈጺሙ_, parv_, рәнт, --, 
   {{0x7760014b,0x236c0419,0xc0b80023,0x00000000}},	//   _somx, hkej_, _ሰሉስ_, --, 
   {{0x77600218,0x68f4022e,0xdb1c51e6,0xd7080d1d}},	//   _pomx, _dezd, _kupü, енее_, 
   {{0x2a68fa45,0x63740332,0x00000000,0x00000000}},	//   byab_, _lánb, --, --, 
   {{0x65600f72,0xab6400e2,0x236c00d0,0xe3b80154}},	//   _bolh, _daļā, dkej_, ঁদাব, 
   {{0x65622ab7,0x98a40184,0xceb004ae,0x68f43712}},	//   _colh, _биге, ציג_, _gezd, 
   {{0x65600072,0xdb04011f,0x85b000d1,0x00000000}},	//   _dolh, _akké, сәтч, --, 
   {{0xb6c5aafe,0xd2580798,0x99900210,0x00000000}},	//   _көлд, ецо_, styń_, --, 
   {{0x3a222ab8,0x656003b7,0x6d880552,0x637401e1}},	//   ntip_, _folh, džan, _bánb, 
   {{0xdb1c0122,0x93441ac1,0x65600009,0xab6400e2}},	//   _kupó, _әнде, _golh, _zaļā, 
   {{0x057400c6,0x7e600267,0x40cc01e1,0x50640137}},	//   _حملة_, ämpn, _jẹyọ_, утпа, 
   {{0x236c01a2,0x3a222ab9,0x717422ad,0x2a680198}},	//   ckej_, ktip_, اهگا, yyab_, 
   {{0xe3b001d9,0x6db62aba,0x00000000,0x00000000}},	//   _برٕ_, ийму, --, --, 
   {{0x68e805be,0x3a20013c,0x2d84eaa6,0xb5040b4c}},	//   _đedo, dtip_, òle_, रणिय_, 
   {{0x80d80375,0xc0e40592,0x4aa400c5,0x21840354}},	//   _אחוז, _صفين_, _कँहव, _тăрр, 
   {{0x68f48e9e,0x3a200194,0x09bc07f7,0x99800064}},	//   _sezd, ftip_, ौद्य, _oskų_, 
   {{0x8d847351,0x6840001f,0x3a20013c,0x2c140f22}},	// [3fcf0] _бунд, _የሚመስ, gtip_, াবেই_, 
   {{0xf77004a2,0x6e2e2abb,0x63740022,0x236c0f91}},	//   ۋان_, _ipab, _kánc, zkej_, 
   {{0xfeb82a60,0xdb1c09d7,0x3a222abc,0x65600120}},	//   _لایت_, _cupó, atip_, _rolh, 
   {{0xc7a80137,0x65601f53,0x68f40810,0xeab80137}},	//   ردال_, _solh, _wezd, _үйү_, 
   {{0xe8000c2e,0x68f42631,0xb92001f2,0x63762abd}},	//   _लटका_, _tezd, ntrị_, _lánc, 
   {{0x6e2c013b,0x2cac012c,0x00000000,0x00000000}},	//   _mpab, ředu_, --, --, 
   {{0x65605b5e,0x6e2c0055,0x248000a3,0x236c0419}},	//   _volh, _lpab, àhm_, tkej_, 
   {{0x65600af9,0xa20406dc,0x6e2c02d0,0x50d80055}},	//   _wolh, апид, _opab, _āyāṃ_, 
   {{0x65622abe,0x672a2abf,0x637402f0,0x236c0419}},	//   _tolh, _ibej, _pánb, rkej_, 
   {{0x236c01a2,0xe0d80fc0,0x60240798,0x00000000}},	//   skej_, ъво_, адоа, --, 
   {{0x6e2e2ac0,0x6374204e,0xf04400b7,0x04b002dd}},	//   _apab, _cánc, ንግሊዝ, _الاڭ, 
   {{0x6728031c,0xe80c02ab,0x61ec036e,0xf1940139}},	//   _jbej, _हिना_, _çalo, _һичь, 
   {{0x6d881326,0x672a2ac1,0xf13400cf,0x00000000}},	//   ržan, _mbej, _گةنة, --, 
   {{0x61ea2ac2,0xd24c01c8,0xdd900035,0x1278010f}},	//   mpel, _آنو_, زوز_, _באנע, 
   {{0x67284966,0x6d8809a8,0x5bc4007b,0xdee47577}},	//   _obej, mžal, لترف, _койи, 
   {{0x61ea2ac3,0x28a80034,0x3a20e9a0,0x1ae43591}},	//   opel, _कड़ि, ttip_, роам, 
   {{0x61e8398e,0xdb1e2ac4,0x3a2020ac,0x5aca2ac5}},	// [3fd00] npel, _supó, utip_, тлам_, 
   {{0x61ea2ac6,0x3a222ac7,0x61ec003d,0x672a2ac8}},	//   ipel, rtip_, _ħall, _abej, 
   {{0x3a222ac9,0x985421a8,0xeab001ed,0x61e801c7}},	//   stip_, шташ, قعے_, hpel, 
   {{0x61e82af2,0x9f4402e2,0x3a200327,0x00000000}},	//   kpel, uplè_, ptip_, --, 
   {{0x7bc40ad4,0x3a200357,0x61e88d28,0x6b80017a}},	//   mmiu, qtip_, jpel, ëlge, 
   {{0x61e808cd,0x67280327,0x7bc4023a,0x6d880841}},	//   dpel, _ebej, lmiu, jžal, 
   {{0x61ea2aca,0x6d8801fa,0xe80c00af,0xa86401ee}},	//   epel, džal, _हिया_, _лерҙ, 
   {{0x7bc40cfe,0x67280248,0x63746293,0x18a401f0}},	//   nmiu, _gbej, _ránc, _баҳм, 
   {{0x61ec0598,0x6374307d,0x61e82b92,0x7e60049f}},	//   _çall, _sánc, gpel, ämpl, 
   {{0x15b82d35,0x301402f4,0x6375e46b,0x7bc40200}},	//   _рыбы_, бдор, _pánc, hmiu, 
   {{0x7bc40d04,0xefd40020,0xc1b405f5,0x6e2c0728}},	//   kmiu, ራሻዎ_, рлэх_, _spab, 
   {{0x6728031c,0xd2440139,0xebd804a9,0x00000000}},	//   _xbej, _вэки, ғдаш_, --, 
   {{0x7bc62acb,0x956402d3,0x00000000,0x00000000}},	//   dmiu, _ጸሎትን_, --, --, 
   {{0xac18468b,0x7bc416b8,0x6e2c0793,0x637401ed}},	//   логу_, emiu, _vpab, _tánc, 
   {{0xb92002e3,0xefcc0092,0xbab000fe,0x00000000}},	//   strị_, ጣለው_, _কলগছ, --, 
   {{0xdb1c5b80,0x00000000,0x00000000,0x00000000}},	//   _supò, --, --, --, 
   {{0x4aa42e1e,0x0c1c001f,0x91b800c5,0x8d840214}},	// [3fd10] _कुशव, ስቲያኒ, _उठाई, _نشدن, 
   {{0x63741bb0,0x7bc420ac,0x9e940345,0x00000000}},	//   _mána, amiu, _چایچ, --, 
   {{0xd2448384,0x63762acc,0xc7c401b9,0x66d40ada}},	//   _کن_, _lána, асди, ميائ, 
   {{0x61e80158,0xdc34008f,0x4ad8012c,0x87040cc9}},	//   ypel, _פארט_, _भलिव, ряже, 
   {{0x6374008c,0x6b8e2acd,0xf6080075,0x00000000}},	//   _nána, miag, ңхәй_, --, 
   {{0xa8041709,0x77b80077,0x1670267c,0xdcfc0356}},	//   _coñé, ríxa, чқур, _impă, 
   {{0x69c62ace,0xe44800db,0x6b8c00ad,0x00000000}},	//   mmhe, البى_, oiag, --, 
   {{0x61e8398e,0x6b8e2acf,0x672a2ad0,0xf7715e46}},	//   tpel, niag, _ubej, _قاق_, 
   {{0x637400c6,0x81dc0f22,0x61e8b594,0x69c40549}},	//   _cána, ধীন_, upel, omhe, 
   {{0x6b8c152d,0xc51400aa,0x61ee0d21,0x637408a5}},	//   hiag, _خبرت, _çalm, _dána, 
   {{0x61e8398e,0x69c62ad1,0x6d8805a1,0x6b8c01c0}},	//   spel, imhe, ržal, kiag, 
   {{0x61ea2ad2,0x63762ad3,0x257802e2,0x6b8c3df1}},	//   ppel, _fána, _dèle_, jiag, 
   {{0x63aa2ad4,0x63740789,0x6144010a,0x4aa521d3}},	//   moen, _gána, _гела, _कुलव, 
   {{0x63aa2ad5,0xf0880214,0x910001af,0x00000000}},	//   loen, ائیه_, _епше, --, 
   {{0x6b8c04c9,0xdcb02302,0x69c437a8,0x311c06b1}},	//   fiag, سىر_, dmhe, _मातृ_, 
   {{0x63aa2ad6,0x7bc40618,0x69c401a4,0x00000000}},	//   noen, umiu, emhe, --, 
   {{0x7bc556e9,0x3964013e,0x25780129,0x80b000d1}},	// [3fd20] rmiu, онаҳ, _zèle_, _دەھش, 
   {{0x63aa2ad7,0x9cf400a8,0x6b8e2ad8,0x8a00005b}},	//   hoen, _учиш, aiag, язуе, 
   {{0x63aa2ad9,0x6b8c3e38,0xdc6801c0,0x00000000}},	//   koen, biag, _санд_, --, 
   {{0x6b8e2ada,0x63aa2adb,0x69c40e29,0xbb740137}},	//   ciag, joen, amhe, _بۇرع, 
   {{0x63aa2adc,0xa8040005,0x6120007f,0x6d8800f3}},	//   doen, _poñé, _kňlč, džaj, 
   {{0xf8dc1b37,0x3ea22add,0x69c400a3,0x63742131}},	//   _बलिय, _mxit_, cmhe, _rána, 
   {{0x61ec010e,0x00000000,0x00000000,0x00000000}},	//   _çalj, --, --, --, 
   {{0x63aa2ade,0x4aa4060c,0x3ea00208,0xd794007b}},	//   goen, _कुँव, _oxit_, _الرخ, 
   {{0xb1c82d40,0x3ea00240,0x8b5400d9,0x7178001b}},	//   аңда_, _nxit_, מיקס_, ибир_, 
   {{0xe80c05ba,0x6374022c,0x6b8c01c6,0xd1391650}},	//   ांचा_, _vána, ziag, ухи_, 
   {{0x63a893e0,0x3ea001fb,0x569401e0,0x3fd401c6}},	//   boen, _axit_, _таҡт, ймээ_, 
   {{0x63aa2adf,0x6b8c528b,0xe600010b,0x637400ae}},	//   coen, xiag, _эҗән, _tána, 
   {{0x6b8c0354,0x4aa40d54,0x9f4407c5,0x69c47e1a}},	//   viag, _कुंव, mplì_, ymhe, 
   {{0x257801e1,0x106800ae,0x00000000,0x00000000}},	//   _tèle_, _محبى_, --, --, 
   {{0x6b8e2ae0,0x00000000,0x00000000,0x00000000}},	//   tiag, --, --, --, 
   {{0xac1807d6,0x637400e5,0x00000000,0x00000000}},	//   лоҳу_, _lánn, --, --, 
   {{0x6b8e2ae1,0x00000000,0x00000000,0x00000000}},	// [3fd30] riag, --, --, --, 
   {{0x63aa2ae2,0x6b8e2ae3,0xaac406b1,0x00000000}},	//   zoen, siag, लेषक, --, 
   {{0x63aa2ae4,0x69c40491,0x8d740075,0xf7722ae5}},	//   yoen, rmhe, _ناھا, کال_, 
   {{0xd7080075,0xc06c001f,0x6b8c0194,0x63a801c4}},	//   لىمۇ_, ሥልጣን_, qiag, xoen, 
   {{0x69c401af,0xa90801d9,0x63a9df62,0x63740f47}},	//   pmhe, _پٲزٕ_, voen, _bánn, 
   {{0xc958036b,0x33d008b0,0x63a80098,0x2c980023}},	//   _сўм_, _ﺗﺎﺭﻣ, woen, _ዘስዕቦ_, 
   {{0x36880116,0x00000000,0x00000000,0x00000000}},	//   исән_, --, --, --, 
   {{0x25080133,0x61ec0e2d,0xe3b80120,0x00000000}},	//   _چرای_, _çalk, јби_, --, 
   {{0x63aa2ae6,0x7dc16810,0x65940124,0x00000000}},	//   roen, löse, _даау, --, 
   {{0x63aa2ae7,0x5fdc01ad,0x00000000,0x00000000}},	//   soen, _नंदल, --, --, 
   {{0xb5c807d6,0x7dc001ed,0x00000000,0x00000000}},	//   _اولم_, nöse, --, --, 
   {{0xd24c021a,0x1ec8f4e0,0xe1f002e9,0xa2541046}},	//   رنۍ_, илни_, _قست_, _وپاش, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9f440597,0x29cc00f3,0x7dc0023a,0x637403da}},	//   mplí_, _džak_, köse, _káno, 
   {{0x63762ae8,0xdb5001d9,0x00000000,0x00000000}},	//   _jáno, وَس_, --, --, 
   {{0x3ea0009d,0xdb080205,0x00000000,0x00000000}},	//   _txit_, _ünüv, --, --, 
   {{0x9d4400ee,0x00000000,0x00000000,0x00000000}},	// [3fd40] _депд, --, --, --, 
   {{0x7f440051,0x60cc010b,0x00000000,0x00000000}},	//   _haiq, _şamy, --, --, 
   {{0x7f440113,0x6d880558,0x63762ae9,0x6de41bf4}},	//   _kaiq, džah, _náno, _وثیق, 
   {{0xace80133,0xb0a800a2,0x00000000,0x00000000}},	//   _پریل_, _üýşd, --, --, 
   {{0x7f462aea,0x3b000369,0x68ea2aeb,0x27ec0010}},	//   _maiq, maiq_, _şede, _čene_, 
   {{0x53e40588,0x7ae47636,0x63745f5b,0x7d1c0194}},	//   оциа, lcit, _báno, ngrs, 
   {{0xd37a2aec,0x637492c4,0x186940cf,0x00000000}},	//   ичи_, _cáno, _тави_, --, 
   {{0x63741709,0x7f440333,0x00000000,0x00000000}},	//   _dáno, _naiq, --, --, 
   {{0xbdd00115,0x02a001c0,0x7ae62aed,0x6374032e}},	//   _esɨi, дрэм, icit, _tánn, 
   {{0x7ae401f9,0x3178012d,0x10480229,0x00000000}},	//   hcit, órz_, аями_, --, 
   {{0x7ae400f1,0x7f440007,0x637400d7,0xdb7c0092}},	//   kcit, _baiq, _gáno, _ረገድም_, 
   {{0x7f440399,0x61440131,0x7ae461cf,0x8de801d5}},	//   _caiq, قىۋە, jcit, ифга_, 
   {{0x7f440007,0x3224025c,0xd24c0014,0x63740306}},	//   _daiq, _འདྲར_, _شۆد_, _záno, 
   {{0x7ae4003a,0x6374283e,0x6d880064,0x00000000}},	//   ecit, _lánl, ožai, --, 
   {{0x7ae4003a,0x61ec0003,0x7f4406be,0x0b880107}},	//   fcit, _ħali, _faiq, асаи_, 
   {{0x7f440399,0x3b000007,0x7ae4010a,0x20100f91}},	//   _gaiq, gaiq_, gcit, ázie_, 
   {{0x29d62aee,0x6ce45a05,0x60cc06be,0x4338010f}},	// [3fd50] سياس, _ىزدە, _şamx, סעמב, 
   {{0x6f1c508f,0xdeb40139,0xbd8801f7,0x6e9400f1}},	//   lgsc, _qayƅ, _ونين_, _ولګا, 
   {{0x2d922aef,0x6d4406a3,0xab7800aa,0x00000000}},	//   mize_, _iaha, _همدا_, --, 
   {{0x6f1e2af0,0x9f462af1,0x3b000007,0x2d92147d}},	//   ngsc, mplã_, caiq_, lize_, 
   {{0xdb1c00d8,0x637400ae,0xd5ac0050,0x3ce001f9}},	//   _cupõ, _dánl, گہٕ_, कडचे_, 
   {{0x2d908d13,0x2578180f,0x63740122,0x69dc0115}},	//   nize_, _bèla_, _páno, _iuse, 
   {{0x29022af2,0x6d4433c3,0x69dc00ed,0x7dc00730}},	//   maha_, _maha, _huse, lösc, 
   {{0x6d462af3,0x29022af4,0x2d922af5,0x63740316}},	//   _laha, laha_, hize_, _váno, 
   {{0x69d62af6,0x2d922af7,0x6d462af8,0x7538013a}},	//   _kize, kize_, _oaha, bevz, 
   {{0x05762af9,0x6d462afa,0x29022afb,0x7ae40369}},	//   _بارد, _naha, naha_, zcit, 
   {{0x69d62afc,0x7ae417e8,0x7f440784,0x3b000097}},	//   _mize, ycit, _paiq, yaiq_, 
   {{0x69d41859,0x7f440333,0x44240b6f,0x69dc0c8c}},	//   _lize, _qaiq, mtn_, _ouse, 
   {{0x29022afd,0x69de2afe,0x2d913d57,0x7f440007}},	//   kaha_, _nuse, fize_, _vaiq, 
   {{0x2d90633d,0x6d444aa5,0x69d62aff,0x6f1c01f5}},	//   gize_, _caha, _nize, agsc, 
   {{0x29000d62,0x69de2b00,0x63740332,0x00000000}},	//   daha_, _ause, _lánm, --, 
   {{0x69de2b01,0xd00c00c6,0x69d62b02,0x68e5ccf2}},	//   _buse, _إلي_, _aize, echd, 
   {{0x6d440875,0x7ae62b03,0x69d62b04,0x69de2b05}},	// [3fd60] _faha, rcit, _bize, _cuse, 
   {{0x2d922b06,0x29022b07,0x644005ce,0x661801f5}},	//   cize_, gaha_, _osli, duwk, 
   {{0x69d62b08,0x69de2b09,0xdb1c00d8,0x661801a4}},	//   _dize, _euse, _supõ, euwk, 
   {{0x6d462b0a,0x68e40876,0x20040072,0x69d62b0b}},	//   _zaha, achd, isli_, _eize, 
   {{0x6d45bef8,0x69dc0516,0x69d62b0c,0x64422b0d}},	//   _yaha, _guse, _fize, _asli, 
   {{0x69d62b0e,0x6d44003d,0x80fc009e,0xf43400a8}},	//   _gize, _xaha, ্ভুজ_, декэ, 
   {{0x395a2b0f,0x69dc03fa,0x64422b10,0x6618017a}},	//   _inrs_, _zuse, _csli, auwk, 
   {{0x69d62b11,0x2d922b12,0x8c18008d,0x69dc037e}},	//   _zize, zize_, צופי, _yuse, 
   {{0x2d922b13,0x69dc0050,0x69d58170,0xc7a0008e}},	//   yize_, _xuse, _yize, _читк, 
   {{0x4424f17b,0x2578020c,0x64400334,0x637401e1}},	//   btn_, _tèla_, _fsli, _jánj, 
   {{0x2d922b14,0x20040158,0x2fdc01d5,0xc950011a}},	//   vize_, gsli_, _quvg_, גמת_, 
   {{0x6d462b15,0x29000851,0x2d922b16,0x6e9468dd}},	//   _saha, zaha_, wize_, диму, 
   {{0x29022b17,0x2d922b18,0x6e3c0936,0x0ec403f3}},	//   yaha_, tize_, uwsb, रेंड, 
   {{0x69de2b19,0x29000050,0x395800a3,0x64400ea0}},	//   _ruse, xaha_, _nnrs_, _ysli, 
   {{0x6d462b1a,0x29022b1b,0x69d62b1c,0xcb0805f5}},	//   _vaha, vaha_, _rize, йхад_, 
   {{0x2d913890,0x2900092b,0x395803b2,0x68e42811}},	//   size_, waha_, _anrs_, wchd, 
   {{0x6d462b1d,0x29022b1e,0x637422ec,0x6f0c0bd7}},	// [3fd70] _taha, taha_, _bánj, _idac, 
   {{0x395a2b1f,0x69de2b20,0x6d441662,0x2d9001f0}},	//   _cnrs_, _vuse, _uaha, qize_, 
   {{0x29022b21,0x69d62b22,0x68e62b23,0x63762b24}},	//   raha_, _vize, rchd, _dánj, 
   {{0x69dc78d0,0x68e62b25,0xe6962aee,0x69d62b26}},	//   _tuse, schd, ولاد, _wize, 
   {{0x69d401ed,0x6f0c009f,0x69dc0037,0x7dc00267}},	//   _tize, _mdac, _uuse, lösa, 
   {{0x29022b27,0x69d40204,0x7c9443fb,0x68e401ab}},	//   qaha_, _uize, _آشیا, qchd, 
   {{0x4430004e,0xd4640828,0x38600023,0x7dc001f4}},	//   ïx_, дище_, _ተጋሂዱ_, nösa, 
   {{0x2b491f19,0xe3b02a4b,0x637401e1,0xbc7c00d9}},	//   ndac_, خرت_, _tánm, מנות, 
   {{0xd344aeda,0x2004031c,0x00000000,0x00000000}},	//   بینه_, wsli_, --, --, 
   {{0x6f0e2b28,0x60081bf6,0x44242a1f,0x660800f1}},	//   _adac, оном_, ptn_, _ivek, 
   {{0x64402630,0x63740413,0xa069254a,0x00000000}},	//   _usli, _jánk, цана_, --, 
   {{0x224839ae,0x00000000,0x00000000,0x00000000}},	//   _šaku_, --, --, --, 
   {{0x2b480334,0x00000000,0x00000000,0x00000000}},	//   ddac_, --, --, --, 
   {{0x6f0c0393,0x00000000,0x00000000,0x00000000}},	//   _edac, --, --, --, 
   {{0x2b480198,0x2ee80175,0x224e2b29,0x25fc3af7}},	//   fdac_, _ffaf_, lvek_, रीती_, 
   {{0x660a2b2a,0x2b580356,0x7bd800e4,0x92c003d4}},	//   _ovek, _cnsc_, _ũvus, ্ডৰ_, 
   {{0x27ec009b,0xef18033f,0x6fe800bc,0x224c0165}},	// [3fd80] _čena_, óże_, _věce, nvek_, 
   {{0x63762b2b,0x61ec0166,0x2b4800d7,0x00000000}},	//   _bánk, _çalu, adac_, --, 
   {{0x9b4407d6,0x660a2b2c,0x6f0c6bba,0x00000000}},	//   _قندو, _avek, _ydac, --, 
   {{0x2b480589,0x00000000,0x00000000,0x00000000}},	//   cdac_, --, --, --, 
   {{0x6d8804b9,0x66088bbb,0x645c00c0,0xc4b80150}},	//   ržav, _cvek, _ąsia, _ﺠﺭﺍﺌ, 
   {{0xdea0001f,0x98a43412,0x224cb35a,0x00000000}},	//   _ወንድሜ_, _жиге, dvek_, --, 
   {{0x660a2b2d,0xa5080131,0x63740241,0x00000000}},	//   _evek, سىيە_, _kánh, --, 
   {{0x25780036,0x00000000,0x00000000,0x00000000}},	//   _hèll_, --, --, --, 
   {{0xd62418a1,0x6f0c01c3,0xdb040166,0x92680139}},	//   _تعزي, _rdac, _ikkä, юрка_, 
   {{0x661c168c,0x60cc00df,0x2b480113,0x61ec025c}},	//   _åska, _ŝama, zdac_, _ħalt, 
   {{0x05141564,0x66080e8a,0x04d80375,0x09d8012c}},	//   _زينب_, _zvek, _וקבל, _बढ्य, 
   {{0xb9001b4b,0x201025fd,0x77b800db,0x7ff08d3c}},	//   _ཤུ_, ázia_, fíxi, کسیا, 
   {{0x527400db,0x625c01e4,0x6f0c0419,0x00000000}},	//   _تااز, sɨor, _vdac, --, 
   {{0x63ae2b2e,0xe1ec05d9,0x7dc00108,0x00000000}},	//   čane, _اڳي_, tösa, --, 
   {{0x6d8801fa,0x2b48037e,0x61440e56,0x00000000}},	//   džat, tdac_, _سىيە, --, 
   {{0x6f0c0bd7,0x637404d4,0x6d8800d7,0x7dc0007c}},	//   _udac, _ránk, ežat, rösa, 
   {{0x637400d0,0x61ec010b,0x8d844eca,0x00000000}},	// [3fd90] _sánk, _çalt, _жунд, --, 
   {{0xd3640272,0xb68c0125,0x7dc001e6,0x39162b2f}},	//   _ڵه_, _ፓርላማ_, lösn, кмур, 
   {{0x66080217,0xd1e01954,0xdb14010e,0x00000000}},	//   _svek, _ነጥበ_, lmyý, --, 
   {{0x2b580295,0xd3645edc,0x224cf7b3,0x00000000}},	//   _unsc_, _صه_, yvek_, --, 
   {{0x65962b30,0x2d480023,0xaac40709,0x00000000}},	//   наду, _ብምስጢ, लेखक, --, 
   {{0x2578068c,0xd5440063,0x00000000,0x00000000}},	//   _vèlo_, епше_, --, --, 
   {{0x23d40f1a,0xa2e4004e,0x7dc001f4,0x566000db}},	//   нцир, нойд, kösn, _ەگىف, 
   {{0x660a2b31,0x224c2a06,0x637401d3,0xdb1400a2}},	//   _tvek, tvek_, _káni, kmyý, 
   {{0x2578020c,0x260828d4,0x66080158,0x61ec0327}},	//   _hèlm_, _सिटी_, _uvek, _ħals, 
   {{0x224e2b32,0x63762b33,0x00000000,0x00000000}},	//   rvek_, _máni, --, --, 
   {{0x63752ebe,0x224c007c,0x4424cdcc,0x00000000}},	//   _láni, svek_, _زراف, --, 
   {{0x9878008f,0xb8140154,0x00000000,0x00000000}},	//   פארט, _সহমত_, --, --, 
   {{0xd1e0044e,0xa1580063,0x539800d9,0x637402d2}},	//   _ነጥቢ_, _наду_, _צינו, _náni, 
   {{0xa0a4239a,0x00000000,0x00000000,0x00000000}},	//   _палд, --, --, --, 
   {{0x6d8802d5,0xffa4013d,0xa2c003d4,0xf2c401af}},	//   ežas, _илкү, _উলিও, _псән, 
   {{0x6374f126,0x61ed14e3,0xdca4013d,0x29cc00ef}},	//   _báni, _çals, _җами, _ožas_, 
   {{0x3f800a73,0x6374fc1b,0x19c47b17,0x00000000}},	// [3fda0] _iliu_, _cáni, ебам, --, 
   {{0x63762b34,0x00000000,0x00000000,0x00000000}},	//   _dáni, --, --, --, 
   {{0x6d8807f5,0x5c1400c7,0x779402f2,0x7dc001f4}},	//   ržat, _џьоу, نیسا, löso, 
   {{0xd1e00201,0xdad00131,0x6374032e,0x0ec401f9}},	//   _ነጥብ_, _مەزھ, _fáni, रेकड, 
   {{0x7dc0007c,0x00000000,0x00000000,0x00000000}},	//   nöso, --, --, --, 
   {{0x3f800113,0x637401e1,0x6d4001e4,0x83d40220}},	//   _lliu_, _kánw, ĵlag, _ﺟﺎﺭﻳ, 
   {{0x3f8008e5,0x637402fb,0xd394008e,0x00000000}},	//   _oliu_, _záni, нәдә_, --, 
   {{0xb3540116,0x068001c6,0x7dc001f4,0x93880108}},	//   ткиш, _өгсн, köso, ясла_, 
   {{0x7414a2ee,0x55880120,0x833001c6,0x764403e0}},	//   روکا, _ебам_, уных, çiyd, 
   {{0x82300f13,0x3f822b35,0x00000000,0x00000000}},	//   اريا, _aliu_, --, --, 
   {{0x92c00f22,0x97540055,0x00000000,0x00000000}},	//   ্ডে_, _eṇey, --, --, 
   {{0x3f822b36,0x80d00372,0x00000000,0x00000000}},	//   _cliu_, چۅۇچ, --, --, 
   {{0x6d89083f,0xd1c80220,0x0dc800d8,0x00000000}},	//   džar, _елде_, зуви_, --, 
   {{0x3f800481,0x63740413,0xf1940108,0xfd44009d}},	//   _eliu_, _ráni, _шиль, лэсн, 
   {{0x41c0627d,0x257802e2,0x2fc40116,0x8bc400d8}},	//   _حقوق, _bèlj_, _ириң, есад, 
   {{0x3f800ffb,0x63762b37,0x92c0009e,0x00b80375}},	//   _gliu_, _dánw, ংশী_, _ממומ, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3fdb0] --, --, --, --, 
   {{0x2dc801ec,0x63750c89,0x00000000,0x00000000}},	//   _تابۋ_, _váni, --, --, 
   {{0x39a47b00,0xac9804fb,0x79a400d8,0xe5a401e1}},	//   уштв, _آنجا_, урте, _ìkẹ́, 
   {{0x61ec10d8,0x6375b4ef,0x00000000,0x00000000}},	//   _éalg, _táni, --, --, 
   {{0x2fc801ab,0x46c8033f,0x7dc00108,0x00000000}},	//   _mhag_, ़ेंह, kösl, --, 
   {{0x2fc80363,0xa998008f,0xc98433cc,0x4aa4010a}},	//   _lhag_, _חבֿר, _чуми, ăкăн_, 
   {{0x92c004c5,0xfbd004d3,0x61ec025c,0x00000000}},	//   ্ডো_, _ختی_, _ħalq, --, 
   {{0x291001a6,0x661c03cd,0x63741d1d,0x7dc00108}},	//   _hdza_, _åsko, _lánv, yöso, 
   {{0x29cc1b24,0x2d8006ed,0xd36c00c6,0x00000000}},	//   _užas_, _olhe_, تهي_, --, 
   {{0x2cac00bc,0x2904000d,0xdfe821f3,0x00000000}},	//   ředy_, _õlad_, мдод_, --, 
   {{0x2fc8020c,0x00000000,0x00000000,0x00000000}},	//   _bhag_, --, --, --, 
   {{0x2fc88e4e,0xe2b400ee,0xd4c0013d,0xe214004e}},	//   _chag_, _ислэ, _төчк, _амды, 
   {{0x29100161,0x2fc80067,0xa2cc2802,0x4fa00107}},	//   _odza_, _dhag_, देश्, рияв, 
   {{0x291007a9,0x398441b5,0x7dc00267,0x2054bb65}},	//   _ndza_, _köse_, röso, _атир, 
   {{0x2fc808c2,0x3f8000a3,0xdb14007f,0x62880036}},	//   _fhag_, _tliu_, dmyò, lzeo, 
   {{0x29122b38,0x160001ad,0x39840112,0xfa840240}},	//   _adza_, रीडर_, _möse_, _ሓሸውየ_, 
   {{0x39840112,0x1ec80108,0x00000000,0x00000000}},	// [3fdc0] _löse_, _юлии_, --, --, 
   {{0x25a499a6,0x2450025c,0x2fc80240,0x40cc01e1}},	//   _njll_, _oġm_, _zhag_, _lẹmọ_, 
   {{0x7bd8011c,0x7dc001f4,0x00000000,0x00000000}},	//   _èvuo, nösm, --, --, 
   {{0x29100433,0x637403b2,0xbec800ef,0x00000000}},	//   _edza_, _kánu, _etīž, --, 
   {{0x25fc45bf,0xc6f40845,0xb8e8015b,0x00000000}},	//   रीली_, тніх_, _উল_, --, 
   {{0x637400fc,0x398403fa,0x6288013f,0x7dc001f4}},	//   _mánu, _böse_, dzeo, kösm, 
   {{0x24d4009e,0x27f00118,0x63740aab,0x00000000}},	//   _স্বহ, ěnné_, _lánu, --, 
   {{0xdb0401a8,0x00000000,0x00000000,0x00000000}},	//   _akkú, --, --, --, 
   {{0x2fc800a9,0x55e402bf,0x43700640,0xa2cc00c5}},	//   _rhag_, _розб, рујт, देल्, 
   {{0x2fca2b39,0xd1b80150,0x63ae2b3a,0xb51c01ad}},	//   _shag_, باعا_, čana, _नाटय_, 
   {{0x5344865c,0x25a807ea,0x6288005a,0x0574007b}},	//   _ахла, éale_, azeo, _جملة_, 
   {{0xc2e0036b,0x78bc143a,0x40cc0ca8,0x00000000}},	//   _кўши, _myrv, _kẹjọ_, --, 
   {{0x2c500034,0x63740118,0x68440092,0x2165a4ef}},	//   _sąd_, _pánv, _የዋስት, ттөг, 
   {{0x7054e869,0x40cc0241,0x7ec801e1,0xe2a802da}},	//   _منتا, _mẹjọ_, _sèpí, _ثامن_, 
   {{0x0ec401ad,0x2fc80051,0x29100210,0x00000000}},	//   रेजड, _thag_, _rdza_, --, 
   {{0x660ce13c,0x809c01ad,0x637402d2,0x7c2801c3}},	//   šaki, ऑपरे, _fánu, àdra, 
   {{0x66e42c1d,0x78bc062c,0x2d80ae80,0xe6b003ce}},	// [3fdd0] қола, _ayrv, _tlhe_, _जडेज, 
   {{0x1ce00135,0x6e2e2b3b,0xf9901b45,0x81dc00fe}},	//   _སུར_, _iqab, يبل_, ধীক_, 
   {{0xe7180491,0x0590036b,0x7dc001f4,0x00000000}},	//   فيات_, یاتگ, kösj, --, 
   {{0xf7722b3c,0x64a40184,0xe70404fb,0xddd400a2}},	//   يان_, һала, اسای, _aryň, 
   {{0x6e2c025c,0x63740241,0x00000000,0x00000000}},	//   _jqab, _mánt, --, --, 
   {{0x2910a238,0x6e2c0003,0x63753728,0xb5c80214}},	//   _udza_, _mqab, _lánt, نونم_, 
   {{0x1ce00135,0xd90c00ec,0x00000000,0x00000000}},	//   _སུལ_, _رڌل_, --, --, 
   {{0xa0a4005e,0x2a6c068f,0x6e2c014b,0x637551c2}},	//   ғамд, _żeby_, _oqab, _nánt, 
   {{0x6e2e2b3d,0x21740107,0xc32c0a81,0x57a401ee}},	//   _nqab, гунр, مٕژ_, _сырҡ, 
   {{0x6fe800bc,0x6abc007c,0x3984013d,0xd180008e}},	//   _věcn, _mysf, _töse_, йлый, 
   {{0x6e2e2b3e,0x6abc0ac8,0x6374772a,0xe2840075}},	//   _aqab, _lysf, _bánt, _әлли, 
   {{0x63742b76,0xf48421cb,0x00000000,0x00000000}},	//   _cánt, _туун, --, --, 
   {{0x6374007b,0x40cc0248,0xd00c8e33,0x6e0400c7}},	//   _dánt, _kẹkọ_, يلی_, аҭым_, 
   {{0x9f680139,0x00000000,0x00000000,0x00000000}},	//   фрүз_, --, --, --, 
   {{0x6e2c0b6f,0x2578067c,0xdee40116,0x61e80309}},	//   _eqab, _vèlh_, _йойи, lqel, 
   {{0xe3e40011,0x6374032e,0x00000000,0x00000000}},	//   _নবাব, _tánu, --, --, 
   {{0x637400d2,0x6e2c0472,0x78bc003a,0x61ea2b3f}},	// [3fde0] _háns, _gqab, _syrv, nqel, 
   {{0x2578068c,0x3a202e5e,0x9d440120,0xc82c0092}},	//   _uèlh_, ruip_, _сеод, _አላምን, 
   {{0x25780ba1,0x661c143a,0x3a200af9,0x637402f0}},	//   _gèli_, _åskj, suip_, _jáns, 
   {{0xa8540640,0x7dc0005b,0x9bf40139,0x78bc01ef}},	//   штуј, kösk, _изүч, _vyrv, 
   {{0xd5b83a22,0x3a201730,0x6375ddce,0x645400d0}},	//   нск_, quip_, _láns, _ázij, 
   {{0x1ce00003,0x67280200,0xceb00677,0x75d491e8}},	//   _སུས_, _ecej, זיד_, جيتا, 
   {{0x15b801e0,0x637402d2,0xa86400fb,0x00000000}},	//   мыҫы_, _náns, _керҙ, --, 
   {{0x068047da,0x087404ac,0x3374013e,0x00000000}},	//   ргән, _געלט_, ргир, --, 
   {{0x63753d26,0x61e80472,0xdb040200,0x00000000}},	//   _ránt, gqel, _ajkë, --, 
   {{0xcee81b8f,0xc0b80240,0xe8680092,0x00000000}},	//   کردن_, ሰፍሐ_, ደርጉም_, --, 
   {{0xc0541c26,0xe4e83fa9,0x63745923,0x00000000}},	//   гія_, _شعله_, _pánt, --, 
   {{0x7dc001e6,0x63740122,0x00000000,0x00000000}},	//   lösh, _dáns, --, --, 
   {{0x69b800cd,0x00000000,0x00000000,0x00000000}},	//   ्तमी, --, --, --, 
   {{0x22583986,0x8fc000c7,0x00000000,0x00000000}},	//   æske_, раҭҵ, --, --, 
   {{0x7b6429db,0x41b800d9,0x99900210,0x00000000}},	//   әтсе, _רצוע, krył_, --, 
   {{0x6e2c0135,0x00000000,0x00000000,0x00000000}},	//   _tqab, --, --, --, 
   {{0x6e2d002b,0x9e9400d1,0x7dc001f4,0x00000000}},	// [3fdf0] _uqab, _پايچ, kösh, --, 
   {{0x6d3431e2,0x48aa2b40,0x00000000,0x00000000}},	//   _теоф, нтем_, --, --, 
   {{0x48a801f0,0x00000000,0x00000000,0x00000000}},	//   хтам_, --, --, --, 
   {{0x8704005e,0xa5f99bc2,0x6abc143a,0x61e80113}},	//   ابال, веду_, _tysf, yqel, 
   {{0xd2462b41,0xd0040050,0x00000000,0x00000000}},	//   _بن_, _ڈل_, --, --, 
   {{0xd004bb6e,0x27140016,0x35f804fb,0x61e800ac}},	//   _ول_, ền_, ارند_, vqel, 
   {{0x9f50036e,0x00000000,0x00000000,0x00000000}},	//   ëzë_, --, --, --, 
   {{0x63ac00d0,0x7dc0d7af,0x64a4446e,0x63762b42}},	//   čano, tösk, лаһа, _ráns, 
   {{0x50d4004b,0x63762b43,0xe2c800f1,0xe2980114}},	//   یزپر, _sáns, کوکو_, ђао_, 
   {{0x637403c6,0x2174412c,0x7dc22b44,0x61e80200}},	//   _páns, руир, rösk, rqel, 
   {{0xb385c9b6,0xe7a82802,0xfe4400d1,0x00000000}},	//   рлөл, _कदाप, әмгү, --, 
   {{0x62347724,0x16000490,0x3f8596f2,0x00000000}},	//   _веду, रीवर_, ómu_, --, 
   {{0x3984049f,0x61e8208d,0xde3402d5,0xddc401d5}},	//   _lösa_, qqel, шэнь, ибми, 
   {{0xe1f80024,0x32000166,0xdb140108,0x00000000}},	//   mpų_, _çiya_, nmyö, --, 
   {{0x1fa8768b,0xe1f80006,0x00000000,0x00000000}},	//   _икки_, lpų_, --, --, 
   {{0xdfd000b2,0x236c036e,0x5f740133,0x8fa002e8}},	//   _ڏيڻ_, njej_, _خاتر, _маще, 
   {{0x1d1980e2,0x5a640351,0x3ab40116,0x63740241}},	// [3fe00] _июнь_, шкаб, сәнт, _yánr, 
   {{0xc9600212,0x236c0455,0x98d8e7eb,0x7dc00108}},	//   овуй, hjej_, نباز_, kösi, 
   {{0xd1140375,0xd708005b,0x00000000,0x00000000}},	//   שקעה_, внее_, --, --, 
   {{0x656000ad,0x257804fb,0x47c0011c,0x00000000}},	//   _anlh, _mèlu_, обхв, --, 
   {{0xe728004b,0x25780241,0x63ac0419,0x00000000}},	//   اسمو_, _lèlu_, čanl, --, 
   {{0x741400cf,0x8e540a1e,0xdcfc00e2,0x00000000}},	//   موتا, יינג_, _impē, --, 
   {{0x25a8007b,0xd704005b,0x63740248,0x7dc000e5}},	//   éala_, _взби, _ránr, rösh, 
   {{0x65600022,0x236c0240,0xd7b001f9,0x00000000}},	//   _enlh, gjej_, जवळच, --, 
   {{0x68e8084c,0x6fe8013a,0x00000000,0x00000000}},	//   _şedi, _věcm, --, --, 
   {{0x3d20012d,0x00000000,0x00000000,0x00000000}},	//   बलों_, --, --, --, 
   {{0x660c0113,0x4fc5c4c7,0x00000000,0x00000000}},	//   šakt, исма, --, --, 
   {{0x25fc6495,0x35c4013e,0x09d00073,0x00000000}},	//   रीकी_, _таҷҳ, _तळ्य, --, 
   {{0x65600076,0xf1f4008e,0x00000000,0x00000000}},	//   _ynlh, _узлэ, --, --, 
   {{0x2d840034,0xdb141f3f,0x61ec007b,0xc278011a}},	//   óle_, loyè, _éala, _ברדי, 
   {{0x25b800c6,0x3cec02fb,0xdcfc00ef,0x00904b00}},	//   _ísle_, _živý_, _ampē, _мишэ, 
   {{0x398405d5,0x27e401ed,0xa2cc043e,0x80d8123b}},	//   _rösa_, _élni_, देक्, _בחוז, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3fe10] --, --, --, --, 
   {{0x60cc01e4,0x661c143a,0x637400ae,0x2a68058a}},	//   _ŝami, _åski, _lánp, rxab_, 
   {{0x0ca80276,0xc864cd99,0xfe700133,0xfeb80244}},	//   _штии_, штаи, _فدی_, _مایت_, 
   {{0x60d800c8,0x20100419,0x00000000,0x00000000}},	//   אַנג, ázii_, --, --, 
   {{0xf770da67,0xda1c000d,0x00000000,0x00000000}},	//   بال_, _पियत_, --, --, 
   {{0x63ac00d0,0x7dc00108,0x00000000,0x00000000}},	//   čanm, tösi, --, --, 
   {{0xf9900014,0xa444036b,0x236c0267,0x6fe8013a}},	//   _آبُ_, ёнид, tjej_, _děck, 
   {{0xd24c00aa,0x3d2005ac,0xe1240131,0x66940240}},	//   ځني_, ম্প্_, әмни, ሃላልዋ_, 
   {{0xd24c0597,0x22580321,0x00000000,0x00000000}},	//   فني_, ísk_, --, --, 
   {{0x257a2b45,0xe1f80153,0x00000000,0x00000000}},	//   _pèlu_, rpų_, --, --, 
   {{0xdee404a9,0x201000e5,0xade00037,0x00000000}},	//   йони, ézi_, _गंजन_, --, 
   {{0x6fe80118,0x236c047e,0x2018007f,0x7dc05a03}},	//   _měch, qjej_, čsi_, nösv, 
   {{0xdcfc00cd,0xf38c008f,0x217400ee,0x934400cf}},	//   _alpā, _בראָ, _гуйр, _دىنۇ, 
   {{0xdd922b46,0xd25402e4,0x98b80356,0xfc380124}},	//   سوز_, _לשנה_, nepă_, аҭо_, 
   {{0xd0040276,0xdb140036,0xdea0158b,0x63740241}},	//   _леще_, loyé, تیکی, _yánp, 
   {{0x5f740344,0x9e64009b,0x00000000,0x00000000}},	//   _چاکر, _гвид, --, --, 
   {{0x5f744046,0x5aca2b47,0x09e00124,0x00000000}},	// [3fe20] _ناکر, улам_, зоун, --, 
   {{0x1868026a,0x6b800af9,0x6fe801ef,0x00000000}},	//   лази_, ëlgr, _běch, --, 
   {{0x63ac341a,0x00000000,0x00000000,0x00000000}},	//   čanj, --, --, --, 
   {{0xd70809a5,0xdb1402ea,0x764403ee,0x00000000}},	//   унде_, koyé, çiyo, --, 
   {{0x94100cc1,0x3b00014f,0x63740241,0x7bc400c0}},	//   əcək_, mbiq_, _ránp, mliu, 
   {{0x7bc62b48,0x86040597,0x38c8f968,0x637401e1}},	//   lliu, حقوق_, _نازی_, _sánp, 
   {{0x7bc40024,0x738800d1,0x96f80064,0x92a40210}},	//   oliu, ириң_, _бэзу_, zbłę, 
   {{0x257856ec,0x7bc62b49,0x72197c97,0x3b00014f}},	//   _bèls_, nliu, ажир_, nbiq_, 
   {{0x7dc13c7a,0x2578067c,0x7bc62b4a,0xdb14020c}},	//   lösu, _cèls_, iliu, royè, 
   {{0x7bc40399,0x3a20013c,0x22580158,0x3b00014f}},	//   hliu, irip_, æska_, hbiq_, 
   {{0x7bc62b4b,0xa02000c5,0x3a200790,0xd17402dd}},	//   kliu, _ööla, hrip_, _қыды, 
   {{0x3a202819,0xe2f401e1,0x00000000,0x00000000}},	//   krip_, _lọjà_, --, --, 
   {{0x11f401d5,0x7bc401ab,0xb50c0550,0x3b007885}},	//   _اوتک_, dliu, _सजाय_, dbiq_, 
   {{0xc6900bd9,0x7bc62b4c,0x7dc001f4,0x90640114}},	//   לאר_, eliu, kösu, _гњил, 
   {{0xfc6402e8,0x661c01e3,0xea680092,0x7bc62b4d}},	//   пътн, _åskv, _ተራዘመ_, fliu, 
   {{0xcfaa2b4e,0x7bc4db60,0xce6807b5,0x50380092}},	//   _حاتم_, gliu, _брод_, _እራሳች, 
   {{0x3a222b4f,0xff504fca,0xeb980209,0x6ce4247f}},	// [3fe30] grip_, _سخي_, гиң_, _وزدە, 
   {{0x7bc62b50,0xe9180212,0xad4000cf,0xc27800df}},	//   aliu, рожі_, _تۉسۉ, ארמי, 
   {{0x7bc62b51,0x3a200eda,0x1ce00135,0x6d54003c}},	//   bliu, arip_, _སུག_, mdza, 
   {{0x6d540196,0x7bc40381,0x7a3000c7,0xe7b800ee}},	//   ldza, cliu, _ẽteg, шгеш_, 
   {{0xf77015b0,0x25d880fd,0xdb0403b2,0xa50813d6}},	//   عام_, амды_, _ekkó, аела_, 
   {{0x6d562b52,0x6b8c5bae,0x6fe80316,0xdc54034c}},	//   ndza, lhag, _těch, _اریک, 
   {{0x29004147,0x25fc02e5,0x6d5400e2,0x7dc00108}},	//   mbha_, रीजी_, idza, möst, 
   {{0x7dc22b53,0x257800db,0x6d54003e,0x29022b54}},	//   löst, _pèls_, hdza, lbha_, 
   {{0xe12575c2,0x69c62b55,0x6b8c1368,0x26d80ca8}},	//   омпи, olhe, ihag, _àso_, 
   {{0x29000649,0x7dc008ae,0x7bc62b56,0x6d562b57}},	//   nbha_, nöst, zliu, jdza, 
   {{0x69c62b58,0xdeec044e,0x6b8e2b59,0x7de00248}},	//   ilhe, _ጀጋኑ_, khag, _lásì, 
   {{0x44262b5a,0x3a200cf9,0x6d562b5b,0x7bc40007}},	//   mun_, yrip_, edza, xliu, 
   {{0x63aa2b5c,0x1ce00135,0x6b8e2b5d,0x6d540d27}},	//   mnen, _སུང_, dhag, fdza, 
   {{0x44262b5e,0xdc94044e,0x63aa2b5f,0x6440007f}},	//   oun_, _ፍልልይ_, lnen, _kpli, 
   {{0x44262b60,0x3b00f7c0,0x63aa2b61,0x7de001e1}},	//   nun_, tbiq_, onen, _aásì, 
   {{0x63aa2b62,0x3a222b63,0x69c62b64,0x6b8e2b65}},	//   nnen, trip_, elhe, ghag, 
   {{0x44242434,0x7bc62b66,0x3a2000f2,0x3b000327}},	// [3fe40] hun_, rliu, urip_, rbiq_, 
   {{0x44262b67,0x6440ea11,0x63aa2b68,0x3a222b69}},	//   kun_, _opli, hnen, rrip_, 
   {{0x7bc62b6a,0xdc6805f5,0x64400211,0x6b8d8648}},	//   pliu, _танд_, _npli, bhag, 
   {{0x6b8e2b6b,0x44262b6c,0x63aa2b6d,0x69c59be6}},	//   chag, dun_, jnen, alhe, 
   {{0x44241dd4,0x63a801f1,0x46e400fd,0x29022b6e}},	//   eun_, dnen, әдән_, bbha_, 
   {{0x8c400365,0x26cc0099,0x61ec0209,0x7dc0403a}},	//   ışve, _dzeo_, _çaly, möss, 
   {{0x69b80da5,0x44262b6f,0x6440003a,0x799c010a}},	//   ्तरी, gun_, _cpli, _imrw, 
   {{0x63aa2b70,0xdebc00b7,0x2bec17cb,0xb2740075}},	//   gnen, ደርን_, _आंसू_, злиш, 
   {{0x44262b71,0x7dc22b72,0x64422b73,0x00000000}},	//   aun_, nöss, _epli, --, 
   {{0x44262b74,0x63aa2b75,0x00000000,0x00000000}},	//   bun_, anen, --, --, 
   {{0x44262b76,0x63a80030,0x25b803b2,0xd14801d5}},	//   cun_, bnen, _ísla_, هشگن_, 
   {{0x91e504b6,0x6d540034,0x6b8c0097,0x63aa2b77}},	//   _доде, wdza, xhag, cnen, 
   {{0xf1f401c0,0x7dc1901b,0xd9e8000d,0x6b8c00e4}},	//   _эзлэ, yöst, _झूलत_, vhag, 
   {{0x6d54004c,0x3cdc3996,0x799c035a,0x0ca802e8}},	//   udza, _गृहे_, _nmrw, атби_, 
   {{0x6b8e2b78,0x100800db,0x6d545b38,0xcb086ed2}},	//   thag, _ئتتى_, rdza, ихад_, 
   {{0xb4f811b1,0x290006a3,0x799c015d,0x20c8009f}},	//   ुरुप_, wbha_, _amrw, _ابهي_, 
   {{0x44262b79,0x69c62b7a,0x7dc0023a,0x2fd80790}},	// [3fe50] zun_, tlhe, töst, mmsg_, 
   {{0x6b8e2b7b,0x44262b7c,0x63aa2b7d,0x63ac6517}},	//   shag, yun_, znen, čani, 
   {{0x6b8e2b7e,0x7dc03714,0x69c570d3,0x44262b7f}},	//   phag, röst, rlhe, xun_, 
   {{0x44262b80,0x6ce40efb,0x6b8c00aa,0x644400ad}},	//   vun_, _وزگە, qhag, çhim, 
   {{0x44262b81,0x63aa2b82,0xfd5001f2,0x64422b83}},	//   wun_, vnen, _nchụ, _spli, 
   {{0x44262b84,0x6f0e2b85,0x2b4a2b86,0xa978004e}},	//   tun_, _leac, leac_, _уйгу_, 
   {{0xfd5002e3,0x63aa2b87,0x44262b88,0x3b1000fd}},	//   _achụ, tnen, uun_, _ölqä_, 
   {{0x6f0c0876,0x64400fb7,0x63aa2b89,0x2b4a2b8a}},	//   _neac, _vpli, unen, neac_, 
   {{0x26cc1326,0x13051987,0xe2985fd4,0x799c0368}},	//   _uzeo_, чный_, сап_, _ymrw, 
   {{0x44262b8b,0x63aa2b8c,0x6f0c0381,0x660801c8}},	//   pun_, snen, _aeac, _iwek, 
   {{0x44262b8d,0x7dc22b8e,0x6f0c53c6,0x66080433}},	//   qun_, zöss, _beac, _hwek, 
   {{0x660a2b8f,0x6f0c00c6,0x7dc002f6,0x661c007c}},	//   _kwek, _ceac, yöss, _åsks, 
   {{0x6f0c35b8,0x2b48030a,0x00000000,0x00000000}},	//   _deac, deac_, --, --, 
   {{0x6608a760,0x6f0c00ad,0x6b9c035a,0x201001d3}},	//   _mwek, _eeac, _amsg, ázis_, 
   {{0x6f0c7ea1,0x66088482,0x1d0800d1,0x799c02d0}},	//   _feac, _lwek, _қени_, _rmrw, 
   {{0x6f0e2b90,0x6b9c0022,0x660a2b91,0x2b4806af}},	//   _geac, _cmsg, _owek, geac_, 
   {{0x660800b4,0x6b9c0327,0x00000000,0x00000000}},	// [3fe60] _nwek, _dmsg, --, --, 
   {{0x1d24016c,0x7dc0fc1f,0x9f0407d6,0x6b9c03ac}},	//   _эмом, röss, _بوکو, _emsg, 
   {{0x7dc06c3f,0x1dd000cd,0x574400d8,0x00000000}},	//   söss, _दीयत, знеб, --, 
   {{0x66082252,0x224c007f,0xf8b22b92,0x00000000}},	//   _bwek, kwek_, _یکا_, --, 
   {{0x799c02d0,0x96640212,0x7c9c0092,0x00000000}},	//   _tmrw, якде, ፈጸመው_, --, 
   {{0xdebc001f,0x18680ce4,0xf578007b,0x6aa802d2}},	//   ደርና_, _лаги_, تمتع_, _þefa, 
   {{0x660a2b93,0x6b9c0175,0x00000000,0x00000000}},	//   _ewek, _ymsg, --, --, 
   {{0x66080100,0x15cc0150,0x00000000,0x00000000}},	//   _fwek, _ﯗﺩﺩﻩ, --, --, 
   {{0x6f0e2b94,0x66081418,0x2fd8010a,0x6d40000d}},	//   _reac, _gwek, vmsg_, õlak, 
   {{0x6f0e2b95,0x59bc0c00,0x2fd80175,0x00000000}},	//   _seac, ्तिर, wmsg_, --, 
   {{0x82301fe4,0x6608014b,0x6f0c2517,0x661c08fb}},	//   وریا, _zwek, _peac, _åskr, 
   {{0x224c0165,0x622000f7,0x00000000,0x00000000}},	//   bwek_, رۉۉل, --, --, 
   {{0x59bd1e83,0x6f0c0311,0x90a4036b,0x2fd80175}},	//   ्तार, _veac, تحکم, rmsg_, 
   {{0x6f0c3998,0xad2415c3,0x661c00b5,0x2fd8010a}},	//   _weac, بىسى, _æske, smsg_, 
   {{0x6f0e2b96,0x2b48005a,0xe50c00dc,0xddd4012d}},	//   _teac, teac_, हरति_, _brył, 
   {{0xe0845214,0x24900205,0x2264013d,0x00000000}},	//   _تجهي, _üzme_, _üpkä_, --, 
   {{0x2b487fb9,0xadb50081,0xe978cfc6,0x6e941d0f}},	// [3fe70] reac_, _обиш, обаш_, _ципу, 
   {{0xba742dfc,0x66080433,0xc6a4010b,0xe6100133}},	//   راقت, _rwek, үрди, ۆشت_, 
   {{0x66080564,0xebc40022,0xe7183a16,0xbdf80133}},	//   _swek, _жәан, قيات_, _وریا_, 
   {{0xb9041524,0x660a2b97,0xe6480023,0xb8d407d6}},	//   _पृ_, _pwek, _መልክዕ, رتلش, 
   {{0x9ba02928,0x659596ea,0x00000000,0x00000000}},	//   _شەكى, маду, --, --, 
   {{0x15400276,0xf67401c6,0xbc3805af,0x7dc001f4}},	//   вешм, эгчэ, _بسیا_, nösp, 
   {{0x1ce0025c,0x77a801d9,0x00000000,0x00000000}},	//   _སུབ_, _کێنہ_, --, --, 
   {{0xe1fa2b98,0x660a2b99,0x00000000,0x00000000}},	//   оги_, _twek, --, --, 
   {{0x66080451,0xb5c8c5ff,0x06d80154,0xd1d00092}},	//   _uwek, _کولم_, _ড্রি, _የገቡ_, 
   {{0x224c0ea0,0x00000000,0x00000000,0x00000000}},	//   rwek_, --, --, --, 
   {{0xa0240023,0x00000000,0x00000000,0x00000000}},	//   _ተሰዲዶ, --, --, --, 
   {{0x6374056a,0x00000000,0x00000000,0x00000000}},	//   _lánz, --, --, --, 
   {{0xc2c96eb0,0x8e040276,0x24d401ec,0x00000000}},	//   _ابال_, мняв_, _ﺘﻭﺠﻬ, --, 
   {{0x1ce00003,0xf0b8034c,0xd1d0001f,0x00000000}},	//   _སུད_, _کاهش_, _የገቢ_, --, 
   {{0xdb7c0020,0xdca4f3e5,0x1fb400ea,0x00000000}},	//   _የለውም_, фави, _осир, --, 
   {{0x3b6c0092,0x6b542081,0xdf200064,0x00000000}},	//   _ሰጪዎች_, нтух, _рэкi_, --, 
   {{0xc0b8001f,0xde040354,0x00000000,0x00000000}},	// [3fe80] ደውም_, _юппи, --, --, 
   {{0x6fc8012d,0x00000000,0x00000000,0x00000000}},	//   रतअं, --, --, --, 
   {{0x9bd800c6,0xf4280139,0xc68c0014,0xd1d00092}},	//   _мємє_, _kräş_, یِم_, _የገባ_, 
   {{0xd83c09a8,0x59bc012c,0xdb040205,0x00000000}},	//   ščob_, ्तहर, _akkö, --, 
   {{0xcb100a1e,0xc7a00114,0x00000000,0x00000000}},	//   _שלש_, њичк, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x637401ed,0x160001ad,0xd394013d,0x38c8691d}},	//   _hány, रीजर_, мәдә_, _راسی_, 
   {{0x6374f126,0x1ce00135,0x32542377,0x59bc00cd}},	//   _kány, _སུན_, евир, ्तवर, 
   {{0xc6c00372,0x9149b688,0x07a0026a,0xa2c0891e}},	//   _айтк, очна_, _ратн, ләшк, 
   {{0x395a2b9a,0x00000000,0x00000000,0x00000000}},	//   _jars_, --, --, --, 
   {{0x637400dd,0x8af40213,0xc950011a,0xdcfc00ef}},	//   _lány, çəkm, דמת_, _empī, 
   {{0x6e941de1,0x00000000,0x00000000,0x00000000}},	//   еиму, --, --, --, 
   {{0x39580225,0xdb0402f6,0xb640037e,0xc20c01d9}},	//   _oars_, _ykkö, _ｂｗ_, _نٔن_, 
   {{0x3958256c,0xdb24025a,0xf3c80345,0x00000000}},	//   _nars_, _äpêr, _ببڕه_, --, 
   {{0xc0d402d3,0xac940229,0x7054007b,0x00000000}},	//   _ጭርሖ_, хавш, _أنبا, --, 
   {{0x6375b834,0x3958508f,0x00000000,0x00000000}},	//   _sánz, _aars_, --, --, 
   {{0x395a2b9b,0xcd0509e0,0x00000000,0x00000000}},	// [3fe90] _bars_, _очни, --, --, 
   {{0x3958d999,0xba7402f2,0xaa6c0432,0x00000000}},	//   _cars_, خافت, _göýä_, --, 
   {{0x3958036b,0xfaf001d3,0x00000000,0x00000000}},	//   _dars_, اثہ_, --, --, 
   {{0x95280327,0x395826e7,0xcd280214,0x66b401ec}},	//   སཔའི_, _ears_, _اسکن_, нбеу, 
   {{0x395a2b9c,0x2b58007b,0x00000000,0x00000000}},	//   _fars_, _iasc_, --, --, 
   {{0x395a2b9d,0x61ec00d8,0x290403b2,0xf6640137}},	//   _gars_, _éali, _ýla_, тешү, 
   {{0x2910009d,0x59bc024a,0xa824258c,0x00000000}},	//   _ieza_, ्तरर, _سکان, --, 
   {{0x29100230,0x2b5800d8,0x63740241,0x395800ef}},	//   _heza_, _jasc_, _yány, _zars_, 
   {{0x2b5a2b9e,0x29122b9f,0x3d10000d,0x46d001f9}},	//   _masc_, _keza_, _तजले_, _तरिह, 
   {{0x45a03b5f,0x29122ba0,0x2b5800ae,0x00000000}},	//   _جەتك, _jeza_, _lasc_, --, 
   {{0xa069baad,0x28a402ab,0xe194009d,0x00000000}},	//   чана_, _गेमि, _үрлэ, --, 
   {{0x2b580597,0x63ac506e,0x29122ba1,0xe8101431}},	//   _nasc_, čans, _leza_, डीया_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x2910633d,0x44262ba2,0x63762ba3,0xf1c80150}},	//   _neza_, orn_, _rány, _قونى_, 
   {{0x2b5866ce,0x395a2ba4,0x2d940cb9,0xe810012c}},	//   _basc_, _rars_, тряс, डीमा_, 
   {{0x44262ba5,0x395a2ba6,0x2b5a2ba7,0x71700075}},	//   irn_, _sars_, _casc_, _مۇۋا, 
   {{0x1ce01b4b,0x395a2ba8,0x7f462ba9,0x4424e599}},	// [3fea0] _སུམ_, _pars_, _ibiq, hrn_, 
   {{0x291003ee,0x7e662baa,0x09e00183,0x39580213}},	//   _ceza_, _irip, যৱসা, _qars_, 
   {{0x291064d3,0x2b58070d,0x395a2bab,0xdca4014b}},	//   _deza_, _fasc_, _vars_, _чани, 
   {{0x39582734,0x637401d3,0xbb5402f2,0x00000000}},	//   _wars_, _tány, _جۆرب, --, 
   {{0x44262bac,0x87e41e4a,0x3958002e,0x7f44036e}},	//   ern_, رتمە, _tars_, _mbiq, 
   {{0x7e640e4a,0x00000000,0x00000000,0x00000000}},	//   _mrip, --, --, --, 
   {{0x09e03fae,0x7c3c2a9d,0x44242ab0,0xf8d400c5}},	//   যৱহা, ntrr, grn_, _थरिय, 
   {{0x2910c97f,0x7e662bad,0x00000000,0x00000000}},	//   _zeza_, _orip, --, --, 
   {{0x44262bae,0x2910676c,0xd6280a5b,0x00000000}},	//   arn_, _yeza_, _хозе_, --, 
   {{0x44240427,0x661c032e,0x84540bd6,0x00000000}},	//   brn_, _æska, фрәт_, --, 
   {{0x7e662baf,0xef1800f7,0x44240334,0x7e6001bf}},	//   _arip, үмү_, crn_, æmpn, 
   {{0x7e6425a9,0x249003b9,0x00000000,0x00000000}},	//   _brip, _üzma_, --, --, 
   {{0x7e4400c7,0x00000000,0x00000000,0x00000000}},	//   лхре, --, --, --, 
   {{0x7f440921,0x7e643fe5,0x4ad8095f,0xd01800f3}},	//   _ebiq, _drip, _मृगव, _ефи_, 
   {{0x7e662bb0,0x2b580036,0xe0d00014,0xe1e801d9}},	//   _erip, _pasc_, _پٲٹ_, _کى۪و_, 
   {{0x29122bb1,0xcee80451,0x6e94007b,0x00000000}},	//   _seza_, _عربن_, _للبا, --, 
   {{0x29122bb2,0x2b580208,0x44240165,0x8d8401c4}},	// [3feb0] _peza_, _vasc_, zrn_, _зунд, 
   {{0x44240731,0x2b580618,0x291003b9,0x6e3c002f}},	//   yrn_, _wasc_, _qeza_, mtsb, 
   {{0x6d44c28e,0x6e3e2bb3,0x63740077,0x2b58007b}},	//   _ibha, ltsb, _tánx, _tasc_, 
   {{0x291057e3,0x2b586679,0x322c0327,0x7c280bcd}},	//   _weza_, _uasc_, _ཨཀྵར_, ádre, 
   {{0x6e3e2bb4,0xf1d0145f,0x4424015d,0x00000000}},	//   ntsb, हतान, wrn_, --, 
   {{0x6e3c03fa,0x44240109,0x0948013d,0xfdf8011a}},	//   itsb, trn_, _эчми_, עצות_, 
   {{0x6d462bb5,0x00000000,0x00000000,0x00000000}},	//   _mbha, --, --, --, 
   {{0x44262bb6,0x6e3ca2ec,0x67d41eed,0x245000d7}},	//   rrn_, ktsb, _робу, _všm_, 
   {{0x6d462bb7,0x248800da,0xd24c007b,0xe55400d8}},	//   _obha, ņam_, قني_, _икањ, 
   {{0x6d4401ab,0x7e640240,0x44240010,0x6e3c01bf}},	//   _nbha, _rrip, prn_, dtsb, 
   {{0x7e640687,0x6e3e2bb8,0x602402e8,0x44240066}},	//   _srip, etsb, ъдна, _سراف, 
   {{0x7e662bb9,0x3984049f,0xd24c0b43,0x6e3c6eb8}},	//   _prip, _höst_, حنی_, ftsb, 
   {{0x6d44020c,0xdea064ec,0x7f440393,0x6e3c005c}},	//   _bbha, شیدی, _vbiq, gtsb, 
   {{0x6d440055,0x21a4009d,0x00000000,0x00000000}},	//   _cbha, _шилм, --, --, 
   {{0x42500075,0x6d4400b8,0x398408a5,0x5bc44e77}},	//   _شۆھر, _dbha, _möst_, نترف, 
   {{0x20062bba,0x6d443e44,0x7f462bbb,0x3984893b}},	//   mpli_, _ebha, _ubiq, _löst_, 
   {{0x6f0836ed,0x200400c8,0x7e662bbc,0x7c3c0240}},	// [3fec0] ñece, lpli_, _urip, strr, 
   {{0xc0c8001f,0x3f800037,0xdb140139,0x00000000}},	//   _በራስ_, _hoiu_, llyü, --, 
   {{0x2004434d,0x38c80d6d,0x5ea41f0d,0x00000000}},	//   npli_, راطی_, _سمگل, --, 
   {{0x0be00131,0xb6f80131,0x6ed8302b,0x9a9c030d}},	//   _ﺋﺎﻳﺮ, رىتا_, नेकु, _дугi, 
   {{0xe9701c5c,0x7bc40270,0xd5b8dead,0xc0c80092}},	//   _گۇلد, moiu, мск_, _በራሴ_, 
   {{0x3f80005a,0x7bc401ab,0x8360036b,0x00000000}},	//   _loiu_, loiu, یگنل, --, 
   {{0x98a40601,0xe970075e,0x97c41bbc,0x00000000}},	//   _риве, _دۇلد, _айве, --, 
   {{0x7bc40311,0x18a402a9,0x00000000,0x00000000}},	//   noiu, _заҳм, --, --, 
   {{0x398408a5,0x200400ef,0x00000000,0x00000000}},	//   _föst_, epli_, --, --, 
   {{0x7bc400c5,0xabc80150,0x00000000,0x00000000}},	//   hoiu, _ﺒﻌﻤﺎ, --, --, 
   {{0x3f8019f5,0x6d4405ef,0x00000000,0x00000000}},	//   _boiu_, _rbha, --, --, 
   {{0x83801de1,0x6fb40150,0x999000ee,0x6e3c202b}},	//   _выше, امحا, yryş_, ttsb, 
   {{0xcee80424,0xef0800e5,0x00000000,0x00000000}},	//   بردن_, وںکو_, --, --, 
   {{0x39840267,0x200400a2,0xc5f00677,0x00000000}},	//   _möss_, bpli_, ידש_, --, 
   {{0xdeb002dd,0x7bc40356,0x398401e3,0x7c8400f3}},	//   _ғұры, foiu, _löss_, ауте, 
   {{0x3f822bbd,0x33f80789,0x00000000,0x00000000}},	//   _goiu_, _méx_, --, --, 
   {{0xaf540588,0x6d4000c5,0x61ec0798,0x00000000}},	// [3fed0] _анқә, õlas, _éalt, --, 
   {{0x6d400013,0xdcec0166,0x00000000,0x00000000}},	//   òlad, bibı, --, --, 
   {{0xa2c802f8,0x398401e6,0x33f800e8,0x7bc40356}},	//   _हुन्, _röst_, _néx_, boiu, 
   {{0x2d822bbe,0x8704011b,0x66d400ec,0x00000000}},	//   _hohe_, тяже, هيائ, --, 
   {{0x2d822bbf,0x00000000,0x00000000,0x00000000}},	//   _kohe_, --, --, --, 
   {{0xc0c80020,0x6b8c090e,0x2d80003a,0xc9862bc0}},	//   _በራሱ_, lkag, _johe_, _руми, 
   {{0x69c62bc1,0x2d8003c1,0x6b8c017a,0xd8400118}},	//   mohe, _mohe_, okag, ěčí_, 
   {{0x69c62bc2,0x2fc80457,0x2d80123c,0x00000000}},	//   lohe, _nkag_, _lohe_, --, 
   {{0xa1c62bc3,0x3f800254,0x6b8e2bc4,0xf98c0023}},	//   лбид, _roiu_, ikag, _ዘረብኡ_, 
   {{0x27ee2bc5,0x600809fe,0x69c62bc6,0x3f8008e5}},	//   _hien_, нном_, nohe, _soiu_, 
   {{0x27ec1f21,0x6b8e2bc7,0x26cc020b,0xa0a4678d}},	//   _kien_, kkag, _hyeo_, уанд, 
   {{0x69c62bc8,0x2d80123c,0x27ec003d,0x200407c5}},	//   hohe, _aohe_, _jien_, rpli_, 
   {{0x63aa2bc9,0x6144a8fc,0x69c62bca,0x2d800564}},	//   mien, _бела, kohe, _bohe_, 
   {{0x27ee2bcb,0x69c534a4,0x20058435,0x628a2bcc}},	//   _lien_, johe, ppli_, myeo, 
   {{0x3f8019f5,0x41cc0d0a,0x69c40023,0x63a80d27}},	//   _toiu_, _सीएस, dohe, oien, 
   {{0x6b8cda76,0x27ee2bcd,0x6d400254,0x6fc401f9}},	//   gkag, _nien_, õlar, रवणू, 
   {{0x628a2bce,0x2d8003a0,0x69c62bcf,0x7bc62bd0}},	// [3fee0] nyeo, _fohe_, fohe, roiu, 
   {{0x63aa2bd1,0x6b8e2bd2,0x69c62bd3,0x7bc49bc1}},	//   hien, akag, gohe, soiu, 
   {{0x27ee2bd4,0x63aa2bd5,0x62880263,0x6b8c0009}},	//   _bien_, kien, hyeo, bkag, 
   {{0x63aa2bd6,0x27ee2bd7,0x6b8e2bd8,0x6288020b}},	//   jien, _cien_, ckag, kyeo, 
   {{0x69c4039e,0x63aa2bd9,0x27ee2bda,0xc6a001c0}},	//   bohe, dien, _dien_, йрши, 
   {{0x69c62bdb,0x8e5425f9,0x63a9b35d,0x25a49e69}},	//   cohe, טינג_, eien, _cmll_, 
   {{0x63aa2bdc,0x27ec01f5,0x938806ed,0x349401b9}},	//   fien, _fien_, еспа_, райр, 
   {{0x63aa2bdd,0x27ee2bde,0x7ec001ef,0x00000000}},	//   gien, _gien_, _zápů, --, 
   {{0x51862bdf,0x8380023a,0x00000000,0x00000000}},	//   гуна, сыще, --, --, 
   {{0x27ee2be0,0x63aa2be1,0x6b8c01c6,0x2fc80af9}},	//   _zien_, aien, zkag, _skag_, 
   {{0x2d800325,0x27ec00ad,0xd51000f1,0x6b8e2be2}},	//   _rohe_, _yien_, _نېږد, ykag, 
   {{0x63aa2be3,0x69c4044e,0x95740020,0xcf241b45}},	//   cien, zohe, ሪዎችን_, دردي, 
   {{0x4ea62be4,0x69c5bf5e,0x6288213f,0x2d8002b1}},	//   урна, yohe, cyeo, _pohe_, 
   {{0x69c40023,0x8c340107,0x00000000,0x00000000}},	//   xohe, логӣ_, --, --, 
   {{0x69c62be5,0x2fc8017a,0x5ea40154,0x3c940117}},	//   vohe, _tkag_, _গুদে, бирё, 
   {{0x69c42dab,0xf7c01c5c,0x2d8000f2,0x6d6000f3}},	//   wohe, ﻣﺎﻧﺪ, _wohe_, _žvać, 
   {{0x27ee074a,0x69c62be6,0x6b8e2be7,0x2d8004fe}},	// [3fef0] _rien_, tohe, rkag, _tohe_, 
   {{0x27ee2be8,0xb908063f,0x2dc80046,0x39141188}},	//   _sien_, _iriọ_, _جابۋ_, ймур, 
   {{0x69c62be9,0x27ee2bea,0x63a9b01d,0xa6f400d8}},	//   rohe, _pien_, yien, азеш, 
   {{0x69c4044e,0x63a8056a,0xd7080075,0x27ec0789}},	//   sohe, xien, نىمۇ_, _qien_, 
   {{0x63aa2beb,0x27ee2bec,0x69c62bed,0xf7700b61}},	//   vien, _vien_, pohe, ثال_, 
   {{0x27ee2bee,0x63aa2bef,0x26cc00ec,0x69c62bf0}},	//   _wien_, wien, _vyeo_, qohe, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x27ec0d27,0x61fc02fb,0x63a991b8,0x63842360}},	//   _uien_, íslo, uien, ргиа, 
   {{0xe29a2bf1,0x6d580134,0xa5f81d0f,0x00000000}},	//   тап_, _ɔwar, _резу_, --, 
   {{0x62880165,0xe04400d8,0xb7bc01e1,0x00000000}},	//   ryeo, анои, _ọ̀ru, --, 
   {{0x63a98e53,0xdcec00b0,0x20101f3f,0x00000000}},	//   pien, ākīt, èzi_, --, 
   {{0xa2dc01bc,0x62880332,0x2d84007c,0x9834011a}},	//   _परप्, pyeo, ölen_, סטרו_, 
   {{0x6f08937c,0x975405d0,0x00000000,0x00000000}},	//   ñeca, בירו_, --, --, 
   {{0x9298011a,0xf0a801ec,0x00000000,0x00000000}},	//   _בינת, _өкіл_, --, --, 
   {{0x10a00dab,0xa2c80303,0x00000000,0x00000000}},	//   _мишн, _हुत्, --, --, 
   {{0x9b040e4e,0x95740092,0x00000000,0x00000000}},	//   рзад, ሪዎቹን_, --, --, 
   {{0x6d4001c3,0xa2dc06e3,0x00000000,0x00000000}},	// [3ff00] òlac, _परफ्, --, --, 
   {{0x9d462bf2,0xa2de012b,0x186983eb,0x661c143a}},	//   _теод, _परन्, кази_, _åsky, 
   {{0xe8100073,0x00000000,0x00000000,0x00000000}},	//   डीला_, --, --, --, 
   {{0x8c180375,0x966404b4,0x00000000,0x00000000}},	//   _בוטי, икее, --, --, 
   {{0x850000f1,0x00000000,0x00000000,0x00000000}},	//   ښوون, --, --, --, 
   {{0x7d1e2bf3,0x44f008b0,0x3a200194,0xceb00375}},	//   nars, يسىز, msip_, חיד_, 
   {{0x6754006c,0x3a200869,0x7d1e2bf4,0xb9fc0092}},	//   _گینس_, lsip_, iars, _ጆሮ_, 
   {{0x7d1c102c,0x43800131,0x00000000,0x00000000}},	//   hars, قلىق, --, --, 
   {{0x1dc43812,0x04a0002b,0x00000000,0x00000000}},	//   लकात, _māṇi, --, --, 
   {{0x7d1c1d1d,0x3a222bf5,0x50662bf6,0x7760022e}},	//   jars, isip_, атма, _hamx, 
   {{0x2f181b04,0x77606521,0x00000000,0x00000000}},	//   лонь_, _kamx, --, --, 
   {{0x3a200784,0x61440131,0xcfa40124,0x00000000}},	//   ksip_, لىۋە, ршои, --, 
   {{0x7d1e2bf7,0xaf540022,0x00000000,0x00000000}},	//   fars, анҟә, --, --, 
   {{0x7760208d,0x16f4025c,0x11641968,0x6fdccb71}},	//   _lamx, _བུའམ_, _ضلعی_, déce, 
   {{0x0ba4732e,0x00000000,0x00000000,0x00000000}},	//   ашам, --, --, --, 
   {{0xa2dc3be5,0x7d1c0140,0xaa580117,0x271400c5}},	//   _परम्, aars, либу_, _ढ़ेर_, 
   {{0x7d1c22a9,0x6f1c08d5,0x37ac015b,0x00000000}},	// [3ff10] bars, masc, গকার, --, 
   {{0xcdca1061,0x09043075,0x00000000,0x00000000}},	//   _جذبن_, рчам, --, --, 
   {{0x6d562bf8,0x77600921,0xfbd000dd,0x3a200194}},	//   meza, _bamx, ستہ_, asip_, 
   {{0x6f1e2bf9,0x6d547bd6,0xf56800dd,0x60e40213}},	//   nasc, leza, یمنٹ_, ürmə, 
   {{0x6f1c0276,0xf770b74b,0x67d401b9,0x00000000}},	//   iasc, ظام_, _ҳову, --, 
   {{0xa2dc06ff,0xc1bc0150,0x8544013d,0x00000000}},	//   _परब्, _ﺯﻳﺮﺍ, рэде, --, 
   {{0x2900006c,0x2c140c58,0x67d4497a,0x5f1800cd}},	//   mcha_, তংকৈ_, _гову, परम्_, 
   {{0x61b01d8a,0x6d562bfa,0x29022bfb,0x6f1c2a2a}},	//   ीक्ष, heza, lcha_, jasc, 
   {{0x7d1e2bfc,0x6f1e2bfd,0x6d562bfe,0x29022bff}},	//   yars, dasc, keza, ocha_, 
   {{0x29022c00,0x7d1e2c01,0x6d562c02,0x217401e0}},	//   ncha_, xars, jeza, суир, 
   {{0x6f1e2c03,0x6d562c04,0x7760d709,0xe4d400db}},	//   fasc, deza, _yamx, _اقاد, 
   {{0x6f1e2c05,0xa068052f,0x7d1e2c06,0x64422c07}},	//   gasc, _ҡала_, wars, _iqli, 
   {{0x7d1ceabc,0x6d562c08,0x29022c09,0x6560012c}},	//   tars, feza, kcha_, _kalh, 
   {{0x6d5517e4,0xdcfdc211,0x290002d1,0x7d1c013c}},	//   geza, _topč, jcha_, uars, 
   {{0x65622c0a,0x6f1cc044,0xe0d01f84,0x3a200194}},	//   _malh, basc, _عزت_, wsip_, 
   {{0x7d1e2c0b,0xa3c80a28,0x3a222c0c,0x6fdc0005}},	//   sars, ोति_, tsip_, téce, 
   {{0xdb6c001f,0x09c002f5,0xcb6402e8,0x04a0002b}},	// [3ff20] _አገዛዝ_, ্গনা, щате_, _vāṇi, 
   {{0x7d1c0680,0x6fdc1709,0x3a200eda,0x776001d4}},	//   qars, réce, rsip_, _samx, 
   {{0xa2c8072a,0xa3c827c6,0x00000000,0x00000000}},	//   _हुस्, ोता_, --, --, 
   {{0x29022c0d,0x3a222c0e,0x6560062c,0xdb0c00fd}},	//   acha_, psip_, _aalh, ädäg, 
   {{0x65622c0f,0x64413136,0x795403e6,0x41c40834}},	//   _balh, _aqli, _وێرا, रकास, 
   {{0x65608a8f,0x77600944,0x29001197,0x00000000}},	//   _calh, _wamx, ccha_, --, 
   {{0x65622c10,0x77616008,0x6f1e2c11,0x28100131}},	//   _dalh, _tamx, yasc, _يۈكس, 
   {{0x6d562c12,0x7ae000d2,0x656003ac,0x00000000}},	//   zeza, _úmts, _ealh, --, 
   {{0x6f1c4c41,0x65622c13,0x81c00eac,0x6fe8012d}},	//   vasc, _falh, ্ষন_, _uści, 
   {{0x656180bd,0x61ec0395,0x66800014,0x6f1d1276}},	//   _galh, _èall, _تیٖل, wasc, 
   {{0x6d54596b,0x6f1e2c14,0x6fba2c15,0x6f0911e5}},	//   veza, tasc, игор_, ñeco, 
   {{0x290104f8,0x6d547851,0x65600165,0x5ea80073}},	//   zcha_, weza, _zalh, _चेहऱ, 
   {{0x6f1e2c16,0x29022c17,0xe3b00014,0x61f8010e}},	//   rasc, ycha_, _ترٕ_, _guwl, 
   {{0x6f1e2c18,0x6d540489,0xa2dc00dc,0x6e2816a3}},	//   sasc, ueza, _परत्, šebo, 
   {{0x68040153,0xac1a2c19,0x100401d5,0x2900732e}},	//   _kėde, робу_, _уялм, vcha_, 
   {{0x6d544005,0x8ea8045e,0x40809ed2,0x2900da79}},	//   seza, _গুণগ, _хушб, wcha_, 
   {{0x29022c1a,0x6d562c1b,0x75280034,0xae4401d3}},	// [3ff30] tcha_, peza, _oddz, _بھجو, 
   {{0x661c01a8,0x6d540200,0xce90014b,0x00000000}},	//   _æski, qeza, _мақъ, --, 
   {{0x29007787,0x1bf000e1,0x6560067c,0xfeb85598}},	//   rcha_, _आंचल_, _ralh, _نایت_, 
   {{0x29013c16,0xe69400f7,0x65622c1c,0xddd4010e}},	//   scha_, يلاد, _salh, _kryş, 
   {{0x29022c1d,0x65603c2f,0x64422c1e,0xef180034}},	//   pcha_, _palh, _sqli, óży_, 
   {{0x29004ce9,0xdcfc3da0,0x2b4801bf,0xb5140154}},	//   qcha_, _kopā, lfac_, _সাউথ_, 
   {{0x81c0000e,0x61f800ee,0x2a680037,0x00000000}},	//   ্ষম_, _suwl, lvab_, --, 
   {{0x65622c1f,0x61f80113,0x73980220,0x24422c20}},	//   _walh, _puwl, йтыс_, róm_, 
   {{0x65622c21,0xd3440133,0xdcfc00b8,0x68040064}},	//   _talh, تینه_, _lopā, _dėde, 
   {{0xc0f002d3,0x6728025c,0x6e280327,0x00000000}},	//   _ፍርሒ_, _hdej, ġebl, --, 
   {{0xa2c8012c,0xddd400a2,0xdcfc002b,0x2a680254}},	//   _हुर्, _aryş, _nopā, hvab_, 
   {{0x6728025c,0x7df4010e,0x627400ec,0x00000000}},	//   _jdej, _ańsa, _وهائ, --, 
   {{0x2b4a2c22,0x6728031c,0xd00c04f2,0xf1d4000d}},	//   dfac_, _mdej, _یلو_, _ठीकन, 
   {{0xa06a2c23,0x660801f7,0xd5f80677,0xe0780066}},	//   _вака_, _mtek, יפשר, _نصبش_, 
   {{0xa0a40724,0x672945ce,0xdcfc00cd,0xcc84009b}},	//   _файд, _odej, _copā, обре_, 
   {{0x672a2c24,0x6d980309,0xdb5000e3,0x00000000}},	//   _ndej, _pìac, بَر_, --, 
   {{0x660a2c25,0x59847af6,0xdb1400e5,0x5cf40153}},	// [3ff40] _ntek, олаб, nnyé, _мяну, 
   {{0x672a2c26,0x7d000241,0x6fdc06af,0x1d080063}},	//   _adej, _dàró, méca, _њени_, 
   {{0x67280135,0xdcfc00cd,0x6fdc0129,0x00000000}},	//   _bdej, _gopā, léca, --, 
   {{0x5fc801bc,0xfbd80154,0x2cb400e5,0x00000000}},	//   रविल, _দূরত, őadó_, --, 
   {{0x6728031c,0x118c02d3,0x00000000,0x00000000}},	//   _ddej, _ዝፈጠሮ_, --, --, 
   {{0xe7080131,0x98a62c27,0x18a400c0,0xdcfc0055}},	//   لتۇن_, _диге, _дагм, _yopā, 
   {{0x9f50002e,0x6728025c,0x6fdc06af,0x5fc8b1e3}},	//   _ciyë_, _fdej, héca, रवाल, 
   {{0x136873f9,0xccf0011a,0x00000000,0x00000000}},	//   ршки_, וכו_, --, --, 
   {{0x27040208,0x00000000,0x00000000,0x00000000}},	//   _ồng_, --, --, --, 
   {{0x67280ebb,0x6fdc0109,0xd5ac00e5,0xe81028fe}},	//   _zdej, déca, _جہت_, डीका_, 
   {{0x864802d3,0x9f50033b,0xc304015b,0x98a80790}},	//   _ሓርነት, _kiyè_, োলজি_, _kabı_, 
   {{0x9f500699,0xaee804c5,0xcfa40212,0x00000000}},	//   _jiyè_, _ক্ষণ_, ішни, --, 
   {{0x51862c28,0xdcfc00cd,0x6ea4000d,0x05dc0210}},	//   _мука, _sopā, _चेखु, _पीडब, 
   {{0x0dc81ff0,0x98a80139,0x00000000,0x00000000}},	//   руми_, _labı_, --, --, 
   {{0x2bda2c29,0x70962c2a,0x00000000,0x00000000}},	//   مارک_, _хайф, --, --, 
   {{0xdd980107,0xdcfc00b8,0x00000000,0x00000000}},	//   ашӣ_, _vopā, --, --, 
   {{0x8d8405f5,0x2b480356,0x00000000,0x00000000}},	// [3ff50] _дунд, rfac_, --, --, 
   {{0xa2dc1a3e,0x893400c6,0x2b480311,0xadd80276}},	//   _परस्, تعرا, sfac_, _ымпу_, 
   {{0x660a2c2b,0x9f500100,0xd36400b2,0x2a6800af}},	//   _stek, _biyè_, _ٻه_, svab_, 
   {{0x67280327,0x37740139,0x00000000,0x00000000}},	//   _qdej, дышс, --, --, 
   {{0x81c00729,0xa5084358,0x8ae401ce,0xdec80092}},	//   ্ষত_, бела_, _фінл, _በዋና_, 
   {{0xae1c000d,0x118c0023,0x00000000,0x00000000}},	//   बीयन_, _ዝፈጥሮ_, --, --, 
   {{0x39a40014,0x9f500248,0xe45801d5,0x00000000}},	//   _تیلہ, _fiyè_, ёжи_, --, 
   {{0x77544bcc,0x672a2c2c,0x660a2c2d,0x00000000}},	//   _оксф, _udej, _ttek, --, 
   {{0x66084793,0xeff80023,0x6144010b,0xfbd4011a}},	//   _utek, ላኻዊ_, пепа, ותק_, 
   {{0xdb1400dd,0x681403e3,0x00000000,0x00000000}},	//   rnyé, _ağdə, --, --, 
   {{0xb5c90db3,0xf1a80133,0x00000000,0x00000000}},	//   _بولم_, ڵایه_, --, --, 
   {{0x9f50020c,0x6ee002e3,0xe3a400f2,0x00000000}},	//   _kiyé_, _ịban, _عشای, --, 
   {{0x33b000db,0x216801f0,0x00000000,0x00000000}},	//   _جەير, _гили_, --, --, 
   {{0x9f5002ea,0x661c01a8,0x6fdc0129,0x00000000}},	//   _miyé_, _æsku, réca, --, 
   {{0x75dc0139,0x60240209,0xf10400db,0x00000000}},	//   _hāzä, _эдйа, _تۉپۉ_, --, 
   {{0x50180302,0x00000000,0x00000000,0x00000000}},	//   _פופו, --, --, --, 
   {{0xdcfc0356,0x400400ec,0x00000000,0x00000000}},	// [3ff60] _copă, _ايڊٽ_, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x9f500241,0xed040150,0x398401d3,0x00000000}},	//   _aiyé_, _توپپ, _kösz_, --, 
   {{0xbb74afa0,0x98a85043,0xb8d40037,0x00000000}},	//   _تۇرع, _qabı_, _जइ_, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x09e22c2e,0x850016ac,0x65d80006,0x9f501ed9}},	//   _чорн, روين, цьцё_, _tiyè_, 
   {{0x98a40107,0xb27400d4,0xdb2401f4,0xa2dc043e}},	//   _диҳе, длиш, _äpär, _परश्, 
   {{0x8778008f,0x799c02d0,0xd5b0007b,0xb1c850e5}},	//   _פאמי, _klrw, _كفر_, оңда_, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x68040006,0x53f804fb,0x00000000,0x00000000}},	//   _kėda, _طراح_, --, --, 
   {{0xfd5400b8,0x00000000,0x00000000,0x00000000}},	//   _iyeṣ, --, --, --, 
   {{0xfd54002b,0xed5800fb,0x00000000,0x00000000}},	//   _hyeṣ, ҙоң_, --, --, 
   {{0x41e000d4,0xa6a800eb,0x00000000,0x00000000}},	//   _піща, _ছুঁয়, --, --, 
   {{0xdb140793,0x1008021f,0xfd5400dc,0x3ce8302b}},	//   boyü, _اتتى_, _jyeṣ, छेले_, 
   {{0x00b80375,0x7b65d87d,0x00000000,0x00000000}},	//   _למומ, нтуе, --, --, 
   {{0x6fdc20ef,0xfb3401c0,0x0dc800ee,0x644403e0}},	// [3ff70] léco, энтэ, _гуни_, çhiz, 
   {{0xad400228,0x2fd801ab,0xb4dc0073,0x4278010f}},	//   _جۉسۉ, llsg_, _ठरू_, זאמג, 
   {{0x6fdc004a,0x0ae82a29,0xfd54002b,0xdcfc00c0}},	//   néco, _گردي_, _nyeṣ, _alpė, 
   {{0x9f500214,0xdc55da3e,0xaa940354,0x00000000}},	//   _piyé_, _کریک, _жимч, --, 
   {{0xb8d4da62,0xe4c40213,0x6fdc0129,0x680400c0}},	//   _जे_, _köçə, héco, _dėda, 
   {{0x29040254,0x85200133,0xd5a401e2,0x00000000}},	//   _üla_, روبۆ, ولنی, --, 
   {{0xa3e81080,0x9f50002e,0xcabc0154,0x00000000}},	//   одка_, _wiyé_, _আরিফ, --, 
   {{0x6fdc004a,0xe298013e,0xaa300092,0x7c280162}},	//   déco, жаи_, _እርስዋ, ádri, 
   {{0x6fdc9ace,0xf65000ec,0xa1340066,0xa6340150}},	//   técn, _مئل_, وردش, _інжі, 
   {{0x35b4084c,0xcabc015b,0x24580229,0x00000000}},	//   _збур, _আরাফ, _мазь_, --, 
   {{0xe8100073,0xe1f0030f,0x8ea800cc,0xa0a4ce63}},	//   डीचा_, _یست_, _গুলগ, фанд, 
   {{0x44240175,0x00000000,0x00000000,0x00000000}},	//   msn_, --, --, --, 
   {{0x61462c2f,0x4424007c,0x00000000,0x00000000}},	//   _жела, lsn_, --, --, 
   {{0x61fc03c6,0x6b9c7ec8,0x00000000,0x00000000}},	//   íslu, _alsg, --, --, 
   {{0x8c422c30,0x44240036,0x70540354,0x8d600395}},	//   кере, nsn_, _пĕре, ъвре, 
   {{0x44262c31,0xfbd8000d,0x1ef800ae,0x00000000}},	//   isn_, _भीखम, _بعثة_, --, 
   {{0x7f440a73,0x0e6000f7,0xf1b400cd,0x00000000}},	// [3ff80] _iciq, _акын, ुवचन, --, 
   {{0x7e662c32,0x6b9c03ac,0x8e34008f,0x680400c0}},	//   _isip, _elsg, _קניא_, _sėda, 
   {{0x57441de8,0xa3cc0073,0x680400c0,0x00000000}},	//   днеб, ळवा_, _pėda, --, 
   {{0x7c3e2c33,0xb6c401e0,0x00000000,0x00000000}},	//   murr, ниеһ, --, --, 
   {{0x6f080f71,0x7c3e2c34,0x2bbc18ea,0x6fdc0129}},	//   ñeci, lurr, ्करा, décl, 
   {{0x7e6417fa,0x31a00100,0x98b800b0,0x44262c35}},	//   _msip, _kòze_, nepī_, fsn_, 
   {{0x7c3c198f,0x6b9c0175,0x6ed42e04,0x00000000}},	//   nurr, _ylsg, _युनु, --, 
   {{0x7c3c01c4,0x00000000,0x00000000,0x00000000}},	//   iurr, --, --, --, 
   {{0xea980a28,0x7c3e2c36,0x7e6407ab,0x88400092}},	//   maṃ_, hurr, _nsip, _ያልተሰ, 
   {{0xea981161,0x7c3c0323,0x30162c37,0xd1b8005e}},	//   laṃ_, kurr, ндор, تاعا_, 
   {{0x7e64094a,0x130834d8,0x7c3e2c38,0x00000000}},	//   _asip, _дней_, jurr, --, 
   {{0xea981161,0xa2c8134e,0x00000000,0x00000000}},	//   naṃ_, _हुक्, --, --, 
   {{0x7e64795e,0x94a801e0,0x69200327,0xdb1400e5}},	//   _csip, _утҡа_, lġeż, gnyí, 
   {{0xea981161,0x7e6408cd,0x7c3e2c39,0xbf4c01ef}},	//   haṃ_, _dsip, furr, _čížk, 
   {{0x7e640928,0xea981161,0x7c3e2c3a,0x80a0004b}},	//   _esip, kaṃ_, gurr, _لمون, 
   {{0xea980882,0xf990ba0b,0x00000000,0x00000000}},	//   jaṃ_, یبل_, --, --, 
   {{0xea980a28,0x7c3c01c4,0x81c00154,0x6e9400d8}},	// [3ff90] daṃ_, aurr, ্ষর_, _чипу, 
   {{0xf7703ef3,0x7c3e2c3b,0x4424022c,0x29d62c3c}},	//   یان_, burr, ysn_, رياس, 
   {{0x6e3e2c3d,0x7c3c307e,0x6d462c3e,0xe71800ae}},	//   lusb, curr, _icha, كيات_, 
   {{0xea980882,0x442401fa,0x6d44005a,0x9f500248}},	//   gaṃ_, vsn_, _hcha, _niyì_, 
   {{0xa509aca5,0x6e3e2c3f,0xc8d801f9,0x00000000}},	//   пела_, nusb, _भरकट, --, 
   {{0x44240109,0xeb34247f,0xa50816a4,0x00000000}},	//   tsn_, _تىڭد, чека_, --, 
   {{0x6d462c40,0xa5c40241,0x69d40d27,0xe4512f7a}},	//   _mcha, _akóì, _ikze, اضت_, 
   {{0x22162c41,0x6d44036b,0x62640108,0xea9800dc}},	//   нфор, _lcha, евиа, caṃ_, 
   {{0x6d462c42,0x7c3e2c43,0x44240221,0xf748007b}},	//   _ocha, zurr, ssn_, _تلقي_, 
   {{0x6d462c44,0x0574107b,0xa03c001f,0x6e3c0254}},	//   _ncha, _تارد, _በተከታ, dusb, 
   {{0xd00ce109,0x7e64003e,0x7c3c01c4,0xe0d84316}},	//   یلی_, _ssip, xurr, яво_, 
   {{0x34954ff3,0x31a0007f,0x7e64010e,0x7c3e2c45}},	//   _шахр, _ròze_, _psip, vurr, 
   {{0x6e3e2c46,0x7c3c0198,0xa19402d5,0x1b1c0183}},	//   gusb, wurr, _падч, _ফালে_, 
   {{0x61462c47,0x6d462c48,0x00000000,0x00000000}},	//   _чека, _ccha, --, --, 
   {{0xea981161,0x6d45bd9b,0x7c3c0687,0x6e3c1f8e}},	//   yaṃ_, _dcha, uurr, ausb, 
   {{0xd00c0597,0x7e662c49,0x7c3e2c4a,0x69d62c4b}},	//   _الي_, _tsip, rurr, _akze, 
   {{0x7c3e2c4c,0xea980a28,0x68040153,0x200401a9}},	// [3ffa0] surr, vaṃ_, _bėdo, lqli_, 
   {{0x7c3e2c4d,0x98a62c4e,0x00000000,0x00000000}},	//   purr, низе, --, --, 
   {{0xea981161,0x7c3c01d5,0x200403e3,0x00000000}},	//   taṃ_, qurr, nqli_, --, 
   {{0x69d41a4c,0x7c285b84,0x07a0005a,0x00000000}},	//   _ekze, ádru, лахн, --, 
   {{0xea981161,0x69d401fa,0x6d446a41,0x00000000}},	//   raṃ_, _fkze, _ycha, --, 
   {{0xceb000c8,0xea980882,0x68040153,0x1db000cd}},	//   ניג_, saṃ_, _gėdo, ुचित, 
   {{0xea980a28,0x33240054,0xdcfc0aea,0x450803d4}},	//   paṃ_, tamx_, _alpī, _ৰাখক_, 
   {{0x03c17b88,0xc3241c02,0x325407a5,0xecc401f9}},	//   лсым, ىكىن_, ввир, लॅटफ, 
   {{0xc7a00032,0x1db000ab,0x6e3c1ba6,0x07a22c4f}},	//   _ситк, ुचात, xusb, _сатн, 
   {{0x9f50011f,0x21240561,0x5468059f,0x00000000}},	//   _niyâ_, galh_, _назм_, --, 
   {{0x8934008f,0xc9500375,0x91a4033f,0x6d440175}},	//   ערטע_, אמת_, टोगै, _rcha, 
   {{0x6d462c50,0x6e3e2c51,0x13e800cf,0xf3f402f2}},	//   _scha, tusb, _эмей_, _شتاک, 
   {{0x21241497,0x6fdc04e6,0x6d445f0b,0x00000000}},	//   balh_, léck, _pcha, --, 
   {{0x6e3e2c52,0x3135c3cc,0x8d840853,0xc29402d5}},	//   rusb, _рекр, хумд, _якіх_, 
   {{0x013032ae,0x4c3002d3,0x6e3c0162,0x00000000}},	//   _صعود, _ክልቲኤ, susb, --, 
   {{0x68040064,0x80d8011a,0x00000000,0x00000000}},	//   _sėdo, _מחוז, --, --, 
   {{0x6fdc04c4,0x6f0cc010,0x68040024,0xdb140162}},	// [3ffb0] héck, _ifac, _pėdo, royð, 
   {{0x6d462c53,0x61ec011c,0x6e2c0099,0x88c4b071}},	//   _ucha, _èalt, _ivab, ىتال, 
   {{0x48a8004e,0xdb1403b2,0x00000000,0x00000000}},	//   чтам_, poyð, --, --, 
   {{0x6fdc0036,0x0ba800be,0x00000000,0x00000000}},	//   déck, _راجى_, --, --, 
   {{0x9ba00075,0x49b812fd,0x6aa8031c,0x7d1000e5}},	//   _ئەقى, _فاسد_, _żeff, _éhsé, 
   {{0x6e2c00ca,0xc58835c7,0x167004a9,0x00000000}},	//   _mvab, ящее_, шқур, --, 
   {{0xd4643a17,0x39a40014,0x6f0c9f4e,0x2124067c}},	//   вище_, _حیلہ, _ofac, valh_, 
   {{0x6e2c0857,0x200401a9,0x63ac00d7,0x00000000}},	//   _ovab, vqli_, ďano, --, 
   {{0xdcfcd418,0xd2f404fb,0x21240ba1,0x6fdc01c7}},	//   _uopć, نکها_, talh_, méch, 
   {{0x6f0c00a8,0x6fde2c54,0x600a2c55,0x2174f79d}},	//   _afac, léch, мном_, туир, 
   {{0x7dd800d2,0x6e2e2c56,0x21262c57,0xb38401c6}},	//   _lúsî, _avab, ralh_, тлөл, 
   {{0x21240a2e,0x81c004c5,0x200486da,0x6fdc0129}},	//   salh_, ্ষই_, rqli_, néch, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x224c011f,0x2dc40046,0x6f0dcd04,0x6fdc0036}},	//   mtek_, лқын_, _efac, héch, 
   {{0x224e2c58,0x6e2c8f07,0x6f0c0368,0x20040327}},	//   ltek_, _evab, _ffac, qqli_, 
   {{0x7dd800d2,0x236c02d3,0xb068007b,0x1e9407a5}},	//   _búsî, ndej_, _أصول_, _арор, 
   {{0x224e2c59,0x6fdcd8b9,0x00000000,0x00000000}},	// [3ffc0] ntek_, déch, --, --, 
   {{0x9a6c0020,0x224e2c5a,0x77940133,0xba0400cf}},	//   _ትክክል_, itek_, گیرا, _ۅسسۉ, 
   {{0x6a1404a9,0xdca403a6,0xdb1401b8,0x6e2c006f}},	//   نبەر, _рани, doyö, _zvab, 
   {{0x224e2c5b,0x77948c9e,0x00000000,0x00000000}},	//   ktek_, دیرا, --, --, 
   {{0x224e2c5c,0x47302626,0x95843fc2,0x6fdc04e6}},	//   jtek_, рніс, клде, wéck, 
   {{0x224e2c5d,0xf784010b,0x6fdc04e6,0xdcfc012d}},	//   dtek_, _өвгү, téck, _popę, 
   {{0xa5080131,0x6fdc01c7,0x8cb40825,0x93400131}},	//   رىيە_, béch, ोपयो, لىغۇ, 
   {{0x6fdc0a40,0x236c0218,0x660c01e4,0xe3e400eb}},	//   réck, gdej_, ŭaka, _পূবব, 
   {{0x224c28be,0x6f0c2761,0x6fdc0036,0x00000000}},	//   gtek_, _rfac, séck, --, 
   {{0x6f0e2c5e,0xc17000f5,0x52e001f9,0x00000000}},	//   _sfac, альщ, _परीस, --, 
   {{0x6e2c0882,0x224e2c5f,0x6f0c0810,0x49380375}},	//   _svab, atek_, _pfac, וגיו, 
   {{0x224c0327,0xa14000c7,0x61400022,0x00000000}},	//   btek_, аҭәе, аҵәа, --, 
   {{0x28d81533,0x224c102c,0x00000000,0x00000000}},	//   _बुनि, ctek_, --, --, 
   {{0x19cc0131,0xdb14007f,0x68040153,0x00000000}},	//   ﻐﺎﻧﻠ, liyè, _sėdm, --, 
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --, 
   {{0x6f0c03e0,0x6e2c00b8,0x00000000,0x00000000}},	//   _ufac, _tvab, --, --, 
   {{0x6fdc26b6,0xe97804f0,0x00000000,0x00000000}},	// [3ffd0] véch, нбаш_, --, --, 
   {{0x6fddb63a,0x236cdde0,0x5ae421ef,0x3914e274}},	//   déci, zdej_, اقكە, имур, 
   {{0x224ca586,0x7bc8004a,0x6fdc06af,0xdb162c60}},	//   ztek_, éduc, téch, kiyè, 
   {{0x224e2c61,0xa52c02d3,0x6d4001a8,0xc050008f}},	//   ytek_, ሰዓንቀ, ólaf, יזע_, 
   {{0x6fde2c62,0x26c803b7,0x65962c63,0xabd401d9}},	//   réch, çao_, ладу, _لٲگت, 
   {{0x6fde2c64,0x75e4007f,0x7e9c05d0,0x00000000}},	//   séch, tòza, וסדו, --, 
   {{0x224c0548,0x6fdc0129,0x25080214,0x43700116}},	//   wtek_, péch, ورژی_, ғуқт, 
   {{0x248804b9,0x224d45db,0x6fdc246d,0x3cf401ad}},	//   ćam_, ttek_, béci, ंधते_, 
   {{0xe1fa2c65,0x224e2c66,0x9f50011f,0x236e2c67}},	//   нги_, utek_, _niyá_, rdej_, 
   {{0x224e2c68,0x855404d3,0xf1b80327,0x660401af}},	//   rtek_, _شیعر_, giġ_, _апҡа, 
   {{0x2010036e,0xdb140241,0x00000000,0x00000000}},	//   ëzi_, biyè, --, --, 
   {{0x224e2c69,0xdca40131,0x2010005f,0xdb1400e8}},	//   ptek_, қаби, īzi_, riyë, 
   {{0xc0f4001f,0xd36c00ec,0x224c031c,0x6e000166}},	//   _ጊዜም_, _رهو_, qtek_, оҗые, 
   {{0xdd901365,0x00000000,0x00000000,0x00000000}},	//   حوس_, --, --, --, 
   {{0x525800db,0x7b04022e,0x00000000,0x00000000}},	//   _يسۇڭ_, аvtе, --, --, 
   {{0xcb662c6a,0x6e280135,0x00000000,0x00000000}},	//   ласе_, ġebr, --, --, 
   {{0x3f800270,0x6e280e3c,0xda646ea9,0xd9380798}},	// [3ffe0] _iniu_, šebr, دازي, ечеш_, 
   {{0xdb140100,0x10380092,0x00000000,0x00000000}},	//   ziyè, _በተቀመ, --, --, 
   {{0x28f80276,0x7d1c0219,0x00000000,0x00000000}},	//   вэцэ_, mbrs, --, --, 
   {{0x1b1c045e,0x09c000cc,0x00000000,0x00000000}},	//   _ফাকে_, ্গগা, --, --, 
   {{0x6d40012b,0x7bc5a1ca,0x6b880086,0xdcf86f43}},	//   ólag, mniu, _òega, _ترکش_, 
   {{0x7bc40953,0x6fdc14ac,0x87e4021f,0x00000000}},	//   lniu, réci, _ەتكە, --, 
   {{0x779597a2,0x2ee00b02,0x7bc4003a,0x98a4011c}},	//   _پیشا, _नर्त, oniu, _сиве, 
   {{0x7bc40af5,0x6fdc0261,0xc7a0030d,0xdb040112}},	//   nniu, péci, _лиск, _umkä, 
   {{0x7bc62c6b,0x89d401ed,0x55e40276,0xdb14033b}},	//   iniu, _شوہر_, _боаб, riyè, 
   {{0x86580bd9,0x71b400d8,0x3f822c6c,0x00000000}},	//   _אדמי, рбоф, _aniu_, --, 
   {{0x947800fd,0x7bc62c6d,0x64a400c7,0xd13000db}},	//   _ясау_, kniu, _ҩаӡа, _ۇمش_, 
   {{0xf1b8025c,0x00000000,0x00000000,0x00000000}},	//   siġ_, --, --, --, 
   {{0x9f902242,0x3f800034,0xd1300214,0x68040153}},	//   ráð_, _dniu_, _همش_, _pėdk, 
   {{0x7bc43343,0xe2a801d9,0xa6d0015b,0x7f8402dd}},	//   eniu, _جامن_, ়েকট, _ۇلىن, 
   {{0x7c851421,0x814000cf,0xaa6c0432,0x8bc4009d}},	//   буте, _انىن, _köçä_, гсад, 
   {{0x7bc62c6e,0x09bc0882,0xdb0c0241,0x00000000}},	//   gniu, ्व्य, _èjìo, --, 
   {{0x52e005f9,0x6d4001c3,0xff5001c8,0xdd8c00e5}},	// [3fff0] _परोस, òlas, _رخي_, سڈی_, 
   {{0xa2c40404,0x7d180306,0x7bc43805,0x6d4001a8}},	//   ापत्, časí, aniu, ólad, 
   {{0xc7b81086,0x79c800be,0x7bc44d8c,0x00000000}},	//   нёд_, دولف_, bniu, --, 
   {{0x7bc401ab,0xe6980120,0x00000000,0x00000000}},	//   cniu, квеш_, --, --, 
   {{0x6f1df5f0,0x6b8c00a2,0x572000db,0x00000000}},	//   ibsc, mjag, زۉلك, --, 
   {{0x6b8e2c6f,0xae1c02a0,0x39580142,0xc9862c70}},	//   ljag, बीएन_, _gbrs_, _суми, 
   {{0x6fddca51,0xe89405f5,0x58fc031c,0x6e3c0e78}},	//   lécu, _тавь, _ཟུགས_, hrsb, 
   {{0x6b8e2c71,0xa30001e0,0x45a00137,0x00000000}},	//   njag, әүҙе, _گەتك, --, 
   {{0x2d8002c4,0x69c62c72,0x6aac011c,0x6d54004e}},	//   _onhe_, onhe, nzaf, kfza, 
   {{0x69c62c73,0x2fc80c6a,0x6b8e2c74,0x6aac030a}},	//   nnhe, _ajag_, hjag, izaf, 
   {{0x27ec0016,0x6e3c0430,0x69c62c75,0x3438117d}},	//   _khen_, ersb, inhe, _مسند_, 
   {{0x69c403fa,0x7bc40399,0xe51800dc,0xa2c400cd}},	//   hnhe, xniu, _न्ति_, ापद्, 
   {{0x53980302,0x63aa2c76,0x21680022,0x6b8c1368}},	//   _שינו, mhen, _аили_, djag, 
   {{0x63aa2c77,0xdca405f5,0x27ee2c78,0x6aac0bd7}},	//   lhen, ааги, _lhen_, dzaf, 
   {{0x7bc62c79,0x63a80104,0x69c405b1,0x6e3c2112}},	//   tniu, ohen, dnhe, arsb, 
   {{0x63aa2c7a,0x69c42e2b,0x24740882,0x7d1c010a}},	//   nhen, enhe, _mām_, sbrs, 
  
  };
  // table_hash = afbd-951b, unused_entries = 206040 (19.65%)

static const uint32 kQuad0122SizeOne = 142459;    // Bucket count one-lang
static const uint32 kQuad0122Ind[142459] = {
  // [0000]
  0x00000000, 0x00000000, 0x1d105155, 0x00002a0f,   // -- --  kl.lt.la_442 bo.un.un_600 
  0x0000790a, 0x00001903, 0x0000100f, 0x0000610f,   // war.un.un_500 gl.un.un_300  lt.un.un_600 za.un.un_600 
  0x00000e0f, 0x00003b01, 0x0000750f, 0x1c090daf,   // is.un.un_600 so.un.un_200  nso.un.un_600 ne.hi.mr_655 
  0x18004002, 0x00001303, 0x0b00331a, 0x00002c03,   // lb.ga.un_220 bh.un.un_300  as.bn.un_760 fy.un.un_300 
  // [0010]
  0x00002901, 0x33000b0d, 0x205c61a4, 0x0000271c,   // sl.un.un_200 bn.as.un_540  za.sa.sq_433 gd.un.un_800 
  0x00003b0a, 0x05190b08, 0x00002b15, 0x30233c0c,   // ks.un.un_500 es.gl.fr_443  vi.un.un_700 ug.ky.uz_543 
  0x1d0406a0, 0x30003c21, 0x23374408, 0x30002304,   // de.fi.la_322 ug.uz.un_860  kk.ba.ky_443 ky.uz.un_320 
  0x190b4e0c, 0x423e1f0c, 0x00002b0f, 0x00001e0f,   // ay.es.gl_543 cy.rm.co_543  vi.un.un_600 am.un.un_600 
  // [0020]
  0x00001e15, 0x04070aa0, 0x00003606, 0x0000200a,   // am.un.un_700 mk.bg.ru_322  ab.un.un_400 ti.un.un_500 
  0x0000100a, 0x37003604, 0x44002304, 0x0d1c0955,   // lt.un.un_500 gn.st.un_320  ky.kk.un_320 hi.mr.ne_442 
  0x5d353408, 0x00000f1c, 0x64075204, 0x00005c06,   // xh.zu.ss_443 lv.un.un_800  ha.it.lg_332 sa.un.un_400 
  0x3e0647a9, 0x00002c01, 0x00004c03, 0x00000601,   // sn.de.rm_544 fy.un.un_200  wo.un.un_300 de.un.un_200 
  // [0030]
  0x00002d0a, 0xfc3f0305, 0x0000370f, 0x2e3f1f0b,   // sk.un.un_500 nl.af.zzp_333  ba.un.un_600 cy.af.fo_542 
  0x0000090f, 0x18002108, 0x00004001, 0x00001306,   // pl.un.un_600 fa.ar.un_430  lb.un.un_200 bh.un.un_400 
  0x00002d1c, 0x02133804, 0x00001d01, 0x00000803,   // sk.un.un_800 tk.et.da_332  la.un.un_200 no.un.un_300 
  0x00005d0f, 0x00002a15, 0x00002f01, 0x13651e07,   // ss.un.un_600 mt.un.un_700  su.un.un_200 ms.gv.et_432 
  // [0040]
  0x2f004702, 0x37484455, 0x00001f03, 0x62006533,   // sn.su.un_220 kk.tt.ba_442  cy.un.un_300 gv.kha.un_A70 
  0x47395e08, 0x0f004719, 0x00004415, 0x0c066007,   // ts.br.sn_443 sn.lv.un_750  kk.un.un_700 vo.de.sv_432 
  0x0000430a, 0x2b001f08, 0x00000506, 0x0000340f,   // ie.un.un_500 cy.vi.un_430  fr.un.un_400 xh.un.un_600 
  0x00004706, 0x00002b06, 0x00002301, 0x0900471a,   // sn.un.un_400 vi.un.un_400  ky.un.un_200 sn.pl.un_760 
  // [0050]
  0x00003b15, 0x00002b01, 0x6300012b, 0x00004b15,   // ks.un.un_700 vi.un.un_200  en.sco.un_980 mi.un.un_700 
  0x00004e0f, 0x00005c01, 0x7601630d, 0x0f007313,   // ay.un.un_600 sa.un.un_200  sco.en.crs_554 ny.lv.un_650 
  0x00003c24, 0x353401ec, 0x00002501, 0x00000406,   // ug.un.un_900 en.xh.zu_644  eu.un.un_200 fi.un.un_400 
  0x00000203, 0x0000fa06, 0x0000441c, 0x00000f0f,   // da.un.un_300 nr.un.un_400  kk.un.un_800 lv.un.un_600 
  // [0060]
  0x3430120e, 0x5c000f1a, 0x352315a0, 0x0000170a,   // ur.uz.ps_555 lv.sa.un_760  un.ky.tg_322 sr.un.un_500 
  0x00001001, 0x06003e02, 0x00002103, 0x00003b06,   // lt.un.un_200 rm.de.un_220  jw.un.un_300 so.un.un_400 
  0x0800250c, 0x00006a0a, 0x00005b0f, 0x042125ee,   // mn.uk.un_530 haw.un.un_500  sg.un.un_600 eu.jw.fi_422 
  0x0000301c, 0x0000091c, 0x4a006e08, 0x0000470a,   // uz.un.un_800 pl.un.un_800  hmn.yo.un_430 sn.un.un_500 
  // [0070]
  0x00006e15, 0x4800020d, 0x00006501, 0x00001c0a,   // hmn.un.un_700 da.tt.un_540  gv.un.un_200 mr.un.un_500 
  0x024d58af, 0x00003c15, 0x00006503, 0x00001901,   // om.aa.da_655 ug.un.un_700  gv.un.un_300 gl.un.un_200 
  0x340f6ea7, 0x372c2aa0, 0x13090da0, 0x0000180a,   // hmn.lv.xh_532 mt.fy.st_322  ne.hi.bh_322 ga.un.un_500 
  0x00000c01, 0x00001315, 0x0c4604a7, 0x00005301,   // sv.un.un_200 bh.un.un_700  fi.qu.sv_532 ht.un.un_200 
  // [0080]
  0x47780fad, 0x3b584d0c, 0x02003304, 0x00006401,   // lv.ve.sn_643 aa.om.so_543  nn.da.un_320 lg.un.un_200 
  0x0000781c, 0x0000450a, 0x0000570f, 0x65330805,   // ve.un.un_800 ln.un.un_500  na.un.un_600 no.nn.gv_333 
  0x080225ee, 0x07004004, 0x0900470b, 0x2f001c04,   // eu.da.no_422 lb.it.un_320  sn.pl.un_520 id.su.un_320 
  0x00000e15, 0x0100240d, 0x0000480a, 0x0000240f,   // is.un.un_700 yi.iw.un_540  tt.un.un_500 yi.un.un_600 
  // [0090]
  0x102d47ee, 0x50003b0c, 0x00001e0a, 0x00004903,   // sn.sk.lt_422 so.fj.un_530  am.un.un_500 to.un.un_300 
  0x4c00580e, 0x7800470e, 0x39006507, 0x0000611c,   // om.wo.un_550 sn.ve.un_550  gv.br.un_420 za.un.un_800 
  0x00002f03, 0x00004703, 0x00003401, 0x00001703,   // su.un.un_300 sn.un.un_300  xh.un.un_200 sr.un.un_300 
  0x64346eee, 0x00002506, 0x0b003307, 0x00002801,   // hmn.xh.lg_422 eu.un.un_400  as.bn.un_420 sd.un.un_200 
  // [00a0]
  0x05004504, 0x17003204, 0x00003801, 0x00002703,   // ln.fr.un_320 bs.sr.un_320  tk.un.un_200 gd.un.un_300 
  0x30003802, 0x5c001c19, 0x3500360d, 0x0000070a,   // tk.uz.un_220 mr.sa.un_750  ab.tg.un_540 bg.un.un_500 
  0x00001115, 0x00001f15, 0x00003415, 0x09001304,   // ro.un.un_700 cy.un.un_700  ps.un.un_700 bh.hi.un_320 
  0x0000310f, 0x0000650a, 0x00001806, 0x0000130f,   // az.un.un_600 gv.un.un_500  ar.un.un_400 et.un.un_600 
  // [00b0]
  0x00004b01, 0x37004802, 0x0000281c, 0x2134180b,   // mi.un.un_200 tt.ba.un_220  sd.un.un_800 ar.ps.fa_542 
  0x0000681c, 0x00000206, 0x34003d20, 0x20001e12,   // ig.un.un_800 da.un.un_400  ku.ps.un_850 am.ti.un_640 
  0x00005c03, 0x30283b09, 0x04621ca0, 0x0f001304,   // sa.un.un_300 ks.sd.uz_444  id.kha.fi_322 et.lv.un_320 
  0x00000d0a, 0x00000b15, 0x00003c01, 0x33000c0d,   // ne.un.un_500 bn.un.un_700  ug.un.un_200 sv.nn.un_540 
  // [00c0]
  0x00001003, 0x1821340e, 0x30003513, 0x4b000408,   // lt.un.un_300 ps.fa.ar_555  tg.uz.un_650 fi.mi.un_430 
  0x08000e08, 0x0000130a, 0x0000180f, 0x0000360a,   // is.no.un_430 et.un.un_500  ar.un.un_600 ab.un.un_500 
  0x00002415, 0x15000413, 0x00005501, 0x23443705,   // yi.un.un_700 ru.un.un_650  rw.un.un_200 ba.kk.ky_333 
  0x00003306, 0x00005c0a, 0x0d000908, 0x00002306,   // as.un.un_400 sa.un.un_500  hi.ne.un_430 ky.un.un_400 
  // [00d0]
  0x00002d06, 0x00003c0a, 0x00005d03, 0x1000080d,   // sk.un.un_400 ug.un.un_500  ss.un.un_300 uk.be.un_540 
  0x00000806, 0x00002f0a, 0x00000815, 0x00002d01,   // uk.un.un_400 su.un.un_500  uk.un.un_700 sk.un.un_200 
  0x00000a01, 0x2400010c, 0x00000f15, 0x00002303,   // mk.un.un_200 iw.yi.un_530  lv.un.un_700 ky.un.un_300 
  0x00005c0f, 0x00001215, 0x00000f06, 0x00002406,   // sa.un.un_600 hu.un.un_700  lv.un.un_400 yi.un.un_400 
  // [00e0]
  0x090d5cec, 0x13000905, 0x00000f0a, 0x18002802,   // sa.ne.hi_644 hi.bh.un_330  lv.un.un_500 sd.ar.un_220 
  0x00003603, 0x00001206, 0x0804150c, 0x0e001212,   // gn.un.un_300 ur.un.un_400  un.ru.uk_543 hu.is.un_640 
  0x00004c06, 0x3500080d, 0x0a001707, 0x00000b06,   // wo.un.un_400 uk.tg.un_540  sr.mk.un_420 bn.un.un_400 
  0x0000280a, 0x330208a4, 0x0000380f, 0x00000f01,   // sd.un.un_500 no.da.nn_433  tk.un.un_600 lv.un.un_200 
  // [00f0]
  0x17000a04, 0x0000340a, 0x00002106, 0x00001701,   // mk.sr.un_320 ps.un.un_500  fa.un.un_400 sr.un.un_200 
  0x0000232d, 0x08000404, 0x213d1207, 0x0000230f,   // ky.un.un_A00 ru.uk.un_320  ur.ku.fa_432 ky.un.un_600 
  0x00001224, 0x213430ec, 0x44001008, 0x00003706,   // ur.un.un_900 uz.ps.fa_644  be.kk.un_430 ba.un.un_400 
  0x00000e1c, 0x0000480f, 0x0000330a, 0x342821ac,   // is.un.un_800 tt.un.un_600  as.un.un_500 fa.sd.ps_632 
  // [0100]
  0x00005303, 0x21001202, 0x30250705, 0x12343d07,   // ht.un.un_300 ur.fa.un_220  bg.mn.uz_333 ku.ps.ur_432 
  0x04003702, 0x2500100c, 0x1a005f04, 0x0000350a,   // ba.ru.un_220 be.mn.un_530  tn.tl.un_320 tg.un.un_500 
  0x00000403, 0x00005601, 0x00001506, 0x0000380a,   // ru.un.un_300 mg.un.un_200  un.un.un_400 tk.un.un_500 
  0x1e00200d, 0x23352508, 0x00003803, 0x0000240a,   // ti.am.un_540 mn.tg.ky_443  tk.un.un_300 yi.un.un_500 
  // [0110]
  0x465a1007, 0x1000080e, 0x00000603, 0x00004601,   // lt.sm.qu_432 uk.be.un_550  de.un.un_300 qu.un.un_200 
  0x00001706, 0x00002403, 0x00003c06, 0x00003503,   // sr.un.un_400 yi.un.un_300  ug.un.un_400 tg.un.un_300 
  0x00000d06, 0x1d001d08, 0x0000010a, 0x08000409,   // ne.un.un_400 la.la.un_430  iw.un.un_500 ru.uk.un_440 
  0x00000701, 0x34213004, 0x38004d0b, 0x00004d0a,   // bg.un.un_200 uz.fa.ps_332  aa.tk.un_520 aa.un.un_500 
  // [0120]
  0x00000a06, 0x37004404, 0x2d000d0e, 0x18282104,   // mk.un.un_400 kk.ba.un_320  cs.sk.un_550 fa.sd.ar_332 
  0x0000360f, 0x20001e19, 0x07080408, 0x2100180c,   // ab.un.un_600 am.ti.un_750  ru.uk.bg_443 ar.fa.un_530 
  0x18003413, 0x00000501, 0x1c0d5cee, 0x12000e0d,   // ps.ar.un_650 fr.un.un_200  sa.ne.mr_422 is.hu.un_540 
  0x00000d0f, 0x00000906, 0x30213d11, 0x281221ec,   // ne.un.un_600 hi.un.un_400  ku.fa.uz_653 fa.ur.sd_644 
  // [0130]
  0x07084805, 0x00003c0f, 0x23004405, 0x00003d0a,   // tt.uk.bg_333 ug.un.un_600  kk.ky.un_330 ku.un.un_500 
  0x00006715, 0x00002a0a, 0x44233c5a, 0x0000230a,   // ak.un.un_700 bo.un.un_500  ug.ky.kk_553 ky.un.un_500 
  0x04000808, 0x00004801, 0x00000d03, 0x0000671c,   // uk.ru.un_430 tt.un.un_200  cs.un.un_300 ak.un.un_800 
  0x00005103, 0x00004806, 0x0000350f, 0x0000670a,   // kl.un.un_300 tt.un.un_400  tg.un.un_600 ak.un.un_500 
  // [0140]
  0x00005106, 0x0d1c095a, 0x00001f01, 0x39001f0b,   // kl.un.un_400 hi.mr.ne_553  cy.un.un_200 cy.br.un_520 
  0x3b003802, 0x23003c0d, 0x0d095cec, 0x09005905,   // tk.so.un_220 ug.ky.un_540  sa.hi.ne_644 rn.pl.un_330 
  0x100804a0, 0x2c00fe12, 0x00006015, 0x00003501,   // ru.uk.be_322 tlh.fy.un_640  vo.un.un_700 tg.un.un_200 
  0x00005f1c, 0x1200280e, 0x12180ea7, 0x0000fe0a,   // tn.un.un_800 sd.ur.un_550  is.ga.hu_532 tlh.un.un_500 
  // [0150]
  0x00004403, 0x00003f15, 0x34123008, 0x00001006,   // kk.un.un_300 af.un.un_700  uz.ur.ps_443 lt.un.un_400 
  0x00000b0a, 0x673b01a0, 0x0000390a, 0x5c001c18,   // bn.un.un_500 en.so.ak_322  dz.un.un_500 mr.sa.un_740 
  0x00003301, 0x755f3760, 0x55024d04, 0x00000b0f,   // nn.un.un_200 st.tn.nso_664  aa.da.rw_332 bn.un.un_600 
  0x59005514, 0x00001f06, 0x34003d04, 0x65094d0c,   // rw.rn.un_660 cy.un.un_400  ku.ps.un_320 aa.pl.gv_543 
  // [0160]
  0x5d00470c, 0x00007306, 0x00002e03, 0x5d35340d,   // sn.ss.un_530 ny.un.un_400  fo.un.un_300 xh.zu.ss_554 
  0x08004421, 0x00003901, 0x00004803, 0x1c005d04,   // kk.uk.un_860 br.un.un_200  tt.un.un_300 ss.id.un_320 
  0x1f6501a7, 0x3b003004, 0x0704150d, 0x0000670f,   // en.gv.cy_532 uz.so.un_320  un.ru.bg_554 ak.un.un_600 
  0x00003515, 0x0000fe15, 0x64353408, 0x3f1b760c,   // tg.un.un_700 tlh.un.un_700  xh.zu.lg_443 crs.tr.af_543 
  // [0170]
  0x0000560f, 0x00000f03, 0xfe182f08, 0x34003512,   // mg.un.un_600 lv.un.un_300  su.ga.tlh_443 zu.xh.un_640 
  0x00002e06, 0x00001501, 0x20271fa0, 0x2259555a,   // fo.un.un_400 un.un.un_200  cy.gd.sq_322 rw.rn.oc_553 
  0x0e4b6a0c, 0x1f3f27a4, 0x00003f01, 0x20476aa4,   // haw.mi.is_543 gd.af.cy_433  af.un.un_200 haw.sn.sq_433 
  0x5955640c, 0x0c003504, 0x3c303507, 0x49044bee,   // lg.rw.rn_543 zu.sv.un_320  tg.uz.ug_432 mi.fi.to_422 
  // [0180]
  0x3b006e07, 0x20002807, 0x5800fc08, 0x00003315,   // hmn.so.un_420 sw.sq.un_420  zzp.om.un_430 as.un.un_700 
  0x00003715, 0x38302505, 0xfc3564a0, 0x0e0608a4,   // ba.un.un_700 eu.uz.tk_333  lg.zu.zzp_322 no.de.is_433 
  0x42002718, 0x47005508, 0x30370455, 0x09001f12,   // gd.co.un_740 rw.sn.un_430  fi.st.uz_442 cy.pl.un_640 
  0x045c3fa0, 0x52006419, 0x3704230c, 0x13003012,   // af.sa.fi_322 lg.ha.un_750  ca.fi.st_543 uz.et.un_640 
  // [0190]
  0x00006e24, 0x12005504, 0x00002715, 0xfe600613,   // hmn.un.un_900 rw.hu.un_320  gd.un.un_700 de.vo.tlh_665 
  0x00005101, 0x042307a9, 0x0000030a, 0x0400650c,   // kl.un.un_200 bg.ky.ru_544  nl.un.un_500 gv.fi.un_530 
  0x00005201, 0x341821a9, 0x370420a9, 0x00000215,   // ha.un.un_200 fa.ar.ps_544  sq.fi.st_544 da.un.un_700 
  0x3100550d, 0x09000607, 0x5800fe04, 0x00005906,   // rw.az.un_540 de.pl.un_420  tlh.om.un_320 rn.un.un_400 
  // [01a0]
  0x643f0307, 0x39002507, 0x00002d15, 0x025604a4,   // nl.af.lg_432 eu.br.un_420  sk.un.un_700 fi.mg.da_433 
  0x00000303, 0x3f122f07, 0x00001601, 0x402c150c,   // nl.un.un_300 su.hu.af_432  hr.un.un_200 un.fy.lb_543 
  0x00000e0a, 0x00003003, 0x00005515, 0x00002701,   // is.un.un_500 uz.un.un_300  rw.un.un_700 gd.un.un_200 
  0x372a5f0d, 0x1c000902, 0x63570608, 0x00003701,   // tn.mt.st_554 hi.mr.un_220  de.na.sco_443 st.un.un_200 
  // [01b0]
  0x091c130c, 0x373b7508, 0x5900550e, 0x35003407,   // bh.mr.hi_543 nso.so.st_443  rw.rn.un_550 xh.zu.un_420 
  0x24004804, 0x42231909, 0x22004309, 0x3f190b09,   // tt.eo.un_320 gl.ca.co_444  ie.oc.un_440 es.gl.af_444 
  0x0000600a, 0x0000300a, 0x596455ec, 0x19555907,   // vo.un.un_500 uz.un.un_500  rw.lg.rn_644 rn.rw.gl_432 
  0x1c005c0d, 0x353455ee, 0x117905a9, 0x00000201,   // sa.mr.un_540 rw.xh.zu_422  fr.war.ro_544 da.un.un_200 
  // [01c0]
  0x0000250f, 0x595e2007, 0x081b3fa0, 0x00002706,   // eu.un.un_600 sq.ts.rn_432  af.tr.no_322 gd.un.un_400 
  0x00002503, 0x5d343507, 0x0000250a, 0x00004003,   // eu.un.un_300 zu.xh.ss_432  mn.un.un_500 lb.un.un_300 
  0x00002806, 0x65301b04, 0x08001002, 0x31001907,   // sw.un.un_400 tr.uz.gv_332  be.uk.un_220 gl.az.un_420 
  0x3f0630a4, 0x13030404, 0x0800100d, 0x06004013,   // uz.de.af_433 fi.nl.et_332  be.uk.un_540 lb.de.un_650 
  // [01d0]
  0x03630204, 0x4c1d0407, 0x37004819, 0x0000120a,   // da.sco.nl_332 fi.la.wo_432  tt.ba.un_750 hu.un.un_500 
  0x00006e0a, 0x00003006, 0x480320a0, 0x303704a4,   // hmn.un.un_500 uz.un.un_400  sq.nl.tt_322 fi.st.uz_433 
  0x073723a4, 0x00003b0f, 0x070a17ad, 0x313b30a0,   // ca.st.it_433 ks.un.un_600  sr.mk.bg_643 uz.so.az_322 
  0x00002b24, 0x10001112, 0x15113ca4, 0x48000a04,   // vi.un.un_900 ro.be.un_640  ug.ro.un_433 mk.tt.un_320 
  // [01e0]
  0x0000370a, 0x00004a03, 0x00003406, 0x00000c03,   // ba.un.un_500 yo.un.un_300  ps.un.un_400 sv.un.un_300 
  0x00002401, 0x23000702, 0x00000c0a, 0x00001803,   // eo.un.un_200 bg.ky.un_220  sv.un.un_500 ga.un.un_300 
  0x04483707, 0x0a1517ec, 0x25004813, 0x21121812,   // ba.tt.ru_432 sr.mk.un_640  tt.mn.un_650 ar.ur.fa_654 
  0x00004406, 0x0000120f, 0x00003703, 0x00000d01,   // kk.un.un_400 hu.un.un_600  st.un.un_300 cs.un.un_200 
  // [01f0]
  0x00003506, 0x00002d0f, 0x0000680a, 0x20001e0c,   // tg.un.un_400 sk.un.un_600  ig.un.un_500 am.ti.un_530 
  0x00000401, 0x00000301, 0x12001804, 0x00002803,   // ru.un.un_200 nl.un.un_200  ga.hu.un_320 sw.un.un_300 
  0x03006114, 0x00001c06, 0x00003201, 0x00002b0a,   // za.nl.un_660 id.un.un_400  bs.un.un_200 vi.un.un_500 
  0x07004804, 0x3d342107, 0x30003502, 0x28213d04,   // tt.bg.un_320 fa.ps.ku_432  tg.uz.un_220 ku.fa.sd_332 
  // [0200]
  0x00002001, 0x00001e1c, 0x44002321, 0x070815ac,   // sq.un.un_200 am.un.un_800  ky.kk.un_860 un.uk.bg_632 
  0x00006306, 0x00001b01, 0x2800341a, 0x0000612d,   // sco.un.un_400 tr.un.un_200  ps.sd.un_760 za.un.un_A00 
  0x00002b03, 0x00003815, 0x3000350e, 0x00001c01,   // vi.un.un_300 tk.un.un_700  tg.uz.un_550 id.un.un_200 
  0x00002101, 0x1c095c0b, 0x21123da0, 0x04000704,   // jw.un.un_200 sa.hi.mr_542  ku.ur.fa_322 bg.ru.un_320 
  // [0210]
  0x00000903, 0x00006e0f, 0x0000080a, 0x0000310a,   // pl.un.un_300 hmn.un.un_600  uk.un.un_500 az.un.un_500 
  0x0000210a, 0x34002013, 0x2d000d08, 0x08003304,   // fa.un.un_500 sq.xh.un_650  cs.sk.un_430 nn.no.un_320 
  0x00006e06, 0x00002906, 0x0000341c, 0x04000812,   // hmn.un.un_400 sl.un.un_400  ps.un.un_800 uk.ru.un_640 
  0x19000a02, 0x04070aec, 0x3e001502, 0x23004413,   // pt.gl.un_220 mk.bg.ru_644  un.rm.un_220 kk.ky.un_650 
  // [0220]
  0x0000440f, 0x0000400a, 0x3c442360, 0x00005503,   // kk.un.un_600 lb.un.un_500  ky.kk.ug_664 rw.un.un_300 
  0x44003608, 0x00002c15, 0x00006124, 0x00004e0a,   // ab.kk.un_430 fy.un.un_700  za.un.un_900 ay.un.un_500 
  0x00002315, 0x08000405, 0x2d000d07, 0x3b002808,   // ky.un.un_700 ru.uk.un_330  cs.sk.un_420 sw.so.un_430 
  0x00002e0f, 0x1e281804, 0x00003001, 0x00005803,   // fo.un.un_600 ga.sw.ms_332  uz.un.un_200 om.un.un_300 
  // [0230]
  0x0000550a, 0x00000515, 0x2d000d14, 0x2000280c,   // rw.un.un_500 fr.un.un_700  cs.sk.un_660 sw.sq.un_530 
  0x353023ec, 0x22002b09, 0x3d3430ee, 0x2d0d3baf,   // ky.uz.tg_644 vi.oc.un_440  uz.ps.ku_422 so.cs.sk_655 
  0x57215ead, 0x400e6bee, 0x0000040a, 0x3500300d,   // ts.jw.na_643 ceb.is.lb_422  ru.un.un_500 uz.tg.un_540 
  0x28fc2711, 0x48001d02, 0x13000908, 0x3d003009,   // gd.zzp.sw_653 la.tt.un_220  hi.bh.un_430 uz.ku.un_440 
  // [0240]
  0x00002006, 0x00004a06, 0x2f000a02, 0x5c001305,   // sq.un.un_400 yo.un.un_400  pt.su.un_220 bh.sa.un_330 
  0x00003d01, 0xfc005c04, 0x48001004, 0x39000304,   // ku.un.un_200 sa.zzp.un_320  be.tt.un_320 nl.br.un_320 
  0x00004a0a, 0x15040805, 0x5c000d04, 0x4b001305,   // yo.un.un_500 uk.ru.un_333  ne.sa.un_320 et.mi.un_330 
  0x35003007, 0x150417a4, 0x122134a9, 0x0a136aee,   // uz.tg.un_420 sr.ru.un_433  ps.fa.ur_544 haw.et.pt_422 
  // [0250]
  0x33080ca0, 0x08041507, 0x2e000e0c, 0x582c1311,   // sv.no.nn_322 un.ru.uk_432  is.fo.un_530 et.fy.om_653 
  0x00001301, 0x252a4da9, 0x0a00150c, 0x1e00200b,   // et.un.un_200 aa.mt.eu_544  un.mk.un_530 ti.am.un_520 
  0x0e002504, 0x31001b13, 0x00005b0a, 0x2f003904,   // eu.is.un_320 tr.az.un_650  sg.un.un_500 br.su.un_320 
  0x00002a06, 0x24000111, 0x25000907, 0x0000011c,   // mt.un.un_400 iw.yi.un_630  pl.eu.un_420 iw.un.un_800 
  // [0260]
  0x1b033fa4, 0x00000a0f, 0x0000111c, 0x00001c03,   // af.nl.tr_433 pt.un.un_600  ro.un.un_800 id.un.un_300 
  0x21002f08, 0x0f004902, 0x350a17a0, 0x00000c06,   // su.jw.un_430 to.lv.un_220  sr.mk.tg_322 sv.un.un_400 
  0x00004206, 0x3c4415a4, 0x00001715, 0x08000402,   // co.un.un_400 un.kk.ug_433  sr.un.un_700 ru.uk.un_220 
  0x00004203, 0x1500270c, 0x213b2808, 0x48004412,   // co.un.un_300 gd.un.un_530  sw.so.jw_443 kk.tt.un_640 
  // [0270]
  0x00004901, 0x34002107, 0x00003d24, 0x515e6a07,   // to.un.un_200 fa.ps.un_420  ku.un.un_900 haw.ts.kl_432 
  0x38001b0c, 0x13006a1b, 0x0000110a, 0x393f1b04,   // tr.tk.un_530 haw.et.un_770  ro.un.un_500 tr.af.br_332 
  0x37764905, 0x03393f0c, 0x18001209, 0x67005513,   // to.crs.st_333 af.br.nl_543  ur.ar.un_440 rw.ak.un_650 
  0x204f1b12, 0x18003404, 0x0d003904, 0x3f3925ad,   // tr.bi.sq_654 ps.ar.un_320  br.cs.un_320 eu.br.af_643 
  // [0280]
  0x00001a01, 0x19000a12, 0x4b00060c, 0x1504170c,   // tl.un.un_200 pt.gl.un_640  de.mi.un_530 sr.ru.un_543 
  0x15043604, 0x1f00392b, 0x00005003, 0x381c2fee,   // ab.ru.un_332 br.cy.un_980  fj.un.un_300 su.id.tk_422 
  0x0700171b, 0x0e390c11, 0x13000919, 0x2f005812,   // sr.bg.un_770 sv.br.is_653  hi.bh.un_750 om.su.un_640 
  0x4b006a12, 0x290d53af, 0x3400210c, 0x494013a7,   // haw.mi.un_640 ht.cs.sl_655  fa.ps.un_530 et.lb.to_532 
  // [0290]
  0x4d005813, 0x2a650cee, 0x29211304, 0x285e3b04,   // om.aa.un_650 sv.gv.mt_422  et.jw.sl_332 so.ts.sw_332 
  0x52214708, 0x0000570a, 0x00004515, 0x64006112,   // sn.jw.ha_443 na.un.un_500  ln.un.un_700 za.lg.un_640 
  0x080a1712, 0x630c2004, 0x56385711, 0x31345d05,   // sr.mk.uk_654 sq.sv.sco_332  na.tk.mg_653 ss.xh.az_333 
  0x12003402, 0x63000107, 0x3d002108, 0x31001b0d,   // ps.ur.un_220 en.sco.un_420  fa.ku.un_430 tr.az.un_540 
  // [02a0]
  0x1c00090c, 0x555e4aad, 0x65233904, 0x0a2311a7,   // hi.mr.un_530 yo.ts.rw_643  br.ca.gv_332 ro.ky.mk_532 
  0x00006524, 0x3f000212, 0x0b003313, 0x3e4006ac,   // gv.un.un_900 da.af.un_640  as.bn.un_650 de.lb.rm_632 
  0x00005206, 0x3000350d, 0x36005a04, 0x1c000905,   // ha.un.un_400 tg.uz.un_540  sm.gn.un_320 hi.mr.un_330 
  0x30004807, 0x13004920, 0x29001609, 0x3c00301b,   // tt.uz.un_420 to.et.un_850  hr.sl.un_440 uz.ug.un_770 
  // [02b0]
  0x7800581a, 0x00004b06, 0x35342104, 0x651a0ca0,   // om.ve.un_760 mi.un.un_400  jw.xh.zu_332 sv.tl.gv_322 
  0x2f1e1c04, 0x00004b03, 0x4a676113, 0x06000107,   // id.ms.su_332 mi.un.un_300  za.ak.yo_665 en.de.un_420 
  0x06004023, 0x00005e06, 0x480a0702, 0x153c3804,   // lb.de.un_880 ts.un.un_400  bg.mk.tt_222 tk.ug.un_332 
  0x63011e07, 0x0000530f, 0x57400613, 0x0000080f,   // ms.en.sco_432 ht.un.un_600  de.lb.na_665 no.un.un_600 
  // [02c0]
  0x12213dee, 0x06004002, 0x06000108, 0x5c001304,   // ku.fa.ur_422 lb.de.un_220  en.de.un_430 bh.sa.un_320 
  0x00005e03, 0x083517a4, 0x15101705, 0x31005302,   // ts.un.un_300 sr.tg.uk_433  sr.be.un_333 ht.az.un_220 
  0x0a35305a, 0x18002105, 0x1504155a, 0x34001202,   // uz.tg.mk_553 fa.ar.un_330  un.ru.un_553 ur.ps.un_220 
  0x0e001209, 0x0a173608, 0x0000730a, 0x22001304,   // hu.is.un_440 ab.sr.mk_443  ny.un.un_500 et.oc.un_320 
  // [02d0]
  0x0000fc01, 0x0000460a, 0x00000e01, 0x0000200f,   // zzp.un.un_200 qu.un.un_500  is.un.un_200 sq.un.un_600 
  0x0e00040c, 0x00001015, 0x12000413, 0x070a1714,   // fi.is.un_530 be.un.un_700  fi.hu.un_650 sr.mk.bg_666 
  0x0e04120c, 0x48003712, 0x18002107, 0x13091ca4,   // hu.fi.is_543 ba.tt.un_640  fa.ar.un_420 mr.hi.bh_433 
  0x4400100d, 0x0000440a, 0x44002314, 0x17005302,   // be.kk.un_540 kk.un.un_500  ky.kk.un_660 ht.sr.un_220 
  // [02e0]
  0x271d2208, 0x12213b0c, 0x00005306, 0x0000680f,   // oc.la.gd_443 ks.fa.ur_543  ht.un.un_400 ig.un.un_600 
  0x24000112, 0x09001307, 0x35303c04, 0x21303404,   // iw.yi.un_640 bh.hi.un_420  ug.uz.tg_332 ps.uz.fa_332 
  0x00000706, 0x18003d02, 0x00004506, 0x28001812,   // bg.un.un_400 ku.ar.un_220  ln.un.un_400 ar.sd.un_640 
  0x2300300c, 0x33000204, 0x0400170e, 0x18003c07,   // uz.ky.un_530 da.nn.un_320  sr.ru.un_550 ug.ar.un_420 
  // [02f0]
  0x2d000d02, 0x234838a9, 0x00003d06, 0x0415100b,   // cs.sk.un_220 tk.tt.ky_544  ku.un.un_400 be.ru.un_520 
  0x30003519, 0x0b003308, 0x0000040f, 0x12040ca0,   // tg.uz.un_750 as.bn.un_430  fi.un.un_600 sv.fi.hu_322 
  0x00000d24, 0x0c1204a4, 0x6b001d12, 0x2d000d09,   // cs.un.un_900 fi.hu.sv_433  la.ceb.un_640 cs.sk.un_440 
  0x12000404, 0x2d000d12, 0x0d13095a, 0x0700350c,   // fi.hu.un_320 cs.sk.un_640  hi.bh.ne_553 tg.bg.un_530 
  // [0300]
  0x2d000d21, 0x32001604, 0x00000115, 0x0d005c0c,   // cs.sk.un_860 hr.bs.un_320  iw.un.un_700 sa.ne.un_530 
  0x37004807, 0x07001702, 0x2d000d05, 0x0900130c,   // tt.ba.un_420 sr.bg.un_220  cs.sk.un_330 bh.hi.un_530 
  0x2d000d0d, 0x00004606, 0x00003903, 0x3d003020,   // cs.sk.un_540 qu.un.un_400  br.un.un_300 uz.ku.un_850 
  0x2300440c, 0x0000150a, 0x5955500c, 0x21003d04,   // kk.ky.un_530 un.un.un_500  fj.rw.rn_543 ku.fa.un_320 
  // [0310]
  0x3b122812, 0x00001106, 0x1000040b, 0x0d002d12,   // sd.ur.ks_654 ro.un.un_400  ru.be.un_520 sk.cs.un_640 
  0x07080405, 0x15003005, 0x00000d15, 0xfc64300d,   // ru.uk.bg_333 uz.un.un_330  cs.un.un_700 uz.lg.zzp_554 
  0x5c000f13, 0x596755a9, 0x1c03690c, 0x12003021,   // lv.sa.un_650 rw.ak.rn_544  mfe.nl.id_543 uz.ur.un_860 
  0x00002a03, 0x2d000d19, 0x30001304, 0x2d000d20,   // mt.un.un_300 cs.sk.un_750  et.uz.un_320 cs.sk.un_850 
  // [0320]
  0x536930a7, 0x2e000e0d, 0x383c23af, 0x0000251c,   // uz.mfe.ht_532 is.fo.un_540  ky.ug.tk_655 mn.un.un_800 
  0x15000204, 0x00004b1c, 0x213d34a0, 0x00002a01,   // da.un.un_320 mi.un.un_800  ps.ku.fa_322 mt.un.un_200 
  0x443c230d, 0x08000a04, 0x15006e07, 0x21002f0d,   // ky.ug.kk_554 mk.uk.un_320  hmn.un.un_420 su.jw.un_540 
  0x09001312, 0x1b313807, 0x00000e03, 0x3d003404,   // bh.hi.un_640 tk.az.tr_432  is.un.un_300 ps.ku.un_320 
  // [0330]
  0x21003d02, 0x17001605, 0x00001801, 0x00005006,   // ku.fa.un_220 hr.sr.un_330  ga.un.un_200 fj.un.un_400 
  0x00001503, 0x4b005c0d, 0x131e4d04, 0x0000640a,   // un.un.un_300 sa.mi.un_540  aa.ms.et_332 lg.un.un_500 
  0x3400180d, 0x022855a4, 0x17000a05, 0x0000530a,   // ar.ps.un_540 rw.sw.da_433  mk.sr.un_330 ht.un.un_500 
  0x1b0215a4, 0x0000131c, 0x4b5c4907, 0x0000090a,   // un.da.tr_433 et.un.un_800  to.sa.mi_432 pl.un.un_500 
  // [0340]
  0x4b005c08, 0x537669a4, 0x31001b07, 0x30004d0d,   // sa.mi.un_430 mfe.crs.ht_433  tr.az.un_420 aa.uz.un_540 
  0x21003d05, 0x00003d03, 0x211218ee, 0x18283412,   // ku.fa.un_330 ku.un.un_300  ar.ur.fa_422 ps.sd.ar_654 
  0x48003723, 0x0b003304, 0x484423a4, 0x1500040d,   // ba.tt.un_880 as.bn.un_320  ky.kk.tt_433 ru.un.un_540 
  0x00002115, 0x21003d13, 0x12341807, 0x08000a02,   // jw.un.un_700 ku.fa.un_650  ar.ps.ur_432 mk.uk.un_220 
  // [0350]
  0x341812a4, 0x07002304, 0x37004805, 0x07000a02,   // ur.ar.ps_433 ky.bg.un_320  tt.ba.un_330 mk.bg.un_220 
  0x0000150f, 0x48043755, 0x00001101, 0x0000540f,   // un.un.un_600 ba.ru.tt_442  ro.un.un_200 ik.un.un_600 
  0x0d001302, 0x42116b12, 0x0000fc06, 0x00003615,   // bh.ne.un_220 ceb.ro.co_654  zzp.un.un_400 gn.un.un_700 
  0x21003007, 0x182834a4, 0x112247a4, 0x37003c0c,   // uz.fa.un_420 ps.sd.ar_433  sn.oc.ro_433 ug.ba.un_530 
  // [0360]
  0x403f06ec, 0x480c3007, 0x33653008, 0x0000650f,   // de.af.lb_644 uz.sv.tt_432  uz.gv.nn_443 gv.un.un_600 
  0x0000351c, 0x00001b15, 0x30006513, 0x1e002f02,   // tg.un.un_800 tr.un.un_700  gv.uz.un_650 su.ms.un_220 
  0x00001f0f, 0x0000610a, 0x3000650d, 0x0000300f,   // cy.un.un_600 za.un.un_500  gv.uz.un_540 uz.un.un_600 
  0x3000030e, 0x211812a4, 0x00002003, 0x32001623,   // nl.uz.un_550 ur.ar.fa_433  sq.un.un_300 hr.bs.un_880 
  // [0370]
  0x330c650c, 0x0408150d, 0x0000231c, 0x3f000304,   // gv.sv.nn_543 un.uk.ru_554  ky.un.un_800 nl.af.un_320 
  0x00004b0a, 0x0000010f, 0x011d1dee, 0x04132807,   // mi.un.un_500 iw.un.un_600  la.la.en_422 sw.et.fi_432 
  0x030e30a7, 0x3200210d, 0x6b001a22, 0x182834ec,   // uz.is.nl_532 jw.bs.un_540  tl.ceb.un_870 ps.sd.ar_644 
  0x0a043504, 0x04134213, 0x0000020a, 0x0e330808,   // tg.ru.mk_332 co.et.fi_665  da.un.un_500 no.nn.is_443 
  // [0380]
  0x5c00300e, 0x00001d06, 0x122a5807, 0x0f004b04,   // uz.sa.un_550 la.un.un_400  om.mt.hu_432 mi.lv.un_320 
  0x16321708, 0x00002c24, 0x20000202, 0x233744a4,   // sr.bs.hr_443 fy.un.un_900  da.sq.un_220 kk.ba.ky_433 
  0x0e000204, 0x330820ec, 0x23001f0e, 0x18002805,   // da.is.un_320 sq.no.nn_644  cy.ca.un_550 sd.ar.un_330 
  0x2d004a05, 0x48123012, 0x00000d1c, 0x00002a1c,   // yo.sk.un_330 uz.hu.tt_654  cs.un.un_800 mt.un.un_800 
  // [0390]
  0x3f3065ad, 0x353023a7, 0x32160914, 0x00001d03,   // gv.uz.af_643 ky.uz.tg_532  pl.hr.bs_666 la.un.un_300 
  0x330c30ee, 0x00000703, 0x3f0330a4, 0x3d28210c,   // uz.sv.nn_422 bg.un.un_300  uz.nl.af_433 fa.sd.ku_543 
  0x1523440c, 0x00006115, 0x0000630a, 0x35003013,   // kk.ky.un_543 za.un.un_700  sco.un.un_500 uz.tg.un_650 
  0x48006508, 0x20000102, 0x37003607, 0x330c2e08,   // gv.tt.un_430 en.sq.un_220  ab.ba.un_420 fo.sv.nn_443 
  // [03a0]
  0x0000490a, 0x33000814, 0x0000620a, 0x131e1c09,   // to.un.un_500 no.nn.un_660  kha.un.un_500 id.ms.et_444 
  0x32162aa0, 0x0000362d, 0x0a0717a4, 0x0d362d04,   // mt.hr.bs_322 gn.un.un_A00  sr.bg.mk_433 sk.gn.cs_332 
  0x08025da9, 0x6a29370c, 0x125d370c, 0x2a002922,   // ss.da.no_544 st.sl.haw_543  st.ss.hu_543 sl.mt.un_870 
  0x0000fc03, 0x3729470c, 0x12003419, 0x3412180c,   // zzp.un.un_300 sn.sl.st_543  ps.ur.un_750 ar.ur.ps_543 
  // [03b0]
  0x080417a7, 0x450d1b12, 0x00002e01, 0x2500011a,   // sr.ru.uk_532 tr.cs.ln_654  fo.un.un_200 en.eu.un_760 
  0x0000501c, 0x391c03ad, 0x34213d04, 0x00000a15,   // fj.un.un_800 nl.id.br_643  ku.fa.ps_332 mk.un.un_700 
  0x32001b04, 0x00003103, 0x0d1c0907, 0x24035c07,   // tr.bs.un_320 az.un.un_300  hi.mr.ne_432 sa.nl.eo_432 
  0x2f381c04, 0x0000391c, 0x00003115, 0x34fc58a0,   // id.tk.su_332 br.un.un_800  az.un.un_700 om.zzp.xh_322 
  // [03c0]
  0x25126907, 0x00004915, 0x23003002, 0x40033fa9,   // mfe.hu.eu_432 to.un.un_700  uz.ky.un_220 af.nl.lb_544 
  0x3b00fc07, 0x07000402, 0x2d000d1b, 0x34001204,   // zzp.so.un_420 ru.bg.un_220  cs.sk.un_770 ur.ps.un_320 
  0x3534470b, 0x4c3bfc04, 0x29000d08, 0x00001f0a,   // sn.xh.zu_542 zzp.so.wo_332  cs.sl.un_430 cy.un.un_500 
  0x23003c13, 0x33000802, 0x1c000907, 0x44000404,   // ug.ky.un_650 no.nn.un_220  hi.mr.un_420 ru.kk.un_320 
  // [03d0]
  0x35001504, 0x0000560a, 0x1a002f04, 0x1e561ca9,   // un.tg.un_320 mg.un.un_500  su.tl.un_320 id.mg.ms_544 
  0x0000330f, 0x18002704, 0x20321705, 0x34004707,   // as.un.un_600 gd.ga.un_320  sr.bs.sq_333 sn.xh.un_420 
  0x56001318, 0x3b004d0d, 0x122d0d05, 0x12001b04,   // et.mg.un_740 aa.so.un_540  cs.sk.hu_333 tr.hu.un_320 
  0x0d384dee, 0x4400181a, 0x08004404, 0x12003604,   // aa.tk.cs_422 ar.kk.un_760  kk.uk.un_320 gn.hu.un_320 
  // [03e0]
  0x00001b03, 0x5e005d22, 0x2c002902, 0x00003106,   // tr.un.un_300 ss.ts.un_870  sl.fy.un_220 az.un.un_400 
  0x3d2118a7, 0x1c0913a0, 0x00003d0f, 0x250d3907,   // ar.fa.ku_532 bh.hi.mr_322  ku.un.un_600 br.cs.eu_432 
  0x124d1b05, 0x2a124dad, 0x17100802, 0x2f211c02,   // tr.aa.hu_333 aa.hu.mt_643  uk.be.sr_222 id.jw.su_222 
  0x0f004707, 0x2a00470e, 0x00001b0f, 0x10000f07,   // sn.lv.un_420 sn.mt.un_550  tr.un.un_600 lv.lt.un_420 
  // [03f0]
  0x0000460f, 0x30002523, 0x0e002e05, 0x1c00090e,   // qu.un.un_600 mn.uz.un_880  fo.is.un_330 hi.mr.un_550 
  0x00000b1c, 0x04002504, 0x0a001702, 0x122d0d0d,   // bn.un.un_800 mn.ru.un_320  sr.mk.un_220 cs.sk.hu_554 
  0x09000d13, 0x00005203, 0x0000060a, 0x07001704,   // ne.hi.un_650 ha.un.un_300  de.un.un_500 sr.bg.un_320 
  0x481504a9, 0x0f00470e, 0x3b0925a0, 0x3d122107,   // ru.tt.un_540 sn.lv.un_550  eu.pl.so_322 fa.ur.ku_432 
  
  // [0400]
  0x09000f08, 0x09001c09, 0x2d0d2911, 0x342112ad,   // lv.pl.un_430 mr.hi.un_440  sl.cs.sk_653 ur.fa.ps_643 
  0x1c5c0d0c, 0x21001212, 0x1c001304, 0x00000b03,   // ne.sa.mr_543 ur.fa.un_640  bh.mr.un_320 es.un.un_300 
  0x00001515, 0x0a15300c, 0x3000442b, 0x12003b0d,   // un.un.un_700 uz.mk.un_530  kk.uz.un_980 ks.ur.un_540 
  0x09001f05, 0x3c00441a, 0x04004802, 0x0d792d0b,   // cy.pl.un_330 kk.ug.un_760  tt.ru.un_220 sk.war.cs_542 
  // [0410]
  0x07001008, 0x1600181a, 0x1c000908, 0x0e002e02,   // be.bg.un_430 ar.th.un_760  hi.mr.un_430 fo.is.un_220 
  0x04001708, 0x04002304, 0x15070404, 0x37004407,   // sr.ru.un_430 ky.ru.un_320  ru.bg.un_332 kk.ba.un_420 
  0x00004906, 0x00002d03, 0x321716a4, 0x17000a07,   // to.un.un_400 sk.un.un_300  hr.sr.bs_433 mk.sr.un_420 
  0x5c001c0d, 0x1a0833ee, 0x0e002e0d, 0x55003204,   // mr.sa.un_540 nn.no.tl_422  fo.is.un_540 bs.rw.un_320 
  // [0420]
  0x02003f0e, 0x00005a01, 0x1b483109, 0x0c000802,   // af.da.un_550 sm.un.un_200  az.tt.tr_444 no.sv.un_220 
  0x21003d08, 0x34007307, 0x3d2130ec, 0x00002903,   // ku.fa.un_430 ny.xh.un_420  uz.fa.ku_644 sl.un.un_300 
  0x00005715, 0x00004d15, 0x12282104, 0x342344a4,   // na.un.un_700 aa.un.un_700  fa.sd.ur_332 kk.ky.ps_433 
  0x6b004c0d, 0x53001819, 0x73006802, 0x0a001107,   // wo.ceb.un_540 ga.ht.un_750  ig.ny.un_220 ro.mk.un_420 
  // [0430]
  0x3f000305, 0x632765ec, 0x00003806, 0x0000470f,   // nl.af.un_330 gv.gd.sco_644  tk.un.un_400 sn.un.un_600 
  0x39353402, 0x152c0107, 0x0e002e12, 0x65002705,   // xh.zu.br_222 en.fy.un_432  fo.is.un_640 gd.gv.un_330 
  0x00002f0f, 0x32002008, 0x4a00450d, 0x0000450f,   // su.un.un_600 sq.bs.un_430  ln.yo.un_540 ln.un.un_600 
  0x38391e0c, 0x510410a7, 0x1c005c0c, 0x3f032e0c,   // ms.br.tk_543 lt.fi.kl_532  sa.mr.un_530 fo.nl.af_543 
  // [0440]
  0x3000380c, 0x00006e03, 0x130451a7, 0x2c033f5a,   // tk.uz.un_530 hmn.un.un_300  kl.fi.et_532 af.nl.fy_553 
  0x332c0807, 0x330c0808, 0x55730fa0, 0x3c234413,   // no.fy.nn_432 no.sv.nn_443  lv.ny.rw_322 kk.ky.ug_665 
  0x100a3507, 0x3b005807, 0x2f002804, 0x0d001c0c,   // tg.mk.be_432 om.so.un_420  sw.su.un_320 mr.ne.un_530 
  0x30003c22, 0x122118a9, 0x00002015, 0x286e2b07,   // ug.uz.un_870 ar.fa.ur_544  sq.un.un_700 vi.hmn.sw_432 
  // [0450]
  0x08000205, 0x0000280f, 0x08001704, 0x35005504,   // da.no.un_330 sd.un.un_600  sr.uk.un_320 rw.zu.un_320 
  0x35003005, 0x0000fe06, 0x0d000907, 0x00006e1c,   // uz.tg.un_330 tlh.un.un_400  hi.ne.un_420 hmn.un.un_800 
  0x23353808, 0x18003e08, 0x00000101, 0x5c001302,   // tk.tg.ky_443 rm.ga.un_430  en.un.un_200 et.sa.un_220 
  0x23003707, 0xfe006113, 0x0b00330d, 0x00002c06,   // ba.ky.un_420 za.tlh.un_650  as.bn.un_540 fy.un.un_400 
  // [0460]
  0x0000031c, 0x1d005014, 0x3c003821, 0x09003b04,   // nl.un.un_800 fj.la.un_660  tk.ug.un_860 so.pl.un_320 
  0x0400510e, 0x2157fea4, 0x3f003404, 0x10004b04,   // kl.fi.un_550 tlh.na.jw_433  xh.af.un_320 mi.lt.un_320 
  0x27006521, 0x0a003602, 0x64005508, 0x2f211ca9,   // gv.gd.un_860 gn.pt.un_220  rw.lg.un_430 id.jw.su_544 
  0x31001b14, 0x17004007, 0x1004150d, 0x18004409,   // tr.az.un_660 lb.sr.un_420  un.ru.be_554 kk.ar.un_440 
  // [0470]
  0x586504a4, 0x10003204, 0x00003403, 0x056504a7,   // fi.gv.om_433 bs.lt.un_320  ps.un.un_300 fi.gv.fr_532 
  0x04004804, 0x6b15010c, 0x4d545112, 0x0000fe03,   // tt.ru.un_320 en.ceb.un_530  kl.ik.aa_654 tlh.un.un_300 
  0x2f212009, 0x25001004, 0x530163a7, 0x090138ee,   // sq.jw.su_444 lt.eu.un_320  sco.en.ht_532 tk.en.pl_422 
  0x182765af, 0xfe006111, 0x0000fe0f, 0x1c5c0dad,   // gv.gd.ga_655 za.tlh.un_630  tlh.un.un_600 ne.sa.mr_643 
  // [0480]
  0x1d274dec, 0x0000500a, 0x20330808, 0x00001d15,   // aa.gd.la_644 fj.un.un_500  no.nn.sq_443 la.un.un_700 
  0x0a000705, 0x65000212, 0x28001819, 0x2b006e07,   // bg.mk.un_330 da.gv.un_640  ar.sd.un_750 hmn.vi.un_420 
  0x34005e04, 0x0000390f, 0x04070a07, 0x631e62a9,   // ts.xh.un_320 br.un.un_600  mk.bg.ru_432 kha.ms.sco_544 
  0x0c0262ee, 0x020163a4, 0x09001f13, 0x04313008,   // kha.da.sv_422 sco.en.da_433  cy.pl.un_650 uz.az.fi_443 
  // [0490]
  0x00001c0f, 0x0000181c, 0x3b001f07, 0x0000630f,   // mr.un.un_600 ar.un.un_800  cy.so.un_420 sco.un.un_600 
  0x05002207, 0x305229a0, 0x024651a9, 0x2d003812,   // oc.fr.un_420 sl.ha.uz_322  kl.qu.da_544 tk.sk.un_640 
  0x51000508, 0x380648a9, 0x465104a9, 0x00000415,   // fr.kl.un_430 tt.de.tk_544  fi.kl.qu_544 fi.un.un_700 
  0x605104a9, 0x0717080c, 0x3c00231a, 0x00000c0f,   // fi.kl.vo_544 uk.sr.bg_543  ky.ug.un_760 sv.un.un_600 
  // [04a0]
  0x20005b12, 0x3000462a, 0x3c004414, 0x1e000107,   // sg.sq.un_640 qu.uz.un_970  kk.ug.un_660 en.ms.un_420 
  0x21001c07, 0x1e1c64a0, 0x111d690b, 0x321716a0,   // id.jw.un_420 lg.id.ms_322  mfe.la.ro_542 hr.sr.bs_322 
  0x1e006404, 0x00003c1c, 0x1c0d0904, 0x0c004804,   // lg.ms.un_320 ug.un.un_800  hi.ne.mr_332 tt.sv.un_320 
  0x0000241c, 0x07001012, 0x24000113, 0x09000d05,   // yi.un.un_800 be.bg.un_640  iw.yi.un_650 ne.hi.un_330 
  // [04b0]
  0x170408a0, 0x10000402, 0x20001e0b, 0x23004408,   // uk.ru.sr_322 ru.be.un_220  am.ti.un_520 kk.ky.un_430 
  0x37004804, 0x28182702, 0x28005804, 0x02561e07,   // tt.ba.un_320 gd.ga.sw_222  om.sw.un_320 ms.mg.da_432 
  0x5a000104, 0x32171614, 0x00006403, 0x304804ee,   // en.sm.un_320 hr.sr.bs_666  lg.un.un_300 ru.tt.uz_422 
  0x023665ad, 0x2a30560c, 0x4800400c, 0x2d000d13,   // gv.gn.da_643 mg.uz.mt_543  lb.tt.un_530 cs.sk.un_650 
  // [04c0]
  0x27791804, 0x40004802, 0x0a000402, 0x4c0d210c,   // ga.war.gd_332 tt.lb.un_220  ru.mk.un_220 jw.cs.wo_543 
  0x00004015, 0x0b00330c, 0x65002502, 0x20001e20,   // lb.un.un_700 as.bn.un_530  eu.gv.un_220 am.ti.un_850 
  0x11003002, 0x00005a15, 0x02006512, 0x5f494509,   // uz.ro.un_220 sm.un.un_700  gv.da.un_640 ln.to.tn_444 
  0x00003e01, 0x641825a7, 0x0000020f, 0x19000b0c,   // rm.un.un_200 eu.ga.lg_532  da.un.un_600 es.gl.un_530 
  // [04d0]
  0x5f4502ee, 0x00004024, 0x5f004b1a, 0x00003d15,   // da.ln.tn_422 lb.un.un_900  mi.tn.un_760 ku.un.un_700 
  0x19000b02, 0x526a45ad, 0x5955560e, 0x12005d04,   // es.gl.un_220 ln.haw.ha_643  mg.rw.rn_555 ss.hu.un_320 
  0x64130207, 0x55640208, 0x23003c12, 0x08001021,   // da.et.lg_432 da.lg.rw_443  ug.ky.un_640 be.uk.un_860 
  0x36004517, 0x560d12a4, 0x64690204, 0x495f2502,   // ln.gn.un_730 hu.cs.mg_433  da.mfe.lg_332 eu.tn.to_222 
  // [04e0]
  0x5e552808, 0x2d36455a, 0x5a006507, 0x1b456019,   // sw.rw.ts_443 ln.gn.sk_553  gv.sm.un_420 vo.ln.tr_765 
  0x1c0d5c08, 0x342128ec, 0x00004006, 0x2552560c,   // sa.ne.mr_443 sd.fa.ps_644  lb.un.un_400 mg.ha.eu_543 
  0x502557ec, 0x65272507, 0x353459ee, 0x1c005502,   // na.eu.fj_644 eu.gd.gv_432  rn.xh.zu_422 rw.id.un_220 
  0x652718af, 0x190d0b0c, 0x132c27ee, 0x4000060e,   // ga.gd.gv_655 es.cs.gl_543  gd.fy.et_422 de.lb.un_550 
  // [04f0]
  0x48002304, 0x45002509, 0x12002107, 0x00000c15,   // ky.tt.un_320 eu.ln.un_440  jw.hu.un_420 sv.un.un_700 
  0x102450ad, 0x17003c0b, 0x49025508, 0x0c00380e,   // fj.eo.lt_643 ug.sr.un_520  rw.da.to_443 tk.sv.un_550 
  0x311e30a0, 0xfc535f05, 0x1c091305, 0x0000210f,   // uz.ms.az_322 tn.ht.zzp_333  bh.hi.mr_333 fa.un.un_600 
  0x4b2902a4, 0x30000209, 0x00004b0f, 0x06484004,   // da.sl.mi_433 da.uz.un_440  mi.un.un_600 lb.tt.de_332 
  // [0500]
  0x10000405, 0x0f3210a0, 0x0000211c, 0x303618a7,   // ru.be.un_330 lt.bs.lv_322  fa.un.un_800 ga.gn.uz_532 
  0x083511a0, 0x37343002, 0x47002805, 0x2e0f100c,   // ro.tg.uk_322 uz.xh.st_222  sw.sn.un_330 lt.lv.fo_543 
  0xfe621f05, 0x065e3f0e, 0x0c003302, 0x17040804,   // cy.kha.tlh_333 af.ts.de_555  nn.sv.un_220 uk.ru.sr_332 
  0x3700210c, 0x3b1f6209, 0x48311b11, 0x093f1fa0,   // jw.st.un_530 kha.cy.so_444  tr.az.tt_653 cy.af.pl_322 
  // [0510]
  0x00003824, 0x47545505, 0x3b095508, 0x55353404,   // tk.un.un_900 rw.ik.sn_333  rw.pl.so_443 xh.zu.rw_332 
  0x3b001f05, 0x13002a07, 0x5900551b, 0x00003024,   // cy.so.un_330 mt.et.un_420  rw.rn.un_770 uz.un.un_900 
  0x122d0d04, 0x28112905, 0x05003007, 0x1f407813,   // cs.sk.hu_332 sl.ro.sw_333  uz.fr.un_420 ve.lb.cy_665 
  0x12003034, 0x2f4d210b, 0x68201108, 0x01001507,   // uz.ur.un_A80 jw.aa.su_542  ro.sq.ig_443 un.en.un_420 
  // [0520]
  0x0c00040e, 0x00006815, 0x00006b03, 0x2e003602,   // fi.sv.un_550 ig.un.un_700  ceb.un.un_300 gn.fo.un_220 
  0x55605912, 0x12003605, 0x00005506, 0x287335a4,   // rn.vo.rw_654 gn.hu.un_330  rw.un.un_400 zu.ny.sw_433 
  0x47595555, 0x38004d21, 0x58552fa0, 0x321611a0,   // rw.rn.sn_442 aa.tk.un_860  su.rw.om_322 ro.hr.bs_322 
  0x402720a0, 0x73201104, 0x465d02a4, 0x0000371c,   // sq.gd.lb_322 ro.sq.ny_332  da.ss.qu_433 ba.un.un_800 
  // [0530]
  0x02005513, 0x28003b0d, 0x34122804, 0x3c442313,   // rw.da.un_650 ks.sd.un_540  sd.ur.ps_332 ky.kk.ug_665 
  0x590255ec, 0x345d3555, 0x07001705, 0x59005523,   // rw.da.rn_644 zu.ss.xh_442  sr.bg.un_330 rw.rn.un_880 
  0x1d006504, 0x274238a4, 0x35000b08, 0x2f214eaf,   // gv.la.un_320 tk.co.gd_433  es.zu.un_430 ay.jw.su_655 
  0x42001f1a, 0x3f004005, 0x2f21470c, 0x3700481a,   // cy.co.un_760 lb.af.un_330  sn.jw.su_543 tt.ba.un_760 
  // [0540]
  0x22190b08, 0x24001f05, 0x4d00461b, 0x34211209,   // es.gl.oc_443 cy.eo.un_330  qu.aa.un_770 ur.fa.ps_444 
  0x2700020d, 0x1f274212, 0x3b5552a7, 0xfe465207,   // da.gd.un_540 co.gd.cy_654  ha.rw.so_532 ha.qu.tlh_432 
  0x00004d0f, 0x03003f02, 0x4400370d, 0x095511ee,   // aa.un.un_600 af.nl.un_220  ba.kk.un_540 ro.rw.pl_422 
  0x64003502, 0x04080704, 0x00001103, 0x73642811,   // zu.lg.un_220 bg.uk.ru_332  ro.un.un_300 sw.lg.ny_653 
  // [0550]
  0x13000d0e, 0x5c595555, 0x32161709, 0x12001808,   // ne.bh.un_550 rw.rn.sa_442  sr.hr.bs_444 ga.hu.un_430 
  0x3e002702, 0x033f2707, 0x04001707, 0x1100550e,   // gd.rm.un_220 gd.af.nl_432  sr.ru.un_420 rw.ro.un_550 
  0x171632ee, 0x38003c34, 0x00007315, 0x033f1f07,   // bs.hr.sr_422 ug.tk.un_A80  ny.un.un_700 cy.af.nl_432 
  0x584d27ec, 0x15303c12, 0x48000c07, 0x17070aa4,   // gd.aa.om_644 ug.uz.un_654  sv.tt.un_420 mk.bg.sr_433 
  // [0560]
  0x361537a4, 0x00002201, 0x1c090d05, 0x303515ec,   // ba.ab.un_430 oc.un.un_200  ne.hi.mr_333 un.tg.uz_644 
  0x00005e0a, 0x63396511, 0x6b390213, 0x3800170e,   // ts.un.un_500 gv.br.sco_653  da.br.ceb_665 sr.tk.un_550 
  0x42407904, 0x2f4365a4, 0x00001906, 0x0e020c14,   // war.lb.co_332 gv.ie.su_433  gl.un.un_400 sv.da.is_666 
  0x6e003f08, 0x2c000508, 0x2e002704, 0xfe004a07,   // af.hmn.un_430 fr.fy.un_430  gd.fo.un_320 yo.tlh.un_420 
  // [0570]
  0x00004a24, 0x0000272d, 0x4800440c, 0x63150111,   // yo.un.un_900 gd.un.un_A00  kk.tt.un_530 en.sco.un_630 
  0x00001c15, 0x3f004002, 0x1f194c0c, 0x07170a14,   // mr.un.un_700 lb.af.un_220  wo.gl.cy_543 mk.sr.bg_666 
  0x4c0c025a, 0x00002e15, 0x184773ec, 0x03003f08,   // da.sv.wo_553 fo.un.un_700  ny.sn.ga_644 af.nl.un_430 
  0x0e653304, 0x0600fc02, 0x1f0511ad, 0x0b0a19ee,   // nn.gv.is_332 zzp.de.un_220  ro.fr.cy_643 gl.pt.es_422 
  // [0580]
  0x35000407, 0x24001604, 0x2c000302, 0x12003b0c,   // ru.tg.un_420 hr.eo.un_320  nl.fy.un_220 ks.ur.un_530 
  0x57006e14, 0x00006915, 0x6e003022, 0x0a001904,   // hmn.na.un_660 mfe.un.un_700  uz.hmn.un_870 gl.pt.un_320 
  0x0000361c, 0x00007906, 0x00003b03, 0x1f1876a7,   // gn.un.un_800 war.un.un_400  so.un.un_300 crs.ga.cy_532 
  0x23003021, 0x79000d18, 0x0f002302, 0x31381bad,   // uz.ky.un_860 cs.war.un_740  ca.lv.un_220 tr.tk.az_643 
  // [0590]
  0x2d490d07, 0x00003f1c, 0x18002804, 0x1d052c0c,   // cs.to.sk_432 af.un.un_800  sd.ar.un_320 fy.fr.la_543 
  0x443c2307, 0x0e020c13, 0x052c220d, 0x00001815,   // ky.ug.kk_432 sv.da.is_665  oc.fy.fr_554 ar.un.un_700 
  0x0000481c, 0x12001902, 0x08002514, 0x29005a02,   // tt.un.un_800 gl.hu.un_220  mn.uk.un_660 sm.sl.un_220 
  0x19001209, 0x6b276e0c, 0x18122807, 0x30003509,   // hu.gl.un_440 hmn.gd.ceb_543  sd.ur.ar_432 tg.uz.un_440 
  // [05a0]
  0x2d0d1909, 0x17163205, 0x4800370d, 0x323120a9,   // gl.cs.sk_444 bs.hr.sr_333  ba.tt.un_540 sq.az.bs_544 
  0x0e002e1b, 0x053369ee, 0x0b5223a0, 0x04001313,   // fo.is.un_770 mfe.nn.fr_422  ca.ha.es_322 et.fi.un_650 
  0x2b261507, 0x3c002309, 0x433e0509, 0x23003902,   // un.ia.vi_432 ky.ug.un_440  fr.rm.ie_444 br.ca.un_220 
  0x00003303, 0x431b380d, 0x303412a4, 0x21003404,   // nn.un.un_300 tk.tr.ie_554  ur.ps.uz_433 ps.fa.un_320 
  // [05b0]
  0x08041513, 0x00001e01, 0x070a04ee, 0x1300090d,   // un.ru.uk_665 ms.un.un_200  ru.mk.bg_422 hi.bh.un_540 
  0x10005c12, 0x1c0d1302, 0x38002d02, 0x5c1c1308,   // sa.lt.un_640 bh.ne.mr_222  sk.tk.un_220 bh.mr.sa_443 
  0x00004715, 0x131c5c09, 0x00001c1c, 0x00005b2d,   // sn.un.un_700 sa.mr.bh_444  mr.un.un_800 sg.un.un_A00 
  0x30003819, 0x213034af, 0x00003203, 0x3f3b0313,   // tk.uz.un_750 ps.uz.fa_655  bs.un.un_300 nl.so.af_665 
  // [05c0]
  0x5c001c07, 0x080407a4, 0x30003c19, 0x13000422,   // mr.sa.un_420 bg.ru.uk_433  ug.uz.un_750 fi.et.un_870 
  0x1c213905, 0x070a17a4, 0x28211209, 0x00003906,   // br.jw.id_333 sr.mk.bg_433  ur.fa.sd_444 br.un.un_400 
  0x10150804, 0x4d005319, 0x13044807, 0x1a004f0e,   // uk.be.un_320 ht.aa.un_750  tt.fi.et_432 bi.tl.un_550 
  0x15000419, 0x5c130d08, 0x32171609, 0x22001012,   // ru.un.un_750 ne.bh.sa_443  hr.sr.bs_444 lt.oc.un_640 
  // [05d0]
  0x2400010d, 0x00001b0a, 0x38001b07, 0x3428120c,   // iw.yi.un_540 tr.un.un_500  tr.tk.un_420 ur.sd.ps_543 
  0x1800280d, 0x00003e03, 0x092d0d04, 0x0d000905,   // sd.ar.un_540 rm.un.un_300  cs.sk.pl_332 hi.ne.un_330 
  0x634301a0, 0x00002815, 0x00005603, 0x00006824,   // en.ie.sco_322 sd.un.un_700  mg.un.un_300 ig.un.un_900 
  0x0d001304, 0x092d0d60, 0x1300480d, 0x101536ee,   // bh.ne.un_320 cs.sk.pl_664  tt.et.un_540 ab.be.un_420 
  // [05e0]
  0x34001804, 0x01002419, 0x3c3635a4, 0x48001312,   // ar.ps.un_320 yi.iw.un_750  tg.ab.ug_433 et.tt.un_640 
  0x00003f0a, 0x5369765a, 0x2818340c, 0x794f1e07,   // af.un.un_500 crs.mfe.ht_553  ps.ar.sd_543 ms.bi.war_432 
  0x5d190b02, 0x043c15a0, 0x39001212, 0x010263ad,   // es.gl.ss_222 un.ug.ru_322  hu.br.un_640 sco.da.en_643 
  0x0e2e2408, 0x37483855, 0x2e004c09, 0x18005c04,   // eo.fo.is_443 tk.tt.ba_442  wo.fo.un_440 sa.ga.un_320 
  // [05f0]
  0x575625a4, 0x0a171113, 0x5200570c, 0x481b3114,   // eu.mg.na_433 ro.sr.mk_665  na.ha.un_530 az.tr.tt_666 
  0x51003e0c, 0x00002515, 0x57000108, 0x0e002e0e,   // rm.kl.un_530 mn.un.un_700  en.na.un_430 fo.is.un_550 
  0x12003d11, 0x13000909, 0x06000111, 0x2b27010c,   // ku.ur.un_630 hi.bh.un_440  en.de.un_630 en.gd.vi_543 
  0x107328a0, 0x3e000723, 0x42001108, 0x38000912,   // sw.ny.lt_322 it.rm.un_880  ro.co.un_430 pl.tk.un_640 
  // [0600]
  0x0700100c, 0x040a1702, 0x69007321, 0x56090d0c,   // be.bg.un_530 sr.mk.ru_222  ny.mfe.un_860 cs.pl.mg_543 
  0x06000113, 0x00006724, 0x2d001504, 0x00005a06,   // en.de.un_650 ak.un.un_900  un.sk.un_320 sm.un.un_400 
  0x34001213, 0x2d0d09a4, 0x00003e1c, 0x39207907,   // ur.ps.un_650 pl.cs.sk_433  rm.un.un_800 war.sq.br_432 
  0x13090da9, 0x47732d07, 0x13000911, 0x53000a02,   // ne.hi.bh_544 sk.ny.sn_432  hi.bh.un_630 pt.ht.un_220 
  // [0610]
  0x394063ad, 0x182134a9, 0x30153ca4, 0x0c132e04,   // sco.lb.br_643 ps.fa.ar_544  ug.uz.un_430 fo.et.sv_332 
  0x33280802, 0x190b3605, 0x181228ec, 0x443c23ad,   // no.sw.nn_222 gn.es.gl_333  sd.ur.ar_644 ky.ug.kk_643 
  0x00005a03, 0x43002314, 0x121602a0, 0x0c00131b,   // sm.un.un_300 ca.ie.un_660  da.hr.hu_322 et.sv.un_770 
  0x5300690c, 0x4c000108, 0x1600290e, 0x13000604,   // mfe.ht.un_530 en.wo.un_430  sl.hr.un_550 de.et.un_320 
  // [0620]
  0x20005e0c, 0x04000c07, 0x07004209, 0x080233ee,   // ts.sq.un_530 sv.fi.un_420  co.it.un_440 nn.da.no_422 
  0x06000c12, 0x38003508, 0x58330804, 0x33080208,   // sv.de.un_640 tg.tk.un_430  no.nn.om_332 da.no.nn_443 
  0x00000c1c, 0x25186307, 0x1f000502, 0x0421180c,   // sv.un.un_800 sco.ga.eu_432  fr.cy.un_220 ga.jw.fi_543 
  0x00006506, 0x1b003807, 0xfc001804, 0x2d48030c,   // gv.un.un_400 tk.tr.un_420  ga.zzp.un_320 nl.tt.sk_543 
  // [0630]
  0x401f01a0, 0x04060c67, 0x3f00061b, 0x21003402,   // en.cy.lb_322 sv.de.fi_775  de.af.un_770 ps.fa.un_220 
  0x060c5705, 0x302515a7, 0x1300650c, 0x480c5712,   // na.sv.de_333 un.mn.uz_532  gv.et.un_530 na.sv.tt_654 
  0x2d00390c, 0x00000615, 0x69005c19, 0x08001014,   // br.sk.un_530 de.un.un_700  sa.mfe.un_750 be.uk.un_660 
  0x18190b09, 0x13060cee, 0x1b645504, 0x00006806,   // es.gl.ga_444 sv.de.et_422  rw.lg.tr_332 ig.un.un_400 
  // [0640]
  0x0000170f, 0x04001307, 0x0d1c1355, 0x2d00600c,   // sr.un.un_600 et.fi.un_420  bh.mr.ne_442 vo.sk.un_530 
  0xfa003721, 0x2e0833a4, 0x2d0d12a4, 0x21301205,   // st.nr.un_860 nn.no.fo_433  hu.cs.sk_433 ur.uz.fa_333 
  0x3f02040c, 0x0000620f, 0x38006404, 0x60000420,   // fi.da.af_543 kha.un.un_600  lg.tk.un_320 fi.vo.un_850 
  0x18003d12, 0x10080404, 0x23004808, 0x2a5376a9,   // ku.ar.un_640 ru.uk.be_332  tt.ky.un_430 crs.ht.mt_544 
  // [0650]
  0x190b18ee, 0x1333180c, 0x0000621c, 0x1d001122,   // ga.es.gl_422 ga.nn.et_543  kha.un.un_800 ro.la.un_870 
  0x0c08020e, 0x54781aa9, 0x00007903, 0x30253504,   // da.no.sv_555 tl.ve.ik_544  war.un.un_300 tg.mn.uz_332 
  0x22000a2a, 0x0b230107, 0x026408a9, 0x1300690e,   // pt.oc.un_970 en.ca.es_432  no.lg.da_544 mfe.et.un_550 
  0x21002f05, 0x1200fe08, 0x20fe640c, 0x3400120d,   // su.jw.un_330 tlh.hu.un_430  lg.tlh.sq_543 ur.ps.un_540 
  // [0660]
  0x00003f0f, 0x4800380c, 0x212f60ec, 0x215d2f0c,   // af.un.un_600 tk.tt.un_530  vo.su.jw_644 su.ss.jw_543 
  0x0000041c, 0x31002304, 0x1d435a07, 0x4ffe790c,   // fi.un.un_800 ca.az.un_320  sm.ie.la_432 war.tlh.bi_543 
  0x796446a9, 0x21005308, 0x2e000e12, 0x3b172404,   // qu.lg.war_544 ht.jw.un_430  is.fo.un_640 eo.sr.so_332 
  0xfc00130d, 0x0000121c, 0x49252f07, 0x3035230c,   // et.zzp.un_540 hu.un.un_800  su.eu.to_432 ky.tg.uz_543 
  // [0670]
  0x5a493b0b, 0x31004004, 0x3000350b, 0x28060b04,   // so.to.sm_542 lb.az.un_320  tg.uz.un_520 es.de.sw_332 
  0x12481b07, 0x3b3119a0, 0x351008a9, 0x01002404,   // tr.tt.hu_432 gl.az.so_322  uk.be.tg_544 yi.iw.un_320 
  0x15483760, 0x38374813, 0x3d003434, 0x22007304,   // ba.tt.un_664 tt.ba.tk_665  ps.ku.un_A80 ny.oc.un_320 
  0x00002203, 0x00002024, 0x5f000d0c, 0x2455010c,   // oc.un.un_300 ti.un.un_900  cs.tn.un_530 en.rw.eo_543 
  // [0680]
  0x0000512d, 0x0d00220e, 0x34213d02, 0x22020a0c,   // kl.un.un_A00 oc.cs.un_550  ku.fa.ps_222 pt.da.oc_543 
  0x40122fa9, 0x54315114, 0x3e42505a, 0x2f002104,   // su.hu.lb_544 kl.az.ik_666  fj.co.rm_553 jw.su.un_320 
  0x33080402, 0x22fe0a04, 0x364c2fa9, 0x68006413,   // fi.no.nn_222 pt.tlh.oc_332  su.wo.gn_544 lg.ig.un_650 
  0x0000220a, 0x3b00511b, 0x04004402, 0x00000915,   // oc.un.un_500 kl.so.un_770  kk.ru.un_220 pl.un.un_700 
  // [0690]
  0x283412a0, 0x18003408, 0x043508ee, 0x343b1812,   // ur.ps.sd_322 ps.ar.un_430  uk.tg.ru_422 ar.ks.ps_654 
  0x00004c15, 0x3c11170d, 0x3730040c, 0x170a0712,   // wo.un.un_700 sr.ro.ug_554  ru.uz.ba_543 bg.mk.sr_654 
  0x04000904, 0x00005315, 0x23384407, 0x2300180e,   // pl.fi.un_320 ht.un.un_700  kk.tk.ky_432 ar.ky.un_550 
  0x0000201c, 0x20001e0d, 0x47005711, 0x1c001305,   // ti.un.un_800 am.ti.un_540  na.sn.un_630 bh.mr.un_330 
  // [06a0]
  0x21122805, 0x443704a4, 0x3b0409a6, 0x00006215,   // sd.ur.fa_333 ru.ba.kk_433  pl.fi.so_521 kha.un.un_700 
  0x48303507, 0x460b12a0, 0x04001002, 0x1700080c,   // tg.uz.tt_432 hu.es.qu_322  be.ru.un_220 uk.sr.un_530 
  0x37001712, 0x24000119, 0x3d211807, 0x1c000909,   // sr.ba.un_640 iw.yi.un_750  ar.fa.ku_432 hi.mr.un_440 
  0x100a07a0, 0x23003b0d, 0x482310ad, 0x00000503,   // bg.mk.be_322 ks.ky.un_540  be.ky.tt_643 fr.un.un_300 
  // [06b0]
  0x2523300c, 0x1c090da0, 0x17301105, 0x3c003013,   // uz.ky.mn_543 ne.hi.mr_322  ro.uz.sr_333 uz.ug.un_650 
  0x30001507, 0x3500480c, 0x23001812, 0x12342811,   // un.uz.un_420 tt.tg.un_530  ar.ky.un_640 sd.ps.ur_653 
  0x48002c0c, 0x31001b0e, 0x44003c13, 0x00000715,   // fy.tt.un_530 tr.az.un_550  ug.kk.un_650 bg.un.un_700 
  0x0d000914, 0x0a004802, 0x00003101, 0x04000718,   // hi.ne.un_660 tt.mk.un_220  az.un.un_200 bg.ru.un_740 
  // [06c0]
  0x353036a4, 0x122821ac, 0x18002104, 0x28003d08,   // ab.uz.tg_433 fa.sd.ur_632  fa.ar.un_320 ku.sd.un_430 
  0x170a3507, 0x28003408, 0x2d003604, 0x281834ee,   // tg.mk.sr_432 ps.sd.un_430  gn.sk.un_320 ps.ar.sd_422 
  0x00006a06, 0x0704100c, 0x55003419, 0x35070a0d,   // haw.un.un_400 be.ru.bg_543  xh.rw.un_750 mk.bg.tg_554 
  0x64003504, 0x072535ee, 0x12003012, 0x30350808,   // zu.lg.un_320 tg.mn.bg_422  uz.ur.un_640 uk.tg.uz_443 
  // [06d0]
  0x281230a4, 0x2f001c02, 0x10001509, 0x2300380d,   // uz.ur.sd_433 id.su.un_220  un.be.un_440 tk.ky.un_540 
  0x08002304, 0x00001824, 0x00007815, 0x6b796855,   // ky.uk.un_320 ar.un.un_900  ve.un.un_700 ig.war.ceb_442 
  0x12000904, 0x00005606, 0x04170707, 0x36003505,   // pl.hu.un_320 mg.un.un_400  bg.sr.ru_432 tg.ab.un_330 
  0x30003c07, 0x1e282a04, 0x6400451a, 0x1e001c04,   // ug.uz.un_420 mt.sw.ms_332  ln.lg.un_760 id.ms.un_320 
  // [06e0]
  0x276568ee, 0x5e681fa7, 0x39242da4, 0x09001c08,   // ig.gv.gd_422 cy.ig.ts_532  sk.eo.br_433 mr.hi.un_430 
  0x00005e1c, 0x6827180d, 0x0c00121a, 0x38233c60,   // ts.un.un_800 ga.gd.ig_554  hu.sv.un_760 ug.ky.tk_664 
  0x2a003904, 0x320a40a0, 0x00002e0a, 0x55530207,   // br.mt.un_320 lb.pt.bs_322  fo.un.un_500 da.ht.rw_432 
  0x257945a4, 0x00000a0a, 0x00004503, 0x066b1dad,   // ln.war.eu_433 mk.un.un_500  ln.un.un_300 la.ceb.de_643 
  // [06f0]
  0x25fc3902, 0x03002b05, 0x00006303, 0x46234ea4,   // br.zzp.eu_222 vi.nl.un_330  sco.un.un_300 ay.ca.qu_433 
  0x48383107, 0x1e005c07, 0x18002808, 0x30003814,   // az.tk.tt_432 sa.ms.un_420  sd.ar.un_430 tk.uz.un_660 
  0x480723a0, 0x07370a12, 0x1e2f1c0c, 0x64554511,   // ky.bg.tt_322 mk.ba.bg_654  id.su.ms_543 ln.rw.lg_653 
  0x47097955, 0x21002f02, 0x12213004, 0x0d1c5c07,   // war.pl.sn_442 su.jw.un_220  uz.fa.ur_332 sa.mr.ne_432 
  // [0700]
  0x53001d04, 0x2d124aa0, 0x112d0d12, 0x1e002a0c,   // la.ht.un_320 yo.hu.sk_322  cs.sk.ro_654 mt.ms.un_530 
  0x65fc2807, 0x54006413, 0x5d12360c, 0x2b000d04,   // sw.zzp.gv_432 lg.ik.un_650  gn.hu.ss_543 cs.vi.un_320 
  0x35097307, 0x1c000d04, 0x3e004804, 0x36122d08,   // ny.pl.zu_432 ne.mr.un_320  tt.rm.un_320 sk.hu.gn_443 
  0x213e1c02, 0x0000260a, 0x48003c0c, 0x5c1c0d02,   // id.rm.jw_222 ia.un.un_500  ug.tt.un_530 ne.mr.sa_222 
  // [0710]
  0x251523a4, 0x18000604, 0x3f656307, 0x0a1517a4,   // ky.mn.un_430 de.ga.un_320  sco.gv.af_432 sr.mk.un_430 
  0x1c00091b, 0x0c004814, 0x0400480c, 0x48040ca6,   // hi.mr.un_770 tt.sv.un_660  tt.fi.un_530 sv.fi.tt_521 
  0x38003004, 0x070804a9, 0x73006419, 0x321716af,   // uz.tk.un_320 ru.uk.bg_544  lg.ny.un_750 hr.sr.bs_655 
  0x211844a0, 0x30734ead, 0x5c0d09a9, 0x48000414,   // kk.ar.fa_322 ay.ny.uz_643  hi.ne.sa_544 fi.tt.un_660 
  // [0720]
  0x18002312, 0x3e002304, 0x3421300c, 0x48000411,   // ky.ar.un_640 ca.rm.un_320  uz.fa.ps_543 fi.tt.un_630 
  0x00004815, 0x44233c0c, 0x0c000207, 0x23443c60,   // tt.un.un_700 ug.ky.kk_543  da.sv.un_420 ug.kk.ky_664 
  0x0c000202, 0x0b003312, 0x1c0d090c, 0x08000202,   // da.sv.un_220 as.bn.un_640  hi.ne.mr_543 da.no.un_220 
  0x35002304, 0x00001203, 0x1c135c0c, 0x34487307,   // ky.tg.un_320 ur.un.un_300  sa.bh.mr_543 ny.tt.xh_432 
  // [0730]
  0x0000060f, 0x0000651c, 0x06004005, 0x23004802,   // de.un.un_600 gv.un.un_800  lb.de.un_330 tt.ky.un_220 
  0x554765a9, 0x04480660, 0x18001204, 0x0c0448ec,   // gv.sn.rw_544 de.tt.fi_664  ur.ar.un_320 tt.fi.sv_644 
  0x0c3308ee, 0x2d060402, 0x56003002, 0x06375fa7,   // no.nn.sv_422 fi.de.sk_222  uz.mg.un_220 tn.st.de_532 
  0x00005f06, 0x09001c14, 0x1234210c, 0x2c033f14,   // tn.un.un_400 mr.hi.un_660  fa.ps.ur_543 af.nl.fy_666 
  // [0740]
  0x18122804, 0x12002b04, 0x653f4da9, 0x283b0107,   // sd.ur.ar_332 vi.hu.un_320  aa.af.gv_544 iw.ks.sd_432 
  0x2d000e02, 0x2d000d23, 0x65150107, 0xfc000907,   // is.sk.un_220 cs.sk.un_880  en.gv.un_420 pl.zzp.un_420 
  0x0902730c, 0x3b5804a4, 0x5a00651a, 0x0e0d2d12,   // ny.da.pl_543 fi.om.so_433  gv.sm.un_760 sk.cs.is_654 
  0x3b254d0c, 0x0000151c, 0x6500030e, 0x09130d0b,   // aa.eu.so_543 un.un.un_800  nl.gv.un_550 ne.bh.hi_542 
  // [0750]
  0x4d583b0c, 0x00006a24, 0x4d005819, 0x34003d0c,   // so.om.aa_543 haw.un.un_900  om.aa.un_750 ku.ps.un_530 
  0x4d583b14, 0x2d0d2ba4, 0x5e000205, 0x313847a4,   // so.om.aa_666 vi.cs.sk_433  da.ts.un_330 sn.tk.az_433 
  0x492a280c, 0x3b4d580d, 0x60003808, 0x04001521,   // sw.mt.to_543 om.aa.so_554  tk.vo.un_430 un.ru.un_860 
  0x02452808, 0x175209a6, 0x3c002308, 0x576558af,   // sw.ln.da_443 pl.ha.sr_521  ky.ug.un_430 om.gv.na_655 
  // [0760]
  0x342548ee, 0x584d3b08, 0x40065fa6, 0x08000a13,   // tt.eu.xh_422 so.aa.om_443  tn.de.lb_521 mk.uk.un_650 
  0x5c1c0902, 0x2d0d12af, 0x3b584d04, 0x03003905,   // hi.mr.sa_222 hu.cs.sk_655  aa.om.so_332 br.nl.un_330 
  0x2c396504, 0x28003407, 0x3b00fc22, 0x35483804,   // gv.br.fy_332 ps.sd.un_420  zzp.so.un_870 tk.tt.tg_332 
  0x4d130409, 0x5534450c, 0x0d5c1ca7, 0x2d000d22,   // fi.et.aa_444 ln.xh.rw_543  mr.sa.ne_532 cs.sk.un_870 
  // [0770]
  0x00005f03, 0x4b0c2d07, 0x365e5d12, 0x3f580107,   // tn.un.un_300 sk.sv.mi_432  ss.ts.gn_654 en.om.af_432 
  0x38482f05, 0x15000421, 0x4d580807, 0x0d006b07,   // su.tt.tk_333 ru.un.un_860  no.om.aa_432 ceb.cs.un_420 
  0x4a581302, 0x18002718, 0x232219a4, 0x2e005104,   // et.om.yo_222 gd.ga.un_740  gl.oc.ca_433 kl.fo.un_320 
  0x251530ee, 0x48004e12, 0x13000423, 0x4b004908,   // uz.mn.un_420 ay.tt.un_640  fi.et.un_880 to.mi.un_430 
  // [0780]
  0x0c00600b, 0x301e1c02, 0x090d5c12, 0x53002007,   // vo.sv.un_520 id.ms.uz_222  sa.ne.hi_654 sq.ht.un_420 
  0x00004603, 0x200c60ad, 0x23253012, 0x650163ad,   // qu.un.un_300 vo.sv.sq_643  uz.mn.ky_654 sco.en.gv_643 
  0x6400760c, 0x00000b01, 0x5c001c0e, 0x301708a4,   // crs.lg.un_530 es.un.un_200  mr.sa.un_550 uk.sr.uz_433 
  0x27001807, 0x01651807, 0x0d2e0ea7, 0x55000408,   // ga.gd.un_420 ga.gv.en_432  is.fo.cs_532 fi.rw.un_430 
  // [0790]
  0x00001b06, 0x46001a05, 0x461c1b02, 0x0000600f,   // tr.un.un_400 tl.qu.un_330  tr.id.qu_222 vo.un.un_600 
  0x53264f0c, 0x5800640e, 0x0000550f, 0x47fc65a0,   // bi.ia.ht_543 lg.om.un_550  rw.un.un_600 gv.zzp.sn_322 
  0x00000a03, 0x34213d0c, 0x042d480e, 0x00001a06,   // pt.un.un_300 ku.fa.ps_543  tt.sk.fi_555 tl.un.un_400 
  0x48006017, 0x00001b24, 0x1d1f1007, 0x353008a7,   // vo.tt.un_730 tr.un.un_900  lt.cy.la_432 uk.uz.tg_532 
  // [07a0]
  0x1b2f2007, 0x301b1ea0, 0x101504a9, 0x38000402,   // sq.su.tr_432 ms.tr.uz_322  ru.be.un_540 fi.tk.un_220 
  0x5e00380c, 0x35003004, 0x304d5855, 0x443c23af,   // tk.ts.un_530 uz.tg.un_320  om.aa.uz_442 ky.ug.kk_655 
  0x0000590a, 0x00005e15, 0x5300211a, 0x0000690f,   // rn.un.un_500 ts.un.un_700  jw.ht.un_760 mfe.un.un_600 
  0x64002004, 0x00000224, 0x00002b1c, 0x1c0d0905,   // sq.lg.un_320 da.un.un_900  vi.un.un_800 hi.ne.mr_333 
  // [07b0]
  0x53002107, 0x55001509, 0x1f430107, 0x1b003119,   // jw.ht.un_420 un.rw.un_440  en.ie.cy_432 az.tr.un_750 
  0x35004a04, 0x17000a0e, 0x1c005c09, 0x1c005c08,   // yo.zu.un_320 mk.sr.un_550  sa.mr.un_440 sa.mr.un_430 
  0x28342307, 0x33000c09, 0x09005c22, 0x1c46210d,   // ky.ps.sd_432 sv.nn.un_440  sa.pl.un_870 jw.qu.id_554 
  0x401f0908, 0x1c095c60, 0x3142220c, 0x65632a08,   // pl.cy.lb_443 sa.hi.mr_664  oc.co.az_543 mt.sco.gv_443 
  // [07c0]
  0x183428a0, 0x130d090c, 0x53002109, 0x0a041712,   // sd.ps.ar_322 hi.ne.bh_543  jw.ht.un_440 sr.ru.mk_654 
  0x31001b1a, 0x00003e06, 0x040a0704, 0x04110aa4,   // tr.az.un_760 rm.un.un_400  bg.mk.ru_332 mk.ro.ru_433 
  0x21002707, 0x20005304, 0x36000a07, 0x283d3455,   // gd.jw.un_420 ht.sq.un_320  pt.gn.un_420 ps.ku.sd_442 
  0x1f4c2aa7, 0x283d3b55, 0x3c152505, 0x25003512,   // mt.wo.cy_532 ks.ku.sd_442  mn.ug.un_330 tg.mn.un_640 
  // [07d0]
  0x09005c04, 0x2100530d, 0x3c004404, 0x2100531a,   // sa.hi.un_320 ht.jw.un_540  kk.ug.un_320 ht.jw.un_760 
  0x2a465b12, 0x00001524, 0x00003015, 0x0f005c04,   // sg.qu.mt_654 un.un.un_900  uz.un.un_700 sa.lv.un_320 
  0x04001509, 0x48000405, 0x0d4c640b, 0x0000202d,   // un.ru.un_440 fi.tt.un_330  lg.wo.cs_542 sq.un.un_A00 
  0x6700520c, 0x00003624, 0x00003e0a, 0x64004908,   // ha.ak.un_530 gn.un.un_900  rm.un.un_500 to.lg.un_430 
  // [07e0]
  0x1f000204, 0x211e1c05, 0x1e1c21a4, 0x28211255,   // da.cy.un_320 id.ms.jw_333  jw.id.ms_433 ur.fa.sd_442 
  0x00003924, 0x390969ee, 0x10000407, 0x1e1c2aa9,   // dz.un.un_900 mfe.pl.br_422  ru.be.un_420 mt.id.ms_544 
  0x360501a0, 0x05001905, 0x0000050a, 0x051102a0,   // en.fr.gn_322 gl.fr.un_330  fr.un.un_500 da.ro.fr_322 
  0x39002c0d, 0x02007904, 0x48002308, 0x426764a4,   // fy.br.un_540 war.da.un_320  ky.tt.un_430 lg.ak.co_433 
  // [07f0]
  0x27001812, 0x254b04ad, 0x1828340b, 0x21003102,   // ga.gd.un_640 fi.mi.eu_643  ps.sd.ar_542 az.jw.un_220 
  0x4e001809, 0x32171605, 0x22001919, 0x0d000902,   // ga.ay.un_440 hr.sr.bs_333  gl.oc.un_750 hi.ne.un_220 
  0x0d1c5c08, 0x55256502, 0x17000a1a, 0x15001114,   // sa.mr.ne_443 gv.eu.rw_222  mk.sr.un_760 ro.un.un_660 
  0x34001807, 0x09101fad, 0x27051902, 0x08006005,   // ar.ps.un_420 cy.lt.pl_643  gl.fr.gd_222 vo.no.un_330 
  
  // [0800]
  0x0200270d, 0x0000070f, 0x30002d04, 0x2a006712,   // gd.da.un_540 bg.un.un_600  sk.uz.un_320 ak.mt.un_640 
  0x24003904, 0x211e1ca4, 0x190a39a0, 0x0d1c0908,   // br.eo.un_320 id.ms.jw_433  br.pt.gl_322 hi.mr.ne_443 
  0x17150aa4, 0x02190b55, 0x3000250b, 0x1e1c21a9,   // mk.sr.un_430 es.gl.da_442  eu.uz.un_520 jw.id.ms_544 
  0x13181ba0, 0x65002402, 0x3c3038ec, 0x426505ac,   // tr.ga.et_322 eo.gv.un_220  tk.uz.ug_644 fr.gv.co_632 
  // [0810]
  0x00004701, 0x3400210d, 0x451d050c, 0x153c250c,   // sn.un.un_200 fa.ps.un_540  fr.la.ln_543 mn.ug.un_543 
  0x123428a0, 0x04000807, 0x08001004, 0x18054b07,   // sd.ps.ur_322 uk.ru.un_420  be.uk.un_320 mi.fr.ga_432 
  0x30003507, 0x5d5c46ee, 0x190405a0, 0x23000402,   // tg.uz.un_420 qu.sa.ss_422  fr.fi.gl_322 ru.ky.un_220 
  0x053656a9, 0x04004808, 0x0d1c5c55, 0x39002a19,   // mg.gn.fr_544 tt.fi.un_430  sa.mr.ne_442 bo.dz.un_750 
  // [0820]
  0x0c002904, 0x13000404, 0x4800040e, 0x46004e09,   // sl.sv.un_320 fi.et.un_320  fi.tt.un_550 ay.qu.un_440 
  0x253536a0, 0x1c005c05, 0x10000814, 0x09001208,   // ab.tg.mn_322 sa.mr.un_330  uk.be.un_660 hu.pl.un_430 
  0x040708a0, 0x0d001c0b, 0x21343d07, 0x1d000d02,   // uk.bg.ru_322 mr.ne.un_520  ku.ps.fa_432 cs.la.un_220 
  0x2e004508, 0x0400070d, 0x3418280c, 0x232548a9,   // ln.fo.un_430 bg.ru.un_540  sd.ar.ps_543 tt.mn.ky_544 
  // [0830]
  0x48002305, 0x00003724, 0x21002808, 0x5c091cad,   // ky.tt.un_330 ba.un.un_900  sd.fa.un_430 mr.hi.sa_643 
  0x135c0da0, 0x0a000702, 0x12341855, 0x07171104,   // ne.sa.bh_322 bg.mk.un_220  ar.ps.ur_442 ro.sr.bg_332 
  0x443538a4, 0x10000104, 0x0000760a, 0x343d21a9,   // tk.tg.kk_433 en.lt.un_320  crs.un.un_500 fa.ku.ps_544 
  0x31001b0c, 0x38233012, 0x2d000404, 0x10151107,   // tr.az.un_530 uz.ky.tk_654  fi.sk.un_320 ro.be.un_420 
  // [0840]
  0x0400600c, 0x32001602, 0x0000fe24, 0x1100070e,   // vo.fi.un_530 hr.bs.un_220  tlh.un.un_900 bg.ro.un_550 
  0x04006012, 0x10000813, 0x0d5c1c0c, 0x0c000402,   // vo.fi.un_640 uk.be.un_650  mr.sa.ne_543 fi.sv.un_220 
  0x4c3657ad, 0x3400280e, 0x13090daf, 0x090d560c,   // na.gn.wo_643 sd.ps.un_550  ne.hi.bh_655 mg.cs.pl_543 
  0x0000110f, 0x1c005c0b, 0x28001811, 0x162d29a4,   // ro.un.un_600 sa.mr.un_520  ar.sd.un_630 sl.sk.hr_433 
  // [0850]
  0x350830a4, 0x00005615, 0x0460060d, 0x30003c08,   // uz.uk.tg_433 mg.un.un_700  de.vo.fi_554 ug.uz.un_430 
  0x061360ee, 0x17043855, 0x60002d0d, 0x0000fc0a,   // vo.et.de_422 tk.ru.sr_442  sk.vo.un_540 zzp.un.un_500 
  0x1523480d, 0x1300040b, 0x30003522, 0x3d002104,   // tt.ky.un_554 fi.et.un_520  tg.uz.un_870 fa.ku.un_320 
  0x0d1c5c0c, 0x12283409, 0x07153007, 0x0a003c07,   // sa.mr.ne_543 ps.sd.ur_444  uz.bg.un_420 ug.mk.un_420 
  // [0860]
  0x1d002505, 0x170a07af, 0x1d001302, 0x3600460c,   // eu.la.un_330 bg.mk.sr_655  et.la.un_220 qu.gn.un_530 
  0x5c000d12, 0x562d0d08, 0x092d0d02, 0x39002a1a,   // ne.sa.un_640 cs.sk.mg_443  cs.sk.pl_222 bo.dz.un_760 
  0x04003507, 0x0000510a, 0x15004812, 0x0d5c1cee,   // tg.ru.un_420 kl.un.un_500  tt.un.un_640 mr.sa.ne_422 
  0x38003c1a, 0x2c133e0c, 0x213428ee, 0x3000380d,   // ug.tk.un_760 rm.et.fy_543  sd.ps.fa_422 tk.uz.un_540 
  // [0870]
  0x0d5c0902, 0x20033fa0, 0x123f3baf, 0x44003c14,   // hi.sa.ne_222 af.nl.sq_322  so.af.hu_655 ug.kk.un_660 
  0x38233013, 0x0000562d, 0x00002724, 0x4800041a,   // uz.ky.tk_665 mg.un.un_A00  gd.un.un_900 fi.tt.un_760 
  0x480604ad, 0x1800440b, 0x0b1c24a6, 0xfc4003ee,   // fi.de.tt_643 kk.ar.un_520  eo.id.es_521 nl.lb.zzp_422 
  0x27002107, 0x250a17a7, 0x211830a4, 0x067939ee,   // jw.gd.un_420 sr.mk.mn_532  uz.ar.fa_433 br.war.de_422 
  // [0880]
  0x27200ca0, 0x480c0407, 0x00005c15, 0x13090d11,   // sv.sq.gd_322 fi.sv.tt_432  sa.un.un_700 ne.hi.bh_653 
  0x3500150c, 0x7845060c, 0x061f6504, 0x6b681da0,   // un.tg.un_530 de.ln.ve_543  gv.cy.de_332 la.ig.ceb_322 
  0x48040c0d, 0x58061dad, 0x65131d07, 0x0400480d,   // sv.fi.tt_554 la.de.om_643  la.et.gv_432 tt.fi.un_540 
  0x1800340c, 0x3f033ba4, 0x34301211, 0x0c000409,   // ps.ar.un_530 so.nl.af_433  ur.uz.ps_653 fi.sv.un_440 
  // [0890]
  0x08000a0c, 0x04004819, 0x1c000d0c, 0x76fa18a4,   // mk.uk.un_530 tt.fi.un_750  ne.mr.un_530 ga.nr.crs_433 
  0x27583b04, 0x19000b1a, 0x2c3f0305, 0x39005604,   // so.om.gd_332 es.gl.un_760  nl.af.fy_333 mg.br.un_320 
  0x381b48a0, 0x2c0306a4, 0x09000d14, 0x51001508,   // tt.tr.tk_322 de.nl.fy_433  ne.hi.un_660 un.kl.un_430 
  0x00006b06, 0x04004818, 0x16001208, 0x12002e04,   // ceb.un.un_400 tt.fi.un_740  hu.hr.un_430 fo.hu.un_320 
  // [08a0]
  0x080a0708, 0x04000604, 0x2300301a, 0x5c001c08,   // bg.mk.uk_443 de.fi.un_320  uz.ky.un_760 mr.sa.un_430 
  0x32161705, 0x00000e06, 0x20003b05, 0x0e002e13,   // sr.hr.bs_333 is.un.un_400  so.sq.un_330 fo.is.un_650 
  0x01002408, 0x48001b02, 0x3b000302, 0x48004e0d,   // yi.iw.un_430 tr.tt.un_220  nl.so.un_220 ay.tt.un_540 
  0x18203b08, 0x17163209, 0x0c00040d, 0x4804060b,   // so.sq.ga_443 bs.hr.sr_444  fi.sv.un_540 de.fi.tt_542 
  // [08b0]
  0x3c00440d, 0x47004014, 0x1e1c08a0, 0x04000c21,   // kk.ug.un_540 lb.sn.un_660  no.id.ms_322 sv.fi.un_860 
  0x182b1d08, 0x48040cad, 0x4c00060d, 0x04070a02,   // la.vi.ga_443 sv.fi.tt_643  de.wo.un_540 mk.bg.ru_222 
  0x06390e07, 0x4800040b, 0x3e0647ad, 0x35001c04,   // is.br.de_432 ru.tt.un_520  sn.de.rm_643 id.zu.un_320 
  0x53004a08, 0x04056507, 0x790a3e0c, 0x0a0711ee,   // yo.ht.un_430 gv.fr.fi_432  rm.pt.war_543 ro.bg.mk_422 
  // [08c0]
  0x2e00270c, 0x0a151107, 0x0000270a, 0x2400010b,   // gd.fo.un_530 ro.mk.un_420  gd.un.un_500 iw.yi.un_520 
  0x02065707, 0x04000c08, 0x48000604, 0x03000402,   // na.de.da_432 sv.fi.un_430  de.tt.un_320 fi.nl.un_220 
  0x3f002c02, 0x44233c13, 0x30003508, 0x33080204,   // fy.af.un_220 ug.ky.kk_665  tg.uz.un_430 da.no.nn_332 
  0x1d043ea0, 0x00004f06, 0x2e000e04, 0x12002111,   // rm.fi.la_322 bi.un.un_400  is.fo.un_320 fa.ur.un_630 
  // [08d0]
  0x30153707, 0x130d5ca9, 0x2e000e2c, 0x13090d13,   // ba.uz.un_420 sa.ne.bh_544  is.fo.un_990 ne.hi.bh_665 
  0x332e3ea0, 0x3e000608, 0x630613ec, 0x330208a9,   // rm.fo.nn_322 de.rm.un_430  et.de.sco_644 no.da.nn_544 
  0x0100240b, 0x33600e05, 0x08000704, 0x08070407,   // yi.iw.un_520 is.vo.nn_333  bg.uk.un_320 ru.bg.uk_432 
  0x3d003008, 0x0d005c09, 0x1200180c, 0x0d005c0d,   // uz.ku.un_430 sa.ne.un_440  ar.ur.un_530 sa.ne.un_540 
  // [08e0]
  0x040a1504, 0x080417ee, 0x04004807, 0x13002f05,   // un.mk.ru_332 sr.ru.uk_422  tt.ru.un_420 su.et.un_330 
  0x4400170d, 0x0000420f, 0x5c001c13, 0x0000571c,   // sr.kk.un_540 co.un.un_600  mr.sa.un_650 na.un.un_800 
  0x342118ad, 0x1c130955, 0x39002a22, 0x35304407,   // ar.fa.ps_643 hi.bh.mr_442  bo.dz.un_870 kk.uz.tg_432 
  0x09005c08, 0x174630a6, 0x2d123607, 0x45600355,   // sa.hi.un_430 uz.qu.sr_521  gn.hu.sk_432 nl.vo.ln_442 
  // [08f0]
  0x21002802, 0x3b110302, 0x0d091ca0, 0x3600451a,   // sd.fa.un_220 nl.ro.so_222  mr.hi.ne_322 ln.gn.un_760 
  0x2128180c, 0x0000491c, 0x4c033fa0, 0x3f000314,   // ar.sd.fa_543 to.un.un_800  af.nl.wo_322 nl.af.un_660 
  0x1c005c18, 0x1300360c, 0x13004d14, 0x33000809,   // sa.mr.un_740 gn.et.un_530  aa.et.un_660 no.nn.un_440 
  0x0400070b, 0x5e134d55, 0x37684b0d, 0x032b1f02,   // bg.ru.un_520 aa.et.ts_442  mi.ig.st_554 cy.vi.nl_222 
  // [0900]
  0x04224fa6, 0x3b656e0c, 0x0a000704, 0x33086905,   // bi.oc.fi_521 hmn.gv.so_543  bg.mk.un_320 mfe.no.nn_333 
  0x3f654060, 0x2c372507, 0x30462805, 0x696039a4,   // lb.gv.af_664 eu.st.fy_432  sw.qu.uz_333 br.vo.mfe_433 
  0x0c001804, 0x51395ca7, 0x0d1c5ca7, 0x00000824,   // ga.sv.un_320 sa.br.kl_532  sa.mr.ne_532 no.un.un_900 
  0x00007303, 0x1500fe05, 0x3b006504, 0x2800211a,   // ny.un.un_300 tlh.un.un_330  gv.so.un_320 jw.sw.un_760 
  // [0910]
  0x18330804, 0x5c000618, 0x35003414, 0x351f7304,   // no.nn.ga_332 de.sa.un_740  xh.zu.un_660 ny.cy.zu_332 
  0x4a001812, 0x3f0302ee, 0x09005504, 0x03003f2b,   // ga.yo.un_640 da.nl.af_422  rw.pl.un_320 af.nl.un_980 
  0x09000d1a, 0xfe5e2fad, 0x1c1f2fee, 0x34001912,   // ne.hi.un_760 su.ts.tlh_643  su.cy.id_422 gl.xh.un_640 
  0xfe2f21ee, 0x13004d0c, 0x03005713, 0x03002f08,   // jw.su.tlh_422 aa.et.un_530  na.nl.un_650 su.nl.un_430 
  // [0920]
  0x3f6b4cee, 0x35003405, 0x4d000614, 0x2f391fa0,   // wo.ceb.af_422 xh.zu.un_330  de.aa.un_660 cy.br.su_322 
  0x00004924, 0x0000731c, 0x03003f0c, 0x09001311,   // to.un.un_900 ny.un.un_800  af.nl.un_530 bh.hi.un_630 
  0x3500341b, 0x6e003b0d, 0x4c00fe12, 0x4b006a1b,   // xh.zu.un_770 so.hmn.un_540  tlh.wo.un_640 haw.mi.un_770 
  0x39006119, 0x4b284dee, 0x0000401c, 0x18002813,   // za.br.un_750 aa.sw.mi_422  lb.un.un_800 sd.ar.un_650 
  // [0930]
  0x343d1208, 0x1d171fee, 0x561e29ee, 0x1828125a,   // ur.ku.ps_443 cy.sr.la_422  sl.ms.mg_422 ur.sd.ar_553 
  0x2f004604, 0x384c46ad, 0x00000315, 0x46000904,   // qu.su.un_320 qu.wo.tk_643  nl.un.un_700 pl.qu.un_320 
  0x185f13a4, 0x2800fe13, 0x2f002121, 0x181e1c09,   // et.tn.ga_433 tlh.sw.un_650  jw.su.un_860 id.ms.ga_444 
  0x09003b19, 0x10153504, 0x5e00fe02, 0x15001307,   // ks.hi.un_750 tg.be.un_320  tlh.ts.un_220 et.un.un_420 
  // [0940]
  0x21581e07, 0x2a004d0c, 0x03003f07, 0x0000780a,   // ms.om.jw_432 aa.mt.un_530  af.nl.un_420 ve.un.un_500 
  0x35003409, 0x0704150c, 0x48003002, 0x04006a1b,   // xh.zu.un_440 un.ru.bg_543  uz.tt.un_220 haw.fi.un_770 
  0x101504af, 0x58002702, 0x00004e1c, 0x33461307,   // ru.be.un_650 gd.om.un_220  ay.un.un_800 et.qu.nn_432 
  0x0a0717af, 0x15070405, 0x04002302, 0x30002308,   // sr.bg.mk_655 ru.bg.un_333  ky.ru.un_220 ky.uz.un_430 
  // [0950]
  0x5c000907, 0x4b005102, 0x3c00440e, 0x0000101c,   // hi.sa.un_420 kl.mi.un_220  kk.ug.un_550 be.un.un_800 
  0x091c0d55, 0x21001d04, 0x28001202, 0x0800171a,   // ne.mr.hi_442 la.jw.un_320  ur.sd.un_220 sr.uk.un_760 
  0x48000404, 0x1c130d04, 0x3e00520c, 0x36004608,   // ru.tt.un_320 ne.bh.mr_332  ha.rm.un_530 qu.gn.un_430 
  0x18001502, 0x07002e08, 0x3418300d, 0x5c000d0c,   // un.ga.un_220 fo.it.un_430  uz.ar.ps_554 ne.sa.un_530 
  // [0960]
  0x321617a0, 0x44003705, 0x0400100d, 0x21303413,   // sr.hr.bs_322 ba.kk.un_330  be.ru.un_540 ps.uz.fa_665 
  0x4d006e13, 0x170a36a0, 0x1234180c, 0x44003612,   // hmn.aa.un_650 ab.mk.sr_322  ar.ps.ur_543 ab.kk.un_640 
  0x33084605, 0x0817045a, 0x5a002705, 0x00005a1c,   // qu.no.nn_333 ru.sr.uk_553  gd.sm.un_330 sm.un.un_800 
  0x1bfe2aa9, 0x30213d0c, 0x79601d11, 0x30352511,   // mt.tlh.tr_544 ku.fa.uz_543  la.vo.war_653 mn.tg.uz_653 
  // [0970]
  0x68426a13, 0x311bfe0c, 0x28495a0c, 0x070a370e,   // haw.co.ig_665 tlh.tr.az_543  sm.to.sw_543 ba.mk.bg_555 
  0x4a2504a4, 0x213428ac, 0x3534fead, 0x0e2a0d07,   // fi.eu.yo_433 sd.ps.fa_632  tlh.xh.zu_643 cs.mt.is_432 
  0x0000fe1c, 0x34182808, 0x190b36a4, 0x213d34ee,   // tlh.un.un_800 sd.ar.ps_443  gn.es.gl_433 ps.ku.fa_422 
  0x13224c0c, 0x40000613, 0x1b0e1f07, 0x13162904,   // wo.oc.et_543 de.lb.un_650  cy.is.tr_432 sl.hr.et_332 
  // [0980]
  0x5c18540c, 0x0e544c08, 0x3800300e, 0x2e005412,   // ik.ga.sa_543 wo.ik.is_443  uz.tk.un_550 ik.fo.un_640 
  0x103823ad, 0x585a5109, 0x00004615, 0x114cfe5a,   // ky.tk.be_643 kl.sm.om_444  qu.un.un_700 tlh.wo.ro_553 
  0x462e0e0d, 0x3216170e, 0x13000902, 0x13001c09,   // is.fo.qu_554 sr.hr.bs_555  hi.bh.un_220 mr.bh.un_440 
  0x36001108, 0x3217160e, 0x58001d04, 0x2a006e07,   // ro.ab.un_430 hr.sr.bs_555  la.om.un_320 hmn.mt.un_420 
  // [0990]
  0x23153555, 0x4837440e, 0x04002509, 0x4837440c,   // tg.ky.un_420 kk.ba.tt_555  mn.ru.un_440 kk.ba.tt_543 
  0x321b3155, 0x6400581a, 0x09fe0d07, 0x31004c14,   // az.tr.bs_442 om.lg.un_760  cs.tlh.pl_432 wo.az.un_660 
  0x00004306, 0x0d001104, 0x3711300c, 0x4cfe2a14,   // ie.un.un_400 ro.cs.un_320  uz.ro.ba_543 mt.tlh.wo_666 
  0x6a425aa4, 0x21511e0c, 0x08043ca6, 0x34182813,   // sm.co.haw_433 ms.kl.jw_543  ug.ru.uk_521 sd.ar.ps_665 
  // [09a0]
  0x25002305, 0x2a43fea9, 0x461b4eec, 0x3154fead,   // ky.mn.un_330 tlh.ie.mt_544  ay.tr.qu_644 tlh.ik.az_643 
  0x4000061a, 0x0000381c, 0x28183402, 0x3154240c,   // de.lb.un_760 tk.un.un_800  ps.ar.sd_222 eo.ik.az_543 
  0x0000290a, 0x190b2302, 0x0e001102, 0x09000d07,   // sl.un.un_500 ca.es.gl_222  ro.is.un_220 ne.hi.un_420 
  0x07001508, 0x13001d04, 0x095c1307, 0x300715ee,   // un.bg.un_430 la.et.un_320  bh.sa.hi_432 un.bg.uz_422 
  // [09b0]
  0x170a3555, 0x11000a02, 0x1c0d0902, 0x3c00232a,   // tg.mk.sr_442 pt.ro.un_220  hi.ne.mr_222 ky.ug.un_970 
  0x09005c12, 0x111d5707, 0x2c000307, 0x08373807,   // sa.hi.un_640 na.la.ro_432  nl.fy.un_420 tk.ba.uk_432 
  0x12182ea0, 0x0d005304, 0x79586ba9, 0x1300090c,   // fo.ga.hu_322 ht.cs.un_320  ceb.om.war_544 hi.bh.un_530 
  0x3b4d650c, 0x33000b19, 0x285613a4, 0x3b796baf,   // gv.aa.so_543 bn.as.un_750  et.mg.sw_433 ceb.war.so_655 
  // [09c0]
  0x6a25130c, 0x0a383c07, 0x19000b05, 0x1117080c,   // et.eu.haw_543 ug.tk.mk_432  es.gl.un_330 uk.sr.ro_543 
  0x6a373308, 0x13653b07, 0x516b6408, 0x6a1e49a4,   // nn.st.haw_443 so.gv.et_432  lg.ceb.kl_443 to.ms.haw_433 
  0x3f4d3ba4, 0x37443004, 0x3f03080c, 0x20003614,   // so.aa.af_433 uz.kk.ba_332  no.nl.af_543 gn.sq.un_660 
  0x0e002e1a, 0x645539ad, 0x64005a08, 0x5d00080d,   // fo.is.un_760 br.rw.lg_643  sm.lg.un_430 no.ss.un_540 
  // [09d0]
  0x51583ba4, 0x0e030604, 0x0e532e04, 0x11001d07,   // so.om.kl_433 de.nl.is_332  fo.ht.is_332 la.ro.un_420 
  0x3f5706a4, 0x5800040b, 0x37006114, 0x19000b07,   // de.na.af_433 fi.om.un_520  za.st.un_660 es.gl.un_420 
  0x2d000308, 0x1300091b, 0x033f25a4, 0x034006ee,   // nl.sk.un_430 hi.bh.un_770  eu.af.nl_433 de.lb.nl_422 
  0x033f06ee, 0x023f080c, 0x301708ad, 0x64000308,   // de.af.nl_422 no.af.da_543  uk.sr.uz_643 nl.lg.un_430 
  // [09e0]
  0x0e00120e, 0x3b586409, 0x2d000502, 0x283b37a0,   // hu.is.un_550 lg.om.so_444  fr.sk.un_220 st.so.sw_322 
  0x03286404, 0x3b64510d, 0x1d001208, 0x216a4bad,   // lg.sw.nl_332 kl.lg.so_554  hu.la.un_430 mi.haw.jw_643 
  0x2e000e07, 0x021d06a7, 0x65645107, 0x304873ee,   // is.fo.un_420 de.la.da_532  kl.lg.gv_432 ny.tt.uz_422 
  0x4800fc08, 0x040a0708, 0x135a6b07, 0x284b01a4,   // zzp.tt.un_430 bg.mk.ru_443  ceb.sm.et_432 en.mi.sw_433 
  // [09f0]
  0x0000061c, 0x3b00510c, 0x3f060304, 0x2e000e13,   // de.un.un_800 kl.so.un_530  nl.de.af_332 is.fo.un_650 
  0x480804ad, 0x0d066107, 0x5f00372a, 0x08001714,   // ru.uk.tt_643 za.de.cs_432  st.tn.un_970 sr.uk.un_660 
  0x3c382308, 0x06033fa4, 0x0d1c5ca0, 0x073530ec,   // ky.tk.ug_443 af.nl.de_433  sa.mr.ne_322 uz.tg.bg_644 
  0x48234407, 0x1300091a, 0x0400151b, 0x19000b0e,   // kk.ky.tt_432 hi.bh.un_760  un.ru.un_770 es.gl.un_550 
  // [0a00]
  0x30353408, 0x21382807, 0x490f4ba0, 0x64595513,   // xh.zu.uz_443 sw.tk.jw_432  mi.lv.to_322 rw.rn.lg_665 
  0x32641b05, 0x39001d02, 0x06000207, 0x35345d05,   // tr.lg.bs_333 la.br.un_220  da.de.un_420 ss.xh.zu_333 
  0x38001208, 0x323b2d07, 0x341821a7, 0x6902760c,   // hu.tk.un_430 sk.so.bs_432  fa.ar.ps_532 crs.da.mfe_543 
  0x02346eee, 0x100a7605, 0x0a000707, 0x6bfc1ba0,   // hmn.xh.da_422 crs.pt.lt_333  bg.mk.un_420 tr.zzp.ceb_322 
  // [0a10]
  0x69595514, 0x18003c04, 0x182134ee, 0x07080a12,   // rw.rn.mfe_666 ug.ar.un_320  ps.fa.ar_422 mk.uk.bg_654 
  0x11003202, 0x07040aa0, 0x00000a24, 0x13090dee,   // bs.ro.un_220 mk.ru.bg_322  pt.un.un_900 ne.hi.bh_422 
  0x482001a0, 0x3502690d, 0x55007612, 0x765969af,   // en.sq.tt_322 mfe.da.zu_554  crs.rw.un_640 mfe.rn.crs_655 
  0x13091c60, 0x55006404, 0x0100240c, 0x647669af,   // mr.hi.bh_664 lg.rw.un_320  yi.iw.un_530 mfe.crs.lg_655 
  // [0a20]
  0x59695e05, 0x04442302, 0x03290909, 0x0d00690e,   // ts.mfe.rn_333 ky.kk.ru_222  pl.sl.nl_444 mfe.cs.un_550 
  0x55766907, 0x39670f04, 0x5c004b02, 0x25001112,   // mfe.crs.rw_432 lv.ak.br_332  mi.sa.un_220 ro.mn.un_640 
  0x00005c1c, 0x353428ee, 0x3800360d, 0x0f005c1a,   // sa.un.un_800 sw.xh.zu_422  gn.tk.un_540 sa.lv.un_760 
  0x18002304, 0x2a1b380c, 0x1e001c02, 0x5c000f08,   // ky.ar.un_320 tk.tr.mt_543  id.ms.un_220 lv.sa.un_430 
  // [0a30]
  0x0f005c0e, 0x17070a07, 0x2e0e33af, 0x49002d13,   // sa.lv.un_550 mk.bg.sr_432  nn.is.fo_655 sk.to.un_650 
  0x0d005033, 0x04001f12, 0x07360a07, 0x330e2e0c,   // fj.cs.un_A70 cy.fi.un_640  mk.ab.bg_432 fo.is.nn_543 
  0x762d0da9, 0x1d002708, 0x22003904, 0x230a1507,   // cs.sk.crs_544 gd.la.un_430  br.oc.un_320 un.mk.ky_432 
  0x650661a4, 0x3f020daf, 0x062e60a4, 0x6a000d22,   // za.de.gv_433 cs.da.af_655  vo.fo.de_433 cs.haw.un_870 
  // [0a40]
  0x0000400f, 0x02532d11, 0x08003504, 0x48003804,   // lb.un.un_600 sk.ht.da_653  tg.uk.un_320 tk.tt.un_320 
  0x03500d0c, 0x4a3b58a4, 0x1f3e1804, 0x033f22ee,   // cs.fj.nl_543 om.so.yo_433  ga.rm.cy_332 oc.af.nl_422 
  0x0c004809, 0x0000640f, 0x1000080c, 0x33062e08,   // tt.sv.un_440 lg.un.un_600  uk.be.un_530 fo.de.nn_443 
  0x39190a08, 0x00005824, 0x40003b04, 0x3e000408,   // pt.gl.br_443 om.un.un_900  so.lb.un_320 fi.rm.un_430 
  // [0a50]
  0x2723610c, 0x644e13af, 0x44002322, 0x190a2d14,   // za.ca.gd_543 et.ay.lg_655  ky.kk.un_870 sk.pt.gl_666 
  0x0f005c19, 0x00005815, 0x3b64580c, 0x3b4d64a4,   // sa.lv.un_750 om.un.un_700  om.lg.so_543 lg.aa.so_433 
  0x403b64a7, 0x5c001c0c, 0x0d095cee, 0x17000a02,   // lg.so.lb_532 mr.sa.un_530  sa.hi.ne_422 mk.sr.un_220 
  0x0000022d, 0x0600610b, 0x4c000221, 0x3b644c04,   // da.un.un_A00 za.de.un_520  da.wo.un_860 wo.lg.so_332 
  // [0a60]
  0x221504a0, 0x4619570c, 0x19000a14, 0x3b005804,   // fi.oc.un_320 na.gl.qu_543  pt.gl.un_660 om.so.un_320 
  0x02330808, 0x5a0d2d0c, 0x4c53400e, 0x1f006a0d,   // no.nn.da_443 sk.cs.sm_543  lb.ht.wo_555 haw.cy.un_540 
  0x5d00470d, 0x504b5a13, 0x0e2e06a4, 0x4b00020b,   // sn.ss.un_540 sm.mi.fj_665  de.fo.is_433 da.mi.un_520 
  0x0e2e330c, 0x5a4967a6, 0x194002a9, 0x683b11ee,   // nn.fo.is_543 ak.to.sm_521  da.lb.gl_544 ro.so.ig_422 
  // [0a70]
  0x04070a08, 0x03330805, 0x49000d0d, 0x00005001,   // mk.bg.ru_443 no.nn.nl_333  cs.to.un_540 fj.un.un_200 
  0x47004904, 0x130464ad, 0x073035a4, 0x3b211813,   // to.sn.un_320 lg.fi.et_643  tg.uz.bg_433 ar.fa.ks_665 
  0x5c1c0d5a, 0x4c004002, 0x3b584007, 0x122128ee,   // ne.mr.sa_553 lb.wo.un_220  lb.om.so_432 sd.fa.ur_422 
  0x01002407, 0x060c600b, 0x0e005a07, 0x33020c02,   // yi.iw.un_420 vo.sv.de_542  sm.is.un_420 sv.da.nn_222 
  // [0a80]
  0x18004320, 0x00003b1c, 0x13046413, 0x0a000714,   // ie.ga.un_850 so.un.un_800  lg.fi.et_665 bg.mk.un_660 
  0x48003b08, 0x00002c0f, 0x2e0e1da9, 0x2e000e02,   // so.tt.un_430 fy.un.un_600  la.is.fo_544 is.fo.un_220 
  0x5c000f04, 0x04001004, 0x09001c07, 0x49005a05,   // lv.sa.un_320 be.ru.un_320  mr.hi.un_420 sm.to.un_330 
  0x13001b08, 0x10000708, 0x1800210d, 0x15000412,   // tr.et.un_430 bg.be.un_430  fa.ar.un_540 ru.un.un_640 
  // [0a90]
  0x0a190b04, 0x3c303d07, 0x361015ad, 0x04003504,   // es.gl.pt_332 ku.uz.ug_432  un.be.ab_643 tg.ru.un_320 
  0x1c005c13, 0x2e0e450c, 0x1b3857a9, 0x1c5c0da7,   // sa.mr.un_650 ln.is.fo_543  na.tk.tr_544 ne.sa.mr_532 
  0x34211255, 0x5c0d1cec, 0x5e007821, 0x0d002505,   // ur.fa.ps_442 mr.ne.sa_644  ve.ts.un_860 eu.cs.un_330 
  0x48000602, 0x311b38a4, 0x212818a0, 0x2f3e200c,   // de.tt.un_220 tk.tr.az_433  ar.sd.fa_322 sq.rm.su_543 
  // [0aa0]
  0x18002308, 0x4000240d, 0x0d5c1c08, 0x09001f2a,   // ky.ar.un_430 eo.lb.un_540  mr.sa.ne_443 cy.pl.un_970 
  0x182d0d13, 0x00003524, 0x12002d02, 0x15483712,   // cs.sk.ga_665 tg.un.un_900  sk.hu.un_220 ba.tt.un_654 
  0x0a00070e, 0x08231155, 0x12001812, 0x2e000e09,   // bg.mk.un_550 ro.ky.uk_442  ga.hu.un_640 is.fo.un_440 
  0x3500300c, 0x213d34a9, 0x3c2330af, 0x443c2312,   // uz.tg.un_530 ps.ku.fa_544  uz.ky.ug_655 ky.ug.kk_654 
  // [0ab0]
  0x15006402, 0x21005705, 0x080730a0, 0x2d293ba4,   // lg.un.un_220 na.jw.un_330  uz.bg.uk_322 so.sl.sk_433 
  0x12213da6, 0x31481b08, 0x40652c07, 0x00001b1c,   // ku.fa.ur_521 tr.tt.az_443  fy.gv.lb_432 tr.un.un_800 
  0x18004f04, 0x0e2d0d04, 0x31481b0d, 0x3b00fc05,   // bi.ga.un_320 cs.sk.is_332  tr.tt.az_554 zzp.so.un_330 
  0x311b48af, 0x0d130960, 0x04070a04, 0x08023eee,   // tt.tr.az_655 hi.bh.ne_664  mk.bg.ru_332 rm.da.no_422 
  // [0ac0]
  0x12000d0d, 0x48311b0c, 0x2e2404a4, 0x25003514,   // cs.hu.un_540 tr.az.tt_543  fi.eo.fo_433 tg.mn.un_660 
  0x311b4808, 0x00001e03, 0x0a005c0c, 0x3302080c,   // tt.tr.az_443 ms.un.un_300  sa.pt.un_530 no.da.nn_543 
  0x08023305, 0x2e005d04, 0x25001c04, 0x2100340d,   // nn.da.no_333 ss.fo.un_320  id.eu.un_320 ps.fa.un_540 
  0x51041302, 0x13000d05, 0x080413a9, 0x04151504,   // et.fi.kl_222 ne.bh.un_330  et.fi.no_544 un.ru.un_320 
  // [0ad0]
  0x31006304, 0x3b002904, 0x0e335ca4, 0x0000392d,   // sco.az.un_320 sl.so.un_320  sa.nn.is_433 br.un.un_A00 
  0x54005121, 0x48303855, 0x040837a0, 0x0d095ca9,   // kl.ik.un_860 tk.uz.tt_442  ba.uk.ru_322 sa.hi.ne_544 
  0x0c0e120c, 0x2e000e0e, 0x2800180d, 0x07005104,   // hu.is.sv_543 is.fo.un_550  ar.sd.un_540 kl.it.un_320 
  0x1b314807, 0x1b31480d, 0x40000608, 0x1e000223,   // tt.az.tr_432 tt.az.tr_554  de.lb.un_430 da.ms.un_880 
  // [0ae0]
  0x03603f08, 0x6b3f1dec, 0x304f21a0, 0x3f000313,   // af.vo.nl_443 la.af.ceb_644  jw.bi.uz_322 nl.af.un_650 
  0x113f5604, 0x44003c12, 0x2f006507, 0x162947ac,   // mg.af.ro_332 ug.kk.un_640  gv.su.un_420 sn.sl.hr_632 
  0x5b4c1f0e, 0x305618a0, 0x5c000f0b, 0x44003814,   // cy.wo.sg_555 ga.mg.uz_322  lv.sa.un_520 tk.kk.un_660 
  0x04001013, 0x0f005c13, 0x1e3f6907, 0x190b0a08,   // be.ru.un_650 sa.lv.un_650  mfe.af.ms_432 pt.es.gl_443 
  // [0af0]
  0x193456ee, 0x0f00030d, 0x00005d06, 0x1a004a22,   // mg.xh.gl_422 nl.lv.un_540  ss.un.un_400 yo.tl.un_870 
  0x3f00030d, 0x0000511c, 0x3d003013, 0x65006412,   // nl.af.un_540 kl.un.un_800  uz.ku.un_650 lg.gv.un_640 
  0x0e004707, 0x00003f03, 0x65000104, 0x1b003812,   // sn.is.un_420 af.un.un_300  en.gv.un_320 tk.tr.un_640 
  0x0e006502, 0x341844ad, 0x18002707, 0x095c0d0c,   // gv.is.un_220 kk.ar.ps_643  gd.ga.un_420 ne.sa.hi_543 
  // [0b00]
  0x48001504, 0x35003008, 0x1c005c04, 0x13091c0c,   // un.tt.un_320 uz.tg.un_430  sa.mr.un_320 mr.hi.bh_543 
  0x1a00fc02, 0x430626a4, 0x0600650d, 0x2a0238a9,   // zzp.tl.un_220 ia.de.ie_433  gv.de.un_540 tk.da.mt_544 
  0x08001711, 0x0c4009a4, 0x021106a0, 0x1e211c0c,   // sr.uk.un_630 pl.lb.sv_433  de.ro.da_322 id.jw.ms_543 
  0x0b0a52a4, 0x01652055, 0x01001502, 0x483530ec,   // ha.pt.es_433 sq.gv.en_442  un.en.un_220 uz.tg.tt_644 
  // [0b10]
  0x0f004b08, 0x656b1dad, 0x2800550d, 0x0f005c0d,   // mi.lv.un_430 la.ceb.gv_643  rw.sw.un_540 sa.lv.un_540 
  0x15483708, 0x5a3763a4, 0x17070a09, 0x303d2113,   // ba.tt.un_443 sco.st.sm_433  mk.bg.sr_444 fa.ku.uz_665 
  0xfc1301a0, 0x0b001912, 0x08023302, 0x033f5aa9,   // en.et.zzp_322 gl.es.un_640  nn.da.no_222 sm.af.nl_544 
  0x0a3f0304, 0x01006502, 0x33086502, 0x402765a0,   // nl.af.pt_332 gv.en.un_220  gv.no.nn_222 gv.gd.lb_322 
  // [0b20]
  0x30382308, 0x00002c0a, 0x2e004c04, 0x00005a0a,   // ky.tk.uz_443 fy.un.un_500  wo.fo.un_320 sm.un.un_500 
  0x18003402, 0x3048370e, 0x13000d09, 0x0d1c09a0,   // ps.ar.un_220 ba.tt.uz_555  ne.bh.un_440 hi.mr.ne_322 
  0x21003d0c, 0x1230210c, 0x1b1238a0, 0x070a17ee,   // ku.fa.un_530 fa.uz.ur_543  tk.hu.tr_322 sr.mk.bg_422 
  0x080410a0, 0x370a07a4, 0x0a005a04, 0x18213d0b,   // be.ru.uk_322 bg.mk.ba_433  sm.pt.un_320 ku.fa.ar_542 
  // [0b30]
  0x04001512, 0x033f57af, 0x15000414, 0x0d005c14,   // un.ru.un_640 na.af.nl_655  ru.un.un_660 sa.ne.un_660 
  0x02330855, 0x0a6a4304, 0x34183da7, 0x234425a7,   // no.nn.da_442 ie.haw.pt_332  ku.ar.ps_532 mn.kk.ky_532 
  0x3c002312, 0x12183455, 0x5c004b13, 0x04001702,   // ky.ug.un_640 ps.ar.ur_442  mi.sa.un_650 sr.ru.un_220 
  0x131c5c0c, 0x32002904, 0x0a00170e, 0x2f3f1f07,   // sa.mr.bh_543 sl.bs.un_320  sr.mk.un_550 cy.af.su_432 
  // [0b40]
  0x1c000d12, 0x52003702, 0x385f3f14, 0x21003009,   // ne.mr.un_640 st.ha.un_220  af.tn.tk_666 uz.fa.un_440 
  0x276569a6, 0x0000520a, 0x0a040709, 0x033f2cac,   // mfe.gv.gd_521 ha.un.un_500  bg.ru.mk_444 fy.af.nl_632 
  0x38470911, 0x1ffc39a0, 0x1f1e1c08, 0x00003206,   // pl.sn.tk_653 br.zzp.cy_322  id.ms.cy_443 bs.un.un_400 
  0x1c000d05, 0x1f4038a4, 0x5c0d1ca0, 0x03003f04,   // ne.mr.un_330 tk.lb.cy_433  mr.ne.sa_322 af.nl.un_320 
  // [0b50]
  0x55002c20, 0x303d18ee, 0x2a004205, 0x0a3635ee,   // fy.rw.un_850 ar.ku.uz_422  co.mt.un_330 tg.ab.mk_422 
  0x64004705, 0x0735080b, 0x153830a4, 0x04153804,   // sn.lg.un_330 uk.tg.bg_542  uz.tk.un_433 tk.ru.un_320 
  0x37005f13, 0x041715a0, 0x4c000929, 0x0a1f1955,   // tn.st.un_650 un.sr.ru_322  pl.wo.un_960 gl.cy.pt_442 
  0x0b003808, 0x1e211c07, 0x1000110b, 0x06033f13,   // tk.es.un_430 id.jw.ms_432  ro.be.un_520 af.nl.de_665 
  // [0b60]
  0x19004308, 0x34211807, 0x2a3f3b04, 0x1c033f11,   // ie.gl.un_430 ar.fa.ps_432  so.af.mt_332 af.nl.id_653 
  0x0a0735a9, 0x37004822, 0x441011ad, 0x5c000904,   // tg.bg.mk_544 tt.ba.un_870  ro.be.kk_643 hi.sa.un_320 
  0x091c0dad, 0x630a3e0c, 0x38001f04, 0x34002a04,   // ne.mr.hi_643 rm.pt.sco_543  cy.tk.un_320 mt.xh.un_320 
  0x34002304, 0x5c1c0d04, 0x44234802, 0x35003402,   // ky.ps.un_320 ne.mr.sa_332  tt.ky.kk_222 xh.zu.un_220 
  // [0b70]
  0x3e000604, 0x35203404, 0x090d1ca7, 0x2100180d,   // de.rm.un_320 xh.sq.zu_332  mr.ne.hi_532 ar.fa.un_540 
  0x0a1017a4, 0x35000712, 0x203534a7, 0x4800121b,   // sr.be.mk_433 bg.tg.un_640  xh.zu.sq_532 hu.tt.un_770 
  0x2b001e02, 0x1c291ead, 0x1dfc01a0, 0x08070a04,   // ms.vi.un_220 ms.sl.id_643  en.zzp.la_322 mk.bg.uk_332 
  0x1c005c12, 0x5c130904, 0x04001508, 0x0a001722,   // sa.mr.un_640 hi.bh.sa_332  un.ru.un_430 sr.mk.un_870 
  // [0b80]
  0x071017a4, 0x07002309, 0x1e00200c, 0x4800250d,   // sr.be.bg_433 ky.bg.un_440  ti.am.un_530 mn.tt.un_540 
  0x06000102, 0x12380c18, 0x2700560c, 0x0400150c,   // en.de.un_220 sv.tk.hu_764  mg.gd.un_530 un.ru.un_530 
  0x65001f08, 0x00006e2d, 0x34003013, 0x3e000602,   // cy.gv.un_430 hmn.un.un_A00  uz.ps.un_650 de.rm.un_220 
  0x18003c05, 0x4800371a, 0x343d30a9, 0x1c0d5ca0,   // ug.ar.un_330 ba.tt.un_760  uz.ku.ps_544 sa.ne.mr_322 
  // [0b90]
  0x4800060d, 0x1716320e, 0x035806a0, 0x34580a0c,   // de.tt.un_540 bs.hr.sr_555  de.om.nl_322 pt.om.xh_543 
  0x16003207, 0x04170aee, 0x170a07a9, 0x31001b05,   // bs.hr.un_420 mk.sr.ru_422  bg.mk.sr_544 tr.az.un_330 
  0x5c000d0d, 0x2d0d1305, 0x0d005c05, 0x16000d04,   // ne.sa.un_540 et.cs.sk_333  sa.ne.un_330 cs.hr.un_320 
  0x1c005c19, 0x16000d08, 0x182747ac, 0x2a670f0c,   // sa.mr.un_750 cs.hr.un_430  sn.gd.ga_632 lv.ak.mt_543 
  // [0ba0]
  0x08001513, 0x00002206, 0x580e1f13, 0x00004224,   // un.uk.un_650 oc.un.un_400  cy.is.om_665 co.un.un_900 
  0x391247a6, 0x48311baf, 0x113b42ec, 0x0000580a,   // sn.hu.br_521 tr.az.tt_655  co.so.ro_644 om.un.un_500 
  0x5e3b54a4, 0x58000d04, 0x1b004809, 0x47275ca4,   // ik.so.ts_433 cs.om.un_320  tt.tr.un_440 sa.gd.sn_433 
  0x06004009, 0x234815a0, 0x1c000d08, 0x31001b22,   // lb.de.un_440 un.tt.ky_322  ne.mr.un_430 tr.az.un_870 
  // [0bb0]
  0x483738ad, 0x23001512, 0x0900131a, 0x17000d04,   // tk.ba.tt_643 un.ky.un_640  bh.hi.un_760 cs.sr.un_320 
  0x4d3b1f0c, 0x27475c12, 0x464e470d, 0x48373008,   // cy.so.aa_543 sa.sn.gd_654  sn.ay.qu_554 uz.ba.tt_443 
  0x32161714, 0x48003108, 0x49005a07, 0x130f42a9,   // sr.hr.bs_666 az.tt.un_430  sm.to.un_420 co.lv.et_544 
  0x38001b04, 0x341828af, 0x0a0723a0, 0x18003007,   // tr.tk.un_320 sd.ar.ps_655  ky.bg.mk_322 uz.ar.un_420 
  // [0bc0]
  0x1c0d09a9, 0x58004d0d, 0x7600691a, 0x6328730c,   // hi.ne.mr_544 aa.om.un_540  mfe.crs.un_760 ny.sw.sco_543 
  0x30383507, 0x5c1c09a9, 0x1f5e02a0, 0x31481bad,   // tg.tk.uz_432 hi.mr.sa_544  da.ts.cy_322 tr.tt.az_643 
  0x755f370c, 0x00004e15, 0x1c095c0c, 0x285557a4,   // st.tn.nso_543 ay.un.un_700  sa.hi.mr_543 na.rw.sw_433 
  0x311b4812, 0x0e002e0c, 0x3d00210c, 0x071d510c,   // tt.tr.az_654 fo.is.un_530  fa.ku.un_530 kl.la.it_543 
  // [0bd0]
  0x0a001108, 0x766953af, 0x0a003e05, 0x791a210c,   // ro.mk.un_430 ht.mfe.crs_655  rm.pt.un_330 jw.tl.war_543 
  0x2400011a, 0x73595508, 0x37004809, 0x0000730f,   // iw.yi.un_760 rw.rn.ny_443  tt.ba.un_440 ny.un.un_600 
  0x303538ec, 0x01002412, 0x42000719, 0x79002a12,   // tk.tg.uz_644 yi.iw.un_640  it.co.un_750 mt.war.un_640 
  0x52001f11, 0x55006808, 0x2a5573ad, 0x07004207,   // cy.ha.un_630 ig.rw.un_430  ny.rw.mt_643 co.it.un_420 
  // [0be0]
  0x0a383704, 0x580228a0, 0x18342807, 0x21422fee,   // ba.tk.mk_332 sw.da.om_322  sd.ps.ar_432 su.co.jw_422 
  0x113327ad, 0x08071508, 0x4d006709, 0x5c0d1cad,   // gd.nn.ro_643 un.bg.uk_443  ak.aa.un_440 mr.ne.sa_643 
  0x100835ad, 0x6500680d, 0x1f63610c, 0x1000610c,   // tg.uk.be_643 ig.gv.un_540  za.sco.cy_543 za.lt.un_530 
  0x65182712, 0x00004f1c, 0x4f766904, 0x53007307,   // gd.ga.gv_654 bi.un.un_800  mfe.crs.bi_332 ny.ht.un_420 
  // [0bf0]
  0x01631507, 0x0000461c, 0x25000b04, 0x1300122b,   // un.sco.en_432 qu.un.un_800  es.eu.un_320 hu.et.un_980 
  0x1f006108, 0x2f391f08, 0x34595513, 0x37136155,   // za.cy.un_430 cy.br.su_443  rw.rn.xh_665 za.et.st_442 
  0x131c4faf, 0x3e207908, 0x00004c01, 0x190437ad,   // bi.id.et_655 war.sq.rm_443  wo.un.un_200 st.fi.gl_643 
  0x1b314813, 0x1240390c, 0x4204370d, 0x7928610c,   // tt.az.tr_665 br.lb.hu_543  st.fi.co_554 za.sw.war_543 
  
  // [0c00]
  0x0d1c5cad, 0x1c111dee, 0x311b48ad, 0x023f0e02,   // sa.mr.ne_643 la.ro.id_422  tt.tr.az_643 is.af.da_222 
  0x0000071c, 0x3f004604, 0x47613707, 0x481b3113,   // it.un.un_800 qu.af.un_320  st.za.sn_432 az.tr.tt_665 
  0x47003308, 0x0000520f, 0x4265150c, 0x45595505,   // nn.sn.un_430 ha.un.un_600  un.gv.co_543 rw.rn.ln_333 
  0x373802a9, 0x0257610c, 0x635761af, 0x3000450c,   // da.tk.st_544 za.na.da_543  za.na.sco_655 ln.uz.un_530 
  // [0c10]
  0x34595508, 0x00005e24, 0x330820a4, 0x796b010c,   // rw.rn.xh_443 ts.un.un_900  sq.no.nn_433 en.ceb.war_543 
  0x0700010d, 0x61005f14, 0x7500370c, 0x070a1704,   // en.it.un_540 tn.za.un_660  st.nso.un_530 sr.mk.bg_332 
  0x6300010d, 0x682a3408, 0x1f3940ee, 0x18006505,   // en.sco.un_540 xh.mt.ig_443  lb.br.cy_422 gv.ga.un_330 
  0x1a00611a, 0x5e004507, 0x204079a0, 0x3e001104,   // za.tl.un_760 ln.ts.un_420  war.lb.sq_322 ro.rm.un_320 
  // [0c20]
  0x4c016304, 0x6500020d, 0x0d001c07, 0x21005804,   // sco.en.wo_332 da.gv.un_540  mr.ne.un_420 om.jw.un_320 
  0x47004202, 0x5d565fee, 0x44003614, 0x12004207,   // co.sn.un_220 tn.mg.ss_422  ab.kk.un_660 co.hu.un_420 
  0x0a0765a0, 0x2e0e1f04, 0x194f4812, 0x423e07a4,   // gv.it.pt_322 cy.is.fo_332  tt.bi.gl_654 it.rm.co_433 
  0x07675255, 0x28006108, 0x1300090e, 0x08110a07,   // ha.ak.it_442 za.sw.un_430  hi.bh.un_550 mk.ro.uk_432 
  // [0c30]
  0x63000113, 0x17081002, 0x47006108, 0x1f233912,   // en.sco.un_650 be.uk.sr_222  za.sn.un_430 br.ca.cy_654 
  0x4b006a21, 0x2a096807, 0x1f004f07, 0x381b31ad,   // haw.mi.un_860 ig.pl.mt_432  bi.cy.un_420 az.tr.tk_643 
  0x0000432d, 0x086828ee, 0x0000631c, 0x63000121,   // ie.un.un_A00 sw.ig.no_422  sco.un.un_800 en.sco.un_860 
  0x1b00310c, 0x064201a4, 0x6300011a, 0x5f3761a4,   // az.tr.un_530 en.co.de_433  en.sco.un_760 za.st.tn_433 
  // [0c40]
  0x381b3114, 0x0a2f4bee, 0x3706040c, 0x34555912,   // az.tr.tk_666 mi.su.pt_422  fi.de.st_543 rn.rw.xh_654 
  0x38311b08, 0x383052a9, 0x1d2601a4, 0x464dfea7,   // tr.az.tk_443 ha.uz.tk_544  en.ia.la_433 tlh.aa.qu_532 
  0x38001304, 0x3c113555, 0x153c300c, 0x182812a7,   // et.tk.un_320 tg.ro.ug_442  uz.ug.un_543 ur.sd.ar_532 
  0x1c00090d, 0x3c153808, 0x33000404, 0x12002802,   // hi.mr.un_540 tk.ug.un_430  fi.nn.un_320 sd.ur.un_220 
  // [0c50]
  0x44233c12, 0x122e0ea4, 0x20004007, 0x102d0d04,   // ug.ky.kk_654 is.fo.hu_433  lb.sq.un_420 cs.sk.lt_332 
  0x17003004, 0x3b00122a, 0x07000a0d, 0x12000908,   // uz.sr.un_320 ur.ks.un_970  mk.bg.un_540 pl.hu.un_430 
  0x0000331c, 0x0a073607, 0x0d1c09a4, 0x20004b05,   // as.un.un_800 ab.bg.mk_432  hi.mr.ne_433 mi.sq.un_330 
  0x17001002, 0x300717a0, 0x2d000d04, 0x38002007,   // be.sr.un_220 sr.bg.uz_322  cs.sk.un_320 sq.tk.un_420 
  // [0c60]
  0x3000350c, 0x150602ee, 0x3412210b, 0x12003608,   // tg.uz.un_530 da.de.un_422  fa.ur.ps_542 gn.hu.un_430 
  0x2d005309, 0x2d0d59ee, 0x1c0913ec, 0x0000790f,   // ht.sk.un_440 rn.cs.sk_422  bh.hi.mr_644 war.un.un_600 
  0x48003513, 0x04003502, 0x00002f06, 0x0233080b,   // tg.tt.un_650 tg.ru.un_220  su.un.un_400 no.nn.da_542 
  0x06001207, 0x49002d04, 0x5c1c09a0, 0x5c130902,   // hu.de.un_420 sk.to.un_320  hi.mr.sa_322 hi.bh.sa_222 
  // [0c70]
  0x1c1309a4, 0x3c234405, 0x383c3013, 0x494202a4,   // hi.bh.mr_433 kk.ky.ug_333  uz.ug.tk_665 da.co.to_433 
  0x1f3e130c, 0x44002308, 0x105a490d, 0x551547a0,   // et.rm.cy_543 ky.kk.un_430  to.sm.lt_554 sn.rw.un_320 
  0x2300442c, 0x40190404, 0x046127a4, 0x1d130407,   // kk.ky.un_990 fi.gl.lb_332  gd.za.fi_433 fi.et.la_432 
  0x04153813, 0x4f001019, 0x330632a6, 0x6550420c,   // tk.ru.un_650 lt.bi.un_750  bs.de.nn_521 co.fj.gv_543 
  // [0c80]
  0x42110da0, 0x1f1d20a0, 0x44001507, 0x494f2da0,   // cs.ro.co_322 sq.la.cy_322  un.kk.un_420 sk.bi.to_322 
  0x04564e5a, 0x3e4223a9, 0x00003e0f, 0x5c000902,   // ay.mg.fi_553 ca.co.rm_544  rm.un.un_600 hi.sa.un_220 
  0x27004207, 0x04004602, 0x00006424, 0x18003409,   // co.gd.un_420 qu.fi.un_220  lg.un.un_900 ps.ar.un_440 
  0x0000fc15, 0x42002d09, 0x23002704, 0x10021302,   // zzp.un.un_700 sk.co.un_440  gd.ca.un_320 et.da.lt_222 
  // [0c90]
  0x04006402, 0x073035ee, 0x1c12790c, 0x131c5c07,   // lg.fi.un_220 tg.uz.bg_422  war.hu.id_543 sa.mr.bh_432 
  0x25383c0c, 0x0000421c, 0x6400040e, 0x611923ec,   // ug.tk.mn_543 co.un.un_800  fi.lg.un_550 ca.gl.za_644 
  0x0400100c, 0x2a00392a, 0x23113ea4, 0x08000719,   // be.ru.un_530 dz.bo.un_970  rm.ro.ca_433 bg.uk.un_750 
  0x6822235a, 0x1011420d, 0x1500040e, 0x42105708,   // ca.oc.ig_553 co.ro.lt_554  ru.un.un_550 na.lt.co_443 
  // [0ca0]
  0x30251ea9, 0x0e001f08, 0x2d11420c, 0x4e4658af,   // ms.eu.uz_544 cy.is.un_430  co.ro.sk_543 om.qu.ay_655 
  0x1517040c, 0x122821a0, 0x19330804, 0x12283005,   // ru.sr.un_543 fa.sd.ur_322  no.nn.gl_332 uz.sd.ur_333 
  0x00004a0f, 0x45004c09, 0x02000404, 0x37002308,   // yo.un.un_600 wo.ln.un_440  fi.da.un_320 ky.ba.un_430 
  0x734764ec, 0x00004a15, 0x1c2952a4, 0x0413100c,   // lg.sn.ny_644 yo.un.un_700  ha.sl.id_433 lt.et.fi_543 
  // [0cb0]
  0x4c4a450c, 0x36303560, 0x0d001c09, 0x091c0d12,   // ln.yo.wo_543 tg.uz.ab_664  mr.ne.un_440 ne.mr.hi_654 
  0x09001308, 0x234448a7, 0x17000704, 0x4b000e08,   // bh.hi.un_430 tt.kk.ky_532  bg.sr.un_320 is.mi.un_430 
  0x3d213007, 0x0800040c, 0x5c091c08, 0x3d2134a0,   // uz.fa.ku_432 ru.uk.un_530  mr.hi.sa_443 ps.fa.ku_322 
  0x0c004608, 0x4a004c13, 0x12213da0, 0x0d091307,   // qu.sv.un_430 wo.yo.un_650  ku.fa.ur_322 bh.hi.ne_432 
  // [0cc0]
  0x04000e04, 0x0000311c, 0x480e0c12, 0x36190b05,   // is.fi.un_320 az.un.un_800  sv.is.tt_654 es.gl.gn_333 
  0x040e0ca7, 0x38071105, 0x1b0e0604, 0x79061bec,   // sv.is.fi_532 ro.bg.tk_333  de.is.tr_332 tr.de.war_644 
  0x25003708, 0x08000407, 0x04000714, 0x21002807,   // ba.mn.un_430 ru.uk.un_420  bg.ru.un_660 sd.fa.un_420 
  0x06003e08, 0x0a3615a4, 0x0d5c1308, 0x04060c0c,   // rm.de.un_430 un.ab.mk_433  bh.sa.ne_443 sv.de.fi_543 
  // [0cd0]
  0x2d0d49a0, 0x0600120b, 0x2812210c, 0x04003e02,   // to.cs.sk_322 hu.de.un_520  fa.ur.sd_543 rm.fi.un_220 
  0x3d12300d, 0x3e1930ec, 0x122821ee, 0x08003707,   // uz.ur.ku_554 uz.gl.rm_644  fa.sd.ur_422 ba.uk.un_420 
  0x632b02ec, 0x53005602, 0x08000a12, 0x04071104,   // da.vi.sco_644 mg.ht.un_220  mk.uk.un_640 ro.bg.ru_332 
  0x0600300d, 0x23003812, 0x122d0d02, 0x131c1a04,   // uz.de.un_540 tk.ky.un_640  cs.sk.hu_222 tl.id.et_332 
  // [0ce0]
  0x1c001307, 0x30000402, 0x02003904, 0x1120510d,   // bh.mr.un_420 fi.uz.un_220  br.da.un_320 kl.sq.ro_554 
  0x04000a0c, 0x066543a4, 0x48043707, 0x15150408,   // mk.ru.un_530 ie.gv.de_433  ba.ru.tt_432 ru.un.un_430 
  0x48003709, 0x13004819, 0x1f00fc07, 0x362d0d0d,   // ba.tt.un_440 tt.et.un_750  zzp.cy.un_420 cs.sk.gn_554 
  0x4448150b, 0x79000909, 0x101e1c02, 0x37004814,   // un.tt.kk_542 pl.war.un_440  id.ms.lt_222 tt.ba.un_660 
  // [0cf0]
  0x06003f02, 0x09000d0d, 0x061e1c04, 0x1828120e,   // af.de.un_220 ne.hi.un_540  id.ms.de_332 ur.sd.ar_555 
  0x32001702, 0x050930a7, 0x294202a6, 0x2b2c05a4,   // sr.bs.un_220 uz.pl.fr_532  da.co.sl_521 fr.fy.vi_433 
  0x10001302, 0x0000030f, 0x120d0aa0, 0x4407040e,   // et.lt.un_220 nl.un.un_600  pt.cs.hu_322 ru.bg.kk_555 
  0x00000a1c, 0x00001f1c, 0x00005415, 0x30151107,   // pt.un.un_800 cy.un.un_800  ik.un.un_700 ro.uz.un_420 
  // [0d00]
  0x21123ba7, 0x1c001302, 0x24321602, 0x162429a4,   // ks.ur.fa_532 bh.mr.un_220  hr.bs.eo_222 sl.eo.hr_433 
  0x0000540a, 0x021d0612, 0x170a11a4, 0x4a791aa0,   // ik.un.un_500 de.la.da_654  ro.mk.sr_433 tl.war.yo_322 
  0x040a07a4, 0x070a3ca0, 0x1c000912, 0x0d091c05,   // bg.mk.ru_433 ug.mk.bg_322  hi.mr.un_640 mr.hi.ne_333 
  0x04100aa0, 0x09000d09, 0x484437a4, 0x3217160c,   // mk.be.ru_322 ne.hi.un_440  ba.kk.tt_433 hr.sr.bs_543 
  // [0d10]
  0x0a001208, 0x40060c0d, 0x0e002e08, 0x34006504,   // hu.pt.un_430 sv.de.lb_554  fo.is.un_430 gv.xh.un_320 
  0x2d0d0aec, 0x530d0604, 0x06004008, 0x21281207,   // pt.cs.sk_644 de.cs.ht_332  lb.de.un_430 ur.sd.fa_432 
  0x0c0e29ad, 0x22000a04, 0x1c0d13a0, 0x1201180c,   // sl.is.sv_643 pt.oc.un_320  bh.ne.mr_322 ar.iw.ur_543 
  0x1f0e5aee, 0x07000404, 0x040a48a4, 0x23443c11,   // sm.is.cy_422 ru.bg.un_320  tt.mk.ru_433 ug.kk.ky_653 
  // [0d20]
  0x6200040e, 0x6a005719, 0x33001f04, 0x213d3407,   // fi.kha.un_550 na.haw.un_750  cy.nn.un_320 ps.ku.fa_432 
  0x09002404, 0x5a001f18, 0x095c13a0, 0x00000306,   // eo.pl.un_320 cy.sm.un_740  bh.sa.hi_322 nl.un.un_400 
  0x2800121b, 0x0000531c, 0x0a001907, 0x13090d0c,   // ur.sd.un_770 ht.un.un_800  gl.pt.un_420 ne.hi.bh_543 
  0x5c1c0904, 0x172508a0, 0x0d000904, 0x281834a0,   // hi.mr.sa_332 uk.mn.sr_322  hi.ne.un_320 ps.ar.sd_322 
  // [0d30]
  0x0800100c, 0x48003813, 0x190e2ead, 0x04002505,   // be.uk.un_530 tk.tt.un_650  fo.is.gl_643 mn.ru.un_330 
  0x48003507, 0x131c0913, 0x12000402, 0x23360d55,   // tg.tt.un_420 hi.mr.bh_665  fi.hu.un_220 cs.gn.ca_442 
  0x5c0d0960, 0x220b7955, 0x40063f07, 0x234430ee,   // hi.ne.sa_664 war.es.oc_442  af.de.lb_432 uz.kk.ky_422 
  0x3c182305, 0x48233005, 0x526b6808, 0x4a002e13,   // ky.ar.ug_333 uz.ky.tt_333  ig.ceb.ha_443 fo.yo.un_650 
  // [0d40]
  0x132a095a, 0x5c1c0905, 0x00000b24, 0x67007819,   // pl.mt.et_553 hi.mr.sa_333  bn.un.un_900 ve.ak.un_750 
  0x04081504, 0x30001707, 0x2a003912, 0x03003f05,   // un.uk.ru_332 sr.uz.un_420  dz.bo.un_640 af.nl.un_330 
  0x672868ac, 0x3f004004, 0x12005b13, 0x08150409,   // ig.sw.ak_632 lb.af.un_320  sg.hu.un_650 ru.uk.un_440 
  0x10002d09, 0x442537a0, 0x0d003605, 0x12005b14,   // sk.lt.un_440 ba.mn.kk_322  gn.cs.un_330 sg.hu.un_660 
  // [0d50]
  0x192d1207, 0x2f002108, 0x48003c13, 0x4a0e2dad,   // hu.sk.gl_432 jw.su.un_430  ug.tt.un_650 sk.is.yo_643 
  0x0d091311, 0x1b3b3860, 0x694d240c, 0x11003c14,   // bh.hi.ne_653 tk.so.tr_664  eo.aa.mfe_543 ug.ro.un_660 
  0x0900760e, 0x3b6473a7, 0x73006413, 0x0c3b04a0,   // crs.pl.un_550 ny.lg.so_532  lg.ny.un_650 fi.so.sv_322 
  0x15070409, 0x15024304, 0x3b00730c, 0x1c130914,   // ru.bg.un_444 ie.da.un_332  ny.so.un_530 hi.bh.mr_666 
  // [0d60]
  0x21007305, 0x65630908, 0x00003b24, 0x1d000104,   // ny.jw.un_330 pl.sco.gv_443  so.un.un_900 en.la.un_320 
  0x21006407, 0x00000124, 0x433b3812, 0x4b515a07,   // lg.jw.un_420 iw.un.un_900  tk.so.ie_654 sm.kl.mi_432 
  0xfe4c5707, 0xfe1b62a9, 0x4d54245a, 0x152146a0,   // na.wo.tlh_432 kha.tr.tlh_544  eo.ik.aa_553 qu.jw.un_322 
  0x303b48ad, 0x342130a9, 0x343f5804, 0x1500110d,   // tt.so.uz_643 uz.fa.ps_544  om.af.xh_332 ro.un.un_540 
  // [0d70]
  0x111d4dee, 0x08000c0c, 0x79001a1b, 0x1200300c,   // aa.la.ro_422 sv.no.un_530  tl.war.un_770 uz.ur.un_530 
  0x02080c0c, 0x043b4804, 0x53000308, 0x1300041a,   // sv.no.da_543 tt.so.fi_332  nl.ht.un_430 fi.et.un_760 
  0x21302804, 0x09001c0c, 0x28182108, 0x2d004708,   // sd.uz.fa_332 mr.hi.un_530  fa.ar.sd_443 sn.sk.un_430 
  0x330f040c, 0x21003e04, 0x630901af, 0x1d360107,   // fi.lv.nn_543 rm.jw.un_320  en.pl.sco_655 en.gn.la_432 
  // [0d80]
  0x08022aee, 0x00005e01, 0x0f6301a7, 0x12003b19,   // mt.da.no_422 ts.un.un_200  en.sco.lv_532 so.hu.un_750 
  0x080417a4, 0xfc1b4d08, 0x12000302, 0x21644f02,   // sr.ru.uk_433 aa.tr.zzp_443  nl.hu.un_220 bi.lg.jw_222 
  0x15464d0c, 0x12343b0b, 0x21006111, 0x656301a4,   // aa.qu.un_543 ks.ps.ur_542  za.jw.un_630 en.sco.gv_433 
  0x220603a0, 0x54005119, 0x630b0107, 0x67004d20,   // nl.de.oc_322 kl.ik.un_750  en.es.sco_432 aa.ak.un_850 
  // [0d90]
  0x51000108, 0x36002d07, 0x13000104, 0x436924ac,   // en.kl.un_430 sk.gn.un_420  en.et.un_320 eo.mfe.ie_632 
  0xfe005421, 0x153c38ad, 0x7900200d, 0x040815a0,   // ik.tlh.un_860 tk.ug.un_643  sq.war.un_540 un.uk.ru_322 
  0x1f6509ec, 0x08003508, 0x5c352fa7, 0x59550205,   // pl.gv.cy_644 tg.uk.un_430  su.zu.sa_532 da.rw.rn_333 
  0x31481b12, 0x20006504, 0x353730a0, 0x1a1f01a4,   // tr.tt.az_654 gv.sq.un_320  uz.ba.tg_322 en.cy.tl_433 
  // [0da0]
  0x1c5c1307, 0x303c3807, 0x35004f09, 0x0d13090d,   // bh.sa.mr_432 tk.ug.uz_432  bi.zu.un_440 hi.bh.ne_554 
  0x3d3021ee, 0x1c5c0da4, 0x38303c13, 0x5200152a,   // fa.uz.ku_422 ne.sa.mr_433  ug.uz.tk_665 un.ha.un_970 
  0x13001c19, 0x17001507, 0x13004904, 0x30000704,   // mr.bh.un_750 un.sr.un_420  to.et.un_320 bg.uz.un_320 
  0x5e004736, 0x0900130d, 0x524b6812, 0x48003713,   // sn.ts.un_AA0 bh.hi.un_540  ig.mi.ha_654 ba.tt.un_650 
  // [0db0]
  0x2a4661a9, 0x31481b07, 0x73fa35ad, 0x091c0da4,   // za.qu.mt_544 tr.tt.az_432  zu.nr.ny_643 ne.mr.hi_433 
  0xfe006119, 0x5c00582a, 0x4b006a0c, 0x32003b04,   // za.tlh.un_750 om.sa.un_970  haw.mi.un_530 so.bs.un_320 
  0x73595514, 0xfe5c2a0c, 0x0d001307, 0x150804a4,   // rw.rn.ny_666 mt.sa.tlh_543  bh.ne.un_420 ru.uk.un_433 
  0x23150404, 0x473534ad, 0x17003807, 0xfe1f46a9,   // ru.ky.un_320 xh.zu.sn_643  tk.sr.un_420 qu.cy.tlh_544 
  // [0dc0]
  0x64005821, 0x203b2c11, 0x3800060b, 0x3d2134a9,   // om.lg.un_860 fy.so.sq_653  de.tk.un_520 ps.fa.ku_544 
  0x3d002118, 0x00000d2d, 0x4700781a, 0x73007813,   // fa.ku.un_740 ne.un.un_A00  ve.sn.un_760 ve.ny.un_650 
  0x44150412, 0x0000782d, 0x7335340c, 0x481b4aa0,   // ru.kk.un_640 ve.un.un_A00  xh.zu.ny_543 yo.tr.tt_322 
  0x0d0913ac, 0x11001902, 0x08041002, 0x342812ec,   // bh.hi.ne_632 gl.ro.un_220  be.ru.uk_222 ur.sd.ps_644 
  // [0dd0]
  0x1e003b05, 0x32171660, 0x34001221, 0x36222e07,   // so.ms.un_330 hr.sr.bs_664  ur.ps.un_860 fo.oc.gn_432 
  0x00003915, 0x0a00180c, 0x13003902, 0x115a1302,   // br.un.un_700 ga.pt.un_530  br.et.un_220 et.sm.ro_222 
  0x23004423, 0x04001d02, 0x28006b04, 0x454205a7,   // kk.ky.un_880 la.fi.un_220  ceb.sw.un_320 fr.co.ln_532 
  0x0a006a04, 0x4704500c, 0x31004808, 0x632362af,   // haw.pt.un_320 fj.fi.sn_543  tt.az.un_430 kha.ca.sco_655 
  // [0de0]
  0x23000505, 0x1e2f180d, 0x00004c0a, 0x081735a4,   // fr.ca.un_330 ga.su.ms_554  wo.un.un_500 tg.sr.uk_433 
  0x00001d1c, 0x48464e0c, 0x11004205, 0x48002508,   // la.un.un_800 ay.qu.tt_543  co.ro.un_330 mn.tt.un_430 
  0x3b13560c, 0x52001e08, 0x56376a5a, 0x431d6305,   // mg.et.so_543 ms.ha.un_430  haw.st.mg_553 sco.la.ie_333 
  0x736478a9, 0x0a1218a7, 0x05630107, 0x566a59a9,   // ve.lg.ny_544 ga.hu.pt_532  en.sco.fr_432 rn.haw.mg_544 
  // [0df0]
  0x0565130c, 0x37494b0c, 0x0a001812, 0x1d000307,   // et.gv.fr_543 mi.to.st_543  ga.pt.un_640 nl.la.un_420 
  0x2f003607, 0x09002204, 0x59553b05, 0x075d0107,   // gn.su.un_420 oc.pl.un_320  so.rw.rn_333 en.ss.it_432 
  0x3f002704, 0x353473ee, 0x2b531ba0, 0x490e3b02,   // gd.af.un_320 ny.xh.zu_422  tr.ht.vi_322 so.is.to_222 
  0x340324ee, 0x48464e0d, 0x2d0d29ee, 0x296e0da0,   // eo.nl.xh_422 ay.qu.tt_554  sl.cs.sk_422 cs.hmn.sl_322 
  // [0e00]
  0x20553b07, 0x211c34ee, 0x1c002f04, 0x13000407,   // so.rw.sq_432 xh.id.jw_422  su.id.un_320 fi.et.un_420 
  0x17001602, 0x353402a0, 0x1d420707, 0x19002f04,   // hr.sr.un_220 da.xh.zu_322  it.co.la_432 su.gl.un_320 
  0x1206020c, 0x1d424308, 0x125855ee, 0x593b5c04,   // da.de.hu_543 ie.co.la_443  rw.om.hu_422 sa.so.rn_332 
  0x4749130b, 0x040811a0, 0x37286a04, 0x2d000907,   // et.to.sn_542 ro.uk.ru_322  haw.sw.st_332 pl.sk.un_420 
  // [0e10]
  0x12000902, 0x361d5908, 0x4a00730c, 0x15000d05,   // pl.hu.un_220 rn.la.gn_443  ny.yo.un_530 cs.un.un_330 
  0x00005801, 0x1a7937a4, 0x214773ee, 0x1d00610d,   // om.un.un_200 st.war.tl_433  ny.sn.jw_422 za.la.un_540 
  0x4b6a37a7, 0x0d091bee, 0x47007307, 0x3300080b,   // st.haw.mi_532 tr.pl.cs_422  ny.sn.un_420 no.nn.un_520 
  0x0f000504, 0x4400150d, 0x431d01a4, 0x15002508,   // fr.lv.un_320 un.kk.un_540  en.la.ie_433 mn.un.un_430 
  // [0e20]
  0x24000c04, 0x63000104, 0x3700230e, 0x04170a0d,   // sv.eo.un_320 en.sco.un_320  ky.ba.un_550 mk.sr.ru_554 
  0x36113c04, 0x1200101b, 0x00002324, 0x30080aaf,   // ug.ro.ab_332 lt.hu.un_770  ky.un.un_900 mk.uk.uz_655 
  0x2c000119, 0x03003f14, 0x07370aa0, 0x3f0301a0,   // en.fy.un_750 af.nl.un_660  mk.ba.bg_322 en.nl.af_322 
  0x3c004418, 0x48001b07, 0x565a4f05, 0x60001213,   // kk.ug.un_740 tr.tt.un_420  bi.sm.mg_333 hu.vo.un_650 
  // [0e30]
  0x3202300c, 0x2123340c, 0x61636eec, 0x2d00120c,   // uz.da.bs_543 ps.ky.fa_543  hmn.sco.za_644 hu.sk.un_530 
  0x39001f05, 0x3b5e12af, 0x0600600b, 0x00006e37,   // cy.br.un_330 hu.ts.so_655  vo.de.un_520 hmn.un.un_B00 
  0x3302080e, 0x5a004904, 0x28005c12, 0x10002508,   // no.da.nn_555 to.sm.un_320  sa.sw.un_640 mn.be.un_430 
  0x17163202, 0x61116ea9, 0x441823a4, 0x21123007,   // bs.hr.sr_222 hmn.ro.za_544  ky.ar.kk_433 uz.ur.fa_432 
  // [0e40]
  0x27306e11, 0x6e003014, 0x48001b23, 0x3f656ea4,   // hmn.uz.gd_653 uz.hmn.un_660  tr.tt.un_880 hmn.gv.af_433 
  0x06002102, 0x5c005908, 0x30003c0c, 0x2f00210d,   // jw.de.un_220 rn.sa.un_430  ug.uz.un_530 jw.su.un_540 
  0x04080702, 0x091c0d07, 0x28002112, 0x355e3404,   // bg.uk.ru_222 ne.mr.hi_432  fa.sd.un_640 xh.ts.zu_332 
  0x69765308, 0x35345ea0, 0x35001507, 0x211c2fee,   // ht.crs.mfe_443 ts.xh.zu_322  un.tg.un_420 su.id.jw_422 
  // [0e50]
  0x28001013, 0x48001b0e, 0x31021b11, 0x3d003b0e,   // lt.sw.un_650 tr.tt.un_550  tr.da.az_653 ks.ku.un_550 
  0x353007a0, 0x1200180e, 0x3c002307, 0x095c0dac,   // bg.uz.tg_322 ga.hu.un_550  ky.ug.un_420 ne.sa.hi_632 
  0x170a0707, 0x120e3604, 0x1800440d, 0x1c5c090c,   // bg.mk.sr_432 gn.is.hu_332  kk.ar.un_540 hi.sa.mr_543 
  0x36003019, 0x5e351e07, 0x09002a08, 0x3e00070e,   // uz.ab.un_750 ms.zu.ts_432  mt.pl.un_430 it.rm.un_550 
  // [0e60]
  0x34213dee, 0x35005e04, 0x5e003419, 0x18003019,   // ku.fa.ps_422 ts.zu.un_320  xh.ts.un_750 uz.ar.un_750 
  0x375e2804, 0x1b31485a, 0x08303c0d, 0x0a0710a4,   // sw.ts.st_332 tt.az.tr_553  ug.uz.uk_554 be.bg.mk_433 
  0x5000470c, 0x093b0da4, 0x35005e09, 0x3b122808,   // sn.fj.un_530 cs.so.pl_433  ts.zu.un_440 sd.ur.ks_443 
  0x301523ee, 0x3b461e0b, 0x3f060a09, 0x7367690d,   // ky.uz.un_420 ms.qu.so_542  pt.de.af_444 mfe.ak.ny_554 
  // [0e70]
  0x30045804, 0x04000613, 0x30040808, 0x79000609,   // om.fi.uz_332 de.fi.un_650  uk.ru.uz_443 de.war.un_440 
  0x2c623f12, 0x796505a0, 0x2300441a, 0x2c2e03af,   // af.kha.fy_654 fr.gv.war_322  kk.ky.un_760 nl.fo.fy_655 
  0x00000606, 0x2400120c, 0x033f270c, 0x024c0f11,   // de.un.un_400 hu.eo.un_530  gd.af.nl_543 lv.wo.da_653 
  0x28544707, 0x09005c14, 0x21123d0d, 0x3f040308,   // sn.ik.sw_432 sa.hi.un_660  ku.ur.fa_554 nl.fi.af_443 
  // [0e80]
  0x33033faf, 0x19260ba4, 0x79001e04, 0x2100301b,   // af.nl.nn_655 es.ia.gl_433  ms.war.un_320 uz.fa.un_770 
  0x150a04af, 0x090d5c04, 0x6a4f4da7, 0x2d0d3b14,   // ru.mk.un_655 sa.ne.hi_332  aa.bi.haw_532 so.cs.sk_666 
  0x18654b04, 0x0000270f, 0x0000471c, 0x322d0d08,   // mi.gv.ga_332 gd.un.un_600  sn.un.un_800 cs.sk.bs_443 
  0x373065a0, 0x3f1151ee, 0x3c23440d, 0x501805ec,   // gv.uz.st_322 kl.ro.af_422  kk.ky.ug_554 fr.ga.fj_644 
  // [0e90]
  0x35007304, 0x17070a0d, 0x17000a0d, 0x29005504,   // ny.zu.un_320 mk.bg.sr_554  mk.sr.un_540 rw.sl.un_320 
  0x403f1104, 0x2307425a, 0x2d000d1a, 0x360946ac,   // ro.af.lb_332 co.it.ca_553  cs.sk.un_760 qu.pl.gn_632 
  0x1b3148ec, 0x11502408, 0x172d0d08, 0x1100fc1a,   // tt.az.tr_644 eo.fj.ro_443  cs.sk.sr_443 zzp.ro.un_760 
  0x0c1f6207, 0x043635a7, 0x2700180d, 0x34182114,   // kha.cy.sv_432 tg.ab.ru_532  ga.gd.un_540 fa.ar.ps_666 
  // [0ea0]
  0x00003f06, 0x52003604, 0x47353407, 0x18002722,   // af.un.un_400 gn.ha.un_320  xh.zu.sn_432 gd.ga.un_870 
  0x027368a9, 0x33406107, 0x2a5957ec, 0x04111504,   // ig.ny.da_544 za.lb.nn_432  na.rn.mt_644 un.ro.ru_332 
  0x12001508, 0x28001104, 0x29000919, 0x10002409,   // un.hu.un_430 ro.sw.un_320  pl.sl.un_750 eo.lt.un_440 
  0x33000b12, 0x355e3411, 0x55001f11, 0x03576912,   // bn.as.un_640 xh.ts.zu_653  cy.rw.un_630 mfe.na.nl_654 
  // [0eb0]
  0x5800520c, 0x035a4904, 0x384a5307, 0x5c45730c,   // ha.om.un_530 to.sm.nl_332  ht.yo.tk_432 ny.ln.sa_543 
  0x55005919, 0x4c002008, 0x2b005d19, 0x5d455204,   // rn.rw.un_750 sq.wo.un_430  ss.vi.un_750 ha.ln.ss_332 
  0x1e1c4a09, 0x12282160, 0x08001508, 0x09000d0c,   // yo.id.ms_444 fa.sd.ur_664  un.uk.un_430 cs.pl.un_530 
  0x52313ba0, 0x292d0d05, 0x37001004, 0x47430207,   // so.az.ha_322 cs.sk.sl_333  lt.st.un_320 da.ie.sn_432 
  // [0ec0]
  0x09430c0d, 0x53001b02, 0x457352ec, 0x330208ee,   // sv.ie.pl_554 tr.ht.un_220  ha.ny.ln_644 no.da.nn_422 
  0x04000821, 0x3d3421af, 0x15041008, 0x3b2f53ee,   // uk.ru.un_860 fa.ps.ku_655  be.ru.un_443 ht.su.so_422 
  0x31695207, 0x2100300c, 0x0a795712, 0x06381b09,   // ha.mfe.az_432 uz.fa.un_530  na.war.pt_654 tr.tk.de_444 
  0x4a5267ad, 0x53005219, 0x0a1736a9, 0x00007915,   // ak.ha.yo_643 ha.ht.un_750  ab.sr.mk_544 war.un.un_700 
  // [0ed0]
  0x38004413, 0x3c004412, 0x7900360d, 0x15003019,   // kk.tk.un_650 kk.ug.un_640  gn.war.un_540 uz.un.un_750 
  0x362451a0, 0x24005107, 0x38004822, 0x010318ee,   // kl.eo.gn_322 kl.eo.un_420  tt.tk.un_870 ga.nl.en_422 
  0x34001208, 0x2a003922, 0x00005115, 0x17080407,   // ur.ps.un_430 dz.bo.un_870  kl.un.un_700 ru.uk.sr_432 
  0x12002408, 0x19fc0107, 0x48003814, 0x30002113,   // eo.hu.un_430 en.zzp.gl_432  tk.tt.un_660 fa.uz.un_650 
  // [0ee0]
  0x7900361a, 0x08151004, 0x79003621, 0x79003612,   // gn.war.un_760 be.uk.un_320  gn.war.un_860 gn.war.un_640 
  0x36007913, 0x36007908, 0x251d5105, 0x3d2123ba,   // war.gn.un_650 war.gn.un_430  kl.la.eu_333 ky.fa.ku_843 
  0x21003407, 0x46005104, 0x3c071004, 0x0c384811,   // ps.fa.un_420 kl.qu.un_320  be.bg.ug_332 tt.tk.sv_653 
  0x51004608, 0x10000408, 0x0e002804, 0x0e330804,   // qu.kl.un_430 ru.be.un_430  sw.is.un_320 no.nn.is_332 
  // [0ef0]
  0x5a004b0c, 0x650e2ead, 0x632526ee, 0x5c1d0612,   // mi.sm.un_530 fo.is.gv_643  ia.eu.sco_422 de.la.sa_654 
  0x3d341207, 0x12001307, 0x3c004405, 0x561d13ad,   // ur.ps.ku_432 et.hu.un_420  kk.ug.un_330 et.la.mg_643 
  0x183428ee, 0x08330208, 0x33080c05, 0x00004424,   // sd.ps.ar_422 da.nn.no_443  sv.no.nn_333 kk.un.un_900 
  0x34003007, 0x3e0751ee, 0x12001807, 0x44002313,   // uz.ps.un_420 kl.it.rm_422  ga.hu.un_420 ky.kk.un_650 
  // [0f00]
  0x3d2130a0, 0x21001209, 0x5c355eaf, 0x16002907,   // uz.fa.ku_322 ur.fa.un_440  ts.zu.sa_655 sl.hr.un_420 
  0x0a070809, 0x2000610d, 0x04000802, 0x2700472a,   // uk.bg.mk_444 za.sq.un_540  uk.ru.un_220 sn.gd.un_970 
  0x2e000413, 0x276518a7, 0x082e33ee, 0x204324a4,   // fi.fo.un_650 ga.gv.gd_532  nn.fo.no_422 eo.ie.sq_433 
  0x016b1da4, 0x21121804, 0x134269a4, 0x3e07420b,   // la.ceb.en_433 ar.ur.fa_332  mfe.co.et_433 co.it.rm_542 
  // [0f10]
  0x11101d5a, 0x182812a4, 0x04003604, 0x34281812,   // la.lt.ro_553 ur.sd.ar_433  ab.ru.un_320 ar.sd.ps_654 
  0x0a001712, 0x23004804, 0x20001e22, 0x34281808,   // sr.mk.un_640 tt.ky.un_320  am.ti.un_870 ar.sd.ps_443 
  0x112801ee, 0x5c1827ad, 0x04170a07, 0x18002305,   // en.sw.ro_422 gd.ga.sa_643  mk.sr.ru_432 ky.ar.un_330 
  0x34003008, 0x632f01a4, 0x153c36ad, 0x39365fec,   // uz.ps.un_430 en.su.sco_433  ab.ug.un_643 tn.gn.br_644 
  // [0f20]
  0x5f5a500d, 0x02570408, 0x33000b13, 0x1300040c,   // fj.sm.tn_554 fi.na.da_443  bn.as.un_650 fi.et.un_530 
  0x151204ad, 0x37003c13, 0x3622185a, 0x375f6a0d,   // fi.hu.un_643 ug.ba.un_650  ga.oc.gn_553 haw.tn.st_554 
  0x640a2aa4, 0x65014f04, 0x405706ad, 0x21341807,   // mt.pt.lg_433 bi.en.gv_332  de.na.lb_643 ar.ps.fa_432 
  0x56374907, 0x48382312, 0x2d005609, 0x32585fec,   // to.st.mg_432 ky.tk.tt_654  mg.sk.un_440 tn.om.bs_644 
  // [0f30]
  0x08100409, 0x3b001219, 0x0a040804, 0x3600180c,   // ru.be.uk_444 ur.ks.un_750  uk.ru.mk_332 ga.gn.un_530 
  0x65362c02, 0x45733955, 0x48303108, 0x080417a0,   // fy.gn.gv_222 br.ny.ln_442  az.uz.tt_443 sr.ru.uk_322 
  0x325d560c, 0x04000213, 0x73094a05, 0x0600041a,   // mg.ss.bs_543 da.fi.un_650  yo.pl.ny_333 fi.de.un_760 
  0x040e2e05, 0x37245fec, 0x3c213d07, 0x353437a9,   // fo.is.fi_333 tn.eo.st_644  ku.fa.ug_432 st.xh.zu_544 
  // [0f40]
  0x5c000f12, 0x07170aad, 0x65003804, 0x170a0760,   // lv.sa.un_640 mk.sr.bg_643  tk.gv.un_320 bg.mk.sr_664 
  0x09000d12, 0x481504a4, 0x080c0d07, 0x18001207,   // cs.pl.un_640 ru.tt.un_430  cs.sv.no_432 ur.ar.un_420 
  0x094f4d04, 0x3f000309, 0x0d091ca4, 0x0d3309a0,   // aa.bi.pl_332 nl.af.un_440  mr.hi.ne_433 pl.nn.cs_322 
  0x5c0d0908, 0x17040aa0, 0x0a080404, 0x40091d0b,   // hi.ne.sa_443 mk.ru.sr_322  ru.uk.mk_332 la.pl.lb_542 
  // [0f50]
  0x2a003913, 0x1800360c, 0x0e003607, 0x0d003604,   // dz.bo.un_650 gn.ga.un_530  gn.is.un_420 gn.cs.un_320 
  0x3400180e, 0x0d2d360b, 0x091b3804, 0x12000d07,   // ar.ps.un_550 gn.sk.cs_542  tk.tr.pl_332 cs.hu.un_420 
  0x48090da0, 0x3c443b0b, 0x791d01a0, 0x0f116aee,   // cs.pl.tt_322 ks.kk.ug_542  en.la.war_322 haw.ro.lv_422 
  0x17000a0c, 0x230d1202, 0x03002313, 0x32000d07,   // mk.sr.un_530 hu.cs.ca_222  ca.nl.un_650 cs.bs.un_420 
  // [0f60]
  0x2d0d2ea9, 0x2d3f0d04, 0x390324a4, 0x0d2962a0,   // fo.cs.sk_544 cs.af.sk_332  eo.nl.br_433 kha.sl.cs_322 
  0x0a001504, 0x340339a9, 0x00002137, 0x3e353408,   // un.mk.un_320 br.nl.xh_544  jw.un.un_B00 xh.zu.rm_443 
  0x21001a07, 0x2b731b04, 0x375d1aa4, 0x13005710,   // tl.jw.un_420 tr.ny.vi_332  tl.ss.st_433 na.et.un_620 
  0x6b006235, 0x30443808, 0x120a690c, 0x1a006b36,   // kha.ceb.un_A90 tk.kk.uz_443  mfe.pt.hu_543 ceb.tl.un_AA0 
  // [0f70]
  0x1b03380c, 0x00001915, 0x0000291c, 0xfa3534af,   // tk.nl.tr_543 gl.un.un_700  sl.un.un_800 xh.zu.nr_655 
  0x3600111b, 0x40001c04, 0x5f3040ec, 0x48003107,   // ro.ab.un_770 id.lb.un_320  lb.uz.tn_644 az.tt.un_420 
  0x3c234460, 0x1c1a4307, 0x56003612, 0x00001f24,   // kk.ky.ug_664 ie.tl.id_432  gn.mg.un_640 cy.un.un_900 
  0x1e002011, 0x1b003805, 0x23000704, 0x60002514,   // ti.am.un_630 tk.tr.un_330  bg.ky.un_320 eu.vo.un_660 
  // [0f80]
  0x390a120c, 0x041725a0, 0x03353408, 0x20483904,   // hu.pt.br_543 mn.sr.ru_322  xh.zu.nl_443 br.tt.sq_332 
  0x1800210e, 0x00000103, 0x211d15a0, 0x21002304,   // fa.ar.un_550 en.un.un_300  un.la.jw_322 ky.fa.un_320 
  0x6e00180d, 0x48003007, 0x23032b0c, 0x0000751c,   // ga.hmn.un_540 uz.tt.un_420  vi.nl.ca_543 nso.un.un_800 
  0x4a5d3455, 0x37007309, 0x125f73ec, 0x4602fca4,   // xh.ss.yo_442 ny.st.un_440  ny.tn.hu_644 zzp.da.qu_433 
  // [0f90]
  0x1c5c09a0, 0x0d002d07, 0x0f002919, 0x2a0d20ad,   // hi.sa.mr_322 sk.cs.un_420  sl.lv.un_750 sq.cs.mt_643 
  0x23174408, 0x2a2718a0, 0x30374808, 0x211128a0,   // kk.sr.ky_443 ga.gd.mt_322  tt.ba.uz_443 sw.ro.jw_322 
  0x355d34ee, 0x00000e24, 0x25360bee, 0x2a003014,   // xh.ss.zu_422 is.un.un_900  es.gn.eu_422 uz.mt.un_660 
  0x18272aa0, 0x23041007, 0x06381b12, 0x2a181f0c,   // mt.gd.ga_322 be.ru.ky_432  tr.tk.de_654 cy.ga.mt_543 
  // [0fa0]
  0x360a28a0, 0x35301107, 0x2100340c, 0x1800271a,   // sw.pt.gn_322 ro.uz.tg_432  ps.fa.un_530 gd.ga.un_760 
  0x2a00180c, 0x392a22ee, 0x210c1708, 0x04370aa0,   // ga.mt.un_530 oc.mt.br_422  sr.sv.jw_443 mk.ba.ru_322 
  0x30002705, 0x1500011a, 0x07170a08, 0x35003021,   // gd.uz.un_330 en.un.un_760  mk.sr.bg_443 uz.tg.un_860 
  0x00000801, 0x5700060e, 0x44003013, 0x08003505,   // no.un.un_200 de.na.un_550  uz.kk.un_650 tg.uk.un_330 
  // [0fb0]
  0x2f5c21a4, 0x202d290c, 0x18000108, 0x2a215c07,   // jw.sa.su_433 sl.sk.sq_543  en.ga.un_430 sa.jw.mt_432 
  0x18003405, 0x37442308, 0x2a1024a4, 0x00002915,   // ps.ar.un_330 ky.kk.ba_443  eo.lt.mt_433 sl.un.un_700 
  0x2e2a0f12, 0x1b3138af, 0x34182107, 0x0a1017a7,   // lv.mt.fo_654 tk.az.tr_655  fa.ar.ps_432 sr.be.mk_532 
  0x07004813, 0x1300422a, 0x04000a04, 0x2a2e0e0c,   // tt.bg.un_650 co.et.un_970  mk.ru.un_320 is.fo.mt_543 
  // [0fc0]
  0x3500300e, 0x64002a1a, 0x32002a09, 0x0e381004,   // uz.tg.un_550 mt.lg.un_760  mt.bs.un_440 lt.tk.is_332 
  0x383031a9, 0x10090f12, 0x21343dee, 0x0e002a05,   // az.uz.tk_544 lv.pl.lt_654  ku.ps.fa_422 mt.is.un_330 
  0x13090dec, 0x2e0e20af, 0x4800230e, 0x0a071709,   // ne.hi.bh_644 sq.is.fo_655  ky.tt.un_550 sr.bg.mk_444 
  0x4a003621, 0x311b38af, 0x0f292a60, 0x171632a0,   // gn.yo.un_860 tk.tr.az_655  mt.sl.lv_664 bs.hr.sr_322 
  // [0fd0]
  0x4d1f6413, 0x13151d04, 0x3d182305, 0x2e001a08,   // lg.cy.aa_665 la.et.un_320  ky.ar.ku_333 tl.fo.un_430 
  0x3b001302, 0x34193ba7, 0x0e003618, 0x04353008,   // et.so.un_220 so.gl.xh_532  gn.is.un_740 uz.tg.ru_443 
  0x292a0f13, 0x0400291a, 0x0f00100c, 0x290e2aa9,   // lv.mt.sl_665 sl.fi.un_760  lt.lv.un_530 mt.is.sl_544 
  0x25004804, 0x13292a09, 0x1b303105, 0x290f2a12,   // tt.mn.un_320 mt.sl.et_444  az.uz.tr_333 mt.lv.sl_654 
  // [0fe0]
  0x304423a0, 0x38301b04, 0x0a3c300c, 0x13001c04,   // ky.kk.uz_322 tr.uz.tk_332  uz.ug.mk_543 mr.bh.un_320 
  0x2a00340c, 0x311b30a0, 0x5c1c0d07, 0x12000c08,   // xh.mt.un_530 uz.tr.az_322  ne.mr.sa_432 sv.hu.un_430 
  0x3100380e, 0x42071da0, 0x101e1c08, 0x33002e04,   // tk.az.un_550 la.it.co_322  id.ms.lt_443 fo.nn.un_320 
  0x35003404, 0x3100301a, 0x17150809, 0x2c2a69ee,   // xh.zu.un_320 uz.az.un_760  uk.sr.un_440 mfe.mt.fy_422 
  // [0ff0]
  0x5d381808, 0x040817a0, 0x4d1d180c, 0x15130404,   // ga.tk.ss_443 sr.uk.ru_322  ga.la.aa_543 fi.et.un_332 
  0x5d00011a, 0x0a48380b, 0x33025ca4, 0x0200080d,   // en.ss.un_760 tk.tt.mk_542  sa.da.nn_433 no.da.un_540 
  0x10002405, 0x131b2408, 0x04581d07, 0x00004201,   // eo.lt.un_330 eo.tr.et_443  la.om.fi_432 co.un.un_200 
  0x346b0907, 0x0d735307, 0x154d1a07, 0x1d000707,   // pl.ceb.xh_432 ht.ny.cs_432  tl.aa.un_432 it.la.un_420 
  
  // [1000]
  0x65001f13, 0x34004404, 0x211834ad, 0x586451ee,   // cy.gv.un_650 kk.ps.un_320  ps.ar.fa_643 kl.lg.om_422 
  0x3c283b5a, 0x5c120fa4, 0x5d6b010c, 0x1e4d3912,   // ks.sd.ug_553 lv.hu.sa_433  en.ceb.ss_543 br.aa.ms_654 
  0x79004d12, 0x030201a0, 0x123b13ad, 0x04151707,   // aa.war.un_640 en.da.nl_322  et.so.hu_643 sr.ru.un_420 
  0x2a00fe0c, 0x28402755, 0x151004af, 0xfe003013,   // tlh.mt.un_530 gd.lb.sw_442  ru.be.un_655 uz.tlh.un_650 
  // [1010]
  0x65061f5a, 0x47007321, 0x13186205, 0x46003b02,   // cy.de.gv_553 ny.sn.un_860  kha.ga.et_333 so.qu.un_220 
  0x60062711, 0x1d004d21, 0x062718a0, 0x3800fe08,   // gd.de.vo_653 aa.la.un_860  ga.gd.de_322 tlh.tk.un_430 
  0x0e000d14, 0x170903a0, 0x0f002702, 0x51044614,   // cs.is.un_660 nl.pl.sr_322  gd.lv.un_220 qu.fi.kl_666 
  0x40570612, 0x40000614, 0x05013ea9, 0x10025aad,   // de.na.lb_654 de.lb.un_660  rm.en.fr_544 sm.da.lt_643 
  // [1020]
  0x111d12ad, 0x0600400d, 0x1d074212, 0x100f5c08,   // hu.la.ro_643 lb.de.un_540  co.it.la_654 sa.lv.lt_443 
  0x2c001804, 0x1c090da4, 0x0900110c, 0x2b115c08,   // ga.fy.un_320 ne.hi.mr_433  ro.pl.un_530 sa.ro.vi_443 
  0x00004f0f, 0x20043307, 0x400a060c, 0x3f005711,   // bi.un.un_600 nn.fi.sq_432  de.pt.lb_543 na.af.un_630 
  0x00004d1c, 0x07425c09, 0x1300041b, 0x0d005c12,   // aa.un.un_800 sa.co.it_444  fi.et.un_770 sa.ne.un_640 
  // [1030]
  0x09007307, 0x37444855, 0x17103504, 0x1304510d,   // ny.pl.un_420 tt.kk.ba_442  tg.be.sr_332 kl.fi.et_554 
  0x3623195a, 0x1f6976a4, 0x4d01fc5a, 0x122134a4,   // gl.ca.gn_553 crs.mfe.cy_433  zzp.en.aa_553 ps.fa.ur_433 
  0x2230fea0, 0x10000f0e, 0x13003b08, 0x736301a4,   // tlh.uz.oc_322 lv.lt.un_550  so.et.un_430 en.sco.ny_433 
  0x341228a0, 0x574006a4, 0x1f0501a4, 0x28342107,   // sd.ur.ps_322 de.lb.na_433  en.fr.cy_433 fa.ps.sd_432 
  // [1040]
  0x403e06af, 0x34003b22, 0x1c001207, 0x020618a7,   // de.rm.lb_655 ks.ps.un_870  hu.id.un_420 ga.de.da_532 
  0x12040cee, 0x30234d04, 0x34003d08, 0x2b002e0c,   // sv.fi.hu_422 aa.ca.uz_332  ku.ps.un_430 fo.vi.un_530 
  0x20684f07, 0x17040808, 0x343021ad, 0x23003c14,   // bi.ig.sq_432 uk.ru.sr_443  fa.uz.ps_643 ug.ky.un_660 
  0x34002108, 0x51464e0c, 0x37004808, 0x1b007913,   // fa.ps.un_430 ay.qu.kl_543  tt.ba.un_430 war.tr.un_650 
  // [1050]
  0x321617a4, 0x2f673b04, 0x330840a0, 0x23443ca0,   // sr.hr.bs_433 so.ak.su_332  lb.no.nn_322 ug.kk.ky_322 
  0x18234412, 0x291b3813, 0x34003d0d, 0x04001305,   // kk.ky.ar_654 tk.tr.sl_665  ku.ps.un_540 et.fi.un_330 
  0x25001513, 0x04001314, 0x042538ac, 0x44113ca4,   // un.mn.un_650 et.fi.un_660  tk.mn.ru_632 ug.ro.kk_433 
  0x0000021c, 0x3d003b0c, 0x20212f64, 0x30002108,   // da.un.un_800 ks.ku.un_530  su.jw.sq_762 fa.uz.un_430 
  // [1060]
  0x00002124, 0x0c330855, 0x131c0907, 0x18002102,   // jw.un.un_900 no.nn.sv_442  hi.mr.bh_432 fa.ar.un_220 
  0x0400150d, 0x08250408, 0x3c44230d, 0x23153c0c,   // un.ru.un_540 ru.mn.uk_443  ky.kk.ug_554 ug.ky.un_530 
  0x1600290b, 0x25003504, 0x21002f22, 0x282112a4,   // sl.hr.un_520 tg.mn.un_320  su.jw.un_870 ur.fa.sd_433 
  0x30383505, 0x15002308, 0x3800310c, 0x33001302,   // tg.tk.uz_333 ky.un.un_430  az.tk.un_530 et.nn.un_220 
  // [1070]
  0x0a7965a4, 0x15004604, 0x06330805, 0x1300040d,   // gv.war.pt_433 qu.un.un_320  no.nn.de_333 fi.et.un_540 
  0x30123409, 0x23004409, 0x0a073004, 0x34003009,   // ps.ur.uz_444 kk.ky.un_440  uz.bg.mk_332 uz.ps.un_440 
  0x0a003004, 0x21001208, 0x081517a4, 0x44002311,   // uz.mk.un_320 ur.fa.un_430  sr.uk.un_430 ky.kk.un_630 
  0x1c130909, 0x00001603, 0x48374460, 0x21003012,   // hi.bh.mr_444 hr.un.un_300  kk.ba.tt_664 uz.fa.un_640 
  // [1080]
  0x100407a4, 0x2e006507, 0x6b1a6a04, 0x2a4a3607,   // bg.ru.be_433 gv.fo.un_420  haw.tl.ceb_332 gn.yo.mt_432 
  0x1000440d, 0x796b1a0c, 0x30003512, 0x59553614,   // kk.be.un_540 tl.ceb.war_543  tg.uz.un_640 gn.rw.rn_666 
  0x3308020e, 0x1a796baf, 0x3c002513, 0x55796baf,   // da.no.nn_555 ceb.war.tl_655  mn.ug.un_650 ceb.war.rw_655 
  0x17114804, 0x55372aa4, 0x13003507, 0x5300210d,   // tt.ro.sr_332 mt.st.rw_433  zu.et.un_420 jw.ht.un_540 
  // [1090]
  0x1f003819, 0x292a5905, 0x13090d14, 0x38004414,   // tk.cy.un_750 rn.mt.sl_333  ne.hi.bh_666 kk.tk.un_660 
  0x1c00130e, 0x2100180b, 0x32000204, 0x123418ad,   // bh.mr.un_550 ar.fa.un_520  da.bs.un_320 ar.ps.ur_643 
  0x09001c12, 0x55000209, 0x08001008, 0x1f513855,   // mr.hi.un_640 da.rw.un_440  be.uk.un_430 tk.kl.cy_442 
  0x3000210d, 0x2a2155a0, 0x6b0236a6, 0x64002a07,   // fa.uz.un_540 rw.jw.mt_322  gn.da.ceb_521 mt.lg.un_420 
  // [10a0]
  0x02366ba4, 0x361e6ba0, 0x36000a08, 0x55493605,   // ceb.gn.da_433 ceb.ms.gn_322  mk.ab.un_430 gn.to.rw_333 
  0x32006004, 0x15153c0c, 0x44233707, 0x04081002,   // vo.bs.un_320 ug.un.un_530  ba.ky.kk_432 be.uk.ru_222 
  0x23443cec, 0x6e00790c, 0x00000c2d, 0x086e330c,   // ug.kk.ky_644 war.hmn.un_530  sv.un.un_A00 nn.hmn.no_543 
  0x21341212, 0x0a000812, 0x0a070404, 0x1a6b4cec,   // ur.ps.fa_654 uk.mk.un_640  ru.bg.mk_332 wo.ceb.tl_644 
  // [10b0]
  0x19000a2c, 0x27190a0d, 0x5afe3ba0, 0x09002d08,   // pt.gl.un_990 pt.gl.gd_554  so.tlh.sm_322 sk.pl.un_430 
  0x19000a23, 0x2f616e08, 0x3804100c, 0x0d1c090d,   // pt.gl.un_880 hmn.za.su_443  lt.fi.tk_543 hi.mr.ne_554 
  0x02330813, 0x3c114807, 0x19000a0e, 0x1f190a13,   // no.nn.da_665 tt.ro.ug_432  pt.gl.un_550 pt.gl.cy_665 
  0x6e000314, 0x6e4c6004, 0x220e0a55, 0x2d002908,   // nl.hmn.un_660 vo.wo.hmn_332  pt.is.oc_442 sl.sk.un_430 
  // [10c0]
  0x190a22a4, 0x0a001913, 0x49004511, 0x61303ba4,   // oc.pt.gl_433 gl.pt.un_650  ln.to.un_630 so.uz.za_433 
  0x30003d19, 0x4c023808, 0x373c4414, 0x791a6b13,   // ku.uz.un_750 tk.da.wo_443  kk.ug.ba_666 ceb.tl.war_665 
  0x533969a4, 0x3600351a, 0x633f1a0c, 0x79000a14,   // mfe.br.ht_433 tg.ab.un_760  tl.af.sco_543 pt.war.un_660 
  0x010615a0, 0x17001009, 0x790a1912, 0x3c003012,   // un.de.en_322 be.sr.un_440  gl.pt.war_654 uz.ug.un_640 
  // [10d0]
  0x22190a08, 0x33000c07, 0x190b10a0, 0x07003809,   // pt.gl.oc_443 sv.nn.un_420  lt.es.gl_322 tk.bg.un_440 
  0x10190a5a, 0x36190a08, 0x0a000804, 0x30234805,   // pt.gl.lt_553 pt.gl.gn_443  no.pt.un_320 tt.ky.uz_333 
  0x19000a05, 0x0700040d, 0x0800440c, 0x37483cad,   // pt.gl.un_330 ru.bg.un_540  kk.uk.un_530 ug.tt.ba_643 
  0x1c0d09af, 0x0d1c13a7, 0x2300440e, 0x01002418,   // hi.ne.mr_655 bh.mr.ne_532  kk.ky.un_550 yi.iw.un_740 
  // [10e0]
  0x4400231a, 0x3600450c, 0x15001112, 0x09131cad,   // ky.kk.un_760 ln.gn.un_530  ro.un.un_640 mr.bh.hi_643 
  0x35000702, 0x3421120c, 0x12190b02, 0x040830ee,   // bg.tg.un_220 ur.fa.ps_543  es.gl.hu_222 uz.uk.ru_422 
  0x12002108, 0x3c232107, 0x170a0755, 0x09001c0d,   // fa.ur.un_430 fa.ky.ug_432  bg.mk.sr_442 mr.hi.un_540 
  0x37303ca4, 0x181234a0, 0x12000c04, 0x21122804,   // ug.uz.ba_433 ps.ur.ar_322  sv.hu.un_320 sd.ur.fa_332 
  // [10f0]
  0x07384808, 0x0e000404, 0x30002a04, 0x17000a12,   // tt.tk.bg_443 fi.is.un_320  mt.uz.un_320 mk.sr.un_640 
  0x09131c11, 0x0000081c, 0x15170a08, 0x1c001309,   // mr.bh.hi_653 uk.un.un_800  mk.sr.un_443 bh.mr.un_440 
  0x212318a0, 0x253035a4, 0x13000d0d, 0x2b001702,   // ar.ky.fa_322 tg.uz.mn_433  ne.bh.un_540 sr.vi.un_220 
  0x0a00170d, 0x3f400314, 0x18004404, 0x53006307,   // sr.mk.un_540 nl.lb.af_666  kk.ar.un_320 sco.ht.un_420 
  // [1100]
  0x09005c02, 0x4435480c, 0x0b6a28ad, 0x36464c11,   // sa.hi.un_220 tt.tg.kk_543  sw.haw.es_643 wo.qu.gn_653 
  0x63653f07, 0x00004c2d, 0x1f006305, 0x37345d0c,   // af.gv.sco_432 wo.un.un_A00  sco.cy.un_330 ss.xh.st_543 
  0x34007904, 0x171629a4, 0x5a4a6a11, 0x40654c08,   // war.xh.un_320 sl.hr.sr_433  haw.yo.sm_653 wo.gv.lb_443 
  0x32161702, 0x4a50110d, 0x00004a1c, 0x34456507,   // sr.hr.bs_222 ro.fj.yo_554  yo.un.un_800 gv.ln.xh_432 
  // [1110]
  0x3b016311, 0x23001508, 0x1d37780c, 0x794609ee,   // sco.en.so_653 un.ky.un_430  ve.st.la_543 pl.qu.war_422 
  0x63004029, 0x730e30a9, 0x1c5c09ee, 0x58004208,   // lb.sco.un_960 uz.is.ny_544  hi.sa.mr_422 co.om.un_430 
  0x69755f13, 0x24605fa4, 0x79fe0908, 0x06006507,   // tn.nso.mfe_665 tn.vo.eo_433  pl.tlh.war_443 gv.de.un_420 
  0x4d3f0311, 0x1f6550a7, 0x07262408, 0x655709a9,   // nl.af.aa_653 fj.gv.cy_532  eo.ia.it_443 pl.na.gv_544 
  // [1120]
  0x5d1124ad, 0x33080c14, 0x79000908, 0x5300690e,   // eo.ro.ss_643 sv.no.nn_666  pl.war.un_430 mfe.ht.un_550 
  0x09006509, 0x00002e1c, 0x3500fe19, 0x2d03340b,   // gv.pl.un_440 fo.un.un_800  tlh.zu.un_750 xh.nl.sk_542 
  0x2435110c, 0x21003413, 0x48442307, 0x3f402407,   // ro.zu.eo_543 xh.jw.un_650  ky.kk.tt_432 eo.lb.af_432 
  0x1200040d, 0x23184407, 0x3b30210c, 0x1365630c,   // fi.hu.un_540 kk.ar.ky_432  fa.uz.ks_543 sco.gv.et_543 
  // [1130]
  0x1afc0211, 0x09fe5707, 0x0000490f, 0x032c65ec,   // da.zzp.tl_653 na.tlh.pl_432  to.un.un_600 gv.fy.nl_644 
  0x29001f05, 0x1f0c39ec, 0x090306ad, 0x40004d1a,   // cy.sl.un_330 br.sv.cy_644  de.nl.pl_643 aa.lb.un_760 
  0x313425a7, 0x79000929, 0x153f01a4, 0x5e5376ec,   // eu.xh.az_532 pl.war.un_960  en.af.un_433 crs.ht.ts_644 
  0x00001a0f, 0x525efe12, 0x2300440d, 0x2d6229a4,   // tl.un.un_600 tlh.ts.ha_654  kk.ky.un_540 sl.kha.sk_433 
  // [1140]
  0x00005a0f, 0x08000c02, 0x00001124, 0x0c2d0d5a,   // sm.un.un_600 sv.no.un_220  ro.un.un_900 cs.sk.sv_553 
  0x0c131a02, 0x091d29a4, 0x2c65200d, 0x124d29ad,   // tl.et.sv_222 sl.la.pl_433  sq.gv.fy_554 sl.aa.hu_643 
  0x5800300c, 0x0a1707a0, 0x300417a0, 0x170a150c,   // uz.om.un_530 bg.sr.mk_322  sr.ru.uz_322 un.mk.sr_543 
  0x1d12020c, 0x3c233bee, 0x4f061dec, 0x12002104,   // da.hu.la_543 ks.ky.ug_422  la.de.bi_644 fa.ur.un_320 
  // [1150]
  0x13003b12, 0x0d292da0, 0x1c090d0c, 0x32124f07,   // so.et.un_640 sk.sl.cs_322  ne.hi.mr_543 bi.hu.bs_432 
  0x0d00290c, 0x0d002d04, 0x2d0d290c, 0x090d5ca4,   // sl.cs.un_530 sk.cs.un_320  sl.cs.sk_543 sa.ne.hi_433 
  0x3d2130a4, 0x07350a04, 0x28182107, 0x093f13a4,   // uz.fa.ku_433 mk.tg.bg_332  fa.ar.sd_432 et.af.pl_433 
  0x08100408, 0xfc001f04, 0x1b002912, 0x0c003b02,   // ru.be.uk_443 cy.zzp.un_320  sl.tr.un_640 so.sv.un_220 
  // [1160]
  0x0c001608, 0x00005c24, 0x1f003b19, 0x39001304,   // hr.sv.un_430 sa.un.un_900  so.cy.un_750 et.br.un_320 
  0x0400440d, 0x39005304, 0x351504ad, 0x17373604,   // kk.ru.un_540 ht.br.un_320  ru.tg.un_630 ab.ba.sr_332 
  0x02001108, 0x21003b0d, 0x16122907, 0x0d094dec,   // ro.da.un_430 ks.fa.un_540  sl.hu.hr_432 aa.pl.cs_644 
  0x09004f08, 0x4817150c, 0x0d000602, 0x231d29a4,   // bi.pl.un_430 un.sr.tt_543  de.cs.un_220 sl.la.ca_433 
  // [1170]
  0x29624d08, 0x30003505, 0x2d290907, 0x070a1705,   // aa.kha.sl_443 tg.uz.un_330  pl.sl.sk_432 sr.mk.bg_333 
  0x01000902, 0x27003002, 0x34003d05, 0xfe656304,   // pl.en.un_220 uz.gd.un_220  ku.ps.un_330 sco.gv.tlh_332 
  0x3c4423ec, 0x5c005102, 0x4e26560c, 0x07005c08,   // ky.kk.ug_644 kl.sa.un_220  mg.ia.ay_543 sa.it.un_430 
  0x5304460c, 0x18281207, 0x04000804, 0x287318a7,   // qu.fi.ht_543 ur.sd.ar_432  uk.ru.un_320 ga.ny.sw_532 
  // [1180]
  0x30004802, 0x4e00461a, 0x55310504, 0x23443c0c,   // tt.uz.un_220 qu.ay.un_760  fr.az.rw_332 ug.kk.ky_543 
  0x23000504, 0x350810a9, 0x23004207, 0x6b001a0d,   // fr.ca.un_320 be.uk.tg_544  co.ca.un_420 tl.ceb.un_540 
  0x30003504, 0x40063e11, 0x5a044b02, 0x0a00080d,   // tg.uz.un_320 rm.de.lb_653  mi.fi.sm_222 uk.mk.un_540 
  0x00003d42, 0xfc003e2b, 0x06003e0e, 0x30003607,   // ku.un.un_C00 rm.zzp.un_980  rm.de.un_550 ab.uz.un_420 
  // [1190]
  0x40000304, 0x1300380e, 0x32381bee, 0x06403e12,   // nl.lb.un_320 tk.et.un_550  tr.tk.bs_422 rm.lb.de_654 
  0x21003018, 0x0d002504, 0x40000604, 0x02005c19,   // uz.fa.un_740 eu.cs.un_320  de.lb.un_320 sa.da.un_750 
  0x01400307, 0x0b462aa0, 0x3300080d, 0x0600fc1b,   // nl.lb.en_432 mt.qu.es_322  no.nn.un_540 zzp.de.un_770 
  0x1d045ca4, 0x54004c0c, 0x0a001704, 0x2700fc04,   // sa.fi.la_433 wo.ik.un_530  sr.mk.un_320 zzp.gd.un_320 
  // [11a0]
  0x1c5c0d05, 0x0c4006a0, 0xfc000607, 0x403e0613,   // ne.sa.mr_333 de.lb.sv_322  de.zzp.un_420 de.rm.lb_665 
  0x3d2344a0, 0x061dfc05, 0x13005c04, 0xfc000609,   // kk.ky.ku_322 zzp.la.de_333  sa.bh.un_320 de.zzp.un_440 
  0x06004802, 0x00003124, 0x33020807, 0x13000c08,   // tt.de.un_220 az.un.un_900  no.da.nn_432 sv.et.un_430 
  0x07151107, 0x0c330805, 0x2a000214, 0x0a1511a0,   // ro.bg.un_420 no.nn.sv_333  da.mt.un_660 ro.mk.un_320 
  // [11b0]
  0xfc003404, 0x0d00090e, 0x073c300c, 0x3430210d,   // xh.zzp.un_320 hi.ne.un_550  uz.ug.bg_543 fa.uz.ps_554 
  0x08300704, 0x08303508, 0x04301507, 0x4d1dfe0c,   // bg.uz.uk_332 tg.uz.uk_443  un.uz.ru_432 tlh.la.aa_543 
  0x0e2e25ec, 0x3b00101b, 0x33000b1a, 0x733642af,   // eu.fo.is_644 lt.so.un_770  bn.as.un_760 co.gn.ny_655 
  0x1c0d5c0c, 0x52130fa4, 0x18284412, 0x2a04feaf,   // sa.ne.mr_543 lv.et.ha_433  kk.sd.ar_654 tlh.fi.mt_655 
  // [11c0]
  0x330802a4, 0x00005324, 0x30003d1a, 0x2e000e23,   // da.no.nn_433 ht.un.un_900  ku.uz.un_760 is.fo.un_880 
  0x2d0dfe0e, 0x3d002102, 0x3b5778a4, 0x28001219,   // tlh.cs.sk_555 fa.ku.un_220  ve.na.so_433 ur.sd.un_750 
  0x760a0107, 0x58792ead, 0x3700480c, 0x0a303c13,   // en.pt.crs_432 fo.war.om_643  tt.ba.un_530 ug.uz.mk_665 
  0x35441507, 0x3b1f5812, 0x6b681d0c, 0x2348380d,   // un.kk.tg_432 om.cy.so_654  la.ig.ceb_543 tk.tt.ky_554 
  // [11d0]
  0x13003204, 0x2afe5812, 0x071004ee, 0x2c003b07,   // bs.et.un_320 om.tlh.mt_654  ru.be.bg_422 so.fy.un_420 
  0x64001304, 0x42052a07, 0x17090d07, 0x13091c09,   // et.lg.un_320 mt.fr.co_432  cs.pl.sr_432 mr.hi.bh_444 
  0x3b003113, 0x2a0d2ea9, 0x150a075a, 0x04001009,   // az.so.un_650 fo.cs.mt_544  bg.mk.un_553 be.ru.un_440 
  0x44002312, 0x62fe31a4, 0x04000d0d, 0x2d000c0c,   // ky.kk.un_640 az.tlh.kha_433  cs.fi.un_540 sv.sk.un_530 
  // [11e0]
  0x0a00172a, 0x09130d55, 0x3b2afe60, 0x362344a4,   // sr.mk.un_970 ne.bh.hi_442  tlh.mt.so_664 kk.ky.ab_433 
  0x0a2338a7, 0x040a1704, 0x21002805, 0x480804a0,   // tk.ky.mk_532 sr.mk.ru_332  sd.fa.un_330 ru.uk.tt_322 
  0x1800360b, 0x3021125a, 0x36190ba7, 0x35001704,   // gn.ga.un_520 ur.fa.uz_553  es.gl.gn_532 sr.tg.un_320 
  0x21343012, 0x0400150e, 0x12233da7, 0x2123440d,   // uz.ps.fa_654 un.ru.un_550  ku.ky.ur_532 kk.ky.fa_554 
  // [11f0]
  0x34002811, 0x090d13ac, 0x30003b0d, 0x4a001819,   // sw.xh.un_630 bh.ne.hi_632  so.uz.un_540 ga.yo.un_750 
  0x08040702, 0x02005d14, 0x151725a4, 0x08000705,   // bg.ru.uk_222 ss.da.un_660  mn.sr.un_433 bg.uk.un_330 
  0x223b2807, 0x00000f24, 0x52005d04, 0x62006108,   // sw.so.oc_432 lv.un.un_900  ss.ha.un_320 za.kha.un_430 
  0x21003d0d, 0x030f0911, 0x3b466502, 0x30207507,   // ku.fa.un_540 pl.lv.nl_653  gv.qu.so_222 nso.sq.uz_432 
  // [1200]
  0x2c2b6255, 0x0f000923, 0x530976a4, 0x24000121,   // kha.vi.fy_442 pl.lv.un_880  crs.pl.ht_433 iw.yi.un_860 
  0x3b284da6, 0x1d090f11, 0x48003c12, 0x1d000f08,   // aa.sw.so_521 lv.pl.la_653  ug.tt.un_640 lv.la.un_430 
  0x342112ee, 0x0f091d13, 0x38003b07, 0x1821230c,   // ur.fa.ps_422 la.pl.lv_665  so.tk.un_420 ky.fa.ar_543 
  0x1f001308, 0x46003b13, 0x090f690b, 0x25190b02,   // et.cy.un_430 so.qu.un_650  mfe.lv.pl_542 es.gl.eu_222 
  // [1210]
  0x28003b04, 0x3b202805, 0x0f002d1a, 0x1f006314,   // so.sw.un_320 sw.sq.so_333  sk.lv.un_760 sco.cy.un_660 
  0x07000409, 0x620f2d12, 0x18004407, 0x074a1f07,   // ru.bg.un_440 sk.lv.kha_654  kk.ar.un_420 cy.yo.it_432 
  0x150a0713, 0x37004408, 0x211812a0, 0x123421af,   // bg.mk.un_665 kk.ba.un_430  ur.ar.fa_322 fa.ps.ur_655 
  0x2300380c, 0x13000904, 0x12003b0e, 0x0c1304ee,   // tk.ky.un_530 hi.bh.un_320  ks.ur.un_550 fi.et.sv_422 
  // [1220]
  0x08041004, 0x1c0d5ca9, 0x1a000302, 0x1c5c0d07,   // be.ru.uk_332 sa.ne.mr_544  nl.tl.un_220 ne.sa.mr_432 
  0x29321602, 0x171632a9, 0x4950450d, 0x1e1a45ec,   // hr.bs.sl_222 bs.hr.sr_544  ln.fj.to_554 ln.tl.ms_644 
  0x040809ed, 0x00002437, 0x4b4549a9, 0x17003104,   // pl.no.fi_622 yi.un.un_B00  to.ln.mi_544 az.sr.un_320 
  0x4b4e49a9, 0x2f1e1c0d, 0x520245ad, 0xfe5355a0,   // to.ay.mi_544 id.ms.su_554  ln.da.ha_643 rw.ht.tlh_322 
  // [1230]
  0x09362908, 0x25601b0b, 0x15003b02, 0x24002e04,   // sl.gn.pl_443 tr.vo.eu_542  so.un.un_220 fo.eo.un_320 
  0x070a170b, 0x5d494513, 0x0c004309, 0x493002ad,   // sr.mk.bg_542 ln.to.ss_665  ie.sv.un_440 da.uz.to_643 
  0x2545500d, 0x5d50090e, 0x022e0ead, 0x00000106,   // fj.ln.eu_554 pl.fj.ss_555  is.fo.da_643 iw.un.un_400 
  0x00006a1c, 0x31481bee, 0x2512020c, 0x271e1c0d,   // haw.un.un_800 tr.tt.az_422  da.hu.eu_543 id.ms.gd_554 
  // [1240]
  0x02455008, 0x103515a0, 0x52504508, 0x00004b2d,   // fj.ln.da_443 un.tg.be_322  ln.fj.ha_443 mi.un.un_A00 
  0x494e5012, 0x3837440c, 0x35003702, 0x30003121,   // fj.ay.to_654 kk.ba.tk_543  st.zu.un_220 az.uz.un_860 
  0x00004824, 0x50404e12, 0x50024512, 0x4b4937a9,   // tt.un.un_900 ay.lb.fj_654  ln.da.fj_654 st.to.mi_544 
  0x5d353414, 0x25001118, 0x50004e0b, 0x0f37fea6,   // xh.zu.ss_666 ro.mn.un_740  ay.fj.un_520 tlh.st.lv_521 
  // [1250]
  0x04003804, 0x27006519, 0x5e355d60, 0xfa353413,   // tk.fi.un_320 gv.gd.un_750  ss.zu.ts_664 xh.zu.nr_665 
  0x403f67ee, 0x042916a0, 0x4e395713, 0x1f002c08,   // ak.af.lb_422 hr.sl.fi_322  na.br.ay_665 fy.cy.un_430 
  0x30311b07, 0x1f006708, 0x40036507, 0x311b0207,   // tr.az.uz_432 ak.cy.un_430  gv.nl.lb_432 da.tr.az_432 
  0x2a004607, 0x0c003822, 0x3800371b, 0x48004d14,   // qu.mt.un_420 tk.sv.un_870  ba.tk.un_770 aa.tt.un_660 
  // [1260]
  0xfc1f6704, 0x190a65a0, 0x044408a0, 0x6500fe08,   // ak.cy.zzp_332 gv.pt.gl_322  uk.kk.ru_322 tlh.gv.un_430 
  0x340b350c, 0x292f0cee, 0x0f2e0e13, 0x2d00370c,   // zu.es.xh_543 sv.su.sl_422  is.fo.lv_665 st.sk.un_530 
  0x3b3038ad, 0x00004e2d, 0x53733804, 0x183534a6,   // tk.uz.so_643 ay.un.un_A00  tk.ny.ht_332 xh.zu.ga_521 
  0x402d0d08, 0x0efc4604, 0x5c5e21a4, 0x65600255,   // cs.sk.lb_443 qu.zzp.is_332  jw.ts.sa_433 da.vo.gv_442 
  // [1270]
  0x21005c0e, 0x3500110d, 0x34213d07, 0x55fc590d,   // sa.jw.un_550 ro.tg.un_540  ku.fa.ps_432 rn.zzp.rw_554 
  0x42433e0c, 0x1a386b05, 0x1c0d5c09, 0x383b5c12,   // rm.ie.co_543 ceb.tk.tl_333  sa.ne.mr_444 sa.so.tk_654 
  0x33080ea9, 0x29003e02, 0x35002819, 0x0000fc0f,   // is.no.nn_544 rm.sl.un_220  sw.zu.un_750 zzp.un.un_600 
  0x651f39ac, 0x052226a0, 0x1b000912, 0x23374808,   // br.cy.gv_632 ia.oc.fr_322  pl.tr.un_640 tt.ba.ky_443 
  // [1280]
  0x19000b14, 0x53003821, 0x30350212, 0x28595513,   // es.gl.un_660 tk.ht.un_860  da.zu.uz_654 rw.rn.sw_665 
  0x0c0413a0, 0x5300fc05, 0x531524ad, 0x4600fc0d,   // et.fi.sv_322 zzp.ht.un_330  eo.ht.un_630 zzp.qu.un_540 
  0x38005c13, 0x172912a0, 0x083f040c, 0x1b001002,   // sa.tk.un_650 hu.sl.sr_322  fi.af.no_543 lt.tr.un_220 
  0x421dfea4, 0x44153807, 0x3555fc12, 0x1115fc02,   // tlh.la.co_433 tk.kk.un_420  zzp.rw.zu_654 zzp.ro.un_220 
  // [1290]
  0x30005805, 0x00001201, 0x1b53790c, 0x381a5c08,   // om.uz.un_330 hu.un.un_200  war.ht.tr_543 sa.tl.tk_443 
  0x190b4a14, 0x1b00381b, 0x5c204708, 0x47105ead,   // yo.es.gl_666 tk.tr.un_770  sn.sq.sa_443 ts.lt.sn_643 
  0x4300060d, 0x2c001312, 0x47732104, 0x0c001218,   // de.ie.un_540 et.fy.un_640  jw.ny.sn_332 hu.sv.un_740 
  0x1007040c, 0x3c002305, 0x21003405, 0x311b300c,   // ru.bg.be_543 ky.ug.un_330  ps.fa.un_330 uz.tr.az_543 
  // [12a0]
  0x1d423e08, 0x18442313, 0x080415af, 0xfefc1104,   // rm.co.la_443 ky.kk.ar_665  un.ru.uk_655 ro.zzp.tlh_332 
  0x34281213, 0x12182155, 0x5e786eaf, 0x34302160,   // ur.sd.ps_665 fa.ar.ur_442  hmn.ve.ts_655 fa.uz.ps_664 
  0x1936fc10, 0x4a2e18a0, 0x2d4a0e05, 0x48153504,   // zzp.gn.gl_642 ga.fo.yo_322  is.yo.sk_333 tg.tt.un_320 
  0x02000d0c, 0x4a00180c, 0x4f3f0311, 0x234436a6,   // cs.da.un_530 ga.yo.un_530  nl.af.bi_653 ab.kk.ky_521 
  // [12b0]
  0x470a5c0c, 0x44303ca6, 0x35043007, 0x2f1f23a4,   // sa.pt.sn_543 ug.uz.kk_521  uz.ru.tg_432 ca.cy.su_433 
  0x07150408, 0x221179a4, 0x0600600d, 0x3c2344af,   // ru.bg.un_430 war.ro.oc_433  vo.de.un_540 kk.ky.ug_655 
  0x2f4c2313, 0x44004802, 0x76006913, 0x2d001304,   // ca.wo.su_665 tt.kk.un_220  mfe.crs.un_650 et.sk.un_320 
  0x502f49a0, 0x6100230c, 0x0e0210ad, 0x31002c02,   // to.su.fj_322 ca.za.un_530  lt.da.is_643 fy.az.un_220 
  // [12c0]
  0x115a23a0, 0x10003604, 0x2f3923ac, 0x3d1221ec,   // ca.sm.ro_322 ab.be.un_320  ca.br.su_632 fa.ur.ku_644 
  0x04001008, 0x47006407, 0x53002402, 0x2f230a0b,   // be.ru.un_430 lg.sn.un_420  eo.ht.un_220 pt.ca.su_542 
  0x32425cee, 0x11190a08, 0x311b4813, 0x65002504,   // sa.co.bs_422 pt.gl.ro_443  tt.tr.az_665 eu.gv.un_320 
  0x090d5c60, 0x233744ec, 0x40001304, 0x2500110c,   // sa.ne.hi_664 kk.ba.ky_644  et.lb.un_320 ro.eu.un_530 
  // [12d0]
  0x27006402, 0x532f2ba0, 0x490a2308, 0x28211804,   // lg.gd.un_220 vi.su.ht_322  ca.pt.to_443 ar.fa.sd_332 
  0x15383c0c, 0x4b2f6a0b, 0x23474908, 0x35003012,   // ug.tk.un_543 haw.su.mi_542  to.sn.ca_443 uz.tg.un_640 
  0x1f11230c, 0x42002308, 0x1b3873a0, 0x2338480d,   // ca.ro.cy_543 ca.co.un_430  ny.tk.tr_322 tt.tk.ky_554 
  0x0a2f2308, 0x21122808, 0x10351702, 0x481b3813,   // ca.su.pt_443 sd.ur.fa_443  sr.tg.be_222 tk.tr.tt_665 
  // [12e0]
  0x242b3ea7, 0x30002112, 0x040a1008, 0x21001812,   // rm.vi.eo_532 fa.uz.un_640  be.mk.ru_443 ar.fa.un_640 
  0x38002304, 0x443823af, 0x040715a4, 0x04000707,   // ca.tk.un_320 ky.tk.kk_655  un.bg.ru_433 bg.ru.un_420 
  0x33000202, 0x3000210e, 0x21003408, 0x09000d08,   // da.nn.un_220 fa.uz.un_550  ps.fa.un_430 ne.hi.un_430 
  0x0d135ca4, 0x33080205, 0x211e1cee, 0x27001805,   // sa.bh.ne_433 da.no.nn_333  id.ms.jw_422 ga.gd.un_330 
  // [12f0]
  0x230415a0, 0x483736ee, 0x40001804, 0x1800011a,   // un.ru.ky_322 ab.ba.tt_422  ga.lb.un_320 iw.ar.un_760 
  0x595579a0, 0x48230407, 0x2307110c, 0x083504a4,   // war.rw.rn_322 ru.ky.tt_432  ro.bg.ky_543 ru.tg.uk_433 
  0x1c5c0da6, 0x44152505, 0x10000809, 0x65000308,   // ne.sa.mr_521 mn.kk.un_330  uk.be.un_440 nl.gv.un_430 
  0x34001813, 0x34122104, 0x292d0d02, 0x300711ee,   // ar.ps.un_650 fa.ur.ps_332  cs.sk.sl_222 ro.bg.uz_422 
  // [1300]
  0x1f005202, 0x0400151a, 0x17000709, 0x07795204,   // ha.cy.un_220 un.ru.un_760  bg.sr.un_440 ha.war.it_332 
  0x050c1207, 0x05060107, 0x0300fc0c, 0x40061d08,   // hu.sv.fr_432 en.de.fr_432  zzp.nl.un_530 la.de.lb_443 
  0x06000202, 0x10080405, 0x56380d04, 0x1c09130c,   // da.de.un_220 ru.uk.be_333  cs.tk.mg_332 bh.hi.mr_543 
  0x0c081207, 0x56003804, 0x2100120e, 0x07003004,   // hu.no.sv_432 tk.mg.un_320  ur.fa.un_550 uz.it.un_320 
  // [1310]
  0x2d000f02, 0x0000561c, 0x3809560e, 0x44070a02,   // lv.sk.un_220 mg.un.un_800  mg.pl.tk_555 mk.bg.kk_222 
  0x09385605, 0x12002d08, 0x38005609, 0x11630e05,   // mg.tk.pl_333 sk.hu.un_430  mg.tk.un_440 is.sco.ro_333 
  0x07040804, 0x156506ad, 0x3f0612ee, 0x56003808,   // uk.ru.bg_332 de.gv.un_643  hu.de.af_422 tk.mg.un_430 
  0x1b001122, 0x02355da0, 0x18283407, 0x03083f04,   // ro.tr.un_870 ss.zu.da_322  ps.sd.ar_432 af.no.nl_332 
  // [1320]
  0x6b1d01a0, 0x37003c07, 0x766901a9, 0x351711ac,   // en.la.ceb_322 ug.ba.un_420  en.mfe.crs_544 ro.sr.tg_632 
  0x35003f02, 0x084c33a4, 0x17163214, 0x09003804,   // af.zu.un_220 nn.wo.no_433  bs.hr.sr_666 tk.pl.un_320 
  0x4810250c, 0x38000909, 0x35303c55, 0x09382d07,   // mn.be.tt_543 pl.tk.un_440  ug.uz.tg_442 sk.tk.pl_432 
  0x092d0d0e, 0x041708af, 0x09003b07, 0x12002808,   // cs.sk.pl_555 uk.sr.ru_655  so.pl.un_420 sd.ur.un_430 
  // [1330]
  0x483831a0, 0x0c53600d, 0x2d0d1007, 0x080423a0,   // az.tk.tt_322 vo.ht.sv_554  lt.cs.sk_432 ky.ru.uk_322 
  0x0c3b330c, 0x1300392a, 0x033f1007, 0x10001304,   // nn.so.sv_543 br.et.un_970  lt.af.nl_432 et.lt.un_320 
  0x1508300c, 0x13083307, 0x2300250b, 0x393f24a4,   // uz.uk.un_543 nn.no.et_432  mn.ky.un_520 eo.af.br_433 
  0x0d2d4aad, 0x2f0c3308, 0x3f003702, 0x380a2207,   // yo.sk.cs_643 nn.sv.su_443  st.af.un_220 oc.pt.tk_432 
  // [1340]
  0x23170a05, 0x35001514, 0x07150413, 0x080c3355,   // mk.sr.ky_333 un.tg.un_660  ru.bg.un_650 nn.sv.no_442 
  0x190a03ee, 0x18003b05, 0x04073504, 0x080233a0,   // nl.pt.gl_422 so.ga.un_330  tg.bg.ru_332 nn.da.no_322 
  0x0c2120a4, 0x0f002704, 0x03000c02, 0x48003c0d,   // sq.jw.sv_433 gd.lv.un_320  sv.nl.un_220 ug.tt.un_540 
  0x25001522, 0x39330c0c, 0x1c000904, 0x13003312,   // un.mn.un_870 sv.nn.br_543  hi.mr.un_320 nn.et.un_640 
  // [1350]
  0x73333904, 0x27000105, 0x2d002e0d, 0x23001704,   // br.nn.ny_332 en.gd.un_330  fo.sk.un_540 sr.ca.un_320 
  0x1e1979a7, 0x1b000c07, 0x6200201a, 0x10001705,   // war.gl.ms_532 sv.tr.un_420  sq.kha.un_760 sr.lt.un_330 
  0x30003e04, 0x28001807, 0x19336504, 0x33004902,   // rm.uz.un_320 ar.sd.un_420  gv.nn.gl_332 to.nn.un_220 
  0x0a1711ee, 0x33006509, 0x33006502, 0x3d00340c,   // ro.sr.mk_422 gv.nn.un_440  gv.nn.un_220 ps.ku.un_530 
  // [1360]
  0x48153514, 0x1c095c11, 0x65000604, 0x17000813,   // tg.tt.un_660 sa.hi.mr_653  de.gv.un_320 uk.sr.un_650 
  0x46005412, 0x12283bee, 0x31002004, 0x23004407,   // ik.qu.un_640 ks.sd.ur_422  sq.az.un_320 kk.ky.un_420 
  0x00006515, 0x37007321, 0x3778730c, 0x35003014,   // gv.un.un_700 ny.st.un_860  ny.ve.st_543 uz.tg.un_660 
  0x01006508, 0x15005804, 0x21001207, 0x5d353413,   // gv.en.un_430 om.un.un_320  ur.fa.un_420 xh.zu.ss_665 
  // [1370]
  0x12002812, 0x2134280c, 0x443715ad, 0xfa35345a,   // sd.ur.un_640 sd.ps.fa_543  un.ba.kk_643 xh.zu.nr_553 
  0x2800120e, 0x21001813, 0x071708a0, 0x17070aa9,   // ur.sd.un_550 ar.fa.un_650  uk.sr.bg_322 mk.bg.sr_544 
  0x35100811, 0x65001f22, 0x221d5c11, 0x011d65a0,   // uk.be.tg_653 cy.gv.un_870  sa.la.oc_653 gv.la.en_322 
  0x025955ad, 0x582a2202, 0x38311ba0, 0x09003507,   // rw.rn.da_643 oc.mt.om_222  tr.az.tk_322 zu.pl.un_420 
  // [1380]
  0x120c0213, 0x3e005202, 0x656301a0, 0x3f12020c,   // da.sv.hu_665 ha.rm.un_220  en.sco.gv_322 da.hu.af_543 
  0x7900650d, 0x65000920, 0x303c0aa4, 0x46357302,   // gv.war.un_540 pl.gv.un_850  mk.ug.uz_433 ny.zu.qu_222 
  0x48233709, 0x59005513, 0x2a001004, 0x0b3e6008,   // ba.ky.tt_444 rw.rn.un_650  lt.mt.un_320 vo.rm.es_443 
  0x28596707, 0x46653bec, 0x0300571a, 0x00006224,   // ak.rn.sw_432 so.gv.qu_644  na.nl.un_760 kha.un.un_900 
  // [1390]
  0x212f1ca0, 0x06790909, 0x2c3b4ea7, 0x1f026307,   // id.su.jw_322 pl.war.de_444  ay.so.fy_532 sco.da.cy_432 
  0x534c625a, 0x38481b0c, 0x627328a4, 0x5d001f05,   // kha.wo.ht_553 tr.tt.tk_543  sw.ny.kha_433 cy.ss.un_330 
  0x3e572209, 0x5e007819, 0x600f03a9, 0x35301112,   // oc.na.rm_444 ve.ts.un_750  nl.lv.vo_544 ro.uz.tg_654 
  0x5300520d, 0x05002804, 0x384c09a4, 0x0f001004,   // ha.ht.un_540 sw.fr.un_320  pl.wo.tk_433 lt.lv.un_320 
  // [13a0]
  0x34677305, 0x00005e2d, 0x0257080c, 0x644c28a4,   // ny.ak.xh_333 ts.un.un_A00  no.na.da_543 sw.wo.lg_433 
  0x79001a0d, 0x2c004004, 0x4d421f14, 0x1a590907,   // tl.war.un_540 lb.fy.un_320  cy.co.aa_666 pl.rn.tl_432 
  0x10001607, 0x21503b07, 0x10002d08, 0x50006404,   // hr.lt.un_420 so.fj.jw_432  sk.lt.un_430 lg.fj.un_320 
  0x63fe67a4, 0x48100702, 0x49002808, 0x47005513,   // ak.tlh.sco_433 bg.be.tt_222  sw.to.un_430 rw.sn.un_650 
  // [13b0]
  0x3b006307, 0x4400110c, 0x2f001a20, 0x3b000e02,   // sco.so.un_420 ro.kk.un_530  tl.su.un_850 is.so.un_220 
  0x1c000914, 0x30001702, 0x554759a9, 0x3e2c2a05,   // hi.mr.un_660 sr.uz.un_220  rn.sn.rw_544 mt.fy.rm_333 
  0x283555a0, 0x3f000908, 0x07240fad, 0x1c002102,   // rw.zu.sw_322 pl.af.un_430  lv.eo.it_643 jw.id.un_220 
  0x301f6304, 0x44233c0d, 0x15002a07, 0x79484b0c,   // sco.cy.uz_332 ug.ky.kk_554  mt.un.un_420 mi.tt.war_543 
  // [13c0]
  0x040f2d11, 0x40090612, 0x2f3b2111, 0x23303c0c,   // sk.lv.fi_653 de.pl.lb_654  jw.so.su_653 ug.uz.ky_543 
  0x00005d24, 0x4a006413, 0x38442308, 0x2a0e6305,   // ss.un.un_900 lg.yo.un_650  ky.kk.tk_443 sco.is.mt_333 
  0x5e4753a0, 0x2a1e42a0, 0x0000532d, 0x78005e0d,   // ht.sn.ts_322 co.ms.mt_322  ht.un.un_A00 ts.ve.un_540 
  0x25443c07, 0x64002a0c, 0x08003312, 0x4800110b,   // ug.kk.mn_432 mt.lg.un_530  nn.no.un_640 ro.tt.un_520 
  // [13d0]
  0x3c441807, 0x300a17a4, 0x440423ac, 0x64074255,   // ar.kk.ug_432 sr.mk.uz_433  ky.ru.kk_632 co.it.lg_442 
  0x0a15045a, 0x0d002d08, 0x07000a08, 0x44002323,   // ru.mk.un_530 sk.cs.un_430  mk.bg.un_430 ky.kk.un_880 
  0x04302505, 0x2e001814, 0x5c0d0909, 0x0e001808,   // mn.uz.ru_333 ga.fo.un_660  hi.ne.sa_444 ga.is.un_430 
  0x04001705, 0x18192704, 0x342112a4, 0x0600fc12,   // sr.ru.un_330 gd.gl.ga_332  ur.fa.ps_433 zzp.de.un_640 
  // [13e0]
  0x09001c05, 0x0000212d, 0x01002421, 0xfc064304,   // mr.hi.un_330 fa.un.un_A00  yi.iw.un_860 ie.de.zzp_332 
  0x3b1823a4, 0x39601f60, 0x30381508, 0x0a081705,   // ky.ar.ks_433 cy.vo.br_664  un.tk.uz_443 sr.uk.mk_333 
  0x0c0203a0, 0x39001f12, 0x12002814, 0x40000302,   // nl.da.sv_322 cy.br.un_640  sd.ur.un_660 nl.lb.un_220 
  0x1e3861a0, 0x442348ec, 0x03000604, 0x3c2344ad,   // za.tk.ms_322 tt.ky.kk_644  de.nl.un_320 kk.ky.ug_643 
  // [13f0]
  0x2a510aa6, 0x29001004, 0x30121bee, 0x04000709,   // pt.kl.mt_521 lt.sl.un_320  tr.hu.uz_422 bg.ru.un_440 
  0x383161ad, 0x0d0913ee, 0x4f00030d, 0x1c000d0d,   // za.az.tk_643 bh.hi.ne_422  nl.bi.un_540 ne.mr.un_540 
  0x1b00300d, 0x21003008, 0x0d102d07, 0x40fc06ee,   // uz.tr.un_540 uz.fa.un_430  sk.lt.cs_432 de.zzp.lb_422 
  0x06400da7, 0x00002615, 0x0603fca0, 0x173508a4,   // cs.lb.de_532 ia.un.un_700  zzp.nl.de_322 uk.tg.sr_433 
  
  // [1400]
  0x05002c02, 0x0300fc07, 0x13391f12, 0x164832a4,   // fy.fr.un_220 zzp.nl.un_420  cy.br.et_654 bs.tt.hr_433 
  0x29000d0c, 0x1f001304, 0x482b0dee, 0x20003812,   // cs.sl.un_530 et.cy.un_320  cs.vi.tt_422 tk.sq.un_640 
  0x091c5c07, 0x483068a9, 0x353044a0, 0x29000d13,   // sa.mr.hi_432 ig.uz.tt_544  kk.uz.tg_322 cs.sl.un_650 
  0x0d004819, 0x53290d07, 0x170a07ad, 0x18282107,   // tt.cs.un_750 cs.sl.ht_432  bg.mk.sr_643 fa.sd.ar_432 
  // [1410]
  0x28002108, 0x4400230d, 0x48170402, 0x07041514,   // fa.sd.un_430 ky.kk.un_540  ru.sr.tt_222 un.ru.bg_666 
  0x1c130904, 0x15040aa9, 0x34213d12, 0x12005c05,   // hi.bh.mr_332 mk.ru.un_544  ku.fa.ps_654 sa.hu.un_330 
  0x00006406, 0x5500590d, 0x365c640c, 0x3400300c,   // lg.un.un_400 rn.rw.un_540  lg.sa.gn_543 uz.ps.un_530 
  0x25003508, 0x341221ee, 0x5c006405, 0x1c0d0955,   // tg.mn.un_430 fa.ur.ps_422  lg.sa.un_330 hi.ne.mr_442 
  // [1420]
  0x170a0402, 0x6400550e, 0x04000702, 0x5c005508,   // ru.mk.sr_222 rw.lg.un_550  bg.ru.un_220 rw.sa.un_430 
  0x12342104, 0x151707a4, 0x24000904, 0x0e002e04,   // fa.ps.ur_332 bg.sr.un_433  pl.eo.un_320 fo.is.un_320 
  0x13090d09, 0x08001507, 0x6b1a5cee, 0x16000f02,   // ne.hi.bh_444 un.uk.un_420  sa.tl.ceb_422 lv.hr.un_220 
  0x48555cad, 0x5c09130c, 0x38003c21, 0x18000e0b,   // sa.rw.tt_643 bh.hi.sa_543  ug.tk.un_860 is.ga.un_520 
  // [1430]
  0x18000907, 0x13091ca9, 0x31001b08, 0x06480c08,   // pl.ga.un_420 mr.hi.bh_544  tr.az.un_430 sv.tt.de_443 
  0x17151155, 0x3f402e07, 0x07000804, 0x06000a04,   // ro.sr.un_420 fo.lb.af_432  uk.bg.un_320 pt.de.un_320 
  0x5a00270d, 0x10443810, 0x33000805, 0x095c0dad,   // gd.sm.un_540 tk.kk.be_642  no.nn.un_330 ne.sa.hi_643 
  0x12004a07, 0x30353cad, 0x18002807, 0x10000f12,   // yo.hu.un_420 ug.tg.uz_643  sd.ar.un_420 lv.lt.un_640 
  // [1440]
  0x0d003202, 0x1c301e07, 0x4b004904, 0x282c0414,   // bs.cs.un_220 ms.uz.id_432  to.mi.un_320 fi.fy.sw_666 
  0x3100300d, 0x33000807, 0x0000590f, 0x04005908,   // uz.az.un_540 no.nn.un_420  rn.un.un_600 rn.fi.un_430 
  0x69016304, 0x34003513, 0x532c01a0, 0x3b211208,   // sco.en.mfe_332 zu.xh.un_650  en.fy.ht_322 ur.fa.ks_443 
  0x34123012, 0x35003c0c, 0x65060aad, 0x0d107307,   // uz.ur.ps_654 ug.tg.un_530  pt.de.gv_643 ny.lt.cs_432 
  // [1450]
  0x65190a05, 0x46353408, 0x46004e18, 0x40061504,   // pt.gl.gv_333 xh.zu.qu_443  ay.qu.un_740 un.de.lb_332 
  0x35344ea0, 0x080233a4, 0x23443c0d, 0x18001911,   // ay.xh.zu_322 nn.da.no_433  ug.kk.ky_554 gl.ga.un_630 
  0x20001012, 0x00005915, 0x0430150c, 0x330256a0,   // lt.sq.un_640 rn.un.un_700  un.uz.ru_543 mg.da.nn_322 
  0x190b1805, 0x48000a09, 0x00005b15, 0x5c131c0c,   // ga.es.gl_333 mk.tt.un_440  sg.un.un_700 mr.bh.sa_543 
  // [1460]
  0x18000b05, 0x12180ba0, 0x0d001002, 0x12001802,   // es.ga.un_330 es.ga.hu_322  lt.cs.un_220 ga.hu.un_220 
  0x28795207, 0x463534ad, 0x18190b02, 0x32001714,   // ha.war.sw_432 xh.zu.qu_643  es.gl.ga_222 sr.bs.un_660 
  0x04000809, 0x68595513, 0x30000a02, 0x09005c07,   // uk.ru.un_440 rw.rn.ig_665  mk.uz.un_220 sa.hi.un_420 
  0x091c0d0c, 0x380708af, 0x27005608, 0x420e1355,   // ne.mr.hi_543 uk.bg.tk_655  mg.gd.un_430 et.is.co_442 
  // [1470]
  0x19180b08, 0x5c00fc0e, 0x254c3ba9, 0x3c234412,   // es.ga.gl_443 zzp.sa.un_550  so.wo.eu_544 kk.ky.ug_654 
  0x17000207, 0x19460b07, 0x3c3d300d, 0x33020809,   // da.sr.un_420 es.qu.gl_432  uz.ku.ug_554 no.da.nn_444 
  0x0e240fa0, 0x21005502, 0x4305270c, 0x19000204,   // lv.eo.is_322 rw.jw.un_220  gd.fr.ie_543 da.gl.un_320 
  0x1827050d, 0x093b130c, 0x17000a13, 0x5227050c,   // fr.gd.ga_554 et.so.pl_543  mk.sr.un_650 fr.gd.ha_543 
  // [1480]
  0x0e024c0c, 0x04153655, 0x12213da9, 0x5c27180c,   // wo.da.is_543 ab.ru.un_420  ku.fa.ur_544 ga.gd.sa_543 
  0x3b00510e, 0x504b575a, 0x42000104, 0x47100f5a,   // kl.so.un_550 na.mi.fj_553  en.co.un_320 lv.lt.sn_553 
  0x5c224755, 0x1805270c, 0x26050107, 0x0e002e09,   // sn.oc.sa_442 gd.fr.ga_543  en.fr.ia_432 fo.is.un_440 
  0x2227180c, 0x284e4712, 0x23001605, 0x162d09a0,   // ga.gd.oc_543 sn.ay.sw_654  hr.ca.un_330 pl.sk.hr_322 
  // [1490]
  0x184757a4, 0x1b3b1f08, 0x222718a4, 0x2a1f3b0c,   // na.sn.ga_433 cy.so.tr_443  ga.gd.oc_433 so.cy.mt_543 
  0x10000f13, 0x102d0202, 0x0200fc04, 0x00002215,   // lv.lt.un_650 da.sk.lt_222  zzp.da.un_320 oc.un.un_700 
  0x39000211, 0x36635c60, 0x38171505, 0x02150c0d,   // da.br.un_630 sa.sco.gn_664  un.sr.tk_333 sv.da.un_540 
  0x3e5c0fa4, 0x52474bee, 0x4b05185a, 0x1c061eee,   // lv.sa.rm_433 mi.sn.ha_422  ga.fr.mi_553 ms.de.id_422 
  // [14a0]
  0x34002819, 0x23055302, 0x33087909, 0x081004a0,   // sd.ps.un_750 ht.fr.ca_222  war.no.nn_444 ru.be.uk_322 
  0x07000a13, 0x34002113, 0x29001708, 0x2800760d,   // mk.bg.un_650 fa.ps.un_650  sr.sl.un_430 crs.sw.un_540 
  0x2500350d, 0x42000504, 0x281c2fa7, 0x3000121a,   // tg.mn.un_540 fr.co.un_320  su.id.sw_532 ur.uz.un_760 
  0x05001904, 0x012f580b, 0x1f002204, 0x28002104,   // gl.fr.un_320 om.su.en_542  oc.cy.un_320 fa.sd.un_320 
  // [14b0]
  0x15001102, 0x443c1808, 0x0d002904, 0x17000402,   // ro.un.un_220 ar.ug.kk_443  sl.cs.un_320 ru.sr.un_220 
  0x3e005504, 0x2b431d05, 0x2a056907, 0x17000a14,   // rw.rm.un_320 la.ie.vi_333  mfe.fr.mt_432 mk.sr.un_660 
  0x46002504, 0x2a065cee, 0x3e00230e, 0x21002a07,   // eu.qu.un_320 sa.de.mt_422  ca.rm.un_550 mt.jw.un_420 
  0x35152511, 0x1f472aa4, 0x20063904, 0x03003919,   // mn.tg.un_630 mt.sn.cy_433  br.de.sq_332 br.nl.un_750 
  // [14c0]
  0x1f1a6ba4, 0x0f001808, 0x5c476512, 0x122130ad,   // ceb.tl.cy_433 ga.lv.un_430  gv.sn.sa_654 uz.fa.ur_643 
  0x583b2109, 0x27006505, 0x5e2d09a9, 0x0f0339a0,   // jw.so.om_444 gv.gd.un_330  pl.sk.ts_544 br.nl.lv_322 
  0x18004e13, 0x12570414, 0x48443709, 0x03001208,   // ay.ga.un_650 fi.na.hu_666  ba.kk.tt_444 hu.nl.un_430 
  0x58003b23, 0x250448a0, 0x25003902, 0x00000924,   // so.om.un_880 tt.ru.mn_322  br.eu.un_220 pl.un.un_900 
  // [14d0]
  0x18002713, 0x2800210d, 0x1800632b, 0x520e01a4,   // gd.ga.un_650 fa.sd.un_540  sco.ga.un_980 en.is.ha_433 
  0x3700440d, 0x276418a0, 0x34635208, 0x42480fa0,   // kk.ba.un_540 ga.lg.gd_322  ha.sco.xh_443 lv.tt.co_322 
  0x12422c04, 0x655f3705, 0x3b630107, 0x23122805,   // fy.co.hu_332 st.tn.gv_333  en.sco.so_432 sd.ur.ky_333 
  0x0000fc1c, 0x12004304, 0x30343c14, 0x13090dad,   // zzp.un.un_800 ie.hu.un_320  ug.ps.uz_666 ne.hi.bh_643 
  // [14e0]
  0x01006507, 0x155b2a07, 0x25030608, 0x3b00fe0b,   // gv.en.un_420 mt.sg.un_432  de.nl.eu_443 tlh.so.un_520 
  0x3000630e, 0x0f733904, 0x03090d12, 0x061209ad,   // sco.uz.un_550 br.ny.lv_332  cs.pl.nl_654 pl.hu.de_643 
  0x48383c12, 0x1812280d, 0x30003109, 0x0a153004,   // ug.tk.tt_654 sd.ur.ar_554  az.uz.un_440 uz.mk.un_320 
  0x44101504, 0x76006923, 0x69100fa4, 0x341218ad,   // un.be.kk_332 mfe.crs.un_880  lv.lt.mfe_433 ar.ur.ps_643 
  // [14f0]
  0x07170407, 0x101d0107, 0x09400612, 0x21442311,   // ru.sr.bg_432 en.la.lt_432  de.lb.pl_654 ky.kk.fa_653 
  0x3015350e, 0x330208ec, 0x1d001814, 0x37044807,   // tg.uz.un_550 no.da.nn_644  ga.la.un_660 tt.ru.ba_432 
  0xfe001b19, 0x0600fe0c, 0x3c003407, 0x23003c08,   // tr.tlh.un_750 tlh.de.un_530  ps.ug.un_420 ug.ky.un_430 
  0x0e001805, 0x321b20a0, 0x21342855, 0x2a006307,   // ga.is.un_330 sq.tr.bs_322  sd.ps.fa_442 sco.mt.un_420 
  // [1500]
  0x33003e07, 0x28213daf, 0x3d183408, 0x35001508,   // rm.nn.un_420 ku.fa.sd_655  ps.ar.ku_443 un.tg.un_430 
  0x3b004f07, 0x171632a4, 0x08020ca4, 0x1000040c,   // bi.so.un_420 bs.hr.sr_433  sv.da.no_433 ru.be.un_530 
  0x57005922, 0x00004f0a, 0x56002f07, 0x2a651860,   // rn.na.un_870 bi.un.un_500  su.mg.un_420 ga.gv.mt_664 
  0x4b004907, 0x5c1c09ee, 0x3d001207, 0x060c380c,   // to.mi.un_420 hi.mr.sa_422  ur.ku.un_420 tk.sv.de_543 
  // [1510]
  0x7300550d, 0x0c330809, 0x33080255, 0x30002302,   // rw.ny.un_540 no.nn.sv_444  da.no.nn_442 ky.uz.un_220 
  0x09006412, 0x170a0708, 0x557359af, 0xfe005719,   // lg.pl.un_640 bg.mk.sr_443  rn.ny.rw_655 na.tlh.un_750 
  0x12343012, 0x1f311e12, 0x3700300d, 0x38303c11,   // uz.ps.ur_654 ms.az.cy_654  uz.ba.un_540 ug.uz.tk_653 
  0x0000290f, 0x12002919, 0x3700480d, 0x73595513,   // sl.un.un_600 sl.hu.un_750  tt.ba.un_540 rw.rn.ny_665 
  // [1520]
  0x1f066502, 0x131f2704, 0x13576208, 0x27006511,   // gv.de.cy_222 gd.cy.et_332  kha.na.et_443 gv.gd.un_630 
  0x0d091305, 0x38000d07, 0x340e06a0, 0x10321602,   // bh.hi.ne_333 cs.tk.un_420  de.is.xh_322 hr.bs.lt_222 
  0x3e001504, 0x0000690a, 0x04070aa7, 0x283418ec,   // un.rm.un_320 mfe.un.un_500  mk.bg.ru_532 ar.ps.sd_644 
  0x1f006502, 0x00002524, 0x0300250c, 0x21122855,   // gv.cy.un_220 eu.un.un_900  eu.nl.un_530 sd.ur.fa_442 
  // [1530]
  0x6b3e1d55, 0x08002313, 0x122818a7, 0x13000914,   // la.rm.ceb_442 ky.uk.un_650  ar.sd.ur_532 hi.bh.un_660 
  0x0e1f27ad, 0x08300711, 0x17070a02, 0x21343004,   // gd.cy.is_643 bg.uz.uk_653  mk.bg.sr_222 uz.ps.fa_332 
  0x2d00fc02, 0x1b002507, 0x34003b05, 0x25003904,   // zzp.sk.un_220 eu.tr.un_420  so.xh.un_330 br.eu.un_320 
  0x38000f05, 0x15001107, 0x25001219, 0x3548080c,   // lv.tk.un_330 ro.un.un_420  hu.eu.un_750 uk.tt.tg_543 
  // [1540]
  0x1e00201a, 0x34002804, 0x08064007, 0x06000304,   // ti.am.un_760 sd.ps.un_320  lb.de.no_432 nl.de.un_320 
  0x0b461802, 0x12004007, 0x5c001c09, 0x21003d09,   // ga.qu.es_222 lb.hu.un_420  mr.sa.un_440 ku.fa.un_440 
  0x0a1015a0, 0x2700181b, 0x38004805, 0x18003d11,   // un.be.mk_322 ga.gd.un_770  tt.tk.un_330 ku.ar.un_630 
  0x2900fe0c, 0x2a004709, 0x07000813, 0x39000b02,   // tlh.sl.un_530 sn.mt.un_440  uk.bg.un_650 es.br.un_220 
  // [1550]
  0x3d00300d, 0x64473507, 0x27001813, 0x08150404,   // uz.ku.un_540 zu.sn.lg_432  ga.gd.un_650 ru.uk.un_320 
  0x1800270c, 0x234438af, 0x64005502, 0x5e4773af,   // gd.ga.un_530 tk.kk.ky_655  rw.lg.un_220 ny.sn.ts_655 
  0x6b5058ec, 0x64005804, 0x25021855, 0x08004407,   // om.fj.ceb_644 om.lg.un_320  ga.da.eu_442 kk.uk.un_420 
  0x3f2b1802, 0x1b003004, 0x422043a4, 0x1e313012,   // ga.vi.af_222 uz.tr.un_320  ie.sq.co_433 uz.az.ms_654 
  // [1560]
  0x42631da0, 0x3e006505, 0x090d5c0d, 0x253c15ad,   // la.sco.co_322 gv.rm.un_330  sa.ne.hi_554 un.ug.mn_643 
  0x1800280e, 0x31004821, 0x3e006509, 0xfc006412,   // sw.ga.un_550 tt.az.un_860  gv.rm.un_440 lg.zzp.un_640 
  0x080a0711, 0x2a554707, 0x2a3b64ee, 0x00000724,   // bg.mk.uk_653 sn.rw.mt_432  lg.so.mt_422 bg.un.un_900 
  0x17000707, 0x28123b07, 0x07000805, 0x02005b12,   // bg.sr.un_420 ks.ur.sd_432  uk.bg.un_330 sg.da.un_640 
  // [1570]
  0x00003e15, 0x31003013, 0x48000402, 0x3f2f390d,   // rm.un.un_700 uz.az.un_650  fi.tt.un_220 br.su.af_554 
  0x00004c1c, 0x17070a0c, 0x060163ee, 0x13000405,   // wo.un.un_800 mk.bg.sr_543  sco.en.de_422 fi.et.un_330 
  0x02000835, 0x330812a9, 0x76181b08, 0x1f006b04,   // no.da.un_A90 hu.no.nn_544  tr.ga.crs_443 ceb.cy.un_320 
  0x28341812, 0x343b3011, 0x69005319, 0x3b00fe07,   // ar.ps.sd_654 uz.ks.ps_653  ht.mfe.un_750 tlh.so.un_420 
  // [1580]
  0x3e0640ad, 0x65001322, 0x65001e0d, 0x040a15a0,   // lb.de.rm_643 et.gv.un_870  ms.gv.un_540 un.mk.ru_322 
  0x6a33080d, 0x07101505, 0x23003813, 0x3b000102,   // no.nn.haw_554 un.be.bg_333  tk.ky.un_650 en.so.un_220 
  0x0c004c07, 0x4a1f1007, 0x1200181b, 0x21003d07,   // wo.sv.un_420 lt.cy.yo_432  ar.ur.un_770 ku.fa.un_420 
  0x30004c08, 0x033f0c5a, 0x2e3308af, 0x3d2112a0,   // wo.uz.un_430 sv.af.nl_553  no.nn.fo_655 ur.fa.ku_322 
  // [1590]
  0x01006304, 0x321617a9, 0x0c00390d, 0x2e336508,   // sco.en.un_320 sr.hr.bs_544  br.sv.un_540 gv.nn.fo_443 
  0x52005502, 0x063f0314, 0x59553414, 0x100a0802,   // rw.ha.un_220 nl.af.de_666  xh.rw.rn_666 uk.mk.be_222 
  0x2e004c23, 0x1e2e13a7, 0x07002a04, 0x0e2e18af,   // wo.fo.un_880 et.fo.ms_532  mt.it.un_320 ga.fo.is_655 
  0x5e6a3405, 0x0100241a, 0x18002320, 0x5376690d,   // xh.haw.ts_333 yi.iw.un_760  ky.ar.un_850 mfe.crs.ht_554 
  // [15a0]
  0x0400170d, 0x35003611, 0x35346a05, 0x15170408,   // sr.ru.un_540 ab.tg.un_630  haw.xh.zu_333 ru.sr.un_443 
  0x3e00110b, 0x1e001c1b, 0x08043605, 0x38005304,   // ro.rm.un_520 id.ms.un_770  ab.ru.uk_333 ht.tk.un_320 
  0x09357304, 0x64003004, 0x53026904, 0x17150407,   // ny.zu.pl_332 uz.lg.un_320  mfe.da.ht_332 ru.sr.un_420 
  0x53001502, 0x17002904, 0x510f02a0, 0x245530ee,   // un.ht.un_220 sl.sr.un_320  da.lv.kl_322 uz.rw.eo_422 
  // [15b0]
  0x1200180d, 0x393b0c55, 0x2d001702, 0x650c3907,   // ar.ur.un_540 sv.so.br_442  sr.sk.un_220 br.sv.gv_432 
  0x34001207, 0x2453690b, 0x2a005505, 0x31001b02,   // ur.ps.un_420 mfe.ht.eo_542  rw.mt.un_330 tr.az.un_220 
  0x1a536912, 0x23001604, 0x54306905, 0x1c462f0c,   // mfe.ht.tl_654 hr.ca.un_320  mfe.uz.ik_333 su.qu.id_543 
  0x17163210, 0x10000a04, 0x48000a0d, 0x23003c0c,   // bs.hr.sr_642 mk.be.un_320  mk.tt.un_540 ug.ky.un_530 
  // [15c0]
  0x00000901, 0x375f5e05, 0x36483c55, 0x233c44a9,   // pl.un.un_200 ts.tn.st_333  ug.tt.ab_442 kk.ug.ky_544 
  0x221109a0, 0x35340c09, 0x1136350c, 0x2e34fe55,   // pl.ro.oc_322 sv.xh.zu_444  tg.ab.ro_543 tlh.xh.fo_442 
  0x232d1204, 0x342128a9, 0x0c005b12, 0x27314da9,   // hu.sk.ca_332 sd.fa.ps_544  sg.sv.un_640 aa.az.gd_544 
  0x3f03fe55, 0x24001608, 0x37003009, 0x48373c09,   // tlh.nl.af_442 hr.eo.un_430  uz.ba.un_440 ug.ba.tt_444 
  // [15d0]
  0x504a02a4, 0x30003518, 0x384a5711, 0x3534730c,   // da.yo.fj_433 tg.uz.un_740  na.yo.tk_653 ny.xh.zu_543 
  0x30482304, 0x483023a9, 0x34302108, 0x1c003307,   // ky.tt.uz_332 ky.uz.tt_544  fa.uz.ps_443 nn.id.un_420 
  0x353436a4, 0x53003404, 0x38374412, 0x6900532a,   // gn.xh.zu_433 xh.ht.un_320  kk.ba.tk_654 ht.mfe.un_970 
  0x4afc5fee, 0x55002f02, 0x2d3534a7, 0x6400fc04,   // tn.zzp.yo_422 su.rw.un_220  xh.zu.sk_532 zzp.lg.un_320 
  // [15e0]
  0x1c095c07, 0x230411ad, 0x536933a4, 0x1b5c61ee,   // sa.hi.mr_432 ro.ru.ky_643  nn.mfe.ht_433 za.sa.tr_422 
  0x041008af, 0x786837a4, 0x35347309, 0x02002004,   // uk.be.ru_655 st.ig.ve_433  ny.xh.zu_444 sq.da.un_320 
  0x64001219, 0x282118a7, 0x64695eec, 0x3400180c,   // hu.lg.un_750 ar.fa.sd_532  ts.mfe.lg_644 ar.ps.un_530 
  0x04250705, 0x0000171c, 0x123c30a0, 0x25442302,   // bg.mn.ru_333 sr.un.un_800  uz.ug.ur_322 ky.kk.mn_222 
  // [15f0]
  0x38121ba4, 0x09002a04, 0x182834a0, 0x2a6520a4,   // tr.hu.tk_433 mt.pl.un_320  ps.sd.ar_322 sq.gv.mt_433 
  0x08005304, 0x00007624, 0x21003004, 0x041b5c0c,   // ht.no.un_320 crs.un.un_900  uz.fa.un_320 sa.tr.fi_543 
  0x342812a0, 0x24003709, 0x00003424, 0x0800fc05,   // ur.sd.ps_322 st.eo.un_440  xh.un.un_900 zzp.no.un_330 
  0x1a5279a4, 0x1a796ba4, 0x0c003810, 0x1b003619,   // war.ha.tl_433 ceb.war.tl_433  tk.sv.un_620 gn.tr.un_750 
  // [1600]
  0x330802ee, 0x28002309, 0x38004405, 0x183d3bad,   // da.no.nn_422 ky.sd.un_440  kk.tk.un_330 ks.ku.ar_643 
  0x12000e0e, 0x09000104, 0x17003504, 0x3c00301a,   // is.hu.un_550 en.pl.un_320  tg.sr.un_320 uz.ug.un_760 
  0x30000702, 0x1204135a, 0x2a4c1f04, 0x10000819,   // bg.uz.un_220 et.fi.hu_553  cy.wo.mt_332 uk.be.un_750 
  0x0a001602, 0x2718780c, 0xfe060407, 0x44170aa0,   // hr.pt.un_220 ve.ga.gd_543  fi.de.tlh_432 mk.sr.kk_322 
  // [1610]
  0x053f030b, 0x48000408, 0x13001d08, 0x3f001a02,   // nl.af.fr_542 fi.tt.un_430  la.et.un_430 tl.af.un_220 
  0x0a00171a, 0x3e5401ee, 0x644759a4, 0x34003004,   // sr.mk.un_760 en.ik.rm_422  rn.sn.lg_433 uz.ps.un_320 
  0x3c00350e, 0x5c000f05, 0x5955420b, 0x02353409,   // tg.ug.un_550 lv.sa.un_330  co.rw.rn_542 xh.zu.da_444 
  0x483f020c, 0x3b0e04ad, 0x44231860, 0x1900350d,   // da.af.tt_543 fi.is.so_643  ar.ky.kk_664 zu.gl.un_540 
  // [1620]
  0x303538a7, 0x35003019, 0x213418ee, 0x73551105,   // tk.tg.uz_532 uz.tg.un_750  ar.ps.fa_422 ro.rw.ny_333 
  0x081038a7, 0x52595507, 0x0e184dad, 0x482a23a0,   // tk.be.uk_532 rw.rn.ha_432  aa.ga.is_643 ca.mt.tt_322 
  0x044713ee, 0x64353405, 0x1b001307, 0x5d005508,   // et.sn.fi_422 xh.zu.lg_333  et.tr.un_420 rw.ss.un_430 
  0x55640204, 0x5d005504, 0x25025507, 0x39254508,   // da.lg.rw_332 rw.ss.un_320  rw.da.eu_432 ln.eu.br_443 
  // [1630]
  0x092d6512, 0x07170408, 0x3034120c, 0x0a231555,   // gv.sk.pl_654 ru.sr.bg_443  ur.ps.uz_543 un.ky.mk_442 
  0xfc007812, 0x21004605, 0x44002336, 0x4d001222,   // ve.zzp.un_640 qu.jw.un_330  ky.kk.un_AA0 hu.aa.un_870 
  0x30003c0e, 0x0a081708, 0x1f495a0e, 0x15003c08,   // ug.uz.un_550 sr.uk.mk_443  sm.to.cy_555 ug.un.un_430 
  0x491e1ca9, 0x2a002813, 0x281234a9, 0x170738a0,   // id.ms.to_544 sw.mt.un_650  ps.ur.sd_544 tk.bg.sr_322 
  // [1640]
  0x5e004713, 0x2a006813, 0x6a4b1f0d, 0x6a4b4914,   // sn.ts.un_650 ig.mt.un_650  cy.mi.haw_554 to.mi.haw_666 
  0x17380808, 0x2f104a04, 0x2e001219, 0x070a300d,   // uk.tk.sr_443 yo.lt.su_332  hu.fo.un_750 uz.mk.bg_554 
  0x1e1c10a9, 0x00001f2d, 0x041735a9, 0x1d006502,   // lt.id.ms_544 cy.un.un_A00  tg.sr.ru_544 gv.la.un_220 
  0x1f006513, 0x491f5a12, 0x3e221f0c, 0x1b162908,   // gv.cy.un_650 sm.cy.to_654  cy.oc.rm_543 sl.hr.tr_443 
  // [1650]
  0x5cfc020c, 0x50061fa4, 0x3229170b, 0x2e004202,   // da.zzp.sa_543 cy.de.fj_433  sr.sl.bs_542 co.fo.un_220 
  0x02000c04, 0x371708a0, 0x483e11a0, 0x0e2e12af,   // sv.da.un_320 uk.sr.ba_322  ro.rm.tt_322 hu.fo.is_655 
  0x61505c08, 0x5220470b, 0x3e006e13, 0x0400130b,   // sa.fj.za_443 sn.sq.ha_542  hmn.rm.un_650 et.fi.un_520 
  0x3e105aa9, 0x150704af, 0x28181207, 0x504b1fa4,   // sm.lt.rm_544 ru.bg.un_655  ur.ar.sd_432 cy.mi.fj_433 
  // [1660]
  0x4b5a4914, 0x22501f0d, 0xfc002802, 0x221f500c,   // to.sm.mi_666 cy.fj.oc_554  sw.zzp.un_220 fj.cy.oc_543 
  0x484b1307, 0x3e6a49ec, 0x12001305, 0x0e4a52ac,   // et.mi.tt_432 to.haw.rm_644  et.hu.un_330 ha.yo.is_632 
  0x29321607, 0x37004414, 0x00006a0f, 0x183412ee,   // hr.bs.sl_432 kk.ba.un_660  haw.un.un_600 ur.ps.ar_422 
  0x181d07a4, 0x1c0d09ee, 0x20003e04, 0x0700100d,   // it.la.ga_433 hi.ne.mr_422  rm.sq.un_320 be.bg.un_540 
  // [1670]
  0x42003e21, 0x182134a4, 0x10002d0c, 0x6e00781a,   // rm.co.un_860 ps.fa.ar_433  sk.lt.un_530 ve.hmn.un_760 
  0x32171608, 0x00003e24, 0x11000304, 0x0a001713,   // hr.sr.bs_443 rm.un.un_900  nl.ro.un_320 sr.mk.un_650 
  0x072601a0, 0x07170aaf, 0x06007907, 0x5c103e02,   // en.ia.it_322 mk.sr.bg_655  war.de.un_420 rm.lt.sa_222 
  0x09000604, 0x2a61780c, 0x3c002319, 0x35000807,   // de.pl.un_320 ve.za.mt_543  ky.ug.un_750 uk.tg.un_420 
  // [1680]
  0x12003009, 0x5a006504, 0x0000780f, 0x3e1d2502,   // uz.ur.un_440 gv.sm.un_320  ve.un.un_600 eu.la.rm_222 
  0x09005c09, 0x0a0711a4, 0x12000e05, 0x42103e0c,   // sa.hi.un_440 ro.bg.mk_433  is.hu.un_330 rm.lt.co_543 
  0x4448380c, 0x5a0151a0, 0x3f004007, 0x06040307,   // tk.tt.kk_543 kl.en.sm_322  lb.af.un_420 nl.fi.de_432 
  0x3300080e, 0x00003d1c, 0x19000604, 0x2502fc04,   // no.nn.un_550 ku.un.un_800  de.gl.un_320 zzp.da.eu_332 
  // [1690]
  0x242d09ee, 0xfc000304, 0x423954ee, 0x133e5c0b,   // pl.sk.eo_422 nl.zzp.un_320  ik.br.co_422 sa.rm.et_542 
  0x470cfea4, 0x070a48ee, 0x16321711, 0x083538a0,   // tlh.sv.sn_433 tt.mk.bg_422  sr.bs.hr_653 tk.tg.uk_322 
  0x28003b12, 0x12003405, 0x120ffca0, 0x36003c08,   // ks.sd.un_640 ps.ur.un_330  zzp.lv.hu_322 ug.ab.un_430 
  0x15000422, 0x3d213012, 0xfc2401a4, 0x080251a0,   // ru.un.un_870 uz.fa.ku_654  en.eo.zzp_433 kl.da.no_322 
  // [16a0]
  0x44233caf, 0x1dfc5107, 0x3428180c, 0x32171602,   // ug.ky.kk_655 kl.zzp.la_432  ar.sd.ps_543 hr.sr.bs_222 
  0x17000a09, 0xfe00300d, 0x20004604, 0x063f380c,   // mk.sr.un_440 uz.tlh.un_540  qu.sq.un_320 tk.af.de_543 
  0x07041507, 0x1100020d, 0x2c002907, 0x0400080d,   // un.ru.bg_432 da.ro.un_540  sl.fy.un_420 uk.ru.un_540 
  0x18003407, 0x3d001211, 0x1c5c0907, 0x374448ec,   // ps.ar.un_420 ur.ku.un_630  hi.sa.mr_432 tt.kk.ba_644 
  // [16b0]
  0x392205a0, 0x13002904, 0x01fe02a4, 0x430c040d,   // fr.oc.br_322 sl.et.un_320  da.tlh.en_433 fi.sv.ie_554 
  0xfe3b02a4, 0x13000413, 0x3b00130b, 0x2a005207,   // da.so.tlh_433 fi.et.un_650  et.so.un_520 ha.mt.un_420 
  0x00001d0a, 0x5200130c, 0x2900130d, 0x3c001514,   // la.un.un_500 et.ha.un_530  et.sl.un_540 un.ug.un_660 
  0x380948a0, 0x4f1b1d09, 0x07300804, 0x090d1dad,   // tt.pl.tk_322 la.tr.bi_444  uk.uz.bg_332 la.cs.pl_643 
  // [16c0]
  0x30374804, 0x44353007, 0x2a00620e, 0x3500301a,   // tt.ba.uz_332 uz.tg.kk_432  kha.mt.un_550 uz.tg.un_760 
  0x3c001121, 0x0d292d55, 0x4d2a1f08, 0x3831480e,   // ro.ug.un_860 sk.sl.cs_442  cy.mt.aa_443 tt.az.tk_555 
  0x373c4814, 0x09001d04, 0x13000408, 0x00002824,   // tt.ug.ba_666 la.pl.un_320  fi.et.un_430 sd.un.un_900 
  0x28003402, 0x0c001319, 0x040c130b, 0x120d0905,   // ps.sd.un_220 et.sv.un_750  et.sv.fi_542 pl.cs.hu_333 
  // [16d0]
  0x12003d08, 0x0d005c13, 0x5a00fe07, 0x0d001d09,   // ku.ur.un_430 sa.ne.un_650  tlh.sm.un_420 la.cs.un_440 
  0x23000608, 0x12003b21, 0x0900200e, 0x0d2d0907,   // de.ca.un_430 ks.ur.un_860  sq.pl.un_550 pl.sk.cs_432 
  0x253748a0, 0x12000d05, 0x1c0d09ad, 0x0e5a1807,   // tt.ba.mn_322 cs.hu.un_330  hi.ne.mr_643 ga.sm.is_432 
  0x131d5aee, 0x4001060c, 0x181d6aee, 0x1700040e,   // sm.la.et_422 de.en.lb_543  haw.la.ga_422 ru.sr.un_550 
  // [16e0]
  0x34122112, 0x4800130b, 0x08001104, 0x37005f09,   // fa.ur.ps_654 et.tt.un_520  ro.no.un_320 tn.st.un_440 
  0x17151108, 0x373835a0, 0x21003d19, 0x375f1c07,   // ro.sr.un_430 tg.tk.ba_322  ku.fa.un_750 id.tn.st_432 
  0x1132165a, 0x0a292d07, 0x186315ee, 0x39004904,   // hr.bs.ro_553 sk.sl.pt_432  un.sco.ga_422 to.br.un_320 
  0x37755f0c, 0x5f3f0308, 0x15004904, 0x213428ad,   // tn.nso.st_543 nl.af.tn_443  to.un.un_320 sd.ps.fa_643 
  // [16f0]
  0x0d09130e, 0x3844360c, 0x392511a4, 0x4800131a,   // bh.hi.ne_555 ab.kk.tk_543  ro.eu.br_433 et.tt.un_760 
  0x10235aad, 0x3d001212, 0x11002d04, 0x4f5d010c,   // sm.ca.lt_643 ur.ku.un_640  sk.ro.un_320 en.ss.bi_543 
  0x49000e04, 0x3775390c, 0x5624110c, 0x0e231e04,   // is.to.un_320 br.nso.st_543  ro.eo.mg_543 ms.ca.is_332 
  0x6a00680d, 0x33002002, 0x0000262d, 0x245f110c,   // ig.haw.un_540 sq.nn.un_220  ia.un.un_A00 ro.tn.eo_543 
  // [1700]
  0x33000813, 0x1d006a11, 0x480411a4, 0x0a003e02,   // no.nn.un_650 haw.la.un_630  ro.fi.tt_433 rm.pt.un_220 
  0x30361507, 0x2d0d36a4, 0x1d006b07, 0x732168ad,   // un.ab.uz_432 gn.cs.sk_433  ceb.la.un_420 ig.jw.ny_643 
  0x1935340e, 0x0000190a, 0x0400110c, 0x4b006a0d,   // xh.zu.gl_555 gl.un.un_500  ro.ru.un_530 haw.mi.un_540 
  0x1900230c, 0x56000b07, 0x524507a7, 0x191565af,   // ca.gl.un_530 es.mg.un_420  it.ln.ha_532 gv.gl.un_650 
  // [1710]
  0x32001605, 0x3200160e, 0x02006805, 0x27006504,   // hr.bs.un_330 hr.bs.un_550  ig.da.un_330 gv.gd.un_320 
  0x43190bec, 0x0d091309, 0x20330805, 0x34003519,   // es.gl.ie_644 bh.hi.ne_444  no.nn.sq_333 zu.xh.un_750 
  0x2d0d090e, 0x3c003813, 0x1f002f12, 0x47007813,   // pl.cs.sk_555 tk.ug.un_650  su.cy.un_640 ve.sn.un_650 
  0x10452dec, 0x5d477313, 0x09003204, 0x477378ec,   // sk.ln.lt_644 ny.sn.ss_665  bs.pl.un_320 ve.ny.sn_644 
  // [1720]
  0x5e001004, 0x0f5d09ad, 0x321620a0, 0x0d321608,   // lt.ts.un_320 pl.ss.lv_643  sq.hr.bs_322 hr.bs.cs_443 
  0x47000f19, 0x09005d0c, 0x095c1f04, 0x3200161b,   // lv.sn.un_750 ss.pl.un_530  cy.sa.pl_332 hr.bs.un_770 
  0x530976ad, 0x5b783705, 0x09002d19, 0x09004708,   // crs.pl.ht_643 st.ve.sg_333  sk.pl.un_750 sn.pl.un_430 
  0x3b00fc04, 0x11232507, 0x0000190f, 0x342a3bad,   // zzp.so.un_320 eu.ca.ro_432  gl.un.un_600 so.mt.xh_643 
  // [1730]
  0x00001d0f, 0x10004702, 0x21343da9, 0x32171309,   // la.un.un_600 sn.lt.un_220  ku.ps.fa_544 et.sr.bs_444 
  0x08041707, 0x34000907, 0x455e1c07, 0x4b6b7908,   // sr.ru.uk_432 pl.xh.un_420  id.ts.ln_432 war.ceb.mi_443 
  0x13040e0c, 0x0e2c0412, 0x4d0d2aee, 0x47002f02,   // is.fi.et_543 fi.fy.is_654  mt.cs.aa_422 su.sn.un_220 
  0x1737480c, 0x3715040c, 0x04001709, 0x2e0c0e07,   // tt.ba.sr_543 ru.ba.un_530  sr.ru.un_440 is.sv.fo_432 
  // [1740]
  0x63610255, 0x38003b09, 0x1000170e, 0x53006507,   // da.za.sco_442 so.tk.un_440  sr.be.un_550 gv.ht.un_420 
  0x090f47ad, 0x10002108, 0x121b15a4, 0x511304af,   // sn.lv.pl_643 jw.lt.un_430  un.tr.hu_433 fi.et.kl_655 
  0x09001805, 0x5a046507, 0x20321607, 0x10005c08,   // ga.pl.un_330 gv.fi.sm_432  hr.bs.sq_432 sa.lt.un_430 
  0x2e040e0c, 0x5d3534a9, 0x3300081a, 0x0e292ea0,   // is.fi.fo_543 xh.zu.ss_544  no.nn.un_760 fo.sl.is_322 
  // [1750]
  0x584c420c, 0x38003022, 0x2d000207, 0x29002004,   // co.wo.om_543 uz.tk.un_870  da.sk.un_420 sq.sl.un_320 
  0x4d002d1a, 0x09130407, 0x3e314204, 0x3b283d08,   // sk.aa.un_760 fi.et.pl_432  co.az.rm_332 ku.sd.ks_443 
  0x2d0d1605, 0x330801a9, 0x4c0d2d0b, 0x375f75ec,   // hr.cs.sk_333 en.no.nn_544  sk.cs.wo_542 nso.tn.st_644 
  0x3d342813, 0x19460bee, 0x01fc3ba0, 0x18003419,   // sd.ps.ku_665 es.qu.gl_422  so.zzp.en_322 ps.ar.un_750 
  // [1760]
  0x23003019, 0x04002c04, 0x20002204, 0x132e0e09,   // uz.ky.un_750 fy.fi.un_320  oc.sq.un_320 is.fo.et_444 
  0x0d000208, 0x0f001e04, 0x2d0d2aee, 0x024d01a4,   // da.cs.un_430 ms.lv.un_320  mt.cs.sk_422 en.aa.da_433 
  0x170415a0, 0x44001709, 0xfc003807, 0xfc2ffea7,   // un.ru.sr_322 sr.kk.un_440  tk.zzp.un_420 tlh.su.zzp_532 
  0x15301b07, 0x35005c02, 0x15654d04, 0x5f5e3714,   // tr.uz.un_432 sa.zu.un_220  aa.gv.un_332 st.ts.tn_666 
  // [1770]
  0x51182e0c, 0x23100404, 0x1e002012, 0x0a071104,   // fo.ga.kl_543 ru.be.ky_332  ti.am.un_640 ro.bg.mk_332 
  0x1500100e, 0x01002422, 0x1f677908, 0x095c0da0,   // be.un.un_550 yi.iw.un_870  war.ak.cy_443 ne.sa.hi_322 
  0x3d122302, 0x2d000602, 0x342130a4, 0x08001009,   // ky.ur.ku_222 de.sk.un_220  uz.fa.ps_433 be.uk.un_440 
  0x091c13a4, 0x354415a7, 0x69642808, 0x7500031b,   // bh.mr.hi_433 un.kk.tg_532  sw.lg.mfe_443 nl.nso.un_770 
  // [1780]
  0x03001204, 0x035575a6, 0x08003c0d, 0x09fc1207,   // hu.nl.un_320 nso.rw.nl_521  ug.uk.un_540 hu.zzp.pl_432 
  0x06555fa0, 0x12000909, 0x756468a4, 0x1525360c,   // tn.rw.de_322 pl.hu.un_440  ig.lg.nso_433 ab.mn.un_543 
  0x1c095ca4, 0x17070a05, 0x06003f04, 0x55477508,   // sa.hi.mr_433 mk.bg.sr_333  af.de.un_320 nso.sn.rw_443 
  0x21003c02, 0x08373c08, 0x64285504, 0x1044085a,   // ug.fa.un_220 ug.ba.uk_443  rw.sw.lg_332 uk.kk.be_553 
  // [1790]
  0x1200090d, 0x092855ad, 0x15483604, 0x03001212,   // pl.hu.un_540 rw.sw.pl_643  ab.tt.un_332 hu.nl.un_640 
  0x09000304, 0x036455a4, 0x651209ad, 0x07004404,   // nl.pl.un_320 rw.lg.nl_433  pl.hu.gv_643 kk.bg.un_320 
  0x30000802, 0x55007508, 0x09001212, 0x6b1d79a4,   // uk.uz.un_220 nso.rw.un_430  hu.pl.un_640 war.la.ceb_433 
  0x1800211a, 0x0430070c, 0x21001204, 0x5c130d0c,   // fa.ar.un_760 bg.uz.ru_543  ur.fa.un_320 ne.bh.sa_543 
  // [17a0]
  0x04000a02, 0x1000070b, 0x040a0705, 0x321617ee,   // mk.ru.un_220 bg.be.un_520  bg.mk.ru_333 sr.hr.bs_422 
  0x36005719, 0x1200210c, 0x12302104, 0x28122305,   // na.gn.un_750 fa.ur.un_530  fa.uz.ur_332 ky.ur.sd_333 
  0x072335ad, 0x18123ba7, 0x020c0804, 0x4c005009,   // tg.ky.bg_643 ks.ur.ar_532  no.sv.da_332 fj.wo.un_440 
  0x1535380c, 0x04003605, 0x3412300c, 0x4c003f21,   // tk.tg.un_543 gn.fi.un_330  uz.ur.ps_543 af.wo.un_860 
  // [17b0]
  0x52406e11, 0x52001302, 0x3b001c04, 0x4d574004,   // hmn.lb.ha_653 et.ha.un_220  mr.ks.un_320 lb.na.aa_332 
  0x04004404, 0x0c003f04, 0x0e000b02, 0x4c006e09,   // kk.ru.un_320 af.sv.un_320  es.is.un_220 hmn.wo.un_440 
  0x0c080204, 0x123421a4, 0x0a001808, 0x4c004d0d,   // da.no.sv_332 fa.ps.ur_433  ga.pt.un_430 aa.wo.un_540 
  0x150411ec, 0x152315ec, 0x04083607, 0x2000340d,   // ro.ru.un_644 un.ky.un_644  ab.uk.ru_432 xh.sq.un_540 
  // [17c0]
  0x0c000808, 0x08000214, 0x0f0d0304, 0x20153fa7,   // no.sv.un_430 da.no.un_660  nl.cs.lv_332 af.sq.un_520 
  0x64002807, 0x6e004c0e, 0x1c005c07, 0x4c000104,   // sw.lg.un_420 wo.hmn.un_550  sa.mr.un_420 en.wo.un_320 
  0x3f6e4c07, 0x3810480c, 0x17160da0, 0x1c13090c,   // wo.hmn.af_432 tt.be.tk_543  cs.hr.sr_322 hi.bh.mr_543 
  0x11190a04, 0x0a002302, 0x51000104, 0x25330eee,   // pt.gl.ro_332 ca.pt.un_220  en.kl.un_320 is.nn.eu_422 
  // [17d0]
  0x0a081707, 0x2c000e04, 0x060e620c, 0x080c0260,   // sr.uk.mk_432 is.fy.un_320  kha.is.de_543 da.sv.no_664 
  0x270665ee, 0x63022a0b, 0x08000a14, 0x083744a0,   // gv.de.gd_422 mt.da.sco_542  mk.uk.un_660 kk.ba.uk_322 
  0x0800350c, 0x09050407, 0x40000607, 0x4c076509,   // tg.uk.un_530 fi.fr.pl_432  de.lb.un_420 gv.it.wo_444 
  0x1837045a, 0x06003702, 0x44003c1a, 0x1f0e570c,   // fi.st.ga_553 st.de.un_220  ug.kk.un_760 na.is.cy_543 
  // [17e0]
  0x47041808, 0x07173c07, 0x65000c04, 0x18000408,   // ga.fi.sn_443 ug.sr.bg_432  sv.gv.un_320 fi.ga.un_430 
  0x28005c0e, 0x05000412, 0x1c0d1305, 0x5c00281a,   // sa.sw.un_550 fi.fr.un_640  bh.ne.mr_333 sw.sa.un_760 
  0x18005a02, 0x365c2804, 0x5c28360c, 0x27225005,   // sm.ga.un_220 sw.sa.gn_332  gn.sw.sa_543 fj.oc.gd_333 
  0x2c031fad, 0x3e002f02, 0x09000d04, 0x06002e02,   // cy.nl.fy_643 su.rm.un_220  ne.hi.un_320 fo.de.un_220 
  // [17f0]
  0x0633080e, 0x2e0102a0, 0x597328ec, 0x2800470c,   // no.nn.de_555 da.en.fo_322  sw.ny.rn_644 sn.sw.un_530 
  0x270f06a0, 0x2b00220d, 0x0e2e1508, 0x21002b0c,   // de.lv.gd_322 oc.vi.un_540  un.fo.is_443 vi.jw.un_530 
  0x532b2207, 0x0c080208, 0x53002807, 0x1504110c,   // oc.vi.ht_432 da.no.sv_443  sw.ht.un_420 ro.ru.un_543 
  0x59795c12, 0xfc46540c, 0x28041355, 0x22212b09,   // sa.war.rn_654 ik.qu.zzp_543  et.fi.sw_442 vi.jw.oc_444 
  
  // [1800]
  0x36595c12, 0x53002104, 0x5c00591a, 0x281059a4,   // sa.rn.gn_654 jw.ht.un_320  rn.sa.un_760 rn.lt.sw_433 
  0x130d1cad, 0x5c001013, 0x10070402, 0x30544607,   // mr.ne.bh_643 lt.sa.un_650  ru.bg.be_222 qu.ik.uz_432 
  0x0800110d, 0x3d003011, 0x211812af, 0x35000a04,   // ro.uk.un_540 uz.ku.un_630  ur.ar.fa_655 mk.tg.un_320 
  0x22532b0c, 0x0a001720, 0x73353404, 0x0000220f,   // vi.ht.oc_543 sr.mk.un_850  xh.zu.ny_332 oc.un.un_600 
  // [1810]
  0x5c0d1ca4, 0x2544230e, 0x30213408, 0x00007324,   // mr.ne.sa_433 ky.kk.mn_555  ps.fa.uz_443 ny.un.un_900 
  0x082335ec, 0x735c270c, 0x161b2d04, 0x42291b14,   // tg.ky.uk_644 gd.sa.ny_543  sk.tr.hr_332 tr.sl.co_666 
  0x3507040c, 0x181234ee, 0x294c42a9, 0x1144230c,   // ru.bg.tg_543 ps.ur.ar_422  co.wo.sl_544 ky.kk.ro_543 
  0xfc372702, 0x0000fc42, 0x0f001109, 0x32002d04,   // gd.st.zzp_222 zzp.un.un_C00  ro.lv.un_440 sk.bs.un_320 
  // [1820]
  0x1f292d55, 0x0d292d07, 0x0f001604, 0x23003c1a,   // sk.sl.cy_442 sk.sl.cs_432  hr.lv.un_320 ug.ky.un_760 
  0x290c02a0, 0x2d004207, 0x47001205, 0x73003412,   // da.sv.sl_322 co.sk.un_420  hu.sn.un_330 xh.ny.un_640 
  0x32002d07, 0x1f003f05, 0x4d4c4212, 0x2800330c,   // sk.bs.un_420 af.cy.un_330  co.wo.aa_654 nn.sw.un_530 
  0x1800300c, 0x0d2d0912, 0x65005c1a, 0x2100340e,   // uz.ar.un_530 pl.sk.cs_654  sa.gv.un_760 ps.fa.un_550 
  // [1830]
  0x15040812, 0x532b3f02, 0x0e2e1f07, 0x35002b02,   // uk.ru.un_654 af.vi.ht_222  cy.fo.is_432 vi.zu.un_220 
  0x442318af, 0x2d1b29a4, 0x070410a0, 0x34003522,   // ar.ky.kk_655 sl.tr.sk_433  be.ru.bg_322 zu.xh.un_870 
  0x05003918, 0x555d3502, 0x09004602, 0x21123d08,   // br.fr.un_740 zu.ss.rw_222  qu.pl.un_220 ku.ur.fa_443 
  0x44003c23, 0x11002907, 0x1f000f0c, 0x0a1d11a4,   // ug.kk.un_880 sl.ro.un_420  lv.cy.un_530 ro.la.pt_433 
  // [1840]
  0x6a003308, 0x42002d04, 0x42001123, 0x20002a13,   // nn.haw.un_430 sk.co.un_320  ro.co.un_880 mt.sq.un_650 
  0x39003408, 0x442335a4, 0x39011f04, 0x28345904,   // xh.br.un_430 tg.ky.kk_433  cy.en.br_332 rn.xh.sw_332 
  0x39651fa0, 0x376a4960, 0x53fe3f04, 0x1e1c57ec,   // cy.gv.br_322 to.haw.st_664  af.tlh.ht_332 na.id.ms_644 
  0xfc000c0d, 0x50004908, 0x53fc2807, 0x346a1da0,   // sv.zzp.un_540 to.fj.un_430  sw.zzp.ht_432 la.haw.xh_322 
  // [1850]
  0x47002008, 0x1037080c, 0xfc005720, 0x4b49500d,   // sq.sn.un_430 uk.ba.be_543  na.zzp.un_850 fj.to.mi_554 
  0x1c1d2655, 0x30150a04, 0x59651f0c, 0x3749560b,   // ia.la.id_442 mk.uz.un_320  cy.gv.rn_543 mg.to.st_542 
  0x24395f07, 0x0000402d, 0x2a34450c, 0x090d1caf,   // tn.br.eo_432 lb.un.un_A00  ln.xh.mt_543 mr.ne.hi_655 
  0x30004413, 0x0d1c5c04, 0x44233cad, 0x0c0217a4,   // kk.uz.un_650 sa.mr.ne_332  ug.ky.kk_643 sr.da.sv_433 
  // [1860]
  0x0a242612, 0x4c07450d, 0x3d341202, 0x6b0957ad,   // ia.eo.pt_654 ln.it.wo_554  ur.ps.ku_222 na.pl.ceb_643 
  0x19000108, 0x4c0165a0, 0x281102ee, 0x18001202,   // en.gl.un_430 gv.en.wo_322  da.ro.sw_422 ur.ar.un_220 
  0x56494507, 0x47352104, 0x49001d07, 0x34391da0,   // ln.to.mg_432 jw.zu.sn_332  la.to.un_420 la.br.xh_322 
  0x24110f0c, 0x074919a0, 0x3d003b14, 0x030534a0,   // lv.ro.eo_543 gl.to.it_322  ks.ku.un_660 xh.fr.nl_322 
  // [1870]
  0x44003c0c, 0x041535a0, 0x02001209, 0x2e000e19,   // ug.kk.un_530 tg.ru.un_320  hu.da.un_440 is.fo.un_750 
  0x151d0304, 0x084823a4, 0x0e000c04, 0x03001207,   // nl.la.un_332 ky.tt.uk_433  sv.is.un_320 hu.nl.un_420 
  0x3e005e02, 0x23431908, 0x08041055, 0x15001512,   // ts.rm.un_220 gl.ie.ca_443  be.ru.uk_442 un.un.un_640 
  0x34001209, 0x0000352d, 0x32001712, 0x10000808,   // ur.ps.un_440 tg.un.un_A00  sr.bs.un_640 no.lt.un_430 
  // [1880]
  0x2a420704, 0x35302507, 0x1d2205ee, 0x29321608,   // it.co.mt_332 mn.uz.tg_432  fr.oc.la_422 hr.bs.sl_443 
  0x44003c0d, 0x23384455, 0x091c0d13, 0x30002305,   // ug.kk.un_540 kk.tk.ky_442  ne.mr.hi_665 ky.uz.un_330 
  0x3d002107, 0x1c091309, 0x34212304, 0x07170a04,   // fa.ku.un_420 bh.hi.mr_444  ky.fa.ps_332 mk.sr.bg_332 
  0x04081004, 0x341828a4, 0x063e0daf, 0x0b0c4705,   // be.uk.ru_332 sd.ar.ps_433  cs.rm.de_655 sn.sv.es_333 
  // [1890]
  0x0b0c13a4, 0x19460ba0, 0x23000a05, 0x3b001213,   // et.sv.es_433 es.qu.gl_322  mk.ky.un_330 ur.ks.un_650 
  0x0a0c1e04, 0x23000d02, 0x443c23a4, 0x2e2d0d04,   // ms.sv.pt_332 cs.ca.un_220  ky.ug.kk_433 cs.sk.fo_332 
  0x3b003102, 0x135c0d0c, 0x5c1c0955, 0x10041704,   // az.so.un_220 ne.sa.bh_543  hi.mr.sa_442 sr.ru.be_332 
  0x4400232c, 0x0a1707a4, 0x1c022b05, 0x48001b21,   // ky.kk.un_990 bg.sr.mk_433  vi.da.id_333 tr.tt.un_860 
  // [18a0]
  0x193e0ba7, 0x34182855, 0x2128120c, 0x28343055,   // es.rm.gl_532 sd.ar.ps_442  ur.sd.fa_543 uz.ps.sd_442 
  0x07001707, 0x122118ad, 0x00006a15, 0x0a181d04,   // sr.bg.un_420 ar.fa.ur_643  haw.un.un_700 la.ga.pt_332 
  0x190a01a0, 0x33080602, 0x30070aa6, 0x5e001009,   // en.pt.gl_322 de.no.nn_222  mk.bg.uz_521 lt.ts.un_440 
  0x08041504, 0x4c0c65ad, 0x30003418, 0x1d002308,   // un.ru.uk_332 gv.sv.wo_643  ps.uz.un_740 ca.la.un_430 
  // [18b0]
  0x15006502, 0x02240ca0, 0x123421ac, 0x0c02650c,   // gv.un.un_220 sv.eo.da_322  fa.ps.ur_632 gv.da.sv_543 
  0x0a041002, 0x18006e07, 0x07170aa9, 0x190a010c,   // be.ru.mk_222 hmn.ga.un_420  mk.sr.bg_544 en.pt.gl_543 
  0x40001f04, 0x5a066507, 0x754e370c, 0x01fc1802,   // cy.lb.un_320 gv.de.sm_432  st.ay.nso_543 ga.zzp.en_222 
  0x23004805, 0x64375f0c, 0x3400200c, 0x255c4807,   // tt.ky.un_330 tn.st.lg_543  sq.xh.un_530 tt.sa.eu_432 
  // [18c0]
  0x24000307, 0x03000807, 0x0c000220, 0x0c003802,   // nl.eo.un_420 no.nl.un_420  da.sv.un_850 tk.sv.un_220 
  0x36646507, 0x11070a14, 0x5f007513, 0x48003707,   // gv.lg.gn_432 mk.bg.ro_666  nso.tn.un_650 ba.tt.un_420 
  0x07374802, 0x010612a0, 0x48381b55, 0x53006407,   // tt.ba.bg_222 hu.de.en_322  tr.tk.tt_442 lg.ht.un_420 
  0x5c000d0e, 0x35002508, 0x4800371b, 0x24002507,   // ne.sa.un_550 mn.tg.un_430  ba.tt.un_770 eu.eo.un_420 
  // [18d0]
  0x65153804, 0x481530ee, 0x07150107, 0x245a6511,   // tk.gv.un_320 uz.tt.un_420  en.it.un_420 gv.sm.eo_653 
  0x6551050d, 0x65003304, 0x37005f1a, 0x0c650205,   // fr.kl.gv_554 nn.gv.un_320  tn.st.un_760 da.gv.sv_333 
  0x28494b09, 0x04003705, 0x19000b11, 0x0400131a,   // mi.to.sw_444 ba.ru.un_330  es.gl.un_630 et.fi.un_760 
  0x5d1cfe0c, 0x2000fe04, 0x311d3007, 0x46001d07,   // tlh.id.ss_543 tlh.sq.un_320  uz.la.az_432 la.qu.un_420 
  // [18e0]
  0x796b1a0d, 0x5c0f4bec, 0x11001604, 0x25004407,   // tl.ceb.war_554 mi.lv.sa_644  hr.ro.un_320 kk.mn.un_420 
  0x3e32fe0c, 0x00005c2d, 0x06122514, 0x3806fea7,   // tlh.bs.rm_543 sa.un.un_A00  eu.hu.de_666 tlh.de.tk_532 
  0x462f02a0, 0x04350a05, 0x0d1c5c0d, 0x28185155,   // da.su.qu_322 mk.tg.ru_333  sa.mr.ne_554 kl.ga.sw_442 
  0x07000a1b, 0xfe000f1b, 0x38595508, 0x09001c1b,   // mk.bg.un_770 lv.tlh.un_770  rw.rn.tk_443 mr.hi.un_770 
  // [18f0]
  0x2924fead, 0x294dfea7, 0xfe021e07, 0x6a04130c,   // tlh.eo.sl_643 tlh.aa.sl_532  ms.da.tlh_432 et.fi.haw_543 
  0x30353c12, 0x583f0e11, 0x5c571da7, 0x00005e0f,   // ug.tg.uz_654 is.af.om_653  la.na.sa_532 ts.un.un_600 
  0x46005204, 0x652251a4, 0x58fe0612, 0x25004314,   // ha.qu.un_320 kl.oc.gv_433  de.tlh.om_654 ie.eu.un_660 
  0x233035af, 0x18003c02, 0x20002d02, 0x322efe0c,   // tg.uz.ky_655 ug.ar.un_220  sk.sq.un_220 tlh.fo.bs_543 
  // [1900]
  0x0c00600c, 0x06003402, 0xfe654e13, 0x133e51ee,   // vo.sv.un_530 xh.de.un_220  ay.gv.tlh_665 kl.rm.et_422 
  0x370423a4, 0x5100010d, 0x25004002, 0x1c4dfea7,   // ky.ru.ba_433 en.kl.un_540  lb.eu.un_220 tlh.aa.id_532 
  0x2000fe12, 0x102311af, 0x46fe4d12, 0x44003704,   // tlh.sq.un_640 ro.ky.be_655  aa.tlh.qu_654 ba.kk.un_320 
  0x5c000d08, 0x170435a0, 0x091c0d04, 0x3d1221ad,   // ne.sa.un_430 tg.ru.sr_322  ne.mr.hi_332 fa.ur.ku_643 
  // [1910]
  0x23000a09, 0x2d0e2eee, 0x1515370c, 0x34002808,   // mk.ky.un_440 fo.is.sk_422  ba.un.un_530 sd.ps.un_430 
  0x44483708, 0x35287309, 0x18443c07, 0x37755fa9,   // ba.tt.kk_443 ny.sw.zu_444  ug.kk.ar_432 tn.nso.st_544 
  0x48001b13, 0x483744af, 0x35375355, 0x3f3567a4,   // tr.tt.un_650 kk.ba.tt_655  ht.st.zu_442 ak.zu.af_433 
  0x3f0640a4, 0x06615d05, 0x303c380d, 0x180e2ea0,   // lb.de.af_433 ss.za.de_333  tk.ug.uz_554 fo.is.ga_322 
  // [1920]
  0x170a0709, 0x5573570c, 0x38311b09, 0x0f000d08,   // bg.mk.sr_444 na.ny.rw_543  tr.az.tk_444 cs.lv.un_430 
  0x02002e04, 0x23001507, 0x65382e11, 0x3d213407,   // fo.da.un_320 un.ky.un_420  fo.tk.gv_653 ps.fa.ku_432 
  0xfa353414, 0x345d35a4, 0x07000a14, 0x3b355e55,   // xh.zu.nr_666 zu.ss.xh_433  mk.bg.un_660 ts.zu.so_442 
  0x233c4413, 0x153704a4, 0x00005d15, 0x402c4da9,   // kk.ug.ky_665 ru.ba.un_433  ss.un.un_700 aa.fy.lb_544 
  // [1930]
  0x3c2134ee, 0xfc00781a, 0x652c0312, 0x475f060c,   // ps.fa.ug_422 ve.zzp.un_760  nl.fy.gv_654 de.tn.sn_543 
  0x311b3808, 0x5f5d3509, 0x03003308, 0x53006912,   // tk.tr.az_443 zu.ss.tn_444  nn.nl.un_430 mfe.ht.un_640 
  0xfe003119, 0x01630807, 0x28211208, 0x30482e0c,   // az.tlh.un_750 no.sco.en_432  ur.fa.sd_443 fo.tt.uz_543 
  0x17003207, 0x1c0d5c07, 0xfc006012, 0x00002c2d,   // bs.sr.un_420 sa.ne.mr_432  vo.zzp.un_640 fy.un.un_A00 
  // [1940]
  0x22001f0c, 0x0e001804, 0x354a6805, 0x010665a0,   // cy.oc.un_530 ga.is.un_320  ig.yo.zu_333 gv.de.en_322 
  0x0d005c19, 0x3700480e, 0x4c006318, 0x79620104,   // sa.ne.un_750 tt.ba.un_550  sco.wo.un_740 en.kha.war_332 
  0x3e000104, 0x2300430d, 0x2c0353a0, 0x090d5c0c,   // en.rm.un_320 ie.ca.un_540  ht.nl.fy_322 sa.ne.hi_543 
  0x5e396204, 0x3d3c280c, 0x183c23ad, 0x21001c02,   // kha.br.ts_332 sd.ug.ku_543  ky.ug.ar_643 id.jw.un_220 
  // [1950]
  0x18392707, 0x73095208, 0x37442307, 0x6a78730c,   // gd.br.ga_432 ha.pl.ny_443  ky.kk.ba_432 ny.ve.haw_543 
  0x1e002008, 0x30003c0d, 0x30123405, 0x180163a0,   // ti.am.un_430 ug.uz.un_540  ps.ur.uz_333 sco.en.ga_322 
  0x0000672d, 0x03132904, 0x16003004, 0x527309a4,   // ak.un.un_A00 sl.et.nl_332  uz.hr.un_320 pl.ny.ha_433 
  0x0e042e04, 0x52380912, 0x1f000408, 0x3e1801a0,   // fo.fi.is_332 pl.tk.ha_654  fi.cy.un_430 en.ga.rm_322 
  // [1960]
  0x043937a0, 0x52000904, 0x38095208, 0x0438620c,   // st.br.fi_322 pl.ha.un_320  ha.pl.tk_443 kha.tk.fi_543 
  0x0900640e, 0x04620211, 0x1f04380c, 0x0c001f08,   // lg.pl.un_550 da.kha.fi_653  tk.fi.cy_543 cy.sv.un_430 
  0x2100120c, 0x20656207, 0x7938090d, 0x52007308,   // ur.fa.un_530 kha.gv.sq_432  pl.tk.war_554 ny.ha.un_430 
  0x04081508, 0x4c003413, 0x0a0717ad, 0x09005213,   // un.uk.ru_443 xh.wo.un_650  sr.bg.mk_643 ha.pl.un_650 
  // [1970]
  0x13394f08, 0x13005c08, 0x37520908, 0x12003b13,   // bi.br.et_443 sa.bh.un_430  pl.ha.st_443 ks.ur.un_650 
  0x57097308, 0x73001c04, 0x5c00490d, 0x6a0f5cad,   // ny.pl.na_443 id.ny.un_320  to.sa.un_540 sa.lv.haw_643 
  0x6500040d, 0x10003f04, 0x110a1308, 0x2065620c,   // fi.gv.un_540 af.lt.un_320  et.pt.ro_443 kha.gv.sq_543 
  0x095c0da4, 0x1a1f2655, 0x095c0da7, 0x28344407,   // ne.sa.hi_433 ia.cy.tl_442  ne.sa.hi_532 kk.ps.sd_432 
  // [1980]
  0x380462ac, 0x0f005c09, 0x48443807, 0x2c004007,   // kha.fi.tk_632 sa.lv.un_440  tk.kk.tt_432 lb.fy.un_420 
  0x0e1218ee, 0x08000708, 0x583b51a4, 0x2834180e,   // ga.hu.is_422 bg.uk.un_430  kl.so.om_433 ar.ps.sd_555 
  0x640451a9, 0x533f03ac, 0x233c440c, 0x47583bad,   // kl.fi.lg_544 nl.af.ht_632  kk.ug.ky_543 so.om.sn_643 
  0x04643ba7, 0x0f495cee, 0x0f005c14, 0x0000580f,   // so.lg.fi_532 sa.to.lv_422  sa.lv.un_660 om.un.un_600 
  // [1990]
  0x58003b22, 0x5c000f14, 0x355d340c, 0x3b005122,   // so.om.un_870 lv.sa.un_660  xh.ss.zu_543 kl.so.un_870 
  0x583b68af, 0x3b00241a, 0x11002308, 0x28211205,   // ig.so.om_655 eo.so.un_760  ky.ro.un_430 ur.fa.sd_333 
  0x5a00280d, 0x48002307, 0x5a7927a4, 0x3f005a05,   // sw.sm.un_540 ky.tt.un_420  gd.war.sm_433 sm.af.un_330 
  0x3515040c, 0x372344a0, 0x3600230e, 0x643424a0,   // ru.tg.un_530 kk.ky.ba_322  ky.ab.un_550 eo.xh.lg_322 
  // [19a0]
  0x3b006404, 0x510413a4, 0x0000500f, 0x2c003b13,   // lg.so.un_320 et.fi.kl_433  fj.un.un_600 so.fy.un_650 
  0x583b6409, 0x15000404, 0x5a5c4911, 0x58133b0c,   // lg.so.om_444 ru.un.un_320  to.sa.sm_653 so.et.om_543 
  0x0d1219ee, 0x5142fc08, 0x64515812, 0x12353402,   // gl.hu.cs_422 zzp.co.kl_443  om.kl.lg_654 xh.zu.hu_222 
  0x130451ac, 0x28353405, 0x5c000f09, 0x51583ba7,   // kl.fi.et_632 xh.zu.sw_333  lv.sa.un_440 so.om.kl_532 
  // [19b0]
  0x23004809, 0x23353c07, 0x1b001108, 0x2d000d0b,   // tt.ky.un_440 ug.tg.ky_432  ro.tr.un_430 cs.sk.un_520 
  0x0a255a0c, 0x27255112, 0x18003008, 0x6e255aa4,   // sm.eu.pt_543 kl.eu.gd_654  uz.ar.un_430 sm.eu.hmn_433 
  0x37483cec, 0x514205a0, 0x17003507, 0x23002513,   // ug.tt.ba_644 fr.co.kl_322  tg.sr.un_420 mn.ky.un_650 
  0x21003409, 0xfe375faf, 0x281821ee, 0x383c23ad,   // ps.fa.un_440 tn.st.tlh_655  fa.ar.sd_422 ky.ug.tk_643 
  // [19c0]
  0x44230aa4, 0x101737ee, 0x375e5f12, 0x04170aa0,   // mk.ky.kk_433 ba.sr.be_422  tn.ts.st_654 mk.sr.ru_322 
  0xfa005f14, 0x3c00230c, 0x22002314, 0x172307a0,   // tn.nr.un_660 ky.ug.un_530  ca.oc.un_660 bg.ky.sr_322 
  0x5e00fe1a, 0x0800150e, 0x22001805, 0x23192212,   // tlh.ts.un_760 un.uk.un_550  ga.oc.un_330 oc.gl.ca_654 
  0x1c0d09a0, 0x2e002d04, 0x180e2208, 0x0e002e23,   // hi.ne.mr_322 sk.fo.un_320  oc.is.ga_443 fo.is.un_880 
  // [19d0]
  0x0e2218a7, 0x3d003036, 0x12213014, 0x370d5504,   // ga.oc.is_532 uz.ku.un_AA0  uz.fa.ur_666 rw.cs.st_332 
  0x34303d12, 0x2d642507, 0x2d0d29a0, 0x182322ee,   // ku.uz.ps_654 eu.lg.sk_432  sl.cs.sk_322 oc.ca.ga_422 
  0x4800110d, 0x5500350d, 0x59553405, 0x18001213,   // ro.tt.un_540 zu.rw.un_540  xh.rw.rn_333 hu.ga.un_650 
  0x286434a0, 0x1800121a, 0x53733502, 0x3807170c,   // xh.lg.sw_322 hu.ga.un_760  zu.ny.ht_222 sr.bg.tk_543 
  // [19e0]
  0x5d00190c, 0x5500640e, 0x23003d13, 0x0e192e0d,   // gl.ss.un_530 lg.rw.un_550  ku.ky.un_650 fo.gl.is_554 
  0x18005d04, 0x0d091314, 0x50004207, 0x230e2207,   // ss.ga.un_320 bh.hi.ne_666  co.fj.un_420 oc.is.ca_432 
  0x3800362b, 0x09135c04, 0x234a220c, 0x4400250b,   // ab.tk.un_980 sa.bh.hi_332  oc.yo.ca_543 mn.kk.un_520 
  0x1c001314, 0x0723385a, 0x182322a0, 0x1d045404,   // bh.mr.un_660 tk.ky.bg_553  oc.ca.ga_322 ik.fi.la_332 
  // [19f0]
  0x5000230b, 0x34303d0b, 0x12001912, 0x10005109,   // ca.fj.un_520 ku.uz.ps_542  gl.hu.un_640 kl.lt.un_440 
  0x64005507, 0x0000420a, 0x59005522, 0x1912180b,   // rw.lg.un_420 co.un.un_500  rw.rn.un_870 ga.hu.gl_542 
  0x353473a4, 0x12001819, 0x10005504, 0x182d0d1a,   // ny.xh.zu_433 ar.ur.un_750  rw.lt.un_320 cs.sk.ga_776 
  0x48153ca9, 0x122d0d14, 0x27374955, 0x122d0d12,   // ug.tt.un_540 cs.sk.hu_666  to.st.gd_442 cs.sk.hu_654 
  // [1a00]
  0x08650255, 0x123e6511, 0x443c230e, 0x120d2d0c,   // da.gv.no_442 gv.rm.hu_653  ky.ug.kk_555 sk.cs.hu_543 
  0x5c001308, 0x041535ee, 0x0b000a05, 0x63006512,   // bh.sa.un_430 tg.ru.un_420  pt.es.un_330 gv.sco.un_640 
  0x6a5c490c, 0x122d0d0e, 0x30211c07, 0x30083c08,   // to.sa.haw_543 cs.sk.hu_555  id.jw.uz_432 ug.uk.uz_443 
  0x3f026304, 0x0c5c3f04, 0x65002702, 0x0c1101a0,   // sco.da.af_332 af.sa.sv_332  gd.gv.un_220 en.ro.sv_322 
  // [1a10]
  0x2f003f04, 0x482315a0, 0x1d22060c, 0x151806a7,   // af.su.un_320 un.ky.tt_322  de.oc.la_543 de.ga.un_532 
  0x5c000f0d, 0x122f6504, 0x30153804, 0x1d11540c,   // lv.sa.un_540 gv.su.hu_332  tk.uz.un_320 ik.ro.la_543 
  0x51005c13, 0x42006519, 0x5100fc1b, 0x353011a0,   // sa.kl.un_650 gv.co.un_750  zzp.kl.un_770 ro.uz.tg_322 
  0x10153507, 0x65000508, 0x1c003007, 0x0d2d1207,   // tg.be.un_420 fr.gv.un_430  uz.id.un_420 hu.sk.cs_432 
  // [1a20]
  0x1505fe04, 0x070415a0, 0x5c0d0905, 0x0e512ea0,   // tlh.fr.un_332 un.ru.bg_322  hi.ne.sa_333 fo.kl.is_322 
  0x120d2da9, 0x2e335c04, 0x222305a9, 0x42030555,   // sk.cs.hu_544 sa.nn.fo_332  fr.ca.oc_544 fr.nl.co_442 
  0x0c255107, 0x32163f07, 0x1c005c0e, 0x64190b04,   // kl.eu.sv_432 af.hr.bs_432  sa.mr.un_550 es.gl.lg_332 
  0x0601650b, 0x252365a9, 0x3e11230c, 0x5c000605,   // gv.en.de_542 gv.ca.eu_544  ca.ro.rm_543 de.sa.un_330 
  // [1a30]
  0x5c42380c, 0x3f00020c, 0x331e0207, 0x30002904,   // tk.co.sa_543 da.af.un_530  da.ms.nn_432 sl.uz.un_320 
  0x240925a6, 0x46002e0e, 0x190b0a14, 0x343d2109,   // eu.pl.eo_521 fo.qu.un_550  pt.es.gl_666 fa.ku.ps_444 
  0x510e2e14, 0x07041702, 0x020c09a9, 0x0f105108,   // fo.is.kl_666 sr.ru.bg_222  pl.sv.da_544 kl.lt.lv_443 
  0x100a0708, 0x330c51a7, 0x1c0d5cad, 0x5c005121,   // bg.mk.be_443 kl.sv.nn_532  sa.ne.mr_643 kl.sa.un_860 
  // [1a40]
  0x15001902, 0x04465105, 0x29004c04, 0x484415a7,   // gl.un.un_220 kl.qu.fi_333  wo.sl.un_320 un.kk.tt_532 
  0x3e000704, 0x0f004905, 0x0e001214, 0x095c1c07,   // it.rm.un_320 to.lv.un_330  hu.is.un_660 mr.sa.hi_432 
  0x16002904, 0x172a3ea0, 0x5c0f6aa7, 0x12003d04,   // sl.hr.un_320 rm.mt.sr_322  haw.lv.sa_532 ku.ur.un_320 
  0x00002424, 0x28003b0e, 0x5c090d04, 0x0a0807a4,   // yi.un.un_900 ks.sd.un_550  ne.hi.sa_332 bg.uk.mk_433 
  // [1a50]
  0x233c445a, 0x08003008, 0x190b4802, 0x0e2d0d02,   // kk.ug.ky_553 uz.uk.un_430  tt.es.gl_222 cs.sk.is_222 
  0x32000904, 0x0d005c0e, 0x00004f03, 0x212812a9,   // pl.bs.un_320 sa.ne.un_550  bi.un.un_300 ur.sd.fa_544 
  0x2d120da4, 0x443c2313, 0x5c000f11, 0x2d006505,   // cs.hu.sk_433 ky.ug.kk_665  lv.sa.un_630 gv.sk.un_330 
  0x17001004, 0x4000090d, 0x0d004a04, 0x2e0d2da0,   // lt.sr.un_320 pl.lb.un_540  yo.cs.un_320 sk.cs.fo_322 
  // [1a60]
  0x11081208, 0x23330855, 0x2e00120d, 0x330840a9,   // hu.no.ro_443 no.nn.ca_442  hu.fo.un_540 lb.no.nn_544 
  0x48000d04, 0x634006ad, 0x120c0ead, 0x1c005c22,   // cs.tt.un_320 de.lb.sco_643  is.sv.hu_643 sa.mr.un_870 
  0x0102fc0c, 0x34213da7, 0x05061da4, 0x2d0d5da0,   // zzp.da.en_543 ku.fa.ps_532  la.de.fr_433 ss.cs.sk_322 
  0x4c0d12a6, 0x10003704, 0x47600107, 0x18393bee,   // hu.cs.wo_521 ba.be.un_320  en.vo.sn_432 so.br.ga_422 
  // [1a70]
  0x19000e04, 0x23003008, 0x080711a0, 0x21181204,   // is.gl.un_320 uz.ky.un_430  ro.bg.uk_322 ur.ar.fa_332 
  0x1900120c, 0x13005c0d, 0x135c0d05, 0x120e2eaf,   // hu.gl.un_530 sa.bh.un_540  ne.sa.bh_333 fo.is.hu_655 
  0x2c033fa0, 0x053308a4, 0x033f600b, 0x63000105,   // af.nl.fy_322 no.nn.fr_433  vo.af.nl_542 en.sco.un_330 
  0x03003f09, 0x49361cac, 0x0633085a, 0x00005f24,   // af.nl.un_440 id.gn.to_632  no.nn.de_553 tn.un.un_900 
  // [1a80]
  0x4000060d, 0x495a2da4, 0x3300081b, 0x5f003708,   // de.lb.un_540 sk.sm.to_433  no.nn.un_770 st.tn.un_430 
  0x33000823, 0x2d0d1205, 0x315a57ec, 0x3f001c04,   // no.nn.un_880 hu.cs.sk_333  na.sm.az_644 id.af.un_320 
  0x35007319, 0x75375f12, 0x7359550e, 0x23191fac,   // ny.zu.un_750 tn.st.nso_654  rw.rn.ny_555 cy.gl.ca_632 
  0x5a003b14, 0x124950ad, 0x2c611fec, 0x192b07a0,   // so.sm.un_660 fj.to.hu_643  cy.za.fy_644 it.vi.gl_322 
  // [1a90]
  0x1200280c, 0x231f1208, 0x17070aa0, 0x2c3f03a9,   // sd.ur.un_530 hu.cy.ca_443  mk.bg.sr_322 nl.af.fy_544 
  0x5f4c6007, 0x190a2405, 0x19003604, 0x105a3b08,   // vo.wo.tn_432 eo.pt.gl_333  gn.gl.un_320 so.sm.lt_443 
  0x37483c0c, 0x2b353413, 0x1a135aec, 0x21001807,   // ug.tt.ba_543 xh.zu.vi_665  sm.et.tl_644 ar.fa.un_420 
  0x353450ac, 0x283421af, 0x0a2344ee, 0x05000102,   // fj.xh.zu_632 fa.ps.sd_655  kk.ky.mk_422 en.fr.un_220 
  // [1aa0]
  0x21563fa0, 0x00007824, 0x3f0360a4, 0x18213408,   // af.mg.jw_322 ve.un.un_900  vo.nl.af_433 ps.fa.ar_443 
  0xfa005211, 0x795f370c, 0x641b50a7, 0x3f00031b,   // ha.nr.un_630 st.tn.war_543  fj.tr.lg_532 nl.af.un_770 
  0x47033f11, 0x2d0d12ee, 0x50374da7, 0x04245608,   // af.nl.sn_653 hu.cs.sk_422  aa.st.fj_532 mg.eo.fi_443 
  0x0000451c, 0x47033f04, 0x734c750c, 0x49002507,   // ln.un.un_800 af.nl.sn_332  nso.wo.ny_543 eu.to.un_420 
  // [1ab0]
  0x122d0d08, 0x5a453ba4, 0x1c0d0914, 0x62004c0d,   // cs.sk.hu_443 so.ln.sm_433  hi.ne.mr_666 wo.kha.un_540 
  0x55003502, 0x280f73a7, 0x4d4c3005, 0x0715040c,   // zu.rw.un_220 ny.lv.sw_532  uz.wo.aa_333 ru.bg.un_530 
  0x2d0d1904, 0x37234409, 0x0b003329, 0x04034008,   // gl.cs.sk_332 kk.ky.ba_444  as.bn.un_960 lb.nl.fi_443 
  0x35041004, 0x5c330808, 0x034612ee, 0x1d7511a7,   // be.ru.tg_332 no.nn.sa_443  hu.qu.nl_422 ro.nso.la_532 
  // [1ac0]
  0x12023f60, 0x37004412, 0x22431d07, 0x0800440d,   // af.da.hu_664 kk.ba.un_640  la.ie.oc_432 kk.uk.un_540 
  0x0e1d2e02, 0x0a380707, 0x46190b0c, 0x12002513,   // fo.la.is_222 bg.tk.mk_432  es.gl.qu_543 eu.hu.un_650 
  0x1b31300c, 0x2e00120c, 0x3f000e08, 0x3b5f58ec,   // uz.az.tr_543 hu.fo.un_530  is.af.un_430 om.tn.so_644 
  0x3d2118ec, 0x3f583b5a, 0x04583b08, 0x3b003d13,   // ar.fa.ku_644 so.om.af_553  so.om.fi_443 ku.ks.un_650 
  // [1ad0]
  0x3f040313, 0x790234a4, 0x04004d1a, 0x03621ca4,   // nl.fi.af_665 xh.da.war_433  aa.fi.un_760 id.kha.nl_433 
  0x58403b07, 0x2c3f03ee, 0x070438ad, 0x3b033f07,   // so.lb.om_432 nl.af.fy_422  tk.ru.bg_643 af.nl.so_432 
  0x04022aa4, 0x0a002222, 0x0b000a02, 0x3f031aaf,   // mt.da.fi_433 oc.pt.un_870  pt.es.un_220 tl.nl.af_655 
  0x1b003e08, 0x043048a0, 0x070a15ee, 0xfc002208,   // rm.tr.un_430 tt.uz.ru_322  un.mk.bg_422 oc.zzp.un_430 
  // [1ae0]
  0x0a5e3304, 0x4d2d0d05, 0x10000811, 0x1f00220d,   // nn.ts.pt_332 cs.sk.aa_333  uk.be.un_630 oc.cy.un_540 
  0x1b00310e, 0x3d3412ec, 0x48311b13, 0x27001304,   // az.tr.un_550 ur.ps.ku_644  tr.az.tt_665 et.gd.un_320 
  0x34355d11, 0x1b4831ec, 0x3b4d4c0c, 0x205d320c,   // ss.zu.xh_653 az.tt.tr_644  wo.aa.so_543 bs.ss.sq_543 
  0x21435cac, 0x03003b02, 0x3f035805, 0x6b007914,   // sa.ie.jw_632 so.nl.un_220  om.nl.af_333 war.ceb.un_660 
  // [1af0]
  0x51133ba4, 0x3f133b0c, 0x355c27a9, 0x03003f0d,   // so.et.kl_433 so.et.af_543  gd.sa.zu_544 af.nl.un_540 
  0x4d003b13, 0x30003414, 0x00003d2d, 0x790452ac,   // so.aa.un_650 ps.uz.un_660  ku.un.un_A00 ha.fi.war_632 
  0x0d001c13, 0x06003804, 0x1e00fe0c, 0x3748380b,   // mr.ne.un_650 tk.de.un_320  tlh.ms.un_530 tk.tt.ba_542 
  0x34003d0e, 0x79000912, 0x48313004, 0x29001704,   // ku.ps.un_550 pl.war.un_640  uz.az.tt_332 sr.sl.un_320 
  // [1b00]
  0x300220ee, 0x4e34275a, 0x120e2dee, 0x5702390e,   // sq.da.uz_422 gd.xh.ay_553  sk.is.hu_422 br.da.na_555 
  0x040810a0, 0x6b790960, 0x18002307, 0x48311b0e,   // be.uk.ru_322 pl.war.ceb_664  ca.ga.un_420 tr.az.tt_555 
  0x23001904, 0x311b4814, 0x04000805, 0x201206ad,   // gl.ca.un_320 tt.tr.az_666  uk.ru.un_330 de.hu.sq_643 
  0x1c0d13ad, 0x31001b09, 0x342318a7, 0x2e0a0e07,   // bh.ne.mr_643 tr.az.un_440  ar.ky.ps_532 is.pt.fo_432 
  // [1b10]
  0x170a0713, 0x37003507, 0x1200300d, 0x0000092d,   // bg.mk.sr_665 tg.ba.un_420  uz.ur.un_540 pl.un.un_A00 
  0x04150aa0, 0x37004812, 0x23003c22, 0x3b021aa4,   // mk.ru.un_320 tt.ba.un_640  ug.ky.un_870 tl.da.so_433 
  0x1e025608, 0x3f650e07, 0x360a23a9, 0x2e026507,   // mg.da.ms_443 is.gv.af_432  ca.pt.gn_544 gv.da.fo_432 
  0x3700300c, 0xfe004f33, 0x65000213, 0x65000a2b,   // uz.ba.un_530 bi.tlh.un_A70  da.gv.un_650 pt.gv.un_980 
  // [1b20]
  0x69134560, 0x47006504, 0x18002d05, 0x65006707,   // ln.et.mfe_664 gv.sn.un_320  sk.ga.un_330 ak.gv.un_420 
  0x321716a9, 0x0e000207, 0x79006b12, 0x1d006512,   // hr.sr.bs_544 da.is.un_420  ceb.war.un_640 gv.la.un_640 
  0x422f4d07, 0x796b1a55, 0x2f000108, 0x5c1c0daf,   // aa.su.co_432 tl.ceb.war_442  en.su.un_430 ne.mr.sa_655 
  0x123421a7, 0x2822560c, 0x0700110c, 0x36006519,   // fa.ps.ur_532 mg.oc.sw_543  ro.bg.un_530 gv.gn.un_750 
  // [1b30]
  0x0810040e, 0x18283bee, 0x27006502, 0x5955730c,   // ru.be.uk_555 ks.sd.ar_422  gv.gd.un_220 ny.rw.rn_543 
  0x5efe45a4, 0x2a003934, 0x3b5e4814, 0x0d0913af,   // ln.tlh.ts_433 dz.bo.un_A80  tt.ts.so_666 bh.hi.ne_655 
  0x0a150705, 0x041708a7, 0x3b056511, 0x13511ca9,   // bg.mk.un_330 uk.sr.ru_532  gv.fr.so_653 id.kl.et_544 
  0x2e00331a, 0xfc00010c, 0x13250204, 0x58313bee,   // nn.fo.un_760 en.zzp.un_530  da.eu.et_332 so.az.om_422 
  // [1b40]
  0x3c003007, 0x300651a4, 0x090d1c13, 0x5e4c1ca4,   // uz.ug.un_420 kl.de.uz_433  mr.ne.hi_665 id.wo.ts_433 
  0x0507010c, 0x1800280c, 0x4b000305, 0x0c0e2e07,   // en.it.fr_543 sd.ar.un_530  nl.mi.un_330 fo.is.sv_432 
  0x1ffc0109, 0x1e002013, 0x303744ee, 0x39002a21,   // en.zzp.cy_444 ti.am.un_650  kk.ba.uz_422 bo.dz.un_860 
  0x1300092a, 0x281834ec, 0x35001111, 0x08001709,   // hi.bh.un_970 ps.ar.sd_644  ro.tg.un_630 sr.uk.un_440 
  // [1b50]
  0x0a040702, 0x130d0905, 0x2d0a1205, 0x23150a05,   // bg.ru.mk_222 hi.ne.bh_333  hu.pt.sk_333 mk.ky.un_330 
  0x37080408, 0x48251508, 0x23443caf, 0x1c001308,   // ru.uk.ba_443 un.mn.tt_443  ug.kk.ky_655 bh.mr.un_430 
  0x61131a08, 0x5e00280d, 0x13006504, 0x785028ad,   // tl.et.za_443 sw.ts.un_540  gv.et.un_320 sw.fj.ve_643 
  0x292d0d08, 0x48000412, 0x405e4ead, 0x1a000c04,   // cs.sk.sl_443 ru.tt.un_640  ay.ts.lb_643 sv.tl.un_320 
  // [1b60]
  0x78285e05, 0x0d005c08, 0x5e284e13, 0x0c006514,   // ts.sw.ve_333 sa.ne.un_430  ay.sw.ts_665 gv.sv.un_660 
  0x4e00281a, 0x28475f12, 0x1a003904, 0x4c00360d,   // sw.ay.un_760 tn.sn.sw_654  br.tl.un_320 gn.wo.un_540 
  0x5f4728ac, 0x04351105, 0x645f2805, 0x17000a1b,   // sw.sn.tn_632 ro.tg.ru_333  sw.tn.lg_333 mk.sr.un_770 
  0x1d004802, 0x30003c1b, 0x09005c05, 0x5d287808,   // tt.la.un_220 ug.uz.un_770  sa.hi.un_330 ve.sw.ss_443 
  // [1b70]
  0x50212f09, 0x152317a0, 0x07150a04, 0x190b36af,   // su.jw.fj_444 sr.ky.un_322  mk.bg.un_320 gn.es.gl_655 
  0x3000351a, 0x0c001f0e, 0x1c0d0909, 0x13000d1b,   // tg.uz.un_760 cy.sv.un_550  hi.ne.mr_444 ne.bh.un_770 
  0x5e474e09, 0x53400507, 0x0900121a, 0x4e005e1a,   // ay.sn.ts_444 fr.lb.ht_432  hu.pl.un_760 ts.ay.un_760 
  0x1723300c, 0x39132104, 0x475e3411, 0x475e4e07,   // uz.ky.sr_543 jw.et.br_332  xh.ts.sn_653 ay.ts.sn_432 
  // [1b80]
  0x2800180e, 0x4e285e08, 0x73285eec, 0x4e5f5e12,   // ar.sd.un_550 ts.sw.ay_443  ts.sw.ny_644 ts.tn.ay_654 
  0x0a00230c, 0x5f004723, 0x354e4612, 0x0d091c0c,   // ky.mk.un_530 sn.tn.un_880  qu.ay.zu_654 mr.hi.ne_543 
  0x0a001714, 0x38481bec, 0x272115a4, 0x12304404,   // sr.mk.un_660 tr.tt.tk_644  un.jw.gd_433 kk.uz.ur_332 
  0x040711a4, 0x12003019, 0x0c0302a7, 0x21003d18,   // ro.bg.ru_433 uz.ur.un_750  da.nl.sv_532 ku.fa.un_740 
  // [1b90]
  0x13000d12, 0x1b00340c, 0x233c44ec, 0x04006322,   // ne.bh.un_640 xh.tr.un_530  kk.ug.ky_644 sco.fi.un_870 
  0x30233507, 0x644704a0, 0x252a0408, 0x09130d08,   // tg.ky.uz_432 fi.sn.lg_322  fi.mt.eu_443 ne.bh.hi_443 
  0x65002f04, 0x04001302, 0x5104580c, 0x07083ca4,   // su.gv.un_320 et.fi.un_220  om.fi.kl_543 ug.uk.bg_433 
  0x2a000c04, 0x03003b04, 0x18234408, 0x0400370c,   // sv.mt.un_320 so.nl.un_320  kk.ky.ar_443 st.fi.un_530 
  // [1ba0]
  0x1c002304, 0x6b1a12ee, 0x656445a0, 0x45006e09,   // ca.id.un_320 hu.tl.ceb_422  ln.lg.gv_322 hmn.ln.un_440 
  0x28003004, 0x040c6507, 0x06004007, 0x07003019,   // uz.sw.un_320 gv.sv.fi_432  lb.de.un_420 uz.bg.un_750 
  0x0c0502a0, 0x0200430d, 0x07151007, 0x132f0255,   // da.fr.sv_322 ie.da.un_540  be.bg.un_420 da.su.et_442 
  0x2d122ea4, 0x6100471b, 0x221d26a4, 0x13041b55,   // fo.hu.sk_433 sn.za.un_770  ia.la.oc_433 tr.fi.et_442 
  // [1bb0]
  0x0e002e22, 0x1828340d, 0x0e045d07, 0x04000104,   // fo.is.un_870 ps.sd.ar_554  ss.fi.is_432 en.fi.un_320 
  0x765346a9, 0x1b006b04, 0x28003502, 0x00004624,   // qu.ht.crs_544 ceb.tr.un_320  zu.sw.un_220 qu.un.un_900 
  0x17080aa4, 0x02004708, 0x07480407, 0x0d130904,   // mk.uk.sr_433 sn.da.un_430  ru.tt.bg_432 hi.bh.ne_332 
  0x08002504, 0x24006118, 0x3b3002ad, 0x2d0d12a0,   // eu.no.un_320 za.eo.un_740  da.uz.so_643 hu.cs.sk_322 
  // [1bc0]
  0x170408ee, 0x3048fe0c, 0x0a00151a, 0x0a170755,   // uk.ru.sr_422 tlh.tt.uz_543  un.mk.un_760 bg.sr.mk_442 
  0x07001708, 0x1b004805, 0x1200340c, 0x0b001d05,   // sr.bg.un_430 tt.tr.un_330  ps.ur.un_530 la.es.un_330 
  0x011b3ba0, 0x43190b14, 0x014c3b04, 0x5e004009,   // so.tr.en_322 es.gl.ie_666  so.wo.en_332 lb.ts.un_440 
  0x31fe4d0c, 0x6100250e, 0x00004c0f, 0x131c5ca0,   // aa.tlh.az_543 eu.za.un_550  wo.un.un_600 sa.mr.bh_322 
  // [1bd0]
  0x0d0e2e05, 0x12002e13, 0x135c0d13, 0xfc1d250c,   // fo.is.cs_333 fo.hu.un_650  ne.sa.bh_665 eu.la.zzp_543 
  0x12000d02, 0x5a254907, 0x5c000d09, 0x25611d08,   // cs.hu.un_220 to.eu.sm_432  ne.sa.un_440 la.za.eu_443 
  0x3e25610d, 0x162d0dee, 0x49002004, 0x4830fea0,   // za.eu.rm_554 cs.sk.hr_422  sq.to.un_320 tlh.uz.tt_322 
  0x0723380c, 0x2a003e05, 0x01004607, 0x6002fca4,   // tk.ky.bg_543 rm.mt.un_330  qu.en.un_420 zzp.da.vo_433 
  // [1be0]
  0x3069fe08, 0x5c000908, 0x112549ad, 0x07fc1fa0,   // tlh.mfe.uz_443 hi.sa.un_430  to.eu.ro_643 cy.zzp.it_322 
  0x181665ee, 0x3e1f3805, 0x1d253b08, 0x1700040c,   // gv.hr.ga_422 tk.cy.rm_333  so.eu.la_443 ru.sr.un_530 
  0x1d2401a4, 0x79000108, 0x0cfe08a4, 0x33001007,   // en.eo.la_433 en.war.un_430  no.tlh.sv_433 lt.nn.un_420 
  0x630c0204, 0x226301a0, 0x18653908, 0x38001f07,   // da.sv.sco_332 en.sco.oc_322  br.gv.ga_443 cy.tk.un_420 
  // [1bf0]
  0x0a17080b, 0xfc001f18, 0x3b002a19, 0x34211208,   // uk.sr.mk_542 cy.zzp.un_740  mt.so.un_750 ur.fa.ps_443 
  0x34002104, 0x1f001021, 0x170408a4, 0x07010ba0,   // fa.ps.un_320 lt.cy.un_860  uk.ru.sr_433 es.en.it_322 
  0x04083602, 0x1c1309ee, 0x483b2a0c, 0x3d343bee,   // ab.uk.ru_222 hi.bh.mr_422  mt.so.tt_543 ks.ps.ku_422 
  0x2400331a, 0x0663010b, 0x25001214, 0x3c4423ac,   // nn.eo.un_760 en.sco.de_542  hu.eu.un_660 ky.kk.ug_632 
  
  // [1c00]
  0x17003009, 0x170410a0, 0x23443cad, 0x040815ec,   // uz.sr.un_440 be.ru.sr_322  ug.kk.ky_643 un.uk.ru_644 
  0x6b001a09, 0x1200301b, 0x00001a03, 0x3d003b08,   // tl.ceb.un_440 uz.ur.un_770  tl.un.un_300 ks.ku.un_430 
  0x032865ee, 0x043b51a9, 0x48170aa0, 0x03046555,   // gv.sw.nl_422 kl.so.fi_544  mk.sr.tt_322 gv.fi.nl_442 
  0x3b0451ee, 0x37001509, 0x3534780e, 0x04403b0d,   // kl.fi.so_422 un.ba.un_440  ve.xh.zu_555 so.lb.fi_554 
  // [1c10]
  0x030413ad, 0x733437a4, 0x1a4d3b11, 0x25002313,   // et.fi.nl_643 st.xh.ny_433  so.aa.tl_653 ky.mn.un_650 
  0x21080205, 0x1c5c0d08, 0x40044cad, 0x3b4c1a07,   // da.no.jw_333 ne.sa.mr_443  wo.fi.lb_643 tl.wo.so_432 
  0x20353411, 0x1a3b51a4, 0x57621005, 0x1f40060c,   // xh.zu.sq_653 kl.so.tl_433  lt.kha.na_333 de.lb.cy_543 
  0x3b3f4da7, 0x00006315, 0x0d001004, 0x120833a4,   // aa.af.so_532 sco.un.un_700  lt.cs.un_320 nn.no.hu_433 
  // [1c20]
  0x131d25a7, 0x583b4d04, 0x1500041b, 0x48361705,   // eu.la.et_532 aa.so.om_332  ru.un.un_770 sr.ab.tt_333 
  0x0a1b1d02, 0x03375f08, 0x0800101b, 0x40513904,   // la.tr.pt_222 tn.st.nl_443  be.uk.un_770 br.kl.lb_332 
  0x033f5108, 0x371536ad, 0x033f4caf, 0x2d2061ad,   // kl.af.nl_443 ab.ba.un_630  wo.af.nl_655 za.sq.sk_643 
  0x133f03ec, 0x63763908, 0xfe000104, 0x37443809,   // nl.af.et_644 br.crs.sco_443  en.tlh.un_320 tk.kk.ba_444 
  // [1c30]
  0x3f033904, 0x15000423, 0x3e25010c, 0x262401a0,   // br.nl.af_332 ru.un.un_880  en.eu.rm_543 en.eo.ia_322 
  0x35004404, 0x07080402, 0x1821340c, 0x533113a7,   // kk.tg.un_320 ru.uk.bg_222  ps.fa.ar_543 et.az.ht_532 
  0x2e000e22, 0x0a233805, 0x13001504, 0x3b00120e,   // is.fo.un_870 tk.ky.mk_333  un.et.un_320 ur.ks.un_550 
  0x2338440d, 0x35381112, 0x4400230e, 0x073048a0,   // kk.tk.ky_554 ro.tk.tg_654  ky.kk.un_550 tt.uz.bg_322 
  // [1c40]
  0x21123012, 0x3700040c, 0xfc000207, 0x3421180c,   // uz.ur.fa_654 ru.ba.un_530  da.zzp.un_420 ar.fa.ps_543 
  0x380a17a4, 0x20560aee, 0x2a3555a0, 0x4c1c28a0,   // sr.mk.tk_433 pt.mg.sq_422  rw.zu.mt_322 sw.id.wo_322 
  0x6a005c0d, 0x11153e07, 0x2c311e0c, 0x15003e04,   // sa.haw.un_540 rm.ro.un_420  ms.az.fy_543 rm.un.un_320 
  0x0d005c22, 0x5e000909, 0x28183407, 0x30182105,   // sa.ne.un_870 pl.ts.un_440  ps.ar.sd_432 fa.ar.uz_333 
  // [1c50]
  0x080407a7, 0x04480a04, 0x5c000f0c, 0x0e190b60,   // bg.ru.uk_532 mk.tt.ru_332  lv.sa.un_530 es.gl.is_664 
  0x0d5c1ca0, 0x290d2daf, 0x17004802, 0x354430af,   // mr.sa.ne_322 sk.cs.sl_655  tt.sr.un_220 uz.kk.tg_655 
  0x100a1702, 0x372538ad, 0x3e355505, 0x15234807,   // sr.mk.be_222 tk.mn.ba_643  rw.zu.rm_333 tt.ky.un_432 
  0x3c004413, 0x1c130902, 0x3c15300c, 0x10384409,   // kk.ug.un_650 hi.bh.mr_222  uz.ug.un_530 kk.tk.be_444 
  // [1c60]
  0x0437110c, 0x070a11a0, 0x3c234408, 0x511d1dad,   // ro.ba.ru_543 ro.mk.bg_322  kk.ky.ug_443 la.la.kl_643 
  0x07000612, 0x04001522, 0x6509380c, 0x3012210c,   // de.it.un_640 un.ru.un_870  tk.pl.gv_543 fa.ur.uz_543 
  0x18232512, 0x22002304, 0x2223110c, 0xfc004507,   // mn.ky.ar_654 ca.oc.un_320  ro.ca.oc_543 ln.zzp.un_420 
  0x37001707, 0x421d3702, 0x2b792408, 0x0507150c,   // sr.ba.un_420 st.la.co_222  eo.war.vi_443 un.it.fr_543 
  // [1c70]
  0x52005714, 0x293957ee, 0x3f620107, 0x632718ad,   // na.ha.un_660 na.br.sl_422  en.kha.af_432 ga.gd.sco_643 
  0x1c470204, 0x16002d07, 0x11221d04, 0x033f2007,   // da.sn.id_332 sk.hr.un_420  la.oc.ro_332 sq.af.nl_432 
  0x21461505, 0x0a36380d, 0x78005d09, 0x0a0715a0,   // un.qu.jw_333 tk.ab.mk_554  ss.ve.un_440 un.bg.mk_322 
  0x3000370c, 0x1f035704, 0x24001507, 0x221d04a0,   // ba.uz.un_530 na.nl.cy_332  un.eo.un_420 fi.la.oc_322 
  // [1c80]
  0x016334a0, 0x1a796b08, 0x00003324, 0x170a08a4,   // xh.sco.en_322 ceb.war.tl_443  as.un.un_900 uk.mk.sr_433 
  0x65391da4, 0x103e1d08, 0x18fc3f0c, 0x255701ac,   // la.br.gv_433 la.rm.lt_443  af.zzp.ga_543 en.na.eu_632 
  0x22231dee, 0x0700350d, 0x69001f0e, 0x19006509,   // la.ca.oc_422 tg.bg.un_540  cy.mfe.un_550 gv.gl.un_440 
  0x07171008, 0x0223570b, 0x28004633, 0x1b694f0b,   // be.sr.bg_443 na.ca.da_542  qu.sw.un_A70 bi.mfe.tr_542 
  // [1c90]
  0x17040802, 0x170c5302, 0x07251507, 0x21343d0c,   // uk.ru.sr_222 ht.sv.sr_222  un.mn.bg_432 ku.ps.fa_543 
  0x0f006402, 0x15007911, 0x1500070d, 0x06001205,   // lg.lv.un_220 war.un.un_630  bg.un.un_540 hu.de.un_330 
  0x011f63ee, 0x21461507, 0x461502a4, 0x0e000505,   // sco.cy.en_422 un.qu.jw_432  da.qu.un_430 fr.is.un_330 
  0x51156509, 0x25002004, 0x1c135c08, 0x21303bee,   // gv.kl.un_440 sq.eu.un_320  sa.bh.mr_443 ks.uz.fa_422 
  // [1ca0]
  0x6300401a, 0x44233c08, 0x1f224fa4, 0x07655107,   // lb.sco.un_760 ug.ky.kk_443  bi.oc.cy_433 kl.gv.it_432 
  0x7962010c, 0x214654ad, 0x5a000407, 0x3f1235a0,   // en.kha.war_543 ik.qu.jw_643  fi.sm.un_420 zu.hu.af_322 
  0x49045a05, 0x0a003607, 0x65006304, 0x40004902,   // sm.fi.to_333 ab.mk.un_420  sco.gv.un_320 to.lb.un_220 
  0x5a044907, 0x373435a7, 0x25000307, 0x30080408,   // to.fi.sm_432 zu.xh.st_532  nl.eu.un_420 ru.uk.uz_443 
  // [1cb0]
  0x3800130c, 0xfe000608, 0x04000608, 0x36003814,   // et.tk.un_530 de.tlh.un_430  de.fi.un_430 tk.ab.un_660 
  0x65300ea0, 0x041508a0, 0x040a1708, 0x095c1c12,   // is.uz.gv_322 uk.ru.un_320  sr.mk.ru_443 mr.sa.hi_654 
  0x08001005, 0x04004208, 0x091c5ca4, 0x58002a08,   // be.uk.un_330 co.fi.un_430  sa.mr.hi_433 mt.om.un_430 
  0x23343d08, 0x00004724, 0x49000407, 0x3c234411,   // ku.ps.ky_443 sn.un.un_900  fi.to.un_420 kk.ky.ug_653 
  // [1cc0]
  0x04005a08, 0x37003505, 0x07300807, 0x095c1c08,   // sm.fi.un_430 tg.ba.un_330  uk.uz.bg_432 mr.sa.hi_443 
  0x06001309, 0x55061305, 0x13002908, 0x2128340c,   // et.de.un_440 et.de.rw_333  sl.et.un_430 ps.sd.fa_543 
  0x173c0aa7, 0x17070a04, 0x03004014, 0x0e005d08,   // mk.ug.sr_532 mk.bg.sr_332  lb.nl.un_660 ss.is.un_430 
  0x041b3107, 0x39007308, 0x1b003108, 0x0a152309,   // az.tr.fi_432 ny.br.un_430  az.tr.un_430 ky.mk.un_440 
  // [1cd0]
  0x08001007, 0x37004813, 0x0d1c0904, 0x47241ca0,   // be.uk.un_420 tt.ba.un_650  hi.mr.ne_332 id.eo.sn_322 
  0x1d001104, 0x02345d55, 0x1500380d, 0x23003e05,   // ro.la.un_320 ss.xh.da_442  tk.un.un_540 rm.ca.un_330 
  0x355d340d, 0x07300a02, 0x45000e13, 0x21001e02,   // xh.ss.zu_554 mk.uz.bg_222  is.ln.un_650 ms.jw.un_220 
  0x55132902, 0x062a6aee, 0x1d1f6312, 0x3500340e,   // sl.et.rw_222 haw.mt.de_422  sco.cy.la_654 xh.zu.un_550 
  // [1ce0]
  0x17070405, 0x02571e0c, 0xfa345da4, 0x4b003720,   // ru.bg.sr_333 ms.na.da_543  ss.xh.nr_433 st.mi.un_850 
  0x751d78af, 0x16005504, 0x4779600c, 0x20553604,   // ve.la.nso_655 rw.hr.un_320  vo.war.sn_543 gn.rw.sq_332 
  0x354438ad, 0x03004708, 0x00005d1c, 0x3f0604a4,   // tk.kk.tg_643 sn.nl.un_430  ss.un.un_800 fi.de.af_433 
  0x0600610d, 0x6100571a, 0xfe00470e, 0x3300040c,   // za.de.un_540 na.za.un_760  sn.tlh.un_550 fi.nn.un_530 
  // [1cf0]
  0x29001d04, 0x0300020c, 0x1700300c, 0x51000207,   // la.sl.un_320 da.nl.un_530  uz.sr.un_530 da.kl.un_420 
  0x47005d07, 0x1d001d21, 0x5d002913, 0x08007512,   // ss.sn.un_420 la.la.un_860  sl.ss.un_650 nso.no.un_640 
  0x27001808, 0x09001f14, 0x51336107, 0x39003705,   // ga.gd.un_430 cy.pl.un_660  za.nn.kl_432 st.br.un_330 
  0x64043707, 0x06005102, 0x55000611, 0x29001304,   // st.fi.lg_432 kl.de.un_220  de.rw.un_630 et.sl.un_320 
  // [1d00]
  0x3c004408, 0x18000904, 0x1b000905, 0x0d1c5cee,   // kk.ug.un_430 pl.ga.un_320  pl.tr.un_330 sa.mr.ne_422 
  0x50004904, 0x09001f07, 0x47001f08, 0x4f005a0d,   // to.fj.un_320 cy.pl.un_420  cy.sn.un_430 sm.bi.un_540 
  0x5d375f13, 0x443723ee, 0x34003d02, 0x08100407,   // tn.st.ss_665 ky.ba.kk_422  ku.ps.un_220 fi.lt.no_432 
  0x130d5c14, 0x0a0708a4, 0x0e002e07, 0x07000a04,   // sa.ne.bh_666 uk.bg.mk_433  fo.is.un_420 mk.bg.un_320 
  // [1d10]
  0x21341207, 0x0a080708, 0x2e000e0b, 0x06001307,   // ur.ps.fa_432 bg.uk.mk_443  is.fo.un_520 et.de.un_420 
  0x0f102904, 0x13000912, 0x08070a05, 0x0f000c02,   // sl.lt.lv_332 hi.bh.un_640  mk.bg.uk_333 sv.lv.un_220 
  0x30003523, 0x47000a02, 0x4c002108, 0x08003704,   // tg.uz.un_880 pt.sn.un_220  jw.wo.un_430 ba.uk.un_320 
  0x07170aa4, 0x2e000e08, 0x13003b19, 0x0000282d,   // mk.sr.bg_433 is.fo.un_430  so.et.un_750 sd.un.un_A00 
  // [1d20]
  0x5c00130b, 0x48233608, 0x796b3b07, 0x28536911,   // bh.sa.un_520 ab.ky.tt_443  so.ceb.war_432 mfe.ht.sw_653 
  0x13000d11, 0x483c3708, 0x303c38a9, 0x5c000d1a,   // ne.bh.un_630 ba.ug.tt_443  tk.ug.uz_544 ne.sa.un_760 
  0x4c3b3909, 0x5e356708, 0x040a3007, 0x6400470d,   // br.so.wo_444 ak.zu.ts_443  uz.mk.ru_432 sn.lg.un_540 
  0x1d0929a7, 0x17290d07, 0x0d1c5c0e, 0x2c133ba7,   // sl.pl.la_532 cs.sl.sr_432  sa.mr.ne_555 so.et.fy_532 
  // [1d30]
  0x68006419, 0x08004411, 0x63003b12, 0x29000d05,   // lg.ig.un_750 kk.uk.un_630  so.sco.un_640 cs.sl.un_330 
  0x13001c08, 0x29000d0d, 0x6800670e, 0x44002309,   // mr.bh.un_430 cs.sl.un_540  ak.ig.un_550 ky.kk.un_440 
  0x03394605, 0x0a001708, 0x32290dee, 0x09001c02,   // qu.br.nl_333 sr.mk.un_430  cs.sl.bs_422 mr.hi.un_220 
  0x4c003b07, 0x5d4305a9, 0x04353007, 0x0d000a02,   // so.wo.un_420 fr.ie.ss_544  uz.tg.ru_432 pt.cs.un_220 
  // [1d40]
  0x033f3baf, 0x6b3b1aa4, 0x44152312, 0x09001b07,   // so.af.nl_655 tl.so.ceb_433  ky.kk.un_640 tr.pl.un_420 
  0x5c4b6a12, 0x79463807, 0x1b002902, 0x1d000a05,   // haw.mi.sa_654 tk.qu.war_432  sl.tr.un_220 pt.la.un_330 
  0x213428ec, 0x160d29a0, 0x0a0407a0, 0x48005c04,   // sd.ps.fa_644 sl.cs.hr_322  bg.ru.mk_322 sa.tt.un_320 
  0x0b003322, 0x30002507, 0x27511d07, 0x3e001d0c,   // as.bn.un_870 mn.uz.un_420  la.kl.gd_432 la.rm.un_530 
  // [1d50]
  0x64005a02, 0x5759555a, 0x10483804, 0x64004713,   // sm.lg.un_220 rw.rn.na_553  tk.tt.be_332 sn.lg.un_650 
  0xfe00550d, 0x0d002d0c, 0x3000351b, 0x28183404,   // rw.tlh.un_540 sk.cs.un_530  tg.uz.un_770 ps.ar.sd_332 
  0x1d641902, 0x5300760c, 0x040710a4, 0x080704a0,   // gl.lg.la_222 crs.ht.un_530  be.bg.ru_433 ru.bg.uk_322 
  0x35595555, 0x0e001902, 0x3500110c, 0x45000e12,   // rw.rn.zu_442 gl.is.un_220  ro.tg.un_530 is.ln.un_640 
  // [1d60]
  0x55000604, 0x302f210c, 0x190a0ba4, 0x34002e04,   // de.rw.un_320 jw.su.uz_543  es.pt.gl_433 fo.xh.un_320 
  0x0f001013, 0x08383308, 0x59554714, 0x35344da6,   // lt.lv.un_650 nn.tk.no_443  sn.rw.rn_666 aa.xh.zu_521 
  0x0d091ca9, 0xfe7338a4, 0x20595505, 0x3e536704,   // mr.hi.ne_544 tk.ny.tlh_433  rw.rn.sq_333 ak.ht.rm_332 
  0x040811a9, 0x0a516aa6, 0x343b47a0, 0x65001508,   // ro.uk.ru_544 haw.kl.pt_521  sn.so.xh_322 un.gv.un_430 
  // [1d70]
  0x3d343ca7, 0x1b381205, 0x0d1c09ad, 0x0a07150c,   // ug.ps.ku_532 hu.tk.tr_333  hi.mr.ne_643 un.bg.mk_543 
  0x182e1207, 0x0e2e19a0, 0x5c004b04, 0x5c004b07,   // hu.fo.ga_432 gl.fo.is_322  mi.sa.un_320 mi.sa.un_420 
  0x0e00450b, 0x0e2e5d05, 0x042e39ee, 0x552f6405,   // ln.is.un_520 ss.fo.is_333  br.fo.fi_422 lg.su.rw_333 
  0x2f4b37a0, 0x5c130955, 0x205559ee, 0x2f137904,   // st.mi.su_322 hi.bh.sa_442  rn.rw.sq_422 war.et.su_332 
  // [1d80]
  0x3036350c, 0x23000204, 0x100804a9, 0x17070a08,   // tg.ab.uz_543 da.ca.un_320  ru.uk.be_544 mk.bg.sr_443 
  0x46300507, 0x51071da0, 0x5c004b08, 0x083c30ad,   // fr.uz.qu_432 la.it.kl_322  mi.sa.un_430 uz.ug.uk_643 
  0x223823a7, 0x481b310d, 0x0d000909, 0x1d484604,   // ca.tk.oc_532 az.tr.tt_554  hi.ne.un_440 qu.tt.la_332 
  0x3500151a, 0x122d4cb4, 0x283b5804, 0x12182809,   // un.tg.un_760 wo.sk.hu_754  om.so.sw_332 sd.ar.ur_444 
  // [1d90]
  0x5c130913, 0x2d0d0a05, 0x51051da7, 0x28181204,   // hi.bh.sa_665 pt.cs.sk_333  la.fr.kl_532 ur.ar.sd_332 
  0x13001c0c, 0x4c2e0ead, 0x51004605, 0x5c1c0909,   // mr.bh.un_530 is.fo.wo_643  qu.kl.un_330 hi.mr.sa_444 
  0x0a000b07, 0x10002909, 0x0e002307, 0x070a11a7,   // es.pt.un_420 sl.lt.un_440  ca.is.un_420 ro.mk.bg_532 
  0x3500080c, 0x07001119, 0x20001d04, 0x0f005304,   // uk.tg.un_530 ro.bg.un_750  la.sq.un_320 ht.lv.un_320 
  // [1da0]
  0x10002c08, 0x10002c14, 0x100d2dee, 0x51001319,   // fy.lt.un_430 fy.lt.un_660  sk.cs.lt_422 et.kl.un_750 
  0x2100341b, 0x1d001009, 0x5c004b0c, 0x39000104,   // ps.fa.un_770 lt.la.un_440  mi.sa.un_530 en.br.un_320 
  0x122144a0, 0xfc011d07, 0x2200231a, 0x4d581313,   // kk.fa.ur_322 la.en.zzp_432  ca.oc.un_760 et.om.aa_665 
  0x034c4d07, 0x4d3b1308, 0x4d5851ec, 0x513b58a0,   // aa.wo.nl_432 et.so.aa_443  kl.om.aa_644 om.so.kl_322 
  // [1db0]
  0x18002702, 0x1c3f2f02, 0x0d095ca4, 0x64000307,   // gd.ga.un_220 su.af.id_222  sa.hi.ne_433 nl.lg.un_420 
  0x34003702, 0x4c4d3b11, 0x08003708, 0x213d3460,   // st.xh.un_220 so.aa.wo_653  st.no.un_430 ps.ku.fa_664 
  0x35043f04, 0x3b00580d, 0x03133ba4, 0x332d0d02,   // af.fi.zu_332 om.so.un_540  so.et.nl_433 cs.sk.nn_222 
  0x070a11a4, 0x5c0d09ad, 0x481b38a7, 0x1d655405,   // ro.mk.bg_433 hi.ne.sa_643  tk.tr.tt_532 ik.gv.la_333 
  // [1dc0]
  0x355d37ec, 0x58514d0c, 0x1f005e04, 0x584d3baf,   // st.ss.zu_644 aa.kl.om_543  ts.cy.un_320 so.aa.om_655 
  0x10111d12, 0xfc005909, 0x343f0308, 0x0dfefc0d,   // la.ro.lt_654 rn.zzp.un_440  nl.af.xh_443 zzp.tlh.cs_554 
  0x23004421, 0x55005907, 0x02001204, 0x64004709,   // kk.ky.un_860 rn.rw.un_420  hu.da.un_320 sn.lg.un_440 
  0x59675512, 0x3b004d21, 0x6b15fca9, 0x371738a7,   // rw.ak.rn_654 aa.so.un_860  zzp.ceb.un_540 tk.sr.ba_532 
  // [1dd0]
  0x3b004c0d, 0x0d130913, 0x3b034da6, 0x1a4c4d60,   // wo.so.un_540 hi.bh.ne_665  aa.nl.so_521 aa.wo.tl_664 
  0x00002f1c, 0x29001605, 0x3b035114, 0x1138440c,   // su.un.un_800 hr.sl.un_330  kl.nl.so_666 kk.tk.ro_543 
  0x3d001204, 0x3b034d0c, 0x00006206, 0x3f0340a7,   // ur.ku.un_320 aa.nl.so_543  kha.un.un_400 lb.nl.af_532 
  0x06577904, 0x4600551a, 0x17003608, 0x5dfe370c,   // war.na.de_332 rw.qu.un_760  ab.sr.un_430 st.tlh.ss_543 
  // [1de0]
  0x303c3d55, 0x04001514, 0x31130407, 0x30073c09,   // ku.ug.uz_442 un.ru.un_660  fi.et.az_432 ug.bg.uz_444 
  0x12002d04, 0x30342108, 0x48003708, 0x2821120c,   // sk.hu.un_320 fa.ps.uz_443  ba.tt.un_430 ur.fa.sd_543 
  0x0a171002, 0x551e1c04, 0x0e004504, 0x303c3804,   // be.sr.mk_222 id.ms.rw_332  ln.is.un_320 tk.ug.uz_332 
  0x190b0a05, 0x36001904, 0x122d0d13, 0x04003704,   // pt.es.gl_333 gl.gn.un_320  cs.sk.hu_665 ba.ru.un_320 
  // [1df0]
  0x5c001c05, 0x130d090e, 0x3c004409, 0x21002205,   // mr.sa.un_330 hi.ne.bh_555  kk.ug.un_440 oc.jw.un_330 
  0x10232507, 0x370848ac, 0x30354404, 0x3f130308,   // mn.ky.be_432 tt.uk.ba_632  kk.tg.uz_332 nl.et.af_443 
  0x79006b0c, 0x23004811, 0x030c06a0, 0x294b6aad,   // ceb.war.un_530 tt.ky.un_630  de.sv.nl_322 haw.mi.sl_643 
  0x5c494bec, 0x2b002d08, 0x13000608, 0x48352308,   // mi.to.sa_644 sk.vi.un_430  de.et.un_430 ky.tg.tt_443 
  // [1e00]
  0x48003302, 0x2c023b07, 0x3b003105, 0x025e4e0c,   // nn.tt.un_220 so.da.fy_432  az.so.un_330 ay.ts.da_543 
  0x0c2a3b05, 0x4e000c09, 0x6b231d07, 0x271118ad,   // so.mt.sv_333 sv.ay.un_440  la.ca.ceb_432 ga.ro.gd_643 
  0x3f2f250d, 0x230a0704, 0x233036a0, 0x00003601,   // eu.su.af_554 bg.mk.ky_332  ab.uz.ky_322 gn.un.un_200 
  0x31381b07, 0x4b006a0e, 0x443c2314, 0x583b4da9,   // tr.tk.az_432 haw.mi.un_550  ky.ug.kk_666 aa.so.om_544 
  // [1e10]
  0x08000c08, 0x133127ee, 0x23157904, 0x0a000108,   // sv.no.un_430 gd.az.et_422  war.ca.un_320 en.pt.un_430 
  0x18001907, 0x3b000108, 0xfc1d01a4, 0x062552ec,   // gl.ga.un_420 en.so.un_430  en.la.zzp_433 ha.eu.de_644 
  0x1508040c, 0x583b48ad, 0x34005307, 0x330e3ead,   // ru.uk.un_543 tt.so.om_643  ht.xh.un_420 rm.is.nn_643 
  0x24003e07, 0x23384409, 0x3f321604, 0x0e002e16,   // rm.eo.un_420 kk.tk.ky_444  hr.bs.af_332 fo.is.un_720 
  // [1e20]
  0x4e252f0d, 0x63064e04, 0x1d051507, 0x4851200c,   // su.eu.ay_554 ay.de.sco_332  un.fr.la_432 sq.kl.tt_543 
  0x12002804, 0x045c100d, 0x0a11380c, 0x6a004b12,   // sd.ur.un_320 lt.sa.fi_554  tk.ro.mk_543 mi.haw.un_640 
  0x071504a9, 0x210609a4, 0x3013120d, 0x6a004b13,   // ru.bg.un_540 pl.de.jw_433  hu.et.uz_554 mi.haw.un_650 
  0x07150a02, 0x07000a12, 0x2c202aa9, 0x1200280d,   // mk.bg.un_220 mk.bg.un_640  mt.sq.fy_544 sd.ur.un_540 
  // [1e30]
  0x163b290c, 0x32001609, 0x1044080c, 0x352515ad,   // sl.so.hr_543 hr.bs.un_440  uk.kk.be_543 un.mn.tg_643 
  0x48002904, 0x23004807, 0x16002e04, 0x35303cad,   // sl.tt.un_320 tt.ky.un_420  fo.hr.un_320 ug.uz.tg_643 
  0x1e002019, 0x183c230d, 0x5e4c2108, 0x44234811,   // ti.am.un_750 ky.ug.ar_554  jw.wo.ts_443 tt.ky.kk_653 
  0x2d22250c, 0x26000104, 0x73284ba0, 0x150301a4,   // eu.oc.sk_543 en.ia.un_320  mi.sw.ny_322 en.nl.un_433 
  // [1e40]
  0x28002507, 0x03574311, 0x3b231fa7, 0x482315ad,   // eu.sw.un_420 ie.na.nl_653  cy.ca.so_532 un.ky.tt_643 
  0x2d001f02, 0x12000d18, 0x5e386755, 0x2305220d,   // cy.sk.un_220 cs.hu.un_740  ak.tk.ts_442 oc.fr.ca_554 
  0x0e2e0207, 0x48002319, 0x3c00230d, 0x34003d07,   // da.fo.is_432 ky.tt.un_750  ky.ug.un_540 ku.ps.un_420 
  0x2100220d, 0x303538ee, 0x37005d14, 0x4200050d,   // oc.jw.un_540 tk.tg.uz_422  ss.st.un_660 fr.co.un_540 
  // [1e50]
  0x2123050d, 0x35303ca4, 0xfc0163a0, 0x6a0451ec,   // fr.ca.jw_554 ug.uz.tg_433  sco.en.zzp_322 kl.fi.haw_644 
  0x05002204, 0x250d47a4, 0x25000104, 0x23003408,   // oc.fr.un_320 sn.cs.eu_433  en.eu.un_320 ps.ky.un_430 
  0x111d0107, 0x21042f02, 0x3400280c, 0x060f4207,   // en.la.ro_432 su.fi.jw_222  sd.ps.un_530 co.lv.de_432 
  0x22052355, 0x04005a04, 0x511e1c05, 0x0f002504,   // ca.fr.oc_442 sm.fi.un_320  id.ms.kl_333 eu.lv.un_320 
  // [1e60]
  0x42005212, 0x0d0913a9, 0x58004b05, 0x15032412,   // ha.co.un_640 bh.hi.ne_544  mi.om.un_330 eo.nl.un_654 
  0x0e2e1314, 0x731d0f0c, 0x04131d0b, 0x05271808,   // et.fo.is_666 lv.la.ny_543  la.et.fi_542 ga.gd.fr_443 
  0x53000207, 0x42005312, 0x242d0d0d, 0x04073713,   // da.ht.un_420 ht.co.un_640  cs.sk.eo_554 ba.bg.ru_665 
  0x072a58a9, 0x3f0451ee, 0x1f002202, 0x05005307,   // om.mt.it_544 kl.fi.af_422  oc.cy.un_220 ht.fr.un_420 
  // [1e70]
  0x51000408, 0x3d182107, 0x1a794d04, 0x0304510c,   // fi.kl.un_430 fa.ar.ku_432  aa.war.tl_332 kl.fi.nl_543 
  0x3f51040c, 0x37134d55, 0x04001005, 0x025b4212,   // fi.kl.af_543 aa.et.st_442  be.ru.un_330 co.sg.da_654 
  0x351536a0, 0x24373bee, 0x302d0d09, 0x2200230c,   // ab.tg.un_320 so.st.eo_422  cs.sk.uz_444 ca.oc.un_530 
  0x34123d04, 0x3000311b, 0x34062102, 0x4b000407,   // ku.ur.ps_332 az.uz.un_770  jw.de.xh_222 fi.mi.un_420 
  // [1e80]
  0x070a1709, 0x39002a2b, 0x3b000404, 0x30383c07,   // sr.mk.bg_444 bo.dz.un_980  fi.so.un_320 ug.tk.uz_432 
  0x0700300e, 0x2e0c20ee, 0x15006308, 0x3c002313,   // uz.bg.un_550 sq.sv.fo_422  sco.un.un_430 ky.ug.un_650 
  0x7500291b, 0x05041307, 0x080a0713, 0x113e1ca4,   // sl.nso.un_770 et.fi.fr_432  bg.mk.uk_665 id.rm.ro_433 
  0x4700460d, 0x59475513, 0x55004607, 0x5578590c,   // qu.sn.un_540 rw.sn.rn_665  qu.rw.un_420 rn.ve.rw_543 
  // [1e90]
  0x10006108, 0x55004608, 0x1a006b07, 0x22002109,   // za.lt.un_430 qu.rw.un_430  ceb.tl.un_420 jw.oc.un_440 
  0x646555a0, 0x18213407, 0x3e511312, 0x422f4c07,   // rw.gv.lg_322 ps.fa.ar_432  et.kl.rm_654 wo.su.co_432 
  0x070a150d, 0x40005e08, 0x0c1a6b07, 0x39004308,   // un.mk.bg_554 ts.lb.un_430  ceb.tl.sv_432 ie.br.un_430 
  0x206534ad, 0x681f1d07, 0x3f006b0c, 0x04352505,   // xh.gv.sq_643 la.cy.ig_432  ceb.af.un_530 mn.tg.ru_333 
  // [1ea0]
  0x1b004802, 0x0a005204, 0x0a040705, 0x28583f04,   // tt.tr.un_220 ha.pt.un_320  bg.ru.mk_333 af.om.sw_332 
  0x6537620c, 0x61004813, 0x2100220e, 0x40180605,   // kha.st.gv_543 tt.za.un_650  oc.jw.un_550 de.ga.lb_333 
  0x021bfe07, 0x20001807, 0x40000623, 0x0300200e,   // tlh.tr.da_432 ga.sq.un_420  de.lb.un_880 sq.nl.un_550 
  0x47545114, 0x28003423, 0x632065af, 0x15003c13,   // kl.ik.sn_666 ps.sd.un_880  gv.sq.sco_655 ug.un.un_650 
  // [1eb0]
  0x02003012, 0x3e1151ec, 0x1c2f2112, 0x31006119,   // uz.da.un_640 kl.ro.rm_644  jw.su.id_654 za.az.un_750 
  0x42513e11, 0x10221da0, 0x58656204, 0x0e001a02,   // rm.kl.co_653 la.oc.lt_322  kha.gv.om_332 tl.is.un_220 
  0x3800350e, 0x3b000304, 0x3b002702, 0x25001512,   // tg.tk.un_550 nl.so.un_320  gd.so.un_220 un.mn.un_640 
  0x36153512, 0x00007515, 0x65022004, 0x10000f0d,   // tg.ab.un_640 nso.un.un_700  sq.da.gv_332 lv.lt.un_540 
  // [1ec0]
  0x46211dee, 0x153b650c, 0x375f780e, 0x1f061513,   // la.jw.qu_422 gv.so.un_543  ve.tn.st_555 un.de.cy_665 
  0x343012ee, 0x3b20520c, 0x3f400604, 0x18003d04,   // ur.uz.ps_422 ha.sq.so_543  de.lb.af_332 ku.ar.un_320 
  0x0165430c, 0x20005204, 0x48003004, 0x37002005,   // ie.gv.en_543 ha.sq.un_320  uz.tt.un_320 sq.st.un_330 
  0x28000e02, 0x23442555, 0x07100a04, 0x02001302,   // is.sw.un_220 mn.kk.ky_442  mk.be.bg_332 et.da.un_220 
  // [1ed0]
  0x1300fe05, 0x02000c0d, 0x1000081a, 0x2548150c,   // tlh.et.un_330 sv.da.un_540  uk.be.un_760 un.tt.mn_543 
  0x20311bec, 0x40004702, 0x16003b07, 0x0800440e,   // tr.az.sq_644 sn.lb.un_220  so.hr.un_420 kk.uk.un_550 
  0x29002002, 0x53004a04, 0x27050da0, 0x04003c12,   // sq.sl.un_220 yo.ht.un_320  cs.fr.gd_322 ug.ru.un_640 
  0x021b3907, 0x1700291a, 0x79220504, 0x494a2707,   // br.tr.da_432 sl.sr.un_760  fr.oc.war_332 gd.yo.to_432 
  // [1ee0]
  0x20001e13, 0x48002309, 0x233c4414, 0x30003514,   // am.ti.un_650 ky.tt.un_440  kk.ug.ky_666 tg.uz.un_660 
  0x79595513, 0x3b002704, 0x19794dee, 0x3f004013,   // rw.rn.war_665 gd.so.un_320  aa.war.gl_422 lb.af.un_650 
  0x20001109, 0x2d0f1a02, 0x23044407, 0x3d002304,   // ro.sq.un_440 tl.lv.sk_222  kk.ru.ky_432 ky.ku.un_320 
  0x23003c07, 0x07170aa0, 0x34001108, 0x5e005505,   // ug.ky.un_420 mk.sr.bg_322  ro.xh.un_430 rw.ts.un_330 
  // [1ef0]
  0x20000f02, 0x21303d07, 0x481023af, 0x1c003802,   // lv.sq.un_220 ku.uz.fa_432  ky.be.tt_655 tk.id.un_220 
  0x4a002105, 0x0700250d, 0x17164a0c, 0x1e002007,   // jw.yo.un_330 mn.bg.un_540  yo.hr.sr_543 ti.am.un_420 
  0x386301a7, 0x65000207, 0x1221280d, 0x53005e07,   // en.sco.tk_532 da.gv.un_420  sd.fa.ur_554 ts.ht.un_420 
  0x040a1107, 0x3537300c, 0x39002a2a, 0x03002d02,   // ro.mk.ru_432 uz.ba.tg_543  bo.dz.un_970 sk.nl.un_220 
  // [1f00]
  0x08070a0d, 0x0f0e4604, 0x1b004808, 0x46301baf,   // mk.bg.uk_554 qu.is.lv_332  tt.tr.un_430 tr.uz.qu_655 
  0x0a173612, 0x03000607, 0x21004604, 0x183d34a7,   // ab.sr.mk_654 de.nl.un_420  qu.jw.un_320 ps.ku.ar_532 
  0x12002d0c, 0x04100809, 0x154837a4, 0x190a18a9,   // sk.hu.un_530 uk.be.ru_444  ba.tt.un_433 ga.pt.gl_544 
  0x10000604, 0x28001208, 0x37483c13, 0x23003504,   // de.lt.un_320 ur.sd.un_430  ug.tt.ba_665 tg.ky.un_320 
  // [1f10]
  0x2500380d, 0x1100370d, 0x23303408, 0x1c0d090e,   // tk.mn.un_540 ba.ro.un_540  ps.uz.ky_443 hi.ne.mr_555 
  0x09000d0e, 0x04003e04, 0x154006ee, 0x422322a7,   // ne.hi.un_550 rm.fi.un_320  de.lb.un_422 oc.ca.co_532 
  0x24285209, 0x5d63fc04, 0x57000622, 0x49004b0c,   // ha.sw.eo_444 zzp.sco.ss_332  de.na.un_870 mi.to.un_530 
  0x1240060c, 0x5a6a4b08, 0x494d3ba4, 0x374975a7,   // de.lb.hu_543 mi.haw.sm_443  so.aa.to_433 nso.to.st_532 
  // [1f20]
  0x01000808, 0x00002a24, 0x5a003707, 0x043623a0,   // no.en.un_430 mt.un.un_900  st.sm.un_420 ky.ab.ru_322 
  0x604a4ca4, 0x4600200d, 0x480451a4, 0x5d3545ac,   // wo.yo.vo_433 sq.qu.un_540  kl.fi.tt_433 ln.zu.ss_632 
  0x65136308, 0x1c001e0d, 0x4200fc08, 0x5300340b,   // sco.et.gv_443 ms.id.un_540  zzp.co.un_430 xh.ht.un_520 
  0x51041f0d, 0x222123a7, 0x0a313807, 0x17730aa4,   // cy.fi.kl_554 ca.jw.oc_532  tk.az.pt_432 pt.ny.sr_433 
  // [1f30]
  0x5146200c, 0x26242909, 0x17297612, 0x0400510c,   // sq.qu.kl_543 sl.eo.ia_444  crs.sl.sr_654 kl.fi.un_530 
  0x494a3b04, 0x5a001f02, 0x19245fee, 0x070a2f07,   // so.yo.to_332 cy.sm.un_220  tn.eo.gl_422 su.pt.it_432 
  0x2b00010c, 0x10000404, 0x5420510d, 0x3800372b,   // en.vi.un_530 ru.be.un_320  kl.sq.ik_554 ba.tk.un_980 
  0x121821a4, 0x0c484d07, 0x421d2305, 0x53002204,   // fa.ar.ur_433 aa.tt.sv_432  ca.la.co_333 oc.ht.un_320 
  // [1f40]
  0x2300220c, 0x6563570e, 0x0800040b, 0x422d0d02,   // oc.ca.un_530 na.sco.gv_555  ru.uk.un_520 cs.sk.co_222 
  0x796b1a07, 0x4b004913, 0x175f750c, 0x2e002304,   // tl.ceb.war_432 to.mi.un_650  nso.tn.sr_543 ca.fo.un_320 
  0x292d0d0d, 0x375f0a12, 0x49005a13, 0x124820ee,   // cs.sk.sl_554 pt.tn.st_654  sm.to.un_650 sq.tt.hu_422 
  0x00004b24, 0x0354040c, 0x4c346aa0, 0x08103655,   // mi.un.un_900 fi.ik.nl_543  haw.xh.wo_322 ab.be.uk_442 
  // [1f50]
  0x56002d08, 0x20515409, 0x0a0423a0, 0x0c330804,   // sk.mg.un_430 ik.kl.sq_444  ky.ru.mk_322 no.nn.sv_332 
  0x083c3008, 0x20004602, 0x4842510c, 0x0438510c,   // uz.ug.uk_443 qu.sq.un_220  kl.co.tt_543 kl.tk.fi_543 
  0x4800530d, 0x042e20af, 0x0a00170c, 0x58514608,   // ht.tt.un_540 sq.fo.fi_655  sr.mk.un_530 qu.kl.om_443 
  0x040a0709, 0x21005304, 0x1c130913, 0x0e2e040c,   // bg.mk.ru_444 ht.jw.un_320  hi.bh.mr_665 fi.fo.is_543 
  // [1f60]
  0x0e002e14, 0x4f042212, 0x311b11a4, 0x18042708,   // fo.is.un_660 oc.fi.bi_654  ro.tr.az_433 gd.fi.ga_443 
  0x281838a7, 0x48000c04, 0x04104f13, 0x15003512,   // tk.ga.sw_532 sv.tt.un_320  bi.lt.fi_665 tg.un.un_640 
  0x372c2207, 0x15001f0c, 0x07482505, 0x37271fee,   // oc.fy.st_432 cy.un.un_530  mn.tt.bg_333 cy.gd.st_422 
  0x4f061f08, 0x21003b0e, 0x21283ba4, 0x0900120d,   // cy.de.bi_443 ks.fa.un_550  ks.sd.fa_433 hu.pl.un_540 
  // [1f70]
  0x12003d0c, 0x30003c1a, 0x23001012, 0x10000602,   // ku.ur.un_530 ug.uz.un_760  be.ky.un_640 de.lt.un_220 
  0x2800680e, 0x3b004607, 0x080e50a4, 0x40570608,   // ig.sw.un_550 qu.so.un_420  fj.is.no_433 de.na.lb_443 
  0x221004a9, 0x4f04130c, 0x21002305, 0x211230ad,   // fi.lt.oc_544 et.fi.bi_543  ca.jw.un_330 uz.ur.fa_643 
  0x371530a7, 0x2d091207, 0x3000340e, 0x32001614,   // uz.ba.un_520 hu.pl.sk_432  ps.uz.un_550 hr.bs.un_660 
  // [1f80]
  0x043507a0, 0x15001522, 0x091c13af, 0x13030407,   // bg.tg.ru_322 un.un.un_870  bh.mr.hi_655 fi.nl.et_432 
  0x34122808, 0x0a1736a4, 0x3b005421, 0x17070a55,   // sd.ur.ps_443 ab.sr.mk_433  ik.so.un_860 mk.bg.sr_442 
  0x3b00582a, 0x0804170b, 0x2d000614, 0x64000212,   // om.so.un_970 sr.ru.uk_542  de.sk.un_660 da.lg.un_640 
  0x6b656807, 0x642147ec, 0xfc000602, 0x6803580c,   // ig.gv.ceb_432 sn.jw.lg_644  de.zzp.un_220 om.nl.ig_543 
  // [1f90]
  0x0200461b, 0x170a07a4, 0x2300382b, 0x351530ac,   // qu.da.un_770 bg.mk.sr_433  tk.ky.un_980 uz.tg.un_620 
  0x4600020c, 0x4702460d, 0x06001208, 0x1c000207,   // da.qu.un_530 qu.da.sn_554  hu.de.un_430 da.id.un_420 
  0x0d002d0b, 0x17080404, 0x2d0d0605, 0x0d2d3b08,   // sk.cs.un_520 ru.uk.sr_332  de.cs.sk_333 so.sk.cs_443 
  0x19005104, 0x5500020d, 0x40033f04, 0x3b005823,   // kl.gl.un_320 da.rw.un_540  af.nl.lb_332 om.so.un_880 
  // [1fa0]
  0x584c4d0c, 0x3d002807, 0x21281260, 0x151b2aee,   // aa.wo.om_543 sd.ku.un_420  ur.sd.fa_664 mt.tr.un_422 
  0x2d000613, 0x0600330d, 0x2d065ca9, 0x4600021a,   // de.sk.un_650 nn.de.un_540  sa.de.sk_544 da.qu.un_760 
  0x46000214, 0x30353c13, 0xfc1d5208, 0x0a1710af,   // da.qu.un_660 ug.tg.uz_665  ha.la.zzp_443 be.sr.mk_655 
  0x08071004, 0x0d5c0907, 0x3400210b, 0x07001505,   // be.bg.uk_332 hi.sa.ne_432  fa.ps.un_520 un.bg.un_330 
  // [1fb0]
  0x13000918, 0x48372507, 0x0d5c13a4, 0x251535a9,   // hi.bh.un_740 mn.ba.tt_432  bh.sa.ne_433 tg.mn.un_540 
  0x060e5805, 0x07110a12, 0x63001d1b, 0x35001107,   // om.is.de_333 mk.ro.bg_654  la.sco.un_770 ro.tg.un_420 
  0x3d00340d, 0x0735080c, 0x21001d07, 0x18342811,   // ps.ku.un_540 uk.tg.bg_543  la.jw.un_420 sd.ps.ar_653 
  0x5c001c12, 0x04070aa4, 0x17000a08, 0x0411150c,   // mr.sa.un_640 mk.bg.ru_433  mk.sr.un_430 un.ro.ru_543 
  // [1fc0]
  0x1d003704, 0x040715a9, 0x3b002113, 0x234410a4,   // st.la.un_320 un.bg.ru_544  fa.ks.un_650 be.kk.ky_433 
  0x5c001c04, 0x07353009, 0x4600fe12, 0x48003c1a,   // mr.sa.un_320 uz.tg.bg_444  tlh.qu.un_640 ug.tt.un_760 
  0x37005f11, 0x1d004f08, 0x09001c11, 0x12213da7,   // tn.st.un_630 bi.la.un_430  mr.hi.un_630 ku.fa.ur_532 
  0x12303408, 0x3308020c, 0x25000a02, 0x273e100c,   // ps.uz.ur_443 da.no.nn_543  mk.mn.un_220 lt.rm.gd_543 
  // [1fd0]
  0x30170a09, 0x3e1d2405, 0x091c0da0, 0x1515230c,   // mk.sr.uz_444 eo.la.rm_333  ne.mr.hi_322 ky.un.un_530 
  0x44001509, 0x13091c14, 0x3c4423a4, 0x44121809,   // un.kk.un_440 mr.hi.bh_666  ky.kk.ug_433 ar.ur.kk_444 
  0x5d000104, 0x01003704, 0x186562a7, 0x44173807,   // en.ss.un_320 st.en.un_320  kha.gv.ga_532 tk.sr.kk_432 
  0x48001704, 0x153c1507, 0x5c004602, 0x040810a4,   // sr.tt.un_320 un.ug.un_432  qu.sa.un_220 be.uk.ru_433 
  // [1fe0]
  0x511d1004, 0x3e001d04, 0x08001013, 0x511d42ac,   // lt.la.kl_332 la.rm.un_320  be.uk.un_650 co.la.kl_632 
  0x213d12a4, 0x5c130908, 0x32002907, 0x0d005c07,   // ur.ku.fa_433 hi.bh.sa_443  sl.bs.un_420 sa.ne.un_420 
  0x18000304, 0x10001114, 0x3f033ba9, 0x10000822,   // nl.ga.un_320 ro.be.un_660  so.nl.af_544 uk.be.un_870 
  0x583308a0, 0x4d3b040d, 0x64580404, 0x283b04a4,   // no.nn.om_322 fi.so.aa_554  fi.om.lg_332 fi.so.sw_433 
  // [1ff0]
  0x30070aa4, 0x17001005, 0x1b033b07, 0x3f2d620c,   // mk.bg.uz_433 be.sr.un_330  so.nl.tr_432 kha.sk.af_543 
  0x03644ca0, 0x38233c13, 0x1a6b79af, 0x1828210c,   // wo.lg.nl_322 ug.ky.tk_665  war.ceb.tl_655 fa.sd.ar_543 
  0x1e1c12ee, 0x4c6a04ee, 0x40000402, 0x0e002e21,   // hu.id.ms_422 fi.haw.wo_422  fi.lb.un_220 fo.is.un_860 
  0x3000fe0d, 0x24025dec, 0x3100fe13, 0x10000711,   // tlh.uz.un_540 ss.da.eo_644  tlh.az.un_650 bg.be.un_630 
  
  // [2000]
  0x026357ee, 0x55005922, 0x3c00230e, 0x3b342804,   // na.sco.da_422 rn.rw.un_870  ky.ug.un_550 sw.xh.so_332 
  0x341821ad, 0x69007622, 0x280e1807, 0x13000921,   // fa.ar.ps_643 crs.mfe.un_870  ga.is.sw_432 hi.bh.un_860 
  0x2c1bfe02, 0x3b003108, 0x15005104, 0x3b3130ee,   // tlh.tr.fy_222 az.so.un_430  kl.un.un_320 uz.az.so_422 
  0x6b681dee, 0x5c080205, 0x055851ad, 0x3f130407,   // la.ig.ceb_422 da.no.sa_333  kl.om.fr_643 fi.et.af_432 
  // [2010]
  0x34182112, 0x0c006505, 0x312e0ea6, 0x40583b11,   // fa.ar.ps_654 gv.sv.un_330  is.fo.az_521 so.om.lb_653 
  0x3b3f040c, 0x5a000402, 0x32000602, 0x1c0913a4,   // fi.af.so_543 fi.sm.un_220  de.bs.un_220 bh.hi.mr_433 
  0x032d2a04, 0xfe2e310e, 0x2a063f04, 0x53637612,   // mt.sk.nl_332 az.fo.tlh_555  af.de.mt_332 crs.sco.ht_654 
  0x15570e07, 0x35003604, 0x01004f04, 0x01366504,   // is.na.un_432 ab.tg.un_320  bi.en.un_320 gv.gn.en_332 
  // [2020]
  0x0f302e04, 0x2e0e31ec, 0x0e005122, 0x2e020602,   // fo.uz.lv_332 az.is.fo_644  kl.is.un_870 de.da.fo_222 
  0x39002208, 0x29094e0c, 0x75000f2a, 0x52002305,   // oc.br.un_430 ay.pl.sl_543  lv.nso.un_970 ca.ha.un_330 
  0x100a04a0, 0x170e3fa7, 0x09002a02, 0x0c000104,   // ru.mk.be_322 af.is.sr_532  mt.pl.un_220 en.sv.un_320 
  0x0f003e04, 0x602322a4, 0x1c000d09, 0x04101705,   // rm.lv.un_320 oc.ca.vo_433  ne.mr.un_440 sr.be.ru_333 
  // [2030]
  0x052253ad, 0x0c052704, 0x0b2d0d55, 0x3c2344ec,   // ht.oc.fr_643 gd.fr.sv_332  cs.sk.es_442 kk.ky.ug_644 
  0x20190bee, 0x69007614, 0x39103e04, 0x301234af,   // es.gl.sq_422 crs.mfe.un_660  rm.lt.br_332 ps.ur.uz_655 
  0x040807a4, 0x13171608, 0x04134f0c, 0x300916af,   // bg.uk.ru_433 hr.sr.et_443  bi.et.fi_543 hr.pl.uz_655 
  0x2400fe1b, 0x06007909, 0x301309a7, 0x21283d05,   // tlh.eo.un_770 war.de.un_440  pl.et.uz_532 ku.sd.fa_333 
  // [2040]
  0x01000502, 0x2c033f60, 0x16001308, 0x1228230c,   // fr.en.un_220 af.nl.fy_664  et.hr.un_430 ky.sd.ur_543 
  0x194205a6, 0x00006024, 0x3e0f4007, 0x0000051c,   // fr.co.gl_521 vo.un.un_900  lb.lv.rm_432 fr.un.un_800 
  0x2c003805, 0x0a04170d, 0x4c212fec, 0x04173502,   // tk.fy.un_330 sr.ru.mk_554  su.jw.wo_644 tg.sr.ru_222 
  0x0800441b, 0x22005308, 0x19000b12, 0x21004002,   // kk.uk.un_770 ht.oc.un_430  es.gl.un_640 lb.jw.un_220 
  // [2050]
  0x342130a0, 0x34183ca0, 0x0d001c08, 0x04001323,   // uz.fa.ps_322 ug.ar.ps_322  mr.ne.un_430 et.fi.un_880 
  0x4a004c09, 0x16297511, 0x12000504, 0x31003807,   // wo.yo.un_440 nso.sl.hr_653  fr.hu.un_320 tk.az.un_420 
  0x3f022aec, 0x18364c02, 0x1500150d, 0x12002122,   // mt.da.af_644 wo.gn.ga_222  un.un.un_540 fa.ur.un_870 
  0x2500381b, 0x0d001c19, 0x05001802, 0x3744380b,   // tk.mn.un_770 mr.ne.un_750  ga.fr.un_220 tk.kk.ba_542 
  // [2060]
  0x113835ac, 0x34214712, 0x21fc4a05, 0x25002312,   // tg.tk.ro_632 sn.jw.xh_654  yo.zzp.jw_333 ky.mn.un_640 
  0x084415a0, 0x2a001f1a, 0x300a15a7, 0x15005719,   // un.kk.uk_322 cy.mt.un_760  un.mk.uz_532 na.un.un_750 
  0x0d00091b, 0x08001509, 0x65003918, 0x091c5c08,   // hi.ne.un_770 un.uk.un_440  br.gv.un_740 sa.mr.hi_443 
  0x1500570d, 0x04170804, 0x08000713, 0x1e00202a,   // na.un.un_540 uk.sr.ru_332  bg.uk.un_650 ti.am.un_970 
  // [2070]
  0x4835fc04, 0x30004419, 0x0d091c09, 0x3418210c,   // zzp.zu.tt_332 kk.uz.un_750  mr.hi.ne_444 fa.ar.ps_543 
  0x3200290e, 0x10150412, 0x46001504, 0x07000408,   // sl.bs.un_550 ru.be.un_640  un.qu.un_320 ru.bg.un_430 
  0x11002313, 0xfe1d360c, 0x1e001c09, 0x34004c07,   // ky.ro.un_650 gn.la.tlh_543  id.ms.un_440 wo.xh.un_420 
  0x3e001c04, 0x15100a0c, 0x3f000321, 0x5f007512,   // id.rm.un_320 mk.be.un_543  nl.af.un_860 nso.tn.un_640 
  // [2080]
  0x4400080e, 0x07001002, 0x070a1708, 0x170a07a0,   // uk.kk.un_550 be.bg.un_220  sr.mk.bg_443 bg.mk.sr_322 
  0x28213b04, 0x183428a9, 0x4012060d, 0x4d002a1a,   // ks.fa.sd_332 sd.ps.ar_544  de.hu.lb_554 mt.aa.un_760 
  0x18002112, 0x152242a0, 0x2a00310d, 0x30311b08,   // fa.ar.un_640 co.oc.un_322  az.mt.un_540 tr.az.uz_443 
  0x30002f0e, 0x00005806, 0x18004d0d, 0x34003d12,   // su.uz.un_550 om.un.un_400  aa.ga.un_540 ku.ps.un_640 
  // [2090]
  0x041710a0, 0x1828345a, 0x120258a4, 0x38001b02,   // be.sr.ru_322 ps.sd.ar_553  om.da.hu_433 tr.tk.un_220 
  0x343d30a4, 0x1500360d, 0x0a001711, 0x30003c13,   // uz.ku.ps_433 ab.un.un_540  sr.mk.un_630 ug.uz.un_650 
  0x07381008, 0x21001205, 0x1b322004, 0x04000a05,   // be.tk.bg_443 ur.fa.un_330  sq.bs.tr_332 mk.ru.un_330 
  0x34003504, 0x281e1c08, 0x6a285012, 0x6100fa14,   // zu.xh.un_320 id.ms.sw_443  fj.sw.haw_654 nr.za.un_660 
  // [20a0]
  0x52007319, 0x40000808, 0x0100fc04, 0x4b736a0c,   // ny.ha.un_750 no.lb.un_430  zzp.en.un_320 haw.ny.mi_543 
  0x080213ee, 0x6a2852a4, 0x0928520c, 0x50522114,   // et.da.no_422 ha.sw.haw_433  ha.sw.pl_543 jw.ha.fj_666 
  0x5200730d, 0x48003807, 0x52005713, 0x0e002d02,   // ny.ha.un_540 tk.tt.un_420  na.ha.un_650 sk.is.un_220 
  0x0000510f, 0x213430ee, 0x28645207, 0x1e1c52ec,   // kl.un.un_600 uz.ps.fa_422  ha.lg.sw_432 ha.id.ms_644 
  // [20b0]
  0x4800440d, 0x44363807, 0x38004802, 0x6428090d,   // kk.tt.un_540 tk.ab.kk_432  tt.tk.un_220 pl.sw.lg_554 
  0x15041113, 0x384d5207, 0x645f73ee, 0x28677860,   // ro.ru.un_665 ha.aa.tk_432  ny.tn.lg_422 ve.ak.sw_664 
  0x524b6714, 0x1e1c73ee, 0x7300281b, 0x0800130c,   // ak.mi.ha_666 ny.id.ms_422  sw.ny.un_770 et.no.un_530 
  0x28003221, 0x066269a4, 0x0e002d0b, 0x21123008,   // bs.sd.un_860 mfe.kha.de_433  sk.is.un_520 uz.ur.fa_443 
  // [20c0]
  0x2d000e0c, 0x21303b05, 0x30004805, 0x53633904,   // is.sk.un_530 ks.uz.fa_333  tt.uz.un_330 br.sco.ht_332 
  0x0e031b0c, 0x47005708, 0x63000122, 0x64000607,   // tr.nl.is_543 na.sn.un_430  en.sco.un_870 de.lg.un_420 
  0x10000805, 0x06004713, 0x1813510b, 0x405e4707,   // uk.be.un_330 sn.de.un_650  kl.et.ga_542 sn.ts.lb_432 
  0x3800100b, 0x47595509, 0x46006402, 0x67007314,   // lt.tk.un_520 rw.rn.sn_444  lg.qu.un_220 ny.ak.un_660 
  // [20d0]
  0x35442304, 0x127909a9, 0x2e003604, 0x12213007,   // ky.kk.tg_332 pl.war.hu_544  gn.fo.un_320 uz.fa.ur_432 
  0x3400210e, 0x254423a6, 0x49005a0e, 0x301b310d,   // fa.ps.un_550 ky.kk.mn_521  sm.to.un_550 az.tr.uz_554 
  0x38223ea0, 0x061a2808, 0x1000650c, 0x0a2348a4,   // rm.oc.tk_322 sw.tl.de_443  gv.lt.un_530 tt.ky.mk_433 
  0x0a1011a7, 0x5d004520, 0x63471ca0, 0x06385e5a,   // ro.be.mk_532 ln.ss.un_850  id.sn.sco_322 ts.tk.de_553 
  // [20e0]
  0x214d450c, 0x38443712, 0x374838af, 0x214902a4,   // ln.aa.jw_543 ba.kk.tk_654  tk.tt.ba_655 da.to.jw_433 
  0x08000209, 0x04003608, 0x4b005e14, 0x351b0207,   // da.no.un_440 gn.fi.un_430  ts.mi.un_660 da.tr.zu_432 
  0x12003d0e, 0x100a0702, 0x44233cec, 0x08104412,   // ku.ur.un_550 bg.mk.be_222  ug.ky.kk_644 kk.be.uk_654 
  0x2100640e, 0x24026ba4, 0x28005204, 0x0000050f,   // lg.jw.un_550 ceb.da.eo_433  ha.sw.un_320 fr.un.un_600 
  // [20f0]
  0x1c090d07, 0x356002a4, 0x50005d07, 0x48374412,   // ne.hi.mr_432 da.vo.zu_433  ss.fj.un_420 kk.ba.tt_654 
  0x36231504, 0x03002802, 0x040313ee, 0x02001508,   // un.ky.ab_332 sw.nl.un_220  et.nl.fi_422 un.da.un_430 
  0x644c3fa4, 0x40fc25ee, 0x07000823, 0x02004b08,   // af.wo.lg_433 eu.zzp.lb_422  uk.bg.un_880 mi.da.un_430 
  0x584c64af, 0x280201a4, 0x033f13a0, 0x5000020d,   // lg.wo.om_655 en.da.sw_433  et.af.nl_322 da.fj.un_540 
  // [2100]
  0x3f002f0d, 0x12212807, 0x044c510c, 0x112335af,   // su.af.un_540 sd.fa.ur_432  kl.wo.fi_543 tg.ky.ro_655 
  0x303810a7, 0x42000907, 0x2e0e18ec, 0x3b5c28ee,   // be.tk.uz_532 pl.co.un_420  ga.is.fo_644 sw.sa.so_422 
  0x40002504, 0x32000f04, 0x48373c0e, 0x25071511,   // eu.lb.un_320 lv.bs.un_320  ug.ba.tt_555 un.bg.mn_653 
  0x38041508, 0x3217420e, 0x28001207, 0x3000251b,   // un.ru.tk_443 co.sr.bs_555  ur.sd.un_420 mn.uz.un_770 
  // [2110]
  0xfc330804, 0x32004d04, 0x03002c02, 0x041e1c5a,   // no.nn.zzp_332 aa.bs.un_320  fy.nl.un_220 id.ms.fi_553 
  0x133f2c07, 0x12283b07, 0x20000c05, 0x0410380c,   // fy.af.et_432 ks.sd.ur_432  sv.sq.un_330 tk.be.ru_543 
  0x1828340e, 0x07040a02, 0x5d285507, 0x643b6307,   // ps.sd.ar_555 mk.ru.bg_222  rw.sw.ss_432 sco.so.lg_432 
  0x4a133b5a, 0x680209a9, 0x020f4b09, 0x12002809,   // so.et.yo_553 pl.da.ig_544  mi.lv.da_444 sd.ur.un_440 
  // [2120]
  0x37401308, 0x45133b0c, 0x1c13095a, 0x4800380d,   // et.lb.st_443 so.et.ln_543  hi.bh.mr_553 tk.tt.un_540 
  0x0f420d0c, 0x5a504b07, 0x16001802, 0x4a000104,   // cs.co.lv_543 mi.fj.sm_432  ga.hr.un_220 en.yo.un_320 
  0x6215010c, 0x244d3ba4, 0x484423a7, 0x03003408,   // en.kha.un_530 so.aa.eo_433  ky.kk.tt_532 xh.nl.un_430 
  0x34003b13, 0x18213404, 0x2548370c, 0x1f006e2a,   // so.xh.un_650 ps.fa.ar_332  ba.tt.mn_543 hmn.cy.un_970 
  // [2130]
  0x133f4d0d, 0x0e001802, 0x134c010c, 0x170a1005,   // aa.af.et_554 ga.is.un_220  en.wo.et_543 be.mk.sr_333 
  0x650f13a4, 0x3f001308, 0x38442313, 0x0b0a19a4,   // et.lv.gv_433 et.af.un_430  ky.kk.tk_665 gl.pt.es_433 
  0x2c3b1307, 0x1d004902, 0x4837380d, 0x1d006313,   // et.so.fy_432 to.la.un_220  tk.ba.tt_554 sco.la.un_650 
  0x5a001d08, 0x081710a4, 0x30080a05, 0x2b001c04,   // la.sm.un_430 be.sr.uk_433  mk.uk.uz_333 id.vi.un_320 
  // [2140]
  0x101504ad, 0x1d006319, 0x08000208, 0x07003507,   // ru.be.un_630 sco.la.un_750  da.no.un_430 tg.bg.un_420 
  0x5c00090c, 0x2c000e07, 0x2c5d4a07, 0x2e330804,   // hi.sa.un_530 is.fy.un_420  yo.ss.fy_432 no.nn.fo_332 
  0x40003e1a, 0x3b000904, 0x2c4a0e07, 0x18213b07,   // rm.lb.un_760 pl.so.un_320  is.yo.fy_432 ks.fa.ar_432 
  0x19005d08, 0x18001d12, 0x360e5d05, 0x07170a12,   // ss.gl.un_430 la.ga.un_640  ss.is.gn_333 mk.sr.bg_654 
  // [2150]
  0x420c0507, 0x10001707, 0x153825ec, 0x06006304,   // fr.sv.co_432 sr.be.un_420  mn.tk.un_644 sco.de.un_320 
  0x12344411, 0x40000612, 0x2300301f, 0x1c0f09a9,   // kk.ps.ur_653 de.lb.un_640  uz.ky.un_840 pl.lv.id_544 
  0x0b003319, 0x23304413, 0x23190b02, 0x44483807,   // as.bn.un_750 kk.uz.ky_665  es.gl.ca_222 tk.tt.kk_432 
  0x3c002304, 0x0d1c5c0b, 0x341828ad, 0x362515ad,   // ky.ug.un_320 sa.mr.ne_542  sd.ar.ps_643 un.mn.ab_643 
  // [2160]
  0x44233c11, 0x283418ee, 0x21003c04, 0x123021ec,   // ug.ky.kk_653 ar.ps.sd_422  ug.fa.un_320 fa.uz.ur_644 
  0x041508af, 0x0000760f, 0x76006919, 0x0e002c04,   // uk.ru.un_650 crs.un.un_600  mfe.crs.un_750 fy.is.un_320 
  0x3500371a, 0x23002111, 0x130d09a4, 0x28003404,   // ba.tg.un_760 fa.ky.un_630  hi.ne.bh_433 ps.sd.un_320 
  0x44003507, 0x12003804, 0x28006402, 0x69005d22,   // tg.kk.un_420 tk.hu.un_320  lg.sw.un_220 ss.mfe.un_870 
  // [2170]
  0x5c1c0d0e, 0x6900761b, 0x1200211a, 0x0000452d,   // ne.mr.sa_555 crs.mfe.un_770  fa.ur.un_760 ln.un.un_A00 
  0x50560204, 0x735f45a9, 0x5d73450c, 0x19230f0c,   // da.mg.fj_332 ln.tn.ny_544  ln.ny.ss_543 lv.ca.gl_543 
  0x53697614, 0x25080404, 0x3e061304, 0x3573550d,   // crs.mfe.ht_666 ru.uk.mn_332  et.de.rm_332 rw.ny.zu_554 
  0x2d0d43a4, 0x5f4532a9, 0x69537660, 0x0e2a0fa4,   // ie.cs.sk_433 bs.ln.tn_544  crs.ht.mfe_664 lv.mt.is_433 
  // [2180]
  0x12300ca4, 0x26004c09, 0x09006508, 0x571f01a0,   // sv.uz.hu_433 wo.ia.un_440  gv.pl.un_430 en.cy.na_322 
  0x16110da4, 0x61006422, 0x0f2e64a4, 0x5f2437ad,   // cs.ro.hr_433 lg.za.un_870  lg.fo.lv_433 st.eo.tn_643 
  0x330802a9, 0x1f00390d, 0x5c255804, 0x03133f05,   // da.no.nn_544 br.cy.un_540  om.eu.sa_332 af.et.nl_333 
  0x0d12090c, 0x6100671a, 0x59347307, 0x39002702,   // pl.hu.cs_543 ak.za.un_760  ny.xh.rn_432 gd.br.un_220 
  // [2190]
  0x2a000f1a, 0x2e0e180d, 0x0200760e, 0x1e0912a0,   // lv.mt.un_760 ga.is.fo_554  crs.da.un_550 hu.pl.ms_322 
  0x42006412, 0x0d002d13, 0x737847ec, 0x330d2da7,   // lg.co.un_640 sk.cs.un_650  sn.ve.ny_644 sk.cs.nn_532 
  0x3b121107, 0x494f520d, 0x1200fc08, 0x2d000d0c,   // ro.hu.so_432 ha.bi.to_554  zzp.hu.un_430 cs.sk.un_530 
  0x2c002e04, 0x2e0e4a0c, 0x373b46a7, 0x6523500b,   // fo.fy.un_320 yo.is.fo_543  qu.so.st_532 fj.ca.gv_542 
  // [21a0]
  0x4767730b, 0x2e4518af, 0x4c000f20, 0x697653af,   // ny.ak.sn_542 ga.ln.fo_655  lv.wo.un_850 ht.crs.mfe_655 
  0x2d610d12, 0x69537613, 0x2e103607, 0x09005a04,   // cs.za.sk_654 crs.ht.mfe_665  gn.lt.fo_432 sm.pl.un_320 
  0x35002313, 0x2d300d12, 0x11100812, 0x032140ee,   // ky.tg.un_650 cs.uz.sk_654  uk.be.ro_654 lb.jw.nl_422 
  0x242a0da0, 0x08002d04, 0x480410a0, 0x10041312,   // cs.mt.eo_322 sk.no.un_320  be.ru.tt_322 et.fi.lt_654 
  // [21b0]
  0x30fe1207, 0x131c09ac, 0x1243130c, 0x13003702,   // hu.tlh.uz_432 hi.mr.bh_632  et.ie.hu_543 st.et.un_220 
  0x0a070402, 0x35003607, 0x34375d07, 0x4838360c,   // ru.bg.mk_222 ab.tg.un_420  ss.st.xh_432 ab.tk.tt_543 
  0x5c000d05, 0x34000d04, 0x3548380c, 0x60003813,   // ne.sa.un_330 cs.xh.un_320  tk.tt.tg_543 tk.vo.un_650 
  0x15004c08, 0x09001c04, 0x2e001209, 0x3700482c,   // wo.un.un_430 mr.hi.un_320  hu.fo.un_440 tt.ba.un_990 
  // [21c0]
  0x0e125da0, 0x0408380c, 0x2e180ea4, 0x17080a04,   // ss.hu.is_322 tk.uk.ru_543  is.ga.fo_433 mk.uk.sr_332 
  0x362d0d02, 0x32472ca0, 0x48001304, 0x483b79a4,   // cs.sk.gn_222 fy.sn.bs_322  et.tt.un_320 war.so.tt_433 
  0x73471ba4, 0x3900730d, 0x07170a13, 0x25002308,   // tr.sn.ny_433 ny.br.un_540  mk.sr.bg_665 ky.mn.un_430 
  0x0a0730a4, 0x0f480da4, 0x48381f0c, 0x600a250c,   // uz.bg.mk_433 cs.tt.lv_433  cy.tk.tt_543 eu.pt.vo_543 
  // [21d0]
  0x04151004, 0x1500300e, 0x1d004905, 0x364410af,   // be.ru.un_320 uz.un.un_550  to.la.un_330 be.kk.ab_655 
  0xfc731107, 0x381f3b02, 0x421120a4, 0x07000808,   // ro.ny.zzp_432 so.cy.tk_222  sq.ro.co_433 uk.bg.un_430 
  0x311b3804, 0x642a1f07, 0x112439a0, 0x041008a9,   // tk.tr.az_332 cy.mt.lg_432  br.eo.ro_322 uk.be.ru_544 
  0x092a1bee, 0x2d001802, 0x12003b0b, 0x0700101a,   // tr.mt.pl_422 ga.sk.un_220  ks.ur.un_520 be.bg.un_760 
  // [21e0]
  0x070a1507, 0x0a351507, 0x3600350e, 0x330802a0,   // un.mk.bg_432 un.tg.mk_432  tg.ab.un_550 da.no.nn_322 
  0x3848670b, 0x29003905, 0xfc1f6505, 0x21342807,   // ak.tt.tk_542 br.sl.un_330  gv.cy.zzp_333 sd.ps.fa_432 
  0x552d0dee, 0x170a30ee, 0x3c2344a9, 0x2c004a04,   // cs.sk.rw_422 uz.mk.sr_422  kk.ky.ug_544 yo.fy.un_320 
  0x18002809, 0x2d0d09ee, 0x35000705, 0x443c230c,   // sd.ar.un_440 pl.cs.sk_422  bg.tg.un_330 ky.ug.kk_543 
  // [21f0]
  0x04150808, 0x0e004a04, 0x5c000905, 0x35003009,   // uk.ru.un_430 yo.is.un_320  hi.sa.un_330 uz.tg.un_440 
  0x341221a7, 0x441530a4, 0x095c0d04, 0x37004419,   // fa.ur.ps_532 uz.kk.un_430  ne.sa.hi_332 kk.ba.un_750 
  0x36170a12, 0x3c303812, 0x07000a05, 0x37000a08,   // mk.sr.ab_654 tk.uz.ug_654  mk.bg.un_330 mk.ba.un_430 
  0x23190b04, 0x0f001b05, 0x44003504, 0x6b011d07,   // es.gl.ca_332 tr.lv.un_330  tg.kk.un_320 la.en.ceb_432 
  // [2200]
  0x2e000e11, 0x09003304, 0x11000f12, 0x230407a0,   // is.fo.un_630 nn.pl.un_320  lv.ro.un_640 bg.ru.ky_322 
  0x6900300d, 0x170738ee, 0x16305e0d, 0x10042304,   // uz.mfe.un_540 tk.bg.sr_422  ts.uz.hr_554 ky.ru.be_332 
  0x1c091302, 0x4b6947a4, 0x02001e04, 0x22064304,   // bh.hi.mr_222 sn.mfe.mi_433  ms.da.un_320 ie.de.oc_332 
  0x1f005807, 0x3b0e2e0c, 0x09002905, 0x080435a0,   // om.cy.un_420 fo.is.so_543  sl.pl.un_330 tg.ru.uk_322 
  // [2210]
  0x1a00790d, 0x19232202, 0x3e1e64a9, 0x081104af,   // war.tl.un_540 oc.ca.gl_222  lg.ms.rm_544 ru.ro.uk_655 
  0x3b00110d, 0x3b00650e, 0x060501a0, 0x31092e07,   // ro.so.un_540 gv.so.un_550  en.fr.de_322 fo.pl.az_432 
  0x07080404, 0x4300091b, 0x2e003021, 0x351767b2,   // ru.uk.bg_332 pl.ie.un_770  uz.fo.un_860 ak.sr.zu_732 
  0x3d00180c, 0x34002112, 0x1700690d, 0x0e000804,   // ar.ku.un_530 fa.ps.un_640  mfe.sr.un_540 no.is.un_320 
  // [2220]
  0x3216170c, 0x61003304, 0x0400490c, 0x0600610c,   // sr.hr.bs_543 nn.za.un_320  to.fi.un_530 za.de.un_530 
  0x3000541a, 0x302118ad, 0x0f006112, 0x2e0e5da0,   // ik.uz.un_760 ar.fa.uz_643  za.lv.un_640 ss.is.fo_322 
  0xfc113e55, 0x3f0349ee, 0x0a004807, 0x124804a9,   // rm.ro.zzp_442 to.nl.af_422  tt.mk.un_420 fi.tt.hu_544 
  0x65006307, 0x422511a0, 0x014c6307, 0x4a252412,   // sco.gv.un_420 ro.eu.co_322  sco.wo.en_432 eo.eu.yo_654 
  // [2230]
  0x29001604, 0x102f1f07, 0x09001c13, 0x03001804,   // hr.sl.un_320 cy.su.lt_432  mr.hi.un_650 ga.nl.un_320 
  0x1e1c2514, 0x08004804, 0x470f61ec, 0x03583f07,   // eu.id.ms_666 tt.uk.un_320  za.lv.sn_644 af.om.nl_432 
  0x06000104, 0x12000802, 0x150407a4, 0x062c01a0,   // en.de.un_320 no.hu.un_220  bg.ru.un_433 en.fy.de_322 
  0x2344370c, 0x10002520, 0x0400170c, 0x06002513,   // ba.kk.ky_543 eu.lt.un_850  sr.ru.un_530 eu.de.un_650 
  // [2240]
  0x080f3304, 0x0523655a, 0x2e000e1a, 0x53213907,   // nn.lv.no_332 gv.ca.fr_553  is.fo.un_760 br.jw.ht_432 
  0x39002104, 0x2f091207, 0x755f3714, 0x3600151a,   // jw.br.un_320 hu.pl.su_432  st.tn.nso_666 un.ab.un_760 
  0x1c761e0c, 0x79006904, 0x15250408, 0x0e336007,   // ms.crs.id_543 mfe.war.un_320  ru.mn.un_443 vo.nn.is_432 
  0x2e0e4aa0, 0x512048a0, 0x103f33a4, 0x081504af,   // yo.is.fo_322 tt.sq.kl_322  nn.af.lt_433 ru.uk.un_650 
  // [2250]
  0x40061f60, 0x35004704, 0x00006415, 0x2c033f12,   // cy.de.lb_664 sn.zu.un_320  lg.un.un_700 af.nl.fy_654 
  0xfc1d4011, 0x28006407, 0x2c002f13, 0x2cfe0304,   // lb.la.zzp_653 lg.sw.un_420  su.fy.un_650 nl.tlh.fy_332 
  0x48001b0b, 0x182c4aa0, 0x2d000412, 0x2e2d0ea4,   // tr.tt.un_520 yo.fy.ga_322  fi.sk.un_640 is.sk.fo_433 
  0x3b003d21, 0x5d002e08, 0x03003f1a, 0x30003c05,   // ku.ks.un_860 fo.ss.un_430  af.nl.un_760 ug.uz.un_330 
  // [2260]
  0x630701ec, 0x25482cee, 0x2b033fee, 0x301221a4,   // en.it.sco_644 fy.tt.eu_422  af.nl.vi_422 fa.ur.uz_433 
  0x28003b13, 0x3d213455, 0x183428af, 0x3f00370c,   // ks.sd.un_650 ps.fa.ku_442  sd.ps.ar_655 st.af.un_530 
  0x0e002c02, 0x03001a04, 0x2a676813, 0x53006707,   // fy.is.un_220 tl.nl.un_320  ig.ak.mt_665 ak.ht.un_420 
  0x1b00670c, 0x40004c04, 0x33573907, 0x04375f0d,   // ak.tr.un_530 wo.lb.un_320  br.na.nn_432 tn.st.fi_554 
  // [2270]
  0x27490412, 0x21004207, 0x255703af, 0x4a094c08,   // fi.to.gd_654 co.jw.un_420  nl.na.eu_655 wo.pl.yo_443 
  0x13091c12, 0x4004270c, 0x5047040c, 0x281304ad,   // mr.hi.bh_654 gd.fi.lb_543  fi.sn.fj_543 fi.et.sw_643 
  0x02000104, 0x213d18a7, 0x63182805, 0x0f1827ec,   // en.da.un_320 ar.ku.fa_532  sw.ga.sco_333 gd.ga.lv_644 
  0x5c000d13, 0x022939a4, 0x27220504, 0x584d4c0c,   // ne.sa.un_650 br.sl.da_433  fr.oc.gd_332 wo.aa.om_543 
  // [2280]
  0x25006807, 0x10000207, 0x55000904, 0x5c000205,   // ig.eu.un_420 da.lt.un_420  pl.rw.un_320 da.sa.un_330 
  0x2d0e0dee, 0x054704a4, 0x504763ee, 0x2c004005,   // cs.is.sk_422 fi.sn.fr_433  sco.sn.fj_422 lb.fy.un_330 
  0x08071708, 0x02040f0c, 0x0d1c5cec, 0x101304a4,   // sr.bg.uk_443 lv.fi.da_543  sa.mr.ne_644 fi.et.lt_433 
  0x04000a07, 0x0d130908, 0x070a17af, 0x4f000104,   // mk.ru.un_420 hi.bh.ne_443  sr.mk.bg_655 en.bi.un_320 
  // [2290]
  0x3b584c14, 0x0d000f0e, 0x1a5803a9, 0x34004902,   // wo.om.so_666 lv.cs.un_550  nl.om.tl_544 to.xh.un_220 
  0x3b00040d, 0x00001e24, 0x3f001a04, 0x3864fc0e,   // fi.so.un_540 am.un.un_900  tl.af.un_320 zzp.lg.tk_555 
  0x32163309, 0x765308a4, 0x033f3b0c, 0x3f000c04,   // nn.hr.bs_444 no.ht.crs_433  so.af.nl_543 sv.af.un_320 
  0x5600201a, 0x0a1504af, 0x1e583ba7, 0x50643ba7,   // sq.mg.un_760 ru.mk.un_650  so.om.ms_532 so.lg.fj_532 
  // [22a0]
  0x16000205, 0x6365010c, 0x10005304, 0x58004e09,   // da.hr.un_330 en.gv.sco_543  ht.lt.un_320 ay.om.un_440 
  0x653b49ad, 0x65003822, 0x4b252faf, 0x15303808,   // to.so.gv_643 tk.gv.un_870  su.eu.mi_655 tk.uz.un_443 
  0x4e00020e, 0x0000581c, 0x424e02a4, 0x64205455,   // da.ay.un_550 om.un.un_800  da.ay.co_433 ik.sq.lg_442 
  0x4c003b13, 0x21002809, 0x5c005421, 0x024d4208,   // so.wo.un_650 sd.fa.un_440  ik.sa.un_860 co.aa.da_443 
  // [22b0]
  0x40033fa4, 0x460257ec, 0x3b034d08, 0x59554f09,   // af.nl.lb_433 na.da.qu_644  aa.nl.so_443 bi.rw.rn_444 
  0x3f6e650c, 0x0b0a61a4, 0x03403f0c, 0x653b0112,   // gv.hmn.af_543 za.pt.es_433  af.lb.nl_543 en.so.gv_654 
  0x5f251e07, 0x00006b24, 0x11314008, 0x103e6407,   // ms.eu.tn_432 ceb.un.un_900  lb.az.ro_443 lg.rm.lt_432 
  0x035f6e0c, 0x5955feaf, 0x3b18340c, 0x38002314,   // hmn.tn.nl_543 tlh.rw.rn_655  ps.ar.ks_543 ky.tk.un_660 
  // [22c0]
  0x332c08a0, 0x17321660, 0x55004e19, 0x080407a0,   // no.fy.nn_322 hr.bs.sr_664  ay.rw.un_750 bg.ru.uk_322 
  0x46424ea0, 0x4a025907, 0x174e020b, 0x4e52640c,   // ay.co.qu_322 rn.da.yo_432  da.ay.sr_542 lg.ha.ay_543 
  0x4e004629, 0xfe400107, 0x3809fea4, 0x25002307,   // qu.ay.un_960 en.lb.tlh_432  tlh.pl.tk_433 ky.mn.un_420 
  0x341f5ea0, 0x2100300b, 0xfe00610c, 0x3600fe11,   // ts.cy.xh_322 uz.fa.un_520  za.tlh.un_530 tlh.gn.un_630 
  // [22d0]
  0x00001a0a, 0x2b001c0b, 0x3012285a, 0x102344af,   // tl.un.un_500 id.vi.un_520  sd.ur.uz_553 kk.ky.be_655 
  0x212812a7, 0x1c002b02, 0x2a454f04, 0x040715a0,   // ur.sd.fa_532 vi.id.un_220  bi.ln.mt_332 un.bg.ru_322 
  0x10003009, 0x06001204, 0x20002904, 0x28211d07,   // uz.be.un_440 hu.de.un_320  sl.sq.un_320 la.jw.sw_432 
  0x30352308, 0x09003202, 0x18281255, 0x50001d04,   // ky.tg.uz_443 bs.pl.un_220  ur.sd.ar_442 la.fj.un_320 
  // [22e0]
  0x21283405, 0x1ffc4607, 0x39000904, 0x130d0914,   // ps.sd.fa_333 qu.zzp.cy_432  pl.br.un_320 hi.ne.bh_666 
  0x276318a0, 0x2322050c, 0x364430a4, 0x522f1dee,   // ga.sco.gd_322 fr.oc.ca_543  uz.kk.ab_433 la.su.ha_422 
  0x18001105, 0x150704a4, 0x12183da0, 0x213d180d,   // ro.ga.un_330 ru.bg.un_433  ku.ar.ur_322 ar.ku.fa_554 
  0x12004a0d, 0x35000a09, 0x3c3644ec, 0x400609a4,   // yo.hu.un_540 mk.tg.un_440  kk.ab.ug_644 pl.de.lb_433 
  // [22f0]
  0x443736ec, 0x3600170e, 0x02005114, 0x28001222,   // ab.ba.kk_644 sr.ab.un_550  kl.da.un_660 ur.sd.un_870 
  0x021107a4, 0x1f7906a7, 0x45110707, 0x30003521,   // it.ro.da_433 de.war.cy_532  it.ro.ln_432 tg.uz.un_860 
  0x3e40060c, 0x3700380d, 0x072548ee, 0x373844af,   // de.lb.rm_543 tk.ba.un_540  tt.mn.bg_422 kk.tk.ba_655 
  0x261d010c, 0x2300370c, 0x2c571fad, 0x0a073007,   // en.la.ia_543 ba.ky.un_530  cy.na.fy_643 uz.bg.mk_432 
  // [2300]
  0x06001f12, 0x13003f02, 0x44233c60, 0x211218a7,   // cy.de.un_640 af.et.un_220  ug.ky.kk_664 ar.ur.fa_532 
  0x21123d07, 0x40000602, 0x04000602, 0x06005705,   // ku.ur.fa_432 de.lb.un_220  de.fi.un_220 na.de.un_330 
  0x3007350c, 0x4400230c, 0x400657a7, 0x401f060c,   // tg.bg.uz_543 ky.kk.un_530  na.de.lb_532 de.cy.lb_543 
  0x08150413, 0x35233009, 0x1c130905, 0x301221a9,   // ru.uk.un_650 uz.ky.tg_444  hi.bh.mr_333 fa.ur.uz_544 
  // [2310]
  0x3c003014, 0x1c5c13a4, 0x30001509, 0x3d341208,   // uz.ug.un_660 bh.sa.mr_433  un.uz.un_440 ur.ps.ku_443 
  0x09005c0c, 0x09001504, 0x250240a4, 0x012163ee,   // sa.hi.un_530 un.pl.un_320  lb.da.eu_433 sco.jw.en_422 
  0x29530d07, 0x2a00290e, 0x4a6857ee, 0x2f21fe08,   // cs.ht.sl_432 sl.mt.un_550  na.ig.yo_422 tlh.jw.su_443 
  0x2a482908, 0x042b02a7, 0x171629ee, 0x1d40fc04,   // sl.tt.mt_443 da.vi.fi_532  sl.hr.sr_422 zzp.lb.la_332 
  // [2320]
  0x092d0d09, 0x25000602, 0x19610b0c, 0x1d003b04,   // cs.sk.pl_444 de.eu.un_220  es.za.gl_543 so.la.un_320 
  0x455d5e12, 0x2f0e10a7, 0x2c001108, 0x10006012,   // ts.ss.ln_654 lt.is.su_532  ro.fy.un_430 vo.lt.un_640 
  0x153f28a0, 0x2afe2912, 0x10000d12, 0x53587907,   // sw.af.un_322 sl.tlh.mt_654  cs.lt.un_640 war.om.ht_432 
  0x01006504, 0x37002804, 0x091e1c08, 0x3664470c,   // gv.en.un_320 sw.st.un_320  id.ms.pl_443 sn.lg.gn_543 
  // [2330]
  0x48002002, 0xfe005a05, 0x165c2004, 0x292d0d0c,   // sq.tt.un_220 sm.tlh.un_330  sq.sa.hr_332 cs.sk.sl_543 
  0x163b4daf, 0x371d69a4, 0x5c171604, 0x5800130d,   // aa.so.hr_655 mfe.la.st_433  hr.sr.sa_332 et.om.un_540 
  0x291907ee, 0x07291604, 0x17080402, 0x5a503707,   // it.gl.sl_422 hr.sl.it_332  ru.uk.sr_222 st.fj.sm_432 
  0x25130707, 0x3e2b1913, 0x0900560c, 0x02003804,   // it.et.eu_432 gl.vi.rm_665  mg.pl.un_530 tk.da.un_320 
  // [2340]
  0x3200290c, 0x350240ee, 0x0648040b, 0x162a2904,   // sl.bs.un_530 lb.da.zu_422  fi.tt.de_542 sl.mt.hr_332 
  0x0d092d0c, 0x2e0e4e12, 0x17442307, 0x38004813,   // sk.pl.cs_543 ay.is.fo_654  ky.kk.sr_432 tt.tk.un_650 
  0x29100fa4, 0x3e001304, 0x162905a7, 0x3b2afeee,   // lv.lt.sl_433 et.rm.un_320  fr.sl.hr_532 tlh.mt.so_422 
  0x08000408, 0x39760107, 0x1d002007, 0x1a796ba9,   // ru.uk.un_430 en.crs.br_432  sq.la.un_420 ceb.war.tl_544 
  // [2350]
  0x3048250c, 0x122334a0, 0x2100300e, 0x65003e0c,   // eu.tt.uz_543 ps.ky.ur_322  uz.fa.un_550 rm.gv.un_530 
  0x34213da0, 0x081044af, 0x1c0d0908, 0x042b1b02,   // ku.fa.ps_322 kk.be.uk_655  hi.ne.mr_443 tr.vi.fi_222 
  0x122d0d55, 0x3e000902, 0x13005a04, 0x13495aa0,   // cs.sk.hu_442 pl.rm.un_220  sm.et.un_320 sm.to.et_322 
  0x48001513, 0x03041307, 0x1100351b, 0x652763a0,   // un.tt.un_650 et.fi.nl_432  tg.ro.un_770 sco.gd.gv_322 
  // [2360]
  0x35002507, 0x34281811, 0x441715ad, 0x3d002802,   // mn.tg.un_420 ar.sd.ps_653  un.sr.kk_643 sd.ku.un_220 
  0x28341804, 0x303c4405, 0x13090d0e, 0x40003604,   // ar.ps.sd_332 kk.ug.uz_333  ne.hi.bh_555 gn.lb.un_320 
  0x135c1c0c, 0x150a17a4, 0x23303812, 0x070415ee,   // mr.sa.bh_543 sr.mk.un_433  tk.uz.ky_654 un.ru.bg_422 
  0x48001b04, 0x3e1b29a6, 0x183d23a9, 0x23483707,   // tr.tt.un_320 sl.tr.rm_521  ky.ku.ar_544 ba.tt.ky_432 
  // [2370]
  0x1c000102, 0x12362d02, 0x21281804, 0x362f05ad,   // en.id.un_220 sk.gn.hu_222  ar.sd.fa_332 fr.su.gn_643 
  0x23003c0e, 0x321716ee, 0x043736a0, 0x0a001705,   // ug.ky.un_550 hr.sr.bs_422  ab.ba.ru_322 sr.mk.un_330 
  0x4700fe0d, 0x1d003805, 0x190b4e05, 0x35070aa0,   // tlh.sn.un_540 tk.la.un_330  ay.es.gl_333 mk.bg.tg_322 
  0x596447ad, 0x1700290b, 0x23004411, 0xfe00451a,   // sn.lg.rn_643 sl.sr.un_520  kk.ky.un_630 ln.tlh.un_760 
  // [2380]
  0x18000204, 0x27621808, 0x2c0363ee, 0x1b5238ec,   // da.ga.un_320 ga.kha.gd_443  sco.nl.fy_422 tk.ha.tr_644 
  0x6b1a5212, 0x08153ca9, 0x25003608, 0x69761ea4,   // ha.tl.ceb_654 ug.uk.un_540  ab.mn.un_430 ms.crs.mfe_433 
  0x64004d0c, 0x1800090d, 0xfc002e02, 0x4d2158a4,   // aa.lg.un_530 pl.ga.un_540  fo.zzp.un_220 om.jw.aa_433 
  0x1a513b09, 0x5e583bad, 0x64004a07, 0x29002d07,   // so.kl.tl_444 so.om.ts_643  yo.lg.un_420 sk.sl.un_420 
  // [2390]
  0x0a0710a0, 0x351510ec, 0x0f4c25a4, 0x4a6458ad,   // be.bg.mk_322 be.tg.un_640  eu.wo.lv_433 om.lg.yo_643 
  0x2718fc0d, 0x283b4707, 0x3b56520c, 0x3913200c,   // zzp.ga.gd_554 sn.so.sw_432  ha.mg.so_543 sq.et.br_543 
  0x595552a9, 0x322a1712, 0x35003704, 0x2d0d090c,   // ha.rw.rn_544 sr.mt.bs_654  ba.tg.un_320 pl.cs.sk_543 
  0x4b3b4904, 0x501b48a9, 0x21420f07, 0x6400730c,   // to.so.mi_332 tt.tr.fj_544  lv.co.jw_432 ny.lg.un_530 
  // [23a0]
  0x226b62ee, 0x255842a9, 0x434d1dec, 0x0f101c0c,   // kha.ceb.oc_422 co.om.eu_544  la.aa.ie_644 id.lt.lv_543 
  0x17000a2b, 0x3b2a4d12, 0x0f471009, 0x5c182712,   // mk.sr.un_980 aa.mt.so_654  lt.sn.lv_444 gd.ga.sa_654 
  0x1f3b52a9, 0x18275c12, 0x0a111713, 0x4c364d13,   // ha.so.cy_544 sa.gd.ga_654  sr.ro.mk_665 aa.gn.wo_665 
  0x27000604, 0x43004c0c, 0x186527af, 0x58044211,   // de.gd.un_320 wo.ie.un_530  gd.gv.ga_655 co.fi.om_653 
  // [23b0]
  0x4a3742a4, 0x42250d07, 0x08100a14, 0x17070a12,   // co.st.yo_433 cs.eu.co_432  mk.be.uk_666 mk.bg.sr_654 
  0x5e5f370c, 0x15001f04, 0x044810a4, 0x2a544daf,   // st.tn.ts_543 cy.un.un_320  be.tt.ru_433 aa.ik.mt_655 
  0x233530a9, 0x652701a7, 0x02190b02, 0x341828a0,   // uz.tg.ky_544 en.gd.gv_532  es.gl.da_222 sd.ar.ps_322 
  0x44382308, 0x27000104, 0x07001507, 0x13091c02,   // ky.tk.kk_443 en.gd.un_320  un.bg.un_420 mr.hi.bh_222 
  // [23c0]
  0x2344380e, 0x5c1c0da9, 0x3c2325a9, 0x040a11ee,   // tk.kk.ky_555 ne.mr.sa_544  mn.ky.ug_544 ro.mk.ru_422 
  0x151704a4, 0x17000708, 0x35000a13, 0x10000423,   // ru.sr.un_433 bg.sr.un_430  mk.tg.un_650 ru.be.un_880 
  0x4e521a14, 0x3c483713, 0x23104407, 0x1a505e09,   // tl.ha.ay_666 ba.tt.ug_665  kk.be.ky_432 ts.fj.tl_444 
  0x29002d04, 0x52216aa9, 0x2c006907, 0x21343007,   // sk.sl.un_320 haw.jw.ha_544  mfe.fy.un_420 uz.ps.fa_432 
  // [23d0]
  0x21731eac, 0x2d0d36ee, 0x65003907, 0x17153611,   // ms.ny.jw_632 gn.cs.sk_422  br.gv.un_420 ab.sr.un_630 
  0x28024ea4, 0x28625213, 0x15004419, 0x402c3e12,   // ay.da.sw_433 ha.kha.sw_665  kk.un.un_750 rm.fy.lb_654 
  0x290f32ee, 0x2e020ca0, 0x4f5767a4, 0x00005215,   // bs.lv.sl_422 sv.da.fo_322  ak.na.bi_433 ha.un.un_700 
  0x28021a0d, 0x692c2d0c, 0x3023180c, 0x642f5209,   // tl.da.sw_554 sk.fy.mfe_543  ar.ky.uz_543 ha.su.lg_444 
  // [23e0]
  0x00005015, 0x2a3e09a0, 0x292d0d14, 0x3f000318,   // fj.un.un_700 pl.rm.mt_322  cs.sk.sl_666 nl.af.un_740 
  0x24000118, 0x3d343009, 0x09000222, 0x6450520c,   // iw.yi.un_740 uz.ps.ku_444  da.pl.un_870 ha.fj.lg_543 
  0x03006402, 0x5c001c0b, 0x0273500c, 0x40063e05,   // lg.nl.un_220 mr.sa.un_520  fj.ny.da_543 rm.de.lb_333 
  0x0d003607, 0x1a524e0c, 0x0000691c, 0x1c130908,   // gn.cs.un_420 ay.ha.tl_543  mfe.un.un_800 hi.bh.mr_443 
  // [23f0]
  0x5200500d, 0x3d122109, 0x2d0306a6, 0x2c033f04,   // fj.ha.un_540 fa.ur.ku_444  de.nl.sk_521 af.nl.fy_332 
  0x52024ea9, 0x2c3f0307, 0x3c004421, 0x483f2da0,   // ay.da.ha_544 nl.af.fy_432  kk.ug.un_860 sk.af.tt_322 
  0x4f45050c, 0x2d693960, 0x3e090607, 0x113748a4,   // fr.ln.bi_543 br.mfe.sk_664  de.pl.rm_432 tt.ba.ro_433 
  0x02000f04, 0x130d0960, 0x290f2d0c, 0x131c0904,   // lv.da.un_320 hi.ne.bh_664  sk.lv.sl_543 hi.mr.bh_332 
  
  // [2400]
  0x0a3723a4, 0x04001007, 0x2d001707, 0x63150112,   // ky.ba.mk_433 be.ru.un_420  sr.sk.un_420 en.sco.un_640 
  0x651b1d04, 0x08150411, 0x27184e08, 0x071b4d07,   // la.tr.gv_332 ru.uk.un_630  ay.ga.gd_443 aa.tr.it_432 
  0x0f4820ee, 0x79360107, 0x186526a7, 0x1364780c,   // sq.tt.lv_422 en.gn.war_432  ia.gv.ga_532 ve.lg.et_543 
  0x162f1ea0, 0x1d000f13, 0x33083205, 0x23001813,   // ms.su.hr_322 lv.la.un_650  bs.no.nn_333 ar.ky.un_650 
  // [2410]
  0x2a52280c, 0x342839ad, 0x1a6b7911, 0x00001c24,   // sw.ha.mt_543 br.sw.xh_643  war.ceb.tl_653 mr.un.un_900 
  0x20003b09, 0x4700640c, 0x1d425804, 0x0f003b08,   // so.sq.un_440 lg.sn.un_530  om.co.la_332 so.lv.un_430 
  0x3400120e, 0x28183dad, 0x17353007, 0x290f2d02,   // hu.xh.un_550 ku.ar.sd_643  uz.tg.sr_432 sk.lv.sl_222 
  0x46004e12, 0x56734712, 0x0400070c, 0x24fc0107,   // ay.qu.un_640 sn.ny.mg_654  bg.ru.un_530 en.zzp.eo_432 
  // [2420]
  0x42132a55, 0x12003d0d, 0x42002102, 0x462a31ec,   // mt.et.co_442 ku.ur.un_540  jw.co.un_220 az.mt.qu_644 
  0x0a00171b, 0x1000171a, 0x06004014, 0x403921a0,   // sr.mk.un_770 sr.be.un_760  lb.de.un_660 jw.br.lb_322 
  0x100f38a0, 0x13095ca4, 0x29001608, 0x0d002909,   // tk.lv.lt_322 sa.hi.bh_433  hr.sl.un_430 sl.cs.un_440 
  0x31004c04, 0x353036ee, 0x0d001305, 0x0800101a,   // wo.az.un_320 ab.uz.tg_422  bh.ne.un_330 be.uk.un_760 
  // [2430]
  0x3f005804, 0x24303907, 0x1c5c0d12, 0x04003520,   // om.af.un_320 br.uz.eo_432  ne.sa.mr_654 tg.ru.un_850 
  0x1e301ca9, 0x0d095c07, 0x39370607, 0x34003f05,   // id.uz.ms_544 sa.hi.ne_432  de.st.br_432 af.xh.un_330 
  0x29000d07, 0x37755f13, 0x5300490b, 0x35345eec,   // cs.sl.un_420 tn.nso.st_665  to.ht.un_520 ts.xh.zu_644 
  0x0d1c5ca4, 0xfc2f0804, 0x51545813, 0x203656ad,   // sa.mr.ne_433 no.su.zzp_332  om.ik.kl_665 mg.gn.sq_643 
  // [2440]
  0x20001e11, 0x190a65ee, 0x643b5809, 0x13650412,   // am.ti.un_630 gv.pt.gl_422  om.so.lg_444 fi.gv.et_654 
  0x341221ad, 0x0633180c, 0x1d005107, 0x0f1304a0,   // fa.ur.ps_643 ga.nn.de_543  kl.la.un_420 fi.et.lv_322 
  0x18060e07, 0x20001307, 0x2a000e0e, 0x653306a0,   // is.de.ga_432 et.sq.un_420  is.mt.un_550 de.nn.gv_322 
  0x04156507, 0x340620a0, 0x5c003108, 0x0f002d04,   // gv.fi.un_420 sq.de.xh_322  az.sa.un_430 sk.lv.un_320 
  // [2450]
  0x5c1c09a4, 0x06004607, 0x20002304, 0x3b005a04,   // hi.mr.sa_433 qu.de.un_420  ca.sq.un_320 sm.so.un_320 
  0x4c403b07, 0x133f58ee, 0x1d002307, 0x0f002505,   // so.lb.wo_432 om.af.et_422  ca.la.un_420 eu.lv.un_330 
  0x1f046507, 0x25182fee, 0x44373007, 0x162d0d55,   // gv.fi.cy_432 su.ga.eu_422  uz.ba.kk_432 cs.sk.hr_442 
  0x0613040c, 0x065c33a0, 0x322d0d04, 0x06005712,   // fi.et.de_543 nn.sa.de_322  cs.sk.bs_332 na.de.un_640 
  // [2460]
  0x0a303c12, 0x170a0705, 0x130e2c07, 0x3c0823a4,   // ug.uz.mk_654 bg.mk.sr_333  fy.is.et_432 ky.uk.ug_433 
  0x3f2e08a0, 0x46031355, 0x46511dee, 0x1c0904a7,   // no.fo.af_322 et.nl.qu_442  la.kl.qu_422 fi.pl.id_532 
  0x1221280e, 0x35081013, 0x121823a4, 0x30005222,   // sd.fa.ur_555 be.uk.tg_665  ky.ar.ur_433 ha.uz.un_870 
  0x0d004f07, 0x190b0505, 0x07201dee, 0x0400131b,   // bi.cs.un_420 fr.es.gl_333  la.sq.it_422 et.fi.un_770 
  // [2470]
  0x0a081004, 0x074838a0, 0x07001504, 0xfe4c29a4,   // be.uk.mk_332 tk.tt.bg_322  un.bg.un_320 sl.wo.tlh_433 
  0xfc00250c, 0x73790305, 0x2c172907, 0x48001013,   // eu.zzp.un_530 nl.war.ny_333  sl.sr.fy_432 lt.tt.un_650 
  0x17001208, 0x242e2c02, 0x2900100e, 0x2d303807,   // hu.sr.un_430 fy.fo.eo_222  lt.sl.un_550 tk.uz.sk_432 
  0x10002d19, 0x1e000305, 0x48001b0d, 0x23004412,   // sk.lt.un_750 nl.ms.un_330  tr.tt.un_540 kk.ky.un_640 
  // [2480]
  0x63043f0c, 0x321629af, 0x04100fad, 0x3530480d,   // af.fi.sco_543 sl.hr.bs_655  lv.lt.fi_643 tt.uz.tg_554 
  0x241c2ba4, 0x2e0e1211, 0x5a004908, 0x234838ee,   // vi.id.eo_433 hu.is.fo_653  to.sm.un_430 tk.tt.ky_422 
  0x170415a4, 0x2e040f0c, 0x35301707, 0x2b001c08,   // un.ru.sr_433 lv.fi.fo_543  sr.uz.tg_432 id.vi.un_430 
  0x48000407, 0x16321755, 0x044958a9, 0x33000c02,   // ru.tt.un_420 sr.bs.hr_442  om.to.fi_544 sv.nn.un_220 
  // [2490]
  0x4d585a11, 0x21003b11, 0x4967580c, 0x672804a9,   // sm.om.aa_653 ks.fa.un_630  om.ak.to_543 fi.sw.ak_544 
  0x40033f07, 0x3b586709, 0x492858ec, 0x286758a4,   // af.nl.lb_432 ak.om.so_444  om.sw.to_644 om.ak.sw_433 
  0xfc00760c, 0x27004904, 0x4567580c, 0x113b58a7,   // crs.zzp.un_530 to.gd.un_320  om.ak.ln_543 om.so.ro_532 
  0x17003c0c, 0x73002804, 0x3b02580c, 0x3400300d,   // ug.sr.un_530 sw.ny.un_320  om.da.so_543 uz.ps.un_540 
  // [24a0]
  0x044811a4, 0x04004905, 0x213d3004, 0x3525155a,   // ro.tt.ru_433 to.fi.un_330  uz.ku.fa_332 un.mn.tg_553 
  0x443023a4, 0x3c00481a, 0x07000502, 0x44003c2b,   // ky.uz.kk_433 tt.ug.un_760  fr.it.un_220 ug.kk.un_980 
  0x0c032e5a, 0x35001112, 0x19000602, 0x150408a9,   // fo.nl.sv_553 ro.tg.un_640  de.gl.un_220 uk.ru.un_544 
  0x100835a0, 0x44002808, 0x44003c11, 0x063e43ee,   // tg.uk.be_322 sd.kk.un_430  ug.kk.un_630 ie.rm.de_422 
  // [24b0]
  0x12000a02, 0x0a041707, 0x2100340b, 0x184423ee,   // pt.hu.un_220 sr.ru.mk_432  ps.fa.un_520 ky.kk.ar_422 
  0x69005313, 0x03005607, 0x79000104, 0x284755a9,   // ht.mfe.un_650 mg.nl.un_420  en.war.un_320 rw.sn.sw_544 
  0x0f005c05, 0x495c6a55, 0x00005b24, 0x44353707,   // sa.lv.un_330 haw.sa.to_442  sg.un.un_900 ba.tg.kk_432 
  0x53002209, 0x34283dee, 0x28006408, 0x2f003602,   // oc.ht.un_440 ku.sd.ps_422  lg.sw.un_430 gn.su.un_220 
  // [24c0]
  0x64004c0d, 0x584c64a4, 0xfc000a02, 0x170a04a0,   // wo.lg.un_540 lg.wo.om_433  pt.zzp.un_220 ru.mk.sr_322 
  0x09190b02, 0x34002119, 0x32002905, 0x12003602,   // es.gl.pl_222 fa.ps.un_750  sl.bs.un_330 gn.hu.un_220 
  0x190a0b02, 0x30003820, 0x15303ca4, 0x0f005c02,   // es.pt.gl_222 tk.uz.un_850  ug.uz.un_433 sa.lv.un_220 
  0x281821ad, 0x0a00170b, 0x37004823, 0x182821a7,   // fa.ar.sd_643 sr.mk.un_520  tt.ba.un_880 fa.sd.ar_532 
  // [24d0]
  0x2821300c, 0x2c000308, 0x43095713, 0x343035a4,   // uz.fa.sd_543 nl.fy.un_430  na.pl.ie_665 zu.uz.xh_433 
  0x09730107, 0x30443c11, 0x35470955, 0x20001b08,   // en.ny.pl_432 ug.kk.uz_653  pl.sn.zu_442 tr.sq.un_430 
  0x08441007, 0x2a001f34, 0x5d3b09ee, 0x35080404,   // be.kk.uk_432 cy.mt.un_A80  pl.so.ss_422 ru.uk.tg_332 
  0x17083808, 0x321629a4, 0x45340907, 0x134d4ca4,   // tk.uk.sr_443 sl.hr.bs_433  pl.xh.ln_432 wo.aa.et_433 
  // [24e0]
  0x18003d05, 0x2d0d46ee, 0x1b2548a0, 0x4c525855,   // ku.ar.un_330 qu.cs.sk_422  tt.eu.tr_322 om.ha.wo_442 
  0x2a001e04, 0x17380a04, 0x35400912, 0x24002904,   // ms.mt.un_320 mk.tk.sr_332  pl.lb.zu_654 sl.eo.un_320 
  0x2a321704, 0x422e11a4, 0x1b003013, 0x4b4c5809,   // sr.bs.mt_332 ro.fo.co_433  uz.tr.un_650 om.wo.mi_444 
  0x42001120, 0x361504af, 0x47280904, 0x5a001502,   // ro.co.un_850 ru.ab.un_650  pl.sw.sn_332 un.sm.un_220 
  // [24f0]
  0x5d002812, 0x166109a4, 0x641a0907, 0x2857090d,   // sw.ss.un_640 pl.za.hr_433  pl.tl.lg_432 pl.na.sw_554 
  0x2536460c, 0x433f09a4, 0x06730955, 0x42241ba0,   // qu.gn.eu_543 pl.af.ie_433  pl.ny.de_442 tr.eo.co_322 
  0x2a004613, 0x0f1142a9, 0x4b474c5a, 0x150a07a0,   // qu.mt.un_650 co.ro.lv_544  wo.sn.mi_553 bg.mk.un_322 
  0x0a000708, 0x36002a04, 0x13422aa4, 0x0736380e,   // bg.mk.un_430 mt.gn.un_320  mt.co.et_433 tk.ab.bg_555 
  // [2500]
  0x44070a07, 0x0e003f04, 0x08070402, 0x10002304,   // mk.bg.kk_432 af.is.un_320  ru.bg.uk_222 ky.be.un_320 
  0x3e1afea4, 0x070a1005, 0x03063f02, 0x2e000e05,   // tlh.tl.rm_433 be.mk.bg_333  af.de.nl_222 is.fo.un_330 
  0x0000221c, 0x6a005a09, 0x03023f04, 0x5859555a,   // oc.un.un_800 sm.haw.un_440  af.da.nl_332 rw.rn.om_553 
  0x04070a0e, 0x5d3560a4, 0x257901a0, 0x37676a0c,   // mk.bg.ru_555 vo.zu.ss_433  en.war.eu_322 haw.ak.st_543 
  // [2510]
  0x07352309, 0x0f585104, 0x203063a0, 0x490601ee,   // ky.tg.bg_444 kl.om.lv_332  sco.uz.sq_322 en.de.to_422 
  0x1d003407, 0x02004004, 0x03022eec, 0x63000108,   // xh.la.un_420 lb.da.un_320  fo.da.nl_644 en.sco.un_430 
  0x033f3b05, 0x37002304, 0x3f643bac, 0x04005d02,   // so.af.nl_333 ky.ba.un_320  so.lg.af_632 ss.fi.un_220 
  0x2000220c, 0x50595513, 0x403f0304, 0x402304ac,   // oc.sq.un_530 rw.rn.fj_665  nl.af.lb_332 fi.ca.lb_632 
  // [2520]
  0x07435909, 0x3b584da9, 0x182f20ba, 0x31004819,   // rn.ie.it_444 aa.om.so_544  sq.su.ga_843 tt.az.un_750 
  0x1008150d, 0x103e23a0, 0x58511ead, 0x12213b05,   // un.uk.be_554 ca.rm.lt_322  ms.kl.om_643 ks.fa.ur_333 
  0x53001913, 0x28301214, 0x5900250d, 0x041336a0,   // gl.ht.un_650 ur.uz.sd_666  eu.rn.un_540 gn.et.fi_322 
  0x0a003704, 0x232115a4, 0x47595513, 0x35303c0d,   // st.pt.un_320 un.jw.ca_433  rw.rn.sn_665 ug.uz.tg_554 
  // [2530]
  0x481931a0, 0x36002309, 0x3f003b12, 0x131c090b,   // az.gl.tt_322 ca.gn.un_440  so.af.un_640 hi.mr.bh_542 
  0x36235707, 0x21283d04, 0x425905ac, 0x0563010c,   // na.ca.gn_432 ku.sd.fa_332  fr.rn.co_632 en.sco.fr_543 
  0x2a2e02a0, 0x4c001205, 0x3f0315ad, 0x04001816,   // da.fo.mt_322 hu.wo.un_330  un.nl.af_643 ga.fi.un_720 
  0x47000104, 0x3b0251a7, 0x033b58ec, 0x2e004d0d,   // en.sn.un_320 kl.da.so_532  om.so.nl_644 aa.fo.un_540 
  // [2540]
  0x675547a9, 0x1e0334a0, 0x10734712, 0x40033fa0,   // sn.rw.ak_544 xh.nl.ms_322  sn.ny.lt_654 af.nl.lb_322 
  0x233c440e, 0x2e002307, 0x123d1804, 0x28003d12,   // kk.ug.ky_555 ca.fo.un_420  ar.ku.ur_332 ku.sd.un_640 
  0x13005b0c, 0x3e002305, 0x04251511, 0x0a2f05a0,   // sg.et.un_530 ca.rm.un_330  un.mn.ru_653 fr.su.pt_322 
  0x23190aa4, 0x183c3405, 0x303d12a4, 0x17003008,   // pt.gl.ca_433 ps.ug.ar_333  ur.ku.uz_433 uz.sr.un_430 
  // [2550]
  0x183021a4, 0x300a0707, 0x09651f07, 0x370804ee,   // fa.uz.ar_433 bg.mk.uz_432  cy.gv.pl_432 ru.uk.ba_422 
  0x026062ec, 0x1700380d, 0x4c001a05, 0x21225312,   // kha.vo.da_644 tk.sr.un_540  tl.wo.un_330 ht.oc.jw_654 
  0x00005724, 0x1efe3b04, 0x2f002113, 0x08041505,   // na.un.un_900 so.tlh.ms_332  jw.su.un_650 un.ru.uk_333 
  0x095c0d12, 0x354afcaf, 0x345235ad, 0x2d0d1809,   // ne.sa.hi_654 zzp.yo.zu_655  zu.ha.xh_643 ga.cs.sk_444 
  // [2560]
  0x19003902, 0x5300220c, 0xfc343507, 0x3e040705,   // br.gl.un_220 oc.ht.un_530  zu.xh.zzp_432 it.fi.rm_333 
  0x04000713, 0x214679ee, 0x04102304, 0x4700360c,   // bg.ru.un_650 war.qu.jw_422  ky.be.ru_332 gn.sn.un_530 
  0x20004c07, 0x52004d05, 0x091c1304, 0x13001c21,   // wo.sq.un_420 aa.ha.un_330  bh.mr.hi_332 mr.bh.un_860 
  0x6b791a13, 0x322d1055, 0x48002509, 0x37303812,   // tl.war.ceb_665 lt.sk.bs_442  mn.tt.un_440 tk.uz.ba_654 
  // [2570]
  0x36fe6112, 0x17002312, 0x35005d07, 0x48311b0b,   // za.tlh.gn_654 ky.sr.un_640  ss.zu.un_420 tr.az.tt_542 
  0x12002504, 0x21004608, 0x0e004607, 0x46001502,   // eu.hu.un_320 qu.jw.un_430  qu.is.un_420 un.qu.un_220 
  0x0e331fa7, 0x0415110c, 0x33060f07, 0x1c090d09,   // cy.nn.is_532 ro.ru.un_530  lv.de.nn_432 ne.hi.mr_444 
  0x3f000302, 0x3f000307, 0x4c0f58ee, 0x130427ad,   // nl.af.un_220 nl.af.un_420  om.lv.wo_422 gd.fi.et_643 
  // [2580]
  0x21001213, 0x18400613, 0x3f0369ec, 0x06107914,   // ur.fa.un_650 de.lb.ga_665  mfe.nl.af_644 war.lt.de_666 
  0x213d1255, 0x3f0339ee, 0x2800120d, 0x0e061fa4,   // ur.ku.fa_442 br.nl.af_422  ur.sd.un_540 cy.de.is_433 
  0x1e1561a7, 0x03002902, 0x060e2e5a, 0x23031908,   // za.ms.un_520 sl.nl.un_220  fo.is.de_553 gl.nl.ca_443 
  0x3d3421a9, 0x0d095c0c, 0x04441107, 0x04081f04,   // fa.ps.ku_544 sa.hi.ne_543  ro.kk.ru_432 cy.no.fi_332 
  // [2590]
  0x3e0f6507, 0x1f002c11, 0x352530a9, 0x12005c0c,   // gv.lv.rm_432 fy.cy.un_630  uz.mn.tg_544 sa.hu.un_530 
  0x030e0607, 0x03003f13, 0x403f0308, 0x04005b1b,   // de.is.nl_432 af.nl.un_650  nl.af.lb_443 sg.fi.un_770 
  0x044961a0, 0x4d3f1209, 0x133038a7, 0x3f002a07,   // za.to.fi_322 hu.af.aa_444  tk.uz.et_532 mt.af.un_420 
  0x2d12360c, 0x24003202, 0x080a3508, 0x1c214fa4,   // gn.hu.sk_543 bs.eo.un_220  tg.mk.uk_443 bi.jw.id_433 
  // [25a0]
  0x24100f0c, 0x3000381a, 0x48004413, 0x13002c04,   // lv.lt.eo_543 tk.uz.un_760  kk.tt.un_650 fy.et.un_320 
  0x20392402, 0x40000104, 0x24000202, 0x34002814,   // eo.br.sq_222 en.lb.un_320  da.eo.un_220 sd.ps.un_660 
  0x48003102, 0x21001c04, 0x18004408, 0x1e1c2102,   // az.tt.un_220 id.jw.un_320  kk.ar.un_430 jw.id.ms_222 
  0x1b0c02a9, 0x10000f02, 0x30643502, 0x233c300c,   // da.sv.tr_544 lv.lt.un_220  zu.lg.uz_222 uz.ug.ky_543 
  // [25b0]
  0x320d0fa0, 0x2000690c, 0x2e525807, 0x284418af,   // lv.cs.bs_322 mfe.sq.un_530  om.ha.fo_432 ar.kk.sd_655 
  0x32162902, 0x02004213, 0x464252ad, 0x29001012,   // sl.hr.bs_222 co.da.un_650  ha.co.qu_643 lt.sl.un_640 
  0x043b580c, 0x39003002, 0x3d003c12, 0x584c2a07,   // om.so.fi_543 uz.br.un_220  ug.ku.un_640 mt.wo.om_432 
  0x043748ee, 0x4804080c, 0x1a005804, 0x5500592b,   // tt.ba.ru_422 uk.ru.tt_543  om.tl.un_320 rn.rw.un_980 
  // [25c0]
  0x354830a0, 0x4a4c360c, 0x1c2a580c, 0x38130408,   // uz.tt.tg_322 gn.wo.yo_543  om.mt.id_543 fi.et.tk_443 
  0x30353607, 0x57fe4712, 0x0400130c, 0x5573470c,   // ab.tg.uz_432 sn.tlh.na_654  et.fi.un_530 sn.ny.rw_543 
  0x46000412, 0x0d1c09a7, 0x64595560, 0x12213d55,   // fi.qu.un_640 hi.mr.ne_532  rw.rn.lg_664 ku.fa.ur_442 
  0x3f2c1fad, 0x651f6408, 0x684a5108, 0x0e5242ad,   // cy.fy.af_643 lg.cy.gv_443  kl.yo.ig_443 co.ha.is_643 
  // [25d0]
  0x28005502, 0x0e2e42af, 0x3b00281b, 0x57004708,   // rw.sw.un_220 co.fo.is_655  sd.ks.un_770 sn.na.un_430 
  0x25303555, 0x3e212fa4, 0x5f006412, 0x1200fc02,   // tg.uz.mn_442 su.jw.rm_433  lg.tn.un_640 zzp.hu.un_220 
  0x2d002907, 0x2f004c04, 0x3d002112, 0x57004721,   // sl.sk.un_420 wo.su.un_320  fa.ku.un_640 sn.na.un_860 
  0x13584da9, 0x73004722, 0x4600fe09, 0x73fe47af,   // aa.om.et_544 sn.ny.un_870  tlh.qu.un_440 sn.tlh.ny_655 
  // [25e0]
  0x37003019, 0x64006812, 0x29160d02, 0x0f3216a4,   // uz.ba.un_750 ig.lg.un_640  cs.hr.sl_222 hr.bs.lv_433 
  0x0400130d, 0x64fe2802, 0x0b001904, 0x460413ad,   // et.fi.un_540 sw.tlh.lg_222  gl.es.un_320 et.fi.qu_643 
  0x12283d55, 0x070a3ca9, 0x07003508, 0x2c033f11,   // ku.sd.ur_442 ug.mk.bg_544  tg.bg.un_430 af.nl.fy_653 
  0x08041007, 0x28002513, 0x23303508, 0x21121807,   // be.ru.uk_432 eu.sw.un_650  tg.uz.ky_443 ar.ur.fa_432 
  // [25f0]
  0x5f37670c, 0x0a353055, 0x0a070408, 0x043530a7,   // ak.st.tn_543 uz.tg.mk_442  ru.bg.mk_443 uz.tg.ru_532 
  0x18213d07, 0x12064a07, 0x34035f04, 0x0d002d11,   // ku.fa.ar_432 yo.de.hu_432  tn.nl.xh_332 sk.cs.un_630 
  0x30353caf, 0x01002413, 0x4b005c07, 0x303b210c,   // ug.tg.uz_655 yi.iw.un_650  sa.mi.un_420 fa.ks.uz_543 
  0x17150408, 0x122d0d09, 0x0d1c09ec, 0x041708a0,   // ru.sr.un_430 cs.sk.hu_444  hi.mr.ne_644 uk.sr.ru_322 
  // [2600]
  0x2d0d0fa9, 0x2c0626ee, 0x0f001014, 0x341228ec,   // lv.cs.sk_544 ia.de.fy_422  lt.lv.un_660 sd.ur.ps_644 
  0x124006a4, 0x06001212, 0x211218af, 0x08150412,   // de.lb.hu_433 hu.de.un_640  ar.ur.fa_655 ru.uk.un_640 
  0x12001b0c, 0x150a070b, 0x3f381ba4, 0x06001308,   // tr.hu.un_530 bg.mk.un_542  tr.tk.af_433 et.de.un_430 
  0x16000f04, 0x25003604, 0x38131b12, 0x341e4ca0,   // lv.hr.un_320 gn.eu.un_320  tr.et.tk_654 wo.ms.xh_322 
  // [2610]
  0x5c005302, 0x0c000204, 0x07113012, 0x23080408,   // ht.sa.un_220 da.sv.un_320  uz.ro.bg_654 ru.uk.ky_443 
  0x3428210c, 0x443015a0, 0x0f1b380c, 0x380415af,   // fa.sd.ps_543 un.uz.kk_322  tk.tr.lv_543 un.ru.tk_655 
  0x18000c08, 0x3f001d04, 0x1b3813a4, 0x3f631d0c,   // sv.ga.un_430 la.af.un_320  et.tk.tr_433 la.sco.af_543 
  0x0b000502, 0x1b381214, 0x1d006304, 0x080f60ee,   // fr.es.un_220 hu.tk.tr_666  sco.la.un_320 vo.lv.no_422 
  // [2620]
  0x34232807, 0x444830a0, 0x00007615, 0x3f001d0d,   // sd.ky.ps_432 uz.tt.kk_322  crs.un.un_700 la.af.un_540 
  0x190a4f05, 0x16321704, 0x10000812, 0x0804100b,   // bi.pt.gl_333 sr.bs.hr_332  uk.be.un_640 be.ru.uk_542 
  0x23070a02, 0x1b641d07, 0x02001304, 0x10000f08,   // mk.bg.ky_222 la.lg.tr_432  et.da.un_320 lv.lt.un_430 
  0x0d5c0908, 0x30004e0d, 0x080a1704, 0x0a0436a0,   // hi.sa.ne_443 ay.uz.un_540  sr.mk.uk_332 ab.ru.mk_322 
  // [2630]
  0x17321604, 0x3100300e, 0x31000c04, 0x12003d13,   // hr.bs.sr_332 uz.az.un_550  sv.az.un_320 ku.ur.un_650 
  0x7900090d, 0x1d403f0c, 0x15303504, 0x13091c55,   // pl.war.un_540 af.lb.la_543  tg.uz.un_332 mr.hi.bh_442 
  0x11006502, 0x042308a0, 0x1200212c, 0x13230aa0,   // gv.ro.un_220 uk.ky.ru_322  fa.ur.un_990 pt.ca.et_322 
  0x0f003902, 0x12283007, 0x31003008, 0x061302a0,   // br.lv.un_220 uz.sd.ur_432  uz.az.un_430 da.et.de_322 
  // [2640]
  0x06130a05, 0x12001302, 0x350a07a0, 0x041365ee,   // pt.et.de_333 et.hu.un_220  bg.mk.tg_322 gv.et.fi_422 
  0x0665050c, 0x5c091ca0, 0x58003008, 0x0a234404,   // fr.gv.de_543 mr.hi.sa_322  uz.om.un_430 kk.ky.mk_332 
  0x070a350c, 0x0a003019, 0x130627ee, 0x215651a4,   // tg.mk.bg_543 uz.mk.un_750  gd.de.et_422 kl.mg.jw_433 
  0x1c1e6307, 0x06000e08, 0x151e1c09, 0x13205104,   // sco.ms.id_432 is.de.un_430  id.ms.un_444 kl.sq.et_332 
  // [2650]
  0x48303711, 0x34302107, 0x3f001807, 0x61000619,   // ba.uz.tt_653 fa.uz.ps_432  ga.af.un_420 de.za.un_750 
  0x27005002, 0x12004a12, 0x2b00fc0c, 0x1d000402,   // fj.gd.un_220 yo.hu.un_640  zzp.vi.un_530 fi.la.un_220 
  0x5c1c0da6, 0x04061311, 0x2b004204, 0x48233012,   // ne.mr.sa_521 et.de.fi_653  co.vi.un_320 uz.ky.tt_654 
  0x06001302, 0xfc563bec, 0x15383004, 0x13003e08,   // et.de.un_220 so.mg.zzp_644  uz.tk.un_332 rm.et.un_430 
  // [2660]
  0x3c302309, 0x4b004712, 0xfe00462c, 0x2b1e1c0d,   // ky.uz.ug_444 sn.mi.un_640  qu.tlh.un_990 id.ms.vi_554 
  0x1a495008, 0x13003304, 0x330826a0, 0x0f432812,   // fj.to.tl_443 nn.et.un_320  ia.no.nn_322 sw.ie.lv_654 
  0x173615ad, 0x1b072aa4, 0x4900470d, 0x22001d04,   // un.ab.sr_643 mt.it.tr_433  sn.to.un_540 la.oc.un_320 
  0x2c001005, 0x01303b0b, 0x2b00340d, 0x131c5ca6,   // lt.fy.un_330 so.uz.en_542  xh.vi.un_540 sa.mr.bh_521 
  // [2670]
  0x393305a0, 0x4f006814, 0x10000f0c, 0x63002b22,   // fr.nn.br_322 ig.bi.un_660  lv.lt.un_530 vi.sco.un_870 
  0x121828a4, 0xfc001a04, 0x055660a6, 0x5c0d1c0c,   // sd.ar.ur_433 tl.zzp.un_320  vo.mg.fr_521 mr.ne.sa_543 
  0x070804a4, 0x1f001504, 0x3d213004, 0x17102da0,   // ru.uk.bg_433 un.cy.un_320  uz.fa.ku_332 sk.lt.sr_322 
  0x3c00300e, 0x353c30a4, 0x123430af, 0x01232aa0,   // uz.ug.un_550 uz.ug.tg_433  uz.ps.ur_655 mt.ca.en_322 
  // [2680]
  0x016360a0, 0x1b003002, 0x5f345ea4, 0x286a3408,   // vo.sco.en_322 uz.tr.un_220  ts.xh.tn_433 xh.haw.sw_443 
  0x383c305a, 0x070a10a4, 0x20002213, 0x73345e14,   // uz.ug.tk_553 be.mk.bg_433  oc.sq.un_650 ts.xh.ny_666 
  0x21303407, 0x08006504, 0x47005e08, 0x28345e12,   // ps.uz.fa_432 gv.no.un_320  ts.sn.un_430 ts.xh.sw_654 
  0x6200fe13, 0x322d0d0d, 0x2d2279ee, 0x345f5ea0,   // tlh.kha.un_650 cs.sk.bs_554  war.oc.sk_422 ts.tn.xh_322 
  // [2690]
  0x38621f04, 0x0f3e430c, 0x2300381a, 0x35233807,   // cy.kha.tk_332 ie.rm.lv_543  tk.ky.un_760 tk.ky.tg_432 
  0x2c003f02, 0x346462a0, 0x0a353804, 0x09552fa0,   // af.fy.un_220 kha.lg.xh_322  tk.tg.mk_332 su.rw.pl_322 
  0x2f00220b, 0x0d001c1a, 0x16001002, 0x73fa34a4,   // oc.su.un_520 mr.ne.un_760  lt.hr.un_220 xh.nr.ny_433 
  0x2500040c, 0x5e003413, 0x2f003902, 0x34285e0c,   // ru.mn.un_530 xh.ts.un_650  br.su.un_220 ts.sw.xh_543 
  // [26a0]
  0x213418af, 0x35345e02, 0x233c4409, 0x55005e29,   // ar.ps.fa_655 ts.xh.zu_222  kk.ug.ky_444 ts.rw.un_960 
  0x233d3b0c, 0x34005e23, 0x123d21ee, 0x3f005f04,   // ks.ku.ky_543 ts.xh.un_880  fa.ku.ur_422 tn.af.un_320 
  0x12302107, 0x0e006013, 0x0408070c, 0x16001011,   // fa.uz.ur_432 vo.is.un_650  bg.uk.ru_543 lt.hr.un_630 
  0x082a3307, 0x12002a19, 0x13330804, 0x23071507,   // nn.mt.no_432 mt.hu.un_750  no.nn.et_332 un.bg.ky_432 
  // [26b0]
  0x06003302, 0x17000404, 0x251535ad, 0x3f0e0202,   // nn.de.un_220 ru.sr.un_320  tg.mn.un_630 da.is.af_222 
  0x30183d0e, 0x0408230c, 0x0b003604, 0x23002207,   // ku.ar.uz_555 ky.uk.ru_543  gn.es.un_320 oc.ca.un_420 
  0x2e000e1b, 0x75002d1a, 0x3c302307, 0x04001304,   // is.fo.un_770 sk.nso.un_760  ky.uz.ug_432 et.fi.un_320 
  0x06000c04, 0x3f000604, 0x40003f04, 0x23001707,   // sv.de.un_320 de.af.un_320  af.lb.un_320 sr.ky.un_420 
  // [26c0]
  0x1800340d, 0x3e002f04, 0x1d000108, 0x403f06a9,   // ps.ar.un_540 su.rm.un_320  en.la.un_430 de.af.lb_544 
  0x1500100d, 0x06033fa0, 0x341821a0, 0x080a17a0,   // be.un.un_540 af.nl.de_322  fa.ar.ps_322 sr.mk.uk_322 
  0x36190b13, 0x342144a0, 0x0d005b0b, 0x173538ad,   // es.gl.gn_665 kk.fa.ps_322  sg.cs.un_520 tk.tg.sr_643 
  0x0c330202, 0x11005d04, 0x36190b0d, 0x3f000605,   // da.nn.sv_222 ss.ro.un_320  es.gl.gn_554 de.af.un_330 
  // [26d0]
  0x3f4606a4, 0x514a3b07, 0x3f4006ec, 0x3600180d,   // de.qu.af_433 so.yo.kl_432  de.lb.af_644 ga.gn.un_540 
  0x2812210e, 0x0313400c, 0x40003f09, 0x3c0408a4,   // fa.ur.sd_555 lb.et.nl_543  af.lb.un_440 uk.ru.ug_433 
  0x36002d0c, 0x09000d1b, 0x381548a4, 0x6404680e,   // sk.gn.un_530 ne.hi.un_770  tt.tk.un_430 ig.fi.lg_555 
  0x48003502, 0x635864a4, 0x65000108, 0x63006514,   // tg.tt.un_220 lg.om.sco_433  en.gv.un_430 gv.sco.un_660 
  // [26e0]
  0x4d5a6a08, 0x4063010b, 0x630240ec, 0x39002c04,   // haw.sm.aa_443 en.sco.lb_542  lb.da.sco_644 fy.br.un_320 
  0x095c0d08, 0x0a00172b, 0x285246a0, 0x65630107,   // ne.sa.hi_443 sr.mk.un_980  qu.ha.sw_322 en.sco.gv_432 
  0x633f6e0c, 0x3f036513, 0x0a3c0705, 0x21461da9,   // hmn.af.sco_543 gv.nl.af_665  bg.ug.mk_333 la.qu.jw_544 
  0x09003004, 0x10730f12, 0x23001014, 0x30002504,   // uz.pl.un_320 lv.ny.lt_654  be.ky.un_660 eu.uz.un_320 
  // [26f0]
  0x12213012, 0x42001e0d, 0x42fe1f0c, 0x56006914,   // uz.fa.ur_654 ms.co.un_540  cy.tlh.co_543 mfe.mg.un_660 
  0x0f4b36a0, 0x0e001105, 0x2d0d120c, 0x483038a4,   // gn.mi.lv_322 ro.is.un_330  hu.cs.sk_543 tk.uz.tt_433 
  0x3800481a, 0x1a48fe0c, 0x5a364ba7, 0x170708ee,   // tt.tk.un_760 tlh.tt.tl_543  mi.gn.sm_532 uk.bg.sr_422 
  0x2f001d04, 0x61001b13, 0x04482302, 0x02000808,   // la.su.un_320 tr.za.un_650  ky.tt.ru_222 no.da.un_430 
  // [2700]
  0x39002904, 0x170423ac, 0x2a004d0d, 0x2100fe21,   // sl.br.un_320 ky.ru.sr_632  aa.mt.un_540 tlh.jw.un_860 
  0x0d6a5a0c, 0x02fe420d, 0x1b004814, 0x15fc39ad,   // sm.haw.cs_543 co.tlh.da_554  tt.tr.un_660 br.zzp.un_643 
  0x15003013, 0x0e2e65ec, 0x040f58ad, 0x041711a7,   // uz.un.un_650 gv.fo.is_644  om.lv.fi_643 ro.sr.ru_532 
  0x64001312, 0x58007936, 0x63204c0c, 0x35303807,   // et.lg.un_640 war.om.un_AA0  wo.sq.sco_543 tk.uz.tg_432 
  // [2710]
  0x12002507, 0x2400fc04, 0x26006e0d, 0x090d1c05,   // eu.hu.un_420 zzp.eo.un_320  hmn.ia.un_540 mr.ne.hi_333 
  0x2a4d240c, 0x202d17a0, 0x3500380c, 0x34005e21,   // eo.aa.mt_543 sr.sk.sq_322  tk.tg.un_530 ts.xh.un_860 
  0x52255712, 0x2e2d0d0d, 0x241b3ba9, 0x626563af,   // na.eu.ha_654 cs.sk.fo_554  so.tr.eo_544 sco.gv.kha_655 
  0x02244c07, 0x05630104, 0x00004f37, 0x656e61ad,   // wo.eo.da_432 en.sco.fr_332  bi.un.un_B00 za.hmn.gv_643 
  // [2720]
  0x52000108, 0x2e0633af, 0x33116107, 0x796340af,   // en.ha.un_430 nn.de.fo_655  za.ro.nn_432 lb.sco.war_655 
  0x433e0605, 0x2b036908, 0x4a5e520d, 0x4d5e2b0d,   // de.rm.ie_333 mfe.nl.vi_443  ha.ts.yo_554 vi.ts.aa_554 
  0x4800121a, 0x0c000809, 0x15040704, 0x1504480c,   // hu.tt.un_760 no.sv.un_440  bg.ru.un_332 tt.ru.un_543 
  0x37003b1b, 0x5e4a1a0d, 0x48007505, 0x1a6953a4,   // so.st.un_770 tl.yo.ts_554  nso.tt.un_330 ht.mfe.tl_433 
  // [2730]
  0x3f61300c, 0x31004011, 0x283421ee, 0x250c4812,   // uz.za.af_543 lb.az.un_630  fa.ps.sd_422 tt.sv.eu_654 
  0x06630107, 0x3046feee, 0x2022fead, 0x48001b08,   // en.sco.de_432 tlh.qu.uz_422  tlh.oc.sq_643 tr.tt.un_430 
  0x2476530d, 0x133f24a7, 0x30006e2a, 0x4f6301a4,   // ht.crs.eo_554 eo.af.et_532  hmn.uz.un_970 en.sco.bi_433 
  0x2b000108, 0x080411a0, 0x37442304, 0x3b006514,   // en.vi.un_430 ro.ru.uk_322  ky.kk.ba_332 gv.so.un_660 
  // [2740]
  0x0f2f1ca0, 0x070501af, 0x190701a4, 0x1b3830a9,   // id.su.lv_322 en.fr.it_655  en.it.gl_433 uz.tk.tr_544 
  0x38003f04, 0x542d0d07, 0x38463055, 0x35345daf,   // af.tk.un_320 cs.sk.ik_432  uz.qu.tk_442 ss.xh.zu_655 
  0x1b001012, 0x6b1d0107, 0x381b3108, 0x370415a0,   // lt.tr.un_640 en.la.ceb_432  az.tr.tk_443 un.ru.ba_322 
  0x4823350e, 0x01636507, 0x310c1ba0, 0x3500100b,   // tg.ky.tt_555 gv.sco.en_432  tr.sv.az_322 lt.zu.un_520 
  // [2750]
  0x5d351104, 0x483c37ad, 0x69765312, 0x2d0d290e,   // ro.zu.ss_332 ba.ug.tt_643  ht.crs.mfe_654 sl.cs.sk_555 
  0x5d3550a4, 0x5d1369af, 0x21003412, 0x301b2555,   // fj.zu.ss_433 mfe.et.ss_655  ps.fa.un_640 eu.tr.uz_442 
  0x3800440e, 0x08023314, 0x28211812, 0x0a303c0c,   // kk.tk.un_550 nn.da.no_666  ar.fa.sd_654 ug.uz.mk_543 
  0x211218ad, 0x2a101b08, 0x38000405, 0x12103109,   // ar.ur.fa_643 tr.lt.mt_443  fi.tk.un_330 az.lt.hu_444 
  // [2760]
  0x19000b08, 0x12281807, 0x30350aec, 0x0a071504,   // es.gl.un_430 ar.sd.ur_432  mk.tg.uz_644 un.bg.mk_332 
  0x28003412, 0x090d1c12, 0x08003502, 0xfc6b1a55,   // ps.sd.un_640 mr.ne.hi_654  tg.uk.un_220 tl.ceb.zzp_442 
  0x373c300c, 0x15004412, 0x5c1c0da0, 0x53000507,   // uz.ug.ba_543 kk.un.un_640  ne.mr.sa_322 fr.ht.un_420 
  0x281821a0, 0x3844170c, 0x29001007, 0x0408100d,   // fa.ar.sd_322 sr.kk.tk_543  lt.sl.un_420 be.uk.ru_554 
  // [2770]
  0xfe006309, 0x0c00130c, 0x303815ad, 0x17080aa0,   // sco.tlh.un_440 et.sv.un_530  un.tk.uz_643 mk.uk.sr_322 
  0x38001002, 0x35fc1aa0, 0x00005b1c, 0x44003822,   // lt.tk.un_220 tl.zzp.zu_322  sg.un.un_800 tk.kk.un_870 
  0x583f0309, 0x3b3f03af, 0x1c000920, 0x3f3b580d,   // nl.af.om_444 nl.af.so_655  hi.mr.un_850 om.so.af_554 
  0x070a1702, 0x3d001202, 0x173c3055, 0x034d3bad,   // sr.mk.bg_222 ur.ku.un_220  uz.ug.sr_442 so.aa.nl_643 
  // [2780]
  0x4f221dee, 0x34182812, 0x73353408, 0x3f034d12,   // la.oc.bi_422 sd.ar.ps_654  xh.zu.ny_443 aa.nl.af_654 
  0x0000fa0f, 0x4a033fad, 0x3700110d, 0x2d003b04,   // nr.un.un_600 af.nl.yo_643  ro.ba.un_540 so.sk.un_320 
  0x643b58a9, 0x05233008, 0x0d002d1a, 0x23462255,   // om.so.lg_544 uz.ca.fr_443  sk.cs.un_760 oc.qu.ca_442 
  0x0e002212, 0x06001f09, 0x5c1c0dee, 0x3c4423af,   // oc.is.un_640 cy.de.un_440  ne.mr.sa_422 ky.kk.ug_655 
  // [2790]
  0x3f003b0c, 0x1b003102, 0x190b2202, 0x1c09130b,   // so.af.un_530 az.tr.un_220  oc.es.gl_222 bh.hi.mr_542 
  0x3b036307, 0x1b3f03a7, 0x03004602, 0x64003f0d,   // sco.nl.so_432 nl.af.tr_532  qu.nl.un_220 af.lg.un_540 
  0x3400350c, 0x1b003123, 0x3b005812, 0x220a0507,   // zu.xh.un_530 az.tr.un_880  om.so.un_640 fr.pt.oc_432 
  0x4d033f07, 0x380a17af, 0x18000107, 0x18485da0,   // af.nl.aa_432 sr.mk.tk_655  en.ga.un_420 ss.tt.ga_322 
  // [27a0]
  0x0b006507, 0x34213007, 0x3b004d0b, 0x34005e1b,   // gv.es.un_420 uz.fa.ps_432  aa.so.un_520 ts.xh.un_770 
  0x3500730d, 0x37353405, 0x091c0dee, 0x48001b22,   // ny.zu.un_540 xh.zu.st_333  ne.mr.hi_422 tr.tt.un_870 
  0x07000407, 0x13000929, 0x0e0c2e07, 0x57060a08,   // ru.bg.un_420 hi.bh.un_960  fo.sv.is_432 pt.de.na_443 
  0x31004802, 0x23460a04, 0x08254902, 0x01002411,   // tt.az.un_220 pt.qu.ca_332  to.eu.no_222 yi.iw.un_630 
  // [27b0]
  0x5e253f02, 0x19224655, 0x25001302, 0xfe004613,   // af.eu.ts_222 qu.oc.gl_442  et.eu.un_220 qu.tlh.un_650 
  0x342118ee, 0x032c3f04, 0x493f2507, 0x4a002b0d,   // ar.fa.ps_422 af.fy.nl_332  eu.af.to_432 vi.yo.un_540 
  0x3500451a, 0x19001804, 0x3412280d, 0x3f000308,   // ln.zu.un_760 ga.gl.un_320  sd.ur.ps_554 nl.af.un_430 
  0x68300205, 0x1b0f20ad, 0x00005f0a, 0x44173507,   // da.uz.ig_333 sq.lv.tr_643  tn.un.un_500 tg.sr.kk_432 
  // [27c0]
  0x2c3f03af, 0x52352907, 0x0c0276ee, 0x130d5cad,   // nl.af.fy_655 sl.zu.ha_432  crs.da.sv_422 sa.ne.bh_643 
  0x0000750a, 0x30005213, 0x5c000d02, 0x21303414,   // nso.un.un_500 ha.uz.un_650  ne.sa.un_220 ps.uz.fa_666 
  0x372315ee, 0x1300fe19, 0x563f25a0, 0x15303508,   // un.ky.ba_422 tlh.et.un_750  eu.af.mg_322 tg.uz.un_443 
  0x0000fe2d, 0x4a003013, 0x3d343ba7, 0x0a0708ad,   // tlh.un.un_A00 uz.yo.un_650  ks.ps.ku_532 uk.bg.mk_643 
  // [27d0]
  0x135cfe11, 0x2a05feaf, 0x0230640e, 0x4e46fe11,   // tlh.sa.et_653 tlh.fr.mt_655  lg.uz.da_555 tlh.qu.ay_653 
  0x4200290d, 0x19000904, 0x2a0f4205, 0x55007304,   // sl.co.un_540 pl.gl.un_320  co.lv.mt_333 ny.rw.un_320 
  0x160f02ee, 0x170f29ad, 0x383308ee, 0x1f422a07,   // da.lv.hr_422 sl.lv.sr_643  no.nn.tk_422 mt.co.cy_432 
  0x2800210e, 0x4a00680d, 0x321142ee, 0x39fe130d,   // fa.sd.un_550 ig.yo.un_540  co.ro.bs_422 et.tlh.br_554 
  // [27e0]
  0x4600fe14, 0xfc000802, 0x201e1c0c, 0x18212807,   // tlh.qu.un_660 no.zzp.un_220  id.ms.sq_543 sd.fa.ar_432 
  0x6536620c, 0x297332a4, 0x520d64a7, 0x4600fe22,   // kha.gn.gv_543 bs.ny.sl_433  lg.cs.ha_532 tlh.qu.un_870 
  0x05fe4614, 0x3418230c, 0x425e0d07, 0x4b5564a7,   // qu.tlh.fr_666 ky.ar.ps_543  cs.ts.co_432 lg.rw.mi_532 
  0x23441814, 0x1e001c22, 0x364b020c, 0x42023707,   // ar.kk.ky_666 id.ms.un_870  da.mi.gn_543 st.da.co_432 
  // [27f0]
  0x170710a0, 0x4b2a42a4, 0x095c1ca7, 0x5800fc1a,   // be.bg.sr_322 co.mt.mi_433  mr.sa.hi_532 zzp.om.un_760 
  0x4c585a04, 0x214006a9, 0x25353405, 0x67347809,   // sm.om.wo_332 de.lb.jw_544  xh.zu.eu_333 ve.xh.ak_444 
  0x56000104, 0x371c1e0c, 0x20465004, 0x56473e07,   // en.mg.un_320 ms.id.st_543  fj.qu.sq_332 rm.sn.mg_432 
  0x23000d07, 0x0a101505, 0x044410a0, 0x2f651307,   // cs.ca.un_420 un.be.mk_333  be.kk.ru_322 et.gv.su_432 
  
  // [2800]
  0x1202fea7, 0x1dfc0255, 0x0d005c04, 0x303744a4,   // tlh.da.hu_532 da.zzp.la_442  sa.ne.un_320 kk.ba.uz_433 
  0x17321608, 0x4a001805, 0x071025ee, 0x3d003018,   // hr.bs.sr_443 ga.yo.un_330  mn.be.bg_422 uz.ku.un_740 
  0x32001612, 0x5100460c, 0x460e0407, 0x44003811,   // hr.bs.un_640 qu.kl.un_530  fi.is.qu_432 tk.kk.un_630 
  0x0e0f13a4, 0x443637a0, 0x442123ec, 0x34181202,   // et.lv.is_433 ba.ab.kk_322  ky.fa.kk_644 ur.ar.ps_222 
  // [2810]
  0x1b302e02, 0x27003404, 0x5d003502, 0x2c033fa4,   // fo.uz.tr_222 xh.gd.un_320  zu.ss.un_220 af.nl.fy_433 
  0x213d30ec, 0x190b2305, 0x286468a4, 0x2a345e0b,   // uz.ku.fa_644 ca.es.gl_333  ig.lg.sw_433 ts.xh.mt_542 
  0x23483807, 0x00006b0f, 0x3f036402, 0x1d001c04,   // tk.tt.ky_432 ceb.un.un_600  lg.nl.af_222 id.la.un_320 
  0x6b1a790d, 0x17290f02, 0x03005e04, 0x29000c04,   // war.tl.ceb_554 lv.sl.sr_222  ts.nl.un_320 sv.sl.un_320 
  // [2820]
  0x081015a4, 0x2e006307, 0x1d2731ee, 0x271843a4,   // un.be.uk_433 sco.fo.un_420  az.gd.la_422 ie.ga.gd_433 
  0x34182104, 0x5c0e540c, 0x0a07170c, 0x182d0d20,   // fa.ar.ps_332 ik.is.sa_543  sr.bg.mk_543 cs.sk.ga_875 
  0xfc005c08, 0x20001e08, 0x796b39ad, 0x1800230c,   // sa.zzp.un_430 am.ti.un_430  br.ceb.war_643 ky.ar.un_530 
  0x2c000304, 0x0c001704, 0x2d2e0dee, 0x183c3da0,   // nl.fy.un_320 sr.sv.un_320  cs.fo.sk_422 ku.ug.ar_322 
  // [2830]
  0x0a07170e, 0x1e001c0e, 0x12003b12, 0x2e000e14,   // sr.bg.mk_555 id.ms.un_550  ks.ur.un_640 is.fo.un_660 
  0x183428ad, 0x4d1d1213, 0x09004f13, 0x121d4f0d,   // sd.ps.ar_643 hu.la.aa_665  bi.pl.un_650 bi.la.hu_554 
  0x38001113, 0x150a1da0, 0x0d001904, 0x06404d07,   // ro.tk.un_650 la.pt.un_322  gl.cs.un_320 aa.lb.de_432 
  0x35001702, 0x0d094fec, 0x18004a08, 0x20001204,   // sr.tg.un_220 bi.pl.cs_644  yo.ga.un_430 hu.sq.un_320 
  // [2840]
  0x12002914, 0x061379a0, 0x39586513, 0x0d060905,   // sl.hu.un_660 war.et.de_322  gv.om.br_665 pl.de.cs_333 
  0x395b6508, 0x58002a23, 0x0f2d2912, 0x11094da9,   // gv.sg.br_443 mt.om.un_880  sl.sk.lv_654 aa.pl.ro_544 
  0x636501ee, 0x234f1dec, 0x65002719, 0x27002a13,   // en.gv.sco_422 la.bi.ca_644  gd.gv.un_750 mt.gd.un_650 
  0x40002702, 0x6520580c, 0x653b5804, 0x4804110c,   // gd.lb.un_220 om.sq.gv_543  om.so.gv_332 ro.ru.tt_543 
  // [2850]
  0x17000a19, 0x4d655807, 0x23000a04, 0x0d094dad,   // mk.sr.un_750 om.gv.aa_432  mk.ky.un_320 aa.pl.cs_643 
  0x230408a0, 0x12002a14, 0x484d1211, 0x58004c1a,   // uk.ru.ky_322 mt.hu.un_660  hu.aa.tt_653 wo.om.un_760 
  0x09121d0c, 0x3130fe13, 0x1d004f1a, 0x0f003b07,   // la.hu.pl_543 tlh.uz.az_665  bi.la.un_760 so.lv.un_420 
  0x40000f02, 0x38203002, 0x2f001304, 0x21192355,   // lv.lb.un_220 uz.sq.tk_222  et.su.un_320 ca.gl.jw_442 
  // [2860]
  0x15003b04, 0x315258ad, 0x06041304, 0x2465fe07,   // so.un.un_320 om.ha.az_643  et.fi.de_332 tlh.gv.eo_432 
  0x5afc2408, 0x13494b07, 0x1c002904, 0x2d0d24a4,   // eo.zzp.sm_443 mi.to.et_432  sl.id.un_320 eo.cs.sk_433 
  0x21123ba4, 0x06466502, 0x132d0da0, 0x791a6ba4,   // ks.ur.fa_433 gv.qu.de_222  cs.sk.et_322 ceb.tl.war_433 
  0x2b192307, 0x1800281a, 0x18006504, 0x0c2d0d0c,   // ca.gl.vi_432 sd.ar.un_760  gv.ga.un_320 cs.sk.sv_543 
  // [2870]
  0x2e006213, 0x09001313, 0x016502a0, 0x4c005f04,   // kha.fo.un_650 bh.hi.un_650  da.gv.en_322 tn.wo.un_320 
  0x5d09240c, 0x0a1707ec, 0x2f002904, 0x2b001804,   // eo.pl.ss_543 bg.sr.mk_644  sl.su.un_320 ga.vi.un_320 
  0x3b005805, 0x030c0f07, 0x38002323, 0x65033bad,   // om.so.un_330 lv.sv.nl_432  ky.tk.un_880 so.nl.gv_643 
  0x3000040c, 0x2a484ca0, 0x120d09a4, 0x64242504,   // ru.uz.un_530 wo.tt.mt_322  pl.cs.hu_433 eu.eo.lg_332 
  // [2880]
  0x0e002e19, 0x4b0637a0, 0x425e24a4, 0x4c00560c,   // fo.is.un_750 st.de.mi_322  eo.ts.co_433 mg.wo.un_530 
  0x092d0d0c, 0x18003009, 0x5c1c0d05, 0x4b006713,   // cs.sk.pl_543 uz.ar.un_440  ne.mr.sa_333 ak.mi.un_650 
  0x6b041a0c, 0x212f1c0d, 0x15001113, 0x04000a12,   // tl.fi.ceb_543 id.su.jw_554  ro.un.un_650 mk.ru.un_640 
  0x292d12ee, 0x044b2fa7, 0x092d29a4, 0x4c0224a4,   // hu.sk.sl_422 su.mi.fi_532  sl.sk.pl_433 eo.da.wo_433 
  // [2890]
  0x0f2d0d08, 0x1a2479a4, 0x1b005304, 0x301711a4,   // cs.sk.lv_443 war.eo.tl_433  ht.tr.un_320 ro.sr.uz_433 
  0x1c5c0d04, 0x01004602, 0x303538a4, 0x0a002308,   // ne.sa.mr_332 qu.en.un_220  tk.tg.uz_433 ca.pt.un_430 
  0x37081004, 0x131c5c55, 0x6b461a07, 0x4700731b,   // be.uk.ba_332 sa.mr.bh_442  tl.qu.ceb_432 ny.sn.un_770 
  0x73005e19, 0xfc003504, 0x093856a0, 0x09005604,   // ts.ny.un_750 zu.zzp.un_320  mg.tk.pl_322 mg.pl.un_320 
  // [28a0]
  0xfc004702, 0x0e2e4a08, 0x0d001c05, 0x562d0d05,   // sn.zzp.un_220 yo.fo.is_443  mr.ne.un_330 cs.sk.mg_333 
  0x254448a0, 0x39001d07, 0x38005608, 0x28631da0,   // tt.kk.mn_322 la.br.un_420  mg.tk.un_430 la.sco.sw_322 
  0x070a17a0, 0x38303c0c, 0x56000b02, 0x65005608,   // sr.mk.bg_322 ug.uz.tk_543  es.mg.un_220 mg.gv.un_430 
  0x042e0ea4, 0x231544a4, 0x4d00120c, 0x151008a4,   // is.fo.fi_433 kk.ky.un_430  hu.aa.un_530 uk.be.un_433 
  // [28b0]
  0x21190ba4, 0x2134300c, 0x21002f18, 0x33080209,   // es.gl.jw_433 uz.ps.fa_543  su.jw.un_740 da.no.nn_444 
  0x0d4d12a4, 0x00001606, 0x38002321, 0x10304804,   // hu.aa.cs_433 hr.un.un_400  ky.tk.un_860 tt.uz.lt_332 
  0x091c5cad, 0x4d001213, 0x430d12ad, 0x12004d08,   // sa.mr.hi_643 hu.aa.un_650  hu.cs.ie_643 aa.hu.un_430 
  0x1300060c, 0x080a1714, 0x12004d12, 0x0e003304,   // de.et.un_530 sr.mk.uk_666  aa.hu.un_640 nn.is.un_320 
  // [28c0]
  0x09005607, 0x483c30a4, 0x38095607, 0x4d001208,   // mg.pl.un_420 uz.ug.tt_433  mg.pl.tk_432 hu.aa.un_430 
  0x343d2107, 0x2c0473a0, 0x1c5c0911, 0x4837110c,   // fa.ku.ps_432 ny.fi.fy_322  hi.sa.mr_653 ro.ba.tt_543 
  0x2d0d120e, 0x12004d14, 0x2d120d0e, 0x2d0d12ec,   // hu.cs.sk_555 aa.hu.un_660  cs.hu.sk_555 hu.cs.sk_644 
  0x2f210ba0, 0x40212fee, 0x5d4813a0, 0x0000112d,   // es.jw.su_322 su.jw.lb_422  et.tt.ss_322 ro.un.un_A00 
  // [28d0]
  0x3500550c, 0x2d0d1209, 0x73472813, 0x13042507,   // rw.zu.un_530 hu.cs.sk_444  sw.sn.ny_665 eu.fi.et_432 
  0x1c0d09a4, 0x082133ee, 0x17485e02, 0x18fc09ad,   // hi.ne.mr_433 nn.jw.no_422  ts.tt.sr_222 pl.zzp.ga_643 
  0x5c004c02, 0x06005e07, 0x5500670e, 0x1535300c,   // wo.sa.un_220 ts.de.un_420  ak.rw.un_550 uz.tg.un_543 
  0x03000602, 0x0f00750e, 0x033f4cec, 0x091c0da6,   // de.nl.un_220 nso.lv.un_550  wo.af.nl_644 ne.mr.hi_521 
  // [28e0]
  0x0d5c1c07, 0x1c005c14, 0x19360b04, 0x2112300b,   // mr.sa.ne_432 sa.mr.un_660  es.gn.gl_332 uz.ur.fa_542 
  0x383f4da0, 0x30004804, 0x12484dee, 0x0d006005,   // aa.af.tk_322 tt.uz.un_320  aa.tt.hu_422 vo.cs.un_330 
  0x04000705, 0x27003904, 0x5e595504, 0x07170a02,   // bg.ru.un_330 br.gd.un_320  rw.rn.ts_332 mk.sr.bg_222 
  0x18282109, 0x23000a02, 0x341812a0, 0x04004012,   // fa.sd.ar_444 mk.ky.un_220  ur.ar.ps_322 lb.fi.un_640 
  // [28f0]
  0x5c090dee, 0x10040704, 0x19000b1b, 0x25003507,   // ne.hi.sa_422 bg.ru.be_332  es.gl.un_770 tg.mn.un_420 
  0x342821a0, 0x13000d07, 0x10000807, 0x44003c20,   // fa.sd.ps_322 ne.bh.un_420  uk.be.un_420 ug.kk.un_850 
  0x0a300708, 0x03755f08, 0x2118340c, 0x04302504,   // bg.uz.mk_443 tn.nso.nl_443  ps.ar.fa_543 mn.uz.ru_332 
  0x2300250e, 0x576301a0, 0x1c000d07, 0x2d0d48a0,   // mn.ky.un_550 en.sco.na_322  ne.mr.un_420 tt.cs.sk_322 
  // [2900]
  0x23190b55, 0x35000704, 0x35001009, 0x51004d07,   // es.gl.ca_442 bg.tg.un_320  be.tg.un_440 aa.kl.un_420 
  0x4a000b05, 0x34006414, 0x1d003b1a, 0x511b1ca4,   // es.yo.un_330 lg.xh.un_660  so.la.un_760 id.tr.kl_433 
  0x1d5f370c, 0x4c504aee, 0x4e79470c, 0x37585fa4,   // st.tn.la_543 yo.fj.wo_422  sn.war.ay_543 tn.om.st_433 
  0x1d11190c, 0x250434ee, 0x4a001b2b, 0x30003107,   // gl.ro.la_543 xh.fi.eu_422  tr.yo.un_980 az.uz.un_420 
  // [2910]
  0x30253507, 0x3b3f4c07, 0x38001021, 0x3d1828ee,   // tg.mn.uz_432 wo.af.so_432  be.tk.un_860 sd.ar.ku_422 
  0x3b004c18, 0x2d000c07, 0x4a00470d, 0x31001b2a,   // wo.so.un_740 sv.sk.un_420  sn.yo.un_540 tr.az.un_970 
  0x4c3f035a, 0x17000d0d, 0x1d0a2309, 0x653f0311,   // nl.af.wo_553 cs.sr.un_540  ca.pt.la_444 nl.af.gv_653 
  0x58003122, 0x06470ead, 0x13004c12, 0x4a001214,   // az.om.un_870 is.sn.de_643  wo.et.un_640 hu.yo.un_660 
  // [2920]
  0x3c002509, 0x06594707, 0x2c004c09, 0x034c3fa4,   // mn.ug.un_440 sn.rn.de_432  wo.fy.un_440 af.wo.nl_433 
  0x02004c12, 0x22230a0c, 0x44151507, 0x3d1221a0,   // wo.da.un_640 pt.ca.oc_543  un.kk.un_420 fa.ur.ku_322 
  0x23003c19, 0x1b000302, 0x4c003b0d, 0x03003f22,   // ug.ky.un_750 nl.tr.un_220  so.wo.un_540 af.nl.un_870 
  0x17000807, 0x3f4c63ee, 0x42580107, 0x3b134c07,   // uk.sr.un_420 sco.wo.af_422  en.om.co_432 wo.et.so_432 
  // [2930]
  0x07006404, 0x0b120da7, 0x60392408, 0x20230aa7,   // lg.it.un_320 cs.hu.es_532  eo.br.vo_443 pt.ca.sq_532 
  0x34fc01ad, 0x35345d14, 0x3f404cee, 0x1d002002,   // en.zzp.xh_643 ss.xh.zu_666  wo.lb.af_422 sq.la.un_220 
  0x1b170ea0, 0x5d353404, 0x06231da4, 0x2ffe5907,   // is.sr.tr_322 xh.zu.ss_332  la.ca.de_433 rn.tlh.su_432 
  0x21123b07, 0x35005d05, 0x121819a0, 0x3f020e0c,   // ks.ur.fa_432 ss.zu.un_330  gl.ga.hu_322 is.da.af_543 
  // [2940]
  0x150603a0, 0x1d0b2304, 0x18001212, 0x791a0f08,   // nl.de.un_322 ca.es.la_332  hu.ga.un_640 lv.tl.war_443 
  0x060325a0, 0x361218af, 0x212f1ca4, 0x22641155,   // eu.nl.de_322 ga.hu.gn_655  id.su.jw_433 ro.lg.oc_442 
  0x1c001e07, 0x050742a0, 0x0300fe0e, 0x28003b09,   // ms.id.un_420 co.it.fr_322  tlh.nl.un_550 so.sw.un_440 
  0x37251004, 0x0d001208, 0x1c1e6a5a, 0x1b004804,   // be.mn.ba_332 hu.cs.un_430  haw.ms.id_553 tt.tr.un_320 
  // [2950]
  0x48000708, 0x3b00fe02, 0x48006305, 0x0e00580c,   // bg.tt.un_430 tlh.so.un_220  sco.tt.un_330 om.is.un_530 
  0x280118a0, 0x025f0fa4, 0x1d5c2108, 0x12000912,   // ga.en.sw_322 lv.tn.da_433  jw.sa.la_443 pl.hu.un_640 
  0x6e290fa4, 0x00005d0a, 0x0d00120c, 0x0c003608,   // lv.sl.hmn_433 ss.un.un_500  hu.cs.un_530 gn.sv.un_430 
  0x09001209, 0x15170404, 0x070a11af, 0x12000913,   // hu.pl.un_440 ru.sr.un_332  ro.mk.bg_655 pl.hu.un_650 
  // [2960]
  0x3f002c0d, 0x1200181a, 0x18120d0b, 0x06000302,   // fy.af.un_540 ga.hu.un_760  cs.hu.ga_542 nl.de.un_220 
  0x3f0f100c, 0x3b001f1a, 0x34212804, 0x06006308,   // lt.lv.af_543 cy.so.un_760  sd.fa.ps_332 sco.de.un_430 
  0x1800620c, 0x3c213404, 0x5e000402, 0x09456a08,   // kha.ga.un_530 ps.fa.ug_332  fi.ts.un_220 haw.ln.pl_443 
  0x0a3025ad, 0x4c5d7655, 0x0d1c5c5a, 0x31005214,   // mn.uz.mk_643 crs.ss.wo_442  sa.mr.ne_553 ha.az.un_660 
  // [2970]
  0x30000604, 0x3d30345a, 0x2a006502, 0x30311b0c,   // de.uz.un_320 ps.uz.ku_553  gv.mt.un_220 tr.az.uz_543 
  0x12251309, 0x36000a14, 0x551b4a07, 0x1c095c04,   // et.eu.hu_444 mk.ab.un_660  yo.tr.rw_432 sa.hi.mr_332 
  0x250408ee, 0x3f090f07, 0x023f13ec, 0x0900120e,   // uk.ru.mn_422 lv.pl.af_432  et.af.da_644 hu.pl.un_550 
  0x36220a07, 0x123421ee, 0x635550ad, 0x09250307,   // pt.oc.gn_432 fa.ps.ur_422  fj.rw.sco_643 nl.eu.pl_432 
  // [2980]
  0x09131c55, 0x073510ee, 0x130d0909, 0x1c00130c,   // mr.bh.hi_442 be.tg.bg_422  hi.ne.bh_444 bh.mr.un_530 
  0x1800340b, 0x103f0f09, 0x65002a13, 0x643545ad,   // ps.ar.un_520 lv.af.lt_444  mt.gv.un_650 ln.zu.lg_643 
  0x2a003b04, 0x683f100c, 0x12190d0c, 0x0a353cad,   // so.mt.un_320 lt.af.ig_543  cs.gl.hu_543 ug.tg.mk_643 
  0x0f00090e, 0x30003114, 0x5c1c0907, 0x350c16a0,   // pl.lv.un_550 az.uz.un_660  hi.mr.sa_432 hr.sv.zu_322 
  // [2990]
  0x242867ec, 0x0700100b, 0x0b003333, 0x5e355da0,   // ak.sw.eo_644 be.bg.un_520  as.bn.un_A70 ss.zu.ts_322 
  0x3000310d, 0x28387507, 0x300a0704, 0x0e004a16,   // az.uz.un_540 nso.tk.sw_432  bg.mk.uz_332 yo.is.un_720 
  0x18283413, 0x23000d08, 0x1d004d07, 0x1b0a0207,   // ps.sd.ar_665 cs.ca.un_430  aa.la.un_420 da.pt.tr_432 
  0x12281855, 0x00004a01, 0x11003619, 0x07003502,   // ar.sd.ur_442 yo.un.un_200  ab.ro.un_750 tg.bg.un_220 
  // [29a0]
  0x0a234fa0, 0x383530af, 0x29231d04, 0x48002312,   // bi.ca.pt_322 uz.tg.tk_655  la.ca.sl_332 ky.tt.un_640 
  0x12002121, 0x23001d07, 0x22005712, 0x65102cee,   // fa.ur.un_860 la.ca.un_420  na.oc.un_640 fy.lt.gv_422 
  0x12000408, 0x3b46fc55, 0x2112285a, 0x48001d05,   // fi.hu.un_430 zzp.qu.so_442  sd.ur.fa_553 la.tt.un_330 
  0x36190b55, 0x0e48120c, 0x0d001213, 0x48311b55,   // es.gl.gn_442 hu.tt.is_543  hu.cs.un_650 tr.az.tt_442 
  // [29b0]
  0x431d0da0, 0x1d002304, 0x65fc7911, 0x2f002a04,   // cs.la.ie_322 ca.la.un_320  war.zzp.gv_653 mt.su.un_320 
  0x691b3e0c, 0x38441508, 0x04382307, 0x473b2a0b,   // rm.tr.mfe_543 un.kk.tk_443  ky.tk.ru_432 mt.so.sn_542 
  0x73473b0b, 0x043010ad, 0x7347fe02, 0xfe4c21ec,   // so.sn.ny_542 be.uz.ru_643  tlh.sn.ny_222 jw.wo.tlh_644 
  0x03240ca4, 0x15002804, 0x0a070455, 0x46791aaf,   // sv.eo.nl_433 sw.un.un_320  ru.bg.mk_442 tl.war.qu_655 
  // [29c0]
  0x1f3f2d0c, 0x3b1f210c, 0x0e003302, 0x04000819,   // sk.af.cy_543 jw.cy.so_543  nn.is.un_220 uk.ru.un_750 
  0x3bfc3407, 0x2d001212, 0x23004402, 0x090d5cad,   // xh.zzp.so_432 hu.sk.un_640  kk.ky.un_220 sa.ne.hi_643 
  0x090d1307, 0x47004b0b, 0x2d040daf, 0x58462104,   // bh.ne.hi_432 mi.sn.un_520  cs.fi.sk_655 jw.qu.om_332 
  0x441504a4, 0x46001a0c, 0x401306a0, 0x1f004b07,   // ru.kk.un_430 tl.qu.un_530  de.et.lb_322 mi.cy.un_420 
  // [29d0]
  0xfc000302, 0x57211aec, 0x271f1811, 0x0b001907,   // nl.zzp.un_220 tl.jw.na_644  ga.cy.gd_653 gl.es.un_420 
  0x3f005d05, 0x382325ee, 0x090d1312, 0x0d5c1c0b,   // ss.af.un_330 mn.ky.tk_422  bh.ne.hi_654 mr.sa.ne_542 
  0x221223ec, 0x091c5c0c, 0x5c1c1305, 0x48003714,   // ca.hu.oc_644 sa.mr.hi_543  bh.mr.sa_333 ba.tt.un_660 
  0x3700380c, 0x02fc1f12, 0x563747a0, 0x300a35a6,   // tk.ba.un_530 cy.zzp.da_654  sn.st.mg_322 tg.mk.uz_521 
  // [29e0]
  0x3012340d, 0x3748380c, 0x393428a4, 0x1b000d10,   // ps.ur.uz_554 tk.tt.ba_543  sw.xh.br_433 cs.tr.un_620 
  0x1504080d, 0x3500342c, 0x133160ad, 0x48041507,   // uk.ru.un_554 xh.zu.un_990  vo.az.et_643 un.ru.tt_432 
  0x0d00120b, 0x20246912, 0x0d095caf, 0x20002d04,   // hu.cs.un_520 mfe.eo.sq_654  sa.hi.ne_655 sk.sq.un_320 
  0x4700782c, 0x190b600c, 0x11001513, 0x0000601c,   // ve.sn.un_990 vo.es.gl_543  un.ro.un_650 vo.un.un_800 
  // [29f0]
  0x106976ad, 0x13006402, 0x21303412, 0x3e360b05,   // crs.mfe.lt_643 lg.et.un_220  ps.uz.fa_654 es.gn.rm_333 
  0x1a003908, 0x2d120d0c, 0x640742a7, 0x121a0cad,   // br.tl.un_430 cs.hu.sk_543  co.it.lg_532 sv.tl.hu_643 
  0x0900530e, 0x120c1aa7, 0x3f400607, 0x20001107,   // ht.pl.un_550 tl.sv.hu_532  de.lb.af_432 ro.sq.un_420 
  0x23193607, 0x4200290c, 0x4a194ca9, 0x12194a04,   // gn.gl.ca_432 sl.co.un_530  wo.gl.yo_544 yo.gl.hu_332 
  // [2a00]
  0x460b2302, 0x65005308, 0x3e3f40a4, 0x213d30ac,   // ca.es.qu_222 ht.gv.un_430  lb.af.rm_433 uz.ku.fa_632 
  0xfe004f19, 0x1c0913ad, 0x12003905, 0x47695307,   // bi.tlh.un_750 bh.hi.mr_643  br.hu.un_330 ht.mfe.sn_432 
  0x641f69ac, 0x09005c13, 0xfc00570c, 0x120c1313,   // mfe.cy.lg_632 sa.hi.un_650  na.zzp.un_530 et.sv.hu_665 
  0x0b3e36a9, 0x16290d04, 0x080c330c, 0x3f001f1a,   // gn.rm.es_544 cs.sl.hr_332  nn.sv.no_543 cy.af.un_760 
  // [2a10]
  0x160d2904, 0xfc796b5a, 0x11002321, 0x06001f07,   // sl.cs.hr_332 ceb.war.zzp_553  ky.ro.un_860 cy.de.un_420 
  0x21341811, 0x481b315a, 0x38002910, 0x06001a04,   // ar.ps.fa_653 az.tr.tt_553  sl.tk.un_620 tl.de.un_320 
  0x2b000504, 0x1c396a0b, 0x211828ad, 0x1a79650b,   // fr.vi.un_320 haw.br.id_542  sd.ar.fa_643 gv.war.tl_542 
  0x08171505, 0x7900470e, 0x33000821, 0x00001e06,   // un.sr.uk_333 sn.war.un_550  no.nn.un_860 ms.un.un_400 
  // [2a20]
  0x38002319, 0x4000300b, 0x6400470c, 0x03431d05,   // ky.tk.un_750 uz.lb.un_520  sn.lg.un_530 la.ie.nl_333 
  0x04083507, 0x29000d09, 0x2e004a13, 0x0d13090b,   // tg.uk.ru_432 cs.sl.un_440  yo.fo.un_650 hi.bh.ne_542 
  0x03003f0e, 0x211228a7, 0x0f003204, 0x69000613,   // af.nl.un_550 sd.ur.fa_532  bs.lv.un_320 de.mfe.un_650 
  0xfc00020c, 0xfc004d0c, 0x38440a05, 0x2f002002,   // da.zzp.un_530 aa.zzp.un_530  mk.kk.tk_333 sq.su.un_220 
  // [2a30]
  0x041008a4, 0x0e001211, 0x303736ad, 0x1d001210,   // uk.be.ru_433 hu.is.un_630  ab.ba.uz_643 hu.la.un_620 
  0x300723ee, 0x3035080c, 0x3800600c, 0x100c09a0,   // ky.bg.uz_422 uk.tg.uz_543  vo.tk.un_530 pl.sv.lt_322 
  0x63000609, 0x04001714, 0x183c3407, 0x07000809,   // de.sco.un_440 sr.ru.un_660  ps.ug.ar_432 uk.bg.un_440 
  0x5638fc07, 0x20001f04, 0x2e001f07, 0x17162905,   // zzp.tk.mg_432 cy.sq.un_320  cy.fo.un_420 sl.hr.sr_333 
  // [2a40]
  0x37233855, 0x1f000c13, 0x0d0956ad, 0x381710a7,   // tk.ky.ba_442 sv.cy.un_650  mg.pl.cs_643 lt.sr.tk_532 
  0x100a175a, 0x211801ad, 0x2d0d56ac, 0x292d170c,   // sr.mk.be_553 iw.ar.fa_643  mg.cs.sk_632 sr.sk.sl_543 
  0x48383711, 0x2e00120b, 0x23002104, 0x34181208,   // ba.tk.tt_653 hu.fo.un_520  jw.ca.un_320 ur.ar.ps_443 
  0x251138ad, 0x230b19ee, 0x2c005602, 0x0f001702,   // tk.ro.mn_643 gl.es.ca_422  mg.fy.un_220 sr.lv.un_220 
  // [2a50]
  0x303707a0, 0x671d4f0c, 0x48152305, 0x29171602,   // bg.ba.uz_322 bi.la.ak_543  ky.tt.un_330 hr.sr.sl_222 
  0x3f0913a4, 0x1000440c, 0x03004f05, 0x1700290c,   // et.pl.af_433 kk.be.un_530  bi.nl.un_330 sl.sr.un_530 
  0x0a181210, 0x05005602, 0x09562c08, 0x33082e02,   // hu.ga.pt_642 mg.fr.un_220  fy.mg.pl_443 fo.no.nn_222 
  0x2d0d09af, 0x2d17290d, 0x070a1004, 0x20004d0b,   // pl.cs.sk_655 sl.sr.sk_554  be.mk.bg_332 aa.sq.un_520 
  // [2a60]
  0x21003d12, 0x2128345a, 0x0a3530a4, 0x13381b07,   // ku.fa.un_640 ps.sd.fa_553  uz.tg.mk_433 tr.tk.et_432 
  0x1d4d3e0d, 0x15303507, 0x10301708, 0x0d5c09a0,   // rm.aa.la_554 tg.uz.un_432  sr.uz.be_443 hi.sa.ne_322 
  0x25303502, 0x0d171602, 0x65000405, 0x2c201fa7,   // tg.uz.mn_222 hr.sr.cs_222  fi.gv.un_330 cy.sq.fy_532 
  0x345d35af, 0x20003204, 0x06006504, 0x5821475a,   // zu.ss.xh_655 bs.sq.un_320  gv.de.un_320 sn.jw.om_553 
  // [2a70]
  0x2a2046ee, 0x20004607, 0x04481505, 0x5d3435ec,   // qu.sq.mt_422 qu.sq.un_420  un.tt.ru_333 zu.xh.ss_644 
  0x05002d02, 0x5e28470c, 0x5404510c, 0x3d00210d,   // sk.fr.un_220 sn.sw.ts_543  kl.fi.ik_543 fa.ku.un_540 
  0x22000505, 0x205e390b, 0x650462a4, 0x4800460b,   // fr.oc.un_330 br.ts.sq_542  kha.fi.gv_433 qu.tt.un_520 
  0x12045ead, 0x64202307, 0x17792d0c, 0x04005114,   // ts.fi.hu_643 ca.sq.lg_432  sk.war.sr_543 kl.fi.un_660 
  // [2a80]
  0x3d341808, 0x20021f04, 0x65202305, 0x35003609,   // ar.ps.ku_443 cy.da.sq_332  ca.sq.gv_333 ab.tg.un_440 
  0x6500fe05, 0x24020fa0, 0x2f3435ad, 0x30001b07,   // tlh.gv.un_330 lv.da.eo_322  zu.xh.su_643 tr.uz.un_420 
  0x303b2108, 0x3000fe04, 0x2d00020d, 0x3c44230c,   // fa.ks.uz_443 tlh.uz.un_320  da.sk.un_540 ky.kk.ug_543 
  0x5c0d090e, 0x01264c07, 0x1c090dac, 0x28005607,   // hi.ne.sa_555 wo.ia.en_432  ne.hi.mr_632 mg.sw.un_420 
  // [2a90]
  0x56003004, 0xfc311b07, 0x2d0d2905, 0x18122802,   // uz.mg.un_320 tr.az.zzp_432  sl.cs.sk_333 sd.ur.ar_222 
  0x0436350b, 0x1b00650d, 0xfc1a48a4, 0x6b6501a6,   // tg.ab.ru_542 gv.tr.un_540  tt.tl.zzp_433 en.gv.ceb_521 
  0x1038170c, 0x1a31fc07, 0x53006502, 0x38003108,   // sr.tk.be_543 zzp.az.tl_432  gv.ht.un_220 az.tk.un_430 
  0x04002f02, 0x48003705, 0xfc003005, 0x12003404,   // su.fi.un_220 ba.tt.un_330  uz.zzp.un_330 ps.ur.un_320 
  // [2aa0]
  0x63230112, 0x13000913, 0x0f002916, 0x16002d08,   // en.ca.sco_654 hi.bh.un_650  sl.lv.un_720 sk.hr.un_430 
  0x35004702, 0x18003c0e, 0x10290f0c, 0x162d2907,   // sn.zu.un_220 ug.ar.un_550  lv.sl.lt_543 sl.sk.hr_432 
  0x37000102, 0x2d001019, 0x44212808, 0x33000b18,   // en.st.un_220 lt.sk.un_750  sd.fa.kk_443 bn.as.un_740 
  0x29171605, 0x02005105, 0x13004809, 0x18233ca4,   // hr.sr.sl_333 kl.da.un_330  tt.et.un_440 ug.ky.ar_433 
  // [2ab0]
  0x15006504, 0x6500570c, 0x035706a4, 0x403f120c,   // gv.un.un_320 na.gv.un_530  de.na.nl_433 hu.af.lb_543 
  0x2100120d, 0x0100181a, 0x16001012, 0x33020805,   // ur.fa.un_540 ar.iw.un_760  lt.hr.un_640 no.da.nn_333 
  0x36002d08, 0x65001d08, 0x34003d35, 0x183428a7,   // sk.gn.un_430 la.gv.un_430  ku.ps.un_A90 sd.ps.ar_532 
  0x044d640c, 0x111638a7, 0x0e002405, 0x3c00480d,   // lg.aa.fi_543 tk.hr.ro_532  eo.is.un_330 tt.ug.un_540 
  // [2ac0]
  0x65003b02, 0x2e1d0e55, 0x38001b08, 0x130d09a0,   // so.gv.un_220 is.la.fo_442  tr.tk.un_430 hi.ne.bh_322 
  0x230704a0, 0x1f00400d, 0x56006404, 0x30353807,   // ru.bg.ky_322 lb.cy.un_540  lg.mg.un_320 tk.tg.uz_432 
  0x30233cec, 0x04001213, 0x64785e0d, 0x03000907,   // ug.ky.uz_644 hu.fi.un_650  ts.ve.lg_554 pl.nl.un_420 
  0x4c303bee, 0x5c005d05, 0x022cfc05, 0x0400fe04,   // so.uz.wo_422 ss.sa.un_330  zzp.fy.da_333 tlh.fi.un_320 
  // [2ad0]
  0x36641008, 0x34006404, 0x55005e13, 0x380413a7,   // lt.lg.gn_443 lg.xh.un_320  ts.rw.un_650 et.fi.tk_532 
  0x2c033f07, 0x1200281a, 0x09002e0d, 0x40000605,   // af.nl.fy_432 sd.ur.un_760  fo.pl.un_540 de.lb.un_330 
  0x554264a0, 0x34213008, 0x44003c04, 0x050c20a0,   // lg.co.rw_322 uz.fa.ps_443  ug.kk.un_320 sq.sv.fr_322 
  0x21002202, 0x04171508, 0x6a495208, 0x473404af,   // oc.jw.un_220 un.sr.ru_443  ha.to.haw_443 fi.xh.sn_655 
  // [2ae0]
  0x08131204, 0x65005a13, 0x330e08ee, 0x0807040d,   // hu.et.no_332 sm.gv.un_650  no.is.nn_422 ru.bg.uk_554 
  0x04005504, 0x1f003607, 0x2100040b, 0x17000d0c,   // rw.fi.un_320 gn.cy.un_420  fi.jw.un_520 cs.sr.un_530 
  0xfe293407, 0x64003f08, 0x1f000b1b, 0xfc040da0,   // xh.sl.tlh_432 af.lg.un_430  es.cy.un_770 cs.fi.zzp_322 
  0x4d261fa9, 0x64005513, 0x36002504, 0x16321760,   // cy.ia.aa_544 rw.lg.un_650  eu.gn.un_320 sr.bs.hr_664 
  // [2af0]
  0x37482304, 0x35346908, 0x00004f24, 0x28533007,   // ky.tt.ba_332 mfe.xh.zu_443  bi.un.un_900 uz.ht.sw_432 
  0x303269a6, 0x12003609, 0x353430ec, 0x0413690e,   // mfe.bs.uz_521 gn.hu.un_440  uz.xh.zu_644 mfe.et.fi_555 
  0x073035a7, 0x351f5304, 0x3e621da4, 0x49000d04,   // tg.uz.bg_532 ht.cy.zu_332  la.kha.rm_433 cs.to.un_320 
  0x3b000604, 0x0a002504, 0x02002a08, 0x0c003b07,   // de.so.un_320 mn.mk.un_320  mt.da.un_430 so.sv.un_420 
  // [2b00]
  0x60000104, 0x0e122aa0, 0x30585009, 0x1f0c2d07,   // en.vo.un_320 mt.hu.is_322  fj.om.uz_444 sk.sv.cy_432 
  0x3b000c04, 0x69007613, 0x52024e0c, 0x3b004d07,   // sv.so.un_320 crs.mfe.un_650  ay.da.ha_543 aa.so.un_420 
  0x114e4207, 0x3d21300c, 0x4d601308, 0x320242a4,   // co.ay.ro_432 uz.fa.ku_543  et.vo.aa_443 co.da.bs_433 
  0x18462708, 0x1e021c11, 0x1e024e08, 0x02524e12,   // gd.qu.ga_443 id.da.ms_653  ay.da.ms_443 ay.ha.da_654 
  // [2b10]
  0x2f001e04, 0x364e4212, 0x5702035a, 0x32005008,   // ms.su.un_320 co.ay.gn_654  nl.da.na_553 fj.bs.un_430 
  0x69257609, 0x38000c02, 0x284c1f04, 0x25003c08,   // crs.eu.mfe_444 sv.tk.un_220  cy.wo.sw_332 ug.mn.un_430 
  0x0c1f3907, 0x1a4c4a07, 0x4c4252a4, 0x0b00330b,   // br.cy.sv_432 yo.wo.tl_432  ha.co.wo_433 as.bn.un_520 
  0x60113b08, 0x00004215, 0x65130604, 0x44182308,   // so.ro.vo_443 co.un.un_700  de.et.gv_332 ky.ar.kk_443 
  // [2b20]
  0x35303c0c, 0x13392dac, 0x2411520c, 0x2f581c07,   // ug.uz.tg_543 sk.br.et_632  ha.ro.eo_543 id.om.su_432 
  0x31004804, 0x2d0d30a4, 0x48464eac, 0x33080c0c,   // tt.az.un_320 uz.cs.sk_433  ay.qu.tt_632 sv.no.nn_543 
  0x160f2d08, 0x240f1004, 0x382348af, 0x4b094e09,   // sk.lv.hr_443 lt.lv.eo_332  tt.ky.tk_655 ay.pl.mi_444 
  0x4b024e0c, 0x2500300b, 0x17000702, 0x4b00781b,   // ay.da.mi_543 uz.mn.un_520  bg.sr.un_220 ve.mi.un_770 
  // [2b30]
  0x1d2f4ba6, 0x021d4ead, 0x0f4b4ead, 0x290f48a7,   // mi.su.la_521 ay.la.da_643  ay.mi.lv_643 tt.lv.sl_532 
  0x46004e0d, 0x130c4709, 0x06210909, 0x31005202,   // ay.qu.un_540 sn.sv.et_444  pl.jw.de_444 ha.az.un_220 
  0x61005713, 0x0a170709, 0x381b61ad, 0x27004b04,   // na.za.un_650 bg.sr.mk_444  za.tr.tk_643 mi.gd.un_320 
  0x123021a9, 0x13090d5a, 0x0a151108, 0x103e12a7,   // fa.uz.ur_544 ne.hi.bh_553  ro.mk.un_430 hu.rm.lt_532 
  // [2b40]
  0x1b304812, 0x1504100d, 0x3035360c, 0x32171b04,   // tt.uz.tr_654 be.ru.un_554  ab.tg.uz_543 tr.sr.bs_332 
  0x37350404, 0x071708a7, 0x2a4afc0c, 0x597847ad,   // ru.tg.ba_332 uk.sr.bg_532  zzp.yo.mt_543 sn.ve.rn_643 
  0x36006418, 0x342130af, 0x24006412, 0x1a002102,   // lg.gn.un_740 uz.fa.ps_655  lg.eo.un_640 jw.tl.un_220 
  0x5700fc14, 0x104448a0, 0x7800472c, 0x674d645a,   // zzp.na.un_660 tt.kk.be_322  sn.ve.un_990 lg.aa.ak_553 
  // [2b50]
  0x5e4afc07, 0x0a000602, 0x1f002702, 0x2f001505,   // zzp.yo.ts_432 de.pt.un_220  gd.cy.un_220 un.su.un_330 
  0x510413a0, 0x1d003304, 0x0f001a0c, 0x0d002d0d,   // et.fi.kl_322 nn.la.un_320  tl.lv.un_530 sk.cs.un_540 
  0x572512af, 0x394a0312, 0x17110a08, 0x2e0e2bad,   // hu.eu.na_655 nl.yo.br_654  mk.ro.sr_443 vi.is.fo_643 
  0x1c156004, 0x09002904, 0x1c001004, 0x4a002b08,   // vo.id.un_320 sl.pl.un_320  lt.id.un_320 vi.yo.un_430 
  // [2b60]
  0x27002008, 0x1000360c, 0x23443ca9, 0x17292d0e,   // sq.gd.un_430 ab.be.un_530  ug.kk.ky_544 sk.sl.sr_555 
  0x5a6a110d, 0x2a003935, 0x2601250c, 0x3f172913,   // ro.haw.sm_554 dz.bo.un_A90  eu.en.ia_543 sl.sr.af_665 
  0x2f003622, 0x17674ca4, 0x11007904, 0x39000808,   // gn.su.un_870 wo.ak.sr_433  war.ro.un_320 no.br.un_430 
  0x56375f02, 0x1142070c, 0x13796e04, 0x53330808,   // tn.st.mg_222 it.co.ro_543  hmn.war.et_332 no.nn.ht_443 
  // [2b70]
  0x6919200c, 0x491e1c02, 0x5a00630c, 0x2b000d08,   // sq.gl.mfe_543 id.ms.to_222  sco.sm.un_530 cs.vi.un_430 
  0x69355d5a, 0x65050102, 0x19000b09, 0x13001011,   // ss.zu.mfe_553 en.fr.gv_222  es.gl.un_440 lt.et.un_630 
  0x0d002b0d, 0x694c19a4, 0x044e4611, 0x4a006308,   // vi.cs.un_540 gl.wo.mfe_433  qu.ay.fi_653 sco.yo.un_430 
  0x2e002b0c, 0x134a6b04, 0x123d2112, 0x114a2007,   // vi.fo.un_530 ceb.yo.et_332  fa.ku.ur_654 sq.yo.ro_432 
  // [2b80]
  0x4c5e4704, 0x041511a0, 0x07255805, 0x083748af,   // sn.ts.wo_332 ro.ru.un_320  om.eu.it_333 tt.ba.uk_655 
  0x13000910, 0x07694707, 0x4a1d5a0c, 0x5a674a09,   // pl.et.un_620 sn.mfe.it_432  sm.la.yo_543 yo.ak.sm_444 
  0x2a003919, 0x121947a7, 0x432601a4, 0x594755af,   // dz.bo.un_750 sn.gl.hu_532  en.ia.ie_433 rw.sn.rn_655 
  0x43674704, 0x44003c07, 0x37001504, 0x01182108,   // sn.ak.ie_332 ug.kk.un_420  un.ba.un_320 fa.ar.iw_443 
  // [2b90]
  0x3c23180d, 0x3000170c, 0x00004f15, 0x48003105,   // ar.ky.ug_554 sr.uz.un_530  bi.un.un_700 az.tt.un_330 
  0x033f0204, 0x3800480e, 0x33020802, 0x170a0704,   // da.af.nl_332 tt.tk.un_550  no.da.nn_222 bg.mk.sr_332 
  0x2900650c, 0x20002e22, 0x422a0704, 0x60000609,   // gv.sl.un_530 fo.sq.un_870  it.mt.co_332 de.vo.un_440 
  0x04081509, 0x20000104, 0x3000fe0b, 0x28001209,   // un.uk.ru_444 en.sq.un_320  tlh.uz.un_520 ur.sd.un_440 
  // [2ba0]
  0x56002b07, 0x440848a0, 0x1c0913ee, 0x38001b09,   // vi.mg.un_420 tt.uk.kk_322  bh.hi.mr_422 tr.tk.un_440 
  0x0f00100d, 0x4400231b, 0x283f40a4, 0x0c30540c,   // lt.lv.un_540 ky.kk.un_770  lb.af.sw_433 ik.uz.sv_543 
  0x48371508, 0x4000060b, 0x08070aad, 0x3f000104,   // un.ba.tt_443 de.lb.un_520  mk.bg.uk_643 en.af.un_320 
  0x33003f04, 0x15003f04, 0x4b006a1a, 0x0b003311,   // af.nn.un_320 af.un.un_320  haw.mi.un_760 as.bn.un_630 
  // [2bb0]
  0x2c030204, 0x21002704, 0x7335030c, 0x0c002304,   // da.nl.fy_332 gd.jw.un_320  nl.zu.ny_543 ca.sv.un_320 
  0x0e00120c, 0x2d2f29ee, 0x07001004, 0x070408a0,   // hu.is.un_530 sl.su.sk_422  be.bg.un_320 uk.ru.bg_322 
  0x3b094d0c, 0x3f03060c, 0x10170a04, 0x332e27a0,   // aa.pl.so_543 de.nl.af_543  mk.sr.be_332 gd.fo.nn_322 
  0x0437100c, 0x04001704, 0x10000709, 0x09004008,   // be.ba.ru_543 sr.ru.un_320  bg.be.un_440 lb.pl.un_430 
  // [2bc0]
  0x3d004405, 0x3f5d0204, 0x4b2f640d, 0x15400612,   // kk.ku.un_330 da.ss.af_332  lg.su.mi_554 de.lb.un_654 
  0x16092907, 0x2300790c, 0x18212307, 0x736301a0,   // sl.pl.hr_432 war.ca.un_530  ky.fa.ar_432 en.sco.ny_322 
  0x6447730c, 0x3800090b, 0x292f1c0c, 0x30004407,   // ny.sn.lg_543 pl.tk.un_520  id.su.sl_543 kk.uz.un_420 
  0x31003002, 0x0900290d, 0x04103807, 0x34184405,   // uz.az.un_220 sl.pl.un_540  tk.be.ru_432 kk.ar.ps_333 
  // [2bd0]
  0x350408a7, 0x10005c07, 0x300735a4, 0x23003f07,   // uk.ru.tg_532 sa.lt.un_420  tg.bg.uz_433 af.ca.un_420 
  0x0a30350c, 0x0c001307, 0x1f001d04, 0x3b001307,   // tg.uz.mk_543 et.sv.un_420  la.cy.un_320 et.so.un_420 
  0x2100180e, 0x3b003d0e, 0x37002507, 0x13002f13,   // ar.fa.un_550 ku.ks.un_550  mn.ba.un_420 su.et.un_650 
  0x23343dad, 0x0c00fe0c, 0x0e002e20, 0x1a00130c,   // ku.ps.ky_643 tlh.sv.un_530  fo.is.un_850 et.tl.un_530 
  // [2be0]
  0x3b000c08, 0x18002e04, 0x11002a13, 0x1d00630d,   // sv.so.un_430 fo.ga.un_320  mt.ro.un_650 sco.la.un_540 
  0x1538085a, 0x2500230d, 0x341d4d05, 0x2100300d,   // uk.tk.un_553 ky.mn.un_540  aa.la.xh_333 uz.fa.un_540 
  0x33002a02, 0x070804a0, 0x0c00130d, 0x3b353404,   // mt.nn.un_220 ru.uk.bg_322  et.sv.un_540 xh.zu.so_332 
  0x42002a0c, 0x323b6213, 0x56351dee, 0x12003408,   // mt.co.un_530 kha.so.bs_665  la.zu.mg_422 ps.ur.un_430 
  // [2bf0]
  0x10fe0cee, 0x091c5ca7, 0x0c001305, 0x6500040c,   // sv.tlh.lt_422 sa.mr.hi_532  et.sv.un_330 fi.gv.un_530 
  0x3f000402, 0x0a350708, 0x040a1705, 0x20335d04,   // fi.af.un_220 bg.tg.mk_443  sr.mk.ru_333 ss.nn.sq_332 
  0x0c001508, 0x212438a7, 0x3f150309, 0x25004d07,   // un.sv.un_430 tk.eo.jw_532  nl.af.un_440 aa.eu.un_420 
  0x062e080c, 0x04062c07, 0x0838330c, 0x231234a4,   // no.fo.de_543 fy.de.fi_432  nn.tk.no_543 ps.ur.ky_433 
  
  // [2c00]
  0x374823a7, 0x2c3f0355, 0x101711ad, 0x20003308,   // ky.tt.ba_532 nl.af.fy_442  ro.sr.be_643 nn.sq.un_430 
  0x3d00300c, 0x48001113, 0x5c0d09a7, 0x13091c5a,   // uz.ku.un_530 ro.tt.un_650  hi.ne.sa_532 mr.hi.bh_553 
  0x040a0707, 0x02385d04, 0x2e02080c, 0x07150407,   // bg.mk.ru_432 ss.tk.da_332  no.da.fo_543 ru.bg.un_420 
  0x3338130c, 0x20003819, 0x3c303814, 0x0c330a05,   // et.tk.nn_543 tk.sq.un_750  tk.uz.ug_666 pt.nn.sv_333 
  // [2c10]
  0x28001214, 0x3c00300d, 0x23003708, 0x2e001b02,   // ur.sd.un_660 uz.ug.un_540  ba.ky.un_430 tr.fo.un_220 
  0x46fc3b0c, 0x043537ee, 0x3500fc12, 0x4d00111a,   // so.zzp.qu_543 ba.tg.ru_422  zzp.zu.un_640 ro.aa.un_760 
  0x53006304, 0x1f67fcec, 0x33001f02, 0x1f2e38ee,   // sco.ht.un_320 zzp.ak.cy_644  cy.nn.un_220 tk.fo.cy_422 
  0x34123507, 0x3500301b, 0x0c001f04, 0x21343da4,   // zu.hu.xh_432 uz.tg.un_770  cy.sv.un_320 ku.ps.fa_433 
  // [2c20]
  0x38000908, 0x5f007812, 0x373c48af, 0x301135ad,   // pl.tk.un_430 ve.tn.un_640  tt.ug.ba_655 tg.ro.uz_643 
  0x03006e08, 0x08003004, 0x12002113, 0x483010ad,   // hmn.nl.un_430 uz.uk.un_320  fa.ur.un_650 be.uz.tt_643 
  0x17001505, 0x08440402, 0x0817350e, 0x12002502,   // un.sr.un_330 ru.kk.uk_222  tg.sr.uk_555 eu.hu.un_220 
  0x04070802, 0x7965fe07, 0x5c000d07, 0x2d0d43ec,   // uk.bg.ru_222 tlh.gv.war_432  ne.sa.un_420 ie.cs.sk_644 
  // [2c30]
  0x13000d04, 0x07003504, 0x043008a0, 0x13091c0e,   // ne.bh.un_320 tg.bg.un_320  uk.uz.ru_322 mr.hi.bh_555 
  0x081711a4, 0x09001c0e, 0x64005504, 0x12342807,   // ro.sr.uk_433 mr.hi.un_550  rw.lg.un_320 sd.ps.ur_432 
  0x3b466704, 0x3d003c07, 0x6539020e, 0x381b0fec,   // ak.qu.so_332 ug.ku.un_420  da.br.gv_555 lv.tr.tk_644 
  0x1b38480c, 0x1a004f0c, 0x2f1e1c0c, 0x211c79ee,   // tt.tk.tr_543 bi.tl.un_530  id.ms.su_543 war.id.jw_422 
  // [2c40]
  0x0f481b0c, 0x060328a4, 0x464e010c, 0x13003802,   // tr.tt.lv_543 sw.nl.de_433  en.ay.qu_543 tk.et.un_220 
  0x38001b1a, 0x31000202, 0x38321608, 0x40580607,   // tr.tk.un_760 da.az.un_220  hr.bs.tk_443 de.om.lb_432 
  0x2f1e1c0b, 0x130f1207, 0x28001304, 0x21201807,   // id.ms.su_542 hu.lv.et_432  et.sw.un_320 ga.sq.jw_432 
  0x3f001b07, 0x403f0604, 0x16171dee, 0x0c000412,   // tr.af.un_420 de.af.lb_332  la.sr.hr_422 fi.sv.un_640 
  // [2c50]
  0x05421ba0, 0x151535a0, 0x30381ba4, 0x6b001a12,   // tr.co.fr_322 tg.un.un_320  tr.tk.uz_433 tl.ceb.un_640 
  0x210f1b11, 0x1a00040e, 0x130501a0, 0x23111855,   // tr.lv.jw_653 fi.tl.un_550  en.fr.et_322 ga.ro.ca_442 
  0x1b00fc12, 0xfc002004, 0x06005f12, 0x093848ec,   // zzp.tr.un_640 sq.zzp.un_320  tn.de.un_640 tt.tk.pl_644 
  0x062a47a4, 0x1d28620c, 0x033f02a4, 0x1c1e3104,   // sn.mt.de_433 kha.sw.la_543  da.af.nl_433 az.ms.id_332 
  // [2c60]
  0x353437a4, 0x3700fa12, 0x211e1c5a, 0x17381b0c,   // st.xh.zu_433 nr.st.un_640  id.ms.jw_553 tr.tk.sr_543 
  0x285c580c, 0x08001b0e, 0x22650402, 0x1e1c38a0,   // om.sa.sw_543 tr.no.un_550  fi.gv.oc_222 tk.id.ms_322 
  0x15080405, 0x636008af, 0x063f03a0, 0x3534470c,   // ru.uk.un_333 no.vo.sco_655  nl.af.de_322 sn.xh.zu_543 
  0x34211211, 0x734737ad, 0x3738230d, 0x1b00311a,   // ur.fa.ps_653 st.sn.ny_643  ky.tk.ba_554 az.tr.un_760 
  // [2c70]
  0x481b3160, 0x1504070c, 0x050a23a9, 0x583052a4,   // az.tr.tt_664 bg.ru.un_543  ca.pt.fr_544 ha.uz.om_433 
  0x30003612, 0x1700040d, 0x34002004, 0x766910ad,   // ab.uz.un_640 ru.sr.un_540  sq.xh.un_320 lt.mfe.crs_643 
  0x48311ba7, 0x52fa1b55, 0x3d232105, 0x3b283008,   // tr.az.tt_532 tr.nr.ha_442  fa.ky.ku_333 uz.sw.so_443 
  0x55597908, 0x2d005305, 0x313010a4, 0x5e000104,   // war.rn.rw_443 ht.sk.un_330  lt.uz.az_433 en.ts.un_320 
  // [2c80]
  0x3b003d22, 0x44341811, 0x131c5c08, 0x55000905,   // ku.ks.un_870 ar.ps.kk_653  sa.mr.bh_443 pl.rw.un_330 
  0x3b130912, 0x43281ca9, 0x51330809, 0x48311ba6,   // hi.bh.ks_654 id.sw.ie_544  no.nn.kl_444 tr.az.tt_521 
  0x186527a0, 0x461b5807, 0x481a4607, 0x51002702,   // gd.gv.ga_322 om.tr.qu_432  qu.tl.tt_432 gd.kl.un_220 
  0x1a7830ec, 0x38004e19, 0x464b2ea4, 0x3152280d,   // uz.ve.tl_644 ay.tk.un_750  fo.mi.qu_433 sw.ha.az_554 
  // [2c90]
  0x10040802, 0x50283812, 0x36005308, 0x1a2e280c,   // uk.ru.be_222 tk.sw.fj_654  ht.gn.un_430 sw.fo.tl_543 
  0x4900370b, 0x3300080c, 0x1bfe1aa0, 0x0d091c11,   // st.to.un_520 no.nn.un_530  tl.tlh.tr_322 mr.hi.ne_653 
  0x0e004904, 0x03103f07, 0x2e005919, 0x64001005,   // to.is.un_320 af.lt.nl_432  rn.fo.un_750 lt.lg.un_330 
  0x38486b08, 0x04081708, 0x48004d21, 0x2e33080b,   // ceb.tt.tk_443 sr.uk.ru_443  aa.tt.un_860 no.nn.fo_542 
  // [2ca0]
  0x26004d20, 0x5f004005, 0x4c001f12, 0x2a002e07,   // aa.ia.un_850 lb.tn.un_330  cy.wo.un_640 fo.mt.un_420 
  0x0c636207, 0x1c1309a0, 0x5c001f0c, 0x30003b08,   // kha.sco.sv_432 hi.bh.mr_322  cy.sa.un_530 so.uz.un_430 
  0x31001b04, 0x353001a0, 0x15000604, 0x261d43a9,   // tr.az.un_320 en.uz.zu_322  de.un.un_320 ie.la.ia_544 
  0x1b00fc21, 0x301b31ec, 0x3130480d, 0x6b56795a,   // zzp.tr.un_860 az.tr.uz_644  tt.uz.az_554 war.mg.ceb_553 
  // [2cb0]
  0x281221ad, 0x4e311b12, 0x2e330860, 0x124b43a7,   // fa.ur.sd_643 tr.az.ay_654  no.nn.fo_664 ie.mi.hu_532 
  0x3b004614, 0x20454c07, 0x0d005c20, 0xfe00650d,   // qu.so.un_660 wo.ln.sq_432  sa.ne.un_850 gv.tlh.un_540 
  0x0a1735ee, 0x25150407, 0x2f206007, 0x5c0d1ca7,   // tg.sr.mk_422 ru.mn.un_420  vo.sq.su_432 mr.ne.sa_532 
  0x5c000d1b, 0x30182155, 0x480a220d, 0x342821ec,   // ne.sa.un_770 fa.ar.uz_442  oc.pt.tt_554 fa.sd.ps_644 
  // [2cc0]
  0x122118a7, 0x18213d02, 0xfc6b46ad, 0x4c002f08,   // ar.fa.ur_532 ku.fa.ar_222  qu.ceb.zzp_643 su.wo.un_430 
  0x40005307, 0x33000b0c, 0x183d21a0, 0x1b314804,   // ht.lb.un_420 bn.as.un_530  fa.ku.ar_322 tt.az.tr_332 
  0x4800370e, 0x0a00080c, 0x095c130c, 0x04080a02,   // ba.tt.un_550 uk.mk.un_530  bh.sa.hi_543 mk.uk.ru_222 
  0x0d131cad, 0x17300a07, 0x1c090d12, 0x2d532209,   // mr.bh.ne_643 mk.uz.sr_432  ne.hi.mr_654 oc.ht.sk_444 
  // [2cd0]
  0x23443808, 0x091c13ec, 0x21004008, 0x230a44ee,   // tk.kk.ky_443 bh.mr.hi_644  lb.jw.un_430 kk.mk.ky_422 
  0x37483808, 0x23000a0e, 0x34283d14, 0x0b0a1905,   // tk.tt.ba_443 pt.ca.un_550  ku.sd.ps_666 gl.pt.es_333 
  0x39002302, 0x4700fc04, 0x5d00120c, 0x37003008,   // ca.br.un_220 zzp.sn.un_320  hu.ss.un_530 uz.ba.un_430 
  0x21344407, 0x35003002, 0x3c2130a9, 0x4700fc14,   // kk.ps.fa_432 uz.tg.un_220  uz.fa.ug_544 zzp.sn.un_660 
  // [2ce0]
  0x73003b05, 0x1c13090e, 0x171632af, 0x423e070c,   // so.ny.un_330 hi.bh.mr_555  bs.hr.sr_655 it.rm.co_543 
  0x353b28ad, 0x2e003b04, 0x0d001c0d, 0xfc473507,   // sw.so.zu_643 so.fo.un_320  mr.ne.un_540 zu.sn.zzp_432 
  0x5c002e04, 0x28007304, 0x0c380602, 0x4d001b09,   // fo.sa.un_320 ny.sw.un_320  de.tk.sv_222 tr.aa.un_440 
  0x44043504, 0x444815ee, 0x34122805, 0x213d30a7,   // tg.ru.kk_332 un.tt.kk_422  sd.ur.ps_333 uz.ku.fa_532 
  // [2cf0]
  0x284a4707, 0x442304a0, 0x1a006b1b, 0x234415a0,   // sn.yo.sw_432 ru.ky.kk_322  ceb.tl.un_770 un.kk.ky_322 
  0x0b003607, 0x0d1309a7, 0x564b5aad, 0x1e003b04,   // gn.es.un_420 hi.bh.ne_532  sm.mi.mg_643 so.ms.un_320 
  0x060163a0, 0x53002f0d, 0x1d00130d, 0x2a433ea4,   // sco.en.de_322 su.ht.un_540  et.la.un_540 rm.ie.mt_433 
  0x135104ec, 0x1c0d09a7, 0x08070405, 0x7600400d,   // fi.kl.et_644 hi.ne.mr_532  ru.bg.uk_333 lb.crs.un_540 
  // [2d00]
  0x25003b02, 0x1d000f05, 0x3f030207, 0x0e331204,   // so.eu.un_220 lv.la.un_330  da.nl.af_432 hu.nn.is_332 
  0x02510808, 0x113e43af, 0x4800fc12, 0x0c3f39a0,   // no.kl.da_443 ie.rm.ro_655  zzp.tt.un_640 br.af.sv_322 
  0x0a0725a0, 0x05364ca4, 0x18000119, 0x36042e07,   // mn.bg.mk_322 wo.gn.fr_433  iw.ar.un_750 fo.fi.gn_432 
  0x3100fc05, 0x132f3ea4, 0x07002a14, 0x212f05a7,   // zzp.az.un_330 rm.su.et_433  mt.it.un_660 fr.su.jw_532 
  // [2d10]
  0x3000122a, 0x3b004e1a, 0x2b156402, 0x120c0fa4,   // ur.uz.un_970 ay.so.un_760  lg.vi.un_220 lv.sv.hu_433 
  0x3736100c, 0x03002f02, 0x0d000502, 0x113e4304,   // be.ab.ba_543 su.nl.un_220  fr.cs.un_220 ie.rm.ro_332 
  0x0c0204a0, 0x1d00fc0d, 0x1b003202, 0x0c001219,   // fi.da.sv_322 zzp.la.un_540  bs.tr.un_220 hu.sv.un_750 
  0x48311b07, 0x033f0604, 0x13003e04, 0x0700150d,   // tr.az.tt_432 de.af.nl_332  rm.et.un_320 un.bg.un_540 
  // [2d20]
  0x3d00300b, 0x01006b02, 0x0415080e, 0x383715a4,   // uz.ku.un_520 ceb.en.un_220  uk.ru.un_550 un.ba.tk_433 
  0x42052308, 0x15004207, 0x3900fe04, 0x104437af,   // ca.fr.co_443 co.un.un_420  tlh.br.un_320 ba.kk.be_655 
  0x074301a0, 0x0400080c, 0x2d000d2c, 0x321617af,   // en.ie.it_322 uk.ru.un_530  cs.sk.un_990 sr.hr.bs_655 
  0x1c130d08, 0x40000307, 0x353c3012, 0x3500340c,   // ne.bh.mr_443 nl.lb.un_420  uz.ug.tg_654 xh.zu.un_530 
  // [2d30]
  0x04000813, 0x4400360c, 0x75375f13, 0x4200650c,   // uk.ru.un_650 ab.kk.un_530  tn.st.nso_665 gv.co.un_530 
  0x3f220302, 0x10041512, 0x093f0304, 0x19002d07,   // nl.oc.af_222 un.ru.be_654  nl.af.pl_332 sk.gl.un_420 
  0x133f29a0, 0x04000818, 0x03006404, 0x5c001309,   // sl.af.et_322 uk.ru.un_740  lg.nl.un_320 bh.sa.un_440 
  0x170a0702, 0x10041708, 0x2a000304, 0x190b0aa4,   // bg.mk.sr_222 sr.ru.be_443  nl.mt.un_320 pt.es.gl_433 
  // [2d40]
  0x44003c0e, 0x390306a0, 0x1f003902, 0x441511ac,   // ug.kk.un_550 de.nl.br_322  br.cy.un_220 ro.kk.un_620 
  0x2e000904, 0x40001808, 0x2e002412, 0x08000f05,   // pl.fo.un_320 ga.lb.un_430  eo.fo.un_640 lv.no.un_330 
  0x24570104, 0x794c1ea0, 0xfe4f0807, 0x18001205,   // en.na.eo_332 ms.wo.war_322  no.bi.tlh_432 ur.ar.un_330 
  0x05007634, 0x3f1501a4, 0x18192ca0, 0x23000708,   // crs.fr.un_A80 en.af.un_430  fy.gl.ga_322 it.ca.un_430 
  // [2d50]
  0x583b0414, 0x071d26af, 0x6300fc08, 0x2700182b,   // fi.so.om_666 ia.la.it_655  zzp.sco.un_430 ga.gd.un_980 
  0x19006504, 0x37003813, 0x12003409, 0x080a0702,   // gv.gl.un_320 tk.ba.un_650  ps.ur.un_440 bg.mk.uk_222 
  0x626301ad, 0x21000504, 0x39577904, 0x537669a9,   // en.sco.kha_643 fr.jw.un_320  war.na.br_332 mfe.crs.ht_544 
  0x353815ad, 0x00005337, 0x2b4c3007, 0x76114f12,   // un.tk.tg_643 ht.un.un_B00  uz.wo.vi_432 bi.ro.crs_654 
  // [2d60]
  0x4c4f01a0, 0x76000104, 0x0c003308, 0x095c1c02,   // en.bi.wo_322 en.crs.un_320  nn.sv.un_430 mr.sa.hi_222 
  0xfe00301a, 0x0000062d, 0x40600612, 0x4a01635a,   // uz.tlh.un_760 de.un.un_A00  de.vo.lb_654 sco.en.yo_553 
  0x223e050c, 0x2200070d, 0x2b003e0b, 0x095c1c0c,   // fr.rm.oc_543 it.oc.un_540  rm.vi.un_520 mr.sa.hi_543 
  0x00001c2d, 0x40001a02, 0x22002008, 0x5500020c,   // mr.un.un_A00 tl.lb.un_220  sq.oc.un_430 da.rw.un_530 
  // [2d70]
  0xfa5502af, 0x4cfe0204, 0x2f051208, 0x02007305,   // da.rw.nr_655 da.tlh.wo_332  hu.fr.su_443 ny.da.un_330 
  0x18003004, 0x08023309, 0x4c4d3555, 0x1200210b,   // uz.ar.un_320 nn.da.no_444  zu.aa.wo_442 fa.ur.un_520 
  0x3b005908, 0x2f002116, 0x6b1b1a11, 0x36190b09,   // rn.so.un_430 jw.su.un_720  tl.tr.ceb_653 es.gl.gn_444 
  0x1b003b04, 0x40000507, 0x6b023007, 0x2500350c,   // so.tr.un_320 fr.lb.un_420  uz.da.ceb_432 tg.mn.un_530 
  // [2d80]
  0x5800300d, 0x5c000d0b, 0x303b0204, 0x356030af,   // uz.om.un_540 ne.sa.un_520  da.so.uz_332 uz.vo.zu_655 
  0x47300212, 0x12365d04, 0x190b36a9, 0x0f241bad,   // da.uz.sn_654 ss.gn.hu_332  gn.es.gl_544 tr.eo.lv_643 
  0xfe005c0e, 0x2400250d, 0x59552105, 0x08003307,   // sa.tlh.un_550 eu.eo.un_540  jw.rw.rn_333 nn.no.un_420 
  0x584c5d02, 0x18003d0c, 0x27180e04, 0x0d001308,   // ss.wo.om_222 ku.ar.un_530  is.ga.gd_332 bh.ne.un_430 
  // [2d90]
  0x5e5d35ad, 0x08000302, 0x0a4605a0, 0x0d5c09a4,   // zu.ss.ts_643 nl.no.un_220  fr.qu.pt_322 hi.sa.ne_433 
  0x336b7905, 0x2d005d04, 0x01fe6508, 0x5973550d,   // war.ceb.nn_333 ss.sk.un_320  gv.tlh.en_443 rw.ny.rn_554 
  0x460753ee, 0x27183404, 0x38003104, 0x3006fe5a,   // ht.it.qu_422 xh.ga.gd_332  az.tk.un_320 tlh.de.uz_553 
  0x19002c07, 0x55734711, 0x1a004d12, 0x080a30ec,   // fy.gl.un_420 sn.ny.rw_653  aa.tl.un_640 uz.mk.uk_644 
  // [2da0]
  0x4d004c13, 0x59005519, 0x5900110d, 0x4c004d21,   // wo.aa.un_650 rw.rn.un_750  ro.rn.un_540 aa.wo.un_860 
  0x24002007, 0x4d004c14, 0x05004307, 0x2c3f0312,   // sq.eo.un_420 wo.aa.un_660  ie.fr.un_420 nl.af.fy_654 
  0x0400390c, 0x3f181f07, 0x4c005823, 0x59005509,   // br.fi.un_530 cy.ga.af_432  om.wo.un_880 rw.rn.un_440 
  0x38002404, 0x0723300b, 0x300201a0, 0x483738a0,   // eo.tk.un_320 uz.ky.bg_542  en.da.uz_322 tk.ba.tt_322 
  // [2db0]
  0x18233c04, 0x3b004c08, 0x0a04150c, 0x080411a7,   // ug.ky.ar_332 wo.so.un_430  un.ru.mk_543 ro.ru.uk_532 
  0x4c004d14, 0x3b4d4c11, 0x5c000d21, 0x07002302,   // aa.wo.un_660 wo.aa.so_653  ne.sa.un_860 ky.bg.un_220 
  0x130d0912, 0x0804150e, 0x08003308, 0x044830a0,   // hi.ne.bh_654 un.ru.uk_555  nn.no.un_430 uz.tt.ru_322 
  0x373023a0, 0x17100a13, 0x48003011, 0x07000a0c,   // ky.uz.ba_322 mk.be.sr_665  uz.tt.un_630 mk.bg.un_530 
  // [2dc0]
  0x15170405, 0x07150414, 0x37fa5f14, 0x3c002322,   // ru.sr.un_333 ru.bg.un_660  tn.nr.st_666 ky.ug.un_870 
  0x30353c14, 0x1c000d14, 0x07100409, 0x47766905,   // ug.tg.uz_666 ne.mr.un_660  ru.be.bg_444 mfe.crs.sn_333 
  0x0a3530ec, 0xfc003808, 0x5e5506a0, 0x082e33a9,   // uz.tg.mk_644 tk.zzp.un_430  de.rw.ts_322 nn.fo.no_544 
  0x1f730304, 0x303421ec, 0x44003012, 0x471a64a0,   // nl.ny.cy_332 fa.ps.uz_644  uz.kk.un_640 lg.tl.sn_322 
  // [2dd0]
  0x34001808, 0x55004508, 0x00003d37, 0x15154809,   // ar.ps.un_430 ln.rw.un_430  ku.un.un_B00 tt.un.un_440 
  0x2d0d12a7, 0x35060908, 0x2f000b07, 0x120d360b,   // hu.cs.sk_532 pl.de.zu_443  es.su.un_420 gn.cs.hu_542 
  0x23011b0b, 0x3f035e04, 0xfc47090c, 0x283021a7,   // tr.en.ca_542 ts.nl.af_332  pl.sn.zzp_543 fa.uz.sd_532 
  0x183c2355, 0x3b5759a4, 0x5c001319, 0x47006907,   // ky.ug.ar_442 rn.na.so_433  bh.sa.un_750 mfe.sn.un_420 
  // [2de0]
  0x2330380d, 0x5c002702, 0x5c51130c, 0x1c001312,   // tk.uz.ky_554 gd.sa.un_220  et.kl.sa_543 bh.mr.un_640 
  0x21041355, 0x44004805, 0x405c0604, 0x06034011,   // et.fi.jw_442 tt.kk.un_330  de.sa.lb_332 lb.nl.de_653 
  0x37483c12, 0x21000404, 0x123160a0, 0x362315a0,   // ug.tt.ba_654 fi.jw.un_320  vo.az.hu_322 un.ky.ab_322 
  0x13002105, 0x44000a04, 0x5d00350e, 0x1200360d,   // jw.et.un_330 mk.kk.un_320  zu.ss.un_550 gn.hu.un_540 
  // [2df0]
  0x18003b0c, 0x03005b0d, 0x4838300c, 0x09006404,   // ks.ar.un_530 sg.nl.un_540  uz.tk.tt_543 lg.pl.un_320 
  0x5864030d, 0x3e112307, 0x0f000307, 0x3800251a,   // nl.lg.om_554 ca.ro.rm_432  nl.lv.un_420 mn.tk.un_760 
  0x2155590c, 0x49004b09, 0x4844230d, 0x2f000505,   // rn.rw.jw_543 mi.to.un_440  ky.kk.tt_554 fr.su.un_330 
  0x3c442312, 0x1d105ca0, 0x644c2807, 0x58006409,   // ky.kk.ug_654 sa.lt.la_322  sw.wo.lg_432 lg.om.un_440 
  // [2e00]
  0x31381b08, 0x04081007, 0x190b18ec, 0x0f001012,   // tr.tk.az_443 be.uk.ru_432  ga.es.gl_644 lt.lv.un_640 
  0x1c090d02, 0x0d00090c, 0x584d64ad, 0x21341208,   // ne.hi.mr_222 hi.ne.un_530  lg.aa.om_643 ur.ps.fa_443 
  0x13044609, 0x1b130411, 0x233510ec, 0x28001204,   // qu.fi.et_444 fi.et.tr_653  be.tg.ky_644 ur.sd.un_320 
  0x053f2207, 0x04461311, 0x1e1c2aee, 0x4613040b,   // oc.af.fr_432 et.qu.fi_653  mt.id.ms_422 fi.et.qu_542 
  // [2e10]
  0x12000304, 0x1b003809, 0x5a004a02, 0x0c006502,   // nl.hu.un_320 tk.tr.un_440  yo.sm.un_220 gv.sv.un_220 
  0x37002512, 0x2f052105, 0x36500ba0, 0x0a44230b,   // mn.ba.un_640 jw.fr.su_333  es.fj.gn_322 ky.kk.mk_542 
  0x65001007, 0x2c3f01a0, 0x2e3f34a0, 0x0600130c,   // lt.gv.un_420 en.af.fy_322  xh.af.fo_322 et.de.un_530 
  0x2e132aa0, 0x35002512, 0x5c0d0904, 0x20001e18,   // mt.et.fo_322 mn.tg.un_640  hi.ne.sa_332 am.ti.un_740 
  // [2e20]
  0x0f343f0c, 0x13044eec, 0x03002402, 0x0400600b,   // af.xh.lv_543 ay.fi.et_644  eo.nl.un_220 vo.fi.un_520 
  0x2c003f18, 0x060c2cad, 0x30001004, 0x23000b04,   // af.fy.un_740 fy.sv.de_643  be.uz.un_320 es.ca.un_320 
  0x3c001809, 0x0f2d0d05, 0x13000d02, 0x08023fa0,   // ar.ug.un_440 cs.sk.lv_333  ne.bh.un_220 af.da.no_322 
  0x0a071105, 0x38003c14, 0x212812af, 0x181228af,   // ro.bg.mk_333 ug.tk.un_660  ur.sd.fa_655 sd.ur.ar_655 
  // [2e30]
  0x530f10a7, 0x292d0d04, 0x3f060c14, 0x0c7613a4,   // lt.lv.ht_532 cs.sk.sl_332  sv.de.af_666 et.crs.sv_433 
  0x48153004, 0x1c0d5ca7, 0x08003007, 0x5c130d04,   // uz.tt.un_320 sa.ne.mr_532  uz.uk.un_420 ne.bh.sa_332 
  0x0a361508, 0x040825a0, 0x0e060ca4, 0x0d5c1cad,   // un.ab.mk_443 mn.uk.ru_322  sv.de.is_433 mr.sa.ne_643 
  0x5c091cac, 0x0b004a04, 0x3d00210e, 0x15070413,   // mr.hi.sa_632 yo.es.un_320  fa.ku.un_550 ru.bg.un_665 
  // [2e40]
  0x062c15a0, 0x13003b05, 0x3c3d210d, 0x68671da4,   // un.fy.de_322 so.et.un_330  fa.ku.ug_554 la.ak.ig_433 
  0x3d002809, 0x16004204, 0x0411440c, 0x3c004822,   // sd.ku.un_440 co.hr.un_320  kk.ro.ru_543 tt.ug.un_870 
  0x25004c04, 0x330801a0, 0x643404ee, 0x65002805,   // wo.eu.un_320 en.no.nn_322  fi.xh.lg_422 sw.gv.un_330 
  0x033b0404, 0x64044904, 0x3c00071b, 0x3f351b05,   // fi.so.nl_332 to.fi.lg_332  bg.ug.un_770 tr.zu.af_333 
  // [2e50]
  0x644c58a9, 0x233c4412, 0x5800250d, 0x43024505,   // om.wo.lg_544 kk.ug.ky_654  eu.om.un_540 ln.da.ie_333 
  0x42001e05, 0x531827ad, 0x3c004419, 0x48363cad,   // ms.co.un_330 gd.ga.ht_643  kk.ug.un_750 ug.ab.tt_643 
  0x070a1713, 0x23443805, 0x210245ec, 0x1c033ba0,   // sr.mk.bg_665 tk.kk.ky_333  ln.da.jw_644 so.nl.id_322 
  0x69003322, 0x3800231a, 0x27003f07, 0x20001804,   // nn.mfe.un_870 ky.tk.un_760  af.gd.un_420 ga.sq.un_320 
  // [2e60]
  0x1d005c02, 0x451b78ad, 0x342864ad, 0x35000a0d,   // sa.la.un_220 ve.tr.ln_643  lg.sw.xh_643 pt.zu.un_540 
  0x4c00640d, 0x25004c07, 0x3f136404, 0x211834a4,   // lg.wo.un_540 wo.eu.un_420  lg.et.af_332 ps.ar.fa_433 
  0x62643fa4, 0x42002304, 0x2d00291a, 0x3421120d,   // af.lg.kha_433 ca.co.un_320  sl.sk.un_760 ur.fa.ps_554 
  0x2c3f0308, 0x04006407, 0x28005507, 0x21183404,   // nl.af.fy_443 lg.fi.un_420  rw.sw.un_420 ps.ar.fa_332 
  // [2e70]
  0x1000040d, 0x4a006412, 0x24004c07, 0x043708a0,   // ru.be.un_540 lg.yo.un_640  wo.eo.un_420 uk.ba.ru_322 
  0x23114304, 0x46005111, 0x284951a0, 0x4a005119,   // ie.ro.ca_332 kl.qu.un_630  kl.to.sw_322 kl.yo.un_750 
  0x2500010d, 0x20130807, 0xfe2c2507, 0x47005805,   // en.eu.un_540 no.et.sq_432  eu.fy.tlh_432 om.sn.un_330 
  0x054079a4, 0x311b1105, 0x58003f0e, 0x3f00290d,   // war.lb.fr_433 ro.tr.az_333  af.om.un_550 sl.af.un_540 
  // [2e80]
  0x10002507, 0x33005d04, 0x17080408, 0x5f2501a0,   // mn.be.un_420 ss.nn.un_320  ru.uk.sr_443 en.eu.tn_322 
  0x2d00100d, 0x482d0d02, 0x251f650c, 0x1d006404,   // lt.sk.un_540 cs.sk.tt_222  gv.cy.eu_543 lg.la.un_320 
  0x044837a6, 0xfc6b1dad, 0x183f3504, 0x39256509,   // ba.tt.ru_521 la.ceb.zzp_643  zu.af.ga_332 gv.eu.br_444 
  0x3b1ffe0b, 0x25000804, 0x282118a9, 0x3f005718,   // tlh.cy.so_542 no.eu.un_320  ar.fa.sd_544 na.af.un_740 
  // [2e90]
  0x11311baf, 0x04070a0c, 0x2a400604, 0x35001f04,   // tr.az.ro_655 mk.bg.ru_543  de.lb.mt_332 cy.zu.un_320 
  0x03063faf, 0x00004e24, 0x37033f04, 0x0a632c0c,   // af.de.nl_655 ay.un.un_900  af.nl.st_332 fy.sco.pt_543 
  0x0900400d, 0x11001f07, 0x2344380c, 0x46006212,   // lb.pl.un_540 cy.ro.un_420  tk.kk.ky_543 kha.qu.un_640 
  0x151536a4, 0x203b5812, 0x42060711, 0x3e0c5d0c,   // ab.un.un_430 om.so.sq_654  it.de.co_653 ss.sv.rm_543 
  // [2ea0]
  0x4b4f2055, 0x694b36a4, 0x43006034, 0x21003d0e,   // sq.bi.mi_442 gn.mi.mfe_433  vo.ie.un_A80 ku.fa.un_550 
  0x362024ad, 0x0f103202, 0x174b2912, 0x29245cad,   // eo.sq.gn_643 bs.lt.lv_222  sl.mi.sr_654 sa.eo.sl_643 
  0x44001813, 0x3b006308, 0x5a134c02, 0x2a003918,   // ar.kk.un_650 sco.so.un_430  wo.et.sm_222 dz.bo.un_740 
  0x3400300e, 0x5d330804, 0x38fc1d07, 0x4b001302,   // uz.ps.un_550 no.nn.ss_332  la.zzp.tk_432 et.mi.un_220 
  // [2eb0]
  0x12466010, 0x2d0d0ea4, 0x421ffe04, 0x303f6007,   // vo.qu.hu_642 is.cs.sk_433  tlh.cy.co_332 vo.af.uz_432 
  0x170a11a9, 0x063f39a0, 0x3000430e, 0x2f001b02,   // ro.mk.sr_544 br.af.de_322  ie.uz.un_550 tr.su.un_220 
  0x1b002809, 0x350a38ee, 0x273b46a0, 0x65634608,   // sw.tr.un_440 tk.mk.tg_422  qu.so.gd_322 qu.sco.gv_443 
  0x211e1c04, 0x073c30a9, 0x2f211caf, 0x49454707,   // id.ms.jw_332 uz.ug.bg_544  id.jw.su_655 sn.ln.to_432 
  // [2ec0]
  0x37074802, 0x13004704, 0x28004522, 0x1e2f1c12,   // tt.bg.ba_222 sn.et.un_320  ln.sw.un_870 id.su.ms_654 
  0x0c5101a0, 0x48002507, 0x045120ee, 0x5100630d,   // en.kl.sv_322 mn.tt.un_420  sq.kl.fi_422 sco.kl.un_540 
  0x2000400e, 0x17003502, 0x48002313, 0x04004805,   // lb.sq.un_550 tg.sr.un_220  ky.tt.un_650 tt.ru.un_330 
  0x15041012, 0x6b00791a, 0x5100540c, 0x5c1c0908,   // be.ru.un_654 war.ceb.un_760  ik.kl.un_530 hi.mr.sa_443 
  // [2ed0]
  0x311b48ec, 0x482315a4, 0x31381baf, 0x12213b04,   // tt.tr.az_644 un.ky.tt_433  tr.tk.az_655 ks.fa.ur_332 
  0x353973a0, 0x6a231ca0, 0x04006509, 0x121821a0,   // ny.br.zu_322 id.ca.haw_322  gv.fi.un_440 fa.ar.ur_322 
  0x04170704, 0x3b004b04, 0x301036a4, 0x50474b05,   // bg.sr.ru_332 mi.so.un_320  ab.be.uz_433 mi.sn.fj_333 
  0x080415ad, 0x04002008, 0x512054ee, 0x09282107,   // un.ru.uk_643 sq.fi.un_430  ik.sq.kl_422 jw.sw.pl_432 
  // [2ee0]
  0x57353413, 0x5d511ea0, 0x6a37640d, 0x12000f18,   // xh.zu.na_665 ms.kl.ss_322  lg.st.haw_554 lv.hu.un_740 
  0x2c006504, 0x2e020c0c, 0x5f0247a9, 0x21572fa4,   // gv.fy.un_320 sv.da.fo_543  sn.da.tn_544 su.na.jw_433 
  0x0a3530ad, 0x75375fa9, 0x09006413, 0x305f7509,   // uz.tg.mk_643 tn.st.nso_544  lg.pl.un_650 nso.tn.uz_444 
  0x09253511, 0x73005d19, 0x455f4d0c, 0x35642805,   // zu.eu.pl_653 ss.ny.un_750  aa.tn.ln_543 sw.lg.zu_333 
  // [2ef0]
  0x2f005014, 0x091c0d05, 0x1a00fc07, 0x64572811,   // fj.su.un_660 ne.mr.hi_333  zzp.tl.un_420 sw.na.lg_653 
  0x483c3707, 0x55285d0c, 0x302538a7, 0x2f5b4b08,   // ba.ug.tt_432 ss.sw.rw_543  tk.mn.uz_532 mi.sg.su_443 
  0x12342113, 0x4c004a08, 0x4b0669a6, 0x595502a4,   // fa.ps.ur_665 yo.wo.un_430  mfe.de.mi_521 da.rw.rn_433 
  0xfc002f08, 0x5c090da4, 0x097364a0, 0x1afc4dee,   // su.zzp.un_430 ne.hi.sa_433  lg.ny.pl_322 aa.zzp.tl_422 
  // [2f00]
  0x353c3604, 0x3d2118ee, 0x1dfc1507, 0x68162da4,   // ab.ug.tg_332 ar.fa.ku_422  un.zzp.la_432 sk.hr.ig_433 
  0x0b00332a, 0x0000fc24, 0x00005a24, 0x5f00371b,   // as.bn.un_970 zzp.un.un_900  sm.un.un_900 st.tn.un_770 
  0x0400600e, 0x23003607, 0x0d1c09a9, 0x250a350c,   // vo.fi.un_550 ab.ky.un_420  hi.mr.ne_544 tg.mk.mn_543 
  0x34122160, 0x30003c09, 0x36004613, 0x3b006402,   // fa.ur.ps_664 ug.uz.un_440  qu.gn.un_650 lg.so.un_220 
  // [2f10]
  0x4c4d3b08, 0x1e1c58a9, 0x3600040c, 0x0e001b02,   // so.aa.wo_443 om.id.ms_544  fi.gn.un_530 tr.is.un_220 
  0x0a5c3b0b, 0x442334ad, 0x38003c19, 0x36004421,   // so.sa.pt_542 ps.ky.kk_643  ug.tk.un_750 kk.ab.un_860 
  0x213b7907, 0x28003b07, 0x64006b08, 0x2a000204,   // war.so.jw_432 so.sw.un_420  ceb.lg.un_430 da.mt.un_320 
  0x1e1c58a4, 0x64003b12, 0x3b2812a4, 0x5d002804,   // om.id.ms_433 so.lg.un_640  ur.sd.ks_433 sw.ss.un_320 
  // [2f20]
  0x1d0743a4, 0x24215da9, 0x1800781b, 0x04003707,   // ie.it.la_433 ss.jw.eo_544  ve.ga.un_770 ba.ru.un_420 
  0x1e041307, 0x4d00582a, 0x10002312, 0x2f6463ee,   // et.fi.ms_432 om.aa.un_970  ky.be.un_640 sco.lg.su_422 
  0x0e302eee, 0x2000120e, 0x584c3b12, 0x2f1c1e0c,   // fo.uz.is_422 hu.sq.un_550  so.wo.om_654 ms.id.su_543 
  0x05111da4, 0x0a073809, 0x0d005c1a, 0x53003e07,   // la.ro.fr_433 tk.bg.mk_444  sa.ne.un_760 rm.ht.un_420 
  // [2f30]
  0x2134300b, 0x2e300eaf, 0x12005304, 0x071504af,   // uz.ps.fa_542 is.uz.fo_655  ht.hu.un_320 ru.bg.un_650 
  0x07040807, 0x0e0401a0, 0x130d0907, 0x04025112,   // uk.ru.bg_432 en.fi.is_322  hi.ne.bh_432 kl.da.fi_654 
  0x49003407, 0x01512cec, 0x2318210e, 0x31003005,   // xh.to.un_420 fy.kl.en_644  fa.ar.ky_555 uz.az.un_330 
  0x13290f04, 0x1d5a6a0c, 0x2e060208, 0x1c671e12,   // lv.sl.et_332 haw.sm.la_543  da.de.fo_443 ms.ak.id_654 
  // [2f40]
  0x3900460e, 0x68000104, 0x37755fec, 0x4c004e0c,   // qu.br.un_550 en.ig.un_320  tn.nso.st_644 ay.wo.un_530 
  0x212f47a4, 0x100415af, 0x1d114807, 0x061c1e0c,   // sn.su.jw_433 un.ru.be_655  tt.ro.la_432 ms.id.de_543 
  0x08000207, 0x121d1107, 0x2d0d56ee, 0x69023e08,   // da.no.un_420 ro.la.hu_432  mg.cs.sk_422 rm.da.mfe_443 
  0x4a005807, 0x12003008, 0x42301da4, 0x6a25380b,   // om.yo.un_420 uz.ur.un_430  la.uz.co_433 tk.eu.haw_542 
  // [2f50]
  0x39001f0c, 0x5e004719, 0x47001d20, 0x2d0d0909,   // cy.br.un_530 sn.ts.un_750  la.sn.un_850 pl.cs.sk_444 
  0x1e1c040e, 0x0100630d, 0x28121805, 0x47552108,   // fi.id.ms_555 sco.en.un_540  ar.ur.sd_333 jw.rw.sn_443 
  0x33082402, 0x04080707, 0x650d0904, 0x09005608,   // eo.no.nn_222 bg.uk.ru_432  pl.cs.gv_332 mg.pl.un_430 
  0x17000405, 0x2d003808, 0x1800120c, 0x3000212b,   // ru.sr.un_330 tk.sk.un_430  ur.ar.un_530 fa.uz.un_980 
  // [2f60]
  0xfc00601b, 0x1716320c, 0x10003305, 0xfc006404,   // vo.zzp.un_770 bs.hr.sr_543  nn.lt.un_330 lg.zzp.un_320 
  0x7900082b, 0x6000fc13, 0x4c3b58ad, 0x530601ad,   // no.war.un_980 zzp.vo.un_650  om.so.wo_643 en.de.ht_643 
  0x5c42fcee, 0x255321ad, 0x10000409, 0x522753ec,   // zzp.co.sa_422 jw.ht.eu_643  ru.be.un_440 ht.gd.ha_644 
  0x365c60ad, 0x3b033f14, 0x00006237, 0x380d2d07,   // vo.sa.gn_643 af.nl.so_666  kha.un.un_B00 sk.cs.tk_432 
  // [2f70]
  0x2f630111, 0x380d2da6, 0x1e691caf, 0x2d0d47a4,   // en.sco.su_653 sk.cs.tk_521  id.mfe.ms_655 sn.cs.sk_433 
  0x65255712, 0x2c000113, 0x1c0f1fa9, 0x25695208,   // na.eu.gv_654 en.fy.un_650  cy.lv.id_544 ha.mfe.eu_443 
  0x07100807, 0x52004d36, 0x193148af, 0x303d3404,   // uk.be.bg_432 aa.ha.un_AA0  tt.az.gl_655 ps.ku.uz_332 
  0x443c23a9, 0x521f4aa9, 0x36000413, 0x1f000104,   // ky.ug.kk_544 yo.cy.ha_544  fi.gn.un_650 en.cy.un_320 
  // [2f80]
  0x4831fe0c, 0x33083f02, 0x123f0360, 0x154448a9,   // tlh.az.tt_543 af.no.nn_222  nl.af.hu_664 tt.kk.un_544 
  0x1800210c, 0x62004f35, 0x4d000108, 0x182f27ee,   // fa.ar.un_530 bi.kha.un_A90  en.aa.un_430 gd.su.ga_422 
  0x3b001b04, 0x44004807, 0x381b1aa4, 0x33000b21,   // tr.so.un_320 tt.kk.un_420  tl.tr.tk_433 bn.as.un_860 
  0x1b604814, 0x38003c13, 0x0a073008, 0x385c30a7,   // tt.vo.tr_666 ug.tk.un_650  uz.bg.mk_443 uz.sa.tk_532 
  // [2f90]
  0x1b3060ad, 0x293038ee, 0x1e1c38a4, 0x15083cad,   // vo.uz.tr_643 tk.uz.sl_422  tk.id.ms_433 ug.uk.un_643 
  0x281b64a7, 0x5d00351b, 0x0800300e, 0x0e1b2ea7,   // lg.tr.sw_532 zu.ss.un_770  uz.uk.un_550 fo.tr.is_532 
  0x5b002b13, 0x0000641c, 0x481b62ee, 0x3d181207,   // vi.sg.un_650 lg.un.un_800  kha.tr.tt_422 ur.ar.ku_432 
  0x02003f12, 0x4673475a, 0x1d69355a, 0x07000e07,   // af.da.un_640 sn.ny.qu_553  zu.mfe.la_553 is.it.un_420 
  // [2fa0]
  0x48383007, 0x5c4830a0, 0xfe353409, 0x28357312,   // uz.tk.tt_432 uz.tt.sa_322  xh.zu.tlh_444 ny.zu.sw_654 
  0x0200650d, 0x1f002b04, 0x1b2e0e0c, 0x35343755,   // gv.da.un_540 vi.cy.un_320  is.fo.tr_543 st.xh.zu_442 
  0x1b4830a4, 0x4d003b1a, 0x06fc7907, 0x35003c22,   // uz.tt.tr_433 so.aa.un_760  war.zzp.de_432 ug.tg.un_870 
  0x791a1b55, 0x5c353404, 0x101b3807, 0x55005713,   // tr.tl.war_442 xh.zu.sa_332  tk.tr.lt_432 na.rw.un_650 
  // [2fb0]
  0x170411a0, 0x06006408, 0xfc003b04, 0x39000604,   // ro.ru.sr_322 lg.de.un_430  so.zzp.un_320 de.br.un_320 
  0x735d4ea0, 0x39002a13, 0x3d21120b, 0x56000608,   // ay.ss.ny_322 bo.dz.un_650  ur.fa.ku_542 de.mg.un_430 
  0x12000f05, 0x0a102304, 0x32007507, 0x1d4c3904,   // lv.hu.un_330 ky.be.mk_332  nso.bs.un_420 br.wo.la_332 
  0x561f5e05, 0x01472007, 0x31001b12, 0x481538ec,   // ts.cy.mg_333 sq.sn.en_432  tr.az.un_640 tk.tt.un_640 
  // [2fc0]
  0x2134120c, 0x384006a4, 0x40001212, 0x10001504,   // ur.ps.fa_543 de.lb.tk_433  hu.lb.un_640 un.be.un_320 
  0x2135345a, 0xfe4a2104, 0x192924a0, 0x4c510807,   // xh.zu.jw_553 jw.yo.tlh_332  eo.sl.gl_322 no.kl.wo_432 
  0x15695e07, 0x35070b07, 0x022e0e08, 0x655e0da0,   // ts.mfe.un_432 es.it.zu_432  is.fo.da_443 cs.ts.gv_322 
  0x1b201312, 0x64211aa7, 0x12002004, 0x790e2e04,   // et.sq.tr_654 tl.jw.lg_532  sq.hu.un_320 fo.is.war_332 
  // [2fd0]
  0x3c303855, 0x203965ee, 0x23003b08, 0x4c002b02,   // tk.uz.ug_442 gv.br.sq_422  so.ca.un_430 vi.wo.un_220 
  0x1a656baf, 0x20fe04a0, 0x11002202, 0x0b241ba0,   // ceb.gv.tl_655 fi.tlh.sq_322  oc.ro.un_220 tr.eo.es_322 
  0x6b2f210c, 0x6b00791b, 0x12000d04, 0x0400650d,   // jw.su.ceb_543 war.ceb.un_770  cs.hu.un_320 gv.fi.un_540 
  0x652c1302, 0x65131a0c, 0x304415ad, 0x650e2e08,   // et.fy.gv_222 tl.et.gv_543  un.kk.uz_643 fo.is.gv_443 
  // [2fe0]
  0x21003d29, 0x132a0207, 0x060434ee, 0x4704280c,   // ku.fa.un_960 da.mt.et_432  xh.fi.de_422 sw.fi.sn_543 
  0x511d040c, 0x4800230c, 0x51051d07, 0x2d3f34af,   // fi.la.kl_543 ky.tt.un_530  la.fr.kl_432 xh.af.sk_655 
  0x25042308, 0x3800fc0d, 0x03373fa4, 0x36003808,   // ky.ru.mn_443 zzp.tk.un_540  af.st.nl_433 tk.gn.un_430 
  0x1347040b, 0x51040307, 0x213012a4, 0x04420507,   // fi.sn.et_542 nl.fi.kl_432  ur.uz.fa_433 fr.co.fi_432 
  // [2ff0]
  0x042d3b02, 0x651d43a7, 0x374423a0, 0x1d00630e,   // so.sk.fi_222 ie.la.gv_532  ky.kk.ba_322 sco.la.un_550 
  0x22051905, 0x17000808, 0x5f1d4208, 0x080a15a0,   // gl.fr.oc_333 uk.sr.un_430  co.la.tn_443 un.mk.uk_322 
  0x58002512, 0x33080c0e, 0x330813ee, 0x5000040d,   // eu.om.un_640 sv.no.nn_555  et.no.nn_422 fi.fj.un_540 
  0x35345d0e, 0x071d0408, 0x23000502, 0x42242108,   // ss.xh.zu_555 fi.la.it_443  fr.ca.un_220 jw.eo.co_443 
  
  // [3000]
  0x1d025105, 0x045f3714, 0x033ffcaf, 0x07000108,   // kl.da.la_333 st.tn.fi_666  zzp.af.nl_655 en.it.un_430 
  0x44002305, 0x403f0607, 0x03083fee, 0x3700440c,   // ky.kk.un_330 de.af.lb_432  af.no.nl_422 kk.ba.un_530 
  0x374844ee, 0x18003c0d, 0x123d28ee, 0x3b005808,   // kk.tt.ba_422 ug.ar.un_540  sd.ku.ur_422 om.so.un_430 
  0x03133f07, 0x06003f08, 0x04003004, 0x173538a0,   // af.et.nl_432 af.de.un_430  uz.ru.un_320 tk.tg.sr_322 
  // [3010]
  0x3b004d11, 0x3b004d0e, 0x39005302, 0x0400460d,   // aa.so.un_630 aa.so.un_550  ht.br.un_220 qu.fi.un_540 
  0x100835a4, 0x51020412, 0x34003d09, 0x272f2102,   // tg.uk.be_433 fi.da.kl_654  ku.ps.un_440 jw.su.gd_222 
  0x3b002504, 0x5700680e, 0x7500471a, 0x380e2ea7,   // eu.so.un_320 ig.na.un_550  sn.nso.un_760 fo.is.tk_532 
  0x342128a4, 0x0800170e, 0x34004c2b, 0x35303caf,   // sd.fa.ps_433 sr.uk.un_550  wo.xh.un_980 ug.uz.tg_655 
  // [3020]
  0x3500fc0d, 0x1c044607, 0x5f00780c, 0x0e4e2e08,   // zzp.zu.un_540 qu.fi.id_432  ve.tn.un_530 fo.ay.is_443 
  0x40006404, 0x4a000d05, 0x64477804, 0x13001c13,   // lg.lb.un_320 cs.yo.un_330  ve.sn.lg_332 mr.bh.un_650 
  0x34213d0b, 0x351008a0, 0x23003c23, 0x13000d0c,   // ku.fa.ps_542 uk.be.tg_322  ug.ky.un_880 ne.bh.un_530 
  0x0c27280c, 0x4afc64ac, 0x071535a9, 0x0b000104,   // sw.gd.sv_543 lg.zzp.yo_632  tg.bg.un_540 en.es.un_320 
  // [3030]
  0x4d2718a7, 0x62733b08, 0x0700150b, 0x31560f0c,   // ga.gd.aa_532 so.ny.kha_443  un.bg.un_520 lv.mg.az_543 
  0x071351ee, 0x33080609, 0x426b4d0c, 0x183421ec,   // kl.et.it_422 de.no.nn_444  aa.ceb.co_543 fa.ps.ar_644 
  0x0413510b, 0x464e4da9, 0x303b3d08, 0x3f006404,   // kl.et.fi_542 aa.ay.qu_544  ku.ks.uz_443 lg.af.un_320 
  0x353478a0, 0x080715a0, 0x166e1707, 0x1004070e,   // ve.xh.zu_322 un.bg.uk_322  sr.hmn.hr_432 bg.ru.be_555 
  // [3040]
  0x53002102, 0x652e0e0b, 0x5c091c0c, 0x380a1714,   // jw.ht.un_220 is.fo.gv_542  mr.hi.sa_543 sr.mk.tk_666 
  0x181230a0, 0x463b1f0b, 0x05000104, 0x3430210c,   // uz.ur.ar_322 cy.so.qu_542  en.fr.un_320 fa.uz.ps_543 
  0x300835a9, 0x094839a6, 0x1d006e09, 0x05006504,   // tg.uk.uz_544 br.tt.pl_521  hmn.la.un_440 gv.fr.un_320 
  0x1d65fca0, 0x6a2718ec, 0x30002121, 0x18001102,   // zzp.gv.la_322 ga.gd.haw_644  fa.uz.un_860 ro.ga.un_220 
  // [3050]
  0x040511a7, 0x302310a4, 0x48003c09, 0x054311a0,   // ro.fr.fi_532 be.ky.uz_433  ug.tt.un_440 ro.ie.fr_322 
  0x27653055, 0x30153805, 0x6a290da9, 0xfc015704,   // uz.gv.gd_442 tk.uz.un_330  cs.sl.haw_544 na.en.zzp_332 
  0x345d3512, 0x10252da4, 0x5902640c, 0x28024007,   // zu.ss.xh_654 sk.eu.lt_433  lg.da.rn_543 lb.da.sw_432 
  0x245f600c, 0x07353008, 0x016515a0, 0x5513250c,   // vo.tn.eo_543 uz.tg.bg_443  un.gv.en_322 eu.et.rw_543 
  // [3060]
  0x4000200e, 0x10084412, 0x18443da7, 0x493f04a0,   // sq.lb.un_550 kk.uk.be_654  ku.kk.ar_532 fi.af.to_322 
  0x645955af, 0x6b001305, 0x253515ad, 0x023020a0,   // rw.rn.lg_655 et.ceb.un_330  un.tg.mn_643 sq.uz.da_322 
  0x09242d02, 0x27184305, 0x0a004d0c, 0x4a0b5f07,   // sk.eo.pl_222 ie.ga.gd_333  aa.pt.un_530 tn.es.yo_432 
  0x2910340c, 0x73fa55a4, 0x0c0625a4, 0x59555e05,   // xh.lt.sl_543 rw.nr.ny_433  eu.de.sv_433 ts.rw.rn_333 
  // [3070]
  0x233830af, 0x2502340c, 0x2800471a, 0x2a420708,   // uz.tk.ky_655 xh.da.eu_543  sn.sw.un_760 it.co.mt_443 
  0x4e00531a, 0x15303512, 0x793216ad, 0x25000108,   // ht.ay.un_760 tg.uz.un_654  hr.bs.war_643 en.eu.un_430 
  0x37384408, 0x04652511, 0x65200112, 0x364f250c,   // kk.tk.ba_443 eu.gv.fi_653  en.sq.gv_654 eu.bi.gn_543 
  0x65002c04, 0x46190b04, 0x1d260107, 0x58514d08,   // fy.gv.un_320 es.gl.qu_332  en.ia.la_432 aa.kl.om_443 
  // [3080]
  0x233d44a4, 0x4d5801a0, 0x230a01a4, 0x4d2322a9,   // kk.ku.ky_433 en.om.aa_322  en.pt.ca_433 oc.ca.aa_544 
  0x18276513, 0x38303caf, 0x6558250c, 0x1e1c4fa6,   // gv.gd.ga_665 ug.uz.tk_655  eu.om.gv_543 bi.id.ms_521 
  0x4400371a, 0x3b003013, 0x53000914, 0x52253004,   // ba.kk.un_760 uz.so.un_650  pl.ht.un_660 uz.eu.ha_332 
  0x1b00650e, 0xfe794d08, 0x48003b05, 0x18213dad,   // gv.tr.un_550 aa.war.tlh_443  so.tt.un_330 ku.fa.ar_643 
  // [3090]
  0x34002812, 0x0dfe1e04, 0x2834180c, 0x58005213,   // sd.ps.un_640 ms.tlh.cs_332  ar.ps.sd_543 ha.om.un_650 
  0x5b254d12, 0x55003719, 0x15110a0c, 0x203b2aad,   // aa.eu.sg_654 st.rw.un_750  mk.ro.un_543 mt.so.sq_643 
  0x0000fe01, 0x2000650d, 0x686b65ad, 0x17004f07,   // tlh.un.un_200 gv.sq.un_540  gv.ceb.ig_643 bi.sr.un_420 
  0x2b002c04, 0x58000113, 0x2e31fe07, 0x1004080d,   // fy.vi.un_320 en.om.un_650  tlh.az.fo_432 uk.ru.be_554 
  // [30a0]
  0x010c7909, 0x3b1b3104, 0x2700fc02, 0x3c1823a7,   // war.sv.en_444 az.tr.so_332  zzp.gd.un_220 ky.ar.ug_532 
  0x0d5c1304, 0x1f1b310c, 0xfe1513a0, 0x18342104,   // bh.sa.ne_332 az.tr.cy_543  et.tlh.un_320 fa.ps.ar_332 
  0x311b380c, 0x25004008, 0x4c653004, 0x23002507,   // tk.tr.az_543 lb.eu.un_430  uz.gv.wo_332 mn.ky.un_420 
  0x1f00fe08, 0x39003b02, 0x3b4dfe12, 0x25002319,   // tlh.cy.un_430 so.br.un_220  tlh.aa.so_654 ky.mn.un_750 
  // [30b0]
  0x0e3f2e0c, 0x12003f0d, 0x020e73a7, 0x363f0308,   // fo.af.is_543 af.hu.un_540  ny.is.da_532 nl.af.gn_443 
  0x213b58a0, 0x1c002f02, 0xfe004c08, 0x3b1b3804,   // om.so.jw_322 su.id.un_220  wo.tlh.un_430 tk.tr.so_332 
  0x04101511, 0x304648a9, 0x00001724, 0x1e004c08,   // un.be.ru_653 tt.qu.uz_544  sr.un.un_900 wo.ms.un_430 
  0x40003b02, 0x30314dee, 0x2c062407, 0x341828a7,   // so.lb.un_220 aa.az.uz_422  eo.de.fy_432 sd.ar.ps_532 
  // [30c0]
  0x302112af, 0x1c001504, 0x44002504, 0x016563a7,   // ur.fa.uz_655 un.id.un_320  mn.kk.un_320 sco.gv.en_532 
  0x371536a4, 0x032e51a0, 0x27001504, 0x25000704,   // ab.ba.un_430 kl.fo.nl_322  un.gd.un_320 bg.mn.un_320 
  0x2300481b, 0x080430a6, 0x15005102, 0x3700481b,   // tt.ky.un_770 uz.ru.uk_521  kl.un.un_220 tt.ba.un_770 
  0x062c08a0, 0x3d34210c, 0x253e0bee, 0x36190b08,   // no.fy.de_322 fa.ps.ku_543  es.rm.eu_422 es.gl.gn_443 
  // [30d0]
  0x04303508, 0x1200340b, 0x23180ba0, 0x3c00210d,   // tg.uz.ru_443 ps.ur.un_520  es.ga.ca_322 fa.ug.un_540 
  0x19122da4, 0x0b2e0e08, 0x213418a4, 0x35004602,   // sk.hu.gl_433 is.fo.es_443  ar.ps.fa_433 qu.zu.un_220 
  0x18002d0c, 0x46190b55, 0x190b4a0e, 0x17005c0b,   // sk.ga.un_530 es.gl.qu_442  yo.es.gl_555 sa.sr.un_520 
  0xfc2f7912, 0x0b002508, 0x46000b02, 0x46190b02,   // war.su.zzp_654 eu.es.un_430  es.qu.un_220 es.gl.qu_222 
  // [30e0]
  0x3b00fc21, 0x374423af, 0x12190b04, 0x10002302,   // zzp.so.un_860 ky.kk.ba_655  es.gl.hu_332 ky.be.un_220 
  0x4e190b08, 0x3bfc1bad, 0x40011aa0, 0x300735ac,   // es.gl.ay_443 tr.zzp.so_643  tl.en.lb_322 tg.bg.uz_632 
  0x2b001502, 0x13006018, 0x1d4d5807, 0x1d0e4d07,   // un.vi.un_220 vo.et.un_740  om.aa.la_432 aa.is.la_432 
  0x0a003521, 0x37040514, 0x61004d14, 0x58000423,   // tg.mk.un_860 fr.fi.st_666  aa.za.un_660 fi.om.un_880 
  // [30f0]
  0x0f00460d, 0x46001014, 0x240402a0, 0x1d580f04,   // qu.lv.un_540 lt.qu.un_660  da.fi.eo_322 lv.om.la_332 
  0x2800580e, 0xfc007304, 0x79581aad, 0x0302080c,   // om.sw.un_550 ny.zzp.un_320  tl.om.war_643 no.da.nl_543 
  0x135851af, 0x12004d0d, 0x48173555, 0x0000242d,   // kl.om.et_655 aa.hu.un_540  tg.sr.tt_442 yi.un.un_A00 
  0x0e044d0c, 0x091c1307, 0x21341204, 0x070a38ec,   // aa.fi.is_543 bh.mr.hi_432  ur.ps.fa_332 tk.mk.bg_644 
  // [3100]
  0x0400610c, 0x22005104, 0x6b511c07, 0x5a00501a,   // za.fi.un_530 kl.oc.un_320  id.kl.ceb_432 fj.sm.un_760 
  0x1d130405, 0x13000d14, 0x61004619, 0x38001c04,   // fi.et.la_333 ne.bh.un_660  qu.za.un_750 id.tk.un_320 
  0x4418230c, 0x083517ee, 0x17002902, 0x342128ee,   // ky.ar.kk_543 sr.tg.uk_422  sl.sr.un_220 sd.fa.ps_422 
  0x033f5407, 0x15043504, 0x033f650c, 0x0a172305,   // ik.af.nl_432 tg.ru.un_332  gv.af.nl_543 ky.sr.mk_333 
  // [3110]
  0x04001308, 0x5a494bee, 0x033f65ad, 0x65001d04,   // et.fi.un_430 mi.to.sm_422  gv.af.nl_643 la.gv.un_320 
  0x5d2e0e08, 0x5c0451ad, 0x29003205, 0x17070a13,   // is.fo.ss_443 kl.fi.sa_643  bs.sl.un_330 mk.bg.sr_665 
  0x33086b02, 0x48001107, 0x19002304, 0x170a070d,   // ceb.no.nn_222 ro.tt.un_420  ca.gl.un_320 bg.mk.sr_554 
  0x0800070d, 0x0c003807, 0x64005004, 0x081044ad,   // bg.uk.un_540 tk.sv.un_420  fj.lg.un_320 kk.be.uk_643 
  // [3120]
  0x3f000311, 0x51005a08, 0x04653f08, 0x03005504,   // nl.af.un_630 sm.kl.un_430  af.gv.fi_443 rw.nl.un_320 
  0x133f04ee, 0x30122113, 0x68002b14, 0x00006837,   // fi.af.et_422 fa.ur.uz_665  vi.ig.un_660 ig.un.un_B00 
  0x73645213, 0x04001504, 0x1a64780c, 0x2b00680c,   // ha.lg.ny_665 un.ru.un_320  ve.lg.tl_543 ig.vi.un_530 
  0x4e785213, 0x2d130255, 0x37625208, 0x42002711,   // ha.ve.ay_665 da.et.sk_442  ha.kha.st_443 gd.co.un_630 
  // [3130]
  0x3852280c, 0x4d52570c, 0x2f001c05, 0x1d045407,   // sw.ha.tk_543 na.ha.aa_543  id.su.un_330 ik.fi.la_432 
  0x646b5212, 0x12213d0c, 0x0d001113, 0x6551200c,   // ha.ceb.lg_654 ku.fa.ur_543  ro.cs.un_650 sq.kl.gv_543 
  0x65545109, 0x1a515404, 0x11206508, 0x12162905,   // kl.ik.gv_444 ik.kl.tl_332  gv.sq.ro_443 sl.hr.hu_333 
  0x440a04ad, 0x04654da6, 0x3c004407, 0x15234408,   // ru.mk.kk_643 aa.gv.fi_521  kk.ug.un_420 kk.ky.un_443 
  // [3140]
  0x38524507, 0x30654305, 0x0000521c, 0x5e004d1a,   // ln.ha.tk_432 ie.gv.uz_333  ha.un.un_800 aa.ts.un_760 
  0x6554510c, 0x73005212, 0x64465208, 0x0d00110d,   // kl.ik.gv_543 ha.ny.un_640  ha.qu.lg_443 ro.cs.un_540 
  0x47524e5a, 0x3800300c, 0x3745520c, 0x47371a12,   // ay.ha.sn_553 uz.tk.un_530  ha.ln.st_543 tl.st.sn_654 
  0x34002813, 0x22252407, 0x18002113, 0x32160da0,   // sd.ps.un_650 eo.eu.oc_432  fa.ar.un_650 cs.hr.bs_322 
  // [3150]
  0x4d00651a, 0x07353055, 0x202d0da7, 0x39515412,   // gv.aa.un_760 uz.tg.bg_442  cs.sk.sq_532 ik.kl.br_654 
  0x65000205, 0x11005a2b, 0x0d095c09, 0x20000d04,   // da.gv.un_330 sm.ro.un_980  sa.hi.ne_444 cs.sq.un_320 
  0x15001f09, 0x07003607, 0x19000a07, 0x3d003007,   // cy.un.un_440 ab.bg.un_420  pt.gl.un_420 uz.ku.un_420 
  0x225223ad, 0x630b23ec, 0x3748385a, 0x34183d02,   // ca.ha.oc_643 ca.es.sco_644  tk.tt.ba_553 ku.ar.ps_222 
  // [3160]
  0x48374407, 0x24002a07, 0x10004813, 0x1000250c,   // kk.ba.tt_432 mt.eo.un_420  tt.be.un_650 mn.be.un_530 
  0x0d06090e, 0x31005907, 0x09000d02, 0x04000c04,   // pl.de.cs_555 rn.az.un_420  ne.hi.un_220 sv.fi.un_320 
  0x12002e07, 0x070a170c, 0x03000b04, 0x231511ad,   // fo.hu.un_420 sr.mk.bg_543  es.nl.un_320 ro.ky.un_630 
  0x223963a0, 0x2d000f05, 0x04003008, 0x49004b04,   // sco.br.oc_322 lv.sk.un_330  uz.ru.un_430 mi.to.un_320 
  // [3170]
  0x307920ad, 0x212f13a0, 0x2152fa08, 0x0a000722,   // sq.war.uz_643 et.su.jw_322  nr.ha.jw_443 bg.mk.un_870 
  0x13000d08, 0x49385d0c, 0x49004f07, 0x79000918,   // ne.bh.un_430 ss.tk.to_543  bi.to.un_420 pl.war.un_740 
  0x13002a04, 0x49004b19, 0x1a592504, 0x30646ba4,   // mt.et.un_320 mi.to.un_750  eu.rn.tl_332 ceb.lg.uz_433 
  0x1200450c, 0x2f000208, 0x02521a5a, 0x32161ca9,   // ln.hu.un_530 da.su.un_430  tl.ha.da_553 id.hr.bs_544 
  // [3180]
  0x3f0308a9, 0x150a0709, 0x595564a9, 0x13001107,   // no.nl.af_544 bg.mk.un_444  lg.rw.rn_544 ro.et.un_420 
  0x64005518, 0x4a00670c, 0x2e080e02, 0x101303a9,   // rw.lg.un_740 ak.yo.un_530  is.no.fo_222 nl.et.lt_544 
  0x060f61ee, 0x0279520e, 0x107637a9, 0x34311ba4,   // za.lv.de_422 ha.war.da_555  st.crs.lt_544 tr.az.xh_433 
  0x0800020c, 0x5200350d, 0x2e004a07, 0x391b3808,   // da.no.un_530 zu.ha.un_540  yo.fo.un_420 tk.tr.br_443 
  // [3190]
  0x731b6008, 0x49004b0b, 0x063e3407, 0x3853090c,   // vo.tr.ny_443 mi.to.un_520  xh.rm.de_432 pl.ht.tk_543 
  0x4b5d2f07, 0x1f033f09, 0x73290204, 0x132f37a0,   // su.ss.mi_432 af.nl.cy_444  da.sl.ny_332 st.su.et_322 
  0x4a006a1a, 0x13003404, 0x39003f05, 0x070a04a4,   // haw.yo.un_760 xh.et.un_320  af.br.un_330 ru.mk.bg_433 
  0x31002904, 0x355d52a4, 0x1a026408, 0x08003313,   // sl.az.un_320 ha.ss.zu_433  lg.da.tl_443 nn.no.un_650 
  // [31a0]
  0x1c1309ec, 0x20003007, 0x2e330855, 0x024c2908,   // hi.bh.mr_644 uz.sq.un_420  no.nn.fo_442 sl.wo.da_443 
  0x383036a4, 0x481117a4, 0x79001a23, 0x30000a14,   // ab.uz.tk_433 sr.ro.tt_433  tl.war.un_880 mk.uz.un_660 
  0x1500251a, 0x64004704, 0x080a30a0, 0x3400640d,   // mn.un.un_760 sn.lg.un_320  uz.mk.uk_322 lg.xh.un_540 
  0x2e000e21, 0x1800580d, 0x522b28a0, 0x1000040e,   // is.fo.un_860 om.ga.un_540  sw.vi.ha_322 ru.be.un_550 
  // [31b0]
  0x303c2314, 0x34002802, 0x3f330855, 0x183c23a9,   // ky.ug.uz_666 sw.xh.un_220  no.nn.af_442 ky.ug.ar_544 
  0x03005807, 0x48002c04, 0x303510ee, 0x0e001207,   // om.nl.un_420 fy.tt.un_320  be.tg.uz_422 hu.is.un_420 
  0x0e4c2e0c, 0x3c44180b, 0x30003c35, 0x350647a0,   // fo.wo.is_543 ar.kk.ug_542  ug.uz.un_A90 sn.de.zu_322 
  0x0e252ea4, 0x40004712, 0x0248080c, 0x58302c07,   // fo.eu.is_433 sn.lb.un_640  no.tt.da_543 fy.uz.om_432 
  // [31c0]
  0x080a3507, 0x19001d07, 0x0f6b1108, 0x250b19a4,   // tg.mk.uk_432 la.gl.un_420  ro.ceb.lv_443 gl.es.eu_433 
  0x53004602, 0x3000fe0c, 0x313046a0, 0x1f005f0e,   // qu.ht.un_220 tlh.uz.un_530  qu.uz.az_322 tn.cy.un_550 
  0x0f311b07, 0x303138a4, 0x2a000707, 0x2a5318a0,   // tr.az.lv_432 tk.az.uz_433  it.mt.un_420 ga.ht.mt_322 
  0x39271fa0, 0x30003902, 0x6a004b1b, 0x6a004b0e,   // cy.gd.br_322 br.uz.un_220  mi.haw.un_770 mi.haw.un_550 
  // [31d0]
  0x05000b07, 0x11222005, 0x19000b2a, 0x23190b14,   // es.fr.un_420 sq.oc.ro_333  es.gl.un_970 es.gl.ca_666 
  0x100f13ad, 0x040817a4, 0x213d30a0, 0x3b1bfcee,   // et.lv.lt_643 sr.uk.ru_433  uz.ku.fa_322 zzp.tr.so_422 
  0x022e0e09, 0x2a00390d, 0x3f0301a4, 0x5f001f12,   // is.fo.da_444 dz.bo.un_540  en.nl.af_433 cy.tn.un_640 
  0x08001511, 0x1f2e0ca4, 0x070417a4, 0x1507040d,   // un.uk.un_630 sv.fo.cy_433  sr.ru.bg_433 ru.bg.un_554 
  // [31e0]
  0x1b383111, 0x01fc15a7, 0x0a0817a0, 0x383951a7,   // az.tk.tr_653 un.zzp.en_532  sr.uk.mk_322 kl.br.tk_532 
  0x34003c02, 0x1c001e04, 0x40065108, 0x3d183bad,   // ug.ps.un_220 ms.id.un_320  kl.de.lb_443 ks.ar.ku_643 
  0x5100541b, 0x13541aec, 0x5c490f12, 0x5c6a4baf,   // ik.kl.un_770 tl.ik.et_644  lv.to.sa_654 mi.haw.sa_655 
  0x5400512a, 0x34182807, 0x2500230e, 0x643954a7,   // kl.ik.un_970 sd.ar.ps_432  ky.mn.un_550 ik.br.lg_532 
  // [31f0]
  0x3c4423ad, 0x1c1351ee, 0x0f581dee, 0x28122111,   // ky.kk.ug_643 kl.et.id_422  la.om.lv_422 fa.ur.sd_653 
  0x16290d02, 0x040a1755, 0x28003b0c, 0x4c001d09,   // cs.sl.hr_222 sr.mk.ru_442  ks.sd.un_530 la.wo.un_440 
  0x16006012, 0x0f001d02, 0x29353405, 0x22400607,   // vo.hr.un_640 la.lv.un_220  xh.zu.sl_333 de.lb.oc_432 
  0x2818090d, 0x0a0804a0, 0x6400020e, 0x1d000f04,   // pl.ga.sw_554 ru.uk.mk_322  da.lg.un_550 lv.la.un_320 
  // [3200]
  0x4c3b6405, 0x58284ca0, 0x3f033bec, 0x25000604,   // lg.so.wo_333 wo.sw.om_322  so.nl.af_644 de.eu.un_320 
  0x2c005804, 0x30fc38a7, 0x390f58a0, 0x5f377513,   // om.fy.un_320 tk.zzp.uz_532  om.lv.br_322 nso.st.tn_665 
  0x3b5f4012, 0x0000541c, 0x3d34210e, 0x1e646808,   // lb.tn.so_654 ik.un.un_800  fa.ps.ku_555 ig.lg.ms_443 
  0x3b000704, 0x58004c08, 0x4b0f6a13, 0x1d5451ec,   // it.so.un_320 wo.om.un_430  haw.lv.mi_665 kl.ik.la_644 
  // [3210]
  0x0e005804, 0x033b3fa9, 0x3f036412, 0x391d510c,   // om.is.un_320 af.so.nl_544  lg.nl.af_654 kl.la.br_543 
  0x40135108, 0xfc6452a0, 0x033f040c, 0x1a005104,   // kl.et.lb_443 ha.lg.zzp_322  fi.af.nl_543 kl.tl.un_320 
  0x3b000608, 0x0400580e, 0x0f002502, 0x3b3f4c0c,   // de.so.un_430 om.fi.un_550  eu.lv.un_220 wo.af.so_543 
  0x51000302, 0x5e063e05, 0x0c0657a0, 0x3f0364a4,   // nl.kl.un_220 rm.de.ts_333  na.de.sv_322 lg.nl.af_433 
  // [3220]
  0x52061c0c, 0x0f06580c, 0x403f03a9, 0x1e001c05,   // id.de.ha_543 om.de.lv_543  nl.af.lb_544 id.ms.un_330 
  0x21123d02, 0x17003005, 0x21001804, 0x3900040c,   // ku.ur.fa_222 uz.sr.un_330  ar.fa.un_320 fi.br.un_530 
  0x135c09ee, 0x341828ee, 0x0a3611a4, 0x3500230c,   // hi.sa.bh_422 sd.ar.ps_422  ro.ab.mk_433 ky.tg.un_530 
  0x483015ee, 0x441535a9, 0x30003813, 0x44003002,   // un.uz.tt_422 tg.kk.un_540  tk.uz.un_650 uz.kk.un_220 
  // [3230]
  0x04002102, 0x28002c0b, 0x6500640c, 0x68006e21,   // jw.fi.un_220 fy.sw.un_520  lg.gv.un_530 hmn.ig.un_860 
  0x50643fad, 0x481b31ad, 0x0f564e0c, 0x214f6204,   // af.lg.fj_643 az.tr.tt_643  ay.mg.lv_543 kha.bi.jw_332 
  0x11004707, 0x12002e0c, 0x351710a9, 0x342130ad,   // sn.ro.un_420 fo.hu.un_530  be.sr.tg_544 uz.fa.ps_643 
  0x08651dac, 0x36000a05, 0x1a126ba4, 0x5c4b0f07,   // la.gv.no_632 mk.ab.un_330  ceb.hu.tl_433 lv.mi.sa_432 
  // [3240]
  0x65280404, 0x1d3269ee, 0x09002912, 0x5d004a08,   // fi.sw.gv_332 mfe.bs.la_422  sl.pl.un_640 yo.ss.un_430 
  0x060446a0, 0x040848ee, 0x070417a0, 0x190b1da0,   // qu.fi.de_322 tt.uk.ru_422  sr.ru.bg_322 la.es.gl_322 
  0x252106a0, 0x2500370b, 0x1e1c2605, 0x21182802,   // de.jw.eu_322 ba.mn.un_520  ia.id.ms_333 sd.ar.fa_222 
  0x06004004, 0x2c023002, 0x64003f0c, 0x0a173507,   // lb.de.un_320 uz.da.fy_222  af.lg.un_530 tg.sr.mk_432 
  // [3250]
  0x07001904, 0x3d003422, 0x0a00070d, 0x3b003d19,   // gl.it.un_320 ps.ku.un_870  bg.mk.un_540 ku.ks.un_750 
  0x56003809, 0x3000390d, 0x23003c18, 0x0a006402,   // tk.mg.un_440 br.uz.un_540  ug.ky.un_740 lg.pt.un_220 
  0x5c003804, 0x56003813, 0x07002804, 0x21002b02,   // tk.sa.un_320 tk.mg.un_650  sw.it.un_320 vi.jw.un_220 
  0x43260b08, 0x40063fa0, 0x64003704, 0x00005624,   // es.ia.ie_443 af.de.lb_322  st.lg.un_320 mg.un.un_900 
  // [3260]
  0x3c001807, 0x355359a4, 0x4000060c, 0x5600380d,   // ar.ug.un_420 rn.ht.zu_433  de.lb.un_530 tk.mg.un_540 
  0x3f345d02, 0x36004413, 0x4b006a13, 0x12002109,   // ss.xh.af_222 kk.ab.un_650  haw.mi.un_650 fa.ur.un_440 
  0x096938af, 0x5c383612, 0x4b5c0fa7, 0x4823380d,   // tk.mfe.pl_655 gn.tk.sa_654  lv.sa.mi_532 tk.ky.tt_554 
  0x121821af, 0x150a07a4, 0x5c5636a6, 0x5a005302,   // fa.ar.ur_655 bg.mk.un_433  gn.mg.sa_521 ht.sm.un_220 
  // [3270]
  0x38005619, 0x56003807, 0x35003c0d, 0x10084411,   // mg.tk.un_750 tk.mg.un_420  ug.tg.un_540 kk.uk.be_653 
  0x2d0d380e, 0x3500360e, 0x13090d55, 0x4700370d,   // tk.cs.sk_555 ab.tg.un_550  ne.hi.bh_442 st.sn.un_540 
  0x15233ca0, 0x1b00480e, 0x48303cad, 0x3c1530a4,   // ug.ky.un_322 tt.tr.un_550  ug.uz.tt_643 uz.ug.un_430 
  0x170a070e, 0x383031ec, 0x0a003911, 0x27001814,   // bg.mk.sr_555 az.uz.tk_644  br.pt.un_630 ga.gd.un_660 
  // [3280]
  0x76536908, 0x790660a0, 0x2b3f5baf, 0x392b3f07,   // mfe.ht.crs_443 vo.de.war_322  sg.af.vi_655 af.vi.br_432 
  0x18003b07, 0x2b000a19, 0x0a2b5302, 0x2b003905,   // ks.ar.un_420 pt.vi.un_750  ht.vi.pt_222 br.vi.un_330 
  0x2500361b, 0x65151c02, 0x21343d08, 0x39002b0c,   // ab.mn.un_770 id.gv.un_220  ku.ps.fa_443 vi.br.un_530 
  0x5b003f2a, 0x68002813, 0x0a003c04, 0x2b000a12,   // af.sg.un_970 sw.ig.un_650  ug.mk.un_320 pt.vi.un_640 
  // [3290]
  0x3600371a, 0x0a002b0d, 0x30342114, 0x341221a6,   // ba.ab.un_760 vi.pt.un_540  fa.ps.uz_666 fa.ur.ps_521 
  0x28006811, 0x5e001e09, 0x2821340c, 0x483038a9,   // ig.sw.un_630 ms.ts.un_440  ps.fa.sd_543 tk.uz.tt_544 
  0x30003812, 0xfc002814, 0x06000507, 0x0a000709,   // tk.uz.un_640 sw.zzp.un_660  fr.de.un_420 bg.mk.un_440 
  0x353c300d, 0x0200500d, 0x44003707, 0x134220a0,   // uz.ug.tg_554 fj.da.un_540  ba.kk.un_420 sq.co.et_322 
  // [32a0]
  0x20003612, 0x46381308, 0x2917faaf, 0x1d734708,   // gn.sq.un_640 et.tk.qu_443  nr.sr.sl_655 sn.ny.la_443 
  0x1c231eee, 0x250115ee, 0x1d003807, 0x01001f02,   // ms.ca.id_422 un.en.eu_422  tk.la.un_420 cy.en.un_220 
  0x2a3216a0, 0x765369af, 0x21005302, 0x56002e02,   // hr.bs.mt_322 mfe.ht.crs_655  ht.jw.un_220 fo.mg.un_220 
  0x425138ad, 0x28003604, 0x3421120e, 0x09000602,   // tk.kl.co_643 gn.sw.un_320  ur.fa.ps_555 de.pl.un_220 
  // [32b0]
  0x08001705, 0x0a003502, 0x35002812, 0x48245507,   // sr.uk.un_330 tg.mk.un_220  sw.zu.un_640 rw.eo.tt_432 
  0x1c2f21a4, 0x39000208, 0x3500152b, 0x5c130d11,   // jw.su.id_433 da.br.un_430  un.tg.un_980 ne.bh.sa_653 
  0x3308025a, 0x1e1c2f0c, 0x08001304, 0x1d000404,   // da.no.nn_553 su.id.ms_543  et.no.un_320 fi.la.un_320 
  0x5c003604, 0x16000f0c, 0x02000108, 0x09101b08,   // gn.sa.un_320 lv.hr.un_530  en.da.un_430 tr.lt.pl_443 
  // [32c0]
  0x300435a0, 0x25000e07, 0x3b4d580c, 0x4e002e09,   // tg.ru.uz_322 is.eu.un_420  om.aa.so_543 fo.ay.un_440 
  0x62002519, 0x0f522e0c, 0x5c0d13ee, 0x180a01a0,   // eu.kha.un_750 fo.ha.lv_543  bh.ne.sa_422 en.pt.ga_322 
  0x426301a4, 0x20005c04, 0x381b3012, 0x02000412,   // en.sco.co_433 sa.sq.un_320  uz.tr.tk_654 fi.da.un_640 
  0x3d002812, 0x4404155a, 0x304835a4, 0x07170807,   // sd.ku.un_640 un.ru.kk_553  tg.tt.uz_433 uk.sr.bg_432 
  // [32d0]
  0x24005002, 0x113e420c, 0x30003118, 0x40006304,   // fj.eo.un_220 co.rm.ro_543  az.uz.un_740 sco.lb.un_320 
  0x394622a0, 0x581001a4, 0x0a173804, 0x104804a7,   // oc.qu.br_322 en.lt.om_433  tk.sr.mk_332 ru.tt.be_532 
  0x18000e07, 0x21002009, 0x65006b08, 0x3b001214,   // is.ga.un_420 sq.jw.un_440  ceb.gv.un_430 ur.ks.un_660 
  0x303510a7, 0x39002012, 0x3d21120c, 0x2e2d1207,   // be.tg.uz_532 sq.br.un_640  ur.fa.ku_543 hu.sk.fo_432 
  // [32e0]
  0x1a212007, 0x17004404, 0x2c033f0b, 0x65622013,   // sq.jw.tl_432 kk.sr.un_320  af.nl.fy_542 sq.kha.gv_665 
  0x06002704, 0x4b002504, 0x04150705, 0x081515a0,   // gd.de.un_320 eu.mi.un_320  bg.ru.un_330 un.uk.un_320 
  0x18342808, 0x3e000607, 0x37001505, 0x081004a4,   // sd.ps.ar_443 de.rm.un_420  un.ba.un_330 ru.be.uk_433 
  0x13095c12, 0x0d0913a0, 0x1500621b, 0x51004d12,   // sa.hi.bh_654 bh.hi.ne_322  kha.un.un_770 aa.kl.un_640 
  // [32f0]
  0x1100010c, 0x081104a4, 0x0410230c, 0x12212805,   // en.ro.un_530 ru.ro.uk_433  ky.be.ru_543 sd.fa.ur_333 
  0x440704ee, 0x382d1b02, 0x03053eee, 0x342118a7,   // ru.bg.kk_422 tr.sk.tk_222  rm.fr.nl_422 ar.fa.ps_532 
  0x5d12350c, 0x19063f07, 0x420759a4, 0x30205855,   // zu.hu.ss_543 af.de.gl_432  rn.it.co_433 om.sq.uz_442 
  0x211e1b02, 0x0d135c08, 0x2d001602, 0x00005124,   // tr.ms.jw_222 sa.bh.ne_443  hr.sk.un_220 kl.un.un_900 
  // [3300]
  0x013e65a0, 0x03133f04, 0x5d00350c, 0x0c0165a0,   // gv.rm.en_322 af.et.nl_332  zu.ss.un_530 gv.en.sv_322 
  0x044815a4, 0x3e3f0709, 0x0000320f, 0x18212813,   // un.tt.ru_433 it.af.rm_444  bs.un.un_600 sd.fa.ar_665 
  0x2e000e20, 0x5c1c090b, 0x090d1cad, 0x0e0c10ee,   // is.fo.un_850 hi.mr.sa_542  mr.ne.hi_643 lt.sv.is_422 
  0x4c584dec, 0x04034d13, 0x07041508, 0x33003e02,   // aa.om.wo_644 aa.nl.fi_665  un.ru.bg_443 rm.nn.un_220 
  // [3310]
  0x58004c22, 0x1e3f130d, 0x07043cee, 0x2d121b07,   // wo.om.un_870 et.af.ms_554  ug.ru.bg_422 tr.hu.sk_432 
  0x06001012, 0x4d000419, 0x4c4d580c, 0x3e001f1a,   // lt.de.un_640 fi.aa.un_750  om.aa.wo_543 cy.rm.un_760 
  0x04351004, 0x12282155, 0x0f5864ee, 0x4d3b580c,   // be.tg.ru_332 fa.sd.ur_442  lg.om.lv_422 om.so.aa_543 
  0x21003d0b, 0x104408a4, 0x5851155a, 0x584d3b12,   // ku.fa.un_520 uk.kk.be_433  un.kl.om_553 so.aa.om_654 
  // [3320]
  0x2f214c08, 0x1200210e, 0x3800500b, 0x1c130911,   // wo.jw.su_443 fa.ur.un_550  fj.tk.un_520 hi.bh.mr_653 
  0x0f171604, 0x4c004d22, 0x09323107, 0x44081002,   // hr.sr.lv_332 aa.wo.un_870  az.bs.pl_432 be.uk.kk_222 
  0x30070409, 0x21022ea4, 0x154d51ec, 0x46004804,   // ru.bg.uz_444 fo.da.jw_433  kl.aa.un_644 tt.qu.un_320 
  0x0800330c, 0x4d3b510c, 0x08000204, 0x033f040d,   // nn.no.un_530 kl.so.aa_543  da.no.un_320 fi.af.nl_554 
  // [3330]
  0x1f020eee, 0x4d005419, 0x553f2207, 0x563003a0,   // is.da.cy_422 ik.aa.un_750  oc.af.rw_432 nl.uz.mg_322 
  0x0800100e, 0x01001d07, 0x34003e02, 0x095c1cee,   // be.uk.un_550 la.en.un_420  rm.xh.un_220 mr.sa.hi_422 
  0x483823ad, 0x041511a4, 0x153536af, 0x65021d04,   // ky.tk.tt_643 ro.ru.un_430  ab.tg.un_655 la.da.gv_332 
  0x0a1d5302, 0x303c0704, 0x2d0d10ac, 0x52004805,   // ht.la.pt_222 bg.ug.uz_332  lt.cs.sk_632 tt.ha.un_330 
  // [3340]
  0x1221280c, 0x32001707, 0x73305ba4, 0x10001d05,   // sd.fa.ur_543 sr.bs.un_420  sg.uz.ny_433 la.lt.un_330 
  0x3e000108, 0x3412210c, 0x34002109, 0x1c095ca9,   // en.rm.un_430 fa.ur.ps_543  fa.ps.un_440 sa.hi.mr_544 
  0x08041705, 0x04071009, 0x17070a14, 0x00002c1c,   // sr.ru.uk_333 be.bg.ru_444  mk.bg.sr_666 fy.un.un_800 
  0x5c0f1012, 0x63391f08, 0x08003604, 0x24600d11,   // lt.lv.sa_654 cy.br.sco_443  ab.uk.un_320 cs.vo.eo_653 
  // [3350]
  0x686b1da7, 0x00002d24, 0x3848370c, 0x1f186112,   // la.ceb.ig_532 sk.un.un_900  ba.tt.tk_543 za.ga.cy_654 
  0x092d0302, 0x4d06600c, 0x2500040e, 0x39032aa4,   // nl.sk.pl_222 vo.de.aa_543  fi.eu.un_550 mt.nl.br_433 
  0x10006312, 0x126304a4, 0x656302ee, 0x3d001208,   // sco.lt.un_640 fi.sco.hu_433  da.sco.gv_422 ur.ku.un_430 
  0x026351ad, 0x3f4003ec, 0x30211805, 0x694c5308,   // kl.sco.da_643 nl.lb.af_644  ar.fa.uz_333 ht.wo.mfe_443 
  // [3360]
  0x4f6053ec, 0x1b003109, 0x7600252a, 0x1a79620d,   // ht.vo.bi_644 az.tr.un_440  eu.crs.un_970 kha.war.tl_554 
  0x231218ee, 0x06004019, 0x51001a07, 0x2a002b07,   // ar.ur.ky_422 lb.de.un_750  tl.kl.un_420 vi.mt.un_420 
  0x3e031207, 0x3f65630c, 0x213d1811, 0x37000107,   // hu.nl.rm_432 sco.gv.af_543  ar.ku.fa_653 en.st.un_420 
  0xfc04feee, 0x3b6b1307, 0x40003b21, 0x392565ec,   // tlh.fi.zzp_422 et.ceb.so_432  so.lb.un_860 gv.eu.br_644 
  // [3370]
  0x3e4006a0, 0x01006308, 0x303536ec, 0x4d20fe12,   // de.lb.rm_322 sco.en.un_430  ab.tg.uz_644 tlh.sq.aa_654 
  0x03063904, 0x64583b04, 0x234830af, 0x4d6b64a4,   // br.de.nl_332 so.om.lg_332  uz.tt.ky_655 lg.ceb.aa_433 
  0x23003d04, 0x643b4daf, 0x55005908, 0x32000f0c,   // ku.ky.un_320 aa.so.lg_655  rn.rw.un_430 lv.bs.un_530 
  0x080436a0, 0x355d37a0, 0x170407a0, 0x645b3b0b,   // gn.fi.no_322 st.ss.zu_322  bg.ru.sr_322 so.sg.lg_542 
  // [3380]
  0x10001a04, 0x5c0d1c05, 0x044d6308, 0x1f6536a0,   // tl.lt.un_320 mr.ne.sa_333  sco.aa.fi_443 gn.gv.cy_322 
  0x06005507, 0x76396908, 0x00002f15, 0x0252450c,   // rw.de.un_420 mfe.br.crs_443  su.un.un_700 ln.ha.da_543 
  0x4d583b13, 0x35005d1a, 0x4c2f28a4, 0x0715150c,   // so.om.aa_665 ss.zu.un_760  sw.su.wo_433 un.bg.un_530 
  0x45343007, 0x48000c0e, 0x5f4c450c, 0x58643ba4,   // uz.xh.ln_432 sv.tt.un_550  ln.wo.tn_543 so.lg.om_433 
  // [3390]
  0x06005508, 0x4d003b1b, 0x2f214cad, 0x67643b0c,   // rw.de.un_430 so.aa.un_770  wo.jw.su_643 so.lg.ak_543 
  0x644d58a4, 0x1000360e, 0x583b4d5a, 0x644d3b0c,   // om.aa.lg_433 ab.be.un_550  aa.so.om_553 so.aa.lg_543 
  0x450228ad, 0x1a796bad, 0x13480c12, 0x06005502,   // sw.da.ln_643 ceb.war.tl_643  sv.tt.et_654 rw.de.un_220 
  0x42054508, 0x6406550c, 0x0a1507a4, 0x392206ee,   // ln.fr.co_443 rw.de.lg_543  bg.mk.un_430 de.oc.br_422 
  // [33a0]
  0x302f020d, 0x06000405, 0x42000509, 0x060c480c,   // da.su.uz_554 fi.de.un_330  fr.co.un_440 tt.sv.de_543 
  0x021d15a0, 0x0140fca4, 0x073511ee, 0x303508a7,   // un.la.da_322 zzp.lb.en_433  ro.tg.bg_422 uk.tg.uz_532 
  0x5f4a5608, 0x13000c1a, 0x65051f55, 0x48000c14,   // mg.yo.tn_443 sv.et.un_760  cy.fr.gv_442 sv.tt.un_660 
  0x350415a4, 0x0c48380c, 0x34002105, 0x095c0d0d,   // un.ru.tg_433 tk.tt.sv_543  fa.ps.un_330 ne.sa.hi_554 
  // [33b0]
  0x302335a4, 0x0e001109, 0x38233060, 0x6700450e,   // tg.ky.uz_433 ro.is.un_440  uz.ky.tk_664 ln.ak.un_550 
  0x0c000408, 0x044048a7, 0x07000814, 0x4c002b23,   // fi.sv.un_430 tt.lb.fi_532  uk.bg.un_660 vi.wo.un_880 
  0x33000804, 0x130c04a4, 0x48fc6bad, 0x28213409,   // no.nn.un_320 fi.sv.et_433  ceb.zzp.tt_643 ps.fa.sd_444 
  0x060440a0, 0x3b5a6baf, 0x233530ee, 0x49285407,   // lb.fi.de_322 ceb.sm.so_655  uz.tg.ky_422 ik.sw.to_432 
  // [33c0]
  0x62285012, 0x58004e12, 0x1afc79ee, 0x56001e04,   // fj.sw.kha_654 ay.om.un_640  war.zzp.tl_422 ms.mg.un_320 
  0x38002505, 0x12782f0c, 0x6b001a2b, 0x48060ca0,   // mn.tk.un_330 su.ve.hu_543  tl.ceb.un_980 sv.de.tt_322 
  0x2d0d0905, 0x50002020, 0x0a0733ee, 0x1e001c14,   // pl.cs.sk_333 sq.fj.un_850  nn.it.pt_422 id.ms.un_660 
  0x30001704, 0x08170aa7, 0x56054207, 0x0f214504,   // sr.uz.un_320 mk.sr.uk_532  co.fr.mg_432 ln.jw.lv_332 
  // [33d0]
  0x385e4ca0, 0x2000790e, 0x00003c03, 0x5a6b1a0d,   // wo.ts.tk_322 war.sq.un_550  ug.un.un_300 tl.ceb.sm_554 
  0x6a004b19, 0x3f00fc07, 0x4c1e1f12, 0x4f2322a9,   // mi.haw.un_750 zzp.af.un_420  cy.ms.wo_654 oc.ca.bi_544 
  0x46004e14, 0x045f1aa4, 0x04000c0c, 0x5a006a13,   // ay.qu.un_660 tl.tn.fi_433  sv.fi.un_530 haw.sm.un_650 
  0x17000d07, 0x0900020c, 0x18283da7, 0x48040ca4,   // cs.sr.un_420 da.pl.un_530  ku.sd.ar_532 sv.fi.tt_433 
  // [33e0]
  0x070408a7, 0x13040c04, 0x0a170808, 0x12003b22,   // uk.ru.bg_532 sv.fi.et_332  uk.sr.mk_443 ks.ur.un_870 
  0xfc000c08, 0x3e000a02, 0x1f004202, 0x07001d04,   // sv.zzp.un_430 pt.rm.un_220  co.cy.un_220 la.it.un_320 
  0x20001b0c, 0x0d002907, 0x44003502, 0x1300040e,   // tr.sq.un_530 sl.cs.un_420  tg.kk.un_220 fi.et.un_550 
  0x65004008, 0x17001e08, 0x0d130907, 0x15083607,   // lb.gv.un_430 ms.sr.un_430  hi.bh.ne_432 ab.uk.un_432 
  // [33f0]
  0x13004822, 0x2c045107, 0x07190b05, 0x0c00331a,   // tt.et.un_870 kl.fi.fy_432  es.gl.it_333 nn.sv.un_760 
  0x044f51a7, 0x12213d0d, 0x13004905, 0x48000c0d,   // kl.bi.fi_532 ku.fa.ur_554  to.et.un_330 sv.tt.un_540 
  0x2f00130e, 0x183c4404, 0x15171107, 0x5c006a0d,   // et.su.un_550 kk.ug.ar_332  ro.sr.un_432 haw.sa.un_540 
  0x17001008, 0x04104405, 0x48000c02, 0x1c0d5c11,   // be.sr.un_430 kk.be.ru_333  sv.tt.un_220 sa.ne.mr_653 
  
  // [3400]
  0x13000c04, 0x04135105, 0x33080ca4, 0x2f005114,   // sv.et.un_320 kl.et.fi_333  sv.no.nn_433 kl.su.un_660 
  0x041351ec, 0x063848a0, 0x03005105, 0x48000c09,   // kl.et.fi_644 tt.tk.de_322  kl.nl.un_330 sv.tt.un_440 
  0x60003820, 0x1c095ca7, 0x0a301712, 0x0a0735a0,   // tk.vo.un_850 sa.hi.mr_532  sr.uz.mk_654 tg.bg.mk_322 
  0x18284405, 0x27004a07, 0x32291711, 0x13000402,   // kk.sd.ar_333 yo.gd.un_420  sr.sl.bs_653 fi.et.un_220 
  // [3410]
  0x3c23380c, 0x06004809, 0x1500230d, 0x123d21a0,   // tk.ky.ug_543 tt.de.un_440  ky.un.un_540 fa.ku.ur_322 
  0x35153808, 0x46482a07, 0x06130c11, 0x07080407,   // tk.tg.un_430 mt.tt.qu_432  sv.et.de_653 ru.uk.bg_432 
  0x34002114, 0x37004413, 0x16002908, 0x3b21300e,   // fa.ps.un_660 kk.ba.un_650  sl.hr.un_430 uz.fa.ks_555 
  0x10003002, 0x0c130405, 0x38001514, 0x043351a0,   // uz.be.un_220 fi.et.sv_333  un.tk.un_660 kl.nn.fi_322 
  // [3420]
  0x100817a0, 0x32001705, 0x170a44a9, 0x1a5547a9,   // sr.uk.be_322 sr.bs.un_330  kk.mk.sr_544 sn.rw.tl_544 
  0x3b006507, 0x35000804, 0x3f005407, 0x6b027907,   // gv.so.un_420 uk.tg.un_320  ik.af.un_420 war.da.ceb_432 
  0x043b51a7, 0x3f034a04, 0x4c580404, 0x040c13a0,   // kl.so.fi_532 yo.nl.af_332  fi.om.wo_332 et.sv.fi_322 
  0x3b4065a0, 0x3f121b02, 0x400c0612, 0x37005f08,   // gv.lb.so_322 tr.hu.af_222  de.sv.lb_654 tn.st.un_430 
  // [3430]
  0x3b033f08, 0x58003b1a, 0x00002837, 0x6b791aad,   // af.nl.so_443 so.om.un_760  sd.un.un_B00 tl.war.ceb_643 
  0x3b2c4ca0, 0x642e52a0, 0x585451a4, 0x0c1338a9,   // wo.fy.so_322 ha.fo.lg_322  kl.ik.om_433 tk.et.sv_544 
  0x3f004c0c, 0x0b0a18a7, 0x0c000602, 0x65003b05,   // wo.af.un_530 ga.pt.es_532  de.sv.un_220 so.gv.un_330 
  0x484604ad, 0x08070a09, 0x041530a4, 0x2c0302a0,   // fi.qu.tt_643 mk.bg.uk_444  uz.ru.un_430 da.nl.fy_322 
  // [3440]
  0x4d653baf, 0x3f00031a, 0x033f3ba7, 0x133f03a4,   // so.gv.aa_655 nl.af.un_760  so.af.nl_532 nl.af.et_433 
  0x3b544ca4, 0x38001e08, 0x3f03580c, 0x08001207,   // wo.ik.so_433 ms.tk.un_430  om.nl.af_543 hu.no.un_420 
  0x133f5805, 0x122818ac, 0x48003008, 0x381b31a9,   // om.af.et_333 ar.sd.ur_632  uz.tt.un_430 az.tr.tk_544 
  0x373c1504, 0x1306040d, 0x04130cee, 0x0c130417,   // un.ug.ba_332 fi.de.et_554  sv.et.fi_422 fi.et.sv_753 
  // [3450]
  0x69006013, 0x3d3421ee, 0x37004409, 0x0c001304,   // vo.mfe.un_650 fa.ps.ku_422  kk.ba.un_440 et.sv.un_320 
  0x12007614, 0x2500371b, 0x21003414, 0x5b044812,   // crs.hu.un_660 ba.mn.un_770  ps.fa.un_660 tt.fi.sg_654 
  0x3b313007, 0x53697611, 0x651662ee, 0x11443808,   // uz.az.so_432 crs.mfe.ht_653  kha.hr.gv_422 tk.kk.ro_443 
  0x12006013, 0x2c006507, 0x100411ee, 0x233c4460,   // vo.hu.un_650 gv.fy.un_420  ro.ru.be_422 kk.ug.ky_664 
  // [3460]
  0x07081702, 0x35003022, 0x53697612, 0x34003014,   // sr.uk.bg_222 uz.tg.un_870  crs.mfe.ht_654 uz.ps.un_660 
  0x53006919, 0x36002523, 0x16292d07, 0x24003008,   // mfe.ht.un_750 mn.ab.un_880  sk.sl.hr_432 uz.eo.un_430 
  0x0c000608, 0x59551aa9, 0x1e652ca4, 0x35040804,   // de.sv.un_430 tl.rw.rn_544  fy.gv.ms_433 uk.ru.tg_332 
  0x0200130c, 0x10004407, 0x3b003f02, 0x620306a9,   // et.da.un_530 kk.be.un_420  af.so.un_220 de.nl.kha_544 
  // [3470]
  0x36004817, 0x4000fc0c, 0x400b25ad, 0x0e65040c,   // tt.gn.un_730 zzp.lb.un_530  eu.es.lb_643 fi.gv.is_543 
  0x4000040c, 0xfc79010b, 0x2a033ba0, 0x330825ec,   // fi.lb.un_530 en.war.zzp_542  so.nl.mt_322 eu.no.nn_644 
  0x0e1d38ee, 0x234568ee, 0x23003d14, 0x55673804,   // tk.la.is_422 ig.ln.ca_422  ku.ky.un_660 tk.ak.rw_332 
  0x5d00fe18, 0x0e004a0d, 0x02332511, 0x1f360b0c,   // tlh.ss.un_740 yo.is.un_540  eu.nn.da_653 es.gn.cy_543 
  // [3480]
  0x59005520, 0x02681d05, 0x025538a4, 0x0c004021,   // rw.rn.un_850 la.ig.da_333  tk.rw.da_433 lb.sv.un_860 
  0x301228a4, 0x100438ee, 0x480c0404, 0x335d2d04,   // sd.ur.uz_433 tk.fi.lt_422  fi.sv.tt_332 sk.ss.nn_332 
  0x2c65250c, 0x0f00fe07, 0x5700251b, 0x645c385a,   // eu.gv.fy_543 tlh.lv.un_420  eu.na.un_770 tk.sa.lg_553 
  0x480c60a9, 0x170736a0, 0x5800651a, 0x5e2c03a7,   // vo.sv.tt_544 ab.bg.sr_322  gv.om.un_760 nl.fy.ts_532 
  // [3490]
  0x2a002314, 0x0a3c17a4, 0x64553807, 0x29002d02,   // ca.mt.un_660 sr.ug.mk_433  tk.rw.lg_432 sk.sl.un_220 
  0x55005c07, 0x5a004902, 0x48001307, 0x18002822,   // sa.rw.un_420 to.sm.un_220  et.tt.un_420 sd.ar.un_870 
  0x11000108, 0x0a222508, 0x33510807, 0x09003807,   // en.ro.un_430 eu.oc.pt_443  no.kl.nn_432 tk.pl.un_420 
  0x4000fc04, 0x792a4511, 0x06004804, 0x1a000804,   // zzp.lb.un_320 ln.mt.war_653  tt.de.un_320 no.tl.un_320 
  // [34a0]
  0x0e001f12, 0x1713520c, 0xfc001d02, 0x0e5c64a0,   // cy.is.un_640 ha.et.sr_543  la.zzp.un_220 lg.sa.is_322 
  0x0c004005, 0x5c1c0d13, 0x6500130d, 0x2a330804,   // lb.sv.un_330 ne.mr.sa_665  et.gv.un_540 no.nn.mt_332 
  0x73005609, 0x59555ca4, 0x6b005413, 0x64305c0d,   // mg.ny.un_440 sa.rw.rn_433  ik.ceb.un_650 sa.uz.lg_554 
  0x15003513, 0x5c38550d, 0x25001504, 0x6b1a1ea4,   // tg.un.un_650 rw.tk.sa_554  un.eu.un_320 ms.tl.ceb_433 
  // [34b0]
  0x25003e04, 0x2300441b, 0x332a08a9, 0x18003f02,   // rm.eu.un_320 kk.ky.un_770  no.mt.nn_544 af.ga.un_220 
  0x16283408, 0x4c00311b, 0x01003f02, 0x040a17ee,   // xh.sw.hr_443 az.wo.un_770  af.en.un_220 sr.mk.ru_422 
  0x64685da9, 0x15000302, 0x1d155aa0, 0x23303504,   // ss.ig.lg_544 nl.un.un_220  sm.la.un_320 tg.uz.ky_332 
  0x34002d04, 0x6b1a45a9, 0x0410150c, 0x441504a7,   // sk.xh.un_320 ln.tl.ceb_544  un.be.ru_543 ru.kk.un_520 
  // [34c0]
  0x6b1a79ac, 0x25000c04, 0x33080e02, 0x3551340c,   // war.tl.ceb_632 sv.eu.un_320  is.no.nn_222 xh.kl.zu_543 
  0x352734af, 0x0e001304, 0x3c303508, 0x0704150b,   // xh.gd.zu_655 et.is.un_320  tg.uz.ug_443 un.ru.bg_542 
  0x130436ee, 0x12213d12, 0x5e353405, 0x4800150c,   // gn.fi.et_422 ku.fa.ur_654  xh.zu.ts_333 un.tt.un_530 
  0x2500350b, 0x04171504, 0x52005822, 0x1b001607,   // tg.mn.un_520 un.sr.ru_332  om.ha.un_870 hr.tr.un_420 
  // [34d0]
  0x15374808, 0x1c271804, 0x57065c13, 0x2d003508,   // tt.ba.un_443 ga.gd.id_332  sa.de.na_665 zu.sk.un_430 
  0x130f25a4, 0x0413060c, 0x12090307, 0x2a00041b,   // eu.lv.et_433 de.et.fi_543  nl.pl.hu_432 fi.mt.un_770 
  0x1500041a, 0x31001d0c, 0x0a0407a4, 0x16001307,   // ru.un.un_760 la.az.un_530  bg.ru.mk_433 et.hr.un_420 
  0x03063002, 0xfe00460d, 0x0a081013, 0x173216ad,   // uz.de.nl_222 qu.tlh.un_540  be.uk.mk_665 hr.bs.sr_643 
  // [34e0]
  0x40631fa0, 0x2d000402, 0x1008040c, 0x460306ee,   // cy.sco.lb_322 fi.sk.un_220  ru.uk.be_543 de.nl.qu_422 
  0x12060307, 0x38311b02, 0x20171602, 0xfe002902,   // nl.de.hu_432 tr.az.tk_222  hr.sr.sq_222 sl.tlh.un_220 
  0x3d003423, 0x15301707, 0x230b1907, 0x06007908,   // ps.ku.un_880 sr.uz.un_432  gl.es.ca_432 war.de.un_430 
  0x37233810, 0x5149210c, 0x12303d08, 0x1c000913,   // tk.ky.ba_642 jw.to.kl_543  ku.uz.ur_443 hi.mr.un_650 
  // [34f0]
  0x170730a0, 0x0d2a3ba6, 0x320f21a4, 0x13004705,   // uz.bg.sr_322 so.mt.cs_521  jw.lv.bs_433 sn.et.un_330 
  0x2a2f04a0, 0x10080412, 0x281218a4, 0x183d21a4,   // fi.su.mt_322 ru.uk.be_654  ar.ur.sd_433 fa.ku.ar_433 
  0x13001c1a, 0x381b63ee, 0x40001d0c, 0x3f133b07,   // mr.bh.un_760 sco.tr.tk_422  la.lb.un_530 so.et.af_432 
  0x4000120d, 0x1c5d1e07, 0x0000431c, 0x04584d55,   // hu.lb.un_540 ms.ss.id_432  ie.un.un_800 aa.om.fi_442 
  // [3500]
  0x30003c12, 0x4d04580c, 0x0a3538ee, 0x3e074204,   // ug.uz.un_640 om.fi.aa_543  tk.tg.mk_422 co.it.rm_332 
  0x51584d13, 0x581e1c08, 0x4200fe08, 0x1c090dee,   // aa.om.kl_665 id.ms.om_443  tlh.co.un_430 ne.hi.mr_422 
  0x3b2c3fec, 0x393f58a9, 0x12213d07, 0x584d3f11,   // af.fy.so_644 om.af.br_544  ku.fa.ur_432 af.aa.om_653 
  0x4d3f7907, 0x18004019, 0x30003b07, 0x10400faf,   // war.af.aa_432 lb.ga.un_750  so.uz.un_420 lv.lb.lt_655 
  // [3510]
  0x6458510c, 0x5826420c, 0x42002204, 0x63000612,   // kl.om.lg_543 co.ia.om_543  oc.co.un_320 de.sco.un_640 
  0x08023baf, 0x04100705, 0x3b004d22, 0x13095ca0,   // so.da.no_655 bg.be.ru_333  aa.so.un_870 sa.hi.bh_322 
  0x3d18210c, 0x791c4205, 0x262243a4, 0x5100581b,   // fa.ar.ku_543 co.id.war_333  ie.oc.ia_433 om.kl.un_770 
  0x583f51ad, 0x584d51ad, 0x270d0607, 0x2d002b04,   // kl.af.om_643 kl.aa.om_643  de.cs.gd_432 vi.sk.un_320 
  // [3520]
  0x28123ba9, 0x38303c14, 0x3c383008, 0x040a170c,   // ks.ur.sd_544 ug.uz.tk_666  uz.tk.ug_443 sr.mk.ru_543 
  0x073c2355, 0xfc003104, 0x11101513, 0x11006204,   // ky.ug.bg_442 az.zzp.un_320  un.be.ro_665 kha.ro.un_320 
  0x35002513, 0x07000a0e, 0x0b192304, 0x04082307,   // mn.tg.un_650 mk.bg.un_550  ca.gl.es_332 ky.uk.ru_432 
  0x135c0904, 0x15002519, 0x28003413, 0x36374818,   // hi.sa.bh_332 mn.un.un_750  ps.sd.un_650 tt.ba.ab_764 
  // [3530]
  0x213b3d07, 0x3c004814, 0x0a003008, 0x080a0705,   // ku.ks.fa_432 tt.ug.un_660  uz.mk.un_430 bg.mk.uk_333 
  0x3c341808, 0x1b00310d, 0x1b4838a0, 0x1c007308,   // ar.ps.ug_443 az.tr.un_540  tk.tt.tr_322 ny.id.un_430 
  0x600473a4, 0x010306a0, 0x44041008, 0x0d091c55,   // ny.fi.vo_433 de.nl.en_322  be.ru.kk_443 mr.hi.ne_442 
  0x5f13360c, 0x31004602, 0x33000205, 0x1732160b,   // gn.et.tn_543 qu.az.un_220  da.nn.un_330 hr.bs.sr_542 
  // [3540]
  0x49004009, 0x095c0da6, 0x081715a0, 0x30022504,   // lb.to.un_440 ne.sa.hi_521  un.sr.uk_322 eu.da.uz_332 
  0x330803a0, 0x53002804, 0x0400230c, 0x25000914,   // nl.no.nn_322 sw.ht.un_320  ky.ru.un_530 pl.eu.un_660 
  0x30170a08, 0x0400152a, 0x29000208, 0x4b3f640c,   // mk.sr.uz_443 un.ru.un_970  da.sl.un_430 lg.af.mi_543 
  0x2818300c, 0x23003e04, 0x2513360c, 0x38303512,   // uz.ar.sd_543 rm.ca.un_320  gn.et.eu_543 tg.uz.tk_654 
  // [3550]
  0x01103fa4, 0x48004e13, 0x153e01a0, 0x16652907,   // af.lt.en_433 ay.tt.un_650  en.rm.un_322 sl.gv.hr_432 
  0x180663a0, 0x42002e0d, 0x1e000c08, 0x3c353014,   // sco.de.ga_322 fo.co.un_540  sv.ms.un_430 uz.tg.ug_666 
  0x2725020d, 0x311b3814, 0x040a070c, 0x08170a05,   // da.eu.gd_554 tk.tr.az_666  bg.mk.ru_543 mk.sr.uk_333 
  0x122d11a0, 0x303717a0, 0x1e001c1a, 0x1f002004,   // ro.sk.hu_322 sr.ba.uz_322  id.ms.un_760 sq.cy.un_320 
  // [3560]
  0x19286707, 0x13655808, 0x422a0760, 0x25004402,   // ak.sw.gl_432 om.gv.et_443  it.mt.co_664 kk.mn.un_220 
  0x3f001507, 0x151c240c, 0x58050607, 0x343d180c,   // un.af.un_420 eo.id.un_543  de.fr.om_432 ar.ku.ps_543 
  0x3f0e0609, 0x231e1c02, 0x25001521, 0x2e0e18a4,   // de.is.af_444 id.ms.ca_222  un.mn.un_860 ga.is.fo_433 
  0x1a006b08, 0x6b1a30a9, 0x02731a09, 0x2f4b0aa0,   // ceb.tl.un_430 uz.tl.ceb_544  tl.ny.da_444 pt.mi.su_322 
  // [3570]
  0x0800021b, 0x0b7901a9, 0x30150107, 0x083004a9,   // da.no.un_770 en.war.es_544  en.uz.un_420 ru.uz.uk_544 
  0x641a4505, 0x184a2b08, 0x0a000712, 0x21123d12,   // ln.tl.lg_333 vi.yo.ga_443  bg.mk.un_640 ku.ur.fa_654 
  0x6b4c1a12, 0x55453509, 0x0e025d11, 0x2b004a09,   // tl.wo.ceb_654 zu.ln.rw_444  ss.da.is_653 yo.vi.un_440 
  0x6b003608, 0x4c6b7908, 0x304c3b09, 0x00001a1c,   // gn.ceb.un_430 war.ceb.wo_443  so.wo.uz_444 tl.un.un_800 
  // [3580]
  0x0400070e, 0x55353005, 0x550264a4, 0x0e2b4a0c,   // bg.ru.un_550 uz.zu.rw_333  lg.da.rw_433 yo.vi.is_543 
  0x28123d07, 0x33130eee, 0x0600020c, 0x31004834,   // ku.ur.sd_432 is.et.nn_422  da.de.un_530 tt.az.un_A80 
  0x6569fca4, 0x2b004a21, 0x30026ba4, 0x0e00fe12,   // zzp.mfe.gv_433 yo.vi.un_860  ceb.da.uz_433 tlh.is.un_640 
  0x5c1a4c04, 0x3000fe0e, 0x040a17a7, 0x5e005c08,   // wo.tl.sa_332 tlh.uz.un_550  sr.mk.ru_532 sa.ts.un_430 
  // [3590]
  0x305c1a0c, 0x040a17a0, 0x2800180c, 0x02000c13,   // tl.sa.uz_543 sr.mk.ru_322  ar.sd.un_530 sv.da.un_650 
  0x17002307, 0x1834120c, 0x0400360c, 0x0e0208a0,   // ky.sr.un_420 ur.ps.ar_543  ab.ru.un_530 no.da.is_322 
  0xfc2f3ba4, 0x1c0d5c04, 0x2f001a02, 0x48303cac,   // so.su.zzp_433 sa.ne.mr_332  tl.su.un_220 ug.uz.tt_632 
  0x3815440c, 0x13462a0b, 0x2200530c, 0x22005321,   // kk.tk.un_530 mt.qu.et_542  ht.oc.un_530 ht.oc.un_860 
  // [35a0]
  0x22215308, 0x5300221b, 0x17000407, 0x58004d0c,   // ht.jw.oc_443 oc.ht.un_770  ru.sr.un_420 aa.om.un_530 
  0x2153220c, 0x2200210e, 0x21532211, 0x095c0d09,   // oc.ht.jw_543 jw.oc.un_550  oc.ht.jw_653 ne.sa.hi_444 
  0x1f031804, 0x22005323, 0x3d003409, 0x1800270e,   // ga.nl.cy_332 ht.oc.un_880  ps.ku.un_440 gd.ga.un_550 
  0x183c440c, 0x2321530c, 0x24001804, 0x061827af,   // kk.ug.ar_543 ht.jw.ca_543  ga.eo.un_320 gd.ga.de_655 
  // [35b0]
  0x22005319, 0x3f0679a0, 0x5300220e, 0x347635a4,   // ht.oc.un_750 war.de.af_322  oc.ht.un_550 zu.crs.xh_433 
  0x5e001807, 0x0c6008a0, 0x28001205, 0x1a6b790c,   // ga.ts.un_420 no.vo.sv_322  ur.sd.un_330 war.ceb.tl_543 
  0x1800271b, 0x5d475ea4, 0x64004707, 0x0b232708,   // gd.ga.un_770 ts.sn.ss_433  sn.lg.un_420 gd.ca.es_443 
  0x46182704, 0x13002004, 0x3815080c, 0x335606ee,   // gd.ga.qu_332 sq.et.un_320  uk.tk.un_530 de.mg.nn_422 
  // [35c0]
  0x20000602, 0x6b121aa4, 0x3b000907, 0x36584ba4,   // de.sq.un_220 tl.hu.ceb_433  pl.so.un_420 mi.om.gn_433 
  0x292f7907, 0x1f093ba0, 0x054301a4, 0x15000409,   // war.su.sl_432 so.pl.cy_322  en.ie.fr_433 ru.un.un_440 
  0x3b003204, 0x3500150e, 0x06003907, 0x35301113,   // bs.so.un_320 un.tg.un_550  br.de.un_420 ro.uz.tg_665 
  0x47125611, 0x3d00300e, 0x17000802, 0x3d002105,   // mg.hu.sn_653 uz.ku.un_550  uk.sr.un_220 fa.ku.un_330 
  // [35d0]
  0x2c022504, 0x3c1508ad, 0xfc1d200c, 0x43024205,   // eu.da.fy_332 uk.ug.un_630  sq.la.zzp_543 co.da.ie_333 
  0x07694da4, 0x0a421daf, 0x20516307, 0x1c130912,   // aa.mfe.it_433 la.co.pt_655  sco.kl.sq_432 hi.bh.mr_654 
  0x04006511, 0x631d200d, 0x201d65ee, 0x04001b0e,   // gv.fi.un_630 sq.la.sco_554  gv.la.sq_422 tr.fi.un_550 
  0x0d002004, 0x0800040d, 0x1f005805, 0x1d22650b,   // sq.cs.un_320 ru.uk.un_540  om.cy.un_330 gv.oc.la_542 
  // [35e0]
  0x5c1c0d0c, 0x301715ee, 0x2d0d3607, 0x3c00380d,   // ne.mr.sa_543 un.sr.uz_422  gn.cs.sk_432 tk.ug.un_540 
  0x122d0dee, 0x04006504, 0x122821a4, 0x483725a4,   // cs.sk.hu_422 gv.fi.un_320  fa.sd.ur_433 mn.ba.tt_433 
  0x130d09af, 0x12003e04, 0x28002304, 0x234a2207,   // hi.ne.bh_655 rm.hu.un_320  ky.sd.un_320 oc.yo.ca_432 
  0x063f0302, 0x53232209, 0x330806a0, 0x30233508,   // nl.af.de_222 oc.ca.ht_444  de.no.nn_322 tg.ky.uz_443 
  // [35f0]
  0x04440708, 0x0e003613, 0x08040aa0, 0x4a2d0d5a,   // bg.kk.ru_443 gn.is.un_650  mk.ru.uk_322 cs.sk.yo_553 
  0x23303c0d, 0x23002204, 0x30003613, 0x10003823,   // ug.uz.ky_554 oc.ca.un_320  ab.uz.un_650 tk.be.un_880 
  0x40001302, 0x2800340d, 0x241531a4, 0x22002313,   // et.lb.un_220 ps.sd.un_540  az.eo.un_430 ca.oc.un_650 
  0x01156504, 0x192223a7, 0x2300530d, 0x0165fca0,   // gv.en.un_320 ca.oc.gl_532  ht.ca.un_540 zzp.gv.en_322 
  // [3600]
  0x58130408, 0x3f000408, 0xfc006502, 0x181523a0,   // fi.et.om_443 fi.af.un_430  gv.zzp.un_220 ca.ga.un_320 
  0x1a006b21, 0x170a23a0, 0x2d0d0ea0, 0x1800fc07,   // ceb.tl.un_860 ky.mk.sr_322  is.cs.sk_322 zzp.ga.un_420 
  0x173c0814, 0x15001121, 0x081715ee, 0x311b0e07,   // uk.ug.sr_666 ro.un.un_860  un.sr.uk_422 is.tr.az_432 
  0x5804510c, 0x08002802, 0x44070404, 0x11000202,   // kl.fi.om_543 sw.no.un_220  ru.bg.kk_332 da.ro.un_220 
  // [3610]
  0x04fe2a04, 0x24fe38ad, 0x302315a0, 0x12060e02,   // mt.tlh.fi_332 tk.tlh.eo_643  un.ky.uz_322 is.de.hu_222 
  0x1200790e, 0x13120ca0, 0x4a38fe04, 0x084838ad,   // war.hu.un_550 sv.hu.et_322  tlh.tk.yo_332 tk.tt.uk_643 
  0x133e0c04, 0x2e003304, 0x031102ee, 0x090d13af,   // sv.rm.et_332 nn.fo.un_320  da.ro.nl_422 bh.ne.hi_655 
  0x353c305a, 0x300a3507, 0x08001702, 0x0b002809,   // uz.ug.tg_553 tg.mk.uz_432  sr.uk.un_220 sw.es.un_440 
  // [3620]
  0x38120caf, 0x4000200c, 0x5c1c130d, 0x48000c1a,   // sv.hu.tk_655 sq.lb.un_530  bh.mr.sa_554 sv.tt.un_760 
  0x040823a0, 0x38002907, 0x38000404, 0x21001504,   // ky.uk.ru_322 sl.tk.un_420  fi.tk.un_320 un.jw.un_320 
  0x0c00fe08, 0x34302112, 0x23253007, 0x48001d13,   // tlh.sv.un_430 fa.uz.ps_654  uz.mn.ky_432 la.tt.un_650 
  0x483831af, 0x0d003304, 0x06000c1a, 0x18000d04,   // az.tk.tt_655 nn.cs.un_320  sv.de.un_760 cs.ga.un_320 
  // [3630]
  0x38311baf, 0x3d002834, 0x16483207, 0x25000705,   // tr.az.tk_655 sd.ku.un_A80  bs.tt.hr_432 bg.mn.un_330 
  0x48000613, 0x0c124b04, 0x02001313, 0x12633eec,   // de.tt.un_650 mi.hu.sv_332  et.da.un_650 rm.sco.hu_644 
  0x56115aa0, 0x38481b5a, 0x496a1009, 0x02003e0d,   // sm.ro.mg_322 tr.tt.tk_553  lt.haw.to_444 rm.da.un_540 
  0x4800382a, 0x34282305, 0x123848a4, 0x06000c13,   // tk.tt.un_970 ky.sd.ps_333  tt.tk.hu_433 sv.de.un_650 
  // [3640]
  0x12381b6f, 0x1e003608, 0x381b48af, 0x025d5c05,   // tr.tk.hu_886 gn.ms.un_430  tt.tr.tk_655 sa.ss.da_333 
  0x0d091c12, 0x5d13600c, 0x32292d07, 0x0c005d08,   // mr.hi.ne_654 vo.et.ss_543  sk.sl.bs_432 ss.sv.un_430 
  0x0c004808, 0x15441504, 0x3f001b02, 0x53000304,   // tt.sv.un_430 un.kk.un_332  tr.af.un_220 nl.ht.un_320 
  0x121b48af, 0x1d0239a4, 0x4b736aa0, 0x3308fe05,   // tt.tr.hu_655 br.da.la_433  haw.ny.mi_322 tlh.no.nn_333 
  // [3650]
  0x4600fc14, 0x254b100c, 0x50004f1b, 0x12000c05,   // zzp.qu.un_660 lt.mi.eu_543  bi.fj.un_770 sv.hu.un_330 
  0x37455f13, 0x6b6a4b12, 0x122d0d5a, 0x1f001d02,   // tn.ln.st_665 mi.haw.ceb_654  cs.sk.hu_553 la.cy.un_220 
  0x13330809, 0x10003f05, 0x2e000204, 0x04002002,   // no.nn.et_444 af.lt.un_330  da.fo.un_320 sq.fi.un_220 
  0x2338110c, 0x0600570c, 0x1200480e, 0x30352304,   // ro.tk.ky_543 na.de.un_530  tt.hu.un_550 ky.tg.uz_332 
  // [3660]
  0x10170404, 0x15362512, 0x401c2fa0, 0x233c30af,   // ru.sr.be_332 mn.ab.un_654  su.id.lb_322 uz.ug.ky_655 
  0x5e004714, 0x26001d22, 0x2800630d, 0x0a040707,   // sn.ts.un_660 la.ia.un_870  sco.sw.un_540 bg.ru.mk_432 
  0x5556370c, 0x18003d09, 0x02000607, 0x1511380e,   // st.mg.rw_543 ku.ar.un_440  de.da.un_420 tk.ro.un_555 
  0x483508ee, 0x36002312, 0x1500fe04, 0x2e000202,   // uk.tg.tt_422 ky.ab.un_640  tlh.un.un_320 da.fo.un_220 
  // [3670]
  0xfc1820a7, 0x48001008, 0x40000c08, 0x46003204,   // sq.ga.zzp_532 be.tt.un_430  sv.lb.un_430 bs.qu.un_320 
  0x65001204, 0x120e620c, 0x09003608, 0x40002704,   // hu.gv.un_320 kha.is.hu_543  gn.pl.un_430 gd.lb.un_320 
  0x0704110c, 0x405706a7, 0x00001324, 0x125706ad,   // ro.ru.bg_543 de.na.lb_532  bh.un.un_900 de.na.hu_643 
  0x2a656307, 0x2a001207, 0x10000f22, 0x40005713,   // sco.gv.mt_432 hu.mt.un_420  lv.lt.un_870 na.lb.un_650 
  // [3680]
  0x23361913, 0x22006307, 0x39126255, 0x0e000c0b,   // gl.gn.ca_665 sco.oc.un_420  kha.hu.br_442 sv.is.un_520 
  0x3e006019, 0x0262060c, 0x4b060c0c, 0x3d001209,   // vo.rm.un_750 de.kha.da_543  sv.de.mi_543 ur.ku.un_440 
  0x08fc2304, 0x1f003f0e, 0x12330e55, 0x394006ad,   // ca.zzp.no_332 af.cy.un_550  is.nn.hu_442 de.lb.br_643 
  0x2d001209, 0x2c033f0d, 0x07170a0c, 0x12065755,   // hu.sk.un_440 af.nl.fy_554  mk.sr.bg_543 na.de.hu_442 
  // [3690]
  0x12000602, 0x101240ad, 0x07003f04, 0x5e353f09,   // de.hu.un_220 lb.hu.lt_643  af.it.un_320 af.zu.ts_444 
  0x12006212, 0x2834120c, 0x2f621a0d, 0x23003613,   // kha.hu.un_640 ur.ps.sd_543  tl.kha.su_554 ab.ky.un_650 
  0x202911a0, 0x64004c04, 0x13000c07, 0x03001f02,   // ro.sl.sq_322 wo.lg.un_320  sv.et.un_420 cy.nl.un_220 
  0x23040704, 0x33080cee, 0x24000f02, 0x12283da4,   // bg.ru.ky_332 sv.no.nn_422  lv.eo.un_220 ku.sd.ur_433 
  // [36a0]
  0x233648af, 0x35000102, 0x04081112, 0x34000905,   // tt.ab.ky_655 en.zu.un_220  ro.uk.ru_654 pl.xh.un_330 
  0x3c363805, 0x374830ad, 0x10001107, 0x5e002d09,   // tk.ab.ug_333 uz.tt.ba_643  ro.be.un_420 sk.ts.un_440 
  0x0c031355, 0x0e3b5807, 0x2d0d090d, 0x2d4d12ec,   // et.nl.sv_442 om.so.is_432  pl.cs.sk_554 hu.aa.sk_644 
  0x211828a7, 0x44151104, 0x79384808, 0x1f00030d,   // sd.ar.fa_532 ro.kk.un_320  tt.tk.war_443 nl.cy.un_540 
  // [36b0]
  0x380e31b3, 0x37000704, 0x0c000e04, 0x12004821,   // az.is.tk_743 bg.ba.un_320  is.sv.un_320 tt.hu.un_860 
  0x341812ee, 0x38311b13, 0x04101707, 0x58003b13,   // ur.ar.ps_422 tr.az.tk_665  sr.be.ru_432 so.om.un_650 
  0x583b4c13, 0x2d0d0e02, 0x34003b0c, 0x38480c0c,   // wo.so.om_665 is.cs.sk_222  ks.ps.un_530 sv.tt.tk_543 
  0x20001e21, 0x3d002119, 0x04004814, 0x12000c13,   // am.ti.un_860 fa.ku.un_750  tt.fi.un_660 sv.hu.un_650 
  // [36c0]
  0x0e000c14, 0x213430a4, 0x0e004809, 0x5c091ca9,   // sv.is.un_660 uz.ps.fa_433  tt.is.un_440 mr.hi.sa_544 
  0x04000c17, 0x31003821, 0x3b00580e, 0x5c0d1c07,   // sv.fi.un_730 tk.az.un_860  om.so.un_550 mr.ne.sa_432 
  0x04151011, 0x585451ad, 0x040807a0, 0x17003508,   // be.ru.un_630 kl.ik.om_643  bg.uk.ru_322 tg.sr.un_430 
  0x231715ee, 0x2536150c, 0x3c002107, 0x48374402,   // un.sr.ky_422 un.ab.mn_543  fa.ug.un_420 kk.ba.tt_222 
  // [36d0]
  0x44004821, 0x0e2d0d55, 0x1c5c09a9, 0x3e004802,   // tt.kk.un_860 cs.sk.is_442  hi.sa.mr_544 tt.rm.un_220 
  0x15001a02, 0x0e000c08, 0x39003804, 0x1e002018,   // tl.un.un_220 sv.is.un_430  tk.br.un_320 ti.am.un_740 
  0x38003619, 0x3800480c, 0x3000150c, 0x39001f07,   // ab.tk.un_750 tt.tk.un_530  un.uz.un_530 cy.br.un_420 
  0x64001d07, 0x10001702, 0x654c6e0d, 0x2a002804,   // la.lg.un_420 sr.be.un_220  hmn.wo.gv_554 sw.mt.un_320 
  // [36e0]
  0x2e000205, 0x4800380b, 0x192d0d08, 0x032a39a4,   // da.fo.un_330 tk.tt.un_520  cs.sk.gl_443 br.mt.nl_433 
  0x0e001908, 0x11004305, 0x533b58ee, 0x2812180c,   // gl.is.un_430 ie.ro.un_330  om.so.ht_422 ar.ur.sd_543 
  0x4b001204, 0x341828a9, 0x1d00670b, 0x3b006e12,   // hu.mi.un_320 sd.ar.ps_544  ak.la.un_520 hmn.so.un_640 
  0x5a4b1d08, 0x0000191c, 0x220627a4, 0x5d5f250c,   // la.mi.sm_443 gl.un.un_800  gd.de.oc_433 eu.tn.ss_543 
  // [36f0]
  0x1700070e, 0xfe000605, 0x13006e22, 0x2a004011,   // bg.sr.un_550 de.tlh.un_330  hmn.et.un_870 lb.mt.un_630 
  0x27001804, 0x18270107, 0x0e000c1a, 0x3f1f6207,   // ga.gd.un_320 en.gd.ga_432  sv.is.un_760 kha.cy.af_432 
  0x1827060b, 0x400646ee, 0x383112b2, 0x137325af,   // de.gd.ga_542 qu.de.lb_422  hu.az.tk_732 eu.ny.et_655 
  0x09000305, 0x376e5e0c, 0x34122807, 0x13000204,   // nl.pl.un_330 ts.hmn.st_543  sd.ur.ps_432 da.et.un_320 
  // [3700]
  0x580430a4, 0x2a00421a, 0x22001807, 0x5d0f1011,   // uz.fi.om_433 co.mt.un_760  ga.oc.un_420 lt.lv.ss_653 
  0x071015a4, 0x060c0e05, 0x42003302, 0x30653107,   // un.be.bg_433 is.sv.de_333  nn.co.un_220 az.gv.uz_432 
  0x1f1142a9, 0x09182711, 0x38002e22, 0x25fc3711,   // co.ro.cy_544 gd.ga.pl_653  fo.tk.un_870 st.zzp.eu_653 
  0x2a130907, 0x29003b02, 0x0e1248eb, 0x083f2c07,   // pl.et.mt_432 so.sl.un_220  tt.hu.is_662 fy.af.no_432 
  // [3710]
  0x13020d0c, 0x090d5c08, 0x38001b0e, 0x06003807,   // cs.da.et_543 sa.ne.hi_443  tr.tk.un_550 tk.de.un_420 
  0x06000c0e, 0x4600090e, 0x12480ca7, 0x040748ee,   // sv.de.un_550 pl.qu.un_550  sv.tt.hu_532 tt.bg.ru_422 
  0x2c023f13, 0x24005c04, 0x2b000302, 0x1f002722,   // af.da.fy_665 sa.eo.un_320  nl.vi.un_220 gd.cy.un_870 
  0x48130c11, 0x5c0c08ee, 0x38003102, 0x292413ad,   // sv.et.tt_653 no.sv.sa_422  az.tk.un_220 et.eo.sl_643 
  // [3720]
  0x0c000e07, 0x06600cc5, 0x2c006505, 0x1a652c12,   // is.sv.un_420 sv.vo.de_976  gv.fy.un_330 fy.gv.tl_654 
  0x381b12bc, 0x173802ac, 0x3f00621a, 0x0f000207,   // hu.tr.tk_865 da.tk.sr_632  kha.af.un_760 da.lv.un_420 
  0x25003713, 0x291302ee, 0x173035a4, 0x0c2065ee,   // ba.mn.un_650 da.et.sl_422  tg.uz.sr_433 gv.sq.sv_422 
  0x38004807, 0x2c1f3f13, 0x38002105, 0x1f006505,   // tt.tk.un_420 af.cy.fy_665  jw.tk.un_330 gv.cy.un_330 
  // [3730]
  0x0a1536ec, 0x4a00211a, 0x0e003819, 0x1700fe04,   // ab.mk.un_640 jw.yo.un_760  tk.is.un_750 tlh.sr.un_320 
  0x65001702, 0x0f001b04, 0x4a1c21ee, 0x3d2112a4,   // sr.gv.un_220 tr.lv.un_320  jw.id.yo_422 ur.fa.ku_433 
  0x18002812, 0x0a041004, 0x7900210d, 0x28343da0,   // sd.ar.un_640 be.ru.mk_332  jw.war.un_540 ku.ps.sd_322 
  0x213d3b07, 0x381b3112, 0x38001013, 0x51040507,   // ks.ku.fa_432 az.tr.tk_654  lt.tk.un_650 fr.fi.kl_432 
  // [3740]
  0x44002307, 0x0e023f07, 0x3d123405, 0x1c002104,   // ky.kk.un_420 af.da.is_432  ps.ur.ku_333 jw.id.un_320 
  0x0906380c, 0x04060eee, 0x38310660, 0x2d100d12,   // tk.de.pl_543 is.de.fi_422  de.az.tk_664 cs.lt.sk_654 
  0x3800100e, 0x1238100b, 0x3031fea7, 0x10003c0d,   // lt.tk.un_550 lt.tk.hu_542  tlh.az.uz_532 ug.be.un_540 
  0x18001214, 0x38001008, 0x30001508, 0x63001208,   // ur.ar.un_660 lt.tk.un_430  un.uz.un_430 hu.sco.un_430 
  // [3750]
  0x010a1d0b, 0x35070a05, 0x08151704, 0x24001802,   // la.pt.en_542 mk.bg.tg_333  sr.uk.un_320 ga.eo.un_220 
  0x37005804, 0x30233c0d, 0x0a002304, 0x430301ee,   // om.st.un_320 ug.ky.uz_554  ky.mk.un_320 en.nl.ie_422 
  0x35345d13, 0x2c006307, 0x6b631d07, 0x1d634304,   // ss.xh.zu_665 sco.fy.un_420  la.sco.ceb_432 ie.sco.la_332 
  0x0d0913a4, 0x63001d19, 0x3734feaf, 0x432322a4,   // bh.hi.ne_433 la.sco.un_750  tlh.xh.st_655 oc.ca.ie_433 
  // [3760]
  0x5e3701a0, 0x60016308, 0x3f032caf, 0x254423ee,   // en.st.ts_322 sco.en.vo_443  fy.nl.af_655 ky.kk.mn_422 
  0x2a001b0e, 0x1234300c, 0x30080209, 0x4448370e,   // tr.mt.un_550 uz.ps.ur_543  da.no.uz_444 ba.tt.kk_555 
  0x25600208, 0x44003c08, 0x11002c08, 0xfa353408,   // da.vo.eu_443 ug.kk.un_430  fy.ro.un_430 xh.zu.nr_443 
  0x1b00fe07, 0x3000480d, 0x02000c02, 0x33007904,   // tlh.tr.un_420 tt.uz.un_540  sv.da.un_220 war.nn.un_320 
  // [3770]
  0x1a1238ad, 0x092b23ee, 0x0c2d0d0b, 0x3c3038af,   // tk.hu.tl_643 ca.vi.pl_422  cs.sk.sv_542 tk.uz.ug_655 
  0x2e000208, 0x3c302312, 0x154835a4, 0x15380107,   // da.fo.un_430 ky.uz.ug_654  tg.tt.un_433 en.tk.un_432 
  0x51000208, 0x212812ee, 0x251203a7, 0x4800300e,   // da.kl.un_430 ur.sd.fa_422  nl.hu.eu_532 uz.tt.un_550 
  0x09001f08, 0x1900fe0e, 0x070a17a7, 0x60031ca0,   // cy.pl.un_430 tlh.gl.un_550  sr.mk.bg_532 id.nl.vo_322 
  // [3780]
  0x0f002b08, 0x03580202, 0x30082555, 0x12021a04,   // vi.lv.un_430 da.om.nl_222  mn.uk.uz_442 tl.da.hu_332 
  0x24130308, 0x0c3567a9, 0x37003c1b, 0x25442307,   // nl.et.eo_443 ak.zu.sv_544  ug.ba.un_770 ky.kk.mn_432 
  0x353d30ee, 0x55355d05, 0x58fc0405, 0x34003b04,   // uz.ku.tg_422 ss.zu.rw_333  fi.zzp.om_333 so.xh.un_320 
  0x63650107, 0x54004d13, 0x40006508, 0x394064a0,   // en.gv.sco_432 aa.ik.un_650  gv.lb.un_430 lg.lb.br_322 
  // [3790]
  0x4063010c, 0x4a2b0ead, 0x31003009, 0x09787305,   // en.sco.lb_543 is.vi.yo_643  uz.az.un_440 ny.ve.pl_333 
  0x233044af, 0x630a6508, 0x73000918, 0x097847ad,   // kk.uz.ky_655 gv.pt.sco_443  pl.ny.un_740 sn.ve.pl_643 
  0x65033faf, 0x2d191008, 0x63003f04, 0x532d090c,   // af.nl.gv_655 lt.gl.sk_443  af.sco.un_320 pl.sk.ht_543 
  0x2700181a, 0x34003507, 0x4000580d, 0x47095d12,   // ga.gd.un_760 zu.xh.un_420  om.lb.un_540 ss.pl.sn_654 
  // [37a0]
  0x1d4207a0, 0x07303ca4, 0x382330a4, 0x475d73a4,   // it.co.la_322 ug.uz.bg_433  uz.ky.tk_433 ny.ss.sn_433 
  0x08003812, 0x420918a0, 0x05004613, 0x23000507,   // tk.uk.un_640 ga.pl.co_322  qu.fr.un_650 fr.ca.un_420 
  0x2700180e, 0x1d2d6204, 0x0900470c, 0x071708a4,   // ga.gd.un_550 kha.sk.la_332  sn.pl.un_530 uk.sr.bg_433 
  0x09282d09, 0x2d4709af, 0x73004713, 0x2d2207a0,   // sk.sw.pl_444 pl.sn.sk_655  sn.ny.un_650 it.oc.sk_322 
  // [37b0]
  0x1f000907, 0x1d252da0, 0x65001808, 0xfc062707,   // pl.cy.un_420 sk.eu.la_322  ga.gv.un_430 gd.de.zzp_432 
  0x3f001819, 0x12002d05, 0x0000761c, 0x0a15350c,   // ga.af.un_750 sk.hu.un_330  crs.un.un_800 tg.mk.un_530 
  0x300835a4, 0x38001212, 0x1800210b, 0x0d091c04,   // tg.uk.uz_433 hu.tk.un_640  fa.ar.un_520 mr.hi.ne_332 
  0x0f002808, 0x211e1c0d, 0x1b003819, 0x28000207,   // sw.lv.un_430 id.ms.jw_554  tk.tr.un_750 da.sw.un_420 
  // [37c0]
  0x4e284b0c, 0x68595508, 0x3e4269ac, 0x12001e11,   // mi.sw.ay_543 rw.rn.ig_443  mfe.co.rm_632 ms.hu.un_630 
  0x50006708, 0x0200fe04, 0x28026804, 0x2559550d,   // ak.fj.un_430 tlh.da.un_320  ig.da.sw_332 rw.rn.eu_554 
  0x09000d11, 0x595542a9, 0x1d004202, 0x51504602,   // ne.hi.un_630 co.rw.rn_544  co.la.un_220 qu.fj.kl_222 
  0x090d1c08, 0x64001302, 0x4f001e0d, 0x34005804,   // mr.ne.hi_443 et.lg.un_220  ms.bi.un_540 om.xh.un_320 
  // [37d0]
  0x130d0908, 0x1b0256ec, 0x02285560, 0x595568a4,   // hi.ne.bh_443 mg.da.tr_644  rw.sw.da_664 ig.rw.rn_433 
  0x361b4e5a, 0x7930020d, 0x6427fea4, 0x28123b13,   // ay.tr.gn_553 da.uz.war_554  tlh.gd.lg_433 ks.ur.sd_665 
  0x0afc0208, 0x5e005002, 0x6700681a, 0x680f4b0c,   // da.zzp.pt_443 fj.ts.un_220  ig.ak.un_760 mi.lv.ig_543 
  0x214831a4, 0x562502a0, 0x1255455a, 0x2d1d2655,   // az.tt.jw_433 da.eu.mg_322  ln.rw.hu_553 ia.la.sk_442 
  // [37e0]
  0x3e0f1d0c, 0x6800362b, 0x50004e11, 0x5c000d19,   // la.lv.rm_543 gn.ig.un_980  ay.fj.un_630 ne.sa.un_750 
  0x2d0d5205, 0x1a59550d, 0x0e2e020c, 0x13004204,   // ha.cs.sk_333 rw.rn.tl_554  da.fo.is_543 co.et.un_320 
  0xfa005508, 0x0c000407, 0x55353408, 0x59551caf,   // rw.nr.un_430 fi.sv.un_420  xh.zu.rw_443 id.rw.rn_655 
  0x795548af, 0x041517a9, 0x1c461e0c, 0x46315812,   // tt.rw.war_655 sr.ru.un_540  ms.qu.id_543 om.az.qu_654 
  // [37f0]
  0x47503107, 0x381d280c, 0x693b51a9, 0x0d00090d,   // az.fj.sn_432 sw.la.tk_543  kl.so.mfe_544 hi.ne.un_540 
  0x21343008, 0x1a3b58af, 0x025d69ad, 0x21301207,   // uz.ps.fa_443 om.so.tl_655  mfe.ss.da_643 ur.uz.fa_432 
  0x44003c34, 0x0a442312, 0x23103012, 0x04081507,   // ug.kk.un_A80 ky.kk.mk_654  uz.be.ky_654 un.uk.ru_432 
  0x6500541a, 0x150a44ad, 0x51006512, 0x0a3525a0,   // ik.gv.un_760 kk.mk.un_643  gv.kl.un_640 mn.tg.mk_322 
  
  // [3800]
  0x08044855, 0x18005304, 0x15002509, 0x1a636512,   // tt.ru.uk_442 ht.ga.un_320  mn.un.un_440 gv.sco.tl_654 
  0x0a040708, 0x51006508, 0x1c090dec, 0x67001d0e,   // bg.ru.mk_443 gv.kl.un_430  ne.hi.mr_644 la.ak.un_550 
  0x30000814, 0x5100020b, 0x23071008, 0x7347520d,   // uk.uz.un_660 da.kl.un_520  be.bg.ky_443 ha.sn.ny_554 
  0x21251ea0, 0x4b6a470c, 0x12303404, 0x4b135fa4,   // ms.eu.jw_322 sn.haw.mi_543  ps.uz.ur_332 tn.et.mi_433 
  // [3810]
  0x494b470c, 0x5f005508, 0x1300090b, 0x39002304,   // sn.mi.to_543 rw.tn.un_430  hi.bh.un_520 ca.br.un_320 
  0x42005808, 0x26001d13, 0x391b310c, 0x12205508,   // om.co.un_430 la.ia.un_650  az.tr.br_543 rw.sq.hu_443 
  0x3c234455, 0x1504150d, 0x22002305, 0x02674ba4,   // kk.ky.ug_442 un.ru.un_554  ca.oc.un_330 mi.ak.da_433 
  0x1a4b255a, 0x343d2805, 0x3f001608, 0x671045a9,   // eu.mi.tl_553 sd.ku.ps_333  hr.af.un_430 ln.lt.ak_544 
  // [3820]
  0x3b002607, 0x3d211212, 0x190b0a02, 0x25131d04,   // ia.so.un_420 ur.fa.ku_654  pt.es.gl_222 la.et.eu_332 
  0x73353413, 0x1d1b390c, 0x153823a4, 0x13005712,   // xh.zu.ny_665 br.tr.la_543  ky.tk.un_433 na.et.un_640 
  0x20244002, 0x343d30a7, 0x78000f22, 0x133f1155,   // lb.eo.sq_222 uz.ku.ps_532  lv.ve.un_870 ro.af.et_442 
  0x03004002, 0x20000405, 0x0f2d43a0, 0x6900761a,   // lb.nl.un_220 fi.sq.un_330  ie.sk.lv_322 crs.mfe.un_760 
  // [3830]
  0x651d0e02, 0x2d0d29a4, 0x3d003c13, 0x21183004,   // is.la.gv_222 sl.cs.sk_433  ug.ku.un_650 uz.ar.fa_332 
  0x201d63a0, 0x183c3da7, 0x03006012, 0x12213dad,   // sco.la.sq_322 ku.ug.ar_532  vo.nl.un_640 ku.fa.ur_643 
  0x234437a4, 0x06033f11, 0x033f330b, 0x09000319,   // ba.kk.ky_433 af.nl.de_653  nn.af.nl_542 nl.pl.un_750 
  0x584d1355, 0x02330804, 0x25233c07, 0x0c006402,   // et.aa.om_442 no.nn.da_332  ug.ky.mn_432 lg.sv.un_220 
  // [3840]
  0x1710110c, 0x120e2d12, 0x651d4355, 0x65130407,   // ro.be.sr_543 sk.is.hu_654  ie.la.gv_442 fi.et.gv_432 
  0x06002f04, 0x303c3855, 0x2f121007, 0x12002f04,   // su.de.un_320 tk.ug.uz_442  lt.hu.su_432 su.hu.un_320 
  0x1c122f07, 0x07170a05, 0x3d30120c, 0x3418280b,   // su.hu.id_432 mk.sr.bg_333  ur.uz.ku_543 sd.ar.ps_542 
  0x1c2f1202, 0x4200240e, 0x4c006408, 0x0a1735a0,   // hu.su.id_222 eo.co.un_550  lg.wo.un_430 tg.sr.mk_322 
  // [3850]
  0x1c00092c, 0x29000402, 0x131c0da4, 0x3e1d26ec,   // hi.mr.un_990 fi.sl.un_220  cs.id.et_433 ia.la.rm_644 
  0x2a001204, 0x122f1e07, 0x0a000719, 0x0b003334,   // hu.mt.un_320 ms.su.hu_432  bg.mk.un_750 as.bn.un_A80 
  0x16002d04, 0x1300042b, 0x1a536ba4, 0x09005c1a,   // sk.hr.un_320 fi.et.un_980  ceb.ht.tl_433 sa.hi.un_760 
  0x3e070c0d, 0x1100430d, 0x484438a4, 0x423e2e13,   // sv.it.rm_554 ie.ro.un_540  tk.kk.tt_433 fo.rm.co_665 
  // [3860]
  0x07353004, 0x480423ee, 0x305c6404, 0x44480404,   // uz.tg.bg_332 ky.ru.tt_422  lg.sa.uz_332 ru.tt.kk_332 
  0x1b001e04, 0x1d002008, 0x07040802, 0x4d461d08,   // ms.tr.un_320 sq.la.un_430  uk.ru.bg_222 la.qu.aa_443 
  0x122128a0, 0x070a110c, 0x0a17080e, 0x215c1aa0,   // sd.fa.ur_322 ro.mk.bg_543  uk.sr.mk_555 tl.sa.jw_322 
  0x4625180b, 0x070810a7, 0x18002313, 0x1700100e,   // ga.eu.qu_542 be.uk.bg_532  ky.ar.un_650 be.sr.un_550 
  // [3870]
  0x5400461b, 0x46261d04, 0x1000170c, 0x0a002d04,   // qu.ik.un_770 la.ia.qu_332  sr.be.un_530 sk.pt.un_320 
  0x0d091cec, 0x120efca0, 0x0a422513, 0x3b005102,   // mr.hi.ne_644 zzp.is.hu_322  eu.co.pt_665 kl.so.un_220 
  0x48230508, 0x3200160c, 0x56000504, 0x27001823,   // fr.ca.tt_443 hr.bs.un_530  fr.mg.un_320 ga.gd.un_880 
  0x3900251a, 0x0c2248a0, 0x465c73a0, 0x0600390d,   // eu.br.un_760 tt.oc.sv_322  ny.sa.qu_322 br.de.un_540 
  // [3880]
  0x3b275812, 0x32001708, 0x23073055, 0x29002d08,   // om.gd.so_654 sr.bs.un_430  uz.bg.ky_442 sk.sl.un_430 
  0x29382da4, 0x0d1c09ee, 0x3421300d, 0x35001a02,   // sk.tk.sl_433 hi.mr.ne_422  uz.fa.ps_554 tl.zu.un_220 
  0x27fe68ad, 0x46000407, 0x3e002904, 0x2223050c,   // ig.tlh.gd_643 fi.qu.un_420  sl.rm.un_320 fr.ca.oc_543 
  0x34271812, 0x342118a4, 0x10002908, 0x022846ad,   // ga.gd.xh_654 ar.fa.ps_433  sl.lt.un_430 qu.sw.da_643 
  // [3890]
  0x29462a07, 0x23040808, 0x25004d1b, 0x0a000802,   // mt.qu.sl_432 uk.ru.ky_443  aa.eu.un_770 uk.mk.un_220 
  0x13000c0d, 0x10005d05, 0x2d002914, 0x2134280e,   // sv.et.un_540 ss.lt.un_330  sl.sk.un_660 sd.ps.fa_555 
  0x731827ad, 0x33020c05, 0xfe5e5fec, 0x5c000602,   // gd.ga.ny_643 sv.da.nn_333  tn.ts.tlh_644 de.sa.un_220 
  0x2d0d29ec, 0x46025807, 0x2d0d29af, 0x100704a4,   // sl.cs.sk_644 om.da.qu_432  sl.cs.sk_655 ru.bg.be_433 
  // [38a0]
  0x0d2d290d, 0x2d29240c, 0x2d002919, 0x183d3455,   // sl.sk.cs_554 eo.sl.sk_543  sl.sk.un_750 ps.ku.ar_442 
  0x0d292da7, 0x09001005, 0x1800fc04, 0x080a17af,   // sk.sl.cs_532 lt.pl.un_330  zzp.ga.un_320 sr.mk.uk_655 
  0x040e1255, 0x0810440c, 0x02000c08, 0x1500230e,   // hu.is.fi_442 kk.be.uk_543  sv.da.un_430 ky.un.un_550 
  0x1730350c, 0x35002509, 0x524f5bee, 0x4b005c04,   // tg.uz.sr_543 mn.tg.un_440  sg.bi.ha_422 sa.mi.un_320 
  // [38b0]
  0x1c0d13a4, 0x21233007, 0x100715a7, 0x184a1207,   // bh.ne.mr_433 uz.ky.fa_432  un.bg.be_532 hu.yo.ga_432 
  0x35003011, 0x3d003c0d, 0x071710a4, 0x2100280d,   // uz.tg.un_630 ug.ku.un_540  be.sr.bg_433 sd.fa.un_540 
  0x30482305, 0x460b40a4, 0x2f1e1ca0, 0x1632175a,   // ky.tt.uz_333 lb.es.qu_433  id.ms.su_322 sr.bs.hr_553 
  0x00006906, 0x123d3b55, 0x48004408, 0x09001c19,   // mfe.un.un_400 ks.ku.ur_442  kk.tt.un_430 mr.hi.un_750 
  // [38c0]
  0x104844a0, 0x395605a7, 0x23443812, 0x026705a4,   // kk.tt.be_322 fr.mg.br_532  tk.kk.ky_654 fr.ak.da_433 
  0x0c5f4a5a, 0x3e0205ee, 0x0900fe07, 0x43052309,   // yo.tn.sv_553 fr.da.rm_422  tlh.pl.un_420 ca.fr.ie_444 
  0x300a36a4, 0x3f036307, 0x44304804, 0x30000a0d,   // ab.mk.uz_433 sco.nl.af_432  tt.uz.kk_332 mk.uz.un_540 
  0x2f5f4a0c, 0x4b251355, 0x48233813, 0x1711100c,   // yo.tn.su_543 et.eu.mi_442  tk.ky.tt_665 be.ro.sr_543 
  // [38d0]
  0x15153807, 0x73004721, 0x13000907, 0x730f78a4,   // tk.un.un_420 sn.ny.un_860  hi.bh.un_420 ve.lv.ny_433 
  0x231708a0, 0x033f01a4, 0x443015ee, 0x47007821,   // uk.sr.ky_322 en.af.nl_433  un.uz.kk_422 ve.sn.un_860 
  0x48303c09, 0x09467308, 0x1b093bad, 0x095c1cad,   // ug.uz.tt_444 ny.qu.pl_443  so.pl.tr_643 mr.sa.hi_643 
  0x5c2f6a0c, 0x104773a0, 0x373056ad, 0x2d460908,   // haw.su.sa_543 ny.sn.lt_322  mg.uz.st_643 pl.qu.sk_443 
  // [38e0]
  0x04154804, 0xfc000404, 0x02566aa9, 0x381030a0,   // tt.ru.un_320 fi.zzp.un_320  haw.mg.da_544 uz.lt.tk_322 
  0x5c30580c, 0x4b00370e, 0x09021013, 0x0a3c07a4,   // om.uz.sa_543 st.mi.un_550  lt.da.pl_665 bg.ug.mk_433 
  0x1e473508, 0x64005904, 0x21005608, 0x44002319,   // zu.sn.ms_443 rn.lg.un_320  mg.jw.un_430 ky.kk.un_750 
  0x1000091a, 0x53004702, 0x5c6b79ee, 0x03094702,   // pl.lt.un_760 sn.ht.un_220  war.ceb.sa_422 sn.pl.nl_222 
  // [38f0]
  0x2f000220, 0x16fc090c, 0x21000904, 0x353473a9,   // da.su.un_850 pl.zzp.hr_543  pl.jw.un_320 ny.xh.zu_544 
  0x47007314, 0x315d7304, 0x030210ee, 0x53355d0d,   // ny.sn.un_660 ny.ss.az_332  lt.da.nl_422 ss.zu.ht_554 
  0x1e1d02a0, 0x20005604, 0x2d1247a6, 0x35344aa4,   // da.la.ms_322 mg.sq.un_320  sn.hu.sk_521 yo.xh.zu_433 
  0x3b00590c, 0x0f002f04, 0x2e100207, 0x477309ec,   // rn.so.un_530 su.lv.un_320  da.lt.fo_432 pl.ny.sn_644 
  // [3900]
  0x5d00472a, 0x3b005219, 0x6400120d, 0x2d000908,   // sn.ss.un_970 ha.so.un_750  hu.lg.un_540 pl.sk.un_430 
  0x28355907, 0x31643005, 0x30006b0c, 0x53003005,   // rn.zu.sw_432 uz.lg.az_333  ceb.uz.un_530 uz.ht.un_330 
  0x23005504, 0x04560aa7, 0x3b644da7, 0x1c1a790c,   // rw.ca.un_320 pt.mg.fi_532  aa.lg.so_532 war.tl.id_543 
  0x46524e0c, 0x56021a0c, 0x08041702, 0x52094607,   // ay.ha.qu_543 tl.da.mg_543  sr.ru.uk_222 qu.pl.ha_432 
  // [3910]
  0x35006407, 0x56004b0d, 0x4c34280c, 0x30442107,   // lg.zu.un_420 mi.mg.un_540  sw.xh.wo_543 fa.kk.uz_432 
  0x10461d07, 0x5c6a3607, 0x3900470b, 0x35345da4,   // la.qu.lt_432 gn.haw.sa_432  sn.br.un_520 ss.xh.zu_433 
  0x183421a4, 0x4a677307, 0x032410ac, 0x34005c19,   // fa.ps.ar_433 ny.ak.yo_432  lt.eo.nl_632 sa.xh.un_750 
  0x1b537607, 0x2400100d, 0x3b1c5f02, 0x785d730c,   // crs.ht.tr_432 lt.eo.un_540  tn.id.so_222 ny.ss.ve_543 
  // [3920]
  0x10000913, 0x79006b2b, 0x201009a0, 0x1b00fe0d,   // pl.lt.un_650 ceb.war.un_980  pl.lt.sq_322 tlh.tr.un_540 
  0x233038af, 0x070a040e, 0x353464a4, 0x4800fe12,   // tk.uz.ky_655 ru.mk.bg_555  lg.xh.zu_433 tlh.tt.un_640 
  0x17100708, 0x30001113, 0x01002804, 0x13383108,   // bg.be.sr_443 ro.uz.un_650  sw.en.un_320 az.tk.et_443 
  0x111517a4, 0x080c02a0, 0x30172513, 0x02002e0d,   // sr.ro.un_430 da.sv.no_322  mn.sr.uz_665 fo.da.un_540 
  // [3930]
  0x30000409, 0x2d6557a7, 0x3e394002, 0xfc003918,   // ru.uz.un_440 na.gv.sk_532  lb.br.rm_222 br.zzp.un_740 
  0x04101513, 0x01003e04, 0x30584f07, 0x23133904,   // un.be.ru_665 rm.en.un_320  bi.om.uz_432 br.et.ca_332 
  0x2afe2004, 0x292d1607, 0xfe58fa07, 0x27002f04,   // sq.tlh.mt_332 hr.sk.sl_432  nr.om.tlh_432 su.gd.un_320 
  0x65001e04, 0x52005f04, 0x23302155, 0x65396907,   // ms.gv.un_320 tn.ha.un_320  fa.uz.ky_442 mfe.br.gv_432 
  // [3940]
  0x5800101b, 0x48373ca9, 0x0b003904, 0x3c00350d,   // lt.om.un_770 ug.ba.tt_544  br.es.un_320 tg.ug.un_540 
  0x35005208, 0x12000108, 0x38003013, 0x23004404,   // ha.zu.un_430 en.hu.un_430  uz.tk.un_650 kk.ky.un_320 
  0x28007302, 0x23490b08, 0x0e2e33a9, 0x1b000d04,   // ny.sw.un_220 es.to.ca_443  nn.fo.is_544 cs.tr.un_320 
  0x3b4658ee, 0x0f1024a4, 0x21004b04, 0x643b580c,   // om.qu.so_422 eo.lt.lv_433  mi.jw.un_320 om.so.lg_543 
  // [3950]
  0x794f0811, 0x436025ad, 0x0a00fe12, 0x33000c0c,   // no.bi.war_653 eu.vo.ie_643  tlh.pt.un_640 sv.nn.un_530 
  0x32007308, 0x23003c21, 0x373548a4, 0x6a005a0d,   // ny.bs.un_430 ug.ky.un_860  tt.tg.ba_433 sm.haw.un_540 
  0x05150702, 0xfe004614, 0x241025a9, 0x4f007308,   // it.fr.un_220 qu.tlh.un_660  eu.lt.eo_544 ny.bi.un_430 
  0x38584c12, 0x50532814, 0x18002405, 0x0b2e020c,   // wo.om.tk_654 sw.ht.fj_666  eo.ga.un_330 da.fo.es_543 
  // [3960]
  0x2e3825a9, 0x35170a09, 0x404825a4, 0x521b3108,   // eu.tk.fo_544 mk.sr.tg_444  eu.tt.lb_433 az.tr.ha_443 
  0x2e330e04, 0x081710ee, 0x1a130fa7, 0x04081705,   // is.nn.fo_332 be.sr.uk_422  lv.et.tl_532 sr.uk.ru_333 
  0x3b48315a, 0x03004b04, 0x0f1033a4, 0x60565060,   // az.tt.so_553 mi.nl.un_320  nn.lt.lv_433 fj.mg.vo_664 
  0x7900580c, 0x7900090e, 0xfc3660ac, 0x10004902,   // om.war.un_530 pl.war.un_550  vo.gn.zzp_632 to.lt.un_220 
  // [3970]
  0x30182805, 0x0a171008, 0x5800360d, 0x28004c13,   // sd.ar.uz_333 be.sr.mk_443  gn.om.un_540 wo.sw.un_650 
  0x10000d08, 0x4a456707, 0x4f575404, 0x1a4f05a4,   // cs.lt.un_430 ak.ln.yo_432  ik.na.bi_332 fr.bi.tl_433 
  0xfc001f0d, 0x54270505, 0x3d211204, 0x2500351e,   // cy.zzp.un_540 fr.gd.ik_333  ur.fa.ku_332 tg.mn.un_830 
  0x0d00530b, 0x3d122113, 0x6b620504, 0x12392f55,   // ht.cs.un_520 fa.ur.ku_665  fr.kha.ceb_332 su.br.hu_442 
  // [3980]
  0x2f00120d, 0x08001012, 0x0200050d, 0x1d57540c,   // hu.su.un_540 be.uk.un_640  fr.da.un_540 ik.na.la_543 
  0x34303c07, 0x251a570c, 0x330802a6, 0x25004004,   // ug.uz.ps_432 na.tl.eu_543  da.no.nn_521 lb.eu.un_320 
  0x120554ec, 0x20420507, 0x3023380d, 0x05125412,   // ik.fr.hu_644 fr.co.sq_432  tk.ky.uz_554 ik.hu.fr_654 
  0x374415a4, 0x3140050c, 0x00004f2d, 0x4a001208,   // un.kk.ba_433 fr.lb.az_543  bi.un.un_A00 hu.yo.un_430 
  // [3990]
  0x040844a4, 0x29162d5a, 0x3d283b60, 0x04000712,   // kk.uk.ru_433 sk.hr.sl_553  ks.sd.ku_664 bg.ru.un_640 
  0x5c13090d, 0x2a001f13, 0x13005c12, 0x3400180b,   // hi.bh.sa_554 cy.mt.un_650  sa.bh.un_640 ar.ps.un_520 
  0x34002c04, 0x3500230e, 0x084815a0, 0x0700040c,   // fy.xh.un_320 ky.tg.un_550  un.tt.uk_322 ru.bg.un_530 
  0x28001818, 0x31003802, 0x28fe4712, 0x0a001709,   // ar.sd.un_740 tk.az.un_220  sn.tlh.sw_654 sr.mk.un_440 
  // [39a0]
  0x4659550c, 0x0900130b, 0x64005512, 0x3d3b210c,   // rw.rn.qu_543 bh.hi.un_520  rw.lg.un_640 fa.ks.ku_543 
  0x321610a0, 0x04153005, 0x17301007, 0x135c090c,   // lt.hr.bs_322 uz.ru.un_330  be.uz.sr_432 hi.sa.bh_543 
  0x475559ec, 0x53246909, 0x64595555, 0x16002d05,   // rn.rw.sn_644 mfe.eo.ht_444  rw.rn.lg_442 sk.hr.un_330 
  0x19000e0c, 0x291710ee, 0x32171604, 0x37002302,   // is.gl.un_530 lt.sr.sl_422  hr.sr.bs_332 ky.ba.un_220 
  // [39b0]
  0x10041508, 0x34003d13, 0x56000507, 0x36190b0e,   // un.ru.be_443 ku.ps.un_650  fr.mg.un_420 es.gl.gn_555 
  0x39000504, 0x18212808, 0x183d23a0, 0x38003c1b,   // fr.br.un_320 sd.fa.ar_443  ky.ku.ar_322 ug.tk.un_770 
  0x44003004, 0x282130a7, 0x080a1713, 0x101536a4,   // uz.kk.un_320 uz.fa.sd_532  sr.mk.uk_665 ab.be.un_430 
  0x5c00090b, 0x35000a05, 0x48001707, 0x25040a04,   // hi.sa.un_520 mk.tg.un_330  sr.tt.un_420 mk.ru.mn_332 
  // [39c0]
  0x3801fcee, 0x0a00070c, 0x33080214, 0x0c00330d,   // zzp.en.tk_422 bg.mk.un_530  da.no.nn_666 nn.sv.un_540 
  0x2c001f0d, 0x1c0d5cac, 0x0a004804, 0x48373c12,   // cy.fy.un_540 sa.ne.mr_632  tt.mk.un_320 ug.ba.tt_654 
  0x0a0807a0, 0x041715a4, 0x1732160d, 0x3800360c,   // bg.uk.mk_322 un.sr.ru_433  hr.bs.sr_554 gn.tk.un_530 
  0x08150a04, 0x28213b05, 0x10000a23, 0x63001c08,   // mk.uk.un_320 ks.fa.sd_333  mk.be.un_880 id.sco.un_430 
  // [39d0]
  0x3f001c08, 0x0e2e2d05, 0x2500480c, 0x0500220d,   // id.af.un_430 sk.fo.is_333  tt.mn.un_530 oc.fr.un_540 
  0x2336440d, 0x0d001008, 0x1b4f0107, 0x5c090dad,   // kk.ab.ky_554 lt.cs.un_430  en.bi.tr_432 ne.hi.sa_643 
  0x1b005712, 0x1b00210d, 0x05001d02, 0x0b003321,   // na.tr.un_640 jw.tr.un_540  la.fr.un_220 as.bn.un_860 
  0x063f4007, 0x46055407, 0x1c090d0e, 0x0c330205,   // lb.af.de_432 ik.fr.qu_432  ne.hi.mr_555 da.nn.sv_333 
  // [39e0]
  0x0500fc12, 0x30183dad, 0x17002d04, 0x1c121fa4,   // zzp.fr.un_640 ku.ar.uz_643  sk.sr.un_320 cy.hu.id_433 
  0x162d0d02, 0x1d00540d, 0x10070455, 0x631b2d55,   // cs.sk.hr_222 ik.la.un_540  ru.bg.be_442 sk.tr.sco_442 
  0xfc1c6ea4, 0x5d00fa0c, 0x2c001f07, 0x32005508,   // hmn.id.zzp_433 nr.ss.un_530  cy.fy.un_420 rw.bs.un_430 
  0x25554504, 0x0400fc04, 0x63001c04, 0x33002b13,   // ln.rw.eu_332 zzp.fi.un_320  id.sco.un_320 vi.nn.un_650 
  // [39f0]
  0x3f06fc07, 0x1523150d, 0x183b2113, 0x2500350e,   // zzp.de.af_432 un.ky.un_554  fa.ks.ar_665 tg.mn.un_550 
  0x303c2313, 0x73005d1a, 0x2500360d, 0x03001705,   // ky.ug.uz_665 ss.ny.un_760  ab.mn.un_540 sr.nl.un_330 
  0x21183055, 0x192c25a7, 0x06000402, 0x4400380d,   // uz.ar.fa_442 eu.fy.gl_532  fi.de.un_220 tk.kk.un_540 
  0x070a10a7, 0x2a0752a7, 0x65004e0c, 0x3447350c,   // be.mk.bg_532 ha.it.mt_532  ay.gv.un_530 zu.sn.xh_543 
  // [3a00]
  0x360d4607, 0x2d330da0, 0x0d295d05, 0x250623a4,   // qu.cs.gn_432 cs.nn.sk_322  ss.sl.cs_333 ca.de.eu_433 
  0x2e002b05, 0x2a3025a0, 0x162209a0, 0x06221f08,   // vi.fo.un_330 eu.uz.mt_322  pl.oc.hr_322 cy.oc.de_443 
  0x3d00231a, 0x31005c04, 0x44374812, 0x2a20fe09,   // ky.ku.un_760 sa.az.un_320  tt.ba.kk_654 tlh.sq.mt_444 
  0x5e5f3705, 0x24000404, 0x00000324, 0x02404dee,   // st.tn.ts_333 fi.eo.un_320  nl.un.un_900 aa.lb.da_422 
  // [3a10]
  0x355d5ea0, 0x03006507, 0x3f400308, 0x443c3013,   // ts.ss.zu_322 gv.nl.un_420  nl.lb.af_443 uz.ug.kk_665 
  0x033b3404, 0x303825ec, 0x28001813, 0x040708ec,   // xh.so.nl_332 mn.tk.uz_644  ar.sd.un_650 uk.bg.ru_644 
  0x406364a0, 0x09001c22, 0x4d201e07, 0x4c586307,   // lg.sco.lb_322 mr.hi.un_870  ms.sq.aa_432 sco.om.wo_432 
  0x65002002, 0x2c15490b, 0x58000319, 0x31536211,   // sq.gv.un_220 to.fy.un_520  nl.om.un_750 kha.ht.az_653 
  // [3a20]
  0x3f005d08, 0x233744a9, 0x1504100c, 0x10353007,   // ss.af.un_430 kk.ba.ky_544  be.ru.un_543 uz.tg.be_432 
  0x35033407, 0x123d21ec, 0x33002e02, 0x6b006113,   // xh.nl.zu_432 fa.ku.ur_644  fo.nn.un_220 za.ceb.un_650 
  0x3400640e, 0x041723a0, 0x1d006508, 0x35300a0e,   // lg.xh.un_550 ky.sr.ru_322  gv.la.un_430 mk.uz.tg_555 
  0x022758a4, 0x58063ba0, 0x634d01a0, 0x5c004b05,   // om.gd.da_433 so.de.om_322  en.aa.sco_322 mi.sa.un_330 
  // [3a30]
  0x47001305, 0x37045f60, 0x38303c0e, 0x350a1708,   // et.sn.un_330 tn.fi.st_664  ug.uz.tk_555 sr.mk.tg_443 
  0x03643fa0, 0x18004007, 0x6e375f13, 0x1c5c1308,   // af.lg.nl_322 lb.ga.un_420  tn.st.hmn_665 bh.sa.mr_443 
  0x25003521, 0x1b021a04, 0x6b6365a0, 0x05005204,   // tg.mn.un_860 tl.da.tr_332  gv.sco.ceb_322 ha.fr.un_320 
  0x0d002205, 0x2821180b, 0x1b314da9, 0x5f3837ec,   // oc.cs.un_330 ar.fa.sd_542  aa.az.tr_544 st.tk.tn_644 
  // [3a40]
  0x64311b02, 0x55006402, 0x0b4a2404, 0x4c001b0d,   // tr.az.lg_222 lg.rw.un_220  eo.yo.es_332 tr.wo.un_540 
  0x08000a22, 0x1f002704, 0x34213b0b, 0x15003812,   // mk.uk.un_870 gd.cy.un_320  ks.fa.ps_542 tk.un.un_640 
  0x05002707, 0x2300250d, 0x0000160a, 0x016502a7,   // gd.fr.un_420 mn.ky.un_540  hr.un.un_500 da.gv.en_532 
  0x16001004, 0x0a17100b, 0x3800110e, 0x353c110c,   // lt.hr.un_320 be.sr.mk_542  ro.tk.un_550 ro.ug.tg_543 
  // [3a50]
  0x29000f0b, 0x17000821, 0x0f000204, 0x17162da4,   // lv.sl.un_520 uk.sr.un_860  da.lv.un_320 sk.hr.sr_433 
  0x130c0408, 0x34281205, 0x21123405, 0x04482d08,   // fi.sv.et_443 ur.sd.ps_333  ps.ur.fa_333 sk.tt.fi_443 
  0x44150407, 0x12002b0c, 0x2d0d3805, 0x24000907,   // ru.kk.un_420 vi.hu.un_530  tk.cs.sk_333 pl.eo.un_420 
  0x30150407, 0x403f35a4, 0x3f0603a0, 0x38001107,   // ru.uz.un_420 zu.af.lb_433  nl.de.af_322 ro.tk.un_420 
  // [3a60]
  0xfc004005, 0x080a17a4, 0x130d1caf, 0x58062a07,   // lb.zzp.un_330 sr.mk.uk_433  mr.ne.bh_655 mt.de.om_432 
  0x190b3609, 0x39000302, 0x3b1d54a7, 0x0b185d04,   // gn.es.gl_444 nl.br.un_220  ik.la.so_532 ss.ga.es_332 
  0x13003907, 0x4d001c04, 0x13003905, 0x271509ad,   // br.et.un_420 id.aa.un_320  br.et.un_330 pl.gd.un_630 
  0x190b36a0, 0x42000519, 0x4b0f5cad, 0x63033faf,   // gn.es.gl_322 fr.co.un_750  sa.lv.mi_643 af.nl.sco_655 
  // [3a70]
  0x3300082c, 0x0f005c12, 0x2a403b05, 0x3b004d0c,   // no.nn.un_990 sa.lv.un_640  so.lb.mt_333 aa.so.un_530 
  0x3900290d, 0x0000422d, 0x3400fe05, 0xfc001802,   // sl.br.un_540 co.un.un_A00  tlh.xh.un_330 ga.zzp.un_220 
  0x15002d07, 0x291f580c, 0x1840feee, 0x4b561a09,   // sk.un.un_420 om.cy.sl_543  tlh.lb.ga_422 tl.mg.mi_444 
  0x40000904, 0x211e1c12, 0x3c233508, 0x0d005d05,   // pl.lb.un_320 id.ms.jw_654  tg.ky.ug_443 ss.cs.un_330 
  // [3a80]
  0x423e40a7, 0x2d0d0ba0, 0x4200150d, 0x1e520204,   // lb.rm.co_532 es.cs.sk_322  un.co.un_540 da.ha.ms_332 
  0x0f102a08, 0x45120da4, 0x494b1aa4, 0x600f06ec,   // mt.lt.lv_443 cs.hu.ln_433  tl.mi.to_433 de.lv.vo_644 
  0x02002808, 0x190d0b02, 0x04151709, 0x08071713,   // sw.da.un_430 es.cs.gl_222  sr.ru.un_440 sr.bg.uk_665 
  0x1e1c56ec, 0x211946a0, 0x242a5908, 0x2a125108,   // mg.id.ms_644 qu.gl.jw_322  rn.mt.eo_443 kl.hu.mt_443 
  // [3a90]
  0x79180707, 0x0b000919, 0x56004a1a, 0x18003e04,   // it.ga.war_432 pl.es.un_750  yo.mg.un_760 rm.ga.un_320 
  0x54583baf, 0x0d190b0d, 0x0c003919, 0x1e1c2fa0,   // so.om.ik_655 es.gl.cs_554  br.sv.un_750 su.id.ms_322 
  0x0660090b, 0x46530b04, 0x0c00fe07, 0x253f610c,   // pl.vo.de_542 es.ht.qu_332  tlh.sv.un_420 za.af.eu_543 
  0x0b00190d, 0x2e0239a7, 0x25065707, 0x12001f0d,   // gl.es.un_540 br.da.fo_532  na.de.eu_432 cy.hu.un_540 
  // [3aa0]
  0x5535340e, 0x23002d07, 0x5955300c, 0x12192202,   // xh.zu.rw_555 sk.ca.un_420  uz.rw.rn_543 oc.gl.hu_222 
  0xfe1d2d08, 0x0a17150e, 0x212f550c, 0x0d190b08,   // sk.la.tlh_443 un.sr.mk_555  rw.su.jw_543 es.gl.cs_443 
  0x1e211ca4, 0x0f1032a0, 0x2a003304, 0x0a002702,   // id.jw.ms_433 bs.lt.lv_322  nn.mt.un_320 gd.pt.un_220 
  0x42070f0c, 0x1c2f1e0c, 0x032a0604, 0x00002a2d,   // lv.it.co_543 ms.su.id_543  de.mt.nl_332 mt.un.un_A00 
  // [3ab0]
  0x3f002205, 0x241e1c55, 0x363035a9, 0x02040d07,   // oc.af.un_330 id.ms.eo_442  tg.uz.ab_544 cs.fi.da_432 
  0x08351507, 0x252212ac, 0x1500360e, 0x240afea7,   // un.tg.uk_432 hu.oc.eu_632  ab.un.un_550 tlh.pt.eo_532 
  0x08003c04, 0x30001107, 0x10001602, 0x37002513,   // ug.uk.un_320 ro.uz.un_420  hr.lt.un_220 mn.ba.un_650 
  0x095c1c55, 0x10041513, 0x2318440c, 0x37482308,   // mr.sa.hi_442 un.ru.be_665  kk.ar.ky_543 ky.tt.ba_443 
  // [3ac0]
  0x10002305, 0x11000907, 0x2e1218a7, 0x120e180e,   // ky.be.un_330 pl.ro.un_420  ga.hu.fo_532 ga.is.hu_555 
  0x182e0e04, 0x1c095c14, 0x2d1218a6, 0x0163fca0,   // is.fo.ga_332 sa.hi.mr_666  ga.hu.sk_521 zzp.sco.en_322 
  0x0e121808, 0x307348a9, 0x270d1855, 0x46360ba0,   // ga.hu.is_443 tt.ny.uz_544  ga.cs.gd_442 es.gn.qu_322 
  0x0a0717a0, 0x225b05a7, 0x20005208, 0x5d0e1808,   // sr.bg.mk_322 fr.sg.oc_532  ha.sq.un_430 ga.is.ss_443 
  // [3ad0]
  0x48003c08, 0x180d4a07, 0x33082e0c, 0x0d5c130c,   // ug.tt.un_430 yo.cs.ga_432  fo.no.nn_543 bh.sa.ne_543 
  0x171632ec, 0x1812360c, 0x0a3e5108, 0x1230695a,   // bs.hr.sr_644 gn.hu.ga_543  kl.rm.pt_443 mfe.uz.hu_553 
  0x154804a4, 0x153804ec, 0x132a07a0, 0x321b30ee,   // ru.tt.un_433 ru.tk.un_644  it.mt.et_322 uz.tr.bs_422 
  0x48303555, 0x2e001207, 0x10483007, 0x12001813,   // tg.uz.tt_442 hu.fo.un_420  uz.tt.be_432 ga.hu.un_650 
  // [3ae0]
  0x234438ec, 0x2e1218a4, 0x05004202, 0x3d00180e,   // tk.kk.ky_644 ga.hu.fo_433  co.fr.un_220 ar.ku.un_550 
  0x4800300d, 0x152338a4, 0xfc002f12, 0x0f5c6a13,   // uz.tt.un_540 tk.ky.un_433  su.zzp.un_640 haw.sa.lv_665 
  0xfc001a05, 0x2a00391a, 0x1c532fee, 0x0a071708,   // tl.zzp.un_330 dz.bo.un_760  su.ht.id_422 sr.bg.mk_443 
  0x6576560d, 0x32170f05, 0x3b00fc19, 0x432d3607,   // mg.crs.gv_554 lv.sr.bs_333  zzp.so.un_750 gn.sk.ie_432 
  // [3af0]
  0x3601630c, 0x15000108, 0x2a000907, 0x30353c05,   // sco.en.gn_543 en.un.un_430  pl.mt.un_420 ug.tg.uz_333 
  0x0d1c5ca9, 0x1d001102, 0x0d122da0, 0x5c091c0b,   // sa.mr.ne_544 ro.la.un_220  sk.hu.cs_322 mr.hi.sa_542 
  0x632f1ea0, 0x48150807, 0x04303504, 0x3800670c,   // ms.su.sco_322 uk.tt.un_420  tg.uz.ru_332 ak.tk.un_530 
  0x0e2d2e60, 0x12002d07, 0x303c230d, 0x35467907,   // fo.sk.is_664 sk.hu.un_420  ky.ug.uz_554 war.qu.zu_432 
  // [3b00]
  0x0e000d05, 0x4b5c0f08, 0x5500591a, 0x11000208,   // cs.is.un_330 lv.sa.mi_443  rn.rw.un_760 da.ro.un_430 
  0x693465ec, 0x0f5c490c, 0x285559ac, 0x12182113,   // gv.xh.mfe_644 to.sa.lv_543  rn.rw.sw_632 fa.ar.ur_665 
  0x01006305, 0x0a0835a7, 0x49645f55, 0x53002913,   // sco.en.un_330 tg.uk.mk_532  tn.lg.to_442 sl.ht.un_650 
  0x34006909, 0x555c610b, 0x08303c0c, 0x0d122d0c,   // mfe.xh.un_440 za.sa.rw_542  ug.uz.uk_543 sk.hu.cs_543 
  // [3b10]
  0x33005a02, 0x5c090d55, 0x5f1b78ee, 0x38001b1b,   // sm.nn.un_220 ne.hi.sa_442  ve.tr.tn_422 tr.tk.un_770 
  0x22234dee, 0x645c1aa0, 0x1c130da4, 0x18001d02,   // aa.ca.oc_422 tl.sa.lg_322  ne.bh.mr_433 la.ga.un_220 
  0x3569340c, 0x55003519, 0x2d000e0d, 0x24632005,   // xh.mfe.zu_543 zu.rw.un_750  is.sk.un_540 sq.sco.eo_333 
  0x64001208, 0x23041008, 0x76001512, 0x0f006905,   // hu.lg.un_430 be.ru.ky_443  un.crs.un_640 mfe.lv.un_330 
  // [3b20]
  0x5c483108, 0x55005c08, 0x0c000404, 0x3d0425a9,   // az.tt.sa_443 sa.rw.un_430  fi.sv.un_320 mn.ru.ku_544 
  0x5c000204, 0x11006912, 0x304823a4, 0x321610ee,   // da.sa.un_320 mfe.ro.un_640  ky.tt.uz_433 lt.hr.bs_422 
  0x5a004b04, 0x5c1c090d, 0x211812a9, 0x08041009,   // mi.sm.un_320 hi.mr.sa_554  ur.ar.fa_544 be.ru.uk_444 
  0x2d120da0, 0x2f004007, 0x04071704, 0x041507a7,   // cs.hu.sk_322 lb.su.un_420  sr.bg.ru_332 bg.ru.un_520 
  // [3b30]
  0x07101704, 0x100830ee, 0x120d2dee, 0x11003804,   // sr.be.bg_332 uz.uk.be_422  sk.cs.hu_422 tk.ro.un_320 
  0x063e6112, 0x13080202, 0x0d00120d, 0x5c004b12,   // za.rm.de_654 da.no.et_222  hu.cs.un_540 mi.sa.un_640 
  0x0f00610d, 0x15301108, 0x033f2a04, 0x08000c05,   // za.lv.un_540 ro.uz.un_443  mt.af.nl_332 sv.no.un_330 
  0x213c3d07, 0x153704af, 0x6e6b1da7, 0x12002b19,   // ku.ug.fa_432 ru.ba.un_655  la.ceb.hmn_532 vi.hu.un_750 
  // [3b40]
  0x2d0d125a, 0x04152504, 0x0d002d2a, 0x33081bec,   // hu.cs.sk_553 mn.ru.un_320  sk.cs.un_970 tr.no.nn_644 
  0x4400180c, 0x57000619, 0x5e356408, 0x19122dad,   // ar.kk.un_530 de.na.un_750  lg.zu.ts_443 sk.hu.gl_643 
  0x265a43a7, 0x3c00381b, 0x256a490d, 0x2d0d06af,   // ie.sm.ia_532 tk.ug.un_770  to.haw.eu_554 de.cs.sk_655 
  0x08003319, 0x65000302, 0x6a453ba9, 0x4c1a3f04,   // nn.no.un_750 nl.gv.un_220  so.ln.haw_544 af.tl.wo_332 
  // [3b50]
  0x5c1358a7, 0x5e2178a4, 0x0c000604, 0x506a3ba9,   // om.et.sa_532 ve.jw.ts_433  de.sv.un_320 so.haw.fj_544 
  0x594728a4, 0x041507a4, 0x3f2157ec, 0x3f2b27a0,   // sw.sn.rn_433 bg.ru.un_430  na.jw.af_644 gd.vi.af_322 
  0x2d124aee, 0x2c00030e, 0x38000d02, 0x3b006a07,   // yo.hu.sk_422 nl.fy.un_550  cs.tk.un_220 haw.so.un_420 
  0x6473370c, 0x645d55a0, 0x3534500c, 0x23004422,   // st.ny.lg_543 rw.ss.lg_322  fj.xh.zu_543 kk.ky.un_870 
  // [3b60]
  0x0f001708, 0x1a526a0c, 0x52645e07, 0x49182704,   // sr.lv.un_430 haw.ha.tl_543  ts.lg.ha_432 gd.ga.to_332 
  0x2a000102, 0x127345a7, 0x070a0813, 0x464e1c07,   // en.mt.un_220 ln.ny.hu_532  uk.mk.bg_665 id.ay.qu_432 
  0x314c4dec, 0x5f003707, 0x35345da0, 0x64287808,   // aa.wo.az_644 st.tn.un_420  ss.xh.zu_322 ve.sw.lg_443 
  0x2818340d, 0x73791aa9, 0x2d0d0eaf, 0x314837ad,   // ps.ar.sd_554 tl.war.ny_544  is.cs.sk_655 st.tt.az_643 
  // [3b70]
  0x731a2104, 0x1a6b5b13, 0x79001a09, 0x5a5e33a0,   // jw.tl.ny_332 sg.ceb.tl_665  tl.war.un_440 nn.ts.sm_322 
  0x17483705, 0x35070808, 0x0a1708a4, 0x5a004a0e,   // ba.tt.sr_333 uk.bg.tg_443  uk.sr.mk_433 yo.sm.un_550 
  0x070415a9, 0x1138480c, 0x34211204, 0x12000e08,   // un.ru.bg_544 tt.tk.ro_543  ur.fa.ps_332 is.hu.un_430 
  0x130d5c02, 0x1b004902, 0x070a1504, 0x0f004704,   // sa.ne.bh_222 to.tr.un_220  un.mk.bg_332 sn.lv.un_320 
  // [3b80]
  0x0815100d, 0x170f10a0, 0x12001904, 0x2400060b,   // be.uk.un_540 lt.lv.sr_322  gl.hu.un_320 de.eo.un_520 
  0x0f330802, 0x12000207, 0x0b1819a4, 0x193612a7,   // no.nn.lv_222 da.hu.un_420  gl.ga.es_433 hu.gn.gl_532 
  0x18003607, 0x341821ee, 0x15632c0c, 0x252335ee,   // gn.ga.un_420 fa.ar.ps_422  fy.sco.un_543 tg.ky.mn_422 
  0x3d1221ee, 0x361812a4, 0x12002a12, 0x37000402,   // fa.ur.ku_422 hu.ga.gn_433  mt.hu.un_640 ru.ba.un_220 
  // [3b90]
  0x1c090d08, 0x190b1808, 0x5d122ea0, 0x213d12a0,   // ne.hi.mr_443 ga.es.gl_443  fo.hu.ss_322 ur.ku.fa_322 
  0x3500541b, 0x36001205, 0x2d123609, 0x02002e08,   // ik.zu.un_770 hu.gn.un_330  gn.hu.sk_444 fo.da.un_430 
  0x34212802, 0x3d002123, 0x182d0d08, 0x30002319,   // sd.fa.ps_222 fa.ku.un_880  cs.sk.ga_443 ky.uz.un_750 
  0x27001905, 0x0e000208, 0x35001705, 0x3c3035af,   // gl.gd.un_330 da.is.un_430  sr.tg.un_330 tg.uz.ug_655 
  // [3ba0]
  0x2b006112, 0x0600270d, 0xfc03400c, 0x09002d07,   // za.vi.un_640 gd.de.un_540  lb.nl.zzp_543 sk.pl.un_420 
  0x57fc060c, 0x2000290d, 0x3c003022, 0x4e00050e,   // de.zzp.na_543 sl.sq.un_540  uz.ug.un_870 fr.ay.un_550 
  0x20591e07, 0x2130230b, 0x0400480b, 0x2c2403ee,   // ms.rn.sq_432 ky.uz.fa_542  tt.ru.un_520 nl.eo.fy_422 
  0x18732707, 0x20353004, 0x22055e60, 0x3c002314,   // gd.ny.ga_432 uz.zu.sq_332  ts.fr.oc_664 ky.ug.un_660 
  // [3bb0]
  0x330c0805, 0x18213455, 0x46404e0c, 0x08001022,   // no.sv.nn_333 ps.fa.ar_442  ay.lb.qu_543 be.uk.un_870 
  0x02002e07, 0x1f000909, 0x02002e05, 0x0c002e05,   // fo.da.un_420 pl.cy.un_440  fo.da.un_330 fo.sv.un_330 
  0x40000c04, 0x0900270c, 0x06000c02, 0x0327180c,   // sv.lb.un_320 gd.pl.un_530  sv.de.un_220 ga.gd.nl_543 
  0x523b65a7, 0x15003008, 0x40065707, 0x3b2112a4,   // gv.so.ha_532 uz.un.un_430  na.de.lb_432 ur.fa.ks_433 
  // [3bc0]
  0xfc0246a0, 0x481b310c, 0x481b31af, 0x0c00200d,   // qu.da.zzp_322 az.tr.tt_543  az.tr.tt_655 sq.sv.un_540 
  0x201e52ad, 0x17441005, 0x2c29200b, 0x3bfc790c,   // ha.ms.sq_643 be.kk.sr_333  sq.sl.fy_542 war.zzp.so_543 
  0x2000fe0c, 0x3835340b, 0x09001321, 0x232132ee,   // tlh.sq.un_530 xh.zu.tk_542  bh.hi.un_860 bs.fa.ky_422 
  0x281e56a7, 0x35374804, 0x0900132a, 0x39fa345a,   // mg.ms.sw_532 tt.ba.tg_332  bh.hi.un_970 xh.nr.br_553 
  // [3bd0]
  0x423e6507, 0x08020cee, 0x0c004002, 0x07352304,   // gv.rm.co_432 sv.da.no_422  lb.sv.un_220 ky.tg.bg_332 
  0x0a003608, 0x400c06a4, 0x30003d13, 0x2800340c,   // ab.mk.un_430 de.sv.lb_433  ku.uz.un_650 ps.sd.un_530 
  0x38481ba7, 0x5a001005, 0x103e2eee, 0x21343da7,   // tr.tt.tk_532 lt.sm.un_330  fo.rm.lt_422 ku.ps.fa_532 
  0x08000c04, 0x18122814, 0x0d001702, 0x352530af,   // sv.no.un_320 sd.ur.ar_666  sr.cs.un_220 uz.mn.tg_655 
  // [3be0]
  0x483010a7, 0x211828a0, 0x37003013, 0x10002004,   // be.uz.tt_532 sd.ar.fa_322  uz.ba.un_650 sq.lt.un_320 
  0x3000230d, 0x13090da4, 0x0d1c1307, 0x0c000805,   // ky.uz.un_540 ne.hi.bh_433  bh.mr.ne_432 no.sv.un_330 
  0x46000402, 0x3e001d05, 0x18343da0, 0x15001d04,   // fi.qu.un_220 la.rm.un_330  ku.ps.ar_322 la.un.un_320 
  0x5c000914, 0x0e004a08, 0x18002111, 0x03001f05,   // hi.sa.un_660 yo.is.un_430  fa.ar.un_630 cy.nl.un_330 
  // [3bf0]
  0x3c003712, 0x4b001d07, 0x642873a4, 0x5a001d02,   // ba.ug.un_640 la.mi.un_420  ny.sw.lg_433 la.sm.un_220 
  0x5e356407, 0x5a561dee, 0x09736804, 0x3f002807,   // lg.zu.ts_432 la.mg.sm_422  ig.ny.pl_332 sw.af.un_420 
  0x1a381b55, 0x5e377302, 0x30481009, 0xfc003002,   // tr.tk.tl_442 ny.st.ts_222  be.tt.uz_444 uz.zzp.un_220 
  0x2c00590d, 0x23002519, 0x5c004605, 0x3548380b,   // rn.fy.un_540 mn.ky.un_750  qu.sa.un_330 tk.tt.zu_542 
  
  // [3c00]
  0x301538a0, 0x64003f05, 0x330208a0, 0x0f131ba7,   // tk.uz.un_320 af.lg.un_330  no.da.nn_322 tr.et.lv_532 
  0x2873645a, 0x35006411, 0x15171108, 0x1a1b1007,   // lg.ny.sw_553 lg.zu.un_630  ro.sr.un_443 lt.tr.tl_432 
  0x030e0207, 0x353459ec, 0x30003404, 0x4b001d02,   // da.is.nl_432 rn.xh.zu_644  xh.uz.un_320 la.mi.un_220 
  0x64005e08, 0x5d343004, 0x3000610c, 0x1d001f07,   // ts.lg.un_430 uz.xh.ss_332  za.uz.un_530 cy.la.un_420 
  // [3c10]
  0x3f347307, 0x161b1a08, 0x0802330e, 0x3f001b04,   // ny.xh.af_432 tl.tr.hr_443  nn.da.no_555 tr.af.un_320 
  0x041a1ea4, 0x17003c18, 0x5c000d18, 0x09001b04,   // ms.tl.fi_433 ug.sr.un_740  ne.sa.un_740 tr.pl.un_320 
  0x07170aee, 0x18283408, 0x4800370c, 0x150410af,   // mk.sr.bg_422 ps.sd.ar_443  ba.tt.un_530 be.ru.un_655 
  0x19001216, 0x48002a08, 0x30483107, 0x44003813,   // hu.gl.un_720 mt.tt.un_430  az.tt.uz_432 tk.kk.un_650 
  // [3c20]
  0x1c090d55, 0x38001f13, 0x123021a7, 0xfa355d12,   // ne.hi.mr_442 cy.tk.un_650  fa.uz.ur_532 ss.zu.nr_654 
  0x44003719, 0x3048380c, 0x583b7304, 0xfa5d73a9,   // ba.kk.un_750 tk.tt.uz_543  ny.so.om_332 ny.ss.nr_544 
  0x3ffa34ad, 0x465c6208, 0x73006409, 0x392a2212,   // xh.nr.af_643 kha.sa.qu_443  lg.ny.un_440 oc.mt.br_654 
  0x5d3534a4, 0x34006408, 0x640540ad, 0x22000a0e,   // xh.zu.ss_433 lg.xh.un_430  lb.fr.lg_643 pt.oc.un_550 
  // [3c30]
  0x0900380d, 0x3b6364ad, 0x34005412, 0x091d2e04,   // tk.pl.un_540 lg.sco.so_643  ik.xh.un_640 fo.la.pl_332 
  0x064057a4, 0x220a2aa9, 0x01001504, 0x2a003307,   // na.lb.de_433 mt.pt.oc_544  un.en.un_320 nn.mt.un_420 
  0x2e000207, 0x38000421, 0x03004019, 0x35002b04,   // da.fo.un_420 fi.tk.un_860  lb.nl.un_750 vi.zu.un_320 
  0x0a002204, 0x063618a7, 0x1e5c18ec, 0x28000107,   // oc.pt.un_320 ga.gn.de_532  ga.sa.ms_644 en.sw.un_420 
  // [3c40]
  0x3b00620c, 0x4e001e08, 0x182b62a7, 0x38444812,   // kha.so.un_530 ms.ay.un_430  kha.vi.ga_532 tt.kk.tk_654 
  0x40063f04, 0x1221340b, 0x343021a4, 0x22000a14,   // af.de.lb_332 ps.fa.ur_542  fa.uz.ps_433 pt.oc.un_660 
  0x253530a7, 0x2d001007, 0x220a39ac, 0x34212807,   // uz.tg.mn_532 lt.sk.un_420  br.pt.oc_632 sd.fa.ps_432 
  0x09430207, 0x2a2239a4, 0x39000d08, 0x0a002212,   // da.ie.pl_432 br.oc.mt_433  cs.br.un_430 oc.pt.un_640 
  // [3c50]
  0x0a002205, 0x53002213, 0x32001608, 0x53000607,   // oc.pt.un_330 oc.ht.un_650  hr.bs.un_430 de.ht.un_420 
  0x48353708, 0x0715040d, 0x33000302, 0x27001107,   // ba.tg.tt_443 ru.bg.un_540  nl.nn.un_220 ro.gd.un_420 
  0x04000822, 0x22231107, 0x12003d02, 0x3d002113,   // uk.ru.un_870 ro.ca.oc_432  ku.ur.un_220 fa.ku.un_650 
  0x282718af, 0x1800272a, 0x04171555, 0x37493655,   // ga.gd.sw_655 gd.ga.un_970  un.sr.ru_442 gn.to.st_442 
  // [3c60]
  0x1800272b, 0x6a002d0d, 0x062c7907, 0x03000205,   // gd.ga.un_980 sk.haw.un_540  war.fy.de_432 da.nl.un_330 
  0x4b005e12, 0x1800272c, 0x013f06a4, 0x13204b07,   // ts.mi.un_640 gd.ga.un_990  de.af.en_433 mi.sq.et_432 
  0x3f030607, 0x031827ad, 0x2c003f05, 0x2c001107,   // de.nl.af_432 gd.ga.nl_643  af.fy.un_330 ro.fy.un_420 
  0x5d5f37a0, 0x42000204, 0x03403f0b, 0x5e553708,   // st.tn.ss_322 da.co.un_320  af.lb.nl_542 st.rw.ts_443 
  // [3c70]
  0x6b3f06a9, 0x5c0d0902, 0x21005504, 0x30001213,   // de.af.ceb_544 hi.ne.sa_222  rw.jw.un_320 ur.uz.un_650 
  0x1c5c0955, 0x1f003f04, 0x2700182c, 0x37004b19,   // hi.sa.mr_442 af.cy.un_320  ga.gd.un_990 mi.st.un_750 
  0x30fc46a4, 0x5c554bee, 0x31381bee, 0x37005f2c,   // qu.zzp.uz_433 mi.rw.sa_422  tr.tk.az_422 tn.st.un_990 
  0x374b6a09, 0x651506a0, 0x3600fc0d, 0x3748250c,   // haw.mi.st_444 de.gv.un_320  zzp.gn.un_540 mn.tt.ba_543 
  // [3c80]
  0x190b360e, 0x10003c19, 0x46fc4ea4, 0x07005202,   // gn.es.gl_555 ug.be.un_750  ay.zzp.qu_433 ha.it.un_220 
  0x182834a6, 0x04001505, 0x3e001b0c, 0x43245813,   // ps.sd.ar_521 un.ru.un_330  tr.rm.un_530 om.eo.ie_665 
  0x040f520c, 0xfc2c2560, 0x2f51300c, 0x53006404,   // ha.lv.fi_543 eu.fy.zzp_664  uz.kl.su_543 lg.ht.un_320 
  0x3b6358a6, 0x174d585a, 0x32273e08, 0x10003813,   // om.sco.so_521 om.aa.sr_553  rm.gd.bs_443 tk.be.un_650 
  // [3c90]
  0xfc002c23, 0x3b76100c, 0x0c025707, 0x151707a9,   // fy.zzp.un_880 lt.crs.so_543  na.da.sv_432 bg.sr.un_544 
  0x38485204, 0x55004807, 0x3e074213, 0x282112a0,   // ha.tt.tk_332 tt.rw.un_420  co.it.rm_665 ur.fa.sd_322 
  0x4000650d, 0x15170709, 0x421122a4, 0x07423e5a,   // gv.lb.un_540 bg.sr.un_444  oc.ro.co_433 rm.co.it_553 
  0x6300690e, 0x3e4269ad, 0x3e00110e, 0x3b58300c,   // mfe.sco.un_550 mfe.co.rm_643  ro.rm.un_550 uz.om.so_543 
  // [3ca0]
  0x091e1cad, 0x484a5504, 0x633b090c, 0x102758a4,   // id.ms.pl_643 rw.yo.tt_332  pl.so.sco_543 om.gd.lt_433 
  0x174438a4, 0x68005718, 0x0d792da9, 0x1135360c,   // tk.kk.sr_433 na.ig.un_740  sk.war.cs_544 ab.tg.ro_543 
  0x56261504, 0x42403ea4, 0x06004f05, 0x4a00590c,   // un.ia.mg_332 rm.lb.co_433  bi.de.un_330 rn.yo.un_530 
  0x69004613, 0x3e061505, 0x5e1a4308, 0x110a36a4,   // qu.mfe.un_650 un.de.rm_333  ie.tl.ts_443 ab.mk.ro_433 
  // [3cb0]
  0x23064d0c, 0x01002802, 0x1d001802, 0x232530a7,   // aa.de.ca_543 sw.en.un_220  ga.la.un_220 uz.mn.ky_532 
  0x23000a07, 0x5a005502, 0x0d536007, 0x3600110e,   // mk.ky.un_420 rw.sm.un_220  vo.ht.cs_432 ro.ab.un_550 
  0x2e181302, 0x3d00211a, 0x4823150d, 0x2300360c,   // et.ga.fo_222 fa.ku.un_760  un.ky.tt_554 gn.ca.un_530 
  0x170825a4, 0x423e0705, 0x1c5c0dee, 0x31003904,   // mn.uk.sr_433 it.rm.co_333  ne.sa.mr_422 br.az.un_320 
  // [3cc0]
  0x35000714, 0x3035440c, 0x38481155, 0x130d0902,   // bg.tg.un_660 kk.tg.uz_543  ro.tt.tk_442 hi.ne.bh_222 
  0x34122108, 0x04001507, 0x34002807, 0x10170a05,   // fa.ur.ps_443 un.ru.un_420  sd.ps.un_420 mk.sr.be_333 
  0x304836a4, 0x18303407, 0x250a1704, 0x3d302112,   // ab.tt.uz_433 ps.uz.ar_432  sr.mk.mn_332 fa.uz.ku_654 
  0x3c3835af, 0x30213d08, 0x0a003812, 0x1800230d,   // tg.tk.ug_655 ku.fa.uz_443  tk.mk.un_640 ky.ar.un_540 
  // [3cd0]
  0x15000a09, 0x47003602, 0x576e6412, 0x25113855,   // mk.un.un_440 gn.sn.un_220  lg.hmn.na_654 tk.ro.mn_442 
  0x5800640c, 0x30150707, 0x36640412, 0x30000a08,   // lg.om.un_530 bg.uz.un_420  fi.lg.gn_654 mk.uz.un_430 
  0x35383612, 0x4400232b, 0x3400281b, 0x02002504,   // ab.tk.tg_654 ky.kk.un_980  sd.ps.un_770 eu.da.un_320 
  0x52004d0b, 0x2f4a0907, 0x3d341204, 0x2500360e,   // aa.ha.un_520 pl.yo.su_432  ur.ps.ku_332 ab.mn.un_550 
  // [3ce0]
  0x2d0d03a4, 0x3c004422, 0x23364412, 0x5d00fe12,   // nl.cs.sk_433 kk.ug.un_870  kk.ab.ky_654 tlh.ss.un_640 
  0x30004d19, 0x38004d0d, 0x3f000602, 0x080a1007,   // aa.uz.un_750 aa.tk.un_540  de.af.un_220 be.mk.uk_432 
  0x4700731a, 0x1c5c0dac, 0x311b3055, 0x581f4cee,   // ny.sn.un_760 ne.sa.mr_632  uz.tr.az_442 wo.cy.om_422 
  0x5826240c, 0x374830a4, 0x072335a0, 0x0600580d,   // eo.ia.om_543 uz.tt.ba_433  tg.ky.bg_322 om.de.un_540 
  // [3cf0]
  0x0165fc0c, 0x483069a7, 0x10000a1a, 0x18003b04,   // zzp.gv.en_543 mfe.uz.tt_532  mk.be.un_760 so.ga.un_320 
  0x0c2859a0, 0x1d03580c, 0x30004607, 0x6500fc05,   // rn.sw.sv_322 om.nl.la_543  qu.uz.un_420 zzp.gv.un_330 
  0x2400360c, 0x0c0302ee, 0x61006e0e, 0x10003c05,   // gn.eo.un_530 da.nl.sv_422  hmn.za.un_550 ug.be.un_330 
  0x765d0807, 0x29122202, 0x31000604, 0x6b003409,   // no.ss.crs_432 oc.hu.sl_222  de.az.un_320 xh.ceb.un_440 
  // [3d00]
  0x254006a0, 0x2c1b1304, 0x0f02290c, 0x0a0807a7,   // de.lb.eu_322 et.tr.fy_332  sl.da.lv_543 bg.uk.mk_532 
  0x090212a0, 0x3f0833ad, 0x340f1304, 0x4e004614,   // hu.da.pl_322 nn.no.af_643  et.lv.xh_332 qu.ay.un_660 
  0x3f001219, 0x37003c0d, 0x0500220c, 0xfe000c0d,   // hu.af.un_750 ug.ba.un_540  oc.fr.un_530 sv.tlh.un_540 
  0x0c004c02, 0x64042502, 0x0d004707, 0x60000f14,   // wo.sv.un_220 eu.fi.lg_222  sn.cs.un_420 lv.vo.un_660 
  // [3d10]
  0x0f105d0d, 0x0c0602a0, 0x600601a0, 0x12215d0c,   // ss.lt.lv_554 da.de.sv_322  en.de.vo_322 ss.jw.hu_543 
  0xfa00372b, 0x0524010c, 0x22004312, 0x1d005c20,   // st.nr.un_980 en.eo.fr_543  ie.oc.un_640 sa.la.un_850 
  0x173c15a4, 0x01006307, 0x35005d09, 0x03004704,   // un.ug.sr_433 sco.en.un_420  ss.zu.un_440 sn.nl.un_320 
  0x36000402, 0x1c0d0907, 0x1f00200d, 0x024302a9,   // fi.gn.un_220 hi.ne.mr_432  sq.cy.un_540 da.ie.da_544 
  // [3d20]
  0x3b004c04, 0x792d3807, 0x1c5c0904, 0x2e00250c,   // wo.so.un_320 tk.sk.war_432  hi.sa.mr_332 eu.fo.un_530 
  0x424505ad, 0x63000804, 0x1b1325a9, 0x00004c24,   // fr.ln.co_643 no.sco.un_320  eu.et.tr_544 wo.un.un_900 
  0x0e2e33a4, 0x120e33a4, 0x08070404, 0x132e300c,   // nn.fo.is_433 nn.is.hu_433  ru.bg.uk_332 uz.fo.et_543 
  0x0306080c, 0xfe000f08, 0x061324a0, 0x1b4f5da7,   // no.de.nl_543 lv.tlh.un_430  eo.et.de_322 ss.bi.tr_532 
  // [3d30]
  0x300115ec, 0x18003e0c, 0x02001f02, 0x1b2548ad,   // un.en.uz_644 rm.ga.un_530  cy.da.un_220 tt.eu.tr_643 
  0x100dfe07, 0x22000b04, 0x1f215d11, 0x6500420c,   // tlh.cs.lt_432 es.oc.un_320  ss.jw.cy_653 co.gv.un_530 
  0x1e061208, 0x5a104207, 0x36000708, 0x63fe03ee,   // hu.de.ms_443 co.lt.sm_432  bg.ab.un_430 nl.tlh.sco_422 
  0x30001b02, 0x3b004c12, 0x0900650d, 0x3f004804,   // tr.uz.un_220 wo.so.un_640  gv.pl.un_540 tt.af.un_320 
  // [3d40]
  0x2e0e6305, 0x0e33080c, 0x033f01a0, 0x53000102,   // sco.is.fo_333 no.nn.is_543  en.af.nl_322 en.ht.un_220 
  0x10000907, 0x12183b07, 0x1009650c, 0x0a17080d,   // pl.lt.un_420 ks.ar.ur_432  gv.pl.lt_543 uk.sr.mk_554 
  0x443748a4, 0x12003c09, 0x63000112, 0x23103e0c,   // tt.ba.kk_433 ug.ur.un_440  en.sco.un_640 rm.lt.ca_543 
  0x080a070e, 0x091c13ad, 0x1d1501a0, 0x10000f09,   // bg.mk.uk_555 bh.mr.hi_643  en.la.un_320 lv.lt.un_440 
  // [3d50]
  0x48442312, 0x30352312, 0x0433080d, 0x0f460ca0,   // ky.kk.tt_654 ky.tg.uz_654  no.nn.fi_554 sv.qu.lv_322 
  0x31000204, 0x1d24130c, 0x450e2e12, 0x190b3607,   // da.az.un_320 et.eo.la_543  fo.is.ln_654 gn.es.gl_432 
  0x48443708, 0x23251011, 0x0b002304, 0x403b5813,   // ba.kk.tt_443 be.mn.ky_653  ca.es.un_320 om.so.lb_665 
  0x12303412, 0x403f58a7, 0x44233704, 0x28003204,   // ps.uz.ur_654 om.af.lb_532  ba.ky.kk_332 bs.sw.un_320 
  // [3d60]
  0x0d1c0913, 0x0300580c, 0x0b002402, 0x0a041505,   // hi.mr.ne_665 om.nl.un_530  eo.es.un_220 un.ru.mk_333 
  0x0e004a07, 0x0700171a, 0x374844a9, 0x17321613,   // yo.is.un_420 sr.bg.un_760  kk.tt.ba_544 hr.bs.sr_665 
  0x4c00580d, 0x3b4c5860, 0x3b585b0c, 0x0700080d,   // om.wo.un_540 om.wo.so_664  sg.om.so_543 uk.bg.un_540 
  0x07040a04, 0x1d000702, 0x641f73a0, 0x0b192ea4,   // mk.ru.bg_332 it.la.un_220  ny.cy.lg_322 fo.gl.es_433 
  // [3d70]
  0x36002f02, 0x170a10a0, 0x32172905, 0x79586b0c,   // su.gn.un_220 be.mk.sr_322  sl.sr.bs_333 ceb.om.war_543 
  0x0200fe14, 0x644c55a7, 0x1500350e, 0x4a1347a9,   // tlh.da.un_660 rw.wo.lg_532  tg.un.un_550 sn.et.yo_544 
  0x2f005808, 0x09002a09, 0x69001c1a, 0x2e120e12,   // om.su.un_430 mt.pl.un_440  id.mfe.un_760 is.hu.fo_654 
  0x10003304, 0x041d4cee, 0x3f002004, 0x38125655,   // nn.lt.un_320 wo.la.fi_422  sq.af.un_320 mg.hu.tk_442 
  // [3d80]
  0x6b6410a9, 0x00004524, 0x02005312, 0x071730ee,   // lt.lg.ceb_544 ln.un.un_900  ht.da.un_640 uz.sr.bg_422 
  0x5535fe0b, 0x1b255e0c, 0x351756a0, 0x2800480c,   // tlh.zu.rw_542 ts.eu.tr_543  mg.sr.zu_322 tt.sw.un_530 
  0x3c003b08, 0x10001513, 0x02560f0c, 0x05005305,   // ks.ug.un_430 un.be.un_650  lv.mg.da_543 ht.fr.un_330 
  0xfa2a370c, 0x10002912, 0x4b075907, 0x5018270c,   // st.mt.nr_543 sl.lt.un_640  rn.it.mi_432 gd.ga.fj_543 
  // [3d90]
  0x33003812, 0x5c00fe21, 0x19005604, 0x28122112,   // tk.nn.un_640 tlh.sa.un_860  mg.gl.un_320 fa.ur.sd_654 
  0x190a2509, 0x2f6920a4, 0x21731c08, 0x37000104,   // eu.pt.gl_444 sq.mfe.su_433  id.ny.jw_443 en.st.un_320 
  0x2d007304, 0x0000012d, 0x64343008, 0x19230e07,   // ny.sk.un_320 en.un.un_A00  uz.xh.lg_443 is.ca.gl_432 
  0x253911ec, 0x3435fe12, 0x103035a4, 0x304502a9,   // ro.br.eu_644 tlh.zu.xh_654  tg.uz.be_433 da.ln.uz_544 
  // [3da0]
  0x0f005c08, 0x04000708, 0x2a075fa9, 0x2f13510c,   // sa.lv.un_430 bg.ru.un_430  tn.it.mt_544 kl.et.su_543 
  0x65630112, 0x4851580b, 0x2523350c, 0x4f5efe0c,   // en.sco.gv_654 om.kl.tt_542  tg.ky.mn_543 tlh.ts.bi_543 
  0x0163fea7, 0x15073509, 0x1c000d1a, 0x08170404,   // tlh.sco.en_532 tg.bg.un_444  ne.mr.un_760 ru.sr.uk_332 
  0x651d0611, 0x30002505, 0x171632ac, 0x4400360d,   // de.la.gv_653 mn.uz.un_330  bs.hr.sr_632 ab.kk.un_540 
  // [3db0]
  0x3800231b, 0x29004202, 0x0f005c0c, 0x3444235a,   // ky.tk.un_770 co.sl.un_220  sa.lv.un_530 ky.kk.ps_553 
  0x2348300e, 0x350a1504, 0x472d7812, 0x0a0717ee,   // uz.tt.ky_555 un.mk.tg_332  ve.sk.sn_654 sr.bg.mk_422 
  0x150136a0, 0x374448a4, 0x47007822, 0x213d3402,   // gn.en.un_322 tt.kk.ba_433  ve.sn.un_870 ps.ku.fa_222 
  0x55002805, 0x2d73090b, 0x470f7808, 0x645f34ee,   // sw.rw.un_330 pl.ny.sk_542  ve.lv.sn_443 xh.tn.lg_422 
  // [3dc0]
  0x18731c07, 0x47007820, 0x21002702, 0x355d06a0,   // id.ny.ga_432 ve.sn.un_850  gd.jw.un_220 de.ss.zu_322 
  0x55004b05, 0x35097308, 0x5d0425a4, 0x645535a4,   // mi.rw.un_330 ny.pl.zu_443  eu.fi.ss_433 zu.rw.lg_433 
  0x0a071704, 0x0f006e07, 0x281218ad, 0x2311250c,   // sr.bg.mk_332 hmn.lv.un_420  ar.ur.sd_643 mn.ro.ky_543 
  0x68005813, 0x28645508, 0x791a30a0, 0x30523107,   // om.ig.un_650 rw.lg.sw_443  uz.tl.war_322 az.ha.uz_432 
  // [3dd0]
  0x47007823, 0x78470f12, 0x245552a0, 0x2e00fc07,   // ve.sn.un_880 lv.sn.ve_654  ha.rw.eo_322 zzp.fo.un_420 
  0x6459550d, 0x275c30a4, 0x1d220f11, 0x324b2104,   // rw.rn.lg_554 uz.sa.gd_433  lv.oc.la_653 jw.mi.bs_332 
  0x645f5508, 0x0f003407, 0x071d265a, 0x0f551b0c,   // rw.tn.lg_443 xh.lv.un_420  ia.la.it_553 tr.rw.lv_543 
  0x38003513, 0x18001504, 0x1d2642a4, 0x4b452507,   // zu.tk.un_650 un.ga.un_320  co.ia.la_433 eu.ln.mi_432 
  // [3de0]
  0x0f583bec, 0xfc254507, 0x25001508, 0x13004912,   // so.om.lv_644 ln.eu.zzp_432  un.mn.un_430 to.et.un_640 
  0x07281aa0, 0x10000a12, 0x3502640e, 0x3b026408,   // tl.sw.it_322 mk.be.un_640  lg.da.zu_555 lg.da.so_443 
  0x0a070413, 0x071710a0, 0x330c1da4, 0x1f006504,   // ru.bg.mk_665 be.sr.bg_322  la.sv.nn_433 gv.cy.un_320 
  0x444838a0, 0x281812a4, 0x65631f09, 0x2e002209,   // tk.tt.kk_322 ur.ar.sd_433  cy.sco.gv_444 oc.fo.un_440 
  // [3df0]
  0x1b6e3004, 0x2a003002, 0x21002819, 0x483015ad,   // uz.hmn.tr_332 uz.mt.un_220  sd.fa.un_750 un.uz.tt_643 
  0x170823a7, 0x3c3038a4, 0x65006221, 0x3b00341a,   // ky.uk.sr_532 tk.uz.ug_433  kha.gv.un_860 ps.ks.un_760 
  0x2d0d4aa0, 0x2d001207, 0x190b1209, 0x15101504,   // yo.cs.sk_322 hu.sk.un_420  hu.es.gl_444 un.be.un_332 
  0x1d001f0b, 0x283430a9, 0x3b624e0d, 0x37006819,   // cy.la.un_520 uz.ps.sd_544  ay.kha.so_554 ig.st.un_750 
  // [3e00]
  0x1c000307, 0xfc34350b, 0x3800482a, 0x35005f04,   // nl.id.un_420 zu.xh.zzp_542  tt.tk.un_970 tn.zu.un_320 
  0x0c000205, 0x0e630802, 0x0e1936a0, 0x0a00110d,   // da.sv.un_330 no.sco.is_222  gn.gl.is_322 ro.mk.un_540 
  0x2330350c, 0x35001513, 0x2e020ba0, 0x2e321705,   // tg.uz.ky_543 un.tg.un_650  es.da.fo_322 sr.bs.fo_333 
  0x0a08170c, 0x5c005719, 0x21006112, 0x48061b55,   // sr.uk.mk_543 na.sa.un_750  za.jw.un_640 tr.de.tt_442 
  // [3e10]
  0x15630105, 0x3c23185a, 0x5d5246ad, 0x561c53a0,   // en.sco.un_333 ar.ky.ug_553  qu.ha.ss_643 ht.id.mg_322 
  0x23003721, 0x05004507, 0x5c004b0d, 0x28005302,   // ba.ky.un_860 ln.fr.un_420  mi.sa.un_540 ht.sw.un_220 
  0x0408350c, 0x25002905, 0x2112280d, 0x6b0379a0,   // tg.uk.ru_543 sl.eu.un_330  sd.ur.fa_554 war.nl.ceb_322 
  0x0d5c0960, 0x02003f02, 0x040a17a4, 0x48003812,   // hi.sa.ne_664 af.da.un_220  sr.mk.ru_433 tk.tt.un_640 
  // [3e20]
  0x25000205, 0x6b357908, 0x364b25ec, 0x0410370c,   // da.eu.un_330 war.zu.ceb_443  eu.mi.gn_644 ba.be.ru_543 
  0x24002f04, 0x4400370e, 0x30354405, 0x3023150c,   // su.eo.un_320 ba.kk.un_550  kk.tg.uz_333 un.ky.uz_543 
  0x374844a4, 0x25000813, 0x153f0307, 0x04070a0b,   // kk.tt.ba_433 no.eu.un_650  nl.af.un_432 mk.bg.ru_542 
  0x3d122160, 0x033f3308, 0x10040807, 0x25000721,   // fa.ur.ku_664 nn.af.nl_443  uk.ru.be_432 bg.mn.un_860 
  // [3e30]
  0x23002a05, 0x2f1e12a0, 0x08003709, 0x12000e04,   // mt.ca.un_330 hu.ms.su_322  ba.uk.un_440 is.hu.un_320 
  0x1e001204, 0x5e003412, 0x2f006b08, 0x30152512,   // hu.ms.un_320 xh.ts.un_640  ceb.su.un_430 mn.uz.un_640 
  0x07002504, 0x212f1c07, 0x2f001204, 0x2f00120c,   // mn.bg.un_320 id.su.jw_432  hu.su.un_320 hu.su.un_530 
  0x2f004307, 0x480c2104, 0x122f1c05, 0x170a30a4,   // ie.su.un_420 jw.sv.tt_332  id.su.hu_333 uz.mk.sr_433 
  // [3e40]
  0x15073c05, 0x33080605, 0x303538a0, 0x18122808,   // ug.bg.un_333 de.no.nn_333  tk.tg.uz_322 sd.ur.ar_443 
  0x47353408, 0x18342855, 0x102112ee, 0x28002312,   // xh.zu.sn_443 sd.ps.ar_442  hu.jw.lt_422 ca.sw.un_640 
  0x122e0d0c, 0x1c001212, 0x404306a9, 0x35340ca0,   // cs.fo.hu_543 hu.id.un_640  de.ie.lb_544 sv.xh.zu_322 
  0x31353404, 0x23070aa4, 0x1100251a, 0x0a170704,   // xh.zu.az_332 mk.bg.ky_433  mn.ro.un_760 bg.sr.mk_332 
  // [3e50]
  0x372348a4, 0x064030a0, 0x3c234404, 0x481038a7,   // tt.ky.ba_433 uz.lb.de_322  kk.ky.ug_332 tk.be.tt_532 
  0x2335300c, 0x454a05a7, 0x283668ec, 0x5f006819,   // uz.tg.ky_543 fr.yo.ln_532  ig.gn.sw_644 ig.tn.un_750 
  0x3000211a, 0x122e0ea0, 0x3efc5f5a, 0x15383008,   // fa.uz.un_760 is.fo.hu_322  tn.zzp.rm_553 uz.tk.un_443 
  0x0600fc08, 0x1304120c, 0x5700681a, 0x310530ee,   // zzp.de.un_430 hu.fi.et_543  ig.na.un_760 uz.fr.az_422 
  // [3e60]
  0x0a002f02, 0xfc003507, 0x313058a0, 0x131c0960,   // su.pt.un_220 zu.zzp.un_420  om.uz.az_322 hi.mr.bh_664 
  0x4400370c, 0x65001012, 0x30002114, 0x31481baf,   // ba.kk.un_530 lt.gv.un_640  fa.uz.un_660 tr.tt.az_655 
  0x212f2804, 0xfc125807, 0x352528ee, 0x35383c0c,   // sw.su.jw_332 om.hu.zzp_432  sw.eu.zu_422 ug.tk.tg_543 
  0x27005813, 0x5e5c2112, 0x5d353405, 0x3b005819,   // om.gd.un_650 jw.sa.ts_654  xh.zu.ss_333 om.so.un_750 
  // [3e70]
  0x02001208, 0x4810370c, 0x35001f09, 0x3906730c,   // hu.da.un_430 ba.be.tt_543  cy.zu.un_440 ny.de.br_543 
  0xfc3b5807, 0x35000d13, 0x27005823, 0x64473ea7,   // om.so.zzp_432 cs.zu.un_650  om.gd.un_880 rm.sn.lg_532 
  0x3b005c1a, 0x18002708, 0x186527ad, 0x3b002705,   // sa.so.un_760 gd.ga.un_430  gd.gv.ga_643 gd.so.un_330 
  0x1800270d, 0xfa355e0c, 0x36001d08, 0x2f471c07,   // gd.ga.un_540 ts.zu.nr_543  la.gn.un_430 id.sn.su_432 
  // [3e80]
  0x18652760, 0x2f361e07, 0x3b46470c, 0x15041711,   // gd.gv.ga_664 ms.gn.su_432  sn.qu.so_543 sr.ru.un_653 
  0x1e1cfea4, 0x28212f0c, 0x21343009, 0x5525590d,   // tlh.id.ms_433 su.jw.sw_543  uz.ps.fa_444 rn.eu.rw_554 
  0xfc3b5c0c, 0x1d2f500b, 0x38211ba9, 0x0d006518,   // sa.so.zzp_543 fj.su.la_542  tr.jw.tk_544 gv.cs.un_740 
  0x095c1c13, 0x651f18a4, 0x10391da0, 0x2d0d09a9,   // mr.sa.hi_665 ga.cy.gv_433  la.br.lt_322 pl.cs.sk_544 
  // [3e90]
  0x4d580208, 0x092d0d08, 0x250668ee, 0x62005e1a,   // da.om.aa_443 cs.sk.pl_443  ig.de.eu_422 ts.kha.un_760 
  0x5d343511, 0x30023b0b, 0x10153604, 0x07382355,   // zu.xh.ss_653 so.da.uz_542  ab.be.un_320 ky.tk.bg_442 
  0x583b300d, 0x04383607, 0x34122305, 0x0d003804,   // uz.so.om_554 ab.tk.ru_432  ky.ur.ps_333 tk.cs.un_320 
  0x48233004, 0x10000f04, 0x092d0d0d, 0x070a17a9,   // uz.ky.tt_332 lv.lt.un_320  cs.sk.pl_554 sr.mk.bg_544 
  // [3ea0]
  0x28341860, 0x1d365ca9, 0x23073555, 0x303b310c,   // ar.ps.sd_664 sa.gn.la_544  tg.bg.ky_442 az.so.uz_543 
  0x281b31af, 0x2f214c07, 0x17003809, 0x5e11420c,   // az.tr.sw_655 wo.jw.su_432  tk.sr.un_440 co.ro.ts_543 
  0x06403fad, 0x19003605, 0x10040705, 0x026b3f07,   // af.lb.de_643 gn.gl.un_330  bg.ru.be_333 af.ceb.da_432 
  0x22113ead, 0x5c090d09, 0x0a17150c, 0x1c091314,   // rm.ro.oc_643 ne.hi.sa_444  un.sr.mk_543 bh.hi.mr_666 
  // [3eb0]
  0x480711a9, 0x28303b12, 0x5c5a4b0e, 0x07100408,   // ro.bg.tt_544 ks.uz.sd_654  mi.sm.sa_555 ru.be.bg_443 
  0x40062502, 0x09002d18, 0x0d1c1308, 0x09002c04,   // eu.de.lb_222 sk.pl.un_740  bh.mr.ne_443 fy.pl.un_320 
  0x35251507, 0x07003e02, 0x19000b04, 0x290d2d07,   // un.mn.tg_432 rm.it.un_220  es.gl.un_320 sk.cs.sl_432 
  0x360607ad, 0x35002408, 0x09000f04, 0x1700071a,   // it.de.gn_643 eo.zu.un_430  lv.pl.un_320 bg.sr.un_760 
  // [3ec0]
  0x1200091a, 0x13041ba4, 0x1f005604, 0x17160205,   // pl.hu.un_760 tr.fi.et_433  mg.cy.un_320 da.hr.sr_333 
  0x5300680c, 0x1c5c0d0b, 0x643f3402, 0x23001519,   // ig.ht.un_530 ne.sa.mr_542  xh.af.lg_222 un.ky.un_750 
  0x0c003f0c, 0x07083ca7, 0x1e216b02, 0x24001207,   // af.sv.un_530 ug.uk.bg_532  ceb.jw.ms_222 hu.eo.un_420 
  0x20005602, 0x3823480d, 0x183c44a9, 0x15004f04,   // mg.sq.un_220 tt.ky.tk_554  kk.ug.ar_544 bi.un.un_320 
  // [3ed0]
  0x443c23ec, 0x475d73a9, 0x64000404, 0x241e3f08,   // ky.ug.kk_644 ny.ss.sn_544  fi.lg.un_320 af.ms.eo_443 
  0x18002814, 0x3f650e08, 0x30001504, 0x5c2830a7,   // sd.ar.un_660 is.gv.af_443  un.uz.un_320 uz.sw.sa_532 
  0x33001304, 0x522a7304, 0x64005718, 0x15002513,   // et.nn.un_320 ny.mt.ha_332  na.lg.un_740 mn.un.un_650 
  0x38006b0c, 0x48002302, 0x64003b04, 0x30003511,   // ceb.tk.un_530 ky.tt.un_220  so.lg.un_320 tg.uz.un_630 
  // [3ee0]
  0x23443c12, 0x5c00130d, 0x233738af, 0x253008a0,   // ug.kk.ky_654 bh.sa.un_540  tk.ba.ky_655 no.uz.eu_322 
  0x0900100c, 0x24001509, 0x12002112, 0x01000e02,   // lt.pl.un_530 un.eo.un_440  fa.ur.un_640 is.en.un_220 
  0x0f004c05, 0x351008ee, 0x06050ea0, 0x37003004,   // wo.lv.un_330 uk.be.tg_422  is.fr.de_322 uz.ba.un_320 
  0x495e0c11, 0x60006a2c, 0x16002808, 0x43455fa4,   // sv.ts.to_653 haw.vo.un_990  sw.hr.un_430 tn.ln.ie_433 
  // [3ef0]
  0x49190a04, 0x23000408, 0x39002a02, 0x30213d12,   // pt.gl.to_332 ru.ky.un_430  mt.br.un_220 ku.fa.uz_654 
  0x175d050c, 0x0c2925a9, 0x78375fad, 0x072125ee,   // fr.ss.sr_543 eu.sl.sv_544  tn.st.ve_643 eu.jw.it_422 
  0x45002519, 0x0a000814, 0x04442304, 0x3400780d,   // eu.ln.un_750 uk.mk.un_660  ky.kk.ru_332 ve.xh.un_540 
  0x23002112, 0x37001507, 0x07253ca0, 0x2d001d07,   // fa.ky.un_640 un.ba.un_420  ug.mn.bg_322 la.sk.un_420 
  // [3f00]
  0x5c1c130e, 0x691e1c0e, 0x4f0a6aaf, 0x5f786a08,   // bh.mr.sa_555 id.ms.mfe_555  haw.pt.bi_655 haw.ve.tn_443 
  0x0a002d08, 0x09001004, 0x37001d04, 0x07003007,   // sk.pt.un_430 lt.pl.un_320  la.st.un_320 uz.bg.un_420 
  0x08043ca0, 0x65001005, 0x4f00100d, 0x3b12210c,   // ug.ru.uk_322 lt.gv.un_330  lt.bi.un_540 fa.ur.ks_543 
  0x583b40af, 0x583b4d08, 0x1d566aa4, 0x0800150c,   // lb.so.om_655 aa.so.om_443  haw.mg.la_433 un.uk.un_530 
  // [3f10]
  0x491e37a4, 0x3b2858a0, 0x174811a4, 0x15000d1a,   // st.ms.to_433 om.sw.so_322  ro.tt.sr_433 cs.un.un_760 
  0x233c37a9, 0x492137ee, 0x330237a4, 0x06001304,   // ba.ug.ky_544 st.jw.to_422  st.da.nn_433 et.de.un_320 
  0x34004907, 0x0900fc09, 0x1c0cfc0d, 0x25001002,   // to.xh.un_420 zzp.pl.un_440  zzp.sv.id_554 be.mn.un_220 
  0x0a150404, 0x25004807, 0x2800580d, 0x3900400e,   // ru.mk.un_320 tt.mn.un_420  om.sw.un_540 lb.br.un_550 
  // [3f20]
  0x5c001502, 0x403b28ac, 0x3b4d5860, 0x0a3f490c,   // un.sa.un_220 sw.so.lb_632  om.aa.so_664 to.af.pt_543 
  0x4d004013, 0x56006b0c, 0x21fc1c0c, 0xfc002c05,   // lb.aa.un_650 ceb.mg.un_530  id.zzp.jw_543 fy.zzp.un_330 
  0x6b6a4b07, 0x38003f05, 0x08353012, 0x100f1304,   // mi.haw.ceb_432 af.tk.un_330  uz.tg.uk_654 et.lv.lt_332 
  0x091c5ca0, 0x48004304, 0x28004802, 0x190b2360,   // sa.mr.hi_322 ie.tt.un_320  tt.sw.un_220 ca.es.gl_664 
  // [3f30]
  0x105a13a0, 0x48006812, 0x3d00280c, 0x212330a7,   // et.sm.lt_322 ig.tt.un_640  sd.ku.un_530 uz.ky.fa_532 
  0x203960ee, 0x23383055, 0x080415a9, 0x63432407,   // vo.br.sq_422 uz.tk.ky_442  un.ru.uk_544 eo.ie.sco_432 
  0x21000e05, 0x0d2d1204, 0x44001508, 0x48000c05,   // is.jw.un_330 hu.sk.cs_332  un.kk.un_430 sv.tt.un_330 
  0x1d122d0b, 0x330e3f0c, 0x3848100c, 0x392223a4,   // sk.hu.la_542 af.is.nn_543  lt.tt.tk_543 ca.oc.br_433 
  // [3f40]
  0x30343bee, 0x04000c05, 0x3f003907, 0x39002402,   // ks.ps.uz_422 sv.fi.un_330  br.af.un_420 eo.br.un_220 
  0x5600fc02, 0x321b4812, 0x36150460, 0x48000409,   // zzp.mg.un_220 tt.tr.bs_654  ru.ab.un_640 fi.tt.un_440 
  0x15100414, 0xfc00011a, 0x5600762b, 0x302945a9,   // ru.be.un_666 en.zzp.un_760  crs.mg.un_980 ln.sl.uz_544 
  0x315545ec, 0x09291205, 0x190b11a4, 0x105202a0,   // ln.rw.az_644 hu.sl.pl_333  ro.es.gl_433 da.ha.lt_322 
  // [3f50]
  0x04004002, 0x150408af, 0x45241b0c, 0x553556a6,   // lb.fi.un_220 uk.ru.un_655  tr.eo.ln_543 mg.zu.rw_521 
  0x15002314, 0x0d1c5c12, 0x56001e13, 0x35023855,   // ky.un.un_660 sa.mr.ne_654  ms.mg.un_650 tk.da.zu_442 
  0x32171b0c, 0x3100482b, 0x470a560c, 0x40000609,   // tr.sr.bs_543 tt.az.un_980  mg.pt.sn_543 de.lb.un_440 
  0x0d290912, 0x73002808, 0x76002808, 0x0c0e3f08,   // pl.sl.cs_654 sw.ny.un_430  sw.crs.un_430 af.is.sv_443 
  // [3f60]
  0x1218650c, 0x0c004008, 0x373048a7, 0x0c6540a0,   // gv.ga.hu_543 lb.sv.un_430  tt.uz.ba_532 lb.gv.sv_322 
  0x04000c0d, 0x65001208, 0x654006ac, 0x080a0707,   // sv.fi.un_540 hu.gv.un_430  de.lb.gv_632 bg.mk.uk_432 
  0x0c533fa0, 0x29006504, 0x23191d07, 0x0c6b1a07,   // af.ht.sv_322 gv.sl.un_320  la.gl.ca_432 tl.ceb.sv_432 
  0x44003408, 0x6e2f30ac, 0x4400380c, 0x13090d05,   // ps.kk.un_430 uz.su.hmn_632  tk.kk.un_530 ne.hi.bh_333 
  // [3f70]
  0x281844a7, 0x0c126504, 0x08000709, 0x483015af,   // kk.ar.sd_532 gv.hu.sv_332  bg.uk.un_440 un.uz.tt_655 
  0x33653804, 0x0c3f08a4, 0x33086bee, 0x25040704,   // tk.gv.nn_332 no.af.sv_433  ceb.no.nn_422 bg.ru.mn_332 
  0x052b28a0, 0x1c0d5c60, 0x4a6301a7, 0x44233c14,   // sw.vi.fr_322 sa.ne.mr_664  en.sco.yo_532 ug.ky.kk_666 
  0x50004304, 0x64281302, 0x1c000d02, 0x1300670d,   // ie.fj.un_320 et.sw.lg_222  ne.mr.un_220 ak.et.un_540 
  // [3f80]
  0x186b40a6, 0x1c605407, 0x1800650c, 0x23181f12,   // lb.ceb.ga_521 ik.vo.id_432  gv.ga.un_530 cy.ga.ca_654 
  0x232535ad, 0x123f1002, 0x2d0d5414, 0x02000e1a,   // tg.mn.ky_643 lt.af.hu_222  ik.cs.sk_666 is.da.un_760 
  0x07080a14, 0x30006213, 0x0d000402, 0x0e1540a7,   // mk.uk.bg_666 kha.uz.un_650  fi.cs.un_220 lb.is.un_520 
  0x1e1c60a0, 0x27010ea0, 0x09002d13, 0x33120c02,   // vo.id.ms_322 is.en.gd_322  sk.pl.un_650 sv.hu.nn_222 
  // [3f90]
  0x190b13a0, 0x1d5f2507, 0x04074802, 0x05001d0c,   // et.es.gl_322 eu.tn.la_432  tt.bg.ru_222 la.fr.un_530 
  0x2d002704, 0x1e002404, 0x0d092d12, 0x352a02a0,   // gd.sk.un_320 eo.ms.un_320  sk.pl.cs_654 da.mt.zu_322 
  0x630c0eaf, 0x2d0d10a9, 0x1e1c2fee, 0x153035ad,   // is.sv.sco_655 lt.cs.sk_544  su.id.ms_422 tg.uz.un_643 
  0x131f01a4, 0x2d090daf, 0x0c0e1f04, 0x28002308,   // en.cy.et_433 cs.pl.sk_655  cy.is.sv_332 ky.sd.un_430 
  // [3fa0]
  0x1e1c2faf, 0x13400807, 0x122f1c04, 0x092d0dee,   // su.id.ms_655 no.lb.et_432  id.su.hu_332 cs.sk.pl_422 
  0x173025a0, 0x354830af, 0x2d002e12, 0x00000b2d,   // mn.uz.sr_322 uz.tt.tg_655  fo.sk.un_640 bn.un.un_A00 
  0x3e000702, 0x2834210c, 0x1200301a, 0x20381b55,   // it.rm.un_220 fa.ps.sd_543  uz.ur.un_760 tr.tk.sq_442 
  0x122e0e07, 0x4436370c, 0x0000332d, 0x343b1204,   // is.fo.hu_432 ba.ab.kk_543  as.un.un_A00 ur.ks.ps_332 
  // [3fb0]
  0x5d4c1207, 0x2d001219, 0x2b001b07, 0x34003b2b,   // hu.wo.ss_432 hu.sk.un_750  tr.vi.un_420 ks.ps.un_980 
  0x31004d0c, 0x51000405, 0x0413fea9, 0x2b004c05,   // aa.az.un_530 fi.kl.un_330  tlh.et.fi_544 wo.vi.un_330 
  0x21123404, 0x0c067907, 0x220627a0, 0x040735a0,   // ps.ur.fa_332 war.de.sv_432  gd.de.oc_322 tg.bg.ru_322 
  0x3f00fc11, 0x53000602, 0xfc002713, 0x480c0412,   // zzp.af.un_630 de.ht.un_220  gd.zzp.un_650 fi.sv.tt_654 
  // [3fc0]
  0x28003011, 0x0c00fc04, 0x443723a4, 0x5c100f07,   // uz.sd.un_630 zzp.sv.un_320  ky.ba.kk_433 lv.lt.sa_432 
  0x282a18a4, 0x2f0e43ee, 0x060c08a0, 0x48004613,   // ga.mt.sw_433 ie.is.su_422  no.sv.de_322 qu.tt.un_650 
  0x40067904, 0x6b001508, 0x432406a4, 0x246b25ee,   // war.de.lb_332 un.ceb.un_430  de.eo.ie_433 eu.ceb.eo_422 
  0x04135c04, 0x3f06080c, 0x524d58af, 0x04470ea4,   // sa.et.fi_332 no.de.af_543  om.aa.ha_655 is.sn.fi_433 
  // [3fd0]
  0x0f180607, 0x400613a7, 0x06200c04, 0x131a3402,   // de.ga.lv_432 et.de.lb_532  sv.sq.de_332 xh.tl.et_222 
  0x3f3709a9, 0x6b012b07, 0x15000602, 0x30350807,   // pl.st.af_544 vi.en.ceb_432  de.un.un_220 uk.tg.uz_432 
  0x1300060e, 0x37040708, 0x3e1105a0, 0x03001514,   // de.et.un_550 bg.ru.ba_443  fr.ro.rm_322 un.nl.un_660 
  0x6b1a7908, 0x060c79a4, 0x3b255208, 0x22005c07,   // war.tl.ceb_443 war.sv.de_433  ha.eu.so_443 sa.oc.un_420 
  // [3fe0]
  0x330836a4, 0x2d00060c, 0x1228180c, 0x30231509,   // gn.no.nn_433 de.sk.un_530  ar.sd.ur_543 un.ky.uz_444 
  0x251a6b60, 0x2e000104, 0x34001205, 0x4a000a19,   // ceb.tl.eu_664 en.fo.un_320  ur.ps.un_330 pt.yo.un_750 
  0x3d123b07, 0x25004805, 0x20001108, 0x35003712,   // ks.ur.ku_432 tt.mn.un_330  ro.sq.un_430 ba.tg.un_640 
  0x5c090dec, 0xfc001a0d, 0x481511a4, 0x17000811,   // ne.hi.sa_644 tl.zzp.un_540  ro.tt.un_430 uk.sr.un_630 
  // [3ff0]
  0x0000fc37, 0x306b1a04, 0x0c000413, 0x040648a4,   // zzp.un.un_B00 tl.ceb.uz_332  fi.sv.un_650 tt.de.fi_433 
  0x21004402, 0x3000fc04, 0x130c0409, 0x18233d12,   // kk.fa.un_220 zzp.uz.un_320  fi.sv.et_444 ku.ky.ar_654 
  0x480604a9, 0x0e001119, 0x040c0655, 0x30251507,   // fi.de.tt_544 ro.is.un_750  de.sv.fi_442 un.mn.uz_432 
  0x63063f0c, 0x033f21a4, 0x0200430e, 0x21002814,   // af.de.sco_543 jw.af.nl_433  ie.da.un_550 sd.fa.un_660 
  
  // [4000]
  0x0c000414, 0x694376ad, 0x04000614, 0x303525a9,   // fi.sv.un_660 crs.ie.mfe_643  de.fi.un_660 mn.tg.uz_544 
  0x400604ee, 0x64353455, 0x52182402, 0x481c1eec,   // fi.de.lb_422 xh.zu.lg_442  eo.ga.ha_222 ms.id.tt_644 
  0x07171508, 0x3500370d, 0x09111704, 0x1b0833a9,   // un.sr.bg_443 st.zu.un_540  sr.ro.pl_332 nn.no.tr_544 
  0x3f000323, 0x0e2e4d12, 0x6540fe07, 0x3e004007,   // nl.af.un_880 aa.fo.is_654  tlh.lb.gv_432 lb.rm.un_420 
  // [4010]
  0x3e004023, 0x033f2c07, 0x65281fa0, 0x3d003005,   // lb.rm.un_880 fy.af.nl_432  cy.sw.gv_322 uz.ku.un_330 
  0x1e001d08, 0x3f022c04, 0x3f025a07, 0xfe35345a,   // la.ms.un_430 fy.da.af_332  sm.da.af_432 xh.zu.tlh_553 
  0x0710170c, 0x1f006113, 0x06400314, 0x1b692e0b,   // sr.be.bg_543 za.cy.un_650  nl.lb.de_666 fo.mfe.tr_542 
  0x654240ac, 0x03400613, 0x384c090c, 0x34003508,   // lb.co.gv_632 de.lb.nl_665  pl.wo.tk_543 zu.xh.un_430 
  // [4020]
  0x1e001c2c, 0x40001d0d, 0x04000609, 0x73006707,   // id.ms.un_990 la.lb.un_540  de.fi.un_440 ak.ny.un_420 
  0x0b003004, 0x350804a0, 0x652b3907, 0x241d3e07,   // uz.es.un_320 ru.uk.tg_322  br.vi.gv_432 rm.la.eo_432 
  0x28001213, 0x21283404, 0x1d07420c, 0x12213ba4,   // ur.sd.un_650 ps.sd.fa_332  co.it.la_543 ks.fa.ur_433 
  0x1b404d0c, 0x421dfcee, 0x15041712, 0x2f000104,   // aa.lb.tr_543 zzp.la.co_422  sr.ru.un_654 en.su.un_320 
  // [4030]
  0x1800211b, 0x17001007, 0x0c005804, 0x234448a0,   // fa.ar.un_770 be.sr.un_420  om.sv.un_320 tt.kk.ky_322 
  0x30070a08, 0x17002f04, 0x46000905, 0x1700150b,   // mk.bg.uz_443 su.sr.un_320  pl.qu.un_330 un.sr.un_520 
  0x102344a7, 0x201b480c, 0x0c000405, 0x07100aa0,   // kk.ky.be_532 tt.tr.sq_543  fi.sv.un_330 mk.be.bg_322 
  0x064008a9, 0x28343b04, 0x4376530d, 0x35100405,   // no.lb.de_544 ks.ps.sd_332  ht.crs.ie_554 ru.be.tg_333 
  // [4040]
  0x03330405, 0x576306ac, 0x30353c07, 0x38624d0c,   // fi.nn.nl_333 de.sco.na_632  ug.tg.uz_432 aa.kha.tk_543 
  0x4f0324ee, 0x76004319, 0x34003d19, 0x400203a4,   // eo.nl.bi_422 ie.crs.un_750  ku.ps.un_750 nl.da.lb_433 
  0x0f000c0c, 0x042c4007, 0x34001220, 0x0a1715a0,   // sv.lv.un_530 lb.fy.fi_432  ur.ps.un_850 un.sr.mk_322 
  0x381b4807, 0x364665ee, 0x0a35300c, 0x17003513,   // tt.tr.tk_432 gv.qu.gn_422  uz.tg.mk_543 tg.sr.un_650 
  // [4050]
  0x31202502, 0x04173c08, 0x4f00431a, 0x1b4f43a9,   // eu.sq.az_222 ug.sr.ru_443  ie.bi.un_760 ie.bi.tr_544 
  0x40003307, 0x764308a4, 0x42000508, 0x10301104,   // nn.lb.un_420 no.ie.crs_433  fr.co.un_430 ro.uz.be_332 
  0x301735af, 0x38734855, 0x0a373804, 0x35005413,   // tg.sr.uz_655 tt.ny.tk_442  tk.ba.mk_332 ik.zu.un_650 
  0x38002313, 0x06005304, 0x55003407, 0x20004804,   // ky.tk.un_650 ht.de.un_320  xh.rw.un_420 tt.sq.un_320 
  // [4060]
  0x1d477308, 0x103864ad, 0x4773780b, 0x3859550e,   // ny.sn.la_443 lg.tk.lt_643  ve.ny.sn_542 rw.rn.tk_555 
  0x782d47a4, 0x2e6455ee, 0x5d784712, 0x38006405,   // sn.sk.ve_433 rw.lg.fo_422  sn.ve.ss_654 lg.tk.un_330 
  0x352428a0, 0x09007312, 0x1d000f07, 0x5c2afea0,   // sw.eo.zu_322 ny.pl.un_640  lv.la.un_420 tlh.mt.sa_322 
  0x2a00fe08, 0x64007307, 0x76536912, 0x645559ad,   // tlh.mt.un_430 ny.lg.un_420  mfe.ht.crs_654 rn.rw.lg_643 
  // [4070]
  0x735d47ad, 0x47063b04, 0x18342304, 0x29303102,   // sn.ss.ny_643 so.de.sn_332  ky.ps.ar_332 az.uz.sl_222 
  0x35005002, 0x21183d11, 0x64555d04, 0x00001024,   // fj.zu.un_220 ku.ar.fa_653  ss.rw.lg_332 be.un.un_900 
  0x080f0204, 0x27002204, 0x34001522, 0x083361a7,   // da.lv.no_332 oc.gd.un_320  un.xh.un_870 za.nn.no_532 
  0x12002208, 0x23054d04, 0x353038ad, 0x184227ee,   // oc.hu.un_430 aa.fr.ca_332  tk.uz.tg_643 gd.co.ga_422 
  // [4080]
  0x0a1157a0, 0x213b1208, 0x5564610c, 0x1a1373a4,   // na.ro.pt_322 ur.ks.fa_443  za.lg.rw_543 ny.et.tl_433 
  0x47005d0c, 0x35286408, 0x0900fe05, 0x03000c04,   // ss.sn.un_530 lg.sw.zu_443  tlh.pl.un_330 sv.nl.un_320 
  0x735d095a, 0x28736205, 0x35002321, 0x03060cee,   // pl.ss.ny_553 kha.ny.sw_333  ky.tg.un_860 sv.de.nl_422 
  0x102e730c, 0x730947ec, 0x0973780c, 0x38005507,   // ny.fo.lt_543 sn.pl.ny_644  ve.ny.pl_543 rw.tk.un_420 
  // [4090]
  0x38002513, 0x3b004d12, 0x47097307, 0x3306fea0,   // mn.tk.un_650 aa.so.un_640  ny.pl.sn_432 tlh.de.nn_322 
  0x05001d1b, 0x0f690307, 0x6b5f56a7, 0x31003407,   // la.fr.un_770 nl.mfe.lv_432  mg.tn.ceb_532 xh.az.un_420 
  0x2e330808, 0x69115314, 0x23153807, 0x1c121eaf,   // no.nn.fo_443 ht.ro.mfe_666  tk.ky.un_420 ms.hu.id_655 
  0x00006b0a, 0x185c6507, 0x0b421807, 0x2a22230c,   // ceb.un.un_500 gv.sa.ga_432  ga.co.es_432 ca.oc.mt_543 
  // [40a0]
  0x18135ca4, 0x39006b02, 0x1800fe1a, 0x3000382b,   // sa.et.ga_433 ceb.br.un_220  tlh.ga.un_760 tk.uz.un_980 
  0x0f2539af, 0x303464a9, 0x083725ee, 0x22120a05,   // br.eu.lv_655 lg.xh.uz_544  mn.ba.uk_422 pt.hu.oc_333 
  0x2e54505a, 0x3f122204, 0x5d006411, 0x3b00280e,   // fj.ik.fo_553 oc.hu.af_332  lg.ss.un_630 sd.ks.un_550 
  0x22120aaf, 0x2500100e, 0x51132ea4, 0x79537655,   // pt.hu.oc_655 be.mn.un_550  fo.et.kl_433 crs.ht.war_442 
  // [40b0]
  0x120a2211, 0xfe00530e, 0x133101a0, 0xfe5c450c,   // oc.pt.hu_653 ht.tlh.un_550  en.az.et_322 ln.sa.tlh_543 
  0x170704ee, 0x331308a0, 0x483738a4, 0x28002302,   // ru.bg.sr_422 no.et.nn_322  tk.ba.tt_433 ky.sd.un_220 
  0x691b3105, 0x1504070e, 0x082338a0, 0x2300180c,   // az.tr.mfe_333 bg.ru.un_555  tk.ky.uk_322 ar.ky.un_530 
  0x113c30a9, 0x38234408, 0x3d3421a7, 0x342112a7,   // uz.ug.ro_544 kk.ky.tk_443  fa.ps.ku_532 ur.fa.ps_532 
  // [40c0]
  0x6e6b6804, 0x343c3055, 0x1707350c, 0x0c003808,   // ig.ceb.hmn_332 uz.ug.ps_442  tg.bg.sr_543 tk.sv.un_430 
  0x0a170708, 0x170a1507, 0x53003804, 0x21183408,   // bg.sr.mk_443 un.mk.sr_432  tk.ht.un_320 ps.ar.fa_443 
  0x12213bad, 0x0e382202, 0x28496aad, 0x122d0daf,   // ks.fa.ur_643 oc.tk.is_222  haw.to.sw_643 cs.sk.hu_655 
  0x026a640c, 0x150717a4, 0x063202a0, 0x122d0d60,   // lg.haw.da_543 sr.bg.un_433  da.bs.de_322 cs.sk.hu_664 
  // [40d0]
  0x29045a12, 0x21464c0c, 0x0a00081a, 0x2a645255,   // sm.fi.sl_654 wo.qu.jw_543  uk.mk.un_760 ha.lg.mt_442 
  0x184547a4, 0x5a245ea6, 0x38002c02, 0x27651f0c,   // sn.ln.ga_433 ts.eo.sm_521  fy.tk.un_220 cy.gv.gd_543 
  0x0e321704, 0x330838a0, 0x300804ee, 0x0e2d0d08,   // sr.bs.is_332 tk.no.nn_322  ru.uk.uz_422 cs.sk.is_443 
  0x0e004a05, 0x153710a9, 0x1b5e2fee, 0x5a494b12,   // yo.is.un_330 be.ba.un_544  su.ts.tr_422 mi.to.sm_654 
  // [40e0]
  0x081707ee, 0x3f003905, 0x12497604, 0x4b00501b,   // bg.sr.uk_422 br.af.un_330  crs.to.hu_332 fj.mi.un_770 
  0x18276514, 0x49006a0b, 0x15570611, 0x1d001e02,   // gv.gd.ga_666 haw.to.un_520  de.na.un_653 ms.la.un_220 
  0x53000502, 0x03063f08, 0x2a1f63ad, 0x2f1e12a4,   // fr.ht.un_220 af.de.nl_443  sco.cy.mt_643 hu.ms.su_433 
  0x34211207, 0x3f2c5108, 0x1f006120, 0x65273fee,   // ur.fa.ps_432 kl.fy.af_443  za.cy.un_850 af.gd.gv_422 
  // [40f0]
  0x3f006507, 0x041115a4, 0x65080202, 0x3c002108,   // gv.af.un_420 un.ro.ru_433  da.no.gv_222 fa.ug.un_430 
  0x3031380d, 0x18000607, 0x30004d07, 0x2d004907,   // tk.az.uz_554 de.ga.un_420  aa.uz.un_420 to.sk.un_420 
  0x35001509, 0x53000402, 0x08070a13, 0x21184405,   // un.tg.un_440 fi.ht.un_220  mk.bg.uk_665 kk.ar.fa_333 
  0x06000c05, 0x2123440b, 0x0a083509, 0x6400fc1b,   // sv.de.un_330 kk.ky.fa_542  tg.uk.mk_444 zzp.lg.un_770 
  // [4100]
  0x43006907, 0x08003f05, 0x0200fc05, 0x0d130911,   // mfe.ie.un_420 af.no.un_330  zzp.da.un_330 hi.bh.ne_653 
  0x6b1f0207, 0x38484413, 0x40001c02, 0x68fc2907,   // da.cy.ceb_432 kk.tt.tk_665  id.lb.un_220 sl.zzp.ig_432 
  0x1c000d19, 0x35000402, 0x1700360c, 0x51424d0c,   // ne.mr.un_750 ru.tg.un_220  ab.sr.un_530 aa.co.kl_543 
  0x3e172904, 0x3d3c23ad, 0x4410110c, 0x65001c04,   // sl.sr.rm_332 ky.ug.ku_643  ro.be.kk_543 id.gv.un_320 
  // [4110]
  0x15374408, 0x183d210c, 0x1b3148a0, 0x20004c05,   // kk.ba.un_443 fa.ku.ar_543  tt.az.tr_322 wo.sq.un_330 
  0x0f005c1b, 0x5c100fad, 0x2112180c, 0x3d1221a6,   // sa.lv.un_770 lv.lt.sa_643  ar.ur.fa_543 fa.ur.ku_521 
  0x07001f04, 0x58524da7, 0x4400230b, 0x0400360b,   // cy.it.un_320 aa.ha.om_532  ky.kk.un_520 ab.ru.un_520 
  0x343d21a4, 0x355d2ea6, 0x5c000f07, 0x0c00020e,   // fa.ku.ps_433 fo.ss.zu_521  lv.sa.un_420 da.sv.un_550 
  // [4120]
  0x4830380c, 0x1000fe0d, 0x120306ee, 0x07003c08,   // tk.uz.tt_543 tlh.lt.un_540  de.nl.hu_422 ug.bg.un_430 
  0x4057060c, 0x48000218, 0x0c02035a, 0x0c021f07,   // de.na.lb_543 da.tt.un_740  nl.da.sv_553 cy.da.sv_432 
  0x2a00fc02, 0x03400608, 0x02601f11, 0x33021f0c,   // zzp.mt.un_220 de.lb.nl_443  cy.vo.da_653 cy.da.nn_543 
  0x04001107, 0x06004d08, 0x2afe3f07, 0x5c001c14,   // ro.ru.un_420 aa.de.un_430  af.tlh.mt_432 mr.sa.un_660 
  // [4130]
  0x00004401, 0x303515a4, 0x04003607, 0x38031fee,   // kk.un.un_200 un.tg.uz_433  ab.ru.un_420 cy.nl.tk_422 
  0x3f0357ee, 0x231f38a4, 0x32021fee, 0x23443704,   // na.nl.af_422 tk.cy.ca_433  cy.da.bs_422 ba.kk.ky_332 
  0x342818ee, 0x44381004, 0x283421a4, 0x4a006813,   // ar.sd.ps_422 be.tk.kk_332  fa.ps.sd_433 ig.yo.un_650 
  0x11423ea4, 0x483744ec, 0x11150405, 0x0a08070d,   // rm.co.ro_433 kk.ba.tt_644  ru.ro.un_330 bg.uk.mk_554 
  // [4140]
  0x0a1707a9, 0x122a21a4, 0x1c00090b, 0x170a11ee,   // bg.sr.mk_544 jw.mt.hu_433  hi.mr.un_520 ro.mk.sr_422 
  0x213d3007, 0x0d002e0c, 0x27003b02, 0x215c5e12,   // uz.ku.fa_432 fo.cs.un_530  so.gd.un_220 ts.sa.jw_654 
  0x0a3035a4, 0x04070aa9, 0x3c00351a, 0x1c002108,   // tg.uz.mk_433 mk.bg.ru_544  tg.ug.un_760 jw.id.un_430 
  0x42001107, 0x231828a4, 0x380a070c, 0x421d19a0,   // ro.co.un_420 sd.ar.ky_433  bg.mk.tk_543 gl.la.co_322 
  // [4150]
  0x44070aa4, 0x080437ee, 0x2d001f1a, 0x213b440c,   // mk.bg.kk_433 ba.ru.uk_422  cy.sk.un_760 kk.ks.fa_543 
  0x35002520, 0x35003c14, 0x0a040714, 0x10001f19,   // mn.tg.un_850 ug.tg.un_660  bg.ru.mk_666 cy.lt.un_750 
  0x0e000d07, 0x65001f04, 0x3b002005, 0x38004804,   // cs.is.un_420 cy.gv.un_320  sq.so.un_330 tt.tk.un_320 
  0x0a3625af, 0x34211813, 0x07150404, 0x2100341a,   // mn.ab.mk_655 ar.fa.ps_665  ru.bg.un_320 ps.fa.un_760 
  // [4160]
  0x1b2d0d55, 0x1f000202, 0x0e2e0c04, 0x363035ad,   // cs.sk.tr_442 da.cy.un_220  sv.fo.is_332 tg.uz.ab_643 
  0x07003707, 0x1b00200d, 0x080410ee, 0x2a002904,   // ba.bg.un_420 sq.tr.un_540  be.ru.uk_422 sl.mt.un_320 
  0x20001104, 0x35003808, 0x0c0e2eee, 0x31002804,   // ro.sq.un_320 tk.zu.un_430  fo.is.sv_422 sw.az.un_320 
  0x37004423, 0x27000607, 0x3600470d, 0x162947a4,   // kk.ba.un_880 de.gd.un_420  sn.gn.un_540 sn.sl.hr_433 
  // [4170]
  0x07000a22, 0x330f100c, 0x24000605, 0x443837ac,   // mk.bg.un_870 lt.lv.nn_543  de.eo.un_330 ba.tk.kk_632 
  0x02000304, 0x1c002b07, 0x5e5f5d04, 0x29004708,   // nl.da.un_320 vi.id.un_420  ss.tn.ts_332 sn.sl.un_430 
  0x0c0e2e02, 0x38233c12, 0x1c001512, 0x40000202,   // fo.is.sv_222 ug.ky.tk_654  un.id.un_640 da.lb.un_220 
  0x46330808, 0x0c545ca4, 0x17003904, 0x791a6b12,   // no.nn.qu_443 sa.ik.sv_433  br.sr.un_320 ceb.tl.war_654 
  // [4180]
  0x7300280d, 0x5a001e02, 0x5100620d, 0x551a07ee,   // sw.ny.un_540 ms.sm.un_220  kha.kl.un_540 it.tl.rw_422 
  0x10561508, 0x2f007907, 0x3b002d04, 0x444815a0,   // un.mg.lt_443 war.su.un_420  sk.so.un_320 un.tt.kk_322 
  0x1d13040e, 0x043715a6, 0x40004604, 0x2a0f3e07,   // fi.et.la_555 un.ba.ru_521  qu.lb.un_320 rm.lv.mt_432 
  0x132e0ca0, 0x170a07ec, 0x5c000414, 0x381b3111,   // sv.fo.et_322 bg.mk.sr_644  fi.sa.un_660 az.tr.tk_653 
  // [4190]
  0x03005107, 0x12282113, 0x46003613, 0x2a100f0c,   // kl.nl.un_420 fa.sd.ur_665  gn.qu.un_650 lv.lt.mt_543 
  0x035c0c04, 0x5c0d1c08, 0x5c00130c, 0x2812180b,   // sv.sa.nl_332 mr.ne.sa_443  et.sa.un_530 ar.ur.sd_542 
  0x5c001d02, 0x1a001304, 0x33254007, 0x07361704,   // la.sa.un_220 et.tl.un_320  lb.eu.nn_432 sr.ab.bg_332 
  0x351744a0, 0x04002508, 0x483504a0, 0x062103ee,   // kk.sr.tg_322 eu.fi.un_430  ru.tg.tt_322 nl.jw.de_422 
  // [41a0]
  0x1900230e, 0x2925feee, 0x2c00040d, 0x0205fe05,   // ca.gl.un_550 tlh.eu.sl_422  fi.fy.un_540 tlh.fr.da_333 
  0x2508400c, 0x40002521, 0x1f00fe11, 0x6b0829ee,   // lb.no.eu_543 eu.lb.un_860  tlh.cy.un_630 sl.no.ceb_422 
  0x1d004c04, 0x01632e04, 0x252c0312, 0x212f0204,   // wo.la.un_320 fo.sco.en_332  nl.fy.eu_654 da.su.jw_332 
  0x1c0d5ca4, 0x47002507, 0x33000402, 0x5725610c,   // sa.ne.mr_433 eu.sn.un_420  fi.nn.un_220 za.eu.na_543 
  // [41b0]
  0x442336ee, 0x403f2508, 0x21002505, 0x2130120c,   // ab.ky.kk_422 eu.af.lb_443  eu.jw.un_330 ur.uz.fa_543 
  0xfe5330a4, 0x1b00380d, 0x44182804, 0x06000c19,   // uz.ht.tlh_433 tk.tr.un_540  sd.ar.kk_332 sv.de.un_750 
  0x23025655, 0x25002304, 0x0600570e, 0x38311b04,   // mg.da.ca_442 ky.mn.un_320  na.de.un_550 tr.az.tk_332 
  0x4f00fe1a, 0x10080407, 0x212f1cee, 0x5369fead,   // tlh.bi.un_760 ru.uk.be_432  id.su.jw_422 tlh.mfe.ht_643 
  // [41c0]
  0xfe00090e, 0x1800230e, 0x6b733b04, 0x3c2344ac,   // pl.tlh.un_550 ky.ar.un_550  so.ny.ceb_332 kk.ky.ug_632 
  0x67003b1a, 0x2c003b02, 0x37796bec, 0x6b374b0d,   // so.ak.un_760 so.fy.un_220  ceb.war.st_644 mi.st.ceb_554 
  0x2800610d, 0x2f3b1ca4, 0x19240ba0, 0x044807a0,   // za.sw.un_540 id.so.su_433  es.eo.gl_322 bg.tt.ru_322 
  0x1e28560c, 0x375f60a9, 0x2d090604, 0x2c001f19,   // mg.sw.ms_543 vo.tn.st_544  de.pl.sk_332 cy.fy.un_750 
  // [41d0]
  0x2f1e1ca4, 0x1e131c07, 0x1c00020c, 0x55005609,   // id.ms.su_433 id.et.ms_432  da.id.un_530 mg.rw.un_440 
  0x1a003b0d, 0x1b003122, 0x5c005612, 0x21626a09,   // so.tl.un_540 az.tr.un_870  mg.sa.un_640 haw.kha.jw_444 
  0x1c1309a7, 0x1a526007, 0x55565912, 0x530f5a04,   // hi.bh.mr_532 vo.ha.tl_432  rn.mg.rw_654 sm.lv.ht_332 
  0x06403e02, 0x1a561ca0, 0x44002514, 0x152f400c,   // rm.lb.de_222 id.mg.tl_322  mn.kk.un_660 lb.su.un_543 
  // [41e0]
  0x1221340d, 0x3b004e0d, 0x22242009, 0x511226ec,   // ps.fa.ur_554 ay.so.un_540  sq.eo.oc_444 ia.hu.kl_644 
  0x30002519, 0x44002302, 0x05002007, 0x03fc0408,   // mn.uz.un_750 ky.kk.un_220  sq.fr.un_420 fi.zzp.nl_443 
  0x3c3d21ee, 0x531a79ee, 0x01001604, 0x2c650404,   // fa.ku.ug_422 war.tl.ht_422  hr.en.un_320 fi.gv.fy_332 
  0x1d004604, 0x01696307, 0x3728130b, 0x151138af,   // qu.la.un_320 sco.mfe.en_432  et.sw.st_542 tk.ro.un_655 
  // [41f0]
  0x6a371313, 0x4b003712, 0x01005304, 0x321636ec,   // et.st.haw_665 st.mi.un_640  ht.en.un_320 gn.hr.bs_644 
  0x533101a0, 0x21182805, 0x6300460d, 0x3023170c,   // en.az.ht_322 sd.ar.fa_333  qu.sco.un_540 sr.ky.uz_543 
  0x654c6b04, 0x172916ad, 0x443c2311, 0x57630107,   // ceb.wo.gv_332 hr.sl.sr_643  ky.ug.kk_653 en.sco.na_432 
  0x3755210c, 0x37483c14, 0x0a441702, 0x1812210c,   // jw.rw.st_543 ug.tt.ba_666  sr.kk.mk_222 fa.ur.ar_543 
  // [4200]
  0x374b060c, 0x11001519, 0x184434ad, 0x364b28af,   // de.mi.st_543 un.ro.un_750  ps.kk.ar_643 sw.mi.gn_655 
  0x0600370c, 0x0a0417a4, 0x362949a0, 0x0c006107,   // st.de.un_530 sr.ru.mk_433  to.sl.gn_322 za.sv.un_420 
  0x4415360c, 0x281832ad, 0x5d005e21, 0x1d11240c,   // ab.kk.un_530 bs.ar.sd_643  ts.ss.un_860 eo.ro.la_543 
  0x6b6579ad, 0x0000602d, 0x0240080c, 0x582408a4,   // war.gv.ceb_643 vo.un.un_A00  no.lb.da_543 no.eo.om_433 
  // [4210]
  0x3d001813, 0x4435230c, 0x06000119, 0x52272f0d,   // ar.ku.un_650 ky.tg.kk_543  en.de.un_750 su.gd.ha_554 
  0x47007812, 0x02114c0c, 0x45534aad, 0x6a004c22,   // ve.sn.un_640 wo.ro.da_543  yo.ht.ln_643 wo.haw.un_870 
  0x47005a04, 0x24000104, 0x4c00132b, 0x3e3b0bee,   // sm.sn.un_320 en.eo.un_320  et.wo.un_980 es.so.rm_422 
  0x11656212, 0x36000b0c, 0x2c00180d, 0x19423ead,   // kha.gv.ro_654 es.gn.un_530  ga.fy.un_540 rm.co.gl_643 
  // [4220]
  0x4a004c2b, 0x0b0a190c, 0x4a191e07, 0x08072555,   // wo.yo.un_980 gl.pt.es_543  ms.gl.yo_432 mn.bg.uk_442 
  0x1d3b67ad, 0x1c273908, 0x46006704, 0x4a63010b,   // ak.so.la_643 br.gd.id_443  ak.qu.un_320 en.sco.yo_542 
  0x1f2421ee, 0x114c6713, 0x374c21ad, 0x25603e60,   // jw.eo.cy_422 ak.wo.ro_665  jw.wo.st_643 rm.vo.eu_664 
  0x51003604, 0x35303707, 0x60431a0c, 0x47347307,   // gn.kl.un_320 ba.uz.tg_432  tl.ie.vo_543 ny.xh.sn_432 
  // [4230]
  0x27001802, 0x674c4a60, 0x0d1b3b07, 0x6500200e,   // ga.gd.un_220 yo.wo.ak_664  so.tr.cs_432 sq.gv.un_550 
  0x5d4773ad, 0x483c2307, 0x583435a4, 0x2f1e1c11,   // ny.sn.ss_643 ky.ug.tt_432  zu.xh.om_433 id.ms.su_653 
  0x4400301a, 0x6a00672a, 0x00004037, 0x28343c04,   // uz.kk.un_760 ak.haw.un_970  lb.un.un_B00 ug.ps.sd_332 
  0x1007250c, 0x524a1e12, 0x055569ee, 0x3b005822,   // mn.bg.be_543 ms.yo.ha_654  mfe.rw.fr_422 om.so.un_870 
  // [4240]
  0x5369760c, 0x38003c04, 0x35003412, 0x015265a0,   // crs.mfe.ht_543 ug.tk.un_320  xh.zu.un_640 gv.ha.en_322 
  0x5c0913ee, 0x51003f08, 0x311b3807, 0x054023a7,   // bh.hi.sa_422 af.kl.un_430  tk.tr.az_432 ca.lb.fr_532 
  0x2a0f0ca7, 0x011a790c, 0x3534590e, 0x34211212,   // sv.lv.mt_532 war.tl.en_543  rn.xh.zu_555 ur.fa.ps_654 
  0x374438ee, 0x655e2702, 0x5c1c09a7, 0x11006302,   // tk.kk.ba_422 gd.ts.gv_222  hi.mr.sa_532 sco.ro.un_220 
  // [4250]
  0x53002404, 0x0b003318, 0x1b003813, 0x31005814,   // eo.ht.un_320 as.bn.un_740  tk.tr.un_650 om.az.un_660 
  0xfe00650c, 0x15001704, 0x25153507, 0xfe00310d,   // gv.tlh.un_530 sr.un.un_320  tg.mn.un_420 az.tlh.un_540 
  0x08003507, 0x48000e0c, 0x231015ee, 0x3c00231b,   // tg.uk.un_420 is.tt.un_530  un.be.ky_422 ky.ug.un_770 
  0x484437a9, 0x600448ad, 0x0c04480c, 0x2310170c,   // ba.kk.tt_544 tt.fi.vo_643  tt.fi.sv_543 sr.be.ky_543 
  // [4260]
  0x48046007, 0x0700150e, 0x040c48ad, 0x080407ad,   // vo.fi.tt_432 un.bg.un_550  tt.sv.fi_643 bg.ru.uk_643 
  0x2f001d02, 0x48600414, 0x01000602, 0x0a003513,   // la.su.un_220 fi.vo.tt_666  de.en.un_220 tg.mk.un_650 
  0x04000c02, 0x07083caf, 0x1000151b, 0x4c574608,   // sv.fi.un_220 ug.uk.bg_655  un.be.un_770 qu.na.wo_443 
  0x10001708, 0x00000424, 0x630c1012, 0x04000621,   // sr.be.un_430 fi.un.un_900  lt.sv.sco_654 de.fi.un_860 
  // [4270]
  0x1a206502, 0x0448060c, 0x04006018, 0x30002e34,   // gv.sq.tl_222 de.tt.fi_543  vo.fi.un_740 fo.uz.un_A80 
  0xfe477307, 0x01002702, 0x2500231b, 0x24214605,   // ny.sn.tlh_432 gd.en.un_220  ky.mn.un_770 qu.jw.eo_333 
  0x28211207, 0x211318ee, 0x341a210c, 0x30003104,   // ur.fa.sd_432 ga.et.jw_422  jw.tl.xh_543 az.uz.un_320 
  0x58004d14, 0x030c08a0, 0x00000e2d, 0x04005104,   // aa.om.un_660 no.sv.nl_322  is.un.un_A00 kl.fi.un_320 
  // [4280]
  0x1d001309, 0x38002005, 0x35345c0c, 0x48311ba0,   // et.la.un_440 sq.tk.un_330  sa.xh.zu_543 tr.az.tt_322 
  0x1c091311, 0x5c1827ec, 0x07002308, 0x06273408,   // bh.hi.mr_653 gd.ga.sa_644  ky.bg.un_430 xh.gd.de_443 
  0x06330cad, 0x0e1b06a0, 0x38400607, 0x00002c37,   // sv.nn.de_643 de.tr.is_322  de.lb.tk_432 fy.un.un_B00 
  0x18005c19, 0x4800fc04, 0x407608a4, 0x063461ad,   // sa.ga.un_750 zzp.tt.un_320  no.crs.lb_433 za.xh.de_643 
  // [4290]
  0x060c6012, 0x135c2507, 0x030604ad, 0x155d24ee,   // vo.sv.de_654 eu.sa.et_432  fi.de.nl_643 eo.ss.un_422 
  0x15080408, 0x06005722, 0x252a1dec, 0x695376a4,   // ru.uk.un_443 na.de.un_870  la.mt.eu_644 crs.ht.mfe_433 
  0x21001112, 0x12005c02, 0x0b2c03a4, 0x03006e07,   // ro.jw.un_640 sa.hu.un_220  nl.fy.es_433 hmn.nl.un_420 
  0x093f33ee, 0x25402c07, 0x21123d04, 0x0e001204,   // nn.af.pl_422 fy.lb.eu_432  ku.ur.fa_332 hu.is.un_320 
  // [42a0]
  0x233004a7, 0xfc001807, 0x180627ac, 0x3c122804,   // ru.uz.ky_532 ga.zzp.un_420  gd.de.ga_632 sd.ur.ug_332 
  0x0c00481b, 0x0c0476a0, 0x62275c08, 0x40000c07,   // tt.sv.un_770 crs.fi.sv_322  sa.gd.kha_443 sv.lb.un_420 
  0x35182707, 0x12003e02, 0x2c3f090c, 0x050a43ee,   // gd.ga.zu_432 rm.hu.un_220  pl.af.fy_543 ie.pt.fr_422 
  0x02006e08, 0x12003411, 0x0c0676a9, 0x036b09ad,   // hmn.da.un_430 ps.ur.un_630  crs.de.sv_544 pl.ceb.nl_643 
  // [42b0]
  0xfc004204, 0x1d2a0107, 0x46003b04, 0x5c0c65a0,   // co.zzp.un_320 en.mt.la_432  so.qu.un_320 gv.sv.sa_322 
  0x2f2d0d04, 0x18003d07, 0x18332e07, 0x112a1d07,   // cs.sk.su_332 ku.ar.un_420  fo.nn.ga_432 la.mt.ro_432 
  0x3b000f02, 0x1d000405, 0x53005c0c, 0x20003302,   // lv.so.un_220 fi.la.un_330  sa.ht.un_530 nn.sq.un_220 
  0x3e00420e, 0x51001d0c, 0x2c0603a0, 0x313b0904,   // co.rm.un_550 la.kl.un_530  nl.de.fy_322 pl.so.az_332 
  // [42c0]
  0x2130340c, 0x24000409, 0x12002114, 0x041d63ee,   // ps.uz.fa_543 fi.eo.un_440  fa.ur.un_660 sco.la.fi_422 
  0x0c5c0404, 0x21003423, 0x23004419, 0x20002508,   // fi.sa.sv_332 ps.fa.un_880  kk.ky.un_750 eu.sq.un_430 
  0x47007305, 0x35005d21, 0x35475060, 0x043707ad,   // ny.sn.un_330 ss.zu.un_860  fj.sn.zu_664 bg.ba.ru_643 
  0x3c38150c, 0x041510a9, 0x375e0204, 0x5600250d,   // un.tk.ug_543 be.ru.un_540  da.ts.st_332 eu.mg.un_540 
  // [42d0]
  0x5b482e08, 0x30391eee, 0x64733512, 0x565338ad,   // fo.tt.sg_443 ms.br.uz_422  zu.ny.lg_654 tk.ht.mg_643 
  0x1b4253a4, 0x5935470c, 0x0d4f01a0, 0x170d2da4,   // ht.co.tr_433 sn.zu.rn_543  en.bi.cs_322 sk.cs.sr_433 
  0x20253304, 0x375f2da0, 0x7300450d, 0x30253911,   // nn.eu.sq_332 sk.tn.st_322  ln.ny.un_540 br.eu.uz_653 
  0x47fe08a0, 0x58fc65a4, 0x352e47a9, 0x24111ba4,   // no.tlh.sn_322 gv.zzp.om_433  sn.fo.zu_544 tr.ro.eo_433 
  // [42e0]
  0x11257612, 0x02477308, 0x3012280d, 0x0d091caf,   // crs.eu.ro_654 ny.sn.da_443  sd.ur.uz_554 mr.hi.ne_655 
  0x11007611, 0x64035708, 0x7335470c, 0x1d101fa4,   // crs.ro.un_630 na.nl.lg_443  sn.zu.ny_543 cy.lt.la_433 
  0x4735340e, 0x1f21610c, 0x53007319, 0x73005e1a,   // xh.zu.sn_555 za.jw.cy_543  ny.ht.un_750 ts.ny.un_760 
  0x04101702, 0x34282104, 0x564569a7, 0x0f5c4b0c,   // sr.be.ru_222 fa.sd.ps_332  mfe.ln.mg_532 mi.sa.lv_543 
  // [42f0]
  0x47241907, 0x330c3eee, 0x20003104, 0x1600390d,   // gl.eo.sn_432 rm.sv.nn_422  az.sq.un_320 br.hr.un_540 
  0x21001808, 0x213c3d0d, 0x34354712, 0x18006507,   // ar.fa.un_430 ku.ug.fa_554  sn.zu.xh_654 gv.ga.un_420 
  0x152310a4, 0x23260da4, 0x5e4073a7, 0x49001d08,   // be.ky.un_433 cs.ia.ca_433  ny.lb.ts_532 la.to.un_430 
  0x5d00fc12, 0x370415a4, 0x15420ea9, 0x0e330809,   // zzp.ss.un_640 un.ru.ba_433  is.co.un_544 no.nn.is_444 
  // [4300]
  0x283659a9, 0x25003021, 0xfc0c67ad, 0x17040705,   // rn.gn.sw_544 uz.mn.un_860  ak.sv.zzp_643 bg.ru.sr_333 
  0x42fc0704, 0x595539a4, 0x1b32fc07, 0x02691f12,   // it.zzp.co_332 br.rw.rn_433  zzp.bs.tr_432 cy.mfe.da_654 
  0x5c130d5a, 0x0d5c0912, 0x480a1511, 0x63531fa0,   // ne.bh.sa_553 hi.sa.ne_654  un.mk.tt_653 cy.ht.sco_322 
  0x293830a0, 0x07003702, 0x4800352a, 0x343d28ee,   // uz.tk.sl_322 ba.bg.un_220  tg.tt.un_970 sd.ku.ps_422 
  // [4310]
  0x3d003c08, 0x2a30200c, 0x3e006504, 0x17233502,   // ug.ku.un_430 sq.uz.mt_543  gv.rm.un_320 tg.ky.sr_222 
  0x03061fa9, 0x47002811, 0x08000707, 0x18003e02,   // cy.de.nl_544 sw.sn.un_630  bg.uk.un_420 rm.ga.un_220 
  0x07303c04, 0x3b003d14, 0x12002805, 0x4900682b,   // ug.uz.bg_332 ku.ks.un_660  sd.ur.un_330 ig.to.un_980 
  0x3e002509, 0x00002b2d, 0x2a042508, 0x02002219,   // eu.rm.un_440 vi.un.un_A00  eu.fi.mt_443 oc.da.un_750 
  // [4320]
  0x5700041a, 0x653031a6, 0x344418a9, 0x3f0f620d,   // fi.na.un_760 az.uz.gv_521  ar.kk.ps_544 kha.lv.af_554 
  0x2a002702, 0x05002209, 0x254922a9, 0x68256a08,   // gd.mt.un_220 oc.fr.un_440  oc.to.eu_544 haw.eu.ig_443 
  0x0d0913a7, 0x33253e0c, 0x5a502b12, 0x023031ee,   // bh.hi.ne_532 rm.eu.nn_543  vi.fj.sm_654 az.uz.da_422 
  0x23003514, 0x31025209, 0x494b6a09, 0x2c000313,   // tg.ky.un_660 ha.da.az_444  haw.mi.to_444 nl.fy.un_650 
  // [4330]
  0x1e6e02a0, 0xfc011507, 0x45690509, 0x585c27a4,   // da.hmn.ms_322 un.en.zzp_432  fr.mfe.ln_444 gd.sa.om_433 
  0xfc6a545a, 0x5c496813, 0x34281204, 0x55000802,   // ik.haw.zzp_553 ig.to.sa_665  ur.sd.ps_332 no.rw.un_220 
  0x24002b21, 0x39250312, 0x091c0daf, 0x1253570c,   // vi.eo.un_860 nl.eu.br_654  ne.mr.hi_655 na.ht.hu_543 
  0x40232aa0, 0x0f230408, 0x09005719, 0x62040508,   // mt.ca.lb_322 fi.ca.lv_443  na.pl.un_750 fr.fi.kha_443 
  // [4340]
  0x2539080b, 0x62005234, 0x693f1ca4, 0x342b6211,   // no.br.eu_542 ha.kha.un_A80  id.af.mfe_433 kha.vi.xh_653 
  0x06041d0c, 0x3e000504, 0x0a301705, 0x0b001802,   // la.fi.de_543 fr.rm.un_320  sr.uz.mk_333 ga.es.un_220 
  0x4c4e2ba9, 0x30170a0d, 0x6a2749a9, 0x48003508,   // vi.ay.wo_544 mk.sr.uz_554  to.gd.haw_544 tg.tt.un_430 
  0x4844370b, 0x76536913, 0x6430315a, 0x104006a0,   // ba.kk.tt_542 mfe.ht.crs_665  az.uz.lg_553 de.lb.lt_322 
  // [4350]
  0x0c381b04, 0x65000e07, 0x18281208, 0x31002007,   // tr.tk.sv_332 is.gv.un_420  ur.sd.ar_443 sq.az.un_420 
  0x21003005, 0x2e1a4202, 0x2a000902, 0x2a4d200c,   // uz.fa.un_330 co.tl.fo_222  pl.mt.un_220 sq.aa.mt_543 
  0x17070a0e, 0x04131a04, 0x51003804, 0x2a2d3f04,   // mk.bg.sr_555 tl.et.fi_332  tk.kl.un_320 af.sk.mt_332 
  0x171604a0, 0x652501a0, 0x4600610e, 0x54655812,   // fi.hr.sr_322 en.eu.gv_322  za.qu.un_550 om.gv.ik_654 
  // [4360]
  0x13092d04, 0x0d000302, 0x0a07200c, 0x122118ee,   // sk.pl.et_332 nl.cs.un_220  sq.it.pt_543 ar.fa.ur_422 
  0x2665010c, 0x49511304, 0x125820ad, 0x30183dec,   // en.gv.ia_543 et.kl.to_332  sq.om.hu_643 ku.ar.uz_644 
  0x65634da4, 0x3b003c0e, 0x58384dec, 0x0c630107,   // aa.sco.gv_433 ug.ks.un_550  aa.tk.om_644 en.sco.sv_432 
  0xfc275808, 0x30042508, 0x281827ad, 0x2a482507,   // om.gd.zzp_443 mn.ru.uz_443  gd.ga.sw_643 eu.tt.mt_432 
  // [4370]
  0x0a00fe07, 0x304e46ec, 0x52fe0207, 0x2700fe1a,   // tlh.pt.un_420 qu.ay.uz_644  da.tlh.ha_432 tlh.gd.un_760 
  0x330c0812, 0x0000462d, 0x4600fe13, 0x240a22a0,   // no.sv.nn_654 qu.un.un_A00  tlh.qu.un_650 oc.pt.eo_322 
  0xfe18fc0c, 0x5156480c, 0xfc023611, 0x52584608,   // zzp.ga.tlh_543 tt.mg.kl_543  gn.da.zzp_653 qu.om.ha_443 
  0x3e650107, 0x1d005102, 0x42006905, 0x1c205107,   // en.gv.rm_432 kl.la.un_220  mfe.co.un_330 kl.sq.id_432 
  // [4380]
  0x2200fc04, 0x20005802, 0x581827ad, 0x461a040c,   // zzp.oc.un_320 om.sq.un_220  gd.ga.om_643 fi.tl.qu_543 
  0x02005c2a, 0x26586508, 0x213d44a0, 0x0a221a0c,   // sa.da.un_970 gv.om.ia_443  kk.ku.fa_322 tl.oc.pt_543 
  0x390a2204, 0x3015150c, 0x48003b09, 0x1221340c,   // oc.pt.br_332 un.uz.un_530  so.tt.un_440 ps.fa.ur_543 
  0x30003e13, 0x122e0e0c, 0x6b220aa9, 0x4efe460c,   // rm.uz.un_650 is.fo.hu_543  pt.oc.ceb_544 qu.tlh.ay_543 
  // [4390]
  0x0a43fc07, 0x0115fca0, 0x08003f04, 0x0146fe0c,   // zzp.ie.pt_432 zzp.en.un_320  af.no.un_320 tlh.qu.en_543 
  0x0f10fead, 0x470d2704, 0x063e0107, 0x1c003b04,   // tlh.lt.lv_643 gd.cs.sn_332  en.rm.de_432 so.id.un_320 
  0x13001a02, 0x30fe4611, 0x28001a13, 0x0a002223,   // tl.et.un_220 qu.tlh.uz_653  tl.sw.un_650 oc.pt.un_880 
  0x060a2260, 0x120a22ee, 0x3000310c, 0x22000a12,   // oc.pt.de_664 oc.pt.hu_422  az.uz.un_530 pt.oc.un_640 
  // [43a0]
  0x3c182307, 0x2e0e2bec, 0x44001004, 0x4200100d,   // ky.ar.ug_432 vi.is.fo_644  be.kk.un_320 lt.co.un_540 
  0x3e0a1005, 0x53766911, 0x0a3038ee, 0x15100413,   // lt.pt.rm_333 mfe.crs.ht_653  tk.uz.mk_422 ru.be.un_665 
  0x350a08a7, 0x1a006504, 0x1c5c13a7, 0x285542ad,   // uk.mk.tg_532 gv.tl.un_320  bh.sa.mr_532 co.rw.sw_643 
  0x3e1142ee, 0x095669a7, 0x2a00570d, 0x09005605,   // co.ro.rm_422 mfe.mg.pl_532  na.mt.un_540 mg.pl.un_330 
  // [43b0]
  0x2b420707, 0x34282107, 0x651827a9, 0x0a100805,   // it.co.vi_432 fa.sd.ps_432  gd.ga.gv_544 uk.be.mk_333 
  0x3d002805, 0x18443404, 0x38002519, 0x35442507,   // sd.ku.un_330 ps.kk.ar_332  mn.tk.un_750 mn.kk.tg_432 
  0x532a765a, 0x342818af, 0x0a2d11af, 0x12283b0c,   // crs.mt.ht_553 ar.sd.ps_655  ro.sk.pt_655 ks.sd.ur_543 
  0x4800310e, 0x355e7312, 0x23003814, 0x4735730c,   // az.tt.un_550 ny.ts.zu_654  tk.ky.un_660 ny.zu.sn_543 
  // [43c0]
  0x56000904, 0x73003409, 0x4800230b, 0x233444ad,   // pl.mg.un_320 xh.ny.un_440  ky.tt.un_520 kk.ps.ky_643 
  0x595564af, 0x28003b05, 0x3744150c, 0x08150a07,   // lg.rw.rn_655 ks.sd.un_330  un.kk.ba_543 mk.uk.un_420 
  0x36003c19, 0x594573ec, 0x30004713, 0x442348ee,   // ug.ab.un_750 ny.ln.rn_644  sn.uz.un_650 tt.ky.kk_422 
  0x3b003404, 0x34212809, 0x65000407, 0x041538ee,   // xh.so.un_320 sd.fa.ps_444  fi.gv.un_420 tk.ru.un_420 
  // [43d0]
  0x1f002e07, 0x5c091c07, 0x44002334, 0x0e2e33af,   // fo.cy.un_420 mr.hi.sa_432  ky.kk.un_A80 nn.fo.is_655 
  0x30003c20, 0x183d2804, 0x00005924, 0x043015ec,   // ug.uz.un_850 sd.ku.ar_332  rn.un.un_900 un.uz.ru_644 
  0x022d0d09, 0x33000d04, 0x23003718, 0x4200620c,   // cs.sk.da_444 cs.nn.un_320  ba.ky.un_740 kha.co.un_530 
  0x191d0b07, 0x311b4811, 0x5c00130e, 0x4200071a,   // es.la.gl_432 tt.tr.az_653  bh.sa.un_550 it.co.un_760 
  // [43e0]
  0x32100f02, 0x44000805, 0x4c003613, 0x57fc0112,   // lv.lt.bs_222 uk.kk.un_330  gn.wo.un_650 en.zzp.na_654 
  0x0c000d04, 0x12000e0c, 0x1500440e, 0x21122814,   // cs.sv.un_320 is.hu.un_530  kk.un.un_550 sd.ur.fa_666 
  0x3c002323, 0x12002e02, 0x1b2b05ee, 0x38311b12,   // ky.ug.un_880 fo.hu.un_220  fr.vi.tr_422 tr.az.tk_654 
  0x18003418, 0x12002d09, 0x383c3012, 0x63fc01af,   // ps.ar.un_740 sk.hu.un_440  uz.ug.tk_654 en.zzp.sco_655 
  // [43f0]
  0x3715100c, 0x23121f07, 0x402369ad, 0x2100280e,   // be.ba.un_530 cy.hu.ca_432  mfe.ca.lb_643 sd.fa.un_550 
  0x12001c04, 0x211248a7, 0x18003d0d, 0x3c353008,   // id.hu.un_320 tt.hu.jw_532  ku.ar.un_540 uz.tg.ug_443 
  0x130e3905, 0x12005d07, 0x3308200e, 0x1200210d,   // br.is.et_333 ss.hu.un_420  sq.no.nn_555 fa.ur.un_540 
  0x0e231f12, 0x21330802, 0x1f392307, 0x492d0d05,   // cy.ca.is_654 no.nn.jw_222  ca.br.cy_432 cs.sk.to_333 
  
  // [4400]
  0x033f12a0, 0x64551304, 0x43151b04, 0x30002f05,   // hu.af.nl_322 et.rw.lg_332  tr.ie.un_320 su.uz.un_330 
  0x170811a7, 0x1c002f08, 0x10001207, 0x090d5caf,   // ro.uk.sr_532 su.id.un_430  hu.lt.un_420 sa.ne.hi_655 
  0x08000413, 0x0a070807, 0x39232aaf, 0x06350212,   // ru.uk.un_650 uk.bg.mk_432  mt.ca.br_655 da.zu.de_654 
  0x1c2f120c, 0x1a480204, 0x2f1c2155, 0x04002e07,   // hu.su.id_543 da.tt.tl_332  jw.id.su_442 fo.fi.un_420 
  // [4410]
  0x3521550b, 0x35003608, 0x6b1a1308, 0x081233a4,   // rw.jw.zu_542 ab.tg.un_430  et.tl.ceb_443 nn.hu.no_433 
  0x47001a04, 0x250c47a4, 0x37002204, 0x026b13a4,   // tl.sn.un_320 sn.sv.eu_433  oc.st.un_320 et.ceb.da_433 
  0x3c23440e, 0x034830ad, 0x381021ec, 0x40065711,   // kk.ky.ug_555 uz.tt.nl_643  jw.lt.tk_644 na.de.lb_653 
  0x52000409, 0x0f005c23, 0x36004819, 0x3b212012,   // fi.ha.un_440 sa.lv.un_880  tt.ab.un_750 sq.jw.so_654 
  // [4420]
  0x04065712, 0x10004802, 0x136a60ad, 0x55486ea0,   // na.de.fi_654 tt.lt.un_220  vo.haw.et_643 hmn.tt.rw_322 
  0x5c000f19, 0x13000922, 0x124c4912, 0x30442308,   // lv.sa.un_750 hi.bh.un_870  to.wo.hu_654 ky.kk.uz_443 
  0x0a38070d, 0x5c003404, 0x3e400612, 0x6a64490c,   // bg.tk.mk_554 xh.sa.un_320  de.lb.rm_654 to.lg.haw_543 
  0x49005a08, 0x30000a04, 0x1b31380c, 0x4a1218a0,   // sm.to.un_430 mk.uz.un_320  tk.az.tr_543 ga.hu.yo_322 
  // [4430]
  0x39005204, 0xfc000604, 0x04004604, 0x1c135ca4,   // ha.br.un_320 de.zzp.un_320  qu.fi.un_320 sa.bh.mr_433 
  0x63021aa9, 0x02003005, 0x27001f05, 0x00005224,   // tl.da.sco_544 uz.da.un_330  cy.gd.un_330 ha.un.un_900 
  0x5c0d09a4, 0x12183007, 0x131c090c, 0x271ffc0c,   // hi.ne.sa_433 uz.ar.ur_432  hi.mr.bh_543 zzp.cy.gd_543 
  0x442335ee, 0x4b001c0d, 0x2f004912, 0x44001009,   // tg.ky.kk_422 id.mi.un_540  to.su.un_640 be.kk.un_440 
  // [4440]
  0x2d0d2405, 0x1b004623, 0x3900011a, 0x170a3c07,   // eo.cs.sk_333 qu.tr.un_880  en.br.un_760 ug.mk.sr_432 
  0x44342108, 0x4400480d, 0x654e460d, 0x211e76a4,   // fa.ps.kk_443 tt.kk.un_540  qu.ay.gv_554 crs.ms.jw_433 
  0x3b2a29a9, 0x3b004007, 0x2300fc22, 0x21001222,   // sl.mt.so_544 lb.so.un_420  zzp.ca.un_870 ur.fa.un_870 
  0x58303ba9, 0x31653bac, 0x30002508, 0x15003b12,   // so.uz.om_544 so.gv.az_632  mn.uz.un_430 so.un.un_640 
  // [4450]
  0x3b1e1c09, 0x3d003b0d, 0x4c48690c, 0x33080207,   // id.ms.so_444 ks.ku.un_540  mfe.tt.wo_543 da.no.nn_432 
  0x23173ca0, 0x2f003007, 0x12360aee, 0x46003b07,   // ug.sr.ky_322 uz.su.un_420  pt.gn.hu_422 so.qu.un_420 
  0x3b4c4dad, 0x313b120c, 0x0417110c, 0x0f0229a4,   // aa.wo.so_643 hu.so.az_543  ro.sr.ru_543 sl.da.lv_433 
  0x080e2907, 0x3b6546ec, 0x10004c05, 0x1c5c09a7,   // sl.is.no_432 qu.gv.so_644  wo.lt.un_330 hi.sa.mr_532 
  // [4460]
  0x1e1c2f09, 0x48314d08, 0x24100904, 0x464d4e09,   // su.id.ms_444 aa.az.tt_443  pl.lt.eo_332 ay.aa.qu_444 
  0x00005b06, 0x44253507, 0x1c095c09, 0x080a15a7,   // sg.un.un_400 tg.mn.kk_432  sa.hi.mr_444 un.mk.uk_532 
  0xfc4c11ec, 0x3b00130d, 0x342812a4, 0x11003723,   // ro.wo.zzp_644 et.so.un_540  ur.sd.ps_433 ba.ro.un_880 
  0x1c0d5ca6, 0x03092cee, 0x37003c12, 0x3b000c07,   // sa.ne.mr_521 fy.pl.nl_422  ug.ba.un_640 sv.so.un_420 
  // [4470]
  0x3b033f02, 0x34003f04, 0x08480407, 0x173216a7,   // af.nl.so_222 af.xh.un_320  ru.tt.uk_432 hr.bs.sr_532 
  0x56464e07, 0x0c004604, 0x07041705, 0x79004612,   // ay.qu.mg_432 qu.sv.un_320  sr.ru.bg_333 qu.war.un_640 
  0x37234412, 0x15070455, 0x460b19a7, 0xfc004605,   // kk.ky.ba_654 ru.bg.un_442  gl.es.qu_532 qu.zzp.un_330 
  0x796b1aa4, 0x1c1309a9, 0x07000405, 0x15005c04,   // tl.ceb.war_433 hi.bh.mr_544  ru.bg.un_330 sa.un.un_320 
  // [4480]
  0x3b182105, 0x0200fc0c, 0x0a000721, 0x35003807,   // fa.ar.ks_333 zzp.da.un_530  bg.mk.un_860 tk.tg.un_420 
  0x2e290407, 0x64551208, 0x09005c19, 0x12004308,   // fi.sl.fo_432 hu.rw.lg_443  sa.hi.un_750 ie.hu.un_430 
  0x300a17a9, 0x37303607, 0x350436ee, 0x09005c0d,   // sr.mk.uz_544 ab.uz.ba_432  ab.ru.tg_422 sa.hi.un_540 
  0x354430ee, 0x0400400d, 0x15000713, 0x35003c13,   // uz.kk.tg_422 lb.fi.un_540  bg.un.un_650 ug.tg.un_650 
  // [4490]
  0x302338a9, 0x020c0812, 0x39330311, 0x304838a0,   // tk.ky.uz_544 no.sv.da_654  nl.nn.br_653 tk.tt.uz_322 
  0x44004812, 0x0300080d, 0x6b151dec, 0x04206507,   // tt.kk.un_640 no.nl.un_540  la.ceb.un_640 gv.sq.fi_432 
  0x1b002004, 0x0a000735, 0x20046307, 0x17040707,   // sq.tr.un_320 bg.mk.un_A90  sco.fi.sq_432 bg.ru.sr_432 
  0x0e330805, 0x1340210c, 0x65044dad, 0x090d5ca9,   // no.nn.is_333 jw.lb.et_543  aa.fi.gv_643 sa.ne.hi_544 
  // [44a0]
  0x632065ec, 0x21003902, 0x544d20a4, 0x064001a4,   // gv.sq.sco_644 br.jw.un_220  sq.aa.ik_433 en.lb.de_433 
  0x083c0a11, 0x44002507, 0x20006313, 0x041108af,   // mk.ug.uk_653 mn.kk.un_420  sco.sq.un_650 uk.ro.ru_655 
  0x1b00250d, 0x40240604, 0x04635111, 0x130d09ec,   // eu.tr.un_540 de.eo.lb_332  kl.sco.fi_653 hi.ne.bh_644 
  0x1d006318, 0x3800370e, 0x3f043914, 0x5c000d14,   // sco.la.un_740 ba.tk.un_550  br.fi.af_666 ne.sa.un_660 
  // [44b0]
  0x33030255, 0x3600301a, 0x3000380e, 0x0e000c02,   // da.nl.nn_442 uz.ab.un_760  tk.uz.un_550 sv.is.un_220 
  0x1000150e, 0x04080a0c, 0x03001504, 0x0c631d55,   // un.be.un_550 mk.uk.ru_543  un.nl.un_320 la.sco.sv_442 
  0x083010a4, 0x63040d0b, 0x200463af, 0x4b4746a4,   // be.uz.uk_433 cs.fi.sco_542  sco.fi.sq_655 qu.sn.mi_433 
  0x524e1c12, 0x5d732fec, 0x120e2f0c, 0x211e1c0c,   // id.ay.ha_654 su.ny.ss_644  su.is.hu_543 id.ms.jw_543 
  // [44c0]
  0x3d211260, 0x0700360d, 0x21122812, 0x4d3b040c,   // ur.fa.ku_664 ab.bg.un_540  sd.ur.fa_654 fi.so.aa_543 
  0x2352fe08, 0x05005605, 0x1d002a08, 0x357329a4,   // tlh.ha.ca_443 mg.fr.un_330  mt.la.un_430 sl.ny.zu_433 
  0x59556409, 0x08150455, 0x56036a0c, 0x2f6021a0,   // lg.rw.rn_444 ru.uk.un_420  haw.nl.mg_543 jw.vo.su_322 
  0x442348ad, 0x11fc39a7, 0x52001c04, 0x2f7947ec,   // tt.ky.kk_643 br.zzp.ro_532  id.ha.un_320 sn.war.su_644 
  // [44d0]
  0x5c0d09ee, 0x6953760d, 0x58406a08, 0x5100fe14,   // hi.ne.sa_422 crs.ht.mfe_554  haw.lb.om_443 tlh.kl.un_660 
  0x625f50ec, 0x19360b0c, 0x20495aaf, 0x0f190d0b,   // fj.tn.kha_644 es.gn.gl_543  sm.to.sq_655 cs.gl.lv_542 
  0x3525090c, 0x5e5d500c, 0x3b4c4d11, 0x13003b04,   // pl.eu.zu_543 fj.ss.ts_543  aa.wo.so_653 so.et.un_320 
  0x6bfc1dec, 0x496901a4, 0x5a6049a9, 0xfe514d08,   // la.zzp.ceb_644 en.mfe.to_433  to.vo.sm_544 aa.kl.tlh_443 
  // [44e0]
  0x506033a0, 0x0438350d, 0x350410ee, 0x09131c08,   // nn.vo.fj_322 tg.tk.ru_554  be.ru.tg_422 mr.bh.hi_443 
  0x1700110c, 0x604f500d, 0x685912a7, 0x34213d55,   // ro.sr.un_530 fj.bi.vo_554  hu.rn.ig_532 ku.fa.ps_442 
  0x5a511d07, 0x0900570c, 0x474c28a4, 0x5c090da7,   // la.kl.sm_432 na.pl.un_530  sw.wo.sn_433 ne.hi.sa_532 
  0x35080408, 0x6800571a, 0x27001104, 0x2d0d09a0,   // ru.uk.tg_443 na.ig.un_760  ro.gd.un_320 pl.cs.sk_322 
  // [44f0]
  0x48003012, 0x09005602, 0x0900560e, 0x09002a05,   // uz.tt.un_640 mg.pl.un_220  mg.pl.un_550 mt.pl.un_330 
  0x36122dad, 0x21555cec, 0x58002107, 0x066b6a04,   // sk.hu.gn_643 sa.rw.jw_644  jw.om.un_420 haw.ceb.de_332 
  0x28495eee, 0x216a4b0d, 0x553536a0, 0x37353007,   // ts.to.sw_422 mi.haw.jw_554  gn.zu.rw_322 uz.tg.ba_432 
  0x0000682d, 0x110a42a7, 0x21595505, 0x3c15100c,   // ig.un.un_A00 co.pt.ro_532  rw.rn.jw_333 be.ug.un_530 
  // [4500]
  0x57306408, 0x39330d07, 0x4e00fe1a, 0x3f130904,   // lg.uz.na_443 cs.nn.br_432  tlh.ay.un_760 pl.et.af_332 
  0x1b3b4513, 0x35344ea4, 0x04290304, 0x50106808,   // ln.so.tr_665 ay.xh.zu_433  nl.sl.fi_332 ig.lt.fj_443 
  0x20003829, 0x35345505, 0x4600731b, 0x0a172304,   // tk.sq.un_960 rw.xh.zu_333  ny.qu.un_770 ky.sr.mk_332 
  0x21534cec, 0x133f1007, 0x73001b09, 0x2e000c08,   // wo.ht.jw_644 lt.af.et_432  tr.ny.un_440 sv.fo.un_430 
  // [4510]
  0x1b5338ad, 0x1a796b0c, 0x2f053e04, 0x1b3b52a0,   // tk.ht.tr_643 ceb.war.tl_543  rm.fr.su_332 ha.so.tr_322 
  0x64001b19, 0x17000204, 0x4b5559a7, 0x342130a6,   // tr.lg.un_750 da.sr.un_320  rn.rw.mi_532 uz.fa.ps_521 
  0x5955fe05, 0x5f5c21a0, 0x34003d0b, 0x40333fa0,   // tlh.rw.rn_333 jw.sa.tn_322  ku.ps.un_520 af.nn.lb_322 
  0x090408a0, 0x552159ad, 0x355e73a0, 0x03007904,   // no.fi.pl_322 rn.jw.rw_643  ny.ts.zu_322 war.nl.un_320 
  // [4520]
  0x34007304, 0x311c21a0, 0x07152512, 0x4000040e,   // ny.xh.un_320 jw.id.az_322  mn.bg.un_640 fi.lb.un_550 
  0x3b4c550c, 0x0c2c0fa4, 0x735d4ea4, 0x443537af,   // rw.wo.so_543 lv.fy.sv_433  ay.ss.ny_433 ba.tg.kk_655 
  0x17002e0d, 0x3b6b1aad, 0x73551ba9, 0x47734aa4,   // fo.sr.un_540 tl.ceb.so_643  tr.rw.ny_544 yo.ny.sn_433 
  0x35002312, 0x48001208, 0x1b00380c, 0x3f0338ee,   // ky.tg.un_640 hu.tt.un_430  tk.tr.un_530 tk.nl.af_422 
  // [4530]
  0x23002508, 0x2f003f07, 0x2800590d, 0x170a1505,   // mn.ky.un_430 af.su.un_420  rn.sw.un_540 un.mk.sr_333 
  0x252330a0, 0x0c00330c, 0x03000804, 0x0e1b3112,   // uz.ky.mn_322 nn.sv.un_530  no.nl.un_320 az.tr.is_654 
  0x170704a0, 0x5500590c, 0x1b003107, 0x5c00391b,   // ru.bg.sr_322 rn.rw.un_530  az.tr.un_420 br.sa.un_770 
  0x3c003d05, 0x233c30ad, 0x0c004813, 0x08150408,   // ku.ug.un_330 uz.ug.ky_643  tt.sv.un_650 ru.uk.un_430 
  // [4540]
  0x1c000d13, 0x130d1cec, 0x4c002f0d, 0x3536100c,   // ne.mr.un_650 mr.ne.bh_644  su.wo.un_540 be.ab.tg_543 
  0x0f5c4b60, 0x35003819, 0x511d5408, 0x3f1d0308,   // mi.sa.lv_664 tk.tg.un_750  ik.la.kl_443 nl.la.af_443 
  0x070a0860, 0x03513f04, 0x65006405, 0x282112a9,   // uk.mk.bg_664 af.kl.nl_332  lg.gv.un_330 ur.fa.sd_544 
  0x11001d0d, 0x235122af, 0x44000814, 0x1c5c0dec,   // la.ro.un_540 oc.kl.ca_655  uk.kk.un_660 ne.sa.mr_644 
  // [4550]
  0x342112ac, 0x22111d11, 0x11001d19, 0x23003c04,   // ur.fa.ps_632 la.ro.oc_653  la.ro.un_750 ug.ky.un_320 
  0x201153a4, 0x1038350d, 0x23443504, 0x111d0513,   // ht.ro.sq_433 tg.tk.be_554  tg.kk.ky_332 fr.la.ro_665 
  0x170a15a9, 0x3c2118a0, 0x57511da4, 0xfc006213,   // un.mk.sr_544 ar.fa.ug_322  la.kl.na_433 kha.zzp.un_650 
  0x11121dee, 0x3d001818, 0x57001d21, 0x283b23a4,   // la.hu.ro_422 ar.ku.un_740  la.na.un_860 ky.ks.sd_433 
  // [4560]
  0x38003105, 0x07102307, 0x04004004, 0x48001011,   // az.tk.un_330 ky.be.bg_432  lb.fi.un_320 be.tt.un_630 
  0x12342102, 0x2344480d, 0x1510040e, 0x2c002012,   // fa.ps.ur_222 tt.kk.ky_554  ru.be.un_555 sq.fy.un_640 
  0x09007318, 0x171530ee, 0x321708ee, 0x3c482305,   // ny.pl.un_740 uz.sr.un_420  no.sr.bs_422 ky.tt.ug_333 
  0x2c00201a, 0x12321704, 0x2c002013, 0x1b004812,   // sq.fy.un_760 sr.bs.hu_332  sq.fy.un_650 tt.tr.un_640 
  // [4570]
  0x3e424004, 0x20021602, 0x35002504, 0x06280904,   // lb.co.rm_332 hr.da.sq_222  mn.tg.un_320 pl.sw.de_332 
  0x021f38a0, 0x484437a0, 0x09006912, 0x791709ee,   // tk.cy.da_322 ba.kk.tt_322  mfe.pl.un_640 pl.sr.war_422 
  0x2c00200e, 0x1200090c, 0x1f006714, 0x39202ca0,   // sq.fy.un_550 pl.hu.un_530  ak.cy.un_660 fy.sq.br_322 
  0x2d0d36a9, 0x3f531f07, 0x3000380b, 0x2c201ca0,   // gn.cs.sk_544 cy.ht.af_432  tk.uz.un_520 id.sq.fy_322 
  // [4580]
  0x2c002008, 0x60033fa0, 0x13003b0e, 0x2c122012,   // sq.fy.un_430 af.nl.vo_322  so.et.un_550 sq.hu.fy_654 
  0x3b654c12, 0x3f650314, 0x04301508, 0x150410a7,   // wo.gv.so_654 nl.gv.af_666  un.uz.ru_443 be.ru.un_532 
  0x64003b1a, 0x3b006312, 0x1028420c, 0xfe001f13,   // so.lg.un_760 sco.so.un_640  co.sw.lt_543 cy.tlh.un_650 
  0x4d206513, 0x343d12ee, 0x3b6b6555, 0x04655104,   // gv.sq.aa_665 ur.ku.ps_422  gv.ceb.so_442 kl.gv.fi_332 
  // [4590]
  0x65634d04, 0x20006512, 0x036e6402, 0x04001d04,   // aa.sco.gv_332 gv.sq.un_640  lg.hmn.nl_222 la.fi.un_320 
  0x474c6407, 0x3d2112a7, 0x231320ee, 0x634d1da4,   // lg.wo.sn_432 ur.fa.ku_532  sq.et.ca_422 la.aa.sco_433 
  0x220e02ee, 0x654013ad, 0x651302a0, 0x4d6913a4,   // da.is.oc_422 et.lb.gv_643  da.et.gv_322 et.mfe.aa_433 
  0x65512060, 0x4c001312, 0x22205308, 0x4322230c,   // sq.kl.gv_664 et.wo.un_640  ht.sq.oc_443 ca.oc.ie_543 
  // [45a0]
  0x476513ee, 0x47036407, 0x13006307, 0x123d34ee,   // et.gv.sn_422 lg.nl.sn_432  sco.et.un_420 ps.ku.ur_422 
  0x20006111, 0x481b3112, 0x0a151005, 0x0000430f,   // za.sq.un_630 az.tr.tt_654  be.mk.un_330 ie.un.un_600 
  0x4313200c, 0x10004213, 0x65003f13, 0x206365ad,   // sq.et.ie_543 co.lt.un_650  af.gv.un_650 gv.sco.sq_643 
  0x13204607, 0x3b003f08, 0x3f002002, 0x041711a4,   // qu.sq.et_432 af.so.un_430  sq.af.un_220 ro.sr.ru_433 
  // [45b0]
  0x45620508, 0x23103807, 0x47003b04, 0x15041013,   // fr.kha.ln_443 tk.be.ky_432  so.sn.un_320 be.ru.un_665 
  0x695376af, 0x370415a7, 0x12003418, 0x5c27180e,   // crs.ht.mfe_655 un.ru.ba_532  ps.ur.un_740 ga.gd.sa_555 
  0x6b3b0e12, 0x6500270c, 0x383c3011, 0x0d00360e,   // is.so.ceb_654 gd.gv.un_530  uz.ug.tk_653 gn.cs.un_550 
  0x18652704, 0x3b002a08, 0x2d0d36ec, 0x09001319,   // gd.gv.ga_332 mt.so.un_430  gn.cs.sk_644 bh.hi.un_750 
  // [45c0]
  0x65002704, 0x36000a09, 0x1827650e, 0x02fc1807,   // gd.gv.un_320 mk.ab.un_440  gv.gd.ga_555 ga.zzp.da_432 
  0x070a0407, 0x15001b09, 0xfc006e05, 0x1c000d0e,   // ru.mk.bg_432 tr.un.un_440  hmn.zzp.un_330 ne.mr.un_550 
  0x103023ac, 0x15001013, 0x21002019, 0x11516a0d,   // ky.uz.be_632 be.un.un_650  sq.jw.un_750 haw.kl.ro_554 
  0x123421a0, 0x6b531d07, 0x1517040d, 0x21283407,   // fa.ps.ur_322 la.ht.ceb_432  ru.sr.un_554 ps.sd.fa_432 
  // [45d0]
  0x4d06fcec, 0x3b131ca0, 0x38006509, 0x42494aa9,   // zzp.de.aa_644 id.et.so_322  gv.tk.un_440 yo.to.co_544 
  0x60241560, 0x69004a0e, 0x4a0512a9, 0x21183407,   // un.eo.vo_664 yo.mfe.un_550  hu.fr.yo_544 ps.ar.fa_432 
  0x31003804, 0x51185504, 0x6a4a4f0d, 0x11226912,   // tk.az.un_320 rw.ga.kl_332  bi.yo.haw_554 mfe.oc.ro_654 
  0x40001f13, 0x230738ad, 0x5a006907, 0x69005c13,   // cy.lb.un_650 tk.bg.ky_643  mfe.sm.un_420 sa.mfe.un_650 
  // [45e0]
  0x62005514, 0xfc003204, 0x2f071dee, 0x1b00381a,   // rw.kha.un_660 bs.zzp.un_320  la.it.su_422 tk.tr.un_760 
  0x0d5524ee, 0x350d69ad, 0x1531300c, 0x30373c0c,   // eo.rw.cs_422 mfe.cs.zu_643  uz.az.un_543 ug.ba.uz_543 
  0x291610a0, 0x344535ec, 0x1d005e0c, 0x0000032d,   // lt.hr.sl_322 zu.ln.xh_644  ts.la.un_530 nl.un.un_A00 
  0x285520ee, 0x652b010c, 0x3455590b, 0xfe000f0d,   // sq.rw.sw_422 en.vi.gv_543  rn.rw.xh_542 lv.tlh.un_540 
  // [45f0]
  0x36121804, 0x04171107, 0x24005312, 0x38000202,   // ga.hu.gn_332 ro.sr.ru_432  ht.eo.un_640 da.tk.un_220 
  0x32003909, 0x27001f08, 0x15004814, 0x59003612,   // br.bs.un_440 cy.gd.un_430  tt.un.un_660 gn.rn.un_640 
  0x1e301204, 0x34003c09, 0x3b00121b, 0x48001012,   // hu.uz.ms_332 ug.ps.un_440  ur.ks.un_770 be.tt.un_640 
  0xfe00400e, 0x15353012, 0x240bfeee, 0x44233413,   // lb.tlh.un_550 uz.tg.un_654  tlh.es.eo_422 ps.ky.kk_665 
  // [4600]
  0x15041005, 0x522a1208, 0x24001307, 0x04173507,   // be.ru.un_333 hu.mt.ha_443  et.eo.un_420 tg.sr.ru_432 
  0x3f002d04, 0x3d001205, 0x33000808, 0x4b004905,   // sk.af.un_320 ur.ku.un_330  no.nn.un_430 to.mi.un_330 
  0x302537a0, 0x34002809, 0xfc1a3b07, 0x272322a7,   // ba.mn.uz_322 sd.ps.un_440  so.tl.zzp_432 oc.ca.gd_532 
  0x48000a02, 0x0e0c13a0, 0x3d002804, 0x585e78a4,   // mk.tt.un_220 et.sv.is_322  sd.ku.un_320 ve.ts.om_433 
  // [4610]
  0x0e00130c, 0x34354b0b, 0x104b45a4, 0x4b4552a9,   // et.is.un_530 mi.zu.xh_542  ln.mi.lt_433 ha.ln.mi_544 
  0x1c0913af, 0x1c040fee, 0x160410a0, 0x02102507,   // bh.hi.mr_655 lv.fi.id_422  lt.fi.hr_322 eu.lt.da_432 
  0x104b0204, 0x3823440c, 0x35483713, 0x243749ee,   // da.mi.lt_332 kk.ky.tk_543  ba.tt.tg_665 to.st.eo_422 
  0x040836ee, 0x43004519, 0x105725ad, 0x38044408,   // ab.uk.ru_422 ln.ie.un_750  eu.na.lt_643 kk.ru.tk_443 
  // [4620]
  0x454d5711, 0x290917a0, 0x5d0134a0, 0x0a170705,   // na.aa.ln_653 sr.pl.sl_322  xh.en.ss_322 bg.sr.mk_333 
  0x25004508, 0x356445a4, 0x253458a0, 0x37000404,   // ln.eu.un_430 ln.lg.zu_433  om.xh.eu_322 ru.ba.un_320 
  0x24501005, 0x3c301713, 0x52002908, 0x474b75a7,   // lt.fj.eo_333 sr.uz.ug_665  sl.ha.un_430 nso.mi.sn_532 
  0x090e4b02, 0x150407a0, 0x483825ec, 0x50002409,   // mi.is.pl_222 bg.ru.un_322  mn.tk.tt_644 eo.fj.un_440 
  // [4630]
  0x34001812, 0x480408a0, 0x09001002, 0x1042110c,   // ar.ps.un_640 uk.ru.tt_322  lt.pl.un_220 ro.co.lt_543 
  0x20511d04, 0x102d42a4, 0x100465a0, 0x511d600c,   // la.kl.sq_332 co.sk.lt_433  gv.fi.lt_322 vo.la.kl_543 
  0x43045107, 0x04201b13, 0x11091004, 0x1f5c3404,   // kl.fi.ie_432 tr.sq.fi_665  lt.pl.ro_332 xh.sa.cy_332 
  0x226520ad, 0x09000204, 0x12003f05, 0x5c214707,   // sq.gv.oc_643 da.pl.un_320  af.hu.un_330 sn.jw.sa_432 
  // [4640]
  0x44003607, 0x1d655108, 0x1f005c04, 0x5c0964ad,   // ab.kk.un_420 kl.gv.la_443  sa.cy.un_320 lg.pl.sa_643 
  0x27003807, 0x24000129, 0x58070660, 0x1b554607,   // tk.gd.un_420 iw.yi.un_960  de.it.om_664 qu.rw.tr_432 
  0x06070508, 0x1f000902, 0x06182760, 0x6b0465ac,   // fr.it.de_443 pl.cy.un_220  gd.ga.de_664 gv.fi.ceb_632 
  0x18002705, 0x0115fcad, 0x5c004608, 0x4e004d1a,   // gd.ga.un_330 zzp.en.un_630  qu.sa.un_430 aa.ay.un_760 
  // [4650]
  0x01005c04, 0x1b5c73a7, 0x17004204, 0x65004004,   // sa.en.un_320 ny.sa.tr_532  co.sr.un_320 lb.gv.un_320 
  0x51005723, 0x55094207, 0x0d221da0, 0x201d11a4,   // na.kl.un_880 co.pl.rw_432  la.oc.cs_322 ro.la.sq_433 
  0x51651d5a, 0x11002d0b, 0x20111d55, 0x19402802,   // la.gv.kl_553 sk.ro.un_520  la.ro.sq_442 sw.lb.gl_222 
  0x5c5546a0, 0x5c074260, 0x1dfe4355, 0x0800fc07,   // qu.rw.sa_322 co.it.sa_664  ie.tlh.la_442 zzp.no.un_420 
  // [4660]
  0x48004405, 0x53050605, 0x52465c09, 0x05001504,   // kk.tt.un_330 de.fr.ht_333  sa.qu.ha_444 un.fr.un_320 
  0x46005c14, 0x4003060d, 0x1b5c4607, 0x34003012,   // sa.qu.un_660 de.nl.lb_554  qu.sa.tr_432 uz.ps.un_640 
  0x1c005c11, 0x17301555, 0x35000a08, 0x38353c5a,   // sa.mr.un_630 un.uz.sr_442  mk.tg.un_430 ug.tg.tk_553 
  0x2330380c, 0x09001c0b, 0x07003002, 0x45000d08,   // tk.uz.ky_543 mr.hi.un_520  uz.bg.un_220 cs.ln.un_430 
  // [4670]
  0x0f5c4b07, 0x01005002, 0x17000a35, 0x0800330d,   // mi.sa.lv_432 fj.en.un_220  mk.sr.un_A90 nn.no.un_540 
  0x1b48310c, 0x0233080d, 0x0815045a, 0x2300180d,   // az.tt.tr_543 no.nn.da_554  ru.uk.un_530 ar.ky.un_540 
  0x270154ee, 0x343b28a4, 0x041735ad, 0x041510af,   // ik.en.gd_422 sd.ks.ps_433  tg.sr.ru_643 be.ru.un_650 
  0x09003802, 0x48003113, 0x38002002, 0x07003e07,   // tk.pl.un_220 az.tt.un_650  sq.tk.un_220 rm.it.un_420 
  // [4680]
  0x332d0d55, 0x48303708, 0x311b4804, 0x0a2223a7,   // cs.sk.nn_442 ba.uz.tt_443  tt.tr.az_332 ca.oc.pt_532 
  0x44000407, 0x040a0713, 0x5a00fc12, 0x18282102,   // ru.kk.un_420 bg.mk.ru_665  zzp.sm.un_640 fa.sd.ar_222 
  0x091c13a0, 0x122134a7, 0x07003e04, 0x04081704,   // bh.mr.hi_322 ps.fa.ur_532  rm.it.un_320 sr.uk.ru_332 
  0x3c004821, 0x0815040d, 0x122128af, 0x0e151808,   // tt.ug.un_860 ru.uk.un_540  sd.fa.ur_655 ga.is.un_430 
  // [4690]
  0x1700100d, 0x1f002005, 0x54291ca0, 0x0a231709,   // be.sr.un_540 sq.cy.un_330  id.sl.ik_322 sr.ky.mk_444 
  0x1e1c2f05, 0x18002719, 0x48fe62a7, 0x130d5cec,   // su.id.ms_333 gd.ga.un_750  kha.tlh.tt_532 sa.ne.bh_644 
  0x322179a6, 0x33080ea0, 0x541e1c05, 0x2e200eec,   // war.jw.bs_521 is.no.nn_322  id.ms.ik_333 is.sq.fo_644 
  0x13044faf, 0x65007305, 0x301c2f04, 0x30183302,   // bi.fi.et_655 ny.gv.un_330  su.id.uz_332 nn.ga.uz_222 
  // [46a0]
  0x330840a4, 0x092f1c14, 0x021d2a05, 0x1e1c21a0,   // lb.no.nn_433 id.su.pl_666  mt.la.da_333 jw.id.ms_322 
  0x4001230c, 0x600434a9, 0x64006712, 0x072069ee,   // ca.en.lb_543 xh.fi.vo_544  ak.lg.un_640 mfe.sq.it_422 
  0x212f02a0, 0x5c2f1c02, 0x171629a0, 0x30001207,   // da.su.jw_322 id.su.sa_222  sl.hr.sr_322 hu.uz.un_420 
  0x0c4323af, 0x1e791ca6, 0x283d2104, 0x65013907,   // ca.ie.sv_655 id.war.ms_521  fa.ku.sd_332 br.en.gv_432 
  // [46b0]
  0x332308a7, 0x2d120cac, 0x3c353009, 0x1b003822,   // no.ca.nn_532 sv.hu.sk_632  uz.tg.ug_444 tk.tr.un_870 
  0x0c2f21a0, 0x032c01a0, 0x350737ad, 0x2a004902,   // jw.su.sv_322 en.fy.nl_322  ba.bg.tg_643 to.mt.un_220 
  0x030608a4, 0x1a73490c, 0x0306040c, 0x190b24ee,   // no.de.nl_433 to.ny.tl_543  fi.de.nl_543 eo.es.gl_422 
  0x2100280c, 0x49002d08, 0x1d2569a4, 0x15001509,   // sd.fa.un_530 sk.to.un_430  mfe.eu.la_433 un.un.un_440 
  // [46c0]
  0x034015a9, 0x1800280b, 0x312c03ee, 0x07352507,   // un.lb.nl_544 sd.ar.un_520  nl.fy.az_422 mn.tg.bg_432 
  0x5800630d, 0x480410a4, 0x12002813, 0x09001302,   // sco.om.un_540 lt.fi.tt_433  sd.ur.un_650 bh.hi.un_220 
  0x3000200c, 0x21181207, 0x122128a4, 0x532576ad,   // sq.uz.un_530 ur.ar.fa_432  sd.fa.ur_433 crs.eu.ht_643 
  0x79fc0107, 0x32302504, 0x44002509, 0x38001b22,   // en.zzp.war_432 eu.uz.bs_332  mn.kk.un_440 tr.tk.un_870 
  // [46d0]
  0x621b04a4, 0x15001f0d, 0x081b330c, 0x040263ee,   // fi.tr.kha_433 cy.un.un_540  nn.tr.no_543 sco.da.fi_422 
  0x08173c0c, 0x31003812, 0x425207ee, 0x4d030408,   // ug.sr.uk_543 tk.az.un_640  it.ha.co_422 fi.nl.aa_443 
  0x46004512, 0x06266005, 0x07190b0d, 0x65003812,   // ln.qu.un_640 vo.ia.de_333  es.gl.it_554 tk.gv.un_640 
  0x2d0d36a0, 0x0a1730a0, 0x04697613, 0x5c0d1c12,   // gn.cs.sk_322 uz.sr.mk_322  crs.mfe.fi_665 mr.ne.sa_654 
  // [46e0]
  0x07303507, 0x30003202, 0x18fc01a0, 0x100f040d,   // tg.uz.bg_432 bs.uz.un_220  en.zzp.ga_322 fi.lv.lt_554 
  0x0f00100e, 0x23003819, 0x18342108, 0x184434a4,   // lt.lv.un_550 tk.ky.un_750  fa.ps.ar_443 ps.kk.ar_433 
  0x48003722, 0x49003609, 0x183c3ba4, 0x04480702,   // ba.tt.un_870 gn.to.un_440  ks.ug.ar_433 bg.tt.ru_222 
  0x213d12ad, 0x25353004, 0x44003008, 0x04003b0c,   // ur.ku.fa_643 uz.tg.mn_332  uz.kk.un_430 so.fi.un_530 
  // [46f0]
  0x6b021d55, 0xfc00280c, 0x3f04240c, 0x46004d2b,   // la.da.ceb_442 sw.zzp.un_530  eo.fi.af_543 aa.qu.un_980 
  0x38001f05, 0x3c002318, 0x38002e19, 0x644702a6,   // cy.tk.un_330 ky.ug.un_740  fo.tk.un_750 da.sn.lg_521 
  0x431b2aa7, 0x563b0460, 0x53004d08, 0x0d091c0d,   // mt.tr.ie_532 fi.so.mg_664  aa.ht.un_430 mr.hi.ne_554 
  0x101809ad, 0x443748a9, 0x21644dad, 0x04093b07,   // pl.ga.lt_643 tt.ba.kk_544  aa.lg.jw_643 so.pl.fi_432 
  // [4700]
  0x1a796b07, 0x3c483712, 0x04003b04, 0x3035110b,   // ceb.war.tl_432 ba.tt.ug_654  so.fi.un_320 ro.tg.uz_542 
  0x34001f02, 0x04070805, 0x34281807, 0x0d091c0b,   // cy.xh.un_220 uk.bg.ru_333  ar.sd.ps_432 mr.hi.ne_542 
  0x2e000c19, 0x5c001307, 0x171535a0, 0x183c23a0,   // sv.fo.un_750 bh.sa.un_420  tg.sr.un_320 ky.ug.ar_322 
  0x0a0704a4, 0x0a170807, 0x15041112, 0x15103812,   // ru.bg.mk_433 uk.sr.mk_432  ro.ru.un_654 tk.be.un_654 
  // [4710]
  0x12002807, 0x081007a6, 0x07170a09, 0x23381507,   // sd.ur.un_420 bg.be.uk_521  mk.sr.bg_444 un.tk.ky_432 
  0x19004a07, 0x34123dee, 0x30003d14, 0x23003c29,   // yo.gl.un_420 ku.ur.ps_422  ku.uz.un_660 ug.ky.un_960 
  0x31001802, 0x09135c0b, 0x4700670c, 0x135c1ca4,   // ga.az.un_220 sa.bh.hi_542  ak.sn.un_530 mr.sa.bh_433 
  0x12013409, 0x2f353408, 0x5f006407, 0x370410a0,   // ps.iw.ur_444 xh.zu.su_443  lg.tn.un_420 be.ru.ba_322 
  // [4720]
  0x374838ec, 0x1c0d095a, 0x631c1ea4, 0x354815a0,   // tk.tt.ba_644 hi.ne.mr_553  ms.id.sco_433 un.tt.tg_322 
  0x636201a0, 0x04001a04, 0x353038a4, 0x07000a09,   // en.kha.sco_322 tl.fi.un_320  tk.uz.tg_433 mk.bg.un_440 
  0x091c0dec, 0x48002d0d, 0x65630408, 0x35303c12,   // ne.mr.hi_644 sk.tt.un_540  fi.sco.gv_443 ug.uz.tg_654 
  0x041708a6, 0x38004421, 0x1a003f04, 0x1d0b51ad,   // uk.sr.ru_521 kk.tk.un_860  af.tl.un_320 kl.es.la_643 
  // [4730]
  0x63001b12, 0x51006319, 0x3d003b12, 0x21002818,   // tr.sco.un_640 sco.kl.un_750  ks.ku.un_640 sd.fa.un_740 
  0x15041014, 0x34181207, 0x3c001209, 0x17363504,   // be.ru.un_666 ur.ar.ps_432  ur.ug.un_440 tg.ab.sr_332 
  0x40000502, 0x34122809, 0x2d003605, 0x48000614,   // fr.lb.un_220 sd.ur.ps_444  gn.sk.un_330 de.tt.un_660 
  0x0d00090b, 0x04035809, 0x07153807, 0x181221a4,   // hi.ne.un_520 om.nl.fi_444  tk.bg.un_420 fa.ur.ar_433 
  // [4740]
  0x65044cad, 0x1e731c0c, 0x28506aa9, 0x043b5808,   // wo.fi.gv_643 id.ny.ms_543  haw.fj.sw_544 om.so.fi_443 
  0x043f2509, 0x24000205, 0x43022412, 0x406504a0,   // eu.af.fi_444 da.eo.un_330  eo.da.ie_654 fi.gv.lb_322 
  0x58253b11, 0x0e006402, 0x79281aa9, 0x333b5804,   // so.eu.om_653 lg.is.un_220  tl.sw.war_544 om.so.nn_332 
  0x584c3b0c, 0x28003008, 0x2000060d, 0x6000240c,   // so.wo.om_543 uz.sw.un_430  de.sq.un_540 eo.vo.un_530 
  // [4750]
  0x0c02330c, 0x737628a9, 0x40002421, 0x2440690c,   // nn.da.sv_543 sw.crs.ny_544  eo.lb.un_860 mfe.lb.eo_543 
  0x2800210b, 0x40062455, 0x6064450c, 0x1b312405,   // fa.sd.un_520 eo.de.lb_442  ln.lg.vo_543 eo.az.tr_333 
  0x483730a0, 0x212402a0, 0x48002505, 0x254d3bad,   // uz.ba.tt_322 da.eo.jw_322  eu.tt.un_330 so.aa.eu_643 
  0x18341202, 0x283418a9, 0x65620304, 0x1d3b63ac,   // ur.ps.ar_222 ar.ps.sd_544  nl.kha.gv_332 sco.so.la_632 
  // [4760]
  0x5273640d, 0x150f2eee, 0x033b040c, 0x3473550c,   // lg.ny.ha_554 fo.lv.un_422  fi.so.nl_543 rw.ny.xh_543 
  0x583b04ec, 0x464b7307, 0x655876a7, 0x44342304,   // fi.so.om_644 ny.mi.qu_432  crs.om.gv_532 ky.ps.kk_332 
  0x12213ba7, 0x3f692407, 0x1d190b0d, 0x59000108,   // ks.fa.ur_532 eo.mfe.af_432  es.gl.la_554 en.rn.un_430 
  0x476428a9, 0x4415380c, 0x390224ec, 0x093534ee,   // sw.lg.sn_544 tk.kk.un_530  eo.da.br_644 xh.zu.pl_422 
  // [4770]
  0x06005307, 0x39243f0c, 0x204635ee, 0x1700350e,   // ht.de.un_420 af.eo.br_543  zu.qu.sq_422 tg.sr.un_550 
  0x00006a2d, 0x0a5179ee, 0x4b506a0c, 0x06391f07,   // haw.un.un_A00 war.kl.pt_422  haw.fj.mi_543 cy.br.de_432 
  0x6a19050d, 0x4a0c02a0, 0x2b054912, 0x1e003f08,   // fr.gl.haw_554 da.sv.yo_322  to.fr.vi_654 af.ms.un_430 
  0x6a11430d, 0x137948ad, 0x51000604, 0x384844af,   // ie.ro.haw_554 tt.war.et_643  de.kl.un_320 kk.tt.tk_655 
  // [4780]
  0x17352304, 0x2e0e200d, 0x6a021812, 0x2e002408,   // ky.tg.sr_332 sq.is.fo_554  ga.da.haw_654 eo.fo.un_430 
  0x50454f0c, 0x07502b0c, 0x23196a04, 0x190a5aaf,   // bi.ln.fj_543 vi.fj.it_543  haw.gl.ca_332 sm.pt.gl_655 
  0x2b002514, 0x213b3dad, 0x33085da0, 0xfc004704,   // eu.vi.un_660 ku.ks.fa_643  ss.no.nn_322 sn.zzp.un_320 
  0x2b051f0c, 0x2e0d2da9, 0x4207620d, 0x1b483455,   // cy.fr.vi_543 sk.cs.fo_544  kha.it.co_554 xh.tt.tr_442 
  // [4790]
  0x423604a9, 0x2b4b0508, 0x25443711, 0x55002808,   // fi.gn.co_544 fr.mi.vi_443  ba.kk.mn_653 sw.rw.un_430 
  0xfe003304, 0x063f3b07, 0x28007908, 0x5e007304,   // nn.tlh.un_320 so.af.de_432  war.sw.un_430 ny.ts.un_320 
  0x1b002d08, 0x633bfea9, 0xfe6455ec, 0x462e0ea4,   // sk.tr.un_430 tlh.so.sco_544  rw.lg.tlh_644 is.fo.qu_433 
  0x4c004605, 0x53765c12, 0x64fe350d, 0x0236010c,   // qu.wo.un_330 sa.crs.ht_654  zu.tlh.lg_554 en.gn.da_543 
  // [47a0]
  0x5376690c, 0x470153a0, 0x4c006513, 0x2a00010d,   // mfe.crs.ht_543 ht.en.sn_322  gv.wo.un_650 en.mt.un_540 
  0x1b4d3111, 0x47000204, 0x531a79a7, 0x595530a4,   // az.aa.tr_653 da.sn.un_320  war.tl.ht_532 uz.rw.rn_433 
  0x190b0d0c, 0x3b006513, 0x21223ea4, 0x4c6bfe09,   // cs.es.gl_543 gv.so.un_650  rm.oc.jw_433 tlh.ceb.wo_444 
  0x1c130dad, 0x3b004d19, 0x632f210d, 0x1b003113,   // ne.bh.mr_643 aa.so.un_750  jw.su.sco_554 az.tr.un_650 
  // [47b0]
  0x2f38300c, 0x46005c04, 0x1500fe07, 0x3c003019,   // uz.tk.su_543 sa.qu.un_320  tlh.un.un_420 uz.ug.un_750 
  0x01656307, 0x60000e0d, 0x374823a9, 0x34123013,   // sco.gv.en_432 is.vo.un_540  ky.tt.ba_544 uz.ur.ps_665 
  0x0d091c07, 0x05003b04, 0x04071507, 0x1b006919,   // mr.hi.ne_432 so.fr.un_320  un.bg.ru_432 mfe.tr.un_750 
  0x025cfe04, 0x695313a4, 0x23000205, 0x0a00071a,   // tlh.sa.da_332 et.ht.mfe_433  da.ca.un_330 bg.mk.un_760 
  // [47c0]
  0x0f00101a, 0x07001014, 0x07153504, 0x11070805,   // lt.lv.un_760 be.bg.un_660  tg.bg.un_320 uk.bg.ro_333 
  0x6b021a04, 0x44001005, 0x09130d5a, 0x0a041705,   // tl.da.ceb_332 be.kk.un_330  ne.bh.hi_553 sr.ru.mk_333 
  0x272456a0, 0x3836440c, 0x30002312, 0x56451a14,   // mg.eo.gd_322 kk.ab.tk_543  ky.uz.un_640 tl.ln.mg_666 
  0x04301704, 0x11000708, 0x1700110d, 0x0a17100c,   // sr.uz.ru_332 bg.ro.un_430  ro.sr.un_540 be.sr.mk_543 
  // [47d0]
  0x09000d19, 0x230a3707, 0x3c233da4, 0x241956ee,   // ne.hi.un_750 ba.mk.ky_432  ku.ky.ug_433 mg.gl.eo_422 
  0x4e190b14, 0x073523a0, 0x1149620b, 0x4b002821,   // es.gl.ay_666 ky.tg.bg_322  kha.to.ro_542 sw.mi.un_860 
  0x211e1c08, 0x164e090b, 0x48373c14, 0x48371507,   // id.ms.jw_443 pl.ay.hr_542  ug.ba.tt_666 un.ba.tt_432 
  0x50001c1a, 0x372344ec, 0x232544a9, 0x4b3050a4,   // id.fj.un_760 kk.ky.ba_644  kk.mn.ky_544 fj.uz.mi_433 
  // [47e0]
  0x0e31520c, 0x295259a6, 0x3d301212, 0x25521b0c,   // ha.az.is_543 rn.ha.sl_521  ur.uz.ku_654 tr.ha.eu_543 
  0x0d003b05, 0x283d210c, 0x304552a4, 0x12182107,   // so.cs.un_330 fa.ku.sd_543  ha.ln.uz_433 fa.ar.ur_432 
  0x48005221, 0x31002502, 0x01001814, 0x381025ad,   // ha.tt.un_860 eu.az.un_220  ar.iw.un_660 mn.be.tk_643 
  0x564b460c, 0x281834a4, 0x1504170b, 0x35254804,   // qu.mi.mg_543 ps.ar.sd_433  sr.ru.un_542 tt.mn.tg_332 
  // [47f0]
  0x492050a0, 0x4a003608, 0x525046ee, 0x4c003913,   // fj.sq.to_322 gn.yo.un_430  qu.fj.ha_422 br.wo.un_650 
  0x095049a9, 0x2e2d0deb, 0x6200392a, 0x343d2112,   // to.fj.pl_544 cs.sk.fo_662  br.kha.un_970 fa.ku.ps_654 
  0x4b004912, 0x080415ee, 0x1500071a, 0x64003302,   // to.mi.un_640 un.ru.uk_422  bg.un.un_760 nn.lg.un_220 
  0x57003922, 0x35071508, 0x3c302360, 0x04005b0e,   // br.na.un_870 un.bg.tg_443  ky.uz.ug_664 sg.fi.un_550 
  
  // [4800]
  0x0a00120b, 0x303d1204, 0x5c1c1304, 0x0121185a,   // hu.pt.un_520 ur.ku.uz_332  bh.mr.sa_332 ar.fa.iw_553 
  0x6100391a, 0x033f65a0, 0x40063fa9, 0x0306400d,   // br.za.un_760 gv.af.nl_322  af.de.lb_544 lb.de.nl_554 
  0x040c4904, 0x3e00400e, 0x1e1c50a9, 0x1c2115ad,   // to.sv.fi_332 lb.rm.un_550  fj.id.ms_544 un.jw.id_643 
  0x0d2d3007, 0x1b1e1c12, 0x10000a0d, 0x215d5e0c,   // uz.sk.cs_432 id.ms.tr_654  mk.be.un_540 ts.ss.jw_543 
  // [4810]
  0x2d470d11, 0x16005c04, 0x2a000919, 0xfc4606a0,   // cs.sn.sk_653 sa.hr.un_320  pl.mt.un_750 de.qu.zzp_322 
  0x5d001219, 0x3b0e0ca0, 0x1e50020c, 0x241d42ee,   // hu.ss.un_750 sv.is.so_322  da.fj.ms_543 co.la.eo_422 
  0x021e1c04, 0x15000619, 0x0340060b, 0x07044802,   // id.ms.da_332 de.un.un_750  de.lb.nl_542 tt.ru.bg_222 
  0x234838ec, 0x44070407, 0x4c5d4712, 0x57000614,   // tk.tt.ky_644 ru.bg.kk_432  sn.ss.wo_654 de.na.un_660 
  // [4820]
  0x28fc0f04, 0x0b793bad, 0x182d0d02, 0x172f1212,   // lv.zzp.sw_332 so.war.es_643  cs.sk.ga_222 hu.su.sr_654 
  0x505a4912, 0x632347a4, 0x46190b5a, 0x1100440e,   // to.sm.fj_654 sn.ca.sco_433  es.gl.qu_553 kk.ro.un_550 
  0x471e1c08, 0x06006012, 0x13001c0d, 0x38001b14,   // id.ms.sn_443 vo.de.un_640  mr.bh.un_540 tr.tk.un_660 
  0x122118a0, 0x5d00471a, 0x30641c0b, 0xfc40650e,   // ar.fa.ur_322 sn.ss.un_760  id.lg.uz_542 gv.lb.zzp_555 
  // [4830]
  0x371504a7, 0x30003102, 0x3400440d, 0x4c2578ee,   // ru.ba.un_520 az.uz.un_220  kk.ps.un_540 ve.eu.wo_422 
  0x15040808, 0x1f2f390c, 0x08020c02, 0x405a28a4,   // uk.ru.un_443 br.su.cy_543  sv.da.no_222 sw.sm.lb_433 
  0x1000111a, 0x17300aa0, 0x1136150c, 0x0e472e0b,   // ro.be.un_760 mk.uz.sr_322  un.ab.ro_543 fo.sn.is_542 
  0x0d095cac, 0x0a374807, 0x09131c07, 0x443823ad,   // sa.hi.ne_632 tt.ba.mk_432  mr.bh.hi_432 ky.tk.kk_643 
  // [4840]
  0x40393007, 0x2d0d0f05, 0x343d1807, 0x3b004c02,   // uz.br.lb_432 lv.cs.sk_333  ar.ku.ps_432 wo.so.un_220 
  0x3b3f0304, 0x08043055, 0x3c1138a4, 0x403f3b07,   // nl.af.so_332 uz.ru.uk_442  tk.ro.ug_433 so.af.lb_432 
  0x48203012, 0x082f12ee, 0x44381507, 0x791e1c12,   // uz.sq.tt_654 hu.su.no_422  un.tk.kk_432 id.ms.war_654 
  0x18031da0, 0x18002109, 0x08070a60, 0x12fc1ba0,   // la.nl.ga_322 fa.ar.un_440  mk.bg.uk_664 tr.zzp.hu_322 
  // [4850]
  0x1a00340d, 0x166b51ad, 0x4c006e08, 0x3b601307,   // xh.tl.un_540 kl.ceb.hr_643  hmn.wo.un_430 et.vo.so_432 
  0x6a6228a4, 0x041510a0, 0x2f6a3007, 0x53792507,   // sw.kha.haw_433 be.ru.un_320  uz.haw.su_432 eu.war.ht_432 
  0x3224490d, 0x00002924, 0x4502560d, 0x30003804,   // to.eo.bs_554 sl.un.un_900  mg.da.ln_554 tk.uz.un_320 
  0x5a493709, 0x4d5467ad, 0x03090604, 0x1200340e,   // st.to.sm_444 ak.ik.aa_643  de.pl.nl_332 ps.ur.un_550 
  // [4860]
  0x11670da9, 0x21003504, 0x2f001c07, 0x495a3655,   // cs.ak.ro_544 zu.jw.un_320  id.su.un_420 gn.sm.to_442 
  0x2d290913, 0x3f2d0d08, 0x070437a0, 0x330865a0,   // pl.sl.sk_665 cs.sk.af_443  ba.ru.bg_322 gv.no.nn_322 
  0x4a4f49ec, 0x1f420704, 0x37755f0d, 0x27001102,   // to.bi.yo_644 it.co.cy_332  tn.nso.st_554 ro.gd.un_220 
  0x425c4ca6, 0x653f0312, 0x203069ec, 0x646a7307,   // wo.sa.co_521 nl.af.gv_654  mfe.uz.sq_644 ny.haw.lg_432 
  // [4870]
  0x1b002102, 0x22272308, 0x09033f02, 0x304404a0,   // jw.tr.un_220 ca.gd.oc_443  af.nl.pl_222 ru.kk.uz_322 
  0x30001d13, 0x1c000704, 0x34213011, 0x694f760d,   // la.uz.un_650 it.id.un_320  uz.fa.ps_653 crs.bi.mfe_554 
  0x043312ee, 0x30001d02, 0x531d2ba7, 0x151048a9,   // hu.nn.fi_422 la.uz.un_220  vi.la.ht_532 tt.be.un_544 
  0x21001c0d, 0x4249305a, 0x3500340b, 0x08040704,   // id.jw.un_540 uz.to.co_553  xh.zu.un_520 bg.ru.uk_332 
  // [4880]
  0x083530a4, 0x484415a0, 0x3707fc02, 0x303c35af,   // uz.tg.uk_433 un.kk.tt_322  zzp.it.st_222 tg.ug.uz_655 
  0x0f00470c, 0x2330380b, 0x64002508, 0x283412a7,   // sn.lv.un_530 tk.uz.ky_542  eu.lg.un_430 ur.ps.sd_532 
  0x19000b21, 0x2500100d, 0x0c00fe0d, 0x0c510da0,   // es.gl.un_860 be.mn.un_540  tlh.sv.un_540 cs.kl.sv_322 
  0x0d002908, 0x08173c07, 0x07483707, 0x1f60150c,   // sl.cs.un_430 ug.sr.uk_432  ba.tt.bg_432 un.vo.cy_543 
  // [4890]
  0x381b3104, 0x1f00fc0d, 0x1000fe04, 0x1b4230a0,   // az.tr.tk_332 zzp.cy.un_540  tlh.lt.un_320 uz.co.tr_322 
  0x5a004905, 0x5b006113, 0x08002a04, 0x17382312,   // to.sm.un_330 za.sg.un_650  mt.no.un_320 ky.tk.sr_654 
  0x271f02a7, 0x123b180c, 0x29000102, 0x1828120c,   // da.cy.gd_532 ar.ks.ur_543  en.sl.un_220 ur.sd.ar_543 
  0x2d0d0914, 0x2d000912, 0x1f0e2411, 0x2013fca0,   // pl.cs.sk_666 pl.sk.un_640  eo.is.cy_653 zzp.et.sq_322 
  // [48a0]
  0x44384813, 0x0802330c, 0xfc003804, 0x3e06fc04,   // tt.tk.kk_665 nn.da.no_543  tk.zzp.un_320 zzp.de.rm_332 
  0x0a0704ee, 0x0804070c, 0x30070402, 0x213412a7,   // ru.bg.mk_422 bg.ru.uk_543  ru.bg.uz_222 ur.ps.fa_532 
  0x063e1807, 0x08001708, 0x40000611, 0x041508a4,   // ga.rm.de_432 sr.uk.un_430  de.lb.un_630 uk.ru.un_430 
  0x475d7307, 0x071504ec, 0x38002521, 0x2c007304,   // ny.ss.sn_432 ru.bg.un_640  mn.tk.un_860 ny.fy.un_320 
  // [48b0]
  0x38111b0b, 0x4205620c, 0x212330a0, 0x0600570d,   // tr.ro.tk_542 kha.fr.co_543  uz.ky.fa_322 na.de.un_540 
  0x035706af, 0x35345d0c, 0x10070a11, 0x4e000419,   // de.na.nl_655 ss.xh.zu_543  mk.bg.be_653 fi.ay.un_750 
  0x032c0608, 0x62fc0208, 0x09002a0c, 0x0c003307,   // de.fy.nl_443 da.zzp.kha_443  mt.pl.un_530 nn.sv.un_420 
  0x1500480d, 0x480415a0, 0x2c090308, 0x4a003605,   // tt.un.un_540 un.ru.tt_322  nl.pl.fy_443 gn.yo.un_330 
  // [48c0]
  0x2c030604, 0x34183d07, 0x042e0e08, 0x1b3e23a0,   // de.nl.fy_332 ku.ar.ps_432  is.fo.fi_443 ca.rm.tr_322 
  0x330806a9, 0x1f386304, 0x0700301a, 0x040738ad,   // de.no.nn_544 sco.tk.cy_332  uz.bg.un_760 tk.bg.ru_643 
  0x0a00072c, 0x3d123011, 0x34123da4, 0x36001805,   // bg.mk.un_990 uz.ur.ku_653  ku.ur.ps_433 ga.gn.un_330 
  0x283d2111, 0x283421a0, 0x040a36ee, 0x5638fc0b,   // fa.ku.sd_653 fa.ps.sd_322  ab.mk.ru_422 zzp.tk.mg_542 
  // [48d0]
  0x3812fc07, 0x59005713, 0xfc341211, 0x30003112,   // zzp.hu.tk_432 na.rn.un_650  hu.xh.zzp_653 az.uz.un_640 
  0x07002507, 0x2f68210c, 0x344a3504, 0xfc00120d,   // mn.bg.un_420 jw.ig.su_543  zu.yo.xh_332 hu.zzp.un_540 
  0x64005509, 0x083610a0, 0x09381fa0, 0x4a00590e,   // rw.lg.un_440 be.ab.uk_322  cy.tk.pl_322 rn.yo.un_550 
  0x34122155, 0x5c004904, 0x3634fc0d, 0x3800fc18,   // fa.ur.ps_442 to.sa.un_320  zzp.xh.gn_554 zzp.tk.un_740 
  // [48e0]
  0x211a6b0c, 0x5c000f0e, 0x4a006b04, 0x055545a7,   // ceb.tl.jw_543 lv.sa.un_550  ceb.yo.un_320 ln.rw.fr_532 
  0x306b6308, 0x040a07a0, 0x211e18a0, 0x1b3831ee,   // sco.ceb.uz_443 bg.mk.ru_322  ga.ms.jw_322 az.tk.tr_422 
  0x18442304, 0x1f003f08, 0x02796bad, 0x212240af,   // ky.kk.ar_332 af.cy.un_430  ceb.war.da_643 lb.oc.jw_655 
  0x041515a4, 0x0e000104, 0x5c1c0d55, 0x211230ee,   // un.ru.un_430 en.is.un_320  ne.mr.sa_442 uz.ur.fa_422 
  // [48f0]
  0x442338af, 0x0c062d04, 0x353015a4, 0x1f001e07,   // tk.ky.kk_655 sk.de.sv_332  un.uz.tg_433 ms.cy.un_420 
  0x36001808, 0x35016ba0, 0x18004c04, 0x522a2305,   // ga.gn.un_430 ceb.en.zu_322  wo.ga.un_320 ca.mt.ha_333 
  0x520956a7, 0x4c001209, 0x404c0204, 0x3c003814,   // mg.pl.ha_532 hu.wo.un_440  da.wo.lb_332 tk.ug.un_660 
  0x18003902, 0x3e006018, 0x570106a0, 0xfe6b1dee,   // br.ga.un_220 vo.rm.un_740  de.en.na_322 la.ceb.tlh_422 
  // [4900]
  0x0d095c0e, 0x032c3fad, 0x250a170c, 0x35341ba4,   // sa.hi.ne_555 af.fy.nl_643  sr.mk.mn_543 tr.xh.zu_433 
  0x1b4c31a4, 0x2f003e12, 0x21122860, 0x73007822,   // az.wo.tr_433 rm.su.un_640  sd.ur.fa_664 ve.ny.un_870 
  0x44003723, 0x12003614, 0x2a000f07, 0x69594a0c,   // ba.kk.un_880 gn.hu.un_660  lv.mt.un_420 yo.rn.mfe_543 
  0x35000404, 0x55001b08, 0x341b5da0, 0x0d562da0,   // ru.tg.un_320 tr.rw.un_430  ss.tr.xh_322 sk.mg.cs_322 
  // [4910]
  0x402c2a07, 0x052c1f07, 0x1b5367ad, 0x452a05ee,   // mt.fy.lb_432 cy.fy.fr_432  ak.ht.tr_643 fr.mt.ln_422 
  0x2c002a0c, 0x21005313, 0x62630107, 0x08111707,   // mt.fy.un_530 ht.jw.un_650  en.sco.kha_432 sr.ro.uk_432 
  0x311b300e, 0x123618a4, 0x55451b07, 0x3400fc05,   // uz.tr.az_555 ga.gn.hu_433  tr.ln.rw_432 zzp.xh.un_330 
  0x383c300d, 0x53005e04, 0x1b00451a, 0x62495a13,   // uz.ug.tk_554 ts.ht.un_320  ln.tr.un_760 sm.to.kha_665 
  // [4920]
  0x47731ba0, 0x104b520d, 0x3f030e05, 0x622510a4,   // tr.ny.sn_322 ha.mi.lt_554  is.nl.af_333 lt.eu.kha_433 
  0x62610f0d, 0x2b49650e, 0x151538ee, 0x495a50af,   // lv.za.kha_554 gv.to.vi_555  tk.un.un_420 fj.sm.to_655 
  0x09001c21, 0x303515a9, 0x2c005a18, 0x25524f12,   // mr.hi.un_860 un.tg.uz_544  sm.fy.un_740 bi.ha.eu_654 
  0x692a6208, 0x2b2f6e12, 0x074f5212, 0x1d0a49a0,   // kha.mt.mfe_443 hmn.su.vi_654  ha.bi.it_654 to.pt.la_322 
  // [4930]
  0x5a004935, 0x37650104, 0x612b25a9, 0x39002a34,   // to.sm.un_A90 en.gv.st_332  eu.vi.za_544 bo.dz.un_A80 
  0x28526e0e, 0x6b631d55, 0x2b236ea0, 0x407906ad,   // hmn.ha.sw_555 la.sco.ceb_442  hmn.ca.vi_322 de.war.lb_643 
  0x1f5062a9, 0x5049520d, 0x6500020c, 0x0000502d,   // kha.fj.cy_544 ha.to.fj_554  da.gv.un_530 fj.un.un_A00 
  0x5c0a0fec, 0x506a4b0d, 0x3d213ba7, 0x2b04100d,   // lv.pt.sa_644 mi.haw.fj_554  ks.fa.ku_532 lt.fi.vi_554 
  // [4940]
  0x0365fcad, 0x151038a4, 0x44003508, 0x5a490a02,   // zzp.gv.nl_643 tk.be.un_433  tg.kk.un_430 pt.to.sm_222 
  0x1b314814, 0x15040708, 0x65fe610c, 0x31481b14,   // tt.az.tr_666 bg.ru.un_443  za.tlh.gv_543 tr.tt.az_666 
  0x1c2f21ad, 0x03fc1e02, 0x041738a7, 0x46fe3007,   // jw.su.id_643 ms.zzp.nl_222  tk.sr.ru_532 uz.tlh.qu_432 
  0x5c003302, 0x48311bec, 0x2e00180c, 0x081238a0,   // nn.sa.un_220 tr.az.tt_644  ga.fo.un_530 tk.hu.no_322 
  // [4950]
  0x21281205, 0x0a073c07, 0x31481b13, 0x31001b19,   // ur.sd.fa_333 ug.bg.mk_432  tr.tt.az_665 tr.az.un_750 
  0x211218a6, 0x28002119, 0x1b314860, 0x34212812,   // ar.ur.fa_521 fa.sd.un_750  tt.az.tr_664 sd.fa.ps_654 
  0x04151055, 0x3d18215a, 0x07005602, 0x31481ba7,   // be.ru.un_420 fa.ar.ku_553  mg.it.un_220 tr.tt.az_532 
  0x07001009, 0x241302a0, 0x292d75a7, 0x18000113,   // be.bg.un_440 da.et.eo_322  nso.sk.sl_532 iw.ar.un_650 
  // [4960]
  0x1053020c, 0x170a070c, 0x48442355, 0x1504080c,   // da.ht.lt_543 bg.mk.sr_543  ky.kk.tt_442 uk.ru.un_543 
  0x35004804, 0x04003002, 0x0d000918, 0x5c4b0fa6,   // tt.tg.un_320 uz.ru.un_220  hi.ne.un_740 lv.mi.sa_521 
  0x0a59020c, 0x04000209, 0x13001704, 0x3723440c,   // da.rn.pt_543 da.fi.un_440  sr.et.un_320 kk.ky.ba_543 
  0x17003604, 0x164560af, 0x1b003802, 0x44081005,   // ab.sr.un_320 vo.ln.hr_655  tk.tr.un_220 be.uk.kk_333 
  // [4970]
  0x090d1c0b, 0x5f59550d, 0x026445a4, 0x213d34a4,   // mr.ne.hi_542 rw.rn.tn_554  ln.lg.da_433 ps.ku.fa_433 
  0x4b000f0b, 0x5612640c, 0x605521a4, 0x5e352fee,   // lv.mi.un_520 lg.hu.mg_543  jw.rw.vo_433 su.zu.ts_422 
  0x5d005004, 0x0400080b, 0x3c003812, 0x59353405,   // fj.ss.un_320 uk.ru.un_520  tk.ug.un_640 xh.zu.rn_333 
  0x25003612, 0x5900552a, 0x39210502, 0x0d2960a4,   // ab.mn.un_640 rw.rn.un_970  fr.jw.br_222 vo.sl.cs_433 
  // [4980]
  0x644a53ee, 0x44081702, 0x1c000d0b, 0x30006429,   // ht.yo.lg_422 sr.uk.kk_222  ne.mr.un_520 lg.uz.un_960 
  0x29001904, 0x0e004004, 0x0a1730ee, 0x213012af,   // gl.sl.un_320 lb.is.un_320  uz.sr.mk_422 ur.uz.fa_655 
  0x17041107, 0x18006312, 0x30000e02, 0x23003005,   // ro.ru.sr_432 sco.ga.un_640  is.uz.un_220 uz.ky.un_330 
  0x2b001802, 0x18003604, 0x4c302aee, 0x0d000e04,   // ga.vi.un_220 gn.ga.un_320  mt.uz.wo_422 is.cs.un_320 
  // [4990]
  0x44004804, 0x37234802, 0x343d2105, 0x022e0ea6,   // tt.kk.un_320 tt.ky.ba_222  fa.ku.ps_333 is.fo.da_521 
  0x05005808, 0x1018275a, 0x04073612, 0x15303c08,   // om.fr.un_430 gd.ga.lt_553  ab.bg.ru_654 ug.uz.un_443 
  0x233622a0, 0x20006113, 0x273118a0, 0x304652a0,   // oc.gn.ca_322 za.sq.un_650  ga.az.gd_322 ha.qu.uz_322 
  0x13000c11, 0x2500230c, 0x0a3530ee, 0x231501a0,   // sv.et.un_630 ky.mn.un_530  uz.tg.mk_422 en.ca.un_320 
  // [49a0]
  0x3e221da0, 0x353623ec, 0x1b000c05, 0x0a0946ad,   // la.oc.rm_322 ky.ab.tg_644  sv.tr.un_330 qu.pl.pt_643 
  0x3000480e, 0x4207150c, 0x2a00390c, 0x275e47a4,   // tt.uz.un_550 un.it.co_543  dz.bo.un_530 sn.ts.gd_433 
  0x2300270c, 0x6e005e09, 0x190b09a4, 0x18003605,   // gd.ca.un_530 ts.hmn.un_440  pl.es.gl_433 gn.ga.un_330 
  0x3c483860, 0x1600290c, 0x25070a60, 0x1bfc3802,   // tk.tt.ug_664 sl.hr.un_530  mk.bg.mn_664 tk.zzp.tr_222 
  // [49b0]
  0x10171602, 0x173025ac, 0x3c001509, 0x25003509,   // hr.sr.lt_222 mn.uz.sr_632  un.ug.un_440 tg.mn.un_440 
  0x25004404, 0x1f00270e, 0x37170a0c, 0x4400080b,   // kk.mn.un_320 gd.cy.un_550  mk.sr.ba_543 uk.kk.un_520 
  0x382917a0, 0xfc40030d, 0x304415ec, 0x041538a4,   // sr.sl.tk_322 nl.lb.zzp_554  un.kk.uz_644 tk.ru.un_430 
  0x351510ee, 0x135c1ca9, 0x13090d02, 0x2834300c,   // be.tg.un_420 mr.sa.bh_544  ne.hi.bh_222 uz.ps.sd_543 
  // [49c0]
  0x0a004405, 0x44234807, 0x34001811, 0x27016307,   // kk.mk.un_330 tt.ky.kk_432  ar.ps.un_630 sco.en.gd_432 
  0x0a170702, 0x30170aa9, 0x00003c2d, 0x30353c11,   // bg.sr.mk_222 mk.sr.uz_544  ug.un.un_A00 ug.tg.uz_653 
  0x402f1f08, 0x08005704, 0x050254a4, 0x570433a0,   // cy.su.lb_443 na.no.un_320  ik.da.fr_433 nn.fi.na_322 
  0x303418ad, 0x30004507, 0x5e003014, 0x64003508,   // ar.ps.uz_643 ln.uz.un_420  uz.ts.un_660 zu.lg.un_430 
  // [49d0]
  0x4500531b, 0x02005712, 0x35303c13, 0x5d003021,   // ht.ln.un_770 na.da.un_640  ug.uz.tg_665 uz.ss.un_860 
  0x1f610855, 0x343b580c, 0x6435345a, 0x4379600c,   // no.za.cy_442 om.so.xh_543  xh.zu.lg_553 vo.war.ie_543 
  0x2a475505, 0x345930a4, 0x190b01a0, 0x63006112,   // rw.sn.mt_333 uz.rn.xh_433  en.es.gl_322 za.sco.un_640 
  0x65006309, 0x0b6524a0, 0x04153c04, 0x553064ee,   // sco.gv.un_440 eo.gv.es_322  ug.ru.un_320 lg.uz.rw_422 
  // [49e0]
  0x536461ee, 0x353473ec, 0x34305912, 0x08171005,   // za.lg.ht_422 ny.xh.zu_644  rn.uz.xh_654 be.sr.uk_333 
  0x57000405, 0xfc291508, 0x1a050107, 0x18004f08,   // fi.na.un_330 un.sl.zzp_443  en.fr.tl_432 bi.ga.un_430 
  0x19000105, 0x473073ad, 0x01fc7905, 0x34677308,   // en.gl.un_330 ny.uz.sn_643  war.zzp.en_333 ny.ak.xh_443 
  0x01fc290c, 0x2f3064a0, 0x01312608, 0x22240107,   // sl.zzp.en_543 lg.uz.su_322  ia.az.en_443 en.eo.oc_432 
  // [49f0]
  0x30003b05, 0x090d13ec, 0x103748ad, 0x171504a9,   // so.uz.un_330 bh.ne.hi_644  tt.ba.be_643 ru.sr.un_540 
  0x34281855, 0x3d1228af, 0x3d002307, 0x28003612,   // ar.sd.ps_442 sd.ur.ku_655  ky.ku.un_420 gn.sw.un_640 
  0x30213ba4, 0x0200100d, 0x182830a4, 0x4300590d,   // ks.fa.uz_433 lt.da.un_540  uz.sd.ar_433 rn.ie.un_540 
  0x1c130960, 0x16282909, 0x38351509, 0x1b000f07,   // hi.bh.mr_664 sl.sw.hr_444  un.tg.tk_444 lv.tr.un_420 
  // [4a00]
  0x092d61ad, 0x091c0d08, 0x1d554a0d, 0x08000a08,   // za.sk.pl_643 ne.mr.hi_443  yo.rw.la_554 mk.uk.un_430 
  0x13000934, 0x5b00200c, 0x0e4a1504, 0x6700682c,   // hi.bh.un_A80 sq.sg.un_530  un.yo.is_332 ig.ak.un_990 
  0x1a367907, 0x1b2169ee, 0xfe643204, 0x4800350c,   // war.gn.tl_432 mfe.jw.tr_422  bs.lg.tlh_332 tg.tt.un_530 
  0x4a6768a9, 0x48004f18, 0x381e1bee, 0x31381b04,   // ig.ak.yo_544 bi.tt.un_740  tr.ms.tk_422 tr.tk.az_332 
  // [4a10]
  0x2d002007, 0x15003802, 0x48003b0e, 0x02001c04,   // sq.sk.un_420 tk.un.un_220  so.tt.un_550 id.da.un_320 
  0x46002102, 0x2f001d0c, 0x2f002107, 0x4f001b05,   // jw.qu.un_220 la.su.un_530  jw.su.un_420 tr.bi.un_330 
  0x090d5c07, 0x681d2660, 0x30000404, 0x4b001207,   // sa.ne.hi_432 ia.la.ig_664  ru.uz.un_320 hu.mi.un_420 
  0x31690f05, 0x08001504, 0x06153f02, 0x00004315,   // lv.mfe.az_333 un.no.un_320  af.de.un_220 ie.un.un_700 
  // [4a20]
  0x041011ee, 0x33000e04, 0x162910ee, 0x34213d08,   // ro.be.ru_422 is.nn.un_320  lt.sl.hr_422 ku.fa.ps_443 
  0x5500fe0c, 0x34005507, 0x040c0604, 0x2b42280d,   // tlh.rw.un_530 rw.xh.un_420  de.sv.fi_332 sw.co.vi_554 
  0x04484655, 0x190b23a4, 0x34211804, 0x3f003402,   // qu.tt.fi_442 ca.es.gl_433  ar.fa.ps_332 xh.af.un_220 
  0x360b4ea0, 0x1008040d, 0x23003604, 0x3000230e,   // ay.es.gn_322 ru.uk.be_554  gn.ca.un_320 ky.uz.un_550 
  // [4a30]
  0x102507a0, 0x05004208, 0x35735908, 0x17080a09,   // bg.mn.be_322 co.fr.un_430  rn.ny.zu_443 mk.uk.sr_444 
  0x22190b04, 0x3c001114, 0x12005204, 0x47000607,   // es.gl.oc_332 ro.ug.un_660  ha.hu.un_320 de.sn.un_420 
  0x0f001007, 0x37151007, 0x1d27180c, 0x34001814,   // lt.lv.un_420 be.ba.un_420  ga.gd.la_543 ar.ps.un_660 
  0x0e000c12, 0x56000502, 0x04004b04, 0x11003808,   // sv.is.un_640 fr.mg.un_220  mi.fi.un_320 tk.ro.un_430 
  // [4a40]
  0x4800381b, 0x0c004004, 0x04364807, 0x2a001802,   // tk.tt.un_770 lb.sv.un_320  tt.gn.fi_432 ga.mt.un_220 
  0x173511ec, 0x3c00302b, 0x173530a0, 0x04171505,   // ro.tg.sr_644 uz.ug.un_980  uz.tg.sr_322 un.sr.ru_333 
  0x1100151a, 0x0c003e0d, 0x1b003114, 0x28213b07,   // un.ro.un_760 rm.sv.un_540  az.tr.un_660 ks.fa.sd_432 
  0x30003408, 0x383c2308, 0x48373ca4, 0x483623ac,   // ps.uz.un_430 ky.ug.tk_443  ug.ba.tt_433 ky.ab.tt_632 
  // [4a50]
  0x24004002, 0x083817a9, 0x16001007, 0x242718a0,   // lb.eo.un_220 sr.tk.uk_544  lt.hr.un_420 ga.gd.eo_322 
  0x5c27630c, 0x070408a9, 0x651827a7, 0x2912265a,   // sco.gd.sa_543 uk.ru.bg_544  gd.ga.gv_532 ia.hu.sl_553 
  0x182112a7, 0x06125709, 0x2c000108, 0x58092da0,   // ur.fa.ar_532 na.hu.de_444  en.fy.un_430 sk.pl.om_322 
  0x12002229, 0x1200fe05, 0x1200fe0d, 0x1203080b,   // oc.hu.un_960 tlh.hu.un_330  tlh.hu.un_540 no.nl.hu_542 
  // [4a60]
  0x63461fee, 0x3b000913, 0x3efc010c, 0x2a65570c,   // cy.qu.sco_422 pl.so.un_650  en.zzp.rm_543 na.gv.mt_543 
  0x08002512, 0x1827010b, 0x0cfe120c, 0x1d000614,   // mn.uk.un_640 en.gd.ga_542  hu.tlh.sv_543 de.la.un_660 
  0x0212060c, 0x38303cad, 0x12342109, 0x3400121a,   // de.hu.da_543 ug.uz.tk_643  fa.ps.ur_444 ur.ps.un_760 
  0x35344505, 0x3835100c, 0x2d004214, 0x5f3734a0,   // ln.xh.zu_333 be.tg.tk_543  co.sk.un_660 xh.st.tn_322 
  // [4a70]
  0x535d3502, 0x250a07a4, 0x043513a9, 0x595557af,   // zu.ss.ht_222 bg.mk.mn_433  et.zu.fi_544 na.rw.rn_655 
  0x1a0c390c, 0x0b000904, 0x091c5c55, 0x17041507,   // br.sv.tl_543 pl.es.un_320  sa.mr.hi_442 un.ru.sr_432 
  0x18007820, 0x5c005304, 0x0a0730a0, 0x3f1c55ee,   // ve.ga.un_850 ht.sa.un_320  uz.bg.mk_322 rw.id.af_422 
  0x255d63a9, 0x345d350c, 0x3038080b, 0x3e0679a0,   // sco.ss.eu_544 zu.ss.xh_543  uk.tk.uz_542 war.de.rm_322 
  // [4a80]
  0x2d001113, 0x0a170407, 0x22124a5a, 0x2f342807,   // ro.sk.un_650 ru.sr.mk_432  yo.hu.oc_553 sw.xh.su_432 
  0x4b000404, 0x05001902, 0x67006821, 0x64006723,   // fi.mi.un_320 gl.fr.un_220  ig.ak.un_860 ak.lg.un_880 
  0x26004322, 0x646867a4, 0x4f0569a0, 0x2a002304,   // ie.ia.un_870 ak.ig.lg_433  mfe.fr.bi_322 ca.mt.un_320 
  0x6467470c, 0x09003b0d, 0x29001d07, 0x17000a2c,   // sn.ak.lg_543 so.pl.un_540  la.sl.un_420 mk.sr.un_990 
  // [4a90]
  0x2d000704, 0x18343d0c, 0x3c3748af, 0x11003919,   // it.sk.un_320 ku.ps.ar_543  tt.ba.ug_655 br.ro.un_750 
  0x560a05ac, 0x1e2f1cee, 0x066301a0, 0x0f001009,   // fr.pt.mg_632 id.su.ms_422  en.sco.de_322 lt.lv.un_440 
  0x38311b0c, 0x461e1c55, 0x121e3bad, 0x5e557304,   // tr.az.tk_543 id.ms.qu_442  so.ms.hu_643 ny.rw.ts_332 
  0x4c1e1c14, 0x24212208, 0x24001e08, 0x4a005508,   // id.ms.wo_666 oc.jw.eo_443  ms.eo.un_430 rw.yo.un_430 
  // [4aa0]
  0x4c042907, 0x252f3bec, 0x171329a0, 0x45693b07,   // sl.fi.wo_432 so.su.eu_644  sl.et.sr_322 so.mfe.ln_432 
  0x7600690d, 0x2f1e1c09, 0x3b004705, 0x5c0d09ec,   // mfe.crs.un_540 id.ms.su_444  sn.so.un_330 hi.ne.sa_644 
  0x1c253bec, 0x03603f12, 0x2f2129ee, 0x2f463ba7,   // so.eu.id_644 af.vo.nl_654  sl.jw.su_422 so.qu.su_532 
  0x3f38030d, 0x0f102d08, 0x123b4c04, 0x384815a7,   // nl.tk.af_554 sk.lt.lv_443  wo.so.hu_332 un.tt.tk_532 
  // [4ab0]
  0x3b004c0e, 0x105c29a4, 0x013b4ca0, 0x04000c09,   // wo.so.un_550 sl.sa.lt_433  wo.so.en_322 sv.fi.un_440 
  0x0c4004a0, 0x433f010c, 0x25293b07, 0x4a59730e,   // fi.lb.sv_322 en.af.ie_543  so.sl.eu_432 ny.rn.yo_555 
  0x17291bad, 0x1c294ca4, 0x21fe38af, 0x5200210e,   // tr.sl.sr_643 wo.sl.id_433  tk.tlh.jw_655 jw.ha.un_550 
  0x04002908, 0x5369fe08, 0x13004004, 0xfe2a2404,   // sl.fi.un_430 tlh.mfe.ht_443  lb.et.un_320 eo.mt.tlh_332 
  // [4ac0]
  0x311b38ee, 0x44001721, 0x12001908, 0x430d24a0,   // tk.tr.az_422 sr.kk.un_860  gl.hu.un_430 eo.cs.ie_322 
  0x1e00fc04, 0x25394804, 0x12000508, 0x5d2862ec,   // zzp.ms.un_320 tt.br.eu_332  fr.hu.un_430 kha.sw.ss_644 
  0x12002a02, 0x0f004c21, 0x5b3073ec, 0x4600100d,   // mt.hu.un_220 wo.lv.un_860  ny.uz.sg_644 lt.qu.un_540 
  0x400c04a0, 0x0000442d, 0x24001d0d, 0x2a4e04a4,   // fi.sv.lb_322 kk.un.un_A00  la.eo.un_540 fi.ay.mt_433 
  // [4ad0]
  0x11004813, 0x09000102, 0x234e22a4, 0x2d29040c,   // tt.ro.un_650 en.pl.un_220  oc.ay.ca_433 fi.sl.sk_543 
  0x043007a7, 0x24040dad, 0x3f0e52a7, 0x132c58ee,   // bg.uz.ru_532 cs.fi.eo_643  ha.is.af_532 om.fy.et_422 
  0x06000205, 0x011dfea7, 0x480838ee, 0x482330a4,   // da.de.un_330 tlh.la.en_532  tk.uk.tt_422 uz.ky.tt_433 
  0x1b00482a, 0x13005a02, 0x1b5028a0, 0x28214aee,   // tt.tr.un_970 sm.et.un_220  sw.fj.tr_322 yo.jw.sw_422 
  // [4ae0]
  0x182858a4, 0x735a6aee, 0x6909450c, 0x795802a7,   // om.sw.ga_433 haw.sm.ny_422  ln.pl.mfe_543 da.om.war_532 
  0x38020c08, 0x35001512, 0x4800301a, 0x382f28a0,   // sv.da.tk_443 un.tg.un_640  uz.tt.un_760 sw.su.tk_322 
  0x31205202, 0x19000502, 0x244928a7, 0x42333b08,   // ha.sq.az_222 fr.gl.un_220  sw.to.eo_532 so.nn.co_443 
  0x4831fe07, 0x30005e04, 0x42000512, 0x131a4812,   // tlh.az.tt_432 ts.uz.un_320  fr.co.un_640 tt.tl.et_654 
  // [4af0]
  0x30383c12, 0x21003b1a, 0x354423a0, 0x0e2950ad,   // ug.tk.uz_654 ks.fa.un_760  ky.kk.tg_322 fj.sl.is_643 
  0x213b3d08, 0xfc001913, 0x00006924, 0x254838a4,   // ku.ks.fa_443 gl.zzp.un_650  mfe.un.un_900 tk.tt.eu_433 
  0x245e3407, 0x070a1002, 0x15070a05, 0x42000507,   // xh.ts.eo_432 be.mk.bg_222  mk.bg.un_333 fr.co.un_420 
  0x48003822, 0x10001608, 0x321710b3, 0x0900790c,   // tk.tt.un_870 hr.lt.un_430  lt.sr.bs_743 war.pl.un_530 
  // [4b00]
  0x4800250c, 0x5c130d09, 0x42584604, 0x253723a7,   // mn.tt.un_530 ne.bh.sa_444  qu.om.co_332 ky.ba.mn_532 
  0x0f2779a0, 0xfc2509a0, 0x19271807, 0x06002302,   // war.gd.lv_322 pl.eu.zzp_322  ga.gd.gl_432 ca.de.un_220 
  0x34182109, 0x05527904, 0xfc00650d, 0x083517ad,   // fa.ar.ps_444 war.ha.fr_332  gv.zzp.un_540 sr.tg.uk_643 
  0x0d32170d, 0x153836a4, 0xfc606304, 0x40460604,   // sr.bs.cs_554 ab.tk.un_433  sco.vo.zzp_332 de.qu.lb_332 
  // [4b10]
  0x0165fc07, 0x4d6001a4, 0x5400fc19, 0x21342812,   // zzp.gv.en_432 en.vo.aa_433  zzp.ik.un_750 sd.ps.fa_654 
  0x213d280c, 0x2118340d, 0x29001602, 0x08150405,   // sd.ku.fa_543 ps.ar.fa_554  hr.sl.un_220 ru.uk.un_330 
  0x23374855, 0x17321008, 0x30444809, 0x3c353060,   // tt.ba.ky_442 lt.bs.sr_443  tt.kk.uz_444 uz.tg.ug_664 
  0x4400380b, 0x4c004618, 0x19005504, 0x0700170c,   // tk.kk.un_520 qu.wo.un_740  rw.gl.un_320 sr.bg.un_530 
  // [4b20]
  0x35441508, 0x02001f04, 0x2f21050e, 0x27000c04,   // un.kk.tg_443 cy.da.un_320  fr.jw.su_555 sv.gd.un_320 
  0x10796505, 0x02135e0c, 0x5d35340e, 0x1bfc380c,   // gv.war.lt_333 ts.et.da_543  xh.zu.ss_555 tk.zzp.tr_543 
  0x5f213307, 0x3f096304, 0x35003408, 0x3800371a,   // nn.jw.tn_432 sco.pl.af_332  xh.zu.un_430 ba.tk.un_760 
  0x10000413, 0x356a01a0, 0x33006307, 0x47004912,   // ru.be.un_650 en.haw.zu_322  sco.nn.un_420 to.sn.un_640 
  // [4b30]
  0x55022804, 0x30005d09, 0x502f3404, 0x173525ad,   // sw.da.rw_332 ss.uz.un_440  xh.su.fj_332 mn.tg.sr_643 
  0x3c3d21a4, 0x04002004, 0x3800360e, 0x64353407,   // fa.ku.ug_433 sq.fi.un_320  ab.tk.un_550 xh.zu.lg_432 
  0x353469a0, 0x5e00421b, 0x63001504, 0x3437645a,   // mfe.xh.zu_322 co.ts.un_770  un.sco.un_320 lg.st.xh_553 
  0x3f1b25ec, 0x6a0e45a7, 0x35303ca0, 0x06001312,   // eu.tr.af_644 ln.is.haw_532  ug.uz.tg_322 et.de.un_640 
  // [4b40]
  0x0737260c, 0x1b003818, 0x17351508, 0x07003b08,   // ia.st.it_543 tk.tr.un_740  un.tg.sr_443 so.it.un_430 
  0x28007305, 0xfe000113, 0x761a5304, 0x02091fa4,   // ny.sw.un_330 en.tlh.un_650  ht.tl.crs_332 cy.pl.da_433 
  0x73004723, 0x353715ac, 0x78005d1b, 0x1afc6b05,   // sn.ny.un_880 un.ba.tg_632  ss.ve.un_770 ceb.zzp.tl_333 
  0x5638310c, 0x040817ee, 0x1a5c3405, 0x791a6b0d,   // az.tk.mg_543 sr.uk.ru_422  xh.sa.tl_333 ceb.tl.war_554 
  // [4b50]
  0x47787355, 0x5d734712, 0x093e56ee, 0x10003502,   // ny.ve.sn_442 sn.ny.ss_654  mg.rm.pl_422 zu.lt.un_220 
  0x39000704, 0x02002c02, 0x47005e0d, 0x0c000102,   // it.br.un_320 fy.da.un_220  ts.sn.un_540 en.sv.un_220 
  0x2d095d55, 0x070a37a0, 0x016b1dee, 0x10383008,   // ss.pl.sk_442 ba.mk.bg_322  la.ceb.en_422 uz.tk.be_443 
  0x30584d08, 0x35347314, 0x5c003004, 0x34734ea9,   // aa.om.uz_443 ny.xh.zu_666  uz.sa.un_320 ay.ny.xh_544 
  // [4b60]
  0x1b6473ad, 0x5d00310d, 0x73344508, 0x02105cad,   // ny.lg.tr_643 az.ss.un_540  ln.xh.ny_443 sa.lt.da_643 
  0x09004907, 0xfc005d12, 0x1b735213, 0xfa00340c,   // to.pl.un_420 ss.zzp.un_640  ha.ny.tr_665 xh.nr.un_530 
  0x2c003302, 0x52005905, 0x654c58a0, 0x5c380204,   // nn.fy.un_220 rn.ha.un_330  om.wo.gv_322 da.tk.sa_332 
  0x357352a4, 0x0d00560c, 0x672356a4, 0x593b4d0d,   // ha.ny.zu_433 mg.cs.un_530  mg.ca.ak_433 aa.so.rn_554 
  // [4b70]
  0x471a5308, 0x122d730d, 0x5e64530c, 0x102d4708,   // ht.tl.sn_443 ny.sk.hu_554  ht.lg.ts_543 sn.sk.lt_443 
  0x5d005208, 0x583b64ec, 0x35585555, 0x353452a9,   // ha.ss.un_430 lg.so.om_644  rw.om.zu_442 ha.xh.zu_544 
  0x216479ee, 0x282130ee, 0x35005d14, 0xfc002c08,   // war.lg.jw_422 uz.fa.sd_422  ss.zu.un_660 fy.zzp.un_430 
  0x12182108, 0x07041107, 0x300408ee, 0x5c533ba7,   // fa.ar.ur_443 ro.ru.bg_432  uk.ru.uz_422 so.ht.sa_532 
  // [4b80]
  0x556473a0, 0x5e630107, 0x52215505, 0x31303b0d,   // ny.lg.rw_322 en.sco.ts_432  rw.jw.ha_333 so.uz.az_554 
  0x22002308, 0x58005e19, 0x645553ee, 0x00000a2d,   // ca.oc.un_430 ts.om.un_750  ht.rw.lg_422 mk.un.un_A00 
  0x35464ea7, 0x040835ee, 0x526430a4, 0x30352560,   // ay.qu.zu_532 tg.uk.ru_422  uz.lg.ha_433 mn.tg.uz_664 
  0x07150460, 0x527355a4, 0x233611af, 0x285934a0,   // ru.bg.un_640 rw.ny.ha_433  ro.ab.ky_655 xh.rn.sw_322 
  // [4b90]
  0x645234a4, 0x0a007907, 0x55734555, 0x79002b22,   // xh.ha.lg_433 war.pt.un_420  ln.ny.rw_442 vi.war.un_870 
  0x2b0a79ec, 0x0a2b79ad, 0x39123305, 0x2844180e,   // war.pt.vi_644 war.vi.pt_643  nn.hu.br_333 ar.kk.sd_555 
  0x2b007913, 0x343b12a4, 0x79002b14, 0xfe002508,   // war.vi.un_650 ur.ks.ps_433  vi.war.un_660 eu.tlh.un_430 
  0x3f00fc0d, 0x67790a13, 0x2b00791a, 0x1b315cee,   // zzp.af.un_540 pt.war.ak_665  war.vi.un_760 sa.az.tr_422 
  // [4ba0]
  0x5c005909, 0x38302313, 0x51033f08, 0x27001819,   // rn.sa.un_440 ky.uz.tk_665  af.nl.kl_443 ga.gd.un_750 
  0x59002d13, 0x3b003c1a, 0x170825a7, 0x2b367960,   // sk.rn.un_650 ug.ks.un_760  mn.uk.sr_532 war.gn.vi_664 
  0x0000791c, 0x31001b1b, 0x09007908, 0x3600fc0e,   // war.un.un_800 tr.az.un_770  war.pl.un_430 zzp.gn.un_550 
  0x213c3b05, 0x362b7912, 0x222153af, 0x5c00100e,   // ks.ug.fa_333 war.vi.gn_654  ht.jw.oc_655 lt.sa.un_550 
  // [4bb0]
  0x2253210d, 0x0a1710a0, 0x684a315a, 0xfe004e12,   // jw.ht.oc_554 be.sr.mk_322  az.yo.ig_553 ay.tlh.un_640 
  0x06007919, 0x2030550c, 0x25003c07, 0x5321225a,   // war.de.un_750 rw.uz.sq_543  ug.mn.un_420 oc.jw.ht_553 
  0x2f1c0d04, 0x1d1d31a7, 0x22532113, 0x4a68675a,   // cs.id.su_332 az.la.la_532  jw.ht.oc_665 ak.ig.yo_553 
  0x041736ee, 0x5c003f02, 0x00001537, 0x68787312,   // ab.sr.ru_422 af.sa.un_220  un.un.un_B00 ny.ve.ig_654 
  // [4bc0]
  0x5c001014, 0x0c003304, 0x21002213, 0x316867ad,   // lt.sa.un_660 nn.sv.un_320  oc.jw.un_650 ak.ig.az_643 
  0x4800200e, 0x53222107, 0x641f4d13, 0x22002108,   // sq.tt.un_550 jw.oc.ht_432  aa.cy.lg_665 jw.oc.un_430 
  0x3000672b, 0x17001604, 0x2a002b04, 0x30001f1a,   // ak.uz.un_980 hr.sr.un_320  vi.mt.un_320 cy.uz.un_760 
  0x481015a0, 0x53002114, 0x370a38a4, 0x21003013,   // un.be.tt_322 jw.ht.un_660  tk.mk.ba_433 uz.fa.un_650 
  // [4bd0]
  0x383c370b, 0x53002120, 0x30006913, 0x203062a4,   // ba.ug.tk_542 jw.ht.un_850  mfe.uz.un_650 kha.uz.sq_433 
  0x28303455, 0x23001c04, 0x53222111, 0x30103708,   // ps.uz.sd_442 id.ca.un_320  jw.oc.ht_653 ba.be.uz_443 
  0x22232111, 0x0f000205, 0x032c09a0, 0x02002805,   // jw.ca.oc_653 da.lv.un_330  pl.fy.nl_322 sw.da.un_330 
  0x3200300c, 0x1c0221a0, 0x2f2868a6, 0x2f000202,   // uz.bs.un_530 jw.da.id_322  ig.sw.su_521 da.su.un_220 
  // [4be0]
  0x150415ec, 0x370a04ee, 0x2d002a05, 0x07360aa9,   // un.ru.un_644 ru.mk.ba_422  mt.sk.un_330 mk.ab.bg_544 
  0x34000404, 0x2a002205, 0x0c291704, 0x20001e1a,   // fi.xh.un_320 oc.mt.un_330  sr.sl.sv_332 am.ti.un_760 
  0x3f030e07, 0x0d002d18, 0x07001709, 0x3200170e,   // is.nl.af_432 sk.cs.un_740  sr.bg.un_440 sr.bs.un_550 
  0x10002512, 0x122229a4, 0x10002902, 0x22232a08,   // mn.be.un_640 sl.oc.hu_433  sl.lt.un_220 mt.ca.oc_443 
  // [4bf0]
  0x56003f02, 0x294311a0, 0x195f3705, 0x21003019,   // af.mg.un_220 ro.ie.sl_322  st.tn.gl_333 uz.fa.un_750 
  0x5a4f5fa9, 0x041508a9, 0x6a00370e, 0x0c003f0d,   // tn.bi.sm_544 uk.ru.un_540  st.haw.un_550 af.sv.un_540 
  0x12183d04, 0x73344512, 0x02033fa0, 0x49563707,   // ku.ar.ur_332 ln.xh.ny_654  af.nl.da_322 st.mg.to_432 
  0x75735faf, 0x38003520, 0x653f2ca0, 0x455f2da4,   // tn.ny.nso_655 tg.tk.un_850  fy.af.gv_322 sk.tn.ln_433 
  
  // [4c00]
  0x6b1d150c, 0x394573a4, 0x18342105, 0x34007319,   // un.la.ceb_543 ny.ln.br_433  fa.ps.ar_333 ny.xh.un_750 
  0x1700080d, 0x24490755, 0x5f37750e, 0x5a6445a9,   // uk.sr.un_540 it.to.eo_442  nso.st.tn_555 ln.lg.sm_544 
  0x245f75a9, 0x03013fa0, 0x385f370c, 0x23353cee,   // nso.tn.eo_544 af.en.nl_322  st.tn.tk_543 ug.tg.ky_422 
  0x335f370b, 0x30153507, 0x21123dee, 0x04101505,   // st.tn.nn_542 tg.uz.un_420  ku.ur.fa_422 un.be.ru_333 
  // [4c10]
  0x06004605, 0x18283411, 0x123d210c, 0x383c2314,   // qu.de.un_330 ps.sd.ar_653  fa.ku.ur_543 ky.ug.tk_666 
  0x12343ba0, 0x55000504, 0x793105a4, 0x3748440c,   // ks.ps.ur_322 fr.rw.un_320  fr.az.war_433 kk.tt.ba_543 
  0x3e002205, 0x130d090d, 0x1e004804, 0x304817a4,   // oc.rm.un_330 hi.ne.bh_554  tt.ms.un_320 sr.tt.uz_433 
  0x342818a4, 0x1d230505, 0x0d1c13a6, 0x27422404,   // ar.sd.ps_433 fr.ca.la_333  bh.mr.ne_521 eo.co.gd_332 
  // [4c20]
  0x6e34350b, 0x0000132d, 0x6512fc07, 0x024e4655,   // zu.xh.hmn_542 bh.un.un_A00  zzp.hu.gv_432 qu.ay.da_442 
  0x031827af, 0x23190b05, 0x605c73ac, 0x46004e13,   // gd.ga.nl_655 es.gl.ca_333  ny.sa.vo_632 ay.qu.un_650 
  0x43000104, 0x374efc11, 0x2cfc0307, 0x0500540e,   // en.ie.un_320 zzp.ay.st_653  nl.zzp.fy_432 ik.fr.un_550 
  0x151517a4, 0x3c2344a4, 0x330802af, 0x05023b04,   // sr.un.un_430 kk.ky.ug_433  da.no.nn_655 so.da.fr_332 
  // [4c30]
  0x015afca0, 0x1d2305af, 0x6e18fca7, 0x561d05a0,   // zzp.sm.en_322 fr.ca.la_655  zzp.ga.hmn_532 fr.la.mg_322 
  0x48374404, 0x621827af, 0x0165fc04, 0x18626e05,   // kk.ba.tt_332 gd.ga.kha_655  zzp.gv.en_332 hmn.kha.ga_333 
  0xfc003819, 0x2b18fc04, 0x34281209, 0x634e460b,   // tk.zzp.un_750 zzp.ga.vi_332  ur.sd.ps_444 qu.ay.sco_542 
  0x02004e12, 0x0d5c1c05, 0x6500fc08, 0x1dfc1f08,   // ay.da.un_640 mr.sa.ne_333  zzp.gv.un_430 cy.zzp.la_443 
  // [4c40]
  0x09184e09, 0x011d15ad, 0x4a1f27ee, 0x3800fc02,   // ay.ga.pl_444 un.la.en_643  gd.cy.yo_422 zzp.tk.un_220 
  0x18fc5caf, 0x0d004204, 0x65fc5c0c, 0x1d004e07,   // sa.zzp.ga_655 co.cs.un_320  sa.zzp.gv_543 ay.la.un_420 
  0x2f001302, 0x110736a4, 0x065713af, 0x02380807,   // et.su.un_220 ab.bg.ro_433  et.na.de_655 no.tk.da_432 
  0x1b455707, 0x151b385a, 0x64000202, 0x6b381ba4,   // na.ln.tr_432 tk.tr.un_553  da.lg.un_220 tr.tk.ceb_433 
  // [4c50]
  0x3504100c, 0x38000c08, 0x3008480c, 0x13fc25a4,   // be.ru.tg_543 sv.tk.un_430  tt.uk.uz_543 eu.zzp.et_433 
  0x385c3207, 0x082335a7, 0xfc002007, 0x38331ba0,   // bs.sa.tk_432 tg.ky.uk_532  sq.zzp.un_420 tr.nn.tk_322 
  0x0c2d38a4, 0x03fc2807, 0x68171dee, 0x5c1c0d08,   // tk.sk.sv_433 sw.zzp.nl_432  la.sr.ig_422 ne.mr.sa_443 
  0x1b2d3802, 0x33000207, 0x632c1fa0, 0x0100011a,   // tk.sk.tr_222 da.nn.un_420  cy.fy.sco_322 iw.iw.un_760 
  // [4c60]
  0x30002a19, 0x381b4812, 0x302f1107, 0x280c480e,   // mt.uz.un_750 tt.tr.tk_654  ro.su.uz_432 tt.sv.sw_555 
  0x17110aa4, 0x1b0c3814, 0x625a11a4, 0x40004b35,   // mk.ro.sr_433 tk.sv.tr_666  ro.sm.kha_433 mi.lb.un_A90 
  0x494b5012, 0xfc000704, 0x17234408, 0x17040a02,   // fj.mi.to_654 it.zzp.un_320  kk.ky.sr_443 mk.ru.sr_222 
  0x402c49af, 0x5a112212, 0x53002108, 0x4b002c13,   // to.fy.lb_655 oc.ro.sm_654  jw.ht.un_430 fy.mi.un_650 
  // [4c70]
  0x0a001719, 0x5600fc07, 0x49656aa0, 0x420c380b,   // sr.mk.un_750 zzp.mg.un_420  haw.gv.to_322 tk.sv.co_542 
  0x104006af, 0x50001122, 0x303924ee, 0x07623312,   // de.lb.lt_655 ro.fj.un_870  eo.br.uz_422 nn.kha.it_654 
  0x1c242704, 0x07004402, 0x522a4907, 0x5a405704,   // gd.eo.id_332 kk.bg.un_220  to.mt.ha_432 na.lb.sm_332 
  0x0b240f07, 0x40161207, 0x475065ec, 0x07001713,   // lv.eo.es_432 hu.hr.lb_432  gv.fj.sn_644 sr.bg.un_650 
  // [4c80]
  0x21003805, 0x07473307, 0x695a76af, 0x0d1c5caf,   // tk.jw.un_330 nn.sn.it_432  crs.sm.mfe_655 sa.mr.ne_655 
  0x211218a4, 0x574f40a9, 0x2f00fe04, 0x23000404,   // ar.ur.fa_433 lb.bi.na_544  tlh.su.un_320 ru.ky.un_320 
  0x1200600e, 0x62005009, 0x6a622212, 0x122134a0,   // vo.hu.un_550 fj.kha.un_440  oc.kha.haw_654 ps.fa.ur_322 
  0x15480404, 0x211b38a0, 0x04130fa0, 0x21001e04,   // ru.tt.un_332 tk.tr.jw_322  lv.et.fi_322 ms.jw.un_320 
  // [4c90]
  0x021210a4, 0x25003004, 0x15001519, 0xfe041307,   // lt.hu.da_433 uz.mn.un_320  un.un.un_750 et.fi.tlh_432 
  0x1618280c, 0x380710ad, 0x0e27fca7, 0x04000204,   // sd.ar.th_543 be.bg.tk_643  zzp.gd.is_532 da.fi.un_320 
  0x60000c0e, 0x0000551c, 0x12342108, 0x02fc1f0e,   // sv.vo.un_550 rw.un.un_800  fa.ps.ur_443 cy.zzp.da_555 
  0x36005508, 0x23113c07, 0x123b2804, 0x131c5c02,   // rw.gn.un_430 ug.ro.ky_432  sd.ks.ur_332 sa.mr.bh_222 
  // [4ca0]
  0x150807a0, 0x2344480b, 0x3d12340d, 0x0d00130c,   // bg.uk.un_322 tt.kk.ky_542  ps.ur.ku_554 bh.ne.un_530 
  0x786a52a4, 0x32001709, 0x211a1e12, 0x55006919,   // ha.haw.ve_433 sr.bs.un_440  ms.tl.jw_654 mfe.rw.un_750 
  0x35343709, 0x1710110d, 0x182134a0, 0x33000c04,   // st.xh.zu_444 ro.be.sr_554  ps.fa.ar_322 sv.nn.un_320 
  0x48005013, 0x37756baf, 0x1a00fe0b, 0x37003812,   // fj.tt.un_650 ceb.nso.st_655  tlh.tl.un_520 tk.ba.un_640 
  // [4cb0]
  0x2f216aa4, 0x6501fc0c, 0x4400250d, 0x25002a02,   // haw.jw.su_433 zzp.en.gv_543  mn.kk.un_540 mt.eu.un_220 
  0x1b524c0c, 0x3b002304, 0x443c380c, 0x65002e0d,   // wo.ha.tr_543 ca.so.un_320  tk.ug.kk_543 fo.gv.un_540 
  0x33491807, 0x5f1c1e0c, 0x31003402, 0x78505e12,   // ga.to.nn_432 ms.id.tn_543  xh.az.un_220 ts.fj.ve_654 
  0x481a5a0c, 0x58003b04, 0x23001514, 0x48001b10,   // sm.tl.tt_543 so.om.un_320  un.ky.un_660 tr.tt.un_620 
  // [4cc0]
  0x48006502, 0x08170aa0, 0x0a0738a9, 0x0a173605,   // gv.tt.un_220 mk.sr.uk_322  tk.bg.mk_544 ab.sr.mk_333 
  0x37003807, 0x00002b37, 0x016b630c, 0x1b464e09,   // tk.ba.un_420 vi.un.un_B00  sco.ceb.en_543 ay.qu.tr_444 
  0x0407350c, 0x353404a0, 0x48353860, 0x12003d14,   // tg.bg.ru_543 fi.xh.zu_322  tk.tg.tt_664 ku.ur.un_660 
  0x27fc1812, 0x21005309, 0x2e025807, 0x081017ee,   // ga.zzp.gd_654 ht.jw.un_440  om.da.fo_432 sr.be.uk_422 
  // [4cd0]
  0x23003012, 0x5955380c, 0x2e001004, 0x1a006b09,   // uz.ky.un_640 tk.rw.rn_543  lt.fo.un_320 ceb.tl.un_440 
  0x58004612, 0x48003b02, 0x36006b05, 0x35231507,   // qu.om.un_640 so.tt.un_220  ceb.gn.un_330 un.ky.tg_432 
  0x5c090d0b, 0x042f130c, 0x6b2f21a4, 0x34182802,   // ne.hi.sa_542 et.su.fi_543  jw.su.ceb_433 sd.ar.ps_222 
  0x0e003702, 0x443748a7, 0x28182ba0, 0x2b001c02,   // st.is.un_220 tt.ba.kk_532  vi.ga.sw_322 id.vi.un_220 
  // [4ce0]
  0x11002314, 0x5300210c, 0x120602a9, 0x55211aa4,   // ky.ro.un_660 jw.ht.un_530  da.de.hu_544 tl.jw.rw_433 
  0x281221ee, 0x21005312, 0x2e000404, 0x5d212f0c,   // fa.ur.sd_422 ht.jw.un_640  fi.fo.un_320 su.jw.ss_543 
  0x302315a4, 0x30004619, 0x3d00281b, 0x2100530c,   // un.ky.uz_433 qu.uz.un_750  sd.ku.un_770 ht.jw.un_530 
  0x28003405, 0x15040709, 0x04380ca7, 0x3500230d,   // ps.sd.un_330 bg.ru.un_444  sv.tk.fi_532 ky.tg.un_540 
  // [4cf0]
  0x15174807, 0x0600790c, 0x181221a9, 0x3c48370e,   // tt.sr.un_432 war.de.un_530  fa.ur.ar_544 ba.tt.ug_555 
  0x070835a4, 0x3c37440d, 0x35041507, 0x041036a0,   // tg.uk.bg_433 kk.ba.ug_554  un.ru.tg_432 ab.be.ru_322 
  0x62190a05, 0x48081002, 0x05313f04, 0x30055b0b,   // pt.gl.kha_333 be.uk.tt_222  af.az.fr_332 sg.fr.uz_542 
  0x373035a6, 0x153c38a0, 0x3b59050c, 0x65003e02,   // tg.uz.ba_521 tk.ug.un_322  fr.rn.so_543 rm.gv.un_220 
  // [4d00]
  0x350810af, 0x07002502, 0x15fc1fee, 0x38000c12,   // be.uk.tg_655 mn.bg.un_220  cy.zzp.un_422 sv.tk.un_640 
  0x3e00fc07, 0x3803020d, 0x0a1708a9, 0xfc003e0d,   // zzp.rm.un_420 da.nl.tk_554  uk.sr.mk_544 rm.zzp.un_540 
  0x0c081b08, 0x1d230507, 0x081ffca4, 0x15080414,   // tr.no.sv_443 fr.ca.la_432  zzp.cy.no_433 ru.uk.un_666 
  0x03001b08, 0x63392904, 0x1f006308, 0xfc021f12,   // tr.nl.un_430 sl.br.sco_332  sco.cy.un_430 cy.da.zzp_654 
  // [4d10]
  0x33381102, 0x00005f0f, 0x1f001b02, 0x2510380e,   // ro.tk.nn_222 tn.un.un_600  tr.cy.un_220 tk.be.mn_555 
  0x201ffc08, 0x150804af, 0x15000708, 0x381f1bad,   // zzp.cy.sq_443 ru.uk.un_655  bg.un.un_430 tr.cy.tk_643 
  0x39633ead, 0xfc003e12, 0x0c530204, 0x3ffc1305,   // rm.sco.br_643 rm.zzp.un_640  da.ht.sv_332 et.zzp.af_333 
  0x21303ba4, 0x04083c04, 0x38fc6055, 0x0c381b60,   // ks.uz.fa_433 ug.uk.ru_332  vo.zzp.tk_442 tr.tk.sv_664 
  // [4d20]
  0x12003005, 0x0d1c5c05, 0x5a245d0c, 0x78006a09,   // uz.ur.un_330 sa.mr.ne_333  ss.eo.sm_543 haw.ve.un_440 
  0x25153805, 0xfc003f04, 0x5d00782b, 0x496a3712,   // tk.mn.un_330 af.zzp.un_320  ve.ss.un_980 st.haw.to_654 
  0x5f73450c, 0x20003604, 0x37045fa4, 0x103e11a9,   // ln.ny.tn_543 gn.sq.un_320  tn.fi.st_433 ro.rm.lt_544 
  0x69457611, 0x233c44af, 0x262407ad, 0x12003007,   // crs.ln.mfe_653 kk.ug.ky_655  it.eo.ia_643 uz.ur.un_420 
  // [4d30]
  0x4804155a, 0x56365f0c, 0x27651f08, 0x5f754508,   // un.ru.tt_553 tn.gn.mg_543  cy.gv.gd_443 ln.nso.tn_443 
  0x110a0205, 0x20001f07, 0x57290d0c, 0x5f007514,   // da.pt.ro_333 cy.sq.un_420  cs.sl.na_543 nso.tn.un_660 
  0x34007311, 0x36007308, 0x3b35340c, 0x34192508,   // ny.xh.un_630 ny.gn.un_430  xh.zu.so_543 eu.gl.xh_443 
  0x32002908, 0x3b093402, 0x0c003804, 0x12182805,   // sl.bs.un_430 xh.pl.so_222  tk.sv.un_320 sd.ar.ur_333 
  // [4d40]
  0x2d2924a9, 0x5a190b08, 0x24001c04, 0x1a001f04,   // eo.sl.sk_544 es.gl.sm_443  id.eo.un_320 cy.tl.un_320 
  0x29242da4, 0x230b3604, 0x3710235a, 0x233011ad,   // sk.eo.sl_433 gn.es.ca_332  ky.be.ba_553 ro.uz.ky_643 
  0x233d21a9, 0x1828340c, 0x222d60ec, 0x3e101155,   // fa.ku.ky_544 ps.sd.ar_543  vo.sk.oc_644 ro.lt.rm_442 
  0x23003719, 0x230d18ee, 0x123d21a4, 0x392625a4,   // ba.ky.un_750 ga.cs.ca_422  fa.ku.ur_433 eu.ia.br_433 
  // [4d50]
  0x37004422, 0x62004e08, 0x21426207, 0x09001305,   // kk.ba.un_870 ay.kha.un_430  kha.co.jw_432 bh.hi.un_330 
  0x11100a0c, 0x2f760107, 0x0410080c, 0x6b000104,   // mk.be.ro_543 en.crs.su_432  uk.be.ru_543 en.ceb.un_320 
  0x23003508, 0x083038ad, 0x3748100d, 0x18000d09,   // tg.ky.un_430 tk.uz.uk_643  be.tt.ba_554 cs.ga.un_440 
  0x31004619, 0x11002519, 0x30002a02, 0x1510480c,   // qu.az.un_750 mn.ro.un_750  mt.uz.un_220 tt.be.un_543 
  // [4d60]
  0x1b2430ee, 0x31201b05, 0x0e0c58a0, 0x322d0dad,   // uz.eo.tr_422 tr.sq.az_333  om.sv.is_322 cs.sk.bs_643 
  0x10070aa4, 0x07001809, 0x342112a0, 0x60494d08,   // mk.bg.be_433 ga.it.un_440  ur.fa.ps_322 aa.to.vo_443 
  0x223e1ca0, 0xfc005808, 0x315146a9, 0x070a1508,   // id.rm.oc_322 om.zzp.un_430  qu.kl.az_544 un.mk.bg_443 
  0x0e102e05, 0x0410460d, 0x52006719, 0x67004922,   // fo.lt.is_333 qu.lt.fi_554  ak.ha.un_750 to.ak.un_870 
  // [4d70]
  0x3f0329a0, 0x495a670c, 0x07004208, 0x69006721,   // sl.nl.af_322 ak.sm.to_543  co.it.un_430 ak.mfe.un_860 
  0x2200230d, 0x08150407, 0x18004202, 0x1500100c,   // ca.oc.un_540 ru.uk.un_420  co.ga.un_220 be.un.un_530 
  0x2900400d, 0x6500fc13, 0x080710a0, 0x052852a7,   // lb.sl.un_540 zzp.gv.un_650  be.bg.uk_322 ha.sw.fr_532 
  0x06003f05, 0x434869a4, 0x190d3607, 0x390e22a0,   // af.de.un_330 mfe.tt.ie_433  gn.cs.gl_432 oc.is.br_322 
  // [4d80]
  0x29033911, 0x281821a7, 0x2300352a, 0x5a5849a4,   // br.nl.sl_653 fa.ar.sd_532  tg.ky.un_970 to.om.sm_433 
  0x60000108, 0x5f5e370e, 0x37303c08, 0x07170a07,   // en.vo.un_430 st.ts.tn_555  ug.uz.ba_443 mk.sr.bg_432 
  0x231965ee, 0x5f00fe08, 0x0e396509, 0x3e595508,   // gv.gl.ca_422 tlh.tn.un_430  gv.br.is_444 rw.rn.rm_443 
  0x1d000904, 0x23003c35, 0x232c650c, 0x090276a9,   // pl.la.un_320 ug.ky.un_A90  gv.fy.ca_543 crs.da.pl_544 
  // [4d90]
  0x2d000909, 0x040c1302, 0x0200210e, 0x19000d08,   // pl.sk.un_440 et.sv.fi_222  jw.da.un_550 cs.gl.un_430 
  0x183d3408, 0x211f3904, 0x39002022, 0x36000d04,   // ps.ku.ar_443 br.cy.jw_332  sq.br.un_870 cs.gn.un_320 
  0x083e5505, 0x101c3802, 0x09002d0c, 0x083035ad,   // rw.rm.no_333 tk.id.lt_222  sk.pl.un_530 tg.uz.uk_643 
  0x134c040b, 0x1f033fa4, 0x1f004714, 0x382d0908,   // fi.wo.et_542 af.nl.cy_433  sn.cy.un_660 pl.sk.tk_443 
  // [4da0]
  0x1c005002, 0x5c1c0dad, 0x34003018, 0x30083cad,   // fj.id.un_220 ne.mr.sa_643  uz.ps.un_740 ug.uk.uz_643 
  0x131c0908, 0x1d0343a0, 0x2d121905, 0x351515a4,   // hi.mr.bh_443 ie.nl.la_322  gl.hu.sk_333 un.tg.un_430 
  0x44003c19, 0x12001905, 0x070a35a7, 0x192d0d04,   // ug.kk.un_750 gl.hu.un_330  tg.mk.bg_532 cs.sk.gl_332 
  0x1b1338a9, 0x30211808, 0x2d0d19ee, 0x03401f11,   // tk.et.tr_544 ar.fa.uz_443  gl.cs.sk_422 cy.lb.nl_653 
  // [4db0]
  0x17000408, 0x3f001f19, 0x073c3060, 0x3800230d,   // ru.sr.un_430 cy.af.un_750  uz.ug.bg_664 ky.tk.un_540 
  0x21003604, 0x12193604, 0x253835ec, 0x07152307,   // gn.jw.un_320 gn.gl.hu_332  tg.tk.mn_644 ky.bg.un_420 
  0x29000f1a, 0x0c043005, 0x1000081b, 0x1000230c,   // lv.sl.un_760 uz.fi.sv_333  uk.be.un_770 ky.be.un_530 
  0x624e0f07, 0xfc00010d, 0x3e150107, 0x631b01a0,   // lv.ay.kha_432 en.zzp.un_540  en.rm.un_420 en.tr.sco_322 
  // [4dc0]
  0x3857580c, 0x3d003408, 0x52283b08, 0x4000fe04,   // om.na.tk_543 ps.ku.un_430  so.sw.ha_443 tlh.lb.un_320 
  0x3b3338ee, 0x5c355d08, 0x35003614, 0x0d363ea4,   // tk.nn.so_422 ss.zu.sa_443  ab.tg.un_660 rm.gn.cs_433 
  0x653bfc14, 0x58006504, 0x45fc62a9, 0x5847650c,   // zzp.so.gv_666 gv.om.un_320  kha.zzp.ln_544 gv.sn.om_543 
  0x1865300c, 0x0a1707ad, 0x190a0b0e, 0x3618fc08,   // uz.gv.ga_543 bg.sr.mk_643  es.pt.gl_555 zzp.ga.gn_443 
  // [4dd0]
  0x11003e22, 0x4e3e4208, 0x3bfc6504, 0x1b0b0204,   // rm.ro.un_870 co.rm.ay_443  gv.zzp.so_332 da.es.tr_332 
  0x3e060c04, 0x2002fc09, 0x3e630107, 0x1d42050b,   // sv.de.rm_332 zzp.da.sq_444  en.sco.rm_432 fr.co.la_542 
  0x020a1dad, 0x1b003104, 0x2c001807, 0x583b65af,   // la.pt.da_643 az.tr.un_320  ga.fy.un_420 gv.so.om_655 
  0x214006a0, 0x3b001814, 0x40570611, 0x03005802,   // de.lb.jw_322 ga.so.un_660  de.na.lb_653 om.nl.un_220 
  // [4de0]
  0x06fc3b04, 0x3c38230e, 0x100804af, 0x13095ca9,   // so.zzp.de_332 ky.tk.ug_555  ru.uk.be_655 sa.hi.bh_544 
  0x05002f04, 0x31303e07, 0x65fc30a4, 0x190b1da9,   // su.fr.un_320 rm.uz.az_432  uz.zzp.gv_433 la.es.gl_544 
  0x311b61af, 0x113efe13, 0x653b1da4, 0x3e000b04,   // za.tr.az_655 tlh.rm.ro_665  la.so.gv_433 es.rm.un_320 
  0x12342802, 0x026301a0, 0x785e34a9, 0x06401508,   // sd.ps.ur_222 en.sco.da_322  xh.ts.ve_544 un.lb.de_443 
  // [4df0]
  0x4706fca0, 0x25790ba0, 0x06fe400c, 0x3e40060d,   // zzp.de.sn_322 es.war.eu_322  lb.tlh.de_543 de.lb.rm_554 
  0x2e620107, 0x0c00fc21, 0x6515fcad, 0x303b4609,   // en.kha.fo_432 zzp.sv.un_860  zzp.gv.un_630 qu.so.uz_444 
  0x23003507, 0x0a151705, 0x36401807, 0x5645050c,   // tg.ky.un_420 sr.mk.un_330  ga.lb.gn_432 fr.ln.mg_543 
  0x16321707, 0x374830ee, 0x04150a04, 0x2f003605,   // sr.bs.hr_432 uz.tt.ba_422  mk.ru.un_320 gn.su.un_330 
  // [4e00]
  0x0d003608, 0x40000504, 0x1821300c, 0x39033fa0,   // gn.cs.un_430 fr.lb.un_320  uz.fa.ar_543 af.nl.br_322 
  0x1500150c, 0x23003602, 0x2c033fa9, 0x1d00670c,   // un.un.un_530 gn.ca.un_220  af.nl.fy_544 ak.la.un_530 
  0x13006311, 0x25041104, 0x50451a0d, 0x63001f12,   // sco.et.un_630 ro.fi.eu_332  tl.ln.fj_554 cy.sco.un_640 
  0x08041008, 0x285275a9, 0x1b004604, 0x1a4b5009,   // be.ru.uk_443 nso.ha.sw_544  qu.tr.un_320 fj.mi.tl_444 
  // [4e10]
  0x12342107, 0x1a602508, 0x1d004904, 0x65006308,   // fa.ps.ur_432 eu.vo.tl_443  to.la.un_320 sco.gv.un_430 
  0x04004608, 0x73005d08, 0x02255505, 0x215d55ee,   // qu.fi.un_430 ss.ny.un_430  rw.eu.da_333 rw.ss.jw_422 
  0x39001f02, 0x44000812, 0x5525310c, 0x2c003f07,   // cy.br.un_220 uk.kk.un_640  az.eu.rw_543 af.fy.un_420 
  0x2d47790c, 0x11042504, 0x48372312, 0x50594eec,   // war.sn.sk_543 eu.fi.ro_332  ky.ba.tt_654 ay.rn.fj_644 
  // [4e20]
  0x564b4eec, 0x1a4e1ea4, 0x10070a12, 0x24004a20,   // ay.mi.mg_644 ms.ay.tl_433  mk.bg.be_654 yo.eo.un_850 
  0x27194307, 0x341230a9, 0x0000052d, 0x1d256908,   // ie.gl.gd_432 uz.ur.ps_544  fr.un.un_A00 mfe.eu.la_443 
  0x4c00390c, 0x0a122da4, 0x3b6425a0, 0x47003504,   // br.wo.un_530 sk.hu.pt_433  eu.lg.so_322 zu.sn.un_320 
  0x4c006235, 0xfc004002, 0x21341812, 0x3f036502,   // kha.wo.un_A90 lb.zzp.un_220  ar.ps.fa_654 gv.nl.af_222 
  // [4e30]
  0xfc005307, 0x53000208, 0x25646907, 0x3738250e,   // ht.zzp.un_420 da.ht.un_430  mfe.lg.eu_432 mn.tk.ba_555 
  0x732138a4, 0x536976ad, 0x5e02380c, 0x533821a4,   // tk.jw.ny_433 crs.mfe.ht_643  tk.da.ts_543 jw.tk.ht_433 
  0x3873470e, 0x735c3807, 0x2a5f130c, 0x095c3807,   // sn.ny.tk_555 tk.sa.ny_432  et.tn.mt_543 tk.sa.pl_432 
  0x27000c02, 0x18002a02, 0x6b1a38ad, 0x4b1a3804,   // sv.gd.un_220 mt.ga.un_220  tk.tl.ceb_643 tk.tl.mi_332 
  // [4e40]
  0x3b005c02, 0x4a000e2a, 0x79214b0c, 0x21004e09,   // sa.so.un_220 is.yo.un_970  mi.jw.war_543 ay.jw.un_440 
  0x0a002a05, 0x532802ec, 0x552a28a0, 0x25190b5a,   // mt.pt.un_330 da.sw.ht_644  sw.mt.rw_322 es.gl.eu_553 
  0x2b001809, 0x0a073814, 0x4b4a5904, 0x063918a0,   // ga.vi.un_440 tk.bg.mk_666  rn.yo.mi_332 ga.br.de_322 
  0x19000b19, 0x5a5007a4, 0x4f4d1a07, 0x18004a21,   // es.gl.un_750 it.fj.sm_433  tl.aa.bi_432 yo.ga.un_860 
  // [4e50]
  0x5f00751a, 0x3f5c380c, 0x22000a07, 0x00004a2d,   // nso.tn.un_760 tk.sa.af_543  pt.oc.un_420 yo.un.un_A00 
  0x1a6b380c, 0x474a52a7, 0x230417ee, 0x2a003804,   // tk.ceb.tl_543 ha.yo.sn_532  sr.ru.ky_422 tk.mt.un_320 
  0x4815385a, 0x44362313, 0x0408150c, 0x64002a0d,   // tk.tt.un_530 ky.ab.kk_665  un.uk.ru_543 mt.lg.un_540 
  0x3d211207, 0x34211202, 0x0e184a14, 0x4a504e55,   // ur.fa.ku_432 ur.fa.ps_222  yo.ga.is_666 ay.fj.yo_442 
  // [4e60]
  0x4b00090d, 0x46005002, 0x73526e04, 0x34005007,   // pl.mi.un_540 fj.qu.un_220  hmn.ha.ny_332 fj.xh.un_420 
  0x3e003504, 0x0a002a07, 0x10362560, 0x53784a11,   // zu.rm.un_320 mt.pt.un_420  mn.ab.be_664 yo.ve.ht_653 
  0x122a0aee, 0x041735a0, 0x44233b08, 0x3c170a05,   // pt.mt.hu_422 tg.sr.ru_322  ks.ky.kk_443 mk.sr.ug_333 
  0x34004702, 0x0d5c1c55, 0x2f004c05, 0x482d0d04,   // sn.xh.un_220 mr.sa.ne_442  wo.su.un_330 cs.sk.tt_332 
  // [4e70]
  0x39210304, 0x0d2d4804, 0x190b2205, 0x48001508,   // nl.jw.br_332 tt.sk.cs_332  oc.es.gl_333 un.tt.un_430 
  0x21004404, 0x34211210, 0x182112a0, 0x183421a0,   // kk.fa.un_320 ur.fa.ps_642  ur.fa.ar_322 fa.ps.ar_322 
  0x38003023, 0x2f001207, 0x4d2e0e60, 0xfc00470d,   // uz.tk.un_880 hu.su.un_420  is.fo.aa_664 sn.zzp.un_540 
  0x2315040c, 0x083511a7, 0x1b003105, 0x3c2812ee,   // ru.ky.un_530 ro.tg.uk_532  az.tr.un_330 ur.sd.ug_422 
  // [4e80]
  0x52004e07, 0x20003208, 0x12004d0c, 0x3d3421ac,   // ay.ha.un_420 bs.sq.un_430  aa.hu.un_530 fa.ps.ku_632 
  0x35361504, 0x34003c08, 0x102d0d08, 0x04150814,   // un.ab.tg_332 ug.ps.un_430  cs.sk.lt_443 uk.ru.un_660 
  0x0f00330d, 0x09000e07, 0x311a30a0, 0x170a08a0,   // nn.lv.un_540 is.pl.un_420  uz.tl.az_322 uk.mk.sr_322 
  0x2d001b09, 0x123c21a0, 0x381b02a0, 0x5c130da0,   // tr.sk.un_440 fa.ug.ur_322  da.tr.tk_322 ne.bh.sa_322 
  // [4e90]
  0x0000252d, 0x0802fc55, 0x065e23ad, 0x3e052309,   // mn.un.un_A00 zzp.da.no_442  ca.ts.de_643 ca.fr.rm_444 
  0x58000208, 0x2e00020d, 0x10000f05, 0x33080caf,   // da.om.un_430 da.fo.un_540  lv.lt.un_330 sv.no.nn_655 
  0x112322ec, 0x20001b04, 0x0d000619, 0x0800020e,   // oc.ca.ro_644 tr.sq.un_320  de.cs.un_750 da.no.un_550 
  0x0500010d, 0x276518a0, 0x42003e07, 0x3802fca4,   // en.fr.un_540 ga.gv.gd_322  rm.co.un_420 zzp.da.tk_433 
  // [4ea0]
  0x0a071702, 0x292d0d13, 0x17303c0c, 0x05016313,   // sr.bg.mk_222 cs.sk.sl_665  ug.uz.sr_543 sco.en.fr_665 
  0x056301af, 0x04081005, 0x63400612, 0x12003d07,   // en.sco.fr_655 be.uk.ru_333  de.lb.sco_654 ku.ur.un_420 
  0x04151005, 0x1c5c13ec, 0x0d095c14, 0x30004405,   // be.ru.un_330 bh.sa.mr_644  sa.hi.ne_666 kk.uz.un_330 
  0x37483c0d, 0x130d5c0c, 0x1c0d090d, 0x12003b1b,   // ug.tt.ba_554 sa.ne.bh_543  hi.ne.mr_554 ks.ur.un_770 
  // [4eb0]
  0x3000250c, 0x44001002, 0x150711a4, 0x0a3836ad,   // mn.uz.un_530 be.kk.un_220  ro.bg.un_433 ab.tk.mk_643 
  0x2d002e04, 0x2d0e2ea0, 0x0a071005, 0x2e002d07,   // fo.sk.un_320 fo.is.sk_322  be.bg.mk_333 sk.fo.un_420 
  0x0163150c, 0x343012a0, 0x1d004607, 0x53751c04,   // un.sco.en_543 ur.uz.ps_322  qu.la.un_420 id.nso.ht_332 
  0x38000204, 0x15000104, 0x3d3021a0, 0x0360065a,   // da.tk.un_320 en.un.un_320  fa.uz.ku_322 de.vo.nl_553 
  // [4ec0]
  0x345f35a0, 0x08041560, 0x35345da9, 0xfc00581a,   // zu.tn.xh_322 un.ru.uk_664  ss.xh.zu_544 om.zzp.un_760 
  0x3428350c, 0x2d000d18, 0x2bfc6212, 0x05004612,   // zu.sw.xh_543 cs.sk.un_740  kha.zzp.vi_654 qu.fr.un_640 
  0x0a0c0107, 0x44003819, 0x23003004, 0x2f261ca4,   // en.sv.pt_432 tk.kk.un_750  uz.ky.un_320 id.ia.su_433 
  0x2300251a, 0x525f2405, 0xfc5827a0, 0x28005a08,   // mn.ky.un_760 eo.tn.ha_333  gd.om.zzp_322 sm.sw.un_430 
  // [4ed0]
  0x2b27fc0c, 0x11004902, 0x3e321604, 0x5c1c13a0,   // zzp.gd.vi_543 to.ro.un_220  hr.bs.rm_332 bh.mr.sa_322 
  0x25001509, 0x1d110702, 0x2b36fcee, 0x2b00fc07,   // un.eu.un_440 it.ro.la_222  zzp.gn.vi_422 zzp.vi.un_420 
  0x301535a4, 0xfc050307, 0x360d1f07, 0x4e00fc08,   // tg.uz.un_430 nl.fr.zzp_432  cy.cs.gn_432 zzp.ay.un_430 
  0x0cfc33ee, 0x1a126b12, 0x36005a12, 0x3f1125a7,   // nn.zzp.sv_422 ceb.hu.tl_654  sm.gn.un_640 eu.ro.af_532 
  // [4ee0]
  0x79002009, 0x47006013, 0x2c1f060c, 0x15003c1a,   // sq.war.un_440 vo.sn.un_650  de.cy.fy_543 ug.un.un_760 
  0x020f0908, 0x56003e04, 0x07000414, 0x383015af,   // pl.lv.da_443 rm.mg.un_320  ru.bg.un_660 un.uz.tk_655 
  0x470603a4, 0x1b003021, 0xfc092c11, 0x08170a0b,   // nl.de.sn_433 uz.tr.un_860  fy.pl.zzp_653 mk.sr.uk_542 
  0x4b1a62ec, 0x0f000209, 0x24121c07, 0x383731ee,   // kha.tl.mi_644 da.lv.un_440  id.hu.eo_432 az.st.tk_422 
  // [4ef0]
  0x5d4a5e0c, 0x0157fc0c, 0x69761eaf, 0x3f101f07,   // ts.yo.ss_543 zzp.na.en_543  ms.crs.mfe_655 cy.lt.af_432 
  0x197942a9, 0xfc003607, 0x07004222, 0x033f0fec,   // co.war.gl_544 gn.zzp.un_420  co.it.un_870 lv.af.nl_644 
  0x351b5d05, 0x4400371b, 0x3c303809, 0x1a5a4aa4,   // ss.tr.zu_333 ba.kk.un_770  tk.uz.ug_444 yo.sm.tl_433 
  0x1b3031ad, 0x5f7345a4, 0x28002d12, 0x05003908,   // az.uz.tr_643 ln.ny.tn_433  sk.sw.un_640 br.fr.un_430 
  // [4f00]
  0x3942fe5a, 0x0a5d39a0, 0x1b4d3108, 0x5c1a6b0b,   // tlh.co.br_553 br.ss.pt_322  az.aa.tr_443 ceb.tl.sa_542 
  0xfc4f36af, 0x55003902, 0x303431af, 0x22002322,   // gn.bi.zzp_655 br.rw.un_220  az.xh.uz_655 ca.oc.un_870 
  0x48313013, 0x39002d13, 0x5700092a, 0x1f00041b,   // uz.az.tt_665 sk.br.un_650  pl.na.un_970 fi.cy.un_770 
  0x35001708, 0x0711440d, 0x190b60a9, 0x73753708,   // sr.tg.un_430 kk.ro.bg_554  vo.es.gl_544 st.nso.ny_443 
  // [4f10]
  0x63005319, 0x072f4fad, 0x5600390c, 0x080704a4,   // ht.sco.un_750 bi.su.it_643  br.mg.un_530 ru.bg.uk_433 
  0x48151109, 0x5137fe0b, 0x3c3611a4, 0x651b6404,   // ro.tt.un_440 tlh.st.kl_542  ro.ab.ug_433 lg.tr.gv_332 
  0x131c0d08, 0x47287312, 0x01001802, 0x42003e0b,   // ne.mr.bh_443 ny.sw.sn_654  ga.en.un_220 rm.co.un_520 
  0x5c4c1a0c, 0x1f341802, 0x3e002308, 0x44233507,   // tl.wo.sa_543 ga.xh.cy_222  ca.rm.un_430 tg.ky.kk_432 
  // [4f20]
  0x0a17300c, 0x2a003708, 0x64005312, 0x4800122b,   // uz.sr.mk_543 st.mt.un_430  ht.lg.un_640 hu.tt.un_980 
  0x63000314, 0x44000412, 0x60795ca4, 0x02005c12,   // nl.sco.un_660 ru.kk.un_640  sa.war.vo_433 sa.da.un_640 
  0x102d0d5a, 0x3c213d05, 0x3700621a, 0x343d3007,   // cs.sk.lt_553 ku.fa.ug_333  kha.st.un_760 uz.ku.ps_432 
  0x12213060, 0x53105c60, 0x231715a4, 0x0a00380d,   // uz.fa.ur_664 sa.lt.ht_664  un.sr.ky_433 tk.mk.un_540 
  // [4f30]
  0x02033f07, 0x3f533b04, 0x08004405, 0x07004802,   // af.nl.da_432 so.ht.af_332  kk.uk.un_330 tt.bg.un_220 
  0x125860a0, 0x1510040d, 0x03332207, 0x0a005c0b,   // vo.om.hu_322 ru.be.un_554  oc.nn.nl_432 sa.pt.un_520 
  0x241f12a0, 0x1e1b3904, 0x65003605, 0x0000260f,   // hu.cy.eo_322 br.tr.ms_332  gn.gv.un_330 ia.un.un_600 
  0x13005c07, 0x18212304, 0x105afe0c, 0x234844a4,   // sa.bh.un_420 ky.fa.ar_332  tlh.sm.lt_543 kk.tt.ky_433 
  // [4f40]
  0x30003b02, 0x23002512, 0x28303b04, 0x304f4da0,   // so.uz.un_220 mn.ky.un_640  ks.uz.sd_332 aa.bi.uz_322 
  0x63000208, 0x3b004808, 0x381b4daf, 0x2e330c55,   // da.sco.un_430 tt.so.un_430  aa.tr.tk_655 sv.nn.fo_442 
  0x4d4058a4, 0x48001219, 0x25302304, 0x1c095c08,   // om.lb.aa_433 hu.tt.un_750  ky.uz.mn_332 sa.hi.mr_443 
  0x11170a08, 0x38121bee, 0x2800340e, 0x1b384ead,   // mk.sr.ro_443 tr.hu.tk_422  ps.sd.un_550 ay.tk.tr_643 
  // [4f50]
  0x06130407, 0x4a000e05, 0x04153607, 0x08351704,   // fi.et.de_432 is.yo.un_330  ab.ru.un_420 sr.tg.uk_332 
  0x381115af, 0x07001007, 0x53374b0b, 0x01654b02,   // un.ro.tk_655 be.bg.un_420  mi.st.ht_542 mi.gv.en_222 
  0x3e000402, 0x10000914, 0x2e002c07, 0x55006814,   // fi.rm.un_220 pl.lt.un_660  fy.fo.un_420 ig.rw.un_660 
  0x17000705, 0x09000202, 0x3400682b, 0x18002811,   // bg.sr.un_330 da.pl.un_220  ig.xh.un_980 sd.ar.un_630 
  // [4f60]
  0x0c000907, 0x32002504, 0x595524af, 0x04002d04,   // pl.sv.un_420 eu.bs.un_320  eo.rw.rn_655 sk.fi.un_320 
  0x01003502, 0x1715040c, 0x10234411, 0x49004b0d,   // zu.en.un_220 ru.sr.un_530  kk.ky.be_653 mi.to.un_540 
  0x212318a4, 0x213b1213, 0x353461a7, 0x46004e19,   // ar.ky.fa_433 ur.ks.fa_665  za.xh.zu_532 ay.qu.un_750 
  0x30481509, 0x07040a0d, 0x53004b02, 0x12213da4,   // un.tt.uz_444 mk.ru.bg_554  mi.ht.un_220 ku.fa.ur_433 
  // [4f70]
  0x2325150c, 0x1c5c0d02, 0x384837a9, 0x25001007,   // un.mn.ky_543 ne.sa.mr_222  ba.tt.tk_544 be.mn.un_420 
  0x39004604, 0x38003202, 0x090d1cee, 0x3e000a04,   // qu.br.un_320 bs.tk.un_220  mr.ne.hi_422 pt.rm.un_320 
  0x650e1f08, 0x64004602, 0x35345d5a, 0x23190a13,   // cy.is.gv_443 qu.lg.un_220  ss.xh.zu_553 pt.gl.ca_665 
  0x0c1f1055, 0x0a003e0c, 0x10000905, 0x00006324,   // lt.cy.sv_442 rm.pt.un_530  pl.lt.un_330 sco.un.un_900 
  // [4f80]
  0x04293207, 0x21294b07, 0x3f006504, 0x2c081004,   // bs.sl.fi_432 mi.sl.jw_432  gv.af.un_320 lt.no.fy_332 
  0x193e0a04, 0x35002519, 0x190a3e07, 0x215559a9,   // pt.rm.gl_332 mn.tg.un_750  rm.pt.gl_432 rn.rw.jw_544 
  0x08101504, 0x47003502, 0xfe000d08, 0x2155790c,   // un.be.uk_332 zu.sn.un_220  cs.tlh.un_430 war.rw.jw_543 
  0x2e000c02, 0x43006320, 0x04173004, 0x381304a7,   // sv.fo.un_220 sco.ie.un_850  uz.sr.ru_332 fi.et.tk_532 
  // [4f90]
  0x341230ee, 0x383536ad, 0x1139610c, 0x563555a6,   // uz.ur.ps_422 ab.tg.tk_643  za.br.ro_543 rw.zu.mg_521 
  0x21781e0c, 0x04002105, 0x20003102, 0x3c0807a4,   // ms.ve.jw_543 jw.fi.un_330  az.sq.un_220 bg.uk.ug_433 
  0x0300021a, 0x02033f04, 0x790657a4, 0x17071008,   // da.nl.un_760 af.nl.da_332  na.de.war_433 be.bg.sr_443 
  0x281e2a04, 0x3f021fa4, 0x5706405a, 0x0f25230c,   // mt.ms.sw_332 cy.da.af_433  lb.de.na_553 ca.eu.lv_543 
  // [4fa0]
  0x1b00470d, 0x3f250308, 0x2c783fa4, 0x2a00570c,   // sn.tr.un_540 nl.eu.af_443  af.ve.fy_433 na.mt.un_530 
  0x2e5267ee, 0x03002c04, 0x205821a0, 0x090f6707,   // ak.ha.fo_422 fy.nl.un_320  jw.om.sq_322 ak.lv.pl_432 
  0x03002c14, 0x033f0212, 0x3067680c, 0x4a672f08,   // fy.nl.un_660 da.af.nl_654  ig.ak.uz_543 su.ak.yo_443 
  0x30003708, 0x67527309, 0x35345ca9, 0x47fc73a9,   // ba.uz.un_430 ny.ha.ak_444  sa.xh.zu_544 ny.zzp.sn_544 
  // [4fb0]
  0x35001e04, 0x65002505, 0x1f005505, 0x4a00672c,   // ms.zu.un_320 eu.gv.un_330  rw.cy.un_330 ak.yo.un_990 
  0x35250aee, 0x01001c04, 0x12182112, 0x230a3508,   // mk.mn.tg_422 id.en.un_320  fa.ar.ur_654 tg.mk.ky_443 
  0x632c1214, 0x2000650e, 0x621f01a0, 0x2500fc04,   // hu.fy.sco_666 gv.sq.un_550  en.cy.kha_322 zzp.eu.un_320 
  0x06402512, 0x03023f08, 0x405706a4, 0x2134fca4,   // eu.lb.de_654 af.da.nl_443  de.na.lb_433 zzp.xh.jw_433 
  // [4fc0]
  0x7300751b, 0x2f00050c, 0x68007512, 0x2a000604,   // nso.ny.un_770 fr.su.un_530  nso.ig.un_640 de.mt.un_320 
  0x15003302, 0x68006722, 0x04003609, 0x1000610d,   // nn.un.un_220 ak.ig.un_870  ab.ru.un_440 za.lt.un_540 
  0x34004705, 0x203e2207, 0x3400280d, 0x233e19a7,   // sn.xh.un_330 oc.rm.sq_432  sd.ps.un_540 gl.rm.ca_532 
  0x0306fc07, 0x123d340e, 0x190a4205, 0x22002319,   // zzp.de.nl_432 ps.ku.ur_555  co.pt.gl_333 ca.oc.un_750 
  // [4fd0]
  0x48371109, 0x07363855, 0x38353c12, 0x135c09a6,   // ro.ba.tt_444 tk.ab.bg_442  ug.tg.tk_654 hi.sa.bh_521 
  0x0e006404, 0x1504230c, 0x35003c19, 0x10422307,   // lg.is.un_320 ky.ru.un_543  ug.tg.un_750 ca.co.lt_432 
  0x0a3e65ec, 0x04172507, 0x3e421105, 0x040711ee,   // gv.rm.pt_644 mn.sr.ru_432  ro.co.rm_333 ro.bg.ru_422 
  0x3d3430a0, 0x3035360b, 0x28001809, 0x12003902,   // uz.ps.ku_322 ab.tg.uz_542  ar.sd.un_440 br.hu.un_220 
  // [4fe0]
  0x3d003413, 0x07360404, 0x5e4a680c, 0x0f000202,   // ps.ku.un_650 ru.ab.bg_332  ig.yo.ts_543 da.lv.un_220 
  0x65151fa0, 0x3f0cfe0c, 0x30113ca4, 0x10002a02,   // cy.gv.un_320 tlh.sv.af_543  ug.ro.uz_433 mt.lt.un_220 
  0x1504150c, 0x360415a4, 0x0e2efcec, 0x28183460,   // un.ru.un_543 un.ru.ab_433  zzp.fo.is_644 ps.ar.sd_664 
  0x05421304, 0x13001c12, 0x06fc25a0, 0x28000c0c,   // et.co.fr_332 mr.bh.un_640  eu.zzp.de_322 sv.sw.un_530 
  // [4ff0]
  0x08350404, 0x0d000913, 0x3f2548a0, 0x11001d04,   // ru.tg.uk_332 hi.ne.un_650  tt.eu.af_322 la.ro.un_320 
  0x0c000302, 0x2b002402, 0x3b001222, 0x251d65a4,   // nl.sv.un_220 eo.vi.un_220  ur.ks.un_870 gv.la.eu_433 
  0x1e2528ee, 0x2e033f0c, 0x0e3e1104, 0x39060e5a,   // sw.eu.ms_422 af.nl.fo_543  ro.rm.is_332 is.de.br_553 
  0x10000f1a, 0x03004007, 0x01000804, 0x6515010b,   // lv.lt.un_760 lb.nl.un_420  no.en.un_320 en.gv.un_520 
  
  // [5000]
  0x21303d12, 0x1e001507, 0x18002c02, 0x01003304,   // ku.uz.fa_654 un.ms.un_420  fy.ga.un_220 nn.en.un_320 
  0x3015255a, 0x1d3e1107, 0x15650307, 0x12002118,   // mn.uz.un_530 ro.rm.la_432  nl.gv.un_432 fa.ur.un_740 
  0x330212ec, 0x5f031ea9, 0x69004c14, 0x05000121,   // hu.da.nn_644 ms.nl.tn_544  wo.mfe.un_660 en.fr.un_860 
  0x330816a0, 0x2000480d, 0x640802a7, 0x2344485a,   // hr.no.nn_322 tt.sq.un_540  da.no.lg_532 tt.kk.ky_553 
  // [5010]
  0x400915ee, 0x45171255, 0x6500670e, 0x0c00120d,   // un.pl.lb_422 hu.sr.ln_442  ak.gv.un_550 hu.sv.un_540 
  0xfc0138a0, 0x15fc4604, 0x04004407, 0x1729125a,   // tk.en.zzp_322 qu.zzp.un_332  kk.ru.un_420 hu.sl.sr_553 
  0x65003e09, 0x12283b04, 0x04002407, 0x02000822,   // rm.gv.un_440 ks.sd.ur_332  eo.fi.un_420 no.da.un_870 
  0x021215a9, 0x17001207, 0x0c291255, 0x18342813,   // un.hu.da_544 hu.sr.un_420  hu.sl.sv_442 sd.ps.ar_665 
  // [5020]
  0x13090d12, 0x30173502, 0x3d12210c, 0x2100050d,   // ne.hi.bh_654 tg.sr.uz_222  fa.ur.ku_543 fr.jw.un_540 
  0x2128120d, 0x22420507, 0x30003c14, 0x1e281207,   // ur.sd.fa_554 fr.co.oc_432  ug.uz.un_660 hu.sw.ms_432 
  0x3004480c, 0x040a1012, 0x07002a08, 0x6455470c,   // tt.ru.uz_543 be.mk.ru_654  mt.it.un_430 sn.rw.lg_543 
  0x4500251a, 0x53fc3902, 0x22056055, 0x23303ca6,   // eu.ln.un_760 br.zzp.ht_222  vo.fr.oc_442 ug.uz.ky_521 
  // [5030]
  0x03552a05, 0x10041505, 0x0f253e0c, 0x0d131c0b,   // mt.rw.nl_333 un.ru.be_333  rm.eu.lv_543 mr.bh.ne_542 
  0x64115507, 0x211234a4, 0x32003802, 0x24003002,   // rw.ro.lg_432 ps.ur.fa_433  tk.bs.un_220 uz.eo.un_220 
  0x163830a0, 0x732d0d55, 0x02003019, 0x0500530c,   // uz.tk.hr_322 cs.sk.ny_442  uz.da.un_750 ht.fr.un_530 
  0x090d1c0d, 0x170715a4, 0x30005514, 0x22000508,   // mr.ne.hi_554 un.bg.sr_433  rw.uz.un_660 fr.oc.un_430 
  // [5040]
  0x17024d08, 0x18001005, 0x0a23110c, 0x48003104,   // aa.da.sr_443 lt.ga.un_330  ro.ky.mk_543 az.tt.un_320 
  0x213c3da4, 0x39004805, 0x28233b0c, 0x1b305512,   // ku.ug.fa_433 tt.br.un_330  ks.ky.sd_543 rw.uz.tr_654 
  0x23303caf, 0x32002902, 0x071023a9, 0x0a0708ee,   // ug.uz.ky_655 sl.bs.un_220  ky.be.bg_544 uk.bg.mk_422 
  0x3000440c, 0x232d10a4, 0x42231005, 0x1700081b,   // kk.uz.un_530 lt.sk.ca_433  lt.ca.co_333 uk.sr.un_770 
  // [5050]
  0x20002d05, 0x21002204, 0x25595508, 0x28007321,   // sk.sq.un_330 oc.jw.un_320  rw.rn.eu_443 ny.sw.un_860 
  0x0911240d, 0x59005505, 0x285c5204, 0x3b004708,   // eo.ro.pl_554 rw.rn.un_330  ha.sa.sw_332 sn.so.un_430 
  0x65005304, 0x765312ec, 0x18213d0c, 0x7600532b,   // ht.gv.un_320 hu.ht.crs_644  ku.fa.ar_543 ht.crs.un_980 
  0x153c3808, 0x1000220d, 0x22233e05, 0x283b2107,   // tk.ug.un_443 oc.lt.un_540  rm.ca.oc_333 fa.ks.sd_432 
  // [5060]
  0x0400200e, 0x1b53610d, 0x69537612, 0x38003002,   // sq.fi.un_550 za.ht.tr_554  crs.ht.mfe_654 uz.tk.un_220 
  0x3b006712, 0x15004902, 0x1f2d0d04, 0x04001019,   // ak.so.un_640 to.un.un_220  cs.sk.cy_332 be.ru.un_750 
  0x4f315ea9, 0x69765313, 0x67001221, 0x53004204,   // ts.az.bi_544 ht.crs.mfe_665  hu.ak.un_860 co.ht.un_320 
  0x1100301e, 0x421d260c, 0x32000d08, 0x48003719,   // uz.ro.un_830 ia.la.co_543  cs.bs.un_430 ba.tt.un_750 
  // [5070]
  0x78375f11, 0x61005314, 0x3b005221, 0x58524daf,   // tn.st.ve_653 ht.za.un_660  ha.so.un_860 aa.ha.om_655 
  0x44000808, 0x0a253607, 0x65005208, 0x53005202,   // uk.kk.un_430 ab.mn.mk_432  ha.gv.un_430 ha.ht.un_220 
  0x2a003921, 0x76695313, 0x76525308, 0x69531e12,   // dz.bo.un_860 ht.mfe.crs_665  ht.ha.crs_443 ms.ht.mfe_654 
  0x2f006504, 0x5c2c53a6, 0x09002302, 0x4f452d04,   // gv.su.un_320 ht.fy.sa_521  ca.pl.un_220 sk.ln.bi_332 
  // [5080]
  0x2300150c, 0x0a300707, 0x0a0408ee, 0x2cfc4004,   // un.ky.un_530 bg.uz.mk_432  uk.ru.mk_422 lb.zzp.fy_332 
  0x101125a7, 0x182812a0, 0x1f006514, 0x1824650c,   // mn.ro.be_532 ur.sd.ar_322  gv.cy.un_660 gv.eo.ga_543 
  0x1e001c23, 0x283d2107, 0x080215ec, 0x026510ee,   // id.ms.un_880 fa.ku.sd_432  un.da.no_644 lt.gv.da_422 
  0x090d5c0e, 0x06004202, 0x1800080c, 0x03000204,   // sa.ne.hi_555 co.de.un_220  no.ga.un_530 da.nl.un_320 
  // [5090]
  0x2300350d, 0x0a3738a0, 0x4f4d650d, 0x3f060309,   // tg.ky.un_540 tk.ba.mk_322  gv.aa.bi_554 nl.de.af_444 
  0x0e2e12ec, 0x3f2c03a0, 0x1c5c13a0, 0x2e002702,   // hu.fo.is_644 nl.fy.af_322  bh.sa.mr_322 gd.fo.un_220 
  0x62001a13, 0x53000d0e, 0x214d1e04, 0x0600fe07,   // tl.kha.un_650 cs.ht.un_550  ms.aa.jw_332 tlh.de.un_420 
  0x4d00200e, 0x0407080c, 0x38001b13, 0x3b001c08,   // sq.aa.un_550 uk.bg.ru_543  tr.tk.un_650 mr.ks.un_430 
  // [50a0]
  0x1c001b04, 0x1a2138a7, 0x281234a4, 0x18283404,   // tr.id.un_320 tk.jw.tl_532  ps.ur.sd_433 ps.sd.ar_332 
  0x092e0e0e, 0x3423280c, 0x18092e0e, 0x18005608,   // is.fo.pl_555 sd.ky.ps_543  fo.pl.ga_555 mg.ga.un_430 
  0x32001711, 0x62002113, 0x2e0e12ad, 0x123f03ee,   // sr.bs.un_630 jw.kha.un_650  hu.is.fo_643 nl.af.hu_422 
  0x32172da4, 0xfc5a3e12, 0x3c001112, 0x1548370d,   // sk.sr.bs_433 rm.sm.zzp_654  ro.ug.un_640 ba.tt.un_554 
  // [50b0]
  0x183b34a4, 0x170a0804, 0x29000e1a, 0x36151005,   // ps.ks.ar_433 uk.mk.sr_332  is.sl.un_760 be.ab.un_330 
  0x08374813, 0x342112ec, 0x21002208, 0x351744ee,   // tt.ba.uk_665 ur.fa.ps_644  oc.jw.un_430 kk.sr.tg_422 
  0x28183411, 0xfc001319, 0x090d5c09, 0x10001104,   // ps.ar.sd_653 et.zzp.un_750  sa.ne.hi_444 ro.be.un_320 
  0x213d34a7, 0x0c321607, 0x34233d0c, 0x23351704,   // ps.ku.fa_532 hr.bs.sv_432  ku.ky.ps_543 sr.tg.ky_332 
  // [50c0]
  0x2300480d, 0xfc180107, 0x18002723, 0x3800352b,   // tt.ky.un_540 en.ga.zzp_432  gd.ga.un_880 tg.tk.un_980 
  0x33082a0e, 0x160d58a0, 0x271801a4, 0x2c0602a0,   // mt.no.nn_555 om.cs.hr_322  en.ga.gd_433 da.de.fy_322 
  0x65271813, 0x21123d0c, 0x3c073505, 0x48003702,   // ga.gd.gv_665 ku.ur.fa_543  tg.bg.ug_333 ba.tt.un_220 
  0x01053e0b, 0x153b58ac, 0x3500070c, 0x303c3507,   // rm.fr.en_542 om.so.un_632  bg.tg.un_530 tg.ug.uz_432 
  // [50d0]
  0x1d4b01a0, 0x30003e05, 0x0c00120c, 0x07040aee,   // en.mi.la_322 rm.uz.un_330  hu.sv.un_530 mk.ru.bg_422 
  0x4e004613, 0x2300480e, 0x2a2030a0, 0x0a3510a4,   // qu.ay.un_650 tt.ky.un_550  uz.sq.mt_322 be.tg.mk_433 
  0x28002107, 0x34123b12, 0x35000709, 0x370448a4,   // fa.sd.un_420 ks.ur.ps_654  bg.tg.un_440 tt.ru.ba_433 
  0x091c1308, 0x0a17080c, 0x100715a4, 0x3c353012,   // bh.mr.hi_443 uk.sr.mk_543  un.bg.be_433 uz.tg.ug_654 
  // [50e0]
  0x08100aec, 0x35233c5a, 0x12005d05, 0x25041508,   // mk.be.uk_644 ug.ky.tg_553  ss.hu.un_330 un.ru.mn_443 
  0x34002313, 0x37003c08, 0x30153c12, 0x18211202,   // ky.ps.un_650 ug.ba.un_430  ug.uz.un_640 ur.fa.ar_222 
  0x3d233b07, 0x2800300c, 0x3000180d, 0x65000102,   // ks.ky.ku_432 uz.sd.un_530  ar.uz.un_540 en.gv.un_220 
  0x213d1209, 0x375f5e0d, 0x1c212fee, 0x1f2709ad,   // ur.ku.fa_444 ts.tn.st_554  su.jw.id_422 pl.gd.cy_643 
  // [50f0]
  0x3d2112ee, 0x08043c0c, 0x2d002f08, 0x650820a0,   // ur.fa.ku_422 ug.ru.uk_543  su.sk.un_430 sq.no.gv_322 
  0x55641fee, 0x0c0e20ad, 0x5c755fad, 0x04004304,   // cy.lg.rw_422 sq.is.sv_643  tn.nso.sa_643 ie.fi.un_320 
  0x78755faf, 0x2f1e1c08, 0x23200304, 0x64001d05,   // tn.nso.ve_655 id.ms.su_443  nl.sq.ca_332 la.lg.un_330 
  0x0a0835ee, 0x0e023707, 0x34005d35, 0x4b275007,   // tg.uk.mk_422 st.da.is_432  ss.xh.un_A90 fj.gd.mi_432 
  // [5100]
  0x2c000208, 0x211c1e0c, 0x363817af, 0x1e002f04,   // da.fy.un_430 ms.id.jw_543  sr.tk.ab_655 su.ms.un_320 
  0x50004d1b, 0x3f796bec, 0x0f001005, 0x35345d12,   // aa.fj.un_770 ceb.war.af_644  lt.lv.un_330 ss.xh.zu_654 
  0x78455e0c, 0x28001504, 0x5e00341a, 0x56245e0c,   // ts.ln.ve_543 un.sw.un_320  xh.ts.un_760 ts.eo.mg_543 
  0x48001b0c, 0x30003823, 0x64002008, 0x5d565e0c,   // tr.tt.un_530 tk.uz.un_880  sq.lg.un_430 ts.mg.ss_543 
  // [5110]
  0x353460a4, 0x10071507, 0x43002013, 0x28002004,   // vo.xh.zu_433 un.bg.be_432  sq.ie.un_650 sq.sw.un_320 
  0x75005f2b, 0x605c5604, 0x073c30af, 0x130c23a0,   // tn.nso.un_980 mg.sa.vo_332  uz.ug.bg_655 ca.sv.et_322 
  0x75375f0d, 0x04151705, 0x20002302, 0x34003704,   // tn.st.nso_554 sr.ru.un_330  ca.sq.un_220 st.xh.un_320 
  0x5f001e04, 0x1e001c07, 0x3400281a, 0x20001504,   // ms.tn.un_320 id.ms.un_420  sd.ps.un_760 un.sq.un_320 
  // [5120]
  0x5f7547a7, 0x15231704, 0x3f0302af, 0x09002d0e,   // sn.nso.tn_532 sr.ky.un_332  da.nl.af_655 sk.pl.un_550 
  0x23001005, 0x363810ec, 0xfc330805, 0x3800100c,   // lt.ca.un_330 lt.tk.gn_644  no.nn.zzp_333 lt.tk.un_530 
  0x271128a4, 0x65001f12, 0x093528a0, 0x040735a7,   // sw.ro.gd_433 cy.gv.un_640  sw.zu.pl_322 tg.bg.ru_532 
  0x38000d0c, 0x29000108, 0x17350a02, 0x02783713,   // cs.tk.un_530 en.sl.un_430  mk.tg.sr_222 st.ve.da_665 
  // [5130]
  0x104423a0, 0x2800780e, 0x44233baf, 0x19002302,   // ky.kk.be_322 ve.sw.un_550  ks.ky.kk_655 ca.gl.un_220 
  0x16292fa0, 0x39004707, 0x38001f09, 0x595564a4,   // su.sl.hr_322 sn.br.un_420  cy.tk.un_440 lg.rw.rn_433 
  0x7600690e, 0x38006308, 0x55006412, 0x0c2a2009,   // mfe.crs.un_550 sco.tk.un_430  lg.rw.un_640 sq.mt.sv_444 
  0x64353409, 0x10381f0e, 0x63003b0d, 0xfc005304,   // xh.zu.lg_444 cy.tk.lt_555  so.sco.un_540 ht.zzp.un_320 
  // [5140]
  0x38001005, 0x55596412, 0x380e2e04, 0x40006813,   // lt.tk.un_330 lg.rn.rw_654  fo.is.tk_332 ig.lb.un_650 
  0x10003e04, 0x17001502, 0x12002a13, 0x1f39640d,   // rm.lt.un_320 un.sr.un_220  mt.hu.un_650 lg.br.cy_554 
  0x65003b0c, 0x097912a9, 0x09001213, 0x5e2d0d05,   // so.gv.un_530 hu.war.pl_544  hu.pl.un_650 cs.sk.ts_333 
  0xfc001f02, 0x085f09a7, 0x38243002, 0x4700fc08,   // cy.zzp.un_220 pl.tn.no_532  uz.eo.tk_222 zzp.sn.un_430 
  // [5150]
  0x69fc01a0, 0x3b00380c, 0x7300370e, 0x2a556404,   // en.zzp.mfe_322 tk.so.un_530  st.ny.un_550 lg.rw.mt_332 
  0xfc080213, 0x342812af, 0x291738a6, 0x441015ec,   // da.no.zzp_665 ur.sd.ps_655  tk.sr.sl_521 un.be.kk_644 
  0x17040aaf, 0x040810a9, 0x0a004204, 0x13000d19,   // mk.ru.sr_655 be.uk.ru_544  co.pt.un_320 ne.bh.un_750 
  0x23003c11, 0x0a073709, 0xfc000211, 0x15fc1d0c,   // ug.ky.un_630 ba.bg.mk_444  da.zzp.un_630 la.zzp.un_543 
  // [5160]
  0x16002902, 0x06000504, 0x0d5c09a9, 0x2e0e02a0,   // sl.hr.un_220 fr.de.un_320  hi.sa.ne_544 da.is.fo_322 
  0x08103612, 0x36150404, 0x1600750c, 0x21181212,   // ab.be.uk_654 ru.ab.un_320  nso.hr.un_530 ur.ar.fa_654 
  0x1c0d5cec, 0x04070a05, 0x0a0817a4, 0x3430230d,   // sa.ne.mr_644 mk.bg.ru_333  sr.uk.mk_433 ky.uz.ps_554 
  0x23004414, 0x11000507, 0x0700110b, 0x00007537,   // kk.ky.un_660 fr.ro.un_420  ro.bg.un_520 nso.un.un_B00 
  // [5170]
  0x2e003102, 0x3c3630a4, 0x15001012, 0x13003f13,   // az.fo.un_220 uz.ab.ug_433  be.un.un_640 af.et.un_650 
  0x360a0709, 0x3400211a, 0x60001014, 0x3e10600c,   // bg.mk.ab_444 fa.ps.un_760  lt.vo.un_660 vo.lt.rm_543 
  0x0b0a19a0, 0x3458fc55, 0x11150705, 0x172d0d02,   // gl.pt.es_322 zzp.om.xh_442  bg.ro.un_330 cs.sk.sr_222 
  0x330835a0, 0x10603f12, 0x15450204, 0x4f0f60a7,   // zu.no.nn_322 af.vo.lt_654  da.ln.un_332 vo.lv.bi_532 
  // [5180]
  0x10006014, 0x0c480409, 0x01000504, 0x3c004812,   // vo.lt.un_660 fi.tt.sv_444  fr.en.un_320 tt.ug.un_640 
  0x25000407, 0x38353404, 0x50796aee, 0x37002322,   // fi.eu.un_420 xh.zu.tk_332  haw.war.fj_422 ky.ba.un_870 
  0x092d0d55, 0x10016012, 0x60001013, 0x1000600c,   // cs.sk.pl_442 vo.en.lt_654  lt.vo.un_650 vo.lt.un_530 
  0x0d5c1309, 0x10151704, 0x25000405, 0x3000481a,   // bh.sa.ne_444 sr.be.un_320  ru.mn.un_330 tt.uz.un_760 
  // [5190]
  0x2c006521, 0x0400250e, 0x080a04a0, 0x0b2a04ad,   // gv.fy.un_860 eu.fi.un_550  ru.mk.uk_322 fi.mt.es_643 
  0x122130a0, 0x0d001321, 0x4a0e36a4, 0x08001114,   // uz.fa.ur_322 bh.ne.un_860  gn.is.yo_433 ro.uk.un_660 
  0x3d18300d, 0x304435ad, 0x1000381a, 0x3000230c,   // uz.ar.ku_554 tg.kk.uz_643  tk.be.un_760 ky.uz.un_530 
  0x1000151a, 0x1b314ca4, 0x103048ec, 0x17350808,   // un.be.un_760 wo.az.tr_433  tt.uz.be_644 uk.tg.sr_443 
  // [51a0]
  0x0300fc04, 0x65630e0c, 0x12003011, 0x3c00482a,   // zzp.nl.un_320 is.sco.gv_543  uz.ur.un_630 tt.ug.un_970 
  0x341221af, 0x1c0913a9, 0x1723350b, 0x08040a04,   // fa.ur.ps_655 bh.hi.mr_544  tg.ky.sr_542 mk.ru.uk_332 
  0x5a256407, 0x64595514, 0x2e53fea9, 0x3b00fe12,   // lg.eu.sm_432 rw.rn.lg_666  tlh.ht.fo_544 tlh.so.un_640 
  0x5f6438a4, 0x30001812, 0x3400120c, 0x0448370c,   // tk.lg.tn_433 ar.uz.un_640  ur.ps.un_530 ba.tt.ru_543 
  // [51b0]
  0x5d003513, 0x311b110c, 0x20595509, 0x59733408,   // zu.ss.un_650 ro.tr.az_543  rw.rn.sq_444 xh.ny.rn_443 
  0x12381b08, 0x73006407, 0x071735a4, 0x381b3160,   // tr.tk.hu_443 lg.ny.un_420  tg.sr.bg_433 az.tr.tk_664 
  0x5d2e0ea7, 0x73003505, 0x29595504, 0x38001b0d,   // is.fo.ss_532 zu.ny.un_330  rw.rn.sl_332 tr.tk.un_540 
  0x10003804, 0x341255a0, 0x4b320402, 0x21003104,   // tk.lt.un_320 rw.hu.xh_322  fi.bs.mi_222 az.jw.un_320 
  // [51c0]
  0x1e211cee, 0x083f0ca6, 0x2e000304, 0x5d007305,   // id.jw.ms_422 sv.af.no_521  nl.fo.un_320 ny.ss.un_330 
  0x76756909, 0x1d005504, 0x322d0d0c, 0x5c2e73ee,   // mfe.nso.crs_444 rw.la.un_320  cs.sk.bs_543 ny.fo.sa_422 
  0x38311ba4, 0x302821ec, 0x12003002, 0x21022fad,   // tr.az.tk_433 fa.sd.uz_644  uz.hu.un_220 su.da.jw_643 
  0x29595508, 0x23002505, 0x5600490c, 0x063f0308,   // rw.rn.sl_443 mn.ky.un_330  to.mg.un_530 nl.af.de_443 
  // [51d0]
  0x53006907, 0x28004404, 0x475d34ee, 0x650602a7,   // mfe.ht.un_420 kk.sd.un_320  xh.ss.sn_422 da.de.gv_532 
  0x23003c20, 0x600c06a4, 0x28303405, 0x3f375f04,   // ug.ky.un_850 de.sv.vo_433  ps.uz.sd_333 tn.st.af_332 
  0x400665a0, 0x75375f09, 0x36022805, 0x351b1da0,   // gv.de.lb_322 tn.st.nso_444  sw.da.gn_333 la.tr.zu_322 
  0x0c080209, 0x3735340b, 0x02063f07, 0x58007305,   // da.no.sv_444 xh.zu.st_542  af.de.da_432 ny.om.un_330 
  // [51e0]
  0x33392f04, 0x2d0d50ee, 0x00006b15, 0x533922a0,   // su.br.nn_332 fj.cs.sk_422  ceb.un.un_700 oc.br.ht_322 
  0x17070408, 0x066b1dee, 0x13001b02, 0xfc1b1fa7,   // ru.bg.sr_443 la.ceb.de_422  tr.et.un_220 cy.tr.zzp_532 
  0x170a1508, 0x08353404, 0x632c03af, 0x135c0d60,   // un.mk.sr_443 xh.zu.no_332  nl.fy.sco_655 ne.sa.bh_664 
  0x33791aa9, 0x371f750c, 0x1f65fcee, 0x050115a0,   // tl.war.nn_544 nso.cy.st_543  zzp.gv.cy_422 un.en.fr_322 
  // [51f0]
  0x3202020c, 0x0c650604, 0x0704155a, 0x096bfea0,   // da.da.bs_543 de.gv.sv_332  un.ru.bg_553 tlh.ceb.pl_322 
  0x381b0f07, 0x1b001f14, 0x25043ca4, 0x1b000204,   // lv.tr.tk_432 cy.tr.un_660  ug.ru.mn_433 da.tr.un_320 
  0x0430370c, 0x3ffc1e07, 0x01000b02, 0x3f0306af,   // ba.uz.ru_543 ms.zzp.af_432  es.en.un_220 de.nl.af_655 
  0x345e3507, 0x0e321702, 0x08071712, 0x0a044804,   // zu.ts.xh_432 sr.bs.is_222  sr.bg.uk_654 tt.ru.mk_332 
  // [5200]
  0x05791207, 0x10130f0c, 0x3300020d, 0x382348ad,   // hu.war.fr_432 lv.et.lt_543  da.nn.un_540 tt.ky.tk_643 
  0x1e001207, 0x0a071713, 0x430e3fad, 0x12001805,   // hu.ms.un_420 sr.bg.mk_665  af.is.ie_643 ar.ur.un_330 
  0xfe420511, 0x797601a0, 0x2a604d0c, 0x363744a9,   // fr.co.tlh_653 en.crs.war_322  aa.vo.mt_543 kk.ba.ab_544 
  0x35004802, 0x08044405, 0x062c2504, 0x30122104,   // tt.tg.un_220 kk.ru.uk_333  eu.fy.de_332 fa.ur.uz_332 
  // [5210]
  0x0c00080e, 0x07000a07, 0x383035af, 0x084835a7,   // no.sv.un_550 mk.bg.un_420  tg.uz.tk_655 tg.tt.uk_532 
  0x34211812, 0x37381555, 0x18002e08, 0x44483002,   // ar.fa.ps_654 un.tk.ba_442  fo.ga.un_430 uz.tt.kk_222 
  0x181221ec, 0x1c090d04, 0x0d005c02, 0x44000a07,   // fa.ur.ar_644 ne.hi.mr_332  sa.ne.un_220 mk.kk.un_420 
  0x10384813, 0x23004204, 0x282112ec, 0x3d30210d,   // tt.tk.be_665 co.ca.un_320  ur.fa.sd_644 fa.uz.ku_554 
  // [5220]
  0x2800121a, 0x0a00231a, 0x5d241ea0, 0x10150855,   // ur.sd.un_760 ky.mk.un_760  ms.eo.ss_322 uk.be.un_420 
  0x483c3709, 0x10002519, 0x34123da0, 0x15002322,   // ba.ug.tt_444 mn.be.un_750  ku.ur.ps_322 ky.un.un_870 
  0x44374813, 0x25002318, 0x3d2318a9, 0x25190b05,   // tt.ba.kk_665 ky.mn.un_740  ar.ky.ku_544 es.gl.eu_333 
  0x383530a4, 0x3f001f05, 0x253715a0, 0x39002004,   // uz.tg.tk_433 cy.af.un_330  un.ba.mn_322 sq.br.un_320 
  // [5230]
  0x2134180c, 0x303635ee, 0x08000a05, 0x28213dec,   // ar.ps.fa_543 tg.ab.uz_422  mk.uk.un_330 ku.fa.sd_644 
  0x37482514, 0x39190b02, 0x3400730c, 0x360823a4,   // mn.tt.ba_666 es.gl.br_222  ny.xh.un_530 ky.uk.ab_433 
  0x040810ad, 0x3e067904, 0x070a11ec, 0x643509a7,   // be.uk.ru_643 war.de.rm_332  ro.mk.bg_644 pl.zu.lg_532 
  0x6a0901a0, 0xfc47095a, 0x2c2565ee, 0x4828470b,   // en.pl.haw_322 pl.sn.zzp_553  gv.eu.fy_422 sn.sw.tt_542 
  // [5240]
  0x4b6a09ad, 0x303e3ba0, 0x09003509, 0x0c33080d,   // pl.haw.mi_643 so.rm.uz_322  zu.pl.un_440 no.nn.sv_554 
  0x1b002a04, 0x09fc35af, 0x5200090c, 0x48001b2b,   // mt.tr.un_320 zu.zzp.pl_655  pl.ha.un_530 tr.tt.un_980 
  0x3efe1fa0, 0x3509640c, 0x19360ba4, 0x39002708,   // cy.tlh.rm_322 lg.pl.zu_543  es.gn.gl_433 gd.br.un_430 
  0x42003902, 0x081504a4, 0x1f003908, 0x0f003008,   // br.co.un_220 ru.uk.un_430  br.cy.un_430 uz.lv.un_430 
  // [5250]
  0x284709ec, 0x355228ec, 0x1004070c, 0x0b4665ee,   // pl.sn.sw_644 sw.ha.zu_644  bg.ru.be_543 gv.qu.es_422 
  0x0900fc23, 0x460b5a07, 0x07003e19, 0xfc000923,   // zzp.pl.un_880 sm.es.qu_432  rm.it.un_750 pl.zzp.un_880 
  0x35253611, 0x53136907, 0x5f2809a4, 0x443c2360,   // ab.mn.tg_653 mfe.et.ht_432  pl.sw.tn_433 ky.ug.kk_664 
  0x3f4c0907, 0x0e33085a, 0x21002f07, 0x48000a08,   // pl.wo.af_432 no.nn.is_553  su.jw.un_420 mk.tt.un_430 
  // [5260]
  0x0a002512, 0x04374404, 0x18341204, 0x28122113,   // mn.mk.un_640 kk.ba.ru_332  ur.ps.ar_332 fa.ur.sd_665 
  0x36150713, 0x040a08a0, 0x0e00020c, 0x0a17350c,   // bg.ab.un_650 uk.mk.ru_322  da.is.un_530 tg.sr.mk_543 
  0x5100020c, 0x6e6b7912, 0x1700350c, 0x3b00650c,   // da.kl.un_530 war.ceb.hmn_654  tg.sr.un_530 gv.so.un_530 
  0x0140630c, 0x1f00400e, 0x631301af, 0x58133b04,   // sco.lb.en_543 lb.cy.un_550  en.et.sco_655 so.et.om_332 
  // [5270]
  0x405e1fa0, 0x0a11070e, 0x58003b19, 0x5f133baf,   // cy.ts.lb_322 bg.ro.mk_555  so.om.un_750 so.et.tn_655 
  0x3b654d0b, 0x5300570d, 0xfc4a3bad, 0x630301a0,   // aa.gv.so_542 na.ht.un_540  so.yo.zzp_643 en.nl.sco_322 
  0x1f616712, 0x114835a9, 0x066301a7, 0x40633b12,   // ak.za.cy_654 tg.tt.ro_544  en.sco.de_532 so.sco.lb_654 
  0x3bfc01a4, 0x12343da0, 0x353439a0, 0x10111560,   // en.zzp.so_433 ku.ps.ur_322  br.xh.zu_322 un.ro.be_664 
  // [5280]
  0x2f002705, 0x53007634, 0x03002c05, 0x58003b11,   // gd.su.un_330 crs.ht.un_A80  fy.nl.un_330 so.om.un_630 
  0x4c003b0e, 0x2800120c, 0x65005f04, 0x2c004019,   // so.wo.un_550 ur.sd.un_530  tn.gv.un_320 lb.fy.un_750 
  0x3f3b1355, 0x23003405, 0x602c030c, 0x25001902,   // et.so.af_442 ps.ky.un_330  nl.fy.vo_543 gl.eu.un_220 
  0x58004d08, 0x645b1508, 0x213430a9, 0xfc6313ad,   // aa.om.un_430 un.sg.lg_443  uz.ps.fa_544 et.sco.zzp_643 
  // [5290]
  0x3700380b, 0x392d0d04, 0x35341ba9, 0x430316a7,   // tk.ba.un_520 cs.sk.br_332  tr.xh.zu_544 hr.nl.ie_532 
  0x2d0d2a02, 0x3d123408, 0x3c3530a9, 0x343d12a0,   // mt.cs.sk_222 ps.ur.ku_443  uz.tg.ug_544 ur.ku.ps_322 
  0x1834285a, 0x253e01a0, 0x103e600e, 0x04003b13,   // sd.ps.ar_553 en.rm.eu_322  vo.rm.lt_555 so.fi.un_650 
  0x23102214, 0x40000508, 0x07000a23, 0x182e0e60,   // oc.lt.ca_666 fr.lb.un_430  mk.bg.un_880 is.fo.ga_664 
  // [52a0]
  0x40006914, 0x5d12180d, 0x0d182d07, 0x102322a4,   // mfe.lb.un_660 ga.hu.ss_554  sk.ga.cs_432 oc.ca.lt_433 
  0x21121811, 0x5d001812, 0x18001e02, 0x200d59ee,   // ar.ur.fa_653 ga.ss.un_640  ms.ga.un_220 rn.cs.sq_422 
  0x353425ad, 0xfe53010c, 0x47003819, 0x0a0737ad,   // eu.xh.zu_643 en.ht.tlh_543  tk.sn.un_750 ba.bg.mk_643 
  0x4c00fe08, 0x095f7313, 0x28007307, 0x651f3b0c,   // tlh.wo.un_430 ny.tn.pl_665  ny.sw.un_420 so.cy.gv_543 
  // [52b0]
  0x115969a4, 0x34785e08, 0x09005e1b, 0x23003e12,   // mfe.rn.ro_433 ts.ve.xh_443  ts.pl.un_770 rm.ca.un_640 
  0x3d343b0b, 0x18213b55, 0x223e2360, 0x4a5f73ad,   // ks.ps.ku_542 ks.fa.ar_442  ca.rm.oc_664 ny.tn.yo_643 
  0x271f3ba4, 0x626310a4, 0x3b636508, 0x1f003b08,   // so.cy.gd_433 lt.sco.kha_433  gv.sco.so_443 so.cy.un_430 
  0x1f3b2a07, 0x2d0d18ec, 0x1c13090d, 0x52006404,   // mt.so.cy_432 ga.cs.sk_644  hi.bh.mr_554 lg.ha.un_320 
  // [52c0]
  0x4800360c, 0x5c005604, 0x114c58ee, 0x21523804,   // ab.tt.un_530 mg.sa.un_320  om.wo.ro_422 tk.ha.jw_332 
  0x44000807, 0x2a6162af, 0x38374814, 0x6b6579a9,   // uk.kk.un_420 kha.za.mt_655  tt.ba.tk_666 war.gv.ceb_544 
  0x18004405, 0x3d3c210d, 0x0823105a, 0x21123004,   // kk.ar.un_330 fa.ug.ku_554  be.ky.uk_553 uz.ur.fa_332 
  0x61003f0e, 0x3500370c, 0x21002f14, 0x216b2fee,   // af.za.un_550 ba.tg.un_530  su.jw.un_660 su.ceb.jw_422 
  // [52d0]
  0x482311a0, 0x17000a0b, 0x093b0d55, 0x0a371708,   // ro.ky.tt_322 mk.sr.un_520  ne.ks.hi_442 sr.ba.mk_443 
  0x1228210c, 0x3f003202, 0x321606a9, 0x27006512,   // fa.sd.ur_543 bs.af.un_220  de.hr.bs_544 gv.gd.un_640 
  0x040817a9, 0x44003613, 0x2f4c0507, 0x08001107,   // sr.uk.ru_544 ab.kk.un_650  fr.wo.su_432 ro.uk.un_420 
  0x23004c12, 0x0e002d0c, 0x30443812, 0x5e5dfa0c,   // wo.ca.un_640 sk.is.un_530  tk.kk.uz_654 nr.ss.ts_543 
  // [52e0]
  0x100a2502, 0x2e004a04, 0x30153508, 0x1235345a,   // mn.mk.be_222 yo.fo.un_320  tg.uz.un_430 xh.zu.hu_553 
  0x1c000a02, 0x40001905, 0x34355dad, 0x366302a0,   // pt.id.un_220 gl.lb.un_330  ss.zu.xh_643 da.sco.gn_322 
  0x5d5e3504, 0x2100400d, 0x153c3508, 0x190b2f02,   // zu.ts.ss_332 lb.jw.un_540  tg.ug.un_443 su.es.gl_222 
  0x2f003804, 0x12007307, 0x17152504, 0x5f0c5da0,   // tk.su.un_320 ny.hu.un_420  mn.sr.un_320 ss.sv.tn_322 
  // [52f0]
  0x08001112, 0x10071704, 0x13091cec, 0x34733511,   // ro.uk.un_640 sr.bg.be_332  mr.hi.bh_644 zu.ny.xh_653 
  0x3500730c, 0x10041507, 0x5f3412ad, 0x153530a4,   // ny.zu.un_530 un.ru.be_432  hu.xh.tn_643 uz.tg.un_433 
  0x37001204, 0x5d35120d, 0x631f57ee, 0x35001518,   // hu.st.un_320 hu.zu.ss_554  na.cy.sco_422 un.tg.un_740 
  0x190b570c, 0x33002e08, 0x40003e0e, 0x0a3538a7,   // na.es.gl_543 fo.nn.un_430  rm.lb.un_550 tk.tg.mk_532 
  // [5300]
  0x381312ee, 0x30734ea4, 0x293016a0, 0x36335804,   // hu.et.tk_422 ay.ny.uz_433  hr.uz.sl_322 om.nn.gn_332 
  0x3e23430c, 0x51006208, 0x63381ba0, 0x6b271d07,   // ie.ca.rm_543 kha.kl.un_430  tr.tk.sco_322 la.gd.ceb_432 
  0x1d002e0e, 0x023909ee, 0x2e3f0eec, 0x52004d14,   // fo.la.un_550 pl.br.da_422  is.af.fo_644 aa.ha.un_660 
  0x303538a9, 0x28001822, 0x095c1c04, 0x3900250d,   // tk.tg.uz_544 ga.sw.un_870  mr.sa.hi_332 eu.br.un_540 
  // [5310]
  0x30003b09, 0x2100301a, 0x21281255, 0x35303c60,   // so.uz.un_440 uz.fa.un_760  ur.sd.fa_442 ug.uz.tg_664 
  0x45051b08, 0x4c7669a4, 0x1000380e, 0x0e2e15a0,   // tr.fr.ln_443 mfe.crs.wo_433  tk.be.un_550 un.fo.is_322 
  0x28000208, 0x05003329, 0x48233612, 0x4c400608,   // da.sw.un_430 nn.fr.un_960  ab.ky.tt_654 de.lb.wo_443 
  0x3f006304, 0x040710a0, 0x4d106e08, 0x0a004809,   // sco.af.un_320 be.bg.ru_322  hmn.lt.aa_443 tt.mk.un_440 
  // [5320]
  0x27002804, 0x04000820, 0x0804110c, 0x63001f0d,   // sw.gd.un_320 uk.ru.un_850  ro.ru.uk_543 cy.sco.un_540 
  0x0725280c, 0x0d1c090b, 0x65183404, 0x2d005d05,   // sw.eu.it_543 hi.mr.ne_542  xh.ga.gv_332 ss.sk.un_330 
  0x10250705, 0x282568af, 0x2e0e020c, 0x130d1c05,   // bg.mn.be_333 ig.eu.sw_655  da.is.fo_543 mr.ne.bh_333 
  0x061dfc11, 0x48007307, 0x1f001213, 0x22003e0d,   // zzp.la.de_653 ny.tt.un_420  hu.cy.un_650 rm.oc.un_540 
  // [5330]
  0x40090607, 0x0a251707, 0x0a0407ee, 0x5f6343a0,   // de.pl.lb_432 sr.mn.mk_432  bg.ru.mk_422 ie.sco.tn_322 
  0x5f00fc08, 0x3b03fcee, 0x0a071707, 0xfc000108,   // zzp.tn.un_430 zzp.nl.so_422  sr.bg.mk_432 en.zzp.un_430 
  0x0369fc07, 0x2e1f3907, 0x12004702, 0x0d2d12a9,   // zzp.mfe.nl_432 br.cy.fo_432  sn.hu.un_220 hu.sk.cs_544 
  0x44232507, 0x0d0e2e0b, 0x1b2a040c, 0x08170702,   // mn.ky.kk_432 fo.is.cs_542  fi.mt.tr_543 bg.sr.uk_222 
  // [5340]
  0x48002907, 0x12182111, 0x25004e21, 0x1b6976af,   // sl.tt.un_420 fa.ar.ur_653  ay.eu.un_860 crs.mfe.tr_655 
  0x12213ca0, 0x13091caf, 0x070a3812, 0x13005c0c,   // ug.fa.ur_322 mr.hi.bh_655  tk.mk.bg_654 sa.bh.un_530 
  0x07170402, 0x34303caf, 0x524659a4, 0x212f4c07,   // ru.sr.bg_222 ug.uz.ps_655  rn.qu.ha_433 wo.su.jw_432 
  0x101548ad, 0x0f000a08, 0x13000923, 0x43242511,   // tt.be.un_630 pt.lv.un_430  hi.bh.un_880 eu.eo.ie_653 
  // [5350]
  0x3d00212a, 0x4c2f4212, 0x2c1139a0, 0x12001a07,   // fa.ku.un_970 co.su.wo_654  br.ro.fy_322 tl.hu.un_420 
  0x07113612, 0x12213d0b, 0x2c373907, 0x2c25190d,   // ab.ro.bg_654 ku.fa.ur_542  br.st.fy_432 gl.eu.fy_554 
  0x3c00111a, 0x73495aa9, 0x250735a0, 0x0a364607,   // ro.ug.un_760 sm.to.ny_544  tg.bg.mn_322 qu.gn.pt_432 
  0x40133614, 0x6a3749a9, 0x353478a9, 0x3c004813,   // gn.et.lb_666 to.st.haw_544  ve.xh.zu_544 tt.ug.un_650 
  // [5360]
  0x1c0d090b, 0x00001337, 0x3900560d, 0x02003f05,   // hi.ne.mr_542 bh.un.un_B00  mg.br.un_540 af.da.un_330 
  0x38006514, 0x356450a9, 0x0a38360c, 0x325a6408,   // gv.tk.un_660 fj.lg.zu_544  ab.tk.mk_543 lg.sm.bs_443 
  0x122818ee, 0x400c0605, 0x5035340e, 0x0600402c,   // ar.sd.ur_422 de.sv.lb_333  xh.zu.fj_555 lb.de.un_990 
  0x11282511, 0x2f211c0b, 0x362560ee, 0x03062c12,   // eu.sw.ro_653 id.jw.su_542  vo.eu.gn_422 fy.de.nl_654 
  // [5370]
  0x570640ad, 0x0c1b080c, 0x2523440c, 0x1c130d07,   // lb.de.na_643 no.tr.sv_543  kk.ky.mn_543 ne.bh.mr_432 
  0x030c2013, 0x47006807, 0x40031109, 0x15230204,   // sq.sv.nl_665 ig.sn.un_420  ro.nl.lb_444 da.ca.un_332 
  0x04002307, 0x020608a4, 0x4002060c, 0x6700370e,   // ky.ru.un_420 no.de.da_433  de.da.lb_543 st.ak.un_550 
  0x17070404, 0x062c57a4, 0x2300060c, 0x12211855,   // ru.bg.sr_332 na.fy.de_433  de.ca.un_530 ar.fa.ur_442 
  // [5380]
  0x12000604, 0x3f004d05, 0x06400cec, 0x0f022507,   // de.hu.un_320 aa.af.un_330  sv.lb.de_644 eu.da.lv_432 
  0x46785e05, 0x4f036208, 0x5e501a0c, 0x5e781aa4,   // ts.ve.qu_333 kha.nl.bi_443  tl.fj.ts_543 tl.ve.ts_433 
  0x285e090c, 0x1c3f02a7, 0x03020cee, 0x1f000e05,   // pl.ts.sw_543 da.af.id_532  sv.da.nl_422 is.cy.un_330 
  0x6300fc12, 0x096402a4, 0xfc5f6407, 0x1b314812,   // zzp.sco.un_640 da.lg.pl_433  lg.tn.zzp_432 tt.az.tr_654 
  // [5390]
  0x212f3504, 0x043c2507, 0x100a0807, 0x37003814,   // zu.su.jw_332 mn.ug.ru_432  uk.mk.be_432 tk.ba.un_660 
  0x346473ee, 0x38003005, 0x3b355ea7, 0x31381ba4,   // ny.lg.xh_422 uz.tk.un_330  ts.zu.so_532 tr.tk.az_433 
  0x3f392404, 0x092146a0, 0xfc001a08, 0x465e4f0d,   // eo.br.af_332 qu.jw.pl_322  tl.zzp.un_430 bi.ts.qu_554 
  0x4e5e5f0c, 0x5c1c13a7, 0x234438ad, 0xfc004609,   // tn.ts.ay_543 bh.mr.sa_532  tk.kk.ky_643 qu.zzp.un_440 
  // [53a0]
  0x15170a09, 0x1b0f1012, 0x28122104, 0x3b004909,   // mk.sr.un_444 lt.lv.tr_654  fa.ur.sd_332 to.so.un_440 
  0x6500681a, 0x5c091c05, 0x07110408, 0x20381f12,   // ig.gv.un_760 mr.hi.sa_333  ru.ro.bg_443 cy.tk.sq_654 
  0x443848a9, 0x422c010c, 0x184423af, 0x0a00110c,   // tt.tk.kk_544 en.fy.co_543  ky.kk.ar_655 ro.mk.un_530 
  0x17100402, 0x0d001209, 0x21006307, 0x2344350c,   // ru.be.sr_222 hu.cs.un_440  sco.jw.un_420 tg.kk.ky_543 
  // [53b0]
  0x03630107, 0xfe001e08, 0x3d00120c, 0x0e1f2c02,   // en.sco.nl_432 ms.tlh.un_430  ur.ku.un_530 fy.cy.is_222 
  0x3f005d02, 0x13001b09, 0x30003d0d, 0x5c001c1a,   // ss.af.un_220 tr.et.un_440  ku.uz.un_540 mr.sa.un_760 
  0x0c2e0ea9, 0x3f003802, 0x2d007909, 0xfc033f09,   // is.fo.sv_544 tk.af.un_220  war.sk.un_440 af.nl.zzp_444 
  0x06403f09, 0x2d290d08, 0x30342112, 0x033f3808,   // af.lb.de_444 cs.sl.sk_443  fa.ps.uz_654 tk.af.nl_443 
  // [53c0]
  0xfc1f650c, 0x06401f05, 0x28001b02, 0x5c001c1b,   // gv.cy.zzp_543 cy.lb.de_333  tr.sw.un_220 mr.sa.un_770 
  0x49205aa4, 0x3e2c65a4, 0x6327010c, 0x091c5c12,   // sm.sq.to_433 gv.fy.rm_433  en.gd.sco_543 sa.mr.hi_654 
  0x39182712, 0xfc6501a4, 0x63652ca4, 0x071715af,   // gd.ga.br_654 en.gv.zzp_433  fy.gv.sco_433 un.sr.bg_655 
  0x18652708, 0x15374805, 0x25001b02, 0x2c1865a4,   // gd.gv.ga_443 tt.ba.un_333  tr.eu.un_220 gv.ga.fy_433 
  // [53d0]
  0x186301ec, 0x070a080c, 0x171023a0, 0x5a3502a0,   // en.sco.ga_644 uk.mk.bg_543  ky.be.sr_322 da.zu.sm_322 
  0x381b0c04, 0x1e1c2f02, 0x4700680e, 0x1221300b,   // sv.tr.tk_332 su.id.ms_222  ig.sn.un_550 uz.fa.ur_542 
  0x57692905, 0x08100707, 0x11004a23, 0x13000d21,   // sl.mfe.na_333 bg.be.uk_432  yo.ro.un_880 ne.bh.un_860 
  0x6753620c, 0x2800520c, 0x50401f05, 0x64001c04,   // kha.ht.ak_543 ha.sw.un_530  cy.lb.fj_333 id.lg.un_320 
  // [53e0]
  0x0a154804, 0x764f01ee, 0x1221300c, 0x3e005c04,   // tt.mk.un_320 en.bi.crs_422  uz.fa.ur_543 sa.rm.un_320 
  0x37233507, 0x3b003302, 0x30383512, 0x212f2007,   // tg.ky.ba_432 nn.so.un_220  tg.tk.uz_654 sq.su.jw_432 
  0x48080404, 0x07040aa4, 0x62630104, 0x43242da9,   // ru.uk.tt_332 mk.ru.bg_433  en.sco.kha_332 sk.eo.ie_544 
  0x1f241c02, 0x00007837, 0x040a30a4, 0x070408a4,   // id.eo.cy_222 ve.un.un_B00  uz.mk.ru_433 uk.ru.bg_433 
  // [53f0]
  0x3c4423a9, 0x15071508, 0x25043504, 0x34213012,   // ky.kk.ug_544 un.bg.un_443  tg.ru.mn_332 uz.fa.ps_654 
  0x47005502, 0x2d0d2907, 0xfc59470c, 0x59555705,   // rw.sn.un_220 sl.cs.sk_432  sn.rn.zzp_543 na.rw.rn_333 
  0x10073607, 0xfc000305, 0x556447a7, 0x16001707,   // ab.bg.be_432 nl.zzp.un_330  sn.lg.rw_532 sr.hr.un_420 
  0x22002507, 0x50001107, 0x11070a0c, 0x35345d09,   // eu.oc.un_420 ro.fj.un_420  mk.bg.ro_543 ss.xh.zu_444 
  
  // [5400]
  0x230225ec, 0x18213411, 0x1500042b, 0x1a3f5d12,   // eu.da.ca_644 ps.fa.ar_653  ru.un.un_980 ss.af.tl_654 
  0x0e103f07, 0x64732809, 0x353454a4, 0x2f250212,   // af.lt.is_432 sw.ny.lg_444  ik.xh.zu_433 da.eu.su_654 
  0x6b463008, 0x4837380c, 0x46121055, 0x7800540d,   // uz.qu.ceb_443 tk.ba.tt_543  lt.hu.qu_442 ik.ve.un_540 
  0x463830a4, 0x5700250e, 0x1a15310c, 0x34005f02,   // uz.tk.qu_433 eu.na.un_550  az.tl.un_530 tn.xh.un_220 
  // [5410]
  0x190b2309, 0x3000360c, 0x7300340d, 0x59285512,   // ca.es.gl_444 ab.uz.un_530  xh.ny.un_540 rw.sw.rn_654 
  0x0e1a2ead, 0x2b1e10ee, 0x28007313, 0x2a345e55,   // fo.tl.is_643 lt.ms.vi_422  ny.sw.un_650 ts.xh.mt_442 
  0x32fe79ee, 0x5400350e, 0x383bfc07, 0x12001008,   // war.tlh.bs_422 zu.ik.un_550  zzp.so.tk_432 lt.hu.un_430 
  0x5d353412, 0x25280208, 0x12342804, 0x73353409,   // xh.zu.ss_654 da.sw.eu_443  sd.ps.ur_332 xh.zu.ny_444 
  // [5420]
  0x335c54ad, 0x57002509, 0x34005e0d, 0x11005a02,   // ik.sa.nn_643 eu.na.un_440  ts.xh.un_540 sm.ro.un_220 
  0x17001014, 0x5e545d0d, 0x25006113, 0x11004b04,   // be.sr.un_660 ss.ik.ts_554  za.eu.un_650 mi.ro.un_320 
  0x5f38fcec, 0x23005712, 0x5c5f5e08, 0x34355d12,   // zzp.tk.tn_644 na.ca.un_640  ts.tn.sa_443 ss.zu.xh_654 
  0x64353404, 0x4600690e, 0x38463007, 0x31790212,   // xh.zu.lg_332 mfe.qu.un_550  uz.qu.tk_432 da.war.az_654 
  // [5430]
  0x303846ee, 0x30004604, 0x15460205, 0x3f5f5ea0,   // qu.tk.uz_422 qu.uz.un_320  da.qu.un_333 ts.tn.af_322 
  0x08071507, 0x3b00460c, 0x0a101705, 0x504f0109,   // un.bg.uk_432 qu.so.un_530  sr.be.mk_333 en.bi.fj_444 
  0x5f655ea4, 0x213430a0, 0x36040aa4, 0x0d1c5c11,   // ts.gv.tn_433 uz.ps.fa_322  mk.ru.ab_433 sa.mr.ne_653 
  0x3c182304, 0x6500380d, 0x38006513, 0x02003913,   // ky.ar.ug_332 tk.gv.un_540  gv.tk.un_650 br.da.un_650 
  // [5440]
  0x39002505, 0x2304105a, 0x08073c04, 0x10003812,   // eu.br.un_330 be.ru.ky_553  ug.bg.uk_332 tk.lt.un_640 
  0x091c5ca9, 0x672846ec, 0x4b525008, 0x2f211c12,   // sa.mr.hi_544 qu.sw.ak_644  fj.ha.mi_443 id.jw.su_654 
  0x2100450d, 0x6a505e13, 0x461a5213, 0x30004608,   // ln.jw.un_540 ts.fj.haw_665  ha.tl.qu_665 qu.uz.un_430 
  0x15173704, 0x34523bee, 0x212862af, 0x290d2da9,   // ba.sr.un_332 so.ha.xh_422  kha.sw.jw_655 sk.cs.sl_544 
  // [5450]
  0x21681aad, 0x160d2955, 0x65003814, 0x645052ec,   // tl.ig.jw_643 sl.cs.hr_442  tk.gv.un_660 ha.fj.lg_644 
  0x0259250d, 0x213d3409, 0x39002508, 0x12003022,   // eu.rn.da_554 ps.ku.fa_444  eu.br.un_430 uz.ur.un_870 
  0x4b005035, 0x0252280b, 0x656b7904, 0xfc003502,   // fj.mi.un_A90 sw.ha.da_542  war.ceb.gv_332 zu.zzp.un_220 
  0x504e460c, 0x07003708, 0x1a46505a, 0x25003605,   // qu.ay.fj_543 ba.bg.un_430  fj.qu.tl_553 ab.mn.un_330 
  // [5460]
  0x3d002836, 0x63002b0d, 0x390c20ee, 0x5f5dfc05,   // sd.ku.un_AA0 vi.sco.un_540  sq.sv.br_422 zzp.ss.tn_333 
  0x0c006907, 0x30374409, 0x482b3005, 0x254002a0,   // mfe.sv.un_420 kk.ba.uz_444  uz.vi.tt_333 da.lb.eu_322 
  0x151510a4, 0x1e283bee, 0x040830a0, 0x635706ad,   // be.un.un_430 so.sw.ms_422  uz.uk.ru_322 de.na.sco_643 
  0x767901a0, 0x2500020e, 0x3f0263a7, 0x03064012,   // en.war.crs_322 da.eu.un_550  sco.da.af_532 lb.de.nl_654 
  // [5470]
  0x321729ad, 0x0946fc0c, 0xfe0c6908, 0x25003313,   // sl.sr.bs_643 zzp.qu.pl_543  mfe.sv.tlh_443 nn.eu.un_650 
  0x1015070d, 0x03400604, 0x17004807, 0x081004a9,   // bg.be.un_540 de.lb.nl_332  tt.sr.un_420 ru.be.uk_544 
  0x030c3f0c, 0xfc5f3704, 0xfc35345a, 0x12002007,   // af.sv.nl_543 st.tn.zzp_332  xh.zu.zzp_553 sq.hu.un_420 
  0x4437480c, 0x0d1c090c, 0x25001f04, 0xfc345e08,   // tt.ba.kk_543 hi.mr.ne_543  cy.eu.un_320 ts.xh.zzp_443 
  // [5480]
  0x1b257604, 0x481737a9, 0x3735345a, 0x402c03a6,   // crs.eu.tr_332 ba.sr.tt_544  xh.zu.st_553 nl.fy.lb_521 
  0x572c2512, 0x294f240b, 0x17113c12, 0x0e033fa0,   // eu.fy.na_654 eo.bi.sl_542  ug.ro.sr_654 af.nl.is_322 
  0x1735110b, 0x4900680d, 0x30233ca0, 0x17002308,   // ro.tg.sr_542 ig.to.un_540  ug.ky.uz_322 ky.sr.un_430 
  0x5d005509, 0x483844a9, 0x101708a4, 0x18531507,   // rw.ss.un_440 kk.tk.tt_544  uk.sr.be_433 un.ht.ga_432 
  // [5490]
  0x22004208, 0x34004c09, 0x30380a04, 0x17381509,   // co.oc.un_430 wo.xh.un_440  mk.tk.uz_332 un.tk.sr_444 
  0x34004c12, 0x17003805, 0x18213ba7, 0x05060102,   // wo.xh.un_640 tk.sr.un_330  ks.fa.ar_532 en.de.fr_222 
  0x212f20ad, 0x694976af, 0x674947ec, 0x01021d07,   // sq.su.jw_643 crs.to.mfe_655  sn.to.ak_644 la.da.en_432 
  0x673468a9, 0x321629a0, 0x2500390c, 0x48001505,   // ig.xh.ak_544 sl.hr.bs_322  br.eu.un_530 un.tt.un_330 
  // [54a0]
  0x30004809, 0x073615a0, 0x48003c19, 0x223e6907,   // tt.uz.un_440 un.ab.bg_322  ug.tt.un_750 mfe.rm.oc_432 
  0x274264a4, 0x5a4b040c, 0x134b0204, 0x04232507,   // lg.co.gd_433 fi.mi.sm_543  da.mi.et_332 mn.ky.ru_432 
  0x0d002914, 0x424969ac, 0x48372305, 0x28211855,   // sl.cs.un_660 mfe.to.co_632  ky.ba.tt_333 ar.fa.sd_442 
  0x1f003f07, 0x31000c02, 0x2d001604, 0x30213407,   // af.cy.un_420 sv.az.un_220  hr.sk.un_320 ps.fa.uz_432 
  // [54b0]
  0x29002d0d, 0x2d290d05, 0x1d002f07, 0x44072502,   // sk.sl.un_540 cs.sl.sk_333  su.la.un_420 mn.bg.kk_222 
  0x283d3b13, 0x36483807, 0x21003b19, 0x044407a6,   // ks.ku.sd_665 tk.tt.ab_432  ks.fa.un_750 bg.kk.ru_521 
  0x21392204, 0x070444a4, 0x21002f0e, 0x49005a04,   // oc.br.jw_332 kk.ru.bg_433  su.jw.un_550 sm.to.un_320 
  0x6400470e, 0x451afea4, 0x44001012, 0x2f0f4dad,   // sn.lg.un_550 tlh.tl.ln_433  be.kk.un_640 aa.lv.su_643 
  // [54c0]
  0x12341811, 0x4c111d07, 0x641a390c, 0x080735a0,   // ar.ps.ur_653 la.ro.wo_432  br.tl.lg_543 tg.bg.uk_322 
  0x53002802, 0x2cfc52a0, 0x550652ad, 0x6400fc0c,   // sw.ht.un_220 ha.zzp.fy_322  ha.de.rw_643 zzp.lg.un_530 
  0x314d1ba4, 0x08041104, 0x64475211, 0x1c5c1304,   // tr.aa.az_433 ro.ru.uk_332  ha.sn.lg_653 bh.sa.mr_332 
  0x355d33a0, 0x2a005213, 0x647833a0, 0x200cfe0c,   // nn.ss.zu_322 ha.mt.un_650  nn.ve.lg_322 tlh.sv.sq_543 
  // [54d0]
  0x0c001002, 0x03683f04, 0x2c05fc02, 0x4d1d1a0c,   // lt.sv.un_220 af.ig.nl_332  zzp.fr.fy_222 tl.la.aa_543 
  0x254415ad, 0x23fe1007, 0x6b421aa7, 0x03006b04,   // un.kk.mn_643 lt.tlh.ca_432  tl.co.ceb_532 ceb.nl.un_320 
  0x73235a04, 0x17000804, 0x35005508, 0x34122113,   // sm.ca.ny_332 uk.sr.un_320  rw.zu.un_430 fa.ur.ps_665 
  0xfc150107, 0x17202fa4, 0x1b383113, 0x545958ec,   // en.zzp.un_420 su.sq.sr_433  az.tk.tr_665 om.rn.ik_644 
  // [54e0]
  0x5e3949a0, 0x3810150e, 0x65002802, 0x23003b05,   // to.br.ts_322 un.be.tk_555  sw.gv.un_220 so.ca.un_330 
  0x286301a7, 0x3e00510d, 0x52033f05, 0x0a001002,   // en.sco.sw_532 kl.rm.un_540  af.nl.ha_333 be.mk.un_220 
  0x73495a0d, 0xfc523855, 0x08041555, 0x08042304,   // sm.to.ny_554 tk.ha.zzp_442  un.ru.uk_442 ky.ru.uk_332 
  0x785e4208, 0x69041312, 0x1b003814, 0x37005f0d,   // co.ts.ve_443 et.fi.mfe_654  tk.tr.un_660 tn.st.un_540 
  // [54f0]
  0x3c003d02, 0x20005b0d, 0x30482308, 0x462b1c08,   // ku.ug.un_220 sg.sq.un_540  ky.tt.uz_443 id.vi.qu_443 
  0x28645802, 0x5828680c, 0x341830a0, 0x3c353811,   // om.lg.sw_222 ig.sw.om_543  uz.ar.ps_322 tk.tg.ug_653 
  0x64005809, 0x10000a08, 0x08100704, 0xfc002704,   // om.lg.un_440 mk.be.un_430  bg.be.uk_332 gd.zzp.un_320 
  0x0e001904, 0x2f1d02a6, 0x0a0810a0, 0x32162909,   // gl.is.un_320 da.la.su_521  be.uk.mk_322 sl.hr.bs_444 
  // [5500]
  0x3d1830a4, 0x53220513, 0x1e084f07, 0x2f1d1c08,   // uz.ar.ku_433 fr.oc.ht_665  bi.no.ms_432 id.la.su_443 
  0x2e03080c, 0x3e06040c, 0x60475faf, 0x51061ba0,   // no.nl.fo_543 fi.de.rm_543  tn.sn.vo_655 tr.de.kl_322 
  0x514f04ec, 0x16202cee, 0x16122007, 0x20030207,   // fi.bi.kl_644 fy.sq.hr_422  sq.hu.hr_432 da.nl.sq_432 
  0x2d0d06a0, 0x20291711, 0x33400607, 0x10791607,   // de.cs.sk_322 sr.sl.sq_653  de.lb.nn_432 hr.war.lt_432 
  // [5510]
  0x12004504, 0x12002c04, 0x3308fcee, 0x1c002f07,   // ln.hu.un_320 fy.hu.un_320  zzp.no.nn_422 su.id.un_420 
  0x3f022e0c, 0x39121f04, 0x34123055, 0x020553af,   // fo.da.af_543 cy.hu.br_332  uz.ur.ps_442 ht.fr.da_655 
  0x2515365a, 0x1d221b05, 0x21002f12, 0x10003508,   // ab.mn.un_530 tr.oc.la_333  su.jw.un_640 tg.be.un_430 
  0x13095caf, 0x30386ba4, 0x0a2325ad, 0x1d384da7,   // sa.hi.bh_655 ceb.tk.uz_433  mn.ky.mk_643 aa.tk.la_532 
  // [5520]
  0x47004f04, 0x1f5f75ee, 0x33080202, 0x25034dee,   // bi.sn.un_320 nso.tn.cy_422  da.no.nn_222 aa.nl.eu_422 
  0x40067905, 0x151f3905, 0x1e2d0d14, 0x400608a9,   // war.de.lb_333 br.cy.un_333  cs.sk.ms_666 no.de.lb_544 
  0x651d63a7, 0x0c40040c, 0x52003b02, 0x041c2f04,   // sco.la.gv_532 fi.lb.sv_543  so.ha.un_220 su.id.fi_332 
  0x151f4007, 0x12002105, 0x322b16a0, 0x26092da4,   // lb.cy.un_432 jw.hu.un_330  hr.vi.bs_322 sk.pl.ia_433 
  // [5530]
  0x12302112, 0x48311b0d, 0x04003414, 0x213412a4,   // fa.uz.ur_654 tr.az.tt_554  xh.fi.un_660 ur.ps.fa_433 
  0x28121809, 0x0c0229ad, 0x1c0d130c, 0x0c00020d,   // ar.ur.sd_444 sl.da.sv_643  bh.ne.mr_543 da.sv.un_540 
  0x551d6402, 0x1c283102, 0x5e005d05, 0x3d003c23,   // lg.la.rw_222 az.sw.id_222  ss.ts.un_330 ug.ku.un_880 
  0x382e0eec, 0x2e000212, 0x2d000a04, 0x0c000e0c,   // is.fo.tk_644 da.fo.un_640  pt.sk.un_320 is.sv.un_530 
  // [5540]
  0x30443caf, 0x100804a4, 0x28fa4755, 0x65002808,   // ug.kk.uz_655 ru.uk.be_433  sn.nr.sw_442 sw.gv.un_430 
  0x234448ec, 0x02330811, 0x046a6808, 0x04100812,   // tt.kk.ky_644 no.nn.da_653  ig.haw.fi_443 uk.be.ru_654 
  0x49005c0e, 0x04070808, 0x0e4a0a04, 0x1828440c,   // sa.to.un_550 uk.bg.ru_443  pt.yo.is_332 kk.sd.ar_543 
  0x17041505, 0x18003616, 0x04370808, 0x070a15a4,   // un.ru.sr_333 gn.ga.un_720  uk.ba.ru_443 un.mk.bg_433 
  // [5550]
  0x372338a7, 0x3c0a070c, 0x2f211c04, 0x28004707,   // tk.ky.ba_532 bg.mk.ug_543  id.jw.su_332 sn.sw.un_420 
  0x4528590c, 0x0f2f47a4, 0x1b313812, 0x2a006304,   // rn.sw.ln_543 sn.su.lv_433  tk.az.tr_654 sco.mt.un_320 
  0x2d0d36b2, 0x52006402, 0x21342805, 0x56001104,   // gn.cs.sk_732 lg.ha.un_220  sd.ps.fa_333 ro.mg.un_320 
  0x734528a4, 0x350825a7, 0x595573a4, 0x2859550d,   // sw.ln.ny_433 mn.uk.tg_532  ny.rw.rn_433 rw.rn.sw_554 
  // [5560]
  0x041038a9, 0x3f730913, 0x38303ca4, 0x29000f04,   // tk.be.ru_544 pl.ny.af_665  ug.uz.tk_433 lv.sl.un_320 
  0x0737480c, 0x17002911, 0x08004414, 0x3f595504,   // tt.ba.bg_543 sl.sr.un_630  kk.uk.un_660 rw.rn.af_332 
  0x594a090c, 0x0a170405, 0x02782855, 0x285559a6,   // pl.yo.rn_543 ru.sr.mk_333  sw.ve.da_442 rn.rw.sw_521 
  0x28005504, 0x2e004a0e, 0x55095960, 0x090e2ea0,   // rw.sw.un_320 yo.fo.un_550  rn.pl.rw_664 fo.is.pl_322 
  // [5570]
  0x09005514, 0x55475913, 0x13095c09, 0x00002e24,   // rw.pl.un_660 rn.sn.rw_665  sa.hi.bh_444 fo.un.un_900 
  0x57003513, 0x5547280d, 0x47000912, 0x170710ee,   // zu.na.un_650 sw.sn.rw_554  pl.sn.un_640 be.bg.sr_422 
  0x55642804, 0x55000912, 0x5559090c, 0x53000504,   // sw.lg.rw_332 pl.rw.un_640  pl.rn.rw_543 fr.ht.un_320 
  0x3b63090c, 0x475909a7, 0x1d27fcee, 0x2c001105,   // pl.sco.so_543 pl.rn.sn_532  zzp.gd.la_422 ro.fy.un_330 
  // [5580]
  0x63006505, 0x3800312b, 0xfc6a2507, 0x49006a14,   // gv.sco.un_330 az.tk.un_980  eu.haw.zzp_432 haw.to.un_660 
  0x112718a0, 0x25fc5707, 0x04071108, 0x360b46a9,   // ga.gd.ro_322 na.zzp.eu_432  ro.bg.ru_443 qu.es.gn_544 
  0x2a19fe09, 0x1c001e22, 0x282f2112, 0x2858fe0c,   // tlh.gl.mt_444 ms.id.un_870  jw.su.sw_654 tlh.om.sw_543 
  0x2a003005, 0x2f55020e, 0x0e00090c, 0x1d552e0d,   // uz.mt.un_330 da.rw.su_555  pl.is.un_530 fo.rw.la_554 
  // [5590]
  0x1dfe55a4, 0x0d2d2e0c, 0x3b002f04, 0x0f101e04,   // rw.tlh.la_433 fo.sk.cs_543  su.so.un_320 ms.lt.lv_332 
  0x39002504, 0x58006b12, 0x73001104, 0x3500fe0d,   // eu.br.un_320 ceb.om.un_640  ro.ny.un_320 tlh.zu.un_540 
  0x3d00210b, 0x190a0b14, 0x101508a4, 0x114207a7,   // fa.ku.un_520 es.pt.gl_666  uk.be.un_430 it.co.ro_532 
  0x353b1308, 0x4a00120c, 0x2f6013a7, 0x3523305a,   // et.so.zu_443 hu.yo.un_530  et.vo.su_532 uz.ky.tg_553 
  // [55a0]
  0x5c0f1008, 0x2f79fe04, 0x0a080405, 0x021e1c11,   // lt.lv.sa_443 tlh.war.su_332  ru.uk.mk_333 id.ms.da_653 
  0x48083704, 0x0a001d02, 0x1600291a, 0x2530350c,   // ba.uk.tt_332 la.pt.un_220  sl.hr.un_760 tg.uz.mn_543 
  0x0a170409, 0x3534faee, 0x7300782b, 0x183d3404,   // ru.sr.mk_444 nr.xh.zu_422  ve.ny.un_980 ps.ku.ar_332 
  0x38000602, 0x03000202, 0x3f3b02a0, 0x3f060302,   // de.tk.un_220 da.nl.un_220  da.so.af_322 nl.de.af_222 
  // [55b0]
  0x37484414, 0x033f4aa0, 0x3d1221a4, 0x30000c04,   // kk.tt.ba_666 yo.af.nl_322  fa.ur.ku_433 sv.uz.un_320 
  0x0000122d, 0x301548a0, 0x36001512, 0x37005d12,   // ur.un.un_A00 tt.uz.un_320  un.ab.un_640 ss.st.un_640 
  0x3b3d21a4, 0x3c3021a7, 0x08021caf, 0x2d0dfea4,   // fa.ku.ks_433 fa.uz.ug_532  id.da.no_655 tlh.cs.sk_433 
  0x380f0302, 0x30213daf, 0x56004308, 0x0c082e04,   // nl.lv.tk_222 ku.fa.uz_655  ie.mg.un_430 fo.no.sv_332 
  // [55c0]
  0x4a007312, 0x00001237, 0x2e330805, 0x0a071705,   // ny.yo.un_640 ur.un.un_B00  no.nn.fo_333 sr.bg.mk_333 
  0x37483c0e, 0x0d122d0d, 0x5d733507, 0x48443713,   // ug.tt.ba_555 sk.hu.cs_554  zu.ny.ss_432 ba.kk.tt_665 
  0x2e2d0d02, 0x1100362a, 0x48000808, 0x21343d0d,   // cs.sk.fo_222 ab.ro.un_970  uk.tt.un_430 ku.ps.fa_554 
  0x07041704, 0x5c003e04, 0x6a5c4b60, 0x34122812,   // sr.ru.bg_332 rm.sa.un_320  mi.sa.haw_664 sd.ur.ps_654 
  // [55d0]
  0x383c3009, 0x150730ec, 0x35153807, 0x100825a9,   // uz.ug.tk_444 uz.bg.un_644  tk.tg.un_420 mn.uk.be_544 
  0x302510a0, 0x293216ee, 0x0a173607, 0x441723ee,   // be.mn.uz_322 hr.bs.sl_422  ab.sr.mk_432 ky.sr.kk_422 
  0x55000302, 0x100a1704, 0x30003c04, 0x2a001807,   // nl.rw.un_220 sr.mk.be_332  ug.uz.un_320 ga.mt.un_420 
  0x08002312, 0x0800440b, 0x2128125a, 0x42001504,   // ky.uk.un_640 kk.uk.un_520  ur.sd.fa_553 un.co.un_320 
  // [55e0]
  0x48464eec, 0x1200600c, 0x12004813, 0x38006504,   // ay.qu.tt_644 vo.hu.un_530  tt.hu.un_650 gv.tk.un_320 
  0x1700070c, 0x1515235a, 0x190948a7, 0x48231507,   // bg.sr.un_530 ky.un.un_530  tt.pl.gl_532 un.ky.tt_432 
  0x64002d02, 0x1f003904, 0x4200090c, 0x43002518,   // sk.lg.un_220 br.cy.un_320  pl.co.un_530 eu.ie.un_740 
  0x2c25030c, 0x1500680d, 0x04150805, 0x40003902,   // nl.eu.fy_543 ig.un.un_540  uk.ru.un_330 br.lb.un_220 
  // [55f0]
  0x15041107, 0x25000207, 0x400325a0, 0x17040702,   // ro.ru.un_432 da.eu.un_420  eu.nl.lb_322 bg.ru.sr_222 
  0x390a4602, 0x1800fc08, 0x03002c29, 0x190b5da0,   // qu.pt.br_222 zzp.ga.un_430  fy.nl.un_960 ss.es.gl_322 
  0x173635ee, 0x233c3509, 0x3534550c, 0x0d004c13,   // tg.ab.sr_422 tg.ug.ky_444  rw.xh.zu_543 wo.cs.un_650 
  0x123d3ba9, 0x1f000108, 0x1a04680c, 0x0d002507,   // ks.ku.ur_544 en.cy.un_430  ig.fi.tl_543 eu.cs.un_420 
  // [5600]
  0x252c03a9, 0x034f2507, 0x3848150c, 0x4d3b5808,   // nl.fy.eu_544 eu.bi.nl_432  un.tt.tk_543 om.so.aa_443 
  0x58003b05, 0x0f033fa0, 0x51044da0, 0x3b006908,   // so.om.un_330 af.nl.lv_322  aa.fi.kl_322 mfe.so.un_430 
  0x67584cec, 0x112339a0, 0x13033ba4, 0x6b151d07,   // wo.om.ak_644 br.ca.ro_322  so.nl.et_433 la.ceb.un_420 
  0x51583b12, 0x21005305, 0x16000d02, 0x28233b07,   // so.om.kl_654 ht.jw.un_330  cs.hr.un_220 ks.ky.sd_432 
  // [5610]
  0x23371708, 0x0a0417af, 0x5c090d05, 0x2c000305,   // sr.ba.ky_443 sr.ru.mk_655  ne.hi.sa_333 nl.fy.un_330 
  0x65031307, 0x2830210c, 0x051139a7, 0x64003404,   // et.nl.gv_432 fa.uz.sd_543  br.ro.fr_532 xh.lg.un_320 
  0x3b3f1307, 0x2c3302ee, 0x07173c0c, 0x28375f04,   // et.af.so_432 da.nn.fy_422  ug.sr.bg_543 tn.st.sw_332 
  0x30002d13, 0x3538480c, 0x04303507, 0x091c135a,   // sk.uz.un_650 tt.tk.tg_543  tg.uz.ru_432 bh.mr.hi_553 
  // [5620]
  0x33380ca0, 0x15330cad, 0x1500170d, 0x4d0e38a4,   // sv.tk.nn_322 sv.nn.un_643  sr.un.un_540 tk.is.aa_433 
  0x4838375a, 0x2c5d200d, 0x12fe5d12, 0x097912a6,   // ba.tk.tt_553 sq.ss.fy_554  ss.tlh.hu_654 hu.war.pl_521 
  0x35005d02, 0x0c080205, 0x080717a0, 0x06206104,   // ss.zu.un_220 da.no.sv_333  sr.bg.uk_322 za.sq.de_332 
  0x2f001c08, 0x28123ba6, 0x25001204, 0x25004904,   // id.su.un_430 ks.ur.sd_521  hu.eu.un_320 to.eu.un_320 
  // [5630]
  0x094012af, 0x4b001f12, 0x5a006a08, 0x52061207,   // hu.lb.pl_655 cy.mi.un_640  haw.sm.un_430 hu.de.ha_432 
  0x1d495aa4, 0x3efc340c, 0x4c28fea9, 0x1f004902,   // sm.to.la_433 xh.zzp.rm_543  tlh.sw.wo_544 to.cy.un_220 
  0x64003812, 0x0e005d1a, 0x1f793955, 0x40281fee,   // tk.lg.un_640 ss.is.un_760  br.war.cy_442 cy.sw.lb_422 
  0x0a001d12, 0x30353655, 0x38fe6407, 0x211f3960,   // la.pt.un_640 ab.tg.uz_442  lg.tlh.tk_432 br.cy.jw_664 
  // [5640]
  0x07263e08, 0x094064a7, 0x09001219, 0x6439730b,   // rm.ia.it_443 lg.lb.pl_532  hu.pl.un_750 ny.br.lg_542 
  0xfe003408, 0x494b3905, 0x47402f11, 0x28005d09,   // xh.tlh.un_430 br.mi.to_333  su.lb.sn_653 ss.sw.un_440 
  0x09212f08, 0x2873feec, 0x18431d07, 0xfe001f05,   // su.jw.pl_443 tlh.ny.sw_644  la.ie.ga_432 cy.tlh.un_330 
  0xfc0e2e07, 0x0e3329a0, 0x04173812, 0x15353007,   // fo.is.zzp_432 sl.nn.is_322  tk.sr.ru_654 uz.tg.un_432 
  // [5650]
  0x23183cee, 0x4000061b, 0x2d0d1609, 0x0d292d04,   // ug.ar.ky_422 de.lb.un_770  hr.cs.sk_444 sk.sl.cs_332 
  0x1c0d1314, 0xfc00540e, 0x311b4807, 0x650163ee,   // bh.ne.mr_666 ik.zzp.un_550  tt.tr.az_432 sco.en.gv_422 
  0x651a01a0, 0x15482508, 0x3c2321a0, 0x17002914,   // en.tl.gv_322 mn.tt.un_443  fa.ky.ug_322 sl.sr.un_660 
  0x4a00360c, 0x63000114, 0xfc005502, 0x36374804,   // gn.yo.un_530 en.sco.un_660  rw.zzp.un_220 tt.ba.ab_332 
  // [5660]
  0x0a171107, 0x2e0e120b, 0x21003d1a, 0x15001712,   // ro.sr.mk_432 hu.is.fo_542  ku.fa.un_760 sr.un.un_640 
  0x4e004d19, 0x071730a0, 0x02005109, 0x32162905,   // aa.ay.un_750 uz.sr.bg_322  kl.da.un_440 sl.hr.bs_333 
  0x1228180e, 0x06002204, 0x04173007, 0x04083002,   // ar.sd.ur_555 oc.de.un_320  uz.sr.ru_432 uz.uk.ru_222 
  0x281830ad, 0x35003c04, 0x100f3ea0, 0x23283b0d,   // uz.ar.sd_643 ug.tg.un_320  rm.lv.lt_322 ks.sd.ky_554 
  // [5670]
  0x28442304, 0x4f1060a9, 0x1c521ea0, 0x3035370d,   // ky.kk.sd_332 vo.lt.bi_544  ms.ha.id_322 ba.tg.uz_554 
  0x2e3e0c04, 0x09007909, 0x403e60ad, 0x2530485a,   // sv.rm.fo_332 war.pl.un_440  vo.rm.lb_643 tt.uz.mn_553 
  0x344002a0, 0x5e595508, 0x30153caf, 0x5e555da4,   // da.lb.xh_322 rw.rn.ts_443  ug.uz.un_650 ss.rw.ts_433 
  0x4f5a3712, 0x35301509, 0x783435a7, 0x1d793707,   // st.sm.bi_654 un.uz.tg_444  zu.xh.ve_532 st.war.la_432 
  // [5680]
  0x48002314, 0x3b3d280c, 0x59555d09, 0x475d5fa6,   // ky.tt.un_660 sd.ku.ks_543  ss.rw.rn_444 tn.ss.sn_521 
  0x4a002808, 0x3d3b340c, 0x4b005a07, 0x5f5d5504,   // sw.yo.un_430 ps.ks.ku_543  sm.mi.un_420 rw.ss.tn_332 
  0x3f061507, 0x1e005504, 0x02002213, 0x3e001113,   // un.de.af_432 rw.ms.un_320  oc.da.un_650 ro.rm.un_650 
  0x3c442307, 0x652b3002, 0x0b004604, 0x47506ea0,   // ky.kk.ug_432 uz.vi.gv_222  qu.es.un_320 hmn.fj.sn_322 
  // [5690]
  0x0d5c1307, 0x7334350c, 0x34005e0c, 0x34005e08,   // bh.sa.ne_432 zu.xh.ny_543  ts.xh.un_530 ts.xh.un_430 
  0x34183d05, 0x355559a7, 0x5e555dad, 0x5e595514,   // ku.ar.ps_333 rn.rw.zu_532  ss.rw.ts_643 rw.rn.ts_666 
  0x303d340c, 0x47005f0e, 0x4b005a12, 0x1d004b07,   // ps.ku.uz_543 tn.sn.un_550  sm.mi.un_640 mi.la.un_420 
  0x2818345a, 0x1d494b55, 0x122834a9, 0x30003707,   // ps.ar.sd_553 mi.to.la_442  ps.sd.ur_544 ba.uz.un_420 
  // [56a0]
  0x230437a0, 0x17003512, 0x44003422, 0x11001b04,   // ba.ru.ky_322 tg.sr.un_640  ps.kk.un_870 tr.ro.un_320 
  0x10004412, 0x3c3738ec, 0x48442308, 0x12213407,   // kk.be.un_640 tk.ba.ug_644  ky.kk.tt_443 ps.fa.ur_432 
  0x2a00380c, 0x2e020e0c, 0x38001807, 0x360711af,   // tk.mt.un_530 is.da.fo_543  ga.tk.un_420 ro.bg.ab_655 
  0x0a040807, 0x3200100c, 0x530c0da0, 0x3217160d,   // uk.ru.mk_432 lt.bs.un_530  cs.sv.ht_322 hr.sr.bs_554 
  // [56b0]
  0x30122808, 0x12002d13, 0x0a07350c, 0x3d123b0c,   // sd.ur.uz_443 sk.hu.un_650  tg.bg.mk_543 ks.ur.ku_543 
  0x0800380d, 0x58004a04, 0x17002318, 0x16004c0d,   // tk.uk.un_540 yo.om.un_320  ky.sr.un_740 wo.hr.un_540 
  0x0676fca4, 0x44383508, 0x0c6b2aec, 0x653f4cee,   // zzp.crs.de_433 tg.tk.kk_443  mt.ceb.sv_644 wo.af.gv_422 
  0x695360ec, 0x58004c21, 0x4c3b25a0, 0x4d582512,   // vo.ht.mfe_644 wo.om.un_860  eu.so.wo_322 eu.om.aa_654 
  // [56c0]
  0x321617ec, 0x13094004, 0x11005804, 0x481b30a4,   // sr.hr.bs_644 lb.pl.et_332  om.ro.un_320 uz.tr.tt_433 
  0x03004c07, 0x583b5a07, 0x34004904, 0x63404c07,   // wo.nl.un_420 sm.so.om_432  to.xh.un_320 wo.lb.sco_432 
  0x3b404cad, 0x1a630104, 0x644d580c, 0x3f0313a9,   // wo.lb.so_643 en.sco.tl_332  om.aa.lg_543 et.nl.af_544 
  0x21463ba0, 0x070408ee, 0x0f001008, 0x2d0d0e0c,   // so.qu.jw_322 uk.ru.bg_422  lt.lv.un_430 is.cs.sk_543 
  // [56d0]
  0x34036302, 0x04151712, 0x37170812, 0x58654cee,   // sco.nl.xh_222 sr.ru.un_640  uk.sr.ba_654 wo.gv.om_422 
  0x6500030c, 0x6bfc0107, 0x44001702, 0x3b004c13,   // nl.gv.un_530 en.zzp.ceb_432  sr.kk.un_220 wo.so.un_650 
  0x5303fcee, 0x3f4d5f08, 0x0400380c, 0x58354cee,   // zzp.nl.ht_422 tn.aa.af_443  tk.ru.un_530 wo.zu.om_422 
  0x03403fa4, 0x4d3f250c, 0x0804170c, 0x4c003b08,   // af.lb.nl_433 eu.af.aa_543  sr.ru.uk_543 so.wo.un_430 
  // [56e0]
  0x3c3823af, 0x122821af, 0x150a0707, 0x15110aa4,   // ky.tk.ug_655 fa.sd.ur_655  bg.mk.un_432 mk.ro.un_433 
  0x2f1e1c55, 0x2d0b19a0, 0x21001811, 0x30000809,   // id.ms.su_442 gl.es.sk_322  ar.fa.un_630 uk.uz.un_440 
  0x34002805, 0x1c000919, 0x55005d04, 0x23002205,   // sd.ps.un_330 hi.mr.un_750  ss.rw.un_320 oc.ca.un_330 
  0x53002207, 0x2300220d, 0x123b2111, 0x190b2dee,   // oc.ht.un_420 oc.ca.un_540  fa.ks.ur_653 sk.es.gl_422 
  // [56f0]
  0x0400310c, 0x3058feee, 0x3b002102, 0x36001014,   // az.fi.un_530 tlh.om.uz_422  jw.so.un_220 be.ab.un_660 
  0x09000a02, 0x234630a0, 0x30004813, 0x3b00300c,   // pt.pl.un_220 uz.qu.ca_322  tt.uz.un_650 uz.so.un_530 
  0x1b003804, 0x23053ba0, 0x18002e02, 0x3b6330af,   // tk.tr.un_320 so.fr.ca_322  fo.ga.un_220 uz.sco.so_655 
  0x5d00370e, 0x30003822, 0x1f00730d, 0x30003c23,   // st.ss.un_550 tk.uz.un_870  ny.cy.un_540 ug.uz.un_880 
  // [5700]
  0x35627511, 0x36190bee, 0x35005908, 0x30136907,   // nso.kha.zu_653 es.gl.gn_422  rn.zu.un_430 mfe.et.uz_432 
  0x1508250c, 0xfe004d13, 0x18342812, 0x12181c08,   // mn.uk.un_543 aa.tlh.un_650  sd.ps.ar_654 mr.ar.ur_443 
  0x73495e08, 0xfe465808, 0x173536a0, 0x10002907,   // ts.to.ny_443 om.qu.tlh_443  ab.tg.sr_322 sl.lt.un_420 
  0x231228a0, 0x304865a4, 0x1d48300c, 0x55190b04,   // sd.ur.ky_322 gv.tt.uz_433  uz.tt.la_543 es.gl.rw_332 
  // [5710]
  0x29001222, 0x0d1d0404, 0x18212802, 0x342818ad,   // hu.sl.un_870 fi.la.cs_332  sd.fa.ar_222 ar.sd.ps_643 
  0x192c060d, 0x640a69a7, 0x081704a4, 0x051d01ee,   // de.fy.gl_554 mfe.pt.lg_532  ru.sr.uk_433 en.la.fr_422 
  0x480436ee, 0x29001d02, 0x5300420c, 0x31003007,   // ab.ru.tt_422 la.sl.un_220  co.ht.un_530 uz.az.un_420 
  0x165c10a7, 0x12003014, 0x531b3111, 0x30000304,   // lt.sa.hr_532 uz.ur.un_660  az.tr.ht_653 nl.uz.un_320 
  // [5720]
  0x30020811, 0x301525ec, 0x3f00032b, 0x0000752d,   // no.da.uz_653 mn.uz.un_640  nl.af.un_980 nso.un.un_A00 
  0x156569ee, 0x4200050c, 0x290f1012, 0x46001d04,   // mfe.gv.un_422 fr.co.un_530  lt.lv.sl_654 la.qu.un_320 
  0x0a07110c, 0x1d002407, 0x08005007, 0x1d40670d,   // ro.bg.mk_543 eo.la.un_420  fj.no.un_420 ak.lb.la_554 
  0x27005e08, 0x183b2107, 0x303507a0, 0x0b2e0ea9,   // ts.gd.un_430 fa.ks.ar_432  bg.tg.uz_322 is.fo.es_544 
  // [5730]
  0x05530ea7, 0x0553220c, 0x27000208, 0x2c251107,   // is.ht.fr_532 oc.ht.fr_543  da.gd.un_430 ro.eu.fy_432 
  0x18003c08, 0x44353004, 0x07380aec, 0x49004508,   // ug.ar.un_430 uz.tg.kk_332  mk.tk.bg_644 ln.to.un_430 
  0x02002f04, 0x12101f05, 0x182112ad, 0x1f1210a9,   // su.da.un_320 cy.lt.hu_333  ur.fa.ar_643 lt.hu.cy_544 
  0x2f1819a0, 0x650210ec, 0x080a1707, 0x05222355,   // gl.ga.su_322 lt.da.gv_644  sr.mk.uk_432 ca.oc.fr_442 
  // [5740]
  0x17003702, 0x3d3034af, 0x182e0e0b, 0x5600090d,   // ba.sr.un_220 ps.uz.ku_655  is.fo.ga_542 pl.mg.un_540 
  0x173c300b, 0x55004707, 0x0d00100c, 0x0a000d08,   // uz.ug.sr_542 sn.rw.un_420  lt.cs.un_530 cs.pt.un_430 
  0x56001019, 0x355d3408, 0x63100107, 0x38311b0e,   // lt.mg.un_750 xh.ss.zu_443  en.lt.sco_432 tr.az.tk_555 
  0x6515100c, 0x48083512, 0x12173707, 0x095c130b,   // lt.gv.un_530 tg.uk.tt_654  st.sr.hu_432 bh.sa.hi_542 
  // [5750]
  0x352330ee, 0x1500080e, 0x29000d02, 0x09000404,   // uz.ky.tg_422 uk.un.un_550  cs.sl.un_220 fi.pl.un_320 
  0x10041709, 0x5f35345a, 0x3d002308, 0x120640ec,   // sr.ru.be_444 xh.zu.tn_553  ky.ku.un_430 lb.de.hu_644 
  0x443b2311, 0x183428ac, 0x6a50fc0d, 0x1218280b,   // ky.ks.kk_653 sd.ps.ar_632  zzp.fj.haw_554 sd.ar.ur_542 
  0x6a52fc08, 0x37005f0c, 0x2f4c5208, 0x0e2e1204,   // zzp.ha.haw_443 tn.st.un_530  ha.wo.su_443 hu.fo.is_332 
  // [5760]
  0x3550fc12, 0x4a005f0e, 0x6a4f5012, 0x2752fca0,   // zzp.fj.zu_654 tn.yo.un_550  fj.bi.haw_654 zzp.ha.gd_322 
  0x4d00fc0c, 0x6a785f0c, 0x171613a4, 0x34183da0,   // zzp.aa.un_530 tn.ve.haw_543  et.hr.sr_433 ku.ar.ps_322 
  0x2d0d0e09, 0x29003313, 0x35fc5204, 0x0000522d,   // is.cs.sk_444 nn.sl.un_650  ha.zzp.zu_332 ha.un.un_A00 
  0x5200fc0d, 0x2f29fea6, 0x122f2aa0, 0x3000150d,   // zzp.ha.un_540 tlh.sl.su_521  mt.su.hu_322 un.uz.un_540 
  // [5770]
  0x17002a04, 0xfe003309, 0x38fc0913, 0x21181107,   // mt.sr.un_320 nn.tlh.un_440  pl.zzp.tk_665 ro.ga.jw_432 
  0x48004a04, 0x48001b09, 0xfc00150c, 0x17040708,   // yo.tt.un_320 tr.tt.un_440  un.zzp.un_530 bg.ru.sr_443 
  0x4b57fca9, 0x4b005014, 0x1c50fc12, 0x38003304,   // zzp.na.mi_544 fj.mi.un_660  zzp.fj.id_654 nn.tk.un_320 
  0x44001121, 0x28004b09, 0x30153607, 0x123876a0,   // ro.kk.un_860 mi.sw.un_440  ab.uz.un_420 crs.tk.hu_322 
  // [5780]
  0x473459a4, 0x25190b04, 0x12162aee, 0x73645f04,   // rn.xh.sn_433 es.gl.eu_332  mt.hr.hu_422 tn.lg.ny_332 
  0x0400fe02, 0x11001c04, 0x202afea0, 0x2e000e18,   // tlh.fi.un_220 id.ro.un_320  tlh.mt.sq_322 is.fo.un_740 
  0x0a040802, 0x281834a9, 0x10000702, 0x1c005c02,   // uk.ru.mk_222 ps.ar.sd_544  bg.be.un_220 sa.mr.un_220 
  0x0400481a, 0x0b190a04, 0x2e005d08, 0x36001807,   // tt.fi.un_760 pt.gl.es_332  ss.fo.un_430 ga.gn.un_420 
  // [5790]
  0x483735ad, 0x19182ea0, 0x33082eec, 0x0e190b04,   // tg.ba.tt_643 fo.ga.gl_322  fo.no.nn_644 es.gl.is_332 
  0x33080c02, 0x7300250e, 0x44354802, 0x321729a0,   // sv.no.nn_222 eu.ny.un_550  tt.tg.kk_222 sl.sr.bs_322 
  0x49006507, 0x190b2e02, 0x30002002, 0x01001d02,   // gv.to.un_420 fo.es.gl_222  sq.uz.un_220 la.en.un_220 
  0x301504a7, 0x00004324, 0x49006a19, 0x594b55a4,   // ru.uz.un_520 ie.un.un_900  haw.to.un_750 rw.mi.rn_433 
  // [57a0]
  0x35005f05, 0x290904a0, 0x520e0412, 0x594552a0,   // tn.zu.un_330 fi.pl.sl_322  fi.is.ha_654 ha.ln.rn_322 
  0x0a171504, 0x50001207, 0x2f001702, 0x52004c05,   // un.sr.mk_332 hu.fj.un_420  sr.su.un_220 wo.ha.un_330 
  0x04251507, 0x0d00160c, 0x44003709, 0x0417070e,   // un.mn.ru_432 hr.cs.un_530  ba.kk.un_440 bg.sr.ru_555 
  0x450262ec, 0x1e001a05, 0x0b192307, 0x6a004b2b,   // kha.da.ln_644 tl.ms.un_330  ca.gl.es_432 mi.haw.un_980 
  // [57b0]
  0x49005012, 0x4b490405, 0x360b23a4, 0x59005313,   // fj.to.un_640 fi.to.mi_333  ca.es.gn_433 ht.rn.un_650 
  0x57006113, 0x3c23300d, 0x5300610d, 0x40005304,   // za.na.un_650 uz.ky.ug_554  za.ht.un_540 ht.lb.un_320 
  0x230a0bec, 0x4a005d05, 0x534a5e07, 0x1b000c0d,   // es.pt.ca_644 ss.yo.un_330  ts.yo.ht_432 sv.tr.un_540 
  0x2f6a4ea9, 0x53576905, 0x3000120d, 0x23000a08,   // ay.haw.su_544 mfe.na.ht_333  ur.uz.un_540 pt.ca.un_430 
  // [57c0]
  0x0a2223a4, 0x211812ee, 0x254423a0, 0x3900590c,   // ca.oc.pt_433 ur.ar.fa_422  ky.kk.mn_322 rn.br.un_530 
  0x0a2319a9, 0x23362e02, 0x0a000404, 0x440430ee,   // gl.ca.pt_544 fo.gn.ca_222  ru.mk.un_320 uz.ru.kk_422 
  0x283f68ee, 0x15372307, 0x551f5302, 0x5300760e,   // ig.af.sw_422 ky.ba.un_432  ht.cy.rw_222 crs.ht.un_550 
  0x34002a1b, 0x734f680c, 0x483715af, 0x01006b04,   // mt.xh.un_770 ig.bi.ny_543  un.ba.tt_655 ceb.en.un_320 
  // [57d0]
  0x21501aac, 0x687328ec, 0x353464ec, 0x5e64680c,   // tl.fj.jw_632 sw.ny.ig_644  lg.xh.zu_644 ig.lg.ts_543 
  0x3c23440c, 0x1d230a0b, 0x0a234309, 0x3c44230e,   // kk.ky.ug_543 pt.ca.la_542  ie.ca.pt_444 ky.kk.ug_555 
  0x220a2304, 0x48001308, 0x455d68ec, 0x11000704,   // ca.pt.oc_332 et.tt.un_430  ig.ss.ln_644 it.ro.un_320 
  0x1821120e, 0x2315440c, 0x650518a9, 0x234437ec,   // ur.fa.ar_555 kk.ky.un_530  ga.fr.gv_544 ba.kk.ky_644 
  // [57e0]
  0x796339a7, 0x04353807, 0x101535a4, 0x2835340d,   // br.sco.war_532 tk.tg.ru_432  tg.be.un_430 xh.zu.sw_554 
  0x040a3804, 0x170415ee, 0x213d120b, 0x48351504,   // tk.mk.ru_332 un.ru.sr_422  ur.ku.fa_542 un.tg.tt_332 
  0x2000310d, 0x355d31a4, 0x09130d60, 0x2d0d31a0,   // az.sq.un_540 az.ss.zu_433  ne.bh.hi_664 az.cs.sk_322 
  0x332d0d13, 0x3410315a, 0x3615040e, 0x4c000e11,   // cs.sk.nn_665 az.lt.xh_553  ru.ab.un_550 is.wo.un_630 
  // [57f0]
  0x49005a0d, 0x593135a0, 0x383530ad, 0x11003013,   // sm.to.un_540 zu.az.rn_322  uz.tg.tk_643 uz.ro.un_650 
  0x283135ee, 0x1b005c04, 0x0a1035a0, 0x5d5c3505,   // zu.az.sw_422 sa.tr.un_320  tg.be.mk_322 zu.sa.ss_333 
  0x0435730c, 0x4425150c, 0x286b5508, 0x28002105,   // ny.zu.fi_543 un.mn.kk_543  rw.ceb.sw_443 fa.sd.un_330 
  0x59552805, 0x20303107, 0x0464590c, 0x3d3412a4,   // sw.rw.rn_333 az.uz.sq_432  rn.lg.fi_543 ur.ps.ku_433 
  
  // [5800]
  0x24002804, 0x13245509, 0x73476405, 0x0a004304,   // sw.eo.un_320 rw.eo.et_444  lg.sn.ny_333 ie.pt.un_320 
  0x0c000e02, 0x64555907, 0x34215507, 0x095c0d02,   // is.sv.un_220 rn.rw.lg_432  rw.jw.xh_432 ne.sa.hi_222 
  0x283b210c, 0x347335a4, 0x5e2502a4, 0x46024e09,   // fa.ks.sd_543 zu.ny.xh_433  da.eu.ts_433 ay.da.qu_444 
  0x59555ea9, 0x6b1234a9, 0x34557304, 0x10001714,   // ts.rw.rn_544 xh.hu.ceb_544  ny.rw.xh_332 sr.be.un_660 
  // [5810]
  0x4b6428a9, 0x12345d0c, 0x080c7955, 0x6e3f58a7,   // sw.lg.mi_544 ss.xh.hu_543  war.sv.no_442 om.af.hmn_532 
  0x475559ad, 0x03003f11, 0x03130407, 0x033f58a9,   // rn.rw.sn_643 af.nl.un_630  fi.et.nl_432 om.af.nl_544 
  0x28494b05, 0x3f3304ee, 0x34004e12, 0x0600040e,   // mi.to.sw_333 fi.nn.af_422  ay.xh.un_640 fi.de.un_550 
  0x0600fc07, 0x213023a9, 0x3b005809, 0x233c44ad,   // zzp.de.un_420 ky.uz.fa_544  om.so.un_440 kk.ug.ky_643 
  // [5820]
  0x3b00400b, 0x18001208, 0x17003607, 0x2d0d3ba0,   // lb.so.un_520 hu.ga.un_430  ab.sr.un_420 so.cs.sk_322 
  0x51584d0c, 0x58006e1a, 0x4a4c5004, 0x5c130da9,   // aa.om.kl_543 hmn.om.un_760  fj.wo.yo_332 ne.bh.sa_544 
  0x2d0f10a0, 0x5c0d090c, 0x11002c26, 0x3b4d040c,   // lt.lv.sk_322 hi.ne.sa_543  fy.ro.un_930 fi.aa.so_543 
  0x526811a0, 0x4200251b, 0x381a47a4, 0x033f4dad,   // ro.ig.ha_322 eu.co.un_770  sn.tl.tk_433 aa.af.nl_643 
  // [5830]
  0x65005108, 0x403f5808, 0x024c4d07, 0x42125604,   // kl.gv.un_430 om.af.lb_443  aa.wo.da_432 mg.hu.co_332 
  0x64005e04, 0x3216290c, 0x65003607, 0x28122155,   // ts.lg.un_320 sl.hr.bs_543  gn.gv.un_420 fa.ur.sd_442 
  0x1b1a46a4, 0x13484bad, 0x016bfe07, 0x69427608,   // qu.tl.tr_433 mi.tt.et_643  tlh.ceb.en_432 crs.co.mfe_443 
  0x791a6ba9, 0x341221a4, 0x385c47ee, 0x3d34300c,   // ceb.tl.war_544 fa.ur.ps_433  sn.sa.tk_422 uz.ps.ku_543 
  // [5840]
  0x190a4a09, 0x3c234414, 0x15004805, 0x13095c0c,   // yo.pt.gl_444 kk.ky.ug_666  tt.un.un_330 sa.hi.bh_543 
  0x11002507, 0x3d00231b, 0x250a04a0, 0x04170a04,   // eu.ro.un_420 ky.ku.un_770  ru.mk.mn_322 mk.sr.ru_332 
  0x30003808, 0x23225312, 0x3600fe0c, 0x150a170c,   // tk.uz.un_430 ht.oc.ca_654  tlh.gn.un_530 sr.mk.un_543 
  0x06003b07, 0x1744380c, 0x091c0da9, 0x100a0707,   // so.de.un_420 tk.kk.sr_543  ne.mr.hi_544 bg.mk.be_432 
  // [5850]
  0x044836a7, 0x0a054aa0, 0x5c131cad, 0x0e000604,   // ab.tt.ru_532 yo.fr.pt_322  mr.bh.sa_643 de.is.un_320 
  0x3c0a0807, 0x102315a0, 0x443c300c, 0x342818ac,   // uk.mk.ug_432 un.ky.be_322  uz.ug.kk_543 ar.sd.ps_632 
  0x48302507, 0x46595c12, 0x181228a9, 0x39001c02,   // mn.uz.tt_432 sa.rn.qu_654  sd.ur.ar_544 id.br.un_220 
  0x2f004a04, 0x5a4b50ec, 0x67006435, 0x52001c05,   // yo.su.un_320 fj.mi.sm_644  lg.ak.un_A90 id.ha.un_330 
  // [5860]
  0x59554aaf, 0x53204cee, 0x181579ee, 0x52004508,   // yo.rw.rn_655 wo.sq.ht_422  war.ga.un_420 ln.ha.un_430 
  0x6700500c, 0x3f2a5e12, 0x501d070d, 0x5c006504,   // fj.ak.un_530 ts.mt.af_654  it.la.fj_554 gv.sa.un_320 
  0x3d00180d, 0x1704300b, 0x48003704, 0x34000902,   // ar.ku.un_540 uz.ru.sr_542  ba.tt.un_320 pl.xh.un_220 
  0x3700360d, 0x55004a04, 0x69006213, 0x37002305,   // ab.ba.un_540 yo.rw.un_320  kha.mfe.un_650 ky.ba.un_330 
  // [5870]
  0x115c420c, 0x3763010b, 0x211834ec, 0x38006502,   // co.sa.ro_543 en.sco.st_542  ps.ar.fa_644 gv.tk.un_220 
  0x23003d0c, 0x59556705, 0xfe001d23, 0x1d005821,   // ku.ky.un_530 ak.rw.rn_333  la.tlh.un_880 om.la.un_860 
  0x5f00670c, 0x6a004d0e, 0x37483604, 0x40004904,   // ak.tn.un_530 aa.haw.un_550  ab.tt.ba_332 to.lb.un_320 
  0x302337a4, 0x071738a7, 0x48170a07, 0x08170a07,   // ba.ky.uz_433 tk.sr.bg_532  mk.sr.tt_432 mk.sr.uk_432 
  // [5880]
  0x03006504, 0x233038a4, 0x17041508, 0x3f4d45a4,   // gv.nl.un_320 tk.uz.ky_433  un.ru.sr_443 ln.aa.af_433 
  0x080410a9, 0x0807155a, 0x65001304, 0x13154507,   // be.ru.uk_544 un.bg.uk_553  et.gv.un_320 ln.et.un_420 
  0x041725ee, 0x353023a0, 0x483c370c, 0x23002102,   // mn.sr.ru_422 ky.uz.tg_322  ba.ug.tt_543 fa.ky.un_220 
  0x07002508, 0x32170fa0, 0x253536af, 0x3f1303ee,   // eu.it.un_430 lv.sr.bs_322  ab.tg.mn_655 nl.et.af_422 
  // [5890]
  0x07303555, 0x0f3f03ec, 0x25082308, 0x25001907,   // tg.uz.bg_442 nl.af.lv_644  ky.uk.mn_443 gl.eu.un_420 
  0x30003c11, 0x15000507, 0x123d21ad, 0x097912af,   // ug.uz.un_630 fr.un.un_420  fa.ku.ur_643 hu.war.pl_655 
  0x52002402, 0x100408a9, 0x48002d0e, 0x303835ad,   // eo.ha.un_220 uk.ru.be_544  sk.tt.un_550 tg.tk.uz_643 
  0x0a0725ad, 0x5f5dfc0d, 0x2e003b1a, 0x3b004819,   // mn.bg.mk_643 zzp.ss.tn_554  so.fo.un_760 tt.so.un_750 
  // [58a0]
  0x4c00131a, 0x37005f14, 0x310f1205, 0x300b19ec,   // et.wo.un_760 tn.st.un_660  hu.lv.az_333 gl.es.uz_644 
  0x4d005714, 0x0900120c, 0x19001b09, 0x3c00381a,   // na.aa.un_660 hu.pl.un_530  tr.gl.un_440 tk.ug.un_760 
  0x040a1707, 0x3b422302, 0x303b5855, 0x1b353408,   // sr.mk.ru_432 ca.co.so_222  om.so.uz_442 xh.zu.tr_443 
  0x30481008, 0x09001214, 0x3d21300d, 0x16173207,   // lt.tt.uz_443 hu.pl.un_660  uz.fa.ku_554 bs.sr.hr_432 
  // [58b0]
  0x5500300d, 0x080238a9, 0xfc1f5207, 0x48002a05,   // uz.rw.un_540 tk.da.no_544  ha.cy.zzp_432 mt.tt.un_330 
  0x3900fc02, 0x0213080c, 0x3f005819, 0x26000108,   // zzp.br.un_220 no.et.da_543  om.af.un_750 en.ia.un_430 
  0x36471811, 0x2d001004, 0x2f1dfc09, 0x36000d08,   // ga.sn.gn_653 lt.sk.un_320  zzp.la.su_444 cs.gn.un_430 
  0x02001f14, 0x0438fca4, 0x1500600c, 0x182123a0,   // cy.da.un_660 zzp.tk.fi_433  vo.un.un_530 ky.fa.ar_322 
  // [58c0]
  0x343c230d, 0x0d1c09af, 0x21343d12, 0xfc004d22,   // ky.ug.ps_554 hi.mr.ne_655  ku.ps.fa_654 aa.zzp.un_870 
  0x303bfcec, 0x281812a0, 0xfc003b0c, 0x483c37af,   // zzp.so.uz_644 ur.ar.sd_322  so.zzp.un_530 ba.ug.tt_655 
  0x2f3bfcac, 0x383c3508, 0x3879fcad, 0x44353008,   // zzp.so.su_632 tg.ug.tk_443  zzp.war.tk_643 uz.tg.kk_443 
  0x644f38ad, 0x4dfc3b0c, 0x2e2909ac, 0x3b00fc1a,   // tk.bi.lg_643 so.zzp.aa_543  pl.sl.fo_632 zzp.so.un_760 
  // [58d0]
  0x15153cec, 0x3b000905, 0x04103b11, 0x4f137612,   // ug.un.un_640 pl.so.un_330  so.lt.fi_653 crs.et.bi_654 
  0x38fc3008, 0x04000711, 0x2e0e3f05, 0x3000fc07,   // uz.zzp.tk_443 bg.ru.un_630  af.is.fo_333 zzp.uz.un_420 
  0x0a00150e, 0x4600fc09, 0x131b3ba0, 0xfc3b1aa0,   // un.mk.un_550 zzp.qu.un_440  so.tr.et_322 tl.so.zzp_322 
  0x02290907, 0x05004d0e, 0x3b2e0908, 0x5f005d02,   // pl.sl.da_432 aa.fr.un_550  pl.fo.so_443 ss.tn.un_220 
  // [58e0]
  0x2d0d5602, 0x052253a7, 0x08043507, 0x04370755,   // mg.cs.sk_222 ht.oc.fr_532  tg.ru.uk_432 bg.ba.ru_442 
  0x234830a0, 0x04002502, 0x054b6aa9, 0x05006313,   // uz.tt.ky_322 mn.ru.un_220  haw.mi.fr_544 sco.fr.un_650 
  0x3c383514, 0x39491ca4, 0x303c23ad, 0x07051112,   // tg.tk.ug_666 id.to.br_433  ky.ug.uz_643 ro.fr.it_654 
  0x4b006a35, 0x5a006a18, 0x2b005004, 0x341b2807,   // haw.mi.un_A90 haw.sm.un_740  fj.vi.un_320 sw.tr.xh_432 
  // [58f0]
  0x07041504, 0x1d000723, 0x0f601011, 0x1d50420d,   // un.ru.bg_332 it.la.un_880  lt.vo.lv_653 co.fj.la_554 
  0x052d0d04, 0x44183407, 0x0b100a08, 0x6000101a,   // cs.sk.fr_332 ps.ar.kk_432  pt.lt.es_443 lt.vo.un_760 
  0x20002a23, 0x2b4c360c, 0x0c001f13, 0x21343d11,   // mt.sq.un_880 gn.wo.vi_543  cy.sv.un_650 ku.ps.fa_653 
  0x091c0d0d, 0x1000602a, 0x170f1011, 0x3b186511,   // ne.mr.hi_554 vo.lt.un_970  lt.lv.sr_653 gv.ga.so_653 
  // [5900]
  0x1b200da0, 0x60002223, 0x3d003c09, 0x385821a0,   // cs.sq.tr_322 oc.vo.un_880  ug.ku.un_440 jw.om.tk_322 
  0x562d0d04, 0x071d5aaf, 0x32003004, 0x13005626,   // cs.sk.mg_332 sm.la.it_655  uz.bs.un_320 mg.et.un_930 
  0x370430a0, 0x0000261c, 0x15101708, 0x34281214,   // uz.ru.ba_322 ia.un.un_800  sr.be.un_443 ur.sd.ps_666 
  0x5a5049ad, 0x33082b05, 0x02000602, 0x0d5c1ca4,   // to.fj.sm_643 vi.no.nn_333  de.da.un_220 mr.sa.ne_433 
  // [5910]
  0x2e210ea0, 0x56002c08, 0xfe344dad, 0x646968ec,   // is.jw.fo_322 fy.mg.un_430  aa.xh.tlh_643 ig.mfe.lg_644 
  0x10000f1b, 0x17003509, 0x0f1510a4, 0x353823af,   // lv.lt.un_770 tg.sr.un_440  lt.lv.un_430 ky.tk.tg_655 
  0x0c002e09, 0x08303512, 0x3421180d, 0x1a0f1055,   // fo.sv.un_440 tg.uz.uk_654  ar.fa.ps_554 lt.lv.tl_442 
  0x34002111, 0x10003207, 0x32001007, 0x32171005,   // fa.ps.un_630 bs.lt.un_420  lt.bs.un_420 lt.sr.bs_333 
  // [5920]
  0x3217100c, 0x350434a4, 0x53352807, 0x2d001208,   // lt.sr.bs_543 xh.fi.zu_433  sw.zu.ht_432 hu.sk.un_430 
  0x5400501a, 0x6455500c, 0x321710ec, 0x321729af,   // fj.ik.un_760 fj.rw.lg_543  lt.sr.bs_644 sl.sr.bs_655 
  0x08001018, 0x302112a4, 0x484404ee, 0x64355104,   // be.uk.un_740 ur.fa.uz_433  ru.kk.tt_422 kl.zu.lg_332 
  0x2864550c, 0x13595513, 0x181228a0, 0x25230402,   // rw.lg.sw_543 rw.rn.et_665  sd.ur.ar_322 ru.ky.mn_222 
  // [5930]
  0x1d004208, 0x1d002504, 0x25234467, 0x483025ad,   // co.la.un_430 eu.la.un_320  kk.ky.mn_775 mn.uz.tt_643 
  0x39001104, 0x73353455, 0x353455a4, 0x04100aa7,   // ro.br.un_320 xh.zu.ny_442  rw.xh.zu_433 mk.be.ru_532 
  0x070a1760, 0x287359a7, 0x234438a9, 0x15003902,   // sr.mk.bg_664 rn.ny.sw_532  tk.kk.ky_544 br.un.un_220 
  0x440448a0, 0x37232512, 0x59005719, 0x42122d07,   // tt.ru.kk_322 mn.ky.ba_654  na.rn.un_750 sk.hu.co_432 
  // [5940]
  0x734745a4, 0x05000a04, 0x47595511, 0x42000407,   // ln.sn.ny_433 pt.fr.un_320  rw.rn.sn_653 fi.co.un_420 
  0x28005913, 0x122130a7, 0x17002908, 0x79006b14,   // rn.sw.un_650 uz.fa.ur_532  sl.sr.un_430 ceb.war.un_660 
  0x30001502, 0x5a00670c, 0x6500fe04, 0x1000290d,   // un.uz.un_220 ak.sm.un_530  tlh.gv.un_320 sl.lt.un_540 
  0x18442307, 0x12003907, 0xfc4830a6, 0x3f6540ec,   // ky.kk.ar_432 br.hu.un_420  uz.tt.zzp_521 lb.gv.af_644 
  // [5950]
  0x48003013, 0x4000040d, 0x49006e04, 0x23153811,   // uz.tt.un_650 fi.lb.un_540  hmn.to.un_320 tk.ky.un_630 
  0x15003814, 0x2d0d12a9, 0x362d0d04, 0x28123407,   // tk.un.un_660 hu.cs.sk_544  cs.sk.gn_332 ps.ur.sd_432 
  0x400365a7, 0x03654007, 0x2d0d17ee, 0x370365a0,   // gv.nl.lb_532 lb.gv.nl_432  sr.cs.sk_422 gv.nl.st_322 
  0x3f4003ad, 0x403f0408, 0x0865330c, 0x65153ba9,   // nl.lb.af_643 fi.af.lb_443  nn.gv.no_543 so.gv.un_540 
  // [5960]
  0x0a372308, 0x47002a14, 0x655363a9, 0x6400730e,   // ky.ba.mk_443 mt.sn.un_660  sco.ht.gv_544 ny.lg.un_550 
  0x23480aa0, 0x6953640c, 0x2c1165ee, 0x736476a4,   // mk.tt.ky_322 lg.ht.mfe_543  gv.ro.fy_422 crs.lg.ny_433 
  0x10001709, 0x474057ad, 0x3b39480c, 0x1700290d,   // sr.lt.un_440 na.lb.sn_643  tt.br.so_543 sl.sr.un_540 
  0x31001b2b, 0x0e252e0c, 0x133f65af, 0x114830a4,   // tr.az.un_980 fo.eu.is_543  gv.af.et_655 uz.tt.ro_433 
  // [5970]
  0x15000805, 0x252e0e07, 0x290f2d07, 0x59550614,   // uk.un.un_330 is.fo.eu_432  sk.lv.sl_432 de.rw.rn_666 
  0x0a1744af, 0x0000591c, 0x1537480c, 0x2500300e,   // kk.sr.mk_655 rn.un.un_800  tt.ba.un_543 uz.mn.un_550 
  0x16000f16, 0x51000404, 0x513676a7, 0x32160fa0,   // lv.hr.un_720 fi.kl.un_320  crs.gn.kl_532 lv.hr.bs_322 
  0x193622a4, 0x443837ad, 0x2932170c, 0x1632170d,   // oc.gn.gl_433 ba.tk.kk_643  sr.bs.sl_543 sr.bs.hr_554 
  // [5980]
  0x3530380d, 0x15003521, 0x381afc07, 0x4dfc460d,   // tk.uz.tg_554 tg.un.un_860  zzp.tl.tk_432 qu.zzp.aa_554 
  0x170a3002, 0xfc283ba0, 0x3000fc21, 0x3000fc12,   // uz.mk.sr_222 so.sw.zzp_322  zzp.uz.un_860 zzp.uz.un_640 
  0x6b3bfc12, 0x4c00fc21, 0x1a00fc1a, 0x21003d14,   // zzp.so.ceb_654 zzp.wo.un_860  zzp.tl.un_760 ku.fa.un_660 
  0x1a003b08, 0x0f002d08, 0x36000207, 0x30002105,   // so.tl.un_430 sk.lv.un_430  da.gn.un_420 fa.uz.un_330 
  // [5990]
  0x07350404, 0x3800fc08, 0x5f024ba4, 0x20004c12,   // ru.tg.bg_332 zzp.tk.un_430  mi.da.tn_433 wo.sq.un_640 
  0x3179fca7, 0x1f006907, 0x4c3bfcec, 0x6550290d,   // zzp.war.az_532 mfe.cy.un_420  zzp.so.wo_644 sl.fj.gv_554 
  0x5330fc02, 0x40502a07, 0x24004c12, 0x1c001e2b,   // zzp.uz.ht_222 mt.fj.lb_432  wo.eo.un_640 ms.id.un_980 
  0x353412ec, 0x2e00201f, 0x1f004219, 0x2e565cee,   // hu.xh.zu_644 sq.fo.un_840  co.cy.un_750 sa.mg.fo_422 
  // [59a0]
  0x482a50a4, 0xfc303bad, 0x181efc02, 0x070430a7,   // fj.mt.tt_433 so.uz.zzp_643  zzp.ms.ga_222 uz.ru.bg_532 
  0x2400521a, 0x1f0f58a4, 0x1f513907, 0x53002011,   // ha.eo.un_760 om.lv.cy_433  br.kl.cy_432 sq.ht.un_630 
  0x17320da0, 0x56003b02, 0x46004c07, 0x64fc68a4,   // cs.bs.sr_322 so.mg.un_220  wo.qu.un_420 ig.zzp.lg_433 
  0x56383005, 0x65002809, 0x39003402, 0x3f3b4004,   // uz.tk.mg_333 sw.gv.un_440  xh.br.un_220 lb.so.af_332 
  // [59b0]
  0x4500060c, 0x583b0412, 0x64343507, 0x22002104,   // de.ln.un_530 fi.so.om_654  zu.xh.lg_432 jw.oc.un_320 
  0x42004b13, 0x21002a19, 0x2200200c, 0x23004814,   // mi.co.un_650 mt.jw.un_750  sq.oc.un_530 tt.ky.un_660 
  0x464c4ba7, 0x79061dad, 0x4b4e5208, 0x2f430a13,   // mi.wo.qu_532 la.de.war_643  ha.ay.mi_443 pt.ie.su_665 
  0x653f3bee, 0x230b0a08, 0x0b061da9, 0x03003b07,   // so.af.gv_422 pt.es.ca_443  la.de.es_544 so.nl.un_420 
  // [59c0]
  0x033f4012, 0x3e0657ac, 0x4c2f45a0, 0x0c2a5002,   // lb.af.nl_654 na.de.rm_632  ln.su.wo_322 fj.mt.sv_222 
  0x13005802, 0x2f0a2d0c, 0x4000050d, 0x213d300c,   // om.et.un_220 sk.pt.su_543  fr.lb.un_540 uz.ku.fa_543 
  0x2100230d, 0x1c13090b, 0x17291008, 0x3516250c,   // ca.jw.un_540 hi.bh.mr_542  lt.sl.sr_443 eu.hr.zu_543 
  0x22000509, 0x0f3f10ec, 0x60000909, 0x343d2155,   // fr.oc.un_440 lt.af.lv_644  pl.vo.un_440 fa.ku.ps_442 
  // [59d0]
  0x0f162907, 0x652c0fee, 0x03792c05, 0x2c3f04a7,   // sl.hr.lv_432 lv.fy.gv_422  fy.war.nl_333 fi.af.fy_532 
  0x343d30ee, 0x2f002213, 0x3e000e0d, 0x020d1555,   // uz.ku.ps_422 oc.su.un_650  is.rm.un_540 un.cs.da_442 
  0x234005ee, 0x373044ee, 0x12213cee, 0x350730a4,   // fr.lb.ca_422 kk.uz.ba_422  ug.fa.ur_422 uz.bg.tg_433 
  0x120d4da7, 0x18122d04, 0x0e2d1207, 0x07003608,   // aa.cs.hu_532 sk.hu.ga_332  hu.sk.is_432 ab.bg.un_430 
  // [59e0]
  0x343b2155, 0x3c00230b, 0x48353011, 0x466a1e0b,   // fa.ks.ps_442 ky.ug.un_520  uz.tg.tt_653 ms.haw.qu_542 
  0x6a001e08, 0x0500390c, 0x2500380c, 0x4b5047a9,   // ms.haw.un_430 br.fr.un_530  tk.mn.un_530 sn.fj.mi_544 
  0x2f4e1e08, 0x0e122d0c, 0x73096b0d, 0x152538a4,   // ms.ay.su_443 sk.hu.is_543  ceb.pl.ny_554 tk.mn.un_433 
  0x2c0e2e0c, 0x4d000d0d, 0x172304a9, 0x2ffc52ee,   // fo.is.fy_543 cs.aa.un_540  ru.ky.sr_544 ha.zzp.su_422 
  // [59f0]
  0x796b1ca4, 0x02120404, 0x034d04a4, 0x12000d09,   // id.ceb.war_433 fi.hu.da_332  fi.aa.nl_433 cs.hu.un_440 
  0x3312040c, 0x641e12a7, 0x46122d07, 0x79645209,   // fi.hu.nn_543 hu.ms.lg_532  sk.hu.qu_432 ha.lg.war_444 
  0x213f0255, 0x0a2223af, 0xfc50470d, 0x4423480c,   // da.af.jw_442 ca.oc.pt_655  sn.fj.zzp_554 tt.ky.kk_543 
  0x35005d04, 0x1a461ea4, 0x23003622, 0x6a464e08,   // ss.zu.un_320 ms.qu.tl_433  ab.ky.un_870 ay.qu.haw_443 
  // [5a00]
  0x46504e13, 0x3f211207, 0x0e0412ee, 0x04001205,   // ay.fj.qu_665 hu.jw.af_432  hu.fi.is_422 hu.fi.un_330 
  0x06355d5a, 0x2300442a, 0x0a1715ee, 0x3c00180b,   // ss.zu.de_553 kk.ky.un_970  un.sr.mk_422 ar.ug.un_520 
  0x15081508, 0x3500250e, 0x30122111, 0x4448375a,   // un.uk.un_443 mn.tg.un_550  fa.ur.uz_653 ba.tt.kk_553 
  0x28342304, 0x3c113508, 0x303748a4, 0x3c070a12,   // ky.ps.sd_332 tg.ro.ug_443  tt.ba.uz_433 mk.bg.ug_654 
  // [5a10]
  0x0d00450c, 0x171629a9, 0x4800150b, 0x17113805,   // ln.cs.un_530 sl.hr.sr_544  un.tt.un_520 tk.ro.sr_333 
  0x36194507, 0x190d2d0b, 0x34002305, 0x090d5ca7,   // ln.gl.gn_432 sk.cs.gl_542  ky.ps.un_330 sa.ne.hi_532 
  0x020d2da7, 0x15100412, 0x213430af, 0x290f10a0,   // sk.cs.da_532 ru.be.un_654  uz.ps.fa_655 lt.lv.sl_322 
  0x0a0415a7, 0x25351104, 0x24003907, 0x35343705,   // un.ru.mk_532 ro.tg.mn_332  br.eo.un_420 st.xh.zu_333 
  // [5a20]
  0x37005e13, 0x07360a05, 0x24006404, 0x04350a07,   // ts.st.un_650 mk.ab.bg_333  lg.eo.un_320 mk.tg.ru_432 
  0x022913a0, 0x64003402, 0x353464af, 0x026308a0,   // et.sl.da_322 xh.lg.un_220  lg.xh.zu_655 no.sco.da_322 
  0x1f6511ad, 0x2c3f0304, 0x55003904, 0x07171502,   // ro.gv.cy_643 nl.af.fy_332  br.rw.un_320 un.sr.bg_222 
  0x3d2821a4, 0x65004a05, 0x1f391e07, 0x4035faec,   // fa.sd.ku_433 yo.gv.un_330  ms.br.cy_432 nr.zu.lb_644 
  // [5a30]
  0x5c0913a0, 0x040807ee, 0x09293802, 0x67001321,   // bh.hi.sa_322 bg.uk.ru_422  tk.sl.pl_222 et.ak.un_860 
  0x35734a0c, 0x2a004808, 0x1d113504, 0x1922230e,   // yo.ny.zu_543 tt.mt.un_430  zu.ro.la_332 ca.oc.gl_555 
  0x2318445a, 0x17292d0c, 0x67377509, 0x15384804,   // kk.ar.ky_553 sk.sl.sr_543  nso.st.ak_444 tt.tk.un_332 
  0x0c29020c, 0x32004008, 0x03584ca0, 0x20001f08,   // da.sl.sv_543 lb.bs.un_430  wo.om.nl_322 cy.sq.un_430 
  // [5a40]
  0x07102ea0, 0x0a0708a0, 0x303c23af, 0x4700350c,   // fo.lt.it_322 uk.bg.mk_322  ky.ug.uz_655 zu.sn.un_530 
  0x30001009, 0x312a300c, 0x0417150c, 0x04003e18,   // be.uz.un_440 uz.mt.az_543  un.sr.ru_543 rm.fi.un_740 
  0x06001904, 0x0f6810a9, 0x322d1609, 0x343b210c,   // gl.de.un_320 lt.ig.lv_544  hr.sk.bs_444 fa.ks.ps_543 
  0x31583b05, 0x730667ee, 0x2f00220d, 0x2a00390b,   // so.om.az_333 ak.de.ny_422  oc.su.un_540 dz.bo.un_520 
  // [5a50]
  0x28002702, 0x301234ec, 0x30002307, 0x5a004914,   // gd.sw.un_220 ps.ur.uz_644  ky.uz.un_420 to.sm.un_660 
  0x2d002904, 0x44253c55, 0x0f001016, 0x18343c0b,   // sl.sk.un_320 ug.mn.kk_442  lt.lv.un_720 ug.ps.ar_542 
  0x22003605, 0x503f2855, 0x040a170d, 0x4800300c,   // gn.oc.un_330 sw.af.fj_442  sr.mk.ru_554 uz.tt.un_530 
  0x6800550d, 0x55594fa7, 0x17001512, 0x38002104,   // rw.ig.un_540 bi.rn.rw_532  un.sr.un_640 jw.tk.un_320 
  // [5a60]
  0x04350705, 0x55003f0c, 0x1b003014, 0x31301b07,   // bg.tg.ru_333 af.rw.un_530  uz.tr.un_660 tr.uz.az_432 
  0x5d35735a, 0x04301b12, 0x2d004602, 0x1b003008,   // ny.zu.ss_553 tr.uz.fi_654  qu.sk.un_220 uz.tr.un_430 
  0x46002302, 0x30481b02, 0x353454a9, 0x30001b05,   // ca.qu.un_220 tr.tt.uz_222  ik.xh.zu_544 tr.uz.un_330 
  0x311b300b, 0x28005508, 0x2834550c, 0x0700250c,   // uz.tr.az_542 rw.sw.un_430  rw.xh.sw_543 mn.bg.un_530 
  // [5a70]
  0x477328a0, 0x31301b0d, 0x2305220c, 0x3f595560,   // sw.ny.sn_322 tr.uz.az_554  oc.fr.ca_543 rw.rn.af_664 
  0x644573a4, 0x54735d0c, 0x123d21af, 0x621e1c0d,   // ny.ln.lg_433 ss.ny.ik_543  fa.ku.ur_655 id.ms.kha_554 
  0x06006405, 0x1b00300c, 0x3b001304, 0x5e007307,   // lg.de.un_330 uz.tr.un_530  et.so.un_320 ny.ts.un_420 
  0x0d001f09, 0x6b3b1d07, 0x30481b0c, 0x31301b12,   // cy.cs.un_440 la.so.ceb_432  tr.tt.uz_543 tr.uz.az_654 
  // [5a80]
  0x27004707, 0x1b00460b, 0x483715a9, 0x683747a4,   // sn.gd.un_420 qu.tr.un_520  un.ba.tt_544 sn.st.ig_433 
  0x644c5808, 0x120b05af, 0x21003b08, 0x5e737805,   // om.wo.lg_443 fr.es.hu_655  so.jw.un_430 ve.ny.ts_333 
  0x15460c04, 0x51001105, 0x03201707, 0x23000b02,   // sv.qu.un_332 ro.kl.un_330  sr.sq.nl_432 es.ca.un_220 
  0x15004005, 0x2d0d0505, 0x303525a0, 0x595537ac,   // lb.un.un_330 fr.cs.sk_333  mn.tg.uz_322 st.rw.rn_632 
  // [5a90]
  0x2b001d02, 0x3b6558a9, 0x17003704, 0x1d035f0c,   // la.vi.un_220 om.gv.so_544  ba.sr.un_320 tn.nl.la_543 
  0x04003b1a, 0x3b082c07, 0x01341512, 0x03023007,   // so.fi.un_760 fy.no.so_432  un.xh.en_654 uz.da.nl_432 
  0x286459a0, 0x153c110c, 0x4838370d, 0x25001121,   // rn.lg.sw_322 ro.ug.un_543  ba.tk.tt_554 ro.mn.un_860 
  0x232537a4, 0x12003d12, 0x442337a0, 0x2d360d55,   // ba.mn.ky_433 ku.ur.un_640  ba.ky.kk_322 cs.gn.sk_442 
  // [5aa0]
  0x3048380d, 0x3748230c, 0x081504a9, 0x21003014,   // tk.tt.uz_554 ky.tt.ba_543  ru.uk.un_540 uz.fa.un_660 
  0x0a071008, 0x0a00120c, 0x150408a4, 0x1037380c,   // be.bg.mk_443 hu.pt.un_530  uk.ru.un_433 tk.ba.be_543 
  0x34006119, 0x2d184d0d, 0x47003407, 0x251517ad,   // za.xh.un_750 aa.ga.sk_554  xh.sn.un_420 sr.mn.un_630 
  0xfc002411, 0x49000f0c, 0x23001002, 0x07350807,   // eo.zzp.un_630 lv.to.un_530  be.ky.un_220 uk.tg.bg_432 
  // [5ab0]
  0x48003019, 0x4400480e, 0x49005a09, 0x20002102,   // uz.tt.un_750 tt.kk.un_550  sm.to.un_440 jw.sq.un_220 
  0x30000a0c, 0x281234a0, 0x0400fc20, 0x3b002119,   // mk.uz.un_530 ps.ur.sd_322  zzp.fi.un_850 fa.ks.un_750 
  0x48003509, 0x303b65a7, 0x3800441a, 0x2300350e,   // tg.tt.un_440 gv.so.uz_532  kk.tk.un_760 tg.ky.un_550 
  0x345f37a9, 0x46003608, 0x46051f0c, 0x0400050d,   // st.tn.xh_544 gn.qu.un_430  cy.fr.qu_543 fr.fi.un_540 
  // [5ac0]
  0x3b30315a, 0x15003813, 0x3b2bfca6, 0x4d3bfcad,   // az.uz.so_553 tk.un.un_650  zzp.vi.so_521 zzp.so.aa_643 
  0x123428a7, 0x3b00560b, 0xfc004d2a, 0x353445a4,   // sd.ps.ur_532 mg.so.un_520  aa.zzp.un_970 ln.xh.zu_433 
  0x4315010c, 0x2f3bfc08, 0x4d00fc20, 0x3500250d,   // en.ie.un_530 zzp.so.su_443  zzp.aa.un_850 mn.tg.un_540 
  0x2a4c6308, 0x30006507, 0x440a10ec, 0x342535af,   // sco.wo.mt_443 gv.uz.un_420  be.mk.kk_644 zu.eu.xh_655 
  // [5ad0]
  0x3b00fc08, 0x3b001a1a, 0x29007312, 0x56003b12,   // zzp.so.un_430 tl.so.un_760  ny.sl.un_640 so.mg.un_640 
  0x210218ad, 0x0a10350c, 0xfc003b0d, 0x23795eec,   // ga.da.jw_643 tg.be.mk_543  so.zzp.un_540 ts.war.ca_644 
  0x34005f04, 0x52684c0d, 0x0a222308, 0x0c190b08,   // tn.xh.un_320 wo.ig.ha_554  ca.oc.pt_443 es.gl.sv_443 
  0x5a506aa9, 0x5e4a5013, 0x3bfc4d13, 0x6a495aaf,   // haw.fj.sm_544 fj.yo.ts_665  aa.zzp.so_665 sm.to.haw_655 
  // [5ae0]
  0x2dfc3b0b, 0x52424cad, 0x4c3bfc08, 0x4c00fc19,   // so.zzp.sk_542 wo.co.ha_643  zzp.so.wo_443 zzp.wo.un_750 
  0x5c091c04, 0x6b684c12, 0x2011305a, 0xfc003b09,   // mr.hi.sa_332 wo.ig.ceb_654  uz.ro.sq_553 so.zzp.un_440 
  0x5e524caf, 0x022a5e12, 0x08170aee, 0x48003111,   // wo.ha.ts_655 ts.mt.da_654  mk.sr.uk_422 az.tt.un_630 
  0x275e7812, 0x02000a0c, 0x695c530d, 0x0302feac,   // ve.ts.gd_654 pt.da.un_530  ht.sa.mfe_554 tlh.da.nl_632 
  // [5af0]
  0xfe006313, 0x344918a4, 0x76694aaf, 0x455f43a7,   // sco.tlh.un_650 ga.to.xh_433  yo.mfe.crs_655 ie.tn.ln_532 
  0x5a03490d, 0x735d010c, 0xfc640207, 0x393b40a0,   // to.nl.sm_554 en.ss.ny_543  da.lg.zzp_432 lb.so.br_322 
  0x353409a4, 0x331d6a04, 0x18656304, 0x40006a05,   // pl.xh.zu_433 haw.la.nn_332  sco.gv.ga_332 haw.lb.un_330 
  0x1c006507, 0x040838a0, 0x28181211, 0x1103fca7,   // gv.id.un_420 tk.uk.ru_322  ur.ar.sd_653 zzp.nl.ro_532 
  // [5b00]
  0x06000c07, 0x63570908, 0x063f3808, 0x181d010c,   // sv.de.un_420 pl.na.sco_443  tk.af.de_443 en.la.ga_543 
  0x4c0e01a0, 0x2ffe58a0, 0x4c3573ee, 0x02570107,   // en.is.wo_322 om.tlh.su_322  ny.zu.wo_422 en.na.da_432 
  0x40380407, 0x44100811, 0x18005805, 0x30001714,   // fi.tk.lb_432 uk.be.kk_653  om.ga.un_330 sr.uz.un_660 
  0x0c002c25, 0x17111004, 0x214d73a4, 0x10004804,   // fy.sv.un_920 be.ro.sr_332  ny.aa.jw_433 tt.be.un_320 
  // [5b10]
  0x3e7942a9, 0x35302504, 0x35345dee, 0xfc002c09,   // co.war.rm_544 mn.uz.tg_332  ss.xh.zu_422 fy.zzp.un_440 
  0x0d5c0904, 0x5130130c, 0x1354510c, 0x59551aa4,   // hi.sa.ne_332 et.uz.kl_543  kl.ik.et_543 tl.rw.rn_433 
  0x2d060daf, 0x54460308, 0x026451af, 0x6b1a1504,   // cs.de.sk_655 nl.qu.ik_443  kl.lg.da_655 un.tl.ceb_332 
  0x12044dee, 0x1a6b5d0c, 0x4a002e04, 0x10001f08,   // aa.fi.hu_422 ss.ceb.tl_543  fo.yo.un_320 cy.lt.un_430 
  // [5b20]
  0x232240ac, 0x64006b02, 0x1200540c, 0x0d7909ad,   // lb.oc.ca_632 ceb.lg.un_220  ik.hu.un_530 pl.war.cs_643 
  0x0451130e, 0x2d000208, 0x5108330c, 0x07000207,   // et.kl.fi_555 da.sk.un_430  nn.no.kl_543 da.it.un_420 
  0x6b021aa0, 0x5c090da0, 0x51021304, 0x02475904,   // tl.da.ceb_322 ne.hi.sa_322  et.da.kl_332 rn.sn.da_332 
  0x213d30a4, 0x021a640d, 0x313530a9, 0x02002e09,   // uz.ku.fa_433 lg.tl.da_554  uz.zu.az_544 fo.da.un_440 
  // [5b30]
  0x3b2134a4, 0x36443ca4, 0x0c006204, 0x48002204,   // ps.fa.ks_433 ug.kk.ab_433  kha.sv.un_320 oc.tt.un_320 
  0x251b3ea0, 0x252338a0, 0x5d353409, 0x2f002805,   // rm.tr.eu_322 tk.ky.mn_322  xh.zu.ss_444 sw.su.un_330 
  0x03000904, 0x21006402, 0x21222308, 0x64000204,   // pl.nl.un_320 lg.jw.un_220  ca.oc.jw_443 da.lg.un_320 
  0x21006504, 0xfc59020c, 0x644755a4, 0x1b353404,   // gv.jw.un_320 da.rn.zzp_543  rw.sn.lg_433 xh.zu.tr_332 
  // [5b40]
  0x212f1cac, 0x214c2faf, 0x2200530d, 0x1f01fca4,   // id.su.jw_632 su.wo.jw_655  ht.oc.un_540 zzp.en.cy_433 
  0xfa006408, 0xfc456409, 0x2b006b0c, 0x080233a9,   // lg.nr.un_430 lg.ln.zzp_444  ceb.vi.un_530 nn.da.no_544 
  0x5f1e1c09, 0x52006407, 0x55fc5704, 0x02003802,   // id.ms.tn_444 lg.ha.un_420  na.zzp.rw_332 tk.da.un_220 
  0x40002e04, 0x382544ad, 0x20002108, 0x6300020d,   // fo.lb.un_320 kk.mn.tk_643  jw.sq.un_430 da.sco.un_540 
  // [5b50]
  0x13002013, 0x15081012, 0x5e006409, 0x2f001213,   // sq.et.un_650 be.uk.un_654  lg.ts.un_440 hu.su.un_650 
  0x0400230d, 0x4c002f12, 0x12006714, 0x0a2105a9,   // ky.ru.un_540 su.wo.un_640  ak.hu.un_660 fr.jw.pt_544 
  0x55005812, 0x211b310c, 0x48557909, 0x402f0507,   // om.rw.un_640 az.tr.jw_543  war.rw.tt_444 fr.su.lb_432 
  0x28002f04, 0x21003502, 0x03003f12, 0x350164a4,   // su.sw.un_320 zu.jw.un_220  af.nl.un_640 lg.en.zu_433 
  // [5b60]
  0x040a1004, 0x235321a0, 0x00005903, 0x45002d12,   // be.mk.ru_332 jw.ht.ca_322  rn.un.un_300 sk.ln.un_640 
  0x46005e04, 0x31005805, 0x35001004, 0x5c0d1ca9,   // ts.qu.un_320 om.az.un_330  be.tg.un_320 mr.ne.sa_544 
  0x5c001b04, 0x55000804, 0x65005504, 0x1e001b07,   // tr.sa.un_320 no.rw.un_320  rw.gv.un_320 tr.ms.un_420 
  0x79005c05, 0x37000a02, 0x320f1012, 0x19222f02,   // sa.war.un_330 mk.ba.un_220  lt.lv.bs_654 su.oc.gl_222 
  // [5b70]
  0x595564ec, 0x393618ec, 0x2d0d2f02, 0x0a3015a0,   // lg.rw.rn_644 ga.gn.br_644  su.cs.sk_222 un.uz.mk_322 
  0x3d342104, 0x11483713, 0x08303807, 0x0f303511,   // fa.ps.ku_332 ba.tt.ro_665  tk.uz.uk_432 tg.uz.ta_653 
  0x301844ac, 0x532205a0, 0x34211808, 0x0d004a08,   // kk.ar.uz_632 fr.oc.ht_322  ar.fa.ps_443 yo.cs.un_430 
  0x5c00100c, 0x0b0a19ec, 0x153825ad, 0x30004808,   // lt.sa.un_530 gl.pt.es_644  mn.tk.un_643 tt.uz.un_430 
  // [5b80]
  0x23002212, 0x210f1ba0, 0x0d091302, 0x10005c09,   // oc.ca.un_640 tr.lv.jw_322  bh.hi.ne_222 sa.lt.un_440 
  0x0b0a1902, 0x30211209, 0x7800431b, 0x37003c21,   // gl.pt.es_222 ur.fa.uz_444  ie.ve.un_770 ug.ba.un_860 
  0x35346405, 0x48381b0d, 0x11000d16, 0x043008ad,   // lg.xh.zu_333 tr.tk.tt_554  cs.ro.un_720 uk.uz.ru_643 
  0x350a15a0, 0x21004808, 0x35303608, 0x103738a4,   // un.mk.tg_322 tt.jw.un_430  ab.uz.tg_443 tk.ba.be_433 
  // [5b90]
  0x04073555, 0x0a192207, 0x301b38a0, 0x0a000d0b,   // tg.bg.ru_442 oc.gl.pt_432  tk.tr.uz_322 cs.pt.un_520 
  0x35363012, 0x06040cee, 0x597347ad, 0x08001011,   // uz.ab.tg_654 sv.fi.de_422  sn.ny.rn_643 be.uk.un_630 
  0xfc7364ee, 0x090d1ca4, 0x47007309, 0x341812a7,   // lg.ny.zzp_422 mr.ne.hi_433  ny.sn.un_440 ur.ar.ps_532 
  0x55005934, 0x73004509, 0x56002305, 0x2800590c,   // rn.rw.un_A80 ln.ny.un_440  ca.mg.un_330 rn.sw.un_530 
  // [5ba0]
  0x17290dee, 0x645573a4, 0x29001707, 0x64555912,   // cs.sl.sr_422 ny.rw.lg_433  sr.sl.un_420 rn.rw.lg_654 
  0x73755faf, 0xfc00590c, 0x10440812, 0x37005f07,   // tn.nso.ny_655 rn.zzp.un_530  uk.kk.be_654 tn.st.un_420 
  0x0400300e, 0x552835a9, 0x0a2d0d5a, 0x0a17300e,   // uz.ru.un_550 zu.sw.rw_544  cs.sk.pt_553 uz.sr.mk_555 
  0x23005602, 0x0c0e40a9, 0x00005f15, 0x73595707,   // mg.ca.un_220 lb.is.sv_544  tn.un.un_700 na.rn.ny_432 
  // [5bb0]
  0xfc380c04, 0x280227a9, 0x64575908, 0x19004507,   // sv.tk.zzp_332 gd.da.sw_544  rn.na.lg_443 ln.gl.un_420 
  0x07303505, 0x04006219, 0x6302feec, 0x1f595711,   // tg.uz.bg_333 kha.fi.un_750  tlh.da.sco_644 na.rn.cy_653 
  0x1200300e, 0x477379ad, 0x2d0d3e05, 0x47007319,   // uz.ur.un_550 war.ny.sn_643  rm.cs.sk_333 ny.sn.un_750 
  0x022f3bad, 0x033227a9, 0x00000242, 0x02582712,   // so.su.da_643 gd.bs.nl_544  da.un.un_C00 gd.om.da_654 
  // [5bc0]
  0x1a626512, 0x17000d12, 0x02212808, 0x2b1f0212,   // gv.kha.tl_654 cs.sr.un_640  sw.jw.da_443 da.cy.vi_654 
  0x02206e0c, 0x08100405, 0x08003002, 0x2d1236ad,   // hmn.sq.da_543 ru.be.uk_333  uz.uk.un_220 gn.hu.sk_643 
  0x40001814, 0x37002508, 0x09006822, 0xfe2b0207,   // ga.lb.un_660 mn.ba.un_430  ig.pl.un_870 da.vi.tlh_432 
  0x653f25a6, 0x2c000c0b, 0x4c005812, 0x4c004704,   // eu.af.gv_521 sv.fy.un_520  om.wo.un_640 sn.wo.un_320 
  // [5bd0]
  0x620c6504, 0x651325a0, 0x0e000808, 0x033f6812,   // gv.sv.kha_332 eu.et.gv_322  no.is.un_430 ig.af.nl_654 
  0x67006813, 0x1f670613, 0x4a004209, 0x15170a04,   // ig.ak.un_650 de.ak.cy_665  co.yo.un_440 mk.sr.un_332 
  0x03005811, 0x42000704, 0x1100620d, 0x3f3b5807,   // om.nl.un_630 it.co.un_320  kha.ro.un_540 om.so.af_432 
  0x6b2f57a9, 0x25352307, 0x6b0962ac, 0x1b004007,   // na.su.ceb_544 ky.tg.mn_432  kha.pl.ceb_632 lb.tr.un_420 
  // [5be0]
  0x073e2208, 0x302812a9, 0x4a600655, 0x033f4008,   // oc.rm.it_443 ur.sd.uz_544  de.vo.yo_442 lb.af.nl_443 
  0x40033f0d, 0x3b00520d, 0x602f0f5a, 0x034063ee,   // af.nl.lb_554 ha.so.un_540  lv.su.vo_553 sco.lb.nl_422 
  0x38303ca9, 0x33080e09, 0x5c55500c, 0x38364607,   // ug.uz.tk_544 is.no.nn_444  fj.rw.sa_543 qu.gn.tk_432 
  0x0f003e0c, 0x15003504, 0x2f4d210c, 0x11005602,   // rm.lv.un_530 zu.un.un_320  jw.aa.su_543 mg.ro.un_220 
  // [5bf0]
  0x24001909, 0xfe004d19, 0x2c007904, 0x22473307,   // gl.eo.un_440 aa.tlh.un_750  war.fy.un_320 nn.sn.oc_432 
  0x211c2f05, 0x4d605c12, 0x0e003e04, 0x32001004,   // su.id.jw_333 sa.vo.aa_654  rm.is.un_320 lt.bs.un_320 
  0x56002805, 0x071715a7, 0x1300081a, 0x033f130d,   // sw.mg.un_330 un.sr.bg_532  no.et.un_760 et.af.nl_554 
  0x30374805, 0x0333080c, 0x03793f02, 0x2a4862a4,   // tt.ba.uz_333 no.nn.nl_543  af.war.nl_222 kha.tt.mt_433 
  
  // [5c00]
  0x34006502, 0x12004802, 0x02003308, 0x23000808,   // gv.xh.un_220 tt.hu.un_220  nn.da.un_430 uk.ky.un_430 
  0x0233085a, 0x2d161708, 0x160d2d07, 0x0f00101b,   // no.nn.da_553 sr.hr.sk_443  sk.cs.hr_432 lt.lv.un_770 
  0x07003c0c, 0x171629ec, 0x32790d0c, 0x131c09a4,   // ug.bg.un_530 sl.hr.sr_644  cs.war.bs_543 hi.mr.bh_433 
  0x12002e0e, 0x73004707, 0x0d091c08, 0x1d000202,   // fo.hu.un_550 sn.ny.un_420  mr.hi.ne_443 da.la.un_220 
  // [5c10]
  0x23002221, 0x3534590b, 0x160d0fa0, 0xfc005908,   // oc.ca.un_860 rn.xh.zu_542  lv.cs.hr_322 rn.zzp.un_430 
  0x121821a7, 0x233525a7, 0x1a5134a7, 0x22002309,   // fa.ar.ur_532 mn.tg.ky_532  xh.kl.tl_532 ca.oc.un_440 
  0x28555911, 0x13001b04, 0x514f280c, 0x0c00020b,   // rn.rw.sw_653 tr.et.un_320  sw.bi.kl_543 da.sv.un_520 
  0x5300fe0c, 0x2f477307, 0x0f595555, 0x3673430c,   // tlh.ht.un_530 ny.sn.su_432  rw.rn.lv_442 ie.ny.gn_543 
  // [5c20]
  0x0e595555, 0x135451a4, 0x47461a04, 0x09002002,   // rw.rn.is_442 kl.ik.et_433  tl.qu.sn_332 sq.pl.un_220 
  0x5a4947ee, 0x35003c12, 0x6a004612, 0x556afe08,   // sn.to.sm_422 ug.tg.un_640  qu.haw.un_640 tlh.haw.rw_443 
  0x2f1c1fee, 0x0c222ea0, 0x190b2d0c, 0x1000362a,   // cy.id.su_422 fo.oc.sv_322  sk.es.gl_543 ab.be.un_970 
  0x35341aa0, 0x551f6bac, 0x5d00351a, 0x3900220d,   // tl.xh.zu_322 ceb.cy.rw_632  zu.ss.un_760 oc.br.un_540 
  // [5c30]
  0x3b784e13, 0x28007311, 0x3d3423ee, 0x2300222a,   // ay.ve.so_665 ny.sw.un_630  ky.ps.ku_422 oc.ca.un_970 
  0x071d23a7, 0x1a005e04, 0x02003619, 0x080423ee,   // ca.la.it_532 ts.tl.un_320  gn.da.un_750 ky.ru.uk_422 
  0x5600fc05, 0x5a074207, 0x2f695cec, 0x23303c5a,   // zzp.mg.un_330 co.it.sm_432  sa.mfe.su_644 ug.uz.ky_553 
  0x46491ca0, 0x33020ca0, 0x5c3b5855, 0x46355e04,   // id.to.qu_322 sv.da.nn_322  om.so.sa_442 ts.zu.qu_332 
  // [5c40]
  0x30005102, 0x2800fe1b, 0x23225360, 0x10043502,   // kl.uz.un_220 tlh.sw.un_770  ht.oc.ca_664 tg.ru.be_222 
  0x21391a02, 0x4006250c, 0x09003504, 0x295a46ee,   // tl.br.jw_222 eu.de.lb_543  zu.pl.un_320 qu.sm.sl_422 
  0x23150405, 0xfc003b1a, 0x1d004a02, 0x1c1f57a9,   // ru.ky.un_330 so.zzp.un_760  yo.la.un_220 na.cy.id_544 
  0x464b47a4, 0x151101a4, 0xfc004635, 0x135a46a4,   // sn.mi.qu_433 en.ro.un_433  qu.zzp.un_A90 qu.sm.et_433 
  // [5c50]
  0x5a4b0207, 0x0c3e0107, 0x1d0a6207, 0x62201ea4,   // da.mi.sm_432 en.rm.sv_432  kha.pt.la_432 ms.sq.kha_433 
  0x69761214, 0xfa7934af, 0x785230a4, 0x1c1a1e04,   // hu.crs.mfe_666 xh.war.nr_655  uz.ha.ve_433 ms.tl.id_332 
  0x620b010b, 0x09002902, 0x04004514, 0x5e344e12,   // en.es.kha_542 sl.pl.un_220  ln.fi.un_660 ay.xh.ts_654 
  0x32292d08, 0x34004604, 0x2a001d02, 0x1e1c5ea4,   // sk.sl.bs_443 qu.xh.un_320  la.mt.un_220 ts.id.ms_433 
  // [5c60]
  0x6976330c, 0x20240704, 0x553b5955, 0x16292404,   // nn.crs.mfe_543 it.eo.sq_332  rn.so.rw_442 eo.sl.hr_332 
  0x3b00fc2b, 0x3f321609, 0x4300010d, 0x1a004507,   // zzp.so.un_980 hr.bs.af_444  en.ie.un_540 ln.tl.un_420 
  0x32000207, 0x4600fc20, 0x29001104, 0xfc004607,   // da.bs.un_420 zzp.qu.un_850  ro.sl.un_320 qu.zzp.un_420 
  0x343b2308, 0x23253014, 0x37303504, 0x301828af,   // ky.ks.ps_443 uz.mn.ky_666  tg.uz.ba_332 sd.ar.uz_655 
  // [5c70]
  0x2c003702, 0x11002504, 0x1b00010d, 0x304c0c04,   // st.fy.un_220 eu.ro.un_320  en.tr.un_540 sv.wo.uz_332 
  0x15000a04, 0x09215707, 0x073e42a4, 0x76691caf,   // pt.un.un_320 na.jw.pl_432  co.rm.it_433 id.mfe.crs_655 
  0x0415100d, 0x15013ba0, 0x10321605, 0x30313bee,   // be.ru.un_540 so.en.un_322  hr.bs.lt_333 so.az.uz_422 
  0x211c1e07, 0x5d1811a9, 0x2000fe0d, 0x02002704,   // ms.id.jw_432 ro.ga.ss_544  tlh.sq.un_540 gd.da.un_320 
  // [5c80]
  0x35233012, 0x0000302d, 0x10002d04, 0x0a170402,   // uz.ky.tg_654 uz.un.un_A00  sk.lt.un_320 ru.sr.mk_222 
  0x3e00061a, 0x3015350d, 0x44233d13, 0x0115fca7,   // de.rm.un_760 tg.uz.un_540  ku.ky.kk_665 zzp.en.un_520 
  0x08380405, 0x483715a4, 0x211834af, 0x0704100b,   // ru.tk.uk_333 un.ba.tt_433  ps.ar.fa_655 be.ru.bg_542 
  0x182130af, 0x09130da7, 0x5c130907, 0x0b22230c,   // uz.fa.ar_655 ne.bh.hi_532  hi.bh.sa_432 ca.oc.es_543 
  // [5c90]
  0x190a220e, 0x0c0257a4, 0x10321704, 0x051122ee,   // oc.pt.gl_555 na.da.sv_433  sr.bs.lt_332 oc.ro.fr_422 
  0x3b342112, 0x0c397608, 0x0c652ca7, 0x08043007,   // fa.ps.ks_654 crs.br.sv_443  fy.gv.sv_532 uz.ru.uk_432 
  0x0a4815ec, 0x27002207, 0x2d0d1002, 0x4f000605,   // un.tt.mk_644 oc.gd.un_420  lt.cs.sk_222 de.bi.un_330 
  0x3037380c, 0x25303507, 0x0a170714, 0x2c000335,   // tk.ba.uz_543 tg.uz.mn_432  bg.sr.mk_666 nl.fy.un_A90 
  // [5ca0]
  0x080402a9, 0x39030211, 0x00000337, 0x02610312,   // da.fi.no_544 da.nl.br_653  nl.un.un_B00 nl.za.da_654 
  0x02595560, 0x03534c60, 0x02000323, 0x5c0d13a0,   // rw.rn.da_664 wo.ht.nl_664  nl.da.un_880 bh.ne.sa_322 
  0x020302af, 0x763f6913, 0x39005712, 0x0200490c,   // da.nl.da_655 mfe.af.crs_665  na.br.un_640 to.da.un_530 
  0x091c5c60, 0x29022504, 0x0458020c, 0xfc004613,   // sa.mr.hi_664 eu.da.sl_332  da.om.fi_543 qu.zzp.un_650 
  // [5cb0]
  0x2b2a02a0, 0x46fc3b12, 0x17374860, 0x083038a4,   // da.mt.vi_322 so.zzp.qu_654  tt.ba.sr_664 tk.uz.uk_433 
  0x3bfc4612, 0x1800440c, 0x64004a04, 0x03000209,   // qu.zzp.so_654 kk.ar.un_530  yo.lg.un_320 da.nl.un_440 
  0x2d000334, 0x3044380c, 0x3b00fc12, 0x2a000319,   // nl.sk.un_A80 tk.kk.uz_543  zzp.so.un_640 nl.mt.un_750 
  0x3f283b0c, 0x644b6212, 0x652f03a0, 0x030221a9,   // so.sw.af_543 kha.mi.lg_654  nl.su.gv_322 jw.da.nl_544 
  // [5cc0]
  0x2e38020c, 0x15002f04, 0x621f6a11, 0x403f090c,   // da.tk.fo_543 su.un.un_320  haw.cy.kha_653 pl.af.lb_543 
  0x3c381711, 0x072517a0, 0x3b004011, 0x450964a4,   // sr.tk.ug_653 sr.mn.bg_322  lb.so.un_630 lg.pl.ln_433 
  0x2f3b6307, 0x40004a04, 0x190b23a0, 0x3f2f21a4,   // sco.so.su_432 yo.lb.un_320  ca.es.gl_322 jw.su.af_433 
  0x03080202, 0x35286402, 0x59286407, 0x2a004c07,   // da.no.nl_222 lg.sw.zu_222  lg.sw.rn_432 wo.mt.un_420 
  // [5cd0]
  0x4c005309, 0x4efc3b0c, 0x53fc46ec, 0x4c4b570c,   // ht.wo.un_440 so.zzp.ay_543  qu.zzp.ht_644 na.mi.wo_543 
  0x2f002120, 0x292d0da4, 0x2f4b09a4, 0x2800571b,   // jw.su.un_850 cs.sk.sl_433  pl.mi.su_433 na.sw.un_770 
  0x4b001f07, 0x44100813, 0x2337485a, 0x123d3bee,   // cy.mi.un_420 uk.be.kk_665  tt.ba.ky_553 ks.ku.ur_422 
  0x28006502, 0x15003c19, 0x2300100c, 0x481025ad,   // gv.sw.un_220 ug.un.un_750  be.ky.un_530 mn.be.tt_643 
  // [5ce0]
  0x1c0d5caf, 0x041515ad, 0x42000302, 0x48002512,   // sa.ne.mr_655 un.ru.un_630  nl.co.un_220 mn.tt.un_640 
  0x25004812, 0x042348ad, 0x08361004, 0x44001704,   // tt.mn.un_640 tt.ky.ru_643  be.ab.uk_332 sr.kk.un_320 
  0x12480da0, 0x3d122104, 0x5c1c0dec, 0x130d5c12,   // cs.tt.hu_322 fa.ur.ku_332  ne.mr.sa_644 sa.ne.bh_654 
  0x171507af, 0x2d0d1214, 0x4a00530c, 0x52301ea4,   // bg.sr.un_650 hu.cs.sk_666  ht.yo.un_530 ms.uz.ha_433 
  // [5cf0]
  0x08170aa4, 0x0a07230c, 0x02000e04, 0x372348ee,   // mk.sr.uk_433 ky.bg.mk_543  is.da.un_320 tt.ky.ba_422 
  0x35302304, 0x0600400c, 0x30233c08, 0x17080704,   // ky.uz.tg_332 lb.de.un_530  ug.ky.uz_443 bg.uk.sr_332 
  0x09001f04, 0x25003519, 0x35000707, 0x1b000e02,   // cy.pl.un_320 tg.mn.un_750  bg.tg.un_420 is.tr.un_220 
  0x3d3421a0, 0x1c004b08, 0x5c1737ee, 0x102c3faf,   // fa.ps.ku_322 mi.id.un_430  st.sr.sa_422 af.fy.lt_655 
  // [5d00]
  0x4c007507, 0x0c330812, 0x100415a9, 0x57004c05,   // nso.wo.un_420 no.nn.sv_654  un.ru.be_544 wo.na.un_330 
  0x1d000208, 0x3f002c12, 0x1c174ca0, 0xfc00390c,   // da.la.un_430 fy.af.un_640  wo.sr.id_322 br.zzp.un_530 
  0x2a00100b, 0xfc38020c, 0x39004022, 0x040a08a4,   // lt.mt.un_520 da.tk.zzp_543  lb.br.un_870 uk.mk.ru_433 
  0x59555eaf, 0x55422507, 0x28006819, 0x4a005004,   // ts.rw.rn_655 eu.co.rw_432  ig.sw.un_750 fj.yo.un_320 
  // [5d10]
  0x5f006a0c, 0x64284f07, 0x59557814, 0x3b5c5eec,   // haw.tn.un_530 bi.sw.lg_432  ve.rw.rn_666 ts.sa.so_644 
  0x4a094b13, 0x50211cee, 0x33020812, 0x53007812,   // mi.pl.yo_665 id.jw.fj_422  no.da.nn_654 ve.ht.un_640 
  0x5700022a, 0x0e2a420c, 0x2f002122, 0x22004c04,   // da.na.un_970 co.mt.is_543  jw.su.un_870 wo.oc.un_320 
  0x4a4c02ee, 0x38001004, 0x0a041555, 0x2e08020e,   // da.wo.yo_422 lt.tk.un_320  un.ru.mk_442 da.no.fo_555 
  // [5d20]
  0x4a5564a0, 0x0600fc0d, 0x150c33a0, 0x6400550c,   // lg.rw.yo_322 zzp.de.un_540  nn.sv.un_322 rw.lg.un_530 
  0x595546ee, 0x0a3515ad, 0x6a59550e, 0x1f645507,   // qu.rw.rn_422 un.tg.mk_643  rw.rn.haw_555 rw.lg.cy_432 
  0x21003021, 0x150a1707, 0x645028a0, 0x09022812,   // uz.fa.un_860 sr.mk.un_432  sw.fj.lg_322 sw.da.pl_654 
  0x35345007, 0x33000b20, 0x03002c07, 0x06033f02,   // fj.xh.zu_432 bn.as.un_850  fy.nl.un_420 af.nl.de_222 
  // [5d30]
  0x5c3973ee, 0x55001505, 0x024efc08, 0x0736300c,   // ny.br.sa_422 un.rw.un_330  zzp.ay.da_443 uz.ab.bg_543 
  0x3e004002, 0x34213d13, 0x5f347512, 0x36153f07,   // lb.rm.un_220 ku.fa.ps_665  nso.xh.tn_654 af.gn.un_420 
  0x13333907, 0x0d001708, 0x03643f04, 0x0346fc07,   // br.nn.et_432 sr.cs.un_430  af.lg.nl_332 zzp.qu.nl_432 
  0x10465ca0, 0x04000f08, 0x65003b08, 0x2b04280b,   // sa.qu.lt_322 lv.fi.un_430  so.gv.un_430 sw.fi.vi_542 
  // [5d40]
  0x04002404, 0x42005018, 0x25004e13, 0x2c3f03a0,   // eo.fi.un_320 fj.co.un_740  ay.eu.un_650 nl.af.fy_322 
  0x425013af, 0xfc002d02, 0x135e4207, 0x50130fec,   // et.fj.co_655 sk.zzp.un_220  co.ts.et_432 lv.et.fj_644 
  0x65004209, 0x46002005, 0x15004c1a, 0x03001320,   // co.gv.un_440 sq.qu.un_330  wo.un.un_760 et.nl.un_850 
  0x332a07ec, 0x01635ba0, 0x3800250e, 0x130d09a9,   // it.mt.nn_644 sg.sco.en_322  eu.tk.un_550 hi.ne.bh_544 
  // [5d50]
  0x24420711, 0x3b123d13, 0x113e0107, 0x34352855,   // it.co.eo_653 ku.ur.ks_665  en.rm.ro_432 sw.zu.xh_442 
  0x631d01a7, 0x46004e0e, 0x42005e05, 0x502d4205,   // en.la.sco_532 ay.qu.un_550  ts.co.un_330 co.sk.fj_333 
  0x201d0f5a, 0x07471d07, 0x0d4250ad, 0x1a0f1005,   // lv.la.sq_553 la.sn.it_432  fj.co.cs_643 lt.lv.tl_333 
  0x3f001e21, 0x1b450204, 0x76692609, 0x09292d0b,   // ms.af.un_860 da.ln.tr_332  ia.mfe.crs_444 sk.sl.pl_542 
  // [5d60]
  0xfc0108a0, 0x174345a7, 0x283421ad, 0x1f006912,   // no.en.zzp_322 ln.ie.sr_532  fa.ps.sd_643 mfe.cy.un_640 
  0x2c1a3f08, 0x3f1a620c, 0x321638a0, 0x171f32a0,   // af.tl.fy_443 kha.tl.af_543  tk.hr.bs_322 bs.cy.sr_322 
  0x243052ee, 0x21002f13, 0x49242ead, 0x07250a02,   // ha.uz.eo_422 su.jw.un_650  fo.eo.to_643 mk.mn.bg_222 
  0x32290da4, 0x1b00481b, 0x35004504, 0x16000f07,   // cs.sl.bs_433 tt.tr.un_770  ln.zu.un_320 lv.hr.un_420 
  // [5d70]
  0x35593407, 0x32301705, 0x0a003807, 0x1b48380d,   // xh.rn.zu_432 sr.uz.bs_333  tk.mk.un_420 tk.tt.tr_554 
  0x170f10a4, 0x202d0907, 0x30001309, 0x041035a4,   // lt.lv.sr_433 pl.sk.sq_432  et.uz.un_440 tg.be.ru_433 
  0x322809ee, 0x17131f07, 0x4d00461a, 0x3b35300b,   // pl.sw.bs_422 cy.et.sr_432  qu.aa.un_760 uz.zu.so_542 
  0x1e00300c, 0x062f4aee, 0x23002202, 0x0a00101a,   // uz.ms.un_530 yo.su.de_422  oc.ca.un_220 be.mk.un_760 
  // [5d80]
  0x10003507, 0x381130a4, 0x104408ad, 0x08381155,   // tg.be.un_420 uz.ro.tk_433  uk.kk.be_643 ro.tk.uk_442 
  0x3657fe0c, 0x0d001808, 0x33000e0c, 0xfe0302a9,   // tlh.na.gn_543 ga.cs.un_430  is.nn.un_530 da.nl.tlh_544 
  0x0a1704a4, 0x1d000107, 0x48000413, 0x12000607,   // ru.sr.mk_433 en.la.un_420  fi.tt.un_650 de.hu.un_420 
  0x24032dad, 0x750106a0, 0x600302af, 0x0200fe33,   // sk.nl.eo_643 de.en.nso_322  da.nl.vo_655 tlh.da.un_A70 
  // [5d90]
  0x50001504, 0x6003020b, 0x481530a7, 0x302118ee,   // un.fj.un_320 da.nl.vo_542  uz.tt.un_520 ar.fa.uz_422 
  0x02000314, 0x343d210c, 0x0a0730ee, 0x58004907,   // nl.da.un_660 fa.ku.ps_543  uz.bg.mk_422 to.om.un_420 
  0x02000a14, 0x1508040d, 0x01fe1504, 0x100715ee,   // pt.da.un_660 ru.uk.un_554  un.tlh.en_332 un.bg.be_422 
  0x0d001c0e, 0x10004414, 0xfe02460c, 0x2500380b,   // mr.ne.un_550 kk.be.un_660  qu.da.tlh_543 tk.mn.un_520 
  // [5da0]
  0x0e311b0d, 0x1d004309, 0x23483612, 0x4e2e3b05,   // tr.az.is_554 ie.la.un_440  ab.tt.ky_654 so.fo.ay_333 
  0x5c006a0c, 0x76265309, 0x1b0e400c, 0x34213da4,   // haw.sa.un_530 ht.ia.crs_444  lb.is.tr_543 ku.fa.ps_433 
  0x18002720, 0x5c00fe07, 0x190b1eee, 0x1c38fc0b,   // gd.ga.un_850 tlh.sa.un_420  ms.es.gl_422 zzp.tk.id_542 
  0x3e190b5a, 0x53003902, 0x11000504, 0x151538a7,   // es.gl.rm_553 br.ht.un_220  fr.ro.un_320 tk.un.un_520 
  // [5db0]
  0x307669a9, 0x6965310c, 0x3b3119ee, 0x19005c02,   // mfe.crs.uz_544 az.gv.mfe_543  gl.az.so_422 sa.gl.un_220 
  0x0c002d04, 0x2f1f57ec, 0x2e0e1ca4, 0x1f00270c,   // sk.sv.un_320 na.cy.su_644  id.is.fo_433 gd.cy.un_530 
  0x31690eec, 0x20304ea4, 0x080c5c0c, 0x21005d04,   // is.mfe.az_644 ay.uz.sq_433  sa.sv.no_543 ss.jw.un_320 
  0x38000a21, 0x07002f0b, 0x0a002507, 0x30002502,   // mk.tk.un_860 su.it.un_520  mn.mk.un_420 mn.uz.un_220 
  // [5dc0]
  0x250a07a0, 0x353615ad, 0x00000f2d, 0x557359ec,   // bg.mk.mn_322 un.ab.tg_643  lv.un.un_A00 rn.ny.rw_644 
  0x100a36a0, 0x0e19120c, 0x28003d02, 0x64005723,   // ab.mk.be_322 hu.gl.is_543  ku.sd.un_220 na.lg.un_880 
  0x17383ca0, 0x48003721, 0x0600731a, 0x64005722,   // ug.tk.sr_322 ba.tt.un_860  ny.de.un_760 na.lg.un_870 
  0x041517a6, 0x30003412, 0x23000807, 0x40000407,   // sr.ru.un_510 ps.uz.un_640  uk.ky.un_420 fi.lb.un_420 
  // [5dd0]
  0x18003005, 0x35483002, 0x58004c0e, 0x5700471a,   // uz.ar.un_330 uz.tt.tg_222  wo.om.un_550 sn.na.un_760 
  0x58004c09, 0x355e73a9, 0x3478fa09, 0x211f7804,   // wo.om.un_440 ny.ts.zu_544  nr.ve.xh_444 ve.cy.jw_332 
  0x3b006508, 0x53190a02, 0x281218ec, 0x15400607,   // gv.so.un_430 pt.gl.ht_222  ar.ur.sd_644 de.lb.un_432 
  0x22002007, 0x2f303b04, 0x5d473507, 0x5c347307,   // sq.oc.un_420 so.uz.su_332  zu.sn.ss_432 ny.xh.sa_432 
  // [5de0]
  0x1a796b0d, 0x18002818, 0x383f1fec, 0x0c00060e,   // ceb.war.tl_554 sd.ar.un_740  cy.af.tk_644 de.sv.un_550 
  0x44003808, 0x0a07370c, 0x4c4d58ec, 0x351f7307,   // tk.kk.un_430 st.it.pt_543  om.aa.wo_644 ny.cy.zu_432 
  0x0c570612, 0x245e5fa0, 0x2f096eee, 0x08001802,   // de.na.sv_654 tn.ts.eo_322  hmn.pl.su_422 ga.no.un_220 
  0x060c5712, 0x15002521, 0x783573a9, 0x071535ad,   // na.sv.de_654 mn.un.un_860  ny.zu.ve_544 tg.bg.un_630 
  // [5df0]
  0x190b26a9, 0x1e1c2fa4, 0x10070aa0, 0x24255e04,   // ia.es.gl_544 su.id.ms_433  mk.bg.be_322 ts.eu.eo_332 
  0x06000c0c, 0x4640030c, 0x46353605, 0x06000c08,   // sv.de.un_530 nl.lb.qu_543  gn.zu.qu_333 sv.de.un_430 
  0x245d5e08, 0x645e3413, 0x13033fad, 0x15060c0d,   // ts.ss.eo_443 xh.ts.lg_665  af.nl.et_643 sv.de.un_554 
  0x5c4a4e07, 0x033f1fac, 0x1006210c, 0x1e1c2f0e,   // ay.yo.sa_432 cy.af.nl_632  jw.de.lt_543 su.id.ms_555 
  // [5e00]
  0x4c002407, 0x290c06ad, 0x73246412, 0x2f1c1ea0,   // eo.wo.un_420 de.sv.sl_643  lg.eo.ny_654 ms.id.su_322 
  0x791d260c, 0xfc003505, 0x0b002308, 0x2128120e,   // ia.la.war_543 zu.zzp.un_330  ca.es.un_430 ur.sd.fa_555 
  0x250a0402, 0x123421ec, 0x6000650e, 0x0a001f02,   // ru.mk.mn_222 fa.ps.ur_644  gv.vo.un_550 cy.pt.un_220 
  0x35002302, 0xfc256808, 0x07431d04, 0x2c0410a9,   // ky.tg.un_220 ig.eu.zzp_443  la.ie.it_332 lt.fi.fy_544 
  // [5e10]
  0x391d0904, 0x63090412, 0x0400620e, 0x12283bad,   // pl.la.br_332 fi.pl.sco_654  kha.fi.un_550 ks.sd.ur_643 
  0x40001f14, 0x1b7653a4, 0x34213c04, 0x79091da7,   // cy.lb.un_660 ht.crs.tr_433  ug.fa.ps_332 la.pl.war_532 
  0x38004419, 0x283d30ec, 0x045369af, 0x33003504,   // kk.tk.un_750 uz.ku.sd_644  mfe.ht.fi_655 zu.nn.un_320 
  0x1b001f04, 0x36000412, 0x01361aa7, 0x3c35360c,   // cy.tr.un_320 fi.gn.un_640  tl.gn.en_532 ab.tg.ug_543 
  // [5e20]
  0x56006304, 0x036563a0, 0x6500041a, 0x0100fc02,   // sco.mg.un_320 sco.gv.nl_322  fi.gv.un_760 zzp.en.un_220 
  0x38090407, 0x0a004a09, 0x0c041055, 0x1a0234ad,   // fi.pl.tk_432 yo.pt.un_440  lt.fi.sv_442 xh.da.tl_643 
  0x02305e08, 0x68022804, 0x122845a9, 0x35382304,   // ts.uz.da_443 sw.da.ig_332  ln.sw.hu_544 ky.tk.tg_332 
  0x1a3745ad, 0x1100231a, 0x65003622, 0x583301a0,   // ln.st.tl_643 ky.ro.un_760  gn.gv.un_870 en.nn.om_322 
  // [5e30]
  0x560763ee, 0x3138fc04, 0x2d002c08, 0x3602040c,   // sco.it.mg_422 zzp.tk.az_332  fy.sk.un_430 fi.da.gn_543 
  0x6b76690c, 0x595545a9, 0x65005604, 0x04382cee,   // mfe.crs.ceb_543 ln.rw.rn_544  mg.gv.un_320 fy.tk.fi_422 
  0x59522f05, 0x20005202, 0x1827fc12, 0x18443c08,   // su.ha.rn_333 ha.sq.un_220  zzp.gd.ga_654 ug.kk.ar_443 
  0x375f1ea4, 0x1234180b, 0x080415a4, 0x2a4a56ee,   // ms.tn.st_433 ar.ps.ur_542  un.ru.uk_433 mg.yo.mt_422 
  // [5e40]
  0x38002c04, 0x38002c05, 0x25101702, 0x04602807,   // fy.tk.un_320 fy.tk.un_330  sr.be.mn_222 sw.vo.fi_432 
  0x375e500c, 0x190b3602, 0x0b361955, 0x08006502,   // fj.ts.st_543 gn.es.gl_222  gl.gn.es_442 gv.no.un_220 
  0x3e060304, 0x0b000705, 0x0d002307, 0x2b003202,   // nl.de.rm_332 it.es.un_330  ca.cs.un_420 bs.vi.un_220 
  0x4c070b5a, 0x3b3f03ee, 0x303c35a9, 0x0e001807,   // es.it.wo_553 nl.af.so_422  tg.ug.uz_544 ga.is.un_420 
  // [5e50]
  0x64002502, 0x05004902, 0x3f003904, 0x17331dee,   // eu.lg.un_220 to.fr.un_220  br.af.un_320 la.nn.sr_422 
  0x2e003108, 0x1b3b31a0, 0x11000402, 0x07151104,   // az.fo.un_430 az.so.tr_322  fi.ro.un_220 ro.bg.un_320 
  0x0d001c1b, 0x0e001f02, 0x23303ca7, 0x074837a0,   // mr.ne.un_770 cy.is.un_220  ug.uz.ky_532 ba.tt.bg_322 
  0x2d0f29a4, 0x32620612, 0x2e0e02a4, 0x0a073605,   // sl.lv.sk_433 de.kha.bs_654  da.is.fo_433 ab.bg.mk_333 
  // [5e60]
  0x60001504, 0x03025c0c, 0x05060113, 0x36004c08,   // un.vo.un_320 sa.da.nl_543  en.de.fr_665 wo.gn.un_430 
  0x292d0d60, 0x63060112, 0x03000235, 0x63010604,   // cs.sk.sl_664 en.de.sco_654  da.nl.un_A90 de.en.sco_332 
  0x2b0a4f60, 0x02000335, 0x651f6211, 0x07374811,   // bi.pt.vi_664 nl.da.un_A90  kha.cy.gv_653 tt.ba.bg_653 
  0x2d002c13, 0x02001e0d, 0x01001508, 0x55003405,   // fy.sk.un_650 ms.da.un_540  un.en.un_430 xh.rw.un_330 
  // [5e70]
  0x080a17ee, 0x28001802, 0x063b02af, 0x400106ad,   // sr.mk.uk_422 ga.sw.un_220  da.so.de_655 de.en.lb_643 
  0x070601a0, 0x21003c05, 0x35253008, 0x0a0e2e0e,   // en.de.it_322 ug.fa.un_330  uz.mn.tg_443 fo.is.pt_555 
  0x44483755, 0x281234ad, 0x070a1108, 0x101748a4,   // ba.tt.kk_442 ps.ur.sd_643  ro.mk.bg_443 tt.sr.be_433 
  0x5c002704, 0x170a2308, 0x5c002709, 0x3035150c,   // gd.sa.un_320 ky.mk.sr_443  gd.sa.un_440 un.tg.uz_543 
  // [5e80]
  0x464f5ba4, 0x352515a7, 0x10004405, 0x2c002d02,   // sg.bi.qu_433 un.mn.tg_532  kk.be.un_330 sk.fy.un_220 
  0x391502a7, 0x301535af, 0x35342ba4, 0x303c2312,   // da.br.un_520 tg.uz.un_650  vi.xh.zu_433 ky.ug.uz_654 
  0x30363c08, 0x3815230c, 0x5b003013, 0x070a36a6,   // ug.ab.uz_443 ky.tk.un_530  uz.sg.un_650 ab.mk.bg_521 
  0x37150455, 0x091c13a9, 0x36041507, 0x3c080a08,   // ru.ba.un_420 bh.mr.hi_544  un.ru.ab_432 mk.uk.ug_443 
  // [5e90]
  0x2d002c07, 0x04001011, 0x184a2da7, 0x10007513,   // fy.sk.un_420 be.ru.un_630  sk.yo.ga_532 nso.lt.un_650 
  0x23001905, 0x30003520, 0x303644a4, 0x455d3f08,   // gl.ca.un_330 tg.uz.un_850  kk.ab.uz_433 af.ss.ln_443 
  0x1b00fe0e, 0x311b63a4, 0x391b6405, 0x02522807,   // tlh.tr.un_550 sco.tr.az_433  lg.tr.br_333 sw.ha.da_432 
  0x6500fe07, 0x42002a07, 0x23042504, 0x79501a08,   // tlh.gv.un_420 mt.co.un_420  mn.ru.ky_332 tl.fj.war_443 
  // [5ea0]
  0x3600350d, 0x4d190b13, 0x250407a7, 0x3b311ba4,   // tg.ab.un_540 es.gl.aa_665  bg.ru.mn_532 tr.az.so_433 
  0x3b584c0d, 0x353455a9, 0x47074311, 0x55003704,   // wo.om.so_554 rw.xh.zu_544  ie.it.sn_653 st.rw.un_320 
  0x044807a6, 0x1a7901a0, 0x07424ca4, 0x10003511,   // bg.tt.ru_521 en.war.tl_322  wo.co.it_433 tg.be.un_630 
  0x30343104, 0x1b303102, 0x04005b14, 0x53002308,   // az.xh.uz_332 az.uz.tr_222  sg.fi.un_660 ca.ht.un_430 
  // [5eb0]
  0x4a00530d, 0x222f12a7, 0x09000c04, 0x18281214,   // ht.yo.un_540 hu.su.oc_532  sv.pl.un_320 ur.sd.ar_666 
  0x44001007, 0x05004205, 0x3e234ca0, 0x21292007,   // be.kk.un_420 co.fr.un_330  wo.ca.rm_322 sq.sl.jw_432 
  0x170415ad, 0x630d2da4, 0x0817070d, 0x0c022004,   // un.ru.sr_643 sk.cs.sco_433  bg.sr.uk_554 sq.da.sv_332 
  0x73004621, 0x0f005034, 0x170a30a9, 0x12004a09,   // qu.ny.un_860 fj.lv.un_A80  uz.mk.sr_544 yo.hu.un_440 
  // [5ec0]
  0x73005f09, 0x17601b07, 0x12302108, 0x1d001107,   // tn.ny.un_440 tr.vo.sr_432  fa.uz.ur_443 ro.la.un_420 
  0x3435540c, 0x25303513, 0x1f0d2d07, 0x2000220b,   // ik.zu.xh_543 tg.uz.mn_665  sk.cs.cy_432 oc.sq.un_520 
  0x1269760c, 0x3464730c, 0x03003704, 0x05001212,   // crs.mfe.hu_543 ny.lg.xh_543  st.nl.un_320 hu.fr.un_640 
  0x0c003612, 0x04005b13, 0x20003605, 0x361969a4,   // gn.sv.un_640 sg.fi.un_650  gn.sq.un_330 mfe.gl.gn_433 
  // [5ed0]
  0x22002025, 0x4600300b, 0x12103f08, 0x472812ec,   // sq.oc.un_920 uz.qu.un_520  af.lt.hu_443 hu.sw.sn_644 
  0x20003609, 0x12003612, 0x29171608, 0x5e784705,   // gn.sq.un_440 gn.hu.un_640  hr.sr.sl_443 sn.ve.ts_333 
  0x12000f0c, 0x6b1afea4, 0x4736fca0, 0x32162da0,   // lv.hu.un_530 tlh.tl.ceb_433  zzp.gn.sn_322 sk.hr.bs_322 
  0x183428a6, 0x5c13090c, 0x5a004b08, 0x1d005310,   // sd.ps.ar_521 hi.bh.sa_543  mi.sm.un_430 ht.la.un_620 
  // [5ee0]
  0x110b0aee, 0x64003007, 0x0573fe07, 0x524673a4,   // pt.es.ro_422 uz.lg.un_420  tlh.ny.fr_432 ny.qu.ha_433 
  0x190a2f09, 0x1d002a02, 0x1c2106a0, 0x15080460,   // su.pt.gl_444 mt.la.un_220  de.jw.id_322 ru.uk.un_664 
  0x2f004005, 0x30002809, 0x563f035a, 0xfc3001af,   // lb.su.un_330 sd.uz.un_440  nl.af.mg_553 en.uz.zzp_655 
  0x3b00fc0c, 0x0d00620c, 0x1c2f69ee, 0x2a007304,   // zzp.so.un_530 kha.cs.un_530  mfe.su.id_422 ny.mt.un_320 
  // [5ef0]
  0x2f004511, 0xfc003b0e, 0x02fc42af, 0x21122fa7,   // ln.su.un_630 so.zzp.un_550  co.zzp.da_655 su.hu.jw_532 
  0x3b38fc12, 0x1902fc0c, 0x2f000514, 0xfc001313,   // zzp.tk.so_654 zzp.da.gl_543  fr.su.un_660 et.zzp.un_650 
  0xfc003b21, 0x0d321604, 0x02001708, 0x190a23a0,   // so.zzp.un_860 hr.bs.cs_332  sr.da.un_430 ca.pt.gl_322 
  0x42000502, 0x0e362e02, 0x404505ad, 0x6b3bfc0c,   // fr.co.un_220 fo.gn.is_222  fr.ln.lb_643 zzp.so.ceb_543 
  // [5f00]
  0x0100fc12, 0xfc003b19, 0x4615fcad, 0x08330204,   // zzp.en.un_640 so.zzp.un_750  zzp.qu.un_630 da.nn.no_332 
  0xfc1a3004, 0x44233714, 0x6301fc0c, 0x38001f19,   // uz.tl.zzp_332 ba.ky.kk_666  zzp.en.sco_543 cy.tk.un_750 
  0x191d01a4, 0x62020812, 0xfc330802, 0x2d000904,   // en.la.gl_433 no.da.kha_654  no.nn.zzp_222 pl.sk.un_320 
  0xfc051d07, 0x041517ec, 0x4c000509, 0x44003007,   // la.fr.zzp_432 sr.ru.un_640  fr.wo.un_440 uz.kk.un_420 
  // [5f10]
  0x0200fc09, 0x0207fcaf, 0x04001104, 0x2348370d,   // zzp.da.un_440 zzp.it.da_655  ro.fi.un_320 ba.tt.ky_554 
  0x2f00211a, 0x05003608, 0x2a123002, 0x1e000c04,   // jw.su.un_760 gn.fr.un_430  uz.hu.mt_222 sv.ms.un_320 
  0x07003005, 0x650c1f07, 0x081007ad, 0x630265ad,   // uz.bg.un_330 cy.sv.gv_432  bg.be.uk_643 gv.da.sco_643 
  0x15041760, 0x184c58a0, 0x2d001009, 0x1f003104,   // sr.ru.un_664 om.wo.ga_322  lt.sk.un_440 az.cy.un_320 
  // [5f20]
  0x552059a0, 0x355d30af, 0x3b2f25a4, 0x45000108,   // rn.sq.rw_322 uz.ss.zu_655  eu.su.so_433 en.ln.un_430 
  0x00004303, 0xfc006519, 0x790f6bec, 0x30004208,   // ie.un.un_300 gv.zzp.un_750  ceb.lv.war_644 co.uz.un_430 
  0x2d0d0aa4, 0x133b79ee, 0x296bfc07, 0x02003b04,   // pt.cs.sk_433 war.so.et_422  zzp.ceb.sl_432 so.da.un_320 
  0x524a67af, 0x25000a08, 0x18003c0c, 0x113b1a0c,   // ak.yo.ha_655 mk.mn.un_430  ug.ar.un_530 tl.so.ro_543 
  // [5f30]
  0x5642050b, 0x2f00050b, 0x3c00440c, 0x5000520b,   // fr.co.mg_542 fr.su.un_520  kk.ug.un_530 ha.fj.un_520 
  0x190b25ee, 0x103015a4, 0x36190a02, 0x4a001f05,   // eu.es.gl_422 un.uz.be_433  pt.gl.gn_222 cy.yo.un_330 
  0x0a001008, 0x58003b08, 0x3b005204, 0x1a1b4aad,   // be.mk.un_430 so.om.un_430  ha.so.un_320 yo.tr.tl_643 
  0x3700150c, 0x07153004, 0x3e000e04, 0x23170a13,   // un.ba.un_530 uz.bg.un_320  is.rm.un_320 mk.sr.ky_665 
  // [5f40]
  0x0900790d, 0x1107080c, 0x233d3c08, 0x0e120da4,   // war.pl.un_540 uk.bg.ro_543  ug.ku.ky_443 cs.hu.is_433 
  0x35073c04, 0x042325a6, 0x13090dac, 0x0e000c05,   // ug.bg.tg_332 mn.ky.ru_521  ne.hi.bh_632 sv.is.un_330 
  0x4a001212, 0x13004508, 0x3e072a14, 0x0e2e0212,   // hu.yo.un_640 ln.et.un_430  mt.it.rm_666 da.fo.is_654 
  0x02031ca4, 0x07301507, 0x05060112, 0x18026312,   // id.nl.da_433 un.uz.bg_432  en.de.fr_654 sco.da.ga_654 
  // [5f50]
  0x00004f42, 0x2c036560, 0x372344ee, 0x2a030214,   // bi.un.un_C00 gv.nl.fy_664  kk.ky.ba_422 da.nl.mt_666 
  0x150601a0, 0x600b2313, 0x0400082a, 0x02082aad,   // en.de.un_322 ca.es.vo_665  uk.ru.un_970 mt.no.da_643 
  0x3e18510c, 0x0921030c, 0x18233b12, 0x12002d0d,   // kl.ga.rm_543 nl.jw.pl_543  ks.ky.ar_654 sk.hu.un_540 
  0x050601a0, 0x300a35a4, 0x12000502, 0x0218480c,   // en.de.fr_322 tg.mk.uz_433  fr.hu.un_220 tt.ga.da_543 
  // [5f60]
  0x2103020c, 0x021809ec, 0x30482309, 0x39530505,   // da.nl.jw_543 pl.ga.da_644  ky.tt.uz_444 fr.ht.br_333 
  0xfe150207, 0x02001b23, 0x391148a9, 0x35151112,   // da.tlh.un_420 tr.da.un_880  tt.ro.br_544 ro.tg.un_640 
  0x233c280c, 0x44254807, 0x2f4505a7, 0x23003d0d,   // sd.ug.ky_543 tt.mn.kk_432  fr.ln.su_532 ku.ky.un_540 
  0x2a002f04, 0x4815150d, 0x69600fa4, 0x190b05a0,   // su.mt.un_320 un.tt.un_540  lv.vo.mfe_433 fr.es.gl_322 
  // [5f70]
  0x53006909, 0x5369760d, 0x21000507, 0x3d301205,   // mfe.ht.un_440 crs.mfe.ht_554  fr.jw.un_420 ur.uz.ku_333 
  0x766953ad, 0x30233c05, 0x60005b21, 0x1d070da0,   // ht.mfe.crs_643 ug.ky.uz_333  sg.vo.un_860 cs.it.la_322 
  0x5c006402, 0x53697613, 0x261d0107, 0x5d0e2eaf,   // lg.sa.un_220 crs.mfe.ht_665  en.la.ia_432 fo.is.ss_655 
  0x1d001e05, 0x3f401ca4, 0x53697660, 0x23001820,   // ms.la.un_330 id.lb.af_433  crs.mfe.ht_664 ar.ky.un_850 
  // [5f80]
  0x47646707, 0x122f05a4, 0x38001302, 0x1a76530c,   // ak.lg.sn_432 fr.su.hu_433  et.tk.un_220 ht.crs.tl_543 
  0x05190a08, 0x05004505, 0x640402a4, 0x332e0e04,   // pt.gl.fr_443 ln.fr.un_330  da.fi.lg_433 is.fo.nn_332 
  0x123f48a4, 0x05001217, 0x571c21a4, 0x65000209,   // tt.af.hu_433 hu.fr.un_730  jw.id.na_433 da.gv.un_440 
  0x69765314, 0x330e2e5a, 0x21183405, 0x21125b07,   // ht.crs.mfe_666 fo.is.nn_553  ps.ar.fa_333 sg.hu.jw_432 
  // [5f90]
  0x132a42a0, 0x213f4704, 0x04330804, 0x531e6955,   // co.mt.et_322 sn.af.jw_332  no.nn.fi_332 mfe.ms.ht_442 
  0x332e0e12, 0x0400600d, 0x2c4c1a07, 0x0200120e,   // is.fo.nn_654 vo.fi.un_540  tl.wo.fy_432 hu.da.un_550 
  0x6b006921, 0x6b791a09, 0x091a79a4, 0x2e0e08ee,   // mfe.ceb.un_860 tl.war.ceb_444  war.tl.pl_433 no.is.fo_422 
  0x2f001b04, 0x07080a13, 0x1735150c, 0x3c001811,   // tr.su.un_320 mk.uk.bg_665  un.tg.sr_543 ar.ug.un_630 
  // [5fa0]
  0x12003809, 0x6400120c, 0x05004a0c, 0x12001b02,   // tk.hu.un_440 hu.lg.un_530  yo.fr.un_530 tr.hu.un_220 
  0x3f036405, 0x042112ee, 0x3400fc08, 0x04001207,   // lg.nl.af_333 hu.jw.fi_422  zzp.xh.un_430 hu.fi.un_420 
  0x0a00300d, 0x093b67ad, 0x25070aa4, 0x3428210b,   // uz.mk.un_540 ak.so.pl_643  mk.bg.mn_433 fa.sd.ps_542 
  0x4d004020, 0x35000809, 0x7600692b, 0x21000e12,   // lb.aa.un_850 uk.tg.un_440  mfe.crs.un_980 is.jw.un_640 
  // [5fb0]
  0x35004813, 0x1234280c, 0x170a3504, 0x2d2e0e02,   // tt.tg.un_650 sd.ps.ur_543  tg.mk.sr_332 is.fo.sk_222 
  0x33084eac, 0x111715a9, 0x066401a0, 0x233048a0,   // ay.no.nn_632 un.sr.ro_544  en.lg.de_322 tt.uz.ky_322 
  0x09766912, 0x46005511, 0x30002c14, 0x0a007909,   // mfe.crs.pl_654 rw.qu.un_630  fy.uz.un_660 war.pt.un_440 
  0x05007905, 0x653063a0, 0x1b30460c, 0x0f001112,   // war.fr.un_330 sco.uz.gv_322  qu.uz.tr_543 ro.lv.un_640 
  // [5fc0]
  0x364505a4, 0x39001218, 0x0c064014, 0x53004604,   // fr.ln.gn_433 hu.br.un_740  lb.de.sv_666 qu.ht.un_320 
  0x3d343004, 0x234436af, 0xfc601fa7, 0x06001f04,   // uz.ps.ku_332 ab.kk.ky_655  cy.vo.zzp_532 cy.de.un_320 
  0x5664fc0c, 0x481b4c07, 0x4c4205ac, 0x072f56a9,   // zzp.lg.mg_543 wo.tr.tt_432  fr.co.wo_632 mg.su.it_544 
  0x04000913, 0x2b003502, 0x07043504, 0xfc002202,   // pl.fi.un_650 zu.vi.un_220  tg.ru.bg_332 oc.zzp.un_220 
  // [5fd0]
  0x25001008, 0x35640107, 0x3b345d08, 0x2d0d56ec,   // be.mn.un_430 en.lg.zu_432  ss.xh.so_443 mg.cs.sk_644 
  0x38234409, 0x02004007, 0x31002504, 0x33005613,   // kk.ky.tk_444 lb.da.un_420  eu.az.un_320 mg.nn.un_650 
  0x33132e04, 0x0b0a190e, 0x46003007, 0x18343d13,   // fo.et.nn_332 gl.pt.es_555  uz.qu.un_420 ku.ps.ar_665 
  0x31301bec, 0x560833ec, 0x0e004512, 0x0e210507,   // tr.uz.az_644 nn.no.mg_644  ln.is.un_640 fr.jw.is_432 
  // [5fe0]
  0x4c004612, 0x4d304a0c, 0x46364eee, 0x3efc40a0,   // qu.wo.un_640 yo.uz.aa_543  ay.gn.qu_422 lb.zzp.rm_322 
  0x6500530e, 0x4b0165a0, 0x05002f02, 0xfc002c0e,   // ht.gv.un_550 gv.en.mi_322  su.fr.un_220 fy.zzp.un_550 
  0x4d34fcaf, 0x3b4c460c, 0x1b38310c, 0x31006504,   // zzp.xh.aa_655 qu.wo.so_543  az.tk.tr_543 gv.az.un_320 
  0x2a00130d, 0x0c003202, 0x0c002a04, 0x2239080b,   // et.mt.un_540 bs.sv.un_220  mt.sv.un_320 no.br.oc_542 
  // [5ff0]
  0x18003014, 0x631d010c, 0x73002819, 0x15650108,   // uz.ar.un_660 en.la.sco_543  sw.ny.un_750 en.gv.un_443 
  0x5d593504, 0x15170407, 0x1353fea4, 0x09005609,   // zu.rn.ss_332 ru.sr.un_432  tlh.ht.et_433 mg.pl.un_440 
  0x127909ad, 0x2504080c, 0x2500351a, 0x1d63010c,   // pl.war.hu_643 uk.ru.mn_543  tg.mn.un_760 en.sco.la_543 
  0x2c004604, 0x30022aec, 0x2a006404, 0x2a031211,   // qu.fy.un_320 mt.da.uz_644  lg.mt.un_320 hu.nl.mt_653 
  
  // [6000]
  0x121b4808, 0x24641214, 0x381535ec, 0x4d643b0c,   // tt.tr.hu_443 hu.lg.eo_666  tg.tk.un_640 so.lg.aa_543 
  0x353447ee, 0x02005e05, 0x03583b11, 0x653b6409,   // sn.xh.zu_422 ts.da.un_330  so.om.nl_653 lg.so.gv_444 
  0x58033bad, 0x47007819, 0x53002214, 0x231544ee,   // so.nl.om_643 ve.sn.un_750  oc.ht.un_660 kk.ky.un_420 
  0x1504370c, 0x3b064d0e, 0x152002ee, 0x170a075a,   // ba.ru.un_543 aa.de.so_555  da.sq.un_422 bg.mk.sr_553 
  // [6010]
  0x330264a0, 0x3b004a07, 0x583b6407, 0x34517355,   // lg.da.nn_322 yo.so.un_420  lg.so.om_432 ny.kl.xh_442 
  0x4265fc02, 0x50005e29, 0x790208a4, 0x15110107,   // zzp.gv.co_222 ts.fj.un_960  no.da.war_433 en.ro.un_432 
  0x00005424, 0x045e5908, 0x00005024, 0x51002d0c,   // ik.un.un_900 rn.ts.fi_443  fj.un.un_900 sk.kl.un_530 
  0x10731360, 0x15021bee, 0xfc030607, 0x1700390d,   // et.ny.lt_664 tr.da.un_422  de.nl.zzp_432 br.sr.un_540 
  // [6020]
  0x03067905, 0x135d50a4, 0x233625ad, 0x37483c11,   // war.de.nl_333 fj.ss.et_433  mn.ab.ky_643 ug.tt.ba_653 
  0x0a23fc0c, 0x161b50a0, 0x107355a0, 0x5550590c,   // zzp.ca.pt_543 fj.tr.hr_322  rw.ny.lt_322 rn.fj.rw_543 
  0x6800450d, 0x595550ac, 0x38001f1a, 0x595550ec,   // ln.ig.un_540 fj.rw.rn_632  cy.tk.un_760 fj.rw.rn_644 
  0x33081302, 0x5051730c, 0x13004c08, 0x38021f04,   // et.no.nn_222 ny.kl.fj_543  wo.et.un_430 cy.da.tk_332 
  // [6030]
  0x3c23380d, 0x48003504, 0x0e004c0d, 0x48170a5a,   // tk.ky.ug_554 tg.tt.un_320  wo.is.un_540 mk.sr.tt_553 
  0x44302355, 0x2a006504, 0x12133302, 0x07233502,   // ky.uz.kk_442 gv.mt.un_320  nn.et.hu_222 tg.ky.bg_222 
  0x380c0204, 0x213d1808, 0x3517110c, 0x6a562612,   // da.sv.tk_332 ar.ku.fa_443  ro.sr.tg_543 ia.mg.haw_654 
  0x56673712, 0x523b2205, 0x5a653bac, 0x2f1c21a0,   // st.ak.mg_654 oc.so.ha_333  so.gv.sm_632 jw.id.su_322 
  // [6040]
  0x01000604, 0x292d0d0e, 0x38592755, 0x375f30af,   // de.en.un_320 cs.sk.sl_555  gd.rn.tk_442 uz.tn.st_655 
  0x1b003904, 0x375639af, 0x42002e07, 0x06006013,   // br.tr.un_320 br.mg.st_655  fo.co.un_420 vo.de.un_650 
  0x18755faf, 0x3d003414, 0x233e430c, 0x213c23ad,   // tn.nso.ga_655 ps.ku.un_660  ie.rm.ca_543 ky.ug.fa_643 
  0x03395b13, 0x07644207, 0x5e455312, 0x02305e5a,   // sg.br.nl_665 co.lg.it_432  ht.ln.ts_654 ts.uz.da_553 
  // [6050]
  0x2d0d11a4, 0x400638a7, 0x301b01a0, 0x0600012b,   // ro.cs.sk_433 tk.de.lb_532  en.tr.uz_322 en.de.un_980 
  0xfc403faf, 0x50fe3013, 0x37467807, 0x4b213907,   // af.lb.zzp_655 uz.tlh.fj_665  ve.qu.st_432 br.jw.mi_432 
  0x48002318, 0x391c57a6, 0x5e4a6712, 0x40000113,   // ky.tt.un_740 na.id.br_521  ak.yo.ts_654 en.lb.un_650 
  0x452d01ec, 0x020c23ee, 0x2f391c02, 0x3f005023,   // en.sk.ln_644 ca.sv.da_422  id.br.su_222 fj.af.un_880 
  // [6060]
  0x6a025a0c, 0x3012180c, 0x3738150c, 0x3f005719,   // sm.da.haw_543 ar.ur.uz_543  un.tk.ba_543 na.af.un_750 
  0x31003004, 0x01625d0c, 0x33082ea4, 0x033f06a9,   // uz.az.un_320 ss.kha.en_543  fo.no.nn_433 de.af.nl_544 
  0x46005f02, 0x3f001008, 0x34004c08, 0x06033f0d,   // tn.qu.un_220 lt.af.un_430  wo.xh.un_430 af.nl.de_554 
  0x5d344c07, 0x4c005e0d, 0x043730ee, 0x55255912,   // wo.xh.ss_432 ts.wo.un_540  uz.ba.ru_422 rn.eu.rw_654 
  // [6070]
  0x766953ec, 0x3d003012, 0x1c094b0b, 0x23003c1b,   // ht.mfe.crs_644 uz.ku.un_640  mi.pl.id_542 ug.ky.un_770 
  0x213f760c, 0x292d0d55, 0x38230805, 0x423e380c,   // crs.af.jw_543 cs.sk.sl_442  uk.ky.tk_333 tk.rm.co_543 
  0x40062d0d, 0xfc7901a0, 0x4b212f0c, 0x06002d02,   // sk.de.lb_554 en.war.zzp_322  su.jw.mi_543 sk.de.un_220 
  0x1b59250c, 0x033f6407, 0x78375f12, 0x32005607,   // eu.rn.tr_543 lg.af.nl_432  tn.st.ve_654 mg.bs.un_420 
  // [6080]
  0x29312504, 0x06002c04, 0x422a07a9, 0x201502a0,   // eu.az.sl_332 fy.de.un_320  it.mt.co_544 da.sq.un_320 
  0x190a0da4, 0x2f002102, 0x09594808, 0x21343ba9,   // cs.pt.gl_433 jw.su.un_220  tt.rn.pl_443 ks.ps.fa_544 
  0x2300280d, 0x34183c04, 0x123034a0, 0x352311a7,   // sd.ky.un_540 ug.ar.ps_332  ps.uz.ur_322 ro.ky.tg_532 
  0x122130af, 0x25481507, 0x49502904, 0x47131255,   // uz.fa.ur_655 un.tt.mn_432  sl.fj.to_332 hu.et.sn_442 
  // [6090]
  0x37003005, 0x49215f11, 0x46002104, 0x15303560,   // uz.ba.un_330 tn.jw.to_653  jw.qu.un_320 tg.uz.un_664 
  0x082536a7, 0x5c002107, 0x46005f05, 0x3e111d04,   // ab.mn.uk_532 jw.sa.un_420  tn.qu.un_330 la.ro.rm_332 
  0x5c474902, 0x2f212007, 0x343d23a6, 0x21472904,   // to.sn.sa_222 sq.jw.su_432  ky.ku.ps_521 sl.sn.jw_332 
  0x5f6a1e07, 0x4700360b, 0x17111011, 0x3730355a,   // ms.haw.tn_432 gn.sn.un_520  be.ro.sr_653 tg.uz.ba_553 
  // [60a0]
  0x3700101b, 0x2300250c, 0x3b003304, 0x29162d07,   // be.ba.un_770 mn.ky.un_530  nn.so.un_320 sk.hr.sl_432 
  0x210b01a0, 0x101715a7, 0x071cfca0, 0x44000402,   // en.es.jw_322 un.sr.be_532  zzp.id.it_322 ru.kk.un_220 
  0x5600fc12, 0x3500150d, 0x342118af, 0x0c001e04,   // zzp.mg.un_640 un.tg.un_540  ar.fa.ps_655 ms.sv.un_320 
  0x40051109, 0x2a006312, 0x06001f02, 0x171538a4,   // ro.fr.lb_444 sco.mt.un_640  cy.de.un_220 tk.sr.un_430 
  // [60b0]
  0x25043607, 0x33203ea0, 0x0a0715a9, 0x3021120c,   // ab.ru.mn_432 rm.sq.nn_322  un.bg.mk_544 ur.fa.uz_543 
  0x5c305011, 0x37006120, 0x3b190a04, 0x65003b04,   // fj.uz.sa_653 za.st.un_850  pt.gl.so_332 so.gv.un_320 
  0x02150307, 0x61006319, 0x1dfc0808, 0x343012af,   // nl.da.un_420 sco.za.un_750  no.zzp.la_443 ur.uz.ps_655 
  0x454f5faf, 0x13000207, 0x2d0d02ee, 0x040723a4,   // tn.bi.ln_655 da.et.un_420  da.cs.sk_422 ky.bg.ru_433 
  // [60c0]
  0x2900170d, 0x503e6505, 0x52005007, 0x305c5060,   // sr.sl.un_540 gv.rm.fj_333  fj.ha.un_420 fj.sa.uz_664 
  0x0834fcee, 0x634c01a0, 0x44003702, 0x1c130907,   // zzp.xh.no_422 en.wo.sco_322  ba.kk.un_220 hi.bh.mr_432 
  0x13007321, 0x0f003b04, 0x4c6303ee, 0xfc1e1c5a,   // ny.et.un_860 so.lv.un_320  nl.sco.wo_422 id.ms.zzp_553 
  0x08382514, 0x25001105, 0x02112508, 0x25007811,   // mn.tk.uk_666 ro.eu.un_330  eu.ro.da_443 ve.eu.un_630 
  // [60d0]
  0x120e2e60, 0x15481707, 0x17233508, 0x5c1c090c,   // fo.is.hu_664 sr.tt.un_432  tg.ky.sr_443 hi.mr.sa_543 
  0x1d190b02, 0x37442313, 0x040a11a7, 0x695376a9,   // es.gl.la_222 ky.kk.ba_665  ro.mk.ru_532 crs.ht.mfe_544 
  0x250242a4, 0x49002504, 0x25001123, 0x0900fc13,   // co.da.eu_433 eu.to.un_320  ro.eu.un_880 zzp.pl.un_650 
  0x25112609, 0x18001219, 0x6409590c, 0x0a301504,   // ia.ro.eu_444 ur.ar.un_750  rn.pl.lg_543 un.uz.mk_332 
  // [60e0]
  0x0900fc19, 0x02003014, 0x33080ea4, 0x302f3707,   // zzp.pl.un_750 uz.da.un_660  is.no.nn_433 st.su.uz_432 
  0x284630a7, 0x4d000f22, 0x0c486907, 0x211c1e12,   // uz.qu.sw_532 lv.aa.un_870  mfe.tt.sv_432 ms.id.jw_654 
  0x38001c08, 0x34024511, 0x21307908, 0x15050102,   // id.tk.un_430 ln.da.xh_653  war.uz.jw_443 en.fr.un_222 
  0x08021b0c, 0x09006808, 0x2118280c, 0x1f000919,   // tr.da.no_543 ig.pl.un_430  sd.ar.fa_543 pl.cy.un_750 
  // [60f0]
  0x48002402, 0x3409fc12, 0x0900fc21, 0x533469ee,   // eo.tt.un_220 zzp.pl.xh_654  zzp.pl.un_860 mfe.xh.ht_422 
  0xfc000914, 0x5d003409, 0x3409fc07, 0x043c1555,   // pl.zzp.un_660 xh.ss.un_440  zzp.pl.xh_432 un.ug.ru_442 
  0x5900450e, 0x28734507, 0x053b42a0, 0x60102a0c,   // ln.rn.un_550 ln.ny.sw_432  co.so.fr_322 mt.lt.vo_543 
  0x5c002105, 0x1c2f36a0, 0x251b380b, 0x302f0204,   // jw.sa.un_330 gn.su.id_322  tk.tr.eu_542 da.su.uz_332 
  // [6100]
  0x486b7904, 0x0c000209, 0x353c3004, 0x123d2107,   // war.ceb.tt_332 da.sv.un_440  uz.ug.tg_332 fa.ku.ur_432 
  0x213b3413, 0x5535345a, 0x40003f05, 0x2d003907,   // ps.ks.fa_665 xh.zu.rw_553  af.lb.un_330 br.sk.un_420 
  0x35730d05, 0x34302109, 0x091c0d09, 0x476435a0,   // cs.ny.zu_333 fa.uz.ps_444  ne.mr.hi_444 zu.lg.sn_322 
  0x3800290d, 0x3bfc4d0c, 0x3b00fc09, 0x076301ec,   // sl.tk.un_540 aa.zzp.so_543  zzp.so.un_440 en.sco.it_644 
  // [6110]
  0x032b0208, 0x030216a9, 0x12002119, 0x2a3e0204,   // da.vi.nl_443 hr.da.nl_544  fa.ur.un_750 da.rm.mt_332 
  0x63000134, 0x39004005, 0x024a690d, 0x010663ad,   // en.sco.un_A80 lb.br.un_330  mfe.yo.da_554 sco.de.en_643 
  0x2b00fc04, 0x23351755, 0xfc003b05, 0x2b0302a4,   // zzp.vi.un_320 sr.tg.ky_442  so.zzp.un_330 da.nl.vi_433 
  0x64564707, 0x4c00fc1a, 0x43023609, 0x2300300e,   // sn.mg.lg_432 zzp.wo.un_760  gn.da.ie_444 uz.ky.un_550 
  // [6120]
  0x2c651faf, 0x07480402, 0x233038ad, 0x462b1504,   // cy.gv.fy_655 ru.tt.bg_222  tk.uz.ky_643 un.vi.qu_332 
  0x02572bac, 0x35100409, 0x0a44300c, 0x35300a04,   // vi.na.da_632 ru.be.tg_444  uz.kk.mk_543 mk.uz.tg_332 
  0x0700380c, 0x79006b13, 0x0e001309, 0x38003207,   // tk.bg.un_530 ceb.war.un_650  et.is.un_440 bs.tk.un_420 
  0x2f004802, 0x20006e07, 0x3c234409, 0x19000b13,   // tt.su.un_220 hmn.sq.un_420  kk.ky.ug_444 es.gl.un_650 
  // [6130]
  0x02000c05, 0x38002504, 0x15383608, 0x24005007,   // sv.da.un_330 eu.tk.un_320  ab.tk.un_443 fj.eo.un_420 
  0x35070a04, 0x25004802, 0x07250802, 0x190a0bee,   // mk.bg.tg_332 tt.mn.un_220  uk.mn.bg_222 es.pt.gl_422 
  0x0a003613, 0x0c0833ec, 0x15001f07, 0x16001508,   // ab.mk.un_650 nn.no.sv_644  cy.un.un_420 un.hr.un_430 
  0x29000908, 0x02001f11, 0x330815a0, 0x080c40a4,   // pl.sl.un_430 cy.da.un_630  un.no.nn_322 lb.sv.no_433 
  // [6140]
  0x48003009, 0x3000110c, 0x4000030c, 0x1500fc02,   // uz.tt.un_440 ro.uz.un_530  nl.lb.un_530 zzp.un.un_220 
  0x06001504, 0x17070aaf, 0x36151d05, 0x15001713,   // un.de.un_320 mk.bg.sr_655  la.gn.un_330 sr.un.un_650 
  0x3000440e, 0x15002009, 0xfc3315a4, 0x330c1504,   // kk.uz.un_550 sq.un.un_440  un.nn.zzp_433 un.sv.nn_332 
  0x08100712, 0x34003f0c, 0x211223ee, 0x791b4604,   // bg.be.uk_654 af.xh.un_530  ky.ur.fa_422 qu.tr.war_332 
  // [6150]
  0x35003c0b, 0x48301b08, 0x2c3f29a0, 0x02fe5fa4,   // ug.tg.un_520 tr.uz.tt_443  sl.af.fy_322 tn.tlh.da_433 
  0x466b48a4, 0x13fc1a02, 0x04100805, 0x6b4846a0,   // tt.ceb.qu_433 tl.zzp.et_222  uk.be.ru_333 qu.tt.ceb_322 
  0x1b384dee, 0x1d110111, 0x733b28a9, 0x1f395c04,   // aa.tk.tr_422 en.ro.la_653  sw.so.ny_544 sa.br.cy_332 
  0x484d6ba4, 0x73003013, 0x2a001502, 0x02001b0d,   // ceb.aa.tt_433 uz.ny.un_650  un.mt.un_220 tr.da.un_540 
  // [6160]
  0x64005f0e, 0x08003c07, 0x302344a7, 0x1b73285a,   // tn.lg.un_550 ug.uk.un_420  kk.ky.uz_532 sw.ny.tr_553 
  0x30001b04, 0x1b3146ee, 0x1c2404ad, 0x0d532d0c,   // tr.uz.un_320 qu.az.tr_422  fi.eo.id_643 sk.ht.cs_543 
  0x1230280c, 0x48303702, 0x0d1d4707, 0x301c010c,   // sd.uz.ur_543 st.uz.tt_222  sn.la.cs_432 en.id.uz_543 
  0x31301b04, 0x79466b07, 0x461bfe0c, 0x30fe460d,   // tr.uz.az_332 ceb.qu.war_432  tlh.tr.qu_543 qu.tlh.uz_554 
  // [6170]
  0xfe396ea4, 0x37004405, 0xfe042f04, 0x1c0d13ee,   // hmn.br.tlh_433 kk.ba.un_330  su.fi.tlh_332 bh.ne.mr_422 
  0x5f566707, 0x5d001e09, 0x010a3fa0, 0x21353408,   // ak.mg.tn_432 ms.ss.un_440  af.pt.en_322 xh.zu.jw_443 
  0x73462807, 0x0a001004, 0x34233da0, 0x15040807,   // sw.qu.ny_432 be.mk.un_320  ku.ky.ps_322 uk.ru.un_432 
  0x2f1c67a4, 0x39005f1a, 0x25003011, 0x19000a09,   // ak.id.su_433 tn.br.un_760  uz.mn.un_630 pt.gl.un_440 
  // [6180]
  0x35304812, 0x562c35a0, 0x10170704, 0x3500670e,   // tt.uz.tg_654 zu.fy.mg_322  bg.sr.be_332 ak.zu.un_550 
  0x48002502, 0x2d0d29a9, 0x06004805, 0x48083012,   // mn.tt.un_220 sl.cs.sk_544  tt.de.un_330 uz.uk.tt_654 
  0x55346707, 0x09335e07, 0x34001a04, 0x2a004c11,   // ak.xh.rw_432 ts.nn.pl_432  tl.xh.un_320 wo.mt.un_630 
  0x60622704, 0x47004604, 0x271139a0, 0x24691c07,   // gd.kha.vo_332 qu.sn.un_320  br.ro.gd_322 id.mfe.eo_432 
  // [6190]
  0x095c1305, 0x35003c07, 0x215945a4, 0x170a04a4,   // bh.sa.hi_333 ug.tg.un_420  ln.rn.jw_433 ru.mk.sr_433 
  0x33084ea0, 0x45006707, 0x36fc57ad, 0x2f2c5302,   // ay.no.nn_322 ak.ln.un_420  na.zzp.gn_643 ht.fy.su_222 
  0x45673505, 0x102536ec, 0x33fc01a4, 0x651801a4,   // zu.ak.ln_333 ab.mn.be_644  en.zzp.nn_433 en.ga.gv_433 
  0x3034210c, 0x286e5d07, 0x15674508, 0x632701a4,   // fa.ps.uz_543 ss.hmn.sw_432  ln.ak.un_443 en.gd.sco_433 
  // [61a0]
  0x4b39fcaf, 0x65271812, 0x186301a9, 0x25001102,   // zzp.br.mi_655 ga.gd.gv_654  en.sco.ga_544 ro.eu.un_220 
  0x23470208, 0x3e420708, 0x23242555, 0x12006e07,   // da.sn.ca_443 it.co.rm_443  eu.eo.ca_442 hmn.hu.un_420 
  0x23180205, 0x370436ac, 0x295c16a0, 0x5c6e120c,   // da.ga.ca_333 ab.ru.ba_632  hr.sa.sl_322 hu.hmn.sa_543 
  0x081704a0, 0x64006e07, 0x2337380c, 0x20002a05,   // ru.sr.uk_322 hmn.lg.un_420  tk.ba.ky_543 mt.sq.un_330 
  // [61b0]
  0x12006e08, 0x12006505, 0x65001119, 0x01635711,   // hmn.hu.un_430 gv.hu.un_330  ro.gv.un_750 na.sco.en_653 
  0x3500251b, 0x28003504, 0x7618010c, 0x3c003d2a,   // mn.tg.un_770 zu.sw.un_320  en.ga.crs_543 ku.ug.un_970 
  0x1c095caf, 0x121e1dee, 0x1d0b25a4, 0x21003b1b,   // sa.hi.mr_655 la.ms.hu_422  eu.es.la_433 ks.fa.un_770 
  0x1d2c0207, 0x11001d02, 0x343d21a7, 0x17290e04,   // da.fy.la_432 la.ro.un_220  fa.ku.ps_532 is.sl.sr_332 
  // [61c0]
  0x3b2847a0, 0x12006e0d, 0x0200fa18, 0x1200050e,   // sn.sw.so_322 hmn.hu.un_540  nr.da.un_740 fr.hu.un_550 
  0x5c005d0c, 0x5300020d, 0x21004d0e, 0x1b330804,   // ss.sa.un_530 da.ht.un_540  aa.jw.un_550 no.nn.tr_332 
  0x3f005605, 0x63004c04, 0x381523a4, 0x33084ca6,   // mg.af.un_330 wo.sco.un_320  ky.tk.un_430 wo.no.nn_521 
  0x15100407, 0x3b00521b, 0x3b005202, 0x5c2d0d02,   // ru.be.un_432 ha.so.un_770  ha.so.un_220 cs.sk.sa_222 
  // [61d0]
  0x2f000507, 0x2e004c05, 0x2f2105a4, 0x213034a0,   // fr.su.un_420 wo.fo.un_330  fr.jw.su_433 ps.uz.fa_322 
  0x55353455, 0x13584c02, 0x08002e09, 0x073c2508,   // xh.zu.rw_442 wo.om.et_222  fo.no.un_440 mn.ug.bg_443 
  0x5c1c09ec, 0x383f0355, 0x1c004c08, 0x0a000409,   // hi.mr.sa_644 nl.af.tk_442  wo.id.un_430 ru.mk.un_440 
  0x4c023ba9, 0x553728ad, 0x53005504, 0x33084ca0,   // so.da.wo_544 sw.st.rw_643  rw.ht.un_320 wo.no.nn_322 
  // [61e0]
  0x21052f02, 0x560539a0, 0x2e124c08, 0x08134c04,   // su.fr.jw_222 br.fr.mg_322  wo.hu.fo_443 wo.et.no_332 
  0x367901a0, 0x0f130460, 0x40000b09, 0x21184407,   // en.war.gn_322 fi.et.lv_664  es.lb.un_440 kk.ar.fa_432 
  0x023937af, 0x3933080c, 0x0258630e, 0x160339a0,   // st.br.da_655 no.nn.br_543  sco.om.da_555 br.nl.hr_322 
  0x2f033f0c, 0x691f010c, 0x114c5caf, 0x5c0d0907,   // af.nl.su_543 en.cy.mfe_543  sa.wo.ro_655 hi.ne.sa_432 
  // [61f0]
  0x0e3f02ee, 0x1d5737ec, 0x5c001312, 0x333f39a7,   // da.af.is_422 st.na.la_644  bh.sa.un_640 br.af.nn_532 
  0x21001214, 0x11441505, 0x19345e12, 0x39033f0c,   // ur.fa.un_660 un.kk.ro_333  ts.xh.gl_654 af.nl.br_543 
  0x0a000d04, 0x0a0430a4, 0x12003414, 0x6069010c,   // cs.pt.un_320 uz.ru.mk_433  ps.ur.un_660 en.mfe.vo_543 
  0x3f030d0c, 0x0302230c, 0x0d00050c, 0x15040713,   // cs.nl.af_543 ca.da.nl_543  fr.cs.un_530 bg.ru.un_665 
  // [6200]
  0x5740010c, 0x3c2330ec, 0x353468ac, 0x4006390c,   // en.lb.na_543 uz.ky.ug_644  ig.xh.zu_632 br.de.lb_543 
  0x0203feaf, 0x65305e13, 0x35001002, 0x5a6a6e14,   // tlh.nl.da_655 ts.uz.gv_665  be.tg.un_220 hmn.haw.sm_666 
  0x48fe20a7, 0x1f00640d, 0x34003c12, 0x5f731f05,   // sq.tlh.tt_532 lg.cy.un_540  ug.ps.un_640 cy.ny.tn_333 
  0x20033fa9, 0x12183414, 0x2e3f3908, 0x21343bee,   // af.nl.sq_544 ps.ar.ur_666  br.af.fo_443 ks.ps.fa_422 
  // [6210]
  0x5d34350c, 0x0d095c0b, 0x20381f04, 0x1f00430e,   // zu.xh.ss_543 sa.hi.ne_542  cy.tk.sq_332 ie.cy.un_550 
  0x332c15ee, 0x44004808, 0x3d1821a0, 0x0a04380c,   // un.fy.nn_422 tt.kk.un_430  fa.ar.ku_322 tk.ru.mk_543 
  0x15352307, 0x3600100e, 0x08303507, 0x0403510c,   // ky.tg.un_432 be.ab.un_550  tg.uz.uk_432 kl.nl.fi_543 
  0xfc382c07, 0x581e51ad, 0x1200180b, 0x45021b0c,   // fy.tk.zzp_432 kl.ms.om_643  ar.ur.un_520 tr.da.ln_543 
  // [6220]
  0x6404520c, 0x52461b08, 0x6b1a79ad, 0x52021b0c,   // ha.fi.lg_543 tr.qu.ha_443  war.tl.ceb_643 tr.da.ha_543 
  0x582a3007, 0x1c1309af, 0x3b005207, 0x52301b09,   // uz.mt.om_432 hi.bh.mr_655  ha.so.un_420 tr.uz.ha_444 
  0x1c005104, 0x2e2d1205, 0x30004d14, 0x31002008,   // kl.id.un_320 hu.sk.fo_333  aa.uz.un_660 sq.az.un_430 
  0x52003505, 0x524d300c, 0x3b521ba0, 0x031202a9,   // zu.ha.un_330 uz.aa.ha_543  tr.ha.so_322 da.hu.nl_544 
  // [6230]
  0x1e4d5407, 0x302a5108, 0x1b553507, 0x44381113,   // ik.aa.ms_432 kl.mt.uz_443  zu.rw.tr_432 ro.tk.kk_665 
  0x5c1b7660, 0x104838a4, 0x5c1c0da4, 0x3f1e51a7,   // crs.tr.sa_664 tk.tt.be_433  ne.mr.sa_433 kl.ms.af_532 
  0x57595505, 0x46301b5a, 0x0a170712, 0x584c1b08,   // rw.rn.na_333 tr.uz.qu_553  bg.sr.mk_654 tr.wo.om_443 
  0x02004707, 0x01000e07, 0x17001607, 0x381136ad,   // sn.da.un_420 is.en.un_420  hr.sr.un_420 ab.ro.tk_643 
  // [6240]
  0x3700230d, 0x21341205, 0x242553a7, 0x58003b12,   // ky.ba.un_540 ur.ps.fa_333  ht.eu.eo_532 so.om.un_640 
  0x2f586b0d, 0x342128ad, 0x4c3b4a08, 0x6b4c4d0c,   // ceb.om.su_554 sd.fa.ps_643  yo.so.wo_443 aa.wo.ceb_543 
  0x12182804, 0x2812210d, 0x4c645855, 0x4c004d1b,   // sd.ar.ur_332 fa.ur.sd_554  om.lg.wo_442 aa.wo.un_770 
  0x02353408, 0xfc002714, 0x4d004c2b, 0x64584c14,   // xh.zu.da_443 gd.zzp.un_660  wo.aa.un_980 wo.om.lg_666 
  // [6250]
  0x4d3b6507, 0x58653b12, 0x583b4da6, 0x330c40a0,   // gv.so.aa_432 so.gv.om_654  aa.so.om_521 lb.sv.nn_322 
  0x3f003908, 0x13001707, 0x58644c60, 0x11001504,   // br.af.un_430 sr.et.un_420  wo.lg.om_664 un.ro.un_320 
  0x3534fcee, 0x525864ad, 0x11003902, 0x2b117907,   // zzp.xh.zu_422 lg.om.ha_643  br.ro.un_220 war.ro.vi_432 
  0x2900120b, 0x3b4c4d0c, 0x22353408, 0x16000404,   // hu.sl.un_520 aa.wo.so_543  xh.zu.oc_443 fi.hr.un_320 
  // [6260]
  0x1500fc18, 0x02005a12, 0x12001605, 0x524c5807,   // zzp.un.un_740 sm.da.un_640  hr.hu.un_330 om.wo.ha_432 
  0x3800101a, 0x2f4c58a4, 0x3216fca0, 0x4c3b4dad,   // be.tk.un_760 om.wo.su_433  zzp.hr.bs_322 aa.so.wo_643 
  0x586b6507, 0x583b5411, 0x4c3b4d0e, 0x01330804,   // gv.ceb.om_432 ik.so.om_653  aa.so.wo_555 no.nn.en_332 
  0x5c65580c, 0x583b4c11, 0x101115a9, 0x4c00581a,   // om.gv.sa_543 wo.so.om_653  un.ro.be_544 om.wo.un_760 
  // [6270]
  0x4c004d1a, 0x4c004d19, 0xfc353408, 0x25303812,   // aa.wo.un_760 aa.wo.un_750  xh.zu.zzp_443 tk.uz.mn_654 
  0x011d1eee, 0x04230702, 0x21123dad, 0x12381604,   // ms.la.en_422 it.ca.fi_222  ku.ur.fa_643 hr.tk.hu_332 
  0x09007907, 0x02162aa0, 0x48440aa4, 0x04174804,   // war.pl.un_420 mt.hr.da_322  mk.kk.tt_433 tt.sr.ru_332 
  0xfe1cfc08, 0x21343014, 0x2d0d1602, 0x2c103808,   // zzp.id.tlh_443 uz.ps.fa_666  hr.cs.sk_222 tk.lt.fy_443 
  // [6280]
  0x35072355, 0x23351507, 0x3800fc04, 0x15443007,   // ky.bg.tg_442 un.tg.ky_432  zzp.tk.un_320 uz.kk.un_432 
  0x242c1808, 0x34003f0d, 0x380415a4, 0x30003c2b,   // ga.fy.eo_443 af.xh.un_540  un.ru.tk_433 ug.uz.un_980 
  0x37440404, 0x1819120c, 0x2c00380e, 0x4a121805,   // ru.kk.ba_332 hu.gl.ga_543  tk.fy.un_550 ga.hu.yo_333 
  0x4800fe07, 0x4a001207, 0x0e00121a, 0x0d1918a4,   // tlh.tt.un_420 hu.yo.un_420  hu.is.un_760 ga.gl.cs_433 
  // [6290]
  0x52004802, 0x12460ead, 0x1c004a05, 0x3600120c,   // tt.ha.un_220 is.qu.hu_643  yo.id.un_330 hu.gn.un_530 
  0x35303cec, 0x4d694307, 0x02002904, 0x0d006007,   // ug.uz.tg_644 ie.mfe.aa_432  sl.da.un_320 vo.cs.un_420 
  0x0d19120c, 0x0b124a07, 0x3b006013, 0x22001907,   // hu.gl.cs_543 yo.hu.es_432  vo.so.un_650 gl.oc.un_420 
  0x5c1c0da7, 0x12000d21, 0x190b2da4, 0x15281304,   // ne.mr.sa_532 cs.hu.un_860  sk.es.gl_433 et.sw.un_332 
  // [62a0]
  0x12184a13, 0x48330e0b, 0x2e001502, 0x23004a07,   // yo.ga.hu_665 is.nn.tt_542  un.fo.un_220 yo.ca.un_420 
  0x2330480d, 0x40330804, 0x350804ee, 0x32060e07,   // tt.uz.ky_554 no.nn.lb_332  ru.uk.tg_422 is.de.bs_432 
  0x090d1c55, 0x281221a9, 0x33483008, 0x130a3ba0,   // mr.ne.hi_442 fa.ur.sd_544  uz.tt.nn_443 so.pt.et_322 
  0x3b1228a4, 0x0833020d, 0x103523af, 0x1f00fc04,   // sd.ur.ks_433 da.nn.no_554  ky.tg.be_655 zzp.cy.un_320 
  // [62b0]
  0x08481fa0, 0x08303511, 0x48080204, 0x171632a7,   // cy.tt.no_322 tg.uz.uk_653  da.no.tt_332 bs.hr.sr_532 
  0x02000e08, 0x48310e0c, 0x48311b5a, 0x12302105,   // is.da.un_430 is.az.tt_543  tr.az.tt_553 fa.uz.ur_333 
  0x15070460, 0x24000114, 0x08303509, 0x02000d12,   // ru.bg.un_664 iw.yi.un_660  tg.uz.uk_444 cs.da.un_640 
  0x21000104, 0x15070408, 0x0d5c1c04, 0x0c1e3802,   // en.jw.un_320 ru.bg.un_443  mr.sa.ne_332 tk.ms.sv_222 
  // [62c0]
  0x40483807, 0x48005b08, 0x040c79a0, 0x04404ead,   // tk.tt.lb_432 sg.tt.un_430  war.sv.fi_322 ay.lb.fi_643 
  0x794860ec, 0x11313804, 0x0c483805, 0x1b00480d,   // vo.tt.war_644 tk.az.ro_332  tk.tt.sv_333 tt.tr.un_540 
  0x0c483807, 0x0c0648a0, 0x48005b1b, 0x38000409,   // tk.tt.sv_432 tt.de.sv_322  sg.tt.un_770 fi.tk.un_440 
  0x48007907, 0x34213013, 0x192f2108, 0x79484b05,   // war.tt.un_420 uz.fa.ps_665  jw.su.gl_443 mi.tt.war_333 
  // [62d0]
  0x0e000d04, 0x13486004, 0x043848ad, 0x49024509,   // cs.is.un_320 vo.tt.et_332  tt.tk.fi_643 ln.da.to_444 
  0x025e45a9, 0x0d4a1255, 0x17113007, 0x375f490d,   // ln.ts.da_544 hu.yo.cs_442  uz.ro.sr_432 to.tn.st_554 
  0x1f1d1baf, 0x07040808, 0x1f685907, 0x04000210,   // tr.la.cy_655 uk.ru.bg_443  rn.ig.cy_432 da.fi.un_620 
  0x474a360c, 0x02254a55, 0x45281b08, 0x09321605,   // gn.yo.sn_543 yo.eu.da_442  tr.sw.ln_443 hr.bs.pl_333 
  // [62e0]
  0x13010504, 0x071b1d08, 0x4d311baf, 0x73002512,   // fr.en.et_332 la.tr.it_443  tr.az.aa_655 eu.ny.un_640 
  0x05060104, 0x15000208, 0x300a04a0, 0x5955450c,   // en.de.fr_332 da.un.un_430  ru.mk.uz_322 ln.rw.rn_543 
  0x060115a0, 0x2efe570c, 0x1d6745a4, 0x442338ad,   // un.en.de_322 na.tlh.fo_543  ln.ak.la_433 tk.ky.kk_643 
  0x350a340c, 0x43060155, 0xfc002e05, 0x2d064005,   // xh.pt.zu_543 en.de.ie_442  fo.zzp.un_330 lb.de.sk_333 
  // [62f0]
  0x1d1afca4, 0x2c003f04, 0xfe000207, 0x562825ad,   // zzp.tl.la_433 af.fy.un_320  da.tlh.un_420 eu.sw.mg_643 
  0x285502a4, 0xfc003b0b, 0x401b09ad, 0x1b004522,   // da.rw.sw_433 so.zzp.un_520  pl.tr.lb_643 ln.tr.un_870 
  0x56245ead, 0x47595508, 0x45004b0d, 0x1a00fc22,   // ts.eo.mg_643 rw.rn.sn_443  mi.ln.un_540 zzp.tl.un_870 
  0x1b1d1c04, 0x063901a0, 0x5b250208, 0x1d0302af,   // id.la.tr_332 en.br.de_322  da.eu.sg_443 da.nl.la_655 
  // [6300]
  0x3bfc1507, 0x291b0107, 0x07060104, 0x02006e0d,   // un.zzp.so_432 en.tr.sl_432  en.de.it_332 hmn.da.un_540 
  0x2c226a07, 0x6e004313, 0x3bfc4d07, 0x370430a7,   // haw.oc.fy_432 ie.hmn.un_650  aa.zzp.so_432 uz.ru.ba_532 
  0x2b00fc12, 0x55001808, 0xfc2557af, 0x791afc0c,   // zzp.vi.un_640 ga.rw.un_430  na.eu.zzp_655 zzp.tl.war_543 
  0x2b001219, 0x3d21230b, 0x043615a7, 0x2b4c12a9,   // hu.vi.un_750 ky.fa.ku_542  un.ab.ru_532 hu.wo.vi_544 
  // [6310]
  0x5e00fe0c, 0x7600011a, 0x2b00120c, 0x2b004c04,   // tlh.ts.un_530 en.crs.un_760  hu.vi.un_530 wo.vi.un_320 
  0x513308a7, 0x2300371a, 0x12002e05, 0x06033f12,   // no.nn.kl_532 ba.ky.un_760  fo.hu.un_330 af.nl.de_654 
  0x395c730b, 0x40063509, 0x0e1b3155, 0x344b6ba6,   // ny.sa.br_542 zu.de.lb_444  az.tr.is_442 ceb.mi.xh_521 
  0x466b3608, 0x033f6307, 0x362c20ee, 0x304846a0,   // gn.ceb.qu_443 sco.af.nl_432  sq.fy.gn_422 qu.tt.uz_322 
  // [6320]
  0x05002208, 0x1a466b0c, 0x483823ec, 0x2909320d,   // oc.fr.un_430 ceb.qu.tl_543  ky.tk.tt_644 bs.pl.sl_554 
  0x2f00462a, 0x0e1b4c55, 0xfc004602, 0x5c003905,   // qu.su.un_970 wo.tr.is_442  qu.zzp.un_220 br.sa.un_330 
  0x02375f0c, 0x04002804, 0x465a1ca4, 0x455f3708,   // tn.st.da_543 sw.fi.un_320  id.sm.qu_433 st.tn.ln_443 
  0x12000e12, 0x5c1e1c14, 0x1d6b7909, 0x353c3707,   // is.hu.un_640 id.ms.sa_666  war.ceb.la_444 ba.ug.tg_432 
  // [6330]
  0x1d001f04, 0x5f6330a7, 0x1a5f1c04, 0x732909a9,   // cy.la.un_320 uz.sco.tn_532  id.tn.tl_332 pl.sl.ny_544 
  0x0a2536a4, 0x471b7308, 0x755f37ec, 0x352515ee,   // ab.mn.mk_433 ny.tr.sn_443  st.tn.nso_644 un.mn.tg_422 
  0x461e2fee, 0x402a06a0, 0x07303c08, 0x34005502,   // su.ms.qu_422 de.mt.lb_322  ug.uz.bg_443 rw.xh.un_220 
  0x69421d09, 0x5900552c, 0x31463709, 0x38003504,   // la.co.mfe_444 rw.rn.un_990  st.qu.az_444 zu.tk.un_320 
  // [6340]
  0x5e1347a7, 0x47005c04, 0x477328ad, 0x284546ad,   // sn.et.ts_532 sa.sn.un_320  sw.ny.sn_643 qu.ln.sw_643 
  0x1c461e12, 0x07001013, 0x7800471b, 0x5c571ca4,   // ms.qu.id_654 be.bg.un_650  sn.ve.un_770 id.na.sa_433 
  0x451a15ec, 0x0a110705, 0x477346ee, 0x10003902,   // un.tl.ln_644 bg.ro.mk_333  qu.ny.sn_422 br.lt.un_220 
  0x04001711, 0x12000d08, 0x53003504, 0x0d482d07,   // sr.ru.un_630 cs.hu.un_430  zu.ht.un_320 sk.tt.cs_432 
  // [6350]
  0xfc1d5605, 0x56000108, 0x130d5c09, 0x340235ad,   // mg.la.zzp_333 en.mg.un_430  sa.ne.bh_444 zu.da.xh_643 
  0x10462f55, 0x1c561e12, 0x18281205, 0x653f03a4,   // su.qu.lt_442 ms.mg.id_654  ur.sd.ar_333 nl.af.gv_433 
  0x1e2156a9, 0x281834a6, 0x424305ad, 0x6462450c,   // mg.jw.ms_544 ps.ar.sd_521  fr.ie.co_643 ln.kha.lg_543 
  0x332f1cee, 0x42074007, 0x2d0d560e, 0x0d4a2da0,   // id.su.nn_422 lb.it.co_432  mg.cs.sk_555 sk.yo.cs_322 
  // [6360]
  0x0a232104, 0x2d120d09, 0x0d2d1208, 0x0d2d0e0b,   // jw.ca.pt_332 cs.hu.sk_444  hu.sk.cs_443 is.sk.cs_542 
  0x17110aa9, 0x03005c04, 0x0a082507, 0x38000302,   // mk.ro.sr_544 sa.nl.un_320  mn.uk.mk_432 nl.tk.un_220 
  0x212f1c04, 0x4f2101a4, 0xfc005813, 0x1a4601a0,   // id.su.jw_332 en.jw.bi_433  om.zzp.un_650 en.qu.tl_322 
  0x0c2c2e02, 0xfe004612, 0x02494b60, 0x45001c04,   // fo.fy.sv_222 qu.tlh.un_640  mi.to.da_664 id.ln.un_320 
  // [6370]
  0x4a1c25a4, 0x5f3745ec, 0x6a2445ec, 0x2e0e0ca0,   // eu.id.yo_433 ln.st.tn_644  ln.eo.haw_644 sv.is.fo_322 
  0x2800490c, 0x5f764512, 0x59551a0e, 0x5f3749a9,   // to.sw.un_530 ln.crs.tn_654  tl.rw.rn_555 to.st.tn_544 
  0x15fc01a7, 0x026957a4, 0x7321280c, 0x283b120c,   // en.zzp.un_532 na.mfe.da_433  sw.jw.ny_543 ur.ks.sd_543 
  0x041511a9, 0x34730212, 0x25005e04, 0xfc006812,   // ro.ru.un_540 da.ny.xh_654  ts.eu.un_320 ig.zzp.un_640 
  // [6380]
  0x50002d21, 0x52781e0c, 0x76090dec, 0x110b25a0,   // sk.fj.un_860 ms.ve.ha_543  cs.pl.crs_644 eu.es.ro_322 
  0x683437a9, 0x5c0d0911, 0x65005a04, 0x24365605,   // st.xh.ig_544 hi.ne.sa_653  sm.gv.un_320 mg.gn.eo_333 
  0x67fc4a08, 0x28677308, 0x56491c0c, 0x321628a4,   // yo.zzp.ak_443 ny.ak.sw_443  id.to.mg_543 sw.hr.bs_433 
  0x2a001f08, 0x1b683814, 0x31007908, 0x2d004802,   // cy.mt.un_430 tk.ig.tr_666  war.az.un_430 tt.sk.un_220 
  // [6390]
  0x30351509, 0x10002307, 0x040717ee, 0x23303c04,   // un.tg.uz_444 ky.be.un_420  sr.bg.ru_422 ug.uz.ky_332 
  0x35000204, 0x08100a08, 0x1218280c, 0x3e5322a0,   // da.zu.un_320 mk.be.uk_443  sd.ar.ur_543 oc.ht.rm_322 
  0x13000935, 0x1a005302, 0x351730af, 0x1c5c13ac,   // hi.bh.un_A90 ht.tl.un_220  uz.sr.tg_655 bh.sa.mr_632 
  0x060501a9, 0x223965a9, 0x170a30ad, 0x0200032b,   // en.fr.de_544 gv.br.oc_544  uz.mk.sr_643 nl.da.un_980 
  // [63a0]
  0x322817a4, 0x02031faf, 0x732869a9, 0x02000334,   // sr.sw.bs_433 cy.nl.da_655  mfe.sw.ny_544 nl.da.un_A80 
  0x0f2b2fee, 0x095c0d5a, 0x21030212, 0x1b0c73ad,   // su.vi.lv_422 ne.sa.hi_553  da.nl.jw_654 ny.sv.tr_643 
  0x3f130307, 0x2102030d, 0x23254802, 0x46026512,   // nl.et.af_432 nl.da.jw_554  tt.mn.ky_222 gv.da.qu_654 
  0x186b1dee, 0x3f1502a0, 0x53001005, 0x1b120907,   // la.ceb.ga_422 da.af.un_320  lt.ht.un_330 pl.hu.tr_432 
  // [63b0]
  0x083f4ea4, 0x07080aee, 0x2e025da0, 0x65000208,   // ay.af.no_433 mk.uk.bg_422  ss.da.fo_322 da.gv.un_430 
  0x2c791f0c, 0x1b313808, 0x01001512, 0xfe000211,   // cy.war.fy_543 tk.az.tr_443  un.en.un_640 da.tlh.un_630 
  0x373c480d, 0x33001e02, 0x10532504, 0x1100100e,   // tt.ug.ba_554 ms.nn.un_220  eu.ht.lt_332 be.ro.un_550 
  0x1b537613, 0x1d060104, 0x40230204, 0x021f10ee,   // crs.ht.tr_665 en.de.la_332  da.ca.lb_332 lt.cy.da_422 
  // [63c0]
  0x05060114, 0x4a190b09, 0x01000505, 0x03020a08,   // en.de.fr_666 es.gl.yo_444  fr.en.un_330 pt.da.nl_443 
  0x01060509, 0x02437960, 0x01002707, 0x794e1ca0,   // fr.de.en_444 war.ie.da_664  gd.en.un_420 id.ay.war_322 
  0x643f2812, 0x650c0202, 0x31302007, 0x69760960,   // sw.af.lg_654 da.sv.gv_222  sq.uz.az_432 pl.crs.mfe_664 
  0x280f58ad, 0x3f002c05, 0x6b001d07, 0x0c3f65a0,   // om.lv.sw_643 fy.af.un_330  la.ceb.un_420 gv.af.sv_322 
  // [63d0]
  0x09005302, 0x6976530c, 0x536976a4, 0x13005c13,   // ht.pl.un_220 ht.crs.mfe_543  crs.mfe.ht_433 sa.bh.un_650 
  0x1a6b530d, 0x04070814, 0x303248ad, 0x3035250c,   // ht.ceb.tl_554 uk.bg.ru_666  tt.bs.uz_643 mn.tg.uz_543 
  0x30282107, 0x20113055, 0x04100802, 0x37233c04,   // fa.sd.uz_432 uz.ro.sq_442  uk.be.ru_222 ug.ky.ba_332 
  0x2d0d2ea4, 0x0a003504, 0x2c00030b, 0x113508a9,   // fo.cs.sk_433 tg.mk.un_320  nl.fy.un_520 uk.tg.ro_544 
  // [63e0]
  0x32001607, 0x374825a7, 0x482d0908, 0x15040a13,   // hr.bs.un_420 mn.tt.ba_532  pl.sk.tt_443 mk.ru.un_665 
  0x322d0d02, 0x2d000f12, 0x0a040704, 0x36253512,   // cs.sk.bs_222 lv.sk.un_640  bg.ru.mk_332 tg.mn.ab_654 
  0x07000819, 0x36004805, 0x350736ee, 0x3700440e,   // uk.bg.un_750 tt.ab.un_330  ab.bg.tg_422 kk.ba.un_550 
  0x341844a9, 0x25001514, 0x35150408, 0x44004822,   // kk.ar.ps_544 un.mn.un_660  ru.tg.un_430 tt.kk.un_870 
  // [63f0]
  0x5d3534ec, 0x07174804, 0x0106050e, 0x301115a4,   // xh.zu.ss_644 tt.sr.bg_332  fr.de.en_555 un.ro.uz_433 
  0x58004707, 0x37002312, 0x390c0802, 0x32191fa4,   // sn.om.un_420 ky.ba.un_640  no.sv.br_222 cy.gl.bs_433 
  0x23220f0d, 0x205039a0, 0x0f006014, 0x1f000c07,   // lv.oc.ca_554 br.fj.sq_322  vo.lv.un_660 sv.cy.un_420 
  0x0a30250b, 0x031f3712, 0x33081fee, 0x033f2ca9,   // mn.uz.mk_542 st.cy.nl_654  cy.no.nn_422 fy.af.nl_544 
  
  // [6400]
  0x1b004d13, 0x133b6502, 0x6e5b4005, 0x65623b55,   // aa.tr.un_650 gv.so.et_222  lb.sg.hmn_333 so.kha.gv_442 
  0x2f3f0308, 0x3e000f0c, 0x13376307, 0x090d13a7,   // nl.af.su_443 lv.rm.un_530  sco.st.et_432 bh.ne.hi_532 
  0x30234407, 0x441710a7, 0x642463a7, 0x23303511,   // kk.ky.uz_432 be.sr.kk_532  sco.eo.lg_532 tg.uz.ky_653 
  0x05227607, 0x67136408, 0x56003e19, 0x6e003b13,   // crs.oc.fr_432 lg.et.ak_443  rm.mg.un_750 so.hmn.un_650 
  // [6410]
  0x65634cec, 0x603f0fa7, 0x65005c09, 0x64033404,   // wo.sco.gv_644 lv.af.vo_532  sa.gv.un_440 xh.nl.lg_332 
  0x0f1801a4, 0x6e00641a, 0x3f230f07, 0x4c6e3b11,   // en.ga.lv_433 lg.hmn.un_760  lv.ca.af_432 so.hmn.wo_653 
  0x30002309, 0x583b4d13, 0x38003905, 0x27001302,   // ky.uz.un_440 aa.so.om_665  br.tk.un_330 et.gd.un_220 
  0x3b584d0d, 0x173c35a4, 0x645868ec, 0x48303804,   // aa.om.so_554 tg.ug.sr_433  ig.om.lg_644 tk.uz.tt_332 
  // [6420]
  0x15080409, 0x0a350807, 0x3d2812ee, 0x2200570c,   // ru.uk.un_444 uk.tg.mk_432  ur.sd.ku_422 na.oc.un_530 
  0x69760807, 0x243564a9, 0x043530a0, 0x23002222,   // no.crs.mfe_432 lg.zu.eo_544  uz.tg.ru_322 oc.ca.un_870 
  0x12000b04, 0x103015a0, 0x5602600c, 0x23002208,   // es.hu.un_320 un.uz.be_322  vo.da.mg_543 oc.ca.un_430 
  0x282118ee, 0x564b6a0c, 0x615b62a9, 0x022555a9,   // ar.fa.sd_422 haw.mi.mg_543  kha.sg.za_544 rw.eu.da_544 
  // [6430]
  0x36280207, 0x23004418, 0x02256008, 0x252460ad,   // da.sw.gn_432 kk.ky.un_740  vo.eu.da_443 vo.eo.eu_643 
  0x332e0e55, 0x24602513, 0x22003f0c, 0x355d4512,   // is.fo.nn_442 eu.vo.eo_665  af.oc.un_530 ln.ss.zu_654 
  0x27006308, 0x252434a9, 0x303d18ec, 0x4c3473ec,   // sco.gd.un_430 xh.eo.eu_544  ar.ku.uz_644 ny.xh.wo_644 
  0x3140060b, 0x56245ea4, 0x55732807, 0xfc342805,   // de.lb.az_542 ts.eo.mg_433  sw.ny.rw_432 sw.xh.zzp_333 
  // [6440]
  0x0601fcee, 0x033ffcee, 0x3534fcaf, 0xfc473fa0,   // zzp.en.de_422 zzp.af.nl_422  zzp.xh.zu_655 af.sn.zzp_322 
  0x2c3f1008, 0x0c001504, 0xfc00060d, 0x38001714,   // lt.af.fy_443 un.sv.un_320  de.zzp.un_540 sr.tk.un_660 
  0x0c002908, 0x34281212, 0x32150202, 0x0906fc07,   // sl.sv.un_430 ur.sd.ps_654  da.bs.un_220 zzp.de.pl_432 
  0x301715a9, 0x50006402, 0x6e6b010c, 0x375f75a4,   // un.sr.uz_544 lg.fj.un_220  en.ceb.hmn_543 nso.tn.st_433 
  // [6450]
  0x0600671b, 0x4e000214, 0x33125da7, 0x0c2c01a0,   // ak.de.un_770 da.ay.un_660  ss.hu.nn_532 en.fy.sv_322 
  0x0c353405, 0x031d0dad, 0x1f002804, 0x4200230d,   // xh.zu.sv_333 cs.la.nl_643  sw.cy.un_320 ca.co.un_540 
  0x1300fc02, 0x0a1008ad, 0x2d353460, 0x06fc2aad,   // zzp.et.un_220 uk.be.mk_643  xh.zu.sk_664 mt.zzp.de_643 
  0x02004c04, 0x372afca7, 0x2700790d, 0x55597307,   // wo.da.un_320 zzp.mt.st_532  war.gd.un_540 ny.rn.rw_432 
  // [6460]
  0xfc000104, 0x34383513, 0x3d001811, 0x033f02ee,   // en.zzp.un_320 zu.tk.xh_665  ar.ku.un_630 da.af.nl_422 
  0x1f006318, 0x48003808, 0x6400550d, 0x343012ec,   // sco.cy.un_740 tk.tt.un_430  rw.lg.un_540 ur.uz.ps_644 
  0x55002102, 0x7902090d, 0x3e650f0c, 0x2c5303a0,   // jw.rw.un_220 pl.da.war_554  lv.gv.rm_543 nl.ht.fy_322 
  0x12302504, 0x35345305, 0x64003912, 0x0ffc1fee,   // eu.uz.hu_332 ht.xh.zu_333  br.lg.un_640 cy.zzp.lv_422 
  // [6470]
  0x270c020d, 0x79094305, 0xfc020811, 0x07002d04,   // da.sv.gd_554 ie.pl.war_333  no.da.zzp_653 sk.it.un_320 
  0x1b1312a0, 0x33084da0, 0x0f001f04, 0x08021f0c,   // hu.et.tr_322 aa.no.nn_322  cy.lv.un_320 cy.da.no_543 
  0x4700550c, 0x2f003604, 0x152402a0, 0x10043504,   // rw.sn.un_530 gn.su.un_320  da.eo.un_322 tg.ru.be_332 
  0x55765307, 0x09002807, 0x07000604, 0x796909a7,   // ht.crs.rw_432 sw.pl.un_420  de.it.un_320 pl.mfe.war_532 
  // [6480]
  0x5c130d55, 0x090f01a4, 0x06002b04, 0x2d0f020b,   // ne.bh.sa_442 en.lv.pl_433  vi.de.un_320 da.lv.sk_542 
  0x3c00360e, 0x15383009, 0x150408ac, 0x4c653b04,   // ab.ug.un_550 uz.tk.un_444  uk.ru.un_632 so.gv.wo_332 
  0x48254308, 0x29001c04, 0x30231505, 0x3b002813,   // ie.eu.tt_443 id.sl.un_320  un.ky.uz_333 sd.ks.un_650 
  0x23372512, 0x17234404, 0x79625212, 0x190a33af,   // mn.ba.ky_654 kk.ky.sr_332  ha.kha.war_654 nn.pt.gl_655 
  // [6490]
  0x25001e04, 0x522a1ea9, 0x4a000e0c, 0x431f650b,   // ms.eu.un_320 ms.mt.ha_544  is.yo.un_530 gv.cy.ie_542 
  0x4d001e08, 0x130d09ad, 0x30000a12, 0x136563a0,   // ms.aa.un_430 hi.ne.bh_643  mk.uz.un_640 sco.gv.et_322 
  0x0e001905, 0x19000e08, 0x52001e22, 0x23190a0d,   // gl.is.un_330 is.gl.un_430  ms.ha.un_870 pt.gl.ca_554 
  0x763952af, 0x23223904, 0x766933a4, 0x31624d0c,   // ha.br.crs_655 br.oc.ca_332  nn.mfe.crs_433 aa.kha.az_543 
  // [64a0]
  0x2a15600e, 0x0b4636a0, 0x050601a4, 0x1b2a5cee,   // vo.mt.un_550 gn.qu.es_322  en.de.fr_433 sa.mt.tr_422 
  0x4837440d, 0x342144a4, 0x65601daf, 0x0b030211,   // kk.ba.tt_554 kk.fa.ps_433  la.vo.gv_655 da.nl.es_653 
  0x06630113, 0x1f46150c, 0x60003e13, 0x3c3530af,   // en.sco.de_665 un.qu.cy_543  rm.vo.un_650 uz.tg.ug_655 
  0x0c261507, 0x35001505, 0x63290204, 0x65020307,   // un.ia.sv_432 un.tg.un_330  da.sl.sco_332 nl.da.gv_432 
  // [64b0]
  0x40020309, 0x2a2818a0, 0x213c230d, 0x07081707,   // nl.da.lb_444 ga.sw.mt_322  ky.ug.fa_554 sr.uk.bg_432 
  0x06070104, 0x0a0502ee, 0x38003c0e, 0x18030211,   // en.it.de_332 da.fr.pt_422  ug.tk.un_550 da.nl.ga_653 
  0x00001542, 0x0243020d, 0x2d004a09, 0x12004808,   // un.un.un_C00 da.ie.da_554  yo.sk.un_440 tt.hu.un_430 
  0x2c000322, 0x25481504, 0x2b006308, 0x34002402,   // nl.fy.un_870 un.tt.mn_332  sco.vi.un_430 eo.xh.un_220 
  // [64c0]
  0x6000020e, 0x0e2e01a0, 0x4800230d, 0x10072504,   // da.vo.un_550 en.fo.is_322  ky.tt.un_540 mn.bg.be_332 
  0x1a003e04, 0x303615a0, 0x041017a9, 0x482310a0,   // rm.tl.un_320 un.ab.uz_322  sr.be.ru_544 be.ky.tt_322 
  0x281221a7, 0x670601ee, 0x301538ad, 0x23002504,   // fa.ur.sd_532 en.de.ak_422  tk.uz.un_630 mn.ky.un_320 
  0x282123a4, 0x08040705, 0x1c4301ad, 0x040815a4,   // ky.fa.sd_433 bg.ru.uk_333  en.ie.id_643 un.uk.ru_433 
  // [64d0]
  0x23302512, 0x790201a7, 0x2a003e0d, 0x69007623,   // mn.uz.ky_654 en.da.war_532  rm.mt.un_540 crs.mfe.un_880 
  0x4800600d, 0xfe0b650b, 0x1507040c, 0x65006314,   // vo.tt.un_540 gv.es.tlh_542  ru.bg.un_543 sco.gv.un_660 
  0x65006809, 0x5c090dac, 0x6300021b, 0x6308620c,   // ig.gv.un_440 ne.hi.sa_632  da.sco.un_770 kha.no.sco_543 
  0x53006305, 0x3d3b3413, 0x52641ca0, 0x42053ea0,   // sco.ht.un_330 ps.ks.ku_665  id.lg.ha_322 rm.fr.co_322 
  // [64e0]
  0x735234a4, 0x07000a1a, 0x30083560, 0x6b5d52a4,   // xh.ha.ny_433 mk.bg.un_760  tg.uk.uz_664 ha.ss.ceb_433 
  0x3c001708, 0x3b5228ec, 0x18443ca4, 0x21004c0e,   // sr.ug.un_430 sw.ha.so_644  ug.kk.ar_433 wo.jw.un_550 
  0x554a6404, 0x4c007807, 0x2b002323, 0x64375211,   // lg.yo.rw_332 ve.wo.un_420  ca.vi.un_880 ha.st.lg_653 
  0x3d2130a7, 0x5a626aaf, 0x59555e09, 0x02296aad,   // uz.fa.ku_532 haw.kha.sm_655  ts.rw.rn_444 haw.sl.da_643 
  // [64f0]
  0x216452ad, 0x5f376408, 0x21005207, 0x10384412,   // ha.lg.jw_643 lg.st.tn_443  ha.jw.un_420 kk.tk.be_654 
  0xfc002f04, 0x6a001e0d, 0x73fe5705, 0x736b210c,   // su.zzp.un_320 ms.haw.un_540  na.tlh.ny_333 jw.ceb.ny_543 
  0x45000804, 0x06005205, 0x20595009, 0x4c4652ad,   // no.ln.un_320 ha.de.un_330  fj.rn.sq_444 ha.qu.wo_643 
  0x40002c12, 0x4afc73a4, 0x766901a0, 0x5000640d,   // fy.lb.un_640 ny.zzp.yo_433  en.mfe.crs_322 lg.fj.un_540 
  // [6500]
  0x2a244d11, 0x18555f08, 0x1a505209, 0x023f0307,   // aa.eo.mt_653 tn.rw.ga_443  ha.fj.tl_444 nl.af.da_432 
  0x23383008, 0x5546520c, 0x1bfc3b11, 0x34597808,   // uz.tk.ky_443 ha.qu.rw_543  so.zzp.tr_653 ve.rn.xh_443 
  0x4b466aad, 0x34fc4aa0, 0x4d1b73a9, 0x73007819,   // haw.qu.mi_643 yo.zzp.xh_322  ny.tr.aa_544 ve.ny.un_750 
  0xfc001107, 0x04113511, 0x1a7821af, 0x56240d07,   // ro.zzp.un_420 tg.ro.ru_653  jw.ve.tl_655 cs.eo.mg_432 
  // [6510]
  0x52792f08, 0x30040705, 0x56005320, 0x305e470c,   // su.war.ha_443 bg.ru.uz_333  ht.mg.un_850 sn.ts.uz_543 
  0x22006714, 0x395a11ec, 0x103538ee, 0x17002d05,   // ak.oc.un_660 ro.sm.br_644  tk.tg.be_422 sk.sr.un_330 
  0x44003708, 0x5c007313, 0x10080409, 0x5955120c,   // ba.kk.un_430 ny.sa.un_650  ru.uk.be_444 hu.rw.rn_543 
  0x443418ad, 0x25697613, 0x17100aa0, 0x350408ad,   // ar.ps.kk_643 crs.mfe.eu_665  mk.be.sr_322 uk.ru.tg_643 
  // [6520]
  0x183430ee, 0x30002004, 0x0a0408a4, 0x0a00360c,   // uz.ps.ar_422 sq.uz.un_320  uk.ru.mk_433 ab.mk.un_530 
  0x371f3907, 0x0c083307, 0x135c09a9, 0x0d091c60,   // br.cy.st_432 nn.no.sv_432  hi.sa.bh_544 mr.hi.ne_664 
  0x08330ead, 0x0e4c08a4, 0x36000a0d, 0x2e4c33ec,   // is.nn.no_643 no.wo.is_433  mk.ab.un_540 nn.wo.fo_644 
  0x53005c07, 0x0a002104, 0x04001012, 0x1c1309ad,   // sa.ht.un_420 jw.pt.un_320  be.ru.un_640 hi.bh.mr_643 
  // [6530]
  0x40fc4702, 0x18344407, 0x0a390602, 0x3476690d,   // sn.zzp.lb_222 kk.ps.ar_432  de.br.pt_222 mfe.crs.xh_554 
  0xfc3964a0, 0x07001104, 0x2e330813, 0x040844a7,   // lg.br.zzp_322 ro.bg.un_320  no.nn.fo_665 kk.uk.ru_532 
  0x571801ee, 0x13004c0c, 0x2c330804, 0x471501a9,   // en.ga.na_422 wo.et.un_530  no.nn.fy_332 en.sn.un_540 
  0x37496a13, 0x6564fc02, 0x5a6a4913, 0x5a6a49af,   // haw.to.st_665 zzp.lg.gv_222  to.haw.sm_665 to.haw.sm_655 
  // [6540]
  0x756301ec, 0x11055214, 0x65583baf, 0x037543ec,   // en.sco.nso_644 ha.fr.ro_666  so.om.gv_655 ie.nso.nl_644 
  0x5d1f65a9, 0x17080a07, 0x090340af, 0x67456313,   // gv.cy.ss_544 mk.uk.sr_432  lb.nl.pl_655 sco.ln.ak_665 
  0x0300fc02, 0x03002b2b, 0x02681f04, 0x2c332004,   // zzp.nl.un_220 vi.nl.un_980  cy.ig.da_332 sq.nn.fy_332 
  0x40002507, 0x35006504, 0x33002c09, 0x4800311a,   // eu.lb.un_420 gv.zu.un_320  fy.nn.un_440 az.tt.un_760 
  // [6550]
  0x37003608, 0x03004012, 0x2c33080d, 0x0100632b,   // ab.ba.un_430 lb.nl.un_640  no.nn.fy_554 sco.en.un_980 
  0xfe0320ec, 0x0d1b010c, 0x0100632c, 0x45204bec,   // sq.nl.tlh_644 en.tr.cs_543  sco.en.un_990 mi.sq.ln_644 
  0x59032a12, 0x3d3430a7, 0x08442308, 0x0a353ca7,   // mt.nl.rn_654 uz.ps.ku_532  ky.kk.uk_443 ug.tg.mk_532 
  0x23383504, 0x0e00120d, 0x42003908, 0x2d0d1702,   // tg.tk.ky_332 hu.is.un_540  br.co.un_430 sr.cs.sk_222 
  // [6560]
  0x483c150c, 0x44152307, 0x170a36a7, 0x1000082b,   // un.ug.tt_543 ky.kk.un_420  ab.mk.sr_532 uk.be.un_980 
  0x4800441a, 0x4800380e, 0x443748a0, 0x08000a1a,   // kk.tt.un_760 tk.tt.un_550  tt.ba.kk_322 mk.uk.un_760 
  0x21281208, 0x33000b22, 0x3c002808, 0x30343b05,   // ur.sd.fa_443 bn.as.un_870  sd.ug.un_430 ks.ps.uz_333 
  0x04001513, 0x0758435a, 0x450e2e60, 0x1a735cad,   // un.ru.un_650 ie.om.it_553  fo.is.ln_664 sa.ny.tl_643 
  // [6570]
  0x0e005d09, 0x5a00670b, 0x601b640c, 0x384f620c,   // ss.is.un_440 ak.sm.un_520  lg.tr.vo_543 kha.bi.tk_543 
  0x736b01a0, 0x15000712, 0x100807ee, 0x651d43a0,   // en.ceb.ny_322 bg.un.un_640  bg.uk.be_422 ie.la.gv_322 
  0x125d35a0, 0x59552909, 0x5f00370d, 0x57021b0c,   // zu.ss.hu_322 sl.rw.rn_444  st.tn.un_540 tr.da.na_543 
  0x07003807, 0x23005802, 0x07294305, 0x0436150d,   // tk.bg.un_420 om.ca.un_220  ie.sl.it_333 un.ab.ru_554 
  // [6580]
  0x35345dec, 0x555752a4, 0x15040712, 0x13000412,   // ss.xh.zu_644 ha.na.rw_433  bg.ru.un_654 fi.et.un_640 
  0x48001507, 0x1a005f07, 0x2b00fe04, 0x311a0107,   // un.tt.un_420 tn.tl.un_420  tlh.vi.un_320 en.tl.az_432 
  0x4f006809, 0x0b1804ee, 0x230835a0, 0x31004d08,   // ig.bi.un_440 fi.ga.es_422  tg.uk.ky_322 aa.az.un_430 
  0x19004612, 0x0b000420, 0x2e0d2d0b, 0x10070409,   // qu.gl.un_640 fi.es.un_850  sk.cs.fo_542 ru.bg.be_444 
  // [6590]
  0x48003819, 0x2000fe07, 0x0c2304a4, 0x5e536907,   // tk.tt.un_750 tlh.sq.un_420  fi.ca.sv_433 mfe.ht.ts_432 
  0x5c000911, 0x4258040c, 0x15370808, 0x3b202f02,   // hi.sa.un_630 fi.om.co_543  uk.ba.un_443 su.sq.so_222 
  0x28206b0c, 0x251715a4, 0x12000e02, 0x79526b12,   // ceb.sq.sw_543 un.sr.mn_433  is.hu.un_220 ceb.ha.war_654 
  0x360415ee, 0x47202855, 0x6e330804, 0x62004623,   // un.ru.ab_422 sw.sq.sn_442  no.nn.hmn_332 qu.kha.un_880 
  // [65a0]
  0x6430feee, 0x120e2e0b, 0x3d30215a, 0x23003513,   // tlh.uz.lg_422 fo.is.hu_542  fa.uz.ku_553 tg.ky.un_650 
  0x3520100c, 0x222023ad, 0xfc3560a9, 0x44003812,   // lt.sq.zu_543 ca.sq.oc_643  vo.zu.zzp_544 tk.kk.un_640 
  0x5d2c4707, 0x30153c0d, 0x0b2e0e07, 0x2ffe5d08,   // sn.fy.ss_432 ug.uz.un_540  is.fo.es_432 ss.tlh.su_443 
  0x074236ac, 0x301b380c, 0x40001d0e, 0x2852730c,   // gn.co.it_632 tk.tr.uz_543  la.lb.un_550 ny.ha.sw_543 
  // [65b0]
  0x4b004f09, 0x4d00340e, 0x063003a4, 0x33311b0c,   // bi.mi.un_440 xh.aa.un_550  nl.uz.de_433 tr.az.nn_543 
  0x1d000204, 0x102820a7, 0x2a07fe0c, 0x3010205a,   // da.la.un_320 sq.sw.lt_532  tlh.it.mt_543 sq.lt.uz_553 
  0x3815040e, 0x4e4d2008, 0x1b2e0ea4, 0x0b002004,   // ru.tk.un_550 sq.aa.ay_443  is.fo.tr_433 sq.es.un_320 
  0x304dfe0d, 0x060c0fa9, 0x154836a4, 0x31003602,   // tlh.aa.uz_554 lv.sv.de_544  ab.tt.un_433 gn.az.un_220 
  // [65c0]
  0x6a0f5c13, 0x183c340c, 0x3800301a, 0x3b001208,   // sa.lv.haw_665 ps.ug.ar_543  uz.tk.un_760 ur.ks.un_430 
  0x0f00170d, 0x5c090da9, 0x01036704, 0x03653fad,   // sr.lv.un_540 ne.hi.sa_544  ak.nl.en_332 af.gv.nl_643 
  0x0200400d, 0x5c0f4b0c, 0x1b1d300c, 0x080415a0,   // lb.da.un_540 mi.lv.sa_543  uz.la.tr_543 un.ru.uk_322 
  0x1b303809, 0x6b100f11, 0x34003b18, 0x170407a9,   // tk.uz.tr_444 lv.lt.ceb_653  ks.ps.un_740 bg.ru.sr_544 
  // [65d0]
  0x1f000209, 0x28003411, 0x09002908, 0x55000d02,   // da.cy.un_440 ps.sd.un_630  sl.pl.un_430 cs.rw.un_220 
  0x5c4b0f12, 0x170a070b, 0x5c4b0f13, 0x182130a0,   // lv.mi.sa_654 bg.mk.sr_542  lv.mi.sa_665 uz.fa.ar_322 
  0x11170a09, 0x1c0d0960, 0x303c3813, 0x170415a7,   // mk.sr.ro_444 hi.ne.mr_664  tk.ug.uz_665 un.ru.sr_532 
  0x12213404, 0x3d342155, 0x6b1afc0c, 0x110a17a4,   // ps.fa.ur_332 fa.ps.ku_442  zzp.tl.ceb_543 sr.mk.ro_433 
  // [65e0]
  0x3f06fc0c, 0x0a0715a4, 0xfc005f0d, 0x2800fc12,   // zzp.de.af_543 un.bg.mk_433  tn.zzp.un_540 zzp.sw.un_640 
  0x35000a0e, 0x5d00180d, 0x58001d19, 0x65002708,   // mk.tg.un_550 ga.ss.un_540  la.om.un_750 gd.gv.un_430 
  0x30004d0e, 0xfc5f37a9, 0x06fc6b60, 0x10002511,   // aa.uz.un_550 st.tn.zzp_544  ceb.zzp.de_664 mn.be.un_630 
  0x2d0d3202, 0x483c370d, 0x2a64fcec, 0xfc001502,   // bs.cs.sk_222 ba.ug.tt_554  zzp.lg.mt_644 un.zzp.un_220 
  // [65f0]
  0x2d0d2502, 0x37484412, 0x18002721, 0x090d2dec,   // eu.cs.sk_222 kk.tt.ba_654  gd.ga.un_860 sk.cs.pl_644 
  0x080a360c, 0x17000812, 0x3d002129, 0x2c001b07,   // ab.mk.uk_543 uk.sr.un_640  fa.ku.un_960 tr.fy.un_420 
  0x39697612, 0x3c00251b, 0x12000a04, 0x12182307,   // crs.mfe.br_654 mn.ug.un_770  pt.hu.un_320 ky.ar.ur_432 
  0x0a00250d, 0x30003409, 0x18003d13, 0x12002e08,   // eu.pt.un_540 ps.uz.un_440  ku.ar.un_650 fo.hu.un_430 
  // [6600]
  0xfc002f0d, 0x45735fa9, 0x3b586407, 0x36003012,   // su.zzp.un_540 tn.ny.ln_544  lg.om.so_432 uz.ab.un_640 
  0x375f4508, 0xfc000209, 0x074225a4, 0x3b000405,   // ln.tn.st_443 da.zzp.un_440  eu.co.it_433 fi.so.un_330 
  0x2f644512, 0x73004207, 0x5d5a4912, 0x3b00640b,   // ln.lg.su_654 co.ny.un_420  to.sm.ss_654 lg.so.un_520 
  0x043748a0, 0x3b643f55, 0x45642d07, 0x190a23a9,   // tt.ba.ru_322 af.lg.so_442  sk.lg.ln_432 ca.pt.gl_544 
  // [6610]
  0x25003c0c, 0x5c0d09a0, 0x1b0969a7, 0x364837a9,   // ug.mn.un_530 hi.ne.sa_322  mfe.pl.tr_532 ba.tt.ab_544 
  0x4c4d5812, 0x34352504, 0x7300640d, 0x34192502,   // om.aa.wo_654 eu.zu.xh_332  lg.ny.un_540 eu.gl.xh_222 
  0x5607500c, 0x79736404, 0x251126a9, 0x65004c0c,   // fj.it.mg_543 lg.ny.war_332  ia.ro.eu_544 wo.gv.un_530 
  0x37002d04, 0x35003018, 0x3830230c, 0x442338a9,   // sk.st.un_320 uz.zu.un_740  ky.uz.tk_543 tk.ky.kk_544 
  // [6620]
  0x13091ca0, 0x3c30380c, 0x07153cee, 0x1000250b,   // mr.hi.bh_322 tk.uz.ug_543  ug.bg.un_420 mn.be.un_520 
  0x38531ea0, 0x383611ec, 0x495c0fee, 0x173508ad,   // ms.ht.tk_322 ro.ab.tk_644  lv.sa.to_422 uk.tg.sr_643 
  0x36385cec, 0x53385c12, 0x531b3804, 0x1d655ca0,   // sa.tk.gn_644 sa.tk.ht_654  tk.tr.ht_332 sa.gv.la_322 
  0x15630112, 0x430203a4, 0x53766912, 0x355f5d05,   // en.sco.un_654 nl.da.ie_433  mfe.crs.ht_654 ss.tn.zu_333 
  // [6630]
  0x69535c5a, 0x643463a0, 0x53765c0d, 0x1a3879a4,   // sa.ht.mfe_553 sco.xh.lg_322  sa.crs.ht_554 war.tk.tl_433 
  0x4b5c6a55, 0x1a6473a0, 0x4d0e0212, 0x35005307,   // haw.sa.mi_442 ny.lg.tl_322  da.is.aa_654 ht.zu.un_420 
  0x791a6908, 0x06150102, 0x031f0ea9, 0x4c35340d,   // mfe.tl.war_443 en.de.un_220  is.cy.nl_544 xh.zu.wo_554 
  0x1d1d150c, 0x64533507, 0xfe1103ee, 0x15fe02ee,   // un.la.la_543 zu.ht.lg_432  nl.ro.tlh_422 da.tlh.un_422 
  // [6640]
  0x12211807, 0x0700230c, 0x53640207, 0x6435340d,   // ar.fa.ur_432 ky.bg.un_530  da.lg.ht_432 xh.zu.lg_554 
  0x02470314, 0x2cfc0207, 0x34122107, 0xfe001508,   // nl.sn.da_666 da.zzp.fy_432  fa.ur.ps_432 un.tlh.un_430 
  0x48001b12, 0x4a004713, 0x06010504, 0x2e2102a4,   // tr.tt.un_640 sn.yo.un_650  fr.en.de_332 da.jw.fo_433 
  0x18256755, 0x07000413, 0x3428180d, 0x49001802,   // ak.eu.ga_442 ru.bg.un_650  ar.sd.ps_554 ga.to.un_220 
  // [6650]
  0x0a443707, 0x5c0d130c, 0x65270107, 0x13005c14,   // ba.kk.mk_432 bh.ne.sa_543  en.gd.gv_432 sa.bh.un_660 
  0x31481ba9, 0x3100481b, 0x4800310d, 0x02332ea7,   // tr.tt.az_544 tt.az.un_770  az.tt.un_540 fo.nn.da_532 
  0x1a270c02, 0x2c000212, 0x30000707, 0x0c0208a4,   // sv.gd.tl_222 da.fy.un_640  bg.uz.un_420 no.da.sv_433 
  0x251515ee, 0x2c5f1b08, 0x066301a4, 0x2f1c36a7,   // un.mn.un_420 tr.tn.fy_443  en.sco.de_433 gn.id.su_532 
  // [6660]
  0x6300110d, 0x4b006a08, 0x102f0fec, 0x10001204,   // ro.sco.un_540 haw.mi.un_430  lv.su.lt_644 hu.lt.un_320 
  0x0b291d07, 0x11695308, 0x6b2a1d07, 0x03403807,   // la.sl.es_432 ht.mfe.ro_443  la.mt.ceb_432 tk.lb.nl_432 
  0x345369ad, 0x440a17a0, 0x2e1333a4, 0x4d000513,   // mfe.ht.xh_643 sr.mk.kk_322  nn.et.fo_433 fr.aa.un_650 
  0x6b7906a9, 0x13002e04, 0x0b695308, 0x1800400e,   // de.war.ceb_544 fo.et.un_320  ht.mfe.es_443 lb.ga.un_550 
  // [6670]
  0x73392108, 0x20314604, 0x0e330802, 0x44233008,   // jw.br.ny_443 qu.az.sq_332  no.nn.is_222 uz.ky.kk_443 
  0x532d0d02, 0x401f2a13, 0x3412215a, 0x39001e13,   // cs.sk.ht_222 mt.cy.lb_665  fa.ur.ps_553 ms.br.un_650 
  0x1c2f1e07, 0x56002304, 0x080407ee, 0x3600fc05,   // ms.su.id_432 ca.mg.un_320  bg.ru.uk_422 zzp.gn.un_330 
  0x1d5d2fa4, 0x23000b07, 0x102f21a0, 0xfc00340c,   // su.ss.la_433 es.ca.un_420  jw.su.lt_322 xh.zzp.un_530 
  // [6680]
  0x21281213, 0x79353405, 0x2a002b08, 0x233748a0,   // ur.sd.fa_665 xh.zu.war_333  vi.mt.un_430 tt.ba.ky_322 
  0x22051e07, 0x73003909, 0xfc006308, 0x2c00fe08,   // ms.fr.oc_432 br.ny.un_440  sco.zzp.un_430 tlh.fy.un_430 
  0x06000208, 0x6bfe1d12, 0xfc0d2dee, 0x23040802,   // da.de.un_430 la.tlh.ceb_654  sk.cs.zzp_422 uk.ru.ky_222 
  0x1c5c0d60, 0x30481507, 0x30341207, 0x4a353404,   // ne.sa.mr_664 un.tt.uz_432  ur.ps.uz_432 xh.zu.yo_332 
  // [6690]
  0x101504a4, 0x373c30a7, 0x383023a9, 0x21343507,   // ru.be.un_430 uz.ug.ba_532  ky.uz.tk_544 zu.xh.jw_432 
  0x3d213055, 0x13003607, 0x07044405, 0x28181210,   // uz.fa.ku_442 gn.et.un_420  kk.ru.bg_333 ur.ar.sd_642 
  0x30483c05, 0x36001005, 0x443038a0, 0x483837ad,   // ug.tt.uz_333 be.ab.un_330  tk.uz.kk_322 ba.tk.tt_643 
  0x3c0a3608, 0x34001222, 0x2e001002, 0x73356412,   // ab.mk.ug_443 ur.ps.un_870  lt.fo.un_220 lg.zu.ny_654 
  // [66a0]
  0x47007312, 0x28477307, 0x3c15255a, 0x443c2308,   // ny.sn.un_640 ny.sn.sw_432  mn.ug.un_530 ky.ug.kk_443 
  0x55fc5712, 0x12282109, 0x3b000b02, 0x52002119,   // na.zzp.rw_654 fa.sd.ur_444  es.so.un_220 jw.ha.un_750 
  0x6959550e, 0x59005518, 0x284773af, 0x481510a4,   // rw.rn.mfe_555 rw.rn.un_740  ny.sn.sw_655 be.tt.un_430 
  0x35595508, 0x35fa5d0b, 0x55735907, 0x4759550d,   // rw.rn.zu_443 ss.nr.zu_542  rn.ny.rw_432 rw.rn.sn_554 
  // [66b0]
  0x21006404, 0x47595708, 0x532145ee, 0x06004704,   // lg.jw.un_320 na.rn.sn_443  ln.jw.ht_422 sn.de.un_320 
  0x070a04a0, 0x1030350c, 0x0b6452a0, 0x052b59a6,   // ru.mk.bg_322 tg.uz.be_543  ha.lg.es_322 rn.vi.fr_521 
  0x35003c0e, 0x31003202, 0x0b2321ee, 0xfc1f45ec,   // ug.tg.un_550 bs.az.un_220  jw.ca.es_422 ln.cy.zzp_644 
  0x112d0d04, 0x64002102, 0x38001114, 0x3600fc1a,   // cs.sk.ro_332 jw.lg.un_220  ro.tk.un_660 zzp.gn.un_760 
  // [66c0]
  0x1c5c0da0, 0x0700080c, 0x35151108, 0x126b7909,   // ne.sa.mr_322 uk.bg.un_530  ro.tg.un_430 war.ceb.hu_444 
  0x054221a4, 0x5300fc02, 0x03000236, 0x01271509,   // jw.co.fr_433 zzp.ht.un_220  da.nl.un_AA0 un.gd.en_444 
  0x00000342, 0x03641aad, 0x274c18af, 0x30351513,   // nl.un.un_C00 tl.lg.nl_643  ga.wo.gd_655 un.tg.uz_665 
  0x172a150c, 0x5503020d, 0x23002213, 0x4600610c,   // un.mt.sr_543 da.nl.rw_554  oc.ca.un_650 za.qu.un_530 
  // [66d0]
  0x23030208, 0x35004812, 0x234a220d, 0x18332e60,   // da.nl.ca_443 tt.tg.un_640  oc.yo.ca_554 fo.nn.ga_664 
  0x34003002, 0x320d17a0, 0x03180212, 0x2d0d69a4,   // uz.xh.un_220 sr.cs.bs_322  da.ga.nl_654 mfe.cs.sk_433 
  0x02163014, 0x1e1c030e, 0x32002013, 0x58004d13,   // uz.hr.da_666 nl.id.ms_555  sq.bs.un_650 aa.om.un_650 
  0x3200290d, 0x7600691b, 0x34001a13, 0x211228a9,   // sl.bs.un_540 mfe.crs.un_770  tl.xh.un_650 sd.ur.fa_544 
  // [66e0]
  0x15381707, 0x30000713, 0x4a232205, 0x3400090c,   // sr.tk.un_432 bg.uz.un_650  oc.ca.yo_333 pl.xh.un_530 
  0x40001508, 0x2200230e, 0x2afe4eac, 0x5e000d04,   // un.lb.un_430 ca.oc.un_550  ay.tlh.mt_632 cs.ts.un_320 
  0x1d09020c, 0x3e151809, 0x0200090d, 0x0d5c090c,   // da.pl.la_543 ga.rm.un_440  pl.da.un_540 hi.sa.ne_543 
  0x79006b34, 0x561a1c0c, 0x3500fe04, 0x1f184f0c,   // ceb.war.un_A80 id.tl.mg_543  tlh.zu.un_320 bi.ga.cy_543 
  // [66f0]
  0x1a301c0c, 0x212f200c, 0x3b1c1e0c, 0x033f3908,   // id.uz.tl_543 sq.su.jw_543  ms.id.so_543 br.af.nl_443 
  0x22234314, 0x04070860, 0x3b56580d, 0x4a306b0c,   // ie.ca.oc_666 uk.bg.ru_664  om.mg.so_554 ceb.uz.yo_543 
  0x27222311, 0x04353c04, 0x3530340c, 0x3035fe13,   // ca.oc.gd_653 ug.tg.ru_332  xh.uz.zu_543 tlh.zu.uz_665 
  0x3b315e0c, 0x4a07240c, 0x1f000908, 0x4b005a05,   // ts.az.so_543 eo.it.yo_543  pl.cy.un_430 sm.mi.un_330 
  // [6700]
  0x63001d14, 0x54513012, 0x30343dec, 0x21281ea4,   // la.sco.un_660 uz.kl.ik_654  ku.ps.uz_644 ms.sw.jw_433 
  0x4b001d08, 0x52045d12, 0x073015a7, 0x5a346a07,   // la.mi.un_430 ss.fi.ha_654  un.uz.bg_532 haw.xh.sm_432 
  0x150a0708, 0x0d00291a, 0x0523220c, 0x233c30a4,   // bg.mk.un_443 sl.cs.un_760  oc.ca.fr_543 uz.ug.ky_433 
  0x17290d04, 0x2f0522a0, 0x25000a0d, 0x125e39a4,   // cs.sl.sr_332 oc.fr.su_322  mk.mn.un_540 br.ts.hu_433 
  // [6710]
  0x2d005d09, 0x2d003608, 0x16000d19, 0x4800130c,   // ss.sk.un_440 gn.sk.un_430  cs.hr.un_750 et.tt.un_530 
  0x033b58a4, 0x1115370c, 0x02675812, 0x0340580c,   // om.so.nl_433 ba.ro.un_530  om.ak.da_654 om.lb.nl_543 
  0x38000a0e, 0x080a17a9, 0x4000580c, 0x150a0404,   // mk.tk.un_550 sr.mk.uk_544  om.lb.un_530 ru.mk.un_332 
  0x5c080204, 0x3b4a5807, 0x0251fc0b, 0x0c0838ee,   // da.no.sa_332 om.yo.so_432  zzp.kl.da_542 tk.no.sv_422 
  // [6720]
  0x02006308, 0x5d003605, 0x28341207, 0x644a580c,   // sco.da.un_430 gn.ss.un_330  ur.ps.sd_432 om.yo.lg_543 
  0x033f64ad, 0x4c645812, 0x03005813, 0x12342155,   // lg.af.nl_643 om.lg.wo_654  om.nl.un_650 fa.ps.ur_442 
  0x28122108, 0x39001f04, 0x441511a4, 0x00006003,   // fa.ur.sd_443 cy.br.un_320  ro.kk.un_430 vo.un.un_300 
  0x396505a7, 0x0f3216a0, 0x0106fc07, 0x3723440d,   // fr.gv.br_532 hr.bs.lv_322  zzp.de.en_432 kk.ky.ba_554 
  // [6730]
  0x31002a02, 0x1a003502, 0x13006404, 0x38004814,   // mt.az.un_220 zu.tl.un_220  lg.et.un_320 tt.tk.un_660 
  0x0e004f07, 0xfe002a08, 0x19360b0d, 0x180d0e04,   // bi.is.un_420 mt.tlh.un_430  es.gn.gl_554 is.cs.ga_332 
  0x33006304, 0x2c003f1a, 0x64363ba7, 0x15080404,   // sco.nn.un_320 af.fy.un_760  so.gn.lg_532 ru.uk.un_332 
  0x10002d0d, 0x485564ee, 0x18000d0b, 0x0e005d05,   // sk.lt.un_540 lg.rw.tt_422  cs.ga.un_520 ss.is.un_330 
  // [6740]
  0x0c30420c, 0x23003505, 0x6b212f5a, 0x6400fe0b,   // co.uz.sv_543 tg.ky.un_330  su.jw.ceb_553 tlh.lg.un_520 
  0x1f01630c, 0x0600090c, 0x354a45ec, 0x5e6a780c,   // sco.en.cy_543 pl.de.un_530  ln.yo.zu_644 ve.haw.ts_543 
  0x2b5e6455, 0x4c1f2a08, 0x2145500c, 0x174a580c,   // lg.ts.vi_442 mt.cy.wo_443  fj.ln.jw_543 om.yo.sr_543 
  0x2d0d1017, 0x313007ee, 0x792d0d60, 0x1e020f04,   // lt.cs.sk_753 it.uz.az_422  cs.sk.war_664 lv.da.ms_332 
  // [6750]
  0x150a2507, 0x512252ec, 0x3f001309, 0x17111e0c,   // mn.mk.un_432 ha.oc.kl_644  et.af.un_440 ms.ro.sr_543 
  0x73353b02, 0x0f6a5c60, 0x53583407, 0x35581904,   // so.zu.ny_222 sa.haw.lv_664  xh.om.ht_432 gl.om.zu_332 
  0x0a001009, 0x6a280904, 0x35004509, 0x3d003019,   // be.mk.un_440 pl.sw.haw_332  ln.zu.un_440 uz.ku.un_750 
  0x295e6b0c, 0x1b38110c, 0x08170a0c, 0x0a000813,   // ceb.ts.sl_543 ro.tk.tr_543  mk.sr.uk_543 uk.mk.un_650 
  // [6760]
  0x170a15ee, 0x400648ad, 0x182128a0, 0x3035380c,   // un.mk.sr_422 tt.de.lb_643  sd.fa.ar_322 tk.tg.uz_543 
  0x4a002308, 0x0d00360c, 0x1c095cee, 0x16291007,   // ca.yo.un_430 gn.cs.un_530  sa.hi.mr_422 lt.sl.hr_432 
  0x25002311, 0x2a2c0307, 0x2a002407, 0x070a38ee,   // ky.mn.un_630 nl.fy.mt_432  eo.mt.un_420 tk.mk.bg_422 
  0x3500340d, 0x24000207, 0x12610208, 0x233048ee,   // xh.zu.un_540 da.eo.un_420  da.za.hu_443 tt.uz.ky_422 
  // [6770]
  0x04151008, 0x2b321602, 0x2444230c, 0x2731250c,   // be.ru.un_430 hr.bs.vi_222  ky.kk.yi_543 eu.az.gd_543 
  0x261d25ec, 0x13000409, 0x3e003902, 0x0435300c,   // eu.la.ia_644 fi.et.un_440  br.rm.un_220 uz.tg.ru_543 
  0x033308a0, 0x23481507, 0x1800250e, 0x6b591aad,   // no.nn.nl_322 un.tt.ky_432  mn.ar.un_550 tl.rn.ceb_643 
  0x06004c07, 0x2a2d0d02, 0x68021dee, 0x556828ad,   // wo.de.un_420 cs.sk.mt_222  la.da.ig_422 sw.ig.rw_643 
  // [6780]
  0x04151714, 0x4d5c1a0c, 0x233c3809, 0x24382504,   // sr.ru.un_660 tl.sa.aa_543  tk.ug.ky_444 eu.tk.eo_332 
  0x643768ad, 0x39000804, 0x30001212, 0xfc2868a4,   // ig.st.lg_643 no.br.un_320  ur.uz.un_640 ig.sw.zzp_433 
  0x44003c21, 0x0e0d2e04, 0x34003021, 0x0600040d,   // ug.kk.un_860 fo.cs.is_332  uz.ps.un_860 fi.de.un_540 
  0x0228fc12, 0x44003712, 0x28003409, 0x23002705,   // zzp.sw.da_654 ba.kk.un_640  ps.sd.un_440 gd.ca.un_330 
  // [6790]
  0x2f004c07, 0x12004a04, 0x05002f0d, 0x321611a9,   // wo.su.un_420 yo.hu.un_320  su.fr.un_540 ro.hr.bs_544 
  0x213d3c04, 0x3534fa09, 0x4a060e05, 0x0f1360ee,   // ug.ku.fa_332 nr.xh.zu_444  is.de.yo_333 vo.et.lv_422 
  0x642c0307, 0x04070a09, 0x25070aa0, 0x622718af,   // nl.fy.lg_432 mk.bg.ru_444  mk.bg.mn_322 ga.gd.kha_655 
  0x13000304, 0x18002709, 0x31003b04, 0x3b4258ec,   // nl.et.un_320 gd.ga.un_440  so.az.un_320 om.co.so_644 
  // [67a0]
  0x301827ee, 0x1f652714, 0x31305ba0, 0x5e3727a9,   // gd.ga.uz_422 gd.gv.cy_666  sg.uz.az_322 gd.st.ts_544 
  0x130304a4, 0x030813a0, 0x17153807, 0x5c1c0d14,   // fi.nl.et_433 et.no.nl_322  tk.sr.un_420 ne.mr.sa_666 
  0x07003812, 0x304648ad, 0x2d0d19ed, 0x48311b08,   // tk.bg.un_640 tt.qu.uz_643  gl.cs.sk_622 tr.az.tt_443 
  0x12001907, 0x052220a4, 0x1b003902, 0x044813a4,   // gl.hu.un_420 sq.oc.fr_433  br.tr.un_220 et.tt.fi_433 
  // [67b0]
  0x48002513, 0x0d1c5c13, 0x070a23a0, 0x182834ee,   // mn.tt.un_650 sa.mr.ne_665  ky.mk.bg_322 ps.sd.ar_422 
  0x1200190c, 0x0a070409, 0x04000605, 0x08001512,   // gl.hu.un_530 ru.bg.mk_444  de.fi.un_330 un.uk.un_640 
  0x0b0a4aa4, 0x19001b04, 0x1500300d, 0x150811a9,   // yo.pt.es_433 tr.gl.un_320  uz.un.un_540 ro.uk.un_544 
  0x070a4809, 0x73037805, 0x391625a0, 0x0835100c,   // tt.mk.bg_444 ve.nl.ny_333  eu.hr.br_322 be.tg.uk_543 
  // [67c0]
  0x215537a9, 0x23002209, 0x233044a7, 0x03002c08,   // st.rw.jw_544 oc.ca.un_440  kk.uz.ky_532 fy.nl.un_430 
  0x02000604, 0x4a005502, 0x792602a4, 0x0e120c0c,   // de.da.un_320 rw.yo.un_220  da.ia.war_433 sv.hu.is_543 
  0x3e630104, 0x0a190b0d, 0x190a0ba0, 0x31001234,   // en.sco.rm_332 es.gl.pt_554  es.pt.gl_322 hu.az.un_A80 
  0x2d150dec, 0x55005e0c, 0x0f091807, 0x0a251709,   // cs.sk.un_640 ts.rw.un_530  ga.pl.lv_432 sr.mn.mk_444 
  // [67d0]
  0x376455a0, 0x3c002321, 0x55374cec, 0x4823370b,   // rw.lg.st_322 ky.ug.un_860  wo.st.rw_644 ba.ky.tt_542 
  0x15120208, 0x34002723, 0x15030255, 0x37303507,   // da.hu.un_443 gd.xh.un_880  da.nl.un_442 tg.uz.ba_432 
  0x3202280c, 0x5d355ead, 0x30160fec, 0x2300270e,   // sw.da.bs_543 ts.zu.ss_643  lv.hr.uz_644 gd.ca.un_550 
  0x684c62a4, 0x354727a0, 0x2700fe0d, 0x0c083312,   // kha.wo.ig_433 gd.sn.zu_322  tlh.gd.un_540 nn.no.sv_654 
  // [67e0]
  0x0d3e2dee, 0x12182e55, 0x303723a0, 0x123e0ca0,   // sk.rm.cs_422 fo.ga.hu_442  ky.ba.uz_322 sv.rm.hu_322 
  0x28123da6, 0x12000702, 0x44482304, 0x23002710,   // ku.ur.sd_521 it.hu.un_220  ky.tt.kk_332 gd.ca.un_620 
  0x2a2d0da4, 0x0f002907, 0x0d002f07, 0x0273340c,   // cs.sk.mt_433 sl.lv.un_420  su.cs.un_420 xh.ny.da_543 
  0x12072a09, 0x5d000d08, 0x340225a9, 0x25365fa4,   // mt.it.hu_444 cs.ss.un_430  eu.da.xh_544 tn.gn.eu_433 
  // [67f0]
  0x08170a02, 0x6a1e1c05, 0x36321605, 0x36005014,   // mk.sr.uk_222 id.ms.haw_333  hr.bs.gn_333 fj.gn.un_660 
  0x2402250c, 0x37234413, 0x37697612, 0x40062102,   // eu.da.eo_543 kk.ky.ba_665  crs.mfe.st_654 jw.de.lb_222 
  0x300748ee, 0x07122a11, 0x303f0608, 0x342545ad,   // tt.bg.uz_422 mt.hu.it_653  de.af.uz_443 ln.eu.xh_643 
  0x21004c05, 0x233730a4, 0x2500340d, 0x074212ee,   // wo.jw.un_330 uz.ba.ky_433  xh.eu.un_540 hu.co.it_422 
  
  // [6800]
  0x532049a0, 0x642934a0, 0x556459a7, 0x455d64a4,   // to.sq.ht_322 xh.sl.lg_322  rn.lg.rw_532 lg.ss.ln_433 
  0x2500341a, 0x35fa5907, 0x555f25ad, 0x472536ec,   // xh.eu.un_760 rn.nr.zu_432  eu.tn.rw_643 gn.eu.sn_644 
  0x1c5f1e0c, 0x40002a04, 0x2402600c, 0x02002513,   // ms.tn.id_543 mt.lb.un_320  vo.da.eo_543 eu.da.un_650 
  0x2800fe07, 0x28341855, 0x472d1704, 0x07041707,   // tlh.sw.un_420 ga.xh.sw_442  sr.sk.sn_332 sr.ru.bg_432 
  // [6810]
  0x293736ad, 0x35301512, 0x3735305a, 0x3d211208,   // gn.st.sl_643 un.uz.tg_654  uz.tg.ba_553 ur.fa.ku_443 
  0x34003618, 0x0d00120e, 0x25001013, 0x04082304,   // gn.xh.un_740 hu.cs.un_550  be.mn.un_650 ky.uk.ru_332 
  0x12000d0c, 0x22000a05, 0x15351507, 0x3500440d,   // cs.hu.un_530 pt.oc.un_330  un.tg.un_432 kk.tg.un_540 
  0x0825360c, 0x580364a0, 0x5c091302, 0x58006407,   // ab.mn.uk_543 lg.nl.om_322  bh.hi.sa_222 lg.om.un_420 
  // [6820]
  0x5f024ca4, 0x07101504, 0x3b002822, 0x12000d19,   // wo.da.tn_433 un.be.bg_332  sw.so.un_870 cs.hu.un_750 
  0x122130ee, 0x40005f0e, 0x2e0e0c0d, 0x5b003408,   // uz.fa.ur_422 tn.lb.un_550  sv.is.fo_554 xh.sg.un_430 
  0x52005c04, 0x1a790b08, 0x2d001902, 0x3f3b0308,   // sa.ha.un_320 es.war.tl_443  gl.sk.un_220 nl.so.af_443 
  0x0e4006ec, 0x04250a02, 0x0200580b, 0x08170712,   // de.lb.is_644 mk.mn.ru_222  om.da.un_520 bg.sr.uk_654 
  // [6830]
  0x07170805, 0x4f646704, 0x21283060, 0x3700482b,   // uk.sr.bg_333 ak.lg.bi_332  uz.sd.fa_664 tt.ba.un_980 
  0x4a3b4c11, 0x4a003b05, 0x64211aee, 0x35345509,   // wo.so.yo_653 so.yo.un_330  tl.jw.lg_422 rw.xh.zu_444 
  0xfc002c07, 0x3f644c0c, 0x04350a0c, 0x0e400604,   // fy.zzp.un_420 wo.lg.af_543  mk.tg.ru_543 de.lb.is_332 
  0x4d00580e, 0x34483507, 0x40060e07, 0x360b4707,   // om.aa.un_550 zu.tt.xh_432  is.de.lb_432 sn.es.gn_432 
  // [6840]
  0x79531aa4, 0x3b033f0c, 0x033f0207, 0x475c1aad,   // tl.ht.war_433 af.nl.so_543  da.af.nl_432 tl.sa.sn_643 
  0x53485508, 0x0f005a02, 0x5c00470d, 0x091c0d0b,   // rw.tt.ht_443 sm.lv.un_220  sn.sa.un_540 ne.mr.hi_542 
  0x175c095a, 0x5d73470c, 0x3b5d1aad, 0x0900fc12,   // pl.sa.sr_553 sn.ny.ss_543  tl.ss.so_643 zzp.pl.un_640 
  0x630640af, 0x4000430d, 0x1f006312, 0x5c2c3fec,   // lb.de.sco_655 ie.lb.un_540  sco.cy.un_640 af.fy.sa_644 
  // [6850]
  0x0a10080d, 0x02206412, 0x00003f2d, 0x2c000104,   // uk.be.mk_554 lg.sq.da_654  af.un.un_A00 en.fy.un_320 
  0x65004013, 0x646301a4, 0x5a005c07, 0x0430fea9,   // lb.gv.un_650 en.sco.lg_433  sa.sm.un_420 tlh.uz.fi_544 
  0x65005635, 0x091c0d5a, 0x4c3b1a13, 0x640d01ec,   // mg.gv.un_A90 ne.mr.hi_553  tl.so.wo_665 en.cs.lg_644 
  0x00005524, 0x202c6512, 0x01006411, 0x30551b05,   // rw.un.un_900 gv.fy.sq_654  lg.en.un_630 tr.rw.uz_333 
  // [6860]
  0x60651fec, 0x026564ad, 0x09001108, 0x56000212,   // cy.gv.vo_644 lg.gv.da_643  ro.pl.un_430 da.mg.un_640 
  0x29000304, 0x1e001c0c, 0x55655912, 0x1f3f56af,   // nl.sl.un_320 id.ms.un_530  rn.gv.rw_654 mg.af.cy_655 
  0x025c36ad, 0x36005912, 0x1f092c0c, 0x37002504,   // gn.sa.da_643 rn.gn.un_640  fy.pl.cy_543 mn.ba.un_320 
  0x4844230c, 0x79304608, 0x38791a0c, 0x443707a0,   // ky.kk.tt_543 qu.uz.war_443  tl.war.tk_543 bg.ba.kk_322 
  // [6870]
  0x2a002e08, 0x53346904, 0x0f002d07, 0xfc003802,   // fo.mt.un_430 mfe.xh.ht_332  sk.lv.un_420 tk.zzp.un_220 
  0x23000407, 0x290d2d0c, 0x0e001709, 0x1b2413a0,   // ru.ky.un_420 sk.cs.sl_543  sr.is.un_440 et.eo.tr_322 
  0x2d0d2409, 0x0b002207, 0x37481514, 0x5c00090d,   // eo.cs.sk_444 oc.es.un_420  un.tt.ba_666 hi.sa.un_540 
  0x483530ad, 0x342130ec, 0x532322a4, 0x06000c09,   // uz.tg.tt_643 uz.fa.ps_644  oc.ca.ht_433 sv.de.un_440 
  // [6880]
  0x04000814, 0x0a1708af, 0x230830a4, 0x34004409,   // uk.ru.un_660 uk.sr.mk_655  uz.uk.ky_433 kk.ps.un_440 
  0x21004407, 0x04100804, 0x23443c14, 0x31381ba0,   // kk.fa.un_420 uk.be.ru_332  ug.kk.ky_666 tr.tk.az_322 
  0x38303c08, 0x3400680e, 0x10001508, 0x2a002c04,   // ug.uz.tk_443 ig.xh.un_550  un.be.un_430 fy.mt.un_320 
  0x64006307, 0x2a000802, 0x781a30ec, 0x30007907,   // sco.lg.un_420 no.mt.un_220  uz.tl.ve_644 war.uz.un_420 
  // [6890]
  0x5c3028a9, 0x3b2834af, 0x0a230712, 0x353b5ca4,   // sw.uz.sa_544 ps.sd.ks_655  bg.ky.mk_654 sa.so.zu_433 
  0x73280208, 0x3b00fe0d, 0x79006b23, 0x48233009,   // da.sw.ny_443 tlh.so.un_540  ceb.war.un_880 uz.ky.tt_444 
  0x15043705, 0x0b190a08, 0x55350208, 0x651e63a0,   // ba.ru.un_333 pt.gl.es_443  da.zu.rw_443 sco.ms.gv_322 
  0x18213007, 0x465c6302, 0x67033f12, 0x025530a9,   // uz.fa.ar_432 sco.sa.qu_222  af.nl.ak_654 uz.rw.da_544 
  // [68a0]
  0x645c02af, 0x20002c04, 0x221b5cad, 0x332c0302,   // da.sa.lg_655 fy.sq.un_320  sa.tr.oc_643 nl.fy.nn_222 
  0x574652a4, 0x39233104, 0x795c30a4, 0x043308ad,   // ha.qu.na_433 az.ca.br_332  uz.sa.war_433 no.nn.fi_643 
  0x12002009, 0x65003905, 0x485c30ad, 0x153bfe55,   // sq.hu.un_440 br.gv.un_330  uz.sa.tt_643 tlh.so.un_442 
  0x795c6ba4, 0x3000460e, 0x044415a0, 0x1b00100c,   // ceb.sa.war_433 qu.uz.un_550  un.kk.ru_322 lt.tr.un_530 
  // [68b0]
  0x21342808, 0x190b0a0e, 0x37234807, 0x48233c12,   // sd.ps.fa_443 pt.es.gl_555  tt.ky.ba_432 ug.ky.tt_654 
  0x0b0e18a4, 0x16003907, 0xfc330808, 0x44040755,   // ga.is.es_433 br.hr.un_420  no.nn.zzp_443 bg.ru.kk_442 
  0x0ffc10ad, 0x3c374412, 0x25000a04, 0x7350520c,   // lt.zzp.lv_643 kk.ba.ug_654  mk.mn.un_320 ha.fj.ny_543 
  0x02400608, 0x353037a4, 0x3b003019, 0x08380713,   // de.lb.da_443 ba.uz.tg_433  uz.ks.un_750 bg.tk.uk_665 
  // [68c0]
  0x343d30a0, 0x3b2ffcee, 0x0f2939ee, 0x023b67a4,   // uz.ku.ps_322 zzp.su.so_422  br.sl.lv_422 ak.so.da_433 
  0x61556413, 0x55355904, 0x023b2a08, 0x64353413,   // lg.rw.za_665 rn.zu.rw_332  mt.so.da_443 xh.zu.lg_665 
  0x2b000207, 0x04295302, 0x020812a9, 0x1008360e,   // da.vi.un_420 ht.sl.fi_222  hu.no.da_544 ab.uk.be_555 
  0x10001121, 0x37483ca4, 0x15001508, 0x34001219,   // ro.be.un_860 ug.tt.ba_433  un.un.un_430 ur.ps.un_750 
  // [68d0]
  0xfc004d13, 0x3b4c0207, 0x5c005914, 0x46353405,   // aa.zzp.un_650 da.wo.so_432  rn.sa.un_660 xh.zu.qu_333 
  0x4600fc0e, 0x35251505, 0x37005f2b, 0x353455a0,   // zzp.qu.un_550 un.mn.tg_333  tn.st.un_980 rw.xh.zu_322 
  0x3800200d, 0x07170aa7, 0x11073ca4, 0x15080708,   // sq.tk.un_540 mk.sr.bg_532  ug.bg.ro_433 bg.uk.un_443 
  0x37234404, 0x35000408, 0x5a000f04, 0x10000712,   // kk.ky.ba_332 ru.tg.un_430  lv.sm.un_320 bg.be.un_640 
  // [68e0]
  0x3c303805, 0x341218a7, 0x37483014, 0x081115a4,   // tk.uz.ug_333 ar.ur.ps_532  uz.tt.ba_666 un.ro.uk_433 
  0x38303c12, 0x21344405, 0x08172304, 0x12003b11,   // ug.uz.tk_654 kk.ps.fa_333  ky.sr.uk_332 ks.ur.un_630 
  0x53002a02, 0x055663a0, 0x082330ee, 0x08000702,   // mt.ht.un_220 sco.mg.fr_322  uz.ky.uk_422 bg.uk.un_220 
  0x170a3805, 0x23353ca9, 0x0a122dec, 0x0c000904,   // tk.mk.sr_333 ug.tg.ky_544  sk.hu.pt_644 pl.sv.un_320 
  // [68f0]
  0x44353c07, 0x0e002e0b, 0x09001102, 0x480a1702,   // ug.tg.kk_432 fo.is.un_520  ro.pl.un_220 sr.mk.tt_222 
  0x3e1d06ec, 0x30153cad, 0x4410080b, 0x123b3d0c,   // de.la.rm_644 ug.uz.un_630  uk.be.kk_542 ku.ks.ur_543 
  0x3b3d30af, 0x3000382c, 0x25290f12, 0x2c1640ee,   // uz.ku.ks_655 tk.uz.un_990  lv.sl.eu_654 lb.hr.fy_422 
  0x30382311, 0x0e3f0308, 0x21026307, 0x3d213060,   // ky.tk.uz_653 nl.af.is_443  sco.da.jw_432 uz.fa.ku_664 
  // [6900]
  0x02333fa4, 0x38001534, 0x19061da0, 0x1d022a0c,   // af.nn.da_433 un.tk.un_A80  la.de.gl_322 mt.da.la_543 
  0x11001d05, 0x170d09a4, 0x07250a0d, 0x1d002c08,   // la.ro.un_330 pl.cs.sr_433  mk.mn.bg_554 fy.la.un_430 
  0x06016304, 0x2500370c, 0x150302ad, 0x0f1060ad,   // sco.en.de_332 ba.mn.un_530  da.nl.un_643 vo.lt.lv_643 
  0x1c0d1309, 0x0e400ca0, 0x15240102, 0x431d02af,   // bh.ne.mr_444 sv.lb.is_322  en.eo.un_222 da.la.ie_655 
  // [6910]
  0x1d0908a0, 0x23443c5a, 0x18030214, 0x13004902,   // no.pl.la_322 ug.kk.ky_553  da.nl.ga_666 to.et.un_220 
  0x040825ee, 0x060207a0, 0x0c000e09, 0x22001534,   // mn.uk.ru_422 it.da.de_322  is.sv.un_440 un.oc.un_A80 
  0x584c4daf, 0x654d4c0c, 0x1b000c13, 0x4c2c3f07,   // aa.wo.om_655 wo.aa.gv_543  sv.tr.un_650 af.fy.wo_432 
  0x0e000c0c, 0x3d003402, 0x2103025a, 0x47000404,   // sv.is.un_530 ps.ku.un_220  da.nl.jw_553 fi.sn.un_320 
  // [6920]
  0x4d020313, 0x3f134d08, 0x64002104, 0x23443c13,   // nl.da.aa_665 aa.et.af_443  jw.lg.un_320 ug.kk.ky_665 
  0x64045a55, 0x36756712, 0x633b4c07, 0x3700150e,   // sm.fi.lg_442 ak.nso.gn_654  wo.so.sco_432 un.ba.un_550 
  0x3b004d14, 0x3b586404, 0x4d4c3b12, 0x4d6303ec,   // aa.so.un_660 lg.om.so_332  so.wo.aa_654 nl.sco.aa_644 
  0x642a07af, 0x25402ca0, 0x422a0712, 0x65016302,   // it.mt.lg_655 fy.lb.eu_322  it.mt.co_654 sco.en.gv_222 
  // [6930]
  0x07002a23, 0x65001305, 0x4d4c04a9, 0x0700420d,   // mt.it.un_880 et.gv.un_330  fi.wo.aa_544 co.it.un_540 
  0x2a640204, 0x13000411, 0x64004204, 0x58000104,   // da.lg.mt_332 fi.et.un_630  co.lg.un_320 en.om.un_320 
  0x42002a22, 0x041301a0, 0x041303a4, 0x6b791312,   // mt.co.un_870 en.et.fi_322  nl.et.fi_433 et.war.ceb_654 
  0x1e002021, 0x4830130e, 0x12006407, 0x0a00131a,   // ti.am.un_860 et.uz.tt_555  lg.hu.un_420 et.pt.un_760 
  // [6940]
  0x11fe13ee, 0x2a006413, 0x1a336b0c, 0x48004414,   // et.tlh.ro_422 lg.mt.un_650  ceb.nn.tl_543 kk.tt.un_660 
  0x1a216b08, 0x48000104, 0x422a64ad, 0x1d000808,   // ceb.jw.tl_443 en.tt.un_320  lg.mt.co_643 no.la.un_430 
  0x42002a08, 0x3e13220c, 0x42072a12, 0x1c5c0d55,   // mt.co.un_430 oc.et.rm_543  mt.it.co_654 ne.sa.mr_442 
  0x3000480c, 0x34211260, 0x2a00641b, 0x07044207,   // tt.uz.un_530 ur.fa.ps_664  lg.mt.un_770 co.fi.it_432 
  // [6950]
  0x374830a0, 0x4823300c, 0x2a5369a9, 0x564205a7,   // uz.tt.ba_322 uz.ky.tt_543  mfe.ht.mt_544 fr.co.mg_532 
  0x30244802, 0x48113c07, 0x13001c07, 0x373c150c,   // tt.eo.uz_222 ug.ro.tt_432  mr.bh.un_420 un.ug.ba_543 
  0x081711a7, 0x481221a6, 0x033f57a7, 0x2300fe04,   // ro.sr.uk_532 jw.hu.tt_521  na.af.nl_532 tlh.ca.un_320 
  0x17351155, 0x173511af, 0x231038ee, 0x0f004908,   // ro.tg.sr_442 ro.tg.sr_655  tk.be.ky_422 to.lv.un_430 
  // [6960]
  0x28006918, 0x100f2604, 0x1d5d2608, 0x300835a0,   // mfe.sw.un_740 ia.lv.lt_332  ia.ss.la_443 tg.uk.uz_322 
  0x2e000218, 0x67005d13, 0x08035ca7, 0x07173002,   // da.fo.un_740 ss.ak.un_650  sa.nl.no_532 uz.sr.bg_222 
  0x125d5c07, 0x233538a4, 0x5d125c55, 0x07004805,   // sa.ss.hu_432 tk.tg.ky_433  sa.hu.ss_442 tt.bg.un_330 
  0x47002807, 0x2e510255, 0x033f2cad, 0x1300fe0d,   // sw.sn.un_420 da.kl.fo_442  fy.af.nl_643 tlh.et.un_540 
  // [6970]
  0x13311bee, 0x12004804, 0x0e0313a4, 0x16005e02,   // tr.az.et_422 tt.hu.un_320  et.nl.is_433 ts.hr.un_220 
  0xfc006307, 0x081333a9, 0x15215d55, 0x48fe13a4,   // sco.zzp.un_420 nn.et.no_544  ss.jw.un_442 et.tlh.tt_433 
  0x5d003709, 0x2e005a05, 0x035e5d04, 0x2e065107,   // st.ss.un_440 sm.fo.un_330  ss.ts.nl_332 kl.de.fo_432 
  0x420e050c, 0xfa5d34a9, 0x51125ca7, 0x65012fa0,   // fr.is.co_543 xh.ss.nr_544  sa.hu.kl_532 su.en.gv_322 
  // [6980]
  0x37755f14, 0x2c006b07, 0x35005805, 0x38481b04,   // tn.nso.st_666 ceb.fy.un_420  om.zu.un_330 tr.tt.tk_332 
  0x0e002e2c, 0x345d35a9, 0x5e00470c, 0x0e102ea4,   // fo.is.un_990 zu.ss.xh_544  sn.ts.un_530 fo.lt.is_433 
  0x04071509, 0x5f00371a, 0x031348a0, 0x30383c60,   // un.bg.ru_444 st.tn.un_760  tt.et.nl_322 ug.tk.uz_664 
  0x0e4833a4, 0x383e2c08, 0x09796304, 0x380e2505,   // nn.tt.is_433 fy.rm.tk_443  sco.war.pl_332 eu.is.tk_333 
  // [6990]
  0x36001514, 0x0f005c07, 0x46004e08, 0x5d005e1b,   // un.ab.un_660 sa.lv.un_420  ay.qu.un_430 ts.ss.un_770 
  0x3534200c, 0x233015a0, 0x0102620c, 0x17000a22,   // sq.xh.zu_543 un.uz.ky_322  kha.da.en_543 mk.sr.un_870 
  0x1d2101a0, 0x31003b12, 0x442334a4, 0x0c0d02a0,   // en.jw.la_322 so.az.un_640  ps.ky.kk_433 da.cs.sv_322 
  0x303c4413, 0x2348380c, 0x30350707, 0x10041da0,   // kk.ug.uz_665 tk.tt.ky_543  bg.tg.uz_432 la.fi.lt_322 
  // [69a0]
  0x5c001313, 0x10003004, 0x23003409, 0x0a002529,   // bh.sa.un_650 uz.be.un_320  ps.ky.un_440 mn.mk.un_960 
  0x04003505, 0x33002a04, 0x28003007, 0x4900641b,   // tg.ru.un_330 mt.nn.un_320  uz.sd.un_420 lg.to.un_770 
  0x6a644c0c, 0x0e000602, 0x15003009, 0x4c00420c,   // wo.lg.haw_543 de.is.un_220  uz.un.un_440 co.wo.un_530 
  0x114423ec, 0x524c64af, 0x253c3060, 0x131c0912,   // ky.kk.ro_644 lg.wo.ha_655  uz.ug.mn_664 hi.mr.bh_654 
  // [69b0]
  0x4a004207, 0x12003c13, 0x375f28af, 0x2e4a0ea7,   // co.yo.un_420 ug.ur.un_650  sw.tn.st_655 is.yo.fo_532 
  0x5300630d, 0x033f04ad, 0x636a0107, 0x434a28a4,   // sco.ht.un_540 fi.af.nl_643  en.haw.sco_432 sw.yo.ie_433 
  0x27111855, 0x26284260, 0x1b00651b, 0x12343ba7,   // ga.ro.gd_442 co.sw.ia_664  gv.tr.un_770 ks.ps.ur_532 
  0x04130209, 0x300a0705, 0x270748a0, 0x28007323,   // da.et.fi_444 bg.mk.uz_333  tt.it.gd_322 ny.sw.un_880 
  // [69c0]
  0x5f691b05, 0x13182760, 0x2b6b01a4, 0x184c4da7,   // tr.mfe.tn_333 gd.ga.et_664  en.ceb.vi_433 aa.wo.ga_532 
  0xfc000221, 0x532811ec, 0x0300790c, 0x354c34a4,   // da.zzp.un_860 ro.sw.ht_644  war.nl.un_530 xh.wo.zu_433 
  0x5e002309, 0x0802fca0, 0x5e005f19, 0x2e0efca4,   // ca.ts.un_440 zzp.da.no_322  tn.ts.un_750 zzp.is.fo_433 
  0x115e280c, 0x2e0e33a9, 0x064efc0c, 0x63005e0d,   // sw.ts.ro_543 nn.is.fo_544  zzp.ay.de_543 ts.sco.un_540 
  // [69d0]
  0x3f2c03a4, 0x2c63010c, 0x12182808, 0x351b11a0,   // nl.fy.af_433 en.sco.fy_543  sd.ar.ur_443 ro.tr.zu_322 
  0x154a01a0, 0x2d0657ee, 0x133f0304, 0xfc024007,   // en.yo.un_322 na.de.sk_422  nl.af.et_332 lb.da.zzp_432 
  0x04250704, 0x02000e05, 0x09fc0207, 0x30003821,   // bg.mn.ru_332 is.da.un_330  da.zzp.pl_432 tk.uz.un_860 
  0x054039a0, 0x0d091ca6, 0x09130d13, 0x13321708,   // br.lb.fr_322 mr.hi.ne_521  ne.bh.hi_665 sr.bs.et_443 
  // [69e0]
  0x0200fc14, 0x633e01a4, 0x0a1710ad, 0x400c0607,   // zzp.da.un_660 en.rm.sco_433  be.sr.mk_643 de.sv.lb_432 
  0x0e00021e, 0x0e0d2da4, 0x653062a6, 0x182112ee,   // da.is.un_830 sk.cs.is_433  kha.uz.gv_521 ur.fa.ar_422 
  0x2e00020c, 0x1537350c, 0x2d0d19a4, 0x535c4ba0,   // da.fo.un_530 tg.ba.un_543  gl.cs.sk_433 mi.sa.ht_322 
  0x2e1d02a4, 0x3523300c, 0x13060c07, 0x18001613,   // da.la.fo_433 uz.ky.tg_543  sv.de.et_432 th.ar.un_650 
  // [69f0]
  0x65003202, 0x211234a0, 0x28213404, 0x35171555,   // bs.gv.un_220 ps.ur.fa_322  ps.fa.sd_332 un.sr.tg_442 
  0x653f5104, 0x06000804, 0x65023b04, 0x04006508,   // kl.af.gv_332 no.de.un_320  so.da.gv_332 gv.fi.un_430 
  0x40133ba7, 0x23003c2a, 0x2c4811a6, 0x124a5b0c,   // so.et.lb_532 ug.ky.un_970  ro.tt.fy_521 sg.yo.hu_543 
  0x4d1801a0, 0x39653f08, 0x291610a4, 0x3b085804,   // en.ga.aa_322 af.gv.br_443  lt.hr.sl_433 om.no.so_332 
  // [6a00]
  0x65693f04, 0x3f3b13a0, 0x123306a0, 0x653b58ad,   // af.mfe.gv_332 et.so.af_322  de.nn.hu_322 om.so.gv_643 
  0x1c090d0d, 0x073530a4, 0x402813a0, 0x133f0a07,   // ne.hi.mr_554 uz.tg.bg_433  et.sw.lb_322 pt.af.et_432 
  0x42000521, 0x070a0805, 0x070a10a0, 0x070a3c0c,   // fr.co.un_860 uk.mk.bg_333  be.mk.bg_322 ug.mk.bg_543 
  0x040711a0, 0x082e33a0, 0x2100120b, 0x1f003e02,   // ro.bg.ru_322 nn.fo.no_322  ur.fa.un_520 rm.cy.un_220 
  // [6a10]
  0x10000705, 0x30000708, 0x082e3307, 0x1f2c3f04,   // bg.be.un_330 bg.uz.un_430  nn.fo.no_432 af.fy.cy_332 
  0x3c04110c, 0x182130ee, 0x5b47280c, 0x303523ad,   // ro.ru.ug_543 uz.fa.ar_422  sw.sn.sg_543 ky.tg.uz_643 
  0x1b5c0f0c, 0x153548ad, 0x4b422fa4, 0x21004609,   // lv.sa.tr_543 tt.tg.un_643  su.co.mi_433 qu.jw.un_440 
  0x42651da0, 0x2a4c2805, 0x01233ea7, 0x42004004,   // la.gv.co_322 sw.wo.mt_333  rm.ca.en_532 lb.co.un_320 
  // [6a20]
  0x1d002e08, 0x252f680c, 0x22023e05, 0x16005019,   // fo.la.un_430 ig.su.eu_543  rm.da.oc_333 fj.hr.un_750 
  0x25000402, 0x285067a4, 0x161042ee, 0x303515a0,   // ru.mn.un_220 ak.fj.sw_433  co.lt.hr_422 un.tg.uz_322 
  0x23223ea7, 0x3f033e0d, 0x55003607, 0x3e002209,   // rm.oc.ca_532 rm.nl.af_554  gn.rw.un_420 oc.rm.un_440 
  0x79092d11, 0x4b006821, 0x32044a02, 0x3730480c,   // sk.pl.war_653 ig.mi.un_860  yo.fi.bs_222 tt.uz.ba_543 
  // [6a30]
  0x3600420d, 0x36001122, 0x79511504, 0x4b00680c,   // co.gn.un_540 ro.ab.un_870  un.kl.war_332 ig.mi.un_530 
  0x46214ca4, 0x15002520, 0x3f000102, 0x1b00fe04,   // wo.jw.qu_433 mn.un.un_850  en.af.un_220 tlh.tr.un_320 
  0x3e220c0d, 0x02000e02, 0x23000104, 0x28003d07,   // sv.oc.rm_554 is.da.un_220  en.ca.un_320 ku.sd.un_420 
  0x2b002d07, 0x18790911, 0x1b48fc07, 0x10302305,   // sk.vi.un_420 pl.war.ga_653  zzp.tt.tr_432 ky.uz.be_333 
  // [6a40]
  0x17001509, 0xfc003004, 0x0d5c09a7, 0x5300fc07,   // un.sr.un_440 uz.zzp.un_320  hi.sa.ne_532 zzp.ht.un_420 
  0x2e5102a7, 0x09002d0d, 0x44041507, 0x08022e02,   // da.kl.fo_532 sk.pl.un_540  un.ru.kk_432 fo.da.no_222 
  0x18343bee, 0x0c005e12, 0x353025a7, 0x53001302,   // ks.ps.ar_422 ts.sv.un_640  mn.uz.tg_532 et.ht.un_220 
  0x28340fee, 0x5d556404, 0x29172da4, 0x33406755,   // lv.xh.sw_422 lg.rw.ss_332  sk.sr.sl_433 ak.lb.nn_442 
  // [6a50]
  0x3d21180d, 0x28001302, 0x505d250d, 0x40fe06a4,   // ar.fa.ku_554 et.sw.un_220  eu.ss.fj_554 de.tlh.lb_433 
  0x1312380c, 0x5c355d5a, 0x2c000312, 0x122913a0,   // tk.hu.et_543 ss.zu.sa_553  nl.fy.un_640 et.sl.hu_322 
  0x02755608, 0x51554f08, 0x3800120c, 0x25796b08,   // mg.nso.da_443 bi.rw.kl_443  hu.tk.un_530 ceb.war.eu_443 
  0x34354711, 0x51041307, 0x0f1004a4, 0x64375607,   // sn.zu.xh_653 et.fi.kl_432  fi.lt.lv_433 mg.st.lg_432 
  // [6a60]
  0x095c0d07, 0x2e001d05, 0x64fa25a4, 0x041602ee,   // ne.sa.hi_432 la.fo.un_330  eu.nr.lg_433 da.hr.fi_422 
  0x18473502, 0x255c5d0c, 0x1200380d, 0x35005c05,   // zu.sn.ga_222 ss.sa.eu_543  tk.hu.un_540 sa.zu.un_330 
  0x082033a0, 0x5d5625a9, 0x5d026413, 0x4700350e,   // nn.sq.no_322 eu.mg.ss_544  lg.da.ss_665 zu.sn.un_550 
  0xfc002804, 0x504756a4, 0x38000d08, 0x345c35a9,   // sw.zzp.un_320 mg.sn.fj_433  cs.tk.un_430 zu.sa.xh_544 
  // [6a70]
  0x38123904, 0x5d5625ad, 0x123421a9, 0x596425ec,   // br.hu.tk_332 eu.mg.ss_643  fa.ps.ur_544 eu.lg.rn_644 
  0x355c3407, 0x3d30210c, 0x29254b08, 0x0800300d,   // xh.sa.zu_432 fa.uz.ku_543  mi.eu.sl_443 uz.uk.un_540 
  0x34001f09, 0x37001c08, 0x37000702, 0x152535ec,   // cy.xh.un_440 id.st.un_430  bg.ba.un_220 tg.mn.un_644 
  0x07003505, 0x2f002702, 0x2344300b, 0x02001205,   // tg.bg.un_330 gd.su.un_220  uz.kk.ky_542 hu.da.un_330 
  // [6a80]
  0x32003b02, 0x15400207, 0x0f00fc10, 0x0f003b02,   // so.bs.un_220 da.lb.un_432  zzp.lv.un_620 so.lv.un_220 
  0x463b62a0, 0x48153ca7, 0x0d006502, 0x44001808,   // kha.so.qu_322 ug.tt.un_520  gv.cs.un_220 ar.kk.un_430 
  0x60000f1a, 0x39001d04, 0x2d003404, 0x081035a0,   // lv.vo.un_760 la.br.un_320  xh.sk.un_320 tg.be.uk_322 
  0x5300fe12, 0x134c4d04, 0x07173512, 0x6000fc08,   // tlh.ht.un_640 aa.wo.et_332  tg.sr.bg_654 zzp.vo.un_430 
  // [6a90]
  0x133f63a4, 0x04005814, 0x063e2d05, 0x5848040c,   // sco.af.et_433 om.fi.un_660  sk.rm.de_333 fi.tt.om_543 
  0x233c44ee, 0x0f003f05, 0x5a000419, 0x34001d04,   // kk.ug.ky_422 af.lv.un_330  fi.sm.un_750 la.xh.un_320 
  0x1f0150a0, 0x65580407, 0x5800150e, 0x65004d12,   // fj.en.cy_322 fi.om.gv_432  un.om.un_550 aa.gv.un_640 
  0x633b4dad, 0x65041307, 0x15011dee, 0x03584d0c,   // aa.so.sco_643 et.fi.gv_432  la.en.un_422 aa.om.nl_543 
  // [6aa0]
  0x3c383709, 0x133f04a0, 0x351030a0, 0x52002004,   // ba.tk.ug_444 fi.af.et_322  uz.be.tg_322 sq.ha.un_320 
  0x17001011, 0x123021af, 0x1f153807, 0x0f002918,   // be.sr.un_630 fa.uz.ur_655  tk.cy.un_420 sl.lv.un_740 
  0x1100380e, 0x1f652004, 0x483e650d, 0x65381f60,   // tk.ro.un_550 sq.gv.cy_332  gv.rm.tt_554 cy.tk.gv_664 
  0x20003804, 0x38003604, 0x65003823, 0x0d252904,   // tk.sq.un_320 gn.tk.un_320  tk.gv.un_880 sl.eu.cs_332 
  // [6ab0]
  0x02001f07, 0x332e0ead, 0x20002c0e, 0x3d12340c,   // cy.da.un_420 is.fo.nn_643  fy.sq.un_550 ps.ur.ku_543 
  0x38654704, 0x43090d07, 0x65000c05, 0x3865080c,   // sn.gv.tk_332 cs.pl.ie_432  sv.gv.un_330 no.gv.tk_543 
  0x0d00130b, 0x33020814, 0x38000c05, 0x386336ee,   // bh.ne.un_520 no.da.nn_666  sv.tk.un_330 gn.sco.tk_422 
  0x0f002419, 0x443c235a, 0x211c2f02, 0x23002d04,   // eo.lv.un_750 ky.ug.kk_553  su.id.jw_222 sk.ca.un_320 
  // [6ac0]
  0x35150407, 0x0a0715ad, 0x5c130da4, 0x5c130d02,   // ru.tg.un_420 un.bg.mk_643  ne.bh.sa_433 ne.bh.sa_222 
  0x182134a7, 0x15070412, 0x3023355a, 0x30252305,   // ps.fa.ar_532 ru.bg.un_654  tg.ky.uz_553 ky.mn.uz_333 
  0x30251508, 0x07301702, 0x02006118, 0x0400360e,   // un.mn.uz_443 sr.uz.bg_222  za.da.un_740 ab.ru.un_550 
  0x08071705, 0x0a000805, 0x5c130909, 0x0a0736a7,   // sr.bg.uk_333 uk.mk.un_330  hi.bh.sa_444 ab.bg.mk_532 
  // [6ad0]
  0x0000fc2d, 0x3c003d1b, 0x48234413, 0x016bfcad,   // zzp.un.un_A00 ku.ug.un_770  kk.ky.tt_665 zzp.ceb.en_643 
  0x18fc6b0c, 0x4500780d, 0x5e255f05, 0x3932165a,   // ceb.zzp.ga_543 ve.ln.un_540  tn.eu.ts_333 hr.bs.br_553 
  0x171025ee, 0x5f753708, 0x25071111, 0xfc000113,   // mn.be.sr_422 st.nso.tn_443  ro.bg.mn_653 en.zzp.un_650 
  0x6900fc14, 0x4d00fc1a, 0xfc004c04, 0x5d5e35a9,   // zzp.mfe.un_660 zzp.aa.un_760  wo.zzp.un_320 zu.ts.ss_544 
  // [6ae0]
  0x21303d13, 0x35345eaf, 0x20000312, 0x0e003802,   // ku.uz.fa_665 ts.xh.zu_655  nl.sq.un_640 tk.is.un_220 
  0x685f255a, 0x35003419, 0x120e2e04, 0x100407a9,   // eu.tn.ig_553 xh.zu.un_750  fo.is.hu_332 bg.ru.be_544 
  0x5c0d1c14, 0x37441007, 0x3d283004, 0x040a07a7,   // mr.ne.sa_666 be.kk.ba_432  uz.sd.ku_332 bg.mk.ru_532 
  0x07171004, 0x341844a0, 0x00003215, 0x3d003021,   // be.sr.bg_332 kk.ar.ps_322  bs.un.un_700 uz.ku.un_860 
  // [6af0]
  0x422660a7, 0x185e09a7, 0x170430a0, 0x3400280b,   // vo.ia.co_532 pl.ts.ga_532  uz.ru.sr_322 sd.ps.un_520 
  0x0a170408, 0x04072504, 0x04006502, 0x04070804,   // ru.sr.mk_443 mn.bg.ru_332  gv.fi.un_220 uk.bg.ru_332 
  0x3879fc04, 0x2d0d10a0, 0x33080ca9, 0x332c3fee,   // zzp.war.tk_332 lt.cs.sk_322  sv.no.nn_544 af.fy.nn_422 
  0x3f2f1c02, 0x4800350b, 0x04081008, 0x18123407,   // id.su.af_222 tg.tt.un_520  be.uk.ru_443 ps.ur.ar_432 
  // [6b00]
  0x480e3312, 0x23001004, 0x440a07a0, 0x395a1fa6,   // nn.is.tt_654 lt.ca.un_320  bg.mk.kk_322 cy.sm.br_521 
  0x0e08330c, 0x172e0eee, 0x4a1d57ee, 0x0d002d19,   // nn.no.is_543 is.fo.sr_422  na.la.yo_422 sk.cs.un_750 
  0x33480e12, 0x463b2e11, 0x0908330c, 0x6e00fe0d,   // is.tt.nn_654 fo.so.qu_653  nn.no.pl_543 tlh.hmn.un_540 
  0x60060eaf, 0x1d0e330b, 0x631d01a4, 0x3e00091a,   // is.de.vo_655 nn.is.la_542  en.la.sco_433 pl.rm.un_760 
  // [6b10]
  0x1500351a, 0x09384855, 0x12003307, 0x29000f02,   // tg.un.un_760 tt.tk.pl_442  nn.hu.un_420 lv.sl.un_220 
  0x0e005f08, 0x480e33a9, 0x12330ea4, 0x250e2208,   // tn.is.un_430 nn.is.tt_544  is.nn.hu_433 oc.is.eu_443 
  0x12003d0b, 0x360a17af, 0x04002308, 0x330847ac,   // ku.ur.un_520 sr.mk.ab_655  ky.ru.un_430 sn.no.nn_632 
  0x070a08a9, 0x0a0811ee, 0x122134ec, 0x100807af,   // uk.mk.bg_544 ro.uk.mk_422  ps.fa.ur_644 bg.uk.be_655 
  // [6b20]
  0x53006402, 0x3c00480e, 0x4a5c53ac, 0x350710a4,   // lg.ht.un_220 tt.ug.un_550  ht.sa.yo_632 be.bg.tg_433 
  0x3b002502, 0x4a005f0c, 0x1c0d5c05, 0x48003109,   // eu.so.un_220 tn.yo.un_530  sa.ne.mr_333 az.tt.un_440 
  0x37234408, 0x04302302, 0x15003509, 0xfe35340d,   // kk.ky.ba_443 ky.uz.ru_222  tg.un.un_440 xh.zu.tlh_554 
  0x3400fe04, 0x0748250c, 0x5c0913a6, 0x48001519,   // tlh.xh.un_320 mn.tt.bg_543  bh.hi.sa_521 un.tt.un_750 
  // [6b30]
  0x6afc2755, 0x5600300c, 0x1b00450d, 0x20562513,   // gd.zzp.haw_442 uz.mg.un_530  ln.tr.un_540 eu.mg.sq_665 
  0x5f5834a4, 0x606a0da0, 0x37001522, 0x3b3534a4,   // xh.om.tn_433 cs.haw.vo_322  un.ba.un_870 xh.zu.so_433 
  0x453038a9, 0x5a004923, 0x5f383baf, 0x38733009,   // tk.uz.ln_544 to.sm.un_880  so.tk.tn_655 uz.ny.tk_444 
  0x18004a04, 0x04440702, 0x30004c13, 0x354423a7,   // yo.ga.un_320 bg.kk.ru_222  wo.uz.un_650 ky.kk.tg_532 
  // [6b40]
  0x23050209, 0x18000104, 0x18391f04, 0x083c3011,   // da.fr.ca_444 en.ga.un_320  cy.br.ga_332 uz.ug.uk_653 
  0x483b300c, 0x564360ad, 0x345e7308, 0x0506400c,   // uz.so.tt_543 vo.ie.mg_643  ny.ts.xh_443 lb.de.fr_543 
  0x16002905, 0x10001d07, 0x0d112da7, 0x3f644ca4,   // sl.hr.un_330 la.lt.un_420  sk.ro.cs_532 wo.lg.af_433 
  0x3c3510a9, 0x2d090d12, 0x12000c07, 0x525355ee,   // be.tg.ug_544 cs.pl.sk_654  sv.hu.un_420 rw.ht.ha_422 
  // [6b50]
  0x21656704, 0x19221dee, 0x560f10ee, 0x3400fc02,   // ak.gv.jw_332 la.oc.gl_422  lt.lv.mg_422 zzp.xh.un_220 
  0xfc00571b, 0x43002507, 0x3e000c02, 0x65004905,   // na.zzp.un_770 eu.ie.un_420  sv.rm.un_220 to.gv.un_330 
  0x2348375a, 0x0a353007, 0x1f00670e, 0x0e2e4aa9,   // ba.tt.ky_553 uz.tg.mk_432  ak.cy.un_550 yo.fo.is_544 
  0x35001f0c, 0x34213da9, 0x47353411, 0x48311b04,   // cy.zu.un_530 ku.fa.ps_544  xh.zu.sn_653 tr.az.tt_332 
  // [6b60]
  0x16112da4, 0x09fc3504, 0x48003c0b, 0x4815040c,   // sk.ro.hr_433 zu.zzp.pl_332  ug.tt.un_520 ru.tt.un_530 
  0x044c6514, 0x190e18a7, 0x2c0361ee, 0x033f2c0d,   // gv.wo.fi_666 ga.is.gl_532  za.nl.fy_422 fy.af.nl_554 
  0x074837a7, 0x1a005d0c, 0x38001011, 0x101f1da0,   // ba.tt.bg_532 ss.tl.un_530  lt.tk.un_630 la.cy.lt_322 
  0x3400350b, 0x46001b08, 0x3812100c, 0x5a002c0d,   // zu.xh.un_520 tr.qu.un_430  lt.hu.tk_543 fy.sm.un_540 
  // [6b70]
  0x35006707, 0x47fe5cad, 0x5d5c35a4, 0x3d211804,   // ak.zu.un_420 sa.tlh.sn_643  zu.sa.ss_433 ar.fa.ku_332 
  0x482511a7, 0x341f3512, 0x6b004614, 0x5c5d35af,   // ro.mn.tt_532 zu.cy.xh_654  qu.ceb.un_660 zu.ss.sa_655 
  0x12001007, 0x5c004d0d, 0x02000904, 0x0f00fc04,   // lt.hu.un_420 aa.sa.un_540  pl.da.un_320 zzp.lv.un_320 
  0x301525af, 0x03133fa4, 0x09003813, 0x02002502,   // mn.uz.un_650 af.et.nl_433  tk.pl.un_650 eu.da.un_220 
  // [6b80]
  0x15070a55, 0x5d005c1b, 0x09001019, 0x0a071109,   // mk.bg.un_442 sa.ss.un_770  lt.pl.un_750 ro.bg.mk_444 
  0x1b00460e, 0x0ffe4e07, 0x1b004607, 0x0f1afe07,   // qu.tr.un_550 ay.tlh.lv_432  qu.tr.un_420 tlh.tl.lv_432 
  0x4600fe0d, 0x3412280c, 0x0800330b, 0x4e00580e,   // tlh.qu.un_540 sd.ur.ps_543  nn.no.un_520 om.ay.un_550 
  0x1812580d, 0x11394602, 0x31004812, 0x6b6279af,   // om.hu.ga_554 qu.br.ro_222  tt.az.un_640 war.kha.ceb_655 
  // [6b90]
  0x1a2858a0, 0x2800580b, 0x0d002902, 0x300425a4,   // om.sw.tl_322 om.sw.un_520  sl.cs.un_220 mn.ru.uz_433 
  0x7900581a, 0x09001f02, 0x5d4e5812, 0x15001f12,   // om.war.un_760 cy.pl.un_220  om.ay.ss_654 cy.un.un_640 
  0x2533130c, 0x02002508, 0x48317904, 0x1c090da9,   // et.nn.eu_543 eu.da.un_430  war.az.tt_332 ne.hi.mr_544 
  0x100a1709, 0x345d350b, 0x79002508, 0x0d0916a4,   // sr.mk.be_444 zu.ss.xh_542  eu.war.un_430 hr.pl.cs_433 
  // [6ba0]
  0x1a4e58a4, 0x12172e04, 0x021a25a0, 0x37003c0b,   // om.ay.tl_433 fo.sr.hu_332  eu.tl.da_322 ug.ba.un_520 
  0x02585211, 0xfe0e060c, 0x382513a4, 0x35fe58ad,   // ha.om.da_653 de.is.tlh_543  et.eu.tk_433 om.tlh.zu_643 
  0x38170aa4, 0x13103307, 0x484efcad, 0x4c001d08,   // mk.sr.tk_433 nn.lt.et_432  zzp.ay.tt_643 la.wo.un_430 
  0xfc3b4c0b, 0xfc002522, 0x4825130c, 0x04170805,   // wo.so.zzp_542 eu.zzp.un_870  et.eu.tt_543 uk.sr.ru_333 
  // [6bb0]
  0x190b2511, 0x382310ad, 0x1c16feee, 0x4d003b14,   // eu.es.gl_653 be.ky.tk_643  tlh.hr.id_422 so.aa.un_660 
  0x40003e04, 0x070411a0, 0x37000a04, 0xfc003b12,   // rm.lb.un_320 ro.ru.bg_322  mk.ba.un_320 so.zzp.un_640 
  0x38001519, 0x10003619, 0xfc001f07, 0xfc004d1b,   // un.tk.un_750 gn.lt.un_750  cy.zzp.un_420 aa.zzp.un_770 
  0x35360a0d, 0x4d00fc22, 0x35360804, 0x1d002a04,   // mk.ab.tg_554 zzp.aa.un_870  uk.ab.tg_332 mt.la.un_320 
  // [6bc0]
  0xfc003b23, 0x070438a0, 0xfc26430d, 0x1f01fc07,   // so.zzp.un_880 tk.ru.bg_322  ie.ia.zzp_554 zzp.en.cy_432 
  0x3b004605, 0x120b0a05, 0x122818a4, 0x030c3fee,   // qu.so.un_330 pt.es.hu_333  ar.sd.ur_433 af.sv.nl_422 
  0x32172909, 0x0e1b1502, 0x652038a0, 0x2d171604,   // sl.sr.bs_444 un.tr.is_222  tk.sq.gv_322 hr.sr.sk_332 
  0x28122107, 0x3c003819, 0x2300300d, 0x1c090d5a,   // fa.ur.sd_432 tk.ug.un_750  uz.ky.un_540 ne.hi.mr_553 
  // [6bd0]
  0x15383013, 0x09135cad, 0x360b0a0d, 0x36000508,   // uz.tk.un_665 sa.bh.hi_643  pt.es.gn_554 fr.gn.un_430 
  0x3c12185a, 0x25003812, 0x16282fa0, 0x36002513,   // ar.ur.ug_553 tk.mn.un_640  su.sw.hr_322 mn.ab.un_650 
  0x2818120c, 0x2515110d, 0x0844230d, 0x182812af,   // ur.ar.sd_543 ro.mn.un_540  ky.kk.uk_554 ur.sd.ar_655 
  0x0e121855, 0x3635300c, 0x122130ec, 0x0b001908,   // ga.hu.is_442 uz.tg.ab_543  uz.fa.ur_644 gl.es.un_430 
  // [6be0]
  0x0a004a08, 0x23003009, 0x08070408, 0x533769a0,   // yo.pt.un_430 uz.ky.un_440  ru.bg.uk_443 mfe.st.ht_322 
  0x5c001210, 0x173515a7, 0x08041512, 0x2a004a04,   // hu.sa.un_620 un.tg.sr_532  un.ru.uk_654 yo.mt.un_320 
  0x2e1362a4, 0x5d550b02, 0x19002b13, 0x0a362d08,   // kha.et.fo_433 es.rw.ss_222  vi.gl.un_650 sk.gn.pt_443 
  0x2b000e1a, 0x0a0717a9, 0x35003c1b, 0x12003018,   // is.vi.un_760 sr.bg.mk_544  ug.tg.un_770 uz.ur.un_740 
  // [6bf0]
  0x0e4c0c08, 0x150410ec, 0x13091cac, 0x2c00050c,   // sv.wo.is_443 be.ru.un_644  mr.hi.bh_632 fr.fy.un_530 
  0x0d0b0a05, 0x0830350d, 0x0d001319, 0x30350812,   // pt.es.cs_333 tg.uz.uk_554  bh.ne.un_750 uk.tg.uz_654 
  0x00001924, 0x5f753713, 0x151017a7, 0x13321702,   // gl.un.un_900 st.nso.tn_665  sr.be.un_532 sr.bs.et_222 
  0x46000104, 0x3500360b, 0x3f1b31a9, 0x06311b12,   // en.qu.un_320 ab.tg.un_520  az.tr.af_544 tr.az.de_654 
  
  // [6c00]
  0x35000a02, 0x36000108, 0x4d30285a, 0x65002c08,   // mk.tg.un_220 en.gn.un_430  sw.uz.aa_553 fy.gv.un_430 
  0x1c212faf, 0x3b004709, 0xfe1d4c13, 0x1d2f210c,   // su.jw.id_655 sn.so.un_440  wo.la.tlh_665 jw.su.la_543 
  0x13091cad, 0x65003808, 0x0f000808, 0x65003813,   // mr.hi.bh_643 tk.gv.un_430  no.lv.un_430 tk.gv.un_650 
  0x60000614, 0x1f3836a4, 0x42003e0e, 0x3800040d,   // de.vo.un_660 gn.tk.cy_433  rm.co.un_550 fi.tk.un_540 
  // [6c10]
  0x3b005f1b, 0x6b301a07, 0x583b5212, 0x38001f0d,   // tn.so.un_770 tl.uz.ceb_432  ha.so.om_654 cy.tk.un_540 
  0x02004d07, 0x23443707, 0x30003b13, 0x1f00020d,   // aa.da.un_420 ba.kk.ky_432  so.uz.un_650 da.cy.un_540 
  0x64005114, 0x03513f09, 0x52104a55, 0x640451a4,   // kl.lg.un_660 af.kl.nl_444  yo.lt.ha_442 kl.fi.lg_433 
  0x1d2f37a0, 0x302112a7, 0x3b304dee, 0x0a1017ee,   // st.su.la_322 ur.fa.uz_532  aa.uz.so_422 sr.be.mk_422 
  // [6c20]
  0x0804100c, 0x0e006212, 0x1e1c51a4, 0x2f211ea7,   // be.ru.uk_543 kha.is.un_640  kl.id.ms_433 ms.jw.su_532 
  0x21121e07, 0x2e000408, 0x38001f0c, 0x2e380e12,   // ms.hu.jw_432 fi.fo.un_430  cy.tk.un_530 is.tk.fo_654 
  0x3804650c, 0x64005204, 0x12005112, 0x65003f04,   // gv.fi.tk_543 ha.lg.un_320  kl.hu.un_640 af.gv.un_320 
  0x3f653955, 0x65000802, 0x38003613, 0x3c003004,   // br.gv.af_442 no.gv.un_220  gn.tk.un_650 uz.ug.un_320 
  // [6c30]
  0x3b3d2113, 0x0400480e, 0x48304408, 0x48152507,   // fa.ku.ks_665 tt.fi.un_550  kk.uz.tt_443 mn.tt.un_420 
  0x64003002, 0x34004704, 0x5246020c, 0x120833a0,   // uz.lg.un_220 sn.xh.un_320  da.qu.ha_543 nn.no.hu_322 
  0x51040305, 0x2900091b, 0x55005f05, 0x1d00430c,   // nl.fi.kl_333 pl.sl.un_770  tn.rw.un_330 ie.la.un_530 
  0x0f001704, 0x44303509, 0x0940390c, 0x12000407,   // sr.lv.un_320 tg.uz.kk_444  br.lb.pl_543 fi.hu.un_420 
  // [6c40]
  0x3f2e0ea4, 0x36071707, 0x29004007, 0x170a1004,   // is.fo.af_433 sr.bg.ab_432  lb.sl.un_420 be.mk.sr_332 
  0x3f003305, 0x29000914, 0x5f5e670c, 0x67006321,   // nn.af.un_330 pl.sl.un_660  ak.ts.tn_543 sco.ak.un_860 
  0x0800040e, 0x0a003002, 0x02796b07, 0x34001f04,   // ru.uk.un_550 uz.mk.un_220  ceb.war.da_432 cy.xh.un_320 
  0x3d23445a, 0x1100171a, 0x2800fc19, 0x09002919,   // kk.ky.ku_553 sr.ro.un_760  zzp.sw.un_750 sl.pl.un_750 
  // [6c50]
  0x2900090d, 0x121f3804, 0x09135ca0, 0x09002921,   // pl.sl.un_540 tk.cy.hu_332  sa.bh.hi_322 sl.pl.un_860 
  0x40425a05, 0x21092955, 0x44070a08, 0x03003f18,   // sm.co.lb_333 sl.pl.jw_442  mk.bg.kk_443 af.nl.un_740 
  0x033f3ba0, 0x0a15170c, 0x1c095c05, 0x15382508,   // so.af.nl_322 sr.mk.un_530  sa.hi.mr_333 mn.tk.un_443 
  0x1708070d, 0x3b00fe09, 0xfc0265a0, 0x347335ee,   // bg.uk.sr_554 tlh.so.un_440  gv.da.zzp_322 zu.ny.xh_422 
  // [6c60]
  0x1004155a, 0x355d0107, 0x766301a0, 0x4c403ba4,   // un.ru.be_553 en.ss.zu_432  en.sco.crs_322 so.lb.wo_433 
  0x3023440b, 0xfc002b02, 0x44000a02, 0x2c006309,   // kk.ky.uz_542 vi.zzp.un_220  mk.kk.un_220 sco.fy.un_440 
  0x23003c09, 0x03001104, 0x352536ee, 0x040848a0,   // ug.ky.un_440 ro.nl.un_320  ab.mn.tg_422 tt.uk.ru_322 
  0x1d0465a0, 0x080735a4, 0x183c2104, 0x39001902,   // gv.fi.la_322 tg.bg.uk_433  fa.ug.ar_332 gl.br.un_220 
  // [6c70]
  0x22360b02, 0x213d1204, 0x3d213412, 0x300a0804,   // es.gn.oc_222 ur.ku.fa_332  ps.fa.ku_654 uk.mk.uz_332 
  0x3d213c0c, 0x151730a7, 0x0715440c, 0x3e004004,   // ug.fa.ku_543 uz.sr.un_532  kk.bg.un_530 lb.rm.un_320 
  0x0f211013, 0x06630104, 0x0c020312, 0x5a7901ee,   // lt.jw.lv_665 en.sco.de_332  nl.da.sv_654 en.war.sm_422 
  0x632c01af, 0x17370aa4, 0x1f1839af, 0x5e0a1512,   // en.fy.sco_655 mk.ba.sr_433  br.ga.cy_655 un.pt.ts_654 
  // [6c80]
  0x42000505, 0x060501ee, 0x600262ec, 0x3537440c,   // fr.co.un_330 en.fr.de_422  kha.da.vo_644 kk.ba.tg_543 
  0x24000e04, 0x10000f19, 0x374811a4, 0x0b191212,   // is.eo.un_320 lv.lt.un_750  ro.tt.ba_433 hu.gl.es_654 
  0x1510080c, 0x2643020d, 0x03000234, 0x5600fc2c,   // uk.be.un_543 da.ie.ia_554  da.nl.un_A80 zzp.mg.un_990 
  0x1707100c, 0x393bfca0, 0x5c1c090e, 0x48001534,   // be.bg.sr_543 zzp.so.br_322  hi.mr.sa_555 un.tt.un_A80 
  // [6c90]
  0x043015ad, 0x2e2739ad, 0x364d3b0d, 0x1523040d,   // un.uz.ru_643 br.gd.fo_643  so.aa.gn_554 ru.ky.un_554 
  0x35003c11, 0x1c091307, 0x170735a0, 0x33003f05,   // ug.tg.un_630 bh.hi.mr_432  tg.bg.sr_322 af.nn.un_330 
  0xfc000502, 0x4600fc1a, 0x23003704, 0x044d1311,   // fr.zzp.un_220 zzp.qu.un_760  ba.ky.un_320 et.aa.fi_653 
  0x10002504, 0x2130120e, 0x0e004205, 0x25003613,   // mn.be.un_320 ur.uz.fa_555  co.is.un_330 ab.mn.un_650 
  // [6ca0]
  0x35007308, 0x183430a0, 0x35006404, 0x736b1a05,   // ny.zu.un_430 uz.ps.ar_322  lg.zu.un_320 tl.ceb.ny_333 
  0x3f065aa7, 0x06003f0b, 0x0657400c, 0x07080aa4,   // sm.de.af_532 af.de.un_520  lb.na.de_543 mk.uk.bg_433 
  0x60381bec, 0x361525ad, 0x3c003d13, 0x3f00090e,   // tr.tk.vo_644 mn.ab.un_630  ku.ug.un_650 pl.af.un_550 
  0x282a3f02, 0x643573a7, 0x482310a4, 0x09003902,   // af.mt.sw_222 ny.zu.lg_532  be.ky.tt_433 br.pl.un_220 
  // [6cb0]
  0x3b521e04, 0x67007319, 0x792a09a7, 0x352a7311,   // ms.ha.so_332 ny.ak.un_750  pl.mt.war_532 ny.mt.zu_653 
  0x42000904, 0xfc007307, 0x2130120d, 0x3d23440c,   // pl.co.un_320 ny.zzp.un_420  ur.uz.fa_554 kk.ky.ku_543 
  0x42390faf, 0x34004405, 0x31003808, 0x3000650c,   // lv.br.co_655 kk.ps.un_330  tk.az.un_430 gv.uz.un_530 
  0x09062a07, 0x06000308, 0x17073c0c, 0x63570605,   // mt.de.pl_432 nl.de.un_430  ug.bg.sr_543 de.na.sco_333 
  // [6cc0]
  0x25074208, 0x17081507, 0x0d0e2e04, 0x3d3418a4,   // co.it.eu_443 un.uk.sr_432  fo.is.cs_332 ar.ps.ku_433 
  0x35372314, 0x17073002, 0x1f002b05, 0x153c3008,   // ky.ba.tg_666 uz.bg.sr_222  vi.cy.un_330 uz.ug.un_443 
  0x051b3804, 0x126407a9, 0x253830ec, 0x12074204,   // tk.tr.fr_332 it.lg.hu_544  uz.tk.mn_644 co.it.hu_332 
  0x3b006113, 0x423e0704, 0x3e420760, 0x2a6412ad,   // za.so.un_650 it.rm.co_332  it.co.rm_664 hu.lg.mt_643 
  // [6cd0]
  0x12002a0d, 0x56621e12, 0x4d00610e, 0x07422a5a,   // mt.hu.un_540 ms.kha.mg_654  za.aa.un_550 mt.co.it_553 
  0x1c2f1ea9, 0x2a64120c, 0x3f28780c, 0x1a2f79a9,   // ms.su.id_544 hu.lg.mt_543  ve.sw.af_543 war.su.tl_544 
  0x471a280c, 0x063f0355, 0x2a65640b, 0x1c2165a0,   // sw.tl.sn_543 nl.af.de_442  lg.gv.mt_542 gv.jw.id_322 
  0x73fe6407, 0x30004307, 0x3c3025ad, 0x215d6404,   // lg.tlh.ny_432 ie.uz.un_420  mn.uz.ug_643 lg.ss.jw_332 
  // [6ce0]
  0x3b1a51ad, 0xfe004611, 0x1a213fee, 0x1a1e1c60,   // kl.tl.so_643 qu.tlh.un_630  af.jw.tl_422 id.ms.tl_664 
  0xfe001d19, 0xfc182760, 0x1a7964ec, 0x12006408,   // la.tlh.un_750 gd.ga.zzp_664  lg.war.tl_644 lg.hu.un_430 
  0x2100571a, 0x12423ea4, 0x1015040e, 0x28375e0c,   // na.jw.un_760 rm.co.hu_433  ru.be.un_550 ts.st.sw_543 
  0x07422aaf, 0x1b645008, 0x4c00640c, 0x4d3b4c11,   // mt.co.it_655 fj.lg.tr_443  lg.wo.un_530 wo.so.aa_653 
  // [6cf0]
  0x3b005e08, 0x423e64ec, 0x07422aa9, 0x4e4a5905,   // ts.so.un_430 lg.rm.co_644  mt.co.it_544 rn.yo.ay_333 
  0x17002502, 0x485c69a4, 0x1500fc05, 0x48373c0d,   // mn.sr.un_220 mfe.sa.tt_433  zzp.un.un_330 ug.ba.tt_554 
  0x212f02ec, 0x130d5c0e, 0x506012a9, 0x1a4c2105,   // da.su.jw_644 sa.ne.bh_555  hu.vo.fj_544 jw.wo.tl_333 
  0x79001a1a, 0x31571b07, 0x36002209, 0x5a27180b,   // tl.war.un_760 tr.na.az_432  oc.gn.un_440 ga.gd.sm_542 
  // [6d00]
  0x31591b08, 0x2169310e, 0x45576504, 0x1a1d76af,   // tr.rn.az_443 az.mfe.jw_555  gv.na.ln_332 crs.la.tl_655 
  0x0236fca7, 0x05004304, 0x01156507, 0x30153504,   // zzp.gn.da_532 ie.fr.un_320  gv.en.un_420 tg.uz.un_320 
  0x481b20ad, 0x041ffc55, 0x1c095c0d, 0x15041714,   // sq.tr.tt_643 zzp.cy.fi_442  sa.hi.mr_554 sr.ru.un_666 
  0x070a15ec, 0x62001f21, 0x0e001f05, 0x384831a0,   // un.mk.bg_644 cy.kha.un_860  cy.is.un_330 az.tt.tk_322 
  // [6d10]
  0x3800fc05, 0x5c00010d, 0x08103012, 0x530b5c0c,   // zzp.tk.un_330 en.sa.un_540  uz.be.uk_654 sa.es.ht_543 
  0x1f3f3812, 0x02004608, 0x3d21230c, 0xfc3862a7,   // tk.af.cy_654 qu.da.un_430  ky.fa.ku_543 kha.tk.zzp_532 
  0x48000e04, 0x35003035, 0x103865a6, 0x103035a0,   // is.tt.un_320 uz.tg.un_A90  gv.tk.lt_521 tg.uz.be_322 
  0x46004704, 0x3c184408, 0x36734604, 0x1a004607,   // sn.qu.un_320 kk.ar.ug_443  qu.ny.gn_332 qu.tl.un_420 
  // [6d20]
  0x12182807, 0x73463660, 0x462036ee, 0x35301007,   // sd.ar.ur_432 gn.qu.ny_664  gn.sq.qu_422 be.uz.tg_432 
  0x3f1c46a0, 0x21003d2a, 0x211c1302, 0x1d003404,   // qu.id.af_322 ku.fa.un_970  et.id.jw_222 xh.la.un_320 
  0x3717350c, 0x281218a0, 0x040a0712, 0x15044805,   // tg.sr.ba_543 ar.ur.sd_322  bg.mk.ru_654 tt.ru.un_333 
  0x08133307, 0x1c73460c, 0x1800fc05, 0x2f46360c,   // nn.et.no_432 qu.ny.id_543  zzp.ga.un_330 gn.qu.su_543 
  // [6d30]
  0x46003602, 0x020f030d, 0x4a6901a0, 0x180163ad,   // gn.qu.un_220 nl.lv.da_554  en.mfe.yo_322 sco.en.ga_643 
  0x1700250b, 0x06010508, 0x2115020c, 0x062d0d04,   // mn.sr.un_520 fr.en.de_443  da.jw.un_530 cs.sk.de_332 
  0x0f4002a0, 0x05010614, 0x30233caf, 0x151e1c08,   // da.lb.lv_322 de.en.fr_666  ug.ky.uz_655 id.ms.un_443 
  0x79642da0, 0x600601a7, 0x1502030d, 0x1137230c,   // sk.lg.war_322 en.de.vo_532  nl.da.un_554 ky.ba.ro_543 
  // [6d40]
  0x223e210d, 0x37030213, 0x121834ee, 0x645a11a7,   // jw.rm.oc_554 da.nl.st_665  ps.ar.ur_422 ro.sm.lg_532 
  0x44342114, 0x483c3713, 0x5f604fad, 0x2f5f64a9,   // fa.ps.kk_666 ba.ug.tt_665  bi.vo.tn_643 lg.tn.su_544 
  0x1afc3b5a, 0xfc004d0d, 0x50005d0d, 0x16254511,   // so.zzp.tl_553 aa.zzp.un_540  ss.fj.un_540 ln.eu.hr_653 
  0x38002d13, 0x73005009, 0x79002d13, 0x08481507,   // sk.tk.un_650 fj.ny.un_440  sk.war.un_650 un.tt.uk_432 
  // [6d50]
  0x19002502, 0x23443604, 0x643e08a0, 0x5a5045ec,   // eu.gl.un_220 ab.kk.ky_332  no.rm.lg_322 ln.fj.sm_644 
  0x2c002e08, 0x070810a0, 0x041517a4, 0x35040704,   // fo.fy.un_430 be.uk.bg_322  sr.ru.un_430 bg.ru.tg_332 
  0x1c5c0da9, 0x3800040e, 0x08441002, 0x48311ba9,   // ne.sa.mr_544 fi.tk.un_550  be.kk.uk_222 tr.az.tt_544 
  0x24200204, 0x37444805, 0x081036a0, 0x3500250c,   // da.sq.eo_332 tt.kk.ba_333  ab.be.uk_322 mn.tg.un_530 
  // [6d60]
  0x15001514, 0x3f3810a0, 0x4a000e11, 0x23001713,   // un.un.un_660 lt.tk.af_322  is.yo.un_630 sr.ky.un_650 
  0x23003007, 0x090d1c07, 0x0400150b, 0x100e2aa0,   // uz.ky.un_420 mr.ne.hi_432  un.ru.un_520 mt.is.lt_322 
  0x080f1007, 0x212812a0, 0x212e2aa0, 0x242d0d04,   // lt.lv.no_432 ur.sd.fa_322  mt.fo.jw_322 cs.sk.eo_332 
  0x1800120d, 0x03001d02, 0x2500080d, 0x5c0610a0,   // ur.ar.un_540 la.nl.un_220  uk.mn.un_540 lt.de.sa_322 
  // [6d70]
  0x1d002633, 0x233725ad, 0x5c131caf, 0x101604a4,   // ia.la.un_A70 mn.ba.ky_643  mr.bh.sa_655 fi.hr.lt_433 
  0x6500300e, 0x425605a4, 0x1700460c, 0x12003f07,   // uz.gv.un_550 fr.mg.co_433  qu.sr.un_530 af.hu.un_420 
  0x65005821, 0x1f002308, 0x270565a9, 0x39005e09,   // om.gv.un_860 ca.cy.un_430  gv.fr.gd_544 ts.br.un_440 
  0x62481705, 0x3600380d, 0x2a00392b, 0x3b210204,   // sr.tt.kha_333 tk.ab.un_540  dz.bo.un_980 da.jw.so_332 
  // [6d80]
  0x21003b09, 0x42054d11, 0x230605a4, 0xfe433ea7,   // so.jw.un_440 aa.fr.co_653  fr.de.ca_433 rm.ie.tlh_532 
  0x3400470d, 0x2c586508, 0x3e42fe0b, 0x53692908,   // sn.xh.un_540 gv.om.fy_443  tlh.co.rm_542 sl.mfe.ht_443 
  0x0c003e08, 0x30000a11, 0x206265ac, 0x36002c02,   // rm.sv.un_430 mk.uz.un_630  gv.kha.sq_632 fy.gn.un_220 
  0x383c30af, 0x63755f60, 0x5800fc19, 0x4a005e0c,   // uz.ug.tk_655 tn.nso.sco_664  zzp.om.un_750 ts.yo.un_530 
  // [6d90]
  0x122c1fee, 0x1c002c20, 0x100436ec, 0x20192308,   // cy.fy.hu_422 fy.id.un_850  ab.ru.be_644 ca.gl.sq_443 
  0x58006508, 0x40006519, 0x30443c0b, 0x4c005e09,   // gv.om.un_430 gv.lb.un_750  ug.kk.uz_542 ts.wo.un_440 
  0x170a10a7, 0x3b473402, 0x17361504, 0x4f654da0,   // be.mk.sr_532 xh.sn.so_222  un.ab.sr_332 aa.gv.bi_322 
  0x3d213c05, 0x4800fe04, 0x13006502, 0x3f032c13,   // ug.fa.ku_333 tlh.tt.un_320  gv.et.un_220 fy.nl.af_665 
  // [6da0]
  0x353025a4, 0x17153c13, 0x64281802, 0x13000c09,   // mn.uz.tg_433 ug.sr.un_650  ga.sw.lg_222 sv.et.un_440 
  0x2400012a, 0x46525f60, 0x226540a0, 0x3f006505,   // iw.yi.un_970 tn.ha.qu_664  lb.gv.oc_322 gv.af.un_330 
  0x353023a9, 0x40003b08, 0x31004f07, 0x11003609,   // ky.uz.tg_544 so.lb.un_430  bi.az.un_420 ab.ro.un_440 
  0x1700100c, 0x35481114, 0x07004e19, 0x4b5c0f0c,   // be.sr.un_530 ro.tt.tg_666  ay.it.un_750 lv.sa.mi_543 
  // [6db0]
  0xfe00510c, 0x374835a4, 0x5c002204, 0x42002505,   // kl.tlh.un_530 tg.tt.ba_433  oc.sa.un_320 eu.co.un_330 
  0x230704a4, 0x0f5c4bee, 0x162d29ee, 0x044423ad,   // ru.bg.ky_433 mi.sa.lv_422  sl.sk.hr_422 ky.kk.ru_643 
  0x4600040d, 0x511d01ee, 0x39090d12, 0x63060105,   // fi.qu.un_540 en.la.kl_422  cs.pl.br_654 en.de.sco_333 
  0x081802a4, 0x07250a55, 0xfe001523, 0x3942110c,   // da.ga.no_433 mk.mn.bg_442  un.tlh.un_880 ro.co.br_543 
  // [6dc0]
  0x400601a0, 0x40001b04, 0x1500150e, 0x48003014,   // en.de.lb_322 tr.lb.un_320  un.un.un_550 uz.tt.un_660 
  0x0d02095a, 0x020353ec, 0x040748a0, 0x060501a4,   // pl.da.cs_553 ht.nl.da_644  tt.bg.ru_322 en.fr.de_433 
  0x64000104, 0x022d0d05, 0x1f451512, 0x1530110c,   // en.lg.un_320 cs.sk.da_333  un.ln.cy_654 ro.uz.un_543 
  0x02031c11, 0x2303020d, 0x211802a9, 0x606e01a0,   // id.nl.da_653 da.nl.ca_554  da.ga.jw_544 en.hmn.vo_322 
  // [6dd0]
  0x481f395a, 0x061b12a4, 0x09001012, 0x09001007,   // br.cy.tt_553 hu.tr.de_433  lt.pl.un_640 lt.pl.un_420 
  0x0b002404, 0x0e2a0c55, 0x1d360207, 0x28002113,   // eo.es.un_320 sv.mt.is_442  da.gn.la_432 fa.sd.un_650 
  0x496a5da4, 0x18122105, 0x344423a4, 0x0235470b,   // ss.haw.to_433 fa.ur.ar_333  ky.kk.ps_433 sn.zu.da_542 
  0x21003034, 0x0c0102ee, 0x09000f02, 0x3e001f02,   // uz.fa.un_A80 da.en.sv_422  lv.pl.un_220 cy.rm.un_220 
  // [6de0]
  0x102d0f04, 0x34497302, 0x2f001804, 0x39503507,   // lv.sk.lt_332 ny.to.xh_222  ga.su.un_320 zu.fj.br_432 
  0x13003e02, 0x532722a7, 0x586a495a, 0x440738ee,   // rm.et.un_220 oc.gd.ht_532  to.haw.om_553 tk.bg.kk_422 
  0x6a002d04, 0x0a002508, 0x25581fa6, 0x59004713,   // sk.haw.un_320 mn.mk.un_430  cy.om.eu_521 sn.rn.un_650 
  0x13002907, 0x1b476408, 0x483825ad, 0x130248ee,   // sl.et.un_420 lg.sn.tr_443  mn.tk.tt_643 tt.da.et_422 
  // [6df0]
  0x34007308, 0x30342155, 0x3534580c, 0x40002502,   // ny.xh.un_430 fa.ps.uz_442  om.xh.zu_543 eu.lb.un_220 
  0x47356404, 0x47504d05, 0xfe5f3707, 0x34005d1b,   // lg.zu.sn_332 aa.fj.sn_333  st.tn.tlh_432 ss.xh.un_770 
  0x023e60ec, 0x3f002c04, 0x3f00fc05, 0x5000730c,   // vo.rm.da_644 fy.af.un_320  zzp.af.un_330 ny.fj.un_530 
  0xfe3534a7, 0x0c0102af, 0x0d2836a0, 0x33004007,   // xh.zu.tlh_532 da.en.sv_655  gn.sw.cs_322 lb.nn.un_420 
  // [6e00]
  0x0b231108, 0x353e4204, 0x1d650208, 0x15003f07,   // ro.ca.es_443 co.rm.zu_332  da.gv.la_443 af.un.un_420 
  0x18375fa6, 0x25002904, 0x287339a4, 0x23003d19,   // tn.st.ga_521 sl.eu.un_320  br.ny.sw_433 ku.ky.un_750 
  0x73003414, 0x792864a4, 0x153525ad, 0x35733412,   // xh.ny.un_660 lg.sw.war_433  mn.tg.un_643 xh.ny.zu_654 
  0x30003413, 0x3d213402, 0x35003413, 0x2d500daf,   // ps.uz.un_650 ps.fa.ku_222  xh.zu.un_650 cs.fj.sk_655 
  // [6e10]
  0x06291307, 0x09736412, 0x3c233860, 0x0a043702,   // et.sl.de_432 lg.ny.pl_654  tk.ky.ug_664 ba.ru.mk_222 
  0x377528a9, 0x332429ee, 0x43000108, 0x04352507,   // sw.nso.st_544 sl.eo.nn_422  en.ie.un_430 mn.tg.ru_432 
  0x133701a4, 0xfe007312, 0x35347312, 0x031502ee,   // en.st.et_433 ny.tlh.un_640  ny.xh.zu_654 da.nl.un_420 
  0x2c003f08, 0x183421a9, 0x04003007, 0x25000708,   // af.fy.un_430 fa.ps.ar_544  uz.ru.un_420 bg.mn.un_430 
  // [6e20]
  0x2348370b, 0x2e0c33a0, 0x343d3c12, 0x18011902,   // ba.tt.ky_542 nn.sv.fo_322  ug.ku.ps_654 gl.en.ga_222 
  0x01001804, 0x28001804, 0x1036300c, 0x041707a0,   // ga.en.un_320 ga.sw.un_320  uz.ab.be_543 bg.sr.ru_322 
  0x0c790da0, 0x406b1a0c, 0x17073007, 0x1c2f1eee,   // cs.war.sv_322 tl.ceb.lb_543  uz.bg.sr_432 ms.su.id_422 
  0x6b1a1304, 0xfe005005, 0x383730a4, 0x46005f04,   // et.tl.ceb_332 fj.tlh.un_330  uz.ba.tk_433 tn.qu.un_320 
  // [6e30]
  0x222105ee, 0x693b2105, 0xfc1a790c, 0x29002713,   // fr.jw.oc_422 jw.so.mfe_333  war.tl.zzp_543 gd.sl.un_650 
  0x645528a4, 0xfe006112, 0x5300fc29, 0x303517a4,   // sw.rw.lg_433 za.tlh.un_640  zzp.ht.un_960 sr.tg.uz_433 
  0x46004e23, 0x531821a7, 0xfc004519, 0x240176a0,   // ay.qu.un_880 fa.ar.un_532  ln.zzp.un_750 crs.en.eo_322 
  0x765369ec, 0x022e0e11, 0x0a4817a0, 0x37071509,   // mfe.ht.crs_644 is.fo.da_653  sr.tt.mk_322 un.bg.ba_444 
  // [6e40]
  0x04074809, 0x1f0476a7, 0x49005e04, 0x65004c04,   // tt.bg.ru_444 crs.fi.cy_532  ts.to.un_320 wo.gv.un_320 
  0x490f5e0c, 0xfc00460d, 0x215c1c07, 0x482330a0,   // ts.lv.to_543 qu.zzp.un_540  id.sa.jw_432 uz.ky.tt_322 
  0x2800670e, 0x735028a4, 0x2a000904, 0x37630107,   // ak.sw.un_550 sw.fj.ny_433  pl.mt.un_320 en.sco.st_432 
  0x695349ad, 0x17162502, 0x6a4a490c, 0x08170a0d,   // to.ht.mfe_643 eu.hr.sr_222  to.yo.haw_543 mk.sr.uk_554 
  // [6e50]
  0x5a496a0b, 0x5e004a0b, 0x6a00580d, 0x3800100d,   // haw.to.sm_542 yo.ts.un_520  om.haw.un_540 lt.tk.un_540 
  0x0f002e19, 0x42001708, 0x42495a08, 0x7900520d,   // fo.lv.un_750 sr.co.un_430  sm.to.co_443 ha.war.un_540 
  0x492d0d11, 0x205e4207, 0x5f3b5012, 0x3000441a,   // cs.sk.to_653 co.ts.sq_432  fj.so.tn_654 kk.uz.un_760 
  0x480d01a4, 0x6307010b, 0x13000108, 0x07101705,   // en.cs.tt_433 en.it.sco_542  en.et.un_430 sr.be.bg_333 
  // [6e60]
  0x43422614, 0x27094aad, 0x5a5829a4, 0x65006912,   // ia.co.ie_666 yo.pl.gd_643  sl.om.sm_433 mfe.gv.un_640 
  0x42321608, 0xfe61020d, 0x2e0e1ca9, 0x2e0e1ea4,   // hr.bs.co_443 da.za.tlh_554  id.is.fo_544 ms.is.fo_433 
  0x2b023107, 0x1500390d, 0x310e2e14, 0x48150a11,   // az.da.vi_432 br.un.un_540  fo.is.az_666 mk.tt.un_630 
  0x0e2557ad, 0x2f201ea4, 0x510a30a7, 0x18002b0c,   // na.eu.is_643 ms.sq.su_433  uz.pt.kl_532 vi.ga.un_530 
  // [6e70]
  0x2b3402a0, 0x1f2e39ec, 0x18002b0e, 0x0220460c,   // da.xh.vi_322 br.fo.cy_644  vi.ga.un_550 qu.sq.da_543 
  0x42052f60, 0x1f000e2a, 0x17040713, 0x030e2e13,   // su.fr.co_664 is.cy.un_970  bg.ru.sr_665 fo.is.nl_665 
  0x2b150207, 0xfe1d01a0, 0x62001c08, 0xfe20155a,   // da.vi.un_420 en.la.tlh_322  id.kha.un_430 un.sq.tlh_553 
  0x1e260107, 0xfc000504, 0x15000b05, 0x2520690c,   // en.ia.ms_432 fr.zzp.un_320  es.un.un_330 mfe.sq.eu_543 
  // [6e80]
  0x2100311a, 0x3b313009, 0x3e002e35, 0x57022108,   // az.jw.un_760 uz.az.so_444  fo.rm.un_A90 jw.da.na_443 
  0x0103020c, 0x12002b0d, 0x2e1d1c0c, 0x30020a07,   // da.nl.en_543 vi.hu.un_540  id.la.fo_543 pt.da.uz_432 
  0x0a611504, 0x2f00200d, 0x2100fc07, 0x021e2ba4,   // un.za.pt_332 sq.su.un_540  zzp.jw.un_420 vi.ms.da_433 
  0x21311da0, 0x4e30200c, 0x02fe48af, 0x28003b22,   // la.az.jw_322 sq.uz.ay_543  tt.tlh.da_655 ks.sd.un_870 
  // [6e90]
  0x34006b08, 0x05fc0213, 0x12003d05, 0x213d3013,   // ceb.xh.un_430 da.zzp.fr_665  ku.ur.un_330 uz.ku.fa_665 
  0x11653ea4, 0x2e000c05, 0xfc003e04, 0x3e000209,   // rm.gv.ro_433 sv.fo.un_330  rm.zzp.un_320 da.rm.un_440 
  0x0f001002, 0x5500fc02, 0x1200281b, 0x4404070c,   // lt.lv.un_220 zzp.rw.un_220  sd.ur.un_770 bg.ru.kk_543 
  0x302515a4, 0x443d230c, 0x153810ec, 0x33122ea0,   // un.mn.uz_433 ky.ku.kk_543  be.tk.un_644 fo.hu.nn_322 
  // [6ea0]
  0x1e1c4ea4, 0x46003008, 0x1711480c, 0x46003004,   // ay.id.ms_433 uz.qu.un_430  tt.ro.sr_543 uz.qu.un_320 
  0x304846a9, 0x040807ad, 0x46003002, 0x13001c11,   // qu.tt.uz_544 bg.uk.ru_643  uz.qu.un_220 mr.bh.un_630 
  0x0d091c5a, 0x21002804, 0x212f0407, 0x0e006507,   // mr.hi.ne_553 sd.fa.un_320  fi.su.jw_432 gv.is.un_420 
  0x15384412, 0x0e004e12, 0x2e124fa0, 0x0e3833a0,   // kk.tk.un_654 ay.is.un_640  bi.hu.fo_322 nn.tk.is_322 
  // [6eb0]
  0x30004602, 0x643829a7, 0x08004004, 0x30004613,   // qu.uz.un_220 sl.tk.lg_532  lb.no.un_320 qu.uz.un_650 
  0x0e004008, 0x21003302, 0x15004004, 0x3d18340c,   // lb.is.un_430 nn.jw.un_220  lb.un.un_320 ps.ar.ku_543 
  0x33000604, 0x02376204, 0x3044350c, 0x20001214,   // de.nn.un_320 kha.st.da_332  tg.kk.uz_543 hu.sq.un_660 
  0x1f000e0c, 0x041015a4, 0x33150ea7, 0x3f330807,   // is.cy.un_530 un.be.ru_433  is.nn.un_520 no.nn.af_432 
  // [6ec0]
  0x18002b04, 0x2300360e, 0x3015350c, 0x2c00420c,   // vi.ga.un_320 ab.ky.un_550  tg.uz.un_530 co.fy.un_530 
  0x332e0ea7, 0x29001212, 0x3e3b4c07, 0x123829a9,   // is.fo.nn_532 hu.sl.un_640  wo.so.rm_432 sl.tk.hu_544 
  0x3bfc46a0, 0x3b4c4d12, 0x131238ee, 0x29002c02,   // qu.zzp.so_322 aa.wo.so_654  tk.hu.et_422 fy.sl.un_220 
  0x65004002, 0x2a00201b, 0x4c004d2a, 0x35004408,   // lb.gv.un_220 sq.mt.un_770  aa.wo.un_970 kk.tg.un_430 
  // [6ed0]
  0x311b30a7, 0x4c003b05, 0x17002504, 0x40060c07,   // uz.tr.az_532 so.wo.un_330  mn.sr.un_320 sv.de.lb_432 
  0x2e020c55, 0x3b004c07, 0x584d3b14, 0x04301705,   // sv.da.fo_442 wo.so.un_420  so.aa.om_666 sr.uz.ru_333 
  0x58003b09, 0x3b004c14, 0x48302309, 0x3100fe07,   // so.om.un_440 wo.so.un_660  ky.uz.tt_444 tlh.az.un_420 
  0x08040a09, 0x08072507, 0x05005302, 0x17231507,   // mk.ru.uk_444 mn.bg.uk_432  ht.fr.un_220 un.ky.sr_432 
  // [6ee0]
  0x36170aa4, 0x0751fc07, 0x0800150d, 0x09382ca4,   // mk.sr.ab_433 zzp.kl.it_432  un.uk.un_540 fy.tk.pl_433 
  0x0a150407, 0xfc1d045a, 0x093f2c12, 0x07fc42a7,   // ru.mk.un_420 fi.la.zzp_553  fy.af.pl_654 co.zzp.it_532 
  0x36003812, 0x3000211b, 0xfc002c04, 0x0e000407,   // tk.ab.un_640 fa.uz.un_770  fy.zzp.un_320 fi.is.un_420 
  0x0700040e, 0x30004409, 0x05000107, 0x08023307,   // ru.bg.un_550 kk.uz.un_440  en.fr.un_420 nn.da.no_432 
  // [6ef0]
  0x1e004002, 0x09000208, 0x0e512ea4, 0x102c090c,   // lb.ms.un_220 da.pl.un_430  fo.kl.is_433 pl.fy.lt_543 
  0x4800440e, 0x50001109, 0x52645507, 0x73790907,   // kk.tt.un_550 ro.fj.un_440  rw.lg.ha_432 pl.war.ny_432 
  0x07001c05, 0x16320d0c, 0x44002505, 0x5d55640c,   // id.it.un_330 cs.bs.hr_543  mn.kk.un_330 lg.rw.ss_543 
  0x420711a0, 0x4d3e52ec, 0x3635040d, 0x3b12280c,   // ro.it.co_322 ha.rm.aa_644  ru.tg.ab_554 sd.ur.ks_543 
  // [6f00]
  0x080417af, 0x0a557907, 0x16324c04, 0x15055304,   // sr.ru.uk_655 war.rw.pt_432  wo.bs.hr_332 ht.fr.un_332 
  0x28001212, 0x56005308, 0x1d2a0704, 0x2f1a5a5a,   // ur.sd.un_640 ht.mg.un_430  it.mt.la_332 sm.tl.su_553 
  0x51100107, 0x5c6b79a4, 0x640210ad, 0x1b101d08,   // en.lt.kl_432 war.ceb.sa_433  lt.da.lg_643 la.lt.tr_443 
  0x23003821, 0x1900360b, 0x59551d14, 0x3700470e,   // tk.ky.un_860 gn.gl.un_520  la.rw.rn_666 sn.st.un_550 
  // [6f10]
  0x2d002407, 0x09130d0c, 0x302325a0, 0x5f1b34a4,   // eo.sk.un_420 ne.bh.hi_543  mn.ky.uz_322 xh.tr.tn_433 
  0x210a2f04, 0x64005d08, 0x35006405, 0x032d15a0,   // su.pt.jw_332 ss.lg.un_430  lg.zu.un_330 un.sk.nl_322 
  0x34381b08, 0x3b002a04, 0x050315a0, 0x545964a4,   // tr.tk.xh_443 mt.so.un_320  un.nl.fr_322 lg.rn.ik_433 
  0x76011d0c, 0x357837a9, 0x371b34ec, 0x5c1d1060,   // la.en.crs_543 st.ve.zu_544  xh.tr.st_644 lt.la.sa_664 
  // [6f20]
  0x581b380c, 0x75003809, 0x34006807, 0x01003f04,   // tk.tr.om_543 tk.nso.un_440  ig.xh.un_420 af.en.un_320 
  0x51001d08, 0x5f641da4, 0x51755f5a, 0x1a4713a9,   // la.kl.un_430 la.lg.tn_433  tn.nso.kl_553 et.sn.tl_544 
  0x101d0412, 0xfe007309, 0x354c46a7, 0x051b340c,   // fi.la.lt_654 ny.tlh.un_440  qu.wo.zu_532 xh.tr.fr_543 
  0x18213c02, 0x39694c12, 0x6459550e, 0x5f381b0d,   // ug.fa.ar_222 wo.mfe.br_654  rw.rn.lg_555 tr.tk.tn_554 
  // [6f30]
  0x1b00311b, 0x58375104, 0x4423380c, 0x281230a0,   // az.tr.un_770 kl.st.om_332  tk.ky.kk_543 uz.ur.sd_322 
  0x2500300d, 0x20001b02, 0x304836a9, 0x0a041512,   // uz.mn.un_540 tr.sq.un_220  ab.tt.uz_544 un.ru.mk_654 
  0x311b480d, 0x2a000908, 0x3e072a0c, 0x343d3bad,   // tt.tr.az_554 pl.mt.un_430  mt.it.rm_543 ks.ku.ps_643 
  0x42002a19, 0x1e005202, 0x2a004214, 0x3d211205,   // mt.co.un_750 ha.ms.un_220  co.mt.un_660 ur.fa.ku_333 
  // [6f40]
  0x2a000723, 0x52006413, 0x100407a0, 0x211230a4,   // it.mt.un_880 lg.ha.un_650  bg.ru.be_322 uz.ur.fa_433 
  0x5dfa27a4, 0x551d3060, 0x353447a4, 0x355f2807,   // gd.nr.ss_433 uz.la.rw_664  sn.xh.zu_433 sw.tn.zu_432 
  0x5c355d12, 0x293e2a0c, 0x1d432607, 0x475c35a4,   // ss.zu.sa_654 mt.rm.sl_543  ia.ie.la_432 zu.sa.sn_433 
  0x64554204, 0x07426404, 0x07002a13, 0x3400350d,   // co.rw.lg_332 lg.co.it_332  mt.it.un_650 zu.xh.un_540 
  // [6f50]
  0x0b421da9, 0x213d120c, 0x4c000208, 0x253c300d,   // la.co.es_544 ur.ku.fa_543  da.wo.un_430 uz.ug.mn_554 
  0x3435470c, 0x19353402, 0x35345dad, 0x6400590c,   // sn.zu.xh_543 xh.zu.gl_222  ss.xh.zu_643 rn.lg.un_530 
  0x1f0c63a4, 0x64792805, 0x37001513, 0x5500450c,   // sco.sv.cy_433 sw.war.lg_333  un.ba.un_650 ln.rw.un_530 
  0x31796baf, 0x211234ad, 0x2d0d1755, 0x071135a4,   // ceb.war.az_655 ps.ur.fa_643  sr.cs.sk_442 tg.ro.bg_433 
  // [6f60]
  0x3534fc0e, 0x08070a02, 0x02005c04, 0x3000231b,   // zzp.xh.zu_555 mk.bg.uk_222  sa.da.un_320 ky.uz.un_770 
  0x1c0d0912, 0x044815a0, 0x65001f0d, 0x42002319,   // hi.ne.mr_654 un.tt.ru_322  cy.gv.un_540 ca.co.un_750 
  0x48003b04, 0x120b2d02, 0x652d0d08, 0x34350212,   // so.tt.un_320 sk.es.hu_222  cs.sk.gv_443 da.zu.xh_654 
  0x3d442312, 0x0a372504, 0x5f1d1f07, 0x6b386007,   // ky.kk.ku_654 mn.ba.mk_332  cy.la.tn_432 vo.tk.ceb_432 
  // [6f70]
  0x5f37640e, 0x484425a9, 0x300725ad, 0x5f582fa0,   // lg.st.tn_555 mn.kk.tt_544  mn.bg.uz_643 su.om.tn_322 
  0x1d7312a4, 0x0c002502, 0x28005104, 0x5d4e35af,   // hu.ny.la_433 eu.sv.un_220  kl.sw.un_320 zu.ay.ss_655 
  0x44003713, 0x355f3407, 0xfe353414, 0x3e00600c,   // ba.kk.un_650 xh.tn.zu_432  xh.zu.tlh_666 vo.rm.un_530 
  0x0e004c02, 0x581d5dac, 0x6bfe1dee, 0x38121ba7,   // wo.is.un_220 ss.la.om_632  la.tlh.ceb_422 tr.hu.tk_532 
  // [6f80]
  0x34002308, 0x253538a7, 0x7335340e, 0x25353012,   // ky.ps.un_430 tk.tg.mn_532  xh.zu.ny_555 uz.tg.mn_654 
  0x021d4655, 0x0e003002, 0x08042507, 0x1d00730d,   // qu.la.da_442 uz.is.un_220  mn.ru.uk_432 ny.la.un_540 
  0x38003608, 0x65001d05, 0x4f026504, 0x5c001807,   // gn.tk.un_430 la.gv.un_330  gv.da.bi_332 ga.sa.un_420 
  0x0d005305, 0x53002208, 0x3f401da0, 0x1715300c,   // ht.cs.un_330 oc.ht.un_430  la.lb.af_322 uz.sr.un_530 
  // [6f90]
  0x5300220d, 0x230738ec, 0x2d002102, 0x3608230c,   // oc.ht.un_540 tk.bg.ky_644  jw.sk.un_220 ky.uk.ab_543 
  0x1a630107, 0x2102fe5a, 0x22005304, 0x130218ad,   // en.sco.tl_432 tlh.da.jw_553  ht.oc.un_320 ga.da.et_643 
  0x2d001011, 0x02216013, 0x1c005302, 0x2a020f11,   // lt.sk.un_630 vo.jw.da_665  ht.id.un_220 lv.da.mt_653 
  0x322efea9, 0x240e2e12, 0x04002007, 0x08002302,   // tlh.fo.bs_544 fo.is.eo_654  sq.fi.un_420 ky.uk.un_220 
  // [6fa0]
  0x4c330ca9, 0x230e020c, 0x2d120dee, 0x34002a02,   // sv.nn.wo_544 da.is.ca_543  cs.hu.sk_422 mt.xh.un_220 
  0x2d12090b, 0x1502330e, 0x02650309, 0x1279530b,   // pl.hu.sk_542 nn.da.un_555  nl.gv.da_444 ht.war.hu_542 
  0x0c002404, 0x083017ee, 0x56022004, 0x1000120c,   // eo.sv.un_320 sr.uz.uk_422  sq.da.mg_332 hu.lt.un_530 
  0x220208a4, 0x35000713, 0x20002b02, 0xfc375fad,   // no.da.oc_433 bg.tg.un_650  vi.sq.un_220 tn.st.zzp_643 
  // [6fb0]
  0x1d0601a0, 0x2a002e19, 0xfc003402, 0x120833ee,   // en.de.la_322 fo.mt.un_750  xh.zzp.un_220 nn.no.hu_422 
  0x6400fc08, 0x65601504, 0x4b5c5a07, 0x182344ad,   // zzp.lg.un_430 un.vo.gv_332  sm.sa.mi_432 kk.ky.ar_643 
  0x050601af, 0x39001f18, 0x06050109, 0x0704150e,   // en.de.fr_655 cy.br.un_740  en.fr.de_444 un.ru.bg_555 
  0x5c5d5704, 0x0a001723, 0x3f092c04, 0x78284913,   // na.ss.sa_332 sr.mk.un_880  fy.pl.af_332 to.sw.ve_665 
  // [6fc0]
  0x38233c08, 0x04370aa4, 0x0f524908, 0x35343b0c,   // ug.ky.tk_443 mk.ba.ru_433  to.ha.lv_443 so.xh.zu_543 
  0x5a00040c, 0x0e2910ad, 0x64524ca4, 0x09002c0c,   // fi.sm.un_530 lt.sl.is_643  wo.ha.lg_433 fy.pl.un_530 
  0x527328a4, 0x0d734c07, 0x05005304, 0x07043508,   // sw.ny.ha_433 wo.ny.cs_432  ht.fr.un_320 tg.ru.bg_443 
  0x644c52a4, 0x1d0c5905, 0x472852ad, 0x1b636aad,   // ha.wo.lg_433 rn.sv.la_333  ha.sw.sn_643 haw.sco.tr_643 
  // [6fd0]
  0x64783ba9, 0x5f4a5ca0, 0x0a0723ee, 0x07630112,   // so.ve.lg_544 sa.yo.tn_322  ky.bg.mk_422 en.sco.it_654 
  0x342812a9, 0x3f0902ec, 0x394c42a0, 0x375f340c,   // ur.sd.ps_544 da.pl.af_644  co.wo.br_322 xh.tn.st_543 
  0x252c3fee, 0x47495a55, 0x40003b0d, 0x50002a07,   // af.fy.eu_422 sm.to.sn_442  so.lb.un_540 mt.fj.un_420 
  0x0e003822, 0x050911a7, 0x212f1c09, 0x3800621a,   // tk.is.un_870 ro.pl.fr_532  id.su.jw_444 kha.tk.un_760 
  // [6fe0]
  0x132c5307, 0x0a495a5a, 0x38330807, 0x352534a4,   // ht.fy.et_432 sm.to.pt_553  no.nn.tk_432 xh.eu.zu_433 
  0x0a003507, 0x4d004c1b, 0x3f001f08, 0x63005314,   // tg.mk.un_420 wo.aa.un_770  cy.af.un_430 ht.sco.un_660 
  0x53000104, 0x5c091ca7, 0x0a49500d, 0x041510ec,   // en.ht.un_320 mr.hi.sa_532  fj.to.pt_554 be.ru.un_640 
  0x50286aec, 0x2e3f65a7, 0x1d205aee, 0x58090607,   // haw.sw.fj_644 gv.af.fo_532  sm.sq.la_422 de.pl.om_432 
  // [6ff0]
  0x302112a9, 0x0825600b, 0x351f1808, 0x033f400c,   // ur.fa.uz_544 vo.eu.no_542  ga.cy.zu_443 lb.af.nl_543 
  0x5e355daf, 0x2d0e0da0, 0xfe004008, 0x040717a0,   // ss.zu.ts_655 cs.is.sk_322  lb.tlh.un_430 sr.bg.ru_322 
  0x072530a4, 0x1300400c, 0x63064d04, 0x0d2718a4,   // uz.mn.bg_433 lb.et.un_530  aa.de.sco_332 ga.gd.cs_433 
  0x06005e0b, 0x0c2e3bee, 0x271865af, 0x3000200d,   // ts.de.un_520 so.fo.sv_422  gv.ga.gd_655 sq.uz.un_540 
  
  // [7000]
  0x37002d07, 0x341827a4, 0x551e0207, 0x09190f08,   // sk.st.un_420 gd.ga.xh_433  da.ms.rw_432 lv.gl.pl_443 
  0x791a6baf, 0x39000d0c, 0x385c7904, 0x3c384812,   // ceb.tl.war_655 cs.br.un_530  war.sa.tk_332 tt.tk.ug_654 
  0x1b000d08, 0x190b12a4, 0x13003912, 0x79460207,   // cs.tr.un_430 hu.es.gl_433  br.et.un_640 da.qu.war_432 
  0x190e2eee, 0x0d00610c, 0xfc000f18, 0x03003b09,   // fo.is.gl_422 za.cs.un_530  lv.zzp.un_740 so.nl.un_440 
  // [7010]
  0x3862655a, 0x1c301ea9, 0x0e38790b, 0x5f1e1c0d,   // gv.kha.tk_553 ms.uz.id_544  war.tk.is_542 id.ms.tn_554 
  0x6b791a55, 0x4c0f1008, 0xfc4d130c, 0x49122ea9,   // tl.war.ceb_442 lt.lv.wo_443  et.aa.zzp_543 fo.hu.to_544 
  0x072335a4, 0x381a79a4, 0x2245250c, 0x5d605e0c,   // tg.ky.bg_433 war.tl.tk_433  eu.ln.oc_543 ts.vo.ss_543 
  0x392825ad, 0x31004d0b, 0x396a3808, 0x1b003604,   // eu.sw.br_643 aa.az.un_520  tk.haw.br_443 gn.tr.un_320 
  // [7020]
  0x1e001c2b, 0x34001d02, 0x30005c13, 0xfc5c4704,   // id.ms.un_980 la.xh.un_220  sa.uz.un_650 sn.sa.zzp_332 
  0x17480404, 0x1715380c, 0x1c4c21a9, 0x56450507,   // ru.tt.sr_332 tk.sr.un_530  jw.wo.id_544 fr.ln.mg_432 
  0x4b5c0f12, 0x32312aac, 0x11000f0b, 0x102d0d02,   // lv.sa.mi_654 mt.az.bs_632  lv.ro.un_520 cs.sk.lt_222 
  0x23253ca6, 0x0f5c4b0d, 0x400c0604, 0x1500250d,   // ug.mn.ky_521 mi.sa.lv_554  de.sv.lb_332 mn.un.un_540 
  // [7030]
  0x345530ee, 0x2c0833a0, 0x2d00100e, 0x110d0f12,   // uz.rw.xh_422 nn.no.fy_322  lt.sk.un_550 lv.cs.ro_654 
  0x17000f13, 0x1711040c, 0x080410ec, 0x0a3517a0,   // lv.sr.un_650 ru.ro.sr_543  be.ru.uk_644 sr.tg.mk_322 
  0x34214407, 0x0d000912, 0x34301208, 0x2315440d,   // kk.fa.ps_432 hi.ne.un_640  ur.uz.ps_443 kk.ky.un_540 
  0x00005406, 0x2300482a, 0x06030ca0, 0x32162912,   // ik.un.un_400 tt.ky.un_970  sv.nl.de_322 sl.hr.bs_654 
  // [7040]
  0x0500fe04, 0x3025380c, 0x5700fe0c, 0x1d6701a0,   // tlh.fr.un_320 tk.mn.uz_543  tlh.na.un_530 en.ak.la_322 
  0x640259a9, 0x59001d0e, 0x556459ec, 0x0261640c,   // rn.da.lg_544 la.rn.un_550  rn.lg.rw_644 lg.za.da_543 
  0x5c2853ee, 0x570264ad, 0x23483813, 0x24504d08,   // ht.sw.sa_422 lg.da.na_643  tk.tt.ky_665 aa.fj.eo_443 
  0x03022113, 0x0200030c, 0x013e0211, 0x02000322,   // jw.da.nl_665 nl.da.un_530  da.rm.en_653 nl.da.un_870 
  // [7050]
  0x020c3ea4, 0x3f005602, 0x1c640212, 0x24103eee,   // rm.sv.da_433 mg.af.un_220  da.lg.id_654 rm.lt.eo_422 
  0x2c1310ee, 0x0a351704, 0x0a4825a4, 0x61001f2a,   // lt.et.fy_422 sr.tg.mk_332  mn.tt.mk_433 cy.za.un_970 
  0xfe156ea0, 0x5000271b, 0x38000f08, 0x02595514,   // hmn.tlh.un_320 gd.fj.un_770  lv.tk.un_430 rw.rn.da_666 
  0x5c004d08, 0x06016ea0, 0x46360bee, 0x582a1c07,   // aa.sa.un_430 hmn.en.de_322  es.gn.qu_422 id.mt.om_432 
  // [7060]
  0x06002107, 0x38033f07, 0x05010607, 0x0900100d,   // jw.de.un_420 af.nl.tk_432  de.en.fr_432 lt.pl.un_540 
  0xfc002705, 0x064d01a0, 0x036e6709, 0x63061b0c,   // gd.zzp.un_330 en.aa.de_322  ak.hmn.nl_444 tr.de.sco_543 
  0x13002a05, 0x5000670b, 0x5800250c, 0x0e004c04,   // mt.et.un_330 ak.fj.un_520  eu.om.un_530 wo.is.un_320 
  0xfe100f07, 0x27004802, 0x3d183b0b, 0x30fe5805,   // lv.lt.tlh_432 tt.gd.un_220  ks.ar.ku_542 om.tlh.uz_333 
  // [7070]
  0x3e000f19, 0x4d003014, 0x041023a4, 0xfe00690e,   // lv.rm.un_750 uz.aa.un_660  ky.be.ru_433 mfe.tlh.un_550 
  0x061827ee, 0x303c3512, 0x3f1b06a6, 0x3f332fa0,   // gd.ga.de_422 tg.ug.uz_654  de.tr.af_521 su.nn.af_322 
  0x482511ad, 0x4a6001a0, 0x0c153ead, 0x3e002613,   // ro.mn.tt_643 en.vo.yo_322  rm.sv.un_630 ia.rm.un_650 
  0x3e001513, 0x4a002e1a, 0x796501a0, 0x32170daf,   // un.rm.un_650 fo.yo.un_760  en.gv.war_322 cs.sr.bs_655 
  // [7080]
  0x44003b08, 0x2c391da0, 0x46360b08, 0x170a1104,   // ks.kk.un_430 la.br.fy_322  es.gn.qu_443 ro.mk.sr_332 
  0x0b1a0607, 0x10080204, 0x0a000104, 0x0e2460ec,   // de.tl.es_432 da.no.lt_332  en.pt.un_320 vo.eo.is_644 
  0x79027607, 0x1d005712, 0x330208af, 0x122123a9,   // crs.da.war_432 na.la.un_640  no.da.nn_655 ky.fa.ur_544 
  0x40002c2b, 0x31001b21, 0x121834a0, 0x08002c12,   // fy.lb.un_980 tr.az.un_860  ps.ar.ur_322 fy.no.un_640 
  // [7090]
  0x2c003808, 0x12213405, 0x18003d08, 0x49005002,   // tk.fy.un_430 ps.fa.ur_333  ku.ar.un_430 fj.to.un_220 
  0x7300fc13, 0x1f007308, 0x040a07ec, 0x07381505,   // zzp.ny.un_650 ny.cy.un_430  bg.mk.ru_644 un.tk.bg_333 
  0x7300fc1a, 0x343c23a0, 0xfc007319, 0xfc00731b,   // zzp.ny.un_760 ky.ug.ps_322  ny.zzp.un_750 ny.zzp.un_770 
  0x18213ca0, 0x48301560, 0x033ffcad, 0x73fc5e0d,   // ug.fa.ar_322 un.uz.tt_664  zzp.af.nl_643 ts.zzp.ny_554 
  // [70a0]
  0x0f002802, 0x3f0363a4, 0x130c040c, 0x4c644da0,   // sw.lv.un_220 sco.nl.af_433  fi.sv.et_543 aa.lg.wo_322 
  0x3715480d, 0x49253704, 0x3e001007, 0x09fc7312,   // tt.ba.un_540 st.eu.to_332  lt.rm.un_420 ny.zzp.pl_654 
  0x62380107, 0x1500fc07, 0x02fc29a0, 0x731ffc07,   // en.tk.kha_432 zzp.un.un_420  sl.zzp.da_322 zzp.cy.ny_432 
  0x3f004c04, 0x1f73fc0c, 0x3217fea0, 0x5373fca7,   // wo.af.un_320 zzp.ny.cy_543  tlh.sr.bs_322 zzp.ny.ht_532 
  // [70b0]
  0x1c005c1b, 0x29321604, 0x0400350d, 0x2400130c,   // sa.mr.un_770 hr.bs.sl_332  tg.ru.un_540 et.eo.un_530 
  0x163857a0, 0x64002504, 0x3b006405, 0x08004808,   // na.tk.hr_322 eu.lg.un_320  lg.so.un_330 tt.uk.un_430 
  0x530313a0, 0x2508040c, 0xfc641313, 0x1c5c0daf,   // et.nl.ht_322 ru.uk.mn_543  et.lg.zzp_665 ne.sa.mr_655 
  0x182334ee, 0x1004380c, 0x2c004035, 0x04150760,   // ps.ky.ar_422 tk.ru.be_543  lb.fy.un_A90 bg.ru.un_640 
  // [70c0]
  0x4c6e6407, 0x173510ee, 0x301348ee, 0xfc2110a4,   // lg.hmn.wo_432 be.tg.sr_422  tt.et.uz_422 lt.jw.zzp_433 
  0x02266ba4, 0x39022f02, 0x3f02fe07, 0x2c033f05,   // ceb.ia.da_433 su.da.br_222  tlh.da.af_432 af.nl.fy_333 
  0x34213dad, 0x080410ad, 0x3435470b, 0x28343d07,   // ku.fa.ps_643 be.ru.uk_643  sn.zu.xh_542 ku.ps.sd_432 
  0x524734ad, 0x53766913, 0x35005304, 0x1500fe09,   // xh.sn.ha_643 mfe.crs.ht_665  ht.zu.un_320 tlh.un.un_440 
  // [70d0]
  0x3400351a, 0xfc4d4e08, 0x2d001704, 0x1f476407,   // zu.xh.un_760 ay.aa.zzp_443  sr.sk.un_320 lg.sn.cy_432 
  0x3b001f04, 0x34383507, 0x7876690e, 0x2c0c0255,   // cy.so.un_320 zu.tk.xh_432  mfe.crs.ve_555 da.sv.fy_442 
  0x40000207, 0x01183bee, 0x2c003f13, 0x595569af,   // da.lb.un_420 so.ga.en_422  af.fy.un_650 mfe.rw.rn_655 
  0x655378a6, 0x44303ca7, 0x76695312, 0x150436a4,   // ve.ht.gv_521 ug.uz.kk_532  ht.mfe.crs_654 ab.ru.un_433 
  // [70e0]
  0x52595504, 0x2a004c0b, 0x6e006b12, 0x48001b18,   // rw.rn.ha_332 wo.mt.un_520  ceb.hmn.un_640 tr.tt.un_740 
  0x04170aa7, 0x0715040e, 0x37003012, 0x34183b12,   // mk.sr.ru_532 ru.bg.un_550  uz.ba.un_640 ks.ar.ps_654 
  0x4d016314, 0x2a4251a9, 0x0a073704, 0x54465360,   // sco.en.aa_666 kl.co.mt_544  ba.bg.mk_332 ht.qu.ik_664 
  0x09024da4, 0x123d3ba0, 0x4d462da4, 0x29302008,   // aa.da.pl_433 ks.ku.ur_322  sk.qu.aa_433 sq.uz.sl_443 
  // [70f0]
  0x292d0d07, 0x4d134b09, 0x305e2d02, 0x29302da0,   // cs.sk.sl_432 mi.et.aa_444  sk.ts.uz_222 sk.uz.sl_322 
  0x371511ad, 0x1b312d08, 0x38203008, 0x1b004813,   // ro.ba.un_630 sk.az.tr_443  uz.sq.tk_443 tt.tr.un_650 
  0x39420511, 0x3609460c, 0x47004c04, 0x30292d07,   // fr.co.br_653 qu.pl.gn_543  wo.sn.un_320 sk.sl.uz_432 
  0x4c004619, 0x51541308, 0x124a2d55, 0x38462d09,   // qu.wo.un_750 et.ik.kl_443  sk.yo.hu_442 sk.qu.tk_444 
  // [7100]
  0x21025312, 0x031c0208, 0x150701a0, 0x600310ec,   // ht.da.jw_654 da.id.nl_443  en.it.un_322 lt.nl.vo_644 
  0x150848a4, 0x03653f04, 0x4b000f0c, 0x2e0c0e04,   // tt.uk.un_433 af.gv.nl_332  lv.mi.un_530 is.sv.fo_332 
  0x1d4301a0, 0x2b150208, 0x40051d13, 0x061521ad,   // en.ie.la_322 da.vi.un_430  la.fr.lb_665 jw.de.un_630 
  0x04200212, 0x301048a9, 0x3c00300c, 0x30000823,   // da.sq.fi_654 tt.be.uz_544  uz.ug.un_530 uk.uz.un_880 
  // [7110]
  0x34443c05, 0x070415a4, 0x311bfaa4, 0x690601ee,   // ug.kk.ps_333 un.ru.bg_433  nr.tr.az_433 en.de.mfe_422 
  0x42030212, 0x4421230c, 0x25303807, 0x2102030c,   // da.nl.co_654 ky.fa.kk_543  tk.uz.mn_432 nl.da.jw_543 
  0x071711ec, 0x15004809, 0x090253ec, 0x17353cec,   // ro.sr.bg_644 tt.un.un_440  ht.da.pl_644 ug.tg.sr_644 
  0x40003005, 0x33081daf, 0x3b0e11a4, 0x5dfc0eee,   // uz.lb.un_330 la.no.nn_655  ro.is.so_433 is.zzp.ss_422 
  // [7120]
  0x2902160c, 0x3b002319, 0x483023af, 0x1c135c55,   // hr.da.sl_543 ky.ks.un_750  ky.uz.tt_655 sa.bh.mr_442 
  0x21343cee, 0x25003005, 0x2900110d, 0x0d2911a7,   // ug.ps.fa_422 uz.mn.un_330  ro.sl.un_540 ro.sl.cs_532 
  0xfc002205, 0x35003029, 0x23153011, 0x53572211,   // oc.zzp.un_330 uz.tg.un_960  uz.ky.un_630 oc.na.ht_653 
  0x0c001308, 0x343d3012, 0x0d5c1c0d, 0x3b002114,   // et.sv.un_430 uz.ku.ps_654  mr.sa.ne_554 fa.ks.un_660 
  // [7130]
  0x3d282111, 0x08043cec, 0x06233ea7, 0x212f61ad,   // fa.sd.ku_653 ug.ru.uk_644  rm.ca.de_532 za.su.jw_643 
  0x0c004312, 0x35300702, 0x07170a0d, 0x0c003e04,   // ie.sv.un_640 bg.uz.tg_222  mk.sr.bg_554 rm.sv.un_320 
  0x1228210e, 0x2e003e02, 0x0a071714, 0x3c483812,   // fa.sd.ur_555 rm.fo.un_220  sr.bg.mk_666 tk.tt.ug_654 
  0x0c330802, 0x5d00320c, 0x11fc2a0c, 0x01000c04,   // no.nn.sv_222 bs.ss.un_530  mt.zzp.ro_543 sv.en.un_320 
  // [7140]
  0x15151008, 0x08171112, 0x1c121e04, 0x12003d20,   // be.un.un_430 ro.sr.uk_654  ms.hu.id_332 ku.ur.un_850 
  0x16000b02, 0x6b0c38a9, 0x21001819, 0x36153007,   // es.hr.un_220 tk.sv.ceb_544  ar.fa.un_750 uz.ab.un_420 
  0x13000609, 0x481e1cad, 0x643830a0, 0x64007308,   // de.et.un_440 id.ms.tt_643  uz.tk.lg_322 ny.lg.un_430 
  0x0cfe1204, 0x080254a9, 0x645c3011, 0x2c005108,   // hu.tlh.sv_332 ik.da.no_544  uz.sa.lg_653 kl.fy.un_430 
  // [7150]
  0x2e0c0ea4, 0x020279a0, 0x22fc1107, 0x34282112,   // is.sv.fo_433 war.da.da_322  ro.zzp.oc_432 fa.sd.ps_654 
  0xfc001304, 0x5c003002, 0x6500010d, 0x04151155,   // et.zzp.un_320 uz.sa.un_220  en.gv.un_540 ro.ru.un_420 
  0x34281805, 0x03763f55, 0x3900610d, 0x071004ad,   // ar.sd.ps_333 af.crs.nl_442  za.br.un_540 ru.be.bg_643 
  0x61003f13, 0x36103809, 0x3f390304, 0x12401307,   // af.za.un_650 tk.be.ab_444  nl.br.af_332 et.lb.hu_432 
  // [7160]
  0x1700070d, 0x33084c55, 0x170807ee, 0x13004005,   // bg.sr.un_540 wo.no.nn_442  bg.uk.sr_422 lb.et.un_330 
  0x190b1802, 0x3c00232b, 0x02003902, 0x321710a0,   // ga.es.gl_222 ky.ug.un_980  br.da.un_220 lt.sr.bs_322 
  0x03004905, 0x1504350e, 0x10150407, 0x313848a0,   // to.nl.un_330 tg.ru.un_555  ru.be.un_420 tt.tk.az_322 
  0x443c38ee, 0x5c1c0d0d, 0x330813a0, 0x0a0407a9,   // tk.ug.kk_422 ne.mr.sa_554  et.no.nn_322 bg.ru.mk_544 
  // [7170]
  0x02202409, 0x13004c07, 0x22002307, 0x290d09ee,   // eo.sq.da_444 wo.et.un_420  ca.oc.un_420 pl.cs.sl_422 
  0x35373012, 0x213012a9, 0x00001137, 0x23444804,   // uz.ba.tg_654 ur.uz.fa_544  ro.un.un_B00 tt.kk.ky_332 
  0x110a1f12, 0x1f4c49ad, 0x4c002736, 0x02400611,   // cy.pt.ro_654 to.wo.cy_643  gd.wo.un_AA0 de.lb.da_653 
  0x4f004c36, 0x6e482b0c, 0x3700230c, 0x096b48a7,   // wo.bi.un_AA0 vi.tt.hmn_543  ky.ba.un_530 tt.ceb.pl_532 
  // [7180]
  0x1500170e, 0x6afe6912, 0x05fe2213, 0x504340a9,   // sr.un.un_550 mfe.tlh.haw_654  oc.tlh.fr_665 lb.ie.fj_544 
  0x381729a9, 0x674c5e12, 0x18002121, 0x58003b35,   // sl.sr.tk_544 ts.wo.ak_654  jw.ga.un_860 so.om.un_A90 
  0x21283bee, 0x31543855, 0x13002a19, 0x1b001c04,   // ks.sd.fa_422 tk.ik.az_442  mt.et.un_750 id.tr.un_320 
  0x421f6a09, 0x301b38a9, 0x15073c0c, 0x54fc4dad,   // haw.cy.co_444 tk.tr.uz_544  ug.bg.un_543 aa.zzp.ik_643 
  // [7190]
  0x350a110c, 0x6162fea4, 0x094a4c0c, 0x1b310e08,   // ro.mk.tg_543 tlh.kha.za_433  wo.yo.pl_543 is.az.tr_443 
  0x322907a9, 0x38351705, 0x444837af, 0x1f003e04,   // it.sl.bs_544 sr.tg.tk_333  ba.tt.kk_655 rm.cy.un_320 
  0x15002904, 0x303b31ad, 0x481b31a9, 0x1b30feec,   // sl.un.un_320 az.so.uz_643  az.tr.tt_544 tlh.uz.tr_644 
  0x093b46a4, 0x071735ad, 0x426a5a08, 0x76693e0d,   // qu.so.pl_433 tg.sr.bg_643  sm.haw.co_443 rm.mfe.crs_554 
  // [71a0]
  0x3130fe09, 0x21303dee, 0xfc62615a, 0x095c1c11,   // tlh.uz.az_444 ku.uz.fa_422  za.kha.zzp_553 mr.sa.hi_653 
  0x48234404, 0x04251555, 0x091c5c0e, 0x475d5ca9,   // kk.ky.tt_332 un.mn.ru_442  sa.mr.hi_555 sa.ss.sn_544 
  0x34182304, 0x18345c0c, 0x64003405, 0x564005ee,   // ky.ar.ps_332 sa.xh.ga_543  xh.lg.un_330 fr.lb.mg_422 
  0x27005c1b, 0x081333a0, 0x033f06a7, 0x482113a0,   // sa.gd.un_770 nn.et.no_322  de.af.nl_532 et.jw.tt_322 
  // [71b0]
  0x1d796007, 0x123d18ac, 0xfc5c1b12, 0x1b002c19,   // vo.war.la_432 ar.ku.ur_632  tr.sa.zzp_654 fy.tr.un_750 
  0x5c5d3504, 0x3f007307, 0x53760455, 0x0143fcad,   // zu.ss.sa_332 ny.af.un_420  fi.crs.ht_442 zzp.ie.en_643 
  0x033f0613, 0x3f0603a4, 0x35475cec, 0x40060355,   // de.af.nl_665 nl.de.af_433  sa.sn.zu_644 nl.de.lb_442 
  0x47005c19, 0x07380a08, 0x1218340e, 0x47185cad,   // sa.sn.un_750 mk.tk.bg_443  ps.ar.ur_555 sa.ga.sn_643 
  // [71c0]
  0x00006737, 0x48374408, 0x27475c05, 0x253810ec,   // ak.un.un_B00 kk.ba.tt_443  sa.sn.gd_333 be.tk.mn_644 
  0x1b43fca7, 0x30003419, 0x381065a0, 0x10374808,   // zzp.ie.tr_532 ps.uz.un_750  gv.lt.tk_322 tt.ba.be_443 
  0x06380955, 0x531202a0, 0x173007ee, 0x5c005305,   // pl.tk.de_442 da.hu.ht_322  bg.uz.sr_422 ht.sa.un_330 
  0x021f65ad, 0x040810a6, 0x3c003404, 0x0b794607,   // gv.cy.da_643 be.uk.ru_521  ps.ug.un_320 qu.war.es_432 
  // [71d0]
  0x251038a0, 0x47002f07, 0x671b3013, 0x2d0d56a0,   // tk.be.mn_322 su.sn.un_420  uz.tr.ak_665 mg.cs.sk_322 
  0x38001007, 0x1b00480c, 0x481b3104, 0x30441555,   // lt.tk.un_420 tt.tr.un_530  az.tr.tt_332 un.kk.uz_442 
  0x31004822, 0x12005c07, 0x460b3605, 0x3f380907,   // tt.az.un_870 sa.hu.un_420  gn.es.qu_333 pl.tk.af_432 
  0x1b5931a0, 0x6900762b, 0xfc1f38ad, 0x30152560,   // az.rn.tr_322 crs.mfe.un_980  tk.cy.zzp_643 mn.uz.un_640 
  // [71e0]
  0x551a49ee, 0x48311b12, 0x6a000108, 0x303d3b0c,   // to.tl.rw_422 tr.az.tt_654  en.haw.un_430 ks.ku.uz_543 
  0x4e00521b, 0x02450ea9, 0x73005408, 0x38000205,   // ha.ay.un_770 is.ln.da_544  ik.ny.un_430 da.tk.un_330 
  0x2b00650c, 0x6a2f52ac, 0x1c52150c, 0x23481511,   // gv.vi.un_530 ha.su.haw_632  un.ha.id_543 un.tt.ky_653 
  0x10496308, 0x31001c04, 0x2d0d560c, 0x59556bec,   // sco.to.lt_443 id.az.un_320  mg.cs.sk_543 ceb.rw.rn_644 
  // [71f0]
  0x2d005607, 0x342821ad, 0x1d1e28a4, 0x4a554504,   // mg.sk.un_420 fa.sd.ps_643  sw.ms.la_433 ln.rw.yo_332 
  0x0d093807, 0x48083009, 0x211b1ea4, 0x384f1c0c,   // tk.pl.cs_432 uz.uk.tt_444  ms.tr.jw_433 id.bi.tk_543 
  0x243615a0, 0x20495aa0, 0x4f2b45ac, 0x10002319,   // un.gn.eo_322 sm.to.sq_322  ln.vi.bi_632 ky.be.un_750 
  0x44283407, 0x20046a0c, 0x44483707, 0x4b005a0d,   // ps.sd.kk_432 haw.fi.sq_543  ba.tt.kk_432 sm.mi.un_540 
  // [7200]
  0x1f4b6a0c, 0x07040a09, 0x2d330804, 0x495b5a07,   // haw.mi.cy_543 mk.ru.bg_444  no.nn.sk_332 sm.sg.to_432 
  0x0f005c18, 0x0c1233a0, 0x424a0207, 0x2b502304,   // sa.lv.un_740 nn.hu.sv_322  da.yo.co_432 ca.fj.vi_332 
  0x07151105, 0x3300fc04, 0x37304807, 0x2304080c,   // ro.bg.un_330 zzp.nn.un_320  tt.uz.ba_432 uk.ru.ky_543 
  0x57252014, 0x15000405, 0x07262a07, 0x364502a7,   // sq.eu.na_666 ru.un.un_330  mt.ia.it_432 da.ln.gn_532 
  // [7210]
  0x17fe0807, 0x2520190c, 0x124702a0, 0x5005360c,   // no.tlh.sr_432 gl.sq.eu_543  da.sn.hu_322 gn.fr.fj_543 
  0x080233ec, 0x4b20500c, 0x3530380c, 0x2e001908,   // nn.da.no_644 fj.sq.mi_543  tk.uz.tg_543 gl.fo.un_430 
  0x695020a4, 0x114257a9, 0x28003307, 0x3d2134a4,   // sq.fj.mfe_433 na.co.ro_544  nn.sw.un_420 ps.fa.ku_433 
  0x443038a7, 0x230a3007, 0x363844a4, 0x0a000713,   // tk.uz.kk_532 uz.mk.ky_432  kk.tk.ab_433 bg.mk.un_650 
  // [7220]
  0x090d1c0c, 0x19000d07, 0x0d001908, 0x1037480c,   // mr.ne.hi_543 cs.gl.un_420  gl.cs.un_430 tt.ba.be_543 
  0x18003411, 0x31001b0b, 0x283412af, 0x350a1702,   // ps.ar.un_630 tr.az.un_520  ur.ps.sd_655 sr.mk.tg_222 
  0x30071504, 0x25004b07, 0x1f003804, 0x0e000d0c,   // un.bg.uz_332 mi.eu.un_420  tk.cy.un_320 cs.is.un_530 
  0x4815100c, 0x1b483112, 0x07150412, 0x6529170d,   // be.tt.un_530 az.tt.tr_654  ru.bg.un_640 sr.sl.gv_554 
  // [7230]
  0x1b483113, 0x0a043507, 0x353038a9, 0x2f1c210c,   // az.tt.tr_665 tg.ru.mk_432  tk.uz.tg_544 jw.id.su_543 
  0x311b48a7, 0x233c370d, 0x1b003112, 0x100704ee,   // tt.tr.az_532 ba.ug.ky_554  az.tr.un_640 ru.bg.be_422 
  0x17001614, 0x090d5c0b, 0x38442312, 0x21122813,   // hr.sr.un_660 sa.ne.hi_542  ky.kk.tk_654 sd.ur.fa_665 
  0x48373caf, 0x3c371505, 0x31004813, 0x3700381a,   // ug.ba.tt_655 un.ba.ug_333  tt.az.un_650 tk.ba.un_760 
  // [7240]
  0x12213bec, 0x2d120d12, 0x3d003c11, 0x25000712,   // ks.fa.ur_644 cs.hu.sk_654  ug.ku.un_630 bg.mn.un_640 
  0x350415a6, 0x21001805, 0x02000e0c, 0x362d0d05,   // un.ru.tg_521 ar.fa.un_330  is.da.un_530 cs.sk.gn_333 
  0x15043cee, 0x1f634007, 0x173035a0, 0x484423ec,   // ug.ru.un_422 lb.sco.cy_432  tg.uz.sr_322 ky.kk.tt_644 
  0x342818a9, 0x362d0d55, 0x0a2d0d0b, 0x07103504,   // ar.sd.ps_544 cs.sk.gn_442  cs.sk.pt_542 tg.be.bg_332 
  // [7250]
  0x30363504, 0x2100230e, 0x0d001f11, 0x3c384860,   // tg.ab.uz_332 ky.fa.un_550  cy.cs.un_630 tt.tk.ug_664 
  0x122130a9, 0x30152304, 0x02006505, 0x04101704,   // uz.fa.ur_544 ky.uz.un_320  gv.da.un_330 sr.be.ru_332 
  0x43003313, 0x3c3530ad, 0x1c0d5c12, 0x25000a05,   // nn.ie.un_650 uz.tg.ug_643  sa.ne.mr_654 mk.mn.un_330 
  0x0d2f3b0c, 0x31fe3bad, 0x13095c0e, 0x483b4d0b,   // so.su.cs_543 so.tlh.az_643  sa.hi.bh_555 aa.so.tt_542 
  // [7260]
  0x02551b12, 0x791a1b0c, 0x46633b60, 0x37303512,   // tr.rw.da_654 tr.tl.war_543  so.sco.qu_664 tg.uz.ba_654 
  0x25001511, 0x5c001b19, 0x5c007308, 0x697335a4,   // un.mn.un_630 tr.sa.un_750  ny.sa.un_430 zu.ny.mfe_433 
  0xfe003b0e, 0x31003b14, 0x5c090daf, 0x0d005c11,   // so.tlh.un_550 so.az.un_660  ne.hi.sa_655 sa.ne.un_630 
  0x48003b07, 0x216b1aa6, 0x0d005c21, 0x1a7964ee,   // so.tt.un_420 tl.ceb.jw_521  sa.ne.un_860 lg.war.tl_422 
  // [7270]
  0x343021ee, 0x5c130dee, 0x02001b12, 0x154837a0,   // fa.uz.ps_422 ne.bh.sa_422  tr.da.un_640 ba.tt.un_322 
  0x040710ad, 0x3b4d6512, 0x5500350c, 0x551b6bac,   // be.bg.ru_643 gv.aa.so_654  zu.rw.un_530 ceb.tr.rw_632 
  0x0e3b4d11, 0x55021bec, 0x4d00311a, 0x5c1a1b08,   // aa.so.is_653 tr.da.rw_644  az.aa.un_760 tr.tl.sa_443 
  0x1b6b02a0, 0x32161707, 0x15300a04, 0x224223ad,   // da.ceb.tr_322 sr.hr.bs_432  mk.uz.un_332 ca.co.oc_643 
  // [7280]
  0x28342113, 0x353025a9, 0x17301509, 0x4400360b,   // fa.ps.sd_665 mn.uz.tg_544  un.uz.sr_444 ab.kk.un_520 
  0x402c06ee, 0x4c001308, 0x213418a7, 0x5d1d6b02,   // de.fy.lb_422 et.wo.un_430  ar.ps.fa_532 ceb.la.ss_222 
  0x2300371b, 0x1d656a09, 0x06231507, 0x5f033711,   // ba.ky.un_770 haw.gv.la_444  un.ca.de_432 st.nl.tn_653 
  0x44374807, 0x2e2201a0, 0x345f5d0c, 0x5efe4705,   // tt.ba.kk_432 en.oc.fo_322  ss.tn.xh_543 sn.tlh.ts_333 
  // [7290]
  0x3534260c, 0x5300fc04, 0x07110a14, 0x5a00492a,   // ia.xh.zu_543 zzp.ht.un_320  mk.ro.bg_666 to.sm.un_970 
  0x55006407, 0x1d021ba4, 0x1a605504, 0x351d3407,   // lg.rw.un_420 tr.da.la_433  rw.vo.tl_332 xh.la.zu_432 
  0x5dfa340c, 0x213b2809, 0x0a1504a9, 0x303d2107,   // xh.nr.ss_543 sd.ks.fa_444  ru.mk.un_540 fa.ku.uz_432 
  0x0a0425a0, 0xfe375f08, 0x347537a9, 0x36001c13,   // mn.ru.mk_322 tn.st.tlh_443  st.nso.xh_544 id.gn.un_650 
  // [72a0]
  0x30002513, 0x5f000104, 0x5c131c08, 0x3700fe0c,   // mn.uz.un_650 en.tn.un_320  mr.bh.sa_443 tlh.st.un_530 
  0x0f1d01a0, 0x2c330805, 0x48005104, 0x232511ee,   // en.la.lv_322 no.nn.fy_333  kl.tt.un_320 ro.mn.ky_422 
  0x5a465107, 0x391e6204, 0x07002104, 0x5c000208,   // kl.qu.sm_432 kha.ms.br_332  jw.it.un_320 da.sa.un_430 
  0x1c006402, 0x1a2a1e0c, 0x1c5c0d0e, 0x021e0107,   // lg.id.un_220 ms.mt.tl_543  ne.sa.mr_555 en.ms.da_432 
  // [72b0]
  0x1c2f1e0b, 0x1c2f2108, 0x35171504, 0x050126ad,   // ms.su.id_542 jw.su.id_443  un.sr.tg_332 ia.en.fr_643 
  0x11423e0e, 0x301b0fa6, 0x330e08a0, 0x0f3020a6,   // rm.co.ro_555 lv.tr.uz_521  no.is.nn_322 sq.uz.lv_521 
  0x1d53690c, 0x3e5701a0, 0x1f30580d, 0x13074214,   // mfe.ht.la_543 en.na.rm_322  om.uz.cy_554 co.it.et_666 
  0x356b1dad, 0x2d0dfea9, 0x214e1e0b, 0x02000818,   // la.ceb.zu_643 tlh.cs.sk_544  ms.ay.jw_542 no.da.un_740 
  // [72c0]
  0x1c5c09a4, 0x204d30a4, 0x011202a0, 0x2e301ca4,   // hi.sa.mr_433 uz.aa.sq_433  da.hu.en_322 id.uz.fo_433 
  0x0900fc04, 0x08171504, 0xfc000105, 0x1f580e11,   // zzp.pl.un_320 un.sr.uk_332  en.zzp.un_330 is.om.cy_653 
  0x021f3908, 0x1f222304, 0x18004412, 0x081525ee,   // br.cy.da_443 ca.oc.cy_332  kk.ar.un_640 mn.uk.un_420 
  0xfc00fe07, 0x2912300d, 0x4e4d6911, 0x30004c0d,   // tlh.zzp.un_420 uz.hu.sl_554  mfe.aa.ay_653 wo.uz.un_540 
  // [72d0]
  0x090d1c11, 0x38091f0c, 0x0b694da4, 0x4911510c,   // mr.ne.hi_653 cy.pl.tk_543  aa.mfe.es_433 kl.ro.to_543 
  0x162d6bee, 0x420730ec, 0x39230da0, 0x112d10a0,   // ceb.sk.hr_422 uz.it.co_644  cs.ca.br_322 lt.sk.ro_322 
  0x58543008, 0x353c30af, 0x2130fead, 0x37481504,   // uz.ik.om_443 uz.ug.tg_655  tlh.uz.jw_643 un.tt.ba_332 
  0x5a004907, 0x2d0d1ea0, 0x47001f02, 0x4a3250a0,   // to.sm.un_420 ms.cs.sk_322  cy.sn.un_220 fj.bs.yo_322 
  // [72e0]
  0x5e73130c, 0x1a1f35a0, 0x1e001c08, 0x733b1f12,   // et.ny.ts_543 zu.cy.tl_322  id.ms.un_430 cy.so.ny_654 
  0x1c212d07, 0x040a1508, 0x1e1c2002, 0x35135507,   // sk.jw.id_432 un.mk.ru_443  sq.id.ms_222 rw.et.zu_432 
  0x5500041b, 0x5d003504, 0x62471d08, 0x4c284255,   // fi.rw.un_770 zu.ss.un_320  la.sn.kha_443 co.sw.wo_442 
  0x2f211ca0, 0x47005e0c, 0x1d00130b, 0x52281705,   // id.jw.su_322 ts.sn.un_530  et.la.un_520 sr.sw.ha_333 
  // [72f0]
  0x22002b05, 0x1f353408, 0x10000f0b, 0x125d1d12,   // vi.oc.un_330 xh.zu.cy_443  lv.lt.un_520 la.ss.hu_654 
  0x135c1c05, 0x47006408, 0x026a0812, 0x3d003b22,   // mr.sa.bh_333 lg.sn.un_430  no.haw.da_654 ks.ku.un_870 
  0x50001d07, 0x504d490c, 0x303625a9, 0x0a0804a4,   // la.fj.un_420 to.aa.fj_543  mn.ab.uz_544 ru.uk.mk_433 
  0x11496a0c, 0x5a6a4912, 0x04424b07, 0x340a6a12,   // haw.to.ro_543 to.haw.sm_654  mi.co.fi_432 haw.pt.xh_654 
  // [7300]
  0x212f4213, 0x28475d55, 0x25005f05, 0x5a00450d,   // co.su.jw_665 ss.sn.sw_442  tn.eu.un_330 ln.sm.un_540 
  0x1d475007, 0x1b381208, 0x55645d07, 0x292833a9,   // fj.sn.la_432 hu.tk.tr_443  ss.lg.rw_432 nn.sw.sl_544 
  0x1700090c, 0x3f003704, 0x2f003502, 0x4912750c,   // pl.sr.un_530 st.af.un_320  zu.su.un_220 nso.hu.to_543 
  0x371249a4, 0x130e1dee, 0x0a1711a6, 0x5d001e08,   // to.hu.st_433 la.is.et_422  ro.sr.mk_521 ms.ss.un_430 
  // [7310]
  0x4a3f03a0, 0x2a791fad, 0x1f002104, 0x32171655,   // nl.af.yo_322 cy.war.mt_643  jw.cy.un_320 hr.sr.bs_442 
  0x25003813, 0x480737ee, 0x3d342109, 0x4a5f3409,   // tk.mn.un_650 ba.bg.tt_422  fa.ps.ku_444 xh.tn.yo_444 
  0x755f3713, 0x0b19345a, 0x4d005019, 0x39005f04,   // st.tn.nso_665 xh.gl.es_553  fj.aa.un_750 tn.br.un_320 
  0x3f031208, 0x361715a0, 0x4a485aad, 0x5a004508,   // hu.nl.af_443 un.sr.ab_322  sm.tt.yo_643 ln.sm.un_430 
  // [7320]
  0x49002802, 0x5f750107, 0x50343507, 0x3530360c,   // sw.to.un_220 en.nso.tn_432  zu.xh.fj_432 ab.uz.tg_543 
  0x3f060305, 0x233748ad, 0x1500232a, 0x0a1711ad,   // nl.de.af_333 tt.ba.ky_643  ky.un.un_970 ro.sr.mk_643 
  0x0c002c04, 0x02001f05, 0x44103707, 0x343d2104,   // fy.sv.un_320 cy.da.un_330  ba.be.kk_432 fa.ku.ps_332 
  0x030553a0, 0x30341812, 0x30003605, 0x38100c04,   // ht.fr.nl_322 ar.ps.uz_654  gn.uz.un_330 sv.lt.tk_332 
  // [7330]
  0x3800620d, 0x21003d2c, 0x38301b13, 0x0c002104,   // kha.tk.un_540 ku.fa.un_990  tr.uz.tk_665 jw.sv.un_320 
  0x3b283408, 0x484d300c, 0x070a1505, 0x2d532907,   // ps.sd.ks_443 uz.aa.tt_543  un.mk.bg_333 sl.ht.sk_432 
  0x33003802, 0x01002b02, 0x33003f02, 0x0d005307,   // tk.nn.un_220 vi.en.un_220  af.nn.un_220 ht.cs.un_420 
  0x1d00380c, 0x1f00090d, 0x3000481b, 0x0f00530d,   // tk.la.un_530 pl.cy.un_540  tt.uz.un_770 ht.lv.un_540 
  // [7340]
  0x2900530d, 0x1128580d, 0x11586a0d, 0x49006a07,   // ht.sl.un_540 om.sw.ro_554  haw.om.ro_554 haw.to.un_420 
  0x09115812, 0x35153014, 0x49583b0c, 0x13091cee,   // om.ro.pl_654 uz.tg.un_660  so.om.to_543 mr.hi.bh_422 
  0x67583b12, 0x116758a9, 0x09113ba9, 0x32503502,   // so.om.ak_654 om.ak.ro_544  so.ro.pl_544 zu.fj.bs_222 
  0x02005d0d, 0x27004908, 0x316b58a9, 0x1d2d110d,   // ss.da.un_540 to.gd.un_430  om.ceb.az_544 ro.sk.la_554 
  // [7350]
  0xfc002002, 0x113c305a, 0x584211ec, 0x2128340d,   // sq.zzp.un_220 uz.ug.ro_553  ro.co.om_644 ps.sd.fa_554 
  0x02005d05, 0x58674a13, 0x491d11a4, 0x583b6712,   // ss.da.un_330 yo.ak.om_665  ro.la.to_433 ak.so.om_654 
  0x5c00020b, 0x3b115813, 0x173035ee, 0x40000e02,   // da.sa.un_520 om.ro.so_665  tg.uz.sr_422 is.lb.un_220 
  0x51001d04, 0x58110d0c, 0x4448380b, 0x674958a9,   // la.kl.un_320 cs.ro.om_543  tk.tt.kk_542 om.to.ak_544 
  // [7360]
  0x04116a12, 0x3b00581a, 0x0e472e04, 0x1a005307,   // haw.ro.fi_654 om.so.un_760  fo.sn.is_332 ht.tl.un_420 
  0x5d0c3355, 0x6953760e, 0x51025ca0, 0x51000212,   // nn.sv.ss_442 crs.ht.mfe_555  sa.da.kl_322 da.kl.un_640 
  0x2f004607, 0x35004409, 0x150411a4, 0x07001d07,   // qu.su.un_420 kk.tg.un_440  ro.ru.un_433 la.it.un_420 
  0x1510170d, 0x691a6b09, 0x2500fc02, 0x53300211,   // sr.be.un_554 ceb.tl.mfe_444  zzp.eu.un_220 da.uz.ht_653 
  // [7370]
  0x45002013, 0x124c2fee, 0x073617a4, 0x6500621b,   // sq.ln.un_650 su.wo.hu_422  sr.ab.bg_433 kha.gv.un_770 
  0x1100620b, 0x3e0922a7, 0x2f000102, 0x351504af,   // kha.ro.un_520 oc.pl.rm_532  en.su.un_220 ru.tg.un_650 
  0x274c65ee, 0x0d2d120c, 0x2f1202ec, 0x5c003b08,   // gv.wo.gd_422 hu.sk.cs_543  da.hu.su_644 so.sa.un_430 
  0x27004c05, 0x12002f09, 0x02122fa4, 0x38000a04,   // wo.gd.un_330 su.hu.un_440  su.hu.da_433 pt.tk.un_320 
  // [7380]
  0x3d21340c, 0x2d3911a7, 0x1c0d09ec, 0x383310ee,   // ps.fa.ku_543 ro.br.sk_532  hi.ne.mr_644 lt.nn.tk_422 
  0x43002413, 0x2d00120e, 0x080212a4, 0x48193102,   // eo.ie.un_650 hu.sk.un_550  hu.da.no_433 az.gl.tt_222 
  0x022f08a0, 0x2d0d2fa4, 0x64024daf, 0x090d13a6,   // no.su.da_322 su.cs.sk_433  aa.da.lg_655 bh.ne.hi_521 
  0x3b003504, 0x38000905, 0x06002402, 0x090d5ca0,   // zu.so.un_320 pl.tk.un_330  eo.de.un_220 sa.ne.hi_322 
  // [7390]
  0x23003013, 0x0a0735ee, 0x2d000902, 0x3e3664a0,   // uz.ky.un_650 tg.bg.mk_422  pl.sk.un_220 lg.gn.rm_322 
  0x061540a0, 0x40020e07, 0x063225a0, 0x063440ee,   // lb.de.un_320 is.da.lb_432  eu.bs.de_322 lb.xh.de_422 
  0x60561f14, 0x405806a0, 0x035b4a07, 0x1c135cec,   // cy.mg.vo_666 de.om.lb_322  yo.sg.nl_432 sa.bh.mr_644 
  0x33084002, 0x1d00600c, 0x3f00150c, 0x0408150b,   // lb.no.nn_222 vo.la.un_530  un.af.un_530 un.uk.ru_542 
  // [73a0]
  0x2f000504, 0x0c5306a4, 0x39003204, 0x2500301b,   // fr.su.un_320 de.ht.sv_433  bs.br.un_320 uz.mn.un_770 
  0x4838155a, 0x03001502, 0x4006030c, 0x2c0602ee,   // un.tk.tt_553 un.nl.un_220  nl.de.lb_543 da.de.fy_422 
  0x58002a05, 0x17081508, 0x631b1f0c, 0x12001814,   // mt.om.un_330 un.uk.sr_443  cy.tr.sco_543 ar.ur.un_660 
  0x30232512, 0x44000a09, 0x0a0711ad, 0x15003819,   // mn.ky.uz_654 mk.kk.un_440  ro.bg.mk_643 tk.un.un_750 
  // [73b0]
  0x38001f08, 0x15040a07, 0x214601a0, 0x2500150d,   // cy.tk.un_430 mk.ru.un_432  en.qu.jw_322 un.mn.un_540 
  0x04381f0c, 0x2300480c, 0x44372307, 0x08043604,   // cy.tk.fi_543 tt.ky.un_530  ky.ba.kk_432 ab.ru.uk_332 
  0x07000a19, 0x36151512, 0x0f102d09, 0x11070a0d,   // mk.bg.un_750 un.ab.un_640  sk.lt.lv_444 mk.bg.ro_554 
  0x10003807, 0x183d2160, 0x4b006a14, 0x442337ad,   // tk.lt.un_420 fa.ku.ar_664  haw.mi.un_660 ba.ky.kk_643 
  // [73c0]
  0x30081708, 0x102e30ee, 0x2d000408, 0x35003812,   // sr.uk.uz_443 uz.fo.lt_422  fi.sk.un_430 tk.tg.un_640 
  0x3c44185a, 0x2300442b, 0x0d00091a, 0x10041555,   // ar.kk.ug_553 kk.ky.un_980  hi.ne.un_760 un.ru.be_442 
  0x5a005308, 0x21183d02, 0x13000d1a, 0x09002d09,   // ht.sm.un_430 ku.ar.fa_222  ne.bh.un_760 sk.pl.un_440 
  0x7669fe0c, 0x24000107, 0x151538a4, 0x6a004b21,   // tlh.mfe.crs_543 iw.yi.un_420  tk.un.un_430 mi.haw.un_860 
  // [73d0]
  0x2d003204, 0x10360807, 0x171038a0, 0x3700360c,   // bs.sk.un_320 uk.ab.be_432  tk.be.sr_322 ab.ba.un_530 
  0x5c0d1307, 0x16001005, 0x08040a07, 0x34213b07,   // bh.ne.sa_432 lt.hr.un_330  mk.ru.uk_432 ks.fa.ps_432 
  0x3100480d, 0x070a3009, 0x04170807, 0x3100fc0c,   // tt.az.un_540 uz.mk.bg_444  uk.sr.ru_432 zzp.az.un_530 
  0x3c0810af, 0x041017ee, 0x697605a4, 0x30000c0d,   // be.uk.ug_655 sr.be.ru_422  fr.crs.mfe_433 sv.uz.un_540 
  // [73e0]
  0x25010407, 0x48001f0d, 0x483515ee, 0x3c303560,   // fi.en.eu_432 cy.tt.un_540  un.tg.tt_422 tg.uz.ug_664 
  0x3f001f14, 0x234448a4, 0x04000a08, 0x0100fc0e,   // cy.af.un_660 tt.kk.ky_433  mk.ru.un_430 zzp.en.un_550 
  0x3815110c, 0x343d3008, 0x170a07ee, 0x28341808,   // ro.tk.un_530 uz.ku.ps_443  bg.mk.sr_422 ar.ps.sd_443 
  0xfe004707, 0x014d62ad, 0x624b49af, 0x070a1755,   // sn.tlh.un_420 kha.aa.en_643  to.mi.kha_655 sr.mk.bg_442 
  // [73f0]
  0x61203213, 0x1d3b2aa0, 0x420768ec, 0x08304804,   // bs.sq.za_665 mt.so.la_322  ig.it.co_644 tt.uz.uk_332 
  0x0000492d, 0x3744360b, 0x04002507, 0x300a07a0,   // to.un.un_A00 ab.kk.ba_542  mn.ru.un_420 bg.mk.uz_322 
  0x20783913, 0x04170a02, 0x20006e19, 0x5d343512,   // br.ve.sq_665 mk.sr.ru_222  hmn.sq.un_750 zu.xh.ss_654 
  0x1e1c490e, 0x25000a14, 0x58025404, 0x4810380b,   // to.id.ms_555 mk.mn.un_660  ik.da.om_332 tk.be.tt_542 
  
  // [7400]
  0x3c00371a, 0x08040a02, 0x1023150b, 0x3015360c,   // ba.ug.un_760 mk.ru.uk_222  un.ky.be_542 ab.uz.un_530 
  0x28212304, 0x212812a4, 0x48443812, 0x33081b05,   // ky.fa.sd_332 ur.sd.fa_433  tk.kk.tt_654 tr.no.nn_333 
  0xfc1e1c08, 0x480e0804, 0x32001504, 0x40001207,   // id.ms.zzp_443 no.is.tt_332  un.bs.un_320 hu.lb.un_420 
  0x63650ea4, 0xfc005002, 0x3b005e04, 0x072535ec,   // is.gv.sco_433 fj.zzp.un_220  ts.so.un_320 tg.mn.bg_644 
  // [7410]
  0x4c006212, 0x070a0408, 0x25353014, 0x04070a13,   // kha.wo.un_640 ru.mk.bg_443  uz.tg.mn_666 mk.bg.ru_665 
  0x567567ad, 0x10051f0c, 0x31005c0c, 0x0e1506ec,   // ak.nso.mg_643 cy.fr.lt_543  sa.az.un_530 de.is.un_640 
  0x1f000608, 0x2f273b0b, 0x18fe2a08, 0x35001707,   // de.cy.un_430 so.gd.su_542  mt.tlh.ga_443 sr.tg.un_420 
  0x2018fca0, 0x1000110e, 0x011ffc07, 0x53006b11,   // zzp.ga.sq_322 ro.be.un_550  zzp.cy.en_432 ceb.ht.un_630 
  // [7420]
  0x15000814, 0x0600fc04, 0x697653a4, 0x63271812,   // uk.un.un_660 zzp.de.un_320  ht.crs.mfe_433 ga.gd.sco_654 
  0x01000208, 0x303c4409, 0x0900530d, 0x1834280c,   // da.en.un_430 kk.ug.uz_444  ht.pl.un_540 sd.ps.ar_543 
  0x440a17a4, 0x2d0d5605, 0x190b0e0c, 0x211834a0,   // sr.mk.kk_433 mg.cs.sk_333  is.es.gl_543 ps.ar.fa_322 
  0x2348300d, 0xfe2f01a0, 0x355efa0c, 0x56006502,   // uz.tt.ky_554 en.su.tlh_322  nr.ts.zu_543 gv.mg.un_220 
  // [7430]
  0x3b534309, 0x12283ba4, 0x5d303404, 0x1a004902,   // ie.ht.so_444 ks.sd.ur_433  xh.uz.ss_332 to.tl.un_220 
  0x122128a7, 0x34285555, 0xfe610b0c, 0x0225730c,   // sd.fa.ur_532 rw.sw.xh_442  es.za.tlh_543 ny.eu.da_543 
  0x291b280c, 0x2c000502, 0x55242508, 0x553435ee,   // sw.tr.sl_543 fr.fy.un_220  eu.eo.rw_443 zu.xh.rw_422 
  0x37330802, 0x30004d1b, 0x34005e0e, 0x30732807,   // no.nn.st_222 aa.uz.un_770  ts.xh.un_550 sw.ny.uz_432 
  // [7440]
  0x1afe3004, 0x2800250c, 0x595510a0, 0x4d00fe14,   // uz.tlh.tl_332 eu.sw.un_530  lt.rw.rn_322 tlh.aa.un_660 
  0x3f300304, 0x130410a9, 0x01091b02, 0x64355da4,   // nl.uz.af_332 lt.fi.et_544  tr.pl.en_222 ss.zu.lg_433 
  0x2d001213, 0x59005d0c, 0x1ffe3b04, 0x0400fc07,   // hu.sk.un_650 ss.rn.un_530  so.tlh.cy_332 zzp.fi.un_420 
  0x033f40a4, 0x080a3704, 0x57004d19, 0x253402ee,   // lb.af.nl_433 ba.mk.uk_332  aa.na.un_750 da.xh.eu_422 
  // [7450]
  0x487902af, 0x55355eec, 0x0a3c0807, 0x35554c07,   // da.war.tt_655 ts.zu.rw_644  uk.ug.mk_432 wo.rw.zu_432 
  0x305d3407, 0x1700620c, 0x353452a4, 0x256b0208,   // xh.ss.uz_432 kha.sr.un_530  ha.xh.zu_433 da.ceb.eu_443 
  0x16572905, 0x24602811, 0x304a2eec, 0x443038ad,   // sl.na.hr_333 sw.vo.eo_653  fo.yo.uz_644 tk.uz.kk_643 
  0x4dfe54a4, 0x5200340d, 0x4415300c, 0x47002912,   // ik.tlh.aa_433 xh.ha.un_540  uz.kk.un_530 sl.sn.un_640 
  // [7460]
  0x21005202, 0x6b0264a4, 0x1b093008, 0x134e300c,   // ha.jw.un_220 lg.da.ceb_433  uz.pl.tr_443 uz.ay.et_543 
  0x4d044c0e, 0x22002705, 0x16094e0b, 0x18000111,   // wo.fi.aa_555 gd.oc.un_330  ay.pl.hr_542 iw.ar.un_630 
  0x13290913, 0x09020f0c, 0x52091804, 0x382f6b08,   // pl.sl.et_665 lv.da.pl_543  ga.pl.ha_332 ceb.su.tk_443 
  0x0245490c, 0x13093013, 0x212834ec, 0x3009250c,   // to.ln.da_543 uz.pl.et_665  ps.sd.fa_644 eu.pl.uz_543 
  // [7470]
  0x4e09460c, 0x19001808, 0x3000280e, 0x0409290d,   // qu.pl.ay_543 ga.gl.un_430  sd.uz.un_550 sl.pl.fi_554 
  0x0f6a02a4, 0x0f006502, 0x306569a7, 0x48303ba4,   // da.haw.lv_433 gv.lv.un_220  mfe.gv.uz_532 so.uz.tt_433 
  0x130f1008, 0x19001807, 0x52000404, 0x122830ac,   // lt.lv.et_443 ga.gl.un_420  fi.ha.un_320 uz.sd.ur_632 
  0x25001009, 0x04080aa4, 0x533b4c04, 0x44000a0d,   // be.mn.un_440 mk.uk.ru_433  wo.so.ht_332 mk.kk.un_540 
  // [7480]
  0x21001c05, 0x44362309, 0x09002408, 0x00007524,   // id.jw.un_330 ky.ab.kk_444  eo.pl.un_430 nso.un.un_900 
  0x3d44230c, 0x04003018, 0x18233d04, 0x23002113,   // ky.kk.ku_543 uz.ru.un_740  ku.ky.ar_332 fa.ky.un_650 
  0x23003807, 0x07152507, 0x0e002c08, 0x353038a7,   // tk.ky.un_420 mn.bg.un_420  fy.is.un_430 tk.uz.tg_532 
  0x2300481a, 0x190b0a09, 0x3b00461b, 0x0f3f2ca0,   // tt.ky.un_760 pt.es.gl_444  qu.so.un_770 fy.af.lv_322 
  // [7490]
  0x58653ba7, 0x23005302, 0x46003b1b, 0x13003f07,   // so.gv.om_532 ht.ca.un_220  so.qu.un_770 af.et.un_420 
  0x46003b14, 0x3b4846ec, 0x44370404, 0x1a4d3b55,   // so.qu.un_660 qu.tt.so_644  ru.ba.kk_332 so.aa.tl_442 
  0x483b3060, 0x190b0aee, 0x0a2d0d04, 0x1b313007,   // uz.so.tt_664 pt.es.gl_422  cs.sk.pt_332 uz.az.tr_432 
  0x3b004619, 0x3f2d0d04, 0x4d463b08, 0x53004205,   // qu.so.un_750 cs.sk.af_332  so.qu.aa_443 co.ht.un_330 
  // [74a0]
  0x15070a0d, 0x482330af, 0x463b3114, 0x3b004613,   // mk.bg.un_554 uz.ky.tt_655  az.so.qu_666 qu.so.un_650 
  0x2ffe4607, 0x15102507, 0x48463b12, 0x17043608,   // qu.tlh.su_432 mn.be.un_432  so.qu.tt_654 ab.ru.sr_443 
  0x01281808, 0x01003402, 0x09131c10, 0x25170aa4,   // ar.sd.iw_443 xh.en.un_220  mr.bh.hi_642 mk.sr.mn_433 
  0x44371508, 0x095c13a7, 0x3b000209, 0x30000208,   // un.ba.kk_443 bh.sa.hi_532  da.so.un_440 da.uz.un_430 
  // [74b0]
  0x0710040d, 0x3b000e08, 0x1e2557a4, 0x65004f04,   // ru.be.bg_554 is.so.un_430  na.eu.ms_433 bi.gv.un_320 
  0x65004702, 0x0c002e02, 0x10002a0c, 0x6527fe07,   // sn.gv.un_220 fo.sv.un_220  mt.lt.un_530 tlh.gd.gv_432 
  0x5659fe55, 0x2c003008, 0x223bfead, 0x0000182d,   // tlh.rn.mg_442 uz.fy.un_430  tlh.so.oc_643 ar.un.un_A00 
  0x56002f08, 0x03001c05, 0x07003c07, 0x2f004e12,   // su.mg.un_430 id.nl.un_330  ug.bg.un_420 ay.su.un_640 
  // [74c0]
  0x524a020c, 0x0c33fc55, 0x32003402, 0x0b0a1914,   // da.yo.ha_543 zzp.nn.sv_442  xh.bs.un_220 gl.pt.es_666 
  0x07080413, 0x28181da4, 0x09fe1904, 0x1865fc07,   // ru.uk.bg_665 la.ga.sw_433  gl.tlh.pl_332 zzp.gv.ga_432 
  0x0d095c05, 0x166b1804, 0x170a350d, 0x3500fe08,   // sa.hi.ne_333 ga.ceb.hr_332  tg.mk.sr_554 tlh.zu.un_430 
  0x21001f02, 0x02103208, 0x2d07fca4, 0xfe2f53a0,   // cy.jw.un_220 bs.lt.da_443  zzp.it.sk_433 ht.su.tlh_322 
  // [74d0]
  0x2802fe55, 0x3642fc0c, 0x401f6508, 0x1c21fe07,   // tlh.da.sw_442 zzp.co.gn_543  gv.cy.lb_443 tlh.jw.id_432 
  0x350634ee, 0x5e5d300c, 0x65190b14, 0x28123409,   // xh.de.zu_422 uz.ss.ts_543  es.gl.gv_666 xh.hu.sw_444 
  0x343d3ba7, 0x406022ad, 0x1d630107, 0x76126412,   // ks.ku.ps_532 oc.vo.lb_643  en.sco.la_432 lg.hu.crs_654 
  0x3b646307, 0x3c003d07, 0x01003307, 0x30001708,   // sco.lg.so_432 ku.ug.un_420  nn.en.un_420 sr.uz.un_430 
  // [74e0]
  0x6400580d, 0x61001213, 0x5f006413, 0x34183d0c,   // om.lg.un_540 hu.za.un_650  lg.tn.un_650 ku.ar.ps_543 
  0x043515a7, 0x35253013, 0x16652d0b, 0x10001119,   // un.tg.ru_532 uz.mn.tg_665  sk.gv.hr_542 ro.be.un_750 
  0x3efc11ad, 0x04170708, 0x12006e11, 0x3536300c,   // ro.zzp.rm_643 bg.sr.ru_443  hmn.hu.un_630 uz.ab.tg_543 
  0x30443c13, 0x64007309, 0x0b191210, 0x12083307,   // ug.kk.uz_665 ny.lg.un_440  hu.gl.es_642 nn.no.hu_432 
  // [74f0]
  0x4400300c, 0x38003c22, 0x05001207, 0x21003b14,   // uz.kk.un_530 ug.tk.un_870  hu.fr.un_420 ks.fa.un_660 
  0x16292d0c, 0x522a0fa0, 0x0d001c12, 0x09000405,   // sk.sl.hr_543 lv.mt.ha_322  mr.ne.un_640 fi.pl.un_330 
  0x02001013, 0x04234812, 0x4c584d0c, 0x32172a08,   // lt.da.un_650 tt.ky.ru_654  aa.om.wo_543 mt.sr.bs_443 
  0x6800101a, 0x4c000505, 0x0e002905, 0x32002a04,   // lt.ig.un_760 fr.wo.un_330  sl.is.un_330 mt.bs.un_320 
  // [7500]
  0x21342804, 0x0f292aa0, 0x09001009, 0x35001519,   // sd.ps.fa_332 mt.sl.lv_322  lt.pl.un_440 un.tg.un_750 
  0x2a00091b, 0x0d322904, 0x4c003807, 0x292a0f55,   // pl.mt.un_770 sl.bs.cs_332  tk.wo.un_420 lv.mt.sl_442 
  0x232538ac, 0x5c000d22, 0x5d0e2907, 0x31292a5a,   // tk.mn.ky_632 ne.sa.un_870  sl.is.ss_432 mt.sl.az_553 
  0x0f002a19, 0x05000d07, 0x34183cad, 0x482337ad,   // mt.lv.un_750 cs.fr.un_420  ug.ar.ps_643 ba.ky.tt_643 
  // [7510]
  0x15003021, 0xfc002a05, 0x5c091ca6, 0x40003002,   // uz.un.un_860 mt.zzp.un_330  mr.hi.sa_521 uz.lb.un_220 
  0x11002013, 0x2a00071b, 0x50587308, 0x645e730d,   // sq.ro.un_650 it.mt.un_770  ny.om.fj_443 ny.ts.lg_554 
  0x2afc06a0, 0x5c6b790c, 0x04073055, 0x5c105807,   // de.zzp.mt_322 war.ceb.sa_543  uz.bg.ru_442 om.lt.sa_432 
  0x5c73580c, 0x37001002, 0x7358470d, 0x3c002320,   // om.ny.sa_543 be.ba.un_220  sn.om.ny_554 ky.ug.un_850 
  // [7520]
  0x1d6458a4, 0x170a15ec, 0x37003509, 0x12003607,   // om.lg.la_433 un.mk.sr_644  zu.st.un_440 gn.hu.un_420 
  0x250b08a4, 0x0273550b, 0x64465908, 0x49500807,   // no.es.eu_433 rw.ny.da_542  rn.qu.lg_443 no.fj.to_432 
  0x471d130c, 0x2e5129a4, 0x3502500c, 0x5c02580c,   // et.la.sn_543 sl.kl.fo_433  fj.da.zu_543 om.da.sa_543 
  0x331f0d0c, 0x13095cec, 0x0802600c, 0x735c51a9,   // cs.cy.nn_543 sa.hi.bh_644  vo.da.no_543 kl.sa.ny_544 
  // [7530]
  0x796b470c, 0x3430210b, 0x354d46a4, 0x51130404,   // sn.ceb.war_543 fa.uz.ps_542  qu.aa.zu_433 fi.et.kl_332 
  0x0925455a, 0x34004c13, 0x12003808, 0x4300120e,   // ln.eu.pl_553 wo.xh.un_650  tk.hu.un_430 hu.ie.un_550 
  0x40001802, 0x0903490c, 0x353451ec, 0x212f1fad,   // ga.lb.un_220 to.nl.pl_543  kl.xh.zu_644 cy.su.jw_643 
  0x3d1821a7, 0x08004408, 0x05003604, 0x53766908,   // fa.ar.ku_532 kk.uk.un_430  gn.fr.un_320 mfe.crs.ht_443 
  // [7540]
  0x2a000905, 0x0b002f04, 0x0d192d0b, 0x5c531ba0,   // pl.mt.un_330 su.es.un_320  sk.gl.cs_542 tr.ht.sa_322 
  0x09005309, 0x6500620d, 0x070a0402, 0x1c2f1ea0,   // ht.pl.un_440 kha.gv.un_540  ru.mk.bg_222 ms.su.id_322 
  0x553b21a4, 0x250a1708, 0x643b310c, 0x1821285a,   // jw.so.rw_433 sr.mk.mn_443  az.so.lg_543 sd.fa.ar_553 
  0x311b3b04, 0x3800fe04, 0x12003308, 0x473b35a0,   // so.tr.az_332 tlh.tk.un_320  nn.hu.un_430 zu.so.sn_322 
  // [7550]
  0x6953760c, 0x55456407, 0x34003120, 0x33321604,   // crs.ht.mfe_543 lg.ln.rw_432  az.xh.un_850 hr.bs.nn_332 
  0x3500640e, 0x483715a0, 0x1b644d07, 0x313b1b05,   // lg.zu.un_550 un.ba.tt_322  aa.lg.tr_432 tr.so.az_333 
  0x3f001b12, 0x113c3009, 0x64005e0d, 0x47001b02,   // tr.af.un_640 uz.ug.ro_444  ts.lg.un_540 tr.sn.un_220 
  0x553b5e07, 0x152337ac, 0x5d4e5e0c, 0x02000204,   // ts.so.rw_432 ba.ky.un_632  ts.ay.ss_543 da.da.un_320 
  // [7560]
  0x44373560, 0x1b64540c, 0x2d00fc07, 0x331201a4,   // tg.ba.kk_664 ik.lg.tr_543  zzp.sk.un_420 en.hu.nn_433 
  0x384823ad, 0x3302fca6, 0x0300fe04, 0x0c15fea7,   // ky.tt.tk_643 zzp.da.nn_521  tlh.nl.un_320 tlh.sv.un_520 
  0x35153cad, 0x483c3760, 0x21400507, 0x441525ad,   // ug.tg.un_630 ba.ug.tt_664  fr.lb.jw_432 mn.kk.un_630 
  0x202847ee, 0x05004005, 0x134873a0, 0x303b3d07,   // sn.sw.sq_422 lb.fr.un_330  ny.tt.et_322 ku.ks.uz_432 
  // [7570]
  0x2e002013, 0x58002e0d, 0x442330a9, 0x135c1c55,   // sq.fo.un_650 fo.om.un_540  uz.ky.kk_544 mr.sa.bh_442 
  0x2100fc02, 0x40000512, 0x35003907, 0x3c003009,   // zzp.jw.un_220 fr.lb.un_640  br.zu.un_420 uz.ug.un_440 
  0x0200130d, 0x0a0704a0, 0x17384404, 0x020f7905,   // et.da.un_540 ru.bg.mk_322  kk.tk.sr_332 war.lv.da_333 
  0x0217fcaf, 0x48113804, 0x52003b04, 0x2e0e4e5a,   // zzp.sr.da_655 tk.ro.tt_332  so.ha.un_320 ay.is.fo_553 
  // [7580]
  0x422f050c, 0x06130305, 0x210102a0, 0x11420707,   // fr.su.co_543 nl.et.de_333  da.en.jw_322 it.co.ro_432 
  0x04300805, 0x03063f07, 0x24005202, 0x421505ad,   // uk.uz.ru_333 af.de.nl_432  ha.eo.un_220 fr.co.un_630 
  0xfc000212, 0x0c000214, 0x38100fad, 0x1dfe4d11,   // da.zzp.un_640 da.sv.un_660  lv.lt.tk_643 aa.tlh.la_653 
  0x3b3d21ec, 0xfe004d0e, 0x2d005612, 0x343c3dad,   // fa.ku.ks_644 aa.tlh.un_550  mg.sk.un_640 ku.ug.ps_643 
  // [7590]
  0x2336110c, 0x301b31a9, 0x313f0307, 0x15004007,   // ro.ab.ky_543 az.tr.uz_544  nl.af.az_432 lb.un.un_420 
  0x5e003414, 0x441023ee, 0x212f1e05, 0x1b38310e,   // xh.ts.un_660 ky.be.kk_422  ms.su.jw_333 az.tk.tr_555 
  0x170715a9, 0x2b003102, 0x153835a4, 0x31131b07,   // un.bg.sr_544 az.vi.un_220  tg.tk.un_433 tr.et.az_432 
  0x0f1379a0, 0x080430a0, 0x5a577904, 0x08001113,   // war.et.lv_322 uz.ru.uk_322  war.na.sm_332 ro.uk.un_650 
  // [75a0]
  0x30000705, 0x65000408, 0x0a070405, 0x211e1cec,   // bg.uz.un_330 fi.gv.un_430  ru.bg.mk_333 id.ms.jw_644 
  0x79002d0d, 0x082504a0, 0x183428ec, 0x34302111,   // sk.war.un_540 ru.mn.uk_322  sd.ps.ar_644 fa.uz.ps_653 
  0x2c003802, 0x2330250d, 0x5600090c, 0x301221ad,   // tk.fy.un_220 mn.uz.ky_554  pl.mg.un_530 fa.ur.uz_643 
  0x25005a05, 0x23001821, 0x3800091a, 0x3800560e,   // sm.eu.un_330 ar.ky.un_860  pl.tk.un_760 mg.tk.un_550 
  // [75b0]
  0x18122104, 0x18284402, 0x0d005602, 0x17084404,   // fa.ur.ar_332 kk.sd.ar_222  mg.cs.un_220 kk.uk.sr_332 
  0x283b3daf, 0x29003b09, 0x766953a4, 0x06000b04,   // ku.ks.sd_655 so.sl.un_440  ht.mfe.crs_433 es.de.un_320 
  0x15101707, 0x3c233ba7, 0x1a500207, 0x443748ad,   // sr.be.un_432 ks.ky.ug_532  da.fj.tl_432 tt.ba.kk_643 
  0x0b006502, 0x2305fca7, 0x090d130c, 0x171548a4,   // gv.es.un_220 zzp.fr.ca_532  bh.ne.hi_543 tt.sr.un_430 
  // [75c0]
  0x1b001107, 0x06003902, 0x25153004, 0x2c002004,   // ro.tr.un_420 br.de.un_220  uz.mn.un_320 sq.fy.un_320 
  0x03002204, 0x033b2c02, 0x056301a0, 0x40062007,   // oc.nl.un_320 fy.so.nl_222  en.sco.fr_322 sq.de.lb_432 
  0x4065060c, 0x4c006508, 0x2e006e07, 0x034c6e0c,   // de.gv.lb_543 gv.wo.un_430  hmn.fo.un_420 hmn.wo.nl_543 
  0x09003f04, 0x5a000102, 0x65001b0c, 0x6e3f40a7,   // af.pl.un_320 en.sm.un_220  tr.gv.un_530 lb.af.hmn_532 
  // [75d0]
  0x3f63090b, 0x28123414, 0x17150413, 0x27001f04,   // pl.sco.af_542 ps.ur.sd_666  ru.sr.un_650 cy.gd.un_320 
  0x1b003808, 0x2000630c, 0x6e004c09, 0x30040804,   // tk.tr.un_430 sco.sq.un_530  wo.hmn.un_440 uk.ru.uz_332 
  0x034e3f5a, 0x65003f02, 0x63003f09, 0x444825a0,   // af.ay.nl_553 af.gv.un_220  af.sco.un_440 mn.tt.kk_322 
  0x122130ac, 0x301735a4, 0x23443cac, 0x44080405,   // uz.fa.ur_632 tg.sr.uz_433  ug.kk.ky_632 ru.uk.kk_333 
  // [75e0]
  0x182328ad, 0x48001005, 0x2c033f0c, 0x0f00100b,   // sd.ky.ar_643 be.tt.un_330  af.nl.fy_543 lt.lv.un_520 
  0x28123bad, 0x2112300d, 0x0830355a, 0x2f0913a4,   // ks.ur.sd_643 uz.ur.fa_554  tg.uz.uk_553 et.pl.su_433 
  0x21001304, 0x062e34a0, 0x0a073cad, 0x0e0d2ea4,   // et.jw.un_320 xh.fo.de_322  ug.bg.mk_643 fo.cs.is_433 
  0x34000304, 0x232118ee, 0x13000602, 0x1b001f02,   // nl.xh.un_320 ar.fa.ky_422  de.et.un_220 cy.tr.un_220 
  // [75f0]
  0x2f000912, 0x07111505, 0x61006713, 0x07003813,   // pl.su.un_640 un.ro.bg_333  ak.za.un_650 tk.bg.un_650 
  0x302511a4, 0x213412a0, 0x30150408, 0x381704a4,   // ro.mn.uz_433 ur.ps.fa_322  ru.uz.un_430 ru.sr.tk_433 
  0x5e6e560c, 0x02002e02, 0x03000207, 0x5a001308,   // mg.hmn.ts_543 fo.da.un_220  da.nl.un_420 et.sm.un_430 
  0x075342a0, 0x0742390b, 0x0a1715a4, 0x48153007,   // co.ht.it_322 br.co.it_542  un.sr.mk_433 uz.tt.un_420 
  // [7600]
  0x120d4804, 0x37004421, 0x3b30feac, 0x0c5a24ee,   // tt.cs.hu_332 kk.ba.un_860  tlh.uz.so_632 eo.sm.sv_422 
  0x560779a0, 0x6131380c, 0x6129fea9, 0x3b6707a4,   // war.it.mg_322 tk.az.za_543  tlh.sl.za_544 it.ak.so_433 
  0x795a56a0, 0xfe4d2e07, 0x4d135808, 0xfe303b0c,   // mg.sm.war_322 fo.aa.tlh_432  om.et.aa_443 so.uz.tlh_543 
  0x4400480c, 0x3d302108, 0x38003b0e, 0x073510a0,   // tt.kk.un_530 fa.uz.ku_443  so.tk.un_550 be.tg.bg_322 
  // [7610]
  0x2300340d, 0x21123407, 0xfe1b30ec, 0x041b12ee,   // ps.ky.un_540 ps.ur.fa_432  uz.tr.tlh_644 hu.tr.fi_422 
  0x2efe2a13, 0x30483760, 0x07002312, 0x483830a9,   // mt.tlh.fo_665 ba.tt.uz_664  ky.bg.un_640 uz.tk.tt_544 
  0x6976080c, 0x5400481b, 0x150a100c, 0x3e30fead,   // no.crs.mfe_543 tt.ik.un_770  be.mk.un_543 tlh.uz.rm_643 
  0x3038fe60, 0x30fe4dad, 0x48002504, 0x3c2134ad,   // tlh.tk.uz_664 aa.tlh.uz_643  eu.tt.un_320 ps.fa.ug_643 
  // [7620]
  0x3800651a, 0x1700150d, 0x27521ba7, 0x52001c02,   // gv.tk.un_760 un.sr.un_540  tr.ha.gd_532 id.ha.un_220 
  0x25004408, 0x651306a4, 0x374838a4, 0x381b100c,   // kk.mn.un_430 de.et.gv_433  tk.tt.ba_433 lt.tr.tk_543 
  0x58003802, 0x0d5824a7, 0x651f02ee, 0x09001008,   // tk.om.un_220 eo.om.cs_532  da.cy.gv_422 lt.pl.un_430 
  0x2e600207, 0x4b00301b, 0x43007913, 0x6945100c,   // da.vo.fo_432 uz.mi.un_770  war.ie.un_650 lt.ln.mfe_543 
  // [7630]
  0x65fe3bee, 0x25041012, 0x1000452a, 0x0e753709,   // so.tlh.gv_422 lt.fi.eu_654  ln.lt.un_970 st.nso.is_444 
  0x11103baf, 0x0200fc19, 0x1d001504, 0x4c001d04,   // so.lt.ro_655 zzp.da.un_750  un.la.un_320 la.wo.un_320 
  0x3b002507, 0x4f5e5608, 0x213418a6, 0x76536909,   // eu.so.un_420 mg.ts.bi_443  ar.ps.fa_521 mfe.ht.crs_444 
  0x49003308, 0x08000712, 0x11302508, 0x1c00020d,   // nn.to.un_430 bg.uk.un_640  eu.uz.ro_443 da.id.un_540 
  // [7640]
  0x28123404, 0x304556af, 0x02fe42a4, 0x58026355,   // ps.ur.sd_332 mg.ln.uz_655  co.tlh.da_433 sco.da.om_442 
  0x4c583bad, 0x4d002a08, 0x012322a4, 0x3f004c05,   // so.om.wo_643 mt.aa.un_430  oc.ca.en_433 wo.af.un_330 
  0x1d180107, 0x094b1004, 0x070a1712, 0x301339a6,   // en.ga.la_432 lt.mi.pl_332  sr.mk.bg_654 br.et.uz_521 
  0x281221a4, 0x6a302da7, 0x0430480c, 0x2400101a,   // fa.ur.sd_433 sk.uz.haw_532  tt.uz.ru_543 lt.eo.un_760 
  // [7650]
  0x57104f0e, 0x170804a4, 0x071725a7, 0x093137a4,   // bi.lt.na_555 ru.uk.sr_433  mn.sr.bg_532 st.az.pl_433 
  0x151504ad, 0x48234411, 0x35001712, 0x312d0d08,   // ru.un.un_630 kk.ky.tt_653  sr.tg.un_640 cs.sk.az_443 
  0x220b3102, 0x0b003908, 0x0e2d0d05, 0x11041513,   // az.es.oc_222 br.es.un_430  cs.sk.is_333 un.ru.ro_665 
  0x21002812, 0x1234280e, 0x0602fcee, 0x23003822,   // sd.fa.un_640 sd.ps.ur_555  zzp.da.de_422 tk.ky.un_870 
  // [7660]
  0x12211804, 0x04003e05, 0x13001c14, 0x0e2e12a9,   // ar.fa.ur_332 rm.fi.un_330  mr.bh.un_660 hu.fo.is_544 
  0x0c00fc02, 0x153015a4, 0x13016355, 0x323e18a4,   // zzp.sv.un_220 un.uz.un_433  sco.en.et_442 ga.rm.bs_433 
  0x20000305, 0x10481504, 0x1d000114, 0x12342812,   // nl.sq.un_330 un.tt.be_332  en.la.un_660 sd.ps.ur_654 
  0x33001312, 0x2a000913, 0x37483c5a, 0x041015af,   // et.nn.un_640 pl.mt.un_650  ug.tt.ba_553 un.be.ru_655 
  // [7670]
  0x08000108, 0x17301507, 0x37354805, 0x30383713,   // en.no.un_430 un.uz.sr_432  tt.tg.ba_333 ba.tk.uz_665 
  0x130d3ba9, 0x2e006508, 0x071004a0, 0x1800120e,   // ks.ne.bh_544 gv.fo.un_430  ru.be.bg_322 ur.ar.un_550 
  0x62115709, 0x625a490d, 0x6a5a4b12, 0x48373c13,   // na.ro.kha_444 to.sm.kha_554  mi.sm.haw_654 ug.ba.tt_665 
  0x401162a0, 0x5500640c, 0x0a0262ec, 0x5702505a,   // kha.ro.lb_322 lg.rw.un_530  kha.da.pt_644 fj.da.na_553 
  // [7680]
  0x36401204, 0x074961ee, 0x12253ea4, 0x6a005c19,   // hu.lb.gn_332 za.to.it_422  rm.eu.hu_433 sa.haw.un_750 
  0x11004908, 0x0f0a11a4, 0x12004514, 0x19110a07,   // to.ro.un_430 ro.pt.lv_433  ln.hu.un_660 pt.ro.gl_432 
  0x090d1c09, 0x4761500c, 0x57006234, 0x3c003023,   // mr.ne.hi_444 fj.za.sn_543  kha.na.un_A80 uz.ug.un_880 
  0x5000620d, 0x1f254908, 0x10040aee, 0x06016ba0,   // kha.fj.un_540 to.eu.cy_443  mk.ru.be_422 ceb.en.de_322 
  // [7690]
  0x28211211, 0x1d005002, 0x3217fe09, 0x12002002,   // ur.fa.sd_653 fj.la.un_220  tlh.sr.bs_444 sq.hu.un_220 
  0x04101504, 0x20494bec, 0x070a1707, 0x3c44370e,   // un.be.ru_332 mi.to.sq_644  sr.mk.bg_432 ba.kk.ug_555 
  0x32005604, 0x2d0d3602, 0x1504080e, 0x24004702,   // mg.bs.un_320 gn.cs.sk_222  uk.ru.un_555 sn.eo.un_220 
  0x15004414, 0x5500560d, 0x3023380c, 0x0afe5e09,   // kk.un.un_660 mg.rw.un_540  tk.ky.uz_543 ts.tlh.pt_444 
  // [76a0]
  0x08041107, 0x5c004719, 0x254437ec, 0x5c006509,   // ro.ru.uk_432 sn.sa.un_750  ba.kk.mn_644 gv.sa.un_440 
  0x0a00251a, 0x2d0d2002, 0x15233cad, 0x303421a9,   // mn.mk.un_760 sq.cs.sk_222  ug.ky.un_643 fa.ps.uz_544 
  0x17480702, 0x04001020, 0x5c0278ad, 0x731a1e0c,   // bg.tt.sr_222 be.ru.un_850  ve.da.sa_643 ms.tl.ny_543 
  0x0a170713, 0x0e002e11, 0x3400730d, 0x64354207,   // bg.sr.mk_665 fo.is.un_630  ny.xh.un_540 co.zu.lg_432 
  // [76b0]
  0x78736b0c, 0x35735e08, 0x49000a02, 0x3564500d,   // ceb.ny.ve_543 ts.ny.zu_443  pt.to.un_220 fj.lg.zu_554 
  0x0a173508, 0x3c0a3808, 0x17153508, 0x30005204,   // tg.sr.mk_443 tk.mk.ug_443  tg.sr.un_430 ha.uz.un_320 
  0x1000360d, 0x3c00441b, 0x255e60a4, 0x79302313,   // ab.be.un_540 kk.ug.un_770  vo.ts.eu_433 ca.uz.war_665 
  0x31003823, 0x4c003404, 0x5d505e0c, 0x330827ee,   // tk.az.un_880 xh.wo.un_320  ts.fj.ss_543 gd.no.nn_422 
  // [76c0]
  0x11234308, 0x67001f13, 0x1b4820ee, 0x314d4660,   // ie.ca.ro_443 cy.ak.un_650  sq.tt.tr_422 qu.aa.az_664 
  0x23183d08, 0x353c3008, 0x30482702, 0x02000414,   // ku.ar.ky_443 uz.ug.tg_443  gd.tt.uz_222 fi.da.un_660 
  0x33003009, 0x4e09560c, 0x170a3005, 0x3d123ba4,   // uz.nn.un_440 mg.pl.ay_543  uz.mk.sr_333 ks.ur.ku_433 
  0x5d647607, 0x35041702, 0x18233c0d, 0x0e003604,   // crs.lg.ss_432 sr.ru.tg_222  ug.ky.ar_554 gn.is.un_320 
  // [76d0]
  0x44483705, 0xfc006304, 0x13005c02, 0x21343d09,   // ba.tt.kk_333 sco.zzp.un_320  sa.bh.un_220 ku.ps.fa_444 
  0x0f00fc02, 0x1c2e3f0d, 0x393b1fad, 0x121821a9,   // zzp.lv.un_220 af.fo.id_554  cy.so.br_643 fa.ar.ur_544 
  0x1d696a0c, 0x212f0807, 0x24000919, 0x4b023707,   // haw.mfe.la_543 no.su.jw_432  pl.eo.un_750 st.da.mi_432 
  0x530a4cee, 0x020f3608, 0x393e1007, 0x4c003604,   // wo.pt.ht_422 gn.lv.da_443  lt.rm.br_432 gn.wo.un_320 
  // [76e0]
  0x2d290d07, 0x213428a7, 0x1e002022, 0x22755f0b,   // cs.sl.sk_432 sd.ps.fa_532  ti.am.un_870 tn.nso.oc_542 
  0x1f002108, 0x380c0207, 0x532269a4, 0x47365fa0,   // jw.cy.un_430 da.sv.tk_432  mfe.oc.ht_433 tn.gn.sn_322 
  0x303c35ec, 0x153c150c, 0x29003902, 0x4c003405,   // tg.ug.uz_644 un.ug.un_543  br.sl.un_220 xh.wo.un_330 
  0x39473407, 0x5300280c, 0x0a0715a7, 0x0a120105,   // xh.sn.br_432 sw.ht.un_530  un.bg.mk_532 en.hu.pt_333 
  // [76f0]
  0x09004a02, 0x3f2f39ad, 0x29495a0c, 0x2415010b,   // yo.pl.un_220 br.su.af_643  sm.to.sl_543 en.eo.un_520 
  0x020f1fa0, 0x151d0155, 0x60101ca0, 0x2e080202,   // cy.lv.da_322 en.la.un_442  id.lt.vo_322 da.no.fo_222 
  0x0d09130c, 0x29fe1b07, 0x380a0713, 0x5500610c,   // bh.hi.ne_543 tr.tlh.sl_432  bg.mk.tk_665 za.rw.un_530 
  0x4025060c, 0x32002702, 0x44002812, 0x00003937,   // de.eu.lb_543 gd.bs.un_220  sd.kk.un_640 dz.un.un_B00 
  // [7700]
  0x27001702, 0x0700150c, 0x31002404, 0x18480608,   // sr.gd.un_220 un.bg.un_530  eo.az.un_320 de.tt.ga_443 
  0x23005304, 0x10040855, 0x35382308, 0x08004419,   // ht.ca.un_320 uk.ru.be_442  ky.tk.tg_443 kk.uk.un_750 
  0x3b003002, 0x0c0806ee, 0x123467ad, 0x0e130f0c,   // uz.so.un_220 de.no.sv_422  ak.xh.hu_643 lv.et.is_543 
  0x495a5860, 0x3c3038a0, 0x55002804, 0x30573107,   // om.sm.to_664 tk.uz.ug_322  sw.rw.un_320 az.na.uz_432 
  // [7710]
  0x10290f04, 0x08044808, 0x4a002d08, 0x4c00581b,   // lv.sl.lt_332 tt.ru.uk_443  sk.yo.un_430 om.wo.un_770 
  0x5c001c21, 0x495a58af, 0x0e000704, 0x37254804,   // mr.sa.un_860 om.sm.to_655  it.is.un_320 tt.mn.ba_332 
  0x3b006911, 0x1f1b0eec, 0x4a190bee, 0x0c001f02,   // mfe.so.un_630 is.tr.cy_644  es.gl.yo_422 cy.sv.un_220 
  0x6563010c, 0x3f007304, 0x170711a4, 0x20312aee,   // en.sco.gv_543 ny.af.un_320  ro.bg.sr_433 mt.az.sq_422 
  // [7720]
  0x135c0d08, 0x6b1a0b0d, 0x12520eaf, 0x65016304,   // ne.sa.bh_443 es.tl.ceb_554  is.ha.hu_655 sco.en.gv_332 
  0x15080413, 0x39632aaf, 0x2d00091a, 0x65091f11,   // ru.uk.un_665 mt.sco.br_655  pl.sk.un_760 cy.pl.gv_653 
  0x15600111, 0x63011fa0, 0x4a00120d, 0x2d000919,   // en.vo.un_653 cy.en.sco_322  hu.yo.un_540 pl.sk.un_750 
  0x0d001312, 0x1044360c, 0x011f6307, 0x2d00090c,   // bh.ne.un_640 ab.kk.be_543  sco.cy.en_432 pl.sk.un_530 
  // [7730]
  0x0d2d09a7, 0x39006304, 0x330263ee, 0x2544480c,   // pl.sk.cs_532 sco.br.un_320  sco.da.nn_422 tt.kk.mn_543 
  0x151004a9, 0x21003419, 0x303536af, 0x0a1107a4,   // ru.be.un_544 ps.fa.un_750  ab.tg.uz_655 bg.ro.mk_433 
  0x0800380b, 0x12003613, 0x3600121a, 0x3e0c40ad,   // tk.uk.un_520 gn.hu.un_650  hu.gn.un_760 lb.sv.rm_643 
  0x2d000913, 0x04153808, 0x30005207, 0x08005212,   // pl.sk.un_650 tk.ru.un_430  ha.uz.un_420 ha.no.un_640 
  // [7740]
  0x0415360b, 0x2a001a07, 0x300425ad, 0x350715a4,   // ab.ru.un_520 tl.mt.un_420  mn.ru.uz_643 un.bg.tg_433 
  0x482337a0, 0x35001709, 0x153635ec, 0x212f0507,   // ba.ky.tt_322 sr.tg.un_440  tg.ab.un_644 fr.su.jw_432 
  0x05213605, 0x2b001d04, 0x25233009, 0x3000150b,   // gn.jw.fr_333 la.vi.un_320  uz.ky.mn_444 un.uz.un_520 
  0x25003502, 0x3700441a, 0x341828ec, 0x44001204,   // tg.mn.un_220 kk.ba.un_760  sd.ar.ps_644 ur.kk.un_320 
  // [7750]
  0x363f2202, 0x55005e11, 0x595547a9, 0x15003c0d,   // oc.af.gn_222 ts.rw.un_630  sn.rw.rn_544 ug.un.un_540 
  0x32005c07, 0x2d0d3609, 0x3635300d, 0x25381012,   // sa.bs.un_420 gn.cs.sk_444  uz.tg.ab_554 be.tk.mn_654 
  0x0a170707, 0x02026007, 0x791b3807, 0x1a1202a4,   // bg.sr.mk_432 vo.da.da_432  tk.tr.war_432 da.hu.tl_433 
  0x1a1bfe04, 0x0c333fa4, 0x383c36a4, 0x2b2d10ee,   // tlh.tr.tl_332 af.nn.sv_433  ab.ug.tk_433 lt.sk.vi_422 
  // [7760]
  0x38001521, 0x4548380c, 0x04071012, 0x3c382314,   // un.tk.un_860 tk.tt.ln_543  be.bg.ru_654 ky.tk.ug_666 
  0x48001b1b, 0x3600250d, 0x173530ad, 0x481b3811,   // tr.tt.un_770 mn.ab.un_540  uz.tg.sr_643 tk.tr.tt_653 
  0x09131c0b, 0x4600fe04, 0x104837af, 0x390536a7,   // mr.bh.hi_542 tlh.qu.un_320  ba.tt.be_655 gn.fr.br_532 
  0x21301214, 0x02155307, 0x0a1025ee, 0x1c392c04,   // ur.uz.fa_666 ht.da.un_420  mn.be.mk_422 fy.br.id_332 
  // [7770]
  0x400833a0, 0x343d1204, 0x022f21ee, 0x024065a0,   // nn.no.lb_322 ur.ku.ps_332  jw.su.da_422 gv.lb.da_322 
  0x365c3809, 0x3b2f5c07, 0x38626107, 0x032c3f0c,   // tk.sa.gn_444 sa.su.so_432  za.kha.tk_432 af.fy.nl_543 
  0x08002e0c, 0x08022e05, 0x38005c0e, 0x213965a0,   // fo.no.un_530 fo.da.no_333  sa.tk.un_550 gv.br.jw_322 
  0x0e00600b, 0x1e006b04, 0x3f001f02, 0x2e330c07,   // vo.is.un_520 ceb.ms.un_320  cy.af.un_220 sv.nn.fo_432 
  // [7780]
  0x38352513, 0x380d2d12, 0x33000f12, 0x36595514,   // mn.tg.tk_665 sk.cs.tk_654  lv.nn.un_640 rw.rn.gn_666 
  0x4e250912, 0x650163a4, 0x1a6b01a4, 0x2200300c,   // pl.eu.ay_654 sco.en.gv_433  en.ceb.tl_433 uz.oc.un_530 
  0x793128ec, 0x60016505, 0x0e2e3308, 0x796b1a13,   // sw.az.war_644 gv.en.vo_333  nn.fo.is_443 tl.ceb.war_665 
  0x65190a08, 0x491a4cee, 0x562d0d09, 0x504d59a4,   // pt.gl.gv_443 wo.tl.to_422  cs.sk.mg_444 rn.aa.fj_433 
  // [7790]
  0x56000d12, 0x2f3638a0, 0x604d65a9, 0x64595509,   // cs.mg.un_640 tk.gn.su_322  gv.aa.vo_544 rw.rn.lg_444 
  0x2d0d56a9, 0x10440a02, 0x23080a07, 0x3b000e0e,   // mg.cs.sk_544 mk.kk.be_222  mk.uk.ky_432 is.so.un_550 
  0x10150413, 0x1f00fc0c, 0x13002e0d, 0x03133f0c,   // ru.be.un_650 zzp.cy.un_530  fo.et.un_540 af.et.nl_543 
  0x0e003313, 0x564d465a, 0x5c0d13a4, 0x0c002a0e,   // nn.is.un_650 qu.aa.mg_553  bh.ne.sa_433 mt.sv.un_550 
  // [77a0]
  0x1a211c0b, 0x6b1a0107, 0x563050a9, 0xfc000b05,   // id.jw.tl_542 en.tl.ceb_432  fj.uz.mg_544 es.zzp.un_330 
  0x04170702, 0x321617a6, 0x13003013, 0x342818ec,   // bg.sr.ru_222 sr.hr.bs_521  uz.et.un_650 ar.sd.ps_644 
  0x25001702, 0x47001d08, 0x12004c07, 0x08133002,   // sr.mn.un_220 la.sn.un_430  wo.hu.un_420 uz.et.no_222 
  0x253b2a0c, 0x24000302, 0x0e005a02, 0x2e4c07ec,   // mt.so.eu_543 nl.eo.un_220  sm.is.un_220 it.wo.fo_644 
  // [77b0]
  0x484c2aac, 0x3c0a1712, 0x3b6b1304, 0x033f40ee,   // mt.wo.tt_632 sr.mk.ug_654  et.ceb.so_332 lb.af.nl_422 
  0x04152804, 0x301b73a4, 0x12000c0c, 0x1b3b38ee,   // sw.fi.un_320 ny.tr.uz_433  sv.hu.un_530 tk.so.tr_422 
  0x301b31af, 0x04003f02, 0x10003e14, 0x11130f08,   // az.tr.uz_655 af.fi.un_220  rm.lt.un_660 lv.et.ro_443 
  0x070a36ee, 0x101f4213, 0x0c0869a4, 0x5d3308ee,   // ab.mk.bg_422 co.cy.lt_665  mfe.no.sv_433 no.nn.ss_422 
  // [77c0]
  0x2f2d1209, 0x0400080e, 0x30211208, 0x4a3628a9,   // hu.sk.su_444 uk.ru.un_550  ur.fa.uz_443 sw.gn.yo_544 
  0xfe004f21, 0x73004a12, 0x15150412, 0x30170a11,   // bi.tlh.un_860 yo.ny.un_640  ru.un.un_640 mk.sr.uz_653 
  0x56002812, 0x170a35ee, 0x091c0d02, 0x113823af,   // sw.mg.un_640 tg.mk.sr_422  ne.mr.hi_222 ky.tk.ro_655 
  0x240f4b07, 0x353015ec, 0x24002809, 0x3704150c,   // mi.lv.eo_432 un.uz.tg_644  sw.eo.un_440 un.ru.ba_543 
  // [77d0]
  0x03004004, 0x553e4011, 0x403925a0, 0x07110a05,   // lb.nl.un_320 lb.rm.rw_653  eu.br.lb_322 mk.ro.bg_333 
  0x0c330813, 0x46002209, 0x2d0d12b2, 0x5c000909,   // no.nn.sv_665 oc.qu.un_440  hu.cs.sk_732 hi.sa.un_440 
  0x3648300e, 0x073e4204, 0x153815a4, 0x0340255a,   // uz.tt.ab_555 co.rm.it_332  un.tk.un_433 eu.lb.nl_553 
  0x406309ee, 0x1200091b, 0x44004813, 0x4807380c,   // pl.sco.lb_422 pl.hu.un_770  tt.kk.un_650 tk.bg.tt_543 
  // [77e0]
  0x07361107, 0x1200090b, 0x20001e2b, 0x480715a4,   // ro.ab.bg_432 pl.hu.un_520  am.ti.un_980 un.bg.tt_433 
  0x10002d0e, 0x25000408, 0x12330808, 0x2700670c,   // sk.lt.un_550 ru.mn.un_430  no.nn.hu_443 ak.gd.un_530 
  0x3534375a, 0x40355d05, 0x5d196ba0, 0x44212807,   // st.xh.zu_553 ss.zu.lb_333  ceb.gl.ss_322 sd.fa.kk_432 
  0x654605a0, 0x27073ea0, 0x3c041509, 0x2d005f05,   // fr.qu.gv_322 rm.it.gd_322  un.ru.ug_444 tn.sk.un_330 
  // [77f0]
  0x3b00301a, 0x79001c08, 0x1b00460c, 0x03000407,   // uz.so.un_760 id.war.un_430  qu.tr.un_530 fi.nl.un_420 
  0x35153812, 0x5d732808, 0x64002f07, 0x07040aa9,   // tk.tg.un_640 sw.ny.ss_443  su.lg.un_420 mk.ru.bg_544 
  0x133b1ea0, 0x1b313811, 0x1a0260a6, 0x0d002804,   // ms.so.et_322 tk.az.tr_653  vo.da.tl_521 sw.cs.un_320 
  0x5f753404, 0x3b1e1c5a, 0x3534360c, 0x302315ee,   // xh.nso.tn_332 id.ms.so_553  gn.xh.zu_543 un.ky.uz_422 
  
  // [7800]
  0x6b4913a0, 0x47005a02, 0x485f130d, 0x48243e12,   // et.to.ceb_322 sm.sn.un_220  et.tn.tt_554 rm.eo.tt_654 
  0x0a071512, 0x28004704, 0x36041312, 0x2f1e1c5a,   // un.bg.mk_654 sn.sw.un_320  et.fi.gn_654 id.ms.su_553 
  0x343627ee, 0x2d0d3bee, 0x04471304, 0x20000204,   // gd.gn.xh_422 so.cs.sk_422  et.sn.fi_332 da.sq.un_320 
  0x2f3b1e04, 0x65004609, 0x4b0436ee, 0x645e36a0,   // ms.so.su_332 qu.gv.un_440  gn.fi.mi_422 gn.ts.lg_322 
  // [7810]
  0x0e60fc55, 0x21303da9, 0x1500310c, 0x33000c08,   // zzp.vo.is_442 ku.uz.fa_544  az.un.un_530 sv.nn.un_430 
  0x38153612, 0x12000d13, 0x042d0d04, 0xfe00471a,   // ab.tk.un_640 cs.hu.un_650  cs.sk.fi_332 sn.tlh.un_760 
  0x392901a0, 0x5c004708, 0x22000d08, 0x63201507,   // en.sl.br_322 sn.sa.un_430  cs.oc.un_430 un.sq.sco_432 
  0x18282155, 0x2130340d, 0x0a041704, 0x121e1812,   // fa.sd.ar_442 ps.uz.fa_554  sr.ru.mk_332 ar.am.ur_654 
  // [7820]
  0x50000404, 0x24005804, 0x290447a0, 0xfc00020b,   // fi.fj.un_320 om.eo.un_320  sn.fi.sl_322 da.zzp.un_520 
  0x08000604, 0x0a1517af, 0x48303ca0, 0x082a2e04,   // de.no.un_320 sr.mk.un_650  ug.uz.tt_322 fo.mt.no_332 
  0x5223220d, 0x05223902, 0x1015040b, 0x01fe13a0,   // oc.ca.ha_554 br.oc.fr_222  ru.be.un_520 et.tlh.en_322 
  0x02000e09, 0x79630109, 0x39630107, 0x440407ee,   // is.da.un_440 en.sco.war_444  en.sco.br_432 bg.ru.kk_422 
  // [7830]
  0x1700110b, 0x1e005302, 0x391363a4, 0x2d63010c,   // ro.sr.un_520 ht.ms.un_220  sco.et.br_433 en.sco.sk_543 
  0x401205a0, 0x2d002107, 0x016339ec, 0x48005504,   // fr.hu.lb_322 jw.sk.un_420  br.sco.en_644 rw.tt.un_320 
  0x04080a05, 0x3d3028a4, 0x63650105, 0x42362204,   // mk.uk.ru_333 sd.uz.ku_433  en.gv.sco_333 oc.gn.co_332 
  0x2e0e3313, 0x15443807, 0x35172508, 0x30006b08,   // nn.is.fo_665 tk.kk.un_432  mn.sr.tg_443 ceb.uz.un_430 
  // [7840]
  0x58004d1a, 0x5800131a, 0x47134d08, 0x04170a09,   // aa.om.un_760 et.om.un_760  aa.et.sn_443 mk.sr.ru_444 
  0x6a00490d, 0x64020405, 0x13005812, 0x3f1d5811,   // to.haw.un_540 fi.da.lg_333  om.et.un_640 om.la.af_653 
  0x35004809, 0x3600370e, 0x400328ee, 0x10000713,   // tt.tg.un_440 ba.ab.un_550  sw.nl.lb_422 bg.be.un_650 
  0x2858645a, 0x2d000302, 0x04581307, 0x03584c0c,   // lg.om.sw_553 nl.sk.un_220  et.om.fi_432 wo.om.nl_543 
  // [7850]
  0x353011ee, 0x64002804, 0x43001912, 0x48003c18,   // ro.uz.tg_422 sw.lg.un_320  gl.ie.un_640 ug.tt.un_740 
  0x080723ee, 0x354430a0, 0x402a0cad, 0x1a64120b,   // ky.bg.uk_422 uz.kk.tg_322  sv.mt.lb_643 hu.lg.tl_542 
  0x17070aec, 0x595f680d, 0x30383c0d, 0x4830380b,   // mk.bg.sr_644 ig.tn.rn_554  ug.tk.uz_554 tk.uz.tt_542 
  0x212834a0, 0x64005505, 0x04100aee, 0x4823350c,   // ps.sd.fa_322 rw.lg.un_330  mk.be.ru_422 tg.ky.tt_543 
  // [7860]
  0x3800232a, 0x1200480d, 0x0d001c2a, 0x08040708,   // ky.tk.un_970 tt.hu.un_540  mr.ne.un_970 bg.ru.uk_443 
  0x4a2b0e04, 0x0d004a1b, 0x0b184a5a, 0x432b5d08,   // is.vi.yo_332 yo.cs.un_770  yo.ga.es_553 ss.vi.ie_443 
  0x0b002204, 0x18004a35, 0x19490aaf, 0x2b184aec,   // oc.es.un_320 yo.ga.un_A90  pt.to.gl_655 yo.ga.vi_644 
  0x18434aa4, 0x0d002919, 0x1b53450c, 0x07644255,   // yo.ie.ga_433 sl.cs.un_750  ln.ht.tr_543 co.lg.it_442 
  // [7870]
  0x041023a7, 0x091b5307, 0x42640705, 0x15253808,   // ky.be.ru_532 ht.tr.pl_432  it.lg.co_333 tk.mn.un_443 
  0x34184407, 0x1c095c02, 0x09002704, 0x12642aad,   // kk.ar.ps_432 sa.hi.mr_222  gd.pl.un_320 mt.lg.hu_643 
  0x30002118, 0x2e184aad, 0x06392aa0, 0x10003518,   // fa.uz.un_740 yo.ga.fo_643  mt.br.de_322 tg.be.un_740 
  0x233025ad, 0x40005205, 0x2a060107, 0x0700640c,   // mn.uz.ky_643 ha.lb.un_330  en.de.mt_432 lg.it.un_530 
  // [7880]
  0x0d002b1a, 0x09002d04, 0x150407ec, 0x2e004a34,   // vi.cs.un_760 sk.pl.un_320  bg.ru.un_644 yo.fo.un_A80 
  0x06004012, 0x3100300c, 0x63291dee, 0x1800491a,   // lb.de.un_640 uz.az.un_530  la.sl.sco_422 to.ga.un_760 
  0x170a3807, 0x65016355, 0x34311ba6, 0x30483b0d,   // tk.mk.sr_432 sco.en.gv_442  tr.az.xh_521 so.tt.uz_554 
  0x34311b08, 0x6b79010c, 0x64731ba7, 0x39006307,   // tr.az.xh_443 en.war.ceb_543  tr.ny.lg_532 sco.br.un_420 
  // [7890]
  0x03003f1b, 0x1f000304, 0x311b5e07, 0x07000b02,   // af.nl.un_770 nl.cy.un_320  ts.tr.az_432 es.it.un_220 
  0x0a11070d, 0x4a004704, 0x4448380e, 0x072a42a4,   // bg.ro.mk_554 sn.yo.un_320  tk.tt.kk_555 co.mt.it_433 
  0x5d5035a0, 0x03004207, 0x34355d08, 0x2d0d01a0,   // zu.fj.ss_322 co.nl.un_420  ss.zu.xh_443 en.cs.sk_322 
  0x210679ee, 0x40006307, 0x631f01a9, 0x6553fc02,   // war.de.jw_422 sco.lb.un_420  en.cy.sco_544 zzp.ht.gv_222 
  // [78a0]
  0x30311b05, 0x341b35af, 0x0a007904, 0x4838310c,   // tr.az.uz_333 zu.tr.xh_655  war.pt.un_320 az.tk.tt_543 
  0x22000704, 0x025f57a6, 0x2f001908, 0x04070aad,   // it.oc.un_320 na.tn.da_521  gl.su.un_430 mk.bg.ru_643 
  0x675764af, 0x562178a4, 0x19001d04, 0x1b4d340c,   // lg.na.ak_655 ve.jw.mg_433  la.gl.un_320 xh.aa.tr_543 
  0x0a00190d, 0xfc650702, 0x62101ea9, 0x300a25a0,   // gl.pt.un_540 it.gv.zzp_222  ms.lt.kha_544 mn.mk.uz_322 
  // [78b0]
  0x4b003e04, 0x6a491ea9, 0x0f00102c, 0x2d0d0609,   // rm.mi.un_320 ms.to.haw_544  lt.lv.un_990 de.cs.sk_444 
  0x52471ea4, 0x12793b04, 0x50495aec, 0x5a1e1c0d,   // ms.sn.ha_433 so.war.hu_332  sm.to.fj_644 id.ms.sm_554 
  0x1d001919, 0x1e5c4602, 0x517329a0, 0x495a36ee,   // gl.la.un_750 qu.sa.ms_222  sl.ny.kl_322 gn.sm.to_422 
  0x570f10a9, 0x3e400608, 0x0f120ca0, 0x135c0907,   // lt.lv.na_544 de.lb.rm_443  sv.hu.lv_322 hi.sa.bh_432 
  // [78c0]
  0x383c15a4, 0x3e6e4ea9, 0x495a10a9, 0x50526a12,   // un.ug.tk_433 ay.hmn.rm_544  lt.sm.to_544 haw.ha.fj_654 
  0x02105a0d, 0x495a1f05, 0x36000804, 0x25233602,   // sm.lt.da_554 cy.sm.to_333  no.gn.un_320 ab.ky.mn_222 
  0x0c2e0804, 0x28302308, 0x5b005019, 0x385310a0,   // no.fo.sv_332 ky.uz.sd_443  fj.sg.un_750 lt.ht.tk_322 
  0x09171202, 0x0a150408, 0x040711a7, 0x6b0e2ea0,   // hu.sr.pl_222 ru.mk.un_430  ro.bg.ru_532 fo.is.ceb_322 
  // [78d0]
  0x0c330808, 0x2b002007, 0x0a101709, 0x305a35a0,   // no.nn.sv_443 sq.vi.un_420  sr.be.mk_444 zu.sm.uz_322 
  0x020cfca0, 0x0e330855, 0x02000302, 0x321660ee,   // zzp.sv.da_322 no.nn.is_442  nl.da.un_220 vo.hr.bs_422 
  0x30443707, 0x2e33085a, 0x48443704, 0x3d21180c,   // ba.kk.uz_432 no.nn.fo_553  ba.kk.tt_332 ar.fa.ku_543 
  0x2523440b, 0x3d003022, 0x50000102, 0xfe004f09,   // kk.ky.mn_542 uz.ku.un_870  en.fj.un_220 bi.tlh.un_440 
  // [78e0]
  0x1200fe04, 0x303815af, 0xfe2d0d05, 0x341823a0,   // tlh.hu.un_320 un.tk.uz_655  cs.sk.tlh_333 ky.ar.ps_322 
  0x4c033f13, 0x03003f36, 0x3f030c08, 0x650313ee,   // af.nl.wo_665 af.nl.un_AA0  sv.nl.af_443 et.nl.gv_422 
  0x11000719, 0x0a1711a7, 0x39003b04, 0x3b604da4,   // bg.ro.un_750 ro.sr.mk_532  so.br.un_320 aa.vo.so_433 
  0x4000fc02, 0x15000f04, 0x1f3638ee, 0x382a05a0,   // zzp.lb.un_220 lv.un.un_320  tk.gn.cy_422 fr.mt.tk_322 
  // [78f0]
  0x12655804, 0x3d23120c, 0x234825a4, 0x292030a0,   // om.gv.hu_332 ur.ky.ku_543  mn.tt.ky_433 uz.sq.sl_322 
  0x25000819, 0x21283412, 0x604d45ad, 0x3f2c030c,   // uk.mn.un_750 ps.sd.fa_654  ln.aa.vo_643 nl.fy.af_543 
  0x3b134caf, 0x43061055, 0x022a0bee, 0x03063f09,   // wo.et.so_655 lt.de.ie_442  es.mt.da_422 af.de.nl_444 
  0x2160450c, 0x5f1d4509, 0x2d0d0ca0, 0x4cfc4d0c,   // ln.vo.jw_543 ln.la.tn_444  sv.cs.sk_322 aa.zzp.wo_543 
  // [7900]
  0x176efe07, 0x34760205, 0x3b004c11, 0x53000702,   // tlh.hmn.sr_432 da.crs.xh_333  wo.so.un_630 it.ht.un_220 
  0x53650d04, 0x4d1d11a4, 0x4006fca7, 0x321257af,   // cs.gv.ht_332 ro.la.aa_433  zzp.de.lb_532 na.hu.bs_655 
  0x384006ad, 0x2031feec, 0x0d2e0204, 0x34092913,   // de.lb.tk_643 tlh.az.sq_644  da.fo.cs_332 sl.pl.xh_665 
  0x04082508, 0x324830a0, 0x5500340e, 0x120e2e12,   // mn.uk.ru_443 uz.tt.bs_322  xh.rw.un_550 fo.is.hu_654 
  // [7910]
  0x093960a9, 0x15111d07, 0x19000104, 0x23003f02,   // vo.br.pl_544 la.ro.un_432  en.gl.un_320 af.ca.un_220 
  0x34536704, 0x4d3045a4, 0x090118af, 0x190b0aa0,   // ak.ht.xh_332 ln.uz.aa_433  ar.iw.hi_655 pt.es.gl_322 
  0x23303c09, 0x343024ee, 0x38000607, 0x022429a4,   // ug.uz.ky_444 eo.uz.xh_422  de.tk.un_420 sl.eo.da_433 
  0x0d5c13a0, 0x42005802, 0x044210a0, 0x303f24a0,   // bh.sa.ne_322 om.co.un_220  lt.co.fi_322 eo.af.uz_322 
  // [7920]
  0x240d1702, 0x34041d08, 0x1c005c1a, 0x56000407,   // sr.cs.eo_222 la.fi.xh_443  sa.mr.un_760 fi.mg.un_420 
  0x042515ad, 0x65001104, 0x104835a9, 0x10080408,   // un.mn.ru_643 ro.gv.un_320  tg.tt.be_544 ru.uk.be_443 
  0x1c0d3bee, 0x3000240c, 0x25001021, 0x30001002,   // ks.ne.mr_422 eo.uz.un_530  be.mn.un_860 lt.uz.un_220 
  0x174838ad, 0x29003007, 0x240630a4, 0x3035255a,   // tk.tt.sr_643 uz.sl.un_420  uz.de.eo_433 mn.tg.uz_553 
  // [7930]
  0x0e003105, 0x0d17160e, 0x1828120d, 0x3c374805,   // az.is.un_330 hr.sr.cs_555  ur.sd.ar_554 tt.ba.ug_333 
  0x03000102, 0x211230af, 0x352338a6, 0x17081055,   // en.nl.un_220 uz.ur.fa_655  tk.ky.tg_521 be.uk.sr_442 
  0x35000405, 0x04070a0d, 0x07100a02, 0x303735a4,   // ru.tg.un_330 mk.bg.ru_554  mk.be.bg_222 tg.ba.uz_433 
  0x52003202, 0x04001319, 0x2d002408, 0xfc033f11,   // bs.ha.un_220 et.fi.un_750  eo.sk.un_430 af.nl.zzp_653 
  // [7940]
  0x3b314ea9, 0xfe0e1304, 0x0e5c3f04, 0xfc003305,   // ay.az.so_544 et.is.tlh_332  af.sa.is_332 nn.zzp.un_330 
  0x0c330807, 0x135c4707, 0x182830ad, 0x245c130c,   // no.nn.sv_432 sn.sa.et_432  uz.sd.ar_643 et.sa.eo_543 
  0x30351560, 0x470615a0, 0x2e130e0c, 0x47004007,   // un.tg.uz_664 un.de.sn_322  is.et.fo_543 lb.sn.un_420 
  0x40fe3b07, 0x360906ad, 0x0b224012, 0x6501fc08,   // so.tlh.lb_432 de.pl.gn_643  lb.oc.es_654 zzp.en.gv_443 
  // [7950]
  0x34374507, 0x150622a4, 0x0a351705, 0x333b58a7,   // ln.st.xh_432 oc.de.un_433  sr.tg.mk_333 om.so.nn_532 
  0x36000a04, 0x07004012, 0x523b4da4, 0x1e1c58a0,   // pt.gn.un_320 lb.it.un_640  aa.so.ha_433 om.id.ms_322 
  0x291bfeee, 0x22001d02, 0x02533b05, 0x08020c05,   // tlh.tr.sl_422 la.oc.un_220  so.ht.da_333 sv.da.no_333 
  0x644a3b04, 0x1b202aa0, 0x69001213, 0x0e2e0404,   // so.yo.lg_332 mt.sq.tr_322  hu.mfe.un_650 fi.fo.is_332 
  // [7960]
  0x2a1d58ec, 0x03001008, 0x4c5813a4, 0x12000104,   // om.la.mt_644 lt.nl.un_430  et.om.wo_433 en.hu.un_320 
  0x09463604, 0x28343008, 0x11001721, 0x11460fad,   // gn.qu.pl_332 uz.ps.sd_443  sr.ro.un_860 lv.qu.ro_643 
  0x16003104, 0x07151008, 0x4c3b1fee, 0x0200390e,   // az.hr.un_320 be.bg.un_430  cy.so.wo_422 br.da.un_550 
  0x15002319, 0x59005b0d, 0x32004c11, 0x020a64a0,   // ky.un.un_750 sg.rn.un_540  wo.bs.un_630 lg.pt.da_322 
  // [7970]
  0x1f4d3ba4, 0x130d1c11, 0x5c0239a4, 0x3710080c,   // so.aa.cy_433 mr.ne.bh_653  br.da.sa_433 uk.be.ba_543 
  0x2b006507, 0x31481b0c, 0x1f63010b, 0x4600620c,   // gv.vi.un_420 tr.tt.az_543  en.sco.cy_542 kha.qu.un_530 
  0x0e005d04, 0x04083705, 0x63650205, 0x6463010c,   // ss.is.un_320 ba.uk.ru_333  da.gv.sco_333 en.sco.lg_543 
  0x04080711, 0x30003d12, 0x3400302b, 0x303523a0,   // bg.uk.ru_653 ku.uz.un_640  uz.ps.un_980 ky.tg.uz_322 
  // [7980]
  0x10300f02, 0x2d2e1207, 0x261028a4, 0x3d003004,   // lv.uz.lt_222 hu.fo.sk_432  sw.lt.ia_433 uz.ku.un_320 
  0x28271004, 0x4a0454a0, 0x04281007, 0x131c0dee,   // lt.gd.sw_332 ik.fi.yo_322  lt.sw.fi_432 ne.mr.bh_422 
  0x791b500c, 0x30563807, 0x37303cad, 0x0b002319,   // fj.tr.war_543 tk.mg.uz_432  ug.uz.ba_643 ca.es.un_750 
  0x15001119, 0x330860a4, 0x1e004a04, 0x46002704,   // ro.un.un_750 vo.no.nn_433  yo.ms.un_320 gd.qu.un_320 
  // [7990]
  0x76225a0c, 0x30170aa0, 0x49133e55, 0x070836ee,   // sm.oc.crs_543 mk.sr.uz_322  rm.et.to_442 ab.uk.bg_422 
  0x60000919, 0x0a00350c, 0x2c2e0e12, 0x1f0447a0,   // pl.vo.un_750 tg.mk.un_530  is.fo.fy_654 sn.fi.cy_322 
  0x215a1055, 0x38001f12, 0x11002d05, 0x5e005a04,   // lt.sm.jw_442 cy.tk.un_640  sk.ro.un_330 sm.ts.un_320 
  0x3607350c, 0x4448370c, 0x234437a0, 0x04150aaf,   // tg.bg.ab_543 ba.tt.kk_543  ba.kk.ky_322 mk.ru.un_650 
  // [79a0]
  0x07004807, 0x23226014, 0x0d002e08, 0x17000202,   // tt.bg.un_420 vo.oc.ca_666  fo.cs.un_430 da.sr.un_220 
  0x07081504, 0x13005208, 0x3b213d13, 0x07173807,   // un.uk.bg_332 ha.et.un_430  ku.fa.ks_665 tk.sr.bg_432 
  0x4800690d, 0x09001018, 0x1700330c, 0x09006502,   // mfe.tt.un_540 lt.pl.un_740  nn.sr.un_530 gv.pl.un_220 
  0x11001019, 0x07150804, 0x25003618, 0x21343da0,   // be.ro.un_750 uk.bg.un_320  ab.mn.un_740 ku.ps.fa_322 
  // [79b0]
  0x38001505, 0x33536907, 0x233035a0, 0x7939250d,   // un.tk.un_330 mfe.ht.nn_432  tg.uz.ky_322 eu.br.war_554 
  0x3837480e, 0x1363010c, 0x392b0107, 0x30290d07,   // tt.ba.tk_555 en.sco.et_543  en.vi.br_432 cs.sl.uz_432 
  0x21001a04, 0x35796b12, 0x21281214, 0x29003b08,   // tl.jw.un_320 ceb.war.zu_654  ur.sd.fa_666 so.sl.un_430 
  0x1a004019, 0x523061ad, 0x10566bee, 0x2d0d3807,   // lb.tl.un_750 za.uz.ha_643  ceb.mg.lt_422 tk.cs.sk_432 
  // [79c0]
  0x644a5ba7, 0x1563010c, 0x15483713, 0x303138a0,   // sg.yo.lg_532 en.sco.un_543  ba.tt.un_665 tk.az.uz_322 
  0x1200640d, 0x5c1c09ad, 0x25004305, 0x190a0bec,   // lg.hu.un_540 hi.mr.sa_643  ie.eu.un_330 es.pt.gl_644 
  0x15003e02, 0x28003f02, 0x63020108, 0x3f5535a0,   // rm.un.un_220 af.sw.un_220  en.da.sco_443 zu.rw.af_322 
  0x033f2c04, 0x390c02ec, 0x27254d08, 0x30002f02,   // fy.af.nl_332 da.sv.br_644  aa.eu.gd_443 su.uz.un_220 
  // [79d0]
  0xfe002408, 0x3d1234a4, 0x796b64a4, 0x44152308,   // eo.tlh.un_430 ps.ur.ku_433  lg.ceb.war_433 ky.kk.un_430 
  0x34003b02, 0x2e1b3304, 0x0752290c, 0x29003904,   // so.xh.un_220 nn.tr.fo_332  sl.ha.it_543 br.sl.un_320 
  0x11521e0b, 0x181d0704, 0x31111ba7, 0x29090dad,   // ms.ha.ro_542 it.la.ga_332  tr.ro.az_532 cs.pl.sl_643 
  0x16006108, 0x48353711, 0x3c234809, 0x1d000921,   // za.hr.un_430 ba.tg.tt_653  tt.ky.ug_444 pl.la.un_860 
  // [79e0]
  0x12fe0209, 0x0d202da0, 0x4d520da4, 0x074c42a9,   // da.tlh.hu_444 sk.sq.cs_322  cs.ha.aa_433 co.wo.it_544 
  0x443023a0, 0x070a0808, 0x121511a0, 0x30170402,   // ky.uz.kk_322 uk.mk.bg_443  ro.hu.un_320 ru.sr.uz_222 
  0x0d2961ad, 0x02001207, 0x2300380b, 0x29002d0c,   // za.sl.cs_643 hu.da.un_420  tk.ky.un_520 sk.sl.un_530 
  0x0d0952a0, 0x40002d04, 0x3d002819, 0x48215802,   // ha.pl.cs_322 sk.lb.un_320  sd.ku.un_750 om.jw.tt_222 
  // [79f0]
  0x4a005219, 0x30000205, 0x34002122, 0x1c005712,   // ha.yo.un_750 da.uz.un_330  jw.xh.un_870 na.id.un_640 
  0x6b791aec, 0x343b21ad, 0x4a005711, 0x683b52a7,   // tl.war.ceb_644 fa.ks.ps_643  na.yo.un_630 ha.so.ig_532 
  0x3421120b, 0x1200fe09, 0x3b004802, 0x066515ee,   // ur.fa.ps_542 tlh.hu.un_440  tt.so.un_220 un.gv.de_422 
  0x4852fe04, 0x4a524d0c, 0x796b520e, 0x23081502,   // tlh.ha.tt_332 aa.ha.yo_543  ha.ceb.war_555 un.uk.ky_222 
  // [7a00]
  0x0a1548a7, 0x4a00341a, 0x1500fc08, 0x52004704,   // tt.mk.un_520 xh.yo.un_760  zzp.un.un_430 sn.ha.un_320 
  0x346b1a12, 0x28001e02, 0x3000fe05, 0x330e2ead,   // tl.ceb.xh_654 ms.sw.un_220  tlh.uz.un_330 fo.is.nn_643 
  0x5e004d21, 0x072e3e0c, 0x364417ec, 0x101738ec,   // aa.ts.un_860 rm.fo.it_543  sr.kk.ab_644 tk.sr.be_644 
  0x1b00250c, 0x205c3305, 0x4800310c, 0x3c233513,   // eu.tr.un_530 nn.sa.sq_333  az.tt.un_530 tg.ky.ug_665 
  // [7a10]
  0x510640ad, 0x0e332ea4, 0x173504a4, 0x181228a4,   // lb.de.kl_643 fo.nn.is_433  ru.tg.sr_433 sd.ur.ar_433 
  0x071011a0, 0x37483cee, 0x15002512, 0x37fe2604,   // ro.be.bg_322 ug.tt.ba_422  mn.un.un_640 ia.tlh.st_332 
  0x095c1c0d, 0x632a4707, 0x15006a0d, 0x01003902,   // mr.sa.hi_554 sn.mt.sco_432  haw.un.un_540 br.en.un_220 
  0x5d473504, 0x1828090c, 0x080233af, 0x21183d07,   // zu.sn.ss_332 pl.sw.ga_543  nn.da.no_655 ku.ar.fa_432 
  // [7a20]
  0x1c0d0911, 0x2765630b, 0x25303c0c, 0x10000f11,   // hi.ne.mr_653 sco.gv.gd_542  ug.uz.mn_543 lv.lt.un_630 
  0x2b2763ee, 0x63005612, 0x19002307, 0x152afe04,   // sco.gd.vi_422 mg.sco.un_640  ca.gl.un_420 tlh.mt.un_332 
  0x757835a9, 0x24025ea7, 0xfe374713, 0x1f002b1b,   // zu.ve.nso_544 ts.da.eo_532  sn.st.tlh_665 vi.cy.un_770 
  0x35fcfe07, 0x2b001f0d, 0x3400fe12, 0x1d002b0c,   // tlh.zzp.zu_432 cy.vi.un_540  tlh.xh.un_640 vi.la.un_530 
  // [7a30]
  0x07005607, 0x350436a7, 0x44003c1b, 0x5a00560d,   // mg.it.un_420 ab.ru.tg_532  ug.kk.un_770 mg.sm.un_540 
  0x43001f0d, 0x095c13ad, 0x381b310c, 0x23073c0c,   // cy.ie.un_540 bh.sa.hi_643  az.tr.tk_543 ug.bg.ky_543 
  0x10020ca4, 0x283b1807, 0x363035a4, 0x36003709,   // sv.da.lt_433 ar.ks.sd_432  tg.uz.ab_433 ba.ab.un_440 
  0x15153008, 0x0a3007a0, 0x03173fa0, 0x182834a9,   // uz.un.un_430 bg.uz.mk_322  af.sr.nl_322 ps.sd.ar_544 
  // [7a40]
  0x15003c12, 0x0f000304, 0x2f211ba0, 0x342d0d02,   // ug.un.un_640 nl.lv.un_320  tr.jw.su_322 cs.sk.xh_222 
  0x35372507, 0x0c000605, 0x0a002522, 0x221d43ee,   // mn.ba.tg_432 de.sv.un_330  mn.mk.un_870 ie.la.oc_422 
  0x1c0913ac, 0x38fc4d60, 0x381b21a4, 0x1a566a07,   // bh.hi.mr_632 aa.zzp.tk_664  jw.tr.tk_433 haw.mg.tl_432 
  0x2f006408, 0x69307613, 0x396001a4, 0x4f00032a,   // lg.su.un_430 crs.uz.mfe_665  en.vo.br_433 nl.bi.un_970 
  // [7a50]
  0x1500381a, 0x1c1b29ee, 0x1a006319, 0x10760204,   // tk.un.un_760 sl.tr.id_422  sco.tl.un_750 da.crs.lt_332 
  0x171110ad, 0x6500fc0c, 0x3b00fe08, 0x475e49ee,   // be.ro.sr_643 zzp.gv.un_530  tlh.so.un_430 to.ts.sn_422 
  0x403f0211, 0x24002504, 0x3b5f750c, 0x321b25a0,   // da.af.lb_653 eu.eo.un_320  nso.tn.so_543 eu.tr.bs_322 
  0x474a64a9, 0x482335a0, 0x53005502, 0x761e1ca9,   // lg.yo.sn_544 tg.ky.tt_322  rw.ht.un_220 id.ms.crs_544 
  // [7a60]
  0x3200130c, 0x2460490c, 0x584d52ad, 0x1b245eec,   // et.bs.un_530 to.vo.eo_543  ha.aa.om_643 ts.eo.tr_644 
  0x6b471aa4, 0x30fe3b07, 0x0f475e05, 0x233c300d,   // tl.sn.ceb_433 so.tlh.uz_432  ts.sn.lv_333 uz.ug.ky_554 
  0x1c5c21a0, 0x2900390d, 0x49003b0c, 0x1138350d,   // jw.sa.id_322 br.sl.un_540  so.to.un_530 tg.tk.ro_554 
  0x15330860, 0x2d093bec, 0x2d3b0da4, 0x4800250b,   // no.nn.un_664 so.pl.sk_644  cs.so.sk_433 mn.tt.un_520 
  // [7a70]
  0x42004c08, 0x37482307, 0x2d09380c, 0x040817ec,   // wo.co.un_430 ky.tt.ba_432  tk.pl.sk_543 sr.uk.ru_644 
  0x06556455, 0x070a1055, 0x682c03af, 0x2e0c0e13,   // lg.rw.de_442 be.mk.bg_442  nl.fy.ig_655 is.sv.fo_665 
  0x3e000605, 0x555d3507, 0x170a44a0, 0x55645907,   // de.rm.un_330 zu.ss.rw_432  kk.mk.sr_322 rn.lg.rw_432 
  0x796b3ea4, 0x063634a0, 0x04582a0c, 0x03001608,   // rm.ceb.war_433 xh.gn.de_322  mt.om.fi_543 hr.nl.un_430 
  // [7a80]
  0x34003f09, 0x040744a0, 0x48306405, 0x30003811,   // af.xh.un_440 kk.bg.ru_322  lg.uz.tt_333 tk.uz.un_630 
  0x06002404, 0x060364a0, 0x0c000d05, 0x035f06ad,   // eo.de.un_320 lg.nl.de_322  cs.sv.un_330 de.tn.nl_643 
  0x273018a0, 0x441515a0, 0x380d10ee, 0x133b0d07,   // ga.uz.gd_322 un.kk.un_320  lt.cs.tk_422 ne.ks.bh_432 
  0x1324330c, 0x3500151b, 0x403f0c04, 0x042338a4,   // nn.eo.et_543 un.tg.un_770  sv.af.lb_332 tk.ky.ru_433 
  // [7a90]
  0x1f001004, 0x1f1d2e55, 0x47001008, 0x352308ee,   // lt.cy.un_320 fo.la.cy_442  lt.sn.un_430 uk.ky.tg_422 
  0x17001013, 0x04104607, 0x091f12ad, 0x150835a0,   // be.sr.un_650 qu.lt.fi_432  hu.cy.pl_643 tg.uk.un_322 
  0x0901fc07, 0x33002c02, 0x10001f04, 0x373c2311,   // zzp.en.pl_432 fy.nn.un_220  cy.lt.un_320 ky.ug.ba_653 
  0x10000804, 0x3863090c, 0x3d002321, 0x10000714,   // uk.be.un_320 pl.sco.tk_543  ky.ku.un_860 bg.be.un_660 
  // [7aa0]
  0x48001b05, 0x07043502, 0x53330855, 0x481008a0,   // tr.tt.un_330 tg.ru.bg_222  no.nn.ht_442 uk.be.tt_322 
  0x1c001319, 0x08005d07, 0x1000380d, 0x035d3f04,   // bh.mr.un_750 ss.no.un_420  tk.lt.un_540 af.ss.nl_332 
  0x096976ec, 0x5c001005, 0x38000913, 0x3b2a6b07,   // crs.mfe.pl_644 lt.sa.un_330  pl.tk.un_650 ceb.mt.so_432 
  0x3b002a02, 0x5f5637a9, 0x31303813, 0x12003407,   // mt.so.un_220 st.mg.tn_544  tk.uz.az_665 ps.ur.un_420 
  // [7ab0]
  0x353428a4, 0x564702a4, 0x5c004712, 0x733154ec,   // sw.xh.zu_433 da.sn.mg_433  sn.sa.un_640 ik.az.ny_644 
  0x6b001a08, 0x60005d0e, 0x345d64a9, 0x56555fa9,   // tl.ceb.un_430 ss.vo.un_550  lg.ss.xh_544 tn.rw.mg_544 
  0x58355d04, 0x51644508, 0x535c52a4, 0x356436a9,   // ss.zu.om_332 ln.lg.kl_443  ha.sa.ht_433 gn.lg.zu_544 
  0x50595509, 0x0812580c, 0x0a1707ee, 0x35345caf,   // rw.rn.fj_444 om.hu.no_543  bg.sr.mk_422 sa.xh.zu_655 
  // [7ac0]
  0x5d3435ad, 0x2a495607, 0x28006007, 0x5c53690b,   // zu.xh.ss_643 mg.to.mt_432  vo.sw.un_420 mfe.ht.sa_542 
  0x5c004e14, 0x64255604, 0x735c3508, 0x5d3534a7,   // ay.sa.un_660 mg.eu.lg_332  zu.sa.ny_443 xh.zu.ss_532 
  0x35346414, 0x5d007302, 0x28003e14, 0x5c001004,   // lg.xh.zu_666 ny.ss.un_220  rm.sw.un_660 lt.sa.un_320 
  0x5c355d04, 0x34005d05, 0x651b5cad, 0x532328ee,   // ss.zu.sa_332 ss.xh.un_330  sa.tr.gv_643 sw.ca.ht_422 
  // [7ad0]
  0x40003f08, 0x026445ad, 0x5c3e390c, 0x47647307,   // af.lb.un_430 ln.lg.da_643  br.rm.sa_543 ny.lg.sn_432 
  0x6450280d, 0x31106b02, 0x5f37fea4, 0x56002909,   // sw.fj.lg_554 ceb.lt.az_222  tlh.st.tn_433 sl.mg.un_440 
  0x353469a4, 0x303138ee, 0x35344e0c, 0x302535ad,   // mfe.xh.zu_433 tk.az.uz_422  ay.xh.zu_543 tg.mn.uz_643 
  0x1d15020c, 0x0a36250c, 0x3038fca4, 0x345e375a,   // da.la.un_530 mn.ab.mk_543  zzp.tk.uz_433 st.ts.xh_553 
  // [7ae0]
  0x55355ca6, 0x35003113, 0x0f3801a4, 0x53003f04,   // sa.zu.rw_521 az.zu.un_650  en.tk.lv_433 af.ht.un_320 
  0xfc00651a, 0x3b243fee, 0x183428a4, 0x2d004604,   // gv.zzp.un_760 af.eo.so_422  sd.ps.ar_433 qu.sk.un_320 
  0x28003d05, 0x2e3363ee, 0x37002313, 0x23003014,   // ku.sd.un_330 sco.nn.fo_422  ky.ba.un_650 uz.ky.un_660 
  0x1c000d11, 0x392d30a4, 0x33084809, 0x1708105a,   // ne.mr.un_630 uz.sk.br_433  tt.no.nn_444 be.uk.sr_553 
  // [7af0]
  0x05004807, 0x211830a0, 0x383c23ee, 0x390802ee,   // tt.fr.un_420 uz.ar.fa_322  ky.ug.tk_422 da.no.br_422 
  0x101730a0, 0x043c0a04, 0x1100150e, 0x08374807,   // uz.sr.be_322 mk.ug.ru_332  un.ro.un_550 tt.ba.uk_432 
  0x28002102, 0x44482308, 0x17383704, 0x302344a4,   // fa.sd.un_220 ky.tt.kk_443  ba.tk.sr_332 kk.ky.uz_433 
  0x37150413, 0x350a3caf, 0x05005604, 0x28001805,   // ru.ba.un_650 ug.mk.tg_655  mg.fr.un_320 ga.sw.un_330 
  // [7b00]
  0x0a001721, 0x04233002, 0x12003004, 0x21283460,   // sr.mk.un_860 uz.ky.ru_222  uz.ur.un_320 ps.sd.fa_664 
  0x4d00fe1b, 0x09130d12, 0x48005207, 0x0b150208,   // tlh.aa.un_770 ne.bh.hi_654  ha.tt.un_420 da.es.un_430 
  0x30353c60, 0x342344a0, 0x0a000408, 0x25521f08,   // ug.tg.uz_664 kk.ky.ps_322  ru.mk.un_430 cy.ha.eu_443 
  0x2723220c, 0x08041709, 0x07000802, 0x04371508,   // oc.ca.gd_543 sr.ru.uk_444  uk.bg.un_220 un.ba.ru_443 
  // [7b10]
  0x4d00fe13, 0x2a001704, 0x2a2156ee, 0x5c240402,   // tlh.aa.un_650 sr.mt.un_320  mg.jw.mt_422 fi.eo.sa_222 
  0x4c005820, 0x213d3408, 0x21003d11, 0x0800170d,   // om.wo.un_850 ps.ku.fa_443  ku.fa.un_630 sr.uk.un_540 
  0x483008a0, 0x3400181b, 0x2821180e, 0x17001519,   // uk.uz.tt_322 ar.ps.un_770  ar.fa.sd_555 un.sr.un_750 
  0x0d2e2d0b, 0x3c1834a0, 0x2800640d, 0x08303c07,   // sk.fo.cs_542 ps.ar.ug_322  lg.sw.un_540 ug.uz.uk_432 
  // [7b20]
  0x484417ee, 0x4844350c, 0x3c00481b, 0x130928a0,   // sr.kk.tt_422 tg.kk.tt_543  tt.ug.un_770 sw.pl.et_322 
  0x402425ad, 0x4800200c, 0x25763e0c, 0x0313400b,   // eu.eo.lb_643 sq.tt.un_530  rm.crs.eu_543 lb.et.nl_542 
  0x48353ca0, 0x231b0aa0, 0x36555ea4, 0x12000209,   // ug.tg.tt_322 pt.tr.ca_322  ts.rw.gn_433 da.hu.un_440 
  0x64001305, 0x2e4840ee, 0x1364fc04, 0x1d24430c,   // et.lg.un_330 lb.tt.fo_422  zzp.lg.et_332 ie.eo.la_543 
  // [7b30]
  0x4c001508, 0x07350a02, 0x12213bee, 0x09003607,   // un.wo.un_430 mk.tg.bg_222  ks.fa.ur_422 gn.pl.un_420 
  0x422a070d, 0x3800120d, 0x343d3ba0, 0x311b380d,   // it.mt.co_554 hu.tk.un_540  ks.ku.ps_322 tk.tr.az_554 
  0x23383caf, 0x253e13a9, 0x39381b08, 0x5a006a1a,   // ug.tk.ky_655 et.rm.eu_544  tr.tk.br_443 haw.sm.un_760 
  0x253c3804, 0x60281e0c, 0x64781c0c, 0x34fe5e0c,   // tk.ug.mn_332 ms.sw.vo_543  id.ve.lg_543 ts.tlh.xh_543 
  // [7b40]
  0xfc3f0407, 0xfe00311a, 0x190a540c, 0x30342107,   // fi.af.zzp_432 az.tlh.un_760  ik.pt.gl_543 fa.ps.uz_432 
  0x67402805, 0x303c38af, 0x4d284f0c, 0x311b48a0,   // sw.lb.ak_333 tk.ug.uz_655  bi.sw.aa_543 tt.tr.az_322 
  0x73134b09, 0x0e004b05, 0x52250607, 0x32163614,   // mi.et.ny_444 mi.is.un_330  de.eu.ha_432 gn.hr.bs_666 
  0x48024c05, 0x31003b11, 0x1b3138a9, 0x151d2155,   // wo.da.tt_333 so.az.un_630  tk.az.tr_544 jw.la.un_442 
  // [7b50]
  0x11755fec, 0x1a101c07, 0x02000d02, 0x4f1c1e0c,   // tn.nso.ro_644 id.lt.tl_432  cs.da.un_220 ms.id.bi_543 
  0x1b4831af, 0x3130510c, 0x3e505eec, 0x2f5221ad,   // az.tt.tr_655 kl.uz.az_543  ts.fj.rm_644 jw.ha.su_643 
  0x06002004, 0x121a5aec, 0x3bfc1aa7, 0x2460faaf,   // sq.de.un_320 sm.tl.hu_644  tl.zzp.so_532 nr.vo.eo_655 
  0x23253ca9, 0x2028360c, 0x6339010c, 0x3b6a5711,   // ug.mn.ky_544 gn.sw.sq_543  en.br.sco_543 na.haw.so_653 
  // [7b60]
  0x040a11ac, 0x131d5d07, 0x65130107, 0x341821a4,   // ro.mk.ru_632 ss.la.et_432  en.et.gv_432 fa.ar.ps_433 
  0x5d5f370c, 0x6a020e0d, 0x2a011f0c, 0x09333bac,   // st.tn.ss_543 is.da.haw_554  cy.en.mt_543 so.nn.pl_632 
  0x0a17360c, 0x093b2d0c, 0x230a2204, 0x135404af,   // ab.sr.mk_543 sk.so.pl_543  oc.pt.ca_332 fi.ik.et_655 
  0x51000413, 0x12183dee, 0x040f1302, 0x045e13ad,   // fi.kl.un_650 ku.ar.ur_422  et.lv.fi_222 et.ts.fi_643 
  // [7b70]
  0x18003c13, 0x046453a0, 0x2d3b09a4, 0x0100630b,   // ug.ar.un_650 ht.lg.fi_322  pl.so.sk_433 sco.en.un_520 
  0x47005108, 0x3b013908, 0x370912ee, 0x0f045105,   // kl.sn.un_430 br.en.so_443  hu.pl.st_422 kl.fi.lv_333 
  0x303515ad, 0x64006509, 0x28003d04, 0x645c4704,   // un.tg.uz_643 gv.lg.un_440  ku.sd.un_320 sn.sa.lg_332 
  0x1f000604, 0x06020c07, 0x070a040c, 0x24684cee,   // de.cy.un_320 sv.da.de_432  ru.mk.bg_543 wo.ig.eo_422 
  // [7b80]
  0x3c483760, 0x3c002812, 0x240320ee, 0x5c041302,   // ba.tt.ug_664 sd.ug.un_640  sq.nl.eo_422 et.fi.sa_222 
  0x46041311, 0x0c150604, 0x51130405, 0x09002a19,   // et.fi.qu_653 de.sv.un_320  fi.et.kl_333 mt.pl.un_750 
  0x35003708, 0x5e005a1a, 0x64004702, 0x5a005122,   // ba.tg.un_430 sm.ts.un_760  sn.lg.un_220 kl.sm.un_870 
  0x12000919, 0x0807100d, 0x1504350c, 0x21001809,   // pl.hu.un_750 be.bg.uk_554  tg.ru.un_543 ar.fa.un_440 
  // [7b90]
  0xfc003f21, 0x0d172d07, 0x2d090d08, 0x4438375a,   // af.zzp.un_860 sk.sr.cs_432  cs.pl.sk_443 ba.tk.kk_553 
  0x2c3f1005, 0x170a15ad, 0x25000a12, 0x032c2a0c,   // lt.af.fy_333 un.mk.sr_643  mk.mn.un_640 mt.fy.nl_543 
  0x0a04070c, 0x2b001214, 0x38150412, 0x091c130b,   // bg.ru.mk_543 hu.vi.un_660  ru.tk.un_640 bh.mr.hi_542 
  0x083725a0, 0x23121855, 0x02005d02, 0x63002c21,   // mn.ba.uk_322 ar.ur.ky_442  ss.da.un_220 fy.sco.un_860 
  // [7ba0]
  0x3f6503a0, 0x2c631860, 0x122134ee, 0x3e63010b,   // nl.gv.af_322 ga.sco.fy_664  ps.fa.ur_422 en.sco.rm_542 
  0x38002205, 0x27001904, 0x020163a7, 0x02630107,   // oc.tk.un_330 gl.gd.un_320  sco.en.da_532 en.sco.da_432 
  0x7901630d, 0x481736a0, 0x15000207, 0x30443ca7,   // sco.en.war_554 ab.sr.tt_322  da.un.un_420 ug.kk.uz_532 
  0x233848af, 0x6b007909, 0x20091f02, 0x38003705,   // tt.tk.ky_655 war.ceb.un_440  cy.pl.sq_222 ba.tk.un_330 
  // [7bb0]
  0x6b6301ac, 0x3e2c2707, 0x632c0107, 0x25002314,   // en.sco.ceb_632 gd.fy.rm_432  en.fy.sco_432 ky.mn.un_660 
  0x795801ec, 0xfe630107, 0x23170a04, 0x3d3b23af,   // en.om.war_644 en.sco.tlh_432  mk.sr.ky_332 ky.ks.ku_655 
  0x1548040c, 0x2d001804, 0x0a0715af, 0x180b19ee,   // ru.tt.un_543 ga.sk.un_320  un.bg.mk_655 gl.es.ga_422 
  0x13003804, 0x2f4d3008, 0x28461b05, 0x40003502,   // tk.et.un_320 uz.aa.su_443  tr.qu.sw_333 zu.lb.un_220 
  // [7bc0]
  0x301b31a4, 0x1f007318, 0x1f347304, 0x00006b1c,   // az.tr.uz_433 ny.cy.un_740  ny.xh.cy_332 ceb.un.un_800 
  0x101115ad, 0x284f3805, 0x34357308, 0x353c1508,   // un.ro.be_643 tk.bi.sw_333  ny.zu.xh_443 un.ug.tg_443 
  0x34001f05, 0x5c004b09, 0x1000480d, 0x64003b07,   // cy.xh.un_330 mi.sa.un_440  tt.be.un_540 so.lg.un_420 
  0x09005109, 0x44352305, 0x31004704, 0x567321ad,   // kl.pl.un_440 ky.tg.kk_333  sn.az.un_320 jw.ny.mg_643 
  // [7bd0]
  0x6a00491a, 0x20004809, 0x5f00372c, 0x06001e07,   // to.haw.un_760 tt.sq.un_440  st.tn.un_990 ms.de.un_420 
  0x1b5228a9, 0x2f000408, 0x56002808, 0x19004a04,   // sw.ha.tr_544 fi.su.un_430  sw.mg.un_430 yo.gl.un_320 
  0x56001e08, 0x53367907, 0x174b21a7, 0x3000580c,   // ms.mg.un_430 war.gn.ht_432  jw.mi.sr_532 om.uz.un_530 
  0x42403607, 0x64451ea0, 0x1707080c, 0x48103007,   // gn.lb.co_432 ms.ln.lg_322  uk.bg.sr_543 uz.be.tt_432 
  // [7be0]
  0x343d21ec, 0x73644709, 0x25025eec, 0x25004208,   // fa.ku.ps_644 sn.lg.ny_444  ts.da.eu_644 co.eu.un_430 
  0x684e79a4, 0x4700730c, 0x73281e11, 0x24364a02,   // war.ay.ig_433 ny.sn.un_530  ms.sw.ny_653 yo.gn.eo_222 
  0x5a732107, 0x56001c04, 0x302523a0, 0x6a561ea0,   // jw.ny.sm_432 id.mg.un_320  ky.mn.uz_322 ms.mg.haw_322 
  0x25400aa4, 0x3c342807, 0x032c3fa9, 0x220523ec,   // pt.lb.eu_433 sd.ps.ug_432  af.fy.nl_544 ca.fr.oc_644 
  // [7bf0]
  0x05001222, 0x3748110b, 0x08100aa9, 0x6e211ca0,   // hu.fr.un_870 ro.tt.ba_542  mk.be.uk_544 id.jw.hmn_322 
  0x3615070c, 0x1205220c, 0x2f6e02a0, 0x372344a9,   // bg.ab.un_530 oc.fr.hu_543  da.hmn.su_322 kk.ky.ba_544 
  0x6e003e08, 0x653e6e12, 0x2f001211, 0x1b004819,   // rm.hmn.un_430 hmn.rm.gv_654  hu.su.un_630 tt.tr.un_750 
  0x1c3e6ea7, 0x0522125a, 0x3900130c, 0x3b353402,   // hmn.rm.id_532 hu.oc.fr_553  et.br.un_530 xh.zu.so_222 
  
  // [7c00]
  0x221205a7, 0x01631ca4, 0x0a006e0b, 0x0b000a21,   // fr.hu.oc_532 id.sco.en_433  hmn.pt.un_520 pt.es.un_860 
  0x12002823, 0x03403ba7, 0x230b0504, 0x40003b13,   // sd.ur.un_880 so.lb.nl_532  fr.es.ca_332 so.lb.un_650 
  0x39133b07, 0x3b007305, 0x480710a7, 0x3b000113,   // so.et.br_432 ny.so.un_330  be.bg.tt_532 en.so.un_650 
  0x04151107, 0x192d1ca0, 0x0500122c, 0x0a2f6e04,   // ro.ru.un_420 id.sk.gl_322  hu.fr.un_990 hmn.su.pt_332 
  // [7c10]
  0x0500230c, 0x63017607, 0x34211213, 0x2f05120d,   // ca.fr.un_530 crs.en.sco_432  ur.fa.ps_665 hu.fr.su_554 
  0x43263e08, 0x040a110c, 0x05001219, 0x0e2e0c08,   // rm.ia.ie_443 ro.mk.ru_543  hu.fr.un_750 sv.fo.is_443 
  0x35002805, 0x526365a0, 0x2a3b13a0, 0x03000208,   // sw.zu.un_330 gv.sco.ha_322  et.so.mt_322 da.nl.un_430 
  0x633b3f08, 0x0c000804, 0x473b65a0, 0x13631507,   // af.so.sco_443 no.sv.un_320  gv.so.sn_322 un.sco.et_432 
  // [7c20]
  0x04481507, 0x043517ad, 0x020c2e07, 0x64005602,   // un.tt.ru_432 sr.tg.ru_643  fo.sv.da_432 mg.lg.un_220 
  0x19004702, 0x3b002814, 0x01000304, 0x38311b0d,   // sn.gl.un_220 sd.ks.un_660  nl.en.un_320 tr.az.tk_554 
  0x3f0320a4, 0x0c3903a6, 0x02002408, 0x3c00070d,   // sq.nl.af_433 nl.br.sv_521  eo.da.un_430 bg.ug.un_540 
  0xfc2e0e0c, 0x16002a04, 0x44003c0b, 0x3e022a07,   // is.fo.zzp_543 mt.hr.un_320  ug.kk.un_520 mt.da.rm_432 
  // [7c30]
  0x02403e07, 0x17303c12, 0x033840ac, 0x09000d0b,   // rm.lb.da_432 ug.uz.sr_654  lb.tk.nl_632 ne.hi.un_520 
  0x250a23a9, 0x080a1711, 0x19000a1b, 0x013f1507,   // ca.pt.eu_544 sr.mk.uk_653  pt.gl.un_770 un.af.en_432 
  0x072330a7, 0x041108a9, 0x3f001f12, 0x0e2e2d0c,   // uz.ky.bg_532 uk.ro.ru_544  cy.af.un_640 sk.fo.is_543 
  0x1218210c, 0x15071704, 0x48006e04, 0x25002302,   // fa.ar.ur_543 sr.bg.un_332  hmn.tt.un_320 ky.mn.un_220 
  // [7c40]
  0x232538ee, 0x150448a4, 0x3710230c, 0x3f001804,   // tk.mn.ky_422 tt.ru.un_433  ky.be.ba_543 ga.af.un_320 
  0x250a3655, 0x300735a9, 0x0c001004, 0x35233007,   // ab.mk.mn_442 tg.bg.uz_544  lt.sv.un_320 uz.ky.tg_432 
  0x1f003913, 0xfc000c02, 0x17350707, 0x79106bad,   // br.cy.un_650 sv.zzp.un_220  bg.tg.sr_432 ceb.lt.war_643 
  0x3c00370e, 0x2c1f3f0b, 0x73000108, 0x47001007,   // ba.ug.un_550 af.cy.fy_542  en.ny.un_430 lt.sn.un_420 
  // [7c50]
  0x11153608, 0x44483813, 0x0c000208, 0x1a2c1f04,   // ab.ro.un_430 tk.tt.kk_665  da.sv.un_430 cy.fy.tl_332 
  0x67000913, 0x35303708, 0x3604350c, 0x10006505,   // pl.ak.un_650 ba.uz.tg_443  tg.ru.ab_543 gv.lt.un_330 
  0x041708a4, 0x2d0d0fee, 0x3338fc04, 0x34303d13,   // uk.sr.ru_433 lv.cs.sk_422  zzp.tk.nn_332 ku.uz.ps_665 
  0x5b572bad, 0x033f3ea0, 0x0710380c, 0x050601ec,   // vi.na.sg_643 rm.af.nl_322  tk.be.bg_543 en.de.fr_644 
  // [7c60]
  0x35005505, 0x73477805, 0x0a350404, 0x07113011,   // rw.zu.un_330 ve.sn.ny_333  ru.tg.mk_332 uz.ro.bg_653 
  0x4815045a, 0x19250ba0, 0x190e0a0c, 0x5d001304,   // ru.tt.un_530 es.eu.gl_322  pt.is.gl_543 et.ss.un_320 
  0x202d0d60, 0x33007907, 0x3b653902, 0x190b0a12,   // cs.sk.sq_664 war.nn.un_420  br.gv.so_222 pt.es.gl_654 
  0x37002309, 0x38002522, 0x05004c04, 0x35002804,   // ky.ba.un_440 mn.tk.un_870  wo.fr.un_320 sw.zu.un_320 
  // [7c70]
  0x12002f08, 0x45000512, 0x171510ec, 0x0d007525,   // su.hu.un_430 fr.ln.un_640  be.sr.un_640 nso.cs.un_920 
  0x2f1c21a4, 0x2933080e, 0x37040807, 0x39002c09,   // jw.id.su_433 no.nn.sl_555  uk.ru.ba_432 fy.br.un_440 
  0x21183da7, 0x08002008, 0x252c02ee, 0x12000e09,   // ku.ar.fa_532 sq.no.un_430  da.fy.eu_422 is.hu.un_440 
  0x25271102, 0x364c120c, 0x18343060, 0x06000105,   // ro.gd.eu_222 hu.wo.gn_543  uz.ps.ar_664 en.de.un_330 
  // [7c80]
  0x25005604, 0x19360ba9, 0x44153c0c, 0x18112707,   // mg.eu.un_320 es.gn.gl_544  ug.kk.un_530 gd.ro.ga_432 
  0x0b002807, 0x10080402, 0x35003b04, 0x01001302,   // sw.es.un_420 ru.uk.be_222  so.zu.un_320 et.en.un_220 
  0x52000e08, 0x111827af, 0x44233c07, 0x4d0e3b08,   // is.ha.un_430 gd.ga.ro_655  ug.ky.kk_432 so.is.aa_443 
  0x06001502, 0x65001f02, 0x2f0e360b, 0x65000105,   // un.de.un_220 cy.gv.un_220  gn.is.su_542 en.gv.un_330 
  // [7c90]
  0x35043cee, 0x3d343007, 0x4c00050c, 0x2242050c,   // ug.ru.tg_422 uz.ps.ku_432  fr.wo.un_530 fr.co.oc_543 
  0x160555ee, 0x172d0d0c, 0x53420505, 0x20004704,   // rw.fr.hr_422 cs.sk.sr_543  fr.co.ht_333 sn.sq.un_320 
  0x40304607, 0x3e005308, 0x1200fc04, 0x2e0e0ca6,   // qu.uz.lb_432 ht.rm.un_430  zzp.hu.un_320 sv.is.fo_521 
  0x083004a4, 0x0c033302, 0x362f21ad, 0x2a0139a6,   // ru.uz.uk_433 nn.nl.sv_222  jw.su.gn_643 br.en.mt_521 
  // [7ca0]
  0x12000509, 0x20003b04, 0x2f360eb3, 0x383b460c,   // fr.hu.un_440 so.sq.un_320  is.gn.su_743 qu.so.tk_543 
  0x026a1a07, 0x64282f13, 0x0c333e07, 0x2000fc05,   // tl.haw.da_432 su.sw.lg_665  rm.nn.sv_432 zzp.sq.un_330 
  0x212f020c, 0x1a217909, 0x31003b02, 0x6400fc02,   // da.su.jw_543 war.jw.tl_444  so.az.un_220 zzp.lg.un_220 
  0x021213a0, 0x4762520c, 0x5efe6407, 0x503b5205,   // et.hu.da_322 ha.kha.sn_543  lg.tlh.ts_432 ha.so.fj_333 
  // [7cb0]
  0x2f4f39ec, 0x793e0aa7, 0x230219a6, 0x2f6b5202,   // br.bi.su_644 pt.rm.war_532  gl.da.ca_521 ha.ceb.su_222 
  0x360b05a4, 0x23001207, 0x64397355, 0xfe004c07,   // fr.es.gn_433 hu.ca.un_420  ny.br.lg_442 wo.tlh.un_420 
  0x2a002902, 0x074410ee, 0x211e1c09, 0x48004422,   // sl.mt.un_220 be.kk.bg_422  id.ms.jw_444 kk.tt.un_870 
  0x1800340e, 0x482f05ee, 0x212f4607, 0x25735f0c,   // ps.ar.un_550 fr.su.tt_422  qu.su.jw_432 tn.ny.eu_543 
  // [7cc0]
  0x421905ec, 0xfe002819, 0xfc00130c, 0xfe004a13,   // fr.gl.co_644 sw.tlh.un_750  et.zzp.un_530 yo.tlh.un_650 
  0x5c2f1a0c, 0x42073ead, 0x781a33a0, 0xfc00460b,   // tl.su.sa_543 rm.it.co_643  nn.tl.ve_322 qu.zzp.un_520 
  0x2a002708, 0x39273e04, 0xfc001307, 0x38004008,   // gd.mt.un_430 rm.gd.br_332  et.zzp.un_420 lb.tk.un_430 
  0x27005809, 0x052112ac, 0x65002a0d, 0x07101708,   // om.gd.un_440 hu.jw.fr_632  mt.gv.un_540 sr.be.bg_443 
  // [7cd0]
  0x3b15fcee, 0x0a070808, 0x36000502, 0x0d050a04,   // zzp.so.un_420 uk.bg.mk_443  fr.gn.un_220 pt.fr.cs_332 
  0x3007110c, 0x4c2f21a4, 0x0e002f04, 0x0d321705,   // ro.bg.uz_543 jw.su.wo_433  su.is.un_320 sr.bs.cs_333 
  0x21002f0c, 0x31003805, 0x12002102, 0x08153604,   // su.jw.un_530 tk.az.un_330  jw.hu.un_220 ab.uk.un_320 
  0x0b0a12b2, 0x48003c21, 0x3000370d, 0x1c135c0e,   // hu.pt.es_732 ug.tt.un_860  ba.uz.un_540 sa.bh.mr_555 
  // [7ce0]
  0x1538305a, 0x2f000e04, 0x2e0c0eee, 0x12183bee,   // uz.tk.un_553 is.su.un_320  is.sv.fo_422 ks.ar.ur_422 
  0x2330360b, 0x36000b08, 0x24280204, 0x4a335aee,   // ab.uz.ky_542 es.gn.un_430  da.sw.eo_332 sm.nn.yo_422 
  0x23153c07, 0x10003008, 0x6b681d07, 0x363c3008,   // ug.ky.un_420 uz.be.un_430  la.ig.ceb_432 uz.ug.ab_443 
  0x30173c0c, 0x37483812, 0x443815ad, 0x64001804,   // ug.sr.uz_543 tk.tt.ba_654  un.tk.kk_643 ga.lg.un_320 
  // [7cf0]
  0x53360507, 0x214a12a0, 0x02006219, 0x05004a07,   // fr.gn.ht_432 hu.yo.jw_322  kha.da.un_750 yo.fr.un_420 
  0x1004150c, 0x05000a12, 0x28181202, 0x1200fc05,   // un.ru.be_543 pt.fr.un_640  ur.ar.sd_222 zzp.hu.un_330 
  0x21004c08, 0x123b2808, 0x04380805, 0x0a000509,   // wo.jw.un_430 sd.ks.ur_443  uk.tk.ru_333 fr.pt.un_440 
  0x120c0607, 0x422f05a6, 0x3b002e13, 0x300204ec,   // de.sv.hu_432 fr.su.co_521  fo.so.un_650 fi.da.uz_644 
  // [7d00]
  0x17160d02, 0x4c122fa4, 0x48300407, 0x040815a9,   // cs.hr.sr_222 su.hu.wo_433  fi.uz.tt_432 un.uk.ru_544 
  0x65420704, 0x04006404, 0x301b31a0, 0x09135cee,   // it.co.gv_332 lg.fi.un_320  az.tr.uz_322 sa.bh.hi_422 
  0x045851a7, 0x34234402, 0x080a07ad, 0x38233caf,   // kl.om.fi_532 kk.ky.ps_222  bg.mk.uk_643 ug.ky.tk_655 
  0x381b31ee, 0x30007919, 0x050a0ea0, 0xfe003114,   // az.tr.tk_422 war.uz.un_750  is.pt.fr_322 az.tlh.un_660 
  // [7d10]
  0x2e003002, 0x04170a08, 0x21004c13, 0x2338300c,   // uz.fo.un_220 mk.sr.ru_443  wo.jw.un_650 uz.tk.ky_543 
  0x30183407, 0x0410650d, 0x1b481113, 0x073811a7,   // ps.ar.uz_432 gv.lt.fi_554  ro.tt.tr_665 ro.tk.bg_532 
  0x352337a4, 0x09003808, 0x08073804, 0x330809a4,   // ba.ky.tg_433 tk.pl.un_430  tk.bg.uk_332 pl.no.nn_433 
  0x190a4ca0, 0x103536a4, 0x082315a6, 0x34212302,   // wo.pt.gl_322 ab.tg.be_433  un.ky.uk_521 ky.fa.ps_222 
  // [7d20]
  0x2f001802, 0x380b2002, 0x2400370c, 0x1e301caf,   // ga.su.un_220 sq.es.tk_222  st.eo.un_530 id.uz.ms_655 
  0x210e1207, 0x15004829, 0x190b12a0, 0x6563130c,   // hu.is.jw_432 tt.un.un_960  hu.es.gl_322 et.sco.gv_543 
  0x1d005f04, 0x0d001012, 0x65016312, 0x48004308,   // tn.la.un_320 lt.cs.un_640  sco.en.gv_654 ie.tt.un_430 
  0x44233811, 0x30343dad, 0x252f1e02, 0x183f01a7,   // tk.ky.kk_653 ku.ps.uz_643  ms.su.eu_222 en.af.ga_532 
  // [7d30]
  0x5e784608, 0x375d08a4, 0x36002f08, 0x4a1d400c,   // qu.ve.ts_443 no.ss.st_433  su.gn.un_430 lb.la.yo_543 
  0x345c3504, 0x12002f12, 0x2f36120c, 0x35004f0d,   // zu.sa.xh_332 su.hu.un_640  hu.gn.su_543 bi.zu.un_540 
  0x31464e07, 0x5c007307, 0x75375f14, 0x353402a4,   // ay.qu.az_432 ny.sa.un_420  tn.st.nso_666 da.xh.zu_433 
  0x1d4a78a9, 0x190a0b05, 0x5307760c, 0x20523208,   // ve.yo.la_544 es.pt.gl_333  crs.it.ht_543 bs.ha.sq_443 
  // [7d40]
  0xfc583bee, 0x60033fa9, 0x56536402, 0x07643807,   // so.om.zzp_422 af.nl.vo_544  lg.ht.mg_222 tk.lg.it_432 
  0xfe476707, 0x131f0107, 0x35453404, 0x53002205,   // ak.sn.tlh_432 en.cy.et_432  xh.ln.zu_332 oc.ht.un_330 
  0x5e001d05, 0x755f370d, 0x3f553704, 0x65333ea0,   // la.ts.un_330 st.tn.nso_554  st.rw.af_332 rm.nn.gv_322 
  0x5e004607, 0x2e003609, 0x18002734, 0x05002205,   // qu.ts.un_420 gn.fo.un_440  gd.ga.un_A80 oc.fr.un_330 
  // [7d50]
  0x250742a0, 0x1d2462ee, 0x5f377509, 0x423e0707,   // co.it.eu_322 kha.eo.la_422  nso.st.tn_444 it.rm.co_432 
  0x2518270c, 0x556b020c, 0x182527af, 0x08005c0c,   // gd.ga.eu_543 da.ceb.rw_543  gd.eu.ga_655 sa.no.un_530 
  0x4700fe08, 0x5d005e23, 0x12213d09, 0x2d5f0d12,   // tlh.sn.un_430 ts.ss.un_880  ku.fa.ur_444 cs.tn.sk_654 
  0x04002e13, 0x183c2307, 0x5a002504, 0x18052713,   // fo.fi.un_650 ky.ug.ar_432  eu.sm.un_320 gd.fr.ga_665 
  // [7d60]
  0x2500150c, 0x47002005, 0x072a4208, 0x38003904,   // un.mn.un_530 sq.sn.un_330  co.mt.it_443 br.tk.un_320 
  0x11000209, 0x322c18ee, 0x2c2518a4, 0x1d27250c,   // da.ro.un_440 ga.fy.bs_422  ga.eu.fy_433 eu.gd.la_543 
  0x1d0b2608, 0x48111007, 0x05000108, 0xfc005c05,   // ia.es.la_443 be.ro.tt_432  en.fr.un_430 sa.zzp.un_330 
  0x4b3724a4, 0x123418af, 0x36280d07, 0x292024ee,   // eo.st.mi_433 ar.ps.ur_655  cs.sw.gn_432 eo.sq.sl_422 
  // [7d70]
  0x105a69ad, 0x0b3e0707, 0x01003607, 0x1e001104,   // mfe.sm.lt_643 it.rm.es_432  gn.en.un_420 ro.ms.un_320 
  0x6b681da4, 0x5300360e, 0x303d120c, 0x5a0a2007,   // la.ig.ceb_433 gn.ht.un_550  ur.ku.uz_543 sq.pt.sm_432 
  0x1c2f55a0, 0x5d00fc08, 0x5e6278ec, 0x15043614,   // rw.su.id_322 zzp.ss.un_430  ve.kha.ts_644 ab.ru.un_666 
  0x5c00101a, 0x49006a09, 0xfc005e13, 0x28214404,   // lt.sa.un_760 haw.to.un_440  ts.zzp.un_650 kk.fa.sd_332 
  // [7d80]
  0x042348a7, 0x12002305, 0xfc386704, 0x37644e07,   // tt.ky.ru_532 ky.ur.un_330  ak.tk.zzp_332 ay.lg.st_432 
  0x53001f23, 0x3b00fc02, 0x47fc1e0c, 0x075369ee,   // cy.ht.un_880 zzp.so.un_220  ms.zzp.sn_543 mfe.ht.it_422 
  0x3d234404, 0x2304150d, 0x3c1823a4, 0x0f004d0d,   // kk.ky.ku_332 un.ru.ky_554  ky.ar.ug_433 aa.lv.un_540 
  0xfc005e12, 0xfc007313, 0x21460fa0, 0x5e75fc0c,   // ts.zzp.un_640 ny.zzp.un_650  lv.qu.jw_322 zzp.nso.ts_543 
  // [7d90]
  0x1d004204, 0x0639480c, 0x0d3bfe07, 0x3555fc07,   // co.la.un_320 tt.br.de_543  tlh.so.cs_432 zzp.rw.zu_432 
  0x11003e12, 0x24005c05, 0xfc005819, 0x190f0b07,   // rm.ro.un_640 sa.eo.un_330  om.zzp.un_750 es.lv.gl_432 
  0x08001505, 0x0b0a43af, 0x024207af, 0x05003904,   // un.uk.un_330 ie.pt.es_655  it.co.da_655 br.fr.un_320 
  0x1b001f12, 0x30004408, 0x1e084e0b, 0x3700110c,   // cy.tr.un_640 kk.uz.un_430  ay.no.ms_542 ro.ba.un_530 
  // [7da0]
  0x0f003e02, 0x10040808, 0xfe02060b, 0x36fe12a0,   // rm.lv.un_220 uk.ru.be_443  de.da.tlh_542 hu.tlh.gn_322 
  0x39002d14, 0x13001502, 0x18342802, 0x07003e05,   // sk.br.un_660 un.et.un_220  sd.ps.ar_222 rm.it.un_330 
  0x102d0d0c, 0x40330107, 0x07351704, 0x40001313,   // cs.sk.lt_543 en.nn.lb_432  sr.tg.bg_332 et.lb.un_650 
  0x06007904, 0x090d13ee, 0x5f3709a4, 0x1b3340a4,   // war.de.un_320 bh.ne.hi_422  pl.st.tn_433 lb.nn.tr_433 
  // [7db0]
  0x2a630607, 0x405f3704, 0x01006505, 0x0d0913ec,   // de.sco.mt_432 st.tn.lb_332  gv.en.un_330 bh.hi.ne_644 
  0x25003609, 0x3e072504, 0x112507a0, 0x38354804,   // ab.mn.un_440 eu.it.rm_332  it.eu.ro_322 tt.tg.tk_332 
  0x45252da7, 0x1c1e2555, 0x24392507, 0x56102004,   // sk.eu.ln_532 eu.ms.id_442  eu.br.eo_432 sq.lt.mg_332 
  0x21121855, 0x384301a9, 0x11073e04, 0x5a006307,   // ar.ur.fa_442 en.ie.tk_544  rm.it.ro_332 sco.sm.un_420 
  // [7dc0]
  0x37381707, 0x53002f02, 0x343018af, 0x56000909,   // sr.tk.ba_432 su.ht.un_220  ar.uz.ps_655 pl.mg.un_440 
  0x113e07af, 0x30002c08, 0x30283404, 0x024734a4,   // it.rm.ro_655 fy.uz.un_430  xh.sw.uz_332 xh.sn.da_433 
  0x12694205, 0x68526407, 0x56122808, 0x07202507,   // co.mfe.hu_333 lg.ha.ig_432  sw.hu.mg_443 eu.sq.it_432 
  0x00007924, 0x00005d01, 0x3e072d07, 0x48004007,   // war.un.un_900 ss.un.un_200  sk.it.rm_432 lb.tt.un_420 
  // [7dd0]
  0x78002d08, 0x116864ee, 0x734c60ec, 0x11252dee,   // sk.ve.un_430 lg.ig.ro_422  vo.wo.ny_644 sk.eu.ro_422 
  0x303108a0, 0x47005604, 0x6800120d, 0x5a362ea4,   // no.az.uz_322 mg.sn.un_320  hu.ig.un_540 fo.gn.sm_433 
  0x25002d05, 0x2847640d, 0x072511a4, 0x313073a0,   // sk.eu.un_330 lg.sn.sw_554  ro.eu.it_433 ny.uz.az_322 
  0x31006b08, 0x121334a0, 0x2f004602, 0x09001207,   // ceb.az.un_430 xh.et.hu_322  qu.su.un_220 hu.pl.un_420 
  // [7de0]
  0x5a000307, 0x07642a0e, 0x2f003908, 0x30233c13,   // nl.sm.un_420 mt.lg.it_555  br.su.un_430 ug.ky.uz_665 
  0x291b2002, 0x15443705, 0x0a1347ee, 0x30003704,   // sq.tr.sl_222 ba.kk.un_333  sn.et.pt_422 ba.uz.un_320 
  0x5f73280c, 0x6b791aaf, 0x02572807, 0x69000d08,   // sw.ny.tn_543 tl.war.ceb_655  sw.na.da_432 cs.mfe.un_430 
  0x21002f04, 0x2b004609, 0x51315802, 0x38000907,   // su.jw.un_320 qu.vi.un_440  om.az.kl_222 pl.tk.un_420 
  // [7df0]
  0x09000d22, 0x070a15a9, 0x1000070e, 0xfc302aa4,   // ne.hi.un_870 un.mk.bg_544  bg.be.un_550 mt.uz.zzp_433 
  0x06080207, 0x20400607, 0x0a171507, 0x043635ad,   // da.no.de_432 de.lb.sq_432  un.sr.mk_432 tg.ab.ru_643 
  0x013f02ee, 0x481004ee, 0x2e330802, 0x48171107,   // da.af.en_422 ru.be.tt_422  no.nn.fo_222 ro.sr.tt_432 
  0x3b24fca9, 0x29001607, 0x0a1737a4, 0x08072513,   // zzp.eo.so_544 hr.sl.un_420  ba.sr.mk_433 mn.bg.uk_665 
  // [7e00]
  0x01656311, 0x283b1205, 0x36002c04, 0x3e000304,   // sco.gv.en_653 ur.ks.sd_333  fy.gn.un_320 nl.rm.un_320 
  0x1f001507, 0x0e330ca0, 0x2300fc19, 0x7300500e,   // un.cy.un_420 sv.nn.is_322  zzp.ca.un_750 fj.ny.un_550 
  0x3d443c08, 0x3800150e, 0x3302fcee, 0x5955470c,   // ug.kk.ku_443 un.tk.un_550  zzp.da.nn_422 sn.rw.rn_543 
  0x4300731a, 0x0200fc08, 0x17150a5a, 0x343f1204,   // ny.ie.un_760 zzp.da.un_430  mk.sr.un_530 hu.af.xh_332 
  // [7e10]
  0x314658ee, 0x163029ee, 0x07150aec, 0x170708a9,   // om.qu.az_422 sl.uz.hr_422  mk.bg.un_640 uk.bg.sr_544 
  0x3800620c, 0x08001f07, 0x100938a0, 0x173435ad,   // kha.tk.un_530 cy.no.un_420  tk.pl.lt_322 zu.xh.sr_643 
  0x20001f09, 0x102e38ee, 0x0c001f07, 0x10001713,   // cy.sq.un_440 tk.fo.lt_422  cy.sv.un_420 sr.be.un_650 
  0x381009ec, 0x042317ee, 0x0839100c, 0x5e00450e,   // pl.lt.tk_644 sr.ky.ru_422  lt.br.no_543 ln.ts.un_550 
  // [7e20]
  0x0a353ca4, 0x171523af, 0x47001002, 0x3d122155,   // ug.tg.mk_433 ky.sr.un_650  lt.sn.un_220 fa.ur.ku_442 
  0x375f7513, 0x0807100c, 0x252338a6, 0x483738af,   // nso.tn.st_665 be.bg.uk_543  tk.ky.mn_521 tk.ba.tt_655 
  0x64004d0d, 0x09001c1a, 0x09005c0e, 0x1200100c,   // aa.lg.un_540 mr.hi.un_760  sa.hi.un_550 lt.hu.un_530 
  0x34003d11, 0x64492807, 0x49006a2a, 0x524c5b07,   // ku.ps.un_630 sw.to.lg_432  haw.to.un_970 sg.wo.ha_432 
  // [7e30]
  0x675a64ec, 0x504c6408, 0x040a07ee, 0x64004b07,   // lg.sm.ak_644 lg.wo.fj_443  bg.mk.ru_422 mi.lg.un_420 
  0x0e000309, 0x310f1b07, 0x674c4dec, 0x4c006413,   // nl.is.un_440 tr.lv.az_432  aa.wo.ak_644 lg.wo.un_650 
  0x28000f22, 0x102852a7, 0x48234408, 0x0408380d,   // lv.sw.un_870 ha.sw.lt_532  kk.ky.tt_443 tk.uk.ru_554 
  0x10004421, 0x5d73350c, 0x425e4c09, 0x345f460d,   // kk.be.un_860 zu.ny.ss_543  wo.ts.co_444 qu.tn.xh_554 
  // [7e40]
  0x73374d05, 0x78353409, 0x06000204, 0x64203708,   // aa.st.ny_333 xh.zu.ve_444  da.de.un_320 st.sq.lg_443 
  0x68287307, 0x1c5537a0, 0x73005012, 0x45005033,   // ny.sw.ig_432 st.rw.id_322  fj.ny.un_640 fj.ln.un_A70 
  0x315e5507, 0x7335640c, 0x311b54a0, 0x0b4643a0,   // rw.ts.az_432 lg.zu.ny_543  ik.tr.az_322 ie.qu.es_322 
  0x5e6768a9, 0x35786a0c, 0x375f5ea9, 0x1d075007,   // ig.ak.ts_544 haw.ve.zu_543  ts.tn.st_544 fj.it.la_432 
  // [7e50]
  0x68675214, 0x2f434f0c, 0x35641ca0, 0x731e50ee,   // ha.ak.ig_666 bi.ie.su_543  id.lg.zu_322 fj.ms.ny_422 
  0x00004d06, 0x01151308, 0x735a51a4, 0x494b5aaf,   // aa.un.un_400 et.en.un_430  kl.sm.ny_433 sm.mi.to_655 
  0x6320490d, 0x5e5d35a4, 0x0e432e09, 0x22454a08,   // to.sq.sco_554 zu.ss.ts_433  fo.ie.is_444 yo.ln.oc_443 
  0x080273a4, 0x6451450c, 0x2f521b04, 0x353443a9,   // ny.da.no_433 ln.kl.lg_543  tr.ha.su_332 ie.xh.zu_544 
  // [7e60]
  0x53632811, 0x05264308, 0x25003622, 0x30072307,   // sw.sco.ht_653 ie.ia.fr_443  ab.mn.un_870 ky.bg.uz_432 
  0x48007308, 0x4352250d, 0x1d630112, 0x4a525f07,   // ny.tt.un_430 eu.ha.ie_554  en.sco.la_654 tn.ha.yo_432 
  0x6a62490d, 0x09382aa0, 0x112315a4, 0x355e340d,   // to.kha.haw_554 mt.tk.pl_322  un.ky.ro_433 xh.ts.zu_554 
  0x1d135008, 0x69130414, 0x0b763804, 0x30002102,   // fj.et.la_443 fi.et.mfe_666  tk.crs.es_332 jw.uz.un_220 
  // [7e70]
  0x7335340d, 0x2e0e51a9, 0x115134a4, 0x1d00090c,   // xh.zu.ny_554 kl.is.fo_544  xh.kl.ro_433 pl.la.un_530 
  0x5a431ca4, 0x383121a7, 0x3c3023af, 0x306425ee,   // id.ie.sm_433 jw.az.tk_532  ky.uz.ug_655 eu.lg.uz_422 
  0x33082eee, 0x07100808, 0x35100855, 0x0a08070e,   // fo.no.nn_422 uk.be.bg_443  uk.be.tg_442 bg.uk.mk_555 
  0x095c13a4, 0x2f004c08, 0x07000807, 0x6b002a04,   // bh.sa.hi_433 wo.su.un_430  uk.bg.un_420 mt.ceb.un_320 
  // [7e80]
  0x06024007, 0x07040a05, 0x0b002a04, 0x21343dac,   // lb.da.de_432 mk.ru.bg_333  mt.es.un_320 ku.ps.fa_632 
  0x39006111, 0x39136307, 0x3034120b, 0x56000a07,   // za.br.un_630 sco.et.br_432  ur.ps.uz_542 pt.mg.un_420 
  0x0f000d12, 0x3400301a, 0x2a004a05, 0x38003008,   // cs.lv.un_640 uz.ps.un_760  yo.mt.un_330 uz.tk.un_430 
  0x15170a07, 0x33630155, 0x35383608, 0x3c1830a7,   // mk.sr.un_432 en.sco.nn_442  ab.tk.tg_443 uz.ar.ug_532 
  // [7e90]
  0xfc003f08, 0x52004a04, 0x130d5cee, 0x2c0f03a0,   // af.zzp.un_430 yo.ha.un_320  sa.ne.bh_422 nl.lv.fy_322 
  0x31004702, 0x1f003912, 0x17002909, 0x10041514,   // sn.az.un_220 br.cy.un_640  sl.sr.un_440 un.ru.be_666 
  0x35007321, 0x54005114, 0x56000a08, 0x0a001807,   // ny.zu.un_860 kl.ik.un_660  pt.mg.un_430 ga.pt.un_420 
  0x18001119, 0x6525110c, 0x12002a04, 0x27001822,   // ro.ga.un_750 ro.eu.gv_543  mt.hu.un_320 ga.gd.un_870 
  // [7ea0]
  0x5d34470c, 0x18002714, 0x4d00680e, 0x40000108,   // sn.xh.ss_543 gd.ga.un_660  ig.aa.un_550 en.lb.un_430 
  0x25006504, 0x2200050d, 0x18002712, 0x55006123,   // gv.eu.un_320 fr.oc.un_540  gd.ga.un_640 za.rw.un_880 
  0x53004713, 0xfa353460, 0x4612fc07, 0x285535a0,   // sn.ht.un_650 xh.zu.nr_664  zzp.hu.qu_432 zu.rw.sw_322 
  0x020301a4, 0x5d353411, 0x58644cee, 0x55005e2a,   // en.nl.da_433 xh.zu.ss_653  wo.lg.om_422 ts.rw.un_970 
  // [7eb0]
  0x1200fc0e, 0x3308020d, 0x55003b0c, 0x2a63010b,   // zzp.hu.un_550 da.no.nn_554  so.rw.un_530 en.sco.mt_542 
  0x11004708, 0x252711a0, 0x12000202, 0x584c4d60,   // sn.ro.un_430 ro.gd.eu_322  da.hu.un_220 aa.wo.om_664 
  0x49005a0c, 0x0a070804, 0x2400030d, 0x34000408,   // sm.to.un_530 uk.bg.mk_332  nl.eo.un_540 fi.xh.un_430 
  0x135c09a0, 0x44481508, 0x1b6230a4, 0x59554c0e,   // hi.sa.bh_322 un.tt.kk_443  uz.kha.tr_433 wo.rw.rn_555 
  // [7ec0]
  0x3b481bec, 0x04364504, 0xfc120907, 0x4830795a,   // tr.tt.so_644 ln.gn.fi_332  pl.hu.zzp_432 war.uz.tt_553 
  0x28213ba0, 0x1f383311, 0x30003b0e, 0x13005005,   // ks.fa.sd_322 nn.tk.cy_653  so.uz.un_550 fj.et.un_330 
  0xfc000804, 0x65023b07, 0x1248fca4, 0x47001304,   // no.zzp.un_320 so.da.gv_432  zzp.tt.hu_433 et.sn.un_320 
  0x01026304, 0x2e1f33ec, 0x11001318, 0x0a001007,   // sco.da.en_332 nn.cy.fo_644  et.ro.un_740 be.mk.un_420 
  // [7ed0]
  0x483b380c, 0xfe314d12, 0x302b3b08, 0x30000213,   // tk.so.tt_543 aa.az.tlh_654  so.vi.uz_443 da.uz.un_650 
  0x1b316908, 0x3d3c2311, 0x6b6830a4, 0x304831ec,   // mfe.az.tr_443 ky.ug.ku_653  uz.ig.ceb_433 az.tt.uz_644 
  0xfe4d3804, 0x0a1736ee, 0x2e040eee, 0x34183d08,   // tk.aa.tlh_332 ab.sr.mk_422  is.fi.fo_422 ku.ar.ps_443 
  0x33003804, 0x0400380d, 0x213b1211, 0x2d002902,   // tk.nn.un_320 tk.ru.un_540  ur.ks.fa_653 sl.sk.un_220 
  // [7ee0]
  0x026e2ea0, 0x15003514, 0x4e005214, 0x1500290e,   // fo.hmn.da_322 tg.un.un_660  ha.ay.un_660 sl.un.un_550 
  0x281234ec, 0x183444a0, 0x2d0dfea6, 0x461b5212,   // ps.ur.sd_644 kk.ps.ar_322  tlh.cs.sk_521 ha.tr.qu_654 
  0x56003009, 0x0d091c13, 0x182812a9, 0x68004a1b,   // uz.mg.un_440 mr.hi.ne_665  ur.sd.ar_544 yo.ig.un_770 
  0x30120f02, 0x3c374809, 0x123d30ee, 0x4a685bad,   // lv.hu.uz_222 tt.ba.ug_444  uz.ku.ur_422 sg.ig.yo_643 
  // [7ef0]
  0x25230aa0, 0x68004a13, 0x440425a0, 0x040838a4,   // mk.ky.mn_322 yo.ig.un_650  mn.ru.kk_322 tk.uk.ru_433 
  0x373c4409, 0x091c0da7, 0x230a17ee, 0x233c2555,   // kk.ug.ba_444 ne.mr.hi_532  sr.mk.ky_422 mn.ug.ky_442 
  0x18122355, 0x44234804, 0x3b000914, 0x2b00670d,   // ky.ur.ar_442 tt.ky.kk_332  hi.ks.un_660 ak.vi.un_540 
  0x2f005802, 0x353456a4, 0x2c004c04, 0x244258ec,   // om.su.un_220 mg.xh.zu_433  wo.fy.un_320 om.co.eo_644 
  // [7f00]
  0x580f4d07, 0x1c002f0c, 0x1f2f1c04, 0x2a004802,   // aa.lv.om_432 su.id.un_530  id.su.cy_332 tt.mt.un_220 
  0x132f42a0, 0x213412ad, 0x02006707, 0x2f001311,   // co.su.et_322 ur.ps.fa_643  ak.da.un_420 et.su.un_630 
  0x08371005, 0x1f00020e, 0x24001104, 0x1c211e0c,   // be.ba.uk_333 da.cy.un_550  ro.eo.un_320 ms.jw.id_543 
  0x5e006714, 0x075325ee, 0x03000408, 0x44302307,   // ak.ts.un_660 eu.ht.it_422  fi.nl.un_430 ky.uz.kk_432 
  // [7f10]
  0x230a1704, 0x0f004b12, 0x060f2c04, 0x35004605,   // sr.mk.ky_332 mi.lv.un_640  fy.lv.de_332 qu.zu.un_330 
  0x1f1301a0, 0x133f3bee, 0x1700080b, 0x03001f04,   // en.et.cy_322 so.af.et_422  uk.sr.un_520 cy.nl.un_320 
  0x2ffe6808, 0x1e1c6ea4, 0x1c09130e, 0x302134ec,   // ig.tlh.su_443 hmn.id.ms_433  bh.hi.mr_555 ps.fa.uz_644 
  0x372f3502, 0x68006712, 0x09135c07, 0x64006714,   // zu.su.st_222 ak.ig.un_640  sa.bh.hi_432 ak.lg.un_660 
  // [7f20]
  0x2f2146ee, 0x44483704, 0x12343008, 0x67006834,   // qu.jw.su_422 ba.tt.kk_332  uz.ps.ur_443 ig.ak.un_A80 
  0x02016304, 0x33051e04, 0x67002f20, 0x092d3b12,   // sco.en.da_332 ms.fr.nn_332  su.ak.un_850 so.sk.pl_654 
  0x5c004713, 0x045c0e07, 0x20045c12, 0x04480807,   // sn.sa.un_650 is.sa.fi_432  sa.fi.sq_654 uk.tt.ru_432 
  0x04475c07, 0x6e003012, 0x041347a4, 0x01036ba4,   // sa.sn.fi_432 uz.hmn.un_640  sn.et.fi_433 ceb.nl.en_433 
  // [7f30]
  0x5c002d14, 0x65011307, 0x100c0ead, 0x1824270c,   // sk.sa.un_660 et.en.gv_432  is.sv.lt_643 gd.eo.ga_543 
  0x39000309, 0xfe0b02a0, 0x48093ba0, 0x1e1c300c,   // nl.br.un_440 da.es.tlh_322  so.pl.tt_322 uz.id.ms_543 
  0x2d4658a0, 0x23041107, 0x351a6bad, 0x330862a4,   // om.qu.sk_322 ro.ru.ky_432  ceb.tl.zu_643 kha.no.nn_433 
  0x050e690c, 0x074201a4, 0x080210a4, 0x4d00fe0e,   // mfe.is.fr_543 en.co.it_433  lt.da.no_433 tlh.aa.un_550 
  // [7f40]
  0x15004818, 0x12475cec, 0x431f01a0, 0x3f060ea0,   // tt.un.un_740 sa.sn.hu_644  en.cy.ie_322 is.de.af_322 
  0x2a2218ee, 0x3f020e07, 0x20475c04, 0x13045ca7,   // ga.oc.mt_422 is.da.af_432  sa.sn.sq_332 sa.fi.et_532 
  0x0e5c4708, 0x15000a12, 0x103515a9, 0x79004d08,   // sn.sa.is_443 pt.un.un_640  un.tg.be_544 aa.war.un_430 
  0x0d1f650c, 0x6b6309a7, 0x064004a0, 0x02083307,   // gv.cy.cs_543 pl.sco.ceb_532  fi.lb.de_322 nn.no.da_432 
  // [7f50]
  0x3035170c, 0x21281204, 0x080715ee, 0x33000b2b,   // sr.tg.uz_543 ur.sd.fa_332  un.bg.uk_422 bn.as.un_980 
  0x35041007, 0x35170a0c, 0x350715a7, 0x232b6304,   // be.ru.tg_432 mk.sr.tg_543  un.bg.tg_532 sco.vi.ca_332 
  0x13004b04, 0x796a5f07, 0x28005a21, 0x3b004c05,   // mi.et.un_320 tn.haw.war_432  sm.sw.un_860 wo.so.un_330 
  0x46790907, 0x4d002a22, 0x4a4c54ee, 0x233504ee,   // pl.war.qu_432 mt.aa.un_870  ik.wo.yo_422 ru.tg.ky_422 
  // [7f60]
  0x10303504, 0x36475a07, 0x3b4e3007, 0x28565a04,   // tg.uz.be_332 sm.sn.gn_432  uz.ay.so_432 sm.mg.sw_332 
  0x07081708, 0x183430a6, 0x0a3530af, 0x15001034,   // sr.uk.bg_443 uz.ps.ar_521  uz.tg.mk_655 be.un.un_A80 
  0x28180212, 0x18443c16, 0x08072307, 0x4c58650c,   // ja.ar.sd_654 ug.kk.ar_752  ky.bg.uk_432 gv.om.wo_543 
  0x082311ad, 0x37003c0e, 0x3b655807, 0x37001120,   // ro.ky.uk_643 ug.ba.un_550  om.gv.so_432 ro.ba.un_850 
  // [7f70]
  0x39000507, 0x12430607, 0x362223ad, 0x10003802,   // fr.br.un_420 de.ie.hu_432  ca.oc.gn_643 tk.lt.un_220 
  0x170710ad, 0x53006911, 0x07234407, 0x48381b0c,   // be.bg.sr_643 mfe.ht.un_630  kk.ky.bg_432 tr.tk.tt_543 
  0x2a000704, 0x243828ee, 0x37252307, 0x1200fc12,   // it.mt.un_320 sw.tk.eo_422  ky.mn.ba_432 zzp.hu.un_640 
  0x431a3e05, 0x404c6308, 0x73000c07, 0x2e002802,   // rm.tl.ie_333 sco.wo.lb_443  sv.ny.un_420 sw.fo.un_220 
  // [7f80]
  0x050f5707, 0x29160d07, 0x35150413, 0x55002807,   // na.lv.fr_432 cs.hr.sl_432  ru.tg.un_650 sw.rw.un_420 
  0x06002905, 0x1d6301a7, 0x5f455e5a, 0x3500280c,   // sl.de.un_330 en.sco.la_532  ts.ln.tn_553 sw.zu.un_530 
  0x35002808, 0x1a1d5602, 0x025d35a9, 0x285955ec,   // sw.zu.un_430 mg.la.tl_222  zu.ss.da_544 rw.rn.sw_644 
  0x355e36a4, 0xfe00040d, 0x47321614, 0x56373bad,   // gn.ts.zu_433 fi.tlh.un_540  hr.bs.sn_666 so.st.mg_643 
  // [7f90]
  0x131c09ec, 0x35026aa0, 0x5f5d45ec, 0x10004612,   // hi.mr.bh_644 haw.da.zu_322  ln.ss.tn_644 qu.lt.un_640 
  0x06280804, 0x070435ee, 0x3b2355a0, 0x02002913,   // no.sw.de_332 tg.ru.bg_422  rw.ca.so_322 sl.da.un_650 
  0x2855645a, 0x64285955, 0x071738a4, 0x1a5535a0,   // lg.rw.sw_553 rn.sw.lg_442  tk.sr.bg_433 zu.rw.tl_322 
  0x501d4dec, 0x10000c07, 0x4e6e1c12, 0x0a3811a7,   // aa.la.fj_644 sv.lt.un_420  id.hmn.ay_654 ro.tk.mk_532 
  // [7fa0]
  0x28122a04, 0x554c5904, 0x5e353413, 0x29353402,   // mt.hu.sw_332 rn.wo.rw_332  xh.zu.ts_665 xh.zu.sl_222 
  0x34355e0d, 0x48003005, 0x175e2d07, 0x345328a0,   // ts.zu.xh_554 uz.tt.un_330  sk.ts.sr_432 sw.ht.xh_322 
  0x1d003502, 0x5e5559ad, 0x11154808, 0x73466eaf,   // zu.la.un_220 rn.rw.ts_643  tt.ro.un_430 hmn.qu.ny_655 
  0x59553509, 0x731c1e12, 0x58213bad, 0x2d092aad,   // zu.rw.rn_444 ms.id.ny_654  so.jw.om_643 mt.pl.sk_643 
  // [7fb0]
  0x0a6579a4, 0x645f29a9, 0x49734ba4, 0x2c151dee,   // war.gv.pt_433 sl.tn.lg_544  mi.ny.to_433 la.fy.un_420 
  0x596455af, 0x100415a0, 0x2d002a07, 0x371730ec,   // rw.lg.rn_655 un.ru.be_322  mt.sk.un_420 uz.sr.ba_644 
  0x18007812, 0x111827ad, 0x07170a0b, 0x1f006e0c,   // ve.ga.un_640 gd.ga.ro_643  mk.sr.bg_542 hmn.cy.un_530 
  0x635852a9, 0x2d092a08, 0x15182760, 0x466235a4,   // ha.om.sco_544 mt.pl.sk_443  gd.ga.un_664 zu.kha.qu_433 
  // [7fc0]
  0x4e00462b, 0x23443714, 0x23002902, 0x2b006b07,   // qu.ay.un_980 ba.kk.ky_666  sl.ca.un_220 ceb.vi.un_420 
  0x68631dee, 0x00003b2d, 0x78182760, 0x483023ec,   // la.sco.ig_422 ks.un.un_A00  gd.ga.ve_664 ky.uz.tt_644 
  0xfc002a14, 0x7364fcad, 0x0b3b28af, 0x442336a7,   // mt.zzp.un_660 zzp.lg.ny_643  sw.so.es_655 ab.ky.kk_532 
  0x351517a0, 0x211a5013, 0x21303da4, 0x0200fc0d,   // sr.tg.un_320 fj.tl.jw_665  ku.uz.fa_433 zzp.da.un_540 
  // [7fd0]
  0x4702fc0c, 0x5e78460c, 0x68455f0c, 0x3b4a4c12,   // zzp.da.sn_543 qu.ve.ts_543  tn.ln.ig_543 wo.yo.so_654 
  0x5f345212, 0x135c1c04, 0x10007511, 0x5e734d04,   // ha.xh.tn_654 mr.sa.bh_332  nso.lt.un_630 aa.ny.ts_332 
  0x521a1e07, 0x2d0d39af, 0x3f69535a, 0x46505208,   // ms.tl.ha_432 br.cs.sk_655  ht.mfe.af_553 ha.fj.qu_443 
  0x15103513, 0x2800fc07, 0x190b0fee, 0x01020307,   // tg.be.un_665 zzp.sw.un_420  lv.es.gl_422 nl.da.en_432 
  // [7fe0]
  0x183d2808, 0x21791ca0, 0x443428a0, 0x350a17a4,   // sd.ku.ar_443 id.war.jw_322  sd.ps.kk_322 sr.mk.tg_433 
  0x464e4704, 0x0c0827a4, 0x780b47ec, 0x190a6009,   // sn.ay.qu_332 gd.no.sv_433  sn.es.ve_644 vo.pt.gl_444 
  0x381515ad, 0x68522f0c, 0x1f3920af, 0x172325a9,   // un.tk.un_630 su.ha.ig_543  sq.br.cy_655 mn.ky.sr_544 
  0x35002307, 0x025e47ee, 0x080210ee, 0x69537608,   // ky.tg.un_420 sn.ts.da_422  lt.da.no_422 crs.ht.mfe_443 
  // [7ff0]
  0xfe007907, 0x383c2313, 0x64002904, 0x1c130daf,   // war.tlh.un_420 ky.ug.tk_665  sl.lg.un_320 ne.bh.mr_655 
  0x1b1c1e07, 0x2a0a1802, 0x341228a9, 0x1a4a6b02,   // ms.id.tr_432 ga.pt.mt_222  sd.ur.ps_544 ceb.yo.tl_222 
  0x122823a7, 0x18283b07, 0x07003604, 0x3400231a,   // ky.sd.ur_532 ks.sd.ar_432  ab.bg.un_320 ky.ps.un_760 
  0x073017ec, 0x37041504, 0x10003904, 0x0c080202,   // sr.uz.bg_644 un.ru.ba_332  br.lt.un_320 da.no.sv_222 
  
  // [8000]
  0x38353012, 0x031b2407, 0x27003f04, 0x083f0304,   // uz.tg.tk_654 eo.tr.nl_432  af.gd.un_320 nl.af.no_332 
  0x0d095c04, 0x1c005c21, 0x63090204, 0x3f000207,   // sa.hi.ne_332 sa.mr.un_860  da.pl.sco_332 da.af.un_420 
  0x070417a7, 0x5d0e2ea4, 0x10653f0c, 0x12000921,   // sr.ru.bg_532 fo.is.ss_433  af.gv.lt_543 pl.hu.un_860 
  0x03001d04, 0x35784713, 0x092012ee, 0x03223f07,   // la.nl.un_320 sn.ve.zu_665  hu.sq.pl_422 af.oc.nl_432 
  // [8010]
  0xfc003f02, 0x18002e05, 0x180d3908, 0x04082c04,   // af.zzp.un_220 fo.ga.un_330  br.cs.ga_443 fy.no.fi_332 
  0x070a44a7, 0x6a00650d, 0x04002c0e, 0x10441704,   // kk.mk.bg_532 gv.haw.un_540  fy.fi.un_550 sr.kk.be_332 
  0x09007905, 0x06031f02, 0x032a2013, 0x25003819,   // war.pl.un_330 cy.nl.de_222  sq.mt.nl_665 tk.mn.un_750 
  0x17000d08, 0x2c000621, 0x536923ad, 0x0e00180b,   // cs.sr.un_430 de.fy.un_860  ca.mfe.ht_643 ga.is.un_520 
  // [8020]
  0x12005a02, 0x48003802, 0x04fe1308, 0x0a000b04,   // sm.hu.un_220 tk.tt.un_220  et.tlh.fi_443 es.pt.un_320 
  0x4a004c05, 0x1c1f21a0, 0x481209a7, 0x30442309,   // wo.yo.un_330 jw.cy.id_322  pl.hu.tt_532 ky.kk.uz_444 
  0x360f2aa7, 0x2c2003a0, 0x51076905, 0x0d1c0960,   // mt.lv.gn_532 nl.sq.fy_322  mfe.it.kl_333 hi.mr.ne_664 
  0x07033f08, 0x25042c13, 0x04153512, 0x12004f08,   // af.nl.it_443 fy.fi.eu_665  tg.ru.un_640 bi.hu.un_430 
  // [8030]
  0x042c65a4, 0x10362e12, 0x22080204, 0x4c651eee,   // gv.fy.fi_433 fo.gn.lt_654  da.no.oc_332 ms.gv.wo_422 
  0x4d65580d, 0x153035a4, 0x32fe290c, 0x04655814,   // om.gv.aa_554 tg.uz.un_433  sl.tlh.bs_543 om.gv.fi_666 
  0x03004305, 0x1369760d, 0x65001512, 0x1e653f55,   // ie.nl.un_330 crs.mfe.et_554  un.gv.un_640 af.gv.ms_442 
  0x34003d18, 0x3d3034a4, 0x082530ad, 0x6500580e,   // ku.ps.un_740 ps.uz.ku_433  uz.mn.uk_643 om.gv.un_550 
  // [8040]
  0x0a071712, 0x4c00650e, 0x444804af, 0x033ffca9,   // sr.bg.mk_654 gv.wo.un_550  ru.tt.kk_655 zzp.af.nl_544 
  0x173036ee, 0x586365ee, 0x150a04a4, 0x31000305,   // ab.uz.sr_422 gv.sco.om_422  ru.mk.un_433 nl.az.un_330 
  0x64006504, 0x03406507, 0x07361108, 0x3c4837af,   // gv.lg.un_320 gv.lb.nl_432  ro.ab.bg_443 ba.tt.ug_655 
  0x2d003207, 0x36001213, 0x215322a0, 0x37480709,   // bs.sk.un_420 hu.gn.un_650  oc.ht.jw_322 bg.tt.ba_444 
  // [8050]
  0x2812215a, 0x070448a7, 0x1d020605, 0x3534fa14,   // fa.ur.sd_553 tt.ru.bg_532  de.da.la_333 nr.xh.zu_666 
  0x5c1c13a4, 0x3c483714, 0xfa355d0c, 0x25070a02,   // bh.mr.sa_433 ba.tt.ug_666  ss.zu.nr_543 mk.bg.mn_222 
  0xfe00fc0d, 0x536301ad, 0x20006307, 0x1632170b,   // zzp.tlh.un_540 en.sco.ht_643  sco.sq.un_420 sr.bs.hr_542 
  0x28181205, 0x1100171b, 0x0d005309, 0x2a006e09,   // ur.ar.sd_333 sr.ro.un_770  ht.cs.un_440 hmn.mt.un_440 
  // [8060]
  0x3f000202, 0x1c0913a7, 0x34355d0c, 0x09001f22,   // da.af.un_220 bh.hi.mr_532  ss.zu.xh_543 cy.pl.un_870 
  0x2b002f08, 0x2a006e19, 0x0a3607a4, 0x02000d04,   // su.vi.un_430 hmn.mt.un_750  bg.ab.mk_433 cs.da.un_320 
  0x23003714, 0x153c17a4, 0x344428a4, 0x2112300c,   // ba.ky.un_660 sr.ug.un_433  sd.kk.ps_433 uz.ur.fa_543 
  0x284a5509, 0x05002102, 0x64002808, 0x513767a6,   // rw.yo.sw_444 jw.fr.un_220  sw.lg.un_430 ak.st.kl_521 
  // [8070]
  0x644b020c, 0x55676ead, 0x286447a9, 0x341823ee,   // da.mi.lg_543 hmn.ak.rw_643  sn.lg.sw_544 ky.ar.ps_422 
  0x28342104, 0x2f002105, 0x0c08020d, 0x3d183b0c,   // fa.ps.sd_332 jw.su.un_330  da.no.sv_554 ks.ar.ku_543 
  0x17296a13, 0x34181255, 0x754737a4, 0x26630107,   // haw.sl.sr_665 ur.ar.ps_442  st.sn.nso_433 en.sco.ia_432 
  0x76533208, 0x73284ead, 0x4800231a, 0x5a004a07,   // bs.ht.crs_443 ay.sw.ny_643  ky.tt.un_760 yo.sm.un_420 
  // [8080]
  0x351534a0, 0x01090da0, 0xfc1507ee, 0x25003704,   // xh.zu.un_320 cs.pl.en_322  it.zzp.un_420 ba.mn.un_320 
  0x45283612, 0x3b35fc0c, 0xfc006911, 0x3800230e,   // gn.sw.ln_654 zzp.zu.so_543  mfe.zzp.un_630 ky.tk.un_550 
  0x150163ee, 0x63430107, 0x01fc6309, 0x22234308,   // sco.en.un_422 en.ie.sco_432  sco.zzp.en_444 ie.ca.oc_443 
  0x5d000e08, 0x651ffc0c, 0x1c00620c, 0x1f00fc02,   // is.ss.un_430 zzp.cy.gv_543  kha.id.un_530 zzp.cy.un_220 
  // [8090]
  0x20046212, 0x2e00450e, 0x20000407, 0x15374807,   // kha.fi.sq_654 ln.fo.un_550  fi.sq.un_420 tt.ba.un_432 
  0x040807a9, 0x366e2204, 0x2b3907a0, 0x535d69a0,   // bg.uk.ru_544 oc.hmn.gn_332  it.br.vi_322 mfe.ss.ht_322 
  0x131c09a9, 0x39190a14, 0x3736110c, 0x173c0704,   // hi.mr.bh_544 pt.gl.br_666  ro.ab.ba_543 bg.ug.sr_332 
  0x312a4ca0, 0x2b000e05, 0x20000413, 0x2b0e2e07,   // wo.mt.az_322 is.vi.un_330  fi.sq.un_650 fo.is.vi_432 
  // [80a0]
  0x095c1ca0, 0x2c2722ee, 0x30002511, 0x34303dec,   // mr.sa.hi_322 oc.gd.fy_422  mn.uz.un_630 ku.uz.ps_644 
  0x0d0e2ba0, 0x3d003b18, 0x30003d07, 0x0a35170b,   // vi.is.cs_322 ks.ku.un_740  ku.uz.un_420 sr.tg.mk_542 
  0x28fe570d, 0x1f78fead, 0x0900570d, 0x1f00fe0d,   // na.tlh.sw_554 tlh.ve.cy_643  na.pl.un_540 tlh.cy.un_540 
  0x5559fe11, 0x7353fea9, 0x5d120da4, 0xfe2a590c,   // tlh.rn.rw_653 tlh.ht.ny_544  cs.hu.ss_433 rn.mt.tlh_543 
  // [80b0]
  0x4c003b11, 0x7357fead, 0x48150404, 0x21651604,   // so.wo.un_630 tlh.na.ny_643  ru.tt.un_320 hr.gv.jw_332 
  0x3435780d, 0x183d30a0, 0x29171604, 0x2a4dfe08,   // ve.zu.xh_554 uz.ku.ar_322  hr.sr.sl_332 tlh.aa.mt_443 
  0x5300fe0d, 0x0000592d, 0xfe005e34, 0x2f211e0c,   // tlh.ht.un_540 rn.un.un_A00  ts.tlh.un_A80 ms.jw.su_543 
  0x2f6b1a0c, 0x043bfe07, 0x3b000407, 0x10004304,   // tl.ceb.su_543 tlh.so.fi_432  fi.so.un_420 ie.lt.un_320 
  // [80c0]
  0x2e000f05, 0x38000904, 0x213d340c, 0x04002c02,   // lv.fo.un_330 pl.tk.un_320  ps.ku.fa_543 fy.fi.un_220 
  0x3f00fc02, 0x12400608, 0x05111da7, 0x2d004702,   // zzp.af.un_220 de.lb.hu_443  la.ro.fr_532 sn.sk.un_220 
  0x313830a0, 0x64004207, 0x0b116507, 0x461a29a0,   // uz.tk.az_322 co.lg.un_420  gv.ro.es_432 sl.tl.qu_322 
  0x5c15feee, 0x083510a4, 0x12000d0e, 0x233744af,   // tlh.sa.un_420 be.tg.uk_433  cs.hu.un_550 kk.ba.ky_655 
  // [80d0]
  0x1200790d, 0x1200fe13, 0x3c1036ec, 0xfe000913,   // war.hu.un_540 tlh.hu.un_650  ab.be.ug_644 pl.tlh.un_650 
  0x7900fe07, 0x126b79ad, 0x48000904, 0x17150404,   // tlh.war.un_420 war.ceb.hu_643  pl.tt.un_320 ru.sr.un_320 
  0x6b001212, 0x1a48120c, 0x3f6365a0, 0x6b1206a0,   // hu.ceb.un_640 hu.tt.tl_543  gv.sco.af_322 de.hu.ceb_322 
  0x2c001f0c, 0x3b001820, 0x342128a0, 0x07041513,   // cy.fy.un_530 ar.ks.un_850  sd.fa.ps_322 un.ru.bg_665 
  // [80e0]
  0x113536ad, 0x3e002207, 0x3000352b, 0x23002a08,   // ab.tg.ro_643 oc.rm.un_420  tg.uz.un_980 mt.ca.un_430 
  0x10001723, 0x283d12ee, 0x0a043704, 0x04002305,   // sr.be.un_880 ur.ku.sd_422  ba.ru.mk_332 ky.ru.un_330 
  0x040a080c, 0x08001029, 0x090d5cee, 0x18343da7,   // uk.mk.ru_543 be.uk.un_960  sa.ne.hi_422 ku.ps.ar_532 
  0xfc002d04, 0x2f285204, 0x095c0d05, 0x403f0307,   // sk.zzp.un_320 ha.sw.su_332  ne.sa.hi_333 nl.af.lb_432 
  // [80f0]
  0x0436350c, 0x11002513, 0x68007514, 0x5c000913,   // tg.ab.ru_543 mn.ro.un_650  nso.ig.un_660 hi.sa.un_650 
  0x10002308, 0x08174412, 0x1b383114, 0x0e2e0cec,   // ky.be.un_430 kk.sr.uk_654  az.tk.tr_666 sv.fo.is_644 
  0x34005202, 0x2c002b04, 0x10152304, 0x1710080e,   // ha.xh.un_220 vi.fy.un_320  ky.be.un_320 uk.be.sr_555 
  0x48004a0c, 0x3744230c, 0x290d2da7, 0x73005e0d,   // yo.tt.un_530 ky.kk.ba_543  sk.cs.sl_532 ts.ny.un_540 
  // [8100]
  0x1b5d4a07, 0x64002114, 0x46006307, 0x5500560e,   // yo.ss.tr_432 jw.lg.un_660  sco.qu.un_420 mg.rw.un_550 
  0x17080414, 0x5500680d, 0x1c002107, 0x0b00360c,   // ru.uk.sr_666 ig.rw.un_540  jw.id.un_420 gn.es.un_530 
  0x18302155, 0x1c0d5c0b, 0x3d283ba7, 0x131c5ca4,   // fa.uz.ar_442 sa.ne.mr_542  ks.sd.ku_532 sa.mr.bh_433 
  0x5c001c22, 0x19002d04, 0x17230aa4, 0x5d5f3755,   // mr.sa.un_870 sk.gl.un_320  mk.ky.sr_433 st.tn.ss_442 
  // [8110]
  0x2d006407, 0x44341812, 0x341f7307, 0x47735e55,   // lg.sk.un_420 ar.ps.kk_654  ny.cy.xh_432 ts.ny.sn_442 
  0x365d280d, 0xfc005f04, 0x383723ad, 0x21003422,   // sw.ss.gn_554 tn.zzp.un_320  ky.ba.tk_643 ps.fa.un_870 
  0x5148fca7, 0x30006504, 0x0238010b, 0x0934520c,   // zzp.tt.kl_532 gv.uz.un_320  en.tk.da_542 ha.xh.pl_543 
  0x32005504, 0x4c7364a4, 0x28655daf, 0x1b003012,   // rw.bs.un_320 lg.ny.wo_433  ss.gv.sw_655 uz.tr.un_640 
  // [8120]
  0x250e30a0, 0x311636ee, 0x65005708, 0x3400181a,   // uz.is.eu_322 gn.hr.az_422  na.gv.un_430 ar.ps.un_760 
  0x4d6538ad, 0x32006504, 0x4c00650c, 0x2800fc08,   // tk.gv.aa_643 gv.bs.un_320  gv.wo.un_530 zzp.sw.un_430 
  0x63386513, 0x481b25ec, 0x03647312, 0x285d34a0,   // gv.tk.sco_665 eu.tr.tt_644  ny.lg.nl_654 xh.ss.sw_322 
  0x73644c14, 0x0807045a, 0x2163380c, 0x06383f08,   // wo.lg.ny_666 ru.bg.uk_553  tk.sco.jw_543 af.tk.de_443 
  // [8130]
  0x6a097355, 0x305308a0, 0x65004708, 0x27006508,   // ny.pl.haw_442 no.ht.uz_322  sn.gv.un_430 gv.gd.un_430 
  0x347367a7, 0x09000113, 0x25303604, 0x65005812,   // ak.ny.xh_532 en.pl.un_650  gn.uz.eu_332 om.gv.un_640 
  0x220c2fa0, 0x2a003013, 0x584965ee, 0x4c6558af,   // su.sv.oc_322 uz.mt.un_650  gv.to.om_422 om.gv.wo_655 
  0x5c006307, 0x5d4f65a0, 0x65000607, 0x5c130905,   // sco.sa.un_420 gv.bi.ss_322  de.gv.un_420 hi.bh.sa_333 
  // [8140]
  0x3b4065a4, 0x39002002, 0x07150a09, 0x3b6558ee,   // gv.lb.so_433 sq.br.un_220  mk.bg.un_440 om.gv.so_422 
  0x4d65580c, 0x2a185807, 0x19220b12, 0x3723445a,   // om.gv.aa_543 om.ga.mt_432  es.oc.gl_654 kk.ky.ba_553 
  0x080a04a4, 0x2b1f5009, 0x583b6507, 0x05002404,   // ru.mk.uk_433 fj.cy.vi_444  gv.so.om_432 eo.fr.un_320 
  0x2c001119, 0x01003e02, 0x404565a7, 0x58006513,   // ro.fy.un_750 rm.en.un_220  gv.ln.lb_532 gv.om.un_650 
  // [8150]
  0x213d340d, 0x170438a6, 0x070a35a0, 0x091c5c04,   // ps.ku.fa_554 tk.ru.sr_521  tg.mk.bg_322 sa.mr.hi_332 
  0x05252004, 0x2500200e, 0x062d0d05, 0x37001705,   // sq.eu.fr_332 sq.eu.un_550  cs.sk.de_333 sr.ba.un_330 
  0x342f2d02, 0x2500111a, 0x48440aee, 0x34303d0d,   // sk.su.xh_222 ro.eu.un_760  mk.kk.tt_422 ku.uz.ps_554 
  0x08040709, 0x4430370e, 0x13003b07, 0x17253655,   // bg.ru.uk_444 ba.uz.kk_555  so.et.un_420 ab.mn.sr_442 
  // [8160]
  0x18213d05, 0x091efc07, 0x15170aa4, 0x253830af,   // ku.fa.ar_333 zzp.ms.pl_432  mk.sr.un_433 uz.tk.eu_655 
  0x64003008, 0x304423af, 0x12285cad, 0x553559a0,   // uz.lg.un_430 ky.kk.uz_655  sa.sw.hu_643 rn.zu.rw_322 
  0x086455ad, 0x55005c0e, 0x353464a9, 0x08170aaf,   // rw.lg.no_643 sa.rw.un_550  lg.xh.zu_544 mk.sr.uk_655 
  0x10080a05, 0x03002013, 0x1b31fe09, 0xfc0425ee,   // mk.uk.be_333 sq.nl.un_650  tlh.az.tr_444 eu.fi.zzp_422 
  // [8170]
  0x24201207, 0x15170807, 0x645810a9, 0x6b001d08,   // hu.sq.eo_432 uk.sr.un_432  lt.om.lg_544 la.ceb.un_430 
  0x0c020207, 0x4013040d, 0x1b3b3804, 0x3f031504,   // da.da.sv_432 fi.et.lb_554  tk.so.tr_332 un.nl.af_332 
  0x1b003b08, 0x12095e02, 0x2d292008, 0x1c697655,   // so.tr.un_430 ts.pl.hu_222  sq.sl.sk_443 crs.mfe.id_442 
  0x371279a7, 0x59005c22, 0x3b003904, 0x1f006508,   // war.hu.st_532 sa.rn.un_870  br.so.un_320 gv.cy.un_430 
  // [8180]
  0x11120907, 0x0e582e0c, 0x0f3b100c, 0x58074214,   // pl.hu.ro_432 fo.om.is_543  lt.so.lv_543 co.it.om_666 
  0x793b4d0c, 0x17321655, 0x30003b04, 0x3e4d1d0c,   // aa.so.war_543 hr.bs.sr_442  so.uz.un_320 la.aa.rm_543 
  0x232548af, 0x07363511, 0x30314804, 0x101225ad,   // tt.mn.ky_655 tg.ab.bg_653  tt.az.uz_332 eu.hu.lt_643 
  0xfe313811, 0x0e104d0d, 0x303738a9, 0x253023a4,   // tk.az.tlh_653 aa.lt.is_554  tk.ba.uz_544 ky.uz.mn_433 
  // [8190]
  0x1d3130af, 0x3900fc04, 0x30002902, 0x2a464ead,   // uz.az.la_655 zzp.br.un_320  sl.uz.un_220 ay.qu.mt_643 
  0x182834ad, 0x42075812, 0x332e0eee, 0x2c0cfc07,   // ps.sd.ar_643 om.it.co_654  is.fo.nn_422 zzp.sv.fy_432 
  0x3d002114, 0x3b4d540c, 0x28183408, 0x25083005,   // fa.ku.un_660 ik.aa.so_543  ps.ar.sd_443 uz.uk.mn_333 
  0x17233509, 0x3217fe0b, 0x2e00020b, 0x2d0d29a6,   // tg.ky.sr_444 tlh.sr.bs_542  da.fo.un_520 sl.cs.sk_521 
  // [81a0]
  0x170a1108, 0x07003c05, 0x0a153008, 0x3000441b,   // ro.mk.sr_443 ug.bg.un_330  uz.mk.un_430 kk.uz.un_770 
  0x65004909, 0x65004908, 0x170a3804, 0x18233c0c,   // to.gv.un_440 to.gv.un_430  tk.mk.sr_332 ug.ky.ar_543 
  0x34357312, 0x1e000502, 0x52004c07, 0x735f37ec,   // ny.zu.xh_654 fr.ms.un_220  wo.ha.un_420 st.tn.ny_644 
  0x5dfa35ec, 0x3400fc09, 0x733435ad, 0x0c375f0b,   // zu.nr.ss_644 zzp.xh.un_440  zu.xh.ny_643 tn.st.sv_542 
  // [81b0]
  0x4c005e0e, 0x5c2c1ba0, 0x36004605, 0x353473af,   // ts.wo.un_550 tr.fy.sa_322  qu.gn.un_330 ny.xh.zu_655 
  0x053f02a4, 0x352530a0, 0x35344c0e, 0x101517a9,   // da.af.fr_433 uz.mn.tg_322  wo.xh.zu_555 sr.be.un_540 
  0x334c73ee, 0x23353007, 0x32000808, 0x7350460e,   // ny.wo.nn_422 uz.tg.ky_432  no.bs.un_430 qu.fj.ny_555 
  0x4e0e5da4, 0x18001a1b, 0x2f1e1c02, 0x0900340d,   // ss.is.ay_433 tl.ar.un_770  id.ms.su_222 xh.pl.un_540 
  // [81c0]
  0x58003422, 0x4673640c, 0x5d6258af, 0x355d5755,   // xh.om.un_870 lg.ny.qu_543  om.kha.ss_655 na.ss.zu_442 
  0x5e451eaf, 0x5e1b4d0c, 0x6a504eaf, 0x1c00fe13,   // ms.ln.ts_655 aa.tr.ts_543  ay.fj.haw_655 tlh.id.un_650 
  0x791a7309, 0x241b5ca7, 0x5d5828ee, 0x32001e04,   // ny.tl.war_444 sa.tr.eo_532  sw.om.ss_422 ms.bs.un_320 
  0x384a1b04, 0x21123b0c, 0x2e33fcee, 0x472e5c05,   // tr.yo.tk_332 ks.ur.fa_543  zzp.nn.fo_422 sa.fo.sn_333 
  // [81d0]
  0x2a003504, 0x035c25a6, 0x6000040e, 0x18381b0c,   // zu.mt.un_320 eu.sa.nl_521  fi.vo.un_550 tr.tk.ga_543 
  0x20000402, 0x5f3764af, 0x4a005202, 0x1b006119,   // fi.sq.un_220 lg.st.tn_655  ha.yo.un_220 za.tr.un_750 
  0x73464ea0, 0x73006909, 0x735e560d, 0x483038ec,   // ay.qu.ny_322 mfe.ny.un_440  mg.ts.ny_554 tk.uz.tt_644 
  0x5e5650a9, 0x02285012, 0x4c536b08, 0x233730ad,   // fj.mg.ts_544 fj.sw.da_654  ceb.ht.wo_443 uz.ba.ky_643 
  // [81e0]
  0x4b2856ec, 0x30005504, 0x5e56450e, 0x3f01fc04,   // mg.sw.mi_644 rw.uz.un_320  ln.mg.ts_555 zzp.en.af_332 
  0x37381107, 0x5d5e7308, 0x1d11250c, 0xfc005e09,   // ro.tk.ba_432 ny.ts.ss_443  eu.ro.la_543 ts.zzp.un_440 
  0x04182712, 0x5c00090e, 0xfc676812, 0x56470407,   // gd.ga.fi_654 hi.sa.un_550  ig.ak.zzp_654 fi.sn.mg_432 
  0x29003304, 0x25002204, 0xfc001f13, 0x25271d04,   // nn.sl.un_320 oc.eu.un_320  cy.zzp.un_650 la.gd.eu_332 
  // [81f0]
  0xfc001f0c, 0x00004d24, 0x50285505, 0x3515365a,   // cy.zzp.un_530 aa.un.un_900  rw.sw.fj_333 ab.tg.un_530 
  0x0a2a0705, 0x396b1dad, 0x033f3ba4, 0x136e4c04,   // it.mt.pt_333 la.ceb.br_643  so.af.nl_433 wo.hmn.et_332 
  0x42fe5e05, 0x2f3b3fad, 0x2b001113, 0xfe59555a,   // ts.tlh.co_333 af.so.su_643  ro.vi.un_650 rw.rn.tlh_553 
  0x3c374813, 0x23383c13, 0x230f0aa4, 0xfc5e1f0c,   // tt.ba.ug_665 ug.tk.ky_665  pt.lv.ca_433 cy.ts.zzp_543 
  // [8200]
  0x3b00630c, 0x38305507, 0x3b4c4dee, 0x24000902,   // sco.so.un_530 rw.uz.tk_432  aa.wo.so_422 pl.eo.un_220 
  0x134c63ad, 0x15382313, 0xfe59550c, 0x3400230c,   // sco.wo.et_643 ky.tk.un_665  rw.rn.tlh_543 ky.ps.un_530 
  0x25233712, 0x1e1c3bee, 0xfe004d0d, 0x38360207,   // ba.ky.mn_654 so.id.ms_422  aa.tlh.un_540 da.gn.tk_432 
  0x4437350c, 0x595542af, 0xfe2329a0, 0x5d00040d,   // tg.ba.kk_543 co.rw.rn_655  sl.ca.tlh_322 fi.ss.un_540 
  // [8210]
  0xfc032c05, 0x0a1748ec, 0x42221204, 0x47001c02,   // fy.nl.zzp_333 tt.sr.mk_644  hu.oc.co_332 id.sn.un_220 
  0x241dfea4, 0x2c004c13, 0x48313008, 0x5500fe0d,   // tlh.la.eo_433 wo.fy.un_650  uz.az.tt_443 tlh.rw.un_540 
  0x03006212, 0xfe5d5e12, 0x03632f07, 0x3b046ba9,   // kha.nl.un_640 ts.ss.tlh_654  su.sco.nl_432 ceb.fi.so_544 
  0x4f4e01a4, 0x46655507, 0x20001702, 0x34182111,   // en.ay.bi_433 rw.gv.qu_432  sr.sq.un_220 fa.ar.ps_653 
  // [8220]
  0x3b0b4304, 0x07233604, 0x173504a7, 0x28004709,   // ie.es.so_332 ab.ky.bg_332  ru.tg.sr_532 sn.sw.un_440 
  0x5e00630d, 0x21343b07, 0x08004604, 0x4900100e,   // sco.ts.un_540 ks.ps.fa_432  qu.no.un_320 lt.to.un_550 
  0x1e1c11ec, 0x55645bad, 0x032c05a0, 0x506a4b12,   // ro.id.ms_644 sg.lg.rw_643  fr.fy.nl_322 mi.haw.fj_654 
  0x47735cad, 0x10000412, 0x10002809, 0x15000408,   // sa.ny.sn_643 ru.be.un_640  sw.lt.un_440 ru.un.un_430 
  // [8230]
  0x1d495aaf, 0x612336ec, 0x080c0204, 0x17040709,   // sm.to.la_655 gn.ca.za_644  da.sv.no_332 bg.ru.sr_444 
  0x04001309, 0x342112a9, 0x5f115008, 0x111d4313,   // et.fi.un_440 ur.fa.ps_544  fj.ro.tn_443 ie.la.ro_665 
  0x383711ad, 0x38153507, 0x1511070b, 0x23483812,   // ro.ba.tk_643 tg.tk.un_420  bg.ro.un_542 tk.tt.ky_654 
  0x100245ad, 0x34281255, 0x283412ad, 0x10005014,   // ln.da.lt_643 ur.sd.ps_442  ur.ps.sd_643 fj.lt.un_660 
  // [8240]
  0x15005807, 0x6150020c, 0x040a3807, 0x04495a0c,   // om.un.un_420 da.fj.za_543  tk.mk.ru_432 sm.to.fi_543 
  0x23431d08, 0x12030607, 0x2e060e04, 0x2f4d6212,   // la.ie.ca_443 de.nl.hu_432  is.de.fo_332 kha.aa.su_654 
  0x34183c02, 0x0a0735ad, 0x34231813, 0x48044455,   // ug.ar.ps_222 tg.bg.mk_643  ar.ky.ps_665 kk.ru.tt_442 
  0x15040814, 0x36001019, 0x213d3404, 0x17483504,   // uk.ru.un_666 be.ab.un_750  ps.ku.fa_332 tg.tt.sr_332 
  // [8250]
  0x0a351709, 0x28006414, 0x292e2807, 0x0e182eee,   // sr.tg.mk_444 lg.sw.un_660  sw.fo.sl_432 fo.ga.is_422 
  0x5a6a4bad, 0x475d780c, 0x29000d04, 0x353437ec,   // mi.haw.sm_643 ve.ss.sn_543  cs.sl.un_320 st.xh.zu_644 
  0x30004822, 0x2d00190e, 0x5d003512, 0x477837ec,   // tt.uz.un_870 gl.sk.un_550  zu.ss.un_640 st.ve.sn_644 
  0x04251508, 0x55005f07, 0x30003c18, 0x1b00481a,   // un.mn.ru_443 tn.rw.un_420  ug.uz.un_740 tt.tr.un_760 
  // [8260]
  0x47003708, 0x34005d14, 0x11070a08, 0x353464ee,   // st.sn.un_430 ss.xh.un_660  mk.bg.ro_443 lg.xh.zu_422 
  0x242b2807, 0x3200420c, 0x534a4c04, 0x2a462008,   // sw.vi.eo_432 co.bs.un_530  wo.yo.ht_332 sq.qu.mt_443 
  0x42006422, 0x531c0e04, 0x11020708, 0x680d04a7,   // lg.co.un_870 is.id.ht_332  it.da.ro_443 fi.cs.ig_532 
  0xfc3534ec, 0x470e2e11, 0x37341fa7, 0x304d4808,   // xh.zu.zzp_644 fo.is.sn_653  cy.xh.st_532 tt.aa.uz_443 
  // [8270]
  0x47375dec, 0x44080404, 0x20466207, 0x5f00471a,   // ss.st.sn_644 ru.uk.kk_332  kha.qu.sq_432 sn.tn.un_760 
  0x5537475a, 0x4d2e0e08, 0x3835300e, 0x071d430b,   // sn.st.rw_553 is.fo.aa_443  uz.tg.tk_555 ie.la.it_542 
  0x3d213013, 0x4a2253ac, 0x07361707, 0x311e2dad,   // uz.fa.ku_665 ht.oc.yo_632  sr.ab.bg_432 sk.ms.az_643 
  0x2e002d08, 0x3d1218ee, 0x3043530c, 0x1f463808,   // sk.fo.un_430 ar.ur.ku_422  ht.ie.uz_543 tk.qu.cy_443 
  // [8280]
  0x07431c0c, 0x1c006508, 0x4728780c, 0x0e5825af,   // id.ie.it_543 gv.id.un_430  ve.sw.sn_543 eu.om.is_655 
  0x30073604, 0x123902ee, 0x453b2807, 0x07432d07,   // ab.bg.uz_332 da.br.hu_422  sw.so.ln_432 sk.ie.it_432 
  0x2a3b460c, 0x68006519, 0x080a07a0, 0x65580255,   // qu.so.mt_543 gv.ig.un_750  bg.mk.uk_322 da.om.gv_442 
  0x73004e14, 0x150417ad, 0x035e5da9, 0x3d34305a,   // ay.ny.un_660 sr.ru.un_643  ss.ts.nl_544 uz.ps.ku_553 
  // [8290]
  0x08333b04, 0x3b00090e, 0x48041007, 0x595547af,   // so.nn.no_332 pl.so.un_550  be.ru.tt_432 sn.rw.rn_655 
  0x12002405, 0x0700420e, 0x5300200b, 0x12006413,   // eo.hu.un_330 co.it.un_550  sq.ht.un_520 lg.hu.un_650 
  0x161729a4, 0x25126404, 0x0c2e0ead, 0x5d734d07,   // sl.sr.hr_433 lg.hu.eu_332  is.fo.sv_643 aa.ny.ss_432 
  0x20002305, 0x04003807, 0x0a0415ee, 0x557359ee,   // ca.sq.un_330 tk.ru.un_420  un.ru.mk_422 rn.ny.rw_422 
  // [82a0]
  0x37000f02, 0x212d0d04, 0x21000b02, 0x18790912,   // lv.st.un_220 cs.sk.jw_332  es.jw.un_220 pl.war.ga_654 
  0x0a0438ad, 0x76fc0512, 0xfe004d07, 0x48381209,   // tk.ru.mk_643 fr.zzp.crs_654  aa.tlh.un_420 hu.tk.tt_444 
  0x392e0ea0, 0x13002f02, 0x31001b23, 0x52506b08,   // is.fo.br_322 su.et.un_220  tr.az.un_880 ceb.fj.ha_443 
  0x125238ec, 0x6e005e21, 0x392d0d0d, 0x2f00210c,   // tk.ha.hu_644 ts.hmn.un_860  cs.sk.br_554 jw.su.un_530 
  // [82b0]
  0x212a09af, 0x0e2e4602, 0x05002307, 0x3000342c,   // pl.mt.jw_655 qu.fo.is_222  ca.fr.un_420 ps.uz.un_990 
  0x0c134ead, 0x46001f21, 0x4afa340c, 0x53006308,   // ay.et.sv_643 cy.qu.un_860  xh.nr.yo_543 sco.ht.un_430 
  0x13000302, 0x1f006313, 0x5e1f6e09, 0x1dfc4604,   // nl.et.un_220 sco.cy.un_650  hmn.cy.ts_444 qu.zzp.la_332 
  0xfc34faa7, 0x40001f0d, 0xfc001d04, 0x261d01a0,   // nr.xh.zzp_532 cy.lb.un_540  la.zzp.un_320 en.la.ia_322 
  // [82c0]
  0x333ffea0, 0x4d001313, 0x3825150e, 0x09213fee,   // tlh.af.nn_322 et.aa.un_650  un.mn.tk_555 af.jw.pl_422 
  0x4f006e29, 0x483744a0, 0x355d34ad, 0x17002d02,   // hmn.bi.un_960 kk.ba.tt_322  xh.ss.zu_643 sk.sr.un_220 
  0x44000705, 0x536555a0, 0x286a01a0, 0x2f021ea9,   // bg.kk.un_330 rw.gv.ht_322  en.haw.sw_322 ms.da.su_544 
  0x5f002809, 0x4c535da0, 0x1c1a1ea9, 0x1e4c48a4,   // sw.tn.un_440 ss.ht.wo_322  ms.tl.id_544 tt.wo.ms_433 
  // [82d0]
  0x6400340c, 0x47354d07, 0x521a6b0c, 0x73003019,   // xh.lg.un_530 aa.zu.sn_432  ceb.tl.ha_543 uz.ny.un_750 
  0x73280955, 0x644652ec, 0x213034a9, 0x30006402,   // pl.sw.ny_442 ha.qu.lg_644  ps.uz.fa_544 lg.uz.un_220 
  0x4c501e0c, 0x4c022fa9, 0x1744150c, 0x466a4e12,   // ms.fj.wo_543 su.da.wo_544  un.kk.sr_543 ay.haw.qu_654 
  0x37002808, 0x52501e0c, 0x101715a0, 0x483738a7,   // sw.st.un_430 ms.fj.ha_543  un.sr.be_322 tk.ba.tt_532 
  // [82e0]
  0x39002e04, 0x30352313, 0x08003005, 0x2d001808,   // fo.br.un_320 ky.tg.uz_665  uz.uk.un_330 ga.sk.un_430 
  0x120a2d0d, 0x0a2517a0, 0x4830380e, 0x3d3421ad,   // sk.pt.hu_554 sr.mn.mk_322  tk.uz.tt_555 fa.ps.ku_643 
  0x2c001808, 0x3b000413, 0x01005807, 0x634c5807,   // ga.fy.un_430 fi.so.un_650  om.en.un_420 om.wo.sco_432 
  0x105f3713, 0x481036a0, 0x12232d0b, 0x4d584cad,   // st.tn.lt_665 ab.be.tt_322  sk.ca.hu_542 wo.om.aa_643 
  // [82f0]
  0x174835a6, 0x475f0205, 0x48150412, 0x73755fa9,   // tg.tt.sr_521 da.tn.sn_333  ru.tt.un_640 tn.nso.ny_544 
  0x730445a4, 0x2f041ca0, 0x47002809, 0x5f1337a0,   // ln.fi.ny_433 id.fi.su_322  sw.sn.un_440 st.et.tn_322 
  0x4a1ffe12, 0x552f2504, 0x23003605, 0x12222dad,   // tlh.cy.yo_654 eu.su.rw_332  gn.ca.un_330 sk.oc.hu_643 
  0x400604a4, 0x75374d08, 0x2f5d5907, 0x3300fc07,   // fi.de.lb_433 aa.st.nso_443  rn.ss.su_432 zzp.nn.un_420 
  // [8300]
  0x21123bad, 0x17444804, 0x4c002012, 0x58040708,   // ks.ur.fa_643 tt.kk.sr_332  sq.wo.un_640 it.fi.om_443 
  0x17003c12, 0x364844a4, 0x6e015804, 0x580465a6,   // ug.sr.un_640 kk.tt.ab_433  om.en.hmn_332 gv.fi.om_521 
  0x3f0304ec, 0x342f0fee, 0x6439730d, 0x37287513,   // fi.nl.af_644 lv.su.xh_422  ny.br.lg_554 nso.sw.st_665 
  0x154823ee, 0x391b2e04, 0x1538370d, 0x025903a4,   // ky.tt.un_422 fo.tr.br_332  ba.tk.un_554 nl.rn.da_433 
  // [8310]
  0x12003619, 0x0c000813, 0x73042dee, 0x1d0543ee,   // gn.hu.un_750 no.sv.un_650  sk.fi.ny_422 ie.fr.la_422 
  0x734b28ad, 0x3e002a1a, 0x18302107, 0x1548370c,   // sw.mi.ny_643 mt.rm.un_760  fa.uz.ar_432 ba.tt.un_543 
  0x790243a4, 0x69581c07, 0x301b6107, 0x21041c11,   // ie.da.war_433 id.om.mfe_432  za.tr.uz_432 id.fi.jw_653 
  0x484408a0, 0x1f042014, 0x4c2e3b55, 0x383e52ee,   // uk.kk.tt_322 sq.fi.cy_666  so.fo.wo_442 ha.rm.tk_422 
  // [8320]
  0x073b1c07, 0x122e18ee, 0x4d6e3baf, 0x1800600e,   // id.so.it_432 ga.fo.hu_422  so.hmn.aa_655 vo.ga.un_550 
  0x1b1367a7, 0x4d3b120c, 0x28003414, 0x10000908,   // ak.et.tr_532 hu.so.aa_543  ps.sd.un_660 pl.lt.un_430 
  0x16353404, 0x1200611a, 0x1f105fa0, 0x484e3109,   // xh.zu.hr_332 za.hu.un_760  tn.lt.cy_322 az.ay.tt_444 
  0x37252305, 0x5f375d12, 0x2f641008, 0x42761ca4,   // ky.mn.ba_333 ss.st.tn_654  lt.lg.su_443 id.crs.co_433 
  // [8330]
  0x3b2a460c, 0x35281bee, 0x30172512, 0x594a0912,   // qu.mt.so_543 tr.sw.zu_422  mn.sr.uz_654 pl.yo.rn_654 
  0x04071508, 0x3f113507, 0x12006402, 0x233c4411,   // un.bg.ru_443 zu.ro.af_432  lg.hu.un_220 kk.ug.ky_653 
  0x34003011, 0x30154407, 0x0d002b04, 0x37003011,   // uz.ps.un_630 kk.uz.un_420  vi.cs.un_320 uz.ba.un_630 
  0x402c1807, 0x63182ca6, 0x7906fcec, 0x15070a11,   // ga.fy.lb_432 fy.ga.sco_521  zzp.de.war_644 mk.bg.un_653 
  // [8340]
  0x37100407, 0x2134120d, 0x152c1807, 0x3c35300d,   // ru.be.ba_432 ur.ps.fa_554  ga.fy.un_432 uz.tg.ug_554 
  0x4400180d, 0x150407af, 0x3704080c, 0x23151505,   // ar.kk.un_540 bg.ru.un_655  uk.ru.ba_543 un.ky.un_330 
  0x132a3ea7, 0x6343010c, 0x4800fe0c, 0x18002c08,   // rm.mt.et_532 en.ie.sco_543  tlh.tt.un_530 fy.ga.un_430 
  0x3e005304, 0x252c1811, 0x65182c02, 0x07171507,   // ht.rm.un_320 ga.fy.eu_653  fy.ga.gv_222 un.sr.bg_432 
  // [8350]
  0x65003e04, 0x12003e0c, 0x2e000f04, 0x3e6b010c,   // rm.gv.un_320 rm.hu.un_530  lv.fo.un_320 en.ceb.rm_543 
  0x0800380c, 0x44371708, 0x16002912, 0x12400607,   // tk.uk.un_530 sr.ba.kk_443  sl.hr.un_640 de.lb.hu_432 
  0x1a626155, 0x12003e19, 0x40002607, 0x5c3435a4,   // za.kha.tl_442 rm.hu.un_750  ia.lb.un_420 zu.xh.sa_433 
  0x386201a4, 0x08003813, 0x284418ee, 0x73353460,   // en.kha.tk_433 tk.uk.un_650  ar.kk.sd_422 xh.zu.ny_664 
  // [8360]
  0x0d091312, 0x23074804, 0x5d003304, 0x6b5e1d60,   // bh.hi.ne_654 tt.bg.ky_332  nn.ss.un_320 la.ts.ceb_664 
  0x5d000d13, 0x344f640c, 0x355d69ec, 0x1c5c090b,   // cs.ss.un_650 lg.bi.xh_543  mfe.ss.zu_644 hi.sa.mr_542 
  0x5f3775ad, 0x0f1b1308, 0x15361105, 0x09003002,   // nso.st.tn_643 et.tr.lv_443  ro.ab.un_333 uz.pl.un_220 
  0x1b254213, 0x4a000908, 0x0500400d, 0x25353008,   // co.eu.tr_665 pl.yo.un_430  lb.fr.un_540 uz.tg.mn_443 
  // [8370]
  0x12183402, 0x570ffa13, 0x04151704, 0x2d0d57ee,   // ps.ar.ur_222 nr.lv.na_665  sr.ru.un_320 na.cs.sk_422 
  0x150704a9, 0x34213d11, 0x09420f07, 0x366467ad,   // ru.bg.un_544 ku.fa.ps_653  lv.co.pl_432 ak.lg.gn_643 
  0x6700641a, 0x4b004a04, 0x23443c09, 0x07111704,   // lg.ak.un_760 yo.mi.un_320  ug.kk.ky_444 sr.ro.bg_332 
  0x09003604, 0x23183408, 0x4836380c, 0x383615a4,   // gn.pl.un_320 ps.ar.ky_443  tk.ab.tt_543 un.ab.tk_433 
  // [8380]
  0x121828a9, 0x186563a0, 0x041548af, 0x37483c07,   // sd.ar.ur_544 sco.gv.ga_322  tt.ru.un_650 ug.tt.ba_432 
  0x28213b0c, 0x04153508, 0x190a090c, 0x182309ee,   // ks.fa.sd_543 tg.ru.un_430  pl.pt.gl_543 pl.ca.ga_422 
  0x483015a0, 0x365552ad, 0x12283b08, 0x55002407,   // un.uz.tt_322 ha.rw.gn_643  ks.sd.ur_443 eo.rw.un_420 
  0x27001f09, 0x30521ea0, 0x342346a0, 0x07303807,   // cy.gd.un_440 ms.ha.uz_322  qu.ca.xh_322 tk.uz.bg_432 
  // [8390]
  0x1a004307, 0x34121855, 0x30103508, 0x5a004b07,   // ie.tl.un_420 ar.ur.ps_442  tg.be.uz_443 mi.sm.un_420 
  0x17000e04, 0x38004422, 0x46003f07, 0x5c0d13ec,   // is.sr.un_320 kk.tk.un_870  af.qu.un_420 bh.ne.sa_644 
  0x2a011fee, 0x43002609, 0x37484407, 0x0a2c3fa0,   // cy.en.mt_422 ia.ie.un_440  kk.tt.ba_432 af.fy.pt_322 
  0x13653fee, 0x350723ee, 0x4c006512, 0x28fc7355,   // af.gv.et_422 ky.bg.tg_422  gv.wo.un_640 ny.zzp.sw_442 
  // [83a0]
  0x3f3b58ee, 0x53007604, 0x58004c12, 0x0a1715ec,   // om.so.af_422 crs.ht.un_320  wo.om.un_640 un.sr.mk_644 
  0x250e12ee, 0x064f3b0c, 0x17000304, 0x35005204,   // hu.is.eu_422 so.bi.de_543  nl.sr.un_320 ha.zu.un_320 
  0x120d2d07, 0x5700fc1a, 0x4b402007, 0x4a001a0d,   // sk.cs.hu_432 zzp.na.un_760  sq.lb.mi_432 tl.yo.un_540 
  0x2018600d, 0x37005d0d, 0x1a003509, 0x20001302,   // vo.ga.sq_554 ss.st.un_540  zu.tl.un_440 et.sq.un_220 
  // [83b0]
  0x2000600b, 0x34006b04, 0x16000d07, 0x24001a02,   // vo.sq.un_520 ceb.xh.un_320  cs.hr.un_420 tl.eo.un_220 
  0x2c00580c, 0x1504250c, 0x0c023bee, 0x3e232255,   // om.fy.un_530 mn.ru.un_543  so.da.sv_422 oc.ca.rm_442 
  0x2c646860, 0x23202108, 0x01656211, 0x123909a7,   // ig.lg.fy_664 jw.sq.ca_443  kha.gv.en_653 pl.br.hu_532 
  0x5c64280d, 0x233430a4, 0x6b000e04, 0x1d002704,   // sw.lg.sa_554 uz.ps.ky_433  is.ceb.un_320 gd.la.un_320 
  // [83c0]
  0x170704a4, 0x17043808, 0x211320ad, 0x18432709,   // ru.bg.sr_433 tk.ru.sr_443  sq.et.jw_643 gd.ie.ga_444 
  0x0f2c6404, 0x20002207, 0x37005f1b, 0x0c005302,   // lg.fy.lv_332 oc.sq.un_420  tn.st.un_770 ht.sv.un_220 
  0x27fc01a0, 0x23443c0e, 0x22002012, 0x27062ca0,   // en.zzp.gd_322 ug.kk.ky_555  sq.oc.un_640 fy.de.gd_322 
  0x20004c08, 0x20330504, 0x2040050d, 0x655012a0,   // wo.sq.un_430 fr.nn.sq_332  fr.lb.sq_554 hu.fj.gv_322 
  // [83d0]
  0x2c2715a7, 0x312864a4, 0x2f400507, 0x221923a6,   // un.gd.fy_532 lg.sw.az_433  fr.lb.su_432 ca.gl.oc_521 
  0x45430508, 0x2f4005a0, 0x132c5804, 0x39270e0c,   // fr.ie.ln_443 fr.lb.su_322  om.fy.et_332 is.gd.br_543 
  0x536428a0, 0x020661a7, 0x36002218, 0x36000205,   // sw.lg.ht_322 za.de.da_532  oc.gn.un_740 da.gn.un_330 
  0x060d05a0, 0x0c054011, 0x06023e07, 0x42131d12,   // fr.cs.de_322 lb.fr.sv_653  rm.da.de_432 la.et.co_654 
  // [83e0]
  0x2c27185a, 0x02002718, 0x032c02ee, 0x131c090d,   // ga.gd.fy_553 gd.da.un_740  da.fy.nl_422 hi.mr.bh_554 
  0x2a001208, 0x04400564, 0x44231560, 0x40052f04,   // hu.mt.un_430 fr.lb.fi_762  un.ky.kk_664 su.fr.lb_332 
  0x36000908, 0x2f006305, 0x45400555, 0x1200300b,   // pl.gn.un_430 sco.su.un_330  fr.lb.ln_442 uz.ur.un_520 
  0x35100704, 0x0e2e62af, 0x2f430505, 0x1204060d,   // bg.be.tg_332 kha.fo.is_655  fr.ie.su_333 de.fi.hu_554 
  // [83f0]
  0x0a0425ee, 0x3437040d, 0x04301555, 0x3000230b,   // mn.ru.mk_422 fi.st.xh_554  un.uz.ru_442 ky.uz.un_520 
  0x4600040b, 0x30352504, 0x480807a7, 0x36041d07,   // fi.qu.un_520 mn.tg.uz_332  bg.uk.tt_532 la.fi.gn_432 
  0x58150402, 0x3000352a, 0x34183004, 0xfc000102,   // fi.om.un_220 tg.uz.un_970  uz.ar.ps_332 en.zzp.un_220 
  0x30213d0d, 0x04004e12, 0x2c58020d, 0x304224a4,   // ku.fa.uz_554 ay.fi.un_640  da.om.fy_554 eo.co.uz_433 
  
  // [8400]
  0x6402510c, 0x024c2a0c, 0x4c5f3707, 0x37364707,   // kl.da.lg_543 mt.wo.da_543  st.tn.wo_432 sn.gn.st_432 
  0x040a0702, 0x2d121902, 0x2e450e60, 0x2924460c,   // bg.mk.ru_222 gl.hu.sk_222  is.ln.fo_664 qu.eo.sl_543 
  0x15004607, 0x48640207, 0x35153012, 0x034c1ba9,   // qu.un.un_420 da.lg.tt_432  uz.tg.un_640 tr.wo.nl_544 
  0x0d224aa0, 0x04000e0c, 0x49474604, 0x31003704,   // yo.oc.cs_322 is.fi.un_530  qu.sn.to_332 st.az.un_320 
  // [8410]
  0x2c001812, 0x3100480c, 0x79002519, 0x11121804,   // ga.fy.un_640 tt.az.un_530  eu.war.un_750 ga.hu.ro_332 
  0x02041308, 0x13510409, 0x0a001104, 0x47000e05,   // et.fi.da_443 fi.kl.et_444  ro.pt.un_320 is.sn.un_330 
  0x63033f05, 0x0d003620, 0x4d542a5a, 0x4e79460c,   // af.nl.sco_333 gn.cs.un_850  mt.ik.aa_553 qu.war.ay_543 
  0x2a004c0d, 0x3c44235a, 0x0a2d2e0c, 0x0e1d36a0,   // wo.mt.un_540 ky.kk.ug_553  fo.sk.pt_543 gn.la.is_322 
  // [8420]
  0x18362e0c, 0x42003e0d, 0x232243ec, 0x022223ad,   // fo.gn.ga_543 rm.co.un_540  ie.oc.ca_644 ca.oc.da_643 
  0x653f6307, 0x4a34210c, 0x51000107, 0x43120aa4,   // sco.af.gv_432 jw.xh.yo_543  en.kl.un_420 pt.hu.ie_433 
  0x0a12430b, 0x58004a05, 0x421d63a4, 0x6400fe07,   // ie.hu.pt_542 yo.om.un_330  sco.la.co_433 tlh.lg.un_420 
  0x347909ac, 0x09003809, 0x303c3814, 0x35342fa4,   // pl.war.xh_632 tk.pl.un_440  tk.ug.uz_666 su.xh.zu_433 
  // [8430]
  0x3f00680d, 0x584d4008, 0x13644d0c, 0x37345da9,   // ig.af.un_540 lb.aa.om_443  aa.lg.et_543 ss.xh.st_544 
  0x0d122214, 0x34464212, 0x25002f08, 0x42002205,   // oc.hu.cs_666 co.qu.xh_654  su.eu.un_430 oc.co.un_330 
  0x36004304, 0x040a08ad, 0x4d64130c, 0x47633407,   // ie.gn.un_320 uk.mk.ru_643  et.lg.aa_543 xh.sco.sn_432 
  0x36431205, 0x464a280c, 0x21501c04, 0x58654c07,   // hu.ie.gn_333 sw.yo.qu_543  id.fj.jw_332 wo.gv.om_432 
  // [8440]
  0x12002508, 0x13733b08, 0x64003b08, 0x4400481a,   // eu.hu.un_430 so.ny.et_443  so.lg.un_430 tt.kk.un_760 
  0x016563ac, 0x20392508, 0x120208af, 0x344c6907,   // sco.gv.en_632 eu.br.sq_443  no.da.hu_655 mfe.wo.xh_432 
  0x125334a0, 0x0a051107, 0x120208a9, 0xfa355d0d,   // xh.ht.hu_322 ro.fr.pt_432  no.da.hu_544 ss.zu.nr_554 
  0x6a732808, 0x34005519, 0x55002c0e, 0x03211e0b,   // sw.ny.haw_443 rw.xh.un_750  fy.rw.un_550 ms.jw.nl_542 
  // [8450]
  0x46691108, 0x67005719, 0x0a1243ad, 0x21001102,   // ro.mfe.qu_443 na.ak.un_750  ie.hu.pt_643 ro.jw.un_220 
  0x2c000813, 0x73005e0c, 0x08041708, 0x13392f0b,   // no.fy.un_650 ts.ny.un_530  sr.ru.uk_443 su.br.et_542 
  0x55005302, 0x6400130d, 0x6a006412, 0x131d64a4,   // ht.rw.un_220 et.lg.un_540  lg.haw.un_640 lg.la.et_433 
  0x1544230d, 0x4c3b1308, 0x1300640e, 0x640413ad,   // ky.kk.un_554 et.so.wo_443  lg.et.un_550 et.fi.lg_643 
  // [8460]
  0x583b4d0c, 0x5c005502, 0x653f630c, 0x484d1d05,   // aa.so.om_543 rw.sa.un_220  sco.af.gv_543 la.aa.tt_333 
  0x1a002821, 0x3b101dee, 0x07050104, 0x041515af,   // sw.tl.un_860 la.lt.so_422  en.fr.it_332 un.ru.un_650 
  0x781e1c5a, 0x0c380612, 0x6b00501b, 0x0c2e0608,   // id.ms.ve_553 de.tk.sv_654  fj.ceb.un_770 de.fo.sv_443 
  0x25002804, 0x441823ec, 0x5c4a1da0, 0x081715a6,   // sw.eu.un_320 ky.ar.kk_644  la.yo.sa_322 un.sr.uk_521 
  // [8470]
  0x134804a0, 0x251d57a7, 0x040609b2, 0x1812280b,   // fi.tt.et_322 na.la.eu_532  pl.de.fi_732 sd.ur.ar_542 
  0x55251a05, 0x3534fc55, 0x26001d08, 0x09001804,   // tl.eu.rw_333 zzp.xh.zu_442  la.ia.un_430 ga.pl.un_320 
  0xfc353405, 0xfc353413, 0x733525a0, 0x283c1207,   // xh.zu.zzp_333 xh.zu.zzp_665  eu.zu.ny_322 ur.ug.sd_432 
  0x11002304, 0x5d1ffcee, 0x5700091b, 0x3534fc08,   // ca.ro.un_320 zzp.cy.ss_422  pl.na.un_770 zzp.xh.zu_443 
  // [8480]
  0x2552130c, 0x04000612, 0x34005d21, 0x32401da4,   // et.ha.eu_543 de.fi.un_640  ss.xh.un_860 la.lb.bs_433 
  0x0c060407, 0x1306040c, 0x252336ec, 0x06600407,   // fi.de.sv_432 fi.de.et_543  ab.ky.mn_644 fi.vo.de_432 
  0x1500381b, 0x24002502, 0x043c150c, 0x12002404,   // tk.un.un_770 eu.eo.un_220  un.ug.ru_543 eo.hu.un_320 
  0x28003d0e, 0x3c382312, 0x35174407, 0x1230180c,   // ku.sd.un_550 ky.tk.ug_654  kk.sr.tg_432 ar.uz.ur_543 
  // [8490]
  0x2a006402, 0x48443c12, 0x400c06ee, 0x12241507,   // lg.mt.un_220 ug.kk.tt_654  de.sv.lb_422 un.eo.hu_432 
  0x250324a4, 0x55002502, 0x09002c09, 0x090d1ca0,   // eo.nl.eu_433 eu.rw.un_220  fy.pl.un_440 mr.ne.hi_322 
  0x3800020d, 0x37172507, 0x183d34a0, 0x443523a0,   // da.tk.un_540 mn.sr.ba_432  ps.ku.ar_322 ky.tg.kk_322 
  0x15044813, 0x353464a0, 0x050663ad, 0xfc000409,   // tt.ru.un_665 lg.xh.zu_322  sco.de.fr_643 fi.zzp.un_440 
  // [84a0]
  0x0e0233a0, 0x12182102, 0x35006408, 0x15004408,   // nn.da.is_322 fa.ar.ur_222  lg.zu.un_430 kk.un.un_430 
  0x13002107, 0x25170a07, 0x21436004, 0x104415ee,   // jw.et.un_420 mk.sr.mn_432  vo.ie.jw_332 un.kk.be_422 
  0x0a1548a0, 0x1704070e, 0x1d002f04, 0x5e00340c,   // tt.mk.un_320 bg.ru.sr_555  su.la.un_320 xh.ts.un_530 
  0x34355d0d, 0x04004d0d, 0x02006507, 0x3c003521,   // ss.zu.xh_554 aa.fi.un_540  gv.da.un_420 tg.ug.un_860 
  // [84b0]
  0x2e00200b, 0x20463007, 0x30001302, 0x4c4d31a7,   // sq.fo.un_520 uz.qu.sq_432  et.uz.un_220 az.aa.wo_532 
  0x2800390c, 0x52004707, 0x39004708, 0x1c5c0912,   // br.sw.un_530 sn.ha.un_420  sn.br.un_430 hi.sa.mr_654 
  0x095c0d55, 0x03000704, 0x2d0912a4, 0x790912ad,   // ne.sa.hi_442 it.nl.un_320  hu.pl.sk_433 hu.pl.war_643 
  0x3c353013, 0x4600200c, 0x313046a9, 0x1b000604,   // uz.tg.ug_665 sq.qu.un_530  qu.uz.az_544 de.tr.un_320 
  // [84c0]
  0x20314da4, 0x0d220ba4, 0x213c2308, 0x30314d0c,   // aa.az.sq_433 es.oc.cs_433  ky.ug.fa_443 aa.az.uz_543 
  0x1716290c, 0x39460912, 0x48004509, 0x130936a0,   // sl.hr.sr_543 pl.qu.br_654  ln.tt.un_440 gn.pl.et_322 
  0x44233812, 0x7900091a, 0x24003804, 0x0a071113,   // tk.ky.kk_654 pl.war.un_760  tk.eo.un_320 ro.bg.mk_665 
  0x23303c13, 0x1b001304, 0x1300120c, 0x30350704,   // ug.uz.ky_665 et.tr.un_320  hu.et.un_530 bg.tg.uz_332 
  // [84d0]
  0x44151107, 0x122d3604, 0x21343d02, 0x30005108,   // ro.kk.un_420 gn.sk.hu_332  ku.ps.fa_222 kl.uz.un_430 
  0x31004c07, 0x2d180d05, 0x1e006504, 0x0f003002,   // wo.az.un_420 cs.ga.sk_333  gv.ms.un_320 uz.lv.un_220 
  0x23373804, 0x0a07045a, 0x0810040c, 0x04016307,   // tk.ba.ky_332 ru.bg.mk_553  ru.be.uk_543 sco.en.fi_432 
  0x041008a0, 0x3738230c, 0x48353807, 0x170815a0,   // uk.be.ru_322 ky.tk.ba_543  tk.tg.tt_432 un.uk.sr_322 
  // [84e0]
  0x110543a7, 0x3b0e4dee, 0x36385807, 0x10600f07,   // ie.fr.ro_532 aa.is.so_422  om.tk.gn_432 lv.vo.lt_432 
  0xfe005805, 0x232548a4, 0x110715a4, 0x2900020d,   // om.tlh.un_330 tt.mn.ky_433  un.bg.ro_433 da.sl.un_540 
  0x10001111, 0x32161204, 0x1a1113a0, 0x18003b02,   // ro.be.un_630 hu.hr.bs_332  et.ro.tl_322 so.ga.un_220 
  0x10234408, 0x2536100d, 0x137911ee, 0x78006822,   // kk.ky.be_443 be.ab.mn_554  ro.war.et_422 ig.ve.un_870 
  // [84f0]
  0x58006511, 0x4c3b65a4, 0x65584c08, 0x48002317,   // gv.om.un_630 gv.so.wo_433  wo.om.gv_443 ky.tt.un_730 
  0x13006509, 0x4c5865ec, 0x3bfe4d12, 0x0413600b,   // gv.et.un_440 gv.om.wo_644  aa.tlh.so_654 vo.et.fi_542 
  0x0413605a, 0x371011af, 0x131b6012, 0x214929a0,   // vo.et.fi_553 ro.be.ba_655  vo.tr.et_654 sl.to.jw_322 
  0x3b58650d, 0x102338a0, 0x0c58040c, 0x2a005212,   // gv.om.so_554 tk.ky.be_322  fi.om.sv_543 ha.mt.un_640 
  // [8500]
  0x041213a0, 0x0f042f04, 0x041d0e07, 0x0c002402,   // et.hu.fi_322 su.fi.lv_332  is.la.fi_432 eo.sv.un_220 
  0x13000c02, 0x40000622, 0x0d001818, 0x46001304,   // sv.et.un_220 de.lb.un_870  ga.cs.un_740 et.qu.un_320 
  0x25150712, 0x153736ee, 0x6b1a6aa4, 0x3b2865a9,   // bg.mn.un_640 ab.ba.un_422  haw.tl.ceb_433 gv.sw.so_544 
  0x1b001305, 0x3b476a05, 0x58002519, 0x31112fa0,   // et.tr.un_330 haw.sn.so_333  eu.om.un_750 su.ro.az_322 
  // [8510]
  0xfc005602, 0x2f2167ee, 0x07423512, 0x796764af,   // mg.zzp.un_220 ak.jw.su_422  zu.co.it_654 lg.ak.war_655 
  0x094d0fad, 0x4c3b580d, 0x5a375707, 0x632030ad,   // lv.aa.pl_643 om.so.wo_554  na.st.sm_432 uz.sq.sco_643 
  0x1d00370d, 0x031948a0, 0x58004005, 0x314830af,   // st.la.un_540 tt.gl.nl_322  lb.om.un_330 uz.tt.az_655 
  0x64004c18, 0x1d1f4b0b, 0x53640912, 0x13481ba0,   // wo.lg.un_740 mi.cy.la_542  pl.lg.ht_654 tr.tt.et_322 
  // [8520]
  0x0e6013a4, 0x13494ba4, 0x13001708, 0x180742a7,   // et.vo.is_433 mi.to.et_433  sr.et.un_430 co.it.ga_532 
  0x1f000e08, 0x07043604, 0x2d1b2407, 0x1f001d09,   // is.cy.un_430 ab.ru.bg_332  eo.tr.sk_432 la.cy.un_440 
  0x30093204, 0x2d0d0fa0, 0x21001f04, 0x0f005012,   // bs.pl.uz_332 lv.cs.sk_322  cy.jw.un_320 fj.lv.un_640 
  0x064803a0, 0x4c475807, 0x583b4d12, 0x314b0e04,   // nl.tt.de_322 om.sn.wo_432  aa.so.om_654 is.mi.az_332 
  // [8530]
  0x5946100d, 0x4c003b1a, 0x343664ad, 0x2847580c,   // lt.qu.rn_554 so.wo.un_760  lg.gn.xh_643 om.sn.sw_543 
  0x584b4cee, 0x4f0e73a7, 0x0b3e070c, 0x2b00610e,   // wo.mi.om_422 ny.is.bi_532  it.rm.es_543 za.vi.un_550 
  0x040a150e, 0x0b003e02, 0x47006219, 0x1b1248ad,   // un.mk.ru_555 rm.es.un_220  kha.sn.un_750 tt.hu.tr_643 
  0x111d0f0c, 0x20424d07, 0x1d4b5a07, 0x312e10ac,   // lv.la.ro_543 aa.co.sq_432  sm.mi.la_432 lt.fo.az_632 
  // [8540]
  0x08003c08, 0x50115a0c, 0x130248a4, 0x1f005712,   // ug.uk.un_430 sm.ro.fj_543  tt.da.et_433 na.cy.un_640 
  0x4d595514, 0x1800fe12, 0x12183d08, 0x55597355,   // rw.rn.aa_666 tlh.ga.un_640  ku.ar.ur_443 ny.rn.rw_442 
  0xfc0c13a0, 0x3438fea0, 0x40002705, 0x35170a02,   // et.sv.zzp_322 tlh.tk.xh_322  gd.lb.un_330 mk.sr.tg_222 
  0x42596207, 0x2a071ea4, 0x04695313, 0x080206a4,   // kha.rn.co_432 ms.it.mt_433  ht.mfe.fi_665 de.da.no_433 
  // [8550]
  0x2e190b04, 0x20005013, 0x4ffe4bec, 0x0d00290b,   // es.gl.fo_332 fj.sq.un_650  mi.tlh.bi_644 sl.cs.un_520 
  0x211a4a0c, 0x301548ee, 0x59555da9, 0x293217ee,   // yo.tl.jw_543 tt.uz.un_420  ss.rw.rn_544 sr.bs.sl_422 
  0x48253707, 0x1d271813, 0x35007309, 0x24002709,   // ba.mn.tt_432 ga.gd.la_665  ny.zu.un_440 gd.eo.un_440 
  0x63002f0d, 0x18002a07, 0x483023ee, 0x04100807,   // su.sco.un_540 mt.ga.un_420  ky.uz.tt_422 uk.be.ru_432 
  // [8560]
  0x17300a09, 0x42631304, 0x6b68fe04, 0x1e476b07,   // mk.uz.sr_444 et.sco.co_332  tlh.ig.ceb_332 ceb.sn.ms_432 
  0x59353414, 0x27180102, 0x3c12280c, 0x171510a4,   // xh.zu.rn_666 en.ga.gd_222  sd.ur.ug_543 be.sr.un_430 
  0x3d212304, 0x53231f55, 0x041036ee, 0x23383c60,   // ky.fa.ku_332 cy.ca.ht_442  ab.be.ru_422 ug.tk.ky_664 
  0x1f35fcad, 0x07381108, 0x0900730e, 0x596455a4,   // zzp.zu.cy_643 ro.tk.bg_443  ny.pl.un_550 rw.lg.rn_433 
  // [8570]
  0x170807a7, 0x30090602, 0x0f001609, 0x1200040c,   // bg.uk.sr_532 de.pl.uz_222  hr.lv.un_440 fi.hu.un_530 
  0x21001e05, 0x1e006207, 0x1200640c, 0x5300040b,   // ms.jw.un_330 kha.ms.un_420  lg.hu.un_530 fi.ht.un_520 
  0x59125508, 0x276a1f12, 0x562504a4, 0x28640207,   // rw.hu.rn_443 cy.haw.gd_654  fi.eu.mg_433 da.lg.sw_432 
  0x373615af, 0x39001b02, 0x0b63260c, 0x52005602,   // un.ab.ba_655 tr.br.un_220  ia.sco.es_543 mg.ha.un_220 
  // [8580]
  0x233c4404, 0x1c001e08, 0x535c280c, 0x5e044507,   // kk.ug.ky_332 ms.id.un_430  sw.sa.ht_543 ln.fi.ts_432 
  0x651e04a4, 0x04007307, 0x34003605, 0x17074407,   // fi.ms.gv_433 ny.fi.un_420  gn.xh.un_330 kk.bg.sr_432 
  0x5100650e, 0x1004230d, 0x5c0d1c09, 0x1b48310e,   // gv.kl.un_550 ky.ru.be_554  mr.ne.sa_444 az.tt.tr_555 
  0x0d1c09a6, 0x164629ee, 0x2317380c, 0x0400100b,   // hi.mr.ne_521 sl.qu.hr_422  tk.sr.ky_543 be.ru.un_520 
  // [8590]
  0x2f1e1c14, 0x370423ee, 0x3f40fc08, 0x0900130e,   // id.ms.su_666 ky.ru.ba_422  zzp.lb.af_443 bh.hi.un_550 
  0x07350aa4, 0x3c004819, 0x1036230c, 0x272c02a0,   // mk.tg.bg_433 tt.ug.un_750  ky.ab.be_543 da.fy.gd_322 
  0x632c0204, 0x483038ad, 0x30484404, 0x3f276502,   // da.fy.sco_332 tk.uz.tt_643  kk.tt.uz_332 gv.gd.af_222 
  0x0d1c5cac, 0x2f00050d, 0x11593608, 0x23001504,   // sa.mr.ne_632 fr.su.un_540  gn.rn.ro_443 un.ky.un_320 
  // [85a0]
  0x5d00360c, 0x35003612, 0x29001702, 0x016b02a0,   // gn.ss.un_530 ab.tg.un_640  sr.sl.un_220 da.ceb.en_322 
  0x2523150c, 0x40653e08, 0x2c2702a0, 0x183e06ee,   // un.ky.mn_543 rm.gv.lb_443  da.gd.fy_322 de.rm.ga_422 
  0x2300110c, 0x190e2e08, 0x330812a0, 0x1000290c,   // ro.ky.un_530 fo.is.gl_443  hu.no.nn_322 sl.lt.un_530 
  0x3f007821, 0x371011a0, 0x17290f04, 0x4b004c22,   // ve.af.un_860 ro.be.ba_322  lv.sl.sr_332 wo.mi.un_870 
  // [85b0]
  0x07234402, 0x3e003409, 0x38001704, 0x555028ad,   // kk.ky.bg_222 xh.rm.un_440  sr.tk.un_320 sw.fj.rw_643 
  0x5d59555a, 0x12001f04, 0x59002109, 0x3e081207,   // rw.rn.ss_553 cy.hu.un_320  jw.rn.un_440 hu.no.rm_432 
  0x55004a08, 0x3f2f2112, 0x595578af, 0x330c08ee,   // yo.rw.un_430 jw.su.af_654  ve.rw.rn_655 no.sv.nn_422 
  0x173515ee, 0x443530ee, 0x214c4bec, 0x595578a9,   // un.tg.sr_422 uz.tg.kk_422  mi.wo.jw_644 ve.rw.rn_544 
  // [85c0]
  0x04081707, 0x1f00570e, 0x21283da0, 0x5e01fcec,   // sr.uk.ru_432 na.cy.un_550  ku.sd.fa_322 zzp.en.ts_644 
  0x04303509, 0x48153ca0, 0x25152307, 0x04003112,   // tg.uz.ru_444 ug.tt.un_320  ky.mn.un_420 az.fi.un_640 
  0x5364fc08, 0x53006413, 0x350807a0, 0x10372308,   // zzp.lg.ht_443 lg.ht.un_650  bg.uk.tg_322 ky.ba.be_443 
  0x64385304, 0x01104d04, 0x3600250e, 0x33000b08,   // ht.tk.lg_332 aa.lt.en_332  mn.ab.un_550 bn.as.un_430 
  // [85d0]
  0x3d004419, 0x52211ea4, 0x1c272f04, 0x571e1c08,   // kk.ku.un_750 ms.jw.ha_433  su.gd.id_332 id.ms.na_443 
  0x21003d22, 0x5f501c08, 0x532f76ad, 0x20003009,   // ku.fa.un_870 id.fj.tn_443  crs.su.ht_643 uz.sq.un_440 
  0x64000108, 0x3018650c, 0x0c3308a0, 0x3f032c0d,   // en.lg.un_430 gv.ga.uz_543  no.nn.sv_322 fy.nl.af_554 
  0x2f1c1ea4, 0x2f005c04, 0x40063fa4, 0x38353402,   // ms.id.su_433 sa.su.un_320  af.de.lb_433 xh.zu.tk_222 
  // [85e0]
  0x0700230d, 0x06001b02, 0x283418ac, 0x5e004c09,   // ky.bg.un_540 tr.de.un_220  ar.ps.sd_632 wo.ts.un_440 
  0x1c4a6b04, 0x64524c07, 0x73646155, 0x67570107,   // ceb.yo.id_332 wo.ha.lg_432  za.lg.ny_442 en.na.ak_432 
  0x1e1c210e, 0x6400090e, 0x042d3ea7, 0x6768640c,   // jw.id.ms_555 pl.lg.un_550  rm.sk.fi_532 lg.ig.ak_543 
  0x3600780d, 0x1c006421, 0x0b00190b, 0x56505c0c,   // ve.gn.un_540 lg.id.un_860  gl.es.un_520 sa.fj.mg_543 
  // [85f0]
  0x13fc070c, 0x08023e05, 0x0a00250c, 0x35071055,   // it.zzp.et_543 rm.da.no_333  mn.mk.un_530 be.bg.tg_442 
  0x38080205, 0x2515230e, 0x05362f04, 0x3308fca0,   // da.no.tk_333 ky.mn.un_550  su.gn.fr_332 zzp.no.nn_322 
  0x422205ad, 0x39202d0c, 0x0e003904, 0x7669010c,   // fr.oc.co_643 sk.sq.br_543  br.is.un_320 en.mfe.crs_543 
  0x080438a7, 0x595529ee, 0x382c3f0c, 0x0b000a0c,   // tk.fi.no_532 sl.rw.rn_422  af.fy.tk_543 pt.es.un_530 
  // [8600]
  0x44001018, 0x2335380c, 0x1000250d, 0x2a0b0a02,   // be.kk.un_740 tk.tg.ky_543  mn.be.un_540 pt.es.mt_222 
  0x0e2c38ee, 0x0e080204, 0x3b3d2813, 0x19000a04,   // tk.fy.is_422 da.no.is_332  sd.ku.ks_665 pt.gl.un_320 
  0x3c001005, 0x494c5a07, 0x36233804, 0x13003504,   // be.ug.un_330 sm.wo.to_432  tk.ky.ab_332 zu.et.un_320 
  0x32003404, 0x497328a0, 0x13330808, 0x240c33ec,   // xh.bs.un_320 sw.ny.to_322  no.nn.et_443 nn.sv.eo_644 
  // [8610]
  0x4d005213, 0x1f005a04, 0x03004a04, 0x12133604,   // ha.aa.un_650 sm.cy.un_320  yo.nl.un_320 gn.et.hu_332 
  0x763901a4, 0x2053690c, 0x21002f09, 0x39001205,   // en.br.crs_433 mfe.ht.sq_543  su.jw.un_440 hu.br.un_330 
  0x39003302, 0x49175aa7, 0x42fe0107, 0x2f000b02,   // nn.br.un_220 sm.sr.to_532  en.tlh.co_432 es.su.un_220 
  0x5e355d07, 0x30484da4, 0x0c025fa4, 0x2118120c,   // ss.zu.ts_432 aa.tt.uz_433  tn.da.sv_433 ur.ar.fa_543 
  // [8620]
  0x404205a6, 0x65573b13, 0x78064012, 0x762f69ad,   // fr.co.lb_521 so.na.gv_665  lb.de.ve_654 mfe.su.crs_643 
  0x465c6905, 0x5dfc3507, 0x29002809, 0x2700011a,   // mfe.sa.qu_333 zu.zzp.ss_432  sw.sl.un_440 en.gd.un_760 
  0x016534a0, 0x78fc5ead, 0x48000108, 0x4069760e,   // xh.gv.en_322 ts.zzp.ve_643  en.tt.un_430 crs.mfe.lb_555 
  0x42280f0b, 0x110a05a9, 0x65fc47a7, 0x3e3308ad,   // lv.sw.co_542 fr.pt.ro_544  sn.zzp.gv_532 no.nn.rm_643 
  // [8630]
  0x36052fa0, 0x01fc47a0, 0x7310fe0c, 0x38006907,   // su.fr.gn_322 sn.zzp.en_322  tlh.lt.ny_543 mfe.tk.un_420 
  0x2f190b05, 0x4700fc19, 0x3b696311, 0x6263010c,   // es.gl.su_333 zzp.sn.un_750  sco.mfe.so_653 en.sco.kha_543 
  0x03005002, 0x1044380c, 0x3e0f3911, 0x05223904,   // fj.nl.un_220 tk.kk.be_543  br.lv.rm_653 br.oc.fr_332 
  0x1d001108, 0x2a003302, 0x3e0a69a4, 0x0704080c,   // ro.la.un_430 nn.mt.un_220  mfe.pt.rm_433 uk.ru.bg_543 
  // [8640]
  0x3402630d, 0x0200341b, 0x69103e14, 0x75350107,   // sco.da.xh_554 xh.da.un_770  rm.lt.mfe_666 en.zu.nso_432 
  0x631f06ad, 0x18234413, 0x50643404, 0x502d3604,   // de.cy.sco_643 kk.ky.ar_665  xh.lg.fj_332 gn.sk.fj_332 
  0x27001d0d, 0x34000108, 0x17506455, 0x32505e0c,   // la.gd.un_540 en.xh.un_430  lg.fj.sr_442 ts.fj.bs_543 
  0x450205a4, 0x285dfca7, 0x381b3113, 0x5300fc08,   // fr.da.ln_433 zzp.ss.sw_532  az.tr.tk_665 zzp.ht.un_430 
  // [8650]
  0x3700fc08, 0x05212fa0, 0x454205ad, 0x27180555,   // zzp.st.un_430 su.jw.fr_322  fr.co.ln_643 fr.ga.gd_442 
  0x051d18ad, 0x302b6313, 0x150704ec, 0x2f052112,   // ga.la.fr_643 sco.vi.uz_665  ru.bg.un_644 jw.fr.su_654 
  0x213d34af, 0x3c30230c, 0x0802050c, 0x2b004e13,   // ps.ku.fa_655 ky.uz.ug_543  fr.da.no_543 ay.vi.un_650 
  0x2325380c, 0x5c1cfeee, 0x2f1e5c04, 0x37001721,   // tk.mn.ky_543 tlh.id.sa_422  sa.ms.su_332 sr.ba.un_860 
  // [8660]
  0x442330a4, 0x30003623, 0x4c2223a4, 0x15003821,   // uz.ky.kk_433 ab.uz.un_880  ca.oc.wo_433 tk.un.un_860 
  0x32642808, 0x3bfe610c, 0x5c5f37ad, 0x64321602,   // sw.lg.bs_443 za.tlh.so_543  st.tn.sa_643 hr.bs.lg_222 
  0x080736a0, 0x071108ad, 0x18281209, 0x64044fec,   // ab.bg.uk_322 uk.ro.bg_643  ur.sd.ar_444 bi.fi.lg_644 
  0x04001a02, 0x34301213, 0x3f497307, 0x5200511b,   // tl.fi.un_220 ur.uz.ps_665  ny.to.af_432 kl.ha.un_770 
  // [8670]
  0x1500372b, 0x7335345a, 0x045a0eaf, 0x480a110c,   // ba.un.un_980 xh.zu.ny_553  is.sm.fi_655 ro.mk.tt_543 
  0x12100907, 0x1000070d, 0x4810300c, 0x12004c05,   // pl.lt.hu_432 bg.be.un_540  uz.be.tt_543 wo.hu.un_330 
  0x24536402, 0x3f2c0302, 0x38003b05, 0x32000208,   // lg.ht.eo_222 nl.fy.af_222  so.tk.un_330 da.bs.un_430 
  0x39004607, 0x345d5c04, 0x5928550b, 0x10090208,   // qu.br.un_420 sa.ss.xh_332  rw.sw.rn_542 da.pl.lt_443 
  // [8680]
  0x13010404, 0x4c5658ad, 0x1800050b, 0x73353405,   // fi.en.et_332 om.mg.wo_643  fr.ga.un_520 xh.zu.ny_333 
  0x5d001c08, 0x250430a7, 0x4b28540c, 0x1c000d18,   // id.ss.un_430 uz.ru.mn_532  ik.sw.mi_543 ne.mr.un_740 
  0x3400230d, 0x09006504, 0x4a5d05a0, 0x100a23ec,   // ky.ps.un_540 gv.pl.un_320  fr.ss.yo_322 ky.mk.be_644 
  0x0a3c170c, 0x34002307, 0x34fc4fee, 0x0a001111,   // sr.ug.mk_543 ky.ps.un_420  bi.zzp.xh_422 ro.mk.un_630 
  // [8690]
  0x4410085a, 0x73261307, 0x51005904, 0x4815370d,   // uk.be.kk_553 et.ia.ny_432  rn.kl.un_320 ba.tt.un_540 
  0x4a190b08, 0x063b63a0, 0x2f054205, 0x650c09ec,   // es.gl.yo_443 sco.so.de_322  co.fr.su_333 pl.sv.gv_644 
  0x05000b0e, 0x457505a4, 0x5d05730c, 0x0535340d,   // es.fr.un_550 fr.nso.ln_433  ny.fr.ss_543 xh.zu.fr_554 
  0x29090d07, 0x3c002302, 0x37002319, 0x37004520,   // cs.pl.sl_432 ky.ug.un_220  ky.ba.un_750 ln.st.un_850 
  // [86a0]
  0x582a3508, 0x0a1735a4, 0x4c5505a0, 0x64000402,   // zu.mt.om_443 tg.sr.mk_433  fr.rw.wo_322 fi.lg.un_220 
  0x302f0402, 0x0d000e07, 0x12046405, 0x0d00531e,   // fi.su.uz_222 is.cs.un_420  lg.fi.hu_333 ht.cs.un_830 
  0x404805a0, 0x390657a7, 0x5c566ea0, 0x2d091205,   // fr.tt.lb_322 na.de.br_532  hmn.mg.sa_322 hu.pl.sk_333 
  0x16002608, 0x0e796bee, 0x13200f07, 0x6e4205ee,   // ia.hr.un_430 ceb.war.is_422  lv.sq.et_432 fr.co.hmn_422 
  // [86b0]
  0x45006412, 0x64002404, 0x3f1265a0, 0x080a1508,   // lg.ln.un_640 eo.lg.un_320  gv.hu.af_322 un.mk.uk_443 
  0x426905a7, 0x483073ad, 0x1c002f0d, 0x21004c0c,   // fr.mfe.co_532 ny.uz.tt_643  su.id.un_540 wo.jw.un_530 
  0x485305a6, 0x242509ec, 0x55007307, 0x04253607,   // fr.ht.tt_521 pl.eu.eo_644  ny.rw.un_420 ab.mn.ru_432 
  0x321612a0, 0x45002113, 0x2a29120c, 0x34182804,   // hu.hr.bs_322 jw.ln.un_650  hu.sl.mt_543 sd.ar.ps_332 
  // [86c0]
  0x0e480d04, 0x19230b07, 0x56000508, 0x2f004205,   // cs.tt.is_332 es.ca.gl_432  fr.mg.un_430 co.su.un_330 
  0x1b50730c, 0x24001313, 0x2d355da4, 0x24601d55,   // ny.fj.tr_543 et.eo.un_650  ss.zu.sk_433 la.vo.eo_442 
  0x4f000f0d, 0x736550a0, 0x181d2407, 0x2a074008,   // lv.bi.un_540 fj.gv.ny_322  eo.la.ga_432 lb.it.mt_443 
  0x31201e04, 0x46005218, 0x36212f08, 0x12000e07,   // ms.sq.az_332 ha.qu.un_740  su.jw.gn_443 is.hu.un_420 
  // [86d0]
  0x222f45a4, 0x284c49a7, 0x38000919, 0x59307305,   // ln.su.oc_433 to.wo.sw_532  pl.tk.un_750 ny.uz.rn_333 
  0x0600401b, 0x2e020e0d, 0x1007350c, 0x46003f08,   // lb.de.un_770 is.da.fo_554  tg.bg.be_543 af.qu.un_430 
  0x4d654c5a, 0x17002408, 0x30003113, 0x2a766912,   // wo.gv.aa_553 eo.sr.un_430  az.uz.un_650 mfe.crs.mt_654 
  0x5900730e, 0x313028ec, 0x17001112, 0x3800090d,   // ny.rn.un_550 sw.uz.az_644  ro.sr.un_640 pl.tk.un_540 
  // [86e0]
  0x081544a6, 0x51000211, 0x274609a4, 0x0e00060e,   // kk.uk.un_510 da.kl.un_630  pl.qu.gd_433 de.is.un_550 
  0x3f6558af, 0x0a003007, 0x21000609, 0x3406350c,   // om.gv.af_655 uz.mk.un_420  de.jw.un_440 zu.de.xh_543 
  0x330657a4, 0xfc353455, 0x34000604, 0x1bfc1504,   // na.de.nn_433 xh.zu.zzp_442  de.xh.un_320 un.zzp.tr_332 
  0x15000607, 0x07004204, 0x02002e0c, 0x15fc370c,   // de.un.un_420 co.it.un_320  fo.da.un_530 st.zzp.un_543 
  // [86f0]
  0x0d00fc02, 0x061e1c13, 0x190a43a9, 0x02251da0,   // zzp.cs.un_220 id.ms.de_665  ie.pt.gl_544 la.eu.da_322 
  0x30003d08, 0x0d2d290b, 0x3c003612, 0x30153b07,   // ku.uz.un_430 sl.sk.cs_542  ab.ug.un_640 so.uz.un_420 
  0x08070aa4, 0x04006b0c, 0x0e003807, 0x39462704,   // mk.bg.uk_433 ceb.fi.un_530  tk.is.un_420 gd.qu.br_332 
  0x48003718, 0x32000605, 0x2e006812, 0x155503a0,   // ba.tt.un_740 de.bs.un_330  ig.fo.un_640 nl.rw.un_322 
  // [8700]
  0x65000602, 0x040708a4, 0x23001009, 0x25361111,   // de.gv.un_220 uk.bg.ru_433  be.ky.un_440 ro.ab.mn_653 
  0x39041004, 0x154830a0, 0x32162402, 0x212812ec,   // lt.fi.br_332 uz.tt.un_322  eo.hr.bs_222 ur.sd.fa_644 
  0x12002f05, 0x213c30a4, 0x1500042c, 0x53003814,   // su.hu.un_330 uz.ug.fa_433  ru.un.un_990 tk.ht.un_660 
  0x231048a4, 0x35383005, 0x1c001a02, 0x084417a0,   // tt.be.ky_433 uz.tk.tg_333  tl.id.un_220 sr.kk.uk_322 
  // [8710]
  0x11443812, 0x53003b04, 0x1a003b13, 0x4d000213,   // tk.kk.ro_654 so.ht.un_320  so.tl.un_650 da.aa.un_650 
  0x5202fea4, 0x44374804, 0x1d5d60ad, 0x64001807,   // tlh.da.ha_433 tt.ba.kk_332  vo.ss.la_643 ga.lg.un_420 
  0x55004a1a, 0x184a27ad, 0x17040704, 0x1c2f520c,   // yo.rw.un_760 gd.yo.ga_643  bg.ru.sr_332 ha.su.id_543 
  0x295c3604, 0x0f1c1ea4, 0x6b1b5805, 0x55255908,   // gn.sa.sl_332 ms.id.lv_433  om.tr.ceb_333 rn.eu.rw_443 
  // [8720]
  0x0d003621, 0x130657ad, 0x3b002821, 0x5500fe0e,   // gn.cs.un_860 na.de.et_643  sd.ks.un_860 tlh.rw.un_550 
  0x5c0f3613, 0x303c3505, 0x30003702, 0x0415100c,   // gn.lv.sa_665 tg.ug.uz_333  st.uz.un_220 be.ru.un_530 
  0x1d39fea0, 0x2ffe2107, 0x30353ca9, 0x342130ee,   // tlh.br.la_322 jw.tlh.su_432  ug.tg.uz_544 uz.fa.ps_422 
  0x222f120c, 0x2a4039af, 0x12000512, 0x213412ee,   // hu.su.oc_543 br.lb.mt_655  fr.hu.un_640 ur.ps.fa_422 
  // [8730]
  0x4c6e0111, 0x17000f09, 0x4f001c08, 0x0640fe0e,   // en.hmn.wo_653 lv.sr.un_440  id.bi.un_430 tlh.lb.de_555 
  0x03022007, 0x2d215005, 0x10000d04, 0x6b111d07,   // sq.da.nl_432 fj.jw.sk_333  cs.lt.un_320 la.ro.ceb_432 
  0x095c1311, 0x07080a04, 0x500f1055, 0x1d6e01af,   // bh.sa.hi_653 mk.uk.bg_332  lt.lv.fj_442 en.hmn.la_655 
  0x100a0407, 0x02560ca4, 0x300276a4, 0x024e65a4,   // ru.mk.be_432 sv.mg.da_433  crs.da.uz_433 gv.ay.da_433 
  // [8740]
  0x48001007, 0x1d002904, 0x2d491504, 0x10003811,   // be.tt.un_420 sl.la.un_320  un.to.sk_332 tk.lt.un_630 
  0x1d006e35, 0x05001209, 0x153c1512, 0x08043504,   // hmn.la.un_A90 hu.fr.un_440  un.ug.un_654 tg.ru.uk_332 
  0x3023250c, 0x382a4dac, 0x494c3107, 0x10122d04,   // mn.ky.uz_543 aa.mt.tk_632  az.wo.to_432 sk.hu.lt_332 
  0x395860ee, 0x36001a08, 0x49001204, 0x5a375f04,   // vo.om.br_422 tl.gn.un_430  hu.to.un_320 tn.st.sm_332 
  // [8750]
  0x1d261a05, 0x2e0251a0, 0x215c1cad, 0x1d003f02,   // tl.ia.la_333 kl.da.fo_322  id.sa.jw_643 af.la.un_220 
  0x30005712, 0x5955680c, 0x130e2c04, 0x052f3605,   // na.uz.un_640 ig.rw.rn_543  fy.is.et_332 gn.su.fr_333 
  0x05190d02, 0x23003e02, 0x15061207, 0x345d2802,   // cs.gl.fr_222 rm.ca.un_220  hu.de.un_432 sw.ss.xh_222 
  0x67286812, 0x0f301b08, 0x53004a05, 0x36125d05,   // ig.sw.ak_654 tr.uz.lv_443  yo.ht.un_330 ss.hu.gn_333 
  // [8760]
  0x5f00680c, 0x2a003004, 0x735c530c, 0x2d00090e,   // ig.tn.un_530 uz.mt.un_320  ht.sa.ny_543 pl.sk.un_550 
  0x3e1501a4, 0x4204630e, 0x2b001008, 0x15000904,   // en.rm.un_430 sco.fi.co_555  lt.vi.un_430 pl.un.un_320 
  0x214c0502, 0x30006407, 0x48001d04, 0x3f06fc08,   // fr.wo.jw_222 lg.uz.un_420  la.tt.un_320 zzp.de.af_443 
  0x09004f14, 0x3d3430ec, 0x10150460, 0x0407085a,   // bi.pl.un_660 uz.ps.ku_644  ru.be.un_640 uk.bg.ru_553 
  // [8770]
  0x37fc5f0d, 0x5e1209ad, 0x242530a0, 0x47392804,   // tn.zzp.st_554 pl.hu.ts_643  uz.eu.eo_322 sw.br.sn_332 
  0x4535fca9, 0x30480f05, 0x75685f0d, 0x0c38030d,   // zzp.zu.ln_544 lv.tt.uz_333  tn.ig.nso_554 nl.tk.sv_554 
  0x2a030407, 0xfc6468a7, 0x190b38ee, 0xfc006407,   // fi.nl.mt_432 ig.lg.zzp_532  tk.es.gl_422 lg.zzp.un_420 
  0x302548a0, 0x4d004219, 0xfc253805, 0x553f03ee,   // tt.eu.uz_322 co.aa.un_750  tk.eu.zzp_333 nl.af.rw_422 
  // [8780]
  0x34212808, 0x2a734a11, 0x3bfe52ad, 0x100208a4,   // sd.fa.ps_443 yo.ny.mt_653  ha.tlh.so_643 no.da.lt_433 
  0x02000813, 0xfc5e0204, 0x64006502, 0x322d1702,   // no.da.un_650 da.ts.zzp_332  gv.lg.un_220 sr.sk.bs_222 
  0x577352a9, 0x3848fc0c, 0x220b64ad, 0x271e58a6,   // ha.ny.na_544 zzp.tt.tk_543  lg.es.oc_643 om.ms.gd_521 
  0x35342aec, 0x5c091ca4, 0x1c5c095a, 0x2a001f0d,   // mt.xh.zu_644 mr.hi.sa_433  hi.sa.mr_553 cy.mt.un_540 
  // [8790]
  0x05360d07, 0x0e2e1f12, 0x22031fee, 0x2f002d04,   // cs.gn.fr_432 cy.fo.is_654  cy.nl.oc_422 sk.su.un_320 
  0x2109730c, 0x31301ba4, 0x30463b04, 0x65791bee,   // ny.pl.jw_543 tr.uz.az_433  so.qu.uz_332 tr.war.gv_422 
  0x251011a9, 0x53002010, 0x65793b04, 0x23043804,   // ro.be.mn_544 sq.ht.un_620  so.war.gv_332 tk.ru.ky_332 
  0x65000202, 0x4a002b05, 0x4a002b09, 0x1b004602,   // da.gv.un_220 vi.yo.un_330  vi.yo.un_440 qu.tr.un_220 
  // [87a0]
  0x343d180b, 0x29001521, 0x1a734707, 0x1b002f0c,   // ar.ku.ps_542 un.sl.un_860  sn.ny.tl_432 su.tr.un_530 
  0x2000121b, 0x134b6ba0, 0x3600050d, 0x30311b13,   // hu.sq.un_770 ceb.mi.et_322  fr.gn.un_540 tr.az.uz_665 
  0x3b005412, 0x21303d0c, 0x36000504, 0x12002829,   // ik.so.un_640 ku.uz.fa_543  fr.gn.un_320 sd.ur.un_960 
  0x12342808, 0x3d303404, 0x463b300e, 0x362212ad,   // sd.ps.ur_443 ps.uz.ku_332  uz.so.qu_555 hu.oc.gn_643 
  // [87b0]
  0x05003e02, 0x4e004619, 0x633901a4, 0x3600120e,   // rm.fr.un_220 qu.ay.un_750  en.br.sco_433 hu.gn.un_550 
  0x63001308, 0x0d000404, 0x63011ca4, 0x04071004,   // et.sco.un_430 fi.cs.un_320  id.en.sco_433 be.bg.ru_332 
  0x79492d07, 0x4e00460e, 0x396301a0, 0x36242aa4,   // sk.to.war_432 qu.ay.un_550  en.sco.br_322 mt.eo.gn_433 
  0x1200361a, 0x32121707, 0x122f360c, 0x04651e07,   // gn.hu.un_760 sr.hu.bs_432  gn.su.hu_543 ms.gv.fi_432 
  // [87c0]
  0x6331010c, 0x0e0c3104, 0x33022ea0, 0x06002802,   // en.az.sco_543 az.sv.is_332  fo.da.nn_322 sw.de.un_220 
  0x6315010c, 0x160d2d11, 0x123b2155, 0x08071504,   // en.sco.un_530 sk.cs.hr_653  fa.ks.ur_442 un.bg.uk_332 
  0x23443709, 0x2e000c09, 0x1a313008, 0x0a0b05a0,   // ba.kk.ky_444 sv.fo.un_440  uz.az.tl_443 fr.es.pt_322 
  0x7653690d, 0x013965a4, 0x050b19ee, 0x3c384411,   // mfe.ht.crs_554 gv.br.en_433  gl.es.fr_422 kk.tk.ug_653 
  // [87d0]
  0x1800010c, 0x123d3ba4, 0x36006b04, 0x2f1e1c0e,   // en.ga.un_530 ks.ku.ur_433  ceb.gn.un_320 id.ms.su_555 
  0x26691a05, 0x1c2e15a0, 0x6b791a08, 0x1d007904,   // tl.mfe.ia_333 un.fo.id_322  tl.war.ceb_443 war.la.un_320 
  0x2e080cee, 0x13091c07, 0x0f2910a4, 0x15483ca4,   // sv.no.fo_422 mr.hi.bh_432  lt.sl.lv_433 ug.tt.un_433 
  0x5e00fc04, 0x2c1d79a0, 0x1a6b1b04, 0x30080455,   // zzp.ts.un_320 war.la.fy_322  tr.ceb.tl_332 ru.uk.uz_442 
  // [87e0]
  0x11000a07, 0x2c002d12, 0x1c2139a0, 0x303c23ec,   // pt.ro.un_420 sk.fy.un_640  br.jw.id_322 ky.ug.uz_644 
  0x150a07ec, 0x5d005b0c, 0x0a002509, 0x10044404,   // bg.mk.un_644 sg.ss.un_530  mn.mk.un_440 kk.ru.be_332 
  0x213b280c, 0x30113ca9, 0x091c5ca6, 0x1c5c09a6,   // sd.ks.fa_543 ug.ro.uz_544  sa.mr.hi_521 hi.sa.mr_521 
  0xfc003f0d, 0x2f001e07, 0x130d095a, 0x05002104,   // af.zzp.un_540 ms.su.un_420  hi.ne.bh_553 jw.fr.un_320 
  // [87f0]
  0x20401e04, 0x2e120e07, 0x2f1c1eaf, 0x1e3e2f07,   // ms.lb.sq_332 is.hu.fo_432  ms.id.su_655 su.rm.ms_432 
  0x1234180e, 0x3e182004, 0x49003704, 0x1b182712,   // ar.ps.ur_555 sq.ga.rm_332  st.to.un_320 gd.ga.tr_654 
  0x73344709, 0x43000e19, 0x360a150c, 0x0a002f04,   // sn.xh.ny_444 is.ie.un_750  un.mk.ab_543 su.pt.un_320 
  0x0a403e08, 0x567359a9, 0x05120aa0, 0x0a000819,   // rm.lb.pt_443 rn.ny.mg_544  pt.hu.fr_322 uk.mk.un_750 
  
  // [8800]
  0x355f495a, 0x2f052107, 0x35035da9, 0x0d1f48ee,   // to.tn.zu_553 jw.fr.su_432  ss.nl.zu_544 tt.cy.cs_422 
  0x5f3747ee, 0x602f12ec, 0x691f01a4, 0x041507af,   // sn.st.tn_422 hu.su.vo_644  en.cy.mfe_433 bg.ru.un_650 
  0x4c695307, 0x056527af, 0x23443b05, 0x3f1264a4,   // ht.mfe.wo_432 gd.gv.fr_655  ks.kk.ky_333 lg.hu.af_433 
  0x0c33060c, 0x07254807, 0x03003204, 0x40020d07,   // de.nn.sv_543 tt.mn.bg_432  bs.nl.un_320 cs.da.lb_432 
  // [8810]
  0x022a03ec, 0x153038ec, 0x1f000d13, 0x48221804,   // nl.mt.da_644 tk.uz.un_644  cs.cy.un_650 ga.oc.tt_332 
  0x2b0e2ea0, 0x3e561555, 0x2e0e27ee, 0x0506560c,   // fo.is.vi_322 un.mg.rm_442  gd.is.fo_422 mg.de.fr_543 
  0x3c2344a7, 0x62391fa9, 0x0335340c, 0x151f1d04,   // kk.ky.ug_532 cy.br.kha_544  xh.zu.nl_543 la.cy.un_332 
  0x11004904, 0x080522ac, 0x5e731208, 0x57642809,   // to.ro.un_320 oc.fr.no_632  hu.ny.ts_443 sw.lg.na_444 
  // [8820]
  0x033f55a9, 0x2200561a, 0x1d313307, 0x02122d0c,   // rw.af.nl_544 mg.oc.un_760  nn.az.la_432 sk.hu.da_543 
  0x65000d08, 0x30006304, 0x122d0aee, 0x082812a4,   // cs.gv.un_430 sco.uz.un_320  pt.sk.hu_422 hu.sw.no_433 
  0x07231508, 0x33052202, 0x0d781f0c, 0x6500150c,   // un.ky.bg_443 oc.fr.nn_222  cy.ve.cs_543 un.gv.un_530 
  0x08111708, 0x420e0d04, 0x62002a1a, 0x0165570b,   // sr.ro.uk_443 cs.is.co_332  mt.kha.un_760 na.gv.en_542 
  // [8830]
  0x060220a7, 0x20fe4707, 0x2f1a6104, 0x47135707,   // sq.da.de_532 sn.tlh.sq_432  za.tl.su_332 na.et.sn_432 
  0x320f47ee, 0x292f6004, 0x12001c0d, 0x1548300c,   // sn.lv.bs_422 vo.su.sl_332  id.hu.un_540 uz.tt.un_543 
  0x1a002c02, 0x5c550407, 0x37130107, 0x0c00390c,   // fy.tl.un_220 fi.rw.sa_432  en.et.st_432 br.sv.un_530 
  0x1021670c, 0x481b6011, 0x2f3216a0, 0x13002512,   // ak.jw.lt_543 vo.tr.tt_653  hr.bs.su_322 eu.et.un_640 
  // [8840]
  0x10004d08, 0x29001705, 0x2f13570c, 0x13043807,   // aa.lt.un_430 sr.sl.un_330  na.et.su_543 tk.fi.et_432 
  0x40004a08, 0x2b002c02, 0x203e0107, 0x1600290d,   // yo.lb.un_430 fy.vi.un_220  en.rm.sq_432 sl.hr.un_540 
  0x0c130605, 0x79363b55, 0x164729a4, 0x69733408,   // de.et.sv_333 so.gn.war_442  sl.sn.hr_433 xh.ny.mfe_443 
  0x064025ad, 0x215c3007, 0x5e5d45a9, 0x5300470c,   // eu.lb.de_643 uz.sa.jw_432  ln.ss.ts_544 sn.ht.un_530 
  // [8850]
  0x0115fe08, 0x2f00210e, 0x0f2a2905, 0x647345a7,   // tlh.en.un_430 jw.su.un_550  sl.mt.lv_333 ln.ny.lg_532 
  0x28002319, 0x25152f04, 0x63651e04, 0x4a4c6502,   // ky.sd.un_750 su.eu.un_320  ms.gv.sco_332 gv.wo.yo_222 
  0x4d0645ac, 0x0c3304a0, 0x3b692f12, 0x2d0d1ca0,   // ln.de.aa_632 fi.nn.sv_322  su.mfe.so_654 id.cs.sk_322 
  0x233c38af, 0x6b4c60ad, 0x3217290e, 0x21581ba4,   // tk.ug.ky_655 vo.wo.ceb_643  sl.sr.bs_555 tr.om.jw_433 
  // [8860]
  0x13000202, 0x35001521, 0x39007304, 0x3d003407,   // da.et.un_220 un.tg.un_860  ny.br.un_320 ps.ku.un_420 
  0x2d0d09ec, 0x4c5e30a0, 0x62730508, 0x3c2338af,   // pl.cs.sk_644 uz.ts.wo_322  fr.ny.kha_443 tk.ky.ug_655 
  0x58003011, 0x475e69ad, 0x30383555, 0x52343511,   // uz.om.un_630 mfe.ts.sn_643  tg.tk.uz_442 zu.xh.ha_653 
  0x50000907, 0x3b587304, 0x64001e04, 0x4410080c,   // pl.fj.un_420 ny.om.so_332  ms.lg.un_320 uk.be.kk_543 
  // [8870]
  0x040836a6, 0x12213b0e, 0x785e730d, 0x18234411,   // ab.uk.ru_521 ks.fa.ur_555  ny.ts.ve_554 kk.ky.ar_653 
  0x595550a4, 0x6459555a, 0x5c006e0c, 0x1b50fea4,   // fj.rw.rn_433 rw.rn.lg_553  hmn.sa.un_530 tlh.fj.tr_433 
  0x422a3eaf, 0x10006422, 0x40000109, 0x73005505,   // rm.mt.co_655 lg.lt.un_870  en.lb.un_440 rw.ny.un_330 
  0x595055af, 0x2330250c, 0x5e503ea4, 0x48003114,   // rw.fj.rn_655 mn.uz.ky_543  rm.fj.ts_433 az.tt.un_660 
  // [8880]
  0x04005604, 0x1b000f0c, 0x56005305, 0x50005e08,   // mg.fi.un_320 lv.tr.un_530  ht.mg.un_330 ts.fj.un_430 
  0x56270407, 0x42503605, 0x343f04a0, 0x37234414,   // fi.gd.mg_432 gn.fj.co_333  fi.af.xh_322 kk.ky.ba_666 
  0x39006318, 0x56580407, 0x303146ad, 0x06004709,   // sco.br.un_740 fi.om.mg_432  qu.az.uz_643 sn.de.un_440 
  0x64343ba7, 0x35305e5a, 0x795d01ee, 0x355e3b0c,   // so.xh.lg_532 ts.uz.zu_553  en.ss.war_422 so.ts.zu_543 
  // [8890]
  0x0825300c, 0x34003b08, 0x403f03ee, 0x3b301b08,   // uz.mn.uk_543 so.xh.un_430  nl.af.lb_422 tr.uz.so_443 
  0x791a6b04, 0x30643bad, 0x1a000404, 0x793b30a4,   // ceb.tl.war_332 so.lg.uz_643  fi.tl.un_320 uz.so.war_433 
  0x17000412, 0x173036a0, 0x11003613, 0x07576aa9,   // ru.sr.un_640 ab.uz.sr_322  ab.ro.un_650 haw.na.it_544 
  0x37007813, 0x0e2b120c, 0x311b6502, 0x102429a9,   // ve.st.un_650 hu.vi.is_543  gv.tr.az_222 sl.eo.lt_544 
  // [88a0]
  0x15003b08, 0x52005004, 0x38301baf, 0xfc0e0cee,   // so.un.un_430 fj.ha.un_320  tr.uz.tk_655 sv.is.zzp_422 
  0x371d5707, 0x03002b0d, 0x67001508, 0x461b3108,   // na.la.st_432 vi.nl.un_540  un.ak.un_430 az.tr.qu_443 
  0x33120eee, 0x56fe5c04, 0x311bfca4, 0x6a4b5aaf,   // is.hu.nn_422 sa.tlh.mg_332  zzp.tr.az_433 sm.mi.haw_655 
  0x313b3013, 0x2f122b07, 0x45000205, 0x20005311,   // uz.so.az_665 vi.hu.su_432  da.ln.un_330 ht.sq.un_630 
  // [88b0]
  0x34002823, 0x305056a4, 0x2b004007, 0x34194d0d,   // sd.ps.un_880 mg.fj.uz_433  lb.vi.un_420 aa.gl.xh_554 
  0x60000608, 0x5c005005, 0x0a3c08a4, 0xfc0b1dee,   // de.vo.un_430 fj.sa.un_330  uk.ug.mk_433 la.es.zzp_422 
  0x374804ad, 0x2b002f0e, 0x73000d04, 0x0c021da0,   // ru.tt.ba_643 su.vi.un_550  cs.ny.un_320 la.da.sv_322 
  0x5000340d, 0x2b004a02, 0x53004c05, 0x0e2e38ec,   // xh.fj.un_540 yo.vi.un_220  wo.ht.un_330 tk.fo.is_644 
  // [88c0]
  0x33081dee, 0x462a5008, 0x53024c07, 0x50025c07,   // la.no.nn_422 fj.mt.qu_443  wo.da.ht_432 sa.da.fj_432 
  0x697601a4, 0x0b00050c, 0x1300120d, 0x6500570d,   // en.crs.mfe_433 fr.es.un_530  hu.et.un_540 na.gv.un_540 
  0x363038af, 0x133f4ca0, 0x2c0c0205, 0x534505ec,   // tk.uz.ab_655 wo.af.et_322  da.sv.fy_333 fr.ln.ht_644 
  0x4c001305, 0x5300050e, 0x64400602, 0x272f280c,   // et.wo.un_330 fr.ht.un_550  de.lb.lg_222 sw.su.gd_543 
  // [88d0]
  0x0b60090c, 0x1d0c030e, 0x0f062d08, 0x2a063fad,   // pl.vo.es_543 nl.sv.la_555  sk.de.lv_443 af.de.mt_643 
  0x06000a08, 0x0f001d12, 0x48041504, 0x0e4c2807,   // pt.de.un_430 la.lv.un_640  un.ru.tt_332 sw.wo.is_432 
  0x0f000902, 0x08002e02, 0x1e003508, 0x1b650407,   // pl.lv.un_220 fo.no.un_220  zu.ms.un_430 fi.gv.tr_432 
  0x2a006507, 0x65005805, 0x03066b02, 0x182b1c04,   // gv.mt.un_420 om.gv.un_330  ceb.de.nl_222 id.vi.ga_332 
  // [88e0]
  0x3f003502, 0xfc35450c, 0x330839ee, 0x3f4d4ca4,   // zu.af.un_220 ln.zu.zzp_543  br.no.nn_422 wo.aa.af_433 
  0x25034c0c, 0x32003904, 0x21003f02, 0x1312600c,   // wo.nl.eu_543 br.bs.un_320  af.jw.un_220 vo.hu.et_543 
  0x1b003502, 0x12001304, 0x100c6ba6, 0x65005808,   // zu.tr.un_220 et.hu.un_320  ceb.sv.lt_521 om.gv.un_430 
  0x072412ad, 0x0c0402a0, 0x35004512, 0x654c58af,   // hu.eo.it_643 da.fi.sv_322  ln.zu.un_640 om.wo.gv_655 
  // [88f0]
  0x495d50ec, 0x041a34a0, 0x1c095c55, 0x09000a07,   // fj.ss.to_644 xh.tl.fi_322  sa.hi.mr_442 pt.pl.un_420 
  0x50455504, 0x465d55ee, 0x4d421fec, 0x64fc1aa0,   // rw.ln.fj_332 rw.ss.qu_422  cy.co.aa_644 tl.zzp.lg_322 
  0x65003404, 0x46002805, 0x12001005, 0x02006b05,   // xh.gv.un_320 sw.qu.un_330  lt.hu.un_330 ceb.da.un_330 
  0x02345f05, 0x0f006412, 0x28007308, 0x07001d08,   // tn.xh.da_333 lg.lv.un_640  ny.sw.un_430 la.it.un_430 
  // [8900]
  0x576339af, 0x1101fc07, 0x5800651b, 0x42005012,   // br.sco.na_655 zzp.en.ro_432  gv.om.un_770 fj.co.un_640 
  0x05005104, 0x6563010b, 0x44073707, 0x791f1b60,   // kl.fr.un_320 en.sco.gv_542  ba.bg.kk_432 tr.cy.war_664 
  0x48002902, 0x2a001f07, 0x18282302, 0x35081004,   // sl.tt.un_220 cy.mt.un_420  ky.sd.ar_222 be.uk.tg_332 
  0x152a040c, 0x480c060c, 0x3d343013, 0x3f2c0208,   // fi.mt.un_543 de.sv.tt_543  uz.ps.ku_665 da.fy.af_443 
  // [8910]
  0x10120407, 0x020413ac, 0x1543010c, 0x64005202,   // fi.hu.lt_432 et.fi.da_632  en.ie.un_543 ha.lg.un_220 
  0x01fc1255, 0x04024c08, 0x23440aad, 0x46005e21,   // hu.zzp.en_442 wo.da.fi_443  mk.kk.ky_643 ts.qu.un_860 
  0x53004605, 0x091c130d, 0x38113008, 0x1b00020c,   // qu.ht.un_330 bh.mr.hi_554  uz.ro.tk_443 da.tr.un_530 
  0x334d2ca4, 0x3f034d07, 0x48373cec, 0x02036409,   // fy.aa.nn_433 aa.nl.af_432  ug.ba.tt_644 lg.nl.da_444 
  // [8920]
  0x64002a0e, 0x64024cec, 0x302538ee, 0x0837150b,   // mt.lg.un_550 wo.da.lg_644  tk.mn.uz_422 un.ba.uk_542 
  0x3f124dad, 0x04130204, 0x37005d0c, 0x4c006402,   // aa.hu.af_643 da.et.fi_332  ss.st.un_530 lg.wo.un_220 
  0x0000582d, 0x0d095c08, 0x07043ca4, 0x07170811,   // om.un.un_A00 sa.hi.ne_443  ug.ru.bg_433 uk.sr.bg_653 
  0x04126004, 0x07150a08, 0x0a17070c, 0x17162902,   // vo.hu.fi_332 mk.bg.un_430  bg.sr.mk_543 sl.hr.sr_222 
  // [8930]
  0x2337150d, 0x5400360e, 0x3f00502b, 0x120413a4,   // un.ba.ky_554 gn.ik.un_550  fj.af.un_980 et.fi.hu_433 
  0x64003604, 0x3f5f47ec, 0x373f5f0b, 0x04170aa9,   // gn.lg.un_320 sn.tn.af_644  tn.af.st_542 mk.sr.ru_544 
  0x13001004, 0x4a002118, 0x40002f04, 0x06000c0d,   // lt.et.un_320 jw.yo.un_740  su.lb.un_320 sv.de.un_540 
  0x0b65020c, 0x21343011, 0x53653604, 0x15004808,   // da.gv.es_543 uz.ps.fa_653  gn.gv.ht_332 tt.un.un_430 
  // [8940]
  0x59002822, 0x3730380b, 0x4b003f02, 0x04003f04,   // sw.rn.un_870 tk.uz.ba_542  af.mi.un_220 af.fi.un_320 
  0x34003c04, 0x2e001f0c, 0x47040fa0, 0x420711a4,   // ug.ps.un_320 cy.fo.un_530  lv.fi.sn_322 ro.it.co_433 
  0x1dfe1302, 0x0e001308, 0x11442313, 0x043517a0,   // et.tlh.la_222 et.is.un_430  ky.kk.ro_665 sr.tg.ru_322 
  0x1e001f0c, 0x6e6b68a0, 0x1d2b39a0, 0x440415ee,   // cy.ms.un_530 ig.ceb.hmn_322  br.vi.la_322 un.ru.kk_422 
  // [8950]
  0x2e044704, 0x56504755, 0x28002a05, 0x493634a9,   // sn.fi.fo_332 sn.fj.mg_442  mt.sw.un_330 xh.gn.to_544 
  0x35040708, 0x5c5a36ad, 0x34001f08, 0x46004e22,   // bg.ru.tg_443 gn.sm.sa_643  cy.xh.un_430 ay.qu.un_870 
  0x1821280c, 0x473436a9, 0x0200551a, 0x352510ee,   // sd.fa.ar_543 gn.xh.sn_544  rw.da.un_760 be.mn.tg_422 
  0x070b02ee, 0x55006405, 0x1c3031a4, 0x5c130604,   // da.es.it_422 lg.rw.un_330  az.uz.id_433 de.et.sa_332 
  // [8960]
  0x15fe4607, 0x33000b2a, 0x5e6455a0, 0x430e5c08,   // qu.tlh.un_432 bn.as.un_970  rw.lg.ts_322 sa.is.ie_443 
  0x345f5d0d, 0x02001f1a, 0x1d001c02, 0x35007307,   // ss.tn.xh_554 cy.da.un_760  id.la.un_220 ny.zu.un_420 
  0x51005c07, 0x32171002, 0x3c233014, 0x0a000723,   // sa.kl.un_420 lt.sr.bs_222  uz.ky.ug_666 bg.mk.un_880 
  0x42004c04, 0x45000107, 0x130163a0, 0x3c381505,   // wo.co.un_320 en.ln.un_420  sco.en.et_322 un.tk.ug_333 
  // [8970]
  0x07351007, 0x12183404, 0x02330c0c, 0x0c5706af,   // be.tg.bg_432 ps.ar.ur_332  sv.nn.da_543 de.na.sv_655 
  0x432c0112, 0x49135a0c, 0x30472807, 0x0100631b,   // en.fy.ie_654 sm.et.to_543  sw.sn.uz_432 sco.en.un_770 
  0x435706a4, 0x132718a7, 0x233530a6, 0x0e6b3307,   // de.na.ie_433 ga.gd.et_532  uz.tg.ky_521 nn.ceb.is_432 
  0x1300100c, 0x24002d08, 0x10284707, 0x04311b0c,   // lt.et.un_530 sk.eo.un_430  sn.sw.lt_432 tr.az.fi_543 
  // [8980]
  0x0e001f1a, 0x3e001534, 0x040a38ad, 0x32001c04,   // cy.is.un_760 un.rm.un_A80  tk.mk.ru_643 id.bs.un_320 
  0x4800440b, 0x043035a7, 0x07041512, 0x1d4618a7,   // kk.tt.un_520 tg.uz.ru_532  un.ru.bg_654 ga.qu.la_532 
  0x65004c08, 0x63011307, 0x2d006504, 0x65630111,   // wo.gv.un_430 et.en.sco_432  gv.sk.un_320 en.sco.gv_653 
  0x3f03fc08, 0x09004802, 0x693b6513, 0x47007313,   // zzp.nl.af_443 tt.pl.un_220  gv.so.mfe_665 ny.sn.un_650 
  // [8990]
  0x2e020812, 0x0a3c17ac, 0x631f010c, 0x3130480e,   // no.da.fo_654 sr.ug.mk_632  en.cy.sco_543 tt.uz.az_555 
  0x47061fa7, 0x2e0e33ee, 0x183c3055, 0x3e2f1ea4,   // cy.de.sn_532 nn.is.fo_422  uz.ug.ar_442 ms.su.rm_433 
  0x5c355ba9, 0x242204ee, 0x650e010b, 0x5c004702,   // sg.zu.sa_544 fi.oc.eo_422  en.is.gv_542 sn.sa.un_220 
  0x041918a6, 0x3f0603a9, 0x183713ee, 0x03fe3fa0,   // ga.gl.fi_521 nl.de.af_544  et.st.ga_422 af.tlh.nl_322 
  // [89a0]
  0x79011f07, 0x460c1ca0, 0x475d35a9, 0x2a002502,   // cy.en.war_432 id.sv.qu_322  zu.ss.sn_544 eu.mt.un_220 
  0x23202204, 0x48251107, 0x1c000104, 0x443723af,   // oc.sq.ca_332 ro.mn.tt_432  en.id.un_320 ky.ba.kk_655 
  0x2e0e620c, 0x1b383209, 0x40003804, 0x06001e08,   // kha.is.fo_543 bs.tk.tr_444  tk.lb.un_320 ms.de.un_430 
  0x233537a0, 0x35004012, 0x0933085a, 0x48302307,   // ba.tg.ky_322 lb.zu.un_640  no.nn.pl_553 ky.uz.tt_432 
  // [89b0]
  0x25071507, 0x29181eee, 0x0d1c13a4, 0x1233085a,   // un.bg.mn_432 ms.ga.sl_422  bh.mr.ne_433 no.nn.hu_553 
  0x38001804, 0x0e003007, 0x443530a0, 0x0c002e04,   // ga.tk.un_320 uz.is.un_420  uz.tg.kk_322 fo.sv.un_320 
  0x301125af, 0x20004605, 0x34123ba0, 0x2f211212,   // mn.ro.uz_655 qu.sq.un_330  ks.ur.ps_322 hu.jw.su_654 
  0x65630207, 0x48002f05, 0x3600110c, 0x44100807,   // da.sco.gv_432 su.tt.un_330  ro.gn.un_530 uk.be.kk_432 
  // [89c0]
  0x0403fe02, 0x18494dec, 0x03003302, 0x30001505,   // tlh.nl.fi_222 aa.to.ga_644  nn.nl.un_220 un.uz.un_330 
  0x12494a07, 0x242c39ee, 0x3c1138af, 0x2d0d27af,   // yo.to.hu_432 br.fy.eo_422  tk.ro.ug_655 gd.cs.sk_655 
  0x17382708, 0x233c34a4, 0xfc1502a4, 0x2a004b04,   // gd.tk.sr_443 ps.ug.ky_433  da.zzp.un_430 mi.mt.un_320 
  0x6b151da4, 0x230a11a0, 0x3725480c, 0x22005311,   // la.ceb.un_430 ro.mk.ky_322  tt.mn.ba_543 ht.oc.un_630 
  // [89d0]
  0x444838ee, 0x4a526404, 0x35002305, 0x10004c04,   // tk.tt.kk_422 lg.ha.yo_332  ky.tg.un_330 wo.lt.un_320 
  0x24003304, 0x24003605, 0x24001a0d, 0x09190ba4,   // nn.eo.un_320 gn.eo.un_330  tl.eo.un_540 es.gl.pl_433 
  0x2d1a79ec, 0x040247a7, 0x350264a9, 0x3b624c60,   // war.tl.sk_644 sn.da.fi_532  lg.da.zu_544 wo.kha.so_664 
  0x5f3b6a05, 0x27003b05, 0x3f49600c, 0x09001334,   // haw.so.tn_333 so.gd.un_330  vo.to.af_543 bh.hi.un_A80 
  // [89e0]
  0x16006008, 0x02fe2405, 0x3715150c, 0x2d0d53a0,   // vo.hr.un_430 eo.tlh.da_333  un.ba.un_530 ht.cs.sk_322 
  0x641a55a4, 0x341a79ad, 0x38302312, 0x36005f12,   // rw.tl.lg_433 war.tl.xh_643  ky.uz.tk_654 tn.gn.un_640 
  0x19002207, 0x29001d08, 0x47003b12, 0x16022d04,   // oc.gl.un_420 la.sl.un_430  so.sn.un_640 sk.da.hr_332 
  0x5c003b0c, 0x15041705, 0x47002814, 0x4d02280c,   // so.sa.un_530 sr.ru.un_333  sw.sn.un_660 sw.da.aa_543 
  // [89f0]
  0x5c0d0913, 0x151004a4, 0x6b1a0214, 0x07303511,   // hi.ne.sa_665 ru.be.un_433  da.tl.ceb_666 tg.uz.bg_653 
  0x1d595555, 0x5c3b1a11, 0x38007308, 0x1a796b12,   // rw.rn.la_442 tl.so.sa_653  ny.tk.un_430 ceb.war.tl_654 
  0x2f190a04, 0x0a003702, 0x1a003b04, 0x0d392da4,   // pt.gl.su_332 ba.mk.un_220  so.tl.un_320 sk.br.cs_433 
  0x11287607, 0xfe006e09, 0x4d003b21, 0x1c755d07,   // crs.sw.ro_432 hmn.tlh.un_440  so.aa.un_860 ss.nso.id_432 
  // [8a00]
  0x1c5d1ea4, 0x485c30a0, 0x58001e04, 0x30763b07,   // ms.ss.id_433 uz.sa.tt_322  ms.om.un_320 so.crs.uz_432 
  0x1a6b2a55, 0x3437750c, 0x30483b0b, 0x353428a0,   // mt.ceb.tl_442 nso.st.xh_543  so.tt.uz_542 sw.xh.zu_322 
  0x5a3f10ec, 0x353447ac, 0x456443ec, 0x2855640c,   // lt.af.sm_644 sn.xh.zu_632  ie.lg.ln_644 lg.rw.sw_543 
  0x78005d14, 0x35342fa9, 0x39005f13, 0x25003012,   // ss.ve.un_660 su.xh.zu_544  tn.br.un_650 uz.mn.un_640 
  // [8a10]
  0x21736404, 0x350c5602, 0x5564590d, 0x070501a4,   // lg.ny.jw_332 mg.sv.zu_222  rn.lg.rw_554 en.fr.it_433 
  0xfc016302, 0x3500fc02, 0x6a211e07, 0x5e4764a0,   // sco.en.zzp_222 zzp.zu.un_220  ms.jw.haw_432 lg.sn.ts_322 
  0x02001008, 0x2835590c, 0x35552809, 0x46001c04,   // lt.da.un_430 rn.zu.sw_543  sw.rw.zu_444 id.qu.un_320 
  0x074817a4, 0x46204e08, 0x53003505, 0x2f5621a7,   // sr.tt.bg_433 ay.sq.qu_443  zu.ht.un_330 jw.mg.su_532 
  // [8a20]
  0x37242fa4, 0x565d7304, 0x55004712, 0x17351504,   // su.eo.st_433 ny.ss.mg_332  sn.rw.un_640 un.tg.sr_332 
  0x11205ca0, 0x10254fa0, 0x045e7308, 0x4c2028a0,   // sa.sq.ro_322 bi.eu.lt_322  ny.ts.fi_443 sw.sq.wo_322 
  0x2029730c, 0x35345e05, 0x0f37730c, 0x596455ee,   // ny.sl.sq_543 ts.xh.zu_333  ny.st.lv_543 rw.lg.rn_422 
  0x283555a7, 0x0f286a0c, 0x043007a0, 0x0f074fad,   // rw.zu.sw_532 haw.sw.lv_543  bg.uz.ru_322 bi.it.lv_643 
  // [8a30]
  0x080715a4, 0x42002805, 0x383c23a7, 0x7300201b,   // un.bg.uk_433 sw.co.un_330  ky.ug.tk_532 sq.ny.un_770 
  0x35fc4e0c, 0x5a00650d, 0x17303560, 0x5000532a,   // ay.zzp.zu_543 gv.sm.un_540  tg.uz.sr_664 ht.fj.un_970 
  0x297311a9, 0x1e002508, 0x422a07a4, 0x35fc4e12,   // ro.ny.sl_544 eu.ms.un_430  it.mt.co_433 ay.zzp.zu_654 
  0x67007313, 0x1c5c090d, 0x1d22110c, 0x24123307,   // ny.ak.un_650 hi.sa.mr_554  ro.oc.la_543 nn.hu.eo_432 
  // [8a40]
  0x2d004807, 0x213430ad, 0x2c0612ec, 0x2c123302,   // tt.sk.un_420 uz.ps.fa_643  hu.de.fy_644 nn.hu.fy_222 
  0x122003ee, 0x40002c04, 0x53000508, 0x231844af,   // nl.sq.hu_422 fy.lb.un_320  fr.ht.un_430 kk.ar.ky_655 
  0x054a5307, 0x481036ac, 0x3500150b, 0x183421af,   // ht.yo.fr_432 ab.be.tt_632  un.tg.un_520 fa.ps.ar_655 
  0x34123d0c, 0x1f123fa7, 0x24004602, 0x0d1c0912,   // ku.ur.ps_543 af.hu.cy_532  qu.eo.un_220 hi.mr.ne_654 
  // [8a50]
  0xfc005d2a, 0x3300020b, 0x4c4d58a9, 0x3b644dad,   // ss.zzp.un_970 da.nn.un_520  om.aa.wo_544 aa.lg.so_643 
  0x12342112, 0x3b00580b, 0x52456ea7, 0x09000d20,   // fa.ps.ur_654 om.so.un_520  hmn.ln.ha_532 ne.hi.un_850 
  0x1b4c69a7, 0x21283b04, 0x3b016307, 0x44003022,   // mfe.wo.tr_532 ks.sd.fa_332  sco.en.so_432 uz.kk.un_870 
  0x28003c04, 0x3f0413a4, 0x51006514, 0x3f045805,   // ug.sd.un_320 et.fi.af_433  gv.kl.un_660 om.fi.af_333 
  // [8a60]
  0x4c40200c, 0x34121807, 0x1044080b, 0x0400440c,   // sq.lb.wo_543 ar.ur.ps_432  uk.kk.be_542 kk.ru.un_530 
  0x20004c0d, 0x213b4608, 0x1248640d, 0x2f1e1c05,   // wo.sq.un_540 qu.so.jw_443  lg.tt.hu_554 id.ms.su_333 
  0x53210a05, 0x53002202, 0x32101655, 0x0a1707af,   // pt.jw.ht_333 oc.ht.un_220  hr.lt.bs_442 bg.sr.mk_655 
  0x57064011, 0x48005511, 0x1b004608, 0x17070a60,   // lb.de.na_653 rw.tt.un_630  qu.tr.un_430 mk.bg.sr_664 
  // [8a70]
  0x05122009, 0x28483507, 0x34183dec, 0x64281902,   // sq.hu.fr_444 zu.tt.sw_432  ku.ar.ps_644 gl.sw.lg_222 
  0x53002111, 0x0a174802, 0x697645a9, 0x2f1e1cec,   // jw.ht.un_630 tt.sr.mk_222  ln.crs.mfe_544 id.ms.su_644 
  0x0d2d53a0, 0x0f33080e, 0x34001b05, 0x1e004602,   // ht.sk.cs_322 no.nn.lv_555  tr.xh.un_330 qu.ms.un_220 
  0x05005308, 0x02630c04, 0x272a15a0, 0x35071104,   // ht.fr.un_430 sv.sco.da_332  un.mt.gd_322 ro.bg.tg_332 
  // [8a80]
  0x08512fee, 0x042537a7, 0x3b001212, 0x6300010c,   // su.kl.no_422 ba.mn.ru_532  hu.so.un_640 en.sco.un_530 
  0x6b1c48a9, 0x38104802, 0x2d120513, 0x0c630808,   // tt.id.ceb_544 tt.lt.tk_222  fr.hu.sk_665 no.sco.sv_443 
  0x162910a4, 0x25003c1a, 0x0f002904, 0x2d210da0,   // lt.sl.hr_433 ug.mn.un_760  sl.lv.un_320 cs.jw.sk_322 
  0x1f6301a0, 0x433901a0, 0x30000405, 0x0a002208,   // en.sco.cy_322 en.br.ie_322  ru.uz.un_330 oc.pt.un_430 
  // [8a90]
  0x17250702, 0x21001814, 0x52131b13, 0x52510408,   // bg.mn.sr_222 ar.fa.un_660  tr.et.ha_665 fi.kl.ha_443 
  0x5300420d, 0x632c4d09, 0x044c580c, 0x171629af,   // co.ht.un_540 aa.fy.sco_444  om.wo.fi_543 sl.hr.sr_655 
  0x5600fc1a, 0x122d2e0d, 0x0d004a07, 0x4c580807,   // zzp.mg.un_760 fo.sk.hu_554  yo.cs.un_420 no.om.wo_432 
  0x2d120ea0, 0x36595060, 0x4a003e05, 0x120e2da0,   // is.hu.sk_322 fj.rn.gn_664  rm.yo.un_330 sk.is.hu_322 
  // [8aa0]
  0x5e5d6412, 0x0e640207, 0x2d002e08, 0x5203020c,   // lg.ss.ts_654 da.lg.is_432  fo.sk.un_430 da.nl.ha_543 
  0x30584dad, 0x043f4604, 0x2e2d1255, 0x55005913,   // aa.om.uz_643 qu.af.fi_332  hu.sk.fo_442 rn.rw.un_650 
  0x59557305, 0x2a0458ec, 0x524c510c, 0x04250a04,   // ny.rw.rn_333 om.fi.mt_644  kl.wo.ha_543 mk.mn.ru_332 
  0x29001005, 0x02033fa4, 0x554d59af, 0x4d000813,   // lt.sl.un_330 af.nl.da_433  rn.aa.rw_655 no.aa.un_650 
  // [8ab0]
  0x1221300d, 0x17070aee, 0x17000f04, 0x5d001c04,   // uz.fa.ur_554 mk.bg.sr_422  lv.sr.un_320 id.ss.un_320 
  0x2d190a55, 0x0d122d07, 0x5c215904, 0x28004407,   // pt.gl.sk_442 sk.hu.cs_432  rn.jw.sa_332 kk.sd.un_420 
  0x73595504, 0x0a005604, 0x3508170b, 0x44003014,   // rw.rn.ny_332 mg.pt.un_320  sr.uk.tg_542 uz.kk.un_660 
  0x30004404, 0x22002105, 0x1000290e, 0x5c233607,   // kk.uz.un_320 jw.oc.un_330  sl.lt.un_550 gn.ca.sa_432 
  // [8ac0]
  0x0a004908, 0x180a12a4, 0x2f2125a9, 0x3e6b63a0,   // to.pt.un_430 hu.pt.ga_433  eu.jw.su_544 sco.ceb.rm_322 
  0x352f5da9, 0x5f005921, 0x12000a08, 0x035e2109,   // ss.su.zu_544 rn.tn.un_860  pt.hu.un_430 jw.ts.nl_444 
  0x64005308, 0x61271813, 0x39002222, 0x42004d0c,   // ht.lg.un_430 ga.gd.za_665  oc.br.un_870 aa.co.un_530 
  0x2f002d08, 0x4d026207, 0x61002b36, 0x062c29ee,   // sk.su.un_430 kha.da.aa_432  vi.za.un_AA0 sl.fy.de_422 
  // [8ad0]
  0x4d65610d, 0x23001217, 0x111015a4, 0x080c0207,   // za.gv.aa_554 hu.ca.un_730  un.be.ro_433 da.sv.no_432 
  0x783b4c08, 0x20002a08, 0x18002735, 0x5f003722,   // wo.so.ve_443 mt.sq.un_430  gd.ga.un_A90 st.tn.un_870 
  0x37755f12, 0x61624daf, 0x2f4d50ac, 0x0b002607,   // tn.nso.st_654 aa.kha.za_655  fj.aa.su_632 ia.es.un_420 
  0xfe6501a9, 0x04006405, 0x67624d12, 0x12644dad,   // en.gv.tlh_544 lg.fi.un_330  aa.kha.ak_654 aa.lg.hu_643 
  // [8ae0]
  0x15003018, 0x250a23ee, 0x5673250c, 0x0e2e1210,   // uz.un.un_740 ky.mk.mn_422  eu.ny.mg_543 hu.fo.is_642 
  0x5e022fa4, 0x352534ee, 0x0e02120c, 0x285f2f07,   // su.da.ts_433 xh.eu.zu_422  hu.da.is_543 su.tn.sw_432 
  0x2d36120c, 0x332108a4, 0x16007304, 0x376a2f0c,   // hu.gn.sk_543 no.jw.nn_433  ny.hr.un_320 su.haw.st_543 
  0x271f01a9, 0x020a7807, 0x2f006122, 0x0e300204,   // en.cy.gd_544 ve.pt.da_432  za.su.un_870 da.uz.is_332 
  // [8af0]
  0x306501a9, 0x401b3eee, 0x32160ca0, 0x31004805,   // en.gv.uz_544 rm.tr.lb_422  sv.hr.bs_322 tt.az.un_330 
  0x07150409, 0x21462aad, 0x1900230b, 0x0361625a,   // ru.bg.un_440 mt.qu.jw_643  ca.gl.un_520 kha.za.nl_553 
  0x381b31a4, 0x3c303513, 0x53002211, 0x1e3b28a4,   // az.tr.tk_433 tg.uz.ug_665  oc.ht.un_630 sw.so.ms_433 
  0x253015ee, 0x253e39ad, 0x6b6808a0, 0x05000113,   // un.uz.mn_422 br.rm.eu_643  no.ig.ceb_322 en.fr.un_650 
  // [8b00]
  0x7325500c, 0x04383155, 0x3900131b, 0x4b006204,   // fj.eu.ny_543 az.tk.fi_442  et.br.un_770 kha.mi.un_320 
  0x10291602, 0x3e395708, 0x440410ee, 0x12283402,   // hr.sl.lt_222 na.br.rm_443  be.ru.kk_422 ps.sd.ur_222 
  0x12343b09, 0x124a1308, 0x37002505, 0x55003919,   // ks.ps.ur_444 et.yo.hu_443  mn.ba.un_330 br.rw.un_750 
  0x5c5750a7, 0x08351007, 0x3300310c, 0x5c10390c,   // fj.na.sa_532 be.tg.uk_432  az.nn.un_530 br.lt.sa_543 
  // [8b10]
  0x37001512, 0x370804a0, 0x0a395808, 0x08000905,   // un.ba.un_640 ru.uk.ba_322  om.br.pt_443 pl.no.un_330 
  0x00001a15, 0x2f6b67a4, 0x150408ec, 0x3b003005,   // tl.un.un_700 ak.ceb.su_433  uk.ru.un_644 uz.so.un_330 
  0x11153505, 0x29321605, 0x13000809, 0x30002509,   // tg.ro.un_330 hr.bs.sl_333  no.et.un_440 mn.uz.un_440 
  0x65000808, 0x304435a0, 0x12182109, 0x25003c0d,   // no.gv.un_430 tg.kk.uz_322  fa.ar.ur_444 ug.mn.un_540 
  // [8b20]
  0x342064ee, 0x353c380b, 0x584c655a, 0x1a005c04,   // lg.sq.xh_422 tk.ug.tg_542  gv.wo.om_553 sa.tl.un_320 
  0x13584c0c, 0x3d003412, 0x3f3b5802, 0x40003719,   // wo.om.et_543 ps.ku.un_640  om.so.af_222 st.lb.un_750 
  0x033f1355, 0x183412a0, 0x60000305, 0x033f4da0,   // et.af.nl_442 ur.ps.ar_322  nl.vo.un_330 aa.af.nl_322 
  0x3b023f04, 0x37002519, 0x4c6b1dee, 0x04120ca4,   // af.da.so_332 mn.ba.un_750  la.ceb.wo_422 sv.hu.fi_433 
  // [8b30]
  0x04153707, 0x4c6b02ee, 0x3f1d0107, 0x343d30ec,   // ba.ru.un_420 da.ceb.wo_422  en.la.af_432 uz.ku.ps_644 
  0x51003f02, 0x3f000108, 0x3f1303a4, 0x0e002d13,   // af.kl.un_220 en.af.un_430  nl.et.af_433 sk.is.un_650 
  0x036e21ee, 0x1a790107, 0x4e6a46ad, 0x28004713,   // jw.hmn.nl_422 en.war.tl_432  qu.haw.ay_643 sn.sw.un_650 
  0x5c2f42a0, 0x131a4707, 0x64551307, 0x26231da9,   // co.su.sa_322 sn.tl.et_432  et.rw.lg_432 la.ca.ia_544 
  // [8b40]
  0x3b005f0e, 0x073c300d, 0x2b450207, 0x0800250d,   // tn.so.un_550 uz.ug.bg_554  da.ln.vi_432 mn.uk.un_540 
  0x28732507, 0x213b5c12, 0x3748150c, 0x64004504,   // eu.ny.sw_432 sa.so.jw_654  un.tt.ba_543 ln.lg.un_320 
  0x106b1a08, 0x472804a0, 0x1a6b3ba7, 0x150a0408,   // tl.ceb.lt_443 fi.sw.sn_322  so.ceb.tl_532 ru.mk.un_443 
  0x5c5d35a9, 0x18003412, 0x5e3046ad, 0x021a4608,   // zu.ss.sa_544 ps.ar.un_640  qu.uz.ts_643 qu.tl.da_443 
  // [8b50]
  0x38044811, 0x48000423, 0x393bfe0d, 0x091038ec,   // tt.fi.tk_653 fi.tt.un_880  tlh.so.br_554 tk.lt.pl_644 
  0x79044812, 0x6a5733a4, 0x1d4c01a4, 0xfe405713,   // tt.fi.war_654 nn.na.haw_433  en.wo.la_433 na.lb.tlh_665 
  0x79004d0d, 0x6943260d, 0x380448a4, 0x30153c04,   // aa.war.un_540 ia.ie.mfe_554  tt.fi.tk_433 ug.uz.un_320 
  0x65633f11, 0x2a33080d, 0x4800041b, 0x2e0e0c05,   // af.sco.gv_653 no.nn.mt_554  fi.tt.un_770 sv.is.fo_333 
  // [8b60]
  0x4e00210c, 0x3f610107, 0x48005b0b, 0x0c30625a,   // jw.ay.un_530 en.za.af_432  sg.tt.un_520 kha.uz.sv_553 
  0x23153009, 0x12001a0c, 0x47003509, 0x1d3e0aa4,   // uz.ky.un_440 tl.hu.un_530  zu.sn.un_440 pt.rm.la_433 
  0x190a620c, 0x56465904, 0x5e353408, 0x20004902,   // kha.pt.gl_543 rn.qu.mg_332  xh.zu.ts_443 to.sq.un_220 
  0x29221607, 0x4c291f05, 0x38251ba4, 0x3216130c,   // hr.oc.sl_432 cy.sl.wo_333  tr.eu.tk_433 et.hr.bs_543 
  // [8b70]
  0x30fe4cec, 0x34284404, 0x1165430d, 0x48303b07,   // wo.tlh.uz_644 kk.sd.ps_332  ie.gv.ro_554 so.uz.tt_432 
  0x3e00070d, 0x1a005502, 0x043c1009, 0x100711a0,   // it.rm.un_540 rw.tl.un_220  be.ug.ru_444 ro.bg.be_322 
  0x29000209, 0x69fe6208, 0x49005a0b, 0x790236ec,   // da.sl.un_440 kha.tlh.mfe_443  sm.to.un_520 gn.da.war_644 
  0x27342aac, 0x091038ee, 0x36485b11, 0x51182f0c,   // mt.xh.gd_632 tk.lt.pl_422  sg.tt.gn_653 su.ga.kl_543 
  // [8b80]
  0x30fe58a4, 0x43110613, 0x04004812, 0x04605bad,   // om.tlh.uz_433 de.ro.ie_665  tt.fi.un_640 sg.vo.fi_643 
  0xfe4c4011, 0x04004505, 0x283d215a, 0x104e5111,   // lb.wo.tlh_653 ln.fi.un_330  fa.ku.sd_553 kl.ay.lt_653 
  0x36002519, 0x1f003802, 0x33000c0e, 0x044e67a7,   // mn.ab.un_750 tk.cy.un_220  sv.nn.un_550 ak.ay.fi_532 
  0x17002d08, 0x1e1c27a4, 0x79005c0c, 0x1c211eaf,   // sk.sr.un_430 gd.id.ms_433  sa.war.un_530 ms.jw.id_655 
  // [8b90]
  0x5a006e07, 0x1b001309, 0x5e005014, 0x1b00fe08,   // hmn.sm.un_420 et.tr.un_440  fj.ts.un_660 tlh.tr.un_430 
  0x5a00510d, 0x095c1304, 0x4b001b0d, 0x0e120aee,   // kl.sm.un_540 bh.sa.hi_332  tr.mi.un_540 pt.hu.is_422 
  0x3300fc02, 0x090a18ec, 0x13003608, 0x097912ec,   // zzp.nn.un_220 ga.pt.pl_644  gn.et.un_430 hu.war.pl_644 
  0x3c1515a4, 0x0e000907, 0x53003b07, 0x1b002e04,   // un.ug.un_430 pl.is.un_420  so.ht.un_420 fo.tr.un_320 
  // [8ba0]
  0x06400cad, 0x0a00121b, 0x29000a02, 0x1523380c,   // sv.lb.de_643 hu.pt.un_770  pt.sl.un_220 tk.ky.un_543 
  0x3844150c, 0x190a0902, 0x0b230a07, 0x56232208,   // un.kk.tk_543 pl.pt.gl_222  pt.ca.es_432 oc.ca.mg_443 
  0x2d0d3f05, 0x58002a07, 0x530a1b07, 0x03000104,   // af.cs.sk_333 mt.om.un_420  tr.pt.ht_432 en.nl.un_320 
  0x12000a05, 0x42790704, 0x23221219, 0x122d0aa4,   // pt.hu.un_330 it.war.co_332  hu.oc.ca_765 pt.sk.hu_433 
  // [8bb0]
  0x6500250d, 0x3600220b, 0x0a22235e, 0x2d002912,   // eu.gv.un_540 oc.gn.un_520  ca.oc.pt_652 sl.sk.un_640 
  0x332e1b07, 0x5c000912, 0x361504a9, 0x0d1c13ee,   // tr.fo.nn_432 hi.sa.un_640  ru.ab.un_540 bh.mr.ne_422 
  0x0a042307, 0x062479a6, 0x51002f04, 0x32001704,   // ky.ru.mk_432 war.eo.de_521  su.kl.un_320 sr.bs.un_320 
  0x12004c0e, 0x3c002519, 0x0407170c, 0x36252313,   // wo.hu.un_550 mn.ug.un_750  sr.bg.ru_543 ky.mn.ab_665 
  // [8bc0]
  0x383148ee, 0x1b0e13a0, 0x130e1ba0, 0x1b0e60a9,   // tt.az.tk_422 et.is.tr_322  tr.is.et_322 vo.is.tr_544 
  0x0e001305, 0x0700360c, 0x35003c09, 0x4a004e1b,   // et.is.un_330 ab.bg.un_530  ug.tg.un_440 ay.yo.un_770 
  0x5200641a, 0x303738a0, 0x5d354612, 0x2e1b3bad,   // lg.ha.un_760 tk.ba.uz_322  qu.zu.ss_654 so.tr.fo_643 
  0x0f5a4bee, 0x1b3b46a4, 0x5e2f2108, 0x64464e07,   // mi.sm.lv_422 qu.so.tr_433  jw.su.ts_443 ay.qu.lg_432 
  // [8bd0]
  0x581b4dee, 0x615564af, 0x3b004602, 0x31003b0c,   // aa.tr.om_422 lg.rw.za_655  qu.so.un_220 so.az.un_530 
  0x0c1b1307, 0x641565a0, 0x1b003b05, 0x6b007920,   // et.tr.sv_432 gv.lg.un_320  so.tr.un_330 war.ceb.un_850 
  0x123c28a4, 0x104836ad, 0x0c001b14, 0x372f67ee,   // sd.ug.ur_433 ab.tt.be_643  tr.sv.un_660 ak.su.st_422 
  0x3f006402, 0x7969760c, 0x430b5da9, 0x32291604,   // lg.af.un_220 crs.mfe.war_543  ss.es.ie_544 hr.sl.bs_332 
  // [8be0]
  0x2d290d0c, 0x2f1c1eee, 0x1b1a4604, 0x281e1c0d,   // cs.sl.sk_543 ms.id.su_422  qu.tl.tr_332 id.ms.sw_554 
  0x642845ec, 0x533b31ec, 0x13001802, 0x30002514,   // ln.sw.lg_644 az.so.ht_644  ga.et.un_220 mn.uz.un_660 
  0x31001a04, 0x533864ee, 0x48005202, 0x483b46ec,   // tl.az.un_320 lg.tk.ht_422  ha.tt.un_220 qu.so.tt_644 
  0x4800152b, 0x5d643404, 0x21003b0c, 0x4b49580c,   // un.tt.un_980 xh.lg.ss_332  ks.fa.un_530 om.to.mi_543 
  // [8bf0]
  0x281812af, 0x50114605, 0x38001504, 0x102337ee,   // ur.ar.sd_655 qu.ro.fj_333  un.tk.un_320 ba.ky.be_422 
  0x5a522004, 0x5820590c, 0x5f473502, 0x21003b13,   // sq.ha.sm_332 rn.sq.om_543  zu.sn.tn_222 ks.fa.un_650 
  0x1cfe6311, 0x31732511, 0x5c4773ad, 0x21fe2aa4,   // sco.tlh.id_653 eu.ny.az_653  ny.sn.sa_643 mt.tlh.jw_433 
  0x093031a0, 0x2d0d48ee, 0x304650a0, 0x5b004719,   // az.uz.pl_322 tt.cs.sk_422  fj.qu.uz_322 sn.sg.un_750 
  
  // [8c00]
  0x37003c04, 0x48381504, 0x040a38a0, 0x112f4eee,   // ug.ba.un_320 un.tk.tt_332  tk.mk.ru_322 ay.su.ro_422 
  0x1d005a07, 0x2d002905, 0x092d3b02, 0x00002e2d,   // sm.la.un_420 sl.sk.un_330  so.sk.pl_222 fo.un.un_A00 
  0x322d29a4, 0x43505d04, 0x352434a0, 0x3d122102,   // sl.sk.bs_433 ss.fj.ie_332  xh.eo.zu_322 fa.ur.ku_222 
  0x35346005, 0x0b0f240c, 0x4c002712, 0x30483713,   // vo.xh.zu_333 eo.lv.es_543  gd.wo.un_640 ba.tt.uz_665 
  // [8c10]
  0x2e182d0c, 0x033f2eec, 0x09481608, 0x104844ac,   // sk.ga.fo_543 fo.af.nl_644  hr.tt.pl_443 kk.tt.be_632 
  0x0e0918ee, 0x07002519, 0x32000f07, 0x162d2908,   // ga.pl.is_422 mn.bg.un_750  lv.bs.un_420 sl.sk.hr_443 
  0x313b4dec, 0x05432408, 0x12182da0, 0x5d005007,   // aa.so.az_644 eo.ie.fr_443  sk.ga.hu_322 fj.ss.un_420 
  0x283021a0, 0x4863fca9, 0x50365e10, 0x6410500c,   // fa.uz.sd_322 zzp.sco.tt_544  ts.gn.fj_642 fj.lt.lg_543 
  // [8c20]
  0x361707a9, 0x0a303504, 0x0900180c, 0x07081014,   // bg.sr.ab_544 tg.uz.mk_332  ga.pl.un_530 be.uk.bg_666 
  0x570163ee, 0x4c00040d, 0x483530a6, 0x231538a4,   // sco.en.na_422 fi.wo.un_540  uz.tg.tt_521 tk.ky.un_430 
  0x4830440c, 0x353c23a0, 0x64003607, 0x35004805,   // kk.uz.tt_543 ky.ug.tg_322  gn.lg.un_420 tt.tg.un_330 
  0x29003202, 0x32001002, 0x300a36a9, 0x48073707,   // bs.sl.un_220 lt.bs.un_220  ab.mk.uz_544 ba.bg.tt_432 
  // [8c30]
  0x44231855, 0x364540ee, 0x202146a7, 0x35253ca7,   // ar.ky.kk_442 lb.ln.gn_422  qu.jw.sq_532 ug.mn.tg_532 
  0x1217290c, 0x03002102, 0x24006e2b, 0x641349a0,   // sl.sr.hu_543 jw.nl.un_220  hmn.eo.un_980 to.et.lg_322 
  0x170844ee, 0x532961ac, 0x37006a05, 0x475a50a0,   // kk.uk.sr_422 za.sl.ht_632  haw.st.un_330 fj.sm.sn_322 
  0x30083504, 0x576e6111, 0x65003f1a, 0x28606a11,   // tg.uk.uz_332 za.hmn.na_653  af.gv.un_760 haw.vo.sw_653 
  // [8c40]
  0x083f13a0, 0x02004e19, 0x56005f1a, 0x2d004004,   // et.af.no_322 ay.da.un_750  tn.mg.un_760 lb.sk.un_320 
  0x42124c04, 0x56024907, 0x051103a0, 0x096e61af,   // wo.hu.co_332 to.da.mg_432  nl.ro.fr_322 za.hmn.pl_655 
  0x551133a4, 0x3039130c, 0x34075da0, 0x03023f07,   // nn.ro.rw_433 et.br.uz_543  ss.it.xh_322 af.da.nl_432 
  0x350410a4, 0x0c4010ee, 0x24006e35, 0x0a08330c,   // be.ru.tg_433 lt.lb.sv_422  hmn.eo.un_A90 nn.no.pt_543 
  // [8c50]
  0x16002a05, 0x2500650e, 0x53004804, 0x08021fa4,   // mt.hr.un_330 gv.eu.un_550  tt.ht.un_320 cy.da.no_433 
  0x12002505, 0x61006e2b, 0x2d005004, 0x283d3004,   // eu.hu.un_330 hmn.za.un_980  fj.sk.un_320 uz.ku.sd_332 
  0x1d000602, 0x6e006135, 0x21283d0c, 0x58001207,   // de.la.un_220 za.hmn.un_A90  ku.sd.fa_543 hu.om.un_420 
  0x2b271805, 0x35001719, 0x1d5808ee, 0x07045aa7,   // ga.gd.vi_333 sr.tg.un_750  no.om.la_422 sm.fi.it_532 
  // [8c60]
  0x075a4204, 0x39063307, 0x2c1f01a0, 0x3f2c0307,   // co.sm.it_332 nn.de.br_432  en.cy.fy_322 nl.fy.af_432 
  0x2f211c55, 0x373c0a55, 0x0c003904, 0x17070a5a,   // id.jw.su_442 mk.ug.ba_442  br.sv.un_320 mk.bg.sr_553 
  0x51004202, 0x600945af, 0x02567907, 0x122834a0,   // co.kl.un_220 ln.pl.vo_655  war.mg.da_432 ps.sd.ur_322 
  0x37444804, 0x30150704, 0x02261d0c, 0x320d2955,   // tt.kk.ba_332 bg.uz.un_320  la.ia.da_543 sl.cs.bs_442 
  // [8c70]
  0x01001a04, 0x79292fa0, 0x10041509, 0x154838ec,   // tl.en.un_320 su.sl.war_322  un.ru.be_444 tk.tt.un_644 
  0x300f7305, 0x0000152d, 0x3534590c, 0x65092d0b,   // ny.lv.uz_333 un.un.un_A00  rn.xh.zu_543 sk.pl.gv_542 
  0x301309a9, 0x32000908, 0x17162da0, 0x73596712,   // pl.et.uz_544 pl.bs.un_430  sk.hr.sr_322 ak.rn.ny_654 
  0x353048a4, 0x2c034ca0, 0x183d2107, 0x5a006407,   // tt.uz.tg_433 wo.nl.fy_322  fa.ku.ar_432 lg.sm.un_420 
  // [8c80]
  0x654c580c, 0x080e62a0, 0x3f3b58a6, 0x6b2e1d07,   // om.wo.gv_543 kha.is.no_322  om.so.af_521 la.fo.ceb_432 
  0x23380a05, 0x330f58a7, 0x58041312, 0x320e17a9,   // mk.tk.ky_333 om.lv.nn_532  et.fi.om_654 sr.is.bs_544 
  0x58003b0c, 0x1d000e04, 0x6e003b12, 0x0f00580c,   // so.om.un_530 is.la.un_320  so.hmn.un_640 om.lv.un_530 
  0x32002d05, 0xfc005d05, 0xfc001d1a, 0x173504ee,   // sk.bs.un_330 ss.zzp.un_330  la.zzp.un_760 ru.tg.sr_422 
  // [8c90]
  0xfa73450d, 0x07001512, 0x3b034d07, 0x2e025105,   // ln.ny.nr_554 un.bg.un_640  aa.nl.so_432 kl.da.fo_333 
  0x1d0e0fee, 0x0c00360c, 0x25302307, 0x061b58ac,   // lv.is.la_422 gn.sv.un_530  ky.uz.mn_432 om.tr.de_632 
  0x07001513, 0x286452a4, 0x64552804, 0x154417a7,   // un.bg.un_650 ha.lg.sw_433  sw.rw.lg_332 sr.kk.un_532 
  0x330865ac, 0x37345d07, 0x3d3421a4, 0x02005e22,   // gv.no.nn_632 ss.xh.st_432  fa.ps.ku_433 ts.da.un_870 
  // [8ca0]
  0x3c000709, 0x6402520c, 0x2f1e5205, 0x1000480c,   // bg.ug.un_440 ha.da.lg_543  ha.ms.su_333 tt.be.un_530 
  0x21001e09, 0x45556411, 0x2f003002, 0x3011350c,   // ms.jw.un_440 lg.rw.ln_653  uz.su.un_220 tg.ro.uz_543 
  0x213034ec, 0x286a4ba9, 0x12190b5a, 0x3530255a,   // ps.uz.fa_644 mi.haw.sw_544  es.gl.hu_553 mn.uz.tg_553 
  0x30343b0c, 0x5a0f5c0c, 0x5a006a0d, 0x040a3504,   // ks.ps.uz_543 sa.lv.sm_543  haw.sm.un_540 tg.mk.ru_332 
  // [8cb0]
  0x5c001e21, 0x44342812, 0x09130dad, 0x404b3908,   // ms.sa.un_860 sd.ps.kk_654  ne.bh.hi_643 br.mi.lb_443 
  0x2e002c0d, 0x4b4a6a09, 0x04250aa0, 0x64496aa0,   // fy.fo.un_540 haw.yo.mi_444  mk.mn.ru_322 haw.to.lg_322 
  0x284c10a4, 0x3200360d, 0x560252a4, 0x0e004508,   // lt.wo.sw_433 gn.bs.un_540  ha.da.mg_433 ln.is.un_430 
  0x28593408, 0x35004c08, 0x1511080c, 0x10150a07,   // xh.rn.sw_443 wo.zu.un_430  uk.ro.un_543 mk.be.un_420 
  // [8cc0]
  0x442338ee, 0x245e52ee, 0x1a6949a4, 0x4b6a36a4,   // tk.ky.kk_422 ha.ts.eo_422  to.mfe.tl_433 gn.haw.mi_433 
  0x35001020, 0x5e005035, 0x135c0905, 0x30001513,   // be.tg.un_850 fj.ts.un_A90  hi.sa.bh_333 un.uz.un_650 
  0x2a3b2dac, 0x026925a4, 0x040725a4, 0x122130b3,   // sk.so.mt_632 eu.mfe.da_433  mn.bg.ru_433 uz.fa.ur_743 
  0x12005f07, 0x122f1caf, 0x09003b12, 0xfc001f0b,   // tn.hu.un_420 id.su.hu_655  so.pl.un_640 cy.zzp.un_520 
  // [8cd0]
  0x3c001513, 0x50fc5e04, 0x03000802, 0x0850fcee,   // un.ug.un_650 ts.zzp.fj_332  no.nl.un_220 zzp.fj.no_422 
  0x3b075804, 0x53007312, 0x01122a07, 0x2a35345a,   // om.it.so_332 ny.ht.un_640  mt.hu.en_432 xh.zu.mt_553 
  0x333b0ca4, 0x03403f08, 0x2d001805, 0x35003423,   // sv.so.nn_433 af.lb.nl_443  ga.sk.un_330 xh.zu.un_880 
  0x0900530c, 0x2a00730d, 0x3004360c, 0x64344ca4,   // ht.pl.un_530 ny.mt.un_540  ab.ru.uz_543 wo.xh.lg_433 
  // [8ce0]
  0x2a733507, 0x02000c07, 0x18233407, 0x6453760d,   // zu.ny.mt_432 sv.da.un_420  ps.ky.ar_432 crs.ht.lg_554 
  0x0940fcec, 0x4a3b580c, 0x35480707, 0x04083502,   // zzp.lb.pl_644 om.so.yo_543  bg.tt.tg_432 tg.uk.ru_222 
  0xfc50190c, 0x64006505, 0x0e002202, 0x2319fc0c,   // gl.fj.zzp_543 gv.lg.un_330  oc.is.un_220 zzp.gl.ca_543 
  0x04286504, 0x3b641304, 0x093428a0, 0x0256fc55,   // gv.sw.fi_332 et.lg.so_332  sw.xh.pl_322 zzp.mg.da_442 
  // [8cf0]
  0x552a530c, 0x130904a0, 0x645547a0, 0x48006404,   // ht.mt.rw_543 fi.pl.et_322  sn.rw.lg_322 lg.tt.un_320 
  0x471e64a0, 0x343c440b, 0x5300690d, 0x6364650c,   // lg.ms.sn_322 kk.ug.ps_542  mfe.ht.un_540 gv.lg.sco_543 
  0x25000808, 0x353036a0, 0x40130407, 0x65001319,   // uk.mn.un_430 ab.uz.tg_322  fi.et.lb_432 et.gv.un_750 
  0x1827110d, 0x5739290c, 0x04071055, 0x0a081704,   // ro.gd.ga_554 sl.br.na_543  be.bg.ru_442 sr.uk.mk_332 
  // [8d00]
  0x69483008, 0x632c3908, 0x39000a04, 0x1b004f14,   // uz.tt.mfe_443 br.fy.sco_443  pt.br.un_320 bi.tr.un_660 
  0x63050112, 0x30001105, 0x57064da9, 0x3f2d0d07,   // en.fr.sco_654 ro.uz.un_330  aa.de.na_544 cs.sk.af_432 
  0x4c523b0c, 0x6b006e0c, 0x30004c19, 0x07423e0c,   // so.ha.wo_543 hmn.ceb.un_530  wo.uz.un_750 rm.co.it_543 
  0x311b3012, 0x1a105307, 0x02423eac, 0x2a005304,   // uz.tr.az_654 ht.lt.tl_432  rm.co.da_632 ht.mt.un_320 
  // [8d10]
  0x69000107, 0x3e2afe0c, 0x04153ca7, 0x76531b0c,   // en.mfe.un_420 tlh.mt.rm_543  ug.ru.un_520 tr.ht.crs_543 
  0x0f105cac, 0x6200fe0e, 0x4d00fe21, 0x30234408,   // sa.lt.lv_632 tlh.kha.un_550  tlh.aa.un_860 kk.ky.uz_443 
  0x40390107, 0x796b63ec, 0x34281207, 0x131c0da9,   // en.br.lb_432 sco.ceb.war_644  ur.sd.ps_432 ne.mr.bh_544 
  0x2dfe5c04, 0x3f2a05a0, 0x3f020955, 0x48301b04,   // sa.tlh.sk_332 fr.mt.af_322  pl.da.af_442 tr.uz.tt_332 
  // [8d20]
  0x041537a4, 0x6300fe13, 0x22002312, 0x56283ba0,   // ba.ru.un_430 tlh.sco.un_650  ca.oc.un_640 so.sw.mg_322 
  0x343d300c, 0x250c2aee, 0x3f001b05, 0x5369060c,   // uz.ku.ps_543 mt.sv.eu_422  tr.af.un_330 de.mfe.ht_543 
  0x2c000309, 0x25005304, 0x154838ad, 0x1b3820ad,   // nl.fy.un_440 ht.eu.un_320  tk.tt.un_643 sq.tk.tr_643 
  0x23000705, 0x39003304, 0x04083c02, 0x04172307,   // bg.ky.un_330 nn.br.un_320  ug.uk.ru_222 ky.sr.ru_432 
  // [8d30]
  0x40080208, 0x12022004, 0x016348a0, 0x070a175a,   // da.no.lb_443 sq.da.hu_332  tt.sco.en_322 sr.mk.bg_553 
  0x6b021d07, 0x5d000604, 0x1500020e, 0x08330c55,   // la.da.ceb_432 de.ss.un_320  da.un.un_550 sv.nn.no_442 
  0x1d002413, 0x293f53ee, 0x303c17a9, 0x791a6b5a,   // eo.la.un_650 ht.af.sl_422  sr.ug.uz_544 ceb.tl.war_553 
  0x12343d04, 0x211d1e04, 0x260539ad, 0x01001204,   // ku.ps.ur_332 ms.la.jw_332  br.fr.ia_643 hu.en.un_320 
  // [8d40]
  0x246a6055, 0x081f0c0c, 0x091c1313, 0x3e221d04,   // vo.haw.eo_442 sv.cy.no_543  bh.mr.hi_665 la.oc.rm_332 
  0x79090d07, 0x537633a0, 0x213d1804, 0x182f21a6,   // cs.pl.war_432 nn.crs.ht_322  ar.ku.fa_332 jw.su.ga_521 
  0x20003919, 0x190b3ea9, 0x79003e19, 0x25303512,   // br.sq.un_750 rm.es.gl_544  rm.war.un_750 tg.uz.mn_654 
  0x353c380c, 0x082507a0, 0x211823a0, 0x30042307,   // tk.ug.tg_543 bg.mn.uk_322  ky.ar.fa_322 ky.ru.uz_432 
  // [8d50]
  0x350830af, 0x30443ca4, 0x290c090c, 0x10002a04,   // uz.uk.tg_655 ug.kk.uz_433  pl.sv.sl_543 mt.lt.un_320 
  0x38304408, 0x28002902, 0x2c0333a0, 0x13007812,   // kk.uz.tk_443 sl.sw.un_220  nn.nl.fy_322 ve.et.un_640 
  0x5a072605, 0x5d02350c, 0x633b010c, 0x02630708,   // ia.it.sm_333 zu.da.ss_543  en.so.sco_543 it.sco.da_443 
  0x620201a4, 0x2d003f04, 0x53001e04, 0x080a3004,   // en.da.kha_433 af.sk.un_320  ms.ht.un_320 uz.mk.uk_332 
  // [8d60]
  0x67001229, 0x04001108, 0x07000b04, 0x6163010c,   // hu.ak.un_960 ro.ru.un_430  es.it.un_320 en.sco.za_543 
  0x2c33030c, 0x11153805, 0x3b271f12, 0x15353405,   // nl.nn.fy_543 tk.ro.un_330  cy.gd.so_654 xh.zu.un_333 
  0x15001c04, 0x27003604, 0x301234a9, 0x3b002e1b,   // id.un.un_320 gn.gd.un_320  ps.ur.uz_544 fo.so.un_770 
  0x30373504, 0x03472104, 0x1f653b11, 0x29002d18,   // tg.ba.uz_332 jw.sn.nl_332  so.gv.cy_653 sk.sl.un_740 
  // [8d70]
  0x24490b04, 0x01156b02, 0x1537300c, 0x1300110e,   // es.to.eo_332 ceb.en.un_220  uz.ba.un_543 ro.et.un_550 
  0x6e00010d, 0x31001504, 0x052f4aa9, 0x631f0107,   // en.hmn.un_540 un.az.un_320  yo.su.fr_544 en.cy.sco_432 
  0x03001507, 0x1227020c, 0x1215075a, 0x16000d0c,   // un.nl.un_420 da.gd.hu_543  it.hu.un_530 cs.hr.un_530 
  0x05122fad, 0x0a15170d, 0x25001a07, 0x1e1c4d14,   // su.hu.fr_643 sr.mk.un_540  tl.eu.un_420 aa.id.ms_666 
  // [8d80]
  0x23190b07, 0x65004d0c, 0x0a002c04, 0x1517350c,   // es.gl.ca_432 aa.gv.un_530  fy.pt.un_320 tg.sr.un_543 
  0x6100620e, 0x442337a7, 0x11000505, 0x1500370d,   // kha.za.un_550 ba.ky.kk_532  fr.ro.un_330 ba.un.un_540 
  0x48000702, 0x251612a0, 0x3b343d0c, 0x1300092b,   // bg.tt.un_220 hu.hr.eu_322  ku.ps.ks_543 hi.bh.un_980 
  0x0e0c0404, 0x2a003920, 0x033f76a7, 0x63651304,   // fi.sv.is_332 dz.bo.un_850  crs.af.nl_532 et.gv.sco_332 
  // [8d90]
  0x5b003e1a, 0x06401305, 0x37000305, 0x35000409,   // rm.sg.un_760 et.lb.de_333  nl.st.un_330 ru.tg.un_440 
  0x58283b07, 0x5b006029, 0x0c0e3ea9, 0x57003e13,   // so.sw.om_432 vo.sg.un_960  rm.is.sv_544 rm.na.un_650 
  0x0365580c, 0x48003121, 0x07253508, 0x53002016,   // om.gv.nl_543 az.tt.un_860  tg.mn.bg_443 sq.ht.un_720 
  0x4b605b0c, 0x01033f0c, 0x583b650c, 0x5758370c,   // sg.vo.mi_543 af.nl.en_543  gv.so.om_543 st.om.na_543 
  // [8da0]
  0x25003c0e, 0x0d000507, 0x21000d09, 0x53234a0b,   // ug.mn.un_550 fr.cs.un_420  cs.jw.un_440 yo.ca.ht_542 
  0x0600131a, 0x2a00fe04, 0x1c2f1eaf, 0xfe311ba4,   // et.de.un_760 tlh.mt.un_320  ms.su.id_655 tr.az.tlh_433 
  0x3e2a3908, 0x37002321, 0x3c003714, 0x0c023f05,   // br.mt.rm_443 ky.ba.un_860  ba.ug.un_660 af.da.sv_333 
  0x284707a0, 0x01003804, 0x251e24ee, 0x3b00641a,   // it.sn.sw_322 tk.en.un_320  eo.ms.eu_422 lg.so.un_760 
  // [8db0]
  0x2100fe12, 0x20002a02, 0x6900531b, 0x796b38a4,   // tlh.jw.un_640 mt.sq.un_220  ht.mfe.un_770 tk.ceb.war_433 
  0x2c1f6404, 0x31633b0c, 0x65002102, 0x34213d5a,   // lg.cy.fy_332 so.sco.az_543  jw.gv.un_220 ku.fa.ps_553 
  0x3d1830ac, 0x0a0738a0, 0x7600fe13, 0x25001704,   // uz.ar.ku_632 tk.bg.mk_322  tlh.crs.un_650 sr.mn.un_320 
  0x652a690c, 0x4e004621, 0x0d003b07, 0x30311ba0,   // mfe.mt.gv_543 qu.ay.un_860  so.cs.un_420 tr.az.uz_322 
  // [8dc0]
  0x2a3e0708, 0x76002a08, 0x07003e09, 0x20003e05,   // it.rm.mt_443 mt.crs.un_430  rm.it.un_440 rm.sq.un_330 
  0x3510170c, 0x0a1c1eec, 0x253c3504, 0x4800231b,   // sr.be.tg_543 ms.id.pt_644  tg.ug.mn_332 ky.tt.un_770 
  0x12004704, 0x1b190b05, 0x182344a7, 0x48003c23,   // sn.hu.un_320 es.gl.tr_333  kk.ky.ar_532 ug.tt.un_880 
  0x3f463305, 0x04025b07, 0x070810ad, 0x09033f5a,   // nn.qu.af_333 sg.da.fi_432  be.uk.bg_643 af.nl.pl_553 
  // [8dd0]
  0x3b586213, 0x63001109, 0x103038a9, 0x1a106bec,   // kha.om.so_665 ro.sco.un_440  tk.uz.be_544 ceb.lt.tl_644 
  0x2d090da0, 0x1a3b21ad, 0x36000b09, 0x0b130807,   // cs.pl.sk_322 jw.so.tl_643  es.gn.un_440 no.et.es_432 
  0x1d25600c, 0x64004c20, 0x032e02a4, 0x1f00391a,   // vo.eu.la_543 wo.lg.un_850  da.fo.nl_433 br.cy.un_760 
  0x1c150602, 0x4c644d12, 0x09007609, 0x3c1038ad,   // de.id.un_220 aa.lg.wo_654  crs.pl.un_440 tk.be.ug_643 
  // [8de0]
  0x34214405, 0x193b250c, 0x2c330809, 0x2f2155a0,   // kk.fa.ps_333 eu.so.gl_543  no.nn.fy_444 rw.jw.su_322 
  0x134c0208, 0x131b04ee, 0x1a0f2a0d, 0x152e0e12,   // da.wo.et_443 fi.tr.et_422  mt.lv.tl_554 is.fo.un_654 
  0x6b1a79a4, 0x31583b0c, 0x032c64a4, 0x134c4d12,   // war.tl.ceb_433 so.om.az_543  lg.fy.nl_433 aa.wo.et_654 
  0x47002913, 0x48301ea4, 0x3c382305, 0x384817a4,   // sl.sn.un_650 ms.uz.tt_433  ky.tk.ug_333 sr.tt.tk_433 
  // [8df0]
  0x4c000e0c, 0x55fc1fa4, 0x170a1504, 0xfc00691a,   // is.wo.un_530 cy.zzp.rw_433  un.mk.sr_332 mfe.zzp.un_760 
  0x033f650d, 0x403906af, 0x213d1208, 0x59552da4,   // gv.af.nl_554 de.br.lb_655  ur.ku.fa_443 sk.rw.rn_433 
  0x123b1811, 0x35233c0c, 0xfc003902, 0x42000713,   // ar.ks.ur_653 ug.ky.tg_543  br.zzp.un_220 it.co.un_650 
  0x680201a0, 0x6200fc1a, 0x0a234807, 0x21123408,   // en.da.ig_322 zzp.kha.un_760  tt.ky.mk_432 ps.ur.fa_443 
  // [8e00]
  0x5a671d12, 0x5500fc07, 0x37343fac, 0x3c3d44a7,   // la.ak.sm_654 zzp.rw.un_420  af.xh.st_632 kk.ku.ug_532 
  0x22000305, 0x484407a0, 0x0e1f0d07, 0x09766914,   // nl.oc.un_330 bg.kk.tt_322  cs.cy.is_432 mfe.crs.pl_666 
  0x0a4d19a9, 0x2c001505, 0x650149ec, 0x2d0d45ad,   // gl.aa.pt_544 un.fy.un_330  to.en.gv_644 ln.cs.sk_643 
  0x441007a7, 0x2c3f030c, 0x49533612, 0x46204d0c,   // bg.be.kk_532 nl.af.fy_543  gn.ht.to_654 aa.sq.qu_543 
  // [8e10]
  0x34182105, 0x06005714, 0x2f002508, 0x580d3b0c,   // fa.ar.ps_333 na.de.un_660  eu.su.un_430 so.cs.om_543 
  0x2f1225ee, 0x58604955, 0x033b4c0d, 0x375f490c,   // eu.hu.su_422 to.vo.om_442  wo.so.nl_554 to.tn.st_543 
  0x173011ad, 0x2b3b0407, 0x51584c12, 0x550e3407,   // ro.uz.sr_643 fi.so.vi_432  wo.om.kl_654 xh.is.rw_432 
  0x3b506e04, 0x49005212, 0x12212508, 0x0679610c,   // hmn.fj.so_332 ha.to.un_640  eu.jw.hu_443 za.war.de_543 
  // [8e20]
  0x2b791304, 0x25001005, 0x56005212, 0x533435a0,   // et.war.vi_332 be.mn.un_330  ha.mg.un_640 zu.xh.ht_322 
  0x64135102, 0x3f0603af, 0x033f060c, 0x033f0608,   // kl.et.lg_222 nl.de.af_655  de.af.nl_543 de.af.nl_443 
  0x033f2c55, 0x081017ad, 0x125253a0, 0x5e004704,   // fy.af.nl_442 sr.be.uk_643  ht.ha.hu_322 sn.ts.un_320 
  0x3f0304ee, 0x28005207, 0x04133fa0, 0x3f033b13,   // fi.nl.af_422 ha.sw.un_420  af.et.fi_322 so.nl.af_665 
  // [8e30]
  0x043f1308, 0x53004907, 0x3f005802, 0x211234ee,   // et.af.fi_443 to.ht.un_420  om.af.un_220 ps.ur.fa_422 
  0x07233607, 0x303617a0, 0x44283b0c, 0x1c0913a6,   // ab.ky.bg_432 sr.ab.uz_322  ks.sd.kk_543 bh.hi.mr_521 
  0x04071702, 0x03402ea0, 0x4c003b09, 0x2f005207,   // sr.bg.ru_222 fo.lb.nl_322  so.wo.un_440 ha.su.un_420 
  0x23001702, 0x4c3b4d0c, 0x122402a7, 0x4c583b09,   // sr.ky.un_220 aa.so.wo_543  da.eo.hu_532 so.om.wo_444 
  // [8e40]
  0x12190ea7, 0x1c2f3007, 0x211228ad, 0x44003505,   // is.gl.hu_532 uz.su.id_432  sd.ur.fa_643 tg.kk.un_330 
  0x3e002512, 0x07003e12, 0x342865ee, 0x47002504,   // eu.rm.un_640 rm.it.un_640  gv.sw.xh_422 eu.sn.un_320 
  0x0a2515a0, 0x343c44ec, 0x2f004a07, 0x0c130602,   // un.mn.mk_322 kk.ug.ps_644  yo.su.un_420 de.et.sv_222 
  0x2e0c3355, 0x4e3b46a4, 0x39003004, 0x5c007511,   // nn.sv.fo_442 qu.so.ay_433  uz.br.un_320 nso.sa.un_630 
  // [8e50]
  0x0f101104, 0x182344ee, 0x060c0f05, 0x42073eaf,   // ro.lt.lv_332 kk.ky.ar_422  lv.sv.de_333 rm.it.co_655 
  0x46003607, 0x2336380c, 0x3d442311, 0x3d283ca9,   // gn.qu.un_420 tk.ab.ky_543  ky.kk.ku_653 ug.sd.ku_544 
  0x0000321c, 0x06212f07, 0x371535a4, 0x46004819,   // bs.un.un_800 su.jw.de_432  tg.ba.un_430 tt.qu.un_750 
  0x18004604, 0x2e001304, 0x06020c09, 0x3b004622,   // qu.ga.un_320 et.fo.un_320  sv.da.de_444 qu.so.un_870 
  // [8e60]
  0x1a36460c, 0x3000fe08, 0x6b005512, 0x02656304,   // qu.gn.tl_543 tlh.uz.un_430  rw.ceb.un_640 sco.gv.da_332 
  0x42003904, 0x1c004604, 0x123d3b12, 0x22007907,   // br.co.un_320 qu.id.un_320  ks.ku.ur_654 war.oc.un_420 
  0x655159a0, 0x5500110e, 0x462f21a0, 0x11006304,   // rn.kl.gv_322 ro.rw.un_550  jw.su.qu_322 sco.ro.un_320 
  0x4b1d5607, 0x4837360c, 0x56001221, 0x10002607,   // mg.la.mi_432 ab.ba.tt_543  hu.mg.un_860 ia.lt.un_420 
  // [8e70]
  0x17002907, 0x274218a4, 0x38361c07, 0x76695c0d,   // sl.sr.un_420 ga.co.gd_433  id.gn.tk_432 sa.mfe.crs_554 
  0x1a1e1c0d, 0x537669af, 0x605f1c0b, 0x561d15a4,   // id.ms.tl_554 mfe.crs.ht_655  id.tn.vo_542 un.la.mg_433 
  0x5642120c, 0x653e6b07, 0x1d001507, 0x1f005c02,   // hu.co.mg_543 ceb.rm.gv_432  un.la.un_420 sa.cy.un_220 
  0x5c6965af, 0x221901a0, 0x02fc1d09, 0x7328fc55,   // gv.mfe.sa_655 en.gl.oc_322  la.zzp.da_444 zzp.sw.ny_442 
  // [8e80]
  0x314c7607, 0x531f5604, 0x46304812, 0x64fc7305,   // crs.wo.az_432 mg.cy.ht_332  tt.uz.qu_654 ny.zzp.lg_333 
  0x4600fc34, 0x10082504, 0x033f010c, 0x343d28a0,   // zzp.qu.un_A80 mn.uk.be_332  en.af.nl_543 sd.ku.ps_322 
  0x073e27a7, 0x15023e07, 0x3f155811, 0x07112da4,   // gd.rm.it_532 rm.da.un_432  om.af.un_630 sk.ro.it_433 
  0x22231113, 0x107669a4, 0x48311b14, 0x5c0269af,   // ro.ca.oc_665 mfe.crs.lt_433  tr.az.tt_666 mfe.da.sa_655 
  // [8e90]
  0x565a4b04, 0x3f030107, 0x3f002102, 0x21005b07,   // mi.sm.mg_332 en.nl.af_432  jw.af.un_220 sg.jw.un_420 
  0x0d004804, 0x1f4c58ec, 0x1e001504, 0x6400fc0d,   // tt.cs.un_320 om.wo.cy_644  un.ms.un_320 zzp.lg.un_540 
  0x3c4423a7, 0x25073e04, 0x19004202, 0x755f3709,   // ky.kk.ug_532 rm.it.eu_332  co.gl.un_220 st.tn.nso_444 
  0x342a2560, 0x796bfc11, 0x30004812, 0x03001b02,   // eu.mt.xh_664 zzp.ceb.war_653  tt.uz.un_640 tr.nl.un_220 
  // [8ea0]
  0x302134af, 0x39076904, 0x43001f18, 0x383048ee,   // ps.fa.uz_655 mfe.it.br_332  cy.ie.un_740 tt.uz.tk_422 
  0x072a3e0c, 0x0600582a, 0x0e403f0c, 0x25000714,   // rm.mt.it_543 om.de.un_970  af.lb.is_543 it.eu.un_660 
  0x0d002d22, 0x3e0742af, 0x477906ad, 0x20381b0c,   // sk.cs.un_870 co.it.rm_655  de.war.sn_643 tr.tk.sq_543 
  0x1b3148a9, 0x32000d04, 0x2d001b02, 0x3f003902,   // tt.az.tr_544 cs.bs.un_320  tr.sk.un_220 br.af.un_220 
  // [8eb0]
  0x482939a0, 0x0a10440c, 0x3e007614, 0x2523360c,   // br.sl.tt_322 kk.be.mk_543  crs.rm.un_660 ab.ky.mn_543 
  0x17001113, 0x344006a0, 0x10083cee, 0x483c38ad,   // ro.sr.un_650 de.lb.xh_322  ug.uk.be_422 tk.ug.tt_643 
  0x38005204, 0x48311bad, 0x1100381b, 0x3b00580c,   // ha.tk.un_320 tr.az.tt_643  tk.ro.un_770 om.so.un_530 
  0x332e0807, 0xfe000911, 0x3b6558a4, 0x38004a04,   // no.fo.nn_432 pl.tlh.un_630  om.gv.so_433 yo.tk.un_320 
  // [8ec0]
  0x4c005821, 0x3d001213, 0x48003204, 0x2812340c,   // om.wo.un_860 ur.ku.un_650  bs.tt.un_320 ps.ur.sd_543 
  0x230730a9, 0x18004004, 0x15173813, 0x15033f05,   // uz.bg.ky_544 lb.ga.un_320  tk.sr.un_665 af.nl.un_333 
  0x2e0e2da7, 0x39002d08, 0xfc2a4d0c, 0x373515a4,   // sk.is.fo_532 sk.br.un_430  aa.mt.zzp_543 un.tg.ba_433 
  0x0e000202, 0x65024c04, 0x0765fc0d, 0x4200070c,   // da.is.un_220 wo.da.gv_332  zzp.gv.it_554 it.co.un_530 
  // [8ed0]
  0x653b13a4, 0x38001014, 0x08041511, 0x425864ee,   // et.so.gv_433 be.tk.un_660  un.ru.uk_653 lg.om.co_422 
  0x640413a4, 0x30150804, 0x25001109, 0x1704150d,   // et.fi.lg_433 uk.uz.un_320  ro.eu.un_440 un.ru.sr_554 
  0x04133b0c, 0x041707a4, 0xfc424ca7, 0x0a100855,   // so.et.fi_543 bg.sr.ru_433  wo.co.zzp_532 uk.be.mk_442 
  0x225a5e02, 0x5e120411, 0x2e4c2407, 0x35170aa4,   // ts.sm.oc_222 fi.hu.ts_653  eo.wo.fo_432 mk.sr.tg_433 
  // [8ee0]
  0x4a295ead, 0x495c450c, 0x30003402, 0x494245af,   // ts.sl.yo_643 ln.sa.to_543  xh.uz.un_220 ln.co.to_655 
  0x3b003407, 0x11001305, 0x13271855, 0x21183402,   // xh.so.un_420 et.ro.un_330  ga.gd.et_442 ps.ar.fa_222 
  0x343018a9, 0x205c11a4, 0x25000807, 0x4c475e07,   // ar.uz.ps_544 ro.sa.sq_433  uk.mn.un_420 ts.sn.wo_432 
  0x49564da4, 0x213946a0, 0x2b031ea0, 0x21283b0c,   // aa.mg.to_433 qu.br.jw_322  ms.nl.vi_322 ks.sd.fa_543 
  // [8ef0]
  0x021811ad, 0x29321704, 0x153638ad, 0x02005807,   // ro.ga.da_643 sr.bs.sl_332  tk.ab.un_643 om.da.un_420 
  0x030436a0, 0x0c130b07, 0x2d0d4a09, 0x2518270e,   // gn.fi.nl_322 es.et.sv_432  yo.cs.sk_444 gd.ga.eu_555 
  0x38234413, 0x251801a4, 0x47002902, 0x34003019,   // kk.ky.tk_665 en.ga.eu_433  sl.sn.un_220 uz.ps.un_750 
  0x011d4355, 0x55001602, 0x4400300d, 0x28734760,   // ie.la.en_442 hr.rw.un_220  uz.kk.un_540 sn.ny.sw_664 
  // [8f00]
  0x35735d11, 0x025a2807, 0x1d3b11ee, 0x0b111d08,   // ss.ny.zu_653 sw.sm.da_432  ro.so.la_422 la.ro.es_443 
  0x027378a7, 0x13796a0c, 0x46783412, 0x5c004704,   // ve.ny.da_532 haw.war.et_543  xh.ve.qu_654 sn.sa.un_320 
  0x2d120e12, 0x215f3707, 0x2f1c2105, 0x36321655,   // is.hu.sk_654 st.tn.jw_432  jw.id.su_333 hr.bs.gn_442 
  0x230444a0, 0x082e55a4, 0x1200470e, 0x082e46ad,   // kk.ru.ky_322 rw.fo.no_433  sn.hu.un_550 qu.fo.no_643 
  // [8f10]
  0x1000470c, 0x1c642107, 0x22421da0, 0x10002b04,   // sn.lt.un_530 jw.lg.id_432  la.co.oc_322 vi.lt.un_320 
  0x070f1d0b, 0x593e1da7, 0x44083607, 0x30fe460c,   // la.lv.it_542 la.rm.rn_532  ab.uk.kk_432 qu.tlh.uz_543 
  0x08170402, 0x383c4812, 0x483015a9, 0x02647312,   // ru.sr.uk_222 tt.ug.tk_654  un.uz.tt_544 ny.lg.da_654 
  0xfa000921, 0x02007312, 0x13001007, 0x19232207,   // pl.nr.un_860 ny.da.un_640  lt.et.un_420 oc.ca.gl_432 
  // [8f20]
  0x132f2007, 0x5c4755a0, 0x2845fca9, 0x291d25a4,   // sq.su.et_432 rw.sn.sa_322  zzp.ln.sw_544 eu.la.sl_433 
  0x39002204, 0x53fc57a9, 0x65000813, 0x5a00fc08,   // oc.br.un_320 na.zzp.ht_544  no.gv.un_650 zzp.sm.un_430 
  0x3f6b6ead, 0x59006413, 0x551264ec, 0x04212808,   // hmn.ceb.af_643 lg.rn.un_650  lg.hu.rw_644 sw.jw.fi_443 
  0x042ffca4, 0x044807ad, 0x5c005008, 0x385c640c,   // zzp.su.fi_433 bg.tt.ru_643  fj.sa.un_430 lg.sa.tk_543 
  // [8f30]
  0x2e08330c, 0xfe043507, 0x04684f55, 0x23441002,   // nn.no.fo_543 zu.fi.tlh_432  bi.ig.fi_442 be.kk.ky_222 
  0x036e270e, 0x5c091c12, 0x2f041eee, 0x56005c04,   // gd.hmn.nl_555 mr.hi.sa_654  ms.fi.su_422 sa.mg.un_320 
  0x00003437, 0x245350a4, 0x17001504, 0x2e3e60ee,   // ps.un.un_B00 fj.ht.eo_433  un.sr.un_320 vo.rm.fo_422 
  0x483530af, 0x120d18ee, 0x3e031fa0, 0x2a3e0713,   // uz.tg.tt_655 ga.cs.hu_422  cy.nl.rm_322 it.rm.mt_665 
  // [8f40]
  0x56001f07, 0x125650ad, 0x170410a7, 0x151525ad,   // cy.mg.un_420 fj.mg.hu_643  be.ru.sr_532 mn.un.un_630 
  0x16094202, 0x211250a0, 0x1f3b2e04, 0x3000080d,   // co.pl.hr_222 fj.hu.jw_322  fo.so.cy_332 uk.uz.un_540 
  0x055011a4, 0x5f003705, 0x353424ac, 0xfe281a07,   // ro.fj.fr_433 st.tn.un_330  eo.xh.zu_632 tl.sw.tlh_432 
  0x11002508, 0x215c50a4, 0x2200040c, 0x3c4425ec,   // mn.ro.un_430 fj.sa.jw_433  fi.oc.un_530 mn.kk.ug_644 
  // [8f50]
  0x64346713, 0x335c5004, 0x343d21ee, 0x42021007,   // ak.xh.lg_665 fj.sa.nn_332  fa.ku.ps_422 lt.da.co_432 
  0x1100151b, 0x08003822, 0x5c2450a7, 0x1030350d,   // un.ro.un_770 tk.uk.un_870  fj.eo.sa_532 tg.uz.be_554 
  0x212f1ea4, 0x34303da4, 0x5c002805, 0x0f00fe05,   // ms.su.jw_433 ku.uz.ps_433  sw.sa.un_330 tlh.lv.un_330 
  0x2573475a, 0x3e2a42a0, 0x5e627809, 0x2a6407af,   // sn.ny.eu_553 co.mt.rm_322  ve.kha.ts_444 it.lg.mt_655 
  // [8f60]
  0x2b6847af, 0x35000a14, 0x3000440d, 0x23000e02,   // sn.ig.vi_655 mk.tg.un_660  kk.uz.un_540 is.ca.un_220 
  0x5c28210c, 0x78002722, 0x735cfea4, 0x30006b04,   // jw.sw.sa_543 gd.ve.un_870  tlh.sa.ny_433 ceb.uz.un_320 
  0x3600300c, 0x1c122502, 0x2310380b, 0x5c001f0d,   // uz.gn.un_530 eu.hu.id_222  tk.be.ky_542 cy.sa.un_540 
  0x21004521, 0x5f3746ec, 0x3021340e, 0x354e4613,   // ln.jw.un_860 qu.st.tn_644  ps.fa.uz_555 qu.ay.zu_665 
  // [8f70]
  0x4b000113, 0x27375fa9, 0x30070a55, 0x49550407,   // en.mi.un_650 tn.st.gd_544  mk.bg.uz_442 fi.rw.to_432 
  0x34003035, 0x39000505, 0x38003629, 0x074423a7,   // uz.ps.un_A90 fr.br.un_330  ab.tk.un_960 ky.kk.bg_532 
  0x39001102, 0x350a0707, 0x103607af, 0x0a291cee,   // ro.br.un_220 bg.mk.tg_432  bg.ab.be_655 id.sl.pt_422 
  0x44003609, 0x15401d08, 0x11002a04, 0x55000502,   // ab.kk.un_440 la.lb.un_443  mt.ro.un_320 fr.rw.un_220 
  // [8f80]
  0x055502a4, 0x29001709, 0x07000605, 0x153140a0,   // da.rw.fr_433 sr.sl.un_440  de.it.un_330 lb.az.un_322 
  0x55000102, 0x050106a0, 0x10384804, 0x07192404,   // en.rw.un_220 de.en.fr_322  tt.tk.be_332 eo.gl.it_332 
  0x40000702, 0x191b55a0, 0x40001819, 0x37443604,   // it.lb.un_220 rw.tr.gl_322  ga.lb.un_750 ab.kk.ba_332 
  0x07170a55, 0x40000a04, 0x381711ad, 0x1b5830a0,   // mk.sr.bg_442 pt.lb.un_320  ro.sr.tk_643 uz.om.tr_322 
  // [8f90]
  0x65001e05, 0x07001718, 0x64003b20, 0x11005a0e,   // ms.gv.un_330 sr.bg.un_740  so.lg.un_850 sm.ro.un_550 
  0x3b644da0, 0x132711ee, 0x2800550c, 0x27000a04,   // aa.lg.so_322 ro.gd.et_422  rw.sw.un_530 pt.gd.un_320 
  0x35001511, 0x0408110c, 0x30006502, 0x0b0a1da0,   // un.tg.un_630 ro.uk.ru_543  gv.uz.un_220 la.pt.es_322 
  0x0e330807, 0x2e0833a0, 0x0a3c380c, 0x151115af,   // no.nn.is_432 nn.no.fo_322  tk.ug.mk_543 un.ro.un_655 
  // [8fa0]
  0x1d0b0a08, 0x041735a4, 0x0c000213, 0x25003007,   // pt.es.la_443 tg.sr.ru_433  da.sv.un_650 uz.mn.un_420 
  0x0c0448ad, 0x08043ea0, 0x1100480e, 0x13001c22,   // tt.fi.sv_643 rm.fi.no_322  tt.ro.un_550 mr.bh.un_870 
  0x790e0cee, 0x442336a0, 0x2112180b, 0x1e033f04,   // sv.is.war_422 ab.ky.kk_322  ar.ur.fa_542 af.nl.ms_332 
  0x15003721, 0x17000a23, 0x303418a4, 0x34004608,   // ba.un.un_860 mk.sr.un_880  ar.ps.uz_433 qu.xh.un_430 
  // [8fb0]
  0x5d6b340c, 0x302818a7, 0x3534fc04, 0x35523407,   // xh.ceb.ss_543 ar.sd.uz_532  zzp.xh.zu_332 xh.ha.zu_432 
  0x2e06fca0, 0x22190b0c, 0x48353c07, 0x564c32a4,   // zzp.de.fo_322 es.gl.oc_543  ug.tg.tt_432 bs.wo.mg_433 
  0x1a00310d, 0x37003c1a, 0x0415380c, 0x233c3011,   // az.tl.un_540 ug.ba.un_760  tk.ru.un_530 uz.ug.ky_653 
  0x0b311b0d, 0x4600480e, 0x3c070aa9, 0x2a00401a,   // tr.az.es_554 tt.qu.un_550  mk.bg.ug_544 lb.mt.un_760 
  // [8fc0]
  0x2d0d27a0, 0x37150460, 0x480b3004, 0x21000c02,   // gd.cs.sk_322 ru.ba.un_640  uz.es.tt_332 sv.jw.un_220 
  0x63186508, 0x35080411, 0x11002502, 0x2700180b,   // gv.ga.sco_443 ru.uk.tg_653  eu.ro.un_220 ga.gd.un_520 
  0x79001a12, 0x025564ec, 0x112743a0, 0x28181208,   // tl.war.un_640 lg.rw.da_644  ie.gd.ro_322 ur.ar.sd_443 
  0x33001904, 0x11fc010c, 0x4900fe0b, 0x5f003b0c,   // gl.nn.un_320 en.zzp.ro_543  tlh.to.un_520 so.tn.un_530 
  // [8fd0]
  0x09120da0, 0x330863a4, 0x3b004d18, 0x06002a12,   // cs.hu.pl_322 sco.no.nn_433  aa.so.un_740 mt.de.un_640 
  0x381517af, 0x271101a4, 0x1e061c04, 0x402c2707,   // sr.tk.un_650 en.ro.gd_433  id.de.ms_332 gd.fy.lb_432 
  0x371004a0, 0x04101508, 0x34003c07, 0x30003e0c,   // ru.be.ba_322 un.be.ru_443  ug.ps.un_420 rm.uz.un_530 
  0x123b2107, 0x15002304, 0x21123402, 0x1500380e,   // fa.ks.ur_432 ca.un.un_320  ps.ur.fa_222 tk.un.un_550 
  // [8fe0]
  0x17101507, 0x303c1108, 0x04083004, 0x281823af,   // un.be.sr_432 ro.ug.uz_443  uz.uk.ru_332 ky.ar.sd_655 
  0x403e6a11, 0x3965290c, 0x3b3f0307, 0x04003711,   // haw.rm.lb_653 sl.gv.br_543  nl.af.so_432 ba.ru.un_630 
  0x400c08af, 0x6900760e, 0x4c005809, 0x3b033f04,   // no.sv.lb_655 crs.mfe.un_550  om.wo.un_440 af.nl.so_332 
  0x69650c0c, 0x19124604, 0x15330804, 0x0300130c,   // sv.gv.mfe_543 qu.hu.gl_332  no.nn.un_332 et.nl.un_530 
  // [8ff0]
  0x18116508, 0xfe2e48ec, 0x6b5036ad, 0x0f114c13,   // gv.ro.ga_443 tt.fo.tlh_644  gn.fj.ceb_643 wo.ro.lv_665 
  0x3f633b07, 0x400633a9, 0x3b006304, 0x033f650b,   // so.sco.af_432 nn.de.lb_544  sco.so.un_320 gv.af.nl_542 
  0x236976ec, 0x2800731b, 0x0c2e39a9, 0x3845500c,   // crs.mfe.ca_644 ny.sw.un_770  br.fo.sv_544 fj.ln.tk_543 
  0x76692512, 0x5e686713, 0x691b63ec, 0x647347ec,   // eu.mfe.crs_654 ak.ig.ts_665  sco.tr.mfe_644 sn.ny.lg_644 
  
  // [9000]
  0x4000fe07, 0x0d311b07, 0x051b76af, 0x15003107,   // tlh.lb.un_420 tr.az.cs_432  crs.tr.fr_655 az.un.un_420 
  0x033f3912, 0x3b695707, 0x485a490c, 0x2d0d39a0,   // br.af.nl_654 na.mfe.so_432  to.sm.tt_543 br.cs.sk_322 
  0x4800301b, 0x38111ba0, 0x3710150c, 0x06002c23,   // uz.tt.un_770 tr.ro.tk_322  un.be.ba_543 fy.de.un_880 
  0x3b65030c, 0x033f63a0, 0x53056509, 0x281834af,   // nl.gv.so_543 sco.af.nl_322  gv.fr.ht_444 ps.ar.sd_655 
  // [9010]
  0x3d342113, 0x6b002a09, 0x111b48af, 0x2f4a210b,   // fa.ps.ku_665 mt.ceb.un_440  tt.tr.ro_655 jw.yo.su_542 
  0x06000912, 0x3e5634ee, 0x3e001b07, 0x3e002004,   // pl.de.un_640 xh.mg.rm_422  tr.rm.un_420 sq.rm.un_320 
  0x46534b08, 0x091f6355, 0x011563a4, 0x44043004,   // mi.ht.qu_443 sco.cy.pl_442  sco.en.un_430 uz.ru.kk_332 
  0x631f01a4, 0x2150fc04, 0x2a001f0c, 0x091f2aa0,   // en.cy.sco_433 zzp.fj.jw_332  cy.mt.un_530 mt.cy.pl_322 
  // [9020]
  0x34303daf, 0x250410a0, 0x2200231b, 0x0c00060c,   // ku.uz.ps_655 be.ru.mn_322  ca.oc.un_770 de.sv.un_530 
  0x45000104, 0x1f00092a, 0x303c1155, 0x4000050b,   // en.ln.un_320 pl.cy.un_970  ro.ug.uz_442 fr.lb.un_520 
  0x39091fa4, 0x465502a7, 0x086306ad, 0x0f00060d,   // cy.pl.br_433 da.rw.qu_532  de.sco.no_643 de.lv.un_540 
  0x51000602, 0x070d1ba0, 0x2834120d, 0x2a2835a0,   // de.kl.un_220 tr.cs.it_322  ur.ps.sd_554 zu.sw.mt_322 
  // [9030]
  0x060702ee, 0x0c130fa0, 0x29001b0d, 0x3800481b,   // da.it.de_422 lv.et.sv_322  tr.sl.un_540 tt.tk.un_770 
  0x0d002407, 0x567328ad, 0x34733b07, 0x36734705,   // eo.cs.un_420 sw.ny.mg_643  so.ny.xh_432 sn.ny.gn_333 
  0x345d7308, 0x06243902, 0x3b1a6b05, 0x2f626b09,   // ny.ss.xh_443 br.eo.de_222  ceb.tl.so_333 ceb.kha.su_444 
  0x3b0234a4, 0x73023bad, 0x685259a9, 0x0f005712,   // xh.da.so_433 so.da.ny_643  rn.ha.ig_544 na.lv.un_640 
  // [9040]
  0x0700170b, 0x29003004, 0x34442307, 0x40001b07,   // sr.bg.un_520 uz.sl.un_320  ky.kk.ps_432 tr.lb.un_420 
  0x0a241155, 0x2c033f08, 0x3b347308, 0x3e001307,   // ro.eo.pt_442 af.nl.fy_443  ny.xh.so_443 et.rm.un_420 
  0x1b4735a0, 0x28475b04, 0x3b007319, 0x05214304,   // zu.sn.tr_322 sg.sn.sw_332  ny.so.un_750 ie.jw.fr_332 
  0x5c3b5d0b, 0x735d550c, 0x12052f07, 0x12002509,   // ss.so.sa_542 rw.ss.ny_543  su.fr.hu_432 eu.hu.un_440 
  // [9050]
  0x5a3725a9, 0x4b5a6aec, 0x2d00180d, 0x214b115a,   // eu.st.sm_544 haw.sm.mi_644  ga.sk.un_540 ro.mi.jw_553 
  0x19002604, 0x38003b04, 0x124205ad, 0x3012210d,   // ia.gl.un_320 so.tk.un_320  fr.co.hu_643 fa.ur.uz_554 
  0x13003f08, 0x130465a4, 0x170a25a9, 0x0f003913,   // af.et.un_430 gv.fi.et_433  mn.mk.sr_544 br.lv.un_650 
  0x153844a4, 0x25003908, 0x23004e12, 0x15271812,   // kk.tk.un_433 br.eu.un_430  ay.ca.un_640 ga.gd.un_654 
  // [9060]
  0x34fc2208, 0x11271808, 0x794b6a11, 0x303c35ad,   // oc.zzp.xh_443 ga.gd.ro_443  haw.mi.war_653 tg.ug.uz_643 
  0x28466aa7, 0x4e004612, 0x15002719, 0x3c004423,   // haw.qu.sw_532 qu.ay.un_640  gd.un.un_750 kk.ug.un_880 
  0x29164507, 0x02005104, 0x15002707, 0x48000713,   // ln.hr.sl_432 kl.da.un_320  gd.un.un_420 bg.tt.un_650 
  0x67004a2a, 0x2736150c, 0x36254704, 0x5c090d11,   // yo.ak.un_970 un.gn.gd_543  sn.eu.gn_332 ne.hi.sa_653 
  // [9070]
  0x16005f05, 0x1527180d, 0x1c1a2fa4, 0x32006402,   // tn.hr.un_330 ga.gd.un_554  su.tl.id_433 lg.bs.un_220 
  0x060c1809, 0x481539a0, 0x034615a0, 0x02032c08,   // ga.sv.de_444 br.tt.un_320  un.qu.nl_322 fy.nl.da_443 
  0x255f13a4, 0x23220aa4, 0x791518a4, 0x554b1d04,   // et.tn.eu_433 pt.oc.ca_433  ga.war.un_430 la.mi.rw_332 
  0x49695608, 0x18151107, 0x3f031502, 0x360a08ee,   // mg.mfe.to_443 ro.ga.un_420  un.nl.af_222 uk.mk.ab_422 
  // [9080]
  0x353038a0, 0x0a153507, 0x04151755, 0x00000524,   // tk.uz.tg_322 tg.mk.un_420  sr.ru.un_420 fr.un.un_900 
  0x63000c0b, 0x240440ec, 0x0a0b12a4, 0x17233607,   // sv.sco.un_520 lb.fi.eo_644  hu.es.pt_433 ab.ky.sr_432 
  0x07170a0e, 0x15231104, 0x45006713, 0x02000205,   // mk.sr.bg_555 ro.ky.un_332  ak.ln.un_650 da.da.un_330 
  0x3d00302b, 0x05001204, 0x2d0d1802, 0x0c00130e,   // uz.ku.un_980 hu.fr.un_320  ga.cs.sk_222 et.sv.un_550 
  // [9090]
  0x043048a4, 0x18000502, 0x3f001307, 0x63003f0d,   // tt.uz.ru_433 fr.ga.un_220  et.af.un_420 af.sco.un_540 
  0x48170aa4, 0x3738480d, 0x05002202, 0x25233713,   // mk.sr.tt_433 tt.tk.ba_554  oc.fr.un_220 ba.ky.mn_665 
  0x3c003021, 0x35300407, 0x3c003020, 0x28342102,   // uz.ug.un_860 ru.uz.tg_432  uz.ug.un_850 fa.ps.sd_222 
  0x3b6b58a4, 0x58643b08, 0x28352a04, 0x4c643b0c,   // om.ceb.so_433 so.lg.om_443  mt.zu.sw_332 so.lg.wo_543 
  // [90a0]
  0x02007309, 0x5e00640c, 0x361918a4, 0x6b791aa9,   // ny.da.un_440 lg.ts.un_530  ga.gl.gn_433 tl.war.ceb_544 
  0x6b644c0c, 0x35004423, 0x3b2864a9, 0x5d645e07,   // wo.lg.ceb_543 kk.tg.un_880  lg.sw.so_544 ts.lg.ss_432 
  0x42430509, 0x483715ee, 0x643b580e, 0x0415070e,   // fr.ie.co_444 un.ba.tt_422  om.so.lg_555 bg.ru.un_550 
  0x180157a7, 0x35002505, 0x5800640d, 0x092a6407,   // na.en.ga_532 mn.tg.un_330  lg.om.un_540 lg.mt.pl_432 
  // [90b0]
  0x3b4c640d, 0x0a080704, 0x341221a0, 0x3b644cad,   // lg.wo.so_554 bg.uk.mk_332  fa.ur.ps_322 wo.lg.so_643 
  0x52006e22, 0xfc283513, 0x3b584c09, 0x58006b19,   // hmn.ha.un_870 zu.sw.zzp_665  wo.om.so_444 ceb.om.un_750 
  0x46002e12, 0x332e4e04, 0x64564ca0, 0x13000420,   // fo.qu.un_640 ay.fo.nn_332  wo.mg.lg_322 fi.et.un_850 
  0x2f002013, 0x404205ee, 0x35005c04, 0x2d0d20ee,   // sq.su.un_650 fr.co.lb_422  sa.zu.un_320 sq.cs.sk_422 
  // [90c0]
  0x0a17100d, 0x23383007, 0x2f4205a4, 0x0e202a0d,   // be.sr.mk_554 uz.tk.ky_432  fr.co.su_433 mt.sq.is_554 
  0x07000a36, 0x20000c07, 0x51003502, 0x343d2111,   // mk.bg.un_AA0 sv.sq.un_420  zu.kl.un_220 fa.ku.ps_653 
  0x0d042d0c, 0x3f520904, 0x13090d08, 0x16004207,   // sk.fi.cs_543 pl.ha.af_332  ne.hi.bh_443 co.hr.un_420 
  0x36353ca7, 0x0a2f1908, 0x190b2fec, 0x18001708,   // ug.tg.ab_532 gl.su.pt_443  su.es.gl_644 sr.ga.un_430 
  // [90d0]
  0x19002f05, 0x1100290d, 0x25351504, 0x0d001907,   // su.gl.un_330 sl.ro.un_540  un.tg.mn_332 gl.cs.un_420 
  0x0a004004, 0x23170702, 0x2d000921, 0x28005c0d,   // lb.pt.un_320 bg.sr.ky_222  pl.sk.un_860 sa.sw.un_540 
  0x2a001507, 0x1e1c2112, 0x04292da4, 0x3f5301ad,   // un.mt.un_420 jw.id.ms_654  sk.sl.fi_433 en.ht.af_643 
  0x38003b08, 0x2d0d79a9, 0x3b006e0c, 0x5f37680c,   // so.tk.un_430 war.cs.sk_544  hmn.so.un_530 ig.st.tn_543 
  // [90e0]
  0x371e1c12, 0x64001504, 0x640f380c, 0x15272907,   // id.ms.st_654 un.lg.un_320  tk.lv.lg_543 sl.gd.un_432 
  0x612a6e0d, 0x4a6533a0, 0x21343c0e, 0xfc005804,   // hmn.mt.za_554 nn.gv.yo_322  ug.ps.fa_555 om.zzp.un_320 
  0x2a12080b, 0x21003702, 0x60033f09, 0x1527020c,   // no.hu.mt_542 st.jw.un_220  af.nl.vo_444 da.gd.un_543 
  0x303811a0, 0x2f052104, 0x64002507, 0x67004519,   // ro.tk.uz_322 jw.fr.su_332  eu.lg.un_420 ln.ak.un_750 
  // [90f0]
  0x40000208, 0x21183d0c, 0x2c202aa7, 0x051d010c,   // da.lb.un_430 ku.ar.fa_543  mt.sq.fy_532 en.la.fr_543 
  0x3302080b, 0x1c1e38a7, 0x1f006e19, 0x340640a7,   // no.da.nn_542 tk.ms.id_532  hmn.cy.un_750 lb.de.xh_532 
  0x19471ca0, 0xfc004508, 0x0d1640ad, 0x042e330c,   // id.sn.gl_322 ln.zzp.un_430  lb.hr.cs_643 nn.fo.fi_543 
  0x12004c0c, 0x3764380c, 0x0dfc40ec, 0x3e223902,   // wo.hu.un_530 tk.lg.st_543  lb.zzp.cs_644 br.oc.rm_222 
  // [9100]
  0x070a30a0, 0xfc006912, 0x44003804, 0x22004304,   // uz.mk.bg_322 mfe.zzp.un_640  tk.kk.un_320 ie.oc.un_320 
  0x0c252a04, 0x3b00121a, 0xfc190b09, 0x332162ad,   // mt.eu.sv_332 ur.ks.un_760  es.gl.zzp_444 kha.jw.nn_643 
  0x1500fc04, 0x44351007, 0x0f002a02, 0x330c080e,   // zzp.un.un_320 be.tg.kk_432  mt.lv.un_220 no.sv.nn_555 
  0x09004002, 0x1f001b13, 0x29001107, 0x15fc40ec,   // lb.pl.un_220 tr.cy.un_650  ro.sl.un_420 lb.zzp.un_644 
  // [9110]
  0x3f472aee, 0x1700380c, 0x1f400d55, 0x1dfc22a4,   // mt.sn.af_422 tk.sr.un_530  cs.lb.cy_442 oc.zzp.la_433 
  0x5c305512, 0x04123fee, 0x38003404, 0x0c1e3302,   // rw.uz.sa_654 af.hu.fi_422  xh.tk.un_320 nn.ms.sv_222 
  0x0c022d12, 0x56000d08, 0x341218a9, 0x44182304,   // sk.da.sv_654 cs.mg.un_430  ar.ur.ps_544 ky.ar.kk_332 
  0x040d36a7, 0x0408230b, 0x4800150e, 0x303835ec,   // gn.cs.fi_532 ky.uk.ru_542  un.tt.un_550 tg.tk.uz_644 
  // [9120]
  0x070a100c, 0x13633fa9, 0x3f004d1a, 0x58026307,   // be.mk.bg_543 af.sco.et_544  aa.af.un_760 sco.da.om_432 
  0x341821ec, 0x3b005304, 0x153530af, 0x303c3504,   // fa.ar.ps_644 ht.so.un_320  uz.tg.un_655 tg.ug.uz_332 
  0x170a25a0, 0x0d1c13a0, 0x24001308, 0x50004602,   // mn.mk.sr_322 bh.mr.ne_322  et.eo.un_430 qu.fj.un_220 
  0x09130d07, 0x2d6501a4, 0x07001712, 0x100a07a4,   // ne.bh.hi_432 en.gv.sk_433  sr.bg.un_640 bg.mk.be_433 
  // [9130]
  0x08044402, 0x354815ee, 0x182134ec, 0x0708100c,   // kk.ru.uk_222 un.tt.tg_422  ps.fa.ar_644 be.uk.bg_543 
  0x23444809, 0x4b00492a, 0x13005813, 0x556a0409,   // tt.kk.ky_444 to.mi.un_970  om.et.un_650 fi.haw.rw_444 
  0x4a250408, 0x6a5d5ead, 0x3100020d, 0x4537520c,   // fi.eu.yo_443 ts.ss.haw_643  da.az.un_540 ha.st.ln_543 
  0x564a73a0, 0x233735ee, 0x4a00fc09, 0x28002114,   // ny.yo.mg_322 tg.ba.ky_422  zzp.yo.un_440 fa.sd.un_660 
  // [9140]
  0x3b007912, 0x55643455, 0x562534a0, 0x45003414,   // war.so.un_640 xh.lg.rw_442  xh.eu.mg_322 xh.ln.un_660 
  0x48793b07, 0x072348ee, 0x5d734605, 0x48001a04,   // so.war.tt_432 tt.ky.bg_422  qu.ny.ss_333 tl.tt.un_320 
  0x24292f05, 0x2f2118a7, 0x21452808, 0x153b6402,   // su.sl.eo_333 ga.jw.su_532  sw.ln.jw_443 lg.so.un_222 
  0x564953a4, 0x190b2505, 0x022b250c, 0x00006706,   // ht.to.mg_433 eu.es.gl_333  eu.vi.da_543 ak.un.un_400 
  // [9150]
  0x64583ba4, 0x37483caf, 0x30353c0e, 0x1a796b14,   // so.om.lg_433 ug.tt.ba_655  ug.tg.uz_555 ceb.war.tl_666 
  0x13003604, 0x1b3848af, 0x373c44ec, 0x34003520,   // gn.et.un_320 tt.tk.tr_655  kk.ug.ba_644 zu.xh.un_850 
  0x483031a4, 0x1b2f3bee, 0x2c0865a0, 0x32006b02,   // az.uz.tt_433 so.su.tr_422  gv.no.fy_322 ceb.bs.un_220 
  0x39002a29, 0x481b31a6, 0x2c001302, 0x183430a9,   // bo.dz.un_960 az.tr.tt_521  et.fy.un_220 uz.ps.ar_544 
  // [9160]
  0x25002705, 0x3f330809, 0x19002e02, 0x303d2112,   // gd.eu.un_330 no.nn.af_444  fo.gl.un_220 fa.ku.uz_654 
  0x76020107, 0x28343d04, 0x3544230d, 0x034063a4,   // en.da.crs_432 ku.ps.sd_332  ky.kk.tg_554 sco.lb.nl_433 
  0x35004305, 0x31003012, 0x64520207, 0x101a1ea0,   // ie.zu.un_330 uz.az.un_640  da.ha.lg_432 ms.tl.lt_322 
  0x6a345f0c, 0x45566a08, 0x122d6ba0, 0x482338af,   // tn.xh.haw_543 haw.mg.ln_443  ceb.sk.hu_322 tk.ky.tt_655 
  // [9170]
  0x55644aee, 0x1a461ea9, 0x25041107, 0x5d000908,   // yo.lg.rw_422 ms.qu.tl_544  ro.ru.mn_432 pl.ss.un_430 
  0x374e210c, 0x302d0d08, 0x59006419, 0x28361307,   // jw.ay.st_543 cs.sk.uz_443  lg.rn.un_750 et.gn.sw_432 
  0x6b007314, 0x1e5556a0, 0x2a001c04, 0x02004a0e,   // ny.ceb.un_660 mg.rw.ms_322  id.mt.un_320 yo.da.un_550 
  0x15303c0d, 0x35594509, 0x0f3e60a9, 0x34003705,   // ug.uz.un_554 ln.rn.zu_444  vo.rm.lv_544 st.xh.un_330 
  // [9180]
  0x25001523, 0x37005f0e, 0x02285208, 0x25374804,   // un.mn.un_880 tn.st.un_550  ha.sw.da_443 tt.ba.mn_332 
  0x1d604f07, 0x150228ee, 0x4b7346a9, 0x110a07a4,   // bi.vo.la_432 sw.da.un_422  qu.ny.mi_544 bg.mk.ro_433 
  0x2c006308, 0x335e46a4, 0x51004612, 0x40001e04,   // sco.fy.un_430 qu.ts.nn_433  qu.kl.un_640 ms.lb.un_320 
  0x1239430c, 0x123b3d0e, 0x272b390c, 0x180227a9,   // ie.br.hu_543 ku.ks.ur_555  br.vi.gd_543 gd.da.ga_544 
  // [9190]
  0x0e00270d, 0x330843a4, 0x22000702, 0x432b0907,   // gd.is.un_540 ie.no.nn_433  it.oc.un_220 pl.vi.ie_432 
  0x12002f0d, 0x5c734ead, 0x1e000c05, 0x112d15ad,   // su.hu.un_540 ay.ny.sa_643  sv.ms.un_330 un.sk.ro_643 
  0x2f4e1012, 0x68005f18, 0x1b00041b, 0x473502ac,   // lt.ay.su_654 tn.ig.un_740  fi.tr.un_770 da.zu.sn_632 
  0x13000605, 0x3b001d04, 0x02005322, 0x130dfe12,   // de.et.un_330 la.so.un_320  ht.da.un_870 tlh.cs.et_654 
  // [91a0]
  0x2f211a04, 0x28006307, 0x36003512, 0x1e00531a,   // tl.jw.su_332 sco.sw.un_420  tg.ab.un_640 ht.ms.un_760 
  0x64006309, 0x0600fe04, 0x1053690c, 0x09006e07,   // sco.lg.un_440 tlh.de.un_320  mfe.ht.lt_543 hmn.pl.un_420 
  0x5d356207, 0x6b422c07, 0x16001704, 0x5d5e250d,   // kha.zu.ss_432 fy.co.ceb_432  sr.hr.un_320 eu.ts.ss_554 
  0x2a3e4207, 0x2a004004, 0x42073e08, 0x124006af,   // co.rm.mt_432 lb.mt.un_320  rm.it.co_443 de.lb.hu_655 
  // [91b0]
  0x1b022cee, 0x20290204, 0x3e002719, 0x09001211,   // fy.da.tr_422 da.sl.sq_332  gd.rm.un_750 hu.pl.un_630 
  0x53007904, 0x090a0ba0, 0x2a1b01a0, 0x22000f08,   // war.ht.un_320 es.pt.pl_322  en.tr.mt_322 lv.oc.un_430 
  0x56075502, 0x271839a9, 0x2a422cac, 0x18000804,   // rw.it.mg_222 br.ga.gd_544  fy.co.mt_632 no.ga.un_320 
  0x341502ee, 0x65426304, 0x425cfe02, 0x3e006304,   // da.xh.un_420 sco.co.gv_332  tlh.sa.co_222 sco.rm.un_320 
  // [91c0]
  0x0b393ea0, 0x1a4e6704, 0x52584d5a, 0x23041507,   // rm.br.es_322 ak.ay.tl_332  aa.om.ha_553 un.ru.ky_432 
  0x734e4660, 0x4200020c, 0xfe004e13, 0x36691f55,   // qu.ay.ny_664 da.co.un_530  ay.tlh.un_650 cy.mfe.gn_442 
  0x17250407, 0x766b69a4, 0x420763a4, 0x48003c07,   // ru.mn.sr_432 mfe.ceb.crs_433  sco.it.co_433 ug.tt.un_420 
  0x290701a0, 0x3f03fca4, 0x632a4204, 0x09006e0e,   // en.it.sl_322 zzp.nl.af_433  co.mt.sco_332 hmn.pl.un_550 
  // [91d0]
  0x33080e05, 0x12130604, 0x3306fca7, 0x3000420d,   // is.no.nn_333 de.et.hu_332  zzp.de.nn_532 co.uz.un_540 
  0x736306a0, 0x172c03a7, 0x0c3e0ea0, 0x2c000c08,   // de.sco.ny_322 nl.fy.sr_532  is.rm.sv_322 sv.fy.un_430 
  0x37070a0b, 0x2f1b1207, 0x2e2c3f02, 0xfc000107,   // mk.bg.ba_542 hu.tr.su_432  af.fy.fo_222 en.zzp.un_420 
  0x654079a0, 0x043611ad, 0x23251508, 0x374836af,   // war.lb.gv_322 ro.ab.ru_643  un.mn.ky_443 ab.tt.ba_655 
  // [91e0]
  0x483723ec, 0x00000624, 0x34003d29, 0x38003721,   // ky.ba.tt_644 de.un.un_900  ku.ps.un_960 ba.tk.un_860 
  0x1000350c, 0x3d003c04, 0x3c002802, 0x4c4d6409,   // tg.be.un_530 ug.ku.un_320  sd.ug.un_220 lg.aa.wo_444 
  0x28211808, 0x51003b07, 0x17000a18, 0x243f3bee,   // ar.fa.sd_443 so.kl.un_420  mk.sr.un_740 so.af.eo_422 
  0x3048370c, 0x4d4c5860, 0x58643b05, 0x2700220c,   // ba.tt.uz_543 om.wo.aa_664  so.lg.om_333 oc.gd.un_530 
  // [91f0]
  0x22002714, 0x31003b0b, 0x070a3c02, 0x15003b07,   // gd.oc.un_660 so.az.un_520  ug.mk.bg_222 so.un.un_420 
  0x65000414, 0x15033fa4, 0x58002c05, 0x093b58a4,   // fi.gv.un_660 af.nl.un_433  fy.om.un_330 om.so.pl_433 
  0x12004c08, 0x31003907, 0x39006504, 0x36005004,   // wo.hu.un_430 br.az.un_420  gv.br.un_320 fj.gn.un_320 
  0x48311b09, 0x3b461b04, 0x53360502, 0x40655805,   // tr.az.tt_444 tr.qu.so_332  fr.gn.ht_222 om.gv.lb_333 
  // [9200]
  0x583b65a4, 0x5c090d08, 0x22241da0, 0x3c352355,   // gv.so.om_433 ne.hi.sa_443  la.eo.oc_322 ky.tg.ug_442 
  0x6b791307, 0x1708100c, 0x25790b04, 0xfc001d09,   // et.war.ceb_432 be.uk.sr_543  es.war.eu_332 la.zzp.un_440 
  0x301a52a7, 0x5b006821, 0x79252807, 0x2749630c,   // ha.tl.uz_532 ig.sg.un_860  sw.eu.war_432 sco.to.gd_543 
  0x213463a0, 0x1c001e13, 0x1f006304, 0x34212308,   // sco.xh.jw_322 ms.id.un_650  sco.cy.un_320 ky.fa.ps_443 
  // [9210]
  0x2700630c, 0x46534d12, 0x23483012, 0x061213a0,   // sco.gd.un_530 aa.ht.qu_654  uz.tt.ky_654 et.hu.de_322 
  0x070830a4, 0x0400230e, 0x15234407, 0x403e06ee,   // uz.uk.bg_433 ky.ru.un_550  kk.ky.un_432 de.rm.lb_422 
  0x6300270d, 0x44233807, 0x17080a08, 0x12130608,   // gd.sco.un_540 tk.ky.kk_432  mk.uk.sr_443 de.et.hu_443 
  0x39006502, 0x22002713, 0x374423ee, 0x08000f08,   // gv.br.un_220 gd.oc.un_650  ky.kk.ba_422 lv.no.un_430 
  // [9220]
  0x321353a0, 0x1700020c, 0x211c6ea7, 0x0b002302,   // ht.et.bs_322 da.sr.un_530  hmn.id.jw_532 ca.es.un_220 
  0x240430ad, 0x181e1c0c, 0x04004809, 0x04033f07,   // uz.fi.eo_643 id.ms.ga_543  tt.ru.un_440 af.nl.fi_432 
  0x3f003e0e, 0x2c00010d, 0x183e6e07, 0x220a3e08,   // rm.af.un_550 en.fy.un_540  hmn.rm.ga_432 rm.pt.oc_443 
  0x04001812, 0x3b0925ad, 0x014033a7, 0x3b003007,   // ga.fi.un_640 eu.pl.so_643  nn.lb.en_532 uz.so.un_420 
  // [9230]
  0x03002c22, 0x4800fe05, 0x04344e5a, 0x23fc190c,   // fy.nl.un_870 tlh.tt.un_330  ay.xh.fi_553 gl.zzp.ca_543 
  0xfc15020c, 0x407906a4, 0x1c0a6e08, 0x063f03a4,   // da.zzp.un_530 de.war.lb_433  hmn.pt.id_443 nl.af.de_433 
  0x27180a0d, 0x6e001d19, 0x2c00030c, 0x50006e07,   // pt.ga.gd_554 la.hmn.un_750  nl.fy.un_530 hmn.fj.un_420 
  0x186e1d07, 0x46203b02, 0x27006307, 0x28211212,   // la.hmn.ga_432 so.sq.qu_222  sco.gd.un_420 ur.fa.sd_654 
  // [9240]
  0x38003c0c, 0x033f1f13, 0x1d2f01a0, 0x1535250c,   // ug.tk.un_530 cy.af.nl_665  en.su.la_322 mn.tg.un_543 
  0x122e3305, 0x342128a7, 0x35443012, 0x0d001804,   // nn.fo.hu_333 sd.fa.ps_532  uz.kk.tg_654 ga.cs.un_320 
  0x0a000204, 0x2305010c, 0x73fc2812, 0x0d130955,   // da.pt.un_320 en.fr.ca_543  sw.zzp.ny_654 hi.bh.ne_442 
  0x030d0602, 0x0900fc22, 0x17103512, 0x2d0d24a0,   // de.cs.nl_222 zzp.pl.un_870  tg.be.sr_654 eo.cs.sk_322 
  // [9250]
  0x5e596709, 0x6467fcad, 0x3efc06ee, 0x67fc06a9,   // ak.rn.ts_444 zzp.ak.lg_643  de.zzp.rm_422 de.zzp.ak_544 
  0x02020c07, 0x25000a07, 0x0269fc07, 0x19090aaf,   // sv.da.da_432 mk.mn.un_420  zzp.mfe.da_432 pt.pl.gl_655 
  0x42002213, 0x27730a04, 0x34233d07, 0x09595555,   // oc.co.un_650 pt.ny.gd_332  ku.ky.ps_432 rw.rn.pl_442 
  0x213430ac, 0x55003b02, 0x095c1caf, 0x016b4dad,   // uz.ps.fa_632 so.rw.un_220  mr.sa.hi_655 aa.ceb.en_643 
  // [9260]
  0x533034ee, 0x023b01a0, 0x12002308, 0x0e003e07,   // xh.uz.ht_422 en.so.da_322  ca.hu.un_430 rm.is.un_420 
  0x332b0802, 0x65003008, 0x2913fe04, 0x1b006402,   // no.vi.nn_222 uz.gv.un_430  tlh.et.sl_332 lg.tr.un_220 
  0x5150380c, 0x37007509, 0x53001b08, 0x464e23a4,   // tk.fj.kl_543 nso.st.un_440  tr.ht.un_430 ca.ay.qu_433 
  0xfc452505, 0x23283460, 0x11176305, 0x3d342160,   // eu.ln.zzp_333 ps.sd.ky_664  sco.sr.ro_333 fa.ps.ku_664 
  // [9270]
  0x2d006404, 0x5f53fc0c, 0x1b00580c, 0x2d170da4,   // lg.sk.un_320 zzp.ht.tn_543  om.tr.un_530 cs.sr.sk_433 
  0x5373280b, 0xfe2320a4, 0x6b001b04, 0x23304404,   // sw.ny.ht_542 sq.ca.tlh_433  tr.ceb.un_320 kk.uz.ky_332 
  0x65484307, 0x09005804, 0x215f37af, 0x27002302,   // ie.tt.gv_432 om.pl.un_320  st.tn.jw_655 ca.gd.un_220 
  0x34123d02, 0x23000610, 0x35301504, 0x30001512,   // ku.ur.ps_222 de.ca.un_620  un.uz.tg_332 un.uz.un_640 
  // [9280]
  0x49006504, 0x483607a4, 0x21234407, 0x4a005b19,   // gv.to.un_320 bg.ab.tt_433  kk.ky.fa_432 sg.yo.un_750 
  0x1a4a680c, 0x33000e07, 0x37fc0207, 0xfc375fa4,   // ig.yo.tl_543 is.nn.un_420  da.zzp.st_432 tn.st.zzp_433 
  0x5f37fca9, 0x05034904, 0x3025350c, 0x574006af,   // zzp.st.tn_544 to.nl.fr_332  tg.mn.uz_543 de.lb.na_655 
  0x37025fa9, 0x2c40060b, 0x05000b02, 0x02003f04,   // tn.da.st_544 de.lb.fy_542  es.fr.un_220 af.da.un_320 
  // [9290]
  0xfc006e07, 0x3500101a, 0x041048a6, 0x443038a4,   // hmn.zzp.un_420 be.tg.un_760  tt.be.ru_521 tk.uz.kk_433 
  0x0600fc09, 0x1c095ca6, 0x462e4304, 0x02003205,   // zzp.de.un_440 sa.hi.mr_521  ie.fo.qu_332 bs.da.un_330 
  0x3744380c, 0x122d2ea4, 0x2342220b, 0x1d090f12,   // tk.kk.ba_543 fo.sk.hu_433  oc.co.ca_542 lv.pl.la_654 
  0x2f003419, 0xfc1009ad, 0x1b643b5a, 0x06003007,   // xh.su.un_750 pl.lt.zzp_643  so.lg.tr_553 uz.de.un_420 
  // [92a0]
  0x090c2dee, 0x0e2d19af, 0x28580207, 0x73026407,   // sk.sv.pl_422 gl.sk.is_655  da.om.sw_432 lg.da.ny_432 
  0x52586404, 0x091d1112, 0x5f3f6405, 0x27002304,   // lg.om.ha_332 ro.la.pl_654  lg.af.tn_333 ca.gd.un_320 
  0x24000914, 0x013618a4, 0x29001a04, 0x066b5e08,   // pl.eo.un_660 ga.gn.en_433  tl.sl.un_320 ts.ceb.de_443 
  0x153010ad, 0x15000435, 0x40790912, 0x123c1807,   // be.uz.un_643 ru.un.un_A90  pl.war.lb_654 ar.ug.ur_432 
  // [92b0]
  0x30354807, 0x55644507, 0x42020fa7, 0x331b0c0b,   // tt.tg.uz_432 ln.lg.rw_432  lv.da.co_532 sv.tr.nn_542 
  0x790a280c, 0x48101507, 0x4c005805, 0x65006208,   // sw.pt.war_543 un.be.tt_432  om.wo.un_330 kha.gv.un_430 
  0x3f003b0b, 0x2e0e2d0b, 0x05004604, 0x021d1808,   // so.af.un_520 sk.is.fo_542  qu.fr.un_320 ga.la.da_443 
  0x6b000108, 0x4c655807, 0x58656712, 0x381004a4,   // en.ceb.un_430 om.gv.wo_432  ak.gv.om_654 ru.be.tk_433 
  // [92c0]
  0x15125c07, 0x5c000d11, 0x095c1ca9, 0x18004507,   // sa.hu.un_432 ne.sa.un_630  mr.sa.hi_544 ln.ga.un_420 
  0x2e190b05, 0x67023f0c, 0x150a04a0, 0x4d586511,   // es.gl.fo_333 af.da.ak_543  ru.mk.un_322 gv.om.aa_653 
  0x12184408, 0x1211fc07, 0x3200160b, 0x47281a0c,   // kk.ar.ur_443 zzp.ro.hu_432  hr.bs.un_520 tl.sw.sn_543 
  0x38002108, 0x473b6408, 0x4c216ba4, 0x152344a4,   // jw.tk.un_430 lg.so.sn_443  ceb.jw.wo_433 kk.ky.un_433 
  // [92d0]
  0x4d575208, 0x5247490c, 0x52576a0c, 0x16090dad,   // ha.na.aa_443 to.sn.ha_543  haw.na.ha_543 cs.pl.hr_643 
  0x68641a11, 0x67475209, 0x52002104, 0x176a50ad,   // tl.lg.ig_653 ha.sn.ak_444  jw.ha.un_320 fj.haw.sr_643 
  0x52623b5a, 0x1239470c, 0x2f00fc13, 0x37000214,   // so.kha.ha_553 sn.br.hu_543  zzp.su.un_650 da.st.un_660 
  0x1a38620c, 0x1200470c, 0x56006402, 0x06455255,   // kha.tk.tl_543 sn.hu.un_530  lg.mg.un_220 ha.ln.de_442 
  // [92e0]
  0x47392007, 0x1a6b7908, 0x2500490d, 0x56002413,   // sq.br.sn_432 war.ceb.tl_443  to.eu.un_540 eo.mg.un_650 
  0x4955250b, 0x52004623, 0x69002808, 0x454728ad,   // eu.rw.to_542 qu.ha.un_880  sw.mfe.un_430 sw.sn.ln_643 
  0x6b1a4655, 0x50463b0d, 0x2821570c, 0x6500270e,   // qu.tl.ceb_442 so.qu.fj_554  na.jw.sw_543 gd.gv.un_550 
  0x17041504, 0x5625470b, 0x0252100c, 0x2c4006a9,   // un.ru.sr_332 sn.eu.mg_542  lt.ha.da_543 de.lb.fy_544 
  // [92f0]
  0x504347a7, 0x7347280d, 0x452d0d13, 0x083c1555,   // sn.ie.fj_532 sw.sn.ny_554  cs.sk.ln_665 un.ug.uk_442 
  0x15111707, 0x2d0d45ee, 0x0163fc05, 0x2d0d45a4,   // sr.ro.un_432 ln.cs.sk_422  zzp.sco.en_333 ln.cs.sk_433 
  0x131c5cee, 0x123c28a0, 0x36001308, 0x353725a9,   // sa.mr.bh_422 sd.ug.ur_322  et.gn.un_430 mn.ba.tg_544 
  0x11373812, 0x23384413, 0x37002307, 0x5800280b,   // tk.ba.ro_654 kk.tk.ky_665  ky.ba.un_420 sw.om.un_520 
  // [9300]
  0x12002834, 0x25001529, 0x200c1511, 0x3300620e,   // sd.ur.un_A80 un.mn.un_960  un.sv.sq_653 kha.nn.un_550 
  0x3d1834a7, 0x2d005013, 0x15330802, 0x19002305,   // ps.ar.ku_532 fj.sk.un_650  no.nn.un_222 ca.gl.un_330 
  0x07001509, 0x56004b21, 0x33081fa4, 0x47645504,   // un.bg.un_440 mi.mg.un_860  cy.no.nn_433 rw.lg.sn_332 
  0x39374bee, 0x34007812, 0x460515ee, 0x50004208,   // mi.st.br_422 ve.xh.un_640  un.fr.qu_422 co.fj.un_430 
  // [9310]
  0x495f2c0c, 0x214679a0, 0x0b0a19af, 0x17150a04,   // fy.tn.to_543 war.qu.jw_322  gl.pt.es_655 mk.sr.un_320 
  0x341f47ee, 0x5a2c4baf, 0x4006fc07, 0x1823345a,   // sn.cy.xh_422 mi.fy.sm_655  zzp.de.lb_432 ps.ky.ar_553 
  0x12360aa7, 0x375f01a0, 0x036501a0, 0x556b28a0,   // pt.gn.hu_532 en.tn.st_322  en.gv.nl_322 sw.ceb.rw_322 
  0x56004204, 0x2c1775a0, 0x382d1fa4, 0x18005505,   // co.mg.un_320 nso.sr.fy_322  cy.sk.tk_433 rw.ga.un_330 
  // [9320]
  0x12000a07, 0x02fe6307, 0x100f5009, 0x20003002,   // pt.hu.un_420 sco.tlh.da_432  fj.lv.lt_444 uz.sq.un_220 
  0x46003402, 0x564b11a7, 0x56003013, 0x35003f04,   // xh.qu.un_220 ro.mi.mg_532  uz.mg.un_650 af.zu.un_320 
  0x4535fcad, 0x4746fcee, 0x5a00112b, 0x3d2130a6,   // zzp.zu.ln_643 zzp.qu.sn_422  ro.sm.un_980 uz.fa.ku_521 
  0x182130ad, 0x25301012, 0x070a3505, 0x2d002c04,   // uz.fa.ar_643 be.uz.mn_654  tg.mk.bg_333 fy.sk.un_320 
  // [9330]
  0x303c360b, 0x251004a0, 0x15070a04, 0x10003613,   // ab.ug.uz_542 ru.be.mn_322  mk.bg.un_332 ab.be.un_650 
  0x49004b07, 0x53001a07, 0x2300630c, 0x65000107,   // mi.to.un_420 tl.ht.un_420  sco.ca.un_530 en.gv.un_420 
  0x3b00640e, 0x22206ba0, 0x08025302, 0x033f0f07,   // lg.so.un_550 ceb.sq.oc_322  ht.da.no_222 lv.af.nl_432 
  0x33082e05, 0x5d65580c, 0x20030e07, 0x4c2c4da0,   // fo.no.nn_333 om.gv.ss_543  is.nl.sq_432 aa.fy.wo_322 
  // [9340]
  0x7958650c, 0x4d0458ec, 0x650458a9, 0x48154407,   // gv.om.war_543 om.fi.aa_644  om.fi.gv_544 kk.tt.un_420 
  0x2c2e10ee, 0x4c586ba4, 0x5c1a1ea0, 0x12002304,   // lt.fo.fy_422 ceb.om.wo_433  ms.tl.sa_322 ky.ur.un_320 
  0x153811a9, 0x443c2305, 0x5c1a5b55, 0x3b654d12,   // ro.tk.un_544 ky.ug.kk_333  sg.tl.sa_442 aa.gv.so_654 
  0x480604ac, 0x063f5807, 0x3017350b, 0x1e3b30a0,   // fi.de.tt_632 om.af.de_432  tg.sr.uz_542 uz.so.ms_322 
  // [9350]
  0x28123dec, 0x372046ee, 0x182765a0, 0x0405650c,   // ku.ur.sd_644 qu.sq.st_422  gv.gd.ga_322 gv.fr.fi_543 
  0x4e0454ad, 0x350a250c, 0x2311380c, 0x30004622,   // ik.fi.ay_643 mn.mk.tg_543  tk.ro.ky_543 qu.uz.un_870 
  0x163217a7, 0x39580ba0, 0x5c003507, 0x1d15470c,   // sr.bs.hr_532 es.om.br_322  zu.sa.un_420 sn.la.un_530 
  0x27185109, 0x2a00fe12, 0x4e654609, 0x122c2e0c,   // kl.ga.gd_444 tlh.mt.un_640  qu.gv.ay_444 fo.fy.hu_543 
  // [9360]
  0x20002312, 0x51006513, 0x0b004702, 0x4f006208,   // ca.sq.un_640 gv.kl.un_650  sn.es.un_220 kha.bi.un_430 
  0x515c1fee, 0x46232008, 0x464220ee, 0x550c590b,   // cy.sa.kl_422 sq.ca.qu_443  sq.co.qu_422 rn.sv.rw_542 
  0x2c3f65ad, 0x37103604, 0x151017a0, 0x04005607,   // gv.af.fy_643 ab.be.ba_332  sr.be.un_322 mg.fi.un_420 
  0x23006721, 0x51002004, 0x190b0e05, 0x0807170c,   // ak.ca.un_860 sq.kl.un_320  is.es.gl_333 sr.bg.uk_543 
  // [9370]
  0x0700041b, 0x103c380c, 0x28183414, 0x31465ba9,   // ru.bg.un_770 tk.ug.be_543  ps.ar.sd_666 sg.qu.az_544 
  0x55002704, 0x35153804, 0x02034d0c, 0x013f03ad,   // gd.rw.un_320 tk.tg.un_320  aa.nl.da_543 nl.af.en_643 
  0xfc153bee, 0x4a001514, 0x4c583b07, 0x4c3b5808,   // so.zzp.un_420 un.yo.un_660  so.om.wo_432 om.so.wo_443 
  0x46000b04, 0x12003b07, 0x460b360b, 0x012b3bee,   // es.qu.un_320 ks.ur.un_420  gn.es.qu_542 so.vi.en_422 
  // [9380]
  0x03004c04, 0x07443807, 0x3f005805, 0x10002521,   // wo.nl.un_320 tk.kk.bg_432  om.af.un_330 mn.be.un_860 
  0x041025a0, 0x35000719, 0x0a3c350c, 0x13095c05,   // mn.be.ru_322 bg.tg.un_750  tg.ug.mk_543 sa.hi.bh_333 
  0x6a004b0d, 0x230a37ad, 0x18214405, 0x595546a0,   // mi.haw.un_540 ba.mk.ky_643  kk.fa.ar_333 qu.rw.rn_322 
  0x45647312, 0x353478af, 0x0b0a1209, 0x4a343511,   // ny.lg.ln_654 ve.xh.zu_655  hu.pt.es_444 zu.xh.yo_653 
  // [9390]
  0x64595508, 0x28231204, 0x48001512, 0x4d375f0c,   // rw.rn.lg_443 ur.ky.sd_332  un.tt.un_640 tn.st.aa_543 
  0x305f5a0c, 0x40002404, 0x59641f0d, 0x3b1b64a0,   // sm.tn.uz_543 eo.lb.un_320  cy.lg.rn_554 lg.tr.so_322 
  0x0000382d, 0x4a001213, 0x0f1c2fa0, 0x211c3004,   // tk.un.un_A00 hu.yo.un_650  su.id.lv_322 uz.id.jw_332 
  0x21551f0c, 0x0e080202, 0x22005b0e, 0x30495aa4,   // cy.rw.jw_543 da.no.is_222  sg.oc.un_550 sm.to.uz_433 
  // [93a0]
  0x5c793605, 0x093f2807, 0x12322804, 0x0c563b09,   // gn.war.sa_333 sw.af.pl_432  sw.bs.hu_332 so.mg.sv_444 
  0x24131b07, 0x2f21fe09, 0x40104fa7, 0xfe007607,   // tr.et.eo_432 tlh.jw.su_444  bi.lt.lb_532 crs.tlh.un_420 
  0x5528640c, 0x732851ad, 0x023f30a4, 0x3f000e07,   // lg.sw.rw_543 kl.sw.ny_643  uz.af.da_433 is.af.un_420 
  0x0b3430a4, 0x2800270e, 0xfe1b01a0, 0x31231502,   // uz.xh.es_433 gd.sw.un_550  en.tr.tlh_322 un.ca.az_222 
  // [93b0]
  0x56500da4, 0x3855fca0, 0x64006814, 0x073125a9,   // cs.fj.mg_433 zzp.rw.tk_322  ig.lg.un_660 eu.az.it_544 
  0x281b2007, 0x4e73560e, 0x302426a9, 0x25120107,   // sq.tr.sw_432 mg.ny.ay_555  ia.eo.uz_544 en.hu.eu_432 
  0x2d0d38a4, 0x0f15fe07, 0x481b31a4, 0x5e001508,   // tk.cs.sk_433 tlh.lv.un_420  az.tr.tt_433 un.ts.un_430 
  0x3b003021, 0x4a3512a4, 0x1d270107, 0x310230ee,   // uz.so.un_860 ur.tg.un_433  en.gd.la_432 uz.da.az_422 
  // [93c0]
  0x15041709, 0xfc003007, 0x4602fe07, 0x04253804,   // sr.ru.un_444 uz.zzp.un_420  tlh.da.qu_432 tk.mn.ru_332 
  0x4831fe08, 0x69003019, 0x1d314855, 0x131c5cad,   // tlh.az.tt_443 uz.mfe.un_750  tt.az.la_442 sa.mr.bh_643 
  0x23190a09, 0x3700231a, 0x5116280c, 0x0d5c1c12,   // pt.gl.ca_444 ky.ba.un_760  sw.hr.kl_543 mr.sa.ne_654 
  0x241d1004, 0x2100122b, 0x330812a4, 0x483530a0,   // lt.la.eo_332 ur.fa.un_980  hu.no.nn_433 uz.tg.tt_322 
  // [93d0]
  0x3b3d3460, 0x383530a7, 0x2344180c, 0x091c5c05,   // ps.ku.ks_664 uz.tg.tk_532  ar.kk.ky_543 sa.mr.hi_333 
  0x3b5c3504, 0x5e3534ec, 0x063f030c, 0x3f24220c,   // zu.sa.so_332 xh.zu.ts_644  nl.af.de_543 oc.eo.af_543 
  0x73347812, 0x36003021, 0x47343507, 0x645559a7,   // ve.xh.ny_654 uz.ab.un_860  zu.xh.sn_432 rn.rw.lg_532 
  0x736453ec, 0x1d005204, 0x5c2709a4, 0x1d004707,   // ht.lg.ny_644 ha.la.un_320  pl.gd.sa_433 sn.la.un_420 
  // [93e0]
  0x08020ca0, 0x1900120b, 0x34550207, 0x1b00300b,   // sv.da.no_322 hu.gl.un_520  da.rw.xh_432 uz.tr.un_520 
  0x35001007, 0x1d006b04, 0x5cfe270d, 0x30350a04,   // be.tg.un_420 ceb.la.un_320  gd.tlh.sa_554 mk.tg.uz_332 
  0x35002707, 0x645955ad, 0x64595504, 0x35003429,   // gd.zu.un_420 rw.rn.lg_643  rw.rn.lg_332 xh.zu.un_960 
  0x27004705, 0x73554707, 0x092d0d5a, 0x44361011,   // sn.gd.un_330 sn.rw.ny_432  cs.sk.pl_553 be.ab.kk_653 
  // [93f0]
  0x094315ad, 0x5c1c6b0b, 0x5c641a02, 0x08003808,   // un.ie.pl_643 ceb.id.sa_542  tl.lg.sa_222 tk.uk.un_430 
  0x475c5d0c, 0x3d3b2112, 0x1900fc02, 0x170711a0,   // ss.sa.sn_543 fa.ks.ku_654  zzp.gl.un_220 ro.bg.sr_322 
  0x2300280e, 0x083815ee, 0x301748a9, 0x07001005,   // sd.ky.un_550 un.tk.uk_422  tt.sr.uz_544 be.bg.un_330 
  0x28001808, 0x23182802, 0x34004408, 0x070a2504,   // ar.sd.un_430 sd.ar.ky_222  kk.ps.un_430 mn.mk.bg_332 
  
  // [9400]
  0x3b006e04, 0x5c0d0955, 0x58024cad, 0x17070409,   // hmn.so.un_320 hi.ne.sa_442  wo.da.om_643 ru.bg.sr_444 
  0x096b3bee, 0x63510307, 0x032f1008, 0x0f00fe0d,   // so.ceb.pl_422 nl.kl.sco_432  lt.su.nl_443 tlh.lv.un_540 
  0x48040d02, 0x370817ac, 0x4c650214, 0x0d392f04,   // cs.fi.tt_222 sr.uk.ba_632  da.gv.wo_666 su.br.cs_332 
  0x0804380c, 0x2118120d, 0x09002b14, 0x380d2da0,   // tk.ru.uk_543 ur.ar.fa_554  vi.pl.un_660 sk.cs.tk_322 
  // [9410]
  0x28005d21, 0x0b00120b, 0x645302ee, 0x23002b1a,   // ss.sw.un_860 hu.es.un_520  da.ht.lg_422 vi.ca.un_760 
  0x625305a4, 0x67002f28, 0x04374812, 0x095c0d0b,   // fr.ht.kha_433 su.ak.un_950  tt.ba.ru_654 ne.sa.hi_542 
  0x130d0955, 0x5c003609, 0x38033f12, 0x23003712,   // hi.ne.bh_442 gn.sa.un_440  af.nl.tk_654 ba.ky.un_640 
  0x641a06a0, 0x285d2112, 0x204804a4, 0x30003608,   // de.tl.lg_322 jw.ss.sw_654  fi.tt.sq_433 ab.uz.un_430 
  // [9420]
  0x30004c05, 0x07300808, 0x04250807, 0x0b005e04,   // wo.uz.un_330 uk.uz.bg_443  uk.mn.ru_432 ts.es.un_320 
  0x2e0e1208, 0x0c006307, 0x23441004, 0x27630107,   // hu.is.fo_443 sco.sv.un_420  be.kk.ky_332 en.sco.gd_432 
  0x0e332e13, 0x4a003609, 0x020e2e12, 0x373035ee,   // fo.nn.is_665 gn.yo.un_440  fo.is.da_654 tg.uz.ba_422 
  0x08022eee, 0x0c330213, 0x2e0c06a4, 0x0600380e,   // fo.da.no_422 da.nn.sv_665  de.sv.fo_433 tk.de.un_550 
  // [9430]
  0x50650611, 0x64002c12, 0x402d0d04, 0x30484ead,   // de.gv.fj_653 fy.lg.un_640  cs.sk.lb_332 ay.tt.uz_643 
  0x64000902, 0x3f032507, 0x13332e05, 0x4c2c05ad,   // pl.lg.un_220 eu.nl.af_432  fo.nn.et_333 fr.fy.wo_643 
  0x18006402, 0x052d2ca0, 0x2c000c05, 0x46190b07,   // lg.ga.un_220 fy.sk.fr_322  sv.fy.un_330 es.gl.qu_432 
  0x12283b0d, 0x37044402, 0x1e002e04, 0x3b321604,   // ks.sd.ur_554 kk.ru.ba_222  fo.ms.un_320 hr.bs.so_332 
  // [9440]
  0x375365a0, 0x481115a7, 0x0c00fc07, 0x79066b05,   // gv.ht.st_322 un.ro.tt_532  zzp.sv.un_420 ceb.de.war_333 
  0x643853a0, 0x03002408, 0x0500400e, 0x793f51ad,   // ht.tk.lg_322 eo.nl.un_430  lb.fr.un_550 kl.af.war_643 
  0x12182104, 0x04002402, 0x1526010c, 0x40001602,   // fa.ar.ur_332 eo.fi.un_220  en.ia.un_543 hr.lb.un_220 
  0x190a2e0e, 0x4b001a02, 0x493b580c, 0x35443c04,   // fo.pt.gl_555 tl.mi.un_220  om.so.to_543 ug.kk.tg_332 
  // [9450]
  0x2c006407, 0x584c5b04, 0x3f5f58a9, 0x1f386555,   // lg.fy.un_420 sg.wo.om_332  om.tn.af_544 gv.tk.cy_442 
  0x044d03a9, 0x32001619, 0x60004029, 0x794c510c,   // nl.aa.fi_544 hr.bs.un_750  lb.vo.un_960 kl.wo.war_543 
  0x330e30ee, 0x09402a0c, 0x250a1707, 0x644d5809,   // uz.is.nn_422 mt.lb.pl_543  sr.mk.mn_432 om.aa.lg_444 
  0x300efc07, 0x100a17a0, 0x40001205, 0x3b4d1512,   // zzp.is.uz_432 sr.mk.be_322  hu.lb.un_330 un.aa.so_654 
  // [9460]
  0x403b4c0d, 0x00005a2d, 0x03584dee, 0x33081f02,   // wo.so.lb_554 sm.un.un_A00  aa.om.nl_422 cy.no.nn_222 
  0x0900640d, 0x083715ee, 0x1f002c02, 0x4c044da0,   // lg.pl.un_540 un.ba.uk_422  fy.cy.un_220 aa.fi.wo_322 
  0x13041c07, 0x0400132b, 0x5a58155a, 0x15301005,   // id.fi.et_432 et.fi.un_980  un.om.sm_553 be.uz.un_333 
  0x36000419, 0x35153060, 0xfe001308, 0x2e2d0e09,   // fi.gn.un_750 uz.tg.un_640  et.tlh.un_430 is.sk.fo_444 
  // [9470]
  0x3b341208, 0x301035ec, 0x3c001521, 0x35302513,   // ur.ps.ks_443 tg.be.uz_644  un.ug.un_860 mn.uz.tg_665 
  0x0e0a2ea6, 0x2e0208a7, 0x2834180b, 0x37353012,   // fo.pt.is_521 no.da.fo_532  ar.ps.sd_542 uz.tg.ba_654 
  0x40221207, 0x114815a4, 0x0e060c0c, 0x4c005808,   // hu.oc.lb_432 un.tt.ro_433  sv.de.is_543 om.wo.un_430 
  0xfa355daf, 0x374415ad, 0x104404ee, 0x13355e07,   // ss.zu.nr_655 un.kk.ba_643  ru.kk.be_422 ts.zu.et_432 
  // [9480]
  0x48002322, 0x33022f12, 0x1b001208, 0x2f595504,   // ky.tt.un_870 su.da.nn_654  hu.tr.un_430 rw.rn.su_332 
  0x33002504, 0x68355d0c, 0x28183412, 0x02002f08,   // eu.nn.un_320 ss.zu.ig_543  ps.ar.sd_654 su.da.un_430 
  0x5d35500c, 0x555d350c, 0x5e132fa4, 0x4c00580c,   // fj.zu.ss_543 zu.ss.rw_543  su.et.ts_433 om.wo.un_530 
  0x023308a4, 0x5e2f4b04, 0x444835ee, 0x15173808,   // no.nn.da_433 mi.su.ts_332  tg.tt.kk_422 tk.sr.un_443 
  // [9490]
  0x38482313, 0x3700300e, 0x75212fa9, 0x230430a0,   // ky.tt.tk_665 uz.ba.un_550  su.jw.nso_544 uz.ru.ky_322 
  0x17002407, 0x25004c02, 0x0c2e0207, 0x2f005013,   // eo.sr.un_420 wo.eu.un_220  da.fo.sv_432 fj.su.un_650 
  0x233c4408, 0x09243904, 0x30003f04, 0x351536ad,   // kk.ug.ky_443 br.eo.pl_332  af.uz.un_320 ab.tg.un_630 
  0x794b6aa4, 0x332e2907, 0x28004702, 0x35392807,   // haw.mi.war_433 sl.fo.nn_432  sn.sw.un_220 sw.br.zu_432 
  // [94a0]
  0x524a0fa4, 0x252f35a4, 0x2d1624a4, 0x351e5009,   // lv.yo.ha_433 zu.su.eu_433  eo.hr.sk_433 fj.ms.zu_444 
  0x4a572113, 0x344a7307, 0x35731307, 0x55005912,   // jw.na.yo_665 ny.yo.xh_432  et.ny.zu_432 rn.rw.un_640 
  0x01002a02, 0x311d1bec, 0x525d3bec, 0x304838ec,   // mt.en.un_220 tr.la.az_644  so.ss.ha_644 tk.tt.uz_644 
  0x1a001c1a, 0x1a5630a9, 0x2e4b4955, 0x10005204,   // id.tl.un_760 uz.mg.tl_544  to.mi.fo_442 ha.lt.un_320 
  // [94b0]
  0x4f375f0c, 0x501a1ca4, 0x1e1c30a4, 0x16002404,   // tn.st.bi_543 id.tl.fj_433  uz.id.ms_433 eo.hr.un_320 
  0x205a5fee, 0x333155a4, 0x2f006708, 0x30001d0c,   // tn.sm.sq_422 rw.az.nn_433  ak.su.un_430 la.uz.un_530 
  0x305051ad, 0x182134ad, 0x170811a4, 0x375f7508,   // kl.fj.uz_643 ps.fa.ar_643  ro.uk.sr_433 nso.tn.st_443 
  0x31003302, 0x47311b04, 0x4600670d, 0x173508a7,   // nn.az.un_220 tr.az.sn_332  ak.qu.un_540 uk.tg.sr_532 
  // [94c0]
  0x5f1f5c08, 0x2d002504, 0x355834a4, 0x1f001508,   // sa.cy.tn_443 eu.sk.un_320  xh.om.zu_433 un.cy.un_430 
  0x285364ee, 0x11195811, 0x23005e04, 0x093b2f07,   // lg.ht.sw_422 om.gl.ro_653  ts.ca.un_320 su.so.pl_432 
  0x51004604, 0x2500300c, 0x460b4708, 0x7604530c,   // qu.kl.un_320 uz.eu.un_530  sn.es.qu_443 ht.fi.crs_543 
  0x36116755, 0x48303105, 0x40060107, 0x3c000814,   // ak.ro.gn_442 az.uz.tt_333  en.de.lb_432 uk.ug.un_660 
  // [94d0]
  0x064301a0, 0x3b314055, 0x18000112, 0x332f4004,   // en.ie.de_322 lb.az.so_442  iw.ar.un_640 lb.su.nn_332 
  0x374423a7, 0x2e003608, 0x04073002, 0x65000807,   // ky.kk.ba_532 gn.fo.un_430  uz.bg.ru_222 no.gv.un_420 
  0x03583f0c, 0x03005812, 0x79006b1a, 0x36251512,   // af.om.nl_543 om.nl.un_640  ceb.war.un_760 un.mn.ab_654 
  0x4c005804, 0x322947ee, 0x0c3f0302, 0x5c652704,   // om.wo.un_320 sn.sl.bs_422  nl.af.sv_222 gd.gv.sa_332 
  // [94e0]
  0x0d2e0e04, 0x4c005814, 0x0300020e, 0x4c3f58af,   // is.fo.cs_332 om.wo.un_660  da.nl.un_550 om.af.wo_655 
  0x0c0e08a0, 0x033ffc04, 0x08231555, 0x2e001d04,   // no.is.sv_322 zzp.af.nl_332  un.ky.uk_442 la.fo.un_320 
  0x35001d02, 0xfc033f02, 0x04002c07, 0x08173508,   // la.zu.un_220 af.nl.zzp_222  fy.fi.un_420 tg.sr.uk_443 
  0x3007480d, 0x50002404, 0xfc000405, 0x0a1748a0,   // tt.bg.uz_554 eo.fj.un_320  fi.zzp.un_330 tt.sr.mk_322 
  // [94f0]
  0x2c000207, 0x343d21ad, 0x23384408, 0x0601fca4,   // da.fy.un_420 fa.ku.ps_643  kk.tk.ky_443 zzp.en.de_433 
  0x3300fc08, 0x20004002, 0x30003b0c, 0x091c1311,   // zzp.nn.un_430 lb.sq.un_220  so.uz.un_530 bh.mr.hi_653 
  0x481537af, 0x2c003908, 0x37382309, 0x231536a4,   // ba.tt.un_650 br.fy.un_430  ky.tk.ba_444 ab.ky.un_430 
  0x3f000204, 0x1a64120c, 0x400657ad, 0x071117a4,   // da.af.un_320 hu.lg.tl_543  na.de.lb_643 sr.ro.bg_433 
  // [9500]
  0x10352513, 0x5c006408, 0x1a003405, 0x011602ee,   // mn.tg.be_665 lg.sa.un_430  xh.tl.un_330 da.hr.en_422 
  0x5c1264a0, 0x443048a0, 0x095c1c05, 0x0d5c0905,   // lg.hu.sa_322 tt.uz.kk_322  mr.sa.hi_333 hi.sa.ne_333 
  0x64001502, 0x443715a0, 0x13001904, 0x3800fe07,   // un.lg.un_220 un.ba.kk_322  gl.et.un_320 tlh.tk.un_420 
  0x0e001208, 0x38003114, 0x0a1017ec, 0x18342112,   // hu.is.un_430 az.tk.un_660  sr.be.mk_644 fa.ps.ar_654 
  // [9510]
  0x0e00400c, 0x4c002805, 0x045d56a9, 0x172804ee,   // lb.is.un_530 sw.wo.un_330  mg.ss.fi_544 fi.sw.sr_422 
  0x0423480c, 0x0a1738ec, 0x33121504, 0x046434a0,   // tt.ky.ru_543 tk.sr.mk_644  un.hu.nn_332 xh.lg.fi_322 
  0x095c13ee, 0x1d3058a0, 0x12006b08, 0x283418a4,   // bh.sa.hi_422 om.uz.la_322  ceb.hu.un_430 ar.ps.sd_433 
  0x18122809, 0x043811a4, 0x0d1309ad, 0x042a0708,   // sd.ur.ar_444 ro.tk.ru_433  hi.bh.ne_643 it.mt.fi_443 
  // [9520]
  0x34283d55, 0x032c33a4, 0x2e1d22ee, 0x083036a4,   // ku.sd.ps_442 nn.fy.nl_433  oc.la.fo_422 ab.uz.uk_433 
  0x55034a07, 0x3c444809, 0x64687308, 0x0a0d2c08,   // yo.nl.rw_432 tt.kk.ug_444  ny.ig.lg_443 fy.cs.pt_443 
  0x34003005, 0x2a001b04, 0x1b001207, 0x27001809,   // uz.ps.un_330 tr.mt.un_320  hu.tr.un_420 ga.gd.un_440 
  0x3f2c03ee, 0x5d451308, 0x03003804, 0x02685b12,   // nl.fy.af_422 et.ln.ss_443  tk.nl.un_320 sg.ig.da_654 
  // [9530]
  0x35000821, 0x1900650c, 0x25153007, 0x1a003602,   // uk.tg.un_860 gv.gl.un_530  uz.mn.un_420 gn.tl.un_220 
  0x0e4c3ea0, 0x040e1302, 0x631501a9, 0x2e180ea7,   // rm.wo.is_322 et.is.fi_222  en.sco.un_540 is.ga.fo_532 
  0x12130ea4, 0x2c1360af, 0x151711ec, 0x65017904,   // is.et.hu_433 vo.et.fy_655  ro.sr.un_644 war.en.gv_332 
  0x56001307, 0x0423220b, 0x3744235a, 0x1737440d,   // et.mg.un_420 oc.ca.fi_542  ky.kk.ba_553 kk.ba.sr_554 
  // [9540]
  0x2800640e, 0x290e2d0c, 0x130c600c, 0x5c091307,   // lg.sw.un_550 sk.is.sl_543  vo.sv.et_543 bh.hi.sa_432 
  0x4c00210d, 0x2d292cec, 0x00003f24, 0x2e131808,   // jw.wo.un_540 fy.sl.sk_644  af.un.un_900 ga.et.fo_443 
  0x34003d2a, 0x6a00571a, 0x091c5cee, 0x44233607,   // ku.ps.un_970 na.haw.un_760  sa.mr.hi_422 ab.ky.kk_432 
  0x13003f04, 0x065739a4, 0x396915a7, 0x2d29020e,   // af.et.un_320 br.na.de_433  un.mfe.br_532 da.sl.sk_555 
  // [9550]
  0x0f39610d, 0x3504300c, 0x2e0e3f08, 0x2c002f02,   // za.br.lv_554 uz.ru.tg_543  af.is.fo_443 su.fy.un_220 
  0x0539610d, 0x30153611, 0x401506a0, 0x402539ad,   // za.br.fr_554 ab.uz.un_630  de.lb.un_320 br.eu.lb_643 
  0x4c002114, 0x0e2d0d0d, 0x3b2c04a9, 0x29002d14,   // jw.wo.un_660 cs.sk.is_554  fi.fy.so_544 sk.sl.un_660 
  0x020d0e0c, 0x2300370d, 0x293f2d05, 0x1d032402,   // is.cs.da_543 ba.ky.un_540  sk.af.sl_333 eo.nl.la_222 
  // [9560]
  0x2a000108, 0x3f02080c, 0x2d2e1802, 0x022e1507,   // en.mt.un_430 no.da.af_543  ga.fo.sk_222 un.fo.da_432 
  0x30100808, 0x4211240c, 0x0e292d13, 0x39002b04,   // uk.be.uz_443 eo.ro.co_543  sk.sl.is_665 vi.br.un_320 
  0x355e5daf, 0x1200092b, 0x1e1c62af, 0x06401dee,   // ss.ts.zu_655 pl.hu.un_980  kha.id.ms_655 la.lb.de_422 
  0x12003b04, 0xfe6527a9, 0x23000607, 0x48311b60,   // so.hu.un_320 gd.gv.tlh_544  de.ca.un_420 tr.az.tt_664 
  // [9570]
  0x1e003707, 0x30fe06a9, 0x07001304, 0x0e000213,   // st.ms.un_420 de.tlh.uz_544  et.it.un_320 da.is.un_650 
  0x0e000209, 0x2e060cac, 0x400c0609, 0x06000c14,   // da.is.un_440 sv.de.fo_632  de.sv.lb_444 sv.de.un_660 
  0x4009fe0b, 0x27185ea4, 0x44003809, 0x0e38300d,   // tlh.pl.lb_542 ts.ga.gd_433  tk.kk.un_440 uz.tk.is_554 
  0x65003f05, 0x1169090c, 0x4b286aa0, 0x316b0807,   // af.gv.un_330 pl.mfe.ro_543  haw.sw.mi_322 no.ceb.az_432 
  // [9580]
  0x524a69ee, 0x1a790908, 0x053b51a0, 0x1d1101a0,   // mfe.yo.ha_422 pl.war.tl_443  kl.so.fr_322 en.ro.la_322 
  0x06003904, 0x3b005104, 0xfc1101a4, 0x02000c0b,   // br.de.un_320 kl.so.un_320  en.ro.zzp_433 sv.da.un_520 
  0x131104ec, 0x25006a0b, 0x24674305, 0x21531ca4,   // fi.ro.et_644 haw.eu.un_520  ie.ak.eo_333 id.ht.jw_433 
  0x0c400612, 0x30081702, 0x300a3607, 0x21123da6,   // de.lb.sv_654 sr.uk.uz_222  ab.mk.uz_432 ku.ur.fa_521 
  // [9590]
  0x5a562402, 0x43004013, 0x373c38a0, 0x210f45ad,   // eo.mg.sm_222 lb.ie.un_650  tk.ug.ba_322 ln.lv.jw_643 
  0x0a1735ad, 0x24292da4, 0x08000c07, 0x2d004704,   // tg.sr.mk_643 sk.sl.eo_433  sv.no.un_420 sn.sk.un_320 
  0x3e4b47a0, 0x5f1036a4, 0x016b7955, 0x3815370c,   // sn.mi.rm_322 gn.lt.tn_433  war.ceb.en_442 ba.tk.un_530 
  0x0a004202, 0x0a253502, 0x043536a6, 0x0100fc07,   // co.pt.un_220 tg.mn.mk_222  ab.tg.ru_521 zzp.en.un_420 
  // [95a0]
  0x33080213, 0x44483cee, 0x37001508, 0x37443855,   // da.no.nn_665 ug.tt.kk_422  un.ba.un_430 tk.kk.ba_442 
  0x2e004a05, 0x6a001014, 0x33022e02, 0x04102104,   // yo.fo.un_330 lt.haw.un_660  fo.da.nn_222 jw.lt.fi_332 
  0x3e131007, 0x5a684904, 0x51000205, 0x30354855,   // lt.et.rm_432 to.ig.sm_332  da.kl.un_330 tt.tg.uz_442 
  0x10006807, 0x18003b0d, 0x23483013, 0x3d002313,   // ig.lt.un_420 ks.ar.un_540  uz.tt.ky_665 ky.ku.un_650 
  // [95b0]
  0x08002e07, 0x491004ee, 0x17080a02, 0x36351505,   // fo.no.un_420 fi.lt.to_422  mk.uk.sr_222 un.tg.ab_333 
  0x5a1004ad, 0x24003205, 0x31006408, 0x281834ac,   // fi.lt.sm_643 bs.eo.un_330  lg.az.un_430 ps.ar.sd_632 
  0x32002408, 0x1b6548a7, 0x48305204, 0x10002402,   // eo.bs.un_430 tt.gv.tr_532  ha.uz.tt_332 eo.lt.un_220 
  0x120e4c0c, 0x2a005804, 0x1504070d, 0x022a0704,   // wo.is.hu_543 om.mt.un_320  bg.ru.un_554 it.mt.da_332 
  // [95c0]
  0x040717a7, 0x21001904, 0x073e21af, 0x350b11a0,   // sr.bg.ru_532 gl.jw.un_320  jw.rm.it_655 ro.es.zu_322 
  0x342118ec, 0x060c38a7, 0x364448a4, 0x2f2a07a0,   // ar.fa.ps_644 tk.sv.de_532  tt.kk.ab_433 it.mt.su_322 
  0x17150455, 0x3130100c, 0x2f003404, 0x332a0e05,   // ru.sr.un_420 lt.uz.az_543  xh.su.un_320 is.mt.nn_333 
  0x2a4207a0, 0x762f69af, 0x2d600d12, 0x3f0206a0,   // it.co.mt_322 mfe.su.crs_655  cs.vo.sk_654 de.da.af_322 
  // [95d0]
  0x420701a0, 0x150437ec, 0x24001305, 0x1d650c08,   // en.it.co_322 ba.ru.un_644  et.eo.un_330 sv.gv.la_443 
  0x07420da9, 0x32420707, 0x13001c02, 0x06001b08,   // cs.co.it_544 it.co.bs_432  id.et.un_220 tr.de.un_430 
  0x0f2d0d04, 0x19006404, 0x38000408, 0x42073ea0,   // cs.sk.lv_332 lg.gl.un_320  fi.tk.un_430 rm.it.co_322 
  0x062e0ea7, 0x18002e10, 0x23002522, 0x0e092e0d,   // is.fo.de_532 fo.ga.un_620  mn.ky.un_870 fo.pl.is_554 
  // [95e0]
  0x06002e1e, 0x441537a9, 0x170a38ee, 0x35254411,   // fo.de.un_830 ba.kk.un_540  tk.mk.sr_422 kk.mn.tg_653 
  0x5800040d, 0x1f001912, 0x040501a0, 0x0d004c04,   // fi.om.un_540 gl.cy.un_640  en.fr.fi_322 wo.cs.un_320 
  0x02332aa4, 0x22000604, 0x050609a9, 0x2c043708,   // mt.nn.da_433 de.oc.un_320  pl.de.fr_544 st.fi.fy_443 
  0x0b000507, 0x17153604, 0x0c02fcac, 0x0802fca4,   // fr.es.un_420 ab.sr.un_320  zzp.da.sv_632 zzp.da.no_433 
  // [95f0]
  0x3f1f2407, 0x202a1c07, 0x1202fc0b, 0x522f2455,   // eo.cy.af_432 id.mt.sq_432  zzp.da.hu_542 eo.su.ha_442 
  0x0e122e0c, 0x04001907, 0x634d3b07, 0x3c0a1704,   // fo.hu.is_543 gl.fi.un_420  so.aa.sco_432 sr.mk.ug_332 
  0x3b5f7560, 0xfc000921, 0x0a001119, 0x7835340e,   // nso.tn.so_664 pl.zzp.un_860  ro.mk.un_750 xh.zu.ve_555 
  0x36190b0c, 0xfc055fee, 0xfc02080c, 0x3bfc63ad,   // es.gl.gn_543 tn.fr.zzp_422  no.da.zzp_543 sco.zzp.so_643 
  // [9600]
  0x23483760, 0x5d35340c, 0x53555911, 0x455957a4,   // ba.tt.ky_664 xh.zu.ss_543  rn.rw.ht_653 na.rn.ln_433 
  0x3bfe0dad, 0x26345d14, 0x17163207, 0x1700150c,   // cs.tlh.so_643 ss.xh.ia_666  bs.hr.sr_432 un.sr.un_530 
  0x20000705, 0x3f003b0d, 0x55434d07, 0x375d5fec,   // it.sq.un_330 so.af.un_540  aa.ie.rw_432 tn.ss.st_644 
  0x2d0dfcee, 0x28005c05, 0x1729fcee, 0x566410a7,   // zzp.cs.sk_422 sa.sw.un_330  zzp.sl.sr_422 lt.lg.mg_532 
  // [9610]
  0x73553b09, 0x1708070c, 0x35340aec, 0x3f0e03a4,   // so.rw.ny_444 bg.uk.sr_543  pt.xh.zu_644 nl.is.af_433 
  0x353473a0, 0x625d3505, 0x3c231813, 0x582c4007,   // ny.xh.zu_322 zu.ss.kha_333  ar.ky.ug_665 lb.fy.om_432 
  0x58403b13, 0x1525110c, 0x11003b1e, 0xfc0640a0,   // so.lb.om_665 ro.mn.un_543  so.ro.un_830 lb.de.zzp_322 
  0x01353455, 0x21583507, 0x50005919, 0x3b47550c,   // xh.zu.en_442 zu.om.jw_432  rn.fj.un_750 rw.sn.so_543 
  // [9620]
  0x1a644508, 0x64502560, 0x1d6b15a4, 0x5f00450d,   // ln.lg.tl_443 eu.fj.lg_664  un.ceb.la_433 ln.tn.un_540 
  0x38070a0d, 0x5c731aee, 0x35343ba9, 0x3435fa60,   // mk.bg.tk_554 tl.ny.sa_422  so.xh.zu_544 nr.zu.xh_664 
  0x060c0ea7, 0x38090107, 0x060c0e55, 0x0c060eac,   // is.sv.de_532 en.pl.tk_432  is.sv.de_442 is.de.sv_632 
  0x380956ad, 0x654d5712, 0x15000608, 0x562d0d12,   // mg.pl.tk_643 na.aa.gv_654  de.un.un_430 cs.sk.mg_654 
  // [9630]
  0x5c5638a9, 0x56383612, 0x0c000e08, 0x332e0c04,   // tk.mg.sa_544 gn.tk.mg_654  is.sv.un_430 sv.fo.nn_332 
  0x51003002, 0x1200382b, 0x654d4c13, 0x092d0d14,   // uz.kl.un_220 tk.hu.un_980  wo.aa.gv_665 cs.sk.pl_666 
  0x29001507, 0x15090111, 0x3c0430a9, 0x28181214,   // un.sl.un_420 en.pl.un_653  uz.ru.ug_544 ur.ar.sd_666 
  0x07000a11, 0x0b0a2eec, 0x184601ee, 0x183809ad,   // mk.bg.un_630 fo.pt.es_644  en.qu.ga_422 pl.tk.ga_643 
  // [9640]
  0x0a442307, 0x060c0eec, 0x214c4d09, 0x4b6a28af,   // ky.kk.mk_432 is.sv.de_644  aa.wo.jw_444 sw.haw.mi_655 
  0x060c0e12, 0x082e020c, 0x095638a9, 0x5f6a37ad,   // is.sv.de_654 da.fo.no_543  tk.mg.pl_544 st.haw.tn_643 
  0x17003505, 0x15360d0c, 0x0a005c0d, 0x234407a0,   // tg.sr.un_330 cs.gn.un_543  sa.pt.un_540 bg.kk.ky_322 
  0x6a0f750c, 0x33000819, 0x17160fee, 0x69657613,   // nso.lv.haw_543 no.nn.un_750  lv.hr.sr_422 crs.gv.mfe_665 
  // [9650]
  0x3d1830ec, 0x011853a0, 0x30001b1b, 0x2f001e1a,   // uz.ar.ku_644 ht.ga.en_322  tr.uz.un_770 ms.su.un_760 
  0x55000a08, 0x18002d08, 0x1c1a5604, 0x1000240d,   // pt.rw.un_430 sk.ga.un_430  mg.tl.id_332 eo.lt.un_540 
  0x39001d05, 0x350430a4, 0x5f264305, 0x15000121,   // la.br.un_330 uz.ru.tg_433  ie.ia.tn_333 en.un.un_860 
  0x3d3012a4, 0x0900fe0b, 0x21464b07, 0x21464eaf,   // ur.uz.ku_433 tlh.pl.un_520  mi.qu.jw_432 ay.qu.jw_655 
  // [9660]
  0x05003708, 0x042047a0, 0x0b002802, 0x5a002704,   // st.fr.un_430 sn.sq.fi_322  sw.es.un_220 gd.sm.un_320 
  0x173711ec, 0x37003504, 0x2f002c08, 0x4a002e0e,   // ro.ba.sr_644 tg.ba.un_320  fy.su.un_430 fo.yo.un_550 
  0x495e0da0, 0x3023370c, 0x35005e12, 0x21000f0e,   // cs.ts.to_322 ba.ky.uz_543  ts.zu.un_640 lv.jw.un_550 
  0x640f730e, 0x35304404, 0x50002105, 0x5d352808,   // ny.lv.lg_555 kk.uz.tg_332  jw.fj.un_330 sw.zu.ss_443 
  // [9670]
  0x162d32a0, 0x5a67490c, 0x10170409, 0x6a735fa4,   // bs.sk.hr_322 to.ak.sm_543  ru.sr.be_444 tn.ny.haw_433 
  0x36003013, 0x37005f05, 0x37755f11, 0x39001105,   // uz.ab.un_650 tn.st.un_330  tn.nso.st_653 ro.br.un_330 
  0x25360a07, 0x375f350c, 0x30353c0c, 0x57001005,   // mk.ab.mn_432 zu.tn.st_543  ug.tg.uz_543 lt.na.un_330 
  0x354702a0, 0x463901a4, 0x645f07a4, 0x3750640c,   // da.sn.zu_322 en.br.qu_433  it.tn.lg_433 lg.fj.st_543 
  // [9680]
  0x060f58a0, 0x070511ac, 0x20003019, 0x24fc21a0,   // om.lv.de_322 ro.fr.it_632  uz.sq.un_750 jw.zzp.eo_322 
  0x1000440e, 0x4c244da0, 0x670210ec, 0x484438a9,   // kk.be.un_550 aa.eo.wo_322  lt.da.ak_644 tk.kk.tt_544 
  0x03693f55, 0x53003e08, 0x4c4a64ee, 0x4c00610c,   // af.mfe.nl_442 rm.ht.un_430  lg.yo.wo_422 za.wo.un_530 
  0x58000702, 0x0569070b, 0x0a170814, 0x644a5312,   // it.om.un_220 it.mfe.fr_542  uk.sr.mk_666 ht.yo.lg_654 
  // [9690]
  0x37646aa4, 0x3e01635a, 0x375f7504, 0x2d1224ad,   // haw.lg.st_433 sco.en.rm_553  nso.tn.st_332 eo.hu.sk_643 
  0x01001a07, 0x536569a9, 0x033f5304, 0x07353013,   // tl.en.un_420 mfe.gv.ht_544  ht.af.nl_332 uz.tg.bg_665 
  0x50000104, 0x0b1a3008, 0x182d0d04, 0x2338485a,   // en.fj.un_320 uz.tl.es_443  cs.sk.ga_332 tt.tk.ky_553 
  0x23004821, 0x182d0d60, 0x081538a7, 0x18003d0b,   // tt.ky.un_860 cs.sk.ga_664  tk.uk.un_520 ku.ar.un_520 
  // [96a0]
  0x02011507, 0x69630107, 0x276b1dad, 0x483815ad,   // un.en.da_432 en.sco.mfe_432  la.ceb.gd_643 un.tk.tt_643 
  0x37043507, 0x3d2321a0, 0x3c0a35ad, 0x3146470c,   // tg.ru.ba_432 fa.ky.ku_322  tg.mk.ug_643 sn.qu.az_543 
  0x31005c12, 0x5c006412, 0x73465c04, 0x430d2d11,   // sa.az.un_640 lg.sa.un_640  sa.qu.ny_332 sk.cs.ie_653 
  0x64791a05, 0x17101512, 0x37111507, 0x65353007,   // tl.war.lg_333 un.be.sr_654  un.ro.ba_432 uz.zu.gv_432 
  // [96b0]
  0x23027904, 0x24094fee, 0x6500130c, 0x31524d0c,   // war.da.ca_332 bi.pl.eo_422  et.gv.un_530 aa.ha.az_543 
  0x1221180c, 0x5a1308a0, 0x15003618, 0x10003519,   // ar.fa.ur_543 no.et.sm_322  ab.un.un_740 tg.be.un_750 
  0x65400207, 0x553b5c07, 0x0e04300d, 0x0a23360d,   // da.lb.gv_432 sa.so.rw_432  uz.fi.is_554 ab.ky.mk_554 
  0x106b1dad, 0x5c1b4604, 0x79045c0c, 0x6b007905,   // la.ceb.lt_643 qu.tr.sa_332  sa.fi.war_543 war.ceb.un_330 
  // [96c0]
  0x16003204, 0x5a004308, 0x06002d04, 0x12112411,   // bs.hr.un_320 ie.sm.un_430  sk.de.un_320 eo.ro.hu_653 
  0x381b3007, 0x021d2404, 0x3d00230c, 0x1d0a01a0,   // uz.tr.tk_432 eo.la.da_332  ky.ku.un_530 en.pt.la_322 
  0x21616212, 0x02002405, 0x345e5f07, 0x441823a0,   // kha.za.jw_654 eo.da.un_330  tn.ts.xh_432 ky.ar.kk_322 
  0x1a6b55ad, 0x12581e07, 0x3000341b, 0x1d651f07,   // rw.ceb.tl_643 ms.om.hu_432  ps.uz.un_770 cy.gv.la_432 
  // [96d0]
  0x2c00fe07, 0x2300071b, 0x29383004, 0x18281204,   // tlh.fy.un_420 bg.ky.un_770  uz.tk.sl_332 ur.sd.ar_332 
  0x07041555, 0x303c48af, 0x3b006408, 0x332c0107,   // un.ru.bg_442 tt.ug.uz_655  lg.so.un_430 en.fy.nn_432 
  0x06001004, 0xfc1d0ba0, 0x23002514, 0x103035ee,   // lt.de.un_320 es.la.zzp_322  mn.ky.un_660 tg.uz.be_422 
  0x3f100cee, 0x353418a6, 0x291e2102, 0x03462e07,   // sv.lt.af_422 ga.xh.zu_521  jw.ms.sl_222 fo.qu.nl_432 
  // [96e0]
  0x183421ad, 0x2c0338a9, 0x35005c07, 0x131c09af,   // fa.ps.ar_643 tk.nl.fy_544  sa.zu.un_420 hi.mr.bh_655 
  0x347325ad, 0x48003e0c, 0x0f00030c, 0x1100301a,   // eu.ny.xh_643 rm.tt.un_530  nl.lv.un_530 uz.ro.un_760 
  0x3e127312, 0x09135ca4, 0x25222305, 0x2c00030d,   // ny.hu.rm_654 sa.bh.hi_433  ca.oc.eu_333 nl.fy.un_540 
  0x211828ee, 0x23303555, 0x2e000307, 0x081704af,   // sd.ar.fa_422 tg.uz.ky_442  nl.fo.un_420 ru.sr.uk_655 
  // [96f0]
  0x23002509, 0x18002d07, 0x04071708, 0x150811af,   // mn.ky.un_440 sk.ga.un_420  sr.bg.ru_443 ro.uk.un_655 
  0x0a081709, 0x2a006121, 0x65132aee, 0x0b183102,   // sr.uk.mk_444 za.mt.un_860  mt.et.gv_422 az.ga.es_222 
  0x61002d08, 0x052361ad, 0x15002a12, 0x1517360c,   // sk.za.un_430 za.ca.fr_643  mt.un.un_640 ab.sr.un_543 
  0x15022a55, 0x612a4c0c, 0x152a4309, 0x283d34a6,   // mt.da.un_442 wo.mt.za_543  ie.mt.un_444 ps.ku.sd_521 
  // [9700]
  0x223b4cad, 0x1900060b, 0x04081009, 0x032a0204,   // wo.so.oc_643 de.gl.un_520  be.uk.ru_444 da.mt.nl_332 
  0x2a006114, 0x25232aaf, 0x42610560, 0x443537ee,   // za.mt.un_660 mt.ca.eu_655  fr.za.co_664 ba.tg.kk_422 
  0x2a000314, 0x07303c07, 0x2c002a04, 0x21003011,   // nl.mt.un_660 ug.uz.bg_432  mt.fy.un_320 uz.fa.un_630 
  0x20002408, 0x1c001e0c, 0x17150aee, 0x09005502,   // eo.sq.un_430 ms.id.un_530  mk.sr.un_420 rw.pl.un_220 
  // [9710]
  0x2400fe18, 0x36003719, 0x47355507, 0x35005509,   // tlh.eo.un_740 ba.ab.un_750  rw.zu.sn_432 rw.zu.un_440 
  0x45595513, 0x5900280e, 0x55003505, 0x341228a4,   // rw.rn.ln_665 sw.rn.un_550  zu.rw.un_330 sd.ur.ps_433 
  0x2400200c, 0x22000e02, 0x35230aa0, 0x34553507,   // sq.eo.un_530 is.oc.un_220  mk.ky.tg_322 zu.rw.xh_432 
  0x0723300c, 0x1225270d, 0x5509690b, 0x3830480d,   // uz.ky.bg_543 gd.eu.hu_554  mfe.pl.rw_542 tt.uz.tk_554 
  // [9720]
  0x33553eee, 0x13000102, 0x3507250c, 0x34005c18,   // rm.rw.nn_422 en.et.un_220  mn.bg.tg_543 sa.xh.un_740 
  0x4a631807, 0x130d1cee, 0x4d00050e, 0x25002712,   // ga.sco.yo_432 mr.ne.bh_422  fr.aa.un_550 gd.eu.un_640 
  0x64003407, 0x357334ee, 0x370b62a9, 0x11002319,   // xh.lg.un_420 xh.ny.zu_422  kha.es.st_544 ky.ro.un_750 
  0x365c34a0, 0x75355d08, 0x3e6b1f0c, 0x585f0955,   // xh.sa.gn_322 ss.zu.nso_443  cy.ceb.rm_543 pl.tn.om_442 
  // [9730]
  0x1a3926a0, 0x10002513, 0x09240d07, 0x35251555,   // ia.br.tl_322 mn.be.un_650  cs.eo.pl_432 un.mn.tg_442 
  0x30233804, 0x4800370b, 0x1b001104, 0x0a3035a7,   // tk.ky.uz_332 ba.tt.un_520  ro.tr.un_320 tg.uz.mk_532 
  0x36641fa0, 0x1f006804, 0x375f1a08, 0x67355d07,   // cy.lg.gn_322 ig.cy.un_320  tl.tn.st_443 ss.zu.ak_432 
  0x12005c21, 0x645dfa08, 0x42221f02, 0x22622e07,   // sa.hu.un_860 nr.ss.lg_443  cy.oc.co_222 fo.kha.oc_432 
  // [9740]
  0x4a5b6212, 0x16022955, 0x5d003511, 0x4f003e05,   // kha.sg.yo_654 sl.da.hr_442  zu.ss.un_630 rm.bi.un_330 
  0xfa355d08, 0x15382511, 0x345d355a, 0x5d357808,   // ss.zu.nr_443 mn.tk.un_653  zu.ss.xh_553 ve.zu.ss_443 
  0x73006405, 0x1e003502, 0x5f345da4, 0x34153507,   // lg.ny.un_330 zu.ms.un_220  ss.xh.tn_433 zu.xh.un_420 
  0x1500350d, 0x2b00350c, 0x6535340d, 0x30005e05,   // zu.un.un_540 zu.vi.un_530  xh.zu.gv_554 ts.uz.un_330 
  // [9750]
  0x02000207, 0x17003519, 0x1b2d3002, 0x5c003008,   // da.da.un_420 tg.sr.un_750  uz.sk.tr_222 uz.sa.un_430 
  0x3f002805, 0x036535a0, 0x3200310c, 0x15002535,   // sw.af.un_330 zu.gv.nl_322  az.bs.un_530 mn.un.un_A90 
  0x3f001505, 0x1d003504, 0x35153007, 0x06115c07,   // un.af.un_330 zu.la.un_320  uz.tg.un_420 sa.ro.de_432 
  0x3400460e, 0x2300210d, 0x5d000108, 0x01262007,   // qu.xh.un_550 jw.ca.un_540  en.ss.un_430 sq.ia.en_432 
  // [9760]
  0x345c3507, 0x040738ee, 0x04000907, 0x2c3f09af,   // zu.sa.xh_432 tk.bg.ru_422  pl.fi.un_420 pl.af.fy_655 
  0x476238a7, 0x09002a0d, 0x136301ee, 0x21003421,   // tk.kha.sn_532 mt.pl.un_540  en.sco.et_422 ps.fa.un_860 
  0x1e1c2caf, 0x4b000104, 0x2718010c, 0x100f0107,   // fy.id.ms_655 en.mi.un_320  en.ga.gd_543 en.lv.lt_432 
  0x07426408, 0x11182713, 0x36090412, 0x382e36a4,   // lg.co.it_443 gd.ga.ro_665  fi.pl.gn_654 gn.fo.tk_433 
  // [9770]
  0x156301ad, 0x0a073504, 0x0a426407, 0x3e420713,   // en.sco.un_643 tg.bg.mk_332  lg.co.pt_432 it.co.rm_665 
  0x09003f07, 0x2e040908, 0x6561020b, 0x2a074208,   // af.pl.un_420 pl.fi.fo_443  da.za.gv_542 co.it.mt_443 
  0x532a0704, 0x4b0f5c0c, 0x60005319, 0x2a07180c,   // it.mt.ht_332 sa.lv.mi_543  ht.vo.un_750 ga.it.mt_543 
  0x4437380c, 0x755f01a4, 0x4927130c, 0x49001309,   // tk.ba.kk_543 en.tn.nso_433  et.gd.to_543 et.to.un_440 
  // [9780]
  0x08070a0c, 0x24006e08, 0x56420755, 0x3d301255,   // mk.bg.uk_543 hmn.eo.un_430  it.co.mg_442 ur.uz.ku_442 
  0x07422a12, 0x100408a4, 0x0430350c, 0x5c000f21,   // mt.co.it_654 uk.ru.be_433  tg.uz.ru_543 lv.sa.un_860 
  0x043710a9, 0x2000241a, 0x071d20a0, 0x060440a7,   // be.ba.ru_544 eo.sq.un_760  sq.la.it_322 lb.fi.de_532 
  0x5d286411, 0x2a104205, 0x120c33ee, 0x11150a13,   // lg.sw.ss_653 co.lt.mt_333  nn.sv.hu_422 mk.ro.un_650 
  // [9790]
  0x09135c09, 0x06093fa0, 0x420210ee, 0x64104207,   // sa.bh.hi_444 af.pl.de_322  lt.da.co_422 co.lt.lg_432 
  0x3000381b, 0x58013b07, 0x0d425055, 0x481530ad,   // tk.uz.un_770 so.en.om_432  fj.co.cs_442 uz.tt.un_630 
  0x34003d22, 0x33636504, 0x0400250b, 0x73355dec,   // ku.ps.un_870 gv.sco.nn_332  mn.ru.un_520 ss.zu.ny_644 
  0x5e5d350d, 0x42001013, 0x2e1533a0, 0x08303cee,   // zu.ss.ts_554 lt.co.un_650  nn.fo.un_320 ug.uz.uk_422 
  // [97a0]
  0x5500640d, 0x644958ad, 0x1518010c, 0x25135f0c,   // lg.rw.un_540 om.to.lg_643  en.ga.un_543 tn.et.eu_543 
  0x645e42a9, 0x58644d09, 0x10004208, 0x4d47640d,   // co.ts.lg_544 aa.lg.om_444  co.lt.un_430 lg.sn.aa_554 
  0x2f001a04, 0x475d6007, 0x0726010c, 0x49025a07,   // tl.su.un_320 vo.ss.sn_432  en.ia.it_543 sm.da.to_432 
  0x130365af, 0x1c090d11, 0x480815a0, 0x31003404,   // gv.nl.et_655 ne.hi.mr_653  un.uk.tt_322 xh.az.un_320 
  // [97b0]
  0x3b00030c, 0x3b4d490c, 0x355e34a4, 0x34355e07,   // nl.so.un_530 to.aa.so_543  xh.ts.zu_433 ts.zu.xh_432 
  0x653b63ec, 0x28211807, 0x075e1112, 0x35233c12,   // sco.so.gv_644 ar.fa.sd_432  ro.ts.it_654 ug.ky.tg_654 
  0x06005f04, 0x092a4aee, 0x49375fa4, 0x28734707,   // tn.de.un_320 yo.mt.pl_422  tn.st.to_433 sn.ny.sw_432 
  0x583735ad, 0x4d2858ac, 0x104815a0, 0x210402ee,   // zu.st.om_643 om.sw.aa_632  un.tt.be_322 da.fi.jw_422 
  // [97c0]
  0x4c033fa7, 0x1a4d58a4, 0x584d655a, 0x25003009,   // af.nl.wo_532 om.aa.tl_433  gv.aa.om_553 uz.mn.un_440 
  0x28004914, 0x5852285a, 0x30233808, 0x25001107,   // to.sw.un_660 sw.ha.om_553  tk.ky.uz_443 ro.mn.un_420 
  0x37044809, 0x15153c07, 0x10006522, 0x43106511,   // tt.ru.ba_444 ug.un.un_420  gv.lt.un_870 gv.lt.ie_653 
  0x02001504, 0x0e000210, 0x6a006504, 0x04005005,   // un.da.un_320 da.is.un_620  gv.haw.un_320 fj.fi.un_330 
  // [97d0]
  0x10000704, 0x2112340c, 0x5a002502, 0x65005a0c,   // it.lt.un_320 ps.ur.fa_543  eu.sm.un_220 sm.gv.un_530 
  0x65003e08, 0x48303808, 0x38313e0c, 0x08443508,   // rm.gv.un_430 tk.uz.tt_443  rm.az.tk_543 tg.kk.uk_443 
  0x280b2b0b, 0x5d4773a4, 0x48003823, 0x082536af,   // vi.es.sw_542 ny.sn.ss_433  tk.tt.un_880 ab.mn.uk_655 
  0x483e02a0, 0x476473ec, 0x5d002b04, 0x125c08a4,   // da.rm.tt_322 ny.lg.sn_644  vi.ss.un_320 no.sa.hu_433 
  // [97e0]
  0x5a00101a, 0x3e6539a0, 0x22000a0c, 0x2e156ea9,   // lt.sm.un_760 br.gv.rm_322  pt.oc.un_530 hmn.fo.un_540 
  0x1c150107, 0x2bfe2fa9, 0x15073807, 0x05001704,   // en.id.un_420 su.tlh.vi_544  tk.bg.un_432 sr.fr.un_320 
  0x27000107, 0x05005d04, 0x2700fe05, 0x6e004823,   // en.gd.un_420 ss.fr.un_320  tlh.gd.un_330 tt.hmn.un_880 
  0x0a1f6904, 0x1500361b, 0x6b1f01ee, 0x1f271808,   // mfe.cy.pt_332 ab.un.un_770  en.cy.ceb_422 ga.gd.cy_443 
  // [97f0]
  0x0a3507ee, 0x275b1fad, 0x08043509, 0x39005509,   // bg.tg.mk_422 cy.sg.gd_643  tg.ru.uk_444 rw.br.un_440 
  0x1c2f1fa0, 0x7300fe05, 0x1c2f2105, 0x21343bad,   // cy.su.id_322 tlh.ny.un_330  jw.su.id_333 ks.ps.fa_643 
  0x25190b09, 0x6e766913, 0x370d1807, 0x1f00fc1a,   // es.gl.eu_444 mfe.crs.hmn_665  ga.cs.st_432 zzp.cy.un_760 
  0x12022e08, 0x325c1307, 0x2a150111, 0x0a0715ac,   // fo.da.hu_443 et.sa.bs_432  en.mt.un_630 un.bg.mk_632 
  
  // [9800]
  0x650c1fa0, 0x09fc65a0, 0x6b001309, 0x1100071a,   // cy.sv.gv_322 gv.zzp.pl_322  et.ceb.un_440 bg.ro.un_760 
  0x302348ec, 0x18233ca7, 0x5d2855a9, 0x04130d0c,   // tt.ky.uz_644 ug.ky.ar_532  rw.sw.ss_544 cs.et.fi_543 
  0x0a17070d, 0x04006507, 0xfe5578a4, 0x50fe040c,   // bg.sr.mk_554 gv.fi.un_420  ve.rw.tlh_433 fi.tlh.fj_543 
  0x654830a0, 0x04135c09, 0x55fe42a4, 0x37600a0c,   // uz.tt.gv_322 sa.et.fi_444  co.tlh.rw_433 pt.vo.st_543 
  // [9810]
  0x15303805, 0x556410a4, 0x083033a4, 0x0f0c33a4,   // tk.uz.un_333 lt.lg.rw_433  nn.uz.no_433 nn.sv.lv_433 
  0x434006a4, 0x64000f0e, 0x48373ca7, 0x2e4e5c0c,   // de.lb.ie_433 lv.lg.un_550  ug.ba.tt_532 sa.ay.fo_543 
  0x2859550e, 0x0e006308, 0x13045c13, 0x0400fe0e,   // rw.rn.sw_555 sco.is.un_430  sa.fi.et_665 tlh.fi.un_550 
  0x09211aee, 0x0e5c0d07, 0x735e4507, 0x2f000e02,   // tl.jw.pl_422 cs.sa.is_432  ln.ts.ny_432 is.su.un_220 
  // [9820]
  0x640f5507, 0x4e2101a0, 0x5800460d, 0x330e2e04,   // rw.lv.lg_432 en.jw.ay_322  qu.om.un_540 fo.is.nn_332 
  0x34002f02, 0x0f002a04, 0x65230ba0, 0x10170402,   // su.xh.un_220 mt.lv.un_320  es.ca.gv_322 ru.sr.be_222 
  0x3e132204, 0x0e004014, 0x0a0835a4, 0x22190b05,   // oc.et.rm_332 lb.is.un_660  tg.uk.mk_433 es.gl.oc_333 
  0x382a6304, 0x173507ee, 0x4d000104, 0x1c5c13ee,   // sco.mt.tk_332 bg.tg.sr_422  en.aa.un_320 bh.sa.mr_422 
  // [9830]
  0x27001604, 0x3d213404, 0xfc2c0307, 0x233c1207,   // hr.gd.un_320 ps.fa.ku_332  nl.fy.zzp_432 ur.ug.ky_432 
  0x15004202, 0x2b001805, 0x080a230b, 0x11303c0c,   // co.un.un_220 ga.vi.un_330  ky.mk.uk_542 ug.uz.ro_543 
  0x1d6518a7, 0x0a3507a0, 0x21183c0c, 0x79251d07,   // ga.gv.la_532 bg.tg.mk_322  ug.ar.fa_543 la.eu.war_432 
  0x58463507, 0x1b002f07, 0x1c003807, 0x48005502,   // zu.qu.om_432 su.tr.un_420  tk.id.un_420 rw.tt.un_220 
  // [9840]
  0x465c60a9, 0x0600fc05, 0x0800070c, 0x2400fe12,   // vo.sa.qu_544 zzp.de.un_330  bg.uk.un_530 tlh.eo.un_640 
  0x07080a55, 0x0d003b2a, 0x2c006408, 0x5c003305,   // mk.uk.bg_442 ks.ne.un_970  lg.fy.un_430 nn.sa.un_330 
  0x323124a4, 0x0815040b, 0x25004c05, 0x333f02ee,   // eo.az.bs_433 ru.uk.un_520  wo.eu.un_330 da.af.nn_422 
  0x0a00640c, 0x3f093302, 0x02003f0d, 0x03001d07,   // lg.pt.un_530 nn.pl.af_222  af.da.un_540 la.nl.un_420 
  // [9850]
  0x0e0d2dec, 0x20321702, 0x55283512, 0x06002508,   // sk.cs.is_644 sr.bs.sq_222  zu.sw.rw_654 eu.de.un_430 
  0x35283412, 0x2c00090c, 0x090d1c04, 0x3555590b,   // xh.sw.zu_654 pl.fy.un_530  mr.ne.hi_332 rn.rw.zu_542 
  0x59552814, 0x5c3f240c, 0x28595508, 0x184423a0,   // sw.rw.rn_666 eo.af.sa_543  rw.rn.sw_443 ky.kk.ar_322 
  0x4838230c, 0x2338480c, 0x043f0204, 0x3e3506ee,   // ky.tk.tt_543 tt.tk.ky_543  da.af.fi_332 de.zu.rm_422 
  // [9860]
  0x330809a9, 0x530c1204, 0x28731dee, 0x76006113,   // pl.no.nn_544 hu.sv.ht_332  la.ny.sw_422 za.crs.un_650 
  0x1a792707, 0x73343512, 0xfe005b0d, 0x3f004702,   // gd.war.tl_432 zu.xh.ny_654  sg.tlh.un_540 sn.af.un_220 
  0x35005519, 0x273534a7, 0x03002404, 0x15034502,   // rw.zu.un_750 xh.zu.gd_532  eo.nl.un_320 ln.nl.un_222 
  0x5cfe5d05, 0x36220bee, 0x353427a4, 0x645559ec,   // ss.tlh.sa_333 es.oc.gn_422  gd.xh.zu_433 rn.rw.lg_644 
  // [9870]
  0x35003422, 0x03005604, 0x58595514, 0x07000114,   // xh.zu.un_870 mg.nl.un_320  rw.rn.om_666 en.it.un_660 
  0x345d27a4, 0x5c1827af, 0x1227180c, 0x2f211cee,   // gd.ss.xh_433 gd.ga.sa_655  ga.gd.hu_543 id.jw.su_422 
  0x27003402, 0x67005921, 0x185c27a9, 0x0763260b,   // xh.gd.un_220 rn.ak.un_860  gd.sa.ga_544 ia.sco.it_542 
  0x0c7330a0, 0x5c47340c, 0x190b220c, 0x22190ba0,   // uz.ny.sv_322 xh.sn.sa_543  oc.es.gl_543 es.gl.oc_322 
  // [9880]
  0x135c1c12, 0x4f005619, 0x062f1505, 0x3418270c,   // mr.sa.bh_654 mg.bi.un_750  un.su.de_333 gd.ga.xh_543 
  0x34000d0c, 0x5d1834ee, 0x42005505, 0x3f001e07,   // cs.xh.un_530 xh.ga.ss_422  rw.co.un_330 ms.af.un_420 
  0x5d003522, 0x514915a6, 0x30481107, 0x35001013,   // zu.ss.un_870 un.to.kl_521  ro.tt.uz_432 be.tg.un_650 
  0x6efe2704, 0x1d625207, 0x64341f07, 0x4d3b57ad,   // gd.tlh.hmn_332 ha.kha.la_432  cy.xh.lg_432 na.so.aa_643 
  // [9890]
  0x42001118, 0x3c3748ec, 0x46567311, 0x534e1faf,   // ro.co.un_740 tt.ba.ug_644  ny.mg.qu_653 cy.ay.ht_655 
  0x4c1c2104, 0x254704a0, 0x34005905, 0x6b6a1aa9,   // jw.id.wo_332 fi.sn.eu_322  rn.xh.un_330 tl.haw.ceb_544 
  0x08555907, 0x273f02ad, 0x010362ad, 0x6b006208,   // rn.rw.no_432 da.af.gd_643  kha.nl.en_643 kha.ceb.un_430 
  0x08330c0c, 0x05423908, 0x06003b12, 0x47584e07,   // sv.nn.no_543 br.co.fr_443  so.de.un_640 ay.om.sn_432 
  // [98a0]
  0x0a00360b, 0x1f001804, 0x35001d07, 0x0a150707,   // ab.mk.un_520 ga.cy.un_320  la.zu.un_420 bg.mk.un_420 
  0x440415a0, 0x30001f12, 0x01001d04, 0x1c406707,   // un.ru.kk_322 cy.uz.un_640  la.en.un_320 ak.lb.id_432 
  0x5e003304, 0x652c03ad, 0x1a006a08, 0x56003411,   // nn.ts.un_320 nl.fy.gv_643  haw.tl.un_430 xh.mg.un_630 
  0x5f3734a9, 0x091f4011, 0x47003e0e, 0x4b0428a4,   // xh.st.tn_544 lb.cy.pl_653  rm.sn.un_550 sw.fi.mi_433 
  // [98b0]
  0x34000205, 0x2e0e0204, 0x1d00fe05, 0x3b64340c,   // da.xh.un_330 da.is.fo_332  tlh.la.un_330 xh.lg.so_543 
  0x1a002307, 0x2836fea0, 0x3308290c, 0x56004f22,   // ca.tl.un_420 tlh.gn.sw_322  sl.no.nn_543 bi.mg.un_870 
  0x5f377512, 0x734537a6, 0x1f002e21, 0x61001d13,   // nso.st.tn_654 st.ln.ny_521  fo.cy.un_860 la.za.un_650 
  0x3500fa13, 0x522f2108, 0x17071108, 0x011d6ba0,   // nr.zu.un_650 jw.su.ha_443  ro.bg.sr_443 ceb.la.en_322 
  // [98c0]
  0x6a353b0c, 0x353c3013, 0x474960a9, 0xfc150fa0,   // so.zu.haw_543 uz.ug.tg_665  vo.to.sn_544 lv.zzp.un_320 
  0x0d190b09, 0x23003709, 0x10400611, 0x54376eac,   // es.gl.cs_444 ba.ky.un_440  de.lb.lt_653 hmn.st.ik_632 
  0x255e5da9, 0x0a0d73ee, 0x5e5d60ec, 0x0a4c1907,   // ss.ts.eu_544 ny.cs.pt_422  vo.ss.ts_644 gl.wo.pt_432 
  0x070a170d, 0x75376aa4, 0x55005d22, 0x7900470d,   // sr.mk.bg_554 haw.st.nso_433  ss.rw.un_870 sn.war.un_540 
  // [98d0]
  0x5f371c0c, 0x0a3b1904, 0x0e1f0c0d, 0x24000705,   // id.st.tn_543 gl.so.pt_332  sv.cy.is_554 it.eo.un_330 
  0x190b13af, 0x207669a4, 0x473e050c, 0x3c001723,   // et.es.gl_655 mfe.crs.sq_433  fr.rm.sn_543 sr.ug.un_880 
  0x4f630107, 0x216e5c0d, 0x350a1002, 0x38443655,   // en.sco.bi_432 sa.hmn.jw_554  lt.pt.zu_222 ab.kk.tk_442 
  0xfe000108, 0x0a0b190b, 0x3b343512, 0x28001d02,   // en.tlh.un_430 gl.es.pt_542  zu.xh.so_654 la.sw.un_220 
  // [98e0]
  0x23000804, 0x123418a9, 0x10000607, 0x0a006a11,   // uk.ky.un_320 ar.ps.ur_544  de.lt.un_420 haw.pt.un_630 
  0x15003609, 0x0a000e02, 0x11004805, 0x180b19a0,   // ab.un.un_440 is.pt.un_220  tt.ro.un_330 gl.es.ga_322 
  0x02003b18, 0x10150805, 0x4815230d, 0x3d211855,   // so.da.un_740 uk.be.un_330  ky.tt.un_540 ar.fa.ku_442 
  0x2300370e, 0x505c1ca0, 0x50002f04, 0x0800070b,   // ba.ky.un_550 id.sa.fj_322  su.fj.un_320 bg.uk.un_520 
  // [98f0]
  0x1834280d, 0x370436ee, 0x18000908, 0x73536904,   // sd.ps.ar_554 ab.ru.ba_422  pl.ga.un_430 mfe.ht.ny_332 
  0x69353412, 0x35463404, 0x083748a9, 0x2e100fa7,   // xh.zu.mfe_654 xh.qu.zu_332  tt.ba.uk_544 lv.lt.fo_532 
  0x0a38250c, 0x5d003519, 0x19360b07, 0xfc733b14,   // mn.tk.mk_543 zu.ss.un_750  es.gn.gl_432 so.ny.zzp_666 
  0x151d0208, 0x3b34fca0, 0x36000a18, 0x06001d04,   // da.la.un_443 zzp.xh.so_322  pt.gn.un_740 la.de.un_320 
  // [9900]
  0x21001302, 0x092e0e08, 0x0c335008, 0x0d001d04,   // et.jw.un_220 is.fo.pl_443  fj.nn.sv_443 la.cs.un_320 
  0x553435ad, 0x3b006409, 0x3563fca0, 0x02001d04,   // zu.xh.rw_643 lg.so.un_440  zzp.sco.zu_322 la.da.un_320 
  0x0400090c, 0x3b00351a, 0x582864a4, 0x0ffe5004,   // pl.fi.un_530 zu.so.un_760  lg.sw.om_433 fj.tlh.lv_332 
  0x4b282508, 0x213b3d0d, 0x39002813, 0x4e550107,   // eu.sw.mi_443 ku.ks.fa_554  sw.br.un_650 en.rw.ay_432 
  // [9910]
  0x2e001805, 0x3578340c, 0x091f1804, 0x4e004608,   // ga.fo.un_330 xh.ve.zu_543  ga.cy.pl_332 qu.ay.un_430 
  0x3b644ca4, 0x16004604, 0x553b6407, 0x123b3d07,   // wo.lg.so_433 qu.hr.un_320  lg.so.rw_432 ku.ks.ur_432 
  0x1d190bec, 0x08041005, 0x635b01a0, 0x38000207,   // es.gl.la_644 be.ru.uk_333  en.sg.sco_322 da.tk.un_420 
  0x05231d07, 0x42000735, 0x05004702, 0x4d00582b,   // la.ca.fr_432 it.co.un_A90  sn.fr.un_220 om.aa.un_980 
  // [9920]
  0x33082c04, 0x6200091a, 0x12003c0d, 0x1dfc0112,   // fy.no.nn_332 pl.kha.un_760  ug.ur.un_540 en.zzp.la_654 
  0x211228a0, 0x48440404, 0x641a3ba7, 0xfc1d090c,   // sd.ur.fa_322 ru.kk.tt_332  so.tl.lg_532 pl.la.zzp_543 
  0x350408a0, 0x1300fa09, 0x18003211, 0x3d30340e,   // uk.ru.tg_322 nr.et.un_440  bs.ar.un_630 ps.uz.ku_555 
  0x64025a13, 0x493773ec, 0x59554dec, 0x3500300b,   // sm.da.lg_665 ny.st.to_644  aa.rw.rn_644 uz.tg.un_520 
  // [9930]
  0xfc005721, 0x0a003512, 0x35360a0c, 0x42000712,   // na.zzp.un_860 tg.mk.un_640  mk.ab.tg_543 it.co.un_640 
  0x251008a9, 0x234810ad, 0x0b00190c, 0x3e001520,   // uk.be.mn_544 be.tt.ky_643  gl.es.un_530 un.rm.un_850 
  0x08023f05, 0x4c0e3307, 0x42002809, 0x0e403911,   // af.da.no_333 nn.is.wo_432  sw.co.un_440 br.lb.is_653 
  0x090e2ea9, 0x183c2305, 0x0e1233ec, 0x406506a0,   // fo.is.pl_544 ky.ug.ar_333  nn.hu.is_644 de.gv.lb_322 
  // [9940]
  0x400e33ac, 0x23060ca7, 0x34000608, 0x240c0602,   // nn.is.lb_632 sv.de.ca_532  de.xh.un_430 de.sv.eo_222 
  0x42002405, 0x1d0c2604, 0x02fc1fa0, 0x0600640c,   // eo.co.un_330 ia.sv.la_332  cy.zzp.da_322 lg.de.un_530 
  0x42002c04, 0x6b212fa0, 0x0b222302, 0x0e002402,   // fy.co.un_320 su.jw.ceb_322  ca.oc.es_222 eo.is.un_220 
  0x1d001905, 0x25001507, 0x2d002913, 0x304838af,   // gl.la.un_330 un.mn.un_420  sl.sk.un_650 tk.tt.uz_655 
  // [9950]
  0x33004804, 0x30352305, 0x0cfc1fa7, 0x08000718,   // tt.nn.un_320 ky.tg.uz_333  cy.zzp.sv_532 it.no.un_740 
  0x33031208, 0x17292da9, 0x06fc1507, 0x061f65a0,   // hu.nl.nn_443 sk.sl.sr_544  un.zzp.de_432 gv.cy.de_322 
  0x0e39330c, 0x1533fcee, 0x3d3c23ec, 0x295c2da0,   // nn.br.is_543 zzp.nn.un_422  ky.ug.ku_644 sk.sa.sl_322 
  0x18343d60, 0x20004005, 0x101507ec, 0x371536ec,   // ku.ps.ar_664 lb.sq.un_330  bg.be.un_640 ab.ba.un_640 
  // [9960]
  0x1500111a, 0x07083505, 0x481004ad, 0x0e232e02,   // ro.un.un_760 tg.uk.bg_333  ru.be.tt_643 fo.ca.is_222 
  0x0e1f0c04, 0x190a36ee, 0x33020c0c, 0x230a250c,   // sv.cy.is_332 gn.pt.gl_422  sv.da.nn_543 mn.mk.ky_543 
  0x1b005b07, 0x1a796b04, 0x4b006a07, 0x3767fe12,   // sg.tr.un_420 ceb.war.tl_332  haw.mi.un_420 tlh.ak.st_654 
  0x070a30a7, 0x28471e0c, 0x4700fe12, 0x65001f0c,   // uz.mk.bg_532 ms.sn.sw_543  tlh.sn.un_640 cy.gv.un_530 
  // [9970]
  0x3700fe04, 0x15003604, 0x2300220e, 0x0c1d6507,   // tlh.st.un_320 gn.un.un_320  oc.ca.un_550 gv.la.sv_432 
  0x483c37a9, 0x17003102, 0x30483804, 0x37170a04,   // ba.ug.tt_544 az.sr.un_220  tk.tt.uz_332 mk.sr.ba_332 
  0xfc00650c, 0x2a002504, 0x35481004, 0x294b25a0,   // gv.zzp.un_530 eu.mt.un_320  be.tt.tg_332 eu.mi.sl_322 
  0x3547fe0c, 0x02002e12, 0x0e2e08a4, 0x491729a4,   // tlh.sn.zu_543 fo.da.un_640  no.fo.is_433 sl.sr.to_433 
  // [9980]
  0x1b303108, 0x0e001008, 0x3f6301a4, 0x37474a02,   // az.uz.tr_443 lt.is.un_430  en.sco.af_433 yo.sn.st_222 
  0x1365060c, 0x032a20a9, 0x53691e0c, 0x284b47a0,   // de.gv.et_543 sq.mt.nl_544  ms.mfe.ht_543 sn.mi.sw_322 
  0x5f37750d, 0x0603010b, 0x020c33a4, 0x02060107,   // nso.st.tn_554 en.nl.de_542  nn.sv.da_433 en.de.da_432 
  0x08001712, 0x392412a6, 0x4e000804, 0x2000fe05,   // sr.uk.un_640 hu.eo.br_521  no.ay.un_320 tlh.sq.un_330 
  // [9990]
  0x46150107, 0x032c40a4, 0x30215aa0, 0x15111504,   // en.qu.un_420 lb.fy.nl_433  sm.jw.uz_322 un.ro.un_332 
  0x2a004e2a, 0x331208a9, 0x20002422, 0x350436a4,   // ay.mt.un_970 no.hu.nn_544  eo.sq.un_870 ab.ru.tg_433 
  0x123308a4, 0x25002d07, 0x126b5108, 0x10080713,   // no.nn.hu_433 sk.eu.un_420  kl.ceb.hu_443 bg.uk.be_665 
  0x3f03390c, 0x293217a4, 0x2d004d0d, 0x5f374509,   // br.nl.af_543 sr.bs.sl_433  aa.sk.un_540 ln.st.tn_444 
  // [99a0]
  0x12004d07, 0x08331207, 0x480960a4, 0x071738a0,   // aa.hu.un_420 hu.nn.no_432  vo.pl.tt_433 tk.sr.bg_322 
  0x17303504, 0x453775a4, 0x35005d0c, 0x3b0d09a4,   // tg.uz.sr_332 nso.st.ln_433  ss.zu.un_530 hi.ne.ks_433 
  0x28375f07, 0x23791904, 0x033f39ee, 0x39001307,   // tn.st.sw_432 gl.war.ca_332  br.af.nl_422 et.br.un_420 
  0x0000042d, 0x0e454a07, 0x2d0f0da4, 0x3c3515a0,   // fi.un.un_A00 yo.ln.is_432  cs.lv.sk_433 un.tg.ug_322 
  // [99b0]
  0x111707a9, 0x642d0da0, 0x343735a4, 0x35233804,   // bg.sr.ro_544 cs.sk.lg_322  zu.st.xh_433 tk.ky.tg_332 
  0x47005e0e, 0x24225e0c, 0x0d1c13ad, 0x2b004b02,   // ts.sn.un_550 ts.oc.eo_543  bh.mr.ne_643 mi.vi.un_220 
  0x133061a7, 0x0800fc04, 0x4700211a, 0x3f080f04,   // za.uz.et_532 zzp.no.un_320  jw.sn.un_760 lv.no.af_332 
  0x3ffefaa4, 0x0c33fca0, 0x22467309, 0x042548ee,   // nr.tlh.af_433 zzp.nn.sv_322  ny.qu.oc_444 tt.mn.ru_422 
  // [99c0]
  0x330c0802, 0x0c13fc07, 0x26fc1e07, 0x34006118,   // no.sv.nn_222 zzp.et.sv_432  ms.zzp.ia_432 za.xh.un_740 
  0x331d21ee, 0x79276bec, 0x08044407, 0x355f01a0,   // jw.la.nn_422 ceb.gd.war_644  kk.ru.uk_432 en.tn.zu_322 
  0x651f3ba0, 0x02002404, 0x32004904, 0x260534a9,   // so.cy.gv_322 eo.da.un_320  to.bs.un_320 xh.fr.ia_544 
  0x6b001209, 0x0c03fca0, 0x353036a7, 0x3544370c,   // hu.ceb.un_440 zzp.nl.sv_322  ab.uz.tg_532 ba.kk.tg_543 
  // [99d0]
  0x3f00fc08, 0xfc186502, 0x4d1b5f12, 0x12283414,   // zzp.af.un_430 gv.ga.zzp_222  tn.tr.aa_654 ps.sd.ur_666 
  0x2a00fe1b, 0x36190b14, 0x065e2aa4, 0x0e3733a9,   // tlh.mt.un_770 es.gl.gn_666  mt.ts.de_433 nn.st.is_544 
  0x0d180aaf, 0x2a064e07, 0x2a00fe19, 0x283418ad,   // pt.ga.cs_655 ay.de.mt_432  tlh.mt.un_750 ar.ps.sd_643 
  0x2348fe08, 0x0efc1fad, 0x31383055, 0x75375faf,   // tlh.tt.ca_443 cy.zzp.is_643  uz.tk.az_442 tn.st.nso_655 
  // [99e0]
  0x314e48a4, 0x19004c08, 0xfc6e610c, 0x1c15fc02,   // tt.ay.az_433 wo.gl.un_430  za.hmn.zzp_543 zzp.id.un_220 
  0x39006e04, 0x483830a0, 0x333e12a4, 0x08042308,   // hmn.br.un_320 uz.tk.tt_322  hu.rm.nn_433 ky.ru.uk_443 
  0x4e1b5ca4, 0xfc00270c, 0x1b003b0e, 0x6b3b1a12,   // sa.tr.ay_433 gd.zzp.un_530  so.tr.un_550 tl.so.ceb_654 
  0x3b00280d, 0x0e33fe07, 0x5600fe19, 0x5f00fe1a,   // sw.so.un_540 tlh.nn.is_432  tlh.mg.un_750 tlh.tn.un_760 
  // [99f0]
  0x213d1860, 0x183d300d, 0x0c0efe11, 0x014615ec,   // ar.ku.fa_664 uz.ku.ar_554  tlh.is.sv_653 un.qu.en_644 
  0x30004612, 0x4e4d5ca4, 0x3b4e5ca4, 0x3b4e6408,   // qu.uz.un_640 sa.aa.ay_433  sa.ay.so_433 lg.ay.so_443 
  0x5c004e19, 0x42002313, 0x10152507, 0x23044802,   // ay.sa.un_750 ca.co.un_650  mn.be.un_420 tt.ru.ky_222 
  0x234438a0, 0x10171504, 0x0400071a, 0x03040207,   // tk.kk.ky_322 un.sr.be_332  bg.ru.un_760 da.fi.nl_432 
  // [9a00]
  0x04134613, 0x471861a4, 0x02044ca7, 0x34354707,   // qu.et.fi_665 za.ga.sn_433  wo.fi.da_532 sn.zu.xh_432 
  0x58646308, 0x30003b19, 0x360b19a0, 0x12183da7,   // sco.lg.om_443 so.uz.un_750  gl.es.gn_322 ku.ar.ur_532 
  0x5c274d09, 0x5c0d1c04, 0x511304ec, 0x5d475c07,   // aa.gd.sa_444 mr.ne.sa_332  fi.et.kl_644 sa.sn.ss_432 
  0x3033080c, 0x351536a4, 0x0d004d18, 0x27001821,   // no.nn.uz_543 ab.tg.un_430  aa.cs.un_740 ga.gd.un_860 
  // [9a10]
  0x52000813, 0x5c184d07, 0x12343dad, 0x02004c21,   // no.ha.un_650 aa.ga.sa_432  ku.ps.ur_643 wo.da.un_860 
  0x2700180c, 0x48000219, 0x32000e0c, 0x1912360c,   // ga.gd.un_530 da.tt.un_750  is.bs.un_530 gn.hu.gl_543 
  0x47182708, 0x0403540e, 0xfe5c270c, 0x043036ad,   // gd.ga.sn_443 ik.nl.fi_555  gd.sa.tlh_543 ab.uz.ru_643 
  0x65103f07, 0x38483013, 0xfe004713, 0x442538ee,   // af.lt.gv_432 uz.tt.tk_665  sn.tlh.un_650 tk.mn.kk_422 
  // [9a20]
  0x64044cad, 0x442338a4, 0x30213d13, 0x13005107,   // wo.fi.lg_643 tk.ky.kk_433  ku.fa.uz_665 kl.et.un_420 
  0x32000d05, 0x4838230d, 0x1700151b, 0x5a423ea4,   // cs.bs.un_330 ky.tk.tt_554  un.sr.un_770 rm.co.sm_433 
  0x1c0d1307, 0x17481504, 0x3b511ea0, 0x65101fec,   // bh.ne.mr_432 un.tt.sr_332  ms.kl.so_322 cy.lt.gv_644 
  0x5c0d1caf, 0x35340dee, 0x46004c12, 0x3b1d4ca6,   // mr.ne.sa_655 cs.xh.zu_422  wo.qu.un_640 wo.la.so_521 
  // [9a30]
  0x48071508, 0x07000f16, 0x5e3573a9, 0x2e003b12,   // un.bg.tt_443 lv.it.un_720  ny.zu.ts_544 so.fo.un_640 
  0x465a4908, 0x37484413, 0x51003304, 0x4c361ea0,   // to.sm.qu_443 kk.tt.ba_665  nn.kl.un_320 ms.gn.wo_322 
  0x68365aa9, 0x731324af, 0x045f73a0, 0x302b2e07,   // sm.gn.ig_544 eo.et.ny_655  ny.tn.fi_322 fo.vi.uz_432 
  0x5324340d, 0x47006008, 0x18003b12, 0x20300402,   // xh.eo.ht_554 vo.sn.un_430  ks.ar.un_640 fi.uz.sq_222 
  // [9a40]
  0x13042a0c, 0x080410a4, 0x34003b1a, 0x1b002e02,   // mt.fi.et_543 be.ru.uk_433  ks.ps.un_760 fo.tr.un_220 
  0x48003605, 0x12796ba4, 0x012463a0, 0x37004811,   // gn.tt.un_330 ceb.war.hu_433  sco.eo.en_322 tt.ba.un_630 
  0x55384860, 0x2f784755, 0x0a070802, 0x130f2404,   // tt.tk.rw_664 sn.ve.su_442  uk.bg.mk_222 eo.lv.et_332 
  0x24131ea9, 0x2d0d2914, 0x240d54a7, 0x1200130e,   // ms.et.eo_544 sl.cs.sk_666  ik.cs.eo_532 et.hu.un_550 
  // [9a50]
  0x234c050c, 0x0400170b, 0x354430a4, 0x1c130d55,   // fr.wo.ca_543 sr.ru.un_520  uz.kk.tg_433 ne.bh.mr_442 
  0x51002808, 0x1b3024a4, 0x026436ee, 0x1023380c,   // sw.kl.un_430 eo.uz.tr_433  gn.lg.da_422 tk.ky.be_543 
  0x38003019, 0x1d470255, 0x12213dec, 0x02453405,   // uz.tk.un_750 da.sn.la_442  ku.fa.ur_644 xh.ln.da_333 
  0x0700300d, 0x1d001204, 0x644a02ee, 0x5a122013,   // uz.bg.un_540 hu.la.un_320  da.yo.lg_422 sq.hu.sm_665 
  // [9a60]
  0x295f39a0, 0x15111da4, 0x30000104, 0x190b36a7,   // br.tn.sl_322 la.ro.un_433  en.uz.un_320 gn.es.gl_532 
  0x29003204, 0x35475907, 0x351b0255, 0x4c004d13,   // bs.sl.un_320 rn.sn.zu_432  da.tr.zu_442 aa.wo.un_650 
  0x57000d08, 0x2d000104, 0x182701a9, 0x5d373402,   // cs.na.un_430 en.sk.un_320  en.gd.ga_544 xh.st.ss_222 
  0x57063307, 0x5c353004, 0xfc011da4, 0x2a00020e,   // nn.de.na_432 uz.zu.sa_332  la.en.zzp_433 da.mt.un_550 
  // [9a70]
  0x151f02ad, 0x31003705, 0x26420508, 0x28302104,   // da.cy.un_643 st.az.un_330  fr.co.ia_443 fa.uz.sd_332 
  0x37044812, 0x063f43a7, 0x0e391fa0, 0x1d5c1fee,   // tt.ru.ba_654 ie.af.de_532  cy.br.is_322 cy.sa.la_422 
  0x134b6a0c, 0x34213d05, 0x381544a9, 0x4340390c,   // haw.mi.et_543 ku.fa.ps_333  kk.tk.un_540 br.lb.ie_543 
  0x155c390b, 0x393b1f5a, 0x56100da0, 0x27183307,   // br.sa.un_542 cy.so.br_553  cs.lt.mg_322 nn.ga.gd_432 
  // [9a80]
  0x63113e12, 0x55002d04, 0x0c6406ee, 0x03002c0d,   // rm.ro.sco_654 sk.rw.un_320  de.lg.sv_422 fy.nl.un_540 
  0x4a3e6007, 0x0c060ea0, 0x49000505, 0x12213d04,   // vo.rm.yo_432 is.de.sv_322  fr.to.un_330 ku.fa.ur_332 
  0x48383013, 0x58000413, 0x2c4025a0, 0x07582aa4,   // uz.tk.tt_665 fi.om.un_650  eu.lb.fy_322 mt.om.it_433 
  0x58001b1a, 0x2c3f620c, 0x39001f21, 0x0b466e07,   // tr.om.un_760 kha.af.fy_543  cy.br.un_860 hmn.qu.es_432 
  // [9a90]
  0x38483cec, 0x28003605, 0x79600608, 0x566b2f07,   // ug.tt.tk_644 gn.sw.un_330  de.vo.war_443 su.ceb.mg_432 
  0x0a001512, 0x201c2fee, 0x3c212302, 0x2b004604,   // un.mk.un_640 su.id.sq_422  ky.fa.ug_222 qu.vi.un_320 
  0x3023380b, 0x213d3b04, 0x30000807, 0x1100361b,   // tk.ky.uz_542 ks.ku.fa_332  uk.uz.un_420 ab.ro.un_770 
  0x351536ec, 0x44001108, 0x38004c05, 0x21122811,   // ab.tg.un_640 ro.kk.un_430  wo.tk.un_330 sd.ur.fa_653 
  // [9aa0]
  0x3423210c, 0x2500230b, 0x2f1e1cee, 0x243937a0,   // fa.ky.ps_543 ky.mn.un_520  id.ms.su_422 st.br.eo_322 
  0x133f03a9, 0x08001502, 0x3f1303a0, 0x162d0d0c,   // nl.af.et_544 un.uk.un_220  nl.et.af_322 cs.sk.hr_543 
  0x1d360a04, 0x3f031308, 0x0b193604, 0x13033f02,   // pt.gn.la_332 et.nl.af_443  gn.gl.es_332 af.nl.et_222 
  0x22015ca0, 0x520264ad, 0x553836a0, 0x31023007,   // sa.en.oc_322 lg.da.ha_643  gn.tk.rw_322 uz.da.az_432 
  // [9ab0]
  0x12003807, 0x422a070c, 0x025d4ea4, 0x596455ad,   // tk.hu.un_420 it.mt.co_543  ay.ss.da_433 rw.lg.rn_643 
  0x374825a4, 0x044423ec, 0x0d2322ee, 0x23003805,   // mn.tt.ba_433 ky.kk.ru_644  oc.ca.cs_422 tk.ky.un_330 
  0x12213ea0, 0x17082302, 0x12323eee, 0x6400670e,   // rm.jw.hu_322 ky.uk.sr_222  rm.bs.hu_422 ak.lg.un_550 
  0x1000441a, 0x13006408, 0x44003405, 0x130f0204,   // kk.be.un_760 lg.et.un_430  ps.kk.un_330 da.lv.et_332 
  // [9ac0]
  0x32171613, 0x3f130312, 0x303d2114, 0x3300510c,   // hr.sr.bs_665 nl.et.af_654  fa.ku.uz_666 kl.nn.un_530 
  0x2e001504, 0x5c1e0207, 0x48365ca4, 0x5c00591b,   // un.fo.un_320 da.ms.sa_432  sa.gn.tt_433 rn.sa.un_770 
  0x330108a0, 0x423e2a13, 0x53005c04, 0x0700421b,   // no.en.nn_322 mt.rm.co_665  sa.ht.un_320 co.it.un_770 
  0x5d004808, 0x07423e12, 0x0b0a1909, 0x2100460e,   // tt.ss.un_430 rm.co.it_654  gl.pt.es_444 qu.jw.un_550 
  // [9ad0]
  0x1e00461a, 0x1e5c30a4, 0x373c440c, 0x5c464daf,   // qu.ms.un_760 uz.sa.ms_433  kk.ug.ba_543 aa.qu.sa_655 
  0x50195ca9, 0x64003b0d, 0x3b054cee, 0x2500360c,   // sa.gl.fj_544 so.lg.un_540  wo.fr.so_422 ab.mn.un_530 
  0x30080704, 0x095c1ca4, 0x1704150c, 0x31682105,   // bg.uk.uz_332 mr.sa.hi_433  un.ru.sr_543 jw.ig.az_333 
  0x37482305, 0x65004604, 0x1f0465ad, 0x251035a9,   // ky.tt.ba_333 qu.gv.un_320  gv.fi.cy_643 tg.be.mn_544 
  // [9ae0]
  0x651f3f12, 0x3f046507, 0x5e3565a4, 0x17002905,   // af.cy.gv_654 gv.fi.af_432  gv.zu.ts_433 sl.sr.un_330 
  0x65463b0c, 0x63465ca7, 0x3b004713, 0x3b584d08,   // so.qu.gv_543 sa.qu.sco_532  sn.so.un_650 aa.om.so_443 
  0x35005e14, 0x79345cad, 0x233515ad, 0x3d002305,   // ts.zu.un_660 sa.xh.war_643  un.tg.ky_643 ky.ku.un_330 
  0x2a00610c, 0x24001d05, 0x0f2239a7, 0x033f390c,   // za.mt.un_530 la.eo.un_330  br.oc.lv_532 br.af.nl_543 
  // [9af0]
  0x2c3f6505, 0x124845a0, 0x040717ad, 0x3e561d0c,   // gv.af.fy_333 ln.tt.hu_322  sr.bg.ru_643 la.mg.rm_543 
  0x39002a08, 0x34006705, 0x393f09ec, 0x18281213,   // mt.br.un_430 ak.xh.un_330  pl.af.br_644 ur.sd.ar_665 
  0x5d6435a4, 0x01000204, 0x34002822, 0x4d190b05,   // zu.lg.ss_433 da.en.un_320  sd.ps.un_870 es.gl.aa_333 
  0x443c23ee, 0x3900060c, 0x30483507, 0x06003912,   // ky.ug.kk_422 de.br.un_530  tg.tt.uz_432 br.de.un_640 
  // [9b00]
  0xfa001208, 0x0c033407, 0x1f0639ee, 0x12003e05,   // hu.nr.un_430 xh.nl.sv_432  br.de.cy_422 rm.hu.un_330 
  0x1e481c04, 0x09392a08, 0x35005507, 0x011d260c,   // id.tt.ms_332 mt.br.pl_443  rw.zu.un_420 ia.la.en_543 
  0x48095307, 0x08023e02, 0x0704080b, 0x372335af,   // ht.pl.tt_432 rm.da.no_222  uk.ru.bg_542 tg.ky.ba_655 
  0xfc0c3007, 0x0f1001a9, 0x6300090d, 0x482338a4,   // uz.sv.zzp_432 en.lt.lv_544  pl.sco.un_540 tk.ky.tt_433 
  // [9b10]
  0x0c0f1309, 0x3e0f3f07, 0x630f13ec, 0x020442a4,   // et.lv.sv_444 af.lv.rm_432  et.lv.sco_644 co.fi.da_433 
  0x3b004002, 0x0f000322, 0x48113007, 0x341221ac,   // lb.so.un_220 nl.lv.un_870  uz.ro.tt_432 fa.ur.ps_632 
  0x34001d0c, 0x3f43010c, 0x3b461f11, 0x5a0273a9,   // la.xh.un_530 en.ie.af_543  cy.qu.so_653 ny.da.sm_544 
  0x3f2c010c, 0x2a3920ac, 0x6e000104, 0x3b001d07,   // en.fy.af_543 sq.br.mt_632  en.hmn.un_320 la.so.un_420 
  // [9b20]
  0x60150107, 0x213b3f07, 0x10171604, 0x05302207,   // en.vo.un_420 af.so.jw_432  hr.sr.lt_332 oc.uz.fr_432 
  0xfe4767a4, 0x300a0709, 0x12212809, 0x49735a0c,   // ak.sn.tlh_433 bg.mk.uz_444  sd.fa.ur_444 sm.ny.to_543 
  0x02000c19, 0x136301a0, 0x0f003e14, 0x39474907,   // sv.da.un_750 en.sco.et_322  rm.lv.un_660 to.sn.br_432 
  0x6365010b, 0x3e003012, 0x2100fe07, 0x1a561ea4,   // en.gv.sco_542 uz.rm.un_640  tlh.jw.un_420 ms.mg.tl_433 
  // [9b30]
  0x650115ec, 0x303904ee, 0x302f1ca4, 0x131a1ca4,   // un.en.gv_644 fi.br.uz_422  id.su.uz_433 id.tl.et_433 
  0x03002004, 0x23374409, 0x183d340d, 0x0e1510a0,   // sq.nl.un_320 kk.ba.ky_444  ps.ku.ar_554 lt.is.un_320 
  0xfe001d09, 0x472f21ad, 0x47fe590b, 0x511a13a0,   // la.tlh.un_440 jw.su.sn_643  rn.tlh.sn_542 et.tl.kl_322 
  0x55004b04, 0x25123305, 0x221150a9, 0x73004736,   // mi.rw.un_320 nn.hu.eu_333  fj.ro.oc_544 sn.ny.un_AA0 
  // [9b40]
  0x55645ea4, 0x12001a04, 0x39001f22, 0x04453911,   // ts.lg.rw_433 tl.hu.un_320  cy.br.un_870 br.ln.fi_653 
  0x23154807, 0x4b5a58ad, 0x020c3fa4, 0x33022708,   // tt.ky.un_420 om.sm.mi_643  af.sv.da_433 gd.da.nn_443 
  0x315030af, 0x45162212, 0x172d29a0, 0x5e4c3104,   // uz.fj.az_655 oc.hr.ln_654  sl.sk.sr_322 az.wo.ts_332 
  0x00002224, 0x321c1eee, 0x08043004, 0x1e005b12,   // oc.un.un_900 ms.id.bs_422  uz.ru.uk_332 sg.ms.un_640 
  // [9b50]
  0x751a1e07, 0x251b7904, 0xfa4d300c, 0x2d5228ee,   // ms.tl.nso_432 war.tr.eu_332  uz.aa.nr_543 sw.ha.sk_422 
  0x51005604, 0x46004e1b, 0x22001f1b, 0x34003029,   // mg.kl.un_320 ay.qu.un_770  cy.oc.un_770 uz.ps.un_960 
  0x1a006b14, 0x4d002a0e, 0x5e1350a4, 0x45004c0d,   // ceb.tl.un_660 mt.aa.un_550  fj.et.ts_433 wo.ln.un_540 
  0x4c551207, 0x5a005807, 0x58004008, 0x5f3f2bee,   // hu.rw.wo_432 om.sm.un_420  lb.om.un_430 vi.af.tn_422 
  // [9b60]
  0x0a002b04, 0x06006502, 0x24000120, 0x0a3c3007,   // vi.pt.un_320 gv.de.un_220  iw.yi.un_850 uz.ug.mk_432 
  0x1c3b0d07, 0x2b00620d, 0x083515a0, 0x73475a08,   // ne.ks.mr_432 kha.vi.un_540  un.tg.uk_322 sm.sn.ny_443 
  0x26730112, 0x1a007322, 0x033f4c07, 0x1a454a0d,   // en.ny.ia_654 ny.tl.un_870  wo.af.nl_432 yo.ln.tl_554 
  0x5f353408, 0x644d1c05, 0x023f0355, 0x5d3502ee,   // xh.zu.tn_443 id.aa.lg_333  nl.af.da_442 da.zu.ss_422 
  // [9b70]
  0x07001107, 0xfc2855a0, 0x33360fa4, 0xfc3f0307,   // ro.bg.un_420 rw.sw.zzp_322  lv.gn.nn_433 nl.af.zzp_432 
  0x1c1316a0, 0x653f01a0, 0x1a136a0c, 0x341d3508,   // hr.et.id_322 en.af.gv_322  haw.et.tl_543 zu.la.xh_443 
  0x211828ac, 0x3d003b21, 0x35342205, 0x33002e0d,   // sd.ar.fa_632 ks.ku.un_860  oc.xh.zu_333 fo.nn.un_540 
  0x0a3007a4, 0x65006b04, 0x284613a4, 0x4c005819,   // bg.uz.mk_433 ceb.gv.un_320  et.qu.sw_433 om.wo.un_750 
  // [9b80]
  0x3f000322, 0x1015040c, 0xfe353404, 0x341830ee,   // nl.af.un_870 ru.be.un_530  xh.zu.tlh_332 uz.ar.ps_422 
  0x25361155, 0x1e1c73a4, 0x0c03730c, 0x35214607,   // ro.ab.mn_442 ny.id.ms_433  ny.nl.sv_543 qu.jw.zu_432 
  0x441548a4, 0x311b4dee, 0x343b4708, 0x12343ca0,   // tt.kk.un_430 aa.tr.az_422  sn.so.xh_443 ug.ps.ur_322 
  0x1a764605, 0x36423ea9, 0x17003621, 0x350708a7,   // qu.crs.tl_333 rm.co.gn_544  ab.sr.un_860 uk.bg.tg_532 
  // [9b90]
  0x341a69a0, 0x5d356407, 0x4e002f05, 0x231a79a4,   // mfe.tl.xh_322 lg.zu.ss_432  su.ay.un_330 war.tl.ca_433 
  0x6b791a0c, 0x20612411, 0x2337440c, 0x31580504,   // tl.war.ceb_543 eo.za.sq_653  kk.ba.ky_543 fr.om.az_332 
  0x38483155, 0x5c001b0d, 0x0a1048a0, 0x1100fc04,   // az.tt.tk_442 tr.sa.un_540  tt.be.mk_322 zzp.ro.un_320 
  0x15483ca7, 0x15001521, 0x0a250704, 0x2000240d,   // ug.tt.un_532 un.un.un_860  bg.mn.mk_332 eo.sq.un_540 
  // [9ba0]
  0x64420907, 0x42735a0c, 0x16290f07, 0x51030904,   // pl.co.lg_432 sm.ny.co_543  lv.sl.hr_432 pl.nl.kl_332 
  0x1358515a, 0x2d296455, 0x286442ad, 0x4215510b,   // kl.om.et_553 lg.sl.sk_442  co.lg.sw_643 kl.co.un_520 
  0x4779580b, 0x303517a7, 0x3d1823ee, 0x55002907,   // om.war.sn_542 sr.tg.uz_532  ky.ar.ku_422 sl.rw.un_420 
  0x28022007, 0x425327a7, 0x42000602, 0x32092d04,   // sq.da.sw_432 gd.ht.co_532  de.co.un_220 sk.pl.bs_332 
  // [9bb0]
  0x11005d12, 0x23002521, 0x02005808, 0x355d5e0e,   // ss.ro.un_640 mn.ky.un_860  om.da.un_430 ts.ss.zu_555 
  0x09644208, 0x2d321602, 0x47006409, 0x13786aa9,   // co.lg.pl_443 hr.bs.sk_222  lg.sn.un_440 haw.ve.et_544 
  0x504278a4, 0x640967a7, 0x32161109, 0x353f75ad,   // ve.co.fj_433 ak.pl.lg_532  ro.hr.bs_444 nso.af.zu_643 
  0x55733504, 0x1b11130c, 0x64211ca4, 0x59554da4,   // zu.ny.rw_332 et.ro.tr_543  id.jw.lg_433 aa.rw.rn_433 
  // [9bc0]
  0x550e76a7, 0x11005e04, 0x4b674213, 0x13755fa4,   // crs.is.rw_532 ts.ro.un_320  co.ak.mi_665 tn.nso.et_433 
  0x0259550e, 0x42006409, 0x5d584608, 0x1300510c,   // rw.rn.da_555 lg.co.un_440  qu.om.ss_443 kl.et.un_530 
  0x2e1015a0, 0x17002313, 0x10515808, 0x44003019,   // un.lt.fo_322 ky.sr.un_650  om.kl.lt_443 uz.kk.un_750 
  0x1c001102, 0x48361504, 0x483736a9, 0x4a5e450d,   // ro.id.un_220 un.ab.tt_332  ab.ba.tt_544 ln.ts.yo_554 
  // [9bd0]
  0x5e3411a4, 0x5d354909, 0x15000a0e, 0x5f13110c,   // ro.xh.ts_433 to.zu.ss_444  mk.un.un_550 ro.et.tn_543 
  0x180d1205, 0x5f75370d, 0x2243210c, 0x46000c09,   // hu.cs.ga_333 st.nso.tn_554  jw.ie.oc_543 sv.qu.un_440 
  0x15010607, 0x033ffc11, 0xfc3f57ee, 0x21003804,   // de.en.un_432 zzp.af.nl_653  na.af.zzp_422 tk.jw.un_320 
  0x2c630111, 0x2c000107, 0x40003909, 0xfe0a6e08,   // en.sco.fy_653 en.fy.un_420  br.lb.un_440 hmn.pt.tlh_443 
  // [9be0]
  0x0c3f650c, 0x6e4c300c, 0x1d00fe1a, 0x08000607,   // gv.af.sv_543 uz.wo.hmn_543  tlh.la.un_760 de.no.un_420 
  0x6e675709, 0x1f06fe13, 0x4815115a, 0x56630107,   // na.ak.hmn_444 tlh.de.cy_665  ro.tt.un_530 en.sco.mg_432 
  0x264c6eac, 0x056e1f0c, 0x48021f04, 0x34003b12,   // hmn.wo.ia_632 cy.hmn.fr_543  cy.da.tt_332 ks.ps.un_640 
  0x18233c08, 0x530a52a9, 0x106143a4, 0x341244a9,   // ug.ky.ar_443 ha.pt.ht_544  ie.za.lt_433 kk.ur.ps_544 
  // [9bf0]
  0x05530304, 0x0407150c, 0x0cfc3fa4, 0x0f2916ee,   // nl.ht.fr_332 un.bg.ru_543  af.zzp.sv_433 hr.sl.lv_422 
  0x443035a4, 0x0a2f6ea9, 0x4d1b48a4, 0x303b48a0,   // tg.uz.kk_433 hmn.su.pt_544  tt.tr.aa_433 tt.so.uz_322 
  0x3f0367a4, 0x0400fc19, 0x1b002f02, 0x03563f07,   // ak.nl.af_433 zzp.fi.un_750  su.tr.un_220 af.mg.nl_432 
  0x3b00480b, 0x79003b09, 0x283418a0, 0x6e000e1a,   // tt.so.un_520 so.war.un_440  ar.ps.sd_322 is.hmn.un_760 
  
  // [9c00]
  0x250f100c, 0x1800342a, 0x462023a6, 0x48336a07,   // lt.lv.eu_543 ps.ar.un_970  ca.sq.qu_521 haw.nn.tt_432 
  0x300a35ec, 0x15370405, 0x49105a07, 0x1d3e01a0,   // tg.mk.uz_644 ru.ba.un_333  sm.lt.to_432 en.rm.la_322 
  0x50401ea7, 0x630e65a4, 0x6310060c, 0x0a0415a0,   // ms.lb.fj_532 gv.is.sco_433  de.lt.sco_543 un.ru.mk_322 
  0x3953090c, 0x5904fca0, 0x0e6510a0, 0x3e106e0d,   // pl.ht.br_543 zzp.fi.rn_322  lt.gv.is_322 hmn.lt.rm_554 
  // [9c10]
  0x442523a9, 0x38001b05, 0x15381507, 0x3100480e,   // ky.mn.kk_544 tr.tk.un_330  un.tk.un_432 tt.az.un_550 
  0x0d5c1c5a, 0x0823250c, 0x070804ec, 0x3d182807,   // mr.sa.ne_553 mn.ky.uk_543  ru.uk.bg_644 sd.ar.ku_432 
  0x2311150c, 0x23005307, 0x3f390107, 0x4033085a,   // un.ro.ky_543 ht.ca.un_420  en.br.af_432 no.nn.lb_553 
  0x033f0107, 0x21341202, 0x51102308, 0x34005005,   // en.af.nl_432 ur.ps.fa_222  ca.lt.kl_443 fj.xh.un_330 
  // [9c20]
  0x043715a0, 0x13001c18, 0x35002319, 0x62150107,   // un.ba.ru_322 mr.bh.un_740  ky.tg.un_750 en.kha.un_420 
  0x3600490c, 0x01005d04, 0x461a2ea0, 0x2a180a02,   // to.gn.un_530 ss.en.un_320  fo.tl.qu_322 pt.ga.mt_222 
  0x1e00630c, 0x5351010c, 0x080c33a4, 0x17381507,   // sco.ms.un_530 en.kl.ht_543  nn.sv.no_433 un.tk.sr_432 
  0x041f65ad, 0x2f211c08, 0x25302355, 0x25001a04,   // gv.cy.fi_643 id.jw.su_443  ky.uz.mn_442 tl.eu.un_320 
  // [9c30]
  0x46003405, 0x1865560c, 0x015165ee, 0x3035480c,   // xh.qu.un_330 mg.gv.ga_543  gv.kl.en_422 tt.tg.uz_543 
  0x56006522, 0x36372307, 0x1000380c, 0x171136a7,   // gv.mg.un_870 ky.ba.ab_432  tk.be.un_530 ab.ro.sr_532 
  0x67001e1a, 0x271842a4, 0x38483713, 0x27232209,   // ms.ak.un_760 co.ga.gd_433  ba.tt.tk_665 oc.ca.gd_444 
  0x0a0738a4, 0x3e07650c, 0x1e28110c, 0x2c3f1207,   // tk.bg.mk_433 gv.it.rm_543  ro.sw.ms_543 hu.af.fy_432 
  // [9c40]
  0x2757180c, 0x21511f0c, 0x3e5651a9, 0x301b31ee,   // ga.na.gd_543 cy.kl.jw_543  kl.mg.rm_544 az.tr.uz_422 
  0x183e020c, 0x03000d04, 0x080602ee, 0x51003e12,   // da.rm.ga_543 cs.nl.un_320  da.de.no_422 rm.kl.un_640 
  0x0c080260, 0x2300151a, 0x2b001d08, 0x3b2112a9,   // da.no.sv_664 un.ky.un_760  la.vi.un_430 ur.fa.ks_544 
  0x30122160, 0x073530ee, 0x0c002c09, 0x080243ee,   // fa.ur.uz_664 uz.tg.bg_422  fy.sv.un_440 ie.da.no_422 
  // [9c50]
  0x40020604, 0x23001b12, 0x1544230b, 0x1538230c,   // de.da.lb_332 tr.ca.un_640  ky.kk.un_542 ky.tk.un_543 
  0x311b32a0, 0x0302215a, 0x00000c24, 0x352f3004,   // bs.tr.az_322 jw.da.nl_553  sv.un.un_900 uz.su.zu_332 
  0x100f200d, 0x11624c5a, 0x3f6558ec, 0x49003f02,   // sq.lv.lt_554 wo.kha.ro_553  om.gv.af_644 af.to.un_220 
  0x3b4d58a9, 0x25003e29, 0x3e040f02, 0x0400610d,   // om.aa.so_544 rm.eu.un_960  lv.fi.rm_222 za.fi.un_540 
  // [9c60]
  0x3f04650b, 0x2400062c, 0x154d0412, 0x58004c1b,   // gv.fi.af_542 de.eo.un_990  fi.aa.un_654 wo.om.un_770 
  0x64421f05, 0x031d075a, 0x1f3b3355, 0x15000305,   // cy.co.lg_333 it.la.nl_553  nn.so.cy_442 nl.un.un_330 
  0x182765ec, 0x15595555, 0x03403f04, 0x2638620c,   // gv.gd.ga_644 rw.rn.un_442  af.lb.nl_332 kha.tk.ia_543 
  0x106b79a0, 0x34352812, 0x69003e19, 0x3e53050d,   // war.ceb.lt_322 sw.zu.xh_654  rm.mfe.un_750 fr.ht.rm_554 
  // [9c70]
  0x354423a4, 0x644d4c11, 0x4b006012, 0x4f7327a0,   // ky.kk.tg_433 wo.aa.lg_653  vo.mi.un_640 gd.ny.bi_322 
  0x35285509, 0x3b6e4daf, 0x6948060d, 0x34283512,   // rw.sw.zu_444 aa.hmn.so_655  de.tt.mfe_554 zu.sw.xh_654 
  0x34355d5a, 0x53126107, 0x355955a4, 0x43240512,   // ss.zu.xh_553 za.hu.ht_432  rw.rn.zu_433 fr.eo.ie_654 
  0x4c003b19, 0x242b3004, 0x4d580107, 0x2e311ba0,   // so.wo.un_750 uz.vi.eo_332  en.om.aa_432 tr.az.fo_322 
  // [9c80]
  0x3600fc08, 0x04005102, 0x031e24a7, 0x51580107,   // zzp.gn.un_430 kl.fi.un_220  eo.ms.nl_532 en.om.kl_432 
  0x35095508, 0x63001d13, 0x30073504, 0xfe166905,   // rw.pl.zu_443 la.sco.un_650  tg.bg.uz_332 mfe.hr.tlh_333 
  0x344735af, 0x342835ee, 0x19460102, 0x36001105,   // zu.sn.xh_655 zu.sw.xh_422  en.qu.gl_222 ro.ab.un_330 
  0x04150714, 0x3c48300d, 0x46005c18, 0x3b002802,   // bg.ru.un_660 uz.tt.ug_554  sa.qu.un_740 sw.so.un_220 
  // [9c90]
  0x5300692a, 0x1f002707, 0x18fc3e0c, 0x2201fcaf,   // mfe.ht.un_970 gd.cy.un_420  rm.zzp.ga_543 zzp.en.oc_655 
  0xfc002d0d, 0x23370707, 0x3d003014, 0x3c00440b,   // sk.zzp.un_540 bg.ba.ky_432  uz.ku.un_660 kk.ug.un_520 
  0x1a4665a0, 0x5c001508, 0x5c1e79a4, 0x2d0d2fa0,   // gv.qu.tl_322 un.sa.un_430  war.ms.sa_433 su.cs.sk_322 
  0x464e5ca4, 0x170804a0, 0x10303605, 0x481538ad,   // sa.ay.qu_433 ru.uk.sr_322  ab.uz.be_333 tk.tt.un_630 
  // [9ca0]
  0x381b13a0, 0x15111508, 0x30002802, 0x1b00480b,   // et.tr.tk_322 un.ro.un_443  sw.uz.un_220 tt.tr.un_520 
  0x44372309, 0x08002b02, 0x1a001c04, 0x37000e04,   // ky.ba.kk_444 vi.no.un_220  id.tl.un_320 is.st.un_320 
  0x23190b08, 0x2e403807, 0x04003c07, 0x6b621d55,   // es.gl.ca_443 tk.lb.fo_432  ug.ru.un_420 la.kha.ceb_442 
  0x07153c07, 0x3d342108, 0x081215a0, 0x301821a7,   // ug.bg.un_420 fa.ps.ku_443  un.hu.no_322 fa.ar.uz_532 
  // [9cb0]
  0x3e05790c, 0x402d020c, 0x15003602, 0xfc2324af,   // war.fr.rm_543 da.sk.lb_543  gn.un.un_220 eo.ca.zzp_655 
  0x2a00612b, 0x15374405, 0x3b5451ad, 0xfc007907,   // za.mt.un_980 kk.ba.un_333  kl.ik.so_643 war.zzp.un_420 
  0x08004802, 0x28fc1f07, 0x12001809, 0x15001007,   // tt.uk.un_220 cy.zzp.sw_432  ga.hu.un_440 lt.un.un_420 
  0x5d005307, 0x1738110c, 0x2b00020c, 0x2f00fc02,   // ht.ss.un_420 ro.tk.sr_543  da.vi.un_530 zzp.su.un_220 
  // [9cc0]
  0x190b0a13, 0x02313007, 0x30001709, 0x21183da0,   // pt.es.gl_665 uz.az.da_432  sr.uz.un_440 ku.ar.fa_322 
  0x5740060d, 0x1f001704, 0x09002e04, 0x04091fa7,   // de.lb.na_554 sr.cy.un_320  fo.pl.un_320 cy.pl.fi_532 
  0x21002821, 0x18003b0b, 0x09791fa4, 0x0a190b5a,   // sd.fa.un_860 ks.ar.un_520  cy.war.pl_433 es.gl.pt_553 
  0x33084dac, 0x1d000304, 0x12002819, 0x3d232804,   // aa.no.nn_632 nl.la.un_320  sd.ur.un_750 sd.ky.ku_332 
  // [9cd0]
  0x3f255802, 0x671d15a0, 0x45280107, 0x35040707,   // om.eu.af_222 un.la.ak_322  en.sw.ln_432 bg.ru.tg_432 
  0x04303502, 0x5f371508, 0x18006309, 0x59554ba9,   // tg.uz.ru_222 un.st.tn_443  sco.ga.un_440 mi.rw.rn_544 
  0x3b5e62a4, 0x5c012a02, 0xfc6a0505, 0x28271808,   // kha.ts.so_433 mt.en.sa_222  fr.haw.zzp_333 ga.gd.sw_443 
  0x5602250c, 0x375f6aac, 0x5e00471a, 0x3d182104,   // eu.da.mg_543 haw.tn.st_632  sn.ts.un_760 fa.ar.ku_332 
  // [9ce0]
  0x25000504, 0x5c271ea0, 0x34003022, 0x08000a09,   // fr.eu.un_320 ms.gd.sa_322  uz.ps.un_870 mk.uk.un_440 
  0x36004b21, 0x211c28a7, 0x28fe68a9, 0x30153813,   // mi.gn.un_860 sw.id.jw_532  ig.tlh.sw_544 tk.uz.un_650 
  0x56201dee, 0x37002004, 0x68004b04, 0x48005e07,   // la.sq.mg_422 sq.st.un_320  mi.ig.un_320 ts.tt.un_420 
  0x3b3001a9, 0x130d09ac, 0x1d750107, 0x1800fc02,   // en.uz.so_544 hi.ne.bh_632  en.nso.la_432 zzp.ga.un_220 
  // [9cf0]
  0x3418215a, 0x5f371809, 0x552528af, 0x383748a9,   // fa.ar.ps_553 ga.st.tn_444  sw.eu.rw_655 tt.ba.tk_544 
  0x37482507, 0x583b4c12, 0x35006502, 0x313b46ec,   // mn.tt.ba_432 wo.so.om_654  gv.zu.un_220 qu.so.az_644 
  0x40063e07, 0x0a1007ee, 0x12213b11, 0x4d004c19,   // rm.de.lb_432 bg.be.mk_422  ks.fa.ur_653 wo.aa.un_750 
  0x3715110c, 0x2c000604, 0x08070413, 0x080a07a4,   // ro.ba.un_530 de.fy.un_320  ru.bg.uk_665 bg.mk.uk_433 
  // [9d00]
  0x071023a6, 0x3421440c, 0x07231155, 0x341230ec,   // ky.be.bg_521 kk.fa.ps_543  ro.ky.bg_442 uz.ur.ps_644 
  0x371504a9, 0x1d5804ad, 0x1b000602, 0x01000404,   // ru.ba.un_540 fi.om.la_643  de.tr.un_220 fi.en.un_320 
  0x3f0302a0, 0x6503fca9, 0x133f4da4, 0x133b58a0,   // da.nl.af_322 zzp.nl.gv_544  aa.af.et_433 om.so.et_322 
  0x58033f07, 0x1d005114, 0x08150460, 0x07000422,   // af.nl.om_432 kl.la.un_660  ru.uk.un_640 ru.bg.un_870 
  // [9d10]
  0x633b1aad, 0x23381504, 0x3b006502, 0x3965300b,   // tl.so.sco_643 un.tk.ky_332  gv.so.un_220 uz.gv.br_542 
  0x3b033fa4, 0x0f00040d, 0x133b04a0, 0x635865ad,   // af.nl.so_433 fi.lv.un_540  fi.so.et_322 gv.om.sco_643 
  0x3ffc0205, 0x183d3c05, 0x40761304, 0x193b0b55,   // da.zzp.af_333 ug.ku.ar_333  et.crs.lb_332 es.so.gl_442 
  0x47002102, 0x3e640908, 0x2d0d4b02, 0x19005302,   // jw.sn.un_220 pl.lg.rm_443  mi.cs.sk_222 ht.gl.un_220 
  // [9d20]
  0x59556414, 0x0b791daf, 0x062924a0, 0x25001e08,   // lg.rw.rn_666 la.war.es_655  eo.sl.de_322 ms.eu.un_430 
  0x3031480c, 0x31381ba7, 0x19003b19, 0x171037a0,   // tt.az.uz_543 tr.tk.az_532  so.gl.un_750 ba.be.sr_322 
  0x3200170c, 0x5c2a47ad, 0x302538a6, 0x00002606,   // sr.bs.un_530 sn.mt.sa_643  tk.mn.uz_521 ia.un.un_400 
  0x44001013, 0x3038445a, 0x6e5d5cec, 0x4800361a,   // be.kk.un_650 kk.tk.uz_553  sa.ss.hmn_644 ab.tt.un_760 
  // [9d30]
  0x292d1ea0, 0x09561e04, 0x1e1337ee, 0x24003b07,   // ms.sk.sl_322 ms.mg.pl_332  st.et.ms_422 so.eo.un_420 
  0x0000652d, 0x1c0d5c55, 0x1c2f1b04, 0x1f00650e,   // gv.un.un_A00 sa.ne.mr_442  tr.su.id_332 gv.cy.un_550 
  0x2b3b40a0, 0x040815af, 0x462205a0, 0x073504a9,   // lb.so.vi_322 un.uk.ru_655  fr.oc.qu_322 ru.tg.bg_544 
  0x036a0107, 0x2a0345a9, 0x0804155a, 0x13002a0d,   // en.haw.nl_432 ln.nl.mt_544  un.ru.uk_553 mt.et.un_540 
  // [9d40]
  0x025f4508, 0x380604a0, 0x49037608, 0x1e1c330e,   // ln.tn.da_443 fi.de.tk_322  crs.nl.to_443 nn.id.ms_555 
  0x1300fc13, 0x0f49040c, 0x0a001513, 0x1a005a02,   // zzp.et.un_650 fi.to.lv_543  un.mk.un_650 sm.tl.un_220 
  0x755f45a9, 0x25003b04, 0x7907260c, 0x1000072b,   // ln.tn.nso_544 so.eu.un_320  ia.it.war_543 bg.be.un_980 
  0x1e6a2b0c, 0x29007314, 0x45007312, 0x3c0a3009,   // vi.haw.ms_543 ny.sl.un_660  ny.ln.un_640 uz.mk.ug_444 
  // [9d50]
  0x0800480e, 0x28497305, 0x3f2579a4, 0x1f5f73a4,   // tt.uk.un_550 ny.to.sw_333  war.eu.af_433 ny.tn.cy_433 
  0x22004912, 0x474073ac, 0x5e3f6005, 0x095c13ec,   // to.oc.un_640 ny.lb.sn_632  vo.af.ts_333 bh.sa.hi_644 
  0x1b3148af, 0x06285407, 0x08343707, 0x03343fa0,   // tt.az.tr_655 ik.sw.de_432  st.xh.no_432 af.xh.nl_322 
  0x36001521, 0x1b3148ad, 0x13475a04, 0x35484407,   // un.ab.un_860 tt.az.tr_643  sm.sn.et_332 kk.tt.tg_432 
  // [9d60]
  0x3523380e, 0x1007150c, 0x44002811, 0x37443cee,   // tk.ky.tg_555 un.bg.be_543  sd.kk.un_630 ug.kk.ba_422 
  0x09001508, 0x252338a7, 0x485d2c07, 0x1015070c,   // un.pl.un_430 tk.ky.mn_532  fy.ss.tt_432 bg.be.un_530 
  0x65000412, 0x28003418, 0x311b3813, 0x4a04050c,   // fi.gv.un_640 ps.sd.un_740  tk.tr.az_665 fr.fi.yo_543 
  0x17001813, 0x1c000921, 0x0e000507, 0x23442808,   // ar.sr.un_650 hi.mr.un_860  fr.is.un_420 sd.kk.ky_443 
  // [9d70]
  0x35153005, 0x31303ba7, 0x0500610c, 0x30234804,   // uz.tg.un_330 so.uz.az_532  za.fr.un_530 tt.ky.uz_332 
  0x2f000508, 0x22361904, 0x30636707, 0x40120607,   // fr.su.un_430 gl.gn.oc_332  ak.sco.uz_432 de.hu.lb_432 
  0x2a003008, 0x0c1304a9, 0x2e002a07, 0x322856a0,   // uz.mt.un_430 fi.et.sv_544  mt.fo.un_420 mg.sw.bs_322 
  0x5768360c, 0x041515ec, 0x0a37230c, 0x3d442304,   // gn.ig.na_543 un.ru.un_640  ky.ba.mk_543 ky.kk.ku_332 
  // [9d80]
  0x25005722, 0x303525ac, 0x38481b13, 0x30150411,   // na.eu.un_870 mn.tg.uz_632  tr.tt.tk_665 ru.uz.un_630 
  0x533836a6, 0x19212f55, 0x48004411, 0x380e65a7,   // gn.tk.ht_521 su.jw.gl_442  kk.tt.un_630 gv.is.tk_532 
  0x3f4d3bad, 0x7834fa09, 0x584d51af, 0x28214e0c,   // so.aa.af_643 nr.xh.ve_444  kl.aa.om_655 ay.jw.sw_543 
  0x13584d04, 0x755f3712, 0x3f3b0304, 0x03005804,   // aa.om.et_332 st.tn.nso_654  nl.so.af_332 om.nl.un_320 
  // [9d90]
  0x11170a12, 0x3f3b6b08, 0x040a350c, 0x15080455,   // mk.sr.ro_654 ceb.so.af_443  tg.mk.ru_543 ru.uk.un_442 
  0x555d7307, 0x735d34a4, 0x043865a6, 0x214c2f04,   // ny.ss.rw_432 xh.ss.ny_433  gv.tk.fi_521 su.wo.jw_332 
  0x35fa340c, 0x13475112, 0x0900181a, 0x3b3f0308,   // xh.nr.zu_543 kl.sn.et_654  ar.hi.un_760 nl.af.so_443 
  0x481504af, 0x11001521, 0x23000409, 0x36001509,   // ru.tt.un_650 un.ro.un_860  ru.ky.un_440 un.ab.un_440 
  // [9da0]
  0x061b2407, 0x2f1e4507, 0x22005309, 0x305e2004,   // eo.tr.de_432 ln.ms.su_432  ht.oc.un_440 sq.ts.uz_332 
  0x1e1c460c, 0xfc006504, 0x651c02ac, 0x1b5309ec,   // qu.id.ms_543 gv.zzp.un_320  da.id.gv_632 pl.ht.tr_644 
  0x531809a0, 0x1a001707, 0x213d3412, 0x53002221,   // pl.ga.ht_322 sr.tl.un_420  ps.ku.fa_654 oc.ht.un_860 
  0xfe1b790c, 0x695361af, 0x1b53760c, 0x09001807,   // war.tr.tlh_543 za.ht.mfe_655  crs.ht.tr_543 ga.pl.un_420 
  // [9db0]
  0x0d0e4a04, 0x15040860, 0x0400300b, 0x3c363007,   // yo.is.cs_332 uk.ru.un_664  uz.ru.un_520 uz.ab.ug_432 
  0x0f4b5cad, 0x5c004b14, 0x32000407, 0x495c4ba4,   // sa.mi.lv_643 mi.sa.un_660  fi.bs.un_420 mi.sa.to_433 
  0x4400381b, 0x17080a11, 0x483711ee, 0x28585008,   // tk.kk.un_770 mk.uk.sr_653  ro.ba.tt_422 fj.om.sw_443 
  0x736445af, 0x644c4b08, 0x47287809, 0x58420f05,   // ln.lg.ny_655 mi.wo.lg_443  ve.sw.sn_444 lv.co.om_333 
  // [9dc0]
  0x64552808, 0x505d580c, 0x15040813, 0x48002311,   // sw.rw.lg_443 om.ss.fj_543  uk.ru.un_665 ky.tt.un_630 
  0x420f500c, 0x4c1301a4, 0x173035ad, 0x1834210c,   // fj.lv.co_543 en.et.wo_433  tg.uz.sr_643 fa.ps.ar_543 
  0x375ffa12, 0x645547a4, 0x354438a9, 0x355e6407,   // nr.tn.st_654 sn.rw.lg_433  tk.kk.tg_544 lg.ts.zu_432 
  0x5f736aa9, 0x50644211, 0x4c00130d, 0x670264a4,   // haw.ny.tn_544 co.lg.fj_653  et.wo.un_540 lg.da.ak_433 
  // [9dd0]
  0x1107130c, 0x443038a9, 0x02581ea4, 0x5f4c3908,   // et.it.ro_543 tk.uz.kk_544  ms.om.da_433 br.wo.tn_443 
  0x2c072e55, 0x1e1c7305, 0x48373c5a, 0x240657ec,   // fo.it.fy_442 ny.id.ms_333  ug.ba.tt_553 na.de.eo_644 
  0x75005f14, 0x7350455a, 0x6b004712, 0x330875a9,   // tn.nso.un_660 ln.fj.ny_553  sn.ceb.un_640 nso.no.nn_544 
  0x12332907, 0x3f001a0d, 0x08071005, 0x612f21a4,   // sl.nn.hu_432 tl.af.un_540  be.bg.uk_333 jw.su.za_433 
  // [9de0]
  0x397325a4, 0x56006407, 0x495a50a9, 0x68736a0c,   // eu.ny.br_433 lg.mg.un_420  fj.sm.to_544 haw.ny.ig_543 
  0x0810250c, 0x38005f0c, 0x233835a9, 0x151d01a0,   // mn.be.uk_543 tn.tk.un_530  tg.tk.ky_544 en.la.un_322 
  0x426a49a4, 0x5f1e37a4, 0x35344c14, 0x38005f12,   // to.haw.co_433 st.ms.tn_433  wo.xh.zu_666 tn.tk.un_640 
  0x2cfc0904, 0x2f40390c, 0x074240a6, 0x23363807,   // pl.zzp.fy_332 br.lb.su_543  lb.co.it_521 tk.ab.ky_432 
  // [9df0]
  0x0d001502, 0x25001d13, 0x2e2c3e07, 0x06002c02,   // un.cs.un_220 la.eu.un_650  rm.fy.fo_432 fy.de.un_220 
  0x35002521, 0x1a003907, 0x40001f0c, 0x12272ea0,   // mn.tg.un_860 br.tl.un_420  cy.lb.un_530 fo.gd.hu_322 
  0x47002409, 0x3f002702, 0x4c2f3b11, 0x23153caf,   // eo.sn.un_440 gd.af.un_220  so.su.wo_653 ug.ky.un_650 
  0x303d21ad, 0x09001104, 0x033f79a0, 0x53766914,   // fa.ku.uz_643 ro.pl.un_320  war.af.nl_322 mfe.crs.ht_666 
  // [9e00]
  0x5c6a4bad, 0x7918090c, 0x40790607, 0x04481555,   // mi.haw.sa_643 pl.ga.war_543  de.war.lb_432 un.tt.ru_442 
  0x3c004823, 0x15003022, 0x17081004, 0x24255312,   // tt.ug.un_880 uz.un.un_870  be.uk.sr_332 ht.eu.eo_654 
  0x08004412, 0x495a6a0d, 0x110640a7, 0x39004014,   // kk.uk.un_640 haw.sm.to_554  lb.de.ro_532 lb.br.un_660 
  0x47003713, 0x67003713, 0x3b006509, 0x65005a21,   // st.sn.un_650 st.ak.un_650  gv.so.un_440 sm.gv.un_860 
  // [9e10]
  0x0c033f07, 0x09002d02, 0x47004d0c, 0x0f006513,   // af.nl.sv_432 sk.pl.un_220  aa.sn.un_530 gv.lv.un_650 
  0x47006712, 0x6200fe14, 0x5a654911, 0x47fe675a,   // ak.sn.un_640 tlh.kha.un_660  to.gv.sm_653 ak.tlh.sn_553 
  0x182821a0, 0x0a170812, 0x10111707, 0x254815a4,   // fa.sd.ar_322 uk.sr.mk_654  sr.ro.be_432 un.tt.mn_433 
  0x31381b13, 0x032f2ba0, 0x38002102, 0x313848ee,   // tr.tk.az_665 vi.su.nl_322  jw.tk.un_220 tt.tk.az_422 
  // [9e20]
  0x65180405, 0x483111a4, 0x1d201fa0, 0x183c12ee,   // fi.ga.gv_333 ro.az.tt_433  cy.sq.la_322 ur.ug.ar_422 
  0x34183dee, 0x02002a02, 0x0c1f0404, 0x330210a4,   // ku.ar.ps_422 mt.da.un_220  fi.cy.sv_332 lt.da.nn_433 
  0x22651802, 0x5d5e1fa0, 0x10fc38af, 0x01006007,   // ga.gv.oc_222 cy.ts.ss_322  tk.zzp.lt_655 vo.en.un_420 
  0x04231504, 0x1300020b, 0x030109a0, 0x25003711,   // un.ky.ru_332 da.et.un_520  pl.en.nl_322 st.eu.un_630 
  // [9e30]
  0x27000404, 0x06035712, 0x65001804, 0x3e000508,   // fi.gd.un_320 na.nl.de_654  ga.gv.un_320 fr.rm.un_430 
  0x2d1c54ee, 0x06033f05, 0x09001f18, 0x09000422,   // ik.id.sk_422 af.nl.de_333  cy.pl.un_740 fi.pl.un_870 
  0x3b001b02, 0x4e00541a, 0x040a0807, 0x101f090c,   // tr.so.un_220 ik.ay.un_760  uk.mk.ru_432 pl.cy.lt_543 
  0x330e2e13, 0x44100a60, 0x332e0e0b, 0x135c1c08,   // fo.is.nn_665 mk.be.kk_664  is.fo.nn_542 mr.sa.bh_443 
  // [9e40]
  0x384a2402, 0x0e2e2aa0, 0x044823ad, 0x36005e0d,   // eo.yo.tk_222 mt.fo.is_322  ky.tt.ru_643 ts.gn.un_540 
  0x2e0e2013, 0x174836ec, 0x2f004e07, 0x44001112,   // sq.is.fo_665 ab.tt.sr_644  ay.su.un_420 ro.kk.un_640 
  0x212e0ea0, 0x1e1c510c, 0x120432a0, 0x151015a7,   // is.fo.jw_322 kl.id.ms_543  bs.fi.hu_322 un.be.un_532 
  0x250b57ad, 0x27001a04, 0x31006b04, 0x532f1c04,   // na.es.eu_643 tl.gd.un_320  ceb.az.un_320 id.su.ht_332 
  // [9e50]
  0x0c004007, 0x09130d0d, 0x47005807, 0x371dfea4,   // lb.sv.un_420 ne.bh.hi_554  om.sn.un_420 tlh.la.st_433 
  0x5f00fe14, 0x37fe5f13, 0x2e000209, 0xfe005f1a,   // tlh.tn.un_660 tn.tlh.st_665  da.fo.un_440 tn.tlh.un_760 
  0xfc006311, 0x381bfe0c, 0x0700370b, 0xfe375f12,   // sco.zzp.un_630 tlh.tr.tk_543  ba.bg.un_520 tn.st.tlh_654 
  0x231165a4, 0x08073555, 0x0c005f19, 0x066b1a07,   // gv.ro.ca_433 tg.bg.uk_442  tn.sv.un_750 tl.ceb.de_432 
  // [9e60]
  0xfe005f22, 0x5c0d1cac, 0x57050107, 0x24003b02,   // tn.tlh.un_870 mr.ne.sa_632  en.fr.na_432 so.eo.un_220 
  0x22fe5f0c, 0x2c630ba9, 0x5f37fe12, 0xfe004813,   // tn.tlh.oc_543 es.sco.fy_544  tlh.st.tn_654 tt.tlh.un_650 
  0x330e29a7, 0x24000b02, 0x5f3033ee, 0x58130207,   // sl.is.nn_532 es.eo.un_220  nn.uz.tn_422 da.et.om_432 
  0x03fc13ee, 0x050b01a0, 0x3ffc13ee, 0x47353460,   // et.zzp.nl_422 en.es.fr_322  et.zzp.af_422 xh.zu.sn_664 
  // [9e70]
  0x033f1304, 0x2835fa0c, 0x78353408, 0x59353408,   // et.af.nl_332 nr.zu.sw_543  xh.zu.ve_443 xh.zu.rn_443 
  0x111525ad, 0x35595511, 0x6e033f05, 0x39006e07,   // mn.ro.un_630 rw.rn.zu_653  af.nl.hmn_333 hmn.br.un_420 
  0x04150812, 0x2f3721a4, 0x3f001304, 0x393f40ee,   // uk.ru.un_640 jw.st.su_433  et.af.un_320 lb.af.br_422 
  0x23303ca9, 0x033f1308, 0x0000372d, 0x5f59640c,   // ug.uz.ky_544 et.af.nl_443  st.un.un_A00 lg.rn.tn_543 
  // [9e80]
  0x345535a0, 0x3f036509, 0x0c023502, 0x2855780d,   // zu.rw.xh_322 gv.nl.af_444  zu.da.sv_222 ve.rw.sw_554 
  0x5d4506a9, 0x4900650d, 0x033f6aa6, 0x28002f08,   // de.ln.ss_544 gv.to.un_540  haw.af.nl_521 su.sw.un_430 
  0x18302105, 0x03006513, 0x39034c07, 0x65003f0c,   // fa.uz.ar_333 gv.nl.un_650  wo.nl.br_432 af.gv.un_530 
  0x64355da0, 0x6500620c, 0x3b00390e, 0x45001205,   // ss.zu.lg_322 kha.gv.un_530  br.so.un_550 hu.ln.un_330 
  // [9e90]
  0x31002512, 0x39004602, 0x4448230c, 0x37353455,   // eu.az.un_640 qu.br.un_220  ky.tt.kk_543 xh.zu.st_442 
  0x281230ee, 0x22005e04, 0x65001e02, 0x030f13a0,   // uz.ur.sd_422 ts.oc.un_320  ms.gv.un_220 et.lv.nl_322 
  0x0c060802, 0x1c135cad, 0x2c0233a0, 0x2e0e1808,   // no.de.sv_222 sa.bh.mr_643  nn.da.fy_322 ga.is.fo_443 
  0x07006507, 0x121828ad, 0x21004307, 0x04000e11,   // gv.it.un_420 sd.ar.ur_643  ie.jw.un_420 is.fi.un_630 
  // [9ea0]
  0x095c0dee, 0x1255680d, 0x0e652eee, 0x011865a0,   // ne.sa.hi_422 ig.rw.hu_554  fo.gv.is_422 gv.ga.en_322 
  0x56204f08, 0x0c1304a7, 0x492f73ec, 0x21365c07,   // bi.sq.mg_443 fi.et.sv_532  ny.su.to_644 sa.gn.jw_432 
  0x477328a9, 0x377669a9, 0x2c003f0c, 0x381b0e0c,   // sw.ny.sn_544 mfe.crs.st_544  af.fy.un_530 is.tr.tk_543 
  0x22fc1304, 0x6a5f450c, 0x3e611ca4, 0x5a000a02,   // et.zzp.oc_332 ln.tn.haw_543  id.za.rm_433 pt.sm.un_220 
  // [9eb0]
  0x631f75a7, 0x1300fc21, 0x3d21300e, 0x29000909,   // nso.cy.sco_532 zzp.et.un_860  uz.fa.ku_555 pl.sl.un_440 
  0x28734708, 0x3d1821ee, 0x0a3c30ad, 0x072f26a9,   // sn.ny.sw_443 fa.ar.ku_422  uz.ug.mk_643 ia.su.it_544 
  0x0e2d0d60, 0x050c4713, 0x170a080e, 0x083530a7,   // cs.sk.is_664 sn.sv.fr_665  uk.mk.sr_555 uz.tg.uk_532 
  0x0817350c, 0x041511a7, 0x3c3011ad, 0x170a0805,   // tg.sr.uk_543 ro.ru.un_520  ro.uz.ug_643 uk.mk.sr_333 
  // [9ec0]
  0x17302502, 0x111504a4, 0x382523a9, 0x07301704,   // mn.uz.sr_222 ru.ro.un_430  ky.mn.tk_544 sr.uz.bg_332 
  0x4b000f0e, 0x5f630107, 0x05004204, 0x2b001202,   // lv.mi.un_550 en.sco.tn_432  co.fr.un_320 hu.vi.un_220 
  0x5e001902, 0x56003820, 0x03496a04, 0x1259500c,   // gl.ts.un_220 tk.mg.un_850  haw.to.nl_332 fj.rn.hu_543 
  0x1e003f07, 0x390d0eee, 0x4500380d, 0x1629670c,   // af.ms.un_420 is.cs.br_422  tk.ln.un_540 ak.sl.hr_543 
  // [9ed0]
  0x26431d0c, 0x21003704, 0x373035ad, 0x274f2d0c,   // la.ie.ia_543 st.jw.un_320  tg.uz.ba_643 sk.bi.gd_543 
  0x03003f19, 0x090d1c0e, 0x363835a4, 0x302515ec,   // af.nl.un_750 mr.ne.hi_555  tg.tk.ab_433 un.mn.uz_644 
  0x082456ec, 0x25575013, 0x3f004902, 0x0a055cec,   // mg.eo.no_644 fj.na.eu_665  to.af.un_220 sa.fr.pt_644 
  0x2800180b, 0xfc55590c, 0x2e0c33af, 0x374d67ad,   // ar.sd.un_520 rn.rw.zzp_543  nn.sv.fo_655 ak.aa.st_643 
  // [9ee0]
  0x2e0c33a4, 0x68295755, 0x0e005704, 0x06313e04,   // nn.sv.fo_433 na.sl.ig_442  na.is.un_320 rm.az.de_332 
  0x29002e04, 0x5e5d5708, 0x150e03ad, 0x234430ec,   // fo.sl.un_320 na.ss.ts_443  nl.is.un_643 uz.kk.ky_644 
  0x652223a0, 0x195218a7, 0x02381fac, 0x186e2aa9,   // ca.oc.gv_322 ga.ha.gl_532  cy.tk.da_632 mt.hmn.ga_544 
  0x18002119, 0x081015a9, 0x47735a0c, 0x18375f5a,   // fa.ar.un_750 un.be.uk_544  sm.ny.sn_543 tn.st.ga_553 
  // [9ef0]
  0x5f3756a9, 0x49734708, 0x3e3306a0, 0x354e52a4,   // mg.st.tn_544 sn.ny.to_443  de.nn.rm_322 ha.ay.zu_433 
  0x28005613, 0x0e2733a9, 0x2b005607, 0x63015704,   // mg.sw.un_650 nn.gd.is_544  mg.vi.un_420 na.en.sco_332 
  0x566b1aa0, 0x421d27ee, 0x3b3d21af, 0x23220107,   // tl.ceb.mg_322 gd.la.co_422  fa.ku.ks_655 en.oc.ca_432 
  0x1a00280e, 0x56164708, 0x07300a04, 0x281a560c,   // sw.tl.un_550 sn.hr.mg_443  mk.uz.bg_332 mg.tl.sw_543 
  // [9f00]
  0x07370a02, 0x2112280b, 0x58003b0d, 0x6a171614,   // mk.ba.bg_222 sd.ur.fa_542  so.om.un_540 hr.sr.haw_666 
  0x07003814, 0x4c5158ad, 0x304437a4, 0x1d00501b,   // tk.bg.un_660 om.kl.wo_643  ba.kk.uz_433 fj.la.un_770 
  0x34442311, 0x2c1bfe04, 0x13576212, 0xfc0634ad,   // ky.kk.ps_653 tlh.tr.fy_332  kha.na.et_654 xh.de.zzp_643 
  0x0c425507, 0x641102a0, 0x5a1f4cec, 0x06330804,   // rw.co.sv_432 da.ro.lg_322  wo.cy.sm_644 no.nn.de_332 
  // [9f10]
  0x1020670c, 0x100f110c, 0x09002519, 0x02000a02,   // ak.sq.lt_543 ro.lv.lt_543  eu.pl.un_750 pt.da.un_220 
  0x02066005, 0x3b2d0d02, 0x3f356404, 0x3034fc04,   // vo.de.da_333 cs.sk.so_222  lg.zu.af_332 zzp.xh.uz_332 
  0x28022005, 0x1b313814, 0x0d002c04, 0x02041312,   // sq.da.sw_333 tk.az.tr_666  fy.cs.un_320 et.fi.da_654 
  0x33022e05, 0x652d0d02, 0x303537a0, 0x443615ec,   // fo.da.nn_333 cs.sk.gv_222  ba.tg.uz_322 un.ab.kk_644 
  // [9f20]
  0x0000312d, 0x18281212, 0x1538480c, 0x5c090d07,   // az.un.un_A00 ur.sd.ar_654  tt.tk.un_543 ne.hi.sa_432 
  0x476a6507, 0x5600050c, 0x2e18360c, 0x353017ee,   // gv.haw.sn_432 fr.mg.un_530  gn.ga.fo_543 sr.uz.tg_422 
  0x17003814, 0x04057904, 0x65000502, 0x1300301a,   // tk.sr.un_660 war.fr.fi_332  fr.gv.un_220 uz.et.un_760 
  0x051e1c04, 0x135c09a7, 0x442348a9, 0x0c2f02a7,   // id.ms.fr_332 hi.sa.bh_532  tt.ky.kk_544 da.su.sv_532 
  // [9f30]
  0x1e261c12, 0x1c001e1a, 0x56002013, 0x303536ee,   // id.ia.ms_654 ms.id.un_760  sq.mg.un_650 ab.tg.uz_422 
  0x10300812, 0x16002702, 0x15066004, 0x1f00040c,   // uk.uz.be_654 gd.hr.un_220  vo.de.un_332 fi.cy.un_530 
  0x28003b18, 0x1f00652b, 0x231036a4, 0x5c006a1a,   // ks.sd.un_740 gv.cy.un_980  ab.be.ky_433 haw.sa.un_760 
  0x045c13ee, 0x59345808, 0x3f1213ee, 0x6b0efe07,   // et.sa.fi_422 om.xh.rn_443  et.hu.af_422 tlh.is.ceb_432 
  // [9f40]
  0x46006b05, 0x73002523, 0x67005e1a, 0x34281813,   // ceb.qu.un_330 eu.ny.un_880  ts.ak.un_760 ar.sd.ps_665 
  0x5e001f13, 0x47006809, 0x380465ee, 0x132e0eee,   // cy.ts.un_650 ig.sn.un_440  gv.fi.tk_422 is.fo.et_422 
  0x0764250c, 0x382311ec, 0x38651f07, 0x35170813,   // eu.lg.it_543 ro.ky.tk_644  cy.gv.tk_432 uk.sr.tg_665 
  0x555c590c, 0x04101509, 0xfc003604, 0x2e122ca0,   // rn.sa.rw_543 un.be.ru_444  gn.zzp.un_320 fy.hu.fo_322 
  // [9f50]
  0x1d631111, 0x11383c0c, 0x5c0e13a0, 0x2f5c21ee,   // ro.sco.la_653 ug.tk.ro_543  et.is.sa_322 jw.sa.su_422 
  0x0a083804, 0x430726a9, 0x09131c0c, 0x050e2107,   // tk.uk.mk_332 ia.it.ie_544  mr.bh.hi_543 jw.is.fr_432 
  0xfc00fe04, 0x08040a08, 0x2b630112, 0x2e3863ee,   // tlh.zzp.un_320 mk.ru.uk_443  en.sco.vi_654 sco.tk.fo_422 
  0x51000204, 0x201224ad, 0x031a3faf, 0x184423ad,   // da.kl.un_320 eo.hu.sq_643  af.tl.nl_655 ky.kk.ar_643 
  // [9f60]
  0x640337a0, 0x4a007919, 0x123423a7, 0x42005a05,   // st.nl.lg_322 war.yo.un_750  ky.ps.ur_532 sm.co.un_330 
  0x025f6407, 0x2e000808, 0x07353c09, 0x383025a9,   // lg.tn.da_432 no.fo.un_430  ug.tg.bg_444 mn.uz.tk_544 
  0x092930ee, 0x1f4c3905, 0x0c48130c, 0x5c130d05,   // uz.sl.pl_422 br.wo.cy_333  et.tt.sv_543 ne.bh.sa_333 
  0x0d006b04, 0x3d002109, 0x3f2ffe08, 0x4435300d,   // ceb.cs.un_320 fa.ku.un_440  tlh.su.af_443 uz.tg.kk_554 
  // [9f70]
  0x25000413, 0x0425280d, 0xfc004902, 0x0c007904,   // fi.eu.un_650 sw.eu.fi_554  to.zzp.un_220 war.sv.un_320 
  0x401205ee, 0x043b0207, 0x5125790c, 0x11383c13,   // fr.hu.lb_422 da.so.fi_432  war.eu.kl_543 ug.tk.ro_665 
  0x0f390404, 0x1c003f0b, 0x111504ec, 0x51080255,   // fi.br.lv_332 af.id.un_520  ru.ro.un_640 da.no.kl_442 
  0x301223a4, 0x07042b0c, 0x38301b09, 0x4006fc04,   // ky.ur.uz_433 vi.fi.it_543  tr.uz.tk_444 zzp.de.lb_332 
  // [9f80]
  0x46111902, 0x1b22480c, 0x1b4830a9, 0xfe3f6055,   // gl.ro.qu_222 tt.oc.tr_543  uz.tt.tr_544 vo.af.tlh_442 
  0x31301bac, 0x3e1b3008, 0x5d001109, 0x0c38330c,   // tr.uz.az_632 uz.tr.rm_443  ro.ss.un_440 nn.tk.sv_543 
  0x12002c02, 0x0b30310d, 0x5a000412, 0xfc3830a7,   // fy.hu.un_220 az.uz.es_554  fi.sm.un_640 uz.tk.zzp_532 
  0x2343310b, 0xfc000e07, 0x04006a1a, 0x1b483009,   // az.ie.ca_542 is.zzp.un_420  haw.fi.un_760 uz.tt.tr_444 
  // [9f90]
  0x653e0c04, 0x304838a9, 0x0c48300c, 0x30003308,   // sv.rm.gv_332 tk.tt.uz_544  uz.tt.sv_543 nn.uz.un_430 
  0x30005f05, 0x2e000d1a, 0x481b31ec, 0x481b3808,   // tn.uz.un_330 cs.fo.un_760  az.tr.tt_644 tk.tr.tt_443 
  0x30483113, 0x100437a0, 0x5c00040d, 0x381b48ee,   // az.tt.uz_665 ba.ru.be_322  fi.sa.un_540 tt.tr.tk_422 
  0x342818a7, 0x17350a04, 0x38fe5e0c, 0x31481ba0,   // ar.sd.ps_532 mk.tg.sr_332  ts.tlh.tk_543 tr.tt.az_322 
  // [9fa0]
  0x5f371e07, 0x5f00fe33, 0x342130a7, 0x01fc5c02,   // ms.st.tn_432 tlh.tn.un_A70  uz.fa.ps_532 sa.zzp.en_222 
  0x04006712, 0x04234455, 0x375ffe14, 0x1b2315ee,   // ak.fi.un_640 kk.ky.ru_442  tlh.tn.st_666 un.ca.tr_422 
  0x205f0e07, 0x0b0d1907, 0x0f4838ad, 0x2d000b02,   // is.tn.sq_432 gl.cs.es_432  tk.tt.lv_643 es.sk.un_220 
  0xfe3738a0, 0x1704080c, 0x35113013, 0x11003c19,   // tk.st.tlh_322 uk.ru.sr_543  uz.ro.tg_665 ug.ro.un_750 
  // [9fb0]
  0x0f1bfe0c, 0x18003414, 0x34122111, 0xfe1b1a0c,   // tlh.tr.lv_543 ps.ar.un_660  fa.ur.ps_653 tl.tr.tlh_543 
  0x30383caf, 0x3c4837ec, 0x233c3012, 0x17040aa4,   // ug.tk.uz_655 ba.tt.ug_644  uz.ug.ky_654 mk.ru.sr_433 
  0x070a300c, 0x65003b13, 0x6b7973a7, 0x23443c08,   // uz.mk.bg_543 so.gv.un_650  ny.war.ceb_532 ug.kk.ky_443 
  0x79007319, 0x23303c11, 0x3b00651a, 0x37483ca0,   // ny.war.un_750 ug.uz.ky_653  gv.so.un_760 ug.tt.ba_322 
  // [9fc0]
  0x3534730e, 0x31653b0d, 0x11483c08, 0x28471a02,   // ny.xh.zu_555 so.gv.az_554  ug.tt.ro_443 tl.sn.sw_222 
  0x0100630e, 0x1a6b73a0, 0x02005107, 0x30153c0c,   // sco.en.un_550 ny.ceb.tl_322  kl.da.un_420 ug.uz.un_530 
  0x04171509, 0x0a38110c, 0x162d0d07, 0x3d00230d,   // un.sr.ru_444 ro.tk.mk_543  cs.sk.hr_432 ky.ku.un_540 
  0x3c30350c, 0x153918a0, 0x556434ec, 0x49005708,   // tg.uz.ug_543 ga.br.un_322  xh.lg.rw_644 na.to.un_430 
  // [9fd0]
  0x313b65ee, 0x461a6b11, 0x0b361907, 0x65003b12,   // gv.so.az_422 ceb.tl.qu_653  gl.gn.es_432 so.gv.un_640 
  0x551b020b, 0x69653108, 0x281a02ad, 0x041536a7,   // da.tr.rw_542 az.gv.mfe_443  da.tl.sw_643 ab.ru.un_520 
  0xfe6e3f0d, 0x3f6e0811, 0x1d00110d, 0x4c201eee,   // af.hmn.tlh_554 no.hmn.af_653  ro.la.un_540 ms.sq.wo_422 
  0x30fe6e0d, 0x031c3fa6, 0x35443c0c, 0x5c002a08,   // hmn.tlh.uz_554 af.id.nl_521  ug.kk.tg_543 mt.sa.un_430 
  // [9fe0]
  0x355c2807, 0xfe290aa9, 0x11005102, 0x11003302,   // sw.sa.zu_432 pt.sl.tlh_544  kl.ro.un_220 nn.ro.un_220 
  0x674f600c, 0x39332cac, 0x3f4c2b04, 0x6e00691a,   // vo.bi.ak_543 fy.nn.br_632  vi.wo.af_332 mfe.hmn.un_760 
  0x2b263055, 0x0a002c02, 0x11332cee, 0x39002c05,   // uz.ia.vi_442 fy.pt.un_220  fy.nn.ro_422 fy.br.un_330 
  0x390a3302, 0x060c400e, 0x19003307, 0x36fe6307,   // nn.pt.br_222 lb.sv.de_555  nn.gl.un_420 sco.tlh.gn_432 
  // [9ff0]
  0x1160060d, 0x266e01ad, 0x15215d0b, 0x30004d0c,   // de.vo.ro_554 en.hmn.ia_643  ss.jw.un_542 aa.uz.un_530 
  0x07000104, 0xfc006508, 0x5400070e, 0x011e15a0,   // en.it.un_320 gv.zzp.un_430  it.ik.un_550 un.ms.en_322 
  0x22002c08, 0x345d3513, 0x111d4204, 0x1d000c04,   // fy.oc.un_430 zu.ss.xh_665  co.la.ro_332 sv.la.un_320 
  0x2f0415a0, 0x2b0315ee, 0x250a3607, 0x32001507,   // un.fi.su_322 un.nl.vi_422  ab.mk.mn_432 un.bs.un_420 
  
  // [a000]
  0x21461504, 0x460315ee, 0x3c17300e, 0x070a0107,   // un.qu.jw_332 un.nl.qu_422  uz.sr.ug_555 en.pt.it_432 
  0x170a2507, 0x15000309, 0x23002518, 0x211c0807,   // mn.mk.sr_432 nl.un.un_440  mn.ky.un_740 no.id.jw_432 
  0x5a062404, 0x30233c0e, 0x63003808, 0x1b3038a9,   // eo.de.sm_332 ug.ky.uz_555  tk.sco.un_430 tk.uz.tr_544 
  0x0d005604, 0x092d3804, 0x38005602, 0x252c38a0,   // mg.cs.un_320 tk.sk.pl_332  mg.tk.un_220 tk.fy.eu_322 
  // [a010]
  0x24001f02, 0x48303cee, 0x34281208, 0x25007307,   // cy.eo.un_220 ug.uz.tt_422  ur.sd.ps_443 ny.eu.un_420 
  0x352315ad, 0x4c006308, 0x73001122, 0x102d0d0e,   // un.ky.tg_643 sco.wo.un_430  ro.ny.un_870 cs.sk.lt_555 
  0x13000920, 0x18005208, 0x24202d04, 0x16002d02,   // hi.bh.un_850 ha.ga.un_430  sk.sq.eo_332 sk.hr.un_220 
  0x040a13a0, 0x61000419, 0x04006111, 0x5e004702,   // et.pt.fi_322 fi.za.un_750  za.fi.un_630 sn.ts.un_220 
  // [a020]
  0x4b003922, 0x2c391109, 0x0a173c55, 0x5f003908,   // br.mi.un_870 ro.br.fy_444  ug.sr.mk_442 br.tn.un_430 
  0x051d18a4, 0x041735a6, 0x56000207, 0x792c01a4,   // ga.la.fr_433 tg.sr.ru_521  da.mg.un_420 en.fy.war_433 
  0x652c39ad, 0x11002c2b, 0x04004822, 0x39256502,   // br.fy.gv_643 fy.ro.un_980  tt.fi.un_870 gv.eu.br_222 
  0x0425440e, 0x56003912, 0x69001819, 0x6500020e,   // kk.mn.ru_555 br.mg.un_640  ga.mfe.un_750 da.gv.un_550 
  // [a030]
  0x04651308, 0x6579180b, 0x65006313, 0x65112c08,   // et.gv.fi_443 ga.war.gv_542  sco.gv.un_650 fy.ro.gv_443 
  0x11004b1a, 0x34000209, 0x56790213, 0x28fe2a07,   // mi.ro.un_760 da.xh.un_440  da.war.mg_665 mt.tlh.sw_432 
  0x2c00400e, 0x212f56ac, 0x4b6511a0, 0x45002d04,   // lb.fy.un_550 mg.su.jw_632  ro.gv.mi_322 sk.ln.un_320 
  0x343b1207, 0x1a564a12, 0x044725ec, 0x556459a4,   // ur.ks.ps_432 yo.mg.tl_654  eu.sn.fi_644 rn.lg.rw_433 
  // [a040]
  0x07303ca9, 0x30151702, 0x52205612, 0x5955600c,   // ug.uz.bg_544 sr.uz.un_220  mg.sq.ha_654 vo.rw.rn_543 
  0x602859ee, 0xfe595513, 0x07100805, 0x30005e1b,   // rn.sw.vo_422 rw.rn.tlh_665  uk.be.bg_333 ts.uz.un_770 
  0x48113708, 0x50005113, 0x2500fe08, 0x0955fe07,   // ba.ro.tt_443 kl.fj.un_650  tlh.eu.un_430 tlh.rw.pl_432 
  0x073924a9, 0x3f03490d, 0x3d003b13, 0x254823a4,   // eo.br.it_544 to.nl.af_554  ks.ku.un_650 ky.tt.mn_433 
  // [a050]
  0x313b4607, 0x21003f07, 0x35342aa4, 0x15384807,   // qu.so.az_432 af.jw.un_420  mt.xh.zu_433 tt.tk.un_432 
  0x3d2134a7, 0x2a003408, 0x2d00381e, 0x5c00fe0e,   // ps.fa.ku_532 xh.mt.un_430  tk.sk.un_830 tlh.sa.un_550 
  0x34005107, 0x1f005502, 0x51003405, 0x5c090d0d,   // kl.xh.un_420 rw.cy.un_220  xh.kl.un_330 ne.hi.sa_554 
  0x060c02ee, 0x3f021f07, 0x040a3c0c, 0x0f004d14,   // da.sv.de_422 cy.da.af_432  ug.mk.ru_543 aa.lv.un_660 
  // [a060]
  0x0d092d07, 0x34004602, 0x3100460d, 0x09122d02,   // sk.pl.cs_432 qu.xh.un_220  qu.az.un_540 sk.hu.pl_222 
  0x13091c05, 0x1844235a, 0x3c153011, 0x57004c1b,   // mr.hi.bh_333 ky.kk.ar_553  uz.ug.un_630 wo.na.un_770 
  0x17321607, 0x213b2805, 0x37004c07, 0x36003304,   // hr.bs.sr_432 sd.ks.fa_333  wo.st.un_420 nn.gn.un_320 
  0x2a000207, 0x07173502, 0x231537a9, 0x091c5c11,   // da.mt.un_420 tg.sr.bg_222  ba.ky.un_540 sa.mr.hi_653 
  // [a070]
  0x1548110c, 0x5f7302a4, 0x353925a9, 0x475d3411,   // ro.tt.un_543 da.ny.tn_433  eu.br.zu_544 xh.ss.sn_653 
  0x02566708, 0x080c33a0, 0x5f2f020c, 0x021a6ba6,   // ak.mg.da_443 nn.sv.no_322  da.su.tn_543 ceb.tl.da_521 
  0x25000418, 0x44381112, 0x0262040d, 0x4736040b,   // fi.eu.un_740 ro.tk.kk_654  fi.kha.da_554 fi.gn.sn_542 
  0x0e00fc13, 0x270815a0, 0x531b1e02, 0x3900610c,   // zzp.is.un_650 un.no.gd_322  ms.tr.ht_222 za.br.un_530 
  // [a080]
  0x2e436005, 0x13003909, 0x480e330c, 0x0663400b,   // vo.ie.fo_333 br.et.un_440  nn.is.tt_543 lb.sco.de_542 
  0x39001312, 0x0c0e33a4, 0x393e47a6, 0x02353405,   // et.br.un_640 nn.is.sv_433  sn.rm.br_521 xh.zu.da_333 
  0x0d001102, 0x375550a9, 0x6700620c, 0x1a796bec,   // ro.cs.un_220 fj.rw.st_544  kha.ak.un_530 ceb.war.tl_644 
  0x27002902, 0x2b003204, 0x3325040c, 0x0800332a,   // sl.gd.un_220 bs.vi.un_320  fi.eu.nn_543 nn.no.un_970 
  // [a090]
  0x31004814, 0x5c00091b, 0x330e2e0e, 0x0e003e11,   // tt.az.un_660 hi.sa.un_770  fo.is.nn_555 rm.is.un_630 
  0x220e2e12, 0x2330155a, 0x3c0a35a4, 0x2f1c5ea0,   // fo.is.oc_654 un.uz.ky_553  tg.mk.ug_433 ts.id.su_322 
  0x2e330cac, 0x50055a04, 0x655a2c60, 0x303835af,   // sv.nn.fo_632 sm.fr.fj_332  fy.sm.gv_664 tg.tk.uz_655 
  0x0205010c, 0x1100651a, 0x1d000504, 0x5a004912,   // en.fr.da_543 gv.ro.un_760  fr.la.un_320 to.sm.un_640 
  // [a0a0]
  0x3c3d2307, 0x2e360e05, 0x2b1f3855, 0x1dfc3813,   // ky.ku.ug_432 is.gn.fo_333  tk.cy.vi_442 tk.zzp.la_665 
  0x1f12380b, 0x47003405, 0xfc6538a0, 0x65fc38a7,   // tk.hu.cy_542 xh.sn.un_330  tk.gv.zzp_322 tk.zzp.gv_532 
  0x1100220b, 0x05002702, 0x39054907, 0x6512380d,   // oc.ro.un_520 gd.fr.un_220  to.fr.br_432 tk.hu.gv_554 
  0x2d005304, 0xfc386504, 0x1f38fca0, 0x49006512,   // ht.sk.un_320 gv.tk.zzp_332  zzp.tk.cy_322 gv.to.un_640 
  // [a0b0]
  0x6501fc07, 0x380456a0, 0x0138fc11, 0x070815af,   // zzp.en.gv_432 mg.fi.tk_322  zzp.tk.en_653 un.uk.bg_655 
  0xfc3801a4, 0x65fc3804, 0x53002902, 0x0a303513,   // en.tk.zzp_433 tk.zzp.gv_332  sl.ht.un_220 tg.uz.mk_665 
  0x330815a4, 0x39001d0c, 0x3c483008, 0x15154404,   // un.no.nn_433 la.br.un_530  uz.tt.ug_443 kk.un.un_320 
  0x123418a6, 0x315c3009, 0x38006505, 0x080425a4,   // ar.ps.ur_521 uz.sa.az_444  gv.tk.un_330 mn.ru.uk_433 
  // [a0c0]
  0x1a303155, 0x043865ec, 0x15234805, 0x18343dee,   // az.uz.tl_442 gv.tk.fi_644  tt.ky.un_333 ku.ps.ar_422 
  0x080c3308, 0x0c00330e, 0x35443009, 0x24330c07,   // nn.sv.no_443 nn.sv.un_550  uz.kk.tg_444 sv.nn.eo_432 
  0x213d3bee, 0x48002807, 0x123b34ad, 0x571b25ad,   // ks.ku.fa_422 sw.tt.un_420  ps.ks.ur_643 eu.tr.na_643 
  0x51006804, 0x080436a7, 0x575601a4, 0x1e252904,   // ig.kl.un_320 ab.ru.uk_532  en.mg.na_433 sl.eu.ms_332 
  // [a0d0]
  0x173c3004, 0x1d0e3ea4, 0x31001a07, 0x280118af,   // uz.ug.sr_332 rm.is.la_433  tl.az.un_420 ar.iw.sd_655 
  0x2d180d12, 0x25003505, 0x30213da0, 0x2d450d11,   // cs.ga.sk_654 tg.mn.un_330  ku.fa.uz_322 cs.ln.sk_653 
  0x27150c0c, 0x2d000d2b, 0x33004604, 0x494d2d0c,   // sv.gd.un_530 cs.sk.un_980  qu.nn.un_320 sk.aa.to_543 
  0x0306480c, 0x49004513, 0x13003207, 0xfc40065a,   // tt.de.nl_543 ln.to.un_650  bs.et.un_420 de.lb.zzp_553 
  // [a0e0]
  0x39003608, 0x18494d12, 0x0b4818ee, 0x18000a07,   // gn.br.un_430 aa.to.ga_654  ga.tt.es_422 pt.ga.un_420 
  0x193309ee, 0x26001c08, 0x18000d21, 0x62252608,   // pl.nn.gl_422 id.ia.un_430  cs.ga.un_860 ia.eu.kha_443 
  0x330e2ea7, 0x15332502, 0x26433307, 0x1523255a,   // fo.is.nn_532 eu.nn.un_222  nn.ie.ia_432 mn.ky.un_553 
  0xfc002404, 0x230d4d0c, 0x33263ead, 0x23220aa7,   // eo.zzp.un_320 aa.cs.ca_543  rm.ia.nn_643 pt.oc.ca_532 
  // [a0f0]
  0x1e002504, 0x4a182d11, 0x49180daf, 0x362d0d07,   // eu.ms.un_320 sk.ga.yo_653  cs.ga.to_655 cs.sk.gn_432 
  0x122446a4, 0x374415a0, 0x13624caf, 0x3e002513,   // qu.eo.hu_433 un.kk.ba_322  wo.kha.et_655 eu.rm.un_650 
  0x330925a0, 0x0a304404, 0x033f4cee, 0x230b0a0d,   // eu.pl.nn_322 kk.uz.mk_332  wo.af.nl_422 pt.es.ca_554 
  0x22465aa4, 0x2f622608, 0x42004c07, 0x0a00330b,   // sm.qu.oc_433 ia.kha.su_443  wo.co.un_420 nn.pt.un_520 
  // [a100]
  0x4c006305, 0x2f622104, 0x4c004d18, 0x03023fa9,   // sco.wo.un_330 jw.kha.su_332  aa.wo.un_740 af.da.nl_544 
  0x65003902, 0x3c301508, 0x2500070c, 0x033f4c0c,   // br.gv.un_220 un.uz.ug_443  bg.mn.un_530 wo.af.nl_543 
  0x031201a0, 0x02004c2a, 0x1b006807, 0x654c6ea0,   // en.hu.nl_322 wo.da.un_970  ig.tr.un_420 hmn.wo.gv_322 
  0x220a230c, 0x44002502, 0x5e000604, 0x73005112,   // ca.pt.oc_543 mn.kk.un_220  de.ts.un_320 kl.ny.un_640 
  // [a110]
  0x23382508, 0x505160a4, 0x1a02580c, 0x07151705,   // mn.tk.ky_443 vo.kl.fj_433  om.da.tl_543 sr.bg.un_330 
  0x5c513604, 0x1f3f1513, 0x02552507, 0x2523170c,   // gn.kl.sa_332 un.af.cy_665  eu.rw.da_432 sr.ky.mn_543 
  0x1011200b, 0x15003202, 0x0259510c, 0x06004204,   // sq.ro.lt_542 bs.un.un_220  kl.rn.da_543 co.de.un_320 
  0x591d3507, 0x7300550c, 0x04441505, 0x5c64020c,   // zu.la.rn_432 rw.ny.un_530  un.kk.ru_333 da.lg.sa_543 
  // [a120]
  0x383023a4, 0x3b004c0c, 0x045c4704, 0x150a37a4,   // ky.uz.tk_433 wo.so.un_530  sn.sa.fi_332 ba.mk.un_433 
  0x3036230c, 0x64467304, 0x0360490c, 0x76005a08,   // ky.ab.uz_543 ny.qu.lg_332  to.vo.nl_543 sm.crs.un_430 
  0x135164a4, 0x281a6ba4, 0x5f003504, 0x51465808,   // lg.kl.et_433 ceb.tl.sw_433  zu.tn.un_320 om.qu.kl_443 
  0x295630ad, 0x6b562fa0, 0x675a490b, 0x303538ac,   // uz.mg.sl_643 su.mg.ceb_322  to.sm.ak_542 tk.tg.uz_632 
  // [a130]
  0x073608a4, 0x24004307, 0x3800430c, 0x2d0d37a0,   // uk.ab.bg_433 ie.eo.un_420  ie.tk.un_530 st.cs.sk_322 
  0x18213409, 0x08250402, 0x73005308, 0x44043002,   // ps.fa.ar_444 ru.mn.uk_222  ht.ny.un_430 uz.ru.kk_222 
  0x251943a0, 0x08043608, 0x24001d22, 0xfe003035,   // ie.gl.eu_322 ab.ru.uk_443  la.eo.un_870 uz.tlh.un_A90 
  0x20624f13, 0x65040505, 0x09406e13, 0xfe2b6ea9,   // bi.kha.sq_665 fr.fi.gv_333  hmn.lb.pl_665 hmn.vi.tlh_544 
  // [a140]
  0x1017110c, 0x58515ba0, 0x345262ec, 0x112b63a9,   // ro.sr.be_543 sg.kl.om_322  kha.ha.xh_644 sco.vi.ro_544 
  0x65001d21, 0x69006723, 0x53006e0d, 0x6500fe33,   // la.gv.un_860 ak.mfe.un_880  hmn.ht.un_540 tlh.gv.un_A70 
  0x16000104, 0x536e1f08, 0x496a4baf, 0x2a46fe12,   // en.hr.un_320 cy.hmn.ht_443  mi.haw.to_655 tlh.qu.mt_654 
  0x6e29fea9, 0x211e1c14, 0x3c253504, 0x09345708,   // tlh.sl.hmn_544 id.ms.jw_666  tg.mn.ug_332 na.xh.pl_443 
  // [a150]
  0x36002014, 0x212f68ad, 0x6a697611, 0x6e002705,   // sq.gn.un_660 ig.su.jw_643  crs.mfe.haw_653 gd.hmn.un_330 
  0x391020a4, 0x3f0360af, 0x10070404, 0x1c052108,   // sq.lt.br_433 vo.nl.af_655  ru.bg.be_332 jw.fr.id_443 
  0x44070402, 0x503756ad, 0x34693812, 0x47346707,   // ru.bg.kk_222 mg.st.fj_643  tk.mfe.xh_654 ak.xh.sn_432 
  0x08170a04, 0x040725ee, 0x371e1c0d, 0x3c304408,   // mk.sr.uk_332 mn.bg.ru_422  id.ms.st_554 kk.uz.ug_443 
  // [a160]
  0x47292004, 0x34284705, 0x2d0d20a4, 0x07150807,   // sq.sl.sn_332 sn.sw.xh_333  sq.cs.sk_433 uk.bg.un_420 
  0x061b40a0, 0x030d2407, 0x4438230c, 0x09242da0,   // lb.tr.de_322 eo.cs.nl_432  ky.tk.kk_543 sk.eo.pl_322 
  0x231148af, 0x094215ee, 0x1a04130c, 0x041301a4,   // tt.ro.ky_655 un.co.pl_422  et.fi.tl_543 en.et.fi_433 
  0x100d09ad, 0xfc003905, 0x0e041309, 0x481310a0,   // pl.cs.lt_643 br.zzp.un_330  et.fi.is_444 lt.et.tt_322 
  // [a170]
  0x13000d0b, 0xfc420107, 0x243e070c, 0x20135cad,   // ne.bh.un_520 en.co.zzp_432  it.rm.eo_543 sa.et.sq_643 
  0x4c1301a9, 0x4831300c, 0x341b0ea6, 0x65240da0,   // en.et.wo_544 uz.az.tt_543  is.tr.xh_521 cs.eo.gv_322 
  0x10004704, 0x302535a4, 0x1d424307, 0x0800350e,   // sn.lt.un_320 tg.mn.uz_433  ie.co.la_432 tg.uk.un_550 
  0x0a0810ec, 0x0900060e, 0x2d290d14, 0x48003608,   // be.uk.mk_644 de.pl.un_550  cs.sl.sk_666 ab.tt.un_430 
  // [a180]
  0x060e0ca4, 0x55645904, 0x244a4ca4, 0x59005521,   // sv.is.de_433 rn.lg.rw_332  wo.yo.eo_433 rw.rn.un_860 
  0x10002f05, 0x4e13040c, 0x3204130c, 0x0e334e0c,   // su.lt.un_330 fi.et.ay_543  et.fi.bs_543 ay.nn.is_543 
  0x1a005204, 0x64794ca0, 0x26105ca4, 0x3200590c,   // ha.tl.un_320 wo.war.lg_322  sa.lt.ia_433 rn.bs.un_530 
  0x483830a4, 0x5600fc13, 0x4c00240e, 0x32000e05,   // uz.tk.tt_433 zzp.mg.un_650  eo.wo.un_550 is.bs.un_330 
  // [a190]
  0x49007312, 0x5c0e16a0, 0x6b1d0455, 0x5a006308,   // ny.to.un_640 hr.is.sa_322  fi.la.ceb_442 sco.sm.un_430 
  0x33000e02, 0x024a1cad, 0x5c001802, 0x36004704,   // is.nn.un_220 id.yo.da_643  ga.sa.un_220 sn.gn.un_320 
  0x08042505, 0x21102fad, 0x30002407, 0x15003612,   // mn.ru.uk_333 su.lt.jw_643  eo.uz.un_420 ab.un.un_640 
  0x12212f07, 0x0c082e07, 0x1a2428ee, 0x27002211,   // su.jw.hu_432 fo.no.sv_432  sw.eo.tl_422 oc.gd.un_630 
  // [a1a0]
  0x08481508, 0x10004408, 0x165c0dec, 0x0a233004,   // un.tt.uk_443 kk.be.un_430  cs.sa.hr_644 uz.ky.mk_332 
  0x51001c07, 0x353e28a0, 0x51001602, 0x0603580c,   // id.kl.un_420 sw.rm.zu_322  hr.kl.un_220 om.nl.de_543 
  0x3f584c5a, 0x18002834, 0x65004a1b, 0x351710a4,   // wo.om.af_553 sd.ar.un_A80  yo.gv.un_770 be.sr.tg_433 
  0x4c653b5a, 0x25303514, 0x3b006519, 0x325c2904,   // so.gv.wo_553 tg.uz.mn_666  gv.so.un_750 sl.sa.bs_332 
  // [a1b0]
  0x4c033f12, 0x3b584008, 0x1b3f02a0, 0x343b2108,   // af.nl.wo_654 lb.om.so_443  da.af.tr_322 fa.ks.ps_443 
  0x150a17af, 0x3b00582c, 0x24002622, 0x12200c02,   // sr.mk.un_655 om.so.un_990  ia.eo.un_870 sv.sq.hu_222 
  0x0408070b, 0x3b004702, 0x183b0160, 0x4d4c3baf,   // bg.uk.ru_542 sn.so.un_220  iw.ks.ar_664 so.wo.aa_655 
  0x2c001304, 0x030cfea4, 0x070415af, 0x3b1c0914,   // et.fy.un_320 tlh.sv.nl_433  un.ru.bg_655 hi.mr.ks_666 
  // [a1c0]
  0x3b684d07, 0x4d133ba9, 0x253035a7, 0x51003b21,   // aa.ig.so_432 so.et.aa_544  tg.uz.mn_532 so.kl.un_860 
  0x1b310eee, 0x3f06fea0, 0x47000707, 0x62650408,   // is.az.tr_422 tlh.de.af_322  it.sn.un_420 fi.gv.kha_443 
  0x2c033f0e, 0x1b0e0204, 0x513b2809, 0x3f020f0c,   // af.nl.fy_555 da.is.tr_332  sw.so.kl_444 lv.da.af_543 
  0x5506590d, 0x06002a02, 0x2a024707, 0x1f0efc0b,   // rn.de.rw_554 mt.de.un_220  sn.da.mt_432 zzp.is.cy_542 
  // [a1d0]
  0x06595504, 0x3f030907, 0x031b12a7, 0x5500590b,   // rw.rn.de_332 pl.nl.af_432  hu.tr.nl_532 rn.rw.un_520 
  0x22000a22, 0x18153305, 0x0c000304, 0x2a220a14,   // pt.oc.un_870 nn.ga.un_330  nl.sv.un_320 pt.oc.mt_666 
  0x12034005, 0x48084607, 0x52002a04, 0x3f1e62ee,   // lb.nl.hu_333 qu.no.tt_432  mt.ha.un_320 kha.ms.af_422 
  0x18272104, 0x033f1e0d, 0x3f2c1304, 0x65fe270e,   // jw.gd.ga_332 ms.af.nl_554  et.fy.af_332 gd.tlh.gv_555 
  // [a1e0]
  0x5e005908, 0x16475eee, 0x114438af, 0x2e600e04,   // rn.ts.un_430 ts.sn.hr_422  tk.kk.ro_655 is.vo.fo_332 
  0x1b0e310c, 0x233c3808, 0x480e45a0, 0x0e003305,   // az.is.tr_543 tk.ug.ky_443  ln.is.tt_322 nn.is.un_330 
  0x17006007, 0x08003322, 0x290f0da0, 0xfc3f0304,   // vo.sr.un_420 nn.no.un_870  cs.lv.sl_322 nl.af.zzp_332 
  0x30003908, 0x6218275a, 0x1a004004, 0x62001c04,   // br.uz.un_430 gd.ga.kha_553  lb.tl.un_320 id.kha.un_320 
  // [a1f0]
  0x65002608, 0x79002308, 0x052223ac, 0x0d005c0b,   // ia.gv.un_430 ca.war.un_430  ca.oc.fr_632 sa.ne.un_520 
  0x373c300d, 0x32002d08, 0x1b3856a4, 0x25070aad,   // uz.ug.ba_554 sk.bs.un_430  mg.tk.tr_433 mk.bg.mn_643 
  0x02006113, 0x04151007, 0x1c090da7, 0x045618ad,   // za.da.un_650 be.ru.un_420  ne.hi.mr_532 ga.mg.fi_643 
  0x082530ee, 0x3800690c, 0x642824ee, 0x38025607,   // uz.mn.uk_422 mfe.tk.un_530  eo.sw.lg_422 mg.da.tk_432 
  // [a200]
  0x273e18a9, 0x284c560c, 0x1c130d0c, 0x04003902,   // ga.rm.gd_544 mg.wo.sw_543  ne.bh.mr_543 br.fi.un_220 
  0x2301600c, 0x112f2702, 0x2f272105, 0x10170812,   // vo.en.ca_543 gd.su.ro_222  jw.gd.su_333 uk.sr.be_654 
  0x07271802, 0x08353055, 0x361704a9, 0x185a1fa4,   // ga.gd.it_222 uz.tg.uk_442  ru.sr.ab_544 cy.sm.ga_433 
  0x074254a4, 0x0a071013, 0x170a15a0, 0x39330804,   // ik.co.it_433 be.bg.mk_665  un.mk.sr_322 no.nn.br_332 
  // [a210]
  0x130608ee, 0x02006b0d, 0xfc003309, 0x3000181b,   // no.de.et_422 ceb.da.un_540  nn.zzp.un_440 ar.uz.un_770 
  0x1d004002, 0x15004012, 0x2400fc12, 0x55456404,   // lb.la.un_220 lb.un.un_640  zzp.eo.un_640 lg.ln.rw_332 
  0x13644512, 0x30313baf, 0x59554aa0, 0x06330802,   // ln.lg.et_654 so.az.uz_655  yo.rw.rn_322 no.nn.de_222 
  0x0c003319, 0x64353460, 0x35523b07, 0x21003b04,   // nn.sv.un_750 xh.zu.lg_664  so.ha.zu_432 so.jw.un_320 
  // [a220]
  0x373564a4, 0x293b6ba4, 0x6b693b0d, 0x64596a07,   // lg.zu.st_433 ceb.so.sl_433  so.mfe.ceb_554 haw.rn.lg_432 
  0x355534a0, 0x06464007, 0x1b3031a4, 0x645255a0,   // xh.rw.zu_322 lb.qu.de_432  az.uz.tr_433 rw.ha.lg_322 
  0x3b353455, 0x2500150e, 0x0b190a60, 0x1c0d5c13,   // xh.zu.so_442 un.mn.un_550  pt.gl.es_664 sa.ne.mr_665 
  0x28505509, 0x69003b13, 0x3b006912, 0x4a000d13,   // rw.fj.sw_444 so.mfe.un_650  mfe.so.un_640 cs.yo.un_650 
  // [a230]
  0x17040a08, 0x3b624555, 0x283b305a, 0x48353404,   // mk.ru.sr_443 ln.kha.so_442  uz.so.sw_553 xh.zu.tt_332 
  0x07083002, 0x34000f1b, 0x341d0255, 0x37007518,   // uz.uk.bg_222 lv.xh.un_770  da.la.xh_442 nso.st.un_740 
  0x7300470d, 0x53007308, 0x622e1ca4, 0x64005d1a,   // sn.ny.un_540 ny.ht.un_430  id.fo.kha_433 ss.lg.un_760 
  0x57784911, 0x2e0c330b, 0x330e2e12, 0x25001708,   // to.ve.na_653 nn.sv.fo_542  fo.is.nn_654 sr.mn.un_430 
  // [a240]
  0x2f1b31a6, 0x4e4b640c, 0x0e4d330c, 0x2f480ca0,   // az.tr.su_521 lg.mi.ay_543  nn.aa.is_543 sv.tt.su_322 
  0x35002209, 0x3500fc04, 0x1c2f1e08, 0x59536404,   // oc.zu.un_440 zzp.zu.un_320  ms.su.id_443 lg.ht.rn_332 
  0x330802ac, 0x0c003313, 0x23073004, 0x221556ee,   // da.no.nn_632 nn.sv.un_650  uz.bg.ky_332 mg.oc.un_420 
  0x59475512, 0x122d3902, 0x38004604, 0x431a6b13,   // rw.sn.rn_654 br.sk.hu_222  qu.tk.un_320 ceb.tl.ie_665 
  // [a250]
  0x392409a9, 0x30002907, 0x4a595513, 0x31000913,   // pl.eo.br_544 sl.uz.un_420  rw.rn.yo_665 pl.az.un_650 
  0x35003e04, 0x0c623311, 0x1a004a07, 0x46595513,   // rm.zu.un_320 nn.kha.sv_653  yo.tl.un_420 rw.rn.qu_665 
  0x39695604, 0x1d000713, 0x482304a0, 0x2f3f1cad,   // mg.mfe.br_332 it.la.un_650  ru.ky.tt_322 id.af.su_643 
  0x56004a07, 0x3f382c02, 0x09003e04, 0x6900790e,   // yo.mg.un_420 fy.tk.af_222  rm.pl.un_320 war.mfe.un_550 
  // [a260]
  0x33033f07, 0x040736a0, 0x483c370e, 0x10005008,   // af.nl.nn_432 ab.bg.ru_322  ba.ug.tt_555 fj.lt.un_430 
  0x5d2d0da7, 0x070817ee, 0x10536908, 0x36001112,   // cs.sk.ss_532 sr.uk.bg_422  mfe.ht.lt_443 ro.ab.un_640 
  0x34001212, 0x3e023504, 0x60000914, 0x03000609,   // ur.ps.un_640 zu.da.rm_332  pl.vo.un_660 de.nl.un_440 
  0x24000e07, 0x400306a0, 0x3b302902, 0x50005508,   // is.eo.un_420 de.nl.lb_322  sl.uz.so_222 rw.fj.un_430 
  // [a270]
  0x15000102, 0x03000613, 0x63007309, 0x13425604,   // en.un.un_220 de.nl.un_650  ny.sco.un_440 mg.co.et_332 
  0x50000704, 0x23002d02, 0x36220dee, 0x1a162102,   // it.fj.un_320 sk.ca.un_220  cs.oc.gn_422 jw.hr.tl_222 
  0x2d003904, 0x40221f08, 0x09394002, 0x035306a4,   // br.sk.un_320 cy.oc.lb_443  lb.br.pl_222 de.ht.nl_433 
  0x6b240a07, 0x30483f02, 0x48002d09, 0x4800560b,   // pt.eo.ceb_432 af.tt.uz_222  sk.tt.un_440 mg.tt.un_520 
  // [a280]
  0x12003304, 0x24033f02, 0x0b4319a0, 0x15003012,   // nn.hu.un_320 af.nl.eo_222  gl.ie.es_322 uz.un.un_640 
  0x42512608, 0x11003714, 0x17002d0d, 0x2d006304,   // ia.kl.co_443 ba.ro.un_660  sk.sr.un_540 sco.sk.un_320 
  0x0c2d1b08, 0x080717ee, 0x32030607, 0x133f030b,   // tr.sk.sv_443 sr.bg.uk_422  de.nl.bs_432 nl.af.et_542 
  0x57060107, 0x06fc0eac, 0x06025104, 0x39002102,   // en.de.na_432 is.zzp.de_632  kl.da.de_332 jw.br.un_220 
  // [a290]
  0x3544300d, 0x481535ad, 0x06002904, 0x0e333f07,   // uz.kk.tg_554 tg.tt.un_630  sl.de.un_320 af.nn.is_432 
  0x49000202, 0x605d01a4, 0x04064007, 0x7600601b,   // da.to.un_220 en.ss.vo_433  lb.de.fi_432 vo.crs.un_770 
  0x030efc04, 0x490756a0, 0x35041155, 0x49606707,   // zzp.is.nl_332 mg.it.to_322  ro.ru.tg_442 ak.vo.to_432 
  0x171507a0, 0x15040809, 0x1d1924a0, 0x11003604,   // bg.sr.un_320 uk.ru.un_444  eo.gl.la_322 gn.ro.un_320 
  // [a2a0]
  0x395645ee, 0x15384408, 0x52003805, 0x545e30a4,   // ln.mg.br_422 kk.tk.un_443  tk.ha.un_330 uz.ts.ik_433 
  0x243f1f07, 0x5a311005, 0x234437ee, 0x6300250d,   // cy.af.eo_432 lt.az.sm_333  ba.kk.ky_422 eu.sco.un_540 
  0x050465a7, 0x3c3d215a, 0x65046160, 0x1523170d,   // gv.fi.fr_532 fa.ku.ug_553  za.fi.gv_664 sr.ky.un_554 
  0x32000104, 0x15383c08, 0x17004804, 0x192565a0,   // en.bs.un_320 ug.tk.un_443  tt.sr.un_320 gv.eu.gl_322 
  // [a2b0]
  0x37332e05, 0x29375fad, 0x06fe5755, 0x016513a0,   // fo.nn.st_333 tn.st.sl_643  na.tlh.de_442 et.gv.en_322 
  0x2820360c, 0x4c4ffe0c, 0x17003007, 0x242206a0,   // gn.sq.sw_543 tlh.bi.wo_543  uz.sr.un_420 de.oc.eo_322 
  0x150f65ec, 0x300725a0, 0x133957ad, 0x30001b08,   // gv.lv.un_644 mn.bg.uz_322  na.br.et_643 tr.uz.un_430 
  0x111707a4, 0x04300707, 0x4a006821, 0x0d002012,   // bg.sr.ro_433 bg.uz.ru_432  ig.yo.un_860 sq.cs.un_640 
  // [a2c0]
  0x37005f21, 0x3e00fe0d, 0x012c3f04, 0x5f00fe1b,   // tn.st.un_860 tlh.rm.un_540  af.fy.en_332 tlh.tn.un_770 
  0x383124a4, 0x1f0742af, 0x56004904, 0x4a002305,   // eo.az.tk_433 co.it.cy_655  to.mg.un_320 ca.yo.un_330 
  0x37785e0d, 0x2747fe0c, 0x20005c09, 0x65000c09,   // ts.ve.st_554 tlh.sn.gd_543  sa.sq.un_440 sv.gv.un_440 
  0x5a043007, 0x277318a9, 0x470456a7, 0x18202712,   // uz.fi.sm_432 ga.ny.gd_544  mg.fi.sn_532 gd.sq.ga_654 
  // [a2d0]
  0x2b003504, 0x2b000407, 0x15001808, 0x39006402,   // zu.vi.un_320 fi.vi.un_420  ga.un.un_430 lg.br.un_220 
  0x38311bec, 0x0a080413, 0x213d23a0, 0x5e001c08,   // tr.az.tk_644 ru.uk.mk_665  ky.ku.fa_322 id.ts.un_430 
  0x3c3830a4, 0x330208ad, 0x7578010b, 0x0a0456ee,   // uz.tk.ug_433 no.da.nn_643  en.ve.nso_542 mg.fi.pt_422 
  0x040f56a4, 0x564904a0, 0x4557fc0b, 0x5f55370c,   // mg.lv.fi_433 fi.to.mg_322  zzp.na.ln_542 st.rw.tn_543 
  // [a2e0]
  0x250a08a0, 0x1b002508, 0x18021e12, 0x043725ee,   // uk.mk.mn_322 eu.tr.un_430  ms.da.ga_654 mn.ba.ru_422 
  0x34284e0c, 0xfc001504, 0x041117a4, 0x112301a0,   // ay.sw.xh_543 un.zzp.un_320  sr.ro.ru_433 en.ca.ro_322 
  0x28000d0d, 0xfc002904, 0x01000702, 0x151102a7,   // cs.sw.un_540 sl.zzp.un_320  it.en.un_220 da.ro.un_532 
  0x33080c09, 0x15040760, 0x3d3412a0, 0x2d001008,   // sv.no.nn_444 bg.ru.un_664  ur.ps.ku_322 lt.sk.un_430 
  // [a2f0]
  0x2ffc0cad, 0x1e000904, 0x21182807, 0x3e4015a0,   // sv.zzp.su_643 pl.ms.un_320  sd.ar.fa_432 un.lb.rm_322 
  0x173c30a7, 0x190b1d0c, 0x11001502, 0x0e2e35ac,   // uz.ug.sr_532 la.es.gl_543  un.ro.un_220 tg.lif.te_632 
  0x170a3011, 0x2d0d17a9, 0x0c12fcec, 0x480407a4,   // uz.mk.sr_653 sr.cs.sk_544  zzp.hu.sv_644 bg.ru.tt_433 
  0x120c4804, 0xfc69760d, 0x37114804, 0x36001113,   // tt.sv.hu_332 crs.mfe.zzp_554  tt.ro.ba_332 ro.ab.un_650 
  // [a300]
  0x3f001802, 0x03001508, 0x38071508, 0x0e00330d,   // ga.af.un_220 un.nl.un_430  un.bg.tk_443 nn.is.un_540 
  0x52002a13, 0x33002e19, 0x2a00fe13, 0xfe002a19,   // mt.ha.un_650 fo.nn.un_750  tlh.mt.un_650 mt.tlh.un_750 
  0x2e222305, 0x1e003102, 0x05002a07, 0x2a00fe14,   // ca.oc.fo_333 az.ms.un_220  mt.fr.un_420 tlh.mt.un_660 
  0x2e0c3307, 0x08001707, 0x2b002a07, 0xfe002a0c,   // nn.sv.fo_432 sr.uk.un_420  mt.vi.un_420 mt.tlh.un_530 
  // [a310]
  0x25353060, 0xfe2a2313, 0x16fe2a12, 0x08111555,   // uz.tg.mn_664 ca.mt.tlh_665  mt.tlh.hr_654 un.ro.uk_442 
  0x30fe2a12, 0x153c360c, 0x2d0d3f5a, 0x655a1812,   // mt.tlh.uz_654 ab.ug.un_543  af.cs.sk_553 ga.sm.gv_654 
  0x480810a0, 0x10000707, 0x18652504, 0x2d2c0107,   // be.uk.tt_322 bg.be.un_420  eu.gv.ga_332 en.fy.sk_432 
  0x40051804, 0x044817a0, 0x30103507, 0x04001804,   // ga.fr.lb_332 sr.tt.ru_322  tg.be.uz_432 ga.fi.un_320 
  // [a320]
  0x30343da9, 0x183d3b04, 0x636579a9, 0x5f000202,   // ku.ps.uz_544 ks.ku.ar_332  war.gv.sco_544 da.tn.un_220 
  0x2f211c0c, 0x151806a4, 0x330204ee, 0x58fc5ca0,   // id.jw.su_543 de.ga.un_433  fi.da.nn_422 sa.zzp.om_322 
  0x301504a4, 0x133f24ee, 0x18283b0c, 0x2812340d,   // ru.uz.un_430 eo.af.et_422  ks.sd.ar_543 ps.ur.sd_554 
  0x0c080213, 0x34313504, 0x6b631dee, 0x352859a7,   // da.no.sv_665 zu.az.xh_332  la.sco.ceb_422 rn.sw.zu_532 
  // [a330]
  0xfc006a09, 0x5e00340d, 0x344428a0, 0x47006502,   // haw.zzp.un_440 xh.ts.un_540  sd.kk.ps_322 gv.sn.un_220 
  0x102c2e09, 0x2337480b, 0x09041007, 0x04081104,   // fo.fy.lt_444 tt.ba.ky_542  lt.fi.pl_432 ro.uk.ru_332 
  0x0a351755, 0x4b001809, 0x0f1729a0, 0x21502fa4,   // sr.tg.mk_442 ga.mi.un_440  sl.sr.lv_322 su.fj.jw_433 
  0x11055208, 0x10693812, 0x4b005a02, 0x1e1c4209,   // ha.fr.ro_443 tk.mfe.lt_654  sm.mi.un_220 co.id.ms_444 
  // [a340]
  0x100409a7, 0x36190b12, 0xfe311b02, 0x27185aa4,   // pl.fi.lt_532 es.gl.gn_654  tr.az.tlh_222 sm.ga.gd_433 
  0x63003608, 0x0900560d, 0x30480aec, 0x093810a9,   // gn.sco.un_430 mg.pl.un_540  mk.tt.uz_644 lt.tk.pl_544 
  0x10006112, 0x17104408, 0x11303512, 0x290cfe0c,   // za.lt.un_640 kk.be.sr_443  tg.uz.ro_654 tlh.sv.sl_543 
  0x392d0d05, 0xfe002919, 0x524830a0, 0x3f032da4,   // cs.sk.br_333 sl.tlh.un_750  uz.tt.ha_322 sk.nl.af_433 
  // [a350]
  0x18004b12, 0x04001318, 0x062d0d08, 0x0432130c,   // mi.ga.un_640 et.fi.un_740  cs.sk.de_443 et.bs.fi_543 
  0x0413fe12, 0x2d0d17a0, 0x27004b23, 0x1e292d07,   // tlh.et.fi_654 sr.cs.sk_322  mi.gd.un_880 sk.sl.ms_432 
  0x73002805, 0x3f002d07, 0x6a02450c, 0x6467450c,   // sw.ny.un_330 sk.af.un_420  ln.da.haw_543 ln.ak.lg_543 
  0x1d3e2607, 0x381b30a7, 0x2000450d, 0x33001109,   // ia.rm.la_432 uz.tr.tk_532  ln.sq.un_540 ro.nn.un_440 
  // [a360]
  0x0a2326ee, 0x2d002a08, 0x47005102, 0x300e2ea9,   // ia.ca.pt_422 mt.sk.un_430  kl.sn.un_220 fo.is.uz_544 
  0x330830a9, 0x1d001f0d, 0x29092dee, 0x30000d09,   // uz.no.nn_544 cy.la.un_540  sk.pl.sl_422 cs.uz.un_440 
  0x3f002402, 0x093f2da0, 0x421d1da4, 0x0d001c11,   // eo.af.un_220 sk.af.pl_322  la.la.co_433 mr.ne.un_630 
  0x2d291605, 0x5c565104, 0x06031507, 0x383031a7,   // hr.sl.sk_333 kl.mg.sa_332  un.nl.de_432 az.uz.tk_532 
  // [a370]
  0x29173fa4, 0x2d2e09a7, 0x070a15a7, 0x1025480c,   // af.sr.sl_433 pl.fo.sk_532  un.mk.bg_532 tt.mn.be_543 
  0x5a000c02, 0x402855a4, 0x30000207, 0x03025cee,   // sv.sm.un_220 rw.sw.lb_433  da.uz.un_420 sa.da.nl_422 
  0x28183ca4, 0x1800100c, 0x105c1507, 0x1f00100b,   // ug.ar.sd_433 lt.ga.un_530  un.sa.lt_432 lt.cy.un_520 
  0x3f003805, 0x05000a02, 0x1823440d, 0x35340205,   // tk.af.un_330 pt.fr.un_220  kk.ky.ar_554 da.xh.zu_333 
  // [a380]
  0x2d101fa0, 0x210568a7, 0x020c4ca0, 0x30073712,   // cy.lt.sk_322 ig.fr.jw_532  wo.sv.da_322 ba.bg.uz_654 
  0x1500112a, 0x1d001002, 0x170425a7, 0x30213ca4,   // ro.un.un_970 lt.la.un_220  mn.ru.sr_532 ug.fa.uz_433 
  0x15353009, 0x271b01a0, 0x650542a4, 0x1f000404,   // uz.tg.un_444 en.tr.gd_322  co.fr.gv_433 fi.cy.un_320 
  0x00001e2d, 0x4300020d, 0x2173610c, 0x250a48a0,   // am.un.un_A00 da.ie.un_540  za.ny.jw_543 tt.mk.mn_322 
  // [a390]
  0x3948540c, 0x12362fec, 0x281234a7, 0x291805a6,   // ik.tt.br_543 su.gn.hu_644  ps.ur.sd_532 fr.ga.sl_521 
  0x05001107, 0x37002b04, 0x0a04150d, 0x283412a9,   // ro.fr.un_420 vi.st.un_320  un.ru.mk_554 ur.ps.sd_544 
  0x1a004802, 0x1015370c, 0x05000d02, 0x18342102,   // tt.tl.un_220 ba.be.un_530  cs.fr.un_220 fa.ps.ar_222 
  0x42400b04, 0x2d000e09, 0x23081504, 0x21002402,   // es.lb.co_332 is.sk.un_440  un.uk.ky_332 eo.jw.un_220 
  // [a3a0]
  0x2f001c0c, 0x5f4830ad, 0x483b34a9, 0x11007304,   // id.su.un_530 uz.tt.tn_643  xh.so.tt_544 ny.ro.un_320 
  0x1300fc14, 0x3f000502, 0x31304808, 0x0d5c1c11,   // zzp.et.un_660 fr.af.un_220  tt.uz.az_443 mr.sa.ne_653 
  0x3f2163a6, 0x213428a0, 0x79003819, 0x391024a7,   // sco.jw.af_521 sd.ps.fa_322  tk.war.un_750 eo.lt.br_532 
  0x185930a6, 0x2e2a0207, 0x483830af, 0x22003304,   // uz.rn.ga_521 da.mt.fo_432  uz.tk.tt_655 nn.oc.un_320 
  // [a3b0]
  0x313830af, 0x2600101a, 0xfc562607, 0x3e0742a4,   // uz.tk.az_655 lt.ia.un_760  ia.mg.zzp_432 co.it.rm_433 
  0x241e1c05, 0x20491004, 0x20005619, 0x13003002,   // id.ms.eo_333 lt.to.sq_332  mg.sq.un_750 uz.et.un_220 
  0x103e26a4, 0x07421007, 0x08000212, 0x4e1e1c14,   // ia.rm.lt_433 lt.co.it_432  da.no.un_640 id.ms.ay_666 
  0x13503604, 0xfc102da4, 0x180e2e07, 0x5100260e,   // gn.fj.et_332 sk.lt.zzp_433  fo.is.ga_432 ia.kl.un_550 
  // [a3c0]
  0x420413a0, 0x0a15070d, 0x23151004, 0x35003023,   // et.fi.co_322 bg.mk.un_540  be.ky.un_320 uz.tg.un_880 
  0x3100461a, 0x07083708, 0x095c0daf, 0x483146ee,   // qu.az.un_760 ba.uk.bg_443  ne.sa.hi_655 qu.az.tt_422 
  0x07170a60, 0x4e1e1c13, 0x3837480c, 0x0f00290e,   // mk.sr.bg_664 id.ms.ay_665  tt.ba.tk_543 sl.lv.un_550 
  0x12000f04, 0x3c1710ad, 0x243935a0, 0x2807420c,   // lv.hu.un_320 be.sr.ug_643  zu.br.eo_322 co.it.sw_543 
  // [a3d0]
  0x124f65ee, 0x2418270c, 0x09007822, 0x06080204,   // gv.bi.hu_422 gd.ga.eo_543  ve.pl.un_870 da.no.de_332 
  0x39001504, 0x5c1c0912, 0x11000104, 0x08021bee,   // un.br.un_320 hi.mr.sa_654  en.ro.un_320 tr.da.no_422 
  0x33080c0b, 0x121809ee, 0x2a074213, 0x1a0d24a0,   // sv.no.nn_542 pl.ga.hu_422  co.it.mt_665 eo.cs.tl_322 
  0x23001907, 0x3300510d, 0x064f57ec, 0x231d0304,   // gl.ca.un_420 kl.nn.un_540  na.bi.de_644 nl.la.ca_332 
  // [a3e0]
  0x2403090b, 0x2c002904, 0x09001222, 0x123b3ea0,   // pl.nl.eo_542 sl.fy.un_320  hu.pl.un_870 rm.so.hu_322 
  0x10000307, 0x5c3b10ad, 0x39fc1da6, 0x48045b07,   // nl.lt.un_420 lt.so.sa_643  la.zzp.br_521 sg.fi.tt_432 
  0x152518ad, 0x4a3148a9, 0x10150408, 0x2a000f02,   // ga.eu.un_643 tt.az.yo_544  ru.be.un_430 lv.mt.un_220 
  0x0e2e3804, 0x55006307, 0x2e520e08, 0x0c03fe07,   // tk.fo.is_332 sco.rw.un_420  is.ha.fo_443 tlh.nl.sv_432 
  // [a3f0]
  0x4c205b08, 0x0c1d400c, 0x52003313, 0x38002905,   // sg.sq.wo_443 lb.la.sv_543  nn.ha.un_650 sl.tk.un_330 
  0x0e0c1f0c, 0x092d0d13, 0x2527185a, 0x444838a7,   // cy.sv.is_543 cs.sk.pl_665  ga.gd.eu_553 tk.tt.kk_532 
  0x30000407, 0x320d2da0, 0x15080407, 0x26002713,   // ru.uz.un_420 sk.cs.bs_322  ru.uk.un_432 gd.ia.un_650 
  0x3e0b3307, 0x4c383ea0, 0x211c2f04, 0x2a003104,   // nn.es.rm_432 rm.tk.wo_322  su.id.jw_332 az.mt.un_320 
  
  // [a400]
  0x082315a0, 0x071704a0, 0x04386502, 0x2a001302,   // un.ky.uk_322 ru.sr.bg_322  gv.tk.fi_222 et.mt.un_220 
  0x2330170c, 0x0a1723a9, 0x0710080c, 0x21343b55,   // sr.uz.ky_543 ky.sr.mk_544  uk.be.bg_543 ks.ps.fa_442 
  0x652547a4, 0x2d290da4, 0xfe006e22, 0x13001207,   // sn.eu.gv_433 cs.sl.sk_433  hmn.tlh.un_870 hu.et.un_420 
  0x043c350c, 0x5efc0102, 0x1748370c, 0x2b190fa0,   // tg.ug.ru_543 en.zzp.ts_222  ba.tt.sr_543 lv.gl.vi_322 
  // [a410]
  0x38004f36, 0x482b62a9, 0x624c2008, 0x28343004,   // bi.tk.un_AA0 kha.vi.tt_544  sq.wo.kha_443 uz.ps.sd_332 
  0x24694313, 0x11170aaf, 0x62004d23, 0x0a4f12ad,   // ie.mfe.eo_665 mk.sr.ro_655  aa.kha.un_880 hu.bi.pt_643 
  0x1b6e620c, 0x4006080c, 0x40481807, 0x1d353409,   // kha.hmn.tr_543 no.de.lb_543  ga.tt.lb_432 xh.zu.la_444 
  0x0f006e0d, 0x6e4c6908, 0x641a1ca4, 0x0a1730ec,   // hmn.lv.un_540 mfe.wo.hmn_443  id.tl.lg_433 uz.sr.mk_644 
  // [a420]
  0x1d004022, 0x04480704, 0x290e0d0b, 0x1a241b09,   // lb.la.un_870 bg.tt.ru_332  cs.is.sl_542 tr.eo.tl_444 
  0x4ffe6e13, 0x0c0a2913, 0x73346b08, 0x5306fe07,   // hmn.tlh.bi_665 sl.pt.sv_665  ceb.xh.ny_443 tlh.de.ht_432 
  0xfe001d08, 0x29000a2c, 0x35423404, 0x10074407,   // la.tlh.un_430 pt.sl.un_990  xh.co.zu_332 kk.bg.be_432 
  0x34733504, 0x0943010c, 0x1d00fe0e, 0x135a0aa0,   // zu.ny.xh_332 en.ie.pl_543  tlh.la.un_550 pt.sm.et_322 
  // [a430]
  0x504301a0, 0x73284604, 0x09001318, 0x31005e0e,   // en.ie.fj_322 qu.sw.ny_332  bh.hi.un_740 ts.az.un_550 
  0x735e78af, 0x48080a04, 0x34001c04, 0x0708175a,   // ve.ts.ny_655 mk.uk.tt_332  id.xh.un_320 sr.uk.bg_553 
  0x08231702, 0x37303407, 0x0a221d07, 0x3d3b21a4,   // sr.ky.uk_222 xh.uz.st_432  la.oc.pt_432 fa.ks.ku_433 
  0x040710ee, 0x183d2308, 0x6a005c1a, 0x352530a4,   // be.bg.ru_422 ky.ku.ar_443  sa.haw.un_760 uz.mn.tg_433 
  // [a440]
  0x353015a0, 0x0708105a, 0x256b4b07, 0x38001f02,   // un.uz.tg_322 be.uk.bg_553  mi.ceb.eu_432 cy.tk.un_220 
  0x64004a09, 0x1c001e2a, 0x735a4a08, 0x35360a07,   // yo.lg.un_440 ms.id.un_970  yo.sm.ny_443 mk.ab.tg_432 
  0x0f350ca7, 0x37732104, 0x5f496a07, 0x5a375f08,   // sv.zu.lv_532 jw.ny.st_332  haw.to.tn_432 tn.st.sm_443 
  0x52000422, 0x170711ee, 0x213428a4, 0x5c090d60,   // fi.ha.un_870 ro.bg.sr_422  sd.ps.fa_433 ne.hi.sa_664 
  // [a450]
  0x75006822, 0x5c005f04, 0x49005e22, 0x55006b0e,   // ig.nso.un_870 tn.sa.un_320  ts.to.un_870 ceb.rw.un_550 
  0x4b002b0e, 0x0a630704, 0x2451020c, 0x56003502,   // vi.mi.un_550 it.sco.pt_332  da.kl.eo_543 zu.mg.un_220 
  0xfe6301a0, 0x5e545c55, 0x20475c12, 0x0c025207,   // en.sco.tlh_322 sa.ik.ts_442  sa.sn.sq_654 ha.da.sv_432 
  0x4500672b, 0x36383ca4, 0x13204608, 0x2e245caf,   // ak.ln.un_980 ug.tk.ab_433  qu.sq.et_443 sa.eo.fo_655 
  // [a460]
  0x5e042ea4, 0x255f37a4, 0x5130fc02, 0x450f4bec,   // fo.fi.ts_433 st.tn.eu_433  zzp.uz.kl_222 mi.lv.ln_644 
  0x375f2408, 0x5a1a79a0, 0x5c65300b, 0xfc0630a6,   // eo.tn.st_443 war.tl.sm_322  uz.gv.sa_542 uz.de.zzp_521 
  0x07253c0c, 0x08100709, 0x34303bee, 0x314830a4,   // ug.mn.bg_543 bg.be.uk_444  ks.uz.ps_422 uz.tt.az_433 
  0x20002907, 0x3f0306a0, 0x02006504, 0x065e7908,   // sl.sq.un_420 de.nl.af_322  gv.da.un_320 war.ts.de_443 
  // [a470]
  0x384448a4, 0x6527fca4, 0x03785ca4, 0x220631ee,   // tt.kk.tk_433 zzp.gd.gv_433  sa.ve.nl_433 az.de.oc_422 
  0x634301a4, 0x1d2c1ca4, 0x34330808, 0x24005302,   // en.ie.sco_433 id.fy.la_433  no.nn.xh_443 ht.eo.un_220 
  0x2f190a02, 0x1f152705, 0x3c184404, 0x30653811,   // pt.gl.su_222 gd.cy.un_330  kk.ar.ug_332 tk.gv.uz_653 
  0x2601270c, 0x48313010, 0x27002c33, 0x383048a4,   // gd.en.ia_543 uz.az.tt_642  fy.gd.un_A70 tt.uz.tk_433 
  // [a480]
  0x0306fca7, 0x06180107, 0x18003c09, 0x18650cee,   // zzp.de.nl_532 en.ga.de_432  ug.ar.un_440 sv.gv.ga_422 
  0x5727185a, 0x21301213, 0x191d2707, 0x2c001818,   // ga.gd.na_553 ur.uz.fa_665  gd.la.gl_432 ga.fy.un_740 
  0x38251560, 0x2c18270c, 0x432c2708, 0x11004821,   // un.mn.tk_664 gd.ga.fy_543  gd.fy.ie_443 tt.ro.un_860 
  0x34002504, 0x0655590c, 0x63000123, 0x43002705,   // eu.xh.un_320 rn.rw.de_543  en.sco.un_880 gd.ie.un_330 
  // [a490]
  0xfc00090e, 0x33001207, 0xfc080255, 0x48001b1a,   // pl.zzp.un_550 hu.nn.un_420  da.no.zzp_442 tr.tt.un_760 
  0x27150112, 0x53641b04, 0x63182711, 0x1a3179a4,   // en.gd.un_640 tr.lg.ht_332  gd.ga.sco_653 war.az.tl_433 
  0x22156304, 0x522d0da4, 0x5e004004, 0x024549ec,   // sco.oc.un_320 cs.sk.ha_433  lb.ts.un_320 to.ln.da_644 
  0x18653ea0, 0x28364cad, 0x5a497609, 0x1e026408,   // rm.gv.ga_322 wo.gn.sw_643  crs.to.sm_444 lg.da.ms_443 
  // [a4a0]
  0x27630aa4, 0x460253a9, 0x0b1827a0, 0x63012708,   // pt.sco.gd_433 ht.da.qu_544  gd.ga.es_322 gd.en.sco_443 
  0x5a5639ee, 0x30002804, 0x5c791205, 0x18123402,   // br.mg.sm_422 sw.uz.un_320  hu.war.sa_333 ps.ur.ar_222 
  0x3b646b0c, 0x0830350c, 0x553b64ee, 0x1d005505,   // ceb.lg.so_543 tg.uz.uk_543  lg.so.rw_422 rw.la.un_330 
  0x735953a0, 0x1200150d, 0x73593004, 0x1b697609,   // ht.rn.ny_322 un.hu.un_540  uz.rn.ny_332 crs.mfe.tr_444 
  // [a4b0]
  0x3d343bad, 0x58004d0e, 0x01007508, 0x482a3b0d,   // ks.ps.ku_643 aa.om.un_550  nso.en.un_430 so.mt.tt_554 
  0x5369760e, 0x477367a9, 0x07231004, 0x531a020c,   // crs.mfe.ht_555 ak.ny.sn_544  be.ky.bg_332 da.tl.ht_543 
  0x50495a0d, 0x4e0438ad, 0x25443705, 0x3d2112ac,   // sm.to.fj_554 tk.fi.ay_643  ba.kk.mn_333 ur.fa.ku_632 
  0x15002908, 0x30005202, 0x42305b07, 0x3600200c,   // sl.un.un_430 ha.uz.un_220  sg.uz.co_432 sq.gn.un_530 
  // [a4c0]
  0x100f5cad, 0x441038a9, 0x150444ec, 0x374838a9,   // sa.lv.lt_643 tk.be.kk_544  kk.ru.un_644 tk.tt.ba_544 
  0x303647a4, 0x5a02360b, 0x3037360c, 0x385e3604,   // sn.gn.uz_433 gn.da.sm_542  ab.ba.uz_543 gn.ts.tk_332 
  0x1504070b, 0x044808a0, 0x28122109, 0x07001113,   // bg.ru.un_542 uk.tt.ru_322  fa.ur.sd_444 ro.bg.un_650 
  0x4200220b, 0x0d091cee, 0x211e56a4, 0x51002820,   // oc.co.un_520 mr.hi.ne_422  mg.ms.jw_433 sw.kl.un_850 
  // [a4d0]
  0x25234408, 0x56000922, 0x4437485a, 0x042e1004,   // kk.ky.mn_443 pl.mg.un_870  tt.ba.kk_553 lt.fo.fi_332 
  0x561012a4, 0x28001307, 0x045113a4, 0x6e07090b,   // hu.lt.mg_433 et.sw.un_420  et.kl.fi_433 pl.it.hmn_542 
  0x56003e08, 0x656b3eec, 0x643647a4, 0x6e006519,   // rm.mg.un_430 rm.ceb.gv_644  sn.gn.lg_433 gv.hmn.un_750 
  0x0423150b, 0x42071205, 0x28491e12, 0x0c333902,   // un.ky.ru_542 hu.it.co_333  ms.to.sw_654 br.nn.sv_222 
  // [a4e0]
  0x560709a4, 0x25190b08, 0x481737a4, 0x0a001718,   // pl.it.mg_433 es.gl.eu_443  ba.sr.tt_433 sr.mk.un_740 
  0x3c2511a9, 0x122f0555, 0x21004602, 0x420d05ee,   // ro.mn.ug_544 fr.su.hu_442  qu.jw.un_220 fr.cs.co_422 
  0x12000513, 0x083035a0, 0x091c13a7, 0x222f0504,   // fr.hu.un_650 tg.uz.uk_322  bh.mr.hi_532 fr.su.oc_332 
  0x30381505, 0x5c272104, 0x46003902, 0x11070aaf,   // un.tk.uz_333 jw.gd.sa_332  br.qu.un_220 mk.bg.ro_655 
  // [a4f0]
  0x233830a4, 0x0500120c, 0x1200050c, 0x0c3ffc07,   // uz.tk.ky_433 hu.fr.un_530  fr.hu.un_530 zzp.af.sv_432 
  0x18007911, 0x4f79010c, 0x0d12050c, 0x05000a14,   // war.ga.un_630 en.war.bi_543  fr.hu.cs_543 pt.fr.un_660 
  0xfc383012, 0x176a470c, 0xfc0f1008, 0x2d000e05,   // uz.tk.zzp_654 sn.haw.sr_543  lt.lv.zzp_443 is.sk.un_330 
  0x22004e0c, 0x39001f08, 0x1e1c1a09, 0x79032ca4,   // ay.oc.un_530 cy.br.un_430  tl.id.ms_444 fy.nl.war_433 
  // [a500]
  0x08022802, 0x1e005c08, 0x5a00250c, 0x5c00760c,   // sw.da.no_222 sa.ms.un_430  eu.sm.un_530 crs.sa.un_530 
  0x3000fc02, 0x27001113, 0x102a3f05, 0x2f002109,   // zzp.uz.un_220 ro.gd.un_650  af.mt.lt_333 jw.su.un_440 
  0x281d4d07, 0x48122ca0, 0x351515a6, 0x1e0673ee,   // aa.la.sw_432 fy.hu.tt_322  un.tg.un_510 ny.de.ms_422 
  0x13000504, 0x2e5221ec, 0x09000f0e, 0x23182ea7,   // fr.et.un_320 jw.ha.fo_644  lv.pl.un_550 fo.ga.ca_532 
  // [a510]
  0x21004611, 0x3e2618ad, 0x07fc3b05, 0xfc3f0308,   // qu.jw.un_630 ga.ia.rm_643  so.zzp.it_333 nl.af.zzp_443 
  0x08351702, 0x73375f0c, 0x51fc330c, 0x081007a9,   // sr.tg.uk_222 tn.st.ny_543  nn.zzp.kl_543 bg.be.uk_544 
  0x3000540d, 0x2f182ea9, 0x5a361a05, 0x36210505,   // ik.uz.un_540 fo.ga.su_544  tl.gn.sm_333 fr.jw.gn_333 
  0x2f450507, 0x3b001812, 0xfc021faf, 0x3e00020d,   // fr.ln.su_432 ga.so.un_640  cy.da.zzp_655 da.rm.un_540 
  // [a520]
  0x796b0313, 0x281834a7, 0x20006e09, 0x1945050c,   // nl.ceb.war_665 ps.ar.sd_532  hmn.sq.un_440 fr.ln.gl_543 
  0x0e182e13, 0x2d006008, 0x4a42050c, 0x20002419,   // fo.ga.is_665 vo.sk.un_430  fr.co.yo_543 eo.sq.un_750 
  0x3c4830ad, 0x631f4da4, 0x3e184305, 0x18005504,   // uz.tt.ug_643 aa.cy.sco_433  ie.ga.rm_333 rw.ga.un_320 
  0x18233c09, 0x42361207, 0x2f052111, 0x30001013,   // ug.ky.ar_444 hu.gn.co_432  jw.fr.su_653 be.uz.un_650 
  // [a530]
  0x02003807, 0x33021002, 0x332d3fee, 0x20002414,   // tk.da.un_420 lt.da.nn_222  af.sk.nn_422 eo.sq.un_660 
  0x3418280d, 0x5a00180d, 0x28006a21, 0x6a182712,   // sd.ar.ps_554 ga.sm.un_540  haw.sw.un_860 gd.ga.haw_654 
  0x4b002804, 0x18005a08, 0x3b1234ad, 0x18005a0c,   // sw.mi.un_320 sm.ga.un_430  ps.ur.ks_643 sm.ga.un_530 
  0x051236a0, 0x15353709, 0x36051905, 0x1d4c12a0,   // gn.hu.fr_322 ba.tg.un_444  gl.fr.gn_333 hu.wo.la_322 
  // [a540]
  0x330851ee, 0x343d120c, 0x3d18210b, 0x480a30ec,   // kl.no.nn_422 ur.ku.ps_543  fa.ar.ku_542 uz.mk.tt_644 
  0x5a001802, 0x19002d0c, 0x2d052f04, 0x0a000504,   // ga.sm.un_220 sk.gl.un_530  su.fr.sk_332 fr.pt.un_320 
  0x2f79fca4, 0x5900fc13, 0x040738a0, 0x045c3802,   // zzp.war.su_433 zzp.rn.un_650  tk.bg.ru_322 tk.sa.fi_222 
  0x561e380e, 0x55fc46ad, 0x34fc2ca0, 0x0500221b,   // tk.ms.mg_555 qu.zzp.rw_643  fy.zzp.xh_322 oc.fr.un_770 
  // [a550]
  0x34fc3702, 0x0a361907, 0x5c382f02, 0x2f191202,   // st.zzp.xh_222 gl.gn.pt_432  su.tk.sa_222 hu.gl.su_222 
  0x28121812, 0x2e001b08, 0x2c000507, 0x47554a11,   // ar.ur.sd_654 tr.fo.un_430  fr.fy.un_420 yo.rw.sn_653 
  0x6e375f12, 0x672f36a4, 0xfc5d35a0, 0x21281212,   // tn.st.hmn_654 gn.su.ak_433  zu.ss.zzp_322 ur.sd.fa_654 
  0x15352555, 0x223619a4, 0x69002019, 0x0e122c04,   // mn.tg.un_442 gl.gn.oc_433  sq.mfe.un_750 fy.hu.is_332 
  // [a560]
  0x48153cad, 0x2d5a4c02, 0x12282309, 0x02003f0c,   // ug.tt.un_630 wo.sm.sk_222  ky.sd.ur_444 af.da.un_530 
  0x2d020d0c, 0x481b31a0, 0x123d21a9, 0x42001114,   // cs.da.sk_543 az.tr.tt_322  fa.ku.ur_544 ro.co.un_660 
  0x12002d1a, 0x5e00060e, 0x4e313060, 0x0e002d08,   // sk.hu.un_760 de.ts.un_550  uz.az.ay_664 sk.is.un_430 
  0x37007523, 0x331f0cec, 0x3f002114, 0x354728a4,   // nso.st.un_880 sv.cy.nn_644  jw.af.un_660 sw.sn.zu_433 
  // [a570]
  0x100d0902, 0x0605190c, 0x20002307, 0x05003902,   // pl.cs.lt_222 gl.fr.de_543  ca.sq.un_420 br.fr.un_220 
  0x4e481908, 0x4a560d0b, 0x2d000508, 0x04000a09,   // gl.tt.ay_443 cs.mg.yo_542  fr.sk.un_430 mk.ru.un_440 
  0x50004a05, 0x6b6826ee, 0x23004822, 0x1200250d,   // yo.fj.un_330 ia.ig.ceb_422  tt.ky.un_870 eu.hu.un_540 
  0x103c30ee, 0x44381708, 0x0a2d05a9, 0x0500450c,   // uz.ug.be_422 sr.tk.kk_443  fr.sk.pt_544 ln.fr.un_530 
  // [a580]
  0x1b00fc04, 0x5628730c, 0x4a3673a4, 0x131c5c04,   // zzp.tr.un_320 ny.sw.mg_543  ny.gn.yo_433 sa.mr.bh_332 
  0x5c1a5607, 0x4a284902, 0x25001212, 0x10111508,   // mg.tl.sa_432 to.sw.yo_222  hu.eu.un_640 un.ro.be_443 
  0x5c5904ee, 0x135c0d07, 0x18472804, 0x24000708,   // fi.rn.sa_422 ne.sa.bh_432  sw.sn.ga_332 it.eo.un_430 
  0x3e3952ee, 0x2e0e2c08, 0x373c4412, 0x36595508,   // ha.br.rm_422 fy.is.fo_443  kk.ug.ba_654 rw.rn.gn_443 
  // [a590]
  0x130442ee, 0x47095c05, 0x120e2aa0, 0x433e46ec,   // co.fi.et_422 sa.pl.sn_333  mt.is.hu_322 qu.rm.ie_644 
  0x3e002804, 0x125c6407, 0x171508a0, 0x36002204,   // sw.rm.un_320 lg.sa.hu_432  uk.sr.un_320 oc.gn.un_320 
  0x27007821, 0x276528a7, 0x0f002007, 0x2e0e12ee,   // ve.gd.un_860 sw.gv.gd_532  sq.lv.un_420 hu.is.fo_422 
  0x39004012, 0x4cfe305a, 0x026447a7, 0x37233005,   // lb.br.un_640 uz.tlh.wo_553  sn.lg.da_532 uz.ky.ba_333 
  // [a5a0]
  0x24284707, 0x531219a0, 0x0400730c, 0x3c3723a4,   // sn.sw.eo_432 gl.hu.ht_322  ny.fi.un_530 ky.ba.ug_433 
  0x35303c08, 0x5c2765a4, 0x5f1d01a4, 0x444823a9,   // ug.uz.tg_443 gv.gd.sa_433  en.la.tn_433 ky.tt.kk_544 
  0x650b630c, 0x3c4837a9, 0x5c131ca4, 0x65272012,   // sco.es.gv_543 ba.tt.ug_544  mr.bh.sa_433 sq.gd.gv_654 
  0x12222307, 0x282d590e, 0x36001211, 0x182821a4,   // ca.oc.hu_432 rn.sk.sw_555  hu.gn.un_630 fa.sd.ar_433 
  // [a5b0]
  0x0413290c, 0x37041505, 0x2f001212, 0x0d1c5ca6,   // sl.et.fi_543 un.ru.ba_333  hu.su.un_640 sa.mr.ne_521 
  0x0e00330b, 0x100a1755, 0x1f000c04, 0x251130ad,   // nn.is.un_520 sr.mk.be_442  sv.cy.un_320 uz.ro.mn_643 
  0x0e0c3307, 0x2440060c, 0x0b4c120b, 0x170a0812,   // nn.sv.is_432 de.lb.eo_543  hu.wo.es_542 uk.mk.sr_654 
  0x2e0e2c0d, 0x15253004, 0x0b001b08, 0x31002e02,   // fy.is.fo_554 uz.mn.un_332  tr.es.un_430 fo.az.un_220 
  // [a5c0]
  0x39001602, 0x4800110c, 0x190b33a0, 0x05002214,   // hr.br.un_220 ro.tt.un_530  nn.es.gl_322 oc.fr.un_660 
  0x651f2707, 0x22420508, 0x480738ac, 0x0a000e05,   // gd.cy.gv_432 fr.co.oc_443  tk.bg.tt_632 is.pt.un_330 
  0x5f007521, 0x044815ad, 0x055647a7, 0x1500070e,   // nso.tn.un_860 un.tt.ru_643  sn.mg.fr_532 bg.un.un_550 
  0x200709a7, 0x5c0d0912, 0x0a080408, 0x3c3815a4,   // pl.it.sq_532 hi.ne.sa_654  ru.uk.mk_443 un.tk.ug_433 
  // [a5d0]
  0x4800151b, 0x28341807, 0x08006705, 0x00005837,   // un.tt.un_770 ar.ps.sd_432  ak.no.un_330 om.un.un_B00 
  0x0c0249a7, 0x4830370c, 0x2e00640b, 0x02006007,   // to.da.sv_532 ba.uz.tt_543  lg.fo.un_520 vo.da.un_420 
  0x3500111a, 0x230738a7, 0xfc007311, 0x30004412,   // ro.tg.un_760 tk.bg.ky_532  ny.zzp.un_630 kk.uz.un_640 
  0x272160ee, 0x76690309, 0x48004404, 0x375f05a4,   // vo.jw.gd_422 nl.mfe.crs_444  kk.tt.un_320 fr.tn.st_433 
  // [a5e0]
  0x2d0dfc09, 0x08006708, 0x0d001707, 0x13001005,   // zzp.cs.sk_444 ak.no.un_430  sr.cs.un_420 lt.et.un_330 
  0x2a003902, 0x2e0c0e0c, 0x37005f12, 0x33083805,   // br.mt.un_220 is.sv.fo_543  tn.st.un_640 tk.no.nn_333 
  0x253036ee, 0x5c00fe08, 0x09365708, 0x20003f04,   // ab.uz.mn_422 tlh.sa.un_430  na.gn.pl_443 af.sq.un_320 
  0x794b2fec, 0x1600240b, 0x10002e04, 0x15380304,   // su.mi.war_644 eo.hr.un_520  fo.lt.un_320 nl.tk.un_332 
  // [a5f0]
  0x33082002, 0x1955580c, 0x56003913, 0x2c000319,   // sq.no.nn_222 om.rw.gl_543  br.mg.un_650 nl.fy.un_750 
  0x28213407, 0x0f00fe0e, 0x3e562808, 0x0c004c1a,   // ps.fa.sd_432 tlh.lv.un_550  sw.mg.rm_443 wo.sv.un_760 
  0x43fc5713, 0x3f792fad, 0xfe002907, 0x1b033fa7,   // na.zzp.ie_665 su.war.af_643  sl.tlh.un_420 af.nl.tr_532 
  0x56000921, 0x2d0dfe0c, 0x2d0d24ec, 0x15042508,   // pl.mg.un_860 tlh.cs.sk_543  eo.cs.sk_644 mn.ru.un_443 
  // [a600]
  0x39250f08, 0x1e005607, 0x20002409, 0x023e27a4,   // lv.eu.br_443 mg.ms.un_420  eo.sq.un_440 gd.rm.da_433 
  0x03002504, 0x494b6460, 0x0e000f11, 0x0c080407,   // eu.nl.un_320 lg.mi.to_664  lv.is.un_630 fi.no.sv_432 
  0x3023120b, 0x365625a7, 0x4b5a5912, 0x5526250c,   // hu.ca.uz_542 eu.mg.gn_532  rn.sm.mi_654 eu.ia.rw_543 
  0x301b47a0, 0x250f0b08, 0x045a13a4, 0x3e090307,   // sn.tr.uz_322 es.lv.eu_443  et.sm.fi_433 nl.pl.rm_432 
  // [a610]
  0xfc2757ad, 0x200a490c, 0xfc001207, 0x5700790d,   // na.gd.zzp_643 to.pt.sq_543  hu.zzp.un_420 war.na.un_540 
  0x12423e02, 0x091279a0, 0x0e002205, 0x3b003012,   // rm.co.hu_222 war.hu.pl_322  oc.is.un_330 uz.so.un_640 
  0x50004b2b, 0x3204020c, 0x50564708, 0x281812a9,   // mi.fj.un_980 da.fi.bs_543  sn.mg.fj_443 ur.ar.sd_544 
  0x38252311, 0x5a000108, 0x494b5a07, 0x301204a4,   // ky.mn.tk_653 en.sm.un_430  sm.mi.to_432 fi.hu.uz_433 
  // [a620]
  0x3e001204, 0x04000502, 0x48241702, 0x392115ee,   // hu.rm.un_320 fr.fi.un_220  sr.eo.tt_222 un.jw.br_422 
  0x071008a0, 0x2a3e64a0, 0x353c3007, 0x644202a7,   // uk.be.bg_322 lg.rm.mt_322  uz.ug.tg_432 da.co.lg_532 
  0x536976af, 0x0a3830a7, 0x48001205, 0x04000509,   // crs.mfe.ht_655 uz.tk.mk_532  hu.tt.un_330 fr.fi.un_440 
  0x40002d08, 0x640702ec, 0x0d131c55, 0x2a002c0e,   // sk.lb.un_430 da.it.lg_644  mr.bh.ne_442 fy.mt.un_550 
  // [a630]
  0x561505a7, 0x09697612, 0x584d4ca4, 0x455a4c0b,   // fr.mg.un_520 crs.mfe.pl_654  wo.aa.om_433 wo.sm.ln_542 
  0x3b6a130c, 0x0d003205, 0x643b34a0, 0x34303c11,   // et.haw.so_543 bs.cs.un_330  xh.so.lg_322 ug.uz.ps_653 
  0x34122109, 0x35303c11, 0x1b313004, 0x0a073502,   // fa.ur.ps_444 ug.uz.tg_653  uz.az.tr_332 tg.bg.mk_222 
  0x4a006809, 0x6e024904, 0x0d321707, 0x3b580207,   // ig.yo.un_440 to.da.hmn_332  sr.bs.cs_432 da.om.so_432 
  // [a640]
  0x483723a4, 0x17070aa7, 0x1538480d, 0x4d34580c,   // ky.ba.tt_433 mk.bg.sr_532  tt.tk.un_554 om.xh.aa_543 
  0x10150807, 0x48001905, 0x4800790b, 0x02580107,   // uk.be.un_420 gl.tt.un_330  war.tt.un_520 en.om.da_432 
  0x4d133bad, 0x252862ac, 0x350a36a0, 0x18001304,   // so.et.aa_643 kha.sw.eu_632  ab.mk.tg_322 et.ga.un_320 
  0x02001f19, 0xfe004c12, 0x465a13ad, 0x3d212802,   // cy.da.un_750 wo.tlh.un_640  et.sm.qu_643 sd.fa.ku_222 
  // [a650]
  0x06002205, 0x031d1955, 0x48193ba4, 0x12001a02,   // oc.de.un_330 gl.la.nl_442  so.gl.tt_433 tl.hu.un_220 
  0x37234407, 0x0d0a06a0, 0x2a1c28a7, 0x6b1a02a4,   // kk.ky.ba_432 de.pt.cs_322  sw.id.mt_532 da.tl.ceb_433 
  0x043c15a6, 0x684567af, 0x2864470c, 0x37005c1a,   // un.ug.ru_521 ak.ln.ig_655  sn.lg.sw_543 sa.st.un_760 
  0x30004904, 0x46006507, 0x1e005304, 0x02001012,   // to.uz.un_320 gv.qu.un_420  ht.ms.un_320 lt.da.un_640 
  // [a660]
  0x02381208, 0x38101211, 0x38000d05, 0x39000908,   // hu.tk.da_443 hu.lt.tk_653  cs.tk.un_330 pl.br.un_430 
  0x10380208, 0x2a001e02, 0x1d1012a7, 0x063f0ca0,   // da.tk.lt_443 ms.mt.un_220  hu.lt.la_532 sv.af.de_322 
  0x362c03ad, 0x33000e0d, 0x65002713, 0x092c38a4,   // nl.fy.gn_643 is.nn.un_540  gd.gv.un_650 tk.fy.pl_433 
  0x0d2d10ac, 0x3f38100c, 0x3f103807, 0x022e0e60,   // lt.sk.cs_632 lt.tk.af_543  tk.lt.af_432 is.fo.da_664 
  // [a670]
  0x5f3701a9, 0x12183d05, 0x18006509, 0x2e0e0213,   // en.st.tn_544 ku.ar.ur_333  gv.ga.un_440 da.is.fo_665 
  0x2a002102, 0x3d00340e, 0x49004b13, 0x23153008,   // jw.mt.un_220 ps.ku.un_550  mi.to.un_650 uz.ky.un_430 
  0x17003002, 0x6b380204, 0x6063010c, 0x65001f0e,   // uz.sr.un_220 da.tk.ceb_332  en.sco.vo_543 cy.gv.un_550 
  0x31003014, 0x31006111, 0x3c23445a, 0x06004208,   // uz.az.un_660 za.az.un_630  kk.ky.ug_553 co.de.un_430 
  // [a680]
  0x376045a4, 0x37007513, 0x370415a6, 0x2400fe05,   // ln.vo.st_433 nso.st.un_650  un.ru.ba_521 tlh.eo.un_330 
  0x20002412, 0x42574ca4, 0x4a001e04, 0x505d21a4,   // eo.sq.un_640 wo.na.co_433  ms.yo.un_320 jw.ss.fj_433 
  0x074423a0, 0x65001f14, 0x5600290d, 0x1d000c08,   // ky.kk.bg_322 cy.gv.un_660  sl.mg.un_540 sv.la.un_430 
  0x24003702, 0x293b5f0b, 0x35000802, 0x21302814,   // st.eo.un_220 tn.so.sl_542  uk.tg.un_220 sd.uz.fa_666 
  // [a690]
  0x455e7812, 0x21502907, 0x17150a02, 0x0b0601a0,   // ve.ts.ln_654 sl.fj.jw_432  mk.sr.un_220 en.de.es_322 
  0x5000570d, 0x30003422, 0x202d12a0, 0x1b00380e,   // na.fj.un_540 ps.uz.un_870  hu.sk.sq_322 tk.tr.un_550 
  0x150717a0, 0x350430af, 0x4838150c, 0x4825100b,   // sr.bg.un_322 uz.ru.tg_655  un.tk.tt_543 be.mn.tt_542 
  0x305d35a9, 0x311b3007, 0x30311b04, 0x303102ee,   // zu.ss.uz_544 uz.tr.az_432  tr.az.uz_332 da.az.uz_422 
  // [a6a0]
  0x73355d08, 0x476428ee, 0x2b000f0d, 0x30504508,   // ss.zu.ny_443 sw.lg.sn_422  lv.vi.un_540 ln.fj.uz_443 
  0x64000302, 0x532103a4, 0x1b003007, 0x73025211,   // nl.lg.un_220 nl.jw.ht_433  uz.tr.un_420 ha.da.ny_653 
  0x0e0c40a4, 0x3f60030d, 0x7345375a, 0x343d23ee,   // lb.sv.is_433 nl.vo.af_554  st.ln.ny_553 ky.ku.ps_422 
  0x300e1007, 0x0a0715ec, 0x240e13a6, 0x58006408,   // lt.is.uz_432 un.bg.mk_644  et.is.eo_521 lg.om.un_430 
  // [a6b0]
  0x55005918, 0x10004709, 0x250b35ee, 0x441223ee,   // rn.rw.un_740 sn.lt.un_440  zu.es.eu_422 ky.ur.kk_422 
  0x78005e0e, 0x64005913, 0x30422d04, 0x55007312,   // ts.ve.un_550 rn.lg.un_650  sk.co.uz_332 ny.rw.un_640 
  0x50595504, 0x470940ee, 0x2e001007, 0x0410080d,   // rw.rn.fj_332 lb.pl.sn_422  lt.fo.un_420 uk.be.ru_554 
  0x50002e2a, 0x35345d60, 0x0a04070e, 0x4755590c,   // fo.fj.un_970 ss.xh.zu_664  bg.ru.mk_555 rn.rw.sn_543 
  // [a6c0]
  0x285c46a9, 0x520250af, 0x07380a12, 0x680247a4,   // qu.sa.sw_544 fj.da.ha_655  mk.tk.bg_654 sn.da.ig_433 
  0x03645307, 0x025f5804, 0x37347811, 0x17001121,   // ht.lg.nl_432 om.tn.da_332  ve.xh.st_653 ro.sr.un_860 
  0x400309a4, 0x3d1821a9, 0x075e2a02, 0x162d10a0,   // pl.nl.lb_433 fa.ar.ku_544  mt.ts.it_222 lt.sk.hr_322 
  0x040e0c0b, 0x095c1c0b, 0x3c30250e, 0x3c3830af,   // sv.is.fi_542 mr.sa.hi_542  mn.uz.ug_555 uz.tk.ug_655 
  // [a6d0]
  0x2600101b, 0x1000230d, 0x3b4c0304, 0x4c3f0308,   // lt.ia.un_770 ca.lt.un_540  nl.wo.so_332 nl.af.wo_443 
  0x4600360e, 0x4c033f0c, 0x55355912, 0x3b0302a0,   // gn.qu.un_550 af.nl.wo_543  rn.zu.rw_654 da.nl.so_322 
  0x4c033f14, 0x4c3f0355, 0x033b3f07, 0x3b2c58a9,   // af.nl.wo_666 nl.af.wo_442  af.so.nl_432 om.fy.so_544 
  0x3f3b6507, 0x3f034ca9, 0x3c38300c, 0x0f001308,   // gv.so.af_432 wo.nl.af_544  uz.tk.ug_543 et.lv.un_430 
  // [a6e0]
  0x342118a9, 0x0c001207, 0x17150707, 0x0600fe0b,   // ar.fa.ps_544 hu.sv.un_420  bg.sr.un_420 tlh.de.un_520 
  0x4d005709, 0x4d004e13, 0x2500231a, 0x3f033b09,   // na.aa.un_440 ay.aa.un_650  ky.mn.un_760 so.nl.af_444 
  0x05554004, 0x3b4c1308, 0x2a003b13, 0x13063f55,   // lb.rw.fr_332 et.wo.so_443  so.mt.un_650 af.de.et_442 
  0x3b004c09, 0x151510ee, 0x304810a4, 0x173c36ee,   // wo.so.un_440 be.un.un_420  be.tt.uz_433 ab.ug.sr_422 
  // [a6f0]
  0x370a10a4, 0x5e640f0c, 0x4c2850a9, 0x101b0f07,   // be.mk.ba_433 lv.lg.ts_543  fj.sw.wo_544 lv.tr.lt_432 
  0x6a285e0c, 0x28450fa9, 0x12652ea0, 0x640f280c,   // ts.sw.haw_543 lv.ln.sw_544  fo.gv.hu_322 sw.lv.lg_543 
  0x4800400d, 0x64007321, 0x073748a4, 0x64280f13,   // lb.tt.un_540 ny.lg.un_860  tt.ba.bg_433 lv.sw.lg_665 
  0x2d0f4507, 0x012526ee, 0x23084402, 0x171011a9,   // ln.lv.sk_432 ia.eu.en_422  kk.uk.ky_222 ro.be.sr_544 
  // [a700]
  0x38003f02, 0x31476404, 0x59730608, 0x6a3313a4,   // af.tk.un_220 lg.sn.az_332  de.ny.rn_443 et.nn.haw_433 
  0x55640faf, 0x3c003713, 0x2134180d, 0x291b17a9,   // lv.lg.rw_655 ba.ug.un_650  ar.ps.fa_554 sr.tr.sl_544 
  0x5e5d4904, 0x47353414, 0x55460fa9, 0x44003c22,   // to.ss.ts_332 xh.zu.sn_666  lv.qu.rw_544 ug.kk.un_870 
  0x42110508, 0x1c2f58a0, 0x0d396e0c, 0xfc5325a4,   // fr.ro.co_443 om.su.id_322  hmn.br.cs_543 eu.ht.zzp_433 
  // [a710]
  0x1700111a, 0x73255e04, 0x135c3604, 0x645e420c,   // ro.sr.un_760 ts.eu.ny_332  gn.sa.et_332 co.ts.lg_543 
  0x4a642002, 0x47005b08, 0x1364260c, 0x5c041355,   // sq.lg.yo_222 sg.sn.un_430  ia.lg.et_543 et.fi.sa_442 
  0x3122250c, 0x79000919, 0x5f000207, 0x29003911,   // eu.oc.az_543 pl.war.un_750  da.tn.un_420 br.sl.un_630 
  0x23303cad, 0x0d5c09ee, 0x0c3911a0, 0x12000914,   // ug.uz.ky_643 hi.sa.ne_422  ro.br.sv_322 pl.hu.un_660 
  // [a720]
  0x171632a6, 0x0e002904, 0x11252205, 0x12000704,   // bs.hr.sr_521 sl.is.un_320  oc.eu.ro_333 it.hu.un_320 
  0x152e62ec, 0x30485507, 0x04114808, 0x09006221,   // kha.fo.un_644 rw.tt.uz_432  tt.ro.ru_443 kha.pl.un_860 
  0x46390907, 0x21461fa0, 0x2d093809, 0x401206a0,   // pl.br.qu_432 cy.qu.jw_322  tk.pl.sk_444 de.hu.lb_322 
  0x1200041a, 0x65002e05, 0x122a04a0, 0x420704a4,   // fi.hu.un_760 fo.gv.un_330  fi.mt.hu_322 fi.it.co_433 
  // [a730]
  0x0e1d33a0, 0x523602a0, 0x1809790b, 0x2c3f1fad,   // nn.la.is_322 da.gn.ha_322  war.pl.ga_542 cy.af.fy_643 
  0x152b65ad, 0x79000913, 0x5d005212, 0x12004202,   // gv.vi.un_643 pl.war.un_650  ha.ss.un_640 co.hu.un_220 
  0xfe00290d, 0x22120407, 0x19002d05, 0x23042204,   // sl.tlh.un_540 fi.hu.oc_432  sk.gl.un_330 oc.fi.ca_332 
  0x291b0f55, 0x090d5c05, 0x18004602, 0x1b002205,   // lv.tr.sl_442 sa.ne.hi_333  qu.ga.un_220 oc.tr.un_330 
  // [a740]
  0x135c1ca0, 0x0444150d, 0x0b000702, 0x0b000708,   // mr.sa.bh_322 un.kk.ru_554  it.es.un_220 it.es.un_430 
  0x12002821, 0x12000205, 0x0e005d07, 0x5a331304,   // sd.ur.un_860 da.hu.un_330  ss.is.un_420 et.nn.sm_332 
  0x0c007807, 0x18003608, 0x083e33a4, 0x302344ee,   // ve.sv.un_420 gn.ga.un_430  nn.rm.no_433 kk.ky.uz_422 
  0x34420207, 0x343b40a0, 0x34302114, 0x60000314,   // da.co.xh_432 lb.so.xh_322  fa.uz.ps_666 nl.vo.un_660 
  // [a750]
  0x060c4304, 0x18213da0, 0x080a1708, 0x383c300b,   // ie.sv.de_332 ku.fa.ar_322  sr.mk.uk_443 uz.ug.tk_542 
  0x34003c0d, 0x13005002, 0x671501a0, 0x021d06a4,   // ug.ps.un_540 fj.et.un_220  en.ak.un_320 de.la.da_433 
  0x6200571a, 0x06301e0c, 0x31004807, 0x5a4b0f07,   // na.kha.un_760 ms.uz.de_543  tt.az.un_420 lv.mi.sm_432 
  0x330c5208, 0x1e001c21, 0x03020ca4, 0x0e006504,   // ha.sv.nn_443 id.ms.un_860  sv.da.nl_433 gv.is.un_320 
  // [a760]
  0x28006413, 0x641e1c12, 0x520602ee, 0x1e001c2a,   // lg.sw.un_650 id.ms.lg_654  da.de.ha_422 id.ms.un_970 
  0x1c1e4807, 0x0d1c5c09, 0x3d2134ad, 0x643b58ec,   // tt.ms.id_432 sa.mr.ne_444  ps.fa.ku_643 om.so.lg_644 
  0x40061811, 0x5f1e1c04, 0x11040708, 0x15061dee,   // ga.de.lb_653 id.ms.tn_332  bg.ru.ro_443 la.de.un_422 
  0x37006408, 0x4e594aa4, 0x3800150c, 0x02000812,   // lg.st.un_430 yo.rn.ay_433  un.tk.un_530 no.da.un_640 
  // [a770]
  0x58001c07, 0x64620211, 0x15000a23, 0x070423ee,   // id.om.un_420 da.kha.lg_653  mk.un.un_880 ky.ru.bg_422 
  0x18002d18, 0x1b000b02, 0x552f3307, 0x0ffe47af,   // sk.ga.un_740 es.tr.un_220  nn.su.rw_432 sn.tlh.lv_655 
  0x0f02fe04, 0x4e671b08, 0x5e005520, 0x1e481ca0,   // tlh.da.lv_332 tr.ak.ay_443  rw.ts.un_850 id.tt.ms_322 
  0x1c005b0d, 0x47531a04, 0x65003f08, 0xfc001f12,   // sg.id.un_540 tl.ht.sn_332  af.gv.un_430 cy.zzp.un_640 
  // [a780]
  0x12005219, 0x3555590c, 0x091c5cec, 0x595578ec,   // ha.hu.un_750 rn.rw.zu_543  sa.mr.hi_644 ve.rw.rn_644 
  0x08003012, 0x5e784712, 0x1c0d5c02, 0x1d00fc0c,   // uz.uk.un_640 sn.ve.ts_654  sa.ne.mr_222 zzp.la.un_530 
  0x50005c04, 0x161304a4, 0x23006504, 0x24001009,   // sa.fj.un_320 fi.et.hr_433  gv.ca.un_320 lt.eo.un_440 
  0x36005c08, 0x541b4613, 0x051101a4, 0x5c3f4707,   // sa.gn.un_430 qu.tr.ik_665  en.ro.fr_433 sn.af.sa_432 
  // [a790]
  0xfe47300c, 0x47595514, 0x4300150d, 0x6500fc07,   // uz.sn.tlh_543 rw.rn.sn_666  un.ie.un_540 zzp.gv.un_420 
  0x48303509, 0x3704100c, 0x25070404, 0x343d12a4,   // tg.uz.tt_444 be.ru.ba_543  ru.bg.mn_332 ur.ku.ps_433 
  0x0a3017ee, 0x303c385a, 0x47005e13, 0x4700550e,   // sr.uz.mk_422 tk.ug.uz_553  ts.sn.un_650 rw.sn.un_550 
  0x06004708, 0x5c1506ee, 0x6506fc02, 0x3d00120d,   // sn.de.un_430 de.sa.un_420  zzp.de.gv_222 ur.ku.un_540 
  // [a7a0]
  0xfc2c3fa4, 0x48253811, 0x0d135c07, 0x1008170c,   // af.fy.zzp_433 tk.mn.tt_653  sa.bh.ne_432 sr.uk.be_543 
  0x0a004704, 0x6b201a0b, 0x17322055, 0x34002834,   // sn.pt.un_320 tl.sq.ceb_542  sq.bs.sr_442 sd.ps.un_A80 
  0x236404a0, 0x0400fe12, 0x173748a0, 0x2d0d2902,   // fi.lg.ca_322 tlh.fi.un_640  tt.ba.sr_322 sl.cs.sk_222 
  0x130464a0, 0x193e0204, 0xfa2835af, 0xfe002912,   // lg.fi.et_322 da.rm.gl_332  zu.sw.nr_655 sl.tlh.un_640 
  // [a7b0]
  0x393137a6, 0x48001904, 0x01300204, 0x06004c05,   // st.az.br_521 gl.tt.un_320  da.uz.en_332 wo.de.un_330 
  0x55353460, 0x08001307, 0x43001914, 0x051a20ee,   // xh.zu.rw_664 et.no.un_420  gl.ie.un_660 sq.tl.fr_422 
  0x6100550c, 0x36004f08, 0x031c1ea0, 0x287355a4,   // rw.za.un_530 bi.gn.un_430  ms.id.nl_322 rw.ny.sw_433 
  0x736a56af, 0x2800021b, 0x1d2702a0, 0x0f40105a,   // mg.haw.ny_655 da.sw.un_770  da.gd.la_322 lt.lb.lv_553 
  // [a7c0]
  0x56002b12, 0x07110a04, 0x79002520, 0x060f33a0,   // vi.mg.un_640 mk.ro.bg_332  eu.war.un_850 nn.lv.de_322 
  0x1d00651a, 0x06100f5a, 0x0b2f2807, 0x650601a0,   // gv.la.un_760 lv.lt.de_553  sw.su.es_432 en.de.gv_322 
  0x044806ee, 0x443b2107, 0x381b2007, 0x395647a0,   // de.tt.fi_422 fa.ks.kk_432  sq.tr.tk_432 sn.mg.br_322 
  0x2b002102, 0x56004212, 0x38043c07, 0x5a005613,   // jw.vi.un_220 co.mg.un_640  ug.ru.tk_432 mg.sm.un_650 
  // [a7d0]
  0x7300280e, 0x562730ee, 0x48373813, 0x100f01a0,   // sw.ny.un_550 uz.gd.mg_422  tk.ba.tt_665 en.lv.lt_322 
  0x40064807, 0x734656a4, 0x462e4207, 0x755f680c,   // tt.de.lb_432 mg.qu.ny_433  co.fo.qu_432 ig.tn.nso_543 
  0x130f12a4, 0x021304a4, 0x48693004, 0x303e13a0,   // hu.lv.et_433 fi.et.da_433  uz.mfe.tt_332 et.rm.uz_322 
  0x23100402, 0x23001304, 0x5e305d08, 0x10000f18,   // ru.be.ky_222 et.ca.un_320  ss.uz.ts_443 lv.lt.un_740 
  // [a7e0]
  0x341a025a, 0x11040aa4, 0x6428520c, 0x1c306e0c,   // da.tl.xh_553 mk.ru.ro_433  ha.sw.lg_543 hmn.uz.id_543 
  0x304cfe08, 0x3b7302a9, 0x30523bec, 0x353421a9,   // tlh.wo.uz_443 da.ny.so_544  so.ha.uz_644 jw.xh.zu_544 
  0x301a52ec, 0x30006912, 0x791a6b0c, 0x52504a07,   // ha.tl.uz_644 mfe.uz.un_640  ceb.tl.war_543 yo.fj.ha_432 
  0x480f10ad, 0x52004d0e, 0x5e64520c, 0x4e00101a,   // lt.lv.tt_643 aa.ha.un_550  ha.lg.ts_543 lt.ay.un_760 
  // [a7f0]
  0x52003b21, 0x3b02520c, 0x30351511, 0x1b1a3ba9,   // so.ha.un_860 ha.da.so_543  un.tg.uz_653 so.tl.tr_544 
  0x305246ec, 0x4c212f0c, 0x4d001b21, 0x48313014,   // qu.ha.uz_644 su.jw.wo_543  tr.aa.un_860 uz.az.tt_666 
  0x0f10270e, 0x64524dee, 0x643b5208, 0x0c02fca4,   // gd.lt.lv_555 aa.ha.lg_422  ha.so.lg_443 zzp.da.sv_433 
  0x59554aa4, 0x080e3312, 0x3b3052ad, 0x2e000c04,   // yo.rw.rn_433 nn.is.no_654  ha.uz.so_643 sv.fo.un_320 
  
  // [a800]
  0x02313ba4, 0x05004002, 0x541b210c, 0x303b5ea4,   // so.az.da_433 lb.fr.un_220  jw.tr.ik_543 ts.so.uz_433 
  0x5b313ba4, 0x63083307, 0x31483005, 0x3b4c7305,   // so.az.sg_433 nn.no.sco_432  uz.tt.az_333 ny.wo.so_333 
  0xfe462108, 0x1a21460d, 0x33082a05, 0x55465212,   // jw.qu.tlh_443 qu.jw.tl_554  mt.no.nn_333 ha.qu.rw_654 
  0x477331a9, 0x0d020c12, 0x5e1a6ba4, 0x4c3b3102,   // az.ny.sn_544 sv.da.cs_654  ceb.tl.ts_433 az.so.wo_222 
  // [a810]
  0x36251508, 0x0c0b0a07, 0x0c003118, 0x28630107,   // un.mn.ab_443 pt.es.sv_432  az.sv.un_740 en.sco.sw_432 
  0x40002007, 0x0a005104, 0x40330e04, 0x080e3307,   // sq.lb.un_420 kl.pt.un_320  is.nn.lb_332 nn.is.no_432 
  0x15070807, 0x08003e04, 0x1e532a02, 0x370a1707,   // uk.bg.un_432 rm.no.un_320  mt.ht.ms_222 sr.mk.ba_432 
  0x2a003e13, 0x65632608, 0x1e002020, 0x3b554aa4,   // rm.mt.un_650 ia.sco.gv_443  ti.am.un_850 yo.rw.so_433 
  // [a820]
  0x28004f0c, 0x3b5d35af, 0x3428120d, 0x330c08a4,   // bi.sw.un_530 zu.ss.so_655  ur.sd.ps_554 no.sv.nn_433 
  0x2f2d1602, 0x3b004a19, 0x2326220c, 0x0c0f330b,   // hr.sk.su_222 yo.so.un_750  oc.ia.ca_543 nn.lv.sv_542 
  0x2163400c, 0x523b1da4, 0x28000802, 0x40002004,   // lb.sco.jw_543 la.so.ha_433  no.sw.un_220 sq.lb.un_320 
  0x2d002404, 0x5f5575a4, 0x55353409, 0x122844a7,   // eo.sk.un_320 nso.rw.tn_433  xh.zu.rw_444 kk.sd.ur_532 
  // [a830]
  0x520a3b07, 0x5d35520c, 0x28123009, 0x29525d0c,   // so.pt.ha_432 ha.zu.ss_543  uz.ur.sd_444 ss.ha.sl_543 
  0x23354812, 0x04095807, 0x15001118, 0x3c08170d,   // tt.tg.ky_654 om.pl.fi_432  ro.un.un_740 sr.uk.ug_554 
  0x113c3812, 0x25000a0e, 0x28477314, 0x49605d08,   // tk.ug.ro_654 mk.mn.un_550  ny.sn.sw_666 ss.vo.to_443 
  0x5a046aa4, 0x213d1855, 0x48381b12, 0x675660a9,   // haw.fi.sm_433 ar.ku.fa_442  tr.tk.tt_654 vo.mg.ak_544 
  // [a840]
  0x4b2b0411, 0x6a477308, 0x49005612, 0x605649ad,   // fi.vi.mi_653 ny.sn.haw_443  mg.to.un_640 to.mg.vo_643 
  0x2b253e0e, 0x011d2e0b, 0x10073e12, 0x3d2334ac,   // rm.eu.vi_555 fo.la.en_542  rm.it.lt_654 ps.ky.ku_632 
  0x3500251a, 0x071a0204, 0x251035ec, 0x58003104,   // mn.tg.un_760 da.tl.it_332  tg.be.mn_644 az.om.un_320 
  0x284423ad, 0x08003021, 0x35005d08, 0x2b000409,   // ky.kk.sd_643 uz.uk.un_860  ss.zu.un_430 fi.vi.un_440 
  // [a850]
  0x28001009, 0x285f73a7, 0x2b003712, 0x1a070404,   // lt.sw.un_440 ny.tn.sw_532  st.vi.un_640 fi.it.tl_332 
  0x0b1f5607, 0x375f3e0e, 0x3c003709, 0x48003c11,   // mg.cy.es_432 rm.tn.st_555  ba.ug.un_440 ug.tt.un_630 
  0x213d3b11, 0x2a0451a9, 0x04371505, 0x1d0451ec,   // ks.ku.fa_653 kl.fi.mt_544  un.ba.ru_333 kl.fi.la_644 
  0x311b485a, 0x0d32160d, 0x053e420c, 0x51040e09,   // tt.tr.az_553 hr.bs.cs_554  co.rm.fr_543 is.fi.kl_444 
  // [a860]
  0x304831a4, 0x440715ee, 0x04221d0c, 0x04374802,   // az.tt.uz_433 un.bg.kk_422  la.oc.fi_543 tt.ba.ru_222 
  0x18342804, 0x04002204, 0x51420aa9, 0x5c475a0c,   // sd.ps.ar_332 oc.fi.un_320  pt.co.kl_544 sm.sn.sa_543 
  0x51000808, 0x64005304, 0x4c00200c, 0x22644da7,   // no.kl.un_430 ht.lg.un_320  sq.wo.un_530 aa.lg.oc_532 
  0xfc4207a7, 0x421d4dad, 0x10171505, 0x12006404,   // it.co.zzp_532 aa.la.co_643  un.sr.be_333 lg.hu.un_320 
  // [a870]
  0x04454dad, 0x1d004d22, 0x1d510807, 0x0e122e07,   // aa.ln.fi_643 aa.la.un_870  no.kl.la_432 fo.hu.is_432 
  0x03062a08, 0x1017290c, 0x041d51ec, 0x04381711,   // mt.de.nl_443 sl.sr.lt_543  kl.la.fi_644 sr.tk.ru_653 
  0x51001d0d, 0x4d0451ec, 0x3e041da4, 0x20004c04,   // la.kl.un_540 kl.fi.aa_644  la.fi.rm_433 wo.sq.un_320 
  0x52006e2a, 0x4d00511b, 0x35006b08, 0x213034ad,   // hmn.ha.un_970 kl.aa.un_770  ceb.zu.un_430 ps.uz.fa_643 
  // [a880]
  0x360a48a4, 0x0a233504, 0x150a1109, 0x07041012,   // tt.mk.ab_433 tg.ky.mk_332  ro.mk.un_444 be.ru.bg_654 
  0x73002b0c, 0x3017080d, 0x20004622, 0x3f003b04,   // vi.ny.un_530 uk.sr.uz_554  qu.sq.un_870 so.af.un_320 
  0x79000709, 0x043b1e08, 0xfc400607, 0x5100fc09,   // it.war.un_440 ms.so.fi_443  de.lb.zzp_432 zzp.kl.un_440 
  0x0d095c02, 0x47005804, 0x0525fca0, 0x47582255,   // sa.hi.ne_222 om.sn.un_320  zzp.eu.fr_322 oc.om.sn_442 
  // [a890]
  0x1c1e3b04, 0x1f5d090c, 0x18342860, 0x6200211b,   // so.ms.id_332 pl.ss.cy_543  sd.ps.ar_664 jw.kha.un_770 
  0x2200fc07, 0x2d0d2909, 0x190b0aa9, 0x05006405,   // zzp.oc.un_420 sl.cs.sk_444  pt.es.gl_544 lg.fr.un_330 
  0x4a00680c, 0x3f3e4ea4, 0x5f003919, 0x38363ba7,   // ig.yo.un_530 ay.rm.af_433  br.tn.un_750 so.gn.tk_532 
  0x3008150d, 0x4c004e12, 0x5c00020c, 0x3c302504,   // un.uk.uz_554 ay.wo.un_640  da.sa.un_530 mn.uz.ug_332 
  // [a8a0]
  0x420f0704, 0x29002404, 0x33036402, 0x6b6330a0,   // it.lv.co_332 eo.sl.un_320  lg.nl.nn_222 uz.sco.ceb_322 
  0x0300060e, 0x51005a0c, 0x42001e04, 0x3f0306ee,   // de.nl.un_550 sm.kl.un_530  ms.co.un_320 de.nl.af_422 
  0x0312fe05, 0x47005d0d, 0x35341aa4, 0x2a200f09,   // tlh.hu.nl_333 ss.sn.un_540  tl.xh.zu_433 lv.sq.mt_444 
  0x53002a05, 0x3e0308af, 0x105c030b, 0x08022305,   // mt.ht.un_330 no.nl.rm_655  nl.sa.lt_542 ca.da.no_333 
  // [a8b0]
  0x5d005c07, 0x0939080b, 0x0200080c, 0x1f000c0e,   // sa.ss.un_420 no.br.pl_542  no.da.un_530 sv.cy.un_550 
  0x34002123, 0x20463055, 0x10002704, 0x352734a0,   // fa.ps.un_880 uz.qu.sq_442  gd.lt.un_320 xh.gd.zu_322 
  0x301b12a4, 0x06033f09, 0x0b103eee, 0x06400355,   // hu.tr.uz_433 af.nl.de_444  rm.lt.es_422 nl.lb.de_442 
  0x1e1c0dee, 0x06032c07, 0x0f002209, 0x401d010b,   // cs.id.ms_422 fy.nl.de_432  oc.lv.un_440 en.la.lb_542 
  // [a8c0]
  0x3e001f0d, 0x47002713, 0x4d005c08, 0x27223ea4,   // cy.rm.un_540 gd.sn.un_650  sa.aa.un_430 rm.oc.gd_433 
  0x29003013, 0x3e2224af, 0x47005c11, 0x081736a4,   // uz.sl.un_650 eo.oc.rm_655  sa.sn.un_630 ab.sr.uk_433 
  0x28003805, 0x17000a21, 0x10003e05, 0x3e33080c,   // tk.sw.un_330 mk.sr.un_860  rm.lt.un_330 no.nn.rm_543 
  0x1b004612, 0x6b021d12, 0x0c004c04, 0x2b001504,   // qu.tr.un_640 la.da.ceb_654  wo.sv.un_320 un.vi.un_320 
  // [a8d0]
  0x19260b08, 0x455e73a0, 0x3e0f6e07, 0x53697655,   // es.ia.gl_443 ny.ts.ln_322  hmn.lv.rm_432 crs.mfe.ht_442 
  0x67004504, 0x39001502, 0x35344512, 0x1000300e,   // ln.ak.un_320 un.br.un_220  ln.xh.zu_654 uz.be.un_550 
  0x2f000502, 0x735c5ba9, 0x2344300d, 0x10002509,   // fr.su.un_220 sg.sa.ny_544  uz.kk.ky_554 mn.be.un_440 
  0x17002507, 0x043723a0, 0x481708a4, 0x353044a4,   // mn.sr.un_420 ky.ba.ru_322  uk.sr.tt_433 kk.uz.tg_433 
  // [a8e0]
  0x2224010c, 0x17655a04, 0x1b000207, 0x013402a0,   // en.eo.oc_543 sm.gv.sr_332  da.tr.un_420 da.xh.en_322 
  0x5363250c, 0x04111755, 0x36483713, 0x5c1c09af,   // eu.sco.ht_543 sr.ro.ru_442  ba.tt.ab_665 hi.mr.sa_655 
  0x0a1711a0, 0x3d3c2308, 0x156b01a0, 0x4775560c,   // ro.sr.mk_322 ky.ug.ku_443  en.ceb.un_322 mg.nso.sn_543 
  0x4b6a5a0e, 0x306b5fa9, 0x4b6a4907, 0x04364509,   // sm.haw.mi_555 tn.ceb.uz_544  to.haw.mi_432 ln.gn.fi_444 
  // [a8f0]
  0x12211008, 0x36003c13, 0x3b003702, 0x376a5f07,   // lt.jw.hu_443 ug.ab.un_650  st.so.un_220 tn.haw.st_432 
  0x025f12a4, 0x25351512, 0x36215fa4, 0x0c473308,   // hu.tn.da_433 un.tg.mn_654  tn.jw.gn_433 nn.sn.sv_443 
  0x5000521a, 0x1a006b0d, 0x12003704, 0x31006407,   // ha.fj.un_760 ceb.tl.un_540  st.hu.un_320 lg.az.un_420 
  0x0000102d, 0x2802450c, 0x64004518, 0x09002f08,   // lt.un.un_A00 ln.da.sw_543  ln.lg.un_740 su.pl.un_430 
  // [a900]
  0x34fc3504, 0x5f736e0c, 0x250a23a0, 0x34fc3508,   // zu.zzp.xh_332 hmn.ny.tn_543  ky.mk.mn_322 zu.zzp.xh_443 
  0x50292da6, 0x56121c07, 0x255a28a7, 0x684b6a0c,   // sk.sl.fj_521 id.hu.mg_432  sw.sm.eu_532 haw.mi.ig_543 
  0x4f006712, 0x2800500c, 0x12213ba9, 0x20fe1e08,   // ak.bi.un_640 fj.sw.un_530  ks.fa.ur_544 ms.tlh.sq_443 
  0x07003704, 0x05002107, 0x3c182804, 0x40001021,   // ba.bg.un_320 jw.fr.un_420  sd.ar.ug_332 lt.lb.un_860 
  // [a910]
  0x38001507, 0x39460aa0, 0x552868af, 0x190a22a0,   // un.tk.un_420 pt.qu.br_322  ig.sw.rw_655 oc.pt.gl_322 
  0x79190a0e, 0x3c384408, 0x60fc2a0c, 0x0b00690c,   // pt.gl.war_555 kk.tk.ug_443  mt.zzp.vo_543 mfe.es.un_530 
  0x3900681a, 0x35733755, 0x25fc0713, 0x33230f08,   // ig.br.un_760 st.ny.zu_442  it.zzp.eu_665 lv.ca.nn_443 
  0x4b0f5a0c, 0x39205cec, 0x2f0821a6, 0x22055807,   // sm.lv.mi_543 sa.sq.br_644  jw.no.su_521 om.fr.oc_432 
  // [a920]
  0x37430da4, 0x36190b5a, 0x39000a13, 0x1610020c,   // cs.ie.st_433 es.gl.gn_553  pt.br.un_650 da.lt.hr_543 
  0x3f5658a0, 0x3f791d04, 0x30003f05, 0x3f003304,   // om.mg.af_322 la.war.af_332  af.uz.un_330 nn.af.un_320 
  0x3f007904, 0x5c005207, 0x036437a0, 0x360b190c,   // war.af.un_320 ha.sa.un_420  st.lg.nl_322 gl.es.gn_543 
  0x11552804, 0x351530af, 0x5f75370e, 0x2f3f03a4,   // sw.rw.ro_332 uz.tg.un_650  st.nso.tn_555 nl.af.su_433 
  // [a930]
  0x47306404, 0x1f0476a9, 0x2c4006a0, 0x385c4604,   // lg.uz.sn_332 crs.fi.cy_544  de.lb.fy_322 qu.sa.tk_332 
  0x2e003305, 0x29001723, 0x5e37560d, 0x1715045a,   // nn.fo.un_330 sr.sl.un_880  mg.st.ts_554 ru.sr.un_530 
  0x1a040502, 0x0200370d, 0x0a046013, 0x22070107,   // fr.fi.tl_222 st.da.un_540  vo.fi.pt_665 en.it.oc_432 
  0x03fc7304, 0x50002108, 0x1d02200c, 0x3c17110c,   // ny.zzp.nl_332 jw.fj.un_430  sq.da.la_543 ro.sr.ug_543 
  // [a940]
  0x3600240d, 0x233025a7, 0x23151507, 0x0a00350d,   // eo.gn.un_540 mn.uz.ky_532  un.ky.un_420 tg.mk.un_540 
  0x13fe0412, 0x51000209, 0xfe041311, 0x4a004513,   // fi.tlh.et_654 da.kl.un_440  et.fi.tlh_653 ln.yo.un_650 
  0x351708af, 0x73004309, 0x496a7307, 0x75007319,   // uk.sr.tg_655 ie.ny.un_440  ny.haw.to_432 ny.nso.un_750 
  0x52003004, 0xfe00040e, 0x42003f02, 0x73755f08,   // uz.ha.un_320 fi.tlh.un_550  af.co.un_220 tn.nso.ny_443 
  // [a950]
  0x02322d07, 0x73575f12, 0x36000204, 0x0c2161a6,   // sk.bs.da_432 tn.na.ny_654  da.gn.un_320 za.jw.sv_521 
  0xfe0413a4, 0xfc003605, 0x2a003404, 0x44233c04,   // et.fi.tlh_433 gn.zzp.un_330  xh.mt.un_320 ug.ky.kk_332 
  0x28211202, 0x12277304, 0x0a15040d, 0xfc000222,   // ur.fa.sd_222 ny.gd.hu_332  ru.mk.un_540 da.zzp.un_870 
  0x1a00211a, 0x3e002d04, 0x57002819, 0x03005004,   // jw.tl.un_760 sk.rm.un_320  sw.na.un_750 fj.nl.un_320 
  // [a960]
  0x4300090d, 0x1e1b1aaf, 0x1c0826ee, 0x207347a4,   // pl.ie.un_540 tl.tr.ms_655  ia.no.id_422 sn.ny.sq_433 
  0x4a006a14, 0x041708ad, 0x09182da0, 0x483037a9,   // haw.yo.un_660 uk.sr.ru_643  sk.ga.pl_322 ba.uz.tt_544 
  0x3e4207ad, 0x01432d04, 0x11000722, 0x0a36170d,   // it.co.rm_643 sk.ie.en_332  bg.ro.un_870 sr.ab.mk_554 
  0x04373004, 0x1c005c20, 0x37150405, 0x30353c0b,   // uz.ba.ru_332 sa.mr.un_850  ru.ba.un_330 ug.tg.uz_542 
  // [a970]
  0x12281805, 0x630165a0, 0x67760107, 0x05393808,   // ar.sd.ur_333 gv.en.sco_322  en.crs.ak_432 tk.br.fr_443 
  0x65392c02, 0x2300440b, 0x38161bee, 0x1b640212,   // fy.br.gv_222 kk.ky.un_520  tr.hr.tk_422 da.lg.tr_654 
  0x483c3855, 0x1a006419, 0x56002c02, 0x1100561a,   // tk.ug.tt_442 lg.tl.un_750  fy.mg.un_220 mg.ro.un_760 
  0x012b5a07, 0x123d30a0, 0x44003509, 0x041510a4,   // sm.vi.en_432 uz.ku.ur_322  tg.kk.un_440 be.ru.un_430 
  // [a980]
  0x10353605, 0x05381ba4, 0x442330a0, 0x1f39400c,   // ab.tg.be_333 tr.tk.fr_433  uz.ky.kk_322 lb.br.cy_543 
  0x4c00391a, 0x44212309, 0x23002004, 0x22003f04,   // br.wo.un_760 ky.fa.kk_444  sq.ca.un_320 af.oc.un_320 
  0x28183ba9, 0x032c06a0, 0x300836ee, 0x40001307,   // ks.ar.sd_544 de.fy.nl_322  ab.uk.uz_422 et.lb.un_420 
  0x475efe0b, 0x2e003302, 0x355d4755, 0x47fe7811,   // tlh.ts.sn_542 nn.fo.un_220  sn.ss.zu_442 ve.tlh.sn_653 
  // [a990]
  0x4c2140a9, 0x33404c0c, 0x3048350b, 0x356455a0,   // lb.jw.wo_544 wo.lb.nn_543  tg.tt.uz_542 rw.lg.zu_322 
  0x060c4009, 0x0c2e0607, 0x59554709, 0x0f004904,   // lb.sv.de_444 de.fo.sv_432  sn.rw.rn_444 to.lv.un_320 
  0x5c0f10a4, 0x0e0c08a0, 0x371511ec, 0x17151107,   // lt.lv.sa_433 no.sv.is_322  ro.ba.un_640 ro.sr.un_420 
  0x304815a0, 0x0a004404, 0x02fc2a13, 0x36002b14,   // un.tt.uz_322 kk.mk.un_320  mt.zzp.da_665 vi.gn.un_660 
  // [a9a0]
  0x29750f0c, 0x24036ea4, 0x0f2d3fa4, 0x2f302012,   // lv.nso.sl_543 hmn.nl.eo_433  af.sk.lv_433 sq.uz.su_654 
  0x1a006a09, 0x3c344404, 0x04067907, 0x5e34370b,   // haw.tl.un_440 kk.ps.ug_332  war.de.fi_432 st.xh.ts_542 
  0x3bfc0405, 0x40006713, 0x65fc4807, 0x0200120c,   // fi.zzp.so_333 ak.lb.un_650  tt.zzp.gv_432 hu.da.un_530 
  0x51360404, 0x58045155, 0x2f005608, 0xfc093b0b,   // fi.gn.kl_332 kl.fi.om_442  mg.su.un_430 so.pl.zzp_542 
  // [a9b0]
  0x64514d08, 0x64044955, 0x333f08a0, 0x1351040c,   // aa.kl.lg_443 to.fi.lg_442  no.af.nn_322 fi.kl.et_543 
  0x460c79a0, 0x04005112, 0x2f003b02, 0x2d0637a7,   // war.sv.qu_322 kl.fi.un_640  so.su.un_220 st.de.sk_532 
  0xfc510107, 0x5c0604a7, 0x3e790655, 0x5c00640c,   // en.kl.zzp_432 fi.de.sa_532  de.war.rm_442 lg.sa.un_530 
  0x64045a12, 0x16002c02, 0x5a6451ad, 0x51000420,   // sm.fi.lg_654 fy.hr.un_220  kl.lg.sm_643 fi.kl.un_850 
  // [a9c0]
  0x51001521, 0x370444a0, 0x30003c0b, 0x0a003520,   // un.kl.un_860 kk.ru.ba_322  ug.uz.un_520 tg.mk.un_850 
  0x0b001007, 0x0c3e130c, 0x100f3e04, 0x39353409,   // lt.es.un_420 et.rm.sv_543  rm.lv.lt_332 xh.zu.br_444 
  0x3e1810a0, 0x1c000c18, 0x5c39640c, 0x3f00011a,   // lt.ga.rm_322 sv.id.un_740  lg.br.sa_543 en.af.un_760 
  0x10000c04, 0x630f1055, 0x1700101a, 0x241d3eec,   // sv.lt.un_320 lt.lv.sco_442  be.sr.un_760 rm.la.eo_644 
  // [a9d0]
  0x170a38a7, 0x073c15a4, 0x58006e04, 0x21003904,   // tk.mk.sr_532 un.ug.bg_433  hmn.om.un_320 br.jw.un_320 
  0x2d0d0907, 0x28422aa4, 0x39110fad, 0x381009ad,   // pl.cs.sk_432 mt.co.sw_433  lv.ro.br_643 pl.lt.tk_643 
  0x6b461007, 0x0c004c05, 0x12282108, 0x1c000f04,   // lt.qu.ceb_432 wo.sv.un_330  fa.sd.ur_443 lv.id.un_320 
  0x30002122, 0x22103e07, 0x3d342304, 0x0f006a08,   // fa.uz.un_870 rm.lt.oc_432  ky.ps.ku_332 haw.lv.un_430 
  // [a9e0]
  0x172d0dee, 0x273e0f04, 0x690353a4, 0x10000c08,   // cs.sk.sr_422 lv.rm.gd_332  ht.nl.mfe_433 sv.lt.un_430 
  0x10001512, 0x0848100c, 0x443738a4, 0x18283402,   // un.be.un_640 be.tt.uk_543  tk.ba.kk_433 ps.sd.ar_222 
  0x080a0704, 0x65001504, 0x3517080c, 0x170d1607,   // bg.mk.uk_332 un.gv.un_320  uk.sr.tg_543 hr.cs.sr_432 
  0x5c091cee, 0x0200251a, 0x1a552805, 0x15113c60,   // mr.hi.sa_422 eu.da.un_760  sw.rw.tl_333 ug.ro.un_664 
  // [a9f0]
  0xfc304d11, 0x122834a7, 0x213c23a0, 0x18342809,   // aa.uz.zzp_653 ps.sd.ur_532  ky.ug.fa_322 sd.ps.ar_444 
  0x343f1da6, 0x15480cad, 0x21443d04, 0x080c020d,   // la.af.xh_521 sv.tt.un_643  ku.kk.fa_332 da.sv.no_554 
  0x0a070805, 0x5b00361b, 0x360a1109, 0x0a1159a4,   // uk.bg.mk_333 gn.sg.un_770  ro.pt.gn_444 rn.ro.pt_433 
  0x30650204, 0x0c0802ad, 0x59554705, 0x392c1fee,   // da.gv.uz_332 da.no.sv_643  sn.rw.rn_333 cy.fy.br_422 
  // [aa00]
  0x69000804, 0x11005b0d, 0x450e2e13, 0x02006a19,   // no.mfe.un_320 sg.ro.un_540  fo.is.ln_665 haw.da.un_750 
  0x212a2c12, 0x1100590d, 0x1e1c6ba4, 0x2f254d04,   // fy.mt.jw_654 rn.ro.un_540  ceb.id.ms_433 aa.eu.su_332 
  0x0a081755, 0x494b6a0b, 0x02000413, 0x595560a4,   // sr.uk.mk_442 haw.mi.to_542  fi.da.un_650 vo.rw.rn_433 
  0x51492813, 0x68353404, 0x06007307, 0x1b313ba4,   // sw.to.kl_665 xh.zu.ig_332  ny.de.un_420 so.az.tr_433 
  // [aa10]
  0x194334a7, 0x0c402ea7, 0x1300250e, 0x132534a9,   // xh.ie.gl_532 fo.lb.sv_532  eu.et.un_550 xh.eu.et_544 
  0x240f1e07, 0x45003012, 0x45735ca4, 0x06004309,   // ms.lv.eo_432 uz.ln.un_640  sa.ny.ln_433 ie.de.un_440 
  0x1b732809, 0x79731a08, 0x253523a9, 0x64005d09,   // sw.ny.tr_444 tl.ny.war_443  ky.tg.mn_544 ss.lg.un_440 
  0x511a0204, 0x40390505, 0x3f5f5111, 0x23303512,   // da.tl.kl_332 fr.br.lb_333  kl.tn.af_653 tg.uz.ky_654 
  // [aa20]
  0x51003504, 0x5c00550c, 0x64796b11, 0x25173804,   // zu.kl.un_320 rw.sa.un_530  ceb.war.lg_653 tk.sr.mn_332 
  0xfc00300c, 0x35344d11, 0x3038375a, 0x3800530c,   // uz.zzp.un_530 aa.xh.zu_653  ba.tk.uz_553 ht.tk.un_530 
  0x13006505, 0x112076a4, 0x0130690c, 0x2c000a0b,   // gv.et.un_330 crs.sq.ro_433  mfe.uz.en_543 pt.fy.un_520 
  0x2700060c, 0x023410ee, 0x13002508, 0x2e134e04,   // de.gd.un_530 lt.xh.da_422  eu.et.un_430 ay.et.fo_332 
  // [aa30]
  0x5d7328ee, 0x31481111, 0x45474c07, 0x10126705,   // sw.ny.ss_422 ro.tt.az_653  wo.sn.ln_432 ak.hu.lt_333 
  0x090d5cac, 0x241d26a4, 0x182812ee, 0x05003912,   // sa.ne.hi_632 ia.la.eo_433  ur.sd.ar_422 br.fr.un_640 
  0x1f002a08, 0x5e646a08, 0x11000a0c, 0x110742a9,   // mt.cy.un_430 haw.lg.ts_443  pt.ro.un_530 co.it.ro_544 
  0x1b003908, 0x15002702, 0x08000b04, 0x3e000804,   // br.tr.un_430 gd.un.un_220  es.no.un_320 no.rm.un_320 
  // [aa40]
  0x19120aa6, 0x0a3e2208, 0x0b0a3ea4, 0x46005507,   // pt.hu.gl_521 oc.rm.pt_443  rm.pt.es_433 rw.qu.un_420 
  0x04231755, 0x220b0a0d, 0x23220504, 0x08104408,   // sr.ky.ru_442 pt.es.oc_554  fr.oc.ca_332 kk.be.uk_443 
  0x22006e0d, 0x2b001f19, 0x38001b19, 0x041d26ad,   // hmn.oc.un_540 cy.vi.un_750  tr.tk.un_750 ia.la.fi_643 
  0x3e1d100c, 0x1300fc12, 0x07002305, 0x287856a4,   // lt.la.rm_543 zzp.et.un_640  ky.bg.un_330 mg.ve.sw_433 
  // [aa50]
  0x38002308, 0x392e33a0, 0x07170404, 0x150417a9,   // ky.tk.un_430 nn.fo.br_322  ru.sr.bg_332 sr.ru.un_544 
  0x172c32a4, 0x18003f04, 0x0a000f04, 0x31381b09,   // bs.fy.sr_433 af.ga.un_320  lv.pt.un_320 tr.tk.az_444 
  0x3f004008, 0x3000060c, 0x04174402, 0x421d0fa0,   // lb.af.un_430 de.uz.un_530  kk.sr.ru_222 lv.la.co_322 
  0x12183b04, 0x250d12a0, 0x1f391107, 0x3900400d,   // ks.ar.ur_332 hu.cs.eu_322  ro.br.cy_432 lb.br.un_540 
  // [aa60]
  0x3e3f1f07, 0x3523110c, 0x2500120d, 0x3f4c03a0,   // cy.af.rm_432 ro.ky.tg_543  hu.eu.un_540 nl.wo.af_322 
  0x4a5321a4, 0x52005308, 0x6500fe1a, 0x2869450d,   // jw.ht.yo_433 ht.ha.un_430  tlh.gv.un_760 ln.mfe.sw_554 
  0x083035a9, 0x564b52ac, 0x3b2e65ec, 0x584945ac,   // tg.uz.uk_544 ha.mi.mg_632  gv.fo.so_644 ln.to.om_632 
  0x04003808, 0x1b3b65ad, 0x69311b05, 0x68001c22,   // tk.ru.un_430 gv.so.tr_643  tr.az.mfe_333 id.ig.un_870 
  // [aa70]
  0x6a39490c, 0x526945a4, 0xfc1565a0, 0x791a4c09,   // to.br.haw_543 ln.mfe.ha_433  gv.zzp.un_320 wo.tl.war_444 
  0x6500fe09, 0x3e1225a9, 0x1b653b55, 0x00006a03,   // tlh.gv.un_440 eu.hu.rm_544  so.gv.tr_442 haw.un.un_300 
  0x584a4bee, 0x2128180b, 0x3e2512ec, 0x56005208,   // mi.yo.om_422 ar.sd.fa_542  hu.eu.rm_644 ha.mg.un_430 
  0x13003705, 0x5d00492a, 0x133b5bee, 0x47005302,   // st.et.un_330 to.ss.un_970  sg.so.et_422 ht.sn.un_220 
  // [aa80]
  0x1b000205, 0x52007321, 0x37455e08, 0x30481b07,   // da.tr.un_330 ny.ha.un_860  ts.ln.st_443 tr.tt.uz_432 
  0x1a53210c, 0x1b3b6507, 0x15003708, 0x15002523,   // jw.ht.tl_543 gv.so.tr_432  ba.un.un_430 mn.un.un_880 
  0x1b000407, 0x33472111, 0x364950ad, 0x73674b0c,   // fi.tr.un_420 jw.sn.nn_653  fj.to.gn_643 mi.ak.ny_543 
  0x2e1b65ad, 0x04006505, 0x15254807, 0x53004712,   // gv.tr.fo_643 gv.fi.un_330  tt.mn.un_432 sn.ht.un_640 
  // [aa90]
  0x39471302, 0x23004704, 0x3f5603a7, 0x3c00181a,   // et.sn.br_222 sn.ca.un_320  nl.mg.af_532 ar.ug.un_760 
  0x080c0212, 0x07006502, 0x0b02220c, 0x08173ca0,   // da.sv.no_654 gv.it.un_220  oc.da.es_543 ug.sr.uk_322 
  0x30343511, 0x25643902, 0x3e000c04, 0x4600340e,   // zu.xh.uz_653 br.lg.eu_222  sv.rm.un_320 xh.qu.un_550 
  0x16003e0e, 0x46003012, 0x2b004707, 0x2311440c,   // rm.hr.un_550 uz.qu.un_640  sn.vi.un_420 kk.ro.ky_543 
  // [aaa0]
  0x11200da0, 0x3b00540c, 0x282134a0, 0x00002842,   // cs.sq.ro_322 ik.so.un_530  ps.fa.sd_322 sd.un.un_C00 
  0x47005507, 0x12282112, 0x47005505, 0x48370804,   // rw.sn.un_420 fa.sd.ur_654  rw.sn.un_330 uk.ba.tt_332 
  0x2c000a04, 0x65003004, 0x2e2406a0, 0x121828a0,   // pt.fy.un_320 uz.gv.un_320  de.eo.fo_322 sd.ar.ur_322 
  0x12003b1a, 0x0e002a04, 0x50001a0c, 0x115d1a08,   // ks.ur.un_760 mt.is.un_320  tl.fj.un_530 tl.ss.ro_443 
  // [aab0]
  0x652160ac, 0x281a1b0c, 0x587352af, 0x0a3515ec,   // vo.jw.gv_632 tr.tl.sw_543  ha.ny.om_655 un.tg.mk_644 
  0x4a48520c, 0x18000313, 0x4200510d, 0x1331110c,   // ha.tt.yo_543 nl.ga.un_650  kl.co.un_540 ro.az.et_543 
  0x575303a9, 0x5a1b1d5a, 0x0a001113, 0x2c06030c,   // nl.ht.na_544 la.tr.sm_553  ro.pt.un_650 nl.de.fy_543 
  0x311b3bee, 0x073008a0, 0x40fc02a0, 0x1b310207,   // so.tr.az_422 uk.uz.bg_322  da.zzp.lb_322 da.az.tr_432 
  // [aac0]
  0x1c093b05, 0x130436a0, 0x55355d07, 0x392b1aee,   // ks.hi.mr_333 gn.fi.et_322  ss.zu.rw_432 tl.vi.br_422 
  0x211a670c, 0x1b005302, 0x2b000204, 0x18006a04,   // ak.tl.jw_543 ht.tr.un_220  da.vi.un_320 haw.ga.un_320 
  0x50fe3007, 0x29001204, 0x29000d1a, 0x28343dad,   // uz.tlh.fj_432 hu.sl.un_320  cs.sl.un_760 ku.ps.sd_643 
  0x5a3e04a7, 0x4448040e, 0x23443c05, 0x02003912,   // fi.rm.sm_532 ru.tt.kk_555  ug.kk.ky_333 br.da.un_640 
  // [aad0]
  0x532718ad, 0x2c001109, 0x6b1b1d07, 0x35254807,   // ga.gd.ht_643 ro.fy.un_440  la.tr.ceb_432 tt.mn.tg_432 
  0x2845550b, 0x47045813, 0x3707150d, 0x1700240b,   // rw.ln.sw_542 om.fi.sn_665  un.bg.ba_554 eo.sr.un_520 
  0x4d04640c, 0x5a3b3f0c, 0x181026ee, 0x454e280c,   // lg.fi.aa_543 af.so.sm_543  ia.lt.ga_422 sw.ay.ln_543 
  0x51670308, 0x22422055, 0x5528fe04, 0xfe005d08,   // nl.ak.kl_443 sq.co.oc_442  tlh.sw.rw_332 ss.tlh.un_430 
  // [aae0]
  0x676558a9, 0x0d000f12, 0x65583b0c, 0x3b4d650e,   // om.gv.ak_544 lv.cs.un_640  so.om.gv_543 gv.aa.so_555 
  0x30204612, 0xfc004707, 0x65005a2a, 0x3c30350e,   // qu.sq.uz_654 sn.zzp.un_420  sm.gv.un_970 tg.uz.ug_555 
  0x133b6509, 0x761f750c, 0x64005f07, 0x585b3b07,   // gv.so.et_444 nso.cy.crs_543  tn.lg.un_420 so.sg.om_432 
  0x0d00020c, 0x4c4d3bad, 0x3e005502, 0x2d0d79ee,   // da.cs.un_530 so.aa.wo_643  rw.rm.un_220 war.cs.sk_422 
  // [aaf0]
  0x58321604, 0x1109feee, 0x3f032704, 0x0d321602,   // hr.bs.om_332 tlh.pl.ro_422  gd.nl.af_332 hr.bs.cs_222 
  0x4c5165a4, 0x6479360d, 0x49005129, 0x24fe4212,   // gv.kl.wo_433 gn.war.lg_554  kl.to.un_960 co.tlh.eo_654 
  0x514d3baf, 0x38353005, 0x47650407, 0x28404d0c,   // so.aa.kl_655 uz.tg.tk_333  fi.gv.sn_432 aa.lb.sw_543 
  0x34371c0c, 0x403f06ee, 0x58513b09, 0x0c060207,   // id.st.xh_543 de.af.lb_422  so.kl.om_444 da.de.sv_432 
  // [ab00]
  0x46007307, 0x040a070d, 0x0c060205, 0x1d005108,   // ny.qu.un_420 bg.mk.ru_554  da.de.sv_333 kl.la.un_430 
  0x0a00221b, 0x25442304, 0x22190aec, 0x406306a9,   // oc.pt.un_770 ky.kk.mn_332  pt.gl.oc_644 de.sco.lb_544 
  0x12396ea4, 0x150d36ee, 0x653f1f08, 0x22004014,   // hmn.br.hu_433 gn.cs.un_422  cy.af.gv_443 lb.oc.un_660 
  0x1d00511a, 0x172d2909, 0x1e5c5d0c, 0x081704a9,   // kl.la.un_760 sl.sk.sr_444  ss.sa.ms_543 ru.sr.uk_544 
  // [ab10]
  0x2a000602, 0x213c34a0, 0x27241812, 0x5c182711,   // de.mt.un_220 ps.ug.fa_322  ga.eo.gd_654 gd.ga.sa_653 
  0x270b18a9, 0x17153511, 0x645c7907, 0x2e001d02,   // ga.es.gd_544 tg.sr.un_630  war.sa.lg_432 la.fo.un_220 
  0x1f006522, 0x0f00390b, 0x5c002104, 0x10220f04,   // gv.cy.un_870 br.lv.un_520  jw.sa.un_320 lv.oc.lt_332 
  0x1d025b07, 0x0b00430d, 0x65097908, 0x23483007,   // sg.da.la_432 ie.es.un_540  war.pl.gv_443 uz.tt.ky_432 
  // [ab20]
  0x04386507, 0x1a6b7904, 0x3f1f6512, 0x1c2f2155,   // gv.tk.fi_432 war.ceb.tl_332  gv.cy.af_654 jw.su.id_442 
  0x07151504, 0x01281812, 0x4a190b04, 0x37303508,   // un.bg.un_320 ar.sd.iw_654  es.gl.yo_332 tg.uz.ba_443 
  0x675d35ec, 0x1c212f55, 0x2e1812ee, 0x253523a0,   // zu.ss.ak_644 su.jw.id_442  hu.ga.fo_422 ky.tg.mn_322 
  0x30314802, 0x06331d04, 0x5f00430d, 0x29101604,   // tt.az.uz_222 la.nn.de_332  ie.tn.un_540 hr.lt.sl_332 
  // [ab30]
  0x48000709, 0x1e5e2004, 0x021204a4, 0x51000419,   // bg.tt.un_440 sq.ts.ms_332  fi.hu.da_433 fi.kl.un_750 
  0x04542812, 0x47000209, 0x04005122, 0x071504a4,   // sw.ik.fi_654 da.sn.un_440  kl.fi.un_870 ru.bg.un_430 
  0x111d40a7, 0x350a30a4, 0x4410305a, 0x06004308,   // lb.la.ro_532 uz.mk.tg_433  uz.be.kk_553 ie.de.un_430 
  0x3534550e, 0x162d2905, 0xfc3545a4, 0x253911a7,   // rw.xh.zu_555 sl.sk.hr_333  ln.zu.zzp_433 ro.br.eu_532 
  // [ab40]
  0x39000519, 0x25000505, 0x1104130b, 0x353439af,   // fr.br.un_750 fr.eu.un_330  et.fi.ro_542 br.xh.zu_655 
  0x28000408, 0x48070404, 0x093905ad, 0x2e0e0607,   // fi.sw.un_430 ru.bg.tt_332  fr.br.pl_643 de.is.fo_432 
  0x48172907, 0x30001108, 0x3d211202, 0x4800100b,   // sl.sr.tt_432 ro.uz.un_430  ur.fa.ku_222 be.tt.un_520 
  0x3d183404, 0x281812ec, 0x0f2410af, 0x55343507,   // ps.ar.ku_332 ur.ar.sd_644  lt.eo.lv_655 zu.xh.rw_432 
  // [ab50]
  0x39003e14, 0x040f1011, 0x084d13ad, 0x3b006b04,   // rm.br.un_660 lt.lv.fi_653  et.aa.no_643 ceb.so.un_320 
  0x15004819, 0x100f13ee, 0x29001b04, 0x21001a12,   // tt.un.un_750 et.lv.lt_422  tr.sl.un_320 tl.jw.un_640 
  0x64594b07, 0x1f00520d, 0x4f00040d, 0x0f006e05,   // mi.rn.lg_432 ha.cy.un_540  fi.bi.un_540 hmn.lv.un_330 
  0x10000c1a, 0x49474b04, 0x55735f11, 0x64216aad,   // sv.lt.un_760 mi.sn.to_332  tn.ny.rw_653 haw.jw.lg_643 
  // [ab60]
  0x120532a0, 0x25532402, 0x4a5f2509, 0x0f006e08,   // bs.fr.hu_322 eo.ht.eu_222  eu.tn.yo_444 hmn.lv.un_430 
  0x305f26a7, 0x4d005508, 0x3f0f1304, 0x427905ad,   // ia.tn.uz_532 rw.aa.un_430  et.lv.af_332 fr.war.co_643 
  0x6e0f10a9, 0x022e0ea4, 0x0600010c, 0xfc0e2ead,   // lt.lv.hmn_544 is.fo.da_433  en.de.un_530 fo.is.zzp_643 
  0x303538ad, 0x354834ad, 0x343c2304, 0xfc2c03ee,   // tk.tg.uz_643 xh.tt.zu_643  ky.ug.ps_332 nl.fy.zzp_422 
  // [ab70]
  0x35004708, 0x350264ad, 0x3b617907, 0x01005312,   // sn.zu.un_430 lg.da.zu_643  war.za.so_432 ht.en.un_640 
  0x29004304, 0x5e346114, 0x2300252b, 0x4b2159a4,   // ie.sl.un_320 za.xh.ts_666  mn.ky.un_980 rn.jw.mi_433 
  0x3f4b290c, 0x5d6b7904, 0x29164a0c, 0x55244ba7,   // sl.mi.af_543 war.ceb.ss_332  yo.hr.sl_543 mi.eo.rw_532 
  0x07043002, 0x1f617908, 0x17000822, 0x15111ea4,   // uz.ru.bg_222 war.za.cy_443  uk.sr.un_870 ms.ro.un_433 
  // [ab80]
  0x211834a9, 0x11001007, 0x4c00611a, 0x2348440e,   // ps.ar.fa_544 lt.ro.un_420  za.wo.un_760 kk.tt.ky_555 
  0x3e002c04, 0x48340107, 0x1f2873a6, 0x4800210e,   // fy.rm.un_320 en.xh.tt_432  ny.sw.cy_521 jw.tt.un_550 
  0x0000342d, 0x2c004002, 0x060451ac, 0x2e006b04,   // ps.un.un_A00 lb.fy.un_220  kl.fi.de_632 ceb.fo.un_320 
  0x473502ee, 0x1a007304, 0x44374808, 0x7300781b,   // da.zu.sn_422 ny.tl.un_320  tt.ba.kk_443 ve.ny.un_770 
  // [ab90]
  0x1d0e04a0, 0x44382312, 0x0a287307, 0x355c02a7,   // fi.is.la_322 ky.tk.kk_654  ny.sw.pt_432 da.sa.zu_532 
  0x59553505, 0x28367355, 0x05005121, 0x47027307,   // zu.rw.rn_333 ny.gn.sw_442  kl.fr.un_860 ny.da.sn_432 
  0x13335107, 0x024a2812, 0x6402550e, 0x36007319,   // kl.nn.et_432 sw.yo.da_654  rw.da.lg_555 ny.gn.un_750 
  0x02005908, 0x3e0b0704, 0x04153c07, 0x645d57a4,   // rn.da.un_430 it.es.rm_332  ug.ru.un_420 na.ss.lg_433 
  // [aba0]
  0x283673ee, 0x47457307, 0x1a7328ad, 0x4731300c,   // ny.gn.sw_422 ny.ln.sn_432  sw.ny.tl_643 uz.az.sn_543 
  0x30100aa0, 0x7335180c, 0x1704300c, 0x5f75730c,   // mk.be.uz_322 ga.zu.ny_543  uz.ru.sr_543 ny.nso.tn_543 
  0x48005302, 0x47006402, 0x3b005007, 0x37004514,   // ht.tt.un_220 lg.sn.un_220  fj.so.un_420 ln.st.un_660 
  0x090d1cec, 0x48170a02, 0x301535ee, 0x641b53a0,   // mr.ne.hi_644 mk.sr.tt_222  tg.uz.un_420 ht.tr.lg_322 
  // [abb0]
  0x303823af, 0x172d32a0, 0x31002508, 0x483736ad,   // ky.tk.uz_655 bs.sk.sr_322  eu.az.un_430 ab.ba.tt_643 
  0x4a5a56a4, 0x35443008, 0x38304807, 0x42393e0c,   // mg.sm.yo_433 uz.kk.tg_443  tt.uz.tk_432 rm.br.co_543 
  0x05003e05, 0x10001712, 0x444837a4, 0x110539a0,   // rm.fr.un_330 sr.be.un_640  ba.tt.kk_433 br.fr.ro_322 
  0x79464807, 0x25000507, 0x373530af, 0x170a380c,   // tt.qu.war_432 fr.eu.un_420  uz.tg.ba_655 tk.mk.sr_543 
  // [abc0]
  0x05392504, 0x1a000102, 0x0a0905a0, 0x401ffe12,   // eu.br.fr_332 en.tl.un_220  fr.pl.pt_322 tlh.cy.lb_654 
  0x565559a7, 0x645520a4, 0x4844380c, 0x22020708,   // rn.rw.mg_532 sq.rw.lg_433  tk.kk.tt_543 it.da.oc_443 
  0x112505a0, 0x27006404, 0x11150aa4, 0x59212004,   // fr.eu.ro_322 lg.gd.un_320  mk.ro.un_430 sq.jw.rn_332 
  0x6400560c, 0x5700241b, 0x3011350e, 0x1f1d30a7,   // mg.lg.un_530 eo.na.un_770  tg.ro.uz_555 uz.la.cy_532 
  // [abd0]
  0x231525ad, 0x382344a9, 0x3f2701a0, 0x2f004f04,   // mn.ky.un_630 kk.ky.tk_544  en.gd.af_322 bi.su.un_320 
  0x480a23ad, 0x2f001504, 0x10000108, 0x211228a4,   // ky.mk.tt_643 un.su.un_320  en.lt.un_430 sd.ur.fa_433 
  0x1f003809, 0x4a256807, 0x64002a0b, 0x0a0724ee,   // tk.cy.un_440 ig.eu.yo_432  mt.lg.un_520 eo.it.pt_422 
  0x1a355504, 0x1b0f130d, 0x42002a13, 0x0f00570d,   // rw.zu.tl_332 et.lv.tr_554  mt.co.un_650 na.lv.un_540 
  // [abe0]
  0x0000fa1c, 0x0100671a, 0x38006521, 0x32372da0,   // nr.un.un_800 un.iw.un_760  gv.tk.un_860 sk.st.bs_322 
  0x04382312, 0x3f3309a0, 0x04006512, 0x4a00210d,   // ky.tk.ru_654 pl.nn.af_322  gv.fi.un_640 jw.yo.un_540 
  0x16000904, 0x482330a9, 0x162d0d08, 0x57000919,   // pl.hr.un_320 uz.ky.tt_544  cs.sk.hr_443 pl.na.un_750 
  0x2a000d08, 0x08002e0d, 0x253650a6, 0x284973a0,   // cs.mt.un_430 fo.no.un_540  fj.gn.eu_521 ny.to.sw_322 
  // [abf0]
  0x2a003105, 0x07360807, 0x30495aa0, 0x65002712,   // az.mt.un_330 uk.ab.bg_432  sm.to.uz_322 gd.gv.un_640 
  0x54005a09, 0xfc50490b, 0x213b3dec, 0x231744ee,   // sm.ik.un_440 to.fj.zzp_542  ku.ks.fa_644 kk.sr.ky_422 
  0x063e635a, 0x3708040c, 0x360a690c, 0x5d3435a4,   // sco.rm.de_553 ru.uk.ba_543  mfe.pt.gn_543 zu.xh.ss_433 
  0x482338ee, 0x213b20a6, 0x0207fc0c, 0x072b110c,   // tk.ky.tt_422 sq.so.jw_521  zzp.it.da_543 ro.vi.it_543 
  
  // [ac00]
  0x483c1555, 0x58122607, 0x035319a0, 0x3e13040c,   // un.ug.tt_442 ia.hu.om_432  gl.ht.nl_322 fi.et.rm_543 
  0x40003907, 0x1d000409, 0x3e2a01a4, 0x02593912,   // br.lb.un_420 fi.la.un_440  en.mt.rm_433 br.rn.da_654 
  0x452212a4, 0x20003705, 0x11001e04, 0x23006907,   // hu.oc.ln_433 st.sq.un_330  ms.ro.un_320 mfe.ca.un_420 
  0x7600010d, 0x040652a0, 0x30206412, 0x0a120655,   // en.crs.un_540 ha.de.fi_322  lg.sq.uz_654 de.hu.pt_442 
  // [ac10]
  0x1e00390b, 0x37625daf, 0x04581205, 0x23005807,   // br.ms.un_520 ss.kha.st_655  hu.om.fi_333 om.ca.un_420 
  0x2f401e04, 0x34182805, 0x3f5b4007, 0x21443407,   // ms.lb.su_332 sd.ar.ps_333  lb.sg.af_432 ps.kk.fa_432 
  0x080a1507, 0xfe002a12, 0x0e43fc04, 0x0a4212a4,   // un.mk.uk_432 mt.tlh.un_640  zzp.ie.is_332 hu.co.pt_433 
  0x2f6b06a0, 0x0e003f0d, 0x47006112, 0x2a1745a0,   // de.ceb.su_322 af.is.un_540  za.sn.un_640 ln.sr.mt_322 
  // [ac20]
  0x3639610c, 0xfc003009, 0x170c13a7, 0x23463e07,   // za.br.gn_543 uz.zzp.un_440  et.sv.sr_532 rm.qu.ca_432 
  0x330c02a0, 0x58090108, 0x10001809, 0x3e190b08,   // da.sv.nn_322 en.pl.om_443  ga.lt.un_440 es.gl.rm_443 
  0x4019050d, 0x17040809, 0x2100fe05, 0x0835150b,   // fr.gl.lb_554 uk.ru.sr_444  tlh.jw.un_330 un.tg.uk_542 
  0x20001304, 0x1d2479a0, 0x290e0c08, 0xfc060ca0,   // et.sq.un_320 war.eo.la_322  sv.is.sl_443 sv.de.zzp_322 
  // [ac30]
  0x30003713, 0x01794fac, 0x0c0efcee, 0x234425a9,   // ba.uz.un_650 bi.war.en_632  zzp.is.sv_422 mn.kk.ky_544 
  0x104a2aa7, 0x27000907, 0x432a3ea4, 0x13002204,   // mt.yo.lt_532 pl.gd.un_420  rm.mt.ie_433 oc.et.un_320 
  0x25002321, 0x233e2a05, 0x0a0811a9, 0x3f000f07,   // ca.eu.un_860 mt.rm.ca_333  ro.uk.mk_544 lv.af.un_420 
  0x3c1530af, 0x62042008, 0x0d00fe1a, 0x355e5f04,   // uz.ug.un_650 sq.fi.kha_443  tlh.cs.un_760 tn.ts.zu_332 
  // [ac40]
  0x170a0408, 0x2100060c, 0x123d3411, 0x12002902,   // ru.mk.sr_443 de.jw.un_530  ps.ku.ur_653 sl.hu.un_220 
  0x351358a0, 0x5600040c, 0x10070860, 0x375f75af,   // om.et.zu_322 fi.mg.un_530  uk.bg.be_664 nso.tn.st_655 
  0x305338a0, 0x06003505, 0x2800fa1b, 0x29130460,   // tk.ht.uz_322 zu.de.un_330  nr.sw.un_770 fi.et.sl_664 
  0x381b480c, 0x35644907, 0x35341ca4, 0x29000e08,   // tt.tr.tk_543 to.lg.zu_432  id.xh.zu_433 is.sl.un_430 
  // [ac50]
  0x2159555a, 0x4804150c, 0x071736ee, 0x080a1709,   // rw.rn.jw_553 un.ru.tt_543  ab.sr.bg_422 sr.mk.uk_444 
  0x1d595707, 0x102f1c02, 0x2c122aa7, 0x0a1704a0,   // na.rn.la_432 id.su.lt_222  mt.hu.fy_532 ru.sr.mk_322 
  0x04001523, 0x36001534, 0x0a1523a6, 0x17000721,   // un.ru.un_880 un.ab.un_A80  ky.mk.un_510 bg.sr.un_860 
  0x37005d04, 0x365a58a4, 0x5d002a09, 0x28123b09,   // ss.st.un_320 om.sm.gn_433  mt.ss.un_440 ks.ur.sd_444 
  // [ac60]
  0x1544150c, 0x1326fa08, 0x0a170804, 0x2735110c,   // un.kk.un_543 nr.ia.et_443  uk.sr.mk_332 ro.zu.gd_543 
  0x675230a4, 0x655d3504, 0x0d001c04, 0x2f4c3b0c,   // uz.ha.ak_433 zu.ss.gv_332  mr.ne.un_320 so.wo.su_543 
  0x02524509, 0x34004413, 0x0b4c4308, 0x2f007308,   // ln.ha.da_444 kk.ps.un_650  ie.wo.es_443 ny.su.un_430 
  0x5773010b, 0x3b00020e, 0x30483114, 0x63420207,   // en.ny.na_542 da.so.un_550  az.tt.uz_666 da.co.sco_432 
  // [ac70]
  0xfe1b450c, 0x38650407, 0x29005c04, 0x1b214ca7,   // ln.tr.tlh_543 fi.gv.tk_432  sa.sl.un_320 wo.jw.tr_532 
  0x01002905, 0x65003302, 0x2f002007, 0x53005804,   // sl.en.un_330 nn.gv.un_220  sq.su.un_420 om.ht.un_320 
  0x5e565213, 0xfc5d3504, 0x354707a4, 0x04131807,   // ha.mg.ts_665 zu.ss.zzp_332  it.sn.zu_433 ga.et.fi_432 
  0x4a002108, 0x64027311, 0x28003b19, 0x0d000c02,   // jw.yo.un_430 ny.da.lg_653  ks.sd.un_750 sv.cs.un_220 
  // [ac80]
  0x21510107, 0x311b5208, 0x023073ec, 0x03001307,   // en.kl.jw_432 ha.tr.az_443  ny.uz.da_644 et.nl.un_420 
  0x3b4831ee, 0x5e02050c, 0x4c007318, 0x39001209,   // az.tt.so_422 fr.da.ts_543  ny.wo.un_740 hu.br.un_440 
  0x455c02a4, 0x254815af, 0x070a0409, 0x3802330c,   // da.sa.ln_433 un.tt.mn_655  ru.mk.bg_444 nn.da.tk_543 
  0x130454ee, 0x20041355, 0x1100120c, 0x23001f12,   // ik.fi.et_422 et.fi.sq_442  hu.ro.un_530 cy.ca.un_640 
  // [ac90]
  0x2c6505ee, 0x071530a9, 0x39001208, 0x0a003902,   // fr.gv.fy_422 uz.bg.un_540  hu.br.un_430 br.pt.un_220 
  0x64476a0b, 0x6b281307, 0x474b5a09, 0x7800671b,   // haw.sn.lg_542 et.sw.ceb_432  sm.mi.sn_444 ak.ve.un_770 
  0x135d78a0, 0x13004608, 0x0c630111, 0x4800070e,   // ve.ss.et_322 qu.et.un_430  en.sco.sv_653 bg.tt.un_550 
  0x25595513, 0x22000b07, 0x2f005908, 0x056301ee,   // rw.rn.eu_665 es.oc.un_420  rn.su.un_430 en.sco.fr_422 
  // [aca0]
  0x3e001d07, 0x20006822, 0x36003e11, 0x6b595513,   // la.rm.un_420 ig.sq.un_870  rm.gn.un_630 rw.rn.ceb_665 
  0x37004402, 0x44352307, 0x34282105, 0x39595555,   // kk.ba.un_220 ky.tg.kk_432  fa.sd.ps_333 rw.rn.br_442 
  0xfe55580c, 0x135e5908, 0x045601a0, 0x126a690c,   // om.rw.tlh_543 rn.ts.et_443  en.mg.fi_322 mfe.haw.hu_543 
  0x68003308, 0x16342007, 0x53765005, 0x4b003e0d,   // nn.ig.un_430 sq.xh.hr_432  fj.crs.ht_333 rm.mi.un_540 
  // [acb0]
  0x3600042a, 0x235a1055, 0x02515da4, 0x13792fa9,   // fi.gn.un_970 lt.sm.ca_442  ss.kl.da_433 su.war.et_544 
  0x3e005a07, 0x2f00130c, 0x2100281b, 0x63045207,   // sm.rm.un_420 et.su.un_530  sd.fa.un_770 ha.fi.sco_432 
  0x433e1da4, 0x304423a4, 0x29011a02, 0x12502fa0,   // la.rm.ie_433 ky.kk.uz_433  tl.en.sl_222 su.fj.hu_322 
  0x3e00330d, 0x4c0e785a, 0x03330807, 0x0c430e07,   // nn.rm.un_540 ve.is.wo_553  no.nn.nl_432 is.ie.sv_432 
  // [acc0]
  0x18344408, 0x48005e23, 0x0e1125a4, 0x68004a09,   // kk.ps.ar_443 ts.tt.un_880  eu.ro.is_433 yo.ig.un_440 
  0x01002604, 0x556a59af, 0x73124507, 0x10004308,   // ia.en.un_320 rn.haw.rw_655  ln.hu.ny_432 ie.lt.un_430 
  0x47005005, 0x1f006b07, 0x73002c09, 0x7320590d,   // fj.sn.un_330 ceb.cy.un_420  fy.ny.un_440 rn.sq.ny_554 
  0x63004608, 0x42003609, 0x2c2f120c, 0x20132fad,   // qu.sco.un_430 gn.co.un_440  hu.su.fy_543 su.et.sq_643 
  // [acd0]
  0x6b206904, 0x20003505, 0x091c1355, 0x35002004,   // mfe.sq.ceb_332 zu.sq.un_330  bh.mr.hi_442 sq.zu.un_320 
  0x1d016307, 0x2c003920, 0x08021eee, 0x2f004904,   // sco.en.la_432 br.fy.un_850  ms.da.no_422 to.su.un_320 
  0x303d210d, 0x4a00681b, 0x0d1c5c02, 0x04001e04,   // fa.ku.uz_554 ig.yo.un_770  sa.mr.ne_222 ms.fi.un_320 
  0x34182809, 0x512e0208, 0x1f1a5211, 0x2f094604,   // sd.ar.ps_444 da.fo.kl_443  ha.tl.cy_653 qu.pl.su_332 
  // [ace0]
  0x2f3f4eec, 0x3e1225a0, 0x3c233812, 0x25003104,   // ay.af.su_644 eu.hu.rm_322  tk.ky.ug_654 az.eu.un_320 
  0x481511ec, 0x30002109, 0x041517af, 0x1b3b300c,   // ro.tt.un_640 fa.uz.un_440  sr.ru.un_650 uz.so.tr_543 
  0x07100a09, 0x301b3b04, 0x3b304daf, 0x3b2830a4,   // mk.be.bg_444 so.tr.uz_332  aa.uz.so_655 uz.sw.so_433 
  0x3d003b07, 0x536b3004, 0x070a1514, 0x313b2b04,   // ks.ku.un_420 uz.ceb.ht_332  un.mk.bg_666 vi.so.az_332 
  // [acf0]
  0x65fc3b0c, 0x3b304804, 0x63125ca9, 0x351afea7,   // so.zzp.gv_543 tt.uz.so_332  sa.hu.sco_544 tlh.tl.zu_532 
  0x201b3804, 0x42560404, 0x330504ad, 0x323b2d02,   // tk.tr.sq_332 fi.mg.co_332  fi.fr.nn_643 sk.so.bs_222 
  0x171511a4, 0x0a170404, 0x0d093baf, 0x0a071760,   // ro.sr.un_430 ru.sr.mk_332  ks.hi.ne_655 sr.bg.mk_664 
  0x382352ad, 0x65691d07, 0x2f003802, 0x484638a6,   // ha.ca.tk_643 la.mfe.gv_432  tk.su.un_220 tk.qu.tt_521 
  // [ad00]
  0x44000702, 0x35113805, 0x053904a4, 0x65006212,   // bg.kk.un_220 tk.ro.tg_333  fi.br.fr_433 kha.gv.un_640 
  0x3b004c19, 0x38005222, 0x4c3b02a4, 0x7903010c,   // wo.so.un_750 ha.tk.un_870  da.so.wo_433 en.nl.war_543 
  0x3f134d09, 0x12254a09, 0x3b385213, 0x1e3846a0,   // aa.et.af_444 yo.eu.hu_444  ha.tk.so_665 qu.tk.ms_322 
  0x47005504, 0x48006012, 0x48443707, 0x251b3860,   // rw.sn.un_320 vo.tt.un_640  ba.kk.tt_432 tk.tr.eu_664 
  // [ad10]
  0x113c080c, 0x5c00690c, 0x642a2807, 0x1d50fc0c,   // uk.ug.ro_543 mfe.sa.un_530  sw.mt.lg_432 zzp.fj.la_543 
  0x5d001508, 0x23170a08, 0x40343507, 0x15030205,   // un.ss.un_430 mk.sr.ky_443  zu.xh.lb_432 da.nl.un_333 
  0x04173704, 0x18343d04, 0x4c3f1307, 0x30002a08,   // ba.sr.ru_332 ku.ps.ar_332  et.af.wo_432 mt.uz.un_430 
  0x3e000609, 0x080715ad, 0x2a003b1a, 0x5c00511a,   // de.rm.un_440 un.bg.uk_643  so.mt.un_760 kl.sa.un_760 
  // [ad20]
  0x46253ba7, 0x3b1e2aee, 0x21fc2f07, 0x6afc6555,   // so.eu.qu_532 mt.ms.so_422  su.zzp.jw_432 gv.zzp.haw_442 
  0x48002320, 0x4635090c, 0x2f004b08, 0x39fc46a4,   // ky.tt.un_850 pl.zu.qu_543  mi.su.un_430 qu.zzp.br_433 
  0x25795f07, 0x32424307, 0x34213055, 0xfc00460c,   // tn.war.eu_432 ie.co.bs_432  uz.fa.ps_442 qu.zzp.un_530 
  0x25522a04, 0x18002114, 0x210c200c, 0x443825ec,   // mt.ha.eu_332 fa.ar.un_660  sq.sv.jw_543 mn.tk.kk_644 
  // [ad30]
  0x3b2a5255, 0x30001f07, 0x422a13ee, 0x30484408,   // ha.mt.so_442 cy.uz.un_420  et.mt.co_422 kk.tt.uz_443 
  0x1c00fc05, 0xfc001c08, 0x38234405, 0x442328a4,   // zzp.id.un_330 id.zzp.un_430  kk.ky.tk_333 sd.ky.kk_433 
  0x303163a0, 0x06004c08, 0x28fa73a4, 0x150e3004,   // sco.az.uz_322 wo.de.un_430  ny.nr.sw_433 uz.is.un_332 
  0x1536380c, 0x67756408, 0x0e00580d, 0x4c000c09,   // tk.ab.un_543 lg.nso.ak_443  om.is.un_540 sv.wo.un_440 
  // [ad40]
  0x3b3f2da0, 0x20000414, 0x2d093ba0, 0x5c001a04,   // sk.af.so_322 fi.sq.un_660  so.pl.sk_322 tl.sa.un_320 
  0x0a0711ec, 0x33023ba0, 0x1d002908, 0x52005804,   // ro.bg.mk_644 so.da.nn_322  sl.la.un_430 om.ha.un_320 
  0x49284705, 0x0c650407, 0x472873a9, 0xfefc29ee,   // sn.sw.to_333 fi.gv.sv_432  ny.sw.sn_544 sl.zzp.tlh_422 
  0x1e000505, 0x55734712, 0x291658a0, 0x1d6a4fec,   // fr.ms.un_330 sn.ny.rw_654  om.hr.sl_322 bi.haw.la_644 
  // [ad50]
  0x5a00220e, 0x18000302, 0x4211fca4, 0x17361112,   // oc.sm.un_550 nl.ga.un_220  zzp.ro.co_433 ro.ab.sr_654 
  0x1d4208a0, 0x734a5514, 0x47006a07, 0x1d003708,   // no.co.la_322 rw.yo.ny_666  haw.sn.un_420 st.la.un_430 
  0x21552f09, 0x10007904, 0x4326290c, 0x08000907,   // su.rw.jw_444 war.lt.un_320  sl.ia.ie_543 pl.no.un_420 
  0x2915fc0c, 0x595573a9, 0x2700040d, 0xfefc2955,   // zzp.sl.un_530 ny.rw.rn_544  fi.gd.un_540 sl.zzp.tlh_442 
  // [ad60]
  0x483c380c, 0xfc1b29a0, 0x1d26010c, 0x0c1f30a4,   // tk.ug.tt_543 sl.tr.zzp_322  en.ia.la_543 uz.cy.sv_433 
  0x1d100bad, 0x370d1007, 0x0f007905, 0x44372302,   // es.lt.la_643 lt.cs.st_432  war.lv.un_330 ky.ba.kk_222 
  0x123c2307, 0x0a174813, 0x330802ec, 0x18343012,   // ky.ug.ur_432 tt.sr.mk_665  da.no.nn_644 uz.ps.ar_654 
  0x1a00020c, 0x35391207, 0x2c170602, 0x24103307,   // da.tl.un_530 hu.br.zu_432  de.sr.fy_222 nn.lt.eo_432 
  // [ad70]
  0xfe286e04, 0x03006b08, 0x39000502, 0x47455912,   // hmn.sw.tlh_332 ceb.nl.un_430  fr.br.un_220 rn.ln.sn_654 
  0x35455907, 0x081015ad, 0x73454712, 0x344535a4,   // rn.ln.zu_432 un.be.uk_643  sn.ln.ny_654 zu.ln.xh_433 
  0x091c13ee, 0x02001f13, 0x36002b09, 0x30341204,   // bh.mr.hi_422 cy.da.un_650  vi.gn.un_440 ur.ps.uz_332 
  0x2c00650c, 0x4900361b, 0x2d000905, 0x0912260c,   // gv.fy.un_530 gn.to.un_770  pl.sk.un_330 ia.hu.pl_543 
  // [ad80]
  0x496a67ec, 0x524a36a0, 0x67456aa4, 0x35005913,   // ak.haw.to_644 gn.yo.ha_322  haw.ln.ak_433 rn.zu.un_650 
  0x1e1c4eee, 0x3500360c, 0x2c006e0d, 0x17201bee,   // ay.id.ms_422 ab.tg.un_530  hmn.fy.un_540 tr.sq.sr_422 
  0x346735ad, 0x2d000f13, 0x04251505, 0x38643ba0,   // zu.ak.xh_643 lv.sk.un_650  un.mn.ru_333 so.lg.tk_322 
  0xfe006e2b, 0x37551ea0, 0x29000f09, 0x755f2108,   // hmn.tlh.un_980 ms.rw.st_322  lv.sl.un_440 jw.tn.nso_443 
  // [ad90]
  0x30000812, 0x32003007, 0x6a494ba4, 0x0d2d365a,   // uk.uz.un_640 uz.bs.un_420  mi.to.haw_433 gn.sk.cs_553 
  0x17335eaf, 0x23304802, 0x4b502808, 0x2f002d05,   // ts.nn.sr_655 tt.uz.ky_222  sw.fj.mi_443 sk.su.un_330 
  0x214b5ea9, 0x21183d04, 0x092f540d, 0x621d6308,   // ts.mi.jw_544 ku.ar.fa_332  ik.su.pl_554 sco.la.kha_443 
  0x10000f17, 0x23151107, 0x1e00520e, 0x08382308,   // lv.lt.un_730 ro.ky.un_420  ha.ms.un_550 ky.tk.uk_443 
  // [ada0]
  0x10002d07, 0x29007508, 0x240e6ba7, 0x0c003007,   // sk.lt.un_420 nso.sl.un_430  ceb.is.eo_532 uz.sv.un_420 
  0x03003002, 0x44103708, 0x080438ee, 0x2a192355,   // uz.nl.un_220 ba.be.kk_443  tk.ru.uk_422 ca.gl.mt_442 
  0x0a002309, 0x3400fe0c, 0x79006b0e, 0x482523a9,   // ca.pt.un_440 tlh.xh.un_530  ceb.war.un_550 ky.mn.tt_544 
  0x1a001307, 0x25153612, 0x4800040c, 0x11003904,   // et.tl.un_420 ab.mn.un_640  ru.tt.un_530 br.ro.un_320 
  // [adb0]
  0x30002123, 0x0a0744a0, 0x23254812, 0x4836230c,   // fa.uz.un_880 kk.bg.mk_322  tt.mn.ky_654 ky.ab.tt_543 
  0x2d003208, 0x2a004d13, 0x374844ec, 0x3e3905a4,   // bs.sk.un_430 aa.mt.un_650  kk.tt.ba_644 fr.br.rm_433 
  0x0a003609, 0x04073005, 0x151008ec, 0x162d0d05,   // ab.mk.un_440 uz.bg.ru_333  uk.be.un_644 cs.sk.hr_333 
  0x2d0d17a4, 0x17000d05, 0x083035af, 0xfe002b12,   // sr.cs.sk_433 cs.sr.un_330  tg.uz.uk_655 vi.tlh.un_640 
  // [adc0]
  0x10170a07, 0x11174412, 0x1334590c, 0x5e656aaf,   // mk.sr.be_432 kk.sr.ro_654  rn.xh.et_543 haw.gv.ts_655 
  0x5d5535a0, 0x49126a10, 0x65005613, 0x64000213,   // zu.rw.ss_322 haw.hu.to_642  mg.gv.un_650 da.lg.un_650 
  0x56006504, 0x0a3515a0, 0x45004213, 0x64354aa4,   // gv.mg.un_320 un.tg.mk_322  co.ln.un_650 yo.zu.lg_433 
  0x405d3507, 0x5e09280c, 0x33005a05, 0x215c35a0,   // zu.ss.lb_432 sw.pl.ts_543  sm.nn.un_330 zu.sa.jw_322 
  // [add0]
  0x64005514, 0x5d5c5e12, 0x25211fa4, 0x55000208,   // rw.lg.un_660 ts.sa.ss_654  cy.jw.eu_433 da.rw.un_430 
  0x6468500c, 0x643534ec, 0x08370404, 0x61006e29,   // fj.ig.lg_543 xh.zu.lg_644  ru.ba.uk_332 hmn.za.un_960 
  0x3e6518a0, 0x3b215eec, 0x640212ec, 0x64092507,   // ga.gv.rm_322 ts.jw.so_644  hu.da.lg_644 eu.pl.lg_432 
  0x4b13490c, 0x363c150c, 0x211a3fa4, 0x4c004d12,   // to.et.mi_543 un.ug.ab_543  af.tl.jw_433 aa.wo.un_640 
  // [ade0]
  0x6e004708, 0x5a1849ee, 0x300431a0, 0x5c002819,   // sn.hmn.un_430 to.ga.sm_422  az.fi.uz_322 sw.sa.un_750 
  0x4800111a, 0x5e00611a, 0x6b6860ee, 0x5e004904,   // ro.tt.un_760 za.ts.un_760  vo.ig.ceb_422 to.ts.un_320 
  0x3534610c, 0x233748a4, 0x15003505, 0x46285208,   // za.xh.zu_543 tt.ba.ky_433  zu.un.un_330 ha.sw.qu_443 
  0x27181304, 0x46344e08, 0x1d1827ee, 0x3349fc11,   // et.ga.gd_332 ay.xh.qu_443  gd.ga.la_422 zzp.to.nn_653 
  // [adf0]
  0x1827010c, 0x18471104, 0xfc00631a, 0x183d2104,   // en.gd.ga_543 ro.sn.ga_332  sco.zzp.un_760 fa.ku.ar_332 
  0x153035ec, 0x391c2505, 0x632711a4, 0x1d1918a4,   // tg.uz.un_644 eu.id.br_333  ro.gd.sco_433 ga.gl.la_433 
  0x276301a0, 0x28301812, 0x17083c05, 0x1b2f1e07,   // en.sco.gd_322 ar.uz.sd_654  ug.uk.sr_333 ms.su.tr_432 
  0x63016ba0, 0x2f361d04, 0x52000104, 0x215c4e08,   // ceb.en.sco_322 la.gn.su_332  en.ha.un_320 ay.sa.jw_443 
  // [ae00]
  0x1e1c2109, 0x2f2862a9, 0x31473bec, 0x5f5c4e0c,   // jw.id.ms_444 kha.sw.su_544  so.sn.az_644 ay.sa.tn_543 
  0x266301a7, 0x024a3b12, 0x6b1a52ec, 0x041710ee,   // en.sco.ia_532 so.yo.da_654  ha.tl.ceb_644 be.sr.ru_422 
  0x212f1c0c, 0xfe476304, 0x52674c07, 0x15003608,   // id.su.jw_543 sco.sn.tlh_332  wo.ak.ha_432 ab.un.un_430 
  0x270b1855, 0x52487304, 0x02190b0d, 0x1744350c,   // ga.es.gd_442 ny.tt.ha_332  es.gl.da_554 tg.kk.sr_543 
  // [ae10]
  0x2f213ba4, 0x314c3b07, 0x2f5f3ba4, 0x1b316804,   // so.jw.su_433 so.wo.az_432  so.tn.su_433 ig.az.tr_332 
  0x4752310c, 0xfe3b46a6, 0x314e3b11, 0x500b5ca7,   // az.ha.sn_543 qu.so.tlh_521  so.ay.az_653 sa.es.fj_532 
  0x52211e07, 0x731b1a09, 0x3038235a, 0x1b2f59ad,   // ms.jw.ha_432 tl.tr.ny_444  ky.tk.uz_553 rn.su.tr_643 
  0x463b5005, 0x150425a9, 0x28123455, 0x5f353414,   // fj.so.qu_333 mn.ru.un_544  ps.ur.sd_442 xh.zu.tn_666 
  // [ae20]
  0x40576507, 0x2e0c13ee, 0x130f3eee, 0x635701a4,   // gv.na.lb_432 et.sv.fo_422  rm.lv.et_422 en.na.sco_433 
  0x40436308, 0x785e7312, 0xfe064507, 0x151035ee,   // sco.ie.lb_443 ny.ts.ve_654  ln.de.tlh_432 tg.be.un_422 
  0x173810af, 0x34653e12, 0x4000062c, 0x353048a0,   // be.tk.sr_655 rm.gv.xh_654  de.lb.un_990 tt.uz.tg_322 
  0x0c635704, 0x2a006505, 0x48001002, 0x02004d08,   // na.sco.sv_332 gv.mt.un_330  be.tt.un_220 aa.da.un_430 
  // [ae30]
  0x1f002320, 0x083f2ca0, 0x111f2611, 0x1c003502,   // ca.cy.un_850 fy.af.no_322  ia.cy.ro_653 zu.id.un_220 
  0x400e6507, 0x3f024d0c, 0x05630155, 0x40001f22,   // gv.is.lb_432 aa.da.af_543  en.sco.fr_442 cy.lb.un_870 
  0x4d000e21, 0x46353409, 0x3723110c, 0x2e3306ee,   // is.aa.un_860 xh.zu.qu_444  ro.ky.ba_543 de.nn.fo_422 
  0x01002305, 0x03403f07, 0x37483ca9, 0x06fc40a0,   // ca.en.un_330 af.lb.nl_432  ug.tt.ba_544 lb.zzp.de_322 
  // [ae40]
  0x04005802, 0x4f001f19, 0x2315150b, 0x3f00530c,   // om.fi.un_220 cy.bi.un_750  un.ky.un_520 ht.af.un_530 
  0x330c08a9, 0x796b1aaf, 0x08070409, 0x311b48a9,   // no.sv.nn_544 tl.ceb.war_655  ru.bg.uk_444 tt.tr.az_544 
  0x024e4608, 0x02642aa4, 0x31481b0e, 0x6400090d,   // qu.ay.da_443 mt.lg.da_433  tr.tt.az_555 pl.lg.un_540 
  0x0a1736a0, 0x01003604, 0x2300620c, 0x0900460c,   // ab.sr.mk_322 gn.en.un_320  kha.ca.un_530 qu.pl.un_530 
  // [ae50]
  0x08151007, 0x12002f02, 0x1f081207, 0x18233c07,   // be.uk.un_420 su.hu.un_220  hu.no.cy_432 ug.ky.ar_432 
  0x47004b04, 0x522f210c, 0x25233760, 0xfc3f0907,   // mi.sn.un_320 jw.su.ha_543  ba.ky.mn_664 pl.af.zzp_432 
  0x12001f09, 0x21003d1b, 0x291748a0, 0x3000370e,   // cy.hu.un_440 ku.fa.un_770  tt.sr.sl_322 ba.uz.un_550 
  0x05001305, 0x65130404, 0x36562013, 0x6225040c,   // et.fr.un_330 fi.et.gv_332  sq.mg.gn_665 fi.eu.kha_543 
  // [ae60]
  0x524d3bad, 0x47650404, 0x6500040e, 0x04005123,   // so.aa.ha_643 fi.gv.sn_332  fi.gv.un_550 kl.fi.un_880 
  0x420451a4, 0x52650407, 0x30253811, 0x18000704,   // kl.fi.co_433 fi.gv.ha_432  tk.mn.uz_653 it.ga.un_320 
  0x51304205, 0x073536a0, 0x55560507, 0x422a06ad,   // co.uz.kl_333 ab.tg.bg_322  fr.mg.rw_432 de.mt.co_643 
  0x641251ad, 0x3708070c, 0x40050404, 0x0500120d,   // kl.hu.lg_643 bg.uk.ba_543  fi.fr.lb_332 hu.fr.un_540 
  // [ae70]
  0x2d0d20a0, 0x650504a4, 0x0a4212ad, 0x6204055a,   // sq.cs.sk_322 fi.fr.gv_433  hu.co.pt_643 fr.fi.kha_553 
  0x2b006808, 0x3e00090d, 0x131204a4, 0x063f03a7,   // ig.vi.un_430 pl.rm.un_540  fi.hu.et_433 nl.af.de_532 
  0x48442304, 0x121d51ac, 0x09135c05, 0x1b375f13,   // ky.kk.tt_332 kl.la.hu_632  sa.bh.hi_333 tn.st.tr_665 
  0x2213fe04, 0x30fe1b0c, 0x3e000d02, 0x06001b07,   // tlh.et.oc_332 tr.tlh.uz_543  cs.rm.un_220 tr.de.un_420 
  // [ae80]
  0x5f00fe13, 0x5a001702, 0x111d0a04, 0x48130407,   // tlh.tn.un_650 sr.sm.un_220  pt.la.ro_332 fi.et.tt_432 
  0x37fe2308, 0x0b001004, 0x3e00fe12, 0x18001f04,   // ca.tlh.st_443 lt.es.un_320  tlh.rm.un_640 cy.ga.un_320 
  0x1200680c, 0x1f00621b, 0x03002405, 0x081233a0,   // ig.hu.un_530 kha.cy.un_770  eo.nl.un_330 nn.hu.no_322 
  0x5c00200c, 0x0c003e0e, 0x206847af, 0x0a07250c,   // sq.sa.un_530 rm.sv.un_550  sn.ig.sq_655 mn.bg.mk_543 
  // [ae90]
  0x4253110c, 0x335ffe07, 0x46556408, 0x165ffeee,   // ro.ht.co_543 tlh.tn.nn_432  lg.rw.qu_443 tlh.tn.hr_422 
  0x30002313, 0x3b3779ee, 0x3000fe1a, 0x2a005607,   // ky.uz.un_650 war.st.so_422  tlh.uz.un_760 mg.mt.un_420 
  0x213d3b0c, 0x5e00fe12, 0x122f2107, 0x38081060,   // ks.ku.fa_543 tlh.ts.un_640  jw.su.hu_432 be.uk.tk_664 
  0x350830a0, 0x2500610c, 0x3527180b, 0x270c34a0,   // uz.uk.tg_322 za.eu.un_530  ga.gd.zu_542 xh.sv.gd_322 
  // [aea0]
  0x356a2505, 0x5c001f1b, 0x33085ca0, 0x25003022,   // eu.haw.zu_333 cy.sa.un_770  sa.no.nn_322 uz.eu.un_870 
  0x34271804, 0xfe730107, 0x27000204, 0x09355e04,   // ga.gd.xh_332 en.ny.tlh_432  da.gd.un_320 ts.zu.pl_332 
  0x27187812, 0x3ffe6512, 0x53192f04, 0x2f00120b,   // ve.ga.gd_654 gv.tlh.af_654  su.gl.ht_332 hu.su.un_520 
  0x38203f07, 0x40311b04, 0x12002f07, 0x1f5e650d,   // af.sq.tk_432 tr.az.lb_332  su.hu.un_420 gv.ts.cy_554 
  // [aeb0]
  0x08383513, 0x3d34120c, 0x3500380d, 0x151d01ad,   // tg.tk.uk_665 ur.ps.ku_543  tk.tg.un_540 en.la.un_643 
  0x3b003413, 0x35252804, 0x6e00250d, 0x1c0d5c0e,   // ps.ks.un_650 sw.eu.zu_332  eu.hmn.un_540 sa.ne.mr_555 
  0x09003b0c, 0x311b12a9, 0x08232510, 0x31121b04,   // ks.hi.un_530 hu.tr.az_544  mn.ky.uk_642 tr.hu.az_332 
  0x0800102a, 0x3025230c, 0x12343d02, 0x350408a4,   // be.uk.un_970 ky.mn.uz_543  ku.ps.ur_222 uk.ru.tg_433 
  // [aec0]
  0x2f041304, 0x130804a0, 0x04084807, 0x25000404,   // et.fi.su_332 fi.no.et_322  tt.uk.ru_432 ru.mn.un_320 
  0x0400601a, 0x6b1f13a9, 0x4a0742a4, 0x10121f55,   // vo.fi.un_760 et.cy.ceb_544  co.it.yo_433 cy.hu.lt_442 
  0x4a595504, 0x130438a4, 0x2e0e1604, 0x350804a4,   // rw.rn.yo_332 tk.fi.et_433  hr.is.fo_332 ru.uk.tg_433 
  0x0c130407, 0x0c24330c, 0x552a67ec, 0x5c002a0e,   // fi.et.sv_432 nn.eo.sv_543  ak.mt.rw_644 mt.sa.un_550 
  // [aed0]
  0x20005509, 0x55002a04, 0x2e2601a0, 0x20005c02,   // rw.sq.un_440 mt.rw.un_320  en.ia.fo_322 sa.sq.un_220 
  0x190a55a4, 0x2b001507, 0x15003c18, 0x13003808,   // rw.pt.gl_433 un.vi.un_420  ug.un.un_740 tk.et.un_430 
  0x257960a4, 0x690e53af, 0x3d213008, 0x450526ad,   // vo.war.eu_433 ht.is.mfe_655  uz.fa.ku_443 ia.fr.ln_643 
  0x596e55ad, 0x2d2047ad, 0x30443c0c, 0x555e365a,   // rw.hmn.rn_643 sn.sq.sk_643  ug.kk.uz_543 gn.ts.rw_553 
  // [aee0]
  0x6e006405, 0x110742a4, 0x645355a0, 0x1a3b5604,   // lg.hmn.un_330 co.it.ro_433  rw.ht.lg_322 mg.so.tl_332 
  0x05120a02, 0x19120a07, 0x230a0711, 0x2205530c,   // pt.hu.fr_222 pt.hu.gl_432  bg.mk.ky_653 ht.fr.oc_543 
  0x0d102d0c, 0x2a002109, 0x122f05a0, 0x25243407,   // sk.lt.cs_543 jw.mt.un_440  fr.su.hu_322 xh.eo.eu_432 
  0x11285da4, 0x351b0305, 0x08002702, 0x1ffe26af,   // ss.sw.ro_433 nl.tr.zu_333  gd.no.un_220 ia.tlh.cy_655 
  // [aef0]
  0x39051955, 0x02004519, 0x081038a4, 0x346502ee,   // gl.fr.br_442 ln.da.un_750  tk.be.uk_433 da.gv.xh_422 
  0x1900430d, 0x0d000207, 0x35345fa4, 0x2d123004,   // ie.gl.un_540 da.cs.un_420  tn.xh.zu_433 uz.hu.sk_332 
  0x4c004512, 0x4c052f09, 0x2d0d64a0, 0x6b000307,   // ln.wo.un_640 su.fr.wo_444  lg.cs.sk_322 nl.ceb.un_420 
  0x636547ee, 0x535576a6, 0x352845ee, 0x3035280c,   // sn.gv.sco_422 crs.rw.ht_521  ln.sw.zu_422 sw.zu.uz_543 
  // [af00]
  0x0449130c, 0x537345ad, 0xfc6301a9, 0x06006804,   // et.to.fi_543 ln.ny.ht_643  en.sco.zzp_544 ig.de.un_320 
  0x083011a4, 0x0a282007, 0x4a004804, 0x2300221a,   // ro.uz.uk_433 sq.sw.pt_432  tt.yo.un_320 oc.ca.un_760 
  0x1500080d, 0x1c641eaf, 0x30350aa0, 0x07002b07,   // uk.un.un_540 ms.lg.id_655  mk.tg.uz_322 vi.it.un_420 
  0x354573a0, 0x0c0603a0, 0x2d2973a4, 0x5d3573ad,   // ny.ln.zu_322 nl.de.sv_322  ny.sl.sk_433 ny.zu.ss_643 
  // [af10]
  0x47674a5a, 0x424505ee, 0x1e21fe02, 0x3c15360c,   // yo.ak.sn_553 fr.ln.co_422  tlh.jw.ms_222 ab.ug.un_530 
  0x366501a0, 0x23000a0c, 0x190b0aaf, 0x2f211204,   // en.gv.gn_322 mk.ky.un_530  pt.es.gl_655 hu.jw.su_332 
  0x12002205, 0x0500651b, 0x2b000104, 0x2b00071a,   // oc.hu.un_330 gv.fr.un_770  en.vi.un_320 it.vi.un_760 
  0x3b00210e, 0x2b005a02, 0x1c5a1fad, 0x0f1813a4,   // fa.ks.un_550 sm.vi.un_220  cy.sm.id_643 et.ga.lv_433 
  // [af20]
  0x1f526907, 0x24102211, 0x100f2407, 0x1f00420d,   // mfe.ha.cy_432 oc.lt.eo_653  eo.lv.lt_432 co.cy.un_540 
  0x64000219, 0x5200760b, 0x40002f02, 0x53640307,   // da.lg.un_750 crs.ha.un_520  su.lb.un_220 nl.lg.ht_432 
  0x791f2a12, 0x3f270c07, 0x07001111, 0x6e001f13,   // mt.cy.war_654 sv.gd.af_432  ro.bg.un_630 cy.hmn.un_650 
  0x041538a9, 0x0a1036ad, 0x1f006e13, 0x18006908,   // tk.ru.un_540 ab.be.mk_643  hmn.cy.un_650 mfe.ga.un_430 
  // [af30]
  0x1e006307, 0x69765213, 0x276b1a04, 0x060f64ee,   // sco.ms.un_420 ha.crs.mfe_665  tl.ceb.gd_332 lg.lv.de_422 
  0x4676690c, 0x08480404, 0x233428af, 0x11001f0c,   // mfe.crs.qu_543 ru.tt.uk_332  sd.ps.ky_655 cy.ro.un_530 
  0x3b0d1c0b, 0x47000208, 0x18276207, 0x4400180e,   // mr.ne.ks_542 da.sn.un_430  kha.gd.ga_432 ar.kk.un_550 
  0x2a0930a0, 0x65003612, 0x65000507, 0x07041955,   // uz.pl.mt_322 gn.gv.un_640  fr.gv.un_420 gl.fi.it_442 
  // [af40]
  0x392701a0, 0x421105ee, 0x170a0807, 0x65003919,   // en.gd.br_322 fr.ro.co_422  uk.mk.sr_432 br.gv.un_750 
  0x0a001505, 0x4800600c, 0x170748ee, 0x050408a0,   // un.mk.un_330 vo.tt.un_530  tt.bg.sr_422 no.fi.fr_322 
  0x23001802, 0x2500600b, 0x4afa2aad, 0x37483607,   // ga.ca.un_220 vo.eu.un_520  mt.nr.yo_643 ab.tt.ba_432 
  0x39002f08, 0x2a46640c, 0x3f124802, 0x28004512,   // su.br.un_430 lg.qu.mt_543  tt.hu.af_222 ln.sw.un_640 
  // [af50]
  0x64004522, 0x4500640e, 0x38483002, 0x382d48a0,   // ln.lg.un_870 lg.ln.un_550  uz.tt.tk_222 tt.sk.tk_322 
  0x6a452d07, 0x2315250c, 0x25000a0c, 0x18004413,   // sk.ln.haw_432 mn.ky.un_530  mk.mn.un_530 kk.ar.un_650 
  0x2c003f0d, 0x1c002d04, 0x0f3908a9, 0x1e002029,   // af.fy.un_540 sk.id.un_320  no.br.lv_544 ti.am.un_960 
  0x04002904, 0x49002905, 0x32002a0d, 0x04002e02,   // sl.fi.un_320 sl.to.un_330  mt.bs.un_540 fo.fi.un_220 
  // [af60]
  0x595513a4, 0x282d0d08, 0x2a005d04, 0x5f003713,   // et.rw.rn_433 cs.sk.sw_443  ss.mt.un_320 st.tn.un_650 
  0x7959520c, 0x16004209, 0x555747ad, 0x3f2f450b,   // ha.rn.war_543 co.hr.un_440  sn.na.rw_643 ln.su.af_542 
  0x02fc57af, 0x16284f07, 0x59555a09, 0x3f06fe04,   // na.zzp.da_655 bi.sw.hr_432  sm.rw.rn_444 tlh.de.af_332 
  0x0d091c0e, 0x733250a0, 0x675b01a4, 0x3f092aa4,   // mr.hi.ne_555 fj.bs.ny_322  en.sg.ak_433 mt.pl.af_433 
  // [af70]
  0x64fc3012, 0x423f5fee, 0xfc005719, 0x0e022ea4,   // uz.zzp.lg_654 tn.af.co_422  na.zzp.un_750 fo.da.is_433 
  0x2e0402a9, 0x30000907, 0x5500500c, 0x28002411,   // da.fi.fo_544 pl.uz.un_420  fj.rw.un_530 eo.sw.un_630 
  0x38005504, 0x75213fa9, 0x53003904, 0x0c003f08,   // rw.tk.un_320 af.jw.nso_544  br.ht.un_320 af.sv.un_430 
  0x32595508, 0xfe00370c, 0x595255a4, 0x02001307,   // rw.rn.bs_443 st.tlh.un_530  rw.ha.rn_433 et.da.un_420 
  // [af80]
  0x30101507, 0x02003018, 0x302523a7, 0x484423a0,   // un.be.uz_432 uz.da.un_740  ky.mn.uz_532 ky.kk.tt_322 
  0x2100121a, 0x23441505, 0x353c300c, 0x3d123008,   // ur.fa.un_760 un.kk.ky_333  uz.ug.tg_543 uz.ur.ku_443 
  0x39214602, 0x03353fa4, 0x3c3830ec, 0x30070a0c,   // qu.jw.br_222 af.zu.nl_433  uz.tk.ug_644 mk.bg.uz_543 
  0x4a000505, 0x3500470d, 0x3023480c, 0x37044407,   // fr.yo.un_330 sn.zu.un_540  tt.ky.uz_543 kk.ru.ba_432 
  // [af90]
  0x06032a0c, 0x30002d07, 0x04005205, 0x245230a0,   // mt.nl.de_543 sk.uz.un_420  ha.fi.un_330 uz.ha.eo_322 
  0x353f2c02, 0x0f5c02a0, 0x05401ea0, 0x34005d04,   // fy.af.zu_222 da.sa.lv_322  ms.lb.fr_322 ss.xh.un_320 
  0x10001c02, 0x3f1b3002, 0x2c2b2ea0, 0x3017110c,   // id.lt.un_220 uz.tr.af_222  fo.vi.fy_322 ro.sr.uz_543 
  0x0e352ea4, 0x3c303509, 0x0a001112, 0x44170aaf,   // fo.zu.is_433 tg.uz.ug_444  ro.mk.un_640 mk.sr.kk_655 
  // [afa0]
  0x4400232a, 0x4c0e6007, 0x1d004908, 0x34000605,   // ky.kk.un_970 vo.is.wo_432  to.la.un_430 de.xh.un_330 
  0x524a4904, 0x46004307, 0x330869a9, 0x3400fa11,   // to.yo.ha_332 ie.qu.un_420  mfe.no.nn_544 nr.xh.un_630 
  0x04001e02, 0x0a3825ec, 0x231525a4, 0x1c2f15ee,   // ms.fi.un_220 mn.tk.mk_644  mn.ky.un_430 un.su.id_422 
  0x211c30a0, 0x12004b05, 0x5d6e3404, 0x2e3f2504,   // uz.id.jw_322 mi.hu.un_330  xh.hmn.ss_332 eu.af.fo_332 
  // [afb0]
  0x391276ec, 0x53766904, 0x685f6711, 0x53685cee,   // crs.hu.br_644 mfe.crs.ht_332  ak.tn.ig_653 sa.ig.ht_422 
  0x3b3412a9, 0x211e1207, 0x07010504, 0x2a695307,   // ur.ps.ks_544 hu.ms.jw_432  fr.en.it_332 ht.mfe.mt_432 
  0x353468ec, 0x64005812, 0x481011a0, 0x440737a0,   // ig.xh.zu_644 om.lg.un_640  ro.be.tt_322 ba.bg.kk_322 
  0x12005c11, 0x343021a9, 0x23645c07, 0x213b280d,   // sa.hu.un_630 fa.uz.ps_544  sa.lg.ca_432 sd.ks.fa_554 
  // [afc0]
  0x1523150c, 0x76120807, 0x5c005507, 0x55005c0c,   // un.ky.un_543 no.hu.crs_432  rw.sa.un_420 sa.rw.un_530 
  0x440815a0, 0x3200260b, 0x030f12ee, 0x46001212,   // un.uk.kk_322 ia.bs.un_520  hu.lv.nl_422 hu.qu.un_640 
  0x5a000418, 0x03002005, 0x040205a4, 0x03120f0b,   // fi.sm.un_740 sq.nl.un_330  fr.da.fi_433 lv.hu.nl_542 
  0x10004e12, 0x21075c55, 0x2830120d, 0x5a1865ee,   // ay.lt.un_640 sa.it.jw_442  ur.uz.sd_554 gv.ga.sm_422 
  // [afd0]
  0x25004811, 0x04363005, 0x13034e07, 0x35170a55,   // tt.mn.un_630 uz.ab.ru_333  ay.nl.et_432 mk.sr.tg_442 
  0x0447560c, 0x3c442355, 0x253504ee, 0x05000402,   // mg.sn.fi_543 ky.kk.ug_442  ru.tg.mn_422 fi.fr.un_220 
  0x6503050c, 0x0417080b, 0x38001104, 0x173504ec,   // fr.nl.gv_543 uk.sr.ru_542  ro.tk.un_320 ru.tg.sr_644 
  0x3607080c, 0x65380ea0, 0x35153c0c, 0x38556512,   // uk.bg.ab_543 is.tk.gv_322  ug.tg.un_530 gv.rw.tk_654 
  // [afe0]
  0x05001907, 0x0e003808, 0x07040a07, 0x48311bee,   // gl.fr.un_420 tk.is.un_430  mk.ru.bg_432 tr.az.tt_422 
  0x5c595560, 0x0c205260, 0x2a002807, 0x5c59550d,   // rw.rn.sa_664 ha.sq.sv_664  sw.mt.un_420 rw.rn.sa_554 
  0x57230aa4, 0x3d2134af, 0x20651b05, 0x48003112,   // pt.ca.na_433 ps.fa.ku_655  tr.gv.sq_333 az.tt.un_640 
  0x2a0c200c, 0x1800080b, 0x3025570c, 0x20353402,   // sq.sv.mt_543 no.ga.un_520  na.eu.uz_543 xh.zu.sq_222 
  // [aff0]
  0x211c1eaf, 0x23005207, 0x395345ee, 0x0e122e60,   // ms.id.jw_655 ha.ca.un_420  ln.ht.br_422 fo.hu.is_664 
  0x1e1c2aa0, 0x302e33a0, 0x2158340d, 0x3b4e31af,   // mt.id.ms_322 nn.fo.uz_322  xh.om.jw_554 az.ay.so_655 
  0x2e0c3309, 0x17001122, 0x0e005218, 0x230b330c,   // nn.sv.fo_444 ro.sr.un_870  ha.is.un_740 nn.es.ca_543 
  0x353402af, 0x20007308, 0x20001009, 0x73023ea7,   // da.xh.zu_655 ny.sq.un_430  lt.sq.un_440 rm.da.ny_532 
  
  // [b000]
  0x35343e09, 0x2864250c, 0x53001704, 0x200c02a0,   // rm.xh.zu_444 eu.lg.sw_543  sr.ht.un_320 da.sv.sq_322 
  0x342542a4, 0x253817a0, 0xfe006523, 0x6500fe18,   // co.eu.xh_433 sr.tk.mn_322  gv.tlh.un_880 tlh.gv.un_740 
  0x170415ec, 0x351a5da9, 0x1e1c4eac, 0x311b3bec,   // un.ru.sr_644 ss.tl.zu_544  ay.id.ms_632 so.tr.az_644 
  0x5d281ea4, 0x491a1ea4, 0x2f1c21ec, 0x3534faaf,   // ms.sw.ss_433 ms.tl.to_433  jw.id.su_644 nr.xh.zu_655 
  // [b010]
  0x20002a12, 0x5d005904, 0x49355d0d, 0x20001105,   // mt.sq.un_640 rn.ss.un_320  ss.zu.to_554 ro.sq.un_330 
  0x4b007822, 0x38094508, 0x311b3b08, 0x02102007,   // ve.mi.un_870 ln.pl.tk_443  so.tr.az_443 sq.lt.da_432 
  0x311b3b07, 0x2f5c500c, 0x353155ee, 0x23003713,   // so.tr.az_432 fj.sa.su_543  rw.az.zu_422 ba.ky.un_650 
  0x555d3ba4, 0x6500fe0d, 0x59553ba0, 0x1ffc730d,   // so.ss.rw_433 tlh.gv.un_540  so.rw.rn_322 ny.zzp.cy_554 
  // [b020]
  0x3f4038ac, 0x35343ba0, 0x5d475011, 0x3b65fead,   // tk.lb.af_632 so.xh.zu_322  fj.sn.ss_653 tlh.gv.so_643 
  0x5200571a, 0x281c1e0c, 0x091f6404, 0x553b4c04,   // na.ha.un_760 ms.id.sw_543  lg.cy.pl_332 wo.so.rw_332 
  0x1a1e1c0e, 0x374423ac, 0x354830a6, 0x5d1b55a4,   // id.ms.tl_555 ky.kk.ba_632  uz.tt.tg_521 rw.tr.ss_433 
  0x6400760e, 0x1b6b1a0b, 0x30002014, 0x2e33080d,   // crs.lg.un_550 tl.ceb.tr_542  sq.uz.un_660 no.nn.fo_554 
  // [b030]
  0x27531d02, 0x581f3910, 0x0000622d, 0x2a001c0d,   // la.ht.gd_222 br.cy.om_642  kha.un.un_A00 id.mt.un_540 
  0x35003b02, 0x2a30620c, 0x1e530502, 0x6e574d60,   // so.zu.un_220 kha.uz.mt_543  fr.ht.ms_222 aa.na.hmn_664 
  0x1f520404, 0x353037a0, 0x1e001f02, 0x01006302,   // fi.ha.cy_332 ba.uz.tg_322  cy.ms.un_220 sco.en.un_220 
  0x11421daf, 0x3b1a5807, 0x681d24a9, 0x4c3f030c,   // la.co.ro_655 om.tl.so_432  eo.la.ig_544 nl.af.wo_543 
  // [b040]
  0x5d003405, 0x371723a7, 0x22407305, 0x0f1a5807,   // xh.ss.un_330 ky.sr.ba_532  ny.lb.oc_333 om.tl.lv_432 
  0x4000062a, 0x4c3b3913, 0x4f000102, 0x4c3b0fa4,   // de.lb.un_970 br.so.wo_665  en.bi.un_220 lv.so.wo_433 
  0x2b316eee, 0x584c3bad, 0x284b5e0c, 0x44041702,   // hmn.az.vi_422 so.wo.om_643  ts.mi.sw_543 sr.ru.kk_222 
  0x35345ea9, 0x4b5e6812, 0x6e1ffe0c, 0x535e4ba4,   // ts.xh.zu_544 ig.ts.mi_654  tlh.cy.hmn_543 mi.ts.ht_433 
  // [b050]
  0x301523a0, 0x344b5e0c, 0x40004c02, 0x37007508,   // ky.uz.un_320 ts.mi.xh_543  wo.lb.un_220 nso.st.un_430 
  0x1d1e2f04, 0x4c4d5808, 0x2f583b12, 0x150430a9,   // su.ms.la_332 om.aa.wo_443  so.om.su_654 uz.ru.un_544 
  0x796b1a09, 0x3f584c55, 0x4c583b13, 0x73005e08,   // tl.ceb.war_444 wo.om.af_442  so.om.wo_665 ts.ny.un_430 
  0x49335eee, 0x21005e34, 0x295e250c, 0x35345e0c,   // ts.nn.to_422 ts.jw.un_A80  eu.ts.sl_543 ts.xh.zu_543 
  // [b060]
  0x6a644b0c, 0xfc003b02, 0x070a2507, 0x301544ec,   // mi.lg.haw_543 so.zzp.un_220  mn.mk.bg_432 kk.uz.un_640 
  0x234438a7, 0x04001b13, 0x69005e1a, 0x330e12a0,   // tk.kk.ky_532 tr.fi.un_650  ts.mfe.un_760 hu.is.nn_322 
  0x5e005c07, 0x65314fad, 0x3f246ba0, 0x3575370d,   // sa.ts.un_420 bi.az.gv_643  ceb.eo.af_322 st.nso.zu_554 
  0x2004fca0, 0x353c3009, 0x0d246b55, 0x2c3f125a,   // zzp.fi.sq_322 uz.ug.tg_444  ceb.eo.cs_442 hu.af.fy_553 
  // [b070]
  0x093f04ee, 0x44003c09, 0x4c006404, 0x2f002402,   // fi.af.pl_422 ug.kk.un_440  lg.wo.un_320 eo.su.un_220 
  0x51034308, 0x12342814, 0x17040a05, 0x55523b04,   // ie.nl.kl_443 sd.ps.ur_666  mk.ru.sr_333 so.ha.rw_332 
  0x5e1573a4, 0x3700341b, 0x394a5c04, 0x5c242105,   // ny.ts.un_430 xh.st.un_770  sa.yo.br_332 jw.eo.sa_333 
  0x524c450c, 0x3c004434, 0x35344aee, 0x21130f04,   // ln.wo.ha_543 kk.ug.un_A80  yo.xh.zu_422 lv.et.jw_332 
  // [b080]
  0x474564ec, 0x4d004509, 0x4a5253a0, 0x3b314d07,   // lg.ln.sn_644 ln.aa.un_440  ht.ha.yo_322 aa.az.so_432 
  0x58005313, 0x3c001812, 0x18342155, 0x355234a6,   // ht.om.un_650 ar.ug.un_640  fa.ps.ar_442 xh.ha.zu_521 
  0x4c4a52af, 0x23005e07, 0x341e52ec, 0x6b1f4da7,   // ha.yo.wo_655 ts.ca.un_420  ha.ms.xh_644 aa.cy.ceb_532 
  0x05375d07, 0x55003914, 0x016563ad, 0x230a1707,   // ss.st.fr_432 br.rw.un_660  sco.gv.en_643 sr.mk.ky_432 
  // [b090]
  0x4d674aa4, 0x6953580e, 0x090d2da7, 0x11091204,   // yo.ak.aa_433 om.ht.mfe_555  sk.cs.pl_532 hu.pl.ro_332 
  0x0e3f2ea0, 0x10153612, 0x09005505, 0x31481b02,   // fo.af.is_322 ab.be.un_640  rw.pl.un_330 tr.tt.az_222 
  0x2f472b07, 0x1c201ea4, 0x112f1e05, 0xfc053902,   // vi.sn.su_432 ms.sq.id_433  ms.su.ro_333 br.fr.zzp_222 
  0x10081707, 0x48595560, 0x46002013, 0x1b1f18ee,   // sr.uk.be_432 rw.rn.tt_664  sq.qu.un_650 ga.cy.tr_422 
  // [b0a0]
  0x190b18a9, 0x1d3620a4, 0x1b4018a4, 0x394805ee,   // ga.es.gl_544 sq.gn.la_433  ga.lb.tr_433 fr.tt.br_422 
  0x3600011a, 0x44043807, 0x2400010e, 0x33002012,   // en.gn.un_760 tk.ru.kk_432  iw.yi.un_550 sq.nn.un_640 
  0x04254404, 0x35643905, 0x0c003312, 0x4b2750af,   // kk.mn.ru_332 br.lg.zu_333  nn.sv.un_640 fj.gd.mi_655 
  0x211e1ca7, 0x0f004b0e, 0x1d0a01a4, 0x33fe4c07,   // id.ms.jw_532 mi.lv.un_550  en.pt.la_433 wo.tlh.nn_432 
  // [b0b0]
  0x65184b0d, 0x18fe09ad, 0xfc005805, 0x1d005104,   // mi.ga.gv_554 pl.tlh.ga_643  om.zzp.un_330 kl.la.un_320 
  0x1b002021, 0x30230407, 0x481d2055, 0x11005302,   // sq.tr.un_860 ru.ky.uz_432  sq.la.tt_442 ht.ro.un_220 
  0x080c33ac, 0x0400100e, 0x35253607, 0x0f000c04,   // nn.sv.no_632 be.ru.un_550  ab.mn.tg_432 sv.lv.un_320 
  0x3d1834a4, 0x49654802, 0x052f56a7, 0x03020407,   // ps.ar.ku_433 tt.gv.to_222  mg.su.fr_532 fi.da.nl_432 
  // [b0c0]
  0x0100040c, 0x2200570d, 0x0c334c04, 0x1f000d0d,   // fi.en.un_530 na.oc.un_540  wo.nn.sv_332 cs.cy.un_540 
  0x5e006a04, 0x2f00120e, 0x321657a4, 0x4c2f12ad,   // haw.ts.un_320 hu.su.un_550  na.hr.bs_433 hu.su.wo_643 
  0x1f104d5a, 0x20005305, 0x2f001208, 0x04002d02,   // aa.lt.cy_553 ht.sq.un_330  hu.su.un_430 sk.fi.un_220 
  0x37671712, 0x124c2f04, 0x37001722, 0x6b000205,   // sr.ak.st_654 su.wo.hu_332  sr.ba.un_870 da.ceb.un_330 
  // [b0d0]
  0x4700570c, 0x49004507, 0xfc040105, 0x4a005812,   // na.sn.un_530 ln.to.un_420  en.fi.zzp_333 om.yo.un_640 
  0x13056aee, 0x23444813, 0x2d1f5708, 0x4c000207,   // haw.fr.et_422 tt.kk.ky_665  na.cy.sk_443 da.wo.un_420 
  0x0e2f1208, 0x07464aa0, 0x291c2104, 0x65006a12,   // hu.su.is_443 yo.qu.it_322  jw.id.sl_332 haw.gv.un_640 
  0x08024ba0, 0x37755f60, 0x11074a04, 0x09006407,   // mi.da.no_322 tn.nso.st_664  yo.it.ro_332 lg.pl.un_420 
  // [b0e0]
  0x12005a07, 0x1a1053a0, 0x214615ee, 0x33002202,   // sm.hu.un_420 ht.lt.tl_322  un.qu.jw_422 oc.nn.un_220 
  0x30182704, 0x311b2e08, 0x3e0e0c0c, 0x65016ba0,   // gd.ga.uz_332 fo.tr.az_443  sv.is.rm_543 ceb.en.gv_322 
  0x0000320a, 0x0c005204, 0x3f020302, 0x36190b07,   // bs.un.un_500 ha.sv.un_320  nl.da.af_222 es.gl.gn_432 
  0x65000113, 0x0c333ea9, 0x64024d12, 0x5b6526a4,   // en.gv.un_650 rm.nn.sv_544  aa.da.lg_654 ia.gv.sg_433 
  // [b0f0]
  0x0165150c, 0x4c4a64a4, 0xfe0c5207, 0x584964a7,   // un.gv.en_543 lg.yo.wo_433  ha.sv.tlh_432 lg.to.om_532 
  0x5a500807, 0x023b65a4, 0x232243a0, 0x21000502,   // no.fj.sm_432 gv.so.da_433  ie.oc.ca_322 fr.jw.un_220 
  0x17041055, 0x4c766507, 0x040735ad, 0x44373ca0,   // be.ru.sr_442 gv.crs.wo_432  tg.bg.ru_643 ug.ba.kk_322 
  0x503b6504, 0x3b4c1507, 0x0e2e4ea4, 0x5a353404,   // gv.so.fj_332 un.wo.so_432  ay.fo.is_433 xh.zu.sm_332 
  // [b100]
  0x3700360b, 0x26003e1a, 0x533b57ad, 0x152a3bec,   // ab.ba.un_520 rm.ia.un_760  na.so.ht_643 so.mt.un_644 
  0x393f030c, 0x3900100d, 0x1500301b, 0x191d100c,   // nl.af.br_543 lt.br.un_540  uz.un.un_770 lt.la.gl_543 
  0x2800160e, 0x46233e04, 0xfe4f1f12, 0x484a02a4,   // hr.sw.un_550 rm.ca.qu_332  cy.bi.tlh_654 da.yo.tt_433 
  0x011f650c, 0x211d63a0, 0x0e0a23a0, 0x49004208,   // gv.cy.en_543 sco.la.jw_322  ca.pt.is_322 co.to.un_430 
  // [b110]
  0x6b363b04, 0x01631c07, 0x155c3b13, 0x18016507,   // so.gn.ceb_332 id.sco.en_432  so.sa.un_665 gv.en.ga_432 
  0x5500360d, 0x375e2805, 0x15040a14, 0x216469a9,   // gn.rw.un_540 sw.ts.st_333  mk.ru.un_666 mfe.lg.jw_544 
  0x57334f0c, 0x1b3002a4, 0x60152a0c, 0x47735ca4,   // bi.nn.na_543 da.uz.tr_433  mt.vo.un_530 sa.ny.sn_433 
  0x5363650c, 0x53764da9, 0x4f695d04, 0x02004e0c,   // gv.sco.ht_543 aa.crs.ht_544  ss.mfe.bi_332 ay.da.un_530 
  // [b120]
  0x5a2d0d05, 0x61645512, 0x3900fe02, 0x75005f1b,   // cs.sk.sm_333 rw.lg.za_654  tlh.br.un_220 tn.nso.un_770 
  0x225c2007, 0x343564ad, 0x5c023108, 0x1f004f0d,   // sq.sa.oc_432 lg.zu.xh_643  az.da.sa_443 bi.cy.un_540 
  0x646915ad, 0x311e1ca9, 0x50605d0b, 0xfe000105,   // un.mfe.lg_643 id.ms.az_544  ss.vo.fj_542 en.tlh.un_330 
  0x3e2e0ca9, 0x014615ee, 0x644d1b5a, 0x39002d04,   // sv.fo.rm_544 un.qu.en_422  tr.aa.lg_553 sk.br.un_320 
  // [b130]
  0x2800500d, 0x252337ad, 0x44374805, 0x3b5c3011,   // fj.sw.un_540 ba.ky.mn_643  tt.ba.kk_333 uz.sa.so_653 
  0x50000f08, 0x02002308, 0x345d3704, 0x64004902,   // lv.fj.un_430 ca.da.un_430  st.ss.xh_332 to.lg.un_220 
  0x03006805, 0x01000209, 0x53384cee, 0x215c6907,   // ig.nl.un_330 da.en.un_440  wo.tk.ht_422 mfe.sa.jw_432 
  0x3f004704, 0x6b285e07, 0xfc30040c, 0x524d4fa4,   // sn.af.un_320 ts.sw.ceb_432  fi.uz.zzp_543 bi.aa.ha_433 
  // [b140]
  0x5c643407, 0x4d0f01a0, 0x0b0a01a0, 0x2400150c,   // xh.lg.sa_432 en.lv.aa_322  en.pt.es_322 un.eo.un_530 
  0x2300251b, 0x5c531ba4, 0x5c1b5355, 0x3b3464a7,   // mn.ky.un_770 tr.ht.sa_433  ht.tr.sa_442 lg.xh.so_532 
  0x695364ad, 0x0a070407, 0x3000fc1a, 0x674b130c,   // lg.ht.mfe_643 ru.bg.mk_432  zzp.uz.un_760 et.mi.ak_543 
  0x464002ee, 0x4a00750c, 0x405163af, 0x49134a07,   // da.lb.qu_422 nso.yo.un_530  sco.kl.lb_655 yo.et.to_432 
  // [b150]
  0x2e016304, 0x3e630112, 0x44071005, 0x23002702,   // sco.en.fo_332 en.sco.rm_654  be.bg.kk_333 gd.ca.un_220 
  0x17000809, 0x353025af, 0x0c2d0da7, 0x05006507,   // uk.sr.un_440 mn.uz.tg_655  cs.sk.sv_532 gv.fr.un_420 
  0x400c3e08, 0x04481002, 0x071735a0, 0x4c3e6308,   // rm.sv.lb_443 be.tt.ru_222  tg.sr.bg_322 sco.rm.wo_443 
  0x303e40a7, 0x45000423, 0x041801a0, 0x5f001008,   // lb.rm.uz_532 fi.ln.un_880  en.ga.fi_322 lt.tn.un_430 
  // [b160]
  0x187537ad, 0x46270bec, 0x5813fc11, 0x5f004f21,   // st.nso.ga_643 es.gd.qu_644  zzp.et.om_653 bi.tn.un_860 
  0x4a473502, 0x05005607, 0x4b212004, 0x3d3021a4,   // zu.sn.yo_222 mg.fr.un_420  sq.jw.mi_332 fa.uz.ku_433 
  0x2e0e2aa6, 0x443823a9, 0x0c450807, 0x47002904,   // mt.is.fo_521 ky.tk.kk_544  no.ln.sv_432 sl.sn.un_320 
  0x67004d22, 0x4d004b23, 0x65003e19, 0x1523110c,   // aa.ak.un_870 mi.aa.un_880  rm.gv.un_750 ro.ky.un_543 
  // [b170]
  0x5b562e0c, 0x37005f04, 0x39675f07, 0x40003919,   // fo.mg.sg_543 tn.st.un_320  tn.ak.br_432 br.lb.un_750 
  0x634045a0, 0x3b000414, 0x4837350c, 0x2d2401a4,   // ln.lb.sco_322 fi.so.un_660  tg.ba.tt_543 en.eo.sk_433 
  0x377501a0, 0x071738ad, 0x071708af, 0x09006007,   // en.nso.st_322 tk.sr.bg_643  uk.sr.bg_655 vo.pl.un_420 
  0x4d001f2b, 0x34002d02, 0x300415a0, 0x230b0a02,   // cy.aa.un_980 sk.xh.un_220  un.ru.uz_322 pt.es.ca_222 
  // [b180]
  0x5c000104, 0x39002d07, 0x40002d07, 0x15000113,   // en.sa.un_320 sk.br.un_420  sk.lb.un_420 en.un.un_650 
  0x34003d14, 0x4837110b, 0x045679a4, 0x4b496a0b,   // ku.ps.un_660 ro.ba.tt_542  war.mg.fi_433 haw.to.mi_542 
  0x06001505, 0x68021da4, 0x046a4ba4, 0x13005604,   // un.de.un_330 la.da.ig_433  mi.haw.fi_433 mg.et.un_320 
  0x21233409, 0x36004702, 0x170a3607, 0x5a5651ee,   // ps.ky.fa_444 sn.gn.un_220  ab.mk.sr_432 kl.mg.sm_422 
  // [b190]
  0x04150709, 0x0a040755, 0x170410a6, 0x042348a0,   // bg.ru.un_440 bg.ru.mk_442  be.ru.sr_521 tt.ky.ru_322 
  0x0a073012, 0x1f000804, 0x131d5c0c, 0x2a001f11,   // uz.bg.mk_654 no.cy.un_320  sa.la.et_543 cy.mt.un_630 
  0x47041305, 0x08002a07, 0x243e22af, 0x264333a4,   // et.fi.sn_333 mt.no.un_420  oc.rm.eo_655 nn.ie.ia_433 
  0x1500030c, 0x15080412, 0x2e483307, 0x0a1d0f0c,   // nl.un.un_530 ru.uk.un_654  nn.tt.fo_432 lv.la.pt_543 
  // [b1a0]
  0x0e000405, 0x111d15a0, 0x0e332eaf, 0x0b001d04,   // fi.is.un_330 un.la.ro_322  fo.nn.is_655 la.es.un_320 
  0x51001a04, 0x1a2f21a4, 0x43263e13, 0x33086705,   // tl.kl.un_320 jw.su.tl_433  rm.ia.ie_665 ak.no.nn_333 
  0x5a004b02, 0x07101507, 0x2efe4c07, 0x30002e04,   // mi.sm.un_220 un.be.bg_432  wo.tlh.fo_432 fo.uz.un_320 
  0x52330c13, 0x0e52220d, 0x1b230cee, 0x2504150d,   // sv.nn.ha_665 oc.ha.is_554  sv.ca.tr_422 un.ru.mn_554 
  // [b1b0]
  0x08303514, 0x44483809, 0x0c020407, 0x353450ee,   // tg.uz.uk_666 tk.tt.kk_444  fi.da.sv_432 fj.xh.zu_422 
  0x755d370c, 0x13160209, 0x1b536907, 0x21005f04,   // st.ss.nso_543 da.hr.et_444  mfe.ht.tr_432 tn.jw.un_320 
  0x201f0ea9, 0x732802a9, 0x5e6a3b05, 0x0a00fc07,   // is.cy.sq_544 da.sw.ny_544  so.haw.ts_333 zzp.pt.un_420 
  0x73525aee, 0x254746ac, 0x363704a4, 0x28123405,   // sm.ha.ny_422 qu.sn.eu_632  ru.ba.ab_433 ps.ur.sd_333 
  // [b1c0]
  0x3600300d, 0x44382555, 0x0a171108, 0x132512ee,   // uz.ab.un_540 mn.tk.kk_442  ro.sr.mk_443 hu.eu.et_422 
  0x48120d07, 0x49006a04, 0x2b2d0d55, 0x2c122eee,   // cs.hu.tt_432 haw.to.un_320  cs.sk.vi_442 fo.hu.fy_422 
  0x651dfcee, 0x36002613, 0x5a00260c, 0x7339420d,   // zzp.la.gv_422 ia.gn.un_650  ia.sm.un_530 co.br.ny_554 
  0x353425ec, 0x041536a4, 0x4900180b, 0x2a1809a0,   // eu.xh.zu_644 ab.ru.un_430  ga.to.un_520 pl.ga.mt_322 
  // [b1d0]
  0x1500040c, 0x0a07250d, 0x34303d0c, 0x39002704,   // ru.un.un_530 mn.bg.mk_554  ku.uz.ps_543 gd.br.un_320 
  0x5e001809, 0x3844480e, 0x61003919, 0x181221a0,   // ga.ts.un_440 tt.kk.tk_555  br.za.un_750 fa.ur.ar_322 
  0x3c2307ad, 0x2b001c07, 0x23301007, 0x1d003202,   // bg.ky.ug_643 id.vi.un_420  be.uz.ky_432 bs.la.un_220 
  0x2a252c0c, 0x39021f02, 0x56003622, 0x3e00200c,   // fy.eu.mt_543 cy.da.br_222  gn.mg.un_870 sq.rm.un_530 
  // [b1e0]
  0x15000804, 0x06003e04, 0x060c2402, 0x1c095ca0,   // no.un.un_320 rm.de.un_320  eo.sv.de_222 sa.hi.mr_322 
  0x0300080c, 0x522e0ea0, 0x4722400c, 0x08022c02,   // no.nl.un_530 is.fo.ha_322  lb.oc.sn_543 fy.da.no_222 
  0x20005312, 0x5e007813, 0x5e00591b, 0x46364c0b,   // ht.sq.un_640 ve.ts.un_650  rn.ts.un_770 wo.gn.qu_542 
  0x29002402, 0x526b1a14, 0x1a006402, 0x06fc63ee,   // eo.sl.un_220 tl.ceb.ha_666  lg.tl.un_220 sco.zzp.de_422 
  // [b1f0]
  0x0a04440c, 0x3e05200c, 0x20000527, 0x04027807,   // kk.ru.mk_543 sq.fr.rm_543  fr.sq.un_940 ve.da.fi_432 
  0x042528ec, 0x2200270d, 0x5605430c, 0x4823445a,   // sw.eu.fi_644 gd.oc.un_540  ie.fr.mg_543 kk.ky.tt_553 
  0x104549a4, 0x1d000e1a, 0x6a000212, 0x042502a9,   // to.ln.lt_433 is.la.un_760  da.haw.un_640 da.eu.fi_544 
  0x2a213fad, 0x1f001812, 0x65640204, 0x513048a7,   // af.jw.mt_643 ga.cy.un_640  da.lg.gv_332 tt.uz.kl_532 
  // [b200]
  0x5c60470c, 0x493473a0, 0x01032c02, 0x73305c04,   // sn.vo.sa_543 ny.xh.to_322  fy.nl.en_222 sa.uz.ny_332 
  0x50495e0c, 0x3848120e, 0x13463808, 0x2d0d05a4,   // ts.to.fj_543 hu.tt.tk_555  tk.qu.et_443 fr.cs.sk_433 
  0x04000520, 0x350f10ad, 0x56006808, 0x46102402,   // fr.fi.un_850 lt.lv.zu_643  ig.mg.un_430 eo.lt.qu_222 
  0x38481213, 0x5a3060af, 0x6b5d10a4, 0x1000450c,   // hu.tt.tk_665 vo.uz.sm_655  lt.ss.ceb_433 ln.lt.un_530 
  // [b210]
  0x38126bee, 0x42003b05, 0x4700650b, 0x0d1c1304,   // ceb.hu.tk_422 so.co.un_330  gv.sn.un_520 bh.mr.ne_332 
  0x0400500c, 0x370815a0, 0x0c041307, 0x4543055a,   // fj.fi.un_530 un.uk.ba_322  et.fi.sv_432 fr.ie.ln_553 
  0x20004711, 0x10250255, 0x424c05ee, 0x25286807,   // sn.sq.un_630 da.eu.lt_442  fr.wo.co_422 ig.sw.eu_432 
  0x6300651a, 0x05494c02, 0x1f000e14, 0x1e004204,   // gv.sco.un_760 wo.to.fr_222  is.cy.un_660 co.ms.un_320 
  // [b220]
  0x5500200c, 0x3b003202, 0x50005c09, 0x6b3848ec,   // sq.rw.un_530 bs.so.un_220  sa.fj.un_440 tt.tk.ceb_644 
  0x092d0daf, 0x28005a09, 0x213430a7, 0x28213008,   // cs.sk.pl_655 sm.sw.un_440  uz.ps.fa_532 uz.fa.sd_443 
  0x123559ee, 0x30005009, 0x17007518, 0x481238af,   // rn.zu.hu_422 fj.uz.un_440  nso.sr.un_740 tk.hu.tt_655 
  0x652d0d04, 0x29240d0b, 0x12483855, 0x21283cee,   // cs.sk.gv_332 cs.eo.sl_542  tk.tt.hu_442 ug.sd.fa_422 
  // [b230]
  0x121a6204, 0x18002d0d, 0x48384fa4, 0x352f34a0,   // kha.tl.hu_332 sk.ga.un_540  bi.tk.tt_433 xh.su.zu_322 
  0x46157604, 0x16290f0b, 0x4b00020c, 0x026315a4,   // crs.qu.un_320 lv.sl.hr_542  da.mi.un_530 un.sco.da_433 
  0x65005305, 0x1d650107, 0x25354b04, 0x73003b21,   // ht.gv.un_330 en.gv.la_432  mi.zu.eu_332 so.ny.un_860 
  0x1e004507, 0x3534640c, 0x18003b13, 0x0827390c,   // ln.ms.un_420 lg.xh.zu_543  ks.ar.un_650 br.gd.no_543 
  // [b240]
  0x06130c07, 0x3c150455, 0x33080aee, 0x2036110c,   // sv.et.de_432 ru.ug.un_420  pt.no.nn_422 ro.gn.sq_543 
  0x3534020c, 0x3e000904, 0x0f007519, 0x294348a7,   // da.xh.zu_543 pl.rm.un_320  nso.lv.un_750 tt.ie.sl_532 
  0x19005304, 0x2818120b, 0x1230210d, 0x0f321708,   // ht.gl.un_320 ur.ar.sd_542  fa.uz.ur_554 sr.bs.lv_443 
  0x2f3012ee, 0x62004823, 0x79004713, 0x2e002f04,   // hu.uz.su_422 tt.kha.un_880  sn.war.un_650 su.fo.un_320 
  // [b250]
  0x343d1804, 0x2e003008, 0x0e0f2ea0, 0x0b1936a0,   // ar.ku.ps_332 uz.fo.un_430  fo.lv.is_322 gn.gl.es_322 
  0x3048690c, 0x2318440e, 0x6b024da7, 0x2b1a0f02,   // mfe.tt.uz_543 kk.ar.ky_555  aa.da.ceb_532 lv.tl.vi_222 
  0x25002323, 0x35004718, 0x0800360c, 0x48001e04,   // ky.mn.un_880 sn.zu.un_740  ab.uk.un_530 ms.tt.un_320 
  0x4800360d, 0x2e0e3312, 0x35071702, 0x36444807,   // ab.tt.un_540 nn.is.fo_654  sr.bg.tg_222 tt.kk.ab_432 
  // [b260]
  0x4a004812, 0x342128af, 0x42072aaf, 0x24000204,   // tt.yo.un_640 sd.fa.ps_655  mt.it.co_655 da.eo.un_320 
  0x21443dad, 0x422a0713, 0x13002c02, 0x09002c2a,   // ku.kk.fa_643 it.mt.co_665  fy.et.un_220 fy.pl.un_970 
  0x0a081104, 0x3e004208, 0x7942076d, 0x4349790d,   // ro.uk.mk_332 co.rm.un_430  it.co.war_874 war.to.ie_554 
  0x69006119, 0x49003e04, 0x0d2a0711, 0x033f630c,   // za.mfe.un_750 rm.to.un_320  it.mt.cs_653 sco.af.nl_543 
  // [b270]
  0x2a00430d, 0x07002a0d, 0x07422a09, 0x423e0712,   // ie.mt.un_540 mt.it.un_540  mt.co.it_444 it.rm.co_654 
  0x213d2807, 0x423e230d, 0x374423ad, 0x58136aec,   // sd.ku.fa_432 ca.rm.co_554  ky.kk.ba_643 haw.et.om_644 
  0x00001242, 0x4c006a21, 0x64133bad, 0x25003002,   // ur.un.un_C00 haw.wo.un_860  so.et.lg_643 uz.mn.un_220 
  0x3b4d4c0d, 0x1d004316, 0x40160107, 0x654c4d60,   // wo.aa.so_554 ie.la.un_720  en.hr.lb_432 aa.wo.gv_664 
  // [b280]
  0x15040855, 0x15001c02, 0x3b581da4, 0x48153008,   // uk.ru.un_442 id.un.un_220  la.om.so_433 uz.tt.un_430 
  0x0c002f04, 0x37170708, 0x4c003b1b, 0x36041508,   // su.sv.un_320 bg.sr.ba_443  so.wo.un_770 un.ru.ab_443 
  0x0a001209, 0x304823a0, 0x30113cad, 0x65134d0c,   // hu.pt.un_440 ky.tt.uz_322  ug.ro.uz_643 aa.et.gv_543 
  0x08000423, 0x1300010d, 0x58373b55, 0x403f4cee,   // ru.uk.un_880 en.et.un_540  so.st.om_442 wo.af.lb_422 
  // [b290]
  0x154301a4, 0x0e2e33a6, 0x17234812, 0x2b291007,   // en.ie.un_433 nn.fo.is_521  tt.ky.sr_654 lt.sl.vi_432 
  0x24003308, 0x462e1f07, 0x293316a0, 0x260c330c,   // nn.eo.un_430 cy.fo.qu_432  hr.nn.sl_322 nn.sv.ia_543 
  0x0600040b, 0x071511ad, 0x47003f04, 0x06000904,   // fi.de.un_520 ro.bg.un_630  af.sn.un_320 pl.de.un_320 
  0x0f00751a, 0x234418ec, 0x17153811, 0x01003202,   // nso.lv.un_760 ar.kk.ky_644  tk.sr.un_630 bs.en.un_220 
  // [b2a0]
  0x21002904, 0x2c201f07, 0x67003b13, 0x170d2da0,   // sl.jw.un_320 cy.sq.fy_432  so.ak.un_650 sk.cs.sr_322 
  0x641a2104, 0x12006720, 0x12006414, 0x0f321704,   // jw.tl.lg_332 ak.hu.un_850  lg.hu.un_660 sr.bs.lv_332 
  0x44233813, 0x3c003405, 0x37004704, 0x4b796aa9,   // tk.ky.kk_665 ps.ug.un_330  sn.st.un_320 haw.war.mi_544 
  0x13003614, 0x5d136a0b, 0x443035a9, 0x59555ca9,   // gn.et.un_660 haw.et.ss_542  tg.uz.kk_544 sa.rw.rn_544 
  // [b2b0]
  0x16000f0b, 0x4a1c1e0c, 0x5d596aa9, 0x6b5855a9,   // lv.hr.un_520 ms.id.yo_543  haw.rn.ss_544 rw.om.ceb_544 
  0x491a210b, 0x0d1c5c60, 0x162d2904, 0x2d0d55a0,   // jw.tl.to_542 sa.mr.ne_664  sl.sk.hr_332 rw.cs.sk_322 
  0x282a02a7, 0x18045e0c, 0x494b21a9, 0x5e002508,   // da.mt.sw_532 ts.fi.ga_543  jw.mi.to_544 eu.ts.un_430 
  0x1c4a39a4, 0x0a171508, 0x29000f07, 0x021321a4,   // br.yo.id_433 un.sr.mk_443  lv.sl.un_420 jw.et.da_433 
  // [b2c0]
  0x6a03010c, 0x397301a0, 0x01fc6bee, 0x464b13a7,   // en.nl.haw_543 en.ny.br_322  ceb.zzp.en_422 et.mi.qu_532 
  0x0d0f1604, 0x52005d08, 0x243936a0, 0x4a550408,   // hr.lv.cs_332 ss.ha.un_430  gn.br.eo_322 fi.rw.yo_443 
  0x454f37ec, 0x6e5e1308, 0x02005021, 0x555d28af,   // st.bi.ln_644 et.ts.hmn_443  fj.da.un_860 sw.ss.rw_655 
  0x0700420c, 0x4b1e1c12, 0x2900fe04, 0x35732807,   // co.it.un_530 id.ms.mi_654  tlh.sl.un_320 sw.ny.zu_432 
  // [b2d0]
  0x45356412, 0x45007322, 0x0325730b, 0x52557304,   // lg.zu.ln_654 ny.ln.un_870  ny.eu.nl_542 ny.rw.ha_332 
  0x525902a4, 0x330867ee, 0x30253104, 0x474936a4,   // da.rn.ha_433 ak.no.nn_422  az.eu.uz_332 gn.to.sn_433 
  0x02214baf, 0x253037ac, 0x03202108, 0x2f13040c,   // mi.jw.da_655 ba.uz.mn_632  jw.sq.nl_443 fi.et.su_543 
  0x0c6908a9, 0x29212f0c, 0x47000308, 0x022873a4,   // no.mfe.sv_544 su.jw.sl_543  nl.sn.un_430 ny.sw.da_433 
  // [b2e0]
  0x564b01a4, 0x563ffe07, 0x2100fc12, 0x0c0833af,   // en.mi.mg_433 tlh.af.mg_432  zzp.jw.un_640 nn.no.sv_655 
  0x24002002, 0x633002ee, 0x25004b02, 0x0e003408,   // sq.eo.un_220 da.uz.sco_422  mi.eu.un_220 xh.is.un_430 
  0x204721a9, 0x28477312, 0x421107a4, 0x536b02a0,   // jw.sn.sq_544 ny.sn.sw_654  it.ro.co_433 da.ceb.ht_322 
  0x35150aad, 0x42071005, 0x48371512, 0x3f045e10,   // mk.tg.un_630 lt.it.co_333  un.ba.tt_654 ts.fi.af_642 
  // [b2f0]
  0x62000413, 0x5d003505, 0x07002812, 0x0a1504a4,   // fi.kha.un_650 zu.ss.un_330  sw.it.un_640 ru.mk.un_430 
  0x2100621a, 0x56345804, 0x106446a9, 0xfe2a2808,   // kha.jw.un_760 om.xh.mg_332  qu.lg.lt_544 sw.mt.tlh_443 
  0x47002702, 0x3f330804, 0xfc6a5a08, 0x112901a4,   // gd.sn.un_220 no.nn.af_332  sm.haw.zzp_443 en.sl.ro_433 
  0x2f755f12, 0x2600040c, 0x12000907, 0x2069560c,   // tn.nso.su_654 fi.ia.un_530  pl.hu.un_420 mg.mfe.sq_543 
  // [b300]
  0x020502a0, 0x4d596b0c, 0x13000414, 0x100f5ca4,   // da.fr.da_322 ceb.rn.aa_543  fi.et.un_660 sa.lv.lt_433 
  0x38fe1b05, 0x1c5c0d0d, 0x13002d02, 0x1f00470c,   // tr.tlh.tk_333 ne.sa.mr_554  sk.et.un_220 sn.cy.un_530 
  0x42074fa9, 0x1300280d, 0x46606507, 0x24002302,   // bi.it.co_544 sw.et.un_540  gv.vo.qu_432 ca.eo.un_220 
  0x4b5653ad, 0x231d260c, 0x475c5802, 0x54513013,   // ht.mg.mi_643 ia.la.ca_543  om.sa.sn_222 uz.kl.ik_665 
  // [b310]
  0x1dfe200d, 0x64005907, 0x023f0304, 0x464ffe05,   // sq.tlh.la_554 rn.lg.un_420  nl.af.da_332 tlh.bi.qu_333 
  0x674b54a9, 0x3f031d07, 0x534773a9, 0x48003612,   // ik.mi.ak_544 la.nl.af_432  ny.sn.ht_544 gn.tt.un_640 
  0x31000a04, 0x12190bee, 0x425c04ac, 0x3b001223,   // pt.az.un_320 es.gl.hu_422  fi.sa.co_632 ur.ks.un_880 
  0x25173c07, 0x5c002609, 0x3b2838a4, 0x1d5c0e0b,   // ug.sr.mn_432 ia.sa.un_440  tk.sw.so_433 is.sa.la_542 
  // [b320]
  0x18233dac, 0x340102a0, 0x3b003502, 0x1d004207,   // ku.ky.ar_632 da.en.xh_322  zu.so.un_220 co.la.un_420 
  0x200561a4, 0x07360804, 0x67002108, 0x213034ee,   // za.fr.sq_433 uk.ab.bg_332  jw.ak.un_430 ps.uz.fa_422 
  0x38003514, 0x35153013, 0x3d3412ee, 0x1b650504,   // tg.tk.un_660 uz.tg.un_650  ur.ps.ku_422 fr.gv.tr_332 
  0x101704a0, 0x15003614, 0x301710a4, 0x234430a9,   // ru.sr.be_322 ab.un.un_660  be.sr.uz_433 uz.kk.ky_544 
  // [b330]
  0x283d2112, 0x253e07af, 0x16523ba7, 0x3b290d07,   // fa.ku.sd_654 it.rm.eu_655  so.ha.hr_532 cs.sl.so_432 
  0x3b131cec, 0x17003b04, 0x584c47ee, 0x3b586413,   // mr.bh.ks_644 so.sr.un_320  sn.wo.om_422 lg.om.so_665 
  0x347956a6, 0x424d3b55, 0x644c58a4, 0x1f003b09,   // mg.war.xh_521 so.aa.co_442  om.wo.lg_433 so.cy.un_440 
  0x04371012, 0x644b6aa4, 0x321775ee, 0x071704a4,   // be.ba.ru_654 haw.mi.lg_433  nso.sr.bs_422 ru.sr.bg_433 
  // [b340]
  0x0d00130d, 0x4a523b07, 0x1b4811ec, 0x160d3ba6,   // bh.ne.un_540 so.ha.yo_432  ro.tt.tr_644 so.cs.hr_521 
  0x351515ec, 0x2e0e0c13, 0x58006420, 0x06003008,   // un.tg.un_640 sv.is.fo_665  lg.om.un_850 uz.de.un_430 
  0x57003b13, 0x320d0fac, 0x2a1f3bee, 0x50253ba0,   // so.na.un_650 lv.cs.bs_632  so.cy.mt_422 so.eu.fj_322 
  0x4c002808, 0x1f353404, 0x15003613, 0x4d006422,   // sw.wo.un_430 xh.zu.cy_332  ab.un.un_650 lg.aa.un_870 
  // [b350]
  0x020452a7, 0x58006419, 0x2a4f1ea4, 0x64583b08,   // ha.fi.da_532 lg.om.un_750  ms.bi.mt_433 so.om.lg_443 
  0x1b005204, 0x094b470c, 0x40063207, 0x50284e0c,   // ha.tr.un_320 sn.mi.pl_543  bs.de.lb_432 ay.sw.fj_543 
  0x0415170c, 0x131251a9, 0x12000c02, 0x375a2809,   // sr.ru.un_530 kl.hu.et_544  sv.hu.un_220 sw.sm.st_444 
  0x1d5550a7, 0x02123f08, 0x47004b08, 0x1a007907,   // fj.rw.la_532 af.hu.da_443  mi.sn.un_430 war.tl.un_420 
  // [b360]
  0x2529100c, 0x3b000602, 0x330804ee, 0x38001213,   // lt.sl.eu_543 de.so.un_220  fi.no.nn_422 hu.tk.un_650 
  0x0200fe18, 0x3d44235a, 0x5e4e535a, 0xfe003b12,   // tlh.da.un_740 ky.kk.ku_553  ht.ay.ts_553 so.tlh.un_640 
  0x05000207, 0x734b210c, 0x79643404, 0x3f000707,   // da.fr.un_420 jw.mi.ny_543  xh.lg.war_332 it.af.un_420 
  0x30292da9, 0x6b006512, 0x2d2948a9, 0x0f002d0d,   // sk.sl.uz_544 gv.ceb.un_640  tt.sl.sk_544 sk.lv.un_540 
  // [b370]
  0x48292d11, 0x5e7367a4, 0x31292d0c, 0x31001105,   // sk.sl.tt_653 ak.ny.ts_433  sk.sl.az_543 ro.az.un_330 
  0xfc473602, 0x30312d05, 0x6500fe0e, 0xfe3b65ad,   // gn.sn.zzp_222 sk.az.uz_333  tlh.gv.un_550 gv.so.tlh_643 
  0x316e2da6, 0x150708a4, 0x21342810, 0x13001c05,   // sk.hmn.az_521 uk.bg.un_433  sd.ps.fa_642 mr.bh.un_330 
  0x29482da7, 0x38697612, 0xfe30310d, 0x48006e1a,   // sk.tt.sl_532 crs.mfe.tk_654  az.uz.tlh_554 hmn.tt.un_760 
  // [b380]
  0x792d2960, 0x1c090d13, 0x48292da9, 0x13000d22,   // sl.sk.war_664 ne.hi.mr_665  sk.sl.tt_544 ne.bh.un_870 
  0x32292da4, 0x183d28ee, 0x18213d04, 0x29fe2d0c,   // sk.sl.bs_433 sd.ku.ar_422  ku.fa.ar_332 sk.tlh.sl_543 
  0x29482da4, 0x25151555, 0x483031af, 0x0d094707,   // sk.tt.sl_433 un.mn.un_420  az.uz.tt_655 sn.pl.cs_432 
  0x041515a0, 0x0b000a0e, 0x30383c13, 0x0a480755,   // un.ru.un_320 pt.es.un_550  ug.tk.uz_665 bg.tt.mk_442 
  // [b390]
  0x441538a9, 0x10301507, 0x37004821, 0x483129a9,   // tk.kk.un_540 un.uz.be_432  tt.ba.un_860 sl.az.tt_544 
  0x514904ad, 0x2d1c4d0c, 0x04282ea4, 0x4600500d,   // fi.to.kl_643 aa.id.sk_543  fo.sw.fi_433 fj.qu.un_540 
  0x64005a04, 0x30386bee, 0x534c5208, 0x4a004308,   // sm.lg.un_320 ceb.tk.uz_422  ha.wo.ht_443 ie.yo.un_430 
  0x1b005f05, 0x2200120b, 0x5f4d67a4, 0x31005313,   // tn.tr.un_330 hu.oc.un_520  ak.aa.tn_433 ht.az.un_650 
  // [b3a0]
  0x53004c07, 0x08374809, 0x3700442b, 0x473534a7,   // wo.ht.un_420 tt.ba.uk_444  kk.ba.un_980 xh.zu.sn_532 
  0x0a007908, 0x071d420c, 0x4800251a, 0x21005e07,   // war.pt.un_430 co.la.it_543  mn.tt.un_760 ts.jw.un_420 
  0x2917100c, 0x4c535f0c, 0x102d0dee, 0x282134a7,   // lt.sr.sl_543 tn.ht.wo_543  cs.sk.lt_422 ps.fa.sd_532 
  0x18004704, 0x69005314, 0x3b002804, 0x16100f0c,   // sn.ga.un_320 ht.mfe.un_660  sw.so.un_320 lv.lt.hr_543 
  // [b3b0]
  0x28301807, 0x4735340d, 0x0417380c, 0x481515a4,   // ar.uz.sd_432 xh.zu.sn_554  tk.sr.ru_543 un.tt.un_430 
  0x2f001b19, 0x3100530e, 0x06003b02, 0x1b00fc0d,   // tr.su.un_750 ht.az.un_550  so.de.un_220 zzp.tr.un_540 
  0x653628ee, 0x38042004, 0x041711ad, 0x233644ad,   // sw.gn.gv_422 sq.fi.tk_332  ro.sr.ru_643 kk.ab.ky_643 
  0x17003707, 0x04303160, 0x24005602, 0xfc004805,   // ba.sr.un_420 az.uz.fi_664  mg.eo.un_220 tt.zzp.un_330 
  // [b3c0]
  0x13006a09, 0x51004607, 0x5f7501a0, 0x2900750c,   // haw.et.un_440 qu.kl.un_420  en.nso.tn_322 nso.sl.un_530 
  0x473b6507, 0x3e6b0708, 0x455376a4, 0x024d4808,   // gv.so.sn_432 it.ceb.rm_443  crs.ht.ln_433 tt.aa.da_443 
  0x30002013, 0x2b003b04, 0x503b4508, 0x4200070d,   // sq.uz.un_650 so.vi.un_320  ln.so.fj_443 it.co.un_540 
  0x28001223, 0x15003b05, 0x4d650107, 0x042802a0,   // ur.sd.un_880 so.un.un_330  en.gv.aa_432 da.sw.fi_322 
  // [b3d0]
  0x4b5e5aec, 0x4f006214, 0x29003207, 0x0e2e6512,   // sm.ts.mi_644 kha.bi.un_660  bs.sl.un_420 gv.fo.is_654 
  0x121354ee, 0x384a5204, 0x33005c09, 0x3e4039a6,   // ik.et.hu_422 ha.yo.tk_332  sa.nn.un_440 br.lb.rm_521 
  0x11000a0b, 0x5c002009, 0x5c005009, 0x20003607,   // pt.ro.un_520 sq.sa.un_440  fj.sa.un_440 gn.sq.un_420 
  0x36000719, 0x08100711, 0x3c00251a, 0x42565102,   // bg.ab.un_750 bg.be.uk_653  mn.ug.un_760 kl.mg.co_222 
  // [b3e0]
  0x64005808, 0x1d190a04, 0x15000722, 0x09006113,   // om.lg.un_430 pt.gl.la_332  bg.un.un_870 za.pl.un_650 
  0x36001119, 0x20321604, 0x36001004, 0x5c2d3e0c,   // ro.gn.un_750 hr.bs.sq_332  lt.gn.un_320 rm.sk.sa_543 
  0x0c006905, 0x1d20260c, 0x04135c12, 0x08004402,   // mfe.sv.un_330 ia.sq.la_543  sa.et.fi_654 kk.uk.un_220 
  0x6400250c, 0x103217a0, 0x08101705, 0x48070a04,   // eu.lg.un_530 sr.bs.lt_322  sr.be.uk_333 mk.bg.tt_332 
  // [b3f0]
  0x23003702, 0x3b761ba7, 0x1b595513, 0x25004707,   // ba.ky.un_220 tr.crs.so_532  rw.rn.tr_665 sn.eu.un_420 
  0x732861a0, 0x0e2e2d13, 0x073736ee, 0x20551104,   // za.sw.ny_322 sk.fo.is_665  ab.ba.bg_422 ro.rw.sq_332 
  0x08002e04, 0x30565f0c, 0x2f6a0207, 0x2e00080c,   // fo.no.un_320 tn.mg.uz_543  da.haw.su_432 no.fo.un_530 
  0x285e4713, 0x2f003504, 0x290449a0, 0x184f6aad,   // sn.ts.sw_665 zu.su.un_320  to.fi.sl_322 haw.bi.ga_643 
  
  // [b400]
  0x44383612, 0x041043a7, 0x5d534a04, 0x56004f04,   // ab.tk.kk_654 ie.lt.fi_532  yo.ht.ss_332 bi.mg.un_320 
  0x3c374414, 0x1f005a21, 0x48250a12, 0x651827ad,   // kk.ba.ug_666 sm.cy.un_860  mk.mn.tt_654 gd.ga.gv_643 
  0x11244aa0, 0x07005504, 0x041536ad, 0x5cfc690c,   // yo.eo.ro_322 rw.it.un_320  ab.ru.un_630 mfe.zzp.sa_543 
  0x35003b07, 0x45591b0c, 0x100415a4, 0x5d283555,   // so.zu.un_420 tr.rn.ln_543  un.ru.be_433 zu.sw.ss_442 
  // [b410]
  0x59535507, 0x44043ca6, 0x5d003b04, 0x301218a0,   // rw.ht.rn_432 ug.ru.kk_521  so.ss.un_320 ar.ur.uz_322 
  0x55535804, 0x2e000805, 0x042156a0, 0x18565a0c,   // om.ht.rw_332 no.fo.un_330  mg.jw.fi_322 sm.mg.ga_543 
  0x332e08a4, 0x7847500c, 0x560742af, 0x564947a0,   // no.fo.nn_433 fj.sn.ve_543  co.it.mg_655 sn.to.mg_322 
  0x2e000e2b, 0x28006a08, 0x332e080c, 0x5f3739a9,   // is.fo.un_980 haw.sw.un_430  no.fo.nn_543 br.st.tn_544 
  // [b420]
  0x2f565904, 0x37233808, 0x28000604, 0x5300fe02,   // rn.mg.su_332 tk.ky.ba_443  de.sw.un_320 tlh.ht.un_220 
  0xfc005e05, 0x012d15a0, 0x15011daf, 0x1a00fe12,   // ts.zzp.un_330 un.sk.en_322  la.en.un_655 tlh.tl.un_640 
  0x01000e04, 0x2100400c, 0x00005e37, 0x39004204,   // is.en.un_320 lb.jw.un_530  ts.un.un_B00 co.br.un_320 
  0x240f420d, 0x1500250e, 0x2c533faf, 0xfe6906a4,   // co.lv.eo_554 mn.un.un_550  af.ht.fy_655 de.mfe.tlh_433 
  // [b430]
  0x58524dad, 0x213b3d05, 0x53643405, 0x2c000504,   // aa.ha.om_643 ku.ks.fa_333  xh.lg.ht_333 fr.fy.un_320 
  0x52584d12, 0x30002012, 0x345f75ad, 0x5800380d,   // aa.om.ha_654 sq.uz.un_640  nso.tn.xh_643 tk.om.un_540 
  0x06005d07, 0xfe003820, 0x1a382a5a, 0x171004a9,   // ss.de.un_420 tk.tlh.un_850  mt.tk.tl_553 ru.be.sr_544 
  0x38005805, 0x37151555, 0x5c302012, 0x35002813,   // om.tk.un_330 un.ba.un_420  sq.uz.sa_654 sw.zu.un_650 
  // [b440]
  0x46584e08, 0x20000108, 0x0c00fc12, 0x0657fc55,   // ay.om.qu_443 en.sq.un_430  zzp.sv.un_640 zzp.na.de_442 
  0x39002a20, 0x7300020e, 0x1f003907, 0x284630ec,   // bo.dz.un_850 da.ny.un_550  br.cy.un_420 uz.qu.sw_644 
  0x08102511, 0x65002023, 0x0e004902, 0x06003e07,   // mn.be.uk_653 sq.gv.un_880  to.is.un_220 rm.de.un_420 
  0x12303ba4, 0x34233d0b, 0x5a004909, 0x0679fc55,   // ks.uz.ur_433 ku.ky.ps_542  to.sm.un_440 zzp.war.de_442 
  // [b450]
  0x18001f02, 0x04481508, 0x49005a19, 0x64002109,   // cy.ga.un_220 un.tt.ru_443  sm.to.un_750 jw.lg.un_440 
  0x330c4fa0, 0x2f6e21a9, 0x421026a4, 0x4700260e,   // bi.sv.nn_322 jw.hmn.su_544  ia.lt.co_433 ia.sn.un_550 
  0x0a07300c, 0x48103607, 0x2e3308ee, 0x23000a13,   // uz.bg.mk_543 ab.be.tt_432  no.nn.fo_422 mk.ky.un_650 
  0x20004c14, 0x2e005105, 0x17302302, 0xfc004c07,   // wo.sq.un_660 kl.fo.un_330  ky.uz.sr_222 wo.zzp.un_420 
  // [b460]
  0x34282108, 0x380e4804, 0x621b480c, 0x01650e0c,   // fa.sd.ps_443 tt.is.tk_332  tt.tr.kha_543 is.gv.en_543 
  0x081004ee, 0x1b0f1007, 0x5c006b04, 0x50002207,   // ru.be.uk_422 lt.lv.tr_432  ceb.sa.un_320 oc.fj.un_420 
  0x13621009, 0x7526515a, 0x5e3762a7, 0x04151012,   // lt.kha.et_444 kl.ia.nso_553  kha.st.ts_532 be.ru.un_640 
  0x0e001013, 0x301525ad, 0x181f27a4, 0x040815a7,   // lt.is.un_650 mn.uz.un_630  gd.cy.ga_433 un.uk.ru_532 
  // [b470]
  0x1f00580d, 0x18233405, 0x02003618, 0x4f3024a0,   // om.cy.un_540 ps.ky.ar_333  gn.da.un_740 eo.uz.bi_322 
  0x4b006819, 0x492036a0, 0xfe007308, 0x351036a0,   // ig.mi.un_750 gn.sq.to_322  ny.tlh.un_430 ab.be.tg_322 
  0x65460311, 0x0e102e0c, 0x0a103508, 0x17113507,   // nl.qu.gv_653 fo.lt.is_543  tg.be.mk_443 tg.ro.sr_432 
  0x0e481fee, 0x01005707, 0x15620107, 0x355f37af,   // cy.tt.is_422 na.en.un_420  en.kha.un_432 st.tn.zu_655 
  // [b480]
  0x13fe2904, 0x080736ad, 0x4b006304, 0x18375f0c,   // sl.tlh.et_332 ab.bg.uk_643  sco.mi.un_320 tn.st.ga_543 
  0x2b00fe07, 0x3200171b, 0x47fe2908, 0x46003807,   // tlh.vi.un_420 sr.bs.un_770  sl.tlh.sn_443 tk.qu.un_420 
  0x29156007, 0x0c650412, 0x2b002f07, 0x02006013,   // vo.sl.un_420 fi.gv.sv_654  su.vi.un_420 vo.da.un_650 
  0x0c006512, 0x0204650c, 0x39fe1311, 0x38fc0912,   // gv.sv.un_640 gv.fi.da_543  et.tlh.br_653 pl.zzp.tk_654 
  // [b490]
  0x20532aa0, 0x3c30360c, 0x1d000e07, 0x0900381b,   // mt.ht.sq_322 ab.uz.ug_543  is.la.un_420 tk.pl.un_770 
  0x374836ec, 0x6e000234, 0x53697608, 0x3e2223a4,   // ab.tt.ba_644 da.hmn.un_A80  crs.mfe.ht_443 ca.oc.rm_433 
  0x2913fea4, 0x4c330804, 0x04006519, 0x040c02a4,   // tlh.et.sl_433 no.nn.wo_332  gv.fi.un_750 da.sv.fi_433 
  0x080725a0, 0x48005b0e, 0x40004805, 0x38000918,   // mn.bg.uk_322 sg.tt.un_550  tt.lb.un_330 pl.tk.un_740 
  // [b4a0]
  0x42004905, 0x01002420, 0x0a000502, 0x0b001304,   // to.co.un_330 yi.iw.un_850  fr.pt.un_220 et.es.un_320 
  0xfc545107, 0x0c001807, 0x190b0da0, 0x42fc070c,   // kl.ik.zzp_432 ga.sv.un_420  cs.es.gl_322 it.zzp.co_543 
  0x1c0d09ac, 0x34001211, 0x42076407, 0x5c1309a0,   // hi.ne.mr_632 ur.ps.un_630  lg.it.co_432 hi.bh.sa_322 
  0x2100302a, 0x6b0e1dee, 0xfc004213, 0x12362e0c,   // uz.fa.un_970 la.is.ceb_422  co.zzp.un_650 fo.gn.hu_543 
  // [b4b0]
  0x2e022007, 0x6043010c, 0x2b222f02, 0x2c2665a4,   // sq.da.fo_432 en.ie.vo_543  su.oc.vi_222 gv.ia.fy_433 
  0x68001d08, 0x332e0ca0, 0x24000304, 0x1d00fc02,   // la.ig.un_430 sv.fo.nn_322  nl.eo.un_320 zzp.la.un_220 
  0x3c11040d, 0x0a123604, 0x12003e11, 0x2a000104,   // ru.ro.ug_554 gn.hu.pt_332  rm.hu.un_630 en.mt.un_320 
  0x17162907, 0x2f2a45a0, 0x040715af, 0x3f001a07,   // sl.hr.sr_432 ln.mt.su_322  un.bg.ru_655 tl.af.un_420 
  // [b4c0]
  0x153102a6, 0x035376a7, 0x0c0e2e05, 0x12005005,   // da.az.un_521 crs.ht.nl_532  fo.is.sv_333 fj.hu.un_330 
  0x33080cad, 0x3b381ba4, 0x345e56ad, 0x4400100c,   // sv.no.nn_643 tr.tk.so_433  mg.ts.xh_643 be.kk.un_530 
  0x330e2ea0, 0x763e69a4, 0x03004604, 0x041511ec,   // fo.is.nn_322 mfe.rm.crs_433  qu.nl.un_320 ro.ru.un_640 
  0x03001c0d, 0x08330c08, 0x29434d07, 0x300742a0,   // id.nl.un_540 sv.nn.no_443  aa.ie.sl_432 co.it.uz_322 
  // [b4d0]
  0x1d510207, 0x040a28b2, 0x093416a0, 0x44483007,   // da.kl.la_432 sd.mk.ru_732  hr.xh.pl_322 uz.tt.kk_432 
  0x03464e12, 0x3b003d1a, 0x15383c55, 0x36111507,   // ay.qu.nl_654 ku.ks.un_760  ug.tk.un_442 un.ro.ab_432 
  0x073c3707, 0x110a3014, 0x301735a0, 0x4c002d08,   // ba.ug.bg_432 uz.mk.ro_666  tg.sr.uz_322 sk.wo.un_430 
  0x30182112, 0x135c090d, 0x101515ad, 0x52001b04,   // fa.ar.uz_654 hi.sa.bh_554  un.be.un_630 tr.ha.un_320 
  // [b4e0]
  0x0a08170b, 0x162917a4, 0x321646ee, 0x0a441155,   // sr.uk.mk_542 sr.sl.hr_433  qu.hr.bs_422 ro.kk.mk_442 
  0x122238a4, 0x64126713, 0x5a4301a0, 0x64006711,   // tk.oc.hu_433 ak.hu.lg_665  en.ie.sm_322 ak.lg.un_630 
  0x64001213, 0x0e2821a6, 0x071038a0, 0x2e5102ac,   // hu.lg.un_650 jw.sw.is_521  tk.be.bg_322 da.kl.fo_632 
  0x46002807, 0x4222010b, 0x46002916, 0x375f5204,   // sw.qu.un_420 en.oc.co_542  sl.qu.un_720 ha.tn.st_332 
  // [b4f0]
  0x3f024d07, 0x2a595508, 0x07481504, 0x2226010c,   // aa.da.af_432 rw.rn.mt_443  un.tt.bg_332 en.ia.oc_543 
  0x5e00211a, 0x5c201d0c, 0x55001212, 0x3600251a,   // jw.ts.un_760 la.sq.sa_543  hu.rw.un_640 mn.ab.un_760 
  0x0700480c, 0x3f001f2a, 0x6b211d55, 0x3e1d6004,   // tt.bg.un_530 cy.af.un_970  la.jw.ceb_442 vo.la.rm_332 
  0x5d2c010c, 0xfe094f0c, 0x1d00fc04, 0x1c000922,   // en.fy.ss_543 bi.pl.tlh_543  zzp.la.un_320 hi.mr.un_870 
  // [b500]
  0x095c0d13, 0x13122507, 0x30001c08, 0x074a4207,   // ne.sa.hi_665 eu.hu.et_432  id.uz.un_430 co.yo.it_432 
  0x4a4257a0, 0x39003b14, 0x301228af, 0x4a005714,   // na.co.yo_322 so.br.un_660  sd.ur.uz_655 na.yo.un_660 
  0x3f001f0b, 0x42534aee, 0x21022804, 0x12136ba6,   // cy.af.un_520 yo.ht.co_422  sw.da.jw_332 ceb.et.hu_521 
  0x07224207, 0x40002a05, 0x38364955, 0x73000404,   // co.oc.it_432 mt.lb.un_330  to.gn.tk_442 fi.ny.un_320 
  // [b510]
  0x1a5c5fa0, 0x534a57ad, 0x5e3534a4, 0x073e420c,   // tn.sa.tl_322 na.yo.ht_643  xh.zu.ts_433 co.rm.it_543 
  0x6473470c, 0x29002d13, 0x15002a02, 0x570661af,   // sn.ny.lg_543 sk.sl.un_650  mt.un.un_220 za.de.na_655 
  0x245c3405, 0x2f00360e, 0x5c28760d, 0x424a5604,   // xh.sa.eo_333 gn.su.un_550  crs.sw.sa_554 mg.yo.co_332 
  0x38002d0c, 0x121a24ee, 0x4a075712, 0x31685e07,   // sk.tk.un_530 eo.tl.hu_422  na.it.yo_654 ts.ig.az_432 
  // [b520]
  0x2c1333a0, 0x07424a08, 0x12343b07, 0x3e06795a,   // nn.et.fy_322 yo.co.it_443  ks.ps.ur_432 war.de.rm_553 
  0x183430ad, 0x6100fc0e, 0x02322807, 0x03292b0c,   // uz.ps.ar_643 zzp.za.un_550  sw.bs.da_432 vi.sl.nl_543 
  0x47002834, 0x080c3307, 0x1b0e020e, 0x0f001212,   // sw.sn.un_A80 nn.sv.no_432  da.is.tr_555 hu.lv.un_640 
  0x6447605a, 0x73004e09, 0x7800fe0c, 0x1a2a020b,   // vo.sn.lg_553 ay.ny.un_440  tlh.ve.un_530 da.mt.tl_542 
  // [b530]
  0x19005a11, 0x2e0e65a7, 0xfe105804, 0x01421d07,   // sm.gl.un_630 gv.is.fo_532  om.lt.tlh_332 la.co.en_432 
  0x293038a0, 0x160e42a7, 0x01004205, 0x5c002619,   // tk.uz.sl_322 co.is.hr_532  co.en.un_330 ia.sa.un_750 
  0x6b113014, 0x3528340c, 0x55fe6011, 0x4c006123,   // uz.ro.ceb_666 xh.sw.zu_543  vo.tlh.rw_653 za.wo.un_880 
  0x48004d13, 0x24120207, 0x1a555912, 0x65360aa9,   // aa.tt.un_650 da.hu.eo_432  rn.rw.tl_654 pt.gn.gv_544 
  // [b540]
  0x27001e04, 0x13652508, 0x2c001f08, 0x2d09290c,   // ms.gd.un_320 eu.gv.et_443  cy.fy.un_430 sl.pl.sk_543 
  0x37595508, 0x2e0e33a0, 0x08230aa0, 0x3f001f09,   // rw.rn.st_443 nn.is.fo_322  mk.ky.uk_322 cy.af.un_440 
  0x48301202, 0x73005e21, 0x055a0107, 0x100f5ca9,   // hu.uz.tt_222 ts.ny.un_860  en.sm.fr_432 sa.lv.lt_544 
  0x4a0449a0, 0x65203908, 0x0d00132a, 0x2a0733a4,   // to.fi.yo_322 br.sq.gv_443  bh.ne.un_970 nn.it.mt_433 
  // [b550]
  0x465559ad, 0x1d5c51ec, 0x50004b07, 0x514226a4,   // rn.rw.qu_643 kl.sa.la_644  mi.fj.un_420 ia.co.kl_433 
  0x0b005304, 0x0a004602, 0x2d3bfc0c, 0x6500011a,   // ht.es.un_320 qu.pt.un_220  zzp.so.sk_543 en.gv.un_760 
  0x0a233804, 0x58653b13, 0x5c002b1d, 0x173010a7,   // tk.ky.mk_332 so.gv.om_665  vi.sa.un_820 be.uz.sr_532 
  0x173011ee, 0x4448376c, 0x34231805, 0x05000304,   // ro.uz.sr_422 ba.tt.kk_873  ar.ky.ps_333 nl.fr.un_320 
  // [b560]
  0x52003b22, 0x636501a4, 0x37656eec, 0x49735a05,   // so.ha.un_870 en.gv.sco_433  hmn.gv.st_644 sm.ny.to_333 
  0x63656eec, 0x4f001314, 0xfc3450ad, 0x75005f1a,   // hmn.gv.sco_644 et.bi.un_660  fj.xh.zzp_643 tn.nso.un_760 
  0x1a002404, 0x0c2546a0, 0x21092507, 0x5d375ea0,   // eo.tl.un_320 qu.eu.sv_322  eu.pl.jw_432 ts.st.ss_322 
  0x23191113, 0x3e000705, 0x0200180e, 0x44100408,   // ro.gl.ca_665 it.rm.un_330  ga.da.un_550 ru.be.kk_443 
  // [b570]
  0x283e47a0, 0x0f000604, 0x47002407, 0x5a025f07,   // sn.rm.sw_322 de.lv.un_320  eo.sn.un_420 tn.da.sm_432 
  0x65423eec, 0x230511a0, 0x17000712, 0x0d09130b,   // rm.co.gv_644 ro.fr.ca_322  bg.sr.un_640 bh.hi.ne_542 
  0x2d0dfe14, 0x5d003508, 0x34003d1a, 0x11022a0d,   // tlh.cs.sk_666 zu.ss.un_430  ku.ps.un_760 mt.da.ro_554 
  0x083c3002, 0x6e39fe0c, 0x02003b0d, 0x651f01a0,   // uz.ug.uk_222 tlh.br.hmn_543  so.da.un_540 en.cy.gv_322 
  // [b580]
  0x31001b18, 0x0f651fad, 0x3f4f0111, 0xfc064007,   // tr.az.un_740 cy.gv.lv_643  en.bi.af_653 lb.de.zzp_432 
  0x3930fe07, 0x08330c5a, 0x250711a0, 0x33080ca7,   // tlh.uz.br_432 sv.nn.no_553  ro.bg.mn_322 sv.no.nn_532 
  0x4f7601ee, 0x02fe2aa4, 0x283421a9, 0x1300330d,   // en.crs.bi_422 mt.tlh.da_433  fa.ps.sd_544 nn.et.un_540 
  0x6e3bfea9, 0x65000d0d, 0x06fe630c, 0x1d001a07,   // tlh.so.hmn_544 cs.gv.un_540  sco.tlh.de_543 tl.la.un_420 
  // [b590]
  0x384823af, 0x080c3304, 0x15003808, 0x111007ad,   // ky.tt.tk_655 nn.sv.no_332  tk.un.un_430 bg.be.ro_643 
  0x3f001504, 0x06fc6502, 0x0f003904, 0x0b193e12,   // un.af.un_320 gv.zzp.de_222  br.lv.un_320 rm.gl.es_654 
  0x234437af, 0x04351709, 0x33080211, 0x21004c07,   // ba.kk.ky_655 sr.tg.ru_444  da.no.nn_653 wo.jw.un_420 
  0x6500151a, 0x304c6507, 0x483538ee, 0x330c08ad,   // un.gv.un_760 gv.wo.uz_432  tk.tg.tt_422 no.sv.nn_643 
  // [b5a0]
  0x103919a4, 0x17001020, 0x65003b0e, 0x082e33a4,   // gl.br.lt_433 be.sr.un_850  so.gv.un_550 nn.fo.no_433 
  0x08332ea7, 0x190b3ea4, 0x1d4b4204, 0xfe653b0c,   // fo.nn.no_532 rm.es.gl_433  co.mi.la_332 so.gv.tlh_543 
  0x4b1c0407, 0x202436ec, 0x4b0475a4, 0x5f006a21,   // fi.id.mi_432 gn.eo.sq_644  nso.fi.mi_433 haw.tn.un_860 
  0x342812a6, 0x1f004621, 0x6a4b47a7, 0x303f0307,   // ur.sd.ps_521 qu.cy.un_860  sn.mi.haw_532 nl.af.uz_432 
  // [b5b0]
  0x30363509, 0x30151004, 0x08102508, 0x1c476708,   // tg.ab.uz_444 be.uz.un_320  mn.be.uk_443 ak.sn.id_443 
  0x6a494b07, 0x36734f07, 0x24002805, 0x5269765a,   // mi.to.haw_432 bi.ny.gn_432  sw.eo.un_330 crs.mfe.ha_553 
  0x20450da4, 0x364b4705, 0x104b120c, 0x5f1e1c05,   // cs.ln.sq_433 sn.mi.gn_333  hu.mi.lt_543 id.ms.tn_333 
  0x37003822, 0x4b364755, 0x53000514, 0x033f1ca4,   // tk.ba.un_870 sn.gn.mi_442  fr.ht.un_660 id.af.nl_433 
  // [b5c0]
  0x59550eaf, 0x211b2f05, 0x643947ad, 0x31524904,   // is.rw.rn_655 su.tr.jw_333  sn.br.lg_643 to.ha.az_332 
  0x6a1c3ba4, 0x0b3f2d02, 0x211643a7, 0x47002808,   // so.id.haw_433 sk.af.es_222  ie.hr.jw_532 sw.sn.un_430 
  0x49005221, 0x373b12a4, 0x063f0313, 0x585a4904,   // ha.to.un_860 hu.so.st_433  nl.af.de_665 to.sm.om_332 
  0x02000320, 0x36001f04, 0x644a3508, 0x47385b0c,   // nl.da.un_850 cy.gn.un_320  zu.yo.lg_443 sg.tk.sn_543 
  // [b5d0]
  0x55006411, 0x3b001908, 0x471e52a0, 0x2f033f08,   // lg.rw.un_630 gl.so.un_430  ha.ms.sn_322 af.nl.su_443 
  0x3700040d, 0x64005309, 0x350417a4, 0x453f1ca4,   // fi.st.un_540 ht.lg.un_440  sr.ru.tg_433 id.af.ln_433 
  0x281e1c13, 0x5e00331a, 0x49000504, 0x4f002c12,   // id.ms.sw_665 nn.ts.un_760  fr.to.un_320 fy.bi.un_640 
  0x31531104, 0x1b130404, 0x4236050c, 0x320425a0,   // ro.ht.az_332 fi.et.tr_332  fr.gn.co_543 eu.fi.bs_322 
  // [b5e0]
  0x34123d07, 0x52005607, 0x0e3028a7, 0x470e5e0b,   // ku.ur.ps_432 mg.ha.un_420  sw.uz.is_532 ts.is.sn_542 
  0x475553a0, 0x49005219, 0x21171602, 0x2c033907,   // ht.rw.sn_322 ha.to.un_750  hr.sr.jw_222 br.nl.fy_432 
  0x12303da4, 0x2f732807, 0x7304250c, 0x6467695a,   // ku.uz.ur_433 sw.ny.su_432  eu.fi.ny_543 mfe.ak.lg_553 
  0x20022a07, 0x341812a9, 0x101123a4, 0x1b3538ad,   // mt.da.sq_432 ur.ar.ps_544  ky.ro.be_433 tk.zu.tr_643 
  // [b5f0]
  0x0d130912, 0x1a002f0c, 0x2b211cee, 0x23000d19,   // hi.bh.ne_654 su.tl.un_530  id.jw.vi_422 cs.ca.un_750 
  0x17481108, 0x30002512, 0x06002804, 0x28001608,   // ro.tt.sr_443 mn.uz.un_640  sw.de.un_320 hr.sw.un_430 
  0xfc343b07, 0x4a016ba4, 0x13383612, 0xfc001f09,   // so.xh.zzp_432 ceb.en.yo_433  gn.tk.et_654 cy.zzp.un_440 
  0x5e353604, 0x53001f04, 0x250708a4, 0x23374804,   // gn.zu.ts_332 cy.ht.un_320  uk.bg.mn_433 tt.ba.ky_332 
  // [b600]
  0x300e2e04, 0x04170755, 0x03000a02, 0x483c3008,   // fo.is.uz_332 bg.sr.ru_442  pt.nl.un_220 uz.ug.tt_443 
  0x4d004a1a, 0x0e632e13, 0x1ffc3f0c, 0x1f000214,   // yo.aa.un_760 fo.sco.is_665  af.zzp.cy_543 da.cy.un_660 
  0x40002012, 0x38001721, 0x2c00020b, 0x402d01a0,   // sq.lb.un_640 sr.tk.un_860  da.fy.un_520 en.sk.lb_322 
  0x56002302, 0x31536804, 0x343b2107, 0x08022dee,   // ca.mg.un_220 ig.ht.az_332  fa.ks.ps_432 sk.da.no_422 
  // [b610]
  0x442348a0, 0x09211607, 0x443d3407, 0x164709a0,   // tt.ky.kk_322 hr.jw.pl_432  ps.ku.kk_432 pl.sn.hr_322 
  0x36004212, 0x0d003f0b, 0x34184404, 0x2d042402,   // co.gn.un_640 af.cs.un_520  kk.ar.ps_332 eo.fi.sk_222 
  0x23003e08, 0x3f4a1309, 0x2a006412, 0x121009a0,   // rm.ca.un_430 et.yo.af_444  lg.mt.un_640 pl.lt.hu_322 
  0x4a4b49a0, 0x2e005102, 0x6e00640d, 0x51644aec,   // to.mi.yo_322 kl.fo.un_220  lg.hmn.un_540 yo.lg.kl_644 
  // [b620]
  0x58006404, 0x123c2802, 0x3517040e, 0x441138ad,   // lg.om.un_320 sd.ug.ur_222  ru.sr.tg_555 tk.ro.kk_643 
  0x153748a0, 0x0c000e12, 0x02002e0e, 0x095c1cec,   // tt.ba.un_322 is.sv.un_640  fo.da.un_550 mr.sa.hi_644 
  0x353447ec, 0x211c2fa9, 0x12023504, 0x2022620c,   // sn.xh.zu_644 su.id.jw_544  zu.da.hu_332 kha.oc.sq_543 
  0x1e2f1cad, 0x2a0d5ea0, 0x152535a4, 0x1e002507,   // id.su.ms_643 ts.cs.mt_322  tg.mn.un_433 eu.ms.un_420 
  // [b630]
  0x2b3e6504, 0x09001908, 0x3400110d, 0x12041007,   // gv.rm.vi_332 gl.pl.un_430  ro.xh.un_540 lt.fi.hu_432 
  0x5e733509, 0x522701a4, 0xfc003608, 0x100811af,   // zu.ny.ts_444 en.gd.ha_433  gn.zzp.un_430 ro.uk.be_655 
  0x60523ba4, 0x28356404, 0x1823280c, 0x35343ba4,   // so.ha.vo_433 lg.zu.sw_332  sd.ky.ar_543 so.xh.zu_433 
  0x62003e14, 0x4200022b, 0x34731b0c, 0x47110da9,   // rm.kha.un_660 da.co.un_980  tr.ny.xh_543 cs.ro.sn_544 
  // [b640]
  0x16001a04, 0x732853a0, 0x3b735c05, 0x01003b04,   // tl.hr.un_320 ht.sw.ny_322  sa.ny.so_333 so.en.un_320 
  0x09002f02, 0x33030812, 0x79005508, 0x00000137,   // su.pl.un_220 no.nl.nn_654  rw.war.un_430 en.un.un_B00 
  0x653b5c07, 0x21301208, 0x22001c04, 0x27001507,   // sa.so.gv_432 ur.uz.fa_443  id.oc.un_320 un.gd.un_420 
  0x062122a7, 0x36041005, 0x30736404, 0x383609a7,   // oc.jw.de_532 lt.fi.gn_333  lg.ny.uz_332 pl.gn.tk_532 
  // [b650]
  0x76006934, 0x357652a4, 0x35595d0c, 0x1e00150b,   // mfe.crs.un_A80 ha.crs.zu_433  ss.rn.zu_543 un.ms.un_520 
  0xfc585c13, 0x102d6304, 0x53003b0b, 0x20381b11,   // sa.om.zzp_665 sco.sk.lt_332  so.ht.un_520 tr.tk.sq_653 
  0x091c5c0d, 0x36001102, 0x123428a4, 0x351e1c09,   // sa.mr.hi_554 ro.gn.un_220  sd.ps.ur_433 id.ms.zu_444 
  0x00000637, 0x09000d23, 0x495956a9, 0x23002802,   // de.un.un_B00 ne.hi.un_880  mg.rn.to_544 sw.ca.un_220 
  // [b660]
  0x250d2da4, 0x021b1ca4, 0x20554c07, 0x1d301f0c,   // sk.cs.eu_433 id.tr.da_433  wo.rw.sq_432 cy.uz.la_543 
  0x5c461aa0, 0x6b587955, 0x02455711, 0x79536bec,   // tl.qu.sa_322 war.om.ceb_442  na.ln.da_653 ceb.ht.war_644 
  0x34123b5a, 0x5c6b1aa0, 0x5c00120b, 0x0a041507,   // ks.ur.ps_553 tl.ceb.sa_322  hu.sa.un_520 un.ru.mk_432 
  0x372315a7, 0x0821fea7, 0x121e1c04, 0x37354804,   // un.ky.ba_532 tlh.jw.no_532  id.ms.hu_332 tt.tg.ba_332 
  // [b670]
  0x1d00620d, 0x44483714, 0x44103ca0, 0x6900530e,   // kha.la.un_540 ba.tt.kk_666  ug.be.kk_322 ht.mfe.un_550 
  0x35210cad, 0x3b123da4, 0x36151712, 0x5c005308,   // sv.jw.zu_643 ku.ur.ks_433  sr.ab.un_640 ht.sa.un_430 
  0x285e450b, 0x0448100c, 0x151036a4, 0x48114e08,   // ln.ts.sw_542 be.tt.ru_543  ab.be.un_433 ay.ro.tt_443 
  0x391753a0, 0x470f45a0, 0x304815ac, 0x2d1142ee,   // ht.sr.br_322 ln.lv.sn_322  un.tt.uz_632 co.ro.sk_422 
  // [b680]
  0x42790707, 0x29003934, 0x0a172308, 0x0b001112,   // it.war.co_432 br.sl.un_A80  ky.sr.mk_443 ro.es.un_640 
  0x2d7939a0, 0x075369a7, 0x28003d14, 0x09001f21,   // br.war.sk_322 mfe.ht.it_532  ku.sd.un_660 cy.pl.un_860 
  0x3e0f2504, 0x10004805, 0x2900090e, 0x5c000822,   // eu.lv.rm_332 tt.be.un_330  pl.sl.un_550 no.sa.un_870 
  0x300804a0, 0x12443c04, 0x3400230e, 0x182112ac,   // ru.uk.uz_322 ug.kk.ur_332  ky.ps.un_550 ur.fa.ar_632 
  // [b690]
  0x04151013, 0x48006013, 0x034c3f07, 0x65024c12,   // be.ru.un_650 vo.tt.un_650  af.wo.nl_432 wo.da.gv_654 
  0x0b006025, 0x10042502, 0x1565010c, 0x2348150c,   // vo.es.un_920 mn.ru.be_222  en.gv.un_543 un.tt.ky_543 
  0x03006308, 0x4a033f07, 0x63005b0d, 0x79001a13,   // sco.nl.un_430 af.nl.yo_432  sg.sco.un_540 tl.war.un_650 
  0x1b603008, 0x2000590c, 0x033f3ba9, 0x19230ba0,   // uz.vo.tr_443 rn.sq.un_530  so.af.nl_544 es.ca.gl_322 
  // [b6a0]
  0x4f0430ad, 0x73004609, 0x020301a0, 0x5f003723,   // uz.fi.bi_643 qu.ny.un_440  en.nl.da_322 st.tn.un_880 
  0x30384d0c, 0x0400130e, 0x08330c07, 0x12243804,   // aa.tk.uz_543 et.fi.un_550  sv.nn.no_432 tk.eo.hu_332 
  0x38301e07, 0x21442307, 0x2f2a61ee, 0x380708a4,   // ms.uz.tk_432 ky.kk.fa_432  za.mt.su_422 uk.bg.tk_433 
  0x374815a4, 0x47007814, 0x25303cec, 0x230748a6,   // un.tt.ba_433 ve.sn.un_660  ug.uz.mn_644 tt.bg.ky_521 
  // [b6b0]
  0x35152504, 0x5e594708, 0x110701a4, 0x6b00020d,   // mn.tg.un_320 sn.rn.ts_443  en.it.ro_433 da.ceb.un_540 
  0x3b321705, 0x3110470c, 0x48313202, 0x5c222e07,   // sr.bs.so_333 sn.lt.az_543  bs.az.tt_222 fo.oc.sa_432 
  0x65330802, 0x434006af, 0x0f10fe0c, 0x46007308,   // no.nn.gv_222 de.lb.ie_655  tlh.lt.lv_543 ny.qu.un_430 
  0x0c06fcee, 0x08123307, 0x47007913, 0x2a00470b,   // zzp.de.sv_422 nn.hu.no_432  war.sn.un_650 sn.mt.un_520 
  // [b6c0]
  0x1a793807, 0x62002f1a, 0x0a17110c, 0x3e080202,   // tk.war.tl_432 su.kha.un_760  ro.sr.mk_543 da.no.rm_222 
  0x65033fa0, 0x64365e08, 0x0100fe02, 0x5300761a,   // af.nl.gv_322 ts.gn.lg_443  tlh.en.un_220 crs.ht.un_760 
  0x3f003308, 0x0e0c02a0, 0x3302fc02, 0x15004821,   // nn.af.un_430 da.sv.is_322  zzp.da.nn_222 tt.un.un_860 
  0x17003804, 0x21001829, 0x070ffe0c, 0x09021f12,   // tk.sr.un_320 ar.fa.un_960  tlh.lv.it_543 cy.da.pl_654 
  // [b6d0]
  0x64284c0c, 0x0a00380c, 0x35343fa4, 0x201f3fec,   // wo.sw.lg_543 tk.mk.un_530  af.xh.zu_433 af.cy.sq_644 
  0x3800151a, 0x08103708, 0x1b003118, 0x3823440d,   // un.tk.un_760 ba.be.uk_443  az.tr.un_740 kk.ky.tk_554 
  0x1f330809, 0x183d3407, 0x5f003714, 0x49472808,   // no.nn.cy_444 ps.ku.ar_432  st.tn.un_660 sw.sn.to_443 
  0x5c122fa0, 0x492830ec, 0x2b001e04, 0x355c1255,   // su.hu.sa_322 uz.sw.to_644  ms.vi.un_320 hu.sa.zu_442 
  // [b6e0]
  0x345a5da9, 0x2832160d, 0x34455fa4, 0x070210ad,   // ss.sm.xh_544 hr.bs.sw_554  tn.ln.xh_433 lt.da.it_643 
  0x431211a4, 0x65185a05, 0x204a45a4, 0x0d4211a4,   // ro.hu.ie_433 sm.ga.gv_333  ln.yo.sq_433 ro.co.cs_433 
  0x04153ca9, 0x6b2a4d12, 0x123128a9, 0x1f003922,   // ug.ru.un_540 aa.mt.ceb_654  sw.az.hu_544 br.cy.un_870 
  0x385c1b0c, 0x0f1c25ee, 0x1e1c18a4, 0x5e00600c,   // tr.sa.tk_543 eu.id.lv_422  ga.id.ms_433 vo.ts.un_530 
  // [b6f0]
  0x153c3604, 0x586413a0, 0x355d4ba6, 0x5c11200c,   // ab.ug.un_332 et.lg.om_322  mi.ss.zu_521 sq.ro.sa_543 
  0x051342a0, 0x5c652bad, 0x10003607, 0x4f03010c,   // co.et.fr_322 vi.gv.sa_643  ab.be.un_420 en.nl.bi_543 
  0x1000041a, 0x17490d07, 0x16101e07, 0xfe2a2bee,   // fi.lt.un_760 cs.to.sr_432  ms.lt.hr_432 vi.mt.tlh_422 
  0x37001107, 0x63000136, 0x0263620c, 0x283c21a9,   // ro.ba.un_420 en.sco.un_AA0  kha.sco.da_543 fa.ug.sd_544 
  // [b700]
  0x10000f14, 0x35342a05, 0x095c0d0e, 0x3025150c,   // lv.lt.un_660 mt.xh.zu_333  ne.sa.hi_555 un.mn.uz_543 
  0x6200011a, 0x263b1811, 0x3b3e01a9, 0x150a57ad,   // en.kha.un_760 ga.so.ia_653  en.rm.so_544 na.pt.un_643 
  0x3500510c, 0x534d580c, 0x353455ec, 0x35004604,   // kl.zu.un_530 om.aa.ht_543  rw.xh.zu_644 qu.zu.un_320 
  0x310d3907, 0x31fe5cec, 0x103017a9, 0x34513504,   // br.cs.az_432 sa.tlh.az_644  sr.uz.be_544 zu.kl.xh_332 
  // [b710]
  0x0b1d09ac, 0x170a38a0, 0x01066304, 0x35341105,   // pl.la.es_632 tk.mk.sr_322  sco.de.en_332 ro.xh.zu_333 
  0x3f396012, 0x1507110c, 0x304dfeec, 0x0c00fe2c,   // vo.br.af_654 ro.bg.un_543  tlh.aa.uz_644 tlh.sv.un_990 
  0x34643513, 0x6200632b, 0x0b001104, 0x38005305,   // zu.lg.xh_665 sco.kha.un_980  ro.es.un_320 ht.tk.un_330 
  0x3711230c, 0x10000414, 0x471b4204, 0x5534350c,   // ky.ro.ba_543 ru.be.un_660  co.tr.sn_332 zu.xh.rw_543 
  // [b720]
  0x234410ee, 0x0a2319ad, 0x043017a9, 0x07001e0d,   // be.kk.ky_422 gl.ca.pt_643  sr.uz.ru_544 am.bg.un_540 
  0x0a001d04, 0x420f1d08, 0x645c3455, 0x5c004707,   // la.pt.un_320 la.lv.co_443  xh.sa.lg_442 sn.sa.un_420 
  0x31001309, 0x5804130b, 0x1d134e0c, 0x68796ba9,   // et.az.un_440 et.fi.om_542  ay.et.la_543 ceb.war.ig_544 
  0x55286960, 0x284e46ac, 0x2b001f02, 0x3c3035a9,   // mfe.sw.rw_664 qu.ay.sw_632  cy.vi.un_220 tg.uz.ug_544 
  // [b730]
  0x3f000404, 0x08042305, 0x5c001219, 0x485c2107,   // fi.af.un_320 ky.ru.uk_333  hu.sa.un_750 jw.sa.tt_432 
  0x23254405, 0x123539ee, 0x06001802, 0x12003f04,   // kk.mn.ky_333 br.zu.hu_422  ga.de.un_220 af.hu.un_320 
  0x3b350ba4, 0x422e5ca0, 0x3700250b, 0x556b6409,   // es.zu.so_433 sa.fo.co_322  mn.ba.un_520 lg.ceb.rw_444 
  0x3f002f04, 0x2a2e46af, 0x46104e0b, 0x0e00240d,   // su.af.un_320 qu.fo.mt_655  ay.lt.qu_542 eo.is.un_540 
  // [b740]
  0x15004608, 0x3b002407, 0x3b005d05, 0x4800120c,   // qu.un.un_430 eo.so.un_420  ss.so.un_330 hu.tt.un_530 
  0x12002e12, 0x0000160f, 0x3515170c, 0x12301807,   // fo.hu.un_640 hr.un.un_600  sr.tg.un_530 ar.uz.ur_432 
  0x1b00120c, 0x24004a05, 0x0b001a09, 0x341218ec,   // hu.tr.un_530 yo.eo.un_330  tl.es.un_440 ar.ur.ps_644 
  0x151707af, 0x342330a9, 0x1834280e, 0x400e06ad,   // bg.sr.un_655 uz.ky.ps_544  sd.ps.ar_555 de.is.lb_643 
  // [b750]
  0x09001205, 0x51002f08, 0x30003b12, 0x1b004822,   // hu.pl.un_330 su.kl.un_430  so.uz.un_640 tt.tr.un_870 
  0x04071002, 0x634d0107, 0x1a3b0404, 0x20113004,   // be.bg.ru_222 en.aa.sco_432  fi.so.tl_332 uz.ro.sq_332 
  0x4b45045a, 0x3b553704, 0x29305da4, 0x58003420,   // fi.ln.mi_553 st.rw.so_332  ss.uz.sl_433 xh.om.un_850 
  0x4a1a34a0, 0x29377511, 0x0f2c010c, 0x30004c07,   // xh.tl.yo_322 nso.st.sl_653  en.fy.lv_543 wo.uz.un_420 
  // [b760]
  0x4a23450c, 0x3b005507, 0x69486508, 0x3b007313,   // ln.ca.yo_543 rw.so.un_420  gv.tt.mfe_443 ny.so.un_650 
  0x5a4802ee, 0x244d2da4, 0x6a5a12ec, 0x48003b22,   // da.tt.sm_422 sk.aa.eo_433  hu.sm.haw_644 so.tt.un_870 
  0x38001f18, 0x110916a0, 0x73003012, 0x02004d13,   // cy.tk.un_740 hr.pl.ro_322  uz.ny.un_640 aa.da.un_650 
  0x57000104, 0xfe4c4d07, 0x18303cad, 0x50493008,   // en.na.un_320 aa.wo.tlh_432  ug.uz.ar_643 uz.to.fj_443 
  // [b770]
  0x1d000902, 0x17110711, 0x451d0da4, 0x2e0310a4,   // pl.la.un_220 bg.ro.sr_653  cs.la.ln_433 lt.nl.fo_433 
  0x041dfca4, 0x0d372109, 0x51002709, 0x2308360e,   // zzp.la.fi_433 jw.st.cs_444  gd.kl.un_440 ab.uk.ky_555 
  0x34000a02, 0x65001b04, 0x103525ad, 0x3b4a5104,   // pt.xh.un_220 tr.gv.un_320  mn.tg.be_643 kl.yo.so_332 
  0x65643705, 0x38000104, 0x0e062ea9, 0x38004205,   // st.lg.gv_333 en.tk.un_320  fo.de.is_544 co.tk.un_330 
  // [b780]
  0x30353ca7, 0x3300060c, 0x30081008, 0x5900450d,   // ug.tg.uz_532 de.nn.un_530  be.uk.uz_443 ln.rn.un_540 
  0x064003a0, 0x25005c02, 0x3012280e, 0x25007318,   // nl.lb.de_322 sa.eu.un_220  sd.ur.uz_555 ny.eu.un_740 
  0x2344350b, 0x37443807, 0x15041060, 0x330c0814,   // tg.kk.ky_542 tk.kk.ba_432  be.ru.un_664 no.sv.nn_666 
  0x0c0efc0c, 0x29000f08, 0x32160dee, 0x1b4811a4,   // zzp.is.sv_543 lv.sl.un_430  cs.hr.bs_422 ro.tt.tr_433 
  // [b790]
  0x37002318, 0x79732fa4, 0x1b00501a, 0x0f3f02a7,   // ky.ba.un_740 su.ny.war_433  fj.tr.un_760 da.af.lv_532 
  0x0a041513, 0x1000071b, 0x64500204, 0x31361ba4,   // un.ru.mk_665 bg.be.un_770  da.fj.lg_332 tr.gn.az_433 
  0x1b31550c, 0x475034a9, 0x475e5d07, 0x1b0245a7,   // rw.az.tr_543 xh.fj.sn_544  ss.ts.sn_432 ln.da.tr_532 
  0x64005007, 0x1b28460b, 0x64004605, 0x34211855,   // fj.lg.un_420 qu.sw.tr_542  qu.lg.un_330 ar.fa.ps_442 
  // [b7a0]
  0x0c4a34a0, 0x4c4205ee, 0x174844a0, 0xfc004904,   // xh.yo.sv_322 fr.co.wo_422  kk.tt.sr_322 to.zzp.un_320 
  0x4a5a4304, 0x15353402, 0x35475da0, 0x25353807,   // ie.sm.yo_332 xh.zu.un_222  ss.sn.zu_322 tk.tg.mn_432 
  0x4d005821, 0x03000f04, 0x1e181b0c, 0x082315ec,   // om.aa.un_860 lv.nl.un_320  tr.ga.ms_543 un.ky.uk_644 
  0xfe00150c, 0x156b1dee, 0x3b4958a0, 0x1d100fa4,   // un.tlh.un_530 la.ceb.un_422  om.to.so_322 lv.lt.la_433 
  // [b7b0]
  0x130d09ee, 0x38001029, 0x252336a4, 0x3e0f1902,   // hi.ne.bh_422 be.tk.un_960  ab.ky.mn_433 gl.lv.rm_222 
  0x56004a04, 0x1600170c, 0x173704a0, 0x0f000d02,   // yo.mg.un_320 sr.hr.un_530  ru.ba.sr_322 cs.lv.un_220 
  0xfc4006ee, 0x110a29a0, 0x232b3404, 0x08044802,   // de.lb.zzp_422 sl.pt.ro_322  xh.vi.ca_332 tt.ru.uk_222 
  0x0c02fc07, 0x0e0c1fee, 0x2b000102, 0x0c00fc05,   // zzp.da.sv_432 cy.sv.is_422  en.vi.un_220 zzp.sv.un_330 
  // [b7c0]
  0x180cfca0, 0x33001f05, 0x16290d55, 0x4837380e,   // zzp.sv.ga_322 cy.nn.un_330  cs.sl.hr_442 tk.ba.tt_555 
  0x10001313, 0x2c00fc04, 0x0a002008, 0x183028ad,   // et.lt.un_650 zzp.fy.un_320  sq.pt.un_430 sd.uz.ar_643 
  0x23002502, 0x35301760, 0x080710a7, 0x0e1ffc0e,   // mn.ky.un_220 sr.uz.tg_664  be.bg.uk_532 zzp.cy.is_555 
  0x250415ee, 0x1f0e0ca4, 0x2000530d, 0x100a17a7,   // un.fi.eu_422 sv.is.cy_433  ht.sq.un_540 sr.mk.be_532 
  // [b7d0]
  0x56024711, 0x210d20ee, 0x56005f07, 0x204c0d09,   // sn.da.mg_653 sq.cs.jw_422  tn.mg.un_420 cs.wo.sq_444 
  0x28000214, 0x5f6a73ad, 0x0d2d53a9, 0x4b28020c,   // da.sw.un_660 ny.haw.tn_643  ht.sk.cs_544 da.sw.mi_543 
  0x2d0d21ee, 0x314811ad, 0x21052fa7, 0x0e4e0607,   // jw.cs.sk_422 ro.tt.az_643  su.fr.jw_532 de.ay.is_432 
  0x49005607, 0x5b000213, 0x4c4253ad, 0x10071508,   // mg.to.un_420 da.sg.un_650  ht.co.wo_643 un.bg.be_443 
  // [b7e0]
  0x0a23210d, 0x2c000605, 0x25004808, 0x02285f04,   // jw.ca.pt_554 de.fy.un_330  tt.mn.un_430 tn.sw.da_332 
  0x1b02560c, 0x0d4921a4, 0x2f005604, 0x17351507,   // mg.da.tr_543 jw.to.cs_433  mg.su.un_320 un.tg.sr_432 
  0x2d00fe19, 0x6900fe09, 0x2d290d12, 0x48fe13a7,   // tlh.sk.un_750 tlh.mfe.un_440  cs.sl.sk_654 et.tlh.tt_532 
  0x0d00fe08, 0x290d6e0c, 0x2367fc0c, 0x0a15040c,   // tlh.cs.un_430 hmn.cs.sl_543  zzp.ak.ca_543 ru.mk.un_530 
  // [b7f0]
  0x643e5108, 0x514d0413, 0x0d002d21, 0x1834215a,   // kl.rm.lg_443 fi.aa.kl_665  sk.cs.un_860 fa.ps.ar_553 
  0x470406a0, 0x0a071507, 0x17001108, 0x041351a4,   // de.fi.sn_322 un.bg.mk_432  ro.sr.un_430 kl.et.fi_433 
  0x02001118, 0x092d0d12, 0x0a48620c, 0x13000f1a,   // ro.da.un_740 cs.sk.pl_654  kha.tt.pt_543 lv.et.un_760 
  0x4800290c, 0x1e004d07, 0x65181f04, 0x221d11a0,   // sl.tt.un_530 aa.ms.un_420  cy.ga.gv_332 ro.la.oc_322 
  
  // [b800]
  0x13005119, 0x39000d19, 0x48303111, 0x1d4dfca4,   // kl.et.un_750 cs.br.un_750  az.uz.tt_653 zzp.aa.la_433 
  0x33083ea0, 0x211830a7, 0x44070a05, 0x2c5d1ba0,   // rm.no.nn_322 uz.ar.fa_532  mk.bg.kk_333 tr.ss.fy_322 
  0x60396ea4, 0x122830a0, 0x1afc010b, 0x3f000613,   // hmn.br.vo_433 uz.sd.ur_322  en.zzp.tl_542 de.af.un_650 
  0x4b003612, 0x40060313, 0x23006807, 0x4704510c,   // gn.mi.un_640 nl.de.lb_665  ig.ca.un_420 kl.fi.sn_543 
  // [b810]
  0x4204400c, 0x5c005a05, 0x252337a0, 0x0a2b1c07,   // lb.fi.co_543 sm.sa.un_330  ba.ky.mn_322 id.vi.pt_432 
  0x4f002e14, 0x45000521, 0x02135c08, 0x026953a4,   // fo.bi.un_660 fr.ln.un_860  sa.et.da_443 ht.mfe.da_433 
  0x55485908, 0x32005c0c, 0x48104460, 0x37006e29,   // rn.tt.rw_443 sa.bs.un_530  kk.be.tt_664 hmn.st.un_960 
  0x1d6502a0, 0x3b006419, 0x3f031305, 0x2e005c0c,   // da.gv.la_322 lg.so.un_750  et.nl.af_333 sa.fo.un_530 
  // [b820]
  0x170d29a0, 0x48363712, 0x586a4a07, 0x21283455,   // sl.cs.sr_322 ba.ab.tt_654  yo.haw.om_432 ps.sd.fa_442 
  0x69006408, 0x1c0d09a6, 0x6500631a, 0x28301b12,   // lg.mfe.un_430 hi.ne.mr_521  sco.gv.un_760 tr.uz.sw_654 
  0x65210107, 0x04fe13a4, 0x291662ee, 0x2c3f20ed,   // en.jw.gv_432 et.tlh.fi_433  kha.hr.sl_422 sq.af.fy_622 
  0x0a060c04, 0x652c5cad, 0x38554604, 0x44173808,   // sv.de.pt_332 sa.fy.gv_643  qu.rw.tk_332 tk.sr.kk_443 
  // [b830]
  0x2d0d4905, 0x2c650305, 0x17290da4, 0x6e636508,   // to.cs.sk_333 nl.gv.fy_333  cs.sl.sr_433 gv.sco.hmn_443 
  0x1700080e, 0x37001104, 0x1b000404, 0x62041312,   // uk.sr.un_550 ro.st.un_320  fi.tr.un_320 et.fi.kha_654 
  0x50353455, 0x483835a4, 0x65041360, 0x46684d0b,   // xh.zu.fj_442 tg.tk.tt_433  et.fi.gv_664 aa.ig.qu_542 
  0x302904a0, 0x3b006822, 0x204a64a4, 0x0c000607,   // fi.sl.uz_322 ig.so.un_870  lg.yo.sq_433 de.sv.un_420 
  // [b840]
  0x735245ee, 0x0a2d0d02, 0x68603507, 0x2f000412,   // ln.ha.ny_422 cs.sk.pt_222  zu.vo.ig_432 fi.su.un_640 
  0x381d560c, 0x302508ad, 0x47735daf, 0x73002912,   // mg.la.tk_543 uk.mn.uz_643  ss.ny.sn_655 sl.ny.un_640 
  0x106b1a0c, 0x483015a4, 0x1f273e0c, 0x19001204,   // tl.ceb.lt_543 un.uz.tt_433  rm.gd.cy_543 hu.gl.un_320 
  0x1100102b, 0x64582aa0, 0x42003502, 0x3e00270e,   // be.ro.un_980 mt.om.lg_322  zu.co.un_220 gd.rm.un_550 
  // [b850]
  0x304415a0, 0x01007902, 0x655701a7, 0x08303caf,   // un.kk.uz_322 war.en.un_220  en.na.gv_532 ug.uz.uk_655 
  0x396922a4, 0x1532fe07, 0x38442309, 0x55153405,   // oc.mfe.br_433 tlh.bs.un_432  ky.kk.tk_444 xh.rw.un_330 
  0x0c290d08, 0x34465e04, 0x1a2f62a4, 0x15004002,   // cs.sl.sv_443 ts.qu.xh_332  kha.su.tl_433 lb.un.un_220 
  0x1f4f62a0, 0x23552207, 0x3c4437af, 0x01005602,   // kha.bi.cy_322 oc.rw.ca_432  ba.kk.ug_655 mg.en.un_220 
  // [b860]
  0x160d2908, 0x6b467912, 0x2310440c, 0x150817a0,   // sl.cs.hr_443 war.qu.ceb_654  kk.be.ky_543 sr.uk.un_322 
  0x190118a0, 0x290d3e08, 0x1d003e02, 0x03232e0c,   // ga.en.gl_322 rm.cs.sl_443  rm.la.un_220 fo.ca.nl_543 
  0x23253804, 0x301c38a7, 0x3f005202, 0x2f6b7304,   // tk.mn.ky_332 tk.id.uz_532  ha.af.un_220 ny.ceb.su_332 
  0x483b46ee, 0x1700380b, 0x1c461aa0, 0x04082507,   // qu.so.tt_422 tk.sr.un_520  tl.qu.id_322 mn.uk.ru_432 
  // [b870]
  0x453656a9, 0x584c6512, 0x5c005a0d, 0x2b00422c,   // mg.gn.ln_544 gv.wo.om_654  sm.sa.un_540 co.vi.un_990 
  0x69330805, 0x12004905, 0x424a2bec, 0x4a002b22,   // no.nn.mfe_333 to.hu.un_330  vi.yo.co_644 vi.yo.un_870 
  0x42002b1b, 0x4a2742a9, 0x58004c11, 0x4a00422b,   // vi.co.un_770 co.gd.yo_544  wo.om.un_630 co.yo.un_980 
  0x4a002b19, 0x33086eee, 0x2b564aec, 0x4a004222,   // vi.yo.un_750 hmn.no.nn_422  yo.mg.vi_644 co.yo.un_870 
  // [b880]
  0x63003f12, 0x65004c1a, 0x3f001702, 0x27224a5a,   // af.sco.un_640 wo.gv.un_760  sr.af.un_220 yo.oc.gd_553 
  0x3f00040d, 0x0e3908a0, 0xfc281d55, 0x0a25170c,   // fi.af.un_540 no.br.is_322  la.sw.zzp_442 sr.mn.mk_543 
  0x3d342112, 0x2a76010c, 0x0c00021a, 0x49003104,   // fa.ps.ku_654 en.crs.mt_543  da.sv.un_760 az.to.un_320 
  0x654c5209, 0x65630c55, 0x40150e04, 0x53460e02,   // ha.wo.gv_444 sv.sco.gv_442  is.lb.un_320 is.qu.ht_222 
  // [b890]
  0x5d063504, 0x21011813, 0x1f003f13, 0x4c69760c,   // zu.de.ss_332 ar.iw.fa_665  af.cy.un_650 crs.mfe.wo_543 
  0x12092cee, 0x303810af, 0x1f003f0c, 0x0c083f08,   // fy.pl.hu_422 be.tk.uz_655  af.cy.un_530 af.no.sv_443 
  0x33083fee, 0x535520a0, 0x53002004, 0x35285da9,   // af.no.nn_422 sq.rw.ht_322  sq.ht.un_320 ss.sw.zu_544 
  0x460e6007, 0x17043704, 0x0d006304, 0x49375f14,   // vo.is.qu_432 ba.ru.sr_332  sco.cs.un_320 tn.st.to_666 
  // [b8a0]
  0x0e025304, 0x35005a0c, 0x471156a0, 0x2d000e07,   // ht.da.is_332 sm.zu.un_530  mg.ro.sn_322 is.sk.un_420 
  0x3830230e, 0x1a500208, 0x2c1f3f11, 0x73004511,   // ky.uz.tk_555 da.fj.tl_443  af.cy.fy_653 ln.ny.un_630 
  0x095c0d11, 0x0f4b5c0e, 0x2a005e09, 0x5300760b,   // ne.sa.hi_653 sa.mi.lv_555  ts.mt.un_440 crs.ht.un_520 
  0x4d1b1e07, 0x5c1a4d08, 0x28473709, 0x697853a4,   // ms.tr.aa_432 aa.tl.sa_443  st.sn.sw_444 ht.ve.mfe_433 
  // [b8b0]
  0x465428af, 0x211c2f13, 0x3d30340d, 0x265e0da0,   // sw.ik.qu_655 su.id.jw_665  ps.uz.ku_554 cs.ts.ia_322 
  0x24000108, 0x15103808, 0x432601a0, 0x28595504,   // iw.yi.un_430 tk.be.un_443  en.ia.ie_322 rw.rn.sw_332 
  0x4f1a010c, 0x51005818, 0x49120b04, 0x4c53280c,   // en.tl.bi_543 om.kl.un_740  es.hu.to_332 sw.ht.wo_543 
  0x30283407, 0x55175a07, 0xfe600112, 0x6301fc0b,   // ps.sd.uz_432 sm.sr.rw_432  en.vo.tlh_654 zzp.en.sco_542 
  // [b8c0]
  0x68006713, 0x58755f09, 0x572873a9, 0x15004822,   // ak.ig.un_650 tn.nso.om_444  ny.sw.na_544 tt.un.un_870 
  0x32252da4, 0x18562707, 0x18002122, 0x12004c13,   // sk.eu.bs_433 gd.mg.ga_432  fa.ar.un_870 wo.hu.un_650 
  0x1d2c01a4, 0x1d620107, 0x106001a4, 0x070a2304,   // en.fy.la_433 en.kha.la_432  en.vo.lt_433 ky.mk.bg_332 
  0x47625ea9, 0x48382308, 0x734650a4, 0x1b282da0,   // ts.kha.sn_544 ky.tk.tt_443  fj.qu.ny_433 sk.sw.tr_322 
  // [b8d0]
  0x3c443714, 0x48002511, 0x37000a07, 0x23003502,   // ba.kk.ug_666 mn.tt.un_630  mk.ba.un_420 tg.ky.un_220 
  0x28303408, 0x2507480c, 0x5c131c14, 0x3c2118a7,   // ps.uz.sd_443 tt.bg.mn_543  mr.bh.sa_666 ar.fa.ug_532 
  0x07080a07, 0x3e1320a0, 0x4437100c, 0x0e2e36a0,   // mk.uk.bg_432 sq.et.rm_322  be.ba.kk_543 gn.fo.is_322 
  0x3b304d11, 0x29002d1a, 0x3c303504, 0x34123da6,   // aa.uz.so_653 sk.sl.un_760  tg.uz.ug_332 ku.ur.ps_521 
  // [b8e0]
  0xfc3534a0, 0x15150407, 0x65002f05, 0x171007af,   // xh.zu.zzp_322 ru.un.un_420  su.gv.un_330 bg.be.sr_655 
  0x01282fee, 0x53006914, 0x2507150b, 0x35645da4,   // su.sw.en_422 mfe.ht.un_660  un.bg.mn_542 ss.lg.zu_433 
  0x303bfea6, 0x1f00fe05, 0x4836380d, 0x15001021,   // tlh.so.uz_521 tlh.cy.un_330  tk.ab.tt_554 be.un.un_860 
  0x2d290d09, 0x32621613, 0x28213455, 0x1b314809,   // cs.sl.sk_444 hr.kha.bs_665  ps.fa.sd_442 tt.az.tr_444 
  // [b8f0]
  0x2f000419, 0x1b48310d, 0x641c2102, 0x343135ee,   // fi.su.un_750 az.tt.tr_554  jw.id.lg_222 zu.az.xh_422 
  0x431c1e0c, 0x080710af, 0x080710ad, 0x1d002105,   // ms.id.ie_543 be.bg.uk_655  be.bg.uk_643 jw.la.un_330 
  0x3b475304, 0x3c170a07, 0x04070a12, 0x64324fa0,   // ht.sn.so_332 mk.sr.ug_432  mk.bg.ru_654 bi.bs.lg_322 
  0x17213407, 0x472f2102, 0x21521ca4, 0x1e2f1ca0,   // xh.jw.sr_432 jw.su.sn_222  id.ha.jw_433 id.su.ms_322 
  // [b900]
  0x11004202, 0x37234455, 0x28625ca9, 0x40060e12,   // co.ro.un_220 kk.ky.ba_442  sa.kha.sw_544 is.de.lb_654 
  0x6300011b, 0x4c305d08, 0x2159550d, 0x03065713,   // en.sco.un_770 ss.uz.wo_443  rw.rn.jw_554 na.de.nl_665 
  0x3c043808, 0x04003c0d, 0x30005c2b, 0x2500480e,   // tk.ru.ug_443 ug.ru.un_540  sa.uz.un_980 tt.mn.un_550 
  0x1d114cee, 0x1cfc1ea0, 0x2c001305, 0x21504c09,   // wo.ro.la_422 ms.zzp.id_322  et.fy.un_330 wo.fj.jw_444 
  // [b910]
  0x09000c08, 0x33020602, 0x0e041fa4, 0x211e1c07,   // sv.pl.un_430 de.da.nn_222  cy.fi.is_433 id.ms.jw_432 
  0x192722a0, 0x2c000602, 0x305450a4, 0x5e002404,   // oc.gd.gl_322 de.fy.un_220  fj.ik.uz_433 eo.ts.un_320 
  0x1f005804, 0x1b383105, 0x16003804, 0x58005120,   // om.cy.un_320 az.tk.tr_333  tk.hr.un_320 kl.om.un_850 
  0x08170408, 0x33001c02, 0x39005112, 0x234830ad,   // ru.sr.uk_443 id.nn.un_220  kl.br.un_640 uz.tt.ky_643 
  // [b920]
  0x3d343bac, 0x65280307, 0x28595aa4, 0x1100380c,   // ks.ps.ku_632 nl.sw.gv_432  sm.rn.sw_433 tk.ro.un_530 
  0x0c0f1008, 0x15790504, 0x535228ee, 0x1d1d6555,   // lt.lv.sv_443 fr.war.un_332  sw.ha.ht_422 gv.la.la_442 
  0xfc0230a4, 0x69595513, 0x343935a0, 0x31515a0c,   // uz.da.zzp_433 rw.rn.mfe_665  zu.br.xh_322 sm.kl.az_543 
  0x200f18ee, 0x0f24105a, 0x20fe2407, 0x09400ba0,   // ga.lv.sq_422 lt.eo.lv_553  eo.tlh.sq_432 es.lb.pl_322 
  // [b930]
  0x3f003405, 0x100c08a7, 0x790a390c, 0x33085ca4,   // xh.af.un_330 no.sv.lt_532  br.pt.war_543 sa.no.nn_433 
  0x0c100fa4, 0x10791a0c, 0x29100f04, 0x07353404,   // lv.lt.sv_433 tl.war.lt_543  lv.lt.sl_332 xh.zu.it_332 
  0x3e001d08, 0x0b003008, 0x645c2802, 0x123539ad,   // la.rm.un_430 uz.es.un_430  sw.sa.lg_222 br.zu.hu_643 
  0x12001309, 0x044437a0, 0x47291760, 0x18001612,   // et.hu.un_440 ba.kk.ru_322  sr.sl.sn_664 th.ar.un_640 
  // [b940]
  0x65761ca4, 0x19001207, 0xfc00360c, 0x32003807,   // id.crs.gv_433 hu.gl.un_420  gn.zzp.un_530 tk.bs.un_420 
  0x0c263e12, 0x59124e0c, 0x101d2405, 0x10172d04,   // rm.ia.sv_654 ay.hu.rn_543  eo.la.lt_333 sk.sr.lt_332 
  0x585143af, 0x292d0d11, 0x353045ad, 0x23001511,   // ie.kl.om_655 cs.sk.sl_653  ln.uz.zu_643 un.ky.un_630 
  0x32003505, 0x1800230b, 0x301e1c09, 0x30353813,   // zu.bs.un_330 ky.ar.un_520  id.ms.uz_444 tk.tg.uz_665 
  // [b950]
  0x0f00fe09, 0x3f131e0c, 0x2f1e1aad, 0x56072608,   // tlh.lv.un_440 ms.et.af_543  tl.ms.su_643 ia.it.mg_443 
  0x12001a19, 0x36006a0c, 0x2c201aa0, 0x2f1e52a9,   // tl.hu.un_750 haw.gn.un_530  tl.sq.fy_322 ha.ms.su_544 
  0x0600550b, 0x63383007, 0x483b30a0, 0x0f002908,   // rw.de.un_520 uz.tk.sco_432  uz.so.tt_322 sl.lv.un_430 
  0x15670612, 0x5d4b510c, 0x1f032a04, 0x520e330b,   // de.ak.un_654 kl.mi.ss_543  mt.nl.cy_332 nn.is.ha_542 
  // [b960]
  0x50522f08, 0x5c134e07, 0x64524955, 0x25005202,   // su.ha.fj_443 ay.et.sa_432  to.ha.lg_442 ha.eu.un_220 
  0x2d0d16a0, 0x25002b04, 0x122f30a0, 0x3200470b,   // hr.cs.sk_322 vi.eu.un_320  uz.su.hu_322 sn.bs.un_520 
  0x212f1c11, 0x464b6aec, 0x100748a0, 0x48233714,   // id.su.jw_653 haw.mi.qu_644  tt.bg.be_322 ba.ky.tt_666 
  0x351750ee, 0x4a523604, 0x55000608, 0x10081704,   // fj.sr.zu_422 gn.ha.yo_332  de.rw.un_430 sr.uk.be_332 
  // [b970]
  0x55000607, 0x0a00100c, 0x10001604, 0x0f291007,   // de.rw.un_420 be.mk.un_530  hr.lt.un_320 lt.sl.lv_432 
  0x21132cec, 0x0413400c, 0x2d0d1014, 0x046a3fa9,   // fy.et.jw_644 lb.et.fi_543  lt.cs.sk_666 af.haw.fi_544 
  0x0f581307, 0x070430a4, 0x13065705, 0x0f007904,   // et.om.lv_432 uz.ru.bg_433  na.de.et_333 war.lv.un_320 
  0x1800282b, 0x033f510c, 0x303106a4, 0x4e2e0e08,   // sd.ar.un_980 kl.af.nl_543  de.az.uz_433 is.fo.ay_443 
  // [b980]
  0x7904510c, 0x24fe06a7, 0x2a000d1a, 0xfc005202,   // kl.fi.war_543 de.tlh.eo_532  cs.mt.un_760 ha.zzp.un_220 
  0x0d292da4, 0x1b2d0d04, 0x040c130c, 0x1003fca0,   // sk.sl.cs_433 cs.sk.tr_332  et.sv.fi_543 zzp.nl.lt_322 
  0x13000e11, 0x6b130ea4, 0x10271812, 0x15003c21,   // is.et.un_630 is.et.ceb_433  ga.gd.lt_654 ug.un.un_860 
  0x29013e05, 0x3f005102, 0x443723ac, 0x7679010c,   // rm.en.sl_333 kl.af.un_220  ky.ba.kk_632 en.war.crs_543 
  // [b990]
  0x32062202, 0x18211208, 0x1d631907, 0x284c47a4,   // oc.de.bs_222 ur.fa.ar_443  gl.sco.la_432 sn.wo.sw_433 
  0x0e033fa9, 0x5c091311, 0x76692da4, 0x13014602,   // af.nl.is_544 bh.hi.sa_653  sk.mfe.crs_433 qu.en.et_222 
  0x4c190a02, 0x034b04ee, 0x581304ec, 0x105f755a,   // pt.gl.wo_222 fi.mi.nl_422  fi.et.om_644 nso.tn.lt_553 
  0x6a004a22, 0x0d313005, 0x130407a4, 0x04475ea4,   // yo.haw.un_870 uz.az.cs_333  it.fi.et_433 ts.sn.fi_433 
  // [b9a0]
  0x47286a0c, 0x2a075804, 0x4e130107, 0x544604a4,   // haw.sw.sn_543 om.it.mt_332  en.et.ay_432 fi.qu.ik_433 
  0x402206ee, 0x1e003008, 0x513f54ad, 0x2c0302ee,   // de.oc.lb_422 uz.ms.un_430  ik.af.kl_643 da.nl.fy_422 
  0x29002a2b, 0x04321605, 0x36482355, 0x34123014,   // mt.sl.un_980 hr.bs.fi_333  ky.tt.ab_442 uz.ur.ps_666 
  0x070a170e, 0x15041512, 0x3c383012, 0x29004604,   // sr.mk.bg_555 un.ru.un_654  uz.tk.ug_654 qu.sl.un_320 
  // [b9b0]
  0x0a0717ec, 0x3b303107, 0x4c586560, 0x473b51af,   // sr.bg.mk_644 az.uz.so_432  gv.om.wo_664 kl.so.sn_655 
  0x102d1605, 0x382d3204, 0x384415ac, 0x0d001602,   // hr.sk.lt_333 bs.sk.tk_332  un.kk.tk_632 hr.cs.un_220 
  0x114d3ba4, 0x6700640e, 0x64004714, 0x153b58a7,   // so.aa.ro_433 lg.ak.un_550  sn.lg.un_660 om.so.un_532 
  0x16170f0c, 0x17000f08, 0x29006404, 0x070a3ca7,   // lv.sr.hr_543 lv.sr.un_430  lg.sl.un_320 ug.mk.bg_532 
  // [b9c0]
  0x130d1c0d, 0x290f1007, 0x3b006512, 0x070a480c,   // mr.ne.bh_554 lt.lv.sl_432  gv.so.un_640 tt.mk.bg_543 
  0x36001e0c, 0x4564520c, 0x13551205, 0x1d006008,   // ms.gn.un_530 ha.lg.ln_543  hu.rw.et_333 vo.la.un_430 
  0x21003813, 0x2f123708, 0x095e0212, 0x643630ad,   // tk.jw.un_650 st.hu.su_443  da.ts.pl_654 uz.gn.lg_643 
  0x024c52ad, 0x53645e0d, 0x22232a04, 0x2f524c0c,   // ha.wo.da_643 ts.lg.ht_554  mt.ca.oc_332 wo.ha.su_543 
  // [b9d0]
  0x0d00460b, 0x53302f04, 0xfc002102, 0x021e1c0c,   // qu.cs.un_520 su.uz.ht_332  jw.zzp.un_220 id.ms.da_543 
  0x40024f04, 0x040708af, 0x4c353404, 0x1700381a,   // bi.da.lb_332 uk.bg.ru_655  xh.zu.wo_332 tk.sr.un_760 
  0x1827650d, 0x1c2f26ee, 0x4f65390c, 0x0d00460d,   // gv.gd.ga_554 ia.su.id_422  br.gv.bi_543 qu.cs.un_540 
  0x5b65fe08, 0x030e2e55, 0x08000104, 0x04361504,   // tlh.gv.sg_443 fo.is.nl_442  en.no.un_320 un.ab.ru_332 
  // [b9e0]
  0x044530af, 0x053b5cac, 0x3e004f18, 0x3f3b57a4,   // uz.ln.fi_655 sa.so.fr_632  bi.rm.un_740 na.so.af_433 
  0x4d002721, 0x171011ee, 0x39796eec, 0x47003914,   // gd.aa.un_860 ro.be.sr_422  hmn.war.br_644 br.sn.un_660 
  0x1f001e08, 0x27183602, 0x24000c05, 0x64287313,   // ms.cy.un_430 gn.ga.gd_222  sv.eo.un_330 ny.sw.lg_665 
  0x311b200d, 0x04301504, 0x181f2712, 0x4200362a,   // sq.tr.az_554 un.uz.ru_332  gd.cy.ga_654 gn.co.un_970 
  // [b9f0]
  0x36190b04, 0x356428ec, 0x26241d13, 0x1d0a240c,   // es.gl.gn_332 sw.lg.zu_644  la.eo.ia_665 eo.pt.la_543 
  0x5573645a, 0x190b1dee, 0xfe002a2a, 0x06630112,   // lg.ny.rw_553 la.es.gl_422  mt.tlh.un_970 en.sco.de_654 
  0x406001a0, 0x3e5046af, 0x483b46a7, 0x3e1d2407,   // en.vo.lb_322 qu.fj.rm_655  qu.so.tt_532 eo.la.rm_432 
  0x275a1807, 0x1d392407, 0x55004711, 0x213412a9,   // ga.sm.gd_432 eo.br.la_432  sn.rw.un_630 ur.ps.fa_544 
  // [ba00]
  0x28005312, 0x34170a0d, 0x3f3b58a0, 0x51000607,   // ht.sw.un_640 mk.sr.ps_554  om.so.af_322 de.kl.un_420 
  0x13120609, 0x170a3604, 0x032d3ba0, 0x3d3021ad,   // de.hu.et_444 ab.mk.sr_332  so.sk.nl_322 fa.uz.ku_643 
  0x1e1c4caf, 0x380c3307, 0x0a002305, 0x34122105,   // wo.id.ms_655 nn.sv.tk_432  ca.pt.un_330 fa.ur.ps_333 
  0x13393ba0, 0x3b0c0ea6, 0x10001518, 0x19001211,   // so.br.et_322 is.sv.so_521  un.be.un_740 hu.gl.un_630 
  // [ba10]
  0x4d001214, 0x524cfeee, 0x45003408, 0x0b004904,   // hu.aa.un_660 tlh.wo.ha_422  xh.ln.un_430 to.es.un_320 
  0x122f230c, 0x1200280b, 0x070411ec, 0x33000607,   // ca.su.hu_543 sd.ur.un_520  ro.ru.bg_644 de.nn.un_420 
  0x074430a0, 0x0f020c07, 0x0f005007, 0x23521aa4,   // uz.kk.bg_322 sv.da.lv_432  fj.lv.un_420 tl.ha.ca_433 
  0x4658080c, 0x23303c12, 0x09075aa6, 0x05004207,   // no.om.qu_543 ug.uz.ky_654  sm.it.pl_521 co.fr.un_420 
  // [ba20]
  0x18121ba4, 0x64595505, 0x3534feaf, 0x19001004,   // tr.hu.ga_433 rw.rn.lg_333  tlh.xh.zu_655 lt.gl.un_320 
  0x1100361a, 0x5c5310ec, 0x1f131807, 0x5c2446a0,   // ab.ro.un_760 lt.ht.sa_644  ga.et.cy_432 qu.eo.sa_322 
  0x040a230c, 0x220f0b05, 0x27000a08, 0x39535c02,   // ky.mk.ru_543 es.lv.oc_333  pt.gd.un_430 sa.ht.br_222 
  0x585a5104, 0x24061d07, 0x18273ea0, 0x07222307,   // kl.sm.om_332 la.de.eo_432  rm.gd.ga_322 ca.oc.it_432 
  // [ba30]
  0x0b3e1da0, 0x44483cec, 0x212834ee, 0x0c331007,   // la.rm.es_322 ug.tt.kk_644  ps.sd.fa_422 lt.nn.sv_432 
  0x243e0aec, 0x1b375fad, 0x300425a0, 0x4000220d,   // pt.rm.eo_644 tn.st.tr_643  mn.ru.uz_322 oc.lb.un_540 
  0x211342ee, 0x26510807, 0x10003e07, 0x19001212,   // co.et.jw_422 no.kl.ia_432  rm.lt.un_420 hu.gl.un_640 
  0x5c3f10ee, 0x48004604, 0x23384813, 0x28123d08,   // lt.af.sa_422 qu.tt.un_320  tt.tk.ky_665 ku.ur.sd_443 
  // [ba40]
  0x1228180b, 0x5d19120c, 0x234815ac, 0x311b3b09,   // ar.sd.ur_542 hu.gl.ss_543  un.tt.ky_632 so.tr.az_444 
  0x1c01210c, 0x31483002, 0x080415a7, 0x0b19120b,   // jw.en.id_543 uz.tt.az_222  un.ru.uk_532 hu.gl.es_542 
  0x190b12ec, 0x2834440c, 0x19122d55, 0x213d180c,   // hu.es.gl_644 kk.ps.sd_543  sk.hu.gl_442 ar.ku.fa_543 
  0x0710080d, 0x1900120d, 0x56fc1dee, 0x21122807,   // uk.be.bg_554 hu.gl.un_540  la.zzp.mg_422 sd.ur.fa_432 
  // [ba50]
  0x2300101a, 0x5200fe04, 0x1a00fe04, 0x40062c13,   // be.ky.un_760 tlh.ha.un_320  tlh.tl.un_320 fy.de.lb_665 
  0x1f002c05, 0x30253c08, 0x0d2dfc08, 0x5c006021,   // fy.cy.un_330 ug.mn.uz_443  zzp.sk.cs_443 vo.sa.un_860 
  0x0400200c, 0x04001021, 0x205e600c, 0x391560ad,   // sq.fi.un_530 be.ru.un_860  vo.ts.sq_543 vo.br.un_630 
  0x04004b05, 0x20000404, 0x79002012, 0x135360a4,   // mi.fi.un_330 fi.sq.un_320  sq.war.un_640 vo.ht.et_433 
  // [ba60]
  0x12004d0e, 0x05003e04, 0x300435ee, 0x48233008,   // aa.hu.un_550 rm.fr.un_320  tg.ru.uz_422 uz.ky.tt_443 
  0x1129390d, 0x2e0204ee, 0x536efe0c, 0x696013a9,   // br.sl.ro_554 fi.da.fo_422  tlh.hmn.ht_543 et.vo.mfe_544 
  0x04302012, 0x790420a4, 0x0213390c, 0x0000692d,   // sq.uz.fi_654 sq.fi.war_433  br.et.da_543 mfe.un.un_A00 
  0x08060c02, 0x0d3e2da4, 0x23004420, 0x041302a7,   // sv.de.no_222 sk.rm.cs_433  kk.ky.un_850 da.et.fi_532 
  // [ba70]
  0x04103607, 0x5a02390c, 0x040811a4, 0x311a6b08,   // ab.be.ru_432 br.da.sm_543  ro.uk.ru_433 ceb.tl.az_443 
  0x481255ee, 0x13005719, 0x65003b07, 0x4a006812,   // rw.hu.tt_422 na.et.un_750  so.gv.un_420 ig.yo.un_640 
  0x4c004714, 0x230735a0, 0x65674a04, 0x15373ca4,   // sn.wo.un_660 tg.bg.ky_322  yo.ak.gv_332 ug.ba.un_433 
  0x47552555, 0x04171514, 0x3435390c, 0x1c135c13,   // eu.rw.sn_442 un.sr.ru_666  br.zu.xh_543 sa.bh.mr_665 
  // [ba80]
  0x0e270607, 0x16290d07, 0x18fc0102, 0x4b5a30ad,   // de.gd.is_432 cs.sl.hr_432  en.zzp.ga_222 uz.sm.mi_643 
  0x44233c0e, 0x50003009, 0x18233c12, 0x651655a4,   // ug.ky.kk_555 uz.fj.un_440  ug.ky.ar_654 rw.hr.gv_433 
  0x4b005618, 0x026563a4, 0x4b4956a7, 0x35341d04,   // mg.mi.un_740 sco.gv.da_433  mg.to.mi_532 la.xh.zu_332 
  0x305a4904, 0xfe576307, 0x492c4b0c, 0x08110a05,   // to.sm.uz_332 sco.na.tlh_432  mi.fy.to_543 mk.ro.uk_333 
  // [ba90]
  0x22796304, 0x09133b02, 0x3f0c330c, 0x04293b08,   // sco.war.oc_332 so.et.pl_222  nn.sv.af_543 so.sl.fi_443 
  0x0c332107, 0x02002d04, 0x33003f0c, 0x11002c04,   // jw.nn.sv_432 sk.da.un_320  af.nn.un_530 fy.ro.un_320 
  0x0c3f0e05, 0x50005613, 0x56495aa4, 0x3f1e1c04,   // is.af.sv_333 mg.fj.un_650  sm.to.mg_433 id.ms.af_332 
  0x11003004, 0x48fe31ad, 0x39fc120c, 0x11494b55,   // uz.ro.un_320 az.tlh.tt_643  hu.zzp.br_543 mi.to.ro_442 
  // [baa0]
  0x12000f12, 0x2a004602, 0x0c3f330b, 0x390410a7,   // lv.hu.un_640 qu.mt.un_220  nn.af.sv_542 lt.fi.br_532 
  0x6500fe0c, 0xfc320cee, 0x070a1007, 0x30353ca4,   // tlh.gv.un_530 sv.bs.zzp_422  be.mk.bg_432 ug.tg.uz_433 
  0x013f1da4, 0x12002302, 0x24fc0f07, 0x2c400609,   // la.af.en_433 ky.ur.un_220  lv.zzp.eo_432 de.lb.fy_444 
  0x19000a08, 0xfe0c5502, 0x651c1eee, 0x3302fca4,   // pt.gl.un_430 rw.sv.tlh_222  ms.id.gv_422 zzp.da.nn_433 
  // [bab0]
  0x3e600107, 0x100a3e08, 0x24100f12, 0x254c60a4,   // en.vo.rm_432 rm.pt.lt_443  lv.lt.eo_654 vo.wo.eu_433 
  0x22000f04, 0x1b00460d, 0x240afca0, 0x40003f02,   // lv.oc.un_320 qu.tr.un_540  zzp.pt.eo_322 af.lb.un_220 
  0x0b00fc07, 0x1234210b, 0x040c1312, 0x22103e04,   // zzp.es.un_420 fa.ps.ur_542  et.sv.fi_654 rm.lt.oc_332 
  0x46002a18, 0x260a3e09, 0x0a002a02, 0x34442305,   // mt.qu.un_740 rm.pt.ia_444  mt.pt.un_220 ky.kk.ps_333 
  // [bac0]
  0x33001507, 0x30150409, 0x3c353004, 0x4805390c,   // un.nn.un_420 ru.uz.un_440  uz.tg.ug_332 br.fr.tt_543 
  0x053963a0, 0x070a1555, 0x0d003907, 0x1500090d,   // sco.br.fr_322 un.mk.bg_442  br.cs.un_420 pl.un.un_540 
  0x5c090d02, 0x3b001813, 0x58473b05, 0x37361508,   // ne.hi.sa_222 ar.ks.un_650  so.sn.om_333 un.ab.ba_443 
  0x05002519, 0x250539a4, 0x043c17a9, 0x1100050c,   // eu.fr.un_750 br.fr.eu_433  sr.ug.ru_544 fr.ro.un_530 
  // [bad0]
  0x3b47580d, 0x483c23ad, 0x21005807, 0x17153504,   // om.sn.so_554 ky.ug.tt_643  om.jw.un_420 tg.sr.un_320 
  0x04170809, 0x04006a0e, 0x563b5aa6, 0x303515af,   // uk.sr.ru_444 haw.fi.un_550  sm.so.mg_521 un.tg.uz_655 
  0x1e315611, 0x21002404, 0x20340402, 0x735249a9,   // mg.az.ms_653 eo.jw.un_320  fi.xh.sq_222 to.ha.ny_544 
  0x130e280d, 0x2f001308, 0x7355310c, 0x313830a7,   // sw.is.et_554 et.su.un_430  az.rw.ny_543 uz.tk.az_532 
  // [bae0]
  0x30234808, 0x52495a0c, 0x1b48540c, 0x35345aa6,   // tt.ky.uz_443 sm.to.ha_543  ik.tt.tr_543 sm.xh.zu_521 
  0x100408a0, 0x15002d04, 0x15200207, 0x0b0a19a9,   // uk.ru.be_322 sk.un.un_320  da.sq.un_432 gl.pt.es_544 
  0x555d3508, 0x4300fe0e, 0x1b3143a0, 0x73125612,   // zu.ss.rw_443 tlh.ie.un_550  ie.az.tr_322 mg.hu.ny_654 
  0x15153608, 0x233530a4, 0x47003119, 0x526428ee,   // ab.un.un_430 uz.tg.ky_433  az.sn.un_750 sw.lg.ha_422 
  // [baf0]
  0x3d342114, 0x56284d0c, 0x561b28a4, 0x24005305,   // fa.ps.ku_666 aa.sw.mg_543  sw.tr.mg_433 ht.eo.un_330 
  0x18302104, 0x080704af, 0x555d34a0, 0x46000f05,   // fa.uz.ar_332 ru.bg.uk_655  xh.ss.rw_322 lv.qu.un_330 
  0x00001837, 0x583b650e, 0x08043704, 0x3b6558ad,   // ar.un.un_B00 gv.so.om_555  ba.ru.uk_332 om.gv.so_643 
  0x40002802, 0x65005c04, 0x360b46ee, 0x023b65ee,   // sw.lb.un_220 sa.gv.un_320  qu.es.gn_422 gv.so.da_422 
  // [bb00]
  0x102e0ead, 0x346564a9, 0x1724080c, 0x64005814,   // is.fo.lt_643 lg.gv.xh_544  no.eo.sr_543 om.lg.un_660 
  0x02390302, 0x64003b18, 0x10000302, 0x345864a4,   // nl.br.da_222 so.lg.un_740  nl.lt.un_220 lg.om.xh_433 
  0x345864ad, 0x485b3008, 0x1511360c, 0x343d215a,   // lg.om.xh_643 uz.sg.tt_443  ab.ro.un_543 fa.ku.ps_553 
  0x29004807, 0x4c0234a0, 0x3e240ca0, 0x53004708,   // tt.sl.un_420 xh.da.wo_322  sv.eo.rm_322 sn.ht.un_430 
  // [bb10]
  0x4d643bec, 0x34003b11, 0x12213402, 0x12183c07,   // so.lg.aa_644 ks.ps.un_630  ps.fa.ur_222 ug.ar.ur_432 
  0x21fc1f55, 0x37483512, 0x1f002c04, 0x56002c04,   // cy.zzp.jw_442 tg.tt.ba_654  fy.cy.un_320 fy.mg.un_320 
  0x202f3007, 0x69595caf, 0x1e06fe0c, 0x13001204,   // uz.su.sq_432 sa.rn.mfe_655  tlh.de.ms_543 hu.et.un_320 
  0x205c0604, 0x1d001e08, 0xfc476408, 0x73004708,   // de.sa.sq_332 ms.la.un_430  lg.sn.zzp_443 sn.ny.un_430 
  // [bb20]
  0x353473a6, 0x111008ec, 0x64001a13, 0x56002004,   // ny.xh.zu_521 uk.be.ro_644  tl.lg.un_650 sq.mg.un_320 
  0x53007629, 0x06302055, 0x190d20a0, 0x082e0ea7,   // crs.ht.un_960 sq.uz.de_442  sq.cs.gl_322 is.fo.no_532 
  0x053b15a6, 0x5c4c53a4, 0x3b584c12, 0x343d28ec,   // un.so.fr_521 ht.wo.sa_433  wo.om.so_654 sd.ku.ps_644 
  0x202913a4, 0x1d000102, 0x4c005822, 0x645f4708,   // et.sl.sq_433 en.la.un_220  om.wo.un_870 sn.tn.lg_443 
  // [bb30]
  0x06033f04, 0x283c12ee, 0x112652ad, 0x3e005302,   // af.nl.de_332 ur.ug.sd_422  ha.ia.ro_643 ht.rm.un_220 
  0x35111507, 0x205146ee, 0x6500630d, 0x422225a0,   // un.ro.tg_432 qu.kl.sq_422  sco.gv.un_540 eu.oc.co_322 
  0x22392360, 0x1f003014, 0x1b1e0ea0, 0x0640fca0,   // ca.br.oc_664 uz.cy.un_660  is.ms.tr_322 zzp.lb.de_322 
  0x0c005c04, 0x36110a05, 0x0e005307, 0x2622010c,   // sa.sv.un_320 mk.ro.ab_333  ht.is.un_420 en.oc.ia_543 
  // [bb40]
  0x08003013, 0x240379a0, 0x52001804, 0x0203fea0,   // uz.uk.un_650 war.nl.eo_322  ga.ha.un_320 tlh.nl.da_322 
  0x3b000202, 0x4c583b08, 0x04005807, 0x070a1104,   // da.so.un_220 so.om.wo_443  om.fi.un_420 ro.mk.bg_332 
  0x6100690e, 0x4d4e46a4, 0x0d1f630c, 0x2916fe0c,   // mfe.za.un_550 qu.ay.aa_433  sco.cy.cs_543 tlh.hr.sl_543 
  0x2bfc0307, 0x09004608, 0x38005c08, 0x30002a0e,   // nl.zzp.vi_432 qu.pl.un_430  sa.tk.un_430 mt.uz.un_550 
  // [bb50]
  0x35000602, 0x51464207, 0x46003112, 0x16204ea6,   // de.zu.un_220 co.qu.kl_432  az.qu.un_640 ay.sq.hr_521 
  0x5c000c04, 0x1c001704, 0x644d63ad, 0x30233811,   // sv.sa.un_320 sr.id.un_320  sco.aa.lg_643 tk.ky.uz_653 
  0x30483cad, 0x686b0107, 0x4a001513, 0x2500050c,   // ug.tt.uz_643 en.ceb.ig_432  un.yo.un_650 fr.eu.un_530 
  0x3500100c, 0x2b102fa0, 0x29262a0e, 0x05002507,   // be.tg.un_530 su.lt.vi_322  mt.ia.sl_555 eu.fr.un_420 
  // [bb60]
  0x233711a0, 0x35002502, 0x10001704, 0x44003807,   // ro.ba.ky_322 eu.zu.un_220  sr.be.un_320 tk.kk.un_420 
  0x030902a0, 0x25003008, 0x1e1c0308, 0x213418a9,   // da.pl.nl_322 uz.mn.un_430  nl.id.ms_443 ar.ps.fa_544 
  0x4a004508, 0x3c2123ee, 0x21003807, 0x391f38ac,   // ln.yo.un_430 ky.fa.ug_422  tk.jw.un_420 tk.cy.br_632 
  0x130c4ca0, 0x3735440c, 0x1834440c, 0x21341808,   // wo.sv.et_322 kk.tg.ba_543  kk.ps.ar_543 ar.ps.fa_443 
  // [bb70]
  0x06232402, 0x28580408, 0x2000240e, 0x153048ad,   // eo.ca.de_222 fi.om.sw_443  eo.sq.un_550 tt.uz.un_643 
  0x04002012, 0x39002404, 0x44234808, 0x363748a4,   // sq.fi.un_640 eo.br.un_320  tt.ky.kk_443 tt.ba.ab_433 
  0x100f2408, 0x22263eaf, 0x2300070c, 0x3f004612,   // eo.lv.lt_443 rm.ia.oc_655  bg.ky.un_530 qu.af.un_640 
  0x44233ba9, 0x46002404, 0x0246530c, 0x04171104,   // ks.ky.kk_544 eo.qu.un_320  ht.qu.da_543 ro.sr.ru_332 
  // [bb80]
  0x39000b04, 0x0f003604, 0x041508a6, 0x095c13ac,   // es.br.un_320 gn.lv.un_320  uk.ru.un_510 bh.sa.hi_632 
  0x20102408, 0x24000f12, 0x2d3905a0, 0x0500390d,   // eo.lt.sq_443 lv.eo.un_640  fr.br.sk_322 br.fr.un_540 
  0x3100030d, 0x30353cee, 0x28002f05, 0x21002d04,   // nl.az.un_540 ug.tg.uz_422  su.sw.un_330 sk.jw.un_320 
  0x28002f02, 0x04000302, 0x18261fa4, 0x766946a4,   // su.sw.un_220 nl.fi.un_220  cy.ia.ga_433 qu.mfe.crs_433 
  // [bb90]
  0x3e0c08a4, 0xfc005e04, 0x2f001502, 0x21511f09,   // no.sv.rm_433 ts.zzp.un_320  un.su.un_220 cy.kl.jw_444 
  0x15000511, 0x053925af, 0x01001505, 0x34181211,   // fr.un.un_630 eu.br.fr_655  un.en.un_330 ur.ar.ps_653 
  0x3e00090e, 0xfc2601a4, 0x63030604, 0x2d2c2902,   // pl.rm.un_550 en.ia.zzp_433  de.nl.sco_332 sl.fy.sk_222 
  0x6700fc13, 0x13004202, 0x07423007, 0x300d3fee,   // zzp.ak.un_650 co.et.un_220  uz.co.it_432 af.cs.uz_422 
  // [bba0]
  0x124a0d07, 0x03233f02, 0x17003c04, 0x03003f20,   // cs.yo.hu_432 af.ca.nl_222  ug.sr.un_320 af.nl.un_850 
  0x393e0708, 0x2f001508, 0x20005e0d, 0x303125a0,   // it.rm.br_443 un.su.un_430  ts.sq.un_540 eu.az.uz_322 
  0x301c1e0c, 0x1026070c, 0x13002007, 0x00005d2d,   // ms.id.uz_543 it.ia.lt_543  sq.et.un_420 ss.un.un_A00 
  0x10385da9, 0x51002d08, 0x271d63ac, 0x255d2cec,   // ss.tk.lt_544 sk.kl.un_430  sco.la.gd_632 fy.ss.eu_644 
  // [bbb0]
  0x48000304, 0x44041112, 0x17003818, 0x1357fc08,   // nl.tt.un_320 ro.ru.kk_654  tk.sr.un_740 zzp.na.et_443 
  0x2f1b38a9, 0x5c0e6ba4, 0x30315d09, 0x150a0807,   // tk.tr.su_544 ceb.is.sa_433  ss.az.uz_444 uk.mk.un_432 
  0x10003504, 0x5d1e1c0c, 0x1d2305a9, 0x06201ea0,   // tg.be.un_320 id.ms.ss_543  fr.ca.la_544 ms.sq.de_322 
  0x20605608, 0x4f005d21, 0x08360405, 0x1e565d0c,   // mg.vo.sq_443 ss.bi.un_860  ru.ab.uk_333 ss.mg.ms_543 
  // [bbc0]
  0x3c00382a, 0x04100855, 0x283d2102, 0x79000613,   // tk.ug.un_970 uk.be.ru_442  fa.ku.sd_222 de.war.un_650 
  0x03000313, 0x063e3fa0, 0x22002311, 0x134a7311,   // nl.nl.un_650 af.rm.de_322  ca.oc.un_630 ny.yo.et_653 
  0x49002e0c, 0x08001713, 0x35002314, 0x43730107,   // fo.to.un_530 sr.uk.un_650  ky.tg.un_660 en.ny.ie_432 
  0x28123408, 0x33083905, 0x3c184407, 0x0c0e2e04,   // ps.ur.sd_443 br.no.nn_333  kk.ar.ug_432 fo.is.sv_332 
  // [bbd0]
  0x3b4a4da7, 0x0c3b08a0, 0x636501a0, 0x5c00730e,   // aa.yo.so_532 no.so.sv_322  en.gv.sco_322 ny.sa.un_550 
  0x3f004021, 0x044836ee, 0x28183405, 0x03003f23,   // lb.af.un_860 ab.tt.ru_422  ps.ar.sd_333 af.nl.un_880 
  0x58004c0c, 0x102d0d07, 0x51534cad, 0x1004080c,   // wo.om.un_530 cs.sk.lt_432  wo.ht.kl_643 uk.ru.be_543 
  0x4c006309, 0x30150412, 0x0d000b04, 0x63004c0d,   // sco.wo.un_440 ru.uz.un_640  es.cs.un_320 wo.sco.un_540 
  // [bbe0]
  0x03004d23, 0x360a17a4, 0x4a006408, 0x2f004d11,   // aa.nl.un_880 sr.mk.ab_433  lg.yo.un_430 aa.su.un_630 
  0x311b1cec, 0x2f511307, 0x2d00750c, 0x4300620e,   // id.tr.az_644 et.kl.su_432  nso.sk.un_530 kha.ie.un_550 
  0x382325a4, 0x28465204, 0x46524e08, 0x0b000c02,   // mn.ky.tk_433 ha.qu.sw_332  ay.ha.qu_443 sv.es.un_220 
  0x4000460c, 0x1200340d, 0x6b461a0d, 0x46006e07,   // qu.lb.un_530 ps.ur.un_540  tl.qu.ceb_554 hmn.qu.un_420 
  // [bbf0]
  0x15005207, 0x23000707, 0x073c48a4, 0x52006e07,   // ha.un.un_420 bg.ky.un_420  tt.ug.bg_433 hmn.ha.un_420 
  0xfc004604, 0x4d004613, 0x070a3805, 0x0f17290b,   // qu.zzp.un_320 qu.aa.un_650  tk.mk.bg_333 sl.sr.lv_542 
  0x2a4e52af, 0x1f4e1ca4, 0x0d0f1055, 0x6b52090c,   // ha.ay.mt_655 id.ay.cy_433  lt.lv.cs_442 pl.ha.ceb_543 
  0x2ffc21ee, 0x3c443713, 0x4800460e, 0x122818a0,   // jw.zzp.su_422 ba.kk.ug_665  qu.tt.un_550 ar.sd.ur_322 
  
  // [bc00]
  0x44040804, 0x231530af, 0x110561ad, 0x55357305,   // uk.ru.kk_332 uz.ky.un_650  za.fr.ro_643 ny.zu.rw_333 
  0x163217ad, 0x343d21af, 0x13252d05, 0x36001219,   // sr.bs.hr_643 fa.ku.ps_655  sk.eu.et_333 hu.gn.un_750 
  0x37483ca7, 0x2d0f1707, 0x64004907, 0x25005512,   // ug.tt.ba_532 sr.lv.sk_432  to.lg.un_420 rw.eu.un_640 
  0x30234413, 0x2d0e120e, 0x5d552104, 0x31004604,   // kk.ky.uz_665 hu.is.sk_555  jw.rw.ss_332 qu.az.un_320 
  // [bc10]
  0x34183da9, 0x25025e55, 0x35346402, 0x05394807,   // ku.ar.ps_544 ts.da.eu_442  lg.xh.zu_222 tt.br.fr_432 
  0x210213ad, 0xfc003f05, 0x5d3502ad, 0x68494b11,   // et.da.jw_643 af.zzp.un_330  da.zu.ss_643 mi.to.ig_653 
  0x59345cad, 0x1f005308, 0x234436a0, 0x032c1f07,   // sa.xh.rn_643 ht.cy.un_430  ab.kk.ky_322 cy.fy.nl_432 
  0x33082e09, 0x645c5507, 0x04002019, 0x311b5807,   // fo.no.nn_444 rw.sa.lg_432  sq.fi.un_750 om.tr.az_432 
  // [bc20]
  0x0f2410ad, 0x4538fca4, 0x0f00750d, 0x09240f0c,   // lt.eo.lv_643 zzp.tk.ln_433  nso.lv.un_540 lv.eo.pl_543 
  0x2000240c, 0x30005c02, 0x1704070d, 0x19001805,   // eo.sq.un_530 sa.uz.un_220  bg.ru.sr_554 ga.gl.un_330 
  0x21003022, 0x0e2e0c13, 0x10fe24a0, 0x22606a0c,   // uz.fa.un_870 sv.fo.is_665  eo.tlh.lt_322 haw.vo.oc_543 
  0x16002919, 0x6b00381b, 0x7300471a, 0x2700390d,   // sl.hr.un_750 tk.ceb.un_770  sn.ny.un_760 br.gd.un_540 
  // [bc30]
  0x5f1b28ec, 0x37044802, 0x27121a07, 0x221a12ec,   // sw.tr.tn_644 tt.ru.ba_222  tl.hu.gd_432 hu.tl.oc_644 
  0x0b006004, 0x465451af, 0x0f001602, 0x79470107,   // vo.es.un_320 kl.ik.qu_655  hr.lv.un_220 en.sn.war_432 
  0x28000502, 0x292d100b, 0x30001602, 0x35005d35,   // fr.sw.un_220 lt.sk.sl_542  hr.uz.un_220 ss.zu.un_A90 
  0x08170409, 0x3d00211b, 0x12005c08, 0x125c58ec,   // ru.sr.uk_444 fa.ku.un_770  sa.hu.un_430 om.sa.hu_644 
  // [bc40]
  0x303815a4, 0x12796b12, 0x100804ee, 0x5d5c475a,   // un.tk.uz_433 ceb.war.hu_654  ru.uk.be_422 sn.sa.ss_553 
  0x3e474ea9, 0x0c002b04, 0x36730204, 0x321716ac,   // ay.sn.rm_544 vi.sv.un_320  da.ny.gn_332 hr.sr.bs_632 
  0x3900121b, 0x48fe46a0, 0x0f002902, 0xfc004b19,   // hu.br.un_770 qu.tlh.tt_322  sl.lv.un_220 mi.zzp.un_750 
  0x0f000d04, 0x40003b05, 0x463151a9, 0x49630107,   // cs.lv.un_320 so.lb.un_330  kl.az.qu_544 en.sco.to_432 
  // [bc50]
  0x02002c0e, 0x44001513, 0x35004e21, 0x5a5f4904,   // fy.da.un_550 un.kk.un_650  ay.zu.un_860 to.tn.sm_332 
  0x27021805, 0x0d001704, 0x2d0d32a0, 0x11100f08,   // ga.da.gd_333 sr.cs.un_320  bs.cs.sk_322 lv.lt.ro_443 
  0x17001018, 0x37482312, 0x3008350b, 0x27111812,   // lt.sr.un_740 ky.tt.ba_654  tg.uk.uz_542 ga.ro.gd_654 
  0x16004708, 0x1900600c, 0x2135340e, 0x0700290c,   // sn.hr.un_430 vo.gl.un_530  xh.zu.jw_555 sl.it.un_530 
  // [bc60]
  0xfc403909, 0x47003404, 0x234438ac, 0x32172911,   // br.lb.zzp_444 xh.sn.un_320  tk.kk.ky_632 sl.sr.bs_653 
  0x4b001308, 0x0d0f75ec, 0x2d001705, 0x3e495a04,   // et.mi.un_430 nso.lv.cs_644  sr.sk.un_330 sm.to.rm_332 
  0x634f01af, 0x6b11fe04, 0x32172d0c, 0x06002e14,   // en.bi.sco_655 tlh.ro.ceb_332  sk.sr.bs_543 fo.de.un_660 
  0x15001513, 0x04150707, 0x2f561e02, 0xfc303ba4,   // un.un.un_650 bg.ru.un_420  ms.mg.su_222 so.uz.zzp_433 
  // [bc70]
  0x15000a13, 0x24fc1104, 0x2e303b09, 0x52005f0e,   // mk.un.un_650 ro.zzp.eo_332  so.uz.fo_444 tn.ha.un_550 
  0x160f75ad, 0x4b005005, 0x2d0d2855, 0x1d001804,   // nso.lv.hr_643 fj.mi.un_330  sw.cs.sk_442 ga.la.un_320 
  0x08384412, 0x15170704, 0x12fe04a4, 0x21123b0d,   // kk.tk.uk_654 bg.sr.un_332  fi.tlh.hu_433 ks.ur.fa_554 
  0x2d001708, 0x136e5813, 0x640d42a4, 0x0e000605,   // sr.sk.un_430 om.hmn.et_665  co.cs.lg_433 de.is.un_330 
  // [bc80]
  0x1b1e4a55, 0x2a003405, 0x1c095cec, 0x30150709,   // yo.ms.tr_442 xh.mt.un_330  sa.hi.mr_644 bg.uz.un_440 
  0x2b003404, 0x2e330202, 0x1c002404, 0x5e004e08,   // xh.vi.un_320 da.nn.fo_222  eo.id.un_320 ay.ts.un_430 
  0x32463007, 0x34004008, 0x29001307, 0x2118305a,   // uz.qu.bs_432 lb.xh.un_430  et.sl.un_420 uz.ar.fa_553 
  0x3b00130c, 0x2a65480c, 0x3c00372a, 0xfc001e04,   // et.so.un_530 tt.gv.mt_543  ba.ug.un_970 ms.zzp.un_320 
  // [bc90]
  0x3b4dfc0c, 0x5a001f0c, 0x0a1738ee, 0x0d0f2da0,   // zzp.aa.so_543 cy.sm.un_530  tk.sr.mk_422 sk.lv.cs_322 
  0x063f1b0c, 0xfa5434ec, 0x034a5804, 0x4a001209,   // tr.af.de_543 xh.ik.nr_644  om.yo.nl_332 hu.yo.un_440 
  0x73242805, 0x4c252e08, 0x3b584d13, 0x1f026ea0,   // sw.eo.ny_333 fo.eu.wo_443  aa.om.so_665 hmn.da.cy_322 
  0x10003623, 0x2f2e2102, 0x15644c0b, 0x46004e07,   // gn.lt.un_880 jw.fo.su_222  wo.lg.un_542 ay.qu.un_420 
  // [bca0]
  0x15001d05, 0x51005412, 0x164c4eee, 0x4c1b480c,   // la.un.un_330 ik.kl.un_640  ay.wo.hr_422 tt.tr.wo_543 
  0x253515ee, 0x36564705, 0x09130d11, 0x792846ee,   // un.tg.mn_422 sn.mg.gn_333  ne.bh.hi_653 qu.sw.war_422 
  0x17000c07, 0x4600520d, 0x300748a0, 0x734578a4,   // sv.sr.un_420 ha.qu.un_540  tt.bg.uz_322 ve.ln.ny_433 
  0x091f3fa9, 0x42005109, 0x5c65fe55, 0x171537ad,   // af.cy.pl_544 kl.co.un_440  tlh.gv.sa_442 ba.sr.un_630 
  // [bcb0]
  0x4e4c200c, 0x25004c08, 0x19460b04, 0x1a311bee,   // sq.wo.ay_543 wo.eu.un_430  es.qu.gl_332 tr.az.tl_422 
  0x041c1305, 0x054243a4, 0x36000209, 0x4d596e07,   // et.id.fi_333 ie.co.fr_433  da.gn.un_440 hmn.rn.aa_432 
  0x1c251e0c, 0x1d001a0e, 0x4e250fac, 0x2d0d13ee,   // ms.eu.id_543 tl.la.un_550  lv.eu.ay_632 et.cs.sk_422 
  0x095c1308, 0x12484ea6, 0x1c1ffeac, 0x0cfc1d08,   // bh.sa.hi_443 ay.tt.hu_521  tlh.cy.id_632 la.zzp.sv_443 
  // [bcc0]
  0x4a002102, 0x4b006405, 0x47551ba0, 0x00001a24,   // jw.yo.un_220 lg.mi.un_330  tr.rw.sn_322 tl.un.un_900 
  0x30464ea4, 0x23001a04, 0x465448a4, 0x1f630107,   // ay.qu.uz_433 tl.ca.un_320  tt.ik.qu_433 en.sco.cy_432 
  0x45003f13, 0x3b001a04, 0xfc2a1fa0, 0x482310af,   // af.ln.un_650 tl.so.un_320  cy.mt.zzp_322 be.ky.tt_655 
  0x09002913, 0x3800460c, 0x1f000904, 0x09004709,   // sl.pl.un_650 qu.tk.un_530  pl.cy.un_320 sn.pl.un_440 
  // [bcd0]
  0x344e1308, 0x460f6005, 0x58005202, 0x35110aa4,   // et.ay.xh_443 vo.lv.qu_333  ha.om.un_220 mk.ro.tg_433 
  0x2a004608, 0x5c00461a, 0x38464e08, 0x2f004004,   // qu.mt.un_430 qu.sa.un_760  ay.qu.tk_443 lb.su.un_320 
  0x174e3208, 0x06405707, 0x33130802, 0x35443002,   // bs.ay.sr_443 na.lb.de_432  no.et.nn_222 uz.kk.tg_222 
  0x1b005602, 0x4000650b, 0x46791a0b, 0x35003c2a,   // mg.tr.un_220 gv.lb.un_520  tl.war.qu_542 ug.tg.un_970 
  // [bce0]
  0x25153c0e, 0x121830a6, 0x460f3607, 0x40000f07,   // ug.mn.un_550 uz.ar.ur_521  gn.lv.qu_432 lv.lb.un_420 
  0x28183d07, 0x292d12a0, 0x4700361b, 0x5c4e4611,   // ku.ar.sd_432 hu.sk.sl_322  gn.sn.un_770 qu.ay.sa_653 
  0x4a000d08, 0x1c4e460c, 0x60464ea4, 0x18465c08,   // cs.yo.un_430 qu.ay.id_543  ay.qu.vo_433 sa.qu.ga_443 
  0x2c000204, 0x3e004319, 0x0e5c46ee, 0x464e3414,   // da.fy.un_320 ie.rm.un_750  qu.sa.is_422 xh.ay.qu_666 
  // [bcf0]
  0x47003607, 0x06034002, 0x3008170c, 0x16000804,   // gn.sn.un_420 lb.nl.de_222  sr.uk.uz_543 no.hr.un_320 
  0x07006716, 0x4800372b, 0x05003905, 0x15482312,   // ak.it.un_720 ba.tt.un_980  br.fr.un_330 ky.tt.un_654 
  0x04101507, 0x0e182e0d, 0x65284c0c, 0x1c004d08,   // un.be.ru_432 fo.ga.is_554  wo.sw.gv_543 aa.id.un_430 
  0x55024704, 0x35000104, 0x12001a05, 0x0f2213ec,   // sn.da.rw_332 en.zu.un_320  tl.hu.un_330 et.oc.lv_644 
  // [bd00]
  0x4d584c13, 0x16130d07, 0x63130107, 0x2c6913a7,   // wo.om.aa_665 cs.et.hr_432  en.et.sco_432 et.mfe.fy_532 
  0x6b1f1dec, 0x13001d07, 0x070a36a0, 0x0c1301a4,   // la.cy.ceb_644 la.et.un_420  ab.mk.bg_322 en.et.sv_433 
  0x04170705, 0x30363cee, 0x621a2d07, 0x231511ec,   // bg.sr.ru_333 ug.ab.uz_422  sk.tl.kha_432 ro.ky.un_640 
  0x6379010b, 0x01131d0d, 0x34182811, 0x023b3f0d,   // en.war.sco_542 la.et.en_554  sd.ar.ps_653 af.so.da_554 
  // [bd10]
  0x2a001804, 0x5c091cec, 0x0400110e, 0x17083555,   // ga.mt.un_320 mr.hi.sa_644  ro.ru.un_550 tg.uk.sr_442 
  0x0e2e2413, 0x07100a0c, 0x0a3035af, 0x15043708,   // eo.fo.is_665 mk.be.bg_543  tg.uz.mk_655 ba.ru.un_443 
  0x2059555a, 0x39336304, 0x092d0fee, 0x12003113,   // rw.rn.sq_553 sco.nn.br_332  lv.sk.pl_422 az.hu.un_650 
  0x302315ec, 0x3f002005, 0x18281211, 0x405d06a7,   // un.ky.uz_644 sq.af.un_330  ur.sd.ar_653 de.ss.lb_532 
  // [bd20]
  0x18fc5604, 0x56365304, 0x06005b0e, 0x34003202,   // mg.zzp.ga_332 ht.gn.mg_332  sg.de.un_550 bs.xh.un_220 
  0x37483c04, 0x152a0d04, 0x0f2012ad, 0x3f3403a0,   // ug.tt.ba_332 cs.mt.un_332  hu.sq.lv_643 nl.xh.af_322 
  0x1b4f01a4, 0x320f120c, 0x48303907, 0x4afc15a0,   // en.bi.tr_433 hu.lv.bs_543  br.uz.tt_432 un.zzp.yo_322 
  0x78006e12, 0x39002522, 0x35472813, 0x1f001302,   // hmn.ve.un_640 eu.br.un_870  sw.sn.zu_665 et.cy.un_220 
  // [bd30]
  0x0a735607, 0x3bfc12a0, 0x2000fc07, 0x083011ee,   // mg.ny.pt_432 hu.zzp.so_322  zzp.sq.un_420 ro.uz.uk_422 
  0x44383709, 0x2a301702, 0x4500130e, 0x20002405,   // ba.tk.kk_444 sr.uz.mt_222  et.ln.un_550 eo.sq.un_330 
  0x10040f0c, 0x042d0d05, 0x34302155, 0x0f000805,   // lv.fi.lt_543 cs.sk.fi_333  fa.uz.ps_442 no.lv.un_330 
  0x2300080e, 0x460d24a9, 0x0000082d, 0x44303513,   // uk.ky.un_550 eo.cs.qu_544  uk.un.un_A00 tg.uz.kk_665 
  // [bd40]
  0x29002407, 0x0e0d1209, 0x354658a7, 0x303c44ec,   // eo.sl.un_420 hu.cs.is_444  om.qu.zu_532 kk.ug.uz_644 
  0x624d1fa4, 0x2f00690c, 0x59397907, 0x796b1aa9,   // cy.aa.kha_433 mfe.su.un_530  war.br.rn_432 tl.ceb.war_544 
  0x0f00340d, 0xfe6a1da4, 0x2f286a0c, 0x10002408,   // xh.lv.un_540 la.haw.tlh_433  haw.sw.su_543 eo.lt.un_430 
  0x123418a4, 0x2879fead, 0x10290fee, 0x67732808,   // ar.ps.ur_433 tlh.war.sw_643  lv.sl.lt_422 sw.ny.ak_443 
  // [bd50]
  0x455b370c, 0x647328a7, 0x51674a0c, 0x464a2807,   // st.sg.ln_543 sw.ny.lg_532  yo.ak.kl_543 sw.yo.qu_432 
  0x4b116a0c, 0x651f46ee, 0x19fe45a7, 0x734e6a07,   // haw.ro.mi_543 qu.cy.gv_422  ln.tlh.gl_532 haw.ay.ny_432 
  0x1c0f2f08, 0x5f2f1c0c, 0x48303c0d, 0x56004a12,   // su.lv.id_443 id.su.tn_543  ug.uz.tt_554 yo.mg.un_640 
  0x35361507, 0x07100aa4, 0x283418a7, 0x34fe4a12,   // un.ab.tg_432 mk.be.bg_433  ar.ps.sd_532 yo.tlh.xh_654 
  // [bd60]
  0x29132a09, 0x36000705, 0x12211808, 0x041342ec,   // mt.et.sl_444 it.gn.un_330  ar.fa.ur_443 co.et.fi_644 
  0x09000c0d, 0x322a0e07, 0x46054ea9, 0x1b00200c,   // sv.pl.un_540 is.mt.bs_432  ay.fr.qu_544 sq.tr.un_530 
  0x30005823, 0x472845a4, 0x58003b2b, 0x0f4a460c,   // om.uz.un_880 ln.sw.sn_433  so.om.un_980 qu.yo.lv_543 
  0x132f2a07, 0x04071502, 0x1b002302, 0x285cfe0d,   // mt.su.et_432 un.bg.ru_222  ca.tr.un_220 tlh.sa.sw_554 
  // [bd70]
  0x2a00fe0e, 0x2a002007, 0x73474e08, 0x53004704,   // tlh.mt.un_550 sq.mt.un_420  ay.sn.ny_443 sn.ht.un_320 
  0x1115100c, 0x303823ad, 0x3e2836a0, 0x2c001f02,   // be.ro.un_530 ky.tk.uz_643  gn.sw.rm_322 cy.fy.un_220 
  0x48101704, 0x4d003b2b, 0x37004609, 0xfc060f07,   // sr.be.tt_332 so.aa.un_980  qu.st.un_440 lv.de.zzp_432 
  0x224e13a4, 0x13042909, 0x33132cee, 0xfe0d2a08,   // et.ay.oc_433 sl.fi.et_444  fy.et.nn_422 mt.cs.tlh_443 
  // [bd80]
  0x08002307, 0x38481ba4, 0x4e00fe19, 0x17001508,   // ky.uk.un_420 tr.tt.tk_433  tlh.ay.un_750 un.sr.un_430 
  0x35003102, 0x153810a9, 0x1a001f02, 0x343d3b11,   // az.zu.un_220 be.tk.un_544  cy.tl.un_220 ks.ku.ps_653 
  0x3e001302, 0x381b3107, 0x38003c20, 0x343d2108,   // et.rm.un_220 az.tr.tk_432  ug.tk.un_850 fa.ku.ps_443 
  0x30482312, 0x0d000911, 0x341230a4, 0x38001b0b,   // ky.tt.uz_654 hi.ne.un_630  uz.ur.ps_433 tr.tk.un_520 
  // [bd90]
  0x074c42ee, 0x300807a0, 0x23003c05, 0x0d5c3bad,   // co.wo.it_422 bg.uk.uz_322  ug.ky.un_330 ks.sa.ne_643 
  0x0800020b, 0x042410a9, 0x3c003008, 0x242810ec,   // da.no.un_520 lt.eo.fi_544  uz.ug.un_430 lt.sw.eo_644 
  0x021264ad, 0x10002414, 0x121e4508, 0x10170407,   // lg.hu.da_643 eo.lt.un_660  ln.ms.hu_443 ru.sr.be_432 
  0x651d620c, 0x5c027309, 0x02006409, 0x13242004,   // kha.la.gv_543 ny.da.sa_444  lg.da.un_440 sq.eo.et_332 
  // [bda0]
  0x533473a0, 0x37251007, 0x37353408, 0x21021204,   // ny.xh.ht_322 be.mn.ba_432  xh.zu.st_443 hu.da.jw_332 
  0x10002412, 0x551c64a6, 0x60fe62a7, 0x05002f08,   // eo.lt.un_640 lg.id.rw_521  kha.tlh.vo_532 su.fr.un_430 
  0x15041708, 0x5c470204, 0x24281012, 0x233444ec,   // sr.ru.un_443 da.sn.sa_332  lt.sw.eo_654 kk.ps.ky_644 
  0x285c02a9, 0x3b003008, 0x4c2d0d5a, 0x03123f02,   // da.sa.sw_544 uz.so.un_430  cs.sk.wo_553 af.hu.nl_222 
  // [bdb0]
  0x302c40a0, 0x0a3c3504, 0x1515040d, 0x4a004d12,   // lb.fy.uz_322 tg.ug.mk_332  ru.un.un_540 aa.yo.un_640 
  0x1f001e04, 0x0b191311, 0x0300fe07, 0x300c0713,   // ms.cy.un_320 et.gl.es_653  tlh.nl.un_420 it.sv.uz_665 
  0x46004d0b, 0xfc371f0c, 0x1c212f13, 0x2533040c,   // aa.qu.un_520 cy.st.zzp_543  su.jw.id_665 fi.nn.eu_543 
  0x182c10ee, 0x27000707, 0x693965a4, 0x734757af,   // lt.fy.ga_422 it.gd.un_420  gv.br.mfe_433 na.sn.ny_655 
  // [bdc0]
  0x07425907, 0x07423908, 0xfc002502, 0x2873020c,   // rn.co.it_432 br.co.it_443  eu.zzp.un_220 da.ny.sw_543 
  0x07081107, 0x0c290107, 0x39005307, 0x12000e13,   // ro.uk.bg_432 en.sl.sv_432  ht.br.un_420 is.hu.un_650 
  0x2a111809, 0x67354a08, 0x16290aa9, 0x76001e04,   // ga.ro.mt_444 yo.zu.ak_443  pt.sl.hr_544 ms.crs.un_320 
  0x25170aec, 0x09002d1a, 0x3f125302, 0x64003408,   // mk.sr.mn_644 sk.pl.un_760  ht.hu.af_222 xh.lg.un_430 
  // [bdd0]
  0x3f00030e, 0x2e0c0807, 0x0b0a0da6, 0x303d18af,   // nl.af.un_550 no.sv.fo_432  cs.pt.es_521 ar.ku.uz_655 
  0x0a071107, 0x50555a04, 0x234226a9, 0x223926ac,   // ro.bg.mk_432 sm.rw.fj_332  ia.co.ca_544 ia.br.oc_632 
  0x32001008, 0x535969a9, 0x150c0807, 0x3f4615a0,   // lt.bs.un_430 mfe.rn.ht_544  no.sv.un_432 un.qu.af_322 
  0x5c130d14, 0x3f030604, 0x20000d07, 0x3f27fc02,   // ne.bh.sa_666 de.nl.af_332  cs.sq.un_420 zzp.gd.af_222 
  // [bde0]
  0x07170a5a, 0x0a0717a7, 0x12001f0c, 0x0e122e04,   // mk.sr.bg_553 sr.bg.mk_532  cy.hu.un_530 fo.hu.is_332 
  0x65002a08, 0x250a1504, 0x12001504, 0x0d135cee,   // mt.gv.un_430 un.mk.mn_332  un.hu.un_320 sa.bh.ne_422 
  0x07170804, 0x441007a0, 0x351025ee, 0xfc000c12,   // uk.sr.bg_332 bg.be.kk_322  mn.be.tg_422 sv.zzp.un_640 
  0x070817a4, 0x0800111a, 0x05003b02, 0x29300f07,   // sr.uk.bg_433 ro.uk.un_760  so.fr.un_220 lv.uz.sl_432 
  // [bdf0]
  0x354a58a4, 0x042508a7, 0x303c4809, 0x73495aac,   // om.yo.zu_433 uk.mn.ru_532  tt.ug.uz_444 sm.to.ny_632 
  0x4423150c, 0x58004a08, 0xfe004e21, 0x23381512,   // un.ky.kk_543 yo.om.un_430  ay.tlh.un_860 un.tk.ky_654 
  0x43002019, 0x4430230b, 0x33000212, 0x11382512,   // sq.ie.un_750 ky.uz.kk_542  da.nn.un_640 mn.tk.ro_654 
  0x1c00131a, 0x2000300c, 0x13fe61ad, 0x21004607,   // bh.mr.un_760 uz.sq.un_530  za.tlh.et_643 qu.jw.un_420 
  // [be00]
  0x3548300c, 0x46001a08, 0x300715a0, 0x3500302a,   // uz.tt.tg_543 tl.qu.un_430  un.bg.uz_322 uz.tg.un_970 
  0x211230a7, 0x6500460d, 0x28003d09, 0x2f001102,   // uz.ur.fa_532 qu.gv.un_540  ku.sd.un_440 ro.su.un_220 
  0x0e002d09, 0x353454ec, 0x0e002d11, 0x13002d16,   // sk.is.un_440 ik.xh.zu_644  sk.is.un_630 sk.et.un_720 
  0x44233ca9, 0x290d17a6, 0x692f450c, 0x163447a7,   // ug.ky.kk_544 sr.cs.sl_521  ln.su.mfe_543 sn.xh.hr_532 
  // [be10]
  0x30285f05, 0x59003719, 0x17000714, 0x56004a13,   // tn.sw.uz_333 st.rn.un_750  bg.sr.un_660 yo.mg.un_650 
  0x34093b0c, 0x39001a02, 0x0533210c, 0x45002f21,   // so.pl.xh_543 tl.br.un_220  jw.nn.fr_543 su.ln.un_860 
  0x151f6407, 0x075001a4, 0x5d6a34ad, 0x59005809,   // lg.cy.un_432 en.fj.it_433  xh.haw.ss_643 om.rn.un_440 
  0x2f211cec, 0xfc001b18, 0x54353414, 0x1b00fc19,   // id.jw.su_644 tr.zzp.un_740  xh.zu.ik_666 zzp.tr.un_750 
  // [be20]
  0x45696412, 0x19005a0c, 0x35475905, 0x6a004519,   // lg.mfe.ln_654 sm.gl.un_530  rn.sn.zu_333 ln.haw.un_750 
  0x3b001104, 0x553459ad, 0x5d352855, 0x12001d02,   // ro.so.un_320 rn.xh.rw_643  sw.zu.ss_442 la.hu.un_220 
  0x30402507, 0x307660ec, 0x3526fca4, 0x553553a7,   // eu.lb.uz_432 vo.crs.uz_644  zzp.ia.zu_433 ht.zu.rw_532 
  0x3530550c, 0x1f004d12, 0x29002702, 0x3b3530ad,   // rw.uz.zu_543 aa.cy.un_640  gd.sl.un_220 uz.zu.so_643 
  // [be30]
  0x1b38120d, 0x38003708, 0x437623a4, 0x252302a0,   // hu.tk.tr_554 st.tk.un_430  ca.crs.ie_433 da.ca.eu_322 
  0x3308fea9, 0x223143a0, 0x305804ac, 0x5f561804,   // tlh.no.nn_544 ie.az.oc_322  fi.om.uz_632 ga.mg.tn_332 
  0x19002012, 0x0717350d, 0x5c002007, 0x55002013,   // sq.gl.un_640 tg.sr.bg_554  sq.sa.un_420 sq.rw.un_650 
  0x36002f11, 0x00000c37, 0x2100351a, 0x2a004e0d,   // su.gn.un_630 sv.un.un_B00  zu.jw.un_760 ay.mt.un_540 
  // [be40]
  0x5c7863af, 0x4c00050d, 0x13fe04a7, 0x4830380d,   // sco.ve.sa_655 fr.wo.un_540  fi.tlh.et_532 tk.uz.tt_554 
  0x08363704, 0x330115ee, 0x04fe13ec, 0x63182712,   // ba.ab.uk_332 un.en.nn_422  et.tlh.fi_644 gd.ga.sco_654 
  0x4d003021, 0x7318270c, 0x241d1107, 0x1d002119,   // uz.aa.un_860 gd.ga.ny_543  ro.la.eo_432 jw.la.un_750 
  0x1f2d2ca0, 0x22421c0c, 0xfc1f010c, 0x64001a02,   // fy.sk.cy_322 id.co.oc_543  en.cy.zzp_543 tl.lg.un_220 
  // [be50]
  0x275f630d, 0x1d23fc07, 0x38003e04, 0x202102a0,   // sco.tn.gd_554 zzp.ca.la_432  rm.tk.un_320 da.jw.sq_322 
  0x301504ee, 0x06030f02, 0x73353414, 0x4258300c,   // fi.uz.un_420 lv.nl.de_222  xh.zu.ny_666 uz.om.co_543 
  0x73343507, 0x11353012, 0x21054c07, 0x3e76530c,   // zu.xh.ny_432 uz.tg.ro_654  wo.fr.jw_432 ht.crs.rm_543 
  0x133b58ee, 0x182e270c, 0x11155c07, 0x353469a9,   // om.so.et_422 gd.fo.ga_543  sa.ro.un_420 mfe.xh.zu_544 
  // [be60]
  0x34213d0d, 0x3720fe07, 0x102d0d60, 0x643445ee,   // ku.fa.ps_554 tlh.sq.st_432  cs.sk.lt_664 ln.xh.lg_422 
  0x48152355, 0x34004507, 0x15000307, 0x25003705,   // ky.tt.un_420 ln.xh.un_420  nl.un.un_420 ba.mn.un_330 
  0x214c15a0, 0x0f000104, 0x071d26a9, 0x24060208,   // un.wo.jw_322 en.lv.un_320  ia.la.it_544 da.de.eo_443 
  0x44382314, 0x21005307, 0x30001209, 0x231037a4,   // ky.tk.kk_666 ht.jw.un_420  ur.uz.un_440 ba.be.ky_433 
  // [be70]
  0x21000a04, 0x36153caf, 0x23303cee, 0x3b00610d,   // pt.jw.un_320 ug.ab.un_650  ug.uz.ky_422 za.so.un_540 
  0x39060107, 0x3d1228a4, 0x396b3b0c, 0x49584c0c,   // en.de.br_432 sd.ur.ku_433  so.ceb.br_543 wo.om.to_543 
  0x55001504, 0x3f002404, 0x24003f02, 0x4a493bee,   // un.rw.un_320 eo.af.un_320  af.eo.un_220 so.to.yo_422 
  0x3c170aa4, 0x34004c14, 0x48003b1a, 0x644d3b12,   // mk.sr.ug_433 wo.xh.un_660  so.tt.un_760 so.aa.lg_654 
  // [be80]
  0x156465a7, 0x10040804, 0x1115300c, 0x3b30110c,   // gv.lg.un_532 uk.ru.be_332  uz.ro.un_530 ro.uz.so_543 
  0x3c000713, 0x23350707, 0x2f211ea4, 0x4dfe58a9,   // bg.ug.un_650 bg.tg.ky_432  ms.jw.su_433 om.tlh.aa_544 
  0x25043c04, 0x20321b04, 0x214c58a7, 0x283b12ec,   // ug.ru.mn_332 tr.bs.sq_332  om.wo.jw_532 ur.ks.sd_644 
  0x135c1c07, 0x353017af, 0x173507a4, 0x796301a4,   // mr.sa.bh_432 sr.uz.tg_655  bg.tg.sr_433 en.sco.war_433 
  // [be90]
  0x2700182a, 0x30233da9, 0x3e002c19, 0x60630104,   // ga.gd.un_970 ku.ky.uz_544  fy.rm.un_750 en.sco.vo_332 
  0x2c002704, 0x0b002804, 0x6800fc09, 0x30003105,   // gd.fy.un_320 sw.es.un_320  zzp.ig.un_440 az.uz.un_330 
  0x4800151a, 0x083507ee, 0x04000f13, 0x042410af,   // un.tt.un_760 bg.tg.uk_422  lv.fi.un_650 lt.eo.fi_655 
  0x1500370e, 0x20000409, 0x533669a7, 0x153507af,   // ba.un.un_550 fi.sq.un_440  mfe.gn.ht_532 bg.tg.un_655 
  // [bea0]
  0x1f6545a7, 0x5534250c, 0x20731ea4, 0x01000207,   // ln.gv.cy_532 eu.xh.rw_543  ms.ny.sq_433 da.en.un_420 
  0x381504a4, 0x44212314, 0x10001f02, 0x3510170d,   // ru.tk.un_430 ky.fa.kk_666  cy.lt.un_220 sr.be.tg_554 
  0x1024200c, 0x0f042407, 0x3400690c, 0x535c6905,   // sq.eo.lt_543 eo.fi.lv_432  mfe.xh.un_530 mfe.sa.ht_333 
  0x276257af, 0x1d0c3402, 0x5f374a14, 0x35071704,   // na.kha.gd_655 xh.sv.la_222  yo.st.tn_666 sr.bg.tg_332 
  // [beb0]
  0x44081012, 0x1d00fe13, 0x79094a08, 0x0f490107,   // be.uk.kk_654 tlh.la.un_650  yo.pl.war_443 en.to.lv_432 
  0x48373c60, 0x5f370305, 0x343012ac, 0x5c12040c,   // ug.ba.tt_664 nl.st.tn_333  ur.uz.ps_632 fi.hu.sa_543 
  0x40045ca0, 0x48045c04, 0x6b697912, 0xfc285a07,   // sa.fi.lb_322 sa.fi.tt_332  war.mfe.ceb_654 sm.sw.zzp_432 
  0x0d000923, 0x37755faf, 0x17000a34, 0x3700fc05,   // hi.ne.un_880 tn.nso.st_655  mk.sr.un_A80 zzp.st.un_330 
  // [bec0]
  0x5e786e0c, 0x4700fc07, 0x792d10a9, 0x3000070c,   // hmn.ve.ts_543 zzp.sn.un_420  lt.sk.war_544 bg.uz.un_530 
  0x44040aa4, 0x18282105, 0x032b3fa0, 0x2c003b04,   // mk.ru.kk_433 fa.sd.ar_333  af.vi.nl_322 so.fy.un_320 
  0x5a104fa7, 0x282757ad, 0x17073805, 0x5a271814,   // bi.lt.sm_532 na.gd.sw_643  tk.bg.sr_333 ga.gd.sm_666 
  0x482315ee, 0x6a006519, 0x3b313f0c, 0x04252c04,   // un.ky.tt_422 gv.haw.un_750  af.az.so_543 fy.eu.fi_332 
  // [bed0]
  0x101f5007, 0x40002202, 0x431d2513, 0x2e0e120c,   // fj.cy.lt_432 oc.lb.un_220  eu.la.ie_665 hu.is.fo_543 
  0x281812ee, 0x650163a0, 0x651d11a0, 0x0a4437a0,   // ur.ar.sd_422 sco.en.gv_322  ro.la.gv_322 ba.kk.mk_322 
  0x65102b09, 0x631d0208, 0x0b47550c, 0x42220507,   // vi.lt.gv_444 da.la.sco_443  rw.sn.es_543 fr.oc.co_432 
  0x202c3f05, 0x18111dee, 0x64005d02, 0x353445a0,   // af.fy.sq_333 la.ro.ga_422  ss.lg.un_220 ln.xh.zu_322 
  // [bee0]
  0x231048af, 0x792f1cee, 0x23104904, 0x353459a0,   // tt.be.ky_655 id.su.war_422  to.lt.ca_332 rn.xh.zu_322 
  0x5a1d360d, 0x15fc4ba0, 0x082e3304, 0x3c3034ad,   // gn.la.sm_554 mi.zzp.un_322  nn.fo.no_332 ps.uz.ug_643 
  0x422560ad, 0x49130104, 0x2515040e, 0x1715360c,   // vo.eu.co_643 en.et.to_332  ru.mn.un_550 ab.sr.un_530 
  0x4c00690d, 0x30005304, 0x07113804, 0x17041513,   // mfe.wo.un_540 ht.uz.un_320  tk.ro.bg_332 un.ru.sr_665 
  // [bef0]
  0x5c1c09a6, 0x241210a0, 0x48303109, 0x1e245304,   // hi.mr.sa_521 lt.hu.eo_322  az.uz.tt_444 ht.eo.ms_332 
  0x0f002404, 0x0e00131b, 0x5c00360d, 0x0708040c,   // eo.lv.un_320 et.is.un_770  gn.sa.un_540 ru.uk.bg_543 
  0x6400020c, 0x13003305, 0x1b0b01a0, 0x4e4608a4,   // da.lg.un_530 nn.et.un_330  en.es.tr_322 no.qu.ay_433 
  0x132e0e08, 0x33003604, 0x111d430c, 0x13000c21,   // is.fo.et_443 gn.nn.un_320  ie.la.ro_543 sv.et.un_860 
  // [bf00]
  0x212f6107, 0x1c2f1eec, 0x02004e1a, 0x24394708,   // za.su.jw_432 ms.su.id_644  ay.da.un_760 sn.br.eo_443 
  0x6500fc14, 0x30353c08, 0x2e0e33a4, 0x642f55a4,   // zzp.gv.un_660 ug.tg.uz_443  nn.is.fo_433 rw.su.lg_433 
  0x2a392402, 0x53001d05, 0x42003304, 0x3b3930a9,   // eo.br.mt_222 la.ht.un_330  nn.co.un_320 uz.br.so_544 
  0xfc7901a4, 0x1c2f2109, 0x020779a4, 0x01651da0,   // en.war.zzp_433 jw.su.id_444  war.it.da_433 la.gv.en_322 
  // [bf10]
  0x04125ca6, 0x28691c07, 0x070523a0, 0x1b005c08,   // sa.hu.fi_521 id.mfe.sw_432  ca.fr.it_322 sa.tr.un_430 
  0x1f2a18a0, 0x30004814, 0x2e0313a4, 0x21001818,   // ga.mt.cy_322 tt.uz.un_660  et.nl.fo_433 ar.fa.un_740 
  0x0a002402, 0x5c003608, 0x332e13a9, 0x10202da4,   // eo.pt.un_220 gn.sa.un_430  et.fo.nn_544 sk.sq.lt_433 
  0x73595ca7, 0x332e13a4, 0x0e2e03a4, 0x0a4837ee,   // sa.rn.ny_532 et.fo.nn_433  nl.fo.is_433 ba.tt.mk_422 
  // [bf20]
  0x5c130460, 0x4635340e, 0x1f6301a4, 0x39004712,   // fi.et.sa_664 xh.zu.qu_555  en.sco.cy_433 sn.br.un_640 
  0x3d3412ad, 0x1a004604, 0x1d001812, 0x29232a04,   // ur.ps.ku_643 qu.tl.un_320  ga.la.un_640 mt.ca.sl_332 
  0x39002209, 0x35000708, 0x3010350c, 0x040a0714,   // oc.br.un_440 bg.tg.un_430  tg.be.uz_543 bg.mk.ru_666 
  0x23304860, 0x2e0d0ea7, 0x253530a4, 0x5d2535a0,   // tt.uz.ky_664 is.cs.fo_532  uz.tg.mn_433 zu.eu.ss_322 
  // [bf30]
  0x2821120d, 0x351711ee, 0x35311b0c, 0x2c31250c,   // ur.fa.sd_554 ro.sr.tg_422  tr.az.zu_543 eu.az.fy_543 
  0x11312012, 0x38234407, 0x640d1104, 0xfa455d0c,   // sq.az.ro_654 kk.ky.tk_432  ro.cs.lg_332 ss.ln.nr_543 
  0x483715a7, 0x3b796b12, 0x551a590c, 0x050b45ee,   // un.ba.tt_532 ceb.war.so_654  rn.tl.rw_543 ln.es.fr_422 
  0x564734a7, 0x350a17a9, 0x595d5507, 0x3e000207,   // xh.sn.mg_532 sr.mk.tg_544  rw.ss.rn_432 da.rm.un_420 
  // [bf40]
  0x6b3529a0, 0x3418280e, 0x285559a7, 0x36552b07,   // sl.zu.ceb_322 sd.ar.ps_555  rn.rw.sw_532 vi.rw.gn_432 
  0x0b004d19, 0x3534faa4, 0x18211255, 0x4c003b04,   // aa.es.un_750 nr.xh.zu_433  ur.fa.ar_442 so.wo.un_320 
  0x091c5c14, 0x48353405, 0x3455590c, 0x22231ea4,   // sa.mr.hi_666 xh.zu.tt_333  rn.rw.xh_543 ms.ca.oc_433 
  0x5c2f0204, 0x1b2b0ba0, 0x28182104, 0x240452ee,   // da.su.sa_332 es.vi.tr_322  fa.ar.sd_332 ha.fi.eo_422 
  // [bf50]
  0x060c3e07, 0x46005112, 0x642850a7, 0x3f2a2108,   // rm.sv.de_432 kl.qu.un_640  fj.sw.lg_532 jw.mt.af_443 
  0x1b3830ad, 0x0e005204, 0x28007808, 0x45007812,   // uz.tk.tr_643 ha.is.un_320  ve.sw.un_430 ve.ln.un_640 
  0x06003607, 0x301b4d14, 0x574006ec, 0x1c375904,   // gn.de.un_420 aa.tr.uz_666  de.lb.na_644 rn.st.id_332 
  0x2b535507, 0x2f563004, 0x08074408, 0x61003014,   // rw.ht.vi_432 uz.mg.su_332  kk.bg.uk_443 uz.za.un_660 
  // [bf60]
  0x381b31a7, 0x277336a7, 0x3028210c, 0x324217a0,   // az.tr.tk_532 gn.ny.gd_532  fa.sd.uz_543 sr.co.bs_322 
  0x1b381e08, 0x59005512, 0x04071005, 0x50000f0c,   // ms.tk.tr_443 rw.rn.un_640  be.bg.ru_333 lv.fj.un_530 
  0x3000610d, 0x64004d07, 0x2a1b3012, 0x78005e21,   // za.uz.un_540 aa.lg.un_420  uz.tr.mt_654 ts.ve.un_860 
  0x2d0d0602, 0x0d005d07, 0x3e4258a4, 0x3e580ca4,   // de.cs.sk_222 ss.cs.un_420  om.co.rm_433 sv.om.rm_433 
  // [bf70]
  0x4600fe19, 0x58001f1a, 0x58001d0e, 0x0a0408a0,   // tlh.qu.un_750 cy.om.un_760  la.om.un_550 uk.ru.mk_322 
  0x4900580b, 0x043008a7, 0x234836a4, 0x17000805,   // om.to.un_520 uk.uz.ru_532  ab.tt.ky_433 uk.sr.un_330 
  0x373c30af, 0x25113813, 0x1f4d4812, 0x20006912,   // uz.ug.ba_655 tk.ro.mn_665  tt.aa.cy_654 mfe.sq.un_640 
  0x0200600d, 0x10383507, 0x0200fe21, 0x697901ee,   // vo.da.un_540 tg.tk.be_432  tlh.da.un_860 en.war.mfe_422 
  // [bf80]
  0x100407a7, 0x45695505, 0x28000a05, 0x0d135c02,   // bg.ru.be_532 rw.mfe.ln_333  pt.sw.un_330 sa.bh.ne_222 
  0x595562ec, 0x44373805, 0x432f210c, 0x5528640b,   // kha.rw.rn_644 tk.ba.kk_333  jw.su.ie_543 lg.sw.rw_542 
  0x4a002809, 0x64004f09, 0x20000702, 0xfe005f11,   // sw.yo.un_440 bi.lg.un_440  it.sq.un_220 tn.tlh.un_630 
  0x51003608, 0x536447a4, 0x474a1ea0, 0x0a004905,   // gn.kl.un_430 sn.lg.ht_433  ms.yo.sn_322 to.pt.un_330 
  // [bf90]
  0x0b3b5002, 0x09001c34, 0x2b006e13, 0x350f3ba4,   // fj.so.es_222 mr.hi.un_A80  hmn.vi.un_650 so.lv.zu_433 
  0x651d1905, 0x4d00522c, 0x47002b21, 0x35005205,   // gl.la.gv_333 ha.aa.un_990  vi.sn.un_860 ha.zu.un_330 
  0x1537380c, 0x582a3504, 0x63005705, 0x354a69ad,   // tk.ba.un_543 zu.mt.om_332  na.sco.un_330 mfe.yo.zu_643 
  0x1f3e2ba4, 0x634a0107, 0x59524d08, 0x28525809,   // vi.rm.cy_433 en.yo.sco_432  aa.ha.rn_443 om.ha.sw_444 
  // [bfa0]
  0x4a000108, 0x22211caf, 0x1a00260b, 0x3b005821,   // en.yo.un_430 id.jw.oc_655  ia.tl.un_520 om.so.un_860 
  0x5d553508, 0x64005302, 0x755237a9, 0x47211c04,   // zu.rw.ss_443 ht.lg.un_220  st.ha.nso_544 id.jw.sn_332 
  0x17080a13, 0x2b006e0d, 0x23000802, 0x30043704,   // mk.uk.sr_665 hmn.vi.un_540  uk.ky.un_220 ba.ru.uz_332 
  0x15353860, 0x34002407, 0x341218ee, 0x442334ec,   // tk.tg.un_664 eo.xh.un_420  ar.ur.ps_422 ps.ky.kk_644 
  // [bfb0]
  0x08173ca4, 0x353708a4, 0x122821a9, 0x251038af,   // ug.sr.uk_433 uk.ba.tg_433  fa.sd.ur_544 tk.be.mn_655 
  0x150730a0, 0x060c0412, 0x10000904, 0x08150708,   // uz.bg.un_322 fi.sv.de_654  pl.lt.un_320 bg.uk.un_430 
  0x37040805, 0x35215cee, 0x121821ad, 0x46fe1da7,   // uk.ru.ba_333 sa.jw.zu_422  fa.ar.ur_643 la.tlh.qu_532 
  0xfe461d12, 0x46fe1d60, 0xfe00461a, 0x23fe1d07,   // la.qu.tlh_654 la.tlh.qu_664  qu.tlh.un_760 la.tlh.ca_432 
  // [bfc0]
  0x1200341b, 0x22001d0c, 0x111538a4, 0x46001d09,   // ps.ur.un_770 la.oc.un_530  tk.ro.un_430 la.qu.un_440 
  0x2a001d0d, 0x172d0da9, 0x48303c07, 0x0200360d,   // la.mt.un_540 cs.sk.sr_544  ug.uz.tt_432 gn.da.un_540 
  0x5c1c095a, 0x02005e04, 0x231d2255, 0x1e461d07,   // hi.mr.sa_553 ts.da.un_320  oc.la.ca_442 la.qu.ms_432 
  0x1d00462a, 0x654b18a7, 0x221d46ad, 0x28006522,   // qu.la.un_970 ga.mi.gv_532  qu.la.oc_643 gv.sw.un_870 
  // [bfd0]
  0x56002814, 0x27281809, 0x49475a12, 0x07654fa4,   // sw.mg.un_660 ga.sw.gd_444  sm.sn.to_654 bi.gv.it_433 
  0x1c645802, 0x2427180c, 0x2a00fc05, 0x5627180c,   // om.lg.id_222 ga.gd.eo_543  zzp.mt.un_330 ga.gd.mg_543 
  0x1d290107, 0x2b653e05, 0x300438a4, 0x1d6a730c,   // en.sl.la_432 rm.gv.vi_333  tk.ru.uz_433 ny.haw.la_543 
  0x1d06010c, 0x2e000411, 0x22026ea9, 0x07472707,   // en.de.la_543 fi.fo.un_630  hmn.da.oc_544 gd.sn.it_432 
  // [bfe0]
  0x5a79490c, 0x440735ee, 0x27181c07, 0x65000605,   // to.war.sm_543 tg.bg.kk_422  id.ga.gd_432 de.gv.un_330 
  0x253017a7, 0x1efcfea0, 0x5f00fe2b, 0x40fc060c,   // sr.uz.mn_532 tlh.zzp.ms_322  tlh.tn.un_980 de.zzp.lb_543 
  0x12064307, 0x57fe62a4, 0x24585aa0, 0x4d001823,   // ie.de.hu_432 kha.tlh.na_433  sm.om.eo_322 ga.aa.un_880 
  0x0f322909, 0x35170804, 0x58514c09, 0x2b005002,   // sl.bs.lv_444 uk.sr.tg_332  wo.kl.om_444 fj.vi.un_220 
  // [bff0]
  0x4c5125a7, 0xfe00460e, 0x76006922, 0x37003104,   // eu.kl.wo_532 qu.tlh.un_550  mfe.crs.un_870 az.st.un_320 
  0x56422909, 0x2b002704, 0x53001e11, 0x12000608,   // sl.co.mg_444 gd.vi.un_320  ms.ht.un_630 de.hu.un_430 
  0x0c123e04, 0x2c005502, 0x6b001a13, 0x5c202508,   // rm.hu.sv_332 rw.fy.un_220  tl.ceb.un_650 eu.sq.sa_443 
  0x04363509, 0x0a6b0ca4, 0x3f380602, 0x0c000411,   // tg.ab.ru_444 sv.ceb.pt_433  de.tk.af_222 fi.sv.un_630 
  
  // [c000]
  0x0400fc05, 0x583b6304, 0x53014602, 0x35463155,   // zzp.fi.un_330 sco.so.om_332  qu.en.ht_222 az.qu.zu_442 
  0x31002202, 0x35002518, 0x1f006307, 0x6b697908,   // oc.az.un_220 mn.tg.un_740  sco.cy.un_420 war.mfe.ceb_443 
  0x5300730d, 0x28121807, 0x01026307, 0x01790507,   // ny.ht.un_540 ar.ur.sd_432  sco.da.en_432 fr.war.en_432 
  0x2a004c04, 0x0b002a0c, 0x483038af, 0x12004a08,   // wo.mt.un_320 mt.es.un_530  tk.uz.tt_655 yo.hu.un_430 
  // [c010]
  0x0200580d, 0x44483760, 0x0a081108, 0x0a1515ad,   // om.da.un_540 ba.tt.kk_664  ro.uk.mk_443 un.mk.un_630 
  0x3c483709, 0x281821a4, 0x18303409, 0x0408440c,   // ba.tt.ug_444 fa.ar.sd_433  ps.uz.ar_444 kk.uk.ru_543 
  0x0708350c, 0x18213402, 0x374423a9, 0x49006a22,   // tg.uk.bg_543 ps.fa.ar_222  ky.kk.ba_544 haw.to.un_870 
  0x5e004708, 0x1e004907, 0x3f1b38a0, 0x12330805,   // sn.ts.un_430 to.ms.un_420  tk.tr.af_322 no.nn.hu_333 
  // [c020]
  0x47003508, 0x0e5a57ee, 0x3100600b, 0x1b384805,   // zu.sn.un_430 na.sm.is_422  vo.az.un_520 tt.tk.tr_333 
  0x1e1c62ee, 0x03000914, 0x5c1b3104, 0x78736ea4,   // kha.id.ms_422 pl.nl.un_660  az.tr.sa_332 hmn.ny.ve_433 
  0x39001805, 0x17071004, 0x48047560, 0x0e000913,   // ga.br.un_330 be.bg.sr_332  nso.fi.tt_664 pl.is.un_650 
  0x37003002, 0x02090e0d, 0x205c2102, 0x286721a4,   // uz.ba.un_220 is.pl.da_554  jw.sa.sq_222 jw.ak.sw_433 
  // [c030]
  0x12042513, 0x1b483107, 0x1024200b, 0x1b4f5312,   // eu.fi.hu_665 az.tt.tr_432  sq.eo.lt_542 ht.bi.tr_654 
  0x1d584d0c, 0x24494f05, 0x1137300c, 0x30253805,   // aa.om.la_543 bi.to.eo_333  uz.ba.ro_543 tk.mn.uz_333 
  0x22002f02, 0x56005802, 0x1d2a04a0, 0x37080407,   // su.oc.un_220 om.mg.un_220  fi.mt.la_322 ru.uk.ba_432 
  0x432401a4, 0x170a08ad, 0x2a023907, 0x171025ac,   // en.eo.ie_433 uk.mk.sr_643  br.da.mt_432 mn.be.sr_632 
  // [c040]
  0x252d0d08, 0x55005602, 0x35565f04, 0x191024ee,   // cs.sk.eu_443 mg.rw.un_220  tn.mg.zu_332 eo.lt.gl_422 
  0x07004205, 0x0e070da9, 0x5f3437a4, 0x5f003509,   // co.it.un_330 cs.it.is_544  st.xh.tn_433 zu.tn.un_440 
  0x2a004212, 0x29682d11, 0x160d7904, 0x2d002f02,   // co.mt.un_640 sk.ig.sl_653  war.cs.hr_332 su.sk.un_220 
  0x32003502, 0xfe000c02, 0x3e003308, 0x5d001904,   // zu.bs.un_220 sv.tlh.un_220  nn.rm.un_430 gl.ss.un_320 
  // [c050]
  0x36170a04, 0x0a353008, 0x271865ad, 0x113155a0,   // mk.sr.ab_332 uz.tg.mk_443  gv.ga.gd_643 rw.az.ro_322 
  0x38374808, 0x39073e02, 0x565535ad, 0x02fa35af,   // tt.ba.tk_443 rm.it.br_222  zu.rw.mg_643 zu.nr.da_655 
  0x15002008, 0x462f4eee, 0x105327ee, 0x555645a4,   // sq.un.un_430 ay.su.qu_422  gd.ht.lt_422 ln.mg.rw_433 
  0x56007308, 0x354dfa12, 0x080a0402, 0x0b001505,   // ny.mg.un_430 nr.aa.zu_654  ru.mk.uk_222 un.es.un_330 
  // [c060]
  0x3800fc1a, 0x13000502, 0x1c1929a0, 0x09006309,   // zzp.tk.un_760 fr.et.un_220  sl.gl.id_322 sco.pl.un_440 
  0x07151507, 0x044959a4, 0x44152507, 0x18233dec,   // un.bg.un_420 rn.to.fi_433  mn.kk.un_420 ku.ky.ar_644 
  0x47182755, 0x20005104, 0x173835a7, 0x2b475e04,   // gd.ga.sn_442 kl.sq.un_320  tg.tk.sr_532 ts.sn.vi_332 
  0x496a6714, 0xfe1873a9, 0x622765a4, 0x47494a02,   // ak.haw.to_666 ny.ga.tlh_544  gv.gd.kha_433 yo.to.sn_222 
  // [c070]
  0x6500fe13, 0x52531807, 0x051f1d0c, 0x380262ec,   // tlh.gv.un_650 ga.ht.ha_432  la.cy.fr_543 kha.da.tk_644 
  0x152b010b, 0x36005a08, 0x49296a0c, 0x213673ad,   // en.vi.un_542 sm.gn.un_430  haw.sl.to_543 ny.gn.jw_643 
  0x732001a0, 0x374b7308, 0x082336a0, 0x5f364907,   // en.sq.ny_322 ny.mi.st_443  ab.ky.uk_322 to.gn.tn_432 
  0x36001104, 0x58004c0d, 0x0f006a0c, 0x10040708,   // ro.gn.un_320 wo.om.un_540  haw.lv.un_530 bg.ru.be_443 
  // [c080]
  0x5a3036ee, 0x23154404, 0x041338a4, 0x37136aee,   // gn.uz.sm_422 kk.ky.un_320  tk.et.fi_433 haw.et.st_422 
  0x496a4ba9, 0x480a15ee, 0x233530af, 0x23182255,   // mi.haw.to_544 un.mk.tt_422  uz.tg.ky_655 oc.ga.ca_442 
  0x0f002407, 0x15004804, 0x1c213002, 0x622336a4,   // eo.lv.un_420 tt.un.un_320  uz.jw.id_222 gn.ca.kha_433 
  0x0c0630a0, 0x06005713, 0x04150809, 0x38374860,   // uz.de.sv_322 na.de.un_650  uk.ru.un_440 tt.ba.tk_664 
  // [c090]
  0x17100707, 0x35301555, 0x36001022, 0x08150704,   // bg.be.sr_432 un.uz.tg_442  be.ab.un_870 bg.uk.un_320 
  0x0a080711, 0x46005d04, 0x0c03150c, 0x3b4c65ec,   // bg.uk.mk_653 ss.qu.un_320  un.nl.sv_543 gv.wo.so_644 
  0x2d00090d, 0x17003c05, 0x1f001018, 0x1b003b02,   // pl.sk.un_540 ug.sr.un_330  lt.cy.un_740 so.tr.un_220 
  0x5c281312, 0x2f47780c, 0x4c654da4, 0x78212f0c,   // et.sw.sa_654 ve.sn.su_543  aa.gv.wo_433 su.jw.ve_543 
  // [c0a0]
  0x65003b1a, 0x12283ba0, 0x59552f05, 0x64251ea0,   // so.gv.un_760 ks.sd.ur_322  su.rw.rn_333 ms.eu.lg_322 
  0x084b4907, 0x104928a0, 0x4525040c, 0x6a000413,   // to.mi.no_432 sw.to.lt_322  fi.eu.ln_543 fi.haw.un_650 
  0x12281811, 0x101704a4, 0x2535380b, 0x49003f08,   // ar.sd.ur_653 ru.sr.be_433  tk.tg.mn_542 af.to.un_430 
  0x285c2fee, 0x2b021007, 0x28001814, 0x6a002521,   // su.sa.sw_422 lt.da.vi_432  ar.sd.un_660 eu.haw.un_860 
  // [c0b0]
  0x104902ee, 0x4f005e18, 0x20230b07, 0x3b52280c,   // da.to.lt_422 ts.bi.un_740  es.ca.sq_432 sw.ha.so_543 
  0x25002f0c, 0x49000209, 0x534a64a4, 0x48005304,   // su.eu.un_530 da.to.un_440  lg.yo.ht_433 ht.tt.un_320 
  0x0c001602, 0x52644aad, 0x21000509, 0x30002314,   // hr.sv.un_220 yo.lg.ha_643  fr.jw.un_440 ky.uz.un_660 
  0x09006408, 0x594b550d, 0x21105e08, 0x79030908,   // lg.pl.un_430 rw.mi.rn_554  ts.lt.jw_443 pl.nl.war_443 
  // [c0c0]
  0x04494b13, 0x15252307, 0x30002e0c, 0x05000b05,   // mi.to.fi_665 ky.mn.un_432  fo.uz.un_530 es.fr.un_330 
  0x570204a4, 0x470410af, 0x0a071555, 0x01635e04,   // fi.da.na_433 lt.fi.sn_655  un.bg.mk_442 ts.sco.en_332 
  0x1000020c, 0x56420507, 0x33001502, 0x353409ee,   // da.lt.un_530 fr.co.mg_432  un.nn.un_220 pl.xh.zu_422 
  0x341228ad, 0x1b00420e, 0x4d5851a9, 0x13000704,   // sd.ur.ps_643 co.tr.un_550  kl.om.aa_544 it.et.un_320 
  // [c0d0]
  0x645851a9, 0xfe51540c, 0x033b58ad, 0x51584baf,   // kl.om.lg_544 ik.kl.tlh_543  om.so.nl_643 mi.om.kl_655 
  0x1b004204, 0x585130a4, 0x3b1358ec, 0x645a5813,   // co.tr.un_320 uz.kl.om_433  om.et.so_644 om.sm.lg_665 
  0x6458510d, 0x1d0311a4, 0x123d300c, 0x10000209,   // kl.om.lg_554 ro.nl.la_433  uz.ku.ur_543 da.lt.un_440 
  0x4d005822, 0x1b423107, 0x2b2401ee, 0x3534180c,   // om.aa.un_870 az.co.tr_432  en.eo.vi_422 ga.xh.zu_543 
  // [c0e0]
  0x3b4c585a, 0x3f04130c, 0x1b0242a4, 0x30122107,   // om.wo.so_553 et.fi.af_543  co.da.tr_433 fa.ur.uz_432 
  0x4c64580c, 0x17003108, 0x5851150d, 0x111b420c,   // om.lg.wo_543 az.sr.un_430  un.kl.om_554 co.tr.ro_543 
  0x2b002802, 0x134d58ac, 0x1351580c, 0x042f510c,   // sw.vi.un_220 om.aa.et_632  om.kl.et_543 kl.su.fi_543 
  0x2b3435a9, 0x583b51ad, 0x3435fc12, 0x303748a0,   // zu.xh.vi_544 kl.so.om_643  zzp.zu.xh_654 tt.ba.uz_322 
  // [c0f0]
  0x08073c0c, 0x25001908, 0x43020107, 0x1700151a,   // ug.bg.uk_543 gl.eu.un_430  en.da.ie_432 un.sr.un_760 
  0x1504085a, 0x2e242da0, 0x10000a07, 0x24002e02,   // uk.ru.un_553 sk.eo.fo_322  mk.be.un_420 fo.eo.un_220 
  0x0e5d0307, 0x3b001221, 0x512e02a0, 0x130d1c0c,   // nl.ss.is_432 ur.ks.un_860  da.fo.kl_322 mr.ne.bh_543 
  0x3f0f0305, 0x2515110c, 0x56033f08, 0x2a0425af,   // nl.lv.af_333 ro.mn.un_530  af.nl.mg_443 eu.fi.mt_655 
  // [c100]
  0x150736a4, 0x2a002408, 0x551d0507, 0x18011208,   // ab.bg.un_433 eo.mt.un_430  fr.la.rw_432 ur.iw.ar_443 
  0x04101709, 0x0f5f2da4, 0x041107a4, 0x213d44a6,   // sr.be.ru_444 sk.tn.lv_433  bg.ro.ru_433 kk.ku.fa_521 
  0x3000fe13, 0x355dfaee, 0x59346708, 0x24004608,   // tlh.uz.un_650 nr.ss.zu_422  ak.xh.rn_443 qu.eo.un_430 
  0x151d39ad, 0x1d7567a7, 0x084410a9, 0x04001511,   // br.la.un_643 ak.nso.la_532  be.kk.uk_544 un.ru.un_630 
  // [c110]
  0x2d0d2a0c, 0x2d0d34a4, 0x11234460, 0x5c003007,   // mt.cs.sk_543 xh.cs.sk_433  kk.ky.ro_664 uz.sa.un_420 
  0x043044a4, 0x21642f07, 0x5c002109, 0x17100702,   // kk.uz.ru_433 su.lg.jw_432  jw.sa.un_440 bg.be.sr_222 
  0x3c4838af, 0x1c130dee, 0x35300405, 0x44233ca0,   // tk.tt.ug_655 ne.bh.mr_422  ru.uz.tg_333 ug.ky.kk_322 
  0x4b001b05, 0x6b5f45a4, 0x123d2105, 0x1504110d,   // tr.mi.un_330 ln.tn.ceb_433  fa.ku.ur_333 ro.ru.un_554 
  // [c120]
  0x65534c04, 0x354c5c07, 0x3900100b, 0x455f370c,   // wo.ht.gv_332 sa.wo.zu_432  lt.br.un_520 st.tn.ln_543 
  0x69025c05, 0x374804af, 0x1c5c0908, 0x2d0d73ee,   // sa.da.mfe_333 ru.tt.ba_655  hi.sa.mr_443 ny.cs.sk_422 
  0x79007312, 0x21442355, 0x3600440e, 0x190b3002,   // ny.war.un_640 ky.kk.fa_442  kk.ab.un_550 uz.es.gl_222 
  0x4c4739a4, 0x0957730c, 0x34677311, 0x7660380d,   // br.sn.wo_433 ny.na.pl_543  ny.ak.xh_653 tk.vo.crs_554 
  // [c130]
  0x084837a0, 0x383744a9, 0x36001523, 0x37000407,   // ba.tt.uk_322 kk.ba.tk_544  un.ab.un_880 ru.ba.un_420 
  0x10041504, 0x28006807, 0x46301d04, 0x1b00040d,   // un.ru.be_332 ig.sw.un_420  la.uz.qu_332 fi.tr.un_540 
  0x074258ad, 0x35007312, 0x58000419, 0x25002f13,   // om.co.it_643 ny.zu.un_640  fi.om.un_750 su.eu.un_650 
  0x685e450c, 0x1230340e, 0x0700581a, 0x2c006213,   // ln.ts.ig_543 ps.uz.ur_555  om.it.un_760 kha.fy.un_650 
  // [c140]
  0x02496855, 0x25441504, 0x44303508, 0x1100170e,   // ig.to.da_442 un.kk.mn_332  tg.uz.kk_443 sr.ro.un_550 
  0x4c007322, 0x2e0e0412, 0x566857ec, 0x2f1d26a4,   // ny.wo.un_870 fi.is.fo_654  na.ig.mg_644 ia.la.su_433 
  0x644853a4, 0x55561b02, 0x581b04a7, 0x26002913,   // ht.tt.lg_433 tr.mg.rw_222  fi.tr.om_532 sl.ia.un_650 
  0x3f2f030c, 0x5f751212, 0x0d165307, 0x221c1ead,   // nl.su.af_543 hu.nso.tn_654  ht.hr.cs_432 ms.id.oc_643 
  // [c150]
  0x355d4da9, 0x57375e0d, 0x40595555, 0x324002a7,   // aa.ss.zu_544 ts.st.na_554  rw.rn.lb_442 da.lb.bs_532 
  0x062c0302, 0x25646aa4, 0x483825af, 0x2d101c07,   // nl.fy.de_222 haw.lg.eu_433  eu.tk.tt_655 id.lt.sk_432 
  0x345964ee, 0x35123407, 0xfe595505, 0x34005605,   // lg.rn.xh_422 xh.hu.zu_432  rw.rn.tlh_333 mg.xh.un_330 
  0x5d5648a0, 0x64251da0, 0x682657a9, 0x796b4a0c,   // tt.mg.ss_322 la.eu.lg_322  na.ia.ig_544 yo.ceb.war_543 
  // [c160]
  0x564a64a7, 0x3b00650b, 0x6500fe14, 0x3b6458a7,   // lg.yo.mg_532 gv.so.un_520  tlh.gv.un_660 om.lg.so_532 
  0x0260fea7, 0x6bfc1dee, 0x65267307, 0x3f2e0ead,   // tlh.vo.da_532 la.zzp.ceb_422  ny.ia.gv_432 is.fo.af_643 
  0x390106a7, 0x3530235a, 0x681e1da4, 0x566548ee,   // de.en.br_532 ky.uz.tg_553  la.ms.ig_433 tt.gv.mg_422 
  0x0e602eaf, 0x31020e07, 0x4c156507, 0x19005907,   // fo.vo.is_655 is.da.az_432  gv.wo.un_420 rn.gl.un_420 
  // [c170]
  0x481b30a0, 0x443023ee, 0x040807a7, 0x65736312,   // uz.tr.tt_322 ky.uz.kk_422  bg.uk.ru_532 sco.ny.gv_654 
  0x5e003004, 0x0c045b07, 0x5a005c0d, 0x2579300c,   // uz.ts.un_320 sg.fi.sv_432  sa.sm.un_540 uz.war.eu_543 
  0x38fe240d, 0x5c6b5308, 0x53006504, 0x49006a12,   // eo.tlh.tk_554 ht.ceb.sa_443  gv.ht.un_320 haw.to.un_640 
  0x690e2eaf, 0x5a1f490e, 0x2d000a02, 0x23381008,   // fo.is.mfe_655 to.cy.sm_555  pt.sk.un_220 be.tk.ky_443 
  // [c180]
  0x6b00380d, 0x2ffe6255, 0x73001205, 0x1a6bfe08,   // tk.ceb.un_540 kha.tlh.su_442  hu.ny.un_330 tlh.ceb.tl_443 
  0x1700250c, 0x043302a9, 0x44303607, 0x12000212,   // mn.sr.un_530 da.nn.fi_544  ab.uz.kk_432 da.hu.un_640 
  0x0200120d, 0x2f2e2ba0, 0x10004c07, 0x12386b5a,   // hu.da.un_540 vi.fo.su_322  wo.lt.un_420 ceb.tk.hu_553 
  0x2e042aa0, 0x3008100c, 0x0a07175a, 0xfc016314,   // mt.fi.fo_322 be.uk.uz_543  sr.bg.mk_553 sco.en.zzp_666 
  // [c190]
  0x0469760d, 0x32090d0c, 0x02651d0c, 0x032508a9,   // crs.mfe.fi_554 cs.pl.bs_543  la.gv.da_543 no.eu.nl_544 
  0x190a01a4, 0x012243ee, 0x44373ca9, 0x0325090c,   // en.pt.gl_433 ie.oc.en_422  ug.ba.kk_544 pl.eu.nl_543 
  0x574e01ee, 0x48233507, 0x3e004202, 0x233c44a0,   // en.ay.na_422 tg.ky.tt_432  co.rm.un_220 kk.ug.ky_322 
  0x1d1708a4, 0x234837ad, 0x3e1dfcaf, 0x02000208,   // no.sr.la_433 ba.tt.ky_643  zzp.la.rm_655 da.da.un_430 
  // [c1a0]
  0x151715ad, 0x04483708, 0x250408a9, 0x55573455,   // un.sr.un_643 ba.tt.ru_443  uk.ru.mn_544 xh.na.rw_442 
  0x3c3611a9, 0x62005113, 0x46133fee, 0x2c7334a4,   // ro.ab.ug_544 kl.kha.un_650  af.et.qu_422 xh.ny.fy_433 
  0x3e004209, 0x041e48a0, 0x34000413, 0x34180155,   // co.rm.un_440 tt.ms.fi_322  fi.xh.un_650 iw.ar.ps_442 
  0x213c3da0, 0x2f005302, 0x5e393412, 0x330820a0,   // ku.ug.fa_322 ht.su.un_220  xh.br.ts_654 sq.no.nn_322 
  // [c1b0]
  0x10351505, 0x0a304813, 0x1b1224ad, 0x24321702,   // un.tg.be_333 tt.uz.mk_665  eo.hu.tr_643 sr.bs.eo_222 
  0x2d0d0fa4, 0x30005804, 0x21000302, 0x28201008,   // lv.cs.sk_433 om.uz.un_320  nl.jw.un_220 lt.sq.sw_443 
  0x17001609, 0x1500230b, 0x102804ad, 0x42011fee,   // hr.sr.un_440 ky.un.un_520  fi.sw.lt_643 cy.en.co_422 
  0x475d130d, 0x224010a0, 0x49000409, 0x27003407,   // et.ss.sn_554 lt.lb.oc_322  fi.to.un_440 xh.gd.un_420 
  // [c1c0]
  0x734b5507, 0x4a005408, 0x5a006a0c, 0x2f122104,   // rw.mi.ny_432 ik.yo.un_430  haw.sm.un_530 jw.hu.su_332 
  0x42072a0d, 0x5a5545a4, 0x523e10a7, 0x28001a0c,   // mt.it.co_554 ln.rw.sm_433  lt.rm.ha_532 tl.sw.un_530 
  0x3800441b, 0x483036a0, 0x08100402, 0x3f0b2c02,   // kk.tk.un_770 gn.uz.tt_322  ru.be.uk_222 fy.es.af_222 
  0x0f242012, 0x070a3807, 0x071004af, 0x2200fe02,   // sq.eo.lv_654 tk.mk.bg_432  fi.lt.it_655 tlh.oc.un_220 
  // [c1d0]
  0x135028a4, 0x40000404, 0x06690ca4, 0xfc0315ee,   // sw.fj.et_433 fi.lb.un_320  sv.mfe.de_433 un.nl.zzp_422 
  0x645e5007, 0x102344ee, 0x2425530e, 0x34302804,   // fj.ts.lg_432 kk.ky.be_422  ht.eu.eo_555 sd.uz.ps_332 
  0x31585ba9, 0x525d4c0e, 0x02113ba4, 0x1d004205,   // sg.om.az_544 wo.ss.ha_555  so.ro.da_433 co.la.un_330 
  0x024659a7, 0x3b5b5112, 0x28642fa4, 0x07151d55,   // rn.qu.da_532 kl.sg.so_654  su.lg.sw_433 la.it.un_420 
  // [c1e0]
  0x041536a0, 0x3b005112, 0x072145a9, 0x25324207,   // ab.ru.un_320 kl.so.un_640  ln.jw.it_544 co.bs.eu_432 
  0x6b00452a, 0x3b001c02, 0x35344aa0, 0x204260af,   // ln.ceb.un_970 id.so.un_220  yo.xh.zu_322 vo.co.sq_655 
  0x4a0165ee, 0xfe4c59a4, 0x635065ad, 0x2500580c,   // gv.en.yo_422 rn.wo.tlh_433  gv.fj.sco_643 om.eu.un_530 
  0x2f00590e, 0x2f031c07, 0x0b004204, 0x17001107,   // rn.su.un_550 id.nl.su_432  co.es.un_320 ro.sr.un_420 
  // [c1f0]
  0x3b584daf, 0x18631504, 0x190b1102, 0x614c6bad,   // aa.om.so_655 un.sco.ga_332  ro.es.gl_222 ceb.wo.za_643 
  0x38374408, 0x353459a4, 0x763553ec, 0x5955fe14,   // kk.ba.tk_443 rn.xh.zu_433  ht.zu.crs_644 tlh.rw.rn_666 
  0x12303d04, 0x3b584da4, 0x2a007302, 0x150737a4,   // ku.uz.ur_332 aa.om.so_433  ny.mt.un_220 ba.bg.un_433 
  0x011e6502, 0x51004d19, 0x421d07a9, 0x4d5902a4,   // gv.ms.en_222 aa.kl.un_750  it.la.co_544 da.rn.aa_433 
  // [c200]
  0x5d04130c, 0x353458a4, 0x251351ac, 0x5400511a,   // et.fi.ss_543 om.xh.zu_433  kl.et.eu_632 kl.ik.un_760 
  0x23001502, 0x3b514da7, 0x2a005805, 0x42071c07,   // un.ca.un_220 aa.kl.so_532  om.mt.un_330 id.it.co_432 
  0x100701a4, 0x51003b12, 0x1c59fea7, 0x3b00511a,   // en.it.lt_433 so.kl.un_640  tlh.rn.id_532 kl.so.un_760 
  0x5d3216a7, 0x2f321502, 0x3b005120, 0x131d63af,   // hr.bs.ss_532 un.bs.su_222  kl.so.un_850 sco.la.et_655 
  // [c210]
  0x0e001812, 0x46005f13, 0x024830a4, 0x38003c09,   // ga.is.un_640 tn.qu.un_650  uz.tt.da_433 ug.tk.un_440 
  0x163275a9, 0x042a1baf, 0x20004813, 0x1b3012ec,   // nso.bs.hr_544 tr.mt.fi_655  tt.sq.un_650 ur.uz.pa_644 
  0x30151512, 0xfc003022, 0x18005807, 0x12002307,   // un.uz.un_640 uz.zzp.un_870  om.ga.un_420 ca.hu.un_420 
  0x5838fc0c, 0x071d5804, 0x12303b07, 0x443035af,   // zzp.tk.om_543 om.la.it_332  ks.uz.ur_432 tg.uz.kk_655 
  // [c220]
  0x581307a0, 0x5000451a, 0x3400232a, 0x50375fa7,   // it.et.om_322 ln.fj.un_760  ky.ps.un_970 tn.st.fj_532 
  0x64591cee, 0x09fc0412, 0x64003702, 0x2f007908,   // id.rn.lg_422 fi.zzp.pl_654  st.lg.un_220 war.su.un_430 
  0x52005a02, 0x506e230c, 0x537669ec, 0x150a1704,   // sm.ha.un_220 ca.hmn.fj_543  mfe.crs.ht_644 sr.mk.un_332 
  0x10646aa0, 0x48001f0c, 0x12006b07, 0x5d004518,   // haw.lg.lt_322 cy.tt.un_530  ceb.hu.un_420 ln.ss.un_740 
  // [c230]
  0x2a005e08, 0x3e2223af, 0x21183409, 0x5500671a,   // ts.mt.un_430 ca.oc.rm_655  ps.ar.fa_444 ak.rw.un_760 
  0x1a126b07, 0x2c33085a, 0x672a2d07, 0x170835a9,   // ceb.hu.tl_432 no.nn.fy_553  sk.mt.ak_432 tg.uk.sr_544 
  0x356425a7, 0x64372dad, 0x1f004002, 0x24002311,   // eu.lg.zu_532 sk.st.lg_643  lb.cy.un_220 ca.eo.un_630 
  0x6e35340d, 0x32000f0e, 0x04483704, 0x110a1708,   // xh.zu.hmn_554 lv.bs.un_550  ba.tt.ru_332 sr.mk.ro_443 
  // [c240]
  0x123d215a, 0x18783704, 0x73002121, 0x5f3701a4,   // fa.ku.ur_553 st.ve.ga_332  jw.ny.un_860 en.st.tn_433 
  0x440a17af, 0x3400fc0c, 0x3534010c, 0x461e1c04,   // sr.mk.kk_655 zzp.xh.un_530  en.xh.zu_543 id.ms.qu_332 
  0x12213005, 0x63607308, 0x78007308, 0x48311b02,   // uz.fa.ur_333 ny.vo.sco_443  ny.ve.un_430 tr.az.tt_222 
  0x07440404, 0x27631808, 0x373c44ad, 0x20007314,   // ru.kk.bg_332 ga.sco.gd_443  kk.ug.ba_643 ny.sq.un_660 
  // [c250]
  0x03003404, 0x3700350d, 0x78733555, 0x0d162904,   // xh.nl.un_320 zu.st.un_540  zu.ny.ve_442 sl.hr.cs_332 
  0x02002318, 0x2f21560c, 0x53283607, 0x2f0e4509,   // ca.da.un_740 mg.jw.su_543  gn.sw.ht_432 ln.is.su_444 
  0x6b1a1dec, 0x6301fc04, 0x34122860, 0x090c530c,   // la.tl.ceb_644 zzp.en.sco_332  sd.ur.ps_664 ht.sv.pl_543 
  0x11071760, 0x17000f05, 0x282ffca4, 0x5f00500d,   // sr.bg.ro_664 lv.sr.un_330  zzp.su.sw_433 fj.tn.un_540 
  // [c260]
  0x041715a9, 0x671d08a0, 0x35043009, 0x1d681ea4,   // un.sr.ru_544 no.la.ak_322  uz.ru.tg_444 ms.ig.la_433 
  0x330402a0, 0x38151da4, 0x34003e12, 0x00006b2d,   // da.fi.nn_322 la.tk.un_430  rm.xh.un_640 ceb.un.un_A00 
  0x53001304, 0x3b5c0204, 0x375f6712, 0x2a004504,   // et.ht.un_320 da.sa.so_332  ak.tn.st_654 ln.mt.un_320 
  0x3e364007, 0x28486ea4, 0x12213d11, 0x456b010c,   // lb.gn.rm_432 hmn.tt.sw_433  ku.fa.ur_653 en.ceb.ln_543 
  // [c270]
  0x060e6107, 0x38400907, 0x18052002, 0x203545a7,   // za.is.de_432 pl.lb.tk_432  sq.fr.ga_222 ln.zu.sq_532 
  0x25fc450c, 0x02021504, 0x370e0605, 0x4a003405,   // ln.zzp.eu_543 un.da.da_332  de.is.st_333 xh.yo.un_330 
  0x480f100c, 0x68021d07, 0xfc021d04, 0x0e1f40ee,   // lt.lv.tt_543 la.da.ig_432  la.da.zzp_332 lb.cy.is_422 
  0x02004905, 0x0f330e05, 0x3f020308, 0x092910a6,   // to.da.un_330 is.nn.lv_333  nl.da.af_443 lt.sl.pl_521 
  // [c280]
  0x051b310c, 0x1d55fc09, 0x0e0657a4, 0x06796b08,   // az.tr.fr_543 zzp.rw.la_444  na.de.is_433 ceb.war.de_443 
  0x21003b07, 0x391c2102, 0x1b001d02, 0x20003504,   // ks.fa.un_420 jw.id.br_222  la.tr.un_220 zu.sq.un_320 
  0x5e3e22a0, 0x0c003e02, 0x074201a0, 0x240e5c04,   // oc.rm.ts_322 rm.sv.un_220  en.co.it_322 sa.is.eo_332 
  0x10006119, 0x112923ee, 0x5d353460, 0x48312a0d,   // za.lt.un_750 ca.sl.ro_422  xh.zu.ss_664 mt.az.tt_554 
  // [c290]
  0x44171504, 0x33480e0c, 0x21763f04, 0x04005a0b,   // un.sr.kk_332 is.tt.nn_543  af.crs.jw_332 sm.fi.un_520 
  0x33060e55, 0x130e100c, 0x065c65ad, 0x3e1001a4,   // is.de.nn_442 lt.is.et_543  gv.sa.de_643 en.lt.rm_433 
  0x3c2538a4, 0x0e003809, 0x6b021504, 0x27465a04,   // tk.mn.ug_433 tk.is.un_440  un.da.ceb_332 sm.qu.gd_332 
  0x4b6a475a, 0x15170855, 0x69761c0c, 0x6b366aa6,   // sn.haw.mi_553 uk.sr.un_442  id.crs.mfe_543 haw.gn.ceb_521 
  // [c2a0]
  0x1a6b1ca0, 0x2f5f375a, 0x46621e0c, 0x17291aa9,   // id.ceb.tl_322 st.tn.su_553  ms.kha.qu_543 tl.sl.sr_544 
  0x2100460d, 0x4b4e6aa7, 0x345b4eac, 0x1a1e1c14,   // qu.jw.un_540 haw.ay.mi_532  ay.sg.xh_632 id.ms.tl_666 
  0x6b251a04, 0x0e102eee, 0x0d004802, 0x75003722,   // tl.eu.ceb_332 fo.lt.is_422  tt.cs.un_220 st.nso.un_870 
  0x2e0e0f07, 0x253039a9, 0x1a5a5fa0, 0x13004e14,   // lv.is.fo_432 br.uz.eu_544  tn.sm.tl_322 ay.et.un_660 
  // [c2b0]
  0x5900690e, 0x1b00462b, 0x2f001e0e, 0x04130f0c,   // mfe.rn.un_550 qu.tr.un_980  ms.su.un_550 lv.et.fi_543 
  0x304838ee, 0x222324ec, 0x69fe76af, 0x0e2e0f04,   // tk.tt.uz_422 eo.ca.oc_644  crs.tlh.mfe_655 lv.fo.is_332 
  0x1a3846a9, 0x55641a04, 0x31fe4614, 0x331ffca0,   // qu.tk.tl_544 tl.lg.rw_332  qu.tlh.az_666 zzp.cy.nn_322 
  0x47000421, 0x4700361a, 0x47287360, 0x32172902,   // fi.sn.un_860 gn.sn.un_760  ny.sw.sn_664 sl.sr.bs_222 
  // [c2c0]
  0x49004e08, 0x27004b02, 0x15002302, 0x5a024b11,   // ay.to.un_430 mi.gd.un_220  ca.un.un_220 mi.da.sm_653 
  0x100e2e12, 0x231548ec, 0x0a0430ee, 0x250e10a7,   // fo.is.lt_654 tt.ky.un_640  uz.ru.mk_422 lt.is.eu_532 
  0x233836ec, 0x18211204, 0x2d1629a7, 0x233538a6,   // ab.tk.ky_644 ur.fa.ar_332  sl.hr.sk_532 tk.tg.ky_521 
  0x2c2a0304, 0x21000f04, 0x631501a4, 0x1f4a02a0,   // nl.mt.fy_332 lv.jw.un_320  en.sco.un_430 da.yo.cy_322 
  // [c2d0]
  0x04000207, 0x20003014, 0x0b594a07, 0x63002e19,   // da.fi.un_420 uz.sq.un_660  yo.rn.es_432 fo.sco.un_750 
  0x16290ea0, 0x203238a0, 0x04002405, 0x21002004,   // is.sl.hr_322 tk.bs.sq_322  eo.fi.un_330 sq.jw.un_320 
  0x17150a0c, 0x02005f13, 0x2b002004, 0x48374413,   // mk.sr.un_530 tn.da.un_650  sq.vi.un_320 kk.ba.tt_665 
  0x36004f23, 0x63653ea4, 0x150430a4, 0x36006507,   // bi.gn.un_880 rm.gv.sco_433  uz.ru.un_433 gv.gn.un_420 
  // [c2e0]
  0x090230a9, 0x1300fc0d, 0x041015a9, 0x262453a4,   // uz.da.pl_544 zzp.et.un_540  un.be.ru_544 ht.eo.ia_433 
  0x051501a4, 0x30002409, 0x1f246260, 0x34067907,   // en.fr.un_430 eo.uz.un_440  kha.eo.cy_664 war.de.xh_432 
  0x10205c0c, 0x166320ee, 0x63150107, 0x4f594604,   // sa.sq.lt_543 sq.sco.hr_422  en.sco.un_420 qu.rn.bi_332 
  0x48234455, 0x5a00650c, 0x0a006505, 0x12002d14,   // kk.ky.tt_442 gv.sm.un_530  gv.pt.un_330 sk.hu.un_660 
  // [c2f0]
  0x5300650b, 0x12002d19, 0x0b004208, 0x08070aa0,   // gv.ht.un_520 sk.hu.un_750  co.es.un_430 mk.bg.uk_322 
  0x12002d21, 0x18122db6, 0x3500fa1a, 0x043015a0,   // sk.hu.un_860 sk.hu.ga_766  nr.zu.un_760 un.uz.ru_322 
  0x06000404, 0x17003902, 0x0f0622ee, 0x34003518,   // fi.de.un_320 br.sr.un_220  oc.de.lv_422 zu.xh.un_740 
  0x1c5c0d13, 0x5c0d090b, 0x150407ad, 0x24003604,   // ne.sa.mr_665 hi.ne.sa_542  bg.ru.un_643 gn.eo.un_320 
  // [c300]
  0x08022ea0, 0x370823a0, 0x38303cec, 0x211228ee,   // fo.da.no_322 ky.uk.ba_322  ug.uz.tk_644 sd.ur.fa_422 
  0x03000605, 0x36001902, 0x1300fe12, 0x3f03fcee,   // de.nl.un_330 gl.gn.un_220  tlh.et.un_640 zzp.nl.af_422 
  0x0d130205, 0x30001308, 0x3735fa11, 0x03fc3f12,   // da.et.cs_333 et.uz.un_430  nr.zu.st_653 af.zzp.nl_654 
  0x1b313855, 0x30136e04, 0x130cfe09, 0x05461dad,   // tk.az.tr_442 hmn.et.uz_332  tlh.sv.et_444 la.qu.fr_643 
  // [c310]
  0x13fe4212, 0xfc730111, 0x190bfe02, 0x23303ca4,   // co.tlh.et_654 en.ny.zzp_653  tlh.es.gl_222 ug.uz.ky_433 
  0x06fc0107, 0x23001d0b, 0x46033fa4, 0x132dfea7,   // en.zzp.de_432 la.ca.un_520  af.nl.qu_433 tlh.sk.et_532 
  0x0b001913, 0x3f00fc0c, 0x190b0a0c, 0x46001d0d,   // gl.es.un_650 zzp.af.un_530  pt.es.gl_543 la.qu.un_540 
  0x6e00020e, 0x255646a0, 0x30fe60a4, 0x2e000607,   // da.hmn.un_550 qu.mg.eu_322  vo.tlh.uz_433 de.fo.un_420 
  // [c320]
  0x12341804, 0x051d2208, 0x3013feee, 0xfc006312,   // ar.ps.ur_332 oc.la.fr_443  tlh.et.uz_422 sco.zzp.un_640 
  0x46fc1d07, 0x651dfc55, 0x0b001207, 0x0a231dee,   // la.zzp.qu_432 zzp.la.gv_442  hu.es.un_420 la.ca.pt_422 
  0x0b005104, 0x4600fe0c, 0x5100620e, 0x64003202,   // kl.es.un_320 tlh.qu.un_530  kha.kl.un_550 bs.lg.un_220 
  0x36002e02, 0x110736ec, 0x7900400e, 0x251508af,   // fo.gn.un_220 ab.bg.ro_644  lb.war.un_550 uk.mn.un_650 
  // [c330]
  0x07233812, 0x48233708, 0x0f001508, 0xfc4603ad,   // tk.ky.bg_654 ba.ky.tt_443  un.lv.un_430 nl.qu.zzp_643 
  0x301a49a4, 0x35375ead, 0x444836a9, 0x15000122,   // to.tl.uz_433 ts.st.zu_643  ab.tt.kk_544 en.un.un_870 
  0x23001f18, 0x233d4404, 0x0f1001a0, 0xfc45010c,   // cy.ca.un_740 kk.ku.ky_332  en.lt.lv_322 en.ln.zzp_543 
  0x4f00010d, 0x0911650c, 0x043530a4, 0x6500200c,   // en.bi.un_540 gv.ro.pl_543  uz.tg.ru_433 sq.gv.un_530 
  // [c340]
  0x030d200c, 0x21005d05, 0x60347305, 0x35152509,   // sq.cs.nl_543 ss.jw.un_330  ny.xh.vo_333 mn.tg.un_440 
  0x21183455, 0x0417150b, 0x0e002c05, 0x3e471355,   // ps.ar.fa_442 un.sr.ru_542  fy.is.un_330 et.sn.rm_442 
  0x121834a7, 0x17001521, 0x170710a4, 0x350430a7,   // ps.ar.ur_532 un.sr.un_860  be.bg.sr_433 uz.ru.tg_532 
  0x12182114, 0x30250a0c, 0x3507300e, 0x37104805,   // fa.ar.ur_666 mk.mn.uz_543  uz.bg.tg_555 tt.be.ba_333 
  // [c350]
  0x201b310d, 0x0430110c, 0x24004604, 0x44001b14,   // az.tr.sq_554 ro.uz.ru_543  qu.eo.un_320 pa.kk.un_660 
  0x04733608, 0x5c7336a7, 0x343935ee, 0x2c002e02,   // gn.ny.fi_443 gn.ny.sa_532  zu.br.xh_422 fo.fy.un_220 
  0x37361504, 0x48003c1b, 0x51006404, 0x02341a0c,   // un.ab.ba_332 ug.tt.un_770  lg.kl.un_320 tl.xh.da_543 
  0x34182102, 0x15001505, 0x4000fc07, 0x04002209,   // fa.ar.ps_222 un.un.un_330  zzp.lb.un_420 oc.fi.un_440 
  // [c360]
  0x0d5c1302, 0x3e004807, 0x23101d0c, 0x6b791fad,   // bh.sa.ne_222 tt.rm.un_420  la.lt.ca_543 cy.war.ceb_643 
  0x2e002c02, 0x20243902, 0x47001f07, 0x1a002407,   // fy.fo.un_220 br.eo.sq_222  cy.sn.un_420 eo.tl.un_420 
  0x4423340b, 0x24000d04, 0x30483ca7, 0x21003905,   // ps.ky.kk_542 cs.eo.un_320  ug.tt.uz_532 br.jw.un_330 
  0x1b1f1a04, 0x19483eee, 0x241f22ec, 0x5f376a0c,   // tl.cy.tr_332 rm.tt.gl_422  oc.cy.eo_644 haw.st.tn_543 
  // [c370]
  0x24000f19, 0x15fc620d, 0x4a2e0eaf, 0x30162907,   // lv.eo.un_750 kha.zzp.un_554  is.fo.yo_655 sl.hr.uz_432 
  0x505c36ad, 0x53003e04, 0x4a007918, 0x462069a0,   // gn.sa.fj_643 rm.ht.un_320  war.yo.un_740 mfe.sq.qu_322 
  0x11044755, 0x30213409, 0x04430dee, 0x58645502,   // sn.fi.ro_442 ps.fa.uz_444  cs.ie.fi_422 rw.lg.om_222 
  0x1d0f10ee, 0x5536450d, 0x4c455fee, 0x360a07a0,   // lt.lv.la_422 ln.gn.rw_554  tn.ln.wo_422 bg.mk.ab_322 
  // [c380]
  0x4a006822, 0x4a3f030c, 0x475e6007, 0x15002504,   // ig.yo.un_870 nl.af.yo_543  vo.ts.sn_432 eu.un.un_320 
  0x5f3775af, 0x36004508, 0x1d0f3e0c, 0x05651004,   // nso.st.tn_655 ln.gn.un_430  rm.lv.la_543 lt.gv.fr_332 
  0x043c3007, 0x0e3e61ee, 0x1000110d, 0x53204c04,   // uz.ug.ru_432 za.rm.is_422  ro.be.un_540 wo.sq.ht_332 
  0x35345502, 0x65630104, 0x452847af, 0x494a4ca4,   // rw.xh.zu_222 en.sco.gv_332  sn.sw.ln_655 wo.yo.to_433 
  // [c390]
  0x62016304, 0x5c002812, 0x5e000a0e, 0x070a23a4,   // sco.en.kha_332 sw.sa.un_640  pt.ts.un_550 ky.mk.bg_433 
  0x3e1d69ee, 0x53027304, 0x06002407, 0x5a004d0d,   // mfe.la.rm_422 ny.da.ht_332  eo.de.un_420 aa.sm.un_540 
  0x3c3811ec, 0x112a010b, 0x49642805, 0x3c043604,   // ro.tk.ug_644 en.mt.ro_542  sw.lg.to_333 ab.ru.ug_332 
  0x1d2052a0, 0x55422aa0, 0x5a1e1c04, 0x091c1312,   // ha.sq.la_322 mt.co.rw_322  id.ms.sm_332 bh.mr.hi_654 
  // [c3a0]
  0x0c060404, 0x4245490c, 0x13000208, 0x033f13ad,   // fi.de.sv_332 to.ln.co_543  da.et.un_430 et.af.nl_643 
  0x4b3e5a0b, 0x10054e0c, 0x21343005, 0x0f0e10a0,   // sm.rm.mi_542 ay.fr.lt_543  uz.ps.fa_333 lt.is.lv_322 
  0x4b244d11, 0x3f1f09a4, 0x3b4d6313, 0x3f650107,   // aa.eo.mi_653 pl.cy.af_433  sco.aa.so_665 en.gv.af_432 
  0x2f6761ad, 0x13400407, 0x02671d07, 0x2a003f04,   // za.ak.su_643 fi.lb.et_432  la.ak.da_432 af.mt.un_320 
  // [c3b0]
  0x631301a9, 0x033f65a9, 0x123718ee, 0x46215ca9,   // en.et.sco_544 gv.af.nl_544  ga.st.hu_422 sa.jw.qu_544 
  0x20004c09, 0x2818210c, 0x3d302111, 0x215b4e12,   // wo.sq.un_440 fa.ar.sd_543  fa.uz.ku_653 ay.sg.jw_654 
  0x375f01a4, 0x1a73270c, 0xfc005d09, 0x40353409,   // en.tn.st_433 gd.ny.tl_543  ss.zzp.un_440 xh.zu.lb_444 
  0x08100413, 0x18210107, 0x18271f08, 0x6327fcec,   // ru.be.uk_665 en.jw.ga_432  cy.gd.ga_443 zzp.gd.sco_644 
  // [c3c0]
  0x21780112, 0x73005c12, 0x015c270c, 0x5d5e780c,   // en.ve.jw_654 sa.ny.un_640  gd.sa.en_543 ve.ts.ss_543 
  0x5c730107, 0x20475ead, 0x20404c11, 0x350748ee,   // en.ny.sa_432 ts.sn.sq_643  wo.lb.sq_653 tt.bg.tg_422 
  0x53002702, 0x0c005a04, 0x0e005107, 0x48001705,   // gd.ht.un_220 sm.sv.un_320  kl.is.un_420 sr.tt.un_330 
  0x0e002c0d, 0x37080405, 0x0415105a, 0x234436ad,   // fy.is.un_540 ru.uk.ba_333  be.ru.un_530 ab.kk.ky_643 
  // [c3d0]
  0x3c35380d, 0x38003c2a, 0x30213460, 0x1f004702,   // tk.tg.ug_554 ug.tk.un_970  ps.fa.uz_664 sn.cy.un_220 
  0x0c332004, 0x02584c0d, 0x58044cad, 0x1a004c22,   // sq.nn.sv_332 wo.om.da_554  wo.fi.om_643 wo.tl.un_870 
  0x63136aad, 0x02036555, 0x134d3b14, 0x024c04a4,   // haw.et.sco_643 gv.nl.da_442  so.aa.et_666 fi.wo.da_433 
  0x65134c07, 0x2b0213ee, 0x583b4caf, 0x493f01a9,   // wo.et.gv_432 et.da.vi_422  wo.so.om_655 en.af.to_544 
  // [c3e0]
  0x18303408, 0x73004d08, 0x1a40470c, 0x3f034c0c,   // ps.uz.ar_443 aa.ny.un_430  sn.lb.tl_543 wo.nl.af_543 
  0x6a1a4caf, 0x3bfe4cec, 0x645559a9, 0x46001e04,   // wo.tl.haw_655 wo.tlh.so_644  rn.rw.lg_544 ms.qu.un_320 
  0x633f5808, 0x4c636512, 0x7936570d, 0x654c3b12,   // om.af.sco_443 gv.sco.wo_654  na.gn.war_554 so.wo.gv_654 
  0x4a4e1c14, 0x684a630c, 0x2f3b5812, 0x100830a0,   // id.ay.yo_666 sco.yo.ig_543  om.so.su_654 uz.uk.be_322 
  // [c3f0]
  0x1f001822, 0x6e64730c, 0x23000304, 0x031c4c0c,   // ga.cy.un_870 ny.lg.hmn_543  nl.ca.un_320 wo.id.nl_543 
  0x12342111, 0x3b002b05, 0x3f034c13, 0x3f044c0c,   // fa.ps.ur_653 vi.so.un_330  wo.nl.af_665 wo.fi.af_543 
  0x04070a11, 0x584c1a13, 0x58654c0c, 0x27044ca7,   // mk.bg.ru_653 tl.wo.om_665  wo.gv.om_543 wo.fi.gd_532 
  0x371d7307, 0x30002107, 0x733f030c, 0x0700300c,   // ny.la.st_432 fa.uz.un_420  nl.af.ny_543 uz.bg.un_530 
  
  // [c400]
  0x04381555, 0x20001802, 0x042210a7, 0x4b006504,   // un.tk.ru_442 ga.sq.un_220  lt.oc.fi_532 gv.mi.un_320 
  0x13104212, 0x3e6b1dee, 0x3e00101a, 0x28000102,   // co.lt.et_654 la.ceb.rm_422  lt.rm.un_760 en.sw.un_220 
  0x08481007, 0x10220512, 0x041707a7, 0x3e00100d,   // be.tt.uk_432 fr.oc.lt_654  bg.sr.ru_532 lt.rm.un_540 
  0x20002413, 0x3600100d, 0x05131eee, 0x0708100e,   // eo.sq.un_650 lt.gn.un_540  ms.et.fr_422 be.uk.bg_555 
  // [c410]
  0x79002708, 0x045a10ec, 0x06120cee, 0x273534a0,   // gd.war.un_430 lt.sm.fi_644  sv.hu.de_422 xh.zu.gd_322 
  0x32001723, 0x29000f21, 0x47000614, 0x08043505,   // sr.bs.un_880 lv.sl.un_860  de.sn.un_660 tg.ru.uk_333 
  0x4000470d, 0x0d00fc0c, 0x21283da4, 0x5b792705,   // sn.lb.un_540 zzp.cs.un_530  ku.sd.fa_433 gd.war.sg_333 
  0x1507170b, 0x0d003b08, 0x04005305, 0x30373c14,   // sr.bg.un_542 ks.ne.un_430  ht.fi.un_330 ug.ba.uz_666 
  // [c420]
  0x070a0812, 0x79595560, 0x21737808, 0x2a3b04ee,   // uk.mk.bg_654 rw.rn.war_664  ve.ny.jw_443 fi.so.mt_422 
  0x0c08330c, 0x03002108, 0x50003f04, 0x24002c05,   // nn.no.sv_543 jw.nl.un_430  af.fj.un_320 fy.eo.un_330 
  0x64fc120d, 0x13645007, 0x38000304, 0x58643faf,   // hu.zzp.lg_554 fj.lg.et_432  nl.tk.un_320 af.lg.om_655 
  0x2a00340d, 0x13001f07, 0x1d003e07, 0x375f39a7,   // xh.mt.un_540 cy.et.un_420  rm.la.un_420 br.tn.st_532 
  // [c430]
  0x3f2138ee, 0x3f382f02, 0x282a7307, 0x6313fc0c,   // tk.jw.af_422 su.tk.af_222  ny.mt.sw_432 zzp.et.sco_543 
  0x1e005913, 0x39766904, 0x0f004b05, 0x46004f04,   // rn.ms.un_650 mfe.crs.br_332  mi.lv.un_330 bi.qu.un_320 
  0x5a006a22, 0x303c3513, 0x040a080d, 0x21234412,   // haw.sm.un_870 tg.ug.uz_665  uk.mk.ru_554 kk.ky.fa_654 
  0x08041509, 0x100a070c, 0x235a1902, 0x0454480c,   // un.ru.uk_444 bg.mk.be_543  gl.sm.ca_222 tt.ik.fi_543 
  // [c440]
  0x0d002a19, 0x062a0411, 0x122404a0, 0x322a160c,   // mt.cs.un_750 fi.mt.de_653  fi.eo.hu_322 hr.mt.bs_543 
  0x030c0ea0, 0x311b2d07, 0x37003b05, 0x20001004,   // is.sv.nl_322 sk.tr.az_432  so.st.un_330 lt.sq.un_320 
  0x350810a4, 0x3f046007, 0x0415230c, 0x48152308,   // be.uk.tg_433 vo.fi.af_432  ky.ru.un_530 ky.tt.un_430 
  0x3f000905, 0x2a00121a, 0x5000fe0c, 0x34353708,   // pl.af.un_330 hu.mt.un_760  tlh.fj.un_530 st.zu.xh_443 
  // [c450]
  0x0c631f07, 0x345135a0, 0x2f003004, 0xfe002f05,   // cy.sco.sv_432 zu.kl.xh_322  uz.su.un_320 su.tlh.un_330 
  0x0d5c1cec, 0x08040a55, 0x3446350c, 0x013547a0,   // mr.sa.ne_644 mk.ru.uk_442  zu.qu.xh_543 sn.zu.en_322 
  0x091f2e12, 0x1e1c30ee, 0x120e2ea9, 0x3b001234,   // fo.cy.pl_654 uz.id.ms_422  fo.is.hu_544 ur.ks.un_A80 
  0x44001504, 0x102d0d13, 0x123d30a9, 0x090d1cac,   // un.kk.un_320 cs.sk.lt_665  uz.ku.ur_544 mr.ne.hi_632 
  // [c460]
  0x0c001f19, 0x38351508, 0x4b00100d, 0x301007ad,   // cy.sv.un_750 un.tg.tk_443  lt.mi.un_540 bg.be.uz_643 
  0x152325a7, 0x5c001c2c, 0x09002d12, 0x153c3608,   // mn.ky.un_532 mr.sa.un_990  sk.pl.un_640 ab.ug.un_443 
  0x246b7904, 0x120e2ea0, 0x02044d0c, 0x534756ad,   // war.ceb.eo_332 fo.is.hu_322  aa.fi.da_543 mg.sn.ht_643 
  0x041f60ee, 0x23007908, 0x1d002804, 0x64006713,   // vo.cy.fi_422 war.ca.un_430  sw.la.un_320 ak.lg.un_650 
  // [c470]
  0x47002d04, 0x6b2479a0, 0x212330ec, 0x1d004d0e,   // sk.sn.un_320 war.eo.ceb_322  uz.ky.fa_644 aa.la.un_550 
  0x40002204, 0x03004507, 0x0e00450c, 0x3e004c04,   // oc.lb.un_320 ln.nl.un_420  ln.is.un_530 wo.rm.un_320 
  0x3500670c, 0x1a1f79a0, 0x38443755, 0x53006b12,   // ak.zu.un_530 war.cy.tl_322  ba.kk.tk_442 ceb.ht.un_640 
  0x49604513, 0x59192108, 0x6400500e, 0x4b11780c,   // ln.vo.to_665 jw.gl.rn_443  fj.lg.un_550 ve.ro.mi_543 
  // [c480]
  0x35344712, 0x38521ea0, 0x5f003022, 0x1d5d3512,   // sn.xh.zu_654 ms.ha.tk_322  uz.tn.un_870 zu.ss.la_654 
  0x5f003004, 0x042513a0, 0x47006714, 0x30005f12,   // uz.tn.un_320 et.eu.fi_322  ak.sn.un_660 tn.uz.un_640 
  0x1c135ca9, 0x295f370b, 0x062e6e55, 0xfe005f13,   // sa.bh.mr_544 st.tn.sl_542  hmn.fo.de_442 tn.tlh.un_650 
  0x17383c12, 0x2555fa0c, 0x791d06a4, 0x0400350c,   // ug.tk.sr_654 nr.rw.eu_543  de.la.war_433 tg.ru.un_530 
  // [c490]
  0x337354ad, 0x5c134755, 0x2f00fe0c, 0x642f1ca4,   // ik.ny.nn_643 sn.et.sa_442  tlh.su.un_530 id.su.lg_433 
  0x25733812, 0x30fe5faf, 0x0a064905, 0x5d352705,   // tk.ny.eu_654 tn.tlh.uz_655  to.de.pt_333 gd.zu.ss_333 
  0x5c650602, 0x671a6ba4, 0x283b1211, 0x223905a0,   // de.gv.sa_222 ceb.tl.ak_433  ur.ks.sd_653 fr.br.oc_322 
  0x6e005c05, 0x5a4950a9, 0xfe5f30ad, 0x30005e09,   // sa.hmn.un_330 fj.to.sm_544  uz.tn.tlh_643 ts.uz.un_440 
  // [c4a0]
  0x190b2ea4, 0x1b00090c, 0xfe223055, 0x1c5c1311,   // fo.es.gl_433 pl.tr.un_530  uz.oc.tlh_442 bh.sa.mr_653 
  0x186301a7, 0x651d43a4, 0x09fe5fad, 0x066e3304,   // en.sco.ga_532 ie.la.gv_433  tn.tlh.pl_643 nn.hmn.de_332 
  0x16006908, 0x4b006313, 0x73065705, 0x47001107,   // mfe.hr.un_430 sco.mi.un_650  na.de.ny_333 ro.sn.un_420 
  0x6e06280c, 0x11fe6255, 0x61005419, 0x21005a02,   // sw.de.hmn_543 kha.tlh.ro_442  ik.za.un_750 sm.jw.un_220 
  // [c4b0]
  0x0c02620c, 0xfc496402, 0x02002707, 0x6500181b,   // kha.da.sv_543 lg.to.zzp_222  gd.da.un_420 ga.gv.un_770 
  0x040835a0, 0x61794fa9, 0x4735780c, 0x33003505,   // tg.uk.ru_322 bi.war.za_544  ve.zu.sn_543 zu.nn.un_330 
  0x28123dee, 0x45780911, 0x6400471a, 0xfc5d1fa0,   // ku.ur.sd_422 pl.ve.ln_653  sn.lg.un_760 cy.ss.zzp_322 
  0x396bfe07, 0x53003502, 0x55004519, 0x2e003819,   // tlh.ceb.br_432 zu.ht.un_220  ln.rw.un_750 tk.fo.un_750 
  // [c4c0]
  0x0c3802a4, 0x033f6508, 0x4f006313, 0x291239ad,   // da.tk.sv_433 gv.af.nl_443  sco.bi.un_650 br.hu.sl_643 
  0x38321602, 0x343568a7, 0x2344250d, 0x37003513,   // hr.bs.tk_222 ig.zu.xh_532  mn.kk.ky_554 zu.st.un_650 
  0x483853a0, 0x53370208, 0x35000a12, 0x47552804,   // ht.tk.tt_322 da.st.ht_443  pt.zu.un_640 sw.rw.sn_332 
  0x3500780c, 0x120e2e55, 0x44002119, 0x73005d0e,   // ve.zu.un_530 fo.is.hu_442  fa.kk.un_750 ss.ny.un_550 
  // [c4d0]
  0x6200640e, 0x73000605, 0x57645508, 0x5f7355a4,   // lg.kha.un_550 de.ny.un_330  rw.lg.na_443 rw.ny.tn_433 
  0x38041005, 0x0a4823a4, 0x391dfc08, 0x18004205,   // be.ru.tk_333 ky.tt.mk_433  zzp.la.br_443 co.ga.un_330 
  0x2d0d2e0c, 0x121b3811, 0x29002e0d, 0x1f2c3fa6,   // fo.cs.sk_543 tk.tr.hu_653  fo.sl.un_540 af.fy.cy_521 
  0x1f3f2ca0, 0x5c1c1307, 0x1a6b49a4, 0xfc5a3e02,   // fy.af.cy_322 bh.mr.sa_432  to.ceb.tl_433 rm.sm.zzp_222 
  // [c4e0]
  0x4c5320a0, 0x1f001e13, 0x285329a0, 0x241f0107,   // sq.ht.wo_322 ms.cy.un_650  sl.ht.sw_322 en.cy.eo_432 
  0x285868ee, 0x1e255fa0, 0x73001f12, 0x5d000107,   // ig.om.sw_422 tn.eu.ms_322  cy.ny.un_640 en.ss.un_420 
  0x240425a7, 0x1d003902, 0x122e0e0e, 0x242c1f0c,   // eu.fi.eo_532 br.la.un_220  is.fo.hu_555 cy.fy.eo_543 
  0x24001f19, 0x051f0107, 0x2300690c, 0x0f00fc1b,   // cy.eo.un_750 en.cy.fr_432  mfe.ca.un_530 zzp.lv.un_770 
  // [c4f0]
  0x3f1506a0, 0x39691fec, 0x12213411, 0x383c23a4,   // de.af.un_320 cy.mfe.br_644  ps.fa.ur_653 ky.ug.tk_433 
  0x0000222d, 0x270602a0, 0x36016304, 0x0e020fa9,   // oc.un.un_A00 da.de.gd_322  sco.en.gn_332 lv.da.is_544 
  0x203969a4, 0x36004705, 0x06403fa0, 0x222605af,   // mfe.br.sq_433 sn.gn.un_330  af.lb.de_322 fr.ia.oc_655 
  0x3605010c, 0x051501af, 0x24391fa9, 0x380407a4,   // en.fr.gn_543 en.fr.un_650  cy.br.eo_544 bg.ru.tk_433 
  // [c500]
  0x37483c05, 0x022404a0, 0x4400150c, 0x230a4802,   // ug.tt.ba_333 fi.eo.da_322  un.kk.un_530 tt.mk.ky_222 
  0x04153855, 0x2e06fc07, 0xfc000605, 0x13100ea4,   // tk.ru.un_420 zzp.de.fo_432  de.zzp.un_330 is.lt.et_433 
  0x2e006a08, 0x48233804, 0x134947a0, 0x03002b02,   // haw.fo.un_430 tk.ky.tt_332  sn.to.et_322 vi.nl.un_220 
  0x01635604, 0x2d0d38a0, 0x27002b08, 0x2b003807,   // mg.sco.en_332 tk.cs.sk_322  vi.gd.un_430 tk.vi.un_420 
  // [c510]
  0x5c0410a0, 0x50044907, 0x0e04060c, 0x0e041e07,   // lt.fi.sa_322 to.fi.fj_432  de.fi.is_543 ms.fi.is_432 
  0x2d0d0209, 0x2d6229af, 0x122f1d0b, 0x10233808,   // da.cs.sk_444 sl.kha.sk_655  la.su.hu_542 tk.ky.be_443 
  0x39115707, 0x53001205, 0x35253007, 0x00001d24,   // na.ro.br_432 hu.ht.un_330  uz.mn.tg_432 la.un.un_900 
  0x204063ee, 0x5c4c12a7, 0x07004405, 0x330823a4,   // sco.lb.sq_422 hu.wo.sa_532  kk.bg.un_330 ca.no.nn_433 
  // [c520]
  0x2f004f08, 0x16632907, 0x06003e0d, 0x285376a7,   // bi.su.un_430 sl.sco.hr_432  rm.de.un_540 crs.ht.sw_532 
  0x1d004612, 0x3216290e, 0x3015080c, 0x1e002f09,   // qu.la.un_640 sl.hr.bs_555  uk.uz.un_530 su.ms.un_440 
  0x46001d08, 0x3e082207, 0x4c003908, 0x1d2246ee,   // la.qu.un_430 oc.no.rm_432  br.wo.un_430 qu.oc.la_422 
  0x2f002304, 0x06005804, 0x1d004605, 0x486502ad,   // ca.su.un_320 om.de.un_320  qu.la.un_330 da.gv.tt_643 
  // [c530]
  0x28002307, 0x28184b0d, 0x1d004611, 0x75004f23,   // ky.sd.un_420 mi.ga.sw_554  qu.la.un_630 bi.nso.un_880 
  0x734728ad, 0x395669ad, 0x0663400c, 0x58000604,   // sw.sn.ny_643 mfe.mg.br_643  lb.sco.de_543 de.om.un_320 
  0x5428390c, 0x184423a7, 0x2f4f6004, 0x27005604,   // br.sw.ik_543 ky.kk.ar_532  vo.bi.su_332 mg.gd.un_320 
  0x2300501a, 0x28007309, 0x47281a11, 0x11005004,   // fj.ca.un_760 ny.sw.un_440  tl.sw.sn_653 fj.ro.un_320 
  // [c540]
  0x07003409, 0x2510110c, 0x36002e05, 0x595545ec,   // xh.it.un_440 ro.be.mn_543  fo.gn.un_330 ln.rw.rn_644 
  0x4f2723a4, 0x39055602, 0x79476aa0, 0x374815ee,   // ca.gd.bi_433 mg.fr.br_222  haw.sn.war_322 un.tt.ba_422 
  0x07005007, 0x5e004712, 0x73286a0c, 0x1a4b5614,   // fj.it.un_420 sn.ts.un_640  haw.sw.ny_543 mg.mi.tl_666 
  0x21245202, 0x42502907, 0x650634ad, 0x3f632ea4,   // ha.eo.jw_222 sl.fj.co_432  xh.de.gv_643 fo.sco.af_433 
  // [c550]
  0x62420207, 0x53063f02, 0x1f004204, 0x5c005204,   // da.co.kha_432 af.de.ht_222  co.cy.un_320 ha.sa.un_320 
  0x48fc3455, 0x5d354713, 0x164502ad, 0x42004c0e,   // xh.zzp.tt_442 sn.zu.ss_665  da.ln.hr_643 wo.co.un_550 
  0x0f004512, 0x1c001e34, 0x212f1c12, 0x212067ad,   // ln.lv.un_640 ms.id.un_A80  id.su.jw_654 ak.sq.jw_643 
  0x455534a7, 0x294250ad, 0x4404350d, 0x2c3f035a,   // xh.rw.ln_532 fj.co.sl_643  tg.ru.kk_554 nl.af.fy_553 
  // [c560]
  0x0d001802, 0x04421307, 0xfc001a02, 0x37004912,   // ga.cs.un_220 et.co.fi_432  tl.zzp.un_220 to.st.un_640 
  0x18000d0d, 0x033f24a4, 0x3900340c, 0x1d000d0b,   // cs.ga.un_540 eo.af.nl_433  xh.br.un_530 cs.la.un_520 
  0x35153c11, 0x56002d04, 0x73002108, 0x35253812,   // ug.tg.un_630 sk.mg.un_320  jw.ny.un_430 tk.mn.tg_654 
  0x2000460d, 0x123d30a6, 0x34473813, 0x121834a4,   // qu.sq.un_540 uz.ku.ur_521  tk.sn.xh_665 ps.ar.ur_433 
  // [c570]
  0x34123bee, 0x303d21ee, 0x18000d07, 0x0a0407a7,   // ks.ur.ps_422 fa.ku.uz_422  cs.ga.un_420 bg.ru.mk_532 
  0x04134612, 0x0a1711ec, 0x13006005, 0x2e0c330c,   // qu.et.fi_654 ro.sr.mk_644  vo.et.un_330 nn.sv.fo_543 
  0x183423a0, 0x2e51020d, 0x2e2546ad, 0x4a3428a0,   // ky.ps.ar_322 da.kl.fo_554  qu.eu.fo_643 sw.xh.yo_322 
  0x2300420c, 0x6b065c05, 0x1b461307, 0x480a01a4,   // co.ca.un_530 sa.de.ceb_333  et.qu.tr_432 en.pt.tt_433 
  // [c580]
  0x6b120e05, 0x4c180707, 0x360a1505, 0x10150409,   // is.hu.ceb_333 it.ga.wo_432  un.mk.ab_333 ru.be.un_440 
  0x595725ad, 0x64002005, 0x55001308, 0x4837100c,   // eu.na.rn_643 sq.lg.un_330  et.rw.un_430 be.ba.tt_543 
  0x1d3e45ad, 0x23004212, 0x5f455d0c, 0x15040a12,   // ln.rm.la_643 co.ca.un_640  ss.ln.tn_543 mk.ru.un_654 
  0x23004214, 0x0f152ea7, 0x1d044604, 0x1f000305,   // co.ca.un_660 fo.lv.un_520  qu.fi.la_332 nl.cy.un_330 
  // [c590]
  0x6b794607, 0xfe461a02, 0x375f4509, 0x2d001014,   // qu.war.ceb_432 tl.qu.tlh_222  ln.tn.st_444 lt.sk.un_660 
  0x3c153007, 0x79251909, 0x5221730b, 0x196322a4,   // uz.ug.un_420 gl.eu.war_444  ny.jw.ha_542 oc.sco.gl_433 
  0x2900170c, 0x2d006014, 0x090667ac, 0x090d13a0,   // sr.sl.un_530 vo.sk.un_660  ak.de.pl_632 bh.ne.hi_322 
  0x45573708, 0x6b3922a7, 0x372338ac, 0x183615ee,   // st.na.ln_443 oc.br.ceb_532  tk.ky.ba_632 un.gn.ga_422 
  // [c5a0]
  0x79226baf, 0x34007908, 0x18302807, 0x24000209,   // ceb.oc.war_655 war.xh.un_430  sd.uz.ar_432 da.eo.un_440 
  0x20622707, 0x2134305a, 0x2400fe0d, 0x22533009,   // gd.kha.sq_432 uz.ps.fa_553  tlh.eo.un_540 uz.ht.oc_444 
  0x02615e08, 0x21005c04, 0x12001105, 0x07352305,   // ts.za.da_443 sa.jw.un_320  ro.hu.un_330 ky.tg.bg_333 
  0x20100fa6, 0x34065ea6, 0x511d1208, 0x12004407,   // lv.lt.sq_521 ts.de.xh_521  hu.la.kl_443 kk.ur.un_420 
  // [c5b0]
  0x305e0404, 0x6820620c, 0x2228fe02, 0x03001607,   // fi.ts.uz_332 kha.sq.ig_543  tlh.sw.oc_222 hr.nl.un_420 
  0x351b3855, 0x18005102, 0x0c1b0e05, 0x38350a14,   // tk.tr.zu_442 kl.ga.un_220  is.tr.sv_333 mk.tg.tk_666 
  0x0f3f5cee, 0x38130207, 0xfe002108, 0x1bfe5f05,   // sa.af.lv_422 da.et.tk_432  jw.tlh.un_430 tn.tlh.tr_333 
  0x3b001235, 0x543137a4, 0x18003308, 0x42000708,   // ur.ks.un_A90 st.az.ik_433  nn.ga.un_430 it.co.un_430 
  // [c5c0]
  0x2b1d270c, 0x041c1e12, 0x2a001108, 0x65005f07,   // gd.la.vi_543 ms.id.fi_654  ro.mt.un_430 tn.gv.un_420 
  0x070a3004, 0x54383013, 0x4436380c, 0x656301ad,   // uz.mk.bg_332 uz.tk.ik_665  tk.ab.kk_543 en.sco.gv_643 
  0x1b304804, 0x30482204, 0x16005404, 0x3f5f78a6,   // tt.uz.tr_332 oc.tt.uz_332  ik.hr.un_320 ve.tn.af_521 
  0x2b00360d, 0x5f1b13ad, 0x341830ad, 0x372a5f07,   // gn.vi.un_540 et.tr.tn_643  uz.ar.ps_643 tn.mt.st_432 
  // [c5d0]
  0x27001e07, 0x08101508, 0x481b310e, 0x150f0511,   // ms.gd.un_420 un.be.uk_443  az.tr.tt_555 fr.lv.un_653 
  0x3008230c, 0x180165a0, 0x4e005313, 0x2d0d4cec,   // ky.uk.uz_543 gv.en.ga_322  ht.ay.un_650 wo.cs.sk_644 
  0x1b1d02ee, 0x34301808, 0x0b003602, 0x1f00fc12,   // da.la.tr_422 ar.uz.ps_443  gn.es.un_220 zzp.cy.un_640 
  0x3700441b, 0x1a793808, 0x484437af, 0x48373c07,   // kk.ba.un_770 tk.war.tl_443  ba.kk.tt_655 ug.ba.tt_432 
  // [c5e0]
  0x24000402, 0x18273e0b, 0x43000c0e, 0x1f791a04,   // fi.eo.un_220 rm.gd.ga_542  sv.ie.un_550 tl.war.cy_332 
  0x2300382a, 0x0b004602, 0x1a107607, 0x04005a07,   // tk.ky.un_970 qu.es.un_220  crs.lt.tl_432 sm.fi.un_420 
  0x330c3ea0, 0x650129ee, 0xfe004c04, 0x22001905,   // rm.sv.nn_322 sl.en.gv_422  wo.tlh.un_320 gl.oc.un_330 
  0x3e42070c, 0x3d214404, 0x120519a6, 0x48302312,   // it.co.rm_543 kk.fa.ku_332  gl.fr.hu_521 ky.uz.tt_654 
  // [c5f0]
  0x250430a4, 0x314d58a9, 0x3d00301a, 0x07250aaf,   // uz.ru.mn_433 om.aa.az_544  uz.ku.un_760 mk.mn.bg_655 
  0x432a070c, 0x301b6009, 0x0a111755, 0xfc0f24ee,   // it.mt.ie_543 vo.tr.uz_444  sr.ro.mk_442 eo.lv.zzp_422 
  0x0b001b04, 0x23113812, 0x07150a07, 0x79005209,   // tr.es.un_320 tk.ro.ky_654  mk.bg.un_420 ha.war.un_440 
  0x585cfc0d, 0x12022409, 0x4c58020e, 0x123430ee,   // zzp.sa.om_554 eo.da.hu_444  da.om.wo_555 uz.ps.ur_422 
  // [c600]
  0x17242002, 0x0a150405, 0x3c001204, 0x2d0d22ed,   // sq.eo.sr_222 ru.mk.un_330  ur.ug.un_320 oc.cs.sk_622 
  0x136b4c0c, 0x07301709, 0x6b6301a0, 0x0b2d19ee,   // wo.ceb.et_543 sr.uz.bg_444  en.sco.ceb_322 gl.sk.es_422 
  0x48002007, 0x09002008, 0x045379a0, 0x24522008,   // sq.tt.un_420 sq.pl.un_430  war.ht.fi_322 sq.ha.eo_443 
  0x0c1c2407, 0x11004810, 0x30440404, 0x35345909,   // eo.id.sv_432 tt.ro.un_620  ru.kk.uz_332 rn.xh.zu_444 
  // [c610]
  0x0d2d2912, 0x73002812, 0x1537070c, 0x1d5a6a11,   // sl.sk.cs_654 sw.ny.un_640  bg.ba.un_543 haw.sm.la_653 
  0x595573ee, 0x6702450c, 0x35345f05, 0x2035fe13,   // ny.rw.rn_422 ln.da.ak_543  tn.xh.zu_333 tlh.zu.sq_665 
  0x556453a7, 0x7901155a, 0xfe455f0c, 0x186511ad,   // ht.lg.rw_532 un.en.war_553  tn.ln.tlh_543 ro.gv.ga_643 
  0x0d00020d, 0x73471a0c, 0x100a0755, 0x42351f07,   // da.cs.un_540 tl.sn.ny_543  bg.mk.be_442 cy.zu.co_432 
  // [c620]
  0x0d00010d, 0x5e31480c, 0x1c422fa4, 0x022d0d55,   // en.cs.un_540 tt.az.ts_543  su.co.id_433 cs.sk.da_442 
  0x31004608, 0x28556aa0, 0x7300670c, 0x1b006409,   // qu.az.un_430 haw.rw.sw_322  ak.ny.un_530 lg.tr.un_440 
  0x56000d07, 0x38301b0d, 0x010d5607, 0x22002504,   // cs.mg.un_420 tr.uz.tk_554  mg.cs.en_432 eu.oc.un_320 
  0x57002f1a, 0x34233d5a, 0x2e7925ad, 0x56000d0d,   // su.na.un_760 ku.ky.ps_553  eu.war.fo_643 cs.mg.un_540 
  // [c630]
  0x313e300c, 0x381b33a4, 0x0201560b, 0x31301b0c,   // uz.rm.az_543 nn.tr.tk_433  mg.en.da_542 tr.uz.az_543 
  0x1e1c1a05, 0x231d13ee, 0x303d21a9, 0x18253004,   // tl.id.ms_333 et.la.ca_422  fa.ku.uz_544 uz.eu.ga_332 
  0x310b30a9, 0x15171155, 0x4844040c, 0x48383009,   // uz.es.az_544 ro.sr.un_442  ru.kk.tt_543 uz.tk.tt_444 
  0x2d293f02, 0x40033f14, 0x1b48300c, 0x48253755,   // af.sl.sk_222 af.nl.lb_666  uz.tt.tr_543 ba.mn.tt_442 
  // [c640]
  0x4838300d, 0x5702080c, 0x11004812, 0x79006b1b,   // uz.tk.tt_554 no.da.na_543  tt.ro.un_640 ceb.war.un_770 
  0xfe2a2d11, 0x483031a9, 0x25695312, 0x604f3414,   // sk.mt.tlh_653 az.uz.tt_544  ht.mfe.eu_654 xh.bi.vo_666 
  0x3306fca0, 0x043c4807, 0x281230ec, 0x352348a0,   // zzp.de.nn_322 tt.ug.ru_432  uz.ur.sd_644 tt.ky.tg_322 
  0x4c0c2da0, 0x06002c2a, 0x576b6712, 0x4448230e,   // sk.sv.wo_322 fy.de.un_970  ak.ceb.na_654 ky.tt.kk_555 
  // [c650]
  0x0833fc07, 0x18213d12, 0x02672d0c, 0x062efc07,   // zzp.nn.no_432 ku.fa.ar_654  sk.ak.da_543 zzp.fo.de_432 
  0x1b4c3b0c, 0x212818a4, 0x06fc4004, 0x0c15fc04,   // so.wo.tr_543 ar.sd.fa_433  lb.zzp.de_332 zzp.sv.un_320 
  0x074430ee, 0x0711500c, 0x1500362c, 0x501b5212,   // uz.kk.bg_422 fj.ro.it_543  ab.un.un_990 ha.tr.fj_654 
  0x07000d08, 0x0f171055, 0x1d230708, 0x32000707,   // cs.it.un_430 lt.sr.lv_442  it.ca.la_443 it.bs.un_420 
  // [c660]
  0x482515a9, 0x0804250c, 0x3c442309, 0x10171507,   // un.mn.tt_544 mn.ru.uk_543  ky.kk.ug_444 un.sr.be_432 
  0x0b033fa0, 0x341828a6, 0x36005c1a, 0x5c304805,   // af.nl.es_322 sd.ar.ps_521  sa.gn.un_760 tt.uz.sa_333 
  0xfe1501ee, 0x64005c08, 0x1863060c, 0x5253280b,   // en.tlh.un_420 sa.lg.un_430  de.sco.ga_543 sw.ht.ha_542 
  0x373c4812, 0x12365c13, 0x30483712, 0x1e5c64ee,   // tt.ug.ba_654 sa.gn.hu_665  ba.tt.uz_654 lg.sa.ms_422 
  // [c670]
  0x55003619, 0x341844a4, 0x040748a4, 0x4d58310d,   // gn.rw.un_750 kk.ar.ps_433  tt.bg.ru_433 az.om.aa_554 
  0x6520300d, 0x5a005104, 0x28044b04, 0x203821ac,   // uz.sq.gv_554 kl.sm.un_320  mi.fi.sw_332 jw.tk.sq_632 
  0x3d3021af, 0x1f15010c, 0x5c003422, 0x642efea4,   // fa.uz.ku_655 en.cy.un_530  xh.sa.un_870 tlh.fo.lg_433 
  0x12003b14, 0x73005413, 0x3ffc05a7, 0x46525c0b,   // ks.ur.un_660 ik.ny.un_650  fr.zzp.af_532 sa.ha.qu_542 
  // [c680]
  0x581042a4, 0x53695ca4, 0x1f001d13, 0x1d002112,   // co.lt.om_433 sa.mfe.ht_433  la.cy.un_650 jw.la.un_640 
  0x02561109, 0x65221f07, 0x1b561f13, 0x4f216307,   // ro.mg.da_444 cy.oc.gv_432  cy.mg.tr_665 sco.jw.bi_432 
  0x1d5a0404, 0x6900250e, 0x1f005012, 0x10464e12,   // fi.sm.la_332 eu.mfe.un_550  fj.cy.un_640 ay.qu.lt_654 
  0x21001f1a, 0x2900100d, 0x343720a0, 0x0335345a,   // cy.jw.un_760 lt.sl.un_540  sq.st.xh_322 xh.zu.nl_553 
  // [c690]
  0x215d63ee, 0x52214c07, 0x1d003008, 0x252c36ec,   // sco.ss.jw_422 wo.jw.ha_432  uz.la.un_430 gn.fy.eu_644 
  0x2c2511ac, 0x5600251b, 0x182701a4, 0x36562ca0,   // ro.eu.fy_632 eu.mg.un_770  en.gd.ga_433 fy.mg.gn_322 
  0x022c25ec, 0x651827ec, 0x30281207, 0x11250aa0,   // eu.fy.da_644 gd.ga.gv_644  ur.sd.uz_432 pt.eu.ro_322 
  0x2c111c07, 0x20022c07, 0x25001114, 0x32fe2a04,   // id.ro.fy_432 fy.da.sq_432  ro.eu.un_660 mt.tlh.bs_332 
  // [c6a0]
  0x22001107, 0x18273012, 0x0700fe0c, 0x2a00fe07,   // ro.oc.un_420 uz.gd.ga_654  tlh.it.un_530 tlh.mt.un_420 
  0x02011da4, 0x25001108, 0x08073ba0, 0x11005614,   // la.en.da_433 ro.eu.un_430  so.it.no_322 mg.ro.un_660 
  0x59150107, 0x02252c08, 0x64024c02, 0x2c2511ec,   // en.rn.un_420 fy.eu.da_443  wo.da.lg_222 ro.eu.fy_644 
  0x287936a4, 0x4d004213, 0x2f4536ad, 0x2c3611ee,   // gn.war.sw_433 co.aa.un_650  gn.ln.su_643 ro.gn.fy_422 
  // [c6b0]
  0x354c2807, 0x4a005504, 0x284e7308, 0x213d1211,   // sw.wo.zu_432 rw.yo.un_320  ny.ay.sw_443 ur.ku.fa_653 
  0x0a0115ee, 0x15303c0c, 0x40124dee, 0x0a041105,   // un.en.pt_422 ug.uz.un_543  aa.hu.lb_422 ro.ru.mk_333 
  0x0c1204ad, 0x30245607, 0x0d091c02, 0x324e2808,   // fi.hu.sv_643 mg.eo.uz_432  mr.hi.ne_222 sw.ay.bs_443 
  0x122a20a9, 0x32000d02, 0x0a30440c, 0x18190b05,   // sq.mt.hu_544 cs.bs.un_220  kk.uz.mk_543 es.gl.ga_333 
  // [c6c0]
  0x5efe78ad, 0x10007519, 0x30000804, 0x1e00470d,   // ve.tlh.ts_643 nso.lt.un_750  uk.uz.un_320 sn.ms.un_540 
  0x2a004202, 0x1000292a, 0x20302208, 0x04301255,   // co.mt.un_220 sl.lt.un_970  oc.uz.sq_443 hu.uz.fi_442 
  0x3300082b, 0x23303c0e, 0x20001208, 0x0c00040c,   // no.nn.un_980 ug.uz.ky_555  hu.sq.un_430 fi.sv.un_530 
  0x1004380e, 0x090d13ad, 0xfe005508, 0x06304805,   // tk.ru.be_555 bh.ne.hi_643  rw.tlh.un_430 tt.uz.de_333 
  // [c6d0]
  0x475967ad, 0x3e004f04, 0x73004f2b, 0x0a795707,   // ak.rn.sn_643 bi.rm.un_320  bi.ny.un_980 na.war.pt_432 
  0x3115fcaf, 0x591e4dad, 0x15000a19, 0x79616b13,   // zzp.az.un_650 aa.ms.rn_643  mk.un.un_750 ceb.za.war_665 
  0xfc006b09, 0xfc0501a4, 0x31481ba4, 0x30211212,   // ceb.zzp.un_440 en.fr.zzp_433  tr.tt.az_433 ur.fa.uz_654 
  0x1b330802, 0x0715045a, 0x586301ad, 0x0d632d07,   // no.nn.tr_222 ru.bg.un_530  en.sco.om_643 sk.sco.cs_432 
  // [c6e0]
  0x06002f05, 0x0f2f33a4, 0x440704a0, 0x4423100c,   // su.de.un_330 nn.su.lv_433  ru.bg.kk_322 be.ky.kk_543 
  0x4400101a, 0x0d005c18, 0x40016307, 0x18380108,   // be.kk.un_760 sa.ne.un_740  sco.en.lb_432 en.tk.ga_443 
  0x3700730d, 0x567364ad, 0x17161009, 0x735602ec,   // ny.st.un_540 lg.ny.mg_643  lt.hr.sr_444 da.mg.ny_644 
  0x641dfcee, 0x061d2612, 0x755f37af, 0x2500581b,   // zzp.la.lg_422 ia.la.de_654  st.tn.nso_655 om.eu.un_770 
  // [c6f0]
  0x643b2502, 0x375f45a9, 0xfe565007, 0x155d01a4,   // eu.so.lg_222 ln.tn.st_544  fj.mg.tlh_432 en.ss.un_433 
  0x35003802, 0x5247350c, 0x6400680d, 0x3b000204,   // tk.zu.un_220 zu.sn.ha_543  ig.lg.un_540 da.so.un_320 
  0x45005d0c, 0x015d50a7, 0x68fe06a9, 0x65002c05,   // ss.ln.un_530 fj.ss.en_532  de.tlh.ig_544 fy.gv.un_330 
  0x5f1d25a4, 0x2d0d520c, 0x64006512, 0x35005007,   // eu.la.tn_433 ha.cs.sk_543  gv.lg.un_640 fj.zu.un_420 
  // [c700]
  0x48303bee, 0x0a006404, 0x5d733504, 0x735b02a4,   // so.uz.tt_422 lg.pt.un_320  zu.ny.ss_332 da.sg.ny_433 
  0x564d78ec, 0x56372908, 0x64355505, 0x3b00091a,   // ve.aa.mg_644 sl.st.mg_443  rw.zu.lg_333 hi.ks.un_760 
  0x0d2d10a9, 0x58003502, 0x37170aa7, 0x1f6563a0,   // lt.sk.cs_544 zu.om.un_220  mk.sr.ba_532 sco.gv.cy_322 
  0x4e000c1a, 0x0411360c, 0x16102908, 0x0a0704a9,   // sv.ay.un_760 ab.ro.ru_543  sl.lt.hr_443 ru.bg.mk_544 
  // [c710]
  0x08002507, 0x43002c0d, 0x353748a0, 0x5a004702,   // mn.uk.un_420 fy.ie.un_540  tt.ba.tg_322 sn.sm.un_220 
  0x457605a4, 0x49005a12, 0x402c2702, 0x132434a0,   // fr.crs.ln_433 sm.to.un_640  gd.fy.lb_222 xh.eo.et_322 
  0x35361012, 0x15003519, 0x2c002207, 0x565a0504,   // be.ab.tg_654 tg.un.un_750  oc.fy.un_420 fr.sm.mg_332 
  0x5a054912, 0x79004912, 0x073508ee, 0x11070a09,   // to.fr.sm_654 to.war.un_640  uk.tg.bg_422 mk.bg.ro_444 
  // [c720]
  0x171035ee, 0x5e004e07, 0x23354e0c, 0x183c23a7,   // tg.be.sr_422 ay.ts.un_420  ay.zu.ca_543 ky.ug.ar_532 
  0x2c00fc07, 0x131c09ad, 0x44302305, 0x1f6509ad,   // zzp.fy.un_420 hi.mr.bh_643  ky.uz.kk_333 pl.gv.cy_643 
  0x30004e11, 0x2c000d02, 0x29001002, 0x25004e22,   // ay.uz.un_630 cs.fy.un_220  lt.sl.un_220 ay.eu.un_870 
  0x46004b05, 0x286a5408, 0x5e4778af, 0x1c006a08,   // mi.qu.un_330 ik.haw.sw_443  ve.sn.ts_655 haw.id.un_430 
  // [c730]
  0x10007508, 0x08151504, 0x0603090c, 0x443c370d,   // nso.lt.un_430 un.uk.un_320  pl.nl.de_543 ba.ug.kk_554 
  0x343d30ad, 0x2200051b, 0x33274b0c, 0x1e006714,   // uz.ku.ps_643 fr.oc.un_770  mi.gd.nn_543 ak.ms.un_660 
  0x56000208, 0x65630108, 0x4b00490e, 0x3412210d,   // da.mg.un_430 en.sco.gv_443  to.mi.un_550 fa.ur.ps_554 
  0x112648a4, 0x293148a0, 0x50003604, 0x0500231b,   // tt.ia.ro_433 tt.az.sl_322  gn.fj.un_320 ca.fr.un_770 
  // [c740]
  0x0e48510d, 0x2e0e2508, 0x6527060c, 0x0c2e0e11,   // kl.tt.is_554 eu.is.fo_443  de.gd.gv_543 is.fo.sv_653 
  0x013f6502, 0x3500152a, 0x1d25690d, 0x0748300d,   // gv.af.en_222 un.tg.un_970  mfe.eu.la_554 uz.tt.bg_554 
  0x51005619, 0x2321340c, 0x10003808, 0x62002e19,   // mg.kl.un_750 ps.fa.ky_543  tk.lt.un_430 fo.kha.un_750 
  0x5c2933a4, 0x043e420b, 0x2e0e510c, 0x0e4f2555,   // nn.sl.sa_433 co.rm.fi_542  kl.is.fo_543 eu.bi.is_442 
  // [c750]
  0x17290d08, 0x22500504, 0x30151555, 0x53200a04,   // cs.sl.sr_443 fr.fj.oc_332  un.uz.un_420 pt.sq.ht_332 
  0x69573eaf, 0x06110507, 0x12000e19, 0x0d001007,   // rm.na.mfe_655 fr.ro.de_432  is.hu.un_750 lt.cs.un_420 
  0x18274f12, 0x2920670c, 0x40030555, 0x1732165a,   // bi.gd.ga_654 ak.sq.sl_543  fr.nl.lb_442 hr.bs.sr_553 
  0x422c050c, 0x11005a12, 0x6e311b09, 0x050602ee,   // fr.fy.co_543 sm.ro.un_640  tr.az.hmn_444 da.de.fr_422 
  // [c760]
  0x3e436e08, 0x6b4f1d07, 0x48303b04, 0x321b4fec,   // hmn.ie.rm_443 la.bi.ceb_432  so.uz.tt_332 bi.tr.bs_644 
  0x1b4f1ca4, 0x43004f13, 0x36003b0d, 0x4f001e08,   // id.bi.tr_433 bi.ie.un_650  so.gn.un_540 ms.bi.un_430 
  0x07005102, 0x48363ba9, 0x02000520, 0x38483b0c,   // kl.it.un_220 so.gn.tt_544  fr.da.un_850 so.tt.tk_543 
  0x2e2d38a7, 0x39110555, 0x153b3611, 0x02052ca4,   // tk.sk.fo_532 fr.ro.br_442  gn.so.un_653 fy.fr.da_433 
  // [c770]
  0x091c5c09, 0x021105ad, 0x4b000507, 0x652e63a0,   // sa.mr.hi_444 fr.ro.da_643  fr.mi.un_420 sco.fo.gv_322 
  0x170a1113, 0x1c001323, 0x17150414, 0x481007ee,   // ro.mk.sr_665 bh.mr.un_880  ru.sr.un_660 bg.be.tt_422 
  0x36001505, 0x4c003112, 0x3530360e, 0x240c13a0,   // un.gn.un_330 az.wo.un_640  ab.uz.tg_555 et.sv.eo_322 
  0x52071da4, 0x68583baf, 0x08070a07, 0x025d500c,   // la.it.ha_433 so.om.ig_655  mk.bg.uk_432 fj.ss.da_543 
  // [c780]
  0x3508105a, 0x321750ee, 0x183423a7, 0x23443009,   // be.uk.tg_553 fj.sr.bs_422  ky.ps.ar_532 uz.kk.ky_444 
  0x4c73205a, 0x644a5a07, 0x30041509, 0x52022e07,   // sq.ny.wo_553 sm.yo.lg_432  un.ru.uz_444 fo.da.ha_432 
  0x795213ec, 0x042069a7, 0x3000360e, 0x1e451ca9,   // et.ha.war_644 mfe.sq.fi_532  gn.uz.un_550 id.ln.ms_544 
  0x30003604, 0x52021fad, 0x3f062da0, 0x29695007,   // ab.uz.un_320 cy.da.ha_643  sk.de.af_322 fj.mfe.sl_432 
  // [c790]
  0x35022507, 0x3b680205, 0x1a6b7960, 0x482335ad,   // eu.da.zu_432 da.ig.so_333  war.ceb.tl_664 tg.ky.tt_643 
  0x47003513, 0x39003005, 0x325017ee, 0x221d4308,   // zu.sn.un_650 uz.br.un_330  sr.fj.bs_422 ie.la.oc_443 
  0x3f2257a0, 0x42001d05, 0x69537611, 0x6000fe0c,   // na.oc.af_322 la.co.un_330  crs.ht.mfe_653 tlh.vo.un_530 
  0x205e1ba0, 0x15043714, 0x02595505, 0x623f40a4,   // tr.ts.sq_322 ba.ru.un_666  rw.rn.da_333 lb.af.kha_433 
  // [c7a0]
  0x27000202, 0x063f08a4, 0x52000211, 0x3e2c400c,   // da.gd.un_220 no.af.de_433  da.ha.un_630 lb.fy.rm_543 
  0xfa64020c, 0x09003513, 0x5c4260ad, 0x46735204,   // da.lg.nr_543 zu.pl.un_650  vo.co.sa_643 ha.ny.qu_332 
  0x02352804, 0x3b4d1e0c, 0x4600021b, 0x30250a09,   // sw.zu.da_332 ms.aa.so_543  da.qu.un_770 mk.mn.uz_444 
  0x68006708, 0x46005809, 0x47005c09, 0x08003e05,   // ak.ig.un_430 om.qu.un_440  sa.sn.un_440 rm.no.un_330 
  // [c7b0]
  0x35004407, 0x34093511, 0x2c6340ad, 0x36004c0c,   // kk.tg.un_420 zu.pl.xh_653  lb.sco.fy_643 wo.gn.un_530 
  0x484430ee, 0x1123380c, 0x234411ee, 0x07170aec,   // uz.kk.tt_422 tk.ky.ro_543  ro.kk.ky_422 mk.sr.bg_644 
  0x5c130911, 0x0225090c, 0x25076504, 0x395125ad,   // hi.bh.sa_653 pl.eu.da_543  gv.it.eu_332 eu.kl.br_643 
  0x25423305, 0x54512508, 0x2e090ead, 0x13002504,   // nn.co.eu_333 eu.kl.ik_443  is.pl.fo_643 eu.et.un_320 
  // [c7c0]
  0x300a150c, 0x041a79ad, 0x2a642c07, 0x3600150d,   // un.mk.uz_543 war.tl.fi_643  fy.lg.mt_432 un.ab.un_540 
  0x37004a04, 0x21005e0c, 0x0cfe58a0, 0x6a172904,   // yo.st.un_320 ts.jw.un_530  om.tlh.sv_322 sl.sr.haw_332 
  0x64484dad, 0x2d07250b, 0x3b002c04, 0x15003518,   // aa.tt.lg_643 eu.it.sk_542  fy.so.un_320 tg.un.un_740 
  0x07004202, 0x2f1156a4, 0x37080455, 0x1c003808,   // co.it.un_220 mg.ro.su_433  ru.uk.ba_442 tk.id.un_430 
  // [c7d0]
  0x4f255111, 0x50003707, 0x1e255108, 0x250415af,   // kl.eu.bi_653 st.fj.un_420  kl.eu.ms_443 un.ru.mn_655 
  0x4a36675a, 0x250415ad, 0x0d1c1312, 0x79285a0c,   // ak.gn.yo_553 un.ru.mn_643  bh.mr.ne_654 sm.sw.war_543 
  0x2c006409, 0x5c4b1b05, 0x29000f13, 0x25043760,   // lg.fy.un_440 tr.mi.sa_333  lv.sl.un_650 ba.ru.mn_664 
  0x122524ee, 0x6500690c, 0x622401a4, 0xfc0765a9,   // eo.eu.hu_422 mfe.gv.un_530  en.eo.kha_433 gv.it.zzp_544 
  // [c7e0]
  0x48003c22, 0x0400650e, 0x3000690e, 0x0e001319,   // ug.tt.un_870 gv.fi.un_550  mfe.uz.un_550 et.is.un_750 
  0x24002d07, 0x7902130c, 0x4264120c, 0x13002405,   // sk.eo.un_420 et.da.war_543  hu.lg.co_543 eo.et.un_330 
  0x245079a6, 0x58004d12, 0x3b796bad, 0x484423af,   // war.fj.eo_521 aa.om.un_640  ceb.war.so_643 ky.kk.tt_655 
  0x6200240e, 0x37084807, 0x49004c02, 0x24003b12,   // eo.kha.un_550 tt.uk.ba_432  wo.to.un_220 so.eo.un_640 
  // [c7f0]
  0x632e130c, 0x31004d12, 0x44374860, 0x370408ee,   // et.fo.sco_543 aa.az.un_640  tt.ba.kk_664 uk.ru.ba_422 
  0x1f6b30ee, 0x6503fea0, 0x502601a0, 0x0400581b,   // uz.ceb.cy_422 tlh.nl.gv_322  en.ia.fj_322 om.fi.un_770 
  0xfc004c13, 0x13091c08, 0x130301a0, 0x53003119,   // wo.zzp.un_650 mr.hi.bh_443  en.nl.et_322 az.ht.un_750 
  0x3848300c, 0x2e003812, 0x23381107, 0x15061fa4,   // uz.tt.tk_543 tk.fo.un_640  ro.tk.ky_432 cy.de.un_433 
  
  // [c800]
  0x4c002018, 0x5c0e7302, 0x1d001704, 0x303d3b05,   // sq.wo.un_740 ny.is.sa_222  sr.la.un_320 ks.ku.uz_333 
  0x264201a0, 0x5c03680e, 0x3e003919, 0x06000502,   // en.co.ia_322 ig.nl.sa_555  br.rm.un_750 fr.de.un_220 
  0x341821ac, 0x0e0c3304, 0x0e083311, 0x08070455,   // fa.ar.ps_632 nn.sv.is_332  nn.no.is_653 ru.bg.uk_442 
  0x2d0d3614, 0x08330207, 0x125cfe08, 0x09001f0c,   // gn.cs.sk_666 da.nn.no_432  tlh.sa.hu_443 cy.pl.un_530 
  // [c810]
  0x5c130408, 0x34213b0c, 0x3f002202, 0x101704a9,   // fi.et.sa_443 ks.fa.ps_543  oc.af.un_220 ru.sr.be_544 
  0x48234412, 0x332e0e07, 0x2535300d, 0x5f002808,   // kk.ky.tt_654 is.fo.nn_432  uz.tg.mn_554 sw.tn.un_430 
  0x100a0813, 0x3812450c, 0x4c002005, 0x481023a4,   // uk.mk.be_665 ln.hu.tk_543  sq.wo.un_330 ky.be.tt_433 
  0x2300fe07, 0x2f006502, 0x36080202, 0x2f006a08,   // tlh.ca.un_420 gv.su.un_220  da.no.gn_222 haw.su.un_430 
  // [c820]
  0x232201a4, 0x0e002808, 0x28004904, 0x5f002f05,   // en.oc.ca_433 sw.is.un_430  to.sw.un_320 su.tn.un_330 
  0x09000e12, 0x564937a6, 0x5f281307, 0x276a490c,   // is.pl.un_640 st.to.mg_521  et.sw.tn_432 to.haw.gd_543 
  0x3f0360ec, 0x21111d14, 0x473b0e08, 0x271718ec,   // vo.nl.af_644 la.ro.jw_666  is.so.sn_443 ga.sr.gd_644 
  0x303510a4, 0x1f004c14, 0x4900560e, 0x27fe43ee,   // be.tg.uz_433 wo.cy.un_660  mg.to.un_550 ie.tlh.gd_422 
  // [c830]
  0x0f0912ad, 0x47202804, 0x2c00130d, 0x040711ec,   // hu.pl.lv_643 sw.sq.sn_332  et.fy.un_540 ro.bg.ru_644 
  0x0b4b36a4, 0x755f450c, 0x44373c14, 0x477367a4,   // gn.mi.es_433 ln.tn.nso_543  ug.ba.kk_666 ak.ny.sn_433 
  0x0200391a, 0x084411a4, 0x1c132755, 0x0e1b4c07,   // br.da.un_760 ro.kk.uk_433  gd.et.id_442 wo.tr.is_432 
  0x300a1107, 0x241902ee, 0x12002820, 0x0e001f13,   // ro.mk.uz_432 da.gl.eo_422  sd.ur.un_850 cy.is.un_650 
  // [c840]
  0x150a2512, 0x22791d04, 0x34281260, 0x1d00021a,   // mn.mk.un_654 la.war.oc_332  ur.sd.ps_664 da.la.un_760 
  0x4e46fc13, 0x48382311, 0x0a173c0c, 0x3f003807,   // zzp.qu.ay_665 ky.tk.tt_653  ug.sr.mk_543 tk.af.un_420 
  0x483c250c, 0x353036a6, 0x63fe0508, 0x38153ca4,   // mn.ug.tt_543 ab.uz.tg_521  fr.tlh.sco_443 ug.tk.un_430 
  0x1708360c, 0x3c150405, 0x620163a4, 0x44233804,   // ab.uk.sr_543 ru.ug.un_330  sco.en.kha_433 tk.ky.kk_332 
  // [c850]
  0x301821af, 0x44003604, 0x18342805, 0x5c090d0c,   // fa.ar.uz_655 ab.kk.un_320  sd.ps.ar_333 ne.hi.sa_543 
  0x22154c0c, 0xfe6576a7, 0x1f27180d, 0x1f475e08,   // wo.oc.un_530 crs.gv.tlh_532  ga.gd.cy_554 ts.sn.cy_443 
  0x2d002405, 0x65005407, 0x621e34a4, 0x1d005802,   // eo.sk.un_330 ik.gv.un_420  xh.ms.kha_433 om.la.un_220 
  0x0333fc0c, 0x5c001e04, 0x2b021cec, 0x0ffc1311,   // zzp.nn.nl_543 ms.sa.un_320  id.da.vi_644 et.zzp.lv_653 
  // [c860]
  0x3f002705, 0xfe2868ac, 0x2500361a, 0x21002902,   // gd.af.un_330 ig.sw.tlh_632  ab.mn.un_760 sl.jw.un_220 
  0x364b4d04, 0x06003313, 0x252403ee, 0x04230807,   // aa.mi.gn_332 nn.de.un_650  nl.eo.eu_422 uk.ky.ru_432 
  0x36680107, 0x240c18a0, 0x126536a0, 0x372173a9,   // en.ig.gn_432 ga.sv.eo_322  gn.gv.hu_322 ny.jw.st_544 
  0x5c2d0d08, 0x2e1e1c08, 0x3000280c, 0x375f75a9,   // cs.sk.sa_443 id.ms.fo_443  sw.uz.un_530 nso.tn.st_544 
  // [c870]
  0x342112af, 0x535221a4, 0x30253c0d, 0x64006919,   // ur.fa.ps_655 jw.ha.ht_433  ug.mn.uz_554 mfe.lg.un_750 
  0x69005713, 0x10001d02, 0x52535da4, 0x73494f5a,   // na.mfe.un_650 la.lt.un_220  ss.ht.ha_433 bi.to.ny_553 
  0x61784b05, 0x037946a6, 0x1a001e04, 0x475d64a9,   // mi.ve.za_333 qu.war.nl_521  ms.tl.un_320 lg.ss.sn_544 
  0x6900531a, 0x46012aee, 0x2f005213, 0x28004605,   // ht.mfe.un_760 mt.en.qu_422  ha.su.un_650 qu.sw.un_330 
  // [c880]
  0x552a59af, 0x1c090d60, 0x09003f02, 0x0f00610c,   // rn.mt.rw_655 ne.hi.mr_664  af.pl.un_220 za.lv.un_530 
  0x02000920, 0x13044805, 0x384d58ec, 0x43002418,   // pl.da.un_850 tt.fi.et_333  om.aa.tk_644 eo.ie.un_740 
  0x54003e19, 0x5d3437af, 0x4411175a, 0x17440404,   // rm.ik.un_750 st.xh.ss_655  sr.ro.kk_553 ru.kk.sr_332 
  0x162d0d09, 0x3000040e, 0x18053ea7, 0x100815ee,   // cs.sk.hr_444 fi.uz.un_550  rm.fr.ga_532 un.uk.be_422 
  // [c890]
  0x5000580b, 0x303548ee, 0x0a173708, 0x483744a4,   // om.fj.un_520 tt.tg.uz_422  ba.sr.mk_443 kk.ba.tt_433 
  0x2128300d, 0x12283009, 0x07080a05, 0x172338ee,   // uz.sd.fa_554 uz.sd.ur_444  mk.uk.bg_333 tk.ky.sr_422 
  0x0e0c0612, 0x62001f13, 0x443c3714, 0x17070a11,   // de.sv.is_654 cy.kha.un_650  ba.ug.kk_666 mk.bg.sr_653 
  0x5800652a, 0x100a1708, 0x2400180c, 0x4900560d,   // gv.om.un_970 sr.mk.be_443  ga.eo.un_530 mg.to.un_540 
  // [c8a0]
  0x55005618, 0x1f375dad, 0x495a56a4, 0x055a36a7,   // mg.rw.un_740 ss.st.cy_643  mg.sm.to_433 gn.sm.fr_532 
  0x5a4a60a7, 0x36650cee, 0x36002512, 0x5f3733a4,   // vo.yo.sm_532 sv.gv.gn_422  eu.gn.un_640 nn.st.tn_433 
  0x4a005612, 0x21442807, 0x131c0955, 0x3900340d,   // mg.yo.un_640 sd.kk.fa_432  hi.mr.bh_442 xh.br.un_540 
  0x30373ca0, 0x072a4fa9, 0x19220a0d, 0x38443613,   // ug.ba.uz_322 bi.mt.it_544  pt.oc.gl_554 ab.kk.tk_665 
  // [c8b0]
  0x49005604, 0x5e0720a4, 0x280f31a4, 0x38003308,   // mg.to.un_320 sq.it.ts_433  az.lv.sw_433 nn.tk.un_430 
  0x020e2ea4, 0x31305807, 0x21123409, 0x512e4da9,   // fo.is.da_433 om.uz.az_432  ps.ur.fa_444 aa.fo.kl_544 
  0x290f0c09, 0x0c79090c, 0x4b475604, 0x65000c08,   // sv.lv.sl_444 pl.war.sv_543  mg.sn.mi_332 sv.gv.un_430 
  0x4e463805, 0x37383cad, 0x350a0708, 0x1c0d0913,   // tk.qu.ay_333 ug.tk.ba_643  bg.mk.tg_443 hi.ne.mr_665 
  // [c8c0]
  0x300c08ee, 0x09466b08, 0x4e3925ac, 0x02384eee,   // no.sv.uz_422 ceb.qu.pl_443  eu.br.ay_632 ay.tk.da_422 
  0x150411ad, 0x241c60ee, 0x0e2e0255, 0x190b0502,   // ro.ru.un_643 vo.id.eo_422  da.fo.is_442 fr.es.gl_222 
  0x2b003618, 0x5a00340e, 0x421d4dee, 0x041015ee,   // gn.vi.un_740 xh.sm.un_550  aa.la.co_422 un.be.ru_422 
  0x1f021d07, 0x35004907, 0x0d091c14, 0x120b25ee,   // la.da.cy_432 to.zu.un_420  mr.hi.ne_666 eu.es.hu_422 
  // [c8d0]
  0x53004504, 0x65007604, 0x17311fa6, 0x202a0707,   // ln.ht.un_320 crs.gv.un_320  cy.az.sr_521 it.mt.sq_432 
  0x211b58a0, 0x15233cee, 0x650c0208, 0x0a230704,   // om.tr.jw_322 ug.ky.un_422  da.sv.gv_443 bg.ky.mk_332 
  0x1b004807, 0x57055c08, 0x10151112, 0x18016304,   // tt.tr.un_420 sa.fr.na_443  ro.be.un_640 sco.en.ga_332 
  0x371548af, 0x21181208, 0x11000a14, 0x350a30a0,   // tt.ba.un_650 ur.ar.fa_443  mk.ro.un_660 uz.mk.tg_322 
  // [c8e0]
  0x4e00120e, 0x12213409, 0x25441509, 0x285601a0,   // hu.ay.un_550 ps.fa.ur_444  un.kk.mn_444 en.mg.sw_322 
  0x443538a7, 0x622f4faf, 0x13586707, 0x12755f08,   // tk.tg.kk_532 bi.su.kha_655  ak.om.et_432 tn.nso.hu_443 
  0x385f12a4, 0xfe1b13a4, 0x375ffe0c, 0x38751ba9,   // hu.tn.tk_433 et.tr.tlh_433  tlh.tn.st_543 tr.nso.tk_544 
  0x1b481209, 0x5f4c1bad, 0x125f48ee, 0x32002912,   // hu.tt.tr_444 tr.wo.tn_643  tt.tn.hu_422 sl.bs.un_640 
  // [c8f0]
  0x170a3512, 0x1b48380c, 0x0737480d, 0x12383104,   // tg.mk.sr_654 tk.tt.tr_543  tt.ba.bg_554 az.tk.hu_332 
  0x38121b12, 0x3b13580c, 0x213d18ee, 0x2d29fe0c,   // tr.hu.tk_654 om.et.so_543  ar.ku.fa_422 tlh.sl.sk_543 
  0x3f5e5fec, 0x343c23ec, 0x315f12a4, 0x121b2d07,   // tn.ts.af_644 ky.ug.ps_644  hu.tn.az_433 sk.tr.hu_432 
  0x16295fa4, 0x07253c07, 0x605f370c, 0x62006e13,   // tn.sl.hr_433 ug.mn.bg_432  st.tn.vo_543 hmn.kha.un_650 
  // [c900]
  0x1a006b04, 0x38593007, 0x20000c02, 0x2818440c,   // ceb.tl.un_320 uz.rn.tk_432  sv.sq.un_220 kk.ar.sd_543 
  0xfc061807, 0x2304100c, 0x20001808, 0x5a00fc07,   // ga.de.zzp_432 be.ru.ky_543  ga.sq.un_430 zzp.sm.un_420 
  0x10071707, 0x36005718, 0x34283d08, 0x12342855,   // sr.bg.be_432 na.gn.un_740  ku.sd.ps_443 sd.ps.ur_442 
  0x4c000507, 0x055701a0, 0x20631f0c, 0x4a00120e,   // fr.wo.un_420 en.na.fr_322  cy.sco.sq_543 hu.yo.un_550 
  // [c910]
  0x214a2f04, 0x04001f09, 0x0c06040c, 0x1f002013,   // su.yo.jw_332 cy.fi.un_440  fi.de.sv_543 sq.cy.un_650 
  0x0700580c, 0x26051da4, 0x201dfc07, 0x05002f0c,   // om.it.un_530 la.fr.ia_433  zzp.la.sq_432 su.fr.un_530 
  0x30003536, 0x12464e0d, 0x123308ee, 0x07043507,   // tg.uz.un_AA0 ay.qu.hu_554  no.nn.hu_422 tg.ru.bg_432 
  0x1d2625a4, 0x454c05ad, 0x1f65fc0d, 0x42114ba0,   // eu.ia.la_433 fr.wo.ln_643  zzp.gv.cy_554 mi.ro.co_322 
  // [c920]
  0x44041504, 0x450205af, 0x23005204, 0x343028a4,   // un.ru.kk_332 fr.da.ln_655  ha.ca.un_320 sd.uz.ps_433 
  0x1f1d1d0c, 0x1dfc22a0, 0x253023a7, 0x092512ec,   // la.la.cy_543 oc.zzp.la_322  ky.uz.mn_532 hu.eu.pl_644 
  0x170811a0, 0x091f7907, 0x50045aec, 0x2b001f04,   // ro.uk.sr_322 war.cy.pl_432  sm.fi.fj_644 cy.vi.un_320 
  0x42001d04, 0x09651fa0, 0x1100521a, 0x0900630d,   // la.co.un_320 cy.gv.pl_322  ha.ro.un_760 sco.pl.un_540 
  // [c930]
  0x101333a0, 0x5afc040c, 0x2d090da7, 0x111d0807,   // nn.et.lt_322 fi.zzp.sm_543  cs.pl.sk_532 no.la.ro_432 
  0x4e484613, 0x051827a9, 0x18276560, 0x10150411,   // qu.tt.ay_665 gd.ga.fr_544  gv.gd.ga_664 ru.be.un_630 
  0x6500fc12, 0x30040702, 0x234438a4, 0x2c001f04,   // zzp.gv.un_640 bg.ru.uz_222  tk.kk.ky_433 cy.fy.un_320 
  0x1f000c19, 0x15352312, 0x182762af, 0x12306b02,   // sv.cy.un_750 ky.tg.un_654  kha.gd.ga_655 ceb.uz.hu_222 
  // [c940]
  0x3000081b, 0x04386012, 0x79fe6bad, 0x2b2463a9,   // uk.uz.un_770 vo.tk.fi_654  ceb.tlh.war_643 sco.eo.vi_544 
  0x253373ee, 0x097357a7, 0x2f2161af, 0x23443ca4,   // ny.nn.eu_422 na.ny.pl_532  za.jw.su_655 ug.kk.ky_433 
  0x0e242eee, 0x154838a4, 0x083536ee, 0x36005712,   // fo.eo.is_422 tk.tt.un_433  ab.tg.uk_422 na.gn.un_640 
  0x5e5725ad, 0x041342ee, 0x2e332aa4, 0x2a5c52a0,   // eu.na.ts_643 co.et.fi_422  mt.nn.fo_433 ha.sa.mt_322 
  // [c950]
  0x2f791fad, 0x15350707, 0x48000421, 0x243651a4,   // cy.war.su_643 bg.tg.un_432  fi.tt.un_860 kl.gn.eo_433 
  0x652e0e0c, 0x44373c13, 0x20330ca4, 0x0600790d,   // is.fo.gv_543 ug.ba.kk_665  sv.nn.sq_433 war.de.un_540 
  0x071f27a4, 0x0a00070b, 0x6b00790d, 0x5d3428a7,   // gd.cy.it_433 bg.mk.un_520  war.ceb.un_540 sw.xh.ss_532 
  0x2a002419, 0x0e332104, 0x4c002404, 0x22192307,   // eo.mt.un_750 jw.nn.is_332  eo.wo.un_320 ca.gl.oc_432 
  // [c960]
  0x3c003b04, 0x40001e02, 0x3b6a4907, 0x63fc0107,   // ks.ug.un_320 ms.lb.un_220  to.haw.so_432 en.zzp.sco_432 
  0x2b001119, 0x46006a13, 0x17001302, 0x49001307,   // ro.vi.un_750 haw.qu.un_650  et.sr.un_220 et.to.un_420 
  0x1e002002, 0x0156030c, 0x15005a05, 0x56012604,   // sq.ms.un_220 nl.mg.en_543  sm.un.un_330 ia.en.mg_332 
  0x4006380c, 0x2300220b, 0x2000120c, 0x56001212,   // tk.de.lb_543 oc.ca.un_520  hu.sq.un_530 hu.mg.un_640 
  // [c970]
  0x016356af, 0x2f2b1ba0, 0x37576305, 0x18630104,   // mg.sco.en_655 tr.vi.su_322  sco.na.st_333 en.sco.ga_332 
  0x0e4b49a6, 0x12183408, 0x5c0d1c55, 0x56630108,   // to.mi.is_521 ps.ar.ur_443  mr.ne.sa_442 en.sco.mg_443 
  0x17080702, 0x04670107, 0x0e002004, 0x040836a0,   // bg.uk.sr_222 en.ak.fi_432  sq.is.un_320 ab.uk.ru_322 
  0x201e3ea0, 0x253530ad, 0x40004202, 0x17002007,   // rm.ms.sq_322 uz.tg.mn_643  co.lb.un_220 sq.sr.un_420 
  // [c980]
  0x0e362da4, 0x10074807, 0x650f2aee, 0x784d6a0c,   // sk.gn.is_433 tt.bg.be_432  mt.lv.gv_422 haw.aa.ve_543 
  0x481e1c14, 0x073710a0, 0x39321604, 0x5f756808,   // id.ms.tt_666 be.ba.bg_322  hr.bs.br_332 ig.nso.tn_443 
  0x21002c04, 0x100639a9, 0x183b210c, 0x1b1e1ca9,   // fy.jw.un_320 br.de.lt_544  fa.ks.ar_543 id.ms.tr_544 
  0x07001b02, 0x0a3c44ec, 0x2f091ba0, 0x1d002609,   // tr.it.un_220 kk.ug.mk_644  tr.pl.su_322 ia.la.un_440 
  // [c990]
  0x3b004004, 0x03063fa9, 0x32004207, 0x4d003113,   // lb.so.un_320 af.de.nl_544  co.bs.un_420 az.aa.un_650 
  0x17374804, 0x171b5007, 0x42000108, 0x1e1c37af,   // tt.ba.sr_332 fj.tr.sr_432  en.co.un_430 st.id.ms_655 
  0x283b18a4, 0x423209a0, 0xfe026005, 0x083035ac,   // ar.ks.sd_433 pl.bs.co_322  vo.da.tlh_333 tg.uz.uk_632 
  0x375f670c, 0x20000c04, 0xfc150607, 0x113209a0,   // ak.tn.st_543 sv.sq.un_320  de.zzp.un_420 pl.bs.ro_322 
  // [c9a0]
  0x11434207, 0x32501b07, 0x0e2e1802, 0x4b501e04,   // co.ie.ro_432 tr.fj.bs_432  ga.fo.is_222 ms.fj.mi_332 
  0x1844230c, 0x50004f29, 0x2800730b, 0x6b481d07,   // ky.kk.ar_543 bi.fj.un_960  ny.sw.un_520 la.tt.ceb_432 
  0x63784b07, 0x51790b04, 0x3e005608, 0x441008a4,   // mi.ve.sco_432 es.war.kl_332  mg.rm.un_430 uk.be.kk_433 
  0x070403a4, 0x5a002821, 0x79630b05, 0x51003612,   // nl.fi.it_433 sw.sm.un_860  es.sco.war_333 gn.kl.un_640 
  // [c9b0]
  0x271f23a0, 0x6100fe0e, 0x50fc7907, 0x2c3f0fa0,   // ca.cy.gd_322 tlh.za.un_550  war.zzp.fj_432 lv.af.fy_322 
  0x4500490d, 0x0a35110c, 0x1d003e14, 0x32005407,   // to.ln.un_540 ro.tg.mk_543  rm.la.un_660 ik.bs.un_420 
  0x25004604, 0x4c00fe05, 0x211c2205, 0x0900040c,   // qu.eu.un_320 tlh.wo.un_330  oc.id.jw_333 fi.pl.un_530 
  0x115a01a4, 0x4c2d0907, 0x0f0763a0, 0x63000f21,   // en.sm.ro_433 pl.sk.wo_432  sco.it.lv_322 lv.sco.un_860 
  // [c9c0]
  0x1d504ba4, 0x423e0fec, 0x0b004b04, 0x4860041a,   // mi.fj.la_433 lv.rm.co_644  mi.es.un_320 fi.vo.tt_776 
  0x32004805, 0xfc1d01a0, 0x3c00442b, 0x0f005e0e,   // tt.bs.un_330 en.la.zzp_322  kk.ug.un_980 ts.lv.un_550 
  0x4800232c, 0x1e3b4802, 0x091e2da0, 0x485c4e08,   // ky.tt.un_990 tt.so.ms_222  sk.ms.pl_322 ay.sa.tt_443 
  0x032f1504, 0x0c123107, 0x48005c12, 0x30382305,   // un.su.nl_332 az.hu.sv_432  sa.tt.un_640 ky.tk.uz_333 
  // [c9d0]
  0x2e2c20a0, 0x303c44af, 0x1e1c5cec, 0x68261d07,   // sq.fy.fo_322 kk.ug.uz_655  sa.id.ms_644 la.ia.ig_432 
  0x3d301804, 0x39002407, 0x040f10af, 0x10002404,   // ar.uz.ku_332 eo.br.un_420  lt.lv.fi_655 eo.lt.un_320 
  0x304838a4, 0x060c040c, 0x0c3e06ee, 0x35363011,   // tk.tt.uz_433 fi.sv.de_543  de.rm.sv_422 uz.ab.tg_653 
  0x63270207, 0x483017a9, 0x48451b04, 0x0e000c07,   // da.gd.sco_432 sr.uz.tt_544  tr.ln.tt_332 sv.is.un_420 
  // [c9e0]
  0x016512a0, 0x3000231a, 0x35231560, 0x12003819,   // hu.gv.en_322 ky.uz.un_760  un.ky.tg_664 tk.hu.un_750 
  0x04202412, 0x0a3f1f02, 0x16042907, 0x791a6ba7,   // eo.sq.fi_654 cy.af.pt_222  sl.fi.hr_432 ceb.tl.war_532 
  0x0a15070c, 0x65006a22, 0x3f036512, 0x060c57af,   // bg.mk.un_530 haw.gv.un_870  gv.nl.af_654 na.sv.de_655 
  0x080a30a4, 0x38006b02, 0x55121da0, 0x22004f08,   // uz.mk.uk_433 ceb.tk.un_220  la.hu.rw_322 bi.oc.un_430 
  // [c9f0]
  0x28123d04, 0x21000c07, 0x334806ee, 0x0d040c0c,   // ku.ur.sd_332 sv.jw.un_420  de.tt.nn_422 sv.fi.cs_543 
  0x3e0f0607, 0x510705af, 0x486410a9, 0x2d383055,   // de.lv.rm_432 fr.it.kl_655  lt.lg.tt_544 uz.tk.sk_442 
  0x5c2f3002, 0x24500807, 0x06001a02, 0x585107a4,   // uz.su.sa_222 no.fj.eo_432  tl.de.un_220 it.kl.om_433 
  0x3f00651b, 0x15100405, 0x63006513, 0x3000151a,   // gv.af.un_770 ru.be.un_333  gv.sco.un_650 un.uz.un_760 
  // [ca00]
  0x384e3004, 0x15003002, 0x15482aa0, 0x10060fad,   // uz.ay.tk_332 uz.un.un_220  mt.tt.un_322 lv.de.lt_643 
  0x2340060c, 0x58000108, 0x37100402, 0x07425ca9,   // de.lb.ca_543 en.om.un_430  ru.be.ba_222 sa.co.it_544 
  0x0a001507, 0xfc00100b, 0x12fc0304, 0x4760730d,   // un.mk.un_420 lt.zzp.un_520  nl.zzp.hu_332 ny.vo.sn_554 
  0xfc001208, 0x3810fc04, 0x2300300b, 0x48004407,   // hu.zzp.un_430 zzp.lt.tk_332  uz.ky.un_520 kk.tt.un_420 
  // [ca10]
  0x5f1336a4, 0x3810fc0c, 0x04285ca0, 0x257312a9,   // gn.et.tn_433 zzp.lt.tk_543  sa.sw.fi_322 hu.ny.eu_544 
  0x5a005607, 0x5f367305, 0x39532507, 0x233038a9,   // mg.sm.un_420 ny.gn.tn_333  eu.ht.br_432 tk.uz.ky_544 
  0x28213bee, 0x12213d08, 0x17257308, 0x15006307,   // ks.fa.sd_422 ku.fa.ur_443  ny.eu.sr_443 sco.un.un_420 
  0x28025c04, 0x476936a4, 0x3f287308, 0x3810fcaf,   // sa.da.sw_332 gn.mfe.sn_433  ny.sw.af_443 zzp.lt.tk_655 
  // [ca20]
  0x7537390c, 0x37254fad, 0x36003f05, 0x73000104,   // br.st.nso_543 bi.eu.st_643  af.gn.un_330 en.ny.un_320 
  0x1c006308, 0x1a362ead, 0x23001814, 0x56002002,   // sco.id.un_430 fo.gn.tl_643  ar.ky.un_660 sq.mg.un_220 
  0x505d1ca0, 0x4760100c, 0x642006a9, 0x2a2032ee,   // id.ss.fj_322 lt.vo.sn_543  de.sq.lg_544 bs.sq.mt_422 
  0x48001b14, 0x19001b08, 0x02000229, 0x170a3608,   // tr.tt.un_660 tr.gl.un_430  da.da.un_960 ab.mk.sr_443 
  // [ca30]
  0x0100251a, 0x645a1f12, 0x403f06ad, 0x574020af,   // mn.iw.un_760 cy.sm.lg_654  de.af.lb_643 sq.lb.na_655 
  0xfe581c12, 0x0c022007, 0x22130408, 0x470750a6,   // id.om.tlh_654 sq.da.sv_432  fi.et.oc_443 fj.it.sn_521 
  0x47353404, 0x17292d12, 0x04373607, 0x11000a0e,   // xh.zu.sn_332 sk.sl.sr_654  ab.ba.ru_432 pt.ro.un_550 
  0x46003104, 0x31fe46af, 0x281812ad, 0x351530ad,   // az.qu.un_320 qu.tlh.az_655  ur.ar.sd_643 uz.tg.un_630 
  // [ca40]
  0x0a041504, 0x44213dad, 0x48001009, 0x3007350e,   // un.ru.mk_332 ku.fa.kk_643  be.tt.un_440 tg.bg.uz_555 
  0x07230a02, 0x15112311, 0x51542a11, 0x653f04a0,   // mk.ky.bg_222 ky.ro.un_653  mt.ik.kl_653 fi.af.gv_322 
  0xfe204607, 0x55005b12, 0x45561213, 0x3f040304,   // qu.sq.tlh_432 sg.rw.un_640  hu.mg.ln_665 nl.fi.af_332 
  0x78005e22, 0x35453408, 0x15635807, 0x183c300d,   // ts.ve.un_870 xh.ln.zu_443  om.sco.un_432 uz.ug.ar_554 
  // [ca50]
  0x0d002b07, 0x030126a0, 0x0c004704, 0x6b791a04,   // vi.cs.un_420 ia.en.nl_322  sn.sv.un_320 tl.war.ceb_332 
  0x6b1a56a0, 0x3e002b04, 0x566b2f0c, 0x595535ee,   // mg.tl.ceb_322 vi.rm.un_320  su.ceb.mg_543 zu.rw.rn_422 
  0x2f796baf, 0x56796bad, 0x56000404, 0x38002b05,   // ceb.war.su_655 ceb.war.mg_643  fi.mg.un_320 vi.tk.un_330 
  0x0e2e380c, 0x250e2e0d, 0x07234804, 0x0700380d,   // tk.fo.is_543 fo.is.eu_554  tt.ky.bg_332 tk.bg.un_540 
  // [ca60]
  0x1a006b0e, 0x08074407, 0x1f002719, 0x030f3807,   // ceb.tl.un_550 kk.bg.uk_432  gd.cy.un_750 tk.lv.nl_432 
  0x0c200fa4, 0x63581f0c, 0x49003604, 0x1d003904,   // lv.sq.sv_433 cy.om.sco_543  gn.to.un_320 br.la.un_320 
  0x3f003618, 0x0a23440c, 0x01060502, 0x791a2e13,   // gn.af.un_740 kk.ky.mk_543  fr.de.en_222 fo.tl.war_665 
  0x36001508, 0x050115ec, 0x3b274da0, 0x6b1a560c,   // un.gn.un_430 un.en.fr_644  aa.gd.so_322 mg.tl.ceb_543 
  // [ca70]
  0x0f111205, 0x1cfe380d, 0x53050107, 0x23383c07,   // hu.ro.lv_333 tk.tlh.id_554  en.fr.ht_432 ug.tk.ky_432 
  0x043711ad, 0x4c005813, 0x17290fa4, 0x10154407,   // ro.ba.ru_643 om.wo.un_650  lv.sl.sr_433 kk.be.un_420 
  0x392030a0, 0x1d380f04, 0x0f003807, 0x1c06fc0c,   // uz.sq.br_322 lv.tk.la_332  tk.lv.un_420 zzp.de.id_543 
  0x4400350c, 0x06587307, 0x1d002402, 0x082624a4,   // tg.kk.un_530 ny.om.de_432  eo.la.un_220 eo.ia.no_433 
  // [ca80]
  0x64423ba0, 0x301b6104, 0x0f003202, 0x3b0802a4,   // so.co.lg_322 za.tr.uz_332  bs.lv.un_220 da.no.so_433 
  0x3b3006a0, 0x0c3b6b04, 0x3401280c, 0xfe650107,   // de.uz.so_322 ceb.so.sv_332  sd.iw.ps_543 en.gv.tlh_432 
  0x3b00510b, 0x234425a4, 0x603b5814, 0x1d5c3ea4,   // kl.so.un_520 mn.kk.ky_433  om.so.vo_666 rm.sa.la_433 
  0x4d4e3b11, 0x182b36a7, 0x5d3708a0, 0x233c3060,   // so.ay.aa_653 gn.vi.ga_532  no.st.ss_322 uz.ug.ky_664 
  // [ca90]
  0x223e790d, 0x13002212, 0x22052305, 0x5c730cee,   // war.rm.oc_554 oc.et.un_640  ca.fr.oc_333 sv.ny.sa_422 
  0x15041105, 0x351507a7, 0x3035375a, 0x23004823,   // ro.ru.un_333 bg.tg.un_520  ba.tg.uz_553 tt.ky.un_880 
  0x3430180c, 0x1812285a, 0x0200fc20, 0x154844af,   // ar.uz.ps_543 sd.ur.ar_553  zzp.da.un_850 kk.tt.un_655 
  0x372307a0, 0x0a60690d, 0x6a472508, 0x1d4f0d0c,   // bg.ky.ba_322 mfe.vo.pt_554  eu.sn.haw_443 cs.bi.la_543 
  // [caa0]
  0x091c0d11, 0x2c0623a9, 0x20620d0c, 0x12294fec,   // ne.mr.hi_653 ca.de.fy_544  cs.kha.sq_543 bi.sl.hu_644 
  0xfc002707, 0x17480402, 0x0a0d1da9, 0x234718ad,   // gd.zzp.un_420 ru.tt.sr_222  la.cs.pt_544 ga.sn.ca_643 
  0x69005905, 0x400a0212, 0x4d1d0d07, 0x35233c09,   // rn.mfe.un_330 da.pt.lb_654  cs.la.aa_432 ug.ky.tg_444 
  0x483c1704, 0x083504ee, 0x0a30380c, 0x174410a4,   // sr.ug.tt_332 ru.tg.uk_422  tk.uz.mk_543 be.kk.sr_433 
  // [cab0]
  0x234c4d08, 0x0a290da4, 0x574f09ec, 0x06231da0,   // aa.wo.ca_443 cs.sl.pt_433  pl.bi.na_644 la.ca.de_322 
  0x4f1d2d0c, 0x4f000d1a, 0x0d4f6708, 0xfe004d22,   // sk.la.bi_543 cs.bi.un_760  ak.bi.cs_443 aa.tlh.un_870 
  0x735a49ad, 0x02006421, 0x2e390ead, 0x1b342f02,   // to.sm.ny_643 lg.da.un_860  is.br.fo_643 su.xh.tr_222 
  0x0260470c, 0x250564ec, 0x2d0d52a4, 0xfc686404,   // sn.vo.da_543 lg.fr.eu_644  ha.cs.sk_433 lg.ig.zzp_332 
  // [cac0]
  0x5d006119, 0x45004b09, 0x64006314, 0x555e64ad,   // za.ss.un_750 mi.ln.un_440  sco.lg.un_660 lg.ts.rw_643 
  0x565a730c, 0x57000613, 0x16290908, 0xfc5734a4,   // ny.sm.mg_543 de.na.un_650  pl.sl.hr_443 xh.na.zzp_433 
  0x6100641b, 0x0c064004, 0x05000208, 0x4000120b,   // lg.za.un_770 lb.de.sv_332  da.fr.un_430 hu.lb.un_520 
  0x56592805, 0x44373caf, 0x130d5caf, 0x025b69af,   // sw.rn.mg_333 ug.ba.kk_655  sa.ne.bh_655 mfe.sg.da_655 
  // [cad0]
  0x53007607, 0x09006411, 0x5a495007, 0x351f3404,   // crs.ht.un_420 lg.pl.un_630  fj.to.sm_432 xh.cy.zu_332 
  0x6b343507, 0x2348360c, 0x09005c0b, 0x51005414,   // zu.xh.ceb_432 ab.tt.ky_543  sa.hi.un_520 ik.kl.un_660 
  0x21005108, 0x070415a6, 0x07100804, 0x043010a0,   // kl.jw.un_430 un.ru.bg_521  uk.be.bg_332 be.uz.ru_322 
  0x0408100c, 0x4823305a, 0x2e003309, 0x0b003804,   // be.uk.ru_543 uz.ky.tt_553  nn.fo.un_440 tk.es.un_320 
  // [cae0]
  0x342821ee, 0x48002004, 0x0e003312, 0x041038a6,   // fa.sd.ps_422 sq.tt.un_320  nn.is.un_640 tk.be.ru_521 
  0x53020308, 0x2d0d79a4, 0x06003112, 0x2c252755,   // nl.da.ht_443 war.cs.sk_433  az.de.un_640 gd.eu.fy_442 
  0x23252cad, 0x622601a0, 0x2c251808, 0x3e000404,   // fy.eu.ca_643 en.ia.kha_322  ga.eu.fy_443 fi.rm.un_320 
  0x0227180c, 0x2c65250e, 0x2c253302, 0x00003537,   // ga.gd.da_543 eu.gv.fy_555  nn.eu.fy_222 tg.un.un_B00 
  // [caf0]
  0x18272508, 0x65182c08, 0x252c1808, 0x10151707,   // eu.gd.ga_443 fy.ga.gv_443  ga.fy.eu_443 sr.be.un_420 
  0x060227a4, 0x38002004, 0x18001114, 0x3d003419,   // gd.da.de_433 sq.tk.un_320  ro.ga.un_660 ps.ku.un_750 
  0x2a1207a0, 0x313f035a, 0x182334a4, 0x64002a02,   // it.hu.mt_322 nl.af.az_553  ps.ky.ar_433 mt.lg.un_220 
  0x1707370c, 0x68004a19, 0x02002c0d, 0x2f004a0c,   // ba.bg.sr_543 yo.ig.un_750  fy.da.un_540 yo.su.un_530 
  // [cb00]
  0x2c254b0d, 0x4b252cad, 0x2c15010c, 0x6301fc08,   // mi.eu.fy_554 fy.eu.mi_643  en.fy.un_530 zzp.en.sco_443 
  0x27000b08, 0x4500120d, 0xfe15640c, 0xfe006402,   // es.gd.un_430 hu.ln.un_540  lg.tlh.un_530 lg.tlh.un_220 
  0x42000723, 0x15443560, 0x2a005108, 0x64001218,   // it.co.un_880 tg.kk.un_664  kl.mt.un_430 hu.lg.un_740 
  0x044837ad, 0x301035a7, 0x0a3511ee, 0x2548230c,   // ba.tt.ru_643 tg.be.uz_532  ro.tg.mk_422 ky.tt.mn_543 
  // [cb10]
  0x17380804, 0x4831460e, 0x11442308, 0x0a0715ee,   // uk.tk.sr_332 qu.az.tt_555  ky.kk.ro_443 un.bg.mk_422 
  0x381b1e05, 0x10353005, 0x1b584da4, 0x441023ec,   // ms.tr.tk_333 uz.tg.be_333  aa.om.tr_433 ky.be.kk_644 
  0x304435a4, 0x30001c04, 0x33083602, 0x1200620d,   // tg.kk.uz_433 id.uz.un_320  gn.no.nn_222 kha.hu.un_540 
  0x0e2e0d04, 0xfe001208, 0x0c322fee, 0x052523a0,   // cs.fo.is_332 hu.tlh.un_430  su.bs.sv_422 ca.eu.fr_322 
  // [cb20]
  0x30313809, 0x1c212f05, 0x383130a9, 0x154823a9,   // tk.az.uz_444 su.jw.id_333  uz.az.tk_544 ky.tt.un_544 
  0x0c5e390c, 0x5e385fa9, 0x1b5f300c, 0x31305f08,   // br.ts.sv_543 tn.tk.ts_544  uz.tn.tr_543 tn.uz.az_443 
  0x483812a4, 0x48383008, 0x07002307, 0x1700361a,   // hu.tk.tt_433 uz.tk.tt_443  ky.bg.un_420 ab.sr.un_760 
  0x233625a7, 0x390b1207, 0x481b30a9, 0x11001e02,   // mn.ab.ky_532 hu.es.br_432  uz.tr.tt_544 ms.ro.un_220 
  // [cb30]
  0x15084804, 0x37385f12, 0x08073507, 0x12304809,   // tt.uk.un_332 tn.tk.st_654  tg.bg.uk_432 tt.uz.hu_444 
  0x2000100e, 0x48082504, 0x15003102, 0x38375f08,   // lt.sq.un_550 mn.uk.tt_332  az.un.un_220 tn.st.tk_443 
  0x31381b55, 0x203004ec, 0x211230a0, 0x483c30ac,   // tr.tk.az_442 fi.uz.sq_644  uz.ur.fa_322 uz.ug.tt_632 
  0x24002014, 0x17040807, 0x04000f0d, 0x18213dee,   // sq.eo.un_660 uk.ru.sr_432  lv.fi.un_540 ku.fa.ar_422 
  // [cb40]
  0x023b38a7, 0x6b1a5c08, 0x042530a0, 0x11001014,   // tk.so.da_532 sa.tl.ceb_443  uz.mn.ru_322 be.ro.un_660 
  0x38004d0c, 0x38006409, 0x69386408, 0x0f102408,   // aa.tk.un_530 lg.tk.un_440  lg.tk.mfe_443 eo.lt.lv_443 
  0x0a15380c, 0x24002013, 0x643b38ad, 0x1bfe62a7,   // tk.mk.un_530 sq.eo.un_650  tk.so.lg_643 kha.tlh.tr_532 
  0x1b2f4902, 0x3800640e, 0x276218ec, 0x3500fe0b,   // to.su.tr_222 lg.tk.un_550  ga.kha.gd_644 tlh.zu.un_520 
  // [cb50]
  0x4efc31a4, 0x65182711, 0x10697612, 0x21763808,   // az.zzp.ay_433 gd.ga.gv_653  crs.mfe.lt_654 tk.crs.jw_443 
  0x454005a4, 0x6a4f2708, 0x1000211b, 0x115c2608,   // fr.lb.ln_433 gd.bi.haw_443  jw.lt.un_770 ia.sa.ro_443 
  0x313010af, 0x18005712, 0x1d004e0c, 0x38006402,   // lt.uz.az_655 na.ga.un_640  ay.la.un_530 lg.tk.un_220 
  0x69797608, 0x643b380c, 0x28005a07, 0x48005713,   // crs.war.mfe_443 tk.so.lg_543  sm.sw.un_420 na.tt.un_650 
  // [cb60]
  0x18275a60, 0x422205a0, 0x4415100c, 0x0a00050d,   // sm.gd.ga_664 fr.oc.co_322  be.kk.un_530 fr.pt.un_540 
  0x34090dee, 0x4b003207, 0x040c0608, 0x30002321,   // cs.pl.xh_422 bs.mi.un_420  de.sv.fi_443 ky.uz.un_860 
  0x31420a09, 0x044b36a0, 0x373023a4, 0x3508100c,   // pt.co.az_444 gn.mi.fi_322  ky.uz.ba_433 be.uk.tg_543 
  0x65271807, 0x6500460e, 0x15001720, 0x76545cad,   // ga.gd.gv_432 qu.gv.un_550  sr.un.un_850 sa.ik.crs_643 
  // [cb70]
  0x04060c08, 0x19000504, 0x153b5804, 0x040c480d,   // sv.de.fi_443 fr.gl.un_320  om.so.un_332 tt.sv.fi_554 
  0x1d21510c, 0x342404ad, 0x070415a7, 0x4e4601a0,   // kl.jw.la_543 fi.eo.xh_643  un.ru.bg_532 en.qu.ay_322 
  0x26425109, 0x0102fc04, 0x240b2da4, 0x563b39a7,   // kl.co.ia_444 zzp.da.en_332  sk.es.eo_433 br.so.mg_532 
  0x3b626505, 0x1b3848a0, 0x1a7347ad, 0x18790107,   // gv.kha.so_333 tt.tk.tr_322  sn.ny.tl_643 en.war.ga_432 
  // [cb80]
  0x0a0748ee, 0x364e4607, 0x200224ad, 0x25153604,   // tt.bg.mk_422 qu.ay.gn_432  eo.da.sq_643 ab.mn.un_320 
  0x5f4636a7, 0x282947a4, 0x24003908, 0x33360c04,   // gn.qu.tn_532 sn.sl.sw_433  br.eo.un_430 sv.gn.nn_332 
  0x4773280d, 0x1e001a04, 0x1f0265ee, 0x2e0e5207,   // sw.ny.sn_554 tl.ms.un_320  gv.da.cy_422 ha.is.fo_432 
  0x3c374411, 0x792e01a0, 0x240efa0c, 0x060e4708,   // kk.ba.ug_653 en.fo.war_322  nr.is.eo_543 sn.is.de_443 
  // [cb90]
  0x0f006407, 0x135c1cad, 0x1f0e2e05, 0x47732807,   // lg.lv.un_420 mr.sa.bh_643  fo.is.cy_333 sw.ny.sn_432 
  0x1b1c2fa9, 0x2d736304, 0x79262212, 0x24002d02,   // su.id.tr_544 sco.ny.sk_332  oc.ia.war_654 sk.eo.un_220 
  0x37000812, 0xfc002a07, 0x47025eee, 0x49001504,   // uk.ba.un_640 mt.zzp.un_420  ts.da.sn_422 un.to.un_320 
  0x15007907, 0x381f2aa4, 0x38562da9, 0x560d380c,   // war.un.un_420 mt.cy.tk_433  sk.mg.tk_544 tk.cs.mg_543 
  // [cba0]
  0x0d385612, 0x032c3fa4, 0x3b005107, 0x2a00fc04,   // mg.tk.cs_654 af.fy.nl_433  kl.so.un_420 zzp.mt.un_320 
  0x0d003812, 0x1f001505, 0x0a653f02, 0x0d3856ad,   // tk.cs.un_640 un.cy.un_330  af.gv.pt_222 mg.tk.cs_643 
  0x65003502, 0x560d3812, 0x2c330202, 0x02006502,   // zu.gv.un_220 tk.cs.mg_654  da.nn.fy_222 gv.da.un_220 
  0x56003812, 0x2134185a, 0x2d0d38ee, 0x33000c05,   // tk.mg.un_640 ar.ps.fa_553  tk.cs.sk_422 sv.nn.un_330 
  // [cbb0]
  0x44003409, 0x39033fa4, 0x312a51a4, 0x0d00380d,   // ps.kk.un_440 af.nl.br_433  kl.mt.az_433 tk.cs.un_540 
  0x110a1509, 0x5c0d1c02, 0x12560d09, 0x032c3f11,   // un.mk.ro_444 mr.ne.sa_222  cs.mg.hu_444 af.fy.nl_653 
  0x0d4756a4, 0x56003814, 0x6e38560d, 0x1711480d,   // mg.sn.cs_433 tk.mg.un_660  mg.tk.hmn_554 tt.ro.sr_554 
  0x04151555, 0x21343d55, 0x0a303507, 0x3c002105,   // un.ru.un_420 ku.ps.fa_442  tg.uz.mk_432 fa.ug.un_330 
  // [cbc0]
  0x080a1104, 0x42510705, 0x2a005102, 0x120c0eee,   // ro.mk.uk_332 it.kl.co_333  kl.mt.un_220 is.sv.hu_422 
  0x43010204, 0x30071107, 0x442318ad, 0x0a101707,   // da.en.ie_332 ro.bg.uz_432  ar.ky.kk_643 sr.be.mk_432 
  0x2413100c, 0x0b5279a0, 0x211062ad, 0x1e1c3b05,   // lt.et.eo_543 war.ha.es_322  kha.lt.jw_643 so.id.ms_333 
  0x60796ba4, 0x28245a0c, 0x1a244d07, 0x32520d04,   // ceb.war.vo_433 sm.eo.sw_543  aa.eo.tl_432 cs.ha.bs_332 
  // [cbd0]
  0x52160dee, 0x2400100c, 0x04004a0e, 0x0247620c,   // cs.hr.ha_422 lt.eo.un_530  yo.fi.un_550 kha.sn.da_543 
  0x022852a4, 0x421128ad, 0x07201d07, 0x11002f0c,   // ha.sw.da_433 sw.ro.co_643  la.sq.it_432 su.ro.un_530 
  0x0d005221, 0x04120c55, 0x56005221, 0x213418ad,   // ha.cs.un_860 sv.hu.fi_442  ha.mg.un_860 ar.ps.fa_643 
  0x59551ca4, 0x50002205, 0x09430d07, 0x1a005e22,   // id.rw.rn_433 oc.fj.un_330  cs.ie.pl_432 ts.tl.un_870 
  // [cbe0]
  0x26000723, 0x2448200c, 0x591255ee, 0x5a534b09,   // it.ia.un_880 sq.tt.eo_543  rw.hu.rn_422 mi.ht.sm_444 
  0x160d2408, 0x1b524304, 0x09483bee, 0x55575908,   // eo.cs.hr_443 ie.ha.tr_332  so.tt.pl_422 rn.na.rw_443 
  0x1c5052a9, 0x17070dee, 0x50000108, 0x0e2c0aa4,   // ha.fj.id_544 cs.it.sr_422  en.fj.un_430 pt.fy.is_433 
  0x51005004, 0x0742220c, 0x173023ad, 0x123f0305,   // fj.kl.un_320 oc.co.it_543  ky.uz.sr_643 nl.af.hu_333 
  // [cbf0]
  0x391c3f07, 0x2f003e0c, 0x353451a0, 0x48374405,   // af.id.br_432 rm.su.un_530  kl.xh.zu_322 kk.ba.tt_333 
  0x0a110707, 0x3b123d0c, 0x1e1cfeee, 0x0a36150b,   // bg.ro.mk_432 ku.ur.ks_543  tlh.id.ms_422 un.ab.mk_542 
  0x15373008, 0x15070a0c, 0x484630ad, 0x5430510c,   // uz.ba.un_443 mk.bg.un_543  uz.qu.tt_643 kl.uz.ik_543 
  0x3400fc04, 0x3035380b, 0x37443c12, 0x06001211,   // zzp.xh.un_320 tk.tg.uz_542  ug.kk.ba_654 hu.de.un_630 
  
  // [cc00]
  0x0a3707a9, 0x35074404, 0x13120404, 0x0f172912,   // bg.ba.mk_544 kk.bg.tg_332  fi.hu.et_332 sl.sr.lv_654 
  0x23220507, 0x69513ea4, 0x48240b04, 0x382230a9,   // fr.oc.ca_432 rm.kl.mfe_433  es.eo.tt_332 uz.oc.tk_544 
  0xfc4011a7, 0x045e3505, 0x29100904, 0x101b0fa0,   // ro.lb.zzp_532 zu.ts.fi_333  pl.lt.sl_332 lv.tr.lt_322 
  0x1b002519, 0x37443c0c, 0x25334704, 0x03375fee,   // eu.tr.un_750 ug.kk.ba_543  sn.nn.eu_332 tn.st.nl_422 
  // [cc10]
  0x0e004804, 0x36052304, 0x24001219, 0x1f095ca0,   // tt.is.un_320 ca.fr.gn_332  hu.eo.un_750 sa.pl.cy_322 
  0x156307ee, 0x1f0676ee, 0x0c581c07, 0x303548af,   // it.sco.un_422 crs.de.cy_422  id.om.sv_432 tt.tg.uz_655 
  0x10002009, 0x5100270d, 0x162d0d04, 0x02003013,   // sq.lt.un_440 gd.kl.un_540  cs.sk.hr_332 uz.da.un_650 
  0x040b20a7, 0x63673011, 0x381b25af, 0x10002e21,   // sq.es.fi_532 uz.ak.sco_653  eu.tr.tk_655 fo.lt.un_860 
  // [cc20]
  0xfc00580d, 0x0e1125ad, 0x1f38250c, 0x0200fe0d,   // om.zzp.un_540 eu.ro.is_643  eu.tk.cy_543 tlh.da.un_540 
  0x4800130d, 0x59004709, 0x08003f02, 0x0e060c02,   // et.tt.un_540 sn.rn.un_440  af.no.un_220 sv.de.is_222 
  0x5a0154a7, 0xfc0f1011, 0x2c000a1a, 0x060c0407,   // ik.en.sm_532 lt.lv.zzp_653  pt.fy.un_760 fi.sv.de_432 
  0x79001d08, 0x530515ee, 0x06005e04, 0x4800fc02,   // la.war.un_430 un.fr.ht_422  ts.de.un_320 zzp.tt.un_220 
  // [cc30]
  0x17000a11, 0x55001f02, 0x254437a4, 0x2e003308,   // mk.sr.un_630 cy.rw.un_220  ba.kk.mn_433 nn.fo.un_430 
  0x0407480c, 0x48000607, 0x100738a0, 0x3f0165a0,   // tt.bg.ru_543 de.tt.un_420  tk.bg.be_322 gv.en.af_322 
  0x393618a4, 0x46190b13, 0x01533fa7, 0x38234414,   // ga.gn.br_433 es.gl.qu_665  af.ht.en_532 kk.ky.tk_666 
  0x230a0707, 0x350a3004, 0x1015350c, 0x48001523,   // bg.mk.ky_432 uz.mk.tg_332  tg.be.un_530 un.tt.un_880 
  // [cc40]
  0x150411af, 0x0d095ca0, 0xfc016307, 0x2335110c,   // ro.ru.un_655 sa.hi.ne_322  sco.en.zzp_432 ro.tg.ky_543 
  0x4a005319, 0x34003c19, 0x4823380b, 0x21341211,   // ht.yo.un_750 ug.ps.un_750  tk.ky.tt_542 ur.ps.fa_653 
  0x302344a9, 0x5600420d, 0x2b18420c, 0x4a00182b,   // kk.ky.uz_544 co.mg.un_540  co.ga.vi_543 ga.yo.un_980 
  0x2f422107, 0x232b4aaf, 0x23303c60, 0x4c184aad,   // jw.co.su_432 yo.vi.ca_655  ug.uz.ky_664 yo.ga.wo_643 
  // [cc50]
  0x49004a13, 0x2f004a2a, 0x24002a13, 0x484423a9,   // yo.to.un_650 yo.su.un_970  mt.eo.un_650 ky.kk.tt_544 
  0x56000a0d, 0x2500172b, 0x5b454a12, 0x5c000d2c,   // pt.mg.un_540 sr.mn.un_980  yo.ln.sg_654 ne.sa.un_990 
  0x0a174402, 0x4a0e1812, 0x303538af, 0x10001209,   // kk.sr.mk_222 ga.is.yo_654  tk.tg.uz_655 hu.lt.un_440 
  0x461210a0, 0x3f011d0c, 0x592f4a11, 0x4a4c23a9,   // lt.hu.qu_322 la.en.af_543  yo.su.rn_653 ca.wo.yo_544 
  // [cc60]
  0x04120c04, 0x030602ee, 0x10000204, 0x5c1506a4,   // sv.hu.fi_332 da.de.nl_422  da.lt.un_320 de.sa.un_430 
  0x0c001d12, 0x063403a0, 0x06127904, 0x3f00fe09,   // la.sv.un_640 nl.xh.de_322  war.hu.de_332 tlh.af.un_440 
  0x3b650f02, 0x18341209, 0xfc001812, 0x040c12a4,   // lv.gv.so_222 ur.ps.ar_444  ga.zzp.un_640 hu.sv.fi_433 
  0x48fc25a0, 0x2c090204, 0x02000c09, 0x03003602,   // eu.zzp.tt_322 da.pl.fy_332  sv.da.un_440 gn.nl.un_220 
  // [cc70]
  0x120e0c08, 0x120602ee, 0x0c001208, 0x12060c05,   // sv.is.hu_443 da.de.hu_422  hu.sv.un_430 sv.de.hu_333 
  0x180163a7, 0x1d002302, 0x1d091f0c, 0x030233ee,   // sco.en.ga_532 ca.la.un_220  cy.pl.la_543 nn.da.nl_422 
  0x21123d13, 0x0400120b, 0x46000102, 0x1221300e,   // ku.ur.fa_665 hu.fi.un_520  en.qu.un_220 uz.fa.ur_555 
  0x341328a0, 0x1f0165ad, 0x0c0612a4, 0x120c0608,   // sw.et.xh_322 gv.en.cy_643  hu.de.sv_433 de.sv.hu_443 
  // [cc80]
  0x073c3007, 0x060c1255, 0x3500280d, 0x130d1ca9,   // uz.ug.bg_432 hu.sv.de_442  sw.zu.un_540 mr.ne.bh_544 
  0x23212804, 0x301523a9, 0x27000102, 0x27002519,   // sd.fa.ky_332 ky.uz.un_540  en.gd.un_220 eu.gd.un_750 
  0x65302011, 0x200424ee, 0x3000040d, 0x4c006e2b,   // sq.uz.gv_653 eo.fi.sq_422  fi.uz.un_540 hmn.wo.un_980 
  0x16000407, 0x0d2301a0, 0x23190ba9, 0x3202160c,   // fi.hr.un_420 en.ca.cs_322  es.gl.ca_544 hr.da.bs_543 
  // [cc90]
  0x4c406ead, 0x2d1048ee, 0x1d00fc08, 0x1725230d,   // hmn.lb.wo_643 tt.lt.sk_422  zzp.la.un_430 ky.mn.sr_554 
  0x31005002, 0x4c005005, 0x0c000e11, 0x070501a0,   // fj.az.un_220 fj.wo.un_330  is.sv.un_630 en.fr.it_322 
  0x150708a6, 0x0a006e04, 0x070417ee, 0x24041755,   // uk.bg.un_521 hmn.pt.un_320  sr.ru.bg_422 sr.fi.eo_442 
  0x564704ad, 0x4c63010c, 0x042024ac, 0x6e006307,   // fi.sn.mg_643 en.sco.wo_543  eo.sq.fi_632 sco.hmn.un_420 
  // [cca0]
  0x123f24ec, 0x13006e09, 0x2c000a02, 0x6b000804,   // eo.af.hu_644 hmn.et.un_440  pt.fy.un_220 no.ceb.un_320 
  0x3d18230c, 0x3c35300e, 0x42001022, 0x253315ad,   // ky.ar.ku_543 uz.tg.ug_555  lt.co.un_870 un.nn.eu_643 
  0x25001222, 0x424301a9, 0x08153505, 0x62000108,   // hu.eu.un_870 en.ie.co_544  tg.uk.un_330 en.kha.un_430 
  0x1d002507, 0x0b6b1a0d, 0x03000619, 0x221c48a0,   // eu.la.un_420 tl.ceb.es_554  de.nl.un_750 tt.id.oc_322 
  // [ccb0]
  0x0a1511a4, 0x4a005604, 0x495f37a4, 0x495f5a13,   // ro.mk.un_430 mg.yo.un_320  st.tn.to_433 sm.tn.to_665 
  0x490c56a9, 0x3100fe04, 0x2b006502, 0x733756a4,   // mg.sv.to_544 tlh.az.un_320  gv.vi.un_220 mg.st.ny_433 
  0x565a61a9, 0x15005a0d, 0x3700751a, 0x3f001e02,   // za.sm.mg_544 sm.un.un_540  nso.st.un_760 ms.af.un_220 
  0x1015040d, 0x495a67ec, 0x04103705, 0x0e000c09,   // ru.be.un_540 ak.sm.to_644  ba.be.ru_333 sv.is.un_440 
  // [ccc0]
  0x1c00130d, 0x35170aa0, 0x0a301507, 0x442338a6,   // bh.mr.un_540 mk.sr.tg_322  un.uz.mk_432 tk.ky.kk_521 
  0x17232508, 0x44373004, 0x65001823, 0x24566760,   // mn.ky.sr_443 uz.ba.kk_332  ga.gv.un_880 ak.mg.eo_664 
  0x2a1506a7, 0x73561204, 0x2a003b0d, 0x56495a11,   // de.mt.un_520 hu.mg.ny_332  so.mt.un_540 sm.to.mg_653 
  0x095c1360, 0x181e1c13, 0x3c383013, 0x0a111da9,   // bh.sa.hi_664 id.ms.ga_665  uz.tk.ug_665 la.ro.pt_544 
  // [ccd0]
  0x605c33a0, 0x08001d02, 0x60002d13, 0x62221ca4,   // nn.sa.vo_322 la.no.un_220  sk.vo.un_650 id.oc.kha_433 
  0x1b000402, 0x30442307, 0x4d4c5ca9, 0x5c4d4c5a,   // fi.tr.un_220 ky.kk.uz_432  sa.wo.aa_544 wo.aa.sa_553 
  0x315cfea9, 0x484c3809, 0x1d465c0d, 0x35370a12,   // tlh.sa.az_544 tk.wo.tt_444  sa.qu.la_554 mk.ba.tg_654 
  0x48383c55, 0x385c600c, 0x233c48ad, 0xfe4d4609,   // ug.tk.tt_442 vo.sa.tk_543  tt.ug.ky_643 qu.aa.tlh_444 
  // [cce0]
  0x0c006504, 0x65005707, 0x34276502, 0x0e000402,   // gv.sv.un_320 na.gv.un_420  gv.gd.xh_222 fi.is.un_220 
  0x093f0307, 0x30004422, 0x2530150d, 0x0612fc0e,   // nl.af.pl_432 kk.uz.un_870  un.uz.mn_554 zzp.hu.de_555 
  0x33006e08, 0x6b390107, 0xfc3f03a0, 0x04001018,   // hmn.nn.un_430 en.br.ceb_432  nl.af.zzp_322 be.ru.un_740 
  0x34005008, 0x48233812, 0x0d001f05, 0x28000602,   // fj.xh.un_430 tk.ky.tt_654  cy.cs.un_330 de.sw.un_220 
  // [ccf0]
  0x34005108, 0x3500fc05, 0x34000702, 0x3f002f07,   // kl.xh.un_430 zzp.zu.un_330  it.xh.un_220 su.af.un_420 
  0x3f4039a4, 0x2f393fad, 0x4a0d2d12, 0x51003407,   // br.lb.af_433 af.br.su_643  sk.cs.yo_654 xh.kl.un_420 
  0x1f190b0e, 0x391f40af, 0x12000c0d, 0x080a170c,   // es.gl.cy_555 lb.cy.br_655  sv.hu.un_540 sr.mk.uk_543 
  0x30001b13, 0x2c00390b, 0x482a46a0, 0x2e521fa0,   // tr.uz.un_650 br.fy.un_520  qu.mt.tt_322 cy.ha.fo_322 
  // [cd00]
  0x23003e07, 0x48004609, 0x48003123, 0x38004602,   // rm.ca.un_420 qu.tt.un_440  az.tt.un_880 qu.tk.un_220 
  0x2a00510c, 0x1f2e390c, 0x010a39a0, 0x18443407,   // kl.mt.un_530 br.fo.cy_543  br.pt.en_322 ps.kk.ar_432 
  0x2a00511b, 0x4804370e, 0x19601f07, 0x10070aec,   // kl.mt.un_770 ba.ru.tt_555  cy.vo.gl_432 mk.bg.be_644 
  0x1f645f07, 0x2f3902a6, 0x050701a4, 0x15753713,   // tn.lg.cy_432 da.br.su_521  en.it.fr_433 st.nso.un_665 
  // [cd10]
  0x12002e14, 0x0a003604, 0x355e1fee, 0x184301a0,   // fo.hu.un_660 ab.mk.un_320  cy.ts.zu_422 en.ie.ga_322 
  0x0f001f07, 0x5f58510c, 0x040742ee, 0x3f005112,   // cy.lv.un_420 kl.om.tn_543  co.it.fi_422 kl.af.un_640 
  0x15114805, 0x3b134bad, 0x0c00091a, 0x03513f08,   // tt.ro.un_333 mi.et.so_643  pl.sv.un_760 af.kl.nl_443 
  0x3b584d14, 0x153611ec, 0x1f003b04, 0x301223ad,   // aa.om.so_666 ro.ab.un_644  so.cy.un_320 ky.ur.uz_643 
  // [cd20]
  0x3b514d09, 0x3f035fa0, 0x5c0e2eec, 0x124d6407,   // aa.kl.so_444 tn.nl.af_322  fo.is.sa_644 lg.aa.hu_432 
  0x4d003b19, 0x30480a04, 0x122a64ee, 0x1b5230a4,   // so.aa.un_750 mk.tt.uz_332  lg.mt.hu_422 uz.ha.tr_433 
  0x1d006b08, 0x64002a13, 0x42122aa0, 0x30373809,   // ceb.la.un_430 mt.lg.un_650  mt.hu.co_322 tk.ba.uz_444 
  0x584c3bec, 0x4a001321, 0xfe002a14, 0x4700780e,   // so.wo.om_644 et.yo.un_860  mt.tlh.un_660 ve.sn.un_550 
  // [cd30]
  0x5955640e, 0x584c3ba9, 0x033f540c, 0x2a000708,   // lg.rw.rn_555 so.wo.om_544  ik.af.nl_543 it.mt.un_430 
  0x35301105, 0x583f030c, 0x122a4d04, 0x4d58510c,   // ro.uz.tg_333 nl.af.om_543  aa.mt.hu_332 kl.om.aa_543 
  0x64522a08, 0x4c513b0d, 0x5b002d04, 0x4a3f51a4,   // mt.ha.lg_443 so.kl.wo_554  sk.sg.un_320 kl.af.yo_433 
  0x51004d22, 0x10792405, 0x25002d04, 0x4d64520c,   // aa.kl.un_870 eo.war.lt_333  sk.eu.un_320 ha.lg.aa_543 
  // [cd40]
  0x17595255, 0x39295ea9, 0x01005804, 0x101639a7,   // ha.rn.sr_442 ts.sl.br_544  om.en.un_320 br.hr.lt_532 
  0x12002a0c, 0x55001508, 0x08582a07, 0x28001705,   // mt.hu.un_530 un.rw.un_430  mt.om.no_432 sr.sw.un_330 
  0x19230bec, 0x49130412, 0x321655a0, 0x06521211,   // es.ca.gl_644 fi.et.to_654  rw.hr.bs_322 hu.ha.de_653 
  0x62004c08, 0x5831fe13, 0x1d554702, 0x30001809,   // wo.kha.un_430 tlh.az.om_665  sn.rw.la_222 ar.uz.un_440 
  // [cd50]
  0x1d280304, 0x1a6b0c0c, 0x29103eee, 0x343018ad,   // nl.sw.la_332 sv.ceb.tl_543  rm.lt.sl_422 ar.uz.ps_643 
  0x12390d0b, 0x3717115a, 0x2f21670c, 0x48003519,   // cs.br.hu_542 ro.sr.ba_553  ak.jw.su_543 tg.tt.un_750 
  0x0d352804, 0x040725ad, 0x18213ca4, 0x4408170c,   // sw.zu.cs_332 mn.bg.ru_643  ug.fa.ar_433 sr.uk.kk_543 
  0x071011ee, 0x303d180c, 0x04351507, 0x383c30ec,   // ro.be.bg_422 ar.ku.uz_543  un.tg.ru_432 uz.ug.tk_644 
  // [cd60]
  0x07003c0d, 0x30080402, 0x5300691a, 0x222d0dee,   // ug.bg.un_540 ru.uk.uz_222  mfe.ht.un_760 cs.sk.oc_422 
  0x35002309, 0x18002309, 0x13001c0e, 0x28171304,   // ky.tg.un_440 ky.ar.un_440  mr.bh.un_550 et.sr.sw_332 
  0xfc001513, 0x76061f0c, 0x30382313, 0x0a0715a6,   // un.zzp.un_650 cy.de.crs_543  ky.tk.uz_665 un.bg.mk_521 
  0x76000108, 0x08440405, 0x5d645209, 0x525c1507,   // en.crs.un_430 ru.kk.uk_333  ha.lg.ss_444 un.sa.ha_432 
  // [cd70]
  0x58134d0b, 0x2f350204, 0x25315204, 0xfc4d0107,   // aa.et.om_542 da.zu.su_332  ha.az.eu_332 en.aa.zzp_432 
  0x13043ba4, 0x3b001313, 0x4d003b23, 0x0a1711af,   // so.fi.et_433 et.so.un_650  so.aa.un_880 ro.sr.mk_655 
  0x584d3b11, 0x3f1f0ea4, 0x122e0e04, 0x3f3b02a9,   // so.aa.om_653 is.cy.af_433  is.fo.hu_332 da.so.af_544 
  0x022555a4, 0x48070455, 0x592f5508, 0x3b3534ee,   // rw.eu.da_433 ru.bg.tt_442  rw.su.rn_443 xh.zu.so_422 
  // [cd80]
  0x59555da4, 0x796b1c07, 0x1a6b48a4, 0x3bfc15a4,   // ss.rw.rn_433 id.ceb.war_432  tt.ceb.tl_433 un.zzp.so_433 
  0xfc133b08, 0x3b4834ee, 0x40583b08, 0x093b1307,   // so.et.zzp_443 xh.tt.so_422  so.om.lb_443 et.so.pl_432 
  0x3700130b, 0x070a3708, 0x351510a7, 0x06004819,   // et.st.un_520 ba.mk.bg_443  be.tg.un_520 tt.de.un_750 
  0x100f1705, 0x070435a0, 0x61003622, 0x02001912,   // sr.lv.lt_333 tg.ru.bg_322  gn.za.un_870 gl.da.un_640 
  // [cd90]
  0x3534feee, 0x15352512, 0x35302502, 0x30004605,   // tlh.xh.zu_422 mn.tg.un_654  mn.uz.tg_222 qu.uz.un_330 
  0x29002d22, 0x18154355, 0x13002011, 0x2d002909,   // sk.sl.un_870 ie.ga.un_420  sq.et.un_630 sl.sk.un_440 
  0x10002002, 0x35000a07, 0x22001f13, 0x03050207,   // sq.lt.un_220 mk.tg.un_420  cy.oc.un_650 da.fr.nl_432 
  0x3f002507, 0x0c033f55, 0x2400091a, 0x23004002,   // eu.af.un_420 af.nl.sv_442  pl.eo.un_760 lb.ca.un_220 
  // [cda0]
  0x22115012, 0x03023f02, 0x793f4a0c, 0x23000619,   // fj.ro.oc_654 af.da.nl_222  yo.af.war_543 de.ca.un_750 
  0x060a23a4, 0x0a00250b, 0x04080a07, 0x3106795a,   // ca.pt.de_433 mn.mk.un_520  mk.uk.ru_432 war.de.az_553 
  0x330848a0, 0x21003e0e, 0x2d0d5802, 0x060d3f0c,   // tt.no.nn_322 rm.jw.un_550  om.cs.sk_222 af.cs.de_543 
  0x03273fa0, 0x483e22a7, 0x3f431f0c, 0x12001b09,   // af.gd.nl_322 oc.rm.tt_532  cy.ie.af_543 tr.hu.un_440 
  // [cdb0]
  0x35443013, 0x1f1924a4, 0x071f4912, 0x02253607,   // uz.kk.tg_665 eo.gl.cy_433  to.cy.it_654 gn.eu.da_432 
  0xfc004312, 0x213412a6, 0x2dfc4307, 0x08302507,   // ie.zzp.un_640 ur.ps.fa_521  ie.zzp.sk_432 mn.uz.uk_432 
  0x2f003813, 0x644a67ec, 0x4c006712, 0x57003929,   // tk.su.un_650 ak.yo.lg_644  ak.wo.un_640 br.na.un_960 
  0x01004802, 0x1306600b, 0x10241f04, 0xfc433b60,   // tt.en.un_220 vo.de.et_542  cy.eo.lt_332 so.ie.zzp_664 
  // [cdc0]
  0x23fc430c, 0x3530250c, 0x21343d04, 0x3831fe0c,   // ie.zzp.ca_543 mn.uz.tg_543  ku.ps.fa_332 tlh.az.tk_543 
  0x37042507, 0x1c671e11, 0x04493fa0, 0x13374907,   // mn.ru.ba_432 ms.ak.id_653  af.to.fi_322 to.st.et_432 
  0x03001304, 0x11303cec, 0x65353408, 0x530a2207,   // et.nl.un_320 ug.uz.ro_644  xh.zu.gv_443 oc.pt.ht_432 
  0x34002102, 0x2c4803a0, 0x07000304, 0x19001d02,   // fa.ps.un_220 nl.tt.fy_322  nl.it.un_320 la.gl.un_220 
  // [cdd0]
  0x0334fea6, 0x2300210c, 0x25003c13, 0x2c650304,   // tlh.xh.nl_521 jw.ca.un_530  ug.mn.un_650 nl.gv.fy_332 
  0x2c3f0311, 0x1830565a, 0x28003d0d, 0x48000618,   // nl.af.fy_653 mg.uz.ga_553  ku.sd.un_540 de.tt.un_740 
  0xfe1d46ad, 0x07004212, 0x22461d5a, 0x3d2134ee,   // qu.la.tlh_643 co.it.un_640  la.qu.oc_553 ps.fa.ku_422 
  0x301b310c, 0x02041304, 0x13065ca4, 0x38301b07,   // az.tr.uz_543 et.fi.da_332  sa.de.et_433 tr.uz.tk_432 
  // [cde0]
  0x3b301007, 0x1f001221, 0x6b031d07, 0x30fc1a04,   // lt.uz.so_432 hu.cy.un_860  la.nl.ceb_432 tl.zzp.uz_332 
  0x56100404, 0x1700150e, 0x190b3e04, 0x31001f07,   // fi.lt.mg_332 un.sr.un_550  rm.es.gl_332 cy.az.un_420 
  0x3b383f08, 0x1b483008, 0x100a0709, 0x481d4607,   // af.tk.so_443 uz.tt.tr_443  bg.mk.be_444 qu.la.tt_432 
  0x1d00460d, 0x4c523005, 0x5a276504, 0x265376a4,   // qu.la.un_540 uz.ha.wo_333  gv.gd.sm_332 crs.ht.ia_433 
  // [cdf0]
  0x38311bee, 0x5a697612, 0x484630a9, 0x063e790c,   // tr.az.tk_422 crs.mfe.sm_654  uz.qu.tt_544 war.rm.de_543 
  0x1f1046a0, 0x12002a05, 0x4823250b, 0x4700100c,   // qu.lt.cy_322 mt.hu.un_330  mn.ky.tt_542 lt.sn.un_530 
  0x5c001314, 0x34353704, 0x2718655a, 0x3e001f07,   // bh.sa.un_660 st.zu.xh_332  gv.ga.gd_553 cy.rm.un_420 
  0x4300270e, 0xfc005a04, 0x31001b11, 0x36380704,   // gd.ie.un_550 sm.zzp.un_320  tr.az.un_630 bg.tk.ab_332 
  // [ce00]
  0x355573a7, 0x44252302, 0x56000e13, 0x13002502,   // ny.rw.zu_532 ky.mn.kk_222  is.mg.un_650 eu.et.un_220 
  0x1738045a, 0x24736004, 0x30003609, 0x0b001f02,   // ru.tk.sr_553 vo.ny.eo_332  ab.uz.un_440 cy.es.un_220 
  0x3b002004, 0x2704180c, 0x3504175a, 0x194722a0,   // sq.so.un_320 ga.fi.gd_543  sr.ru.tg_553 oc.sn.gl_322 
  0x18002202, 0x51002c02, 0x021b3108, 0x43604712,   // oc.ga.un_220 fy.kl.un_220  az.tr.da_443 sn.vo.ie_654 
  // [ce10]
  0x0a2d0d0e, 0x04510107, 0x111e1c0d, 0x02002a1a,   // cs.sk.pt_555 en.kl.fi_432  id.ms.ro_554 mt.da.un_760 
  0xfc790105, 0x1f5a5cec, 0x320917a4, 0x17371111,   // en.war.zzp_333 sa.sm.cy_644  sr.pl.bs_433 ro.ba.sr_653 
  0x15025304, 0x42223ea0, 0x09110fa4, 0x6a5f67a4,   // ht.da.un_332 rm.oc.co_322  lv.ro.pl_433 ak.tn.haw_433 
  0x05524dad, 0x370a17a7, 0x420207a4, 0x293f0355,   // aa.ha.fr_643 sr.mk.ba_532  it.da.co_433 nl.af.sl_442 
  // [ce20]
  0x65074208, 0x113823ad, 0x640e0c07, 0x1e1c1fee,   // co.it.gv_443 ky.tk.ro_643  sv.is.lg_432 cy.id.ms_422 
  0x233c15ad, 0x23487904, 0x0c001204, 0x330cfcec,   // un.ug.ky_643 war.tt.ca_332  hu.sv.un_320 zzp.sv.nn_644 
  0x0c001b08, 0x0c33080e, 0x5e3ffc07, 0x4d001323,   // tr.sv.un_430 no.nn.sv_555  zzp.af.ts_432 et.aa.un_880 
  0x020303a4, 0x3e5651ad, 0x51003012, 0x0e0c12a9,   // nl.nl.da_433 kl.mg.rm_643  uz.kl.un_640 hu.sv.is_544 
  // [ce30]
  0xfc0327ee, 0x06120c02, 0x3f02fca0, 0x1200fc07,   // gd.nl.zzp_422 sv.hu.de_222  zzp.da.af_322 zzp.hu.un_420 
  0x11002b02, 0x01651507, 0x5100630c, 0x09002a0e,   // vi.ro.un_220 un.gv.en_432  sco.kl.un_530 mt.pl.un_550 
  0x3e0610a0, 0x063e61a9, 0xfc3f6502, 0x2d006e0e,   // lt.de.rm_322 za.rm.de_544  gv.af.zzp_222 hmn.sk.un_550 
  0x0c03fca7, 0x0f00730c, 0x0a002b02, 0x0640fcec,   // zzp.nl.sv_532 ny.lv.un_530  vi.pt.un_220 zzp.lb.de_644 
  // [ce40]
  0x3308fc02, 0x2f002b02, 0x250448a4, 0x06512509,   // zzp.no.nn_222 vi.su.un_220  tt.ru.mn_433 eu.kl.de_444 
  0x3e400604, 0x443c3012, 0x02000804, 0x23250407,   // de.lb.rm_332 uz.ug.kk_654  no.da.un_320 ru.mn.ky_432 
  0x42533807, 0x170a25a4, 0x07002207, 0x07234204,   // tk.ht.co_432 mn.mk.sr_433  oc.it.un_420 co.ca.it_332 
  0x48153709, 0x38074255, 0x04003719, 0x375a6a0b,   // ba.tt.un_440 co.it.tk_442  st.fi.un_750 haw.sm.st_542 
  // [ce50]
  0x4423480d, 0x13154304, 0x13003707, 0x1500fe0d,   // tt.ky.kk_554 ie.et.un_320  st.et.un_420 tlh.un.un_540 
  0x04301104, 0x37005a0e, 0x311b480b, 0x28251f0d,   // ro.uz.ru_332 sm.st.un_550  tt.tr.az_542 cy.eu.sw_554 
  0x19091fa4, 0x041007a0, 0x34004a02, 0x11003907,   // cy.pl.gl_433 bg.be.ru_322  yo.xh.un_220 br.ro.un_420 
  0x1f394702, 0x0200fc07, 0x391d1fee, 0x1d1f4608,   // sn.br.cy_222 zzp.da.un_420  cy.la.br_422 qu.cy.la_443 
  // [ce60]
  0x695901a0, 0x0f3217a4, 0x2c0c3fee, 0x483735a0,   // en.rn.mfe_322 sr.bs.lv_433  af.sv.fy_422 tg.ba.tt_322 
  0x62002122, 0x17071508, 0x2a1f21a6, 0x13002f09,   // jw.kha.un_870 un.bg.sr_443  jw.cy.mt_521 su.et.un_440 
  0x2a033fa0, 0x1f07650c, 0x32000f08, 0x46353404,   // af.nl.mt_322 gv.it.cy_543  lv.bs.un_430 xh.zu.qu_332 
  0x3f006b08, 0x033f3e12, 0x304831a9, 0x16001814,   // ceb.af.un_430 rm.af.nl_654  az.tt.uz_544 ar.th.un_660 
  // [ce70]
  0x36040808, 0x282118a6, 0x55475911, 0x16100fa7,   // uk.ru.ab_443 ar.fa.sd_521  rn.sn.rw_653 lv.lt.hr_532 
  0x3048380e, 0x08000c0e, 0x29001b07, 0x331330ad,   // tk.tt.uz_555 sv.no.un_550  tr.sl.un_420 uz.et.nn_643 
  0x4e3046a9, 0x4c00201a, 0x061330ac, 0x4c00200e,   // qu.uz.ay_544 sq.wo.un_760  uz.et.de_632 sq.wo.un_550 
  0x24001b04, 0x301711ec, 0x133009a4, 0x13005804,   // tr.eo.un_320 ro.sr.uz_644  pl.uz.et_433 om.et.un_320 
  // [ce80]
  0x360a3ca4, 0x0a1515ee, 0x0f1b3060, 0x3c003d04,   // ug.mk.ab_433 un.mk.un_420  uz.tr.lv_664 ku.ug.un_320 
  0x44231155, 0x1300300d, 0x05001104, 0x4e5130a9,   // ro.ky.kk_442 uz.et.un_540  ro.fr.un_320 uz.kl.ay_544 
  0x361725ec, 0x23003811, 0x330c08a7, 0x07000822,   // mn.sr.ab_644 tk.ky.un_630  no.sv.nn_532 uk.bg.un_870 
  0x537969ad, 0x64003707, 0x243369a7, 0x2e3612ee,   // mfe.war.ht_643 st.lg.un_420  mfe.nn.eo_532 hu.gn.fo_422 
  // [ce90]
  0x17162d05, 0x2a003911, 0x0a30080c, 0x07253c55,   // sk.hr.sr_333 dz.bo.un_630  uk.uz.mk_543 ug.mn.bg_442 
  0x04170aa6, 0x30041555, 0x443715a4, 0x4a004908,   // mk.sr.ru_521 un.ru.uz_442  un.ba.kk_433 to.yo.un_430 
  0x09004814, 0x5a005604, 0x29201308, 0x1d063907,   // tt.pl.un_660 mg.sm.un_320  et.sq.sl_443 br.de.la_432 
  0x2f1261a0, 0x0e120ca9, 0x3500302b, 0x23041004,   // za.hu.su_322 sv.hu.is_544  uz.tg.un_980 be.ru.ky_332 
  // [cea0]
  0x070a36a7, 0x1b002a0c, 0x04151708, 0x5efc73a4,   // ab.mk.bg_532 mt.tr.un_530  sr.ru.un_430 ny.zzp.ts_433 
  0x08004409, 0x12002822, 0x1000080b, 0xfc003702,   // kk.uk.un_440 sd.ur.un_870  uk.be.un_520 st.zzp.un_220 
  0x12283b12, 0xfc631f0c, 0x1100301b, 0x5a041107,   // ks.sd.ur_654 cy.sco.zzp_543  uz.ro.un_770 ro.fi.sm_432 
  0x0400111a, 0x1c5c130c, 0x045f4704, 0x04003619,   // ro.fi.un_760 bh.sa.mr_543  sn.tn.fi_332 gn.fi.un_750 
  // [ceb0]
  0x5a001107, 0x241b3855, 0x1156670c, 0x2d0dfeec,   // ro.sm.un_420 tk.tr.eo_442  ak.mg.ro_543 tlh.cs.sk_644 
  0x0136110c, 0x171515ec, 0x043510a0, 0x123824a7,   // ro.gn.en_543 un.sr.un_640  be.tg.ru_322 eo.tk.hu_532 
  0x08071704, 0x47001104, 0x16292da4, 0x04115605,   // sr.bg.uk_332 ro.sn.un_320  sk.sl.hr_433 mg.ro.fi_333 
  0x68553508, 0x382344a4, 0x040211ee, 0x28000104,   // zu.rw.ig_443 kk.ky.tk_433  ro.da.fi_422 en.sw.un_320 
  // [cec0]
  0x605a01a0, 0x220211a6, 0x2815730c, 0x381348ad,   // en.sm.vo_322 ro.da.oc_521  ny.sw.un_530 tt.et.tk_643 
  0x0a001102, 0x134b5c55, 0x35302307, 0x67686413,   // ro.pt.un_220 sa.mi.et_442  ca.uz.zu_432 lg.ig.ak_665 
  0x1e002a02, 0x240260a4, 0x5f3775a4, 0x383e2a0c,   // mt.ms.un_220 vo.da.eo_433  nso.st.tn_433 mt.rm.tk_543 
  0x572460af, 0x68004508, 0x06004035, 0x45692007,   // vo.eo.na_655 ln.ig.un_430  lb.de.un_A90 sq.mfe.ln_432 
  // [ced0]
  0x2e020e12, 0x39246012, 0x55642855, 0x26381b08,   // is.da.fo_654 vo.eo.br_654  sw.lg.rw_442 tr.tk.ia_443 
  0x73506413, 0x35304805, 0x5f2d0d04, 0x735f375a,   // lg.fj.ny_665 tt.uz.tg_333  cs.sk.tn_332 st.tn.ny_553 
  0x0a004705, 0x792452a7, 0x5000370b, 0x05003f04,   // sn.pt.un_330 ha.eo.war_532  st.fj.un_520 af.fr.un_320 
  0x345e5daf, 0x5c172907, 0x2a47fea0, 0x3e407907,   // ss.ts.xh_655 sl.sr.sa_432  tlh.sn.mt_322 war.lb.rm_432 
  // [cee0]
  0x48381511, 0x3f1d1312, 0x2530350d, 0x63001213,   // un.tk.tt_653 et.la.af_654  tg.uz.mn_554 hu.sco.un_650 
  0x0417300c, 0x1d004712, 0x17000108, 0x302118af,   // uz.sr.ru_543 sn.la.un_640  en.sr.un_430 ar.fa.uz_655 
  0x0c1925a7, 0x30470804, 0x060c0e60, 0xfc4a4607,   // eu.gl.sv_532 no.sn.uz_332  is.sv.de_664 qu.yo.zzp_432 
  0x0d000412, 0x30133608, 0x29002a0b, 0x472013a0,   // fi.cs.un_640 gn.et.uz_443  mt.sl.un_520 et.sq.sn_322 
  // [cef0]
  0x505a1355, 0x3f6b1555, 0x12213013, 0x2e0e330c,   // et.sm.fj_442 un.ceb.af_442  uz.fa.ur_665 nn.is.fo_543 
  0x23213d0c, 0x35000307, 0x31301ea0, 0x0f005a09,   // ku.fa.ky_543 nl.zu.un_420  ms.uz.az_322 sm.lv.un_440 
  0x15041004, 0x33fa0ea4, 0x292354ad, 0x17300a02,   // be.ru.un_332 is.nr.nn_433  ik.ca.sl_643 mk.uz.sr_222 
  0x3d213b0c, 0x2e003313, 0x2a002104, 0x375d2aad,   // ks.fa.ku_543 nn.fo.un_650  jw.mt.un_320 mt.ss.st_643 
  // [cf00]
  0x48080402, 0x2112180d, 0x151504a4, 0x1b120c02,   // ru.uk.tt_222 ar.ur.fa_554  ru.un.un_430 sv.hu.tr_222 
  0x1200610c, 0xfe001b08, 0x123b3d0b, 0x2b004b14,   // za.hu.un_530 tr.tlh.un_430  ku.ks.ur_542 mi.vi.un_660 
  0x170a11a7, 0x19254dad, 0x20262507, 0x4900fc04,   // ro.mk.sr_532 aa.eu.gl_643  eu.ia.sq_432 zzp.to.un_320 
  0x4800080c, 0x083c0408, 0x5c005a11, 0x253038a0,   // uk.tt.un_530 ru.ug.uk_443  sm.sa.un_630 tk.uz.mn_322 
  // [cf10]
  0x04003708, 0x49006a0c, 0x3748100c, 0x0b36120c,   // st.fi.un_430 haw.to.un_530  be.tt.ba_543 hu.gn.es_543 
  0x2e0833ad, 0x123418ac, 0x35304809, 0x38002902,   // nn.no.fo_643 ar.ps.ur_632  tt.uz.tg_444 sl.tk.un_220 
  0x5506fea7, 0x35475dec, 0x55004702, 0x24003104,   // tlh.de.rw_532 ss.sn.zu_644  sn.rw.un_220 az.eo.un_320 
  0x4b004902, 0x242812ee, 0x12561007, 0x330858ee,   // to.mi.un_220 hu.sw.eo_422  lt.mg.hu_432 om.no.nn_422 
  // [cf20]
  0x350a08a0, 0x1e000807, 0x09023b02, 0x120c1ea4,   // uk.mk.tg_322 no.ms.un_420  so.da.pl_222 ms.sv.hu_433 
  0x10120911, 0x36003014, 0x291602a0, 0x3f0115a0,   // pl.hu.lt_653 uz.ab.un_660  da.hr.sl_322 un.en.af_322 
  0x0c093fa0, 0x13120208, 0x043711ac, 0x4a375f55,   // af.pl.sv_322 da.hu.et_443  ro.ba.ru_632 tn.st.yo_442 
  0x080723a9, 0x3100250c, 0x566745a9, 0x6a2245a4,   // ky.bg.uk_544 eu.az.un_530  ln.ak.mg_544 ln.oc.haw_433 
  // [cf30]
  0x2348300c, 0x45175707, 0x3f000335, 0x3c442311,   // uz.tt.ky_543 na.sr.ln_432  nl.af.un_A90 ky.kk.ug_653 
  0x5d002c0c, 0x67630107, 0x0a301702, 0x64004c08,   // fy.ss.un_530 en.sco.ak_432  sr.uz.mk_222 wo.lg.un_430 
  0x18234455, 0x1b6202a9, 0x59552809, 0x6b340b04,   // kk.ky.ar_442 da.kha.tr_544  sw.rw.rn_444 es.xh.ceb_332 
  0x521e02a4, 0x5602450d, 0x5d353455, 0x353445a9,   // da.ms.ha_433 ln.da.mg_554  xh.zu.ss_442 ln.xh.zu_544 
  // [cf40]
  0x026a6507, 0x0f104902, 0x04005223, 0x2559555a,   // gv.haw.da_432 to.lt.lv_222  ha.fi.un_880 rw.rn.eu_553 
  0x1c2f52ad, 0x39003b23, 0x634c3faf, 0x08020cec,   // ha.su.id_643 so.br.un_880  af.wo.sco_655 sv.da.no_644 
  0x55003702, 0x043302ee, 0x013e63a4, 0x130425a4,   // st.rw.un_220 da.nn.fi_422  sco.rm.en_433 eu.fi.et_433 
  0x032c1dee, 0x1325460c, 0x4c033f60, 0x363515a9,   // la.fy.nl_422 qu.eu.et_543  af.nl.wo_664 un.tg.ab_544 
  // [cf50]
  0x555973a7, 0x4c653f07, 0x04003304, 0x042e0e07,   // ny.rn.rw_532 af.gv.wo_432  nn.fi.un_320 is.fo.fi_432 
  0x0c00021b, 0x330e2eaf, 0x2c003605, 0x353637ee,   // da.sv.un_770 fo.is.nn_655  gn.fy.un_330 ba.ab.tg_422 
  0x296b2eee, 0x45351ca4, 0x2b1d010b, 0x3f2404a0,   // fo.ceb.sl_422 id.zu.ln_433  en.la.vi_542 fi.eo.af_322 
  0x422e0ea4, 0x73285c08, 0x46001a18, 0x0c000e13,   // is.fo.co_433 sa.sw.ny_443  tl.qu.un_740 is.sv.un_650 
  // [cf60]
  0x565127a0, 0x0f794b0e, 0x0f106a0d, 0x345d370d,   // gd.kl.mg_322 mi.war.lv_555  haw.lt.lv_554 st.ss.xh_554 
  0x321734ee, 0x56002819, 0x380c5b0b, 0x0f201155,   // xh.sr.bs_422 sw.mg.un_750  sg.sv.tk_542 ro.sq.lv_442 
  0x020c0805, 0x094838ee, 0x190b25a0, 0xfc100f0c,   // no.sv.da_333 tk.tt.pl_422  eu.es.gl_322 lv.lt.zzp_543 
  0x0413255a, 0x09004702, 0x385c300c, 0x07001112,   // eu.et.fi_553 sn.pl.un_220  uz.sa.tk_543 ro.bg.un_640 
  // [cf70]
  0x0d393e04, 0x53003302, 0x39000305, 0x30002119,   // rm.br.cs_332 nn.ht.un_220  nl.br.un_330 fa.uz.un_750 
  0x2279255a, 0x120e0ca0, 0xfc005c1a, 0x0c330814,   // eu.war.oc_553 sv.is.hu_322  sa.zzp.un_760 no.nn.sv_666 
  0x0a001b07, 0x1b00530e, 0x4b5249af, 0x4945500c,   // tr.pt.un_420 ht.tr.un_550  to.ha.mi_655 fj.ln.to_543 
  0x2e2d1213, 0x202925a7, 0x5a00492b, 0x51002511,   // hu.sk.fo_665 eu.sl.sq_532  to.sm.un_980 eu.kl.un_630 
  // [cf80]
  0x30240714, 0x110748a9, 0x48004f04, 0x0a153505,   // it.eo.uz_666 tt.bg.ro_544  bi.tt.un_320 tg.mk.un_330 
  0x24000f04, 0x394660ee, 0x015a1504, 0x20005607,   // lv.eo.un_320 vo.qu.br_422  un.sm.en_332 mg.sq.un_420 
  0x25005a09, 0x764945a9, 0x253038a7, 0x3000251a,   // sm.eu.un_440 ln.to.crs_544  tk.uz.mn_532 mn.uz.un_760 
  0x3d12280e, 0x033f2414, 0x234434a9, 0x260904ad,   // sd.ur.ku_555 eo.af.nl_666  ps.kk.ky_544 fi.pl.ia_643 
  // [cf90]
  0x3e002a22, 0x65002302, 0x123d34a7, 0x1f003b0c,   // mt.rm.un_870 ca.gv.un_220  ps.ku.ur_532 so.cy.un_530 
  0x253704a0, 0x40007905, 0x3e00080d, 0x24016308,   // ru.ba.mn_322 war.lb.un_330  no.rm.un_540 sco.en.eo_443 
  0x17083c04, 0x043007ee, 0x481025a9, 0x30442313,   // ug.uk.sr_332 bg.uz.ru_422  mn.be.tt_544 ky.kk.uz_665 
  0x35000c02, 0x08113055, 0x183034a0, 0x35341ba6,   // sv.zu.un_220 uz.ro.uk_442  ps.uz.ar_322 tr.xh.zu_521 
  // [cfa0]
  0x06005e09, 0x080435ee, 0x4a005605, 0x44001011,   // ts.de.un_440 tg.ru.uk_422  mg.yo.un_330 be.kk.un_630 
  0x105109a7, 0x0476510c, 0x6757120e, 0x35080202,   // pl.kl.lt_532 kl.crs.fi_543  hu.na.ak_555 da.no.zu_222 
  0x021e1c05, 0x241a2f02, 0x42003005, 0x04131007,   // id.ms.da_333 su.tl.eo_222  uz.co.un_330 lt.et.fi_432 
  0x44233713, 0x281221a0, 0x17040a07, 0x27342805,   // ba.ky.kk_665 fa.ur.sd_322  mk.ru.sr_432 sw.xh.gd_333 
  // [cfb0]
  0x230844a0, 0x48374411, 0x330c0807, 0x0469760c,   // kk.uk.ky_322 kk.ba.tt_653  no.sv.nn_432 crs.mfe.fi_543 
  0x27002d0e, 0x01006b0d, 0x3018215a, 0x104256a7,   // sk.gd.un_550 ceb.en.un_540  fa.ar.uz_553 mg.co.lt_532 
  0x3f2d1f0c, 0x4600350b, 0x1f2dfe08, 0x3b34350c,   // cy.sk.af_543 zu.qu.un_520  tlh.sk.cy_443 zu.xh.so_543 
  0x25000304, 0x2c002d0d, 0x3b100fa0, 0xfe2d060c,   // nl.eu.un_320 sk.fy.un_540  lv.lt.so_322 de.sk.tlh_543 
  // [cfc0]
  0x16006805, 0x122821ec, 0x532d1fa7, 0x3007100c,   // ig.hr.un_330 fa.sd.ur_644  cy.sk.ht_532 be.bg.uz_543 
  0xfe002d0e, 0x1f002d0c, 0x17350a07, 0x211218a0,   // sk.tlh.un_550 sk.cy.un_530  mk.tg.sr_432 ar.ur.fa_322 
  0x0f00690d, 0x30004707, 0x402c2d08, 0x434d1d07,   // mfe.lv.un_540 sn.uz.un_420  sk.fy.lb_443 la.aa.ie_432 
  0x301f2dad, 0x53fe2d07, 0x0c537904, 0x50005a13,   // sk.cy.uz_643 sk.tlh.ht_432  war.ht.sv_332 sm.fj.un_650 
  // [cfd0]
  0x5f457514, 0x393865ad, 0x64001b0b, 0x35285d09,   // nso.ln.tn_666 gv.tk.br_643  tr.lg.un_520 ss.sw.zu_444 
  0x18006314, 0x17004207, 0x5500620c, 0x0603180c,   // sco.ga.un_660 co.sr.un_420  kha.rw.un_530 ga.nl.de_543 
  0x425a1b55, 0x170a10af, 0x3e002709, 0x2c060312,   // tr.sm.co_442 be.mk.sr_655  gd.rm.un_440 nl.de.fy_654 
  0x07173cee, 0x421b310d, 0x12190ea0, 0x0d001d08,   // ug.sr.bg_422 az.tr.co_554  is.gl.hu_322 la.cs.un_430 
  // [cfe0]
  0x402f0504, 0x04002807, 0x07043509, 0x3044480c,   // fr.su.lb_332 sw.fi.un_420  tg.ru.bg_444 tt.kk.uz_543 
  0x6a7328a9, 0x02241d0c, 0x21004708, 0x04fe1a09,   // sw.ny.haw_544 la.eo.da_543  sn.jw.un_430 tl.tlh.fi_444 
  0x2d0d31a4, 0x383c2360, 0x3f007909, 0x2536350c,   // az.cs.sk_433 ky.ug.tk_664  war.af.un_440 tg.ab.mn_543 
  0x0f1b31af, 0x5c5425a4, 0x371b360c, 0x2d0dfeee,   // az.tr.lv_655 eu.ik.sa_433  gn.tr.st_543 tlh.cs.sk_422 
  // [cff0]
  0x1b1273a0, 0x081007a0, 0x182128a4, 0x212f5508,   // ny.hu.tr_322 bg.be.uk_322  sd.fa.ar_433 rw.su.jw_443 
  0x372548a0, 0x3e0f2904, 0x4e004622, 0x1f00fc05,   // tt.mn.ba_322 sl.lv.rm_332  qu.ay.un_870 zzp.cy.un_330 
  0x04100502, 0x212f55a4, 0x1e2f21ec, 0x370415ee,   // fr.lt.fi_222 rw.su.jw_433  jw.su.ms_644 un.ru.ba_422 
  0x170715a0, 0x1a51790c, 0x48373c0c, 0xfc0413a0,   // un.bg.sr_322 war.kl.tl_543  ug.ba.tt_543 et.fi.zzp_322 
  
  // [d000]
  0x3f000c02, 0x043715ad, 0x1e1c1b02, 0x5c1304ad,   // sv.af.un_220 un.ba.ru_643  tr.id.ms_222 fi.et.sa_643 
  0x213d1812, 0x05004704, 0x32004704, 0x0c0833a0,   // ar.ku.fa_654 sn.fr.un_320  sn.bs.un_320 nn.no.sv_322 
  0x38000209, 0x12005e07, 0x2515040c, 0x55004704,   // da.tk.un_440 ts.hu.un_420  ru.mn.un_530 sn.rw.un_320 
  0x04100708, 0x17151104, 0x302515a9, 0x11766960,   // bg.be.ru_443 ro.sr.un_320  un.mn.uz_544 mfe.crs.ro_664 
  // [d010]
  0x080425ee, 0x25041504, 0x2320390b, 0x091c5c0b,   // mn.ru.uk_422 un.ru.mn_332  br.sq.ca_542 sa.mr.hi_542 
  0x300811ee, 0x23190a04, 0x2b002508, 0x44232505,   // ro.uk.uz_422 pt.gl.ca_332  eu.vi.un_430 mn.ky.kk_333 
  0x2b002504, 0x092469a7, 0x2ffe4208, 0x19004608,   // eu.vi.un_320 mfe.eo.pl_532  co.tlh.su_443 qu.gl.un_430 
  0x2464565a, 0x3115fc0c, 0x10480a0b, 0x253638ad,   // mg.lg.eo_553 zzp.az.un_530  mk.tt.be_542 tk.ab.mn_643 
  // [d020]
  0x5f00370c, 0x3000250d, 0x070838ee, 0x5f000208,   // st.tn.un_530 eu.uz.un_540  tk.uk.bg_422 da.tn.un_430 
  0x135c0912, 0x01fe6307, 0x38000c04, 0x36001519,   // hi.sa.bh_654 sco.tlh.en_432  sv.tk.un_320 un.ab.un_750 
  0x362337a0, 0x15003908, 0x2e120aa0, 0x19000a0c,   // ba.ky.ab_322 br.un.un_430  pt.hu.fo_322 pt.gl.un_530 
  0x25150408, 0xfe003812, 0x1d000207, 0x5d351ea0,   // ru.mn.un_430 tk.tlh.un_640  da.la.un_420 ms.zu.ss_322 
  // [d030]
  0x2d00250c, 0x1b003707, 0x08005805, 0x09002004,   // eu.sk.un_530 st.tr.un_420  om.no.un_330 sq.pl.un_320 
  0x135c0da9, 0x08103c0c, 0x0900250c, 0x563f5304,   // ne.sa.bh_544 ug.be.uk_543  eu.pl.un_530 ht.af.mg_332 
  0x69125f0c, 0x5e5c27ee, 0x181715ad, 0x0a044707,   // tn.hu.mfe_543 gd.sa.ts_422  un.sr.ga_643 sn.fi.pt_432 
  0x1263010c, 0x34211805, 0x1300600b, 0x1f003f09,   // en.sco.hu_543 ar.fa.ps_333  vo.et.un_520 af.cy.un_440 
  // [d040]
  0x29434c0c, 0x5c355dad, 0x42005108, 0x292d1602,   // wo.ie.sl_543 ss.zu.sa_643  kl.co.un_430 hr.sk.sl_222 
  0x3e00111b, 0x47215c08, 0x375f4912, 0x402c1da4,   // ro.rm.un_770 sa.jw.sn_443  to.tn.st_654 la.fy.lb_433 
  0x11624ead, 0x392011a7, 0x34697611, 0x073c1555,   // ay.kha.ro_643 ro.sq.br_532  crs.mfe.xh_653 un.ug.bg_442 
  0x18005c12, 0x35473411, 0x0d001c14, 0x061bfcee,   // sa.ga.un_640 xh.sn.zu_653  mr.ne.un_660 zzp.tr.de_422 
  // [d050]
  0x4e68460e, 0x0b002707, 0x35173007, 0x39252855,   // qu.ig.ay_555 gd.es.un_420  uz.sr.tg_432 sw.eu.br_442 
  0x130d0913, 0x13007904, 0x534f6755, 0x251511a4,   // hi.ne.bh_665 war.et.un_320  ak.bi.ht_442 ro.mn.un_430 
  0x3900470c, 0x3500341a, 0x34475d08, 0x171048a0,   // sn.br.un_530 xh.zu.un_760  ss.sn.xh_443 tt.be.sr_322 
  0x5c001214, 0x30007818, 0x2c006019, 0x35083cee,   // hu.sa.un_660 ve.uz.un_740  vo.fy.un_750 ug.uk.tg_422 
  // [d060]
  0x080e33a6, 0x1000090c, 0x5c202713, 0x3707040c,   // nn.is.no_521 pl.lt.un_530  gd.sq.sa_665 ru.bg.ba_543 
  0x5c1e1ca7, 0x5d00010d, 0x3efefca4, 0x156e01a0,   // id.ms.sa_532 en.ss.un_540  zzp.tlh.rm_433 en.hmn.un_322 
  0x113e3909, 0x525f4707, 0x3c383009, 0x38021f07,   // br.rm.ro_444 sn.tn.ha_432  uz.tk.ug_444 cy.da.tk_432 
  0x28006a18, 0x62005c13, 0x25006a0d, 0x55651f07,   // haw.sw.un_740 sa.kha.un_650  haw.eu.un_540 cy.gv.rw_432 
  // [d070]
  0x5800fc04, 0x25233704, 0x351030ad, 0x0400250d,   // zzp.om.un_320 ba.ky.mn_332  uz.be.tg_643 eu.fi.un_540 
  0x48003c2b, 0x4425230b, 0x04371555, 0x0600290c,   // ug.tt.un_980 ky.mn.kk_542  un.ba.ru_442 sl.de.un_530 
  0x074404a4, 0x6900fe13, 0x151048ec, 0x2a134da9,   // ru.kk.bg_433 tlh.mfe.un_650  tt.be.un_644 aa.et.mt_544 
  0x2a0e2e60, 0x535f3707, 0x565f3704, 0x0d000921,   // fo.is.mt_664 st.tn.ht_432  st.tn.mg_332 hi.ne.un_860 
  // [d080]
  0x10081702, 0x4400382b, 0x2d003202, 0x5f753712,   // sr.uk.be_222 tk.kk.un_980  bs.sk.un_220 st.nso.tn_654 
  0x170a2504, 0x5d4967a7, 0x30251512, 0x292d1702,   // mn.mk.sr_332 ak.to.ss_532  un.mn.uz_654 sr.sk.sl_222 
  0x2530150e, 0x033b2ea4, 0x35304405, 0x2e045caf,   // un.uz.mn_555 fo.so.nl_433  kk.uz.tg_333 sa.fi.fo_655 
  0x0e2d12a7, 0x17294e07, 0x2d003908, 0x4c123604,   // hu.sk.is_532 ay.sl.sr_432  br.sk.un_430 gn.hu.wo_332 
  // [d090]
  0x021b3bee, 0x024704a7, 0x04101502, 0x04150a07,   // so.tr.da_422 fi.sn.da_532  un.be.ru_222 mk.ru.un_420 
  0x32102dee, 0x48464e07, 0x250f390b, 0x03001108,   // sk.lt.bs_422 ay.qu.tt_432  br.lv.eu_542 ro.nl.un_430 
  0x504962a4, 0x48300207, 0x5c0a56ad, 0x5c044e08,   // kha.to.fj_433 da.uz.tt_432  mg.pt.sa_643 ay.fi.sa_443 
  0x5d090755, 0x11120107, 0x04524ea9, 0x562d40a0,   // it.pl.ss_442 en.hu.ro_432  ay.ha.fi_544 lb.sk.mg_322 
  // [d0a0]
  0x275706ad, 0x08024eee, 0x79566b0d, 0x7962270c,   // de.na.gd_643 ay.da.no_422  ceb.mg.war_554 gd.kha.war_543 
  0x3b005602, 0x4749500d, 0x032d3ea4, 0x2bfe2707,   // mg.so.un_220 fj.to.sn_554  rm.sk.nl_433 gd.tlh.vi_432 
  0x46302aa0, 0x0300090c, 0x501233a0, 0x03003904,   // mt.uz.qu_322 pl.nl.un_530  nn.hu.fj_322 br.nl.un_320 
  0x435649a4, 0x27fe2caf, 0x241d0a11, 0x07190bee,   // to.mg.ie_433 fy.tlh.gd_655  pt.la.eo_653 es.gl.it_422 
  // [d0b0]
  0x3009270d, 0x5a511302, 0x5d4a5c13, 0x191101a4,   // gd.pl.uz_554 et.kl.sm_222  sa.yo.ss_665 en.ro.gl_433 
  0x153025ac, 0x1012110c, 0x21022fa4, 0x284a60ad,   // mn.uz.un_632 ro.hu.lt_543  su.da.jw_433 vo.yo.sw_643 
  0x59000208, 0x24003705, 0x3c1821ee, 0x113817a4,   // da.rn.un_430 st.eo.un_330  fa.ar.ug_422 sr.tk.ro_433 
  0x15170455, 0x262130a4, 0x31005204, 0x4846feac,   // ru.sr.un_442 uz.jw.ia_433  ha.az.un_320 tlh.qu.tt_632 
  // [d0c0]
  0x02042404, 0x272c2d07, 0x342035a9, 0x4846fe0c,   // eo.fi.da_332 sk.fy.gd_432  zu.sq.xh_544 tlh.qu.tt_543 
  0x233048af, 0x3f030212, 0x314c5807, 0x0d092c02,   // tt.uz.ky_655 da.nl.af_654  om.wo.az_432 fy.pl.cs_222 
  0x1a007909, 0x51fc010c, 0x3f05030d, 0x5d001702,   // war.tl.un_440 en.zzp.kl_543  nl.fr.af_554 sr.ss.un_220 
  0x2134280b, 0xfc00642a, 0x0f001f19, 0x043024ee,   // sd.ps.fa_542 lg.zzp.un_970  cy.lv.un_750 eo.uz.fi_422 
  // [d0d0]
  0x47000e22, 0x053e79a9, 0x5e737811, 0x783508a0,   // is.sn.un_870 war.rm.fr_544  ve.ny.ts_653 no.zu.ve_322 
  0x500a5a0d, 0x15fc010c, 0x2f5163a7, 0x73357808,   // sm.pt.fj_554 en.zzp.un_543  sco.kl.su_532 ve.zu.ny_443 
  0x5a00490d, 0x5d002713, 0x1f402604, 0x11002004,   // to.sm.un_540 gd.ss.un_650  ia.lb.cy_332 sq.ro.un_320 
  0x0627180d, 0x34004607, 0x172d0d0d, 0x473673af,   // ga.gd.de_554 qu.xh.un_420  cs.sk.sr_554 ny.gn.sn_655 
  // [d0e0]
  0x060e0c04, 0x0e120c09, 0x040a1507, 0x251115a4,   // sv.is.de_332 sv.hu.is_444  un.mk.ru_432 un.ro.mn_433 
  0x395f3707, 0x30123107, 0x6b002014, 0x40113e12,   // st.tn.br_432 az.hu.uz_432  sq.ceb.un_660 rm.ro.lb_654 
  0x30693107, 0xfe6a3612, 0x5600670d, 0x3e003512,   // az.mfe.uz_432 gn.haw.tlh_654  ak.mg.un_540 zu.rm.un_640 
  0x17043004, 0x48001a02, 0x623020a4, 0x081711ee,   // uz.ru.sr_332 tl.tt.un_220  sq.uz.kha_433 ro.sr.uk_422 
  // [d0f0]
  0x3765620b, 0x2062370e, 0x1b0931a0, 0x330c1d55,   // kha.gv.st_542 st.kha.sq_555  az.pl.tr_322 la.sv.nn_442 
  0x2500070e, 0x381b315a, 0x09005c11, 0x183d2307,   // bg.mn.un_550 az.tr.tk_553  sa.hi.un_630 ky.ku.ar_432 
  0x361202a0, 0x374415a7, 0x20001318, 0x763e0107,   // da.hu.gn_322 un.kk.ba_532  et.sq.un_740 en.rm.crs_432 
  0xfc260107, 0x0a382307, 0x40000621, 0x42002705,   // en.ia.zzp_432 ky.tk.mk_432  de.lb.un_860 gd.co.un_330 
  // [d100]
  0x4800240b, 0x10060f07, 0x06041204, 0x28213011,   // eo.tt.un_520 lv.de.lt_432  hu.fi.de_332 uz.fa.sd_653 
  0x04005a02, 0x424947ee, 0x091c3bad, 0x4f485455,   // sm.fi.un_220 sn.to.co_422  ks.mr.hi_643 ik.tt.bi_442 
  0x06003308, 0x425305a4, 0x17001118, 0x47005a0d,   // nn.de.un_430 fr.ht.co_433  ro.sr.un_740 sm.sn.un_540 
  0x221d3e09, 0x045452af, 0x15003623, 0x06001007,   // rm.la.oc_444 ha.ik.fi_655  ab.un.un_880 lt.de.un_420 
  // [d110]
  0x5a005419, 0x06040107, 0x35070a02, 0x28302155,   // ik.sm.un_750 en.fi.de_432  mk.bg.tg_222 fa.uz.sd_442 
  0x0200301a, 0x50003022, 0x024730a7, 0x18006012,   // uz.da.un_760 uz.fj.un_870  uz.sn.da_532 vo.ga.un_640 
  0x68003008, 0x10062da4, 0xfc014307, 0x734a0904,   // uz.ig.un_430 sk.de.lt_433  ie.en.zzp_432 pl.yo.ny_332 
  0x22001207, 0x30004d12, 0x51005712, 0x5559640c,   // hu.oc.un_420 aa.uz.un_640  na.kl.un_640 lg.rn.rw_543 
  // [d120]
  0x645928a4, 0x6400781a, 0x4a347307, 0x50000208,   // sw.rn.lg_433 ve.lg.un_760  ny.xh.yo_432 da.fj.un_430 
  0x30001802, 0x33382e07, 0x2e041308, 0x110730a6,   // ga.uz.un_220 fo.tk.nn_432  et.fi.fo_443 uz.it.ro_521 
  0x64735305, 0x59556412, 0x4730110c, 0x47112504,   // ht.ny.lg_333 lg.rw.rn_654  ro.uz.sn_543 eu.ro.sn_332 
  0x55002812, 0x64213407, 0x302812a4, 0x051d3008,   // sw.rw.un_640 xh.jw.lg_432  ur.sd.uz_433 uz.la.fr_443 
  // [d130]
  0x53006419, 0x6534730c, 0x32104e07, 0x350838a4,   // lg.ht.un_750 ny.xh.gv_543  ay.lt.bs_432 tk.uk.tg_433 
  0x200e2e55, 0x0a002404, 0x02002e21, 0x2100281a,   // fo.is.sq_442 eo.pt.un_320  fo.da.un_860 sd.fa.un_760 
  0x234415ad, 0x5200500e, 0x18001108, 0x1d005604,   // un.kk.ky_643 fj.ha.un_550  ro.ga.un_430 mg.la.un_320 
  0x20002702, 0x1239110c, 0x344735ee, 0x73002823,   // gd.sq.un_220 ro.br.hu_543  zu.sn.xh_422 sw.ny.un_880 
  // [d140]
  0x595553a4, 0x59282105, 0x33002e09, 0x130e330c,   // ht.rw.rn_433 jw.sw.rn_333  fo.nn.un_440 nn.is.et_543 
  0xfe000d0c, 0x04002f05, 0x5e35340d, 0x373048af,   // cs.tlh.un_530 su.fi.un_330  xh.zu.ts_554 tt.uz.ba_655 
  0x2ffe040c, 0x5a4b6a08, 0x3f03650b, 0x641363a4,   // fi.tlh.su_543 haw.mi.sm_443  gv.nl.af_542 sco.et.lg_433 
  0x344724a9, 0x48040755, 0x34646502, 0x6e006314,   // eo.sn.xh_544 bg.ru.tt_442  gv.lg.xh_222 sco.hmn.un_660 
  // [d150]
  0x171004ee, 0x374844a6, 0x58006312, 0x49000104,   // ru.be.sr_422 kk.tt.ba_521  sco.om.un_640 en.to.un_320 
  0x526a2807, 0x52002804, 0x6a6301af, 0x34000308,   // sw.haw.ha_432 sw.ha.un_320  en.sco.haw_655 nl.xh.un_430 
  0x22235a5a, 0x476434a4, 0x28002122, 0x4936520b,   // sm.ca.oc_553 xh.lg.sn_433  fa.sd.un_870 ha.gn.to_542 
  0x630601ac, 0x2000680e, 0x291304ec, 0x656e570d,   // en.de.sco_632 ig.sq.un_550  fi.et.sl_644 na.hmn.gv_554 
  // [d160]
  0x63005e12, 0x481525a6, 0x0604feee, 0x070810a9,   // ts.sco.un_640 mn.tt.un_510  tlh.fi.de_422 be.uk.bg_544 
  0x036e13ad, 0x0d2d2c55, 0x4d005209, 0x20001602,   // et.hmn.nl_643 fy.sk.cs_442  ha.aa.un_440 hr.sq.un_220 
  0x1c003813, 0x532c3502, 0x33085ea4, 0x6b6369a0,   // tk.mr.un_650 zu.fy.ht_222  ts.no.nn_433 mfe.sco.ceb_322 
  0x481b3155, 0x19020b08, 0x2500121b, 0x24000109,   // az.tr.tt_442 es.da.gl_443  hu.eu.un_770 iw.yi.un_440 
  // [d170]
  0x0b002513, 0x344423a9, 0x560f21a0, 0x4415170c,   // eu.es.un_650 ky.kk.ps_544  jw.lv.mg_322 sr.kk.un_530 
  0x4800150d, 0x483723a9, 0x08352508, 0x37174855,   // un.tt.un_540 ky.ba.tt_544  mn.tg.uk_443 tt.sr.ba_442 
  0x49553502, 0x1535010c, 0x554b56ad, 0x0a004813,   // zu.rw.to_222 en.zu.un_543  mg.mi.rw_643 tt.mk.un_650 
  0x5500340b, 0x250804a7, 0x651f38a4, 0x3865090d,   // xh.rw.un_520 ru.uk.mn_532  tk.cy.gv_433 pl.gv.tk_554 
  // [d180]
  0x30233c04, 0x65003807, 0x650d2dee, 0x38001f23,   // ug.ky.uz_332 tk.gv.un_420  sk.cs.gv_422 cy.tk.un_880 
  0x0238120c, 0x0e3f1204, 0x07422308, 0x650238a4,   // hu.tk.da_543 hu.af.is_332  ca.co.it_443 tk.da.gv_433 
  0x656e010b, 0x46000a07, 0x03403f02, 0x3e000a2b,   // en.hmn.gv_542 pt.qu.un_420  af.lb.nl_222 pt.rm.un_980 
  0x0900621a, 0x134736a0, 0x3f00401b, 0x792322a7,   // kha.pl.un_760 gn.sn.et_322  lb.af.un_770 oc.ca.war_532 
  // [d190]
  0x4000091a, 0x033e050c, 0x64122aa4, 0x092d0d07,   // pl.lb.un_760 fr.rm.nl_543  mt.hu.lg_433 cs.sk.pl_432 
  0x02001821, 0x34213dec, 0x09004005, 0x1900300e,   // ga.da.un_860 ku.fa.ps_644  lb.pl.un_330 uz.gl.un_550 
  0x2d380907, 0x09386512, 0x091b13a0, 0x12002905,   // pl.tk.sk_432 gv.tk.pl_654  et.tr.pl_322 sl.hu.un_330 
  0x123048a9, 0x13003908, 0x220458a0, 0x3e110ca0,   // tt.uz.hu_544 br.et.un_430  om.fi.oc_322 sv.ro.rm_322 
  // [d1a0]
  0x1d43010c, 0x5a3e22ee, 0x0a333ea4, 0x1d00261b,   // en.ie.la_543 oc.rm.sm_422  rm.nn.pt_433 ia.la.un_770 
  0x40092a0c, 0x1d1501ad, 0x0a170805, 0x040a2502,   // mt.pl.lb_543 en.la.un_630  uk.sr.mk_333 mn.mk.ru_222 
  0x1b25380d, 0x0917fe0c, 0x3e2bfe0c, 0x2d4021a4,   // tk.eu.tr_554 tlh.sr.pl_543  tlh.vi.rm_543 jw.lb.sk_433 
  0x483035a4, 0x302115a4, 0x37383c0d, 0x1d002208,   // tg.uz.tt_433 un.fa.uz_433  ug.tk.ba_554 oc.la.un_430 
  // [d1b0]
  0x1d005202, 0x1f0c2002, 0x23052212, 0x46002f08,   // ha.la.un_220 sq.sv.cy_222  oc.fr.ca_654 su.qu.un_430 
  0x07171007, 0x1d521fad, 0x4a561a11, 0x07044404,   // be.sr.bg_432 cy.ha.la_643  tl.mg.yo_653 kk.ru.bg_332 
  0x37287304, 0x0807110c, 0x02001c0d, 0x59344509,   // ny.sw.st_332 ro.bg.uk_543  id.da.un_540 ln.xh.rn_444 
  0x456b5a0c, 0x2700fc07, 0x4535340e, 0x5345575a,   // sm.ceb.ln_543 zzp.gd.un_420  xh.zu.ln_555 na.ln.ht_553 
  // [d1c0]
  0x35001721, 0x20006212, 0x121e690d, 0x19690bec,   // sr.tg.un_860 kha.sq.un_640  mfe.ms.hu_554 es.mfe.gl_644 
  0x330c3f04, 0x01007602, 0x2c003504, 0x011530a0,   // af.sv.nn_332 crs.en.un_220  zu.fy.un_320 uz.en.un_320 
  0x49471aa0, 0x2d0d0502, 0x0c002005, 0x36540ea7,   // tl.sn.to_322 fr.cs.sk_222  sq.sv.un_330 is.ik.gn_532 
  0x150a0460, 0x046e0604, 0x06041004, 0x400e06a4,   // ru.mk.un_664 de.hmn.fi_332  lt.fi.de_332 de.is.lb_433 
  // [d1d0]
  0x04571007, 0x060422a0, 0x3d30340b, 0x04304802,   // lt.na.fi_432 oc.fi.de_322  ps.uz.ku_542 tt.uz.ru_222 
  0x17234409, 0x40060f09, 0x345d35ec, 0x3e1d0207,   // kk.ky.sr_444 lv.de.lb_444  zu.ss.xh_644 da.la.rm_432 
  0x481715a0, 0x3b00671b, 0x443738a9, 0x76646709,   // un.sr.tt_322 ak.so.un_770  tk.ba.kk_544 ak.lg.crs_444 
  0x5c473455, 0x5c001202, 0x12211c02, 0x06002202,   // xh.sn.sa_442 hu.sa.un_220  id.jw.hu_222 oc.de.un_220 
  // [d1e0]
  0x34005821, 0x060f10ad, 0x12215c07, 0x10063e02,   // om.xh.un_860 lt.lv.de_643  sa.jw.hu_432 rm.de.lt_222 
  0x0f250604, 0x17040aa9, 0x360a1707, 0x22001004,   // de.eu.lv_332 mk.ru.sr_544  sr.mk.ab_432 lt.oc.un_320 
  0x48383108, 0x473b55a9, 0x1e555caf, 0x1b5c0204,   // az.tk.tt_443 rw.so.sn_544  sa.rw.ms_655 da.sa.tr_332 
  0x465c5512, 0x385c47a4, 0x341218a6, 0x44003513,   // rw.sa.qu_654 sn.sa.tk_433  ar.ur.ps_521 tg.kk.un_650 
  // [d1f0]
  0x58473b07, 0x642855ad, 0x17694b55, 0x0717100c,   // so.sn.om_432 rw.sw.lg_643  mi.mfe.sr_442 be.sr.bg_543 
  0x213605a0, 0xfe5a4955, 0x42005504, 0x39004a04,   // fr.gn.jw_322 to.sm.tlh_442  rw.co.un_320 yo.br.un_320 
  0x523831a4, 0x53004719, 0x18393b02, 0x05002109,   // az.tk.ha_433 sn.ht.un_750  so.br.ga_222 jw.fr.un_440 
  0x5c005919, 0x16004a07, 0x1d002614, 0x55523805,   // rn.sa.un_750 yo.hr.un_420  ia.la.un_660 tk.ha.rw_333 
  // [d200]
  0x26190b14, 0x07110a5a, 0x303735a0, 0x2d120d08,   // es.gl.ia_666 mk.ro.bg_553  tg.ba.uz_322 cs.hu.sk_443 
  0x3d003405, 0x0600550c, 0x2535300c, 0x4a006907,   // ps.ku.un_330 rw.de.un_530  uz.tg.mn_543 mfe.yo.un_420 
  0x5e00470d, 0x470655a4, 0x303d3b04, 0x0c21200d,   // sn.ts.un_540 rw.de.sn_433  ks.ku.uz_332 sq.jw.sv_554 
  0x2556280c, 0x793e240e, 0x04080708, 0x762024a9,   // sw.mg.eu_543 eo.rm.war_555  bg.uk.ru_443 eo.sq.crs_544 
  // [d210]
  0x242204a0, 0x010c20a7, 0x44043ca0, 0x3548100c,   // fi.oc.eo_322 sq.sv.en_532  ug.ru.kk_322 be.tt.tg_543 
  0x30001112, 0x0b000a09, 0x055d2d04, 0x76003304,   // ro.uz.un_640 pt.es.un_440  sk.ss.fr_332 nn.crs.un_320 
  0x0126fe07, 0x2615010b, 0x251e1c13, 0x3e1d240c,   // tlh.ia.en_432 en.ia.un_520  id.ms.eu_665 eo.la.rm_543 
  0x20006304, 0x3000011a, 0x173748ec, 0x2a001805,   // sco.sq.un_320 en.uz.un_760  tt.ba.sr_644 ga.mt.un_330 
  // [d220]
  0x374425ee, 0x303544a4, 0x301234a4, 0x1525350e,   // mn.kk.ba_422 kk.tg.uz_433  ps.ur.uz_433 tg.mn.un_555 
  0x0447360c, 0x40000518, 0x041548a4, 0x07004407,   // gn.sn.fi_543 fr.lb.un_740  tt.ru.un_430 kk.bg.un_420 
  0x3b58300d, 0x5c4b7308, 0x07383c0c, 0x4837380b,   // uz.om.so_554 ny.mi.sa_443  ug.tk.bg_543 tk.ba.tt_542 
  0x4d02520c, 0x73374709, 0x02523b12, 0x3b00460d,   // ha.da.aa_543 sn.st.ny_444  so.ha.da_654 qu.so.un_540 
  // [d230]
  0x47365f08, 0x047347a9, 0x3e2b040c, 0x3b524d11,   // tn.gn.sn_443 sn.ny.fi_544  fi.vi.rm_543 aa.ha.so_653 
  0x313054a9, 0x7347280e, 0x18283414, 0x2b000421,   // ik.uz.az_544 sw.sn.ny_555  ps.sd.ar_666 fi.vi.un_860 
  0x2f251304, 0x1c000c02, 0x732b1aa4, 0x0f5a4902,   // et.eu.su_332 sv.id.un_220  tl.vi.ny_433 to.sm.lv_222 
  0x0402fc04, 0x07001a23, 0x2e001c08, 0x0433460c,   // zzp.da.fi_332 tl.it.un_880  id.fo.un_430 qu.nn.fi_543 
  // [d240]
  0x3e2b2409, 0x50fc3f0b, 0x315e3b0c, 0x12283408,   // eo.vi.rm_444 af.zzp.fj_542  so.ts.az_543 ps.sd.ur_443 
  0x3b21590c, 0x0400fc0d, 0x1b314ea9, 0x48103c07,   // rn.jw.so_543 zzp.fi.un_540  ay.az.tr_544 ug.be.tt_432 
  0x2e001a0e, 0x0447420c, 0x443648a9, 0x3c004429,   // tl.fo.un_550 co.sn.fi_543  tt.ab.kk_544 kk.ug.un_960 
  0x531a58ee, 0x4d304612, 0x25482311, 0x2b3e0708,   // om.tl.ht_422 qu.uz.aa_654  ky.tt.mn_653 it.rm.vi_443 
  // [d250]
  0x6500fe12, 0x2b000419, 0x48313005, 0x25383cad,   // tlh.gv.un_640 fi.vi.un_750  uz.az.tt_333 ug.tk.mn_643 
  0x301b3104, 0x35000808, 0x1d000507, 0xfe1e1c08,   // az.tr.uz_332 uk.tg.un_430  fr.la.un_420 id.ms.tlh_443 
  0x0c082e05, 0x58632fa0, 0x120542a0, 0x200a22a4,   // fo.no.sv_333 su.sco.om_322  co.fr.hu_322 oc.pt.sq_433 
  0x013778ad, 0x343d44a0, 0x3c2515a0, 0x652f620c,   // ve.st.en_643 kk.ku.ps_322  un.mn.ug_322 kha.su.gv_543 
  // [d260]
  0x271865a4, 0x060a2f04, 0x173704ee, 0x0e000607,   // gv.ga.gd_433 su.pt.de_332  ru.ba.sr_422 de.is.un_420 
  0x06796b04, 0x303c440c, 0x040708ad, 0x20004008,   // ceb.war.de_332 kk.ug.uz_543  uk.bg.ru_643 lb.sq.un_430 
  0x65210407, 0x6e04470c, 0x10153508, 0x0e002108,   // fi.jw.gv_432 sn.fi.hmn_543  tg.be.un_430 jw.is.un_430 
  0x360e0504, 0x276501ee, 0x6b006509, 0x225243a4,   // fr.is.gn_332 en.gv.gd_422  gv.ceb.un_440 ie.ha.oc_433 
  // [d270]
  0x0f1004a7, 0x233c18ad, 0x40004c0e, 0x4000200b,   // fi.lt.lv_532 ar.ug.ky_643  wo.lb.un_550 sq.lb.un_520 
  0x300804a9, 0x5c53690c, 0x10253509, 0x58633ba0,   // ru.uk.uz_544 mfe.ht.sa_543  tg.mn.be_444 so.sco.om_322 
  0x584f040d, 0x63767904, 0x520412a9, 0x18032512,   // fi.bi.om_554 war.crs.sco_332  hu.fi.ha_544 eu.nl.ga_654 
  0x303146a4, 0x083615ad, 0x13002e02, 0x3c182311,   // qu.az.uz_433 un.ab.uk_643  fo.et.un_220 ky.ar.ug_653 
  // [d280]
  0x443c30ec, 0x440417ec, 0x350a0704, 0x0a255aa0,   // uz.ug.kk_644 sr.ru.kk_644  bg.mk.tg_332 sm.eu.pt_322 
  0x796b57a4, 0x49566712, 0x15353ca7, 0x246b7907,   // na.ceb.war_433 ak.mg.to_654  ug.tg.un_532 war.ceb.eo_432 
  0x0c003311, 0x2b2024a4, 0x191e23a4, 0x15170409,   // nn.sv.un_630 eo.sq.vi_433  ca.ms.gl_433 ru.sr.un_444 
  0x25151513, 0x4428230c, 0x56003007, 0x67005f0e,   // un.mn.un_650 ky.sd.kk_543  uz.mg.un_420 tn.ak.un_550 
  // [d290]
  0x241a6b12, 0x37245707, 0x5f3767a4, 0x04002409,   // ceb.tl.eo_654 na.eo.st_432  ak.st.tn_433 eo.fi.un_440 
  0x56006714, 0x130d5c04, 0x24004d0b, 0x30004e12,   // ak.mg.un_660 sa.ne.bh_332  aa.eo.un_520 ay.uz.un_640 
  0x0a103807, 0x37001009, 0x3d30280c, 0x3534fe0b,   // tk.be.mk_432 be.ba.un_440  sd.uz.ku_543 tlh.xh.zu_542 
  0x0a071508, 0x44370407, 0x2c006404, 0x376515a0,   // un.bg.mk_443 ru.ba.kk_432  lg.fy.un_320 un.gv.st_322 
  // [d2a0]
  0x12006e12, 0xfe003721, 0x054a7604, 0x2f532702,   // hmn.hu.un_640 st.tlh.un_860  crs.yo.fr_332 gd.ht.su_222 
  0x0c002302, 0x19001f1b, 0x3c44380c, 0x337969ee,   // ca.sv.un_220 cy.gl.un_770  tk.kk.ug_543 mfe.war.nn_422 
  0x22190a13, 0x102729ad, 0x3f00030c, 0x456569ee,   // pt.gl.oc_665 sl.gd.lt_643  nl.af.un_530 mfe.gv.ln_422 
  0x19003802, 0x052402a7, 0x2f3027a4, 0x241f56a7,   // tk.gl.un_220 da.eo.fr_532  gd.uz.su_433 mg.cy.eo_532 
  // [d2b0]
  0x43004f2b, 0x19260b07, 0x79006b19, 0x18112705,   // bi.ie.un_980 es.ia.gl_432  ceb.war.un_750 gd.ro.ga_333 
  0x092402a0, 0x6b190b04, 0x031824a6, 0x654911a4,   // da.eo.pl_322 es.gl.ceb_332  eo.ga.nl_521 ro.to.gv_433 
  0x62631807, 0x1c0d130e, 0x11003008, 0x112c18a9,   // ga.sco.kha_432 bh.ne.mr_555  uz.ro.un_430 ga.fy.ro_544 
  0x650530ee, 0x05243004, 0x2f021104, 0x21690da0,   // uz.fr.gv_422 uz.eo.fr_332  ro.da.su_332 cs.mfe.jw_322 
  // [d2c0]
  0x110301a0, 0x15042307, 0x6b5263a0, 0x551e1c02,   // en.nl.ro_322 ky.ru.un_432  sco.ha.ceb_322 id.ms.rw_222 
  0x65115a09, 0x672701a0, 0x5d1101a7, 0x091c13a6,   // sm.ro.gv_444 en.gd.ak_322  en.ro.ss_532 bh.mr.hi_521 
  0x33004004, 0x25233060, 0x3c213405, 0x30000e07,   // lb.nn.un_320 uz.ky.mn_664  ps.fa.ug_333 is.uz.un_420 
  0x15171105, 0x173023a0, 0x351017a4, 0x08021fa0,   // ro.sr.un_333 ky.uz.sr_322  sr.be.tg_433 cy.da.no_322 
  // [d2d0]
  0x5c003b07, 0x3846fea0, 0x2e003314, 0x02002a07,   // so.sa.un_420 tlh.qu.tk_322  nn.fo.un_660 mt.da.un_420 
  0x4afc680c, 0x630626a9, 0x38003021, 0x604d510c,   // ig.zzp.yo_543 ia.de.sco_544  uz.tk.un_860 kl.aa.vo_543 
  0x3c001207, 0x406551a0, 0xfc735cec, 0x354bfc04,   // ur.ug.un_420 kl.gv.lb_322  sa.ny.zzp_644 zzp.mi.zu_332 
  0x0c3813ee, 0x625c550c, 0x4a007307, 0x37fc3e5a,   // et.tk.sv_422 rw.sa.kha_543  ny.yo.un_420 rm.zzp.st_553 
  // [d2e0]
  0x0642520c, 0xfe001f09, 0x4600122a, 0x09006402,   // ha.co.de_543 cy.tlh.un_440  hu.qu.un_970 lg.pl.un_220 
  0x68005719, 0x021d4d0c, 0x18006304, 0xfe002d04,   // na.ig.un_750 aa.la.da_543  sco.ga.un_320 sk.tlh.un_320 
  0x1100101a, 0x02007608, 0x01112004, 0x2a185113,   // be.ro.un_760 crs.da.un_430  sq.ro.en_332 kl.ga.mt_665 
  0x652a330c, 0x032a060c, 0x060c1302, 0x384d51ec,   // nn.mt.gv_543 de.mt.nl_543  et.sv.de_222 kl.aa.tk_644 
  // [d2f0]
  0x0a081505, 0x1b18fea7, 0x30113ea0, 0x1d000502,   // un.uk.mk_333 tlh.ga.tr_532  rm.ro.uz_322 fr.la.un_220 
  0x0c043fa0, 0x100844ac, 0x0815100c, 0x25000302,   // af.fi.sv_322 kk.uk.be_632  be.uk.un_530 nl.eu.un_220 
  0x09002b08, 0x0c3f15a4, 0x04003f0c, 0x23001521,   // vi.pl.un_430 un.af.sv_433  af.fi.un_530 un.ky.un_860 
  0x353c15ec, 0x30000904, 0x30351712, 0x290d1602,   // un.ug.tg_644 pl.uz.un_320  sr.tg.uz_654 hr.cs.sl_222 
  // [d300]
  0x3048350c, 0x0d001902, 0x21183d05, 0x44002512,   // tg.tt.uz_543 gl.cs.un_220  ku.ar.fa_333 mn.kk.un_640 
  0x31481b5a, 0x0237670c, 0x5200450e, 0x08071702,   // tr.tt.az_553 ak.st.da_543  ln.ha.un_550 sr.bg.uk_222 
  0x04002522, 0x105f45ad, 0x3252080c, 0x4a023f07,   // eu.fi.un_870 ln.tn.lt_643  no.ha.bs_543 af.da.yo_432 
  0x376a4907, 0x397649af, 0x2515040d, 0x0400220c,   // to.haw.st_432 to.crs.br_655  ru.mn.un_540 oc.fi.un_530 
  // [d310]
  0x385864a9, 0x0f3604a4, 0x0a000302, 0x0f291ca4,   // lg.om.tk_544 fi.gn.lv_433  nl.pt.un_220 id.sl.lv_433 
  0x1b561209, 0x332a560c, 0x73674fa9, 0x44044811,   // hu.mg.tr_444 mg.mt.nn_543  bi.ak.ny_544 tt.ru.kk_653 
  0x01656308, 0x6500010c, 0x3600101b, 0x2863010c,   // sco.gv.en_443 en.gv.un_530  be.ab.un_770 en.sco.sw_543 
  0x5c3354ee, 0x15150460, 0x23151504, 0x25226208,   // ik.nn.sa_422 ru.un.un_640  un.ky.un_320 kha.oc.eu_443 
  // [d320]
  0x22021014, 0x3e000407, 0x380413a9, 0x3d3412a6,   // lt.da.oc_666 fi.rm.un_420  et.fi.tk_544 ur.ps.ku_521 
  0x423905ee, 0x02001d0c, 0x01003808, 0xfe016355,   // fr.br.co_422 la.da.un_530  tk.en.un_430 sco.en.tlh_442 
  0x0800171b, 0x282344a4, 0xfc006402, 0x52006409,   // sr.uk.un_770 kk.ky.sd_433  lg.zzp.un_220 lg.ha.un_440 
  0x5600470e, 0x395628a7, 0x24002004, 0x565f1f5a,   // sn.mg.un_550 sw.mg.br_532  sq.eo.un_320 cy.tn.mg_553 
  // [d330]
  0x52004002, 0x290b10a0, 0x5d2d290c, 0x1a1b3804,   // lb.ha.un_220 lt.es.sl_322  sl.sk.ss_543 tk.tr.tl_332 
  0x10006b05, 0x3d183ca4, 0x30381ba0, 0x64001a08,   // ceb.lt.un_330 ug.ar.ku_433  tr.tk.uz_322 tl.lg.un_430 
  0x6b630102, 0x100a19ee, 0x070a150c, 0x062a220c,   // en.sco.ceb_222 gl.pt.lt_422  un.mk.bg_543 oc.mt.de_543 
  0x1b005f07, 0x4425110c, 0x2f2469ee, 0x06003004,   // tn.tr.un_420 ro.mn.kk_543  mfe.eo.su_422 uz.de.un_320 
  // [d340]
  0x336b54ad, 0x0e135ca4, 0x330e63a0, 0x31001e04,   // ik.ceb.nn_643 sa.et.is_433  sco.is.nn_322 ms.az.un_320 
  0x24402504, 0x330651a7, 0x1d001012, 0x34002002,   // eu.lb.eo_332 kl.de.nn_532  lt.la.un_640 sq.xh.un_220 
  0x6435120c, 0x21302808, 0x6b7902a7, 0x080e2e07,   // hu.zu.lg_543 sd.uz.fa_443  da.war.ceb_532 fo.is.no_432 
  0x5c386307, 0x65003305, 0x673e24a4, 0x00002624,   // sco.tk.sa_432 nn.gv.un_330  eo.rm.ak_433 ia.un.un_900 
  // [d350]
  0x3000470e, 0x1d244507, 0x5c0742ee, 0x1b005414,   // sn.uz.un_550 ln.eo.la_432  co.it.sa_422 ik.tr.un_660 
  0x766956a4, 0x220e0107, 0x1b5e5407, 0x4b004505,   // mg.mfe.crs_433 en.is.oc_432  ik.ts.tr_432 ln.mi.un_330 
  0x0a5e56ec, 0x20003008, 0x48383004, 0x1d002f02,   // mg.ts.pt_644 uz.sq.un_430  uz.tk.tt_332 su.la.un_220 
  0x370c5d04, 0x10002e0e, 0x5f483104, 0x5f00fe07,   // ss.sv.st_332 fo.lt.un_550  az.tt.tn_332 tlh.tn.un_420 
  // [d360]
  0x3f1a6ba0, 0x0e0833ee, 0x4f2a6904, 0x233c3013,   // ceb.tl.af_322 nn.no.is_422  mfe.mt.bi_332 uz.ug.ky_665 
  0x5d004c0c, 0x0e40060c, 0x332e1107, 0x422d6807,   // wo.ss.un_530 de.lb.is_543  ro.fo.nn_432 ig.sk.co_432 
  0x2c243fa0, 0x2f041e07, 0x3000fe19, 0x3f00240d,   // af.eo.fy_322 ms.fi.su_432  tlh.uz.un_750 eo.af.un_540 
  0x131b0407, 0x30003d21, 0x3f1f0309, 0x65004608,   // fi.tr.et_432 ku.uz.un_860  nl.cy.af_444 qu.gv.un_430 
  // [d370]
  0x3f2f210c, 0x34002821, 0x460363ee, 0x44383c12,   // jw.su.af_543 sd.ps.un_860  sco.nl.qu_422 ug.tk.kk_654 
  0x4a00fc0c, 0x1f000121, 0x1b00fe05, 0x303c370d,   // zzp.yo.un_530 en.cy.un_860  tlh.tr.un_330 ba.ug.uz_554 
  0x1f0301ec, 0x0e000205, 0x2c005d04, 0x044d1355,   // en.nl.cy_644 da.is.un_330  ss.fy.un_320 et.aa.fi_442 
  0x252024ee, 0x2100121b, 0x3f0313a4, 0x1304fea0,   // eo.sq.eu_422 ur.fa.un_770  et.nl.af_433 tlh.fi.et_322 
  // [d380]
  0x020e2e64, 0x0e2c2eee, 0x4a007309, 0x332e0e5a,   // fo.is.da_762 fo.fy.is_422  ny.yo.un_440 is.fo.nn_553 
  0x45555911, 0x443804a4, 0x755e3708, 0x32164902,   // rn.rw.ln_653 ru.tk.kk_433  st.ts.nso_443 to.hr.bs_222 
  0x2f6a4a0c, 0x30566a0d, 0x39006509, 0x270d2f02,   // yo.haw.su_543 haw.mg.uz_554  gv.br.un_440 su.cs.gd_222 
  0x043f6a04, 0x03001805, 0x122123ac, 0x483811ec,   // haw.af.fi_332 ga.nl.un_330  ky.fa.ur_632 ro.tk.tt_644 
  // [d390]
  0x250408a0, 0x38002514, 0x16000d05, 0x202d0d02,   // uk.ru.mn_322 mn.tk.un_660  cs.hr.un_330 cs.sk.sq_222 
  0x48003805, 0x6e001f12, 0x4b25490c, 0x6b007919,   // tk.tt.un_330 cy.hmn.un_640  to.eu.mi_543 war.ceb.un_750 
  0x4800600e, 0x483044a0, 0x3611150c, 0x2e2c0e55,   // vo.tt.un_550 kk.uz.tt_322  un.ro.ab_543 is.fy.fo_442 
  0x234830a9, 0x04004e13, 0x083011ad, 0x214a5504,   // uz.tt.ky_544 ay.fi.un_650  ro.uz.uk_643 rw.yo.jw_332 
  // [d3a0]
  0x28442308, 0x0815070c, 0x2c251912, 0x190b2304,   // ky.kk.sd_443 bg.uk.un_530  gl.eu.fy_654 ca.es.gl_332 
  0x23481707, 0x4430350c, 0x08041508, 0x4c004608,   // sr.tt.ky_432 tg.uz.kk_543  un.ru.uk_443 qu.wo.un_430 
  0x1c090d14, 0xfc004d14, 0x37150404, 0x23004707,   // ne.hi.mr_666 aa.zzp.un_660  ru.ba.un_320 sn.ca.un_420 
  0x28123b14, 0x1708040e, 0x483c15a0, 0x3421300e,   // ks.ur.sd_666 ru.uk.sr_555  un.ug.tt_322 uz.fa.ps_555 
  // [d3b0]
  0x12063e04, 0x3c170805, 0x40003908, 0x3f044a04,   // rm.de.hu_332 uk.sr.ug_333  br.lb.un_430 yo.fi.af_332 
  0x060302a0, 0x42fc01ee, 0x7367240d, 0x15005c11,   // da.nl.de_322 en.zzp.co_422  eo.ak.ny_554 sa.un.un_630 
  0x2c00400c, 0x5809630c, 0x15004a12, 0x0a071112,   // lb.fy.un_530 sco.pl.om_543  yo.un.un_640 ro.bg.mk_654 
  0x5800650d, 0x03481ba0, 0x38130e08, 0x52464fa7,   // gv.om.un_540 tr.tt.nl_322  is.et.tk_443 bi.qu.ha_532 
  // [d3c0]
  0x19562504, 0x51351c07, 0x58005105, 0x090d5c55,   // eu.mg.gl_332 id.zu.kl_432  kl.om.un_330 sa.ne.hi_442 
  0x06375f0d, 0x0c5f3707, 0x6800672c, 0xfc2a55a4,   // tn.st.de_554 st.tn.sv_432  ak.ig.un_990 rw.mt.zzp_433 
  0x42643b07, 0x631f010b, 0x58516ba4, 0x522a4713,   // so.lg.co_432 en.cy.sco_542  ceb.kl.om_433 sn.mt.ha_665 
  0x15002e07, 0x18275112, 0x65031502, 0x01554fa0,   // fo.un.un_420 kl.gd.ga_654  un.nl.gv_222 bi.rw.en_322 
  // [d3d0]
  0x234435a9, 0x5c330308, 0x11001d1a, 0x0200150d,   // tg.kk.ky_544 nl.nn.sa_443  la.ro.un_760 un.da.un_540 
  0x623e3b08, 0x101273ee, 0x1d0257a4, 0x09000309,   // so.rm.kha_443 ny.hu.lt_422  na.da.la_433 nl.pl.un_440 
  0x68006412, 0x686b01a0, 0x02002c08, 0x150415a0,   // lg.ig.un_640 en.ceb.ig_322  fy.da.un_430 un.ru.un_322 
  0xfe001d05, 0x43003e0d, 0x1e522a04, 0x3900510e,   // la.tlh.un_330 rm.ie.un_540  mt.ha.ms_332 kl.br.un_550 
  // [d3e0]
  0x595501a4, 0x03002c13, 0x2a0d4005, 0x1d5c1e07,   // en.rw.rn_433 fy.nl.un_650  lb.cs.mt_333 ms.sa.la_432 
  0x332205ee, 0x595564a0, 0x69003808, 0x475201a4,   // fr.oc.nn_422 lg.rw.rn_322  tk.mfe.un_430 en.ha.sn_433 
  0x230219a4, 0x220dfe05, 0x2a400da4, 0x36190b02,   // gl.da.ca_433 tlh.cs.oc_333  cs.lb.mt_433 es.gl.gn_222 
  0x02251aa4, 0x481d1ca4, 0x0d005005, 0x63586412,   // tl.eu.da_433 id.la.tt_433  fj.cs.un_330 lg.om.sco_654 
  // [d3f0]
  0x52250608, 0xfe260d0c, 0x730213ec, 0x32005007,   // de.eu.ha_443 cs.ia.tlh_543  et.da.ny_644 fj.bs.un_420 
  0x353c3704, 0x150430ad, 0x471002ad, 0x39fe0d02,   // ba.ug.tg_332 uz.ru.un_643  da.lt.sn_643 cs.tlh.br_222 
  0x0d005208, 0x221d5da4, 0x183c3da4, 0x02003714,   // ha.cs.un_430 ss.la.oc_433  ku.ug.ar_433 st.da.un_660 
  0x3b3158ad, 0x033f0205, 0xfc381fa7, 0x0a002502,   // om.az.so_643 da.af.nl_333  cy.tk.zzp_532 mn.mk.un_220 
  
  // [d400]
  0x79000d0e, 0x40391f5a, 0x233d3404, 0x21150da7,   // cs.war.un_550 cy.br.lb_553  ps.ku.ky_332 cs.jw.un_520 
  0x110d4205, 0x09400d08, 0x63000111, 0x1f400d11,   // co.cs.ro_333 cs.lb.pl_443  en.sco.un_630 cs.lb.cy_653 
  0x4b000204, 0x1200230b, 0x0d0f1107, 0x4e190b0d,   // da.mi.un_320 ky.ur.un_520  ro.lv.cs_432 es.gl.ay_554 
  0x514702a0, 0x10070a08, 0x0227050c, 0x05004034,   // da.sn.kl_322 mk.bg.be_443  fr.gd.da_543 lb.fr.un_A80 
  // [d410]
  0x05001914, 0x34002a07, 0x33004707, 0x170407a7,   // gl.fr.un_660 mt.xh.un_420  sn.nn.un_420 bg.ru.sr_532 
  0x1165390e, 0x27390509, 0x3700fe02, 0x202937ec,   // br.gv.ro_555 fr.br.gd_444  tlh.st.un_220 st.sl.sq_644 
  0x3200161a, 0x135706a7, 0x5d1137a6, 0x493273a0,   // hr.bs.un_760 de.na.et_532  st.ro.ss_521 ny.bs.to_322 
  0x032c3fa0, 0x654c39ad, 0x23002007, 0x1b004307,   // af.fy.nl_322 br.wo.gv_643  sq.ca.un_420 ie.tr.un_420 
  // [d420]
  0x3f005d07, 0x0f0657ee, 0x5d004e12, 0x18352ca0,   // ss.af.un_420 na.de.lv_422  ay.ss.un_640 fy.zu.ga_322 
  0x23000302, 0x382ffaad, 0x1b003407, 0x130420ad,   // nl.ca.un_220 nr.su.tk_643  xh.tr.un_420 sq.fi.et_643 
  0x1b3222ad, 0x1f2e6504, 0x555f67a9, 0x21035da7,   // oc.bs.tr_643 gv.fo.cy_332  ak.tn.rw_544 ss.nl.jw_532 
  0x24005622, 0x1c2421a4, 0x35252307, 0x2f1d02a4,   // mg.eo.un_870 jw.eo.id_433  ky.mn.tg_432 da.la.su_433 
  // [d430]
  0x64005819, 0x3d002312, 0x1115080c, 0x64003721,   // om.lg.un_750 ky.ku.un_640  uk.ro.un_530 st.lg.un_860 
  0x10084409, 0x43222312, 0x2c005b25, 0x25000d04,   // kk.uk.be_444 ca.oc.ie_654  sg.fy.un_920 cs.eu.un_320 
  0x3530445a, 0x39003e05, 0x0800300c, 0x10380405,   // kk.uz.tg_553 rm.br.un_330  uz.uk.un_530 ru.tk.be_333 
  0x313048ec, 0x0a11360c, 0x12000d0b, 0x53021ea0,   // tt.uz.az_644 gn.ro.pt_543  cs.hu.un_520 ms.da.ht_322 
  // [d440]
  0x3c00380e, 0x2c005b0b, 0x100417a7, 0x24002f19,   // tk.ug.un_550 sg.fy.un_520  sr.ru.be_532 su.eo.un_750 
  0x1e1c230c, 0x350748a0, 0x3f0361a7, 0x03603fa4,   // ca.id.ms_543 tt.bg.tg_322  za.nl.af_532 af.vo.nl_433 
  0x2c000a08, 0x11005711, 0x6a0258ee, 0x440a23a0,   // pt.fy.un_430 na.ro.un_630  om.da.haw_422 ky.mk.kk_322 
  0x3b586aac, 0x0d0913ad, 0x04151509, 0x10003013,   // haw.om.so_632 bh.hi.ne_643  un.ru.un_440 uz.be.un_650 
  // [d450]
  0x10000802, 0x35170404, 0x3f002504, 0x1c463ba6,   // uk.be.un_220 ru.sr.tg_332  eu.af.un_320 so.qu.id_521 
  0x636a0207, 0x46006504, 0x07081505, 0x2e0e0c04,   // da.haw.sco_432 gv.qu.un_320  un.uk.bg_333 sv.is.fo_332 
  0x3f2803a0, 0x173035a9, 0xfc4c28ec, 0x3000212a,   // nl.sw.af_322 tg.uz.sr_544  sw.wo.zzp_644 fa.uz.un_970 
  0x2afc4da0, 0x4a6857ad, 0x65000304, 0xfc1503a4,   // aa.zzp.mt_322 na.ig.yo_643  nl.gv.un_320 nl.zzp.un_430 
  // [d460]
  0x13091c04, 0x34005f05, 0x5d036ba4, 0x48001708,   // mr.hi.bh_332 tn.xh.un_330  ceb.nl.ss_433 sr.tt.un_430 
  0x353934ee, 0x69000713, 0x15170413, 0xfc0315a0,   // xh.br.zu_422 it.mfe.un_650  ru.sr.un_665 un.nl.zzp_322 
  0x65000c02, 0x6b1506a0, 0x0603400d, 0x016515ee,   // sv.gv.un_220 de.ceb.un_320  lb.nl.de_554 un.gv.en_422 
  0x5000510e, 0x28382f08, 0x1b2a07a9, 0x55022807,   // kl.fj.un_550 su.tk.sw_443  it.mt.tr_544 sw.da.rw_432 
  // [d470]
  0x3046520d, 0x30442311, 0x40002721, 0x644f5da4,   // ha.qu.uz_554 ky.kk.uz_653  gd.lb.un_860 ss.bi.lg_433 
  0x25006907, 0x2151fe07, 0x355d25a0, 0x07080a09,   // mfe.eu.un_420 tlh.kl.jw_432  eu.ss.zu_322 mk.uk.bg_444 
  0x135a1da9, 0x062c400c, 0x0f25020b, 0x04100808,   // la.sm.et_544 lb.fy.de_543  da.eu.lv_542 uk.be.ru_443 
  0x533925ad, 0x1d455aa4, 0x07173504, 0x3b595513,   // eu.br.ht_643 sm.ln.la_433  tg.sr.bg_332 rw.rn.so_665 
  // [d480]
  0x50595560, 0x56004902, 0x691b3b05, 0x036a4912,   // rw.rn.fj_664 to.mg.un_220  so.tr.mfe_333 to.haw.nl_654 
  0x1b59550d, 0x4e001c22, 0x0a483804, 0x353425a0,   // rw.rn.tr_554 id.ay.un_870  tk.tt.mk_332 eu.xh.zu_322 
  0x6b451ca9, 0x35005502, 0x24002008, 0x3b001b09,   // id.ln.ceb_544 rw.zu.un_220  sq.eo.un_430 tr.so.un_440 
  0x693b1b0c, 0x1a474da4, 0x4408150c, 0x1b55520e,   // tr.so.mfe_543 aa.sn.tl_433  un.uk.kk_543 ha.rw.tr_555 
  // [d490]
  0x675a1ea4, 0x1b464f04, 0x50001e1a, 0x5d000205,   // ms.sm.ak_433 bi.qu.tr_332  ms.fj.un_760 da.ss.un_330 
  0x2578525a, 0x40630612, 0xfc5e130c, 0x00004937,   // ha.ve.eu_553 de.sco.lb_654  et.ts.zzp_543 to.un.un_B00 
  0x0f11285a, 0x4a595508, 0x570615a4, 0x1b5559ad,   // sw.ro.lv_553 rw.rn.yo_443  un.de.na_433 rn.rw.tr_643 
  0x47597505, 0x28644607, 0x3e005d04, 0x1b5047ec,   // nso.rn.sn_333 qu.lg.sw_432  ss.rm.un_320 sn.fj.tr_644 
  // [d4a0]
  0x3c4423ee, 0x5e4d3b07, 0x3b6467a6, 0x4d471eaf,   // ky.kk.ug_422 so.aa.ts_432  ak.lg.so_521 ms.sn.aa_655 
  0x593b5513, 0x47731ea9, 0x47005034, 0x1b59555a,   // rw.so.rn_665 ms.ny.sn_544  fj.sn.un_A80 rw.rn.tr_553 
  0x15044407, 0x4c732107, 0x38003713, 0x4436150c,   // kk.ru.un_432 jw.ny.wo_432  ba.tk.un_650 un.ab.kk_543 
  0x1800370d, 0x3d213b5a, 0x0a381705, 0x3c00040e,   // st.ga.un_540 ks.fa.ku_553  sr.tk.mk_333 ru.ug.un_550 
  // [d4b0]
  0x171007a0, 0x3b123d5a, 0x4804170c, 0x38483708,   // bg.be.sr_322 ku.ur.ks_553  sr.ru.tt_543 ba.tt.tk_443 
  0x5a376aad, 0x37005a08, 0x46005802, 0x34072102,   // haw.st.sm_643 sm.st.un_430  om.qu.un_220 jw.it.xh_222 
  0x07002402, 0x1821305a, 0x28255804, 0x440a37a4,   // eo.it.un_220 uz.fa.ar_553  om.eu.sw_332 ba.mk.kk_433 
  0x0b004607, 0x25580e0c, 0x651b200c, 0x3c3004a0,   // qu.es.un_420 is.om.eu_543  sq.tr.gv_543 ru.uz.ug_322 
  // [d4c0]
  0x23440407, 0x3e00250c, 0x3f37350d, 0x34002118,   // ru.kk.ky_432 eu.rm.un_530  zu.st.af_554 fa.ps.un_740 
  0x1a2012a4, 0x125852ee, 0x4b005713, 0x11233611,   // hu.sq.tl_433 ha.om.hu_422  na.mi.un_650 ab.ky.ro_653 
  0x02311507, 0x5c51330c, 0x27000e04, 0x252451ad,   // un.az.da_432 nn.kl.sa_543  is.gd.un_320 kl.eo.eu_643 
  0x48465407, 0x30213412, 0x043715a7, 0x0000632d,   // ik.qu.tt_432 ps.fa.uz_654  un.ba.ru_532 sco.un.un_A00 
  // [d4d0]
  0x080411a4, 0x303537ad, 0x1b382ca0, 0x63001f13,   // ro.ru.uk_433 ba.tg.uz_643  fy.tk.tr_322 cy.sco.un_650 
  0x300a1702, 0x10040805, 0x39002f04, 0x21000a08,   // sr.mk.uz_222 uk.ru.be_333  su.br.un_320 pt.jw.un_430 
  0x2f005804, 0x03634f0c, 0x08006308, 0x3c153804,   // om.su.un_320 bi.sco.nl_543  sco.no.un_430 tk.ug.un_320 
  0x10044805, 0x11002c02, 0x040715ee, 0x6e681da7,   // tt.ru.be_333 fy.ro.un_220  un.bg.ru_422 la.ig.hmn_532 
  // [d4e0]
  0x2e083311, 0x37001f18, 0x0e2e1d0d, 0x37004013,   // nn.no.fo_653 cy.st.un_740  la.fo.is_554 lb.st.un_650 
  0x04073505, 0x40002509, 0x0e2e1c0c, 0x1d006b0c,   // tg.bg.ru_333 eu.lb.un_440  id.fo.is_543 ceb.la.un_530 
  0xfc6a36a7, 0x170e2e5a, 0x043b510c, 0x620e1da9,   // gn.haw.zzp_532 fo.is.sr_553  kl.so.fi_543 la.is.kha_544 
  0x56473605, 0x1d002f0d, 0x1f3f0305, 0x2c3b5108,   // gn.sn.mg_333 su.la.un_540  nl.af.cy_333 kl.so.fy_443 
  // [d4f0]
  0x4c000e20, 0x58043ba4, 0x4b35020c, 0x514c64a4,   // is.wo.un_850 so.fi.om_433  da.zu.mi_543 lg.wo.kl_433 
  0x60111d0c, 0x2c583b11, 0x3b585aa4, 0x3534280e,   // la.ro.vo_543 so.om.fy_653  sm.om.so_433 sw.xh.zu_555 
  0x136458ad, 0x0c2e0e13, 0x37005f19, 0x100a17ee,   // om.lg.et_643 is.fo.sv_665  tn.st.un_750 sr.mk.be_422 
  0x791b2eac, 0x4d3b5812, 0x52003007, 0x304c1d08,   // fo.tr.war_632 om.so.aa_654  uz.ha.un_420 la.wo.uz_443 
  // [d500]
  0x4f2e1d14, 0x2400520b, 0x09004c1b, 0x3f032cec,   // la.fo.bi_666 ha.eo.un_520  wo.pl.un_770 fy.nl.af_644 
  0x520e1dec, 0x03000705, 0x30005d04, 0x20001d07,   // la.is.ha_644 it.nl.un_330  ss.uz.un_320 la.sq.un_420 
  0x1b1d010c, 0xfe00520d, 0x15642cee, 0x4f2e1d13,   // en.la.tr_543 ha.tlh.un_540  fy.lg.un_422 la.fo.bi_665 
  0x49000419, 0x122134af, 0x4cfe4613, 0x3b6451ad,   // fi.to.un_750 ps.fa.ur_655  qu.tlh.wo_665 kl.lg.so_643 
  // [d510]
  0x302f29af, 0x513b58a4, 0x643b51a9, 0x052212a9,   // sl.su.uz_655 om.so.kl_433  kl.so.lg_544 hu.oc.fr_544 
  0x112d0d08, 0x3b58510c, 0x12290fa7, 0x300ffea0,   // cs.sk.ro_443 kl.om.so_543  lv.sl.hu_532 tlh.lv.uz_322 
  0x403e030c, 0x65302f02, 0x1b48310b, 0x39000c04,   // nl.rm.lb_543 su.uz.gv_222  az.tt.tr_542 sv.br.un_320 
  0x40030612, 0x21533907, 0x24054dac, 0x281ffca4,   // de.nl.lb_654 br.ht.jw_432  aa.fr.eo_632 zzp.cy.sw_433 
  // [d520]
  0x30113507, 0x032c2205, 0x65001f07, 0x17042509,   // tg.ro.uz_432 oc.fy.nl_333  cy.gv.un_420 mn.ru.sr_444 
  0x38094a07, 0x3800fc0c, 0x58490907, 0x3b5c58a0,   // yo.pl.tk_432 zzp.tk.un_530  pl.to.om_432 om.sa.so_322 
  0x093029a4, 0x0f002913, 0x4a005602, 0x2e4c3002,   // sl.uz.pl_433 sl.lv.un_650  mg.yo.un_220 uz.wo.fo_222 
  0x3700150d, 0x303421a4, 0x08005a04, 0x43001812,   // un.ba.un_540 fa.ps.uz_433  sm.no.un_320 ga.ie.un_640 
  // [d530]
  0x35000907, 0x5c007607, 0x3e001505, 0x2a46fea4,   // pl.zu.un_420 crs.sa.un_420  un.rm.un_330 tlh.qu.mt_433 
  0x1b001504, 0x48461a12, 0x79fe6baf, 0x12212808,   // un.tr.un_320 tl.qu.tt_654  ceb.tlh.war_655 sd.fa.ur_443 
  0x17083ca9, 0x621ffe12, 0x1f0918a4, 0x56285255,   // ug.uk.sr_544 tlh.cy.kha_654  ga.pl.cy_433 ha.sw.mg_442 
  0x4800610c, 0xfe004814, 0x1737250b, 0x1a48fea7,   // za.tt.un_530 tt.tlh.un_660  mn.ba.sr_542 tlh.tt.tl_532 
  // [d540]
  0x0200fe07, 0x381dfea7, 0x4348fead, 0x4800fe1b,   // tlh.da.un_420 tlh.la.tk_532  tlh.tt.ie_643 tlh.tt.un_770 
  0x2f202504, 0x1c511e11, 0x031101a4, 0x13005105,   // eu.sq.su_332 ms.kl.id_653  en.ro.nl_433 kl.et.un_330 
  0x4b1354a4, 0x2536200c, 0x21205155, 0x072025ee,   // ik.et.mi_433 sq.gn.eu_543  kl.sq.jw_442 eu.sq.it_422 
  0x205e5ca4, 0x072636a9, 0x041036a7, 0x4800100d,   // sa.ts.sq_433 gn.ia.it_544  ab.be.ru_532 be.tt.un_540 
  // [d550]
  0x0a041508, 0x2f2033a0, 0x11003605, 0x79190a04,   // un.ru.mk_443 nn.sq.su_322  gn.ro.un_330 pt.gl.war_332 
  0x0e5264a0, 0x2f2520ad, 0x2500200d, 0x2e2420a0,   // lg.ha.is_322 sq.eu.su_643  sq.eu.un_540 sq.eo.fo_322 
  0x043035a4, 0x1b000c08, 0x20250107, 0x4438230d,   // tg.uz.ru_433 sv.tr.un_430  en.eu.sq_432 ky.tk.kk_554 
  0x640c520c, 0x25105108, 0x204b5a07, 0x122818ad,   // ha.sv.lg_543 kl.lt.eu_443  sm.mi.sq_432 ar.sd.ur_643 
  // [d560]
  0x30383ca9, 0x30281813, 0x07150aa4, 0x637601a4,   // ug.tk.uz_544 ar.sd.uz_665  mk.bg.un_430 en.crs.sco_433 
  0x42072a60, 0x06005204, 0x4b496a13, 0x49360dec,   // mt.it.co_664 ha.de.un_320  haw.to.mi_665 cs.gn.to_644 
  0x6a494a0c, 0x13004908, 0x132d0d09, 0x0400230b,   // yo.to.haw_543 to.et.un_430  cs.sk.et_444 ky.ru.un_520 
  0x0407080b, 0x0100380c, 0x6a4b13a4, 0x62790107,   // uk.bg.ru_542 tk.en.un_530  et.mi.haw_433 en.war.kha_432 
  // [d570]
  0x364a5d12, 0x49004521, 0x6a4a5ca7, 0x34123b0c,   // ss.yo.gn_654 ln.to.un_860  sa.yo.haw_532 ks.ur.ps_543 
  0x132d0d04, 0x59002812, 0x6a4b3305, 0x4361fa12,   // cs.sk.et_332 sw.rn.un_640  nn.mi.haw_333 nr.za.ie_654 
  0x4d006719, 0x204a4b07, 0x02672007, 0x20001308,   // ak.aa.un_750 mi.yo.sq_432  sq.ak.da_432 et.sq.un_430 
  0x04000102, 0x4b283655, 0x3500fa12, 0xfa000108,   // en.fi.un_220 gn.sw.mi_442  nr.zu.un_640 en.nr.un_430 
  // [d580]
  0x516b07ad, 0x307938a7, 0x2337360c, 0x21152f04,   // it.ceb.kl_643 tk.war.uz_532  ab.ba.ky_543 su.jw.un_320 
  0x526929a7, 0x5c116005, 0x52004a14, 0x46006404,   // sl.mfe.ha_532 vo.ro.sa_333  yo.ha.un_660 lg.qu.un_320 
  0x63004b12, 0x09131c12, 0x1a6b4a0d, 0x0000fa15,   // mi.sco.un_640 mr.bh.hi_654  yo.ceb.tl_554 nr.un.un_700 
  0x470751ad, 0x4222050c, 0x496920a4, 0x152201a4,   // kl.it.sn_643 fr.oc.co_543  sq.mfe.to_433 en.oc.un_433 
  // [d590]
  0x1d001119, 0x10000912, 0x07354407, 0x34211809,   // ro.la.un_750 pl.lt.un_640  kk.tg.bg_432 ar.fa.ps_444 
  0x10234807, 0x15002b08, 0x4e360e05, 0x4411235a,   // tt.ky.be_432 vi.un.un_430  is.gn.ay_333 ky.ro.kk_553 
  0x31201c07, 0x231d52ee, 0x522515a0, 0x033815a0,   // id.sq.az_432 ha.la.ca_422  un.eu.ha_322 un.tk.nl_322 
  0x5c0913ad, 0x081037a7, 0x3700080c, 0x0a041007,   // bh.hi.sa_643 ba.be.uk_532  uk.ba.un_530 be.ru.mk_432 
  // [d5a0]
  0x38025ca4, 0x313860ad, 0x0a443855, 0x02732f04,   // sa.da.tk_433 vo.tk.az_643  tk.kk.mk_442 su.ny.da_332 
  0x441823ee, 0x3b5c2107, 0x6a004913, 0x134f0204,   // ky.ar.kk_422 jw.sa.so_432  to.haw.un_650 da.bi.et_332 
  0xfc354aa4, 0x1b005c02, 0x10003012, 0x3b584e12,   // yo.zu.zzp_433 sa.tr.un_220  uz.be.un_640 ay.om.so_654 
  0x1c130d02, 0x645c3b08, 0x47535ca0, 0x214564af,   // ne.bh.mr_222 so.sa.lg_443  sa.ht.sn_322 lg.ln.jw_655 
  // [d5b0]
  0x645c4507, 0x52001a02, 0x38003f07, 0x5c53500e,   // ln.sa.lg_432 tl.ha.un_220  af.tk.un_420 fj.ht.sa_555 
  0x150a11ec, 0x463b5004, 0x190a3ea9, 0x39006919,   // ro.mk.un_644 fj.so.qu_332  rm.pt.gl_544 mfe.br.un_750 
  0x4a002702, 0x56001504, 0x33067955, 0x33083eec,   // gd.yo.un_220 un.mg.un_320  war.de.nn_442 rm.no.nn_644 
  0x3400301b, 0x3f004b05, 0x0600402a, 0x21003f08,   // uz.ps.un_770 mi.af.un_330  lb.de.un_970 af.jw.un_430 
  // [d5c0]
  0x0a221da4, 0x11000f05, 0x5e4c4d07, 0x15003402,   // la.oc.pt_433 lv.ro.un_330  aa.wo.ts_432 xh.un.un_220 
  0x16fe6504, 0x23000108, 0x043e01a0, 0x755b40a4,   // gv.tlh.hr_332 en.ca.un_430  en.rm.fi_322 lb.sg.nso_433 
  0x21033f0b, 0x18442311, 0x1124fe0c, 0x23190a0c,   // af.nl.jw_542 ky.kk.ar_653  tlh.eo.ro_543 pt.gl.ca_543 
  0x04231002, 0x634620ec, 0x131c0d04, 0x48000813,   // be.ky.ru_222 sq.qu.sco_644  ne.mr.bh_332 uk.tt.un_650 
  // [d5d0]
  0x0d135ca7, 0x11000a1a, 0x022a43ee, 0xfe000208,   // sa.bh.ne_532 mk.ro.un_760  ie.mt.da_422 da.tlh.un_430 
  0x3e002a02, 0x174415a0, 0xfe30465a, 0x4600fc0b,   // mt.rm.un_220 un.kk.sr_322  qu.uz.tlh_553 zzp.qu.un_520 
  0x342818a6, 0x4400080c, 0x0700080e, 0x123b2104,   // ar.sd.ps_521 uk.kk.un_530  uk.bg.un_550 fa.ks.ur_332 
  0x04111505, 0x48350aa0, 0x480437a4, 0x36303808,   // un.ro.ru_333 mk.tg.tt_322  ba.ru.tt_433 tk.uz.ab_443 
  // [d5e0]
  0x1136380c, 0x40001f02, 0x3b2f27ee, 0x3133240c,   // tk.ab.ro_543 cy.lb.un_220  gd.su.so_422 eo.nn.az_543 
  0x2e000c07, 0x25270107, 0x1f156307, 0x40001904,   // sv.fo.un_420 en.gd.eu_432  sco.cy.un_420 gl.lb.un_320 
  0x35253955, 0x0a0737ee, 0x06020fa7, 0x2e004e05,   // br.eu.zu_442 ba.bg.mk_422  lv.da.de_532 ay.fo.un_330 
  0x302535a0, 0x0e332e0c, 0x1c135c12, 0x651501ee,   // tg.mn.uz_322 fo.nn.is_543  sa.bh.mr_654 en.gv.un_420 
  // [d5f0]
  0x6b004612, 0x5e5c56a9, 0x092701a0, 0x0410120b,   // qu.ceb.un_640 mg.sa.ts_544  en.gd.pl_322 hu.lt.fi_542 
  0x0918270d, 0x51001e08, 0x09271812, 0x17005c05,   // gd.ga.pl_554 ms.kl.un_430  ga.gd.pl_654 sa.sr.un_330 
  0x09002102, 0x1827fe12, 0x10070a13, 0x0900101a,   // jw.pl.un_220 tlh.gd.ga_654  mk.bg.be_665 lt.pl.un_760 
  0x091827af, 0x313822ac, 0x1a544da4, 0x43180607,   // gd.ga.pl_655 oc.tk.az_632  aa.ik.tl_433 de.ga.ie_432 
  // [d600]
  0x3b58fe07, 0x32006708, 0x040d2dad, 0x27010904,   // tlh.om.so_432 ak.bs.un_430  sk.cs.fi_643 pl.en.gd_332 
  0x1f1809a4, 0x23001518, 0x0c003107, 0x5c12feee,   // pl.ga.cy_433 un.ky.un_740  az.sv.un_420 tlh.hu.sa_422 
  0x0e2e3304, 0x5300761b, 0x013f2fa0, 0x20005411,   // nn.fo.is_332 crs.ht.un_770  su.af.en_322 ik.sq.un_630 
  0x532d3904, 0x09001011, 0x270918af, 0x2d0d4d0c,   // br.sk.ht_332 lt.pl.un_630  ga.pl.gd_655 aa.cs.sk_543 
  // [d610]
  0x15100907, 0x091827a9, 0x09271813, 0x43752a0c,   // pl.lt.un_432 gd.ga.pl_544  ga.gd.pl_665 mt.nso.ie_543 
  0x182709a7, 0x2f003b08, 0x1538300e, 0x2a335107,   // pl.gd.ga_532 so.su.un_430  uz.tk.un_555 kl.nn.mt_432 
  0x21123d0e, 0x35081007, 0x08020502, 0x1d4c67ee,   // ku.ur.fa_555 be.uk.tg_432  fr.da.no_222 ak.wo.la_422 
  0x43381b0d, 0x34283d0e, 0x102556ad, 0x102545a0,   // tr.tk.ie_554 ku.sd.ps_555  mg.eu.lt_643 ln.eu.lt_322 
  // [d620]
  0x1234300d, 0x48043007, 0x1a796b11, 0x17082307,   // uz.ps.ur_554 uz.ru.tt_432  ceb.war.tl_653 ky.uk.sr_432 
  0x44231708, 0x73004912, 0x0a483805, 0x23002804,   // sr.ky.kk_443 to.ny.un_640  tk.tt.pt_333 sw.ca.un_320 
  0x1b204809, 0x0c004b04, 0x3500070d, 0xfc003304,   // tt.sq.tr_444 mi.sv.un_320  bg.tg.un_540 nn.zzp.un_320 
  0x3538230c, 0x353704a0, 0x04001312, 0x2800250d,   // ky.tk.tg_543 ru.ba.tg_322  et.fi.un_640 eu.sw.un_540 
  // [d630]
  0x1f392504, 0x0e000a0c, 0x35fc0112, 0x474d5712,   // eu.br.cy_332 pt.is.un_530  en.zzp.zu_654 na.aa.sn_654 
  0x1f000d08, 0x0135fcee, 0x1f3f2504, 0x38002a07,   // cs.cy.un_430 zzp.zu.en_422  eu.af.cy_332 mt.tk.un_420 
  0x343d21ac, 0x130d1ca4, 0x556b34a0, 0x6a286bec,   // fa.ku.ps_632 mr.ne.bh_433  xh.ceb.rw_322 ceb.sw.haw_644 
  0x462859a0, 0x44303c13, 0x17002302, 0x55284b04,   // rn.sw.qu_322 ug.uz.kk_665  ky.sr.un_220 mi.sw.rw_332 
  // [d640]
  0x5200280e, 0x49000405, 0x18443c04, 0x44353855,   // sw.ha.un_550 fi.to.un_330  ug.kk.ar_332 tk.tg.kk_442 
  0x38314807, 0x15374813, 0x08040707, 0x352855a0,   // tt.az.tk_432 tt.ba.un_665  bg.ru.uk_432 rw.sw.zu_322 
  0x48072504, 0x48372302, 0x552f4b04, 0x250415a0,   // mn.bg.tt_332 ky.ba.tt_222  mi.su.rw_332 un.ru.mn_322 
  0x28000404, 0x12182308, 0x5d35640c, 0x03200602,   // fi.sw.un_320 ky.ar.ur_443  lg.zu.ss_543 de.sq.nl_222 
  // [d650]
  0x240306ad, 0x25000a09, 0x25442313, 0x122130a4,   // de.nl.eo_643 mk.mn.un_440  ky.kk.mn_665 uz.fa.ur_433 
  0x113038a4, 0x481023ec, 0x1e000202, 0x0f005a04,   // tk.uz.ro_433 ky.be.tt_644  da.ms.un_220 sm.lv.un_320 
  0x194d0bec, 0x24000d0d, 0x370a4808, 0x15004305,   // es.aa.gl_644 cs.eo.un_540  tt.mk.ba_443 ie.un.un_330 
  0x3e006b04, 0x2b1127a0, 0x400306a9, 0x2f000304,   // ceb.rm.un_320 gd.ro.vi_322  de.nl.lb_544 nl.su.un_320 
  // [d660]
  0x4f00012b, 0x13003c12, 0x13060ca9, 0x5c005a04,   // en.bi.un_980 ug.bh.un_640  sv.de.et_544 sm.sa.un_320 
  0x3b00610c, 0x2b1827af, 0x12616412, 0x381b48a9,   // za.so.un_530 gd.ga.vi_655  lg.za.hu_654 tt.tr.tk_544 
  0x23443814, 0x2f214505, 0x0e362e04, 0x2a2407a0,   // tk.kk.ky_666 ln.jw.su_333  fo.gn.is_332 it.eo.mt_322 
  0x5c211212, 0x18442308, 0x081e1d04, 0x480415ee,   // hu.jw.sa_654 ky.kk.ar_443  la.ms.no_332 un.ru.tt_422 
  // [d670]
  0x1234300b, 0x07441755, 0x623b3960, 0x4800100c,   // uz.ps.ur_542 sr.kk.bg_442  br.so.kha_664 be.tt.un_530 
  0x11003e1a, 0x182128ee, 0x36136212, 0xfc191fee,   // rm.ro.un_760 sd.fa.ar_422  kha.et.gn_654 cy.gl.zzp_422 
  0x67491e12, 0x0405010b, 0x01006a0b, 0x150104ad,   // ms.to.ak_654 en.fr.fi_542  haw.en.un_520 ru.iw.un_643 
  0xfc000622, 0x58755ca4, 0x03065704, 0x1600490c,   // de.zzp.un_870 sa.nso.om_433  na.de.nl_332 to.hr.un_530 
  // [d680]
  0x1c3b0911, 0x073748ee, 0x04441508, 0x21521ba7,   // hi.ks.mr_653 tt.ba.bg_422  un.kk.ru_443 tr.ha.jw_532 
  0x5f49520c, 0x48001802, 0x01006309, 0x48382313,   // ha.to.tn_543 ga.tt.un_220  sco.en.un_440 ky.tk.tt_665 
  0x29001013, 0x00005706, 0x4b46135a, 0x494d52a4,   // lt.sl.un_650 na.un.un_400  et.qu.mi_553 ha.aa.to_433 
  0x50005208, 0x30002005, 0x133b6aa0, 0x49004a05,   // ha.fj.un_430 sq.uz.un_330  haw.so.et_322 yo.to.un_330 
  // [d690]
  0x2b451308, 0x63000102, 0x37321605, 0xfe006711,   // et.ln.vi_443 en.sco.un_220  hr.bs.st_333 ak.tlh.un_630 
  0x4b1e1c0c, 0x4c004014, 0x3f03fa13, 0x307910ee,   // id.ms.mi_543 lb.wo.un_660  nr.nl.af_665 lt.war.uz_422 
  0x4c000102, 0x2e005804, 0x1d003b02, 0x15151707,   // en.wo.un_220 om.fo.un_320  so.la.un_220 sr.un.un_420 
  0x63004722, 0xfe6324ad, 0x38005d0c, 0x633f520c,   // sn.sco.un_870 eo.sco.tlh_643  ss.tk.un_530 ha.af.sco_543 
  // [d6a0]
  0x090c02a0, 0x223803a0, 0x47731c0c, 0x02031dad,   // da.sv.pl_322 nl.tk.oc_322  id.ny.sn_543 la.nl.da_643 
  0x2a002012, 0x6b1a7913, 0x23001d04, 0x732801a0,   // sq.mt.un_640 war.tl.ceb_665  la.ca.un_320 en.sw.ny_322 
  0x13002404, 0x0e373312, 0x37154807, 0x03232908,   // eo.et.un_320 nn.st.is_654  tt.ba.un_420 sl.ca.nl_443 
  0x134c3bec, 0x134604ad, 0x3f00200c, 0x2c5dfaad,   // so.wo.et_644 fi.qu.et_643  sq.af.un_530 nr.ss.fy_643 
  // [d6b0]
  0x5d00fe0e, 0x541b04ad, 0x25241205, 0x33462eee,   // tlh.ss.un_550 fi.tr.ik_643  hu.eo.eu_333 fo.qu.nn_422 
  0x5c044907, 0x375e5d07, 0x1f461504, 0x1c0a1d04,   // to.fi.sa_432 ss.ts.st_432  un.qu.cy_332 la.pt.id_332 
  0x03005c0c, 0x58004e13, 0x20511fa9, 0x4900360c,   // sa.nl.un_530 ay.om.un_650  cy.kl.sq_544 gn.to.un_530 
  0x47002b09, 0x5c004714, 0x027347ec, 0x21005814,   // vi.sn.un_440 sn.sa.un_660  sn.ny.da_644 om.jw.un_660 
  // [d6c0]
  0x07170812, 0x2047020d, 0x101511a0, 0x5f73370e,   // uk.sr.bg_654 da.sn.sq_554  ro.be.un_320 st.ny.tn_555 
  0x3f001f04, 0x0b1d0702, 0x231d4304, 0x214428ee,   // cy.af.un_320 it.la.es_222  ie.la.ca_332 sd.kk.fa_422 
  0x100417a9, 0x0a370302, 0x26004019, 0x650361a4,   // sr.ru.be_544 nl.st.pt_222  lb.ia.un_750 za.nl.gv_433 
  0x3f002502, 0x351017a0, 0x212c03a0, 0x033f0208,   // eu.af.un_220 sr.be.tg_322  nl.fy.jw_322 da.af.nl_443 
  // [d6d0]
  0x28037905, 0x24000604, 0x12420708, 0x1500181b,   // war.nl.sw_333 de.eo.un_320  it.co.hu_443 ar.un.un_770 
  0x03611f0c, 0x033f37ec, 0x1d003f04, 0x4a000e18,   // cy.za.nl_543 st.af.nl_644  af.la.un_320 is.yo.un_740 
  0x37254805, 0x081107a9, 0x67006213, 0x63004b0d,   // tt.mn.ba_333 bg.ro.uk_544  kha.ak.un_650 mi.sco.un_540 
  0x42073e0c, 0x4a002d09, 0x330c0202, 0x100a17a4,   // rm.it.co_543 sk.yo.un_440  da.sv.nn_222 sr.mk.be_433 
  // [d6e0]
  0x292d69a0, 0x4d122308, 0x371004ee, 0x120e4eec,   // mfe.sk.sl_322 ca.hu.aa_443  ru.be.ba_422 ay.is.hu_644 
  0x35381bee, 0x12283da0, 0x120b4d05, 0x070a30ee,   // tr.tk.zu_422 ku.sd.ur_322  aa.es.hu_333 uz.mk.bg_422 
  0x44153504, 0x28383113, 0x6a001e22, 0x0f365207,   // tg.kk.un_320 az.tk.sw_665  ms.haw.un_870 ha.gn.lv_432 
  0x122321a0, 0x2f2855a7, 0x5f373307, 0x081117a4,   // fa.ky.ur_322 rw.sw.su_532  nn.st.tn_432 sr.ro.uk_433 
  // [d6f0]
  0x123d340c, 0x02005713, 0x0f1629a9, 0x11001022,   // ps.ku.ur_543 na.da.un_650  sl.hr.lv_544 be.ro.un_870 
  0x23001211, 0x32002108, 0x653b4a0c, 0x643f0655,   // hu.ca.un_630 jw.bs.un_430  yo.so.gv_543 de.af.lg_442 
  0x67006113, 0x483704a7, 0x190a23af, 0x5f1c1eaf,   // za.ak.un_650 ru.ba.tt_532  ca.pt.gl_655 ms.id.tn_655 
  0x3b3e58a0, 0x5e473307, 0x4757500c, 0x3b00fe04,   // om.rm.so_322 nn.sn.ts_432  fj.na.sn_543 tlh.so.un_320 
  // [d700]
  0x150415af, 0x481511ad, 0x4efe4612, 0x43000d0d,   // un.ru.un_655 ro.tt.un_630  qu.tlh.ay_654 cs.ie.un_540 
  0x7600532a, 0x15370407, 0x042538a0, 0x0436155a,   // ht.crs.un_970 ru.ba.un_432  tk.mn.ru_322 un.ab.ru_553 
  0x6e6b6260, 0x34004d0c, 0x48004402, 0x20004608,   // kha.ceb.hmn_664 aa.xh.un_530  kk.tt.un_220 qu.sq.un_430 
  0x4e462a0e, 0x08070a55, 0x25033f04, 0x441007a4,   // mt.qu.ay_555 mk.bg.uk_442  af.nl.eu_332 bg.be.kk_433 
  // [d710]
  0x2c250304, 0x2a3048af, 0x2800210c, 0x4658300c,   // nl.eu.fy_332 tt.uz.mt_655  fa.sd.un_530 uz.om.qu_543 
  0x484630af, 0x180b190b, 0x4d5451af, 0x074830a7,   // uz.qu.tt_655 gl.es.ga_542  kl.ik.aa_655 uz.tt.bg_532 
  0x10081112, 0x00003037, 0x29002507, 0x442536a7,   // ro.uk.be_654 uz.un.un_B00  eu.sl.un_420 ab.mn.kk_532 
  0x25003f08, 0x5d007323, 0x2f003b12, 0x19002f07,   // af.eu.un_430 ny.ss.un_880  so.su.un_640 su.gl.un_420 
  // [d720]
  0x281e1c02, 0x3f00131a, 0x13095c55, 0x30483108,   // id.ms.sw_222 et.af.un_760  sa.hi.bh_442 az.tt.uz_443 
  0x6e033f0d, 0x202c03a0, 0x4c6e40af, 0x033b3fa0,   // af.nl.hmn_554 nl.fy.sq_322  lb.hmn.wo_655 af.so.nl_322 
  0x3035110c, 0x353c3011, 0x4c6e0304, 0x40634c0b,   // ro.tg.uz_543 uz.ug.tg_653  nl.hmn.wo_332 wo.sco.lb_542 
  0x694c0110, 0x403b3f0c, 0x4c006e23, 0x4c006e0c,   // en.wo.mfe_642 af.so.lb_543  hmn.wo.un_880 hmn.wo.un_530 
  // [d730]
  0x377547a4, 0x080c48ee, 0x4c1f4007, 0x3528730b,   // sn.nso.st_433 tt.sv.no_422  lb.cy.wo_432 ny.sw.zu_542 
  0x631301a0, 0x353445ec, 0x6e006521, 0x40003f2b,   // en.et.sco_322 ln.xh.zu_644  gv.hmn.un_860 af.lb.un_980 
  0x674a4512, 0x35002802, 0x3c37480e, 0x562d0d02,   // ln.yo.ak_654 sw.zu.un_220  tt.ba.ug_555 cs.sk.mg_222 
  0x1a3b1e07, 0x1a4d50ec, 0x4e1e5c09, 0x2f5c1ca4,   // ms.so.tl_432 fj.aa.tl_644  sa.ms.ay_444 id.sa.su_433 
  // [d740]
  0x2a00670c, 0x303421a0, 0x3b1a6b09, 0x38002a09,   // ak.mt.un_530 fa.ps.uz_322  ceb.tl.so_444 mt.tk.un_440 
  0x2f1a1ca4, 0x503b5c14, 0x0e006012, 0x290210a9,   // id.tl.su_433 sa.so.fj_666  vo.is.un_640 lt.da.sl_544 
  0x4e0d020e, 0x100252ec, 0x3b5c1aa9, 0x52001009,   // da.cs.ay_555 ha.da.lt_644  tl.sa.so_544 lt.ha.un_440 
  0x2d0d360c, 0x60545caf, 0x2f1e4ea9, 0x35003613,   // gn.cs.sk_543 sa.ik.vo_655  ay.ms.su_544 ab.tg.un_650 
  // [d750]
  0x36442308, 0x464e3ba4, 0x44302308, 0x171002a4,   // ky.kk.ab_443 so.ay.qu_433  ky.uz.kk_443 da.lt.sr_433 
  0x195025ee, 0x2f1d55a0, 0x2500420c, 0x39572555,   // eu.fj.gl_422 rw.la.su_322  co.eu.un_530 eu.na.br_442 
  0x2c000213, 0x3435065a, 0x40050211, 0x29062508,   // da.fy.un_650 de.zu.xh_553  da.fr.lb_653 eu.de.sl_443 
  0x2b004807, 0x23354402, 0x080c0208, 0x080a07ee,   // tt.vi.un_420 kk.tg.ky_222  da.sv.no_443 bg.mk.uk_422 
  // [d760]
  0x372304a0, 0x61033fa4, 0x534a1bee, 0x1118270c,   // ru.ky.ba_322 af.nl.za_433  tr.yo.ht_422 gd.ga.ro_543 
  0x15080402, 0x5500592a, 0x15381112, 0x67595505,   // ru.uk.un_222 rn.rw.un_970  ro.tk.un_654 rw.rn.ak_333 
  0x28122102, 0x315d1ba7, 0x483710ee, 0x1100600d,   // fa.ur.sd_222 tr.ss.az_532  be.ba.tt_422 vo.ro.un_540 
  0x28551bee, 0x162e080c, 0x4415040d, 0x35083702,   // tr.rw.sw_422 no.fo.hr_543  ru.kk.un_540 ba.uk.tg_222 
  // [d770]
  0x5369fc07, 0x1000380b, 0x1b595312, 0x64006704,   // zzp.mfe.ht_432 tk.be.un_520  ht.rn.tr_654 ak.lg.un_320 
  0x05533604, 0x25003c09, 0x1d0517a0, 0x39292d0c,   // gn.ht.fr_332 ug.mn.un_440  sr.fr.la_322 sk.sl.br_543 
  0x2d0d39ee, 0x1b4831ad, 0x202a36a0, 0x01006e07,   // br.cs.sk_422 az.tt.tr_643  gn.mt.sq_322 hmn.en.un_420 
  0x01fc02a6, 0x1107fca0, 0x15040705, 0x44041055,   // da.zzp.en_521 zzp.it.ro_322  bg.ru.un_333 be.ru.kk_442 
  // [d780]
  0x011f63a7, 0x1d2301a4, 0x043530ad, 0x18442807,   // sco.cy.en_532 en.ca.la_433  uz.tg.ru_643 sd.kk.ar_432 
  0x28000204, 0x0e00040d, 0x0425070c, 0x0e001219,   // da.sw.un_320 fi.is.un_540  bg.mn.ru_543 hu.is.un_750 
  0x12040e04, 0x04370807, 0x052201a9, 0x311d3e55,   // is.fi.hu_332 uk.ba.ru_432  en.oc.fr_544 rm.la.az_442 
  0x30004704, 0x023b4d0c, 0x1b005a0c, 0x47007308,   // sn.uz.un_320 aa.so.da_543  sm.tr.un_530 ny.sn.un_430 
  // [d790]
  0x463736a0, 0x483038a0, 0x020c32a0, 0x5c13090b,   // gn.st.qu_322 tk.uz.tt_322  bs.sv.da_322 hi.bh.sa_542 
  0x24005307, 0x0e120407, 0x301b3202, 0x104006ad,   // ht.eo.un_420 fi.hu.is_432  bs.tr.uz_222 de.lb.lt_643 
  0x171107a4, 0x73000f12, 0x1c003e07, 0x0d001b05,   // bg.ro.sr_433 lv.ny.un_640  rm.id.un_420 tr.cs.un_330 
  0x39003109, 0x2c3f40a0, 0x04002c19, 0x120930a0,   // az.br.un_440 lb.af.fy_322  fy.fi.un_750 uz.pl.hu_322 
  // [d7a0]
  0x100a38ee, 0x21281211, 0x2b00fe08, 0x2100100c,   // tk.mk.be_422 ur.sd.fa_653  tlh.vi.un_430 lt.jw.un_530 
  0x31040ea7, 0x2f182708, 0x0a1704ee, 0x68464e12,   // is.fi.az_532 gd.ga.su_443  ru.sr.mk_422 ay.qu.ig_654 
  0x1500060d, 0x2f0413a0, 0x2a000208, 0x3900180d,   // de.un.un_540 et.fi.su_322  da.mt.un_430 ga.br.un_540 
  0x0c120ea4, 0x465e36ad, 0x4f003914, 0x04000e0d,   // is.hu.sv_433 gn.ts.qu_643  br.bi.un_660 is.fi.un_540 
  // [d7b0]
  0x04000e0e, 0x0800110c, 0x35004a0e, 0x3700fa1b,   // is.fi.un_550 ro.uk.un_530  yo.zu.un_550 nr.st.un_770 
  0x19000b0b, 0x36000308, 0x29167307, 0x0e004d0c,   // es.gl.un_520 nl.gn.un_430  ny.hr.sl_432 aa.is.un_530 
  0x1c000304, 0x1c1760ee, 0x0435150c, 0x365d3508,   // nl.id.un_320 vo.sr.id_422  un.tg.ru_543 zu.ss.gn_443 
  0x0d5c13a7, 0x033f2ca7, 0x2c11fca0, 0x46791a08,   // bh.sa.ne_532 fy.af.nl_532  zzp.ro.fy_322 tl.war.qu_443 
  // [d7c0]
  0x48386407, 0x212f640c, 0x1b003111, 0x02533307,   // lg.tk.tt_432 lg.su.jw_543  az.tr.un_630 nn.ht.da_432 
  0x6b336404, 0x3f330808, 0x150710a7, 0x6300360d,   // lg.nn.ceb_332 no.nn.af_443  be.bg.un_532 gn.sco.un_540 
  0x1b006308, 0x38126407, 0x1c213fa0, 0x190b12a7,   // sco.tr.un_430 lg.hu.tk_432  af.jw.id_322 hu.es.gl_532 
  0x484cfe0c, 0x582a0e0c, 0x07002c0d, 0x2d0d6e0e,   // tlh.wo.tt_543 is.mt.om_543  fy.it.un_540 hmn.cs.sk_555 
  // [d7d0]
  0x1a694ca4, 0x48123804, 0x231036ee, 0x2b073e0c,   // wo.mfe.tl_433 tk.hu.tt_332  ab.be.ky_422 rm.it.vi_543 
  0x64005c1a, 0x0e0208af, 0x6500491a, 0x0700221b,   // sa.lg.un_760 no.da.is_655  to.gv.un_760 oc.it.un_770 
  0x501b4c04, 0x372b1cee, 0x0e005809, 0x68651d07,   // wo.tr.fj_332 id.vi.st_422  om.is.un_440 la.gv.ig_432 
  0x37482313, 0x02003307, 0x2c003004, 0x370163a7,   // ky.tt.ba_665 nn.da.un_420  uz.fy.un_320 sco.en.st_532 
  // [d7e0]
  0x31006e14, 0x3f6efe13, 0x536908a4, 0x6e39fe12,   // hmn.az.un_660 tlh.hmn.af_665  no.mfe.ht_433 tlh.br.hmn_654 
  0x2a00020d, 0x0d382dee, 0x4800790c, 0x3900fe05,   // da.mt.un_540 sk.tk.cs_422  war.tt.un_530 tlh.br.un_330 
  0x6300fc0d, 0x116e67a6, 0x353650ee, 0x17443807,   // zzp.sco.un_540 ak.hmn.ro_521  fj.gn.zu_422 tk.kk.sr_432 
  0x23056ea0, 0x25006304, 0x334302a7, 0x3536600c,   // hmn.fr.ca_322 sco.eu.un_320  da.ie.nn_532 vo.gn.zu_543 
  // [d7f0]
  0x651d0e04, 0x0e0c040c, 0x3300fe04, 0xfe396e0c,   // is.la.gv_332 fi.sv.is_543  tlh.nn.un_320 hmn.br.tlh_543 
  0xfe006e1a, 0x76695314, 0x120c1bad, 0xfe696eec,   // hmn.tlh.un_760 ht.mfe.crs_666  tr.sv.hu_643 hmn.mfe.tlh_644 
  0x332e0c55, 0x38040c0c, 0x04001211, 0x352507a0,   // sv.fo.nn_442 sv.fi.tk_543  hu.fi.un_630 bg.mn.tg_322 
  0x3216290b, 0x0804330c, 0x33002902, 0x3b301208,   // sl.hr.bs_542 nn.fi.no_543  sl.nn.un_220 ur.uz.ks_443 
  
  // [d800]
  0x0d00220c, 0x6e785e13, 0x0c000e0b, 0x35173608,   // oc.cs.un_530 ts.ve.hmn_665  is.sv.un_520 gn.sr.zu_443 
  0x040c1255, 0x120c480d, 0x51005907, 0x0a2536ee,   // hu.sv.fi_442 tt.sv.hu_554  rn.kl.un_420 ab.mn.mk_422 
  0x2500151a, 0x48121ba9, 0x0804170d, 0x213b300c,   // un.mn.un_760 tr.hu.tt_544  sr.ru.uk_554 uz.ks.fa_543 
  0x02004521, 0x3f2502a7, 0x340f73a4, 0x0f353404,   // ln.da.un_860 da.eu.af_532  ny.lv.xh_433 xh.zu.lv_332 
  // [d810]
  0x17153507, 0x06000407, 0x352536ad, 0x38481b09,   // tg.sr.un_420 fi.de.un_420  ab.mn.tg_643 tr.tt.tk_444 
  0x311b38a9, 0x733130ad, 0x1a002104, 0x300715a7,   // tk.tr.az_544 uz.az.ny_643  jw.tl.un_320 un.bg.uz_532 
  0x310638a9, 0x0b00230d, 0x45230b07, 0x071004a4,   // tk.de.az_544 ca.es.un_540  es.ca.ln_432 ru.be.bg_433 
  0x1b4568a7, 0x120b1814, 0x120b23af, 0x00002337,   // ig.ln.tr_532 ga.es.hu_666  ca.es.hu_655 ca.un.un_B00 
  // [d820]
  0x0a3017a0, 0x0c33085a, 0x10150404, 0x0d562d0c,   // sr.uz.mk_322 no.nn.sv_553  ru.be.un_320 sk.mg.cs_543 
  0x562d0d13, 0x1c00131b, 0x5c30fea4, 0x562d0d0d,   // cs.sk.mg_665 bh.mr.un_770  tlh.uz.sa_433 cs.sk.mg_554 
  0x64fe30a7, 0x23001902, 0x6502630c, 0x5c004802,   // uz.tlh.lg_532 gl.ca.un_220  sco.da.gv_543 tt.sa.un_220 
  0x1b6b1dee, 0x3200520c, 0x34182860, 0x6855280c,   // la.ceb.tr_422 ha.bs.un_530  sd.ar.ps_664 sw.rw.ig_543 
  // [d830]
  0x362d0d13, 0x2d0d56af, 0x1008440c, 0x4800250e,   // cs.sk.gn_665 mg.cs.sk_655  kk.uk.be_543 mn.tt.un_550 
  0x5c3058a6, 0x302f5c08, 0x0a002202, 0x11002b13,   // om.uz.sa_521 sa.su.uz_443  oc.pt.un_220 vi.ro.un_650 
  0x34007305, 0x3c003d14, 0x153304ec, 0x2e5202ee,   // ny.xh.un_330 ku.ug.un_660  fi.nn.un_644 da.ha.fo_422 
  0x582504ee, 0x070204a9, 0x150c56ee, 0x515804ec,   // fi.eu.om_422 fi.da.it_544  mg.sv.un_422 fi.om.kl_644 
  // [d840]
  0x04173c13, 0x5a63010b, 0x36001522, 0x53001f07,   // ug.sr.ru_665 en.sco.sm_542  un.ab.un_870 cy.ht.un_420 
  0x27001508, 0x0a0807ee, 0x225564a0, 0x04060c0b,   // un.gd.un_430 bg.uk.mk_422  lg.rw.oc_322 sv.de.fi_542 
  0x15045111, 0x033f04a0, 0x48003809, 0x12302808,   // kl.fi.un_653 fi.af.nl_322  tk.tt.un_440 sd.uz.ur_443 
  0x50550204, 0x58003413, 0x0c000e14, 0x4d122808,   // da.rw.fj_332 xh.om.un_650  is.sv.un_660 sw.hu.aa_443 
  // [d850]
  0x5f003709, 0x28000405, 0x032e0e11, 0x4a003612,   // st.tn.un_440 fi.sw.un_330  is.fo.nl_653 gn.yo.un_640 
  0x17000305, 0x5a1852a0, 0x033f01af, 0x5c000919,   // nl.sr.un_330 ha.ga.sm_322  en.af.nl_655 hi.sa.un_750 
  0x2e271fa7, 0x0848300c, 0x4a495608, 0x58595513,   // cy.gd.fo_532 uz.tt.uk_543  mg.to.yo_443 rw.rn.om_665 
  0x3f001f11, 0x2c020807, 0x4f300708, 0x07111055,   // cy.af.un_630 no.da.fy_432  it.uz.bi_443 be.ro.bg_442 
  // [d860]
  0x13026355, 0x565d5ea7, 0x31481102, 0x2d00fe04,   // sco.da.et_442 ts.ss.mg_532  ro.tt.az_222 tlh.sk.un_320 
  0x3c483808, 0x15000d04, 0x16000604, 0x45002e0e,   // tk.tt.ug_443 cs.un.un_320  de.hr.un_320 fo.ln.un_550 
  0x063e13a0, 0x03000e02, 0x1800fc11, 0x30342104,   // et.rm.de_322 is.nl.un_220  zzp.ga.un_630 fa.ps.uz_332 
  0x48361507, 0x0a3604a0, 0x0b212217, 0x23153808,   // un.ab.tt_432 ru.ab.mk_322  oc.jw.es_753 tk.ky.un_430 
  // [d870]
  0x0a103808, 0x35564aa0, 0x033f610c, 0x35302305,   // tk.be.mk_443 yo.mg.zu_322  za.af.nl_543 ky.uz.tg_333 
  0x3730380c, 0x20002f08, 0x35481505, 0x37481509,   // tk.uz.ba_543 su.sq.un_430  un.tt.tg_333 un.tt.ba_444 
  0x01002409, 0x28005808, 0x5e5c21ad, 0x475827a0,   // yi.iw.un_440 om.sw.un_430  jw.sa.ts_643 gd.om.sn_322 
  0x64000304, 0x0a00360d, 0x3d3021ec, 0x3e000618,   // nl.lg.un_320 ab.mk.un_540  fa.uz.ku_644 de.rm.un_740 
  // [d880]
  0x68734712, 0x0a002513, 0x035c6ba0, 0x1ffc4aa4,   // sn.ny.ig_654 mn.mk.un_650  ceb.sa.nl_322 yo.zzp.cy_433 
  0x120d2d0b, 0x3e6434a0, 0x2cfc5b07, 0x38006804,   // sk.cs.hu_542 xh.lg.rm_322  sg.zzp.fy_432 ig.tk.un_320 
  0x17000819, 0x122d0d07, 0x15081004, 0x02006008,   // uk.sr.un_750 cs.sk.hu_432  be.uk.un_332 vo.da.un_430 
  0x0800fc08, 0x28213408, 0x791f1a0d, 0x313848af,   // zzp.no.un_430 ps.fa.sd_443  tl.cy.war_554 tt.tk.az_655 
  // [d890]
  0x3b0358a0, 0x1e2720ee, 0x291f0d07, 0x791a1e07,   // om.nl.so_322 sq.gd.ms_422  cs.cy.sl_432 ms.tl.war_432 
  0x39122aa0, 0x2a0f1208, 0x60001f21, 0x601a6ba9,   // mt.hu.br_322 hu.lv.mt_443  cy.vo.un_860 ceb.tl.vo_544 
  0x30601f0c, 0x65fe4daf, 0x38fe1b13, 0x44100812,   // cy.vo.uz_543 aa.tlh.gv_655  tr.tlh.tk_665 uk.be.kk_654 
  0x12223b07, 0x38fe1b0b, 0x3500101b, 0x17003c08,   // so.oc.hu_432 tr.tlh.tk_542  be.tg.un_770 ug.sr.un_430 
  // [d8a0]
  0x34006505, 0x31531b0c, 0x31125304, 0x79301a08,   // gv.xh.un_330 tr.ht.az_543  ht.hu.az_332 tl.uz.war_443 
  0x1c095c0e, 0x350e3f0c, 0x4ffe1f07, 0x3b00fe05,   // sa.hi.mr_555 af.is.zu_543  cy.tlh.bi_432 tlh.so.un_330 
  0x38653ba0, 0x28122114, 0x60791e0c, 0x166b790c,   // so.gv.tk_322 fa.ur.sd_666  ms.war.vo_543 war.ceb.hr_543 
  0x0a113508, 0x2d0d29ac, 0x651bfeee, 0x044415ad,   // tg.ro.mk_443 sl.cs.sk_632  tlh.tr.gv_422 un.kk.ru_643 
  // [d8b0]
  0x02374b0c, 0x311bfe11, 0x732d4708, 0x29321614,   // mi.st.da_543 tlh.tr.az_653  sn.sk.ny_443 hr.bs.sl_666 
  0xfe001b14, 0x19600a12, 0x643b6555, 0x34002a08,   // tr.tlh.un_660 pt.vo.gl_654  gv.so.lg_442 mt.xh.un_430 
  0xfe651ba7, 0x40000505, 0x48071dad, 0x1b79fead,   // tr.gv.tlh_532 fr.lb.un_330  la.it.tt_643 tlh.war.tr_643 
  0x1a596b05, 0x482ffe04, 0x69763e12, 0x44231813,   // ceb.rn.tl_333 tlh.su.tt_332  rm.crs.mfe_654 ar.ky.kk_665 
  // [d8c0]
  0x697621af, 0x35250804, 0x042312ac, 0x524c0204,   // jw.crs.mfe_655 uk.mn.tg_332  ur.ky.ru_632 da.wo.ha_332 
  0x0a173702, 0x1b487307, 0x1a2649a4, 0x4b020ca4,   // ba.sr.mk_222 ny.tt.tr_432  to.ia.tl_433 sv.da.mi_433 
  0x4c5102ee, 0x10081508, 0x03023908, 0x5a4b6a0c,   // da.kl.wo_422 un.uk.be_443  br.da.nl_443 haw.mi.sm_543 
  0x4b000409, 0x47005d12, 0x0400670d, 0x6a007513,   // fi.mi.un_440 ss.sn.un_640  ak.fi.un_540 nso.haw.un_650 
  // [d8d0]
  0x34111d07, 0x44004809, 0x0e182ea9, 0x12180e0c,   // la.ro.xh_432 tt.kk.un_440  fo.ga.is_544 is.ga.hu_543 
  0x0f001102, 0x0e2d180c, 0x4844150c, 0x49004b21,   // ro.lv.un_220 ga.sk.is_543  un.kk.tt_543 mi.to.un_860 
  0x375036a0, 0x483c3507, 0x233c44a7, 0x734550ad,   // gn.fj.st_322 tg.ug.tt_432  kk.ug.ky_532 fj.ln.ny_643 
  0x4b00670e, 0xfe4b6a09, 0x04173505, 0x211647a0,   // ak.mi.un_550 haw.mi.tlh_444  tg.sr.ru_333 sn.hr.jw_322 
  // [d8e0]
  0x200d2dee, 0x3d281207, 0x50495eaf, 0x2e121804,   // sk.cs.sq_422 ur.sd.ku_432  ts.to.fj_655 ga.hu.fo_332 
  0x4b291704, 0x5f5337a4, 0x794b2855, 0x20003404,   // sr.sl.mi_332 st.ht.tn_433  sw.mi.war_442 xh.sq.un_320 
  0x375e3311, 0x5e493311, 0x5d2d0d08, 0x1c135ca7,   // nn.ts.st_653 nn.to.ts_653  cs.sk.ss_443 sa.bh.mr_532 
  0x3e00430e, 0x041535a9, 0x7500372b, 0x46206aa0,   // ie.rm.un_550 tg.ru.un_540  st.nso.un_980 haw.sq.qu_322 
  // [d8f0]
  0x686a4a09, 0x18211209, 0x69001c08, 0x153748af,   // yo.haw.ig_444 ur.fa.ar_444  id.mfe.un_430 tt.ba.un_655 
  0x51040ba4, 0x0400452b, 0x200e2e13, 0x32000907,   // es.fi.kl_433 ln.fi.un_980  fo.is.sq_665 pl.bs.un_420 
  0x2c080f04, 0x10004411, 0x0e1310ec, 0x1a00fe07,   // lv.no.fy_332 kk.be.un_630  lt.et.is_644 tlh.tl.un_420 
  0x3f5f3711, 0x37444802, 0x0e124d0c, 0x353c1507,   // st.tn.af_653 tt.kk.ba_222  aa.hu.is_543 un.ug.tg_432 
  // [d900]
  0x09007313, 0x17374813, 0x3430120c, 0x1515360c,   // ny.pl.un_650 tt.ba.sr_665  ur.uz.ps_543 ab.un.un_530 
  0x3f002c14, 0x154825ec, 0x2d0c12a0, 0x02336aa4,   // fy.af.un_660 mn.tt.un_644  hu.sv.sk_322 haw.nn.da_433 
  0x0b3619ec, 0x40004c0d, 0x17001304, 0x151715ee,   // gl.gn.es_644 wo.lb.un_540  et.sr.un_320 un.sr.un_422 
  0x442315a0, 0x034002ee, 0x2f00640c, 0x2300350c,   // un.ky.kk_322 da.lb.nl_422  lg.su.un_530 tg.ky.un_530 
  // [d910]
  0x44150413, 0x346403ee, 0x4c006412, 0x38102511,   // ru.kk.un_650 nl.lg.xh_422  lg.wo.un_640 mn.be.tk_653 
  0x47330202, 0x063f4b04, 0x3e3f4da6, 0x08204bee,   // da.nn.sn_222 mi.af.de_332  aa.af.rm_521 mi.sq.no_422 
  0x65000804, 0x4b5559ad, 0x31006011, 0x0e0c65a0,   // no.gv.un_320 rn.rw.mi_643  vo.az.un_630 gv.sv.is_322 
  0x211834a7, 0x213d28a4, 0x12381b05, 0x311b380b,   // ps.ar.fa_532 sd.ku.fa_433  tr.tk.hu_333 tk.tr.az_542 
  // [d920]
  0x0b1d07a0, 0x320268a4, 0x250424a7, 0x1221180d,   // it.la.es_322 ig.da.bs_433  eo.fi.eu_532 ar.fa.ur_554 
  0x32006809, 0x12000214, 0x2d0d02a4, 0x05002c04,   // ig.bs.un_440 da.hu.un_660  da.cs.sk_433 fy.fr.un_320 
  0x0f284709, 0x40330205, 0x021d6908, 0x082f4002,   // sn.sw.lv_444 da.nn.lb_333  mfe.la.da_443 lb.su.no_222 
  0x28024507, 0x17110a07, 0x40003f18, 0x6420450c,   // ln.da.sw_432 mk.ro.sr_432  af.lb.un_740 ln.sq.lg_543 
  // [d930]
  0x520657af, 0x04224013, 0x64002d04, 0x3e0240ad,   // na.de.ha_655 lb.oc.fi_665  sk.lg.un_320 lb.da.rm_643 
  0x11003805, 0x401506a9, 0x0a361104, 0x026448ec,   // tk.ro.un_330 de.lb.un_540  ro.ab.mk_332 tt.lg.da_644 
  0x3b595508, 0x38001e04, 0x2f000704, 0x21004705,   // rw.rn.so_443 ms.tk.un_320  it.su.un_320 sn.jw.un_330 
  0x5c5b2808, 0x0c005604, 0x25000d07, 0x3e00600d,   // sw.sg.sa_443 mg.sv.un_320  cs.eu.un_420 vo.rm.un_540 
  // [d940]
  0x5259550d, 0x403b06a0, 0x0f470da0, 0x0e27630c,   // rw.rn.ha_554 de.so.lb_322  cs.sn.lv_322 sco.gd.is_543 
  0x47001119, 0xfc002e14, 0x1d004021, 0x036301a4,   // ro.sn.un_750 fo.zzp.un_660  lb.la.un_860 en.sco.nl_433 
  0x3e4005a7, 0x64522804, 0x28341811, 0x5c5369a9,   // fr.lb.rm_532 sw.ha.lg_332  ar.ps.sd_653 mfe.ht.sa_544 
  0x212e1b04, 0x69535209, 0x261b650c, 0x343b65a4,   // tr.fo.jw_332 ha.ht.mfe_444  gv.tr.ia_543 gv.so.xh_433 
  // [d950]
  0x730552a4, 0x4b1b13a0, 0x53651b0c, 0x5c005504,   // ha.fr.ny_433 et.tr.mi_322  tr.gv.ht_543 rw.sa.un_320 
  0x2e653b07, 0x0e311ba0, 0x3b0e65ee, 0x2a001f14,   // so.gv.fo_432 tr.az.is_322  gv.is.so_422 cy.mt.un_660 
  0x3b00650d, 0x2e060e08, 0x1300601a, 0x23043502,   // gv.so.un_540 is.de.fo_443  vo.et.un_760 tg.ru.ky_222 
  0x31381ba9, 0x36651bad, 0x22003b02, 0x08000c0d,   // tr.tk.az_544 tr.gv.gn_643  so.oc.un_220 sv.no.un_540 
  // [d960]
  0x4c1b0e05, 0x33080cec, 0x1d0e1ba4, 0x2e1b0e12,   // is.tr.wo_333 sv.no.nn_644  tr.is.la_433 is.tr.fo_654 
  0x442338a7, 0x5c2d0d04, 0x170a300c, 0x5c091305,   // tk.ky.kk_532 cs.sk.sa_332  uz.mk.sr_543 bh.hi.sa_333 
  0x21303d11, 0x091c0dac, 0x330c01a0, 0x033f0f0c,   // ku.uz.fa_653 ne.mr.hi_632  en.sv.nn_322 lv.af.nl_543 
  0x3100380c, 0x174808a0, 0x380613af, 0x304661ac,   // tk.az.un_530 uk.tt.sr_322  et.de.tk_655 za.qu.uz_632 
  // [d970]
  0x301748a0, 0x441538a0, 0x1d262dad, 0x043f0eec,   // tt.sr.uz_322 tk.kk.un_320  sk.ia.la_643 is.af.fi_644 
  0x0a1036a0, 0x290602ee, 0x17151009, 0x08022e09,   // ab.be.mk_322 da.de.sl_422  be.sr.un_440 fo.da.no_444 
  0x623e09a4, 0x15041713, 0x09001f19, 0x06032ea4,   // pl.rm.kha_433 sr.ru.un_665  cy.pl.un_750 fo.nl.de_433 
  0x48fe6112, 0x39002c02, 0x0d100404, 0x32003908,   // za.tlh.tt_654 fy.br.un_220  fi.lt.cs_332 br.bs.un_430 
  // [d980]
  0x02004209, 0x2d0d5d0c, 0x103748a0, 0x5b005819,   // co.da.un_440 ss.cs.sk_543  tt.ba.be_322 om.sg.un_750 
  0x1e005807, 0x153525af, 0x58522c02, 0x04083cec,   // om.ms.un_420 mn.tg.un_655  fy.ha.om_222 ug.uk.ru_644 
  0x64005807, 0x522a5812, 0x44100404, 0x2c023f04,   // om.lg.un_420 om.mt.ha_654  ru.be.kk_332 af.da.fy_332 
  0x011579a0, 0x11395ca0, 0x654001ad, 0x21283408,   // war.en.un_320 sa.br.ro_322  en.lb.gv_643 ps.sd.fa_443 
  // [d990]
  0x342830ad, 0x5f4c3714, 0x6303010c, 0x4423380b,   // uz.sd.ps_643 st.wo.tn_666  en.nl.sco_543 tk.ky.kk_542 
  0x2a3f58a0, 0x344c4dad, 0xfc3f58ad, 0x4c1e5807,   // om.af.mt_322 aa.wo.xh_643  om.af.zzp_643 om.ms.wo_432 
  0x0a15010c, 0x151d0107, 0x3b095804, 0x35080407,   // en.pt.un_530 en.la.un_432  om.pl.so_332 ru.uk.tg_432 
  0x4c134d0c, 0x24006407, 0x3704150d, 0x356402a7,   // aa.et.wo_543 lg.eo.un_420  un.ru.ba_554 da.lg.zu_532 
  // [d9a0]
  0x07353011, 0x644c4da4, 0x13496a07, 0x171038a7,   // uz.tg.bg_653 aa.wo.lg_433  haw.to.et_432 tk.be.sr_532 
  0x34001c07, 0x0c00120b, 0x6b00790e, 0x183b01a0,   // id.xh.un_420 hu.sv.un_520  war.ceb.un_550 en.so.ga_322 
  0x131560a9, 0x25001505, 0x5c1b36a4, 0x153b65a4,   // vo.et.un_540 un.mn.un_330  gn.tr.sa_433 gv.so.un_433 
  0x316953a4, 0x253048a0, 0x0403650c, 0x1f004d0b,   // ht.mfe.az_433 tt.uz.mn_322  gv.nl.fi_543 aa.cy.un_520 
  // [d9b0]
  0x37351508, 0x04150a5a, 0x216501a0, 0x55005c12,   // un.tg.ba_443 mk.ru.un_530  en.gv.jw_322 sa.rw.un_640 
  0x25370404, 0x13621f0b, 0x465c6460, 0x15615ca4,   // ru.ba.mn_332 cy.kha.et_542  lg.sa.qu_664 sa.za.un_433 
  0x1b535caf, 0x481b590b, 0x330810ec, 0x39527305,   // sa.ht.tr_655 rn.tr.tt_542  lt.no.nn_644 ny.ha.br_333 
  0x65553607, 0x311e3b0c, 0x55005c0d, 0x671a1fa9,   // gn.rw.gv_432 so.ms.az_543  sa.rw.un_540 cy.tl.ak_544 
  // [d9c0]
  0x165326ec, 0x3b6913ad, 0x083536a7, 0x33350c07,   // ia.ht.hr_644 et.mfe.so_643  ab.tg.uk_532 sv.zu.nn_432 
  0x431301a4, 0x10170a12, 0x69765c13, 0x016b020c,   // en.et.ie_433 mk.sr.be_654  sa.crs.mfe_665 da.ceb.en_543 
  0x53695ca7, 0x361b5cad, 0x363715a6, 0x400665ee,   // sa.mfe.ht_532 sa.tr.gn_643  un.ba.ab_521 gv.de.lb_422 
  0x1d190b0c, 0x0c3f02ee, 0x15113508, 0x55006423,   // es.gl.la_543 da.af.sv_422  tg.ro.un_443 lg.rw.un_880 
  // [d9d0]
  0x0c000410, 0x041502ee, 0x334002a4, 0xfe016304,   // fi.sv.un_620 da.fi.un_420  da.lb.nn_433 sco.en.tlh_332 
  0x311b38ec, 0x213d180b, 0xfc005d1a, 0x34004805,   // tk.tr.az_644 ar.ku.fa_542  ss.zzp.un_760 tt.xh.un_330 
  0x37150807, 0x2c003f19, 0x5d33080c, 0x25040a07,   // uk.ba.un_420 af.fy.un_750  no.nn.ss_543 mk.ru.mn_432 
  0x12003c0c, 0x49003608, 0x3044230c, 0x1f007307,   // ug.ur.un_530 gn.to.un_430  ky.kk.uz_543 ny.cy.un_420 
  // [d9e0]
  0x08301108, 0x363e070c, 0x3748350e, 0x461827ee,   // ro.uz.uk_443 it.rm.gn_543  tg.tt.ba_555 gd.ga.qu_422 
  0x51370ca0, 0x13000d13, 0x044f13a4, 0x06650304,   // sv.st.kl_322 ne.bh.un_650  et.bi.fi_433 nl.gv.de_332 
  0x35342509, 0x15fc24a0, 0x3d004411, 0x1a636b08,   // eu.xh.zu_444 eo.zzp.un_322  kk.ku.un_630 ceb.sco.tl_443 
  0x08003607, 0x353c3005, 0x1037040c, 0x5500470d,   // ab.uk.un_420 uz.ug.tg_333  ru.ba.be_543 sn.rw.un_540 
  // [d9f0]
  0x1a15fc07, 0x4739610c, 0x3500590e, 0x40006504,   // zzp.tl.un_420 za.br.sn_543  rn.zu.un_550 gv.lb.un_320 
  0x15005c08, 0x3f005f07, 0x0e001302, 0x461d5c0c,   // sa.un.un_430 tn.af.un_420  et.is.un_220 sa.la.qu_543 
  0x2c4003ee, 0x15170412, 0x30212312, 0x40006407,   // nl.lb.fy_422 ru.sr.un_654  ky.fa.uz_654 lg.lb.un_420 
  0x403f0309, 0x0f3f0308, 0x401f3f04, 0x07082507,   // nl.af.lb_444 nl.af.lv_443  af.cy.lb_332 mn.uk.bg_432 
  // [da00]
  0xfc314ea7, 0x64004205, 0x432401a0, 0x5c091caf,   // ay.az.zzp_532 co.lg.un_330  en.eo.ie_322 mr.hi.sa_655 
  0xfe2a46ec, 0x30351512, 0x04361712, 0x343d2804,   // qu.mt.tlh_644 un.tg.uz_654  sr.ab.ru_654 sd.ku.ps_332 
  0x4200180e, 0x4f00011a, 0x03061808, 0x1535300d,   // ga.co.un_550 en.bi.un_760  ga.de.nl_443 uz.tg.un_554 
  0x48151512, 0x2e001807, 0x464207a9, 0x250710ad,   // un.tt.un_640 ga.fo.un_420  it.co.qu_544 be.bg.mn_643 
  // [da10]
  0x466953ad, 0x1f003919, 0x36002509, 0x5c430f0c,   // ht.mfe.qu_643 br.cy.un_750  mn.ab.un_440 lv.ie.sa_543 
  0x46006304, 0x08392a0b, 0x4c002505, 0x1f002b0d,   // sco.qu.un_320 mt.br.no_542  eu.wo.un_330 vi.cy.un_540 
  0x39006312, 0x30002f04, 0x135e0404, 0x0a073602,   // sco.br.un_640 su.uz.un_320  fi.ts.et_332 ab.bg.mk_222 
  0x13004002, 0x10353607, 0x05000105, 0x1f390209,   // lb.et.un_220 ab.tg.be_432  en.fr.un_330 da.br.cy_444 
  // [da20]
  0x382310af, 0x1d001005, 0x21001821, 0x02344708,   // be.ky.tk_655 lt.la.un_330  ar.fa.un_860 sn.xh.da_443 
  0x230a17a9, 0x1d00430d, 0x64353411, 0x34674712,   // sr.mk.ky_544 ie.la.un_540  xh.zu.lg_653 sn.ak.xh_654 
  0x10003c09, 0x47345108, 0x2504380c, 0x28003b11,   // ug.be.un_440 kl.xh.sn_443  tk.ru.mn_543 ks.sd.un_630 
  0x1515040c, 0x37480402, 0x024734af, 0x0c134cee,   // ru.un.un_530 ru.tt.ba_222  xh.sn.da_655 wo.et.sv_422 
  // [da30]
  0x55003504, 0x27002b04, 0x13000e07, 0x13650405,   // zu.rw.un_320 vi.gd.un_320  is.et.un_420 fi.gv.et_333 
  0x47207307, 0x0c002b02, 0x34254bee, 0x734760ad,   // ny.sq.sn_432 vi.sv.un_220  mi.eu.xh_422 vo.sn.ny_643 
  0x2a100f12, 0x5d356bec, 0xfe031008, 0x170926ee,   // lv.lt.mt_654 ceb.zu.ss_644  lt.nl.tlh_443 ia.pl.sr_422 
  0x601d0107, 0x052224ee, 0x60001708, 0x316558a0,   // en.la.vo_432 eo.oc.fr_422  sr.vo.un_430 om.gv.az_322 
  // [da40]
  0x00002737, 0x116b0f07, 0x0e001f19, 0x20005504,   // gd.un.un_B00 lv.ceb.ro_432  cy.is.un_750 rw.sq.un_320 
  0xfc001b02, 0x170a11ad, 0x01003b07, 0x59000213,   // tr.zzp.un_220 ro.mk.sr_643  so.en.un_420 da.rn.un_650 
  0x17070804, 0x53007304, 0x655c3b09, 0x11241007,   // uk.bg.sr_332 ny.ht.un_320  so.sa.gv_444 lt.eo.ro_432 
  0x653b4dac, 0x3c3035a4, 0x4200490e, 0x313b3004,   // aa.so.gv_632 tg.uz.ug_433  to.co.un_550 uz.so.az_332 
  // [da50]
  0x073604a0, 0x1265020b, 0x65005508, 0x46653b11,   // ru.ab.bg_322 da.gv.hu_542  rw.gv.un_430 so.gv.qu_653 
  0x0b00260c, 0x1d0201a0, 0x4700391a, 0x1812300b,   // ia.es.un_530 en.da.la_322  br.sn.un_760 uz.ur.ar_542 
  0x5d002104, 0x343c3da9, 0x2317070e, 0x4000fc12,   // jw.ss.un_320 ku.ug.ps_544  bg.sr.ky_555 zzp.lb.un_640 
  0x06000b02, 0x122e36a7, 0x39005e0d, 0x36002d0d,   // es.de.un_220 gn.fo.hu_532  ts.br.un_540 sk.gn.un_540 
  // [da60]
  0x192d0b07, 0x2b000404, 0x0d1c1311, 0x15440404,   // es.sk.gl_432 fi.vi.un_320  bh.mr.ne_653 ru.kk.un_332 
  0x3f031c04, 0x11000502, 0x0a1117a4, 0x18122108,   // id.nl.af_332 fr.ro.un_220  sr.ro.mk_433 fa.ur.ar_443 
  0x233010ad, 0x33170802, 0x17102d02, 0x0d5c13a6,   // be.uz.ky_643 no.sr.nn_222  sk.lt.sr_222 bh.sa.ne_521 
  0x2508040d, 0x30213b05, 0x1523300c, 0x03001904,   // ru.uk.mn_554 ks.fa.uz_333  uz.ky.un_543 gl.nl.un_320 
  // [da70]
  0x12000f13, 0x123e46ad, 0x04753707, 0x5d100fee,   // lv.hu.un_650 qu.rm.hu_643  st.nso.fi_432 lv.lt.ss_422 
  0x4a2d0d08, 0x282112ac, 0x791a6b08, 0x44041513,   // cs.sk.yo_443 ur.fa.sd_632  ceb.tl.war_443 un.ru.kk_665 
  0x2b002202, 0x38004607, 0x11011da0, 0x0f007513,   // oc.vi.un_220 qu.tk.un_420  la.en.ro_322 nso.lv.un_650 
  0x15003619, 0x3534fca0, 0x12375f12, 0x18003202,   // ab.un.un_750 zzp.xh.zu_322  tn.st.hu_654 bs.ga.un_220 
  // [da80]
  0xfc514ea4, 0x0e0b12a7, 0x04381207, 0x0b45120c,   // ay.kl.zzp_433 hu.es.is_532  hu.tk.fi_432 hu.ln.es_543 
  0x530742ad, 0x30150455, 0x300a17a0, 0x48003902,   // co.it.ht_643 ru.uz.un_420  sr.mk.uz_322 br.tt.un_220 
  0x16170fa9, 0x0f002921, 0x120b23a4, 0x5307420b,   // lv.sr.hr_544 sl.lv.un_860  ca.es.hu_433 co.it.ht_542 
  0x34003c11, 0x1a300fa4, 0x406902a4, 0x0400380e,   // ug.ps.un_630 lv.uz.tl_433  da.mfe.lb_433 tk.fi.un_550 
  // [da90]
  0x1e1c1214, 0x2d00092a, 0x37483c60, 0x2afe3bec,   // hu.id.ms_666 pl.sk.un_970  ug.tt.ba_664 so.tlh.mt_644 
  0x65620604, 0x010c1ba0, 0x35383007, 0x3844230e,   // de.kha.gv_332 tr.sv.en_322  uz.tk.tg_432 ky.kk.tk_555 
  0x21002307, 0x2d091fec, 0x4812380c, 0x397669a4,   // ky.fa.un_420 cy.pl.sk_644  tk.hu.tt_543 mfe.crs.br_433 
  0x0800041a, 0x01270c0c, 0x12001112, 0x483725ee,   // ru.uk.un_760 sv.gd.en_543  ro.hu.un_640 mn.ba.tt_422 
  // [daa0]
  0x2d0f29a7, 0x3b2a48a7, 0x2f5c300c, 0x29000d14,   // sl.lv.sk_532 tt.mt.so_532  uz.sa.su_543 cs.sl.un_660 
  0x3b001308, 0x2e0e33ec, 0x372330a0, 0x48003023,   // et.so.un_430 nn.is.fo_644  uz.ky.ba_322 uz.tt.un_880 
  0x632d0d0d, 0x292f5c0c, 0x4600fe08, 0x2f003005,   // cs.sk.sco_554 sa.su.sl_543  tlh.qu.un_430 uz.su.un_330 
  0x2a652ca9, 0x5c2f1c08, 0x2d091fad, 0xfe464daf,   // fy.gv.mt_544 id.su.sa_443  cy.pl.sk_643 aa.qu.tlh_655 
  // [dab0]
  0x2a00300c, 0x79006518, 0xfe302a04, 0x5cfe2408,   // uz.mt.un_530 gv.war.un_740  mt.uz.tlh_332 eo.tlh.sa_443 
  0x322d2905, 0x043036ee, 0x1300570d, 0x440804a0,   // sl.sk.bs_333 ab.uz.ru_422  na.et.un_540 ru.uk.kk_322 
  0x191223a7, 0x100f7504, 0x04004309, 0x22001211,   // ca.hu.gl_532 nso.lv.lt_332  ie.fi.un_440 hu.oc.un_630 
  0x3c002109, 0x35482512, 0x76071da4, 0x28123bac,   // fa.ug.un_440 mn.tt.tg_654  la.it.crs_433 ks.ur.sd_632 
  // [dac0]
  0x394b6a07, 0x0c0833ee, 0x13005607, 0x29000219,   // haw.mi.br_432 nn.no.sv_422  mg.et.un_420 da.sl.un_750 
  0x2b5f370c, 0x4749590c, 0x3b001802, 0x10234455,   // st.tn.vi_543 rn.to.sn_543  ga.so.un_220 kk.ky.be_442 
  0x562f0507, 0xfc000d19, 0x4700fc0d, 0x4823440c,   // fr.su.mg_432 cs.zzp.un_750  zzp.sn.un_540 kk.ky.tt_543 
  0x39005608, 0x21005602, 0x564b730b, 0x56004704,   // mg.br.un_430 mg.jw.un_220  ny.mi.mg_542 sn.mg.un_320 
  // [dad0]
  0x4c4b28a4, 0x0d001c21, 0x49564ba7, 0x65005202,   // sw.mi.wo_433 mr.ne.un_860  mi.mg.to_532 ha.gv.un_220 
  0x463b1507, 0x0e182712, 0x4815380c, 0x102d0d09,   // un.so.qu_432 gd.ga.is_654  tk.tt.un_530 cs.sk.lt_444 
  0x0b004902, 0x264301a4, 0x0c5c4704, 0x37043607,   // to.es.un_220 en.ie.ia_433  sn.sa.sv_332 gn.fi.st_432 
  0x58103b08, 0x1c090da6, 0x162d0fa7, 0x100f1602,   // so.lt.om_443 ne.hi.mr_521  lv.sk.hr_532 hr.lv.lt_222 
  // [dae0]
  0x0f1675a6, 0x1f3b0408, 0x011f58a0, 0x650210ad,   // nso.hr.lv_521 fi.so.cy_443  om.cy.en_322 lt.da.gv_643 
  0x28005713, 0x100d400c, 0x2d170f04, 0x12006e04,   // na.sw.un_650 lb.cs.lt_543  lv.sr.sk_332 hmn.hu.un_320 
  0x3e000413, 0x5c6304ee, 0x5c041312, 0x081233a9,   // fi.rm.un_650 fi.sco.sa_422  et.fi.sa_654 nn.hu.no_544 
  0x2b1d5e0c, 0x07080a08, 0x33025cee, 0x170a080c,   // ts.la.vi_543 mk.uk.bg_443  sa.da.nn_422 uk.mk.sr_543 
  // [daf0]
  0x22001d08, 0x51041512, 0x37345d05, 0x22002e04,   // la.oc.un_430 un.fi.kl_654  ss.xh.st_333 fo.oc.un_320 
  0x30362305, 0x0d5c1ca9, 0x132e5c0c, 0x041324a4,   // ky.ab.uz_333 mr.sa.ne_544  sa.fo.et_543 eo.et.fi_433 
  0x13160da4, 0x356a1a0c, 0x48132008, 0x3c4835a9,   // cs.hr.et_433 tl.haw.zu_543  sq.et.tt_443 tg.tt.ug_544 
  0x79546bad, 0x32160fed, 0x1a6b4b08, 0x521336a9,   // ceb.ik.war_643 lv.hr.bs_622  mi.ceb.tl_443 gn.et.ha_544 
  // [db00]
  0x2f005504, 0x3b281208, 0x6a000f0d, 0x233035ee,   // rw.su.un_320 ur.sd.ks_443  lv.haw.un_540 tg.uz.ky_422 
  0x4823440b, 0x46050b02, 0x44000409, 0x470b55ac,   // kk.ky.tt_542 es.fr.qu_222  ru.kk.un_440 rw.es.sn_632 
  0x32292da0, 0x25005e08, 0x026a28af, 0x6b1e1c0d,   // sk.sl.bs_322 ts.eu.un_430  sw.haw.da_655 id.ms.ceb_554 
  0x0b002305, 0x3f0360ee, 0x552d0d13, 0x4b6a6ba4,   // ca.es.un_330 vo.nl.af_422  cs.sk.rw_665 ceb.haw.mi_433 
  // [db10]
  0x42000702, 0x48003f12, 0x36003c1a, 0x483025a0,   // it.co.un_220 af.tt.un_640  ug.ab.un_760 mn.uz.tt_322 
  0x354425a0, 0x15483607, 0x353048a6, 0x104704a7,   // mn.kk.tg_322 ab.tt.un_432  tt.uz.tg_521 fi.sn.lt_532 
  0x08043ca4, 0x5d521a09, 0x47341005, 0x2b182802,   // ug.ru.uk_433 tl.ha.ss_444  lt.xh.sn_333 sw.ga.vi_222 
  0x4a001008, 0x28024a13, 0x5100470c, 0x0d346805,   // lt.yo.un_430 yo.da.sw_665  sn.kl.un_530 ig.xh.cs_333 
  // [db20]
  0x171504a4, 0x422853a0, 0x1dfc010c, 0x443548a0,   // ru.sr.un_430 ht.sw.co_322  en.zzp.la_543 tt.tg.kk_322 
  0x4830fe05, 0x38003502, 0x2c0310a7, 0x2d0d4aee,   // tlh.uz.tt_333 zu.tk.un_220  lt.nl.fy_532 yo.cs.sk_422 
  0x5837fe11, 0x5e00781a, 0x38356807, 0x3bfe0eec,   // tlh.st.om_653 ve.ts.un_760  ig.zu.tk_432 is.tlh.so_644 
  0x6b47fea9, 0x4a005205, 0x38001513, 0x0a34350c,   // tlh.sn.ceb_544 ha.yo.un_330  un.tk.un_650 zu.xh.pt_543 
  // [db30]
  0x5d00fe0d, 0x3b5e34ad, 0x3058640c, 0x3bfe5c0c,   // tlh.ss.un_540 xh.ts.so_643  lg.om.uz_543 sa.tlh.so_543 
  0x01631904, 0x18234404, 0x04105f55, 0x4b585904,   // gl.sco.en_332 kk.ky.ar_332  tn.lt.fi_442 rn.om.mi_332 
  0x537601a4, 0x20005002, 0x475c3504, 0x550f2902,   // en.crs.ht_433 fj.sq.un_220  zu.sa.sn_332 sl.lv.rw_222 
  0x47fe7304, 0x47003402, 0x1d28735a, 0x28183d08,   // ny.tlh.sn_332 xh.sn.un_220  ny.sw.la_553 ku.ar.sd_443 
  // [db40]
  0x233e4255, 0x3051460c, 0x22054208, 0x284773ad,   // co.rm.ca_442 qu.kl.uz_543  co.fr.oc_443 ny.sn.sw_643 
  0x35043c07, 0x4a423e5a, 0x423e2304, 0x563e4aa4,   // ug.ru.tg_432 rm.co.yo_553  ca.rm.co_332 yo.rm.mg_433 
  0x1c2f730c, 0x355c34a9, 0x040e6507, 0x233e4211,   // ny.su.id_543 xh.sa.zu_544  gv.is.fi_432 co.rm.ca_653 
  0x65005d08, 0x4a000708, 0x0700220c, 0x53391804,   // ss.gv.un_430 it.yo.un_430  oc.it.un_530 ga.br.ht_332 
  // [db50]
  0x133003ee, 0x4a4223a0, 0x23190ba7, 0x23004219,   // nl.uz.et_422 ca.co.yo_322  es.gl.ca_532 co.ca.un_750 
  0x53000407, 0x19470b0c, 0x3900361a, 0x0d0f1007,   // fi.ht.un_420 es.sn.gl_543  gn.br.un_760 lt.lv.cs_432 
  0x36190bad, 0x56005307, 0x22004207, 0x3c003408,   // es.gl.gn_643 ht.mg.un_420  co.oc.un_420 ps.ug.un_430 
  0x37233011, 0x1e001a02, 0x190b46a9, 0x38005c07,   // uz.ky.ba_653 tl.ms.un_220  qu.es.gl_544 sa.tk.un_420 
  // [db60]
  0x3e00421a, 0x2c002e0d, 0x2a42070e, 0x074223a9,   // co.rm.un_760 fo.fy.un_540  it.co.mt_555 ca.co.it_544 
  0x42000707, 0x0a001d0b, 0x423e4a04, 0x072242ec,   // it.co.un_420 la.pt.un_520  yo.rm.co_332 co.oc.it_644 
  0x4a234204, 0x0a1736a6, 0x3b000a12, 0x421d1904,   // co.ca.yo_332 ab.sr.mk_521  pt.so.un_640 gl.la.co_332 
  0x04131014, 0x13000419, 0x290413a0, 0x332e0e08,   // lt.et.fi_666 fi.et.un_750  et.fi.sl_322 is.fo.nn_443 
  // [db70]
  0x5e004c04, 0x1c0d5c0d, 0x083f36a9, 0x3304080b,   // wo.ts.un_320 sa.ne.mr_554  gn.af.no_544 no.fi.nn_542 
  0x0a00071b, 0x3600630d, 0x353c3014, 0x27003e07,   // bg.mk.un_770 sco.gn.un_540  uz.ug.tg_666 rm.gd.un_420 
  0x36470805, 0x37001f04, 0x2c60030b, 0x303c100c,   // no.sn.gn_333 cy.st.un_320  nl.vo.fy_542 be.ug.uz_543 
  0x3b1d4c07, 0x03796007, 0x1c485804, 0x50101f13,   // wo.la.so_432 vo.war.nl_432  om.tt.id_332 cy.lt.fj_665 
  // [db80]
  0x04481504, 0x08033f02, 0x0f005711, 0x60001f0e,   // un.tt.ru_332 af.nl.no_222  na.lv.un_630 cy.vo.un_550 
  0x28554504, 0x15113512, 0x52074dee, 0x06672107,   // ln.rw.sw_332 tg.ro.un_654  aa.it.ha_422 jw.ak.de_432 
  0x1c633708, 0x64686709, 0xfc3626a0, 0x46005304,   // st.sco.id_443 ak.ig.lg_444  ia.gn.zzp_322 ht.qu.un_320 
  0x0d005f04, 0x645369ac, 0x3f036007, 0x5d351f55,   // tn.cs.un_320 mfe.ht.lg_632  vo.nl.af_432 cy.zu.ss_442 
  // [db90]
  0x3f2c0308, 0x321775a4, 0x2a005808, 0x79031aa4,   // nl.fy.af_443 nso.sr.bs_433  om.mt.un_430 tl.nl.war_433 
  0x1500fc12, 0x2d121aa0, 0x34463508, 0x355e5cee,   // zzp.un.un_640 tl.hu.sk_322  zu.qu.xh_443 sa.ts.zu_422 
  0x2e001308, 0x3048250d, 0x37381112, 0x0e064007,   // et.fo.un_430 mn.tt.uz_554  ro.tk.ba_654 lb.de.is_432 
  0x290c5307, 0x2c002e0c, 0x380712ee, 0x34271802,   // ht.sv.sl_432 fo.fy.un_530  hu.it.tk_422 ga.gd.xh_222 
  // [dba0]
  0x03002407, 0x04465f0c, 0x08003702, 0x12004612,   // eo.nl.un_420 tn.qu.fi_543  ba.uk.un_220 qu.hu.un_640 
  0x47005004, 0x1a4f5c07, 0x6e00fe21, 0x13106e07,   // fj.sn.un_320 sa.bi.tl_432  tlh.hmn.un_860 hmn.lt.et_432 
  0x4c214512, 0x2d0d10ee, 0x130412ee, 0x1d016e04,   // ln.jw.wo_654 lt.cs.sk_422  hu.fi.et_422 hmn.en.la_332 
  0x27185c5a, 0x29004d04, 0x30182707, 0x25005220,   // sa.ga.gd_553 aa.sl.un_320  gd.ga.uz_432 ha.eu.un_850 
  // [dbb0]
  0x43050107, 0x3e69fead, 0x251004a4, 0x076efea9,   // en.fr.ie_432 tlh.mfe.rm_643  ru.be.mn_433 tlh.hmn.it_544 
  0x21001219, 0x04653ba9, 0x2f2137ee, 0x30006e0c,   // ur.fa.un_750 so.gv.fi_544  st.jw.su_422 hmn.uz.un_530 
  0x18041504, 0x534a3505, 0x0164fcee, 0x766efea9,   // un.fi.ga_332 zu.yo.ht_333  zzp.lg.en_422 tlh.hmn.crs_544 
  0x10004602, 0x696efe60, 0x6400670d, 0x2b006e0e,   // qu.lt.un_220 tlh.hmn.mfe_664  ak.lg.un_540 hmn.vi.un_550 
  // [dbc0]
  0x030c650c, 0x162d0d0d, 0x3f036eee, 0x3d123404,   // gv.sv.nl_543 cs.sk.hr_554  hmn.nl.af_422 ps.ur.ku_332 
  0x16001702, 0x01186502, 0x2b1504a0, 0x676579a4,   // sr.hr.un_220 gv.ga.en_222  fi.vi.un_320 war.gv.ak_433 
  0x3428230c, 0x3b530404, 0x111036af, 0x07003509,   // ky.sd.ps_543 fi.ht.so_332  ab.be.ro_655 tg.bg.un_440 
  0x2d190b5a, 0x102d0d05, 0x190b2da0, 0x08302307,   // es.gl.sk_553 cs.sk.lt_333  sk.es.gl_322 ky.uz.uk_432 
  // [dbd0]
  0x10352307, 0x36190bec, 0x16002704, 0x3c00110e,   // ky.tg.be_432 es.gl.gn_644  gd.hr.un_320 ro.ug.un_550 
  0x10000820, 0x55531505, 0x433129ec, 0x372523a7,   // uk.be.un_850 un.ht.rw_333  sl.az.ie_644 ky.mn.ba_532 
  0x18190b60, 0x2c001102, 0x18002e16, 0x0920390c,   // es.gl.ga_664 ro.fy.un_220  fo.ga.un_720 br.sq.pl_543 
  0x24682508, 0x44234812, 0x125d690d, 0x030640a4,   // eu.ig.eo_443 tt.ky.kk_654  mfe.ss.hu_554 lb.de.nl_433 
  // [dbe0]
  0x111025a0, 0x20402513, 0x08001019, 0x47006405,   // eu.lt.ro_322 eu.lb.sq_665  be.uk.un_750 lg.sn.un_330 
  0x36150a08, 0x023735a4, 0x4700200d, 0x6847350d,   // mk.ab.un_430 zu.st.da_433  sq.sn.un_540 zu.sn.ig_554 
  0x22003e12, 0x07534205, 0x643902a7, 0x2900101a,   // rm.oc.un_640 co.ht.it_333  da.br.lg_532 lt.sl.un_760 
  0x341230a0, 0x3000120e, 0x32102907, 0x321610a4,   // uz.ur.ps_322 ur.uz.un_550  sl.lt.bs_432 lt.hr.bs_433 
  // [dbf0]
  0x0730380c, 0x281853ee, 0x29001019, 0x3500370e,   // tk.uz.bg_543 ht.ga.sw_422  lt.sl.un_750 ba.tg.un_550 
  0x44303caf, 0x0723420d, 0x31004829, 0x23153cec,   // ug.uz.kk_655 co.ca.it_554  tt.az.un_960 ug.ky.un_640 
  0x10007512, 0x04fc10a0, 0x1004170d, 0xfc514bee,   // nso.lt.un_640 lt.zzp.fi_322  sr.ru.be_554 mi.kl.zzp_422 
  0x39496aa7, 0x15650107, 0x285a1a07, 0x01002434,   // haw.to.br_532 en.gv.un_432  tl.sm.sw_432 yi.iw.un_A80 
  
  // [dc00]
  0x6a151d55, 0x03061ca0, 0x2d171602, 0x2f101302,   // la.haw.un_420 id.de.nl_322  hr.sr.sk_222 et.lt.su_222 
  0x16007517, 0x4246360d, 0x28121804, 0x2000302b,   // nso.hr.un_730 gn.qu.co_554  ar.ur.sd_332 uz.sq.un_980 
  0x02041fec, 0x234421ee, 0x17161002, 0x255a36a4,   // cy.fi.da_644 fa.kk.ky_422  lt.hr.sr_222 gn.sm.eu_433 
  0x133f35a0, 0x460a4fa4, 0x3730350c, 0x1242390c,   // zu.af.et_322 bi.pt.qu_433  tg.uz.ba_543 br.co.hu_543 
  // [dc10]
  0x213c3405, 0x172d0d55, 0x5f5647ee, 0x353723ad,   // ps.ug.fa_333 cs.sk.sr_442  sn.mg.tn_422 ky.ba.tg_643 
  0x39001219, 0x3f651f08, 0x220f2aee, 0x10004605,   // hu.br.un_750 cy.gv.af_443  mt.lv.oc_422 qu.lt.un_330 
  0x2500040d, 0x04002805, 0x164729a0, 0x253704ec,   // fi.eu.un_540 sw.fi.un_330  sl.sn.hr_322 fi.st.eu_644 
  0x25280408, 0x5c00180c, 0x51000423, 0x2818fe0c,   // fi.sw.eu_443 ga.sa.un_530  fi.kl.un_880 tlh.ga.sw_543 
  // [dc20]
  0x67005a19, 0xfe005822, 0x20002809, 0x792e0e05,   // sm.ak.un_750 om.tlh.un_870  sw.sq.un_440 is.fo.war_333 
  0x28002705, 0x12130409, 0x3e391211, 0x30006208,   // gd.sw.un_330 fi.et.hu_444  hu.br.rm_653 kha.uz.un_430 
  0xfe465da9, 0x20006521, 0x3912030c, 0x2800060c,   // ss.qu.tlh_544 gv.sq.un_860  nl.hu.br_543 de.sw.un_530 
  0x32174602, 0x17153612, 0x56002507, 0x20006b04,   // qu.sr.bs_222 ab.sr.un_640  eu.mg.un_420 ceb.sq.un_320 
  // [dc30]
  0x40002709, 0x04134dee, 0x1d5c0205, 0x25000412,   // gd.lb.un_440 aa.et.fi_422  da.sa.la_333 fi.eu.un_640 
  0x25000414, 0x1e1b69ad, 0x20383011, 0x1a001212,   // fi.eu.un_660 mfe.tr.ms_643  uz.tk.sq_653 hu.tl.un_640 
  0x38304004, 0x56475ea4, 0x04000d04, 0xfe40730c,   // lb.uz.tk_332 ts.sn.mg_433  cs.fi.un_320 ny.lb.tlh_543 
  0x3052450c, 0x02002d18, 0x1a210304, 0x170a11af,   // ln.ha.uz_543 sk.da.un_740  nl.jw.tl_332 ro.mk.sr_655 
  // [dc40]
  0x20005008, 0x46002802, 0x1f18fe0c, 0x5f49690e,   // fj.sq.un_430 sw.qu.un_220  tlh.ga.cy_543 mfe.to.tn_555 
  0x06fe3eec, 0x124a45a9, 0x5a5d76af, 0x65002019,   // rm.tlh.de_644 ln.yo.hu_544  crs.ss.sm_655 sq.gv.un_750 
  0x4afc3ba4, 0x0f1f5655, 0x3e000204, 0x1c502fa0,   // so.zzp.yo_433 mg.cy.lv_442  da.rm.un_320 su.fj.id_322 
  0x182322a4, 0x19001f19, 0x113067ec, 0x19240207,   // oc.ca.ga_433 cy.gl.un_750  ak.uz.ro_644 da.eo.gl_432 
  // [dc50]
  0x560a5304, 0x0c005307, 0x5a001f13, 0x1a0e210c,   // ht.pt.mg_332 ht.sv.un_420  cy.sm.un_650 jw.is.tl_543 
  0x12232212, 0x215d02a7, 0xfc731c04, 0x2f1e1aa4,   // oc.ca.hu_654 da.ss.jw_532  id.ny.zzp_332 tl.ms.su_433 
  0x222312ec, 0x560e30a0, 0x18460207, 0x3e0a190b,   // hu.ca.oc_644 uz.is.mg_322  da.qu.ga_432 gl.pt.rm_542 
  0x0f1173ee, 0x4240760c, 0x0000161c, 0x647367ad,   // ny.ro.lv_422 crs.lb.co_543  hr.un.un_800 ak.ny.lg_643 
  // [dc60]
  0x45315aec, 0x230b1207, 0x073b1d07, 0x2f1902a0,   // sm.az.ln_644 hu.es.ca_432  la.so.it_432 da.gl.su_322 
  0x37002314, 0x23000910, 0x40003404, 0x12003904,   // ky.ba.un_660 pl.ca.un_620  xh.lb.un_320 br.hu.un_320 
  0x03556307, 0x4e00631a, 0x2715010c, 0x1b2c0607,   // sco.rw.nl_432 sco.ay.un_760  en.gd.un_530 de.fy.tr_432 
  0x29321fa0, 0x1d15600c, 0x03634012, 0x28213d07,   // cy.bs.sl_322 vo.la.un_530  lb.sco.nl_654 ku.fa.sd_432 
  // [dc70]
  0x1c382102, 0x1e005204, 0x23443810, 0x3d2812a0,   // jw.tk.id_222 ha.ms.un_320  tk.kk.ky_642 ur.sd.ku_322 
  0x0c083311, 0x5c001c11, 0x1b100fa0, 0x02100609,   // nn.no.sv_653 mr.sa.un_630  lv.lt.tr_322 de.lt.da_444 
  0x0e331f0c, 0x28002909, 0x39652755, 0x2a006b19,   // cy.nn.is_543 sl.sw.un_440  gd.gv.br_442 ceb.mt.un_750 
  0x33080e0c, 0x1c257608, 0x3d00341b, 0x302813a4,   // is.no.nn_543 crs.eu.id_443  ps.ku.un_770 et.sw.uz_433 
  // [dc80]
  0x08007608, 0x201b5c55, 0x0b0105a7, 0x09004607,   // crs.no.un_430 sa.tr.sq_442  fr.en.es_532 qu.pl.un_420 
  0x2c0e0307, 0x5a004204, 0x0e1b2ea4, 0x386b1aad,   // nl.is.fy_432 co.sm.un_320  fo.tr.is_433 tl.ceb.tk_643 
  0xfc1d4604, 0x12003413, 0x2d002607, 0x0b3925ee,   // qu.la.zzp_332 ps.ur.un_650  ia.sk.un_420 eu.br.es_422 
  0x0a002f07, 0x0c100f07, 0x12002519, 0x4e0e2ea4,   // su.pt.un_420 lv.lt.sv_432  eu.hu.un_750 fo.is.ay_433 
  // [dc90]
  0x0c002a07, 0x31304e04, 0x2e5c33a4, 0x51250e04,   // mt.sv.un_420 ay.uz.az_332  nn.sa.fo_433 is.eu.kl_332 
  0x043725a6, 0x2a00fe09, 0x3d1221a7, 0x043844ad,   // mn.ba.ru_521 tlh.mt.un_440  fa.ur.ku_532 kk.tk.ru_643 
  0x04443055, 0x2d003612, 0x4e2e0e12, 0x3c4418a7,   // uz.kk.ru_442 gn.sk.un_640  is.fo.ay_654 ar.kk.ug_532 
  0x040823ee, 0x213b1207, 0x150a1708, 0x0600400b,   // ky.uk.ru_422 ur.ks.fa_432  sr.mk.un_443 lb.de.un_520 
  // [dca0]
  0x02002402, 0x22006008, 0x153525a7, 0x06005708,   // eo.da.un_220 vo.oc.un_430  mn.tg.un_532 na.de.un_430 
  0x04084407, 0x03000e04, 0x38000604, 0x18122d60,   // kk.uk.ru_432 is.nl.un_320  de.tk.un_320 sk.hu.ga_664 
  0x02000e0e, 0x03493fee, 0x2800370d, 0x06000d07,   // is.da.un_550 af.to.nl_422  st.sw.un_540 cs.de.un_420 
  0x3b270310, 0x30442312, 0x2d000608, 0x11275ea0,   // nl.gd.so_642 ky.kk.uz_654  de.sk.un_430 ts.gd.ro_322 
  // [dcb0]
  0x03003813, 0x34003b0d, 0x123d3008, 0x5d5c73a4,   // tk.nl.un_650 ks.ps.un_540  uz.ku.ur_443 ny.sa.ss_433 
  0x01002113, 0x12183405, 0x21005c13, 0x65004304,   // fa.iw.un_650 ps.ar.ur_333  sa.jw.un_650 ie.gv.un_320 
  0x10003007, 0x213d2855, 0x345c35a6, 0x4e4636ec,   // uz.be.un_420 sd.ku.fa_442  zu.sa.xh_521 gn.qu.ay_644 
  0x1f6b38ee, 0x0b1123ee, 0x1c135c09, 0x754e5f08,   // tk.ceb.cy_422 ca.ro.es_422  sa.bh.mr_444 tn.ay.nso_443 
  // [dcc0]
  0x08361008, 0x443748af, 0x40200107, 0x281d6205,   // be.ab.uk_443 tt.ba.kk_655  en.sq.lb_432 kha.la.sw_333 
  0x07170409, 0x4a005305, 0x10004404, 0x321b30a4,   // ru.sr.bg_444 ht.yo.un_330  kk.be.un_320 uz.tr.bs_433 
  0x20006407, 0x482d1ea7, 0x1e3b1fa0, 0x2304440c,   // lg.sq.un_420 ms.sk.tt_532  cy.so.ms_322 kk.ru.ky_543 
  0x6500380c, 0x23001011, 0x06000e0c, 0x041525ee,   // tk.gv.un_530 be.ky.un_630  is.de.un_530 mn.ru.un_420 
  // [dcd0]
  0x204d5109, 0x631f090b, 0x234837a9, 0x231d11a0,   // kl.aa.sq_444 pl.cy.sco_542  ba.tt.ky_544 ro.la.ca_322 
  0x13003812, 0x51002302, 0x112223a7, 0x080411ee,   // tk.et.un_640 ca.kl.un_220  ca.oc.ro_532 ro.ru.uk_422 
  0x39245607, 0x19004b02, 0x64002202, 0x633b010b,   // mg.eo.br_432 mi.gl.un_220  oc.lg.un_220 en.so.sco_542 
  0x38632204, 0x3963010c, 0x1e1c1aee, 0x22484308,   // oc.sco.tk_332 en.sco.br_543  tl.id.ms_422 ie.tt.oc_443 
  // [dce0]
  0x63001f19, 0x15353404, 0x630139a9, 0x25505607,   // cy.sco.un_750 xh.zu.un_332  br.en.sco_544 mg.fj.eu_432 
  0x2d0d79a0, 0x36001504, 0x12002d12, 0x46000604,   // war.cs.sk_322 un.gn.un_320  sk.hu.un_640 de.qu.un_320 
  0x32162a09, 0x451e1c08, 0x48083807, 0x39002114,   // mt.hr.bs_444 id.ms.ln_443  tk.uk.tt_432 jw.br.un_660 
  0x22000302, 0x515a1804, 0x60210112, 0x3e220508,   // nl.oc.un_220 ga.sm.kl_332  en.jw.vo_654 fr.oc.rm_443 
  // [dcf0]
  0x4a002d0c, 0x36005108, 0x043717a0, 0x3463010c,   // sk.yo.un_530 kl.gn.un_430  sr.ba.ru_322 en.sco.xh_543 
  0x28005a14, 0x65002c0d, 0x3909010c, 0x190a25ee,   // sm.sw.un_660 fy.gv.un_540  en.pl.br_543 eu.pt.gl_422 
  0x0f002304, 0x5c63010c, 0x23171504, 0x1563010b,   // ca.lv.un_320 en.sco.sa_543  un.sr.ky_332 en.sco.un_542 
  0x63390112, 0x1f63010c, 0x031d0502, 0x137901ad,   // en.br.sco_654 en.sco.cy_543  fr.la.nl_222 en.war.et_643 
  // [dd00]
  0x6300390e, 0x396301ec, 0x08153c07, 0x60130112,   // br.sco.un_550 en.sco.br_644  ug.uk.un_420 en.et.vo_654 
  0x6000011a, 0x013efc09, 0x1c5c0d11, 0x2a00fe0d,   // en.vo.un_760 zzp.rm.en_444  ne.sa.mr_653 tlh.mt.un_540 
  0x1d5102a0, 0x5a2850ee, 0x58494d12, 0x30234855,   // da.kl.la_322 fj.sw.sm_422  aa.to.om_654 tt.ky.uz_442 
  0x1500362a, 0x28005805, 0x04073ca0, 0x363c1160,   // ab.un.un_970 om.sw.un_330  ug.bg.ru_322 ro.ug.ab_664 
  // [dd10]
  0x0d002f02, 0x27001505, 0x252337ee, 0x09135ca6,   // su.cs.un_220 un.gd.un_330  ba.ky.mn_422 sa.bh.hi_521 
  0x13005808, 0x645813ee, 0x3b242a0c, 0x370736ee,   // om.et.un_430 et.om.lg_422  mt.eo.so_543 ab.bg.ba_422 
  0x0e002d04, 0x100c5708, 0x441711ee, 0x35684a0c,   // sk.is.un_320 na.sv.lt_443  ro.sr.kk_422 yo.ig.zu_543 
  0x381b01a0, 0x00006e01, 0x10fe2da4, 0x303e6eee,   // en.tr.tk_322 hmn.un.un_200  sk.tlh.lt_433 hmn.rm.uz_422 
  // [dd20]
  0x064030a4, 0x16003507, 0x6e004f09, 0x5b6147a9,   // uz.lb.de_433 zu.hr.un_420  bi.hmn.un_440 sn.za.sg_544 
  0x16002802, 0xfe150f11, 0x12250455, 0x534a4d5a,   // sw.hr.un_220 lv.tlh.un_630  fi.eu.hu_442 aa.yo.ht_553 
  0x5d464ea9, 0x1300fe04, 0x0c002e0d, 0x0e002d0d,   // ay.qu.ss_544 tlh.et.un_320  fo.sv.un_540 sk.is.un_540 
  0x46000409, 0x39006e21, 0x030204ad, 0x46002d02,   // fi.qu.un_440 hmn.br.un_860  fi.da.nl_643 sk.qu.un_220 
  // [dd30]
  0x0c0233a4, 0x121a6b0c, 0xfe006e21, 0x230a07a4,   // nn.da.sv_433 ceb.tl.hu_543  hmn.tlh.un_860 bg.mk.ky_433 
  0x13004708, 0x023825a0, 0x3530440d, 0x370a15a0,   // sn.et.un_430 eu.tk.da_322  kk.uz.tg_554 un.mk.ba_322 
  0x3e5efe07, 0x6e103908, 0x3b00181a, 0x6efe69a7,   // tlh.ts.rm_432 br.lt.hmn_443  ar.ks.un_760 mfe.tlh.hmn_532 
  0x15040707, 0x6e00fe1a, 0x1a3646af, 0x09003512,   // bg.ru.un_432 tlh.hmn.un_760  qu.gn.tl_655 zu.pl.un_640 
  // [dd40]
  0x25546ea7, 0x2b006e04, 0x240f0404, 0x174e4608,   // hmn.ik.eu_532 hmn.vi.un_320  fi.lv.eo_332 qu.ay.sr_443 
  0x33082eaf, 0x655851ee, 0x1017080c, 0x46311ba7,   // fo.no.nn_655 kl.om.gv_422  uk.sr.be_543 tr.az.qu_532 
  0x22475c02, 0x325c4604, 0x3808360c, 0x19182707,   // sa.sn.oc_222 qu.sa.bs_332  ab.uk.tk_543 gd.ga.gl_432 
  0x301535a9, 0x65274304, 0x0804360c, 0x08041514,   // tg.uz.un_540 ie.gd.gv_332  ab.ru.uk_543 un.ru.uk_666 
  // [dd50]
  0x29092da0, 0x07250a08, 0x43302004, 0x1c130d0e,   // sk.pl.sl_322 mk.mn.bg_443  sq.uz.ie_332 ne.bh.mr_555 
  0x2f135cee, 0x34211205, 0x4f003013, 0x2c001504,   // sa.et.su_422 ur.fa.ps_333  uz.bi.un_650 un.fy.un_320 
  0x0a101702, 0x3f003004, 0x02651da4, 0x1b483105,   // sr.be.mk_222 uz.af.un_320  la.gv.da_433 az.tt.tr_333 
  0x25002309, 0x341812af, 0x3b003107, 0x0a101507,   // ky.mn.un_440 ur.ar.ps_655  az.so.un_420 un.be.mk_432 
  // [dd60]
  0x230807ad, 0x39016307, 0x0a3036ee, 0x1900430c,   // bg.uk.ky_643 sco.en.br_432  ab.uz.mk_422 ie.gl.un_530 
  0x65113407, 0x22210507, 0x17260204, 0x104837ee,   // xh.ro.gv_432 fr.jw.oc_432  da.ia.sr_332 ba.tt.be_422 
  0x290943a7, 0x190b0a04, 0x3d1834ee, 0x081730a0,   // ie.pl.sl_532 pt.es.gl_332  ps.ar.ku_422 uz.sr.uk_322 
  0x052022ad, 0x0e003b08, 0x230417a4, 0x0a150413,   // oc.sq.fr_643 so.is.un_430  sr.ru.ky_433 ru.mk.un_650 
  // [dd70]
  0x16001902, 0x36190ba6, 0x36005d04, 0x22194308,   // gl.hr.un_220 es.gl.gn_521  ss.gn.un_320 ie.gl.oc_443 
  0x2e083307, 0x15000907, 0x071101a0, 0x48001019,   // nn.no.fo_432 pl.un.un_420  en.ro.it_322 be.tt.un_750 
  0x18003d0e, 0x120a2305, 0x42000a08, 0x27002b13,   // ku.ar.un_550 ca.pt.hu_333  pt.co.un_430 vi.gd.un_650 
  0x53004a34, 0x2b534aad, 0x2b534a12, 0x5300421a,   // yo.ht.un_A80 yo.ht.vi_643  yo.ht.vi_654 co.ht.un_760 
  // [dd80]
  0x12003013, 0x2b4a5360, 0x3e2227a4, 0x2118230c,   // uz.ur.un_650 ht.yo.vi_664  gd.oc.rm_433 ky.ar.fa_543 
  0x2b574aad, 0x301015a0, 0x53004a22, 0x2b004a14,   // yo.na.vi_643 un.be.uz_322  yo.ht.un_870 yo.vi.un_660 
  0x56534204, 0x3038250d, 0x384425a7, 0x38005607,   // co.ht.mg_332 mn.tk.uz_554  mn.kk.tk_532 mg.tk.un_420 
  0x30003709, 0x4a004234, 0x4a00422c, 0x2b224212,   // ba.uz.un_440 co.yo.un_A80  co.yo.un_990 co.oc.vi_654 
  // [dd90]
  0x4c001704, 0x695c5dec, 0x23001121, 0x38005604,   // sr.wo.un_320 ss.sa.mfe_644  ro.ky.un_860 mg.tk.un_320 
  0x476455af, 0x3427030c, 0x211828a4, 0x04003913,   // rw.lg.sn_655 nl.gd.xh_543  sd.ar.fa_433 br.fi.un_650 
  0x2900281a, 0x2d002819, 0x1e305ba4, 0x284a520c,   // sw.sl.un_760 sw.sk.un_750  sg.uz.ms_433 ha.yo.sw_543 
  0x1c1e280b, 0x0200fe12, 0x5d002808, 0x3b002402,   // sw.ms.id_542 tlh.da.un_640  sw.ss.un_430 eo.so.un_220 
  // [dda0]
  0x38005612, 0x3b241f04, 0x4a5228ee, 0x1b000e12,   // mg.tk.un_640 cy.eo.so_332  sw.ha.yo_422 is.tr.un_640 
  0x173e0f07, 0x651b59a4, 0x272e2411, 0x045637ec,   // lv.rm.sr_432 rn.tr.gv_433  eo.fo.gd_653 st.mg.fi_644 
  0x0a1004a4, 0x3b552804, 0x653b64a4, 0x32001207,   // ru.be.mk_433 sw.rw.so_332  lg.so.gv_433 hu.bs.un_420 
  0x24001d07, 0x56000a1b, 0x0200530e, 0x2f002820,   // la.eo.un_420 pt.mg.un_770  ht.da.un_550 sw.su.un_850 
  // [ddb0]
  0x362211ee, 0x1e006e0c, 0x3100fe0e, 0x211b28ee,   // ro.oc.gn_422 hmn.ms.un_530  tlh.az.un_550 sw.tr.jw_422 
  0x550228ec, 0x1c2165a4, 0x25002909, 0x1b3b65a7,   // sw.da.rw_644 gv.jw.id_433  sl.eu.un_440 gv.so.tr_532 
  0x6e0268a4, 0x2a42070d, 0x23171107, 0x4700650c,   // ig.da.hmn_433 it.co.mt_554  ro.sr.ky_432 gv.sn.un_530 
  0x38651b07, 0x070a390c, 0x47005808, 0x303c350c,   // tr.gv.tk_432 br.pt.it_543  om.sn.un_430 tg.ug.uz_543 
  // [ddc0]
  0x630115ec, 0x3b29460d, 0x63284704, 0x052f21a0,   // un.en.sco_644 qu.sl.so_554  sn.sw.sco_332 jw.su.fr_322 
  0x090c13a4, 0x4c00051a, 0x2b254955, 0x3b254ca9,   // et.sv.pl_433 fr.wo.un_760  to.eu.vi_442 wo.eu.so_544 
  0x12211814, 0x0f4d520c, 0x4d5652a9, 0x65fc3f0c,   // ar.fa.ur_666 ha.aa.lv_543  ha.mg.aa_544 af.zzp.gv_543 
  0x4559555a, 0x205f75a4, 0x4c450555, 0x49675a60,   // rw.rn.ln_553 nso.tn.sq_433  fr.ln.wo_442 sm.ak.to_664 
  // [ddd0]
  0x2b5855ee, 0x07043805, 0x735256a4, 0x350448a0,   // rw.om.vi_422 tk.ru.bg_333  mg.ha.ny_433 tt.ru.tg_322 
  0x0a073805, 0x48003b19, 0x02000407, 0x24004b05,   // tk.bg.mk_333 so.tt.un_750  fi.da.un_420 mi.eo.un_330 
  0x09041805, 0x56281ea0, 0x601f24af, 0x13046704,   // ga.fi.pl_333 ms.sw.mg_322  eo.cy.vo_655 ak.fi.et_332 
  0x48080407, 0x58000c08, 0x56005222, 0x08002502,   // ru.uk.tt_432 sv.om.un_430  ha.mg.un_870 eu.no.un_220 
  // [dde0]
  0x092d0d05, 0x16000207, 0x4c5258a0, 0x5a00470c,   // cs.sk.pl_333 da.hr.un_420  om.ha.wo_322 sn.sm.un_530 
  0x0e136707, 0x3b1304a7, 0x181f6113, 0x585104a9,   // ak.et.is_432 fi.et.so_532  za.cy.ga_665 fi.kl.om_544 
  0x21442312, 0x5c130d07, 0x79001a21, 0x12001702,   // ky.kk.fa_654 ne.bh.sa_432  tl.war.un_860 sr.hu.un_220 
  0x17101513, 0x2e043b04, 0x561304a4, 0x302348a0,   // un.be.sr_665 so.fi.fo_332  fi.et.mg_433 tt.ky.uz_322 
  // [ddf0]
  0x35004008, 0x51000402, 0x1b5212a4, 0x0430510d,   // lb.zu.un_430 fi.kl.un_220  hu.ha.tr_433 kl.uz.fi_554 
  0x1800fe05, 0x5c0413a0, 0x3b001504, 0x73000213,   // tlh.ga.un_330 et.fi.sa_322  un.so.un_320 da.ny.un_650 
  0x30153807, 0x42130409, 0x21001309, 0x1715360b,   // tk.uz.un_420 fi.et.co_444  et.jw.un_440 ab.sr.un_520 
  0x1c002e02, 0x20000208, 0x36373007, 0x21001305,   // fo.id.un_220 da.sq.un_430  uz.ba.ab_432 et.jw.un_330 
  // [de00]
  0x3700350c, 0x444838a9, 0x29000f1b, 0x1b212fa0,   // tg.ba.un_530 tk.tt.kk_544  lv.sl.un_770 su.jw.tr_322 
  0x28183ba0, 0x48070aa0, 0x091223a4, 0x0a30230c,   // ks.ar.sd_322 mk.bg.tt_322  ca.hu.pl_433 ky.uz.mk_543 
  0x5c002b19, 0x0c2311a4, 0x0c004f04, 0x0c620408,   // vi.sa.un_750 ro.ca.sv_433  bi.sv.un_320 fi.kha.sv_443 
  0x3f045107, 0x0b000114, 0x2d0d30ad, 0x1e1c0ca4,   // kl.fi.af_432 en.es.un_660  uz.cs.sk_643 sv.id.ms_433 
  // [de10]
  0x44081007, 0x250a3608, 0x1c511ea0, 0x11300ca0,   // be.uk.kk_432 ab.mk.mn_443  ms.kl.id_322 sv.uz.ro_322 
  0x62004d13, 0x0c000d0d, 0x33000307, 0x1a110405,   // aa.kha.un_650 cs.sv.un_540  nl.nn.un_420 fi.ro.tl_333 
  0x330c2ea4, 0x3300030c, 0x3f000c08, 0x04351007,   // fo.sv.nn_433 nl.nn.un_530  sv.af.un_430 be.tg.ru_432 
  0x65643b07, 0x38311ba6, 0x08332e08, 0x3b004c21,   // so.lg.gv_432 tr.az.tk_521  fo.nn.no_443 wo.so.un_860 
  // [de20]
  0xfc002504, 0x42002812, 0x2e000312, 0x65583b08,   // eu.zzp.un_320 sw.co.un_640  nl.fo.un_640 so.om.gv_443 
  0x4d003b0e, 0x635a40a4, 0x09004009, 0x64023b0e,   // so.aa.un_550 lb.sm.sco_433  lb.pl.un_440 so.da.lg_555 
  0x64003b19, 0x64653b05, 0x27004604, 0x25001104,   // so.lg.un_750 so.gv.lg_333  qu.gd.un_320 ro.eu.un_320 
  0x58653b0c, 0x2d0d22af, 0x643b6560, 0x080704ee,   // so.gv.om_543 oc.cs.sk_655  gv.so.lg_664 ru.bg.uk_422 
  // [de30]
  0x2d4006a4, 0x07173ca4, 0x285a4955, 0x23283005,   // de.lb.sk_433 ug.sr.bg_433  to.sm.sw_442 uz.sd.ky_333 
  0x0600fe0d, 0x2c40020c, 0x0c654007, 0x0600fe14,   // tlh.de.un_540 da.lb.fy_543  lb.gv.sv_432 tlh.de.un_660 
  0x4006fe12, 0x4e100faf, 0x03025104, 0x43003304,   // tlh.de.lb_654 lv.lt.ay_655  kl.da.nl_332 nn.ie.un_320 
  0x4b3725a0, 0x37004b21, 0x02002009, 0x222a04a0,   // eu.st.mi_322 mi.st.un_860  sq.da.un_440 fi.mt.oc_322 
  // [de40]
  0x3f00fe0d, 0x405c06ee, 0x2f04fcee, 0x2a06040c,   // tlh.af.un_540 de.sa.lb_422  zzp.fi.su_422 fi.de.mt_543 
  0x0f102daf, 0x0900030c, 0x492e40a0, 0x5a002507,   // sk.lt.lv_655 nl.pl.un_530  lb.fo.to_322 eu.sm.un_420 
  0x43630107, 0x61063f0d, 0x61000f1a, 0x162901a0,   // en.sco.ie_432 af.de.za_554  lv.za.un_760 en.sl.hr_322 
  0x44230405, 0x493f0312, 0x3f0361ad, 0x1d0d0107,   // ru.ky.kk_333 nl.af.to_654  za.nl.af_643 en.cs.la_432 
  // [de50]
  0x3f00250c, 0x020c15a0, 0x09162907, 0x67004613,   // eu.af.un_530 un.sv.da_322  sl.hr.pl_432 qu.ak.un_650 
  0x790f400c, 0x0b072d0c, 0x60100f0d, 0x2c400312,   // lb.lv.war_543 sk.it.es_543  lv.lt.vo_554 nl.lb.fy_654 
  0x016561ac, 0x04002d1a, 0x1e000f04, 0x47003902,   // za.gv.en_632 sk.fi.un_760  lv.ms.un_320 br.sn.un_220 
  0x0a113509, 0x302469a0, 0x2d113eee, 0x30070a04,   // tg.ro.mk_444 mfe.eo.uz_322  rm.ro.sk_422 mk.bg.uz_332 
  // [de60]
  0x39006413, 0x211c5602, 0x1e00070c, 0x30112dee,   // lg.br.un_650 mg.id.jw_222  it.ms.un_530 sk.ro.uz_422 
  0x3e0711ee, 0x34283dac, 0x13005c05, 0x1c435108,   // ro.it.rm_422 ku.sd.ps_632  sa.bh.un_330 kl.ie.id_443 
  0x1153390c, 0x482338a7, 0x3907290c, 0x43511d05,   // br.ht.ro_543 tk.ky.tt_532  sl.it.br_543 la.kl.ie_333 
  0x2039250c, 0x2f1d11ee, 0x25005104, 0x114362a9,   // eu.br.sq_543 ro.la.su_422  kl.eu.un_320 kha.ie.ro_544 
  // [de70]
  0x48301712, 0x392c15ad, 0x43511105, 0x13431d0c,   // sr.uz.tt_654 un.fy.br_643  ro.kl.ie_333 la.ie.et_543 
  0x1b1e3007, 0x1200100d, 0x31393e02, 0x4609790c,   // uz.ms.tr_432 lt.hu.un_540  rm.br.az_222 war.pl.qu_543 
  0x23383012, 0x621e5108, 0x190b230b, 0x1620feee,   // uz.tk.ky_654 kl.ms.kha_443  ca.es.gl_542 tlh.sq.hr_422 
  0x15000205, 0xfe00200e, 0x083c0409, 0x2000fe09,   // da.un.un_330 sq.tlh.un_550  ru.ug.uk_444 tlh.sq.un_440 
  // [de80]
  0x090d20ad, 0x30173ca4, 0x15300804, 0x210115a0,   // sq.cs.pl_643 ug.sr.uz_433  uk.uz.un_332 un.en.jw_322 
  0x12101f0c, 0x08003c19, 0x3c0a0404, 0x4a000c12,   // cy.lt.hu_543 ug.uk.un_750  ru.mk.ug_332 sv.yo.un_640 
  0x23190b0c, 0x16fe20ad, 0x220b18ee, 0x42002311,   // es.gl.ca_543 sq.tlh.hr_643  ga.es.oc_422 ca.co.un_630 
  0xfe2d20ad, 0x0e791d55, 0x46004a05, 0x4a564905,   // sq.sk.tlh_643 la.war.is_442  yo.qu.un_330 to.mg.yo_333 
  // [de90]
  0x2548105a, 0x3d183405, 0xfc1e1b02, 0x211c46a0,   // be.tt.mn_553 ps.ar.ku_333  tr.ms.zzp_222 qu.id.jw_322 
  0x4629fca0, 0x24000609, 0x796b1a14, 0x153738a4,   // zzp.sl.qu_322 de.eo.un_440  tl.ceb.war_666 tk.ba.un_433 
  0x082315ee, 0x25002702, 0x652e4604, 0x073646a0,   // un.ky.uk_422 gd.eu.un_220  qu.fo.gv_332 qu.gn.it_322 
  0x0d5c1c13, 0x532146ee, 0x5c040e55, 0x7600510d,   // mr.sa.ne_665 qu.jw.ht_422  is.fi.sa_442 kl.crs.un_540 
  // [dea0]
  0x4e3f0107, 0x0c2e51a4, 0x31301fa0, 0x28123004,   // en.af.ay_432 kl.fo.sv_433  cy.uz.az_322 uz.ur.sd_332 
  0x29003002, 0x07041509, 0x04553407, 0x20001502,   // uz.sl.un_220 un.ru.bg_444  xh.rw.fi_432 un.sq.un_220 
  0x5500670d, 0x60202508, 0x5a0413ee, 0x201d01a0,   // ak.rw.un_540 eu.sq.vo_443  et.fi.sm_422 en.la.sq_322 
  0x4e190b05, 0x444804a0, 0x11003e04, 0x25170404,   // es.gl.ay_333 ru.tt.kk_322  rm.ro.un_320 ru.sr.mn_332 
  // [deb0]
  0x28381bad, 0x251d5e08, 0x1b68380c, 0x562520a9,   // tr.tk.sw_643 ts.la.eu_443  tk.ig.tr_543 sq.eu.mg_544 
  0x52003723, 0x3e062407, 0x20005804, 0x37353c09,   // st.ha.un_880 eo.de.rm_432  om.sq.un_320 ug.tg.ba_444 
  0x5c301c02, 0x35002807, 0x021c0e08, 0x31004607,   // id.uz.sa_222 sw.zu.un_420  is.id.da_443 qu.az.un_420 
  0x5d004a0c, 0x5cfe06a9, 0x25003723, 0x11007319,   // yo.ss.un_530 de.tlh.sa_544  ba.mn.un_880 ny.ro.un_750 
  // [dec0]
  0x5f3767ee, 0x063f5507, 0x5f355ea0, 0x650833a4,   // ak.st.tn_422 rw.af.de_432  ts.zu.tn_322 nn.no.gv_433 
  0x082e33ac, 0x2b000604, 0x045c0ea4, 0x04102302,   // nn.fo.no_632 de.vi.un_320  is.sa.fi_433 ky.be.ru_222 
  0x5706400c, 0x0e003402, 0x3e064009, 0x31610205,   // lb.de.na_543 xh.is.un_220  lb.de.rm_444 da.za.az_333 
  0x5c002f02, 0x1a3879a0, 0x3e4006ec, 0x55005c02,   // su.sa.un_220 war.tk.tl_322  de.lb.rm_644 sa.rw.un_220 
  // [ded0]
  0x0a111708, 0x343778ad, 0x2c3e4012, 0x4000fc0d,   // sr.ro.mk_443 ve.st.xh_643  lb.rm.fy_654 zzp.lb.un_540 
  0x48007312, 0x5706fc09, 0x53247608, 0x55365ca9,   // ny.tt.un_640 zzp.de.na_444  crs.eo.ht_443 sa.gn.rw_544 
  0x47345c04, 0xfe6847ec, 0x130e0ca7, 0x124b37a4,   // sa.xh.sn_332 sn.ig.tlh_644  sv.is.et_532 st.mi.hu_433 
  0x0c002504, 0x3e0640a4, 0x1c001e21, 0x015e1d07,   // eu.sv.un_320 lb.de.rm_433  ms.id.un_860 la.ts.en_432 
  // [dee0]
  0x206328a4, 0x75783713, 0x0601fca0, 0x7300280c,   // sw.sco.sq_433 st.ve.nso_665  zzp.en.de_322 sw.ny.un_530 
  0x634b0112, 0x343778ec, 0x44213d07, 0x07360a0e,   // en.mi.sco_654 ve.st.xh_644  ku.fa.kk_432 mk.ab.bg_555 
  0x25303504, 0x11000a12, 0x48383c07, 0x440423a0,   // tg.uz.mn_332 mk.ro.un_640  ug.tk.tt_432 ky.ru.kk_322 
  0x30033fee, 0x17002505, 0x29321705, 0x2c3f03a7,   // af.nl.uz_422 eu.sr.un_330  sr.bs.sl_333 nl.af.fy_532 
  // [def0]
  0x251515ad, 0x4f122213, 0x02042207, 0x64002b08,   // un.mn.un_630 oc.hu.bi_665  oc.fi.da_432 vi.lg.un_430 
  0x61005421, 0x25153605, 0x03001c0c, 0x4f201207,   // ik.za.un_860 ab.mn.un_330  id.nl.un_530 hu.sq.bi_432 
  0x1e2a7907, 0x3507380c, 0x201b3204, 0x37000408,   // war.mt.ms_432 tk.bg.tg_543  bs.tr.sq_332 ru.ba.un_430 
  0x371536a9, 0x61123913, 0x15630104, 0x4d131e0c,   // ab.ba.un_540 br.hu.za_665  en.sco.un_332 ms.et.aa_543 
  // [df00]
  0x0f291705, 0x201b12ee, 0x1a000104, 0x180c33a4,   // sr.sl.lv_333 hu.tr.sq_422  en.tl.un_320 nn.sv.ga_433 
  0x226220a4, 0x1d126207, 0x441523a4, 0x6513390c,   // sq.kha.oc_433 kha.hu.la_432  ky.kk.un_430 br.et.gv_543 
  0x373848ec, 0x3e0679ee, 0x360b7912, 0x1f3b180c,   // tt.tk.ba_644 war.de.rm_422  war.es.gn_654 ga.so.cy_543 
  0x2a4e4613, 0x0f00790d, 0x27133ba0, 0x031d3b08,   // qu.ay.mt_665 war.lv.un_540  so.et.gd_322 so.la.nl_443 
  // [df10]
  0x1b006519, 0x041711a0, 0x1a3b6ba9, 0x5cfe13ec,   // gv.tr.un_750 ro.sr.ru_322  ceb.so.tl_544 et.tlh.sa_644 
  0x6b121a09, 0x3f003e0d, 0x65004d0d, 0x1f3913a9,   // tl.hu.ceb_444 rm.af.un_540  aa.gv.un_540 et.br.cy_544 
  0x1f690cec, 0x13002d04, 0x60001c04, 0x160d175a,   // sv.mfe.cy_644 sk.et.un_320  id.vo.un_320 sr.cs.hr_553 
  0x3b2afe0c, 0x48002a0c, 0x30484607, 0x304846ec,   // tlh.mt.so_543 mt.tt.un_530  qu.tt.uz_432 qu.tt.uz_644 
  // [df20]
  0x312a510c, 0x2d063504, 0x300e3f02, 0x372515a9,   // kl.mt.az_543 zu.de.sk_332  af.is.uz_222 un.mn.ba_544 
  0x130d5c08, 0x0d000f13, 0x3f2428ee, 0x16292d12,   // sa.ne.bh_443 lv.cs.un_650  sw.eo.af_422 sk.sl.hr_654 
  0x485c3109, 0x2a000612, 0x4b4a36ad, 0x032e0e0d,   // az.sa.tt_444 de.mt.un_640  gn.yo.mi_643 is.fo.nl_554 
  0x02005c14, 0x48006307, 0x4e125c12, 0x1a485c07,   // sa.da.un_660 sco.tt.un_420  sa.hu.ay_654 sa.tt.tl_432 
  // [df30]
  0x30071507, 0x016263a4, 0x173c0705, 0x0c0e06ee,   // un.bg.uz_432 sco.kha.en_433  bg.ug.sr_333 de.is.sv_422 
  0x01005d02, 0x07000209, 0x133f2f07, 0x320924ee,   // ss.en.un_220 da.it.un_440  su.af.et_432 eo.pl.bs_422 
  0x63651305, 0x0163570b, 0x5dfc3705, 0x22001504,   // et.gv.sco_333 na.sco.en_542  st.zzp.ss_333 un.oc.un_320 
  0x5c00180b, 0x231044ec, 0x2e000605, 0x08002904,   // ga.sa.un_520 kk.be.ky_644  de.fo.un_330 sl.no.un_320 
  // [df40]
  0x68004618, 0x5100fc07, 0x18005c07, 0x0a0b4655,   // qu.ig.un_740 zzp.kl.un_420  sa.ga.un_420 qu.es.pt_442 
  0x4000050c, 0x12000208, 0x0a1508af, 0x1b004202,   // fr.lb.un_530 da.hu.un_430  uk.mk.un_650 co.tr.un_220 
  0x5c27185a, 0x465a3104, 0x4c6212a4, 0x040a1712,   // ga.gd.sa_553 az.sm.qu_332  hu.kha.wo_433 sr.mk.ru_654 
  0x12000412, 0x0f001021, 0x541b5111, 0x33082ca0,   // fi.hu.un_640 lt.lv.un_860  kl.tr.ik_653 fy.no.nn_322 
  // [df50]
  0x4c1b48ee, 0x2f001a0c, 0x20000c12, 0x1800110c,   // tt.tr.wo_422 tl.su.un_530  sv.sq.un_640 ro.ga.un_530 
  0x1a793b0c, 0x1a3b6b04, 0x25004c12, 0x0735105a,   // so.war.tl_543 ceb.so.tl_332  wo.eu.un_640 be.tg.bg_553 
  0x4c3bfca0, 0x0200300b, 0x38004c07, 0x0d044caf,   // zzp.so.wo_322 uz.da.un_520  wo.tk.un_420 wo.fi.cs_655 
  0x36006308, 0x29162d0c, 0x0c040dee, 0x0800fc02,   // sco.gn.un_430 sk.hr.sl_543  cs.fi.sv_422 zzp.no.un_220 
  // [df60]
  0x016b1a07, 0x0300fe0c, 0x4c00200d, 0xfe00370e,   // tl.ceb.en_432 tlh.nl.un_530  sq.wo.un_540 st.tlh.un_550 
  0x25374811, 0x04170a0c, 0x314d3404, 0x44482309,   // tt.ba.mn_653 mk.sr.ru_543  xh.aa.az_332 ky.tt.kk_444 
  0x11003513, 0xfe583b60, 0x10070a0c, 0x1b0c3ba0,   // tg.ro.un_650 so.om.tlh_664  mk.bg.be_543 so.sv.tr_322 
  0x353034a4, 0x1c002702, 0x3400500c, 0x34583b04,   // xh.uz.zu_433 gd.id.un_220  fj.xh.un_530 so.om.xh_332 
  // [df70]
  0xfe004605, 0x11003022, 0x2a005113, 0x03002007,   // qu.tlh.un_330 uz.ro.un_870  kl.mt.un_650 sq.nl.un_420 
  0x0f02460c, 0x595f3708, 0x4f766913, 0x3f2d29a4,   // qu.da.lv_543 st.tn.rn_443  mfe.crs.bi_665 sl.sk.af_433 
  0x2e0c0e05, 0x5a755f0c, 0x0c33080c, 0x32791f04,   // is.sv.fo_333 tn.nso.sm_543  no.nn.sv_543 cy.war.bs_332 
  0x3e0260a4, 0xfe393e12, 0x0f0d0907, 0x0e006513,   // vo.da.rm_433 rm.br.tlh_654  pl.cs.lv_432 gv.is.un_650 
  // [df80]
  0x465efe0b, 0x3d12280c, 0x03330c12, 0x30003108,   // tlh.ts.qu_542 sd.ur.ku_543  sv.nn.nl_654 az.uz.un_430 
  0x790f4e55, 0x3810240c, 0x5800680c, 0x2500351b,   // ay.lv.war_442 eo.lt.tk_543  ig.om.un_530 tg.mn.un_770 
  0x102c6055, 0x213b3d55, 0x4a004c08, 0x0c190b09,   // vo.fy.lt_442 ku.ks.fa_442  wo.yo.un_430 es.gl.sv_444 
  0x2c001205, 0x081510a0, 0x2812300c, 0x3f2c09a0,   // hu.fy.un_330 be.uk.un_320  uz.ur.sd_543 pl.fy.af_322 
  // [df90]
  0x34002708, 0x441048a0, 0x6700fc0e, 0x25002407,   // gd.xh.un_430 tt.be.kk_322  zzp.ak.un_550 eo.eu.un_420 
  0x5200fc2b, 0x01631d04, 0x011f0207, 0x17044455,   // zzp.ha.un_980 la.sco.en_332  da.cy.en_432 kk.ru.sr_442 
  0x23003404, 0x3f0938a0, 0x1f632104, 0xfc2a4ba7,   // xh.ca.un_320 tk.pl.af_322  jw.sco.cy_332 mi.mt.zzp_532 
  0x181221a7, 0x420624ee, 0x282118a0, 0x4e6473a4,   // fa.ur.ar_532 eo.de.co_422  ar.fa.sd_322 ny.lg.ay_433 
  // [dfa0]
  0x2f6b1aa4, 0x231234ee, 0x426e05ad, 0x796b25a7,   // tl.ceb.su_433 ps.ur.ky_422  fr.hmn.co_643 eu.ceb.war_532 
  0x0a3537a0, 0x352f79a0, 0x2f624fad, 0x1a0f10a0,   // ba.tg.mk_322 war.su.zu_322  bi.kha.su_643 lt.lv.tl_322 
  0x3b030f0d, 0x5e005504, 0x644e0213, 0x0430350b,   // lv.nl.so_554 rw.ts.un_320  da.ay.lg_665 tg.uz.ru_542 
  0x1b027908, 0x0e000305, 0x6400020d, 0x04251707,   // war.da.tr_443 nl.is.un_330  da.lg.un_540 sr.mn.ru_432 
  // [dfb0]
  0x54001d0e, 0x4000300c, 0x151017a4, 0x0c032ea0,   // la.ik.un_550 uz.lb.un_530  sr.be.un_433 fo.nl.sv_322 
  0x472c030c, 0x48003e04, 0x5efe3312, 0x01006e0c,   // nl.fy.sn_543 rm.tt.un_320  nn.tlh.ts_654 hmn.en.un_530 
  0x31111b04, 0x29fe0da4, 0x3f26fea4, 0x78766908,   // tr.ro.az_332 cs.tlh.sl_433  tlh.ia.af_433 mfe.crs.ve_443 
  0x393e6ea7, 0x65621d07, 0x67003919, 0x65007304,   // hmn.rm.br_532 la.kha.gv_432  br.ak.un_750 ny.gv.un_320 
  // [dfc0]
  0x06403e09, 0x42072a13, 0x651d18a0, 0x153848a7,   // rm.lb.de_444 mt.it.co_665  ga.la.gv_322 tt.tk.un_532 
  0x6e0a3107, 0x090d2da4, 0x2e000102, 0x4006050d,   // az.pt.hmn_432 sk.cs.pl_433  en.fo.un_220 fr.de.lb_554 
  0x48fe69a0, 0x054239a4, 0x063e42a4, 0x02003805,   // mfe.tlh.tt_322 br.co.fr_433  co.rm.de_433 tk.da.un_330 
  0x30443708, 0xfc005c19, 0x625a01ee, 0x6e2e0f0c,   // ba.kk.uz_443 sa.zzp.un_750  en.sm.kha_422 lv.fo.hmn_543 
  // [dfd0]
  0x55283b02, 0x15002002, 0xfe006e12, 0x2e396e0c,   // so.sw.rw_222 sq.un.un_220  hmn.tlh.un_640 hmn.br.fo_543 
  0x190b22a0, 0x24003307, 0xfe6e0f0c, 0x65fc1f04,   // oc.es.gl_322 nn.eo.un_420  lv.hmn.tlh_543 cy.zzp.gv_332 
  0x51002a05, 0x027625a4, 0x423e1512, 0x311b6107,   // mt.kl.un_330 eu.crs.da_433  un.rm.co_654 za.tr.az_432 
  0x0c18fca0, 0x5e006e05, 0x064615ee, 0x38033f13,   // zzp.ga.sv_322 hmn.ts.un_330  un.qu.de_422 af.nl.tk_665 
  // [dfe0]
  0x40030613, 0x2330250b, 0x19004602, 0x3c00210c,   // de.nl.lb_665 mn.uz.ky_542  qu.gl.un_220 fa.ug.un_530 
  0x1500362b, 0x04005107, 0x23004813, 0x040815ee,   // ab.un.un_980 kl.fi.un_420  tt.ky.un_650 un.uk.ru_422 
  0x3c122312, 0x25343507, 0x225c4855, 0x47453507,   // ky.ur.ug_654 zu.xh.eu_432  tt.sa.oc_442 zu.ln.sn_432 
  0x5900451a, 0x59561209, 0x0400370e, 0x25100408,   // ln.rn.un_760 hu.mg.rn_444  ba.ru.un_550 ru.be.mn_443 
  // [dff0]
  0x070a3504, 0x481f5cac, 0x3f0c02a4, 0x3d3418a6,   // tg.mk.bg_332 sa.cy.tt_632  da.sv.af_433 ar.ps.ku_521 
  0x480a0712, 0x353c3055, 0x2b005d05, 0x21183bac,   // bg.mk.tt_654 uz.ug.tg_442  ss.vi.un_330 ks.ar.fa_632 
  0x0a074802, 0x35005909, 0x12003107, 0x100815a7,   // tt.bg.mk_222 rn.zu.un_440  az.hu.un_420 un.uk.be_532 
  0x341221a9, 0x04292aee, 0x624320a4, 0x1136250c,   // fa.ur.ps_544 mt.sl.fi_422  sq.ie.kha_433 mn.ab.ro_543 
  
  // [e000]
  0x016522ee, 0x132a5404, 0x35303860, 0x0d291d0c,   // oc.gv.en_422 ik.mt.et_332  tk.uz.tg_664 la.sl.cs_543 
  0x2a002008, 0x441704a9, 0x36006013, 0x0f002402,   // sq.mt.un_430 ru.sr.kk_544  vo.gn.un_650 eo.lv.un_220 
  0x23170402, 0x20001207, 0x044823a9, 0x0a36250b,   // ru.sr.ky_222 hu.sq.un_420  ky.tt.ru_544 mn.ab.mk_542 
  0x40053905, 0x2a0c0408, 0x15030207, 0x354d4612,   // br.fr.lb_333 fi.sv.mt_443  da.nl.un_432 qu.aa.zu_654 
  // [e010]
  0x73fcfa07, 0x313035ee, 0x21000212, 0x0273fc60,   // nr.zzp.ny_432 zu.uz.az_422  da.jw.un_640 zzp.ny.da_664 
  0x0e003b02, 0x4a5d7355, 0x15002107, 0x10001507,   // so.is.un_220 ny.ss.yo_442  jw.un.un_420 un.be.un_420 
  0x0d5c3b07, 0x2b111502, 0x21001211, 0x0e00560c,   // ks.sa.ne_432 un.ro.vi_222  ur.fa.un_630 mg.is.un_530 
  0x6b1e1c11, 0x6001150c, 0x35073c55, 0xfe526804,   // id.ms.ceb_653 un.en.vo_543  ug.bg.tg_442 ig.ha.tlh_332 
  // [e020]
  0x28524b08, 0x27002b0d, 0x0c1215a6, 0x13472508,   // mi.ha.sw_443 vi.gd.un_540  un.hu.sv_521 eu.sn.et_443 
  0x31383002, 0x595557a9, 0x686b1da4, 0x3e2b4aaf,   // uz.tk.az_222 na.rw.rn_544  la.ceb.ig_433 yo.vi.rm_655 
  0x082d0d07, 0x195720a4, 0x42002b02, 0x026b1d05,   // cs.sk.no_432 sq.na.gl_433  vi.co.un_220 la.ceb.da_333 
  0x0a2e5755, 0x5a0a52a4, 0x1f005f05, 0x36005713,   // na.fo.pt_442 ha.pt.sm_433  tn.cy.un_330 na.gn.un_650 
  // [e030]
  0x214f4d0c, 0x11001804, 0x6455fe11, 0x48351511,   // aa.bi.jw_543 ga.ro.un_320  tlh.rw.lg_653 un.tg.tt_653 
  0x20320413, 0x043c3807, 0x27004a19, 0x330820ac,   // fi.bs.sq_665 tk.ug.ru_432  yo.gd.un_750 sq.no.nn_632 
  0x1c55fe55, 0x321a4aa7, 0x170a0405, 0x31381b12,   // tlh.rw.id_442 yo.tl.bs_532  ru.mk.sr_333 tr.tk.az_654 
  0x1d001113, 0x3e004a08, 0x0c092da0, 0x65002108,   // ro.la.un_650 yo.rm.un_430  sk.pl.sv_322 jw.gv.un_430 
  // [e040]
  0x4d00490e, 0x33321655, 0x0e002007, 0x3216200c,   // to.aa.un_550 hr.bs.nn_442  sq.is.un_420 sq.hr.bs_543 
  0x39003404, 0x0d00290d, 0x34004908, 0xfc001508,   // xh.br.un_320 sl.cs.un_540  to.xh.un_430 un.zzp.un_430 
  0x18006508, 0x0b194ca6, 0x272a1804, 0x5c0f10a9,   // gv.ga.un_430 wo.gl.es_521  ga.mt.gd_332 lt.lv.sa_544 
  0x044815a7, 0x4a34350c, 0x46004d12, 0x02006422,   // un.tt.ru_532 zu.xh.yo_543  aa.qu.un_640 lg.da.un_870 
  // [e050]
  0x391f0e07, 0x07351507, 0x24005004, 0x4500640d,   // is.cy.br_432 un.tg.bg_432  fj.eo.un_320 lg.ln.un_540 
  0x695f37a4, 0x35004519, 0x01fc15a4, 0x1b116007,   // st.tn.mfe_433 ln.zu.un_750  un.zzp.en_433 vo.ro.tr_432 
  0x1a00450d, 0x0a043902, 0x555364ec, 0x213e2208,   // ln.tl.un_540 br.fi.pt_222  lg.ht.rw_644 oc.rm.jw_443 
  0x67060807, 0x0200550d, 0x20005e04, 0x0c5e0255,   // no.de.ak_432 rw.da.un_540  ts.sq.un_320 da.ts.sv_442 
  // [e060]
  0x4a67580d, 0x5a6049ad, 0x57400e08, 0x250715ec,   // om.ak.yo_554 to.vo.sm_643  is.lb.na_443 un.bg.mn_644 
  0x35344709, 0x0c004602, 0x44361511, 0x59000219,   // sn.xh.zu_444 qu.sv.un_220  un.ab.kk_653 da.rn.un_750 
  0x28006b07, 0x376049af, 0x482515ee, 0x03162cee,   // ceb.sw.un_420 to.vo.st_655  un.mn.tt_422 fy.hr.nl_422 
  0x156b01a4, 0x2c790312, 0x38005f11, 0x44002508,   // en.ceb.un_433 nl.war.fy_654  tn.tk.un_630 mn.kk.un_430 
  // [e070]
  0x39251f12, 0x2a00112a, 0x481038a0, 0x1c212fa4,   // cy.eu.br_654 ro.mt.un_970  tk.be.tt_322 su.jw.id_433 
  0x6b76460c, 0x5c531e0c, 0x1725080c, 0x30571105,   // qu.crs.ceb_543 ms.ht.sa_543  uk.mn.sr_543 ro.na.uz_333 
  0x38fc5c07, 0x5c1c1302, 0x48001104, 0x6bfc695a,   // sa.zzp.tk_432 bh.mr.sa_222  ro.tt.un_320 mfe.zzp.ceb_553 
  0x484436ee, 0x3418440c, 0x070a0802, 0x08101104,   // ab.kk.tt_422 kk.ar.ps_543  uk.mk.bg_222 ro.be.uk_332 
  // [e080]
  0x01022404, 0x1e15240c, 0x28fc4aa4, 0x240315a0,   // eo.da.en_332 eo.ms.un_530  yo.zzp.sw_433 un.nl.eo_322 
  0x2f733b08, 0x04081505, 0x1b673b12, 0x73284a04,   // so.ny.su_443 un.uk.ru_333  so.ak.tr_654 yo.sw.ny_332 
  0x25000702, 0x0f022405, 0x443c38ad, 0x03152407,   // bg.mn.un_220 eo.da.lv_333  tk.ug.kk_643 eo.nl.un_420 
  0x3b5e6507, 0x0a003e04, 0x4c0a2408, 0x30002d08,   // gv.ts.so_432 rm.pt.un_320  eo.pt.wo_443 sk.uz.un_430 
  // [e090]
  0x311b480c, 0x38651b0c, 0x533969a6, 0x23443807,   // tt.tr.az_543 tr.gv.tk_543  mfe.br.ht_521 tk.kk.ky_432 
  0x2c381b0c, 0x081004ec, 0x073530a7, 0x6b006712,   // tr.tk.fy_543 ru.be.uk_644  uz.tg.bg_532 ak.ceb.un_640 
  0x18343cee, 0x0a001908, 0x081017a0, 0x3f1f2ea0,   // ug.ps.ar_422 gl.pt.un_430  sr.be.uk_322 fo.cy.af_322 
  0x44353011, 0x50fe300c, 0x32212d07, 0x30004d05,   // uz.tg.kk_653 uz.tlh.fj_543  sk.jw.bs_432 aa.uz.un_330 
  // [e0a0]
  0xfe004d08, 0x4d00fe19, 0xfc0501a9, 0x3b002002,   // aa.tlh.un_430 tlh.aa.un_750  en.fr.zzp_544 sq.so.un_220 
  0x05005504, 0x35004807, 0x37442312, 0x5c4830ad,   // rw.fr.un_320 tt.zu.un_420  ky.kk.ba_654 uz.tt.sa_643 
  0x520ffcee, 0x6900011a, 0x1f003004, 0x15363c07,   // zzp.lv.ha_422 en.mfe.un_760  uz.cy.un_320 ug.ab.un_432 
  0x651f0c02, 0x032605a9, 0x3f2402ee, 0x3031500b,   // sv.cy.gv_222 fr.ia.nl_544  da.eo.af_422 fj.az.uz_542 
  // [e0b0]
  0x54005134, 0x35fa3b60, 0x10480f0c, 0x304c50ec,   // kl.ik.un_A80 so.nr.zu_664  lv.tt.lt_543 fj.wo.uz_644 
  0x56000405, 0x2928fc0c, 0x3d3c23a7, 0x534f24a7,   // fi.mg.un_330 zzp.sw.sl_543  ky.ug.ku_532 eo.bi.ht_532 
  0x6813fc0b, 0x5d006505, 0x252813a9, 0xfe2e540c,   // zzp.et.ig_542 gv.ss.un_330  et.sw.eu_544 ik.fo.tlh_543 
  0x09001f09, 0x15044808, 0x6342260c, 0x44231809,   // cy.pl.un_440 tt.ru.un_443  ia.co.sco_543 ar.ky.kk_444 
  // [e0c0]
  0x0e003919, 0x39001204, 0x26100f5a, 0x040a10a0,   // br.is.un_750 hu.br.un_320  lv.lt.ia_553 be.mk.ru_322 
  0x30003907, 0x6003fa07, 0x17232260, 0x28291708,   // br.uz.un_420 nr.nl.vo_432  oc.ca.sr_664 sr.sl.sw_443 
  0x22033f0c, 0x3e000302, 0x043954a9, 0x282112af,   // af.nl.oc_543 nl.rm.un_220  ik.br.fi_544 ur.fa.sd_655 
  0x1200200c, 0x3c003708, 0x0700112a, 0x21003204,   // sq.hu.un_530 ba.ug.un_430  ro.bg.un_970 bs.jw.un_320 
  // [e0d0]
  0x0c33fc07, 0x033f2104, 0x2438200c, 0x360d2da4,   // zzp.nn.sv_432 jw.af.nl_332  sq.tk.eo_543 sk.cs.gn_433 
  0x10000d0d, 0x5c00691b, 0x0900fe13, 0x3d123407,   // cs.lt.un_540 mfe.sa.un_770  tlh.pl.un_650 ps.ur.ku_432 
  0x0a1723ee, 0x04353cee, 0x0c00fc0d, 0x0900fc02,   // ky.sr.mk_422 ug.tg.ru_422  zzp.sv.un_540 zzp.pl.un_220 
  0x303c2307, 0x3c153004, 0x02000807, 0x6e002013,   // ky.ug.uz_432 uz.ug.un_320  no.da.un_420 sq.hmn.un_650 
  // [e0e0]
  0x57495aad, 0x565f4712, 0x0b000a04, 0x22151d05,   // sm.to.na_643 sn.tn.mg_654  pt.es.un_320 la.oc.un_330 
  0x04001204, 0x2f1e04a7, 0x0c304d08, 0x325647ee,   // hu.fi.un_320 fi.ms.su_532  aa.uz.sv_443 sn.mg.bs_422 
  0x2300341a, 0x39000e02, 0x2c001b04, 0x495a0e07,   // ps.ky.un_760 is.br.un_220  tr.fy.un_320 is.sm.to_432 
  0x3f590504, 0x2b000907, 0x153611a4, 0x51fc2a60,   // fr.rn.af_332 pl.vi.un_420  ro.ab.un_433 mt.zzp.kl_664 
  // [e0f0]
  0x041d39ee, 0x11033f08, 0x1500430c, 0x44233814,   // br.la.fi_422 af.nl.ro_443  ie.un.un_530 tk.ky.kk_666 
  0x1d79010c, 0x3f001e04, 0x193f4307, 0x22182302,   // en.war.la_543 ms.af.un_320  ie.af.gl_432 ca.ga.oc_222 
  0x2a1d01a4, 0x12231804, 0x1e000a07, 0x35233809,   // en.la.mt_433 ga.ca.hu_332  pt.ms.un_420 tk.ky.tg_444 
  0xfc651b07, 0x4a002208, 0x1200220c, 0x18001902,   // tr.gv.zzp_432 oc.yo.un_430  oc.hu.un_530 gl.ga.un_220 
  // [e100]
  0x100f29ec, 0x22055607, 0x101632a0, 0x073e2aa9,   // sl.lv.lt_644 mg.fr.oc_432  bs.hr.lt_322 mt.rm.it_544 
  0x182212a9, 0x253c300c, 0x53004b05, 0x5c217904,   // hu.oc.ga_544 uz.ug.mn_543  mi.ht.un_330 war.jw.sa_332 
  0x321617ac, 0x3d2130a9, 0x3b000607, 0x3b001004,   // sr.hr.bs_632 uz.fa.ku_544  de.so.un_420 lt.so.un_320 
  0x3b006b09, 0x2d190b04, 0x0a3510a0, 0x303c440b,   // ceb.so.un_440 es.gl.sk_332  be.tg.mk_322 kk.ug.uz_542 
  // [e110]
  0x240436a0, 0x470464af, 0x18155f07, 0x4f003308,   // gn.fi.eo_322 lg.fi.sn_655  tn.ga.un_420 nn.bi.un_430 
  0x48400cac, 0x112d1007, 0x2c354707, 0x40003602,   // sv.lb.tt_632 lt.sk.ro_432  sn.zu.fy_432 gn.lb.un_220 
  0x78045107, 0x21343dec, 0x4b0e33a4, 0x521c1eec,   // kl.fi.ve_432 ku.ps.fa_644  nn.is.mi_433 ms.id.ha_644 
  0x1c2f1ead, 0x62005208, 0x252f53ee, 0x080407af,   // ms.su.id_643 ha.kha.un_430  ht.su.eu_422 bg.ru.uk_655 
  // [e120]
  0x493202a4, 0x53005807, 0x32025211, 0x42002511,   // da.bs.to_433 om.ht.un_420  ha.da.bs_653 eu.co.un_630 
  0x1b000222, 0x6a464b0c, 0x10002904, 0x5e005208,   // da.tr.un_870 mi.qu.haw_543  sl.lt.un_320 ha.ts.un_430 
  0x15234460, 0x08001807, 0x7900510d, 0x361504a4,   // kk.ky.un_664 ga.no.un_420  kl.war.un_540 ru.ab.un_430 
  0x34537604, 0x3f5376a7, 0x17161005, 0x10084455,   // crs.ht.xh_332 crs.ht.af_532  lt.hr.sr_333 kk.uk.be_442 
  // [e130]
  0x5a4751ad, 0x513f46a0, 0x4810080d, 0x044951ee,   // kl.sn.sm_643 qu.af.kl_322  uk.be.tt_554 kl.to.fi_422 
  0x496a40ee, 0x462d10ad, 0x5c005104, 0x442818ee,   // lb.haw.to_422 lt.sk.qu_643  kl.sa.un_320 ar.sd.kk_422 
  0x453f69af, 0x15074407, 0x58004602, 0x5a4951a6,   // mfe.af.ln_655 kk.bg.un_432  qu.om.un_220 kl.to.sm_521 
  0x10001605, 0x130451a9, 0x041030a0, 0x496a670c,   // hr.lt.un_330 kl.fi.et_544  uz.be.ru_322 ak.haw.to_543 
  // [e140]
  0x6b001e07, 0x15233805, 0x33005102, 0x2e530ea0,   // ms.ceb.un_420 tk.ky.un_333  kl.nn.un_220 is.ht.fo_322 
  0x34001b21, 0x1f00231a, 0x4213040c, 0x18213055,   // tr.xh.un_860 ca.cy.un_760  fi.et.co_543 uz.fa.ar_442 
  0x20406308, 0x65793ead, 0x49006404, 0x5868670c,   // sco.lb.sq_443 rm.war.gv_643  lg.to.un_320 ak.ig.om_543 
  0x65041da0, 0x2c271dee, 0x4b583b07, 0x43021daf,   // la.fi.gv_322 la.gd.fy_422  so.om.mi_432 la.da.ie_655 
  // [e150]
  0x46003205, 0x010402a0, 0x1d004312, 0x1d003f05,   // bs.qu.un_330 da.fi.en_322  ie.la.un_640 af.la.un_330 
  0x05004012, 0x0c0833a4, 0x46000d0d, 0x02001d1a,   // lb.fr.un_640 nn.no.sv_433  cs.qu.un_540 la.da.un_760 
  0x07114404, 0x43001d14, 0x22002320, 0x0500600c,   // kk.ro.bg_332 la.ie.un_660  ca.oc.un_850 vo.fr.un_530 
  0x234205a4, 0x01001d0b, 0x16284aa7, 0x2c001d0d,   // fr.co.ca_433 la.en.un_520  yo.sw.hr_532 la.fy.un_540 
  // [e160]
  0x46321602, 0x3f003504, 0x311b4860, 0x345d3508,   // hr.bs.qu_222 zu.af.un_320  tt.tr.az_664 zu.ss.xh_443 
  0x02004a18, 0x01634307, 0xfc151d0e, 0x320c0955,   // yo.da.un_740 ie.sco.en_432  la.zzp.un_550 pl.sv.bs_442 
  0x484404a7, 0x08071505, 0x062c0107, 0x1f004c04,   // ru.kk.tt_532 un.bg.uk_333  en.fy.de_432 wo.cy.un_320 
  0x29006307, 0x481b3111, 0x65000904, 0x30072355,   // sco.sl.un_420 az.tr.tt_653  pl.gv.un_320 ky.bg.uz_442 
  // [e170]
  0x30004f04, 0x6263010b, 0x63003304, 0x43030608,   // bi.uz.un_320 en.sco.kha_542  nn.sco.un_320 de.nl.ie_443 
  0x070a25a0, 0x29002008, 0x0f3e3fa7, 0x15181da0,   // mn.mk.bg_322 sq.sl.un_430  af.rm.lv_532 la.ga.un_322 
  0x28001b07, 0x1d00111a, 0x3c00250e, 0x1200341a,   // tr.sw.un_420 ro.la.un_760  mn.ug.un_550 ps.ur.un_760 
  0x0a07150b, 0xfc1dfe07, 0x02004908, 0x44003714,   // un.bg.mk_542 tlh.la.zzp_432  to.da.un_430 ba.kk.un_660 
  // [e180]
  0x311b7312, 0x482344ec, 0x4a562fa0, 0x4d00120e,   // ny.tr.az_654 kk.ky.tt_644  su.mg.yo_322 hu.aa.un_550 
  0x28006409, 0x3100280d, 0x25372307, 0x48003f02,   // lg.sw.un_440 sw.az.un_540  ky.ba.mn_432 af.tt.un_220 
  0x4400280d, 0x4a5955ad, 0x35190bee, 0x79606b0c,   // sd.kk.un_540 rw.rn.yo_643  es.gl.zu_422 ceb.vo.war_543 
  0x0b5955ad, 0x15170804, 0x3b2a4ca4, 0x552f45ad,   // rw.rn.es_643 uk.sr.un_332  wo.mt.so_433 ln.su.rw_643 
  // [e190]
  0x37455d0d, 0x69595508, 0x645509ad, 0x4a003b04,   // ss.ln.st_554 rw.rn.mfe_443  pl.rw.lg_643 so.yo.un_320 
  0x4a470207, 0x31171602, 0x2f3b4da4, 0x2f391c0c,   // da.sn.yo_432 hr.sr.az_222  aa.so.su_433 id.br.su_543 
  0x130273ee, 0x29006b21, 0x5e004c21, 0x354a3404,   // ny.da.et_422 ceb.sl.un_860  wo.ts.un_860 xh.yo.zu_332 
  0x5900551a, 0x2f005c13, 0x5d5955ec, 0xfe00280c,   // rw.rn.un_760 sa.su.un_650  rw.rn.ss_644 sw.tlh.un_530 
  // [e1a0]
  0x595557a4, 0x2d091f11, 0x3400120b, 0x0d2d090b,   // na.rw.rn_433 cy.pl.sk_653  ur.ps.un_520 pl.sk.cs_542 
  0x19120ba4, 0x25444855, 0x15150411, 0x28123da7,   // es.hu.gl_433 tt.kk.mn_442  ru.un.un_630 ku.ur.sd_532 
  0x302315a9, 0x48002523, 0x345d4c0c, 0x285249ee,   // un.ky.uz_544 mn.tt.un_880  wo.ss.xh_543 to.ha.sw_422 
  0x0147fcee, 0x170a08a9, 0x244f60af, 0x0e2e0da7,   // zzp.sn.en_422 uk.mk.sr_544  vo.bi.eo_655 cs.fo.is_532 
  // [e1b0]
  0x040c5b05, 0x471230a4, 0x630501a4, 0x3044370d,   // sg.sv.fi_333 uz.hu.sn_433  en.fr.sco_433 ba.kk.uz_554 
  0x02471b04, 0x23003519, 0x320e280c, 0x1540fc07,   // tr.sn.da_332 tg.ky.un_750  sw.is.bs_543 zzp.lb.un_432 
  0x1004150b, 0x05004c08, 0x063e31a0, 0x33401d04,   // un.ru.be_542 wo.fr.un_430  az.rm.de_322 la.lb.nn_332 
  0x2a024314, 0x3f222504, 0x49043708, 0x06004304,   // ie.da.mt_666 eu.oc.af_332  st.fi.to_443 ie.de.un_320 
  // [e1c0]
  0x2a003707, 0x5f370312, 0x0715360c, 0x3f695312,   // st.mt.un_420 nl.st.tn_654  ab.bg.un_530 ht.mfe.af_654 
  0x375f13ec, 0x173f60ec, 0x09122502, 0x431f60ec,   // et.tn.st_644 vo.af.sr_644  eu.hu.pl_222 vo.cy.ie_644 
  0x5c005309, 0x23110107, 0x3f5f370c, 0x1f1d3f13,   // ht.sa.un_440 en.ro.ca_432  st.tn.af_543 af.la.cy_665 
  0x032c1fec, 0x436a26a4, 0x17043607, 0x3d18340d,   // cy.fy.nl_644 ia.haw.ie_433  ab.ru.sr_432 ps.ar.ku_554 
  // [e1d0]
  0x2c2103ad, 0x53604f0c, 0x693f13a4, 0x2a001b13,   // nl.jw.fy_643 bi.vo.ht_543  et.af.mfe_433 tr.mt.un_650 
  0xfc401d04, 0x3f561309, 0x04072507, 0x04153ca0,   // la.lb.zzp_332 et.mg.af_444  mn.bg.ru_432 ug.ru.un_320 
  0x2330110c, 0x4a003619, 0x4d545808, 0x4a000404,   // ro.uz.ky_543 gn.yo.un_750  om.ik.aa_443 fi.yo.un_320 
  0x4600310c, 0x1c130dec, 0x21123ba9, 0x2500352a,   // az.qu.un_530 ne.bh.mr_644  ks.ur.fa_544 tg.mn.un_970 
  // [e1e0]
  0x461bfe04, 0x21342802, 0x47734909, 0x042434a0,   // tlh.tr.qu_332 sd.ps.fa_222  to.ny.sn_444 xh.eo.fi_322 
  0x0400280d, 0x04004913, 0x4831fe13, 0x28343007,   // sw.fi.un_540 to.fi.un_650  tlh.az.tt_665 uz.ps.sd_432 
  0x53381bee, 0x11002102, 0x4b000413, 0x10000909,   // tr.tk.ht_422 jw.ro.un_220  fi.mi.un_650 pl.lt.un_440 
  0x0a0738ec, 0x39605304, 0x1d005812, 0x56006507,   // tk.bg.mk_644 ht.vo.br_332  om.la.un_640 gv.mg.un_420 
  // [e1f0]
  0x36001e08, 0x28213d55, 0xfc150302, 0x42686b04,   // ms.gn.un_430 ku.fa.sd_442  nl.zzp.un_220 ceb.ig.co_332 
  0x35033404, 0x22650507, 0x46000519, 0x210802a4,   // xh.nl.zu_332 fr.gv.oc_432  fr.qu.un_750 da.no.jw_433 
  0x2300fc04, 0x1b001209, 0x15002514, 0x300415ee,   // zzp.ca.un_320 hu.tr.un_440  mn.un.un_660 un.ru.uz_422 
  0x3b2afe05, 0x350436a0, 0x1d00060b, 0x5c1309a7,   // tlh.mt.so_333 ab.ru.tg_322  de.la.un_520 hi.bh.sa_532 
  // [e200]
  0x0811100e, 0x302335a7, 0x04001536, 0x23153c5a,   // be.ro.uk_555 tg.ky.uz_532  un.ru.un_AA0 ug.ky.un_530 
  0x17004829, 0x2efc2aa0, 0x123f48a0, 0x541e1c0d,   // tt.sr.un_960 mt.zzp.fo_322  tt.af.hu_322 id.ms.ik_554 
  0x3f003808, 0x0c4c5112, 0x20003b02, 0x1700081a,   // tk.af.un_430 kl.wo.sv_654  so.sq.un_220 uk.sr.un_760 
  0x04001b04, 0x431d2207, 0x422450a4, 0x12002309,   // tr.fi.un_320 oc.la.ie_432  fj.eo.co_433 ca.hu.un_440 
  // [e210]
  0x30fe69a4, 0x025d50a4, 0x2420fea7, 0x3e424704,   // mfe.tlh.uz_433 fj.ss.da_433  tlh.sq.eo_532 sn.co.rm_332 
  0x2e002302, 0x3b281da4, 0x093b0207, 0x46005d13,   // ca.fo.un_220 la.sw.so_433  da.so.pl_432 ss.qu.un_650 
  0x30341212, 0x69007621, 0x0a1711a4, 0x1500440d,   // ur.ps.uz_654 crs.mfe.un_860  ro.sr.mk_433 kk.un.un_540 
  0x150417ec, 0x65323ea0, 0x320d09a7, 0x5c1d2da0,   // sr.ru.un_644 rm.bs.gv_322  pl.cs.bs_532 sk.la.sa_322 
  // [e220]
  0x5d000204, 0x15112b04, 0x0a2f2407, 0x2d2029ad,   // da.ss.un_320 vi.ro.un_332  eo.su.pt_432 sl.sq.sk_643 
  0x11230504, 0x2b2315ee, 0x04441060, 0x356434a4,   // fr.ca.ro_332 un.ca.vi_422  be.kk.ru_664 xh.lg.zu_433 
  0x37043002, 0x39002205, 0x39006b04, 0x1f006405,   // uz.ru.ba_222 oc.br.un_330  ceb.br.un_320 lg.cy.un_330 
  0x07000602, 0x44231811, 0x20001005, 0xfe2b120e,   // de.it.un_220 ar.ky.kk_653  lt.sq.un_330 hu.vi.tlh_555 
  // [e230]
  0x3948450c, 0x53002504, 0x313806ee, 0x30023b07,   // ln.tt.br_543 eu.ht.un_320  de.tk.az_422 so.da.uz_432 
  0x2f000e0d, 0x40030602, 0x3000fe09, 0x3815360c,   // is.su.un_540 de.nl.lb_222  tlh.uz.un_440 ab.tk.un_530 
  0x34fc2507, 0x2a00090c, 0x05001507, 0x3e313007,   // eu.zzp.xh_432 pl.mt.un_530  un.fr.un_420 uz.az.rm_432 
  0x5e00fc08, 0x222927ee, 0x11033f12, 0x48303b12,   // zzp.ts.un_430 gd.sl.oc_422  af.nl.ro_654 so.uz.tt_654 
  // [e240]
  0x3d002314, 0x026330a4, 0x65290cee, 0x04100702,   // ky.ku.un_660 uz.sco.da_433  sv.sl.gv_422 bg.be.ru_222 
  0x23484404, 0x6b340404, 0x04003412, 0x53003604,   // kk.tt.ky_332 fi.xh.ceb_332  xh.fi.un_640 gn.ht.un_320 
  0x27002a07, 0x425604a0, 0x3f000e0d, 0x5115460c,   // mt.gd.un_420 fi.mg.co_322  is.af.un_540 qu.kl.un_530 
  0x56330cad, 0x1f002012, 0x1f00620e, 0x080203a4,   // sv.nn.mg_643 sq.cy.un_640  kha.cy.un_550 nl.da.no_433 
  // [e250]
  0x1a06fca0, 0x34183c0c, 0x2a00300e, 0x654c5811,   // zzp.de.tl_322 ug.ar.ps_543  uz.mt.un_550 om.wo.gv_653 
  0x48233808, 0x3507150c, 0x21231805, 0x4600fc04,   // tk.ky.tt_443 un.bg.tg_543  ar.ky.fa_333 zzp.qu.un_320 
  0x373c380c, 0x080a1505, 0x18343004, 0x19251dee,   // tk.ug.ba_543 un.mk.uk_333  uz.ps.ar_332 la.eu.gl_422 
  0x182834a7, 0x60003308, 0x02000102, 0x03253f02,   // ps.sd.ar_532 nn.vo.un_430  en.da.un_220 af.eu.nl_222 
  // [e260]
  0x15254407, 0x4b005c09, 0x1e003f04, 0x13004007,   // kk.mn.un_432 sa.mi.un_440  af.ms.un_320 lb.et.un_420 
  0x033f2c05, 0x40033f05, 0x0c001604, 0x30792a0c,   // fy.af.nl_333 af.nl.lb_333  hr.sv.un_320 mt.war.uz_543 
  0x123430ec, 0x4830355a, 0x2b35345a, 0x5d4afc11,   // uz.ps.ur_644 tg.uz.tt_553  xh.zu.vi_553 zzp.yo.ss_653 
  0x2b2703a0, 0x217362ad, 0x38481b07, 0x2b001807,   // nl.gd.vi_322 kha.ny.jw_643  tr.tt.tk_432 ga.vi.un_420 
  // [e270]
  0x52000302, 0x0a08040d, 0x55fc5d04, 0x2f1c30a4,   // nl.ha.un_220 ru.uk.mk_554  ss.zzp.rw_332 uz.id.su_433 
  0x353015ee, 0x462b1fa7, 0x55005d05, 0x15100408,   // un.uz.tg_422 cy.vi.qu_532  ss.rw.un_330 ru.be.un_443 
  0x0817040c, 0x0c006507, 0x56007307, 0x49180902,   // ru.sr.uk_543 gv.sv.un_420  ny.mg.un_420 pl.ga.to_222 
  0x5a002812, 0x28004913, 0x16007904, 0x37004604,   // sw.sm.un_640 to.sw.un_650  war.hr.un_320 qu.st.un_320 
  // [e280]
  0x210c1204, 0x51203507, 0x4d672a08, 0x2a481a0c,   // hu.sv.jw_332 zu.sq.kl_432  mt.ak.aa_443 tl.tt.mt_543 
  0x79382fa4, 0x560749a4, 0x100a15a9, 0x0d022d0b,   // su.tk.war_433 to.it.mg_433  un.mk.be_544 sk.da.cs_542 
  0x0a303514, 0x353431a4, 0x123c30ad, 0x2d1029a4,   // tg.uz.mk_666 az.xh.zu_433  uz.ug.ur_643 sl.lt.sk_433 
  0x56002205, 0x792f1e55, 0x35004c0c, 0x30001e02,   // oc.mg.un_330 ms.su.war_442  wo.zu.un_530 ms.uz.un_220 
  // [e290]
  0xfc3f0313, 0x1b002009, 0x4e002a0e, 0x1e496a0c,   // nl.af.zzp_665 sq.tr.un_440  mt.ay.un_550 haw.to.ms_543 
  0x4b00131a, 0x16362d07, 0x0e10fea4, 0x49134604,   // et.mi.un_760 sk.gn.hr_432  tlh.lt.is_433 qu.et.to_332 
  0x400461af, 0x2f5f13ad, 0x2e00150c, 0x150410a4,   // za.fi.lb_655 et.tn.su_643  un.fo.un_530 be.ru.un_433 
  0x39047304, 0x5f371fa4, 0x751d18a9, 0x040a25ad,   // ny.fi.br_332 cy.st.tn_433  ga.la.nso_544 mn.mk.ru_643 
  // [e2a0]
  0x4408110c, 0x1f611da4, 0x2f1c76ee, 0x0f004b11,   // ro.uk.kk_543 la.za.cy_433  crs.id.su_422 mi.lv.un_630 
  0xfe401208, 0x40003605, 0x48043811, 0x4b02490c,   // hu.lb.tlh_443 gn.lb.un_330  tk.ru.tt_653 to.da.mi_543 
  0x0f104b04, 0x496a52a4, 0x59455209, 0x1d20460c,   // mi.lt.lv_332 ha.haw.to_433  ha.ln.rn_444 qu.sq.la_543 
  0x10003907, 0x3c38440c, 0x210369ee, 0x25001113,   // br.lt.un_420 kk.tk.ug_543  mfe.nl.jw_422 ro.mn.un_650 
  // [e2b0]
  0x48152307, 0x04002f0d, 0x522c33ee, 0x59556aa9,   // ky.tt.un_420 su.fi.un_540  nn.fy.ha_422 haw.rw.rn_544 
  0x1d3e4fad, 0x1f00370c, 0x2f2149ad, 0x040208a9,   // bi.rm.la_643 st.cy.un_530  to.jw.su_643 no.da.fi_544 
  0x4b4f1f55, 0x57494f05, 0x2e00020e, 0x5a000f0b,   // cy.bi.mi_442 bi.to.na_333  da.fo.un_550 lv.sm.un_520 
  0x1a6a4908, 0x373b4ba0, 0x24003012, 0x063f0307,   // to.haw.tl_443 mi.so.st_322  uz.eo.un_640 nl.af.de_432 
  // [e2c0]
  0x46002019, 0x54001e08, 0x3f514ca9, 0x29190b04,   // sq.qu.un_750 ms.ik.un_430  wo.kl.af_544 es.gl.sl_332 
  0x033951ad, 0x3f405455, 0x2c5139ad, 0x17000b08,   // kl.br.nl_643 ik.lb.af_442  br.kl.fy_643 es.sr.un_430 
  0x045130ad, 0xfc036502, 0x511e4ca0, 0x4c545111,   // uz.kl.fi_643 gv.nl.zzp_222  wo.ms.kl_322 kl.ik.wo_653 
  0x0400110d, 0x3f034cee, 0x03001521, 0x6e1022a9,   // ro.ru.un_540 wo.nl.af_422  un.nl.un_860 oc.lt.hmn_544 
  // [e2d0]
  0x0417085a, 0x4c5b54ec, 0x3c003513, 0x393f510c,   // uk.sr.ru_553 ik.sg.wo_644  tg.ug.un_650 kl.af.br_543 
  0x3f54510c, 0x3f035109, 0x394051a9, 0x042f5112,   // kl.ik.af_543 kl.nl.af_444  kl.lb.br_544 kl.su.fi_654 
  0x442315af, 0x0f5c100c, 0x234825a9, 0x10001505,   // un.ky.kk_655 lt.sa.lv_543  mn.tt.ky_544 un.be.un_330 
  0x46001805, 0x3e002b12, 0x10070a07, 0x48383c11,   // ga.qu.un_330 vi.rm.un_640  mk.bg.be_432 ug.tk.tt_653 
  // [e2e0]
  0x061b3102, 0x30122109, 0x313812b2, 0x21782fa4,   // az.tr.de_222 fa.ur.uz_444  hu.tk.az_732 su.ve.jw_433 
  0x40006a0c, 0x4b1a2f04, 0x3b006b08, 0x281a5908,   // haw.lb.un_530 su.tl.mi_332  ceb.so.un_430 rn.tl.sw_443 
  0x65286404, 0x6e011f07, 0x381261ac, 0x135479a4,   // lg.sw.gv_332 cy.en.hmn_432  za.hu.tk_632 war.ik.et_433 
  0xfc001f08, 0x1f3b2a05, 0x20003904, 0x1a7955a0,   // cy.zzp.un_430 mt.so.cy_333  br.sq.un_320 rw.war.tl_322 
  // [e2f0]
  0x1f695f55, 0x37154804, 0x755f2a08, 0x48006008,   // tn.mfe.cy_442 tt.ba.un_320  mt.tn.nso_443 vo.tt.un_430 
  0x355d5505, 0x524afe07, 0x5d353fa4, 0x2f285507,   // rw.ss.zu_333 tlh.yo.ha_432  af.zu.ss_433 rw.sw.su_432 
  0x2f4b13a0, 0x38561b12, 0x2a5e5d12, 0x374404ad,   // et.mi.su_322 tr.mg.tk_654  ss.ts.mt_654 ru.kk.ba_643 
  0x1b313804, 0x2d290dad, 0x0a071002, 0x38311b07,   // tk.az.tr_332 cs.sl.sk_643  be.bg.mk_222 tr.az.tk_432 
  // [e300]
  0x0c0234ad, 0x1800471a, 0x2e0e180c, 0x2c393f02,   // xh.da.sv_643 sn.ga.un_760  ga.is.fo_543 af.br.fy_222 
  0x036b3f04, 0x40610307, 0x3200610c, 0x374836ee,   // af.ceb.nl_332 nl.za.lb_432  za.bs.un_530 ab.tt.ba_422 
  0x40001f0e, 0x61033f08, 0x0e0c2e0b, 0x3f002105,   // cy.lb.un_550 af.nl.za_443  fo.sv.is_542 jw.af.un_330 
  0x32002404, 0x07002511, 0x46233907, 0x04025c04,   // eo.bs.un_320 mn.bg.un_630  br.ca.qu_432 sa.da.fi_332 
  // [e310]
  0x4349220c, 0x48033f55, 0x26475ca9, 0x134b5c07,   // oc.to.ie_543 af.nl.tt_442  sa.sn.ia_544 sa.mi.et_432 
  0x483e0602, 0x0a5c0ba4, 0x37480455, 0x40180602,   // de.rm.tt_222 es.sa.pt_433  ru.tt.ba_442 de.ga.lb_222 
  0x243602a9, 0x4d51540c, 0x2a2847af, 0x285c6012,   // da.gn.eo_544 ik.kl.aa_543  sn.sw.mt_655 vo.sa.sw_654 
  0x06201dee, 0x31005e0c, 0x250f43a9, 0x60047305,   // la.sq.de_422 ts.az.un_530  ie.lv.eu_544 ny.fi.vo_333 
  // [e320]
  0x5c362805, 0x4b000f04, 0x31004613, 0x394a0204,   // sw.gn.sa_333 lv.mi.un_320  qu.az.un_650 da.yo.br_332 
  0x39000e07, 0x54002a13, 0x21123d11, 0x54514ead,   // is.br.un_420 mt.ik.un_650  ku.ur.fa_653 ay.kl.ik_643 
  0x09002802, 0x564b250c, 0x650c1da0, 0x4b254aad,   // sw.pl.un_220 eu.mi.mg_543  la.sv.gv_322 yo.eu.mi_643 
  0x0f630107, 0x2c005013, 0x021dfcaf, 0x25006402,   // en.sco.lv_432 fj.fy.un_650  zzp.la.da_655 lg.eu.un_220 
  // [e330]
  0x1b3113ee, 0x09004808, 0x285564a0, 0x1b4831a7,   // et.az.tr_422 tt.pl.un_430  lg.rw.sw_322 az.tt.tr_532 
  0x0c684907, 0x2f5e1ca9, 0x12000612, 0x254c04ec,   // to.ig.sv_432 id.ts.su_544  de.hu.un_640 fi.wo.eu_644 
  0x57522508, 0x4033480c, 0x37756a08, 0x04481107,   // eu.ha.na_443 tt.nn.lb_543  haw.nso.st_443 ro.tt.ru_432 
  0x48001319, 0x02383004, 0x1b375f11, 0x25752013,   // et.tt.un_750 uz.tk.da_332  tn.st.tr_653 sq.nso.eu_665 
  // [e340]
  0xfe3831a0, 0x19114d0e, 0x09001c2a, 0x5376250c,   // az.tk.tlh_322 aa.ro.gl_555  mr.hi.un_970 eu.crs.ht_543 
  0x13123e11, 0x0c492404, 0x3500590d, 0x38005712,   // rm.hu.et_653 eo.to.sv_332  rn.zu.un_540 na.tk.un_640 
  0x1e000208, 0x373c4411, 0x01792a07, 0x0a041708,   // da.ms.un_430 kk.ug.ba_653  mt.war.en_432 sr.ru.mk_443 
  0x1b311313, 0x01002a08, 0x02000b04, 0x1b001d07,   // et.az.tr_665 mt.en.un_430  es.da.un_320 la.tr.un_420 
  // [e350]
  0x120c30a4, 0x22502313, 0x38303109, 0x67002a0e,   // uz.sv.hu_433 ca.fj.oc_665  az.uz.tk_444 mt.ak.un_550 
  0x374536af, 0x4c735dad, 0x3023445a, 0x50004f14,   // gn.ln.st_655 ss.ny.wo_643  kk.ky.uz_553 bi.fj.un_660 
  0x22235f09, 0x16001102, 0x2a0946a4, 0x1b4d1107,   // tn.ca.oc_444 ro.hr.un_220  qu.pl.mt_433 ro.aa.tr_432 
  0x381b31af, 0x22302304, 0x3d21280c, 0x2a00090d,   // az.tr.tk_655 ca.uz.oc_332  sd.fa.ku_543 pl.mt.un_540 
  // [e360]
  0x0400300c, 0x3036385a, 0x36001513, 0x054a5312,   // uz.ru.un_530 tk.ab.uz_553  un.ab.un_650 ht.yo.fr_654 
  0x1b380604, 0x42000518, 0x53054a0c, 0x5f007522,   // de.tk.tr_332 fr.co.un_740  yo.fr.ht_543 nso.tn.un_870 
  0x37041007, 0x3b004c1b, 0x58006507, 0x656e13a4,   // be.ru.ba_432 wo.so.un_770  gv.om.un_420 et.hmn.gv_433 
  0x03002105, 0x102544a4, 0x3500440c, 0x1c003b05,   // jw.nl.un_330 kk.mn.be_433  kk.tg.un_530 so.id.un_330 
  // [e370]
  0x3534fc09, 0x4c205b0d, 0x67002d13, 0x33000304,   // zzp.xh.zu_444 sg.sq.wo_554  sk.ak.un_650 nl.nn.un_320 
  0x2c2903ee, 0x13006e07, 0x1300600d, 0x453767a9,   // nl.sl.fy_422 hmn.et.un_420  vo.et.un_540 ak.st.ln_544 
  0x1b48130c, 0x13006e0c, 0x1200130d, 0x343021ec,   // et.tt.tr_543 hmn.et.un_530  et.hu.un_540 fa.uz.ps_644 
  0x211b1107, 0x151015ee, 0x33081fec, 0x28391802,   // ro.tr.jw_432 un.be.un_422  cy.no.nn_644 ga.br.sw_222 
  // [e380]
  0x44482305, 0x58003b0e, 0x192f4fee, 0x39006912,   // ky.tt.kk_333 so.om.un_550  bi.su.gl_422 mfe.br.un_640 
  0x5100541a, 0x3408fca0, 0x12001f0e, 0x55051d04,   // ik.kl.un_760 zzp.no.xh_322  cy.hu.un_550 la.fr.rw_332 
  0x02001f0d, 0x0363010c, 0x15171507, 0x51005419,   // cy.da.un_540 en.sco.nl_543  un.sr.un_432 ik.kl.un_750 
  0x63154012, 0x1d001502, 0x23113eec, 0x12001b19,   // lb.sco.un_640 un.la.un_220  rm.ro.ca_644 tr.hu.un_750 
  // [e390]
  0x2c003f22, 0x2e001802, 0x1d072204, 0x3f651f14,   // af.fy.un_870 ga.fo.un_220  oc.it.la_332 cy.gv.af_666 
  0x121a6b55, 0x511d540b, 0x5400512b, 0x63000119,   // ceb.tl.hu_442 ik.la.kl_542  kl.ik.un_980 en.sco.un_750 
  0x050601a7, 0x1b3106ee, 0x3e1306a4, 0x2e004309,   // en.de.fr_532 de.az.tr_422  de.et.rm_433 ie.fo.un_440 
  0x183b2704, 0x35341fee, 0x3700010d, 0x110722a0,   // gd.so.ga_332 cy.xh.zu_422  en.st.un_540 oc.it.ro_322 
  // [e3a0]
  0x4222fc04, 0x3f0a40a0, 0x0a001023, 0x3d001807,   // zzp.oc.co_332 lb.pt.af_322  be.mk.un_880 ar.ku.un_420 
  0x1f234804, 0x355d2808, 0x3823445a, 0x023b62a4,   // tt.ca.cy_332 sw.ss.zu_443  kk.ky.tk_553 kha.so.da_433 
  0x284722a9, 0x303f2108, 0x5c0c54ee, 0x1b3831a7,   // oc.sn.sw_544 jw.af.uz_443  ik.sv.sa_422 az.tk.tr_532 
  0x33020ca4, 0x08002004, 0x5c0a3f07, 0x02003002,   // sv.da.nn_433 sq.no.un_320  af.pt.sa_432 uz.da.un_220 
  // [e3b0]
  0x30001e0c, 0x483725ad, 0x30001204, 0x287378ee,   // ms.uz.un_530 mn.ba.tt_643  hu.uz.un_320 ve.ny.sw_422 
  0x482b1fac, 0x35001e02, 0x10005307, 0x38300402,   // cy.vi.tt_632 ms.zu.un_220  ht.lt.un_420 fi.uz.tk_222 
  0x31006113, 0x24562811, 0x03002104, 0x223e1fa4,   // za.az.un_650 sw.mg.eo_653  jw.nl.un_320 cy.rm.oc_433 
  0x2840470c, 0x20330804, 0x64390107, 0x18330802,   // sn.lb.sw_543 no.nn.sq_332  en.br.lg_432 no.nn.ga_222 
  // [e3c0]
  0x28200207, 0x3d001812, 0x46001e12, 0x320f17a4,   // da.sq.sw_432 ar.ku.un_640  ms.qu.un_640 sr.lv.bs_433 
  0x2f004619, 0x05003002, 0x170723a0, 0x02007605,   // qu.su.un_750 uz.fr.un_220  ky.bg.sr_322 crs.da.un_330 
  0x04795713, 0x2e122d11, 0x477352a4, 0x28353404,   // na.war.fi_665 sk.hu.fo_653  ha.ny.sn_433 xh.zu.sw_332 
  0x041715ee, 0x1044230c, 0x024311a0, 0x0e4928a0,   // un.sr.ru_422 ky.kk.be_543  ro.ie.da_322 sw.to.is_322 
  // [e3d0]
  0x3c153005, 0x20232f08, 0x6200502b, 0x16004505,   // uz.ug.un_330 su.ca.sq_443  fj.kha.un_980 ln.hr.un_330 
  0xfe00621a, 0x42455dad, 0x01fc57a0, 0x4d004514,   // kha.tlh.un_760 ss.ln.co_643  na.zzp.en_322 ln.aa.un_660 
  0x170a35a4, 0x2f00020c, 0x6b43610c, 0x2f000404,   // tg.mk.sr_433 da.su.un_530  za.ie.ceb_543 fi.su.un_320 
  0x01155407, 0x11150408, 0x0e1d420b, 0x1300491b,   // ik.en.un_420 ru.ro.un_430  co.la.is_542 to.et.un_770 
  // [e3e0]
  0x23211505, 0x42100fad, 0x1f4c62a4, 0x48007304,   // un.jw.ca_333 lv.lt.co_643  kha.wo.cy_433 ny.tt.un_320 
  0x47211e05, 0x652015a0, 0xfe5320ee, 0x483723ad,   // ms.jw.sn_333 un.sq.gv_322  sq.ht.tlh_422 ky.ba.tt_643 
  0x3b1221a4, 0x374448ad, 0x23383004, 0x1600fe04,   // fa.ur.ks_433 tt.kk.ba_643  uz.tk.ky_332 tlh.hr.un_320 
  0x29005313, 0x55381b04, 0x3b004d23, 0x321653a0,   // ht.sl.un_650 tr.tk.rw_332  aa.so.un_880 ht.hr.bs_322 
  // [e3f0]
  0x3c1117a4, 0x1c212fa0, 0x3c231205, 0x4c52460c,   // sr.ro.ug_433 su.jw.id_322  ur.ky.ug_333 qu.ha.wo_543 
  0x1f001d07, 0x5e3e5da4, 0x05000d04, 0x2300fc07,   // la.cy.un_420 ss.rm.ts_433  cs.fr.un_320 zzp.ca.un_420 
  0x6b011d0c, 0x311b1211, 0x17304804, 0x4836155a,   // la.en.ceb_543 hu.tr.az_653  tt.uz.sr_332 un.ab.tt_553 
  0x34002902, 0x016b09ee, 0x35111555, 0x1e6b7908,   // sl.xh.un_220 pl.ceb.en_422  un.ro.tg_442 war.ceb.ms_443 
  
  // [e400]
  0x31381b02, 0x1500fc09, 0x071515ec, 0x21000707,   // tr.tk.az_222 zzp.un.un_440  un.bg.un_640 it.jw.un_420 
  0x0a1715ac, 0x0d353402, 0x1c003e04, 0x352338a4,   // un.sr.mk_632 xh.zu.cs_222  rm.id.un_320 tk.ky.tg_433 
  0x010e63a6, 0x17360a04, 0x483615a4, 0x213d23ad,   // sco.is.en_521 mk.ab.sr_332  un.ab.tt_433 ky.ku.fa_643 
  0x230c0e12, 0x08064a08, 0x1a000402, 0x7500fe1a,   // is.sv.ca_654 yo.de.no_443  fi.tl.un_220 tlh.nso.un_760 
  // [e410]
  0x426b5407, 0xfc005a07, 0x204724a4, 0x15652307,   // ik.ceb.co_432 sm.zzp.un_420  eo.sn.sq_433 ca.gv.un_432 
  0x29000b09, 0x123d3455, 0x33fe0304, 0x545f2c0c,   // es.sl.un_440 ps.ku.ur_442  nl.tlh.nn_332 fy.tn.ik_543 
  0x060ffea7, 0x331554a0, 0x491a4608, 0x071517a4,   // tlh.lv.de_532 ik.nn.un_320  qu.tl.to_443 sr.bg.un_430 
  0x2e1a4e0d, 0x1e002813, 0x2f215c05, 0x17071507,   // ay.tl.fo_554 sw.ms.un_650  sa.jw.su_333 un.bg.sr_432 
  // [e420]
  0x355f0107, 0x37795f0c, 0x2735fa14, 0x34005805,   // en.tn.zu_432 tn.war.st_543  nr.zu.gd_666 om.xh.un_330 
  0x06006b07, 0x47123fa0, 0x25551307, 0x2a002202,   // ceb.de.un_420 af.hu.sn_322  et.rw.eu_432 oc.mt.un_220 
  0x0501fc04, 0x220a3102, 0x18033702, 0x25287307,   // zzp.en.fr_332 az.pt.oc_222  st.nl.ga_222 ny.sw.eu_432 
  0x5f5d37a4, 0x18283455, 0x0a442311, 0x28135cee,   // st.ss.tn_433 ps.sd.ar_442  ky.kk.mk_653 sa.et.sw_422 
  // [e430]
  0x232605af, 0x734e5c5a, 0x79001e08, 0x78003514,   // fr.ia.ca_655 sa.ay.ny_553  ms.war.un_430 zu.ve.un_660 
  0x734e46ec, 0x204e460d, 0x05003407, 0x44282307,   // qu.ay.ny_644 qu.ay.sq_554  xh.fr.un_420 ky.sd.kk_432 
  0x0900020e, 0x35347305, 0x055bfc55, 0x21123d55,   // da.pl.un_550 ny.xh.zu_333  zzp.sg.fr_442 ku.ur.fa_442 
  0x1d3437ad, 0x53003613, 0x073537ee, 0x48150a04,   // st.xh.la_643 gn.ht.un_650  ba.tg.bg_422 mk.tt.un_320 
  // [e440]
  0x45006812, 0x07301508, 0x28004519, 0x5b353b05,   // ig.ln.un_640 un.uz.bg_443  ln.sw.un_750 so.zu.sg_333 
  0x0810040d, 0x65461ea0, 0x75366aa4, 0x09202407,   // ru.be.uk_554 ms.qu.gv_322  haw.gn.nso_433 eo.sq.pl_432 
  0x12000f0d, 0x15351004, 0x17353011, 0x12302002,   // lv.hu.un_540 be.tg.un_332  uz.tg.sr_653 sq.uz.hu_222 
  0x060c4813, 0x2d294b12, 0x081036a7, 0x440410a0,   // tt.sv.de_665 mi.sl.sk_654  ab.be.uk_532 be.ru.kk_322 
  // [e450]
  0x1000150b, 0x3e001f19, 0x56000a02, 0x080539a0,   // un.be.un_520 cy.rm.un_750  pt.mg.un_220 br.fr.no_322 
  0x35303811, 0x1f006119, 0x27001f02, 0x06001f0d,   // tk.uz.tg_653 za.cy.un_750  cy.gd.un_220 cy.de.un_540 
  0x1f223ea0, 0x0d095c55, 0x3b004813, 0x1f004814,   // rm.oc.cy_322 sa.hi.ne_442  tt.so.un_650 tt.cy.un_660 
  0x580f4f07, 0x1f00480e, 0x24033fa4, 0x1f3e48ee,   // bi.lv.om_432 tt.cy.un_550  af.nl.eo_433 tt.rm.cy_422 
  // [e460]
  0x42486007, 0x33081fa0, 0x25003f04, 0x257920a7,   // vo.tt.co_432 cy.no.nn_322  af.eu.un_320 sq.war.eu_532 
  0x15003822, 0x0a233c07, 0x03006502, 0x27005c05,   // tk.un.un_870 ug.ky.mk_432  gv.nl.un_220 sa.gd.un_330 
  0x07003f02, 0x645a2ca0, 0x375a5605, 0x5600602b,   // af.it.un_220 fy.sm.lg_322  mg.sm.st_333 vo.mg.un_980 
  0x3b032fee, 0x133b6455, 0x65033ba4, 0x75005d09,   // su.nl.so_422 lg.so.et_442  so.nl.gv_433 ss.nso.un_440 
  // [e470]
  0x65581da0, 0x36152360, 0x2b004908, 0x30081007,   // la.om.gv_322 ky.ab.un_640  to.vi.un_430 be.uk.uz_432 
  0x253c36ad, 0x09002d05, 0x3c183455, 0x6465030d,   // ab.ug.mn_643 sk.pl.un_330  ps.ar.ug_442 nl.gv.lg_554 
  0x42003905, 0x3b654d07, 0x2a4931ac, 0x2b006e08,   // br.co.un_330 aa.gv.so_432  az.to.mt_632 hmn.vi.un_430 
  0x5a3b4ca0, 0x190a09af, 0x1d4645a0, 0xfc002c02,   // wo.so.sm_322 pl.pt.gl_655  ln.qu.la_322 fy.zzp.un_220 
  // [e480]
  0x0b001213, 0x2b006504, 0x124d0ba4, 0x46004d0d,   // hu.es.un_650 gv.vi.un_320  es.aa.hu_433 aa.qu.un_540 
  0x18004d0c, 0x0735170d, 0x1b643ba0, 0x122318ad,   // aa.ga.un_530 sr.tg.bg_554  so.lg.tr_322 ar.ky.ur_643 
  0x2d000f09, 0x0c000609, 0x1a006408, 0x5143110c,   // lv.sk.un_440 de.sv.un_440  lg.tl.un_430 ro.ie.kl_543 
  0x1b002829, 0x0e124d12, 0x44233808, 0x1e621ca9,   // sw.tr.un_960 aa.hu.is_654  tk.ky.kk_443 id.kha.ms_544 
  // [e490]
  0x3c1504a4, 0x25364f07, 0x0b001219, 0x49521e0c,   // ru.ug.un_430 bi.gn.eu_432  hu.es.un_750 ms.ha.to_543 
  0x0e230bee, 0x37081012, 0x5a2e0908, 0x2142520c,   // es.ca.is_422 be.uk.ba_654  pl.fo.sm_443 ha.co.jw_543 
  0x04001519, 0x1a5b1ca0, 0x07000120, 0x5a52110c,   // un.ru.un_750 id.sg.tl_322  en.it.un_850 ro.ha.sm_543 
  0x0a115a0c, 0x20004c21, 0x485c1aa4, 0x15003629,   // sm.ro.pt_543 wo.sq.un_860  tl.sa.tt_433 ab.un.un_960 
  // [e4a0]
  0x2500370d, 0x16004e0d, 0x0a07170d, 0x2a004604,   // ba.mn.un_540 ay.hr.un_540  sr.bg.mk_554 qu.mt.un_320 
  0x4600522b, 0x4b451ca4, 0x65005a05, 0x501a4908,   // ha.qu.un_980 id.ln.mi_433  sm.gv.un_330 to.tl.fj_443 
  0x0523150c, 0x65fc1e02, 0x44151707, 0x233e0a13,   // un.ca.fr_543 ms.zzp.gv_222  sr.kk.un_420 pt.rm.ca_665 
  0x52003902, 0x39563607, 0x17002304, 0x052223af,   // br.ha.un_220 gn.mg.br_432  ca.sr.un_320 ca.oc.fr_655 
  // [e4b0]
  0x345035a4, 0x3f6323a0, 0x600523ad, 0x070a15ad,   // zu.fj.xh_433 ca.sco.af_322  ca.fr.vo_643 un.mk.bg_643 
  0x4afc1b60, 0x04370702, 0x35302311, 0x1f002a0e,   // tr.zzp.yo_664 bg.ba.ru_222  ky.uz.tg_653 mt.cy.un_550 
  0x21301813, 0x152517ad, 0x3500040b, 0x3e330805,   // ar.uz.fa_665 sr.mn.un_643  ru.tg.un_520 no.nn.rm_333 
  0x4200fc0c, 0x4000fe0c, 0x06464e0c, 0xfc2b3f05,   // zzp.co.un_530 tlh.lb.un_530  ay.qu.de_543 af.vi.zzp_333 
  // [e4c0]
  0x2c62215a, 0x04070807, 0x30fc4607, 0x0c000e0d,   // jw.kha.fy_553 uk.bg.ru_432  qu.zzp.uz_432 is.sv.un_540 
  0x12212804, 0x083738a7, 0x443623ee, 0x34301804,   // sd.fa.ur_332 tk.ba.uk_532  ky.ab.kk_422 ar.uz.ps_332 
  0x0d093ba4, 0x110715ad, 0x104437a0, 0x1711350c,   // ks.hi.ne_433 un.bg.ro_643  ba.kk.be_322 tg.ro.sr_543 
  0x061b0cee, 0x0a17380c, 0x35346112, 0x303c25ad,   // sv.tr.de_422 tk.sr.mk_543  za.xh.zu_654 mn.ug.uz_643 
  // [e4d0]
  0x2700fc05, 0x07300402, 0x5f024511, 0x530602a0,   // zzp.gd.un_330 ru.uz.bg_222  ln.da.tn_653 da.de.ht_322 
  0x3002450c, 0x233c3d07, 0x2f5d5f08, 0x34fc020c,   // ln.da.uz_543 ku.ug.ky_432  tn.ss.su_443 da.zzp.xh_543 
  0x353438a4, 0x5d00450c, 0x021c2fa4, 0x1f753b08,   // tk.xh.zu_433 ln.ss.un_530  su.id.da_433 so.nso.cy_443 
  0x2d0d180c, 0x25001720, 0x3559730d, 0x113c300c,   // ga.cs.sk_543 sr.mn.un_850  ny.rn.zu_554 uz.ug.ro_543 
  // [e4e0]
  0x0a17070e, 0x3b3701a0, 0x34001f07, 0x252311ee,   // bg.sr.mk_555 en.st.so_322  cy.xh.un_420 ro.ky.mn_422 
  0x37153cec, 0x16000902, 0x39003e08, 0x3b0c4607,   // ug.ba.un_640 pl.hr.un_220  rm.br.un_430 qu.sv.so_432 
  0x19004704, 0x483c1504, 0x210c4604, 0x441008ad,   // sn.gl.un_320 un.ug.tt_332  qu.sv.jw_332 uk.be.kk_643 
  0x0a1725a4, 0xfa353409, 0x605d1808, 0xfe002009,   // mn.sr.mk_433 xh.zu.nr_444  ga.ss.vo_443 sq.tlh.un_440 
  // [e4f0]
  0x1000330c, 0x1800780c, 0x4e003508, 0x5e531804,   // nn.lt.un_530 ve.ga.un_530  zu.ay.un_430 ga.ht.ts_332 
  0x5d00200c, 0x4000010d, 0x342028a4, 0x500d2904,   // sq.ss.un_530 en.lb.un_540  sw.sq.xh_433 sl.cs.fj_332 
  0x35006321, 0x02000d19, 0x550d29a4, 0x38fc35ee,   // sco.zu.un_860 cs.da.un_750  sl.cs.rw_433 zu.zzp.tk_422 
  0x352134af, 0x3008360c, 0x10153607, 0x13004e13,   // xh.jw.zu_655 ab.uk.uz_543  ab.be.un_420 ay.et.un_650 
  // [e500]
  0x35345da6, 0x31483008, 0x185c7313, 0xfe003112,   // ss.xh.zu_521 uz.tt.az_443  ny.sa.ga_665 az.tlh.un_640 
  0x1f0b19ad, 0x1835345a, 0x10001e0c, 0x03fc0207,   // gl.es.cy_643 xh.zu.ga_553  ms.lt.un_530 da.zzp.nl_432 
  0x25002621, 0x1c280da0, 0x283b120d, 0x0d002f05,   // ia.eu.un_860 cs.sw.id_322  ur.ks.sd_554 su.cs.un_330 
  0x65034909, 0x0b1223ee, 0x08441107, 0x4d00581b,   // to.nl.gv_444 ca.hu.es_422  ro.kk.uk_432 om.aa.un_770 
  // [e510]
  0x652803a4, 0x19120b07, 0x755801a4, 0x1c376308,   // nl.sw.gv_433 es.hu.gl_432  en.om.nso_433 sco.st.id_443 
  0x170a36ad, 0x344c5f08, 0x230b4d07, 0x09004d0e,   // ab.mk.sr_643 tn.wo.xh_443  aa.es.ca_432 aa.pl.un_550 
  0x02584c11, 0x49053fa4, 0x40645807, 0x4d00090e,   // wo.om.da_653 af.fr.to_433  om.lg.lb_432 pl.aa.un_550 
  0x2d453607, 0x53643407, 0x344c6412, 0x73006a2a,   // gn.ln.sk_432 xh.lg.ht_432  lg.wo.xh_654 haw.ny.un_970 
  // [e520]
  0x0b122305, 0x36495008, 0x23001205, 0x13003605,   // ca.hu.es_333 fj.to.gn_443  hu.ca.un_330 gn.et.un_330 
  0x68635f0c, 0x21171604, 0x13754ca9, 0x36285f0c,   // tn.sco.ig_543 hr.sr.jw_332  wo.nso.et_544 tn.sw.gn_543 
  0x64631314, 0x58021307, 0x63036407, 0x152836a0,   // et.sco.lg_666 et.da.om_432  lg.nl.sco_432 gn.sw.un_322 
  0x187909ad, 0x4d00010d, 0x493e22ee, 0x1823440e,   // pl.war.ga_643 en.aa.un_540  oc.rm.to_422 kk.ky.ar_555 
  // [e530]
  0x08001308, 0x2f003413, 0x23443004, 0x5c003e18,   // et.no.un_430 xh.su.un_650  uz.kk.ky_332 rm.sa.un_740 
  0x5a7345a4, 0x04151114, 0x49003613, 0x6e365711,   // ln.ny.sm_433 ro.ru.un_660  gn.to.un_650 na.gn.hmn_653 
  0x30004421, 0x65001502, 0x79003e13, 0x1f000208,   // kk.uz.un_860 un.gv.un_220  rm.war.un_650 da.cy.un_430 
  0x79221f55, 0x5c001f02, 0x17101107, 0x3815150c,   // cy.oc.war_442 cy.sa.un_220  ro.be.sr_432 un.tk.un_530 
  // [e540]
  0x34001819, 0x301221a7, 0x08003514, 0x195a1f02,   // ar.ps.un_750 fa.ur.uz_532  tg.uk.un_660 cy.sm.gl_222 
  0x3c3d2302, 0x0700250e, 0x44303d0e, 0x17154407,   // ky.ku.ug_222 mn.bg.un_550  ku.uz.kk_555 kk.sr.un_420 
  0x44372308, 0x21002813, 0x1f2f2b55, 0x2b002f05,   // ky.ba.kk_443 sd.fa.un_650  vi.su.cy_442 su.vi.un_330 
  0x25002f14, 0x023e05a7, 0x3e052f08, 0x090d2dee,   // su.eu.un_660 fr.rm.da_532  su.fr.rm_443 sk.cs.pl_422 
  // [e550]
  0x190b30a9, 0x0b002205, 0x2f394c09, 0x2c00050b,   // uz.es.gl_544 oc.es.un_330  wo.br.su_444 fr.fy.un_520 
  0x093216a7, 0x0c003602, 0xfe00220d, 0x02652f05,   // hr.bs.pl_532 gn.sv.un_220  oc.tlh.un_540 su.gv.da_333 
  0x3e222f0c, 0x423e05ec, 0x3e222ba0, 0x37080404,   // su.oc.rm_543 fr.rm.co_644  vi.oc.rm_322 ru.uk.ba_332 
  0x103611ad, 0x123d300b, 0x3d341260, 0x154423a9,   // ro.ab.be_643 uz.ku.ur_542  ur.ps.ku_664 ky.kk.un_544 
  // [e560]
  0x15003823, 0x25fc0ca4, 0x3e1f10af, 0x0d2d38a4,   // tk.un.un_880 sv.zzp.eu_433  lt.cy.rm_655 tk.sk.cs_433 
  0x3700480b, 0x1f101ea9, 0x28001e09, 0x55473955,   // tt.ba.un_520 ms.lt.cy_544  ms.sw.un_440 br.sn.rw_442 
  0x462a3805, 0x3e221fa6, 0x25466404, 0x11002509,   // tk.mt.qu_333 cy.oc.rm_521  lg.qu.eu_332 eu.ro.un_440 
  0x305511a4, 0x55000a04, 0x1f102213, 0x283b18a0,   // ro.rw.uz_433 pt.rw.un_320  oc.lt.cy_665 ga.so.sw_322 
  // [e570]
  0x1b3039a0, 0x526439a0, 0x1c135c02, 0x550659a4,   // br.uz.tr_322 br.lg.ha_322  sa.bh.mr_222 rn.de.rw_433 
  0x38550208, 0x3e001013, 0x232834a0, 0x22001011,   // da.rw.tk_443 lt.rm.un_650  ps.sd.ky_322 lt.oc.un_630 
  0x10251504, 0x15150a05, 0x554228a9, 0x22101f13,   // un.mn.be_332 mk.un.un_330  sw.co.rw_544 cy.lt.oc_665 
  0x10001f21, 0x10001f12, 0x4410380c, 0x234a0b02,   // cy.lt.un_860 cy.lt.un_640  tk.be.kk_543 es.yo.ca_222 
  // [e580]
  0x3000691a, 0x370804a4, 0x123d3007, 0x0a001005,   // mfe.uz.un_760 ru.uk.ba_433  uz.ku.ur_432 be.mk.un_330 
  0x304823ee, 0x12341809, 0x36004c04, 0x150408ad,   // ky.tt.uz_422 ar.ps.ur_444  wo.gn.un_320 uk.ru.un_643 
  0x0b001208, 0x19234d0b, 0x01061507, 0x0800070e,   // hu.es.un_430 aa.ca.gl_542  un.de.en_432 bg.uk.un_550 
  0x063502ee, 0x06001707, 0x35345d08, 0x2053560c,   // da.zu.de_422 sr.de.un_420  ss.xh.zu_443 mg.ht.sq_543 
  // [e590]
  0x465c3007, 0x12001811, 0x37303c14, 0xfc5c5e07,   // uz.sa.qu_432 ar.ur.un_630  ug.uz.ba_666 ts.sa.zzp_432 
  0x5c003613, 0x40060ea7, 0x18060307, 0x5c001208,   // gn.sa.un_650 is.de.lb_532  nl.de.ga_432 hu.sa.un_430 
  0x46362d04, 0x792d0d05, 0x211218ec, 0x0d792da4,   // sk.gn.qu_332 cs.sk.war_333  ar.ur.fa_644 sk.war.cs_433 
  0x2d000e12, 0x27fc5b07, 0x2d0d2105, 0x2d002502,   // is.sk.un_640 sg.zzp.gd_432  jw.cs.sk_333 eu.sk.un_220 
  // [e5a0]
  0x34001d07, 0x3c3711a4, 0x2a180604, 0x151106a0,   // la.xh.un_420 ro.ba.ug_433  de.ga.mt_332 de.ro.un_322 
  0x301b5caf, 0x782226ec, 0x0d160f07, 0x5c4636ad,   // sa.tr.uz_655 ia.oc.ve_644  lv.hr.cs_432 gn.qu.sa_643 
  0x28222f0c, 0x30004f08, 0x135c1cec, 0x1800020e,   // su.oc.sw_543 bi.uz.un_430  mr.sa.bh_644 da.ga.un_550 
  0xfc1506a0, 0x2d0d69a0, 0x15003118, 0x502202a0,   // de.zzp.un_320 mfe.cs.sk_322  az.un.un_740 da.oc.fj_322 
  // [e5b0]
  0x18001f20, 0x010d2da0, 0x313830ac, 0x0d006508,   // cy.ga.un_850 sk.cs.en_322  uz.tk.az_632 gv.cs.un_430 
  0x791d2da4, 0x650162a0, 0x38001502, 0x023829ee,   // sk.la.war_433 kha.en.gv_322  un.tk.un_220 sl.tk.da_422 
  0x1300fe0c, 0x2b0815ee, 0x5b002021, 0x53462ba0,   // tlh.et.un_530 un.no.vi_422  sq.sg.un_860 vi.qu.ht_322 
  0x20005b20, 0x1d011fee, 0x303508a4, 0x212b1504,   // sg.sq.un_850 cy.en.la_422  uk.tg.uz_433 un.vi.jw_332 
  // [e5c0]
  0x051d7908, 0x0efc6355, 0x021f63a4, 0x4c005b13,   // war.la.fr_443 sco.zzp.is_442  sco.cy.da_433 sg.wo.un_650 
  0x04302304, 0x0642fca4, 0x033f1a07, 0x4c002019,   // ky.uz.ru_332 zzp.co.de_433  tl.af.nl_432 sq.wo.un_750 
  0x40002008, 0x20004c1a, 0x0169040c, 0x3e236004,   // sq.lb.un_430 wo.sq.un_760  fi.mfe.en_543 vo.ca.rm_332 
  0x0a002007, 0x404c5bac, 0x23000508, 0x3e006004,   // sq.pt.un_420 sg.wo.lb_632  fr.ca.un_430 vo.rm.un_320 
  // [e5d0]
  0x3537250c, 0x20404b02, 0x1100430c, 0x390e06a0,   // mn.ba.tg_543 mi.lb.sq_222  ie.ro.un_530 de.is.br_322 
  0x3f002302, 0x40002002, 0x05120b02, 0x20004c10,   // ca.af.un_220 sq.lb.un_220  es.hu.fr_222 wo.sq.un_620 
  0x230263ee, 0x220f33a0, 0x53450904, 0x23456008,   // sco.da.ca_422 nn.lv.oc_322  pl.ln.ht_332 vo.ln.ca_443 
  0x2d002f04, 0x223f3e04, 0x230c3ea7, 0x4a73fca0,   // su.sk.un_320 rm.af.oc_332  rm.sv.ca_532 zzp.ny.yo_322 
  // [e5e0]
  0x2305220b, 0x3f4c0307, 0x79000c19, 0x300a2307,   // oc.fr.ca_542 nl.wo.af_432  sv.war.un_750 ky.mk.uz_432 
  0xfc4a5aa4, 0x4c004b0c, 0x641f5a02, 0x34122855,   // sm.yo.zzp_433 mi.wo.un_530  sm.cy.lg_222 sd.ur.ps_442 
  0x33120302, 0x05122d02, 0x322d29a0, 0x052f1202,   // nl.hu.nn_222 sk.hu.fr_222  sl.sk.bs_322 hu.su.fr_222 
  0x3c004805, 0x1c00130b, 0x2348350c, 0x1f002e12,   // tt.ug.un_330 bh.mr.un_520  tg.tt.ky_543 fo.cy.un_640 
  // [e5f0]
  0x7578430c, 0x32001e0c, 0x5f1228a0, 0x56340207,   // ie.ve.nso_543 ms.bs.un_530  sw.hu.tn_322 da.xh.mg_432 
  0x02561209, 0x48624ba9, 0xfe5c02af, 0x190a2709,   // hu.mg.da_444 mi.kha.tt_544  da.sa.tlh_655 gd.pt.gl_444 
  0x6056fea9, 0x1e696204, 0x47023605, 0x1f000c0d,   // tlh.mg.vo_544 kha.mfe.ms_332  gn.da.sn_333 sv.cy.un_540 
  0x55000d04, 0x4548110c, 0x19312a11, 0x190b365a,   // cs.rw.un_320 ro.tt.ln_543  mt.az.gl_653 gn.es.gl_553 
  // [e600]
  0x64001f19, 0x57595513, 0x07081105, 0x6800420d,   // cy.lg.un_750 rw.rn.na_665  ro.uk.bg_333 co.ig.un_540 
  0x653f0104, 0x65152704, 0x2722650b, 0x34375da0,   // en.af.gv_332 gd.gv.un_320  gv.oc.gd_542 ss.st.xh_322 
  0x2f390a02, 0x07594b0c, 0x15681b0d, 0x1f00fc2b,   // pt.br.su_222 mi.rn.it_543  tr.ig.un_554 zzp.cy.un_980 
  0x3e65270c, 0x20274713, 0x131c095a, 0xfe555707,   // gd.gv.rm_543 sn.gd.sq_665  hi.mr.bh_553 na.rw.tlh_432 
  // [e610]
  0x27006513, 0xfc033f13, 0x40004c0c, 0x1c135caf,   // gv.gd.un_650 af.nl.zzp_665  wo.lb.un_530 sa.bh.mr_655 
  0x27006313, 0x16006502, 0x18341207, 0x40002011,   // sco.gd.un_650 gv.hr.un_220  ur.ps.ar_432 sq.lb.un_630 
  0x0a0807ad, 0x1a38280d, 0x64001c08, 0x581e1ca4,   // bg.uk.mk_643 sw.tk.tl_554  id.lg.un_430 id.ms.om_433 
  0x0f290908, 0x3b525d0d, 0x3c3544a7, 0x3646110c,   // pl.sl.lv_443 ss.ha.so_554  kk.tg.ug_532 ro.qu.gn_543 
  // [e620]
  0x394555ad, 0x4a004f08, 0x53003608, 0xfc002a13,   // rw.ln.br_643 bi.yo.un_430  gn.ht.un_430 mt.zzp.un_650 
  0x5764470c, 0x1a593ba4, 0x64002809, 0x1e1c02a0,   // sn.lg.na_543 so.rn.tl_433  sw.lg.un_440 da.id.ms_322 
  0x0a1f220d, 0x094a4ca0, 0x18442312, 0x221f4711,   // oc.cy.pt_554 wo.yo.pl_322  ky.kk.ar_654 sn.cy.oc_653 
  0x51001c04, 0x17303811, 0x4c3b300c, 0x36380407,   // id.kl.un_320 tk.uz.sr_653  uz.so.wo_543 ru.tk.ab_432 
  // [e630]
  0x0c002607, 0x0a00260c, 0x1f005c1a, 0x242d0d0c,   // ia.sv.un_420 ia.pt.un_530  sa.cy.un_760 cs.sk.eo_543 
  0x282f1e0c, 0x0a3517a7, 0x3c1844a0, 0x4d3b58af,   // ms.su.sw_543 sr.tg.mk_532  kk.ar.ug_322 om.so.aa_655 
  0x57184a12, 0x47001321, 0x31004c08, 0x6902530c,   // yo.ga.na_654 et.sn.un_860  wo.az.un_430 ht.da.mfe_543 
  0x1f3e06af, 0x63001d07, 0xfe002019, 0x59004712,   // de.rm.cy_655 la.sco.un_420  sq.tlh.un_750 sn.rn.un_640 
  // [e640]
  0x4815300c, 0x645359ee, 0x23173055, 0x083704a0,   // uz.tt.un_530 rn.ht.lg_422  uz.sr.ky_442 ru.ba.uk_322 
  0x0b002512, 0x40004c12, 0x0e060407, 0x28123b0c,   // eu.es.un_640 wo.lb.un_640  fi.de.is_432 ks.ur.sd_543 
  0x350a1008, 0x35343b5a, 0x20004c0c, 0x34005504,   // be.mk.tg_443 so.xh.zu_553  wo.sq.un_530 rw.xh.un_320 
  0x533b6407, 0x49005a22, 0x2d321605, 0x30104304,   // lg.so.ht_432 sm.to.un_870  hr.bs.sk_333 ie.lt.uz_332 
  // [e650]
  0x56495a07, 0x470e56ac, 0x4900471a, 0x28000e0c,   // sm.to.mg_432 mg.is.sn_632  sn.to.un_760 is.sw.un_530 
  0x2a005204, 0x585a6005, 0x0a3573a0, 0x28735509,   // ha.mt.un_320 vo.sm.om_333  ny.zu.pt_322 rw.ny.sw_444 
  0x2073530c, 0x16001304, 0x35526402, 0x121834ad,   // ht.ny.sq_543 et.hr.un_320  lg.ha.zu_222 ps.ar.ur_643 
  0x37350aa0, 0x35476707, 0x2d0d1009, 0x25004e0c,   // mk.tg.ba_322 ak.sn.zu_432  lt.cs.sk_444 ay.eu.un_530 
  // [e660]
  0x0c082ea0, 0x0d291604, 0x041007ee, 0x3d30230c,   // fo.no.sv_322 hr.sl.cs_332  bg.be.ru_422 ky.uz.ku_543 
  0x3e42fc11, 0x21345dad, 0x23041505, 0x10006502,   // zzp.co.rm_653 ss.xh.jw_643  un.ru.ky_333 gv.lt.un_220 
  0x35373004, 0xfc3948a6, 0x424c05ad, 0x37231007,   // uz.ba.tg_332 tt.br.zzp_521  fr.wo.co_643 be.ky.ba_432 
  0x3b002104, 0x0711080d, 0x6e002f09, 0x213b12ad,   // jw.so.un_320 uk.ro.bg_554  su.hmn.un_440 ur.ks.fa_643 
  // [e670]
  0x3b211ca0, 0x4c004017, 0xfc404205, 0x242718a9,   // id.jw.so_322 lb.wo.un_730  co.lb.zzp_333 ga.gd.eo_544 
  0x650527a4, 0x041538ad, 0x2900100c, 0x27005c10,   // gd.fr.gv_433 tk.ru.un_630  lt.sl.un_530 sa.gd.un_620 
  0x22006908, 0x03002d04, 0x43002421, 0x4d001f09,   // mfe.oc.un_430 sk.nl.un_320  eo.ie.un_860 cy.aa.un_440 
  0x0b1d6ba9, 0x6b001334, 0x1d000a02, 0x6b130d11,   // ceb.la.es_544 et.ceb.un_A80  pt.la.un_220 cs.et.ceb_653 
  // [e680]
  0x36001813, 0x1e3b130c, 0x79134f0c, 0x1515170c,   // ga.gn.un_650 et.so.ms_543  bi.et.war_543 sr.un.un_530 
  0x1b002f04, 0x6b2f7904, 0x15001b11, 0x30003119,   // su.tr.un_320 war.su.ceb_332  tr.un.un_630 az.uz.un_750 
  0x310c3307, 0x4600fe0e, 0x454d57a4, 0x79002013,   // nn.sv.az_432 tlh.qu.un_550  na.aa.ln_433 sq.war.un_650 
  0x796b0daf, 0x13006b08, 0x174404a4, 0x506a490b,   // cs.ceb.war_655 ceb.et.un_430  ru.kk.sr_433 to.haw.fj_542 
  // [e690]
  0x51001d05, 0x06431004, 0x381b4602, 0x29163802,   // la.kl.un_330 lt.ie.de_332  qu.tr.tk_222 tk.hr.sl_222 
  0x10150809, 0x48373812, 0x244a5212, 0x37504a0d,   // uk.be.un_440 tk.ba.tt_654  ha.yo.eo_654 yo.fj.st_554 
  0x091c5c5a, 0x5e00590e, 0x044a25a0, 0x2d0d5711,   // sa.mr.hi_553 rn.ts.un_550  eu.yo.fi_322 na.cs.sk_653 
  0x2c00020d, 0x56494a0c, 0x58fe0507, 0x27554755,   // da.fy.un_540 yo.to.mg_543  fr.tlh.om_432 sn.rw.gd_442 
  // [e6a0]
  0x153c30ad, 0x12002402, 0x2c1ffe0d, 0x23fe22ad,   // uz.ug.un_643 eo.hu.un_220  tlh.cy.fy_554 oc.tlh.ca_643 
  0x3f353407, 0x345ffead, 0x67000104, 0x5f345d08,   // xh.zu.af_432 tlh.tn.xh_643  en.ak.un_320 ss.xh.tn_443 
  0x0f000905, 0x53fc2f07, 0x345f755a, 0x08300404,   // pl.lv.un_330 su.zzp.ht_432  nso.tn.xh_553 ru.uz.uk_332 
  0x09372ca4, 0x25001129, 0x354034ec, 0x4b286b07,   // fy.st.pl_433 ro.mn.un_960  xh.lb.zu_644 ceb.sw.mi_432 
  // [e6b0]
  0x40002304, 0x2046420c, 0x011d05a0, 0x5d000209,   // ca.lb.un_320 co.qu.sq_543  fr.la.en_322 da.ss.un_440 
  0x035ffe0c, 0x43344fad, 0x632718a4, 0x2f1cfeee,   // tlh.tn.nl_543 bi.xh.ie_643  ga.gd.sco_433 tlh.id.su_422 
  0x2c3534a0, 0x4838440d, 0x3f032cad, 0x3f3b64a0,   // xh.zu.fy_322 kk.tk.tt_554  fy.nl.af_643 lg.so.af_322 
  0x250435ac, 0x322d2907, 0x332e65a6, 0x3c001519,   // tg.ru.mn_632 sl.sk.bs_432  gv.fo.nn_521 un.ug.un_750 
  // [e6c0]
  0x2d0d15ee, 0x30153605, 0x38442307, 0x44100808,   // un.cs.sk_422 ab.uz.un_330  ky.kk.tk_432 uk.be.kk_443 
  0x21123412, 0x560522a7, 0x53000509, 0x321748a0,   // ps.ur.fa_654 oc.fr.mg_532  fr.ht.un_440 tt.sr.bs_322 
  0x6b061d07, 0x36462104, 0x221205a0, 0x3507300c,   // la.de.ceb_432 jw.qu.gn_332  fr.hu.oc_322 uz.bg.tg_543 
  0x5f5d0a04, 0x05000213, 0x301834af, 0x29006502,   // pt.ss.tn_332 da.fr.un_650  ps.ar.uz_655 gv.sl.un_220 
  // [e6d0]
  0x392035a0, 0x565f4204, 0x0e2d18ec, 0x755a5fa9,   // zu.sq.br_322 co.tn.mg_332  ga.sk.is_644 tn.sm.nso_544 
  0x12556404, 0xfc006512, 0x55156802, 0x424005a0,   // lg.rw.hu_332 gv.zzp.un_640  ig.rw.un_220 fr.lb.co_322 
  0x035009a0, 0x074258a9, 0x122a6504, 0x3e2c06ee,   // pl.fj.nl_322 om.co.it_544  gv.mt.hu_332 de.fy.rm_422 
  0x0c003005, 0x0e00fc07, 0x06402c04, 0x233418a0,   // uz.sv.un_330 zzp.is.un_420  fy.lb.de_332 ar.ps.ky_322 
  // [e6e0]
  0xfc000e02, 0x343c2302, 0x4600620e, 0x2c002205,   // is.zzp.un_220 ky.ug.ps_222  kha.qu.un_550 oc.fy.un_330 
  0x34001902, 0x55372511, 0x5f355d13, 0x30001007,   // gl.xh.un_220 eu.st.rw_653  ss.zu.tn_665 be.uz.un_420 
  0x21000a05, 0x4a492008, 0x25243eac, 0x077911ad,   // pt.jw.un_330 sq.to.yo_443  rm.eo.eu_632 ro.war.it_643 
  0x15002a2b, 0x5f376712, 0x40fc0608, 0x29682dec,   // mt.un.un_980 ak.st.tn_654  de.zzp.lb_443 sk.ig.sl_644 
  // [e6f0]
  0x0c400607, 0x1d4601ac, 0x29005212, 0x0c007308,   // de.lb.sv_432 en.qu.la_632  ha.sl.un_640 ny.sv.un_430 
  0x48581e05, 0x76695308, 0x0b5c3e11, 0x5200290d,   // ms.om.tt_333 ht.mfe.crs_443  rm.sa.es_653 sl.ha.un_540 
  0x4f000e21, 0x305d45a0, 0x630501a0, 0x3700fa19,   // is.bi.un_860 ln.ss.uz_322  en.fr.sco_322 nr.st.un_750 
  0x3600590c, 0x300465ad, 0x692a2e0c, 0x4a304304,   // rn.gn.un_530 gv.fi.uz_643  fo.mt.mfe_543 ie.uz.yo_332 
  // [e700]
  0x200c3e08, 0x23303502, 0x5a003604, 0x2d0c02ad,   // rm.sv.sq_443 tg.uz.ky_222  gn.sm.un_320 da.sv.sk_643 
  0x1f001007, 0x2b5e340c, 0x1c0b79a0, 0x4846fe0d,   // lt.cy.un_420 xh.ts.vi_543  war.es.id_322 tlh.qu.tt_554 
  0x381f10a4, 0x0b002208, 0x13045c0c, 0x046b67ee,   // lt.cy.tk_433 oc.es.un_430  sa.fi.et_543 ak.ceb.fi_422 
  0x640265a0, 0x39272bee, 0x1b3b65a0, 0x0a1711ac,   // gv.da.lg_322 vi.gd.br_422  gv.so.tr_322 ro.sr.mk_632 
  // [e710]
  0x1b04650c, 0x3c4838ec, 0x3b44230c, 0x151007a4,   // gv.fi.tr_543 tk.tt.ug_644  ky.kk.ks_543 bg.be.un_433 
  0x182762a4, 0x07006207, 0x103708ad, 0x17233755,   // kha.gd.ga_433 kha.it.un_420  uk.ba.be_643 ba.ky.sr_442 
  0x1c131eac, 0x40060102, 0xfc001e08, 0x2b1d630c,   // ms.et.id_632 en.de.lb_222  ms.zzp.un_430 sco.la.vi_543 
  0x135f3704, 0x36492fa4, 0x4900040b, 0x49286aaf,   // st.tn.et_332 su.to.gn_433  fi.to.un_520 haw.sw.to_655 
  // [e720]
  0x0400101a, 0x3ffc0308, 0x111cfc14, 0x12003811,   // lt.fi.un_760 nl.zzp.af_443  zzp.id.ro_666 tk.hu.un_630 
  0x1c001e19, 0x153c38a4, 0x42112aee, 0x22001108,   // ms.id.un_750 tk.ug.un_433  mt.ro.co_422 ro.oc.un_430 
  0x032410ee, 0x40000905, 0x2f2028ee, 0x070a2505,   // lt.eo.nl_422 pl.lb.un_330  sw.sq.su_422 mn.mk.bg_333 
  0x073c23a0, 0x375ffc0c, 0x47731d08, 0x1b002a19,   // ky.ug.bg_322 zzp.tn.st_543  la.ny.sn_443 mt.tr.un_750 
  // [e730]
  0x0d201ba0, 0x1e00202b, 0x1100481b, 0x38002a05,   // tr.sq.cs_322 ti.am.un_980  tt.ro.un_770 mt.tk.un_330 
  0x27032c09, 0x32172da0, 0x272c0355, 0x303536a4,   // fy.nl.gd_444 sk.sr.bs_322  nl.fy.gd_442 ab.tg.uz_433 
  0x374844a0, 0x25002a13, 0x2d160d0d, 0x44303507,   // kk.tt.ba_322 mt.eu.un_650  cs.hr.sk_554 tg.uz.kk_432 
  0x38004808, 0x3f697608, 0x352532ee, 0x33000812,   // tt.tk.un_430 crs.mfe.af_443  bs.eu.zu_422 no.nn.un_640 
  // [e740]
  0x554a4c07, 0xfc002f07, 0x1812440c, 0xfc002d07,   // wo.yo.rw_432 su.zzp.un_420  kk.ur.ar_543 sk.zzp.un_420 
  0x643525a9, 0x303428af, 0x0800480d, 0x440810a4,   // eu.zu.lg_544 sd.ps.uz_655  tt.uk.un_540 be.uk.kk_433 
  0x1d002204, 0x4c340908, 0x093402a7, 0x3e002208,   // oc.la.un_320 pl.xh.wo_443  da.xh.pl_532 oc.rm.un_430 
  0x09003408, 0x234435a4, 0x44101508, 0x2325360c,   // xh.pl.un_430 tg.kk.ky_433  un.be.kk_443 ab.mn.ky_543 
  // [e750]
  0x12282107, 0x2f005d04, 0x08330c04, 0x0a003505,   // fa.sd.ur_432 ss.su.un_320  sv.nn.no_332 tg.mk.un_330 
  0x35004419, 0x233848ad, 0x39384c0d, 0x38003913,   // kk.tg.un_750 tt.tk.ky_643  wo.tk.br_554 br.tk.un_650 
  0x393857af, 0x23001805, 0x38003921, 0x15003620,   // na.tk.br_655 ga.ca.un_330  br.tk.un_860 ab.un.un_850 
  0x370723a0, 0x3800391a, 0x4e383912, 0x39574ca9,   // ky.bg.ba_322 br.tk.un_760  br.tk.ay_654 wo.na.br_544 
  // [e760]
  0x791f1804, 0x38003908, 0x0f004b02, 0x26060c0c,   // ga.cy.war_332 br.tk.un_430  mi.lv.un_220 sv.de.ia_543 
  0x34005f14, 0xfe353408, 0x0f5c5a07, 0x463f5fa7,   // tn.xh.un_660 xh.zu.tlh_443  sm.sa.lv_432 tn.af.qu_532 
  0x09004a05, 0x47347304, 0x0d294ca4, 0x28303ba4,   // yo.pl.un_330 ny.xh.sn_332  wo.sl.cs_433 ks.uz.sd_433 
  0x37001a04, 0x15001605, 0x65004c05, 0x472837a9,   // tl.st.un_320 hr.un.un_330  wo.gv.un_330 st.sw.sn_544 
  // [e770]
  0x42001112, 0x1b174ca7, 0x4423370c, 0x103811ad,   // ro.co.un_640 wo.sr.tr_532  ba.ky.kk_543 ro.tk.be_643 
  0x03463f07, 0x27004204, 0x1538150c, 0xfc570104,   // af.qu.nl_432 co.gd.un_320  un.tk.un_543 en.na.zzp_332 
  0x09004205, 0x18006307, 0x23221908, 0x23003823,   // co.pl.un_330 sco.ga.un_420  gl.oc.ca_443 tk.ky.un_880 
  0x182128a7, 0x63060107, 0x1b000408, 0x075804a9,   // sd.fa.ar_532 en.de.sco_432  fi.tr.un_430 fi.om.it_544 
  // [e780]
  0x544d04af, 0xfc650307, 0x0407580c, 0x042a5813,   // fi.aa.ik_655 nl.gv.zzp_432  om.it.fi_543 om.mt.fi_665 
  0x5d536408, 0x35644aa4, 0x375f2f05, 0x4a351b55,   // lg.ht.ss_443 yo.lg.zu_433  su.tn.st_333 tr.zu.yo_442 
  0x64001521, 0x73006b07, 0x081735a0, 0x044810ee,   // un.lg.un_860 ceb.ny.un_420  tg.sr.uk_322 be.tt.ru_422 
  0x5804540c, 0x5c1d0408, 0x0c2f520c, 0x08020c0e,   // ik.fi.om_543 fi.la.sa_443  ha.su.sv_543 sv.da.no_555 
  // [e790]
  0x17100404, 0x76002022, 0x31532807, 0x01002304,   // ru.be.sr_332 sq.crs.un_870  sw.ht.az_432 ca.en.un_320 
  0x3b00380d, 0x26735d05, 0x64005c04, 0x3b3007a0,   // tk.so.un_540 ss.ny.ia_333  sa.lg.un_320 it.uz.so_322 
  0x17004c07, 0x1800620d, 0x08441155, 0x18001121,   // wo.sr.un_420 kha.ga.un_540  ro.kk.uk_442 ro.ga.un_860 
  0x17110812, 0x071d4213, 0x5300650e, 0x101744a0,   // uk.ro.sr_654 co.la.it_665  gv.ht.un_550 kk.sr.be_322 
  // [e7a0]
  0x461d52a0, 0x311f0eee, 0x4c006112, 0x1c004804,   // ha.la.qu_322 is.cy.az_422  za.wo.un_640 tt.id.un_320 
  0x65003b09, 0x1bfc76a0, 0x313b650d, 0x2f0479a0,   // so.gv.un_440 crs.zzp.tr_322  gv.so.az_554 war.fi.su_322 
  0x602e0e12, 0x65001b05, 0x5d35260d, 0x32001208,   // is.fo.vo_654 tr.gv.un_330  ia.zu.ss_554 hu.bs.un_430 
  0x242e0c60, 0x231d2904, 0x3b001f08, 0x0f005d0d,   // sv.fo.eo_664 sl.la.ca_332  cy.so.un_430 ss.lv.un_540 
  // [e7b0]
  0x35535d08, 0x442538a6, 0x65001b0e, 0x3b3865a7,   // ss.ht.zu_443 tk.mn.kk_521  tr.gv.un_550 gv.tk.so_532 
  0x4d5c2e09, 0x0e2a2e05, 0x5c1223a4, 0x0e003409,   // fo.sa.aa_444 fo.mt.is_333  ca.hu.sa_433 xh.is.un_440 
  0x1b531a04, 0x1538360d, 0x12001a12, 0x234448ee,   // tl.ht.tr_332 ab.tk.un_554  tl.hu.un_640 tt.kk.ky_422 
  0x2d321702, 0x00006742, 0x4d00312a, 0x2515150c,   // sr.bs.sk_222 ak.un.un_C00  az.aa.un_970 un.mn.un_530 
  // [e7c0]
  0x01001e02, 0x12005202, 0x5c637607, 0x111d0e04,   // ms.en.un_220 ha.hu.un_220  crs.sco.sa_432 is.la.ro_332 
  0x44002108, 0x1d002102, 0x261d4fa4, 0x300810a0,   // fa.kk.un_430 jw.la.un_220  bi.la.ia_433 be.uk.uz_322 
  0x3d2112a9, 0x24001705, 0x3c002112, 0x354c600c,   // ur.fa.ku_544 sr.eo.un_330  fa.ug.un_640 vo.wo.zu_543 
  0x20001d05, 0x103b12ec, 0x55fe38a7, 0x12001311,   // la.sq.un_330 hu.so.lt_644  tk.tlh.rw_532 et.hu.un_630 
  // [e7d0]
  0xfc1039a4, 0x452f28a9, 0x3f00400e, 0x3f264605,   // br.lt.zzp_433 sw.su.ln_544  lb.af.un_550 qu.ia.af_333 
  0x37005f0b, 0x785e5fa7, 0x6536fcec, 0x2f05280c,   // tn.st.un_520 tn.ts.ve_532  zzp.gn.gv_644 sw.fr.su_543 
  0x6478fead, 0xfc003f07, 0x5f643708, 0x3b1f2a04,   // tlh.ve.lg_643 af.zzp.un_420  st.lg.tn_443 mt.cy.so_332 
  0x1f003308, 0x04005d04, 0x4c526408, 0x15002c07,   // nn.cy.un_430 ss.fi.un_320  lg.ha.wo_443 fy.un.un_420 
  // [e7e0]
  0xfe003708, 0x342118a0, 0x5f521fa4, 0x50003804,   // st.tlh.un_430 ar.fa.ps_322  cy.ha.tn_433 tk.fj.un_320 
  0x28000209, 0x0717040d, 0x461f7955, 0x484415ee,   // da.sw.un_440 ru.sr.bg_554  war.cy.qu_442 un.kk.tt_422 
  0x01003602, 0x343b30a4, 0x10303508, 0x3c002104,   // gn.en.un_220 uz.ks.ps_433  tg.uz.be_443 fa.ug.un_320 
  0x253023a9, 0x174823a4, 0x08170707, 0x3d181202,   // ky.uz.mn_544 ky.tt.sr_433  bg.sr.uk_432 ur.ar.ku_222 
  // [e7f0]
  0x190b460e, 0x2f003008, 0x2ffc62a9, 0x34fa355a,   // qu.es.gl_555 uz.su.un_430  kha.zzp.su_544 zu.nr.xh_553 
  0x4b132d09, 0x355f34a0, 0x24003e04, 0x0c1354a7,   // sk.et.mi_444 xh.tn.zu_322  rm.eo.un_320 ik.et.sv_532 
  0x79003e07, 0x190a10a4, 0x1f5d3511, 0x75013708,   // rm.war.un_420 lt.pt.gl_433  zu.ss.cy_653 st.en.nso_443 
  0x47284513, 0x1a5451a9, 0x521b2102, 0x43190b05,   // ln.sw.sn_665 kl.ik.tl_544  jw.tr.ha_222 es.gl.ie_333 
  
  // [e800]
  0x51001002, 0x46521309, 0x10275cee, 0x34153508,   // lt.kl.un_220 et.ha.qu_444  sa.gd.lt_422 zu.xh.un_430 
  0x13735ea9, 0x35341faf, 0x123534a6, 0x5e345d07,   // ts.ny.et_544 cy.xh.zu_655  xh.zu.hu_521 ss.xh.ts_432 
  0x04005118, 0x2554515a, 0xfc3435a7, 0x082304ee,   // kl.fi.un_740 kl.ik.eu_553  zu.xh.zzp_532 ru.ky.uk_422 
  0x54005122, 0x10003e08, 0x626301a7, 0x0e2e12ad,   // kl.ik.un_870 rm.lt.un_430  en.sco.kha_532 hu.fo.is_643 
  // [e810]
  0x656953a4, 0x262506ec, 0x641b37a0, 0x44253704,   // ht.mfe.gv_433 de.eu.ia_644  st.tr.lg_322 ba.mn.kk_332 
  0x0d004a14, 0x53003b02, 0x34003708, 0x5d00150d,   // yo.cs.un_660 so.ht.un_220  st.xh.un_430 un.ss.un_540 
  0xfe255012, 0x46044e04, 0x485930af, 0x0460460c,   // fj.eu.tlh_654 ay.fi.qu_332  uz.rn.tt_655 qu.vo.fi_543 
  0x021b6507, 0x46003604, 0x1b486507, 0x625c46ec,   // gv.tr.da_432 gn.qu.un_320  gv.tt.tr_432 qu.sa.kha_644 
  // [e820]
  0x3c15480c, 0x52294d07, 0x46001302, 0x203b580b,   // tt.ug.un_530 aa.sl.ha_432  et.qu.un_220 om.so.sq_542 
  0x1228340c, 0x054665a0, 0x4c02310e, 0x351530a9,   // ps.sd.ur_543 gv.qu.fr_322  az.da.wo_555 uz.tg.un_540 
  0x01004604, 0x403f1607, 0x2e004d12, 0x0e2e120c,   // qu.en.un_320 hr.af.lb_432  aa.fo.un_640 hu.fo.is_543 
  0x5a5046a0, 0x2e3e5c07, 0x2f004704, 0x4e3f1ea0,   // qu.fj.sm_322 sa.rm.fo_432  sn.su.un_320 ms.af.ay_322 
  // [e830]
  0x465c4e04, 0x04073607, 0x151d51a0, 0x352f64a0,   // ay.sa.qu_332 ab.bg.ru_432  kl.la.un_322 lg.su.zu_322 
  0x1025040d, 0x2f3e60ad, 0x552c64a7, 0x27231a07,   // ru.mn.be_554 vo.rm.su_643  lg.fy.rw_532 tl.ca.gd_432 
  0x3f032b0b, 0x64352f09, 0x0b0a19a7, 0x28183ea7,   // vi.nl.af_542 su.zu.lg_444  gl.pt.es_532 rm.ga.sw_532 
  0x65430eec, 0x22002335, 0x5d002405, 0x30252307,   // is.ie.gv_644 ca.oc.un_A90  eo.ss.un_330 ky.mn.uz_432 
  // [e840]
  0x18003612, 0x0c4c6b04, 0x35002404, 0x34643507,   // gn.ga.un_640 ceb.wo.sv_332  eo.zu.un_320 zu.lg.xh_432 
  0x42006508, 0x152207ee, 0x043035a0, 0x34fe35a4,   // gv.co.un_430 it.oc.un_422  tg.uz.ru_322 zu.tlh.xh_433 
  0x3e232213, 0x5c005a08, 0x4c4079a0, 0x05006014,   // oc.ca.rm_665 sm.sa.un_430  war.lb.wo_322 vo.fr.un_660 
  0x02033f05, 0x341228af, 0x48006b08, 0x483525a0,   // af.nl.da_333 sd.ur.ps_655  ceb.tt.un_430 mn.tg.tt_322 
  // [e850]
  0x18003018, 0x18001904, 0x13360c07, 0x150a170b,   // uz.ar.un_740 gl.ga.un_320  sv.gn.et_432 sr.mk.un_542 
  0x380a0808, 0x2a004d18, 0x10460fa9, 0x10004419,   // uk.mk.tk_443 aa.mt.un_740  lv.qu.lt_544 kk.be.un_750 
  0x0d5c1ca6, 0x51544dec, 0x3b4d54a4, 0x4d3b51ec,   // mr.sa.ne_521 aa.ik.kl_644  ik.aa.so_433 kl.so.aa_644 
  0x3d3c1807, 0x122223a0, 0x2c000608, 0x5100fe0c,   // ar.ug.ku_432 ca.oc.hu_322  de.fy.un_430 tlh.kl.un_530 
  // [e860]
  0x2336370c, 0x364d3411, 0x54514dad, 0x330208ac,   // ba.ab.ky_543 xh.aa.gn_653  aa.kl.ik_643 no.da.nn_632 
  0x1f00180e, 0x08002007, 0x161029a9, 0x03322aee,   // ga.cy.un_550 sq.no.un_420  sl.lt.hr_544 mt.bs.nl_422 
  0x3b544d13, 0x21183dee, 0x4d3b540c, 0x51004d14,   // aa.ik.so_665 ku.ar.fa_422  ik.so.aa_543 aa.kl.un_660 
  0x39732804, 0x1f002313, 0x651f1d55, 0x02053908,   // sw.ny.br_332 ca.cy.un_650  la.cy.gv_442 br.fr.da_443 
  // [e870]
  0x422f1da0, 0x4505020c, 0x3f3927a0, 0x0a303ca4,   // la.su.co_322 da.fr.ln_543  gd.br.af_322 ug.uz.mk_433 
  0x0d2d0fa0, 0x3f004014, 0x38177565, 0x033f6012,   // lv.sk.cs_322 lb.af.un_660  nso.sr.tk_763 vo.af.nl_654 
  0x056339af, 0x3f39030e, 0x11530504, 0x110560a4,   // br.sco.fr_655 nl.br.af_555  fr.ht.ro_332 vo.fr.ro_433 
  0x18281260, 0x12283d0d, 0x11030507, 0x302348ac,   // ur.sd.ar_664 ku.sd.ur_554  fr.nl.ro_432 tt.ky.uz_632 
  // [e880]
  0x10441507, 0x0500110d, 0x5e00580d, 0x170a07a6,   // un.kk.be_432 ro.fr.un_540  om.ts.un_540 bg.mk.sr_521 
  0x053976ee, 0x5f377508, 0x5f371ea4, 0x0203050c,   // crs.br.fr_422 nso.st.tn_443  ms.st.tn_433 fr.nl.da_543 
  0x47645d0c, 0x114905a4, 0x48002323, 0x2679600c,   // ss.lg.sn_543 fr.to.ro_433  ky.tt.un_880 vo.war.ia_543 
  0x21001e08, 0x2b00160e, 0x202b02a0, 0x190b2402,   // ms.jw.un_430 hr.vi.un_550  da.vi.sq_322 eo.es.gl_222 
  // [e890]
  0x42054907, 0xfc3b58a0, 0x3b154c04, 0x3f4060a4,   // to.fr.co_432 om.so.zzp_322  wo.so.un_320 vo.lb.af_433 
  0x35643407, 0x3d123ba7, 0x222310a0, 0x00001737,   // xh.lg.zu_432 ks.ur.ku_532  lt.ca.oc_322 sr.un.un_B00 
  0x635813a7, 0x210d32a0, 0x371e1c13, 0x0a301708,   // et.om.sco_532 bs.cs.jw_322  id.ms.st_665 sr.uz.mk_443 
  0x1cfe470c, 0x2d0d32a4, 0x15110412, 0x531b47a7,   // sn.tlh.id_543 bs.cs.sk_433  ru.ro.un_654 sn.tr.ht_532 
  // [e8a0]
  0x47fa5da4, 0x5f5d6412, 0x321729a4, 0x5c2d2604,   // ss.nr.sn_433 lg.ss.tn_654  sl.sr.bs_433 ia.sk.sa_332 
  0x482279a0, 0x2b007904, 0x2b005104, 0x081710a0,   // war.oc.tt_322 war.vi.un_320  kl.vi.un_320 be.sr.uk_322 
  0x32002d02, 0x276a4904, 0x494b67a9, 0x2b494b11,   // sk.bs.un_220 to.haw.gd_332  ak.mi.to_544 mi.to.vi_653 
  0x0700240d, 0x373e24ad, 0x52132512, 0x51425a04,   // eo.it.un_540 eo.rm.st_643  eu.et.ha_654 sm.co.kl_332 
  // [e8b0]
  0x29100f0b, 0x2f2d0d02, 0x50005234, 0x011d020c,   // lv.lt.sl_542 cs.sk.su_222  ha.fj.un_A80 da.la.en_543 
  0x40033f11, 0x495a6aa9, 0x4e2450a4, 0x183e67a9,   // af.nl.lb_653 haw.sm.to_544  fj.eo.ay_433 ak.rm.ga_544 
  0x40040913, 0x10006e2a, 0x324252a7, 0x04000a0d,   // pl.fi.lb_665 hmn.lt.un_970  ha.co.bs_532 mk.ru.un_540 
  0x56001c2b, 0x0f112da4, 0x49006a29, 0x622c5a11,   // id.mg.un_980 sk.ro.lv_433  haw.to.un_960 sm.fy.kha_653 
  // [e8c0]
  0x454852ad, 0x3e002b2b, 0x1d424312, 0x4056090c,   // ha.tt.ln_643 vi.rm.un_980  ie.co.la_654 pl.mg.lb_543 
  0x3e004207, 0x10320fee, 0x19090b0c, 0x10171611,   // co.rm.un_420 lv.bs.lt_422  es.pl.gl_543 hr.sr.lt_653 
  0x033f2da0, 0x083f40a4, 0x303412a7, 0x2c1d01a0,   // sk.af.nl_322 lb.af.no_433  ur.ps.uz_532 en.la.fy_322 
  0x5200020c, 0x3f093e07, 0x360b1912, 0x252006a0,   // da.ha.un_530 rm.pl.af_432  gl.es.gn_654 de.sq.eu_322 
  // [e8d0]
  0x3e792860, 0x0f524d08, 0x0507015a, 0x034067ee,   // sw.war.rm_664 aa.ha.lv_443  en.it.fr_553 ak.lb.nl_422 
  0x062c39a0, 0x246756af, 0x294c1ea0, 0x1d4b5aa4,   // br.fy.de_322 mg.ak.eo_655  ms.wo.sl_322 sm.mi.la_433 
  0x0a004904, 0x030f090c, 0x10005807, 0x52001314,   // to.pt.un_320 pl.lv.nl_543  om.lt.un_420 et.ha.un_660 
  0x422643a9, 0x0b042d07, 0x182c27a7, 0x2c0940ad,   // ie.ia.co_544 sk.fi.es_432  gd.fy.ga_532 lb.pl.fy_643 
  // [e8e0]
  0x0f4629a0, 0x3d002121, 0x3f041da4, 0x270306a0,   // sl.qu.lv_322 fa.ku.un_860  la.fi.af_433 de.nl.gd_322 
  0x6b0465ee, 0x46190b0d, 0x0f002d02, 0x15101111,   // gv.fi.ceb_422 es.gl.qu_554  sk.lv.un_220 ro.be.un_653 
  0x1d000802, 0x15061fa0, 0x233038a6, 0x30000307,   // no.la.un_220 cy.de.un_322  tk.uz.ky_521 nl.uz.un_420 
  0x0300300c, 0x044425a7, 0x48233705, 0x042507a0,   // uz.nl.un_530 mn.kk.ru_532  ba.ky.tt_333 bg.mn.ru_322 
  // [e8f0]
  0x0d1629ee, 0x46163211, 0x181228a6, 0x231912ee,   // sl.hr.cs_422 bs.hr.qu_653  sd.ur.ar_521 hu.gl.ca_422 
  0x654d5811, 0x2a00581a, 0x04302307, 0x42002c19,   // om.aa.gv_653 om.mt.un_760  ky.uz.ru_432 fy.co.un_750 
  0x0c4a30a7, 0x2afe5707, 0x07422aa4, 0x48302305,   // uz.yo.sv_532 na.tlh.mt_432  mt.co.it_433 ky.uz.tt_333 
  0x374838ad, 0x586a69a0, 0x30002f13, 0x53796b0c,   // tk.tt.ba_643 mfe.haw.om_322  su.uz.un_650 ceb.war.ht_543 
  // [e900]
  0x245c21ac, 0x0c002412, 0x09002305, 0x39242507,   // jw.sa.eo_632 eo.sv.un_640  ca.pl.un_330 eu.eo.br_432 
  0x5c0e0305, 0x0c5c4607, 0x2f2d5c07, 0x654d01a0,   // nl.is.sa_333 qu.sa.sv_432  sa.sk.su_432 en.aa.gv_322 
  0x173523a0, 0x38004904, 0x2344150c, 0x31304d5a,   // ky.tg.sr_322 to.tk.un_320  un.kk.ky_543 aa.uz.az_553 
  0x4d00300e, 0x402c06ad, 0x040711ad, 0x46364e12,   // uz.aa.un_550 de.fy.lb_643  ro.bg.ru_643 ay.gn.qu_654 
  // [e910]
  0x4b001504, 0x565c2a08, 0x29004d07, 0x30001d07,   // un.mi.un_320 mt.sa.mg_443  aa.sl.un_420 la.uz.un_420 
  0x62252a08, 0x12604208, 0x11425ca4, 0x1030380b,   // mt.eu.kha_443 co.vo.hu_443  sa.co.ro_433 tk.uz.be_542 
  0x0a080402, 0x111715ad, 0x0c005202, 0x2300380e,   // ru.uk.mk_222 un.sr.ro_643  ha.sv.un_220 tk.ky.un_550 
  0x466a1c0b, 0x4e1a46ec, 0x4e5c1c07, 0x04081702,   // id.haw.qu_542 qu.tl.ay_644  id.sa.ay_432 sr.uk.ru_222 
  // [e920]
  0x377560ad, 0xfc006229, 0x6b5c1a0c, 0x46002a13,   // vo.nso.st_643 kha.zzp.un_960  tl.sa.ceb_543 mt.qu.un_650 
  0x39193302, 0x04001105, 0x0d002b05, 0x17483811,   // nn.gl.br_222 ro.fi.un_330  vi.cs.un_330 tk.tt.sr_653 
  0x3b4830ee, 0x080c31a0, 0x6b4e1d12, 0x47045ca4,   // uz.tt.so_422 az.sv.no_322  la.ay.ceb_654 sa.fi.sn_433 
  0x0d092daf, 0x30353608, 0x28731e0c, 0x5c4e460d,   // sk.pl.cs_655 ab.tg.uz_443  ms.ny.sw_543 qu.ay.sa_554 
  // [e930]
  0x33003f07, 0x5a001f04, 0x461a1ca4, 0x5100041a,   // af.nn.un_420 cy.sm.un_320  id.tl.qu_433 fi.kl.un_760 
  0x2c000e02, 0x4818fca7, 0x301711ad, 0x07003c04,   // is.fy.un_220 zzp.ga.tt_532  ro.sr.uz_643 ug.bg.un_320 
  0x791165ac, 0x040d1d55, 0x3f041308, 0x1d26010b,   // gv.ro.war_632 la.cs.fi_442  et.fi.af_443 en.ia.la_542 
  0x49016e04, 0x401206a4, 0x183d3bac, 0x0f10fea7,   // hmn.en.to_332 de.hu.lb_433  ks.ku.ar_632 tlh.lt.lv_532 
  // [e940]
  0x23213008, 0xfe004219, 0xfe00460c, 0x05596a0c,   // uz.fa.ky_443 co.tlh.un_750  qu.tlh.un_530 haw.rn.fr_543 
  0x20001e0e, 0x311b480e, 0x53473ea0, 0x6e00fe13,   // am.ti.un_550 tt.tr.az_555  rm.sn.ht_322 tlh.hmn.un_650 
  0x481b310b, 0x03020509, 0x1b483108, 0x30122807,   // az.tr.tt_542 fr.da.nl_444  az.tt.tr_443 sd.ur.uz_432 
  0x5e005f09, 0x36135a07, 0x6e0efe12, 0xfe1d30a4,   // tn.ts.un_440 sm.et.gn_432  tlh.is.hmn_654 uz.la.tlh_433 
  // [e950]
  0x43073e0c, 0x125f3707, 0xfe006e1b, 0x3000fe23,   // rm.it.ie_543 st.tn.hu_432  hmn.tlh.un_770 tlh.uz.un_880 
  0x5f7337a0, 0x2a1d36a0, 0x321636a4, 0x1d00260e,   // st.ny.tn_322 gn.la.mt_322  gn.hr.bs_433 ia.la.un_550 
  0x2d0dfea0, 0x19000a21, 0x1515110c, 0x020545af,   // tlh.cs.sk_322 pt.gl.un_860  ro.un.un_530 ln.fr.da_655 
  0x214936a0, 0x0a043c07, 0x372344af, 0x201712a0,   // gn.to.jw_322 ug.ru.mk_432  kk.ky.ba_655 hu.sr.sq_322 
  // [e960]
  0x73364b04, 0x4a075f08, 0x025a45a7, 0x523f30a0,   // mi.gn.ny_332 tn.it.yo_443  ln.sm.da_532 uz.af.ha_322 
  0x17083c12, 0x07170aa6, 0x48351507, 0x10442508,   // ug.uk.sr_654 mk.sr.bg_521  un.tg.tt_432 mn.kk.be_443 
  0x0d5c1c14, 0x18283d04, 0x35005907, 0x2c006808,   // mr.sa.ne_666 ku.sd.ar_332  rn.zu.un_420 ig.fy.un_430 
  0x36002e0c, 0x352538a9, 0x040a15a4, 0x08001122,   // fo.gn.un_530 tk.mn.tg_544  un.mk.ru_433 ro.uk.un_870 
  // [e970]
  0x35005d0d, 0x21004804, 0x475973a4, 0x24003505,   // ss.zu.un_540 tt.jw.un_320  ny.rn.sn_433 zu.eo.un_330 
  0x6b495c08, 0x0f003f07, 0x2a5e5f05, 0x1f006b08,   // sa.to.ceb_443 af.lv.un_420  tn.ts.mt_333 ceb.cy.un_430 
  0x3800310e, 0x4b4936a4, 0x68002b22, 0x68550213,   // az.tk.un_550 gn.to.mi_433  vi.ig.un_870 da.rw.ig_665 
  0x4b686a13, 0x62002734, 0x3700280d, 0x20275860,   // haw.ig.mi_665 gd.kha.un_A80  sw.st.un_540 om.gd.sq_664 
  // [e980]
  0x1f5f47ee, 0x49366a5a, 0x361f685a, 0x26780102,   // sn.tn.cy_422 haw.gn.to_553  ig.cy.gn_553 en.ve.ia_222 
  0x677368ad, 0x47001d05, 0x250a1709, 0x041037a0,   // ig.ny.ak_643 la.sn.un_330  sr.mk.mn_444 ba.be.ru_322 
  0x2f595508, 0x2100fe04, 0x1c1b750c, 0x27475c0d,   // rw.rn.su_443 tlh.jw.un_320  nso.tr.id_543 sa.sn.gd_554 
  0x2d342007, 0x07794208, 0x20583b08, 0x21283007,   // sq.xh.sk_432 co.war.it_443  so.om.sq_443 uz.sd.fa_432 
  // [e990]
  0x6b00361b, 0xfc003b07, 0x11fe650c, 0x30526212,   // gn.ceb.un_770 so.zzp.un_420  gv.tlh.ro_543 kha.ha.uz_654 
  0x1100252b, 0x34622ba4, 0x35346eec, 0x3e002008,   // mn.ro.un_980 vi.kha.xh_433  hmn.xh.zu_644 sq.rm.un_430 
  0x00007842, 0x374b63ad, 0x0815040c, 0x6a493605,   // ve.un.un_C00 sco.mi.st_643  ru.uk.un_530 gn.to.haw_333 
  0x2620280c, 0x37651f09, 0x390f15a0, 0x634b01a9,   // sw.sq.ia_543 cy.gv.st_444  un.lv.br_322 en.mi.sco_544 
  // [e9a0]
  0x03005104, 0x75630111, 0x08041712, 0x362f38a0,   // kl.nl.un_320 en.sco.nso_653  sr.ru.uk_654 tk.su.gn_322 
  0x59550da9, 0x1e2b1504, 0x796b1a12, 0x03001505,   // cs.rw.rn_544 un.vi.ms_332  tl.ceb.war_654 un.nl.un_330 
  0x44003818, 0x34003913, 0x36271508, 0x15631d08,   // tk.kk.un_740 br.xh.un_650  un.gd.gn_443 la.sco.un_443 
  0x5f3756a4, 0x122118af, 0x48234409, 0x2a001505,   // mg.st.tn_433 ar.fa.ur_655  kk.ky.tt_444 un.mt.un_330 
  // [e9b0]
  0x48335010, 0x4800040d, 0x46004d0c, 0x303c380c,   // fj.nn.tt_642 fi.tt.un_540  aa.qu.un_530 tk.ug.uz_543 
  0x4e001314, 0x2500480d, 0x0c1062a7, 0x09003618,   // et.ay.un_660 tt.mn.un_540  kha.lt.sv_532 gn.pl.un_740 
  0x17110a09, 0x24043007, 0x2c0e2ea9, 0x2a1f1807,   // mk.ro.sr_444 uz.fi.eo_432  fo.is.fy_544 ga.cy.mt_432 
  0x1d002404, 0x2330480c, 0x2d002c0c, 0x27001012,   // eo.la.un_320 tt.uz.ky_543  fy.sk.un_530 lt.gd.un_640 
  // [e9c0]
  0x2f1a2155, 0x79001005, 0x1e763f12, 0x1c005304,   // jw.tl.su_442 lt.war.un_330  af.crs.ms_654 ht.id.un_320 
  0x2e000d07, 0x4b1f49a4, 0x23363704, 0x1e1c40af,   // cs.fo.un_420 to.cy.mi_433  ba.ab.ky_332 lb.id.ms_655 
  0x27005302, 0x2a001e08, 0x17373cee, 0x07100407,   // ht.gd.un_220 ms.mt.un_430  ug.ba.sr_422 ru.be.bg_432 
  0x53002a08, 0x12343d0c, 0x041017ad, 0x30081507,   // mt.ht.un_430 ku.ps.ur_543  sr.be.ru_643 un.uk.uz_432 
  // [e9d0]
  0x34182108, 0x291632a0, 0x10040107, 0x093953a7,   // fa.ar.ps_443 bs.hr.sl_322  en.fi.lt_432 ht.br.pl_532 
  0x070417a9, 0x15303605, 0x2f002405, 0x05fc0107,   // sr.ru.bg_544 ab.uz.un_333  eo.su.un_330 en.zzp.fr_432 
  0x5c0218ad, 0x2800490d, 0x79003e1a, 0x5a5c4904,   // ga.da.sa_643 to.sw.un_540  rm.war.un_760 to.sa.sm_332 
  0x4d40690c, 0x5c000e07, 0x165c30ee, 0x35345aee,   // mfe.lb.aa_543 is.sa.un_420  uz.sa.hr_422 sm.xh.zu_422 
  // [e9e0]
  0x0804100d, 0x10005219, 0x5c2d0d09, 0x5a001d05,   // be.ru.uk_554 ha.lt.un_750  cs.sk.sa_444 la.sm.un_330 
  0x3e5842ee, 0x1d005811, 0x070830a7, 0x55004d0c,   // co.om.rm_422 om.la.un_630  uz.uk.bg_532 aa.rw.un_530 
  0x06002502, 0x30002a07, 0x234844a0, 0x300a355a,   // eu.de.un_220 mt.uz.un_420  kk.tt.ky_322 tg.mk.uz_553 
  0x5c003009, 0x3748110c, 0x022855ee, 0x312f0408,   // uz.sa.un_440 ro.tt.ba_543  rw.sw.da_422 fi.su.az_443 
  // [e9f0]
  0x0e002d07, 0x21343060, 0x040807af, 0x600c0107,   // sk.is.un_420 uz.ps.fa_664  bg.uk.ru_655 en.sv.vo_432 
  0x79000107, 0x202a17a0, 0x791001a4, 0x352336a4,   // en.war.un_420 sr.mt.sq_322  en.lt.war_433 ab.ky.tg_433 
  0x183d21af, 0x313065ee, 0x08171507, 0x5e7345af,   // fa.ku.ar_655 gv.uz.az_422  un.sr.uk_432 ln.ny.ts_655 
  0x630f010c, 0x13010f11, 0x404c04ec, 0x34183007,   // en.lv.sco_543 lv.en.et_653  fi.wo.lb_644 uz.ar.ps_432 
  // [ea00]
  0x15002f02, 0xfc631304, 0x390f010c, 0x4575210c,   // su.un.un_220 et.sco.zzp_332  en.lv.br_543 jw.nso.ln_543 
  0x35041512, 0x02402da4, 0x34fc1da7, 0x31483807,   // un.ru.tg_654 sk.lb.da_433  la.zzp.xh_532 tk.tt.az_432 
  0x5f02750c, 0x20007319, 0x59007313, 0x08442355,   // nso.da.tn_543 ny.sq.un_750  ny.rn.un_650 ky.kk.uk_442 
  0x192f6007, 0x291d260d, 0x5b007314, 0x2d00120d,   // vo.su.gl_432 ia.la.sl_554  ny.sg.un_660 hu.sk.un_540 
  // [ea10]
  0x4800381a, 0x3f032c07, 0xfc684aad, 0x25080402,   // tk.tt.un_760 fy.nl.af_432  yo.ig.zzp_643 ru.uk.mn_222 
  0x68005b2a, 0x4a00682c, 0x55fc5955, 0x212f5da0,   // sg.ig.un_970 ig.yo.un_990  rn.zzp.rw_442 ss.su.jw_322 
  0x361550a0, 0x462d0d02, 0x2d004202, 0x1d050704,   // fj.gn.un_320 cs.sk.qu_222  co.sk.un_220 it.fr.la_332 
  0x303c4812, 0x4d005e19, 0x0c2e08ee, 0x2d090d07,   // tt.ug.uz_654 ts.aa.un_750  no.fo.sv_422 cs.pl.sk_432 
  // [ea20]
  0x11225d0b, 0x5c1c0914, 0x0b2d02ee, 0x3600150e,   // ss.oc.ro_542 hi.mr.sa_666  da.sk.es_422 un.ab.un_550 
  0x504b79a9, 0x2f001c0b, 0x39004902, 0x2f000509,   // war.mi.fj_544 id.su.un_520  to.br.un_220 fr.su.un_440 
  0x58003004, 0x311238a7, 0x506a600c, 0x1500361a,   // uz.om.un_320 tk.hu.az_532  vo.haw.fj_543 ab.un.un_760 
  0x6851250c, 0x495865a0, 0x3412305a, 0x4000650c,   // eu.kl.ig_543 gv.om.to_322  uz.ur.ps_553 gv.lb.un_530 
  // [ea30]
  0x4410250d, 0x4afc25af, 0x64556808, 0x0410235a,   // mn.be.kk_554 eu.zzp.yo_655  ig.rw.lg_443 ky.be.ru_553 
  0x362325ad, 0x5700510d, 0x06404307, 0x3868570c,   // mn.ky.ab_643 kl.na.un_540  ie.lb.de_432 na.ig.tk_543 
  0x4825110b, 0x6800650d, 0x25001905, 0x7900620d,   // ro.mn.tt_542 gv.ig.un_540  gl.eu.un_330 kha.war.un_540 
  0x37442309, 0x1a35340c, 0x4423360d, 0x3000580d,   // ky.kk.ba_444 xh.zu.tl_543  ab.ky.kk_554 om.uz.un_540 
  // [ea40]
  0x071023a0, 0x35341ea9, 0xfe3b4dad, 0x353433a0,   // ky.be.bg_322 ms.xh.zu_544  aa.so.tlh_643 nn.xh.zu_322 
  0x38282102, 0x17080455, 0x5d3473a4, 0x55280804,   // jw.sw.tk_222 ru.uk.sr_442  ny.xh.ss_433 no.sw.rw_332 
  0x01001f12, 0x3b004804, 0x484654ec, 0x6e352108,   // cy.en.un_640 tt.so.un_320  ik.qu.tt_644 jw.zu.hmn_443 
  0x073c35ad, 0x240ffc02, 0x02125ca0, 0x25374808,   // tg.ug.bg_643 zzp.lv.eo_222  sa.hu.da_322 tt.ba.mn_443 
  // [ea50]
  0x383f1f05, 0xfa735ca4, 0x28000202, 0x363515ec,   // cy.af.tk_333 sa.ny.nr_433  da.sw.un_220 un.tg.ab_644 
  0x065102a0, 0x27357308, 0x1162670c, 0x5c3501a0,   // da.kl.de_322 ny.zu.gd_443  ak.kha.ro_543 en.zu.sa_322 
  0x24131004, 0x4815370c, 0x170a0404, 0x36001208,   // lt.et.eo_332 ba.tt.un_530  ru.mk.sr_332 hu.gn.un_430 
  0x1d00690d, 0x12182d04, 0x38003107, 0x18120e0c,   // mfe.la.un_540 sk.ga.hu_332  az.tk.un_420 is.hu.ga_543 
  // [ea60]
  0x090e2e0b, 0x02000704, 0x2e001208, 0x06021108,   // fo.is.pl_542 it.da.un_320  hu.fo.un_430 ro.da.de_443 
  0x060e670d, 0x381b48ad, 0x13581c04, 0x58630107,   // ak.is.de_554 tt.tr.tk_643  id.om.et_332 en.sco.om_432 
  0x12000b02, 0x1a4c01a0, 0xfc5c4655, 0x460279a7,   // es.hu.un_220 en.wo.tl_322  qu.sa.zzp_442 war.da.qu_532 
  0x1a634c12, 0x0e2e2c08, 0x4c583f07, 0x12021c04,   // wo.sco.tl_654 fy.fo.is_443  af.om.wo_432 id.da.hu_332 
  // [ea70]
  0x654c63ad, 0x252304a0, 0x343d3b0b, 0x17350aa9,   // sco.wo.gv_643 ru.ky.mn_322  ks.ku.ps_542 mk.tg.sr_544 
  0x090d13a4, 0x79001a2b, 0x3b1a63ad, 0x63000109,   // bh.ne.hi_433 tl.war.un_980  sco.tl.so_643 en.sco.un_440 
  0x4c001a02, 0x3f036313, 0x38374411, 0x46000108,   // tl.wo.un_220 sco.nl.af_665  kk.ba.tk_653 en.qu.un_430 
  0x0ffc46ec, 0x330804a0, 0x2c000404, 0x2d0d0902,   // qu.zzp.lv_644 fi.no.nn_322  fi.fy.un_320 pl.cs.sk_222 
  // [ea80]
  0x21182804, 0x06483810, 0x4c122f08, 0x07171055,   // sd.ar.fa_332 tk.tt.de_642  su.hu.wo_443 be.sr.bg_442 
  0x04170812, 0x18285aaf, 0x18492704, 0x28025007,   // uk.sr.ru_654 sm.sw.ga_655  gd.to.ga_332 fj.da.sw_432 
  0x25006b04, 0x03154207, 0x6301050c, 0x321710a4,   // ceb.eu.un_320 co.nl.un_420  fr.en.sco_543 lt.sr.bs_433 
  0x0c2322ec, 0x03002a12, 0x20430c04, 0x07040aad,   // oc.ca.sv_644 mt.nl.un_640  sv.ie.sq_332 mk.ru.bg_643 
  // [ea90]
  0x3e2301a4, 0x38003521, 0x0f004309, 0x300a3514,   // en.ca.rm_433 tg.tk.un_860  ie.lv.un_440 tg.mk.uz_666 
  0x16365a04, 0x45001208, 0x11005105, 0x273839a4,   // sm.gn.hr_332 hu.ln.un_430  kl.ro.un_330 br.tk.gd_433 
  0x27005a04, 0x0a0817ec, 0x02632a0c, 0x432601a9,   // sm.gd.un_320 sr.uk.mk_644  mt.sco.da_543 en.ia.ie_544 
  0x170f4907, 0x1200090e, 0x0d2d4dad, 0x05003e07,   // to.lv.sr_432 pl.hu.un_550  aa.sk.cs_643 rm.fr.un_420 
  // [eaa0]
  0x06120ca0, 0x156301a4, 0x5e001f05, 0x0e2e0655,   // sv.hu.de_322 en.sco.un_433  cy.ts.un_330 de.fo.is_442 
  0x0c4d2aa9, 0x43006b18, 0x4a002205, 0x620afc0c,   // mt.aa.sv_544 ceb.ie.un_740  oc.yo.un_330 zzp.pt.kha_543 
  0x0d005102, 0x23225109, 0x3d004404, 0x311b4855,   // kl.cs.un_220 kl.oc.ca_444  kk.ku.un_320 tt.tr.az_442 
  0x43110da4, 0x57001f0e, 0x4400381a, 0x5376010c,   // cs.ro.ie_433 cy.na.un_550  tk.kk.un_760 en.crs.ht_543 
  // [eab0]
  0x1f002c19, 0xfc002a04, 0x375d5f0b, 0x5d35fea9,   // fy.cy.un_750 mt.zzp.un_320  tn.ss.st_542 tlh.zu.ss_544 
  0x31381b0c, 0x30233809, 0x33083fa0, 0x39761f14,   // tr.tk.az_543 tk.ky.uz_444  af.no.nn_322 cy.crs.br_666 
  0x6534fc0c, 0x5a473ba6, 0x65004805, 0x1d612fec,   // zzp.xh.gv_543 so.sn.sm_521  tt.gv.un_330 su.za.la_644 
  0x0000482d, 0x67005819, 0x38005f04, 0x2f00490e,   // tt.un.un_A00 om.ak.un_750  tn.tk.un_320 to.su.un_550 
  // [eac0]
  0x3b781f05, 0x2c5d2107, 0x08000d04, 0x231130af,   // cy.ve.so_333 jw.ss.fy_432  cs.no.un_320 uz.ro.ky_655 
  0x214423a0, 0x0b002202, 0x38484cad, 0x394c4812,   // ky.kk.fa_322 oc.es.un_220  wo.tt.tk_643 tt.wo.br_654 
  0x363844ad, 0x6a004921, 0x6a005a1b, 0x35302302,   // kk.tk.ab_643 to.haw.un_860  sm.haw.un_770 ky.uz.tg_222 
  0x18006e08, 0x4200230c, 0x23170aa0, 0x0415080b,   // hmn.ga.un_430 ca.co.un_530  mk.sr.ky_322 uk.ru.un_520 
  // [ead0]
  0x0438370c, 0x1e160da0, 0x0a484408, 0x59735809,   // ba.tk.ru_543 cs.hr.ms_322  kk.tt.mk_443 om.ny.rn_444 
  0x46156804, 0x0e2e2ca7, 0x4654fe0e, 0x1d4318ad,   // ig.qu.un_320 fy.fo.is_532  tlh.ik.qu_555 ga.ie.la_643 
  0x5a006a12, 0x19186508, 0x03002804, 0x30314da7,   // haw.sm.un_640 gv.ga.gl_443  sw.nl.un_320 aa.az.uz_532 
  0x4d005807, 0x13364a08, 0x18001508, 0x206432a4,   // om.aa.un_420 yo.gn.et_443  un.ga.un_430 bs.lg.sq_433 
  // [eae0]
  0x46544da4, 0x6835360c, 0x59361c0c, 0x190b23a9,   // aa.ik.qu_433 gn.zu.ig_543  id.gn.rn_543 ca.es.gl_544 
  0x29330813, 0xfe005819, 0x2032160d, 0xfe00500e,   // no.nn.sl_665 om.tlh.un_750  hr.bs.sq_554 fj.tlh.un_550 
  0x28000304, 0x36204aee, 0x2d0d5cee, 0x2c001604,   // nl.sw.un_320 yo.sq.gn_422  sa.cs.sk_422 hr.fy.un_320 
  0x3d34300b, 0x1c204d04, 0x732120ac, 0x22000a08,   // uz.ps.ku_542 aa.sq.id_332  sq.jw.ny_632 pt.oc.un_430 
  // [eaf0]
  0x474a36a7, 0x3035fe0c, 0x2d290d0e, 0x053320a0,   // gn.yo.sn_532 tlh.zu.uz_543  cs.sl.sk_555 sq.nn.fr_322 
  0x293216a0, 0x08203312, 0x5e005814, 0x48303c12,   // hr.bs.sl_322 nn.sq.no_654  om.ts.un_660 ug.uz.tt_654 
  0x04120cee, 0x0c0204af, 0x3046500c, 0x221803a0,   // sv.hu.fi_422 fi.da.sv_655  fj.qu.uz_543 nl.ga.oc_322 
  0x16042904, 0x2500480b, 0x011803a0, 0x0100182a,   // sl.fi.hr_332 tt.mn.un_520  nl.ga.en_322 ar.iw.un_970 
  // [eb00]
  0x5efe300d, 0x12342809, 0x5900731a, 0x210302a0,   // uz.tlh.ts_554 sd.ps.ur_444  ny.rn.un_760 da.nl.jw_322 
  0x4e003119, 0x2123300c, 0x03001302, 0x171620a4,   // az.ay.un_750 uz.ky.fa_543  et.nl.un_220 sq.hr.sr_433 
  0x19620a12, 0x1f3865af, 0x0a1ffe0d, 0x283b180c,   // pt.kha.gl_654 gv.tk.cy_655  tlh.cy.pt_554 ar.ks.sd_543 
  0x0f4f10a9, 0x2d001223, 0x0b0f10ec, 0x3500281a,   // lt.bi.lv_544 hu.sk.un_880  lt.lv.es_644 sw.zu.un_760 
  // [eb10]
  0x22090ba4, 0x1906050c, 0x48003711, 0x36003813,   // es.pl.oc_433 fr.de.gl_543  ba.tt.un_630 tk.ab.un_650 
  0x2100122a, 0x0b2419ec, 0x6b791a11, 0x23072508,   // ur.fa.un_970 gl.eo.es_644  tl.war.ceb_653 mn.bg.ky_443 
  0x190a2309, 0x52004c13, 0x2f00581a, 0x2b3768ad,   // ca.pt.gl_444 wo.ha.un_650  om.su.un_760 ig.st.vi_643 
  0x37065fa0, 0x0d00100e, 0x48443007, 0x190b26ec,   // tn.de.st_322 lt.cs.un_550  uz.kk.tt_432 ia.es.gl_644 
  // [eb20]
  0x18004702, 0x1b00060d, 0x4c00670d, 0x3d003c19,   // sn.ga.un_220 de.tr.un_540  ak.wo.un_540 ug.ku.un_750 
  0xfe003622, 0x5760fe0c, 0x351f5d07, 0x53696455,   // gn.tlh.un_870 tlh.vo.na_543  ss.cy.zu_432 lg.mfe.ht_442 
  0x30003302, 0xfe004a21, 0x1e2f1caf, 0x541104a4,   // nn.uz.un_220 yo.tlh.un_860  id.su.ms_655 fi.ro.ik_433 
  0x24001f0e, 0x65005e07, 0x11000735, 0x0c005104,   // cy.eo.un_550 ts.gv.un_420  bg.ro.un_A90 kl.sv.un_320 
  // [eb30]
  0x1c1f5002, 0x22005102, 0x34281860, 0x190306a4,   // fj.cy.id_222 kl.oc.un_220  ar.sd.ps_664 de.nl.gl_433 
  0x11232202, 0x400302ee, 0x6b1b1dec, 0x112322a4,   // oc.ca.ro_222 da.nl.lb_422  la.tr.ceb_644 oc.ca.ro_433 
  0x37020c07, 0x394205a7, 0x202f1d04, 0x2f205109,   // sv.da.st_432 fr.co.br_532  la.su.sq_332 kl.sq.su_444 
  0x23431daf, 0x475a4904, 0x123506ee, 0x10301112,   // la.ie.ca_655 to.sm.sn_332  de.zu.hu_422 ro.uz.be_654 
  // [eb40]
  0x341b68ee, 0x302821a4, 0x4f003709, 0x0d0f76a0,   // ig.tr.xh_422 fa.sd.uz_433  st.bi.un_440 crs.lv.cs_322 
  0x10003608, 0x343d210d, 0x311b4809, 0x131c0911,   // ab.be.un_430 fa.ku.ps_554  tt.tr.az_444 hi.mr.bh_653 
  0x30001214, 0x480830a0, 0x28214408, 0x1b0112ee,   // hu.uz.un_660 uz.uk.tt_322  kk.fa.sd_443 hu.en.tr_422 
  0xfc123ba0, 0x30380c07, 0x2500460c, 0x0c121fa7,   // so.hu.zzp_322 sv.tk.uz_432  qu.eu.un_530 cy.hu.sv_532 
  // [eb50]
  0x5a4b49a0, 0x08353002, 0x173048a0, 0x6937010c,   // to.mi.sm_322 uz.tg.uk_222  tt.uz.sr_322 en.st.mfe_543 
  0x4c5804a0, 0x45002512, 0x190b01a4, 0x0c002018,   // fi.om.wo_322 eu.ln.un_640  en.es.gl_433 sq.sv.un_740 
  0x250648a0, 0x11060111, 0x300c48a0, 0x5b1d1f08,   // tt.de.eu_322 en.de.ro_653  tt.sv.uz_322 cy.la.sg_443 
  0x23000604, 0x04002202, 0x3600190c, 0x555f01a0,   // de.ca.un_320 oc.fi.un_220  gl.gn.un_530 en.tn.rw_322 
  // [eb60]
  0x38304da4, 0x48002923, 0x1d641208, 0x3d1221ac,   // aa.uz.tk_433 sl.tt.un_880  hu.lg.la_443 fa.ur.ku_632 
  0x19004e14, 0x0c2d1d55, 0x53204da4, 0x06004a08,   // ay.gl.un_660 la.sk.sv_442  aa.sq.ht_433 yo.de.un_430 
  0x1900460d, 0x2a2322a4, 0x755701ee, 0x20000d20,   // qu.gl.un_540 oc.ca.mt_433  en.na.nso_422 cs.sq.un_850 
  0x3f2f0107, 0x1d1060ec, 0x3bfe2a05, 0x065e470c,   // en.su.af_432 vo.lt.la_644  mt.tlh.so_333 sn.ts.de_543 
  // [eb70]
  0x44253cee, 0x491dfca4, 0x207330ad, 0x482a21a0,   // ug.mn.kk_422 zzp.la.to_433  uz.ny.sq_643 jw.mt.tt_322 
  0x20114309, 0x1e1c22a4, 0x39002305, 0x401f0607,   // ie.ro.sq_444 oc.id.ms_433  ca.br.un_330 de.cy.lb_432 
  0x064d1e05, 0x330820ee, 0x173715a6, 0x0b2519a7,   // ms.aa.de_333 sq.no.nn_422  un.ba.sr_521 gl.eu.es_532 
  0x30001813, 0x213d3055, 0x34303d08, 0x250415a9,   // ar.uz.un_650 uz.ku.fa_442  ku.uz.ps_443 un.ru.mn_544 
  // [eb80]
  0x1f2d0d02, 0x535f36a7, 0x25001904, 0x10003809,   // cs.sk.cy_222 gn.tn.ht_532  gl.eu.un_320 tk.lt.un_440 
  0x790b1912, 0x4b1536a6, 0x53364908, 0x25197955,   // gl.es.war_654 gn.mi.un_510  to.gn.ht_443 war.gl.eu_442 
  0xfc004d19, 0x040a07a9, 0x5f00361b, 0x5f003605,   // aa.zzp.un_750 bg.mk.ru_544  gn.tn.un_770 gn.tn.un_330 
  0x1d1501a4, 0x386b1dad, 0x594a560c, 0x25070407,   // en.la.un_430 la.ceb.tk_643  mg.yo.rn_543 ru.bg.mn_432 
  // [eb90]
  0x5c003607, 0x206521a4, 0x07fc4204, 0x0a2307a9,   // gn.sa.un_420 jw.gv.sq_433  co.zzp.it_332 bg.ky.mk_544 
  0x4f3605a4, 0x6725360c, 0x370407a4, 0x65393307,   // fr.gn.bi_433 gn.eu.ak_543  bg.ru.ba_433 nn.br.gv_432 
  0x1e4736ad, 0x051136a0, 0x1f233e0c, 0x04351504,   // gn.sn.ms_643 gn.ro.fr_322  rm.ca.cy_543 un.tg.ru_332 
  0x1f006309, 0xfc004d2b, 0x421d0a0c, 0x23152507,   // sco.cy.un_440 aa.zzp.un_980  pt.la.co_543 mn.ky.un_420 
  // [eba0]
  0x443007ee, 0x081715af, 0x070411ad, 0x67006835,   // bg.uz.kk_422 un.sr.uk_655  ro.ru.bg_643 ig.ak.un_A90 
  0x5a006a2b, 0x11653913, 0x490f30a0, 0x046013ec,   // haw.sm.un_980 br.gv.ro_665  uz.lv.to_322 et.vo.fi_644 
  0x2f6357a4, 0x2559550c, 0xfc685108, 0x291642ee,   // na.sco.su_433 rw.rn.eu_543  kl.ig.zzp_443 co.hr.sl_422 
  0x482344ac, 0x1f002f04, 0x10472113, 0x646867ec,   // kk.ky.tt_632 su.cy.un_320  jw.sn.lt_665 ak.ig.lg_644 
  // [ebb0]
  0x2c060304, 0x47204ca7, 0x071115a4, 0x27000f02,   // nl.de.fy_332 wo.sq.sn_532  un.ro.bg_433 lv.gd.un_220 
  0x36001f2a, 0x151025ee, 0x0a18120b, 0x073e2a0c,   // cy.gn.un_970 mn.be.un_422  ur.ar.mk_542 mt.rm.it_543 
  0x576801a4, 0x635c1c0c, 0x300365a0, 0x65201f0c,   // en.ig.na_433 id.sa.sco_543  gv.nl.uz_322 cy.sq.gv_543 
  0x1c005a07, 0x240667ee, 0x0e001704, 0x4700490d,   // sm.id.un_420 ak.de.eo_422  sr.is.un_320 to.sn.un_540 
  // [ebc0]
  0x04134212, 0x2325480e, 0x18211207, 0x355a0a0e,   // co.et.fi_654 tt.mn.ky_555  ur.fa.ar_432 pt.sm.zu_555 
  0x0f00151b, 0x0a3730a4, 0x42005c05, 0x0e400c12,   // un.lv.un_770 uz.ba.mk_433  sa.co.un_330 sv.lb.is_654 
  0x050e01a4, 0x1708040c, 0x2a1703a7, 0x0b223607,   // en.is.fr_433 ru.uk.sr_543  nl.sr.mt_532 gn.oc.es_432 
  0x3e000113, 0x57154c0c, 0x01586b04, 0x282118ac,   // en.rm.un_650 wo.na.un_530  ceb.om.en_332 ar.fa.sd_632 
  // [ebd0]
  0x290d2da4, 0x42180f0b, 0x38004c0c, 0x18233d07,   // sk.cs.sl_433 lv.ga.co_542  wo.tk.un_530 ku.ky.ar_432 
  0x2e000213, 0x35011fa4, 0x0e000f0e, 0x18213ba0,   // da.fo.un_650 cy.en.zu_433  lv.is.un_550 ks.fa.ar_322 
  0x2263010c, 0x64004c0c, 0x21464e07, 0x73644cec,   // en.sco.oc_543 wo.lg.un_530  ay.qu.jw_432 wo.lg.ny_644 
  0x535625a0, 0x344c73ee, 0x16001019, 0x401d06a4,   // eu.mg.ht_322 ny.wo.xh_422  lt.hr.un_750 de.la.lb_433 
  // [ebe0]
  0x212f3808, 0x1700fe07, 0x25000f13, 0x1d182711,   // tk.su.jw_443 tlh.sr.un_420  lv.eu.un_650 gd.ga.la_653 
  0x641725ee, 0x1f040c02, 0x1d002502, 0x73004c0c,   // eu.sr.lg_422 sv.fi.cy_222  eu.la.un_220 wo.ny.un_530 
  0x21303dad, 0x08071002, 0x3e1d21a0, 0x273f42a0,   // ku.uz.fa_643 be.bg.uk_222  jw.la.rm_322 co.af.gd_322 
  0x111d790c, 0x1a394fa7, 0x23190b09, 0x4c005d14,   // war.la.ro_543 bi.br.tl_532  es.gl.ca_444 ss.wo.un_660 
  // [ebf0]
  0x32550b0c, 0x00002f24, 0x20094dee, 0x1d1211ee,   // es.rw.bs_543 su.un.un_900  aa.pl.sq_422 ro.hu.la_422 
  0x1d0922ec, 0x2d320d07, 0x292d0f07, 0x121642ee,   // oc.pl.la_644 cs.bs.sk_432  lv.sk.sl_432 co.hr.hu_422 
  0x22110907, 0x190b5da4, 0x0b3619a4, 0x073036a0,   // pl.ro.oc_432 ss.es.gl_433  gl.gn.es_433 ab.uz.bg_322 
  0x12004d1a, 0x4f182714, 0x6b004f0d, 0x5c003505,   // aa.hu.un_760 gd.ga.bi_666  bi.ceb.un_540 zu.sa.un_330 
  
  // [ec00]
  0x32004307, 0x10002c04, 0x4f001a29, 0x0700230e,   // ie.bs.un_420 fy.lt.un_320  tl.bi.un_960 ca.it.un_550 
  0x11420755, 0x11213e07, 0x2311430c, 0x1b003009,   // it.co.ro_442 rm.jw.ro_432  ie.ro.ca_543 uz.tr.un_440 
  0x614838a4, 0x13000212, 0x40002102, 0x22002704,   // tk.tt.za_433 da.et.un_640  jw.lb.un_220 gd.oc.un_320 
  0x0735360c, 0x4a520c0c, 0x1e005119, 0x17001b04,   // ab.tg.bg_543 sv.ha.yo_543  kl.ms.un_750 tr.sr.un_320 
  // [ec10]
  0x20402dad, 0x0e4a36ee, 0x15081708, 0x40026307,   // sk.lb.sq_643 gn.yo.is_422  sr.uk.un_443 sco.da.lb_432 
  0x10170709, 0x431b18a4, 0x22003e07, 0x222351ec,   // bg.sr.be_444 ga.tr.ie_433  rm.oc.un_420 kl.ca.oc_644 
  0x63006020, 0x36482312, 0x481f08a4, 0x04303c0b,   // vo.sco.un_850 ky.tt.ab_654  no.cy.tt_433 ug.uz.ru_542 
  0x3c003509, 0x18004419, 0x0a4804a0, 0x3c2338a9,   // tg.ug.un_440 kk.ar.un_750  ru.tt.mk_322 tk.ky.ug_544 
  // [ec20]
  0x1200360b, 0x1200360c, 0x6e6246a9, 0x190b12ee,   // gn.hu.un_520 gn.hu.un_530  qu.kha.hmn_544 hu.es.gl_422 
  0x60003304, 0x0f001e13, 0x1d0203a9, 0x35fa34a4,   // nn.vo.un_320 ms.lv.un_650  nl.da.la_544 xh.nr.zu_433 
  0x101d2204, 0x2e1d240d, 0x10190a14, 0x241d1c0b,   // oc.la.lt_332 eo.la.fo_554  pt.gl.lt_666 id.la.eo_542 
  0x13095cac, 0x220f1da9, 0x1734fc0c, 0x1304670c,   // sa.hi.bh_632 la.lv.oc_544  zzp.xh.sr_543 ak.fi.et_543 
  // [ec30]
  0x683e24a9, 0xfc001223, 0x53695808, 0x17153ca4,   // eo.rm.ig_544 hu.zzp.un_880  om.mfe.ht_443 ug.sr.un_430 
  0x2f1f21ec, 0x10241d12, 0x27001d07, 0x2337480d,   // jw.cy.su_644 la.eo.lt_654  la.gd.un_420 tt.ba.ky_554 
  0x15002313, 0x2058fea0, 0x2a006408, 0x04004413,   // ky.un.un_650 tlh.om.sq_322  lg.mt.un_430 kk.ru.un_650 
  0x23303807, 0x40064dec, 0x31003819, 0x48000802,   // tk.uz.ky_432 aa.de.lb_644  tk.az.un_750 uk.tt.un_220 
  // [ec40]
  0x5c131ca0, 0x37000707, 0x383023af, 0x150a0760,   // mr.bh.sa_322 bg.ba.un_420  ky.uz.tk_655 bg.mk.un_664 
  0x35000412, 0x23350407, 0x01006e05, 0xfe003f07,   // ru.tg.un_640 ru.tg.ky_432  hmn.en.un_330 af.tlh.un_420 
  0x2400fe0b, 0x1b2a020c, 0x65002904, 0x54006221,   // tlh.eo.un_520 da.mt.tr_543  sl.gv.un_320 kha.ik.un_860 
  0x170425a0, 0x4d043705, 0x315a6a12, 0x384a1b13,   // mn.ru.sr_322 st.fi.aa_333  haw.sm.az_654 tr.yo.tk_665 
  // [ec50]
  0x6a5a680e, 0x0e005e0d, 0x33002a0c, 0x3e26630e,   // ig.sm.haw_555 ts.is.un_540  mt.nn.un_530 sco.ia.rm_555 
  0x750a60ec, 0x4000570d, 0x1d25fc55, 0x170257a0,   // vo.pt.nso_644 na.lb.un_540  zzp.eu.la_442 na.da.sr_322 
  0x20003e1b, 0x10301ba0, 0x17040855, 0x3e1d01a0,   // rm.sq.un_770 tr.uz.lt_322  uk.ru.sr_442 en.la.rm_322 
  0x135f4a55, 0x0c020812, 0x2e3e0e07, 0x0300621b,   // yo.tn.et_442 no.da.sv_654  is.rm.fo_432 kha.nl.un_770 
  // [ec60]
  0x3f60230c, 0x39003f02, 0x054036a9, 0x5a3b6209,   // ca.vo.af_543 af.br.un_220  gn.lb.fr_544 kha.so.sm_444 
  0x2f4005a4, 0x3216fe0c, 0x3f002021, 0x37005e0d,   // fr.lb.su_433 tlh.hr.bs_543  sq.af.un_860 ts.st.un_540 
  0x73fc2512, 0x35170aaf, 0x2800040e, 0x174835ee,   // eu.zzp.ny_654 mk.sr.tg_655  fi.sw.un_550 tg.tt.sr_422 
  0x2d2c56a0, 0x2c003607, 0x4a00681a, 0x31100207,   // mg.fy.sk_322 gn.fy.un_420  ig.yo.un_760 da.lt.az_432 
  // [ec70]
  0x39052204, 0x5c0f4b12, 0x0a005d04, 0x1b537612,   // oc.fr.br_332 mi.lv.sa_654  ss.pt.un_320 crs.ht.tr_654 
  0x68004a1a, 0x20383104, 0x5c091312, 0x30001518,   // yo.ig.un_760 az.tk.sq_332  bh.hi.sa_654 un.uz.un_740 
  0x3031fc04, 0x65431faf, 0x791a6ba0, 0x311b3860,   // zzp.az.uz_332 cy.ie.gv_655  ceb.tl.war_322 tk.tr.az_664 
  0x2c60035a, 0x6b76fca4, 0xfc001a07, 0x30006113,   // nl.vo.fy_553 zzp.crs.ceb_433  tl.zzp.un_420 za.uz.un_650 
  // [ec80]
  0x37004418, 0x5c4b0fa4, 0x564735ad, 0x5c004b11,   // kk.ba.un_740 lv.mi.sa_433  zu.sn.mg_643 mi.sa.un_630 
  0x342c03ad, 0x1c5c09af, 0x38311b60, 0x6e311ba0,   // nl.fy.xh_643 hi.sa.mr_655  tr.az.tk_664 tr.az.hmn_322 
  0x0e002204, 0x4400360e, 0x2b002f02, 0x18122e0c,   // oc.is.un_320 ab.kk.un_550  su.vi.un_220 fo.hu.ga_543 
  0x5c131c11, 0x73694507, 0x192e0eee, 0x6b000204,   // mr.bh.sa_653 ln.mfe.ny_432  is.fo.gl_422 da.ceb.un_320 
  // [ec90]
  0x38001b23, 0x1c001313, 0x5740060c, 0x06080208,   // tr.tk.un_880 bh.mr.un_650  de.lb.na_543 da.no.de_443 
  0x2c4006a4, 0x691b0208, 0x4bfc5707, 0x0c0208a9,   // de.lb.fy_433 da.tr.mfe_443  na.zzp.mi_432 no.da.sv_544 
  0x122d360d, 0x15001134, 0x653e05a0, 0x4a251a07,   // gn.sk.hu_554 ro.un.un_A80  fr.rm.gv_322 tl.eu.yo_432 
  0x07153607, 0x4c006113, 0x31381b60, 0x133e0709,   // ab.bg.un_420 za.wo.un_650  tr.tk.az_664 it.rm.et_444 
  // [eca0]
  0x02001b08, 0x2a1562a4, 0x2f2158a6, 0x381b080c,   // tr.da.un_430 kha.mt.un_430  om.jw.su_521 no.tr.tk_543 
  0x051b3811, 0x1108100c, 0x5c34350c, 0x021b08a4,   // tk.tr.fr_653 be.uk.ro_543  zu.xh.sa_543 no.tr.da_433 
  0x0a043604, 0x3536370d, 0x070425a0, 0x253035ee,   // ab.ru.mk_332 ba.ab.tg_554  mn.ru.bg_322 tg.uz.mn_422 
  0xfc006b04, 0x052301a0, 0xfe0479a0, 0x24016307,   // ceb.zzp.un_320 en.ca.fr_322  war.fi.tlh_322 sco.en.eo_432 
  // [ecb0]
  0x4f0f54af, 0x213428af, 0x48003c0e, 0x101148a4,   // ik.lv.bi_655 sd.ps.fa_655  ug.tt.un_550 tt.ro.be_433 
  0x22630107, 0x35001122, 0x234837a4, 0x0a000f02,   // en.sco.oc_432 ro.tg.un_870  ba.tt.ky_433 lv.pt.un_220 
  0x63270107, 0x54001d19, 0x51796ba0, 0x1f6b1dad,   // en.gd.sco_432 la.ik.un_750  ceb.war.kl_322 la.ceb.cy_643 
  0x430c510c, 0x08003c0b, 0x4c360d0d, 0x05004508,   // kl.sv.ie_543 ug.uk.un_520  cs.gn.wo_554 ln.fr.un_430 
  // [ecc0]
  0x6b00fe09, 0x57003921, 0x4c573911, 0x3b5d340c,   // tlh.ceb.un_440 br.na.un_860  br.na.wo_653 xh.ss.so_543 
  0x4e00391a, 0x574e39af, 0x6e00680d, 0x0d1d2607,   // br.ay.un_760 br.ay.na_655  ig.hmn.un_540 ia.la.cs_432 
  0x5c4e39ec, 0x2f20420c, 0x31480aa0, 0x39004c09,   // br.ay.sa_644 co.sq.su_543  pt.tt.az_322 wo.br.un_440 
  0x65054dad, 0x18002204, 0x03000f07, 0x48003907,   // aa.fr.gv_643 oc.ga.un_320  lv.nl.un_420 br.tt.un_420 
  // [ecd0]
  0x4c004709, 0x481530a4, 0x591b5555, 0x5c004e12,   // sn.wo.un_440 uz.tt.un_430  rw.tr.rn_442 ay.sa.un_640 
  0x39004c07, 0x4e573960, 0x3900570d, 0x48003921,   // wo.br.un_420 br.na.ay_664  na.br.un_540 br.tt.un_860 
  0x18191da4, 0x5c091c0d, 0x50003b04, 0x4b6a2ba9,   // la.gl.ga_433 mr.hi.sa_554  so.fj.un_320 vi.haw.mi_544 
  0x4b6a56ad, 0x56004f2c, 0x4f5a6a12, 0x6500490c,   // mg.haw.mi_643 bi.mg.un_990  haw.sm.bi_654 to.gv.un_530 
  // [ece0]
  0x49654b12, 0x07002f02, 0x3f0343a4, 0x5a6a49a4,   // mi.gv.to_654 su.it.un_220  ie.nl.af_433 to.haw.sm_433 
  0x03133f5a, 0x3f254009, 0x1c1e395a, 0x023f4309,   // af.et.nl_553 lb.eu.af_444  br.ms.id_553 ie.af.da_444 
  0x39033f0d, 0x1f3f3904, 0x4f005a07, 0x08022ca0,   // af.nl.br_554 br.af.cy_332  sm.bi.un_420 fy.da.no_322 
  0x2f005609, 0x032c3fec, 0x3700450c, 0x082c13a7,   // mg.su.un_440 af.fy.nl_644  ln.st.un_530 et.fy.no_532 
  // [ecf0]
  0x07221d05, 0x2c000202, 0x47000e04, 0x56004b23,   // la.oc.it_333 da.fy.un_220  is.sn.un_320 mi.mg.un_880 
  0x1c18120c, 0x56000804, 0x3f080205, 0x55565308,   // ur.ar.mr_543 no.mg.un_320  da.no.af_333 ht.mg.rw_443 
  0x4f006713, 0x5a4b560d, 0x3f032207, 0x5f212c12,   // ak.bi.un_650 mg.mi.sm_554  oc.nl.af_432 fy.jw.tn_654 
  0x65005e05, 0x3b35340d, 0x3c003d0d, 0x43033fec,   // ts.gv.un_330 xh.zu.so_554  ku.ug.un_540 af.nl.ie_644 
  // [ed00]
  0x5e254c02, 0x3f050304, 0x30002a09, 0x033f56ec,   // wo.eu.ts_222 nl.fr.af_332  mt.uz.un_440 mg.af.nl_644 
  0x08022c05, 0x0c003402, 0x3f002c0e, 0x1c213f07,   // fy.da.no_333 xh.sv.un_220  fy.af.un_550 af.jw.id_432 
  0x0a255ea0, 0x122e2d09, 0x2d191207, 0x251923ee,   // ts.eu.pt_322 sk.fo.hu_444  hu.gl.sk_432 ca.gl.eu_422 
  0x2d001f05, 0x19004804, 0x630e0107, 0x23191b04,   // cy.sk.un_330 tt.gl.un_320  en.is.sco_432 tr.gl.ca_332 
  // [ed10]
  0x03000107, 0x4d22230e, 0x130f6307, 0x35231513,   // en.nl.un_420 ca.oc.aa_555  sco.lv.et_432 un.ky.tg_665 
  0x632a0e07, 0x03630f08, 0x2330150c, 0x20003807,   // is.mt.sco_432 lv.sco.nl_443  un.uz.ky_543 tk.sq.un_420 
  0x2d0d04a0, 0x633f01a0, 0x1863010c, 0x120f10a4,   // fi.cs.sk_322 en.af.sco_322  en.sco.ga_543 lt.lv.hu_433 
  0x65015a02, 0x0e2c10ee, 0x3c153507, 0x08024d05,   // sm.en.gv_222 lt.fy.is_422  tg.ug.un_420 aa.da.no_333 
  // [ed20]
  0x3700250c, 0x120c080c, 0x022663a4, 0x07001d05,   // mn.ba.un_530 no.sv.hu_543  sco.ia.da_433 la.it.un_330 
  0x6b150111, 0x79010f0c, 0x2a00fe05, 0x734c5809,   // en.ceb.un_630 lv.en.war_543  tlh.mt.un_330 om.wo.ny_444 
  0x6b736507, 0x30004d13, 0x252f6355, 0x2c003e0d,   // gv.ny.ceb_432 aa.uz.un_650  sco.su.eu_442 rm.fy.un_540 
  0x42571da4, 0x58006520, 0x2f2443ee, 0x1c5c130b,   // la.na.co_433 gv.om.un_850  ie.eo.su_422 bh.sa.mr_542 
  // [ed30]
  0x12005205, 0x134f04ec, 0x30484c04, 0x071115a9,   // ha.hu.un_330 fi.bi.et_644  wo.tt.uz_332 un.ro.bg_544 
  0x23303cec, 0x222123ad, 0x233748af, 0x4c5250a4,   // ug.uz.ky_644 ca.jw.oc_643  tt.ba.ky_655 fj.ha.wo_433 
  0x075865a0, 0x202411ee, 0x201152a0, 0x361511a0,   // gv.om.it_322 ro.eo.sq_422  ha.ro.sq_322 ro.ab.un_320 
  0x3d183c07, 0x23114213, 0x012c65a0, 0x2a65fea4,   // ug.ar.ku_432 co.ro.ca_665  gv.fy.en_322 tlh.gv.mt_433 
  // [ed40]
  0x1b3b4807, 0x360a170d, 0x0a5211a0, 0x2a422d07,   // tt.so.tr_432 sr.mk.ab_554  ro.ha.pt_322 sk.co.mt_432 
  0x4425360c, 0x16001107, 0x521150a0, 0x253723ad,   // ab.mn.kk_543 ro.hr.un_420  fj.ro.ha_322 ky.ba.mn_643 
  0x35003c21, 0x18282108, 0x041507ec, 0x5d2660a4,   // ug.tg.un_860 fa.sd.ar_443  bg.ru.un_640 vo.ia.ss_433 
  0x37235aa4, 0x15360707, 0x315a2ea4, 0x34405605,   // sm.ca.st_433 bg.ab.un_432  fo.sm.az_433 mg.lb.xh_333 
  // [ed50]
  0x645f490c, 0x35002e04, 0x51483007, 0x3b7360a0,   // to.tn.lg_543 fo.zu.un_320  uz.tt.kl_432 vo.ny.so_322 
  0x305451ec, 0x1200212a, 0x134804a7, 0x281232ee,   // kl.ik.uz_644 fa.ur.un_970  fi.tt.et_532 bs.ur.sd_422 
  0x425e2ba0, 0x18003b0e, 0x07150405, 0x201112a0,   // vi.ts.co_322 ks.ar.un_550  ru.bg.un_330 hu.ro.sq_322 
  0x5d001b0b, 0x4a1f3502, 0x485a1fa4, 0x0a36085a,   // tr.ss.un_520 zu.cy.yo_222  cy.sm.tt_433 uk.ab.mk_553 
  // [ed60]
  0x565f2e0c, 0x0e1b2e55, 0x0a483708, 0x5f0e2ea4,   // fo.tn.mg_543 fo.tr.is_442  ba.tt.mk_443 fo.is.tn_433 
  0x36303512, 0x5c090d12, 0x3f032c14, 0x1536100c,   // tg.uz.ab_654 ne.hi.sa_654  fy.nl.af_666 be.ab.un_543 
  0x37381008, 0x364a0ea4, 0x30001819, 0x03000808,   // be.tk.ba_443 is.yo.gn_433  ar.uz.un_750 no.nl.un_430 
  0x34123d09, 0x22005313, 0x48006019, 0x47000304,   // ku.ur.ps_444 ht.oc.un_650  vo.tt.un_750 nl.sn.un_320 
  // [ed70]
  0x06002f07, 0x1100441a, 0x12303d07, 0x330c3008,   // su.de.un_420 kk.ro.un_760  ku.uz.ur_432 uz.sv.nn_443 
  0x01007907, 0x40000412, 0x1b313813, 0x391d1505,   // war.en.un_420 fi.lb.un_640  tk.az.tr_665 un.la.br_333 
  0x4200300c, 0x37040a07, 0x0e002607, 0x07003008,   // uz.co.un_530 mk.ru.ba_432  ia.is.un_420 uz.bg.un_430 
  0x4d30480c, 0x32172ca0, 0x65002c07, 0x6a5a3e0e,   // tt.uz.aa_543 fy.sr.bs_322  fy.gv.un_420 rm.sm.haw_555 
  // [ed80]
  0x53052213, 0x10041107, 0x490630a7, 0x2d347613,   // oc.fr.ht_665 ro.ru.be_432  uz.de.to_532 crs.xh.sk_665 
  0x376a5aec, 0x68675fec, 0x2e001214, 0xfc1d510c,   // sm.haw.st_644 tn.ak.ig_644  hu.fo.un_660 kl.la.zzp_543 
  0x214b6a12, 0x2e120e09, 0x220e6207, 0x33083f07,   // haw.mi.jw_654 is.hu.fo_444  kha.is.oc_432 af.no.nn_432 
  0x270c33ee, 0x05000112, 0x082c560b, 0x6900501a,   // nn.sv.gd_422 en.fr.un_640  mg.fy.no_542 fj.mfe.un_760 
  // [ed90]
  0x430638a4, 0x56016060, 0x07fc1da4, 0x4c006b04,   // tk.de.ie_433 vo.en.mg_664  la.zzp.it_433 ceb.wo.un_320 
  0x64004002, 0x56000802, 0x5163400c, 0x233e06a4,   // lb.lg.un_220 no.mg.un_220  lb.sco.kl_543 de.rm.ca_433 
  0x183b3013, 0x633f13a0, 0x396908a4, 0x42003e04,   // uz.ks.ar_665 et.af.sco_322  no.mfe.br_433 rm.co.un_320 
  0x071736a7, 0x06650207, 0x320916ee, 0x0d052108,   // ab.sr.bg_532 da.gv.de_432  hr.pl.bs_422 jw.fr.cs_443 
  // [eda0]
  0x10111513, 0x4c210d07, 0x08514fa4, 0x023f0eee,   // un.ro.be_665 cs.jw.wo_432  bi.kl.no_433 is.af.da_422 
  0x20002104, 0x2d210d12, 0x33080260, 0x212d0d14,   // jw.sq.un_320 cs.jw.sk_654  da.no.nn_664 cs.sk.jw_666 
  0x21000d08, 0x2c080204, 0x36244aa4, 0x4a2d0d07,   // cs.jw.un_430 da.no.fy_332  yo.eo.gn_433 cs.sk.yo_432 
  0xfc510605, 0x034a4c07, 0x4c2f05a4, 0x244a0404,   // de.kl.zzp_333 wo.yo.nl_432  fr.su.wo_433 fi.yo.eo_332 
  // [edb0]
  0x32172005, 0x21001012, 0x2d0d4a05, 0x42450507,   // sq.sr.bs_333 lt.jw.un_640  yo.cs.sk_333 fr.ln.co_432 
  0x3c001512, 0x040a070b, 0x05465904, 0x21054ca4,   // un.ug.un_640 bg.mk.ru_542  rn.qu.fr_332 wo.fr.jw_433 
  0x05004c12, 0x052d0d60, 0x150a1709, 0x4d4a2112,   // wo.fr.un_640 cs.sk.fr_664  sr.mk.un_444 jw.yo.aa_654 
  0x2d0d050c, 0x212d0d0d, 0x43210508, 0x094820ee,   // fr.cs.sk_543 cs.sk.jw_554  fr.jw.ie_443 sq.tt.pl_422 
  // [edc0]
  0x4a052107, 0x440817a4, 0x183444ee, 0x0905360c,   // jw.fr.yo_432 sr.uk.kk_433  kk.ps.ar_422 gn.fr.pl_543 
  0x38003014, 0x0a04350c, 0x130d5c0b, 0x213b120d,   // uz.tk.un_660 tg.ru.mk_543  sa.ne.bh_542 ur.ks.fa_554 
  0x30343b13, 0x2f645ea4, 0x5d5e340d, 0x555d64a0,   // ks.ps.uz_665 ts.lg.su_433  xh.ts.ss_554 lg.ss.rw_322 
  0x044836a0, 0x4437170c, 0x21732fa0, 0x35003421,   // ab.tt.ru_322 sr.ba.kk_543  su.ny.jw_322 xh.zu.un_860 
  // [edd0]
  0x5d006408, 0x5d006409, 0x5dfe34a4, 0x2f736407,   // lg.ss.un_430 lg.ss.un_440  xh.tlh.ss_433 lg.ny.su_432 
  0x1c100f04, 0x5d35380c, 0x090f3608, 0x0f361004,   // lv.lt.id_332 tk.zu.ss_543  gn.lv.pl_443 lt.gn.lv_332 
  0x0f000908, 0x0b000704, 0x10482312, 0x153804a4,   // pl.lv.un_430 it.es.un_320  ky.tt.be_654 ru.tk.un_433 
  0x04151511, 0x29163207, 0x0a100f08, 0x23304805,   // un.ru.un_630 bs.hr.sl_432  lv.lt.pt_443 tt.uz.ky_333 
  // [ede0]
  0x0f2f2d0c, 0x17480407, 0x28002314, 0x42255602,   // sk.su.lv_543 ru.tt.sr_432  ky.sd.un_660 mg.eu.co_222 
  0x224063a0, 0x032c13a4, 0x1000110c, 0x7913010b,   // sco.lb.oc_322 et.fy.nl_433  ro.be.un_530 en.et.war_542 
  0x39005312, 0x23001822, 0x01630607, 0x13004702,   // ht.br.un_640 ar.ky.un_870  de.sco.en_432 sn.et.un_220 
  0x28521f04, 0x3e001507, 0x390540a4, 0x2d4509ad,   // cy.ha.sw_332 un.rm.un_420  lb.fr.br_433 pl.ln.sk_643 
  // [edf0]
  0x393e22ee, 0x03083f0b, 0x213e050c, 0x48303c0c,   // oc.rm.br_422 af.no.nl_542  fr.rm.jw_543 ug.uz.tt_543 
  0x36000f21, 0x190225a4, 0x365e08a4, 0x45430513,   // lv.gn.un_860 eu.da.gl_433  no.ts.gn_433 fr.ie.ln_665 
  0x46004d0e, 0x671e1c0c, 0x056220ad, 0x3421300b,   // aa.qu.un_550 id.ms.ak_543  sq.kha.fr_643 uz.fa.ps_542 
  0x13304004, 0x2d0d5da9, 0x293308ee, 0xfc1d0302,   // lb.uz.et_332 ss.cs.sk_544  no.nn.sl_422 nl.la.zzp_222 
  // [ee00]
  0x35253002, 0x48041312, 0x396903a4, 0x06002208,   // uz.mn.tg_222 et.fi.tt_654  nl.mfe.br_433 oc.de.un_430 
  0x073011ac, 0x43241d12, 0x3e052da0, 0xfc001305,   // ro.uz.it_632 la.eo.ie_654  sk.fr.rm_322 et.zzp.un_330 
  0x0a190b13, 0x37735f0c, 0x033f15a4, 0x250436a0,   // es.gl.pt_665 tn.ny.st_543  un.af.nl_433 ab.ru.mn_322 
  0x3f630107, 0x353403a0, 0x1b005d22, 0x231e1ca9,   // en.sco.af_432 nl.xh.zu_322  ss.tr.un_870 id.ms.ca_544 
  // [ee10]
  0x1d271f13, 0x30374404, 0x5d034fa9, 0x365a1d0c,   // cy.gd.la_665 kk.ba.uz_332  bi.nl.ss_544 la.sm.gn_543 
  0x461f2707, 0x1f026305, 0x130420a0, 0x044423a0,   // gd.cy.qu_432 sco.da.cy_333  sq.fi.et_322 ky.kk.ru_322 
  0x0e000c0d, 0x205c06a0, 0x17151112, 0x3d3c3ba7,   // sv.is.un_540 de.sa.sq_322  ro.sr.un_640 ks.ug.ku_532 
  0x4a00040c, 0x122f3955, 0x040912a4, 0x04000c0e,   // fi.yo.un_530 br.su.hu_442  hu.pl.fi_433 sv.fi.un_550 
  // [ee20]
  0x102f2907, 0x33080c55, 0x231f1207, 0x2f121c02,   // sl.su.lt_432 sv.no.nn_442  hu.cy.ca_432 id.hu.su_222 
  0x08000e13, 0x2e0d2dad, 0x212d2f07, 0x070c36ee,   // is.no.un_650 sk.cs.fo_643  su.sk.jw_432 gn.sv.it_422 
  0x07114209, 0x32001220, 0x12365ca7, 0x375e400c,   // co.ro.it_444 hu.bs.un_850  sa.gn.hu_532 lb.ts.st_543 
  0x23070a09, 0x0c2f29a0, 0x422d12ee, 0x4d49580c,   // mk.bg.ky_444 sl.su.sv_322  hu.sk.co_422 om.to.aa_543 
  // [ee30]
  0x3b674d0d, 0x134c0407, 0x4a4c67a9, 0x684c65ad,   // aa.ak.so_554 fi.wo.et_432  ak.wo.yo_544 gv.wo.ig_643 
  0x120e1804, 0x2338355a, 0x07005d04, 0x09121808,   // ga.is.hu_332 tg.tk.ky_553  ss.it.un_320 ga.hu.pl_443 
  0x4c3b675a, 0x392f020c, 0x4c65630c, 0x47334002,   // ak.so.wo_553 da.su.br_543  sco.gv.wo_543 lb.nn.sn_222 
  0x1d57470c, 0x4c000804, 0x1d393f55, 0x4c586812,   // sn.na.la_543 no.wo.un_320  af.br.la_442 ig.om.wo_654 
  // [ee40]
  0x394713ec, 0x350715a9, 0x52006813, 0x0a000809,   // et.sn.br_644 un.bg.tg_544  ig.ha.un_650 uk.mk.un_440 
  0x3b4c5809, 0x63005714, 0x1d001f21, 0x58004d2a,   // om.wo.so_444 na.sco.un_660  cy.la.un_860 aa.om.un_970 
  0x27002504, 0x4f394004, 0x02401f0c, 0x674a650c,   // eu.gd.un_320 lb.br.bi_332  cy.lb.da_543 gv.yo.ak_543 
  0x130467ec, 0x1a676a5a, 0x4d005113, 0x04495aec,   // ak.fi.et_644 haw.ak.tl_553  kl.aa.un_650 sm.to.fi_644 
  // [ee50]
  0x495868a9, 0x02062a11, 0x49001c08, 0x4b472c02,   // ig.om.to_544 mt.de.da_653  id.to.un_430 fy.sn.mi_222 
  0x40394bee, 0x48154404, 0x2c4b4055, 0x3124feee,   // mi.br.lb_422 kk.tt.un_320  lb.mi.fy_442 tlh.eo.az_422 
  0x49394ba0, 0x12001708, 0x0465020c, 0x13002b0e,   // mi.br.to_322 sr.hu.un_430  da.gv.fi_543 vi.et.un_550 
  0x0e000c13, 0x441048ad, 0x233118a0, 0x2a005d19,   // sv.is.un_650 tt.be.kk_643  ga.az.ca_322 ss.mt.un_750 
  // [ee60]
  0x033ffc07, 0x240229a6, 0x481b32ee, 0x21003c07,   // zzp.af.nl_432 sl.da.eo_521  bs.tr.tt_422 ug.fa.un_420 
  0x0b003335, 0x374810a6, 0x04380705, 0x4d003b09,   // as.bn.un_A90 be.tt.ba_521  bg.tk.ru_333 so.aa.un_440 
  0x2a584d08, 0x2a58fea7, 0x424d6460, 0x44154804,   // aa.om.mt_443 tlh.om.mt_532  lg.aa.co_664 tt.kk.un_320 
  0x4dfe64a4, 0x65425211, 0x391d18a7, 0xfe4d5208,   // lg.tlh.aa_433 ha.co.gv_653  ga.la.br_532 ha.aa.tlh_443 
  // [ee70]
  0x07002a1a, 0x2e004f04, 0x303525a4, 0x1c002b09,   // mt.it.un_760 bi.fo.un_320  mn.tg.uz_433 vi.id.un_440 
  0x3b580107, 0x58524d0c, 0xfe000e19, 0x2afe5813,   // en.om.so_432 aa.ha.om_543  is.tlh.un_750 om.tlh.mt_665 
  0x65000708, 0x646321a9, 0x4d005222, 0xfe001e0c,   // it.gv.un_430 jw.sco.lg_544  ha.aa.un_870 ms.tlh.un_530 
  0x192311a0, 0x353c30ad, 0x0b231dee, 0x5d003902,   // ro.ca.gl_322 uz.ug.tg_643  la.ca.es_422 br.ss.un_220 
  // [ee80]
  0x56650408, 0x2e0c020d, 0x34233007, 0x3810fc13,   // fi.gv.mg_443 da.sv.fo_554  uz.ky.ps_432 zzp.lt.tk_665 
  0x38113cad, 0x36460b05, 0x3c004420, 0x5c005202,   // ug.ro.tk_643 es.qu.gn_333  kk.ug.un_850 ha.sa.un_220 
  0x1200fc09, 0x303c3d12, 0x072508ad, 0x170a0714,   // zzp.hu.un_440 ku.ug.uz_654  uk.mn.bg_643 bg.mk.sr_666 
  0xfe000a20, 0x10041705, 0x5c190b04, 0xfc650207,   // pt.tlh.un_850 sr.ru.be_333  es.gl.sa_332 da.gv.zzp_432 
  // [ee90]
  0x06432255, 0x1546fca4, 0x15442507, 0x09000c09,   // oc.ie.de_442 zzp.qu.un_433  mn.kk.un_432 sv.pl.un_440 
  0xfc0902a7, 0x25150807, 0x3e65010b, 0x1ffc0960,   // da.pl.zzp_532 uk.mn.un_420  en.gv.rm_542 pl.zzp.cy_664 
  0x275c5805, 0x400601a4, 0x1c00fe04, 0x386013af,   // om.sa.gd_333 en.de.lb_433  tlh.id.un_320 et.vo.tk_655 
  0x46190b05, 0x443715ee, 0x732a6812, 0x220601a4,   // es.gl.qu_333 un.ba.kk_422  ig.mt.ny_654 en.de.oc_433 
  // [eea0]
  0x5e007522, 0x63620107, 0x5e475da9, 0x53372a0b,   // nso.ts.un_870 en.kha.sco_432  ss.sn.ts_544 mt.st.ht_542 
  0x282a64a4, 0x170a3c0c, 0x3435730c, 0x03fc090c,   // lg.mt.sw_433 ug.mk.sr_543  ny.zu.xh_543 pl.zzp.nl_543 
  0x1d6509a0, 0x1f006711, 0x170a4802, 0x19004605,   // pl.gv.la_322 ak.cy.un_630  tt.mk.sr_222 qu.gl.un_330 
  0x64475faf, 0x183421ee, 0x060379ee, 0x4e0c0e12,   // tn.sn.lg_655 fa.ps.ar_422  war.nl.de_422 is.sv.ay_654 
  // [eeb0]
  0x0e6301a4, 0x37004708, 0x69026305, 0x535f7613,   // en.sco.is_433 sn.st.un_430  sco.da.mfe_333 crs.tn.ht_665 
  0x632c01a9, 0x551a53a0, 0x02000312, 0x67642a13,   // en.fy.sco_544 ht.tl.rw_322  nl.da.un_640 mt.lg.ak_665 
  0x63033f0d, 0x1f0176ee, 0x04253555, 0x3e1565a4,   // af.nl.sco_554 crs.en.cy_422  tg.mn.ru_442 gv.rm.un_430 
  0x5a041355, 0x48005e04, 0x0d021304, 0x03330202,   // et.fi.sm_442 ts.tt.un_320  et.da.cs_332 da.nn.nl_222 
  // [eec0]
  0x080436ee, 0x65023fa7, 0x331239a0, 0x17001513,   // ab.ru.uk_422 af.da.gv_532  br.hu.nn_322 un.sr.un_650 
  0x2a0163a0, 0x03fc26a4, 0xfc0108a4, 0x0d5c1caf,   // sco.en.mt_322 ia.zzp.nl_433  no.en.zzp_433 mr.sa.ne_655 
  0x63fc010e, 0x254830a4, 0x330313ee, 0x630c0213,   // en.zzp.sco_555 uz.tt.mn_433  et.nl.nn_422 da.sv.sco_665 
  0x151704ee, 0x073815ad, 0x18233402, 0x042910a9,   // ru.sr.un_422 un.tk.bg_643  ps.ky.ar_222 lt.sl.fi_544 
  // [eed0]
  0x58375fa4, 0x31003409, 0x34000204, 0x3000101b,   // tn.st.om_433 xh.az.un_440  da.xh.un_320 lt.uz.un_770 
  0x2a101704, 0x495a26a4, 0x555d340c, 0x30584cee,   // sr.lt.mt_332 ia.sm.to_433  xh.ss.rw_543 wo.om.uz_422 
  0x1730100c, 0x172a10ac, 0x320410ac, 0x37000110,   // lt.uz.sr_543 lt.mt.sr_632  lt.fi.bs_632 iw.ba.un_620 
  0x2e2d0ea0, 0x283021ad, 0x3f0208a9, 0x38003119,   // is.sk.fo_322 fa.uz.sd_643  no.da.af_544 az.tk.un_750 
  // [eee0]
  0x63150304, 0x402f1c05, 0x44372304, 0x0000762d,   // nl.sco.un_320 id.su.lb_333  ky.ba.kk_332 crs.un.un_A00 
  0x62133bec, 0x3f3b1aad, 0x060c0107, 0x79013ba4,   // so.et.kha_644 tl.so.af_643  en.sv.de_432 so.en.war_433 
  0x28006422, 0x791a2d12, 0x033f3bad, 0x350730ec,   // lg.sw.un_870 sk.tl.war_654  so.af.nl_643 uz.bg.tg_644 
  0x0800441a, 0x0600620c, 0x0c083f04, 0x633b0308,   // kk.uk.un_760 kha.de.un_530  af.no.sv_332 nl.so.sco_443 
  // [eef0]
  0x68563612, 0x46002a04, 0x24495a0d, 0x384a64ec,   // gn.mg.ig_654 mt.qu.un_320  sm.to.eo_554 lg.yo.tk_644 
  0x1d4a01ee, 0x64004f21, 0x0200082a, 0x27026455,   // en.yo.la_422 bi.lg.un_860  no.da.un_970 lg.da.gd_442 
  0x090869a0, 0x756737a4, 0x5739680d, 0x0215fcee,   // mfe.no.pl_322 st.ak.nso_433  ig.br.na_554 zzp.da.un_420 
  0x01003b0e, 0x69003b08, 0x39214604, 0x13403ba0,   // so.en.un_550 so.mfe.un_430  qu.jw.br_332 so.lb.et_322 
  // [ef00]
  0x24004f04, 0x02005307, 0x34624d55, 0x20292d11,   // bi.eo.un_320 ht.da.un_420  aa.kha.xh_442 sk.sl.sq_653 
  0x170804a9, 0x23360a55, 0x20075dad, 0x050106a4,   // ru.uk.sr_544 mk.ab.ky_442  ss.it.sq_643 de.en.fr_433 
  0x3400622a, 0x36253055, 0x1525350d, 0x2e200da0,   // kha.xh.un_970 uz.mn.ab_442  tg.mn.un_554 cs.sq.fo_322 
  0x302535af, 0x09004612, 0x212a79ee, 0x04001133,   // tg.mn.uz_655 qu.pl.un_640  war.mt.jw_422 ro.ru.un_A70 
  // [ef10]
  0x34182155, 0x15033f07, 0x07081013, 0x244006a0,   // fa.ar.ps_442 af.nl.un_432  be.uk.bg_665 de.lb.eo_322 
  0x0603fc02, 0x0e001d04, 0x3f005204, 0x48002407,   // zzp.nl.de_222 la.is.un_320  ha.af.un_320 eo.tt.un_420 
  0x431f3fa4, 0x3f4936a0, 0x364f2104, 0x375f6805,   // af.cy.ie_433 gn.to.af_322  jw.bi.gn_332 ig.tn.st_333 
  0x44232108, 0x284773a9, 0x251115ec, 0x7302040c,   // fa.ky.kk_443 ny.sn.sw_544  un.ro.mn_644 fi.da.ny_543 
  // [ef20]
  0x180102a0, 0x34006708, 0x5a286704, 0x283c4407,   // da.en.ga_322 ak.xh.un_430  ak.sw.sm_332 kk.ug.sd_432 
  0x06000305, 0x303635a4, 0x5d1257a4, 0x2a584d04,   // nl.de.un_330 tg.ab.uz_433  na.hu.ss_433 aa.om.mt_332 
  0x0c3f15a0, 0x07595504, 0x10440808, 0x23004429,   // un.af.sv_322 rw.rn.it_332  uk.kk.be_443 kk.ky.un_960 
  0x233f0504, 0x200b2ca9, 0x2d0d12b3, 0x38004202,   // fr.af.ca_332 fy.es.sq_544  hu.cs.sk_743 co.tk.un_220 
  // [ef30]
  0x0515010c, 0x07380a04, 0x06002505, 0x36001704,   // en.fr.un_530 mk.tk.bg_332  eu.de.un_330 sr.ab.un_320 
  0x320a0f5a, 0x4006790e, 0x0b43120c, 0x43190107,   // lv.pt.bs_553 war.de.lb_555  hu.ie.es_543 en.gl.ie_432 
  0x2f5621a0, 0x0523010c, 0x1f3f6308, 0x57003613,   // jw.mg.su_322 en.ca.fr_543  sco.af.cy_443 gn.na.un_650 
  0x7940010c, 0x2afe2012, 0x040c0ea4, 0x5b4005a4,   // en.lb.war_543 sq.tlh.mt_654  is.sv.fi_433 fr.lb.sg_433 
  // [ef40]
  0x30001519, 0xfc000c04, 0x48070407, 0x1f0c0904,   // un.uz.un_750 sv.zzp.un_320  ru.bg.tt_432 pl.sv.cy_332 
  0x08040aee, 0x1d003007, 0x0a054a07, 0xfc090c12,   // mk.ru.uk_422 uz.la.un_420  yo.fr.pt_432 sv.pl.zzp_654 
  0x234415ee, 0x2d122e07, 0x321710a9, 0x23374802,   // un.kk.ky_422 fo.hu.sk_432  lt.sr.bs_544 tt.ba.ky_222 
  0x350711ee, 0x080448a4, 0x52003e0d, 0x0851020b,   // ro.bg.tg_422 tt.ru.uk_433  rm.ha.un_540 da.kl.no_542 
  // [ef50]
  0x0c32590c, 0x483130a4, 0x07002204, 0x48240304,   // rn.bs.sv_543 uz.az.tt_433  oc.it.un_320 nl.eo.tt_332 
  0x01001e04, 0x6e594f55, 0x38fc1b04, 0x27005923,   // ms.en.un_320 bi.rn.hmn_442  tr.zzp.tk_332 rn.gd.un_880 
  0x2a3530a0, 0x63001c05, 0x422c05ad, 0x0a2322ee,   // uz.zu.mt_322 id.sco.un_330  fr.fy.co_643 oc.ca.pt_422 
  0x10fc1207, 0x1524340b, 0x1d190b08, 0x2cfe42ec,   // hu.zzp.lt_432 xh.eo.un_542  es.gl.la_443 co.tlh.fy_644 
  // [ef60]
  0x1a00121a, 0x0956380c, 0x0417080d, 0x2d020dec,   // hu.tl.un_760 tk.mg.pl_543  uk.sr.ru_554 cs.da.sk_644 
  0x2f211c07, 0x643865a7, 0x101b1fee, 0xfc3f2c08,   // id.jw.su_432 gv.tk.lg_532  cy.tr.lt_422 fy.af.zzp_443 
  0x650a0302, 0x53633bee, 0x5b004d19, 0x17002d07,   // nl.pt.gv_222 so.sco.ht_422  aa.sg.un_750 sk.sr.un_420 
  0x0f002905, 0x315950af, 0x562c02ee, 0x15001f02,   // sl.lv.un_330 fj.rn.az_655  da.fy.mg_422 cy.un.un_220 
  // [ef70]
  0x1b00690d, 0x40120602, 0x0412fc0c, 0x6904fcec,   // mfe.tr.un_540 de.hu.lb_222  zzp.hu.fi_543 zzp.fi.mfe_644 
  0xfc00650e, 0x33fc04ee, 0x3c304460, 0x08020caf,   // gv.zzp.un_550 fi.zzp.nn_422  kk.uz.ug_664 sv.da.no_655 
  0x08293312, 0x2b003e13, 0x321665af, 0x1f001207,   // nn.sl.no_654 rm.vi.un_650  gv.hr.bs_655 hu.cy.un_420 
  0x63fc0113, 0x211234a7, 0x3b1a1f05, 0x182834ac,   // en.zzp.sco_665 ps.ur.fa_532  cy.tl.so_333 ps.sd.ar_632 
  // [ef80]
  0x13330802, 0x332c0860, 0x765369a9, 0x2a004e14,   // no.nn.et_222 no.fy.nn_664  mfe.ht.crs_544 ay.mt.un_660 
  0x054225a0, 0x531069a4, 0xfc1d3fee, 0x250a07a9,   // eu.co.fr_322 mfe.lt.ht_433  af.la.zzp_422 bg.mk.mn_544 
  0x60000c19, 0x21343013, 0x460a2aa7, 0x4b002202,   // sv.vo.un_750 uz.ps.fa_665  mt.pt.qu_532 oc.mi.un_220 
  0x3815235a, 0xfc271813, 0x0f1b690e, 0xfe203e04,   // ky.tk.un_530 ga.gd.zzp_665  mfe.tr.lv_555 rm.sq.tlh_332 
  // [ef90]
  0x482a3b0c, 0x462349a0, 0x0c4f2513, 0x37170aa0,   // so.mt.tt_543 to.ca.qu_322  eu.bi.sv_665 mk.sr.ba_322 
  0x38001713, 0x38000419, 0x03005304, 0x25006b07,   // sr.tk.un_650 fi.tk.un_750  ht.nl.un_320 ceb.eu.un_420 
  0x27003302, 0x5600180d, 0x561709a4, 0x1b002d07,   // nn.gd.un_220 ga.mg.un_540  pl.sr.mg_433 sk.tr.un_420 
  0x3f5a1d07, 0x04000f1b, 0x62572bad, 0x0e6013a7,   // la.sm.af_432 lv.fi.un_770  vi.na.kha_643 et.vo.is_532 
  // [efa0]
  0x0a3823a0, 0x206b2407, 0x681c27ac, 0x016302a0,   // ca.tk.pt_322 eo.ceb.sq_432  gd.id.ig_632 da.sco.en_322 
  0x091d1f07, 0x17093e07, 0x0163600c, 0x1f562707,   // cy.la.pl_432 rm.pl.sr_432  vo.sco.en_543 gd.mg.cy_432 
  0x24002c0c, 0x42001d08, 0x33132907, 0x2e001314,   // fy.eo.un_530 la.co.un_430  sl.et.nn_432 et.fo.un_660 
  0x11005011, 0x3105590b, 0x4317110c, 0x4800300b,   // fj.ro.un_630 rn.fr.az_542  ro.sr.ie_543 uz.tt.un_520 
  // [efb0]
  0x40002d09, 0x1b421d05, 0x10121304, 0x27000908,   // sk.lb.un_440 la.co.tr_333  et.hu.lt_332 pl.gd.un_430 
  0x1b000e05, 0x08173509, 0x05064208, 0x3f400e04,   // is.tr.un_330 tg.sr.uk_444  co.de.fr_443 is.lb.af_332 
  0x043530ee, 0x3d002309, 0x12330802, 0x13392eaf,   // uz.tg.ru_422 ky.ku.un_440  no.nn.hu_222 fo.br.et_655 
  0x2e3308a0, 0xfc305c0c, 0x1200640e, 0x0230750b,   // no.nn.fo_322 sa.uz.zzp_543  lg.hu.un_550 nso.uz.da_542 
  // [efc0]
  0x13002002, 0x5c6412ee, 0x484430a4, 0x18002819,   // sq.et.un_220 hu.lg.sa_422  uz.kk.tt_433 sd.ar.un_750 
  0x305c2fee, 0x08171104, 0x0f002d13, 0x111504af,   // su.sa.uz_422 ro.sr.uk_332  sk.lv.un_650 ru.ro.un_650 
  0x0407150d, 0x63282f12, 0x060c0e14, 0x05003618,   // un.bg.ru_554 su.sw.sco_654  is.sv.de_666 gn.fr.un_740 
  0x043710a0, 0x09000a0c, 0x29002d12, 0x0c121ba4,   // be.ba.ru_322 pt.pl.un_530  sk.sl.un_640 tr.hu.sv_433 
  // [efd0]
  0x501e1c04, 0x0b000907, 0x47002802, 0x203e1d55,   // id.ms.fj_332 pl.es.un_420  sw.sn.un_220 la.rm.sq_442 
  0x084837a4, 0x48233807, 0x1b094e04, 0x2e330204,   // ba.tt.uk_433 tk.ky.tt_432  ay.pl.tr_332 da.nn.fo_332 
  0x326301a4, 0x17483c07, 0x790a1b05, 0x19212f04,   // en.sco.bs_433 ug.tt.sr_432  tr.pt.war_333 su.jw.gl_332 
  0x0c005102, 0x481b3812, 0x73526104, 0x01312412,   // kl.sv.un_220 tk.tr.tt_654  za.ha.ny_332 yi.az.iw_654 
  // [efe0]
  0x5c006112, 0x36482d0c, 0x486301a4, 0x0f482007,   // za.sa.un_640 sk.tt.gn_543  en.sco.tt_433 sq.tt.lv_432 
  0x03004802, 0x123d210b, 0x2e303f07, 0x302d4807,   // tt.nl.un_220 fa.ku.ur_542  af.uz.fo_432 tt.sk.uz_432 
  0x581f7607, 0x0400540c, 0x54000613, 0x58005104,   // crs.cy.om_432 ik.fi.un_530  de.ik.un_650 kl.om.un_320 
  0x074842a4, 0x0f004508, 0x1e5c12a7, 0x5c1e1c08,   // co.tt.it_433 ln.lv.un_430  hu.sa.ms_532 id.ms.sa_443 
  // [eff0]
  0x2d004904, 0x3558fea0, 0x31205004, 0x1e090404,   // to.sk.un_320 tlh.om.zu_322  fj.sq.az_332 fi.pl.ms_332 
  0x30353b02, 0x1609295a, 0x0f000319, 0x03632d08,   // so.zu.uz_222 sl.pl.hr_553  nl.lv.un_750 sk.sco.nl_443 
  0x2f1c1ea7, 0x1e1c4609, 0x3f22030e, 0x30353405,   // ms.id.su_532 qu.id.ms_444  nl.oc.af_555 xh.zu.uz_333 
  0x3b30fea4, 0x2d1e0da4, 0x35233008, 0x095c1c0e,   // tlh.uz.so_433 cs.ms.sk_433  uz.ky.tg_443 mr.sa.hi_555 
  
  // [f000]
  0x441821ad, 0x17153c05, 0x30483b12, 0x481c1ea4,   // fa.ar.kk_643 ug.sr.un_330  so.tt.uz_654 ms.id.tt_433 
  0x511f0104, 0x2a07510c, 0x5c041208, 0x2f501ca0,   // en.cy.kl_332 kl.it.mt_543  hu.fi.sa_443 id.fj.su_322 
  0x1f0c51ad, 0x313b30ad, 0x07190ba7, 0x1e1c5ca4,   // kl.sv.cy_643 uz.so.az_643  es.gl.it_532 sa.id.ms_433 
  0x5000310d, 0x02004013, 0x4d3548a4, 0x30004e22,   // az.fj.un_540 lb.da.un_650  tt.zu.aa_433 ay.uz.un_870 
  // [f010]
  0xfc380fa9, 0x1530360c, 0x38000805, 0x633f01a9,   // lv.tk.zzp_544 ab.uz.un_543  no.tk.un_330 en.af.sco_544 
  0x16242904, 0x50004607, 0x3639250c, 0x230f0804,   // sl.eo.hr_332 qu.fj.un_420  eu.br.gn_543 no.lv.ca_332 
  0x3b004704, 0x3900250e, 0x18213004, 0x06000f12,   // sn.so.un_320 eu.br.un_550  uz.fa.ar_332 lv.de.un_640 
  0x135c1c60, 0x100825ad, 0x2b002702, 0x0407110c,   // mr.sa.bh_664 mn.uk.be_643  gd.vi.un_220 ro.bg.ru_543 
  // [f020]
  0x23001829, 0x0f1025ad, 0x29322da4, 0x0e100f07,   // ar.ky.un_960 eu.lt.lv_643  sk.bs.sl_433 lv.lt.is_432 
  0x13004802, 0x0a08170d, 0x080448ee, 0x0a003012,   // tt.et.un_220 sr.uk.mk_554  tt.ru.uk_422 uz.pt.un_640 
  0x1b36780c, 0x4afc3612, 0x791e1c11, 0x061564a0,   // ve.gn.tr_543 gn.zzp.yo_654  id.ms.war_653 lg.de.un_320 
  0x2d00360c, 0x06003802, 0x4d641f12, 0x68011dee,   // gn.sk.un_530 tk.de.un_220  cy.lg.aa_654 la.en.ig_422 
  // [f030]
  0x1dfc57a4, 0x473620a9, 0x19433807, 0x29300daf,   // na.zzp.la_433 sq.gn.sn_544  tk.ie.gl_432 cs.uz.sl_655 
  0x1f003008, 0x1b57680d, 0x30552207, 0x3e326408,   // uz.cy.un_430 ig.na.tr_554  oc.rw.uz_432 lg.bs.rm_443 
  0x303831af, 0x47003002, 0x5c005605, 0x1c5e7811,   // az.tk.uz_655 uz.sn.un_220  mg.sa.un_330 ve.ts.id_653 
  0x09251c05, 0x47271812, 0x39003e04, 0x34274704,   // id.eu.pl_333 ga.gd.sn_654  rm.br.un_320 sn.gd.xh_332 
  // [f040]
  0x354709ee, 0x34283012, 0x2a00fe11, 0x290d100e,   // pl.sn.zu_422 uz.sd.ps_654  tlh.mt.un_630 lt.cs.sl_555 
  0x12311ba4, 0x731d1f0c, 0x0d003009, 0x3e003904,   // tr.az.hu_433 cy.la.ny_543  uz.cs.un_440 br.rm.un_320 
  0x185f37a9, 0x186539ee, 0x1f1878ad, 0x35151702,   // st.tn.ga_544 br.gv.ga_422  ve.ga.cy_643 sr.tg.un_220 
  0x0a3717a0, 0x4c003605, 0x34002314, 0x5300220b,   // sr.ba.mk_322 gn.wo.un_330  ky.ps.un_660 oc.ht.un_520 
  // [f050]
  0x10371708, 0x48102304, 0x08000734, 0x0e62fc08,   // sr.ba.be_443 ky.be.tt_332  bg.uk.un_A80 zzp.kha.is_443 
  0x4c193660, 0x343b280e, 0x12006502, 0x2d000d2a,   // gn.gl.wo_664 sd.ks.ps_555  gv.hu.un_220 cs.sk.un_970 
  0x21002212, 0x1c135cee, 0xfc1b6b04, 0x4a0c360c,   // oc.jw.un_640 sa.bh.mr_422  ceb.tr.zzp_332 gn.sv.yo_543 
  0x12302155, 0x311d2aec, 0x3130465a, 0x30182104,   // fa.uz.ur_442 mt.la.az_644  qu.uz.az_553 fa.ar.uz_332 
  // [f060]
  0x1f083307, 0x3d2130ad, 0x54004613, 0x46004e0c,   // nn.no.cy_432 uz.fa.ku_643  qu.ik.un_650 ay.qu.un_530 
  0x06483355, 0x63216508, 0x39381ea0, 0x1703020c,   // nn.tt.de_442 gv.jw.sco_443  ms.tk.br_322 da.nl.sr_543 
  0x131c5ca7, 0x08336b04, 0x080201a0, 0x033f1fa0,   // sa.mr.bh_532 ceb.nn.no_332  en.da.no_322 cy.af.nl_322 
  0x04152aa4, 0x20001505, 0x46005102, 0x3f0265ad,   // bo.ru.un_430 un.sq.un_330  kl.qu.un_220 gv.da.af_643 
  // [f070]
  0x0a543009, 0x5400461a, 0x5e650107, 0x1200561b,   // uz.ik.pt_444 qu.ik.un_760  en.gv.ts_432 mg.hu.un_770 
  0x260365a4, 0x1f2d0d11, 0x3f0315ec, 0x1f6b390c,   // gv.nl.ia_433 cs.sk.cy_653  un.nl.af_644 br.ceb.cy_543 
  0x19000402, 0x1017150c, 0x1f150111, 0x1f00300c,   // fi.gl.un_220 un.sr.be_543  en.cy.un_630 uz.cy.un_530 
  0x2500170e, 0x311c7909, 0x3e220707, 0x19002505,   // sr.mn.un_550 war.id.az_444  it.oc.rm_432 eu.gl.un_330 
  // [f080]
  0x101709a4, 0x35073ca0, 0x12211809, 0x39124f07,   // pl.sr.lt_433 ug.bg.tg_322  ar.fa.ur_444 bi.hu.br_432 
  0x09002421, 0x04004705, 0x48001702, 0x011d15a4,   // eo.pl.un_860 sn.fi.un_330  sr.tt.un_220 un.la.en_433 
  0x303c3602, 0x5d005c05, 0x07fe3ea4, 0x37226aa9,   // ab.ug.uz_222 sa.ss.un_330  rm.tlh.it_433 haw.oc.st_544 
  0x6a4b13a9, 0x08441012, 0x4400170e, 0x37506a08,   // et.mi.haw_544 be.kk.uk_654  sr.kk.un_550 haw.fj.st_443 
  // [f090]
  0x4f006512, 0x5a4b6aaf, 0x49005a34, 0x4636530c,   // gv.bi.un_640 haw.mi.sm_655  sm.to.un_A80 ht.gn.qu_543 
  0x2c040307, 0x30204708, 0x3f580309, 0x155a4904,   // nl.fi.fy_432 sn.sq.uz_443  nl.om.af_444 to.sm.un_332 
  0x37676508, 0x5803130c, 0x195911ad, 0x3b68650c,   // gv.ak.st_443 et.nl.om_543  ro.rn.gl_643 gv.ig.so_543 
  0x643f4c09, 0x155e2aee, 0x654f5aa4, 0x03223f08,   // wo.af.lg_444 mt.ts.un_422  sm.bi.gv_433 af.oc.nl_443 
  // [f0a0]
  0x434d3ea7, 0x533925a0, 0x644a3b08, 0x67000107,   // rm.aa.ie_532 eu.br.ht_322  so.yo.lg_443 en.ak.un_420 
  0x1d694d07, 0x184423a4, 0x3b4d1c07, 0x03346404,   // aa.mfe.la_432 ky.kk.ar_433  id.aa.so_432 lg.xh.nl_332 
  0x4b5a49ad, 0x65643b12, 0x130b6507, 0x5700241a,   // to.sm.mi_643 so.lg.gv_654  gv.es.et_432 eo.na.un_760 
  0x17292da0, 0x4c3b6512, 0x644c580c, 0x021d5107,   // sk.sl.sr_322 gv.so.wo_654  om.wo.lg_543 kl.la.da_432 
  // [f0b0]
  0x4d00581a, 0x033f13a4, 0x34005e05, 0x367946ad,   // om.aa.un_760 et.af.nl_433  ts.xh.un_330 qu.war.gn_643 
  0x3035340c, 0x152d0d02, 0x4a005313, 0x114c61ad,   // xh.zu.uz_543 cs.sk.un_222  ht.yo.un_650 za.wo.ro_643 
  0x300448a0, 0x250a0207, 0x3b353405, 0x4c001904,   // tt.ru.uz_322 da.pt.eu_432  xh.zu.so_333 gl.wo.un_320 
  0x0c080207, 0x18003c1a, 0x48001111, 0x31000d09,   // da.no.sv_432 ug.ar.un_760  ro.tt.un_630 cs.az.un_440 
  // [f0c0]
  0x37150411, 0x15002536, 0x35001012, 0x3c002335,   // ru.ba.un_630 mn.un.un_AA0  be.tg.un_640 ky.ug.un_A90 
  0x2a526404, 0x0a171007, 0x4c006505, 0x47006007,   // lg.ha.mt_332 be.sr.mk_432  gv.wo.un_330 vo.sn.un_420 
  0x076342ee, 0x33040804, 0x457302a9, 0x565a4908,   // co.sco.it_422 no.fi.nn_332  da.ny.ln_544 to.sm.mg_443 
  0x0c6458a0, 0x3000690b, 0x6e5305a4, 0x73006712,   // om.lg.sv_322 mfe.uz.un_520  fr.ht.hmn_433 ak.ny.un_640 
  // [f0d0]
  0x615d34a9, 0x52400d0c, 0x02004b0d, 0x3e007904,   // xh.ss.za_544 cs.lb.ha_543  mi.da.un_540 war.rm.un_320 
  0x5700671a, 0x6a0f6005, 0x2a00640c, 0x0a5a02a7,   // ak.na.un_760 vo.lv.haw_333  lg.mt.un_530 da.sm.pt_532 
  0x682a6005, 0x355d3404, 0x3729450c, 0x441715a4,   // vo.mt.ig_333 xh.ss.zu_332  ln.sl.st_543 un.sr.kk_433 
  0x02003b14, 0x38002a08, 0x0c4207a0, 0x01636508,   // so.da.un_660 mt.tk.un_430  it.co.sv_322 gv.sco.en_443 
  // [f0e0]
  0x1000442a, 0x15043c05, 0xfe153fee, 0x64004c07,   // kk.be.un_970 ug.ru.un_333  af.tlh.un_420 wo.lg.un_420 
  0x450264ad, 0x0c001e0d, 0x495a280c, 0x21796bad,   // lg.da.ln_643 ms.sv.un_540  sw.sm.to_543 ceb.war.jw_643 
  0x04070a5a, 0x39004e0e, 0x0d131c11, 0x33086402,   // mk.bg.ru_553 ay.br.un_550  mr.bh.ne_653 lg.no.nn_222 
  0x1f00390b, 0x0837380c, 0x52676407, 0x273e3905,   // br.cy.un_520 tk.ba.uk_543  lg.ak.ha_432 br.rm.gd_333 
  // [f0f0]
  0x6b040c04, 0x52001004, 0x10092daf, 0x033f4ca4,   // sv.fi.ceb_332 lt.ha.un_320  sk.pl.lt_655 wo.af.nl_433 
  0x0640395a, 0x04003308, 0x04071709, 0x652d09ad,   // br.lb.de_553 nn.fi.un_430  sr.bg.ru_444 pl.sk.gv_643 
  0x64561008, 0x033f3b13, 0x32002505, 0x03093e07,   // lt.mg.lg_443 so.af.nl_665  eu.bs.un_330 rm.pl.nl_432 
  0x034c3fad, 0x3f083b02, 0x3f000634, 0x3b3e3f0c,   // af.wo.nl_643 so.no.af_222  de.af.un_A80 af.rm.so_543 
  // [f100]
  0x3900230d, 0x40003f07, 0x19630ba4, 0x11004312,   // ca.br.un_540 af.lb.un_420  es.sco.gl_433 ie.ro.un_640 
  0x10441108, 0x4302670c, 0x35390307, 0x110f2daf,   // ro.kk.be_443 ak.da.ie_543  nl.br.zu_432 sk.lv.ro_655 
  0x0f042d0c, 0x58033f55, 0x04100f12, 0x4c033f07,   // sk.fi.lv_543 af.nl.om_442  lv.lt.fi_654 af.nl.wo_432 
  0x303736a0, 0x2d040da0, 0x100811a9, 0x10444855,   // ab.ba.uz_322 cs.fi.sk_322  ro.uk.be_544 tt.kk.be_442 
  // [f110]
  0x3f000808, 0x330804a4, 0x170a1107, 0x0e00020b,   // no.af.un_430 fi.no.nn_433  ro.mk.sr_432 da.is.un_520 
  0x042508a4, 0x15072307, 0x3c3011a0, 0x16003f04,   // uk.mn.ru_433 ky.bg.un_432  ro.uz.ug_322 af.hr.un_320 
  0x1500fc21, 0x06000e02, 0xfc00250d, 0x13000305,   // zzp.un.un_860 is.de.un_220  eu.zzp.un_540 nl.et.un_330 
  0x0e4a2ea9, 0x3e601e0c, 0x0f001c04, 0x190a1aa4,   // fo.yo.is_544 ms.vo.rm_543  id.lv.un_320 tl.pt.gl_433 
  // [f120]
  0x100f33a0, 0x1546fc04, 0x123430a0, 0x131d65a0,   // nn.lv.lt_322 zzp.qu.un_332  uz.ps.ur_322 gv.la.et_322 
  0x24601e07, 0x240f1c0c, 0x12004a05, 0x07440aaf,   // ms.vo.eo_432 id.lv.eo_543  yo.hu.un_330 mk.kk.bg_655 
  0x1a0f1e0c, 0x183d3008, 0x0613fc02, 0x321703ee,   // ms.lv.tl_543 uz.ku.ar_443  zzp.et.de_222 nl.sr.bs_422 
  0x190b76a9, 0x465c79a9, 0x122e4a07, 0x032e0204,   // crs.es.gl_544 war.sa.qu_544  yo.fo.hu_432 da.fo.nl_332 
  // [f130]
  0x0d120aa4, 0x3e0f2412, 0x0804100e, 0x1d3e3907,   // pt.hu.cs_433 eo.lv.rm_654  be.ru.uk_555 br.rm.la_432 
  0x0f1a46ec, 0x46002a21, 0x311d2a02, 0x300a48a0,   // qu.tl.lv_644 mt.qu.un_860  mt.la.az_222 tt.pt.uz_322 
  0x0a08070c, 0x10153608, 0x1d003004, 0x15003520,   // bg.uk.mk_543 ab.be.un_430  uz.la.un_320 tg.un.un_850 
  0x251936a9, 0x31004e19, 0x461d54a0, 0x37483c09,   // gn.gl.eu_544 ay.az.un_750  ik.la.qu_322 ug.tt.ba_444 
  // [f140]
  0x22003604, 0x23584dec, 0x06075707, 0x0a303c07,   // gn.oc.un_320 aa.om.ca_644  na.it.de_432 ug.uz.mk_432 
  0x100d2d11, 0x3530150e, 0x442537af, 0x261d08a4,   // sk.cs.lt_653 un.uz.tg_555  ba.mn.kk_655 no.la.ia_433 
  0x28123b05, 0x1a001213, 0x0d5c09a6, 0x35170402,   // ks.ur.sd_333 hu.tl.un_650  hi.sa.ne_521 ru.sr.tg_222 
  0x374430a0, 0x170a1512, 0x6e6b1d07, 0x5a001004,   // uz.kk.ba_322 un.mk.sr_654  la.ceb.hmn_432 lt.sm.un_320 
  // [f150]
  0x4418345a, 0x2d1710a6, 0x10005a07, 0x5c003e07,   // ps.ar.kk_553 lt.sr.sk_521  sm.lt.un_420 rm.sa.un_420 
  0x151015a4, 0x330811a4, 0x1700230c, 0x58192309,   // un.be.un_433 ro.no.nn_433  ky.sr.un_530 ca.gl.om_444 
  0x39001f09, 0x3800761a, 0x34190a0c, 0xfc1838ee,   // cy.br.un_440 crs.tk.un_760  pt.gl.xh_543 tk.ga.zzp_422 
  0x38565c07, 0x641038ee, 0x097952a0, 0x647938a4,   // sa.mg.tk_432 tk.lt.lg_422  ha.war.pl_322 tk.war.lg_433 
  // [f160]
  0x4a58780c, 0x220afea4, 0x35383013, 0x5a003f02,   // ve.om.yo_543 tlh.pt.oc_433  uz.tk.tg_665 af.sm.un_220 
  0x342328a0, 0x00005b37, 0x123b210c, 0x69531008,   // sd.ky.ps_322 sg.un.un_B00  fa.ks.ur_543 lt.ht.mfe_443 
  0x043810a4, 0x1e1c2105, 0x6479670c, 0x5000390e,   // be.tk.ru_433 jw.id.ms_333  ak.war.lg_543 br.fj.un_550 
  0x6b1a01a0, 0x67005b0d, 0x595547a4, 0x215c3808,   // en.tl.ceb_322 sg.ak.un_540  sn.rw.rn_433 tk.sa.jw_443 
  // [f170]
  0x34007912, 0x5c1038ee, 0x2a002808, 0x5f675611,   // war.xh.un_640 tk.lt.sa_422  sw.mt.un_430 mg.ak.tn_653 
  0x0676240c, 0x2f216b0b, 0x400c15a9, 0x28004304,   // eo.crs.de_543 ceb.jw.su_542  un.sv.lb_544 ie.sw.un_320 
  0x06003e05, 0x5f43240c, 0x30002807, 0x46001507,   // rm.de.un_330 eo.ie.tn_543  sw.uz.un_420 un.qu.un_420 
  0x1f001502, 0x15000c04, 0x40001f08, 0x17004b0d,   // un.cy.un_220 sv.un.un_320  cy.lb.un_430 mi.sr.un_540 
  // [f180]
  0x6800fc21, 0x40632a05, 0x15001d0c, 0x28004209,   // zzp.ig.un_860 mt.sco.lb_333  la.un.un_530 co.sw.un_440 
  0x482b220c, 0x2145520b, 0x211546a0, 0x5e5978ec,   // oc.vi.tt_543 ha.ln.jw_542  qu.jw.un_320 ve.rn.ts_644 
  0x5a487309, 0x40060c09, 0x341828ac, 0x17004808,   // ny.tt.sm_444 sv.de.lb_444  sd.ar.ps_632 tt.sr.un_430 
  0x48190b02, 0x04373bee, 0x43000614, 0x0400240c,   // es.gl.tt_222 so.st.fi_422  de.ie.un_660 eo.fi.un_530 
  // [f190]
  0x7300470c, 0x49372508, 0x02240b08, 0x390635ee,   // sn.ny.un_530 eu.st.to_443  es.eo.da_443 zu.de.br_422 
  0x21154604, 0x69061fa4, 0x23697655, 0x0c4615a0,   // qu.jw.un_320 cy.de.mfe_433  crs.mfe.ca_442 un.qu.sv_322 
  0x2348440c, 0x5743060e, 0x182d0d55, 0x25003c14,   // kk.tt.ky_543 de.ie.na_555  cs.sk.ga_442 ug.mn.un_660 
  0x735c5a0d, 0x6a04230c, 0x0804110e, 0x28006412,   // sm.sa.ny_554 ca.fi.haw_543  ro.ru.uk_555 lg.sw.un_640 
  // [f1a0]
  0x4e135c0c, 0x042e0c04, 0x5c1e1c0d, 0x15006505,   // sa.et.ay_543 sv.fo.fi_332  id.ms.sa_554 gv.un.un_330 
  0x1c2f21af, 0x3e2601a0, 0x131c5c13, 0x551d25ac,   // jw.su.id_655 en.ia.rm_322  sa.mr.bh_665 eu.la.rw_632 
  0x3023150b, 0x225d3704, 0x20321609, 0x792a02ad,   // un.ky.uz_542 st.ss.oc_332  hr.bs.sq_444 da.mt.war_643 
  0x23383c08, 0x284a36a0, 0x3300200c, 0x1e1c2f14,   // ug.tk.ky_443 gn.yo.sw_322  sq.nn.un_530 su.id.ms_666 
  // [f1b0]
  0x472021a7, 0x0636220d, 0x04466aad, 0x5342feee,   // jw.sq.sn_532 oc.gn.de_554  haw.qu.fi_643 tlh.co.ht_422 
  0x18282111, 0x60000f09, 0x18002a04, 0x061261a7,   // fa.sd.ar_653 lv.vo.un_440  mt.ga.un_320 za.hu.de_532 
  0x37101504, 0x78003705, 0x3d1823a0, 0x3121fc07,   // un.be.ba_332 st.ve.un_330  ky.ar.ku_322 zzp.jw.az_432 
  0x2663010c, 0x55283b04, 0x0420290b, 0x48461d04,   // en.sco.ia_543 so.sw.rw_332  sl.sq.fi_542 la.qu.tt_332 
  // [f1c0]
  0x3308200c, 0x36000714, 0x374438a4, 0x793e51a6,   // sq.no.nn_543 bg.ab.un_660  tk.kk.ba_433 kl.rm.war_521 
  0x2348370c, 0x46004c0c, 0xfe002012, 0x2134285a,   // ba.tt.ky_543 wo.qu.un_530  sq.tlh.un_640 sd.ps.fa_553 
  0x313e5107, 0x17040aa7, 0x48153511, 0x104811a0,   // kl.rm.az_432 mk.ru.sr_532  tg.tt.un_630 ro.tt.be_322 
  0x2c405104, 0x1b31380d, 0x0700080b, 0x01004a05,   // kl.lb.fy_332 tk.az.tr_554  uk.bg.un_520 yo.en.un_330 
  // [f1d0]
  0x113708a4, 0x151711a4, 0x29321707, 0x0a000604,   // uk.ba.ro_433 ro.sr.un_433  sr.bs.sl_432 de.pt.un_320 
  0x2d020d07, 0x3607240c, 0x10250812, 0x242f0ba0,   // cs.da.sk_432 eo.it.gn_543  uk.mn.be_654 es.su.eo_322 
  0x73025caf, 0x4b790204, 0x5c00420c, 0x2d315c04,   // sa.da.ny_655 da.war.mi_332  co.sa.un_530 sa.az.sk_332 
  0x0b240212, 0x2456490c, 0x3000460c, 0x5600360d,   // da.eo.es_654 to.mg.eo_543  qu.uz.un_530 gn.mg.un_540 
  // [f1e0]
  0x0f2a24ee, 0x3e0657ad, 0x2319220d, 0x190b5d0c,   // eo.mt.lv_422 na.de.rm_643  oc.gl.ca_554 ss.es.gl_543 
  0x08002404, 0x23190b0e, 0x244a1055, 0x0800240d,   // eo.no.un_320 es.gl.ca_555  lt.yo.eo_442 eo.no.un_540 
  0x5c3655a4, 0x5c5d52af, 0x19222305, 0x390f2404,   // rw.gn.sa_433 ha.ss.sa_655  ca.oc.gl_333 eo.lv.br_332 
  0x075e79ad, 0x5d005013, 0x135c24ad, 0x65634d07,   // war.ts.it_643 fj.ss.un_650  eo.sa.et_643 aa.sco.gv_432 
  // [f1f0]
  0x39132407, 0x24000a13, 0x3b135aa9, 0x0b003613,   // eo.et.br_432 pt.eo.un_650  sm.et.so_544 gn.es.un_650 
  0x110a170c, 0x4600fe0b, 0x791a6b14, 0x3b475aad,   // sr.mk.ro_543 tlh.qu.un_520  ceb.tl.war_666 sm.sn.so_643 
  0x78796b13, 0x5a68130e, 0x20103fec, 0x1f2255a0,   // ceb.war.ve_665 et.ig.sm_555  af.lt.sq_644 rw.oc.cy_322 
  0x49002a02, 0x5a1330a9, 0xfc00640d, 0xfe64215a,   // mt.to.un_220 uz.et.sm_544  lg.zzp.un_540 jw.lg.tlh_553 
  // [f200]
  0x4c394d04, 0x40030605, 0x1d00250d, 0x31384855,   // aa.br.wo_332 de.nl.lb_333  eu.la.un_540 tt.tk.az_442 
  0x2c060307, 0x2f153ba0, 0x022c1302, 0x01001807,   // nl.de.fy_432 so.su.un_320  et.fy.da_222 ga.en.un_420 
  0x2b002c13, 0x04102504, 0x5a3b2112, 0x48005d12,   // fy.vi.un_650 mn.be.ru_332  jw.so.sm_654 ss.tt.un_640 
  0x480e060b, 0x1f2b2c12, 0x3f020ca0, 0x4200050b,   // de.is.tt_542 fy.vi.cy_654  sv.da.af_322 fr.co.un_520 
  // [f210]
  0x3b254807, 0x03233e07, 0x2a003e08, 0x02595508,   // tt.eu.so_432 rm.ca.nl_432  rm.mt.un_430 rw.rn.da_443 
  0x39062304, 0x2b192c08, 0x1f002b19, 0x404301a4,   // ca.de.br_332 fy.gl.vi_443  vi.cy.un_750 en.ie.lb_433 
  0x304d3504, 0x2b001f0e, 0x53004a0d, 0x34004f07,   // zu.aa.uz_332 cy.vi.un_550  yo.ht.un_540 bi.xh.un_420 
  0x242c3702, 0x2c002b19, 0x56005d04, 0x254c19a0,   // st.fy.eo_222 vi.fy.un_750  ss.mg.un_320 gl.wo.eu_322 
  // [f220]
  0x79002d04, 0x30005e07, 0x353b4cec, 0x3e1201a0,   // sk.war.un_320 ts.uz.un_420  wo.so.zu_644 en.hu.rm_322 
  0x220f2302, 0x65001d02, 0x43001208, 0x213012ee,   // ca.lv.oc_222 la.gv.un_220  hu.ie.un_430 ur.uz.fa_422 
  0x05222305, 0x374823ec, 0x03004a07, 0x37006719,   // ca.oc.fr_333 ky.tt.ba_644  yo.nl.un_420 ak.st.un_750 
  0xfc030a02, 0x6a006712, 0x25731fad, 0x46fe3807,   // pt.nl.zzp_222 ak.haw.un_640  cy.ny.eu_643 tk.tlh.qu_432 
  // [f230]
  0x53002b0c, 0x2a004807, 0x2d321604, 0xfe000621,   // vi.ht.un_530 tt.mt.un_420  hr.bs.sk_332 de.tlh.un_860 
  0x34fc0204, 0x2b010602, 0x283012a9, 0x123430a7,   // da.zzp.xh_332 de.en.vi_222  ur.uz.sd_544 uz.ps.ur_532 
  0x2206fe11, 0x300a3502, 0x27003804, 0x15353c55,   // tlh.de.oc_653 tg.mk.uz_222  tk.gd.un_320 ug.tg.un_442 
  0x192a5ea0, 0x2510360c, 0x53630107, 0x6300fe12,   // ts.mt.gl_322 ab.be.mn_543  en.sco.ht_432 tlh.sco.un_640 
  // [f240]
  0x5d3078ee, 0x37482512, 0xfe000102, 0x2d2bfeaf,   // ve.uz.ss_422 mn.tt.ba_654  en.tlh.un_220 tlh.vi.sk_655 
  0x152530a4, 0x68fc48af, 0x19251d12, 0x462a28a0,   // uz.mn.un_433 tt.zzp.ig_655  la.eu.gl_654 sw.mt.qu_322 
  0x5c004204, 0x4a5afc07, 0x55006819, 0x6700fc1a,   // co.sa.un_320 zzp.sm.yo_432  ig.rw.un_750 zzp.ak.un_760 
  0x246845a4, 0x33252405, 0x15fc0107, 0x03043f04,   // ln.ig.eo_433 eo.eu.nn_333  en.zzp.un_432 af.fi.nl_332 
  // [f250]
  0x06fc620b, 0x3600251b, 0x07040aa7, 0x4e00fc1a,   // kha.zzp.de_542 mn.ab.un_770  mk.ru.bg_532 zzp.ay.un_760 
  0x061557ad, 0x0a0711af, 0x3f101155, 0x071023a4,   // na.de.un_630 ro.bg.mk_655  ro.lt.af_442 ky.be.bg_433 
  0x081044ee, 0x55fc0802, 0x104836ee, 0x043ffcaf,   // kk.be.uk_422 no.zzp.rw_222  ab.tt.be_422 zzp.af.fi_655 
  0x62150111, 0x3f03fc0c, 0x13fc040c, 0x0615fcee,   // en.kha.un_630 zzp.nl.af_543  fi.zzp.et_543 zzp.de.un_420 
  // [f260]
  0x032efc07, 0x0804300c, 0x304423a9, 0x561f3f0b,   // zzp.fo.nl_432 uz.ru.uk_543  ky.kk.uz_544 af.cy.mg_542 
  0x02184304, 0x231004a0, 0x17350a05, 0x482330a7,   // ie.ga.da_332 ru.be.ky_322  mk.tg.sr_333 uz.ky.tt_532 
  0x313811a4, 0x03430505, 0x43232208, 0x222312ee,   // ro.tk.az_433 fr.ie.nl_333  oc.ca.ie_443 hu.ca.oc_422 
  0x18342311, 0x22231805, 0x120e22a4, 0x121823ad,   // ky.ps.ar_653 ga.ca.oc_333  oc.is.hu_433 ky.ar.ur_643 
  // [f270]
  0x1207420e, 0x23122255, 0x5a001304, 0x42481007,   // co.it.hu_555 oc.hu.ca_442  et.sm.un_320 lt.tt.co_432 
  0x2223120c, 0x42450509, 0x22234aa9, 0x222343a4,   // hu.ca.oc_543 fr.ln.co_444  yo.ca.oc_544 ie.ca.oc_433 
  0x0d3b090c, 0x251523af, 0x0e003307, 0x23001219,   // hi.ks.ne_543 ky.mn.un_650  nn.is.un_420 hu.ca.un_750 
  0x22fe460c, 0x463148a0, 0x23224308, 0x12002207,   // qu.tlh.oc_543 tt.az.qu_322  ie.oc.ca_443 oc.hu.un_420 
  // [f280]
  0x084804ee, 0x12001f12, 0x3c212304, 0x211828a9,   // ru.tt.uk_422 cy.hu.un_640  ky.fa.ug_332 sd.ar.fa_544 
  0x300811a0, 0x46003119, 0x30001f04, 0x0f001f1a,   // ro.uk.uz_322 az.qu.un_750  cy.uz.un_320 cy.lv.un_760 
  0x172523ee, 0x131c5c05, 0x2e0e2204, 0x2300120c,   // ky.mn.sr_422 sa.mr.bh_333  oc.is.fo_332 ur.ky.un_530 
  0x3578735a, 0x28343512, 0x3100200e, 0x2a004c12,   // ny.ve.zu_553 zu.xh.sw_654  sq.az.un_550 wo.mt.un_640 
  // [f290]
  0x25113ea0, 0x5100350e, 0x223e1ea4, 0x37353413,   // rm.ro.eu_322 zu.kl.un_550  ms.rm.oc_433 xh.zu.st_665 
  0x10005a13, 0x302035af, 0x5c004821, 0x100815a0,   // sm.lt.un_650 zu.sq.uz_655  tt.sa.un_860 un.uk.be_322 
  0x24000f08, 0x3f7902a0, 0x5d00340c, 0x3620260c,   // lv.eo.un_430 da.war.af_322  xh.ss.un_530 ia.sq.gn_543 
  0x3100350d, 0x332a5c07, 0x223e1fad, 0x170410a4,   // zu.az.un_540 sa.mt.nn_432  cy.rm.oc_643 be.ru.sr_433 
  // [f2a0]
  0x375d3409, 0x3100460c, 0x283435ad, 0x5120fe11,   // xh.ss.st_444 qu.az.un_530  zu.xh.sw_643 tlh.sq.kl_653 
  0x032217a7, 0x78271813, 0x081525ac, 0x3e005c1a,   // sr.oc.nl_532 ga.gd.ve_665  mn.uk.un_620 sa.rm.un_760 
  0x5a4950ee, 0x3f00fc12, 0x1f223e08, 0x3e001f09,   // fj.to.sm_422 zzp.af.un_640  rm.oc.cy_443 cy.rm.un_440 
  0x6502300c, 0x1300600e, 0x115c3e09, 0x123021a4,   // uz.da.gv_543 vo.et.un_550  rm.sa.ro_444 fa.uz.ur_433 
  // [f2b0]
  0x6a5d06a7, 0x1e1cfea9, 0x3f0f2605, 0x24002305,   // de.ss.haw_532 tlh.id.ms_544  ia.lv.af_333 ca.eo.un_330 
  0x12000c0e, 0x0b433e04, 0x53002704, 0x3c0a2304,   // sv.hu.un_550 rm.ie.es_332  gd.ht.un_320 ky.mk.ug_332 
  0x23004202, 0x48381113, 0x565a4912, 0x1d002e02,   // co.ca.un_220 ro.tk.tt_665  to.sm.mg_654 fo.la.un_220 
  0x2e002c05, 0x00003837, 0x490a5a07, 0x064065a0,   // fy.fo.un_330 tk.un.un_B00  sm.pt.to_432 gv.lb.de_322 
  // [f2c0]
  0xfc00180c, 0x38002b04, 0x244a6707, 0x182315a0,   // ga.zzp.un_530 vi.tk.un_320  ak.yo.eo_432 un.ca.ga_322 
  0x20450204, 0x1800090b, 0x421d1fa4, 0x303c4804,   // da.ln.sq_332 pl.ga.un_520  cy.la.co_433 tt.ug.uz_332 
  0x6b001818, 0x322d0d55, 0x1b001211, 0x392305ee,   // ga.ceb.un_740 cs.sk.bs_442  hu.tr.un_630 fr.ca.br_422 
  0x38151507, 0x09000f0d, 0x10002808, 0x07001f13,   // un.tk.un_420 lv.pl.un_540  sw.lt.un_430 cy.it.un_650 
  // [f2d0]
  0x3432560c, 0x401024ec, 0x22420707, 0x421d22a0,   // mg.bs.xh_543 eo.lt.lb_644  it.co.oc_432 oc.la.co_322 
  0xfe2f62af, 0x3400451a, 0x12002c09, 0x36125fa7,   // kha.su.tlh_655 ln.xh.un_760  fy.hu.un_440 tn.hu.gn_532 
  0x68595504, 0x2300360b, 0x25476805, 0x534556ec,   // rw.rn.ig_332 ab.ky.un_520  ig.sn.eu_333 mg.ln.ht_644 
  0x442315a7, 0x3200162c, 0x07004213, 0x3200160d,   // un.ky.kk_532 hr.bs.un_990  co.it.un_650 hr.bs.un_540 
  // [f2e0]
  0x346445ec, 0x68007308, 0x4a3647ee, 0x213831a9,   // ln.lg.xh_644 ny.ig.un_430  sn.gn.yo_422 az.tk.jw_544 
  0x321620a9, 0x640709a4, 0x79000920, 0x3c442314,   // sq.hr.bs_544 pl.it.lg_433  pl.war.un_850 ky.kk.ug_666 
  0x47000f13, 0x36003811, 0x20330813, 0x1800250d,   // lv.sn.un_650 tk.gn.un_630  no.nn.sq_665 eu.ga.un_540 
  0x59483408, 0x04321655, 0x321620af, 0x442112ad,   // xh.tt.rn_443 hr.bs.fi_442  sq.hr.bs_655 ur.fa.kk_643 
  // [f2f0]
  0x3216200e, 0x06002504, 0x31471ba0, 0x0915fcad,   // sq.hr.bs_555 eu.de.un_320  tr.sn.az_322 zzp.pl.un_630 
  0x09004314, 0x6509fc08, 0x0a17110b, 0x6b091dec,   // ie.pl.un_660 zzp.pl.gv_443  ro.sr.mk_542 la.pl.ceb_644 
  0x2c2e0e5a, 0x5400600e, 0x064057ad, 0x23002220,   // is.fo.fy_553 vo.ik.un_550  na.lb.de_643 oc.ca.un_850 
  0x5000540c, 0x48465102, 0x2a005107, 0x341830a7,   // ik.fj.un_530 kl.qu.tt_222  kl.mt.un_420 uz.ar.ps_532 
  // [f300]
  0x08000411, 0x3c121807, 0x240446a0, 0x1d00360d,   // ru.uk.un_630 ar.ur.ug_432  qu.fi.eo_322 gn.la.un_540 
  0x3b6b3409, 0x044251a4, 0x4800641a, 0x30383cad,   // xh.ceb.so_444 kl.co.fi_433  lg.tt.un_760 ug.tk.uz_643 
  0x3448640c, 0x30004207, 0x044651ac, 0x515c04ee,   // lg.tt.xh_543 co.uz.un_420  kl.qu.fi_632 fi.sa.kl_422 
  0x51000702, 0x48000204, 0x0900fe0c, 0x1a3b58ad,   // it.kl.un_220 da.tt.un_320  tlh.pl.un_530 om.so.tl_643 
  // [f310]
  0x3b4c620c, 0x02006402, 0x0458420b, 0x47001c04,   // kha.wo.so_543 lg.da.un_220  co.om.fi_542 id.sn.un_320 
  0xfe64130c, 0x030658a0, 0x393f0204, 0x40034304,   // et.lg.tlh_543 om.de.nl_322  da.af.br_332 ie.nl.lb_332 
  0x6b052204, 0x0b261e07, 0x3b52580c, 0x48006e07,   // oc.fr.ceb_332 ms.ia.es_432  om.ha.so_543 hmn.tt.un_420 
  0x0c005802, 0x583b4dac, 0x16595207, 0x336564ee,   // om.sv.un_220 aa.so.om_632  ha.rn.hr_432 lg.gv.nn_422 
  // [f320]
  0x55005921, 0x29006e08, 0x39000c09, 0x25003b07,   // rn.rw.un_860 hmn.sl.un_430  sv.br.un_440 so.eu.un_420 
  0x5947550c, 0x08005804, 0x18006005, 0x31131ba7,   // rw.sn.rn_543 om.no.un_320  vo.ga.un_330 tr.et.az_532 
  0x3b5831af, 0x31004207, 0x35595504, 0x76000804,   // az.om.so_655 co.az.un_420  rw.rn.zu_332 no.crs.un_320 
  0x2f003b04, 0x122830af, 0x15001504, 0x2d003804,   // so.su.un_320 uz.sd.ur_655  un.un.un_320 tk.sk.un_320 
  // [f330]
  0x110717a4, 0x0d004f19, 0x79521c0c, 0x3e006e04,   // sr.bg.ro_433 bi.cs.un_750  id.ha.war_543 hmn.rm.un_320 
  0x45006423, 0x4559500c, 0x34595504, 0x4a472fad,   // lg.ln.un_880 fj.rn.ln_543  rw.rn.xh_332 su.sn.yo_643 
  0x361c6707, 0x55645eec, 0x040158a0, 0x5c005e19,   // ak.id.gn_432 ts.lg.rw_644  om.en.fi_322 ts.sa.un_750 
  0x4a64750c, 0x20646904, 0x2f1268a9, 0x676164af,   // nso.lg.yo_543 mfe.lg.sq_332  ig.hu.su_544 lg.za.ak_655 
  // [f340]
  0x674afc0c, 0x37441507, 0x5e00551a, 0x7300200e,   // zzp.yo.ak_543 un.kk.ba_432  rw.ts.un_760 sq.ny.un_550 
  0x34025ea4, 0x762069af, 0x5c001a0d, 0x0a170809,   // ts.da.xh_433 mfe.sq.crs_655  tl.sa.un_540 uk.sr.mk_444 
  0x73592811, 0x4c1f5dad, 0x784734a9, 0x353611ad,   // sw.rn.ny_653 ss.cy.wo_643  xh.sn.ve_544 ro.ab.tg_643 
  0x101711a0, 0x0200fc0e, 0x36006907, 0x500165a0,   // ro.sr.be_322 zzp.da.un_550  mfe.gn.un_420 gv.en.fj_322 
  // [f350]
  0x3400fc11, 0x5c004805, 0x3406fca0, 0x23061f12,   // zzp.xh.un_630 tt.sa.un_330  zzp.de.xh_322 cy.de.ca_654 
  0x3e231507, 0x044410ee, 0x30042504, 0x3e221fad,   // un.ca.rm_432 be.kk.ru_422  mn.ru.uz_332 cy.oc.rm_643 
  0x2c405d0c, 0x48005b0d, 0xfc005c14, 0x0802fc0e,   // ss.lb.fy_543 sg.tt.un_540  sa.zzp.un_660 zzp.da.no_555 
  0x1100360e, 0x483e5cee, 0x1f003e05, 0x2c2e0e0e,   // ab.ro.un_550 sa.rm.tt_422  rm.cy.un_330 is.fo.fy_555 
  // [f360]
  0x3e002407, 0x350730a7, 0x1200fe0c, 0x2e761ba4,   // eo.rm.un_420 uz.bg.tg_532  tlh.hu.un_530 tr.crs.fo_433 
  0x483c150b, 0x1823070d, 0x252315ec, 0x4f00581a,   // un.ug.tt_542 it.ca.ga_554  un.ky.mn_644 om.bi.un_760 
  0x5800fc14, 0x3f00fe04, 0x6b0e120b, 0x272c0402,   // zzp.om.un_660 tlh.af.un_320  hu.is.ceb_542 fi.fy.gd_222 
  0x29653807, 0x3430120b, 0x112d12ee, 0x5a004911,   // tk.gv.sl_432 ur.uz.ps_542  hu.sk.ro_422 to.sm.un_630 
  // [f370]
  0x49505a02, 0x681d0308, 0x03133f0e, 0x253b1308,   // sm.fj.to_222 nl.la.ig_443  af.et.nl_555 et.so.eu_443 
  0x0363130c, 0x1b006507, 0x34033f12, 0x2f000519,   // et.sco.nl_543 gv.tr.un_420  af.nl.xh_654 fr.su.un_750 
  0x5a496760, 0x4d583f12, 0x404c6007, 0x033f3b5a,   // ak.to.sm_664 af.om.aa_654  vo.wo.lb_432 so.af.nl_553 
  0x421207a0, 0x43013b04, 0x02520107, 0x20000a02,   // it.hu.co_322 so.en.ie_332  en.ha.da_432 pt.sq.un_220 
  // [f380]
  0x21341255, 0x2e00060c, 0x07003402, 0x2c2e0ea4,   // ur.ps.fa_442 de.fo.un_530  xh.it.un_220 is.fo.fy_433 
  0x65000614, 0x360a1007, 0x1d472fa7, 0x152c2507,   // de.gv.un_660 be.mk.ab_432  su.sn.la_532 eu.fy.un_432 
  0x321217a0, 0x052723a4, 0x07112ca0, 0x2c403ea0,   // sr.hu.bs_322 ca.gd.fr_433  fy.ro.it_322 rm.lb.fy_322 
  0x1f392760, 0x653b13a7, 0x65001314, 0x2f45fc0c,   // gd.br.cy_664 et.so.gv_532  et.gv.un_660 zzp.ln.su_543 
  // [f390]
  0x3927060c, 0x272311a4, 0x65001312, 0x1d6001a4,   // de.gd.br_543 ro.ca.gd_433  et.gv.un_640 en.vo.la_433 
  0x070a250c, 0x07081011, 0x0215080c, 0x090d5c5a,   // mn.mk.bg_543 be.uk.bg_653  no.da.un_530 sa.ne.hi_553 
  0x1a004819, 0x11393f14, 0x3600480c, 0x1f23390c,   // tt.tl.un_750 af.br.ro_666  tt.ab.un_530 br.ca.cy_543 
  0x2c390604, 0x1328fc08, 0x40002c05, 0x19001d0d,   // de.br.fy_332 zzp.sw.et_443  fy.lb.un_330 la.gl.un_540 
  // [f3a0]
  0x6428370c, 0x1128fc60, 0x0d001604, 0x45fc68a4,   // st.sw.lg_543 zzp.sw.ro_664  hr.cs.un_320 ig.zzp.ln_433 
  0x4a00680e, 0x343d1209, 0x0800170c, 0x1f005a0c,   // ig.yo.un_550 ur.ku.ps_444  sr.uk.un_530 sm.cy.un_530 
  0x4a002413, 0x342344a7, 0x38001b12, 0x34001607,   // eo.yo.un_650 kk.ky.ps_532  tr.tk.un_640 th.ps.un_420 
  0x07651755, 0x23124407, 0x35281708, 0x5f007322,   // sr.gv.it_442 kk.ur.ky_432  sr.sw.zu_443 ny.tn.un_870 
  // [f3b0]
  0x23000a14, 0x343c2308, 0x334c79ee, 0x0e2a4202,   // mk.ky.un_660 ky.ug.ps_443  war.wo.nn_422 co.mt.is_222 
  0x33004002, 0xfe3b4609, 0x3b001d0d, 0xfe230b08,   // lb.nn.un_220 qu.so.tlh_444  la.so.un_540 es.ca.tlh_443 
  0x40002c07, 0x69495a0e, 0x211c300c, 0x182812ad,   // fy.lb.un_420 sm.to.mfe_555  uz.id.jw_543 ur.sd.ar_643 
  0x353447a0, 0x06461504, 0x3e064004, 0x423605ee,   // sn.xh.zu_322 un.qu.de_332  lb.de.rm_332 fr.gn.co_422 
  // [f3c0]
  0x36006405, 0x17232507, 0x18343d5a, 0x3600730d,   // lg.gn.un_330 mn.ky.sr_432  ku.ps.ar_553 ny.gn.un_540 
  0x480725a4, 0x11153c13, 0x3f03600d, 0x73452807,   // mn.bg.tt_433 ug.ro.un_650  vo.nl.af_554 sw.ln.ny_432 
  0x6b651508, 0x60033f0e, 0x632705a9, 0x120a26ad,   // un.gv.ceb_443 af.nl.vo_555  fr.gd.sco_544 ia.pt.hu_643 
  0x47001f05, 0x13062055, 0x10230504, 0x0a251704,   // cy.sn.un_330 sq.de.et_442  fr.ca.lt_332 sr.mn.mk_332 
  // [f3d0]
  0x10223ea0, 0x796501ad, 0x5b603ea4, 0x23001505,   // rm.oc.lt_322 en.gv.war_643  rm.vo.sg_433 un.ky.un_330 
  0x20231304, 0x3e0c0e08, 0x0523430d, 0x18122813,   // et.ca.sq_332 is.sv.rm_443  ie.ca.fr_554 sd.ur.ar_665 
  0x0f2935a4, 0x0e0429ee, 0x2b002302, 0x56641204,   // zu.sl.lv_433 sl.fi.is_422  ca.vi.un_220 hu.lg.mg_332 
  0x063451ad, 0x37003508, 0x19430b07, 0x2a002002,   // kl.xh.de_643 tg.ba.un_430  es.ie.gl_432 sq.mt.un_220 
  // [f3e0]
  0x25005e05, 0x040a3005, 0x231d0107, 0x12530907,   // ts.eu.un_330 uz.mk.ru_333  en.la.ca_432 pl.ht.hu_432 
  0x5c091c60, 0x04371507, 0x0b000a1e, 0x47290f07,   // mr.hi.sa_664 un.ba.ru_432  pt.es.un_830 lv.sl.sn_432 
  0x202f0f07, 0x25006e04, 0x2f0429a0, 0x081025ee,   // lv.su.sq_432 hmn.eu.un_320  sl.fi.su_322 mn.be.uk_422 
  0x095c0dec, 0x4a005a02, 0x0502010c, 0x65000a04,   // ne.sa.hi_644 sm.yo.un_220  en.da.fr_543 pt.gv.un_320 
  // [f3f0]
  0x1000170d, 0x124a4507, 0x171504a7, 0x6b1d0208,   // sr.be.un_540 ln.yo.hu_432  ru.sr.un_520 da.la.ceb_443 
  0x6b00792b, 0x074815a6, 0x6424495a, 0x24003004,   // war.ceb.un_980 un.tt.bg_521  to.eo.lg_553 uz.eo.un_320 
  0x56495a12, 0x332e51a0, 0x18001b0e, 0x40277909,   // sm.to.mg_654 kl.fo.nn_322  tr.ga.un_550 war.gd.lb_444 
  0x0b0523a4, 0x3b0227a4, 0x0a432612, 0x3b001902,   // ca.fr.es_433 gd.da.so_433  ia.ie.pt_654 gl.so.un_220 
  
  // [f400]
  0x300715a4, 0x30005605, 0x251937ee, 0x5a3704a4,   // un.bg.uz_433 mg.uz.un_330  st.gl.eu_422 fi.st.sm_433 
  0x49005a2a, 0x38204812, 0x246b1dad, 0x2cfc25a7,   // sm.to.un_970 tt.sq.tk_654  la.ceb.eo_643 eu.zzp.fy_532 
  0x25651504, 0x2c001507, 0x1f004722, 0x49565a11,   // un.gv.eu_332 un.fy.un_420  sn.cy.un_870 sm.mg.to_653 
  0x04070855, 0x06381b08, 0x3f031307, 0x10000a0c,   // uk.bg.ru_442 tr.tk.de_443  et.nl.af_432 mk.be.un_530 
  // [f410]
  0x3f400307, 0x15651307, 0x083f0305, 0x041044a9,   // nl.lb.af_432 et.gv.un_432  nl.af.no_333 kk.be.ru_544 
  0x76004713, 0x253730a4, 0x372a2207, 0x5d123704,   // sn.crs.un_650 uz.ba.mn_433  oc.mt.st_432 st.hu.ss_332 
  0x262e030c, 0xfc00501b, 0x032e3f05, 0x21303b0b,   // nl.fo.ia_543 fj.zzp.un_770  af.fo.nl_333 ks.uz.fa_542 
  0x37002209, 0x20231f0d, 0x2304fcee, 0xfc000d08,   // oc.st.un_440 cy.ca.sq_554  zzp.fi.ca_422 cs.zzp.un_430 
  // [f420]
  0x22230b08, 0x531163ee, 0x164029ee, 0x37481104,   // es.ca.oc_443 sco.ro.ht_422  sl.lb.hr_422 ro.tt.ba_332 
  0x606563ad, 0x2022290c, 0x301035a0, 0x28001211,   // sco.gv.vo_643 sl.oc.sq_543  tg.be.uz_322 ur.sd.un_630 
  0x20003f02, 0x0a300704, 0x0d002a0c, 0x2073fcad,   // af.sq.un_220 bg.uz.mk_332  mt.cs.un_530 zzp.ny.sq_643 
  0x102338a7, 0x07111504, 0x153515a4, 0x250a1711,   // tk.ky.be_532 un.ro.bg_332  un.tg.un_433 sr.mk.mn_653 
  // [f430]
  0x08001518, 0x39793eee, 0x30073c12, 0x0a1036a4,   // un.uk.un_740 rm.war.br_422  ug.bg.uz_654 ab.be.mk_433 
  0x122328a0, 0x44350709, 0x37483008, 0x033f0fa7,   // sd.ky.ur_322 bg.tg.kk_444  uz.tt.ba_443 lv.af.nl_532 
  0x21003304, 0x4b6465a7, 0x102511a7, 0x3d003c1b,   // nn.jw.un_320 gv.lg.mi_532  ro.mn.be_532 ug.ku.un_770 
  0x4b006a09, 0x03080204, 0x2305080c, 0x2f63190c,   // haw.mi.un_440 da.no.nl_332  no.fr.ca_543 gl.sco.su_543 
  // [f440]
  0x464505a4, 0x0302feee, 0x790163ee, 0x190a22af,   // fr.ln.qu_433 tlh.da.nl_422  sco.en.war_422 oc.pt.gl_655 
  0x0b0163a0, 0x22430107, 0x1025150c, 0x26050ba4,   // sco.en.es_322 en.ie.oc_432  un.mn.be_543 es.fr.ia_433 
  0x052201a4, 0x220501a9, 0x0a171012, 0x3f032708,   // en.oc.fr_433 en.fr.oc_544  be.sr.mk_654 gd.nl.af_443 
  0x123018a4, 0x0c792404, 0x36081505, 0x0c00fe02,   // ar.uz.ur_433 eo.war.sv_332  un.uk.ab_333 tlh.sv.un_220 
  // [f450]
  0x13630107, 0x3f031f13, 0x22100504, 0x02650308,   // en.sco.et_432 cy.nl.af_665  fr.lt.oc_332 nl.gv.da_443 
  0x30003904, 0x637910a0, 0x37005f22, 0x054f0107,   // br.uz.un_320 lt.war.sco_322  tn.st.un_870 en.bi.fr_432 
  0x1f3369a4, 0x3e2e1f08, 0x254415a0, 0x37443005,   // mfe.nn.cy_433 cy.fo.rm_443  un.kk.mn_322 uz.kk.ba_333 
  0x050938ee, 0x170a3004, 0x2246570c, 0x392b27a7,   // tk.pl.fr_422 uz.mk.sr_332  na.qu.oc_543 gd.vi.br_532 
  // [f460]
  0x12002e1b, 0x01002f04, 0x256901a0, 0x1c1f1ea4,   // fo.hu.un_770 su.en.un_320  en.mfe.eu_322 ms.cy.id_433 
  0x48443808, 0x0b000204, 0x0a190b55, 0x3f00fc21,   // tk.kk.tt_443 da.es.un_320  es.gl.pt_442 zzp.af.un_860 
  0x15303814, 0x083023a0, 0x173c08a9, 0x7900430d,   // tk.uz.un_666 ky.uz.uk_322  uk.ug.sr_544 ie.war.un_540 
  0x30000719, 0x17080405, 0xfc250b13, 0x44302302,   // bg.uz.un_750 ru.uk.sr_333  es.eu.zzp_665 ky.uz.kk_222 
  // [f470]
  0x19004805, 0x1f103e04, 0x1827fc0c, 0x262406a9,   // tt.gl.un_330 rm.lt.cy_332  zzp.gd.ga_543 de.eo.ia_544 
  0x4d000804, 0x42004c05, 0x20003012, 0x37073e07,   // no.aa.un_320 wo.co.un_330  uz.sq.un_640 rm.it.st_432 
  0x271d18a4, 0x582508a0, 0x27185604, 0x212856a0,   // ga.la.gd_433 no.eu.om_322  mg.ga.gd_332 mg.sw.jw_322 
  0x65003705, 0x564739a9, 0x38103107, 0x4415230c,   // st.gv.un_330 br.sn.mg_544  az.lt.tk_432 ky.kk.un_530 
  // [f480]
  0x6579045a, 0x52002b08, 0x4f3e58a4, 0x2b004a04,   // fi.war.gv_553 vi.ha.un_430  om.rm.bi_433 yo.vi.un_320 
  0x0c020404, 0x15042312, 0x04171004, 0x214423af,   // fi.da.sv_332 ky.ru.un_654  be.sr.ru_332 ky.kk.fa_655 
  0x53005002, 0x080717a9, 0x1535040c, 0x0d093b0e,   // fj.ht.un_220 sr.bg.uk_544  ru.tg.un_543 ks.hi.ne_555 
  0x652c030c, 0x033ffaaf, 0x562c0304, 0x212c3fa0,   // nl.fy.gv_543 nr.af.nl_655  nl.fy.mg_332 af.fy.jw_322 
  // [f490]
  0x791f03a7, 0x07150455, 0x0800350d, 0x40563704,   // nl.cy.war_532 ru.bg.un_420  tg.uk.un_540 st.mg.lb_332 
  0x3f2f03ee, 0x062c0304, 0x06004307, 0x48040a07,   // nl.su.af_422 nl.fy.de_332  ie.de.un_420 mk.ru.tt_432 
  0x2c033fad, 0x3f5a0314, 0x65011504, 0x37484408,   // af.nl.fy_643 nl.sm.af_666  un.en.gv_332 kk.tt.ba_443 
  0x27112eee, 0xfc004004, 0x2e000602, 0x0e0643a0,   // fo.ro.gd_422 lb.zzp.un_320  de.fo.un_220 ie.de.is_322 
  // [f4a0]
  0x373548a6, 0x3800352a, 0x78346408, 0x78006414,   // tt.tg.ba_521 tg.tk.un_970  lg.xh.ve_443 lg.ve.un_660 
  0x345d6412, 0x15fe02a4, 0x171104ee, 0x060102a7,   // lg.ss.xh_654 da.tlh.un_433  fi.ro.sr_422 da.en.de_532 
  0x072479a4, 0x0200550e, 0x29245e0b, 0x360b0a08,   // war.eo.it_433 rw.da.un_550  ts.eo.sl_542 pt.es.gn_443 
  0x523424a9, 0x24002f0d, 0x56302f55, 0x07371155,   // eo.xh.ha_544 su.eo.un_540  su.uz.mg_442 ro.ba.bg_442 
  // [f4b0]
  0x37174805, 0x4e252408, 0x79000a04, 0x09005104,   // tt.sr.ba_333 eo.eu.ay_443  pt.war.un_320 kl.pl.un_320 
  0x5a005c02, 0x04004811, 0x36111708, 0x32432407,   // sa.sm.un_220 tt.fi.un_630  sr.ro.ab_443 eo.ie.bs_432 
  0x19005e0c, 0x5e3f73a7, 0x24291004, 0x212f1c02,   // ts.gl.un_530 ny.af.ts_532  lt.sl.eo_332 id.su.jw_222 
  0x5f457308, 0x06634007, 0x562c6a04, 0x25005a0d,   // ny.ln.tn_443 lb.sco.de_432  haw.fy.mg_332 sm.eu.un_540 
  // [f4c0]
  0x081507a4, 0x100736a0, 0x48491307, 0x35374407,   // bg.uk.un_430 ab.bg.be_322  et.to.tt_432 kk.ba.tg_432 
  0x48000502, 0x04300808, 0x1349500c, 0x5a002c04,   // fr.tt.un_220 uk.uz.ru_443  fj.to.et_543 fy.sm.un_320 
  0x652c25a4, 0x0e000504, 0x33080ca6, 0x305864a0,   // eu.fy.gv_433 fr.is.un_320  sv.no.nn_521 lg.om.uz_322 
  0x205dfaee, 0x4d06405a, 0x3011365a, 0x481330a0,   // nr.ss.sq_422 lb.de.aa_553  ab.ro.uz_553 uz.et.tt_322 
  // [f4d0]
  0x3715540c, 0x64005104, 0x37205da7, 0x58005212,   // ik.st.un_530 kl.lg.un_320  ss.sq.st_532 ha.om.un_640 
  0x50005a04, 0x042d0d08, 0x643e54af, 0x3534370e,   // sm.fj.un_320 cs.sk.fi_443  ik.rm.lg_655 st.xh.zu_555 
  0x0e000212, 0x05190b55, 0x2a372060, 0x12003502,   // da.is.un_640 es.gl.fr_442  sq.st.mt_664 zu.hu.un_220 
  0x30481da0, 0x30005807, 0x381b30a0, 0xfe003508,   // la.tt.uz_322 om.uz.un_420  uz.tr.tk_322 zu.tlh.un_430 
  // [f4e0]
  0x300a07a4, 0x12005d0d, 0x070a17ac, 0x23483708,   // bg.mk.uz_433 ss.hu.un_540  sr.mk.bg_632 ba.tt.ky_443 
  0x2efe200e, 0x21003f04, 0x375d2013, 0x3537380c,   // sq.tlh.fo_555 af.jw.un_320  sq.ss.st_665 tk.ba.tg_543 
  0x29002019, 0x3523faa4, 0x2000230b, 0x09020da4,   // sq.sl.un_750 nr.ca.zu_433  ca.sq.un_520 cs.da.pl_433 
  0x104837a4, 0x153c44af, 0x17083c14, 0x18213405,   // ba.tt.be_433 kk.ug.un_655  ug.uk.sr_666 ps.fa.ar_333 
  // [f4f0]
  0x0a171555, 0x190b26a4, 0x040a075a, 0x3905790d,   // un.sr.mk_442 ia.es.gl_433  bg.mk.ru_553 war.fr.br_554 
  0x352330ec, 0x353457ee, 0x52354704, 0x5f003712,   // uz.ky.tg_644 na.xh.zu_422  sn.zu.ha_332 st.tn.un_640 
  0x55005008, 0x190b2455, 0x1a000108, 0x17381055,   // fj.rw.un_430 eo.es.gl_442  en.tl.un_430 be.tk.sr_442 
  0x38444807, 0x232530a0, 0x475a4907, 0x44001021,   // tt.kk.tk_432 uz.mn.ky_322  to.sm.sn_432 be.kk.un_860 
  // [f500]
  0x153525a9, 0x12180bec, 0x2e0e4aac, 0x19004a11,   // mn.tg.un_544 es.ga.hu_644  yo.is.fo_632 yo.gl.un_630 
  0x652811a4, 0x18000a13, 0x252c110d, 0x342e0e04,   // ro.sw.gv_433 pt.ga.un_650  ro.fy.eu_554 is.fo.xh_332 
  0x495a2eee, 0x252651ad, 0x06004904, 0x180e2eaf,   // fo.sm.to_422 kl.ia.eu_643  to.de.un_320 fo.is.ga_655 
  0x23356055, 0x0100242a, 0x223323a7, 0x3f062cad,   // vo.zu.ca_442 yi.iw.un_970  ca.nn.oc_532 fy.de.af_643 
  // [f510]
  0x47001d04, 0xfe100f04, 0x260b430e, 0x3905080c,   // la.sn.un_320 lv.lt.tlh_332  ie.es.ia_555 no.fr.br_543 
  0x3017350c, 0x0f0605a7, 0xfc344008, 0x4000fe19,   // tg.sr.uz_543 fr.de.lv_532  lb.xh.zzp_443 tlh.lb.un_750 
  0x42000705, 0x33080fee, 0x0425110c, 0x25001122,   // it.co.un_330 lv.no.nn_422  ro.eu.fi_543 ro.eu.un_870 
  0x632d0d07, 0x0f190ba6, 0x130208a4, 0x281125a7,   // cs.sk.sco_432 es.gl.lv_521  no.da.et_433 eu.ro.sw_532 
  // [f520]
  0x1100250d, 0x43050807, 0x0c004205, 0x24002e07,   // eu.ro.un_540 no.fr.ie_432  co.sv.un_330 fo.eo.un_420 
  0x79432304, 0x041037a4, 0x5800fe12, 0x3e3f030c,   // ca.ie.war_332 ba.be.ru_433  tlh.om.un_640 nl.af.rm_543 
  0x32002204, 0x4a003012, 0x1c121aa6, 0x15001802,   // oc.bs.un_320 uz.yo.un_640  tl.hu.id_521 ga.un.un_220 
  0x02510204, 0x4a00090d, 0x4ffe08a0, 0x734a67ee,   // da.kl.da_332 pl.yo.un_540  no.tlh.bi_322 ak.yo.ny_422 
  // [f530]
  0x4b006b04, 0x0f004f22, 0x3600430c, 0x15000518,   // ceb.mi.un_320 bi.lv.un_870  ie.gn.un_530 fr.un.un_740 
  0x4f1f1e07, 0x0f00fe13, 0x2c3011a0, 0x11002b12,   // ms.cy.bi_432 tlh.lv.un_650  ro.uz.fy_322 vi.ro.un_640 
  0x300333ee, 0x1e003302, 0x29003908, 0x253715ee,   // nn.nl.uz_422 nn.ms.un_220  br.sl.un_430 un.ba.mn_422 
  0x471220ee, 0x080212a0, 0x10154405, 0x3c170813,   // sq.hu.sn_422 hu.da.no_322  kk.be.un_330 uk.sr.ug_665 
  // [f540]
  0x44253709, 0x12003f02, 0x08023f02, 0x34233d0e,   // ba.mn.kk_444 af.hu.un_220  af.da.no_222 ku.ky.ps_555 
  0x120f3e60, 0x443735ee, 0x18464007, 0x18001f0d,   // rm.lv.hu_664 tg.ba.kk_422  lb.qu.ga_432 cy.ga.un_540 
  0x2c0640a4, 0x06186507, 0x47016bee, 0x27005821,   // lb.de.fy_433 gv.ga.de_432  ceb.en.sn_422 om.gd.un_860 
  0x443811ad, 0x3c3037ec, 0x17003605, 0x4823110c,   // ro.tk.kk_643 ba.uz.ug_644  ab.sr.un_330 ro.ky.tt_543 
  // [f550]
  0x0f361012, 0x5a10520c, 0x283d12ad, 0x0f007307,   // lt.gn.lv_654 ha.lt.sm_543  ur.ku.sd_643 ny.lv.un_420 
  0x64341da0, 0x05040f0c, 0x67002814, 0x402c03a7,   // la.xh.lg_322 lv.fi.fr_543  sw.ak.un_660 nl.fy.lb_532 
  0x07004307, 0x056342a0, 0x3f000f23, 0x42005a12,   // ie.it.un_420 co.sco.fr_322  lv.af.un_880 sm.co.un_640 
  0x4a005013, 0x4363010c, 0x35040807, 0x013f23a4,   // fj.yo.un_650 en.sco.ie_543  uk.ru.tg_432 ca.af.en_433 
  // [f560]
  0x2223010c, 0x46101109, 0x42321604, 0x311b4507,   // en.ca.oc_543 ro.lt.qu_444  hr.bs.co_332 ln.tr.az_432 
  0x090f4211, 0x030640ad, 0x360143a0, 0x3f061f08,   // co.lv.pl_653 lb.de.nl_643  ie.en.gn_322 cy.de.af_443 
  0x030f0111, 0x2300010d, 0x0f003f23, 0x3f430107,   // en.lv.nl_653 en.ca.un_540  af.lv.un_880 en.ie.af_432 
  0x08100404, 0x3d184404, 0x08361007, 0x73642fa4,   // ru.be.uk_332 kk.ar.ku_332  be.ab.uk_432 su.lg.ny_433 
  // [f570]
  0x2f644cee, 0x040810ee, 0x64214c08, 0x5d64350c,   // wo.lg.su_422 be.uk.ru_422  wo.jw.lg_443 zu.lg.ss_543 
  0x2f001f05, 0x31003022, 0x4b6a4f0c, 0x4b002802,   // cy.su.un_330 uz.az.un_870  bi.haw.mi_543 sw.mi.un_220 
  0x21004c04, 0x02000922, 0x374b5a0d, 0x352f21a0,   // wo.jw.un_320 pl.da.un_870  sm.mi.st_554 jw.su.zu_322 
  0x0242470c, 0x64212fa4, 0x37004907, 0xfe47730c,   // sn.co.da_543 su.jw.lg_433  to.st.un_420 ny.sn.tlh_543 
  // [f580]
  0x5c1915a9, 0x2f684ca9, 0x030236a9, 0x01000607,   // un.gl.sa_544 wo.ig.su_544  gn.da.nl_544 de.en.un_420 
  0x42002c14, 0x0f003b0e, 0x271ffe0e, 0x0b001502,   // fy.co.un_660 so.lv.un_550  tlh.cy.gd_555 un.es.un_220 
  0x186327ad, 0x0b23fc07, 0x1f0602a0, 0x2c00062c,   // gd.sco.ga_643 zzp.ca.es_432  da.de.cy_322 de.fy.un_990 
  0x03fc47a4, 0x183d300b, 0x4437230d, 0x460b02a0,   // sn.zzp.nl_433 uz.ku.ar_542  ky.ba.kk_554 da.es.qu_322 
  // [f590]
  0x2cfe0611, 0x49000507, 0x05221f02, 0x53001f13,   // de.tlh.fy_653 fr.to.un_420  cy.oc.fr_222 cy.ht.un_650 
  0x041017a0, 0x73000308, 0x07154204, 0x022868af,   // sr.be.ru_322 nl.ny.un_430  co.it.un_320 ig.sw.da_655 
  0x5a4b4fec, 0x07033e08, 0x400673a4, 0x2c000402,   // bi.mi.sm_644 rm.nl.it_443  ny.de.lb_433 fi.fy.un_220 
  0x092c3ea4, 0x5a004f0e, 0x5363220c, 0x4553fe04,   // rm.fy.pl_433 bi.sm.un_550  oc.sco.ht_543 tlh.ht.ln_332 
  // [f5a0]
  0x3000fe12, 0x5846fe12, 0x35384408, 0x2c002104,   // tlh.uz.un_640 tlh.qu.om_654  kk.tk.tg_443 jw.fy.un_320 
  0x04234407, 0x1d286505, 0x1d37630c, 0x35374455,   // kk.ky.ru_432 gv.sw.la_333  sco.st.la_543 kk.ba.tg_442 
  0x44233702, 0x1705fca4, 0x02474fa0, 0x44080aa0,   // ba.ky.kk_222 zzp.fr.sr_433  bi.sn.da_322 mk.uk.kk_322 
  0x2c004008, 0x2b00370c, 0x5f006308, 0x2b1c40a0,   // lb.fy.un_430 st.vi.un_530  sco.tn.un_430 lb.id.vi_322 
  // [f5b0]
  0x04392ca0, 0x46653707, 0x10173007, 0x08171004,   // fy.br.fi_322 st.gv.qu_432  uz.sr.be_432 be.sr.uk_332 
  0x04170808, 0x332c2ea0, 0x5f006312, 0x2f211f0c,   // uk.sr.ru_443 fo.fy.nn_322  sco.tn.un_640 cy.jw.su_543 
  0x33002e07, 0x1e00fe04, 0x330c2ca0, 0x2c303e09,   // fo.nn.un_420 tlh.ms.un_320  fy.sv.nn_322 rm.uz.fy_444 
  0x36001311, 0x32005302, 0x4000630c, 0x201605a0,   // et.gn.un_630 ht.bs.un_220  sco.lb.un_530 fr.hr.sq_322 
  // [f5c0]
  0x383e1ba0, 0x154844a9, 0x37302302, 0x234437a7,   // tr.rm.tk_322 kk.tt.un_544  ky.uz.ba_222 ba.kk.ky_532 
  0x2e3e0e0e, 0x40002c08, 0x3e002307, 0x24330802,   // is.rm.fo_555 fy.lb.un_430  ca.rm.un_420 no.nn.eo_222 
  0x010615a4, 0x2c062e05, 0x2c023f07, 0x06332ea0,   // un.de.en_433 fo.de.fy_333  af.da.fy_432 fo.nn.de_322 
  0x54002a0e, 0x480430a0, 0x5c131c09, 0x0400651b,   // mt.ik.un_550 uz.ru.tt_322  mr.bh.sa_444 gv.fi.un_770 
  // [f5d0]
  0x1f1065a9, 0x154265a0, 0x23106513, 0x10006514,   // gv.lt.cy_544 gv.co.un_322  gv.lt.ca_665 gv.lt.un_660 
  0x48303ca7, 0x1000650d, 0x100265af, 0x1f1065a7,   // ug.uz.tt_532 gv.lt.un_540  gv.da.lt_655 gv.lt.cy_532 
  0x5c0d1cee, 0x10060207, 0x3830150c, 0x214418a7,   // mr.ne.sa_422 da.de.lt_432  un.uz.tk_543 ar.kk.fa_532 
  0x2c0910a7, 0x38000412, 0x2c00100d, 0x10046513,   // lt.pl.fy_532 fi.tk.un_640  lt.fy.un_540 gv.fi.lt_665 
  // [f5e0]
  0x3810650d, 0x151d1055, 0x4436110c, 0x5a000907,   // gv.lt.tk_554 lt.la.un_442  ro.ab.kk_543 pl.sm.un_420 
  0x53001504, 0x53006b07, 0x18302160, 0x131517ad,   // un.ht.un_320 ceb.ht.un_420  fa.uz.ar_664 sr.bh.un_630 
  0x170430ee, 0x42000709, 0x301704ee, 0x3c232805,   // uz.ru.sr_422 it.co.un_440  ru.sr.uz_422 sd.ky.ug_333 
  0x3000341a, 0x153748a9, 0x35042505, 0x170f1007,   // ps.uz.un_760 tt.ba.un_544  mn.ru.tg_333 lt.lv.sr_432 
  // [f5f0]
  0x0f000909, 0x372523af, 0x233830a9, 0x25002c0d,   // pl.lv.un_440 ky.mn.ba_655  uz.tk.ky_544 fy.eu.un_540 
  0x12000911, 0x2c09040c, 0x25006502, 0x49256a04,   // pl.hu.un_630 fi.pl.fy_543  gv.eu.un_220 haw.eu.to_332 
  0x37483c55, 0x34001809, 0x22000a20, 0x3615440d,   // ug.tt.ba_442 ar.ps.un_440  pt.oc.un_850 kk.ab.un_540 
  0x174435a4, 0x2500040b, 0x582021af, 0x04001218,   // tg.kk.sr_433 fi.eu.un_520  jw.sq.om_655 hu.fi.un_740 
  // [f600]
  0x1c2c25ee, 0x23350a02, 0x25392cac, 0xfe001f07,   // eu.fy.id_422 mk.tg.ky_222  fy.br.eu_632 cy.tlh.un_420 
  0x211812ec, 0x37004008, 0x2118300b, 0x206301af,   // ur.ar.fa_644 lb.st.un_430  uz.ar.fa_542 en.sco.sq_655 
  0x3428470c, 0x071515a0, 0x35004412, 0x52532455,   // sn.sw.xh_543 un.bg.un_320  kk.tg.un_640 eo.ht.ha_442 
  0x31001709, 0x2a001b02, 0x7669530e, 0x522a1fee,   // sr.az.un_440 tr.mt.un_220  ht.mfe.crs_555 cy.mt.ha_422 
  // [f610]
  0x4835300c, 0x64005305, 0x3f00fc04, 0x04443708,   // uz.tg.tt_543 ht.lg.un_330  zzp.af.un_320 ba.kk.ru_443 
  0x1f09fc04, 0x535828ac, 0x0a153ca7, 0x565a49af,   // zzp.pl.cy_332 sw.om.ht_632  ug.mk.un_520 to.sm.mg_655 
  0x75003719, 0x213d12a9, 0x06631807, 0x0d003613,   // st.nso.un_750 ur.ku.fa_544  ga.sco.de_432 gn.cs.un_650 
  0x302d0d04, 0x1e1c3fa6, 0x02000a18, 0x4b6a205a,   // cs.sk.uz_332 af.id.ms_521  pt.da.un_740 sq.haw.mi_553 
  // [f620]
  0x206a4ba4, 0x06002c07, 0x0700421a, 0x422718a0,   // mi.haw.sq_433 fy.de.un_420  co.it.un_760 ga.gd.co_322 
  0x6b6560ee, 0x1f0c06a0, 0x4b006a0b, 0x17003014,   // vo.gv.ceb_422 de.sv.cy_322  haw.mi.un_520 uz.sr.un_660 
  0x2500440c, 0x183c230c, 0x7300200c, 0x4a6834a9,   // kk.mn.un_530 ky.ug.ar_543  sq.ny.un_530 xh.ig.yo_544 
  0x23353008, 0x44362311, 0x08001c04, 0x27002308,   // uz.tg.ky_443 ky.ab.kk_653  id.no.un_320 ca.gd.un_430 
  // [f630]
  0x2300530b, 0x07040a08, 0x1f001802, 0x2c000c02,   // ht.ca.un_520 mk.ru.bg_443  ga.cy.un_220 sv.fy.un_220 
  0x08100455, 0x13000a04, 0x13000a17, 0x79005035,   // ru.be.uk_442 pt.et.un_320  pt.et.un_730 fj.war.un_A90 
  0x0a5767ad, 0x04006013, 0x121013a0, 0x114b21ec,   // ak.na.pt_643 vo.fi.un_650  et.lt.hu_322 jw.mi.ro_644 
  0x08021ba4, 0x6e1d0fa4, 0x13080204, 0x5900561a,   // tr.da.no_433 lv.la.hmn_433  da.no.et_332 mg.rn.un_760 
  // [f640]
  0x1c002c07, 0x67000c0d, 0x21205512, 0x503f3908,   // fy.id.un_420 sv.ak.un_540  rw.sq.jw_654 br.af.fj_443 
  0x506401a0, 0x36022507, 0x200965ad, 0x2300150d,   // en.lg.fj_322 eu.da.gn_432  gv.pl.sq_643 un.ky.un_540 
  0xfc4b4f55, 0x39073602, 0x33000818, 0x353467a4,   // bi.mi.zzp_442 gn.it.br_222  no.nn.un_740 ak.xh.zu_433 
  0x530545a0, 0x555f58a7, 0x11081013, 0x43002621,   // ln.fr.ht_322 om.tn.rw_532  be.uk.ro_665 ia.ie.un_860 
  // [f650]
  0x5c200a11, 0x5e4006ad, 0x1800120b, 0x18004705,   // pt.sq.sa_653 de.lb.ts_643  hu.ga.un_520 sn.ga.un_330 
  0x06201f04, 0x442515a0, 0x47551da0, 0x0717110c,   // cy.sq.de_332 un.mn.kk_322  la.rw.sn_322 ro.sr.bg_543 
  0x2c033fec, 0x075f75a9, 0x2c460614, 0x0224070c,   // af.nl.fy_644 nso.tn.it_544  de.qu.fy_666 it.eo.da_543 
  0x277358a9, 0x5c3437ec, 0x4006680c, 0x0d565c08,   // om.ny.gd_544 st.xh.sa_644  ig.de.lb_543 sa.mg.cs_443 
  // [f660]
  0x02464e0d, 0x28580d07, 0x076759ad, 0x5c750709,   // ay.qu.da_554 cs.om.sw_432  rn.ak.it_643 it.nso.sa_444 
  0x213f2f02, 0x5e3607ac, 0x18362704, 0x02735808,   // su.af.jw_222 it.gn.ts_632  gd.gn.ga_332 om.ny.da_443 
  0x1958420d, 0x28002f13, 0x075602a9, 0x64025caf,   // co.om.gl_554 su.sw.un_650  da.mg.it_544 sa.da.lg_655 
  0x12730308, 0x5c000722, 0x1100080e, 0x52595e0c,   // nl.ny.hu_443 it.sa.un_870  uk.ro.un_550 ts.rn.ha_543 
  // [f670]
  0x240701a4, 0x46030608, 0x07424ea9, 0x5945020c,   // en.it.eo_433 de.nl.qu_443  ay.co.it_544 da.ln.rn_543 
  0x56112f04, 0x46060312, 0x584e4608, 0x6b1d3e0c,   // su.ro.mg_332 nl.de.qu_654  qu.ay.om_443 rm.la.ceb_543 
  0x2f002814, 0x474a1502, 0x05395307, 0x07440aa0,   // sw.su.un_660 un.yo.sn_222  ht.br.fr_432 mk.kk.bg_322 
  0x183c4408, 0x231504a4, 0x0c3b48a0, 0x582d0d55,   // kk.ug.ar_443 ru.ky.un_430  tt.so.sv_322 cs.sk.om_442 
  // [f680]
  0x23250813, 0x5800fe0d, 0x3e002502, 0x04393008,   // uk.mn.ky_665 tlh.om.un_540  eu.rm.un_220 uz.br.fi_443 
  0x2c002505, 0x0e6301a0, 0x1515360e, 0x1748110d,   // eu.fy.un_330 en.sco.is_322  ab.un.un_550 ro.tt.sr_554 
  0x262533a0, 0x3f2c130b, 0x0800120c, 0x25390605,   // nn.eu.ia_322 et.fy.af_542  hu.no.un_530 de.br.eu_333 
  0x2334180c, 0x25060fad, 0x48443c0c, 0x2b003907,   // ar.ps.ky_543 lv.de.eu_643  ug.kk.tt_543 br.vi.un_420 
  // [f690]
  0x27606512, 0x0e06130c, 0x24750407, 0x2b40fea0,   // gv.vo.gd_654 et.de.is_543  fi.nso.eo_432 tlh.lb.vi_322 
  0x100e0f08, 0x4030530c, 0x40066013, 0x1dfe270c,   // lv.is.lt_443 ht.uz.lb_543  vo.de.lb_665 gd.tlh.la_543 
  0x17480aa0, 0x17302507, 0x69fe1f0c, 0x27002b19,   // mk.tt.sr_322 mn.uz.sr_432  cy.tlh.mfe_543 vi.gd.un_750 
  0xfe00400d, 0x632701a9, 0x37001702, 0x061f220c,   // lb.tlh.un_540 en.gd.sco_544  sr.ba.un_220 oc.cy.de_543 
  // [f6a0]
  0x2ffe1c55, 0x0a080705, 0xfe532707, 0x2b005309,   // id.tlh.su_442 bg.uk.mk_333  gd.ht.tlh_432 ht.vi.un_440 
  0x35154407, 0x1a005813, 0x53fe1f13, 0x0b002704,   // kk.tg.un_420 om.tl.un_650  cy.tlh.ht_665 gd.es.un_320 
  0x67005c19, 0x55fc59af, 0x5f516a5a, 0x532e45a7,   // sa.ak.un_750 rn.zzp.rw_655  haw.kl.tn_553 ln.fo.ht_532 
  0x3d122111, 0x62000104, 0x20000904, 0x061f15a0,   // fa.ur.ku_653 en.kha.un_320  pl.sq.un_320 un.cy.de_322 
  // [f6b0]
  0x2a002802, 0x0e1f15a0, 0x0c36fcee, 0x48001305,   // sw.mt.un_220 un.cy.is_322  zzp.gn.sv_422 et.tt.un_330 
  0x4300690d, 0x6b796404, 0xfc0a1111, 0x24511ca0,   // mfe.ie.un_540 lg.war.ceb_332  ro.pt.zzp_653 id.kl.eo_322 
  0x6900121a, 0x68003809, 0x4d044208, 0x3f00291a,   // hu.mfe.un_760 tk.ig.un_440  co.fi.aa_443 sl.af.un_760 
  0x5f003736, 0x6b010708, 0x514207ee, 0x3e002b05,   // st.tn.un_AA0 it.en.ceb_443  it.co.kl_422 vi.rm.un_330 
  // [f6c0]
  0x52005f1b, 0x0100020d, 0x34183c07, 0x3c213b0c,   // tn.ha.un_770 da.en.un_540  ug.ar.ps_432 ks.fa.ug_543 
  0x3021340c, 0x44483ca4, 0x21283b0b, 0x0c20120c,   // ps.fa.uz_543 ug.tt.kk_433  ks.sd.fa_542 hu.sq.sv_543 
  0x48443712, 0x3f063e07, 0x322c20ee, 0x691b7609,   // ba.kk.tt_654 rm.de.af_432  sq.fy.bs_422 crs.tr.mfe_444 
  0x023e06a0, 0x2c2003af, 0x044430ec, 0x32000305,   // de.rm.da_322 nl.sq.fy_655  uz.kk.ru_644 nl.bs.un_330 
  // [f6d0]
  0x392403ee, 0x28123412, 0x20000304, 0x150438ad,   // nl.eo.br_422 ps.ur.sd_654  nl.sq.un_320 tk.ru.un_643 
  0x06005b12, 0x60200312, 0x0600310d, 0xfe00201a,   // sg.de.un_640 nl.sq.vo_654  az.de.un_540 sq.tlh.un_760 
  0x481b0608, 0x69000608, 0x206003af, 0x3e315b13,   // de.tr.tt_443 de.mfe.un_430  nl.vo.sq_655 sg.az.rm_665 
  0xfa345d0c, 0x403e0604, 0x301a600c, 0x381b5b1d,   // ss.xh.nr_543 de.rm.lb_332  vo.tl.uz_543 sg.tr.tk_852 
  // [f6e0]
  0x480e2e6b, 0x23303804, 0x6200fc19, 0x25fe2e08,   // fo.is.tt_872 tk.uz.ky_332  zzp.kha.un_750 fo.tlh.eu_443 
  0x2f004308, 0x502f45a0, 0x48002104, 0x1530350d,   // ie.su.un_430 ln.su.fj_322  jw.tt.un_320 tg.uz.un_554 
  0x1300060d, 0x251f10a7, 0x42054c11, 0x1d5842ee,   // de.et.un_540 lt.cy.eu_532  wo.fr.co_653 co.om.la_422 
  0x10006b0d, 0x4857130c, 0x2d001d04, 0x1d083ea0,   // ceb.lt.un_540 et.na.tt_543  la.sk.un_320 rm.no.la_322 
  // [f6f0]
  0x2f051d04, 0x31400604, 0x514246ee, 0xfe212f12,   // la.fr.su_332 de.lb.az_332  qu.co.kl_422 su.jw.tlh_654 
  0x64006507, 0x53210507, 0x5d5e2f08, 0x1d002514,   // gv.lg.un_420 fr.jw.ht_432  su.ts.ss_443 eu.la.un_660 
  0x31382204, 0x21004a09, 0x01153b04, 0x252035a0,   // oc.tk.az_332 yo.jw.un_440  so.en.un_320 zu.sq.eu_322 
  0x4c3b2ca4, 0x1b481304, 0x2c1f650c, 0x1b001213,   // fy.so.wo_433 et.tt.tr_332  gv.cy.fy_543 hu.tr.un_650 
  // [f700]
  0x49001f0c, 0x07380a0d, 0x401206a6, 0x18003212,   // cy.to.un_530 mk.tk.bg_554  de.hu.lb_521 bs.ar.un_640 
  0xfc484d09, 0x42040708, 0x38005202, 0x153b63a0,   // aa.tt.zzp_444 it.fi.co_443  ha.tk.un_220 sco.so.un_322 
  0x15002b05, 0x3b001505, 0x2b1511ec, 0x6b2052a9,   // vi.un.un_330 un.so.un_330  ro.vi.un_640 ha.sq.ceb_544 
  0x13083312, 0x02621f07, 0x18fe0107, 0x4b005208,   // nn.no.et_654 cy.kha.da_432  en.tlh.ga_432 ha.mi.un_430 
  // [f710]
  0x30fcfead, 0x44373507, 0x1c091312, 0x0a315802,   // tlh.zzp.uz_643 tg.ba.kk_432  bh.hi.mr_654 om.az.pt_222 
  0x5500280d, 0x08072309, 0x5c6330a7, 0x13006019,   // sw.rw.un_540 ky.bg.uk_444  uz.sco.sa_532 vo.et.un_750 
  0x5e003202, 0x20005207, 0x15003004, 0x4a002e05,   // bs.ts.un_220 ha.sq.un_420  uz.un.un_320 fo.yo.un_330 
  0x2d0d02a0, 0x48000a05, 0x37442355, 0x1044370c,   // da.cs.sk_322 pt.tt.un_330  ky.kk.ba_442 ba.kk.be_543 
  // [f720]
  0x1b00130c, 0x10114807, 0x31003818, 0x28184407,   // et.tr.un_530 tt.ro.be_432  tk.az.un_740 kk.ar.sd_432 
  0x1f0163ee, 0x31381b14, 0xfe364a0c, 0x1e1202a0,   // sco.en.cy_422 tr.tk.az_666  yo.gn.tlh_543 da.hu.ms_322 
  0x0f001e07, 0x3d302104, 0x253c3704, 0x0e4a7907,   // ms.lv.un_420 fa.uz.ku_332  ba.ug.mn_332 war.yo.is_432 
  0x15173cec, 0x211e1ca9, 0x1e002707, 0x17440a0c,   // ug.sr.un_644 id.ms.jw_544  gd.ms.un_420 mk.kk.sr_543 
  // [f730]
  0x59556814, 0x050806ee, 0x280147a0, 0x01005004,   // ig.rw.rn_666 de.no.fr_422  sn.en.sw_322 fj.en.un_320 
  0x09595504, 0x0507010d, 0x3615fc0d, 0x1e1802a0,   // rw.rn.pl_332 en.it.fr_554  zzp.gn.un_540 da.ga.ms_322 
  0x5c466aa6, 0x381b31a0, 0x20002a04, 0xfc365113,   // haw.qu.sa_521 az.tr.tk_322  mt.sq.un_320 kl.gn.zzp_665 
  0x3c233013, 0x18342109, 0x38061bee, 0x34213060,   // uz.ky.ug_665 fa.ps.ar_444  tr.de.tk_422 uz.fa.ps_664 
  // [f740]
  0x1b3138ec, 0x0a04150b, 0x3f4840ec, 0x1500352b,   // tk.az.tr_644 un.ru.mk_542  lb.tt.af_644 tg.un.un_980 
  0x407909ad, 0x4000680e, 0x302535a7, 0x390309a7,   // pl.war.lb_643 ig.lb.un_550  tg.mn.uz_532 pl.nl.br_532 
  0x5300230e, 0x0b0a235a, 0x483ffc04, 0x15003719,   // ca.ht.un_550 ca.pt.es_553  zzp.af.tt_332 ba.un.un_750 
  0x09003f0c, 0x40120608, 0x09004004, 0x2322200c,   // af.pl.un_530 de.hu.lb_443  lb.pl.un_320 sq.oc.ca_543 
  // [f750]
  0x381b6007, 0x1d002621, 0x2000230c, 0x48fe200e,   // vo.tr.tk_432 ia.la.un_860  ca.sq.un_530 sq.tlh.tt_555 
  0x02004e08, 0x0315010c, 0x060967a9, 0x482344a6,   // ay.da.un_430 en.nl.un_530  ak.pl.de_544 kk.ky.tt_521 
  0xfe00200d, 0x353748ee, 0x292d2008, 0x08403fec,   // sq.tlh.un_540 tt.ba.tg_422  sq.sk.sl_443 af.lb.no_644 
  0x09003f13, 0x532d0d55, 0x363525a0, 0x322920af,   // af.pl.un_650 cs.sk.ht_442  mn.tg.ab_322 sq.sl.bs_655 
  // [f760]
  0x12004004, 0x2239230c, 0x0c005319, 0x65061507,   // lb.hu.un_320 ca.br.oc_543  ht.sv.un_750 un.de.gv_432 
  0x04301107, 0x17081504, 0x06303f07, 0x2c002504,   // ro.uz.ru_432 un.uk.sr_332  af.uz.de_432 eu.fy.un_320 
  0x12003105, 0xfc383004, 0x0a002018, 0x0c004e0b,   // az.hu.un_330 uz.tk.zzp_332  sq.pt.un_740 ay.sv.un_520 
  0x343d3c04, 0x2900200c, 0x210522a0, 0x29002018,   // ug.ku.ps_332 sq.sl.un_530  oc.fr.jw_322 sq.sl.un_740 
  // [f770]
  0x2c002507, 0x15303807, 0x0c531fa0, 0x13002817,   // eu.fy.un_420 tk.uz.un_432  cy.ht.sv_322 sw.et.un_730 
  0x04422202, 0x231f6ea9, 0x57796b13, 0x47565ea0,   // oc.co.fi_222 hmn.cy.ca_544  ceb.war.na_665 ts.mg.sn_322 
  0x08041105, 0x02694808, 0x69002119, 0x64001f02,   // ro.ru.uk_333 tt.mfe.da_443  jw.mfe.un_750 cy.lg.un_220 
  0x23766911, 0x15384407, 0x08004418, 0x20001b07,   // mfe.crs.ca_653 kk.tk.un_432  kk.uk.un_740 tr.sq.un_420 
  // [f780]
  0x1a6b690d, 0x4f003e1b, 0x13003107, 0x473b2807,   // mfe.ceb.tl_554 rm.bi.un_770  az.et.un_420 sw.so.sn_432 
  0x285d4709, 0x0a1011ec, 0x0920780c, 0x3ffc01a0,   // sn.ss.sw_444 ro.be.mk_644  ve.sq.pl_543 en.zzp.af_322 
  0x043648a0, 0x160710ee, 0x3e1d40af, 0x223e06a0,   // tt.ab.ru_322 lt.it.hr_422  lb.la.rm_655 de.rm.oc_322 
  0x595525ac, 0x361dfc0c, 0x02200a08, 0x31000608,   // eu.rw.rn_632 zzp.la.gn_543  pt.sq.da_443 de.az.un_430 
  // [f790]
  0x06595513, 0x084410ee, 0x304802a9, 0x63fc0d0c,   // rw.rn.de_665 be.kk.uk_422  da.tt.uz_544 cs.zzp.sco_543 
  0x282120a7, 0x2d3435a9, 0x0700670d, 0x17154809,   // sq.jw.sw_532 zu.xh.sk_544  ak.it.un_540 tt.sr.un_440 
  0x026910a4, 0x1200061a, 0x152a1f08, 0x42111e0b,   // lt.mfe.da_433 de.hu.un_760  cy.mt.un_443 ms.ro.co_542 
  0xfc3804a6, 0x11040705, 0x50004212, 0x1d076408,   // fi.tk.zzp_521 bg.ru.ro_333  co.fj.un_640 lg.it.la_443 
  // [f7a0]
  0x02001705, 0x05451f07, 0x3430210e, 0x08301507,   // sr.da.un_330 cy.ln.fr_432  fa.uz.ps_555 un.uz.uk_432 
  0x56002204, 0x37000113, 0x101708a0, 0x401f37ee,   // oc.mg.un_320 en.st.un_650  uk.sr.be_322 st.cy.lb_422 
  0x045c2f12, 0x5d3f290c, 0x1c090405, 0x350e1207,   // su.sa.fi_654 sl.af.ss_543  fi.pl.id_333 hu.is.zu_432 
  0xfc3704ad, 0x0a1504ee, 0x04211c02, 0x5c1c0405,   // fi.st.zzp_643 ru.mk.un_420  id.jw.fi_222 fi.id.sa_333 
  // [f7b0]
  0x25302305, 0x34002008, 0x1c211ea0, 0x0d001207,   // ky.uz.mn_333 sq.xh.un_430  ms.jw.id_322 hu.cs.un_420 
  0x301828a7, 0x3f005d0b, 0x33081205, 0x33081ba0,   // sd.ar.uz_532 ss.af.un_520  hu.no.nn_333 tr.no.nn_322 
  0x221220ee, 0x32000408, 0x37123804, 0x2d1c2fa4,   // sq.hu.oc_422 fi.bs.un_430  tk.hu.st_332 su.id.sk_433 
  0x33005d22, 0x07250a04, 0x2f1304ad, 0x1e3b4607,   // ss.nn.un_870 mk.mn.bg_332  fi.et.su_643 qu.so.ms_432 
  // [f7c0]
  0x3000311a, 0x483c4409, 0x35301507, 0x0d00040d,   // az.uz.un_760 kk.ug.tt_444  un.uz.tg_432 fi.cs.un_540 
  0x33025302, 0x0c2d0d02, 0x00002a37, 0x46002702,   // ht.da.nn_222 cs.sk.sv_222  mt.un.un_B00 gd.qu.un_220 
  0x18000c04, 0x0400250c, 0x48004607, 0x350a3c12,   // sv.ga.un_320 mn.ru.un_530  qu.tt.un_420 ug.mk.tg_654 
  0x0f3f0ca9, 0x020f0807, 0x050f6055, 0x0a0417ee,   // sv.af.lv_544 no.lv.da_432  vo.lv.fr_442 sr.ru.mk_422 
  // [f7d0]
  0x303421af, 0x281834ad, 0x2d0220ec, 0x400c380c,   // fa.ps.uz_655 ps.ar.sd_643  sq.da.sk_644 tk.sv.lb_543 
  0x0e2e4560, 0x0c003f0e, 0x221d23ee, 0x48382314,   // ln.fo.is_664 af.sv.un_550  ca.la.oc_422 ky.tk.tt_666 
  0xfe000212, 0x18233007, 0x23443708, 0x1d050f07,   // da.tlh.un_640 uz.ky.ar_432  ba.kk.ky_443 lv.fr.la_432 
  0x2325350b, 0x17073cec, 0x353004ec, 0x1b00312b,   // tg.mn.ky_542 ug.bg.sr_644  ru.uz.tg_644 az.tr.un_980 
  // [f7e0]
  0x0817070c, 0x44382307, 0x12283b09, 0x332d250c,   // bg.sr.uk_543 ky.tk.kk_432  ks.sd.ur_444 eu.sk.nn_543 
  0x04003e09, 0x37005a04, 0x35fe3711, 0x2c031aa4,   // rm.fi.un_440 sm.st.un_320  st.tlh.zu_653 tl.nl.fy_433 
  0x4a5d0204, 0x422b07ad, 0x1f1a79a4, 0x29000923,   // da.ss.yo_332 it.vi.co_643  war.tl.cy_433 pl.sl.un_880 
  0x23003611, 0x5d003408, 0x570163a0, 0x4400150e,   // ab.ky.un_630 xh.ss.un_430  sco.en.na_322 un.kk.un_550 
  // [f7f0]
  0x272147a0, 0x2b0407a0, 0x08170a08, 0x4423375a,   // sn.jw.gd_322 it.fi.vi_322  mk.sr.uk_443 ba.ky.kk_553 
  0x28007312, 0x18343bad, 0x4b00670d, 0x653b4013,   // ny.sw.un_640 ks.ps.ar_643  ak.mi.un_540 lb.so.gv_665 
  0x28005212, 0x4e007314, 0x01007307, 0x043b65a4,   // ha.sw.un_640 ny.ay.un_660  ny.en.un_420 gv.so.fi_433 
  0x403f0314, 0x3d183407, 0x0f006522, 0x35070a11,   // nl.af.lb_666 ps.ar.ku_432  gv.lv.un_870 mk.bg.tg_653 
  
  // [f800]
  0x643f3b0c, 0x3b19580c, 0x1d3f4c08, 0x3f580308,   // so.af.lg_543 om.gl.so_543  wo.af.la_443 nl.om.af_443 
  0x3f3b58a9, 0x64033408, 0x4e00361a, 0x653b4c12,   // om.so.af_544 xh.nl.lg_443  gn.ay.un_760 wo.so.gv_654 
  0x13026708, 0x4c6549ad, 0x136349a4, 0x64404c5a,   // ak.da.et_443 to.gv.wo_643  to.sco.et_433 wo.lb.lg_553 
  0x041358ad, 0x373c4408, 0x23183c0c, 0x19000902,   // om.et.fi_643 kk.ug.ba_443  ug.ar.ky_543 pl.gl.un_220 
  // [f810]
  0x253023ad, 0x043708ec, 0x46002204, 0x302a4604,   // ky.uz.mn_643 uk.ba.ru_644  oc.qu.un_320 qu.mt.uz_332 
  0x230b19a7, 0x2d190b05, 0x09001811, 0x233715a7,   // gl.es.ca_532 es.gl.sk_333  ga.pl.un_630 un.ba.ky_532 
  0x0a040713, 0x25003019, 0x2818230c, 0x2e240c04,   // bg.ru.mk_665 uz.mn.un_750  ky.ar.sd_543 sv.eo.fo_332 
  0x5300230c, 0x5c1c13ad, 0x0c3e0f12, 0x1523010c,   // ca.ht.un_530 bh.mr.sa_643  lv.rm.sv_654 en.ca.un_543 
  // [f820]
  0x0d003b04, 0x39000d04, 0x2c2301a9, 0x3f2f03a0,   // so.cs.un_320 cs.br.un_320  en.ca.fy_544 nl.su.af_322 
  0x01065ca4, 0x5d2d4fa0, 0x0c0f050e, 0x304823ac,   // sa.de.en_433 bi.sk.ss_322  fr.lv.sv_555 ky.tt.uz_632 
  0x03000108, 0x630601a4, 0x153e01ec, 0x5c091c13,   // en.nl.un_430 en.de.sco_433  en.rm.un_644 mr.hi.sa_665 
  0x0c0265ee, 0x63013ea4, 0x0c6001a4, 0x0f3e01a9,   // gv.da.sv_422 rm.en.sco_433  en.vo.sv_433 en.rm.lv_544 
  // [f830]
  0x374438a0, 0x1d01150c, 0x2000600e, 0x182060ec,   // tk.kk.ba_322 un.en.la_543  vo.sq.un_550 vo.sq.ga_644 
  0x20006013, 0x071715ee, 0x3f00581b, 0x033f4c08,   // vo.sq.un_650 un.sr.bg_422  om.af.un_770 wo.af.nl_443 
  0x3f00200b, 0x3f004c0e, 0x2200530e, 0x23202104,   // sq.af.un_520 wo.af.un_550  ht.oc.un_550 jw.sq.ca_332 
  0x3f584ca0, 0x584c3fad, 0x3f6b5808, 0x20006011,   // wo.om.af_322 af.wo.om_643  om.ceb.af_443 vo.sq.un_630 
  // [f840]
  0x20002209, 0x234220a7, 0x0f000302, 0x796201a4,   // oc.sq.un_440 sq.co.ca_532  nl.lv.un_220 en.kha.war_433 
  0x0903fe0e, 0x212830a7, 0x20400512, 0x390f1302,   // tlh.nl.pl_555 uz.sd.fa_532  fr.lb.sq_654 et.lv.br_222 
  0x21122fa0, 0x3ffe3707, 0x38006304, 0x0900030d,   // su.hu.jw_322 st.tlh.af_432  sco.tk.un_320 nl.pl.un_540 
  0x33002404, 0x07351702, 0x0300230e, 0xfe003713,   // eo.nn.un_320 sr.tg.bg_222  ca.nl.un_550 st.tlh.un_650 
  // [f850]
  0x130d1807, 0x21343b0c, 0x0324090c, 0x052212a0,   // ga.cs.et_432 ks.ps.fa_543  pl.eo.nl_543 hu.oc.fr_322 
  0x100417a4, 0x09080204, 0x5a002c07, 0x3400fe0d,   // sr.ru.be_433 da.no.pl_332  fy.sm.un_420 tlh.xh.un_540 
  0x21fe0307, 0x20000307, 0x12000507, 0x56002c07,   // nl.tlh.jw_432 nl.sq.un_420  fr.hu.un_420 fy.mg.un_420 
  0x200903a4, 0x121821ee, 0x6e461fa9, 0x4c0d2d0c,   // nl.pl.sq_433 fa.ar.ur_422  cy.qu.hmn_544 sk.cs.wo_543 
  // [f860]
  0x2a460908, 0x532a6355, 0x636e0107, 0x09003b02,   // pl.qu.mt_443 sco.mt.ht_442  en.hmn.sco_432 so.pl.un_220 
  0x3b1f6e0d, 0x56001505, 0x15041007, 0x04082504,   // hmn.cy.so_554 un.mg.un_330  be.ru.un_432 mn.uk.ru_332 
  0x351536af, 0x44382311, 0x383b1fa0, 0x1f6e4307,   // ab.tg.un_650 ky.tk.kk_653  cy.so.tk_322 ie.hmn.cy_432 
  0x016e63a0, 0x18001104, 0x0c3e27ee, 0x2c0a1104,   // sco.hmn.en_322 ro.ga.un_320  gd.rm.sv_422 ro.pt.fy_332 
  // [f870]
  0x21343da6, 0x122d2255, 0x174815af, 0x3b001507,   // ku.ps.fa_521 oc.sk.hu_442  un.tt.sr_655 un.so.un_420 
  0x18000a05, 0x0e003e0d, 0x1035300b, 0x10151708,   // pt.ga.un_330 rm.is.un_540  uz.tg.be_542 sr.be.un_430 
  0x073e42a0, 0x1d006312, 0x04004408, 0x46001102,   // co.rm.it_322 sco.la.un_640  kk.ru.un_430 ro.qu.un_220 
  0x2b284404, 0x23223e0c, 0x3f382c12, 0x1f38fc04,   // kk.sd.dv_332 rm.oc.ca_543  fy.tk.af_654 zzp.tk.cy_332 
  // [f880]
  0x23001007, 0x3b3046a0, 0x0a2d0d05, 0x232d0d65,   // be.ky.un_420 qu.uz.so_322  cs.sk.pt_333 cs.sk.ca_763 
  0x04250808, 0x36122d02, 0x151117ad, 0x33020ded,   // uk.mn.ru_443 sk.hu.gn_222  sr.ro.un_643 cs.da.nn_622 
  0x2b1b2902, 0x303c44ad, 0x083312af, 0x17150aa9,   // sl.tr.vi_222 kk.ug.uz_643  hu.nn.no_655 mk.sr.un_540 
  0x25001707, 0x1535305a, 0x18003c11, 0x100f1da9,   // sr.mn.un_420 uz.tg.un_553  ug.ar.un_630 la.lv.lt_544 
  // [f890]
  0x131d1ea4, 0x382e1b5a, 0x43261dec, 0x3e631da4,   // ms.la.et_433 tr.fo.tk_553  la.ia.ie_644 la.sco.rm_433 
  0x090d5ca6, 0x120f10a9, 0x263e2fa4, 0x1b33080d,   // sa.ne.hi_521 lt.lv.hu_544  su.rm.ia_433 no.nn.tr_554 
  0x04380c04, 0x00001d2d, 0x18130455, 0x15401da9,   // sv.tk.fi_332 la.un.un_A00  fi.et.ga_442 la.lb.un_544 
  0x2e130404, 0x400c60a0, 0x1b006012, 0x023f1508,   // fi.et.fo_332 vo.sv.lb_322  vo.tr.un_640 un.af.da_443 
  // [f8a0]
  0x48380aa4, 0x38461ba0, 0x1d581c0c, 0x155846a0,   // pt.tk.tt_433 tr.qu.tk_322  id.om.la_543 qu.om.un_322 
  0x07265c0d, 0x0407360c, 0x59550805, 0x130c04a0,   // sa.ia.it_554 ab.bg.ru_543  no.rw.rn_333 fi.sv.et_322 
  0x39640f07, 0x344afc0c, 0x020e0812, 0x48040c07,   // lv.lg.br_432 zzp.yo.xh_543  no.is.da_654 sv.fi.tt_432 
  0x33082405, 0x33006507, 0x49365cec, 0x68fc73af,   // eo.no.nn_333 gv.nn.un_420  sa.gn.to_644 ny.zzp.ig_655 
  // [f8b0]
  0x0a000304, 0x3900010d, 0x02fc5a08, 0x420701a4,   // nl.pt.un_320 en.br.un_540  sm.zzp.da_443 en.it.co_433 
  0x05080205, 0x15353ca0, 0x02005102, 0x5a656302,   // da.no.fr_333 ug.tg.un_322  kl.da.un_220 sco.gv.sm_222 
  0x29472da6, 0x400511a7, 0x11423eee, 0x0200760c,   // sk.sn.sl_521 ro.fr.lb_532  rm.co.ro_422 crs.da.un_530 
  0x2d001907, 0x47000a04, 0x30354704, 0x0f330808,   // gl.sk.un_420 pt.sn.un_320  sn.zu.uz_332 no.nn.lv_443 
  // [f8c0]
  0x35005a04, 0x692d1708, 0x02212cee, 0x2a3135ee,   // sm.zu.un_320 sr.sk.mfe_443  fy.jw.da_422 zu.az.mt_422 
  0x3f000f13, 0x0e2d0d09, 0x2e000802, 0x371523a4,   // lv.af.un_650 cs.sk.is_444  no.fo.un_220 ky.ba.un_430 
  0x03002c12, 0x64003f02, 0x0730380d, 0x3d283ba0,   // fy.nl.un_640 af.lg.un_220  tk.uz.bg_554 ks.sd.ku_322 
  0x150423a0, 0x25005d04, 0x4965250c, 0x2300170d,   // ky.ru.un_322 ss.eu.un_320  eu.gv.to_543 sr.ky.un_540 
  // [f8d0]
  0x47013e0c, 0x65212f08, 0x01000205, 0x02000f0e,   // rm.en.sn_543 su.jw.gv_443  da.en.un_330 lv.da.un_550 
  0x4830250c, 0x383025ee, 0x1537480d, 0x382c73ad,   // mn.uz.tt_543 eu.uz.tk_422  tt.ba.un_554 ny.fy.tk_643 
  0x0f253204, 0x47001005, 0x0a0815a4, 0x1f0c65a0,   // bs.eu.lv_332 lt.sn.un_330  un.uk.mk_433 gv.sv.cy_322 
  0x3e004705, 0x16002921, 0x2f0f5504, 0x343021a0,   // sn.rm.un_330 sl.hr.un_860  rw.lv.su_332 fa.uz.ps_322 
  // [f8e0]
  0x400630a0, 0x37000109, 0x44183455, 0x20003902,   // uz.de.lb_322 en.st.un_440  ps.ar.kk_442 br.sq.un_220 
  0x15422cee, 0x212f64a4, 0x080238ee, 0x170835a0,   // fy.co.un_422 lg.su.jw_433  tk.da.no_422 tg.uk.sr_322 
  0x16002507, 0x10002102, 0x02736407, 0x0d5c1c60,   // eu.hr.un_420 jw.lt.un_220  lg.ny.da_432 mr.sa.ne_664 
  0x101707ee, 0x5c6438a7, 0x06001807, 0x381064a0,   // bg.sr.be_422 tk.lg.sa_532  ga.de.un_420 lg.lt.tk_322 
  // [f8f0]
  0x321642a0, 0x30182107, 0x0900060c, 0x101517ee,   // co.hr.bs_322 fa.ar.uz_432  de.pl.un_530 sr.be.un_420 
  0x4b000f14, 0x645c3855, 0x38483714, 0x120838ee,   // lv.mi.un_660 tk.sa.lg_442  ba.tt.tk_666 tk.no.hu_422 
  0x5c48310c, 0x222309a0, 0x04353011, 0x3c00370d,   // az.tt.sa_543 pl.ca.oc_322  uz.tg.ru_653 ba.ug.un_540 
  0x0b001209, 0x09005d04, 0x22231fee, 0x30103607,   // hu.es.un_440 ss.pl.un_320  cy.ca.oc_422 ab.be.uz_432 
  // [f900]
  0x0b0a22a0, 0x18002209, 0x38001123, 0x28181209,   // oc.pt.es_322 oc.ga.un_440  ro.tk.un_880 ur.ar.sd_444 
  0x1108360c, 0x33082e0e, 0x060e0c07, 0x5c004b29,   // ab.uk.ro_543 fo.no.nn_555  sv.is.de_432 mi.sa.un_960 
  0x562d0d5a, 0x2f006118, 0x63fe30ad, 0x345d3707,   // cs.sk.mg_553 za.su.un_740  uz.tlh.sco_643 st.ss.xh_432 
  0x35215c07, 0x4a002813, 0x341816ec, 0x52002813,   // sa.jw.zu_432 sw.yo.un_650  th.ar.ps_644 sw.ha.un_650 
  // [f910]
  0x044435a0, 0x4002fe07, 0xfe004020, 0x3d3c23a0,   // tg.kk.ru_322 tlh.da.lb_432  lb.tlh.un_850 ky.ug.ku_322 
  0x4c111d04, 0x20001d02, 0x654f5011, 0x1c212f02,   // la.ro.wo_332 la.sq.un_220  fj.bi.gv_653 su.jw.id_222 
  0x4a522f05, 0x53004002, 0x3000352c, 0x480738a4,   // su.ha.yo_333 lb.ht.un_220  tg.uz.un_990 tk.bg.tt_433 
  0x5c004b21, 0x2b00300c, 0x5c0f4b11, 0x400357ee,   // mi.sa.un_860 uz.vi.un_530  mi.lv.sa_653 na.nl.lb_422 
  // [f920]
  0x4b4e4aa9, 0x375e7508, 0x28005007, 0x07050112,   // yo.ay.mi_544 nso.ts.st_443  fj.sw.un_420 en.fr.it_654 
  0x735f28af, 0x00005f2d, 0x45736912, 0x0a3530a7,   // sw.tn.ny_655 tn.un.un_A00  mfe.ny.ln_654 uz.tg.mk_532 
  0x09001d02, 0x645f78a9, 0x4a7964ec, 0x0400180b,   // la.pl.un_220 ve.tn.lg_544  lg.war.yo_644 ga.fi.un_520 
  0x5e5368ad, 0x1f3940a9, 0x5e39470d, 0x55006809,   // ig.ht.ts_643 lb.br.cy_544  sn.br.ts_554 ig.rw.un_440 
  // [f930]
  0x5a494b07, 0x670953ec, 0x3d1812af, 0x13080208,   // mi.to.sm_432 ht.pl.ak_644  ur.ar.ku_655 da.no.et_443 
  0x73644705, 0x6a0964a4, 0x3f004020, 0x3f63fc0c,   // sn.lg.ny_333 lg.pl.haw_433  lb.af.un_850 zzp.sco.af_543 
  0x0543010c, 0x75686412, 0x10006308, 0x0240fc0b,   // en.ie.fr_543 lg.ig.nso_654  sco.lt.un_430 zzp.lb.da_542 
  0x64005709, 0x12001d18, 0x3f032ca9, 0xfc00681a,   // na.lg.un_440 la.hu.un_740  fy.nl.af_544 ig.zzp.un_760 
  // [f940]
  0x02000819, 0x2a391faf, 0x76695ead, 0x03060905,   // no.da.un_750 cy.br.mt_655  ts.mfe.crs_643 pl.de.nl_333 
  0x695953a4, 0x35343702, 0x11001514, 0x5e63690d,   // ht.rn.mfe_433 st.xh.zu_222  un.ro.un_660 mfe.sco.ts_554 
  0x5955470e, 0x1a1f7908, 0x11003007, 0x2200232b,   // sn.rw.rn_555 war.cy.tl_443  uz.ro.un_420 ca.oc.un_980 
  0x1023690d, 0x35004013, 0x384055ee, 0x50002102,   // mfe.ca.lt_554 lb.zu.un_650  rw.lb.tk_422 jw.fj.un_220 
  // [f950]
  0x39790507, 0x3f380904, 0x04253004, 0x22000802,   // fr.war.br_432 pl.tk.af_332  uz.mn.ru_332 no.oc.un_220 
  0x3e003008, 0x30063e07, 0x01000f04, 0x133e0404,   // uz.rm.un_430 rm.de.uz_432  lv.en.un_320 fi.rm.et_332 
  0x13000f12, 0x0f131dee, 0x02000f19, 0x3e004014,   // lv.et.un_640 la.et.lv_422  lv.da.un_750 lb.rm.un_660 
  0x4000651a, 0x34000208, 0x041707a9, 0x330865a4,   // gv.lb.un_760 da.xh.un_430  bg.sr.ru_544 gv.no.nn_433 
  // [f960]
  0xfe003007, 0xfe0228a4, 0x7365400c, 0x5c59550e,   // uz.tlh.un_420 sw.da.tlh_433  lb.gv.ny_543 rw.rn.sa_555 
  0x0d732daf, 0xfe00362a, 0x211d5aa7, 0x5c190ba4,   // sk.ny.cs_655 gn.tlh.un_970  sm.la.jw_532 es.gl.sa_433 
  0x123d210d, 0x03580907, 0x063435ee, 0x49005a02,   // fa.ku.ur_554 pl.om.nl_432  zu.xh.de_422 sm.to.un_220 
  0x261901a4, 0x066857ee, 0x4000fe09, 0x1946fca7,   // en.gl.ia_433 na.ig.de_422  tlh.lb.un_440 zzp.qu.gl_532 
  // [f970]
  0x30383cec, 0x0c000e05, 0x04103508, 0x071748a0,   // ug.tk.uz_644 is.sv.un_330  tg.be.ru_443 tt.sr.bg_322 
  0x76006914, 0x68002805, 0x470b4208, 0x23303c55,   // mfe.crs.un_660 sw.ig.un_330  co.es.sn_443 ug.uz.ky_442 
  0x471f06a4, 0x50171608, 0x55345dad, 0x4835230c,   // de.cy.sn_433 hr.sr.fj_443  ss.xh.rw_643 ky.tg.tt_543 
  0x064636a9, 0x730bfca4, 0x44043708, 0x262d530c,   // gn.qu.de_544 zzp.es.ny_433  ba.ru.kk_443 ht.sk.ia_543 
  // [f980]
  0x42001e08, 0x5c004b0e, 0x3e000c0c, 0x315c1b02,   // ms.co.un_430 mi.sa.un_550  sv.rm.un_530 tr.sa.az_222 
  0x5c3447a4, 0x06000e04, 0x31000207, 0x0f004b07,   // sn.xh.sa_433 is.de.un_320  da.az.un_420 mi.lv.un_420 
  0x5a5c4b12, 0x08003522, 0x2254fa07, 0x223f230d,   // mi.sa.sm_654 tg.uk.un_870  nr.ik.oc_432 ca.af.oc_554 
  0x032012ec, 0x205d4eee, 0x5e61370c, 0x04003612,   // hu.sq.nl_644 ay.ss.sq_422  st.za.ts_543 ab.ru.un_640 
  // [f990]
  0x353446a9, 0x5d00200d, 0x125dfa0c, 0x1b006912,   // qu.xh.zu_544 sq.ss.un_540  nr.ss.hu_543 mfe.tr.un_640 
  0x5dfa1808, 0x12281813, 0x5c004208, 0x48302308,   // ga.nr.ss_443 ar.sd.ur_665  co.sa.un_430 ky.uz.tt_443 
  0x46004204, 0x100435a0, 0x071004a9, 0x122022a0,   // co.qu.un_320 tg.ru.be_322  ru.be.bg_544 oc.sq.hu_322 
  0x5d2212ec, 0x0700040b, 0x4e2254a4, 0x2d0d1208,   // hu.oc.ss_644 ru.bg.un_520  ik.oc.ay_433 hu.cs.sk_443 
  // [f9a0]
  0x384e5d55, 0x12130402, 0x1c211e07, 0x34283008,   // ss.ay.tk_442 fi.et.hu_222  ms.jw.id_432 uz.sd.ps_443 
  0x08153012, 0x060309ee, 0x2b004a08, 0x0d122dad,   // uz.uk.un_640 pl.nl.de_422  yo.vi.un_430 sk.hu.cs_643 
  0x4a004913, 0x270742a4, 0x08003512, 0x303f48a0,   // to.yo.un_650 co.it.gd_433  tg.uk.un_640 tt.af.uz_322 
  0x09003602, 0x100d2da7, 0x06001810, 0x0a074855,   // gn.pl.un_220 sk.cs.lt_532  ga.de.un_620 tt.bg.mk_442 
  // [f9b0]
  0x441008ac, 0x52007812, 0x62204e05, 0x5a002b04,   // uk.be.kk_632 ve.ha.un_640  ay.sq.kha_333 vi.sm.un_320 
  0x130a12a0, 0x634d3707, 0x4411155a, 0x185234ee,   // hu.pt.et_322 st.aa.sco_432  un.ro.kk_553 xh.ha.ga_422 
  0x2f002534, 0x19733e08, 0x2a595507, 0x3725fc0d,   // eu.su.un_A80 rm.ny.gl_443  rw.rn.mt_432 zzp.eu.st_554 
  0x0c364daf, 0x24fc01a0, 0x35070402, 0x6200301b,   // aa.gn.sv_655 en.zzp.eo_322  ru.bg.tg_222 uz.kha.un_770 
  // [f9c0]
  0x03283f0c, 0x49624ea9, 0x311b1208, 0x6b6860a4,   // af.sw.nl_543 ay.kha.to_544  hu.tr.az_443 vo.ig.ceb_433 
  0x0e0c0608, 0x2a006407, 0x551d510c, 0x17230407,   // de.sv.is_443 lg.mt.un_420  kl.la.rw_543 ru.ky.sr_432 
  0x651d37ee, 0x0730350c, 0x18443ca0, 0x234837a0,   // st.la.gv_422 tg.uz.bg_543  ug.kk.ar_322 ba.tt.ky_322 
  0x303511ee, 0x565a37a7, 0x4b5628ee, 0x56004905,   // ro.tg.uz_422 st.sm.mg_532  sw.mg.mi_422 to.mg.un_330 
  // [f9d0]
  0x49284b07, 0x4a001808, 0x100844ec, 0x0500360c,   // mi.sw.to_432 ga.yo.un_430  kk.uk.be_644 gn.fr.un_530 
  0x1f3f59a4, 0x110a07af, 0x56005a07, 0x4c1f64ad,   // rn.af.cy_433 bg.mk.ro_655  sm.mg.un_420 lg.cy.wo_643 
  0x56005a02, 0x2a003e12, 0x25081004, 0x1000fc0e,   // sm.mg.un_220 rm.mt.un_640  be.uk.mn_332 zzp.lt.un_550 
  0x3c003d08, 0x40063e13, 0x2a3148a0, 0x17081107,   // ku.ug.un_430 rm.de.lb_665  tt.az.mt_322 ro.uk.sr_432 
  // [f9e0]
  0x11041508, 0x3d002122, 0x30000a0b, 0x3e060e07,   // un.ru.ro_443 fa.ku.un_870  mk.uz.un_520 is.de.rm_432 
  0x511d01a4, 0x431501a0, 0x3e1501a9, 0x44372507,   // en.la.kl_433 en.ie.un_320  en.rm.un_540 mn.ba.kk_432 
  0x63330608, 0x6503400d, 0x2a13fc12, 0x02003f22,   // de.nn.sco_443 lb.nl.gv_554  zzp.et.mt_654 af.da.un_870 
  0x23002105, 0x695701ee, 0x65061d08, 0x0500430d,   // fa.ky.un_330 en.na.mfe_422  la.de.gv_443 ie.fr.un_540 
  // [f9f0]
  0x39003712, 0x2500120e, 0x43400c07, 0x09fc5a07,   // st.br.un_640 hu.eu.un_550  sv.lb.ie_432 sm.zzp.pl_432 
  0x381b310e, 0x40033f5a, 0x011f65a0, 0x02233f0e,   // az.tr.tk_555 af.nl.lb_553  gv.cy.en_322 af.ca.da_555 
  0x32204ba9, 0x1f402ca0, 0x393f0304, 0x021d0107,   // mi.sq.bs_544 fy.lb.cy_322  nl.af.br_332 en.la.da_432 
  0x11000a2a, 0x36005d05, 0x1b003302, 0x03002c21,   // mk.ro.un_970 ss.gn.un_330  nn.tr.un_220 fy.nl.un_860 
  // [fa00]
  0x3e00430d, 0x1b003821, 0x3e016308, 0x67004b1a,   // ie.rm.un_540 tk.tr.un_860  sco.en.rm_443 mi.ak.un_760 
  0x241d1804, 0x17294ba4, 0x010263ec, 0x09001d0c,   // ga.la.eo_332 mi.sl.sr_433  sco.da.en_644 la.pl.un_530 
  0x22000705, 0x36001305, 0x5c003502, 0x08253508,   // it.oc.un_330 et.gn.un_330  zu.sa.un_220 tg.mn.uk_443 
  0x3b2118a4, 0x151809ad, 0x0f004713, 0x3c30110c,   // ar.fa.ks_433 pl.ga.un_643  sn.lv.un_650 ro.uz.ug_543 
  // [fa10]
  0x34091007, 0x5300270c, 0x13063ea0, 0x180115ad,   // lt.pl.xh_432 gd.ht.un_530  rm.de.et_322 un.en.ga_643 
  0x632f010b, 0x01422404, 0x364837ad, 0x01733ead,   // en.su.sco_542 eo.co.en_332  ba.tt.ab_643 rm.ny.en_643 
  0x1540060c, 0x01001d0c, 0x00005c37, 0x49006a0d,   // de.lb.un_543 la.en.un_530  sa.un.un_B00 haw.to.un_540 
  0x18000913, 0x4b6a1e07, 0x505b4b12, 0x21042fa7,   // pl.ga.un_650 ms.haw.mi_432  mi.sg.fj_654 su.fi.jw_532 
  // [fa20]
  0x20281e12, 0x291e21a0, 0x3c2823a0, 0x4b2b6a0e,   // ms.sw.sq_654 jw.ms.sl_322  ky.sd.ug_322 haw.vi.mi_555 
  0x116a5a11, 0xfe624dad, 0x673e1812, 0xfe4d01a0,   // sm.haw.ro_653 aa.kha.tlh_643  ga.rm.ak_654 en.aa.tlh_322 
  0x3e4b5a0d, 0x400b4604, 0x0f59550e, 0x48375f0d,   // sm.mi.rm_554 qu.es.lb_332  rw.rn.lv_555 tn.st.tt_554 
  0x162f61ee, 0x3600401a, 0x2b006e23, 0xfe00320d,   // za.su.hr_422 lb.gn.un_760  hmn.vi.un_880 bs.tlh.un_540 
  // [fa30]
  0x6e501e12, 0x40360b0c, 0x4d62610c, 0x49230aa4,   // ms.fj.hmn_654 es.gn.lb_543  za.kha.aa_543 pt.ca.to_433 
  0x2c1d4007, 0x6700360d, 0x4d002a19, 0x1d044305,   // lb.la.fy_432 gn.ak.un_540  mt.aa.un_750 ie.fi.la_333 
  0x40004513, 0x062c40ad, 0x50006e0e, 0x3e000b0d,   // ln.lb.un_650 lb.fy.de_643  hmn.fj.un_550 es.rm.un_540 
  0x061d57ad, 0x63004f0d, 0x400b1d0d, 0x0a504ba9,   // na.la.de_643 bi.sco.un_540  la.es.lb_554 mi.fj.pt_544 
  // [fa40]
  0x1d070aec, 0xfe626105, 0x4b6e6a08, 0x3e1d2b12,   // pt.it.la_644 za.kha.tlh_333  haw.hmn.mi_443 vi.la.rm_654 
  0x1b006019, 0x5300610c, 0x2f1cfea7, 0x5a1d4904,   // vo.tr.un_750 za.ht.un_530  tlh.id.su_532 to.la.sm_332 
  0x631d3ead, 0x25400ba4, 0x0d135ca0, 0x1d0b26a9,   // rm.la.sco_643 es.lb.eu_433  sa.bh.ne_322 ia.es.la_544 
  0x390a4f07, 0x0b401d07, 0x790a6304, 0x330e0809,   // bi.pt.br_432 la.lb.es_432  sco.pt.war_332 no.is.nn_444 
  // [fa50]
  0x151c0cee, 0x36001b0d, 0x7936560c, 0x2c062b04,   // sv.id.un_422 tr.gn.un_540  mg.gn.war_543 vi.de.fy_332 
  0x17360a0c, 0x56003904, 0x1500790e, 0x18003421,   // mk.ab.sr_543 br.mg.un_320  war.un.un_550 ps.ar.un_860 
  0x17002508, 0x17000718, 0x64fc580c, 0x644c58ad,   // mn.sr.un_430 bg.sr.un_740  om.zzp.lg_543 om.wo.lg_643 
  0x01002108, 0x6b003e08, 0x682f1dee, 0x15304804,   // jw.en.un_430 rm.ceb.un_430  la.su.ig_422 tt.uz.un_332 
  // [fa60]
  0x64005802, 0x233035a7, 0x25002c04, 0x656b0104,   // om.lg.un_220 tg.uz.ky_532  fy.eu.un_320 en.ceb.gv_332 
  0xfc004c08, 0x04153c0c, 0x4d645807, 0x4cfe3baf,   // wo.zzp.un_430 ug.ru.un_530  om.lg.aa_432 so.tlh.wo_655 
  0x1c2f2107, 0x6400580e, 0x15231008, 0x42006408,   // jw.su.id_432 om.lg.un_550  be.ky.un_443 lg.co.un_430 
  0x674d5813, 0x53004c04, 0x585b01a0, 0x080c33ee,   // om.aa.ak_665 wo.ht.un_320  en.sg.om_322 nn.sv.no_422 
  // [fa70]
  0x65584d12, 0x4c64fc12, 0x02000c0c, 0x650c5807,   // aa.om.gv_654 zzp.lg.wo_654  sv.da.un_530 om.sv.gv_432 
  0xfc004c02, 0x79fc580b, 0x0638130c, 0x2e0833ee,   // wo.zzp.un_220 om.zzp.war_542  et.tk.de_543 nn.no.fo_422 
  0x083035a7, 0x15026904, 0xfe0442ee, 0x011f630c,   // tg.uz.uk_532 mfe.da.un_332  co.fi.tlh_422 sco.cy.en_543 
  0x4c2e650e, 0x1f002a05, 0x3000460d, 0x04440709,   // gv.fo.wo_555 mt.cy.un_330  qu.uz.un_540 bg.kk.ru_444 
  // [fa80]
  0xfe00300e, 0x65006305, 0x51003004, 0x3130fe0c,   // uz.tlh.un_550 sco.gv.un_330  uz.kl.un_320 tlh.uz.az_543 
  0x303c3812, 0x35384aee, 0x4d582c60, 0x05004314,   // tk.ug.uz_654 yo.tk.zu_422  fy.om.aa_664 ie.fr.un_660 
  0xfe004c1a, 0x2f08020c, 0x450205ec, 0x45006212,   // wo.tlh.un_760 da.no.su_543  fr.da.ln_644 kha.ln.un_640 
  0x1e523fee, 0x347335a7, 0x23383c04, 0x2c080202,   // af.ha.ms_422 zu.ny.xh_532  ug.tk.ky_332 da.no.fy_222 
  // [fa90]
  0x3c300404, 0x53001a04, 0x2623400c, 0x2a5258ec,   // ru.uz.ug_332 tl.ht.un_320  lb.ca.ia_543 om.ha.mt_644 
  0x434026a4, 0x2a004d0b, 0x11081009, 0x4d004008,   // ia.lb.ie_433 aa.mt.un_520  be.uk.ro_444 lb.aa.un_430 
  0x3f3002ec, 0x6b002007, 0x18342307, 0x3e003809,   // da.uz.af_644 sq.ceb.un_420  ky.ps.ar_432 tk.rm.un_440 
  0x31006502, 0x2a52fe0c, 0x3500170b, 0x152c1d0c,   // gv.az.un_220 tlh.ha.mt_543  sr.tg.un_520 la.fy.un_543 
  // [faa0]
  0x584d2a0c, 0x080226af, 0x2a004d08, 0x0a2605af,   // mt.aa.om_543 ia.da.no_655  aa.mt.un_430 fr.ia.pt_655 
  0x306338a9, 0x211c3e07, 0x53233e07, 0x30002a0b,   // tk.sco.uz_544 rm.id.jw_432  rm.ca.ht_432 mt.uz.un_520 
  0x3e002b13, 0x0a0708a7, 0x22483e08, 0x24451ea0,   // vi.rm.un_650 uk.bg.mk_532  rm.tt.oc_443 ms.ln.eo_322 
  0x34005d29, 0x360a070d, 0x351d34af, 0x0e4538ad,   // ss.xh.un_960 bg.mk.ab_554  xh.la.zu_655 tk.ln.is_643 
  // [fab0]
  0x1d1820ad, 0x15040811, 0x73003418, 0x341b3109,   // sq.ga.la_643 uk.ru.un_653  xh.ny.un_740 az.tr.xh_444 
  0x63006a13, 0x24311107, 0x1a2b6b07, 0x231d010b,   // haw.sco.un_650 ro.az.eo_432  ceb.vi.tl_432 en.la.ca_542 
  0x217334af, 0x6b2b1dec, 0x2f006307, 0x4c00650d,   // xh.ny.jw_655 la.vi.ceb_644  sco.su.un_420 gv.wo.un_540 
  0x46230505, 0x23062a04, 0x3e000513, 0x400c02a4,   // fr.ca.qu_333 mt.de.ca_332  fr.rm.un_650 da.sv.lb_433 
  // [fac0]
  0x06084007, 0x5700061a, 0x151104af, 0x0e00060b,   // lb.no.de_432 de.na.un_760  ru.ro.un_655 de.is.un_520 
  0x0c021507, 0x40006507, 0x0b1d06a0, 0x08000505,   // un.da.sv_432 gv.lb.un_420  de.la.es_322 fr.no.un_330 
  0x020c6304, 0x3f0863ee, 0x080233ac, 0x053e390c,   // sco.sv.da_332 sco.no.af_422  nn.da.no_632 br.rm.fr_543 
  0x0c0e0402, 0x3e6905a4, 0x220543a4, 0x6506050c,   // fi.is.sv_222 fr.mfe.rm_433  ie.fr.oc_433 fr.de.gv_543 
  // [fad0]
  0x0a26230c, 0x061d23ee, 0x2d120e05, 0x041507a9,   // ca.ia.pt_543 ca.la.de_422  is.hu.sk_333 bg.ru.un_540 
  0x082302a0, 0x095c1355, 0x3d183ca7, 0x212834a9,   // da.ca.no_322 bh.sa.hi_442  ug.ar.ku_532 ps.sd.fa_544 
  0x36004409, 0x22001104, 0x2d00290b, 0x062840a0,   // kk.ab.un_440 ro.oc.un_320  sl.sk.un_520 lb.sw.de_322 
  0x0b002504, 0x5c1312a0, 0x5c003909, 0x031122a9,   // eu.es.un_320 hu.et.sa_322  br.sa.un_440 oc.ro.nl_544 
  // [fae0]
  0x2b560404, 0x49000f08, 0x08043708, 0x123418ee,   // fi.mg.vi_332 lv.to.un_430  ba.ru.uk_443 ar.ps.ur_422 
  0x1d222307, 0x02003605, 0x21235da0, 0x395c12ac,   // ca.oc.la_432 gn.da.un_330  ss.ca.jw_322 hu.sa.br_632 
  0x423e13a0, 0x014f63a4, 0x01005302, 0x2815010c,   // et.rm.co_322 sco.bi.en_433  ht.en.un_220 en.sw.un_530 
  0x48002019, 0x122821ad, 0x2c002a22, 0x2d00650d,   // sq.tt.un_750 fa.sd.ur_643  mt.fy.un_870 gv.sk.un_540 
  // [faf0]
  0x06001508, 0x65092da0, 0x060c4d07, 0x09120ca0,   // un.de.un_430 sk.pl.gv_322  aa.sv.de_432 sv.hu.pl_322 
  0x01fc63a0, 0x35080455, 0x37003022, 0x320f1707,   // sco.zzp.en_322 ru.uk.tg_442  uz.ba.un_870 sr.lv.bs_432 
  0x110a1713, 0x09100ca0, 0x191218a0, 0x4a002f05,   // sr.mk.ro_665 sv.lt.pl_322  ga.hu.gl_322 su.yo.un_330 
  0x2e001809, 0x0b122da0, 0x0b190a0d, 0x442330ec,   // ga.fo.un_440 sk.hu.es_322  pt.gl.es_554 uz.ky.kk_644 
  // [fb00]
  0x081738ee, 0x07000a2c, 0x07231113, 0x0b00fc12,   // tk.sr.uk_422 mk.bg.un_990  ro.ky.bg_665 zzp.es.un_640 
  0x48004409, 0x1d344f11, 0x33000811, 0x35173ca6,   // kk.tt.un_440 bi.xh.la_653  no.nn.un_630 ug.sr.tg_521 
  0x46004c04, 0x360e2e11, 0x080411ad, 0x0f1d0b05,   // wo.qu.un_320 fo.is.gn_653  ro.ru.uk_643 es.la.lv_333 
  0x081f0208, 0x0f05010c, 0x65003904, 0x35002308,   // da.cy.no_443 en.fr.lv_543  br.gv.un_320 ky.tg.un_430 
  // [fb10]
  0x560f0105, 0x33020811, 0x3c183407, 0x010b0fee,   // en.lv.mg_333 no.da.nn_653  ps.ar.ug_432 lv.es.en_422 
  0x023f40a0, 0x38044804, 0x28123ba0, 0x0a233c0e,   // lb.af.da_322 tt.fi.tk_332  ks.ur.sd_322 ug.ky.mk_555 
  0x18002e0d, 0x0b004605, 0x02031108, 0x366537a4,   // fo.ga.un_540 qu.es.un_330  ro.nl.da_443 st.gv.gn_433 
  0x443025a0, 0x1d006307, 0x1b025b0c, 0x6e6b0107,   // mn.uz.kk_322 sco.la.un_420  sg.da.tr_543 en.ceb.hmn_432 
  // [fb20]
  0x23000c09, 0x7905010c, 0x60001d08, 0x313f07a0,   // sv.ca.un_440 en.fr.war_543  la.vo.un_430 it.af.az_322 
  0x301544a4, 0x282118a4, 0x04351005, 0x2c033f02,   // kk.uz.un_430 ar.fa.sd_433  be.tg.ru_333 af.nl.fy_222 
  0x2d240da0, 0x2d003607, 0x2d026904, 0x63254711,   // cs.eo.sk_322 gn.sk.un_420  mfe.da.sk_332 sn.eu.sco_653 
  0x64005608, 0x33022e0e, 0x30121808, 0x40063fee,   // mg.lg.un_430 fo.da.nn_555  ar.ur.uz_443 af.de.lb_422 
  // [fb30]
  0x345f29a4, 0x73477811, 0xfc3f1da4, 0x160657a6,   // sl.tn.xh_433 ve.sn.ny_653  la.af.zzp_433 na.de.hr_521 
  0x083f0308, 0x06033f0c, 0x3428440c, 0x52000602,   // nl.af.no_443 af.nl.de_543  kk.sd.ps_543 de.ha.un_220 
  0x0a3547a7, 0x2023220b, 0x02734612, 0x46271812,   // sn.zu.pt_532 oc.ca.sq_542  qu.ny.da_654 ga.gd.qu_654 
  0x52006504, 0x290209ad, 0x476420a0, 0x240429a0,   // gv.ha.un_320 pl.da.sl_643  sq.lg.sn_322 sl.fi.eo_322 
  // [fb40]
  0x20000502, 0x0d201212, 0x31543007, 0x38033fa7,   // fr.sq.un_220 hu.sq.cs_654  uz.ik.az_432 af.nl.tk_532 
  0x20002404, 0x30005414, 0x4620fe0d, 0x5842fe05,   // eo.sq.un_320 ik.uz.un_660  tlh.sq.qu_554 tlh.co.om_333 
  0x587327a9, 0x350234a7, 0x403f0608, 0x52002007,   // gd.ny.om_544 xh.da.zu_532  de.af.lb_443 sq.ha.un_420 
  0x273058a9, 0x222d0d09, 0x0628580c, 0x4408105a,   // om.uz.gd_544 cs.sk.oc_444  om.sw.de_543 be.uk.kk_553 
  // [fb50]
  0x2000fe0e, 0x0b006314, 0x2d120d07, 0x304e460d,   // tlh.sq.un_550 sco.es.un_660  cs.hu.sk_432 qu.ay.uz_554 
  0x311b3812, 0x2d0d090b, 0x303e470c, 0x2d120dad,   // tk.tr.az_654 pl.cs.sk_542  sn.rm.uz_543 cs.hu.sk_643 
  0x4627010b, 0x2a0d24a4, 0x731827ec, 0x362124ad,   // en.gd.qu_542 eo.cs.mt_433  gd.ga.ny_644 eo.jw.gn_643 
  0x58304612, 0x2d004309, 0x4600300d, 0x20381ba7,   // qu.uz.om_654 ie.sk.un_440  uz.qu.un_540 tr.tk.sq_532 
  // [fb60]
  0x37001008, 0x34002f04, 0x21343055, 0x49000802,   // be.ba.un_430 su.xh.un_320  uz.ps.fa_442 no.to.un_220 
  0x21122f07, 0x2112340b, 0x08373ca4, 0x0e001809,   // su.hu.jw_432 ps.ur.fa_542  ug.ba.uk_433 ga.is.un_440 
  0x1c2f3407, 0x03064d07, 0x250435ad, 0x4c003b14,   // xh.su.id_432 aa.de.nl_432  tg.ru.mn_643 so.wo.un_660 
  0x192d0d05, 0x0b002d07, 0x135c09ad, 0x2c2d0d0c,   // cs.sk.gl_333 sk.es.un_420  hi.sa.bh_643 cs.sk.fy_543 
  // [fb70]
  0x2e4e0eec, 0x17100a14, 0x33006504, 0x0912180c,   // is.ay.fo_644 mk.be.sr_666  gv.nn.un_320 ga.hu.pl_543 
  0x3421280d, 0x3b001a08, 0x4c3b640c, 0x2f3b020d,   // sd.fa.ps_554 tl.so.un_430  lg.so.wo_543 da.so.su_554 
  0x16643ba0, 0x3b2913ee, 0x13003b0d, 0x343b6408,   // so.lg.hr_322 et.sl.so_422  so.et.un_540 lg.so.xh_443 
  0x2a016307, 0x3b024d0c, 0x0800230c, 0x0b000108,   // sco.en.mt_432 aa.da.so_543  ky.uk.un_530 en.es.un_430 
  // [fb80]
  0x583b4d07, 0x0663010c, 0x35304814, 0x48371504,   // aa.so.om_432 en.sco.de_543  tt.uz.tg_666 un.ba.tt_332 
  0x1f002d0d, 0x4c134d5a, 0x02133ba4, 0x345e350c,   // sk.cy.un_540 aa.et.wo_553  so.et.da_433 zu.ts.xh_543 
  0x400c12ac, 0x17071504, 0x362d33a4, 0x63650104,   // hu.sv.lb_632 un.bg.sr_332  nn.sk.gn_433 en.gv.sco_332 
  0x656301ee, 0x27005708, 0x38232213, 0x01634004,   // en.sco.gv_422 na.gd.un_430  oc.ca.tk_665 lb.sco.en_332 
  // [fb90]
  0x35233004, 0x150a17a9, 0x442310a0, 0x48002213,   // uz.ky.tg_332 sr.mk.un_544  be.ky.kk_322 oc.tt.un_650 
  0x0c001302, 0x364430a9, 0x39004605, 0x3c001805,   // et.sv.un_220 uz.kk.ab_544  qu.br.un_330 ar.ug.un_330 
  0x07000811, 0x060a2217, 0x130604a6, 0x0c002207,   // uk.bg.un_630 oc.pt.de_753  fi.de.et_521 oc.sv.un_420 
  0x220a48ad, 0x48153714, 0x480a22ec, 0x01500204,   // tt.pt.oc_643 ba.tt.un_660  oc.pt.tt_644 da.fj.en_332 
  // [fba0]
  0xfc001120, 0x483823a4, 0x06041307, 0x0c600413,   // ro.zzp.un_850 ky.tk.tt_433  et.fi.de_432 fi.vo.sv_665 
  0x23003614, 0x48003604, 0x113530ad, 0x170810ee,   // ab.ky.un_660 ab.tt.un_320  uz.tg.ro_643 be.uk.sr_422 
  0x18343ba7, 0xfc001e02, 0x0a004805, 0x1e1c04ac,   // ks.ps.ar_532 ms.zzp.un_220  tt.mk.un_330 fi.id.ms_632 
  0x08000714, 0x6a001c04, 0x1a2f1eac, 0x10304405,   // bg.uk.un_660 id.haw.un_320  ms.su.tl_632 kk.uz.be_333 
  // [fbb0]
  0x1a005a07, 0x4c1a2f0c, 0x582f5aad, 0x32695207,   // sm.tl.un_420 su.tl.wo_543  sm.su.om_643 ha.mfe.bs_432 
  0x64005008, 0x39003607, 0x303b2b05, 0x21003907,   // fj.lg.un_430 gn.br.un_420  vi.so.uz_333 br.jw.un_420 
  0x50021104, 0x6a130d07, 0x65000608, 0x58002f09,   // ro.da.fj_332 cs.et.haw_432  de.gv.un_430 su.om.un_440 
  0x501d6e08, 0x39261d09, 0x2d090dee, 0x33080107,   // hmn.la.fj_443 la.ia.br_444  cs.pl.sk_422 en.no.nn_432 
  // [fbc0]
  0x0a004808, 0x0a0425a7, 0xfc090612, 0x652d0d13,   // tt.mk.un_430 mn.ru.mk_532  de.pl.zzp_654 cs.sk.gv_665 
  0x07041007, 0x2f131a02, 0x632d0d5a, 0x652d0d14,   // be.ru.bg_432 tl.et.su_222  cs.sk.sco_553 cs.sk.gv_666 
  0x0f002c04, 0x38373ca4, 0x24001905, 0x501f63a0,   // fy.lv.un_320 ug.ba.tk_433  gl.eo.un_330 sco.cy.fj_322 
  0x5232200c, 0x18000504, 0x03061d08, 0x1e1c6aa4,   // sq.bs.ha_543 fr.ga.un_320  la.de.nl_443 haw.id.ms_433 
  // [fbd0]
  0x08020107, 0x49004b1a, 0x21287904, 0x25003607,   // en.da.no_432 mi.to.un_760  war.sw.jw_332 ab.mn.un_420 
  0x0c330204, 0x52003114, 0x28181260, 0x2d0d3814,   // da.nn.sv_332 az.ha.un_660  ur.ar.sd_664 tk.cs.sk_666 
  0x52003819, 0x0d1e1c08, 0x2f4678ad, 0x5e00190c,   // tk.ha.un_750 id.ms.cs_443  ve.qu.su_643 gl.ts.un_530 
  0x6a004b09, 0x33082a14, 0x13060da9, 0x486012ad,   // mi.haw.un_440 mt.no.nn_666  cs.de.et_544 hu.vo.tt_643 
  // [fbe0]
  0x33000822, 0x09181902, 0x362019af, 0x04172911,   // no.nn.un_870 gl.ga.pl_222  gl.sq.gn_655 sl.sr.fi_653 
  0x482d0612, 0x281230a9, 0x38002d0e, 0x58005e22,   // de.sk.tt_654 uz.ur.sd_544  sk.tk.un_550 ts.om.un_870 
  0x182130a9, 0x382d0d08, 0x350437ee, 0x20330202,   // uz.fa.ar_544 cs.sk.tk_443  ba.ru.tg_422 da.nn.sq_222 
  0x5e3b1902, 0x05003b08, 0x00000237, 0x2f1c3102,   // gl.so.ts_222 so.fr.un_430  da.un.un_B00 az.id.su_222 
  // [fbf0]
  0x1c191d0e, 0x332c08af, 0x3b005e07, 0x1206600c,   // la.gl.id_555 no.fy.nn_655  ts.so.un_420 vo.de.hu_543 
  0x48303112, 0x25003014, 0x532a2007, 0x0600480c,   // az.uz.tt_654 uz.eu.un_660  sq.mt.ht_432 tt.de.un_530 
  0x20330802, 0x1b253905, 0x13602613, 0x76692508,   // no.nn.sq_222 br.eu.tr_333  ia.vo.et_665 eu.mfe.crs_443 
  0x19300b04, 0x20262e08, 0x0900360d, 0x25003907,   // es.uz.gl_332 fo.ia.sq_443  gn.pl.un_540 br.eu.un_420 
  
  // [fc00]
  0x25353007, 0x18491907, 0x38612507, 0x643012ad,   // uz.tg.mn_432 gl.to.ga_432  eu.za.tk_432 hu.uz.lg_643 
  0x47190b08, 0x251b2a09, 0x183d4407, 0x693061af,   // es.gl.sn_443 mt.tr.eu_444  kk.ku.ar_432 za.uz.mfe_655 
  0x09005307, 0x20302555, 0x15257604, 0x76006921,   // ht.pl.un_420 eu.uz.sq_442  crs.eu.un_332 mfe.crs.un_860 
  0x27000919, 0x42002702, 0x18fc27ee, 0x44153007,   // pl.gd.un_750 gd.co.un_220  gd.zzp.ga_422 uz.kk.un_420 
  // [fc10]
  0x1d001707, 0x0711360c, 0x080a170d, 0x0c3e06a9,   // sr.la.un_420 ab.ro.bg_543  sr.mk.uk_554 de.rm.sv_544 
  0x29160dee, 0x12343007, 0x0d022405, 0x3900670e,   // cs.hr.sl_422 uz.ps.ur_432  eo.da.cs_333 ak.br.un_550 
  0x173515a0, 0x11000509, 0x1715100c, 0x1d001902,   // un.tg.sr_322 fr.ro.un_440  be.sr.un_530 gl.la.un_220 
  0x24000505, 0x15350813, 0x123c3408, 0x0c1206a0,   // fr.eo.un_330 uk.tg.un_665  ps.ug.ur_443 de.hu.sv_322 
  // [fc20]
  0x34302104, 0x080407ec, 0x48003c20, 0x40060ca4,   // fa.uz.ps_332 bg.ru.uk_644  ug.tt.un_850 sv.de.lb_433 
  0x0817370c, 0x23003d12, 0x1700360b, 0x363715a4,   // ba.sr.uk_543 ku.ky.un_640  ab.sr.un_520 un.ba.ab_433 
  0x07154407, 0x303f0305, 0x0830350b, 0x343021af,   // kk.bg.un_420 nl.af.uz_333  tg.uz.uk_542 fa.uz.ps_655 
  0x153c3813, 0x18002d04, 0x35073007, 0x1223280c,   // tk.ug.un_665 sk.ga.un_320  uz.bg.tg_432 sd.ky.ur_543 
  // [fc30]
  0x190b2314, 0x0e362ea4, 0x04003508, 0x5c005e07,   // ca.es.gl_666 fo.gn.is_433  tg.ru.un_430 ts.sa.un_420 
  0x30441509, 0x0a114812, 0x095c0d60, 0x0b001807,   // un.kk.uz_444 tt.ro.mk_654  ne.sa.hi_664 ga.es.un_420 
  0x19790b08, 0x0a1507a0, 0x1c212807, 0x18213008,   // es.war.gl_443 bg.mk.un_320  sw.jw.id_432 uz.fa.ar_443 
  0x25230b04, 0x13003b02, 0x485b01a0, 0x03353404,   // es.ca.eu_332 so.et.un_220  en.sg.tt_322 xh.zu.nl_332 
  // [fc40]
  0x22002612, 0x0d002502, 0x36192d07, 0x21002a08,   // ia.oc.un_640 eu.cs.un_220  sk.gl.gn_432 mt.jw.un_430 
  0x36001911, 0x1d004d0b, 0x1d4d5413, 0x64155107,   // gl.gn.un_630 aa.la.un_520  ik.aa.la_665 kl.lg.un_420 
  0x18122dee, 0x4d424004, 0x27002404, 0x0336280d,   // sk.hu.ga_422 lb.co.aa_332  eo.gd.un_320 sw.gn.nl_554 
  0x4c002112, 0x18362dad, 0x65060c02, 0x2e004f05,   // jw.wo.un_640 sk.gn.ga_643  sv.de.gv_222 bi.fo.un_330 
  // [fc50]
  0x02301212, 0x1f2f21a7, 0x2800291b, 0x4400081a,   // hu.uz.da_654 jw.su.cy_532  sl.sw.un_770 uk.kk.un_760 
  0x18001912, 0x28004008, 0x57000f13, 0x27001e02,   // gl.ga.un_640 lb.sw.un_430  lv.na.un_650 ms.gd.un_220 
  0x65273e12, 0x1d002e12, 0x50000914, 0x530920a0,   // rm.gd.gv_654 fo.la.un_640  pl.fj.un_660 sq.pl.ht_322 
  0x0a171514, 0x4c454305, 0x2500421b, 0x2a005908,   // un.sr.mk_666 ie.ln.wo_333  co.eu.un_770 rn.mt.un_430 
  // [fc60]
  0x1836195e, 0x58182707, 0x2c560302, 0x21002218,   // gl.gn.ga_652 gd.ga.om_432  nl.mg.fy_222 oc.jw.un_740 
  0x3e532105, 0x40002f0d, 0x532122ec, 0x3e212204,   // jw.ht.rm_333 su.lb.un_540  oc.jw.ht_644 oc.jw.rm_332 
  0x34181204, 0x6100091a, 0x5d033f08, 0x33021505,   // ur.ar.ps_332 pl.za.un_760  af.nl.ss_443 un.da.nn_333 
  0x050115ee, 0x533e2255, 0x2200210d, 0x48151111,   // un.en.fr_422 oc.rm.ht_442  jw.oc.un_540 ro.tt.un_630 
  // [fc70]
  0x40002107, 0x55070fad, 0x043708a4, 0x1e007308,   // jw.lb.un_420 lv.it.rw_643  uk.ba.ru_433 ny.ms.un_430 
  0x09110f0c, 0x184430a4, 0x182830a0, 0x07171012,   // lv.ro.pl_543 uz.kk.ar_433  uz.sd.ar_322 be.sr.bg_654 
  0x40002402, 0x043f07a0, 0x53212212, 0x532221a4,   // eo.lb.un_220 it.af.fi_322  oc.jw.ht_654 jw.oc.ht_433 
  0x735d5eaf, 0x0708040d, 0x033f0655, 0x5a004002,   // ts.ss.ny_655 ru.uk.bg_554  de.af.nl_442 lb.sm.un_220 
  // [fc80]
  0x120339a9, 0x0640690c, 0x5c26470d, 0x0c3e0607,   // br.nl.hu_544 mfe.lb.de_543  sn.ia.sa_554 de.rm.sv_432 
  0x05222360, 0x03063fee, 0x17293e05, 0x44253807,   // ca.oc.fr_664 af.de.nl_422  rm.sl.sr_333 tk.mn.kk_432 
  0x34213bac, 0x0a374812, 0x0b1912ee, 0x2337440d,   // ks.fa.ps_632 tt.ba.mk_654  hu.gl.es_422 kk.ba.ky_554 
  0x08363304, 0x0bfc010c, 0x03063f04, 0x51001f02,   // nn.gn.no_332 en.zzp.es_543  af.de.nl_332 cy.kl.un_220 
  // [fc90]
  0x1d1526a4, 0xfc4315ad, 0x06153f05, 0x2f3e0b04,   // ia.la.un_430 un.ie.zzp_643  af.de.un_330 es.rm.su_332 
  0x0a22055a, 0x79000d0d, 0x453610ec, 0x1b002307,   // fr.oc.pt_553 cs.war.un_540  lt.gn.ln_644 ca.tr.un_420 
  0x15113c0c, 0x22002712, 0x100f02ee, 0x53281b08,   // ug.ro.un_543 gd.oc.un_640  da.lv.lt_422 tr.sw.ht_443 
  0x5a630107, 0x02100f0c, 0x3000281a, 0x29305807,   // en.sco.sm_432 lv.lt.da_543  sw.uz.un_760 om.uz.sl_432 
  // [fca0]
  0x520f10ec, 0x4704020c, 0x360d2d11, 0x1a673604,   // lt.lv.ha_644 da.fi.sn_543  sk.cs.gn_653 gn.ak.tl_332 
  0x151125ad, 0x212f1c05, 0x160f10ad, 0x0f1132a0,   // mn.ro.un_643 id.su.jw_333  lt.lv.hr_643 bs.ro.lv_322 
  0x305c28af, 0x07001121, 0x02160f05, 0x282d0d12,   // sw.sa.uz_655 ro.bg.un_860  lv.hr.da_333 cs.sk.sw_654 
  0x15350804, 0x30001008, 0x5800fe1a, 0x304417a0,   // uk.tg.un_332 lt.uz.un_430  tlh.om.un_760 sr.kk.uz_322 
  // [fcb0]
  0x033f61ee, 0x180a1902, 0x334602a0, 0x5200030c,   // za.af.nl_422 gl.pt.ga_222  da.qu.nn_322 nl.ha.un_530 
  0x223f23ad, 0x6e2205a4, 0x441830a4, 0xfe001f1a,   // ca.af.oc_643 fr.oc.hmn_433  uz.ar.kk_433 cy.tlh.un_760 
  0x6e000509, 0x2700fe1b, 0x184c2aa4, 0x2b003f04,   // fr.hmn.un_440 tlh.gd.un_770  mt.wo.ga_433 af.vi.un_320 
  0xfc033fa7, 0x223e2308, 0x0d693313, 0x341228ee,   // af.nl.zzp_532 ca.rm.oc_443  nn.mfe.cs_665 sd.ur.ps_422 
  // [fcc0]
  0x23183ca4, 0x21182308, 0x3e232aa4, 0x0a00040d,   // ug.ar.ky_433 ky.ar.fa_443  mt.ca.rm_433 ru.mk.un_540 
  0x09121855, 0x04002519, 0x0c02080c, 0x4c033f11,   // ga.hu.pl_442 mn.ru.un_750  no.da.sv_543 af.nl.wo_653 
  0x33693e07, 0x1700040b, 0x42004a04, 0x311b300d,   // rm.mfe.nn_432 ru.sr.un_520  yo.co.un_320 uz.tr.az_554 
  0x38311b11, 0x3c3844ec, 0x39002519, 0x2e003902,   // tr.az.tk_653 kk.tk.ug_644  eu.br.un_750 br.fo.un_220 
  // [fcd0]
  0x041048ee, 0x451e690c, 0x08233ca4, 0x611b5360,   // tt.be.ru_422 mfe.ms.ln_543  ug.ky.uk_433 ht.tr.za_664 
  0x65027607, 0x35344aa9, 0x4837150c, 0x1b3130a9,   // crs.da.gv_432 yo.xh.zu_544  un.ba.tt_543 uz.az.tr_544 
  0x3e390b04, 0x1f004d13, 0x63420204, 0x17080a12,   // es.br.rm_332 aa.cy.un_650  da.co.sco_332 mk.uk.sr_654 
  0x1e003005, 0x23000405, 0x65025fee, 0x475f5607,   // uz.ms.un_330 ru.ky.un_330  tn.da.gv_422 mg.tn.sn_432 
  // [fce0]
  0x2900730e, 0x35373408, 0x652afe0c, 0x6e00fe0e,   // ny.sl.un_550 xh.st.zu_443  tlh.mt.gv_543 tlh.hmn.un_550 
  0x28350605, 0x5200fc23, 0x074410ad, 0x4755040c,   // de.zu.sw_333 zzp.ha.un_880  be.kk.bg_643 fi.rw.sn_543 
  0x21232208, 0x0d330802, 0x056518a7, 0x212320a0,   // oc.ca.jw_443 no.nn.cs_222  ga.gv.fr_532 sq.ca.jw_322 
  0x22002018, 0x2917fe07, 0x2e002804, 0x201922ee,   // sq.oc.un_740 tlh.sr.sl_432  sw.fo.un_320 oc.gl.sq_422 
  // [fcf0]
  0x46292a02, 0x3004130c, 0x08001f02, 0x162920a0,   // mt.sl.qu_222 et.fi.uz_543  cy.no.un_220 sq.sl.hr_322 
  0x33082ea0, 0x2822520c, 0x212d0d55, 0x24162907,   // fo.no.nn_322 ha.oc.sw_543  cs.sk.jw_442 sl.hr.eo_432 
  0x0b2f22ac, 0x652522ee, 0x12582007, 0x060e0c12,   // oc.su.es_632 oc.eu.gv_422  sq.om.hu_432 sv.is.de_654 
  0x0e005d02, 0x020c0e0c, 0x3647feaf, 0x49000607,   // ss.is.un_220 is.sv.da_543  tlh.sn.gn_655 de.to.un_420 
  // [fd00]
  0x11000702, 0x12052fee, 0x321746ee, 0x22002f19,   // it.ro.un_220 su.fr.hu_422  qu.sr.bs_422 su.oc.un_750 
  0x46002a0b, 0x2d0d4aa4, 0x17001012, 0x0e006007,   // mt.qu.un_520 yo.cs.sk_433  be.sr.un_640 vo.is.un_420 
  0x171036a4, 0x2822450c, 0x23354404, 0x15253813,   // ab.be.sr_433 ln.oc.sw_543  kk.tg.ky_332 tk.mn.un_665 
  0x2f463ba0, 0x3b4d2709, 0x3b4727a0, 0x0b002d04,   // so.qu.su_322 gd.aa.so_444  gd.sn.so_322 sk.es.un_320 
  // [fd10]
  0x190b2da9, 0x3e001f0c, 0x190b0eee, 0x36001908,   // sk.es.gl_544 cy.rm.un_530  is.es.gl_422 gl.gn.un_430 
  0x2e0e670d, 0x04003307, 0x36192307, 0x1f000e0b,   // ak.is.fo_554 nn.fi.un_420  ca.gl.gn_432 is.cy.un_520 
  0x231548a4, 0x3c302107, 0x56210305, 0x07001108,   // tt.ky.un_430 fa.uz.ug_432  nl.jw.mg_333 ro.bg.un_430 
  0x3400121b, 0x2f005218, 0x17250a02, 0x120e040c,   // ur.ps.un_770 ha.su.un_740  mk.mn.sr_222 fi.is.hu_543 
  // [fd20]
  0x1800090c, 0x08353008, 0x1b000c14, 0x24003407,   // pl.ga.un_530 uz.tg.uk_443  sv.tr.un_660 xh.eo.un_420 
  0x0f006404, 0x18000e0c, 0x2e120e08, 0x04586455,   // lg.lv.un_320 is.ga.un_530  is.hu.fo_443 lg.om.fi_442 
  0x230a220c, 0x0b0a12ee, 0x38314812, 0x38220a05,   // oc.pt.ca_543 hu.pt.es_422  tt.az.tk_654 pt.oc.tk_333 
  0x22380a12, 0x373c44af, 0x38482255, 0x081510a4,   // pt.tk.oc_654 kk.ug.ba_655  oc.tt.tk_442 be.uk.un_430 
  // [fd30]
  0x483160ac, 0x0a00221a, 0x04130602, 0x600929a4,   // vo.az.tt_632 oc.pt.un_760  de.et.fi_222 sl.pl.vo_433 
  0x30070a07, 0x07081111, 0x22000c0c, 0x29095c09,   // mk.bg.uz_432 ro.uk.bg_653  sv.oc.un_530 sa.pl.sl_444 
  0x222338a4, 0x48220a0b, 0x4205220c, 0x173c485a,   // tk.ca.oc_433 pt.oc.tt_542  oc.fr.co_543 tt.ug.sr_553 
  0x38310a02, 0x48004c04, 0x1300092c, 0x4e000e21,   // pt.az.tk_222 wo.tt.un_320  hi.bh.un_990 is.ay.un_860 
  // [fd40]
  0x36152508, 0x0a2317ee, 0x04170a5a, 0x08171007,   // mn.ab.un_430 sr.ky.mk_422  mk.sr.ru_553 be.sr.uk_432 
  0x074836a0, 0x5c46020d, 0x2e5c64a0, 0x1823440c,   // ab.tt.bg_322 da.qu.sa_554  lg.sa.fo_322 kk.ky.ar_543 
  0x52022a12, 0x39002a09, 0x5c002f12, 0x38552811,   // mt.da.ha_654 mt.br.un_440  su.sa.un_640 sw.rw.tk_653 
  0x025528ec, 0x32003808, 0x046b69a0, 0x5d35345a,   // sw.rw.da_644 tk.bs.un_430  mfe.ceb.fi_322 xh.zu.ss_553 
  // [fd50]
  0x04026708, 0x21002302, 0x524a2a08, 0x105d350c,   // ak.da.fi_443 ky.fa.un_220  mt.yo.ha_443 zu.ss.lt_543 
  0x0e002304, 0x022a5208, 0x5e005d04, 0x1d3435ee,   // ca.is.un_320 ha.mt.da_443  ss.ts.un_320 zu.xh.la_422 
  0x282a38ee, 0x231038a4, 0x55003404, 0x12183b05,   // tk.mt.sw_422 tk.be.ky_433  xh.rw.un_320 ks.ar.ur_333 
  0x57002123, 0x303412a6, 0x50005604, 0x30382aa9,   // jw.na.un_880 ur.ps.uz_521  mg.fj.un_320 mt.tk.uz_544 
  // [fd60]
  0x584a2a07, 0x212812ad, 0x6561fe12, 0xfc190a02,   // mt.yo.om_432 ur.sd.fa_643  tlh.za.gv_654 pt.gl.zzp_222 
  0x3300fe21, 0x25795605, 0x1c6162a4, 0x2c686aad,   // tlh.nn.un_860 mg.war.eu_333  kha.za.id_433 haw.ig.fy_643 
  0x0235340d, 0x4f00560d, 0xfc003904, 0x5600040e,   // xh.zu.da_554 mg.bi.un_540  br.zzp.un_320 fi.mg.un_550 
  0x2702570b, 0x3f330e02, 0x2d4d2f0c, 0x2e190b55,   // na.da.gd_542 is.nn.af_222  su.aa.sk_543 es.gl.fo_442 
  // [fd70]
  0x67006121, 0x6179620c, 0x27001c04, 0x0d654c07,   // za.ak.un_860 kha.war.za_543  id.gd.un_320 wo.gv.cs_432 
  0x27000602, 0x1e3830a0, 0x584d7808, 0x080407a9,   // de.gd.un_220 uz.tk.ms_322  ve.aa.om_443 bg.ru.uk_544 
  0x68006a09, 0x170d29ee, 0x04390cad, 0x6200fe21,   // haw.ig.un_440 sl.cs.sr_422  sv.br.fi_643 tlh.kha.un_860 
  0x30002b04, 0x214d67a9, 0xfe4d1ca9, 0x0c3f430c,   // vi.uz.un_320 ak.aa.jw_544  id.aa.tlh_544 ie.af.sv_543 
  // [fd80]
  0x212d1c07, 0x02002c12, 0x590261af, 0x0e003914,   // id.sk.jw_432 fy.da.un_640  za.da.rn_655 br.is.un_660 
  0x11400212, 0x245e3709, 0x20452607, 0x2d0d38a9,   // da.lb.ro_654 st.ts.eo_444  ia.ln.sq_432 tk.cs.sk_544 
  0x33074207, 0x0900360c, 0x120960ac, 0x21072fa4,   // co.it.nn_432 gn.pl.un_530  vo.pl.hu_632 su.it.jw_433 
  0x2e0e12a4, 0x1100fc0d, 0x192d0aad, 0x0d3860ad,   // hu.is.fo_433 zzp.ro.un_540  pt.sk.gl_643 vo.tk.cs_643 
  // [fd90]
  0x0d092d08, 0x380d2dee, 0x3c0a17a4, 0x024207ad,   // sk.pl.cs_443 sk.cs.tk_422  sr.mk.ug_433 it.co.da_643 
  0x5d00421a, 0x1b001902, 0x31483013, 0x0e362e07,   // co.ss.un_760 gl.tr.un_220  uz.tt.az_665 fo.gn.is_432 
  0x46155dee, 0x0e124aa0, 0x3900050b, 0x1b005604,   // ss.qu.un_420 yo.hu.is_322  fr.br.un_520 mg.tr.un_320 
  0x03393f05, 0x571d01a0, 0x0229fc0c, 0x09000e02,   // af.br.nl_333 en.la.na_322  zzp.sl.da_543 is.pl.un_220 
  // [fda0]
  0x2e2d18a7, 0x09000e05, 0x0e2e0955, 0x2d1218ec,   // ga.sk.fo_532 is.pl.un_330  pl.fo.is_442 ga.hu.sk_644 
  0x1000360b, 0x0d005605, 0x0700170d, 0x28213da0,   // ab.be.un_520 mg.cs.un_330  sr.bg.un_540 ku.fa.sd_322 
  0x0e001213, 0x2d00380c, 0x472f1e08, 0x521e21af,   // hu.is.un_650 tk.sk.un_530  ms.su.sn_443 jw.ms.ha_655 
  0x79002818, 0x23150409, 0x4000280c, 0x53000408,   // sw.war.un_740 ru.ky.un_440  sw.lb.un_530 fi.ht.un_430 
  // [fdb0]
  0x375052a0, 0x18343d0b, 0x3b005212, 0x124c200c,   // ha.fj.st_322 ku.ps.ar_542  ha.so.un_640 sq.wo.hu_543 
  0x521e1c08, 0x06005604, 0x2d324aee, 0x21552804,   // id.ms.ha_443 mg.de.un_320  yo.bs.sk_422 sw.rw.jw_332 
  0x060c4002, 0x524a28a7, 0x1c130da0, 0x2d120d04,   // lb.sv.de_222 sw.yo.ha_532  ne.bh.mr_322 cs.hu.sk_332 
  0x48371509, 0x0c001502, 0x0c001d04, 0x15170808,   // un.ba.tt_444 un.sv.un_220  la.sv.un_320 uk.sr.un_443 
  // [fdc0]
  0x1300600c, 0x227905a4, 0x12001822, 0x104425a0,   // vo.et.un_530 fr.war.oc_433  ga.hu.un_870 mn.kk.be_322 
  0x353c30a9, 0x330c080c, 0x4a000e19, 0x2e2d1810,   // uz.ug.tg_544 no.sv.nn_543  is.yo.un_750 ga.sk.fo_642 
  0x215d780c, 0x360a4aa0, 0x3748300c, 0x5d1e1cad,   // ve.ss.jw_543 yo.pt.gn_322  uz.tt.ba_543 id.ms.ss_643 
  0x120e110c, 0x403f035a, 0x1d002508, 0x0437490e,   // ro.is.hu_543 nl.af.lb_553  eu.la.un_430 to.st.fi_555 
  // [fdd0]
  0x792d0d55, 0x1a6b070c, 0x5d1e1c14, 0x481037a4,   // cs.sk.war_442 it.ceb.tl_543  id.ms.ss_666 ba.be.tt_433 
  0x73003402, 0x1200232a, 0x5d240207, 0x10284a55,   // xh.ny.un_220 ky.ur.un_970  da.eo.ss_432 yo.sw.lt_442 
  0x0e2e1da7, 0x356a5dec, 0x5d211ea4, 0x04150807,   // la.fo.is_532 ss.haw.zu_644  ms.jw.ss_433 uk.ru.un_420 
  0x033f4307, 0x11130404, 0x50526409, 0x0a07040d,   // ie.af.nl_432 fi.et.ro_332  lg.ha.fj_444 ru.bg.mk_554 
  // [fde0]
  0x081510af, 0x2d2e0ea4, 0x5e00020c, 0x2b003702,   // be.uk.un_650 is.fo.sk_433  da.ts.un_530 st.vi.un_220 
  0x122e0e0d, 0x07007321, 0x431d02a4, 0x5600371a,   // is.fo.hu_554 ny.it.un_860  da.la.ie_433 st.mg.un_760 
  0x645c02ec, 0x5a002505, 0x2e122dad, 0x0d005c1b,   // da.sa.lg_644 eu.sm.un_330  sk.hu.fo_643 sa.ne.un_770 
  0x2e0e12af, 0x3bfe4613, 0x483537a0, 0x2e180eee,   // hu.is.fo_655 qu.tlh.so_665  ba.tg.tt_322 is.ga.fo_422 
  // [fdf0]
  0x23443702, 0x34fc3555, 0x2c004212, 0x253004a4,   // ba.kk.ky_222 zu.zzp.xh_442  co.fy.un_640 ru.uz.mn_433 
  0x3700361b, 0x3467350c, 0x070a0807, 0x2e001212,   // ab.ba.un_770 zu.ak.xh_543  uk.mk.bg_432 hu.fo.un_640 
  0x212b0604, 0x37007804, 0x5d35fc05, 0x3308460c,   // de.vi.jw_332 ve.st.un_320  zzp.zu.ss_333 qu.no.nn_543 
  0x0e182e07, 0x0f002408, 0x2b000a02, 0x2d1206a0,   // fo.ga.is_432 eo.lv.un_430  pt.vi.un_220 de.hu.sk_322 
  // [fe00]
  0x1b6502a7, 0x0e002e36, 0x23630104, 0x150410a0,   // da.gv.tr_532 fo.is.un_AA0  en.sco.ca_332 be.ru.un_322 
  0x2a0f0604, 0x3000170d, 0x281218ee, 0x24003b05,   // de.lv.mt_332 sr.uz.un_540  ar.ur.sd_422 so.eo.un_330 
  0x150a1712, 0x270640a0, 0x072737a7, 0x22110702,   // sr.mk.un_654 lb.de.gd_322  st.gd.it_532 it.ro.oc_222 
  0x753727a4, 0x1d01fc08, 0x362756ad, 0x07001802,   // gd.st.nso_433 zzp.en.la_443  mg.gd.gn_643 ga.it.un_220 
  // [fe10]
  0x57261daf, 0x25041705, 0x0c001b0c, 0x081025ad,   // la.ia.na_655 sr.ru.mn_333  tr.sv.un_530 mn.be.uk_643 
  0x103508af, 0x1715250c, 0x1c641e07, 0x213d23ee,   // uk.tg.be_655 mn.sr.un_530  ms.lg.id_432 ky.ku.fa_422 
  0x12212802, 0x110804a4, 0x0f002e02, 0x0f2c2ea0,   // sd.fa.ur_222 ru.uk.ro_433  fo.lv.un_220 fo.fy.lv_322 
  0x04080aa0, 0x01002502, 0x21121860, 0x38006313,   // mk.uk.ru_322 eu.en.un_220  ar.ur.fa_664 sco.tk.un_650 
  // [fe20]
  0x481507a4, 0x1b001904, 0x080a2302, 0x0d092dee,   // bg.tt.un_430 gl.tr.un_320  ky.mk.uk_222 sk.pl.cs_422 
  0x15064007, 0x2d0d06a4, 0xfc344a07, 0x0f4063a0,   // lb.de.un_432 de.cs.sk_433  yo.xh.zzp_432 sco.lb.lv_322 
  0x28557307, 0xfc004514, 0x17083c13, 0x360a450c,   // ny.rw.sw_432 ln.zzp.un_660  ug.uk.sr_665 ln.pt.gn_543 
  0x2d0d0cec, 0x0940060c, 0x0c0d2d07, 0x5c131c07,   // sv.cs.sk_644 de.lb.pl_543  sk.cs.sv_432 mr.bh.sa_432 
  // [fe30]
  0x400d63a7, 0x073f080c, 0x11170aa4, 0x0d1c0911,   // sco.cs.lb_532 no.af.it_543  mk.sr.ro_433 hi.mr.ne_653 
  0x0f002805, 0x2c003912, 0x2a00621a, 0x10032c08,   // sw.lv.un_330 br.fy.un_640  kha.mt.un_760 fy.nl.lt_443 
  0x1d000f0d, 0x211d0107, 0x3f2a2ca7, 0x0a483504,   // lv.la.un_540 en.la.jw_432  fy.mt.af_532 tg.tt.mk_332 
  0x3f030fee, 0x10082ca0, 0x62692ca4, 0x04633bee,   // lv.nl.af_422 fy.no.lt_322  fy.mfe.kha_433 so.sco.fi_422 
  // [fe40]
  0x033f2608, 0x3b240404, 0x231715a0, 0x1a6b2409,   // ia.af.nl_443 fi.eo.so_332  un.sr.ky_322 eo.ceb.tl_444 
  0x04002b08, 0x5e001d04, 0x190b07a4, 0x351536ee,   // vi.fi.un_430 la.ts.un_320  it.es.gl_433 ab.tg.un_420 
  0x040725ac, 0x31135ea0, 0x1b004002, 0x23001008,   // mn.bg.ru_632 ts.et.az_322  lb.tr.un_220 be.ky.un_430 
  0x231922a4, 0x183b3d08, 0x0a1525a7, 0x29002c04,   // oc.gl.ca_433 ku.ks.ar_443  mn.mk.un_520 fy.sl.un_320 
  // [fe50]
  0x1d100404, 0x644715ee, 0x3800360b, 0x300438a0,   // fi.lt.la_332 un.sn.lg_422  gn.tk.un_520 tk.ru.uz_322 
  0x4d2f67a4, 0x12006b0d, 0x00004d2d, 0x62fe130c,   // ak.su.aa_433 ceb.hu.un_540  aa.un.un_A00 et.tlh.kha_543 
  0xfe2f1c11, 0x2ffe6212, 0x286834a9, 0x656a1c0c,   // id.su.tlh_653 kha.tlh.su_654  xh.ig.sw_544 id.haw.gv_543 
  0x5c4065ee, 0x4c004e13, 0x65452d07, 0x65672112,   // gv.lb.sa_422 ay.wo.un_650  sk.ln.gv_432 jw.ak.gv_654 
  // [fe60]
  0x1c1efe12, 0x5400241b, 0x1000fc07, 0x1200231a,   // tlh.ms.id_654 eo.ik.un_770  zzp.lt.un_420 ca.hu.un_760 
  0x0a2338a9, 0x1e5667a7, 0x1e316504, 0xfc022855,   // tk.ky.mk_544 ak.mg.ms_532  gv.az.ms_332 sw.da.zzp_442 
  0x120e1905, 0x1f2c4005, 0x17151004, 0x350415ad,   // gl.is.hu_333 lb.fy.cy_333  be.sr.un_320 un.ru.tg_643 
  0x61fe1c0c, 0x6500120c, 0x12022304, 0x191823a0,   // id.tlh.za_543 hu.gv.un_530  ca.da.hu_332 ca.ga.gl_322 
  // [fe70]
  0x126563ee, 0x181d5307, 0x5600620c, 0x1efe620c,   // sco.gv.hu_422 ht.la.ga_432  kha.mg.un_530 kha.tlh.ms_543 
  0x12302809, 0x212f62a4, 0x4d2ffe13, 0x1b2e5d04,   // sd.uz.ur_444 kha.su.jw_433  tlh.su.aa_665 ss.fo.tr_332 
  0x31401102, 0x0c2e3ea0, 0x400342a0, 0x33020309,   // ro.lb.az_222 rm.fo.sv_322  co.nl.lb_322 nl.da.nn_444 
  0x120b19ee, 0x4404480c, 0x04444802, 0x15040aad,   // gl.es.hu_422 tt.ru.kk_543  tt.kk.ru_222 mk.ru.un_643 
  // [fe80]
  0x15040a08, 0x21123055, 0x183d2312, 0x481015ad,   // mk.ru.un_443 uz.ur.fa_442  ky.ku.ar_654 un.be.tt_643 
  0x49006713, 0x1f5373a4, 0x343d18a7, 0x1c302007,   // ak.to.un_650 ny.ht.cy_433  ar.ku.ps_532 sq.uz.id_432 
  0x37345e0e, 0x30003d23, 0x19002e0d, 0x0a081008,   // ts.xh.st_555 ku.uz.un_880  fo.gl.un_540 be.uk.mk_443 
  0x00005f01, 0x36002521, 0x290c3f04, 0x233c44ac,   // tn.un.un_200 mn.ab.un_860  af.sv.sl_332 kk.ug.ky_632 
  // [fe90]
  0x0640650d, 0x0c000108, 0x12006507, 0x070a080b,   // gv.lb.de_554 en.sv.un_430  gv.hu.un_420 uk.mk.bg_542 
  0x056301a7, 0x18000b08, 0xfc1d150b, 0x44041002,   // en.sco.fr_532 es.ga.un_430  un.la.zzp_542 be.ru.kk_222 
  0x303523af, 0x646e5855, 0x354804ee, 0x46003408,   // ky.tg.uz_655 om.hmn.lg_442  ru.tt.tg_422 xh.qu.un_430 
  0x08003009, 0x12283c07, 0x30373cee, 0x0a11230d,   // uz.uk.un_440 ug.sd.ur_432  ug.ba.uz_422 ky.ro.mk_554 
  // [fea0]
  0x10fe09ac, 0x3c2130af, 0x36003c22, 0x1e000204,   // pl.tlh.lt_632 uz.fa.ug_655  ug.ab.un_870 da.ms.un_320 
  0x1000090d, 0x30003c2c, 0x10003819, 0x44041011,   // pl.lt.un_540 ug.uz.un_990  tk.be.un_750 be.ru.kk_653 
  0x6b005419, 0x15303cac, 0x10001f13, 0x3d003c0c,   // ik.ceb.un_750 ug.uz.un_632  cy.lt.un_650 ug.ku.un_530 
  0x36002305, 0x2f401ca0, 0x04171507, 0x06000d04,   // ky.ab.un_330 id.lb.su_322  un.sr.ru_432 cs.de.un_320 
  // [feb0]
  0x183021a7, 0x3e334002, 0x3e004019, 0x6b2b30ad,   // fa.uz.ar_532 lb.nn.rm_222  lb.rm.un_750 uz.vi.ceb_643 
  0x1c130d05, 0x0f002d05, 0x1a206207, 0x5d006213,   // ne.bh.mr_333 sk.lv.un_330  kha.sq.tl_432 kha.ss.un_650 
  0x5c130dec, 0x1125380c, 0x11000205, 0x07171107,   // ne.bh.sa_644 tk.mn.ro_543  da.ro.un_330 ro.sr.bg_432 
  0x0b00332b, 0x301504a0, 0x373c4811, 0x6b481d55,   // as.bn.un_980 ru.uz.un_320  tt.ug.ba_653 la.tt.ceb_442 
  // [fec0]
  0x3419600c, 0x34fc4a07, 0x29374f07, 0x34001d08,   // vo.gl.xh_543 yo.zzp.xh_432  bi.st.sl_432 la.xh.un_430 
  0x09001309, 0x6b735ea4, 0x1d0a7904, 0x53584d0c,   // bh.hi.un_440 ts.ny.ceb_433  war.pt.la_332 aa.om.ht_543 
  0x29fc7304, 0x61004c13, 0x1e003802, 0x19002309,   // ny.zzp.sl_332 wo.za.un_650  tk.ms.un_220 ca.gl.un_440 
  0x73006a07, 0x1d000214, 0x15111755, 0x46261d55,   // haw.ny.un_420 da.la.un_660  sr.ro.un_442 la.ia.qu_442 
  // [fed0]
  0x0e2e3307, 0x20104f07, 0x21004405, 0x1d003707,   // nn.fo.is_432 bi.lt.sq_432  kk.fa.un_330 st.la.un_420 
  0x1700090d, 0x19002318, 0x17360805, 0x39005c04,   // pl.sr.un_540 ca.gl.un_740  uk.ab.sr_333 sa.br.un_320 
  0x3b213008, 0x483517ec, 0x011d26a7, 0x2d002c02,   // uz.fa.ks_443 sr.tg.tt_644  ia.la.en_532 fy.sk.un_220 
  0x04170a55, 0x04251005, 0x512e020c, 0x11003b17,   // mk.sr.ru_442 be.mn.ru_333  da.fo.kl_543 so.ro.un_730 
  // [fee0]
  0x1800fe07, 0x30004508, 0x24002202, 0x154837ec,   // tlh.ga.un_420 ln.uz.un_430  oc.eo.un_220 ba.tt.un_644 
  0x343135ad, 0xfe0361ec, 0x1d1b11a0, 0x2cfe0312,   // zu.az.xh_643 za.nl.tlh_644  ro.tr.la_322 nl.tlh.fy_654 
  0x24000704, 0x15081713, 0x11002007, 0x3f002c08,   // it.eo.un_320 sr.uk.un_665  sq.ro.un_420 fy.af.un_430 
  0x1d005a05, 0x651d3e04, 0x07004a02, 0x3e002402,   // sm.la.un_330 rm.la.gv_332  yo.it.un_220 eo.rm.un_220 
  // [fef0]
  0x30005019, 0x230b0a05, 0x0f002d14, 0x3f6301a0,   // fj.uz.un_750 pt.es.ca_333  sk.lv.un_660 en.sco.af_322 
  0x330c12ee, 0x07423ea9, 0x12001119, 0x073c3012,   // hu.sv.nn_422 rm.co.it_544  ro.hu.un_750 uz.ug.bg_654 
  0x63033f04, 0x3c2818a6, 0x0b0704ee, 0x21281807,   // af.nl.sco_332 ar.sd.ug_521  fi.it.es_422 ar.sd.fa_432 
  0x170a110e, 0x0a371504, 0x11003908, 0x2539050c,   // ro.mk.sr_555 un.ba.mk_332  br.ro.un_430 fr.br.eu_543 
  // [ff00]
  0x53fc09a0, 0x532205ac, 0x0700380b, 0x05392512,   // pl.zzp.ht_322 fr.oc.ht_632  tk.bg.un_520 eu.br.fr_654 
  0x44150814, 0x56001f19, 0x0512390d, 0x2025390b,   // uk.kk.un_660 cy.mg.un_750  br.hu.fr_554 br.eu.sq_542 
  0x193925a9, 0x2200050c, 0x52396807, 0x2505480c,   // eu.br.gl_544 fr.oc.un_530  ig.br.ha_432 tt.fr.eu_543 
  0x42000511, 0x3c1137ec, 0x051b61ec, 0x190e36ee,   // fr.co.un_630 ba.ro.ug_644  za.tr.fr_644 gn.is.gl_422 
  // [ff10]
  0x330d6307, 0x3900092a, 0x76056112, 0x110525a4,   // sco.cs.nn_432 pl.br.un_970  za.fr.crs_654 eu.fr.ro_433 
  0x43053960, 0x28483902, 0x760525a9, 0x012c15a7,   // br.fr.ie_664 br.tt.sw_222  eu.fr.crs_544 un.fy.en_532 
  0x534005ee, 0x3e48050c, 0x400576a9, 0x42220512,   // fr.lb.ht_422 fr.tt.rm_543  crs.fr.lb_544 fr.oc.co_654 
  0x0a07445a, 0x10073602, 0x22002b13, 0x56002d0b,   // kk.bg.mk_553 ab.bg.be_222  vi.oc.un_650 sk.mg.un_520 
  // [ff20]
  0x0425150c, 0x300736a0, 0x341230a7, 0x35003c1a,   // un.mn.ru_543 ab.bg.uz_322  uz.ur.ps_532 ug.tg.un_760 
  0x2100220c, 0x5d002e05, 0x0f004b0d, 0x0e002308,   // oc.jw.un_530 fo.ss.un_330  mi.lv.un_540 ca.is.un_430 
  0x12005712, 0x2f120da9, 0x30233502, 0x1201180b,   // na.hu.un_640 cs.hu.su_544  tg.ky.uz_222 ar.iw.ur_542 
  0x13024ca9, 0x136e1aad, 0x1e6002af, 0x21351fa0,   // wo.da.et_544 tl.hmn.et_643  da.vo.ms_655 cy.zu.jw_322 
  // [ff30]
  0x01006e04, 0x4d543108, 0x21002209, 0x31001520,   // hmn.en.un_320 az.ik.aa_443  oc.jw.un_440 un.az.un_850 
  0x1f092d04, 0x46303108, 0xfe00310e, 0x04171055,   // sk.pl.cy_332 az.uz.qu_443  az.tlh.un_550 be.sr.ru_442 
  0x30000712, 0x3b4831a4, 0x3b006e20, 0x6e004c13,   // bg.uz.un_640 az.tt.so_433  hmn.so.un_850 wo.hmn.un_650 
  0x0a0815a0, 0x6e001313, 0x1dfc09ad, 0x0f4b490c,   // un.uk.mk_322 et.hmn.un_650  pl.zzp.la_643 to.mi.lv_543 
  // [ff40]
  0xfc0d1fa6, 0xfc093607, 0x3048310c, 0x092d06ec,   // cy.cs.zzp_521 gn.pl.zzp_432  az.tt.uz_543 de.sk.pl_644 
  0x25004602, 0x65003009, 0x3b4079ee, 0x40000c35,   // qu.eu.un_220 uz.gv.un_440  war.lb.so_422 sv.lb.un_A90 
  0x282768ee, 0x3f000702, 0x2718feaf, 0x374b5faf,   // ig.gd.sw_422 it.af.un_220  tlh.ga.gd_655 tn.mi.st_655 
  0x03003808, 0x652c03a4, 0x12213412, 0x2f002c02,   // tk.nl.un_430 nl.fy.gv_433  ps.fa.ur_654 fy.su.un_220 
  // [ff50]
  0x20005711, 0xfe003019, 0x1d003411, 0x4d005b19,   // na.sq.un_630 uz.tlh.un_750  xh.la.un_630 sg.aa.un_750 
  0x5035fcaf, 0x12180e55, 0x79000514, 0x4207fc07,   // zzp.zu.fj_655 is.ga.hu_442  fr.war.un_660 zzp.it.co_432 
  0x4400301b, 0x37304809, 0x650163ec, 0x04fc2204,   // uz.kk.un_770 tt.uz.ba_444  sco.en.gv_644 oc.zzp.fi_332 
  0x49004b05, 0x2900471a, 0x370a36ad, 0x1d00220c,   // mi.to.un_330 sn.sl.un_760  ab.mk.ba_643 oc.la.un_530 
  // [ff60]
  0x3e001708, 0x3e332ea0, 0x3534faec, 0x39004705,   // sr.rm.un_430 fo.nn.rm_322  nr.xh.zu_644 sn.br.un_330 
  0x120f100b, 0x16003e05, 0x48371005, 0x630f01a4,   // lt.lv.hu_542 rm.hr.un_330  be.ba.tt_333 en.lv.sco_433 
  0x10003f0c, 0x043615a0, 0x3940050b, 0x39000c07,   // af.lt.un_530 un.ab.ru_322  fr.lb.br_542 sv.br.un_420 
  0x13000c05, 0x242601a4, 0x08174812, 0xfc003e13,   // sv.et.un_330 en.ia.eo_433  tt.sr.uk_654 rm.zzp.un_650 
  // [ff70]
  0x3f2558ad, 0x21002207, 0x1d004d05, 0x0d006404,   // om.eu.af_643 oc.jw.un_420  aa.la.un_330 lg.cs.un_320 
  0x65100fad, 0x455d350d, 0x48000a07, 0x5f006504,   // lv.lt.gv_643 zu.ss.ln_554  mk.tt.un_420 gv.tn.un_320 
  0x3e004604, 0x5321220c, 0x24002702, 0x3e004a1a,   // qu.rm.un_320 oc.jw.ht_543  gd.eo.un_220 yo.rm.un_760 
  0x3700151b, 0x4a001f08, 0x1d420107, 0x6b0469a4,   // un.ba.un_770 cy.yo.un_430  en.co.la_432 mfe.fi.ceb_433 
  // [ff80]
  0x30101d55, 0x242c1007, 0x1c002804, 0x12005d08,   // la.lt.uz_442 lt.fy.eo_432  sw.id.un_320 ss.hu.un_430 
  0x0c00630d, 0x4a003b02, 0x463953a9, 0x01066302,   // sco.sv.un_540 so.yo.un_220  ht.br.qu_544 sco.de.en_222 
  0x5c0d090d, 0x230715ee, 0x01004507, 0x63000c20,   // hi.ne.sa_554 un.bg.ky_422  ln.en.un_420 sv.sco.un_850 
  0x44182104, 0x043517a4, 0x0e004507, 0x080a1705,   // fa.ar.kk_332 sr.tg.ru_433  ln.is.un_420 sr.mk.uk_333 
  // [ff90]
  0x110a070e, 0x3648230c, 0x100f4bac, 0x15153607,   // bg.mk.ro_555 ky.tt.ab_543  mi.lv.lt_632 ab.un.un_420 
  0x35304804, 0x123d34a0, 0x483015a6, 0x2e5d0eee,   // tt.uz.tg_332 ps.ku.ur_322  un.uz.tt_521 is.ss.fo_422 
  0x23002211, 0x17381108, 0x0c002102, 0x043667a7,   // oc.ca.un_630 ro.tk.sr_443  jw.sv.un_220 ak.gn.fi_532 
  0x36006b08, 0x0c003604, 0x36181204, 0x0c005304,   // ceb.gn.un_430 gn.sv.un_320  hu.ga.gn_332 ht.sv.un_320 
  // [ffa0]
  0x253852a4, 0x105628ee, 0x30355007, 0x3700440b,   // ha.tk.eu_433 sw.mg.lt_422  fj.zu.uz_432 kk.ba.un_520 
  0x52103ba0, 0x320720a7, 0x304831a0, 0x482310ee,   // so.lt.ha_322 sq.it.bs_532  az.tt.uz_322 be.ky.tt_422 
  0x38106107, 0x2000320d, 0x1f006e07, 0x474009ee,   // za.lt.tk_432 bs.sq.un_540  hmn.cy.un_420 pl.lb.sn_422 
  0x36003009, 0x46531ba0, 0x345d53a4, 0x1e1c30ec,   // uz.ab.un_440 tr.ht.qu_322  ht.ss.xh_433 uz.id.ms_644 
  // [ffb0]
  0x201c30ee, 0x07002002, 0x200d29a0, 0x103748ec,   // uz.id.sq_422 sq.it.un_220  sl.cs.sq_322 tt.ba.be_644 
  0x2a3534a0, 0x78004714, 0x46002a05, 0xfc64350c,   // xh.zu.mt_322 sn.ve.un_660  mt.qu.un_330 zu.lg.zzp_543 
  0x21fe5104, 0x3c170855, 0x30482313, 0x58004d22,   // kl.tlh.jw_332 uk.sr.ug_442  ky.tt.uz_665 aa.om.un_870 
  0x584d5212, 0xfc180112, 0x53786412, 0x58385208,   // ha.aa.om_654 en.ga.zzp_654  lg.ve.ht_654 ha.tk.om_443 
  // [ffc0]
  0x25040807, 0x4c40fc04, 0x2f1c21a7, 0x4c5852ad,   // uk.ru.mn_432 zzp.lb.wo_332  jw.id.su_532 ha.om.wo_643 
  0x0c5c0805, 0x12342805, 0x35170705, 0x553747a0,   // no.sa.sv_333 sd.ps.ur_333  bg.sr.tg_333 sn.st.rw_322 
  0x52fe4dee, 0x531a7904, 0x195e2a02, 0x3b250ca4,   // aa.tlh.ha_422 war.tl.ht_332  mt.ts.gl_222 sv.eu.so_433 
  0x1c003604, 0x051d3b04, 0x0e3354a0, 0xfc1d60a4,   // gn.id.un_320 so.la.fr_332  ik.nn.is_322 vo.la.zzp_433 
  // [ffd0]
  0x4c1e5802, 0x58304d08, 0x1a003802, 0x0e533907,   // om.ms.wo_222 aa.uz.om_443  tk.tl.un_220 br.ht.is_432 
  0x31004d19, 0x0a004d0e, 0x4d00300d, 0x4bfc0213,   // aa.az.un_750 aa.pt.un_550  uz.aa.un_540 da.zzp.mi_665 
  0x79254d07, 0x4900fc13, 0x30213b0c, 0x0f4b1004,   // aa.eu.war_432 zzp.to.un_650  ks.fa.uz_543 lt.mi.lv_332 
  0x484d310d, 0x0a005e07, 0x3534390c, 0x30543b07,   // az.aa.tt_554 ts.pt.un_420  br.xh.zu_543 so.ik.uz_432 
  // [ffe0]
  0x68151d55, 0x48234460, 0x19485e55, 0x5e3b4c13,   // la.ig.un_420 kk.ky.tt_664  ts.tt.gl_442 wo.so.ts_665 
  0x22000104, 0x02003602, 0x1d3b4ca6, 0x0700fc02,   // en.oc.un_320 gn.da.un_220  wo.so.la_521 zzp.it.un_220 
  0x00006137, 0x103644ec, 0x31003813, 0x5c1c0d0b,   // za.un.un_B00 kk.ab.be_644  tk.az.un_650 ne.mr.sa_542 
  0x38001508, 0x0b00fc08, 0x28000c07, 0x350a30ad,   // un.tk.un_430 zzp.es.un_430  sv.sw.un_420 uz.mk.tg_643 
  // [fff0]
  0x10004b05, 0x17002b04, 0x444837ee, 0x07002a02,   // mi.lt.un_330 vi.sr.un_320  ba.tt.kk_422 mt.it.un_220 
  0x18262712, 0x63003e05, 0x2053020c, 0x442315a4,   // gd.ia.ga_654 rm.sco.un_330  da.ht.sq_543 un.ky.kk_433 
  0x1e0d1cad, 0x23253702, 0x5c00131a, 0x380a48af,   // id.cs.ms_643 ba.mn.ky_222  bh.sa.un_760 tt.mk.tk_655 
  0x084823a0, 0x11000813, 0x343c2314, 0x38006408,   // ky.tt.uk_322 uk.ro.un_650  ky.ug.ps_666 lg.tk.un_430 
  
  // [10000]
  0x523728ad, 0x1218340c, 0x083023a4, 0x3523250c,   // sw.st.ha_643 ps.ar.ur_543  ky.uz.uk_433 mn.ky.tg_543 
  0x252344af, 0x251104a9, 0x562c0405, 0x0a0411a0,   // kk.ky.mn_655 fi.ro.eu_544  fi.fy.mg_333 ro.ru.mk_322 
  0x111b480c, 0x242c2508, 0x18536b07, 0x4a002b0c,   // tt.tr.ro_543 eu.fy.eo_443  ceb.ht.ga_432 vi.yo.un_530 
  0x2b004a2a, 0x2b004a11, 0x422b4a13, 0x2b074a0b,   // yo.vi.un_970 yo.vi.un_630  yo.vi.co_665 yo.it.vi_542 
  // [10010]
  0x56005a29, 0x11675a55, 0x074815a0, 0x4a002b14,   // sm.mg.un_960 sm.ak.ro_442  un.tt.bg_322 vi.yo.un_660 
  0x3e002b29, 0x2b004208, 0x0c070404, 0x11252ca4,   // vi.rm.un_960 co.vi.un_430  fi.it.sv_332 fy.eu.ro_433 
  0x332511a7, 0x07424aad, 0x2b5b4aad, 0x02214eee,   // ro.eu.nn_532 yo.co.it_643  yo.sg.vi_643 ay.jw.da_422 
  0x190b02a0, 0x2f005012, 0x10150414, 0x0a004205,   // da.es.gl_322 fj.su.un_640  ru.be.un_660 co.pt.un_330 
  // [10020]
  0x0a3502ee, 0x2d0dfcec, 0x5d350212, 0x4a004202,   // da.zu.pt_422 zzp.cs.sk_644  da.zu.ss_654 co.yo.un_220 
  0x04350aa0, 0x6724fcad, 0x685e6705, 0x3b000208,   // mk.tg.ru_322 zzp.eo.ak_643  ak.ts.ig_333 da.so.un_430 
  0x07001d02, 0x0a1708ee, 0x274302ad, 0x35003b08,   // la.it.un_220 uk.sr.mk_422  da.ie.gd_643 so.zu.un_430 
  0x42071e07, 0xfc790107, 0x13294304, 0x29002305,   // ms.it.co_432 en.war.zzp_432  ie.sl.et_332 ca.sl.un_330 
  // [10030]
  0x3c00180e, 0x0e002407, 0x295e13a0, 0x5c1b38a4,   // ar.ug.un_550 eo.is.un_420  et.ts.sl_322 tk.tr.sa_433 
  0x13571d11, 0x100f1307, 0x03002907, 0x2d001308,   // la.na.et_653 et.lv.lt_432  sl.nl.un_420 et.sk.un_430 
  0x2f222304, 0x1d3f03ee, 0x32173fa0, 0x211830ee,   // ca.oc.su_332 nl.af.la_422  af.sr.bs_322 uz.ar.fa_422 
  0x1c2113a6, 0x3c001813, 0x310a2405, 0x1b6b4804,   // et.jw.id_521 ar.ug.un_650  eo.pt.az_333 tt.ceb.tr_332 
  // [10040]
  0x36002d12, 0x29005602, 0x17102907, 0x091b31a4,   // sk.gn.un_640 mg.sl.un_220  sl.lt.sr_432 az.tr.pl_433 
  0x5d00fa1a, 0x32162207, 0x5d00670e, 0x2300fa13,   // nr.ss.un_760 oc.hr.bs_432  ak.ss.un_550 nr.ca.un_650 
  0x29005d07, 0x27681804, 0x51001d02, 0x18131aa0,   // ss.sl.un_420 ga.ig.gd_332  la.kl.un_220 tl.et.ga_322 
  0x21001e0c, 0xfe006221, 0x623b4d14, 0x032513a0,   // am.fa.un_530 kha.tlh.un_860  aa.so.kha_666 et.eu.nl_322 
  // [10050]
  0x4d62feec, 0x4b00610d, 0x496b0212, 0x2d0d1902,   // tlh.kha.aa_644 za.mi.un_540  da.ceb.to_654 gl.cs.sk_222 
  0x65010e02, 0x56006508, 0x2f066055, 0x100417ee,   // is.en.gv_222 gv.mg.un_430  vo.de.su_442 sr.ru.be_422 
  0x46001f09, 0x480704a4, 0x5a191da0, 0x48006113,   // cy.qu.un_440 ru.bg.tt_433  la.gl.sm_322 za.tt.un_650 
  0xfc001308, 0x0e2d1260, 0x21fe6755, 0x07350aa0,   // et.zzp.un_430 hu.sk.is_664  ak.tlh.jw_442 mk.tg.bg_322 
  // [10060]
  0x44182307, 0xfe006121, 0xfe002f12, 0x13005602,   // ky.ar.kk_432 za.tlh.un_860  su.tlh.un_640 mg.et.un_220 
  0x61001d19, 0x2b004902, 0x4b005a14, 0x47495a07,   // la.za.un_750 to.vi.un_220  sm.mi.un_660 sm.to.sn_432 
  0x045b4813, 0x020d5007, 0x2d090211, 0x1d022609,   // tt.sg.fi_665 fj.cs.da_432  da.pl.sk_653 ia.da.la_444 
  0x1f004e13, 0x4a002b0e, 0x04172502, 0x4326230c,   // ay.cy.un_650 vi.yo.un_550  mn.sr.ru_222 ca.ia.ie_543 
  // [10070]
  0x211c0208, 0x05234209, 0x4006130c, 0x06083fa4,   // da.id.jw_443 co.ca.fr_444  et.de.lb_543 af.no.de_433 
  0x3b00020d, 0x021220a7, 0x381037a9, 0x3f0802a7,   // da.so.un_540 sq.hu.da_532  ba.be.tk_544 da.no.af_532 
  0x3400020c, 0x20003f08, 0x06023fec, 0x041015a0,   // da.xh.un_530 af.sq.un_430  af.da.de_644 un.be.ru_322 
  0x130601a0, 0x24222307, 0x22432313, 0x232202ee,   // en.de.et_322 ca.oc.eo_432  ca.ie.oc_665 da.oc.ca_422 
  // [10080]
  0x30005604, 0x1700110e, 0x11433bad, 0x21020b07,   // mg.uz.un_320 ro.sr.un_550  so.ie.ro_643 es.da.jw_432 
  0x2c000e05, 0x043035ad, 0x44000804, 0x0e0c4a07,   // is.fy.un_330 tg.uz.ru_643  uk.kk.un_320 yo.sv.is_432 
  0x190a02ee, 0x43052211, 0x153023a9, 0x53000209,   // da.pt.gl_422 oc.fr.ie_653  ky.uz.un_544 da.ht.un_440 
  0x0205080c, 0x032305ad, 0x430f230c, 0x1f006012,   // no.fr.da_543 fr.ca.nl_643  ca.lv.ie_543 vo.cy.un_640 
  // [10090]
  0x2c4a1fa0, 0x3f604307, 0x12003d18, 0x20626108,   // cy.yo.fy_322 ie.vo.af_432  ku.ur.un_740 za.kha.sq_443 
  0x3c00371b, 0x304825ee, 0x122118ec, 0x11005a04,   // ba.ug.un_770 mn.tt.uz_422  ar.fa.ur_644 sm.ro.un_320 
  0x1100040c, 0x0b0a23a4, 0x343d120d, 0x30003423,   // fi.ro.un_530 ca.pt.es_433  ur.ku.ps_554 ps.uz.un_880 
  0x2d004a04, 0x190b4007, 0x2e190ba0, 0x04483155,   // yo.sk.un_320 lb.es.gl_432  es.gl.fo_322 az.tt.fi_442 
  // [100a0]
  0x49400404, 0x39000514, 0x33002204, 0x2118280d,   // fi.lb.to_332 fr.br.un_660  oc.nn.un_320 sd.ar.fa_554 
  0x27fc1805, 0x3e00431b, 0x60300f05, 0x400b4905,   // ga.zzp.gd_333 ie.rm.un_770  lv.uz.vo_333 to.es.lb_333 
  0x1300390e, 0x48403e02, 0x25153c0c, 0x19420b08,   // br.et.un_550 rm.lb.tt_222  ug.mn.un_530 es.co.gl_443 
  0x3b313ea4, 0x3e07010c, 0x4d00301a, 0x3b500107,   // rm.az.so_433 en.it.rm_543  uz.aa.un_760 en.fj.so_432 
  // [100b0]
  0x2e00330c, 0x3f003102, 0x361548a7, 0x1234280b,   // nn.fo.un_530 az.af.un_220  tt.ab.un_520 sd.ps.ur_542 
  0x0a173004, 0x4547520c, 0xfc010204, 0x014afc07,   // uz.sr.mk_332 ha.sn.ln_543  da.en.zzp_332 zzp.yo.en_432 
  0x52003005, 0x65002804, 0x653f1aee, 0x335108ee,   // uz.ha.un_330 sw.gv.un_320  tl.af.gv_422 no.kl.nn_422 
  0x400615ee, 0x3900561b, 0x252c65ee, 0x6976400c,   // un.de.lb_422 mg.br.un_770  gv.fy.eu_422 lb.crs.mfe_543 
  // [100c0]
  0x08021aee, 0x392211a4, 0x76256908, 0x1f4c52ad,   // tl.da.no_422 ro.oc.br_433  mfe.eu.crs_443 ha.wo.cy_643 
  0x25004902, 0x5600391a, 0x69762da4, 0x34531e04,   // to.eu.un_220 br.mg.un_760  sk.crs.mfe_433 ms.ht.xh_332 
  0x76256909, 0x270724a7, 0x00006103, 0x2c562505,   // mfe.eu.crs_444 eo.it.gd_532  za.un.un_300 eu.mg.fy_333 
  0x030e3f0e, 0x182e36a0, 0x340925ad, 0x761b6908,   // af.is.nl_555 gn.fo.ga_322  eu.pl.xh_643 mfe.tr.crs_443 
  // [100d0]
  0x5c130dad, 0x31482505, 0x7621690c, 0x2d2e120c,   // ne.bh.sa_643 eu.tt.az_333  mfe.jw.crs_543 hu.fo.sk_543 
  0x25692da9, 0x0a007608, 0x3c443407, 0x65001f05,   // sk.mfe.eu_544 crs.pt.un_430  ps.kk.ug_432 cy.gv.un_330 
  0x392962ad, 0x12364507, 0x123701a4, 0x1b1260ad,   // kha.sl.br_643 ln.gn.hu_432  en.st.hu_433 vo.hu.tr_643 
  0x4a3425a0, 0x38000108, 0x3200120e, 0x19002d02,   // eu.xh.yo_322 en.tk.un_430  hu.bs.un_550 sk.gl.un_220 
  // [100e0]
  0x05785fa7, 0x122d3e0b, 0x342812a7, 0x1b0d1207,   // tn.ve.fr_532 rm.sk.hu_542  ur.sd.ps_532 hu.cs.tr_432 
  0x1b121f07, 0x38fc1b07, 0x1c1a2007, 0x48383714,   // cy.hu.tr_432 tr.zzp.tk_432  sq.tl.id_432 ba.tk.tt_666 
  0x291dfc0c, 0x20003e09, 0x15200107, 0x231517a9,   // zzp.la.sl_543 rm.sq.un_440  en.sq.un_432 sr.ky.un_540 
  0x171137a4, 0x17000814, 0x2f00200c, 0x20014309,   // ba.ro.sr_433 uk.sr.un_660  sq.su.un_530 ie.en.sq_444 
  // [100f0]
  0x170a3508, 0x05230107, 0x20000504, 0x0c2c0e02,   // tg.mk.sr_443 en.ca.fr_432  fr.sq.un_320 is.fy.sv_222 
  0x0c2e0e12, 0x4300050e, 0x23002012, 0x020520ad,   // is.fo.sv_654 fr.ie.un_550  sq.ca.un_640 sq.fr.da_643 
  0x762001a7, 0x2300052c, 0x4400372b, 0x44001821,   // en.sq.crs_532 fr.ca.un_990  ba.kk.un_980 ar.kk.un_860 
  0x15041009, 0x18003609, 0x08020ea0, 0x48380411,   // be.ru.un_444 gn.ga.un_440  is.da.no_322 fi.tk.tt_653 
  // [10100]
  0x072643af, 0x050a01a4, 0x0e2e2da4, 0x2d2e0e04,   // ie.ia.it_655 en.pt.fr_433  sk.fo.is_433 is.fo.sk_332 
  0x23006304, 0x5c190b02, 0x192e23a0, 0x03403fee,   // sco.ca.un_320 es.gl.sa_222  ca.fo.gl_322 af.lb.nl_422 
  0x58253bad, 0x324721a4, 0x5f3758a4, 0x28526407,   // so.eu.om_643 jw.sn.bs_433  om.st.tn_433 lg.ha.sw_432 
  0x354825ee, 0x190b02a9, 0x600e5d55, 0x2700070d,   // mn.tt.tg_422 da.es.gl_544  ss.is.vo_442 it.gd.un_540 
  // [10110]
  0x65006404, 0x42002212, 0x23353060, 0x06403ba0,   // lg.gv.un_320 oc.co.un_640  uz.tg.ky_664 so.lb.de_322 
  0x4d004c1a, 0x52001f07, 0x070b0a05, 0x43005818,   // wo.aa.un_760 cy.ha.un_420  pt.es.it_333 om.ie.un_740 
  0x21000202, 0x23001c0d, 0x0d35fcac, 0x190a1d14,   // da.jw.un_220 id.ca.un_540  zzp.zu.cs_632 la.pt.gl_666 
  0x4847600c, 0x2a005807, 0x276319a7, 0x032205ad,   // vo.sn.tt_543 om.mt.un_420  gl.sco.gd_532 fr.oc.nl_643 
  // [10120]
  0x555d59a0, 0x30083507, 0x150817af, 0x08020908,   // rn.ss.rw_322 tg.uk.uz_432  sr.uk.un_655 pl.da.no_443 
  0x40013fa0, 0x58003f05, 0x20000207, 0x033f0807,   // af.en.lb_322 af.om.un_330  da.sq.un_420 no.af.nl_432 
  0x11002904, 0x55003604, 0x231f050c, 0x600729af,   // sl.ro.un_320 gn.rw.un_320  fr.cy.ca_543 sl.it.vo_655 
  0x043538ee, 0x43222309, 0x2926070d, 0x1d22230c,   // tk.tg.ru_422 ca.oc.ie_444  it.ia.sl_554 ca.oc.la_543 
  // [10130]
  0x5a003202, 0x50005307, 0x071035a0, 0x420a05a7,   // bs.sm.un_220 ht.fj.un_420  tg.be.bg_322 fr.pt.co_532 
  0x23051ea0, 0x35002809, 0x23130508, 0x22697611,   // ms.fr.ca_322 sw.zu.un_440  fr.et.ca_443 crs.mfe.oc_653 
  0x3525300b, 0x490325a0, 0x13253711, 0x1f002508,   // uz.mn.tg_542 eu.nl.to_322  st.eu.et_653 eu.cy.un_430 
  0x4b003705, 0x15112507, 0xfc1f25a0, 0x5f002512,   // st.mi.un_330 mn.ro.un_432  eu.cy.zzp_322 eu.tn.un_640 
  // [10140]
  0x0c002c07, 0x3f0325ee, 0x190a11ee, 0x3f135608,   // fy.sv.un_420 eu.nl.af_422  ro.pt.gl_422 mg.et.af_443 
  0x373f25a4, 0x04080c0d, 0x56003721, 0x212f1ca9,   // eu.af.st_433 sv.no.fi_554  st.mg.un_860 id.su.jw_544 
  0x23043007, 0x2c11190d, 0x0a222313, 0x151801ee,   // uz.ru.ky_432 gl.ro.fy_554  ca.oc.pt_665 en.ga.un_422 
  0x363c44ec, 0x18211212, 0x19001802, 0x08443704,   // kk.ug.ab_644 ur.fa.ar_654  ga.gl.un_220 ba.kk.uk_332 
  // [10150]
  0x32170f02, 0x184423a9, 0x37483813, 0x44231112,   // lv.sr.bs_222 ky.kk.ar_544  tk.tt.ba_665 ro.ky.kk_654 
  0x42003012, 0x4844370d, 0x233530a7, 0x08003c29,   // uz.co.un_640 ba.kk.tt_554  uz.tg.ky_532 ug.uk.un_960 
  0x483037a0, 0x48233707, 0x2523380c, 0x04080a04,   // ba.uz.tt_322 ba.ky.tt_432  tk.ky.mn_543 mk.uk.ru_332 
  0x230444a7, 0x29002d05, 0x03003f2c, 0x3000040b,   // kk.ru.ky_532 sk.sl.un_330  af.nl.un_990 ru.uz.un_520 
  // [10160]
  0x4000600c, 0x1a006b1a, 0x083f0204, 0x23002f08,   // vo.lb.un_530 ceb.tl.un_760  da.af.no_332 su.ca.un_430 
  0x5c1a64a0, 0x0c006412, 0x39002c0b, 0x042d0d09,   // lg.tl.sa_322 lg.sv.un_640  fy.br.un_520 cs.sk.fi_444 
  0x6400380c, 0x3c483755, 0x0d121808, 0x79006419,   // tk.lg.un_530 ba.tt.ug_442  ga.hu.cs_443 lg.war.un_750 
  0x020f2f0c, 0x63000808, 0x040f39af, 0x5c0f28a4,   // su.lv.da_543 no.sco.un_430  br.lv.fi_655 sw.lv.sa_433 
  // [10170]
  0x393f0302, 0x0200640b, 0x02560fa4, 0x1b5c7907,   // nl.af.br_222 lg.da.un_520  lv.mg.da_433 war.sa.tr_432 
  0x3f46640c, 0x646702a4, 0x32003b07, 0x0200790c,   // lg.qu.af_543 da.ak.lg_433  so.bs.un_420 war.da.un_530 
  0x1a00102a, 0x79676b04, 0x681e5508, 0x25003513,   // lt.tl.un_970 ceb.ak.war_332  rw.ms.ig_443 tg.mn.un_650 
  0x151544ee, 0x310d0fa0, 0x283402a0, 0x281812a7,   // kk.un.un_420 lv.cs.az_322  da.xh.sw_322 ur.ar.sd_532 
  // [10180]
  0x5c480f04, 0x280f2aa9, 0x5657280c, 0x43002808,   // lv.tt.sa_332 mt.lv.sw_544  sw.na.mg_543 sw.ie.un_430 
  0x3102fcad, 0x092751a0, 0x65002714, 0x39004002,   // zzp.da.az_643 kl.gd.pl_322  gd.gv.un_660 lb.br.un_220 
  0x0c001805, 0x6500fe19, 0x6300650d, 0x2b000607,   // ga.sv.un_330 tlh.gv.un_750  gv.sco.un_540 de.vi.un_420 
  0x231302a4, 0x041723a4, 0x19fc0baf, 0x3f211ca4,   // da.et.ca_433 ky.sr.ru_433  es.zzp.gl_655 id.jw.af_433 
  // [10190]
  0x303c1504, 0x19231d07, 0x13003f09, 0x6b2a1dee,   // un.ug.uz_332 la.ca.gl_432  af.et.un_440 la.mt.ceb_422 
  0x400206a9, 0x39055407, 0x1a001507, 0x12343009,   // de.da.lb_544 ik.fr.br_432  un.tl.un_420 uz.ps.ur_444 
  0x0c1d30a4, 0x2765fea7, 0x07111d12, 0x183c3007,   // uz.la.sv_433 tlh.gv.gd_532  la.ro.it_654 uz.ug.ar_432 
  0x31001307, 0x153004a0, 0x064205ee, 0x22231105,   // et.az.un_420 ru.uz.un_322  fr.co.de_422 ro.ca.oc_333 
  // [101a0]
  0x03450204, 0x17040a04, 0x1d6543ee, 0x1d194da0,   // da.ln.nl_332 mk.ru.sr_332  ie.gv.la_422 aa.gl.la_322 
  0x054c0707, 0x2b1c4307, 0x35093ea7, 0x6b1d1d07,   // it.wo.fr_432 ie.id.vi_432  rm.pl.zu_532 la.la.ceb_432 
  0x02110aee, 0x063e18a4, 0x21240a07, 0x030d3fa4,   // pt.ro.da_422 ga.rm.de_433  pt.eo.jw_432 af.cs.nl_433 
  0x3e2d0ca0, 0x5c4769a9, 0x5d000207, 0x3000fc13,   // sv.sk.rm_322 mfe.sn.sa_544  da.ss.un_420 zzp.uz.un_650 
  // [101b0]
  0x5a004008, 0x400615a0, 0x06001202, 0x5a004721,   // lb.sm.un_430 un.de.lb_322  hu.de.un_220 sn.sm.un_860 
  0x09001204, 0x2b1527ee, 0x352924a6, 0x647347ad,   // hu.pl.un_320 gd.vi.un_420  eo.sl.zu_521 sn.ny.lg_643 
  0x23481505, 0x272c26a4, 0x03150ca0, 0x11000407,   // un.tt.ky_333 ia.fy.gd_433  sv.nl.un_320 fi.ro.un_420 
  0x64001a04, 0x2d00290c, 0x17081007, 0x2b151702,   // tl.lg.un_320 sl.sk.un_530  be.uk.sr_432 sr.vi.un_220 
  // [101c0]
  0x120d0907, 0xfe004622, 0x2200650c, 0x0c3f40a0,   // pl.cs.hu_432 qu.tlh.un_870  gv.oc.un_530 lb.af.sv_322 
  0x21181213, 0x2718fe07, 0x2a005504, 0x40065713,   // ur.ar.fa_665 tlh.ga.gd_432  rw.mt.un_320 na.de.lb_665 
  0x25041304, 0x2d0d30a0, 0x402d0da0, 0x2400fe04,   // et.fi.eu_332 uz.cs.sk_322  cs.sk.lb_322 tlh.eo.un_320 
  0x172d0d05, 0x5800060c, 0x080230a0, 0x32002005,   // cs.sk.sr_333 de.om.un_530  uz.da.no_322 sq.bs.un_330 
  // [101d0]
  0x5f2558a4, 0x0d6b5804, 0x3000790e, 0x6300400d,   // om.eu.tn_433 om.ceb.cs_332  war.uz.un_550 lb.sco.un_540 
  0xfe630905, 0x17441107, 0x6353010c, 0x556563ee,   // pl.sco.tlh_333 ro.kk.sr_432  en.ht.sco_543 sco.gv.rw_422 
  0x48000d18, 0x080248a0, 0x1e000504, 0x08022902,   // cs.tt.un_740 tt.da.no_322  fr.ms.un_320 sl.da.no_222 
  0x0e00290b, 0x0d002905, 0x1504150e, 0x23302555,   // sl.is.un_520 sl.cs.un_330  un.ru.un_555 mn.uz.ky_442 
  // [101e0]
  0x112f56ad, 0x07444812, 0x21283b07, 0x28004411,   // mg.su.ro_643 tt.kk.bg_654  ks.sd.fa_432 kk.sd.un_630 
  0x44103607, 0x09000d18, 0x07100a07, 0x04002c08,   // ab.be.kk_432 ne.hi.un_740  mk.be.bg_432 fy.fi.un_430 
  0x2c002212, 0x293209a0, 0x170a3511, 0x041508ec,   // oc.fy.un_640 pl.bs.sl_322  tg.mk.sr_653 uk.ru.un_640 
  0x3504150c, 0x58000e12, 0xfe7347a9, 0x3b100e55,   // un.ru.tg_543 is.om.un_640  sn.ny.tlh_544 is.lt.so_442 
  // [101f0]
  0x684246a0, 0x4746fe07, 0x5d7346a9, 0x16432b04,   // qu.co.ig_322 tlh.qu.sn_432  qu.ny.ss_544 vi.ie.hr_332 
  0x680242a4, 0x222d0d13, 0x08151114, 0x0c003907,   // co.da.ig_433 cs.sk.oc_665  ro.uk.un_660 br.sv.un_420 
  0x0b2868ee, 0x1c003f02, 0x53690955, 0x42460ba7,   // ig.sw.es_422 af.id.un_220  pl.mfe.ht_442 es.qu.co_532 
  0x481538a4, 0x3f4c20a0, 0x01151da4, 0x18341205,   // tk.tt.un_430 sq.wo.af_322  la.en.un_430 ur.ps.ar_333 
  // [10200]
  0x201565ad, 0x06090255, 0x23350a12, 0x02004614,   // gv.sq.un_630 da.pl.de_442  mk.tg.ky_654 qu.da.un_660 
  0x0d000919, 0x30004202, 0x68065d0c, 0x46fe0612,   // hi.ne.un_750 co.uz.un_220  ss.de.ig_543 de.tlh.qu_654 
  0x674e680c, 0x2a002108, 0x100844a9, 0x09650707,   // ig.ay.ak_543 jw.mt.un_430  kk.uk.be_544 it.gv.pl_432 
  0x213c23a7, 0x23283da7, 0x48fe515a, 0x153748a4,   // ky.ug.fa_532 ku.sd.ky_532  kl.tlh.tt_553 tt.ba.un_433 
  // [10210]
  0x09022dee, 0x100f5a14, 0x100f0308, 0x36443c12,   // sk.da.pl_422 sm.lv.lt_666  nl.lv.lt_443 ug.kk.ab_654 
  0x083c17af, 0x35104802, 0x25091013, 0x2a000f14,   // sr.ug.uk_655 tt.be.tg_222  lt.pl.eu_665 lv.mt.un_660 
  0x3f002514, 0x48443c07, 0x09062114, 0x3e2601a4,   // eu.af.un_660 ug.kk.tt_432  jw.de.pl_666 en.ia.rm_433 
  0x393e2507, 0x103623ee, 0x11012604, 0x10220f0c,   // eu.rm.br_432 ky.ab.be_422  ia.en.ro_332 lv.oc.lt_543 
  // [10220]
  0x28211204, 0x0802040c, 0x2c0b01a4, 0x205e4309,   // ur.fa.sd_332 fi.da.no_543  en.es.fy_433 ie.ts.sq_444 
  0x25003e02, 0x255b57a4, 0x0000732d, 0x0d000a04,   // rm.eu.un_220 na.sg.eu_433  ny.un.un_A00 pt.cs.un_320 
  0x03024004, 0x070a230c, 0x080a35ec, 0x08351708,   // lb.da.nl_332 ky.mk.bg_543  tg.mk.uk_644 sr.tg.uk_443 
  0x23442104, 0x48151507, 0x0a3830a4, 0x5c4c4004,   // fa.kk.ky_332 un.tt.un_420  uz.tk.mk_433 lb.wo.sa_332 
  // [10230]
  0x49004b12, 0x39151da0, 0x23004c07, 0x063e400c,   // mi.to.un_640 la.br.un_320  wo.ca.un_420 lb.rm.de_543 
  0x151dfcaf, 0x233c210c, 0x15044812, 0x2d0d15a4,   // zzp.la.un_655 fa.ug.ky_543  tt.ru.un_654 un.cs.sk_433 
  0x18005a04, 0x04084802, 0x36fc680c, 0x39001804,   // sm.ga.un_320 tt.uk.ru_222  ig.zzp.gn_543 ga.br.un_320 
  0x322dfea0, 0x49185aa4, 0x1e000d05, 0x5300fe21,   // tlh.sk.bs_322 sm.ga.to_433  cs.ms.un_330 tlh.ht.un_860 
  // [10240]
  0x0d00360d, 0x473668ad, 0x34183da4, 0x0a000513,   // gn.cs.un_540 ig.gn.sn_643  ku.ar.ps_433 fr.pt.un_650 
  0x151707ec, 0xfe001607, 0x53002a07, 0x0800381a,   // bg.sr.un_644 hr.tlh.un_420  mt.ht.un_420 tk.uk.un_760 
  0x1d386811, 0x343d3b0d, 0x400f1d02, 0x17002305,   // ig.tk.la_653 ks.ku.ps_554  la.lv.lb_222 ky.sr.un_330 
  0x5a00490c, 0x07351002, 0x01150302, 0x48370808,   // to.sm.un_530 be.tg.bg_222  nl.en.un_220 uk.ba.tt_443 
  // [10250]
  0x28344405, 0x3f001d07, 0x401343a4, 0x03003902,   // kk.ps.sd_333 la.af.un_420  ie.et.lb_433 br.nl.un_220 
  0xfc001507, 0x070a44ee, 0x1c5c13ad, 0x40003f0c,   // un.zzp.un_420 kk.mk.bg_422  bh.sa.mr_643 af.lb.un_530 
  0x0f104b55, 0x4c0367a6, 0x28002322, 0x37234460,   // mi.lt.lv_442 ak.nl.wo_521  ky.sd.un_870 kk.ky.ba_664 
  0x18311bad, 0x44373c0c, 0x3035170d, 0x13005c22,   // tr.az.ga_643 ug.ba.kk_543  sr.tg.uz_554 sa.bh.un_870 
  // [10260]
  0x0438485a, 0x08170704, 0x15153c08, 0x09002702,   // tt.tk.ru_553 bg.sr.uk_332  ug.un.un_430 gd.pl.un_220 
  0x03003402, 0x2d040dee, 0x4837440b, 0x26244312,   // xh.nl.un_220 cs.fi.sk_422  kk.ba.tt_542 ie.eo.ia_654 
  0x65630655, 0x20184ea4, 0x09000d21, 0x372344ad,   // de.sco.gv_442 ay.ga.sq_433  cs.pl.un_860 kk.ky.ba_643 
  0x07041807, 0x22006304, 0x03063fa0, 0x07004604,   // ga.fi.it_432 sco.oc.un_320  af.de.nl_322 qu.it.un_320 
  // [10270]
  0x494b3b0c, 0x2a36040c, 0x39406107, 0x20323b0c,   // so.mi.to_543 fi.gn.mt_543  za.lb.br_432 so.bs.sq_543 
  0x27041811, 0x15070414, 0x49614b08, 0x3b004b0c,   // ga.fi.gd_653 ru.bg.un_666  mi.za.to_443 mi.so.un_530 
  0x12311ba7, 0x03123fa4, 0x394f6112, 0x372523a6,   // tr.az.hu_532 af.hu.nl_433  za.bi.br_654 ky.mn.ba_521 
  0x44041004, 0x63062607, 0x03063e07, 0x3b2916a0,   // be.ru.kk_332 ia.de.sco_432  rm.de.nl_432 hr.sl.so_322 
  // [10280]
  0x61004f19, 0x3f0312a7, 0x04003e0b, 0x38121b04,   // bi.za.un_750 hu.nl.af_532  rm.fi.un_520 tr.hu.tk_332 
  0x2e243f04, 0x1b001214, 0x37000705, 0x40570613,   // af.eo.fo_332 hu.tr.un_660  bg.ba.un_330 de.na.lb_665 
  0x0700360b, 0x213b2fa7, 0x63004f19, 0x4006fc08,   // ab.bg.un_520 su.so.jw_532  bi.sco.un_750 zzp.de.lb_443 
  0x396b130c, 0x12381b07, 0x3e4006a9, 0x400651a4,   // et.ceb.br_543 tr.tk.hu_432  de.lb.rm_544 kl.de.lb_433 
  // [10290]
  0x15400611, 0x2100182c, 0x02123602, 0x06033e08,   // de.lb.un_653 ar.fa.un_990  gn.hu.da_222 rm.nl.de_443 
  0x30003805, 0x3e00401a, 0x33131207, 0x4006570c,   // tk.uz.un_330 lb.rm.un_760  hu.et.nn_432 na.de.lb_543 
  0x0400fc08, 0x030640af, 0x08000c1a, 0x080a120c,   // zzp.fi.un_430 lb.de.nl_655  sv.no.un_760 hu.pt.no_543 
  0x3100fc08, 0x073e40a7, 0x08220c0c, 0x024006ac,   // zzp.az.un_430 lb.rm.it_532  sv.oc.no_543 de.lb.da_632 
  // [102a0]
  0x5302fcad, 0x1b3812af, 0x12001b08, 0x12001b05,   // zzp.da.ht_643 hu.tk.tr_655  tr.hu.un_430 tr.hu.un_330 
  0x122021a4, 0x48381b07, 0xfc4006a0, 0x0c000823,   // jw.sq.hu_433 tr.tk.tt_432  de.lb.zzp_322 no.sv.un_880 
  0x381b1212, 0xfc0640ee, 0x13001212, 0x0c061102,   // hu.tr.tk_654 lb.de.zzp_422  hu.et.un_640 ro.de.sv_222 
  0x0c3130ee, 0x40063e12, 0x05471108, 0x40065708,   // uz.az.sv_422 rm.de.lb_654  ro.sn.fr_443 na.de.lb_443 
  // [102b0]
  0x150417af, 0x40fc0304, 0x085e78ec, 0x04002f07,   // sr.ru.un_655 nl.zzp.lb_332  ve.ts.no_644 su.fi.un_420 
  0x363044a0, 0xfa35340d, 0x5d5f37ad, 0x48040c5a,   // kk.uz.ab_322 xh.zu.nr_554  st.tn.ss_643 sv.fi.tt_553 
  0x0e0179a0, 0x3700340c, 0x032b5f07, 0x37003404,   // war.en.is_322 xh.st.un_530  tn.vi.nl_432 xh.st.un_320 
  0x6300340e, 0x28183ca0, 0x6500580d, 0x5a004c05,   // xh.sco.un_550 ug.ar.sd_322  om.gv.un_540 wo.sm.un_330 
  // [102c0]
  0x0300340d, 0x38001e07, 0x1b00130d, 0x021e0402,   // xh.nl.un_540 ms.tk.un_420  et.tr.un_540 fi.ms.da_222 
  0x1b00600c, 0x5a3f1307, 0x3f00130c, 0x656334a0,   // vo.tr.un_530 et.af.sm_432  et.af.un_530 xh.sco.gv_322 
  0x2cfc010c, 0x37153855, 0x35374808, 0x34002c02,   // en.zzp.fy_543 tk.ba.un_420  tt.ba.tg_443 fy.xh.un_220 
  0x124c21a0, 0x4000fc05, 0x062212ee, 0x15081707,   // jw.wo.hu_322 zzp.lb.un_330  hu.oc.de_422 sr.uk.un_432 
  // [102d0]
  0x311b60ed, 0xfc005712, 0x18272804, 0x31121bee,   // vo.tr.az_622 na.zzp.un_640  sw.gd.ga_332 tr.hu.az_422 
  0x1b3860a6, 0x37005007, 0x58681aa4, 0x1b38600c,   // vo.tk.tr_521 fj.st.un_420  tl.ig.om_433 vo.tk.tr_543 
  0x4400070c, 0x4a0f60a4, 0x34495807, 0x0b785a0c,   // bg.kk.un_530 vo.lv.yo_433  om.to.xh_432 sm.ve.es_543 
  0x13311b04, 0x3b003707, 0x2917450c, 0x4600fc11,   // tr.az.et_332 st.so.un_420  ln.sr.sl_543 zzp.qu.un_630 
  // [102e0]
  0x21223bee, 0x2f00010d, 0x080a070d, 0x32171d14,   // so.oc.jw_422 en.su.un_540  bg.mk.uk_554 la.sr.bs_666 
  0x270a18af, 0x591d15a0, 0x4c000a09, 0x18001f0c,   // ga.pt.gd_655 un.la.rn_322  pt.wo.un_440 cy.ga.un_530 
  0x2f2a4fee, 0x0f5f580c, 0x311b380e, 0x5864500c,   // bi.mt.su_422 om.tn.lv_543  tk.tr.az_555 fj.lg.om_543 
  0x50003505, 0x472936a4, 0x503b4609, 0x032c3f05,   // zu.fj.un_330 gn.sl.sn_433  qu.so.fj_444 af.fy.nl_333 
  // [102f0]
  0x67007820, 0x303421ad, 0x1008440b, 0x033f08a0,   // ve.ak.un_850 fa.ps.uz_643  kk.uk.be_542 no.af.nl_322 
  0x3615040c, 0x402c1f07, 0x25fc02a0, 0x2c004018,   // ru.ab.un_530 cy.fy.lb_432  da.zzp.eu_322 lb.fy.un_740 
  0x033f2caf, 0x22235312, 0x23225307, 0x5323210c,   // fy.af.nl_655 ht.ca.oc_654  ht.oc.ca_432 jw.ca.ht_543 
  0x02032aa4, 0x174815a4, 0x312a1da4, 0x21532312,   // mt.nl.da_433 un.tt.sr_433  la.mt.az_433 ca.ht.jw_654 
  // [10300]
  0x254a3fa0, 0x031d48a9, 0x53222307, 0x22532307,   // af.yo.eu_322 tt.la.nl_544  ca.oc.ht_432 ca.ht.oc_432 
  0x16255855, 0x3d213405, 0x1f0239a4, 0x215323a0,   // om.eu.hr_442 ps.fa.ku_333  br.da.cy_433 ca.ht.jw_322 
  0x0000172d, 0x381b1304, 0x2200531a, 0x033f04ee,   // sr.un.un_A00 et.tr.tk_332  ht.oc.un_760 fi.af.nl_422 
  0x212353a4, 0x381260a6, 0x1b25010c, 0x04250107,   // ht.ca.jw_433 vo.hu.tk_521  en.eu.tr_543 en.eu.fi_432 
  // [10310]
  0x53002119, 0x23005312, 0x1c00091a, 0x080444a0,   // jw.ht.un_750 ht.ca.un_640  hi.mr.un_760 kk.ru.uk_322 
  0x07253004, 0x1f002a02, 0x131b60ec, 0x1b12600b,   // uz.mn.bg_332 mt.cy.un_220  vo.tr.et_644 vo.hu.tr_542 
  0x6a000618, 0x1500482a, 0x08042312, 0x2e1243a4,   // de.haw.un_740 tt.un.un_970  ky.ru.uk_654 ie.hu.fo_433 
  0x12311b12, 0x07370a07, 0x3217165a, 0x4437480e,   // tr.az.hu_654 mk.ba.bg_432  hr.sr.bs_553 tt.ba.kk_555 
  // [10320]
  0x31001207, 0x15001523, 0x38303c07, 0x283423a0,   // hu.az.un_420 un.un.un_880  ug.uz.tk_432 ky.ps.sd_322 
  0x1715110c, 0x18122855, 0x440408a0, 0x5100020d,   // ro.sr.un_530 sd.ur.ar_442  uk.ru.kk_322 da.kl.un_540 
  0x30481707, 0x3715440c, 0x46000204, 0x400603a9,   // sr.tt.uz_432 kk.ba.un_530  da.qu.un_320 nl.de.lb_544 
  0x23304402, 0x0807110b, 0x34005f0d, 0x08234407,   // kk.uz.ky_222 ro.bg.uk_542  tn.xh.un_540 kk.ky.uk_432 
  // [10330]
  0x34354dad, 0x251e090b, 0x03002b07, 0x152538ec,   // aa.zu.xh_643 pl.ms.eu_542  vi.nl.un_420 tk.mn.un_644 
  0x39002f02, 0x1035080c, 0x5f373407, 0x48353005,   // su.br.un_220 uk.tg.be_543  xh.st.tn_432 uz.tg.tt_333 
  0x44183d12, 0x21183da4, 0x3e400602, 0x46003e04,   // ku.ar.kk_654 ku.ar.fa_433  de.lb.rm_222 rm.qu.un_320 
  0x2100050c, 0x532a2807, 0x23002214, 0x6000460e,   // fr.jw.un_530 sw.mt.ht_432  oc.ca.un_660 qu.vo.un_550 
  // [10340]
  0x040a11a4, 0x173530ee, 0x27793b0c, 0x04111512,   // ro.mk.ru_433 uz.tg.sr_422  so.war.gd_543 un.ro.ru_654 
  0x2c000f05, 0x28235855, 0x40001902, 0x0c06400c,   // lv.fy.un_330 om.ca.sw_442  gl.lb.un_220 lb.de.sv_543 
  0x4200220c, 0x122d1807, 0x1b3435a0, 0x32fe300c,   // oc.co.un_530 ga.sk.hu_432  zu.xh.tr_322 uz.tlh.bs_543 
  0x4f00fe12, 0x17203007, 0x35005604, 0x61002023,   // tlh.bi.un_640 uz.sq.sr_432  mg.zu.un_320 sq.za.un_880 
  // [10350]
  0x123b21af, 0x1700fe11, 0x292dfe07, 0x3f104307,   // fa.ks.ur_655 tlh.sr.un_630  tlh.sk.sl_432 ie.lt.af_432 
  0x636557a9, 0x482344ee, 0x31481b09, 0x062b0aa0,   // na.gv.sco_544 kk.ky.tt_422  tr.tt.az_444 pt.vi.de_322 
  0x4a00180d, 0x2420fea0, 0x5c007312, 0x3e183b11,   // ga.yo.un_540 tlh.sq.eo_322  ny.sa.un_640 so.ga.rm_653 
  0x372344a4, 0x020e1808, 0x113e3b08, 0x1700fe08,   // kk.ky.ba_433 ga.is.da_443  so.rm.ro_443 tlh.sr.un_430 
  // [10360]
  0x3c30350d, 0x09052607, 0x09022855, 0x3b2718a9,   // tg.uz.ug_554 ia.fr.pl_432  sw.da.pl_442 ga.gd.so_544 
  0x1d1543a0, 0x3d3c2305, 0x732afcad, 0x48114413,   // ie.la.un_320 ky.ug.ku_333  zzp.mt.ny_643 kk.ro.tt_665 
  0x065c1f04, 0x62003b21, 0x27061807, 0x1d005d12,   // cy.sa.de_332 so.kha.un_860  ga.de.gd_432 ss.la.un_640 
  0x073b3ea9, 0x56003409, 0x1e1c56a9, 0x465cfea4,   // rm.so.it_544 xh.mg.un_440  mg.id.ms_544 tlh.sa.qu_433 
  // [10370]
  0x605d3709, 0x73190a09, 0x28465609, 0x52005f05,   // st.ss.vo_444 pt.gl.ny_444  mg.qu.sw_444 tn.ha.un_330 
  0x641302a4, 0x5a52565a, 0x53fc15a4, 0x4d6b2da4,   // da.et.lg_433 mg.ha.sm_553  un.zzp.ht_433 sk.ceb.aa_433 
  0x011cfcee, 0x59fe550c, 0x32162014, 0x313b5e0b,   // zzp.id.en_422 rw.tlh.rn_543  sq.hr.bs_666 ts.so.az_542 
  0x0c1604a4, 0x48233860, 0xfc001813, 0x04204208,   // fi.hr.sv_433 tk.ky.tt_664  ga.zzp.un_650 co.sq.fi_443 
  // [10380]
  0x264e460b, 0x21fe090c, 0x4a5d33a0, 0x232536a4,   // qu.ay.ia_542 pl.tlh.jw_543  nn.ss.yo_322 ab.mn.ky_433 
  0x1dfc11af, 0x360b0a02, 0x11173509, 0x3332165a,   // ro.zzp.la_655 pt.es.gn_222  tg.sr.ro_444 hr.bs.nn_553 
  0x403f06a0, 0x23000413, 0x5d002007, 0x200b29a4,   // de.af.lb_322 ru.ky.un_650  sq.ss.un_420 sl.es.sq_433 
  0x2032165a, 0x44483709, 0x32162a0e, 0x23253004,   // hr.bs.sq_553 ba.tt.kk_444  mt.hr.bs_555 uz.mn.ky_332 
  // [10390]
  0x04483808, 0x230725ad, 0x37153607, 0x3c00232c,   // tk.tt.fi_443 mn.bg.ky_643  ab.ba.un_420 ky.ug.un_990 
  0x48301555, 0x250a15ee, 0x30043509, 0x0a233505,   // un.uz.tt_442 un.mk.mn_422  tg.ru.uz_444 tg.ky.mk_333 
  0x0800110e, 0x0c002010, 0x0d002704, 0x25001709,   // ro.uk.un_550 sq.sv.un_620  gd.cs.un_320 sr.mn.un_440 
  0x441148af, 0x28301209, 0x1b113902, 0x10073812,   // tt.ro.kk_655 ur.uz.sd_444  br.ro.tr_222 tk.bg.be_654 
  // [103a0]
  0x360730a4, 0x3c23380b, 0x15062da0, 0x22002318,   // uz.bg.ab_433 tk.ky.ug_542  sk.de.un_322 ca.oc.un_740 
  0x06040c0d, 0x103048a0, 0x5c100fa4, 0x554b560c,   // sv.fi.de_554 tt.uz.be_322  lv.lt.sa_433 mg.mi.rw_543 
  0x170a380d, 0x0b5c0207, 0x05002013, 0x105004a4,   // tk.mk.sr_554 da.sa.es_432  sq.fr.un_650 fi.fj.lt_433 
  0x494750a9, 0x4d57240c, 0x04004707, 0x09292dee,   // fj.sn.to_544 eo.na.aa_543  sn.fi.un_420 sk.sl.pl_422 
  // [103b0]
  0x24204709, 0x2c4d0312, 0x5e4e25ad, 0x321609ee,   // sn.sq.eo_444 nl.aa.fy_654  eu.ay.ts_643 pl.hr.bs_422 
  0x094659a4, 0x532122a7, 0x32294f04, 0x4a002212,   // rn.qu.pl_433 oc.jw.ht_532  bi.sl.bs_332 oc.yo.un_640 
  0x123021a6, 0x011502a0, 0x3b001a02, 0xfc4a4008,   // fa.uz.ur_521 da.en.un_320  tl.so.un_220 lb.yo.zzp_443 
  0x500237a9, 0x13040c07, 0x4a0912ad, 0x027924af,   // st.da.fj_544 sv.fi.et_432  hu.pl.yo_643 eo.war.da_655 
  // [103c0]
  0x0e124aa4, 0x36022407, 0x1d00020c, 0x0a024355,   // yo.hu.is_433 eo.da.gn_432  da.la.un_530 ie.da.pt_442 
  0x1f3b6507, 0x0200400b, 0x235322ee, 0x5d794607,   // gv.so.cy_432 lb.da.un_520  oc.ht.ca_422 qu.war.ss_432 
  0x0d002404, 0x650224ad, 0x05025d04, 0x190b4e12,   // eo.cs.un_320 eo.da.gv_643  ss.da.fr_332 ay.es.gl_654 
  0x21001d12, 0x24000b05, 0x02114313, 0x2b000502,   // la.jw.un_640 es.eo.un_330  ie.ro.da_665 fr.vi.un_220 
  // [103d0]
  0x21231702, 0x25002404, 0x46072207, 0x30353609,   // sr.ca.jw_222 eo.eu.un_320  oc.it.qu_432 ab.tg.uz_444 
  0x04153604, 0x0a002412, 0x0100181b, 0x02002420,   // ab.ru.un_320 eo.pt.un_640  ar.iw.un_770 eo.da.un_850 
  0x4207010c, 0x19002404, 0x1d0224a4, 0x230a1755,   // en.it.co_543 eo.gl.un_320  eo.da.la_433 sr.mk.ky_442 
  0x03fc06ee, 0x23303507, 0x2d00380e, 0x481123ec,   // de.zzp.nl_422 tg.uz.ky_432  tk.sk.un_550 ky.ro.tt_644 
  // [103e0]
  0x20005007, 0x3c2134a9, 0x19003904, 0x301821ec,   // fj.sq.un_420 ps.fa.ug_544  br.gl.un_320 fa.ar.uz_644 
  0xfe000214, 0x48443755, 0x1b042555, 0x18004905,   // da.tlh.un_660 ba.kk.tt_442  eu.fi.tr_442 to.ga.un_330 
  0x23001114, 0x10361104, 0x23004f07, 0x304ffe0b,   // ro.ky.un_660 ro.ab.be_332  bi.ca.un_420 tlh.bi.uz_542 
  0x130431a6, 0x28302011, 0x154810af, 0x3e010f07,   // az.fi.et_521 sq.uz.sw_653  be.tt.un_655 lv.en.rm_432 
  // [103f0]
  0x220f60ee, 0x0417350c, 0x0f002204, 0x01003e08,   // vo.lv.oc_422 tg.sr.ru_543  oc.lv.un_320 rm.en.un_430 
  0x4407300c, 0x07170405, 0x08003619, 0x31003011,   // uz.bg.kk_543 ru.sr.bg_333  ab.uk.un_750 uz.az.un_630 
  0x033f4207, 0x6022230e, 0x48001902, 0x152301af,   // co.af.nl_432 ca.oc.vo_555  gl.tt.un_220 en.ca.un_655 
  0x361108a4, 0x030523a0, 0x230f2207, 0x4830230c,   // uk.ro.ab_433 ca.fr.nl_322  oc.lv.ca_432 ky.uz.tt_543 
  
  // [10400]
  0x5c093b07, 0x5b001113, 0x3b170aee, 0x5d5a370c,   // ks.hi.sa_432 ro.sg.un_650  pt.sr.so_422 st.sm.ss_543 
  0x183421a7, 0x56003019, 0x5a375f07, 0x375f5dec,   // fa.ps.ar_532 uz.mg.un_750  tn.st.sm_432 ss.tn.st_644 
  0x0307090c, 0x34004d07, 0x1c00310c, 0x40004602,   // pl.it.nl_543 aa.xh.un_420  az.id.un_530 qu.lb.un_220 
  0x20000908, 0x4c30280c, 0x3b343507, 0x283024ee,   // pl.sq.un_430 sw.uz.wo_543  zu.xh.so_432 eo.uz.sw_422 
  // [10410]
  0x5a1030ee, 0x7500280e, 0x0e002e2b, 0x44074807,   // uz.lt.sm_422 sw.nso.un_550  fo.is.un_980 tt.bg.kk_432 
  0x09000c0e, 0x55594704, 0x3e004205, 0x29004707,   // sv.pl.un_550 sn.rn.rw_332  co.rm.un_330 sn.sl.un_420 
  0xfe005012, 0x30314604, 0x35004d0c, 0x0f292dee,   // fj.tlh.un_640 qu.az.uz_332  aa.zu.un_530 sk.sl.lv_422 
  0x21342304, 0x36444813, 0x20002704, 0x08103514,   // ky.ps.fa_332 tt.kk.ab_665  gd.sq.un_320 tg.be.uk_666 
  // [10420]
  0xfc1215a0, 0x0c001104, 0x330803ee, 0x2e330404,   // un.hu.zzp_322 ro.sv.un_320  nl.no.nn_422 fi.nn.fo_332 
  0x241239a0, 0x0a1108ec, 0x3b30200c, 0x0415080d,   // br.hu.eo_322 uk.ro.mk_644  sq.uz.so_543 uk.ru.un_540 
  0x28560f07, 0x1d35fca7, 0x23001513, 0x380e2e07,   // lv.mg.sw_432 zzp.zu.la_532  un.ky.un_650 fo.is.tk_432 
  0x2800341b, 0x4a00181a, 0x2a003e02, 0x2b00200c,   // ps.sd.un_770 ga.yo.un_760  rm.mt.un_220 sq.vi.un_530 
  // [10430]
  0x3744155a, 0x122e2307, 0x60001819, 0x352a34a0,   // un.kk.ba_553 ca.fo.hu_432  ga.vo.un_750 xh.mt.zu_322 
  0x2a133eee, 0x15005304, 0x10000419, 0x240625a4,   // rm.et.mt_422 ht.un.un_320  fi.lt.un_750 eu.de.eo_433 
  0x20730807, 0x040625ac, 0x0a251712, 0x292d0d12,   // no.ny.sq_432 eu.de.fi_632  sr.mn.mk_654 cs.sk.sl_654 
  0x2a071baf, 0x06076007, 0x6b2f2007, 0x58003e12,   // tr.it.mt_655 vo.it.de_432  sq.su.ceb_432 rm.om.un_640 
  // [10440]
  0x4425480d, 0x373534a9, 0x303d1807, 0x212334a4,   // tt.mn.kk_554 xh.zu.st_544  ar.ku.uz_432 ps.ky.fa_433 
  0x1b000414, 0x3e2512ad, 0x070653a0, 0x35003c05,   // fi.tr.un_660 hu.eu.rm_643  ht.de.it_322 ug.tg.un_330 
  0x0a00230e, 0x2d1629a0, 0x4838085a, 0x44002804,   // ky.mk.un_550 sl.hr.sk_322  uk.tk.tt_553 sd.kk.un_320 
  0x56005207, 0x371906a0, 0x0f105ca4, 0x18490e07,   // ha.mg.un_420 de.gl.st_322  sa.lt.lv_433 is.to.ga_432 
  // [10450]
  0x522a4da7, 0x64005604, 0x736543a4, 0x5f0a37a9,   // aa.mt.ha_532 mg.lg.un_320  ie.gv.ny_433 st.pt.tn_544 
  0x29005302, 0x0a154809, 0x2f0e02ee, 0x090d1ca9,   // ht.sl.un_220 tt.mk.un_440  da.is.su_422 mr.ne.hi_544 
  0x115b4207, 0x0e004702, 0x52675a0b, 0x2e002a08,   // co.sg.ro_432 sn.is.un_220  sm.ak.ha_542 mt.fo.un_430 
  0x2300480b, 0x65271f07, 0x230e2e05, 0x18002322,   // tt.ky.un_520 cy.gd.gv_432  fo.is.ca_333 ky.ar.un_870 
  // [10460]
  0x23070aee, 0x374815a9, 0x044823a0, 0x30691208,   // mk.bg.ky_422 un.tt.ba_544  ky.tt.ru_322 hu.mfe.uz_443 
  0x0f4e24a4, 0x1b482aad, 0x6b2e79ee, 0x38301507,   // eo.ay.lv_433 mt.tt.tr_643  war.fo.ceb_422 un.uz.tk_432 
  0x3d00122a, 0x0e334e07, 0x04380a04, 0x3435600b,   // ur.ku.un_970 ay.nn.is_432  mk.tk.ru_332 vo.zu.xh_542 
  0x350817a4, 0x5c001002, 0x5600280d, 0x21006502,   // sr.uk.tg_433 lt.sa.un_220  sw.mg.un_540 gv.jw.un_220 
  // [10470]
  0x2200fc13, 0x4c251f11, 0x02433ea4, 0x39005607,   // zzp.oc.un_650 cy.eu.wo_653  rm.ie.da_433 mg.br.un_420 
  0x231d02ee, 0x300a3ca0, 0x23220708, 0x126527ad,   // da.la.ca_422 ug.mk.uz_322  it.oc.ca_443 gd.gv.hu_643 
  0x0758fca7, 0x2d180dec, 0x27fc58a0, 0x06005807,   // zzp.om.it_532 cs.ga.sk_644  om.zzp.gd_322 om.de.un_420 
  0x0300651a, 0x1221180b, 0x58134d14, 0x3f63010b,   // gv.nl.un_760 ar.fa.ur_542  aa.et.om_666 en.sco.af_542 
  // [10480]
  0x6358640c, 0x4d63430c, 0x58004002, 0x581d40a4,   // lg.om.sco_543 ie.sco.aa_543  lb.om.un_220 lb.la.om_433 
  0x1d404c08, 0x1e632508, 0x0201630c, 0x3c4438ec,   // wo.lb.la_443 eu.sco.ms_443  sco.en.da_543 tk.kk.ug_644 
  0x04005804, 0x254c58a0, 0x0c640207, 0x03631304,   // om.fi.un_320 om.wo.eu_322  da.lg.sv_432 et.sco.nl_332 
  0x4c00402b, 0x640f25ee, 0x4c645804, 0x4c58250c,   // lb.wo.un_980 eu.lv.lg_422  om.lg.wo_332 eu.om.wo_543 
  // [10490]
  0x0f041307, 0x64025f11, 0x482338a0, 0x634c0404,   // et.fi.lv_432 tn.da.lg_653  tk.ky.tt_322 fi.wo.sco_332 
  0x55006408, 0x25681307, 0x28341809, 0x04442305,   // lg.rw.un_430 et.ig.eu_432  ar.ps.sd_444 ky.kk.ru_333 
  0x5c005b0c, 0x44231508, 0x19461dee, 0x03002a04,   // sg.sa.un_530 un.ky.kk_443  la.qu.gl_422 mt.nl.un_320 
  0x45001b09, 0x52007313, 0x73000d05, 0x09007305,   // tr.ln.un_440 ny.ha.un_650  cs.ny.un_330 ny.pl.un_330 
  // [104a0]
  0x19651d04, 0x2537230c, 0x28212f08, 0x3b002a05,   // la.gv.gl_332 ky.ba.mn_543  su.jw.sw_443 mt.so.un_330 
  0x01004c02, 0x23003e19, 0x443810a0, 0x10080712,   // wo.en.un_220 rm.ca.un_750  be.tk.kk_322 bg.uk.be_654 
  0x0c100e0c, 0x4600630e, 0x34000207, 0x2d005204,   // is.lt.sv_543 sco.qu.un_550  da.xh.un_420 ha.sk.un_320 
  0x2d006907, 0x3e050f55, 0x15302507, 0x222e230b,   // mfe.sk.un_420 lv.fr.rm_442  mn.uz.un_432 ca.fo.oc_542 
  // [104b0]
  0x3e0f2355, 0x222362ee, 0x0f2305a7, 0x44361508,   // ca.lv.rm_442 kha.ca.oc_422  fr.ca.lv_532 un.ab.kk_443 
  0x2e010f08, 0x075d35ec, 0x35170aad, 0x0a007304,   // lv.en.fo_443 zu.ss.it_644  mk.sr.tg_643 ny.pt.un_320 
  0x48441055, 0x084810a0, 0x36442305, 0x2b006404,   // be.kk.tt_442 be.tt.uk_322  ky.kk.ab_333 lg.vi.un_320 
  0x053e2207, 0x2b3e055a, 0x234430ad, 0x3f006514,   // oc.rm.fr_432 fr.rm.vi_553  uz.kk.ky_643 gv.af.un_660 
  // [104c0]
  0x2b002f12, 0x05222f0c, 0x47353405, 0x53422a08,   // su.vi.un_640 su.oc.fr_543  xh.zu.sn_333 mt.co.ht_443 
  0x55642807, 0x2b3e22ec, 0x28005814, 0x120e4a04,   // sw.lg.rw_432 oc.rm.vi_644  om.sw.un_660 yo.is.hu_332 
  0x585f3b05, 0x22002b14, 0x3f004707, 0x59585507,   // so.tn.om_333 vi.oc.un_660  sn.af.un_420 rw.om.rn_432 
  0x24006021, 0x15002312, 0x065830a4, 0x100817ee,   // vo.eo.un_860 ky.un.un_640  uz.om.de_433 sr.uk.be_422 
  // [104d0]
  0x21555807, 0x57004e14, 0x31000108, 0x0e001c08,   // om.rw.jw_432 ay.na.un_660  en.az.un_430 id.is.un_430 
  0x585d35af, 0x4900560c, 0x20404cee, 0x1d072607,   // zu.ss.om_655 mg.to.un_530  wo.lb.sq_422 ia.it.la_432 
  0xfc564902, 0x4600571a, 0x27631f07, 0x0c002204,   // to.mg.zzp_222 na.qu.un_760  cy.sco.gd_432 oc.sv.un_320 
  0x495a4aa0, 0x40004c0b, 0x5a006720, 0x1707045a,   // yo.sm.to_322 wo.lb.un_520  ak.sm.un_850 ru.bg.sr_553 
  // [104e0]
  0x15043805, 0x693e240c, 0x40381fee, 0x48151713,   // tk.ru.un_333 eo.rm.mfe_543  cy.tk.lb_422 sr.tt.un_650 
  0x401a03a0, 0x100f3b14, 0x4d00570e, 0x1d150107,   // nl.tl.lb_322 so.lv.lt_666  na.aa.un_550 en.la.un_420 
  0x08003804, 0x5a000208, 0xfe003e0d, 0x03004c08,   // tk.no.un_320 da.sm.un_430  rm.tlh.un_540 wo.nl.un_430 
  0x1e1c04a4, 0x29005307, 0x3e003002, 0x10000f2b,   // fi.id.ms_433 ht.sl.un_420  uz.rm.un_220 lv.lt.un_980 
  // [104f0]
  0x4e005814, 0x0c0f0e55, 0x23070a0c, 0x072a0aa4,   // om.ay.un_660 is.lv.sv_442  mk.bg.ky_543 pt.mt.it_433 
  0x233035ad, 0x06002002, 0x0c004902, 0x073e2a07,   // tg.uz.ky_643 sq.de.un_220  to.sv.un_220 mt.rm.it_432 
  0x30003e14, 0x5a005f07, 0x213d28ee, 0x18275caf,   // rm.uz.un_660 tn.sm.un_420  sd.ku.fa_422 sa.gd.ga_655 
  0x18fe2708, 0x233c35af, 0x2c5347a0, 0x48001b19,   // gd.tlh.ga_443 tg.ug.ky_655  sn.ht.fy_322 tr.tt.un_750 
  // [10500]
  0x0d001320, 0x4e300208, 0x063138a0, 0x10373005,   // bh.ne.un_850 da.uz.ay_443  tk.az.de_322 uz.ba.be_333 
  0x4b004007, 0x302537af, 0x48383104, 0x2b3138a0,   // lb.mi.un_420 ba.mn.uz_655  az.tk.tt_332 tk.az.vi_322 
  0x29004805, 0x30383109, 0x314838ad, 0x4c004e0e,   // tt.sl.un_330 az.tk.uz_444  tk.tt.az_643 ay.wo.un_550 
  0x12003412, 0x21281202, 0x15150807, 0x300a170c,   // ps.ur.un_640 ur.sd.fa_222  uk.un.un_420 sr.mk.uz_543 
  // [10510]
  0x0d054207, 0x4c212f08, 0x39450508, 0x233710a0,   // co.fr.cs_432 su.jw.wo_443  fr.ln.br_443 be.ba.ky_322 
  0x041517ad, 0x113517a4, 0x53003402, 0x24002d04,   // sr.ru.un_630 sr.tg.ro_433  xh.ht.un_220 sk.eo.un_320 
  0x3e026907, 0x300415a7, 0x303525ee, 0x2548110e,   // mfe.da.rm_432 un.ru.uz_532  mn.tg.uz_422 ro.tt.mn_555 
  0x48003505, 0x38113ca4, 0x072535ad, 0x3c001505,   // tg.tt.un_330 ug.ro.tk_433  tg.mn.bg_643 un.ug.un_330 
  // [10520]
  0x19002204, 0x5a4c47a4, 0x2c005c04, 0x4b5301a4,   // oc.gl.un_320 sn.wo.sm_433  sa.fy.un_320 en.ht.mi_433 
  0x6500180c, 0x56000e2c, 0x565f5211, 0x790702a9,   // ga.gv.un_530 is.mg.un_990  ha.tn.mg_653 da.it.war_544 
  0x5d504ca7, 0x5a003704, 0x4a001f09, 0x36472713,   // wo.fj.ss_532 st.sm.un_320  cy.yo.un_440 gd.sn.gn_665 
  0x3534490c, 0x556301a0, 0x5a5860af, 0x270501ee,   // to.xh.zu_543 en.sco.rw_322  vo.om.sm_655 en.fr.gd_422 
  // [10530]
  0x4d206909, 0x21003b02, 0x4300630e, 0x18636955,   // mfe.sq.aa_444 so.jw.un_220  sco.ie.un_550 mfe.sco.ga_442 
  0x550705a0, 0x2909feee, 0x2128340e, 0x10001105,   // fr.it.rw_322 tlh.pl.sl_422  ps.sd.fa_555 ro.be.un_330 
  0x5542680c, 0x5a490207, 0x55004c0b, 0x20185aad,   // ig.co.rw_543 da.to.sm_432  wo.rw.un_520 sm.ga.sq_643 
  0xfe690dad, 0x2523480d, 0x3d001804, 0x2000fe14,   // cs.mfe.tlh_643 tt.ky.mn_554  ar.ku.un_320 tlh.sq.un_660 
  // [10540]
  0x30384808, 0x0d2afea0, 0x050115a4, 0x0a1548a4,   // tt.tk.uz_443 tlh.mt.cs_322  un.en.fr_433 tt.mk.un_430 
  0x3e00651b, 0x161245ee, 0x1d006a12, 0x05082009,   // gv.rm.un_770 ln.hu.hr_422  haw.la.un_640 sq.no.fr_444 
  0x3b00500c, 0x2a524f07, 0x21632cee, 0x1f003704,   // fj.so.un_530 bi.ha.mt_432  fy.sco.jw_422 st.cy.un_320 
  0x05371aa7, 0x5c000a04, 0x24001e02, 0x47001113,   // tl.st.fr_532 pt.sa.un_320  ms.eo.un_220 ro.sn.un_650 
  // [10550]
  0x20004d12, 0x3b595d0c, 0x0e00470d, 0x55026007,   // aa.sq.un_640 ss.rn.so_543  sn.is.un_540 vo.da.rw_432 
  0x565a49ad, 0x3e240a08, 0x31004902, 0x0a362407,   // to.sm.mg_643 pt.eo.rm_443  to.az.un_220 eo.gn.pt_432 
  0x0d092955, 0x0d200202, 0x273b18a0, 0x1220320c,   // sl.pl.cs_442 da.sq.cs_222  ga.so.gd_322 bs.sq.hu_543 
  0x0a0748a7, 0x63181ea0, 0x1811230c, 0x2b002009,   // tt.bg.mk_532 ms.ga.sco_322  ca.ro.ga_543 sq.vi.un_440 
  // [10560]
  0x36001f08, 0x06181f04, 0x1f391507, 0x3800311b,   // cy.gn.un_430 cy.ga.de_332  un.br.cy_432 az.tk.un_770 
  0x5e475d0d, 0x34281804, 0x1f63fcad, 0x65002709,   // ss.sn.ts_554 ar.sd.ps_332  zzp.sco.cy_643 gd.gv.un_440 
  0x33002707, 0x1820fc0b, 0xfc00311a, 0x3723480d,   // gd.nn.un_420 zzp.sq.ga_542  az.zzp.un_760 tt.ky.ba_554 
  0x0c001d02, 0x3f3e3807, 0xfc4f5d04, 0x1535360c,   // la.sv.un_220 tk.rm.af_432  ss.bi.zzp_332 ab.tg.un_543 
  // [10570]
  0xfe005113, 0x3c2128a4, 0x3531fe04, 0x3600152a,   // kl.tlh.un_650 sd.fa.ug_433  tlh.az.zu_332 un.ab.un_970 
  0x0e2e5da4, 0x4400100e, 0x15170aa9, 0x3d233c12,   // ss.fo.is_433 be.kk.un_550  mk.sr.un_544 ug.ky.ku_654 
  0x48002b02, 0x321636a0, 0x5a004a09, 0x25685704,   // vi.tt.un_220 gn.hr.bs_322  yo.sm.un_440 na.ig.eu_332 
  0x48383709, 0x3b001c0d, 0x1c000504, 0x080c3312,   // ba.tk.tt_444 mr.ks.un_540  fr.id.un_320 nn.sv.no_654 
  // [10580]
  0x131c5ca9, 0x3025040c, 0x2900320d, 0x10002502,   // sa.mr.bh_544 ru.mn.uz_543  bs.sl.un_540 mn.be.un_220 
  0x5c091c55, 0x5c004c08, 0x5c00100b, 0x64005f12,   // mr.hi.sa_442 wo.sa.un_430  lt.sa.un_520 tn.lg.un_640 
  0x5d785f0c, 0x4823350d, 0x353478a4, 0x443823a7,   // tn.ve.ss_543 tg.ky.tt_554  ve.xh.zu_433 ky.tk.kk_532 
  0x5d3537a4, 0x5d346408, 0x391d08a4, 0x1f005f18,   // st.zu.ss_433 lg.xh.ss_443  no.la.br_433 tn.cy.un_740 
  // [10590]
  0x1f003404, 0x33086309, 0x35006409, 0x12002811,   // xh.cy.un_320 sco.no.nn_444  lg.zu.un_440 sd.ur.un_630 
  0x09643f02, 0x650701ee, 0x301228a9, 0x0653fca4,   // af.lg.pl_222 en.it.gv_422  sd.ur.uz_544 zzp.ht.de_433 
  0x1f0935a4, 0x480817a7, 0x371f5f08, 0x3711440c,   // zu.pl.cy_433 sr.uk.tt_532  tn.cy.st_443 kk.ro.ba_543 
  0x37345f55, 0x25113507, 0x2c000c04, 0x1d000705,   // tn.xh.st_442 tg.ro.mn_432  sv.fy.un_320 it.la.un_330 
  // [105a0]
  0x48313baf, 0x440810af, 0x2f005a04, 0x0d531007,   // so.az.tt_655 be.uk.kk_655  sm.su.un_320 lt.ht.cs_432 
  0x04081555, 0x2d2910a9, 0xfc5a4907, 0x5f370d02,   // un.uk.ru_442 lt.sl.sk_544  to.sm.zzp_432 cs.st.tn_222 
  0x292d10a6, 0x442310ad, 0x2b1263a0, 0x350a070b,   // lt.sk.sl_521 be.ky.kk_643  sco.hu.vi_322 bg.mk.tg_542 
  0x0d00600c, 0x30003421, 0x23002708, 0x160f4b55,   // vo.cs.un_530 ps.uz.un_860  gd.ca.un_430 mi.lv.hr_442 
  // [105b0]
  0x3744380d, 0x36003821, 0x050145a0, 0x46021507,   // tk.kk.ba_554 tk.ab.un_860  ln.en.fr_322 un.da.qu_432 
  0x302134a9, 0x12180502, 0x6100220e, 0x25234407,   // ps.fa.uz_544 fr.ga.hu_222  oc.za.un_550 kk.ky.mn_432 
  0x28341208, 0x2400630b, 0x1d006207, 0x22000b02,   // ur.ps.sd_443 sco.eo.un_520  kha.la.un_420 es.oc.un_220 
  0x48233007, 0x5c000f20, 0x3525370d, 0x34303d07,   // uz.ky.tt_432 lv.sa.un_850  ba.mn.tg_554 ku.uz.ps_432 
  // [105c0]
  0x38002d12, 0x36001705, 0x0a351502, 0x1b31480c,   // sk.tk.un_640 sr.ab.un_330  un.tg.mk_222 tt.az.tr_543 
  0x0a2317a7, 0x2b003b08, 0x15070aa4, 0x65fc4fac,   // sr.ky.mk_532 so.vi.un_430  mk.bg.un_433 bi.zzp.gv_632 
  0x4837230b, 0x65203013, 0x282130ad, 0x40153304,   // ky.ba.tt_542 uz.sq.gv_665  uz.fa.sd_643 nn.lb.un_320 
  0x220a2302, 0x461c1202, 0x632f1cee, 0xfefc120e,   // ca.pt.oc_222 hu.id.qu_222  id.su.sco_422 hu.zzp.tlh_555 
  // [105d0]
  0x2e150ea9, 0x08110705, 0x306520a0, 0x01002002,   // is.fo.un_540 bg.ro.uk_333  sq.gv.uz_322 sq.en.un_220 
  0x103715a4, 0x40001d02, 0x181c7904, 0x01006704,   // un.ba.be_433 la.lb.un_220  war.id.ga_332 ak.en.un_320 
  0x0a08350c, 0x55004908, 0x2e00360c, 0x37304814,   // tg.uk.mk_543 to.rw.un_430  gn.fo.un_530 tt.uz.ba_666 
  0x0d2d1211, 0x3d211255, 0x44303505, 0x2344120c,   // hu.sk.cs_653 ur.fa.ku_442  tg.uz.kk_333 ur.kk.ky_543 
  // [105e0]
  0x48302313, 0x021943ee, 0x5a003702, 0x345d3605,   // ky.uz.tt_665 ie.gl.da_422  st.sm.un_220 gn.ss.xh_333 
  0x4a00361a, 0x212c64ec, 0x644a3612, 0x47003505,   // gn.yo.un_760 lg.fy.jw_644  gn.yo.lg_654 zu.sn.un_330 
  0x36113855, 0x2e002002, 0x2100390c, 0x64007312,   // tk.ro.ab_442 sq.fo.un_220  br.jw.un_530 ny.lg.un_640 
  0x170a07a7, 0x5a00041a, 0x282118ad, 0x384823a4,   // bg.mk.sr_532 fi.sm.un_760  ar.fa.sd_643 ky.tt.tk_433 
  // [105f0]
  0x10212f07, 0x731d5aee, 0x48641ba9, 0x53002c0c,   // su.jw.lt_432 sm.la.ny_422  tr.lg.tt_544 fy.ht.un_530 
  0x170a15a4, 0x3538230d, 0x4d423b13, 0x1c2a2f0c,   // un.mk.sr_433 ky.tk.tg_554  so.co.aa_665 su.mt.id_543 
  0x1f2909ee, 0x214d730c, 0x4728730c, 0x32384504,   // pl.sl.cy_422 ny.aa.jw_543  ny.sw.sn_543 ln.tk.bs_332 
  0x15043608, 0x02006018, 0x28503307, 0x5c56680c,   // ab.ru.un_443 vo.da.un_740  nn.fj.sw_432 ig.mg.sa_543 
  // [10600]
  0x5e5d2512, 0x6b001e0d, 0x3b464da4, 0x42005e1b,   // eu.ss.ts_654 ms.ceb.un_540  aa.qu.so_433 ts.co.un_770 
  0x732f2107, 0x1a212fa9, 0x3723380c, 0x5d0c4508,   // jw.su.ny_432 su.jw.tl_544  tk.ky.ba_543 ln.sv.ss_443 
  0x200b0a08, 0x30003111, 0x48002008, 0x5c004604,   // pt.es.sq_443 az.uz.un_630  sq.tt.un_430 qu.sa.un_320 
  0x1a6b5c08, 0x25235e0c, 0x735768ec, 0x31482aa0,   // sa.ceb.tl_443 ts.ca.eu_543  ig.na.ny_644 mt.tt.az_322 
  // [10610]
  0x49002304, 0x251e225a, 0x3b002308, 0x0e000902,   // ca.to.un_320 oc.ms.eu_553  ky.ks.un_430 pl.is.un_220 
  0xfe003008, 0x46313004, 0x48303113, 0x4408100c,   // uz.tlh.un_430 uz.az.qu_332  az.uz.tt_665 be.uk.kk_543 
  0x0c0e1504, 0x25634ba0, 0x5f371fa9, 0x3c443712,   // un.is.sv_332 mi.sco.eu_322  cy.st.tn_544 ba.kk.ug_654 
  0x5f4b1f07, 0x4b493609, 0x0710305a, 0x5f1f75a4,   // cy.mi.tn_432 gn.to.mi_444  uz.be.bg_553 nso.cy.tn_433 
  // [10620]
  0x5a004f0c, 0x3b12300c, 0x754b1f13, 0x5c5748ad,   // bi.sm.un_530 uz.ur.ks_543  cy.mi.nso_665 tt.na.sa_643 
  0x37001005, 0x691d1faf, 0x48004c07, 0x4f5f3713,   // be.ba.un_330 cy.la.mfe_655  wo.tt.un_420 st.tn.bi_665 
  0x36004b11, 0x0b384cee, 0x170835af, 0x10111507,   // mi.gn.un_630 wo.tk.es_422  tg.uk.sr_655 un.ro.be_432 
  0x38004c12, 0x153023a4, 0x1828120b, 0x10382507,   // wo.tk.un_640 ky.uz.un_433  ur.sd.ar_542 mn.tk.be_432 
  // [10630]
  0x443c30af, 0x08150aa4, 0x23651d07, 0x08353004,   // uz.ug.kk_655 mk.uk.un_430  la.gv.ca_432 uz.tg.uk_332 
  0x100a08a0, 0x25443002, 0x36121904, 0xfc003509,   // uk.mk.be_322 uz.kk.mn_222  gl.hu.gn_332 zu.zzp.un_440 
  0x16203207, 0x15002b09, 0x44003835, 0x79000209,   // bs.sq.hr_432 vi.un.un_440  tk.kk.un_A90 da.war.un_440 
  0x1b3860ad, 0x1715380e, 0x1b003e0e, 0x0a040805,   // vo.tk.tr_643 tk.sr.un_550  rm.tr.un_550 uk.ru.mk_333 
  // [10640]
  0x34001c02, 0x345e4cad, 0x13005c1b, 0x346435a9,   // id.xh.un_220 wo.ts.xh_643  sa.bh.un_770 zu.lg.xh_544 
  0xfe6b3755, 0x45375fec, 0x1f5f37a9, 0x1b384807,   // st.ceb.tlh_442 tn.st.ln_644  st.tn.cy_544 tt.tk.tr_432 
  0xfc4b6a04, 0x561149ac, 0x2f4b455a, 0x375f5e60,   // haw.mi.zzp_332 to.ro.mg_632  ln.mi.su_553 ts.tn.st_664 
  0x684c04ad, 0x75005d0c, 0x58fc1312, 0x4800101a,   // fi.wo.ig_643 ss.nso.un_530  et.zzp.om_654 lt.tt.un_760 
  // [10650]
  0x09002e0c, 0x5a004b05, 0x11070d0c, 0x5efc5d08,   // fo.pl.un_530 mi.sm.un_330  cs.it.ro_543 ss.zzp.ts_443 
  0x75fc5f09, 0x203073ee, 0x59307307, 0x37355f0c,   // tn.zzp.nso_444 ny.uz.sq_422  ny.uz.rn_432 tn.zu.st_543 
  0x0a10175a, 0x3534fc02, 0x46000e04, 0x352251a7,   // sr.be.mk_553 zzp.xh.zu_222  is.qu.un_320 kl.oc.zu_532 
  0x04005021, 0x69760107, 0x3b3058ec, 0x64477307,   // fj.fi.un_860 en.crs.mfe_432  om.uz.so_644 ny.sn.lg_432 
  // [10660]
  0x4322010c, 0x28213405, 0x3c30380d, 0xfc350102,   // en.oc.ie_543 ps.fa.sd_333  tk.uz.ug_554 en.zu.zzp_222 
  0x33003b02, 0x25003709, 0x21183b0c, 0x43190b0e,   // so.nn.un_220 ba.mn.un_440  ks.ar.fa_543 es.gl.ie_555 
  0x28126911, 0x28005612, 0x604501a4, 0x01fe6ba0,   // mfe.hu.sw_653 mg.sw.un_640  en.ln.vo_433 ceb.tlh.en_322 
  0x4d755f60, 0x18000e04, 0x233d3405, 0x29001102,   // tn.nso.aa_664 is.ga.un_320  ps.ku.ky_333 ro.sl.un_220 
  // [10670]
  0x60246108, 0x075efca7, 0x785e5b09, 0x634a56a9,   // za.eo.vo_443 zzp.ts.it_532  sg.ts.ve_444 mg.yo.sco_544 
  0x400906a6, 0x29001014, 0x1c1309ac, 0x353439a9,   // de.pl.lb_521 lt.sl.un_660  hi.bh.mr_632 br.xh.zu_544 
  0x36001114, 0x08001204, 0x1c1065a9, 0x380423af,   // ro.ab.un_660 hu.no.un_320  gv.lt.id_544 ky.ru.tk_655 
  0x4d420708, 0x3f4a1204, 0x48564904, 0x3500330d,   // it.co.aa_443 hu.yo.af_332  to.mg.tt_332 nn.zu.un_540 
  // [10680]
  0x395e2a07, 0x172308a4, 0x0c630607, 0x40652da0,   // mt.ts.br_432 uk.ky.sr_433  de.sco.sv_432 sk.gv.lb_322 
  0x15041507, 0x3f030ca9, 0x3c003d0e, 0x190a22a9,   // un.ru.un_432 sv.nl.af_544  ku.ug.un_550 oc.pt.gl_544 
  0x044425a0, 0x30213dec, 0x2530235a, 0x10004b12,   // mn.kk.ru_322 ku.fa.uz_644  ky.uz.mn_553 mi.lt.un_640 
  0x362d1208, 0x04081514, 0x30383112, 0x1a02690c,   // hu.sk.gn_443 un.uk.ru_666  az.tk.uz_654 mfe.da.tl_543 
  // [10690]
  0x31383012, 0x3800301b, 0x38303108, 0x2000fe13,   // uz.tk.az_654 uz.tk.un_770  az.uz.tk_443 tlh.sq.un_650 
  0x3831300c, 0x1a3038ad, 0x18283405, 0x18002120,   // uz.az.tk_543 tk.uz.tl_643  ps.sd.ar_333 fa.ar.un_850 
  0x4831300b, 0x2b3130a0, 0x38001a05, 0x311b3809,   // uz.az.tt_542 uz.az.vi_322  tl.tk.un_330 tk.tr.az_444 
  0x1d3b30a0, 0x190b4602, 0x18283ba0, 0x400702a0,   // uz.so.la_322 qu.es.gl_222  ks.sd.ar_322 da.it.lb_322 
  // [106a0]
  0x374823af, 0x44303555, 0x242529ee, 0x15361508,   // ky.tt.ba_655 tg.uz.kk_442  sl.eu.eo_422 un.ab.un_443 
  0x011502ad, 0x0a0817af, 0x28005304, 0x4800130e,   // da.en.un_630 sr.uk.mk_655  ht.sw.un_320 et.tt.un_550 
  0x13040ca7, 0x17353002, 0x38234808, 0x443525af,   // sv.fi.et_532 uz.tg.sr_222  tt.ky.tk_443 mn.tg.kk_655 
  0x7900280d, 0x28005005, 0x1632170c, 0xfe10620c,   // sw.war.un_540 fj.sw.un_330  sr.bs.hr_543 kha.lt.tlh_543 
  // [106b0]
  0x2330150b, 0x103b0fad, 0x05033f04, 0x28183da0,   // un.uz.ky_542 lv.so.lt_643  af.nl.fr_332 ku.ar.sd_322 
  0x321702a0, 0x59551ea0, 0x632efc07, 0x651857ee,   // da.sr.bs_322 ms.rw.rn_322  zzp.fo.sco_432 na.ga.gv_422 
  0x342cfcee, 0x656330ee, 0x012b12a6, 0x190b0702,   // zzp.fy.xh_422 uz.sco.gv_422  hu.vi.en_521 it.es.gl_222 
  0x2530360c, 0x4f001005, 0x4c00fe0d, 0x736435ee,   // ab.uz.mn_543 lt.bi.un_330  tlh.wo.un_540 zu.lg.ny_422 
  // [106c0]
  0x674012a4, 0x55fe640c, 0x4013fc12, 0x1b0e120c,   // hu.lb.ak_433 lg.tlh.rw_543  zzp.et.lb_654 hu.is.tr_543 
  0x10002518, 0x101b3855, 0x2a5c0704, 0x05060304,   // mn.be.un_740 tk.tr.lt_442  it.sa.mt_332 nl.de.fr_332 
  0x0715480c, 0x19000a0b, 0x38000804, 0x18355302,   // tt.bg.un_530 pt.gl.un_520  no.tk.un_320 ht.zu.ga_222 
  0x345d3507, 0x2f002112, 0x3f1f01a0, 0x011b0ea0,   // zu.ss.xh_432 jw.su.un_640  en.cy.af_322 is.tr.en_322 
  // [106d0]
  0x42431da4, 0x4a00fe12, 0x73005e04, 0x381007ad,   // la.ie.co_433 tlh.yo.un_640  ts.ny.un_320 bg.be.tk_643 
  0x281218a6, 0x2000231b, 0x5a504aad, 0x3c3034a9,   // ar.ur.sd_521 ca.sq.un_770  yo.fj.sm_643 ps.uz.ug_544 
  0x40005a22, 0x252c01a4, 0x18651f04, 0x23600a04,   // sm.lb.un_870 en.fy.eu_433  cy.gv.ga_332 pt.vo.ca_332 
  0x65620204, 0x32003e04, 0x48312308, 0x123b3d11,   // da.kha.gv_332 rm.bs.un_320  ca.az.tt_443 ku.ks.ur_653 
  // [106e0]
  0x190a1809, 0x53223904, 0x0b1918a4, 0x5f007523,   // ga.pt.gl_444 br.oc.ht_332  ga.gl.es_433 nso.tn.un_880 
  0x15001005, 0x0b120a5a, 0x3618120c, 0x51254005,   // lt.un.un_330 pt.hu.es_553  hu.ga.gn_543 lb.eu.kl_333 
  0x222825a4, 0x400225a7, 0x04071007, 0x030625a0,   // eu.sw.oc_433 eu.da.lb_532  be.bg.ru_432 eu.de.nl_322 
  0x252240ad, 0x19120aa7, 0x090a2da4, 0x343b3d0c,   // lb.oc.eu_643 pt.hu.gl_532  sk.pt.pl_433 ku.ks.ps_543 
  // [106f0]
  0x15482309, 0x5e005f08, 0x3d3034a0, 0x10383505,   // ky.tt.un_444 tn.ts.un_430  ps.uz.ku_322 tg.tk.be_333 
  0x22004012, 0x21123460, 0x28443c04, 0x2f004c0c,   // lb.oc.un_640 ps.ur.fa_664  ug.kk.sd_332 wo.su.un_530 
  0x0560010c, 0x3e003f14, 0x2c033fa7, 0x233e0107,   // en.vo.fr_543 af.rm.un_660  af.nl.fy_532 en.rm.ca_432 
  0x3f03230e, 0x150301a0, 0x23150805, 0x30002b02,   // ca.nl.af_555 en.nl.un_322  uk.ky.un_330 vi.uz.un_220 
  // [10700]
  0x3e230fa0, 0x4600730d, 0x3e2c03a0, 0x033e010b,   // lv.ca.rm_322 ny.qu.un_540  nl.fy.rm_322 en.rm.nl_542 
  0x05150107, 0x37041512, 0x3f230507, 0x632c3f09,   // en.fr.un_420 un.ru.ba_654  fr.ca.af_432 af.fy.sco_444 
  0x05603f05, 0x071538a4, 0x44361555, 0x12001f05,   // af.vo.fr_333 tk.bg.un_430  un.ab.kk_442 cy.hu.un_330 
  0x0a5d1804, 0x091769a7, 0x530c6b02, 0x307921ee,   // ga.ss.pt_332 mfe.sr.pl_532  ceb.sv.ht_222 jw.war.uz_422 
  // [10710]
  0x01640f04, 0x4a222112, 0x290910a9, 0x2f1502ec,   // lv.lg.en_332 jw.oc.yo_654  lt.pl.sl_544 da.su.un_640 
  0x0a11170c, 0x2b021504, 0x183d21ee, 0x1f004602,   // sr.ro.mk_543 un.da.vi_332  fa.ku.ar_422 qu.cy.un_220 
  0x23192204, 0x0e182e0c, 0x7500602a, 0x2d0d1905,   // oc.gl.ca_332 fo.ga.is_543  vo.nso.un_970 gl.cs.sk_333 
  0x2a784a04, 0x49000c02, 0x13002802, 0x330258a0,   // yo.ve.mt_332 sv.to.un_220  sw.et.un_220 om.da.nn_322 
  // [10720]
  0x1d064008, 0x0200081a, 0x19633504, 0x1022fc0b,   // lb.de.la_443 no.da.un_760  zu.sco.gl_332 zzp.oc.lt_542 
  0x3e476555, 0x564c1bad, 0x0e192d05, 0x063f40a0,   // gv.sn.rm_442 tr.wo.mg_643  sk.gl.is_333 lb.af.de_322 
  0xfe006114, 0x17495aee, 0x03002c09, 0x1f002309,   // za.tlh.un_660 sm.to.sr_422  fy.nl.un_440 ca.cy.un_440 
  0x35005607, 0x190b11a0, 0x030506a0, 0x1d000314,   // mg.zu.un_420 ro.es.gl_322  de.fr.nl_322 nl.la.un_660 
  // [10730]
  0x20352807, 0x052b53a0, 0x23005a02, 0x1d2122ee,   // sw.zu.sq_432 ht.vi.fr_322  sm.ca.un_220 oc.jw.la_422 
  0x423905a4, 0x091f64a4, 0xfc375f0c, 0x3956fc0c,   // fr.br.co_433 lg.cy.pl_433  tn.st.zzp_543 zzp.mg.br_543 
  0x67005619, 0x1f0361ee, 0x3c303807, 0x07264304,   // mg.ak.un_750 za.nl.cy_422  tk.uz.ug_432 ie.ia.it_332 
  0x1b003907, 0x391d05a0, 0x016b5805, 0x3b003e07,   // br.tr.un_420 fr.la.br_322  om.ceb.en_333 rm.so.un_420 
  // [10740]
  0x28123bec, 0x3401180c, 0x320517ee, 0x4823380c,   // ks.ur.sd_644 ar.iw.ps_543  sr.fr.bs_422 tk.ky.tt_543 
  0x033f0605, 0x21123060, 0x1d000508, 0x480711a7,   // de.af.nl_333 uz.ur.fa_664  fr.la.un_430 ro.bg.tt_532 
  0x18283409, 0x362d0d5a, 0x635a62a9, 0x36006504,   // ps.sd.ar_444 cs.sk.gn_553  kha.sm.sco_544 gv.gn.un_320 
  0x2f000d08, 0xfc2718a9, 0x52003304, 0x0e2e2c04,   // cs.su.un_430 ga.gd.zzp_544  nn.ha.un_320 fy.fo.is_332 
  // [10750]
  0x484c3ba4, 0x25003623, 0x31464da4, 0x35483755,   // so.wo.tt_433 ab.mn.un_880  aa.qu.az_433 ba.tt.tg_442 
  0x48001c04, 0x214954ee, 0x040a0811, 0x3000110e,   // id.tt.un_320 ik.to.jw_422  uk.mk.ru_653 ro.uz.un_550 
  0x0e361904, 0x152315a0, 0x31351baf, 0x1b382505,   // gl.gn.is_332 un.ky.un_322  tr.zu.az_655 eu.tk.tr_333 
  0x11004008, 0x31003304, 0x0b231904, 0x061757ee,   // lb.ro.un_430 nn.az.un_320  gl.ca.es_332 na.sr.de_422 
  // [10760]
  0x113161a7, 0x15100807, 0x23000709, 0x05251107,   // za.az.ro_532 uk.be.un_432  bg.ky.un_440 ro.eu.fr_432 
  0x15000705, 0x0a1209a0, 0x301b4807, 0x30311baf,   // bg.un.un_330 pl.hu.pt_322  tt.tr.uz_432 tr.az.uz_655 
  0x35342da0, 0x583f03a9, 0x34136707, 0x4c000302,   // sk.xh.zu_322 nl.af.om_544  ak.et.xh_432 nl.wo.un_220 
  0x31251b5a, 0x13003b21, 0x3700110e, 0x3b652c12,   // tr.eu.az_553 so.et.un_860  ro.ba.un_550 fy.gv.so_654 
  // [10770]
  0x61311b05, 0x0a381ba0, 0x64653b0c, 0x30253855,   // tr.az.za_333 tr.tk.pt_322  so.gv.lg_543 tk.mn.uz_442 
  0x651d640c, 0x034c3f09, 0x3823300d, 0xfc6b59a0,   // lg.la.gv_543 af.wo.nl_444  uz.ky.tk_554 rn.ceb.zzp_322 
  0x05000405, 0x06011507, 0x2e29100c, 0x1c006504,   // fi.fr.un_330 un.en.de_432  lt.sl.fo_543 gv.id.un_320 
  0xfc003602, 0x441537a4, 0x122d4d0b, 0x12007308,   // gn.zzp.un_220 ba.kk.un_430  aa.sk.hu_542 ny.hu.un_430 
  // [10780]
  0x36fc210d, 0x370448ee, 0x133f4cee, 0x3308110c,   // jw.zzp.gn_554 tt.ru.ba_422  wo.af.et_422 ro.no.nn_543 
  0x3f006e07, 0x1d003608, 0x0a041509, 0x65091302,   // hmn.af.un_420 gn.la.un_430  un.ru.mk_444 et.pl.gv_222 
  0x3e000c07, 0x031365a0, 0x65000204, 0x2a00200c,   // sv.rm.un_420 gv.et.nl_322  da.gv.un_320 sq.mt.un_530 
  0x220a2313, 0x3425fc07, 0x192e0a04, 0x302325a4,   // ca.pt.oc_665 zzp.eu.xh_432  pt.fo.gl_332 mn.ky.uz_433 
  // [10790]
  0x122e0ea7, 0x16002f05, 0x2e000a02, 0x36002208,   // is.fo.hu_532 su.hr.un_330  pt.fo.un_220 oc.gn.un_430 
  0x34011808, 0x30181207, 0x40053902, 0x3f0502ee,   // ar.iw.ps_443 ur.ar.uz_432  br.fr.lb_222 da.fr.af_422 
  0x64320907, 0x1d5564a9, 0x49500d07, 0x0e122e02,   // pl.bs.lg_432 lg.rw.la_544  cs.fj.to_432 fo.hu.is_222 
  0x11004b02, 0x01002d02, 0x244e46ec, 0x11005108,   // mi.ro.un_220 sk.en.un_220  qu.ay.eo_644 kl.ro.un_430 
  // [107a0]
  0x4b0f5ca9, 0x52504ea9, 0x3e001105, 0x460752a0,   // sa.lv.mi_544 ay.fj.ha_544  ro.rm.un_330 ha.it.qu_322 
  0x5859550d, 0x05192fee, 0x50025aec, 0x0e002302,   // rw.rn.om_554 su.gl.fr_422  sm.da.fj_644 ca.is.un_220 
  0x794309a9, 0x11074209, 0x2d000b07, 0x36002202,   // pl.ie.war_544 co.it.ro_444  es.sk.un_420 oc.gn.un_220 
  0x390940ad, 0x12421108, 0x555647ee, 0x040a36a0,   // lb.pl.br_643 ro.co.hu_443  sn.mg.rw_422 ab.mk.ru_322 
  // [107b0]
  0x0415175a, 0x1107500c, 0x030758a0, 0x6700500d,   // sr.ru.un_530 fj.it.ro_543  om.it.nl_322 fj.ak.un_540 
  0x511d5a05, 0x594e1ca4, 0x58001f02, 0x464e280d,   // sm.la.kl_333 id.ay.rn_433  cy.om.un_220 sw.ay.qu_554 
  0x3b464e5a, 0x29160da4, 0x7915090d, 0xfa3f5d5a,   // ay.qu.so_553 cs.hr.sl_433  pl.war.un_540 ss.af.nr_553 
  0x02075807, 0x371504ad, 0x190e2e18, 0x15151005,   // om.it.da_432 ru.ba.un_630  fo.is.gl_764 be.un.un_330 
  // [107c0]
  0x2e122dee, 0x345f3fa7, 0x301710a0, 0x44151511,   // sk.hu.fo_422 af.tn.xh_532  be.sr.uz_322 un.kk.un_630 
  0x332a2c07, 0x2c000209, 0x342344ee, 0x0d1c09ac,   // fy.mt.nn_432 da.fy.un_440  kk.ky.ps_422 hi.mr.ne_632 
  0x482315a9, 0x443530a7, 0x37111555, 0x1518060c,   // un.ky.tt_544 uz.tg.kk_532  un.ro.ba_442 de.ga.un_543 
  0x06261112, 0x18283da6, 0x085865a0, 0x304448a0,   // ro.ia.de_654 ku.sd.ar_521  gv.om.no_322 tt.kk.uz_322 
  // [107d0]
  0x3c3648a9, 0x0e002b07, 0xfc006507, 0x0d003802,   // tt.ab.ug_544 vi.is.un_420  gv.zzp.un_420 tk.cs.un_220 
  0x19180a04, 0x300a3c07, 0x52001704, 0x28005202,   // pt.ga.gl_332 ug.mk.uz_432  sr.ha.un_320 ha.sw.un_220 
  0x55005208, 0x21552f04, 0x55001b02, 0x18002833,   // ha.rw.un_430 su.rw.jw_332  tr.rw.un_220 sd.ar.un_A70 
  0x58523bec, 0x0a3510ad, 0x5c000d23, 0x39401fa0,   // so.ha.om_644 be.tg.mk_643  ne.sa.un_880 cy.lb.br_322 
  // [107e0]
  0x31006313, 0x3e3413a0, 0x150407a9, 0x1e006112,   // sco.az.un_650 et.xh.rm_322  bg.ru.un_544 za.ms.un_640 
  0x35fc4507, 0x1e691ca4, 0x5345fc14, 0x3e330802,   // ln.zzp.zu_432 id.mfe.ms_433  zzp.ln.ht_666 no.nn.rm_222 
  0x48370704, 0x481525ad, 0x68354504, 0x170407ee,   // bg.ba.tt_332 mn.tt.un_630  ln.zu.ig_332 bg.ru.sr_422 
  0x1d642aa0, 0x240d29ee, 0x5a35345a, 0x15380aec,   // mt.lg.la_322 sl.cs.eo_422  xh.zu.sm_553 mk.tk.un_644 
  // [107f0]
  0x0744110c, 0x4c001f13, 0x534f470c, 0x34183d0e,   // ro.kk.bg_543 cy.wo.un_650  sn.bi.ht_543 ku.ar.ps_555 
  0x0c00020c, 0x4d01fc60, 0x1f004719, 0x34123512,   // da.sv.un_530 zzp.en.aa_664  sn.cy.un_750 zu.hu.xh_654 
  0x07005718, 0x123c2308, 0x10004807, 0x27003b0c,   // na.it.un_740 ky.ug.ur_443  tt.be.un_420 so.gd.un_530 
  0x3638440c, 0x283d18a0, 0x130d5c11, 0x100d29a0,   // kk.tk.ab_543 ar.ku.sd_322  sa.ne.bh_653 sl.cs.lt_322 
  
  // [10800]
  0x02652704, 0x18000d08, 0x0402640c, 0x73006e12,   // gd.gv.da_332 cs.ga.un_430  lg.da.fi_543 hmn.ny.un_640 
  0x2a102da0, 0x06001b12, 0x2a281804, 0x4f61fc0c,   // sk.lt.mt_322 tr.de.un_640  ga.sw.mt_332 zzp.za.bi_543 
  0x22532109, 0x081525a4, 0x764760ad, 0x38172508,   // jw.ht.oc_444 mn.uk.un_430  vo.sn.crs_643 mn.sr.tk_443 
  0x21023204, 0x355d36a9, 0x12003b02, 0x042a5707,   // bs.da.jw_332 gn.ss.zu_544  so.hu.un_220 na.mt.fi_432 
  // [10810]
  0x0a180e0c, 0x5c002102, 0x04355502, 0x33081305,   // is.ga.pt_543 jw.sa.un_220  rw.zu.fi_222 et.no.nn_333 
  0x2800020c, 0x20304604, 0x0d004602, 0x45000607,   // da.sw.un_530 qu.uz.sq_332  qu.cs.un_220 de.ln.un_420 
  0x061d25a0, 0x10006402, 0x3b005505, 0x1d0504ee,   // eu.la.de_322 lg.lt.un_220  rw.so.un_330 fi.fr.la_422 
  0x420405a4, 0x1d000505, 0x28595507, 0x0d005502,   // fr.fi.co_433 fr.la.un_330  rw.rn.sw_432 rw.cs.un_220 
  // [10820]
  0x03023fa0, 0x25284707, 0x572878a4, 0x2e060e07,   // af.da.nl_322 sn.sw.eu_432  ve.sw.na_433 is.de.fo_432 
  0x1d3e05ee, 0x6400570e, 0x04252f02, 0x04294355,   // fr.rm.la_422 na.lg.un_550  su.eu.fi_222 ie.sl.fi_442 
  0x362801a0, 0x55292804, 0x352308a0, 0x1d4630a0,   // en.sw.gn_322 sw.sl.rw_332  uk.ky.tg_322 uz.qu.la_322 
  0x30283bee, 0x5c1e2fa0, 0x21002312, 0x2d102902,   // so.sw.uz_422 su.ms.sa_322  ky.fa.un_640 sl.lt.sk_222 
  // [10830]
  0x033f0407, 0x17070402, 0x4d004e1a, 0x10005c04,   // fi.af.nl_432 ru.bg.sr_222  ay.aa.un_760 sa.lt.un_320 
  0x17602d07, 0x08104407, 0x1d003302, 0x34204d60,   // sk.vo.sr_432 kk.be.uk_432  nn.la.un_220 aa.sq.xh_664 
  0x01006008, 0x203534a9, 0x10000a02, 0x07374807,   // vo.en.un_430 xh.zu.sq_544  mk.be.un_220 tt.ba.bg_432 
  0x444838a4, 0x79071505, 0x052322a4, 0x321629a9,   // tk.tt.kk_433 un.it.war_333  oc.ca.fr_433 sl.hr.bs_544 
  // [10840]
  0x09001821, 0x3e00060d, 0x343b18ad, 0x495a08a4,   // ar.hi.un_860 de.rm.un_540  ar.ks.ps_643 no.sm.to_433 
  0x100a170c, 0x056301a9, 0x1a20530c, 0x483637ee,   // sr.mk.be_543 en.sco.fr_544  ht.sq.tl_543 ba.ab.tt_422 
  0x670545a4, 0x0c004f13, 0x180c57a7, 0x49fc3655,   // ln.fr.ak_433 bi.sv.un_650  na.sv.ga_532 gn.zzp.to_442 
  0x401518a0, 0x3f002007, 0x0e22275a, 0x0b221907,   // ga.lb.un_320 sq.af.un_420  gd.oc.is_553 gl.oc.es_432 
  // [10850]
  0x1e1d4360, 0x2f00230c, 0x420653a7, 0x67766908,   // ie.la.ms_664 ca.su.un_530  ht.de.co_532 mfe.crs.ak_443 
  0x286953a4, 0x53002634, 0x4000570c, 0x67002822,   // ht.mfe.sw_433 ia.ht.un_A80  na.lb.un_530 sw.ak.un_870 
  0x34003b07, 0x28003614, 0x234838af, 0x0f161707,   // ks.ps.un_420 gn.sw.un_660  tk.tt.ky_655 sr.hr.lv_432 
  0x22330802, 0x05032f08, 0x3f05030c, 0x2b152fa7,   // no.nn.oc_222 su.nl.fr_443  nl.fr.af_543 su.vi.un_520 
  // [10860]
  0x34183c13, 0x053e2f07, 0x1135300c, 0x290d3202,   // ug.ar.ps_665 su.rm.fr_432  uz.tg.ro_543 bs.cs.sl_222 
  0x3e054907, 0x3c30150c, 0x0a041514, 0x3e0305ee,   // to.fr.rm_432 un.uz.ug_543  un.ru.mk_666 fr.nl.rm_422 
  0x42020555, 0x131b31ad, 0x221d1ca0, 0x3e261dec,   // fr.da.co_442 az.tr.et_643  id.la.oc_322 la.ia.rm_644 
  0x253e0502, 0x380717af, 0x2200fc0e, 0x2f0305ec,   // fr.rm.eu_222 sr.bg.tk_655  zzp.oc.un_550 fr.nl.su_644 
  // [10870]
  0x222f0508, 0x07080460, 0x4808040c, 0x252205a0,   // fr.su.oc_443 ru.uk.bg_664  ru.uk.tt_543 fr.oc.eu_322 
  0x48233c08, 0x53033fee, 0x042311ad, 0x351730ee,   // ug.ky.tt_443 af.nl.ht_422  ro.ky.ru_643 uz.sr.tg_422 
  0x171008a4, 0x3023350c, 0x30343d0b, 0x091c5cac,   // uk.be.sr_433 tg.ky.uz_543  ku.ps.uz_542 sa.mr.hi_632 
  0x390928ee, 0x08153607, 0x302118a0, 0x5f005a0c,   // sw.pl.br_422 ab.uk.un_420  ar.fa.uz_322 sm.tn.un_530 
  // [10880]
  0x04234405, 0x0a2301a0, 0x15070a14, 0x5a002722,   // kk.ky.ru_333 en.ca.pt_322  mk.bg.un_666 gd.sm.un_870 
  0x06350e0c, 0x16004c04, 0x48230402, 0x4027065a,   // is.zu.de_543 wo.hr.un_320  ru.ky.tt_222 de.gd.lb_553 
  0x3e0b0a09, 0x1700160e, 0x082330a4, 0x150a3c08,   // pt.es.rm_444 hr.sr.un_550  uz.ky.uk_433 ug.mk.un_443 
  0x0c2d2e04, 0x242207a0, 0x2d0e0c04, 0x3f082daf,   // fo.sk.sv_332 it.oc.eo_322  sv.is.sk_332 sk.no.af_655 
  // [10890]
  0x121918ee, 0x0c000212, 0x63330607, 0x06571313,   // ga.gl.hu_422 da.sv.un_640  de.nn.sco_432 et.na.de_665 
  0x2515150d, 0x04650d08, 0x2e002c04, 0x252330a4,   // un.mn.un_540 cs.gv.fi_443  fy.fo.un_320 uz.ky.mn_433 
  0x2c2d3f0c, 0x0c002d08, 0x0f171602, 0x2f006212,   // af.sk.fy_543 sk.sv.un_430  hr.sr.lv_222 kha.su.un_640 
  0x4410080d, 0x62fe2d0c, 0xfe007813, 0x214dfe07,   // uk.be.kk_554 sk.tlh.kha_543  ve.tlh.un_650 tlh.aa.jw_432 
  // [108a0]
  0x2c2d12a9, 0x2c002d13, 0x24021302, 0x3e060112,   // hu.sk.fy_544 sk.fy.un_650  et.da.eo_222 en.de.rm_654 
  0x4400040c, 0x6200610e, 0x0e2d1204, 0x56052f07,   // ru.kk.un_530 za.kha.un_550  hu.sk.is_332 su.fr.mg_432 
  0x04151002, 0x58001e05, 0x020c3ea0, 0x25374402,   // be.ru.un_220 ms.om.un_330  rm.sv.da_322 kk.ba.mn_222 
  0x043530ec, 0x23006011, 0x0f3e23a4, 0x133831ad,   // uz.tg.ru_644 vo.ca.un_630  ca.rm.lv_433 az.tk.et_643 
  // [108b0]
  0x0e33080e, 0x22230f04, 0x013e23a4, 0x0400fe1a,   // no.nn.is_555 lv.ca.oc_332  ca.rm.en_433 tlh.fi.un_760 
  0x4600fe07, 0x1e2f1ca4, 0x400459a0, 0x122c2d07,   // tlh.qu.un_420 id.su.ms_433  rn.fi.lb_322 sk.fy.hu_432 
  0x4d122caf, 0x01233ea4, 0x123421a6, 0x54006913,   // fy.hu.aa_655 rm.ca.en_433  fa.ps.ur_521 mfe.ik.un_650 
  0x223e23af, 0x22012307, 0x233e08a4, 0x083c3007,   // ca.rm.oc_655 ca.en.oc_432  no.rm.ca_433 uz.ug.uk_432 
  // [108c0]
  0x2f00400b, 0x09131c0d, 0x04083008, 0x350a170d,   // lb.su.un_520 mr.bh.hi_554  uz.uk.ru_443 sr.mk.tg_554 
  0x12003d09, 0x19002214, 0xfe002112, 0x3229160c,   // ku.ur.un_440 oc.gl.un_660  jw.tlh.un_640 hr.sl.bs_543 
  0x1000350b, 0x431d260d, 0x3544380c, 0x1c5d6408,   // tg.be.un_520 ia.la.ie_554  tk.kk.tg_543 lg.ss.id_443 
  0x1f00300d, 0x07083808, 0x3836150e, 0x78373409,   // uz.cy.un_540 tk.uk.bg_443  un.ab.tk_555 xh.st.ve_444 
  // [108d0]
  0x1900610d, 0x4837230c, 0x5d1f3507, 0x35073002,   // za.gl.un_540 ky.ba.tt_543  zu.cy.ss_432 uz.bg.tg_222 
  0x1f005f22, 0x60495aad, 0x37601ca0, 0x56287508,   // tn.cy.un_870 sm.to.vo_643  id.vo.st_322 nso.sw.mg_443 
  0x5e5d340c, 0x0700360e, 0x28000e13, 0x44363705,   // xh.ss.ts_543 ab.bg.un_550  is.sw.un_650 ba.ab.kk_333 
  0x3c30250d, 0x73285a08, 0x355d78af, 0x0a0410ee,   // mn.uz.ug_554 sm.sw.ny_443  ve.ss.zu_655 be.ru.mk_422 
  // [108e0]
  0x0a005e04, 0x78001f09, 0x5d5f37a9, 0x125d22a7,   // ts.pt.un_320 cy.ve.un_440  st.tn.ss_544 oc.ss.hu_532 
  0x1f375f07, 0x5d00760d, 0x18365a07, 0x34005f07,   // tn.st.cy_432 crs.ss.un_540  sm.gn.ga_432 tn.xh.un_420 
  0x454205ec, 0x46353455, 0x031d0107, 0x0500021a,   // fr.co.ln_644 xh.zu.qu_442  en.la.nl_432 da.fr.un_760 
  0x73fc55ec, 0x5d2864a4, 0x235e3b08, 0x370744ee,   // rw.zzp.ny_644 lg.sw.ss_433  so.ts.ca_443 kk.bg.ba_422 
  // [108f0]
  0x5d5f280b, 0x5d595508, 0x31304811, 0x4d594fa9,   // sw.tn.ss_542 rw.rn.ss_443  tt.uz.az_653 bi.rn.aa_544 
  0x472a6414, 0x553f150c, 0x5f754708, 0x0a002f08,   // lg.mt.sn_666 un.af.rw_543  sn.nso.tn_443 su.pt.un_430 
  0x3b584da7, 0x5a271d07, 0x47002705, 0x4d205112,   // aa.om.so_532 la.gd.sm_432  gd.sn.un_330 kl.sq.aa_654 
  0x17001114, 0x0a1d57a4, 0x122344a4, 0x49004b0e,   // ro.sr.un_660 na.la.pt_433  kk.ky.ur_433 mi.to.un_550 
  // [10900]
  0x0a002f05, 0x58005121, 0x0c040805, 0x38000c0c,   // su.pt.un_330 kl.om.un_860  no.fi.sv_333 sv.tk.un_530 
  0x286455ee, 0x0e001f07, 0x350430a0, 0x04003c20,   // rw.lg.sw_422 cy.is.un_420  uz.ru.tg_322 ug.ru.un_850 
  0x5c6a0f12, 0x0e00190c, 0x5100580c, 0x08002c04,   // lv.haw.sa_654 gl.is.un_530  om.kl.un_530 fy.no.un_320 
  0x300a3cee, 0x5e42fcac, 0x0e001210, 0x38004c04,   // ug.mk.uz_422 zzp.co.ts_632  hu.is.un_620 wo.tk.un_320 
  // [10910]
  0x0b004804, 0x2d290dee, 0x1218390c, 0x150135a0,   // tt.es.un_320 cs.sl.sk_422  br.ga.hu_543 zu.en.un_322 
  0x3d233c08, 0x12391f14, 0x10070802, 0x484410a4,   // ug.ky.ku_443 cy.br.hu_666  uk.bg.be_222 be.kk.tt_433 
  0x01182809, 0x4800191a, 0x100815a4, 0x360b4605,   // sd.ar.iw_444 gl.tt.un_760  un.uk.be_433 qu.es.gn_333 
  0x64283607, 0x360b6ba4, 0x2f5630a4, 0x1f00671b,   // gn.sw.lg_432 ceb.es.gn_433  uz.mg.su_433 ak.cy.un_770 
  // [10920]
  0x23113c0c, 0x161f2702, 0x1f005602, 0x40000204,   // ug.ro.ky_543 gd.cy.hr_222  mg.cy.un_220 da.lb.un_320 
  0x3544300c, 0x04002f21, 0x04002f1a, 0x033f2faf,   // uz.kk.tg_543 su.fi.un_860  su.fi.un_760 su.af.nl_655 
  0x16290da0, 0x03002f07, 0x0b5a37a0, 0x5a766011,   // cs.sl.hr_322 su.nl.un_420  st.sm.es_322 vo.crs.sm_653 
  0x494a5a55, 0x04032fad, 0x1830210c, 0x49225e07,   // sm.yo.to_442 su.nl.fi_643  fa.uz.ar_543 ts.oc.to_432 
  // [10930]
  0x150a10ad, 0x53485507, 0x5f00370e, 0x0c480408,   // be.mk.un_643 rw.tt.ht_432  st.tn.un_550 fi.tt.sv_443 
  0x38004821, 0x18003b11, 0x44373504, 0x0f002a0c,   // tt.tk.un_860 ks.ar.un_630  tg.ba.kk_332 mt.lv.un_530 
  0x4c4505ec, 0x054245ee, 0x5b63010b, 0x504b01a0,   // fr.ln.wo_644 ln.co.fr_422  en.sco.sg_542 en.mi.fj_322 
  0x071708ee, 0x23001533, 0x441748a4, 0x2021640c,   // uk.sr.bg_422 un.ky.un_A70  tt.sr.kk_433 lg.jw.sq_543 
  // [10940]
  0x64584c02, 0x110a69a4, 0x252311ec, 0x154d11ad,   // wo.om.lg_222 mfe.pt.ro_433  ro.ky.mn_644 ro.aa.un_643 
  0x07630107, 0x50006b05, 0x48040804, 0x090a12a6,   // en.sco.it_432 ceb.fj.un_330  uk.ru.tt_332 hu.pt.pl_521 
  0x4c006b09, 0x63007507, 0x5c000d29, 0x24000d08,   // ceb.wo.un_440 nso.sco.un_420  ne.sa.un_960 cs.eo.un_430 
  0x03402caf, 0x05282b07, 0x6b000412, 0x2000270d,   // fy.lb.nl_655 vi.sw.fr_432  fi.ceb.un_640 gd.sq.un_540 
  // [10950]
  0xfc000f12, 0x30491e0c, 0x365c4ca4, 0x241001a4,   // lv.zzp.un_640 ms.to.uz_543  wo.sa.gn_433 en.lt.eo_433 
  0x69760da4, 0x211dfc02, 0x6b6863a4, 0x0c0308a4,   // cs.crs.mfe_433 zzp.la.jw_222  sco.ig.ceb_433 no.nl.sv_433 
  0x115c1c07, 0xfc025804, 0x49375aa9, 0x1d00570d,   // id.sa.ro_432 om.da.zzp_332  sm.st.to_544 na.la.un_540 
  0x5300fe07, 0x734778ec, 0x5d6430ec, 0x4c311902,   // tlh.ht.un_420 ve.sn.ny_644  uz.lg.ss_644 gl.az.wo_222 
  // [10960]
  0x2f1d20a0, 0x11003e02, 0x20003708, 0x1c4b1eaf,   // sq.la.su_322 rm.ro.un_220  st.sq.un_430 ms.mi.id_655 
  0x4f635705, 0x1dfc02a0, 0x110a0712, 0x1b00110c,   // na.sco.bi_333 da.zzp.la_322  bg.mk.ro_654 ro.tr.un_530 
  0x21343b12, 0x2821180c, 0x43110f5a, 0x53002105,   // ks.ps.fa_654 ar.fa.sd_543  lv.ro.ie_553 jw.ht.un_330 
  0x44071504, 0x2f23690b, 0x0f734d0c, 0x1dfe5ca4,   // un.bg.kk_332 mfe.ca.su_542  aa.ny.lv_543 sa.tlh.la_433 
  // [10970]
  0x080251ec, 0x134d2a09, 0x57642a0c, 0x32470755,   // kl.da.no_644 mt.aa.et_444  mt.lg.na_543 it.sn.bs_442 
  0x026b1ca0, 0x3e2006ad, 0x53002305, 0x33084f05,   // id.ceb.da_322 de.sq.rm_643  ca.ht.un_330 bi.no.nn_333 
  0x3b2cfea4, 0x03172007, 0x57002d13, 0x6b033f0d,   // tlh.fy.so_433 sq.sr.nl_432  sk.na.un_650 af.nl.ceb_554 
  0x0e4c360c, 0x31001d08, 0x1f2a4cee, 0x04153704,   // gn.wo.is_543 la.az.un_430  wo.mt.cy_422 ba.ru.un_320 
  // [10980]
  0x5f4937a9, 0x1f00fc14, 0x3000610b, 0x19000b0d,   // st.to.tn_544 zzp.cy.un_660  za.uz.un_520 es.gl.un_540 
  0x3b561f07, 0x034f60ee, 0x5a004a12, 0x55025fa0,   // cy.mg.so_432 vo.bi.nl_422  yo.sm.un_640 tn.da.rw_322 
  0x111f4cec, 0x0711fca7, 0x481f12a9, 0x2e3308a6,   // wo.cy.ro_644 zzp.ro.it_532  hu.cy.tt_544 no.nn.fo_521 
  0x4c001f09, 0x391f5a07, 0x0f00490c, 0x061f75ad,   // cy.wo.un_440 sm.cy.br_432  to.lv.un_530 nso.cy.de_643 
  // [10990]
  0x5a000207, 0x48004605, 0x64001207, 0x5e002302,   // da.sm.un_420 qu.tt.un_330  hu.lg.un_420 ca.ts.un_220 
  0x47005a08, 0x2e503004, 0x2a001504, 0x06001114,   // sm.sn.un_430 uz.fj.fo_332  un.mt.un_320 ro.de.un_660 
  0x53004904, 0x56375208, 0x56645aa0, 0x081504ad,   // to.ht.un_320 ha.st.mg_443  sm.lg.mg_322 ru.uk.un_630 
  0x5c210204, 0x50005a21, 0x320c0e07, 0x2a0250ad,   // da.jw.sa_332 sm.fj.un_860  is.sv.bs_432 fj.da.mt_643 
  // [109a0]
  0x2c1d1d0c, 0x555a1f0c, 0x12006e23, 0x49105aa0,   // la.la.fy_543 cy.sm.rw_543  hmn.hu.un_880 sm.lt.to_322 
  0x53001022, 0x0b1f13ec, 0x094c4a12, 0x1234210d,   // lt.ht.un_870 et.cy.es_644  yo.wo.pl_654 fa.ps.ur_554 
  0x20fe2711, 0x020c08a9, 0x4c007319, 0x2227180d,   // gd.tlh.sq_653 no.sv.da_544  ny.wo.un_750 ga.gd.oc_554 
  0x7640060d, 0x12283405, 0x60fe3f0e, 0x1d3e40ec,   // de.lb.crs_554 ps.sd.ur_333  af.tlh.vo_555 lb.rm.la_644 
  // [109b0]
  0xfc1f61ec, 0x1f002a29, 0x48004e19, 0x644c3404,   // za.cy.zzp_644 mt.cy.un_960  ay.tt.un_750 xh.wo.lg_332 
  0x6e766911, 0x48006e19, 0x6e6927ad, 0x23192c04,   // mfe.crs.hmn_653 hmn.tt.un_750  gd.mfe.hmn_643 fy.gl.ca_332 
  0x31004f0d, 0x21183bad, 0x10080209, 0x21006335,   // bi.az.un_540 ks.ar.fa_643  da.no.lt_444 sco.jw.un_A90 
  0x475d5e12, 0x32001d07, 0x1224fea7, 0x233c30ec,   // ts.ss.sn_654 la.bs.un_420  tlh.eo.hu_532 uz.ug.ky_644 
  // [109c0]
  0x79401a05, 0x33084ca9, 0x583f03a0, 0x2a002404,   // tl.lb.war_333 wo.no.nn_544  nl.af.om_322 eo.mt.un_320 
  0x02006312, 0x40650607, 0x2a42120d, 0x1b452807,   // sco.da.un_640 de.gv.lb_432  hu.co.mt_554 sw.ln.tr_432 
  0x073c1705, 0x25004204, 0x361507ec, 0x2c4c6107,   // sr.ug.bg_333 co.eu.un_320  bg.ab.un_640 za.wo.fy_432 
  0x29000308, 0x69767313, 0x39000307, 0x03343f07,   // nl.sl.un_430 ny.crs.mfe_665  nl.br.un_420 af.xh.nl_432 
  // [109d0]
  0x0c060308, 0x24002a0d, 0x151523a9, 0x23184db2,   // nl.de.sv_443 mt.eo.un_540  ky.un.un_540 aa.ga.ca_732 
  0x2a07420c, 0x0f004909, 0x0300251a, 0x44341813,   // co.it.mt_543 to.lv.un_440  eu.nl.un_760 ar.ps.kk_665 
  0x420312a4, 0x2d100da4, 0x0300120c, 0x100715ad,   // hu.nl.co_433 cs.lt.sk_433  hu.nl.un_530 un.bg.be_643 
  0x3c3d21a7, 0x081510ee, 0x29001008, 0x08100708,   // fa.ku.ug_532 be.uk.un_420  lt.sl.un_430 bg.be.uk_443 
  // [109e0]
  0x07080a02, 0x1b1231a0, 0x1b311208, 0x273b6312,   // mk.uk.bg_222 az.hu.tr_322  hu.az.tr_443 sco.so.gd_654 
  0x3b794da7, 0x21002211, 0x17301008, 0x083004a0,   // aa.war.so_532 oc.jw.un_630  be.uz.sr_443 ru.uz.uk_322 
  0x083c1104, 0x53002113, 0x151708a4, 0x09292da0,   // ro.ug.uk_332 jw.ht.un_650  uk.sr.un_433 sk.sl.pl_322 
  0x381b1211, 0x1b3112ee, 0x23002f04, 0x4300602b,   // hu.tr.tk_653 hu.az.tr_422  su.ca.un_320 vo.ie.un_980 
  // [109f0]
  0x153c350c, 0x0a3811a4, 0x40383107, 0x131e1c05,   // tg.ug.un_543 ro.tk.mk_433  az.tk.lb_432 id.ms.et_333 
  0x233738ec, 0x135c0911, 0x6a43120e, 0x2d003619,   // tk.ba.ky_644 hi.sa.bh_653  hu.ie.haw_555 gn.sk.un_750 
  0x360622a9, 0x6500630e, 0x5763010c, 0x183c23ee,   // oc.de.gn_544 sco.gv.un_550  en.sco.na_543 ky.ug.ar_422 
  0x374835ee, 0x30253511, 0x40150655, 0x111538ad,   // tg.tt.ba_422 tg.mn.uz_653  de.lb.un_420 tk.ro.un_630 
  // [10a00]
  0x296357a0, 0x010c63a4, 0x73476707, 0x0d3b13a9,   // na.sco.sl_322 sco.sv.en_433  ak.sn.ny_432 bh.ks.ne_544 
  0x532322a9, 0x28006812, 0x4a003808, 0x5d3534ad,   // oc.ca.ht_544 ig.sw.un_640  tk.yo.un_430 xh.zu.ss_643 
  0x45003813, 0x3534fe0e, 0x35644004, 0x3c483507,   // tk.ln.un_650 tlh.xh.zu_555  lb.lg.zu_332 tg.tt.ug_432 
  0x64fe4555, 0x53344c0c, 0x38007304, 0x5c100f04,   // ln.tlh.lg_442 wo.xh.ht_543  ny.tk.un_320 lv.lt.sa_332 
  // [10a10]
  0x286233a4, 0x070433a0, 0x30000711, 0x34003812,   // nn.kha.sw_433 nn.fi.it_322  bg.uz.un_630 tk.xh.un_640 
  0x73004c0d, 0x31000804, 0x5d00280c, 0x45003805,   // wo.ny.un_540 no.az.un_320  sw.ss.un_530 tk.ln.un_330 
  0x172a0c08, 0x35005e0d, 0x38001b2a, 0x1708110c,   // sv.mt.sr_443 ts.zu.un_540  tr.tk.un_970 ro.uk.sr_543 
  0x020e2808, 0x1b00382b, 0x5e1b0608, 0x381b08af,   // sw.is.da_443 tk.tr.un_980  de.tr.ts_443 no.tr.tk_655 
  // [10a20]
  0x5e080208, 0x212818a9, 0x1d0601a4, 0x38021bac,   // da.no.ts_443 ar.sd.fa_544  en.de.la_433 tr.da.tk_632 
  0x07084807, 0x0c023814, 0x2d001904, 0x31321bec,   // tt.uk.bg_432 tk.da.sv_666  gl.sk.un_320 tr.bs.az_644 
  0x65005120, 0x484d1ba9, 0x053e2255, 0x310c3e0c,   // kl.gv.un_850 tr.aa.tt_544  oc.rm.fr_442 rm.sv.az_543 
  0x5f372daf, 0x071d0107, 0x0e0c33a4, 0x120e0cee,   // sk.st.tn_655 en.la.it_432  nn.sv.is_433 sv.is.hu_422 
  // [10a30]
  0x1b18fea9, 0x1f381ba7, 0x0e022e5a, 0x15001108,   // tlh.ga.tr_544 tr.tk.cy_532  fo.da.is_553 ro.un.un_430 
  0x02201b07, 0x016538ad, 0x38001b2b, 0x1f00690c,   // tr.sq.da_432 tk.gv.en_643  tr.tk.un_980 mfe.cy.un_530 
  0x28123005, 0x511b3813, 0x38151baf, 0x401b385a,   // uz.ur.sd_333 tk.tr.kl_665  tr.tk.un_650 tk.tr.lb_553 
  0x58004704, 0x21642eee, 0x10003618, 0x484410a0,   // sn.om.un_320 fo.lg.jw_422  ab.be.un_740 be.kk.tt_322 
  // [10a40]
  0x443507ad, 0x51214ba6, 0x10374855, 0x6e6b1dec,   // bg.tg.kk_643 mi.jw.kl_521  tt.ba.be_442 la.ceb.hmn_644 
  0x1a006213, 0x08351060, 0x38002f0c, 0x15004602,   // kha.tl.un_650 be.tg.uk_664  su.tk.un_530 qu.un.un_220 
  0x1c001f04, 0x28012111, 0x15006008, 0x50002a02,   // cy.id.un_320 fa.iw.sd_653  vo.un.un_430 mt.fj.un_220 
  0x17160304, 0x1c2f2104, 0x1f002604, 0x05002b12,   // nl.hr.sr_332 jw.su.id_332  ia.cy.un_320 vi.fr.un_640 
  // [10a50]
  0x2b490207, 0x4a006807, 0x4728360c, 0x38113c0c,   // da.to.vi_432 ig.yo.un_420  gn.sw.sn_543 ug.ro.tk_543 
  0x646b12ad, 0x5e5f37a9, 0x23443507, 0x07003609,   // hu.ceb.lg_643 st.tn.ts_544  tg.kk.ky_432 ab.bg.un_440 
  0x38371507, 0x5c007314, 0x28000908, 0xfe3831ee,   // un.ba.tk_432 ny.sa.un_660  pl.sw.un_430 az.tk.tlh_422 
  0x58190bad, 0x5c3669a4, 0x36155cad, 0x39004c0d,   // es.gl.om_643 mfe.gn.sa_433  sa.gn.un_630 wo.br.un_540 
  // [10a60]
  0x341d1c02, 0x533669a4, 0x422711ec, 0x205c36ad,   // id.la.xh_222 mfe.gn.ht_433  ro.gd.co_644 gn.sa.sq_643 
  0x35342005, 0x3b001904, 0x4d002d04, 0x1c502f0c,   // sq.xh.zu_333 gl.so.un_320  sk.aa.un_320 su.fj.id_543 
  0x42261da9, 0x17100813, 0x1d003b07, 0x27001c02,   // la.ia.co_544 uk.be.sr_665  so.la.un_420 id.gd.un_220 
  0x3b005511, 0x48373cad, 0x12343b0c, 0x0c3720a0,   // rw.so.un_630 ug.ba.tt_643  ks.ps.ur_543 sq.st.sv_322 
  // [10a70]
  0x5907420c, 0x5c0d095a, 0x021211a4, 0x0c005e19,   // co.it.rn_543 hi.ne.sa_553  ro.hu.da_433 ts.sv.un_750 
  0xfc1d2712, 0x25675aad, 0x375a4914, 0x4b495a0d,   // gd.la.zzp_654 sm.ak.eu_643  to.sm.st_666 sm.to.mi_554 
  0x15000505, 0x4900250d, 0x4b56250d, 0x36003714,   // fr.un.un_330 eu.to.un_540  eu.mg.mi_554 st.gn.un_660 
  0x572825a4, 0x67495a0c, 0x10083007, 0x5a254b0c,   // eu.sw.na_433 sm.to.ak_543  uz.uk.be_432 mi.eu.sm_543 
  // [10a80]
  0x2f2c47a0, 0x37103011, 0x255767a9, 0x2c133f07,   // sn.fy.su_322 uz.be.ba_653  ak.na.eu_544 af.et.fy_432 
  0x40472cad, 0x6b00020e, 0x04503905, 0x56254ba9,   // fy.sn.lb_643 da.ceb.un_550  br.fj.fi_333 mi.eu.mg_544 
  0x2537560d, 0x3f2c560c, 0x382924ee, 0x2438300c,   // mg.st.eu_554 mg.fy.af_543  eo.sl.tk_422 uz.tk.eo_543 
  0x2c065602, 0x135524ec, 0x3b595505, 0x12192ea0,   // mg.de.fy_222 eo.rw.et_644  rw.rn.so_333 fo.gl.hu_322 
  // [10a90]
  0x2d0d13a9, 0x523829ee, 0x1238500c, 0x13640204,   // et.cs.sk_544 sl.tk.ha_422  fj.tk.hu_543 da.lg.et_332 
  0x4b00fc07, 0x170f24ee, 0x292d32a0, 0x195323a0,   // zzp.mi.un_420 eo.lv.sr_422  bs.sk.sl_322 ca.ht.gl_322 
  0x40004704, 0x07170802, 0x24006413, 0x20002407,   // sn.lb.un_320 uk.sr.bg_222  lg.eo.un_650 eo.sq.un_420 
  0x36004d11, 0x65401f04, 0x642809a0, 0x024d240c,   // aa.gn.un_630 cy.lb.gv_332  pl.sw.lg_322 eo.aa.da_543 
  // [10aa0]
  0x5b000108, 0x2f006113, 0x2a422408, 0x13792407,   // en.sg.un_430 za.su.un_650  eo.co.mt_443 eo.war.et_432 
  0x28552402, 0x2a00680c, 0x182e0e08, 0x38080412,   // eo.rw.sw_222 ig.mt.un_530  is.fo.ga_443 ru.uk.tk_654 
  0x48302707, 0x1a001207, 0x2b005604, 0x340679ee,   // gd.uz.tt_432 hu.tl.un_420  mg.vi.un_320 war.de.xh_422 
  0x2d000307, 0x35fc64ec, 0x2d000504, 0x0a04170c,   // nl.sk.un_420 lg.zzp.zu_644  fr.sk.un_320 sr.ru.mk_543 
  // [10ab0]
  0x0a4417a0, 0x79fc38a4, 0x6434350c, 0xfc3775ec,   // sr.kk.mk_322 tk.zzp.war_433  zu.xh.lg_543 nso.st.zzp_644 
  0x0d5c130b, 0x79005d1a, 0x375ffcee, 0xfc343b04,   // bh.sa.ne_542 ss.war.un_760  zzp.tn.st_422 so.xh.zzp_332 
  0xfc003704, 0x170f100c, 0x47052f08, 0x44003619,   // st.zzp.un_320 lt.lv.sr_543  su.fr.sn_443 ab.kk.un_750 
  0x1f065ba9, 0x2f333f05, 0x3d00120b, 0x070811ac,   // sg.de.cy_544 af.nn.su_333  ur.ku.un_520 ro.uk.bg_632 
  // [10ac0]
  0x041008ee, 0x03053fee, 0x103015a9, 0x4a000e12,   // uk.be.ru_422 af.fr.nl_422  un.uz.be_544 is.yo.un_640 
  0x1d565aa0, 0x02065807, 0x4a563705, 0x05002f07,   // sm.mg.la_322 om.de.da_432  st.mg.yo_333 su.fr.un_420 
  0x182753a0, 0x46374ca7, 0x5876690c, 0x73566805,   // ht.gd.ga_322 wo.st.qu_532  mfe.crs.om_543 ig.mg.ny_333 
  0x1000091b, 0x37457505, 0x28594504, 0x3600650d,   // pl.lt.un_770 nso.ln.st_333  ln.rn.sw_332 gv.gn.un_540 
  // [10ad0]
  0x1f3e58ad, 0x22003308, 0x34003521, 0x49125aa0,   // om.rm.cy_643 nn.oc.un_430  zu.xh.un_860 sm.hu.to_322 
  0x1b766960, 0x644c4da0, 0x04153812, 0x39004c20,   // mfe.crs.tr_664 aa.wo.lg_322  tk.ru.un_640 wo.br.un_850 
  0x763201a6, 0x5a405302, 0x5a0f4704, 0x39002202,   // en.bs.crs_521 ht.lb.sm_222  sn.lv.sm_332 oc.br.un_220 
  0x5a033f08, 0x080437a0, 0x083615ee, 0x17253507,   // af.nl.sm_443 ba.ru.uk_322  un.ab.uk_422 tg.mn.sr_432 
  // [10ae0]
  0x44303c08, 0x1a1715ee, 0x12283ca0, 0x534c30a7,   // ug.uz.kk_443 un.sr.tl_422  ug.sd.ur_322 uz.wo.ht_532 
  0x15002b04, 0x48373cac, 0x110a23a9, 0x304438ee,   // vi.un.un_320 ug.ba.tt_632  ky.mk.ro_544 tk.kk.uz_422 
  0x1302080c, 0x08040712, 0x64002812, 0x47002402,   // no.da.et_543 bg.ru.uk_654  sw.lg.un_640 eo.sn.un_220 
  0x5c7669af, 0x1e002a08, 0x12080255, 0x1e1c2cee,   // mfe.crs.sa_655 mt.ms.un_430  da.no.hu_442 fy.id.ms_422 
  // [10af0]
  0x1e091ca0, 0x081517ad, 0x2b004f08, 0x101c2ba9,   // id.pl.ms_322 sr.uk.un_630  bi.vi.un_430 vi.id.lt_544 
  0x093313a0, 0x151708a0, 0x0a171155, 0x1600320d,   // et.nn.pl_322 uk.sr.un_322  ro.sr.mk_442 bs.hr.un_540 
  0x0c120802, 0x15001709, 0x343b1212, 0x100a1707,   // no.hu.sv_222 sr.un.un_440  ur.ks.ps_654 sr.mk.be_432 
  0x180e2e13, 0x30122105, 0x48001514, 0x04081711,   // fo.is.ga_665 fa.ur.uz_333  un.tt.un_660 sr.uk.ru_653 
  // [10b00]
  0x11363caf, 0x25151507, 0x234819ad, 0x0d2d12ad,   // ug.ab.ro_655 un.mn.un_420  gl.tt.ca_643 hu.sk.cs_643 
  0x122d1812, 0x042335a4, 0x2d181213, 0xfc002702,   // ga.sk.hu_654 tg.ky.ru_433  hu.ga.sk_665 gd.zzp.un_220 
  0x48122dac, 0x040735ee, 0x122e0e12, 0x483708ee,   // sk.hu.tt_632 tg.bg.ru_422  is.fo.hu_654 uk.ba.tt_422 
  0x2d124d0d, 0x60002e0e, 0x40005809, 0x39004907,   // aa.hu.sk_554 fo.vo.un_550  om.lb.un_440 to.br.un_420 
  // [10b10]
  0x18003909, 0x352315af, 0x3e0410ec, 0x22000504,   // br.ga.un_440 un.ky.tg_655  lt.fi.rm_644 fr.oc.un_320 
  0x2f1c39a0, 0x28004b08, 0x242d120c, 0x49565a12,   // br.id.su_322 mi.sw.un_430  hu.sk.eo_543 sm.mg.to_654 
  0xfe272f11, 0x622f330c, 0x2d2e0e55, 0x0e122d0b,   // su.gd.tlh_653 nn.su.kha_543  is.fo.sk_442 sk.hu.is_542 
  0x261d7608, 0x0e122d04, 0x580e2a11, 0x424051ec,   // crs.la.ia_443 sk.hu.is_332  mt.is.om_653 kl.lb.co_644 
  // [10b20]
  0x30083512, 0x0306510c, 0x68061d07, 0x29580da4,   // tg.uk.uz_654 kl.de.nl_543  la.de.ig_432 cs.om.sl_433 
  0x3f583304, 0xfc060204, 0x625f755a, 0x15441107,   // nn.om.af_332 da.de.zzp_332  nso.tn.kha_553 ro.kk.un_432 
  0x13001f0c, 0x29090da4, 0x02005804, 0x0c3b4ca4,   // cy.et.un_530 cs.pl.sl_433  om.da.un_320 wo.so.sv_433 
  0x16290da4, 0x4d4c0908, 0x5a6a2fa9, 0x5a000c04,   // cs.sl.hr_433 pl.wo.aa_443  su.haw.sm_544 sv.sm.un_320 
  // [10b30]
  0x0c2f0d07, 0x104830a0, 0x46fe4da9, 0x0802fc0c,   // cs.su.sv_432 uz.tt.lt_322  aa.tlh.qu_544 zzp.da.no_543 
  0x083933ee, 0x34122813, 0x653f030e, 0x10361507,   // nn.br.no_422 sd.ur.ps_665  nl.af.gv_555 un.ab.be_432 
  0x2f211ca7, 0x47006508, 0x27002f02, 0x2330370d,   // id.jw.su_532 gv.sn.un_430  su.gd.un_220 ba.uz.ky_554 
  0x5c003504, 0x07483811, 0x0c041313, 0x18004402,   // zu.sa.un_320 tk.tt.bg_653  et.fi.sv_665 kk.ar.un_220 
  // [10b40]
  0x5a00490b, 0x36002522, 0x15170aad, 0x04443804,   // to.sm.un_520 mn.ab.un_870  mk.sr.un_643 tk.kk.ru_332 
  0x3d1234ac, 0x0c120804, 0x0c2c1804, 0x00003637,   // ps.ur.ku_632 no.hu.sv_332  ga.fy.sv_332 gn.un.un_B00 
  0x21233c07, 0x353615a0, 0x303c0aa9, 0x5e002f04,   // ug.ky.fa_432 un.ab.tg_322  mk.ug.uz_544 su.ts.un_320 
  0x64212f08, 0x2f215ea7, 0x48003821, 0x5d345eaf,   // su.jw.lg_443 ts.jw.su_532  tk.tt.un_860 ts.xh.ss_655 
  // [10b50]
  0x0a3715a4, 0x34643804, 0x383558a0, 0x52644c0c,   // un.ba.mk_433 tk.lg.xh_332  om.zu.tk_322 wo.lg.ha_543 
  0x2f4c2112, 0x5e644ea4, 0x5d645ea9, 0x1c647307,   // jw.wo.su_654 ay.lg.ts_433  ts.lg.ss_544 ny.lg.id_432 
  0x250810ee, 0x2337480c, 0x23481508, 0x786a4baf,   // be.uk.mn_422 tt.ba.ky_543  un.tt.ky_443 mi.haw.ve_655 
  0x62042808, 0x22495aaf, 0x302335ec, 0x131c5cec,   // sw.fi.kha_443 sm.to.oc_655  tg.ky.uz_644 sa.mr.bh_644 
  // [10b60]
  0x076a5a0c, 0x254007a4, 0x04470908, 0x0b3f2cee,   // sm.haw.it_543 it.lb.eu_433  pl.sn.fi_443 fy.af.es_422 
  0x443c3060, 0x403f0804, 0x37233804, 0x1c0d1312,   // uz.ug.kk_664 no.af.lb_332  tk.ky.ba_332 bh.ne.mr_654 
  0x0b40060c, 0x110b79a4, 0x281218a7, 0x684a09a9,   // de.lb.es_543 war.es.ro_433  ar.ur.sd_532 pl.yo.ig_544 
  0x5a4b2d0c, 0x4b1d6a07, 0x215a2d0c, 0x0f09060c,   // sk.mi.sm_543 haw.la.mi_432  sk.sm.jw_543 de.pl.lv_543 
  // [10b70]
  0x30281204, 0x24000122, 0x252a060e, 0x0b063ea9,   // ur.sd.uz_332 iw.yi.un_870  de.mt.eu_555 rm.de.es_544 
  0x1d2403ee, 0x02400911, 0x1106330c, 0x37481111,   // nl.eo.la_422 pl.lb.da_653  nn.de.ro_543 ro.tt.ba_653 
  0x2406250d, 0x2112305a, 0x394c0504, 0x0b060102,   // eu.de.eo_554 uz.ur.fa_553  fr.wo.br_332 en.de.es_222 
  0x36004a0c, 0x38100813, 0x3f480ea0, 0x31053807,   // yo.gn.un_530 uk.be.tk_665  is.tt.af_322 tk.fr.az_432 
  // [10b80]
  0x130d5ca7, 0x22190a04, 0x4c735e5a, 0x1b483114,   // sa.ne.bh_532 pt.gl.oc_332  ts.ny.wo_553 az.tt.tr_666 
  0x170415a6, 0x150804a9, 0x483c300c, 0x0f00251a,   // un.ru.sr_521 ru.uk.un_544  uz.ug.tt_543 eu.lv.un_760 
  0x5e007309, 0x4804135a, 0x2128230c, 0x214c5da0,   // ny.ts.un_440 et.fi.tt_553  ky.sd.fa_543 ss.wo.jw_322 
  0x472f73a9, 0x0a00100d, 0x0cfe7311, 0x04fe150c,   // ny.su.sn_544 be.mk.un_540  ny.tlh.sv_653 un.tlh.fi_543 
  // [10b90]
  0x19430e0e, 0x0600390c, 0x3e04fe07, 0x17230aec,   // is.ie.gl_555 br.de.un_530  tlh.fi.rm_432 mk.ky.sr_644 
  0x0c2d0d04, 0xfe000c14, 0x350407a0, 0x400305a0,   // cs.sk.sv_332 sv.tlh.un_660  bg.ru.tg_322 fr.nl.lb_322 
  0xfe001213, 0x47001219, 0x1b00fe1a, 0x5c20fe0c,   // hu.tlh.un_650 hu.sn.un_750  tlh.tr.un_760 tlh.sq.sa_543 
  0x17060502, 0x043e0107, 0x172d290c, 0x1200fe14,   // fr.de.sr_222 en.rm.fi_432  sl.sk.sr_543 tlh.hu.un_660 
  // [10ba0]
  0x040710a9, 0x56001c02, 0x373c4808, 0x070823a0,   // be.bg.ru_544 id.mg.un_220  tt.ug.ba_443 ky.uk.bg_322 
  0x125e36a4, 0x4b49200c, 0x5300201b, 0x557964a9,   // gn.ts.hu_433 sq.to.mi_543  sq.ht.un_770 lg.war.rw_544 
  0x697653ad, 0x5e12330c, 0x120c0809, 0x255d5ea9,   // ht.crs.mfe_643 nn.hu.ts_543  no.sv.hu_444 ts.ss.eu_544 
  0x5d50250c, 0x20400d07, 0x6742170c, 0x05002304,   // eu.fj.ss_543 cs.lb.sq_432  sr.co.ak_543 ca.fr.un_320 
  // [10bb0]
  0x24001212, 0x375311a4, 0x24174604, 0x3f125e0c,   // hu.eo.un_640 ro.ht.st_433  qu.sr.eo_332 ts.hu.af_543 
  0x190a36ec, 0x39766911, 0x30001e1a, 0x6e00fe09,   // gn.pt.gl_644 mfe.crs.br_653  ms.uz.un_760 tlh.hmn.un_440 
  0x36004509, 0x55641505, 0x57250107, 0x11425eee,   // ln.gn.un_440 un.lg.rw_333  en.eu.na_432 ts.co.ro_422 
  0x172d090c, 0x2d0d55a9, 0x2c074007, 0x2012fea0,   // pl.sk.sr_543 rw.cs.sk_544  lb.it.fy_432 tlh.hu.sq_322 
  // [10bc0]
  0x360753ad, 0x4c20fe04, 0x1b3912a9, 0x12697613,   // ht.it.gn_643 tlh.sq.wo_332  hu.br.tr_544 crs.mfe.hu_665 
  0x32172a07, 0x695301a0, 0x20002f05, 0x235e480d,   // mt.sr.bs_432 en.ht.mfe_322  su.sq.un_330 tt.ts.ca_554 
  0x3734200d, 0x4900201a, 0x643f57a4, 0x683f53ec,   // sq.xh.st_554 sq.to.un_760  na.af.lg_433 ht.af.ig_644 
  0x4f5a67a9, 0x063612a9, 0x3100200d, 0x32004c07,   // ak.sm.bi_544 hu.gn.de_544  sq.az.un_540 wo.bs.un_420 
  // [10bd0]
  0x24006e13, 0x15443707, 0x17fe6e04, 0x23002108,   // hmn.eo.un_650 ba.kk.un_432  hmn.tlh.sr_332 fa.ky.un_430 
  0x23301112, 0x10001d04, 0x335102a0, 0x1d003402,   // ro.uz.ky_654 la.lt.un_320  da.kl.nn_322 xh.la.un_220 
  0x0a002405, 0x374448af, 0x3e075307, 0x36000d12,   // eo.pt.un_330 tt.kk.ba_655  ht.it.rm_432 cs.gn.un_640 
  0x4e4d300c, 0x02000912, 0x495011ad, 0x2d003902,   // uz.aa.ay_543 pl.da.un_640  ro.fj.to_643 br.sk.un_220 
  // [10be0]
  0x080e3910, 0x23483712, 0x30383c0c, 0x233c2560,   // br.is.no_642 ba.tt.ky_654  ug.tk.uz_543 mn.ug.ky_664 
  0x3f004f04, 0x36000922, 0x39001b18, 0x79263ea0,   // bi.af.un_320 pl.gn.un_870  tr.br.un_740 rm.ia.war_322 
  0x2d0d10ec, 0x17353055, 0x3600110d, 0x44040808,   // lt.cs.sk_644 uz.tg.sr_442  ro.ab.un_540 uk.ru.kk_443 
  0x29172daf, 0x04481509, 0x173515ec, 0x0b231907,   // sk.sr.sl_655 un.tt.ru_444  un.tg.sr_644 gl.ca.es_432 
  // [10bf0]
  0x0a171105, 0x07005304, 0x6b002505, 0x4400481b,   // ro.sr.mk_333 ht.it.un_320  eu.ceb.un_330 tt.kk.un_770 
  0x4a0257a4, 0x555f1fa4, 0x2718fe0c, 0x734a5213,   // na.da.yo_433 cy.tn.rw_433  tlh.ga.gd_543 ha.yo.ny_665 
  0x22190a0e, 0x644b3607, 0x5d7333a0, 0x2a37fe60,   // pt.gl.oc_555 gn.mi.lg_432  nn.ny.ss_322 tlh.st.mt_664 
  0x2128580e, 0x470e1f55, 0x39250aa7, 0x366a2da0,   // om.sw.jw_555 cy.is.sn_442  pt.eu.br_532 sk.haw.gn_322 
  
  // [10c00]
  0x2206470c, 0x3b4b36a4, 0x065afe07, 0x5f5d35a0,   // sn.de.oc_543 gn.mi.so_433  tlh.sm.de_432 zu.ss.tn_322 
  0x48383705, 0x182009ee, 0x06006404, 0x3300780c,   // ba.tk.tt_333 pl.sq.ga_422  lg.de.un_320 ve.nn.un_530 
  0x074265a4, 0x395e4708, 0xfe00361b, 0x355d47a9,   // gv.co.it_433 sn.ts.br_443  gn.tlh.un_770 sn.ss.zu_544 
  0x40050107, 0x6e00200b, 0x2afe4b0c, 0x496a3955,   // en.fr.lb_432 sq.hmn.un_520  mi.tlh.mt_543 br.haw.to_442 
  // [10c10]
  0x34fe5e0d, 0x28001e04, 0x353401a0, 0xfe464e12,   // ts.tlh.xh_554 ms.sw.un_320  en.xh.zu_322 ay.qu.tlh_654 
  0x1b475eec, 0x0501060c, 0xfc014b0c, 0x1d0815a0,   // ts.sn.tr_644 de.en.fr_543  mi.en.zzp_543 un.no.la_322 
  0x205e0609, 0x2800650d, 0x5a002e0e, 0x0102730c,   // de.ts.sq_444 gv.sw.un_540  fo.sm.un_550 ny.da.en_543 
  0x57647312, 0x10172504, 0x2f006112, 0x40005f21,   // ny.lg.na_654 mn.sr.be_332  za.su.un_640 tn.lb.un_860 
  // [10c20]
  0x355d280d, 0x37006405, 0x1335730c, 0x65000413,   // sw.ss.zu_554 lg.st.un_330  ny.zu.et_543 fi.gv.un_650 
  0x287364a9, 0x68151d07, 0x35005d13, 0x04080755,   // lg.ny.sw_544 la.ig.un_420  ss.zu.un_650 bg.uk.ru_442 
  0x31001114, 0x13260411, 0x334610a0, 0x1e000608,   // ro.az.un_660 fi.ia.et_653  lt.qu.nn_322 de.ms.un_430 
  0x38005804, 0x67642aaf, 0x063f5e07, 0x3700340d,   // om.tk.un_320 mt.lg.ak_655  ts.af.de_432 xh.st.un_540 
  // [10c30]
  0x09000c02, 0x17110a04, 0x04300812, 0x0c091007,   // sv.pl.un_220 mk.ro.sr_332  uk.uz.ru_654 lt.pl.sv_432 
  0x0c001007, 0x0408250c, 0x103507a0, 0x30002521,   // lt.sv.un_420 mn.uk.ru_543  bg.tg.be_322 mn.uz.un_860 
  0x2a061fa0, 0x3b40fcee, 0x30253513, 0x0700170e,   // cy.de.mt_322 zzp.lb.so_422  tg.mn.uz_665 sr.bg.un_550 
  0x0e1d020c, 0x08002523, 0x40063f05, 0x25000b02,   // da.la.is_543 mn.uk.un_880  af.de.lb_333 es.eu.un_220 
  // [10c40]
  0x360b5507, 0x02005309, 0x190a0207, 0x31513007,   // rw.es.gn_432 ht.da.un_440  da.pt.gl_432 uz.kl.az_432 
  0x31002905, 0x300a0402, 0x46005d02, 0x56300ba4,   // sl.az.un_330 ru.mk.uz_222  ss.qu.un_220 es.uz.mg_433 
  0x64475dac, 0x3b311ba6, 0x55280902, 0x05071da0,   // ss.sn.lg_632 tr.az.so_521  pl.sw.rw_222 la.it.fr_322 
  0x584afe07, 0x341d5d0b, 0x56003014, 0x5d373404,   // tlh.yo.om_432 ss.la.xh_542  uz.mg.un_660 xh.st.ss_332 
  // [10c50]
  0x3c001507, 0x55561005, 0x30480807, 0x32115d55,   // un.ug.un_420 lt.mg.rw_333  uk.tt.uz_432 ss.ro.bs_442 
  0x1c1165a0, 0x4c004007, 0x32172f02, 0x5f05230c,   // gv.ro.id_322 lb.wo.un_420  su.sr.bs_222 ca.fr.tn_543 
  0x36001913, 0x0b005608, 0x100b4602, 0x08170a09,   // gl.gn.un_650 mg.es.un_430  qu.es.lt_222 mk.sr.uk_444 
  0x2500340c, 0x0b2519ee, 0x2400020b, 0x03004f04,   // xh.eu.un_530 gl.eu.es_422  da.eo.un_520 bi.nl.un_320 
  // [10c60]
  0x1d190aa0, 0x341004a4, 0x291202a4, 0x2f005305,   // pt.gl.la_322 fi.lt.xh_433  da.hu.sl_433 ht.su.un_330 
  0x30005104, 0x482344af, 0x29fe20a4, 0x5700fe0e,   // kl.uz.un_320 kk.ky.tt_655  sq.tlh.sl_433 tlh.na.un_550 
  0xfe0a30ec, 0x3b000d22, 0x2d0d0a0c, 0x2e646aa9,   // uz.pt.tlh_644 cs.so.un_870  pt.cs.sk_543 haw.lg.fo_544 
  0x2f3b46a4, 0x0464330c, 0x580f6408, 0x0d000a08,   // qu.so.su_433 nn.lg.fi_543  lg.lv.om_443 pt.cs.un_430 
  // [10c70]
  0x484c3b0c, 0x04086407, 0x300a070c, 0x39005102,   // so.wo.tt_543 lg.no.fi_432  bg.mk.uz_543 kl.br.un_220 
  0x5100080d, 0x4f0c0d0b, 0x2c1703a7, 0x2c1202ee,   // no.kl.un_540 cs.sv.bi_542  nl.sr.fy_532 da.hu.fy_422 
  0x3f370304, 0x030e12af, 0x09250d07, 0x032501a9,   // nl.st.af_332 hu.is.nl_655  cs.eu.pl_432 en.eu.nl_544 
  0x463609a4, 0x3b482507, 0x0c0601a4, 0x44483811,   // pl.gn.qu_433 eu.tt.so_432  en.de.sv_433 tk.tt.kk_653 
  // [10c80]
  0x19002504, 0x3846090c, 0x190d0aa7, 0x0264360c,   // eu.gl.un_320 pl.qu.tk_543  pt.cs.gl_532 gn.lg.da_543 
  0x46523baf, 0x2d0d0aaf, 0x3f1236ee, 0x4f007619,   // so.ha.qu_655 pt.cs.sk_655  gn.hu.af_422 crs.bi.un_750 
  0x153035a9, 0x0d002e02, 0x1c0163a0, 0x031248a4,   // tg.uz.un_544 fo.cs.un_220  sco.en.id_322 tt.hu.nl_433 
  0x3f00120c, 0x082515a7, 0x0c004904, 0x0b23190c,   // hu.af.un_530 un.mn.uk_532  to.sv.un_320 gl.ca.es_543 
  // [10c90]
  0x2400330d, 0x29002007, 0xfc003122, 0x120d2d11,   // nn.eo.un_540 sq.sl.un_420  az.zzp.un_870 sk.cs.hu_653 
  0x1d0c0202, 0x111d6907, 0x0e3612ec, 0x3c303813,   // da.sv.la_222 mfe.la.ro_432  hu.gn.is_644 tk.uz.ug_665 
  0x2e001213, 0x362d1204, 0x5c000304, 0x33000e08,   // hu.fo.un_650 hu.sk.gn_332  nl.sa.un_320 is.nn.un_430 
  0x3c350a04, 0x0a1117af, 0x362d1207, 0x3528fca4,   // mk.tg.ug_332 sr.ro.mk_655  hu.sk.gn_432 zzp.sw.zu_433 
  // [10ca0]
  0x362d120c, 0x0e00180c, 0x040730a4, 0x0e5d2d07,   // hu.sk.gn_543 ga.is.un_530  uz.bg.ru_433 sk.ss.is_432 
  0x04080712, 0x0c1a46a0, 0x46470905, 0x13002208,   // bg.uk.ru_654 qu.tl.sv_322  pl.sn.qu_333 oc.et.un_430 
  0x0a002e04, 0x01001808, 0x330864a0, 0x154837a9,   // fo.pt.un_320 ar.iw.un_430  lg.no.nn_322 ba.tt.un_544 
  0x2205620c, 0x05003e34, 0x3b314611, 0x5a003e04,   // kha.fr.oc_543 rm.fr.un_A80  qu.az.so_653 rm.sm.un_320 
  // [10cb0]
  0x4800460d, 0x531d01ee, 0x65033fa9, 0x020c08a4,   // qu.tt.un_540 en.la.ht_422  af.nl.gv_544 no.sv.da_433 
  0x58fcfe0c, 0x230603af, 0x5e2e76a4, 0x2e2f0e0d,   // tlh.zzp.om_543 nl.de.ca_655  crs.fo.ts_433 is.su.fo_554 
  0x556b640c, 0x3e002334, 0x02000a07, 0x46290207,   // lg.ceb.rw_543 ca.rm.un_A80  pt.da.un_420 da.sl.qu_432 
  0x0e0a23ee, 0x06431804, 0x27003104, 0x53393602,   // ca.pt.is_422 ga.ie.de_332  az.gd.un_320 gn.br.ht_222 
  // [10cc0]
  0x1d001f14, 0x3e005204, 0x1508040e, 0x21303bad,   // cy.la.un_660 ha.rm.un_320  ru.uk.un_555 ks.uz.fa_643 
  0x122e2d08, 0x444811ad, 0x122e0e09, 0x3f113107,   // sk.fo.hu_443 ro.tt.kk_643  is.fo.hu_444 az.ro.af_432 
  0x48384405, 0x36190b11, 0x092d19a7, 0x581228a4,   // kk.tk.tt_333 es.gl.gn_653  gl.sk.pl_532 sw.hu.om_433 
  0x39004c05, 0x113e120c, 0x38004c09, 0x062504ec,   // wo.br.un_330 hu.rm.ro_543  wo.tk.un_440 fi.eu.de_644 
  // [10cd0]
  0x1300201a, 0x28001823, 0x3800570d, 0x5c2812ee,   // sq.et.un_760 ar.sd.un_880  na.tk.un_540 hu.sw.sa_422 
  0xfe001219, 0x68592907, 0x44384807, 0x2535235a,   // hu.tlh.un_750 sl.rn.ig_432  tt.tk.kk_432 ky.tg.mn_553 
  0x40621d5a, 0x360904ec, 0x35476807, 0x464759ee,   // la.kha.lb_553 fi.pl.gn_644  ig.sn.zu_432 rn.sn.qu_422 
  0x28000702, 0x0612200c, 0x5c0612a0, 0x17150760,   // it.sw.un_220 sq.hu.de_543  hu.de.sa_322 bg.sr.un_640 
  // [10ce0]
  0x4900730b, 0x06005302, 0x04081011, 0x39796b11,   // ny.to.un_520 ht.de.un_220  be.uk.ru_653 ceb.war.br_653 
  0x305e73a7, 0x174811ac, 0x352330a0, 0x190b0705,   // ny.ts.uz_532 ro.tt.sr_632  uz.ky.tg_322 it.es.gl_333 
  0x55001c0d, 0x2a045007, 0x13204209, 0x202e0e0c,   // id.rw.un_540 fj.fi.mt_432  co.sq.et_444 is.fo.sq_543 
  0x4e2a6412, 0x1032160d, 0x46007907, 0x20290e0c,   // lg.mt.ay_654 hr.bs.lt_554  war.qu.un_420 is.sl.sq_543 
  // [10cf0]
  0x03040fee, 0x02004207, 0x13042013, 0x12292aa4,   // lv.fi.nl_422 co.da.un_420  sq.fi.et_665 mt.sl.hu_433 
  0x2133080d, 0x64004e13, 0x1b000608, 0x2c4865a0,   // no.nn.jw_554 ay.lg.un_650  de.tr.un_430 gv.tt.fy_322 
  0x2f000605, 0x303421ee, 0x21000604, 0x4823440e,   // de.su.un_330 fa.ps.uz_422  de.jw.un_320 kk.ky.tt_555 
  0x202a0908, 0x2e002908, 0x09202aa9, 0x44303404,   // pl.mt.sq_443 sl.fo.un_430  mt.sq.pl_544 ps.uz.kk_332 
  // [10d00]
  0x2a2012ec, 0x02321608, 0x2c330813, 0x2f471d07,   // hu.sq.mt_644 hr.bs.da_443  no.nn.fy_665 la.sn.su_432 
  0x1d2f5a09, 0x361d610c, 0x491d61a7, 0x2200060c,   // sm.su.la_444 za.la.gn_543  za.la.to_532 de.oc.un_530 
  0x2f006119, 0x42000604, 0x1d002f08, 0x2f00610e,   // za.su.un_750 de.co.un_320  su.la.un_430 za.su.un_550 
  0x102538af, 0x1d492f0c, 0x1f001902, 0x632f610c,   // tk.mn.be_655 su.to.la_543  gl.cy.un_220 za.su.sco_543 
  // [10d10]
  0x1d002f12, 0x283b3da4, 0x233508a4, 0x2d380d0c,   // su.la.un_640 ku.ks.sd_433  uk.tg.ky_433 cs.tk.sk_543 
  0x15003c14, 0x070410a7, 0x080a35a9, 0x19253602,   // ug.un.un_660 be.ru.bg_532  tg.mk.uk_544 gn.eu.gl_222 
  0x55353402, 0x5000fc04, 0x39065eee, 0x1b6431a0,   // xh.zu.rw_222 zzp.fj.un_320  ts.de.br_422 az.lg.tr_322 
  0x38002502, 0x0b0a4ca9, 0x4a003708, 0x751f5fa9,   // eu.tk.un_220 wo.pt.es_544  st.yo.un_430 tn.cy.nso_544 
  // [10d20]
  0x02006413, 0x21552f08, 0x3534540c, 0x31111b07,   // lg.da.un_650 su.rw.jw_443  ik.xh.zu_543 tr.ro.az_432 
  0x55645311, 0x5e007313, 0x30504e04, 0x06601208,   // ht.lg.rw_653 ny.ts.un_650  ay.fj.uz_332 hu.vo.de_443 
  0x1d4c010c, 0x17080a05, 0x1d5a49ec, 0x342031a0,   // en.wo.la_543 mk.uk.sr_333  to.sm.la_644 az.sq.xh_322 
  0x64001209, 0x570640a4, 0x2d0d34ee, 0x475d34ad,   // hu.lg.un_440 lb.de.na_433  xh.cs.sk_422 xh.ss.sn_643 
  // [10d30]
  0x19004d0d, 0x38110a09, 0x2253010c, 0x0c006404,   // aa.gl.un_540 mk.ro.tk_444  en.ht.oc_543 lg.sv.un_320 
  0x3e371ba4, 0x35343012, 0x071523ad, 0x343135ec,   // tr.st.rm_433 uz.xh.zu_654  ky.bg.un_630 zu.az.xh_644 
  0x5d003402, 0x21123455, 0x4c00371b, 0x2d0943a0,   // xh.ss.un_220 ps.ur.fa_442  st.wo.un_770 ie.pl.sk_322 
  0x3428350b, 0x2d0c02ee, 0x203050a0, 0x4a002d05,   // zu.sw.xh_542 da.sv.sk_422  fj.uz.sq_322 sk.yo.un_330 
  // [10d40]
  0x066a01a0, 0x0c00080c, 0x6e3f1ea4, 0x15381512,   // en.haw.de_322 no.sv.un_530  ms.af.hmn_433 un.tk.un_654 
  0x3f6e20a9, 0x220b6e13, 0x4c6e3f11, 0x6553630c,   // sq.hmn.af_544 hmn.es.oc_665  af.hmn.wo_653 sco.ht.gv_543 
  0x2c3863ee, 0x1d042505, 0x4004610c, 0x43010704,   // sco.tk.fy_422 eu.fi.la_333  za.fi.lb_543 it.en.ie_332 
  0x07006307, 0x1d254307, 0x39401dec, 0x1f0263ec,   // sco.it.un_420 ie.eu.la_432  la.lb.br_644 sco.da.cy_644 
  // [10d50]
  0x254619ad, 0x064b36ad, 0x6b1a55ec, 0x3800152a,   // gl.qu.eu_643 gn.mi.de_643  rw.tl.ceb_644 un.tk.un_970 
  0x33006104, 0x0e692305, 0x36002514, 0x2a003908,   // za.nn.un_320 ca.mfe.is_333  eu.gn.un_660 dz.bo.un_430 
  0x6e003019, 0x3b003812, 0xfc6521a0, 0x653b38ad,   // uz.hmn.un_750 tk.so.un_640  jw.gv.zzp_322 tk.so.gv_643 
  0x2776fe0c, 0x0f001011, 0x224cfe14, 0x3f436014,   // tlh.crs.gd_543 lt.lv.un_630  tlh.wo.oc_666 vo.ie.af_666 
  // [10d60]
  0x216364ad, 0x6efe0104, 0x43052612, 0xfc00630e,   // lg.sco.jw_643 en.tlh.hmn_332  ia.fr.ie_654 sco.zzp.un_550 
  0x0f2f6e0d, 0x2b3e57a7, 0x43005012, 0x75253612,   // hmn.su.lv_554 na.rm.vi_532  fj.ie.un_640 gn.eu.nso_654 
  0x15253012, 0x3b382704, 0x4c194e14, 0x46194eec,   // uz.mn.un_654 gd.tk.so_332  ay.gl.wo_666 ay.gl.qu_644 
  0x12213d05, 0x1a6b7909, 0x1a003009, 0x30000204,   // ku.fa.ur_333 war.ceb.tl_444  uz.tl.un_440 da.uz.un_320 
  // [10d70]
  0x33002e0c, 0x511a02ad, 0x34003d21, 0x12302113,   // fo.nn.un_530 da.tl.kl_643  ku.ps.un_860 fa.uz.ur_665 
  0x0128180c, 0x02006b08, 0x07005502, 0x481511af,   // ar.sd.iw_543 ceb.da.un_430  rw.it.un_220 ro.tt.un_650 
  0x190b4caf, 0x42055112, 0x63002a19, 0x32171da4,   // wo.es.gl_655 kl.fr.co_654  mt.sco.un_750 la.sr.bs_433 
  0x2a00630e, 0x132e38ec, 0x1113380c, 0x5f131f04,   // sco.mt.un_550 tk.fo.et_644  tk.et.ro_543 cy.et.tn_332 
  // [10d80]
  0x524256a6, 0x4c2f270c, 0x40004d13, 0x5e001308,   // mg.co.ha_521 gd.su.wo_543  aa.lb.un_650 et.ts.un_430 
  0x255a5fa0, 0x23004819, 0x40150604, 0x400601a9,   // tn.sm.eu_322 tt.ky.un_750  de.lb.un_320 en.de.lb_544 
  0x392e0e07, 0x22001904, 0x1b004009, 0x0a204802,   // is.fo.br_432 gl.oc.un_320  lb.tr.un_440 tt.sq.pt_222 
  0x0a003c08, 0x1d3625a4, 0x020c5255, 0x1b001109,   // ug.mk.un_430 eu.gn.la_433  ha.sv.da_442 ro.tr.un_440 
  // [10d90]
  0x27002402, 0x23170a02, 0x322d3804, 0x48331b07,   // eo.gd.un_220 mk.sr.ky_222  tk.sk.bs_332 tr.nn.tt_432 
  0x25385fee, 0x064220a4, 0x420a25a9, 0x5c08330c,   // tn.tk.eu_422 sq.co.de_433  eu.pt.co_544 nn.no.sa_543 
  0x1b3831a0, 0x1b3138ac, 0x0b002c02, 0x15153ca4,   // az.tk.tr_322 tk.az.tr_632  fy.es.un_220 ug.un.un_430 
  0x21005913, 0x1200fc0d, 0xfc79010c, 0x1544230c,   // rn.jw.un_650 zzp.hu.un_540  en.war.zzp_543 ky.kk.un_543 
  // [10da0]
  0x25003804, 0x1f5856a9, 0x494b6aa7, 0x1f00fc08,   // tk.eu.un_320 mg.om.cy_544  haw.mi.to_532 zzp.cy.un_430 
  0x5d5845a9, 0x15fc01af, 0x0c333f02, 0x1d226a08,   // ln.om.ss_544 en.zzp.un_655  af.nn.sv_222 haw.oc.la_443 
  0x23580302, 0x132d0d0d, 0x5a000e04, 0x03005202,   // nl.om.ca_222 cs.sk.et_554  is.sm.un_320 ha.nl.un_220 
  0x76fc010c, 0x2d2c03a0, 0x254705a9, 0x3b5851a7,   // en.zzp.crs_543 nl.fy.sk_322  fr.sn.eu_544 kl.om.so_532 
  // [10db0]
  0x31002002, 0x1d005508, 0x52032da4, 0x3000340d,   // sq.az.un_220 rw.la.un_430  sk.nl.ha_433 ps.uz.un_540 
  0x494b5aec, 0x040a0711, 0x2f001e0d, 0x2c0f1055,   // sm.mi.to_644 bg.mk.ru_653  ms.su.un_540 lt.lv.fy_442 
  0x01022d04, 0x35006412, 0x636507ee, 0x5d3f2c0c,   // sk.da.en_332 lg.zu.un_640  it.gv.sco_422 fy.af.ss_543 
  0x122818af, 0x483820a0, 0x15230405, 0x5d646707,   // ar.sd.ur_655 sq.tk.tt_322  ru.ky.un_333 ak.lg.ss_432 
  // [10dc0]
  0x2830120c, 0x3564210c, 0x2800441a, 0xfe003011,   // ur.uz.sd_543 jw.lg.zu_543  kk.sd.un_760 uz.tlh.un_630 
  0x19363804, 0x25004c19, 0x48302011, 0x3008380c,   // tk.gn.gl_332 wo.eu.un_750  sq.uz.tt_653 tk.no.uz_543 
  0x30234807, 0x59063ead, 0x1b20310c, 0x60033fad,   // tt.ky.uz_432 rm.de.rn_643  az.sq.tr_543 af.nl.vo_643 
  0x1a30385a, 0x3f00690c, 0x4d523baf, 0x2200050e,   // tk.uz.tl_553 mfe.af.un_530  so.ha.aa_655 fr.oc.un_550 
  // [10dd0]
  0x0b3b2d07, 0x631d6512, 0x130f1012, 0x2a313004,   // sk.so.es_432 gv.la.sco_654  lt.lv.et_654 uz.az.mt_332 
  0x012a15a0, 0x34122304, 0x063308a4, 0x3f0c230c,   // un.mt.en_322 ky.ur.ps_332  no.nn.de_433 ca.sv.af_543 
  0x1f650408, 0x38202104, 0x4600570c, 0x0200031b,   // fi.gv.cy_443 jw.sq.tk_332  na.qu.un_530 nl.da.un_770 
  0x214434a0, 0x3f0307a4, 0x30007904, 0x38001207,   // ps.kk.fa_322 it.nl.af_433  war.uz.un_320 hu.tk.un_420 
  // [10de0]
  0x3308790e, 0x15005604, 0x4809380c, 0x02175612,   // war.no.nn_555 mg.un.un_320  tk.pl.tt_543 mg.sr.da_654 
  0x31303860, 0x2f3e1c07, 0x32004804, 0x381f650c,   // tk.uz.az_664 id.rm.su_432  tt.bs.un_320 gv.cy.tk_543 
  0x30613807, 0x3b313012, 0x2300060d, 0x016550a9,   // tk.za.uz_432 uz.az.so_654  de.ca.un_540 fj.gv.en_544 
  0x0e000409, 0x06070305, 0x4006fc0c, 0x0c001904,   // fi.is.un_440 nl.it.de_333  zzp.de.lb_543 gl.sv.un_320 
  // [10df0]
  0x01004b02, 0x48000e05, 0x1308330c, 0x55052f0c,   // mi.en.un_220 is.tt.un_330  nn.no.et_543 su.fr.rw_543 
  0x194c0b0c, 0x0233080c, 0x40061b12, 0x2900020e,   // es.wo.gl_543 no.nn.da_543  tr.de.lb_654 da.sl.un_550 
  0x2e173307, 0x65306307, 0x150efca4, 0x1b383160,   // nn.sr.fo_432 sco.uz.gv_432  zzp.is.un_433 az.tk.tr_664 
  0x13000e08, 0x3e360402, 0x42fc3e0c, 0x15373cee,   // is.et.un_430 fi.gn.rm_222  rm.zzp.co_543 ug.ba.un_422 
  // [10e00]
  0x2e130c0c, 0x0b1d2dee, 0x2d0952a4, 0x5d003313,   // sv.et.fo_543 sk.la.es_422  ha.pl.sk_433 nn.ss.un_650 
  0x222319af, 0x365f020c, 0x2e0e1e0c, 0x295d1da7,   // gl.ca.oc_655 da.tn.gn_543  ms.is.fo_543 la.ss.sl_532 
  0x24224308, 0x26190b08, 0x1f096107, 0x1d001212,   // ie.oc.eo_443 es.gl.ia_443  za.pl.cy_432 hu.la.un_640 
  0x5c000f02, 0x5c131cee, 0x082504a4, 0x08230a02,   // lv.sa.un_220 mr.bh.sa_422  ru.mn.uk_433 mk.ky.uk_222 
  // [10e10]
  0x0c034ca0, 0x11261d07, 0x6e003b09, 0x44151005,   // wo.nl.sv_322 la.ia.ro_432  so.hmn.un_440 be.kk.un_330 
  0x381515a4, 0x38000208, 0x0a000807, 0x48231707,   // un.tk.un_430 da.tk.un_430  uk.mk.un_420 sr.ky.tt_432 
  0xfe062a0c, 0x37484405, 0x37040804, 0x3f080204,   // mt.de.tlh_543 kk.tt.ba_333  uk.ru.ba_332 da.no.af_332 
  0x25151007, 0x064601a0, 0x4c301902, 0x020dfea0,   // be.mn.un_420 en.qu.de_322  gl.uz.wo_222 tlh.cs.da_322 
  // [10e20]
  0x0448150c, 0x3217fea6, 0x240c380c, 0x330863ee,   // un.tt.ru_543 tlh.sr.bs_521  tk.sv.eo_543 sco.no.nn_422 
  0x46005305, 0x5c000f1e, 0x2a32020c, 0x300dfe02,   // ht.qu.un_330 lv.sa.un_830  da.bs.mt_543 tlh.cs.uz_222 
  0x17040a0c, 0x2002feee, 0x6100fe19, 0x0200121a,   // mk.ru.sr_543 tlh.da.sq_422  tlh.za.un_750 hu.da.un_760 
  0x3f00630c, 0x0f004b1a, 0xfc00020d, 0x2d2e12ee,   // sco.af.un_530 mi.lv.un_760  da.zzp.un_540 hu.fo.sk_422 
  // [10e30]
  0x0c02fe04, 0x2400fe0e, 0x153f1d55, 0x4b005c20,   // tlh.da.sv_332 tlh.eo.un_550  la.af.un_442 sa.mi.un_850 
  0x5c004b1a, 0x1c003f04, 0x0f4b5c12, 0x34001104,   // mi.sa.un_760 af.id.un_320  sa.mi.lv_654 ro.xh.un_320 
  0x09366307, 0x50004b04, 0x25116712, 0x632c0604,   // sco.gn.pl_432 mi.fj.un_320  ak.ro.eu_654 de.fy.sco_332 
  0x4b006a23, 0x6a0428a9, 0x2500281a, 0x4c515811,   // haw.mi.un_880 sw.fi.haw_544  sw.eu.un_760 om.kl.wo_653 
  // [10e40]
  0x114f5a12, 0x0151130c, 0x252811a4, 0x05002d0d,   // sm.bi.ro_654 et.kl.en_543  ro.sw.eu_433 sk.fr.un_540 
  0x2500672a, 0x13006405, 0x123b30a4, 0x681d11a6,   // ak.eu.un_970 lg.et.un_330  uz.ks.ur_433 ro.la.ig_521 
  0x4c583ba4, 0x580313a4, 0x13645807, 0x133b64a9,   // so.om.wo_433 et.nl.om_433  om.lg.et_432 lg.so.et_544 
  0x28250d0c, 0x5d6878ee, 0x505a490c, 0x67024b0c,   // cs.eu.sw_543 ve.ig.ss_422  to.sm.fj_543 mi.da.ak_543 
  // [10e50]
  0x25114b14, 0x302507a6, 0x25261112, 0x32643ba4,   // mi.ro.eu_666 bg.mn.uz_521  ro.ia.eu_654 so.lg.bs_433 
  0x2a005a2b, 0x3b656404, 0x03004d12, 0x03511314,   // sm.mt.un_980 lg.gv.so_332  aa.nl.un_640 et.kl.nl_666 
  0x3f0364ec, 0x2e002d02, 0x03135114, 0x0358640d,   // lg.nl.af_644 sk.fo.un_220  kl.et.nl_666 lg.om.nl_554 
  0x0313640b, 0x1a1e1c5a, 0x51005807, 0x08154804,   // lg.et.nl_542 id.ms.tl_553  om.kl.un_420 tt.uk.un_320 
  // [10e60]
  0x48003908, 0x442310a4, 0x2e122d07, 0x233801ad,   // br.tt.un_430 be.ky.kk_433  sk.hu.fo_432 en.tk.ca_643 
  0x3c1530ec, 0x4f10fe0c, 0x4a122d60, 0x6e004f13,   // uz.ug.un_640 tlh.lt.bi_543  sk.hu.yo_664 bi.hmn.un_650 
  0x3e0b2214, 0x0c3915ad, 0x19360b60, 0x05236eec,   // oc.es.rm_666 un.br.sv_643  es.gn.gl_664 hmn.ca.fr_644 
  0x60000613, 0x62001f22, 0x300735ee, 0x131d3908,   // de.vo.un_650 cy.kha.un_870  tg.bg.uz_422 br.la.et_443 
  // [10e70]
  0xfe1f01a0, 0x4c6976a9, 0x1f001a02, 0x1b1a6b09,   // en.cy.tlh_322 crs.mfe.wo_544  tl.cy.un_220 ceb.tl.tr_444 
  0xfe5c6e14, 0x4c486ea7, 0x5e3b2a0c, 0x0c00fe05,   // hmn.sa.tlh_666 hmn.tt.wo_532  mt.so.ts_543 tlh.sv.un_330 
  0x1f093ba7, 0x4e3e22a9, 0x202205af, 0x0c0302a0,   // so.pl.cy_532 oc.rm.ay_544  fr.oc.sq_655 da.nl.sv_322 
  0x066301ad, 0x261143a4, 0x0f2a6e14, 0x0c060302,   // en.sco.de_643 ie.ro.ia_433  hmn.mt.lv_666 nl.de.sv_222 
  // [10e80]
  0x2812230c, 0x221a62ee, 0x150279ec, 0x2a006107,   // ky.ur.sd_543 kha.tl.oc_422  war.da.un_644 za.mt.un_420 
  0x4b005c12, 0x5c0f4baf, 0x20000804, 0x093e46a9,   // sa.mi.un_640 mi.lv.sa_655  no.sq.un_320 qu.rm.pl_544 
  0x0c384f07, 0x481723a0, 0x3600fe0d, 0x342821af,   // bi.tk.sv_432 ky.sr.tt_322  tlh.gn.un_540 fa.sd.ps_655 
  0x55003805, 0x08097907, 0x153035af, 0x301b36ee,   // tk.rw.un_330 war.pl.no_432  tg.uz.un_655 gn.tr.uz_422 
  // [10e90]
  0x2100fe08, 0x39000204, 0x061b30ec, 0x0a1108a4,   // tlh.jw.un_430 da.br.un_320  uz.tr.de_644 uk.ro.mk_433 
  0x34003f08, 0x0f00360b, 0x05000a05, 0x4b5c0fec,   // af.xh.un_430 gn.lv.un_520  pt.fr.un_330 lv.sa.mi_644 
  0x1b04430b, 0x110448ee, 0x5b004e0e, 0x0d292d12,   // ie.fi.tr_542 tt.fi.ro_422  ay.sg.un_550 sk.sl.cs_654 
  0x222739a0, 0x580704a4, 0x295825a4, 0x481538ac,   // br.gd.oc_322 fi.it.om_433  eu.om.sl_433 tk.tt.un_620 
  // [10ea0]
  0x6500fc0d, 0x4b0f5c12, 0x07422609, 0x0e0c33a7,   // zzp.gv.un_540 sa.lv.mi_654  ia.co.it_444 nn.sv.is_532 
  0x3500252b, 0x123444a4, 0x10000107, 0x303523a4,   // mn.tg.un_980 kk.ps.ur_433  en.lt.un_420 ky.tg.uz_433 
  0x1b04480c, 0x110539ad, 0xfe1902a0, 0x36001012,   // tt.fi.tr_543 br.fr.ro_643  da.gl.tlh_322 be.ab.un_640 
  0x07292d05, 0x2a074207, 0x3f043907, 0x34002c07,   // sk.sl.it_333 co.it.mt_432  br.fi.af_432 fy.xh.un_420 
  // [10eb0]
  0x041507a0, 0x46790b08, 0x0a151104, 0x5c000f1b,   // bg.ru.un_320 es.war.qu_443  ro.mk.un_320 lv.sa.un_770 
  0x463657ad, 0x0d002104, 0x252924a0, 0x366563a0,   // na.gn.qu_643 jw.cs.un_320  eo.sl.eu_322 sco.gv.gn_322 
  0x07002005, 0x05002504, 0x260b1da4, 0x2a000709,   // sq.it.un_330 eu.fr.un_320  la.es.ia_433 it.mt.un_440 
  0x183d12a9, 0x12002d0e, 0x090d13a9, 0x2b2f35a7,   // ur.ku.ar_544 sk.hu.un_550  bh.ne.hi_544 zu.su.vi_532 
  // [10ec0]
  0x42071d04, 0x05004a04, 0x1b0c2402, 0x5d34670c,   // la.it.co_332 yo.fr.un_320  eo.sv.tr_222 ak.xh.ss_543 
  0x0e2d2e0b, 0x5a491812, 0x122d0e05, 0x40671f08,   // fo.sk.is_542 ga.to.sm_654  is.sk.hu_333 cy.ak.lb_443 
  0x28680e05, 0x301f67ee, 0x0400081b, 0x322d2aee,   // is.ig.sw_333 ak.cy.uz_422  uk.ru.un_770 mt.sk.bs_422 
  0x0e002408, 0x2a4a1da4, 0x1f002113, 0x0a001919,   // eo.is.un_430 la.yo.mt_433  jw.cy.un_650 gl.pt.un_750 
  // [10ed0]
  0x5a3b6407, 0x15005504, 0x4700730e, 0x1f2c40ee,   // lg.so.sm_432 rw.un.un_320  ny.sn.un_550 lb.fy.cy_422 
  0x06001d0e, 0x1f0c2c02, 0x3e4301a9, 0x15000813,   // la.de.un_550 fy.sv.cy_222  en.ie.rm_544 uk.un.un_650 
  0x120e2eee, 0x0e001b21, 0x23371507, 0x39122aa7,   // fo.is.hu_422 tr.is.un_860  un.ba.ky_432 mt.hu.br_532 
  0x49535a04, 0x04081012, 0x111f0e0c, 0x343b35a4,   // sm.ht.to_332 be.uk.ru_654  is.cy.ro_543 zu.so.xh_433 
  // [10ee0]
  0x692a1fa4, 0x3f1f0205, 0x0d004207, 0x311b20ee,   // cy.mt.mfe_433 da.cy.af_333  co.cs.un_420 sq.tr.az_422 
  0x402c06a7, 0xfc0e06ee, 0x28122105, 0x40040604,   // de.fy.lb_532 de.is.zzp_422  fa.ur.sd_333 de.fi.lb_332 
  0x08001023, 0x2d1646a0, 0x0c13260c, 0x29004602,   // be.uk.un_880 qu.hr.sk_322  ia.et.sv_543 qu.sl.un_220 
  0x0900290b, 0xfe330808, 0x42000219, 0x27105a04,   // sl.pl.un_520 no.nn.tlh_443  da.co.un_750 sm.lt.gd_332 
  // [10ef0]
  0x225d520c, 0x1d26110c, 0x50494f07, 0x1e2f1c04,   // ha.ss.oc_543 ro.ia.la_543  bi.to.fj_432 id.su.ms_332 
  0x2100230c, 0x11000913, 0x2850730c, 0x071142ee,   // ca.jw.un_530 pl.ro.un_650  ny.fj.sw_543 co.ro.it_422 
  0x34454e0b, 0x1d242512, 0x0250130c, 0x30374812,   // ay.ln.xh_542 eu.eo.la_654  et.fj.da_543 tt.ba.uz_654 
  0x454b6811, 0x23222707, 0x483537ad, 0x48353408,   // ig.mi.ln_653 gd.oc.ca_432  ba.tg.tt_643 xh.zu.tt_443 
  // [10f00]
  0x73245a0c, 0xfc355107, 0x213c3ba4, 0x17353004,   // sm.eo.ny_543 kl.zu.zzp_432  ks.ug.fa_433 uz.tg.sr_332 
  0x190b3502, 0x460735a7, 0x343d3004, 0x07000102,   // zu.es.gl_222 zu.it.qu_532  uz.ku.ps_332 en.it.un_220 
  0x19590b0c, 0x50002f23, 0x2d002b0b, 0x23796ea4,   // es.rn.gl_543 su.fj.un_880  vi.sk.un_520 hmn.war.ca_433 
  0x34513507, 0x1d237909, 0x2d0f17a9, 0x614615af,   // zu.kl.xh_432 war.ca.la_444  sr.lv.sk_544 un.qu.za_655 
  // [10f10]
  0x150a070d, 0x25007614, 0x3b001108, 0x2e5803ee,   // bg.mk.un_554 crs.eu.un_660  ro.so.un_430 nl.om.fo_422 
  0x261d01a4, 0x44111505, 0x2d5909a4, 0x48001c05,   // en.la.ia_433 un.ro.kk_333  pl.rn.sk_433 id.tt.un_330 
  0x172311ee, 0x1900480d, 0x16041204, 0x2f5c3b07,   // ro.ky.sr_422 tt.gl.un_540  hu.fi.hr_332 so.sa.su_432 
  0x095c290c, 0x50313b04, 0x0a00310c, 0x5d5559ee,   // sl.sa.pl_543 so.az.fj_332  az.pt.un_530 rn.rw.ss_422 
  // [10f20]
  0x1d00500d, 0x35002320, 0x6b483012, 0x135830a9,   // fj.la.un_540 ky.tg.un_850  uz.tt.ceb_654 uz.om.et_544 
  0x3b185aad, 0x494b3312, 0x58005a11, 0x2530fc0c,   // sm.ga.so_643 nn.mi.to_654  sm.om.un_630 zzp.uz.eu_543 
  0x4e000b08, 0x5f75370b, 0x170930ee, 0x4d00301b,   // es.ay.un_430 st.nso.tn_542  uz.pl.sr_422 uz.aa.un_770 
  0x0e00300c, 0x3b0c1ca0, 0x400306a4, 0x113b5a0c,   // uz.is.un_530 id.sv.so_322  de.nl.lb_433 sm.so.ro_543 
  // [10f30]
  0x2f000604, 0x652c03ee, 0x65030605, 0x330e3ba4,   // de.su.un_320 nl.fy.gv_422  de.nl.gv_333 so.is.nn_433 
  0x3f4006a9, 0x2d0d295a, 0x48733012, 0x48383b08,   // de.lb.af_544 sl.cs.sk_553  uz.ny.tt_654 so.tk.tt_443 
  0x2e25485a, 0x1900300c, 0x1b003019, 0x20006402,   // tt.eu.fo_553 uz.gl.un_530  uz.tr.un_750 lg.sq.un_220 
  0x3e003023, 0x485a110c, 0x65335da0, 0x48301ca9,   // uz.rm.un_880 ro.sm.tt_543  ss.nn.gv_322 id.uz.tt_544 
  // [10f40]
  0x551c63a0, 0x6330380c, 0x482c73ee, 0x023003ec,   // sco.id.rw_322 tk.uz.sco_543  ny.fy.tt_422 nl.uz.da_644 
  0x21005204, 0x34003f02, 0x07081704, 0x3900230e,   // ha.jw.un_320 af.xh.un_220  sr.uk.bg_332 ca.br.un_550 
  0x13285004, 0x505a1caf, 0x020306a4, 0x42021311,   // fj.sw.et_332 id.sm.fj_655  de.nl.da_433 et.da.co_653 
  0x04170aaf, 0x6b02130b, 0x1300302b, 0x0a4435a0,   // mk.sr.ru_655 et.da.ceb_542  uz.et.un_980 tg.kk.mk_322 
  // [10f50]
  0x3e551312, 0x1b005004, 0x484423ad, 0x3c3507a4,   // et.rw.rm_654 fj.tr.un_320  ky.kk.tt_643 bg.tg.ug_433 
  0x44082504, 0x173025ee, 0x173015a0, 0x30120207,   // mn.uk.kk_332 eu.uz.sr_422  un.uz.sr_322 da.hu.uz_432 
  0x35003c20, 0x15004422, 0x121343ee, 0x22505a08,   // ug.tg.un_850 kk.un.un_870  ie.et.hu_422 sm.fj.oc_443 
  0x305002a4, 0x5a2f0207, 0x18234407, 0x1ffc3404,   // da.fj.uz_433 da.su.sm_432  kk.ky.ar_432 xh.zzp.cy_332 
  // [10f60]
  0x37153504, 0x56003302, 0x23004307, 0x33000c2c,   // tg.ba.un_320 nn.mg.un_220  ie.ca.un_420 sv.nn.un_990 
  0x0e243207, 0x33082102, 0x30253560, 0x33085ea9,   // bs.eo.is_432 jw.no.nn_222  tg.mn.uz_664 ts.no.nn_544 
  0x1f330807, 0x55001f09, 0x33005505, 0x12020ca6,   // no.nn.cy_432 cy.rw.un_440  rw.nn.un_330 sv.da.hu_521 
  0x30000813, 0x0b001005, 0x245610ad, 0x2f4a10ec,   // uk.uz.un_650 lt.es.un_330  lt.mg.eo_643 lt.yo.su_644 
  // [10f70]
  0x2f5910af, 0x32122407, 0x4a021007, 0x0c1310a0,   // lt.rn.su_655 eo.hu.bs_432  lt.da.yo_432 lt.et.sv_322 
  0x39007305, 0x2f29100d, 0x0c005507, 0x16000b04,   // ny.br.un_330 lt.sl.su_554  rw.sv.un_420 es.hr.un_320 
  0x30154808, 0x17380409, 0x0a233cec, 0x24001013,   // tt.uz.un_430 ru.tk.sr_444  ug.ky.mk_644 lt.eo.un_650 
  0x0a001019, 0x3e2810ee, 0x21002909, 0x73785ea9,   // lt.pt.un_750 lt.sw.rm_422  sl.jw.un_440 ts.ve.ny_544 
  // [10f80]
  0x0c023407, 0x47002a18, 0x4700671a, 0x554b6a07,   // xh.da.sv_432 mt.sn.un_740  ak.sn.un_760 haw.mi.rw_432 
  0x216b5ca0, 0x381511a4, 0x58002123, 0x5c00360e,   // sa.ceb.jw_322 ro.tk.un_430  jw.om.un_880 gn.sa.un_550 
  0x5b002813, 0x1a003805, 0x38095608, 0x47004205,   // sw.sg.un_650 tk.tl.un_330  mg.pl.tk_443 co.sn.un_330 
  0x301b2a12, 0x2000350e, 0x11050705, 0x3600560d,   // mt.tr.uz_654 zu.sq.un_550  it.fr.ro_333 mg.gn.un_540 
  // [10f90]
  0x21001d02, 0x36005605, 0x65005e1a, 0x0e040f0c,   // la.jw.un_220 mg.gn.un_330  ts.gv.un_760 lv.fi.is_543 
  0x78002036, 0x18042712, 0x06153ba7, 0x75003708,   // sq.ve.un_AA0 gd.fi.ga_654  so.de.un_520 st.nso.un_430 
  0x0700110e, 0x69462a0e, 0x3e2738ee, 0x0400330d,   // ro.bg.un_550 mt.qu.mfe_555  tk.gd.rm_422 nn.fi.un_540 
  0x211146ad, 0x5c15690b, 0x40061b0c, 0x152101a0,   // qu.ro.jw_643 mfe.sa.un_520  tr.de.lb_543 en.jw.un_322 
  // [10fa0]
  0x35285502, 0x162e0ca7, 0x0b232212, 0x110a0713,   // rw.sw.zu_222 sv.fo.hr_532  oc.ca.es_654 bg.mk.ro_665 
  0x2e100ca4, 0x30383607, 0x04001122, 0x53693613,   // sv.lt.fo_433 gn.tk.uz_432  ro.fi.un_870 gn.mfe.ht_665 
  0x04300aa0, 0x38fc1f0b, 0x1036380c, 0x0e3b095a,   // mk.uz.ru_322 cy.zzp.tk_542  tk.gn.lt_543 pl.so.is_553 
  0x0900031a, 0x32091e0b, 0x100d040c, 0x2e0e0ca9,   // nl.pl.un_760 ms.pl.bs_542  fi.cs.lt_543 sv.is.fo_544 
  // [10fb0]
  0x06020ca0, 0x040c48a7, 0x0f001302, 0x040a1711,   // sv.da.de_322 tt.sv.fi_532  et.lv.un_220 sr.mk.ru_653 
  0x04004f14, 0x4f0f5c0c, 0x1008070c, 0x23465ca6,   // bi.fi.un_660 sa.lv.bi_543  bg.uk.be_543 sa.qu.ca_521 
  0x1969240c, 0x0a003804, 0x46003013, 0x232812ad,   // eo.mfe.gl_543 tk.pt.un_320  uz.qu.un_650 ur.sd.ky_643 
  0x3e004e07, 0x121d10a4, 0x4a2f0204, 0x44374802,   // ay.rm.un_420 lt.la.hu_433  da.su.yo_332 tt.ba.kk_222 
  // [10fc0]
  0x48381baf, 0x110b40a9, 0x53002a04, 0x5d2002ad,   // tr.tk.tt_655 lb.es.ro_544  mt.ht.un_320 da.sq.ss_643 
  0x040725a9, 0x2f0b3607, 0x361c21a4, 0x19230d04,   // mn.bg.ru_544 gn.es.su_432  jw.id.gn_433 cs.ca.gl_332 
  0x08021007, 0x2328180c, 0x182112af, 0x292d09ad,   // lt.da.no_432 ar.sd.ky_543  ur.fa.ar_655 pl.sk.sl_643 
  0x35234811, 0x443515ee, 0x173010a0, 0x11003014,   // tt.ky.tg_653 un.tg.kk_422  be.uz.sr_322 uz.ro.un_660 
  // [10fd0]
  0x0c00600e, 0x1d190a05, 0x49002f07, 0x0e033f07,   // vo.sv.un_550 pt.gl.la_333  su.to.un_420 af.nl.is_432 
  0x170c3304, 0x1d0f3ea9, 0x48003b23, 0x08020c0c,   // nn.sv.sr_332 rm.lv.la_544  so.tt.un_880 sv.da.no_543 
  0x0e3b63ee, 0x135c1cac, 0x651d4d07, 0x103f30ee,   // sco.so.is_422 mr.sa.bh_632  aa.la.gv_432 uz.af.lt_422 
  0x12002120, 0x2b004804, 0x3e421ca0, 0x3f004219,   // fa.ur.un_850 tt.vi.un_320  id.co.rm_322 co.af.un_750 
  // [10fe0]
  0x38003621, 0x1b003e04, 0x37070aa9, 0x345035ee,   // ab.tk.un_860 rm.tr.un_320  mk.bg.ba_544 zu.fj.xh_422 
  0x4c003608, 0x173c23a4, 0x38001b21, 0xfefc1baf,   // gn.wo.un_430 ky.ug.sr_433  tr.tk.un_860 tr.zzp.tlh_655 
  0x0e1918a7, 0x20005107, 0x1d02fc09, 0x35005108,   // ga.gl.is_532 kl.sq.un_420  zzp.da.la_444 kl.zu.un_430 
  0x211834ee, 0x1800360d, 0x041358ec, 0x100f4e14,   // ps.ar.fa_422 gn.ga.un_540  om.et.fi_644 ay.lv.lt_666 
  // [10ff0]
  0x3b0458ec, 0x234a18ee, 0x3b586760, 0x51004904,   // om.fi.so_644 ga.yo.ca_422  ak.om.so_664 to.kl.un_320 
  0x18fc1da0, 0x493b580d, 0x582804a9, 0x673b5812,   // la.zzp.ga_322 om.so.to_554  fi.sw.om_544 om.so.ak_654 
  0x644b57a4, 0x6728585a, 0x513b58a9, 0x192d0d13,   // na.mi.lg_433 om.sw.ak_553  om.so.kl_544 cs.sk.gl_665 
  0x244702ee, 0x1d1f4bad, 0x4c3b58ec, 0x4602250c,   // da.sn.eo_422 mi.cy.la_643  om.so.wo_644 eu.da.qu_543 
  
  // [11000]
  0x3b4d5813, 0x371c2504, 0x1ffc0207, 0x120e2e05,   // om.aa.so_665 eu.id.st_332  da.zzp.cy_432 fo.is.hu_333 
  0x455828a4, 0x543b5812, 0xfc014eec, 0x5a5104a9,   // sw.om.ln_433 om.so.ik_654  ay.en.zzp_644 fi.kl.sm_544 
  0x32162907, 0x686758a9, 0x0467580e, 0x3b6758ec,   // sl.hr.bs_432 om.ak.ig_544  om.ak.fi_555 om.ak.so_644 
  0x0e000905, 0x4c6758ec, 0x044a6a0d, 0x370336a0,   // pl.is.un_330 om.ak.wo_644  haw.yo.fi_554 gn.nl.st_322 
  // [11010]
  0x0e000a08, 0x4b405fa0, 0x254b390d, 0x21181260,   // pt.is.un_430 tn.lb.mi_322  br.mi.eu_554 ur.ar.fa_664 
  0x47006421, 0x5102570c, 0x073925a0, 0x2a006419,   // lg.sn.un_860 na.da.kl_543  eu.br.it_322 lg.mt.un_750 
  0x2800730d, 0x1b3564ec, 0x55686405, 0x480b3605,   // ny.sw.un_540 lg.zu.tr_644  lg.ig.rw_333 gn.es.tt_333 
  0x652718a9, 0x0c000e2b, 0x02005d19, 0x1f1827a4,   // ga.gd.gv_544 is.sv.un_980  ss.da.un_750 gd.ga.cy_433 
  // [11020]
  0x200e1f11, 0x184006a7, 0x28353409, 0x631f40a4,   // cy.is.sq_653 de.lb.ga_532  xh.zu.sw_444 lb.cy.sco_433 
  0x0c026507, 0x38190b02, 0x0a4844a0, 0x070a440b,   // gv.da.sv_432 es.gl.tk_222  kk.tt.mk_322 kk.mk.bg_542 
  0x0f0e60ad, 0x063e23ee, 0x0100360b, 0x250b36a0,   // vo.is.lv_643 ca.rm.de_422  gn.en.un_520 gn.es.eu_322 
  0x3b006309, 0x22004308, 0x10351707, 0x3e1516a0,   // sco.so.un_440 ie.oc.un_430  sr.tg.be_432 hr.rm.un_320 
  // [11030]
  0x2d003b02, 0x022d0d60, 0x432201a4, 0x1553600c,   // so.sk.un_220 cs.sk.da_664  en.oc.ie_433 vo.ht.un_543 
  0x26011508, 0x22233e07, 0x221d0107, 0x2b002608,   // un.en.ia_443 rm.ca.oc_432  en.la.oc_432 ia.vi.un_430 
  0x1d42070c, 0x01001b04, 0x11025705, 0x03000502,   // it.co.la_543 tr.en.un_320  na.da.ro_333 fr.nl.un_220 
  0x231d2209, 0x444823a0, 0x05002b05, 0x42070213,   // oc.la.ca_444 ky.tt.kk_322  vi.fr.un_330 da.it.co_665 
  // [11040]
  0x2b000b05, 0x12000a14, 0x19123604, 0x1e001f08,   // es.vi.un_330 pt.hu.un_660  gn.hu.gl_332 cy.ms.un_430 
  0x1d000f02, 0x072315a0, 0x2f006108, 0x562f300c,   // lv.la.un_220 un.ky.bg_322  za.su.un_430 uz.su.mg_543 
  0x040730a0, 0x3744110c, 0xfc6401a4, 0x3d123007,   // uz.bg.ru_322 ro.kk.ba_543  en.lg.zzp_433 uz.ur.ku_432 
  0x61006222, 0x26005605, 0x3004070e, 0x0f101da0,   // kha.za.un_870 mg.ia.un_330  bg.ru.uz_555 la.lt.lv_322 
  // [11050]
  0x305a5d07, 0x23351708, 0x5a2802a7, 0x285201a4,   // ss.sm.uz_432 sr.tg.ky_443  da.sw.sm_532 en.ha.sw_433 
  0x081711ac, 0x5d474902, 0x1023485a, 0x183c34a0,   // ro.sr.uk_632 to.sn.ss_222  tt.ky.be_553 ps.ug.ar_322 
  0x55116007, 0x106429ec, 0x49004c04, 0x5700291b,   // vo.ro.rw_432 sl.lg.lt_644  wo.to.un_320 sl.na.un_770 
  0x21001221, 0x5500290e, 0x1000291a, 0x0b3629a7,   // ur.fa.un_860 sl.rw.un_550  sl.lt.un_760 sl.gn.es_532 
  // [11060]
  0x10002913, 0x64005813, 0x644d5907, 0x101729ec,   // sl.lt.un_650 om.lg.un_650  rn.aa.lg_432 sl.sr.lt_644 
  0x06000212, 0x12001d04, 0x4f285aa4, 0x2800520e,   // da.de.un_640 la.hu.un_320  sm.sw.bi_433 ha.sw.un_550 
  0x304c29ee, 0x5a5b4908, 0x1200500c, 0x39006519,   // sl.wo.uz_422 to.sg.sm_443  fj.hu.un_530 gv.br.un_750 
  0x0c29390c, 0x374423a4, 0x23194aee, 0x0e2e0d14,   // br.sl.sv_543 ky.kk.ba_433  yo.gl.ca_422 cs.fo.is_666 
  // [11070]
  0x02396505, 0x1f2765ad, 0x1d0757a7, 0x02602507,   // gv.br.da_333 gv.gd.cy_643  na.it.la_532 eu.vo.da_432 
  0x1f233904, 0x041202ee, 0x3f030eee, 0xfc120404,   // br.ca.cy_332 da.hu.fi_422  is.nl.af_422 fi.hu.zzp_332 
  0x302335a0, 0x0f127904, 0x29124d07, 0x39006508,   // tg.ky.uz_322 war.hu.lv_332  aa.hu.sl_432 gv.br.un_430 
  0x464dfe12, 0x39120e11, 0x2d290d04, 0x422307a4,   // tlh.aa.qu_654 is.hu.br_653  cs.sl.sk_332 it.ca.co_433 
  // [11080]
  0x12006508, 0x2a103b0d, 0x4d4a270c, 0x1a023b09,   // gv.hu.un_430 so.lt.mt_554  gd.yo.aa_543 so.da.tl_444 
  0x11fe2a0c, 0xfe044204, 0x642a0ba4, 0x1017365a,   // mt.tlh.ro_543 co.fi.tlh_332  es.mt.lg_433 ab.sr.be_553 
  0x3b314807, 0x656425a0, 0x685b4a12, 0x020f06a9,   // tt.az.so_432 eu.lg.gv_322  yo.sg.ig_654 de.lv.da_544 
  0x79061bee, 0x190a0ba9, 0x12233b07, 0x0d002912,   // tr.de.war_422 es.pt.gl_544  so.ca.hu_432 sl.cs.un_640 
  // [11090]
  0x3f2c06ee, 0x2c0c4aee, 0x190a6402, 0x12160d07,   // de.fy.af_422 yo.sv.fy_422  lg.pt.gl_222 cs.hr.hu_432 
  0x3b000908, 0x56020ca0, 0xfe0d2daf, 0x3bfe6208,   // pl.so.un_430 sv.da.mg_322  sk.cs.tlh_655 kha.tlh.so_443 
  0x2a00620d, 0x07081112, 0x30443807, 0x530d1004,   // kha.mt.un_540 ro.uk.bg_654  tk.kk.uz_432 lt.cs.ht_332 
  0x332e1f05, 0x4d000d08, 0x1238fea9, 0x303848a4,   // cy.fo.nn_333 cs.aa.un_430  tlh.tk.hu_544 tt.tk.uz_433 
  // [110a0]
  0x10040702, 0x40066304, 0x13244807, 0x6b016504,   // bg.ru.be_222 sco.de.lb_332  tt.eo.et_432 gv.en.ceb_332 
  0x4423300c, 0x24021304, 0x5818fc08, 0x3600020d,   // uz.ky.kk_543 et.da.eo_332  zzp.ga.om_443 da.gn.un_540 
  0x341801a4, 0x252348ee, 0x23483604, 0x36352513,   // iw.ar.ps_433 tt.ky.mn_422  ab.tt.ky_332 mn.tg.ab_665 
  0x25000409, 0x23374807, 0x3f08020d, 0x0d091ca7,   // ru.mn.un_440 tt.ba.ky_432  da.no.af_554 mr.hi.ne_532 
  // [110b0]
  0x04071707, 0x3610350c, 0x2300360d, 0x24001a0b,   // sr.bg.ru_432 tg.be.ab_543  ab.ky.un_540 tl.eo.un_520 
  0x6e63fe0c, 0x13001e1a, 0xfe4f240c, 0x2e230560,   // tlh.sco.hmn_543 ms.et.un_760  eo.bi.tlh_543 fr.ca.fo_664 
  0xfc320105, 0x1ffe100d, 0x32004c02, 0x1e1d39a7,   // en.bs.zzp_333 lt.tlh.cy_554  wo.bs.un_220 br.la.ms_532 
  0x402c0607, 0x05006e34, 0x64214c0c, 0x23060512,   // de.fy.lb_432 hmn.fr.un_A80  wo.jw.lg_543 fr.de.ca_654 
  // [110c0]
  0x044436ee, 0x630e130c, 0x4c004a05, 0x6e234f12,   // ab.kk.ru_422 et.is.sco_543  yo.wo.un_330 bi.ca.hmn_654 
  0x1f0c22a4, 0x382a1504, 0x6e690313, 0x170407a4,   // oc.sv.cy_433 un.mt.tk_332  nl.mfe.hmn_665 bg.ru.sr_433 
  0x650c63a4, 0x6e00011a, 0x1812650c, 0x4c003812,   // sco.sv.gv_433 en.hmn.un_760  gv.hu.ga_543 tk.wo.un_640 
  0x17083804, 0x1f3f0355, 0x1d630104, 0x383e05a9,   // tk.uk.sr_332 nl.af.cy_442  en.sco.la_332 fr.rm.tk_544 
  // [110d0]
  0x3b001312, 0x38004819, 0x4f29fe08, 0x213f63a9,   // et.so.un_640 tt.tk.un_750  tlh.sl.bi_443 sco.af.jw_544 
  0x3f631355, 0x69056eac, 0x13033f07, 0x18010204,   // et.sco.af_442 hmn.fr.mfe_632  af.nl.et_432 da.en.ga_332 
  0x2925650d, 0x76431211, 0x033b4d0c, 0x242e3302,   // gv.eu.sl_554 hu.ie.crs_653  aa.so.nl_543 nn.fo.eo_222 
  0x13002821, 0x3b033fec, 0x0c002c02, 0x23001f1a,   // sw.et.un_860 af.nl.so_644  fy.sv.un_220 cy.ca.un_760 
  // [110e0]
  0x4c000312, 0x23111f13, 0x3100fe08, 0x170823a9,   // nl.wo.un_640 cy.ro.ca_665  tlh.az.un_430 ky.uk.sr_544 
  0xfa003714, 0x233957a4, 0x38080209, 0x12381b0c,   // st.nr.un_660 na.br.ca_433  da.no.tk_444 tr.tk.hu_543 
  0x046447a7, 0x04381b0c, 0x401304a6, 0x13200607,   // sn.lg.fi_532 tr.tk.fi_543  fi.et.lb_521 de.sq.et_432 
  0x381b130b, 0x2d20240c, 0x29241307, 0x026b1dad,   // et.tr.tk_542 eo.sq.sk_543  et.eo.sl_432 la.ceb.da_643 
  // [110f0]
  0x020524ee, 0x23001104, 0x55005002, 0x401f08a0,   // eo.fr.da_422 ro.ca.un_320  fj.rw.un_220 no.cy.lb_322 
  0x3f034509, 0x13402ab4, 0x2d1b38a0, 0x5e2a6504,   // ln.nl.af_444 mt.lb.et_754  tk.tr.sk_322 gv.mt.ts_332 
  0x1b3f3804, 0x35254a07, 0x40005807, 0x23131b05,   // tk.af.tr_332 yo.eu.zu_432  om.lb.un_420 tr.et.ca_333 
  0x613534ad, 0x55033302, 0x1b240807, 0x351d4ca4,   // xh.zu.za_643 nn.nl.rw_222  no.eo.tr_432 wo.la.zu_433 
  // [11100]
  0x40422aa0, 0x3500680c, 0x125362af, 0x17113555,   // mt.co.lb_322 ig.zu.un_530  kha.ht.hu_655 tg.ro.sr_442 
  0x15003e09, 0x472d510c, 0x431f42af, 0x18000102,   // rm.un.un_440 kl.sk.sn_543  co.cy.ie_655 en.ga.un_220 
  0x0b595704, 0x4c20fe0c, 0x080633ec, 0x35151160,   // na.rn.es_332 tlh.sq.wo_543  nn.de.no_644 ro.tg.un_640 
  0x4c001204, 0x3c0a23a4, 0x42074008, 0x15401e04,   // hu.wo.un_320 ky.mk.ug_433  lb.it.co_443 ms.lb.un_332 
  // [11110]
  0x365d4707, 0x2a00580c, 0x73005f1a, 0x070a4808,   // sn.ss.gn_432 om.mt.un_530  tn.ny.un_760 tt.mk.bg_443 
  0x033f2aee, 0x200f1009, 0x20512f07, 0x2f4760a4,   // mt.af.nl_422 lt.lv.sq_444  su.kl.sq_432 vo.sn.su_433 
  0x47001214, 0x5d004704, 0x300f2da4, 0x1b11290c,   // hu.sn.un_660 sn.ss.un_320  sk.lv.uz_433 sl.ro.tr_543 
  0x360a50a0, 0x291b2f07, 0x29092dad, 0x25122402,   // fj.pt.gn_322 su.tr.sl_432  sk.pl.sl_643 eo.hu.eu_222 
  // [11120]
  0x241d15ad, 0x1d000a04, 0x20002902, 0x5d3415ad,   // un.la.eo_643 pt.la.un_320  sl.sq.un_220 un.xh.ss_643 
  0x433b11a4, 0x150742ec, 0x4c001f0d, 0x06404304,   // ro.so.ie_433 co.it.un_644  cy.wo.un_540 ie.lb.de_332 
  0x1b000b08, 0x31091b12, 0x48151004, 0x31420707,   // es.tr.un_430 tr.pl.az_654  be.tt.un_320 it.co.az_432 
  0x02fc0b07, 0x315a29a0, 0x73006508, 0x3b790f05,   // es.zzp.da_432 sl.sm.az_322  gv.ny.un_430 lv.war.so_333 
  // [11130]
  0x330cfca0, 0x292d09a4, 0xfc000808, 0x606301a0,   // zzp.sv.nn_322 pl.sk.sl_433  no.zzp.un_430 en.sco.vo_322 
  0x1e3b31ee, 0x23240fee, 0x166b1dee, 0x071d01a0,   // az.so.ms_422 lv.eo.ca_422  la.ceb.hr_422 en.la.it_322 
  0x17002a07, 0x5c0913ec, 0x0836110c, 0x06002805,   // mt.sr.un_420 bh.hi.sa_644  ro.ab.uk_543 sw.de.un_330 
  0x0600400e, 0x4f400107, 0x060cfc07, 0x2b65fea4,   // lb.de.un_550 en.lb.bi_432  zzp.sv.de_432 tlh.gv.vi_433 
  // [11140]
  0x0640fc0c, 0x3c4830a4, 0x1218215a, 0x150810a4,   // zzp.lb.de_543 uz.tt.ug_433  fa.ar.ur_553 be.uk.un_433 
  0x23251012, 0x154830a4, 0x041510ad, 0x18342107,   // be.mn.ky_654 uz.tt.un_433  be.ru.un_630 fa.ps.ar_432 
  0x441821a9, 0x234844a9, 0x48000704, 0x34213baf,   // fa.ar.kk_544 kk.tt.ky_544  bg.tt.un_320 ks.fa.ps_655 
  0x15101108, 0x44483805, 0x35251508, 0x4837040c,   // ro.be.un_443 tk.tt.kk_333  un.mn.tg_443 ru.ba.tt_543 
  // [11150]
  0x36483511, 0x22002708, 0x04151112, 0x5e3864a7,   // tg.tt.ab_653 gd.oc.un_430  ro.ru.un_640 lg.tk.ts_532 
  0x64551f55, 0x37401107, 0x5c5355a4, 0x38064804,   // cy.rw.lg_442 ro.lb.st_432  rw.ht.sa_433 tt.de.tk_332 
  0x2b003007, 0x43386707, 0x0411080c, 0x64385507,   // uz.vi.un_420 ak.tk.ie_432  uk.ro.ru_543 rw.tk.lg_432 
  0x251536ec, 0x3800550d, 0x6455380c, 0x6438550c,   // ab.mn.un_640 rw.tk.un_540  tk.rw.lg_543 rw.tk.lg_543 
  // [11160]
  0x6400682a, 0x643855af, 0x595567a4, 0x13381bec,   // ig.lg.un_970 rw.tk.lg_655  ak.rw.rn_433 tr.tk.et_644 
  0x3d003b20, 0x27000b04, 0x42000607, 0xfc295aa4,   // ks.ku.un_850 es.gd.un_320  de.co.un_420 sm.sl.zzp_433 
  0x3622240c, 0x213830a9, 0x2f1238a0, 0x0a173ca0,   // eo.oc.gn_543 uz.tk.jw_544  tk.hu.su_322 ug.sr.mk_322 
  0x020a04a7, 0x04254004, 0x04005813, 0x3f070f07,   // fi.pt.da_532 lb.eu.fi_332  om.fi.un_650 lv.it.af_432 
  // [11170]
  0x532223a7, 0x1b312aa4, 0x3e00250d, 0x15303712,   // ca.oc.ht_532 mt.az.tr_433  eu.rm.un_540 ba.uz.un_654 
  0x3b4663a0, 0x69537614, 0x63002e08, 0x5c1e1c12,   // sco.qu.so_322 crs.ht.mfe_666  fo.sco.un_430 id.ms.sa_654 
  0x1b001112, 0xfe002e04, 0x435d600c, 0x306504ee,   // ro.tr.un_640 fo.tlh.un_320  vo.ss.ie_543 fi.gv.uz_422 
  0x4c690408, 0x46101307, 0x10004a04, 0x380679a7,   // fi.mfe.wo_443 et.lt.qu_432  yo.lt.un_320 war.de.tk_532 
  // [11180]
  0x42111dad, 0x17001104, 0x35345da7, 0x48070402,   // la.ro.co_643 ro.sr.un_320  ss.xh.zu_532 ru.bg.tt_222 
  0x4322fca4, 0x3000100c, 0xfc261da9, 0x020f200b,   // zzp.oc.ie_433 be.uz.un_530  la.ia.zzp_544 sq.lv.da_542 
  0x150a1705, 0xfc1b3808, 0x46002008, 0x31190a0c,   // sr.mk.un_333 tk.tr.zzp_443  sq.qu.un_430 pt.gl.az_543 
  0x1b001519, 0x11004004, 0x362efc0b, 0x11374408,   // un.tr.un_750 lb.ro.un_320  zzp.fo.gn_542 kk.ba.ro_443 
  // [11190]
  0x30253ca4, 0x30006e07, 0x34301204, 0x38004809,   // ug.mn.uz_433 hmn.uz.un_420  ur.uz.ps_332 tt.tk.un_440 
  0x1300480c, 0x40062507, 0x444837a0, 0x15361507,   // tt.et.un_530 eu.de.lb_432  ba.tt.kk_322 un.ab.un_432 
  0x28213dad, 0x04380a55, 0x38003113, 0x402506a0,   // ku.fa.sd_643 mk.tk.ru_442  az.tk.un_650 de.eu.lb_322 
  0x152311a4, 0x18003621, 0x313848a7, 0x44303c12,   // ro.ky.un_433 gn.ga.un_860  tt.tk.az_532 ug.uz.kk_654 
  // [111a0]
  0x35302355, 0x3d213b0b, 0x10150707, 0x302128a9,   // ky.uz.tg_442 ks.fa.ku_542  bg.be.un_420 sd.fa.uz_544 
  0x1b1131a6, 0x06025eec, 0x290d2dec, 0x120a2304,   // az.ro.tr_521 ts.da.de_644  sk.cs.sl_644 ca.pt.hu_332 
  0x1704070b, 0x4600100e, 0x48003e0d, 0x1ffc0305,   // bg.ru.sr_542 lt.qu.un_550  rm.tt.un_540 nl.zzp.cy_333 
  0x48303902, 0x03253fa0, 0x6b007904, 0x302948a4,   // br.uz.tt_222 af.eu.nl_322  war.ceb.un_320 tt.sl.uz_433 
  // [111b0]
  0x1f1118af, 0x23001f04, 0xfc067904, 0x36390aa0,   // ga.ro.cy_655 cy.ca.un_320  war.de.zzp_332 pt.br.gn_322 
  0x095c0207, 0x50000a05, 0x13024002, 0x462140ee,   // da.sa.pl_432 pt.fj.un_330  lb.da.et_222 lb.jw.qu_422 
  0x76256912, 0x5835515a, 0x58305404, 0x31004e22,   // mfe.eu.crs_654 kl.zu.om_553  ik.uz.om_332 ay.az.un_870 
  0x0a2319ee, 0x4c0242ad, 0x0b112da4, 0xfc005102,   // gl.ca.pt_422 co.da.wo_643  sk.ro.es_433 kl.zzp.un_220 
  // [111c0]
  0x292d4607, 0x0a133f04, 0x3b204d07, 0x55345d11,   // qu.sk.sl_432 af.et.pt_332  aa.sq.so_432 ss.xh.rw_653 
  0x073035a0, 0x3b35345a, 0x255c3907, 0x00001b2d,   // tg.uz.bg_322 xh.zu.so_553  br.sa.eu_432 tr.un.un_A00 
  0x010676a4, 0x17002919, 0x2f190b0e, 0x3e110aee,   // crs.de.en_433 sl.sr.un_750  es.gl.su_555 pt.ro.rm_422 
  0xfc003113, 0x50122f07, 0x3b354602, 0x220a11a6,   // az.zzp.un_650 su.hu.fj_432  qu.zu.so_222 ro.pt.oc_521 
  // [111d0]
  0xfe4e20ad, 0x50514d0b, 0x16001b02, 0x110a510c,   // sq.ay.tlh_643 aa.kl.fj_542  tr.hr.un_220 kl.pt.ro_543 
  0x1c4007ad, 0x210802a0, 0x0e0608ee, 0x7300210e,   // it.lb.id_643 da.no.jw_322  no.de.is_422 jw.ny.un_550 
  0x080704a9, 0x43234612, 0x18002004, 0x5c004e22,   // ru.bg.uk_544 qu.ca.ie_654  sq.ga.un_320 ay.sa.un_870 
  0x01636504, 0x10211aa9, 0x08001119, 0x60021d08,   // gv.sco.en_332 tl.jw.lt_544  ro.uk.un_750 la.da.vo_443 
  // [111e0]
  0x651223ad, 0x272c0807, 0x0602080b, 0x3c4418a4,   // ca.hu.gv_643 no.fy.gd_432  no.da.de_542 ar.kk.ug_433 
  0x19460b0c, 0x0b003609, 0x50630107, 0x2e0c03a4,   // es.qu.gl_543 gn.es.un_440  en.sco.fj_432 nl.sv.fo_433 
  0x095e0dec, 0x6a5a50a4, 0x38000b02, 0x48464e5e,   // cs.ts.pl_644 fj.sm.haw_433  es.tk.un_220 ay.qu.tt_652 
  0x374411a4, 0x28003421, 0x4825100d, 0x244f01a4,   // ro.kk.ba_433 ps.sd.un_860  be.mn.tt_554 en.bi.eo_433 
  // [111f0]
  0x02630412, 0x0b1938a0, 0x211c2f08, 0x0712fe0c,   // fi.sco.da_654 tk.gl.es_322  su.id.jw_443 tlh.hu.it_543 
  0xfc00130b, 0x0c071207, 0x483c3712, 0x301b6304,   // et.zzp.un_520 hu.it.sv_432  ba.ug.tt_654 sco.tr.uz_332 
  0x36190ba9, 0x0e4d5411, 0x394c2aee, 0x0c1242ee,   // es.gl.gn_544 ik.aa.is_653  mt.wo.br_422 co.hu.sv_422 
  0x2823440c, 0x09003e02, 0x4d00641a, 0x58005108,   // kk.ky.sd_543 rm.pl.un_220  lg.aa.un_760 kl.om.un_430 
  // [11200]
  0x210f3808, 0x7951640c, 0x3d00232a, 0x52583fa0,   // tk.lv.jw_443 lg.kl.war_543  ky.ku.un_970 af.om.ha_322 
  0x07006412, 0x4d006419, 0x2800181a, 0x154d58a4,   // lg.it.un_640 lg.aa.un_750  ar.sd.un_760 om.aa.un_433 
  0x51004204, 0x4d545111, 0x122128a9, 0x07330804,   // co.kl.un_320 kl.ik.aa_653  sd.fa.ur_544 no.nn.it_332 
  0x020664ad, 0x2a004d0e, 0x38002520, 0x36190a0c,   // lg.de.da_643 aa.mt.un_550  mn.tk.un_850 pt.gl.gn_543 
  // [11210]
  0x303544a7, 0x213d1202, 0x5e643504, 0x4c006409,   // kk.tg.uz_532 ur.ku.fa_222  zu.lg.ts_332 lg.wo.un_440 
  0x233c1808, 0x28525802, 0x4c006407, 0x171504a0,   // ar.ug.ky_443 om.ha.sw_222  lg.wo.un_420 ru.sr.un_320 
  0x5d3564a4, 0x532322a7, 0x08100204, 0x041012ee,   // lg.zu.ss_433 oc.ca.ht_532  da.lt.no_332 hu.lt.fi_422 
  0x27002b05, 0x0d042da4, 0x0904150c, 0x172d0d09,   // vi.gd.un_330 sk.fi.cs_433  un.fi.pl_543 cs.sk.sr_444 
  // [11220]
  0x355d3460, 0x53190b08, 0x375e64a0, 0x35645d13,   // xh.ss.zu_664 es.gl.ht_443  lg.ts.st_322 ss.lg.zu_665 
  0x0c670d0c, 0x37353460, 0x10060907, 0x2b003902,   // cs.ak.sv_543 xh.zu.st_664  pl.de.lt_432 br.vi.un_220 
  0x071715a0, 0x041036ad, 0x040910a4, 0x04083807,   // un.sr.bg_322 gn.lt.fi_643  lt.pl.fi_433 tk.uk.ru_432 
  0x1e1c610c, 0x1300610c, 0x231d26ec, 0x07100813,   // za.id.ms_543 za.et.un_530  ia.la.ca_644 uk.be.bg_665 
  // [11230]
  0x19120ba9, 0x1d002a0b, 0x24331204, 0x36001207,   // es.hu.gl_544 mt.la.un_520  hu.nn.eo_332 hu.gn.un_420 
  0x2821340b, 0x212a4d07, 0x381535a0, 0x4a001219,   // ps.fa.sd_542 aa.mt.jw_432  tg.tk.un_320 hu.yo.un_750 
  0x4600110c, 0x11006505, 0x39464e11, 0x251f6507,   // ro.qu.un_530 gv.ro.un_330  ay.qu.br_653 gv.cy.eu_432 
  0x20001113, 0x4300120d, 0x5a561fa0, 0x39004e12,   // ro.sq.un_650 hu.ie.un_540  cy.mg.sm_322 ay.br.un_640 
  // [11240]
  0x0e1912ac, 0x2628fc08, 0x401bfe07, 0x63fc3307,   // hu.gl.is_632 zzp.sw.ia_443  tlh.tr.lb_432 nn.zzp.sco_432 
  0x202dfe07, 0x630f1305, 0x1100650d, 0x15303509,   // tlh.sk.sq_432 et.lv.sco_333  gv.ro.un_540 tg.uz.un_444 
  0x4b005a0c, 0x58004d21, 0x2f6bfea0, 0x11006504,   // sm.mi.un_530 aa.om.un_860  tlh.ceb.su_322 gv.ro.un_320 
  0x394c4ead, 0x0742040c, 0x2651010c, 0x65331fa4,   // ay.wo.br_643 fi.co.it_543  en.kl.ia_543 cy.nn.gv_433 
  // [11250]
  0x234324a7, 0x114620a0, 0x3300fc05, 0x30001b1a,   // eo.ie.ca_532 sq.qu.ro_322  zzp.nn.un_330 tr.uz.un_760 
  0x5c002e0e, 0x10080455, 0x01002414, 0x34302807,   // fo.sa.un_550 ru.uk.be_442  yi.iw.un_660 sd.uz.ps_432 
  0x170415a9, 0x394902a4, 0x4b0245a4, 0x65494ca0,   // un.ru.sr_544 da.to.br_433  ln.da.mi_433 wo.to.gv_322 
  0x1b31fea0, 0x53474f05, 0x08073702, 0x2c6045a7,   // tlh.az.tr_322 bi.sn.ht_333  ba.bg.uk_222 ln.vo.fy_532 
  // [11260]
  0x2e025113, 0x39005319, 0x4a2d0d60, 0x45024755,   // kl.da.fo_665 ht.br.un_750  cs.sk.yo_664 sn.da.ln_442 
  0x47023908, 0x76530508, 0x475369a0, 0x1900470c,   // br.da.sn_443 fr.ht.crs_443  mfe.ht.sn_322 sn.gl.un_530 
  0x47735305, 0x090d5c13, 0x0e00650d, 0x23001b02,   // ht.ny.sn_333 sa.ne.hi_665  gv.is.un_540 tr.ca.un_220 
  0x301535ec, 0x3b0e65ad, 0x2e006504, 0x39004702,   // tg.uz.un_640 gv.is.so_643  gv.fo.un_320 sn.br.un_220 
  // [11270]
  0x173c2304, 0x4a003502, 0x17303707, 0x35482302,   // ky.ug.sr_332 zu.yo.un_220  ba.uz.sr_432 ky.tt.tg_222 
  0x36122e0c, 0x043610ad, 0x2800060d, 0x46000b07,   // fo.hu.gn_543 be.ab.ru_643  de.sw.un_540 es.qu.un_420 
  0x362e12ee, 0x06400c12, 0x44283d07, 0x3f092da4,   // hu.fo.gn_422 sv.lb.de_654  ku.sd.kk_432 sk.pl.af_433 
  0xfc3f09a4, 0x12004a0c, 0x48374414, 0x0e6357ee,   // pl.af.zzp_433 yo.hu.un_530  kk.ba.tt_666 na.sco.is_422 
  // [11280]
  0x10003f07, 0xfc0b3faf, 0xfc573f14, 0x460a6005,   // af.lt.un_420 af.es.zzp_655  af.na.zzp_666 vo.pt.qu_333 
  0x79093f08, 0x090ffc0c, 0x17001a04, 0x0f42095a,   // af.pl.war_443 zzp.lv.pl_543  tl.sr.un_320 pl.co.lv_553 
  0x0a173707, 0x1500230c, 0x030f0408, 0x09064009,   // ba.sr.mk_432 ky.un.un_530  fi.lv.nl_443 lb.de.pl_444 
  0x111d02a0, 0x3f0ffcaf, 0x5c00580b, 0x243ffca4,   // da.la.ro_322 zzp.lv.af_655  om.sa.un_520 zzp.af.eo_433 
  // [11290]
  0x4f3f6708, 0x12190b09, 0x120b3612, 0xfc3f0f55,   // ak.af.bi_443 es.gl.hu_444  gn.es.hu_654 lv.af.zzp_442 
  0x29001505, 0x443c48a0, 0x2d0d3eee, 0x38130407,   // un.sl.un_330 tt.ug.kk_322  rm.cs.sk_422 fi.et.tk_432 
  0x290d0fee, 0x070408ad, 0x795509a9, 0x233c3da4,   // lv.cs.sl_422 uk.ru.bg_643  pl.rw.war_544 ku.ug.ky_433 
  0x3b005005, 0x2e4a0e07, 0x18004a0c, 0x29002802,   // fj.so.un_330 is.yo.fo_432  yo.ga.un_530 sw.sl.un_220 
  // [112a0]
  0x22001908, 0x20392aa4, 0x51001f21, 0x03fc3f55,   // gl.oc.un_430 mt.br.sq_433  cy.kl.un_860 af.zzp.nl_442 
  0x13005c1a, 0x47002012, 0x24005a11, 0x3efc56a4,   // sa.bh.un_760 sq.sn.un_640  sm.eo.un_630 mg.zzp.rm_433 
  0x64556ba9, 0x2f005221, 0x44483cac, 0x69385508,   // ceb.rw.lg_544 ha.su.un_860  ug.tt.kk_632 rw.tk.mfe_443 
  0x22114507, 0x11120207, 0x070425ac, 0x3859550d,   // ln.ro.oc_432 da.hu.ro_432  mn.ru.bg_632 rw.rn.tk_554 
  // [112b0]
  0x0600250e, 0x5c480212, 0x13193904, 0x5c00100d,   // eu.de.un_550 da.tt.sa_654  br.gl.et_332 lt.sa.un_540 
  0x5e6542ad, 0x4c00521b, 0x0d000e0b, 0x37002b19,   // co.gv.ts_643 ha.wo.un_770  is.cs.un_520 vi.st.un_750 
  0x173510ec, 0x2e181207, 0x2d0d12a6, 0x27654755,   // be.tg.sr_644 hu.ga.fo_432  hu.cs.sk_521 sn.gv.gd_442 
  0x39006520, 0x394c05a7, 0x65005605, 0x37381507,   // gv.br.un_850 fr.wo.br_532  mg.gv.un_330 un.tk.ba_432 
  // [112c0]
  0x0a190b08, 0x4b6e6ba0, 0x37652b11, 0x233c35a0,   // es.gl.pt_443 ceb.hmn.mi_322  vi.gv.st_653 tg.ug.ky_322 
  0x27002209, 0x13000607, 0x1269fe12, 0x15043005,   // oc.gd.un_440 de.et.un_420  tlh.mfe.hu_654 uz.ru.un_333 
  0x233c3814, 0x05155dee, 0x353007ad, 0x38000c13,   // tk.ug.ky_666 ss.fr.un_420  bg.uz.tg_643 sv.tk.un_650 
  0x02006518, 0x122118a4, 0x0a122d11, 0x04002e04,   // gv.da.un_740 ar.fa.ur_433  sk.hu.pt_653 fo.fi.un_320 
  // [112d0]
  0x50005c12, 0x344935a0, 0xfc3802a4, 0x091f0d07,   // sa.fj.un_640 zu.to.xh_322  da.tk.zzp_433 cs.cy.pl_432 
  0x34004c04, 0x190a12ac, 0x5c111aaf, 0x350815a0,   // wo.xh.un_320 hu.pt.gl_632  tl.ro.sa_655 un.uk.tg_322 
  0x13005c11, 0x2c093f07, 0x630215ee, 0x2e0e4aa7,   // sa.bh.un_630 af.pl.fy_432  un.da.sco_422 yo.is.fo_532 
  0x061d3007, 0x17150705, 0x171048a7, 0x120e36ee,   // uz.la.de_432 bg.sr.un_330  tt.be.sr_532 gn.is.hu_422 
  // [112e0]
  0x395305a0, 0x4a000e0d, 0x44000a08, 0x0e2e12a4,   // fr.ht.br_322 is.yo.un_540  mk.kk.un_430 hu.fo.is_433 
  0x0d1c130b, 0x0835110c, 0x122d0d1b, 0x5c13090e,   // bh.mr.ne_542 ro.tg.uk_543  cs.sk.hu_777 hi.bh.sa_555 
  0x361218ad, 0x59180da4, 0x041011a7, 0x180e1207,   // ga.hu.gn_643 cs.ga.rn_433  ro.be.ru_532 hu.is.ga_432 
  0x2e120ea4, 0x360e12a7, 0x2d0d1211, 0x03003e02,   // is.hu.fo_433 hu.is.gn_532  hu.cs.sk_653 rm.nl.un_220 
  // [112f0]
  0x69002a19, 0x47006412, 0x285564ac, 0x1024290c,   // mt.mfe.un_750 lg.sn.un_640  lg.rw.sw_632 sl.eo.lt_543 
  0x240b4aa4, 0x0b292409, 0x5559645a, 0x39002f05,   // yo.es.eo_433 eo.sl.es_444  lg.rn.rw_553 su.br.un_330 
  0x24003402, 0x1000240e, 0x2f211eee, 0x562136ad,   // xh.eo.un_220 eo.lt.un_550  ms.jw.su_422 gn.jw.mg_643 
  0x19000b29, 0x370b200c, 0x0e003605, 0x2900240b,   // es.gl.un_960 sq.es.st_543  gn.is.un_330 eo.sl.un_520 
  // [11300]
  0x25121fa7, 0x250f34a0, 0x10244a04, 0x4728200c,   // cy.hu.eu_532 xh.lv.eu_322  yo.eo.lt_332 sq.sw.sn_543 
  0x40003408, 0x423e01ee, 0x102924a0, 0x47385d07,   // xh.lb.un_430 en.rm.co_422  eo.sl.lt_322 ss.tk.sn_432 
  0x3e000d04, 0x44103804, 0x285559ee, 0x04170a11,   // cs.rm.un_320 tk.be.kk_332  rn.rw.sw_422 mk.sr.ru_653 
  0x573905a4, 0x29240a12, 0x22263605, 0x244a0ba0,   // fr.br.na_433 pt.eo.sl_654  gn.ia.oc_333 es.yo.eo_322 
  // [11310]
  0x20001205, 0x201134a0, 0x2e475e12, 0x04001212,   // hu.sq.un_330 xh.ro.sq_322  ts.sn.fo_654 hu.fi.un_640 
  0x5d4735af, 0x3546fe0c, 0x08150414, 0x230a1708,   // zu.sn.ss_655 tlh.qu.zu_543  ru.uk.un_660 sr.mk.ky_443 
  0x2300080c, 0x303c37ad, 0x34006402, 0x13001902,   // uk.ky.un_530 ba.ug.uz_643  lg.xh.un_220 gl.et.un_220 
  0x12213008, 0x1d023ea4, 0x04071555, 0x34283da0,   // uz.fa.ur_443 rm.da.la_433  un.bg.ru_442 ku.sd.ps_322 
  // [11320]
  0x2112345a, 0x2c003708, 0x674b6a0c, 0x37000804,   // ps.ur.fa_553 st.fy.un_430  haw.mi.ak_543 uk.ba.un_320 
  0x08251507, 0x2c003922, 0x152511a4, 0x3700482a,   // un.mn.uk_432 br.fy.un_870  ro.mn.un_433 tt.ba.un_970 
  0x230425a6, 0x38003f09, 0x53007614, 0x2c001c04,   // mn.ru.ky_521 af.tk.un_440  crs.ht.un_660 id.fy.un_320 
  0x23353012, 0x044838ee, 0x36103304, 0x0f002c02,   // uz.tg.ky_654 tk.tt.ru_422  nn.lt.gn_332 fy.lv.un_220 
  // [11330]
  0x27532207, 0x53000f07, 0x01406307, 0x33085105,   // oc.ht.gd_432 lv.ht.un_420  sco.lb.en_432 kl.no.nn_333 
  0x3bfe58a0, 0x2200270e, 0x2722235a, 0x193b4804,   // om.tlh.so_322 gd.oc.un_550  ca.oc.gd_553 tt.so.gl_332 
  0x474b6a11, 0x494b6a12, 0x3130feee, 0x1b1310a0,   // haw.mi.sn_653 haw.mi.to_654  tlh.uz.az_422 lt.et.tr_322 
  0x3909460c, 0x4b28490c, 0x0f005008, 0x0f5a49ad,   // qu.pl.br_543 to.sw.mi_543  fj.lv.un_430 to.sm.lv_643 
  // [11340]
  0x11040a0c, 0x193b30a4, 0x644cfea9, 0x3e00220d,   // mk.ru.ro_543 uz.so.gl_433  tlh.wo.lg_544 oc.rm.un_540 
  0x40065007, 0x2d102913, 0x35344ca9, 0x06050fee,   // fj.de.lb_432 sl.lt.sk_665  wo.xh.zu_544 lv.fr.de_422 
  0x173715a0, 0x30353404, 0x3c483811, 0x42006407,   // un.ba.sr_322 xh.zu.uz_332  tk.tt.ug_653 lg.co.un_420 
  0x3c001202, 0x064b1005, 0x482530ee, 0x2500070d,   // ur.ug.un_220 lt.mi.de_333  uz.eu.tt_422 bg.mn.un_540 
  // [11350]
  0x226a1a05, 0x3b483008, 0x1b5afc0d, 0x73002813,   // tl.haw.oc_333 uz.tt.so_443  zzp.sm.tr_554 sw.ny.un_650 
  0x402c06a9, 0x50495aa9, 0x38114807, 0xfc001509,   // de.fy.lb_544 sm.to.fj_544  tt.ro.tk_432 un.zzp.un_440 
  0xfc485aa0, 0x40054507, 0xfe63280c, 0x302846a9,   // sm.tt.zzp_322 ln.fr.lb_432  sw.sco.tlh_543 qu.sw.uz_544 
  0x28fe4e11, 0x286301a4, 0x28180907, 0x27fc1802,   // ay.tlh.sw_653 en.sco.sw_433  pl.ga.sw_432 ga.zzp.gd_222 
  // [11360]
  0x63000634, 0x27630208, 0x34002012, 0x0a40fe0c,   // de.sco.un_A80 da.sco.gd_443  sq.xh.un_640 tlh.lb.pt_543 
  0x58000913, 0x794036a4, 0x34730308, 0xfe00302a,   // pl.om.un_650 gn.lb.war_433  nl.ny.xh_443 uz.tlh.un_970 
  0x4423385a, 0x35153cec, 0x483730ee, 0x48073704,   // tk.ky.kk_553 ug.tg.un_640  uz.ba.tt_422 ba.bg.tt_332 
  0x406301a4, 0x09006307, 0x22462814, 0x3046fead,   // en.sco.lb_433 sco.pl.un_420  sw.qu.oc_666 tlh.qu.uz_643 
  // [11370]
  0x2839feec, 0x4006fe09, 0x2cfe470c, 0x23040812,   // tlh.br.sw_644 tlh.de.lb_444  sn.tlh.fy_543 uk.ru.ky_654 
  0x3c4448af, 0x23003608, 0x07041004, 0x10303507,   // tt.kk.ug_655 ab.ky.un_430  be.ru.bg_332 tg.uz.be_432 
  0x0200400c, 0x070817a0, 0x15002522, 0x1800fe0d,   // lb.da.un_530 sr.uk.bg_322  mn.un.un_870 tlh.ga.un_540 
  0x1e18fe60, 0x2765180c, 0x0e001004, 0x44374855,   // tlh.ga.ms_664 ga.gv.gd_543  lt.is.un_320 tt.ba.kk_442 
  // [11380]
  0x5900060e, 0x1f1a6b0c, 0x346b3fee, 0x2d0d0a09,   // de.rn.un_550 ceb.tl.cy_543  af.ceb.xh_422 pt.cs.sk_444 
  0x3f1a6b11, 0x02fe1812, 0x1800300d, 0x524846ee,   // ceb.tl.af_653 ga.tlh.da_654  uz.ar.un_540 qu.tt.ha_422 
  0x19003607, 0x12002e0b, 0x190a1814, 0x333f0204,   // gn.gl.un_420 fo.hu.un_520  ga.pt.gl_666 da.af.nn_332 
  0x071511ec, 0x220e2e04, 0x23190a08, 0x1d1105a4,   // ro.bg.un_640 fo.is.oc_332  pt.gl.ca_443 fr.ro.la_433 
  // [11390]
  0x06052f0c, 0x034b050c, 0x2f2c3fa4, 0x04381707,   // su.fr.de_543 fr.mi.nl_543  af.fy.su_433 sr.tk.ru_432 
  0x080711a4, 0x4605590b, 0x4003050c, 0x36000408,   // ro.bg.uk_433 rn.fr.qu_542  fr.nl.lb_543 fi.gn.un_430 
  0x45053f55, 0x032f0504, 0x06190504, 0x2e240e07,   // af.fr.ln_442 fr.su.nl_332  fr.gl.de_332 is.eo.fo_432 
  0x24332e07, 0x31481b55, 0x0a080407, 0x3039280c,   // fo.nn.eo_432 tr.tt.az_442  ru.uk.mk_432 sw.br.uz_543 
  // [113a0]
  0x02246405, 0x256456a4, 0x2d1720a6, 0x122e24a0,   // lg.eo.da_333 mg.lg.eu_433  sq.sr.sk_521 eo.fo.hu_322 
  0x47007836, 0x73003912, 0x0b00641a, 0x42063e0b,   // ve.sn.un_AA0 br.ny.un_640  lg.es.un_760 rm.de.co_542 
  0xfe766912, 0x73382007, 0x7669470c, 0x1100020c,   // mfe.crs.tlh_654 sq.tk.ny_432  sn.mfe.crs_543 da.ro.un_530 
  0x46032a07, 0x32000304, 0x73472d0b, 0x53002008,   // mt.nl.qu_432 nl.bs.un_320  sk.sn.ny_542 sq.ht.un_430 
  // [113b0]
  0x27003e04, 0x640701a0, 0x023138a4, 0x301b2902,   // rm.gd.un_320 en.it.lg_322  tk.az.da_433 sl.tr.uz_222 
  0x52382aa0, 0x2864730c, 0x20002c07, 0x12000923,   // mt.tk.ha_322 ny.lg.sw_543  fy.sq.un_420 pl.hu.un_880 
  0x0815380c, 0x0625010c, 0x121304ec, 0x18313007,   // tk.uk.un_530 en.eu.de_543  fi.et.hu_644 uz.az.ga_432 
  0x33082ca4, 0x03321604, 0x04153711, 0x10391204,   // fy.no.nn_433 hr.bs.nl_332  ba.ru.un_630 hu.br.lt_332 
  // [113c0]
  0x04001214, 0x38310607, 0x1b040ea4, 0x2c3e0404,   // hu.fi.un_660 de.az.tk_432  is.fi.tr_433 fi.rm.fy_332 
  0x65180f04, 0x03003f0b, 0x1b3106a9, 0x06315b0d,   // lv.ga.gv_332 af.nl.un_520  de.az.tr_544 sg.az.de_554 
  0x1f004004, 0x33084da6, 0x1b483809, 0x191b0fec,   // lb.cy.un_320 aa.no.nn_521  tk.tt.tr_444 lv.tr.gl_644 
  0x3c281213, 0x04152507, 0x351044a0, 0x1b573808,   // ur.sd.ug_665 mn.ru.un_420  kk.be.tg_322 tk.na.tr_443 
  // [113d0]
  0x2e1d0ea0, 0x061b1307, 0x120363ad, 0x25120412,   // is.la.fo_322 et.tr.de_432  sco.nl.hu_643 fi.hu.eu_654 
  0x041312a4, 0x121304a4, 0x36000405, 0x1f003807,   // hu.et.fi_433 fi.et.hu_433  fi.gn.un_330 tk.cy.un_420 
  0x30382512, 0x18281202, 0x382c360b, 0x381b4855,   // mn.tk.uz_654 ur.sd.ar_222  gn.fy.tk_542 tt.tr.tk_442 
  0x17040805, 0x35001714, 0x55fa57ec, 0x4ffe5b05,   // uk.ru.sr_333 sr.tg.un_660  na.nr.rw_644 sg.tlh.bi_333 
  // [113e0]
  0x5b78450c, 0x39002c07, 0x12213455, 0x42645504,   // ln.ve.sg_543 fy.br.un_420  ps.fa.ur_442 rw.lg.co_332 
  0x631d0107, 0x35fa68ad, 0x07442507, 0x031f6305,   // en.la.sco_432 ig.nr.zu_643  mn.kk.bg_432 sco.cy.nl_333 
  0x13006011, 0x65400107, 0xfc005713, 0x4d002c14,   // vo.et.un_630 en.lb.gv_432  na.zzp.un_650 fy.aa.un_660 
  0x073e0304, 0x1f4c4da4, 0x03001f07, 0x42642a04,   // nl.rm.it_332 aa.wo.cy_433  cy.nl.un_420 mt.lg.co_332 
  // [113f0]
  0x42001f07, 0x272d4007, 0x2a000e07, 0x121821ec,   // cy.co.un_420 lb.sk.gd_432  is.mt.un_420 fa.ar.ur_644 
  0x51004c04, 0x6a00490b, 0x15653ba4, 0x51002f19,   // wo.kl.un_320 to.haw.un_520  so.gv.un_433 su.kl.un_750 
  0x15002f0c, 0x494a2a11, 0x691360a4, 0x3800130b,   // su.un.un_530 mt.yo.to_653  vo.et.mfe_433 et.tk.un_520 
  0x0f3f60a4, 0x213b3da4, 0x52514a04, 0x4d006314,   // vo.af.lv_433 ku.ks.fa_433  yo.kl.ha_332 sco.aa.un_660 
  
  // [11400]
  0x2200190d, 0x60001305, 0x2f004709, 0x16004c05,   // gl.oc.un_540 et.vo.un_330  sn.su.un_440 wo.hr.un_330 
  0x0b5a6a07, 0x02001308, 0x13696012, 0x531d0555,   // haw.sm.es_432 et.da.un_430  vo.mfe.et_654 fr.la.ht_442 
  0x211865a0, 0x0f006019, 0x2165fea0, 0x60001313,   // gv.ga.jw_322 vo.lv.un_750  tlh.gv.jw_322 et.vo.un_650 
  0x0d397308, 0x1b3831a9, 0x1c136055, 0x40061ba0,   // ny.br.cs_443 az.tk.tr_544  vo.et.id_442 tr.de.lb_322 
  // [11410]
  0x1e1c42a0, 0x0165fea7, 0x1c0515a0, 0x2818340e,   // co.id.ms_322 tlh.gv.en_532  un.fr.id_322 ps.ar.sd_555 
  0x5000460b, 0x0c136011, 0x08171002, 0x4f600f08,   // qu.fj.un_520 vo.et.sv_653  be.sr.uk_222 lv.vo.bi_443 
  0x69001309, 0x1d00050e, 0x370413ee, 0x1c093b07,   // et.mfe.un_440 fr.la.un_550  et.fi.st_422 ks.hi.mr_432 
  0x35303ca9, 0x53241805, 0x084448a0, 0x39003f04,   // ug.uz.tg_544 ga.eo.ht_333  tt.kk.uk_322 af.br.un_320 
  // [11420]
  0x30001102, 0x170a110c, 0x4d004823, 0x37303c05,   // ro.uz.un_220 ro.mk.sr_543  tt.aa.un_880 ug.uz.ba_333 
  0x2a006112, 0x022961ee, 0x0c3f6907, 0x4c1504a7,   // za.mt.un_640 za.sl.da_422  mfe.af.sv_432 fi.wo.un_520 
  0x02004012, 0x580b4cee, 0x30370704, 0x2c650408,   // lb.da.un_640 wo.es.om_422  bg.ba.uz_332 fi.gv.fy_443 
  0x12311baf, 0x48003304, 0x1f024d0c, 0x32300204,   // tr.az.hu_655 nn.tt.un_320  aa.da.cy_543 da.uz.bs_332 
  // [11430]
  0x095c1c5a, 0x05000404, 0x06047908, 0x02001102,   // mr.sa.hi_553 fi.fr.un_320  war.fi.de_443 ro.da.un_220 
  0x47340402, 0x48443002, 0x373c4460, 0x472c3607,   // fi.xh.sn_222 uz.kk.tt_222  kk.ug.ba_664 gn.fy.sn_432 
  0x3515040b, 0x3c3015a9, 0x3e2379a0, 0x0d135c05,   // ru.tg.un_520 un.uz.ug_544  war.ca.rm_322 sa.bh.ne_333 
  0x3f2f0604, 0x272c6507, 0x2f000804, 0x11002f0d,   // de.su.af_332 gv.fy.gd_432  no.su.un_320 su.ro.un_540 
  // [11440]
  0x154415a9, 0x053f0307, 0x1d2f02a0, 0x42067904,   // un.kk.un_544 nl.af.fr_432  da.su.la_322 war.de.co_332 
  0x3f3e0504, 0x1a6479a9, 0x422f0555, 0x3f230505,   // fr.rm.af_332 war.lg.tl_544  fr.su.co_442 fr.ca.af_333 
  0x21555c08, 0x0a0417ec, 0x5c45640c, 0x5c00552a,   // sa.rw.jw_443 sr.ru.mk_644  lg.ln.sa_543 rw.sa.un_970 
  0x3169760c, 0x131c0d12, 0x1b002805, 0x1e006812,   // crs.mfe.az_543 ne.mr.bh_654  sw.tr.un_330 ig.ms.un_640 
  // [11450]
  0x61676ba9, 0xfe003113, 0x4c3b64a4, 0x555c2007,   // ceb.ak.za_544 az.tlh.un_650  lg.so.wo_433 sq.sa.rw_432 
  0x311bfeec, 0x025c55af, 0x1b5c5504, 0x645c73ec,   // tlh.tr.az_644 rw.sa.da_655  rw.sa.tr_332 ny.sa.lg_644 
  0x0b002e08, 0x1b614507, 0x524d5814, 0x08003605,   // fo.es.un_430 ln.za.tr_432  om.aa.ha_666 ab.uk.un_330 
  0x6b1a79a9, 0x31302e07, 0x285c7908, 0x0cfc5d60,   // war.tl.ceb_544 fo.uz.az_432  war.sa.sw_443 ss.zzp.sv_664 
  // [11460]
  0x4c0312a0, 0x02004719, 0x79005c34, 0x4d005808,   // hu.nl.wo_322 sn.da.un_750  sa.war.un_A80 om.aa.un_430 
  0x30fe4604, 0x101525a9, 0x154701a0, 0x64766907,   // qu.tlh.uz_332 mn.be.un_540  en.sn.un_322 mfe.crs.lg_432 
  0x2a3bfead, 0x763f3104, 0x3e0640ee, 0x466b1a04,   // tlh.so.mt_643 az.af.crs_332  lb.de.rm_422 tl.ceb.qu_332 
  0x02005d13, 0x17150409, 0x170408a9, 0x3600fc19,   // ss.da.un_650 ru.sr.un_440  uk.ru.sr_544 zzp.gn.un_750 
  // [11470]
  0x073517a0, 0x55355da0, 0x0600120c, 0x30003b0b,   // sr.tg.bg_322 ss.zu.rw_322  hu.de.un_530 so.uz.un_520 
  0x1200060e, 0x48381ba7, 0x2afe3b05, 0x31fe3b0c,   // de.hu.un_550 tr.tk.tt_532  so.tlh.mt_333 so.tlh.az_543 
  0x300121ec, 0x11423e13, 0xfc5055a0, 0x28001218,   // fa.iw.uz_644 rm.co.ro_665  rw.fj.zzp_322 ur.sd.un_740 
  0x0d5c13ad, 0x154810a0, 0x34122102, 0x5300460b,   // bh.sa.ne_643 be.tt.un_322  fa.ur.ps_222 qu.ht.un_520 
  // [11480]
  0x083035ee, 0x34303dad, 0x074417ee, 0x0a1007a0,   // tg.uz.uk_422 ku.uz.ps_643  sr.kk.bg_422 bg.be.mk_322 
  0x15073007, 0x10001521, 0x30000808, 0x0d091cac,   // uz.bg.un_432 un.be.un_860  uk.uz.un_430 mr.hi.ne_632 
  0x12213408, 0x205349a0, 0x39005a19, 0x1b383102,   // ps.fa.ur_443 to.ht.sq_322  sm.br.un_750 az.tk.tr_222 
  0x29002f14, 0x4b224fa4, 0x4b5f5e07, 0x63106805,   // su.sl.un_660 bi.oc.mi_433  ts.tn.mi_432 ig.lt.sco_333 
  // [11490]
  0x24294a0c, 0x11202aa4, 0x135525af, 0x5c2429a4,   // yo.sl.eo_543 mt.sq.ro_433  eu.rw.et_655 sl.eo.sa_433 
  0x062f35a0, 0x483515ad, 0x50114904, 0x375f4507,   // zu.su.de_322 un.tg.tt_643  to.ro.fj_332 ln.tn.st_432 
  0x595506a9, 0x10004808, 0x3c373607, 0x044a63a4,   // de.rw.rn_544 tt.be.un_430  ab.ba.ug_432 sco.yo.fi_433 
  0x43fc010c, 0x43360b0c, 0x44001014, 0x1b002019,   // en.zzp.ie_543 es.gn.ie_543  be.kk.un_660 sq.tr.un_750 
  // [114a0]
  0x255c11ec, 0x34306b08, 0x10131d02, 0x330805a0,   // ro.sa.eu_644 ceb.uz.xh_443  la.et.lt_222 fr.no.nn_322 
  0x50045e12, 0x331a79a4, 0x34005508, 0x5cfe29ad,   // ts.fi.fj_654 war.tl.nn_433  rw.xh.un_430 sl.tlh.sa_643 
  0x0b0f4004, 0x3c3023a9, 0x02005108, 0x0844100b,   // lb.lv.es_332 ky.uz.ug_544  kl.da.un_430 be.kk.uk_542 
  0x68fc2013, 0x3b4a290c, 0x026304ad, 0xfc00730e,   // sq.zzp.ig_665 sl.yo.so_543  fi.sco.da_643 ny.zzp.un_550 
  // [114b0]
  0x1b000f08, 0x47150904, 0x29673805, 0x15043605,   // lv.tr.un_430 pl.sn.un_320  tk.ak.sl_333 ab.ru.un_333 
  0x15003804, 0x1510360c, 0x04054208, 0x0d006504,   // tk.un.un_320 ab.be.un_543  co.fr.fi_443 gv.cs.un_320 
  0x1c3f2f04, 0x0200610c, 0x1707110c, 0x0708100d,   // su.af.id_332 za.da.un_530  ro.bg.sr_543 be.uk.bg_554 
  0x350a10a0, 0x48001109, 0x3f001305, 0x13002f0d,   // be.mk.tg_322 ro.tt.un_440  et.af.un_330 su.et.un_540 
  // [114c0]
  0x0439050c, 0x0a07080d, 0x0807110e, 0x49005a1a,   // fr.br.fi_543 uk.bg.mk_554  ro.bg.uk_555 sm.to.un_760 
  0x3900370e, 0x5c002d04, 0x51034c0d, 0x5a000405,   // st.br.un_550 sk.sa.un_320  wo.nl.kl_554 fi.sm.un_330 
  0x6327185a, 0x026a5a0c, 0x026365a7, 0x09400608,   // ga.gd.sco_553 sm.haw.da_543  gv.sco.da_532 de.lb.pl_443 
  0x63653914, 0x6503250c, 0x15110404, 0x070a085a,   // br.gv.sco_666 eu.nl.gv_543  ru.ro.un_332 uk.mk.bg_553 
  // [114d0]
  0x2e0a190b, 0x65672e0e, 0x39001111, 0x440a23a4,   // gl.pt.fo_542 fo.ak.gv_555  ro.br.un_630 ky.mk.kk_433 
  0x07100aec, 0x653b3904, 0x083710a9, 0x23004205,   // mk.be.bg_644 br.so.gv_332  be.ba.uk_544 co.ca.un_330 
  0x3b004e13, 0x35344eaf, 0x766b1a0c, 0x23104455,   // ay.so.un_650 ay.xh.zu_655  tl.ceb.crs_543 kk.be.ky_442 
  0x3f0379a6, 0x23001d0d, 0x31484ead, 0x2a004d2b,   // war.nl.af_521 la.ca.un_540  ay.tt.az_643 aa.mt.un_980 
  // [114e0]
  0x30003e08, 0x2d0d16a4, 0x25234eec, 0x311b3802,   // rm.uz.un_430 hr.cs.sk_433  ay.ca.eu_644 tk.tr.az_222 
  0x235e3b02, 0x2a002321, 0x067924a9, 0x58483007,   // so.ts.ca_222 ca.mt.un_860  eo.war.de_544 uz.tt.om_432 
  0x09483004, 0x7900fc08, 0x30483508, 0x25040702,   // uz.tt.pl_332 zzp.war.un_430  tg.tt.uz_443 bg.ru.mn_222 
  0x153515a7, 0x28183455, 0x1c0d13ec, 0x2318440d,   // un.tg.un_532 ps.ar.sd_442  bh.ne.mr_644 kk.ar.ky_554 
  // [114f0]
  0xfe356a07, 0x55003f04, 0x28003507, 0x4c04580c,   // haw.zu.tlh_432 af.rw.un_320  zu.sw.un_420 om.fi.wo_543 
  0x68554508, 0x04005822, 0x64580408, 0x63035804,   // ln.rw.ig_443 om.fi.un_870  fi.om.lg_443 om.nl.sco_332 
  0x1d3e5004, 0x402c58a4, 0x1d00690e, 0x0804105a,   // fj.rm.la_332 om.fy.lb_433  mfe.la.un_550 be.ru.uk_553 
  0x21183ca0, 0x23002402, 0x080c3311, 0x3bfc58af,   // ug.ar.fa_322 eo.ca.un_220  nn.sv.no_653 om.zzp.so_655 
  // [11500]
  0x23226007, 0x495863a4, 0x23225302, 0x6400031b,   // vo.oc.ca_432 sco.om.to_433  ht.oc.ca_222 nl.lg.un_770 
  0x6b1d4309, 0x04006422, 0x59240705, 0x30683507,   // ie.la.ceb_444 lg.fi.un_870  it.eo.rn_333 zu.ig.uz_432 
  0x11001607, 0x5a1304a4, 0x0512230d, 0x04682cee,   // hr.ro.un_420 fi.et.sm_433  ca.hu.fr_554 fy.ig.fi_422 
  0x23443c55, 0x31004204, 0x051853a7, 0x53000517,   // ug.kk.ky_442 co.az.un_320  ht.ga.fr_532 fr.ht.un_730 
  // [11510]
  0x4620020b, 0x46390502, 0x19002202, 0x0a16240c,   // da.sq.qu_542 fr.br.qu_222  oc.gl.un_220 eo.hr.pt_543 
  0x182f21a9, 0x2c000314, 0x0a041055, 0x31004818,   // jw.su.ga_544 nl.fy.un_660  be.ru.mk_442 tt.az.un_740 
  0x17110a0d, 0x4d3b6160, 0x63014d07, 0x30111707,   // mk.ro.sr_554 za.so.aa_664  aa.en.sco_432 sr.ro.uz_432 
  0x3b001f12, 0x04070a14, 0x0a0163a0, 0xfc006309,   // cy.so.un_640 mk.bg.ru_666  sco.en.pt_322 sco.zzp.un_440 
  // [11520]
  0x3f0601a4, 0x73016307, 0x46fe5807, 0x406306a0,   // en.de.af_433 sco.en.ny_432  om.tlh.qu_432 de.sco.lb_322 
  0x6202610e, 0x29032da9, 0x63004609, 0x3b002a07,   // za.da.kha_555 sk.nl.sl_544  qu.sco.un_440 mt.so.un_420 
  0x3f22230c, 0x794006a4, 0x2a00fe1a, 0x50006304,   // ca.oc.af_543 de.lb.war_433  tlh.mt.un_760 sco.fj.un_320 
  0x042c6555, 0x53734dee, 0x026301a9, 0x3b2a2007,   // gv.fy.fi_442 aa.ny.ht_422  en.sco.da_544 sq.mt.so_432 
  // [11530]
  0x010265ad, 0x6e6b69ee, 0x20002519, 0x3b003308,   // gv.da.en_643 mfe.ceb.hmn_422  eu.sq.un_750 nn.so.un_430 
  0x101544a4, 0x30040707, 0x402c1fee, 0x6b1f2f04,   // kk.be.un_430 bg.ru.uz_432  cy.fy.lb_422 su.cy.ceb_332 
  0x33041f0c, 0x430b0a5a, 0x46005019, 0x2a005019,   // cy.fi.nn_543 pt.es.ie_553  fj.qu.un_750 fj.mt.un_750 
  0x504d2a55, 0x40006112, 0x1d001904, 0x230d0aa0,   // mt.aa.fj_442 za.lb.un_640  gl.la.un_320 pt.cs.ca_322 
  // [11540]
  0x65000e0c, 0x53000205, 0x07000a34, 0x44073504,   // is.gv.un_530 da.ht.un_330  mk.bg.un_A80 tg.bg.kk_332 
  0x3023310c, 0x47005f22, 0x27004602, 0x47675e08,   // az.ca.uz_543 tn.sn.un_870  qu.gd.un_220 ts.ak.sn_443 
  0x31001904, 0x344735ad, 0x4830fea7, 0x6a1365ec,   // gl.az.un_320 zu.sn.xh_643  tlh.uz.tt_532 gv.et.haw_644 
  0x55005f04, 0x3d003c21, 0x49656304, 0x47355913,   // tn.rw.un_320 ug.ku.un_860  sco.gv.to_332 rn.zu.sn_665 
  // [11550]
  0x2864350c, 0x3700650d, 0x30312aee, 0x64735704,   // zu.lg.sw_543 gv.st.un_540  mt.az.uz_422 na.ny.lg_332 
  0x59284704, 0x23052fac, 0x3b5a650b, 0x0d0e2d5a,   // sn.sw.rn_332 su.fr.ca_632  gv.sm.so_542 sk.is.cs_553 
  0x4600360b, 0x15040a0c, 0x3428180e, 0x2812300d,   // gn.qu.un_520 mk.ru.un_543  ar.sd.ps_555 uz.ur.sd_554 
  0x4500121a, 0x20312204, 0x4c0405ee, 0x081004af,   // hu.ln.un_760 oc.az.sq_332  fr.fi.wo_422 ru.be.uk_655 
  // [11560]
  0x120d45a7, 0x30351008, 0x38481ba0, 0x15364808,   // ln.cs.hu_532 be.tg.uz_443  tr.tt.tk_322 tt.ab.un_443 
  0x28002121, 0x05486011, 0x06220aa0, 0x070a15a0,   // fa.sd.un_860 vo.tt.fr_653  pt.oc.de_322 un.mk.bg_322 
  0x1b312002, 0x13645607, 0x64615505, 0x3e475c0d,   // sq.az.tr_222 mg.lg.et_432  rw.za.lg_333 sa.sn.rm_554 
  0x27006107, 0x23052207, 0x5c04130c, 0x1e001902,   // za.gd.un_420 oc.fr.ca_432  et.fi.sa_543 gl.ms.un_220 
  // [11570]
  0x122961ee, 0x1d392f0c, 0x0e0c730c, 0x27002f19,   // za.sl.hu_422 su.br.la_543  ny.sv.is_543 su.gd.un_750 
  0x2d4826a4, 0x48122e0c, 0x0313fca7, 0x02000e22,   // ia.tt.sk_433 fo.hu.tt_543  zzp.et.nl_532 is.da.un_870 
  0x5a42260c, 0x030c13a4, 0x291703af, 0x0c64780d,   // ia.co.sm_543 et.sv.nl_433  nl.sr.sl_655 ve.lg.sv_554 
  0x08001f0c, 0x061d0307, 0x063f0e05, 0x27002f07,   // cy.no.un_530 nl.la.de_432  is.af.de_333 su.gd.un_420 
  // [11580]
  0x12033fa4, 0x12614713, 0x041d4255, 0x2b004704,   // af.nl.hu_433 sn.za.hu_665  co.la.fi_442 sn.vi.un_320 
  0x102e3607, 0x043e5405, 0x135c0da4, 0x1c1e2712,   // gn.fo.lt_432 ik.rm.fi_333  cs.sa.et_433 gd.ms.id_654 
  0x135c470c, 0x0f473904, 0x02003004, 0x213423a7,   // sn.sa.et_543 br.sn.lv_332  uz.da.un_320 ky.ps.fa_532 
  0x15000308, 0x0e2e08a0, 0x21443007, 0x3f0e1507,   // nl.un.un_430 no.fo.is_322  uz.kk.fa_432 un.is.af_432 
  // [11590]
  0x10080411, 0x232c2d12, 0x2c000907, 0x122701a0,   // ru.uk.be_653 sk.fy.ca_654  pl.fy.un_420 en.gd.hu_322 
  0x23001d08, 0x103f06ac, 0x4e100807, 0x24fe0455,   // la.ca.un_430 de.af.lt_632  no.lt.ay_432 fi.tlh.eo_442 
  0x124d2513, 0x15006519, 0x48584c0c, 0x080704ac,   // eu.aa.hu_665 gv.un.un_750  wo.om.tt_543 ru.bg.uk_632 
  0x0f00250c, 0x07043702, 0x11fc4d08, 0x2c083307,   // eu.lv.un_530 ba.ru.bg_222  aa.zzp.ro_443 nn.no.fy_432 
  // [115a0]
  0x22004a08, 0x0d0e1207, 0x24251b07, 0x3e0c04ad,   // yo.oc.un_430 hu.is.cs_432  tr.eu.eo_432 fi.sv.rm_643 
  0x40066512, 0x35002514, 0x02000608, 0x0a42230c,   // gv.de.lb_654 mn.tg.un_660  de.da.un_430 ca.co.pt_543 
  0x1e250704, 0x25361107, 0x281843a0, 0x23001909,   // it.eu.ms_332 ro.ab.mn_432  ie.ga.sw_322 gl.ca.un_440 
  0xfe00fc04, 0x1e2d0d55, 0x38234404, 0x3600440d,   // zzp.tlh.un_320 cs.sk.ms_442  kk.ky.tk_332 kk.ab.un_540 
  // [115b0]
  0x3711150c, 0x08152507, 0xfe5d35a0, 0x48004c08,   // un.ro.ba_543 mn.uk.un_420  zu.ss.tlh_322 wo.tt.un_430 
  0x40004a12, 0x040a0802, 0x30352509, 0x3f020107,   // yo.lb.un_640 uk.mk.ru_222  mn.tg.uz_444 en.da.af_432 
  0x1b000605, 0x2f000a04, 0x0b311b1d, 0x374448ee,   // de.tr.un_330 pt.su.un_320  tr.az.es_852 tt.kk.ba_422 
  0x61001214, 0x791261a4, 0x12006112, 0x05004a08,   // hu.za.un_660 za.hu.war_433  za.hu.un_640 yo.fr.un_430 
  // [115c0]
  0x22190b5a, 0x22002302, 0x6100120e, 0x08363cac,   // es.gl.oc_553 ca.oc.un_220  hu.za.un_550 ug.ab.uk_632 
  0x30000107, 0x070a3005, 0x483717a0, 0x04000912,   // en.uz.un_420 uz.mk.bg_333  sr.ba.tt_322 pl.fi.un_640 
  0x19000d19, 0x106b1dee, 0x2f3e1ca0, 0x03001f20,   // cs.gl.un_750 la.ceb.lt_422  id.rm.su_322 cy.nl.un_850 
  0x4411380c, 0x56553e07, 0x0b0a26a0, 0x0c40060e,   // tk.ro.kk_543 rm.rw.mg_432  ia.pt.es_322 de.lb.sv_555 
  // [115d0]
  0x2c005614, 0x230501a0, 0x1b400502, 0x321762a9,   // mg.fy.un_660 en.fr.ca_322  fr.lb.tr_222 kha.sr.bs_544 
  0x11007313, 0x4900670c, 0x182763ad, 0x11173ea7,   // ny.ro.un_650 ak.to.un_530  sco.gd.ga_643 rm.sr.ro_532 
  0x6a655aec, 0x40000c02, 0x02094d0c, 0x475f1ca9,   // sm.gv.haw_644 sv.lb.un_220  aa.pl.da_543 id.tn.sn_544 
  0x73681ea0, 0x061b3f07, 0x4773550c, 0x48381ba4,   // ms.ig.ny_322 af.tr.de_432  rw.ny.sn_543 tr.tk.tt_433 
  // [115e0]
  0x096a2aa4, 0x06033f07, 0x6000181a, 0x765318a4,   // mt.haw.pl_433 af.nl.de_432  ga.vo.un_760 ga.ht.crs_433 
  0x390357a9, 0x134006a7, 0x675f0608, 0x475e730c,   // na.nl.br_544 de.lb.et_532  de.tn.ak_443 ny.ts.sn_543 
  0xfc063fa4, 0x060c0255, 0x34403f02, 0x2c006509,   // af.de.zzp_433 da.sv.de_442  af.lb.xh_222 gv.fy.un_440 
  0x0340fc02, 0x1f063fa4, 0x034301a7, 0x03737508,   // zzp.lb.nl_222 af.de.cy_433  en.ie.nl_532 nso.ny.nl_443 
  // [115f0]
  0x3f00732a, 0x03004307, 0x5a632404, 0x06134cee,   // ny.af.un_970 ie.nl.un_420  eo.sco.sm_332 wo.et.de_422 
  0x530640a7, 0x28006405, 0x49431f07, 0x47003b07,   // lb.de.ht_532 lg.sw.un_330  cy.ie.to_432 so.sn.un_420 
  0x12481004, 0x3e003004, 0x3f00481a, 0x23443bee,   // lt.tt.hu_332 uz.rm.un_320  tt.af.un_760 ks.kk.ky_422 
  0x11325ea0, 0x1f643f09, 0x345d61af, 0x3e033fa9,   // ts.bs.ro_322 af.lg.cy_444  za.ss.xh_655 af.nl.rm_544 
  // [11600]
  0x2c034007, 0x3e001102, 0x3f670309, 0x03002c19,   // lb.nl.fy_432 ro.rm.un_220  nl.ak.af_444 fy.nl.un_750 
  0x15061d55, 0x3f470313, 0x3f40060d, 0x55fc01a4,   // la.de.un_442 nl.sn.af_665  de.lb.af_554 en.zzp.rw_433 
  0x11005807, 0x03403f5a, 0x3f6b73a0, 0x5f005812,   // om.ro.un_420 af.lb.nl_553  ny.ceb.af_322 om.tn.un_640 
  0x3b0d4dac, 0x10173512, 0x6400fe0e, 0x3c003402,   // aa.cs.so_632 tg.sr.be_654  tlh.lg.un_550 ps.ug.un_220 
  // [11610]
  0x022a6012, 0x38001311, 0x0c001f0c, 0x30003e09,   // vo.mt.da_654 et.tk.un_630  cy.sv.un_530 rm.uz.un_440 
  0x521f0607, 0x69112408, 0x2a00640d, 0x52001304,   // de.cy.ha_432 eo.ro.mfe_443  lg.mt.un_540 et.ha.un_320 
  0x03005a02, 0x35fa3412, 0x4421230d, 0x3d442307,   // sm.nl.un_220 xh.nr.zu_654  ky.fa.kk_554 ky.kk.ku_432 
  0x2e33080e, 0x0b003320, 0x1b230aec, 0x36002408,   // no.nn.fo_555 as.bn.un_850  pt.ca.tr_644 eo.gn.un_430 
  // [11620]
  0x17083ca0, 0x24003607, 0x2d000407, 0x383018a7,   // ug.uk.sr_322 gn.eo.un_420  fi.sk.un_420 ga.uz.tk_532 
  0x58553411, 0x1ffe5805, 0x0a17250d, 0x28735e12,   // xh.rw.om_653 om.tlh.cy_333  mn.sr.mk_554 ts.ny.sw_654 
  0x346858a4, 0x64285502, 0x11643412, 0x46fe30a7,   // om.ig.xh_433 rw.sw.lg_222  xh.lg.ro_654 uz.tlh.qu_532 
  0x646b28a4, 0x5d47340c, 0x15001714, 0x73474655,   // sw.ceb.lg_433 xh.sn.ss_543  sr.un.un_660 qu.sn.ny_442 
  // [11630]
  0x552864ee, 0x34522807, 0x0408360c, 0x355d34a0,   // lg.sw.rw_422 sw.ha.xh_432  ab.uk.ru_543 xh.ss.zu_322 
  0x5564350c, 0x55355da4, 0x202a07a7, 0x47785e12,   // zu.lg.rw_543 ss.zu.rw_433  it.mt.sq_532 ts.ve.sn_654 
  0x301802a0, 0x5d475905, 0x28347360, 0x2800760c,   // da.ga.uz_322 rn.sn.ss_333  ny.xh.sw_664 crs.sw.un_530 
  0x2f0221a7, 0x1a0e6ba4, 0x5f5d5e08, 0x39003202,   // jw.da.su_532 ceb.is.tl_433  ts.ss.tn_443 bs.br.un_220 
  // [11640]
  0x556859a4, 0x48153613, 0x223e23a0, 0x3400130c,   // rn.ig.rw_433 ab.tt.un_650  ca.rm.oc_322 et.xh.un_530 
  0x041715ac, 0x55000212, 0x020e13a4, 0x183d1207,   // un.sr.ru_632 da.rw.un_640  et.is.da_433 ur.ku.ar_432 
  0x18001604, 0x55500260, 0x28000902, 0x38081012,   // hr.ga.un_320 da.fj.rw_664  pl.sw.un_220 be.uk.tk_654 
  0x5c1d03a0, 0x0c212f04, 0x253530a9, 0x65400111,   // nl.la.sa_322 su.jw.sv_332  uz.tg.mn_544 en.lb.gv_653 
  // [11650]
  0x08350407, 0x275515a9, 0x050426ee, 0x1802170e,   // ru.tg.uk_432 un.rw.gd_544  ia.fi.fr_422 sr.da.ga_555 
  0x511643a0, 0x211230a9, 0x05011e07, 0x5600430d,   // ie.hr.kl_322 uz.ur.fa_544  ms.en.fr_432 ie.mg.un_540 
  0x253717a0, 0x0b260a12, 0x382544af, 0x074835a0,   // sr.ba.mn_322 pt.ia.es_654  kk.mn.tk_655 tg.tt.bg_322 
  0x042548a4, 0x3b3130ec, 0x11005b11, 0x556435a4,   // tt.mn.ru_433 uz.az.so_644  sg.ro.un_630 zu.lg.rw_433 
  // [11660]
  0x557364a7, 0x3564fea4, 0x1e484d07, 0x3b00fe0c,   // lg.ny.rw_532 tlh.lg.zu_433  aa.tt.ms_432 tlh.so.un_530 
  0xfe00210e, 0x38005209, 0x37025aec, 0x4c002502,   // jw.tlh.un_550 ha.tk.un_440  sm.da.st_644 eu.wo.un_220 
  0x3b3048a4, 0x2f213860, 0x2b2a25a0, 0x2f6421af,   // tt.uz.so_433 tk.jw.su_664  eu.mt.vi_322 jw.lg.su_655 
  0x25111705, 0x56005a05, 0x081044a0, 0x0624fcee,   // sr.ro.mn_333 sm.mg.un_330  kk.be.uk_322 zzp.eo.de_422 
  // [11670]
  0x0700fc04, 0x1dfc1ba0, 0x01002402, 0x420d2d12,   // zzp.it.un_320 tr.zzp.la_322  eo.en.un_220 sk.cs.co_654 
  0x0f624d12, 0x3400590c, 0x04473312, 0xfe18130e,   // aa.kha.lv_654 rn.xh.un_530  nn.sn.fi_654 et.ga.tlh_555 
  0x37007812, 0x0c46330c, 0x12fe1808, 0x2a362f0c,   // ve.st.un_640 nn.qu.sv_543  ga.tlh.hu_443 su.gn.mt_543 
  0x35345d0d, 0x1b4d330c, 0x4d153b09, 0x63063608,   // ss.xh.zu_554 nn.aa.tr_543  so.aa.un_440 gn.de.sco_443 
  // [11680]
  0x2d0d36af, 0x476459a4, 0x4000030d, 0x08240d0c,   // gn.cs.sk_655 rn.lg.sn_433  nl.lb.un_540 cs.eo.no_543 
  0xfe4d3b5a, 0x58353404, 0x64361d0c, 0x02123f0c,   // so.aa.tlh_553 xh.zu.om_332  la.gn.lg_543 af.hu.da_543 
  0x302512a7, 0x364d4612, 0x1248fea7, 0x3100fe0c,   // hu.eu.uz_532 qu.aa.gn_654  tlh.tt.hu_532 tlh.az.un_530 
  0xfe4d4608, 0x42002704, 0x1200251a, 0x4d4846ec,   // qu.aa.tlh_443 gd.co.un_320  eu.hu.un_760 qu.tt.aa_644 
  // [11690]
  0x630c1dee, 0x03651f04, 0x3b285907, 0x3f00100c,   // la.sv.sco_422 cy.gv.nl_332  rn.sw.so_432 lt.af.un_530 
  0x37001807, 0x3428185a, 0x17440808, 0x07370402,   // ar.ba.un_420 ar.sd.ps_553  uk.kk.sr_443 ru.ba.bg_222 
  0xfc002712, 0x0206fe11, 0x0640fe07, 0x241e40ee,   // gd.zzp.un_640 tlh.de.da_653  tlh.lb.de_432 lb.ms.eo_422 
  0xfc3440a4, 0x060b270c, 0x04073807, 0x69000102,   // lb.xh.zzp_433 gd.es.de_543  tk.bg.ru_432 en.mfe.un_220 
  // [116a0]
  0x190b6509, 0x321c2107, 0x2c63fea9, 0x233021a4,   // gv.es.gl_444 jw.id.bs_432  tlh.sco.fy_544 fa.uz.ky_433 
  0x48073ca7, 0x03007320, 0x02007319, 0x3810230c,   // ug.bg.tt_532 ny.nl.un_850  ny.da.un_750 ky.be.tk_543 
  0x30220b02, 0x0511180c, 0x18fe58a4, 0x4630fe60,   // es.oc.uz_222 ga.ro.fr_543  om.tlh.ga_433 tlh.uz.qu_664 
  0x28650307, 0x40730613, 0x2c003e08, 0x342821a9,   // nl.gv.sw_432 de.ny.lb_665  rm.fy.un_430 fa.sd.ps_544 
  // [116b0]
  0x1d5f37a4, 0x043813ee, 0x1e1c130c, 0x11371dee,   // st.tn.la_433 et.tk.fi_422  et.id.ms_543 la.st.ro_422 
  0x1a044904, 0x2c0413ad, 0x151738ec, 0x56005a04,   // to.fi.tl_332 et.fi.fy_643  tk.sr.un_644 sm.mg.un_320 
  0x2f1d5aa0, 0x6b0913a4, 0x233736a4, 0x372548ad,   // sm.la.su_322 et.pl.ceb_433  ab.ba.ky_433 tt.mn.ba_643 
  0x0f3e0608, 0x304c3e0b, 0x173b50a4, 0x32177909,   // de.rm.lv_443 rm.wo.uz_542  fj.so.sr_433 war.sr.bs_444 
  // [116c0]
  0x32003b08, 0x3e003011, 0x58372005, 0x2a002704,   // so.bs.un_430 uz.rm.un_630  sq.st.om_333 gd.mt.un_320 
  0x3b505d11, 0x5f000408, 0x35fe4607, 0x125f25a0,   // ss.fj.so_653 fi.tn.un_430  qu.tlh.zu_432 eu.tn.hu_322 
  0x13005a07, 0x107613ad, 0x464e51a4, 0x343d305a,   // sm.et.un_420 et.crs.lt_643  kl.ay.qu_433 uz.ku.ps_553 
  0x50593b08, 0xfe00371a, 0xfe00610d, 0x53691307,   // so.rn.fj_443 st.tlh.un_760  za.tlh.un_540 et.mfe.ht_432 
  // [116d0]
  0x502855a9, 0x0efe04ec, 0x45353408, 0x1d0451ad,   // rw.sw.fj_544 fi.tlh.is_644  xh.zu.ln_443 kl.fi.la_643 
  0x13001f12, 0x1b3b50a0, 0x3e001522, 0x35345005,   // cy.et.un_640 fj.so.tr_322  un.rm.un_870 fj.xh.zu_333 
  0x0e3e3060, 0x23003e0b, 0x25001018, 0x08042504,   // uz.rm.is_664 rm.ca.un_520  be.mn.un_740 mn.ru.uk_332 
  0x1f00510c, 0x180801a0, 0x5a0f5c12, 0x16fc4204,   // kl.cy.un_530 en.no.ga_322  sa.lv.sm_654 co.zzp.hr_332 
  // [116e0]
  0x45630111, 0x4579050c, 0x583b01ad, 0x231942ee,   // en.sco.ln_653 fr.war.ln_543  en.so.om_643 co.gl.ca_422 
  0x3421280c, 0x10001511, 0x534207ec, 0x1e6a1ca9,   // sd.fa.ps_543 un.be.un_630  it.co.ht_644 id.haw.ms_544 
  0x28004305, 0x494b500e, 0x6a4b6e12, 0x25002823,   // ie.sw.un_330 fj.mi.to_555  hmn.mi.haw_654 sw.eu.un_880 
  0x1735110c, 0x50001c0d, 0x1d4b4708, 0x33001d08,   // ro.tg.sr_543 id.fj.un_540  sn.mi.la_443 la.nn.un_430 
  // [116f0]
  0x28495a11, 0x4b001113, 0x47404ba0, 0x67506808,   // sm.to.sw_653 ro.mi.un_650  mi.lb.sn_322 ig.fj.ak_443 
  0x080236ec, 0x36021d04, 0x1d004008, 0x1d400ba4,   // gn.da.no_644 la.da.gn_332  lb.la.un_430 es.lb.la_433 
  0x222336ad, 0x202545ad, 0x1d00402a, 0x25026b07,   // gn.ca.oc_643 ln.eu.sq_643  lb.la.un_970 ceb.da.eu_432 
  0x191d0b0c, 0x28045012, 0x4b5a1ea4, 0x50254ba9,   // es.la.gl_543 fj.fi.sw_654  ms.sm.mi_433 mi.eu.fj_544 
  // [11700]
  0x6a2567ad, 0x0600250c, 0x5a4b1c07, 0x42071d09,   // ak.eu.haw_643 eu.de.un_530  id.mi.sm_432 la.it.co_444 
  0x2c003902, 0x0c2c1d08, 0x02261d07, 0x51fc1d0c,   // br.fy.un_220 la.fy.sv_443  la.ia.da_432 la.zzp.kl_543 
  0x3c1017af, 0x25372304, 0x23303811, 0x303748af,   // sr.be.ug_655 ky.ba.mn_332  tk.uz.ky_653 tt.ba.uz_655 
  0x56003607, 0x19180bee, 0x46000a04, 0x0730250b,   // gn.mg.un_420 es.ga.gl_422  pt.qu.un_320 mn.uz.bg_542 
  // [11710]
  0x34002011, 0x52355d0c, 0x5a6a0107, 0x6a0e06ee,   // sq.xh.un_630 ss.zu.ha_543  en.haw.sm_432 de.is.haw_422 
  0x2700230c, 0x151104ad, 0x1b005a02, 0x3530440c,   // ca.gd.un_530 ru.ro.un_643  sm.tr.un_220 kk.uz.tg_543 
  0x314d12a4, 0x791a38a4, 0x5d1d110c, 0x35001b05,   // hu.aa.az_433 tk.tl.war_433  ro.la.ss_543 tr.zu.un_330 
  0x181d4ba4, 0x3f00090d, 0x18311b0d, 0x5c5a0fa0,   // mi.la.ga_433 pl.af.un_540  tr.az.ga_554 lv.sm.sa_322 
  // [11720]
  0x123421ad, 0x5c2a6208, 0x432101a4, 0x462a20a4,   // fa.ps.ur_643 kha.mt.sa_443  en.jw.ie_433 sq.mt.qu_433 
  0x330c50af, 0x402c51a4, 0x0603250c, 0x05074b04,   // fj.sv.nn_655 kl.fy.lb_433  eu.nl.de_543 mi.it.fr_332 
  0x0a0c15a9, 0x4b1dfcad, 0x205867a9, 0x02002407,   // un.sv.pt_544 zzp.la.mi_643  ak.om.sq_544 eo.da.un_420 
  0x373f03a0, 0x47641daf, 0x3f120c07, 0x33005104,   // nl.af.st_322 la.lg.sn_655  sv.hu.af_432 kl.nn.un_320 
  // [11730]
  0x4e3633a4, 0x762a46ad, 0x5c005634, 0x172512a9,   // nn.gn.ay_433 qu.mt.crs_643  mg.sa.un_A80 hu.eu.sr_544 
  0x4c121e12, 0xfe462aec, 0x115d0107, 0x0c333eee,   // ms.hu.wo_654 mt.qu.tlh_644  en.ss.ro_432 rm.nn.sv_422 
  0x1b0e0c0c, 0x421156a7, 0x26232512, 0x30021508,   // sv.is.tr_543 mg.ro.co_532  eu.ca.ia_654 un.da.uz_443 
  0x2d5c20ee, 0x46070107, 0x0a153c07, 0x3010230c,   // sq.sa.sk_422 en.it.qu_432  ug.mk.un_420 ky.be.uz_543 
  // [11740]
  0x10151712, 0x2300100e, 0x362548a0, 0x4b000f08,   // sr.be.un_640 be.ky.un_550  tt.mn.ab_322 lv.mi.un_430 
  0x111748a9, 0x63673808, 0x05004004, 0x150a11a7,   // tt.sr.ro_544 tk.ak.sco_443  lb.fr.un_320 ro.mk.un_532 
  0x47003802, 0x35483013, 0x494b0fac, 0x0410170c,   // tk.sn.un_220 uz.tt.tg_665  lv.mi.to_632 sr.be.ru_543 
  0x15005312, 0x182312a0, 0x17346a08, 0xfc006214,   // ht.un.un_640 ur.ky.ar_322  haw.xh.sr_443 kha.zzp.un_660 
  // [11750]
  0x40060312, 0x0d3049a0, 0x584c350b, 0x07173c0b,   // nl.de.lb_654 to.uz.cs_322  zu.wo.om_542 ug.sr.bg_542 
  0x68007814, 0x34001b0d, 0x685202af, 0xfc353402,   // ve.ig.un_660 tr.xh.un_540  da.ha.ig_655 xh.zu.zzp_222 
  0x021501a4, 0x42311b0c, 0x44381013, 0x15000a05,   // en.da.un_430 tr.az.co_543  be.tk.kk_665 mk.un.un_330 
  0x32004204, 0x45006019, 0x0d00fe04, 0x3048370d,   // co.bs.un_320 vo.ln.un_750  tlh.cs.un_320 ba.tt.uz_554 
  // [11760]
  0xfc005308, 0x2b040804, 0x422d31ec, 0x175a09a0,   // ht.zzp.un_430 no.fi.vi_332  az.sk.co_644 pl.sm.sr_322 
  0x1d003107, 0x24004208, 0x52285b07, 0x023035a4,   // az.la.un_420 co.eo.un_430  sg.sw.ha_432 zu.uz.da_433 
  0x49505a14, 0x1c0d5c5a, 0x0123150b, 0x01001102,   // sm.fj.to_666 sa.ne.mr_553  un.ca.en_542 ro.en.un_220 
  0x3e2530a0, 0x4004060c, 0x040825a7, 0x040a1502,   // uz.eu.rm_322 de.fi.lb_543  mn.uk.ru_532 un.mk.ru_222 
  // [11770]
  0x3f062e02, 0x502d0d0d, 0x260b0107, 0x0c3f0e02,   // fo.de.af_222 cs.sk.fj_554  en.es.ia_432 is.af.sv_222 
  0x17002f02, 0x320a60ee, 0x16020da0, 0x191729a9,   // su.sr.un_220 vo.pt.bs_422  cs.da.hr_322 sl.sr.gl_544 
  0x0c001212, 0x483038ac, 0x5a002702, 0x1100240c,   // hu.sv.un_640 tk.uz.tt_632  gd.sm.un_220 eo.ro.un_530 
  0x5d5934a0, 0x442330ad, 0x6500111a, 0x2435290c,   // xh.rn.ss_322 uz.ky.kk_643  ro.gv.un_760 sl.zu.eo_543 
  // [11780]
  0x35635d08, 0x65004005, 0x3400212a, 0x0c1d4304,   // ss.sco.zu_443 lb.gv.un_330  fa.ps.un_970 ie.la.sv_332 
  0x0f0303a4, 0x69584e0d, 0x363504a0, 0x0a583ba9,   // nl.nl.lv_433 ay.om.mfe_554  ru.tg.ab_322 so.om.pt_544 
  0x1d110704, 0x4e622d07, 0x2c0c0208, 0x58027505,   // it.ro.la_332 sk.kha.ay_432  da.sv.fy_443 nso.da.om_333 
  0x18002302, 0x395e63ad, 0x7600080d, 0x0a10250c,   // ky.ar.un_220 sco.ts.br_643  no.crs.un_540 mn.be.mk_543 
  // [11790]
  0x11002804, 0x4d582a05, 0x124d2712, 0x3f120207,   // sw.ro.un_320 mt.om.aa_333  gd.aa.hu_654 da.hu.af_432 
  0x380730a4, 0x24000607, 0xfc00511a, 0x1a6b3ba9,   // uz.bg.tk_433 de.eo.un_420  kl.zzp.un_760 so.ceb.tl_544 
  0x433e01a4, 0x31004d22, 0x794d4e05, 0x37735f13,   // en.rm.ie_433 aa.az.un_870  ay.aa.war_333 tn.ny.st_665 
  0x2d1b0d08, 0x3e5804af, 0x46135c07, 0x10070408,   // cs.tr.sk_443 fi.om.rm_655  sa.et.qu_432 ru.bg.be_443 
  // [117a0]
  0x041b3f08, 0x64fe5ca0, 0x4e2a300c, 0x2134280d,   // af.tr.fi_443 sa.tlh.lg_322  uz.mt.ay_543 sd.ps.fa_554 
  0x3b306407, 0x06151107, 0x173711ee, 0x5f51735a,   // lg.uz.so_432 ro.de.un_420  ro.ba.sr_422 ny.kl.tn_553 
  0x1e524e07, 0x261dfc0c, 0x241d4d0c, 0x64580ba0,   // ay.ha.ms_432 zzp.la.ia_543  aa.la.eo_543 es.om.lg_322 
  0x1c2b64ee, 0x40731d07, 0x07423e09, 0x50006a1b,   // lg.vi.id_422 la.ny.lb_432  rm.co.it_444 haw.fj.un_770 
  // [117b0]
  0x02005509, 0x5c00640d, 0x512842ee, 0x381b02a7,   // rw.da.un_440 lg.sa.un_540  co.sw.kl_422 da.tr.tk_532 
  0x73552814, 0x58006414, 0x03003108, 0x39002e02,   // sw.rw.ny_666 lg.om.un_660  az.nl.un_430 fo.br.un_220 
  0x04007907, 0x50100907, 0x0a08170e, 0x30005c07,   // war.fi.un_420 pl.lt.fj_432  sr.uk.mk_555 sa.uz.un_420 
  0x2224110c, 0x79000708, 0x23003b19, 0x4c5c64a0,   // ro.eo.oc_543 it.war.un_430  ks.ky.un_750 lg.sa.wo_322 
  // [117c0]
  0x5c582a09, 0x30550208, 0x120e1805, 0x043e42ad,   // mt.om.sa_444 da.rw.uz_443  ga.is.hu_333 co.rm.fi_643 
  0x240979a0, 0x304834a0, 0x30551bad, 0x3f150ca0,   // war.pl.eo_322 xh.tt.uz_322  tr.rw.uz_643 sv.af.un_320 
  0x181f2155, 0x1847020c, 0x3646680d, 0x31381bec,   // jw.cy.ga_442 da.sn.ga_543  ig.qu.gn_554 tr.tk.az_644 
  0x584efe0c, 0x065301a4, 0xfe53735a, 0x3100381a,   // tlh.ay.om_543 en.ht.de_433  ny.ht.tlh_553 tk.az.un_760 
  // [117d0]
  0xfe00060d, 0x062865a4, 0x18fc2760, 0x532206a4,   // de.tlh.un_540 gv.sw.de_433  gd.zzp.ga_664 de.oc.ht_433 
  0x1b005305, 0x023068a4, 0x73000909, 0x734746ec,   // ht.tr.un_330 ig.uz.da_433  pl.ny.un_440 qu.sn.ny_644 
  0x474e46af, 0x4630fe5a, 0x31121ba7, 0x2c007309,   // qu.ay.sn_655 tlh.uz.qu_553  tr.hu.az_532 ny.fy.un_440 
  0x38006007, 0x30183da4, 0x3600300e, 0x2e00fc04,   // vo.tk.un_420 ku.ar.uz_433  uz.ab.un_550 zzp.fo.un_320 
  // [117e0]
  0xfe001f08, 0x400d2da7, 0x550964a0, 0x484415af,   // cy.tlh.un_430 sk.cs.lb_532  lg.pl.rw_322 un.kk.tt_655 
  0x55006409, 0x15003704, 0xfe006520, 0xfe006521,   // lg.rw.un_440 st.un.un_320  gv.tlh.un_850 gv.tlh.un_860 
  0x1704070c, 0xfe006519, 0x2500380e, 0x0f002a1b,   // bg.ru.sr_543 gv.tlh.un_750  tk.mn.un_550 mt.lv.un_770 
  0x1228305a, 0x6a545dad, 0x605451a4, 0x04100e07,   // uz.sd.ur_553 ss.ik.haw_643  kl.ik.vo_433 is.lt.fi_432 
  // [117f0]
  0x0f002a29, 0x5e5a11a4, 0x35255407, 0x52102f05,   // mt.lv.un_960 ro.sm.ts_433  ik.eu.zu_432 su.lt.ha_333 
  0x5a002a04, 0x4423370d, 0x15000407, 0x5835340e,   // mt.sm.un_320 ba.ky.kk_554  ru.un.un_420 xh.zu.om_555 
  0x52542e07, 0x3f003e07, 0x2f51110c, 0x3f0f08a0,   // fo.ik.ha_432 rm.af.un_420  ro.kl.su_543 no.lv.af_322 
  0x51004e0e, 0x17100aec, 0x350a100c, 0x15002a13,   // ay.kl.un_550 mk.be.sr_644  be.mk.tg_543 mt.un.un_650 
  
  // [11800]
  0x2b2d3fa0, 0x020c110c, 0x0612040c, 0x39000508,   // af.sk.vi_322 ro.sv.da_543  fi.hu.de_543 fr.br.un_430 
  0x154205ad, 0x17480aee, 0x0700650b, 0x020b6eee,   // fr.co.un_643 mk.tt.sr_422  gv.it.un_520 hmn.es.da_422 
  0x05fc01a4, 0x214615a0, 0x44351508, 0x0100fc19,   // en.zzp.fr_433 un.qu.jw_322  un.tg.kk_443 zzp.en.un_750 
  0x494b5aee, 0x44171107, 0x30352512, 0x1a006404,   // sm.mi.to_422 ro.sr.kk_432  mn.tg.uz_654 lg.tl.un_320 
  // [11810]
  0x043038a7, 0x314830a9, 0x09684904, 0x552e79ee,   // tk.uz.ru_532 uz.tt.az_544  to.ig.pl_332 war.fo.rw_422 
  0x6b005e12, 0x3d1234ee, 0x55006413, 0x0e2e55a0,   // ts.ceb.un_640 ps.ur.ku_422  lg.rw.un_650 rw.fo.is_322 
  0x33080eee, 0x55002e05, 0x34212855, 0x3b795505,   // is.no.nn_422 fo.rw.un_330  sd.fa.ps_442 rw.war.so_333 
  0x65005804, 0x07150811, 0x0408100b, 0x36002808,   // om.gv.un_320 uk.bg.un_630  be.uk.ru_542 sw.gn.un_430 
  // [11820]
  0x170a100b, 0x1a6b6804, 0x0700220d, 0x5e1827ad,   // be.mk.sr_542 ig.ceb.tl_332  oc.it.un_540 gd.ga.ts_643 
  0x35006a0e, 0x37343507, 0x255d6a08, 0x275d18a0,   // haw.zu.un_550 zu.xh.st_432  haw.ss.eu_443 ga.ss.gd_322 
  0x170a10ee, 0x07153611, 0x65345ead, 0x6330280c,   // be.mk.sr_422 ab.bg.un_630  ts.xh.gv_643 sw.uz.sco_543 
  0x34737508, 0x46003304, 0x6b0165ee, 0x301511ee,   // nso.ny.xh_443 nn.qu.un_320  gv.en.ceb_422 ro.uz.un_420 
  // [11830]
  0x46003308, 0x24007308, 0x461e1ca9, 0x01156312,   // nn.qu.un_430 ny.eo.un_430  id.ms.qu_544 sco.en.un_640 
  0x47363ea4, 0x46685409, 0x2b46fead, 0x1e1c01a4,   // rm.gn.sn_433 ik.ig.qu_444  tlh.qu.vi_643 en.id.ms_433 
  0x3f3e24a4, 0x36004b13, 0x63062008, 0x08103507,   // eo.rm.af_433 mi.gn.un_650  sq.de.sco_443 tg.be.uk_432 
  0x1e1c20a0, 0x793f6804, 0x190b0a55, 0x33123f07,   // sq.id.ms_322 ig.af.war_332  pt.es.gl_442 af.hu.nn_432 
  // [11840]
  0x100848a4, 0x633f0304, 0x3f000807, 0x48383102,   // tt.uk.be_433 nl.af.sco_332  no.af.un_420 az.tk.tt_222 
  0x2c002405, 0x474625a0, 0x1000150c, 0x2e6246a9,   // eo.fy.un_330 eu.qu.sn_322  un.be.un_530 qu.kha.fo_544 
  0x01796504, 0x0446fe55, 0x10440855, 0x44080402,   // gv.war.en_332 tlh.qu.fi_442  uk.kk.be_442 ru.uk.kk_222 
  0xfe4e4612, 0x121b25a0, 0x066301ee, 0x0c69210c,   // qu.ay.tlh_654 eu.tr.hu_322  en.sco.de_422 jw.mfe.sv_543 
  // [11850]
  0x16243305, 0x080c0f07, 0x761e1ca4, 0x1b312005,   // nn.eo.hr_333 lv.sv.no_432  id.ms.crs_433 sq.az.tr_333 
  0x2e120eac, 0x48004419, 0x032a0107, 0x23170804,   // is.hu.fo_632 kk.tt.un_750  en.mt.nl_432 uk.sr.ky_332 
  0x122e0ea9, 0x2e090e04, 0x212220ad, 0x44122113,   // is.fo.hu_544 is.pl.fo_332  sq.oc.jw_643 fa.ur.kk_665 
  0x265d1da9, 0x1218280e, 0x1503010c, 0x53232208,   // la.ss.ia_544 sd.ar.ur_555  en.nl.un_543 oc.ca.ht_443 
  // [11860]
  0x2f1b5204, 0x1d0c26a0, 0x2e091207, 0x26001d1b,   // ha.tr.su_332 ia.sv.la_322  hu.pl.fo_432 la.ia.un_770 
  0x4c002f11, 0x253c3007, 0x654f53a0, 0x2f43050c,   // su.wo.un_630 uz.ug.mn_432  ht.bi.gv_322 fr.ie.su_543 
  0x23112555, 0xfc005504, 0x420729a0, 0x56002104,   // mn.ro.ky_442 rw.zzp.un_320  sl.it.co_322 jw.mg.un_320 
  0x6e002009, 0x210a2fa0, 0x42071211, 0x3025350e,   // sq.hmn.un_440 su.pt.jw_322  hu.it.co_653 tg.mn.uz_555 
  // [11870]
  0x0b4e22a7, 0x35231002, 0x24003204, 0x113534ec,   // oc.ay.es_532 be.ky.tg_222  bs.eo.un_320 xh.zu.ro_644 
  0x19213604, 0x64006318, 0x3e074212, 0x1d01fcec,   // gn.jw.gl_332 sco.lg.un_740  co.it.rm_654 zzp.en.la_644 
  0x29002d0e, 0x34005d23, 0x4900210c, 0x1d092f05,   // sk.sl.un_550 ss.xh.un_880  jw.to.un_530 su.pl.la_333 
  0xfe006e08, 0x42160704, 0x292238a4, 0x1f002902,   // hmn.tlh.un_430 it.hr.co_332  tk.oc.sl_433 sl.cy.un_220 
  // [11880]
  0x061c6ea6, 0x3b5a50ee, 0x1c4c2fad, 0x4c1f6eee,   // hmn.id.de_521 fj.sm.so_422  su.wo.id_643 hmn.cy.wo_422 
  0x11003c1a, 0x18003013, 0x091a13ee, 0x551f150b,   // ug.ro.un_760 uz.ar.un_650  et.tl.pl_422 un.cy.rw_542 
  0x4c002504, 0x09003402, 0x4c211f0c, 0x10001312,   // eu.wo.un_320 xh.pl.un_220  cy.jw.wo_543 et.lt.un_640 
  0x16330804, 0x2f00400d, 0x0f0c1304, 0x443625a7,   // no.nn.hr_332 lb.su.un_540  et.sv.lv_332 mn.ab.kk_532 
  // [11890]
  0x21006e07, 0x0f0c4804, 0xfc006807, 0x50482a5a,   // hmn.jw.un_420 tt.sv.lv_332  ig.zzp.un_420 mt.tt.fj_553 
  0x135a50a4, 0x4c6a50af, 0x1f495aaf, 0x4900230b,   // fj.sm.et_433 fj.haw.wo_655  sm.to.cy_655 ca.to.un_520 
  0x122e0e08, 0x630e13ad, 0x34001302, 0x5d5e35a4,   // is.fo.hu_443 et.is.sco_643  et.xh.un_220 zu.ts.ss_433 
  0x0d004904, 0x56422f02, 0x2d0d6eee, 0x6e2718ad,   // to.cs.un_320 su.co.mg_222  hmn.cs.sk_422 ga.gd.hmn_643 
  // [118a0]
  0x2325100d, 0x4a2d18af, 0x21122809, 0x0b2d0d05,   // be.mn.ky_554 ga.sk.yo_655  sd.ur.fa_444 cs.sk.es_333 
  0x27620e55, 0x20001b05, 0x3100fe12, 0x3e005602,   // is.kha.gd_442 tr.sq.un_330  tlh.az.un_640 mg.rm.un_220 
  0x12002d0b, 0x12281814, 0x343d12ad, 0x1f001807,   // sk.hu.un_520 ar.sd.ur_666  ur.ku.ps_643 ga.cy.un_420 
  0x65003713, 0x22390209, 0x20fe46ad, 0x35345405,   // st.gv.un_650 da.br.oc_444  qu.tlh.sq_643 ik.xh.zu_333 
  // [118b0]
  0x083707a0, 0x1100430e, 0x070a35ee, 0x0a006504,   // bg.ba.uk_322 ie.ro.un_550  tg.mk.bg_422 gv.pt.un_320 
  0x0735300b, 0x4600fe21, 0x2afe4609, 0x58004d07,   // uz.tg.bg_542 tlh.qu.un_860  qu.tlh.mt_444 aa.om.un_420 
  0x190a38a0, 0x48004612, 0x4600fe1a, 0x48fe4d12,   // tk.pt.gl_322 qu.tt.un_640  tlh.qu.un_760 aa.tlh.tt_654 
  0x20004609, 0x58002a12, 0x58482a0c, 0x25153807,   // qu.sq.un_440 mt.om.un_640  mt.tt.om_543 tk.mn.un_420 
  // [118c0]
  0x3448350c, 0x63000512, 0x3b464dee, 0x4dfe2aec,   // zu.tt.xh_543 fr.sco.un_640  aa.qu.so_422 mt.tlh.aa_644 
  0x0a00480c, 0x2e330ca0, 0x18122da4, 0x380a600b,   // tt.mk.un_530 sv.nn.fo_322  sk.hu.ga_433 vo.pt.tk_542 
  0x36004e21, 0x64004608, 0x281b25ee, 0x4800fe14,   // ay.gn.un_860 qu.lg.un_430  eu.tr.sw_422 tlh.tt.un_660 
  0xfe2a4611, 0x041008ad, 0x48000504, 0x2a004622,   // qu.mt.tlh_653 uk.be.ru_643  fr.tt.un_320 qu.mt.un_870 
  // [118d0]
  0x314860ea, 0x00004637, 0x3048fe04, 0x2a516409,   // vo.tt.az_822 qu.un.un_B00  tlh.tt.uz_332 lg.kl.mt_444 
  0x19004e0c, 0x241b64ec, 0x355d5e5a, 0x34182302,   // ay.gl.un_530 lg.tr.eo_644  ts.ss.zu_553 ky.ar.ps_222 
  0x645173a9, 0x25233855, 0x04350a02, 0x12301804,   // ny.kl.lg_544 tk.ky.mn_442  mk.tg.ru_222 ar.uz.ur_332 
  0x5d3528ee, 0x440710ee, 0x101730a4, 0x2c102a0c,   // sw.zu.ss_422 be.bg.kk_422  uz.sr.be_433 mt.lt.fy_543 
  // [118e0]
  0x28005d08, 0x211234ac, 0x5d3547ec, 0x1e1c1305,   // ss.sw.un_430 ps.ur.fa_632  sn.zu.ss_644 et.id.ms_333 
  0x35006821, 0x080717a4, 0x28343012, 0x68782a13,   // ig.zu.un_860 sr.bg.uk_433  uz.ps.sd_654 mt.ve.ig_665 
  0x1c212f07, 0x171004a4, 0x40000619, 0x55003507,   // su.jw.id_432 ru.be.sr_433  de.lb.un_750 zu.rw.un_420 
  0x49001812, 0x441834a4, 0x3534680c, 0x21283409,   // ga.to.un_640 ps.ar.kk_433  ig.xh.zu_543 ps.sd.fa_444 
  // [118f0]
  0x2700110c, 0x04022b07, 0x03002d08, 0x272f21a0,   // ro.gd.un_530 vi.da.fi_432  sk.nl.un_430 jw.su.gd_322 
  0x64286860, 0x28685d08, 0x251f1304, 0x3800180c,   // ig.sw.lg_664 ss.ig.sw_443  et.cy.eu_332 ga.tk.un_530 
  0x276b37ad, 0x676847a7, 0x3534450c, 0x425c0212,   // st.ceb.gd_643 sn.ig.ak_532  ln.xh.zu_543 da.sa.co_654 
  0x1d00600d, 0x2f054307, 0x1b004811, 0x60692308,   // vo.la.un_540 ie.fr.su_432  tt.tr.un_630 ca.mfe.vo_443 
  // [11900]
  0x07100855, 0x0d131c0c, 0x34183bee, 0x56001509,   // uk.be.bg_442 mr.bh.ne_543  ks.ar.ps_422 un.mg.un_440 
  0x27190b02, 0x18270204, 0x271865ee, 0x2c003e07,   // es.gl.gd_222 da.gd.ga_332  gv.ga.gd_422 rm.fy.un_420 
  0x3848230e, 0x15383708, 0x16006507, 0x62050104,   // ky.tt.tk_555 ba.tk.un_443  gv.hr.un_420 en.fr.kha_332 
  0x170a0407, 0x02005c13, 0xfe006013, 0x1f4a54a0,   // ru.mk.sr_432 sa.da.un_650  vo.tlh.un_650 ik.yo.cy_322 
  // [11910]
  0x1710150c, 0x08fc1504, 0xfe004702, 0x6300620b,   // un.be.sr_543 un.zzp.no_332  sn.tlh.un_220 kha.sco.un_520 
  0x1f182b5a, 0x30201204, 0x0e131502, 0x23304804,   // vi.ga.cy_553 hu.sq.uz_332  un.et.is_222 tt.uz.ky_332 
  0x2315480c, 0x16000304, 0x38461d07, 0x17000908,   // tt.ky.un_530 nl.hr.un_320  la.qu.tk_432 pl.sr.un_430 
  0x01fe46ee, 0x040a2304, 0x21123ba0, 0x2e001008,   // qu.tlh.en_422 ky.mk.ru_332  ks.ur.fa_322 lt.fo.un_430 
  // [11920]
  0x06005711, 0x29320f02, 0x4c6346ec, 0x3b211209,   // na.de.un_630 lv.bs.sl_222  qu.sco.wo_644 ur.fa.ks_444 
  0x39005305, 0x31000302, 0x22000b09, 0x20036204,   // ht.br.un_330 nl.az.un_220  es.oc.un_440 kha.nl.sq_332 
  0x2e430207, 0x121844a0, 0x01000608, 0x18005302,   // da.ie.fo_432 kk.ar.ur_322  de.en.un_430 ht.ga.un_220 
  0x2e003605, 0x271d0107, 0x483b2e0c, 0x23001819,   // gn.fo.un_330 en.la.gd_432  fo.so.tt_543 ar.ky.un_750 
  // [11930]
  0x332c1002, 0x0a441505, 0x12001102, 0x04080aac,   // lt.fy.nn_222 un.kk.mk_333  ro.hu.un_220 mk.uk.ru_632 
  0x0d190ba7, 0x0d452d08, 0x483725af, 0x381530a9,   // es.gl.cs_532 sk.ln.cs_443  mn.ba.tt_655 uz.tk.un_540 
  0x0807040b, 0x4c6b4d12, 0x5300200c, 0x332763a4,   // ru.bg.uk_542 aa.ceb.wo_654  sq.ht.un_530 sco.gd.nn_433 
  0x5c0913a7, 0x31321602, 0x3e002007, 0x37441055,   // bh.hi.sa_532 hr.bs.az_222  sq.rm.un_420 be.kk.ba_442 
  // [11940]
  0x0d00340d, 0x210520ad, 0x2000210e, 0x073e4214,   // xh.cs.un_540 sq.fr.jw_643  jw.sq.un_550 co.rm.it_666 
  0x21007813, 0x43005408, 0x190b18a7, 0x425321b2,   // ve.jw.un_650 ik.ie.un_430  ga.es.gl_532 jw.ht.co_732 
  0x35347812, 0x420754ad, 0x2d0d21af, 0x3952780c,   // ve.xh.zu_654 ik.it.co_643  jw.cs.sk_655 ve.ha.br_543 
  0x052149a7, 0x0553210d, 0x73785ead, 0x215049a9,   // to.jw.fr_532 jw.ht.fr_554  ts.ve.ny_643 to.fj.jw_544 
  // [11950]
  0x17000608, 0x20242da0, 0x48232514, 0x202147a4,   // de.sr.un_430 sk.eo.sq_322  mn.ky.tt_666 sn.jw.sq_433 
  0x05002213, 0x1a3e07a4, 0x071d42ee, 0x5e002012,   // oc.fr.un_650 it.rm.tl_433  co.la.it_422 sq.ts.un_640 
  0x18122ea0, 0x074254ee, 0x18000e02, 0x09533402,   // fo.hu.ga_322 ik.co.it_422  is.ga.un_220 xh.ht.pl_222 
  0x3f000704, 0x0e2e1a07, 0x3e001d1a, 0x425a4907,   // it.af.un_320 tl.fo.is_432  la.rm.un_760 to.sm.co_432 
  // [11960]
  0x6900130d, 0x4a184507, 0x29734508, 0x08153707,   // et.mfe.un_540 ln.ga.yo_432  ln.ny.sl_443 ba.uk.un_420 
  0x39006134, 0x436e3ead, 0x18002e0c, 0x6e400612,   // za.br.un_A80 rm.hmn.ie_643  fo.ga.un_530 de.lb.hmn_654 
  0x35134a07, 0x4f060107, 0x2f6e27ee, 0x3f3e030d,   // yo.et.zu_432 en.de.bi_432  gd.hmn.su_422 nl.rm.af_554 
  0x034861a7, 0x4a3551a0, 0x27001e0d, 0x392a0aa7,   // za.tt.nl_532 kl.zu.yo_322  ms.gd.un_540 pt.mt.br_532 
  // [11970]
  0x39006122, 0x6800350d, 0x03096ead, 0x1b003404,   // za.br.un_870 zu.ig.un_540  hmn.pl.nl_643 xh.tr.un_320 
  0xfe3832a0, 0x110b2212, 0x05006905, 0x1122fe12,   // bs.tk.tlh_322 oc.es.ro_654  mfe.fr.un_330 tlh.oc.ro_654 
  0x79011dee, 0x43053ead, 0xfe002119, 0x69390d11,   // la.en.war_422 rm.fr.ie_643  jw.tlh.un_750 cs.br.mfe_653 
  0x58001321, 0x69384808, 0x0e002902, 0x13353405,   // et.om.un_860 tt.tk.mfe_443  sl.is.un_220 xh.zu.et_333 
  // [11980]
  0x18004902, 0x043615a4, 0x30004c12, 0x4c00300c,   // to.ga.un_220 un.ab.ru_433  wo.uz.un_640 uz.wo.un_530 
  0x25002a04, 0x343773ec, 0x04152308, 0x48150411,   // mt.eu.un_320 ny.st.xh_644  ky.ru.un_430 ru.tt.un_630 
  0x27005d04, 0xfe7302a4, 0x15080aa0, 0x4a423e0d,   // ss.gd.un_320 da.ny.tlh_433  mk.uk.un_322 rm.co.yo_554 
  0x2700fe21, 0x2b005d04, 0x4200790d, 0x1f1865a9,   // tlh.gd.un_860 ss.vi.un_320  war.co.un_540 gv.ga.cy_544 
  // [11990]
  0x3400370c, 0x341821a6, 0x7900420d, 0x20222164,   // st.xh.un_530 fa.ar.ps_521  co.war.un_540 jw.oc.sq_762 
  0x18005d05, 0x081107a4, 0x571306a4, 0x18002b1a,   // ss.ga.un_330 bg.ro.uk_433  de.et.na_433 vi.ga.un_760 
  0x2a1b3e04, 0x3e00420d, 0x3e004204, 0x42000b04,   // rm.tr.mt_332 co.rm.un_540  co.rm.un_320 es.co.un_320 
  0xfc003e07, 0x09001604, 0xfc3e3702, 0x402f3604,   // rm.zzp.un_420 hr.pl.un_320  st.rm.zzp_222 gn.su.lb_332 
  // [119a0]
  0xfe026104, 0x36001212, 0x212f0d07, 0x17092d09,   // za.da.tlh_332 hu.gn.un_640  cs.su.jw_432 sk.pl.sr_444 
  0x482344a9, 0x6200121a, 0x532122ad, 0x18004c08,   // kk.ky.tt_544 hu.kha.un_760  oc.jw.ht_643 wo.ga.un_430 
  0x2400090c, 0x22000d0d, 0x05000e04, 0x041508ee,   // pl.eo.un_530 cs.oc.un_540  is.fr.un_320 uk.ru.un_420 
  0x2d0d12ed, 0x04173605, 0x4f003e13, 0x123d3b0c,   // hu.cs.sk_622 ab.sr.ru_333  rm.bi.un_650 ks.ku.ur_543 
  // [119b0]
  0x18003422, 0x2a006905, 0x18003c12, 0x29246e07,   // ps.ar.un_870 mfe.mt.un_330  ug.ar.un_640 hmn.eo.sl_432 
  0x2f000d07, 0x40212f12, 0x6e2dfea0, 0x214c120c,   // cs.su.un_420 su.jw.lb_654  tlh.sk.hmn_322 hu.wo.jw_543 
  0x25354808, 0x1d001b11, 0x483c3714, 0x6b531dec,   // tt.tg.mn_443 tr.la.un_630  ba.ug.tt_666 la.ht.ceb_644 
  0x043848a7, 0x120e2ea7, 0x1f004d14, 0x07110804,   // tt.tk.fi_532 fo.is.hu_532  aa.cy.un_660 uk.ro.bg_332 
  // [119c0]
  0x53000604, 0x08003c0e, 0x3808100e, 0x23182107,   // de.ht.un_320 ug.uk.un_550  be.uk.tk_555 fa.ar.ky_432 
  0x0a153c11, 0x220d0e0c, 0x3600fc0c, 0x0a002313,   // ug.mk.un_630 is.cs.oc_543  zzp.gn.un_530 ca.pt.un_650 
  0x120b1911, 0x44233004, 0x3c3d2107, 0x0e0a1904,   // gl.es.hu_653 uz.ky.kk_332  fa.ku.ug_432 gl.pt.is_332 
  0x0e2d0d5e, 0x6b0262ad, 0x2e0e2d07, 0x22232709,   // cs.sk.is_652 kha.da.ceb_643  sk.is.fo_432 gd.ca.oc_444 
  // [119d0]
  0x120a2e0c, 0x56422305, 0x11002f04, 0x652b3712,   // fo.pt.hu_543 ca.co.mg_333  su.ro.un_320 st.vi.gv_654 
  0x5c093b10, 0x18005622, 0x0b003605, 0x180b3605,   // ks.hi.sa_642 mg.ga.un_870  gn.es.un_330 gn.es.ga_333 
  0x2d4a0d0c, 0x0000fe37, 0x4807150c, 0x185d0ea4,   // cs.yo.sk_543 tlh.un.un_B00  un.bg.tt_543 is.ss.ga_433 
  0x22000a1a, 0x0e5154a9, 0x2e2223eb, 0x0a002214,   // pt.oc.un_760 ik.kl.is_544  ca.oc.fo_662 oc.pt.un_660 
  // [119e0]
  0x06004812, 0x38480502, 0x6754510c, 0x0a4860ad,   // tt.de.un_640 fr.tt.tk_222  kl.ik.ak_543 vo.tt.pt_643 
  0x1b002202, 0x46006012, 0x22000612, 0x0200481a,   // oc.tr.un_220 vo.qu.un_640  de.oc.un_640 tt.da.un_760 
  0x514afc55, 0x4b004909, 0x5f00640e, 0x25002d02,   // zzp.yo.kl_442 to.mi.un_440  lg.tn.un_550 sk.eu.un_220 
  0x64602609, 0x46222507, 0x2e001804, 0x04001112,   // ia.vo.lg_444 eu.oc.qu_432  ga.fo.un_320 ro.ru.un_640 
  // [119f0]
  0x0c021008, 0x34003d23, 0x2e0e18a7, 0x18004d13,   // lt.da.sv_443 ku.ps.un_880  ga.is.fo_532 aa.ga.un_650 
  0x236e2507, 0x0b004905, 0x0b0742ee, 0x18000b04,   // eu.hmn.ca_432 to.es.un_330  co.it.es_422 es.ga.un_320 
  0x48100aa4, 0x42000d0b, 0x42220755, 0x1b006407,   // mk.be.tt_433 cs.co.un_520  it.oc.co_442 lg.tr.un_420 
  0x3600650e, 0x0a350455, 0x48006407, 0x2d003802,   // gv.gn.un_550 ru.tg.mk_442  lg.tt.un_420 tk.sk.un_220 
  // [11a00]
  0x38001a02, 0x5a5c4ba0, 0x47002804, 0x0f5c4bad,   // tl.tk.un_220 mi.sa.sm_322  sw.sn.un_320 mi.sa.lv_643 
  0xfe360ba9, 0x2d5b45ec, 0x21005d08, 0x022f520c,   // es.gn.tlh_544 ln.sg.sk_644  ss.jw.un_430 ha.su.da_543 
  0x0700280c, 0x40680107, 0x023b2808, 0x1d581ba4,   // sw.it.un_530 en.ig.lb_432  sw.so.da_443 tr.om.la_433 
  0x2a5257a4, 0x2d470d0c, 0x1d1142a0, 0x04081107,   // na.ha.mt_433 cs.sn.sk_543  co.ro.la_322 ro.uk.ru_432 
  // [11a10]
  0x582802ad, 0x5300640c, 0x301ffea4, 0x1a003604,   // da.sw.om_643 lg.ht.un_530  tlh.cy.uz_433 gn.tl.un_320 
  0x5c220909, 0xfe531fa9, 0x0f021ca0, 0x19591d12,   // pl.oc.sa_444 cy.ht.tlh_544  id.da.lv_322 la.rn.gl_654 
  0x151025a4, 0x630b0a14, 0x1b682f0c, 0x10004d11,   // mn.be.un_433 pt.es.sco_666  su.ig.tr_543 aa.lt.un_630 
  0x400338ee, 0x4a005019, 0x29003804, 0x3510380c,   // tk.nl.lb_422 fj.yo.un_750  tk.sl.un_320 tk.lt.zu_543 
  // [11a20]
  0x065309a0, 0x30004721, 0x303823a9, 0x495c4b05,   // pl.ht.de_322 sn.uz.un_860  ky.tk.uz_544 mi.sa.to_333 
  0x06054012, 0x4000370d, 0x59555c0e, 0x47195308,   // lb.fr.de_654 st.lb.un_540  sa.rw.rn_555 ht.gl.sn_443 
  0x5c61420c, 0x5e0252af, 0x02211e11, 0x4b005c19,   // co.za.sa_543 ha.da.ts_655  ms.jw.da_653 sa.mi.un_750 
  0x11474213, 0x561c4fa4, 0x063947a9, 0x5e1742a0,   // co.sn.ro_665 bi.id.mg_433  sn.br.de_544 co.sr.ts_322 
  // [11a30]
  0x1036010c, 0x205c28a4, 0x5700210e, 0x4e004f19,   // en.gn.lt_543 sw.sa.sq_433  jw.na.un_550 bi.ay.un_750 
  0x1e4dfe11, 0x6b2d0dad, 0x40006b02, 0xfe2f4da9,   // tlh.aa.ms_653 cs.sk.ceb_643  ceb.lb.un_220 aa.su.tlh_544 
  0x2f001a05, 0x6200fe2a, 0x0804070b, 0x2f211ca4,   // tl.su.un_330 tlh.kha.un_970  bg.ru.uk_542 id.jw.su_433 
  0xfe4d62a9, 0x300a04a7, 0x4b0f490c, 0x4d2f62af,   // kha.aa.tlh_544 ru.mk.uz_532  to.lv.mi_543 kha.su.aa_655 
  // [11a40]
  0x62004d0c, 0x4d611e05, 0x2d0960ad, 0x09004a04,   // aa.kha.un_530 ms.za.aa_333  vo.pl.sk_643 yo.pl.un_320 
  0x3c1844a4, 0x12001f08, 0x37100408, 0x2300381b,   // kk.ar.ug_433 cy.hu.un_430  ru.be.ba_443 tk.ky.un_770 
  0xfe4d2fa4, 0x10083ca4, 0x21674d07, 0x4d022f08,   // su.aa.tlh_433 ug.uk.be_433  aa.ak.jw_432 su.da.aa_443 
  0x2d0d0a0e, 0x4d00622b, 0x62004d22, 0x53052fa0,   // pt.cs.sk_555 kha.aa.un_980  aa.kha.un_870 su.fr.ht_322 
  // [11a50]
  0x3700fe07, 0x301c4d07, 0x3648150c, 0x346a28a9,   // tlh.st.un_420 aa.id.uz_432  un.tt.ab_543 sw.haw.xh_544 
  0x6a152812, 0x5e29280c, 0x2d0d2ea0, 0x6730340c,   // sw.haw.un_640 sw.sl.ts_543  fo.cs.sk_322 xh.uz.ak_543 
  0x58fe34a4, 0x18003b08, 0x0b18190c, 0x0100240e,   // xh.tlh.om_433 ks.ar.un_430  gl.ga.es_543 yi.iw.un_550 
  0x356431a9, 0x31305ead, 0x362e1202, 0x1b38300e,   // az.lg.zu_544 ts.uz.az_643  hu.fo.gn_222 uz.tk.tr_555 
  // [11a60]
  0x4a365d02, 0x36120e08, 0x314e3055, 0x2d2309a4,   // ss.gn.yo_222 is.hu.gn_443  uz.ay.az_442 pl.ca.sk_433 
  0x0e2e4a09, 0x23443755, 0x122e0d07, 0x1c3b09ec,   // yo.fo.is_444 ba.kk.ky_442  cs.fo.hu_432 hi.ks.mr_644 
  0x15171008, 0x300a1704, 0x041711a6, 0x48231007,   // be.sr.un_443 sr.mk.uz_332  ro.sr.ru_521 be.ky.tt_432 
  0x0d2d12ec, 0x362d0d08, 0x0a361504, 0x36000c09,   // hu.sk.cs_644 cs.sk.gn_443  un.ab.mk_332 sv.gn.un_440 
  // [11a70]
  0x4b5c0f5a, 0x5c4b0f0d, 0x4b0f5cec, 0x060c13a0,   // lv.sa.mi_553 lv.mi.sa_554  sa.lv.mi_644 et.sv.de_322 
  0x352a3704, 0x37040855, 0x54004e19, 0x353c1505,   // st.mt.zu_332 uk.ru.ba_442  ay.ik.un_750 un.ug.tg_333 
  0x5100581a, 0x1900340e, 0x44381108, 0x0d00181f,   // om.kl.un_760 xh.gl.un_550  ro.tk.kk_443 ga.cs.un_840 
  0x5435340e, 0x353446a4, 0x230448ee, 0x122d0da9,   // xh.zu.ik_555 qu.xh.zu_433  tt.ru.ky_422 cs.sk.hu_544 
  // [11a80]
  0x0d0a1908, 0x34005e19, 0x190a0b09, 0x222346ec,   // gl.pt.cs_443 ts.xh.un_750  es.pt.gl_444 qu.ca.oc_644 
  0x64001309, 0x2d00180b, 0x5c3673ec, 0x3534130e,   // et.lg.un_440 ga.sk.un_520  ny.gn.sa_644 et.xh.zu_555 
  0x071025ad, 0x24004007, 0x2e002d05, 0x31004809,   // mn.be.bg_643 lb.eo.un_420  sk.fo.un_330 tt.az.un_440 
  0x736a38a4, 0x30004a21, 0x73034c05, 0x081707a0,   // tk.haw.ny_433 yo.uz.un_860  wo.nl.ny_333 bg.sr.uk_322 
  // [11a90]
  0x0e00210c, 0x1159550d, 0x46252407, 0x170a3505,   // jw.is.un_530 rw.rn.ro_554  eo.eu.qu_432 tg.mk.sr_333 
  0x2e0e0a07, 0x68475e08, 0x02001d02, 0x5d0b0aa4,   // pt.is.fo_432 ts.sn.ig_443  la.da.un_220 pt.es.ss_433 
  0x4e7347ad, 0x64002802, 0x6400680c, 0x65731dee,   // sn.ny.ay_643 sw.lg.un_220  ig.lg.un_530 la.ny.gv_422 
  0x7335faa4, 0x24421d0c, 0x35685fa4, 0x2868735a,   // nr.zu.ny_433 la.co.eo_543  tn.ig.zu_433 ny.ig.sw_553 
  // [11aa0]
  0x01646ba4, 0x5d287302, 0x40001107, 0x253035a0,   // ceb.lg.en_433 ny.sw.ss_222  ro.lb.un_420 tg.uz.mn_322 
  0x07081712, 0x0f09470e, 0x35230808, 0x3e000918,   // sr.uk.bg_654 sn.pl.lv_555  uk.ky.tg_443 pl.rm.un_740 
  0x3e420707, 0xfe001a08, 0x2504100c, 0x400625a9,   // it.co.rm_432 tl.tlh.un_430  be.ru.mn_543 eu.de.lb_544 
  0xfe005305, 0x400921a4, 0x094012ec, 0x23441507,   // ht.tlh.un_330 jw.pl.lb_433  hu.lb.pl_644 un.kk.ky_432 
  // [11ab0]
  0x17151007, 0x421321ad, 0x046a4907, 0x496a0407,   // be.sr.un_420 jw.et.co_643  to.haw.fi_432 fi.haw.to_432 
  0x501e1c08, 0x114a1704, 0x4217090c, 0x2e42040c,   // id.ms.fj_443 sr.yo.ro_332  pl.sr.co_543 fi.co.fo_543 
  0x4311290b, 0x1700291b, 0x2b1146a0, 0x30090d11,   // sl.ro.ie_542 sl.sr.un_770  qu.ro.vi_322 cs.pl.uz_653 
  0x49111da0, 0x111e1c13, 0x2c0511ee, 0x48043804,   // la.ro.to_322 id.ms.ro_665  ro.fr.fy_422 tk.ru.tt_332 
  // [11ac0]
  0x251135a0, 0x426a4a0c, 0x49401108, 0x2a004204,   // zu.ro.eu_322 yo.haw.co_543  ro.lb.to_443 co.mt.un_320 
  0x73355da0, 0x190b23ee, 0x491721a7, 0x1311040c,   // ss.zu.ny_322 ca.es.gl_422  jw.sr.to_532 fi.ro.et_543 
  0x04083704, 0x2f001113, 0x2a001c02, 0x65001d07,   // ba.uk.ru_332 ro.su.un_650  id.mt.un_220 la.gv.un_420 
  0x3c003d09, 0x12343da7, 0x59550209, 0x104afcec,   // ku.ug.un_440 ku.ps.ur_532  da.rw.rn_444 zzp.yo.lt_644 
  // [11ad0]
  0x4c2057a7, 0x15656304, 0x5c6311a4, 0xfc1d57a4,   // na.sq.wo_532 sco.gv.un_332  ro.sco.sa_433 na.la.zzp_433 
  0x1d0e110d, 0x24206355, 0x4200221b, 0x37002f08,   // ro.is.la_554 sco.sq.eo_442  oc.co.un_770 su.st.un_430 
  0x04003012, 0x64005e07, 0x1c135c05, 0x475955a4,   // uz.ru.un_640 ts.lg.un_420  sa.bh.mr_333 rw.rn.sn_433 
  0x302515ad, 0x0748150c, 0x353007ec, 0x36381b08,   // un.mn.uz_643 un.tt.bg_543  bg.uz.tg_644 tr.tk.gn_443 
  // [11ae0]
  0x5a002004, 0x173023ec, 0x3000180e, 0x29624dad,   // sq.sm.un_320 ky.uz.sr_644  ar.uz.un_550 aa.kha.sl_643 
  0x624dfe09, 0x08041108, 0x12002b22, 0x2e002b18,   // tlh.aa.kha_444 ro.ru.uk_443  vi.hu.un_870 vi.fo.un_740 
  0x122b4a0c, 0x4d1e1c11, 0x61294dec, 0x2e0d2b55,   // yo.vi.hu_543 id.ms.aa_653  aa.sl.za_644 vi.cs.fo_442 
  0x303ffea6, 0x0e510204, 0x58005411, 0x0e2b12ee,   // tlh.af.uz_521 da.kl.is_332  ik.om.un_630 hu.vi.is_422 
  // [11af0]
  0x121b1fee, 0x2f00212c, 0x0e222cec, 0x1b294dec,   // cy.tr.hu_422 jw.su.un_990  fy.oc.is_644 aa.sl.tr_644 
  0x2962fe08, 0x0a000407, 0xfe004d1b, 0x6a00391b,   // tlh.kha.sl_443 ru.mk.un_420  aa.tlh.un_770 br.haw.un_770 
  0x39045313, 0x0f003007, 0x0d1c130c, 0x3f00110d,   // ht.fi.br_665 uz.lv.un_420  bh.mr.ne_543 ro.af.un_540 
  0x44231555, 0x3530100d, 0x17370405, 0x07043607,   // un.ky.kk_442 be.uz.tg_554  ru.ba.sr_333 ab.ru.bg_432 
  // [11b00]
  0x026539ad, 0x33025105, 0x39407304, 0x01733907,   // br.gv.da_643 kl.da.nn_333  ny.lb.br_332 br.ny.en_432 
  0x341221ec, 0x76020da0, 0x15251112, 0x05003922,   // fa.ur.ps_644 cs.da.crs_322  ro.mn.un_654 br.fr.un_870 
  0x53000121, 0x396976a9, 0x2e0f0eec, 0x30090da0,   // en.ht.un_860 crs.mfe.br_544  is.lv.fo_644 cs.pl.uz_322 
  0x34183bac, 0x08150712, 0x15001009, 0x530a110c,   // ks.ar.ps_632 bg.uk.un_640  be.un.un_440 ro.pt.ht_543 
  // [11b10]
  0x19230a07, 0x0a601bad, 0xfc364a0c, 0x1e1c1bee,   // pt.ca.gl_432 tr.vo.pt_643  yo.gn.zzp_543 tr.id.ms_422 
  0x5d396004, 0x5d001d0d, 0x55505d0c, 0x06240ea0,   // vo.br.ss_332 la.ss.un_540  ss.fj.rw_543 is.eo.de_322 
  0x2c24fc02, 0x11091b04, 0x2b000208, 0x241d0e04,   // zzp.eo.fy_222 tr.pl.ro_332  da.vi.un_430 is.la.eo_332 
  0x24000602, 0x1b3529a7, 0x233004a4, 0x190b45a0,   // de.eo.un_220 sl.zu.tr_532  ru.uz.ky_433 ln.es.gl_322 
  // [11b20]
  0x5c0d1c5a, 0x400e060e, 0x011b12a6, 0x6500fe02,   // mr.ne.sa_553 de.is.lb_555  hu.tr.en_521 tlh.gv.un_220 
  0x233517ee, 0x1d0115a4, 0x2000040d, 0x64126755,   // sr.tg.ky_422 un.en.la_433  fi.sq.un_540 ak.hu.lg_442 
  0x1a003f07, 0x07083509, 0x64002009, 0x23374860,   // af.tl.un_420 tg.uk.bg_444  sq.lg.un_440 tt.ba.ky_664 
  0x232218a4, 0x23302207, 0x23302212, 0x0823100c,   // ga.oc.ca_433 oc.uz.ca_432  oc.uz.ca_654 be.ky.uk_543 
  // [11b30]
  0x3e00300c, 0x31005812, 0x3700200d, 0x31004d05,   // uz.rm.un_530 om.az.un_640  sq.st.un_540 aa.az.un_330 
  0x1b00040c, 0x30232212, 0x12043404, 0x30003e0d,   // fi.tr.un_530 oc.ca.uz_654  xh.fi.hu_332 rm.uz.un_540 
  0x2330225a, 0x3b3534a9, 0x22001520, 0x28183d04,   // oc.uz.ca_553 xh.zu.so_544  un.oc.un_850 ku.ar.sd_332 
  0x5e5d6402, 0x1e003504, 0x063022ee, 0x4500fc0d,   // lg.ss.ts_222 zu.ms.un_320  oc.uz.de_422 zzp.ln.un_540 
  // [11b40]
  0x3e222313, 0x23223013, 0x5100fe11, 0x58353408,   // ca.oc.rm_665 uz.oc.ca_665  tlh.kl.un_630 xh.zu.om_443 
  0x34121804, 0x354438af, 0x25381711, 0x0a003c0d,   // ar.ur.ps_332 tk.kk.tg_655  sr.tk.mn_653 ug.mk.un_540 
  0x3c442304, 0x4410040b, 0x170a350c, 0x022e5108,   // ky.kk.ug_332 ru.be.kk_542  tg.mk.sr_543 kl.fo.da_443 
  0x35070455, 0x16003102, 0x0f001018, 0x48371107,   // ru.bg.tg_442 az.hr.un_220  lt.lv.un_740 ro.ba.tt_432 
  // [11b50]
  0x33005d0b, 0x0c0e5d0c, 0x30483702, 0x3c342304,   // ss.nn.un_520 ss.is.sv_543  ba.tt.uz_222 ky.ps.ug_332 
  0x25000709, 0x0e0c3308, 0x15101505, 0x1e1c6502,   // bg.mn.un_440 nn.sv.is_443  un.be.un_333 gv.id.ms_222 
  0x2112280c, 0x2e180e08, 0x18123609, 0x45003613,   // sd.ur.fa_543 is.ga.fo_443  gn.hu.ga_444 gn.ln.un_650 
  0x1d5154ad, 0x30254807, 0x03080cad, 0x562b0a04,   // ik.kl.la_643 tt.mn.uz_432  sv.no.nl_643 pt.vi.mg_332 
  // [11b60]
  0x200911a9, 0x0e2f62a4, 0x4c000c04, 0x29090f05,   // ro.pl.sq_544 kha.su.is_433  sv.wo.un_320 lv.pl.sl_333 
  0x0c3e01a0, 0x0c400107, 0x0c7957ee, 0x06002b02,   // en.rm.sv_322 en.lb.sv_432  na.war.sv_422 vi.de.un_220 
  0x25171507, 0x154823a4, 0x3015355a, 0x441738af,   // un.sr.mn_432 ky.tt.un_433  tg.uz.un_530 tk.sr.kk_655 
  0x06630c07, 0x3575340c, 0x352336a7, 0x1d6b01a0,   // sv.sco.de_432 xh.nso.zu_543  ab.ky.tg_532 en.ceb.la_322 
  // [11b70]
  0x17100855, 0x4a004519, 0x2d100d07, 0x2e3265ee,   // uk.be.sr_442 ln.yo.un_750  cs.lt.sk_432 gv.bs.fo_422 
  0x27004307, 0x05002c07, 0x1d007307, 0x284651a0,   // ie.gd.un_420 fy.fr.un_420  ny.la.un_420 kl.qu.sw_322 
  0x58006413, 0x20215305, 0x19000e02, 0x071d1104,   // lg.om.un_650 ht.jw.sq_333  is.gl.un_220 ro.la.it_332 
  0x233715a0, 0x4a00240c, 0x2022530d, 0x2023225e,   // un.ba.ky_322 eo.yo.un_530  ht.oc.sq_554 oc.ca.sq_652 
  // [11b80]
  0x15003807, 0x5c002412, 0x19005e14, 0x02000d07,   // tk.un.un_420 eo.sa.un_640  ts.gl.un_660 cs.da.un_420 
  0x28005a12, 0x37001d07, 0xfe3829ec, 0x19240b5a,   // sm.sw.un_640 la.st.un_420  sl.tk.tlh_644 es.eo.gl_553 
  0x200f2a02, 0x340bfeec, 0x28002405, 0xfe006219,   // mt.lv.sq_222 tlh.es.xh_644  eo.sw.un_330 kha.tlh.un_750 
  0x0a002207, 0xfe2a200c, 0x630b4ea4, 0x1823225e,   // oc.pt.un_420 sq.mt.tlh_543  ay.es.sco_433 oc.ca.ga_652 
  // [11b90]
  0xfe001013, 0x0d242aa7, 0x24002913, 0x20242a04,   // lt.tlh.un_650 mt.eo.cs_532  sl.eo.un_650 mt.eo.sq_332 
  0x242032a0, 0x0a004c05, 0x2300511a, 0x19002f0c,   // bs.sq.eo_322 wo.pt.un_330  kl.ca.un_760 su.gl.un_530 
  0x0e182e0e, 0x100c51a7, 0x2e001813, 0x10004418,   // fo.ga.is_555 kl.sv.lt_532  ga.fo.un_650 kk.be.un_740 
  0x31001902, 0x2300280c, 0x283b1ea4, 0x2e190e0b,   // gl.az.un_220 sd.ky.un_530  ms.so.sw_433 is.gl.fo_542 
  // [11ba0]
  0x182e0ea9, 0x1710070c, 0x080736ec, 0x2e003307,   // is.fo.ga_544 bg.be.sr_543  ab.bg.uk_644 nn.fo.un_420 
  0xfe00280e, 0x0b001812, 0x5c0f4ba7, 0x31000607,   // sw.tlh.un_550 ga.es.un_640  mi.lv.sa_532 de.az.un_420 
  0x150735af, 0x1b003e05, 0x354838a7, 0x44251055,   // tg.bg.un_655 rm.tr.un_330  tk.tt.tg_532 be.mn.kk_442 
  0x5e004c08, 0x0a4415ec, 0x3c343b07, 0x49005c0d,   // wo.ts.un_430 un.kk.mk_644  ks.ps.ug_432 sa.to.un_540 
  // [11bb0]
  0x4b005c1a, 0x2200271f, 0x23070aa7, 0x2d001010,   // sa.mi.un_760 gd.oc.un_840  mk.bg.ky_532 lt.sk.un_620 
  0x23005716, 0x321629ee, 0x23190bec, 0x2815351f,   // na.ca.un_720 sl.hr.bs_422  es.gl.ca_644 tg.sd.un_840 
  0x0f003207, 0x1b3e31af, 0x0f004b09, 0x200d2d65,   // bs.lv.un_420 az.rm.tr_655  mi.lv.un_440 sk.cs.sq_763 
  0x232d0deb, 0x29083e11, 0x3e0938a4, 0x532d0d11,   // cs.sk.ca_662 rm.no.sl_653  tk.pl.rm_433 cs.sk.ht_653 
  // [11bc0]
  0x36021307, 0x21003e05, 0x353206a0, 0x1f005e07,   // et.da.gn_432 rm.jw.un_330  de.bs.zu_322 ts.cy.un_420 
  0x3f0602a7, 0x0410110b, 0x2d0dfc05, 0x06370307,   // da.de.af_532 ro.be.ru_542  zzp.cs.sk_333 nl.st.de_432 
  0x06381755, 0x400212ad, 0x4813040c, 0x4602fc04,   // sr.tk.de_442 hu.da.lb_643  fi.et.tt_543 zzp.da.qu_332 
  0x120d2dec, 0x333e2e04, 0xfc2d0d04, 0x0d002d09,   // sk.cs.hu_644 fo.rm.nn_332  cs.sk.zzp_332 sk.cs.un_440 
  // [11bd0]
  0x33fc29a6, 0x03005502, 0x46033f04, 0x2e0c0ea0,   // sl.zzp.nn_521 rw.nl.un_220  af.nl.qu_332 is.sv.fo_322 
  0x10331304, 0x220a200d, 0x17111505, 0x0a111704,   // et.nn.lt_332 sq.pt.oc_554  un.ro.sr_333 sr.ro.mk_332 
  0x40063e0c, 0x222723ad, 0x23064804, 0x0a120ea0,   // rm.de.lb_543 ca.gd.oc_643  tt.de.ca_332 is.hu.pt_322 
  0x1d180aa0, 0x0c00480b, 0x0f5c4ba9, 0x79400605,   // pt.ga.la_322 tt.sv.un_520  mi.sa.lv_544 de.lb.war_333 
  // [11be0]
  0x232d0daf, 0x4b005c05, 0x04636aad, 0x2f506aa9,   // cs.sk.ca_655 sa.mi.un_330  haw.sco.fi_643 haw.fj.su_544 
  0x3b2812a9, 0x36250b04, 0x3800600d, 0x2a353404,   // ur.sd.ks_544 es.eu.gn_332  vo.tk.un_540 xh.zu.mt_332 
  0x060a0308, 0x272b2204, 0x4263480c, 0x5200501b,   // nl.pt.de_443 oc.vi.gd_332  tt.sco.co_543 fj.ha.un_770 
  0x2c1f2e04, 0x0e001810, 0x617348ec, 0x23443809,   // fo.cy.fy_332 ga.is.un_620  tt.ny.za_644 tk.kk.ky_444 
  // [11bf0]
  0x75100f09, 0x490d2dad, 0x10082355, 0x6428730c,   // lv.lt.nso_444 sk.cs.to_643  ky.uk.be_442 ny.sw.lg_543 
  0x22235a0c, 0x35003c08, 0x2e0e0aa0, 0x5c4b0f5a,   // sm.ca.oc_543 ug.tg.un_430  pt.is.fo_322 lv.mi.sa_553 
  0x183c30ee, 0x28183d05, 0x6e683bee, 0x1100230e,   // uz.ug.ar_422 ku.ar.sd_333  so.ig.hmn_422 ky.ro.un_550 
  0x4d6e3bad, 0x4c00130c, 0x583b6e08, 0x5f1a13a4,   // so.hmn.aa_643 et.wo.un_530  hmn.so.om_443 et.tl.tn_433 
  
  // [11c00]
  0x186e64a4, 0x3b154c11, 0x6e654cad, 0x3b636507,   // lg.hmn.ga_433 wo.so.un_630  wo.gv.hmn_643 gv.sco.so_432 
  0x4d583bad, 0x121834a9, 0x53651f04, 0x4b004914,   // so.om.aa_643 ps.ar.ur_544  cy.gv.ht_332 to.mi.un_660 
  0x3f002802, 0x2d001f19, 0x4d3b5813, 0x696e4ca4,   // sw.af.un_220 cy.sk.un_750  om.so.aa_665 wo.hmn.mfe_433 
  0x2d6e29af, 0x1d0d1fee, 0x09003612, 0x17251513,   // sl.hmn.sk_655 cy.cs.la_422  gn.pl.un_640 un.mn.sr_665 
  // [11c10]
  0x2d092207, 0x37114809, 0x0c330208, 0x1b2248b2,   // oc.pl.sk_432 tt.ro.ba_444  da.nn.sv_443 tt.oc.tr_732 
  0x27002205, 0x1b22230e, 0x0c065713, 0xfc423f04,   // oc.gd.un_330 ca.oc.tr_555  na.de.sv_665 af.co.zzp_332 
  0x22063e07, 0x2a697608, 0x12001b07, 0x231844a9,   // rm.de.oc_432 crs.mfe.mt_443  tr.hu.un_420 kk.ar.ky_544 
  0x0f001209, 0x12330813, 0x1a6b2e07, 0x47002905,   // hu.lv.un_440 no.nn.hu_665  fo.ceb.tl_432 sl.sn.un_330 
  // [11c20]
  0x4800360b, 0x37364805, 0x22003609, 0x22001917,   // ab.tt.un_520 tt.ab.ba_333  gn.oc.un_440 gl.oc.un_730 
  0x24002307, 0x0a081009, 0x511e1c0c, 0x2300420d,   // ca.eo.un_420 be.uk.mk_444  id.ms.kl_543 co.ca.un_540 
  0x070848a0, 0x101515a0, 0x6a1a79a4, 0x17304805,   // tt.uk.bg_322 un.be.un_320  war.tl.haw_433 tt.uz.sr_333 
  0x0a1117a9, 0x2700220b, 0x5a00512c, 0x13005102,   // sr.ro.mk_544 oc.gd.un_520  kl.sm.un_990 kl.et.un_220 
  // [11c30]
  0x3b113404, 0x2d290908, 0x33000c13, 0x232722a9,   // xh.ro.so_332 pl.sl.sk_443  sv.nn.un_650 oc.gd.ca_544 
  0x12182312, 0x5d6452ee, 0x4e1123ac, 0x045a515a,   // ca.ga.hu_654 ha.lg.ss_422  ca.ro.ay_632 kl.sm.fi_553 
  0x3715040d, 0x041a245a, 0x511a6a0c, 0x1c005c2a,   // ru.ba.un_540 eo.tl.fi_553  haw.tl.kl_543 sa.mr.un_970 
  0x30372507, 0x35001005, 0x2300221b, 0x525831af,   // mn.ba.uz_432 be.tg.un_330  oc.ca.un_770 az.om.ha_655 
  // [11c40]
  0x37004411, 0x585231ec, 0x1e005207, 0x4a52310c,   // kk.ba.un_630 az.ha.om_644  ha.ms.un_420 az.ha.yo_543 
  0x33081f09, 0x314d5808, 0x5200310c, 0x3b1d19a7,   // cy.no.nn_444 om.aa.az_443  az.ha.un_530 gl.la.so_532 
  0x120d060d, 0x4800372a, 0x4c005e0c, 0x52001e05,   // de.cs.hu_554 ba.tt.un_970  ts.wo.un_530 ms.ha.un_330 
  0x58314d12, 0x3b191d0c, 0x04073007, 0x524d315a,   // aa.az.om_654 la.gl.so_543  uz.bg.ru_432 az.aa.ha_553 
  // [11c50]
  0x52314d13, 0x29001712, 0x0d482d0c, 0x212818ad,   // aa.az.ha_665 sr.sl.un_640  sk.tt.cs_543 ar.sd.fa_643 
  0x0b2d0d0d, 0x07422ba0, 0x2f004d0b, 0x191d2aa0,   // cs.sk.es_554 vi.co.it_322  aa.su.un_520 mt.la.gl_322 
  0x35152308, 0x19303114, 0x444823a6, 0x30123e08,   // ky.tg.un_430 az.uz.gl_666  ky.tt.kk_521 rm.hu.uz_443 
  0x7600692c, 0x0d29130d, 0x3548370b, 0x1100432c,   // mfe.crs.un_990 et.sl.cs_554  ba.tt.tg_542 ie.ro.un_990 
  // [11c60]
  0x1d262408, 0x4600390b, 0x303148ee, 0x12046b0c,   // eo.ia.la_443 br.qu.un_520  tt.az.uz_422 ceb.fi.hu_543 
  0x1b616912, 0x190a790e, 0x185106a4, 0x0a00190c,   // mfe.za.tr_654 war.pt.gl_555  de.kl.ga_433 gl.pt.un_530 
  0x1b393804, 0x3525445a, 0x0c002e07, 0x1d003e04,   // tk.br.tr_332 kk.mn.tg_553  fo.sv.un_420 rm.la.un_320 
  0x0f101202, 0x1a0f4f11, 0x116961a4, 0x69003805,   // hu.lt.lv_222 bi.lv.tl_653  za.mfe.ro_433 tk.mfe.un_330 
  // [11c70]
  0x0976690c, 0x23183b0c, 0x5300030d, 0x2300152a,   // mfe.crs.pl_543 ks.ar.ky_543  nl.ht.un_540 un.ky.un_970 
  0x080218ee, 0x03001d12, 0x12420412, 0x63024f0c,   // ga.da.no_422 la.nl.un_640  fi.co.hu_654 bi.da.sco_543 
  0x630601a0, 0xfe6b0404, 0x44213008, 0x02060c12,   // en.de.sco_322 fi.ceb.tlh_332  uz.fa.kk_443 sv.de.da_654 
  0x30383107, 0x636557a0, 0x57000c14, 0x32025704,   // az.tk.uz_432 na.gv.sco_322  sv.na.un_660 na.da.bs_332 
  // [11c80]
  0xfc001b07, 0x51024507, 0x07170808, 0x1d3047a7,   // tr.zzp.un_420 ln.da.kl_432  uk.sr.bg_443 sn.uz.la_532 
  0x1011480c, 0x01fc3808, 0x0c0601ee, 0x013f06a0,   // tt.ro.be_543 tk.zzp.en_443  en.de.sv_422 de.af.en_322 
  0x24002a04, 0x685064af, 0x29353455, 0x5e20450c,   // mt.eo.un_320 lg.fj.ig_655  xh.zu.sl_442 ln.sq.ts_543 
  0x0c002902, 0x40353408, 0x6800642a, 0x063f0907,   // sl.sv.un_220 xh.zu.lb_443  lg.ig.un_970 pl.af.de_432 
  // [11c90]
  0x40010605, 0x18fc010b, 0x15081505, 0x35006808,   // de.en.lb_333 en.zzp.ga_542  un.uk.un_333 ig.zu.un_430 
  0x30171107, 0x48251512, 0x353447af, 0x230542ee,   // ro.sr.uz_432 un.mn.tt_654  sn.xh.zu_655 co.fr.ca_422 
  0x026458a4, 0x38094002, 0x28006404, 0x1e4c58a0,   // om.lg.da_433 lb.pl.tk_222  lg.sw.un_320 om.wo.ms_322 
  0x0600571a, 0x60030107, 0x1511fc0c, 0x063f5ead,   // na.de.un_760 en.nl.vo_432  zzp.ro.un_543 ts.af.de_643 
  // [11ca0]
  0x1a211dee, 0x1a036ba4, 0x5d003509, 0x58003e02,   // la.jw.tl_422 ceb.nl.tl_433  zu.ss.un_440 rm.om.un_220 
  0x21131105, 0x15240302, 0x5d355e09, 0x15064fa0,   // ro.et.jw_333 nl.eo.un_222  ts.zu.ss_444 bi.de.un_322 
  0x080333a7, 0x1e002102, 0x110d55a0, 0x355d34ec,   // nn.nl.no_532 jw.ms.un_220  rw.cs.ro_322 xh.ss.zu_644 
  0x15251512, 0x39080204, 0x0d502da0, 0x52005d05,   // un.mn.un_654 da.no.br_332  sk.fj.cs_322 ss.ha.un_330 
  // [11cb0]
  0x15fe4ca0, 0x260c5805, 0x05151908, 0x0c2e33ad,   // wo.tlh.un_322 om.sv.ia_333  gl.fr.un_430 nn.fo.sv_643 
  0x311b48ac, 0x3f002c13, 0x0d001f04, 0x34281211,   // tt.tr.az_632 fy.af.un_650  cy.cs.un_320 ur.sd.ps_653 
  0x32002b08, 0x2c0e2e02, 0x0c1f390c, 0x04150aad,   // vi.bs.un_430 fo.is.fy_222  br.cy.sv_543 mk.ru.un_630 
  0x0a1004a0, 0x2847340b, 0x34643508, 0x153f0312,   // ru.be.mk_322 xh.sn.sw_542  zu.lg.xh_443 nl.af.un_654 
  // [11cc0]
  0x47787308, 0x21003411, 0x253023a0, 0x213d3411,   // ny.ve.sn_443 ps.fa.un_630  ky.uz.mn_322 ps.ku.fa_653 
  0x15040aa4, 0x47002e07, 0x31003e12, 0x213d12a6,   // mk.ru.un_433 fo.sn.un_420  rm.az.un_640 ur.ku.fa_521 
  0x15082307, 0x65004012, 0x4a002e02, 0x23444805,   // ky.uk.un_432 lb.gv.un_640  fo.yo.un_220 tt.kk.ky_333 
  0x424a3ea0, 0x303c11ec, 0x56423e02, 0x38481b12,   // rm.yo.co_322 ro.ug.uz_644  rm.co.mg_222 tr.tt.tk_654 
  // [11cd0]
  0x3508250c, 0x3e4a07af, 0x060c13ee, 0x4a423ead,   // mn.uk.tg_543 it.yo.rm_655  et.sv.de_422 rm.co.yo_643 
  0x172b11a0, 0x02001004, 0x073515ee, 0x02282baf,   // ro.vi.sr_322 lt.da.un_320  un.tg.bg_422 vi.sw.da_655 
  0x3f00280b, 0x24000908, 0x3e424a08, 0x35082309,   // sw.af.un_520 pl.eo.un_430  yo.co.rm_443 ky.uk.tg_444 
  0x424a070b, 0x42003e08, 0x5a00fc09, 0x49000602,   // it.yo.co_542 rm.co.un_430  zzp.sm.un_440 de.to.un_220 
  // [11ce0]
  0x251048ec, 0x360335a0, 0x3f35fcee, 0x0c003f07,   // tt.be.mn_644 zu.nl.gn_322  zzp.zu.af_422 af.sv.un_420 
  0x09050fa0, 0x27005f02, 0x093e5304, 0x0b261d0c,   // lv.fr.pl_322 tn.gd.un_220  ht.rm.pl_332 la.ia.es_543 
  0x2b5a6907, 0x79000313, 0x23001908, 0x15003904,   // mfe.sm.vi_432 nl.war.un_650  gl.ca.un_430 br.un.un_320 
  0x4235fc04, 0x0900fc05, 0x114201a0, 0x2c006508,   // zzp.zu.co_332 zzp.pl.un_330  en.co.ro_322 gv.fy.un_430 
  // [11cf0]
  0x1b003207, 0x1569760e, 0x0704360c, 0x080a3c0c,   // bs.tr.un_420 crs.mfe.un_555  ab.ru.bg_543 ug.mk.uk_543 
  0x56003005, 0x167902a9, 0x2b0b27a0, 0x105f2913,   // uz.mg.un_330 da.war.hr_544  gd.es.vi_322 sl.tn.lt_665 
  0x60095f0c, 0x03311d04, 0x36081007, 0x1800560c,   // tn.pl.vo_543 la.az.nl_332  be.uk.ab_432 mg.ga.un_530 
  0x1748470c, 0x561b53ee, 0x15000807, 0x28005f08,   // sn.tt.sr_543 ht.tr.mg_422  uk.un.un_420 tn.sw.un_430 
  // [11d00]
  0x3800020c, 0x2d0d10a4, 0x02384804, 0x28120aa0,   // da.tk.un_530 lt.cs.sk_433  tt.tk.da_332 pt.hu.sw_322 
  0x28641fa7, 0x0b26020e, 0x22002904, 0x595f2faf,   // cy.lg.sw_532 da.ia.es_555  sl.oc.un_320 su.tn.rn_655 
  0x183d2302, 0x5900470d, 0x230b02a0, 0x30001705,   // ky.ku.ar_222 sn.rn.un_540  da.es.ca_322 sr.uz.un_330 
  0x4b0c04ee, 0x120e2d04, 0x172a2411, 0x3748380e,   // fi.sv.mi_422 sk.is.hu_332  eo.mt.sr_653 tk.tt.ba_555 
  // [11d10]
  0x21002407, 0x1b000104, 0x643545a4, 0x20634004,   // eo.jw.un_420 en.tr.un_320  ln.zu.lg_433 lb.sco.sq_332 
  0x12213055, 0x061d1008, 0x7920130b, 0x34356407,   // uz.fa.ur_442 lt.la.de_443  et.sq.war_542 lg.zu.xh_432 
  0x201b40a4, 0x3c002813, 0x35456409, 0x16242d05,   // lb.tr.sq_433 sd.ug.un_650  lg.ln.zu_444 sk.eo.hr_333 
  0x79001204, 0xfc630107, 0x34005119, 0x3700060b,   // hu.war.un_320 en.sco.zzp_432  kl.xh.un_750 de.st.un_520 
  // [11d20]
  0x1d3e2604, 0x463435a7, 0x24002a22, 0x20005109,   // ia.rm.la_332 zu.xh.qu_532  mt.eo.un_870 kl.sq.un_440 
  0x5c1c0913, 0x04330802, 0x47005511, 0x355559ec,   // hi.mr.sa_665 no.nn.fi_222  rw.sn.un_630 rn.rw.zu_644 
  0x1b200107, 0x134201a0, 0x24000d0c, 0x3900080d,   // en.sq.tr_432 en.co.et_322  cs.eo.un_530 no.br.un_540 
  0x042012a7, 0x32292dee, 0x3c2318ec, 0x2f2113a0,   // hu.sq.fi_532 sk.sl.bs_422  ar.ky.ug_644 et.jw.su_322 
  // [11d30]
  0x08041307, 0x08023fee, 0x032f3fa0, 0x213d3008,   // et.fi.no_432 af.da.no_422  af.su.nl_322 uz.ku.fa_443 
  0x130e0caf, 0x056976a9, 0x0500121a, 0x2348100d,   // sv.is.et_655 crs.mfe.fr_544  hu.fr.un_760 be.tt.ky_554 
  0x0a007905, 0x2328120c, 0x1900fc07, 0x2f00fe2a,   // war.pt.un_330 ur.sd.ky_543  zzp.gl.un_420 tlh.su.un_970 
  0x1c621ead, 0x4810070b, 0x4dfe2f0d, 0x15152513,   // ms.kha.id_643 bg.be.tt_542  su.tlh.aa_554 mn.un.un_650 
  // [11d40]
  0x62294da4, 0x2f4945ee, 0x4d2f2113, 0x21532007,   // aa.sl.kha_433 ln.to.su_422  jw.su.aa_665 sq.ht.jw_432 
  0x212f4d04, 0x033f0602, 0x30213455, 0x2f674d0c,   // aa.su.jw_332 de.af.nl_222  ps.fa.uz_442 aa.ak.su_543 
  0x61005619, 0x214d2f05, 0x2f4d1e0b, 0x214434ee,   // mg.za.un_750 su.aa.jw_333  ms.aa.su_542 ps.kk.fa_422 
  0x624d2f08, 0xfe1e4d0c, 0x2f2917a4, 0x372523ad,   // su.aa.kha_443 aa.ms.tlh_543  sr.sl.su_433 ky.mn.ba_643 
  // [11d50]
  0x04000305, 0x2d0d21ec, 0x49007308, 0x060312ee,   // nl.fi.un_330 jw.cs.sk_644  ny.to.un_430 hu.nl.de_422 
  0x2d0d2109, 0x543860a4, 0x212d0d60, 0x08233507,   // jw.cs.sk_444 vo.tk.ik_433  cs.sk.jw_664 tg.ky.uk_432 
  0x65001302, 0x0e305411, 0x65000c0e, 0x0a150412,   // et.gv.un_220 ik.uz.is_653  sv.gv.un_550 ru.mk.un_640 
  0x2e006b09, 0x64494704, 0x42073e11, 0x211234ec,   // ceb.fo.un_440 sn.to.lg_332  rm.it.co_653 ps.ur.fa_644 
  // [11d60]
  0x7300671a, 0x0d2d2110, 0x5e003408, 0x1834230c,   // ak.ny.un_760 jw.sk.cs_642  xh.ts.un_430 ky.ps.ar_543 
  0x07384204, 0x0d2d2111, 0x2d002119, 0x10002c0e,   // co.tk.it_332 jw.sk.cs_653  jw.sk.un_750 fy.lt.un_550 
  0x46001a04, 0x420c3ea4, 0x3e00380c, 0x3e384204,   // tl.qu.un_320 rm.sv.co_433  tk.rm.un_530 co.tk.rm_332 
  0x5c003713, 0x3e2e0e04, 0x211b0b0c, 0x2a4869a4,   // st.sa.un_650 is.fo.rm_332  es.tr.jw_543 mfe.tt.mt_433 
  // [11d70]
  0x0400152b, 0x370e5fa6, 0x390f6155, 0x13040c0c,   // un.ru.un_980 tn.is.st_521  za.lv.br_442 sv.fi.et_543 
  0x39766912, 0x48256107, 0x31001118, 0x312861ee,   // mfe.crs.br_654 za.eu.tt_432  ro.az.un_740 za.sw.az_422 
  0x0c003902, 0x76690aa9, 0x69092d11, 0x616938af,   // br.sv.un_220 pt.mfe.crs_544  sk.pl.mfe_653 tk.mfe.za_655 
  0x08303513, 0x154807ad, 0x063948a0, 0x28062aee,   // tg.uz.uk_665 bg.tt.un_643  tt.br.de_322 mt.de.sw_422 
  // [11d80]
  0x5a004910, 0x0d492d07, 0x2e0d2dac, 0x0d1d2dee,   // to.sm.un_620 sk.to.cs_432  sk.cs.fo_632 sk.la.cs_422 
  0x070a08a4, 0xfc0269ad, 0x212d0d5a, 0x6000671a,   // uk.mk.bg_433 mfe.da.zzp_643  cs.sk.jw_553 ak.vo.un_760 
  0x490d2dec, 0x5367640c, 0x28586508, 0x1b006013,   // sk.cs.to_644 lg.ak.ht_543  gv.om.sw_443 vo.tr.un_650 
  0x36000b04, 0x2b002805, 0x4a5a5f0c, 0x47492814,   // es.gn.un_320 sw.vi.un_330  tn.sm.yo_543 sw.to.sn_666 
  // [11d90]
  0x0430080d, 0x122d3605, 0x6b472555, 0x35176408,   // uk.uz.ru_554 gn.sk.hu_333  eu.sn.ceb_442 lg.sr.zu_443 
  0x73002822, 0x36200b07, 0x3c4438ad, 0x4f042007,   // sw.ny.un_870 es.sq.gn_432  tk.kk.ug_643 sq.fi.bi_432 
  0x3e20fcaf, 0x5e6759a9, 0x1d15010b, 0x25003405,   // zzp.sq.rm_655 rn.ak.ts_544  en.la.un_520 xh.eu.un_330 
  0x3f1e6408, 0x79616213, 0x0a003605, 0x510756a4,   // lg.ms.af_443 kha.za.war_665  gn.pt.un_330 mg.it.kl_433 
  // [11da0]
  0x12fc0455, 0x40fc2011, 0x67004522, 0x08370aa0,   // fi.zzp.hu_442 sq.zzp.lb_653  ln.ak.un_870 mk.ba.uk_322 
  0x02203e0b, 0x19360baf, 0x3e002012, 0x60390112,   // rm.sq.da_542 es.gn.gl_655  sq.rm.un_640 en.br.vo_654 
  0x34205102, 0x44283b07, 0x5873280c, 0x320a4204,   // kl.sq.xh_222 ks.sd.kk_432  sw.ny.om_543 co.pt.bs_332 
  0x1d4211a0, 0xfc00201a, 0x325d0207, 0x04104805,   // ro.co.la_322 sq.zzp.un_760  da.ss.bs_432 tt.be.ru_333 
  // [11db0]
  0x08004805, 0x1d0d2da4, 0x0817480c, 0x2300110d,   // tt.uk.un_330 sk.cs.la_433  tt.sr.uk_543 ro.ky.un_540 
  0x390b3604, 0x2d360aa4, 0x1a005505, 0x550a59ee,   // gn.es.br_332 pt.gn.sk_433  rw.tl.un_330 rn.pt.rw_422 
  0x16000208, 0x39006513, 0x684c57ec, 0x55675907,   // da.hr.un_430 gv.br.un_650  na.wo.ig_644 rn.ak.rw_432 
  0x23004812, 0x65390107, 0x676501a0, 0x250411af,   // tt.ky.un_640 en.br.gv_432  en.gv.ak_322 ro.fi.eu_655 
  // [11dc0]
  0x3d3b120e, 0x101515a9, 0x02761108, 0x070a0404,   // ur.ks.ku_555 un.be.un_540  ro.crs.da_443 ru.mk.bg_332 
  0x3900651a, 0x33003407, 0x374404a7, 0x2a000b04,   // gv.br.un_760 xh.nn.un_420  ru.kk.ba_532 es.mt.un_320 
  0x190a260e, 0x0a554307, 0x10482509, 0x4600510d,   // ia.pt.gl_555 ie.rw.pt_432  mn.tt.be_444 kl.qu.un_540 
  0x3f4059a4, 0x0e002d18, 0x02fe0811, 0x40003905,   // rn.lb.af_433 sk.is.un_740  no.tlh.da_653 br.lb.un_330 
  // [11dd0]
  0x0c3121a7, 0x05023905, 0x12636007, 0x05071d60,   // jw.az.sv_532 br.da.fr_333  vo.sco.hu_432 la.it.fr_664 
  0x0c00230c, 0x24fe3804, 0x1b080209, 0x2d1d0a13,   // ca.sv.un_530 tk.tlh.eo_332  da.no.tr_444 pt.la.sk_665 
  0x63005312, 0x46150612, 0x09375ea9, 0x2a0c020d,   // ht.sco.un_640 de.qu.un_640  ts.st.pl_544 da.sv.mt_554 
  0x382402a6, 0x0c0801a4, 0x392a5302, 0x080258a0,   // da.eo.tk_521 en.no.sv_433  ht.mt.br_222 om.da.no_322 
  // [11de0]
  0x05431107, 0x53004c08, 0x010a1f0c, 0x48003720,   // ro.ie.fr_432 wo.ht.un_430  cy.pt.en_543 ba.tt.un_850 
  0x056b1dee, 0x023908ee, 0x04790207, 0x55233ea0,   // la.ceb.fr_422 no.br.da_422  da.war.fi_432 rm.ca.rw_322 
  0x1d00260c, 0x071d24ee, 0x05006305, 0x360e2ead,   // ia.la.un_530 eo.la.it_422  sco.fr.un_330 fo.is.gn_643 
  0x156312ee, 0x12001502, 0x33071b07, 0x016b39a4,   // hu.sco.un_422 un.hu.un_220  tr.it.nn_432 br.ceb.en_433 
  // [11df0]
  0x15653807, 0x2c123307, 0x08022a05, 0x230a17a0,   // tk.gv.un_432 nn.hu.fy_432  mt.da.no_333 sr.mk.ky_322 
  0x231922a0, 0x041007a4, 0x0a1510a4, 0x15251107,   // oc.gl.ca_322 bg.be.ru_433  be.mk.un_430 ro.mn.un_432 
  0x24501fa4, 0x1a4702ad, 0x556424a0, 0x39005a04,   // cy.fj.eo_433 da.sn.tl_643  eo.lg.rw_322 sm.br.un_320 
  0x07171511, 0x251535ec, 0x0b23180e, 0x551f0902,   // un.sr.bg_653 tg.mn.un_640  ga.ca.es_555 pl.cy.rw_222 
  // [11e00]
  0x51190a0d, 0x3d3412a7, 0x24355d07, 0x23003904,   // pt.gl.kl_554 ur.ps.ku_532  ss.zu.eo_432 br.ca.un_320 
  0x36004a08, 0x38000407, 0x08041704, 0x2f003923,   // yo.gn.un_430 fi.tk.un_420  sr.ru.uk_332 br.su.un_880 
  0x02130412, 0x2c0304ee, 0x28041308, 0x392f4cee,   // fi.et.da_654 fi.nl.fy_422  et.fi.sw_443 wo.su.br_422 
  0x2c392f0c, 0x51004c08, 0x042858a4, 0x5a002f14,   // su.br.fy_543 wo.kl.un_430  om.sw.fi_433 su.sm.un_660 
  // [11e10]
  0x4c1304a4, 0x2f0465a4, 0x30383ca4, 0x0804150d,   // fi.et.wo_433 gv.fi.su_433  ug.tk.uz_433 un.ru.uk_554 
  0x6a272f11, 0x1c2f4d04, 0x1a134cac, 0x1715040d,   // su.gd.haw_653 aa.su.id_332  wo.et.tl_632 ru.sr.un_540 
  0x392f1f07, 0x3b1d58ee, 0x495a39a4, 0x652f1c07,   // cy.su.br_432 om.la.so_422  br.sm.to_433 id.su.gv_432 
  0x35004607, 0x35003713, 0x424027a7, 0x420205a7,   // qu.zu.un_420 ba.tg.un_650  gd.lb.co_532 fr.da.co_532 
  // [11e20]
  0x6404130c, 0x033f3907, 0x4b130408, 0x22000507,   // et.fi.lg_543 br.af.nl_432  fi.et.mi_443 fr.oc.un_420 
  0x39001f0d, 0x3f0357ec, 0x3903610c, 0x64386713,   // cy.br.un_540 na.nl.af_644  za.nl.br_543 ak.tk.lg_665 
  0x02003909, 0x0d360208, 0x64001b14, 0x0c023fa0,   // br.da.un_440 da.gn.cs_443  tr.lg.un_660 af.da.sv_322 
  0x38006414, 0x34005907, 0x62386412, 0x15304812,   // lg.tk.un_660 rn.xh.un_420  lg.tk.kha_654 tt.uz.un_654 
  // [11e30]
  0x1e003811, 0x1000670c, 0x3f03430c, 0x23fc22a0,   // tk.ms.un_630 ak.lt.un_530  ie.nl.af_543 oc.zzp.ca_322 
  0x65025a07, 0x301523a7, 0xfe52020c, 0x070a02ac,   // sm.da.gv_432 ky.uz.un_520  da.ha.tlh_543 da.pt.it_632 
  0x17005204, 0x2953280c, 0x62045360, 0x505d3502,   // ha.sr.un_320 sw.ht.sl_543  ht.fi.kha_664 zu.ss.fj_222 
  0x04081013, 0x28001e08, 0x1a5210ee, 0x520b3ba9,   // be.uk.ru_665 ms.sw.un_430  lt.ha.tl_422 so.es.ha_544 
  // [11e40]
  0x64006719, 0x64384608, 0x52003b13, 0x1715150c,   // ak.lg.un_750 qu.tk.lg_443  so.ha.un_650 un.sr.un_530 
  0x3b602004, 0x212f52a4, 0x1d6511a0, 0x280252a4,   // sq.vo.so_332 ha.su.jw_433  ro.gv.la_322 ha.da.sw_433 
  0x56003719, 0x070a0405, 0x255a11ad, 0x11001f08,   // st.mg.un_750 ru.mk.bg_333  ro.sm.eu_643 cy.ro.un_430 
  0x04303512, 0x25361555, 0x29201b04, 0x23001811,   // tg.uz.ru_654 un.ab.mn_442  tr.sq.sl_332 ar.ky.un_630 
  // [11e50]
  0x0d0e2e07, 0x203f040d, 0x2700652a, 0x10003408,   // fo.is.cs_432 fi.af.sq_554  gv.gd.un_970 xh.lt.un_430 
  0x131a79a4, 0x42002312, 0x636501af, 0x080246a0,   // war.tl.et_433 ca.co.un_640  en.gv.sco_655 qu.da.no_322 
  0x5f48130c, 0x046311ee, 0x1e000104, 0xfc3e01a0,   // et.tt.tn_543 ro.sco.fi_422  en.ms.un_320 en.rm.zzp_322 
  0x286a78a9, 0x110415a4, 0x13321604, 0x3e1811ad,   // ve.haw.sw_544 un.fi.ro_433  hr.bs.et_332 ro.ga.rm_643 
  // [11e60]
  0x5e73780d, 0x1c732904, 0x33002009, 0x070a3607,   // ve.ny.ts_554 sl.ny.id_332  sq.nn.un_440 ab.mk.bg_432 
  0x784a52ad, 0x1d42500c, 0x13095c07, 0x04171002,   // ha.yo.ve_643 fj.co.la_543  sa.hi.bh_432 be.sr.ru_222 
  0x7852730d, 0x3b5e4e0d, 0x51004902, 0x5d5a73af,   // ny.ha.ve_554 ay.ts.so_554  to.kl.un_220 ny.sm.ss_655 
  0x483825a9, 0x33082ca9, 0x02fe0312, 0x07151707,   // mn.tk.tt_544 fy.no.nn_544  nl.tlh.da_654 sr.bg.un_420 
  // [11e70]
  0x374823a0, 0x153504af, 0x354830ec, 0x12192302,   // ky.tt.ba_322 ru.tg.un_655  uz.tt.tg_644 ca.gl.hu_222 
  0x17110704, 0x483023a0, 0x353638ec, 0x58271fee,   // bg.ro.sr_332 ky.uz.tt_322  tk.ab.tg_644 cy.gd.om_422 
  0x44213407, 0x47732855, 0x5d001808, 0x36005a07,   // ps.fa.kk_432 sw.ny.sn_442  ga.ss.un_430 sm.gn.un_420 
  0x63003819, 0x1b000904, 0x39000d02, 0x48003122,   // tk.sco.un_750 pl.tr.un_320  cs.br.un_220 az.tt.un_870 
  // [11e80]
  0x65002c13, 0x20004004, 0x210a79a0, 0x0d095c11,   // fy.gv.un_650 lb.sq.un_320  war.pt.jw_322 sa.hi.ne_653 
  0x091f3907, 0x40650604, 0x0d63650b, 0x0640790c,   // br.cy.pl_432 de.gv.lb_332  gv.sco.cs_542 war.lb.de_543 
  0x2b0c33ad, 0x2d290d02, 0x39002013, 0x0d5c1311,   // nn.sv.vi_643 cs.sl.sk_222  sq.br.un_650 bh.sa.ne_653 
  0x7600390d, 0x11083c0c, 0x39132207, 0x38063209,   // br.crs.un_540 ug.uk.ro_543  oc.et.br_432 bs.de.tk_444 
  // [11e90]
  0x6540630c, 0x3f330805, 0x45401d07, 0x06152a55,   // sco.lb.gv_543 no.nn.af_333  la.lb.ln_432 mt.de.un_420 
  0x3c303b05, 0x403206a4, 0x27066960, 0x3902080c,   // ks.uz.ug_333 de.bs.lb_433  mfe.de.gd_664 no.da.br_543 
  0x4c561a07, 0x65002107, 0x20154d07, 0x4c6b0207,   // tl.mg.wo_432 jw.gv.un_420  aa.sq.un_420 da.ceb.wo_432 
  0x2d460fa0, 0x31021507, 0x0c001507, 0x31176304,   // lv.qu.sk_322 un.da.az_432  un.sv.un_420 sco.sr.az_332 
  // [11ea0]
  0x2d650d04, 0x121830a0, 0x38561807, 0x03400607,   // cs.gv.sk_332 uz.ar.ur_322  ga.mg.tk_432 de.lb.nl_432 
  0x303d2108, 0x53004308, 0x3f1133a7, 0x0c150804,   // fa.ku.uz_443 ie.ht.un_430  nn.ro.af_532 no.sv.un_320 
  0x3420290b, 0x04100a02, 0x0a1710ec, 0x0c006405,   // sl.sq.xh_542 mk.be.ru_222  be.sr.mk_644 lg.sv.un_330 
  0x49686407, 0x15443808, 0x3f652b04, 0x44040802,   // lg.ig.to_432 tk.kk.un_443  vi.gv.af_332 uk.ru.kk_222 
  // [11eb0]
  0x78005e1b, 0x2a005d0e, 0x3000fe07, 0xfc19fe04,   // ts.ve.un_770 ss.mt.un_550  tlh.uz.un_420 tlh.gl.zzp_332 
  0x35300aa4, 0x3f5f02a0, 0x5c4676a0, 0x3723480c,   // mk.uz.tg_433 da.tn.af_322  crs.qu.sa_322 tt.ky.ba_543 
  0xfe30060d, 0x2d5376ee, 0x10353004, 0x5c000407,   // de.uz.tlh_554 crs.ht.sk_422  uz.tg.be_332 fi.sa.un_420 
  0x3c38110c, 0x30536907, 0x52fe0255, 0x0a002e14,   // ro.tk.ug_543 mfe.ht.uz_432  da.tlh.ha_442 fo.pt.un_660 
  // [11ec0]
  0x5d1d0107, 0x304823ec, 0xfc12fe04, 0xfe001b04,   // en.la.ss_432 ky.tt.uz_644  tlh.hu.zzp_332 tr.tlh.un_320 
  0x6800571b, 0x1d4015a4, 0x343c1808, 0x234417ee,   // na.ig.un_770 un.lb.la_433  ar.ug.ps_443 sr.kk.ky_422 
  0x0a100402, 0x23224a07, 0x100e2f0b, 0x25000904,   // ru.be.mk_222 yo.oc.ca_432  su.is.lt_542 pl.eu.un_320 
  0x073836a7, 0x1d4a04ee, 0x47003408, 0x30341205,   // ab.tk.bg_532 fi.yo.la_422  xh.sn.un_430 ur.ps.uz_333 
  // [11ed0]
  0x36441507, 0x44000408, 0x130e3307, 0x20003f09,   // un.kk.ab_432 ru.kk.un_430  nn.is.et_432 af.sq.un_440 
  0x1e1c25a0, 0x303504a7, 0x69622a08, 0x63392a08,   // eu.id.ms_322 ru.tg.uz_532  mt.kha.mfe_443 mt.br.sco_443 
  0x034039af, 0x48150407, 0x3f0f0907, 0x581b4da0,   // br.lb.nl_655 ru.tt.un_420  pl.lv.af_432 aa.tr.om_322 
  0x32203055, 0x3e006108, 0x5c005804, 0x030f1d08,   // uz.sq.bs_442 za.rm.un_430  om.sa.un_320 la.lv.nl_443 
  // [11ee0]
  0x06fc1504, 0x0f003914, 0x2c3f2a0c, 0x072304a0,   // un.zzp.de_332 br.lv.un_660  mt.af.fy_543 ru.ky.bg_322 
  0x436919a4, 0x61690f08, 0x2a2d1da0, 0x04080705,   // gl.mfe.ie_433 lv.mfe.za_443  la.sk.mt_322 bg.uk.ru_333 
  0x585c1ba4, 0x5e005804, 0x0100fc0c, 0x671c1ea9,   // tr.sa.om_433 om.ts.un_320  zzp.en.un_530 ms.id.ak_544 
  0x2f1e1c13, 0x18121904, 0x13004a04, 0x2f4d1ea9,   // id.ms.su_665 gl.hu.ga_332  yo.et.un_320 ms.aa.su_544 
  // [11ef0]
  0x2b2d0d05, 0x5c21620c, 0x1c4d1ea9, 0x2c243e04,   // cs.sk.vi_333 kha.jw.sa_543  ms.aa.id_544 rm.eo.fy_332 
  0x1f00fc0e, 0x452f1807, 0x4d621e0c, 0x4d292108,   // zzp.cy.un_550 ga.su.ln_432  ms.kha.aa_543 jw.sl.aa_443 
  0x24103e02, 0x4a00270c, 0x38001802, 0x5b1c1ea7,   // rm.lt.eo_222 gd.yo.un_530  ga.tk.un_220 ms.id.sg_532 
  0x21004d12, 0x293f560c, 0x4d1c1e0c, 0x38003007,   // aa.jw.un_640 mg.af.sl_543  ms.id.aa_543 uz.tk.un_420 
  // [11f00]
  0x1827fc11, 0x62211ea4, 0x1efe4daf, 0x0165fcee,   // zzp.gd.ga_653 ms.jw.kha_433  aa.tlh.ms_655 zzp.gv.en_422 
  0x30282108, 0x04000a13, 0x23002b02, 0x15330855,   // fa.sd.uz_443 mk.ru.un_650  vi.ca.un_220 no.nn.un_442 
  0x38647313, 0x76246909, 0x342f5d0c, 0x304837ee,   // ny.lg.tk_665 mfe.eo.crs_444  ss.su.xh_543 ba.tt.uz_422 
  0x303b21a4, 0x796b330d, 0x483c38ee, 0x73345d04,   // fa.ks.uz_433 nn.ceb.war_554  tk.ug.tt_422 ss.xh.ny_332 
  // [11f10]
  0x48362512, 0x0a231704, 0x08000412, 0x21303c5a,   // mn.ab.tt_654 sr.ky.mk_332  ru.uk.un_640 ug.uz.fa_553 
  0x13095c04, 0x08441708, 0x48360704, 0x5f4279ee,   // sa.hi.bh_332 sr.kk.uk_443  bg.ab.tt_332 war.co.tn_422 
  0x17321611, 0x11001702, 0x39004313, 0x1535040d,   // hr.bs.sr_653 sr.ro.un_220  ie.br.un_650 ru.tg.un_554 
  0x041007ad, 0x42002712, 0x23103004, 0x56000902,   // bg.be.ru_643 gd.co.un_640  uz.be.ky_332 pl.mg.un_220 
  // [11f20]
  0x135c0d04, 0x343c2107, 0x08000a07, 0x23184404,   // ne.sa.bh_332 fa.ug.ps_432  mk.uk.un_420 kk.ar.ky_332 
  0x104836a4, 0x2000460c, 0x27002307, 0x1068130c,   // ab.tt.be_433 qu.sq.un_530  ca.gd.un_420 et.ig.lt_543 
  0x0f1360ac, 0x0b0a36ee, 0x301023a9, 0x3c231504,   // vo.et.lv_632 gn.pt.es_422  ky.be.uz_544 un.ky.ug_332 
  0x25154804, 0x3c003412, 0x103523a4, 0x154437a4,   // tt.mn.un_320 ps.ug.un_640  ky.tg.be_433 ba.kk.un_433 
  // [11f30]
  0x442304ee, 0x37000a05, 0x191102a0, 0x11271807,   // ru.ky.kk_422 mk.ba.un_330  da.ro.gl_322 ga.gd.ro_432 
  0x073efc07, 0x5e065c0c, 0x420711af, 0x10362513,   // zzp.rm.it_432 sa.de.ts_543  ro.it.co_655 mn.ab.be_665 
  0x27001818, 0x18002729, 0x23444808, 0x0c00081b,   // ga.gd.un_740 gd.ga.un_960  tt.kk.ky_443 no.sv.un_770 
  0x4006570b, 0x1262220c, 0x09000207, 0x12080c11,   // na.de.lb_542 oc.kha.hu_543  da.pl.un_420 sv.no.hu_653 
  // [11f40]
  0x06403ea9, 0x0c4f08ee, 0x0c21200c, 0x40063ea0,   // rm.lb.de_544 no.bi.sv_422  sq.jw.sv_543 rm.de.lb_322 
  0x27181f0c, 0x05001808, 0x330c0860, 0x44483c0c,   // cy.ga.gd_543 ga.fr.un_430  no.sv.nn_664 ug.tt.kk_543 
  0x400643a7, 0x30005008, 0x28001502, 0x12203960,   // ie.de.lb_532 fj.uz.un_430  un.sw.un_220 br.sq.hu_664 
  0x15182712, 0x0c08200c, 0x20211205, 0x38080c0c,   // gd.ga.un_654 sq.no.sv_543  hu.jw.sq_333 sv.no.tk_543 
  // [11f50]
  0x091c2102, 0x0c622008, 0x11001b08, 0x51626307,   // jw.id.pl_222 sq.kha.sv_443  tr.ro.un_430 sco.kha.kl_432 
  0x281234ee, 0x1004170c, 0x0a2315ad, 0x301725ad,   // ps.ur.sd_422 sr.ru.be_543  un.ky.mk_643 mn.sr.uz_643 
  0x250717a0, 0x0a171513, 0x070a25a9, 0x46004808,   // sr.bg.mn_322 un.sr.mk_665  mn.mk.bg_544 tt.qu.un_430 
  0x3f6303a9, 0x52460205, 0x05423904, 0x46005213,   // nl.sco.af_544 da.qu.ha_333  br.co.fr_332 ha.qu.un_650 
  // [11f60]
  0x3f0539a0, 0x52460407, 0x49471d04, 0x3152460c,   // br.fr.af_322 fi.qu.ha_432  la.sn.to_332 qu.ha.az_543 
  0x3f2c5208, 0x380446a0, 0xfc4a520c, 0x79fc0e07,   // ha.fy.af_443 qu.fi.tk_322  ha.yo.zzp_543 is.zzp.war_432 
  0xfc005209, 0x1b525c07, 0x1f2d0d13, 0x535a49ee,   // ha.zzp.un_440 sa.ha.tr_432  cs.sk.cy_665 to.sm.ht_422 
  0xfc1b3109, 0xfefc46a4, 0x46fe52af, 0x351239a4,   // az.tr.zzp_444 qu.zzp.tlh_433  ha.tlh.qu_655 br.hu.zu_433 
  // [11f70]
  0x4a044607, 0x02055da0, 0x423e3908, 0x693e3908,   // qu.fi.yo_432 ss.fr.da_322  br.rm.co_443 br.rm.mfe_443 
  0x27006305, 0x0a101704, 0x15253608, 0x40190a05,   // sco.gd.un_330 sr.be.mk_332  ab.mn.un_443 pt.gl.lb_333 
  0x1f004607, 0x50630f02, 0x53000d08, 0x48063802,   // qu.cy.un_420 lv.sco.fj_222  cs.ht.un_430 tk.de.tt_222 
  0x080423a4, 0x2d053907, 0x3e486909, 0x766939a4,   // ky.ru.uk_433 br.fr.sk_432  mfe.tt.rm_444 br.mfe.crs_433 
  // [11f80]
  0x28341813, 0x0b003912, 0x212344a4, 0x093906ee,   // ar.ps.sd_665 br.es.un_640  kk.ky.fa_433 de.br.pl_422 
  0x09303113, 0x23482504, 0x46002d05, 0x6800420e,   // az.uz.pl_665 mn.tt.ky_332  sk.qu.un_330 co.ig.un_550 
  0x481538a7, 0x0c04400c, 0x302337a9, 0x08170a14,   // tk.tt.un_520 lb.fi.sv_543  ba.ky.uz_544 mk.sr.uk_666 
  0x11170aa9, 0x39403f04, 0x07005712, 0x654039a4,   // mk.sr.ro_544 af.lb.br_332  na.it.un_640 br.lb.gv_433 
  // [11f90]
  0x123901a0, 0x10152307, 0x5c691004, 0x2c02080c,   // en.br.hu_322 ky.be.un_420  lt.mfe.sa_332 no.da.fy_543 
  0x2e245c07, 0x2a123f07, 0x2c002002, 0x2f401c04,   // sa.eo.fo_432 af.hu.mt_432  sq.fy.un_220 id.lb.su_332 
  0x2c006304, 0x10481104, 0x620c010b, 0x24003902,   // sco.fy.un_320 ro.tt.be_332  en.sv.kha_542 br.eo.un_220 
  0x0a001511, 0x35111014, 0x6b005c12, 0x3900040e,   // un.mk.un_630 be.ro.tg_666  sa.ceb.un_640 fi.br.un_550 
  // [11fa0]
  0x162d1007, 0x125c1004, 0x4f39080b, 0x2f125c0c,   // lt.sk.hr_432 lt.sa.hu_332  no.br.bi_542 sa.hu.su_543 
  0x11070aa4, 0x1735230c, 0x16001821, 0x2c00560b,   // mk.bg.ro_433 ky.tg.sr_543  ar.th.un_860 mg.fy.un_520 
  0x30444804, 0x2d0d5d02, 0x422205a4, 0x394a5607,   // tt.kk.uz_332 ss.cs.sk_222  fr.oc.co_433 mg.yo.br_432 
  0xfc00fe13, 0x19005611, 0x06571f0c, 0x40271855,   // tlh.zzp.un_650 mg.gl.un_630  cy.na.de_543 ga.gd.lb_442 
  // [11fb0]
  0x3053010c, 0x090627ec, 0x21220508, 0x400d4611,   // en.ht.uz_543 gd.de.pl_644  fr.oc.jw_443 qu.cs.lb_653 
  0x224205ad, 0x1c1d21a0, 0x632c010c, 0x7800341a,   // fr.co.oc_643 jw.la.id_322  en.fy.sco_543 xh.ve.un_760 
  0x18270112, 0x4a122e0c, 0x1f090d0c, 0x234e73ad,   // en.gd.ga_654 fo.hu.yo_543  cs.pl.cy_543 ny.ay.ca_643 
  0x402205a4, 0x73fe630c, 0xfe69650d, 0x0240630c,   // fr.oc.lb_433 sco.tlh.ny_543  gv.mfe.tlh_554 sco.lb.da_543 
  // [11fc0]
  0x34fc0107, 0x15400111, 0x06403e0e, 0x092dfe55,   // en.zzp.xh_432 en.lb.un_653  rm.lb.de_555 tlh.sk.pl_442 
  0x65574704, 0x0c004d12, 0x0a58340d, 0x63670107,   // sn.na.gv_332 aa.sv.un_640  xh.om.pt_554 en.ak.sco_432 
  0x46005009, 0x10303512, 0x532322ee, 0x363c380c,   // fj.qu.un_440 tg.uz.be_654  oc.ca.ht_422 tk.ug.ab_543 
  0x48005004, 0x070817a7, 0x0a2a1da0, 0x5d005c08,   // fj.tt.un_320 sr.uk.bg_532  la.mt.pt_322 sa.ss.un_430 
  // [11fd0]
  0x2b00730b, 0x10441505, 0x181f2707, 0x0a301007,   // ny.vi.un_520 un.kk.be_333  gd.cy.ga_432 be.uz.mk_432 
  0x25001022, 0x3b27180c, 0x082317a0, 0x151801a4,   // be.mn.un_870 ga.gd.so_543  sr.ky.uk_322 en.ga.un_433 
  0x42551d04, 0x1704100c, 0x1b3812a0, 0x30002518,   // la.rw.co_332 be.ru.sr_543  hu.tk.tr_322 mn.uz.un_740 
  0x3c00180c, 0x232153a0, 0x06040cec, 0x11150412,   // ar.ug.un_530 ht.jw.ca_322  sv.fi.de_644 ru.ro.un_640 
  // [11fe0]
  0x343c21a7, 0x483c44a7, 0x430b0a05, 0x39033f04,   // fa.ug.ps_532 kk.ug.tt_532  pt.es.ie_333 af.nl.br_332 
  0x0b2219a4, 0x21232207, 0x2400fc02, 0x04004813,   // gl.oc.es_433 oc.ca.jw_432  zzp.eo.un_220 tt.fi.un_650 
  0x09001814, 0x23442504, 0x3c184455, 0x30314814,   // ar.hi.un_660 mn.kk.ky_332  kk.ar.ug_442 tt.az.uz_666 
  0x732f21a0, 0x38233c14, 0x382d0d0b, 0x65483004,   // jw.su.ny_322 ug.ky.tk_666  cs.sk.tk_542 uz.tt.gv_332 
  // [11ff0]
  0x122e3907, 0x150807a7, 0x211c2fa4, 0x106467a9,   // br.fo.hu_432 bg.uk.un_532  su.id.jw_433 ak.lg.lt_544 
  0x55003602, 0x3f080208, 0x64003609, 0x5d3435a9,   // gn.rw.un_220 da.no.af_443  gn.lg.un_440 zu.xh.ss_544 
  0x2122230b, 0x0b006407, 0x601b1260, 0x1e1c4aec,   // ca.oc.jw_542 lg.es.un_420  hu.tr.vo_664 yo.id.ms_644 
  0x311b12ec, 0x15000612, 0x460b4aee, 0x31121b02,   // hu.tr.az_644 de.un.un_640  yo.es.qu_422 tr.hu.az_222 
  
  // [12000]
  0x205653a6, 0x486012a4, 0x213667ee, 0x470dfa07,   // ht.mg.sq_521 hu.vo.tt_433  ak.gn.jw_422 nr.cs.sn_432 
  0x0d4f7607, 0x041d2007, 0x08153004, 0x2f3920ee,   // crs.bi.cs_432 sq.la.fi_432  uz.uk.un_320 sq.br.su_422 
  0x35523007, 0x1300200c, 0x022a2012, 0x5c322a0b,   // uz.ha.zu_432 sq.et.un_530  sq.mt.da_654 mt.bs.sa_542 
  0x0f213802, 0x2d004002, 0x556435a0, 0x53311ea0,   // tk.jw.lv_222 lb.sk.un_220  zu.lg.rw_322 ms.az.ht_322 
  // [12010]
  0x1b601211, 0x56003204, 0x0d00200c, 0x0b002904,   // hu.vo.tr_653 bs.mg.un_320  sq.cs.un_530 sl.es.un_320 
  0x481b120c, 0x12002013, 0x12321655, 0x36020baf,   // hu.tr.tt_543 sq.hu.un_650  hr.bs.hu_442 es.da.gn_655 
  0x290820ee, 0x08201608, 0x321620a4, 0x3f001302,   // sq.no.sl_422 hr.sq.no_443  sq.hr.bs_433 et.af.un_220 
  0x4437250c, 0x07173c11, 0x0e2d0da7, 0x35443007,   // mn.ba.kk_543 ug.sr.bg_653  cs.sk.is_532 uz.kk.tg_432 
  // [12020]
  0x0e0d3865, 0x21080204, 0x380d2d10, 0x353017a0,   // tk.cs.is_763 da.no.jw_332  sk.cs.tk_642 sr.uz.tg_322 
  0x382d0d05, 0x1b001822, 0x3f40060c, 0x3744480d,   // cs.sk.tk_333 ga.tr.un_870  de.lb.af_543 tt.kk.ba_554 
  0x282112ee, 0x0d1d2ea0, 0x08301555, 0x53002307,   // ur.fa.sd_422 fo.la.cs_322  un.uz.uk_442 ca.ht.un_420 
  0x33000904, 0x212830a9, 0x025f1f07, 0x5f251908,   // pl.nn.un_320 uz.sd.fa_544  cy.tn.da_432 gl.eu.tn_443 
  // [12030]
  0x25391fa9, 0x2118120b, 0x080a15ad, 0x0a4436a0,   // cy.br.eu_544 ur.ar.fa_542  un.mk.uk_643 ab.kk.mk_322 
  0x20321605, 0x2f2539a9, 0x243f5407, 0x17200907,   // hr.bs.sq_333 br.eu.su_544  ik.af.eo_432 pl.sq.sr_432 
  0x25003204, 0x322203ad, 0x17100407, 0x3e000707,   // bs.eu.un_320 nl.oc.bs_643  ru.be.sr_432 it.rm.un_420 
  0x21000a07, 0x402509a0, 0x1a006405, 0x39026007,   // pt.jw.un_420 pl.eu.lb_322  lg.tl.un_330 vo.da.br_432 
  // [12040]
  0x1f355f07, 0x0c005f07, 0x150a0705, 0x484438a0,   // tn.zu.cy_432 tn.sv.un_420  bg.mk.un_333 tk.kk.tt_322 
  0x39004202, 0x1a392aa0, 0x1b465411, 0x4d4e5413,   // co.br.un_220 mt.br.tl_322  ik.qu.tr_653 ik.ay.aa_665 
  0x52005809, 0x3f000f0c, 0x03004619, 0x52384d60,   // om.ha.un_440 lv.af.un_530  qu.nl.un_750 aa.tk.ha_664 
  0x25003911, 0x0c464e07, 0x52005802, 0x384d5212,   // br.eu.un_630 ay.qu.sv_432  om.ha.un_220 ha.aa.tk_654 
  // [12050]
  0x2d00fc04, 0x2c4003a7, 0x1e5838a9, 0x2700fc08,   // zzp.sk.un_320 nl.lb.fy_532  tk.om.ms_544 zzp.gd.un_430 
  0x1a6b790d, 0x2d001b08, 0x46001a02, 0x594d5812,   // war.ceb.tl_554 tr.sk.un_430  tl.qu.un_220 om.aa.rn_654 
  0x0300fe12, 0x0a100407, 0x091c5c02, 0x102f0408,   // tlh.nl.un_640 fi.lt.pt_432  sa.mr.hi_222 fi.su.lt_443 
  0x5e004305, 0x3f001212, 0x011922a7, 0x373604ee,   // ie.ts.un_330 hu.af.un_640  oc.gl.en_532 fi.gn.st_422 
  // [12060]
  0x0c5c760b, 0x131004a4, 0x041036ec, 0x1d340ca0,   // crs.sa.sv_542 fi.lt.et_433  gn.lt.fi_644 sv.xh.la_322 
  0x4a0f1007, 0x2a005e04, 0x246976a9, 0x1d005a08,   // lt.lv.yo_432 ts.mt.un_320  crs.mfe.eo_544 sm.la.un_430 
  0x655a6aad, 0x38524d0c, 0x6b001008, 0x52004902,   // haw.sm.gv_643 aa.ha.tk_543  lt.ceb.un_430 to.ha.un_220 
  0x384d52ad, 0x352344a0, 0x20000b04, 0x343b4c0c,   // ha.aa.tk_643 kk.ky.tg_322  es.sq.un_320 wo.so.xh_543 
  // [12070]
  0x495a1d08, 0x38001108, 0x20042d07, 0x0300fe19,   // la.sm.to_443 ro.tk.un_430  sk.fi.sq_432 tlh.nl.un_750 
  0x2010040c, 0x5a37300c, 0x48300360, 0x0f362d07,   // fi.lt.sq_543 uz.st.sm_543  nl.uz.tt_664 sk.gn.lv_432 
  0x29204704, 0x01004e07, 0x201304a4, 0x1d023b07,   // sn.sq.sl_332 ay.en.un_420  fi.et.sq_433 so.da.la_432 
  0x5600570b, 0x19003b09, 0x23041509, 0x3c342107,   // na.mg.un_520 so.gl.un_440  un.ru.ky_444 fa.ps.ug_432 
  // [12080]
  0x4b045a05, 0x25565aad, 0x64000602, 0x102325a0,   // sm.fi.mi_333 sm.mg.eu_643  de.lg.un_220 mn.ky.be_322 
  0x09105305, 0x2c006514, 0x43571da4, 0x2b00390c,   // ht.lt.pl_333 gv.fy.un_660  la.na.ie_433 br.vi.un_530 
  0x27000512, 0x180c09ee, 0x0c000d02, 0x12004807,   // fr.gd.un_640 pl.sv.ga_422  cs.sv.un_220 tt.hu.un_420 
  0x253748a4, 0x0a3515a9, 0x171610a0, 0x353023a4,   // tt.ba.mn_433 un.tg.mk_544  lt.hr.sr_322 ky.uz.tg_433 
  // [12090]
  0x231535ee, 0x40011502, 0x08231004, 0x4400340c,   // tg.ky.un_420 un.en.lb_222  be.ky.uk_332 ps.kk.un_530 
  0x080a04ee, 0x0915620c, 0x183c44a0, 0x04441704,   // ru.mk.uk_422 kha.pl.un_530  kk.ug.ar_322 sr.kk.ru_332 
  0x35101504, 0x343c3da4, 0x20005904, 0x02002108,   // un.be.tg_332 ku.ug.ps_433  rn.sq.un_320 jw.da.un_430 
  0x18343007, 0x1d002622, 0x04002f08, 0x63000323,   // uz.ps.ar_432 ia.la.un_870  su.fi.un_430 nl.sco.un_880 
  // [120a0]
  0x03632507, 0x0a00260d, 0x4c632fa4, 0x34003604,   // eu.sco.nl_432 ia.pt.un_540  su.sco.wo_433 gn.xh.un_320 
  0x65002f02, 0x35592912, 0x79433ba4, 0x19070b60,   // su.gv.un_220 sl.rn.zu_654  so.ie.war_433 es.it.gl_664 
  0x50001d0c, 0x45595b0c, 0x28302307, 0x353059a4,   // la.fj.un_530 sg.rn.ln_543  ky.uz.sd_432 rn.uz.zu_433 
  0x45353404, 0x2d1629a4, 0x48003b13, 0x59003514,   // xh.zu.ln_332 sl.hr.sk_433  so.tt.un_650 zu.rn.un_660 
  // [120b0]
  0x1e003004, 0x49002807, 0x310b46ee, 0x48004423,   // uz.ms.un_320 sw.to.un_420  qu.es.az_422 kk.tt.un_880 
  0x06330808, 0x1015250c, 0x11382509, 0x1b020807,   // no.nn.de_443 mn.be.un_530  mn.tk.ro_444 no.da.tr_432 
  0x553320ee, 0x1d004307, 0x23443804, 0x34301807,   // sq.nn.rw_422 ie.la.un_420  tk.kk.ky_332 ar.uz.ps_432 
  0x19004304, 0x302338af, 0xfe00540c, 0x04083504,   // ie.gl.un_320 tk.ky.uz_655  ik.tlh.un_530 tg.uk.ru_332 
  // [120c0]
  0x3c170a55, 0x633904a4, 0x2d0d3605, 0x1800fe04,   // mk.sr.ug_442 fi.br.sco_433  gn.cs.sk_333 tlh.ga.un_320 
  0x1a4b6aa0, 0x4200fc04, 0x17071007, 0x18003012,   // haw.mi.tl_322 zzp.co.un_320  be.bg.sr_432 uz.ar.un_640 
  0x362e185a, 0x25372314, 0x32291612, 0x37444807,   // ga.fo.gn_553 ky.ba.mn_666  hr.sl.bs_654 tt.kk.ba_432 
  0x28002002, 0x1d004b02, 0x1d004f07, 0x36482514,   // sq.sw.un_220 mi.la.un_220  bi.la.un_420 mn.tt.ab_666 
  // [120d0]
  0x5a004b0b, 0x170807a4, 0x0744230d, 0x152344a9,   // mi.sm.un_520 bg.uk.sr_433  ky.kk.bg_554 kk.ky.un_544 
  0x123d2111, 0x4421120e, 0x1500750c, 0x0e4c0ca0,   // fa.ku.ur_653 ur.fa.kk_555  nso.un.un_530 sv.wo.is_322 
  0x18120ea4, 0x44000802, 0x57001014, 0x73006408,   // is.hu.ga_433 uk.kk.un_220  lt.na.un_660 lg.ny.un_430 
  0x353468a0, 0x595579a9, 0x311b48a4, 0x35005513,   // ig.xh.zu_322 war.rw.rn_544  tt.tr.az_433 rw.zu.un_650 
  // [120e0]
  0x5d3559a4, 0x64000209, 0x35645dee, 0x01551504,   // rn.zu.ss_433 da.lg.un_440  ss.lg.zu_422 un.rw.en_332 
  0x2f592109, 0x4a38125a, 0x28353455, 0x5d006821,   // jw.rn.su_444 hu.tk.yo_553  xh.zu.sw_442 ig.ss.un_860 
  0x1a2f21a9, 0x644773a4, 0x3b006511, 0x28006808,   // jw.su.tl_544 ny.sn.lg_433  gv.so.un_630 ig.sw.un_430 
  0x00004337, 0x0d5c13ee, 0x21000207, 0x213d345a,   // ie.un.un_B00 bh.sa.ne_422  da.jw.un_420 ps.ku.fa_553 
  // [120f0]
  0x2d0d5909, 0x5955350b, 0x0a0736a0, 0x18000205,   // rn.cs.sk_444 zu.rw.rn_542  ab.bg.mk_322 da.ga.un_330 
  0x2b000e07, 0x04082505, 0x0a153ca4, 0x080230a4,   // is.vi.un_420 mn.uk.ru_333  ug.mk.un_430 uz.da.no_433 
  0x040a17ad, 0x1b0e2eee, 0x44043604, 0x3b290f0c,   // sr.mk.ru_643 fo.is.tr_422  ab.ru.kk_332 lv.sl.so_543 
  0x0a1725a0, 0x23173ca4, 0x25001705, 0x0e002b19,   // mn.sr.mk_322 ug.sr.ky_433  sr.mn.un_330 vi.is.un_750 
  // [12100]
  0x3830310c, 0x082e2904, 0x2e3129a4, 0x4835370c,   // az.uz.tk_543 sl.fo.no_332  sl.az.fo_433 ba.tg.tt_543 
  0x24063ea0, 0x0f00170c, 0x346402ee, 0x212f4ca0,   // rm.de.eo_322 sr.lv.un_530  da.lg.xh_422 wo.su.jw_322 
  0x10004002, 0x60001b13, 0x18004414, 0x043f400c,   // lb.lt.un_220 tr.vo.un_650  kk.ar.un_660 lb.af.fi_543 
  0x43030408, 0x04004014, 0x130440af, 0x23442512,   // fi.nl.ie_443 lb.fi.un_660  lb.fi.et_655 mn.kk.ky_654 
  // [12110]
  0x21001b14, 0x0f404ca0, 0x013f63ec, 0x55285611,   // tr.jw.un_660 wo.lb.lv_322  sco.af.en_644 mg.sw.rw_653 
  0x64312808, 0x1a180107, 0x583b5204, 0x2847560c,   // sw.az.lg_443 en.ga.tl_432  ha.so.om_332 mg.sn.sw_543 
  0x2236020c, 0x39630409, 0x5a56500d, 0x40130412,   // da.gn.oc_543 fi.sco.br_444  fj.mg.sm_554 fi.et.lb_654 
  0x645855a4, 0x363815a7, 0x040313a4, 0x02005622,   // rw.om.lg_433 un.tk.ab_532  et.nl.fi_433 mg.da.un_870 
  // [12120]
  0x473673a0, 0x1f00460c, 0x6100550e, 0x35173605,   // ny.gn.sn_322 qu.cy.un_530  rw.za.un_550 ab.sr.tg_333 
  0x4659555a, 0x5e5a5da4, 0x5c1c1355, 0x442834ee,   // rw.rn.qu_553 ss.sm.ts_433  bh.mr.sa_442 ps.sd.kk_422 
  0x033f06a0, 0x104438ad, 0x2536150e, 0x1d232209,   // de.af.nl_322 tk.kk.be_643  un.ab.mn_555 oc.ca.la_444 
  0x44002320, 0x1e1c1ba0, 0x070a1502, 0x190bfc05,   // ky.kk.un_850 tr.id.ms_322  un.mk.bg_222 zzp.es.gl_333 
  // [12130]
  0x0a001519, 0x3844100c, 0x1d001f08, 0x23001212,   // un.mk.un_750 be.kk.tk_543  cy.la.un_430 hu.ca.un_640 
  0x15150405, 0x3e00071b, 0x120e3607, 0x0e2d12a4,   // ru.un.un_330 it.rm.un_770  gn.is.hu_432 hu.sk.is_433 
  0x2d0910ec, 0x2d0e2ea7, 0x17100a02, 0x2e230ea0,   // lt.pl.sk_644 fo.is.sk_532  mk.be.sr_222 is.ca.fo_322 
  0x2e2d0eee, 0x232d0a04, 0x3c374814, 0x2d004304,   // is.sk.fo_422 pt.sk.ca_332  tt.ba.ug_666 ie.sk.un_320 
  // [12140]
  0x2b0902a0, 0x0e2e23ee, 0x4c003f0e, 0x34301205,   // da.pl.vi_322 ca.fo.is_422  af.wo.un_550 ur.uz.ps_333 
  0x230e2e07, 0x070a3605, 0x11003c22, 0x2308100d,   // fo.is.ca_432 ab.mk.bg_333  ug.ro.un_870 be.uk.ky_554 
  0x3f4001ee, 0x35040805, 0x042308ee, 0x1707040c,   // en.lb.af_422 uk.ru.tg_333  uk.ky.ru_422 ru.bg.sr_543 
  0x24000133, 0x35002204, 0x153530ad, 0x0c3308a7,   // iw.yi.un_A70 oc.zu.un_320  uz.tg.un_643 no.nn.sv_532 
  // [12150]
  0xfe000e09, 0x33083002, 0x23120e04, 0x1a003302,   // is.tlh.un_440 uz.no.nn_222  is.hu.ca_332 nn.tl.un_220 
  0x3c441512, 0x351530a4, 0x20303302, 0x30483555,   // un.kk.ug_654 uz.tg.un_430  nn.uz.sq_222 tg.tt.uz_442 
  0x07174807, 0x302335ad, 0x09fc7311, 0x281821ec,   // tt.sr.bg_432 tg.ky.uz_643  ny.zzp.pl_653 fa.ar.sd_644 
  0x7365fc0c, 0x44363711, 0x09002413, 0x65fefca4,   // zzp.gv.ny_543 ba.ab.kk_653  eo.pl.un_650 zzp.tlh.gv_433 
  // [12160]
  0x13351e02, 0x02006304, 0x0c1157ee, 0x25001014,   // ms.zu.et_222 sco.da.un_320  na.ro.sv_422 be.mn.un_660 
  0x18123ca0, 0x73fefca4, 0x18003f07, 0x2d172304,   // ug.ur.ar_322 zzp.tlh.ny_433  af.ga.un_420 ca.sr.sk_332 
  0x42051da4, 0x12004604, 0x2d005912, 0x00000a37,   // la.fr.co_433 qu.hu.un_320  rn.sk.un_640 mk.un.un_B00 
  0x112d3ead, 0x48001114, 0x24000a04, 0x2d003e07,   // rm.sk.ro_643 ro.tt.un_660  pt.eo.un_320 rm.sk.un_420 
  // [12170]
  0x360379a0, 0x48233713, 0x09000c19, 0x3b6559ee,   // war.nl.gn_322 ba.ky.tt_665  sv.pl.un_750 rn.gv.so_422 
  0x1f002319, 0x0500230b, 0x0722fc02, 0x0a1511ee,   // ca.cy.un_750 ca.fr.un_520  zzp.oc.it_222 ro.pt.un_420 
  0x111501a4, 0x1d63fc04, 0x06021f04, 0x044815af,   // en.ro.un_430 zzp.sco.la_332  cy.da.de_332 un.tt.ru_655 
  0x030c63a0, 0x0c2d0d09, 0x0a071012, 0x18091507,   // sco.sv.nl_322 cs.sk.sv_444  be.bg.mk_654 un.pl.ga_432 
  // [12180]
  0x0f004a0e, 0x021260a4, 0x103217a6, 0x02537607,   // yo.lv.un_550 vo.hu.da_433  sr.bs.lt_521 crs.ht.da_432 
  0x38001b29, 0x48303704, 0x56004307, 0x52000607,   // tr.tk.un_960 ba.uz.tt_332  ie.mg.un_420 de.ha.un_420 
  0x1b033f05, 0x3e3504ee, 0x5a581f07, 0x482530ad,   // af.nl.tr_333 fi.zu.rm_422  cy.om.sm_432 uz.mn.tt_643 
  0x1b065707, 0x641a5008, 0x353048ec, 0x270165a0,   // na.de.tr_432 fj.tl.lg_443  tt.uz.tg_644 gv.en.gd_322 
  // [12190]
  0x551225a9, 0x150a1105, 0x5c681207, 0x525c76ee,   // eu.hu.rw_544 ro.mk.un_333  hu.ig.sa_432 crs.sa.ha_422 
  0x5c1247a0, 0x79730205, 0x765c53a4, 0x6b1a600c,   // sn.hu.sa_322 da.ny.war_333  ht.sa.crs_433 vo.tl.ceb_543 
  0x1b023809, 0x0206040d, 0x3704480c, 0x07150a0c,   // tk.da.tr_444 fi.de.da_554  tt.ru.ba_543 mk.bg.un_530 
  0x08001d04, 0x0400fe05, 0x0c4c3704, 0x330e2a0c,   // la.no.un_320 tlh.fi.un_330  st.wo.sv_332 mt.is.nn_543 
  // [121a0]
  0x1b000b05, 0x3d002111, 0x17003c07, 0x0d135c0c,   // es.tr.un_330 fa.ku.un_630  ug.sr.un_420 sa.bh.ne_543 
  0x08441704, 0x290d17a9, 0x38003605, 0x061279a0,   // sr.kk.uk_332 sr.cs.sl_544  gn.tk.un_330 war.hu.de_322 
  0x0800360b, 0x53007613, 0x0e00100b, 0xfe4746a9,   // ab.uk.un_520 crs.ht.un_650  lt.is.un_520 qu.sn.tlh_544 
  0x603848a4, 0x33003909, 0x76001511, 0xfe0b470e,   // tt.tk.vo_433 br.nn.un_440  un.crs.un_630 sn.es.tlh_555 
  // [121b0]
  0x18fe27ec, 0x5302fc55, 0x4203fead, 0x05126307,   // gd.tlh.ga_644 zzp.da.ht_442  tlh.nl.co_643 sco.hu.fr_432 
  0x620206a4, 0x36420b55, 0xfe00030e, 0x092d0da4,   // de.da.kha_433 es.co.gn_442  nl.tlh.un_550 cs.sk.pl_433 
  0x641d5007, 0x28000c04, 0xfe000213, 0x5a004b1a,   // fj.la.lg_432 sv.sw.un_320  da.tlh.un_650 mi.sm.un_760 
  0x2c001004, 0x28213b14, 0x123b28a4, 0xfe470908,   // lt.fy.un_320 ks.fa.sd_666  sd.ks.ur_433 pl.sn.tlh_443 
  // [121c0]
  0xfe000612, 0x09fe460c, 0xfe00462b, 0x6800060d,   // de.tlh.un_640 qu.tlh.pl_543  qu.tlh.un_980 de.ig.un_540 
  0x014851a7, 0x27002208, 0x192223ee, 0x21183013,   // kl.tt.en_532 oc.gd.un_430  ca.oc.gl_422 uz.ar.fa_665 
  0x0a170813, 0x211823a7, 0x03002e08, 0x100f1704,   // uk.sr.mk_665 ky.ar.fa_532  fo.nl.un_430 sr.lv.lt_332 
  0x2b00020e, 0x46000308, 0x072504a0, 0x21003b12,   // da.vi.un_550 nl.qu.un_430  ru.mn.bg_322 ks.fa.un_640 
  // [121d0]
  0x0d2e0ea0, 0x3c1228a7, 0x17100804, 0x13095c02,   // is.fo.cs_322 sd.ur.ug_532  uk.be.sr_332 sa.hi.bh_222 
  0x224f2ba9, 0x3b3d2105, 0x13002205, 0x200d0902,   // vi.bi.oc_544 fa.ku.ks_333  oc.et.un_330 pl.cs.sq_222 
  0x36003712, 0x041508a7, 0x103704ad, 0x354043ee,   // ba.ab.un_640 uk.ru.un_520  ru.ba.be_643 ie.lb.zu_422 
  0x0a004c04, 0x63024da9, 0xfc002e0d, 0x401312ad,   // wo.pt.un_320 aa.da.sco_544  fo.zzp.un_540 hu.et.lb_643 
  // [121e0]
  0x0c002407, 0x655803a0, 0x303515a7, 0x2b001c09,   // eo.sv.un_420 nl.om.gv_322  un.tg.uz_532 id.vi.un_440 
  0x052234ec, 0x024d3baf, 0x37002809, 0x28002109,   // xh.oc.fr_644 so.aa.da_655  sw.st.un_440 fa.sd.un_440 
  0x4c5a2807, 0x071015ad, 0x1b3824a0, 0x3c003d0c,   // sw.sm.wo_432 un.be.bg_643  eo.tk.tr_322 ku.ug.un_530 
  0x3138130c, 0x05006011, 0x171008a9, 0x10440860,   // et.tk.az_543 vo.fr.un_630  uk.be.sr_544 uk.kk.be_664 
  // [121f0]
  0x483c30a0, 0x4a2e0e08, 0x10153807, 0x1f001d0d,   // uz.ug.tt_322 is.fo.yo_443  tk.be.un_420 la.cy.un_540 
  0x05003907, 0x57fc0108, 0x25003905, 0x4b00490c,   // br.fr.un_420 en.zzp.na_443  br.eu.un_330 to.mi.un_530 
  0x0d131c08, 0x5a003908, 0x3f000802, 0x31004811,   // mr.bh.ne_443 br.sm.un_430  no.af.un_220 tt.az.un_630 
  0x3c00340d, 0x27004e09, 0x0a151012, 0x18046505,   // ps.ug.un_540 ay.gd.un_440  be.mk.un_640 gv.fi.ga_333 
  // [12200]
  0x64001507, 0x04006513, 0x06006505, 0x34212805,   // un.lg.un_420 gv.fi.un_650  gv.de.un_330 sd.fa.ps_333 
  0x04651807, 0x04353005, 0x2e0c6511, 0x3e002704,   // ga.gv.fi_432 uz.tg.ru_333  gv.sv.fo_653 gd.rm.un_320 
  0x3d1828a9, 0x0a15040b, 0x1c091310, 0x36004814,   // sd.ar.ku_544 ru.mk.un_520  bh.hi.mr_642 tt.ab.un_660 
  0x17001608, 0x2b001305, 0x052315a0, 0x081738a4,   // hr.sr.un_430 et.vi.un_330  un.ca.fr_322 tk.sr.uk_433 
  // [12210]
  0x08021502, 0x496a5ea4, 0x6411fea9, 0x42491c04,   // un.da.no_222 ts.haw.to_433  tlh.ro.lg_544 id.to.co_332 
  0x496a5a0c, 0x2c6a0411, 0x1a6b110c, 0x154438ad,   // sm.haw.to_543 fi.haw.fy_653  ro.ceb.tl_543 tk.kk.un_643 
  0x342535a9, 0x502f48a4, 0x42211107, 0x4d004214,   // zu.eu.xh_544 tt.su.fj_433  ro.jw.co_432 co.aa.un_660 
  0x2f112108, 0x5a786409, 0x49455aa9, 0x3400370d,   // jw.ro.su_443 lg.ve.sm_444  sm.ln.to_544 st.xh.un_540 
  // [12220]
  0x25111d0c, 0x30213413, 0x0f5a5007, 0x641b31ad,   // la.ro.eu_543 ps.fa.uz_665  fj.sm.lv_432 az.tr.lg_643 
  0x11003413, 0x7311420c, 0x0d002e12, 0x64735d05,   // xh.ro.un_650 co.ro.ny_543  fo.cs.un_640 ss.ny.lg_333 
  0x36134812, 0x1d00340d, 0x311b1112, 0x11005e12,   // tt.et.gn_654 xh.la.un_540  ro.tr.az_654 ts.ro.un_640 
  0x1d190aee, 0x11003705, 0x4812310b, 0x313534ad,   // pt.gl.la_422 st.ro.un_330  az.hu.tt_542 xh.zu.az_643 
  // [12230]
  0x3d2112ad, 0x19006307, 0x013e670c, 0x2500790c,   // ur.fa.ku_643 sco.gl.un_420  ak.rm.en_543 war.eu.un_530 
  0x20003507, 0x38153713, 0x68004309, 0x68184704,   // zu.sq.un_420 ba.tk.un_650  ie.ig.un_440 sn.ga.ig_332 
  0x1f182707, 0x32155ca4, 0x55000704, 0x03160ea0,   // gd.ga.cy_432 sa.bs.un_430  it.rw.un_320 is.hr.nl_322 
  0x11001f05, 0x44230402, 0x2c0524ee, 0x3c3421a0,   // cy.ro.un_330 ru.ky.kk_222  eo.fr.fy_422 fa.ps.ug_322 
  // [12240]
  0x1e3775ee, 0x25003821, 0x1228300c, 0xfe47785a,   // nso.st.ms_422 tk.mn.un_860  uz.sd.ur_543 ve.sn.tlh_553 
  0x1f004707, 0x02006021, 0x1b214805, 0x081015a0,   // sn.cy.un_420 vo.da.un_860  tt.jw.tr_333 un.be.uk_322 
  0x5a6047a9, 0x2a11fe0b, 0x7356520c, 0x35302512,   // sn.vo.sm_544 tlh.ro.mt_542  ha.mg.ny_543 mn.uz.tg_654 
  0x10005804, 0x316b7908, 0x100f60a4, 0x656333a4,   // om.lt.un_320 war.ceb.az_443  vo.lv.lt_433 nn.sco.gv_433 
  // [12250]
  0x08004f08, 0x56495a04, 0x553834a0, 0x606b290c,   // bi.no.un_430 sm.to.mg_332  xh.tk.rw_322 sl.ceb.vo_543 
  0x033f2102, 0x4f003913, 0x09114804, 0x223b5008,   // jw.af.nl_222 br.bi.un_650  tt.ro.pl_332 fj.so.oc_443 
  0x25003e13, 0x252847a4, 0x04fc28ee, 0x566050a4,   // rm.eu.un_650 sn.sw.eu_433  sw.zzp.fi_422 fj.vo.mg_433 
  0x2f736b04, 0x58502508, 0x10003202, 0x0200510c,   // ceb.ny.su_332 eu.fj.om_443  bs.lt.un_220 kl.da.un_530 
  // [12260]
  0x2e020860, 0x37443607, 0x4800461b, 0x07250a05,   // no.da.fo_664 ab.kk.ba_432  qu.tt.un_770 mk.mn.bg_333 
  0x51000202, 0x2bfe4607, 0x4c007908, 0x442548a0,   // da.kl.un_220 qu.tlh.vi_432  war.wo.un_430 tt.mn.kk_322 
  0x024d1d05, 0x04231507, 0x463130a9, 0x31483012,   // la.aa.da_333 un.ky.ru_432  uz.az.qu_544 uz.tt.az_654 
  0x4c313b12, 0x634e46ad, 0x31003b08, 0x37044804,   // so.az.wo_654 qu.ay.sco_643  so.az.un_430 tt.ru.ba_332 
  // [12270]
  0x31004307, 0x0a3704a7, 0x122830ad, 0x111d5dee,   // ie.az.un_420 ru.ba.mk_532  uz.sd.ur_643 ss.la.ro_422 
  0x44041508, 0x22420da0, 0x2b005b22, 0x112601a4,   // un.ru.kk_443 cs.co.oc_322  sg.vi.un_870 en.ia.ro_433 
  0x170a3cee, 0x195d52a0, 0x482311ad, 0x122e18a4,   // ug.mk.sr_422 ha.ss.gl_322  ro.ky.tt_643 ga.fo.hu_433 
  0x4a12180c, 0x15004813, 0x040811a7, 0x35440402,   // ga.hu.yo_543 tt.un.un_650  ro.uk.ru_532 ru.kk.tg_222 
  // [12280]
  0x35232511, 0x23003808, 0x3c374812, 0x30342160,   // mn.ky.tg_653 tk.ky.un_430  tt.ba.ug_654 fa.ps.uz_664 
  0x23431812, 0x2d001813, 0x174410a0, 0x495253a4,   // ga.ie.ca_654 ga.sk.un_650  be.kk.sr_322 ht.ha.to_433 
  0x28352702, 0x4a187302, 0x0a29690c, 0x3421125a,   // gd.zu.sw_222 ny.ga.yo_222  mfe.sl.pt_543 ur.fa.ps_553 
  0x506b42a9, 0x2f112007, 0x35285d07, 0x20102aee,   // co.ceb.fj_544 sq.ro.su_432  ss.sw.zu_432 mt.lt.sq_422 
  // [12290]
  0x01006004, 0x51002a04, 0x301036ad, 0x1364510c,   // vo.en.un_320 mt.kl.un_320  ab.be.uz_643 kl.lg.et_543 
  0x2a001d0c, 0x12001308, 0x0c1208a4, 0x63004304,   // la.mt.un_530 et.hu.un_430  no.hu.sv_433 ie.sco.un_320 
  0x36006304, 0x42003605, 0x131220a4, 0x2a004d12,   // sco.gn.un_320 gn.co.un_330  sq.hu.et_433 aa.mt.un_640 
  0x374946a0, 0x38301ca0, 0x0f002a12, 0x35312aa0,   // qu.to.st_322 id.uz.tk_322  mt.lv.un_640 mt.az.zu_322 
  // [122a0]
  0x42001104, 0x53001602, 0x3f2e0308, 0x44371505,   // ro.co.un_320 hr.ht.un_220  nl.fo.af_443 un.ba.kk_333 
  0x04180ea4, 0x30002e0b, 0x130c1012, 0x0e2e79a0,   // is.ga.fi_433 fo.uz.un_520  lt.sv.et_654 war.fo.is_322 
  0x1d05fca4, 0x132f2a04, 0x13091c11, 0x01004902,   // zzp.fr.la_433 mt.su.et_332  mr.hi.bh_653 to.en.un_220 
  0x04000e05, 0x032e3f14, 0x044838a7, 0x1025150e,   // is.fi.un_330 af.fo.nl_666  tk.tt.ru_532 un.mn.be_555 
  // [122b0]
  0x2e100ead, 0x24004308, 0x032a3e07, 0x07304404,   // is.lt.fo_643 ie.eo.un_430  rm.mt.nl_432 kk.uz.bg_332 
  0x0408170c, 0x6e3534ec, 0x3b6518a4, 0x0e1227a9,   // sr.uk.ru_543 xh.zu.hmn_644  ga.gv.so_433 gd.hu.is_544 
  0x24006e07, 0x17162d02, 0x0a171505, 0x3b656213,   // hmn.eo.un_420 sk.hr.sr_222  un.sr.mk_333 kha.gv.so_665 
  0x67006913, 0x1b0446a4, 0x520446a7, 0x17041111,   // mfe.ak.un_650 qu.fi.tr_433  qu.fi.ha_532 ro.ru.sr_653 
  // [122c0]
  0x5cfc30a4, 0x062b0302, 0x02005208, 0x1546fca0,   // uz.zzp.sa_433 nl.vi.de_222  ha.da.un_430 zzp.qu.un_322 
  0x48000e02, 0x2e080204, 0x1b31460c, 0x2b000602,   // is.tt.un_220 da.no.fo_332  qu.az.tr_543 de.vi.un_220 
  0x42fe5cee, 0x52004619, 0x0231210c, 0x32171102,   // sa.tlh.co_422 qu.ha.un_750  jw.az.da_543 ro.sr.bs_222 
  0x21233c0b, 0x101716ac, 0x482504a0, 0x10004413,   // ug.ky.fa_542 hr.sr.lt_632  ru.mn.tt_322 kk.be.un_650 
  // [122d0]
  0x083604a4, 0x17360a07, 0x28004712, 0x2000361a,   // ru.ab.uk_433 mk.ab.sr_432  sn.sw.un_640 gn.sq.un_760 
  0x10003005, 0x0a173808, 0x09002a14, 0x300a1705,   // uz.be.un_330 tk.sr.mk_443  mt.pl.un_660 sr.mk.uz_333 
  0x23100808, 0x092d0dad, 0x36301104, 0x182344a4,   // uk.be.ky_443 cs.sk.pl_643  ro.uz.ab_332 kk.ky.ar_433 
  0x111544af, 0x6b3549a0, 0x5f736412, 0x2f1c03a4,   // kk.ro.un_650 to.zu.ceb_322  lg.ny.tn_654 nl.id.su_433 
  // [122e0]
  0x47fc6208, 0x79494608, 0x36353012, 0x330851a4,   // kha.zzp.sn_443 qu.to.war_443  uz.tg.ab_654 kl.no.nn_433 
  0x0c080214, 0x1025380e, 0x2d3302a0, 0x351d7312,   // da.no.sv_666 tk.mn.be_555  da.nn.sk_322 ny.la.zu_654 
  0x0c061207, 0x361d0f55, 0x4c005213, 0x5a000404,   // hu.de.sv_432 lv.la.gn_442  ha.wo.un_650 fi.sm.un_320 
  0x49003204, 0x122903a0, 0x080252a0, 0x68285c09,   // bs.to.un_320 nl.sl.hu_322  ha.da.no_322 sa.sw.ig_444 
  // [122f0]
  0x53220507, 0x403f4704, 0x35fa3655, 0x08020da9,   // fr.oc.ht_432 sn.af.lb_332  gn.nr.zu_442 cs.da.no_544 
  0x042d0faf, 0x5f007305, 0x2004360c, 0x1d004319,   // lv.sk.fi_655 ny.tn.un_330  gn.fi.sq_543 ie.la.un_750 
  0x251a01a4, 0x65631d07, 0x123f47a0, 0x0f172004,   // en.tl.eu_433 la.sco.gv_432  sn.af.hu_322 sq.sr.lv_332 
  0x11232212, 0x2a0413a7, 0xfe002918, 0x04552fee,   // oc.ca.ro_654 et.fi.mt_532  sl.tlh.un_740 su.rw.fi_422 
  // [12300]
  0x12006504, 0x4c3b190c, 0x4e2f21a4, 0x17150804,   // gv.hu.un_320 gl.so.wo_543  jw.su.ay_433 uk.sr.un_320 
  0x03404607, 0x28042da0, 0x032433a0, 0x4d514e07,   // qu.lb.nl_432 sk.fi.sw_322  nn.eo.nl_322 ay.kl.aa_432 
  0x5f000a05, 0x2d001807, 0x443c37ec, 0x05001505,   // pt.tn.un_330 ga.sk.un_420  ba.ug.kk_644 un.fr.un_330 
  0x180e2dad, 0x122d0e0c, 0x132f0102, 0x25004d12,   // sk.is.ga_643 is.sk.hu_543  en.su.et_222 aa.eu.un_640 
  // [12310]
  0x093b3404, 0x19341d04, 0x0b121807, 0x313b4d12,   // xh.so.pl_332 la.xh.gl_332  ga.hu.es_432 aa.so.az_654 
  0x32000a02, 0x0d005d04, 0x25004d21, 0x0a304805,   // pt.bs.un_220 ss.cs.un_320  aa.eu.un_860 tt.uz.mk_333 
  0x34003109, 0x44183bec, 0x154435a7, 0x483b1d0c,   // az.xh.un_440 ks.ar.kk_644  tg.kk.un_532 la.so.tt_543 
  0x0b0c5755, 0x58004808, 0x11003e08, 0x5c000a02,   // na.sv.es_442 tt.om.un_430  rm.ro.un_430 pt.sa.un_220 
  // [12320]
  0x12003518, 0xfc240e0d, 0x190a23ee, 0x182123ee,   // tg.ur.un_740 is.eo.zzp_554  ca.pt.gl_422 ky.fa.ar_422 
  0x08251704, 0x364d5711, 0x42002004, 0x0704380c,   // sr.mn.uk_332 na.aa.gn_653  sq.co.un_320 tk.ru.bg_543 
  0x2b005605, 0x091c0d0e, 0x351730a4, 0x0900121b,   // mg.vi.un_330 ne.mr.hi_555  uz.sr.tg_433 hu.pl.un_770 
  0x20002109, 0x05001807, 0x2d002105, 0x353830a4,   // jw.sq.un_440 ga.fr.un_420  jw.sk.un_330 uz.tk.tg_433 
  // [12330]
  0x396502a0, 0x1d250204, 0x36180904, 0x0e2e3305,   // da.gv.br_322 da.eu.la_332  pl.ga.gn_332 nn.fo.is_333 
  0x3e00420b, 0x1008445a, 0xfe000205, 0x4a005718,   // co.rm.un_520 kk.uk.be_553  da.tlh.un_330 na.yo.un_740 
  0x2d214c08, 0x4c254dad, 0x21002d11, 0x28003d1a,   // wo.jw.sk_443 aa.eu.wo_643  sk.jw.un_630 ku.sd.un_760 
  0x5d5223a0, 0x284d57a4, 0x02671fa7, 0x65001605,   // ca.ha.ss_322 na.aa.sw_433  cy.ak.da_532 hr.gv.un_330 
  // [12340]
  0x063357a7, 0x0c40060c, 0x36070a0c, 0x230811a7,   // na.nn.de_532 de.lb.sv_543  mk.bg.ab_543 ro.uk.ky_532 
  0x38000a16, 0x38004e0e, 0xfc002204, 0x22002323,   // pt.tk.un_720 ay.tk.un_550  oc.zzp.un_320 ca.oc.un_880 
  0x09006818, 0x404c06ad, 0x34400607, 0x1b000611,   // ig.pl.un_740 de.wo.lb_643  de.lb.xh_432 de.tr.un_630 
  0x10040809, 0x370438ee, 0x65631d0d, 0x153c30a4,   // uk.ru.be_444 tk.ru.ba_422  la.sco.gv_554 uz.ug.un_433 
  // [12350]
  0x35513404, 0x3815250c, 0x27004c0d, 0x1800011b,   // xh.kl.zu_332 mn.tk.un_530  wo.gd.un_540 iw.ar.un_770 
  0x3b34120c, 0x2f001104, 0x3c07110d, 0x2834180d,   // ur.ps.ks_543 ro.su.un_320  ro.bg.ug_554 ar.ps.sd_554 
  0x35483455, 0x130d1c5a, 0x0b4a2d07, 0x151511ad,   // xh.tt.zu_442 mr.ne.bh_553  sk.yo.es_432 ro.un.un_630 
  0x3e00fc02, 0x10003609, 0x42000d0d, 0x420d2d10,   // zzp.rm.un_220 ab.be.un_440  cs.co.un_540 sk.cs.co_642 
  // [12360]
  0x23483704, 0x38001119, 0x21283b08, 0x123d34ac,   // ba.tt.ky_332 ro.tk.un_750  ks.sd.fa_443 ps.ku.ur_632 
  0x1e1d3b07, 0x19120b12, 0x27203b5a, 0x44182360,   // so.la.ms_432 es.hu.gl_654  so.sq.gd_553 ky.ar.kk_664 
  0x251523ec, 0xfe001834, 0x09003605, 0xfc001004,   // ky.mn.un_640 ga.tlh.un_A80  gn.pl.un_330 lt.zzp.un_320 
  0x20fc0204, 0x2028655a, 0x44150808, 0x1844230b,   // da.zzp.sq_332 gv.sw.sq_553  uk.kk.un_430 ky.kk.ar_542 
  // [12370]
  0x090d1c02, 0x34213009, 0x10234404, 0x15000a22,   // mr.ne.hi_222 uz.fa.ps_444  kk.ky.be_332 mk.un.un_870 
  0x233c440d, 0x223e0107, 0x1800600d, 0x372344a7,   // kk.ug.ky_554 en.rm.oc_432  vo.ga.un_540 kk.ky.ba_532 
  0x48002707, 0x0e0b0a04, 0x10004604, 0x0410480b,   // gd.tt.un_420 pt.es.is_332  qu.lt.un_320 tt.be.ru_542 
  0x190e2e0b, 0x0d1c3b07, 0x34001e04, 0x17005308,   // fo.is.gl_542 ks.mr.ne_432  ms.xh.un_320 ht.sr.un_430 
  // [12380]
  0x3530150b, 0x0a000207, 0x0a180e04, 0x30233c07,   // un.uz.tg_542 da.pt.un_420  is.ga.pt_332 ug.ky.uz_432 
  0x3b2d2e02, 0x2e0e1804, 0x44001111, 0x50005d02,   // fo.sk.so_222 ga.is.fo_332  ro.kk.un_630 ss.fj.un_220 
  0x65025504, 0x3f00560d, 0x35524512, 0x2e0e3007,   // rw.da.gv_332 mg.af.un_540  ln.ha.zu_654 uz.is.fo_432 
  0x0a430ea7, 0x375f73af, 0x0e765d0c, 0xfc4958ee,   // is.ie.pt_532 ny.tn.st_655  ss.crs.is_543 om.to.zzp_422 
  // [12390]
  0x34563512, 0x42345da0, 0x550264af, 0x3c1834ee,   // zu.mg.xh_654 ss.xh.co_322  lg.da.rw_655 ps.ar.ug_422 
  0x08022ea4, 0x17302907, 0x2a2e2912, 0x375d4508,   // fo.da.no_433 sl.uz.sr_432  sl.fo.mt_654 ln.ss.st_443 
  0x270907a0, 0x35456412, 0x4c375f04, 0x55005712,   // it.pl.gd_322 lg.ln.zu_654  tn.st.wo_332 na.rw.un_640 
  0x593573a9, 0x15004405, 0x1b433907, 0x35007313,   // ny.zu.rn_544 kk.un.un_330  br.ie.tr_432 ny.zu.un_650 
  // [123a0]
  0x3e000709, 0x321673a0, 0xfc345da0, 0x67003513,   // it.rm.un_440 ny.hr.bs_322  ss.xh.zzp_322 zu.ak.un_650 
  0x495a28ec, 0x09003908, 0x08003509, 0x544e1b0c,   // sw.sm.to_644 br.pl.un_430  tg.uk.un_440 tr.ay.ik_543 
  0x1e035cee, 0x10070aee, 0x0a360704, 0x541b200c,   // sa.nl.ms_422 mk.bg.be_422  bg.ab.mk_332 sq.tr.ik_543 
  0x44040702, 0x080c5307, 0x120c54ee, 0x304823a7,   // bg.ru.kk_222 ht.sv.no_432  ik.sv.hu_422 ky.tt.uz_532 
  // [123b0]
  0x20001b21, 0xfc00540c, 0x244e100c, 0x48003609,   // tr.sq.un_860 ik.zzp.un_530  lt.ay.eo_543 ab.tt.un_440 
  0x290d0904, 0x4d005c05, 0x20003409, 0x28006514,   // pl.cs.sl_332 sa.aa.un_330  xh.sq.un_440 gv.sw.un_660 
  0x5000280c, 0x104328a7, 0x0e2e3312, 0x73493eec,   // sw.fj.un_530 sw.ie.lt_532  nn.fo.is_654 rm.to.ny_644 
  0x1a4e54a4, 0x09005102, 0x3e400655, 0x11422fee,   // ik.ay.tl_433 kl.pl.un_220  de.lb.rm_442 su.co.ro_422 
  // [123c0]
  0x65211c07, 0x18343dec, 0x0e4e2e04, 0x47003202,   // id.jw.gv_432 ku.ps.ar_644  fo.ay.is_332 bs.sn.un_220 
  0x07006b21, 0x0f1054ec, 0x283e73a7, 0x10060e55,   // ceb.it.un_860 ik.lt.lv_644  ny.rm.sw_532 is.de.lt_442 
  0x123217a7, 0x35003418, 0x373c485a, 0x330e2e07,   // sr.bs.hu_532 xh.zu.un_740  tt.ug.ba_553 fo.is.nn_432 
  0x482429a0, 0x18000612, 0x17001b05, 0x422f0705,   // sl.eo.tt_322 de.ga.un_640  tr.sr.un_330 it.su.co_333 
  // [123d0]
  0x1000512a, 0x2f3e51a9, 0x2f106b05, 0x09401255,   // kl.lt.un_970 kl.rm.su_544  ceb.lt.su_333 hu.lb.pl_442 
  0x213d30a9, 0x1b007308, 0x233015ad, 0x1536150c,   // uz.ku.fa_544 ny.tr.un_430  un.uz.ky_643 un.ab.un_543 
  0x0a362508, 0x0a1517ee, 0x20000907, 0x00000937,   // mn.ab.mk_443 sr.mk.un_420  pl.sq.un_420 hi.un.un_B00 
  0x2a306ea4, 0x21343d05, 0x25003822, 0x0408170b,   // hmn.uz.mt_433 ku.ps.fa_333  tk.mn.un_870 sr.uk.ru_542 
  // [123e0]
  0x04083708, 0x44000709, 0x04100a0c, 0x782a50ad,   // ba.uk.ru_443 bg.kk.un_440  mk.be.ru_543 fj.mt.ve_643 
  0x5478510d, 0x73002008, 0x022e500c, 0x342e20a4,   // kl.ve.ik_554 sq.ny.un_430  fj.fo.da_543 sq.fo.xh_433 
  0x605828a6, 0x44183caf, 0x38285312, 0x287354ec,   // sw.om.vo_521 ug.ar.kk_655  ht.sw.tk_654 ik.ny.sw_644 
  0x1d3e06ee, 0x28782e55, 0x183c4405, 0x7300341a,   // de.rm.la_422 fo.ve.sw_442  kk.ug.ar_333 xh.ny.un_760 
  // [123f0]
  0x452e500c, 0x04005105, 0x2e4551a7, 0x49466aec,   // fj.fo.ln_543 kl.fi.un_330  kl.ln.fo_532 haw.qu.to_644 
  0x30204608, 0x1b313809, 0x12092d08, 0x32001e02,   // qu.sq.uz_443 tk.az.tr_444  sk.pl.hu_443 ms.bs.un_220 
  0x13000f02, 0x4f4501a4, 0x16002909, 0x4811445a,   // lv.et.un_220 en.ln.bi_433  sl.hr.un_440 kk.ro.tt_553 
  0x6953765a, 0x1a276b07, 0x2a0b10ee, 0x04691004,   // crs.ht.mfe_553 ceb.gd.tl_432  lt.es.mt_422 lt.mfe.fi_332 
  
  // [12400]
  0x2500101b, 0x761606a7, 0x190b0aa6, 0x28000108,   // be.mn.un_770 de.hr.crs_532  pt.es.gl_521 en.sw.un_430 
  0x32102d07, 0x0c001214, 0x1d100204, 0x50004504,   // sk.lt.bs_432 hu.sv.un_660  da.lt.la_332 ln.fj.un_320 
  0x0a004a05, 0x0b3f5a02, 0x48003734, 0x06135705,   // yo.pt.un_330 sm.af.es_222  ba.tt.un_A80 na.et.de_333 
  0x21233d07, 0x27001811, 0x4500670e, 0x03fc4007,   // ku.ky.fa_432 ga.gd.un_630  ak.ln.un_550 lb.zzp.nl_432 
  // [12410]
  0x69064a08, 0x2f002302, 0x23421105, 0x1f22050c,   // yo.de.mfe_443 ca.su.un_220  ro.co.ca_333 fr.oc.cy_543 
  0x287873ad, 0x305107ee, 0x0a00040b, 0x353442a4,   // ny.ve.sw_643 it.kl.uz_422  fi.pt.un_520 co.xh.zu_433 
  0x081707a4, 0x3efc0605, 0x42080ca0, 0x323029a7,   // bg.sr.uk_433 de.zzp.rm_333  sv.no.co_322 sl.uz.bs_532 
  0x234412a0, 0x0d293007, 0x25152305, 0x08104405,   // ur.kk.ky_322 uz.sl.cs_432  ky.mn.un_330 kk.be.uk_333 
  // [12420]
  0x21002002, 0x46001512, 0xfe4736a0, 0x190a36a4,   // sq.jw.un_220 un.qu.un_640  gn.sn.tlh_322 gn.pt.gl_433 
  0x55006805, 0x68001d0d, 0x36004a19, 0x150a1108,   // ig.rw.un_330 la.ig.un_540  yo.gn.un_750 ro.mk.un_443 
  0x475e2b60, 0x2f475912, 0x3b5c6504, 0x554b7805,   // vi.ts.sn_664 rn.sn.su_654  gv.sa.so_332 ve.mi.rw_333 
  0x342718ad, 0x05006502, 0x272b460d, 0x3b36fe04,   // ga.gd.xh_643 gv.fr.un_220  qu.vi.gd_554 tlh.gn.so_332 
  // [12430]
  0x5827200c, 0x310e79ad, 0x364725ad, 0x1c135c14,   // sq.gd.om_543 war.is.az_643  eu.sn.gn_643 sa.bh.mr_666 
  0x382325a7, 0x31584da7, 0x460230ac, 0x37734e0c,   // mn.ky.tk_532 aa.om.az_532  uz.da.qu_632 ay.ny.st_543 
  0x621801a0, 0x554b59a4, 0x2e303108, 0x6379010c,   // en.ga.kha_322 rn.mi.rw_433  az.uz.fo_443 en.war.sco_543 
  0x27180107, 0x576201a4, 0x631f1860, 0x5e5f73a0,   // en.ga.gd_432 en.kha.na_433  ga.cy.sco_664 ny.tn.ts_322 
  // [12440]
  0x2300171b, 0x1b3112a0, 0x47001504, 0x1d0c03ee,   // sr.ky.un_770 hu.az.tr_322  un.sn.un_320 nl.sv.la_422 
  0x63421f07, 0x65620107, 0x1d6301a4, 0x1d6369a4,   // cy.co.sco_432 en.kha.gv_432  en.sco.la_433 mfe.sco.la_433 
  0x36000e0d, 0x233048ec, 0x061312a4, 0x06381ba0,   // is.gn.un_540 tt.uz.ky_644  hu.et.de_433 tr.tk.de_322 
  0x45030507, 0x052b3ea9, 0x55006418, 0x793e2fad,   // fr.nl.ln_432 rm.vi.fr_544  lg.rw.un_740 su.rm.war_643 
  // [12450]
  0x1035305a, 0x47fe730c, 0x4200230b, 0x032c12ee,   // uz.tg.be_553 ny.tlh.sn_543  ca.co.un_520 hu.fy.nl_422 
  0x23003e0e, 0x2b3e22a7, 0x3e652205, 0x06001b0b,   // rm.ca.un_550 oc.rm.vi_532  oc.gv.rm_333 tr.de.un_520 
  0x057907a4, 0x05223e07, 0x2d00fe0e, 0x562e4904,   // it.war.fr_433 rm.oc.fr_432  tlh.sk.un_550 to.fo.mg_332 
  0x79552a14, 0x57006422, 0x422f3eec, 0x28004002,   // mt.rw.war_666 lg.na.un_870  rm.su.co_644 lb.sw.un_220 
  // [12460]
  0x1d01260c, 0x08023ea4, 0x04361007, 0x3810150c,   // ia.en.la_543 rm.da.no_433  be.ab.ru_432 un.be.tk_543 
  0x0624fc07, 0x586b790c, 0x640254ee, 0x463b02a7,   // zzp.eo.de_432 war.ceb.om_543  ik.da.lg_422 da.so.qu_532 
  0x343d230c, 0x64284607, 0x2e1729ee, 0xfc0e33a4,   // ky.ku.ps_543 qu.sw.lg_432  sl.sr.fo_422 nn.is.zzp_433 
  0x1c2159a7, 0x2100fc14, 0x42004a07, 0x55003004,   // rn.jw.id_532 zzp.jw.un_660  yo.co.un_420 uz.rw.un_320 
  // [12470]
  0x352034af, 0x531e56ee, 0x030102a4, 0x0e290f0c,   // xh.sq.zu_655 mg.ms.ht_422  da.en.nl_433 lv.sl.is_543 
  0x58193407, 0x292f1eec, 0x1359360c, 0x3b460207,   // xh.gl.om_432 ms.su.sl_644  gn.rn.et_543 da.qu.so_432 
  0x58290bee, 0x1a6979ec, 0x29171609, 0x2a001904,   // es.sl.om_422 war.mfe.tl_644  hr.sr.sl_444 gl.mt.un_320 
  0x622154ad, 0x2a352007, 0x12005602, 0x076525a0,   // ik.jw.kha_643 sq.zu.mt_432  mg.hu.un_220 eu.gv.it_322 
  // [12480]
  0x1e1c04ee, 0x58fe3bad, 0x461c5507, 0x19001d19,   // fi.id.ms_422 so.tlh.om_643  rw.id.qu_432 la.gl.un_750 
  0x1a465ea0, 0x303515ee, 0x0b605814, 0x3900070b,   // ts.qu.tl_322 un.tg.uz_422  om.vo.es_666 it.br.un_520 
  0x52301bee, 0x3568640c, 0x0f002e08, 0x1c095eee,   // tr.uz.ha_422 lg.ig.zu_543  fo.lv.un_430 ts.pl.id_422 
  0x48003408, 0x40152da0, 0x1d001913, 0x07003304,   // xh.tt.un_430 sk.lb.un_320  gl.la.un_650 nn.it.un_320 
  // [12490]
  0xfe00580c, 0x040f46ee, 0x19005e04, 0x354815ad,   // om.tlh.un_530 qu.lv.fi_422  ts.gl.un_320 un.tt.tg_643 
  0x7618060d, 0x20002e02, 0x18051108, 0x0a23360c,   // de.ga.crs_554 fo.sq.un_220  ro.fr.ga_443 ab.ky.mk_543 
  0x260b0a09, 0x6b330804, 0x1000fc02, 0x39002a33,   // pt.es.ia_444 no.nn.ceb_332  zzp.lt.un_220 bo.dz.un_A70 
  0x2b00180c, 0x58561f13, 0x152b0255, 0x4c4a6007,   // ga.vi.un_530 cy.mg.om_665  da.vi.un_442 vo.yo.wo_432 
  // [124a0]
  0x5e495aec, 0x0d001a04, 0x6976580c, 0x25601e07,   // sm.to.ts_644 tl.cs.un_320  om.crs.mfe_543 ms.vo.eu_432 
  0x022218a7, 0x181127af, 0x2e0e02ec, 0x3b274d05,   // ga.oc.da_532 gd.ro.ga_655  da.is.fo_644 aa.gd.so_333 
  0x1f394c0c, 0x25151055, 0x01154307, 0x1f525a05,   // wo.br.cy_543 be.mn.un_420  ie.en.un_420 sm.ha.cy_333 
  0x48233ba0, 0x3b4c01a0, 0x60242004, 0x00004d37,   // so.ca.tt_322 en.wo.so_322  sq.eo.vo_332 aa.un.un_B00 
  // [124b0]
  0x48475ea4, 0x22001808, 0x1b003e02, 0x5548280c,   // ts.sn.tt_433 ga.oc.un_430  rm.tr.un_220 sw.tt.rw_543 
  0x18005a07, 0x02fe4dec, 0x4d002f0d, 0x1e1c4da9,   // sm.ga.un_420 aa.tlh.da_644  su.aa.un_540 aa.id.ms_544 
  0xfe216212, 0x171115af, 0x2f006209, 0x4d2f62ad,   // kha.jw.tlh_654 un.ro.sr_655  kha.su.un_440 kha.su.aa_643 
  0x2304070c, 0x61002f14, 0x2a4d610d, 0x2f611ea4,   // bg.ru.ky_543 su.za.un_660  za.aa.mt_554 ms.za.su_433 
  // [124c0]
  0x52284da0, 0x30372302, 0x4d002109, 0x27002a04,   // aa.sw.ha_322 ky.ba.uz_222  jw.aa.un_440 mt.gd.un_320 
  0x2f00211b, 0x401c2fee, 0x46492a0c, 0x64512aad,   // jw.su.un_770 su.id.lb_422  mt.to.qu_543 mt.kl.lg_643 
  0x73002809, 0x6764350d, 0x0a3615ee, 0x2b003507,   // sw.ny.un_440 zu.lg.ak_554  un.ab.mk_422 zu.vi.un_420 
  0x3b28230c, 0x041008a7, 0x353025ec, 0x15040804,   // ky.sd.ks_543 uk.be.ru_532  mn.uz.tg_644 uk.ru.un_332 
  // [124d0]
  0x35303808, 0x2e1001a0, 0x5435340d, 0x0500181a,   // tk.uz.tg_443 en.lt.fo_322  xh.zu.ik_554 ga.fr.un_760 
  0x12002e11, 0x762601af, 0x283421ec, 0x73265ca4,   // fo.hu.un_630 en.ia.crs_655  fa.ps.sd_644 sa.ia.ny_433 
  0x534b10ac, 0x291726a9, 0x4d260a5a, 0x4718360d,   // lt.mi.ht_632 ia.sr.sl_544  pt.ia.aa_553 gn.ga.sn_554 
  0x2900260d, 0x06311bac, 0x645376a4, 0x223e7312,   // ia.sl.un_540 tr.az.de_632  crs.ht.lg_433 ny.rm.oc_654 
  // [124e0]
  0x132a20ee, 0x06001b0d, 0x1e65570b, 0x1240200c,   // sq.mt.et_422 tr.de.un_540  na.gv.ms_542 sq.lb.hu_543 
  0x1e5a1c12, 0x18002b07, 0x2754180e, 0x09fc64ee,   // id.sm.ms_654 vi.ga.un_420  ga.ik.gd_555 lg.zzp.pl_422 
  0x483160a4, 0x350268ee, 0x35100812, 0x68545aa4,   // vo.az.tt_433 ig.da.zu_422  uk.be.tg_654 sm.ik.ig_433 
  0x4f083312, 0x645d4505, 0x0f202a0c, 0x25211ca9,   // nn.no.bi_654 ln.ss.lg_333  mt.sq.lv_543 id.jw.eu_544 
  // [124f0]
  0x425a2805, 0x53000202, 0x39381b55, 0x0600310b,   // sw.sm.co_333 da.ht.un_220  tr.tk.br_442 az.de.un_520 
  0x081017a4, 0x04112508, 0x0c02600c, 0x3421280b,   // sr.be.uk_433 mn.ro.ru_443  vo.da.sv_543 sd.fa.ps_542 
  0x080425a7, 0x0408150e, 0x104804a0, 0x39000202,   // mn.ru.uk_532 un.uk.ru_555  ru.tt.be_322 da.br.un_220 
  0x080cfcee, 0x3e006307, 0x150807ee, 0x064025ee,   // zzp.sv.no_422 sco.rm.un_420  bg.uk.un_422 eu.lb.de_422 
  // [12500]
  0x3f002108, 0x1a3f01ee, 0x122f4a0c, 0x0a002a08,   // jw.af.un_430 en.af.tl_422  yo.su.hu_543 mt.pt.un_430 
  0xfe484e60, 0x0448250d, 0x1c001d02, 0x63483eec,   // ay.tt.tlh_664 mn.tt.ru_554  la.id.un_220 rm.tt.sco_644 
  0x46004d19, 0x37005d08, 0x0a11175a, 0x100163a7,   // aa.qu.un_750 ss.st.un_430  sr.ro.mk_553 sco.en.lt_532 
  0x441023a0, 0x101511a9, 0x460522a0, 0x30233812,   // ky.be.kk_322 ro.be.un_540  oc.fr.qu_322 tk.ky.uz_654 
  // [12510]
  0x28045dad, 0x354734af, 0x082510a9, 0x3004080b,   // ss.fi.sw_643 xh.sn.zu_655  be.mn.uk_544 uk.ru.uz_542 
  0x47345504, 0x08350402, 0x02003108, 0x463602ee,   // rw.xh.sn_332 ru.tg.uk_222  az.da.un_430 da.gn.qu_422 
  0x3525110c, 0x29360404, 0x0b7304a4, 0x47170407,   // ro.mn.tg_543 fi.gn.sl_332  fi.ny.es_433 fi.sr.sn_432 
  0x30351504, 0x07423ea7, 0x36040d09, 0x365604a0,   // un.tg.uz_332 rm.co.it_532  cs.fi.gn_444 fi.mg.gn_322 
  // [12520]
  0x1f100107, 0x431d7911, 0x59355008, 0x3b423ead,   // en.lt.cy_432 war.la.ie_653  fj.zu.rn_443 rm.co.so_643 
  0x1b314811, 0x28003623, 0x39006b07, 0x29003618,   // tt.az.tr_653 gn.sw.un_880  ceb.br.un_420 gn.sl.un_740 
  0x06000e05, 0x390579a0, 0x20002804, 0x353628a0,   // is.de.un_330 war.fr.br_322  sw.sq.un_320 sw.gn.zu_322 
  0x28211213, 0x55000907, 0x0d002413, 0x3e000e14,   // ur.fa.sd_665 pl.rw.un_420  eo.cs.un_650 is.rm.un_660 
  // [12530]
  0x36290405, 0x0c794207, 0x042d0d60, 0x1f1509ee,   // fi.sl.gn_333 co.war.sv_432  cs.sk.fi_664 pl.cy.un_420 
  0x1d003907, 0x42793e05, 0x09001d08, 0x49632004,   // br.la.un_420 rm.war.co_333  la.pl.un_430 sq.sco.to_332 
  0x59001009, 0x1f653ba0, 0x09006521, 0x22006529,   // lt.rn.un_440 so.gv.cy_322  gv.pl.un_860 gv.oc.un_960 
  0x332a0ca7, 0x536520a0, 0x302538a4, 0x4c212907,   // sv.mt.nn_532 sq.gv.ht_322  tk.mn.uz_433 sl.jw.wo_432 
  // [12540]
  0x4830375a, 0x51112314, 0x2f000c04, 0x34003c13,   // ba.uz.tt_553 ca.ro.kl_666  sv.su.un_320 ug.ps.un_650 
  0x4200200b, 0x02386507, 0x3c351505, 0x3b3263a7,   // sq.co.un_520 gv.tk.da_432  un.tg.ug_333 sco.bs.so_532 
  0x632001a9, 0x1c2002a4, 0x251515a9, 0x49130455,   // en.sq.sco_544 da.sq.id_433  un.mn.un_540 fi.et.to_442 
  0x5100131b, 0x3b13040c, 0x35100804, 0x103c0455,   // et.kl.un_770 fi.et.so_543  uk.be.tg_332 ru.ug.be_442 
  // [12550]
  0x644d3b04, 0x3b5864ee, 0x48513ba0, 0x182720ad,   // so.aa.lg_332 lg.om.so_422  so.kl.tt_322 sq.gd.ga_643 
  0x3d343008, 0x02fc13a0, 0x30001807, 0x0c200e07,   // uz.ps.ku_443 et.zzp.da_322  ar.uz.un_420 is.sq.sv_432 
  0x0327060d, 0x17071105, 0x2000270e, 0x303c48a9,   // de.gd.nl_554 ro.bg.sr_333  gd.sq.un_550 tt.ug.uz_544 
  0x1523300d, 0x505e1ea4, 0x04003512, 0x506025ad,   // uz.ky.un_554 ms.ts.fj_433  tg.ru.un_640 eu.vo.fj_643 
  // [12560]
  0x504b25ec, 0x2f000204, 0x4c605aaf, 0x3004350d,   // eu.mi.fj_644 da.su.un_320  sm.vo.wo_655 tg.ru.uz_554 
  0x292d6112, 0x2c001805, 0x311b3ea9, 0x5d6420a4,   // za.sk.sl_654 ga.fy.un_330  rm.tr.az_544 sq.lg.ss_433 
  0x25001913, 0x565023a4, 0x64682109, 0x3000111a,   // gl.eu.un_650 ca.fj.mg_433  jw.ig.lg_444 ro.uz.un_760 
  0x2a311b55, 0x230c3307, 0x0423380b, 0x1b113807,   // tr.az.mt_442 nn.sv.ca_432  tk.ky.ru_542 tk.ro.tr_432 
  // [12570]
  0x48372304, 0x30006e0b, 0x1218340d, 0x44483712,   // ky.ba.tt_332 hmn.uz.un_520  ps.ar.ur_554 ba.tt.kk_654 
  0x34233ba4, 0x0d29100b, 0x3c003619, 0x06003707,   // ks.ky.ps_433 lt.sl.cs_542  ab.ug.un_750 st.de.un_420 
  0x505a49ee, 0x5f004a08, 0x0f172a07, 0x30003b23,   // to.sm.fj_422 yo.tn.un_430  mt.sr.lv_432 ks.uz.un_880 
  0x2d001713, 0x5f003719, 0x292a0dee, 0x2b006113,   // sr.sk.un_650 st.tn.un_750  cs.mt.sl_422 za.vi.un_650 
  // [12580]
  0x170a37a7, 0x25003702, 0x28183bac, 0x15001122,   // ba.mk.sr_532 ba.mn.un_220  ks.ar.sd_632 ro.un.un_870 
  0x65003908, 0x1715690c, 0x3c483708, 0x6e006112,   // br.gv.un_430 mfe.sr.un_530  ba.tt.ug_443 za.hmn.un_640 
  0x2b002208, 0x2f002b04, 0x2200670c, 0x483625ad,   // oc.vi.un_430 vi.su.un_320  ak.oc.un_530 mn.ab.tt_643 
  0x23225304, 0x213c23ee, 0x25234807, 0x090d5c11,   // ht.oc.ca_332 ky.ug.fa_422  tt.ky.mn_432 sa.ne.hi_653 
  // [12590]
  0x35006402, 0x40004612, 0x333f03ec, 0x64003505,   // lg.zu.un_220 qu.lb.un_640  nl.af.nn_644 zu.lg.un_330 
  0x53001905, 0x35004a08, 0x281221af, 0x48002a02,   // gl.ht.un_330 yo.zu.un_430  fa.ur.sd_655 mt.tt.un_220 
  0x401206a7, 0x17002c07, 0x03123902, 0x15004423,   // de.hu.lb_532 fy.sr.un_420  br.hu.nl_222 kk.un.un_880 
  0x040e34a0, 0x11003909, 0x460434a7, 0x06033f08,   // xh.is.fi_322 br.ro.un_440  xh.fi.qu_532 af.nl.de_443 
  // [125a0]
  0x40002104, 0x655559a0, 0x3035250b, 0x3b0467ee,   // jw.lb.un_320 rn.rw.gv_322  mn.tg.uz_542 ak.fi.so_422 
  0x3e1b3807, 0x2123225a, 0x28001602, 0x182312a7,   // tk.tr.rm_432 oc.ca.jw_553  hr.sw.un_220 ur.ky.ar_532 
  0x32003907, 0x4c004008, 0x031239a4, 0x30383508,   // br.bs.un_420 lb.wo.un_430  br.hu.nl_433 tg.tk.uz_443 
  0x215322a7, 0xfe513507, 0x11005607, 0x23224204,   // oc.ht.jw_532 zu.kl.tlh_432  mg.ro.un_420 co.oc.ca_332 
  // [125b0]
  0x35285da4, 0x220a05a4, 0x3300fe0c, 0x53002218,   // ss.sw.zu_433 fr.pt.oc_433  tlh.nn.un_530 oc.ht.un_740 
  0x1f005f04, 0x73645f0d, 0x3500642a, 0x481035a0,   // tn.cy.un_320 tn.lg.ny_554  lg.zu.un_970 tg.be.tt_322 
  0x4c73575a, 0x084815ee, 0x02030e0c, 0x1b001102,   // na.ny.wo_553 un.tt.uk_422  is.nl.da_543 ro.tr.un_220 
  0x104220a7, 0x06271da0, 0x0a000508, 0x06fc1fee,   // sq.co.lt_532 la.gd.de_322  fr.pt.un_430 cy.zzp.de_422 
  // [125c0]
  0x25002c05, 0x5e37250c, 0x2e023ba9, 0x374844ac,   // fy.eu.un_330 eu.st.ts_543  so.da.fo_544 kk.tt.ba_632 
  0x281218a9, 0x0200040d, 0x30040a02, 0x370163a0,   // ar.ur.sd_544 fi.da.un_540  mk.ru.uz_222 sco.en.st_322 
  0x63065707, 0x01630208, 0x4448070c, 0x12001b11,   // na.de.sco_432 da.sco.en_443  bg.tt.kk_543 tr.hu.un_630 
  0x01656355, 0x01655707, 0x03002c0e, 0x201d0604,   // sco.gv.en_442 na.gv.en_432  fy.nl.un_550 de.la.sq_332 
  // [125d0]
  0x343d3011, 0x222e0e5a, 0x40630607, 0x650c6307,   // uz.ku.ps_653 is.fo.oc_553  de.sco.lb_432 sco.sv.gv_432 
  0x40fe15a0, 0x65321702, 0x63025104, 0x7328130d,   // un.tlh.lb_322 sr.bs.gv_222  kl.da.sco_332 et.sw.ny_554 
  0x46736a0c, 0x2500600c, 0x4a206008, 0x100823a9,   // haw.ny.qu_543 vo.eu.un_530  vo.sq.yo_443 ky.uk.be_544 
  0x122073a4, 0x59355507, 0x5c3613a4, 0x04371105,   // ny.sq.hu_433 rw.zu.rn_432  et.gn.sa_433 ro.ba.ru_333 
  // [125e0]
  0x301b1507, 0x2f1afe07, 0x5d1346ad, 0x15fc1b07,   // un.tr.uz_432 tlh.tl.su_432  qu.et.ss_643 tr.zzp.un_432 
  0x120260a4, 0x04003005, 0x78600407, 0x2afe300c,   // vo.da.hu_433 uz.fi.un_330  fi.vo.ve_432 uz.tlh.mt_543 
  0x34303da9, 0x73023007, 0x553558a4, 0x31301b14,   // ku.uz.ps_544 uz.da.ny_432  om.zu.rw_433 tr.uz.az_666 
  0x05003004, 0x04003019, 0x69571b08, 0x0a004402,   // uz.fr.un_320 uz.fi.un_750  tr.na.mfe_443 kk.mk.un_220 
  // [125f0]
  0x4a646711, 0x45025905, 0x02003007, 0x3d212812,   // ak.lg.yo_653 rn.da.ln_333  uz.da.un_420 sd.fa.ku_654 
  0x1530120c, 0x4a311ba0, 0x3130fead, 0x2d0d4aec,   // hu.uz.un_543 tr.az.yo_322  tlh.uz.az_643 yo.cs.sk_644 
  0x48041508, 0x131c09a0, 0x3c003719, 0x3e002507,   // un.ru.tt_443 hi.mr.bh_322  ba.ug.un_750 eu.rm.un_420 
  0x190b4aa0, 0x190b4a09, 0x40252208, 0x441821ee,   // yo.es.gl_322 yo.es.gl_444  oc.eu.lb_443 fa.ar.kk_422 
  // [12600]
  0x61006e21, 0x28443da6, 0x39002802, 0x384a2a0c,   // hmn.za.un_860 ku.kk.sd_521  sw.br.un_220 mt.yo.tk_543 
  0x274c550c, 0x2500101a, 0x111e1c08, 0x481023ee,   // rw.wo.gd_543 be.mn.un_760  id.ms.ro_443 ky.be.tt_422 
  0x3c233060, 0x4c4a2a07, 0x28342108, 0x6976125a,   // uz.ky.ug_664 mt.yo.wo_432  fa.ps.sd_443 hu.crs.mfe_553 
  0x21612fa4, 0x103537a0, 0x3c342305, 0x0823440c,   // su.za.jw_433 ba.tg.be_322  ky.ps.ug_333 kk.ky.uk_543 
  // [12610]
  0x44483ca6, 0x1b38310b, 0xfe041b02, 0x0f003b19,   // ug.tt.kk_521 az.tk.tr_542  tr.fi.tlh_222 so.lv.un_750 
  0x20766913, 0x3b000305, 0x353b340c, 0x53002f04,   // mfe.crs.sq_665 nl.so.un_330  xh.so.zu_543 su.ht.un_320 
  0x2500190d, 0x133e1ba0, 0x13004804, 0x230a3c07,   // gl.eu.un_540 tr.rm.et_322  tt.et.un_320 ug.mk.ky_432 
  0x123d18ad, 0x18002007, 0x1f151d09, 0x5c000f18,   // ar.ku.ur_643 sq.ga.un_420  la.cy.un_440 lv.sa.un_740 
  // [12620]
  0x215e7304, 0x46231f11, 0x644931a9, 0x35006505,   // ny.ts.jw_332 cy.ca.qu_653  az.to.lg_544 gv.zu.un_330 
  0x18004a12, 0x0d454a12, 0x50493409, 0x13403005,   // yo.ga.un_640 yo.ln.cs_654  xh.to.fj_444 uz.lb.et_333 
  0x351b59ee, 0x0a000e19, 0x0a0415a4, 0x09002402,   // rn.tr.zu_422 is.pt.un_750  un.ru.mk_433 eo.pl.un_220 
  0x34356807, 0x21000402, 0x29172da6, 0x5c093bad,   // ig.zu.xh_432 fi.jw.un_220  sk.sr.sl_521 ks.hi.sa_643 
  // [12630]
  0x4235590b, 0x10005208, 0x3700100d, 0x18002507,   // rn.zu.co_542 ha.lt.un_430  be.ba.un_540 eu.ga.un_420 
  0x10241d13, 0x37153c0c, 0x10124802, 0x35041509,   // la.eo.lt_665 ug.ba.un_530  tt.hu.lt_222 un.ru.tg_444 
  0x10002104, 0x4c190a13, 0x37111508, 0x180e2e12,   // jw.lt.un_320 pt.gl.wo_665  un.ro.ba_443 fo.is.ga_654 
  0x360a6055, 0x07151055, 0x1548230e, 0x525543a0,   // vo.pt.gn_442 be.bg.un_420  ky.tt.un_555 ie.rw.ha_322 
  // [12640]
  0x1c5c0d5a, 0x6800670d, 0x28003c0c, 0x23001105,   // ne.sa.mr_553 ak.ig.un_540  ug.sd.un_530 ro.ca.un_330 
  0x152511ad, 0x30002020, 0x3d342804, 0x012d6304,   // ro.mn.un_643 sq.uz.un_850  sd.ps.ku_332 sco.sk.en_332 
  0x084404ec, 0x374838ac, 0x204d53a4, 0x56005302,   // ru.kk.uk_644 tk.tt.ba_632  ht.aa.sq_433 ht.mg.un_220 
  0x2b004607, 0x7900011a, 0x5f3735a0, 0x260601a7,   // qu.vi.un_420 en.war.un_760  zu.st.tn_322 en.de.ia_532 
  // [12650]
  0x0a004902, 0x3900520d, 0x302338ee, 0x090157ee,   // to.pt.un_220 ha.br.un_540  tk.ky.uz_422 na.en.pl_422 
  0x5800390c, 0x63520107, 0x24205304, 0x52495a0e,   // br.om.un_530 en.ha.sco_432  ht.sq.eo_332 sm.to.ha_555 
  0x0705010c, 0x656b18ee, 0x1f2e2da0, 0x3b34210e,   // en.fr.it_543 ga.ceb.gv_422  sk.fo.cy_322 fa.ps.ks_555 
  0x2c241005, 0x29020c60, 0x2c2e0eee, 0x283412a4,   // lt.eo.fy_333 sv.da.sl_664  is.fo.fy_422 ur.ps.sd_433 
  // [12660]
  0x3e001d02, 0x39652904, 0x110a0714, 0x060c1308,   // la.rm.un_220 sl.gv.br_332  bg.mk.ro_666 et.sv.de_443 
  0x39005602, 0x1c1b1eee, 0x52004c04, 0x2d341da4,   // mg.br.un_220 ms.tr.id_422  wo.ha.un_320 la.xh.sk_433 
  0x42242bad, 0x07191f07, 0x69764c0d, 0x404cfc0c,   // vi.eo.co_643 cy.gl.it_432  wo.crs.mfe_554 zzp.wo.lb_543 
  0x49005a14, 0x2c0640af, 0x123138a9, 0x5c1309ee,   // sm.to.un_660 lb.de.fy_655  tk.az.hu_544 hi.bh.sa_422 
  // [12670]
  0x36002308, 0x15000613, 0x121b06ee, 0x2e2c0e04,   // ca.gn.un_430 de.un.un_650  de.tr.hu_422 is.fy.fo_332 
  0x3e375f09, 0x310e1bee, 0x2d0d60ee, 0x58000204,   // tn.st.rm_444 tr.is.az_422  vo.cs.sk_422 da.om.un_320 
  0x313e060b, 0x2d120ea7, 0x10004811, 0x3418120c,   // de.rm.az_542 is.hu.sk_532  tt.be.un_630 ur.ar.ps_543 
  0x48002a04, 0x34233008, 0x2e120e0c, 0x1b3106a4,   // mt.tt.un_320 uz.ky.ps_443  is.hu.fo_543 de.az.tr_433 
  // [12680]
  0x3f002a04, 0x04004d14, 0x28003607, 0x04005113,   // mt.af.un_320 aa.fi.un_660  gn.sw.un_420 kl.fi.un_650 
  0x281812a6, 0x080a1755, 0x06400c04, 0x06313607,   // ur.ar.sd_521 sr.mk.uk_442  sv.lb.de_332 gn.az.de_432 
  0x082c3307, 0x34001218, 0x12481bee, 0x49396508,   // nn.fy.no_432 ur.ps.un_740  tr.tt.hu_422 gv.br.to_443 
  0x1b311304, 0x024b535a, 0x3f6953ad, 0x08001719,   // et.az.tr_332 ht.mi.da_553  ht.mfe.af_643 sr.uk.un_750 
  // [12690]
  0x53000108, 0x6b1b3155, 0x40040107, 0x58474908,   // en.ht.un_430 az.tr.ceb_442  en.fi.lb_432 to.sn.om_443 
  0x311b3009, 0x2d38620c, 0x301b4aa4, 0x1579010c,   // uz.tr.az_444 kha.tk.sk_543  yo.tr.uz_433 en.war.un_543 
  0x024c6312, 0x2e380ea7, 0x35170807, 0x224901a9,   // sco.wo.da_654 is.tk.fo_532  uk.sr.tg_432 en.to.oc_544 
  0x0240390c, 0x1a1b3007, 0x37007304, 0x06381307,   // br.lb.da_543 uz.tr.tl_432  ny.st.un_320 et.tk.de_432 
  // [126a0]
  0x311b30a4, 0x612c010c, 0x634b01a0, 0x043031a0,   // uz.tr.az_433 en.fy.za_543  en.mi.sco_322 az.uz.fi_322 
  0x303831a4, 0x19473907, 0x5b6301a0, 0x636053a9,   // az.tk.uz_433 br.sn.gl_432  en.sco.sg_322 ht.vo.sco_544 
  0x4a311ba4, 0x6100390e, 0x04001b05, 0x2b305904,   // tr.az.yo_433 br.za.un_550  tr.fi.un_330 rn.uz.vi_332 
  0x5356390c, 0x2d003504, 0x22005314, 0x22005322,   // br.mg.ht_543 zu.sk.un_320  ht.oc.un_660 ht.oc.un_870 
  // [126b0]
  0x15001104, 0x34001214, 0x18016107, 0x25103602,   // ro.un.un_320 ur.ps.un_660  za.en.ga_432 ab.be.mn_222 
  0x041007ec, 0x551f45a4, 0x5300221a, 0x18000e16,   // bg.be.ru_644 ln.cy.rw_433  oc.ht.un_760 is.ga.un_720 
  0x6961395a, 0x383515ad, 0x48004602, 0x53002212,   // br.za.mfe_553 un.tg.tk_643  qu.tt.un_220 oc.ht.un_640 
  0x20301b55, 0x07100a05, 0x1f0364a9, 0x1f006413,   // tr.uz.sq_442 mk.be.bg_333  lg.nl.cy_544 lg.cy.un_650 
  // [126c0]
  0x30233609, 0x060c79a0, 0x2e0e2004, 0x33086ba4,   // ab.ky.uz_444 war.sv.de_322  sq.is.fo_332 ceb.no.nn_433 
  0x3835300d, 0xfc651da9, 0x303804ee, 0x12020807,   // uz.tg.tk_554 la.gv.zzp_544  ru.tk.uz_422 no.da.hu_432 
  0x06020811, 0x2c001802, 0x19000a11, 0x0d000307,   // no.da.de_653 ga.fy.un_220  pt.gl.un_630 nl.cs.un_420 
  0x18001507, 0x7600050d, 0x016579a0, 0x2f006a07,   // un.ga.un_420 fr.crs.un_540  war.gv.en_322 haw.su.un_420 
  // [126d0]
  0x51001009, 0x402c65af, 0x37443808, 0x45002421,   // lt.kl.un_440 gv.fy.lb_655  tk.kk.ba_443 eo.ln.un_860 
  0x3515040d, 0x0711650c, 0x355e2fa9, 0x10630107,   // ru.tg.un_540 gv.ro.it_543  su.ts.zu_544 en.sco.lt_432 
  0x4c465205, 0x2d093f12, 0x36150405, 0x686920af,   // ha.qu.wo_333 af.pl.sk_654  ru.ab.un_330 sq.mfe.ig_655 
  0x1ffe4705, 0x07050907, 0x03063f12, 0x481b3107,   // sn.tlh.cy_333 pl.fr.it_432  af.de.nl_654 az.tr.tt_432 
  // [126e0]
  0x65003f22, 0x11496713, 0x2c3e63ec, 0x696803ad,   // af.gv.un_870 ak.to.ro_665  sco.rm.fy_644 nl.ig.mfe_643 
  0x52004509, 0x44353c0b, 0x2c026813, 0x09000613,   // ln.ha.un_440 ug.tg.kk_542  ig.da.fy_665 de.pl.un_650 
  0x0f000108, 0x456505a9, 0x4b501e0c, 0x2c67060e,   // en.lv.un_430 fr.gv.ln_544  ms.fj.mi_543 de.ak.fy_555 
  0x2d0f24a9, 0x49003f0c, 0x48440a04, 0x595558a9,   // eo.lv.sk_544 af.to.un_530  mk.kk.tt_332 om.rw.rn_544 
  // [126f0]
  0x5c5850a9, 0x122c2e07, 0x1f4753a0, 0x491a51a7,   // fj.om.sa_544 fo.fy.hu_432  ht.sn.cy_322 kl.tl.to_532 
  0x53003f02, 0x4400111a, 0x15154804, 0x25125508,   // af.ht.un_220 ro.kk.un_760  tt.un.un_320 rw.hu.eu_443 
  0x4d5c4e0d, 0x584c4e07, 0x2f501e0c, 0x0e2e2c07,   // ay.sa.aa_554 ay.wo.om_432  ms.fj.su_543 fy.fo.is_432 
  0x1b483007, 0x515a1d04, 0x4e471e07, 0x731a4eec,   // uz.tt.tr_432 la.sm.kl_332  ms.sn.ay_432 ay.tl.ny_644 
  // [12700]
  0x1c5c0d14, 0x46514e0d, 0x183b120c, 0x48303102,   // ne.sa.mr_666 ay.kl.qu_554  ur.ks.ar_543 az.uz.tt_222 
  0x1b000607, 0x0c006305, 0x2e0402a0, 0x23003411,   // de.tr.un_420 sco.sv.un_330  da.fi.fo_322 ps.ky.un_630 
  0x47352aa0, 0x443c2b0c, 0x390f0207, 0x0e2e36ee,   // mt.zu.sn_322 vi.ug.kk_543  da.lv.br_432 gn.fo.is_422 
  0x1a3b6e0c, 0x48073755, 0x033f4ca0, 0x100425a9,   // hmn.so.tl_543 ba.bg.tt_442  wo.af.nl_322 mn.ru.be_544 
  // [12710]
  0x3b6e4ca9, 0x15440413, 0x3f006e0d, 0x3f6e13a9,   // wo.hmn.so_544 ru.kk.un_665  hmn.af.un_540 et.hmn.af_544 
  0x6e004c1a, 0x3044150c, 0x230410a4, 0x135c09a4,   // wo.hmn.un_760 un.kk.uz_543  be.ru.ky_433 hi.sa.bh_433 
  0x2c002e07, 0x04151105, 0x230e2eec, 0x0e192e12,   // fo.fy.un_420 ro.ru.un_330  fo.is.ca_644 fo.gl.is_654 
  0x3d122108, 0x2c120ea7, 0x2e0a2dac, 0x2c120e07,   // fa.ur.ku_443 is.hu.fy_532  sk.pt.fo_632 is.hu.fy_432 
  // [12720]
  0x0a230eaf, 0x4f00390e, 0x2d005602, 0x2a004f12,   // is.ca.pt_655 br.bi.un_550  mg.sk.un_220 bi.mt.un_640 
  0x0c003204, 0x38002c07, 0x1b3e380c, 0x0425370c,   // bs.sv.un_320 fy.tk.un_420  tk.rm.tr_543 ba.mn.ru_543 
  0x583e2a04, 0x65123304, 0x2c2676ec, 0x303412af,   // mt.rm.om_332 nn.hu.gv_332  crs.ia.fy_644 ur.ps.uz_655 
  0x39001b0d, 0x2a420107, 0x0e004808, 0x2251545a,   // tr.br.un_540 en.co.mt_432  tt.is.un_430 ik.kl.oc_553 
  // [12730]
  0x15051f0c, 0x62601d08, 0x373c3504, 0x3833080e,   // cy.fr.un_543 la.vo.kha_443  tg.ug.ba_332 no.nn.tk_555 
  0x071736a4, 0x153517a4, 0x13697607, 0x2f1d43a4,   // ab.sr.bg_433 sr.tg.un_433  crs.mfe.et_432 ie.la.su_433 
  0x1f001d08, 0x2a001307, 0x5f00fc05, 0x51583e12,   // la.cy.un_430 et.mt.un_420  zzp.tn.un_330 rm.om.kl_654 
  0x0a07380c, 0x753733a9, 0x2d420da4, 0x33300307,   // tk.bg.mk_543 nn.st.nso_544  cs.co.sk_433 nl.uz.nn_432 
  // [12740]
  0x792824a4, 0x305f13a7, 0x3f5f3708, 0x0c2550a9,   // eo.sw.war_433 et.tn.uz_532  st.tn.af_443 fj.eu.sv_544 
  0x556976a9, 0x0d133bee, 0x294236a9, 0x17755fac,   // crs.mfe.rw_544 ks.bh.ne_422  gn.co.sl_544 tn.nso.sr_632 
  0x5c001904, 0xfc002008, 0x48251011, 0x48373560,   // gl.sa.un_320 sq.zzp.un_430  be.mn.tt_653 tg.ba.tt_664 
  0x041007a7, 0x3c003722, 0x51001104, 0x1c4864ee,   // bg.be.ru_532 ba.ug.un_870  ro.kl.un_320 lg.tt.id_422 
  // [12750]
  0x100437a4, 0x303544ac, 0x3e00100c, 0x04101708,   // ba.ru.be_433 kk.tg.uz_632  lt.rm.un_530 sr.be.ru_443 
  0x49006834, 0x02285812, 0x48153704, 0x29203202,   // ig.to.un_A80 om.sw.da_654  ba.tt.un_320 bs.sq.sl_222 
  0x5c342b07, 0x11003534, 0x443723a9, 0x1e1c10a0,   // vi.xh.sa_432 tg.ro.un_A80  ky.ba.kk_544 lt.id.ms_322 
  0x36fe6a07, 0x3f682bad, 0x2032fe05, 0x3b786704,   // haw.tlh.gn_432 vi.ig.af_643  tlh.bs.sq_333 ak.ve.so_332 
  // [12760]
  0x363e07af, 0x165210a7, 0x00002037, 0x28001220,   // it.rm.gn_655 lt.ha.hr_532  sq.un.un_B00 ur.sd.un_850 
  0x7800270e, 0x2b68feac, 0x30003d0e, 0x36552fa0,   // gd.ve.un_550 tlh.ig.vi_632  ku.uz.un_550 su.rw.gn_322 
  0x4639fe04, 0x01656312, 0xfe2b58a4, 0x0900fe0d,   // tlh.br.qu_332 sco.gv.en_654  om.vi.tlh_433 tlh.pl.un_540 
  0x2b001704, 0x2800291a, 0x5e004b02, 0x55002f07,   // sr.vi.un_320 sl.sw.un_760  mi.ts.un_220 su.rw.un_420 
  // [12770]
  0x180e2ea7, 0x15100455, 0x1b00021a, 0x2502450c,   // fo.is.ga_532 ru.be.un_442  da.tr.un_760 ln.da.eu_543 
  0x21190bee, 0x4c311ba4, 0x25004c13, 0x0f002912,   // es.gl.jw_422 tr.az.wo_433  wo.eu.un_650 sl.lv.un_640 
  0x48373004, 0x11001904, 0x38023112, 0x351704a0,   // uz.ba.tt_332 gl.ro.un_320  az.da.tk_654 ru.sr.tg_322 
  0x30001a04, 0x36103807, 0x3644230c, 0x2d2f6107,   // tl.uz.un_320 tk.be.ab_432  ky.kk.ab_543 za.su.sk_432 
  // [12780]
  0x381544a4, 0x34301207, 0x08071160, 0x461219a0,   // kk.tk.un_430 ur.uz.ps_432  ro.bg.uk_664 gl.hu.qu_322 
  0x4434210c, 0x0e123ead, 0x39033f05, 0x16001a07,   // fa.ps.kk_543 rm.hu.is_643  af.nl.br_333 tl.hr.un_420 
  0x02791aa4, 0x28004421, 0x05004907, 0x2e1629a0,   // tl.war.da_433 kk.sd.un_860  to.fr.un_420 sl.hr.fo_322 
  0x21283413, 0x42060755, 0x642e1aee, 0x29001713,   // ps.sd.fa_665 it.de.co_442  tl.fo.lg_422 sr.sl.un_650 
  // [12790]
  0x55356808, 0x08002a02, 0x36651f60, 0x09123eee,   // ig.zu.rw_443 mt.no.un_220  cy.gv.gn_664 rm.hu.pl_422 
  0x06003f13, 0x126b02a0, 0x0e2e3e0e, 0x2e005002,   // af.de.un_650 da.ceb.hu_322  rm.fo.is_555 fj.fo.un_220 
  0x4b004e12, 0x35555da0, 0x36002d13, 0x423e0708,   // ay.mi.un_640 ss.rw.zu_322  sk.gn.un_650 it.rm.co_443 
  0x68025507, 0x3e420712, 0x1a606bad, 0x79006b0d,   // rw.da.ig_432 it.co.rm_654  ceb.vo.tl_643 ceb.war.un_540 
  // [127a0]
  0x0448105a, 0x40005804, 0x36002e14, 0x25302308,   // be.tt.ru_553 om.lb.un_320  fo.gn.un_660 ky.uz.mn_443 
  0x135c0d0d, 0x0c3f0ea0, 0x48440702, 0x213057a7,   // ne.sa.bh_554 is.af.sv_322  bg.kk.tt_222 na.uz.jw_532 
  0x2d00360e, 0x093308ec, 0x04071713, 0x362d0d12,   // gn.sk.un_550 no.nn.pl_644  sr.bg.ru_665 cs.sk.gn_654 
  0x12001d08, 0x26001d09, 0x23001213, 0x35003411,   // la.hu.un_430 la.ia.un_440  ur.ky.un_650 xh.zu.un_630 
  // [127b0]
  0x1e1c3805, 0x63000d04, 0x343c44a4, 0x25100f12,   // tk.id.ms_333 cs.sco.un_320  kk.ug.ps_433 lv.lt.eu_654 
  0x0e6a01a4, 0x5a00540d, 0x443723ec, 0x20353404,   // en.haw.is_433 ik.sm.un_540  ky.ba.kk_644 xh.zu.sq_332 
  0x230a1da0, 0x2f2263a0, 0x65504f0d, 0x2035340b,   // la.pt.ca_322 sco.oc.su_322  bi.fj.gv_554 xh.zu.sq_542 
  0x2322460c, 0x52284712, 0x1d006509, 0x311b38a0,   // qu.oc.ca_543 sn.sw.ha_654  gv.la.un_440 tk.tr.az_322 
  // [127c0]
  0x234448ad, 0x4f0e5208, 0x44383c07, 0x61005a12,   // tt.kk.ky_643 ha.is.bi_443  ug.tk.kk_432 sm.za.un_640 
  0x63044707, 0x286347a4, 0x734b5a0c, 0x37254802,   // sn.fi.sco_432 sn.sco.sw_433  sm.mi.ny_543 tt.mn.ba_222 
  0x42002207, 0x362325ec, 0x29120904, 0x20122907,   // oc.co.un_420 mn.ky.ab_644  pl.hu.sl_332 sl.hu.sq_432 
  0x556402a9, 0x29001208, 0x761f6911, 0x2300111b,   // da.lg.rw_544 hu.sl.un_430  mfe.cy.crs_653 ro.ky.un_770 
  // [127d0]
  0x4000fe12, 0x53645555, 0x183401a4, 0x10251111,   // tlh.lb.un_640 rw.lg.ht_442  iw.ps.ar_433 ro.mn.be_653 
  0x122d69a4, 0x641d55a4, 0x6e005e0d, 0x3715170d,   // mfe.sk.hu_433 rw.la.lg_433  ts.hmn.un_540 sr.ba.un_540 
  0x486a6812, 0x33006b04, 0x4f001521, 0x68002818,   // ig.haw.tt_654 ceb.nn.un_320  un.bi.un_860 sw.ig.un_740 
  0x364a68ad, 0x04153507, 0x73524baf, 0x33002402,   // ig.yo.gn_643 tg.ru.un_420  mi.ha.ny_655 eo.nn.un_220 
  // [127e0]
  0x1821120c, 0x6e6301a0, 0x6500560c, 0x020c02a4,   // ur.fa.ar_543 en.sco.hmn_322  mg.gv.un_530 da.sv.da_433 
  0x2f491cee, 0x15000107, 0x20481b07, 0x0100570e,   // id.to.su_422 en.un.un_420  tr.tt.sq_432 na.en.un_550 
  0x361525af, 0x29003213, 0x2800730c, 0x2b020104,   // mn.ab.un_650 bs.sl.un_650  ny.sw.un_530 en.da.vi_332 
  0x57015605, 0x476434a7, 0x2510080c, 0x3b2c3fa7,   // mg.en.na_333 xh.lg.sn_532  uk.be.mn_543 af.fy.so_532 
  // [127f0]
  0x645512a4, 0x3519340d, 0x12000309, 0x036020ec,   // hu.rw.lg_433 xh.gl.zu_554  nl.hu.un_440 sq.vo.nl_644 
  0x28213da4, 0x38311205, 0x353019a0, 0x022e0e0d,   // ku.fa.sd_433 hu.az.tk_333  gl.uz.zu_322 is.fo.da_554 
  0x0a361912, 0x5546340e, 0x4500430e, 0x043508ad,   // gl.gn.pt_654 xh.qu.rw_555  ie.ln.un_550 uk.tg.ru_643 
  0x283d3405, 0x321612a4, 0x40023e07, 0x32170309,   // ps.ku.sd_333 hu.hr.bs_433  rm.da.lb_432 nl.sr.bs_444 
  
  // [12800]
  0x0e022e07, 0x3f0803a4, 0x0e022eec, 0x10482508,   // fo.da.is_432 nl.no.af_433  fo.da.is_644 mn.tt.be_443 
  0x2f4751a4, 0x2511150c, 0x11000a13, 0x6b4d2f12,   // kl.sn.su_433 un.ro.mn_543  mk.ro.un_650 su.aa.ceb_654 
  0x03060207, 0x2f006b0e, 0x04234804, 0x1800191a,   // da.de.nl_432 ceb.su.un_550  tt.ky.ru_332 gl.ga.un_760 
  0x4b00100b, 0x353048ee, 0x083c0a0c, 0x37443ca4,   // lt.mi.un_520 tt.uz.tg_422  mk.ug.uk_543 ug.kk.ba_433 
  // [12810]
  0x3f002204, 0x11004b0c, 0x21182808, 0x650510a9,   // oc.af.un_320 mi.ro.un_530  sd.ar.fa_443 lt.fr.gv_544 
  0x0c00270d, 0x0c003f02, 0x2033080c, 0x0600200e,   // gd.sv.un_540 af.sv.un_220  no.nn.sq_543 sq.de.un_550 
  0x27001d13, 0x65001d1a, 0x120220a0, 0x1200020c,   // la.gd.un_650 la.gv.un_760  sq.da.hu_322 da.hu.un_530 
  0x39000607, 0x18003e0d, 0x1d276507, 0x25484c07,   // de.br.un_420 rm.ga.un_540  gv.gd.la_432 wo.tt.eu_432 
  // [12820]
  0x0c09200d, 0x65004307, 0x401d4bad, 0x200608a4,   // sq.pl.sv_554 ie.gv.un_420  mi.la.lb_643 no.de.sq_433 
  0x4306080c, 0x120c430c, 0x3d213408, 0x2c002b07,   // no.de.ie_543 ie.sv.hu_543  ps.fa.ku_443 vi.fy.un_420 
  0x38311ba9, 0x07171509, 0x38003109, 0x080448a7,   // tr.az.tk_544 un.sr.bg_444  az.tk.un_440 tt.ru.uk_532 
  0x2c002b18, 0x2c002b05, 0x151107ec, 0x350a070c,   // vi.fy.un_740 vi.fy.un_330  bg.ro.un_644 bg.mk.tg_543 
  // [12830]
  0x5a000b05, 0x13005c21, 0x080e330c, 0x330612a0,   // es.sm.un_330 sa.bh.un_860  nn.is.no_543 hu.de.nn_322 
  0x23484412, 0x0b482502, 0x48173ca0, 0x12003029,   // kk.tt.ky_654 eu.tt.es_222  ug.sr.tt_322 uz.ur.un_960 
  0x28001221, 0x3c3d28ee, 0x782861a9, 0x063f0c0c,   // ur.sd.un_860 sd.ku.ug_422  za.sw.ve_544 sv.af.de_543 
  0x1302280c, 0x0e2e0c12, 0x55477311, 0x50135d5a,   // sw.da.et_543 sv.fo.is_654  ny.sn.rw_653 ss.et.fj_553 
  // [12840]
  0x645373a0, 0x5955360e, 0x04366a11, 0x73004508,   // ny.ht.lg_322 gn.rw.rn_555  haw.gn.fi_653 ln.ny.un_430 
  0x20103202, 0x40002813, 0x194e0b07, 0x25005d08,   // bs.lt.sq_222 sw.lb.un_650  es.ay.gl_432 ss.eu.un_430 
  0x44233d07, 0x283829af, 0x25004c09, 0x240920a4,   // ku.ky.kk_432 sl.tk.sw_655  wo.eu.un_440 sq.pl.eo_433 
  0x0435300b, 0x4700280c, 0x55597312, 0x4a68570c,   // uz.tg.ru_542 sw.sn.un_530  ny.rn.rw_654 na.ig.yo_543 
  // [12850]
  0x334736a7, 0x1900610c, 0x475d64ec, 0x13365d11,   // gn.sn.nn_532 za.gl.un_530  lg.ss.sn_644 ss.gn.et_653 
  0x64557307, 0x0a001802, 0x254b3608, 0x73595505,   // ny.rw.lg_432 ga.pt.un_220  gn.mi.eu_443 rw.rn.ny_333 
  0x2f025511, 0x49001019, 0x0b464ca0, 0x46004c09,   // rw.da.su_653 lt.to.un_750  wo.qu.es_322 wo.qu.un_440 
  0x353420a9, 0x1e594a08, 0x0b3619ee, 0x32002018,   // sq.xh.zu_544 yo.rn.ms_443  gl.gn.es_422 sq.bs.un_740 
  // [12860]
  0x384a68a4, 0x2000331a, 0x3829090b, 0x19003b05,   // ig.yo.tk_433 nn.sq.un_760  pl.sl.tk_542 so.gl.un_330 
  0x0b360204, 0x1000200b, 0x122911a0, 0x09293809,   // da.gn.es_332 sq.lt.un_520  ro.sl.hu_322 tk.sl.pl_444 
  0x5d023505, 0x16200e04, 0x183b4407, 0x372c03a0,   // zu.da.ss_333 is.sq.hr_332  kk.ks.ar_432 nl.fy.st_322 
  0x40004b04, 0x024d3807, 0x3b150108, 0x40000205,   // mi.lb.un_320 tk.aa.da_432  en.so.un_430 da.lb.un_330 
  // [12870]
  0x3b006708, 0x673801a4, 0x4c00480d, 0x383b5704,   // ak.so.un_430 en.tk.ak_433  tt.wo.un_540 na.so.tk_332 
  0x1c2146a7, 0x1900360c, 0x02604614, 0x095c0da9,   // qu.jw.id_532 gn.gl.un_530  qu.vo.da_666 ne.sa.hi_544 
  0x79521a08, 0x4d3b01a0, 0x3b02fe04, 0x64025412,   // tl.ha.war_443 en.so.aa_322  tlh.da.so_332 ik.da.lg_654 
  0x64004519, 0x463b4da6, 0x1200060b, 0x021a79a4,   // ln.lg.un_750 aa.so.qu_521  de.hu.un_520 war.tl.da_433 
  // [12880]
  0x02003819, 0x4d573b13, 0x79211aad, 0x384c190c,   // tk.da.un_750 so.na.aa_665  tl.jw.war_643 gl.wo.tk_543 
  0x48003b0d, 0x11003019, 0x65005712, 0x3b6e02ad,   // so.tt.un_540 uz.ro.un_750  na.gv.un_640 da.hmn.so_643 
  0x67005722, 0x64025c04, 0x37697613, 0x3b4d4caf,   // na.ak.un_870 sa.da.lg_332  crs.mfe.st_665 wo.aa.so_655 
  0x57670111, 0x252a3ba7, 0x093b67a7, 0x343b5ea4,   // en.ak.na_653 so.mt.eu_532  ak.so.pl_532 ts.so.xh_433 
  // [12890]
  0x48386704, 0x650c1904, 0x646b0208, 0x31394cec,   // ak.tk.tt_332 gl.sv.gv_332  da.ceb.lg_443 wo.br.az_644 
  0x5a004921, 0x2f2146ad, 0x1a025807, 0x1000120d,   // to.sm.un_860 qu.jw.su_643  om.da.tl_432 hu.lt.un_540 
  0x4d00190e, 0x44001804, 0x48003404, 0x08001020,   // gl.aa.un_550 ar.kk.un_320  xh.tt.un_320 be.uk.un_850 
  0x5f7537a4, 0x1d4c3bec, 0x12003812, 0x38097904,   // st.nso.tn_433 so.wo.la_644  tk.hu.un_640 war.pl.tk_332 
  // [128a0]
  0x082344a4, 0x443738ee, 0x2a005c05, 0x383c35a9,   // kk.ky.uk_433 tk.ba.kk_422  sa.mt.un_330 tg.ug.tk_544 
  0x101b0f60, 0x30482555, 0x4000390e, 0x02002f05,   // lv.tr.lt_664 mn.tt.uz_442  br.lb.un_550 su.da.un_330 
  0x57403914, 0x5c4647af, 0x12040f05, 0x23022204,   // br.lb.na_666 sn.qu.sa_655  lv.fi.hu_333 oc.da.ca_332 
  0x12135ca0, 0x0c002804, 0x0e332e07, 0x35003813,   // sa.et.hu_322 sw.sv.un_320  fo.nn.is_432 tk.tg.un_650 
  // [128b0]
  0x34005313, 0x123458a0, 0x041d43ad, 0x23441513,   // ht.xh.un_650 om.xh.hu_322  ie.la.fi_643 un.kk.ky_665 
  0x1d023907, 0x5c00101b, 0x28442307, 0x29135ca0,   // br.da.la_432 lt.sa.un_770  ky.kk.sd_432 sa.et.sl_322 
  0x351536a9, 0x481037ee, 0x044825a4, 0x403f03a0,   // ab.tg.un_540 ba.be.tt_422  mn.tt.ru_433 nl.af.lb_322 
  0x30384807, 0x303c4407, 0x68006a0d, 0x3b60430c,   // tt.tk.uz_432 kk.ug.uz_432  haw.ig.un_540 ie.vo.so_543 
  // [128c0]
  0x0f004605, 0x271863af, 0x04083007, 0x170810a9,   // qu.lv.un_330 sco.ga.gd_655  uz.uk.ru_432 be.uk.sr_544 
  0x4b2165ee, 0x180327af, 0x21472807, 0x4200550c,   // gv.jw.mi_422 gd.nl.ga_655  sw.sn.jw_432 rw.co.un_530 
  0x48003904, 0x4c2f4711, 0x2f000302, 0x08101713,   // br.tt.un_320 sn.su.wo_653  nl.su.un_220 sr.be.uk_665 
  0x1b002a08, 0x4f620807, 0x02001d08, 0x43001b05,   // mt.tr.un_430 no.kha.bi_432  la.da.un_430 tr.ie.un_330 
  // [128d0]
  0x600c08ee, 0x623908a0, 0x21343ba0, 0x5c130daf,   // no.sv.vo_422 no.br.kha_322  ks.ps.fa_322 ne.bh.sa_655 
  0x3c00150e, 0x633e42af, 0x33080305, 0x693976ad,   // un.ug.un_550 co.rm.sco_655  nl.no.nn_333 crs.br.mfe_643 
  0x0a4807a4, 0x403f65ee, 0x50551ba0, 0x42002011,   // bg.tt.mk_433 gv.af.lb_422  tr.rw.fj_322 sq.co.un_630 
  0x21343dad, 0x12283b11, 0x061b1204, 0x1126010c,   // ku.ps.fa_643 ks.sd.ur_653  hu.tr.de_332 en.ia.ro_543 
  // [128e0]
  0x7926010b, 0x4f005c08, 0x02105fec, 0x5537580c,   // en.ia.war_542 sa.bi.un_430  tn.lt.da_644 om.st.rw_543 
  0x371004a7, 0x54211f05, 0x761126a9, 0x5f5a600c,   // ru.be.ba_532 cy.jw.ik_333  ia.ro.crs_544 vo.sm.tn_543 
  0x262d110c, 0x26485cad, 0x19114c04, 0x306375a4,   // ro.sk.ia_543 sa.tt.ia_643  wo.ro.gl_332 nso.sco.uz_433 
  0x132601af, 0x09006904, 0x2812185a, 0x1142260c,   // en.ia.et_655 mfe.pl.un_320  ar.ur.sd_553 ia.co.ro_543 
  // [128f0]
  0x28492608, 0x29596804, 0x20315809, 0x2f215c07,   // ia.to.sw_443 ig.rn.sl_332  om.az.sq_444 sa.jw.su_432 
  0x6e000c12, 0x1f005714, 0x5f105a0c, 0x6a00060d,   // sv.hmn.un_640 na.cy.un_660  sm.lt.tn_543 de.haw.un_540 
  0x35040802, 0x10477808, 0x04083ca7, 0x02251fa0,   // uk.ru.tg_222 ve.sn.lt_443  ug.uk.ru_532 cy.eu.da_322 
  0x033f5aa0, 0x3504070e, 0x291668ac, 0x37005f35,   // sm.af.nl_322 bg.ru.tg_555  ig.hr.sl_632 tn.st.un_A90 
  // [12900]
  0x68603611, 0x586a4ca9, 0x5a004a0c, 0x01002607,   // gn.vo.ig_653 wo.haw.om_544  yo.sm.un_530 ia.en.un_420 
  0x375d5f09, 0x234448a9, 0x23390ea0, 0x0811150d,   // tn.ss.st_444 tt.kk.ky_544  is.br.ca_322 un.ro.uk_554 
  0x221923a7, 0x39001002, 0x0a00050c, 0x202d0208,   // ca.gl.oc_532 lt.br.un_220  fr.pt.un_530 da.sk.sq_443 
  0x0c0e0407, 0x172568ad, 0x02006309, 0xfe005313,   // fi.is.sv_432 ig.eu.sr_643  sco.da.un_440 ht.tlh.un_650 
  // [12910]
  0x07080a0c, 0x350a1507, 0x35111007, 0x3900050c,   // mk.uk.bg_543 un.mk.tg_432  be.ro.tg_432 fr.br.un_530 
  0x18343da4, 0x443808ad, 0x0e001504, 0x48003622,   // ku.ps.ar_433 uk.tk.kk_643  un.is.un_320 ab.tt.un_870 
  0x17240caf, 0x044411a7, 0x4a00520e, 0x121b0608,   // sv.eo.sr_655 ro.kk.ru_532  ha.yo.un_550 de.tr.hu_443 
  0x0e0f13ad, 0x48000a16, 0x0e2e50ad, 0x0b001d07,   // et.lv.is_643 pt.tt.un_720  fj.fo.is_643 la.es.un_420 
  // [12920]
  0x090c0807, 0x2c40060c, 0x1f0920a9, 0x630c3304,   // no.sv.pl_432 de.lb.fy_543  sq.pl.cy_544 nn.sv.sco_332 
  0x2e003607, 0x12491aee, 0x065357ac, 0x1d033f07,   // gn.fo.un_420 tl.to.hu_422  na.ht.de_632 af.nl.la_432 
  0x061b38a0, 0x330213a4, 0x622f210d, 0x0c290208,   // tk.tr.de_322 et.da.nn_433  jw.su.kha_554 da.sl.sv_443 
  0x18232807, 0x1700480b, 0x13003302, 0x2a1301a0,   // sd.ky.ar_432 tt.sr.un_520  nn.et.un_220 en.et.mt_322 
  // [12930]
  0x07042302, 0x30342111, 0x424702ee, 0x18003d19,   // ky.ru.bg_222 fa.ps.uz_653  da.sn.co_422 ku.ar.un_750 
  0x2c0833ec, 0x332f2008, 0x0c003004, 0x17041355,   // nn.no.fy_644 sq.su.nn_443  uz.sv.un_320 et.fi.sr_442 
  0x1b4812a4, 0x20190a04, 0x73360412, 0x0e422e0c,   // hu.tt.tr_433 pt.gl.sq_332  fi.gn.ny_654 fo.co.is_543 
  0x081d4311, 0x1b0338ad, 0x03002c0c, 0x5c1946a9,   // ie.la.no_653 tk.nl.tr_643  fy.nl.un_530 qu.gl.sa_544 
  // [12940]
  0x5c4c1a04, 0x04001b08, 0x64364709, 0x407906a0,   // tl.wo.sa_332 tr.fi.un_430  sn.gn.lg_444 de.war.lb_322 
  0x5c073ea4, 0x5c004b1e, 0x31041ba4, 0x443c30ad,   // rm.it.sa_433 mi.sa.un_830  tr.fi.az_433 uz.ug.kk_643 
  0x241b4611, 0x255173ee, 0x04381ba7, 0x0e0c4208,   // qu.tr.eo_653 ny.kl.eu_422  tr.tk.fi_532 co.sv.is_443 
  0x5c005211, 0x1b02030c, 0x056b0709, 0x1b384607,   // ha.sa.un_630 nl.da.tr_543  it.ceb.fr_444 qu.tk.tr_432 
  // [12950]
  0x03003502, 0x1b002904, 0x125c1a05, 0x20004c11,   // zu.nl.un_220 sl.tr.un_320  tl.sa.hu_333 wo.sq.un_630 
  0x3e0c390c, 0x12001b1a, 0x1b311aa7, 0x24393f12,   // br.sv.rm_543 tr.hu.un_760  tl.az.tr_532 af.br.eo_654 
  0x1b000108, 0x1b005421, 0x40032ca0, 0xfc03480c,   // en.tr.un_430 ik.tr.un_860  fy.nl.lb_322 tt.nl.zzp_543 
  0x422e0e07, 0x1b5246ee, 0x425505a6, 0x03381ba4,   // is.fo.co_432 qu.ha.tr_422  fr.rw.co_521 tr.tk.nl_433 
  // [12960]
  0x461b3155, 0x630c2ca0, 0xfe004604, 0x2800fe0c,   // az.tr.qu_442 fy.sv.sco_322  qu.tlh.un_320 tlh.sw.un_530 
  0x091f1a0c, 0x21002811, 0x1f000912, 0x27062d07,   // tl.cy.pl_543 sd.fa.un_630  pl.cy.un_640 sk.de.gd_432 
  0x2344480c, 0x1936220c, 0x34534c04, 0x53005e08,   // tt.kk.ky_543 oc.gn.gl_543  wo.ht.xh_332 ts.ht.un_430 
  0x57004e0e, 0x4e673808, 0x67005714, 0x53002f05,   // ay.na.un_550 tk.ak.ay_443  na.ak.un_660 su.ht.un_330 
  // [12970]
  0x303421ac, 0x21281809, 0x3e002204, 0x29003208,   // fa.ps.uz_632 ar.sd.fa_444  oc.rm.un_320 bs.sl.un_430 
  0x450a05ad, 0x37481508, 0x35604a12, 0x654b2ba0,   // fr.pt.ln_643 un.tt.ba_443  yo.vo.zu_654 vi.mi.gv_322 
  0x34282e08, 0x3f352807, 0x38004a05, 0x114c6bad,   // fo.sw.xh_443 sw.zu.af_432  yo.tk.un_330 ceb.wo.ro_643 
  0x344363a0, 0x5a280a05, 0x1a006b05, 0x04006007,   // sco.ie.xh_322 pt.sw.sm_333  ceb.tl.un_330 vo.fi.un_420 
  // [12980]
  0x56000509, 0x6800040d, 0x180930a0, 0x63001f14,   // fr.mg.un_440 fi.ig.un_540  uz.pl.ga_322 cy.sco.un_660 
  0x2d004805, 0x06400c02, 0x2e08020d, 0x3e002102,   // tt.sk.un_330 sv.lb.de_222  da.no.fo_554 jw.rm.un_220 
  0x2c003e04, 0x511a790b, 0x1d075407, 0x15394602,   // rm.fy.un_320 war.tl.kl_542  ik.it.la_432 qu.br.un_222 
  0x05190aa7, 0x36001b08, 0x49283ea7, 0x756e3714,   // pt.gl.fr_532 tr.gn.un_430  rm.sw.to_532 st.hmn.nso_666 
  // [12990]
  0x0400350e, 0x3f0379ee, 0x1b5364a7, 0x04191f11,   // tg.ru.un_550 war.nl.af_422  lg.ht.tr_532 cy.gl.fi_653 
  0x13046a12, 0x2a4a6808, 0x092d0da9, 0x3800060c,   // haw.fi.et_654 ig.yo.mt_443  cs.sk.pl_544 de.tk.un_530 
  0xfc365c55, 0x27576904, 0x532e20a0, 0x16002708,   // sa.gn.zzp_442 mfe.na.gd_332  sq.fo.ht_322 gd.hr.un_430 
  0x09392dee, 0x130c04a6, 0x0d090c07, 0x331548a0,   // sk.br.pl_422 fi.sv.et_521  sv.pl.cs_432 tt.nn.un_320 
  // [129a0]
  0x2800090c, 0x69233e60, 0x1cfc2f04, 0x09375f0c,   // pl.sw.un_530 rm.ca.mfe_664  su.zzp.id_332 tn.st.pl_543 
  0x682869af, 0x0d001219, 0x40182712, 0x28181608,   // mfe.sw.ig_655 hu.cs.un_750  gd.ga.lb_654 th.ar.sd_443 
  0x48371008, 0x1dfcfea7, 0x1530350c, 0x19360ba0,   // be.ba.tt_443 tlh.zzp.la_532  tg.uz.un_543 es.gn.gl_322 
  0x246563a0, 0x63180912, 0x0a2c2d0c, 0x09003613,   // sco.gv.eo_322 pl.ga.sco_654  sk.fy.pt_543 gn.pl.un_650 
  // [129b0]
  0x1d07fca7, 0x426b1dad, 0x035342a0, 0x5c004c12,   // zzp.it.la_532 la.ceb.co_643  co.ht.nl_322 wo.sa.un_640 
  0x1000460e, 0x0225fca0, 0x6a005c09, 0x03001004,   // qu.lt.un_550 zzp.eu.da_322  sa.haw.un_440 lt.nl.un_320 
  0x30350a02, 0x3900240e, 0x2c005907, 0x2c004f04,   // mk.tg.uz_222 eo.br.un_550  rn.fy.un_420 bi.fy.un_320 
  0x3f1001a0, 0x3c303755, 0x350a3007, 0x5e2e0e12,   // en.lt.af_322 ba.uz.ug_442  uz.mk.tg_432 is.fo.ts_654 
  // [129c0]
  0x28121811, 0x05005318, 0x2500131b, 0x35303613,   // ar.ur.sd_653 ht.fr.un_740  et.eu.un_770 ab.uz.tg_665 
  0x084d49a4, 0x3e0e30a0, 0x43112608, 0x1a512408,   // to.aa.no_433 uz.is.rm_322  ia.ro.ie_443 eo.kl.tl_443 
  0x300437a0, 0x595524ec, 0x3b643813, 0x1d18510c,   // ba.ru.uz_322 eo.rw.rn_644  tk.lg.so_665 kl.ga.la_543 
  0x2f791a11, 0x1a595508, 0x0a000507, 0x35342c0c,   // tl.war.su_653 rw.rn.tl_443  fr.pt.un_420 fy.xh.zu_543 
  // [129d0]
  0x1f2ffc0c, 0x542451a9, 0x1a5559a7, 0x59545112,   // zzp.su.cy_543 kl.eo.ik_544  rn.rw.tl_532 kl.ik.rn_654 
  0x51281a08, 0x3725100c, 0x156bfca4, 0x233825a7,   // tl.sw.kl_443 be.mn.ba_543  zzp.ceb.un_433 mn.tk.ky_532 
  0x03001809, 0x442530a4, 0x51000a07, 0x3f002012,   // ga.nl.un_440 uz.mn.kk_433  pt.kl.un_420 sq.af.un_640 
  0x4d42050c, 0x15043607, 0x3f002f13, 0x00002f2d,   // fr.co.aa_543 ab.ru.un_432  su.af.un_650 su.un.un_A00 
  // [129e0]
  0x4c002f23, 0x5f422f0c, 0x3908020d, 0x472f57a4,   // su.wo.un_880 su.co.tn_543  da.no.br_554 na.su.sn_433 
  0x10170809, 0x252f1f12, 0x183c2312, 0x17083504,   // uk.sr.be_444 cy.su.eu_654  ky.ug.ar_654 tg.uk.sr_332 
  0x1f39495a, 0x131c0d07, 0x254c2fad, 0x4c00470e,   // to.br.cy_553 ne.mr.bh_432  su.wo.eu_643 sn.wo.un_550 
  0x223f2f13, 0x08232502, 0x47002f12, 0x28005e04,   // su.af.oc_665 mn.ky.uk_222  su.sn.un_640 ts.sw.un_320 
  // [129f0]
  0x1f2f47a7, 0x4c2f4908, 0x2b002e08, 0x453efea0,   // sn.su.cy_532 to.su.wo_443  fo.vi.un_430 tlh.rm.ln_322 
  0x073036ee, 0x212834a4, 0x36655512, 0x0200360c,   // ab.uz.bg_422 ps.sd.fa_433  rw.gv.gn_654 gn.da.un_530 
  0x2c643605, 0x2e002502, 0x11241909, 0x24164607,   // gn.lg.fy_333 eu.fo.un_220  gl.eo.ro_444 qu.hr.eo_432 
  0x353468a6, 0x12001820, 0x20003f0c, 0x092d4ca9,   // ig.xh.zu_521 ar.ur.un_850  af.sq.un_530 wo.sk.pl_544 
  // [12a00]
  0x550e2ea7, 0x48233811, 0x1d003607, 0x033f56af,   // fo.is.rw_532 tk.ky.tt_653  gn.la.un_420 mg.af.nl_655 
  0x6a4b4911, 0x4b6a49ec, 0x1c631311, 0x2b006a08,   // to.mi.haw_653 to.haw.mi_644  et.sco.id_653 haw.vi.un_430 
  0x13004604, 0x032c0107, 0x365e460c, 0x52006808,   // qu.et.un_320 en.fy.nl_432  qu.ts.gn_543 ig.ha.un_430 
  0x035f40a0, 0x653957a7, 0x112f2108, 0x09281ca4,   // lb.tn.nl_322 na.br.gv_532  jw.su.ro_443 id.sw.pl_433 
  // [12a10]
  0x56672c07, 0x353446ec, 0x5a4901a0, 0x5e473608,   // fy.ak.mg_432 qu.xh.zu_644  en.to.sm_322 gn.sn.ts_443 
  0x476035ec, 0x18282307, 0x28644609, 0x523629a0,   // zu.vo.sn_644 ky.sd.ar_432  qu.lg.sw_444 sl.gn.ha_322 
  0x362846ec, 0x17095208, 0x3500100d, 0x594636a9,   // qu.sw.gn_644 ha.pl.sr_443  be.tg.un_540 gn.qu.rn_544 
  0x215511ee, 0x37003d13, 0x474b460c, 0x09521207,   // ro.rw.jw_422 ku.ba.un_650  qu.mi.sn_543 hu.ha.pl_432 
  // [12a20]
  0x28125c55, 0x5c293607, 0x2900320c, 0x430b11a4,   // sa.hu.sw_442 gn.sl.sa_432  bs.sl.un_530 ro.es.ie_433 
  0x0d3936ee, 0x502c0904, 0x3500040d, 0x130d5ca4,   // gn.br.cs_422 pl.fy.fj_332  ru.tg.un_540 sa.ne.bh_433 
  0x12340ea9, 0x30234814, 0x04003709, 0x071035a7,   // is.xh.hu_544 tt.ky.uz_666  ba.ru.un_440 tg.be.bg_532 
  0x5600360c, 0x0e2e3607, 0x09001013, 0x152504a9,   // gn.mg.un_530 gn.fo.is_432  lt.pl.un_650 ru.mn.un_544 
  // [12a30]
  0x0900102a, 0x10001522, 0x481715ee, 0x24006502,   // lt.pl.un_970 un.be.un_870  un.sr.tt_422 gv.eo.un_220 
  0x173510a7, 0x02233e0b, 0x10000923, 0x070437ec,   // be.tg.sr_532 rm.ca.da_542  pl.lt.un_880 ba.ru.bg_644 
  0x103511ee, 0x0d095ca7, 0x211c1e11, 0x4d1e1c60,   // ro.tg.be_422 sa.hi.ne_532  ms.id.jw_653 id.ms.aa_664 
  0x1d002b04, 0x0e004a02, 0x09001704, 0x08231013,   // vi.la.un_320 yo.is.un_220  sr.pl.un_320 be.ky.uk_665 
  // [12a40]
  0x09001021, 0x0700440d, 0x1d1623ee, 0x1a4d095a,   // lt.pl.un_860 kk.bg.un_540  ca.hr.la_422 pl.aa.tl_553 
  0x505a0909, 0x2b00610c, 0x23253709, 0x44151555,   // pl.sm.fj_444 za.vi.un_530  ba.mn.ky_444 un.kk.un_420 
  0x1a005c07, 0x2f005c21, 0x1b541a05, 0x2d1709a0,   // sa.tl.un_420 sa.su.un_860  tl.ik.tr_333 pl.sr.sk_322 
  0x5c006b05, 0x2d2e0eee, 0x5c4654ac, 0x06302ca0,   // ceb.sa.un_330 is.fo.sk_422  ik.qu.sa_632 fy.uz.de_322 
  // [12a50]
  0x6b5c5304, 0x16000908, 0x12003302, 0x04005302,   // ht.sa.ceb_332 pl.hr.un_430  nn.hu.un_220 ht.fi.un_220 
  0x44081504, 0x2e3065a0, 0x53000404, 0x206530a0,   // un.uk.kk_332 gv.uz.fo_322  fi.ht.un_320 uz.gv.sq_322 
  0x03002009, 0x0417080c, 0x6b4654ee, 0x31002a08,   // sq.nl.un_440 uk.sr.ru_543  ik.qu.ceb_422 mt.az.un_430 
  0x12283baf, 0x5a2218a4, 0x5c1c13a9, 0x4600792b,   // ks.sd.ur_655 ga.oc.sm_433  bh.mr.sa_544 war.qu.un_980 
  // [12a60]
  0x074236a0, 0x0b001804, 0x27106305, 0x25374807,   // gn.co.it_322 ga.es.un_320  sco.lt.gd_333 tt.ba.mn_432 
  0x041b13ad, 0x07462402, 0x04154408, 0x0c330860,   // et.tr.fi_643 eo.qu.it_222  kk.ru.un_430 no.nn.sv_664 
  0x2d09650d, 0xfc2724a0, 0x36004602, 0x33001002,   // gv.pl.sk_554 eo.gd.zzp_322  qu.gn.un_220 lt.nn.un_220 
  0x15041513, 0x36000f04, 0x06003e0c, 0x100a4604,   // un.ru.un_665 lv.gn.un_320  rm.de.un_530 qu.pt.lt_332 
  // [12a70]
  0x33084cec, 0x1828235a, 0x0c084ca9, 0x353008a0,   // wo.no.nn_644 ky.sd.ar_553  wo.no.sv_544 uk.uz.tg_322 
  0x48442311, 0x304425a7, 0x08651fa7, 0x21343daf,   // ky.kk.tt_653 mn.kk.uz_532  cy.gv.no_532 ku.ps.fa_655 
  0x190b4ea9, 0x10080a08, 0x21343d13, 0x32000205,   // ay.es.gl_544 mk.uk.be_443  ku.ps.fa_665 da.bs.un_330 
  0x5e347309, 0x4a006414, 0x10043507, 0x07230a07,   // ny.xh.ts_444 lg.yo.un_660  tg.ru.be_432 mk.ky.bg_432 
  // [12a80]
  0x071711a0, 0x1f006404, 0x11231508, 0x47785e13,   // ro.sr.bg_322 lg.cy.un_320  un.ky.ro_443 ts.ve.sn_665 
  0x34123004, 0x56024ca9, 0x1c041360, 0x0c335fa0,   // uz.ur.ps_332 wo.da.mg_544  et.fi.id_664 tn.nn.sv_322 
  0x095f01ad, 0x0a003904, 0x68005f0d, 0x375e2da0,   // en.tn.pl_643 br.pt.un_320  tn.ig.un_540 sk.ts.st_322 
  0x092960a4, 0x15041104, 0x1f1024a4, 0x785f49af,   // vo.sl.pl_433 ro.ru.un_332  eo.lt.cy_433 to.tn.ve_655 
  // [12a90]
  0x27694304, 0x28442107, 0x644a3705, 0x09472407,   // ie.mfe.gd_332 fa.kk.sd_432  st.yo.lg_333 eo.sn.pl_432 
  0x6a4869af, 0x6b3064a7, 0x01193002, 0x1e2d02ee,   // mfe.tt.haw_655 lg.uz.ceb_532  uz.gl.en_222 da.sk.ms_422 
  0x247356a6, 0x122506a0, 0x64577314, 0x06fe3e07,   // mg.ny.eo_521 de.eu.hu_322  ny.na.lg_666 rm.tlh.de_432 
  0x6702400c, 0x50482aa0, 0x782005ec, 0x2d244fa6,   // lb.da.ak_543 mt.tt.fj_322  fr.sq.ve_644 bi.eo.sk_521 
  // [12aa0]
  0x24296a0c, 0x100f250c, 0x12284404, 0x484437ec,   // haw.sl.eo_543 eu.lv.lt_543  kk.sd.ur_332 ba.kk.tt_644 
  0x17300709, 0x533f4204, 0x2f005d13, 0x34000602,   // bg.uz.sr_444 co.af.ht_332  ss.su.un_650 de.xh.un_220 
  0x48382309, 0x09001220, 0x2500232b, 0x35343608,   // ky.tk.tt_444 hu.pl.un_850  ky.mn.un_980 gn.xh.zu_443 
  0x40190608, 0x123034ec, 0x49006307, 0x0c253bee,   // de.gl.lb_443 ps.uz.ur_644  sco.to.un_420 so.eu.sv_422 
  // [12ab0]
  0x4d000a0e, 0x56000913, 0x19346904, 0x4c6b5308,   // pt.aa.un_550 pl.mg.un_650  mfe.xh.gl_332 ht.ceb.wo_443 
  0xfe004c0e, 0x3b00340d, 0x3b130914, 0x231925a4,   // wo.tlh.un_550 xh.so.un_540  hi.bh.ks_666 eu.gl.ca_433 
  0x15004c18, 0x0d2d5cad, 0x4d003413, 0x09003404,   // wo.un.un_740 sa.sk.cs_643  xh.aa.un_650 xh.pl.un_320 
  0x0a073507, 0x05023407, 0x63001914, 0x5e3b345a,   // tg.bg.mk_432 xh.da.fr_432  gl.sco.un_660 xh.so.ts_553 
  // [12ac0]
  0x031d4ca9, 0x1d002e04, 0x10350807, 0x20125d0c,   // wo.la.nl_544 fo.la.un_320  uk.tg.be_432 ss.hu.sq_543 
  0x526e620c, 0x12002012, 0x3c3021a9, 0x440a380c,   // kha.hmn.ha_543 sq.hu.un_640  fa.uz.ug_544 tk.mk.kk_543 
  0x213d3405, 0x1865270c, 0x352548a9, 0x120c2a12,   // ps.ku.fa_333 gd.gv.ga_543  tt.mn.tg_544 mt.sv.hu_654 
  0x3800101b, 0x2a201212, 0x04480802, 0x05006505,   // be.tk.un_770 hu.sq.mt_654  uk.tt.ru_222 gv.fr.un_330 
  // [12ad0]
  0x65006e07, 0x4425380c, 0x401b0607, 0x09033fa0,   // hmn.gv.un_420 tk.mn.kk_543  de.tr.lb_432 af.nl.pl_322 
  0x2f122107, 0x100708ee, 0x04644aac, 0x440823a4,   // jw.hu.su_432 uk.bg.be_422  yo.lg.fi_632 ky.uk.kk_433 
  0x07171504, 0x27203ea0, 0x656263ad, 0x46001004,   // un.sr.bg_332 rm.sq.gd_322  sco.kha.gv_643 lt.qu.un_320 
  0x13006819, 0x27246502, 0x05006008, 0x11505a05,   // ig.et.un_750 gv.eo.gd_222  vo.fr.un_430 sm.fj.ro_333 
  // [12ae0]
  0x15321602, 0x5700461a, 0x284773a0, 0x2e1b38a4,   // hr.bs.un_222 qu.na.un_760  ny.sn.sw_322 tk.tr.fo_433 
  0x48330802, 0x34644a07, 0x21571a0d, 0x383031a4,   // no.nn.tt_222 yo.lg.xh_432  tl.na.jw_554 az.uz.tk_433 
  0x311b1ea4, 0x2a004002, 0x30233c12, 0x38040eee,   // ms.tr.az_433 lb.mt.un_220  ug.ky.uz_654 is.fi.tk_422 
  0x0e313808, 0x31240e04, 0x0238300c, 0x0a303cee,   // tk.az.is_443 is.eo.az_332  uz.tk.da_543 ug.uz.mk_422 
  // [12af0]
  0x5a005c0e, 0x1b483804, 0x04023107, 0x1b382e08,   // sa.sm.un_550 tk.tt.tr_332  az.da.fi_432 fo.tk.tr_443 
  0x381b3109, 0x381b310d, 0x343b0fa7, 0x35440a07,   // az.tr.tk_444 az.tr.tk_554  lv.so.xh_532 mk.kk.tg_432 
  0x1c1b210c, 0x040715a7, 0x1218440c, 0x4418285a,   // jw.tr.id_543 un.bg.ru_532  kk.ar.ur_543 sd.ar.kk_553 
  0x3038230e, 0x63003b0e, 0x6b451d07, 0x233421ad,   // ky.tk.uz_555 so.sco.un_550  la.ln.ceb_432 fa.ps.ky_643 
  // [12b00]
  0x2f311004, 0x4817360b, 0x52000e04, 0x483837af,   // lt.az.su_332 ab.sr.tt_542  is.ha.un_320 ba.tk.tt_655 
  0x1a6b79ec, 0x05002302, 0x1523440d, 0x364c2304,   // war.ceb.tl_644 ca.fr.un_220  kk.ky.un_554 ca.wo.gn_332 
  0x443723a0, 0x486b1a04, 0x05564cee, 0x0b000a12,   // ky.ba.kk_322 tl.ceb.tt_332  wo.mg.fr_422 pt.es.un_640 
  0x48303809, 0x3d342102, 0x15003621, 0x04376311,   // tk.uz.tt_444 fa.ps.ku_222  ab.un.un_860 sco.st.fi_653 
  // [12b10]
  0x5f674912, 0x362b1c04, 0x043f65ee, 0x3f6a1809,   // to.ak.tn_654 id.vi.gn_332  gv.af.fi_422 ga.haw.af_444 
  0x65000404, 0x496a6312, 0xfe4b65a0, 0x672f61ad,   // fi.gv.un_320 sco.haw.to_654  gv.mi.tlh_322 za.su.ak_643 
  0x190b1faf, 0x09653912, 0x3f00632b, 0x151d2507,   // cy.es.gl_655 br.gv.pl_654  sco.af.un_980 eu.la.un_432 
  0x092e0eee, 0x63005f23, 0x58651f0c, 0x584a1da0,   // is.fo.pl_422 tn.sco.un_880  cy.gv.om_543 la.yo.om_322 
  // [12b20]
  0x1d00fc12, 0x39006319, 0x380f0ea0, 0x041730a0,   // zzp.la.un_640 sco.br.un_750  is.lv.tk_322 uz.sr.ru_322 
  0x09001f1a, 0x4b1d39a4, 0x2efc120c, 0x2f2163ad,   // cy.pl.un_760 br.la.mi_433  hu.zzp.fo_543 sco.jw.su_643 
  0x0cfc1207, 0x04005905, 0x1d365a07, 0x63212f12,   // hu.zzp.sv_432 rn.fi.un_330  sm.gn.la_432 su.jw.sco_654 
  0x4b006334, 0x042029ad, 0x0910020c, 0x624301a0,   // sco.mi.un_A80 sl.sq.fi_643  da.lt.pl_543 en.ie.kha_322 
  // [12b30]
  0x233610ee, 0x235c04a7, 0x08251114, 0x0400281a,   // be.ab.ky_422 fi.sa.ca_532  ro.mn.uk_666 sw.fi.un_760 
  0x1200fc1a, 0x0c001f11, 0x29002804, 0x1336280d,   // zzp.hu.un_760 cy.sv.un_630  sw.sl.un_320 sw.gn.et_554 
  0x233748a9, 0x0500090b, 0x1548380e, 0x36fc10ec,   // tt.ba.ky_544 pl.fr.un_520  tk.tt.un_555 lt.zzp.gn_644 
  0x35000805, 0x09fc10a4, 0x172804a9, 0x1e3b1002,   // uk.tg.un_330 lt.zzp.pl_433  fi.sw.sr_544 lt.so.ms_222 
  // [12b40]
  0x3600091b, 0x201304ee, 0x05003f08, 0x1309040c,   // pl.gn.un_770 fi.et.sq_422  af.fr.un_430 fi.pl.et_543 
  0x2f2104ee, 0x33081202, 0x2b002e02, 0x213d30ad,   // fi.jw.su_422 hu.no.nn_222  fo.vi.un_220 uz.ku.fa_643 
  0x3b28120c, 0x17163309, 0x1000370d, 0x08020309,   // ur.sd.ks_543 nn.hr.sr_444  ba.be.un_540 nl.da.no_444 
  0x06020da0, 0x0a362204, 0x40120912, 0x19360bec,   // cs.da.de_322 oc.gn.pt_332  pl.hu.lb_654 es.gn.gl_644 
  // [12b50]
  0x330212a0, 0x3b001602, 0x0407115a, 0x2e00670c,   // hu.da.nn_322 hr.so.un_220  ro.bg.ru_553 ak.fo.un_530 
  0x5000070d, 0x2a001007, 0x4c4d6712, 0x1d003b08,   // it.fj.un_540 lt.mt.un_420  ak.aa.wo_654 so.la.un_430 
  0x750b5f09, 0x65191d05, 0x0b005619, 0xfc100ca0,   // tn.es.nso_444 la.gl.gv_333  mg.es.un_750 sv.lt.zzp_322 
  0x3d00342b, 0x191d0a0c, 0x2d5d4aa4, 0x1f004e1a,   // ps.ku.un_980 pt.la.gl_543  yo.ss.sk_433 ay.cy.un_760 
  // [12b60]
  0x21004d13, 0x2d0d0ea7, 0x12281812, 0x123d2108,   // aa.jw.un_650 is.cs.sk_532  ar.sd.ur_654 fa.ku.ur_443 
  0x08070a12, 0x2000290c, 0x1b4d4607, 0x46304ead,   // mk.bg.uk_654 sl.sq.un_530  qu.aa.tr_432 ay.uz.qu_643 
  0x02651a12, 0x1100170c, 0x2348380e, 0x65003b0d,   // tl.gv.da_654 sr.ro.un_530  tk.tt.ky_555 so.gv.un_540 
  0x35483008, 0x4c3830a0, 0x4c4d300b, 0x30484604,   // uz.tt.tg_443 uz.tk.wo_322  uz.aa.wo_542 qu.tt.uz_332 
  // [12b70]
  0x056a390c, 0x014f46a0, 0x53760107, 0x65670505,   // br.haw.fr_543 qu.bi.en_322  en.crs.ht_432 fr.ak.gv_333 
  0x58306512, 0x1d4905a0, 0x0a485608, 0x60760107,   // gv.uz.om_654 fr.to.la_322  mg.tt.pt_443 en.crs.vo_432 
  0x30253c0b, 0x283412ec, 0x78490208, 0x47051d0c,   // ug.mn.uz_542 ur.ps.sd_644  da.to.ve_443 la.fr.sn_543 
  0x024b0408, 0x036505ee, 0x1000381b, 0x395a05ee,   // fi.mi.da_443 fr.gv.nl_422  tk.be.un_770 fr.sm.br_422 
  // [12b80]
  0x220539ee, 0x09130d04, 0x05192204, 0x65000504,   // br.fr.oc_422 ne.bh.hi_332  oc.gl.fr_332 fr.gv.un_320 
  0x390563a0, 0x09731fa9, 0x350a170c, 0x47005a23,   // sco.fr.br_322 cy.ny.pl_544  sr.mk.tg_543 sm.sn.un_880 
  0x053965ee, 0x49003904, 0x303c210c, 0x0c004c0e,   // gv.br.fr_422 br.to.un_320  fa.ug.uz_543 wo.sv.un_550 
  0x0c0833a9, 0x40007308, 0x10352505, 0x13002e05,   // nn.no.sv_544 ny.lb.un_430  mn.tg.be_333 fo.et.un_330 
  // [12b90]
  0x15364f55, 0x04000c11, 0x15103611, 0x160f1004,   // bi.gn.un_442 sv.fi.un_630  ab.be.un_653 lt.lv.hr_332 
  0x1b3138a0, 0x0cfc53a7, 0x5c006b11, 0x3508170d,   // tk.az.tr_322 ht.zzp.sv_532  ceb.sa.un_630 sr.uk.tg_554 
  0x1200400b, 0x09126904, 0x362348ad, 0x3600480d,   // lb.hu.un_520 mfe.hu.pl_332  tt.ky.ab_643 tt.gn.un_540 
  0x3e1242a0, 0x30483ca9, 0x17353607, 0x530a5704,   // co.hu.rm_322 ug.tt.uz_544  ab.tg.sr_432 na.pt.ht_332 
  // [12ba0]
  0x3e2312ad, 0x38190bee, 0x19004c09, 0x25100405,   // hu.ca.rm_643 es.gl.tk_422  wo.gl.un_440 ru.be.mn_333 
  0x3c1844ac, 0x171025a7, 0x121821ac, 0x0b4c360b,   // kk.ar.ug_632 mn.be.sr_532  fa.ar.ur_632 gn.wo.es_542 
  0x51fc1f08, 0x1d2643a4, 0x637338a4, 0x55474507,   // cy.zzp.kl_443 ie.ia.la_433  tk.ny.sco_433 ln.sn.rw_432 
  0x28027307, 0x3000071a, 0x023f0313, 0x64003507,   // ny.da.sw_432 bg.uz.un_760  nl.af.da_665 zu.lg.un_420 
  // [12bb0]
  0x7900fc19, 0x2a090207, 0x301b3113, 0x364a5907,   // zzp.war.un_750 da.pl.mt_432  az.tr.uz_665 rn.yo.gn_432 
  0x684d2d07, 0x326501a0, 0x15fe39a0, 0x5c1c1309,   // sk.aa.ig_432 en.gv.bs_322  br.tlh.un_322 bh.mr.sa_444 
  0x1f281502, 0x58001505, 0x0400fc0b, 0x15081705,   // un.sw.cy_222 un.om.un_330  zzp.fi.un_520 sr.uk.un_333 
  0x5b004a22, 0x1100250e, 0x48003905, 0x33001307,   // yo.sg.un_870 mn.ro.un_550  br.tt.un_330 et.nn.un_420 
  // [12bc0]
  0x2a000918, 0x110823a4, 0x353017ad, 0x103815a4,   // pl.mt.un_740 ky.uk.ro_433  sr.uz.tg_643 un.tk.be_433 
  0x28121860, 0xfc021207, 0x3e2912a0, 0x0c3ffca7,   // ar.ur.sd_664 hu.da.zzp_432  hu.sl.rm_322 zzp.af.sv_532 
  0x2c002323, 0x080c02a4, 0x36002313, 0x03001218,   // ca.fy.un_880 da.sv.no_433  ca.gn.un_650 hu.nl.un_740 
  0x150417a0, 0x1d545111, 0x2a026212, 0x09652aaf,   // sr.ru.un_322 kl.ik.la_653  kha.da.mt_654 mt.gv.pl_655 
  // [12bd0]
  0x2e006304, 0x39004c04, 0x0167620c, 0x53006205,   // sco.fo.un_320 wo.br.un_320  kha.ak.en_543 kha.ht.un_330 
  0x38303513, 0x5a033f07, 0x09002a07, 0x382a62ec,   // tg.uz.tk_665 af.nl.sm_432  mt.pl.un_420 kha.mt.tk_644 
  0x15071707, 0x1c00340c, 0x6a2260ee, 0x44002105,   // sr.bg.un_432 xh.id.un_530  vo.oc.haw_422 fa.kk.un_330 
  0x2324fc0b, 0x2a790907, 0x53386711, 0x53002a0c,   // zzp.eo.ca_542 pl.war.mt_432  ak.tk.ht_653 mt.ht.un_530 
  // [12be0]
  0x3f034204, 0x53676207, 0x631124ec, 0x3062205a,   // co.nl.af_332 kha.ak.ht_432  eo.ro.sco_644 sq.kha.uz_553 
  0x30314808, 0x1c027308, 0x39004807, 0x2b301cee,   // tt.az.uz_443 ny.da.id_443  tt.br.un_420 id.uz.vi_422 
  0x552f21af, 0x4817440c, 0x2b005508, 0x2f005c02,   // jw.su.rw_655 kk.sr.tt_543  rw.vi.un_430 sa.su.un_220 
  0x483002ee, 0xfc2e38a0, 0x2f1b46ee, 0x05004a0e,   // da.uz.tt_422 tk.fo.zzp_322  qu.tr.su_422 yo.fr.un_550 
  // [12bf0]
  0x61285512, 0x055568a0, 0x535e5555, 0x384301a0,   // rw.sw.za_654 ig.rw.fr_322  rw.ts.ht_442 en.ie.tk_322 
  0x640955a4, 0x303b2a04, 0x1b00310b, 0x1008230c,   // rw.pl.lg_433 mt.so.uz_332  az.tr.un_520 ky.uk.be_543 
  0x2c006502, 0x09002a22, 0x311b3eec, 0x64550907,   // gv.fy.un_220 mt.pl.un_870  rm.tr.az_644 pl.rw.lg_432 
  0x303523ec, 0x2a002d04, 0x440810a0, 0x554638ad,   // ky.tg.uz_644 sk.mt.un_320  be.uk.kk_322 tk.qu.rw_643 
  
  // [12c00]
  0x3e311b0c, 0x40481ba0, 0x6b6438ec, 0x441834ee,   // tr.az.rm_543 tr.tt.lb_322  tk.lg.ceb_644 ps.ar.kk_422 
  0x231038af, 0x0f001023, 0x63790107, 0x28003f04,   // tk.be.ky_655 lt.lv.un_880  en.war.sco_432 af.sw.un_320 
  0x17002702, 0x0a170412, 0x3b1218a4, 0x59696e12,   // gd.sr.un_220 ru.sr.mk_654  ar.ur.ks_433 hmn.mfe.rn_654 
  0x0a001502, 0x234844af, 0x1c005609, 0x105c0f08,   // un.pt.un_220 kk.tt.ky_655  mg.id.un_440 lv.sa.lt_443 
  // [12c10]
  0x0d090aa0, 0x101b06a0, 0x03065708, 0x4b005c02,   // pt.pl.cs_322 de.tr.lt_322  na.de.nl_443 sa.mi.un_220 
  0x2c005607, 0x3865620c, 0x041508ad, 0x11004413,   // mg.fy.un_420 kha.gv.tk_543  uk.ru.un_630 kk.ro.un_650 
  0x3d182804, 0x2e00120e, 0x27000d04, 0x3f030da0,   // sd.ar.ku_332 hu.fo.un_550  cs.gd.un_320 cs.nl.af_322 
  0x3f1b390c, 0x09130da6, 0x31000104, 0x2d001b04,   // br.tr.af_543 cs.et.pl_521  en.az.un_320 tr.sk.un_320 
  // [12c20]
  0x311b60ba, 0x022e38ec, 0x2e001d07, 0x5f3e3908,   // vo.tr.az_843 tk.fo.da_644  la.fo.un_420 br.rm.tn_443 
  0x484411a9, 0x136458ee, 0x5f003e14, 0x1b3825a0,   // ro.kk.tt_544 om.lg.et_422  rm.tn.un_660 eu.tk.tr_322 
  0x203e3811, 0x5c00790c, 0x2e200e08, 0x3e100e08,   // tk.rm.sq_653 war.sa.un_530  is.sq.fo_443 is.lt.rm_443 
  0x212324a4, 0x2500210e, 0x24291009, 0x57381e07,   // eo.ca.jw_433 jw.eu.un_550  lt.sl.eo_444 ms.tk.na_432 
  // [12c30]
  0x283825ad, 0x11001b07, 0x3b2e0ea4, 0x1707100d,   // eu.tk.sw_643 tr.ro.un_420  is.fo.so_433 be.bg.sr_554 
  0x28002007, 0x39383e07, 0x230410a0, 0x370804a9,   // sq.sw.un_420 rm.tk.br_432  be.ru.ky_322 ru.uk.ba_544 
  0x0e602e13, 0x0b22250c, 0x21001d08, 0x35255f08,   // fo.vo.is_665 eu.oc.es_543  la.jw.un_430 tn.eu.zu_443 
  0x3e0e1ea4, 0x383e5f04, 0x5a001e0e, 0x01002a04,   // ms.is.rm_433 tn.rm.tk_332  ms.sm.un_550 mt.en.un_320 
  // [12c40]
  0x1c211ea4, 0x233e0e05, 0x64004609, 0x603b1307,   // ms.jw.id_433 is.rm.ca_333  qu.lg.un_440 et.so.vo_432 
  0x132a0e55, 0x4b005c0c, 0x374411ad, 0x13001804,   // is.mt.et_442 sa.mi.un_530  ro.kk.ba_643 ga.et.un_320 
  0x102338ee, 0x180e130c, 0x1200130c, 0x31111b0c,   // tk.ky.be_422 et.is.ga_543  et.hu.un_530 tr.ro.az_543 
  0x2a002505, 0x3308180e, 0x53001307, 0x08001311,   // eu.mt.un_330 ga.no.nn_555  et.ht.un_420 et.no.un_630 
  // [12c50]
  0x10154804, 0x64000604, 0x1737480b, 0x1d275a0c,   // tt.be.un_320 de.lg.un_320  tt.ba.sr_542 sm.gd.la_543 
  0x38483760, 0x3d1234a7, 0x43006021, 0x2a00fc07,   // ba.tt.tk_664 ps.ur.ku_532  vo.ie.un_860 zzp.mt.un_420 
  0x59007813, 0x0a383655, 0x47004b07, 0x05001d04,   // ve.rn.un_650 ab.tk.mk_442  mi.sn.un_420 la.fr.un_320 
  0xfc000905, 0x402c02af, 0x5a004b22, 0x02001f08,   // pl.zzp.un_330 da.fy.lb_655  mi.sm.un_870 cy.da.un_430 
  // [12c60]
  0x1948310c, 0x2e002b04, 0x1b004605, 0x050c010c,   // az.tt.gl_543 vi.fo.un_320  qu.tr.un_330 en.sv.fr_543 
  0x3e001804, 0x39001b04, 0x4c003609, 0x55fc47a0,   // ga.rm.un_320 tr.br.un_320  gn.wo.un_440 sn.zzp.rw_322 
  0x190b4ca9, 0x3b3c28a4, 0x36390b04, 0x19254cad,   // wo.es.gl_544 sd.ug.ks_433  es.br.gn_332 wo.eu.gl_643 
  0x040825a9, 0x1f002713, 0x28123012, 0x38001c02,   // mn.uk.ru_544 gd.cy.un_650  uz.ur.sd_654 id.tk.un_220 
  // [12c70]
  0x286b1dee, 0x0a6b1dee, 0x23374805, 0x281234af,   // la.ceb.sw_422 la.ceb.pt_422  tt.ba.ky_333 ps.ur.sd_655 
  0x241b315a, 0x2b232f07, 0x0800350b, 0x4c574612,   // az.tr.eo_553 su.ca.vi_432  tg.uk.un_520 qu.na.wo_654 
  0x48004c0d, 0x30002e08, 0x0b5746af, 0x19007907,   // wo.tt.un_540 fo.uz.un_430  qu.na.es_655 war.gl.un_420 
  0x5c003612, 0x190b4ca0, 0x36460b04, 0x0b4c5712,   // gn.sa.un_640 wo.es.gl_322  es.qu.gn_332 na.wo.es_654 
  // [12c80]
  0x4804080b, 0x2f005304, 0x1d00490b, 0x4c004e14,   // uk.ru.tt_542 ht.su.un_320  to.la.un_520 ay.wo.un_660 
  0x190b465a, 0x1e004904, 0x3600790e, 0x553759a0,   // qu.es.gl_553 to.ms.un_320  war.gn.un_550 rn.st.rw_322 
  0x194c0b55, 0x0b004c1a, 0x12281808, 0x5200581a,   // es.wo.gl_442 wo.es.un_760  ar.sd.ur_443 om.ha.un_760 
  0x17100a04, 0x52004d2b, 0x02330860, 0x1b315855,   // mk.be.sr_332 aa.ha.un_980  no.nn.da_664 om.az.tr_442 
  // [12c90]
  0x561f0d07, 0x330863ec, 0x24003602, 0x752d0d0c,   // cs.cy.mg_432 sco.no.nn_644  gn.eo.un_220 cs.sk.nso_543 
  0x484c57a7, 0x67684a08, 0x37080707, 0x68364512,   // na.wo.tt_532 yo.ig.ak_443  bg.uk.ba_432 ln.gn.ig_654 
  0x1d310ba0, 0x1e6367ac, 0x2f401504, 0x76534a0d,   // es.az.la_322 ak.sco.ms_632  un.lb.su_332 yo.ht.crs_554 
  0x2d005c09, 0x2c50020c, 0x1d000905, 0x2948790c,   // sa.sk.un_440 da.fj.fy_543  pl.la.un_330 war.tt.sl_543 
  // [12ca0]
  0x26000102, 0x36000602, 0x5c004c0e, 0x68000208,   // en.ia.un_220 de.gn.un_220  wo.sa.un_550 da.ig.un_430 
  0x48384cee, 0x1d315102, 0x50001f02, 0x23002a1a,   // wo.tk.tt_422 kl.az.la_222  cy.fj.un_220 mt.ca.un_760 
  0x1b1a240b, 0x5c21600c, 0x35343ea4, 0x65212fa0,   // eo.tl.tr_542 vo.jw.sa_543  rm.xh.zu_433 su.jw.gv_322 
  0x40171ca0, 0x0e525ca0, 0x1515250c, 0x1a293507,   // id.sr.lb_322 sa.ha.is_322  mn.un.un_530 zu.sl.tl_432 
  // [12cb0]
  0x0c223e55, 0x0e6138ec, 0x12005c04, 0x58105a07,   // rm.oc.sv_442 tk.za.is_644  sa.hu.un_320 sm.lt.om_432 
  0x080448a0, 0x063b40a0, 0x21200802, 0x48040807,   // tt.ru.uk_322 lb.so.de_322  no.sq.jw_222 uk.ru.tt_432 
  0x07002509, 0x31301ba0, 0x2b000705, 0x125c670e,   // mn.bg.un_440 tr.uz.az_322  it.vi.un_330 ak.sa.hu_555 
  0x201a1f04, 0x4c001909, 0x421e51a4, 0x5e5c4708,   // cy.tl.sq_332 gl.wo.un_440  kl.ms.co_433 sn.sa.ts_443 
  // [12cc0]
  0x4d2e0ea4, 0x2f5c0e05, 0x0b004c0c, 0x34005e12,   // is.fo.aa_433 is.sa.su_333  wo.es.un_530 ts.xh.un_640 
  0x07001011, 0x19002607, 0x32000704, 0x2b001d13,   // be.bg.un_630 ia.gl.un_420  it.bs.un_320 la.vi.un_650 
  0x1b383109, 0x46004c08, 0x46003911, 0x06000112,   // az.tk.tr_444 wo.qu.un_430  br.qu.un_630 en.de.un_640 
  0x02353413, 0x1d00090b, 0x10374814, 0x441011ee,   // xh.zu.da_665 pl.la.un_520  tt.ba.be_666 ro.be.kk_422 
  // [12cd0]
  0x30233cee, 0x1d00fe07, 0x12361c04, 0x020c04a0,   // ug.ky.uz_422 tlh.la.un_420  id.gn.hu_332 fi.sv.da_322 
  0x391b4807, 0x0b003907, 0x1d6063a9, 0x79432da4,   // tt.tr.br_432 br.es.un_420  sco.vo.la_544 sk.ie.war_433 
  0x1e1c210c, 0x44483009, 0x1d5c0fa7, 0x16002911,   // jw.id.ms_543 uz.tt.kk_444  lv.sa.la_532 sl.hr.un_630 
  0x374825ec, 0x0f0d29ee, 0x3f134ea7, 0x21000211,   // mn.tt.ba_644 sl.cs.lv_422  ay.et.af_532 da.jw.un_630 
  // [12ce0]
  0x31002b04, 0x486940a4, 0x35041504, 0x330238ec,   // vi.az.un_320 lb.mfe.tt_433  un.ru.tg_332 tk.da.nn_644 
  0x083517a0, 0x65003821, 0x4c4e3960, 0x384839ee,   // sr.tg.uk_322 tk.gv.un_860  br.ay.wo_664 br.tt.tk_422 
  0x28004f05, 0x641d5704, 0x350723a0, 0x01106307,   // bi.sw.un_330 na.la.lg_332  ky.bg.tg_322 sco.lt.en_432 
  0x5900570e, 0x480a04a7, 0x170435a9, 0x19295a04,   // na.rn.un_550 ru.mk.tt_532  tg.ru.sr_544 sm.sl.gl_332 
  // [12cf0]
  0x68000108, 0x395b6907, 0x3f006007, 0x330809a0,   // en.ig.un_430 mfe.sg.br_432  vo.af.un_420 pl.no.nn_322 
  0x303c485a, 0x5c0f4ba4, 0x195376a7, 0x04490207,   // tt.ug.uz_553 mi.lv.sa_433  crs.ht.gl_532 da.to.fi_432 
  0x39400202, 0x65494d08, 0x53000204, 0x684065af,   // da.lb.br_222 aa.to.gv_443  da.ht.un_320 gv.lb.ig_655 
  0x04103511, 0x4c654d0d, 0x37230407, 0x1f5a4904,   // tg.be.ru_653 aa.gv.wo_554  ru.ky.ba_432 to.sm.cy_332 
  // [12d00]
  0x18194c0c, 0x654d3f0c, 0x2d004305, 0x071038ee,   // wo.gl.ga_543 af.aa.gv_543  ie.sk.un_330 tk.be.bg_422 
  0x5868650c, 0x5c004b22, 0x041015ad, 0x6a6749ad,   // gv.ig.om_543 mi.sa.un_870  un.be.ru_643 to.ak.haw_643 
  0x1823440b, 0x13006508, 0x40636812, 0x1c2b49ee,   // kk.ky.ar_542 gv.et.un_430  ig.sco.lb_654 to.vi.id_422 
  0x4b0f5c11, 0x0f5c4b11, 0x37004820, 0x17100a05,   // sa.lv.mi_653 mi.sa.lv_653  tt.ba.un_850 mk.be.sr_333 
  // [12d10]
  0x1365fc04, 0x1200020d, 0x0758650b, 0x6551150c,   // zzp.gv.et_332 da.hu.un_540  gv.om.it_542 un.kl.gv_543 
  0x43002318, 0x51045413, 0x48045c08, 0x2e0e0da0,   // ca.ie.un_740 ik.fi.kl_665  sa.fi.tt_443 cs.is.fo_322 
  0x190b0d02, 0x22001702, 0x421123a9, 0x37480408,   // cs.es.gl_222 sr.oc.un_220  ca.ro.co_544 ru.tt.ba_443 
  0x554d590c, 0x111220a4, 0x30152305, 0x07420a07,   // rn.aa.rw_543 sq.hu.ro_433  ky.uz.un_330 pt.co.it_432 
  // [12d20]
  0x732d0aa7, 0x05421da0, 0x1d005602, 0x53004004,   // pt.sk.ny_532 la.co.fr_322  mg.la.un_220 lb.ht.un_320 
  0x11595504, 0x40005107, 0x010626a0, 0x251548ad,   // rw.rn.ro_332 kl.lb.un_420  ia.de.en_322 tt.mn.un_630 
  0x0e00640c, 0x440407a4, 0x5300400b, 0x1f005507,   // lg.is.un_530 bg.ru.kk_433  lb.ht.un_520 rw.cy.un_420 
  0x392353ad, 0x4a1218ee, 0x2d181208, 0x23000b09,   // ht.ca.br_643 ga.hu.yo_422  hu.ga.sk_443 es.ca.un_440 
  // [12d30]
  0x36001214, 0x12303405, 0x65310eec, 0x65000e14,   // hu.gn.un_660 ps.uz.ur_333  is.az.gv_644 is.gv.un_660 
  0x48170a04, 0x0b1912a7, 0x36122dec, 0x31003b0d,   // mk.sr.tt_332 hu.gl.es_532  sk.hu.gn_644 so.az.un_540 
  0x1836120d, 0x3b651f60, 0x182d0da9, 0x0f001219,   // hu.gn.ga_554 cy.gv.so_664  cs.sk.ga_544 hu.lv.un_750 
  0x362d0d17, 0x313b6504, 0x1b00651a, 0x6b220502,   // cs.sk.gn_753 gv.so.az_332  gv.tr.un_760 fr.oc.ceb_222 
  // [12d40]
  0x172515a0, 0x30006b0e, 0x35171107, 0x0448230b,   // un.mn.sr_322 ceb.uz.un_550  ro.sr.tg_432 ky.tt.ru_542 
  0x190d12a7, 0x122d0dad, 0x12192d07, 0x0300120b,   // hu.cs.gl_532 cs.sk.hu_643  sk.gl.hu_432 hu.nl.un_520 
  0x19182d55, 0x104823a4, 0x6357650c, 0x2d1219a9,   // sk.ga.gl_442 ky.tt.be_433  gv.na.sco_543 gl.hu.sk_544 
  0xfe624e09, 0x5a1d11a0, 0x122d190c, 0x6746fe0c,   // ay.kha.tlh_444 ro.la.sm_322  gl.sk.hu_543 tlh.qu.ak_543 
  // [12d50]
  0x131224a0, 0x1a4e2a0d, 0xfe4e2a0c, 0x61766709,   // eo.hu.et_322 mt.ay.tl_554  mt.ay.tlh_543 ak.crs.za_444 
  0x576b1a08, 0x6b1a7909, 0x4a000a0c, 0x485d2aee,   // tl.ceb.na_443 war.tl.ceb_444  pt.yo.un_530 mt.ss.tt_422 
  0x33081702, 0x674d5705, 0x6b6201a0, 0x4e00fe21,   // sr.no.nn_222 na.aa.ak_333  en.kha.ceb_322 tlh.ay.un_860 
  0x3e5313a0, 0x0e404ca0, 0x13004c04, 0x0c00040b,   // et.ht.rm_322 wo.lb.is_322  wo.et.un_320 fi.sv.un_520 
  // [12d60]
  0x1b004823, 0x481525a0, 0x23003413, 0x122d0aac,   // tt.tr.un_880 mn.tt.un_320  ps.ky.un_650 pt.sk.hu_632 
  0x120a2d0c, 0x1b314808, 0x12fe0a0c, 0x31005807,   // sk.pt.hu_543 tt.az.tr_443  pt.tlh.hu_543 om.az.un_420 
  0x2d120aa0, 0x0e0d2e05, 0x0704170e, 0x2d000a05,   // pt.hu.sk_322 fo.cs.is_333  sr.ru.bg_555 pt.sk.un_330 
  0x102406a0, 0x03330802, 0x06000e12, 0x6b1d4207,   // de.eo.lt_322 no.nn.nl_222  is.de.un_640 co.la.ceb_432 
  // [12d70]
  0x36190a04, 0x393b5204, 0x3b001205, 0x1f003812,   // pt.gl.gn_332 ha.so.br_332  hu.so.un_330 tk.cy.un_640 
  0x0f004004, 0x392818ee, 0x0448230c, 0x12000a1a,   // lb.lv.un_320 ga.sw.br_422  ky.tt.ru_543 pt.hu.un_760 
  0x031506a0, 0x4500470d, 0x2e000a1a, 0x55001309,   // de.nl.un_320 sn.ln.un_540  pt.fo.un_760 et.rw.un_440 
  0x484404a0, 0x0e4013ee, 0x43455a0c, 0x020c0fa0,   // ru.kk.tt_322 et.lb.is_422  sm.ln.ie_543 lv.sv.da_322 
  // [12d80]
  0x105a22a4, 0x060d2d07, 0x190a26a0, 0x37350707,   // oc.sm.lt_433 sk.cs.de_432  ia.pt.gl_322 bg.tg.ba_432 
  0x215c4608, 0x7313500c, 0x48303512, 0x55455d55,   // qu.sa.jw_443 fj.et.ny_543  tg.uz.tt_654 ss.ln.rw_442 
  0x435025ad, 0x510213ad, 0x4e545111, 0x370415ad,   // eu.fj.ie_643 et.da.kl_643  kl.ik.ay_653 un.ru.ba_643 
  0x481b3109, 0x234411ec, 0x0a192307, 0x3e1d0107,   // az.tr.tt_444 ro.kk.ky_644  ca.gl.pt_432 en.la.rm_432 
  // [12d90]
  0x120e36a0, 0x51004602, 0x0a3848a9, 0x2d122e0d,   // gn.is.hu_322 qu.kl.un_220  tt.tk.mk_544 fo.hu.sk_554 
  0x20002c0d, 0x0e12180c, 0x0b121902, 0x684a730c,   // fy.sq.un_540 ga.hu.is_543  gl.hu.es_222 ny.yo.ig_543 
  0x2c3925a0, 0x46023fa4, 0x68006723, 0x2d001218,   // eu.br.fy_322 af.da.qu_433  ak.ig.un_880 hu.sk.un_740 
  0x083c480c, 0x4a68370c, 0x4a006819, 0x2e0e2da0,   // tt.ug.uk_543 st.ig.yo_543  ig.yo.un_750 sk.is.fo_322 
  // [12da0]
  0x5a49675a, 0x2d190b02, 0x40573f08, 0x756837a9,   // ak.to.sm_553 es.gl.sk_222  af.na.lb_443 st.ig.nso_544 
  0x083048ee, 0x233c30a9, 0x7600690c, 0x313848ec,   // tt.uz.uk_422 uz.ug.ky_544  mfe.crs.un_530 tt.tk.az_644 
  0x2e003311, 0x080202a0, 0x5c000608, 0x1d29020c,   // nn.fo.un_630 da.da.no_322  de.sa.un_430 da.sl.la_543 
  0x29004005, 0x060b5105, 0x2f2e7904, 0x12213009,   // lb.sl.un_330 kl.es.de_333  war.fo.su_332 uz.fa.ur_444 
  // [12db0]
  0x1865510c, 0x1e1c1502, 0x1f003b05, 0x65453bee,   // kl.gv.ga_543 un.id.ms_222  so.cy.un_330 so.ln.gv_422 
  0x0800150b, 0x070804af, 0x2e001d1a, 0x07541aa9,   // un.uk.un_520 ru.uk.bg_655  la.fo.un_760 tl.ik.it_544 
  0x0e642ea9, 0x065102ee, 0x07251008, 0x10000a05,   // fo.lg.is_544 da.kl.de_422  be.mn.bg_443 mk.be.un_330 
  0x555f1e0c, 0x56005f0c, 0x51103004, 0x0e2e60a9,   // ms.tn.rw_543 tn.mg.un_530  uz.lt.kl_332 vo.fo.is_544 
  // [12dc0]
  0x02375fa4, 0x0700fc09, 0x42285a07, 0x28006a07,   // tn.st.da_433 zzp.it.un_440  sm.sw.co_432 haw.sw.un_420 
  0x06543ba4, 0x1f195607, 0x3d3c3b05, 0x59551c0c,   // so.ik.de_433 mg.gl.cy_432  ks.ug.ku_333 id.rw.rn_543 
  0x1dfc51ac, 0x50591ba0, 0xfc001d05, 0x592555af,   // kl.zzp.la_632 tr.rn.fj_322  la.zzp.un_330 rw.eu.rn_655 
  0x1d004d19, 0x11475407, 0x681a64a4, 0x483138a0,   // aa.la.un_750 ik.sn.ro_432  lg.tl.ig_433 tk.az.tt_322 
  // [12dd0]
  0x240f360c, 0x51036008, 0x51004d0c, 0x13fc51a4,   // gn.lv.eo_543 vo.nl.kl_443  aa.kl.un_530 kl.zzp.et_433 
  0x043511ad, 0x372338a9, 0x372510ad, 0x3d183402,   // ro.tg.ru_643 tk.ky.ba_544  be.mn.ba_643 ps.ar.ku_222 
  0x07381012, 0x1e6428a0, 0x2800211b, 0x383748af,   // be.tk.bg_654 sw.lg.ms_322  fa.sd.un_770 tt.ba.tk_655 
  0x302a5807, 0x64004c19, 0x32002c09, 0x64001f1a,   // om.mt.uz_432 wo.lg.un_750  fy.bs.un_440 cy.lg.un_760 
  // [12de0]
  0x30006408, 0x2d0d1f14, 0x130d1cac, 0x46524c5a,   // lg.uz.un_430 cy.cs.sk_666  mr.ne.bh_632 wo.ha.qu_553 
  0x13000d18, 0x26050108, 0x2f006835, 0x23631f04,   // ne.bh.un_740 en.fr.ia_443  ig.su.un_A90 cy.sco.ca_332 
  0x345d5e0d, 0x120410ee, 0x4a2468a4, 0x4600360d,   // ts.ss.xh_554 lt.fi.hu_422  ig.eo.yo_433 gn.qu.un_540 
  0x100936a0, 0x48005e05, 0x0748350d, 0xfc2e08a0,   // gn.pl.lt_322 ts.tt.un_330  tg.tt.bg_554 no.fo.zzp_322 
  // [12df0]
  0x2700080c, 0x21342312, 0xfc1033a4, 0x220b1d09,   // no.gd.un_530 ky.ps.fa_654  nn.lt.zzp_433 la.es.oc_444 
  0x033ffc08, 0x36000921, 0x09001322, 0x43260107,   // zzp.af.nl_443 pl.gn.un_860  bh.hi.un_870 en.ia.ie_432 
  0x1203fc07, 0x390929a7, 0x3b09150d, 0x303c25af,   // zzp.nl.hu_432 sl.pl.br_532  un.pl.so_554 mn.ug.uz_655 
  0x31034860, 0x330f2da0, 0x3f0e48ec, 0x0c06fc0c,   // tt.nl.az_664 sk.lv.nn_322  tt.is.af_644 zzp.de.sv_543 
  // [12e00]
  0x33083faf, 0x30173ca7, 0x2a004814, 0x372348a9,   // af.no.nn_655 ug.sr.uz_532  tt.mt.un_660 tt.ky.ba_544 
  0x426b1dee, 0x05002212, 0x482517a0, 0x0f2e04ec,   // la.ceb.co_422 oc.fr.un_640  sr.mn.tt_322 fi.fo.lv_644 
  0x381b480b, 0x19362f07, 0x240904a6, 0x05005b0c,   // tt.tr.tk_542 su.gn.gl_432  fi.pl.eo_521 sg.fr.un_530 
  0x58000409, 0x345804ad, 0x081548ad, 0x30231002,   // fi.om.un_440 fi.om.xh_643  tt.uk.un_630 be.ky.uz_222 
  // [12e10]
  0x15002907, 0x2f005e04, 0x080204a9, 0x6e1e1ca4,   // sl.un.un_420 ts.su.un_320  fi.da.no_544 id.ms.hmn_433 
  0x32004a07, 0x53042407, 0x38004812, 0x6b006e0d,   // yo.bs.un_420 eo.fi.ht_432  tt.tk.un_640 hmn.ceb.un_540 
  0x20000a07, 0x292f21a4, 0x380744ac, 0x656e0607,   // pt.sq.un_420 jw.su.sl_433  kk.bg.tk_632 de.hmn.gv_432 
  0x0e001009, 0x2a6318a0, 0x1b156ea0, 0x27005304,   // lt.is.un_440 ga.sco.mt_322  hmn.tr.un_320 ht.gd.un_320 
  // [12e20]
  0x2834210b, 0x46190bee, 0x6e4006af, 0x21234405,   // fa.ps.sd_542 es.gl.qu_422  de.lb.hmn_655 kk.ky.fa_333 
  0x3c3d3007, 0x57006e22, 0x63006e09, 0x11043505,   // uz.ku.ug_432 hmn.na.un_870  hmn.sco.un_440 tg.ru.ro_333 
  0x39005611, 0xfe002712, 0x1827fe11, 0x04003818,   // mg.br.un_630 gd.tlh.un_640  tlh.gd.ga_653 tk.ru.un_740 
  0x44304807, 0x24002207, 0x79470aa7, 0x28475805,   // tt.uz.kk_432 oc.eo.un_420  pt.sn.war_532 om.sn.sw_333 
  // [12e30]
  0x38231505, 0x312a78ee, 0x79fe6b12, 0x5c5f1012,   // un.ky.tk_333 ve.mt.az_422  ceb.tlh.war_654 lt.tn.sa_654 
  0x38026904, 0x1d1238ad, 0x5c005e05, 0x070a0412,   // mfe.da.tk_332 tk.hu.la_643  ts.sa.un_330 ru.mk.bg_654 
  0x3f043607, 0x38345ead, 0x2f001d0e, 0x2530230b,   // gn.fi.af_432 ts.xh.tk_643  la.su.un_550 ky.uz.mn_542 
  0x30243ba0, 0x11390605, 0x105c36ad, 0x05392f11,   // so.eo.uz_322 de.br.ro_333  gn.sa.lt_643 su.br.fr_653 
  // [12e40]
  0x53020507, 0x033f2fa4, 0x0d095ca6, 0x2a1bfc0d,   // fr.da.ht_432 su.af.nl_433  sa.hi.ne_521 zzp.tr.mt_554 
  0x1d002607, 0x404205a0, 0x25353814, 0x153035a0,   // ia.la.un_420 fr.co.lb_322  tk.tg.mn_666 tg.uz.un_322 
  0x4400110e, 0x3e002302, 0x1e33fca4, 0x5c000f23,   // ro.kk.un_550 ca.rm.un_220  zzp.nn.ms_433 lv.sa.un_880 
  0x01532702, 0x24004909, 0x23003d11, 0x5c25100b,   // gd.ht.en_222 to.eo.un_440  ku.ky.un_630 lt.eu.sa_542 
  // [12e50]
  0x312048a4, 0x5322fca0, 0x2500112a, 0x1b004820,   // tt.sq.az_433 zzp.oc.ht_322  ro.mn.un_970 tt.tr.un_850 
  0x6500630c, 0x03123fa0, 0x3f4803ec, 0x26021ca0,   // sco.gv.un_530 af.hu.nl_322  nl.tt.af_644 id.da.ia_322 
  0x31044804, 0x4e00462a, 0x15002f09, 0x04233811,   // tt.fi.az_332 qu.ay.un_970  su.un.un_440 tk.ky.ru_653 
  0x38003205, 0x0b002507, 0x5c090da6, 0x301135ec,   // bs.tk.un_330 eu.es.un_420  ne.hi.sa_521 tg.ro.uz_644 
  // [12e60]
  0x79331007, 0x58002808, 0x33656ba0, 0x6b4279a0,   // lt.nn.war_432 sw.om.un_430  ceb.gv.nn_322 war.co.ceb_322 
  0x130f4607, 0x2f1123ad, 0x22000502, 0x1b311307,   // qu.lv.et_432 ca.ro.su_643  fr.oc.un_220 et.az.tr_432 
  0x5158130d, 0x35300707, 0x46190bec, 0x053942ee,   // et.om.kl_554 bg.uz.tg_432  es.gl.qu_644 co.br.fr_422 
  0x13045ca9, 0x0e002d0e, 0x42231904, 0x130f2d07,   // sa.fi.et_544 sk.is.un_550  gl.ca.co_332 sk.lv.et_432 
  // [12e70]
  0x230a22a0, 0x12092e04, 0x34213ba7, 0x38190b08,   // oc.pt.ca_322 fo.pl.hu_332  ks.fa.ps_532 es.gl.tk_443 
  0x4448370d, 0x12000905, 0x20390304, 0x0d0339a7,   // ba.tt.kk_554 pl.hu.un_330  nl.br.sq_332 br.nl.cs_532 
  0x1d112407, 0x2f5936a4, 0x303428ad, 0x63131255,   // eo.ro.la_432 gn.rn.su_433  sd.ps.uz_643 hu.et.sco_442 
  0x40240a0c, 0x4a00381a, 0x59114ead, 0x03001704,   // pt.eo.lb_543 tk.yo.un_760  ay.ro.rn_643 sr.nl.un_320 
  // [12e80]
  0x40631307, 0x42250302, 0x2e0e6505, 0x212f1c08,   // et.sco.lb_432 nl.eu.co_222  gv.is.fo_333 id.su.jw_443 
  0x635701a0, 0x32160302, 0x02005002, 0x33001308,   // en.na.sco_322 nl.hr.bs_222  fj.da.un_220 et.nn.un_430 
  0x64401dee, 0x5c003605, 0x330f1004, 0x0b1323a7,   // la.lb.lg_422 gn.sa.un_330  lt.lv.nn_332 ca.et.es_532 
  0x18000a04, 0x65fc300c, 0x3b28490c, 0x1015150c,   // pt.ga.un_320 uz.zzp.gv_543  to.sw.so_543 un.be.un_530 
  // [12e90]
  0x09000e08, 0x283d3ca0, 0x35285d0d, 0x795e470c,   // is.pl.un_430 ug.ku.sd_322  ss.sw.zu_554 sn.ts.war_543 
  0x3039fe04, 0x08041014, 0x2b00010d, 0x270a4a13,   // tlh.br.uz_332 be.ru.uk_666  en.vi.un_540 yo.pt.gd_665 
  0x59554ea9, 0x63131208, 0x59555d0c, 0x69353408,   // ay.rw.rn_544 hu.et.sco_443  ss.rw.rn_543 xh.zu.mfe_443 
  0x2d595513, 0x5c0a0b55, 0x17044f0c, 0x2d0953a0,   // rw.rn.sk_665 es.pt.sa_442  bi.fi.sr_543 ht.pl.sk_322 
  // [12ea0]
  0x595b64ad, 0x302d060c, 0x4f006022, 0x39593409,   // lg.sg.rn_643 de.sk.uz_543  vo.bi.un_870 xh.rn.br_444 
  0x18122da0, 0x0d0209ad, 0x6967780c, 0x47552811,   // sk.hu.ga_322 pl.da.cs_643  ve.ak.mfe_543 sw.rw.sn_653 
  0x100636a0, 0x381b48ec, 0x112a5204, 0x08353007,   // gn.de.lt_322 tt.tr.tk_644  ha.mt.ro_332 uz.tg.uk_432 
  0x1800300b, 0x0b003917, 0x52304f0c, 0x1e0912a7,   // uz.ar.un_520 br.es.un_730  bi.uz.ha_543 hu.pl.ms_532 
  // [12eb0]
  0x40255707, 0x355934af, 0x5d3757ee, 0x18233ca0,   // na.eu.lb_432 xh.rn.zu_655  na.st.ss_422 ug.ky.ar_322 
  0x4e003f13, 0x0900100e, 0x44170aa7, 0x1f6538a0,   // af.ay.un_650 lt.pl.un_550  mk.sr.kk_532 tk.gv.cy_322 
  0x2c383f12, 0x303b34a7, 0x27002105, 0x081138ad,   // af.tk.fy_654 ps.ks.uz_532  jw.gd.un_330 tk.ro.uk_643 
  0x48100704, 0x040717a4, 0x4a0e2e0c, 0x62fc1512,   // bg.be.tt_332 sr.bg.ru_433  fo.is.yo_543 un.zzp.kha_654 
  // [12ec0]
  0x043f1a08, 0x7359555a, 0x382404ee, 0x231821ad,   // tl.af.fi_443 rw.rn.ny_553  fi.eo.tk_422 fa.ar.ky_643 
  0x5400fe14, 0x48081107, 0x4c002312, 0x735528af,   // tlh.ik.un_660 ro.uk.tt_432  ca.wo.un_640 sw.rw.ny_655 
  0x02102408, 0x2c040f04, 0x1b002013, 0x2f532c0c,   // eo.lt.da_443 lv.fi.fy_332  sq.tr.un_650 fy.ht.su_543 
  0x54100f0c, 0x022e0e12, 0x2f1b04a4, 0x5800020d,   // lv.lt.ik_543 is.fo.da_654  fi.tr.su_433 da.om.un_540 
  // [12ed0]
  0x586428a0, 0x2d0d100b, 0x39002307, 0x301a6b08,   // sw.lg.om_322 lt.cs.sk_542  ca.br.un_420 ceb.tl.uz_443 
  0x3f2939a4, 0x42033f08, 0x3c3d3004, 0x04330305,   // br.sl.af_433 af.nl.co_443  uz.ku.ug_332 nl.nn.fi_333 
  0x122e430c, 0x130560a4, 0x4200180c, 0x690c76a4,   // ie.fo.hu_543 vo.fr.et_433  ga.co.un_530 crs.sv.mfe_433 
  0x4a4773af, 0x2b1c67ad, 0x3c213408, 0x2348150d,   // ny.sn.yo_655 ak.id.vi_643  ps.fa.ug_443 un.tt.ky_554 
  // [12ee0]
  0x1f50390c, 0x2e00130e, 0x695364a9, 0x45674a0c,   // br.fj.cy_543 et.fo.un_550  lg.ht.mfe_544 yo.ak.ln_543 
  0x35303c07, 0x1300420e, 0x09161707, 0x674a6312,   // ug.uz.tg_432 co.et.un_550  sr.hr.pl_432 sco.yo.ak_654 
  0x635564ad, 0x120e2e07, 0x2e0e2007, 0x6700642b,   // lg.rw.sco_643 fo.is.hu_432  sq.is.fo_432 lg.ak.un_980 
  0x2b57650d, 0x030448ee, 0x30073512, 0x1b000308,   // gv.na.vi_554 tt.fi.nl_422  tg.bg.uz_654 nl.tr.un_430 
  // [12ef0]
  0x18421904, 0x3f69550c, 0x2e0e180b, 0x3f531e08,   // gl.co.ga_332 rw.mfe.af_543  ga.is.fo_542 ms.ht.af_443 
  0x3600400c, 0x69765311, 0x214663a0, 0x3f006313,   // lb.gn.un_530 ht.crs.mfe_653  sco.qu.jw_322 sco.af.un_650 
  0x36693f0c, 0x0000472d, 0x3b1e1308, 0x5d254a07,   // af.mfe.gn_543 sn.un.un_A00  et.ms.so_443 yo.eu.ss_432 
  0x28343bac, 0x081511a7, 0x1922235a, 0x355e45a0,   // ks.ps.sd_632 ro.uk.un_520  ca.oc.gl_553 ln.ts.zu_322 
  // [12f00]
  0x46002312, 0x0800360e, 0x23190aa6, 0x390523a0,   // ca.qu.un_640 ab.uk.un_550  pt.gl.ca_521 ca.fr.br_322 
  0x0200300d, 0x0435070d, 0x17006404, 0x170a10a4,   // uz.da.un_540 bg.tg.ru_554  lg.sr.un_320 be.mk.sr_433 
  0x5a525e0c, 0x2d002c12, 0x06235712, 0x354e090c,   // ts.ha.sm_543 fy.sk.un_640  na.ca.de_654 pl.ay.zu_543 
  0x190a23ec, 0x20002308, 0x040810af, 0x405605a4,   // ca.pt.gl_644 ca.sq.un_430  be.uk.ru_655 fr.mg.lb_433 
  // [12f10]
  0x1e016307, 0x2a00200d, 0x44001512, 0x2d002402,   // sco.en.ms_432 sq.mt.un_540  un.kk.un_640 eo.sk.un_220 
  0x0924360c, 0x2400401b, 0x1c480302, 0x30234411,   // gn.eo.pl_543 lb.eo.un_770  nl.tt.id_222 kk.ky.uz_653 
  0x110b01a0, 0x2e003f02, 0x204a29a7, 0x64000107,   // en.es.ro_322 af.fo.un_220  sl.yo.sq_532 en.lg.un_420 
  0x5c4c3b12, 0x20003207, 0x21233d0b, 0x1200190d,   // so.wo.sa_654 bs.sq.un_420  ku.ky.fa_542 gl.hu.un_540 
  // [12f20]
  0x3900fc05, 0x1c002b04, 0x12002322, 0x30342109,   // zzp.br.un_330 vi.id.un_320  ky.ur.un_870 fa.ps.uz_444 
  0x080a0709, 0x04481707, 0x505a49a9, 0x2304070e,   // bg.mk.uk_444 sr.tt.ru_432  to.sm.fj_544 bg.ru.ky_555 
  0x395f1f5a, 0x4c006222, 0x25233507, 0x17005608,   // cy.tn.br_553 kha.wo.un_870  tg.ky.mn_432 mg.sr.un_430 
  0x601f6ba9, 0x25171513, 0x475624a9, 0x1b063ea0,   // ceb.cy.vo_544 un.sr.mn_665  eo.mg.sn_544 rm.de.tr_322 
  // [12f30]
  0x193148ad, 0x1710470c, 0x79022faf, 0x233015ee,   // tt.az.gl_643 sn.lt.sr_543  su.da.war_655 un.uz.ky_422 
  0x17110a05, 0x4a001211, 0x1f000808, 0x07110107,   // mk.ro.sr_333 hu.yo.un_630  no.cy.un_430 en.ro.it_432 
  0x47375f12, 0x5d02130c, 0x55216402, 0x10072555,   // tn.st.sn_654 et.da.ss_543  lg.jw.rw_222 eu.it.lt_442 
  0x64004009, 0x20492807, 0x11552507, 0x1c324c07,   // lb.lg.un_440 sw.to.sq_432  eu.rw.ro_432 wo.bs.id_432 
  // [12f40]
  0x691d01ee, 0x381101a0, 0x53006b04, 0x796b1a08,   // en.la.mfe_422 en.ro.tk_322  ceb.ht.un_320 tl.ceb.war_443 
  0x02006112, 0x5d0773a4, 0x301023a0, 0x0e793ba4,   // za.da.un_640 ny.it.ss_433  ky.be.uz_322 so.war.is_433 
  0x29003005, 0x115c020c, 0x0c23fca7, 0x07004702,   // uz.sl.un_330 da.sa.ro_543  zzp.ca.sv_532 sn.it.un_220 
  0x110268a7, 0x35000718, 0x13090d0d, 0x3644100b,   // ig.da.ro_532 bg.tg.un_740  ne.hi.bh_554 be.kk.ab_542 
  // [12f50]
  0x22230a09, 0x6b1a4e07, 0x15170a05, 0x79002404,   // pt.ca.oc_444 ay.tl.ceb_432  mk.sr.un_333 eo.war.un_320 
  0x30481905, 0x55457308, 0x23005002, 0x16116aad,   // gl.tt.uz_333 ny.ln.rw_443  fj.ca.un_220 haw.ro.hr_643 
  0x091502a9, 0x46002308, 0x390a0f02, 0x07300aa0,   // da.pl.un_540 ca.qu.un_430  lv.pt.br_222 mk.uz.bg_322 
  0x6b731d08, 0x0742110c, 0x0c0412ec, 0xfe4634a0,   // la.ny.ceb_443 ro.co.it_543  hu.fi.sv_644 xh.qu.tlh_322 
  // [12f60]
  0xfc311504, 0x4800460c, 0x253c30af, 0x4c002309,   // un.az.zzp_332 qu.tt.un_530  uz.ug.mn_655 ca.wo.un_440 
  0x3758fe12, 0x1e005804, 0x0535340e, 0x570105a0,   // tlh.om.st_654 om.ms.un_320  xh.zu.fr_555 fr.en.na_322 
  0x7300fe0d, 0x3530155a, 0x65570207, 0x35343105,   // tlh.ny.un_540 un.uz.tg_553  da.na.gv_432 az.xh.zu_333 
  0x5400fe1b, 0x48504e08, 0xfe4630a4, 0x4c003f0d,   // tlh.ik.un_770 ay.fj.tt_443  uz.qu.tlh_433 af.wo.un_540 
  // [12f70]
  0x4600300e, 0x13046012, 0x0b4006af, 0x29100da0,   // uz.qu.un_550 vo.fi.et_654  de.lb.es_655 cs.lt.sl_322 
  0x1612180c, 0x12003b08, 0x16292d02, 0x06002012,   // ar.ur.th_543 ks.ur.un_430  sk.sl.hr_222 sq.de.un_640 
  0x1504080b, 0x12000c0b, 0x34122802, 0x25102805,   // uk.ru.un_542 sv.hu.un_520  sd.ur.ps_222 sw.lt.eu_333 
  0x084411ad, 0x25005607, 0x23281207, 0x3e005b0c,   // ro.kk.uk_643 mg.eu.un_420  ur.sd.ky_432 sg.rm.un_530 
  // [12f80]
  0x0c003e05, 0x1a000c02, 0x026b2e07, 0x16002504,   // rm.sv.un_330 sv.tl.un_220  fo.ceb.da_432 eu.hr.un_320 
  0x25242008, 0x2f1a42a0, 0x28002505, 0x1a6b42a0,   // sq.eo.eu_443 co.tl.su_322  eu.sw.un_330 co.ceb.tl_322 
  0x463e420d, 0x5c000d2b, 0x0e796ba4, 0x35082507,   // co.rm.qu_554 ne.sa.un_980  ceb.war.is_433 mn.uk.tg_432 
  0x3f484202, 0x436b1d08, 0x3d3c2302, 0x190b43ad,   // co.tt.af_222 la.ceb.ie_443  ky.ug.ku_222 ie.es.gl_643 
  // [12f90]
  0x13002804, 0x5279580c, 0x24006713, 0x584d1fa4,   // sw.et.un_320 om.war.ha_543  ak.eo.un_650 cy.aa.om_433 
  0x09001602, 0x301f37a7, 0x06040ea0, 0x0a0730ac,   // hr.pl.un_220 st.cy.uz_532  is.fi.de_322 uz.bg.mk_632 
  0x3308feee, 0x080a3509, 0x3efe0c04, 0x1f020dec,   // tlh.no.nn_422 tg.mk.uk_444  sv.tlh.rm_332 cs.da.cy_644 
  0x3046fe0c, 0x0407300c, 0x353451a4, 0x0c0640af,   // tlh.qu.uz_543 uz.bg.ru_543  kl.xh.zu_433 lb.de.sv_655 
  // [12fa0]
  0x153008a4, 0x253515a7, 0x2302fc12, 0x31001302,   // uk.uz.un_433 un.tg.mn_532  zzp.da.ca_654 et.az.un_220 
  0x35170aac, 0x1823120c, 0x08003714, 0x033f180c,   // mk.sr.tg_632 ur.ky.ar_543  ba.uk.un_660 ga.af.nl_543 
  0x2c400604, 0x133f0807, 0x022c0d0d, 0x190a5eaf,   // de.lb.fy_332 no.af.et_432  cs.fy.da_554 ts.pt.gl_655 
  0x060722ad, 0x08023f09, 0x3f110304, 0x480425a0,   // oc.it.de_643 af.da.no_444  nl.ro.af_332 mn.ru.tt_322 
  // [12fb0]
  0x073c480c, 0x17041104, 0x083530ad, 0x33090d07,   // tt.ug.bg_543 ro.ru.sr_332  uz.tg.uk_643 cs.pl.nn_432 
  0x6500100c, 0x3f026504, 0x30170aa7, 0x40000305,   // lt.gv.un_530 gv.da.af_332  mk.sr.uz_532 nl.lb.un_330 
  0x01003807, 0x13791d04, 0x1d1f65ac, 0x10651fee,   // tk.en.un_420 la.war.et_332  gv.cy.la_632 cy.gv.lt_422 
  0x3f321708, 0x0b0a19a6, 0x35004405, 0x0115fc04,   // sr.bs.af_443 gl.pt.es_521  kk.tg.un_330 zzp.en.un_320 
  // [12fc0]
  0x283430ee, 0x061803a0, 0x08651f04, 0x3f0e65ac,   // uz.ps.sd_422 nl.ga.de_322  cy.gv.no_332 gv.is.af_632 
  0x28190a08, 0x1b123e55, 0x18004411, 0x30203b02,   // pt.gl.sw_443 rm.hu.tr_442  kk.ar.un_630 so.sq.uz_222 
  0x65004308, 0x15481555, 0x441023a4, 0x46003023,   // ie.gv.un_430 un.tt.un_442  ky.be.kk_433 uz.qu.un_880 
  0x15153508, 0x3e001214, 0x48123e05, 0x303523a9,   // tg.un.un_430 hu.rm.un_660  rm.hu.tt_333 ky.tg.uz_544 
  // [12fd0]
  0x1f114307, 0x22232f07, 0x063112a0, 0x23123407,   // ie.ro.cy_432 su.ca.oc_432  hu.az.de_322 ps.ur.ky_432 
  0x13062402, 0x08025dee, 0x38000307, 0x125d0307,   // eo.de.et_222 ss.da.no_422  nl.tk.un_420 nl.ss.hu_432 
  0x06481ba0, 0x300835af, 0x0c2413a4, 0x1700360d,   // tr.tt.de_322 tg.uk.uz_655  et.eo.sv_433 ab.sr.un_540 
  0x60000313, 0x443530a9, 0x20000e04, 0x1b066004,   // nl.vo.un_650 uz.tg.kk_544  is.sq.un_320 vo.de.tr_332 
  // [12fe0]
  0x12000804, 0x0a025c07, 0x3e0106a0, 0x03081207,   // no.hu.un_320 sa.da.pt_432  de.en.rm_322 hu.no.nl_432 
  0x131c0dad, 0x1700260c, 0x11004208, 0x0b421d07,   // ne.mr.bh_643 ia.sr.un_530  co.ro.un_430 la.co.es_432 
  0x50005c07, 0x28002f0d, 0x6a002f08, 0xfc23020d,   // sa.fj.un_420 su.sw.un_540  su.haw.un_430 da.ca.zzp_554 
  0x32201707, 0x32003504, 0x25060aa4, 0x27004c02,   // sr.sq.bs_432 zu.bs.un_320  pt.de.eu_433 wo.gd.un_220 
  // [12ff0]
  0x44152512, 0x120f38a9, 0x1b1213ee, 0x48060410,   // mn.kk.un_640 tk.lv.hu_544  et.hu.tr_422 fi.de.tt_642 
  0x122f19a0, 0xfc605008, 0x0a2f4255, 0x0b2f50a0,   // gl.su.hu_322 fj.vo.zzp_443  co.su.pt_442 fj.su.es_322 
  0x0b2342a4, 0x355d7312, 0x2b2f2807, 0x5e00120c,   // co.ca.es_433 ny.ss.zu_654  sw.su.vi_432 hu.ts.un_530 
  0x23330804, 0x1200250c, 0x100d2812, 0x4b272f07,   // no.nn.ca_332 eu.hu.un_530  sw.cs.lt_654 su.gd.mi_432 
  
  // [13000]
  0x3e3313ee, 0x48001119, 0x22000605, 0x2e0e130c,   // et.nn.rm_422 ro.tt.un_750  de.oc.un_330 et.is.fo_543 
  0x3023440c, 0x040708ee, 0x12111304, 0x12353405,   // kk.ky.uz_543 uk.bg.ru_422  et.ro.hu_332 xh.zu.hu_333 
  0x13000808, 0x652801a4, 0x13001214, 0x10353704,   // no.et.un_430 en.sw.gv_433  hu.et.un_660 ba.tg.be_332 
  0x630213a0, 0x18000d13, 0x40570604, 0x48344602,   // et.da.sco_322 cs.ga.un_650  de.na.lb_332 qu.xh.tt_222 
  // [13010]
  0x230213ac, 0x0c002a05, 0x060302ee, 0x3000620b,   // et.da.ca_632 mt.sv.un_330  da.nl.de_422 kha.uz.un_520 
  0x104404a4, 0x4900610e, 0x2800120b, 0x1812210d,   // ru.kk.be_433 za.to.un_550  ur.sd.un_520 fa.ur.ar_554 
  0x1b3e60a4, 0x332d120c, 0x48061ba0, 0x23343dee,   // vo.rm.tr_433 hu.sk.nn_543  tr.de.tt_322 ku.ps.ky_422 
  0x17000c08, 0x0e00400b, 0x3e481b0c, 0x31000610,   // sv.sr.un_430 lb.is.un_520  tr.tt.rm_543 de.az.un_620 
  // [13020]
  0x3b002708, 0x4400150b, 0x5107630c, 0x3d343c0c,   // gd.so.un_430 un.kk.un_520  sco.it.kl_543 ug.ps.ku_543 
  0x63000209, 0x1b003e0d, 0x381b3e07, 0x1b06600d,   // da.sco.un_440 rm.tr.un_540  rm.tr.tk_432 vo.de.tr_554 
  0x1b172d08, 0x1f2a5b05, 0x07440a02, 0x1b004d0d,   // sk.sr.tr_443 sg.mt.cy_333  mk.kk.bg_222 aa.tr.un_540 
  0x46fe1d07, 0x3b654da7, 0x2800361a, 0x30000108,   // la.tlh.qu_432 aa.gv.so_532  gn.sw.un_760 en.uz.un_430 
  // [13030]
  0x022873ad, 0x643445a4, 0x345502a4, 0x383b4d05,   // ny.sw.da_643 ln.xh.lg_433  da.rw.xh_433 aa.so.tk_333 
  0x1e1c5505, 0x3421285a, 0x3e79060c, 0x292d0905,   // rw.id.ms_333 sd.fa.ps_553  de.war.rm_543 pl.sk.sl_333 
  0x30350aa4, 0x351350ee, 0x467364a9, 0x31003b18,   // mk.tg.uz_433 fj.et.zu_422  lg.ny.qu_544 so.az.un_740 
  0x64005102, 0x463647a9, 0x02024d07, 0x1632295a,   // kl.lg.un_220 sn.gn.qu_544  aa.da.da_432 sl.bs.hr_553 
  // [13040]
  0x520542a4, 0x042d0d13, 0x2834185a, 0x232205af,   // co.fr.ha_433 cs.sk.fi_665  ar.ps.sd_553 fr.oc.ca_655 
  0x162909a7, 0x1b003307, 0x15041108, 0x11151709,   // pl.sl.hr_532 nn.tr.un_420  ro.ru.un_443 sr.ro.un_440 
  0x032d05a4, 0x64002821, 0x735364a4, 0x092a34a4,   // fr.sk.nl_433 sw.lg.un_860  lg.ht.ny_433 xh.mt.pl_433 
  0x47005713, 0x330c06a0, 0x55525907, 0x685f3f13,   // na.sn.un_650 de.sv.nn_322  rn.ha.rw_432 af.tn.ig_665 
  // [13050]
  0x30123212, 0x64114da7, 0x23310aa0, 0x58004908,   // bs.ur.uz_654 aa.ro.lg_532  pt.az.ca_322 to.om.un_430 
  0x3848220e, 0x3500730b, 0x38003112, 0x78475e08,   // oc.tt.tk_555 ny.zu.un_520  az.tk.un_640 ts.sn.ve_443 
  0x47555e04, 0x53004608, 0x475d5ea4, 0x0a0736a4,   // ts.rw.sn_332 qu.ht.un_430  ts.ss.sn_433 ab.bg.mk_433 
  0x11005219, 0x2820690c, 0x481b3807, 0x1d00420b,   // ha.ro.un_750 mfe.sq.sw_543  tk.tr.tt_432 co.la.un_520 
  // [13060]
  0x0a2322a9, 0x0a2315a7, 0x35fc5daf, 0x20381b04,   // oc.ca.pt_544 un.ky.mk_532  ss.zzp.zu_655 tr.tk.sq_332 
  0x6036110c, 0x05fc1104, 0x0f752d0c, 0x555d50a7,   // ro.gn.vo_543 ro.zzp.fr_332  sk.nso.lv_543 fj.ss.rw_532 
  0x46391ba0, 0x07fc24ee, 0x34285504, 0x33200e07,   // tr.br.qu_322 eo.zzp.it_422  rw.sw.xh_332 is.sq.nn_432 
  0x353407a0, 0x29202c07, 0x5c0913a4, 0x4a000e08,   // it.xh.zu_322 fy.sq.sl_432  bh.hi.sa_433 is.yo.un_430 
  // [13070]
  0x33002007, 0xfc650107, 0x2c003907, 0x3b213d08,   // sq.nn.un_420 en.gv.zzp_432  br.fy.un_420 ku.fa.ks_443 
  0x2800540c, 0x0415300d, 0x39002908, 0x10003805,   // ik.sw.un_530 uz.ru.un_540  sl.br.un_430 tk.lt.un_330 
  0x121b1304, 0x55131aa0, 0x020e2eee, 0x11483008,   // et.tr.hu_332 tl.et.rw_322  fo.is.da_422 uz.tt.ro_443 
  0x4a005c09, 0x04002314, 0x68496712, 0xfe005e14,   // sa.yo.un_440 ky.ru.un_660  ak.to.ig_654 ts.tlh.un_660 
  // [13080]
  0x06402007, 0x244608a0, 0x3f4f5c5a, 0x3000181a,   // sq.lb.de_432 no.qu.eo_322  sa.bi.af_553 ar.uz.un_760 
  0x2b1101a4, 0x655c1207, 0x1d574f09, 0x38304813,   // en.ro.vi_433 hu.sa.gv_432  bi.na.la_444 tt.uz.tk_665 
  0x28203007, 0x2f1c1fa0, 0x0f1720a0, 0x4423380d,   // uz.sq.sw_432 cy.id.su_322  sq.sr.lv_322 tk.ky.kk_554 
  0x21303409, 0x4f115c0d, 0x303d34ad, 0x48231504,   // ps.uz.fa_444 sa.ro.bi_554  ps.ku.uz_643 un.ky.tt_332 
  // [13090]
  0x01282bad, 0x0a481511, 0x10003505, 0x3c001208,   // vi.sw.en_643 un.tt.mk_653  tg.be.un_330 ur.ug.un_430 
  0x252344ee, 0x3500480d, 0x48082308, 0x59000a0d,   // kk.ky.mn_422 tt.tg.un_540  ky.uk.tt_443 pt.rn.un_540 
  0x4800060b, 0x17250a09, 0x425cfeec, 0x07654205,   // de.tt.un_520 mk.mn.sr_444  tlh.sa.co_644 co.gv.it_333 
  0x10001118, 0x0f0e130c, 0x6800fe19, 0x33006808,   // ro.be.un_740 et.is.lv_543  tlh.ig.un_750 ig.nn.un_430 
  // [130a0]
  0xfe006814, 0x31003e02, 0x12271807, 0x12311b02,   // ig.tlh.un_660 rm.az.un_220  ga.gd.hu_432 tr.az.hu_222 
  0x5c091c0e, 0x353411a4, 0x5d595504, 0x093b5c13,   // mr.hi.sa_555 ro.xh.zu_433  rw.rn.ss_332 sa.ks.hi_665 
  0x6800fe13, 0x644c5805, 0x21595508, 0x1f000207,   // tlh.ig.un_650 om.wo.lg_333  rw.rn.jw_443 da.cy.un_420 
  0x64005107, 0x0a005d05, 0x22000108, 0x0f005105,   // kl.lg.un_420 ss.pt.un_330  en.oc.un_430 kl.lv.un_330 
  // [130b0]
  0x15040714, 0x131b3107, 0x560b02ee, 0x4d00101a,   // bg.ru.un_666 az.tr.et_432  da.es.mg_422 lt.aa.un_760 
  0x15006509, 0x18234405, 0x2e080208, 0x284773a7,   // gv.un.un_440 kk.ky.ar_333  da.no.fo_443 ny.sn.sw_532 
  0x104d25ad, 0x12002213, 0x0600fe08, 0x0c0233a7,   // eu.aa.lt_643 oc.hu.un_650  tlh.de.un_430 nn.da.sv_532 
  0x34281814, 0x03001604, 0x33082caf, 0x09042e0c,   // ar.sd.ps_666 hr.nl.un_320  fy.no.nn_655 fo.fi.pl_543 
  // [130c0]
  0x2f354a5a, 0x13002102, 0x321608a4, 0x100604ee,   // yo.zu.su_553 jw.et.un_220  no.hr.bs_433 fi.de.lt_422 
  0x35387302, 0x40353405, 0x2f051802, 0x216468a0,   // ny.tk.zu_222 xh.zu.lb_333  ga.fr.su_222 ig.lg.jw_322 
  0x304415a4, 0x32002004, 0x38234813, 0x33082c05,   // un.kk.uz_433 sq.bs.un_320  tt.ky.tk_665 fy.no.nn_333 
  0x2a003b12, 0x55004709, 0x07374804, 0x1800590d,   // so.mt.un_640 sn.rw.un_440  tt.ba.bg_332 rn.ga.un_540 
  // [130d0]
  0x2f002134, 0x212f4d13, 0x4a002f0d, 0x42244dad,   // jw.su.un_A80 aa.su.jw_665  su.yo.un_540 aa.eo.co_643 
  0x29005607, 0x4a00290e, 0x12303da9, 0x20004a0d,   // mg.sl.un_420 sl.yo.un_550  ku.uz.ur_544 yo.sq.un_540 
  0x10005502, 0x42595004, 0x241c21a0, 0x6500fe29,   // rw.lt.un_220 fj.rn.co_332  jw.id.eo_322 tlh.gv.un_960 
  0x0a581107, 0x190f0bad, 0x59004d1b, 0x59005020,   // ro.om.pt_432 es.lv.gl_643  aa.rn.un_770 fj.rn.un_850 
  // [130e0]
  0x02512ea9, 0x2f1820a0, 0x29003602, 0x37295f02,   // fo.kl.da_544 sq.ga.su_322  gn.sl.un_220 tn.sl.st_222 
  0x58592104, 0x0f000107, 0x29000a12, 0x222718a0,   // jw.rn.om_332 en.lv.un_420  pt.sl.un_640 ga.gd.oc_322 
  0x5c002414, 0x48042502, 0x44373604, 0x170815a4,   // eo.sa.un_660 mn.ru.tt_222  ab.ba.kk_332 un.uk.sr_433 
  0x2900160d, 0x3c002807, 0x1b001308, 0x230a0807,   // hr.sl.un_540 sd.ug.un_420  et.tr.un_430 uk.mk.ky_432 
  // [130f0]
  0x34fc350c, 0x4a313012, 0x1228345a, 0x4a1b3808,   // zu.zzp.xh_543 uz.az.yo_654  ps.sd.ur_553 tk.tr.yo_443 
  0x231538a0, 0x1b043005, 0x3800340e, 0x2e543007,   // tk.ky.un_320 uz.fi.tr_333  xh.tk.un_550 uz.ik.fo_432 
  0x194e0b11, 0x1b1531a9, 0x231707a0, 0x311b3e02,   // es.ay.gl_653 az.tr.un_540  bg.sr.ky_322 rm.tr.az_222 
  0x6b1c04a4, 0x531b1ca0, 0x06004807, 0x234844ec,   // fi.id.ceb_433 id.tr.ht_322  tt.de.un_420 kk.tt.ky_644 
  // [13100]
  0x3400090d, 0x401206ee, 0x1c6b1207, 0x2f003702,   // pl.xh.un_540 de.hu.lb_422  hu.ceb.id_432 st.su.un_220 
  0x21183d08, 0x23002813, 0x2021040c, 0x1a216b55,   // ku.ar.fa_443 sd.ky.un_650  fi.jw.sq_543 ceb.jw.tl_442 
  0x13067955, 0x44233cac, 0x02001219, 0x12481307,   // war.de.et_442 ug.ky.kk_632  hu.da.un_750 et.tt.hu_432 
  0x42545111, 0x0415360c, 0x0a1011ad, 0x30003807,   // kl.ik.co_653 ab.ru.un_530  ro.be.mk_643 tk.uz.un_420 
  // [13110]
  0x132e42a4, 0x60383bad, 0x5c005912, 0x51585413,   // co.fo.et_433 so.tk.vo_643  rn.sa.un_640 ik.om.kl_665 
  0x28213cee, 0x302112ec, 0x1d00020b, 0x18273b0c,   // ug.fa.sd_422 ur.fa.uz_644  da.la.un_520 so.gd.ga_543 
  0x1d590107, 0x1c2b2707, 0x43302404, 0x182b2709,   // en.rn.la_432 gd.vi.id_432  eo.uz.ie_332 gd.vi.ga_444 
  0x28007320, 0x48644507, 0x2765fcee, 0x384d3ba9,   // ny.sw.un_850 ln.lg.tt_432  zzp.gv.gd_422 so.aa.tk_544 
  // [13120]
  0x59115aa9, 0x1b1a6b0c, 0x4c794ead, 0x3b4e4d0c,   // sm.ro.rn_544 ceb.tl.tr_543  ay.war.wo_643 aa.ay.so_543 
  0x452104a0, 0x2b001602, 0x22024d12, 0x3b000205,   // fi.jw.ln_322 hr.vi.un_220  aa.da.oc_654 da.so.un_330 
  0x01025c07, 0x0f0e3307, 0x4d004c0e, 0x254664a6,   // sa.da.en_432 nn.is.lv_432  wo.aa.un_550 lg.qu.eu_521 
  0x2855590c, 0x024d3ba4, 0x311a6b12, 0x173530a4,   // rn.rw.sw_543 so.aa.da_433  ceb.tl.az_654 uz.tg.sr_433 
  // [13130]
  0x79300508, 0x484d3008, 0x463b4d0c, 0x01001821,   // fr.uz.war_443 uz.aa.tt_443  aa.so.qu_543 ar.iw.un_860 
  0x28003422, 0x444837ec, 0x3b00300d, 0x790953a0,   // ps.sd.un_870 ba.tt.kk_644  uz.so.un_540 ht.pl.war_322 
  0x44363cec, 0x16202907, 0x231544a9, 0x30383509,   // ug.ab.kk_644 sl.sq.hr_432  kk.ky.un_540 tg.tk.uz_444 
  0x371017a0, 0x1334350c, 0x0f6a2a11, 0x0f001019,   // sr.be.ba_322 zu.xh.et_543  mt.haw.lv_653 lt.lv.un_750 
  // [13140]
  0x48501bee, 0x341b2a07, 0x060f0e0c, 0x2c00200c,   // tr.fj.tt_422 mt.tr.xh_432  is.lv.de_543 sq.fy.un_530 
  0x2a1b37ee, 0x32162a14, 0x12002a08, 0x312c17a0,   // st.tr.mt_422 mt.hr.bs_666  mt.hu.un_430 sr.fy.az_322 
  0x135c09af, 0x15081155, 0x4a6421a4, 0x2447feee,   // hi.sa.bh_655 ro.uk.un_442  jw.lg.yo_433 tlh.sn.eo_422 
  0x184839a0, 0x10001f22, 0x1a005805, 0x421305af,   // br.tt.ga_322 cy.lt.un_870  om.tl.un_330 fr.et.co_655 
  // [13150]
  0x4b285a0c, 0x0f495aa4, 0x796b49a4, 0x30374860,   // sm.sw.mi_543 sm.to.lv_433  to.ceb.war_433 tt.ba.uz_664 
  0x4811230c, 0x226a28a7, 0x425c6808, 0x0c3f0208,   // ky.ro.tt_543 sw.haw.oc_532  ig.sa.co_443 da.af.sv_443 
  0x79066a04, 0x31001f05, 0x1827650c, 0x1a006812,   // haw.de.war_332 cy.az.un_330  gv.gd.ga_543 ig.tl.un_640 
  0x5a0e0f04, 0x10003702, 0x24001208, 0x0300681a,   // lv.is.sm_332 ba.be.un_220  hu.eo.un_430 ig.nl.un_760 
  // [13160]
  0x2d0d1005, 0x303b3407, 0x42115c04, 0x58450507,   // lt.cs.sk_333 ps.ks.uz_432  sa.ro.co_332 fr.ln.om_432 
  0x3f001d02, 0x223f1da0, 0x52002808, 0x683f0107,   // la.af.un_220 la.af.oc_322  sw.ha.un_430 en.af.ig_432 
  0x4b495a07, 0x21303b07, 0x220e33a7, 0x735c5005,   // sm.to.mi_432 ks.uz.fa_432  nn.is.oc_532 fj.sa.ny_333 
  0x28006a13, 0x5c00360c, 0x2a361255, 0x08372307,   // haw.sw.un_650 gn.sa.un_530  hu.gn.mt_442 ky.ba.uk_432 
  // [13170]
  0x3c4422a9, 0x1065020c, 0x36194ea4, 0x08001521,   // si.kk.ug_544 da.gv.lt_543  ay.gl.gn_433 un.uk.un_860 
  0x0d09500c, 0x352308a9, 0x42020712, 0x12005b12,   // fj.pl.cs_543 uk.ky.tg_544  it.da.co_654 sg.hu.un_640 
  0x2d0d0ba4, 0x38005c0d, 0x13032c04, 0x4a006808,   // es.cs.sk_433 sa.tk.un_540  fy.nl.et_332 ig.yo.un_430 
  0x283b5808, 0x39002d0c, 0x11005802, 0x470428a4,   // om.so.sw_443 sk.br.un_530  om.ro.un_220 sw.fi.sn_433 
  // [13180]
  0x05002904, 0x54511312, 0x4d4728a9, 0x533367ee,   // sl.fr.un_320 et.kl.ik_654  sw.sn.aa_544 ak.nn.ht_422 
  0x04511304, 0x0a075da0, 0x4a6e690c, 0x10006507,   // et.kl.fi_332 ss.it.pt_322  mfe.hmn.yo_543 gv.lt.un_420 
  0x6a585107, 0x691739a4, 0x043b580e, 0x53fc0107,   // kl.om.haw_432 br.sr.mfe_433  om.so.fi_555 en.zzp.ht_432 
  0x684a25ec, 0x64025807, 0x50420705, 0x090d020c,   // eu.yo.ig_644 om.da.lg_432  it.co.fj_333 da.cs.pl_543 
  // [13190]
  0x02005813, 0x65003618, 0x42260d07, 0x041d3b07,   // om.da.un_650 gn.gv.un_740  cs.ia.co_432 so.la.fi_432 
  0x51130412, 0x67172912, 0x69172d12, 0x76536914,   // fi.et.kl_654 sl.sr.ak_654  sk.sr.mfe_654 mfe.ht.crs_666 
  0x081044a4, 0x2443080c, 0x04134907, 0x68293f5a,   // kk.be.uk_433 no.ie.eo_543  to.et.fi_432 af.sl.ig_553 
  0x10003707, 0x12001821, 0x170a2508, 0x23002529,   // ba.be.un_420 ar.ur.un_860  mn.mk.sr_443 mn.ky.un_960 
  // [131a0]
  0x6502fc0c, 0xfc39730b, 0x2a5852af, 0x321c64a0,   // zzp.da.gv_543 ny.br.zzp_542  ha.om.mt_655 lg.id.bs_322 
  0x5c2a4da4, 0x4c005c0c, 0x1b007307, 0x2a006421,   // aa.mt.sa_433 sa.wo.un_530  ny.tr.un_420 lg.mt.un_860 
  0x42003e09, 0x4c1c1e07, 0x122a4c04, 0x0417070c,   // rm.co.un_440 ms.id.wo_432  wo.mt.hu_332 bg.sr.ru_543 
  0x5c006418, 0x1b6301ee, 0x46005c0c, 0x522a5c07,   // lg.sa.un_740 en.sco.tr_422  sa.qu.un_530 sa.mt.ha_432 
  // [131b0]
  0x10003814, 0x23444807, 0x58002a0b, 0x645c2a0c,   // tk.be.un_660 tt.kk.ky_432  mt.om.un_520 mt.sa.lg_543 
  0x070a1112, 0x3b30460e, 0x173507a0, 0x123428ee,   // ro.mk.bg_654 qu.uz.so_555  bg.tg.sr_322 sd.ps.ur_422 
  0x352338a0, 0x0a002307, 0x070a1711, 0x04000719,   // tk.ky.tg_322 ca.pt.un_420  sr.mk.bg_653 bg.ru.un_750 
  0x043608a4, 0x332d240c, 0x342821a7, 0x5c005a02,   // uk.ab.ru_433 eo.sk.nn_543  fa.sd.ps_532 sm.sa.un_220 
  // [131c0]
  0x17481004, 0x42005804, 0x122f2105, 0x041036a4,   // be.tt.sr_332 om.co.un_320  jw.su.hu_333 ab.be.ru_433 
  0x032458a0, 0x1510170c, 0x170810a0, 0x2b004207,   // om.eo.nl_322 sr.be.un_543  be.uk.sr_322 co.vi.un_420 
  0x1e002802, 0xfe002713, 0x11003819, 0xfe00652a,   // sw.ms.un_220 gd.tlh.un_650  tk.ro.un_750 gv.tlh.un_970 
  0x170a150e, 0x0200340d, 0x561d05ad, 0x5c00340e,   // un.mk.sr_555 xh.da.un_540  fr.la.mg_643 xh.sa.un_550 
  // [131d0]
  0x397669ad, 0x483034ee, 0xfe006513, 0x480837a0,   // mfe.crs.br_643 xh.uz.tt_422  gv.tlh.un_650 ba.uk.tt_322 
  0x2700fe13, 0x1a00690d, 0x6747205a, 0x4a6945af,   // tlh.gd.un_650 mfe.tl.un_540  sq.sn.ak_553 ln.mfe.yo_655 
  0x766967ec, 0x531802a0, 0x06005208, 0xfe001504,   // ak.mfe.crs_644 da.ga.ht_322  ha.de.un_430 un.tlh.un_320 
  0x554a5aa9, 0x652718a4, 0x192e2aee, 0x07040814,   // sm.yo.rw_544 ga.gd.gv_433  mt.fo.gl_422 uk.ru.bg_666 
  // [131e0]
  0x172330a6, 0x3b00520b, 0x3b005208, 0x162d6504,   // uz.ky.sr_521 ha.so.un_520  ha.so.un_430 gv.sk.hr_332 
  0x0400360d, 0x52000608, 0x12003b20, 0x19176904,   // gn.fi.un_540 de.ha.un_430  ks.ur.un_850 mfe.sr.gl_332 
  0x134257af, 0x64003514, 0x33022e55, 0x3b004d13,   // na.co.et_655 zu.lg.un_660  fo.da.nn_442 aa.so.un_650 
  0x2f00051a, 0x343c1812, 0x440423ee, 0x080717a7,   // fr.su.un_760 ar.ug.ps_654  ky.ru.kk_422 sr.bg.uk_532 
  // [131f0]
  0x10254805, 0x1500252b, 0x37070aa0, 0x28595560,   // tt.mn.be_333 mn.un.un_980  mk.bg.ba_322 rw.rn.sw_664 
  0x23001235, 0x014505a4, 0x443848a4, 0x21183007,   // hu.ca.un_A90 fr.ln.en_433  tt.tk.kk_433 uz.ar.fa_432 
  0x65000905, 0x1d0501ee, 0x0c024cad, 0x311b1d0b,   // pl.gv.un_330 en.fr.la_422  wo.da.sv_643 la.tr.az_542 
  0x332e020c, 0x40000804, 0x54511c07, 0x153525ee,   // da.fo.nn_543 no.lb.un_320  id.kl.ik_432 mn.tg.un_422 
  // [13200]
  0x21525107, 0x79004609, 0x362d12a0, 0x1e004307,   // kl.ha.jw_432 qu.war.un_440  hu.sk.gn_322 ie.ms.un_420 
  0x4c452904, 0x51002505, 0x2d520d08, 0x23484408,   // sl.ln.wo_332 eu.kl.un_330  cs.ha.sk_443 kk.tt.ky_443 
  0x46003704, 0x3b5146ee, 0x52542f07, 0x0800360d,   // st.qu.un_320 qu.kl.so_422  su.ik.ha_432 ab.uk.un_540 
  0x29515204, 0x374cfea4, 0x4c2951ee, 0x2f581e07,   // ha.kl.sl_332 tlh.wo.st_433  kl.sl.wo_422 ms.om.su_432 
  // [13210]
  0x7600130d, 0x4c00300e, 0x0e00360b, 0xfc4205a7,   // et.crs.un_540 uz.wo.un_550  gn.is.un_520 fr.co.zzp_532 
  0x1500301a, 0x5800510e, 0x48005007, 0x30000312,   // uz.un.un_760 kl.om.un_550  fj.tt.un_420 nl.uz.un_640 
  0x515030a9, 0x536976a7, 0x64764813, 0x390530a4,   // uz.fj.kl_544 crs.mfe.ht_532  tt.crs.lg_665 uz.fr.br_433 
  0x53004005, 0x64395808, 0x690576a9, 0x30054008,   // lb.ht.un_330 om.br.lg_443  crs.fr.mfe_544 lb.fr.uz_443 
  // [13220]
  0x1723440c, 0x0208330c, 0x110a1dee, 0x46fe580c,   // kk.ky.sr_543 nn.no.da_543  la.pt.ro_422 om.tlh.qu_543 
  0x111d100c, 0x2f2162ad, 0x1b467904, 0x5e4e4655,   // lt.la.ro_543 kha.jw.su_643  war.qu.tr_332 qu.ay.ts_442 
  0x51330855, 0x3e002d02, 0x08025105, 0x2f215407,   // no.nn.kl_442 sk.rm.un_220  kl.da.no_333 ik.jw.su_432 
  0x31021ca0, 0x29165207, 0x38002f04, 0x51000412,   // id.da.az_322 ha.hr.sl_432  su.tk.un_320 fi.kl.un_640 
  // [13230]
  0x26070da4, 0x16222fee, 0x07364a13, 0x522f5502,   // cs.it.ia_433 su.oc.hr_422  yo.gn.it_665 rw.su.ha_222 
  0x1d511005, 0x10041112, 0x01420307, 0x162911a4,   // lt.kl.la_333 ro.fi.lt_654  nl.co.en_432 ro.sl.hr_433 
  0x15000304, 0x2e5102a4, 0x3048310e, 0x00004537,   // nl.un.un_320 da.kl.fo_433  az.tt.uz_555 ln.un.un_B00 
  0x27182207, 0x481d43ee, 0x0a112204, 0x21004c09,   // oc.ga.gd_432 ie.la.tt_422  oc.ro.pt_332 wo.jw.un_440 
  // [13240]
  0x30005408, 0x26221d08, 0x4b5f33a4, 0x421d2612,   // ik.uz.un_430 la.oc.ia_443  nn.tn.mi_433 ia.la.co_654 
  0xfc031d02, 0x1e4a360c, 0x1f4552a0, 0x1500151b,   // la.nl.zzp_222 gn.yo.ms_543  ha.ln.cy_322 un.un.un_770 
  0x383c23ec, 0x35113460, 0x5e375f05, 0x0a443704,   // ky.ug.tk_644 xh.ro.zu_664  tn.st.ts_333 ba.kk.mk_332 
  0x29110da7, 0x57255fa4, 0x551b34a0, 0x5e002509,   // cs.ro.sl_532 tn.eu.na_433  xh.tr.rw_322 eu.ts.un_440 
  // [13250]
  0x34185da0, 0x646563ee, 0x2d001108, 0x2900010d,   // ss.ga.xh_322 sco.gv.lg_422  ro.sk.un_430 en.sl.un_540 
  0x18790960, 0x42240712, 0x34295dad, 0x5e000c13,   // pl.war.ga_664 it.eo.co_654  ss.sl.xh_643 sv.ts.un_650 
  0x012b02ee, 0x6300090e, 0x1f005d21, 0x5d691d07,   // da.vi.en_422 pl.sco.un_550  ss.cy.un_860 la.mfe.ss_432 
  0xfc001d08, 0x37152307, 0x39050255, 0x1c5c13af,   // la.zzp.un_430 ky.ba.un_420  da.fr.br_442 bh.sa.mr_655 
  // [13260]
  0x2a183b0b, 0x0a122dad, 0x38001602, 0x0408155a,   // so.ga.mt_542 sk.hu.pt_643  hr.tk.un_220 un.uk.ru_553 
  0x3534feec, 0x3e214a55, 0x353625ad, 0x312afea0,   // tlh.xh.zu_644 yo.jw.rm_442  mn.ab.tg_643 tlh.mt.az_322 
  0x085339a0, 0x2e433307, 0x213f1a02, 0x537663a9,   // br.ht.no_322 nn.ie.fo_432  tl.af.jw_222 sco.crs.ht_544 
  0x06400faf, 0x0a00600d, 0x1dfc1502, 0x13353402,   // lv.lb.de_655 vo.pt.un_540  un.zzp.la_222 xh.zu.et_222 
  // [13270]
  0x40330802, 0x042548a0, 0x17110755, 0x49353408,   // no.nn.lb_222 tt.mn.ru_322  bg.ro.sr_442 xh.zu.to_443 
  0x4f001013, 0x0200200e, 0x29321609, 0x08170aa9,   // lt.bi.un_650 sq.da.un_550  hr.bs.sl_444 mk.sr.uk_544 
  0xfe004508, 0x231b0fa0, 0x156301ee, 0x2d0d200c,   // ln.tlh.un_430 lv.tr.ca_322  en.sco.un_422 sq.cs.sk_543 
  0x104808a0, 0x796a340b, 0x124323a4, 0x0f2601a4,   // uk.tt.be_322 xh.haw.war_542  ca.ie.hu_433 en.ia.lv_433 
  // [13280]
  0x2e080205, 0x3300020e, 0xfc003612, 0x48384409,   // da.no.fo_333 da.nn.un_550  gn.zzp.un_640 kk.tk.tt_444 
  0x0e2e65af, 0x173007a0, 0x130f1ca4, 0x18123d02,   // gv.fo.is_655 bg.uz.sr_322  id.lv.et_433 ku.ur.ar_222 
  0x13000804, 0x132c04a0, 0x10302508, 0x582836a6,   // no.et.un_320 fi.fy.et_322  mn.uz.be_443 gn.sw.om_521 
  0x21001b1a, 0x23170aa4, 0x045348a0, 0x122134a6,   // tr.jw.un_760 mk.sr.ky_433  tt.ht.fi_322 ps.fa.ur_521 
  // [13290]
  0x330804ac, 0x15302308, 0x100717a0, 0x4e000f12,   // fi.no.nn_632 ky.uz.un_443  sr.bg.be_322 lv.ay.un_640 
  0x47287302, 0x46002f09, 0x241520ad, 0x2c002f07,   // ny.sw.sn_222 su.qu.un_440  sq.eo.un_630 su.fy.un_420 
  0x48373c11, 0x04303c55, 0x16321712, 0x48371007,   // ug.ba.tt_653 ug.uz.ru_442  sr.bs.hr_654 be.ba.tt_432 
  0x35342a13, 0x213d440d, 0x0a2308af, 0x08001111,   // mt.xh.zu_665 kk.ku.fa_554  uk.ky.mk_655 ro.uk.un_630 
  // [132a0]
  0x4635340d, 0x1a003404, 0x15002004, 0x2f1a20a0,   // xh.zu.qu_554 xh.tl.un_320  sq.un.un_320 sq.tl.su_322 
  0x350823ee, 0x64000207, 0x4b253607, 0xfe006813,   // ky.uk.tg_422 da.lg.un_420  gn.eu.mi_432 ig.tlh.un_650 
  0x21001c13, 0x46343507, 0x6b002522, 0x02006809,   // id.jw.un_650 zu.xh.qu_432  eu.ceb.un_870 ig.da.un_440 
  0x39000513, 0x5a04020b, 0x46004205, 0xfe005c14,   // fr.br.un_650 da.fi.sm_542  co.qu.un_330 sa.tlh.un_660 
  // [132b0]
  0x114b23a9, 0x44303504, 0x6b681da7, 0x021065a4,   // ca.mi.ro_544 tg.uz.kk_332  la.ig.ceb_532 gv.lt.da_433 
  0xfc651f04, 0x0e061f02, 0x091f2ca6, 0x3952fca7,   // cy.gv.zzp_332 cy.de.is_222  fy.cy.pl_521 zzp.ha.br_532 
  0x23000712, 0x464a2507, 0x37041507, 0x31033f0c,   // bg.ky.un_640 eu.yo.qu_432  un.ru.ba_432 af.nl.az_543 
  0x1f1065a4, 0x170704a9, 0x52464704, 0x033f27a9,   // gv.lt.cy_433 ru.bg.sr_544  sn.qu.ha_332 gd.af.nl_544 
  // [132c0]
  0x276526a4, 0x1d3e0355, 0x0e353404, 0x63230107,   // ia.gv.gd_433 nl.rm.la_442  xh.zu.is_332 en.ca.sco_432 
  0x27112304, 0x12003505, 0x071008a4, 0x10081708,   // ca.ro.gd_332 zu.hu.un_330  uk.be.bg_433 sr.uk.be_443 
  0x03426305, 0x242521a0, 0x065c30a0, 0x11102407,   // sco.co.nl_333 jw.eu.eo_322  uz.sa.de_322 eo.lt.ro_432 
  0x274f6307, 0x041736a0, 0x504d4255, 0x351511a4,   // sco.bi.gd_432 ab.sr.ru_322  co.aa.fj_442 ro.tg.un_430 
  // [132d0]
  0x24001504, 0x1a254504, 0x07321707, 0x431d1755,   // un.eo.un_320 ln.eu.tl_332  sr.bs.it_432 sr.la.ie_442 
  0x07632155, 0x2c21030c, 0x62004f23, 0x3c2321a9,   // jw.sco.it_442 nl.jw.fy_543  bi.kha.un_880 fa.ky.ug_544 
  0x283401a4, 0x4c2a2ea0, 0x2e00380b, 0x2a000f08,   // iw.ps.sd_433 fo.mt.wo_322  tk.fo.un_520 lv.mt.un_430 
  0x494b0205, 0x0400510d, 0x13512c12, 0x0400020c,   // da.mi.to_333 kl.fi.un_540  fy.kl.et_654 da.fi.un_530 
  // [132e0]
  0x520545a0, 0x0e4d51a9, 0x05004008, 0x1c005107,   // ln.fr.ha_322 kl.aa.is_544  lb.fr.un_430 kl.id.un_420 
  0x55514d0c, 0x53002f0c, 0x4a2c42a4, 0x40122fa4,   // aa.kl.rw_543 su.ht.un_530  co.fy.yo_433 su.hu.lb_433 
  0x2d0d08a4, 0x0c510807, 0x4d510111, 0x10121fa0,   // no.cs.sk_433 no.kl.sv_432  en.kl.aa_653 cy.hu.lt_322 
  0x58674d07, 0x425c4d07, 0x2f051204, 0x214661ad,   // aa.ak.om_432 aa.sa.co_432  hu.fr.su_332 za.qu.jw_643 
  // [132f0]
  0x48640307, 0x4d675413, 0x61050d0c, 0x06670909,   // nl.lg.tt_432 ik.ak.aa_665  cs.fr.za_543 pl.ak.de_444 
  0x3523440c, 0x1300360b, 0x544d51ad, 0x12052f04,   // kk.ky.tg_543 gn.et.un_520  kl.aa.ik_643 su.fr.hu_332 
  0x54510ea9, 0x0d02040e, 0x0d122d0b, 0x4a002f02,   // is.kl.ik_544 fi.da.cs_555  sk.hu.cs_542 su.yo.un_220 
  0x1f000905, 0x0413510c, 0x2000530b, 0xfc1e1c55,   // pl.cy.un_330 kl.et.fi_543  ht.sq.un_520 id.ms.zzp_442 
  // [13300]
  0x50094da9, 0x0a3c07a0, 0x23fc110c, 0x1502fcad,   // aa.pl.fj_544 bg.ug.mk_322  ro.zzp.ca_543 zzp.da.un_643 
  0x11353404, 0x23122da0, 0x4d3e070c, 0x23053e02,   // xh.zu.ro_332 sk.hu.ca_322  it.rm.aa_543 rm.fr.ca_222 
  0x1b006112, 0x22450507, 0x6b0c1dee, 0x39464311,   // za.tr.un_640 fr.ln.oc_432  la.sv.ceb_422 ie.qu.br_653 
  0x42790504, 0x02071a0c, 0x44353804, 0x23190ba0,   // fr.war.co_332 tl.it.da_543  tk.tg.kk_332 es.gl.ca_322 
  // [13310]
  0x35001b13, 0x0a1219a9, 0x2e02020c, 0x4d003e0d,   // tr.zu.un_650 gl.hu.pt_544  da.da.fo_543 rm.aa.un_540 
  0x3200fc0c, 0x3e074211, 0x19000b23, 0x4317fc0c,   // zzp.bs.un_530 co.it.rm_653  es.gl.un_880 zzp.sr.ie_543 
  0x5e074d07, 0x181b6007, 0x2200fc0c, 0x22000907,   // aa.it.ts_432 vo.tr.ga_432  zzp.oc.un_530 pl.oc.un_420 
  0x082d3307, 0x23253755, 0x0e1812ec, 0x2a243fee,   // nn.sk.no_432 ba.mn.ky_442  hu.ga.is_644 af.eo.mt_422 
  // [13320]
  0x0a3035a0, 0x3e004222, 0x1d00fe04, 0x42243e08,   // tg.uz.mk_322 co.rm.un_870  tlh.la.un_320 rm.eo.co_443 
  0x11190b05, 0x013b3e07, 0x562336ac, 0x30002c02,   // es.gl.ro_333 rm.so.en_432  gn.ca.mg_632 fy.uz.un_220 
  0x3b431fec, 0x3b0e2e08, 0x032e06a4, 0x0e1b2e13,   // cy.ie.so_644 fo.is.so_443  de.fo.nl_433 fo.tr.is_665 
  0x34283d05, 0x58006907, 0x0e181205, 0x0c467313,   // ku.sd.ps_333 mfe.om.un_420  hu.ga.is_333 ny.qu.sv_665 
  // [13330]
  0x1f006519, 0x125363a0, 0x3b465812, 0x463b4d0d,   // gv.cy.un_750 sco.ht.hu_322  om.qu.so_654 aa.so.qu_554 
  0x303b4dad, 0x47303855, 0x582a46a0, 0x4d3b58a9,   // aa.so.uz_643 tk.uz.sn_442  qu.mt.om_322 om.so.aa_544 
  0x50465111, 0x30fc73ee, 0x2c000f0b, 0x2a3b4e05,   // kl.qu.fj_653 ny.zzp.uz_422  lv.fy.un_520 ay.so.mt_333 
  0x254448a9, 0x58464d07, 0x32167305, 0x2d1912a0,   // tt.kk.mn_544 aa.qu.om_432  ny.hr.bs_333 hu.gl.sk_322 
  // [13340]
  0x4e3046ec, 0x584d4c09, 0x483169a6, 0x31000e0b,   // qu.uz.ay_644 wo.aa.om_444  mfe.az.tt_521 is.az.un_520 
  0x31003b05, 0x3000fc09, 0x46304d04, 0x3b2a30ad,   // so.az.un_330 zzp.uz.un_440  aa.uz.qu_332 uz.mt.so_643 
  0x35344da9, 0x23153007, 0x2b1d0207, 0x3b633007,   // aa.xh.zu_544 uz.ky.un_420  da.la.vi_432 uz.sco.so_432 
  0x353431ec, 0x3b004e1b, 0x343b300c, 0x3b314da4,   // az.xh.zu_644 ay.so.un_770  uz.so.xh_543 aa.az.so_433 
  // [13350]
  0x12007304, 0x12300da0, 0x46003019, 0x502a4d0c,   // ny.hu.un_320 cs.uz.hu_322  uz.qu.un_750 aa.mt.fj_543 
  0x330a3655, 0xfe465008, 0xfcfe02a0, 0x4b000f02,   // gn.pt.nn_442 fj.qu.tlh_443  da.tlh.zzp_322 lv.mi.un_220 
  0x3562460c, 0x503b46a0, 0x44100809, 0x1d105107,   // qu.kha.zu_543 qu.so.fj_322  uk.be.kk_444 kl.lt.la_432 
  0x51000a19, 0x071015a0, 0x36040712, 0x38200a02,   // pt.kl.un_750 un.be.bg_322  bg.ru.ab_654 pt.sq.tk_222 
  // [13360]
  0x2d4a0dec, 0x37004508, 0x1535480e, 0x73005f21,   // cs.yo.sk_644 ln.st.un_430  tt.tg.un_555 tn.ny.un_860 
  0x44353002, 0x353467ec, 0x5f3459a4, 0x18002b21,   // uz.tg.kk_222 ak.xh.zu_644  rn.xh.tn_433 vi.ga.un_860 
  0x38220a08, 0x48441107, 0x19480aa6, 0x0f24095a,   // pt.oc.tk_443 ro.kk.tt_432  pt.tt.gl_521 pl.eo.lv_553 
  0x1a4573ec, 0x47005e09, 0x3b21300c, 0x6b684504,   // ny.ln.tl_644 ts.sn.un_440  uz.fa.ks_543 ln.ig.ceb_332 
  // [13370]
  0x12005d0c, 0x213c23a4, 0x0e120da7, 0x43003e12,   // ss.hu.un_530 ky.ug.fa_433  cs.hu.is_532 rm.ie.un_640 
  0x1c135c04, 0x2d355d04, 0x04100707, 0x3534fa0c,   // sa.bh.mr_332 ss.zu.sk_332  bg.be.ru_432 nr.xh.zu_543 
  0x68002d07, 0x28003912, 0x0e063f02, 0x023f0ea6,   // sk.ig.un_420 br.sw.un_640  af.de.is_222 is.af.da_521 
  0x2d0a23af, 0x04150712, 0x395628a0, 0x3f092413,   // ca.pt.sk_655 bg.ru.un_640  sw.mg.br_322 eo.pl.af_665 
  // [13380]
  0x3806fe07, 0x353450a0, 0x1c031eee, 0x190b0ea0,   // tlh.de.tk_432 fj.xh.zu_322  ms.nl.id_422 is.es.gl_322 
  0x0f293911, 0x47353413, 0x3500641a, 0x082d3665,   // br.sl.lv_653 xh.zu.sn_665  lg.zu.un_760 gn.sk.no_763 
  0x36000507, 0x4a35640c, 0x13394004, 0x44234814,   // fr.gn.un_420 lg.zu.yo_543  lb.br.et_332 tt.ky.kk_666 
  0x1e1c62ec, 0x5600390b, 0x39006807, 0x1e1c21ee,   // kha.id.ms_644 br.mg.un_520  ig.br.un_420 jw.id.ms_422 
  // [13390]
  0x0e122e0d, 0x190a2d07, 0x37023eec, 0x4c005713,   // fo.hu.is_554 sk.pt.gl_432  rm.da.st_644 na.wo.un_650 
  0x5c130d0e, 0x444823ee, 0x0200030e, 0x4c005712,   // ne.bh.sa_555 ky.tt.kk_422  nl.da.un_550 na.wo.un_640 
  0x0e2e1211, 0x1735300d, 0x04173ca0, 0x2d23220b,   // hu.fo.is_653 uz.tg.sr_554  ug.sr.ru_322 oc.ca.sk_542 
  0x180e2d07, 0x385767ec, 0x02003e18, 0x4e004623,   // sk.is.ga_432 ak.na.tk_644  rm.da.un_740 qu.ay.un_880 
  // [133a0]
  0x33433e07, 0x36000104, 0x35481555, 0x64083307,   // rm.ie.nn_432 en.gn.un_320  un.tt.tg_442 nn.no.lg_432 
  0x495a01a0, 0x23220a09, 0x29172d0c, 0x4f3601a0,   // en.sm.to_322 pt.oc.ca_444  sk.sr.sl_543 en.gn.bi_322 
  0x2300090c, 0x0d00470d, 0x122d36a7, 0x5c1c0d12,   // pl.ca.un_530 sn.cs.un_540  gn.sk.hu_532 ne.mr.sa_654 
  0x384448a9, 0x0a002218, 0x2300090b, 0x0600020b,   // tt.kk.tk_544 oc.pt.un_740  pl.ca.un_520 da.de.un_520 
  // [133b0]
  0x21183009, 0x49000304, 0x0e004a1a, 0x34364707,   // uz.ar.fa_444 nl.to.un_320  yo.is.un_760 sn.gn.xh_432 
  0x3c003507, 0x0a23220e, 0x38201bec, 0x05114507,   // tg.ug.un_420 oc.ca.pt_555  tr.sq.tk_644 ln.ro.fr_432 
  0x18123ca4, 0x102308a4, 0x2a000c02, 0x64000d08,   // ug.ur.ar_433 uk.ky.be_433  sv.mt.un_220 cs.lg.un_430 
  0x1730040b, 0x644c2a11, 0x23443cee, 0x12002005,   // ru.uz.sr_542 mt.wo.lg_653  ug.kk.ky_422 sq.hu.un_330 
  // [133c0]
  0x48081504, 0x283430a4, 0x08101702, 0x38201b0c,   // un.uk.tt_332 uz.ps.sd_433  sr.be.uk_222 tr.sq.tk_543 
  0x2a126408, 0x49002319, 0x53004220, 0x0e00200b,   // lg.hu.mt_443 ca.to.un_750  co.ht.un_850 sq.is.un_520 
  0x23004208, 0x0e2253a9, 0x29002009, 0x49002d0c,   // co.ca.un_430 ht.oc.is_544  sq.sl.un_440 sk.to.un_530 
  0x1200610b, 0x29006112, 0x3f1210af, 0x370715a0,   // za.hu.un_520 za.sl.un_640  lt.hu.af_655 un.bg.ba_322 
  // [133d0]
  0x22005305, 0x357347a4, 0x350407a4, 0x5e5364a7,   // ht.oc.un_330 sn.ny.zu_433  bg.ru.tg_433 lg.ht.ts_532 
  0x17070802, 0x123c18ee, 0x23420507, 0x300410a0,   // uk.bg.sr_222 ar.ug.ur_422  fr.co.ca_432 be.ru.uz_322 
  0x07303502, 0x42303607, 0x6134fcec, 0x352051a7,   // tg.uz.bg_222 gn.uz.co_432  zzp.xh.za_644 kl.sq.zu_532 
  0x42fe5c07, 0x590255ee, 0x482515a6, 0x604251ad,   // sa.tlh.co_432 rw.da.rn_422  un.mn.tt_521 kl.co.vo_643 
  // [133e0]
  0x4c450508, 0x34005d0c, 0x1d1a5407, 0x5100640c,   // fr.ln.wo_443 ss.xh.un_530  ik.tl.la_432 lg.kl.un_530 
  0x60112412, 0x42003608, 0x79006a13, 0x55540e60,   // eo.ro.vo_654 gn.co.un_430  haw.war.un_650 is.ik.rw_664 
  0x2e460e0c, 0x3900792c, 0x587926a9, 0x6b001e22,   // is.qu.fo_543 war.br.un_990  ia.war.om_544 ms.ceb.un_870 
  0x12fe420c, 0x6859550d, 0x0b004e0b, 0x552f2114,   // co.tlh.hu_543 rw.rn.ig_554  ay.es.un_520 jw.su.rw_666 
  // [133f0]
  0x286852a7, 0x2e5f2fa0, 0x060501af, 0x304f780c,   // ha.ig.sw_532 su.tn.fo_322  en.fr.de_655 ve.bi.uz_543 
  0x425d54a0, 0x2f001002, 0x2f284512, 0x42006404,   // ik.ss.co_322 lt.su.un_220  ln.sw.su_654 lg.co.un_320 
  0x0e000805, 0x580679ee, 0x1e104aee, 0x503b2a0c,   // no.is.un_330 war.de.om_422  yo.lt.ms_422 mt.so.fj_543 
  0x162e2fa7, 0x3b2864a0, 0x31281ca0, 0x1c006808,   // su.fo.hr_532 lg.sw.so_322  id.sw.az_322 ig.id.un_430 
  
  // [13400]
  0x766930af, 0x5d355e13, 0x42fe1113, 0x182a5ea0,   // uz.mfe.crs_655 ts.zu.ss_665  ro.tlh.co_665 ts.mt.ga_322 
  0x4609260d, 0x68214214, 0x01007904, 0xfe004207,   // ia.pl.qu_554 co.jw.ig_666  war.en.un_320 co.tlh.un_420 
  0x475e30af, 0x4d1e1c09, 0x29002302, 0x30205307,   // uz.ts.sn_655 id.ms.aa_444  ca.sl.un_220 ht.sq.uz_432 
  0x47684aa9, 0x080211a4, 0x7669530d, 0x300810ee,   // yo.ig.sn_544 ro.da.no_433  ht.mfe.crs_554 be.uk.uz_422 
  // [13410]
  0x4b405ead, 0x69504b14, 0x511d49a0, 0x33080a02,   // ts.lb.mi_643 mi.fj.mfe_666  to.la.kl_322 pt.no.nn_222 
  0x7800640c, 0x64344a0c, 0x7859680c, 0x78000104,   // lg.ve.un_530 yo.xh.lg_543  ig.rn.ve_543 en.ve.un_320 
  0x55576411, 0x443c2355, 0x1f00651a, 0x391f64ad,   // lg.na.rw_653 ky.ug.kk_442  gv.cy.un_760 lg.cy.br_643 
  0x357678ad, 0x534755a7, 0x095f76ad, 0x1a5346a4,   // ve.crs.zu_643 rw.sn.ht_532  crs.tn.pl_643 qu.ht.tl_433 
  // [13420]
  0x080415ac, 0x011d6355, 0x5e675514, 0x286a680d,   // un.ru.uk_632 sco.la.en_442  rw.ak.ts_666 ig.haw.sw_554 
  0x524b61ad, 0xfc003308, 0x4b046a09, 0x49004b11,   // za.mi.ha_643 nn.zzp.un_430  haw.fi.mi_444 mi.to.un_630 
  0x6a612513, 0x0b1223a4, 0x610454af, 0x1d2279a9,   // eu.za.haw_665 ca.hu.es_433  ik.fi.za_655 war.oc.la_544 
  0x62006113, 0x12190b0d, 0x604b04ec, 0x083748a0,   // za.kha.un_650 es.gl.hu_554  fi.mi.vo_644 tt.ba.uk_322 
  // [13430]
  0x042d6a0c, 0x3e6301a0, 0x1a4b490c, 0x39004804,   // haw.sk.fi_543 en.sco.rm_322  to.mi.tl_543 tt.br.un_320 
  0x2e0e650b, 0x480738a0, 0x3c070a05, 0x0d321702,   // gv.is.fo_542 tk.bg.tt_322  mk.bg.ug_333 sr.bs.cs_222 
  0x2800011a, 0x5300fe04, 0x363c380b, 0x15003507,   // iw.sd.un_760 tlh.ht.un_320  tk.ug.ab_542 tg.un.un_420 
  0x4c2d0d08, 0x440837ee, 0x59005b12, 0x18233d0b,   // cs.sk.wo_443 ba.uk.kk_422  sg.rn.un_640 ku.ky.ar_542 
  // [13440]
  0x3010150b, 0x3d003c1a, 0x0a072305, 0x04100811,   // un.be.uz_542 ug.ku.un_760  ky.bg.mk_333 uk.be.ru_653 
  0x36003509, 0x282134af, 0x1c002802, 0x461229a0,   // tg.ab.un_440 ps.fa.sd_655  sw.id.un_220 sl.hu.qu_322 
  0x35571da7, 0x481d55a4, 0x101704ee, 0x1312060c,   // la.na.zu_532 rw.la.tt_433  ru.sr.be_422 de.hu.et_543 
  0x2e005713, 0x5c001d12, 0x6b5d1dad, 0x0b422207,   // na.fo.un_650 la.sa.un_640  la.ss.ceb_643 oc.co.es_432 
  // [13450]
  0x231d42a0, 0x0836100b, 0x1100190c, 0x2a001f19,   // co.la.ca_322 be.ab.uk_542  gl.ro.un_530 cy.mt.un_750 
  0x0f4b5cee, 0x34002818, 0x062e0c08, 0x24002f07,   // sa.mi.lv_422 sd.ps.un_740  sv.fo.de_443 su.eo.un_420 
  0x46232205, 0x35233707, 0x100708ad, 0x2d004a07,   // oc.ca.qu_333 ba.ky.tg_432  uk.bg.be_643 yo.sk.un_420 
  0x0a004408, 0x170a3c14, 0x68645eee, 0x0e000502,   // kk.mk.un_430 ug.mk.sr_666  ts.lg.ig_422 fr.is.un_220 
  // [13460]
  0x011afcee, 0x34376809, 0x681c1eac, 0x2d00360b,   // zzp.tl.en_422 ig.st.xh_444  ms.id.ig_632 gn.sk.un_520 
  0x55685908, 0x55005e09, 0x65790107, 0x5c1e20ee,   // rn.ig.rw_443 ts.rw.un_440  en.war.gv_432 sq.ms.sa_422 
  0x39755eaf, 0x35002114, 0x2b6903a4, 0x472f73ee,   // ts.nso.br_655 jw.zu.un_660  nl.mfe.vi_433 ny.su.sn_422 
  0x5a002508, 0x47005e1a, 0x73355e0c, 0x672064a9,   // eu.sm.un_430 ts.sn.un_760  ts.zu.ny_543 lg.sq.ak_544 
  // [13470]
  0x5e285208, 0x15202204, 0x496945ec, 0x15434607,   // ha.sw.ts_443 oc.sq.un_332  ln.mfe.to_644 qu.ie.un_432 
  0x13003816, 0x650379a0, 0x05004804, 0x791a1b0d,   // tk.et.un_720 war.nl.gv_322  tt.fr.un_320 tr.tl.war_554 
  0x521312a7, 0x31001107, 0x311b4c07, 0x082335a0,   // hu.et.ha_532 ro.az.un_420  wo.tr.az_432 tg.ky.uk_322 
  0x115e1b07, 0x5a047308, 0x381e5155, 0x0d0e2e0d,   // tr.ts.ro_432 ny.fi.sm_443  kl.ms.tk_442 fo.is.cs_554 
  // [13480]
  0x0d111bee, 0x2800040d, 0x171e60ad, 0x104904af,   // tr.ro.cs_422 fi.sw.un_540  vo.ms.sr_643 fi.to.lt_655 
  0x4f0449a4, 0x0efc6bee, 0x465c36ee, 0x30211807,   // to.fi.bi_433 ceb.zzp.is_422  gn.sa.qu_422 ar.fa.uz_432 
  0x3f004207, 0x44153c13, 0x300f3102, 0x2e001f04,   // co.af.un_420 ug.kk.un_650  az.lv.uz_222 cy.fo.un_320 
  0x10001308, 0x101136ad, 0x49005112, 0x10004009,   // et.lt.un_430 ab.ro.be_643  kl.to.un_640 lb.lt.un_440 
  // [13490]
  0x08002508, 0x4b2404ad, 0x424033a0, 0x0d5c1c09,   // mn.uk.un_430 fi.eo.mi_643  nn.lb.co_322 mr.sa.ne_444 
  0x1a006505, 0x0a151704, 0x46651d04, 0x182d0d0d,   // gv.tl.un_330 sr.mk.un_320  la.gv.qu_332 cs.sk.ga_554 
  0x12213bac, 0x24002c07, 0x13002c07, 0x3e6511a4,   // ks.fa.ur_632 fy.eo.un_420  fy.et.un_420 ro.gv.rm_433 
  0x5300180c, 0x11fe04a0, 0x11007909, 0x42000c02,   // ga.ht.un_530 fi.tlh.ro_322  war.ro.un_440 sv.co.un_220 
  // [134a0]
  0x562d0deb, 0x07303504, 0x100815ec, 0x173530a7,   // cs.sk.mg_662 tg.uz.bg_332  un.uk.be_644 uz.tg.sr_532 
  0x36002019, 0x120e2e02, 0x1a1c3404, 0x12004002,   // sq.gn.un_750 fo.is.hu_222  xh.id.tl_332 lb.hu.un_220 
  0x182e0ea0, 0x3b382a04, 0x32003508, 0x46003107,   // is.fo.ga_322 mt.tk.so_332  zu.bs.un_430 az.qu.un_420 
  0x04496aad, 0x280118a9, 0x5d356b02, 0x1d2e65a0,   // haw.to.fi_643 ar.iw.sd_544  ceb.zu.ss_222 gv.fo.la_322 
  // [134b0]
  0x35070a07, 0x170710a7, 0x25001f12, 0x4d00121a,   // mk.bg.tg_432 be.bg.sr_532  cy.eu.un_640 hu.aa.un_760 
  0x0d1f3705, 0x100804ad, 0x12004d09, 0x5d3b500c,   // st.cy.cs_333 ru.uk.be_643  aa.hu.un_440 fj.so.ss_543 
  0x18311ba9, 0x46352007, 0x3b275c07, 0x35595513,   // tr.az.ga_544 sq.zu.qu_432  sa.gd.so_432 rw.rn.zu_665 
  0x1700420c, 0x73506a04, 0x3150fca4, 0x02003e07,   // co.sr.un_530 haw.fj.ny_332  zzp.fj.az_433 rm.da.un_420 
  // [134c0]
  0x42113bee, 0x3b001523, 0x0d001220, 0x4c053904,   // so.ro.co_422 un.so.un_880  hu.cs.un_850 br.fr.wo_332 
  0x02285aa0, 0x3b5d50a9, 0x1e00500c, 0x5c000f22,   // sm.sw.da_322 fj.ss.so_544  fj.ms.un_530 lv.sa.un_870 
  0x353f04a0, 0x0a311b0d, 0x42053907, 0x19505c11,   // fi.af.zu_322 tr.az.pt_554  br.fr.co_432 sa.fj.gl_653 
  0x040a3502, 0x2035340e, 0x3b212f07, 0x057639a4,   // tg.mk.ru_222 xh.zu.sq_555  su.jw.so_432 br.crs.fr_433 
  // [134d0]
  0x22190504, 0x1d4d15a4, 0x33080c0d, 0x1b2101a0,   // fr.gl.oc_332 un.aa.la_433  sv.no.nn_554 en.jw.tr_322 
  0x15110a04, 0x3e1939a0, 0x493938ee, 0x76053955,   // mk.ro.un_332 br.gl.rm_322  tk.br.to_422 br.fr.crs_442 
  0x25073ca7, 0x583b5c55, 0x361c6a0c, 0x3038250c,   // ug.bg.mn_532 sa.so.om_442  haw.id.gn_543 eu.tk.uz_543 
  0x48006020, 0xfe001c04, 0x400520a0, 0x49000421,   // vo.tt.un_850 id.tlh.un_320  sq.fr.lb_322 fi.to.un_860 
  // [134e0]
  0x69002a29, 0x651d79a4, 0x53003f0c, 0x4300050d,   // mt.mfe.un_960 war.la.gv_433  af.ht.un_530 fr.ie.un_540 
  0x766b010c, 0x5a654b13, 0x3d1221af, 0x27431fac,   // en.ceb.crs_543 mi.gv.sm_665  fa.ur.ku_655 cy.ie.gd_632 
  0x375f48a4, 0x29002a0d, 0x63010714, 0x1f4860a7,   // tt.tn.st_433 mt.sl.un_540  it.en.sco_666 vo.tt.cy_532 
  0x633b0104, 0x31603ead, 0x65054905, 0x3900272b,   // en.so.sco_332 rm.vo.az_643  to.fr.gv_333 gd.br.un_980 
  // [134f0]
  0x2a00330d, 0x5b001c1a, 0x25006809, 0x4069760c,   // nn.mt.un_540 id.sg.un_760  ig.eu.un_440 crs.mfe.lb_543 
  0x373c4804, 0x341812a6, 0x191b0a07, 0x6305680c,   // tt.ug.ba_332 ur.ar.ps_521  pt.tr.gl_432 ig.fr.sco_543 
  0x19002102, 0x36000d13, 0x63070107, 0x2c3e0da9,   // jw.gl.un_220 cs.gn.un_650  en.it.sco_432 cs.rm.fy_544 
  0x6a533ea4, 0x4540050c, 0x23183da0, 0x07011ea0,   // rm.ht.haw_433 fr.lb.ln_543  ku.ar.ky_322 ms.en.it_322 
  // [13500]
  0x030727a0, 0x7901635a, 0x15525504, 0x063b01a0,   // gd.it.nl_322 sco.en.war_553  rw.ha.un_332 en.so.de_322 
  0x1a004c04, 0x3f7901a9, 0x4200071b, 0x2d000202,   // wo.tl.un_320 en.war.af_544  it.co.un_770 da.sk.un_220 
  0x341823a4, 0x022e0e65, 0x25000812, 0x071b3802,   // ky.ar.ps_433 is.fo.da_763  uk.mn.un_640 tk.tr.it_222 
  0x0a1737a0, 0x23353c04, 0x3b211212, 0x180e0207,   // ba.sr.mk_322 ug.tg.ky_332  ur.fa.ks_654 da.is.ga_432 
  // [13510]
  0x0a002e02, 0x51005002, 0x3153690b, 0x30005302,   // fo.pt.un_220 fj.kl.un_220  mfe.ht.az_542 ht.uz.un_220 
  0x5339690c, 0x0c4006ee, 0x054c53ad, 0x053963ee,   // mfe.br.ht_543 de.lb.sv_422  ht.wo.fr_643 sco.br.fr_422 
  0x40060c5a, 0x65635355, 0x36040aa0, 0x0d005c2a,   // sv.de.lb_553 ht.sco.gv_442  mk.ru.ab_322 sa.ne.un_970 
  0x50004604, 0x022e530c, 0x440410ad, 0x18000e09,   // qu.fj.un_320 ht.fo.da_543  be.ru.kk_643 is.ga.un_440 
  // [13520]
  0x53404cee, 0x150410a9, 0x47001302, 0x0e002219,   // wo.lb.ht_422 be.ru.un_544  et.sn.un_220 oc.is.un_750 
  0x0f003804, 0x4b00280d, 0x5c00471a, 0x21183ba4,   // tk.lv.un_320 sw.mi.un_540  sn.sa.un_760 ks.ar.fa_433 
  0x28684608, 0x21005821, 0x150262ee, 0x10151507,   // qu.ig.sw_443 om.jw.un_860  kha.da.un_422 un.be.un_420 
  0x3f001002, 0x2e001808, 0x08104002, 0x18000e1a,   // lt.af.un_220 ga.fo.un_430  lb.lt.no_222 is.ga.un_760 
  // [13530]
  0x5e6501a0, 0x0411350c, 0x78217305, 0x190b7902,   // en.gv.ts_322 tg.ro.ru_543  ny.jw.ve_333 war.es.gl_222 
  0x402f1eee, 0x170804a7, 0x04300804, 0x19001504,   // ms.su.lb_422 ru.uk.sr_532  uk.uz.ru_332 un.gl.un_320 
  0x19430a0c, 0x33022eee, 0x11002522, 0x34123007,   // pt.ie.gl_543 fo.da.nn_422  mn.ro.un_870 uz.ur.ps_432 
  0xfe1624ee, 0x3d3021a9, 0x40130802, 0x27fc1505,   // eo.hr.tlh_422 fa.uz.ku_544  no.et.lb_222 un.zzp.gd_333 
  // [13540]
  0x0800100b, 0x44153804, 0x292d0d09, 0x58003e04,   // be.uk.un_520 tk.kk.un_320  cs.sk.sl_444 rm.om.un_320 
  0x11003608, 0x13080ca0, 0x3c2821a0, 0x13001104,   // ab.ro.un_430 sv.no.et_322  fa.sd.ug_322 ro.et.un_320 
  0x0c000807, 0x0d2d09ee, 0x0e6506a0, 0x3d213cee,   // no.sv.un_420 pl.sk.cs_422  de.gv.is_322 ug.fa.ku_422 
  0x12000204, 0x1d2f4f13, 0x321716ec, 0x135c0d11,   // da.hu.un_320 bi.su.la_665  hr.sr.bs_644 ne.sa.bh_653 
  // [13550]
  0x321642ee, 0x122f400d, 0x11545104, 0x2d0d4805,   // co.hr.bs_422 lb.su.hu_554  kl.ik.ro_332 tt.cs.sk_333 
  0x231504ec, 0x31005012, 0x51116408, 0x31005107,   // ru.ky.un_640 fj.az.un_640  lg.ro.kl_443 kl.az.un_420 
  0x5111240c, 0x3020350e, 0x042d0fa4, 0x204c4802,   // eo.ro.kl_543 zu.sq.uz_555  lv.sk.fi_433 tt.wo.sq_222 
  0x51001e05, 0x34370fa0, 0x35002007, 0x3b313402,   // ms.kl.un_330 lv.st.xh_322  sq.zu.un_420 xh.az.so_222 
  // [13560]
  0x0c1e73ee, 0x03061d07, 0x37001b04, 0x3120fe05,   // ny.ms.sv_422 la.de.nl_432  tr.st.un_320 tlh.sq.az_333 
  0x513746ee, 0x2e1c2f04, 0x08000a0d, 0x503120a0,   // qu.st.kl_422 su.id.fo_332  mk.uk.un_540 sq.az.fj_322 
  0x51004c11, 0x5100fc02, 0x2423120c, 0x52005302,   // wo.kl.un_630 zzp.kl.un_220  hu.ca.eo_543 ht.ha.un_220 
  0x102535a4, 0x17083607, 0x4a004c0c, 0x11000b1b,   // tg.mn.be_433 ab.uk.sr_432  wo.yo.un_530 es.ro.un_770 
  // [13570]
  0x2e0e120d, 0x560553a0, 0x2d0d50a0, 0x1e5d0f11,   // hu.is.fo_554 ht.fr.mg_322  fj.cs.sk_322 lv.ss.ms_653 
  0x29004004, 0x43261d07, 0x53006113, 0x20004202,   // lb.sl.un_320 la.ia.ie_432  za.ht.un_650 co.sq.un_220 
  0x191d0d07, 0x08352505, 0x16006121, 0x23182104,   // cs.la.gl_432 mn.tg.uk_333  za.hr.un_860 fa.ar.ky_332 
  0x1f421d07, 0x611629a4, 0x29005304, 0x00001615,   // la.co.cy_432 sl.hr.za_433  ht.sl.un_320 hr.un.un_700 
  // [13580]
  0x03006505, 0x0f3912a4, 0x55003718, 0x255e2307,   // gv.nl.un_330 hu.br.lv_433  st.rw.un_740 ca.ts.eu_432 
  0x7302680c, 0x42006521, 0x4f42070c, 0x0e392da4,   // ig.da.ny_543 gv.co.un_860  it.co.bi_543 sk.br.is_433 
  0x4d1f3911, 0x6935530e, 0x11245107, 0x4069390c,   // br.cy.aa_653 ht.zu.mfe_555  kl.eo.ro_432 br.mfe.lb_543 
  0x541151a4, 0x3d123004, 0xfe6865af, 0x0000642d,   // kl.ro.ik_433 uz.ur.ku_332  gv.ig.tlh_655 lg.un.un_A00 
  // [13590]
  0x1a6760af, 0x73796b12, 0x7859555a, 0x3f06040c,   // vo.ak.tl_655 ceb.war.ny_654  rw.rn.ve_553 fi.de.af_543 
  0x65006b2a, 0x476b3055, 0x305c5eee, 0x42003912,   // ceb.gv.un_970 uz.ceb.sn_442  ts.sa.uz_422 br.co.un_640 
  0x134211a7, 0x790439ad, 0x51002802, 0x6b603e12,   // ro.co.et_532 br.fi.war_643  sw.kl.un_220 rm.vo.ceb_654 
  0x1a6446a7, 0x426865ec, 0x504811a6, 0x39484d05,   // qu.lg.tl_532 gv.ig.co_644  ro.tt.fj_521 aa.tt.br_333 
  // [135a0]
  0x1b005c13, 0x17001f04, 0x19250b0c, 0xfe42680c,   // sa.tr.un_650 cy.sr.un_320  es.eu.gl_543 ig.co.tlh_543 
  0x24421104, 0x3b65420c, 0x47391f11, 0x65105a05,   // ro.co.eo_332 co.gv.so_543  cy.br.sn_653 sm.lt.gv_333 
  0x1a021d04, 0x2600111a, 0x24114212, 0x58004204,   // la.da.tl_332 ro.ia.un_760  co.ro.eo_654 co.om.un_320 
  0x5c1246a0, 0x18004607, 0x125c650c, 0x3e4839a7,   // qu.hu.sa_322 qu.ga.un_420  gv.sa.hu_543 br.tt.rm_532 
  // [135b0]
  0x796405a4, 0x5c65420d, 0x0b6b02ee, 0xfe006818,   // fr.lg.war_433 co.gv.sa_554  da.ceb.es_422 ig.tlh.un_740 
  0xfe68650d, 0x2c6761a9, 0x02005818, 0x38426511,   // gv.ig.tlh_554 za.ak.fy_544  om.da.un_740 gv.co.tk_653 
  0x113e51ee, 0x4c005d04, 0xfe42650c, 0x6748390c,   // kl.rm.ro_422 ss.wo.un_320  gv.co.tlh_543 br.tt.ak_543 
  0x1951110c, 0x04021a08, 0x6942390c, 0x24115108,   // ro.kl.gl_543 tl.da.fi_443  br.co.mfe_543 kl.ro.eo_443 
  // [135c0]
  0x24511004, 0x55001b0d, 0x35103608, 0x3e006012,   // lt.kl.eo_332 tr.rw.un_540  ab.be.tg_443 vo.rm.un_640 
  0x34005d07, 0x38650c08, 0x2134180e, 0x13006012,   // ss.xh.un_420 sv.gv.tk_443  ar.ps.fa_555 vo.et.un_640 
  0x04130e07, 0x072504ee, 0x795a49ec, 0x55006708,   // is.et.fi_432 ru.mn.bg_422  to.sm.war_644 ak.rw.un_430 
  0x545a510c, 0x3b6b5e55, 0x64005519, 0x040e1305,   // kl.sm.ik_543 ts.ceb.so_442  rw.lg.un_750 et.is.fi_333 
  // [135d0]
  0x213423ac, 0x48640204, 0x76005323, 0x55001008,   // ky.ps.fa_632 da.lg.tt_332  ht.crs.un_880 lt.rw.un_430 
  0x21005507, 0x633e2c14, 0x53106ba0, 0x1a7946ec,   // rw.jw.un_420 fy.rm.sco_666  ceb.lt.ht_322 qu.war.tl_644 
  0x041035ee, 0x2f313005, 0x3c004809, 0x0964550c,   // tg.be.ru_422 uz.az.su_333  tt.ug.un_440 rw.lg.pl_543 
  0x4400380e, 0x3c00302a, 0x2d0e18ac, 0x5c133b0b,   // tk.kk.un_550 uz.ug.un_970  ga.is.sk_632 ks.bh.sa_542 
  // [135e0]
  0x2f005007, 0x2d001811, 0x170e100c, 0x17352302,   // fj.su.un_420 ga.sk.un_630  lt.is.sr_543 ky.tg.sr_222 
  0x020f2508, 0x25203604, 0x455f37ad, 0x170a04a9,   // eu.lv.da_443 gn.sq.eu_332  st.tn.ln_643 ru.mk.sr_544 
  0x13005e04, 0x64000f07, 0x04071505, 0xfe374504,   // ts.et.un_320 lv.lg.un_420  un.bg.ru_333 ln.st.tlh_332 
  0x36651d04, 0x1144370c, 0x5c003809, 0x23103709,   // la.gv.gn_332 ba.kk.ro_543  tk.sa.un_440 ba.be.ky_444 
  // [135f0]
  0x2b2f1cee, 0x300b73a0, 0x10042b04, 0x083e02a0,   // id.su.vi_422 ny.es.uz_322  vi.fi.lt_332 da.rm.no_322 
  0x1b1149a4, 0x4815380d, 0x40002013, 0x11000a08,   // to.ro.tr_433 tk.tt.un_540  sq.lb.un_650 mk.ro.un_430 
  0x0a3504a7, 0x215322ee, 0x15081112, 0x3e000202,   // ru.tg.mk_532 oc.ht.jw_422  ro.uk.un_654 da.rm.un_220 
  0x1d110107, 0x3400fc20, 0x5726fc0c, 0xfc003102,   // en.ro.la_432 zzp.xh.un_850  zzp.ia.na_543 az.zzp.un_220 
  // [13600]
  0x0b1205a0, 0x48003735, 0x31381b0b, 0x1117360c,   // fr.hu.es_322 ba.tt.un_A90  tr.tk.az_542 ab.sr.ro_543 
  0x35041555, 0x3400010d, 0x1c2f1a11, 0x170a360c,   // un.ru.tg_442 en.xh.un_540  tl.su.id_653 ab.mk.sr_543 
  0x15374812, 0x06001a07, 0x1f0163a4, 0x06080209,   // tt.ba.un_654 tl.de.un_420  sco.en.cy_433 da.no.de_444 
  0x5c004902, 0x0c003008, 0x064024a9, 0x46000613,   // to.sa.un_220 uz.sv.un_430  eo.lb.de_544 de.qu.un_650 
  // [13610]
  0x18000f19, 0x58303e08, 0x1a003e12, 0x1d00432a,   // lv.ga.un_750 rm.uz.om_443  rm.tl.un_640 ie.la.un_970 
  0x4d003013, 0x06406304, 0x06001a0d, 0x3b005607,   // uz.aa.un_650 sco.lb.de_332  tl.de.un_540 mg.so.un_420 
  0x584d3b04, 0x0e04130c, 0x0c006508, 0x1a006307,   // so.aa.om_332 et.fi.is_543  gv.sv.un_430 sco.tl.un_420 
  0x4c000619, 0x5c000f10, 0x51003302, 0x28330c12,   // de.wo.un_750 lv.sa.un_620  nn.kl.un_220 sv.nn.sw_654 
  // [13620]
  0x08001312, 0x64174c02, 0x23000b05, 0x39420507,   // et.no.un_640 wo.sr.lg_222  es.ca.un_330 fr.co.br_432 
  0x582821a4, 0x27005804, 0x6b002822, 0x343b350c,   // jw.sw.om_433 om.gd.un_320  sw.ceb.un_870 zu.so.xh_543 
  0x1c3234ad, 0x06347312, 0x785f35a9, 0x4b002f13,   // ps.bs.mr_643 ny.xh.de_654  zu.tn.ve_544 su.mi.un_650 
  0x3b005813, 0x3534faa9, 0x04002f13, 0x285d5108,   // om.so.un_650 nr.xh.zu_544  su.fi.un_650 kl.ss.sw_443 
  // [13630]
  0x3f000804, 0x04002f0b, 0x063302a0, 0x430665ad,   // no.af.un_320 su.fi.un_520  da.nn.de_322 gv.de.ie_643 
  0x48004e22, 0x5a005102, 0x27001a07, 0x183c44ee,   // ay.tt.un_870 kl.sm.un_220  tl.gd.un_420 kk.ug.ar_422 
  0x225623a9, 0x2b002f04, 0x2d0d18a0, 0x04002f04,   // ca.mg.oc_544 su.vi.un_320  ga.cs.sk_322 su.fi.un_320 
  0x0b001805, 0x15071705, 0x192e0b07, 0x2300120b,   // ga.es.un_330 sr.bg.un_333  es.fo.gl_432 hu.ca.un_520 
  // [13640]
  0x5c001c23, 0x16291da0, 0x1d0ffe07, 0x190afea9,   // mr.sa.un_880 la.sl.hr_322  tlh.lv.la_432 tlh.pt.gl_544 
  0x0d001605, 0x10002a18, 0x2c002d14, 0x2e000e10,   // hr.cs.un_330 mt.lt.un_740  sk.fy.un_660 is.fo.un_620 
  0x36460bee, 0x09001702, 0x2e0e2b08, 0x12002b12,   // es.qu.gn_422 sr.pl.un_220  vi.is.fo_443 vi.hu.un_640 
  0x12002b05, 0x1a6b79ad, 0x231c210c, 0x16003308,   // vi.hu.un_330 war.ceb.tl_643  jw.id.ca_543 nn.hr.un_430 
  // [13650]
  0x231979ee, 0x3f67fc04, 0x21000a09, 0x4400110d,   // war.gl.ca_422 zzp.ak.af_332  pt.jw.un_440 ro.kk.un_540 
  0x283c4404, 0x69613808, 0x42071212, 0x38060c04,   // kk.ug.sd_332 tk.za.mfe_443  hu.it.co_654 sv.de.tk_332 
  0x0430150d, 0x30fc6ea7, 0x16392904, 0x07002919,   // un.uz.ru_554 hmn.zzp.uz_532  sl.br.hr_332 sl.it.un_750 
  0x110a0708, 0x20420713, 0x42270712, 0x6a5a0da4,   // bg.mk.ro_443 it.co.sq_665  it.gd.co_654 cs.sm.haw_433 
  // [13660]
  0x0c00200c, 0x51001f07, 0x285c7907, 0x204006a4,   // sq.sv.un_530 cy.kl.un_420  war.sa.sw_432 de.lb.sq_433 
  0x280f64a4, 0x101764ee, 0x3f5b2caf, 0x12511f11,   // lg.lv.sw_433 lg.sr.lt_422  fy.sg.af_655 cy.kl.hu_653 
  0x580f1e05, 0x2f00050e, 0x42003407, 0x35004508,   // ms.lv.om_333 fr.su.un_550  xh.co.un_420 ln.zu.un_430 
  0x20003304, 0x21002320, 0x5000540d, 0x104c5155,   // nn.sq.un_320 ca.jw.un_850  ik.fj.un_540 kl.wo.lt_442 
  // [13670]
  0x1345510c, 0x4c496aa4, 0x5000510c, 0x5c00390c,   // kl.ln.et_543 haw.to.wo_433  kl.fj.un_530 br.sa.un_530 
  0x5e5d35af, 0x46190b08, 0x1cfc15ad, 0x5464510c,   // zu.ss.ts_655 es.gl.qu_443  un.zzp.id_643 kl.lg.ik_543 
  0x0823110c, 0x53222360, 0x19004c04, 0x04100f02,   // ro.ky.uk_543 ca.oc.ht_664  wo.gl.un_320 lv.lt.fi_222 
  0x48002221, 0x251e64a0, 0x44003722, 0x4410040c,   // oc.tt.un_860 lg.ms.eu_322  ba.kk.un_870 ru.be.kk_543 
  // [13680]
  0x200f480c, 0x091246ee, 0x33005c04, 0x5d101a02,   // tt.lv.sq_543 qu.hu.pl_422  sa.nn.un_320 tl.lt.ss_222 
  0x08003608, 0x65000b04, 0x2c0202a0, 0x10170707,   // ab.uk.un_430 es.gv.un_320  da.da.fy_322 bg.sr.be_432 
  0x47001e04, 0x283d21a0, 0x53006807, 0x685d5f12,   // ms.sn.un_320 fa.ku.sd_322  ig.ht.un_420 tn.ss.ig_654 
  0x251515a7, 0x47005d20, 0x15442512, 0x082e33a7,   // un.mn.un_520 ss.sn.un_850  mn.kk.un_654 nn.fo.no_532 
  // [13690]
  0x3830440c, 0x6876530e, 0x52320dee, 0x360d01a0,   // kk.uz.tk_543 ht.crs.ig_555  cs.bs.ha_422 en.cs.gn_322 
  0x4a2d0d0d, 0x0d000108, 0xfc001d12, 0x3b2f2108,   // cs.sk.yo_554 en.cs.un_430  la.zzp.un_640 jw.su.so_443 
  0x52000d21, 0x57475dad, 0x093b2608, 0x08024202,   // cs.ha.un_860 ss.sn.na_643  ia.so.pl_443 co.da.no_222 
  0x19520dee, 0x4d571da4, 0x0b461907, 0x55290dad,   // cs.ha.gl_422 la.na.aa_433  gl.qu.es_432 cs.sl.rw_643 
  // [136a0]
  0x23003705, 0x475f2a07, 0x5f355d0c, 0x48fc6ba4,   // ba.ky.un_330 mt.tn.sn_432  ss.zu.tn_543 ceb.zzp.tt_433 
  0x08042307, 0x0b0a1f05, 0x101125ad, 0x0f6352a7,   // ky.ru.uk_432 cy.pt.es_333  mn.ro.be_643 ha.sco.lv_532 
  0x47005d13, 0x1926010c, 0x64005d19, 0x0b791f04,   // ss.sn.un_650 en.ia.gl_543  ss.lg.un_750 cy.war.es_332 
  0x0b191fa6, 0x2c1d0aa6, 0x59004d19, 0x0d004d0e,   // cy.gl.es_521 pt.la.fy_521  aa.rn.un_750 aa.cs.un_550 
  // [136b0]
  0x110b1907, 0x32020dee, 0x5d005219, 0x1b372ea0,   // gl.es.ro_432 cs.da.bs_422  ha.ss.un_750 fo.st.tr_322 
  0x360b220c, 0x30353ca0, 0x0b000e04, 0x52020d0c,   // oc.es.gn_543 ug.tg.uz_322  is.es.un_320 cs.da.ha_543 
  0x590f1d08, 0x21790507, 0x4205150c, 0x11190b0b,   // la.lv.rn_443 fr.war.jw_432  un.fr.co_543 es.gl.ro_542 
  0x470d1da4, 0x345d35ee, 0x431d4d0b, 0x35231708,   // la.cs.sn_433 zu.ss.xh_422  aa.la.ie_542 sr.ky.tg_443 
  // [136c0]
  0x36000b0d, 0x1a001b07, 0x20000c18, 0x183d2807,   // es.gn.un_540 tr.tl.un_420  sv.sq.un_740 sd.ku.ar_432 
  0x120b0ea0, 0x13121104, 0x182321a0, 0x1d002310,   // is.es.hu_322 ro.hu.et_332  fa.ky.ar_322 ca.la.un_620 
  0x111709ac, 0x060a220b, 0x481015ee, 0x12001321,   // pl.sr.ro_632 oc.pt.de_542  un.be.tt_422 et.hu.un_860 
  0x79fc01a4, 0x17000905, 0x06122da0, 0x634301ee,   // en.zzp.war_433 pl.sr.un_330  sk.hu.de_322 en.ie.sco_422 
  // [136d0]
  0x04060ca4, 0x0d12360b, 0x0d122d04, 0x1d0312a0,   // sv.de.fi_433 gn.hu.cs_542  sk.hu.cs_332 hu.nl.la_322 
  0x4a005904, 0x09360607, 0x3e1906ec, 0x12150107,   // rn.yo.un_320 de.gn.pl_432  de.gl.rm_644 en.hu.un_420 
  0x12572e55, 0x55645ead, 0x5c002d02, 0x5e355dee,   // fo.na.hu_442 ts.lg.rw_643  sk.sa.un_220 ss.zu.ts_422 
  0x0804020c, 0x06313ea4, 0x37004836, 0x4600390c,   // da.fi.no_543 rm.az.de_433  tt.ba.un_AA0 br.qu.un_530 
  // [136e0]
  0x100f020b, 0x02120aa0, 0x2e0e1802, 0x0d292dee,   // da.lv.lt_542 pt.hu.da_322  ga.is.fo_222 sk.sl.cs_422 
  0x2c2e0ead, 0x4822230d, 0x34785dec, 0x20323802,   // is.fo.fy_643 ca.oc.tt_554  ss.ve.xh_644 tk.bs.sq_222 
  0x2d00180c, 0x48000612, 0x400c5b04, 0x483517ad,   // ga.sk.un_530 de.tt.un_640  sg.sv.lb_332 sr.tg.tt_643 
  0x1700440d, 0x38000a08, 0x0500380c, 0x041013a7,   // kk.sr.un_540 pt.tk.un_430  tk.fr.un_530 et.lt.fi_532 
  // [136f0]
  0x2afe11ee, 0x020c0604, 0x48303c0e, 0x0a002519,   // ro.tlh.mt_422 de.sv.da_332  ug.uz.tt_555 mn.mk.un_750 
  0x22290c02, 0x29000f0d, 0x3c34180c, 0x0c000219,   // sv.sl.oc_222 lv.sl.un_540  ar.ps.ug_543 da.sv.un_750 
  0x68004909, 0x2e05fc0c, 0x21006a04, 0x2c041007,   // to.ig.un_440 zzp.fr.fo_543  haw.jw.un_320 lt.fi.fy_432 
  0x15fc35a0, 0x400e05a0, 0x23351504, 0x06595508,   // zu.zzp.un_322 fr.is.lb_322  un.tg.ky_332 rw.rn.de_443 
  // [13700]
  0x6b004609, 0x4634350c, 0x352c2fa0, 0x39001d0d,   // qu.ceb.un_440 zu.xh.qu_543  su.fy.zu_322 la.br.un_540 
  0x65583bad, 0x1d002d0b, 0x3500fc08, 0x2f790608,   // so.om.gv_643 sk.la.un_520  zzp.zu.un_430 de.war.su_443 
  0x3b00640c, 0x35341a05, 0x23003711, 0x465022ee,   // lg.so.un_530 tl.xh.zu_333  ba.ky.un_630 oc.fj.qu_422 
  0x64653b11, 0x283c2108, 0x21123bee, 0x38002c08,   // so.gv.lg_653 fa.ug.sd_443  ks.ur.fa_422 fy.tk.un_430 
  // [13710]
  0x6a00090c, 0x09002c02, 0x2e060ea4, 0x40255d55,   // pl.haw.un_530 fy.pl.un_220  is.de.fo_433 ss.eu.lb_442 
  0x022c3f04, 0xfc341a04, 0x10002313, 0x643b4d12,   // af.fy.da_332 tl.xh.zzp_332  ky.be.un_650 aa.so.lg_654 
  0x043715a4, 0x20302d07, 0x4c00460e, 0x182d0a07,   // un.ba.ru_433 sk.uz.sq_432  qu.wo.un_550 pt.sk.ga_432 
  0x07361708, 0x48373809, 0x5c263008, 0x49004a0d,   // sr.ab.bg_443 tk.ba.tt_444  uz.ia.sa_443 yo.to.un_540 
  // [13720]
  0x301d43a4, 0x08003311, 0x09000108, 0x15003c0c,   // ie.la.uz_433 nn.no.un_630  en.pl.un_430 ug.un.un_530 
  0x30260107, 0x30503b0c, 0x0a2751ee, 0x28330809,   // en.ia.uz_432 so.fj.uz_543  kl.gd.pt_422 no.nn.sw_444 
  0x182e0e0c, 0x6b681dec, 0x32132ea0, 0x40001502,   // is.fo.ga_543 la.ig.ceb_644  fo.et.bs_322 un.lb.un_220 
  0x08134207, 0x113035a4, 0x2f003612, 0x09003904,   // co.et.no_432 tg.uz.ro_433  gn.su.un_640 br.pl.un_320 
  // [13730]
  0x3b0d0908, 0x0e002005, 0x13115107, 0x1e451f07,   // hi.ne.ks_443 sq.is.un_330  kl.ro.et_432 cy.ln.ms_432 
  0x68151d0c, 0x42111da4, 0x4a361212, 0x56390504,   // la.ig.un_530 la.ro.co_433  hu.gn.yo_654 fr.br.mg_332 
  0x6b2f21a7, 0x4800441b, 0x0e045d0b, 0x3004155a,   // jw.su.ceb_532 kk.tt.un_770  ss.fi.is_542 un.ru.uz_553 
  0x2e004902, 0x1d134ba7, 0x1f001c04, 0xfe4e5112,   // to.fo.un_220 mi.et.la_532  id.cy.un_320 kl.ay.tlh_654 
  // [13740]
  0x4811380c, 0x2e003807, 0x73462809, 0x48122d12,   // tk.ro.tt_543 tk.fo.un_420  sw.qu.ny_444 sk.hu.tt_654 
  0x12002c08, 0x17001120, 0x09481211, 0x2322090c,   // fy.hu.un_430 ro.sr.un_850  hu.tt.pl_653 pl.oc.ca_543 
  0x12480608, 0x094806a4, 0x303507a9, 0x092322ec,   // de.tt.hu_443 de.tt.pl_433  bg.tg.uz_544 oc.ca.pl_644 
  0x3723150b, 0x12004819, 0x12133eee, 0x190a0907,   // un.ky.ba_542 tt.hu.un_750  rm.et.hu_422 pl.pt.gl_432 
  // [13750]
  0x65021da4, 0x22240b08, 0x36094dad, 0x2200090c,   // la.da.gv_433 es.eo.oc_443  aa.pl.gn_643 pl.oc.un_530 
  0x5c2f1d07, 0x1d2f0307, 0x0a481307, 0x03004c0c,   // la.su.sa_432 nl.su.la_432  et.tt.pt_432 wo.nl.un_530 
  0x08043502, 0x20003702, 0x23043702, 0x04080a0d,   // tg.ru.uk_222 st.sq.un_220  ba.ru.ky_222 mk.uk.ru_554 
  0x0a3035ee, 0x15153007, 0x240d2eee, 0x4b6a2511,   // tg.uz.mk_422 uz.un.un_420  fo.cs.eo_422 eu.haw.mi_653 
  // [13760]
  0x29000f0c, 0x5e7350ad, 0x4b5a4f0d, 0x550d4aa4,   // lv.sl.un_530 fj.ny.ts_643  bi.sm.mi_554 yo.cs.rw_433 
  0x52555907, 0x0d292da9, 0x421d4508, 0x1d0722a0,   // rn.rw.ha_432 sk.sl.cs_544  ln.la.co_443 oc.it.la_322 
  0x204d24a4, 0x49007318, 0x5547020b, 0x17250a04,   // eo.aa.sq_433 ny.to.un_740  da.sn.rw_542 mk.mn.sr_332 
  0x5c21feee, 0x09007309, 0x59453013, 0x45426aa4,   // tlh.jw.sa_422 ny.pl.un_440  uz.ln.rn_665 haw.co.ln_433 
  // [13770]
  0x513513a0, 0x0d000e1a, 0x063e0c07, 0x134a6409,   // et.zu.kl_322 is.cs.un_760  sv.rm.de_432 lg.yo.et_444 
  0x07041709, 0x0c200607, 0x060c4007, 0x455d13a7,   // sr.ru.bg_444 de.sq.sv_432  lb.sv.de_432 et.ss.ln_532 
  0x2d004c07, 0x330860a0, 0x12000c09, 0x21052211,   // wo.sk.un_420 vo.no.nn_322  sv.hu.un_440 oc.fr.jw_653 
  0x130c3307, 0x061321ac, 0x33004908, 0x3100382b,   // nn.sv.et_432 jw.et.de_632  to.nn.un_430 tk.az.un_980 
  // [13780]
  0x2e0e51af, 0x045851a9, 0x0e402ea4, 0x26005113,   // kl.is.fo_655 kl.om.fi_544  fo.lb.is_433 kl.ia.un_650 
  0x2c2f2307, 0x05122f05, 0x511f580c, 0x525839a9,   // ca.su.fy_432 su.hu.fr_333  om.cy.kl_543 br.om.ha_544 
  0x184d6008, 0x172335ac, 0x02644812, 0x585c4da4,   // vo.aa.ga_443 tg.ky.sr_632  tt.lg.da_654 aa.sa.om_433 
  0x48005820, 0x40000e13, 0x2e000b02, 0x10230a1d,   // om.tt.un_850 is.lb.un_650  es.fo.un_220 pt.ca.lt_852 
  // [13790]
  0x482338ac, 0x10381511, 0x20504d0c, 0x31003502,   // tk.ky.tt_632 un.tk.be_653  aa.fj.sq_543 zu.az.un_220 
  0x20004d0c, 0x08006507, 0x4815040e, 0x50002104,   // aa.sq.un_530 gv.no.un_420  ru.tt.un_550 jw.fj.un_320 
  0x6b1a38a9, 0x0c00690c, 0x31353455, 0x0e190b02,   // tk.tl.ceb_544 mfe.sv.un_530  xh.zu.az_442 es.gl.is_222 
  0x02003811, 0x07654d08, 0x07423e07, 0x233648ec,   // tk.da.un_630 aa.gv.it_443  rm.co.it_432 tt.ab.ky_644 
  // [137a0]
  0x381b3ba4, 0x204d5012, 0x09005908, 0x4c001f19,   // so.tr.tk_433 fj.aa.sq_654  rn.pl.un_430 cy.wo.un_750 
  0x4d0f3808, 0x440a0707, 0x2e073ea9, 0x481515a9,   // tk.lv.aa_443 bg.mk.kk_432  rm.it.fo_544 un.tt.un_540 
  0x3f006b04, 0x42073e09, 0x1500252a, 0x0565580b,   // ceb.af.un_320 rm.it.co_444  mn.un.un_970 om.gv.fr_542 
  0x1b384d11, 0x54271809, 0x5c0d1c60, 0x32381ba7,   // aa.tk.tr_653 ga.gd.ik_444  mr.ne.sa_664 tr.tk.bs_532 
  // [137b0]
  0x211c2f07, 0x1b1e4fad, 0x05000604, 0x3b1d09a7,   // su.id.jw_432 bi.ms.tr_643  de.fr.un_320 pl.la.so_532 
  0x1c003202, 0x46002007, 0x28487904, 0x31214dee,   // bs.id.un_220 sq.qu.un_420  war.tt.sw_332 aa.jw.az_422 
  0x650e0408, 0x18343d05, 0x045451ad, 0x32161b02,   // fi.is.gv_443 ku.ps.ar_333  kl.ik.fi_643 tr.hr.bs_222 
  0x1b3851ec, 0x1b3f4da4, 0x27391faf, 0x6e000312,   // kl.tk.tr_644 aa.af.tr_433  cy.br.gd_655 nl.hmn.un_640 
  // [137c0]
  0x423e2314, 0x360a17ec, 0x33082305, 0x04100860,   // ca.rm.co_666 sr.mk.ab_644  ca.no.nn_333 uk.be.ru_664 
  0x15073cee, 0x04301007, 0x0b00460c, 0x135c1c09,   // ug.bg.un_422 be.uz.ru_432  qu.es.un_530 mr.sa.bh_444 
  0x531dfc04, 0x06400cee, 0x10002505, 0x06000f07,   // zzp.la.ht_332 sv.lb.de_422  mn.be.un_330 lv.de.un_420 
  0x2507360c, 0x2c00fc05, 0x0700fc19, 0x0136fc04,   // ab.bg.mn_543 zzp.fy.un_330  zzp.it.un_750 zzp.gn.en_332 
  // [137d0]
  0x38303c09, 0x4a001804, 0x2e4d58a9, 0x3000670c,   // ug.uz.tk_444 ga.yo.un_320  om.aa.fo_544 ak.uz.un_530 
  0x2f6b620c, 0x07080aa9, 0x11003814, 0x07004223,   // kha.ceb.su_543 mk.uk.bg_544  tk.ro.un_660 co.it.un_880 
  0x18002c0b, 0x67394daf, 0x3e00391b, 0x471273a7,   // fy.ga.un_520 aa.br.ak_655  br.rm.un_770 ny.hu.sn_532 
  0x1d2d0d5a, 0x2322480b, 0x1f002c09, 0x4b02040d,   // cs.sk.la_553 tt.oc.ca_542  fy.cy.un_440 fi.da.mi_554 
  // [137e0]
  0x040d020c, 0x6902040c, 0x04020d07, 0x1a105d0d,   // da.cs.fi_543 fi.da.mfe_543  cs.da.fi_432 ss.lt.tl_554 
  0x390d53a7, 0x080e33ee, 0x33022ea4, 0x393f4707,   // ht.cs.br_532 nn.is.no_422  fo.da.nn_433 sn.af.br_432 
  0x28002f07, 0x15104fec, 0x381021ad, 0x1f6533a0,   // su.sw.un_420 bi.lt.un_644  jw.lt.tk_643 nn.gv.cy_322 
  0x4c5363ee, 0x385355a7, 0x4c0d6905, 0x272865a9,   // sco.ht.wo_422 rw.ht.tk_532  mfe.cs.wo_333 gv.sw.gd_544 
  // [137f0]
  0x073110a4, 0x05534055, 0x24000d09, 0x1f650504,   // lt.az.it_433 lb.ht.fr_442  cs.eo.un_440 fr.gv.cy_332 
  0x5e1b310c, 0x53020da4, 0x34003105, 0x2d0d530c,   // az.tr.ts_543 cs.da.ht_433  az.xh.un_330 ht.cs.sk_543 
  0x2e361207, 0x09784e13, 0x303810a9, 0x47005305,   // hu.gn.fo_432 ay.ve.pl_665  lt.tk.uz_544 ht.sn.un_330 
  0x4c020460, 0x45003605, 0x4e353460, 0x1d006b12,   // fi.da.wo_664 gn.ln.un_330  xh.zu.ay_664 ceb.la.un_640 
  
  // [13800]
  0x2e2d0d55, 0x201028ee, 0x2e1b38ee, 0x600f1108,   // cs.sk.fo_442 sw.lt.sq_422  tk.tr.fo_422 ro.lv.vo_443 
  0x041d670c, 0x34283b0b, 0x52001002, 0x04105aee,   // ak.la.fi_543 ks.sd.ps_542  lt.ha.un_220 sm.lt.fi_422 
  0x2f001511, 0x2a000404, 0x5c1254a4, 0x4c641f08,   // un.su.un_630 fi.mt.un_320  ik.hu.sa_433 cy.lg.wo_443 
  0x484d3baf, 0x0d2d3608, 0x6000391a, 0x313048a4,   // so.aa.tt_655 gn.sk.cs_443  br.vo.un_760 tt.uz.az_433 
  // [13810]
  0x0454510c, 0x2d0d2baf, 0x241112a7, 0x51001c13,   // kl.ik.fi_543 vi.cs.sk_655  hu.ro.eo_532 id.kl.un_650 
  0x101d5407, 0x233d44ee, 0x564902ee, 0x211b52ee,   // ik.la.lt_432 kk.ku.ky_422  da.to.mg_422 ha.tr.jw_422 
  0x15361512, 0x3424100c, 0x56003012, 0x1c475a60,   // un.ab.un_654 lt.eo.xh_543  uz.mg.un_640 sm.sn.id_664 
  0x602b55a4, 0x211f390c, 0x641002ad, 0x06120e04,   // rw.vi.vo_433 br.cy.jw_543  da.lt.lg_643 is.hu.de_332 
  // [13820]
  0x2a225a04, 0x37151107, 0x39732508, 0x48003512,   // sm.oc.mt_332 ro.ba.un_420  eu.ny.br_443 tg.tt.un_640 
  0x35553b05, 0x5e002505, 0x15041504, 0x480410a6,   // so.rw.zu_333 eu.ts.un_330  un.ru.un_332 be.ru.tt_521 
  0x42791b55, 0x112801a0, 0x095539a0, 0x394751a4,   // tr.war.co_442 en.sw.ro_322  br.rw.pl_322 kl.sn.br_433 
  0x372348a7, 0x102511ad, 0x03020c04, 0x183c44af,   // tt.ky.ba_532 ro.mn.be_643  sv.da.nl_332 kk.ug.ar_655 
  // [13830]
  0x12004d11, 0x482308a0, 0x4d000b0e, 0x0d1827a0,   // aa.hu.un_630 uk.ky.tt_322  es.aa.un_550 gd.ga.cs_322 
  0xfe2f2208, 0xfe3040ad, 0x35171002, 0x06002008,   // oc.su.tlh_443 lb.uz.tlh_643  be.sr.tg_222 sq.de.un_430 
  0x20003e02, 0x63653ba9, 0x1f60fea4, 0x060c2010,   // rm.sq.un_220 so.gv.sco_544  tlh.vo.cy_433 sq.sv.de_642 
  0x03382d0c, 0x1507230c, 0x29fe27ad, 0x1d602c08,   // sk.tk.nl_543 ca.it.un_543  gd.tlh.sl_643 fy.vo.la_443 
  // [13840]
  0x15171007, 0x21000a0d, 0x393815a4, 0xfe1b310c,   // be.sr.un_432 pt.jw.un_540  un.tk.br_433 az.tr.tlh_543 
  0x76001c04, 0x170a360b, 0x202122a7, 0x2917fea9,   // id.crs.un_320 ab.mk.sr_542  oc.jw.sq_532 tlh.sr.sl_544 
  0x0c000611, 0x530c20b4, 0x6005010b, 0x4f002c23,   // de.sv.un_630 sq.sv.ht_754  en.fr.vo_542 fy.bi.un_880 
  0x20192fa4, 0x231828ee, 0x532223ec, 0x1f122fa0,   // su.gl.sq_433 sd.ar.ky_422  ca.oc.ht_644 su.hu.cy_322 
  // [13850]
  0x12002211, 0x041535a4, 0x0e002f05, 0x40052204,   // oc.hu.un_630 tg.ru.un_430  su.is.un_330 oc.fr.lb_332 
  0x0a173c12, 0x49000f11, 0x04361508, 0x3f282fee,   // ug.sr.mk_654 lv.to.un_630  un.ab.ru_443 su.sw.af_422 
  0x2f005a14, 0x584728a0, 0x3c38300e, 0x3b5104af,   // sm.su.un_660 sw.sn.om_322  uz.tk.ug_555 fi.kl.so_655 
  0x3f2b27a7, 0x1a466a08, 0x58001302, 0x230b19a0,   // gd.vi.af_532 haw.qu.tl_443  et.om.un_220 gl.es.ca_322 
  // [13860]
  0x4c002f07, 0x04005805, 0x4d3b640d, 0x16296aad,   // su.wo.un_420 om.fi.un_330  lg.so.aa_554 haw.sl.hr_643 
  0x0b2e19a4, 0x78002f13, 0x1d002f05, 0x0b1936ee,   // gl.fo.es_433 su.ve.un_650  su.la.un_330 gn.gl.es_422 
  0x3b13640b, 0x11393f0b, 0x583b1aa9, 0x271f2f12,   // lg.et.so_542 af.br.ro_542  tl.so.om_544 su.cy.gd_654 
  0x3b1e110c, 0x204207a4, 0x11005205, 0x283078a4,   // ro.ms.so_543 it.co.sq_433  ha.ro.un_330 ve.uz.sw_433 
  // [13870]
  0x28005223, 0x0c3224ad, 0x30205202, 0x5d4d50ec,   // ha.sw.un_880 eo.bs.sv_643  ha.sq.uz_222 fj.aa.ss_644 
  0x1c002105, 0x38301514, 0x45390511, 0x392511a6,   // jw.id.un_330 un.uz.tk_666  fr.br.ln_653 ro.eu.br_521 
  0x58006405, 0x42431dad, 0x190a365a, 0x012f28a4,   // lg.om.un_330 la.ie.co_643  gn.pt.gl_553 sw.su.en_433 
  0x1162520c, 0x5864510c, 0x111f2f07, 0x2d190b08,   // ha.kha.ro_543 kl.lg.om_543  su.cy.ro_432 es.gl.sk_443 
  // [13880]
  0x12184a05, 0x02641355, 0x503b3007, 0x07321605,   // yo.ga.hu_333 et.lg.da_442  uz.so.fj_432 hr.bs.it_333 
  0xfe005235, 0x205e50a9, 0x0b1936ec, 0x12182d55,   // ha.tlh.un_A90 fj.ts.sq_544  gn.gl.es_644 sk.ga.hu_442 
  0x1d6b1dad, 0x2d4a1208, 0x4a002d21, 0x68495c07,   // la.ceb.la_643 hu.yo.sk_443  sk.yo.un_860 sa.to.ig_432 
  0x20002713, 0x36002205, 0x3c004411, 0x225c0aa4,   // gd.sq.un_650 oc.gn.un_330  kk.ug.un_630 pt.sa.oc_433 
  // [13890]
  0x595535a4, 0x2765fead, 0x35005d1b, 0x18220ea0,   // zu.rw.rn_433 tlh.gv.gd_643  ss.zu.un_770 is.oc.ga_322 
  0x0d3b2da7, 0x22230aa0, 0x12283008, 0x0f6b10a0,   // sk.so.cs_532 pt.ca.oc_322  uz.sd.ur_443 lt.ceb.lv_322 
  0x232236ac, 0x364a2d05, 0x0a2d0d11, 0x1a182711,   // gn.oc.ca_632 sk.yo.gn_333  cs.sk.pt_653 gd.ga.tl_653 
  0x12182d0c, 0x2d1218ad, 0x354844a9, 0x20003021,   // sk.ga.hu_543 ga.hu.sk_643  kk.tt.tg_544 uz.sq.un_860 
  // [138a0]
  0x0b1812ee, 0x5b006219, 0x22005608, 0x23361207,   // hu.ga.es_422 kha.sg.un_750  mg.oc.un_430 hu.gn.ca_432 
  0x0e0b2e07, 0x0e4d1807, 0x56222307, 0x0b1922a4,   // fo.es.is_432 ga.aa.is_432  ca.oc.mg_432 oc.gl.es_433 
  0x5e002f13, 0x1f002002, 0x2e190b5a, 0x0d1c1313,   // su.ts.un_650 sq.cy.un_220  es.gl.fo_553 bh.mr.ne_665 
  0xfc091f08, 0x1f080208, 0x0100650d, 0x2e0b12a9,   // cy.pl.zzp_443 da.no.cy_443  gv.en.un_540 hu.es.fo_544 
  // [138b0]
  0x33001f07, 0x190b18af, 0x0b192e0c, 0x0410380d,   // cy.nn.un_420 ga.es.gl_655  fo.gl.es_543 tk.be.ru_554 
  0x1f653fee, 0x2e003618, 0x192d0d0c, 0x1c1e0207,   // af.gv.cy_422 gn.fo.un_740  cs.sk.gl_543 da.ms.id_432 
  0x1f653f08, 0x021c61ee, 0x020c1c05, 0x48312e05,   // af.gv.cy_443 za.id.da_422  id.sv.da_333 fo.az.tt_333 
  0x06316105, 0x38000a07, 0x36511304, 0x121836ac,   // za.az.de_333 pt.tk.un_420  et.kl.gn_332 gn.ga.hu_632 
  // [138c0]
  0x11000e13, 0x475451a4, 0x24225807, 0x6bfc15ee,   // is.ro.un_650 kl.ik.sn_433  om.oc.eo_432 un.zzp.ceb_422 
  0x4b0c06a0, 0x38004605, 0x1d264da4, 0x0f101107,   // de.sv.mi_322 qu.tk.un_330  aa.ia.la_433 ro.lt.lv_432 
  0x0b000505, 0x42111da0, 0x443b3d05, 0x041735ee,   // fr.es.un_330 la.ro.co_322  ku.ks.kk_333 tg.sr.ru_422 
  0x2c002302, 0x53005710, 0x183d3c0b, 0x4400280e,   // ca.fy.un_220 na.ht.un_620  ug.ku.ar_542 sd.kk.un_550 
  // [138d0]
  0x233048a9, 0x362f0e04, 0x2e0c0e14, 0x504f1ea4,   // tt.uz.ky_544 is.su.gn_332  is.sv.fo_666 ms.bi.fj_433 
  0x0e00360d, 0x231744a0, 0x0407100c, 0x47501c07,   // gn.is.un_540 kk.sr.ky_322  be.bg.ru_543 id.fj.sn_432 
  0x5d003523, 0x573560ad, 0x4c2e5904, 0x02584d12,   // zu.ss.un_880 vo.zu.na_643  rn.fo.wo_332 aa.om.da_654 
  0x5d643508, 0x26430107, 0x68004a12, 0x552d5d08,   // zu.lg.ss_443 en.ie.ia_432  yo.ig.un_640 ss.sk.rw_443 
  // [138e0]
  0x3537150d, 0x0e004012, 0x47005c05, 0x55645008,   // un.ba.tg_554 lb.is.un_640  sa.sn.un_330 fj.lg.rw_443 
  0x2f545160, 0x300a17a6, 0x33000e12, 0x50646b0c,   // kl.ik.su_664 sr.mk.uz_521  is.nn.un_640 ceb.lg.fj_543 
  0x0912510c, 0x476b1a07, 0x314d35a4, 0x03002a02,   // kl.hu.pl_543 tl.ceb.sn_432  zu.aa.az_433 mt.nl.un_220 
  0x09006111, 0x11532512, 0x1e1c2eee, 0x311b2e07,   // za.pl.un_630 eu.ht.ro_654  fo.id.ms_422 fo.tr.az_432 
  // [138f0]
  0x22000c04, 0x03001d09, 0x08020c09, 0x02090ca0,   // sv.oc.un_320 la.nl.un_440  sv.da.no_444 sv.pl.da_322 
  0x511e2f0d, 0x34fc35ee, 0x12fc0202, 0x30024804,   // su.ms.kl_554 zu.zzp.xh_422  da.zzp.hu_222 tt.da.uz_332 
  0x100835a9, 0xfc000f14, 0x25151107, 0x33002e12,   // tg.uk.be_544 lv.zzp.un_660  ro.mn.un_420 fo.nn.un_640 
  0x02fc0e07, 0x194d600c, 0x0e00fc11, 0x312f50ad,   // is.zzp.da_432 vo.aa.gl_543  zzp.is.un_630 fj.su.az_643 
  // [13900]
  0x372548a4, 0x0900132b, 0x42001d19, 0x38031b12,   // tt.mn.ba_433 bh.hi.un_980  la.co.un_750 tr.nl.tk_654 
  0x2e31090d, 0x25003c04, 0x240b23a4, 0x29190b5a,   // pl.az.fo_554 ug.mn.un_320  ca.es.eo_433 es.gl.sl_553 
  0x18000a02, 0x0e1822a0, 0x21541c04, 0x0e2e18a7,   // pt.ga.un_220 oc.ga.is_322  id.ik.jw_332 ga.fo.is_532 
  0x08003904, 0x29164fa4, 0x53002e07, 0x2e020ea4,   // br.no.un_320 bi.hr.sl_433  fo.ht.un_420 is.da.fo_433 
  // [13910]
  0x35150fa0, 0x23fe3b0c, 0x330e2e08, 0x05420707,   // lv.zu.un_320 so.tlh.ca_543  fo.is.nn_443 it.co.fr_432 
  0x5c023904, 0x02002218, 0x32002407, 0x6a040ea4,   // br.da.sa_332 oc.da.un_740  eo.bs.un_420 is.fi.haw_433 
  0x496a500c, 0x1242075a, 0x48041002, 0x18303c0c,   // fj.haw.to_543 it.co.hu_553  be.ru.tt_222 ug.uz.ar_543 
  0x06024602, 0x0f797307, 0x3b00790e, 0x10602e07,   // qu.da.de_222 ny.war.lv_432  war.so.un_550 fo.vo.lt_432 
  // [13920]
  0x321709af, 0x02003b07, 0x151b3860, 0x63062c04,   // pl.sr.bs_655 so.da.un_420  tk.tr.un_664 fy.de.sco_332 
  0x240413a4, 0x502552af, 0x23183c5a, 0x020e2e0c,   // et.fi.eo_433 ha.eu.fj_655  ug.ar.ky_553 fo.is.da_543 
  0x07041505, 0x330e100c, 0x070815a0, 0x52007307,   // un.ru.bg_333 lt.is.nn_543  un.uk.bg_322 ny.ha.un_420 
  0x04104bad, 0x0f2f52ad, 0x10406a12, 0x08006b07,   // mi.lt.fi_643 ha.su.lv_643  haw.lb.lt_654 ceb.no.un_420 
  // [13930]
  0x7300631b, 0x0f49500c, 0x2c002b02, 0x5e02515a,   // sco.ny.un_770 fj.to.lv_543  vi.fy.un_220 kl.da.ts_553 
  0x081044ec, 0x4d005108, 0x1d58510d, 0x33084ea4,   // kk.be.uk_644 kl.aa.un_430  kl.om.la_554 ay.no.nn_433 
  0x32160502, 0x180e2cee, 0x16003007, 0x08422211,   // fr.hr.bs_222 fy.is.ga_422  uz.hr.un_420 oc.co.no_653 
  0x04103812, 0x37353004, 0x28123b08, 0x251511a0,   // tk.be.ru_654 uz.tg.ba_332  ks.ur.sd_443 ro.mn.un_320 
  // [13940]
  0x0d004004, 0x75005f21, 0x05001805, 0x0a354407,   // lb.cs.un_320 tn.nso.un_860  ga.fr.un_330 kk.tg.mk_432 
  0x375f7512, 0x30152309, 0x38005f0e, 0x23480708,   // nso.tn.st_654 ky.uz.un_440  tn.tk.un_550 bg.tt.ky_443 
  0x28002402, 0x0b253604, 0x050e2e08, 0x080a10a0,   // eo.sw.un_220 gn.eu.es_332  fo.is.fr_443 be.mk.uk_322 
  0x234804ad, 0x37481512, 0x5c0523a0, 0x0900020b,   // ru.tt.ky_643 un.tt.ba_654  ca.fr.sa_322 da.pl.un_520 
  // [13950]
  0x151dfc0c, 0x0d000209, 0x2d2b0d13, 0x304837a4,   // zzp.la.un_543 da.cs.un_440  cs.vi.sk_665 ba.tt.uz_433 
  0x1b524d07, 0x37003809, 0x08303c14, 0x370a48ec,   // aa.ha.tr_432 tk.st.un_440  ug.uz.uk_666 tt.mk.ba_644 
  0x2c01fcee, 0x64544d0c, 0x15110704, 0x4a2f7302,   // zzp.en.fy_422 aa.ik.lg_543  bg.ro.un_332 ny.su.yo_222 
  0x6500fc19, 0x6500fc04, 0x1a381b07, 0x10173555,   // zzp.gv.un_750 zzp.gv.un_320  tr.tk.tl_432 tg.sr.be_442 
  // [13960]
  0x080238a0, 0x2f6a1ca9, 0x3b1d4da4, 0x19180b12,   // tk.da.no_322 id.haw.su_544  aa.la.so_433 es.ga.gl_654 
  0x4c0258a4, 0x584c5c0c, 0xfe00512a, 0x2100540c,   // om.da.wo_433 sa.wo.om_543  kl.tlh.un_970 ik.jw.un_530 
  0x0f4b110b, 0x633b4009, 0x04004b08, 0x3b5860ec,   // ro.mi.lv_542 lb.so.sco_444  mi.fi.un_430 vo.om.so_644 
  0x1e002112, 0x30006307, 0x192223a9, 0x2f361e11,   // jw.ms.un_640 sco.uz.un_420  ca.oc.gl_544 ms.gn.su_653 
  // [13970]
  0x1d00fc0b, 0x4c073e12, 0x092322a7, 0x685f37ec,   // zzp.la.un_520 rm.it.wo_654  oc.ca.pl_532 st.tn.ig_644 
  0x2f206a55, 0x786a100c, 0x03000d08, 0x06283007,   // haw.sq.su_442 lt.haw.ve_543  cs.nl.un_430 uz.sw.de_432 
  0x69484c5a, 0x30313b12, 0x480576a9, 0x5139fe05,   // wo.tt.mfe_553 so.az.uz_654  crs.fr.tt_544 tlh.br.kl_333 
  0x532a3fad, 0x39003502, 0x30002a0c, 0x343012a9,   // af.mt.ht_643 zu.br.un_220  mt.uz.un_530 ur.uz.ps_544 
  // [13980]
  0x103e22a9, 0x07100809, 0x1f4e58ad, 0x293216a7,   // oc.rm.lt_544 uk.be.bg_444  om.ay.cy_643 hr.bs.sl_532 
  0x2a003313, 0x39003e07, 0x177901a4, 0x21001c08,   // nn.mt.un_650 rm.br.un_420  en.war.sr_433 id.jw.un_430 
  0x1d4b2107, 0x35170a05, 0x4b4768ad, 0x2c001d04,   // jw.mi.la_432 mk.sr.tg_333  ig.sn.mi_643 la.fy.un_320 
  0x1e003f0c, 0x2e5d0e0c, 0x2b000408, 0x1b001007,   // af.ms.un_530 is.ss.fo_543  fi.vi.un_430 lt.tr.un_420 
  // [13990]
  0x483710a9, 0x01fc2407, 0x081504ec, 0x48372355,   // be.ba.tt_544 eo.zzp.en_432  ru.uk.un_640 ky.ba.tt_442 
  0x045a1f0c, 0x1023360c, 0x0e060ca0, 0x30fe31ac,   // cy.sm.fi_543 ab.ky.be_543  sv.de.is_322 az.tlh.uz_632 
  0x15173cee, 0x30203405, 0x69002508, 0x121830a9,   // ug.sr.un_422 xh.sq.uz_333  eu.mfe.un_430 uz.ar.ur_544 
  0x53002523, 0x40000a09, 0x5c004a04, 0x20001704,   // eu.ht.un_880 pt.lb.un_440  yo.sa.un_320 sr.sq.un_320 
  // [139a0]
  0x3b313004, 0x060c0e0c, 0x37080412, 0x23000e08,   // uz.az.so_332 is.sv.de_543  ru.uk.ba_654 is.ca.un_430 
  0x125d45a7, 0x3c003005, 0x4418340c, 0x34213cee,   // ln.ss.hu_532 uz.ug.un_330  ps.ar.kk_543 ug.fa.ps_422 
  0x1900180c, 0x070a23af, 0x48152309, 0x44353ca0,   // ga.gl.un_530 ky.mk.bg_655  ky.tt.un_440 ug.tg.kk_322 
  0x394227a0, 0x3c302313, 0x4a004511, 0x0a3c1705,   // gd.co.br_322 ky.uz.ug_665  ln.yo.un_630 sr.ug.mk_333 
  // [139b0]
  0x0700422c, 0x103035af, 0x45002107, 0x5935345a,   // co.it.un_990 tg.uz.be_655  jw.ln.un_420 xh.zu.rn_553 
  0x323564ac, 0xfe000f05, 0x64002a04, 0x3f300404,   // lg.zu.bs_632 lv.tlh.un_330  mt.lg.un_320 fi.uz.af_332 
  0x24041aaf, 0x04211308, 0x04001b07, 0x33081ca4,   // tl.fi.eo_655 et.jw.fi_443  tr.fi.un_420 id.no.nn_433 
  0x20005302, 0x1d005304, 0x10350804, 0x112536a4,   // ht.sq.un_220 ht.la.un_320  uk.tg.be_332 ab.mn.ro_433 
  // [139c0]
  0x3c34300c, 0x34595509, 0x06005107, 0x0c0413ee,   // uz.ps.ug_543 rw.rn.xh_444  kl.de.un_420 et.fi.sv_422 
  0x511304ee, 0x5a003902, 0x24022902, 0x5879630d,   // fi.et.kl_422 br.sm.un_220  sl.da.eo_222 sco.war.om_554 
  0x2900060c, 0x073e4209, 0x7954020e, 0x766053a4,   // de.sl.un_530 co.rm.it_444  da.ik.war_555 ht.vo.crs_433 
  0x0200601a, 0x1a003f0c, 0x430701a0, 0x3bfe46ad,   // vo.da.un_760 af.tl.un_530  en.it.ie_322 qu.tlh.so_643 
  // [139d0]
  0x40063808, 0xfc182712, 0x4c000721, 0x4f1b7912,   // tk.de.lb_443 gd.ga.zzp_654  it.wo.un_860 war.tr.bi_654 
  0x34321704, 0x1f525c04, 0x1b3152a0, 0x0e00061b,   // sr.bs.xh_332 sa.ha.cy_332  ha.az.tr_322 de.is.un_770 
  0x06403fa4, 0x47344c07, 0x11000713, 0x3e33230c,   // af.lb.de_433 wo.xh.sn_432  bg.ro.un_650 ca.nn.rm_543 
  0x5300fe08, 0x24794aa4, 0x202e3ead, 0x3400fe07,   // tlh.ht.un_430 yo.war.eo_433  rm.fo.sq_643 tlh.xh.un_420 
  // [139e0]
  0x6b301a04, 0xfe30790c, 0x040715ac, 0x353704ee,   // tl.uz.ceb_332 war.uz.tlh_543  un.bg.ru_632 ru.ba.tg_422 
  0x081725a4, 0x37114411, 0x07100aa7, 0x231536a7,   // mn.sr.uk_433 kk.ro.ba_653  mk.be.bg_532 ab.ky.un_520 
  0x353015a7, 0x2f334aa0, 0x213b12a4, 0x1d002218,   // un.uz.tg_532 yo.nn.su_322  ur.ks.fa_433 oc.la.un_740 
  0x18283504, 0x400d0904, 0x083302a7, 0x1d000205,   // zu.sw.ga_332 pl.cs.lb_332  da.nn.no_532 da.la.un_330 
  // [139f0]
  0x11150fa0, 0x013718ee, 0x36442355, 0x462d19a0,   // lv.ro.un_320 ga.st.en_422  ky.kk.ab_442 gl.sk.qu_322 
  0x15001520, 0x15280e05, 0x233c1512, 0x15005307,   // un.un.un_850 is.sw.un_333  un.ug.ky_654 ht.un.un_420 
  0x15353004, 0x373c35a4, 0x1711150d, 0x361918af,   // uz.tg.un_332 tg.ug.ba_433  un.ro.sr_554 ga.gl.gn_655 
  0x32002f04, 0x2f004002, 0x09001320, 0x332e0e0c,   // su.bs.un_320 lb.su.un_220  bh.hi.un_850 is.fo.nn_543 
  // [13a00]
  0x2300481e, 0x44151112, 0x162909a9, 0x12282304,   // tt.ca.un_830 ro.kk.un_640  pl.sl.hr_544 ky.sd.ur_332 
  0x38301bad, 0xfe2a300e, 0x440a17ee, 0x555d59ad,   // tr.uz.tk_643 uz.mt.tlh_555  sr.mk.kk_422 rn.ss.rw_643 
  0x46423e55, 0x1e003904, 0x4f2f0f0c, 0x1620100c,   // rm.co.qu_442 br.ms.un_320  lv.su.bi_543 lt.sq.hr_543 
  0x495a7807, 0x6a5a49a4, 0x0717360c, 0x13475e11,   // ve.sm.to_432 to.sm.haw_433  ab.sr.bg_543 ts.sn.et_653 
  // [13a10]
  0x05260d07, 0x29005308, 0x2f005502, 0x6a5f500c,   // cs.ia.fr_432 ht.sl.un_430  rw.su.un_220 fj.tn.haw_543 
  0x120b0a02, 0x0a041107, 0x2801150c, 0x0d2e12a6,   // pt.es.hu_222 ro.ru.mk_432  un.en.sw_543 hu.fo.cs_521 
  0x73105404, 0x73002e0c, 0x17233505, 0x4dfe2a12,   // ik.lt.ny_332 fo.ny.un_530  tg.ky.sr_333 mt.tlh.aa_654 
  0x384813a6, 0x11487355, 0x3b002f07, 0x02001107,   // et.tt.tk_521 ny.tt.ro_442  su.so.un_420 ro.da.un_420 
  // [13a20]
  0x0a6b79a0, 0x23192209, 0x30060c0c, 0x3800121a,   // war.ceb.pt_322 oc.gl.ca_444  sv.de.uz_543 hu.tk.un_760 
  0x1c621ea4, 0x2b002707, 0x21052eee, 0x293912ad,   // ms.kha.id_433 gd.vi.un_420  fo.fr.jw_422 hu.br.sl_643 
  0x44080407, 0x11170a13, 0x250710a0, 0x09002907,   // ru.uk.kk_432 mk.sr.ro_665  be.bg.mn_322 sl.pl.un_420 
  0x4410230d, 0x174408a0, 0x2c001d02, 0x5c494b5a,   // ky.be.kk_554 uk.kk.sr_322  la.fy.un_220 mi.to.sa_553 
  // [13a30]
  0x0f5c4ba0, 0x3f332ca0, 0x3940350b, 0x303d23a7,   // mi.sa.lv_322 fy.nn.af_322  zu.lb.br_542 ky.ku.uz_532 
  0x104808ad, 0x01006313, 0x44233805, 0x0a2e12ad,   // uk.tt.be_643 sco.en.un_650  tk.ky.kk_333 hu.fo.pt_643 
  0x2a005013, 0x50004608, 0x3400460c, 0x6500fc02,   // fj.mt.un_650 qu.fj.un_430  qu.xh.un_530 zzp.gv.un_220 
  0x1b061213, 0x36353408, 0x31004605, 0x233744ee,   // hu.de.tr_665 xh.zu.gn_443  qu.az.un_330 kk.ba.ky_422 
  // [13a40]
  0x28002c07, 0x40000102, 0x030e3f02, 0x090d1c5a,   // fy.sw.un_420 en.lb.un_220  af.is.nl_222 mr.ne.hi_553 
  0x38153008, 0x3d182105, 0x1c003407, 0x40003405,   // uz.tk.un_430 fa.ar.ku_333  xh.id.un_420 xh.lb.un_330 
  0x35043004, 0x0f002911, 0x6b4f5804, 0x641d2704,   // uz.ru.tg_332 sl.lv.un_630  om.bi.ceb_332 gd.la.lg_332 
  0x1b004d0c, 0x3748350c, 0x1b001e05, 0x1a6b7913,   // aa.tr.un_530 tg.tt.ba_543  ms.tr.un_330 war.ceb.tl_665 
  // [13a50]
  0x42643bec, 0x4200641a, 0x054c12a0, 0x15484dad,   // so.lg.co_644 lg.co.un_760  hu.wo.fr_322 aa.tt.un_643 
  0x38372308, 0x254d0107, 0x503f6402, 0x2f3f3ba0,   // ky.ba.tk_443 en.aa.eu_432  lg.af.fj_222 so.af.su_322 
  0x2a092d0c, 0x1b562d0b, 0x1a796b09, 0x1d785e0c,   // sk.pl.mt_543 sk.mg.tr_542  ceb.war.tl_444 ts.ve.la_543 
  0x182344ec, 0x1b382d0c, 0x20470da4, 0x2c1d0107,   // kk.ky.ar_644 sk.tk.tr_543  cs.sn.sq_433 en.la.fy_432 
  // [13a60]
  0x57001f09, 0x46761b09, 0x291759ad, 0x49005807,   // cy.na.un_440 tr.crs.qu_444  rn.sr.sl_643 om.to.un_420 
  0x4c215eee, 0x731f2108, 0x1b00312c, 0x28381b07,   // ts.jw.wo_422 jw.cy.ny_443  az.tr.un_990 tr.tk.sw_432 
  0x250b19ee, 0x205e2a0c, 0x1a5c02ee, 0x28001019,   // gl.es.eu_422 mt.ts.sq_543  da.sa.tl_422 lt.sw.un_750 
  0x0800300b, 0x103748a4, 0x38244255, 0x07003512,   // uz.uk.un_520 tt.ba.be_433  co.eo.tk_442 tg.bg.un_640 
  // [13a70]
  0x08101708, 0x21443ca4, 0x182b1aa0, 0x2844180d,   // sr.be.uk_443 ug.kk.fa_433  tl.vi.ga_322 ar.kk.sd_554 
  0x10003708, 0x21000d0c, 0x0a001520, 0x35000905,   // ba.be.un_430 cs.jw.un_530  un.mk.un_850 pl.zu.un_330 
  0x5c091c5a, 0x332e0811, 0x46002a0d, 0x09110fad,   // mr.hi.sa_553 no.fo.nn_653  mt.qu.un_540 lv.ro.pl_643 
  0x29000f18, 0x461e4804, 0x35005711, 0x46005107,   // lv.sl.un_740 tt.ms.qu_332  na.zu.un_630 kl.qu.un_420 
  // [13a80]
  0x03001e02, 0x73676104, 0x0a071755, 0x080c0fa4,   // ms.nl.un_220 za.ak.ny_332  sr.bg.mk_442 lv.sv.no_433 
  0x26003304, 0xfc366214, 0x4e00031a, 0x252a07a4,   // nn.ia.un_320 kha.gn.zzp_666  nl.ay.un_760 it.mt.eu_433 
  0x382d0d11, 0x0d4006a0, 0x1b002a1a, 0x28122511,   // cs.sk.tk_653 de.lb.cs_322  mt.tr.un_760 eu.hu.sw_653 
  0x5c0d09af, 0x2a002d12, 0x382d0d55, 0x10005202,   // hi.ne.sa_655 sk.mt.un_640  cs.sk.tk_442 ha.lt.un_220 
  // [13a90]
  0x08002e05, 0x103508ee, 0x13595555, 0x6263430c,   // fo.no.un_330 uk.tg.be_422  rw.rn.et_442 ie.sco.kha_543 
  0x0361fe13, 0x20080caf, 0x042afc04, 0x10002014,   // tlh.za.nl_665 sv.no.sq_655  zzp.mt.fi_332 sq.lt.un_660 
  0x073515a0, 0x3b21340c, 0x3f4063a0, 0x330e0804,   // un.tg.bg_322 ps.fa.ks_543  sco.lb.af_322 no.is.nn_332 
  0x0300fe13, 0x173544a4, 0x190b46a4, 0x442523a0,   // tlh.nl.un_650 kk.tg.sr_433  qu.es.gl_433 ky.mn.kk_322 
  // [13aa0]
  0x4800060c, 0x17100808, 0x04304402, 0x01007304,   // de.tt.un_530 uk.be.sr_443  kk.uz.ru_222 ny.en.un_320 
  0x030615a0, 0x38000e04, 0x1b002d02, 0x0c00400e,   // un.de.nl_322 is.tk.un_320  sk.tr.un_220 lb.sv.un_550 
  0x48002a0d, 0x3148380c, 0x3744480b, 0x00004237,   // mt.tt.un_540 tk.tt.az_543  tt.kk.ba_542 co.un.un_B00 
  0x4a005322, 0x534a42ec, 0x1b2538a9, 0x4a00532c,   // ht.yo.un_870 co.yo.ht_644  tk.eu.tr_544 ht.yo.un_990 
  // [13ab0]
  0x072b420c, 0x4d00620e, 0x0c002f02, 0x2b424a13,   // co.vi.it_543 kha.aa.un_550  su.sv.un_220 yo.co.vi_665 
  0x17001612, 0x04081055, 0x1e4c4d0b, 0x53004a1a,   // hr.sr.un_640 be.uk.ru_442  aa.wo.ms_542 yo.ht.un_760 
  0x37304805, 0x04303555, 0x53004a19, 0x17040aec,   // tt.uz.ba_333 tg.uz.ru_442  yo.ht.un_750 mk.ru.sr_644 
  0x53424a12, 0x534a4260, 0x4a00532a, 0x400e06ee,   // yo.co.ht_654 co.yo.ht_664  ht.yo.un_970 de.is.lb_422 
  // [13ac0]
  0x42534a13, 0x38211b07, 0x01211da0, 0x2f000c02,   // yo.ht.co_665 tr.jw.tk_432  la.jw.en_322 sv.su.un_220 
  0x1e001602, 0x33091da0, 0x530507a0, 0x79090d0d,   // hr.ms.un_220 la.pl.nn_322  it.fr.ht_322 cs.pl.war_554 
  0x2b004605, 0x29001804, 0x2d0d0f02, 0x10162907,   // qu.vi.un_330 ga.sl.un_320  lv.cs.sk_222 sl.hr.lt_432 
  0x25002322, 0x19233309, 0x4c501d07, 0x44042502,   // ky.mn.un_870 nn.ca.gl_444  la.fj.wo_432 mn.ru.kk_222 
  // [13ad0]
  0x07001114, 0x083037a4, 0x0800230d, 0x353c38a4,   // ro.it.un_660 ba.uz.uk_433  ky.uk.un_540 tk.ug.tg_433 
  0x083715a0, 0x3d123055, 0x480411ac, 0x2d0d1807,   // un.ba.uk_322 uz.ur.ku_442  ro.ru.tt_632 ga.cs.sk_432 
  0x2b283ea9, 0x302420ee, 0x2a3b4607, 0x282b5f04,   // rm.sw.vi_544 sq.eo.uz_422  qu.so.mt_432 tn.vi.sw_332 
  0x75005f0e, 0x0a35170c, 0x2f00031a, 0x63002f22,   // tn.nso.un_550 sr.tg.mk_543  nl.su.un_760 su.sco.un_870 
  // [13ae0]
  0x2f00630c, 0x4c002f19, 0x0a123004, 0x4434280c,   // sco.su.un_530 su.wo.un_750  uz.hu.pt_332 sd.ps.kk_543 
  0x311c1aa0, 0x63004712, 0x10080a12, 0x0d131c07,   // tl.id.az_322 sn.sco.un_640  mk.uk.be_654 mr.bh.ne_432 
  0x15353708, 0x07001519, 0x3b492f07, 0x47004908,   // ba.tg.un_443 un.bg.un_750  su.to.so_432 to.sn.un_430 
  0x211c2fa0, 0x103f2c02, 0x0e001f0d, 0x1c004c04,   // su.id.jw_322 fy.af.lt_222  cy.is.un_540 wo.id.un_320 
  // [13af0]
  0x3900fe07, 0x013f5c07, 0x5f6875a9, 0x524959a7,   // tlh.br.un_420 sa.af.en_432  nso.ig.tn_544 rn.to.ha_532 
  0x2ffe5c07, 0x253b3907, 0x485209a4, 0x12000a22,   // sa.tlh.su_432 br.so.eu_432  pl.ha.tt_433 pt.hu.un_870 
  0x4d295f13, 0x1000301a, 0x28025a09, 0x755f1c07,   // tn.sl.aa_665 uz.be.un_760  sm.da.sw_444 id.tn.nso_432 
  0x75005f08, 0x022f250c, 0x55006504, 0x5c4c7307,   // tn.nso.un_430 eu.su.da_543  gv.rw.un_320 ny.wo.sa_432 
  // [13b00]
  0x3b001918, 0x13005c0e, 0x5a755f60, 0x0748370c,   // gl.so.un_740 sa.bh.un_550  tn.nso.sm_664 ba.tt.bg_543 
  0x755f500c, 0x025550a0, 0x12283bac, 0x28555004,   // fj.tn.nso_543 fj.rw.da_322  ks.sd.ur_632 fj.rw.sw_332 
  0x245ffea4, 0x163932a7, 0x0900730d, 0x21024da4,   // tlh.tn.eo_433 bs.br.hr_532  ny.pl.un_540 aa.da.jw_433 
  0x38311ba7, 0x30283b0c, 0x230a38a9, 0x3b000d02,   // tr.az.tk_532 ks.sd.uz_543  tk.mk.ky_544 cs.so.un_220 
  // [13b10]
  0x6559730c, 0x2311360c, 0x3f002c0c, 0x080213a0,   // ny.rn.gv_543 ab.ro.ky_543  fy.af.un_530 et.da.no_322 
  0x57fe54a9, 0x4c002f09, 0x58060e55, 0x3f2f750c,   // ik.tlh.na_544 su.wo.un_440  is.de.om_442 nso.su.af_543 
  0x10004909, 0x1b000808, 0x0a483011, 0x443623a0,   // to.lt.un_440 no.tr.un_430  uz.tt.mk_653 ky.ab.kk_322 
  0x44371013, 0x1500fc0c, 0x2b2f1c0c, 0x3e0c1807,   // be.ba.kk_665 zzp.un.un_530  id.su.vi_543 ga.sv.rm_432 
  // [13b20]
  0x23001023, 0x033f2fa9, 0x042c10a9, 0x3f0c390c,   // be.ky.un_880 su.af.nl_544  lt.fy.fi_544 br.sv.af_543 
  0x21283dec, 0x601e4cec, 0x234dfea4, 0xfe001d0c,   // ku.sd.fa_644 wo.ms.vo_644  tlh.aa.ca_433 la.tlh.un_530 
  0xfc001523, 0x041036a9, 0x6500072b, 0x53694f0c,   // un.zzp.un_880 ab.be.ru_544  it.gv.un_980 bi.mfe.ht_543 
  0x292311ac, 0x131c5c0e, 0x63581304, 0x303b58a7,   // ro.ca.sl_632 sa.mr.bh_555  et.om.sco_332 om.so.uz_532 
  // [13b30]
  0x0c121f12, 0x29536907, 0x62001521, 0x3217100b,   // cy.hu.sv_654 mfe.ht.sl_432  un.kha.un_860 lt.sr.bs_542 
  0x0e1d6512, 0x393f03ec, 0x24001016, 0x24002907,   // gv.la.is_654 nl.af.br_644  lt.eo.un_720 sl.eo.un_420 
  0x040a07af, 0x3c363009, 0x21303411, 0x65001022,   // bg.mk.ru_655 uz.ab.ug_444  ps.uz.fa_653 lt.gv.un_870 
  0x15000821, 0x65001008, 0x38444805, 0x113615af,   // uk.un.un_860 lt.gv.un_430  tt.kk.tk_333 un.ab.ro_655 
  // [13b40]
  0x0e003f05, 0x13001e02, 0x061065ad, 0x59554ba0,   // af.is.un_330 ms.et.un_220  gv.lt.de_643 mi.rw.rn_322 
  0x106504af, 0x1a002904, 0x3b213d0c, 0x0c005c02,   // fi.gv.lt_655 sl.tl.un_320  ku.fa.ks_543 sa.sv.un_220 
  0x303148a4, 0x2b380402, 0x5e2f0eee, 0x2d2f79ee,   // tt.az.uz_433 fi.tk.vi_222  is.su.ts_422 war.su.sk_422 
  0xfe002a2b, 0x16321713, 0x2d460d04, 0x303148af,   // mt.tlh.un_980 sr.bs.hr_665  cs.qu.sk_332 tt.az.uz_655 
  // [13b50]
  0x422959a0, 0x584afe0d, 0x09202a04, 0x3e110707,   // rn.sl.co_322 tlh.yo.om_554  mt.sq.pl_332 it.ro.rm_432 
  0x04070813, 0x202a73a7, 0x2a2d0d55, 0x30600ea4,   // uk.bg.ru_665 ny.mt.sq_532  cs.sk.mt_442 is.vo.uz_433 
  0x0b0a11a0, 0x0e6b1d07, 0x190a2302, 0x11594205,   // ro.pt.es_322 la.ceb.is_432  ca.pt.gl_222 co.rn.ro_333 
  0x2000391a, 0x44003009, 0x192a0b07, 0x59007314,   // br.sq.un_760 uz.kk.un_440  es.mt.gl_432 ny.rn.un_660 
  // [13b60]
  0x211d5c04, 0x2e381f0c, 0x171507ec, 0x50001604,   // sa.la.jw_332 cy.tk.fo_543  bg.sr.un_640 hr.fj.un_320 
  0x0bfe4f04, 0x4f202805, 0x3c1834a7, 0x33001d02,   // bi.tlh.es_332 sw.sq.bi_333  ps.ar.ug_532 la.nn.un_220 
  0x330802b4, 0x1a3846ee, 0x796e465a, 0x0e0d12a4,   // da.no.nn_754 qu.tk.tl_422  qu.hmn.war_553 hu.cs.is_433 
  0x08101505, 0x7900460d, 0x1d4615a9, 0x1f006511,   // un.be.uk_333 qu.war.un_540  un.qu.la_544 gv.cy.un_630 
  // [13b70]
  0x03462107, 0x38484ea7, 0x0a081702, 0x040e6212,   // jw.qu.nl_432 ay.tt.tk_532  sr.uk.mk_222 kha.is.fi_654 
  0x38231509, 0x041738a6, 0x12282105, 0x04001f0d,   // un.ky.tk_444 tk.sr.ru_521  fa.sd.ur_333 cy.fi.un_540 
  0x0900290c, 0x3704440c, 0x13000c12, 0x3c234407,   // sl.pl.un_530 kk.ru.ba_543  sv.et.un_640 kk.ky.ug_432 
  0x12311b08, 0x0e001f11, 0x2200531b, 0x354755a0,   // tr.az.hu_443 cy.is.un_630  ht.oc.un_770 rw.sn.zu_322 
  // [13b80]
  0x4c025fa9, 0x4b006b0e, 0x4b3625ec, 0x64004505,   // tn.da.wo_544 ceb.mi.un_550  eu.gn.mi_644 ln.lg.un_330 
  0x110736a9, 0x28456407, 0x4735490c, 0x3700510d,   // ab.bg.ro_544 lg.ln.sw_432  to.zu.sn_543 kl.st.un_540 
  0x64255b07, 0x64573508, 0x08071107, 0x5e00781b,   // sg.eu.lg_432 zu.na.lg_443  ro.bg.uk_432 ve.ts.un_770 
  0x1d0725a7, 0x0e000a1e, 0x471b280c, 0x32004208,   // eu.it.la_532 pt.is.un_830  sw.tr.sn_543 co.bs.un_430 
  // [13b90]
  0x231d110c, 0x0e003f02, 0x0a002102, 0x5000420d,   // ro.la.ca_543 af.is.un_220  jw.pt.un_220 co.fj.un_540 
  0x0e2e4e12, 0x21005d12, 0x5c2d1ea0, 0x5c2202a4,   // ay.fo.is_654 ss.jw.un_640  ms.sk.sa_322 da.oc.sa_433 
  0x3748150d, 0x2500232a, 0x0e022e05, 0x0d000f05,   // un.tt.ba_554 ky.mn.un_970  fo.da.is_333 lv.cs.un_330 
  0x250a0713, 0x281830ee, 0x303610a0, 0x3d34300d,   // bg.mk.mn_665 uz.ar.sd_422  be.ab.uz_322 uz.ps.ku_554 
  // [13ba0]
  0x46001b02, 0x343d44a4, 0x304435ee, 0x0200082b,   // tr.qu.un_220 kk.ku.ps_433  tg.kk.uz_422 no.da.un_980 
  0x30fe5109, 0x55005202, 0x3800460b, 0x304846a4,   // kl.tlh.uz_444 ha.rw.un_220  qu.tk.un_520 qu.tt.uz_433 
  0x0a0737a0, 0x041110af, 0x18302307, 0x3b00180e,   // ba.bg.mk_322 be.ro.ru_655  ky.uz.ar_432 ar.ks.un_550 
  0x1827220e, 0x090118ec, 0x641a24a4, 0x150a25ee,   // oc.gd.ga_555 ar.iw.hi_644  eo.tl.lg_433 mn.mk.un_422 
  // [13bb0]
  0x101f2407, 0x3b2855af, 0x330e0c02, 0x59002413,   // eo.cy.lt_432 rw.sw.so_655  sv.is.nn_222 eo.rn.un_650 
  0x0b0a1ca0, 0x2e0d0e04, 0x24005502, 0x10002e09,   // id.pt.es_322 is.cs.fo_332  rw.eo.un_220 fo.lt.un_440 
  0x012740a7, 0xfc00041a, 0x1d6b1aee, 0x5d6b1dee,   // lb.gd.en_532 fi.zzp.un_760  tl.ceb.la_422 la.ceb.ss_422 
  0x07000412, 0x2c004602, 0x552864a4, 0x79072407,   // ru.bg.un_640 qu.fy.un_220  lg.sw.rw_433 eo.it.war_432 
  // [13bc0]
  0x240a19ad, 0xfc001d07, 0x190a240c, 0x64005f09,   // gl.pt.eo_643 la.zzp.un_420  eo.pt.gl_543 tn.lg.un_440 
  0x1024280c, 0x10002c05, 0x501015a0, 0x2f1c210b,   // sw.eo.lt_543 fy.lt.un_330  un.lt.fj_322 jw.id.su_542 
  0x361c2f02, 0x3f1039a4, 0x34213e07, 0x0d2a21a0,   // su.id.gn_222 br.lt.af_433  rm.jw.xh_432 jw.mt.cs_322 
  0x51472da4, 0x35473407, 0x30113505, 0x0e200dad,   // sk.sn.kl_433 xh.sn.zu_432  tg.ro.uz_333 cs.sq.is_643 
  // [13bd0]
  0x1dfc34ee, 0x30092da9, 0x5a006505, 0x285e47ec,   // xh.zzp.la_422 sk.pl.uz_544  gv.sm.un_330 sn.ts.sw_644 
  0x354823ac, 0x4c004d04, 0x581351ee, 0x0a001912,   // ky.tt.tg_632 aa.wo.un_320  kl.et.om_422 gl.pt.un_640 
  0x474e0912, 0x0950580e, 0x512158a9, 0x213412af,   // pl.ay.sn_654 om.fj.pl_555  om.jw.kl_544 ur.ps.fa_655 
  0x07002702, 0x101744a4, 0x1a792aa9, 0x02000702,   // gd.it.un_220 kk.sr.be_433  mt.war.tl_544 it.da.un_220 
  // [13be0]
  0x3018340b, 0x461a7907, 0x3b3421af, 0x04001502,   // ps.ar.uz_542 war.tl.qu_432  fa.ps.ks_655 un.fi.un_220 
  0x1915fca0, 0x6b1f55ee, 0x212f0208, 0x0708360c,   // zzp.gl.un_320 rw.cy.ceb_422  da.su.jw_443 ab.uk.bg_543 
  0x174c520c, 0x384423af, 0x69795aac, 0x57551a0c,   // ha.wo.sr_543 ky.kk.tk_655  sm.war.mfe_632 tl.rw.na_543 
  0x054250a0, 0x4d002523, 0x58605a08, 0x091629ac,   // fj.co.fr_322 eu.aa.un_880  sm.vo.om_443 sl.hr.pl_632 
  // [13bf0]
  0x574d1fa4, 0x603e1aa4, 0x18343d07, 0x571d28a4,   // cy.aa.na_433 tl.rm.vo_433  ku.ps.ar_432 sw.la.na_433 
  0x4d2c240d, 0x12283b55, 0x31521bee, 0x44233504,   // eo.fy.aa_554 ks.sd.ur_442  tr.ha.az_422 tg.ky.kk_332 
  0x0100fe07, 0x04132f04, 0xfe004d0c, 0x375e3008,   // tlh.en.un_420 su.et.fi_332  aa.tlh.un_530 uz.ts.st_443 
  0x021d11a6, 0x36004412, 0x2e004d14, 0x37003c09,   // ro.la.da_521 kk.ab.un_640  aa.fo.un_660 ug.ba.un_440 
  
  // [13c00]
  0x1d654f04, 0x48100408, 0x1836fca7, 0x6518fcad,   // bi.gv.la_332 ru.be.tt_443  zzp.gn.ga_532 zzp.ga.gv_643 
  0x2d007308, 0x3c2130a6, 0x1800fc22, 0x52003022,   // ny.sk.un_430 uz.fa.ug_521  zzp.ga.un_870 uz.ha.un_870 
  0x1d00fc13, 0x64004c22, 0x1c0b1807, 0x350408ee,   // zzp.la.un_650 wo.lg.un_870  ga.es.id_432 uk.ru.tg_422 
  0x3600fc02, 0x5e000c08, 0x35101112, 0x066a7913,   // zzp.gn.un_220 sv.ts.un_430  ro.be.tg_654 war.haw.de_665 
  // [13c10]
  0x38233c0c, 0x4630fe08, 0x021dfc08, 0x1502fca7,   // ug.ky.tk_543 tlh.uz.qu_443  zzp.la.da_443 zzp.da.un_532 
  0x3611fc0c, 0x52004c0c, 0x00003e2d, 0x330243a0,   // zzp.ro.gn_543 wo.ha.un_530  rm.un.un_A00 ie.da.nn_322 
  0x400635a0, 0x16005004, 0x302348ad, 0x04071504,   // zu.de.lb_322 fj.hr.un_320  tt.ky.uz_643 un.bg.ru_332 
  0x08482305, 0x343e06a7, 0x40002c02, 0x3e00430c,   // ky.tt.uk_333 de.rm.xh_532  fy.lb.un_220 ie.rm.un_530 
  // [13c20]
  0x39000602, 0x1f00150d, 0x0a04080b, 0x1d3f060d,   // de.br.un_220 un.cy.un_540  uk.ru.mk_542 de.af.la_554 
  0x07321608, 0x483715ec, 0x65733612, 0x21303104,   // hr.bs.it_443 un.ba.tt_644  gn.ny.gv_654 az.uz.jw_332 
  0x12342105, 0x0c20290c, 0x220a2311, 0x443711a0,   // fa.ps.ur_333 sl.sq.sv_543  ca.pt.oc_653 ro.ba.kk_322 
  0x090f2955, 0x30002702, 0x42fe6511, 0x10000411,   // sl.lv.pl_442 gd.uz.un_220  gv.tlh.co_653 ru.be.un_630 
  // [13c30]
  0x5c001804, 0xfe2601a0, 0x24420708, 0x0d001f08,   // ga.sa.un_320 en.ia.tlh_322  it.co.eo_443 cy.cs.un_430 
  0x421a68ec, 0x461b30ad, 0x79002b19, 0x4f002b19,   // ig.tl.co_644 uz.tr.qu_643  vi.war.un_750 vi.bi.un_750 
  0x5c004a17, 0x5c182802, 0x07654207, 0xfe001f0e,   // yo.sa.un_730 sw.ga.sa_222  co.gv.it_432 cy.tlh.un_550 
  0x42006813, 0x202e0e55, 0x2b001019, 0x38311104,   // ig.co.un_650 is.fo.sq_442  lt.vi.un_750 ro.az.tk_332 
  // [13c40]
  0x106b790b, 0x3515235a, 0x48303812, 0x35303702,   // war.ceb.lt_542 ky.tg.un_530  tk.uz.tt_654 ba.uz.tg_222 
  0x301535ad, 0x1708040b, 0x21234404, 0x1510230c,   // tg.uz.un_630 ru.uk.sr_542  kk.ky.fa_332 ky.be.un_543 
  0x363530af, 0x17002509, 0x07151704, 0x15000418,   // uz.tg.ab_655 mn.sr.un_440  sr.bg.un_320 ru.un.un_740 
  0x19002205, 0x695376ad, 0x2500fe11, 0x27533fa7,   // oc.gl.un_330 crs.ht.mfe_643  tlh.eu.un_630 af.ht.gd_532 
  // [13c50]
  0x15303c5a, 0xfe765308, 0x0723445a, 0x33791004,   // ug.uz.un_553 ht.crs.tlh_443  kk.ky.bg_553 lt.war.nn_332 
  0x764369af, 0x33100c0c, 0x02531b05, 0x4a0e2ea9,   // mfe.ie.crs_655 sv.lt.nn_543  tr.ht.da_333 fo.is.yo_544 
  0x532a4aa0, 0x53003808, 0x2555680b, 0x3e005305,   // yo.mt.ht_322 tk.ht.un_430  ig.rw.eu_542 ht.rm.un_330 
  0x0a3730ee, 0x08330c0d, 0x25000213, 0x39000b05,   // uz.ba.mk_422 sv.nn.no_554  da.eu.un_650 es.br.un_330 
  // [13c60]
  0x026b01a0, 0x35153102, 0x30023404, 0x13000e02,   // en.ceb.da_322 az.zu.un_220  xh.da.uz_332 is.et.un_220 
  0x6500210c, 0x79001009, 0x0410080b, 0x0e33100c,   // jw.gv.un_530 lt.war.un_440  uk.be.ru_542 lt.nn.is_543 
  0x070430a0, 0x232818a0, 0x241060ec, 0x44040704,   // uz.ru.bg_322 ar.sd.ky_322  vo.lt.eo_644 bg.ru.kk_332 
  0x22000e08, 0x55001802, 0x225c020c, 0x425c070b,   // is.oc.un_430 ga.rw.un_220  da.sa.oc_543 it.sa.co_542 
  // [13c70]
  0x5c003e11, 0x073642a4, 0x2ffe3007, 0x34183055,   // rm.sa.un_630 co.gn.it_433  uz.tlh.su_432 uz.ar.ps_442 
  0x420702a9, 0x4c0c1c02, 0x44353055, 0x425c0707,   // da.it.co_544 id.sv.wo_222  uz.tg.kk_442 it.sa.co_432 
  0x023e070e, 0x0c0e33a0, 0x0c065707, 0x1b004a0c,   // it.rm.da_555 nn.is.sv_322  na.de.sv_432 yo.tr.un_530 
  0x124f1a0c, 0x1a544e12, 0x2a5864af, 0x05330804,   // tl.bi.hu_543 ay.ik.tl_654  lg.om.mt_655 no.nn.fr_332 
  // [13c80]
  0x07052407, 0x1e1c79a9, 0x1000300d, 0x697957a4,   // eo.fr.it_432 war.id.ms_544  uz.be.un_540 na.war.mfe_433 
  0x42002b04, 0x115a0607, 0x02001704, 0x64002f02,   // vi.co.un_320 de.sm.ro_432  sr.da.un_320 su.lg.un_220 
  0x0c00480d, 0x64550207, 0x30001307, 0x073508a6,   // tt.sv.un_540 da.rw.lg_432  et.uz.un_420 uk.tg.bg_521 
  0x0400460b, 0x6100100e, 0x044d46ad, 0x212f28a4,   // qu.fi.un_520 lt.za.un_550  qu.aa.fi_643 sw.su.jw_433 
  // [13c90]
  0x151530ee, 0x04004607, 0x06510207, 0x525c0213,   // uz.un.un_420 qu.fi.un_420  da.kl.de_432 da.sa.ha_665 
  0x50003f05, 0x25115304, 0x48005c02, 0x3e006112,   // af.fj.un_330 ht.ro.eu_332  sa.tt.un_220 za.rm.un_640 
  0x17483cad, 0x341812ad, 0x603953af, 0x48003e0b,   // ug.tt.sr_643 ur.ar.ps_643  ht.br.vo_655 rm.tt.un_520 
  0x27002b0e, 0x072530a0, 0x25153812, 0x104817a0,   // vi.gd.un_550 uz.mn.bg_322  tk.mn.un_640 sr.tt.be_322 
  // [13ca0]
  0x040a1002, 0x1538440c, 0x35043cad, 0x15084408,   // be.mk.ru_222 kk.tk.un_543  ug.ru.tg_643 kk.uk.un_443 
  0x637327a9, 0x113035a9, 0xfe004708, 0x17001802,   // gd.ny.sco_544 tg.uz.ro_544  sn.tlh.un_430 ga.sr.un_220 
  0x5a001d04, 0x211e1c0e, 0xfc33080d, 0x320f1bad,   // la.sm.un_320 id.ms.jw_555  no.nn.zzp_554 tr.lv.bs_643 
  0x65004814, 0x3d343b04, 0x5d781e0c, 0x5e64730e,   // tt.gv.un_660 ks.ps.ku_332  ms.ve.ss_543 ny.lg.ts_555 
  // [13cb0]
  0x5e3742ec, 0x342a5ea7, 0x73495a13, 0x5164730d,   // co.st.ts_644 ts.mt.xh_532  sm.to.ny_665 ny.lg.kl_554 
  0x08151107, 0x6553690c, 0x31504508, 0x33000a04,   // ro.uk.un_420 mfe.ht.gv_543  ln.fj.az_443 pt.nn.un_320 
  0x5d004223, 0x3735340d, 0x2e1d1202, 0x4f4250ad,   // co.ss.un_880 xh.zu.st_554  hu.la.fo_222 fj.co.bi_643 
  0x211c1ea9, 0x31304ea9, 0x425e5dad, 0x33082eb3,   // ms.id.jw_544 ay.uz.az_544  ss.ts.co_643 fo.no.nn_743 
  // [13cc0]
  0x42001b12, 0x5a3550a4, 0x6a4942ad, 0x1f003905,   // tr.co.un_640 fj.zu.sm_433  co.to.haw_643 br.cy.un_330 
  0xfc000904, 0x1f34fc0c, 0x041011a6, 0x380c040b,   // pl.zzp.un_320 zzp.xh.cy_543  ro.be.ru_521 fi.sv.tk_542 
  0x10003f08, 0x1f2c3e07, 0x3544150c, 0x65002e04,   // af.lt.un_430 rm.fy.cy_432  un.kk.tg_543 fo.gv.un_320 
  0x0c57060e, 0x1f0c1009, 0x63fe1ba0, 0x06343fa7,   // de.na.sv_555 lt.sv.cy_444  tr.tlh.sco_322 af.xh.de_532 
  // [13cd0]
  0x20000508, 0x070d0207, 0x2e002f08, 0x0d003f04,   // fr.sq.un_430 da.cs.it_432  su.fo.un_430 af.cs.un_320 
  0x0f002418, 0x52000d08, 0x3f001f0d, 0x114201a4,   // eo.lv.un_740 cs.ha.un_430  cy.af.un_540 en.co.ro_433 
  0x0d005214, 0x4c005108, 0x090d050d, 0x4c005112,   // ha.cs.un_660 kl.wo.un_430  fr.cs.pl_554 kl.wo.un_640 
  0x1e002a04, 0x311b11ac, 0x3015380c, 0xfc5e34a0,   // mt.ms.un_320 ro.tr.az_632  tk.uz.un_530 xh.ts.zzp_322 
  // [13ce0]
  0x0d003808, 0x170a2502, 0x30002708, 0x0e003811,   // tk.cs.un_430 mn.mk.sr_222  gd.uz.un_430 tk.is.un_630 
  0x10002f04, 0x3c153812, 0x0a3038a7, 0x0c003905,   // su.lt.un_320 tk.ug.un_640  tk.uz.mk_532 br.sv.un_330 
  0x3c382313, 0x015e6304, 0x0a42050c, 0x35070a08,   // ky.tk.ug_665 sco.ts.en_332  fr.co.pt_543 mk.bg.tg_443 
  0x2a004c08, 0x302835a0, 0x443710ac, 0x30123d08,   // wo.mt.un_430 zu.sw.uz_322  be.ba.kk_632 ku.ur.uz_443 
  // [13cf0]
  0x041544a0, 0x180928ee, 0x2e00460e, 0x78007323,   // kk.ru.un_320 sw.pl.ga_422  qu.fo.un_550 ny.ve.un_880 
  0x250408a7, 0x2a005202, 0x46156b04, 0x2928020e,   // uk.ru.mn_532 ha.mt.un_220  ceb.qu.un_320 da.sw.sl_555 
  0x20004e07, 0x1100250c, 0x28005505, 0x320928a0,   // ay.sq.un_420 eu.ro.un_530  rw.sw.un_330 sw.pl.bs_322 
  0x46002e07, 0x12420604, 0x120609ec, 0x2f1b2155,   // fo.qu.un_420 de.co.hu_332  pl.de.hu_644 jw.tr.su_442 
  // [13d00]
  0x10170808, 0x3500102b, 0x37070405, 0x48231008,   // uk.sr.be_443 be.tg.un_980  ru.bg.ba_333 be.ky.tt_443 
  0x0700111b, 0x30443c0e, 0x2756220c, 0x28041710,   // ro.bg.un_770 ug.kk.uz_555  oc.mg.gd_543 sr.ru.sd_642 
  0x09000d2a, 0x317930a0, 0x3f000d04, 0x0c333705,   // ne.hi.un_970 uz.war.az_322  cs.af.un_320 st.nn.sv_333 
  0x42185cee, 0xfc025c07, 0xfc425207, 0x075c42ad,   // sa.ga.co_422 sa.da.zzp_432  ha.co.zzp_432 co.sa.it_643 
  // [13d10]
  0x075c42ee, 0x292dfe0b, 0x42002a0d, 0x31243004,   // co.sa.it_422 tlh.sk.sl_542  mt.co.un_540 uz.eo.az_332 
  0x421d5c04, 0x5376460c, 0x62fe5c0c, 0x53004f34,   // sa.la.co_332 qu.crs.ht_543  sa.tlh.kha_543 bi.ht.un_A80 
  0x1a006b13, 0x467954ad, 0x07301708, 0x151d5cee,   // ceb.tl.un_650 ik.war.qu_643  sr.uz.bg_443 sa.la.un_422 
  0x1f006114, 0x2e5102af, 0x5cfc420c, 0x075c4208,   // za.cy.un_660 da.kl.fo_655  co.zzp.sa_543 co.sa.it_443 
  // [13d20]
  0x531f0207, 0x460742ad, 0x53007623, 0x5c1bfea4,   // da.cy.ht_432 co.it.qu_643  crs.ht.un_880 tlh.tr.sa_433 
  0x6e2d29ad, 0x0900fe04, 0x12004a19, 0x2a002402,   // sl.sk.hmn_643 tlh.pl.un_320  yo.hu.un_750 eo.mt.un_220 
  0x026953ad, 0x436b7912, 0x29321709, 0x3146fe0c,   // ht.mfe.da_643 war.ceb.ie_654  sr.bs.sl_444 tlh.qu.az_543 
  0x3f03fe05, 0x23535ca4, 0x40fc1d07, 0x21343c04,   // tlh.nl.af_333 sa.ht.ca_433  la.zzp.lb_432 ug.ps.fa_332 
  // [13d30]
  0x2a0e2ea0, 0x303515ac, 0x38001019, 0x354838ec,   // fo.is.mt_322 un.tg.uz_632  lt.tk.un_750 tk.tt.tg_644 
  0x1d2d26ee, 0x3bfe3014, 0x2d0e0dad, 0x315e48a4,   // ia.sk.la_422 uz.tlh.so_666  cs.is.sk_643 tt.ts.az_433 
  0x3bfe5813, 0x343b58a7, 0xfe002e19, 0x4c003b0c,   // om.tlh.so_665 om.so.xh_532  fo.tlh.un_750 so.wo.un_530 
  0x3b00fe13, 0x070437a4, 0x2d0d080c, 0x345535a4,   // tlh.so.un_650 ba.ru.bg_433  no.cs.sk_543 zu.rw.xh_433 
  // [13d40]
  0x072344ee, 0x4c1e3ba4, 0xfe004c14, 0x43001d08,   // kk.ky.bg_422 so.ms.wo_433  wo.tlh.un_660 la.ie.un_430 
  0x3f000913, 0x25003407, 0x09003f12, 0x39005807,   // pl.af.un_650 xh.eu.un_420  af.pl.un_640 om.br.un_420 
  0x3b005e05, 0xfc000912, 0x34004e14, 0x232b0c07,   // ts.so.un_330 pl.zzp.un_640  ay.xh.un_660 sv.vi.ca_432 
  0x3500550d, 0x384823ec, 0x1504300c, 0x3530110c,   // rw.zu.un_540 ky.tt.tk_644  uz.ru.un_543 ro.uz.tg_543 
  // [13d50]
  0x3e072302, 0x4207180c, 0x07003014, 0x10004422,   // ca.it.rm_222 ga.it.co_543  uz.bg.un_660 kk.be.un_870 
  0x1c3b5c13, 0x1812280c, 0x3037480d, 0x7600531a,   // sa.ks.mr_665 sd.ur.ar_543  tt.ba.uz_554 ht.crs.un_760 
  0x7600532c, 0x2e0c2908, 0x1f002b07, 0x293e12a0,   // ht.crs.un_990 sl.sv.fo_443  vi.cy.un_420 hu.rm.sl_322 
  0x08002f02, 0x3d001214, 0x0a1711a9, 0x645b51a4,   // su.no.un_220 ur.ku.un_660  ro.sr.mk_544 kl.sg.lg_433 
  // [13d60]
  0x040e510c, 0x485154a4, 0x35fa64ad, 0x30282105,   // kl.is.fi_543 ik.kl.tt_433  lg.nr.zu_643 fa.sd.uz_333 
  0x131c2f0d, 0x510e0408, 0x040e5160, 0x4c0e3e55,   // su.id.et_554 fi.is.kl_443  kl.is.fi_664 rm.is.wo_442 
  0x024a0e07, 0x540e510c, 0x08406404, 0x30462f04,   // is.yo.da_432 kl.is.ik_543  lg.lb.no_332 su.qu.uz_332 
  0x64405405, 0x33511c0c, 0x59353413, 0x125c3407,   // ik.lb.lg_333 id.kl.nn_543  xh.zu.rn_665 xh.sa.hu_432 
  // [13d70]
  0x46005113, 0xfc0165a0, 0x182d0e0c, 0x24074307,   // kl.qu.un_650 gv.en.zzp_322  is.sk.ga_543 ie.it.eo_432 
  0x1d2601a0, 0x685f1211, 0x75215f0c, 0x2a6b01a0,   // en.ia.la_322 hu.tn.ig_653  tn.jw.nso_543 en.ceb.mt_322 
  0x6303fa0c, 0x44113855, 0x536939a4, 0x03213fa4,   // nr.nl.sco_543 tk.ro.kk_442  br.mfe.ht_433 af.jw.nl_433 
  0x3034210b, 0x460f5102, 0x2000fc14, 0x25003922,   // fa.ps.uz_542 kl.lv.qu_222  zzp.sq.un_660 br.eu.un_870 
  // [13d80]
  0x510efea0, 0x65000e19, 0x07002a2b, 0x4207fc0c,   // tlh.is.kl_322 is.gv.un_750  mt.it.un_980 zzp.it.co_543 
  0x5f23220d, 0x353447a9, 0x69094ca4, 0x2e0e18ad,   // oc.ca.tn_554 sn.xh.zu_544  wo.pl.mfe_433 ga.is.fo_643 
  0x2a005507, 0x492f2855, 0x0a041702, 0x1315fcee,   // rw.mt.un_420 sw.su.to_442  sr.ru.mk_222 zzp.et.un_420 
  0x40fc2402, 0x0400670c, 0x383744ad, 0x12233d0d,   // eo.zzp.lb_222 ak.fi.un_530  kk.ba.tk_643 ku.ky.ur_554 
  // [13d90]
  0x3ffc4ea4, 0x0e002b14, 0x4417380b, 0x28004b04,   // ay.zzp.af_433 vi.is.un_660  tk.sr.kk_542 mi.sw.un_320 
  0x19003b0e, 0x253844a4, 0x23441504, 0x1500151a,   // so.gl.un_550 kk.tk.mn_433  un.kk.ky_332 un.un.un_760 
  0x0730230c, 0x38151560, 0x44043704, 0x04083604,   // ky.uz.bg_543 un.tk.un_640  ba.ru.kk_332 ab.uk.ru_332 
  0x5f097508, 0x5f751960, 0x5f750911, 0x2a00111a,   // nso.pl.tn_443 gl.nso.tn_664  pl.nso.tn_653 ro.mt.un_760 
  // [13da0]
  0x0900250e, 0x48000804, 0x095f75ad, 0x09595513,   // eu.pl.un_550 uk.tt.un_320  nso.tn.pl_643 rw.rn.pl_665 
  0x05005319, 0x1a6b79a4, 0x35001902, 0x5c002402,   // ht.fr.un_750 war.ceb.tl_433  gl.zu.un_220 eo.sa.un_220 
  0x0900750e, 0x7555090c, 0x353010af, 0x2335480c,   // nso.pl.un_550 pl.rw.nso_543  be.uz.tg_655 tt.tg.ky_543 
  0x402f05a4, 0x380a1708, 0x32003105, 0x38000e0c,   // fr.su.lb_433 sr.mk.tk_443  az.bs.un_330 is.tk.un_530 
  // [13db0]
  0x280410ee, 0x5c100f55, 0x0b37285a, 0x38045ca0,   // lt.fi.sw_422 lv.lt.sa_442  sw.st.es_553 sa.fi.tk_322 
  0x2a002019, 0x1600280d, 0x08400507, 0x20460aad,   // sq.mt.un_750 sw.hr.un_540  fr.lb.no_432 pt.qu.sq_643 
  0x2a002c07, 0x1c240ba0, 0x6a000209, 0x25002802,   // fy.mt.un_420 es.eo.id_322  da.haw.un_440 sw.eu.un_220 
  0x202f2ca4, 0x11000b04, 0x253748ad, 0x3800200e,   // fy.su.sq_433 es.ro.un_320  tt.ba.mn_643 sq.tk.un_550 
  // [13dc0]
  0x0d352802, 0x35285cad, 0x2f002119, 0x0f301614,   // sw.zu.cs_222 sa.sw.zu_643  jw.su.un_750 hr.uz.lv_666 
  0x23220b05, 0x176852ee, 0x0f2920a4, 0x13003e0e,   // es.oc.ca_333 ha.ig.sr_422  sq.sl.lv_433 rm.et.un_550 
  0x17002404, 0x2c2a20a0, 0x2f002004, 0x4430230c,   // eo.sr.un_320 sq.mt.fy_322  sq.su.un_320 ky.uz.kk_543 
  0x28045a07, 0x25474ba0, 0x044808a4, 0x0d054c04,   // sm.fi.sw_432 mi.sn.eu_322  uk.tt.ru_433 wo.fr.cs_332 
  // [13dd0]
  0x292e3ead, 0x183c2304, 0x040201a0, 0x10000919,   // rm.fo.sl_643 ky.ug.ar_332  en.da.fi_322 pl.lt.un_750 
  0x070b0a04, 0x070811a4, 0x08003c13, 0x483b31a7,   // pt.es.it_332 ro.uk.bg_433  ug.uk.un_650 az.so.tt_532 
  0x044028a0, 0x42000513, 0x2b000402, 0x040a08a9,   // sw.lb.fi_322 fr.co.un_650  fi.vi.un_220 uk.mk.ru_544 
  0x38002e09, 0x15080aa9, 0x3c001119, 0x48003619,   // fo.tk.un_440 mk.uk.un_544  ro.ug.un_750 ab.tt.un_750 
  // [13de0]
  0x5800040c, 0x04006a19, 0x5c130914, 0x3048385a,   // fi.om.un_530 haw.fi.un_750  hi.bh.sa_666 tk.tt.uz_553 
  0x0c060307, 0x33084e0c, 0x48300807, 0x334f2e04,   // nl.de.sv_432 ay.no.nn_543  no.uz.tt_432 fo.bi.nn_332 
  0x0d12020d, 0x0f001022, 0x2d0d02a6, 0x1b2f0d07,   // da.hu.cs_554 lt.lv.un_870  da.cs.sk_521 cs.su.tr_432 
  0x02001807, 0x0d2d0212, 0x035c0907, 0x1b4d48ad,   // ga.da.un_420 da.sk.cs_654  pl.sa.nl_432 tt.aa.tr_643 
  // [13df0]
  0x122016a4, 0x2912fe55, 0x402e0ea4, 0x121039a4,   // hr.sq.hu_433 tlh.hu.sl_442  is.fo.lb_433 br.lt.hu_433 
  0x0d095c12, 0x4600201b, 0x402c03a4, 0x335c0807,   // sa.hi.ne_654 sq.qu.un_770  nl.fy.lb_433 no.sa.nn_432 
  0x3d003b19, 0x0d6b2d0c, 0x33090809, 0x171515a6,   // ks.ku.un_750 sk.ceb.cs_543  no.pl.nn_444 un.sr.un_510 
  0x12203202, 0x40002f08, 0x2d090d04, 0x0c000619,   // bs.sq.hu_222 su.lb.un_430  cs.pl.sk_332 de.sv.un_750 
  // [13e00]
  0x173e2955, 0x4f5b3055, 0x32166ea0, 0x40004c07,   // sl.rm.sr_442 uz.sg.bi_442  hmn.hr.bs_322 wo.lb.un_420 
  0x1e24fe07, 0x1c5c0d09, 0x3d302107, 0x0c002007,   // tlh.eo.ms_432 ne.sa.mr_444  fa.uz.ku_432 sq.sv.un_420 
  0x02200ca0, 0x33060c07, 0x200c0611, 0x40200c13,   // sv.sq.da_322 sv.de.nn_432  de.sv.sq_653 sv.sq.lb_665 
  0x3f003b13, 0x3322080c, 0x11363505, 0x330f23a0,   // so.af.un_650 no.oc.nn_543  tg.ab.ro_333 ca.lv.nn_322 
  // [13e10]
  0x40052e07, 0x33082a02, 0x5c004b19, 0x23373807,   // fo.fr.lb_432 mt.no.nn_222  mi.sa.un_750 tk.ba.ky_432 
  0x0e05400c, 0x2e003616, 0x192d2ea0, 0x6b7918ee,   // lb.fr.is_543 gn.fo.un_720  fo.sk.gl_322 ga.war.ceb_422 
  0x442337a6, 0x3d001819, 0x46284707, 0x16003213,   // ba.ky.kk_521 ar.ku.un_750  sn.sw.qu_432 bs.hr.un_650 
  0x475564a4, 0x34736404, 0x1000090b, 0x2800fc02,   // lg.rw.sn_433 lg.ny.xh_332  pl.lt.un_520 zzp.sw.un_220 
  // [13e20]
  0x0704350c, 0x5955280e, 0x52003402, 0x51002a12,   // tg.ru.bg_543 sw.rw.rn_555  xh.ha.un_220 mt.kl.un_640 
  0x595564ee, 0x304835ec, 0x0f003905, 0x081d070b,   // lg.rw.rn_422 tg.tt.uz_644  br.lv.un_330 it.la.no_542 
  0x070442af, 0x29000204, 0x082a4c02, 0x23002e07,   // co.fi.it_655 da.sl.un_320  wo.mt.no_222 fo.ca.un_420 
  0x212856ee, 0x653f56a0, 0x2e421305, 0x10003705,   // mg.sw.jw_422 mg.af.gv_322  et.co.fo_333 ba.be.un_330 
  // [13e30]
  0x091222ee, 0x04030204, 0x0f003f02, 0x2e4a2d04,   // oc.hu.pl_422 da.nl.fi_332  af.lv.un_220 sk.yo.fo_332 
  0x0b122d07, 0x2e190b60, 0x0b554a02, 0x0d2d2ead,   // sk.hu.es_432 es.gl.fo_664  yo.rw.es_222 fo.sk.cs_643 
  0x060e2e0c, 0x0e131bee, 0x0b0e1204, 0x0a0e09ee,   // fo.is.de_543 tr.et.is_422  hu.is.es_332 pl.is.pt_422 
  0x17151504, 0x360910a7, 0x2e003808, 0x05006208,   // un.sr.un_320 lt.pl.gn_532  tk.fo.un_430 kha.fr.un_430 
  // [13e40]
  0x07040809, 0x13003807, 0x3c342307, 0x033f1da4,   // uk.ru.bg_444 tk.et.un_420  ky.ps.ug_432 la.af.nl_433 
  0x040813a0, 0x1a2f21ad, 0x3b004d1a, 0x2a125104,   // et.no.fi_322 jw.su.tl_643  aa.so.un_760 kl.hu.mt_332 
  0x5265640b, 0x04171009, 0x440415ac, 0x060c0e07,   // lg.gv.ha_542 be.sr.ru_444  un.ru.kk_632 is.sv.de_432 
  0x0e040cec, 0x2c4d05ec, 0x381535a4, 0x0100fc05,   // sv.fi.is_644 fr.aa.fy_644  tg.tk.un_430 zzp.en.un_330 
  // [13e50]
  0x551a64af, 0x13200f05, 0x791e1a08, 0x3f73fc0d,   // lg.tl.rw_655 lv.sq.et_333  tl.ms.war_443 zzp.ny.af_554 
  0x654723a0, 0x35346b09, 0x5c1c13a6, 0x2f791a08,   // ca.sn.gv_322 ceb.xh.zu_444  bh.mr.sa_521 tl.war.su_443 
  0x351d5dec, 0x32160fa4, 0x2e020e05, 0x12283407,   // ss.la.zu_644 lv.hr.bs_433  is.da.fo_333 ps.sd.ur_432 
  0x4e000f22, 0x28090408, 0x55060207, 0x212f5907,   // lv.ay.un_870 fi.pl.sw_443  da.de.rw_432 rn.su.jw_432 
  // [13e60]
  0x0a790204, 0x171530a0, 0x35006419, 0x64501e08,   // da.war.pt_332 uz.sr.un_320  lg.zu.un_750 ms.fj.lg_443 
  0x32101307, 0x072b3e0c, 0x591c21a9, 0x0302300c,   // et.lt.bs_432 rm.vi.it_543  jw.id.rn_544 uz.da.nl_543 
  0x1a004d08, 0x04005e0b, 0x0c002202, 0xfe0447ad,   // aa.tl.un_430 ts.fi.un_520  oc.sv.un_220 sn.fi.tlh_643 
  0x34fa3513, 0x0a004702, 0x5d47350c, 0x1c212f08,   // zu.nr.xh_665 sn.pt.un_220  zu.sn.ss_543 su.jw.id_443 
  // [13e70]
  0x2b003e05, 0x5d5c300c, 0x10130fa4, 0xfc001505,   // rm.vi.un_330 uz.sa.ss_543  lv.et.lt_433 un.zzp.un_330 
  0x04fc4707, 0xfc5d220e, 0x360a0760, 0x0a381107,   // sn.zzp.fi_432 oc.ss.zzp_555  bg.mk.ab_664 ro.tk.mk_432 
  0x642859a0, 0x2e001f13, 0x0e303ea0, 0x23104404,   // rn.sw.lg_322 cy.fo.un_650  rm.uz.is_322 kk.be.ky_332 
  0x5955450e, 0x2c001207, 0x1c003b08, 0x3042290b,   // ln.rw.rn_555 hu.fy.un_420  so.id.un_430 sl.co.uz_542 
  // [13e80]
  0x10352302, 0x6455730c, 0x10003621, 0x5300730c,   // ky.tg.be_222 ny.rw.lg_543  ab.be.un_860 ny.ht.un_530 
  0x4815230c, 0x27062409, 0x13221902, 0x482338ec,   // ky.tt.un_530 eo.de.gd_444  gl.oc.et_222 tk.ky.tt_644 
  0x302335ee, 0x06190b08, 0x10082308, 0x040a1760,   // tg.ky.uz_422 es.gl.de_443  ky.uk.be_443 sr.mk.ru_664 
  0x13001907, 0x0200460d, 0x3b0e4d04, 0x11381513,   // gl.et.un_420 qu.da.un_540  aa.is.so_332 un.tk.ro_665 
  // [13e90]
  0x4d000e1a, 0x07350a07, 0x04fc0ea0, 0x48002108,   // is.aa.un_760 mk.tg.bg_432  is.zzp.fi_322 jw.tt.un_430 
  0x4c005605, 0x0a283e0c, 0x567359a4, 0x07081711,   // mg.wo.un_330 rm.sw.pt_543  rn.ny.mg_433 sr.uk.bg_653 
  0x043130a0, 0x51400613, 0x395328a7, 0x05000702,   // uz.az.fi_322 de.lb.kl_665  sw.ht.br_532 it.fr.un_220 
  0x3815fc55, 0x120b590c, 0x0526690c, 0x19360ba6,   // zzp.tk.un_420 rn.es.hu_543  mfe.ia.fr_543 es.gn.gl_521 
  // [13ea0]
  0x22006207, 0x203efe0b, 0x3b004608, 0x0b363ea0,   // kha.oc.un_420 tlh.rm.sq_542  qu.so.un_430 rm.gn.es_322 
  0x5c002405, 0x525c28ee, 0x28476b02, 0x1e3e1cec,   // eo.sa.un_330 sw.sa.ha_422  ceb.sn.sw_222 id.rm.ms_644 
  0x0b3e7355, 0x3c3830a9, 0x1e282105, 0x350a08a4,   // ny.rm.es_442 uz.tk.ug_544  jw.sw.ms_333 uk.mk.tg_433 
  0x1c2c21ee, 0x11002d12, 0x30350a13, 0xfc002507,   // jw.fy.id_422 sk.ro.un_640  mk.tg.uz_665 eu.zzp.un_420 
  // [13eb0]
  0x381c21a0, 0x127909ec, 0x04150813, 0x30363704,   // jw.id.tk_322 pl.war.hu_644  uk.ru.un_650 ba.ab.uz_332 
  0x3d212804, 0x2344370e, 0x381511ec, 0x0710110c,   // sd.fa.ku_332 ba.kk.ky_555  ro.tk.un_640 ro.be.bg_543 
  0x2e000a04, 0x09001014, 0x2800fc04, 0x04103702,   // pt.fo.un_320 lt.pl.un_660  zzp.sw.un_320 ba.be.ru_222 
  0x2f796bad, 0x080233a6, 0x080c020c, 0x760253af,   // ceb.war.su_643 nn.da.no_521  da.sv.no_543 ht.da.crs_655 
  // [13ec0]
  0x12536904, 0x363530ec, 0x29002d09, 0x52002904,   // mfe.ht.hu_332 uz.tg.ab_644  sk.sl.un_440 sl.ha.un_320 
  0x304815ee, 0x20000e02, 0x38100a05, 0x35001529,   // un.tt.uz_422 is.sq.un_220  mk.be.tk_333 un.tg.un_960 
  0xfc005e02, 0x15576505, 0x20005004, 0x53240213,   // ts.zzp.un_220 gv.na.un_333  fj.sq.un_320 da.eo.ht_665 
  0x39531f0d, 0x343d21a0, 0x3f030255, 0x304438a4,   // cy.ht.br_554 fa.ku.ps_322  da.nl.af_442 tk.kk.uz_433 
  // [13ed0]
  0x073c0a08, 0xfe004221, 0x4efe4212, 0x063f7913,   // mk.ug.bg_443 co.tlh.un_860  co.tlh.ay_654 war.af.de_665 
  0x17301504, 0x07360a09, 0x1a063fa0, 0x32001713,   // un.uz.sr_332 mk.ab.bg_444  af.de.tl_322 sr.bs.un_650 
  0x483623a4, 0x635d0107, 0x3700fc02, 0x4c067907,   // ky.ab.tt_433 en.ss.sco_432  zzp.st.un_220 war.de.wo_432 
  0x38fc18a0, 0x2a004e12, 0x58006007, 0xfc330855,   // ga.zzp.tk_322 ay.mt.un_640  vo.om.un_420 no.nn.zzp_442 
  // [13ee0]
  0x477960a7, 0x3e0640a0, 0x03636907, 0x081715a7,   // vo.war.sn_532 lb.de.rm_322  mfe.sco.nl_432 un.sr.uk_532 
  0x3b002d02, 0x12392007, 0x08005104, 0x4a590207,   // sk.so.un_220 sq.br.hu_432  kl.no.un_320 da.rn.yo_432 
  0x2a0928a0, 0x2c63200c, 0x551302a4, 0x4f33080d,   // sw.pl.mt_322 sq.sco.fy_543  da.et.rw_433 no.nn.bi_554 
  0x0b0e19a4, 0x39005c02, 0x0d1246a0, 0x25104e0c,   // gl.is.es_433 sa.br.un_220  qu.hu.cs_322 ay.lt.eu_543 
  // [13ef0]
  0x57750208, 0x645a7511, 0x251a750c, 0x37083504,   // da.nso.na_443 nso.sm.lg_653  nso.tl.eu_543 tg.uk.ba_332 
  0x555f7508, 0x645f75a4, 0x52002514, 0x04374807,   // nso.tn.rw_443 nso.tn.lg_433  eu.ha.un_660 tt.ba.ru_432 
  0x24000702, 0xfa007521, 0x68751aaf, 0x3b1d0107,   // it.eo.un_220 nso.nr.un_860  tl.nso.ig_655 en.la.so_432 
  0x2b000a05, 0x22232112, 0x59555012, 0x3b1221a9,   // pt.vi.un_330 jw.ca.oc_654  fj.rw.rn_654 fa.ur.ks_544 
  // [13f00]
  0x1a6b750c, 0x0a750ba4, 0x4005220b, 0x100817af,   // nso.ceb.tl_543 es.nso.pt_433  oc.fr.lb_542 sr.uk.be_655 
  0x212e2f04, 0x3d1228a0, 0x0407445a, 0x34002121,   // su.fo.jw_332 sd.ur.ku_322  kk.bg.ru_553 fa.ps.un_860 
  0x2205230d, 0x22212307, 0x063f60ec, 0x25005113,   // ca.fr.oc_554 ca.jw.oc_432  vo.af.de_644 kl.eu.un_650 
  0x25004007, 0x2e0e2402, 0x2a2e33a0, 0x3c233012,   // lb.eu.un_420 eo.is.fo_222  nn.fo.mt_322 uz.ky.ug_654 
  // [13f10]
  0x2e0e2a08, 0x42400507, 0x5d220aa6, 0x65461fee,   // mt.is.fo_443 fr.lb.co_432  pt.oc.ss_521 cy.qu.gv_422 
  0x2c060a07, 0x44483c0d, 0x3f00760c, 0x472b1aa0,   // pt.de.fy_432 ug.tt.kk_554  crs.af.un_530 tl.vi.sn_322 
  0x0a4d2a07, 0x2c790aa9, 0x79730aa7, 0x61003913,   // mt.aa.pt_432 pt.war.fy_544  pt.ny.war_532 br.za.un_650 
  0x19470a07, 0x05023907, 0x2bfc0a05, 0x06001102,   // pt.sn.gl_432 br.da.fr_432  pt.zzp.vi_333 ro.de.un_220 
  // [13f20]
  0x4e006113, 0x35000a22, 0x2c2b0a0c, 0x0a00471a,   // za.ay.un_650 pt.zu.un_870  pt.vi.fy_543 sn.pt.un_760 
  0x0a005d22, 0x1f651008, 0x0500532b, 0x79520a0c,   // ss.pt.un_870 lt.gv.cy_443  ht.fr.un_980 pt.ha.war_543 
  0x38151007, 0x43001a12, 0x47040aee, 0x09101fa0,   // be.tk.un_420 tl.ie.un_640  pt.fi.sn_422 cy.lt.pl_322 
  0x02790a04, 0x1d511fee, 0x111d2802, 0x28001107,   // pt.war.da_332 cy.kl.la_422  sw.la.ro_222 ro.sw.un_420 
  // [13f30]
  0x1a111e07, 0x68026aad, 0x73345d0c, 0x0e5a1104,   // ms.ro.tl_432 haw.da.ig_643  ss.xh.ny_543 ro.sm.is_332 
  0x21245407, 0x32002002, 0x6a490208, 0x24111da0,   // ik.eo.jw_432 sq.bs.un_220  da.to.haw_443 la.ro.eo_322 
  0x04070809, 0x126b1a11, 0x3421025a, 0x651d11ad,   // uk.bg.ru_444 tl.ceb.hu_653  da.jw.xh_553 ro.la.gv_643 
  0x374448a0, 0x16023107, 0x5c071204, 0x592910ad,   // tt.kk.ba_322 az.da.hr_432  hu.it.sa_332 lt.sl.rn_643 
  // [13f40]
  0x6900430e, 0x484d4c07, 0x20001013, 0x4a2010ec,   // ie.mfe.un_550 wo.aa.tt_432  lt.sq.un_650 lt.sq.yo_644 
  0x73350211, 0x20595504, 0x38483705, 0x0d100908,   // da.zu.ny_653 rw.rn.sq_332  ba.tt.tk_333 pl.lt.cs_443 
  0x0a1708ad, 0x20001018, 0x60001114, 0x45340304,   // uk.sr.mk_643 lt.sq.un_740  ro.vo.un_660 nl.xh.ln_332 
  0x480c13a0, 0x092902a4, 0x20291055, 0x73006a0d,   // et.sv.tt_322 da.sl.pl_433  lt.sl.sq_442 haw.ny.un_540 
  // [13f50]
  0x5c000704, 0x05023908, 0x20001002, 0x27fc05a6,   // it.sa.un_320 br.da.fr_443  lt.sq.un_220 fr.zzp.gd_521 
  0x1f001012, 0x50000804, 0x4c003e12, 0x3e1865a7,   // lt.cy.un_640 no.fj.un_320  rm.wo.un_640 gv.ga.rm_532 
  0x365c0b07, 0x1020595a, 0x072442ee, 0x3f006502,   // es.sa.gn_432 rn.sq.lt_553  co.eo.it_422 gv.af.un_220 
  0x22261d0c, 0x2c0e330b, 0x531d4c04, 0x05421d0c,   // la.ia.oc_543 nn.is.fy_542  wo.la.ht_332 la.co.fr_543 
  // [13f60]
  0x094a5304, 0x205910af, 0x150742a0, 0x09003e08,   // ht.yo.pl_332 lt.rn.sq_655  co.it.un_322 rm.pl.un_430 
  0x55201008, 0x09002a12, 0x315b1b05, 0x18110708,   // lt.sq.rw_443 mt.pl.un_640  tr.sg.az_333 it.ro.ga_443 
  0x213b285a, 0x3f09100c, 0x421d3ea4, 0x0d5c0955,   // sd.ks.fa_553 lt.pl.af_543  rm.la.co_433 hi.sa.ne_442 
  0x39423e08, 0x3e421aa4, 0x08070aee, 0x043515ad,   // rm.co.br_443 tl.co.rm_433  mk.bg.uk_422 un.tg.ru_643 
  // [13f70]
  0x2e1218ac, 0x0804070d, 0x151117a4, 0x122f0da7,   // ga.hu.fo_632 bg.ru.uk_554  sr.ro.un_433 cs.su.hu_532 
  0x02002d11, 0x16003e04, 0x5d00fc04, 0x5c004b0b,   // sk.da.un_630 rm.hr.un_320  zzp.ss.un_320 mi.sa.un_520 
  0x360e0da0, 0x020d2d5e, 0x3f1206a0, 0x3573280b,   // cs.is.gn_322 sk.cs.da_652  de.hu.af_322 sw.ny.zu_542 
  0x13471002, 0x732b4607, 0x453435ec, 0x355e4513,   // lt.sn.et_222 qu.vi.ny_432  zu.xh.ln_644 ln.ts.zu_665 
  // [13f80]
  0x23041702, 0x0402130c, 0x35344514, 0x35151104,   // sr.ru.ky_222 et.da.fi_543  ln.xh.zu_666 ro.tg.un_320 
  0x060e02a0, 0x1d001907, 0x10080705, 0x735202ad,   // da.is.de_322 gl.la.un_420  bg.uk.be_333 da.ha.ny_643 
  0x31483b07, 0x041136a9, 0x0c400655, 0x10442510,   // so.tt.az_432 ab.ro.ru_544  de.lb.sv_442 mn.kk.be_642 
  0x25233013, 0x0a153508, 0x080c33af, 0x35103013,   // uz.ky.mn_665 tg.mk.un_430  nn.sv.no_655 uz.be.tg_665 
  // [13f90]
  0x153530ee, 0x4005225a, 0x080710a6, 0x10071705,   // uz.tg.un_422 oc.fr.lb_553  be.bg.uk_521 sr.bg.be_333 
  0x150601a7, 0x0a1707a7, 0x3b4013ee, 0x022e130d,   // en.de.un_532 bg.sr.mk_532  et.lb.so_422 et.fo.da_554 
  0x3b642804, 0x045a6a0b, 0x4c00430d, 0x1f000f02,   // sw.lg.so_332 haw.sm.fi_542  ie.wo.un_540 lv.cy.un_220 
  0x13580404, 0x104807ee, 0x043b6404, 0x3b006b13,   // fi.om.et_332 bg.tt.be_422  lg.so.fi_332 ceb.so.un_650 
  // [13fa0]
  0x440407af, 0x222b6155, 0x54003b13, 0x643b51ee,   // bg.ru.kk_655 za.vi.oc_442  so.ik.un_650 kl.so.lg_422 
  0x67002b1a, 0x03002514, 0x5154640c, 0x06002520,   // vi.ak.un_760 eu.nl.un_660  lg.ik.kl_543 eu.de.un_850 
  0x1d005805, 0x4d3b64af, 0x4d000f19, 0x15173b11,   // om.la.un_330 lg.so.aa_655  lv.aa.un_750 so.sr.un_653 
  0xfe001505, 0x193e08a0, 0x034202a0, 0x1b073007,   // un.tlh.un_330 no.rm.gl_322  da.co.nl_322 uz.it.tr_432 
  // [13fb0]
  0x050106ee, 0x192e18a7, 0x120e2e0c, 0x08150aa9,   // de.en.fr_422 ga.fo.gl_532  fo.is.hu_543 mk.uk.un_540 
  0x29000902, 0x1e0910ee, 0x073011ad, 0x36041108,   // pl.sl.un_220 lt.pl.ms_422  ro.uz.it_643 ro.ru.ab_443 
  0x35081707, 0x093b2da0, 0x30001219, 0x1c3b4ab4,   // sr.uk.tg_432 sk.so.pl_322  ur.uz.un_750 yo.so.id_754 
  0x2a000921, 0x322d0da0, 0x153811a7, 0x293216a6,   // pl.mt.un_860 cs.sk.bs_322  ro.tk.un_532 hr.bs.sl_521 
  // [13fc0]
  0x36006a1b, 0x123646a7, 0x30001e05, 0x08070a0b,   // haw.gn.un_770 qu.gn.hu_532  ms.uz.un_330 mk.bg.uk_542 
  0x18122dec, 0x58001c08, 0x4b28360b, 0x512411a4,   // sk.hu.ga_644 id.om.un_430  gn.sw.mi_542 ro.eo.kl_433 
  0x210833a0, 0x1b243855, 0x1100510d, 0x110a24a9,   // nn.no.jw_322 tk.eo.tr_442  kl.ro.un_540 eo.pt.ro_544 
  0x331208a4, 0x16002913, 0x233510ee, 0x374f12a0,   // no.hu.nn_433 sl.hr.un_650  be.tg.ky_422 hu.bi.st_322 
  // [13fd0]
  0x383048af, 0x63304807, 0x1b213055, 0x0d170c04,   // tt.uz.tk_655 tt.uz.sco_432  uz.jw.tr_442 sv.sr.cs_332 
  0x04652604, 0x202afe07, 0x1b7669ad, 0x336008a4,   // ia.gv.fi_332 tlh.mt.sq_432  mfe.crs.tr_643 no.vo.nn_433 
  0x0220feee, 0x2e190a04, 0x69104ca4, 0x2d002e02,   // tlh.sq.da_422 pt.gl.fo_332  wo.lt.mfe_433 fo.sk.un_220 
  0x3b3428a4, 0x36003c21, 0x48000707, 0x0d322004,   // sd.ps.ks_433 ug.ab.un_860  bg.tt.un_420 sq.bs.cs_332 
  // [13fe0]
  0x0900fe1a, 0x3800251b, 0x277925ee, 0x23001807,   // tlh.pl.un_760 mn.tk.un_770  eu.war.gd_422 ga.ca.un_420 
  0x220625a0, 0x25004c0d, 0x20483ba0, 0x0d002e09,   // eu.de.oc_322 wo.eu.un_540  so.tt.sq_322 fo.cs.un_440 
  0x65000a02, 0x122f2104, 0x25004c0c, 0x34315e02,   // pt.gv.un_220 jw.su.hu_332  wo.eu.un_530 ts.az.xh_222 
  0x21fc02a6, 0x35343102, 0x180153a0, 0x256022a4,   // da.zzp.jw_521 az.xh.zu_222  ht.en.ga_322 oc.vo.eu_433 
  // [13ff0]
  0x791140af, 0x1d79060c, 0x225305a4, 0x481c1ea7,   // lb.ro.war_655 de.war.la_543  fr.ht.oc_433 ms.id.tt_532 
  0x13022aa4, 0x5e00362b, 0x6b730f0d, 0x20002a1a,   // mt.da.et_433 gn.ts.un_980  lv.ny.ceb_554 mt.sq.un_760 
  0x0228500c, 0x6a360408, 0x25103807, 0x1c502fa9,   // fj.sw.da_543 fi.gn.haw_443  tk.be.mn_432 su.fj.id_544 
  0x0a04070d, 0x04573612, 0x47283f07, 0x4f4a60ac,   // bg.ru.mk_554 gn.na.fi_654  af.sw.sn_432 vo.yo.bi_632 
  
  // [14000]
  0x59556baf, 0x36733507, 0x1e1c3502, 0x5e5d3460,   // ceb.rw.rn_655 zu.ny.gn_432  zu.id.ms_222 xh.ss.ts_664 
  0x17205607, 0x2d003813, 0x59281213, 0x53595560,   // mg.sq.sr_432 tk.sk.un_650  hu.sw.rn_665 rw.rn.ht_664 
  0x7900fe12, 0x4c001c05, 0x0f2f1104, 0x56321614,   // tlh.war.un_640 id.wo.un_330  ro.su.lv_332 hr.bs.mg_666 
  0xfc001902, 0x1d0d4212, 0x322955a4, 0x5e734614,   // gl.zzp.un_220 co.cs.la_654  rw.sl.bs_433 qu.ny.ts_666 
  // [14010]
  0x0ffc2204, 0x214610a4, 0x4400080d, 0x43047904,   // oc.zzp.lv_332 lt.qu.jw_433  uk.kk.un_540 war.fi.ie_332 
  0x11220a0c, 0x5500170d, 0x280e2e12, 0x59321609,   // pt.oc.ro_543 sr.rw.un_540  fo.is.sw_654 hr.bs.rn_444 
  0x3b261d0c, 0x4053765a, 0x134006ee, 0x0f5e730c,   // la.ia.so_543 crs.ht.lb_553  de.lb.et_422 ny.ts.lv_543 
  0x32161eaf, 0x29002f07, 0x63006207, 0x082c21ee,   // ms.hr.bs_655 su.sl.un_420  kha.sco.un_420 jw.fy.no_422 
  // [14020]
  0x2d005907, 0x171513ee, 0x5500fe13, 0x070163a0,   // rn.sk.un_420 et.sr.un_420  tlh.rw.un_650 sco.en.it_322 
  0x53321608, 0x42210504, 0x0b425004, 0x30383113,   // hr.bs.ht_443 fr.jw.co_332  fj.co.es_332 az.tk.uz_665 
  0xfe32160d, 0x10044807, 0x1b311fa7, 0x1c79fead,   // hr.bs.tlh_554 tt.ru.be_432  cy.az.tr_532 tlh.war.id_643 
  0x61006304, 0x0820330c, 0x283c3d12, 0x18010d04,   // sco.za.un_320 nn.sq.no_543  ku.ug.sd_654 cs.en.ga_332 
  // [14030]
  0x380261ad, 0x083f43a0, 0x150a0409, 0x2e420e07,   // za.da.tk_643 ie.af.no_322  ru.mk.un_444 is.co.fo_432 
  0x0c003f05, 0x12183c04, 0x234810ee, 0x3b464da7,   // af.sv.un_330 ug.ar.ur_332  be.tt.ky_422 aa.qu.so_532 
  0x4d004619, 0x65004602, 0x40730612, 0x25064007,   // qu.aa.un_750 qu.gv.un_220  de.ny.lb_654 lb.de.eu_432 
  0x37113508, 0x064025a7, 0x0300250d, 0x11004005,   // tg.ro.ba_443 eu.lb.de_532  eu.nl.un_540 lb.ro.un_330 
  // [14040]
  0x61006e2a, 0x3b004e0c, 0x40250ca6, 0x6e00610d,   // hmn.za.un_970 ay.so.un_530  sv.eu.lb_521 za.hmn.un_540 
  0x464d4e12, 0x464d4eaf, 0x110e2e02, 0x4d3046af,   // ay.aa.qu_654 ay.aa.qu_655  fo.is.ro_222 qu.uz.aa_655 
  0x0a3611a6, 0x130451ad, 0x51353408, 0x46004d14,   // ro.ab.mk_521 kl.fi.et_643  xh.zu.kl_443 aa.qu.un_660 
  0x100f1da0, 0x0e100f5a, 0x791a6bad, 0x40060207,   // la.lv.lt_322 lv.lt.is_553  ceb.tl.war_643 da.de.lb_432 
  // [14050]
  0x22190b02, 0x64005112, 0x2e000502, 0x083507a4,   // es.gl.oc_222 kl.lg.un_640  fr.fo.un_220 bg.tg.uk_433 
  0x421b05ee, 0x460f5004, 0x31003b0e, 0x1d030504,   // fr.tr.co_422 fj.lv.qu_332  so.az.un_550 fr.nl.la_332 
  0x735e51af, 0x3f1d2507, 0x121151a4, 0x510e4da4,   // kl.ts.ny_655 eu.la.af_432  kl.ro.hu_433 aa.is.kl_433 
  0x18002a05, 0x11003614, 0x46001209, 0x30000504,   // mt.ga.un_330 ab.ro.un_660  hu.qu.un_440 fr.uz.un_320 
  // [14060]
  0x34003c0c, 0x08483004, 0x082d0204, 0x040838ad,   // ug.ps.un_530 uz.tt.uk_332  da.sk.no_332 tk.uk.ru_643 
  0x170c29a0, 0x20003802, 0x11003519, 0x17362507,   // sl.sv.sr_322 tk.sq.un_220  tg.ro.un_750 mn.ab.sr_432 
  0x29002a07, 0x282130a4, 0x20134807, 0x1000361b,   // mt.sl.un_420 uz.fa.sd_433  tt.et.sq_432 ab.be.un_770 
  0x1b222307, 0x480a15a0, 0x4b5c0fa4, 0x2300351b,   // ca.oc.tr_432 un.mk.tt_322  lv.sa.mi_433 tg.ky.un_770 
  // [14070]
  0x480a04a0, 0x48103812, 0x29092d07, 0x043010ee,   // ru.mk.tt_322 tk.be.tt_654  sk.pl.sl_432 be.uz.ru_422 
  0x05072408, 0x1f00fc09, 0x071504a0, 0x48003c14,   // eo.it.fr_443 zzp.cy.un_440  ru.bg.un_320 ug.tt.un_660 
  0x231044ee, 0x0c2a1304, 0x201213a4, 0x23005e05,   // kk.be.ky_422 et.mt.sv_332  et.hu.sq_433 ts.ca.un_330 
  0x10083608, 0x04002808, 0x0b000504, 0x47555912,   // ab.uk.be_443 sw.fi.un_430  fr.es.un_320 rn.rw.sn_654 
  // [14080]
  0x21006813, 0x2ffe47a4, 0x2178fea4, 0x1b2053a9,   // ig.jw.un_650 sn.tlh.su_433  tlh.ve.jw_433 ht.sq.tr_544 
  0x10fe1307, 0xfc731f04, 0x1f006807, 0x2f132aee,   // et.tlh.lt_432 cy.ny.zzp_332  ig.cy.un_420 mt.et.su_422 
  0x42002f07, 0x2859555a, 0x39fe2e07, 0x483710ec,   // su.co.un_420 rw.rn.sw_553  fo.tlh.br_432 be.ba.tt_644 
  0x2f2147a0, 0x30150404, 0x11190b08, 0x494b5aa4,   // sn.jw.su_322 ru.uz.un_320  es.gl.ro_443 sm.mi.to_433 
  // [14090]
  0x1a000407, 0x2a003b07, 0x11003108, 0x022d0d04,   // fi.tl.un_420 so.mt.un_420  az.ro.un_430 cs.sk.da_332 
  0x0800020d, 0x0e002c07, 0x064e510d, 0x643f49a0,   // da.no.un_540 fy.is.un_420  kl.ay.de_554 to.af.lg_322 
  0x080262a4, 0x5d350608, 0x2c004219, 0x0c5440a4,   // kha.da.no_433 de.zu.ss_443  co.fy.un_750 lb.ik.sv_433 
  0x364438a4, 0x35003e05, 0x4c0640a0, 0x233848a9,   // tk.kk.ab_433 rm.zu.un_330  lb.de.wo_322 tt.tk.ky_544 
  // [140a0]
  0x0e406005, 0x30233555, 0x182a060b, 0x2100302b,   // vo.lb.is_333 tg.ky.uz_442  de.mt.ga_542 uz.fa.un_980 
  0x12002e1a, 0x1351540d, 0x796054ad, 0x0f630104,   // fo.hu.un_760 ik.kl.et_554  ik.vo.war_643 en.sco.lv_332 
  0x64003904, 0x2c3f3e04, 0x340e5408, 0x24171ea0,   // br.lg.un_320 rm.af.fy_332  ik.is.xh_443 ms.sr.eo_322 
  0x062e0e08, 0x3f125407, 0x24004c04, 0x0f002004,   // is.fo.de_443 ik.hu.af_432  wo.eo.un_320 sq.lv.un_320 
  // [140b0]
  0x2900520c, 0x534728ad, 0x635d3704, 0x20212fee,   // ha.sl.un_530 sw.sn.ht_643  st.ss.sco_332 su.jw.sq_422 
  0x0b1153af, 0x031d15a4, 0x56002405, 0x19004e13,   // ht.ro.es_655 un.la.nl_433  eo.mg.un_330 ay.gl.un_650 
  0x23fc0c07, 0x12341808, 0x363020ad, 0x2f000a21,   // sv.zzp.ca_432 ar.ps.ur_443  sq.uz.gn_643 pt.su.un_860 
  0x091820a0, 0x17110712, 0x3300fc0b, 0x3d233cad,   // sq.ga.pl_322 bg.ro.sr_654  zzp.nn.un_520 ug.ky.ku_643 
  // [140c0]
  0x35073013, 0x232812a9, 0x08351707, 0x150c0608,   // uz.bg.tg_665 ur.sd.ky_544  sr.tg.uk_432 de.sv.un_443 
  0x1d33085a, 0x38483105, 0x5c090d5a, 0x483035a9,   // no.nn.la_553 az.tt.tk_333  ne.hi.sa_553 tg.uz.tt_544 
  0x59004a0e, 0x20006e05, 0x4a005312, 0x2100360d,   // yo.rn.un_550 hmn.sq.un_330  ht.yo.un_640 gn.jw.un_540 
  0x28342112, 0x11222404, 0x49002404, 0x250a0704,   // fa.ps.sd_654 eo.oc.ro_332  eo.to.un_320 bg.mk.mn_332 
  // [140d0]
  0x022562a0, 0x684a520b, 0x363035ec, 0x0e0c2e13,   // kha.eu.da_322 ha.yo.ig_542  tg.uz.ab_644 fo.sv.is_665 
  0xfc063b0c, 0x04001c02, 0x6b510207, 0x1a006b12,   // so.de.zzp_543 id.fi.un_220  da.kl.ceb_432 ceb.tl.un_640 
  0x441025a6, 0x42024da4, 0x3b0c3002, 0x79074207,   // mn.be.kk_521 aa.da.co_433  uz.sv.so_222 co.it.war_432 
  0x071d42a4, 0x090f1308, 0x2d0d0c05, 0x2c0333ec,   // co.la.it_433 et.lv.pl_443  sv.cs.sk_333 nn.nl.fy_644 
  // [140e0]
  0x125c0207, 0x03003304, 0x1e1c4aa4, 0x0d052da0,   // da.sa.hu_432 nn.nl.un_320  yo.id.ms_433 sk.fr.cs_322 
  0x070b42a4, 0x5c001522, 0x5104420b, 0x5a0d4004,   // co.es.it_433 un.sa.un_870  co.fi.kl_542 lb.cs.sm_332 
  0x39fc130c, 0x3b065807, 0x332e0e0e, 0x42001521,   // et.zzp.br_543 om.de.so_432  is.fo.nn_555 un.co.un_860 
  0x58061aa0, 0x474901a4, 0x652f4a55, 0x3b200f12,   // tl.de.om_322 en.to.sn_433  yo.su.gv_442 lv.sq.so_654 
  // [140f0]
  0x2229fcee, 0x42000722, 0xfe3130ad, 0x532c3907,   // zzp.sl.oc_422 it.co.un_870  uz.az.tlh_643 br.fy.ht_432 
  0x1221280b, 0x271a13a0, 0x10003b07, 0x4a006012,   // sd.fa.ur_542 et.tl.gd_322  so.lt.un_420 vo.yo.un_640 
  0x653e5707, 0x053919a0, 0x63fc65ec, 0x07425c55,   // na.rm.gv_432 gl.br.fr_322  gv.zzp.sco_644 sa.co.it_442 
  0x0200520d, 0x0726150c, 0x0a021007, 0x21000208,   // ha.da.un_540 un.ia.it_543  lt.da.pt_432 da.jw.un_430 
  // [14100]
  0x330e2ea4, 0x570e06a4, 0xfc2c01a9, 0x642f3f04,   // fo.is.nn_433 de.is.na_433  en.fy.zzp_544 af.su.lg_332 
  0x530279ad, 0x33002c22, 0x425c070d, 0x082c3312,   // war.da.ht_643 fy.nn.un_870  it.sa.co_554 nn.fy.no_654 
  0x08104413, 0x564728a0, 0x2b281c55, 0x03420eee,   // kk.be.uk_665 sw.sn.mg_322  id.sw.vi_442 is.co.nl_422 
  0x3e160707, 0x614a30af, 0x1d530d07, 0x427907a7,   // it.hr.rm_432 uz.yo.za_655  cs.ht.la_432 it.war.co_532 
  // [14110]
  0x3d302113, 0x2d003807, 0x0c6b1dad, 0x494bfc55,   // fa.uz.ku_665 tk.sk.un_420  la.ceb.sv_643 zzp.mi.to_442 
  0x421354ee, 0x11000819, 0x3f002c09, 0x0110fca6,   // ik.et.co_422 uk.ro.un_750  fy.af.un_440 zzp.lt.en_521 
  0x04003509, 0x10080aa4, 0x58005e05, 0x25343ba9,   // tg.ru.un_440 mk.uk.be_433  ts.om.un_330 so.xh.eu_544 
  0x0a114ea0, 0x37251507, 0x37442360, 0x2c460b0c,   // ay.ro.pt_322 un.mn.ba_432  ky.kk.ba_664 es.qu.fy_543 
  // [14120]
  0x30fe46ec, 0x314d3b60, 0x4c3b5ca4, 0x0410085a,   // qu.tlh.uz_644 so.aa.az_664  sa.so.wo_433 uk.be.ru_553 
  0x35003b0d, 0x343048a7, 0x31004c21, 0x074411a7,   // so.zu.un_540 tt.uz.xh_532  wo.az.un_860 ro.kk.bg_532 
  0x315e5812, 0x31001305, 0x373c48ad, 0x4c003b22,   // om.ts.az_654 et.az.un_330  tt.ug.ba_643 so.wo.un_870 
  0x5e196012, 0x3c000712, 0x5e004e19, 0x00003b37,   // vo.gl.ts_654 bg.ug.un_640  ay.ts.un_750 so.un.un_B00 
  // [14130]
  0x3e0a4c0c, 0x584e3b55, 0x595550a9, 0x5500280c,   // wo.pt.rm_543 so.ay.om_442  fj.rw.rn_544 sw.rw.un_530 
  0x48373605, 0x2a001b08, 0x04512a13, 0x42111d07,   // ab.ba.tt_333 tr.mt.un_430  mt.kl.fi_665 la.ro.co_432 
  0x0f000704, 0x34355e0c, 0x2e0e4707, 0x1c1d2f04,   // it.lv.un_320 ts.zu.xh_543  sn.is.fo_432 su.la.id_332 
  0x1d190b09, 0x153808a4, 0x553435a4, 0x481525ac,   // es.gl.la_444 uk.tk.un_433  zu.xh.rw_433 mn.tt.un_620 
  // [14140]
  0x52005107, 0x3100110d, 0x104811af, 0x441023a7,   // kl.ha.un_420 ro.az.un_540  ro.tt.be_655 ky.be.kk_532 
  0x46000708, 0x34003c0e, 0x354830ad, 0x48170404,   // it.qu.un_430 ug.ps.un_550  uz.tt.tg_643 ru.sr.tt_332 
  0x4810040d, 0x3035340d, 0x314634a4, 0x1a000304,   // ru.be.tt_554 xh.zu.uz_554  xh.qu.az_433 nl.tl.un_320 
  0x5c6533a0, 0x22064002, 0x0a111005, 0x3f030e04,   // nn.gv.sa_322 lb.de.oc_222  be.ro.mk_333 is.nl.af_332 
  // [14150]
  0x44152311, 0x303146a0, 0x30313ba0, 0x041711ac,   // ky.kk.un_630 qu.az.uz_322  so.az.uz_322 ro.sr.ru_632 
  0x0f000c08, 0x30353805, 0x3c482314, 0x29321702,   // sv.lv.un_430 tk.tg.uz_333  ky.tt.ug_666 sr.bs.sl_222 
  0x30002908, 0x0336040c, 0x2c3f09a7, 0x04003b07,   // sl.uz.un_430 fi.gn.nl_543  pl.af.fy_532 so.fi.un_420 
  0x30005809, 0x48042ea0, 0x0b002e04, 0x58003007,   // om.uz.un_440 fo.fi.tt_322  fo.es.un_320 uz.om.un_420 
  // [14160]
  0x20006907, 0x0e000c20, 0x48441002, 0x300a070e,   // mfe.sq.un_420 sv.is.un_850  be.kk.tt_222 bg.mk.uz_555 
  0x29000104, 0x30384804, 0x12304308, 0x07043855,   // en.sl.un_320 tt.tk.uz_332  ie.uz.hu_443 tk.ru.bg_442 
  0x2544230c, 0x56002b09, 0x170a3502, 0x30311ba4,   // ky.kk.mn_543 vi.mg.un_440  tg.mk.sr_222 tr.az.uz_433 
  0x3d12340b, 0x2e060e05, 0x154006ad, 0x0e2e3004,   // ps.ur.ku_542 is.de.fo_333  de.lb.un_643 uz.fo.is_332 
  // [14170]
  0x2e1206ee, 0x3b361d04, 0x06000e1a, 0x15516b02,   // de.hu.fo_422 la.gn.so_332  is.de.un_760 ceb.kl.un_222 
  0x0d00210c, 0x1b1731a0, 0x35003902, 0x0437150c,   // jw.cs.un_530 az.sr.tr_322  br.zu.un_220 un.ba.ru_543 
  0x554a35ac, 0x46002407, 0x35230708, 0x34733555,   // zu.yo.rw_632 eo.qu.un_420  bg.ky.tg_443 zu.ny.xh_442 
  0x3735fe07, 0x482338a9, 0x370a110c, 0x595535a9,   // tlh.zu.st_432 tk.ky.tt_544  ro.mk.ba_543 zu.rw.rn_544 
  // [14180]
  0x17080aac, 0x48080708, 0xfe00730d, 0x6400fe0d,   // mk.uk.sr_632 bg.uk.tt_443  ny.tlh.un_540 tlh.lg.un_540 
  0x48102507, 0x48443804, 0xfe00730c, 0x48234405,   // mn.be.tt_432 tk.kk.tt_332  ny.tlh.un_530 kk.ky.tt_333 
  0x4500fe12, 0x1b063814, 0x253530af, 0x15003607,   // tlh.ln.un_640 tk.de.tr_666  uz.tg.mn_655 gn.un.un_420 
  0x4632170d, 0x13002217, 0x37480412, 0x3723440b,   // sr.bs.qu_554 oc.et.un_730  ru.tt.ba_654 kk.ky.ba_542 
  // [14190]
  0x3035385a, 0x462c0904, 0x07480aa0, 0x3031485a,   // tk.tg.uz_553 pl.fy.qu_332  mk.tt.bg_322 tt.az.uz_553 
  0x08004807, 0x2e0e02ad, 0x473078a7, 0x20004611,   // tt.uk.un_420 da.is.fo_643  ve.uz.sn_532 qu.sq.un_630 
  0x2a6458af, 0x150c0ea0, 0x3000020d, 0x02000e07,   // om.lg.mt_655 is.sv.un_322  da.uz.un_540 is.da.un_420 
  0x02004d0e, 0x0e0cfca0, 0x300119a6, 0x5e001919,   // aa.da.un_550 zzp.sv.is_322  gl.en.uz_521 gl.ts.un_750 
  // [141a0]
  0x2e330e13, 0x25004c21, 0x5e001905, 0x20122e0c,   // is.nn.fo_665 wo.eu.un_860  gl.ts.un_330 fo.hu.sq_543 
  0x20000e07, 0x08125dee, 0x51421f0c, 0x544f51a9,   // is.sq.un_420 ss.hu.no_422  cy.co.kl_543 kl.bi.ik_544 
  0x0e332eec, 0x33080c60, 0x43005108, 0x2e0e200c,   // fo.nn.is_644 sv.no.nn_664  kl.ie.un_430 sq.is.fo_543 
  0x3e5a1d0c, 0x3e4e54a4, 0x40060c12, 0x0c000307,   // la.sm.rm_543 ik.ay.rm_433  sv.de.lb_654 nl.sv.un_420 
  // [141b0]
  0x58133013, 0x6b3e7913, 0x2d162908, 0x255128a0,   // uz.et.om_665 war.rm.ceb_665  sl.hr.sk_443 sw.kl.eu_322 
  0x520e4e0c, 0x1e1c42a4, 0x354211ad, 0x3e421d12,   // ay.is.ha_543 co.id.ms_433  ro.co.zu_643 la.co.rm_654 
  0x286473ad, 0x19205ea7, 0x5100540e, 0x131a51ec,   // ny.lg.sw_643 ts.sq.gl_532  ik.kl.un_550 kl.tl.et_644 
  0x64605212, 0x42073e0d, 0x2b003e0d, 0x2f11300c,   // ha.vo.lg_654 rm.it.co_554  rm.vi.un_540 uz.ro.su_543 
  // [141c0]
  0x42431d0c, 0x1d002f0e, 0x0d203b07, 0x11001d1b,   // la.ie.co_543 su.la.un_550  so.sq.cs_432 la.ro.un_770 
  0x604c2804, 0x0e2e200b, 0x0745420b, 0x0e202eaf,   // sw.wo.vo_332 sq.fo.is_542  co.ln.it_542 fo.sq.is_655 
  0x1e1a3804, 0x0312355a, 0x1b2825ee, 0x11423e11,   // tk.tl.ms_332 zu.hu.nl_553  eu.sw.tr_422 rm.co.ro_653 
  0x1a00540d, 0x1c4c52ad, 0x60030205, 0x285450a4,   // ik.tl.un_540 ha.wo.id_643  da.nl.vo_333 fj.ik.sw_433 
  // [141d0]
  0x3e00110c, 0x122e2007, 0x6b1d11a7, 0x03670c0c,   // ro.rm.un_530 sq.fo.hu_432  ro.la.ceb_532 sv.ak.nl_543 
  0x04005108, 0x060a22ad, 0x0246510c, 0x5a5c4902,   // kl.fi.un_430 oc.pt.de_643  kl.qu.da_543 to.sa.sm_222 
  0x25005111, 0x2b1a79a0, 0x1d512f0c, 0x103e110c,   // kl.eu.un_630 war.tl.vi_322  su.kl.la_543 ro.rm.lt_543 
  0x164b6a0c, 0x4b001d19, 0x32291007, 0x48305155,   // haw.mi.hr_543 la.mi.un_750  lt.sl.bs_432 kl.uz.tt_442 
  // [141e0]
  0x52004a07, 0x456952ad, 0x3b044955, 0x0a04175a,   // yo.ha.un_420 ha.mfe.ln_643  to.fi.so_442 sr.ru.mk_553 
  0x0410110c, 0x18531902, 0x0a0407a6, 0x28003419,   // ro.be.ru_543 gl.ht.ga_222  bg.ru.mk_521 ps.sd.un_750 
  0x17080aa9, 0x05501ba4, 0x0f001802, 0x0309510c,   // mk.uk.sr_544 tr.fj.fr_433  ga.lv.un_220 kl.pl.nl_543 
  0x3c003b11, 0x49736404, 0x27003004, 0x302d0605,   // ks.ug.un_630 lg.ny.to_332  uz.gd.un_320 de.sk.uz_333 
  // [141f0]
  0x0c0e0802, 0x2d095107, 0x2830210d, 0x64680407,   // no.is.sv_222 kl.pl.sk_432  fa.uz.sd_554 fi.ig.lg_432 
  0x220b60ee, 0x2e080e04, 0x07002505, 0x093308ad,   // vo.es.oc_422 is.no.fo_332  mn.bg.un_330 no.nn.pl_643 
  0x0e650c04, 0x023f035a, 0x30002912, 0x0d293008,   // sv.gv.is_332 nl.af.da_553  sl.uz.un_640 uz.sl.cs_443 
  0x3f3b54ee, 0x390c200c, 0x6b002807, 0x022e3308,   // ik.so.af_422 sq.sv.br_543  sw.ceb.un_420 nn.fo.da_443 
  // [14200]
  0x44302512, 0x38130608, 0x10000835, 0x170708ad,   // mn.uz.kk_654 de.et.tk_443  uk.be.un_A90 uk.bg.sr_643 
  0x4800232b, 0x04003c04, 0x23303604, 0x183023af,   // ky.tt.un_980 ug.ru.un_320  ab.uz.ky_332 ky.uz.ar_655 
  0x4407110c, 0x10081504, 0x0a173704, 0x3c003d0b,   // ro.bg.kk_543 un.uk.be_332  ba.sr.mk_332 ku.ug.un_520 
  0x600c4eec, 0x35041704, 0x28342155, 0x12025404,   // ay.sv.vo_644 sr.ru.tg_332  fa.ps.sd_442 ik.da.hu_332 
  // [14210]
  0x10080702, 0x35020ca0, 0x15173655, 0x254c1204,   // bg.uk.be_222 sv.da.zu_322  ab.sr.un_442 hu.wo.eu_332 
  0x603f0308, 0x3e001704, 0x484411ad, 0x0f5110ee,   // nl.af.vo_443 sr.rm.un_320  ro.kk.tt_643 lt.kl.lv_422 
  0x1e001804, 0x211c1204, 0x1216400c, 0x0300120d,   // ga.ms.un_320 hu.id.jw_332  lb.hr.hu_543 hu.nl.un_540 
  0x12032011, 0x03006508, 0x15001302, 0x52794a0c,   // sq.nl.hu_653 gv.nl.un_430  et.un.un_220 yo.war.ha_543 
  // [14220]
  0x0c2847ee, 0x02005207, 0x49005802, 0x4a3867a9,   // sn.sw.sv_422 ha.da.un_420  om.to.un_220 ak.tk.yo_544 
  0x27001833, 0x07fc26a4, 0x4a002513, 0x1d3907a7,   // ga.gd.un_A70 ia.zzp.it_433  eu.yo.un_650 it.br.la_532 
  0x5cfe6b0c, 0x3b004904, 0x30002104, 0x065703a7,   // ceb.tlh.sa_543 to.so.un_320  jw.uz.un_320 nl.na.de_532 
  0x473b27a0, 0x0200210b, 0x20170304, 0x386557ee,   // gd.so.sn_322 jw.da.un_520  nl.sr.sq_332 na.gv.tk_422 
  // [14230]
  0x5e003913, 0x182035ee, 0x78004713, 0x25002207,   // br.ts.un_650 zu.sq.ga_422  sn.ve.un_650 oc.eu.un_420 
  0x79272b07, 0x0663fa07, 0x40500602, 0x47305e09,   // vi.gd.war_432 nr.sco.de_432  de.fj.lb_222 ts.uz.sn_444 
  0x070430ec, 0x5402040c, 0x02001312, 0x13470404,   // uz.ru.bg_644 fi.da.ik_543  et.da.un_640 fi.sn.et_332 
  0x18000805, 0x133f0412, 0x5a002407, 0x582f4d55,   // no.ga.un_330 fi.af.et_654  eo.sm.un_420 aa.su.om_442 
  // [14240]
  0x47003704, 0x03243f0c, 0x30025ea0, 0x03000711,   // st.sn.un_320 af.eo.nl_543  ts.da.uz_322 it.nl.un_630 
  0x2a063e04, 0x644c02a7, 0x3d341807, 0x100f04a0,   // rm.de.mt_332 da.wo.lg_532  ar.ps.ku_432 fi.lv.lt_322 
  0x13584c04, 0x0c000f08, 0x30000c18, 0x233010a0,   // wo.om.et_332 lv.sv.un_430  sv.uz.un_740 be.uz.ky_322 
  0x1c005c29, 0x37003904, 0x330c6e04, 0x483038a7,   // sa.mr.un_960 br.st.un_320  hmn.sv.nn_332 tk.uz.tt_532 
  // [14250]
  0x0e2f2ea9, 0x532d0d04, 0x49003f04, 0x370704a0,   // fo.su.is_544 cs.sk.ht_332  af.to.un_320 ru.bg.ba_322 
  0x12383e07, 0x1f002904, 0x07001212, 0x07005302,   // rm.tk.hu_432 sl.cy.un_320  hu.it.un_640 ht.it.un_220 
  0x15374809, 0x42073308, 0x052969ee, 0x301015ee,   // tt.ba.un_444 nn.it.co_443  mfe.sl.fr_422 un.be.uz_422 
  0x3b5402a4, 0x3b5c1e04, 0x545c46af, 0x2d124c04,   // da.ik.so_433 ms.sa.so_332  qu.sa.ik_655 wo.hu.sk_332 
  // [14260]
  0x024654a4, 0x35344f07, 0x46004d08, 0x1c3047ee,   // ik.qu.da_433 bi.xh.zu_432  aa.qu.un_430 sn.uz.id_422 
  0x4022060c, 0x5c21130c, 0x1e1c510e, 0x56212f0c,   // de.oc.lb_543 et.jw.sa_543  kl.id.ms_555 su.jw.mg_543 
  0x636003a0, 0x566229a4, 0x1d341907, 0x260b2f08,   // nl.vo.sco_322 sl.kha.mg_433  gl.xh.la_432 su.es.ia_443 
  0x13002920, 0x2b342507, 0x3b734607, 0x12005607,   // sl.et.un_850 eu.xh.vi_432  qu.ny.so_432 mg.hu.un_420 
  // [14270]
  0x5e2a2502, 0x1329110c, 0x595755ec, 0x30154404,   // eu.mt.ts_222 ro.sl.et_543  rw.na.rn_644 kk.uz.un_320 
  0x523446ec, 0x19580b5a, 0x025954a4, 0x0e2e2507,   // qu.xh.ha_644 es.om.gl_553  ik.rn.da_433 eu.fo.is_432 
  0x044613a7, 0x2a46510d, 0x483707a0, 0x4d00511a,   // et.qu.fi_532 kl.qu.mt_554  bg.ba.tt_322 kl.aa.un_760 
  0x3b003f05, 0x64000907, 0x3b3f4da0, 0x5d355c05,   // af.so.un_330 pl.lg.un_420  aa.af.so_322 sa.zu.ss_333 
  // [14280]
  0x642546a0, 0x3e002212, 0x523b460c, 0x351e28a4,   // qu.eu.lg_322 oc.rm.un_640  qu.so.ha_543 sw.ms.zu_433 
  0x40000618, 0x0f0413ad, 0x354c3407, 0x3d283407,   // de.lb.un_740 et.fi.lv_643  xh.wo.zu_432 ps.sd.ku_432 
  0x2f301ea9, 0x25005e07, 0x15383005, 0x3b4651a0,   // ms.uz.su_544 ts.eu.un_420  uz.tk.un_333 kl.qu.so_322 
  0x03004612, 0x1b0e54ad, 0x07253cad, 0x271d1111,   // qu.nl.un_640 ik.is.tr_643  ug.mn.bg_643 ro.la.gd_653 
  // [14290]
  0x79463fad, 0x2e480c08, 0x40060111, 0x6013580d,   // af.qu.war_643 sv.tt.fo_443  en.de.lb_653 om.et.vo_554 
  0x2a600304, 0x1100560d, 0x25001314, 0x45137313,   // nl.vo.mt_332 mg.ro.un_540  et.eu.un_660 ny.et.ln_665 
  0x691b4ca9, 0x49003507, 0x05003e22, 0x29005e04,   // wo.tr.mfe_544 zu.to.un_420  rm.fr.un_870 ts.sl.un_320 
  0x3b184c60, 0x551f73a4, 0x69007314, 0x321e0304,   // wo.ga.so_664 ny.cy.rw_433  ny.mfe.un_660 nl.ms.bs_332 
  // [142a0]
  0x223b190c, 0x45005708, 0xfe005713, 0x69004f1b,   // gl.so.oc_543 na.ln.un_430  na.tlh.un_650 bi.mfe.un_770 
  0x4a020d07, 0x1f22070c, 0x30313814, 0x103829ec,   // cs.da.yo_432 it.oc.cy_543  tk.az.uz_666 sl.tk.lt_644 
  0x2b00110d, 0x4830fe08, 0x3f033eaf, 0x2000550d,   // ro.vi.un_540 tlh.uz.tt_443  rm.nl.af_655 rw.sq.un_540 
  0x553859af, 0x55fe7313, 0x20595508, 0x07363cec,   // rn.tk.rw_655 ny.tlh.rw_665  rw.rn.sq_443 ug.ab.bg_644 
  // [142b0]
  0xfe4d2a0c, 0x79003b12, 0x352d1705, 0x1a006b0b,   // mt.aa.tlh_543 so.war.un_640  sr.sk.zu_333 ceb.tl.un_520 
  0xfe007313, 0x20105504, 0x556473ad, 0x27731fad,   // ny.tlh.un_650 rw.lt.sq_332  ny.lg.rw_643 cy.ny.gd_643 
  0x6473570c, 0x36253005, 0x283b1302, 0x3428125a,   // na.ny.lg_543 uz.mn.ab_333  et.so.sw_222 ur.sd.ps_553 
  0x3bfc5804, 0x46001902, 0x20004a08, 0x190a1f05,   // om.zzp.so_332 gl.qu.un_220  yo.sq.un_430 cy.pt.gl_333 
  // [142c0]
  0x291002a0, 0x55642802, 0x125553a7, 0x442311ec,   // da.lt.sl_322 sw.lg.rw_222  ht.rw.hu_532 ro.ky.kk_644 
  0x1252040c, 0x59551c07, 0x46002f19, 0x1c2f21ee,   // fi.ha.hu_543 id.rw.rn_432  su.qu.un_750 jw.su.id_422 
  0x52004629, 0x283d3b08, 0x3f002f08, 0x1c00fe0c,   // qu.ha.un_960 ks.ku.sd_443  su.af.un_430 tlh.id.un_530 
  0x5c4b0fac, 0x2b004c07, 0x0100600b, 0x3f2f2104,   // lv.mi.sa_632 wo.vi.un_420  vo.en.un_520 jw.su.af_332 
  // [142d0]
  0x4a002a21, 0x1e1c52ee, 0x1e4cfea0, 0x64304dec,   // mt.yo.un_860 ha.id.ms_422  tlh.wo.ms_322 aa.uz.lg_644 
  0x3b004c0b, 0x090d2f05, 0x4c004609, 0x521a5804,   // wo.so.un_520 su.cs.pl_333  qu.wo.un_440 om.tl.ha_332 
  0x4a002a0d, 0x1c2179a9, 0x3c3610af, 0x4900510e,   // mt.yo.un_540 war.jw.id_544  be.ab.ug_655 kl.to.un_550 
  0x4c002202, 0x05114d13, 0x3d1823ad, 0x3b46520c,   // oc.wo.un_220 aa.ro.fr_665  ky.ar.ku_643 ha.qu.so_543 
  // [142e0]
  0x0a0411a4, 0x12343bad, 0x3b0d2aee, 0x44002335,   // ro.ru.mk_433 ks.ps.ur_643  mt.cs.so_422 ky.kk.un_A90 
  0x53003707, 0x17081008, 0x2a000808, 0x3b31300c,   // st.ht.un_420 be.uk.sr_443  no.mt.un_430 uz.az.so_543 
  0x20462a55, 0x69000808, 0x2024380c, 0x53005c14,   // mt.qu.sq_442 no.mfe.un_430  tk.eo.sq_543 sa.ht.un_660 
  0x463b10ad, 0x12002a07, 0x2e0e06a4, 0x1b403eee,   // lt.so.qu_643 mt.hu.un_420  de.is.fo_433 rm.lb.tr_422 
  // [142f0]
  0x131c0d0c, 0x252344a7, 0x021d0c05, 0x18650212,   // ne.mr.bh_543 kk.ky.mn_532  sv.la.da_333 da.gv.ga_654 
  0x2e0e02ee, 0x1b003e07, 0x35252308, 0xfc30fea0,   // da.is.fo_422 rm.tr.un_420  ky.mn.tg_443 tlh.uz.zzp_322 
  0x6b62fe07, 0x2d000a08, 0x06123e0d, 0x0f000919,   // tlh.kha.ceb_432 pt.sk.un_430  rm.hu.de_554 pl.lv.un_750 
  0x0c000e1a, 0x37021807, 0x33004202, 0x34042da4,   // is.sv.un_760 ga.da.st_432  co.nn.un_220 sk.fi.xh_433 
  // [14300]
  0x40fe62a7, 0x21462c07, 0x021c610c, 0x0a153604,   // kha.tlh.lb_532 fy.qu.jw_432  za.id.da_543 ab.mk.un_320 
  0x2b5c1c0c, 0x32353455, 0x5d1b59ee, 0x2567590c,   // id.sa.vi_543 xh.zu.bs_442  rn.tr.ss_422 rn.ak.eu_543 
  0x23003022, 0x463b340c, 0x352e40ad, 0x2e2a24a4,   // uz.ky.un_870 xh.so.qu_543  lb.fo.zu_643 eo.mt.fo_433 
  0x300417ee, 0x231e1c0c, 0x402c3f05, 0x122a64a0,   // sr.ru.uz_422 id.ms.ca_543  af.fy.lb_333 lg.mt.hu_322 
  // [14310]
  0x3217120e, 0x6b631dec, 0x122834a4, 0x372348ad,   // hu.sr.bs_555 la.sco.ceb_644  ps.sd.ur_433 tt.ky.ba_643 
  0x1d0501a0, 0x23013ea0, 0x0e2e5da0, 0x1d00691a,   // en.fr.la_322 rm.en.ca_322  ss.fo.is_322 mfe.la.un_760 
  0x3c2510a4, 0x044837ee, 0x3534300c, 0x36373c05,   // be.mn.ug_433 ba.tt.ru_422  uz.xh.zu_543 ug.ba.ab_333 
  0x02006213, 0x10170a08, 0x2f006b0c, 0x04074807,   // kha.da.un_650 mk.sr.be_443  ceb.su.un_530 tt.bg.ru_432 
  // [14320]
  0x043515a0, 0x0c1d190b, 0x43631d04, 0x266001a4,   // un.tg.ru_322 gl.la.sv_542  la.sco.ie_332 en.vo.ia_433 
  0x042336ac, 0x12005104, 0x1200511a, 0x28213ba7,   // ab.ky.ru_632 kl.hu.un_320  kl.hu.un_760 ks.fa.sd_532 
  0x386a02af, 0x101508ee, 0x510436a0, 0x37456a5a,   // da.haw.tk_655 uk.be.un_420  gn.fi.kl_322 haw.ln.st_553 
  0x64340207, 0x58000904, 0x1b00fc02, 0x255c0204,   // da.xh.lg_432 pl.om.un_320  zzp.tr.un_220 da.sa.eu_332 
  // [14330]
  0x040737a4, 0x0c565807, 0x3807080c, 0x5c3035a0,   // ba.bg.ru_433 om.mg.sv_432  uk.bg.tk_543 tg.uz.sa_322 
  0x3900200e, 0x022e47ad, 0x0a563511, 0x32000d0d,   // sq.br.un_550 sn.fo.da_643  zu.mg.pt_653 cs.bs.un_540 
  0x32650b02, 0x495b0208, 0x6500300c, 0x21292004,   // es.gv.bs_222 da.sg.to_443  uz.gv.un_530 sq.sl.jw_332 
  0x20293607, 0x36002907, 0x392d0d08, 0x3e004c02,   // gn.sl.sq_432 sl.gn.un_420  cs.sk.br_443 wo.rm.un_220 
  // [14340]
  0x1c002a07, 0x22112fa0, 0x24001008, 0x1c000212,   // mt.id.un_420 su.ro.oc_322  lt.eo.un_430 da.id.un_640 
  0x0500220b, 0x6a004b1a, 0x0200640d, 0x061b1255,   // oc.fr.un_520 mi.haw.un_760  lg.da.un_540 hu.tr.de_442 
  0x4246110c, 0x18213005, 0x33220aa9, 0x1f5d3504,   // ro.qu.co_543 uz.fa.ar_333  pt.oc.nn_544 zu.ss.cy_332 
  0x2b2e7904, 0x34355d55, 0x04002b07, 0x795e5d0c,   // war.fo.vi_332 ss.zu.xh_442  vi.fi.un_420 ss.ts.war_543 
  // [14350]
  0x19360bee, 0x0a002c05, 0x220a47ec, 0x181228ad,   // es.gn.gl_422 fy.pt.un_330  sn.pt.oc_644 sd.ur.ar_643 
  0x0a226107, 0x0708040b, 0x080c33a7, 0x170a30a0,   // za.oc.pt_432 ru.uk.bg_542  nn.sv.no_532 uz.mk.sr_322 
  0x5b006b1a, 0x682247ec, 0x02670aa4, 0x0a793507,   // ceb.sg.un_760 sn.oc.ig_644  pt.ak.da_433 zu.war.pt_432 
  0x07233004, 0x0a4722ec, 0x02134dee, 0x27184d0b,   // uz.ky.bg_332 oc.sn.pt_644  aa.et.da_422 aa.ga.gd_542 
  // [14360]
  0x17003619, 0x481023a9, 0xfe062012, 0x1b384d08,   // ab.sr.un_750 ky.be.tt_544  sq.de.tlh_654 aa.tk.tr_443 
  0x20002d1a, 0x212f1e07, 0x0c040604, 0x210269a4,   // sk.sq.un_760 ms.su.jw_432  de.fi.sv_332 mfe.da.jw_433 
  0x2d6413a4, 0x130210a4, 0x23192205, 0x2d5e6e04,   // et.lg.sk_433 lt.da.et_433  oc.gl.ca_333 hmn.ts.sk_332 
  0x20221807, 0x2c003319, 0x25002102, 0x202c330d,   // ga.oc.sq_432 nn.fy.un_750  jw.eu.un_220 nn.fy.sq_554 
  // [14370]
  0x644cfe02, 0x131b2008, 0x303544a0, 0x321648a4,   // tlh.wo.lg_222 sq.tr.et_443  kk.tg.uz_322 tt.hr.bs_433 
  0x3420fea7, 0x39610e11, 0x343d28a9, 0x32175805,   // tlh.sq.xh_532 is.za.br_653  sd.ku.ps_544 om.sr.bs_333 
  0x0a3011a7, 0x2a0e1d0c, 0x2e5c42a4, 0x153c360b,   // ro.uz.mk_532 la.is.mt_543  co.sa.fo_433 ab.ug.un_542 
  0x5c6b1a07, 0x0a100708, 0x790742a0, 0x2e050e0c,   // tl.ceb.sa_432 bg.be.mk_443  co.it.war_322 is.fr.fo_543 
  // [14380]
  0x232818ec, 0x33202c12, 0x330e360c, 0x232e0e07,   // ar.sd.ky_644 fy.sq.nn_654  gn.is.nn_543 is.fo.ca_432 
  0x2a6b1aa4, 0x2e0c3ea4, 0x3b006e08, 0x2e330812,   // tl.ceb.mt_433 rm.sv.fo_433  hmn.so.un_430 no.nn.fo_654 
  0xfe001f0d, 0x2f0a4cee, 0x123b21ad, 0x1f004c12,   // cy.tlh.un_540 wo.pt.su_422  fa.ks.ur_643 wo.cy.un_640 
  0x53004c14, 0x3700100e, 0x292d0da0, 0x4c00671b,   // wo.ht.un_660 be.ba.un_550  cs.sk.sl_322 ak.wo.un_770 
  // [14390]
  0x23080404, 0x67534ca4, 0xfe000902, 0x3f2c04ee,   // ru.uk.ky_332 wo.ht.ak_433  pl.tlh.un_220 fi.fy.af_422 
  0x3f001004, 0x3c170409, 0x0a072507, 0x30043507,   // lt.af.un_320 ru.sr.ug_444  mn.bg.mk_432 tg.ru.uz_432 
  0x1b383107, 0x0e4738a0, 0x31481bec, 0x44150408,   // az.tk.tr_432 tk.sn.is_322  tr.tt.az_644 ru.kk.un_430 
  0x35300aa9, 0x342321ac, 0x3f352ead, 0x46006921,   // mk.uz.tg_544 fa.ky.ps_632  fo.zu.af_643 mfe.qu.un_860 
  // [143a0]
  0x32177309, 0x1000440b, 0x56002f11, 0x0956360c,   // ny.sr.bs_444 kk.be.un_520  su.mg.un_630 gn.mg.pl_543 
  0x09100d08, 0x3f4610ad, 0x2c044608, 0x021c4608,   // cs.lt.pl_443 lt.qu.af_643  qu.fi.fy_443 qu.id.da_443 
  0x13006305, 0x2f6379a4, 0x2d005207, 0x3c004435,   // sco.et.un_330 war.sco.su_433  ha.sk.un_420 kk.ug.un_A90 
  0x2f002507, 0x1800510c, 0x2e00330d, 0x335636a0,   // eu.su.un_420 kl.ga.un_530  nn.fo.un_540 gn.mg.nn_322 
  // [143b0]
  0x560936af, 0x496b1dee, 0x1600350c, 0x0c0260ee,   // gn.pl.mg_655 la.ceb.to_422  zu.hr.un_530 vo.da.sv_422 
  0x3f034e0c, 0x465d105a, 0x461001a0, 0x4d0464a4,   // ay.nl.af_543 lt.ss.qu_553  en.lt.qu_322 lg.fi.aa_433 
  0x3f576307, 0x2b6b79ee, 0x2e25065a, 0x0a261007,   // sco.na.af_432 war.ceb.vi_422  de.eu.fo_553 lt.ia.pt_432 
  0x28001002, 0x043e10ec, 0x150206ad, 0x3909460d,   // lt.sw.un_220 lt.rm.fi_644  de.da.un_643 qu.pl.br_554 
  // [143c0]
  0x063b400c, 0x391d3b02, 0x12004307, 0x3b002b04,   // lb.so.de_543 so.la.br_222  ie.hu.un_420 vi.so.un_320 
  0x3e2623a4, 0x37234405, 0x3b1b2b08, 0x041009a7,   // ca.ia.rm_433 kk.ky.ba_333  vi.tr.so_443 pl.lt.fi_532 
  0x31003f04, 0x07421dec, 0x5238250c, 0x1e002509,   // af.az.un_320 la.co.it_644  eu.tk.ha_543 eu.ms.un_440 
  0x041310af, 0x3e106304, 0x484f33a4, 0x25101a0c,   // lt.et.fi_655 sco.lt.rm_332  nn.bi.tt_433 tl.lt.eu_543 
  // [143d0]
  0x4207530c, 0x651b4a5a, 0x2a523807, 0x5f1827a9,   // ht.it.co_543 yo.tr.gv_553  tk.ha.mt_432 gd.ga.tn_544 
  0x28025ea7, 0x6b3e24a9, 0x35370da4, 0x1b4801a0,   // ts.da.sw_532 eo.rm.ceb_544  cs.st.zu_433 en.tt.tr_322 
  0x172902a7, 0x59005508, 0x5e630d0d, 0x0c06485a,   // da.sl.sr_532 rw.rn.un_430  cs.sco.ts_554 tt.de.sv_553 
  0x12591805, 0x070444ec, 0x504d01a4, 0x0e005723,   // ga.rn.hu_333 kk.ru.bg_644  en.aa.fj_433 na.is.un_880 
  // [143e0]
  0x05150112, 0x761869a4, 0x1d2f6b0c, 0x2322010c,   // en.fr.un_640 mfe.ga.crs_433  ceb.su.la_543 en.oc.ca_543 
  0x595530af, 0x3b005e0c, 0x38251b08, 0x381b1511,   // uz.rw.rn_655 ts.so.un_530  tr.eu.tk_443 un.tr.tk_653 
  0x3b4d4c12, 0x463715ec, 0x541051ad, 0x483515a4,   // wo.aa.so_654 un.st.qu_644  kl.lt.ik_643 un.tg.tt_433 
  0x651b48a9, 0x23071da4, 0x6525170c, 0x21095507,   // tt.tr.gv_544 la.it.ca_433  sr.eu.gv_543 rw.pl.jw_432 
  // [143f0]
  0x0506010c, 0x2100230b, 0x28631da9, 0x1b000a04,   // en.de.fr_543 ky.fa.un_520  la.sco.sw_544 pt.tr.un_320 
  0x302335a6, 0x2500190c, 0x2f1c2104, 0x07353007,   // tg.ky.uz_521 gl.eu.un_530  jw.id.su_332 uz.tg.bg_432 
  0x2500381a, 0x30153511, 0xfc302ba0, 0x53306012,   // tk.mn.un_760 tg.uz.un_630  vi.uz.zzp_322 vo.uz.ht_654 
  0x23fe4aa0, 0x2030fe0d, 0x3001fe04, 0x163037ee,   // yo.tlh.ca_322 tlh.uz.sq_554  tlh.en.uz_332 st.uz.hr_422 
  
  // [14400]
  0x1f002805, 0x24001602, 0x31301bee, 0x25171007,   // sw.cy.un_330 hr.eo.un_220  tr.uz.az_422 be.sr.mn_432 
  0x32162aa9, 0x1b30fe04, 0x190bfeee, 0x330efe55,   // mt.hr.bs_544 tlh.uz.tr_332  tlh.es.gl_422 tlh.is.nn_442 
  0x2e311bee, 0x0817230c, 0x13000a02, 0x47000102,   // tr.az.fo_422 ky.sr.uk_543  pt.et.un_220 en.sn.un_220 
  0x32002207, 0x152206ee, 0x254022a9, 0x063f2512,   // oc.bs.un_420 de.oc.un_422  oc.lb.eu_544 eu.af.de_654 
  // [14410]
  0x183d230b, 0x04350aee, 0x40002508, 0x282522a6,   // ky.ku.ar_542 mk.tg.ru_422  eu.lb.un_430 oc.eu.sw_521 
  0x35070407, 0x2200151a, 0x213b3d0c, 0x40063e55,   // ru.bg.tg_432 un.oc.un_760  ku.ks.fa_543 rm.de.lb_442 
  0x650efc12, 0x3e2522ad, 0x402206ad, 0x3e2756ad,   // zzp.is.gv_654 oc.eu.rm_643  de.oc.lb_643 mg.gd.rm_643 
  0x6e000f09, 0x022c3f0c, 0x0a172302, 0x38003e02,   // lv.hmn.un_440 af.fy.da_543  ky.sr.mk_222 rm.tk.un_220 
  // [14420]
  0x6a374b0c, 0x5e2f1c0c, 0x370249a4, 0x734664ad,   // mi.st.haw_543 id.su.ts_543  to.da.st_433 lg.qu.ny_643 
  0x474037ad, 0x533f0304, 0x5e4728a9, 0x046a5e5a,   // st.lb.sn_643 nl.af.ht_332  sw.sn.ts_544 ts.haw.fi_553 
  0x205e020c, 0x10172907, 0x1e1c50a4, 0x49323402,   // da.ts.sq_543 sl.sr.lt_432  fj.id.ms_433 xh.bs.to_222 
  0x4b001802, 0x376536a0, 0x442348a4, 0x2f0f45ee,   // ga.mi.un_220 gn.gv.st_322  tt.ky.kk_433 ln.lv.su_422 
  // [14430]
  0x1c525905, 0x10354812, 0x50522d13, 0x39002804,   // rn.ha.id_333 tt.tg.be_654  sk.ha.fj_665 sw.br.un_320 
  0x28535905, 0x30322dee, 0x530b1112, 0x64000208,   // rn.ht.sw_333 sk.bs.uz_422  ro.es.ht_654 da.lg.un_430 
  0x321739a0, 0x36110ba4, 0x02345e13, 0x285a400c,   // br.sr.bs_322 es.ro.gn_433  ts.xh.da_665 lb.sm.sw_543 
  0x3646020c, 0x53595504, 0x5e343ba4, 0x2f37350d,   // da.qu.gn_543 rw.rn.ht_332  so.xh.ts_433 zu.st.su_554 
  // [14440]
  0x262e57a4, 0x495e5004, 0x094f360c, 0x5e000208,   // na.fo.ia_433 fj.ts.to_332  gn.bi.pl_543 da.ts.un_430 
  0x1c4b0208, 0x672f6a12, 0x2f6521a9, 0x02154d13,   // da.mi.id_443 haw.su.ak_654  jw.gv.su_544 aa.da.un_650 
  0x1d282f07, 0x732f020d, 0x59535511, 0x5e0f020c,   // su.sw.la_432 da.su.ny_554  rw.ht.rn_653 da.lv.ts_543 
  0x1c1f2fad, 0x233035a9, 0x026a4b08, 0x54004d14,   // su.cy.id_643 tg.uz.ky_544  mi.haw.da_443 aa.ik.un_660 
  // [14450]
  0x0450470c, 0x790b6207, 0x025451a9, 0x05002f21,   // sn.fj.fi_543 kha.es.war_432  kl.ik.da_544 su.fr.un_860 
  0x1d002f19, 0x092039a0, 0x171525ad, 0x68521ea0,   // su.la.un_750 br.sq.pl_322  mn.sr.un_630 ms.ha.ig_322 
  0x032c2fee, 0x5c5d4713, 0x55005312, 0x112953a0,   // su.fy.nl_422 sn.ss.sa_665  ht.rw.un_640 ht.sl.ro_322 
  0x0c063813, 0x55002811, 0x550b530c, 0x2f3b470c,   // tk.de.sv_665 sw.rw.un_630  ht.es.rw_543 sn.so.su_543 
  // [14460]
  0x530b110c, 0x5d3e2f05, 0x38003714, 0x115336a0,   // ro.es.ht_543 su.rm.ss_333  ba.tk.un_660 gn.ht.ro_322 
  0x4700522a, 0x3f2f0314, 0x2d150d0c, 0x02062fa4,   // ha.sn.un_970 nl.su.af_666  cs.sk.un_530 su.de.da_433 
  0x34212fa0, 0x46007513, 0x211f2fa4, 0x1d6a5a60,   // su.jw.xh_322 nso.qu.un_650  su.cy.jw_433 sm.haw.la_664 
  0x5c6410a7, 0x1f003e08, 0xfc3647a7, 0x27001d08,   // lt.lg.sa_532 rm.cy.un_430  sn.gn.zzp_532 la.gd.un_430 
  // [14470]
  0x646155ec, 0x5c00210c, 0x646b38a0, 0x5564340c,   // rw.za.lg_644 jw.sa.un_530  tk.ceb.lg_322 xh.lg.rw_543 
  0x2b00050c, 0x3000360b, 0x022e0808, 0x38005502,   // fr.vi.un_530 ab.uz.un_520  no.fo.da_443 rw.tk.un_220 
  0x5d1253ad, 0x3525380c, 0x48345302, 0x21234402,   // ht.hu.ss_643 tk.mn.tg_543  ht.xh.tt_222 kk.ky.fa_222 
  0x47641da4, 0x330803a9, 0x56005908, 0x0f005c11,   // la.lg.sn_433 nl.no.nn_544  rn.mg.un_430 sa.lv.un_630 
  // [14480]
  0x0a003c05, 0x4b496a08, 0x6a000f33, 0x0708110c,   // ug.mk.un_330 haw.to.mi_443  lv.haw.un_A70 ro.uk.bg_543 
  0x03330804, 0x495c4bad, 0x34002820, 0x100437a7,   // no.nn.nl_332 mi.sa.to_643  sd.ps.un_850 ba.ru.be_532 
  0x35fc1504, 0x6a004b35, 0x0723250c, 0x395a490c,   // un.zzp.zu_332 mi.haw.un_A90  mn.ky.bg_543 to.sm.br_543 
  0x6a004b2a, 0x4b000f2c, 0x2c09150d, 0x2e0e080d,   // mi.haw.un_970 lv.mi.un_990  un.pl.fy_554 no.is.fo_554 
  // [14490]
  0x654009a4, 0x5c1309ec, 0x272e33ee, 0x08000307,   // pl.lb.gv_433 hi.bh.sa_644  nn.fo.gd_422 nl.no.un_420 
  0x12212855, 0x092a06a7, 0x655701ee, 0x08022eac,   // sd.fa.ur_442 de.mt.pl_532  en.na.gv_422 fo.da.no_632 
  0x1c2ffe0c, 0x06355502, 0x33082ea9, 0x2d0d010c,   // tlh.su.id_543 rw.zu.de_222  fo.no.nn_544 en.cs.sk_543 
  0x011536a7, 0x330e2e09, 0x36464caf, 0x2e023302,   // gn.en.un_520 fo.is.nn_444  wo.qu.gn_655 nn.da.fo_222 
  // [144a0]
  0x335d340d, 0x0e2847ad, 0x2e030c04, 0x1000240c,   // xh.ss.nn_554 sn.sw.is_643  sv.nl.fo_332 eo.lt.un_530 
  0x084804a6, 0x3c003409, 0x5300760d, 0x280e47a4,   // ru.tt.uk_521 ps.ug.un_440  crs.ht.un_540 sn.is.sw_433 
  0x1e1c20a4, 0x5e004709, 0x3900790d, 0x213d230c,   // sq.id.ms_433 sn.ts.un_440  war.br.un_540 ky.ku.fa_543 
  0x5104670c, 0x6542070e, 0x1a645504, 0x47002f04,   // ak.fi.kl_543 it.co.gv_555  rw.lg.tl_332 su.sn.un_320 
  // [144b0]
  0x271833a4, 0x48003308, 0x09202d0c, 0x03153fa9,   // nn.ga.gd_433 nn.tt.un_430  sk.sq.pl_543 af.nl.un_540 
  0x0f11300b, 0x1b4858a7, 0x0500330d, 0x4c11670d,   // uz.ro.lv_542 om.tt.tr_532  nn.fr.un_540 ak.ro.wo_554 
  0x3f693b0c, 0x4c2d4d07, 0x044825ee, 0x65000921,   // so.mfe.af_543 aa.sk.wo_432  mn.tt.ru_422 pl.gv.un_860 
  0x62292d0c, 0x5740110c, 0x481d5807, 0x2e0e38a7,   // sk.sl.kha_543 ro.lb.na_543  om.la.tt_432 tk.is.fo_532 
  // [144c0]
  0x253815ac, 0x37444808, 0x4a53390c, 0x53002c02,   // un.tk.mn_632 tt.kk.ba_443  br.ht.yo_543 fy.ht.un_220 
  0x0d406307, 0x21654907, 0x40532ca0, 0x211230a6,   // sco.lb.cs_432 to.gv.jw_432  fy.ht.lb_322 uz.ur.fa_521 
  0x2c270502, 0x2d2305ad, 0x4a39630c, 0x53006313,   // fr.gd.fy_222 fr.ca.sk_643  sco.br.yo_543 sco.ht.un_650 
  0x40006320, 0x375f02af, 0x3e0704a4, 0x3308020b,   // sco.lb.un_850 da.tn.st_655  fi.it.rm_433 da.no.nn_542 
  // [144d0]
  0x05274202, 0x2e0208a6, 0x391d43a0, 0x082e0207,   // co.gd.fr_222 no.da.fo_521  ie.la.br_322 da.fo.no_432 
  0x17001119, 0x03002702, 0x10070a04, 0x15003f02,   // ro.sr.un_750 gd.nl.un_220  mk.bg.be_332 af.un.un_220 
  0x302515af, 0x170437a0, 0x23441808, 0x3200fc19,   // un.mn.uz_655 ba.ru.sr_322  ar.kk.ky_443 zzp.bs.un_750 
  0x37384813, 0x483825a4, 0x06003514, 0x5d00110d,   // tt.tk.ba_665 mn.tk.tt_433  zu.de.un_660 ro.ss.un_540 
  // [144e0]
  0x11492da4, 0x3f006519, 0x37480411, 0x09002d35,   // sk.to.ro_433 gv.af.un_750  ru.tt.ba_653 sk.pl.un_A90 
  0x27000504, 0x65636812, 0x6a090107, 0x0e2e0c07,   // fr.gd.un_320 ig.sco.gv_654  en.pl.haw_432 sv.fo.is_432 
  0x020f3f0c, 0x26432d0c, 0x435a1ea0, 0x05400da4,   // af.lv.da_543 sk.ie.ia_543  ms.sm.ie_322 cs.lb.fr_433 
  0x113f65ad, 0x266809a9, 0x43092d11, 0x1f397604,   // gv.af.ro_643 pl.ig.ia_544  sk.pl.ie_653 crs.br.cy_332 
  // [144f0]
  0x1a6b4704, 0x505c02a7, 0x330873a0, 0x09070da4,   // sn.ceb.tl_332 da.sa.fj_532  ny.no.nn_322 cs.it.pl_433 
  0x536367ad, 0x55000207, 0x67060912, 0x0c1f28a0,   // ak.sco.ht_643 da.rw.un_420  pl.de.ak_654 sw.cy.sv_322 
  0x4311030d, 0x2f001902, 0x69093f12, 0x43090da4,   // nl.ro.ie_554 gl.su.un_220  af.pl.mfe_654 cs.pl.ie_433 
  0x34363ba0, 0x346335a0, 0x0c2e0ea0, 0x05120a04,   // so.gn.xh_322 zu.sco.xh_322  is.fo.sv_322 pt.hu.fr_332 
  // [14500]
  0x153901a0, 0x46003808, 0x1b1a4a13, 0x2c02fe12,   // en.br.un_322 tk.qu.un_430  yo.tl.tr_665 tlh.da.fy_654 
  0xfc2c65af, 0x6bfe1aa9, 0x2540130d, 0x382c1b55,   // gv.fy.zzp_655 tl.tlh.ceb_544  et.lb.eu_554 tr.fy.tk_442 
  0x44212855, 0x00007301, 0x311b1fa9, 0x4a3b510c,   // sd.fa.kk_442 ny.un.un_200  cy.tr.az_544 kl.so.yo_543 
  0x130d1c07, 0x34005812, 0x38611f12, 0x30471ba6,   // mr.ne.bh_432 om.xh.un_640  cy.za.tk_654 tr.sn.uz_521 
  // [14510]
  0x311d190b, 0x38004a0d, 0x523861a6, 0x2e3b1b04,   // gl.la.az_542 yo.tk.un_540  za.tk.ha_521 tr.so.fo_332 
  0x340c190c, 0x481a3814, 0x0600510e, 0x382e0e55,   // gl.sv.xh_543 tk.tl.tt_666  kl.de.un_550 is.fo.tk_442 
  0x73015707, 0x52382504, 0x36000e08, 0x464c3b08,   // na.en.ny_432 eu.tk.ha_332  is.gn.un_430 so.wo.qu_443 
  0x2d0d63af, 0x12002312, 0x1f002e1a, 0x1f003304,   // sco.cs.sk_655 ky.ur.un_640  fo.cy.un_760 nn.cy.un_320 
  // [14520]
  0x443825af, 0x0b1223ec, 0x33022e08, 0x3d182307,   // mn.tk.kk_655 ca.hu.es_644  fo.da.nn_443 ky.ar.ku_432 
  0x352325a7, 0x0444230c, 0x0a174404, 0x11150460,   // mn.ky.tg_532 ky.kk.ru_543  kk.sr.mk_332 ru.ro.un_640 
  0x1304510c, 0x17100a0e, 0x0a0837a0, 0x27183e05,   // kl.fi.et_543 mk.be.sr_555  ba.uk.mk_322 rm.ga.gd_333 
  0x35033f02, 0x24003f04, 0x18515a0b, 0xfc000c07,   // af.nl.zu_222 af.eo.un_320  sm.kl.ga_542 sv.zzp.un_420 
  // [14530]
  0x48373804, 0x0c00fc0c, 0xfc004e13, 0x10170805,   // tk.ba.tt_332 zzp.sv.un_530  ay.zzp.un_650 uk.sr.be_333 
  0x3f006219, 0x046a5a09, 0x303504ee, 0x28182307,   // kha.af.un_750 sm.haw.fi_444  ru.tg.uz_422 ky.ar.sd_432 
  0x080417ac, 0x37251005, 0x17071512, 0x630402a4,   // sr.ru.uk_632 be.mn.ba_333  un.bg.sr_654 da.fi.sco_433 
  0x3e4c0c05, 0x11005821, 0x63005413, 0x421d07a0,   // sv.wo.rm_333 om.ro.un_860  ik.sco.un_650 it.la.co_322 
  // [14540]
  0x634002a4, 0x17004809, 0x48384404, 0x304831af,   // da.lb.sco_433 tt.sr.un_440  kk.tk.tt_332 az.tt.uz_655 
  0x01400207, 0x1b243102, 0x44341807, 0x110a1709,   // da.lb.en_432 az.eo.tr_222  ar.ps.kk_432 sr.mk.ro_444 
  0x42510204, 0x024208a4, 0x3f066302, 0x09110d07,   // da.kl.co_332 no.co.da_433  sco.de.af_222 cs.ro.pl_432 
  0x06002a0d, 0x0c041007, 0x370748a6, 0x64002408,   // mt.de.un_540 lt.fi.sv_432  tt.bg.ba_521 eo.lg.un_430 
  // [14550]
  0x44150411, 0x080c24a7, 0x38001523, 0x65103e0c,   // ru.kk.un_630 eo.sv.no_532  un.tk.un_880 rm.lt.gv_543 
  0x443c3004, 0x2d000d11, 0x1c090dad, 0x48046060,   // uz.ug.kk_332 cs.sk.un_630  ne.hi.mr_643 vo.fi.tt_664 
  0x0613480c, 0x211218ac, 0x04003e0e, 0x0a005f22,   // tt.et.de_543 ar.ur.fa_632  rm.fi.un_550 tn.pt.un_870 
  0x19006112, 0x1a003412, 0x42057607, 0x472873a4,   // za.gl.un_640 xh.tl.un_640  crs.fr.co_432 ny.sw.sn_433 
  // [14560]
  0x22790a0c, 0x2e00121a, 0x640406a0, 0x42071213,   // pt.war.oc_543 hu.fo.un_760  de.fi.lg_322 hu.it.co_665 
  0xfe300d07, 0x492526ad, 0x1a560207, 0x05005a0d,   // cs.uz.tlh_432 ia.eu.to_643  da.mg.tl_432 sm.fr.un_540 
  0x380665ee, 0x656827a9, 0x64325504, 0x390204a7,   // gv.de.tk_422 gd.ig.gv_544  rw.bs.lg_332 fi.da.br_532 
  0x072e42a4, 0x0c19230c, 0x3b364dad, 0x5c275d09,   // co.fo.it_433 ca.gl.sv_543  aa.gn.so_643 ss.gd.sa_444 
  // [14570]
  0x100725ad, 0x6012560c, 0x64002f04, 0x6b074d07,   // mn.bg.be_643 mg.hu.vo_543  su.lg.un_320 aa.it.ceb_432 
  0x0f1034a4, 0x3559fea4, 0x3e064007, 0x042e12ee,   // xh.lt.lv_433 tlh.rn.zu_433  lb.de.rm_432 hu.fo.fi_422 
  0x6e3420a9, 0x021d080c, 0x5a005007, 0x4269070c,   // sq.xh.hmn_544 no.la.da_543  fj.sm.un_420 it.mfe.co_543 
  0x5920550c, 0x67004b14, 0x353418af, 0x02006b04,   // rw.sq.rn_543 mi.ak.un_660  ga.xh.zu_655 ceb.da.un_320 
  // [14580]
  0x0a040d04, 0x2e0e3e11, 0x175e04a4, 0x023f08a4,   // cs.fi.pt_332 rm.is.fo_653  fi.ts.sr_433 no.af.da_433 
  0x5e09fe07, 0x060c63ec, 0x05010605, 0x28183c12,   // tlh.pl.ts_432 sco.sv.de_644  de.en.fr_333 ug.ar.sd_654 
  0x3607100c, 0x480413a0, 0x1e005502, 0x4836440c,   // be.bg.ab_543 et.fi.tt_322  rw.ms.un_220 kk.ab.tt_543 
  0x04131207, 0x560413a4, 0x19000b22, 0x0a441704,   // hu.et.fi_432 et.fi.mg_433  es.gl.un_870 sr.kk.mk_332 
  // [14590]
  0x1c0d13a7, 0x104438a0, 0x52003e07, 0x24021a07,   // bh.ne.mr_532 tk.kk.be_322  rm.ha.un_420 tl.da.eo_432 
  0x02003e08, 0x283c2309, 0x48081004, 0x212f6b07,   // rm.da.un_430 ky.ug.sd_444  be.uk.tt_332 ceb.su.jw_432 
  0x5f1657ee, 0x480735a0, 0x441548ee, 0x44302304,   // na.hr.tn_422 tg.bg.tt_322  tt.kk.un_420 ky.uz.kk_332 
  0x3e08020e, 0x18343ca0, 0x08023eec, 0x33693e0d,   // da.no.rm_555 ug.ps.ar_322  rm.da.no_644 rm.mfe.nn_554 
  // [145a0]
  0x353036ad, 0x25006404, 0x353408a9, 0x44183ca0,   // ab.uz.tg_643 lg.eu.un_320  no.xh.zu_544 ug.ar.kk_322 
  0x29211313, 0x3f4d080c, 0x22fc1d0c, 0x16000312,   // et.jw.sl_665 no.aa.af_543  la.zzp.oc_543 nl.hr.un_640 
  0x2d132912, 0x2c005219, 0x2f026b07, 0x4c003f04,   // sl.et.sk_654 ha.fy.un_750  ceb.da.su_432 af.wo.un_320 
  0xfc3b53a4, 0x3f654cad, 0x156501a0, 0x292d25ec,   // ht.so.zzp_433 wo.gv.af_643  en.gv.un_322 eu.sk.sl_644 
  // [145b0]
  0x3f00360c, 0x034c3f0b, 0x4c3b3fa0, 0x3c4807a4,   // gn.af.un_530 af.wo.nl_542  af.so.wo_322 bg.tt.ug_433 
  0x3e006321, 0x07351504, 0x0f632507, 0x3e006322,   // sco.rm.un_860 un.tg.bg_332  eu.sco.lv_432 sco.rm.un_870 
  0x4b473e07, 0x0e496a08, 0x6a2f0e55, 0x0b4623ee,   // rm.sn.mi_432 haw.to.is_443  is.su.haw_442 ca.qu.es_422 
  0x6a1a4b08, 0x25002f04, 0x2500111b, 0x3f6303ac,   // mi.tl.haw_443 su.eu.un_320  ro.mn.un_770 nl.sco.af_632 
  // [145c0]
  0x062b1d04, 0x6b006a08, 0x0e633ea0, 0x4c4d650c,   // la.vi.de_332 haw.ceb.un_430  rm.sco.is_322 gv.aa.wo_543 
  0x53fc76ec, 0x2f5257a7, 0x6a1d49af, 0x4c3b3fad,   // crs.zzp.ht_644 na.ha.su_532  to.la.haw_655 af.so.wo_643 
  0x761f53af, 0x5f003e08, 0x034c3f04, 0x19071dee,   // ht.cy.crs_655 rm.tn.un_430  af.wo.nl_332 la.it.gl_422 
  0x53766905, 0x1a0e2f04, 0x29090da9, 0x0e004f1b,   // mfe.crs.ht_333 su.is.tl_332  cs.pl.sl_544 bi.is.un_770 
  // [145d0]
  0x633e130d, 0x111e3eee, 0x21183412, 0x4773280c,   // et.rm.sco_554 rm.ms.ro_422  ps.ar.fa_654 sw.ny.sn_543 
  0x4f2f2112, 0x4b545a09, 0x234844ee, 0x47504ba9,   // jw.su.bi_654 sm.ik.mi_444  kk.tt.ky_422 mi.fj.sn_544 
  0x27004907, 0x4b1a6b05, 0x0b124aaf, 0x4d00121b,   // to.gd.un_420 ceb.tl.mi_333  yo.hu.es_655 hu.aa.un_770 
  0x11004905, 0x350a075a, 0x124d0b08, 0x120b4aec,   // to.ro.un_330 bg.mk.tg_553  es.aa.hu_443 yo.es.hu_644 
  // [145e0]
  0x0b001221, 0x2e0e2dad, 0x23124dee, 0x12230b08,   // hu.es.un_860 sk.is.fo_643  aa.hu.ca_422 es.ca.hu_443 
  0x3216095a, 0x2a003802, 0x0b124da4, 0x190b4d55,   // pl.hr.bs_553 tk.mt.un_220  aa.hu.es_433 aa.es.gl_442 
  0x34586507, 0x0f483311, 0x45753708, 0x194a0b0c,   // gv.om.xh_432 nn.tt.lv_653  st.nso.ln_443 es.yo.gl_543 
  0x12190bac, 0x04301505, 0x120b2307, 0x4a120b02,   // es.gl.hu_632 un.uz.ru_333  ca.es.hu_432 es.hu.yo_222 
  // [145f0]
  0x0f002f05, 0x11000405, 0x483525a9, 0x0279290c,   // su.lv.un_330 ru.ro.un_330  mn.tg.tt_544 sl.war.da_543 
  0x30006b0d, 0x3e00230c, 0x23253511, 0x23374414,   // ceb.uz.un_540 ca.rm.un_530  tg.mn.ky_653 kk.ba.ky_666 
  0x53045107, 0x374804a0, 0x10481108, 0x0c003309,   // kl.fi.ht_432 ru.tt.ba_322  ro.tt.be_443 nn.sv.un_440 
  0x2e0e1d04, 0x233548a9, 0x27003f02, 0x0c04620c,   // la.is.fo_332 tt.tg.ky_544  af.gd.un_220 kha.fi.sv_543 
  // [14600]
  0x42052260, 0x27036307, 0x37003c23, 0x2a001319,   // oc.fr.co_664 sco.nl.gd_432  ug.ba.un_880 et.mt.un_750 
  0x0c2033a0, 0x424c3e08, 0x64001f07, 0x0e00020d,   // nn.sq.sv_322 rm.wo.co_443  cy.lg.un_420 da.is.un_540 
  0x0e000219, 0x02002e13, 0x35231504, 0x02060cee,   // da.is.un_750 fo.da.un_650  un.ky.tg_332 sv.de.da_422 
  0x02007907, 0x0c024fee, 0x06004f08, 0x3c353808,   // war.da.un_420 bi.da.sv_422  bi.de.un_430 tk.tg.ug_443 
  // [14610]
  0x793f1a05, 0x57004719, 0x25005d2a, 0x47005d35,   // tl.af.war_333 sn.na.un_750  ss.eu.un_970 ss.sn.un_A90 
  0x48253702, 0x1069605a, 0x02000802, 0x4900671b,   // ba.mn.tt_222 vo.mfe.lt_553  no.da.un_220 ak.to.un_770 
  0x47005d34, 0x40005d0c, 0x0b212f08, 0x061e0e07,   // ss.sn.un_A80 ss.lb.un_530  su.jw.es_443 is.ms.de_432 
  0x0c024aa7, 0x4c00560d, 0x20026008, 0x0e36470c,   // yo.da.sv_532 mg.wo.un_540  vo.da.sq_443 sn.gn.is_543 
  // [14620]
  0x2c33200c, 0x5d001c13, 0x353404a4, 0x362847a7,   // sq.nn.fy_543 id.ss.un_650  fi.xh.zu_433 sn.sw.gn_532 
  0x04065708, 0x60381212, 0x0e004719, 0x132042ad,   // na.de.fi_443 hu.tk.vo_654  sn.is.un_750 co.sq.et_643 
  0x47005d2b, 0x3b003419, 0x2c003335, 0x0e2e5dec,   // ss.sn.un_980 ps.ks.un_750  nn.fy.un_A90 ss.fo.is_644 
  0x324c6412, 0x406558a4, 0x29320807, 0x102012a7,   // lg.wo.bs_654 om.gv.lb_433  no.bs.sl_432 hu.sq.lt_532 
  // [14630]
  0x40063f0c, 0x060302a4, 0x202c030e, 0x20002c2b,   // af.de.lb_543 da.nl.de_433  nl.fy.sq_555 fy.sq.un_980 
  0x342035a0, 0x20360bec, 0x2c7529af, 0x016e0cad,   // zu.sq.xh_322 es.gn.sq_644  sl.nso.fy_655 sv.hmn.en_643 
  0x3d3421a6, 0x204736ad, 0x64671213, 0x20092c08,   // fa.ps.ku_521 gn.sn.sq_643  hu.ak.lg_665 fy.pl.sq_443 
  0x5300021a, 0x2036100c, 0x23003609, 0x6400341a,   // da.ht.un_760 lt.gn.sq_543  ab.ky.un_440 xh.lg.un_760 
  // [14640]
  0x1d420704, 0x35384708, 0x6710040c, 0x12203805,   // it.co.la_332 sn.tk.zu_443  fi.lt.ak_543 tk.sq.hu_333 
  0x33fe2912, 0x032033a4, 0x481137ad, 0x18001d07,   // sl.tlh.nn_654 nn.sq.nl_433  ba.ro.tt_643 la.ga.un_420 
  0x042d0d0e, 0x2c2003a4, 0x18283b12, 0x2144230c,   // cs.sk.fi_555 nl.sq.fy_433  ks.sd.ar_654 ky.kk.fa_543 
  0x010c7908, 0x34330c07, 0x062a15ee, 0x3f2a6905,   // war.sv.en_443 sv.nn.xh_432  un.mt.de_422 mfe.mt.af_333 
  // [14650]
  0x063e120c, 0x3c040805, 0x3d3430ad, 0x483023ad,   // hu.rm.de_543 uk.ru.ug_333  uz.ps.ku_643 ky.uz.tt_643 
  0x531004a0, 0x3c00180d, 0x033f2ead, 0x01215302,   // fi.lt.ht_322 ar.ug.un_540  fo.af.nl_643 ht.jw.en_222 
  0x0d093ba6, 0xfc696705, 0x537629a7, 0x48081007,   // ks.hi.ne_521 ak.mfe.zzp_333  sl.crs.ht_532 be.uk.tt_432 
  0x48101bad, 0x04091013, 0x30073ea0, 0x02101d07,   // tr.lt.tt_643 lt.pl.fi_665  rm.it.uz_322 la.lt.da_432 
  // [14660]
  0x1d4c3b07, 0x483738ec, 0x21302307, 0x3c3835a4,   // so.wo.la_432 tk.ba.tt_644  ky.uz.fa_432 tg.tk.ug_433 
  0x081536ad, 0x533b4c0d, 0x35006304, 0x1b002e05,   // ab.uk.un_630 wo.so.ht_554  sco.zu.un_320 fo.tr.un_330 
  0x025c460c, 0x431d260c, 0x5c2f4604, 0x46590207,   // qu.sa.da_543 ia.la.ie_543  qu.su.sa_332 da.rn.qu_432 
  0x4926010b, 0x5c0279a7, 0x3e005508, 0x25443007,   // en.ia.to_542 war.da.sa_532  rw.rm.un_430 uz.kk.mn_432 
  // [14670]
  0x6b542108, 0x04081060, 0x3e2342a4, 0x22234e13,   // jw.ik.ceb_443 be.uk.ru_664  co.ca.rm_433 ay.ca.oc_665 
  0x2f1a02ee, 0x3800fc07, 0x673b1ea0, 0x04073507,   // da.tl.su_422 zzp.tk.un_420  ms.so.ak_322 tg.bg.ru_432 
  0x21096308, 0x0163650c, 0x630601ee, 0x6b5c4655,   // sco.pl.jw_443 gv.sco.en_543  en.de.sco_422 qu.sa.ceb_442 
  0x485c1d11, 0x0e2e1d55, 0x0c003408, 0x43260713,   // la.sa.tt_653 la.fo.is_442  xh.sv.un_430 it.ia.ie_665 
  // [14680]
  0x0e2e1d04, 0x02004613, 0x12001009, 0x2f3e5d0c,   // la.fo.is_332 qu.da.un_650  lt.hu.un_440 ss.rm.su_543 
  0x1d015708, 0x0b026bad, 0x46002f05, 0x2f1c1e07,   // na.en.la_443 ceb.da.es_643  su.qu.un_330 ms.id.su_432 
  0x09021d04, 0x1d000c0d, 0x34005d0d, 0x233e4213,   // la.da.pl_332 sv.la.un_540  ss.xh.un_540 co.rm.ca_665 
  0x3800020b, 0x315e0c04, 0x30233709, 0x4c1d3ba0,   // da.tk.un_520 sv.ts.az_332  ba.ky.uz_444 so.la.wo_322 
  // [14690]
  0x3b00190c, 0x37483807, 0x36190b60, 0x071d3e08,   // gl.so.un_530 tk.tt.ba_432  es.gl.gn_664 rm.la.it_443 
  0x30281205, 0x21283d08, 0x0a070ba0, 0x3e421dee,   // ur.sd.uz_333 ku.sd.fa_443  es.it.pt_322 la.co.rm_422 
  0x0d162d07, 0x190b24a0, 0x2900110b, 0x25481509,   // sk.hr.cs_432 eo.es.gl_322  ro.sl.un_520 un.tt.mn_444 
  0x07252305, 0x2c001104, 0x36001013, 0x25004819,   // ky.mn.bg_333 ro.fy.un_320  be.ab.un_650 tt.mn.un_750 
  // [146a0]
  0x5800520d, 0x1803270d, 0x153f03ac, 0x032718a7,   // ha.om.un_540 gd.nl.ga_554  nl.af.un_632 ga.gd.nl_532 
  0x032b4602, 0x271839a4, 0x6b00690d, 0x4b2c03a0,   // qu.vi.nl_222 br.ga.gd_433  mfe.ceb.un_540 nl.fy.mi_322 
  0x3c001113, 0x633f0308, 0x034e3fa4, 0x6569395a,   // ro.ug.un_650 nl.af.sco_443  af.ay.nl_433 br.mfe.gv_553 
  0x312f1bee, 0x394c3407, 0x0835040e, 0x30000413,   // tr.su.az_422 xh.wo.br_432  ru.tg.uk_555 ru.uz.un_650 
  // [146b0]
  0x1c536960, 0x48363505, 0x35344002, 0x00004b37,   // mfe.ht.id_664 tg.ab.tt_333  lb.xh.zu_222 mi.un.un_B00 
  0x15230408, 0x2c383fa9, 0x65004c0d, 0x4c003407,   // ru.ky.un_443 af.tk.fy_544  wo.gv.un_540 xh.wo.un_420 
  0x17360aaf, 0x352967ec, 0x474d2e0c, 0x37001c04,   // mk.ab.sr_655 ak.sl.zu_644  fo.aa.sn_543 id.st.un_320 
  0x2f215c0c, 0x3f2103a0, 0x34474d0c, 0x21474d04,   // sa.jw.su_543 nl.jw.af_322  aa.sn.xh_543 aa.sn.jw_332 
  // [146c0]
  0x02005214, 0x4700100b, 0x291262ee, 0x11250408,   // ha.da.un_660 lt.sn.un_520  kha.hu.sl_422 ru.mn.ro_443 
  0x38301505, 0x474d2813, 0x302829af, 0x58003b02,   // un.uz.tk_333 sw.aa.sn_665  sl.sw.uz_655 so.om.un_220 
  0x025930a4, 0x21552fa0, 0x1030350b, 0x09635f55,   // uz.rn.da_433 su.rw.jw_322  tg.uz.be_542 tn.sco.pl_442 
  0x631f1d0b, 0x60004f1a, 0x10090ca0, 0x3825100c,   // la.cy.sco_542 bi.vo.un_760  sv.pl.lt_322 be.mn.tk_543 
  // [146d0]
  0x18302304, 0x11515b0c, 0x303738a4, 0x170a11ec,   // ky.uz.ar_332 sg.kl.ro_543  tk.ba.uz_433 ro.mk.sr_644 
  0x4e003921, 0x3f000e04, 0x08020404, 0x23303560,   // br.ay.un_860 is.af.un_320  fi.da.no_332 tg.uz.ky_664 
  0x5c095605, 0x36003902, 0x655c5608, 0x48372307,   // mg.pl.sa_333 br.gn.un_220  mg.sa.gv_443 ky.ba.tt_432 
  0x5d7601a6, 0x3f1b3307, 0x2f003f02, 0x13030408,   // en.crs.ss_521 nn.tr.af_432  af.su.un_220 fi.nl.et_443 
  // [146e0]
  0x37005e02, 0x2c00fc0c, 0x4f1f39a0, 0x73000412,   // ts.st.un_220 zzp.fy.un_530  br.cy.bi_322 fi.ny.un_640 
  0x63003912, 0x5761045a, 0x38000d13, 0x313f38a0,   // br.sco.un_640 fi.za.na_553  cs.tk.un_650 tk.af.az_322 
  0x2d0d02a9, 0x2c006413, 0x365c56a6, 0x403e060c,   // da.cs.sk_544 lg.fy.un_650  mg.sa.gn_521 de.rm.lb_543 
  0x1f1b22a4, 0x095c565a, 0x22000a21, 0x58672cad,   // oc.tr.cy_433 mg.sa.pl_553  pt.oc.un_860 fy.ak.om_643 
  // [146f0]
  0x38006905, 0x5c005805, 0x22600aaf, 0x31005307,   // mfe.tk.un_330 om.sa.un_330  pt.vo.oc_655 ht.az.un_420 
  0x1b395304, 0x4a004309, 0x4c00620d, 0x5c5520ad,   // ht.br.tr_332 ie.yo.un_440  kha.wo.un_540 sq.rw.sa_643 
  0x381b610d, 0x3e422360, 0x4a000209, 0x027908a4,   // za.tr.tk_554 ca.co.rm_664  da.yo.un_440 no.war.da_433 
  0x09036108, 0x0f1924a4, 0x653001a0, 0x1b024a14,   // za.nl.pl_443 eo.gl.lv_433  en.uz.gv_322 yo.da.tr_666 
  // [14700]
  0x1c2125a0, 0x04393fa4, 0x330302ad, 0x38331b07,   // eu.jw.id_322 af.br.fi_433  da.nl.nn_643 tr.nn.tk_432 
  0x521d2ea9, 0x024afe07, 0x2c006204, 0x79590507,   // fo.la.ha_544 tlh.yo.da_432  kha.fy.un_320 fr.rn.war_432 
  0x631501a7, 0x2e2c79a0, 0x1c002004, 0x49014a02,   // en.sco.un_520 war.fy.fo_322  sq.id.un_320 yo.en.to_222 
  0x250a07a6, 0x432e0e60, 0x0c015aee, 0x28002e08,   // bg.mk.mn_521 is.fo.ie_664  sm.en.sv_422 fo.sw.un_430 
  // [14710]
  0x311b3008, 0x23343c08, 0x1f2e0e07, 0x11000a05,   // uz.tr.az_443 ug.ps.ky_443  is.fo.cy_432 pt.ro.un_330 
  0x2e270e0c, 0x792e0eee, 0x0a110704, 0x21341855,   // is.gd.fo_543 is.fo.war_422  bg.ro.mk_332 ar.ps.fa_442 
  0x2d300dee, 0x2d005e07, 0x0200421b, 0x502d0d60,   // cs.uz.sk_422 ts.sk.un_420  co.da.un_770 cs.sk.fj_664 
  0x0700110d, 0x30005e08, 0x302d0d0e, 0xfc00250b,   // ro.bg.un_540 ts.uz.un_430  cs.sk.uz_555 eu.zzp.un_520 
  // [14720]
  0xfc002512, 0x25004a0d, 0x4e002514, 0x120d0fa0,   // eu.zzp.un_640 yo.eu.un_540  eu.ay.un_660 lv.cs.hu_322 
  0x020d300c, 0x0b006402, 0x0e0c2eaf, 0x132f0a02,   // uz.cs.da_543 lg.es.un_220  fo.sv.is_655 pt.su.et_222 
  0x30114804, 0x40201704, 0x2e00081a, 0x4448300d,   // tt.ro.uz_332 sr.sq.lb_332  no.fo.un_760 uz.tt.kk_554 
  0x4e00250e, 0x30002404, 0x2e003e04, 0x23002523,   // eu.ay.un_550 eo.uz.un_320  rm.fo.un_320 mn.ky.un_880 
  // [14730]
  0x3b044c07, 0x68001308, 0x30443c04, 0x42003b07,   // wo.fi.so_432 et.ig.un_430  ug.kk.uz_332 so.co.un_420 
  0x783b58a4, 0x40000509, 0x1f0e650c, 0x3b4c6b0c,   // om.so.ve_433 fr.lb.un_440  gv.is.cy_543 ceb.wo.so_543 
  0x3e0e0ca9, 0x0f7334ee, 0x3b183ea0, 0x394c3e08,   // sv.is.rm_544 xh.ny.lv_422  rm.ga.so_322 rm.wo.br_443 
  0x134a0405, 0x73045804, 0x51003b19, 0x25483712,   // fi.yo.et_333 om.fi.ny_332  so.kl.un_750 ba.tt.mn_654 
  // [14740]
  0x33003805, 0x2a0c12a0, 0x69127613, 0x76364507,   // tk.nn.un_330 hu.sv.mt_322  crs.hu.mfe_665 ln.gn.crs_432 
  0x2a1d1208, 0x342d1004, 0x2900300e, 0x15340205,   // hu.la.mt_443 lt.sk.xh_332  uz.sl.un_550 da.xh.un_333 
  0x654a79a0, 0x0d341fee, 0x65091d05, 0x2d0d0912,   // war.yo.gv_322 cy.xh.cs_422  la.pl.gv_333 pl.cs.sk_654 
  0x0c3b0204, 0x0e192b04, 0x1225300c, 0x4c3953a4,   // da.so.sv_332 vi.gl.is_332  uz.eu.hu_543 ht.br.wo_433 
  // [14750]
  0x253c3005, 0x34375eee, 0x36002b0c, 0x63420907,   // uz.ug.mn_333 ts.st.xh_422  vi.gn.un_530 pl.co.sco_432 
  0x055553a0, 0x250c3011, 0x40003904, 0x30120c0c,   // ht.rw.fr_322 uz.sv.eu_653  br.lb.un_320 sv.hu.uz_543 
  0x3b00122c, 0x395265a0, 0x1d4c40a9, 0x33082f02,   // ur.ks.un_990 gv.ha.br_322  lb.wo.la_544 su.no.nn_222 
  0x654c5812, 0x044c58ec, 0x12283b05, 0x36006511,   // om.wo.gv_654 om.wo.fi_644  ks.sd.ur_333 gv.gn.un_630 
  // [14760]
  0x6a58490d, 0x2f521e07, 0x35252ea4, 0x62654ca4,   // to.om.haw_554 ms.ha.su_432  fo.eu.zu_433 wo.gv.kha_433 
  0x5100540d, 0x3b4c65a9, 0x1a316ba0, 0x544d0807,   // ik.kl.un_540 gv.wo.so_544  ceb.az.tl_322 no.aa.ik_432 
  0x044a2f0d, 0x58684ca9, 0x1a3179a7, 0x584c3fa9,   // su.yo.fi_554 wo.ig.om_544  war.az.tl_532 af.wo.om_544 
  0x0e3e01a4, 0x02586512, 0x38482312, 0x650e2c05,   // en.rm.is_433 gv.om.da_654  ky.tt.tk_654 fy.is.gv_333 
  // [14770]
  0xfc004802, 0x03482855, 0x21074207, 0x3b584cad,   // tt.zzp.un_220 sw.tt.nl_442  co.it.jw_432 wo.om.so_643 
  0x3f1349a4, 0x5c0742ec, 0x3835305a, 0x5f4c67a9,   // to.et.af_433 co.it.sa_644  uz.tg.tk_553 ak.wo.tn_544 
  0x656758a9, 0x4900651a, 0x586501a9, 0x4c6558a9,   // om.ak.gv_544 gv.to.un_760  en.gv.om_544 om.gv.wo_544 
  0x344428ad, 0x3b001e02, 0x49682608, 0x59003508,   // sd.kk.ps_643 ms.so.un_220  ia.ig.to_443 zu.rn.un_430 
  // [14780]
  0x3b4c5811, 0x3e3142a0, 0x65016b07, 0x4810230c,   // om.wo.so_653 co.az.rm_322  ceb.en.gv_432 ky.be.tt_543 
  0x304838a7, 0x355602a6, 0x681d260b, 0x5c004207,   // tk.tt.uz_532 da.mg.zu_521  ia.la.ig_542 co.sa.un_420 
  0x5c074208, 0x3c1510ec, 0x42232205, 0xfc464207,   // co.it.sa_443 be.ug.un_640  oc.ca.co_333 co.qu.zzp_432 
  0x12213b12, 0x383309ac, 0x3744100c, 0x355dfa08,   // ks.fa.ur_654 pl.nn.tk_632  be.kk.ba_543 nr.ss.zu_443 
  // [14790]
  0x1a6e4c11, 0x63fe0107, 0x48303813, 0x1f62fea9,   // wo.hmn.tl_653 en.tlh.sco_432  tk.uz.tt_665 tlh.kha.cy_544 
  0xfe1f4c13, 0x5800fe05, 0x531f630c, 0x63006e1a,   // wo.cy.tlh_665 tlh.om.un_330  sco.cy.ht_543 hmn.sco.un_760 
  0x1a62790d, 0x172325ad, 0x1f004c05, 0x631a4ca7,   // war.kha.tl_554 mn.ky.sr_643  wo.cy.un_330 wo.tl.sco_532 
  0x1b003e09, 0x311b60af, 0x67004c22, 0x6e4d4c12,   // rm.tr.un_440 vo.tr.az_655  wo.ak.un_870 wo.aa.hmn_654 
  // [147a0]
  0x0100631a, 0xfe006222, 0x0b00360e, 0x4c63fe0c,   // sco.en.un_760 kha.tlh.un_870  gn.es.un_550 tlh.sco.wo_543 
  0x1f4c6e0c, 0x09005e04, 0x3800311a, 0x403804a7,   // hmn.wo.cy_543 ts.pl.un_320  az.tk.un_760 fi.tk.lb_532 
  0x04380c0c, 0x0a100707, 0x06400c07, 0x48231055,   // sv.tk.fi_543 bg.be.mk_432  sv.lb.de_432 be.ky.tt_442 
  0x3748440d, 0x04483807, 0x48000c13, 0x0600040c,   // kk.tt.ba_554 tk.tt.fi_432  sv.tt.un_650 fi.de.un_530 
  // [147b0]
  0x0a001514, 0x19656308, 0x3b001f02, 0x48380408,   // un.mk.un_660 sco.gv.gl_443  cy.so.un_220 fi.tk.tt_443 
  0x0438480c, 0x0c130409, 0x2317110c, 0x2e4e0ead,   // tt.tk.fi_543 fi.et.sv_444  ro.sr.ky_543 is.ay.fo_643 
  0x3b650e07, 0x300a2502, 0x070a150e, 0x6b4b5907,   // is.gv.so_432 mn.mk.uz_222  un.mk.bg_555 rn.mi.ceb_432 
  0x3b004604, 0x6b002809, 0x040242a9, 0x10040860,   // qu.so.un_320 sw.ceb.un_440  co.da.fi_544 uk.ru.be_664 
  // [147c0]
  0x2b006508, 0x2a1333a0, 0x215d5c55, 0x477301a0,   // gv.vi.un_430 nn.et.mt_322  sa.ss.jw_442 en.ny.sn_322 
  0x203b58af, 0x0c000b02, 0x1100fe19, 0x362f0d0c,   // om.so.sq_655 es.sv.un_220  tlh.ro.un_750 cs.su.gn_543 
  0x3d34210b, 0x2b005f1a, 0x103b73a9, 0x054a2f55,   // fa.ps.ku_542 tn.vi.un_760  ny.so.lt_544 su.yo.fr_442 
  0x35395204, 0x5600460c, 0x0257060c, 0x182735a4,   // ha.br.zu_332 qu.mg.un_530  de.na.da_543 zu.gd.ga_433 
  // [147d0]
  0x01796304, 0x1046350c, 0x185a06a0, 0x49004002,   // sco.war.en_332 zu.qu.lt_543  de.sm.ga_322 lb.to.un_220 
  0x2a033ba9, 0x53693fec, 0x3e12130b, 0x3b005618,   // so.nl.mt_544 af.mfe.ht_644  et.hu.rm_542 mg.so.un_740 
  0x25392ca4, 0x39001509, 0x06005f0e, 0x3f3b03a4,   // fy.br.eu_433 un.br.un_440  tn.de.un_550 nl.so.af_433 
  0x11004204, 0x06640811, 0x04004817, 0x4a2b1c02,   // co.ro.un_320 no.lg.de_653  tt.fi.un_730 id.vi.yo_222 
  // [147e0]
  0x27393308, 0x3b495a04, 0x240306a4, 0x0c09100e,   // nn.br.gd_443 sm.to.so_332  de.nl.eo_433 lt.pl.sv_555 
  0x342f3907, 0x2f216207, 0x2b004002, 0x30000c02,   // br.su.xh_432 kha.jw.su_432  lb.vi.un_220 sv.uz.un_220 
  0x467367ad, 0x63004008, 0x304e3baf, 0x331b63a7,   // ak.ny.qu_643 lb.sco.un_430  so.ay.uz_655 sco.tr.nn_532 
  0x09697609, 0x64466709, 0x2c2f0305, 0x63004e07,   // crs.mfe.pl_444 ak.qu.lg_444  nl.su.fy_333 ay.sco.un_420 
  // [147f0]
  0x0802fcee, 0x4e04460c, 0x691852a4, 0x76006908,   // zzp.da.no_422 qu.fi.ay_543  ha.ga.mfe_433 mfe.crs.un_430 
  0x55067808, 0x42003e1b, 0x2e0e1daf, 0x1d00671a,   // ve.de.rw_443 rm.co.un_770  la.is.fo_655 ak.la.un_760 
  0x1d0e2e60, 0x15002e05, 0x33022c55, 0x0e1d2e13,   // fo.is.la_664 fo.un.un_330  fy.da.nn_442 fo.la.is_665 
  0x48000c18, 0x1d1539a0, 0x0c000610, 0x233e4212,   // sv.tt.un_740 br.la.un_320  de.sv.un_620 co.rm.ca_654 
  
  // [14800]
  0x0c004812, 0x180cfcee, 0x06044855, 0x152e0e11,   // tt.sv.un_640 zzp.sv.ga_422  tt.fi.de_442 is.fo.un_653 
  0x060c48a4, 0x48000605, 0x1d2e0e14, 0x15460eee,   // tt.sv.de_433 de.tt.un_330  is.fo.la_666 is.qu.un_422 
  0x48040c12, 0x4a2109a0, 0x021d1a0d, 0x30483811,   // sv.fi.tt_654 pl.jw.yo_322  tl.la.da_554 tk.tt.uz_653 
  0x040c4807, 0x44170a08, 0x3e791aa9, 0x130c4810,   // tt.sv.fi_432 mk.sr.kk_443  tl.war.rm_544 tt.sv.et_642 
  // [14810]
  0x06480c0c, 0x51002805, 0x594250a4, 0x2d480c0d,   // sv.tt.de_543 sw.kl.un_330  fj.co.rn_433 sv.tt.sk_554 
  0x0d002419, 0x252765a0, 0x0c004810, 0x420607a4,   // eo.cs.un_750 gv.gd.eu_322  tt.sv.un_620 it.de.co_433 
  0x0c00400b, 0x472d0d02, 0x52095504, 0x0c004811,   // lb.sv.un_520 cs.sk.sn_222  rw.pl.ha_332 tt.sv.un_630 
  0x2d0d13a0, 0x13044812, 0x04480c0d, 0x2d0d1d0c,   // et.cs.sk_322 tt.fi.et_654  sv.tt.fi_554 la.cs.sk_543 
  // [14820]
  0x190b25a6, 0x60000d04, 0x021a1da4, 0x1d285105,   // eu.es.gl_521 cs.vo.un_320  la.tl.da_433 kl.sw.la_333 
  0x3b4e310c, 0x312d0d14, 0x0d003005, 0x22230408,   // az.ay.so_543 cs.sk.az_666  uz.cs.un_330 fi.ca.oc_443 
  0x0400020b, 0x0f1025a4, 0x04004e0c, 0x58625c0c,   // da.fi.un_520 eu.lt.lv_433  ay.fi.un_530 sa.kha.om_543 
  0x5c3028a7, 0x400c06ad, 0x54020c05, 0x15100707,   // sw.uz.sa_532 de.sv.lb_643  sv.da.ik_333 bg.be.un_432 
  // [14830]
  0x30154809, 0x24100c07, 0x27002102, 0x32fe1b02,   // tt.uz.un_440 sv.lt.eo_432  jw.gd.un_220 tr.tlh.bs_222 
  0x10113808, 0x46481055, 0x46484da4, 0x233515a0,   // tk.ro.be_443 lt.tt.qu_442  aa.tt.qu_433 un.tg.ky_322 
  0x320dfe0b, 0x4e04480c, 0x0e2e1faf, 0x35083002,   // tlh.cs.bs_542 tt.fi.ay_543  cy.fo.is_655 uz.uk.tg_222 
  0x38064007, 0x34302113, 0x0c064008, 0x21123b12,   // lb.de.tk_432 fa.uz.ps_665  lb.de.sv_443 ks.ur.fa_654 
  // [14840]
  0x3e2357ec, 0x3e4223a4, 0x42233e08, 0x3e234207,   // na.ca.rm_644 ca.co.rm_433  rm.ca.co_443 co.ca.rm_432 
  0x060c48af, 0x06604812, 0x38044807, 0x2300420e,   // tt.sv.de_655 tt.vo.de_654  tt.fi.tk_432 co.ca.un_550 
  0x1e001d02, 0x3e004213, 0x64000904, 0x02270304,   // la.ms.un_220 co.rm.un_650  pl.lg.un_320 nl.gd.da_332 
  0x480415a4, 0x434223ee, 0x42002309, 0x04480c04,   // un.ru.tt_433 ca.co.ie_422  ca.co.un_440 sv.tt.fi_332 
  // [14850]
  0x31481eee, 0x064804a6, 0x460c48a9, 0x091d4311,   // ms.tt.az_422 fi.tt.de_521  tt.sv.qu_544 ie.la.pl_653 
  0x0e0d0aa9, 0x34002302, 0x48382305, 0x0a4a18a9,   // pt.cs.is_544 ky.ps.un_220  ky.tk.tt_333 ga.yo.pt_544 
  0x06271813, 0x4500180d, 0x1b001111, 0x4360010c,   // ga.gd.de_665 ga.ln.un_540  ro.tr.un_630 en.vo.ie_543 
  0x64494a07, 0x06002702, 0x2d184a5a, 0xfe0115a9,   // yo.to.lg_432 gd.de.un_220  yo.ga.sk_553 un.en.tlh_544 
  // [14860]
  0x182e0ead, 0x2000360c, 0x4a001822, 0x5d00520c,   // is.fo.ga_643 gn.sq.un_530  ga.yo.un_870 ha.ss.un_530 
  0x33002c04, 0x483530a4, 0x73004809, 0x46000e0c,   // fy.nn.un_320 uz.tg.tt_433  tt.ny.un_440 is.qu.un_530 
  0x2e4a0e08, 0x180d4a08, 0x280c0204, 0x2300222c,   // is.yo.fo_443 yo.cs.ga_443  da.sv.sw_332 oc.ca.un_990 
  0x0d2d090d, 0x2b0e0a08, 0x332e1004, 0x2e001835,   // pl.sk.cs_554 pt.is.vi_443  lt.fo.nn_332 ga.fo.un_A90 
  // [14870]
  0x42002719, 0x07350a08, 0x36000e12, 0x59555709,   // gd.co.un_750 mk.tg.bg_443  is.gn.un_640 na.rw.rn_444 
  0x2d0d10af, 0x36002e08, 0x252d0d0d, 0x46001b11,   // lt.cs.sk_655 fo.gn.un_430  cs.sk.eu_554 tr.qu.un_630 
  0x640257af, 0x04004013, 0x4025640d, 0x04004005,   // na.da.lg_655 lb.fi.un_650  lg.eu.lb_554 lb.fi.un_330 
  0x20001008, 0x02330802, 0x0221650b, 0x38311b0b,   // lt.sq.un_430 no.nn.da_222  gv.jw.da_542 tr.az.tk_542 
  // [14880]
  0x49002819, 0x27000408, 0x40001305, 0x020c040c,   // sw.to.un_750 fi.gd.un_430  et.lb.un_330 fi.sv.da_543 
  0x54003819, 0x2c004c22, 0x10645307, 0x074c0107,   // tk.ik.un_750 wo.fy.un_870  ht.lg.lt_432 en.wo.it_432 
  0x53104f12, 0x42060708, 0x2c383f0e, 0x0c2c3eee,   // bi.lt.ht_654 it.de.co_443  af.tk.fy_555 rm.fy.sv_422 
  0x020920ec, 0x3b004818, 0x21001613, 0x45386408,   // sq.pl.da_644 tt.so.un_740  th.fa.un_650 lg.tk.ln_443 
  // [14890]
  0x033f020c, 0x48350702, 0x18033fa7, 0x3f0327a4,   // da.af.nl_543 bg.tg.tt_222  af.nl.ga_532 gd.nl.af_433 
  0x5c643807, 0x34000904, 0x643438a9, 0x33083e09,   // tk.lg.sa_432 pl.xh.un_320  tk.xh.lg_544 rm.no.nn_444 
  0x385c3607, 0x1d385c5a, 0x5c38105a, 0x5c00470c,   // gn.sa.tk_432 sa.tk.la_553  lt.tk.sa_553 sn.sa.un_530 
  0x3e131207, 0x09344607, 0x0c004805, 0x0c004802,   // hu.et.rm_432 qu.xh.pl_432  tt.sv.un_330 tt.sv.un_220 
  // [148a0]
  0x384804ad, 0x34004a0c, 0x04400607, 0x480c06a0,   // fi.tt.tk_643 yo.xh.un_530  de.lb.fi_432 de.sv.tt_322 
  0x40004817, 0x4900580c, 0x25233055, 0x2c0406ed,   // tt.lb.un_730 om.to.un_530  uz.ky.mn_442 de.fi.fy_622 
  0x350e2005, 0x1f003811, 0x67005821, 0x651f3609,   // sq.is.zu_333 tk.cy.un_630  om.ak.un_860 gn.cy.gv_444 
  0x40064812, 0x21301212, 0x0c00480c, 0x0c4806ee,   // tt.de.lb_654 ur.uz.fa_654  tt.sv.un_530 de.tt.sv_422 
  // [148b0]
  0x123865a7, 0x58000612, 0x08332004, 0x56024c0d,   // gv.tk.hu_532 de.om.un_640  sq.nn.no_332 wo.da.mg_554 
  0x091024a4, 0x025664a4, 0x4900070c, 0x0c004818,   // eo.lt.pl_433 lg.mg.da_433  it.to.un_530 tt.sv.un_740 
  0x4b1d0107, 0x214564a9, 0x604d1e07, 0x38004817,   // en.la.mi_432 lg.ln.jw_544  ms.aa.vo_432 tt.tk.un_730 
  0x04006019, 0x233418ee, 0x43072413, 0x346a690e,   // vo.fi.un_750 ar.ps.ky_422  eo.it.ie_665 mfe.haw.xh_555 
  // [148c0]
  0x190b5aa9, 0x587334a9, 0x370a0707, 0x48153707,   // sm.es.gl_544 xh.ny.om_544  bg.mk.ba_432 ba.tt.un_420 
  0x341802ee, 0x1d5f3708, 0x0b0a43a9, 0x340735a4,   // da.ga.xh_422 st.tn.la_443  ie.pt.es_544 zu.it.xh_433 
  0x444823a4, 0x1600250c, 0x09002909, 0x5b495a0c,   // ky.tt.kk_433 eu.hr.un_530  sl.pl.un_440 sm.to.sg_543 
  0x38021204, 0x23003d05, 0x021024a4, 0x34241008,   // hu.da.tk_332 ku.ky.un_330  eo.lt.da_433 lt.eo.xh_443 
  // [148d0]
  0x02211c05, 0x5e00071a, 0x1c642104, 0x2400640c,   // id.jw.da_333 it.ts.un_760  jw.lg.id_332 lg.eo.un_530 
  0x33000b2c, 0x022407a4, 0x4f215607, 0x6b4b6a0d,   // bn.as.un_990 it.eo.da_433  mg.jw.bi_432 haw.mi.ceb_554 
  0x2330150d, 0x2167780c, 0x494b560c, 0x070410a4,   // un.uz.ky_554 ve.ak.jw_543  mg.mi.to_543 be.ru.bg_433 
  0x234838ad, 0x031925a0, 0x082315ad, 0x09385609,   // tk.tt.ky_643 eu.gl.nl_322  un.ky.uk_643 mg.tk.pl_444 
  // [148e0]
  0x3f4c2011, 0x5c003813, 0x56380912, 0x3609380c,   // sq.wo.af_653 tk.sa.un_650  pl.tk.mg_654 tk.pl.gn_543 
  0x092d38af, 0x385c3612, 0x2d0d5ca6, 0x333f300d,   // tk.sk.pl_655 gn.sa.tk_654  sa.cs.sk_521 uz.af.nn_554 
  0x081037a0, 0x38092d07, 0x5c003812, 0x0c001f12,   // ba.be.uk_322 sk.pl.tk_432  tk.sa.un_640 cy.sv.un_640 
  0x24120ea0, 0x0b004608, 0xfc002207, 0x1a003008,   // is.hu.eo_322 qu.es.un_430  oc.zzp.un_420 uz.tl.un_430 
  // [148f0]
  0x2a1f27a0, 0x343d12a7, 0x20006208, 0x2f002a05,   // gd.cy.mt_322 ur.ku.ps_532  kha.sq.un_430 mt.su.un_330 
  0x2e380e0c, 0x061d46a4, 0x120c2a11, 0x2c122a04,   // is.tk.fo_543 qu.la.de_433  mt.sv.hu_653 mt.hu.fy_332 
  0x0e132aa4, 0x3700fc0d, 0x13004805, 0x1f001d05,   // mt.et.is_433 zzp.st.un_540  tt.et.un_330 la.cy.un_330 
  0x31203402, 0x2f341da9, 0x5a1d6502, 0x04006010,   // xh.sq.az_222 la.xh.su_544  gv.la.sm_222 vo.fi.un_620 
  // [14900]
  0x5b044860, 0x0349050d, 0x0800fe0c, 0x123f0304,   // tt.fi.sg_664 fr.to.nl_554  tlh.no.un_530 nl.af.hu_332 
  0x380711ad, 0x2f5a0505, 0x22790504, 0x2a300207,   // ro.bg.tk_643 fr.sm.su_333  fr.war.oc_332 da.uz.mt_432 
  0x12330207, 0x4a5239a0, 0x3568faad, 0x02002e19,   // da.nn.hu_432 br.ha.yo_322  nr.ig.zu_643 fo.da.un_750 
  0x3216feac, 0x34213bee, 0x2f004a0d, 0x73285913,   // tlh.hr.bs_632 ks.fa.ps_422  yo.su.un_540 rn.sw.ny_665 
  // [14910]
  0x4673fe08, 0x2900fe07, 0x28353402, 0x25373055,   // tlh.ny.qu_443 tlh.sl.un_420  xh.zu.sw_222 uz.ba.mn_442 
  0x33002e05, 0x11474204, 0x3015040c, 0x11360b0c,   // fo.nn.un_330 co.sn.ro_332  ru.uz.un_530 es.gn.ro_543 
  0x08330e55, 0x074837a6, 0x2f73fea4, 0x23153804,   // is.nn.no_442 ba.tt.bg_521  tlh.ny.su_433 tk.ky.un_320 
  0x382223a0, 0x27007304, 0x592936a4, 0x247347a7,   // ca.oc.tk_322 ny.gd.un_320  gn.sl.rn_433 sn.ny.eo_532 
  // [14920]
  0x182130ec, 0x0c4804ee, 0x48000705, 0x082e69a4,   // uz.fa.ar_644 fi.tt.sv_422  bg.tt.un_330 mfe.fo.no_433 
  0x2a3b18ac, 0x40033f0b, 0x2f006b04, 0x460e670c,   // ga.so.mt_632 af.nl.lb_542  ceb.su.un_320 ak.is.qu_543 
  0x25304860, 0x011863a0, 0x23004434, 0x3200200e,   // tt.uz.mn_664 sco.ga.en_322  kk.ky.un_A80 sq.bs.un_550 
  0x082348a4, 0x0c004807, 0x380a3007, 0x2e300e08,   // tt.ky.uk_433 tt.sv.un_420  uz.mk.tk_432 is.uz.fo_443 
  // [14930]
  0x2d0e2e12, 0x4b1d6aa9, 0x5a671da9, 0x1c4b370c,   // fo.is.sk_654 haw.la.mi_544  la.ak.sm_544 st.mi.id_543 
  0x033f65a4, 0x67635a0c, 0x600d2d0c, 0x1500670c,   // gv.af.nl_433 sm.sco.ak_543  sk.cs.vo_543 ak.un.un_530 
  0x18002f04, 0x67611aa9, 0x48000c08, 0x63001d22,   // su.ga.un_320 tl.za.ak_544  sv.tt.un_430 la.sco.un_870 
  0x39656413, 0x1d766912, 0x0c082ca0, 0x30234802,   // lg.gv.br_665 mfe.crs.la_654  fy.no.sv_322 tt.ky.uz_222 
  // [14940]
  0x211e5907, 0x1d495aec, 0x574b6a13, 0x0d102da0,   // rn.ms.jw_432 sm.to.la_644  haw.mi.na_665 sk.lt.cs_322 
  0x4b631d12, 0x245c2955, 0x282f5c05, 0x285d3555,   // la.sco.mi_654 sl.sa.eo_442  sa.su.sw_333 zu.ss.sw_442 
  0x5a1d675a, 0x676a4b09, 0x0d2d4807, 0x135e51a0,   // ak.la.sm_553 mi.haw.ak_444  tt.sk.cs_432 kl.ts.et_322 
  0x2d170d14, 0x38000e13, 0x1d1d600c, 0x250407ee,   // cs.sr.sk_666 is.tk.un_650  vo.la.la_543 bg.ru.mn_422 
  // [14950]
  0x47000402, 0x51132807, 0x071708a9, 0x425605ad,   // fi.sn.un_220 sw.et.kl_432  uk.sr.bg_544 fr.mg.co_643 
  0x401304a0, 0x2a24040c, 0x3f042aa4, 0x39000f07,   // fi.et.lb_322 fi.eo.mt_543  mt.fi.af_433 lv.br.un_420 
  0x1a5369af, 0x48003811, 0x20003805, 0x3811070e,   // mfe.ht.tl_655 tk.tt.un_630  tk.sq.un_330 bg.ro.tk_555 
  0x39003104, 0x530476a9, 0x4f00210d, 0x48003607,   // az.br.un_320 crs.fi.ht_544  jw.bi.un_540 ab.tt.un_420 
  // [14960]
  0x2c5346af, 0x2a4610a4, 0x353004a4, 0x1b483807,   // qu.ht.fy_655 lt.qu.mt_433  ru.uz.tg_433 tk.tt.tr_432 
  0x512e02a7, 0x11004804, 0x48383113, 0x31003814,   // da.fo.kl_532 tt.ro.un_320  az.tk.tt_665 tk.az.un_660 
  0x480c1308, 0xfc4831a9, 0x0648600d, 0x0e2e380e,   // et.sv.tt_443 az.tt.zzp_544  vo.tt.de_554 tk.fo.is_555 
  0x1536100d, 0x1b256b05, 0xfc004608, 0x30450307,   // be.ab.un_554 ceb.eu.tr_333  qu.zzp.un_430 nl.ln.uz_432 
  // [14970]
  0x10022907, 0x3b6b4c09, 0x46005804, 0x46352407,   // sl.da.lt_432 wo.ceb.so_444  om.qu.un_320 eo.zu.qu_432 
  0x281573a0, 0x0400060d, 0x36006819, 0x3c374860,   // ny.sw.un_320 de.fi.un_540  ig.gn.un_750 tt.ba.ug_664 
  0x26020708, 0x56450204, 0x2128120b, 0x47026407,   // it.da.ia_443 da.ln.mg_332  ur.sd.fa_542 lg.da.sn_432 
  0x256924a4, 0x555c5ea0, 0x1d193ba7, 0x241d29a4,   // eo.mfe.eu_433 ts.sa.rw_322  so.gl.la_532 sl.la.eo_433 
  // [14980]
  0x31003604, 0x595573ec, 0x075a2611, 0x7924070c,   // gn.az.un_320 ny.rw.rn_644  ia.sm.it_653 it.eo.war_543 
  0x291a790c, 0x303848a9, 0x753b5f0c, 0x1a3651ad,   // war.tl.sl_543 tt.tk.uz_544  tn.so.nso_543 kl.gn.tl_643 
  0x062a3ea4, 0x2840060c, 0x2818230b, 0x1f272da4,   // rm.mt.de_433 de.lb.sw_543  ky.ar.sd_542 sk.gd.cy_433 
  0x0263010c, 0x042a2ea9, 0x4c002a21, 0x47735ea9,   // en.sco.da_543 fo.mt.fi_544  mt.wo.un_860 ts.ny.sn_544 
  // [14990]
  0x542a070c, 0x0412510c, 0x0c0e40ee, 0x42000804,   // it.mt.ik_543 kl.hu.fi_543  lb.is.sv_422 no.co.un_320 
  0x073f6504, 0x39651f07, 0x481544a9, 0x42002620,   // gv.af.it_332 cy.gv.br_432  kk.tt.un_540 ia.co.un_850 
  0x15630207, 0x3000310e, 0x73631f04, 0x23350702,   // da.sco.un_432 az.uz.un_550  cy.sco.ny_332 bg.tg.ky_222 
  0x254006a9, 0x32007307, 0x28000608, 0x2040060c,   // de.lb.eu_544 ny.bs.un_420  de.sw.un_430 de.lb.sq_543 
  // [149a0]
  0x423e020c, 0x1b06fe0b, 0xfe38530d, 0x3f0665a0,   // da.rm.co_543 tlh.de.tr_542  ht.tk.tlh_554 gv.de.af_322 
  0x06006814, 0x40650ea0, 0x16fe290c, 0x1d680655,   // ig.de.un_660 is.gv.lb_322  sl.tlh.hr_543 de.ig.la_442 
  0x584d6404, 0x53231f02, 0x42fe07a9, 0x48001108,   // lg.aa.om_332 cy.ca.ht_222  it.tlh.co_544 ro.tt.un_430 
  0x12fe01a4, 0x4a003e09, 0xfe002d13, 0x17303c08,   // en.tlh.hu_433 rm.yo.un_440  sk.tlh.un_650 ug.uz.sr_443 
  // [149b0]
  0x4d12fe0c, 0x40fe2d07, 0x2e0e2a12, 0x332c0e04,   // tlh.hu.aa_543 sk.tlh.lb_432  mt.is.fo_654 is.fy.nn_332 
  0x3c374811, 0x08044805, 0x2a006508, 0x122d19ee,   // tt.ba.ug_653 tt.ru.uk_333  gv.mt.un_430 gl.sk.hu_422 
  0x03003607, 0x110817a4, 0x2300180b, 0x352523a4,   // gn.nl.un_420 sr.uk.ro_433  ga.ca.un_520 ky.mn.tg_433 
  0x373c48ec, 0x150223a4, 0xfc5662a0, 0x396a56af,   // tt.ug.ba_644 ca.da.un_433  kha.mg.zzp_322 mg.haw.br_655 
  // [149c0]
  0x60000804, 0x43305614, 0x0c1306ee, 0x02001502,   // no.vo.un_320 mg.uz.ie_666  de.et.sv_422 un.da.un_220 
  0x5d26560d, 0x28123baf, 0x494758a4, 0x3efe4c0c,   // mg.ia.ss_554 ks.ur.sd_655  om.sn.to_433 wo.tlh.rm_543 
  0x175e560c, 0x0d495611, 0x691a1f0c, 0x033f02a7,   // mg.ts.sr_543 mg.to.cs_653  cy.tl.mfe_543 da.af.nl_532 
  0x48474da4, 0x150636ee, 0x245f560b, 0x4d30040c,   // aa.sn.tt_433 gn.de.un_422  mg.tn.eo_542 fi.uz.aa_543 
  // [149d0]
  0x39005104, 0x21502fee, 0x02561a0d, 0x3e63fe04,   // kl.br.un_320 su.fj.jw_422  tl.mg.da_554 tlh.sco.rm_332 
  0x3428120b, 0x631501ec, 0x2544350d, 0x0a150411,   // ur.sd.ps_542 en.sco.un_640  tg.kk.mn_554 ru.mk.un_630 
  0x620163ee, 0x65fc0107, 0x63131d09, 0x65062aee,   // sco.en.kha_422 en.zzp.gv_432  la.et.sco_444 mt.de.gv_422 
  0x492e01a0, 0x4c1e6b02, 0x09000f07, 0x1ffe4c02,   // en.fo.to_322 ceb.ms.wo_222  lv.pl.un_420 wo.tlh.cy_222 
  // [149e0]
  0x4c002a19, 0x06332ca0, 0x30311b12, 0x2f3f03ee,   // mt.wo.un_750 fy.nn.de_322  tr.az.uz_654 nl.af.su_422 
  0x0c0f02a0, 0x6e001507, 0x38004404, 0x1c001502,   // da.lv.sv_322 un.hmn.un_420  kk.tk.un_320 un.id.un_220 
  0xfcfe1304, 0x092a2e04, 0x05003f07, 0x03004c05,   // et.tlh.zzp_332 fo.mt.pl_332  af.fr.un_420 wo.nl.un_330 
  0x23112513, 0x4c001208, 0x07483c04, 0x400c06ec,   // mn.ro.ky_665 hu.wo.un_430  ug.tt.bg_332 de.sv.lb_644 
  // [149f0]
  0x38003c05, 0x4c212f04, 0x06004b02, 0x0c4006a4,   // ug.tk.un_330 su.jw.wo_332  mi.de.un_220 de.lb.sv_433 
  0x2544360c, 0x35233005, 0x213d1205, 0x113807a4,   // ab.kk.mn_543 uz.ky.tg_333  ur.ku.fa_333 bg.tk.ro_433 
  0x48253007, 0x301138af, 0x0c4006ec, 0x09290da4,   // uz.mn.tt_432 tk.ro.uz_655  de.lb.sv_644 cs.sl.pl_433 
  0x123d28a0, 0x345152a9, 0x39005d05, 0x181d0107,   // sd.ku.ur_322 ha.kl.xh_544  ss.br.un_330 en.la.ga_432 
  // [14a00]
  0x521b0dee, 0x5c003b04, 0x32290da6, 0x23004619,   // cs.tr.ha_422 so.sa.un_320  cs.sl.bs_521 qu.ca.un_750 
  0x680f0107, 0x114673ec, 0x07422d05, 0x21604011,   // en.lv.ig_432 ny.qu.ro_644  sk.co.it_333 lb.vo.jw_653 
  0x07524c08, 0x4d1e1fad, 0x37304804, 0x290d1baf,   // wo.ha.it_443 cy.ms.aa_643  tt.uz.ba_332 tr.cs.sl_655 
  0x097973a4, 0x4810110c, 0x3b0e2eee, 0x44072309,   // ny.war.pl_433 ro.be.tt_543  fo.is.so_422 ky.bg.kk_444 
  // [14a10]
  0x050602a0, 0x0d05010c, 0x73005713, 0x071842a9,   // da.de.fr_322 en.fr.cs_543  na.ny.un_650 co.ga.it_544 
  0x3f150f0c, 0x30316009, 0x11002414, 0x0a5e4711,   // lv.af.un_530 vo.az.uz_444  eo.ro.un_660 sn.ts.pt_653 
  0x645e7904, 0x33022e13, 0x12212f02, 0x35287312,   // war.ts.lg_332 fo.da.nn_665  su.jw.hu_222 ny.sw.zu_654 
  0x3f2c0355, 0x61002109, 0x18123007, 0x526b470c,   // nl.fy.af_442 jw.za.un_440  uz.ur.ar_432 sn.ceb.ha_543 
  // [14a20]
  0x38003122, 0x211c61ee, 0x2f4a1aec, 0x21026405,   // az.tk.un_870 za.id.jw_422  tl.yo.su_644 lg.da.jw_333 
  0x33022ea9, 0x46262204, 0x5c346104, 0x33084fee,   // fo.da.nn_544 oc.ia.qu_332  za.xh.sa_332 bi.no.nn_422 
  0x466112af, 0x1b4c030c, 0x1100081a, 0x35443808,   // hu.za.qu_655 nl.wo.tr_543  uk.ro.un_760 tk.kk.tg_443 
  0x5500610d, 0x4c005312, 0x2b000305, 0x480a300b,   // za.rw.un_540 ht.wo.un_640  nl.vi.un_330 uz.mk.tt_542 
  // [14a30]
  0x123b300c, 0x0f020807, 0x04005e04, 0x336b47ec,   // uz.ks.ur_543 no.da.lv_432  ts.fi.un_320 sn.ceb.nn_644 
  0x1007110c, 0x1b003914, 0x163211a9, 0x593435a9,   // ro.bg.be_543 br.tr.un_660  ro.bs.hr_544 zu.xh.rn_544 
  0x5c003419, 0x0419470c, 0x53104c02, 0x040a2108,   // xh.sa.un_750 sn.gl.fi_543  wo.lt.ht_222 jw.pt.fi_443 
  0x791a460c, 0x5c00460c, 0x33087605, 0x4600610d,   // qu.tl.war_543 qu.sa.un_530  crs.no.nn_333 za.qu.un_540 
  // [14a40]
  0x15373807, 0x0c134ebb, 0x38006508, 0x211230ec,   // tk.ba.un_432 ay.et.sv_854  gv.tk.un_430 uz.ur.fa_644 
  0x56002404, 0x040c120b, 0x34123ca0, 0x090d2d0b,   // eo.mg.un_320 hu.sv.fi_542  ug.ur.ps_322 sk.cs.pl_542 
  0x65041f09, 0x292d10a0, 0x393e5507, 0x06040c0c,   // cy.fi.gv_444 lt.sk.sl_322  rw.rm.br_432 sv.fi.de_543 
  0x150436ad, 0x04480ca0, 0x30023e0c, 0x30354808,   // ab.ru.un_643 sv.tt.fi_322  rm.da.uz_543 tt.tg.uz_443 
  // [14a50]
  0x0c0648a4, 0x1d5e6512, 0x09001f0d, 0x101b38ad,   // tt.de.sv_433 gv.ts.la_654  cy.pl.un_540 tk.tr.lt_643 
  0x170744a0, 0x5c003308, 0x30473504, 0x58190104,   // kk.bg.sr_322 nn.sa.un_430  zu.sn.uz_332 en.gl.om_332 
  0x253e0e5a, 0x393e60a0, 0x3e0e2e14, 0x3e133008,   // is.rm.eu_553 vo.rm.br_322  fo.is.rm_666 uz.et.rm_443 
  0x48040c0c, 0x480c4eac, 0x0c4804a4, 0x28556408,   // sv.fi.tt_543 ay.sv.tt_632  fi.tt.sv_433 lg.rw.sw_443 
  // [14a60]
  0x19253004, 0x0400430e, 0x2601fca9, 0x1200fe12,   // uz.eu.gl_332 ie.fi.un_550  zzp.en.ia_544 tlh.hu.un_640 
  0x3d232108, 0x0ffe15a0, 0x100417a0, 0x1f006213,   // fa.ky.ku_443 un.tlh.lv_322  sr.ru.be_322 kha.cy.un_650 
  0x06040c07, 0x125c02a0, 0x06044810, 0x510208a0,   // sv.fi.de_432 da.sa.hu_322  tt.fi.de_642 no.da.kl_322 
  0x17003802, 0x53001508, 0x3f00fe07, 0x0c004e12,   // tk.sr.un_220 un.ht.un_430  tlh.af.un_420 ay.sv.un_640 
  // [14a70]
  0x311148a7, 0x30113807, 0x7901fc04, 0x071711ee,   // tt.ro.az_532 tk.ro.uz_432  zzp.en.war_332 ro.sr.bg_422 
  0x123d2809, 0x02330805, 0x4a000604, 0x3c343007,   // sd.ku.ur_444 no.nn.da_333  de.yo.un_320 uz.ps.ug_432 
  0x3d2130ee, 0x23004209, 0x563e4212, 0x02002a12,   // uz.fa.ku_422 co.ca.un_440  co.rm.mg_654 mt.da.un_640 
  0x48231702, 0x6b0e79af, 0x382e0ea4, 0x6e00090b,   // sr.ky.tt_222 war.is.ceb_655  is.fo.tk_433 pl.hmn.un_520 
  // [14a80]
  0x17073502, 0x2e4c0e05, 0x3e4223af, 0x0410375a,   // tg.bg.sr_222 is.wo.fo_333  ca.co.rm_655 ba.be.ru_553 
  0x0f201007, 0x102a0e0d, 0x30001d04, 0x120e0405,   // lt.sq.lv_432 is.mt.lt_554  la.uz.un_320 fi.is.hu_333 
  0x381b1d5a, 0x023f03a0, 0x0d2d0904, 0x506a5aec,   // la.tr.tk_553 nl.af.da_322  pl.sk.cs_332 sm.haw.fj_644 
  0x1d6a5aad, 0x2515360c, 0x225a6aa4, 0x5c3f03a4,   // sm.haw.la_643 ab.mn.un_530  haw.sm.oc_433 nl.af.sa_433 
  // [14a90]
  0x04481307, 0x38004b02, 0x04735a07, 0x3110110c,   // et.tt.fi_432 mi.tk.un_220  sm.ny.fi_432 ro.lt.az_543 
  0x271830ec, 0x1e2d1c0c, 0x23001021, 0x25001802,   // uz.ga.gd_644 id.sk.ms_543  be.ky.un_860 ga.eu.un_220 
  0x03000c07, 0x134004a4, 0x652c03a7, 0x30250707,   // sv.nl.un_420 fi.lb.et_433  nl.fy.gv_532 bg.mn.uz_432 
  0x29120308, 0x1d4b5aad, 0x4b271812, 0x4a003604,   // nl.hu.sl_443 sm.mi.la_643  ga.gd.mi_654 gn.yo.un_320 
  // [14aa0]
  0x1d005a04, 0x561104a0, 0x03002019, 0x1d006a0d,   // sm.la.un_320 fi.ro.mg_322  sq.nl.un_750 haw.la.un_540 
  0x73290405, 0x422c0355, 0x09001607, 0x36496a12,   // fi.sl.ny_333 nl.fy.co_442  hr.pl.un_420 haw.to.gn_654 
  0x040c4811, 0x34001919, 0x040648a7, 0x23220a14,   // tt.sv.fi_653 gl.xh.un_750  tt.de.fi_532 pt.oc.ca_666 
  0x496a4bad, 0x23050b07, 0x2b001e08, 0x4735fc04,   // mi.haw.to_643 es.fr.ca_432  ms.vi.un_430 zzp.zu.sn_332 
  // [14ab0]
  0x2a003b02, 0x03202c04, 0x12302011, 0x2c650307,   // so.mt.un_220 fy.sq.nl_332  sq.uz.hu_653 nl.gv.fy_432 
  0x69537605, 0x2c65030c, 0x531f3407, 0x2c2903af,   // crs.ht.mfe_333 nl.gv.fy_543  xh.cy.ht_432 nl.sl.fy_655 
  0x25002202, 0x341009a4, 0x0a1710ee, 0x0c00080d,   // oc.eu.un_220 pl.lt.xh_433  be.sr.mk_422 no.sv.un_540 
  0x36301da0, 0x5c00610e, 0x20002b14, 0x2113350c,   // la.uz.gn_322 za.sa.un_550  vi.sq.un_660 zu.et.jw_543 
  // [14ac0]
  0x03153f05, 0x313038a0, 0x40060402, 0x51280208,   // af.nl.un_330 tk.uz.az_322  fi.de.lb_222 da.sw.kl_443 
  0x38003405, 0x154438ee, 0x460136a7, 0x211a3408,   // xh.tk.un_330 tk.kk.un_422  gn.en.qu_532 xh.tl.jw_443 
  0x091253ee, 0x25004005, 0x0465fc08, 0x2500060e,   // ht.hu.pl_422 lb.eu.un_330  zzp.gv.fi_443 de.eu.un_550 
  0x04005c08, 0x04106505, 0xfc1f0202, 0x041707ad,   // sa.fi.un_430 gv.lt.fi_333  da.cy.zzp_222 bg.sr.ru_643 
  // [14ad0]
  0x380efc04, 0x28733804, 0x38006507, 0x1c006804,   // zzp.is.tk_332 tk.ny.sw_332  gv.tk.un_420 ig.id.un_320 
  0x33020cee, 0x30370707, 0x0efc650c, 0x3f204c0c,   // sv.da.nn_422 bg.ba.uz_432  gv.zzp.is_543 wo.sq.af_543 
  0x0d004702, 0x21123411, 0x23304812, 0x35304408,   // sn.cs.un_220 ps.ur.fa_653  tt.uz.ky_654 kk.uz.tg_443 
  0x295f5a0c, 0x23005a04, 0x4d5f75a4, 0x1600500c,   // sm.tn.sl_543 sm.ca.un_320  nso.tn.aa_433 fj.hr.un_530 
  // [14ae0]
  0x52003602, 0x3000590e, 0x5f002f09, 0x30595560,   // gn.ha.un_220 rn.uz.un_550  su.tn.un_440 rw.rn.uz_664 
  0x44000823, 0x215c02a4, 0x2a002d08, 0x30321604,   // uk.kk.un_880 da.sa.jw_433  sk.mt.un_430 hr.bs.uz_332 
  0x38004e11, 0x755f5a0c, 0x575f500c, 0x242d17a0,   // ay.tk.un_630 sm.tn.nso_543  fj.tn.na_543 sr.sk.eo_322 
  0x02645a08, 0x5f005a0e, 0x364415ad, 0x0c041305,   // sm.lg.da_443 sm.tn.un_550  un.kk.ab_643 et.fi.sv_333 
  // [14af0]
  0x3004110c, 0x3412300d, 0x68005921, 0x1048360d,   // ro.ru.uz_543 uz.ur.ps_554  rn.ig.un_860 ab.tt.be_554 
  0x034d02ad, 0x08230408, 0x4815250b, 0x401b0604,   // da.aa.nl_643 ru.ky.uk_443  mn.tt.un_520 de.tr.lb_332 
  0x3d28340b, 0x0400460c, 0x2c0611a0, 0x04484455,   // ps.sd.ku_542 qu.fi.un_530  ro.de.fy_322 kk.tt.ru_442 
  0x184702a0, 0x23150407, 0x400406ee, 0x2e2f3e08,   // da.sn.ga_322 ru.ky.un_420  de.fi.lb_422 rm.su.fo_443 
  // [14b00]
  0x1c1d2fa0, 0x25290f0c, 0x35230407, 0x1d3e0907,   // su.la.id_322 lv.sl.eu_543  ru.ky.tg_432 pl.rm.la_432 
  0x40222502, 0x13000a07, 0x0a0744ee, 0x400406a4,   // eu.oc.lb_222 pt.et.un_420  kk.bg.mk_422 de.fi.lb_433 
  0x17152307, 0x48303713, 0x4f453fa4, 0x110315a0,   // ky.sr.un_420 ba.uz.tt_665  af.ln.bi_433 un.nl.ro_322 
  0x15002704, 0x21026a07, 0x2d4b4609, 0x130c4807,   // gd.un.un_320 haw.da.jw_432  qu.mi.sk_444 tt.sv.et_432 
  // [14b10]
  0x2e004d22, 0x4702730c, 0x2b160207, 0x352447ad,   // aa.fo.un_870 ny.da.sn_543  da.hr.vi_432 sn.eo.zu_643 
  0x321656ee, 0x280273a9, 0x51001c05, 0x353023ad,   // mg.hr.bs_422 ny.da.sw_544  id.kl.un_330 ky.uz.tg_643 
  0x45735ea9, 0x131502a0, 0x28025e13, 0x17000a20,   // ts.ny.ln_544 da.et.un_320  ts.da.sw_665 mk.sr.un_850 
  0x153f0305, 0x17504707, 0x3f032707, 0x2f353402,   // nl.af.un_333 sn.fj.sr_432  gd.nl.af_432 xh.zu.su_222 
  // [14b20]
  0x4b4950af, 0x09005512, 0x364b7513, 0x3548375a,   // fj.to.mi_655 rw.pl.un_640  nso.mi.gn_665 ba.tt.tg_553 
  0x5c005505, 0x48373604, 0x44042307, 0x5700130d,   // rw.sa.un_330 ab.ba.tt_332  ky.ru.kk_432 et.na.un_540 
  0x040c1355, 0x1b0660a7, 0x67006413, 0x571d01a4,   // et.sv.fi_442 vo.de.tr_532  lg.ak.un_650 en.la.na_433 
  0x061348ad, 0x19214e0c, 0x40001b0b, 0x30461bec,   // tt.et.de_643 ay.jw.gl_543  tr.lb.un_520 tr.qu.uz_644 
  // [14b30]
  0x4e000e22, 0x22270608, 0x65002012, 0x36004414,   // is.ay.un_870 de.gd.oc_443  sq.gv.un_640 kk.ab.un_660 
  0x06006011, 0x0a150704, 0x39185e07, 0x2000400c,   // vo.de.un_630 bg.mk.un_320  ts.ga.br_432 lb.sq.un_530 
  0x2a5f7307, 0x180115a0, 0x30647305, 0x430501a0,   // ny.tn.mt_432 un.en.ga_322  ny.lg.uz_333 en.fr.ie_322 
  0x01236308, 0x0b004707, 0x183d3ca7, 0x1b595560,   // sco.ca.en_443 sn.es.un_420  ug.ku.ar_532 rw.rn.tr_664 
  // [14b40]
  0x09003b05, 0x2c122009, 0x46003b0c, 0x35342802,   // so.pl.un_330 sq.hu.fy_444  so.qu.un_530 sw.xh.zu_222 
  0x542e0ea4, 0x2510230e, 0x28005105, 0x31136007,   // is.fo.ik_433 ky.be.mn_555  kl.sw.un_330 vo.et.az_432 
  0x64451208, 0x3455640c, 0x55644511, 0x4a000d0c,   // hu.ln.lg_443 lg.rw.xh_543  ln.lg.rw_653 cs.yo.un_530 
  0x64005108, 0x2c080e07, 0x371511a4, 0x3d1234a0,   // kl.lg.un_430 is.no.fy_432  ro.ba.un_430 ps.ur.ku_322 
  // [14b50]
  0x07fc1512, 0x17621e0b, 0x257662ad, 0x23381012,   // un.zzp.it_654 ms.kha.sr_542  kha.crs.eu_643 be.tk.ky_654 
  0x30650ca0, 0x64344c04, 0x5d007908, 0x785451ad,   // sv.gv.uz_322 wo.xh.lg_332  war.ss.un_430 kl.ik.ve_643 
  0xfc002e07, 0x334b5613, 0x44303807, 0x49006b07,   // fo.zzp.un_420 mg.mi.nn_665  tk.uz.kk_432 ceb.to.un_420 
  0x47494ba7, 0x120cfe0c, 0x5b004821, 0x13063e02,   // mi.to.sn_532 tlh.sv.hu_543  tt.sg.un_860 rm.de.et_222 
  // [14b60]
  0x30645502, 0x562342a0, 0x1a1e1c04, 0x0a001b02,   // rw.lg.uz_222 co.ca.mg_322  id.ms.tl_332 tr.pt.un_220 
  0x51004c0d, 0x11050ea4, 0x0d00450e, 0x2a005621,   // wo.kl.un_540 is.fr.ro_433  ln.cs.un_550 mg.mt.un_860 
  0x5d7302a4, 0x1e18110c, 0x552059ee, 0x2a59550d,   // da.ny.ss_433 ro.ga.ms_543  rn.sq.rw_422 rw.rn.mt_554 
  0x17472a04, 0x5600120e, 0x2f287308, 0x792a460b,   // mt.sn.sr_332 hu.mg.un_550  ny.sw.su_443 qu.mt.war_542 
  // [14b70]
  0x5d2f20ee, 0x2e670e08, 0x07002708, 0x04092504,   // sq.su.ss_422 is.ak.fo_443  gd.it.un_430 eu.pl.fi_332 
  0x12005612, 0x101b06a7, 0x162f2aee, 0x23202fa4,   // mg.hu.un_640 de.tr.lt_532  mt.su.hr_422 su.sq.ca_433 
  0xfc5d3404, 0x2f1c4002, 0x0b0a20a0, 0x1d431155,   // xh.ss.zzp_332 lb.id.su_222  sq.pt.es_322 ro.ie.la_442 
  0x32002a05, 0x2c0204ee, 0x46062509, 0x2e005e04,   // mt.bs.un_330 fi.da.fy_422  eu.de.qu_444 ts.fo.un_320 
  // [14b80]
  0x5e353404, 0x226231af, 0x583b5e08, 0x4000340e,   // xh.zu.ts_332 az.kha.oc_655  ts.so.om_443 xh.lb.un_550 
  0x345d6e12, 0x30314dec, 0x26004d0d, 0x400c06a9,   // hmn.ss.xh_654 aa.az.uz_644  aa.ia.un_540 de.sv.lb_544 
  0x0a2f1d09, 0x42353404, 0x10006504, 0x68650404,   // la.su.pt_444 xh.zu.co_332  gv.lt.un_320 fi.gv.ig_332 
  0x10003402, 0x113b48a9, 0x3b303104, 0x61355d08,   // xh.lt.un_220 tt.so.ro_544  az.uz.so_332 ss.zu.za_443 
  // [14b90]
  0x12001319, 0x261d5c08, 0x5502210c, 0x35080707,   // et.hu.un_750 sa.la.ia_443  jw.da.rw_543 bg.uk.tg_432 
  0x65001002, 0x09107907, 0x212334a7, 0x04103ba0,   // lt.gv.un_220 war.lt.pl_432  ps.ky.fa_532 so.lt.fi_322 
  0x12001d0d, 0x18003b1a, 0x3b002e1a, 0x6500030d,   // la.hu.un_540 ks.ar.un_760  fo.so.un_760 nl.gv.un_540 
  0x5a303b08, 0x0c5a2e0d, 0x3b305a08, 0x2c036555,   // so.uz.sm_443 fo.sm.sv_554  sm.uz.so_443 gv.nl.fy_442 
  // [14ba0]
  0x3b305908, 0x323f2da0, 0x062855ee, 0x0c643b08,   // rn.uz.so_443 sk.af.bs_322  rw.sw.de_422 so.lg.sv_443 
  0x06004a02, 0x634b3607, 0x3b305a12, 0x23371707,   // yo.de.un_220 gn.mi.sco_432  sm.uz.so_654 sr.ba.ky_432 
  0x255c7907, 0x5a1330a7, 0x10190a13, 0x52024008,   // war.sa.eu_432 uz.et.sm_532  pt.gl.lt_665 lb.da.ha_443 
  0x270f100c, 0x68303b08, 0x19483b07, 0x3710250c,   // lt.lv.gd_543 so.uz.ig_443  so.tt.gl_432 eu.lt.st_543 
  // [14bb0]
  0x303b640c, 0x495a6308, 0x1f4f02ee, 0x290309ee,   // lg.so.uz_543 sco.sm.to_443  da.bi.cy_422 pl.nl.sl_422 
  0x0c4806a0, 0x20032cee, 0x46553bee, 0x0c3b30ec,   // de.tt.sv_322 fy.nl.sq_422  so.rw.qu_422 uz.so.sv_644 
  0x34213b12, 0x505a30a9, 0x48130cee, 0x0a001305,   // ks.fa.ps_654 uz.sm.fj_544  sv.et.tt_422 et.pt.un_330 
  0x474006a7, 0x2d006019, 0x13470409, 0x286a4b55,   // de.lb.sn_532 vo.sk.un_750  fi.sn.et_444 mi.haw.sw_442 
  // [14bc0]
  0x52495a12, 0x64004a08, 0x443530ad, 0x43001f14,   // sm.to.ha_654 yo.lg.un_430  uz.tg.kk_643 cy.ie.un_660 
  0x2c000e1b, 0x51020e07, 0x63002205, 0x062c03a0,   // is.fy.un_770 is.da.kl_432  oc.sco.un_330 nl.fy.de_322 
  0x04081305, 0x0f001f13, 0x363e060c, 0x330708af,   // et.no.fi_333 cy.lv.un_650  de.rm.gn_543 no.it.nn_655 
  0x05002211, 0x054222ec, 0x072c02af, 0x400c4c07,   // oc.fr.un_630 oc.co.fr_644  da.fy.it_655 wo.sv.lb_432 
  // [14bd0]
  0x4804100c, 0x3800040c, 0x02000f14, 0x4a3e42a9,   // be.ru.tt_543 fi.tk.un_530  lv.da.un_660 co.rm.yo_544 
  0x12303d0d, 0x1b1c4c02, 0x50381ba4, 0x3e00420c,   // ku.uz.ur_554 wo.id.tr_222  tr.tk.fj_433 co.rm.un_530 
  0x2e041d07, 0x13070404, 0x2e0e6504, 0x22231d04,   // la.fi.fo_432 fi.it.et_332  gv.is.fo_332 la.ca.oc_332 
  0x25151505, 0x46003813, 0x2e4c0e0d, 0x073748a0,   // un.mn.un_330 tk.qu.un_650  is.wo.fo_554 tt.ba.bg_322 
  // [14be0]
  0x070a04a7, 0x64002c08, 0x2c1d0e0c, 0x36373c04,   // ru.mk.bg_532 fy.lg.un_430  is.la.fy_543 ug.ba.ab_332 
  0x44343c04, 0x362d0da4, 0x320c13ee, 0x1b00300e,   // ug.ps.kk_332 cs.sk.gn_433  et.sv.bs_422 uz.tr.un_550 
  0x65003707, 0x2012220c, 0x3b1015a4, 0x39365608,   // st.gv.un_420 oc.hu.sq_543  un.lt.so_433 mg.gn.br_443 
  0x304663a0, 0x38353712, 0x55600d11, 0x0b002d08,   // sco.qu.uz_322 ba.tg.tk_654  cs.vo.rw_653 sk.es.un_430 
  // [14bf0]
  0x30134e0c, 0x043525a7, 0x10190f09, 0x1f40600c,   // ay.et.uz_543 mn.tg.ru_532  lv.gl.lt_444 vo.lb.cy_543 
  0x3b630204, 0x033f0ca9, 0x76696008, 0x33082c0c,   // da.sco.so_332 sv.af.nl_544  vo.mfe.crs_443 fy.no.nn_543 
  0x5f10600c, 0x60001f08, 0x22242d12, 0x1f3957ee,   // vo.lt.tn_543 cy.vo.un_430  sk.eo.oc_654 na.br.cy_422 
  0x5c363e11, 0x34011812, 0x21001235, 0x480c0605,   // rm.gn.sa_653 ar.iw.ps_654  ur.fa.un_A90 de.sv.tt_333 
  
  // [14c00]
  0x30153808, 0x31481b0b, 0x04130ca4, 0x1b00fc08,   // tk.uz.un_430 tr.tt.az_542  sv.et.fi_433 zzp.tr.un_430 
  0x48002111, 0x100ffc0c, 0x0a001b0d, 0x32522907,   // jw.tt.un_630 zzp.lv.lt_543  tr.pt.un_540 sl.ha.bs_432 
  0x27090d02, 0x5c48300c, 0x301b39a7, 0x213d120d,   // cs.pl.gd_222 uz.tt.sa_543  br.tr.uz_532 ur.ku.fa_554 
  0x5c000209, 0x353010a4, 0x3430215a, 0x341830a4,   // da.sa.un_440 be.uz.tg_433  fa.uz.ps_553 uz.ar.ps_433 
  // [14c10]
  0x31001b20, 0x36450e04, 0x1a6a5655, 0x37504ba0,   // tr.az.un_850 is.ln.gn_332  mg.haw.tl_442 mi.fj.st_322 
  0x0b1056ee, 0x406e060c, 0x24570d05, 0x2e180ba0,   // mg.lt.es_422 de.hmn.lb_543  cs.na.eo_333 es.ga.fo_322 
  0x5322050c, 0x3b343d11, 0x24320dee, 0x066b57ad,   // fr.oc.ht_543 ku.ps.ks_653  cs.bs.eo_422 na.ceb.de_643 
  0x071d19ee, 0x24002908, 0x190b24a4, 0x183305a6,   // gl.la.it_422 sl.eo.un_430  eo.es.gl_433 fr.nn.ga_521 
  // [14c20]
  0x0b4006ee, 0x1a430a05, 0x07173604, 0x3800302a,   // de.lb.es_422 pt.ie.tl_333  ab.sr.bg_332 uz.tk.un_970 
  0x3515045a, 0x4835300e, 0x1038370c, 0x3f390312,   // ru.tg.un_530 uz.tg.tt_555  ba.tk.be_543 nl.br.af_654 
  0x53000414, 0x020d4c05, 0x2d0d3804, 0x473f04ad,   // fi.ht.un_660 wo.cs.da_333  tk.cs.sk_332 fi.af.sn_643 
  0x1659380c, 0x5a284904, 0x2c566408, 0x05006319,   // tk.rn.hr_543 to.sw.sm_332  lg.mg.fy_443 sco.fr.un_750 
  // [14c30]
  0x504061a4, 0x032c3f02, 0x1e004f07, 0x2c05650c,   // za.lb.fj_433 af.fy.nl_222  bi.ms.un_420 gv.fr.fy_543 
  0x3f0339ad, 0x1c5c1302, 0x32176409, 0x2f004d0d,   // br.nl.af_643 bh.sa.mr_222  lg.sr.bs_444 aa.su.un_540 
  0x0b004704, 0x123c3ba7, 0x3e403955, 0x390d0209,   // sn.es.un_320 ks.ug.ur_532  br.lb.rm_442 da.cs.br_444 
  0x1e001c0d, 0x05297612, 0x22390511, 0x25071702,   // id.ms.un_540 crs.sl.fr_654  fr.br.oc_653 sr.bg.mn_222 
  // [14c40]
  0x040d0904, 0x38002922, 0x0d000920, 0x0276530d,   // pl.cs.fi_332 sl.tk.un_870  hi.ne.un_850 ht.crs.da_554 
  0x5d2a73a4, 0x0c093804, 0x40001608, 0xfe2873a7,   // ny.mt.ss_433 tk.pl.sv_332  hr.lb.un_430 ny.sw.tlh_532 
  0x32162ca0, 0x3f032205, 0x40120612, 0x5440060c,   // fy.hr.bs_322 oc.nl.af_333  de.hu.lb_654 de.lb.ik_543 
  0x04401309, 0x0e2f540c, 0x123b210e, 0x645568ee,   // et.lb.fi_444 ik.su.is_543  fa.ks.ur_555 ig.rw.lg_422 
  // [14c50]
  0x130c1207, 0x45321705, 0x302e060c, 0x21004508,   // hu.sv.et_432 sr.bs.ln_333  de.fo.uz_543 ln.jw.un_430 
  0x2c00200d, 0x05002222, 0x27645107, 0x35483712,   // sq.fy.un_540 oc.fr.un_870  kl.lg.gd_432 ba.tt.tg_654 
  0x2b421da7, 0x19002e07, 0x6400451b, 0x2300150e,   // la.co.vi_532 fo.gl.un_420  ln.lg.un_770 un.ky.un_550 
  0x2e003813, 0x20002a0c, 0x2e4d1f08, 0x405101a4,   // tk.fo.un_650 mt.sq.un_530  cy.aa.fo_443 en.kl.lb_433 
  // [14c60]
  0x7927010c, 0x28006b0b, 0x5c00fe20, 0x0100fe22,   // en.gd.war_543 ceb.sw.un_520  tlh.sa.un_850 tlh.en.un_870 
  0x3c0a36a4, 0x151d010c, 0x2c27010b, 0x102515a4,   // ab.mk.ug_433 en.la.un_543  en.gd.fy_542 un.mn.be_433 
  0x38000605, 0x2e001f02, 0x6842fe12, 0x6542010b,   // de.tk.un_330 cy.fo.un_220  tlh.co.ig_654 en.co.gv_542 
  0x5c4268a7, 0x2c2d0d5a, 0x23154407, 0x09101f02,   // ig.co.sa_532 cs.sk.fy_553  kk.ky.un_420 cy.lt.pl_222 
  // [14c70]
  0x1a42fea4, 0x10003f02, 0xfe270112, 0x52276707,   // tlh.co.tl_433 af.lt.un_220  en.gd.tlh_654 ak.gd.ha_432 
  0x30080707, 0x40481302, 0x381b3155, 0x061358a0,   // bg.uk.uz_432 et.tt.lb_222  az.tr.tk_442 om.et.de_322 
  0x25353055, 0x40033f08, 0x04000a10, 0x3f034dee,   // uz.tg.mn_442 af.nl.lb_443  pt.fi.un_620 aa.nl.af_422 
  0x2308350b, 0x042330ee, 0x0c0657a9, 0x0a0748a4,   // tg.uk.ky_542 uz.ky.ru_422  na.de.sv_544 tt.bg.mk_433 
  // [14c80]
  0x400c06a7, 0x291358a0, 0x2500302a, 0x21003c0d,   // de.sv.lb_532 om.et.sl_322  uz.mn.un_970 ug.fa.un_540 
  0x13405804, 0x381b31ec, 0x31003809, 0x400c0608,   // om.lb.et_332 az.tr.tk_644  tk.az.un_440 de.sv.lb_443 
  0x400c060c, 0x1900220c, 0x02050ea6, 0x61001021,   // de.sv.lb_543 oc.gl.un_530  is.fr.da_521 lt.za.un_860 
  0x76690ea4, 0x2200120c, 0x53003108, 0x37071108,   // is.mfe.crs_433 hu.oc.un_530  az.ht.un_430 ro.bg.ba_443 
  // [14c90]
  0x350704ee, 0x19002507, 0x6e007914, 0x282c12ad,   // ru.bg.tg_422 eu.gl.un_420  war.hmn.un_660 hu.fy.sw_643 
  0x101e4f07, 0x1b002e07, 0x48353013, 0x0a006e07,   // bi.ms.lt_432 fo.tr.un_420  uz.tg.tt_665 hmn.pt.un_420 
  0x40063307, 0x15301504, 0x48043fed, 0x042c10ad,   // nn.de.lb_432 un.uz.un_332  af.fi.tt_622 lt.fy.fi_643 
  0x38001b18, 0x2d2b56a0, 0x51584d09, 0x3b545111,   // tr.tk.un_740 mg.vi.sk_322  aa.om.kl_444 kl.ik.so_653 
  // [14ca0]
  0x044817ee, 0x12213d13, 0x100433a0, 0x044751a4,   // sr.tt.ru_422 ku.fa.ur_665  nn.fi.lt_322 kl.sn.fi_433 
  0x1b001502, 0x584d3b0c, 0x046458a9, 0x28585107,   // un.tr.un_220 so.aa.om_543  om.lg.fi_544 kl.om.sw_432 
  0x052218ad, 0x4222055a, 0x02466408, 0x4a5a51a4,   // ga.oc.fr_643 fr.oc.co_553  lg.qu.da_443 kl.sm.yo_433 
  0x4a000205, 0x071d4207, 0x580451a4, 0x3b001d12,   // da.yo.un_330 co.la.it_432  kl.fi.om_433 la.so.un_640 
  // [14cb0]
  0x6a005a1a, 0x0b645ca7, 0x12002123, 0x330824ee,   // sm.haw.un_760 sa.lg.es_532  fa.ur.un_880 eo.no.nn_422 
  0x2f1e210c, 0x211c1ea7, 0x371004a4, 0x4f246e0d,   // jw.ms.su_543 ms.id.jw_532  ru.be.ba_433 hmn.eo.bi_554 
  0x24383112, 0x40060ca7, 0x0c004819, 0x383023ec,   // az.tk.eo_654 sv.de.lb_532  tt.sv.un_750 ky.uz.tk_644 
  0x153817ad, 0x080a17a7, 0x1b1039ee, 0x38314805,   // sr.tk.un_643 sr.mk.uk_532  br.lt.tr_422 tt.az.tk_333 
  // [14cc0]
  0x4e004635, 0x20000302, 0x060c38a4, 0x122818ec,   // qu.ay.un_A90 nl.sq.un_220  tk.sv.de_433 ar.sd.ur_644 
  0x066048a4, 0x5a003907, 0x40060c55, 0x0d092da0,   // tt.vo.de_433 br.sm.un_420  sv.de.lb_442 sk.pl.cs_322 
  0x46210ea0, 0x54000f1a, 0x251715a0, 0x6200461b,   // is.jw.qu_322 lv.ik.un_760  un.sr.mn_322 qu.kha.un_770 
  0x04480c07, 0x40620612, 0x401d06af, 0x3b2a58a0,   // sv.tt.fi_432 de.kha.lb_654  de.la.lb_655 om.mt.so_322 
  // [14cd0]
  0x0e4211a0, 0x3b4d6baf, 0xfe003b08, 0x1d4651ad,   // ro.co.is_322 ceb.aa.so_655  so.tlh.un_430 kl.qu.la_643 
  0x0f2a6507, 0xfe006e0d, 0x10625707, 0x0717150c,   // gv.mt.lv_432 hmn.tlh.un_540  na.kha.lt_432 un.sr.bg_543 
  0x46003812, 0x0b121908, 0x30383604, 0x1d2538a4,   // tk.qu.un_640 gl.hu.es_443  ab.tk.uz_332 tk.eu.la_433 
  0x420e2ea4, 0x216b620c, 0x281b3904, 0x3b2a4d13,   // fo.is.co_433 kha.ceb.jw_543  br.tr.sw_332 aa.mt.so_665 
  // [14ce0]
  0x02060da6, 0x421d0107, 0x595501a0, 0x056315a7,   // cs.de.da_521 en.la.co_432  en.rw.rn_322 un.sco.fr_532 
  0x3b026e11, 0x2000031a, 0x477869a9, 0x190b46ee,   // hmn.da.so_653 nl.sq.un_760  mfe.ve.sn_544 qu.es.gl_422 
  0x122818a9, 0x374430a4, 0x6368010b, 0x241d4313,   // ar.sd.ur_544 uz.kk.ba_433  en.ig.sco_542 ie.la.eo_665 
  0x1d261905, 0x76691baf, 0x100a2607, 0x2e00190b,   // gl.ia.la_333 tr.mfe.crs_655  ia.pt.lt_432 gl.fo.un_520 
  // [14cf0]
  0x32200902, 0x1d0f10a4, 0x64072ca9, 0x22532309,   // pl.sq.bs_222 lt.lv.la_433  fy.it.lg_544 ca.ht.oc_444 
  0x1d0c260c, 0x13531ba0, 0x4c002208, 0x5706255a,   // ia.sv.la_543 tr.ht.et_322  oc.wo.un_430 eu.de.na_553 
  0x052c03ee, 0x12000922, 0x2e1d0a04, 0x400c0207,   // nl.fy.fr_422 pl.hu.un_870  pt.la.fo_332 da.sv.lb_432 
  0x0b001002, 0x0e4c0a09, 0x3c2330a4, 0x0e190aa6,   // lt.es.un_220 pt.wo.is_444  uz.ky.ug_433 pt.gl.is_521 
  // [14d00]
  0x07003009, 0x0c001b02, 0x46381907, 0x3e001904,   // uz.bg.un_440 tr.sv.un_220  gl.tk.qu_432 gl.rm.un_320 
  0x10001904, 0x071504a7, 0x37000405, 0x040e4860,   // gl.lt.un_320 ru.bg.un_520  ru.ba.un_330 tt.is.fi_664 
  0x23002a0c, 0x2d0d1faf, 0x2d0d0904, 0x232b19ee,   // mt.ca.un_530 cy.cs.sk_655  pl.cs.sk_332 gl.vi.ca_422 
  0x11003813, 0x3548230c, 0x11364708, 0x58024f0c,   // tk.ro.un_650 ky.tt.tg_543  sn.gn.ro_443 bi.da.om_543 
  // [14d10]
  0x073715ee, 0xfc00101a, 0x3400610c, 0x3c002311,   // un.ba.bg_422 lt.zzp.un_760  za.xh.un_530 ky.ug.un_630 
  0x25004a19, 0x152d0d08, 0x38004a1a, 0x47464a07,   // yo.eu.un_750 cs.sk.un_443  yo.tk.un_760 yo.qu.sn_432 
  0x30314809, 0x30211255, 0xfc343512, 0x1500152a,   // tt.az.uz_444 ur.fa.uz_442  zu.xh.zzp_654 un.un.un_970 
  0x0300fe08, 0x2d004008, 0x0700111a, 0x0e006312,   // tlh.nl.un_430 lb.sk.un_430  ro.bg.un_760 sco.is.un_640 
  // [14d20]
  0x58000f08, 0x647355af, 0x2a002418, 0x1c095c12,   // lv.om.un_430 rw.ny.lg_655  eo.mt.un_740 sa.hi.mr_654 
  0x11001f02, 0x5c005a0b, 0x3b005105, 0x50005122,   // cy.ro.un_220 sm.sa.un_520  kl.so.un_330 kl.fj.un_870 
  0x2f1b21a7, 0x383f03a0, 0x2c004804, 0x35005104,   // jw.tr.su_532 nl.af.tk_322  tt.fy.un_320 kl.zu.un_320 
  0x50002f07, 0x06480c05, 0x3800650b, 0x30005004,   // su.fj.un_420 sv.tt.de_333  gv.tk.un_520 fj.uz.un_320 
  // [14d30]
  0x48041008, 0x12322fa4, 0x30385c04, 0x3418210e,   // be.ru.tt_443 su.bs.hu_433  sa.tk.uz_332 fa.ar.ps_555 
  0x064838a9, 0x1b48465a, 0x79fe2f12, 0x10190b08,   // tk.tt.de_544 qu.tt.tr_553  su.tlh.war_654 es.gl.lt_443 
  0x1d10260d, 0x1c130d11, 0x19261008, 0x073035ad,   // ia.lt.la_554 ne.bh.mr_653  lt.ia.gl_443 tg.uz.bg_643 
  0x181d27a0, 0x52215e07, 0x30003705, 0x18000a08,   // gd.la.ga_322 ts.jw.ha_432  ba.uz.un_330 pt.ga.un_430 
  // [14d40]
  0x02462f04, 0x230503a4, 0x596301af, 0x04006319,   // su.qu.da_332 nl.fr.ca_433  en.sco.rn_655 sco.fi.un_750 
  0x1b4e46ad, 0x0f041355, 0x30555355, 0x1e00460c,   // qu.ay.tr_643 et.fi.lv_442  ht.rw.uz_442 qu.ms.un_530 
  0x521028a4, 0x0e2d0d0c, 0x6e004912, 0x2b1d15a0,   // sw.lt.ha_433 cs.sk.is_543  to.hmn.un_640 un.la.vi_322 
  0x02431d0c, 0x4c00490c, 0x0f103312, 0x1d3e1111,   // la.ie.da_543 to.wo.un_530  nn.lt.lv_654 ro.rm.la_653 
  // [14d50]
  0x1d001912, 0x1a422108, 0x10000b05, 0x422601a0,   // gl.la.un_640 jw.co.tl_443  es.lt.un_330 en.ia.co_322 
  0x3b0651ad, 0x5c0f100c, 0x50221d07, 0x25000f2b,   // kl.de.so_643 lt.lv.sa_543  la.oc.fj_432 lv.eu.un_980 
  0x33026ba0, 0x535a490c, 0x34183d04, 0x25000f1a,   // ceb.da.nn_322 to.sm.ht_543  ku.ar.ps_332 lv.eu.un_760 
  0x1c455207, 0x05016307, 0x131033a4, 0x59006319,   // ha.ln.id_432 sco.en.fr_432  nn.lt.et_433 sco.rn.un_750 
  // [14d60]
  0x730f6a05, 0x53494ba7, 0x05004712, 0x04005019,   // haw.lv.ny_333 mi.to.ht_532  sn.fr.un_640 fj.fi.un_750 
  0x5e475109, 0x443c480c, 0x1b2a3e0d, 0x212f1104,   // kl.sn.ts_444 tt.ug.kk_543  rm.mt.tr_554 ro.su.jw_332 
  0xfc314a0c, 0x30006805, 0x474c73a9, 0x18000912,   // yo.az.zzp_543 ig.uz.un_330  ny.wo.sn_544 pl.ga.un_640 
  0x304269a0, 0x2338440c, 0x2e330212, 0x30006404,   // mfe.co.uz_322 kk.tk.ky_543  da.nn.fo_654 lg.uz.un_320 
  // [14d70]
  0x3e004212, 0x1d004c0d, 0x170823a4, 0x38001905,   // co.rm.un_640 wo.la.un_540  ky.uk.sr_433 gl.tk.un_330 
  0x58000302, 0x3c18440c, 0x32006307, 0x48003c36,   // nl.om.un_220 kk.ar.ug_543  sco.bs.un_420 ug.tt.un_AA0 
  0x06121304, 0x43261d13, 0x443530ec, 0x697653a9,   // et.hu.de_332 la.ia.ie_665  uz.tg.kk_644 ht.crs.mfe_544 
  0x4a3b4708, 0x205c67ec, 0x34182305, 0x5c6467ec,   // sn.so.yo_443 ak.sa.sq_644  ky.ar.ps_333 ak.lg.sa_644 
  // [14d80]
  0x01006314, 0x5c535512, 0x46002f07, 0x213d30ee,   // sco.en.un_660 rw.ht.sa_654  su.qu.un_420 uz.ku.fa_422 
  0x126467ec, 0x0835300c, 0x4c3b6708, 0x64555e0e,   // ak.lg.hu_644 uz.tg.uk_543  ak.so.wo_443 ts.rw.lg_555 
  0x022154a4, 0x5c005512, 0x46000208, 0x4f0115a0,   // ik.jw.da_433 rw.sa.un_640  da.qu.un_430 un.en.bi_322 
  0x21542f08, 0x535c59ad, 0x3f6367af, 0x4c4776a6,   // su.ik.jw_443 rn.sa.ht_643  ak.sco.af_655 crs.sn.wo_521 
  // [14d90]
  0x536952a9, 0x21254da0, 0x7653690c, 0x0100050e,   // ha.mfe.ht_544 aa.eu.jw_322  mfe.ht.crs_543 fr.en.un_550 
  0x10483708, 0x02005408, 0x44233c05, 0x461b3105,   // ba.tt.be_443 ik.da.un_430  ug.ky.kk_333 az.tr.qu_333 
  0x58006821, 0x024e4612, 0x11002d02, 0x383c2312,   // ig.om.un_860 qu.ay.da_654  sk.ro.un_220 ky.ug.tk_654 
  0x12282313, 0x6700490e, 0x4000670b, 0x58510d07,   // ky.sd.ur_665 to.ak.un_550  ak.lb.un_520 cs.kl.om_432 
  // [14da0]
  0x194c1d08, 0x44003005, 0x48083508, 0x11003b0c,   // la.wo.gl_443 uz.kk.un_330  tg.uk.tt_443 so.ro.un_530 
  0x083504a0, 0x033f1bee, 0x291304ad, 0x4e041c0b,   // ru.tg.uk_322 tr.af.nl_422  fi.et.sl_643 id.fi.ay_542 
  0x213028a0, 0x3b5c02ee, 0x0f2176a7, 0x53000904,   // sd.uz.fa_322 da.sa.so_422  crs.jw.lv_532 pl.ht.un_320 
  0x071504ad, 0x1b4d1f0c, 0x13041aa4, 0x532e330b,   // ru.bg.un_630 cy.aa.tr_543  tl.fi.et_433 nn.fo.ht_542 
  // [14db0]
  0x23364808, 0x38004608, 0x24211e07, 0x12183d09,   // tt.ab.ky_443 qu.tk.un_430  ms.jw.eo_432 ku.ar.ur_444 
  0x480735ee, 0x3d442355, 0x123d2104, 0x28001821,   // tg.bg.tt_422 ky.kk.ku_442  fa.ku.ur_332 ar.sd.un_860 
  0x1a002a02, 0x4a292f08, 0x3704070c, 0x3e3b2405,   // mt.tl.un_220 su.sl.yo_443  bg.ru.ba_543 eo.so.rm_333 
  0x491613a0, 0x040a175a, 0x211c2fa7, 0x1d22fea4,   // et.hr.to_322 sr.mk.ru_553  su.id.jw_532 tlh.oc.la_433 
  // [14dc0]
  0x0d00680c, 0xfe001b09, 0x5c0f4604, 0x75075fa9,   // ig.cs.un_530 tr.tlh.un_440  qu.lv.sa_332 tn.it.nso_544 
  0x5e005709, 0x13091c0d, 0x07361d04, 0x16000402,   // na.ts.un_440 mr.hi.bh_554  la.gn.it_332 fi.hr.un_220 
  0x42004b0c, 0x17350aa0, 0x6500500c, 0x3f011dee,   // mi.co.un_530 mk.tg.sr_322  fj.gv.un_530 la.en.af_422 
  0x135c0d12, 0x2c004918, 0xfc6b01a0, 0x19475f0c,   // ne.sa.bh_654 to.fy.un_740  en.ceb.zzp_322 tn.sn.gl_543 
  // [14dd0]
  0x49045055, 0x5000471b, 0x1f185708, 0x13490e04,   // fj.fi.to_442 sn.fj.un_770  na.ga.cy_443 is.to.et_332 
  0x63180e04, 0x456b1a0c, 0x251934a0, 0x2917070c,   // is.ga.sco_332 tl.ceb.ln_543  xh.gl.eu_322 it.sr.sl_543 
  0x34000908, 0x45285e0d, 0x3775730d, 0x49513e07,   // pl.xh.un_430 ts.sw.ln_554  ny.nso.st_554 rm.kl.to_432 
  0x0260105a, 0x365a47a4, 0x5200300c, 0x181f2e12,   // lt.vo.da_553 sn.sm.gn_433  uz.ha.un_530 fo.cy.ga_654 
  // [14de0]
  0x2f164dad, 0x10170813, 0x13020407, 0x5a244ba7,   // aa.hr.su_643 uk.sr.be_665  fi.da.et_432 mi.eo.sm_532 
  0x5d2ffea0, 0x261d1da4, 0x29004d18, 0x37041055,   // tlh.su.ss_322 la.la.ia_433  aa.sl.un_740 be.ru.ba_442 
  0x15073804, 0x13000e12, 0x21301807, 0x04000e09,   // tk.bg.un_332 is.et.un_640  ar.uz.fa_432 is.fi.un_440 
  0x32471655, 0x38000d1a, 0x283c3455, 0x041708ee,   // hr.sn.bs_442 cs.tk.un_760  ps.ug.sd_442 uk.sr.ru_422 
  // [14df0]
  0xfc21090c, 0x474a6813, 0xfc293502, 0x21005713,   // pl.jw.zzp_543 ig.yo.sn_665  zu.sl.zzp_222 na.jw.un_650 
  0x32002402, 0x1c211ea9, 0x503809a7, 0x09002804,   // eo.bs.un_220 ms.jw.id_544  pl.tk.fj_532 sw.pl.un_320 
  0x04460c07, 0x025c4704, 0x09375fa7, 0x430c2413,   // sv.qu.fi_432 sn.sa.da_332  tn.st.pl_532 eo.sv.ie_665 
  0x353468a4, 0x0d2d1907, 0x36256a12, 0x4b00490d,   // ig.xh.zu_433 gl.sk.cs_432  haw.eu.gn_654 to.mi.un_540 
  // [14e00]
  0x35344711, 0x654f11ad, 0x4d003419, 0x31005407,   // sn.xh.zu_653 ro.bi.gv_643  xh.aa.un_750 ik.az.un_420 
  0x51001e0d, 0x583054ac, 0x3748380d, 0x423e11a9,   // ms.kl.un_540 ik.uz.om_632  tk.tt.ba_554 ro.rm.co_544 
  0x4600540c, 0x2a0451a4, 0x0d000405, 0x796b2ead,   // ik.qu.un_530 kl.fi.mt_433  fi.cs.un_330 fo.ceb.war_643 
  0x04134d11, 0x2c134dec, 0x3519340b, 0x2a4a65a4,   // aa.et.fi_653 aa.et.fy_644  xh.gl.zu_542 gv.yo.mt_433 
  // [14e10]
  0x2d0d3fa0, 0x29320da0, 0x42024d0b, 0x363865a4,   // af.cs.sk_322 cs.bs.sl_322  aa.da.co_542 gv.tk.gn_433 
  0x6b423e04, 0x3e004214, 0x102e3305, 0x353430a4,   // rm.co.ceb_332 co.rm.un_660  nn.fo.lt_333 uz.xh.zu_433 
  0x303435a7, 0x6b651f04, 0x50543112, 0x394c4d09,   // zu.xh.uz_532 cy.gv.ceb_332  az.ik.fj_654 aa.wo.br_444 
  0x54004e13, 0x1f002614, 0x4805380c, 0x64034804,   // ay.ik.un_650 ia.cy.un_660  tk.fr.tt_543 tt.nl.lg_332 
  // [14e20]
  0x461e3004, 0x304d6512, 0x353430af, 0x2d0d6ea0,   // uz.ms.qu_332 gv.aa.uz_654  uz.xh.zu_655 hmn.cs.sk_322 
  0x3e034202, 0x3b004d1b, 0x07421da7, 0x4a510107,   // co.nl.rm_222 aa.so.un_770  la.co.it_532 en.kl.yo_432 
  0x40040d0c, 0x23000a12, 0x2e0e08a4, 0x1f04650c,   // cs.fi.lb_543 pt.ca.un_640  no.is.fo_433 gv.fi.cy_543 
  0x23220aaf, 0x64006b04, 0x02630112, 0x13005b11,   // pt.oc.ca_655 ceb.lg.un_320  en.sco.da_654 sg.et.un_630 
  // [14e30]
  0x32291609, 0x38102eee, 0x40060ca0, 0x07230409,   // hr.sl.bs_444 fo.lt.tk_422  sv.de.lb_322 ru.ky.bg_444 
  0x38480507, 0x1043120e, 0x79461aa9, 0x3f0f10a7,   // fr.tt.tk_432 hu.ie.lt_555  tl.qu.war_544 lt.lv.af_532 
  0x38220aa0, 0x1b3823a0, 0x31004d0d, 0x0f001204,   // pt.oc.tk_322 ca.tk.tr_322  aa.az.un_540 hu.lv.un_320 
  0x24100f08, 0x30362512, 0x57004814, 0x3b464c07,   // lv.lt.eo_443 mn.ab.uz_654  tt.na.un_660 wo.qu.so_432 
  // [14e40]
  0x28123402, 0x18fc1ba9, 0x353c0aa4, 0x0a4815a4,   // ps.ur.sd_222 tr.zzp.ga_544  mk.ug.tg_433 un.tt.mk_433 
  0x343b21ec, 0x644c3b0d, 0x3b4c6404, 0x4c3b580c,   // fa.ks.ps_644 so.wo.lg_554  lg.wo.so_332 om.so.wo_543 
  0x06003e0b, 0x2328125a, 0x3b5864a0, 0x2829130b,   // rm.de.un_520 ur.sd.ky_553  lg.om.so_322 et.sl.sw_542 
  0x500e01a0, 0x755f290c, 0x135f1914, 0x755f29ec,   // en.is.fj_322 sl.tn.nso_543  gl.tn.et_666 sl.tn.nso_644 
  // [14e50]
  0x643b4c0c, 0x2a002908, 0x4430110c, 0x2e405a04,   // wo.so.lg_543 sl.mt.un_430  ro.uz.kk_543 sm.lb.fo_332 
  0x644c4da9, 0x5a005f05, 0x59552914, 0x0a003102,   // aa.wo.lg_544 tn.sm.un_330  sl.rw.rn_666 az.pt.un_220 
  0x643b4c08, 0x5f647508, 0x59005021, 0x30234460,   // wo.so.lg_443 nso.lg.tn_443  fj.rn.un_860 kk.ky.uz_664 
  0x360a37a0, 0x24093904, 0x644a3fa0, 0x33002e13,   // ba.mk.ab_322 br.pl.eo_332  af.yo.lg_322 fo.nn.un_650 
  // [14e60]
  0x5a0e290c, 0x5f595504, 0x295913a9, 0x5f5a13ec,   // sl.is.sm_543 rw.rn.tn_332  et.rn.sl_544 et.sm.tn_644 
  0x5f295aa4, 0x1b052207, 0x0a00480e, 0x16002a07,   // sm.sl.tn_433 oc.fr.tr_432  tt.mk.un_550 mt.hr.un_420 
  0x0a382204, 0x230a0407, 0x154306ad, 0x042344a6,   // oc.tk.pt_332 ru.mk.ky_432  de.ie.un_643 kk.ky.ru_521 
  0x230a2213, 0x09161708, 0x161709a7, 0x6a4b490d,   // oc.pt.ca_665 sr.hr.pl_443  pl.sr.hr_532 to.mi.haw_554 
  // [14e70]
  0x4b006a2b, 0x6a005a2a, 0x5a006a2a, 0x38002311,   // haw.mi.un_980 sm.haw.un_970  haw.sm.un_970 ca.tk.un_630 
  0x5a492213, 0x46fa3408, 0x23190b13, 0x213d340b,   // oc.to.sm_665 xh.nr.qu_443  es.gl.ca_665 ps.ku.fa_542 
  0x40003e02, 0x5a00250e, 0x65006113, 0x4f004b09,   // rm.lb.un_220 eu.sm.un_550  za.gv.un_650 mi.bi.un_440 
  0x4b002808, 0x5a004b2c, 0x2a003704, 0x1e1c61ee,   // sw.mi.un_430 mi.sm.un_990  st.mt.un_320 za.id.ms_422 
  // [14e80]
  0x205d6011, 0x33556ba7, 0x0c485b5a, 0x4500670d,   // vo.ss.sq_653 ceb.rw.nn_532  sg.tt.sv_553 ak.ln.un_540 
  0x2e0e3b13, 0x3b006522, 0x5a005307, 0x5e1b3b11,   // so.is.fo_665 gv.so.un_870  ht.sm.un_420 so.tr.ts_653 
  0x6022050c, 0x24005604, 0x23183da4, 0x30070808,   // fr.oc.vo_543 mg.eo.un_320  ku.ar.ky_433 uk.bg.uz_443 
  0x15002a04, 0x0430fcad, 0x242d0d55, 0x3b650412,   // mt.un.un_320 zzp.uz.fi_643  cs.sk.eo_442 fi.gv.so_654 
  // [14e90]
  0x64500907, 0x4d1b3b0c, 0x34003b09, 0x3c003829,   // pl.fj.lg_432 so.tr.aa_543  ks.ps.un_440 tk.ug.un_960 
  0x0a23225a, 0x443c0408, 0x130e2e55, 0x0e003b05,   // oc.ca.pt_553 ru.ug.kk_443  fo.is.et_442 so.is.un_330 
  0x1828230e, 0x3b002e08, 0x17071005, 0x4600302b,   // ky.sd.ar_555 fo.so.un_430  be.bg.sr_333 uz.qu.un_980 
  0x6b2f7907, 0x483138a9, 0x171535a6, 0x343d3b07,   // war.su.ceb_432 tk.az.tt_544  tg.sr.un_510 ks.ku.ps_432 
  // [14ea0]
  0x120d20a0, 0x63364708, 0x130d1ba4, 0x2d1d12ee,   // sq.cs.hu_322 sn.gn.sco_443  tr.cs.et_433 hu.la.sk_422 
  0x63000308, 0x330843a0, 0x36075a14, 0x3428180b,   // nl.sco.un_430 ie.no.nn_322  sm.it.gn_666 ar.sd.ps_542 
  0x31174707, 0x20230a04, 0x2300340c, 0x122047af,   // sn.sr.az_432 pt.ca.sq_332  ps.ky.un_530 sn.sq.hu_655 
  0x1b33360c, 0x0a381b07, 0x0c006408, 0x5c12290d,   // gn.nn.tr_543 tr.tk.pt_432  lg.sv.un_430 sl.hu.sa_554 
  // [14eb0]
  0x135c26a9, 0x1d16200c, 0x1d00200c, 0x09002c08,   // ia.sa.et_544 sq.hr.la_543  sq.la.un_530 fy.pl.un_430 
  0x32000c04, 0x0a23200c, 0x36110404, 0xfc000c22,   // sv.bs.un_320 sq.ca.pt_543  ru.ro.ab_332 sv.zzp.un_870 
  0x0d13090c, 0x33003902, 0x0665fc04, 0x1a25690d,   // hi.bh.ne_543 br.nn.un_220  zzp.gv.de_332 mfe.eu.tl_554 
  0x18001d04, 0x2f211ba7, 0x48253008, 0x21183ba9,   // la.ga.un_320 tr.jw.su_532  uz.mn.tt_443 ks.ar.fa_544 
  // [14ec0]
  0x651c210c, 0x100436ee, 0x7600180c, 0x203b5ca9,   // jw.id.gv_543 ab.ru.be_422  ga.crs.un_530 sa.so.sq_544 
  0x0b353409, 0x332331ad, 0x09464dee, 0xfc1d01ee,   // xh.zu.es_444 az.ca.nn_643  aa.qu.pl_422 en.la.zzp_422 
  0x351715a0, 0x47000904, 0x46000912, 0x11353013,   // un.sr.tg_322 pl.sn.un_320  pl.qu.un_640 uz.tg.ro_665 
  0x1700090b, 0x44170704, 0x27790907, 0x34005009,   // pl.sr.un_520 bg.sr.kk_332  pl.war.gd_432 fj.xh.un_440 
  // [14ed0]
  0x38020907, 0x480408ec, 0x022f2808, 0x35070a09,   // pl.da.tk_432 uk.ru.tt_644  sw.su.da_443 mk.bg.tg_444 
  0x6a640409, 0x18302111, 0x135a5255, 0x5564200c,   // fi.lg.haw_444 fa.uz.ar_653  ha.sm.et_442 sq.lg.rw_543 
  0x2f551ca4, 0x02400613, 0x554659ee, 0x30043505,   // id.rw.su_433 de.lb.da_665  rn.qu.rw_422 tg.ru.uz_333 
  0x6b001a14, 0x52283508, 0x2217290c, 0x5d38290c,   // tl.ceb.un_660 zu.sw.ha_443  sl.sr.oc_543 sl.tk.ss_543 
  // [14ee0]
  0x381a5811, 0x2a5d3512, 0x6404feec, 0x5d005608,   // om.tl.tk_653 zu.ss.mt_654  tlh.fi.lg_644 mg.ss.un_430 
  0x10677309, 0x12047304, 0xfe294005, 0x1e361ca9,   // ny.ak.lt_444 ny.fi.hu_332  lb.sl.tlh_333 id.gn.ms_544 
  0x355647ee, 0x2f004614, 0x5c6b1aaf, 0x3b52460c,   // sn.mg.zu_422 qu.su.un_660  tl.ceb.sa_655 qu.ha.so_543 
  0x5e00501a, 0x2f006405, 0x3f0210a4, 0x3b302108,   // fj.ts.un_760 lg.su.un_330  lt.da.af_433 fa.uz.ks_443 
  // [14ef0]
  0x123b0904, 0x39002f0c, 0x56202c07, 0x3e215207,   // pl.so.hu_332 su.br.un_530  fy.sq.mg_432 ha.jw.rm_432 
  0x09351255, 0x2f003505, 0x05005309, 0x42225304,   // hu.zu.pl_442 zu.su.un_330  ht.fr.un_440 ht.oc.co_332 
  0x4d5320a4, 0x1dfc645a, 0x5900601b, 0x73006412,   // sq.ht.aa_433 lg.zzp.la_553  vo.rn.un_770 lg.ny.un_640 
  0x36122504, 0x2f1246ad, 0x172e2a08, 0x39005002,   // eu.hu.gn_332 qu.hu.su_643  mt.fo.sr_443 fj.br.un_220 
  // [14f00]
  0x736434a0, 0x29003e19, 0x0e001602, 0x4600090c,   // xh.lg.ny_322 rm.sl.un_750  hr.is.un_220 pl.qu.un_530 
  0x082537a0, 0x732a2955, 0x22232d07, 0x2e004b07,   // ba.mn.uk_322 sl.mt.ny_442  sk.ca.oc_432 mi.fo.un_420 
  0x4b042fa7, 0x0c08fc0c, 0x183c44ad, 0x08040aa4,   // su.fi.mi_532 zzp.no.sv_543  kk.ug.ar_643 mk.ru.uk_433 
  0x311b2a17, 0x233e0704, 0x35252313, 0x285237a0,   // mt.tr.az_753 it.rm.ca_332  ky.mn.tg_665 st.ha.sw_322 
  // [14f10]
  0x13000c19, 0x18000611, 0x30233513, 0x46151fa0,   // sv.et.un_750 de.ga.un_630  tg.ky.uz_665 cy.qu.un_320 
  0x0a171112, 0x48151112, 0x1a00570d, 0x0a00361a,   // ro.sr.mk_654 ro.tt.un_640  na.tl.un_540 gn.pt.un_760 
  0x34004807, 0x18004508, 0x472173a0, 0x7800680e,   // tt.xh.un_420 ln.ga.un_430  ny.jw.sn_322 ig.ve.un_550 
  0x35000a19, 0x403f780c, 0x47354d0b, 0x353467ac,   // mk.tg.un_750 ve.af.lb_543  aa.zu.sn_542 ak.xh.zu_632 
  // [14f20]
  0x18000a09, 0x55005935, 0x16001f04, 0x1f735d07,   // pt.ga.un_440 rn.rw.un_A90  cy.hr.un_320 ss.ny.cy_432 
  0x59755f12, 0x0900280e, 0x161e32a0, 0x3b645804,   // tn.nso.rn_654 sw.pl.un_550  bs.ms.hr_322 om.lg.so_332 
  0x37000608, 0x35345905, 0x44371005, 0x38fc0955,   // de.st.un_430 rn.xh.zu_333  be.ba.kk_333 pl.zzp.tk_442 
  0x3b353408, 0x0a004208, 0x53005d0d, 0x4d3f2c0c,   // xh.zu.so_443 co.pt.un_430  ss.ht.un_540 fy.af.aa_543 
  // [14f30]
  0x352f68a0, 0x2c5703ec, 0x53472808, 0x3b384c07,   // ig.su.zu_322 nl.na.fy_644  sw.sn.ht_443 wo.tk.so_432 
  0x173011a0, 0x384830a4, 0x09005712, 0x153f2b0c,   // ro.uz.sr_322 uz.tt.tk_433  na.pl.un_640 vi.af.un_543 
  0xfc00090d, 0x55005604, 0x28734504, 0x162d0904,   // pl.zzp.un_540 mg.rw.un_320  ln.ny.sw_332 pl.sk.hr_332 
  0x2a005502, 0x353010a7, 0x2d150da0, 0x69002314,   // rw.mt.un_220 be.uz.tg_532  cs.sk.un_320 ca.mfe.un_660 
  // [14f40]
  0x19004d0c, 0x5c30310d, 0x60004819, 0x23103007,   // aa.gl.un_530 az.uz.sa_554  tt.vo.un_750 uz.be.ky_432 
  0x1e1c35ee, 0x3421fc07, 0x103530a7, 0x311bfcaf,   // zu.id.ms_422 zzp.jw.xh_432  uz.tg.be_532 zzp.tr.az_655 
  0x0b2223a9, 0x10082307, 0x102c3807, 0x0f00460c,   // ca.oc.es_544 ky.uk.be_432  tk.fy.lt_432 qu.lv.un_530 
  0x08373007, 0x36046507, 0x3b58fe12, 0x556778a4,   // uz.ba.uk_432 gv.fi.gn_432  tlh.om.so_654 ve.ak.rw_433 
  // [14f50]
  0x45251c12, 0x27001d02, 0x353455a6, 0x47284aa9,   // id.eu.ln_654 la.gd.un_220  rw.xh.zu_521 yo.sw.sn_544 
  0x52004a05, 0x23003414, 0x443d2308, 0x25110804,   // yo.ha.un_330 ps.ky.un_660  ky.ku.kk_443 uk.ro.mn_332 
  0x5955fea4, 0x383c4811, 0x17153808, 0x0f131ba0,   // tlh.rw.rn_433 tt.ug.tk_653  tk.sr.un_430 tr.et.lv_322 
  0x2b003607, 0x24002811, 0x37042302, 0x64282a12,   // gn.vi.un_420 sw.eo.un_630  ky.ru.ba_222 mt.sw.lg_654 
  // [14f60]
  0x23102509, 0x5d5e6b12, 0x341218a0, 0x4804250b,   // mn.be.ky_444 ceb.ts.ss_654  ar.ur.ps_322 mn.ru.tt_542 
  0x083025a7, 0x382afc0c, 0x475e790e, 0x28000904,   // mn.uz.uk_532 zzp.mt.tk_543  war.ts.sn_555 pl.sw.un_320 
  0x5c3b2104, 0x5c464e07, 0xfe791a14, 0x5412460c,   // jw.so.sa_332 ay.qu.sa_432  tl.war.tlh_666 qu.hu.ik_543 
  0x16065807, 0x18420507, 0xfe214605, 0x796b4608,   // om.de.hr_432 fr.co.ga_432  qu.jw.tlh_333 qu.ceb.war_443 
  // [14f70]
  0x21000102, 0x2f00240c, 0x0a001508, 0x214562ee,   // en.jw.un_220 eo.su.un_530  un.mk.un_430 kha.ln.jw_422 
  0x1f2106ee, 0x552628ad, 0x231535ec, 0x42590511,   // de.jw.cy_422 sw.ia.rw_643  tg.ky.un_640 fr.rn.co_653 
  0x4600301a, 0x213927ad, 0x38001811, 0x1b5c4e05,   // uz.qu.un_760 gd.br.jw_643  ga.tk.un_630 ay.sa.tr_333 
  0x632f4604, 0x464e5c04, 0x1f0b2f08, 0x0b104f04,   // qu.su.sco_332 sa.ay.qu_332  su.es.cy_443 bi.lt.es_332 
  // [14f80]
  0x47002b02, 0x190b1005, 0x4c004808, 0x2f270407,   // vi.sn.un_220 lt.es.gl_333  tt.wo.un_430 fi.gd.su_432 
  0x36374814, 0x276a4ca9, 0x3e00220b, 0x233035ec,   // tt.ba.ab_666 wo.haw.gd_544  oc.rm.un_520 tg.uz.ky_644 
  0x19092da0, 0x0c001a04, 0x190b4da0, 0x1100071b,   // sk.pl.gl_322 tl.sv.un_320  aa.es.gl_322 bg.ro.un_770 
  0x2d001819, 0x233d3ca0, 0x400639a4, 0x2dfc22a0,   // ga.sk.un_750 ug.ku.ky_322  br.de.lb_433 oc.zzp.sk_322 
  // [14f90]
  0x2e001816, 0xfe00651a, 0x233508ee, 0x062a1204,   // ga.fo.un_720 gv.tlh.un_760  uk.tg.ky_422 hu.mt.de_332 
  0x5cfe650b, 0x3efe650c, 0x05420aa9, 0x65033f05,   // gv.tlh.sa_542 gv.tlh.rm_543  pt.co.fr_544 af.nl.gv_333 
  0xfe00650e, 0x3e000708, 0x6500fe1b, 0x65004214,   // gv.tlh.un_550 it.rm.un_430  tlh.gv.un_770 co.gv.un_660 
  0x6865fe11, 0x5c006507, 0x123d1807, 0x2a003b14,   // tlh.gv.ig_653 gv.sa.un_420  ar.ku.ur_432 so.mt.un_660 
  // [14fa0]
  0x02003b09, 0x0600130d, 0x272e0e18, 0xfe271812,   // so.da.un_440 et.de.un_540  is.fo.gd_764 ga.gd.tlh_654 
  0x3f06030c, 0x65001819, 0xfe004212, 0x287909ad,   // nl.de.af_543 ga.gv.un_750  co.tlh.un_640 pl.war.sw_643 
  0x07fe65ad, 0x1865fe13, 0x47003909, 0x3438fca4,   // gv.tlh.it_643 tlh.gv.ga_665  br.sn.un_440 zzp.tk.xh_433 
  0x185b600e, 0x28647308, 0x780f47af, 0x2d090d0d,   // vo.sg.ga_555 ny.lg.sw_443  sn.lv.ve_655 cs.pl.sk_554 
  // [14fb0]
  0x5c2d0904, 0xfe002d08, 0x31381f04, 0x050636a9,   // pl.sk.sa_332 sk.tlh.un_430  cy.tk.az_332 gn.de.fr_544 
  0x2400301b, 0x27002013, 0x130454af, 0x4a2f7904,   // uz.eo.un_770 sq.gd.un_650  ik.fi.et_655 war.su.yo_332 
  0x3800650c, 0x1d2322af, 0x24007907, 0x18080208,   // gv.tk.un_530 oc.ca.la_655  war.eo.un_420 da.no.ga_443 
  0x5a3f3608, 0x791a6bec, 0x024d3f0d, 0x4226010c,   // gn.af.sm_443 ceb.tl.war_644  af.aa.da_554 en.ia.co_543 
  // [14fc0]
  0x022223a9, 0x0407105a, 0x294609a0, 0x796276ad,   // ca.oc.da_544 be.bg.ru_553  pl.qu.sl_322 crs.kha.war_643 
  0x37003804, 0x48005205, 0x061225ad, 0x364d795a,   // tk.ba.un_320 ha.tt.un_330  eu.hu.de_643 war.aa.gn_553 
  0x05224ca9, 0x1d22235a, 0x0d001809, 0x0d004d12,   // wo.oc.fr_544 ca.oc.la_553  ga.cs.un_440 aa.cs.un_640 
  0x634c4d0c, 0x27244907, 0x020553a9, 0x233f05a4,   // aa.wo.sco_543 to.eo.gd_432  ht.fr.da_544 fr.af.ca_433 
  // [14fd0]
  0x0e001a04, 0x3b6b46ee, 0x692608a4, 0x20004d1a,   // tl.is.un_320 qu.ceb.so_422  no.ia.mfe_433 aa.sq.un_760 
  0x22434c04, 0x4a302ea9, 0x4c00110c, 0x28003104,   // wo.ie.oc_332 fo.uz.yo_544  ro.wo.un_530 az.sw.un_320 
  0x31002507, 0x34000f08, 0x530476ad, 0x6900760c,   // eu.az.un_420 lv.xh.un_430  crs.fi.ht_643 crs.mfe.un_530 
  0x11004c0e, 0x4d002d0e, 0x3f3040a0, 0x12283dee,   // wo.ro.un_550 sk.aa.un_550  lb.uz.af_322 ku.sd.ur_422 
  // [14fe0]
  0x214f610b, 0x4823440d, 0x033f2407, 0x2e123707,   // za.bi.jw_542 kk.ky.tt_554  eo.af.nl_432 st.hu.fo_432 
  0x233d2107, 0x03002e04, 0x3400fc07, 0x181b38a0,   // fa.ku.ky_432 fo.nl.un_320  zzp.xh.un_420 tk.tr.ga_322 
  0x3b2f1c07, 0x31004c09, 0x0a003b19, 0x50584d0d,   // id.su.so_432 wo.az.un_440  so.pt.un_750 aa.om.fj_554 
  0x4d423b0c, 0x0d001107, 0x504d3ba4, 0x210c13af,   // so.co.aa_543 ro.cs.un_420  so.aa.fj_433 et.sv.jw_655 
  // [14ff0]
  0x2f21150d, 0x2e083312, 0x2700150e, 0x083035ec,   // un.jw.su_554 nn.no.fo_654  un.gd.un_550 tg.uz.uk_644 
  0x322433a9, 0x1158270c, 0x4d553ba9, 0x35151105,   // nn.eo.bs_544 gd.om.ro_543  so.rw.aa_544 ro.tg.un_330 
  0x375e42ee, 0x0b2f210c, 0x3b2f180c, 0x62fc090c,   // co.ts.st_422 jw.su.es_543  ga.su.so_543 pl.zzp.kha_543 
  0x28000302, 0x1800270b, 0x303504a4, 0x100d2d07,   // nl.sw.un_220 gd.ga.un_520  ru.tg.uz_433 sk.cs.lt_432 
  
  // [15000]
  0x02000a04, 0x1d192f07, 0x644c58a0, 0x38104414,   // pt.da.un_320 su.gl.la_432  om.wo.lg_322 kk.be.tk_666 
  0x343c28ad, 0x1d000b04, 0x1d190b04, 0x641a5a12,   // sd.ug.ps_643 es.la.un_320  es.gl.la_332 sm.tl.lg_654 
  0x135f30a4, 0x3b1355a4, 0x300e5005, 0x373048ec,   // uz.tn.et_433 rw.et.so_433  fj.is.uz_333 tt.uz.ba_644 
  0x133b0413, 0x1c463407, 0x04005808, 0x30005a19,   // fi.so.et_665 xh.qu.id_432  om.fi.un_430 sm.uz.un_750 
  // [15010]
  0x3b5a5709, 0x583b4da4, 0x2851580c, 0x2a180911,   // na.sm.so_444 aa.so.om_433  om.kl.sw_543 pl.ga.mt_653 
  0x06157907, 0x457909ec, 0x5964550c, 0x46190b0e,   // war.de.un_420 pl.war.ln_644  rw.lg.rn_543 es.gl.qu_555 
  0x2d3b550c, 0x285e730c, 0x4d585108, 0x1b0458a4,   // rw.so.sk_543 ny.ts.sw_543  kl.om.aa_443 om.fi.tr_433 
  0x64353412, 0x6b004d13, 0x135a470c, 0x55755f11,   // xh.zu.lg_654 aa.ceb.un_650  sn.sm.et_543 tn.nso.rw_653 
  // [15020]
  0x55505aad, 0x21555012, 0x5a303605, 0x37043b07,   // sm.fj.rw_643 fj.rw.jw_654  gn.uz.sm_333 so.fi.st_432 
  0x20003613, 0x42130407, 0x1030485a, 0x353430a0,   // gn.sq.un_650 fi.et.co_432  tt.uz.be_553 uz.xh.zu_322 
  0x0c631dee, 0x3508100d, 0x15070805, 0x0400441a,   // la.sco.sv_422 be.uk.tg_554  uk.bg.un_333 kk.ru.un_760 
  0x0a004907, 0x2d00180e, 0x03003913, 0x1600320c,   // to.pt.un_420 ga.sk.un_550  br.nl.un_650 bs.hr.un_530 
  // [15030]
  0x03000405, 0x4c45390d, 0x4c001109, 0x02004019,   // fi.nl.un_330 br.ln.wo_554  ro.wo.un_440 lb.da.un_750 
  0x53394c07, 0x4c001104, 0x15002321, 0x4c116912,   // wo.br.ht_432 ro.wo.un_320  ky.un.un_860 mfe.ro.wo_654 
  0x0e066007, 0x2500790e, 0x11005304, 0x071142a4,   // vo.de.is_432 war.eu.un_550  ht.ro.un_320 co.ro.it_433 
  0x2d2e0e12, 0x051d2804, 0x5a150111, 0x5d0501a4,   // is.fo.sk_654 sw.la.fr_332  en.sm.un_630 en.fr.ss_433 
  // [15040]
  0x52004a13, 0x0306650c, 0x4a793eaf, 0x383025a7,   // yo.ha.un_650 gv.de.nl_543  rm.war.yo_655 mn.uz.tk_532 
  0x42fcfe0c, 0x202228ee, 0x673b1e12, 0x1a421f0c,   // tlh.zzp.co_543 sw.oc.sq_422  ms.so.ak_654 cy.co.tl_543 
  0x5700501a, 0x3f0365a0, 0x42056a04, 0x1a003b20,   // fj.na.un_760 gv.nl.af_322  haw.fr.co_332 so.tl.un_850 
  0x5a456804, 0x46003b19, 0x515845a9, 0x49006513,   // ig.ln.sm_332 so.qu.un_750  ln.om.kl_544 gv.to.un_650 
  // [15050]
  0x0543260b, 0xfc4d3baf, 0x4d153b13, 0x68022511,   // ia.ie.fr_542 so.aa.zzp_655  so.aa.un_650 eu.da.ig_653 
  0x48000205, 0x25201504, 0x450543a4, 0x04300802,   // da.tt.un_330 un.sq.eu_332  ie.fr.ln_433 uk.uz.ru_222 
  0x35341f09, 0x2400760c, 0x495a010c, 0x38463b0c,   // cy.xh.zu_444 crs.eo.un_530  en.sm.to_543 so.qu.tk_543 
  0x6a1d43ad, 0x074211af, 0x051d01a4, 0x023bfcec,   // ie.la.haw_643 ro.co.it_655  en.la.fr_433 zzp.so.da_644 
  // [15060]
  0x3b004d20, 0x53582807, 0x793b1a0c, 0x46000504,   // aa.so.un_850 sw.om.ht_432  tl.so.war_543 fr.qu.un_320 
  0x44482513, 0x162d68a0, 0x47006813, 0x12072a12,   // mn.tt.kk_665 ig.sk.hr_322  ig.sn.un_650 mt.it.hu_654 
  0x6800251b, 0x6a0e190d, 0x3c482312, 0x0400fe07,   // eu.ig.un_770 gl.is.haw_554  ky.tt.ug_654 tlh.fi.un_420 
  0x282134ee, 0x61001519, 0x2c400207, 0x0e2e020b,   // ps.fa.sd_422 un.za.un_750  da.lb.fy_432 da.fo.is_542 
  // [15070]
  0x3c440708, 0x200e1305, 0x1f006512, 0x44153608,   // bg.kk.ug_443 et.is.sq_333  gv.cy.un_640 ab.kk.un_430 
  0x20001f02, 0x043607a0, 0x3148fe0b, 0x42231207,   // cy.sq.un_220 bg.ab.ru_322  tlh.tt.az_542 hu.ca.co_432 
  0x4a1d070c, 0x0a231511, 0x18053312, 0x2d1806a7,   // it.la.yo_543 un.ky.mk_653  nn.fr.ga_654 de.ga.sk_532 
  0x1200330c, 0x203202ad, 0x48370712, 0x1b07050c,   // nn.hu.un_530 da.bs.sq_643  bg.ba.tt_654 fr.it.tr_543 
  // [15080]
  0x300436ee, 0x267633a4, 0x35000a11, 0x0d001512,   // ab.ru.uz_422 nn.crs.ia_433  mk.tg.un_630 un.cs.un_640 
  0x0b232da4, 0x20576304, 0x051506ee, 0x5c003904,   // sk.ca.es_433 sco.na.sq_332  de.fr.un_420 br.sa.un_320 
  0x101548a7, 0x25041007, 0x2073080c, 0x42003e1a,   // tt.be.un_520 be.ru.mn_432  no.ny.sq_543 rm.co.un_760 
  0x2600050d, 0x2205230c, 0x052c33a9, 0x5c00120c,   // fr.ia.un_540 ca.fr.oc_543  nn.fy.fr_544 hu.sa.un_530 
  // [15090]
  0x042338a7, 0x392d0d55, 0x17080409, 0x10004809,   // tk.ky.ru_532 cs.sk.br_442  ru.uk.sr_444 tt.be.un_440 
  0x10190a02, 0x110639ee, 0x041b46ee, 0x1e00200e,   // pt.gl.lt_222 br.de.ro_422  qu.tr.fi_422 ti.am.un_550 
  0x03435f0c, 0x17070808, 0x6535fc04, 0x030159a0,   // tn.ie.nl_543 uk.bg.sr_443  zzp.zu.gv_332 rn.en.nl_322 
  0x020c5108, 0x5e39570c, 0x06025f0c, 0x1d190bee,   // kl.sv.da_443 na.br.ts_543  tn.da.de_543 es.gl.la_422 
  // [150a0]
  0x55002107, 0x472d0d0e, 0x5900061a, 0x5c006421,   // jw.rw.un_420 cs.sk.sn_555  de.rn.un_760 lg.sa.un_860 
  0x04035504, 0x5e002d12, 0x331f28a9, 0x27003b04,   // rw.nl.fi_332 sk.ts.un_640  sw.cy.nn_544 so.gd.un_320 
  0x08172505, 0x463b1c0b, 0x2200fc08, 0x353037ee,   // mn.sr.uk_333 id.so.qu_542  zzp.oc.un_430 st.uz.zu_422 
  0x34182707, 0x4d00fc13, 0x4673010c, 0x21273bac,   // gd.ga.xh_432 zzp.aa.un_650  en.ny.qu_543 so.gd.jw_632 
  // [150b0]
  0x5e34350c, 0x365e1d07, 0x05001702, 0x3065620c,   // zu.xh.ts_543 la.ts.gn_432  sr.fr.un_220 kha.gv.uz_543 
  0x43074205, 0x563429a4, 0x733527a7, 0x16004202,   // co.it.ie_333 sl.xh.mg_433  gd.zu.ny_532 co.hr.un_220 
  0x1635290c, 0x150a07a7, 0x320742a7, 0x13400c07,   // sl.zu.hr_543 bg.mk.un_532  co.it.bs_532 sv.lb.et_432 
  0x36570ba9, 0x29005605, 0x49654007, 0x5a002107,   // es.na.gn_544 mg.sl.un_330  lb.gv.to_432 jw.sm.un_420 
  // [150c0]
  0x07250aa4, 0x3744485a, 0x2d0d0e0e, 0x6500610c,   // mk.mn.bg_433 tt.kk.ba_553  is.cs.sk_555 za.gv.un_530 
  0x5c0d1c13, 0x2f4065a0, 0x1d0742a4, 0x734a640c,   // mr.ne.sa_665 gv.lb.su_322  co.it.la_433 lg.yo.ny_543 
  0x27004c07, 0x442537a4, 0x16291ca0, 0x285a2307,   // wo.gd.un_420 ba.mn.kk_433  id.sl.hr_322 ca.sm.sw_432 
  0x29006113, 0x406165ec, 0x2900610d, 0x4408230c,   // za.sl.un_650 gv.za.lb_644  za.sl.un_540 ky.uk.kk_543 
  // [150d0]
  0x0c065711, 0x21004004, 0x4d2d0d13, 0x2d0d4daf,   // na.de.sv_653 lb.jw.un_320  cs.sk.aa_665 aa.cs.sk_655 
  0x3b00110c, 0xfc005109, 0x170411ee, 0xfc005107,   // ro.so.un_530 kl.zzp.un_440  ro.ru.sr_422 kl.zzp.un_420 
  0x65fe18af, 0x652afea4, 0x27651809, 0x04300a07,   // ga.tlh.gv_655 tlh.mt.gv_433  ga.gv.gd_444 mk.uz.ru_432 
  0x79186b0d, 0x79006514, 0xfe3e65a9, 0x231346a0,   // ceb.ga.war_554 gv.war.un_660  gv.rm.tlh_544 qu.et.ca_322 
  // [150e0]
  0xfe006b34, 0x0e2765ee, 0x1221345a, 0x2a006808,   // ceb.tlh.un_A80 gv.gd.is_422  ps.fa.ur_553 ig.mt.un_430 
  0xfc005119, 0x3c353011, 0x65004208, 0x1800fe19,   // kl.zzp.un_750 uz.tg.ug_653  co.gv.un_430 tlh.ga.un_750 
  0x4265fe12, 0x633ffead, 0x2a27fea9, 0x021b1808,   // tlh.gv.co_654 tlh.af.sco_643  tlh.gd.mt_544 ga.tr.da_443 
  0x080201af, 0x65100111, 0x061e62a7, 0x3f761312,   // en.da.no_655 en.lt.gv_653  kha.ms.de_532 et.crs.af_654 
  // [150f0]
  0x3302085a, 0x61200212, 0x023f13a4, 0x3f6501a0,   // no.da.nn_553 da.sq.za_654  et.af.da_433 en.gv.af_322 
  0x3f574d07, 0x3f1327a4, 0x19001012, 0x6367010c,   // aa.na.af_432 gd.et.af_433  lt.gl.un_640 en.ak.sco_543 
  0x10001f23, 0x45000519, 0x1f2e0ea4, 0x19530b08,   // cy.lt.un_880 fr.ln.un_750  is.fo.cy_433 es.ht.gl_443 
  0x3f1b4da9, 0x193b4d0c, 0x32021307, 0x0e122ea7,   // aa.tr.af_544 aa.so.gl_543  et.da.bs_432 fo.hu.is_532 
  // [15100]
  0x63050107, 0x35483007, 0x1300200d, 0x3b204607,   // en.fr.sco_432 uz.tt.tg_432  sq.et.un_540 qu.sq.so_432 
  0x190b1055, 0x171507ad, 0x6447360c, 0x343c23ad,   // lt.es.gl_442 bg.sr.un_630  gn.sn.lg_543 ky.ug.ps_643 
  0x3748040c, 0x30123da4, 0x123b21a4, 0x22004904,   // ru.tt.ba_543 ku.ur.uz_433  fa.ks.ur_433 to.oc.un_320 
  0x49002207, 0x49002212, 0x4a002312, 0x10000a19,   // oc.to.un_420 oc.to.un_640  ca.yo.un_640 mk.be.un_750 
  // [15110]
  0x2d002214, 0x6507425a, 0x0200610e, 0x190a22ee,   // oc.sk.un_660 co.it.gv_553  za.da.un_550 oc.pt.gl_422 
  0x1a001b05, 0x190a2205, 0x1b1e1c08, 0x1d55fc02,   // tr.tl.un_330 oc.pt.gl_333  id.ms.tr_443 zzp.rw.la_222 
  0x461a1b07, 0x111e21a0, 0x49192212, 0x32001719,   // tr.tl.qu_432 jw.ms.ro_322  oc.gl.to_654 sr.bs.un_750 
  0x49002213, 0x191218a7, 0x42005c12, 0x35613408,   // oc.to.un_650 ga.hu.gl_532  sa.co.un_640 xh.za.zu_443 
  // [15120]
  0x5d004507, 0x1a461b0c, 0x045728a7, 0x461b1a08,   // ln.ss.un_420 tr.qu.tl_543  sw.na.fi_532 tl.tr.qu_443 
  0x39512e0c, 0x0665270c, 0x06006119, 0x1c5c09ec,   // fo.kl.br_543 gd.gv.de_543  za.de.un_750 hi.sa.mr_644 
  0x0e002104, 0x51000307, 0x0f2d4b07, 0xfe00610e,   // jw.is.un_320 nl.kl.un_420  mi.sk.lv_432 za.tlh.un_550 
  0x0f000408, 0x080c62ee, 0x49424707, 0x233c3b0e,   // fi.lv.un_430 kha.sv.no_422  sn.co.to_432 ks.ug.ky_555 
  // [15130]
  0x6a4b68af, 0x10000c02, 0x044b4914, 0x3b0e7307,   // ig.mi.haw_655 sv.lt.un_220  to.mi.fi_666 ny.is.so_432 
  0x2d353007, 0x021f63a7, 0x1c5c5f0b, 0x2f000708,   // uz.zu.sk_432 sco.cy.da_532  tn.sa.id_542 it.su.un_430 
  0x06006219, 0x3700360e, 0x1d004602, 0x19002104,   // kha.de.un_750 gn.st.un_550  qu.la.un_220 jw.gl.un_320 
  0x36004b08, 0x242f2802, 0x38043607, 0x08332e12,   // mi.gn.un_430 sw.su.eo_222  gn.fi.tk_432 fo.nn.no_654 
  // [15140]
  0x2800020d, 0x4b1b4204, 0x1b28510c, 0x38002e04,   // da.sw.un_540 co.tr.mi_332  kl.sw.tr_543 fo.tk.un_320 
  0x0d1d5fa0, 0x28183ba4, 0x6b5f37ad, 0x28495112,   // tn.la.cs_322 ks.ar.sd_433  st.tn.ceb_643 kl.to.sw_654 
  0x2f050ba4, 0x27001112, 0x5962360c, 0x04002707,   // es.fr.su_433 ro.gd.un_640  gn.kha.rn_543 gd.fi.un_420 
  0x4836300d, 0x2a006b07, 0x5a044904, 0x18130411,   // uz.ab.tt_554 ceb.mt.un_420  to.fi.sm_332 fi.et.ga_653 
  // [15150]
  0x3f005413, 0x18fc25a0, 0x440408a4, 0x03001102,   // ik.af.un_650 eu.zzp.ga_322  uk.ru.kk_433 ro.nl.un_220 
  0x036b3f08, 0x25004e12, 0x2b5e2507, 0x071038a4,   // af.ceb.nl_443 ay.eu.un_640  eu.ts.vi_432 tk.be.bg_433 
  0x0400511a, 0x04005a0e, 0x3b2325ee, 0x033f5109,   // kl.fi.un_760 sm.fi.un_550  eu.ca.so_422 kl.af.nl_444 
  0x0411790c, 0x27001108, 0x06001507, 0x48363704,   // war.ro.fi_543 ro.gd.un_430  un.de.un_420 ba.ab.tt_332 
  // [15160]
  0x3c2511a4, 0x3f0257a7, 0x321617ad, 0x2b021aa9,   // ro.mn.ug_433 na.da.af_532  sr.hr.bs_643 tl.da.vi_544 
  0x232548a0, 0x33022e04, 0x51022ea4, 0x3d00120e,   // tt.eu.ca_322 fo.da.nn_332  fo.da.kl_433 ur.ku.un_550 
  0x2e00021e, 0x404967a7, 0x12213d5a, 0x0a042308,   // da.fo.un_830 ak.to.lb_532  ku.fa.ur_553 ky.ru.mk_443 
  0x08020ca9, 0x1f03060c, 0x023b0655, 0x0264550e,   // sv.da.no_544 de.nl.cy_543  de.so.da_442 rw.lg.da_555 
  // [15170]
  0x051f6508, 0x06765312, 0x3e39080b, 0x1353400c,   // gv.cy.fr_443 ht.crs.de_654  no.br.rm_542 lb.ht.et_543 
  0x0618270c, 0x65761807, 0x76006920, 0xfc00580c,   // gd.ga.de_543 ga.crs.gv_432  mfe.crs.un_850 om.zzp.un_530 
  0x02261d09, 0x53697607, 0x1b2459a7, 0x3e05010c,   // la.ia.da_444 crs.mfe.ht_432  rn.eo.tr_532 en.fr.rm_543 
  0x420501a0, 0x6b1d010b, 0xfc001c0d, 0x3339400c,   // en.fr.co_322 en.la.ceb_542  id.zzp.un_540 lb.br.nn_543 
  // [15180]
  0x65645fad, 0x03006422, 0x64004c23, 0x553f59af,   // tn.lg.gv_643 lg.nl.un_870  wo.lg.un_880 rn.af.rw_655 
  0x0251060c, 0x091a6b07, 0x4000530d, 0x0c4065ad,   // de.kl.da_543 ceb.tl.pl_432  ht.lb.un_540 gv.lb.sv_643 
  0x400269a4, 0x401d0204, 0x39040c04, 0x6440670c,   // mfe.da.lb_433 da.la.lb_332  sv.fi.br_332 ak.lb.lg_543 
  0x04253502, 0x30484d0c, 0x65150904, 0x31006405,   // tg.mn.ru_222 aa.tt.uz_543  pl.gv.un_320 lg.az.un_330 
  // [15190]
  0x30041504, 0x15017904, 0x18006502, 0x1515110e,   // un.ru.uz_332 war.en.un_332  gv.ga.un_220 ro.un.un_550 
  0x08002c0c, 0x36246aa0, 0x2569530c, 0x1b002705,   // fy.no.un_530 haw.eo.gn_322  ht.mfe.eu_543 gd.tr.un_330 
  0x155d36ad, 0x362c3fa6, 0x112736a0, 0x21003605,   // gn.ss.un_643 af.fy.gn_521  gn.gd.ro_322 gn.jw.un_330 
  0x190a11a0, 0x48384408, 0x230415a4, 0x11651dee,   // ro.pt.gl_322 kk.tk.tt_443  un.ru.ky_433 la.gv.ro_422 
  // [151a0]
  0x1d1536af, 0x120c0604, 0x09321602, 0x571d26a4,   // gn.la.un_650 de.sv.hu_332  hr.bs.pl_222 ia.la.na_433 
  0x3e76690c, 0x10070807, 0x253c3811, 0x1a090ca0,   // mfe.crs.rm_543 uk.bg.be_432  tk.ug.mn_653 sv.pl.tl_322 
  0x171510a9, 0x04120c07, 0x5f003407, 0x42070cee,   // be.sr.un_540 sv.hu.fi_432  xh.tn.un_420 sv.it.co_422 
  0x1d0c1d0c, 0x1e422807, 0x360a2d07, 0x342721a0,   // la.sv.la_543 sw.co.ms_432  sk.pt.gn_432 jw.gd.xh_322 
  // [151b0]
  0x462b1cee, 0x5d2f6408, 0x3534fe09, 0x12302005,   // id.vi.qu_422 lg.su.ss_443  tlh.xh.zu_444 sq.uz.hu_333 
  0x32001102, 0x06002f08, 0x0a4b2fad, 0x51006a0c,   // ro.bs.un_220 su.de.un_430  su.mi.pt_643 haw.kl.un_530 
  0x12001707, 0x1a4630a7, 0x330608a0, 0x33082e07,   // sr.hu.un_420 uz.qu.tl_532  no.de.nn_322 fo.no.nn_432 
  0x2000fe02, 0x23fc1502, 0x172338a4, 0x5a00510c,   // tlh.sq.un_220 un.zzp.ca_222  tk.ky.sr_433 kl.sm.un_530 
  // [151c0]
  0x04231009, 0x18005313, 0x46004a04, 0x2f002114,   // be.ky.ru_444 ht.ga.un_650  yo.qu.un_320 jw.su.un_660 
  0x2f003921, 0x2b1c02a7, 0x13000b02, 0x19001a02,   // br.su.un_860 da.id.vi_532  es.et.un_220 tl.gl.un_220 
  0x17325204, 0x18097955, 0x26005219, 0x2307440c,   // ha.bs.sr_332 war.pl.ga_442  ha.ia.un_750 kk.bg.ky_543 
  0x03002304, 0x63595212, 0x210e2fa0, 0x2b264c12,   // ca.nl.un_320 ha.rn.sco_654  su.is.jw_322 wo.ia.vi_654 
  // [151d0]
  0x32007304, 0x0200210d, 0x29000904, 0x19730b0c,   // ny.bs.un_320 jw.da.un_540  pl.sl.un_320 es.ny.gl_543 
  0x0230480b, 0x55004d1a, 0x211a2faf, 0x080410a7,   // tt.uz.da_542 aa.rw.un_760  su.tl.jw_655 be.ru.uk_532 
  0x2b115204, 0x0c0210a0, 0x21006b08, 0x4a00682b,   // ha.ro.vi_332 lt.da.sv_322  ceb.jw.un_430 ig.yo.un_980 
  0x434d520c, 0x5c001a05, 0x48300a02, 0x1b003409,   // ha.aa.ie_543 tl.sa.un_330  mk.uz.tt_222 xh.tr.un_440 
  // [151e0]
  0x28002111, 0x0327180e, 0x10000e18, 0x033f2704,   // fa.sd.un_630 ga.gd.nl_555  is.lt.un_740 gd.af.nl_332 
  0x15382311, 0x363435a0, 0x030a07a0, 0x1d3f03a0,   // ky.tk.un_653 zu.xh.gn_322  it.pt.nl_322 nl.af.la_322 
  0x475e7809, 0x3f00032c, 0x170735ee, 0x43011855,   // ve.ts.sn_444 nl.af.un_990  tg.bg.sr_422 ga.en.ie_442 
  0x13001012, 0x33080da0, 0x44000809, 0x64201ea0,   // lt.et.un_640 cs.no.nn_322  uk.kk.un_440 ms.sq.lg_322 
  // [151f0]
  0x342f5ea0, 0x2d0d4aa9, 0x3e006011, 0x04003f07,   // ts.su.xh_322 yo.cs.sk_544  vo.rm.un_630 af.fi.un_420 
  0x1d3f2705, 0x5e3f6355, 0x15001705, 0x440748ad,   // gd.af.la_333 sco.af.ts_442  sr.un.un_330 tt.bg.kk_643 
  0x2e111b07, 0x350730af, 0x25001519, 0x2130120b,   // tr.ro.fo_432 uz.bg.tg_655  un.mn.un_750 ur.uz.fa_542 
  0x2a001104, 0x4c353407, 0x3b213408, 0x0a1738a4,   // ro.mt.un_320 xh.zu.wo_432  ps.fa.ks_443 tk.sr.mk_433 
  // [15200]
  0x021e21a4, 0x2e00381a, 0x401f06a4, 0x046a21ad,   // jw.ms.da_433 tk.fo.un_760  de.cy.lb_433 jw.haw.fi_643 
  0x0e4e210c, 0x3008100b, 0x235f21a4, 0x29002102,   // jw.ay.is_543 be.uk.uz_542  jw.tn.ca_433 jw.sl.un_220 
  0x20004d0d, 0x31584da6, 0x56054504, 0x13045c07,   // aa.sq.un_540 aa.om.az_521  ln.fr.mg_332 sa.fi.et_432 
  0x173c11a4, 0x483c3012, 0x1a4b210c, 0xfc460bee,   // ro.ug.sr_433 uz.ug.tt_654  jw.mi.tl_543 es.qu.zzp_422 
  // [15210]
  0x135c2108, 0x046821ad, 0x15070a07, 0x46002119,   // jw.sa.et_443 jw.ig.fi_643  mk.bg.un_432 jw.qu.un_750 
  0x4600050c, 0x373c445a, 0x443c3413, 0x120c0602,   // fr.qu.un_530 kk.ug.ba_553  ps.ug.kk_665 de.sv.hu_222 
  0x21004204, 0x18443408, 0x4c2a07a0, 0x644a21ec,   // co.jw.un_320 ps.kk.ar_443  it.mt.wo_322 jw.yo.lg_644 
  0x08043607, 0x1f6828a9, 0x3f002e07, 0x2c003f09,   // ab.ru.uk_432 sw.ig.cy_544  fo.af.un_420 af.fy.un_440 
  // [15220]
  0x10041105, 0x39001004, 0x44002107, 0x21123b14,   // ro.ru.be_333 lt.br.un_320  fa.kk.un_420 ks.ur.fa_666 
  0x0c064807, 0x31291da0, 0x15040a0b, 0x345d50a4,   // tt.de.sv_432 la.sl.az_322  mk.ru.un_542 fj.ss.xh_433 
  0x0e3f2ca9, 0x13041004, 0x1163015a, 0x4c671fa4,   // fy.af.is_544 lt.fi.et_332  en.sco.ro_553 cy.ak.wo_433 
  0x55211e04, 0x5c000413, 0x65110107, 0x55000304,   // ms.jw.rw_332 fi.sa.un_650  en.ro.gv_432 nl.rw.un_320 
  // [15230]
  0x38006e07, 0x152f1ca4, 0x5c6b1a0b, 0x34033fa0,   // hmn.tk.un_420 id.su.un_433  tl.ceb.sa_542 af.nl.xh_322 
  0x37151004, 0x261e1c11, 0x20000f14, 0x38000c1a,   // be.ba.un_320 id.ms.ia_653  lv.sq.un_660 sv.tk.un_760 
  0x47353455, 0x1e006304, 0x16291bee, 0x233e42ec,   // xh.zu.sn_442 sco.ms.un_320  tr.sl.hr_422 co.rm.ca_644 
  0x040f1004, 0x0e1d2ea9, 0x3e00360b, 0x1a1079ec,   // lt.lv.fi_332 fo.la.is_544  gn.rm.un_520 war.lt.tl_644 
  // [15240]
  0x46684bec, 0x5c201da9, 0x734b6a08, 0x79000f19,   // mi.ig.qu_644 la.sq.sa_544  haw.mi.ny_443 lv.war.un_750 
  0x40002019, 0x2021530b, 0x083007a0, 0x2e001d12,   // sq.lb.un_750 ht.jw.sq_542  bg.uz.uk_322 la.fo.un_640 
  0x5c690e11, 0x27000e0c, 0x56020eec, 0x532322a0,   // is.mfe.sa_653 is.gd.un_530  is.da.mg_644 oc.ca.ht_322 
  0x2000210b, 0x49004b22, 0x033f1d07, 0x44251508,   // jw.sq.un_520 mi.to.un_870  la.af.nl_432 un.mn.kk_443 
  // [15250]
  0x3f0451ec, 0x27000e14, 0x133f04a7, 0x692e0e0c,   // kl.fi.af_644 is.gd.un_660  fi.af.et_532 is.fo.mfe_543 
  0x03006111, 0x40060eac, 0x1c000923, 0x67003514,   // za.nl.un_630 is.de.lb_632  hi.mr.un_880 zu.ak.un_660 
  0x095534a0, 0x0a2f05ee, 0x395305a6, 0x2f00180c,   // xh.rw.pl_322 fr.su.pt_422  fr.ht.br_521 ga.su.un_530 
  0x0e3369ec, 0x18270ea4, 0x18000e12, 0x2a27400c,   // mfe.nn.is_644 is.gd.ga_433  is.ga.un_640 lb.gd.mt_543 
  // [15260]
  0x5100021a, 0x122823a4, 0x69000e14, 0x212f4cee,   // da.kl.un_760 ky.sd.ur_433  is.mfe.un_660 wo.su.jw_422 
  0x30001305, 0x38002e16, 0x04443704, 0x3e570611,   // et.uz.un_330 fo.tk.un_720  ba.kk.ru_332 de.na.rm_653 
  0x29391004, 0x18684f0c, 0x3b001909, 0x39204d07,   // lt.br.sl_332 bi.ig.ga_543  gl.so.un_440 aa.sq.br_432 
  0x3800482b, 0x3c1523ee, 0x040a0804, 0x20001904,   // tt.tk.un_980 ky.ug.un_420  uk.mk.ru_332 gl.sq.un_320 
  // [15270]
  0x074253a6, 0x3b2c1fa0, 0x4425485a, 0x09000313,   // ht.co.it_521 cy.fy.so_322  tt.mn.kk_553 nl.pl.un_650 
  0x32482f07, 0x27001d04, 0x0b3622a0, 0x135c0dee,   // su.tt.bs_432 la.gd.un_320  oc.gn.es_322 ne.sa.bh_422 
  0x1f004a04, 0x090d2d11, 0x11001302, 0x19004a08,   // yo.cy.un_320 sk.cs.pl_653  et.ro.un_220 yo.gl.un_430 
  0x213423ad, 0x23007909, 0x2d004a0d, 0x2700361e,   // ky.ps.fa_643 war.ca.un_440  yo.sk.un_540 gn.gd.un_830 
  // [15280]
  0x304e51a4, 0x51004e2b, 0x1d2f150c, 0x4d000a08,   // kl.ay.uz_433 ay.kl.un_980  un.su.la_543 pt.aa.un_430 
  0x37483612, 0x544e3b08, 0x182d0d05, 0x4a0751a0,   // ab.tt.ba_654 so.ay.ik_443  cs.sk.ga_333 kl.it.yo_322 
  0x3b4d300b, 0x2c2a65ad, 0x580e65a9, 0x230b36a0,   // uz.aa.so_542 gv.mt.fy_643  gv.is.om_544 gn.es.ca_322 
  0xfc002c0c, 0x30043702, 0x216b1aa0, 0x6501630c,   // fy.zzp.un_530 ba.ru.uz_222  tl.ceb.jw_322 sco.en.gv_543 
  // [15290]
  0x35465408, 0x0e5240ec, 0x50005414, 0x69007618,   // ik.qu.zu_443 lb.ha.is_644  ik.fj.un_660 crs.mfe.un_740 
  0x354e5007, 0x51005022, 0x31381b0e, 0x58304e0c,   // fj.ay.zu_432 fj.kl.un_870  tr.tk.az_555 ay.uz.om_543 
  0x644065ac, 0x5000512b, 0x3401fc02, 0x305146a9,   // gv.lb.lg_632 kl.fj.un_980  zzp.en.xh_222 qu.kl.uz_544 
  0x514650a9, 0x36460ba0, 0x0640fea0, 0x0e2739a9,   // fj.qu.kl_544 es.qu.gn_322  tlh.lb.de_322 br.gd.is_544 
  // [152a0]
  0x2a51fe04, 0x081265a9, 0x033f52ad, 0x6b001f12,   // tlh.kl.mt_332 gv.hu.no_544  ha.af.nl_643 cy.ceb.un_640 
  0xfc6a0408, 0x79002019, 0xfc000423, 0x79004513,   // fi.haw.zzp_443 sq.war.un_750  fi.zzp.un_880 ln.war.un_650 
  0x401d0107, 0x1c213802, 0x521f46ad, 0x1d134904,   // en.la.lb_432 tk.jw.id_222  qu.cy.ha_643 to.et.la_332 
  0x1d004308, 0xfc3e10a7, 0x1b384808, 0x3848600b,   // ie.la.un_430 lt.rm.zzp_532  tt.tk.tr_443 vo.tt.tk_542 
  // [152b0]
  0x190b1d07, 0x2d0d05a0, 0x17110707, 0x0b1d3504,   // la.es.gl_432 fr.cs.sk_322  bg.ro.sr_432 zu.la.es_332 
  0x1d282607, 0x1f00670c, 0x38006510, 0x34282155,   // ia.sw.la_432 ak.cy.un_530  gv.tk.un_620 fa.sd.ps_442 
  0x20003508, 0x23650a55, 0x264315a4, 0x48000c12,   // zu.sq.un_430 pt.gv.ca_442  un.ie.ia_433 sv.tt.un_640 
  0x190b4607, 0x47733507, 0x52003502, 0x352545a4,   // qu.es.gl_432 zu.ny.sn_432  zu.ha.un_220 ln.eu.zu_433 
  // [152c0]
  0x38002804, 0x381b2e07, 0x3c3517a4, 0x6b3579a0,   // sw.tk.un_320 fo.tr.tk_432  sr.tg.ug_433 war.zu.ceb_322 
  0x12004d13, 0x6b374507, 0x220a23a9, 0x2e004a0c,   // aa.hu.un_650 ln.st.ceb_432  ca.pt.oc_544 yo.fo.un_530 
  0x793f78a0, 0x502d0fa0, 0x13026107, 0x4d54730e,   // ve.af.war_322 lv.sk.fj_322  za.da.et_432 ny.ik.aa_555 
  0x36002c08, 0x36272da4, 0x50353408, 0x0530310c,   // fy.gn.un_430 sk.gd.gn_433  xh.zu.fj_443 az.uz.fr_543 
  // [152d0]
  0x4510600c, 0x073515ad, 0xfc000908, 0x25fe1fee,   // vo.lt.ln_543 un.tg.bg_643  pl.zzp.un_430 cy.tlh.eu_422 
  0x3c1530a0, 0x733435ee, 0x376545ee, 0x346a68ec,   // uz.ug.un_320 zu.xh.ny_422  ln.gv.st_422 ig.haw.xh_644 
  0x0a192204, 0x44302313, 0x3515110c, 0x20212f07,   // oc.gl.pt_332 ky.uz.kk_665  ro.tg.un_530 su.jw.sq_432 
  0x330251a0, 0x0b2336a6, 0x071002a4, 0x23002107,   // kl.da.nn_322 gn.ca.es_521  da.lt.it_433 jw.ca.un_420 
  // [152e0]
  0x024b1f0c, 0x4c000b05, 0x2042020c, 0x0d2d3655,   // cy.mi.da_543 es.wo.un_330  da.co.sq_543 gn.sk.cs_442 
  0x1b3136a0, 0x3c002804, 0x210b05a6, 0x4a53020c,   // gn.az.tr_322 sd.ug.un_320  fr.es.jw_521 da.ht.yo_543 
  0x56210508, 0x562105a0, 0x043922ee, 0x27005f0c,   // fr.jw.mg_443 fr.jw.mg_322  oc.br.fi_422 tn.gd.un_530 
  0x07684b0c, 0x5000301a, 0x2100182a, 0x53000916,   // mi.ig.it_543 uz.fj.un_760  ar.fa.un_970 pl.ht.un_720 
  // [152f0]
  0x04080a08, 0x1a002f05, 0x5365285a, 0x306435a4,   // mk.uk.ru_443 su.tl.un_330  sw.gv.ht_553 zu.lg.uz_433 
  0x2f4c2104, 0x04223f04, 0x5100040d, 0x39040207,   // jw.wo.su_332 af.oc.fi_332  fi.kl.un_540 da.fi.br_432 
  0x4c0d0404, 0x0e541a07, 0x34511a55, 0x39791a0c,   // fi.cs.wo_332 tl.ik.is_432  tl.kl.xh_442 tl.war.br_543 
  0x043936ee, 0x6812620d, 0x60001d0e, 0x4200fe23,   // gn.br.fi_422 kha.hu.ig_554  la.vo.un_550 tlh.co.un_880 
  // [15300]
  0x5260210c, 0x59552509, 0x271f6512, 0x642078a7,   // jw.vo.ha_543 eu.rw.rn_444  gv.cy.gd_654 ve.sq.lg_532 
  0x0d0204af, 0x3500fe07, 0x0a390207, 0x2718fca7,   // fi.da.cs_655 tlh.zu.un_420  da.br.pt_432 zzp.ga.gd_532 
  0x524afc08, 0x79001a08, 0x0c656307, 0x162f2e07,   // zzp.yo.ha_443 tl.war.un_430  sco.gv.sv_432 fo.su.hr_432 
  0x52000d04, 0x3f0d5304, 0x566001a0, 0x0e063311,   // cs.ha.un_320 ht.cs.af_332  en.vo.mg_322 nn.de.is_653 
  // [15310]
  0x3e261d08, 0x4f000108, 0x21123011, 0x1a526ba4,   // la.ia.rm_443 en.bi.un_430  uz.ur.fa_653 ceb.ha.tl_433 
  0x793f2907, 0x38480612, 0x3530fe07, 0x5e3b4dad,   // sl.af.war_432 de.tt.tk_654  tlh.uz.zu_432 aa.so.ts_643 
  0x201f6512, 0x11fe4205, 0x10005507, 0x02214d08,   // gv.cy.sq_654 co.tlh.ro_333  rw.lt.un_420 aa.jw.da_443 
  0x1120300b, 0x4c0253a4, 0x65071da0, 0x10514f12,   // uz.sq.ro_542 ht.da.wo_433  la.it.gv_322 bi.kl.lt_654 
  // [15320]
  0x11fe42ee, 0x3f68fe55, 0x5400510e, 0x55005e07,   // co.tlh.ro_422 tlh.ig.af_442  kl.ik.un_550 ts.rw.un_420 
  0x48363c09, 0x2c1f370b, 0x46fe4f0c, 0x13595508,   // ug.ab.tt_444 st.cy.fy_542  bi.tlh.qu_543 rw.rn.et_443 
  0x5a546a55, 0x212818af, 0x08070aaf, 0x37001704,   // haw.ik.sm_442 ar.sd.fa_655  mk.bg.uk_655 sr.ba.un_320 
  0x0d792d12, 0x42002305, 0x37481507, 0x2e001102,   // sk.war.cs_654 ca.co.un_330  un.tt.ba_432 ro.fo.un_220 
  // [15330]
  0x4a230708, 0x36116502, 0x3e005605, 0x0b1819ee,   // it.ca.yo_443 gv.ro.gn_222  mg.rm.un_330 gl.ga.es_422 
  0x223e2355, 0x330e2eec, 0x36390ba9, 0x3f493905,   // ca.rm.oc_442 fo.is.nn_644  es.br.gn_544 br.to.af_333 
  0x690239a4, 0x02000521, 0x1d00391a, 0x04390507,   // br.da.mfe_433 fr.da.un_860  br.la.un_760 fr.br.fi_432 
  0x0b072312, 0x391d0207, 0x05394004, 0x10004402,   // ca.it.es_654 da.la.br_432  lb.br.fr_332 kk.be.un_220 
  // [15340]
  0x054039af, 0x40003914, 0x1548370e, 0x3900631b,   // br.lb.fr_655 br.lb.un_660  ba.tt.un_555 sco.br.un_770 
  0x0e2d120c, 0x63003914, 0x63003919, 0x37483007,   // hu.sk.is_543 br.sco.un_660  br.sco.un_750 uz.tt.ba_432 
  0x5c0d13a9, 0x794e55af, 0x38374409, 0x301221ec,   // bh.ne.sa_544 rw.ay.war_655  kk.ba.tk_444 fa.ur.uz_644 
  0x123d3004, 0x481536a7, 0x040c02ee, 0x02553b0c,   // uz.ku.ur_332 ab.tt.un_520  da.sv.fi_422 so.rw.da_543 
  // [15350]
  0x36000704, 0x650e2ea0, 0x2d00120b, 0x654f6012,   // it.gn.un_320 fo.is.gv_322  hu.sk.un_520 vo.bi.gv_654 
  0x026864a4, 0x402608a0, 0x381b48ac, 0x30372308,   // lg.ig.da_433 no.ia.lb_322  tt.tr.tk_632 ky.ba.uz_443 
  0x0d2d12ee, 0x65162004, 0x431101a0, 0x59552055,   // hu.sk.cs_422 sq.hr.gv_332  en.ro.ie_322 sq.rw.rn_442 
  0x48170808, 0x2f030ca0, 0x0735250b, 0x384830a0,   // uk.sr.tt_443 sv.nl.su_322  mn.tg.bg_542 uz.tt.tk_322 
  // [15360]
  0x1d431c0b, 0x123019ee, 0x250c0804, 0x084823ad,   // id.ie.la_542 gl.uz.hu_422  no.sv.eu_332 ky.tt.uk_643 
  0x09003213, 0x24047904, 0x073e4211, 0x23073ea0,   // bs.pl.un_650 war.fi.eo_332  co.rm.it_653 rm.it.ca_322 
  0x05000a07, 0x404d3008, 0x0e601d0c, 0x3b304d0c,   // pt.fr.un_420 uz.aa.lb_443  la.vo.is_543 aa.uz.so_543 
  0x4c4d11a4, 0x23003e0c, 0x60001f13, 0x0e001d13,   // ro.aa.wo_433 rm.ca.un_530  cy.vo.un_650 la.is.un_650 
  // [15370]
  0x240613ee, 0x1f002d1a, 0x0e5c08a0, 0x3b01fca0,   // et.de.eo_422 sk.cy.un_760  no.sa.is_322 zzp.en.so_322 
  0x151f2d12, 0x1b001c08, 0x064079ee, 0x03023fa4,   // sk.cy.un_654 id.tr.un_430  war.lb.de_422 af.da.nl_433 
  0x3b2a4d0d, 0x01033fee, 0x1f4f2d07, 0x0b2d0d02,   // aa.mt.so_554 af.nl.en_422  sk.bi.cy_432 cs.sk.es_222 
  0x69117611, 0x07422a0c, 0x073e420b, 0x11002a02,   // crs.ro.mfe_653 mt.co.it_543  co.rm.it_542 mt.ro.un_220 
  // [15380]
  0x4a005712, 0x0c0901ad, 0x5321200c, 0x4c0e2e07,   // na.yo.un_640 en.pl.sv_643  sq.jw.ht_543 fo.is.wo_432 
  0x202322a6, 0x1b1f53a4, 0x4f232da0, 0x532c4f13,   // oc.ca.sq_521 ht.cy.tr_433  sk.ca.bi_322 bi.fy.ht_665 
  0x1b2e0e08, 0x1a2223a9, 0x1200111a, 0x2e5c1d0c,   // is.fo.tr_443 ca.oc.tl_544  ro.hu.un_760 la.sa.fo_543 
  0x390e1d08, 0x1f004f34, 0x0e001d1a, 0xfe694fad,   // la.is.br_443 bi.cy.un_A80  la.is.un_760 bi.mfe.tlh_643 
  // [15390]
  0x31303b07, 0x5c00490b, 0x2100200d, 0x3e000908,   // so.uz.az_432 to.sa.un_520  sq.jw.un_540 pl.rm.un_430 
  0x44000820, 0x46001d0c, 0x281a0407, 0x370a4b0d,   // uk.kk.un_850 la.qu.un_530  fi.tl.sw_432 mi.pt.st_554 
  0x18656a60, 0x530d2fee, 0x5a250407, 0x02083311,   // haw.gv.ga_664 su.cs.ht_422  fi.eu.sm_432 nn.no.da_653 
  0x3d302109, 0x122f0504, 0x5f6a3704, 0x3700540c,   // fa.uz.ku_444 fr.su.hu_332  st.haw.tn_332 ik.st.un_530 
  // [153a0]
  0x42002108, 0x042d0d55, 0x6518270c, 0x05532f08,   // jw.co.un_430 cs.sk.fi_442  gd.ga.gv_543 su.ht.fr_443 
  0x1811650b, 0x100447a0, 0x65182713, 0x170d0407,   // gv.ro.ga_542 sn.fi.lt_322  gd.ga.gv_665 fi.cs.sr_432 
  0x5f1827ad, 0x21052fee, 0x203217a4, 0x1d00020d,   // gd.ga.tn_643 su.fr.jw_422  sr.bs.sq_433 da.la.un_540 
  0x4b1a540c, 0x59005b0e, 0x4b045412, 0x182765a9,   // ik.tl.mi_543 sg.rn.un_550  ik.fi.mi_654 gv.gd.ga_544 
  // [153b0]
  0x0a135c07, 0x231d0a0c, 0x0510270c, 0x22192f05,   // sa.et.pt_432 pt.la.ca_543  gd.lt.fr_543 su.gl.oc_333 
  0x3d00341a, 0x1c3b0912, 0x404205a7, 0x6b0e1dec,   // ps.ku.un_760 hi.ks.mr_654  fr.co.lb_532 la.is.ceb_644 
  0x652701a0, 0x18362f07, 0x1b00482b, 0x18001614,   // en.gd.gv_322 su.gn.ga_432  tt.tr.un_980 th.ar.un_660 
  0x420d2d0c, 0x530e690c, 0x321608a0, 0x20792da4,   // sk.cs.co_543 mfe.is.ht_543  no.hr.bs_322 sk.war.sq_433 
  // [153c0]
  0x32002e02, 0x1e005307, 0x5c00210d, 0x64471208,   // fo.bs.un_220 ht.ms.un_420  jw.sa.un_540 hu.sn.lg_443 
  0x794764a4, 0x64340909, 0x013464a0, 0x060c400d,   // lg.sn.war_433 pl.xh.lg_444  lg.xh.en_322 lb.sv.de_554 
  0x1a002007, 0x33082d0b, 0x212b62ad, 0x1800300e,   // sq.tl.un_420 sk.no.nn_542  kha.vi.jw_643 uz.ar.un_550 
  0x30000a13, 0x10004409, 0x192e0b0c, 0x07043007,   // mk.uz.un_650 kk.be.un_440  es.fo.gl_543 uz.ru.bg_432 
  // [153d0]
  0x0e3622a4, 0x0e190b08, 0x070837a0, 0x38006419,   // oc.gn.is_433 es.gl.is_443  ba.uk.bg_322 lg.tk.un_750 
  0x30152507, 0x57003e0e, 0x23220a02, 0x0b2319a0,   // mn.uz.un_420 rm.na.un_550  pt.oc.ca_222 gl.ca.es_322 
  0x06130404, 0x48005b18, 0xfe73650c, 0x2100580d,   // fi.et.de_332 sg.tt.un_740  gv.ny.tlh_543 om.jw.un_540 
  0x303c38ec, 0x24002807, 0x222d36ad, 0x2e1304af,   // tk.ug.uz_644 sw.eo.un_420  gn.sk.oc_643 fi.et.fo_655 
  // [153e0]
  0x2d190b0d, 0x28005109, 0x132e2aee, 0x65023004,   // es.gl.sk_554 kl.sw.un_440  mt.fo.et_422 uz.da.gv_332 
  0x0a005908, 0x3565730c, 0x34282307, 0x560a2255,   // rn.pt.un_430 ny.gv.zu_543  ky.sd.ps_432 oc.pt.mg_442 
  0x5c394e12, 0x4c005109, 0x15002102, 0x280902a9,   // ay.br.sa_654 kl.wo.un_440  jw.un.un_220 da.pl.sw_544 
  0x51645207, 0x62003013, 0x251338a4, 0x19120b0c,   // ha.lg.kl_432 uz.kha.un_650  tk.et.eu_433 es.hu.gl_543 
  // [153f0]
  0x42001505, 0x2e510211, 0x591b350c, 0x180e12ad,   // un.co.un_330 da.kl.fo_653  zu.tr.rn_543 hu.is.ga_643 
  0x190b12a9, 0x060d19a0, 0x6764680c, 0x5e73450c,   // hu.es.gl_544 gl.cs.de_322  ig.lg.ak_543 ln.ny.ts_543 
  0x0d122dec, 0x3504130d, 0x09131c13, 0x38005d04,   // sk.hu.cs_644 et.fi.zu_554  mr.bh.hi_665 ss.tk.un_320 
  0x51001d13, 0x0e063f04, 0x2a006411, 0x567857ec,   // la.kl.un_650 af.de.is_332  lg.mt.un_630 na.ve.mg_644 
  
  // [15400]
  0x230435ee, 0x23220a11, 0x0c002d0c, 0x13000c0c,   // tg.ru.ky_422 pt.oc.ca_653  sk.sv.un_530 sv.et.un_530 
  0x113510a4, 0x130c040b, 0x05482317, 0x13000c0b,   // be.tg.ro_433 fi.sv.et_542  ca.tt.fr_753 sv.et.un_520 
  0x0c00600d, 0x4b0a05ad, 0x19004907, 0x350a3cee,   // vo.sv.un_540 fr.pt.mi_643  to.gl.un_420 ug.mk.tg_422 
  0x233e420c, 0x31221baf, 0x4600180d, 0x2f3f4ca0,   // co.rm.ca_543 tr.oc.az_655  ga.qu.un_540 wo.af.su_322 
  // [15410]
  0x4d001819, 0x01001d08, 0x48040c5e, 0x4e6847ad,   // ga.aa.un_750 la.en.un_430  sv.fi.tt_652 sn.ig.ay_643 
  0x111c2f05, 0x1d364708, 0x474b4e09, 0x0c007604,   // su.id.ro_333 sn.gn.la_443  ay.mi.sn_444 crs.sv.un_320 
  0x11272fee, 0x4e642808, 0x27002f13, 0x213b340c,   // su.gd.ro_422 sw.lg.ay_443  su.gd.un_650 ps.ks.fa_543 
  0x13001d05, 0x3128670c, 0x0247590c, 0x11502fee,   // la.et.un_330 ak.sw.az_543  rn.sn.da_543 su.fj.ro_422 
  // [15420]
  0x2f4c110c, 0x303715a0, 0x316828a9, 0x554e670c,   // ro.wo.su_543 un.ba.uz_322  sw.ig.az_544 ak.ay.rw_543 
  0x42114ca4, 0x1d00130e, 0x505e4711, 0x3f112fa7,   // wo.ro.co_433 et.la.un_550  sn.ts.fj_653 su.ro.af_532 
  0x464b7311, 0x474e55a9, 0x1a1e1c08, 0x1a002a04,   // ny.mi.qu_653 rw.ay.sn_544  id.ms.tl_443 mt.tl.un_320 
  0x476468a9, 0x4b00471b, 0x50204e0c, 0x183c2308,   // ig.lg.sn_544 sn.mi.un_770  ay.sq.fj_543 ky.ug.ar_443 
  // [15430]
  0x28736408, 0x2f5528ad, 0x59551d0c, 0x64450209,   // lg.ny.sw_443 sw.rw.su_643  la.rw.rn_543 da.ln.lg_444 
  0x163b4d08, 0x6b731a0d, 0x645e4cee, 0x04003204,   // aa.so.hr_443 tl.ny.ceb_554  wo.ts.lg_422 bs.fi.un_320 
  0x1a004d13, 0x042d0d5a, 0x395c4ead, 0xfe00570d,   // aa.tl.un_650 cs.sk.fi_553  ay.sa.br_643 na.tlh.un_540 
  0x02261da4, 0x21574d0c, 0x455d5505, 0x4500590e,   // la.ia.da_433 aa.na.jw_543  rw.ss.ln_333 rn.ln.un_550 
  // [15440]
  0x15153505, 0x35287305, 0x285950af, 0x045102a0,   // tg.un.un_330 ny.sw.zu_333  fj.rn.sw_655 da.kl.fi_322 
  0x02284c08, 0x212f520c, 0x48583013, 0x58003405,   // wo.sw.da_443 ha.su.jw_543  uz.om.tt_665 xh.om.un_330 
  0x10286a0d, 0x50004711, 0x2f00510d, 0x51001004,   // haw.sw.lt_554 sn.fj.un_630  kl.su.un_540 lt.kl.un_320 
  0x110a1712, 0x11001704, 0x51006b04, 0x11073612,   // sr.mk.ro_654 sr.ro.un_320  ceb.kl.un_320 ab.bg.ro_654 
  // [15450]
  0x510410ad, 0x3e072312, 0x095110a7, 0x35000304,   // lt.fi.kl_643 ca.it.rm_654  lt.kl.pl_532 nl.zu.un_320 
  0x23423e0c, 0x0e2e02ee, 0x2242230e, 0x13001d1a,   // rm.co.ca_543 da.fo.is_422  ca.co.oc_555 la.et.un_760 
  0x3e4223ee, 0x1e1c1aaf, 0x020c6207, 0x38303105,   // ca.co.rm_422 tl.id.ms_655  kha.sv.da_432 az.uz.tk_333 
  0x1a002c09, 0x162032ee, 0x35314aad, 0x07382304,   // fy.tl.un_440 bs.sq.hr_422  yo.az.zu_643 ky.tk.bg_332 
  // [15460]
  0x2e0e1dee, 0x3e000714, 0x3e2307a4, 0x1c001318,   // la.is.fo_422 it.rm.un_660  it.ca.rm_433 bh.mr.un_740 
  0x220742ad, 0x60001d14, 0x06002d10, 0x0c483002,   // co.it.oc_643 la.vo.un_660  sk.de.un_620 uz.tt.sv_222 
  0x15043655, 0x0d135c04, 0x462f1d0c, 0x2c0e1d55,   // ab.ru.un_442 sa.bh.ne_332  la.su.qu_543 la.is.fy_442 
  0x4438360d, 0x502f52a0, 0x42172613, 0x03002002,   // ab.tk.kk_554 ha.su.fj_322  ia.sr.co_665 sq.nl.un_220 
  // [15470]
  0x36002017, 0x350715ad, 0x64477312, 0x443c23a0,   // sq.gn.un_730 un.bg.tg_643  ny.sn.lg_654 ky.ug.kk_322 
  0x321711af, 0x164710a7, 0x5d00fa11, 0x2d0d42a9,   // ro.sr.bs_655 lt.sn.hr_532  nr.ss.un_630 co.cs.sk_544 
  0x18124dad, 0x0900190d, 0x0b4c5ba7, 0x04081512,   // aa.hu.ga_643 gl.pl.un_540  sg.wo.es_532 un.uk.ru_654 
  0x53000a07, 0x0e0d2d0c, 0x1b00fc07, 0x3e005307,   // pt.ht.un_420 sk.cs.is_543  zzp.tr.un_420 ht.rm.un_420 
  // [15480]
  0x15350aa4, 0x46005504, 0x56002307, 0x56785ea7,   // mk.tg.un_433 rw.qu.un_320  ca.mg.un_420 ts.ve.mg_532 
  0x69004e0e, 0x2afc01a4, 0x0a041d07, 0x454b10ee,   // ay.mfe.un_550 en.zzp.mt_433  la.fi.pt_432 lt.mi.ln_422 
  0x57004019, 0x4d00501b, 0x4500501b, 0x64004509,   // lb.na.un_750 fj.aa.un_770  fj.ln.un_770 ln.lg.un_440 
  0x53002304, 0x224207a0, 0x28122f07, 0x79004518,   // ca.ht.un_320 it.co.oc_322  su.hu.sw_432 ln.war.un_740 
  // [15490]
  0x29004204, 0x36005f21, 0x5f594fad, 0x33086405,   // co.sl.un_320 tn.gn.un_860  bi.rn.tn_643 lg.no.nn_333 
  0x59505708, 0x19530b5a, 0x3f030608, 0x3418210b,   // na.fj.rn_443 es.ht.gl_553  de.nl.af_443 fa.ar.ps_542 
  0x2800440b, 0x353610a4, 0x3e400607, 0x13004808,   // kk.sd.un_520 be.ab.tg_433  de.lb.rm_432 tt.et.un_430 
  0x553534ee, 0x1b1239a4, 0x55605911, 0x48001302,   // xh.zu.rw_422 br.hu.tr_433  rn.vo.rw_653 et.tt.un_220 
  // [154a0]
  0x123d3413, 0x18004d0b, 0x254740ad, 0x02005f0c,   // ps.ku.ur_665 aa.ga.un_520  lb.sn.eu_643 tn.da.un_530 
  0x0e000a05, 0x01116508, 0x1c6501a0, 0x18652714,   // pt.is.un_330 gv.ro.en_443  en.gv.id_322 gd.gv.ga_666 
  0x3c3b3d0c, 0x48400607, 0x294d2d07, 0x014a36a0,   // ku.ks.ug_543 de.lb.tt_432  sk.aa.sl_432 gn.yo.en_322 
  0x180e2c0c, 0x0e2319a4, 0x261d1a12, 0x23443baf,   // fy.is.ga_543 gl.ca.is_433  tl.la.ia_654 ks.kk.ky_655 
  // [154b0]
  0x0e2130a9, 0x2f651e07, 0x2d2319a0, 0x484006ee,   // uz.jw.is_544 ms.gv.su_432  gl.ca.sk_322 de.lb.tt_422 
  0x276518af, 0x1c1143ec, 0x1e431c0c, 0x650157ee,   // ga.gv.gd_655 ie.ro.id_644  id.ie.ms_543 na.en.gv_422 
  0x534c315a, 0x151d310c, 0x5d650104, 0x324f6505,   // az.wo.ht_553 az.la.un_543  en.gv.ss_332 gv.bi.bs_333 
  0x29530107, 0x48651fa4, 0x634d010c, 0x01004f07,   // en.ht.sl_432 cy.gv.tt_433  en.aa.sco_543 bi.en.un_420 
  // [154c0]
  0x27790504, 0x041357a4, 0x2337010c, 0x760a1c0c,   // fr.war.gd_332 na.et.fi_433  en.st.ca_543 id.pt.crs_543 
  0x291153ac, 0x06404308, 0x795a65a4, 0x25234404,   // ht.ro.sl_632 ie.lb.de_443  gv.sm.war_433 kk.ky.mn_332 
  0x05231d08, 0x40650608, 0x0d224da9, 0x02001d07,   // la.ca.fr_443 de.gv.lb_443  aa.oc.cs_544 la.da.un_420 
  0x65002513, 0x25000f02, 0x0a35080d, 0x0c00481f,   // eu.gv.un_650 lv.eu.un_220  uk.tg.mk_554 tt.sv.un_840 
  // [154d0]
  0x0f1d25a0, 0x79480c07, 0x4b495a04, 0x48362309,   // eu.la.lv_322 sv.tt.war_432  sm.to.mi_332 ky.ab.tt_444 
  0x1222460d, 0x2d224d0c, 0x0d2d12a7, 0x030c3304,   // qu.oc.hu_554 aa.oc.sk_543  hu.sk.cs_532 nn.sv.nl_332 
  0x251515af, 0x122d0d0b, 0x48000608, 0x234a4204,   // un.mn.un_650 cs.sk.hu_542  de.tt.un_430 co.yo.ca_332 
  0x3e004219, 0x0c064013, 0x51000219, 0x0a003508,   // co.rm.un_750 lb.de.sv_665  da.kl.un_750 tg.mk.un_430 
  // [154e0]
  0x2e0802a7, 0x10370404, 0x2c0e1d07, 0x13001d0d,   // da.no.fo_532 ru.ba.be_332  la.is.fy_432 la.et.un_540 
  0x481304a4, 0x46000902, 0x060457ad, 0x13000936,   // fi.et.tt_433 pl.qu.un_220  na.fi.de_643 hi.bh.un_AA0 
  0x353025ac, 0x3e00421b, 0x383c3055, 0x6e002c08,   // mn.uz.tg_632 co.rm.un_770  uz.ug.tk_442 fy.hmn.un_430 
  0x4c1d0e0c, 0x2c031d0c, 0x061d0ea9, 0x1c2f34a0,   // is.la.wo_543 la.nl.fy_543  is.la.de_544 xh.su.id_322 
  // [154f0]
  0x04004713, 0x3c231812, 0x5f004902, 0x475c2112,   // sn.fi.un_650 ar.ky.ug_654  to.tn.un_220 jw.sa.sn_654 
  0x13480ca0, 0x17240ca0, 0x46002823, 0x1c0f21a0,   // sv.tt.et_322 sv.eo.sr_322  sw.qu.un_880 jw.lv.id_322 
  0x1e0d22a0, 0x10442307, 0x330203a0, 0x21fa350c,   // oc.cs.ms_322 ky.kk.be_432  nl.da.nn_322 zu.nr.jw_543 
  0x300417a7, 0x154825a7, 0x35342809, 0x25002b18,   // sr.ru.uz_532 mn.tt.un_532  sw.xh.zu_444 vi.eu.un_740 
  // [15500]
  0x1f103812, 0x35344602, 0x480c04ad, 0x0c040609,   // tk.lt.cy_654 qu.xh.zu_222  fi.sv.tt_643 de.fi.sv_444 
  0x4b006812, 0x1e004b07, 0x50491aac, 0x011d4e0b,   // ig.mi.un_640 mi.ms.un_420  tl.to.fj_632 ay.la.en_542 
  0x6a00500d, 0x39032407, 0x483711a4, 0x12002209,   // fj.haw.un_540 eo.nl.br_432  ro.ba.tt_433 oc.hu.un_440 
  0x30005114, 0x6b0201a0, 0x2c5a65ee, 0x27651813,   // kl.uz.un_660 en.da.ceb_322  gv.sm.fy_422 ga.gv.gd_665 
  // [15510]
  0x151001a4, 0x655a01a4, 0x6518480c, 0x2a004222,   // en.lt.un_433 en.sm.gv_433  tt.ga.gv_543 co.mt.un_870 
  0x2800450c, 0x480c04ee, 0x10003b02, 0x2130230c,   // ln.sw.un_530 fi.sv.tt_422  so.lt.un_220 ky.uz.fa_543 
  0x3f0e03a9, 0x37003613, 0x255a0107, 0x48000c21,   // nl.is.af_544 ab.ba.un_650  en.sm.eu_432 sv.tt.un_860 
  0x04495aa4, 0x636a7308, 0x51001d0e, 0x02060404,   // sm.to.fi_433 ny.haw.sco_443  la.kl.un_550 fi.de.da_332 
  // [15520]
  0x42114c08, 0x04000c1b, 0x3e264212, 0x4c00420e,   // wo.ro.co_443 sv.fi.un_770  co.ia.rm_654 co.wo.un_550 
  0x180979a7, 0x2e1d02a0, 0x2100260c, 0x392601a4,   // war.pl.ga_532 da.la.fo_322  ia.jw.un_530 en.ia.br_433 
  0x07023e07, 0x6540020c, 0x073730ee, 0x22124dad,   // rm.da.it_432 da.lb.gv_543  uz.ba.bg_422 aa.hu.oc_643 
  0x407902a0, 0x26000122, 0x22134d04, 0xfe005119,   // da.war.lb_322 en.ia.un_870  aa.et.oc_332 kl.tlh.un_750 
  // [15530]
  0x30183cee, 0x37000204, 0x133804a7, 0x11004d0d,   // ug.ar.uz_422 da.st.un_320  fi.tk.et_532 aa.ro.un_540 
  0x4a00360e, 0x1912220c, 0x0b000a08, 0x40065760,   // gn.yo.un_550 oc.hu.gl_543  pt.es.un_430 na.de.lb_664 
  0x22124daf, 0x5d003012, 0x304d110d, 0x760e53ec,   // aa.hu.oc_655 uz.ss.un_640  ro.aa.uz_554 ht.is.crs_644 
  0x01001f04, 0x060c02a0, 0x043025ee, 0x15150404,   // cy.en.un_320 da.sv.de_322  mn.uz.ru_422 ru.un.un_320 
  // [15540]
  0x21233ca0, 0x13286a04, 0x496a5aa7, 0x0c400407,   // ug.ky.fa_322 haw.sw.et_332  sm.haw.to_532 fi.lb.sv_432 
  0x4b2049a4, 0x3100380d, 0x3f2102a0, 0x0c00041a,   // to.sq.mi_433 tk.az.un_540  da.jw.af_322 fi.sv.un_760 
  0x12006019, 0x51000213, 0x18273404, 0x79004605,   // vo.hu.un_750 da.kl.un_650  xh.gd.ga_332 qu.war.un_330 
  0x491d625a, 0x6800730e, 0x6b004721, 0x40580107,   // kha.la.to_553 ny.ig.un_550  sn.ceb.un_860 en.om.lb_432 
  // [15550]
  0x6302580c, 0x4302620d, 0x4c045108, 0x4b6325a4,   // om.da.sco_543 kha.da.ie_554  kl.fi.wo_443 eu.sco.mi_433 
  0x1312390d, 0xfe4730a9, 0x1afe600c, 0x13477304,   // br.hu.et_554 uz.sn.tlh_544  vo.tlh.tl_543 ny.sn.et_332 
  0x06400e14, 0x02fe60af, 0x79001a19, 0x40004809,   // is.lb.de_666 vo.tlh.da_655  tl.war.un_750 tt.lb.un_440 
  0x474b5a5a, 0x1b092da4, 0x503455a0, 0x64006809,   // sm.mi.sn_553 sk.pl.tr_433  rw.xh.fj_322 ig.lg.un_440 
  // [15560]
  0x060c04a0, 0x42001121, 0x1afe60ad, 0x6440120c,   // fi.sv.de_322 ro.co.un_860  vo.tlh.tl_643 hu.lb.lg_543 
  0x79060d09, 0x02113008, 0x423e0207, 0x4c6764ad,   // cs.de.war_444 uz.ro.da_443  da.rm.co_432 lg.ak.wo_643 
  0x60300207, 0x10321708, 0x30122112, 0x3b304c04,   // da.uz.vo_432 sr.bs.lt_443  fa.ur.uz_654 wo.uz.so_332 
  0x04135407, 0x0e025fa4, 0x04004719, 0x0203fea9,   // ik.et.fi_432 tn.da.is_433  sn.fi.un_750 tlh.nl.da_544 
  // [15570]
  0x041e5204, 0x0e1304a6, 0x150d3707, 0x063f2c08,   // ha.ms.fi_332 fi.et.is_521  st.cs.un_432 fy.af.de_443 
  0x5b390107, 0x5a1a6ba4, 0x300a1708, 0x06480cee,   // en.br.sg_432 ceb.tl.sm_433  sr.mk.uz_443 sv.tt.de_422 
  0x400660a9, 0x043c0804, 0x48040ca0, 0x48000c0c,   // vo.de.lb_544 uk.ug.ru_332  sv.fi.tt_322 sv.tt.un_530 
  0x48000609, 0x0c0448b6, 0x3b343d08, 0x373c11a9,   // de.tt.un_440 tt.fi.sv_766  ku.ps.ks_443 ro.ug.ba_544 
  // [15580]
  0x04360604, 0x230a07af, 0x0c480605, 0x0a1538ec,   // de.gn.fi_332 bg.mk.ky_655  de.tt.sv_333 tk.mk.un_640 
  0x0460061d, 0x0d5c48a0, 0x313032a0, 0x04351712,   // de.vo.fi_852 tt.sa.cs_322  bs.uz.az_322 sr.tg.ru_654 
  0x44483013, 0x23002121, 0x79245c08, 0x3600780c,   // uz.tt.kk_665 fa.ky.un_860  sa.eo.war_443 ve.gn.un_530 
  0x553247a0, 0x79450bee, 0x285c4309, 0x0800390c,   // sn.bs.rw_322 es.ln.war_422  ie.sa.sw_444 br.no.un_530 
  // [15590]
  0x421d01a0, 0x181234a9, 0x261d4314, 0x6b011dee,   // en.la.co_322 ps.ur.ar_544  ie.la.ia_666 la.en.ceb_422 
  0x242f5c07, 0x301511ad, 0x02005502, 0x13095c14,   // sa.su.eo_432 ro.uz.un_630  rw.da.un_220 sa.hi.bh_666 
  0x1d4201a0, 0x5c201302, 0x5d244308, 0x09163307,   // en.co.la_322 et.sq.sa_222  ie.eo.ss_443 nn.hr.pl_432 
  0x28595555, 0x690e76a9, 0x033f0705, 0x121823a0,   // rw.rn.sw_442 crs.is.mfe_544  it.af.nl_333 ky.ar.ur_322 
  // [155a0]
  0x072464ee, 0x6b071aa4, 0x53003912, 0x0c00060d,   // lg.eo.it_422 tl.it.ceb_433  br.ht.un_640 de.sv.un_540 
  0x53005c08, 0x1f3e7355, 0x64025f07, 0x13025c04,   // sa.ht.un_430 ny.rm.cy_442  tn.da.lg_432 sa.da.et_332 
  0x3d12210d, 0x42600704, 0x35001014, 0x345e780c,   // fa.ur.ku_554 it.vo.co_332  lt.zu.un_660 ve.ts.xh_543 
  0x64190bee, 0x53003919, 0x641d5507, 0x7669390c,   // es.gl.lg_422 br.ht.un_750  rw.la.lg_432 br.mfe.crs_543 
  // [155b0]
  0x2e120ea7, 0x1a020ba9, 0x53693907, 0x42003e05,   // is.hu.fo_532 es.da.tl_544  br.mfe.ht_432 rm.co.un_330 
  0x353428a9, 0x69003921, 0x24571f12, 0x2e003923,   // sw.xh.zu_544 br.mfe.un_860  cy.na.eo_654 br.fo.un_880 
  0x24000212, 0x5369390c, 0x02085104, 0x2e461da0,   // da.eo.un_640 br.mfe.ht_543  kl.no.da_332 la.qu.fo_322 
  0x0d006307, 0x36004604, 0x0c005708, 0x12343baf,   // sco.cs.un_420 qu.gn.un_320  na.sv.un_430 ks.ps.ur_655 
  // [155c0]
  0x022e33ec, 0x02082e0c, 0x0e2e0ba0, 0x02000d08,   // nn.fo.da_644 fo.no.da_543  es.fo.is_322 cs.da.un_430 
  0x48060c60, 0x08023904, 0x1e005604, 0x21023fa0,   // sv.de.tt_664 br.da.no_332  mg.ms.un_320 af.da.jw_322 
  0x3f6b1a08, 0x1e001213, 0x16002402, 0x31000904,   // tl.ceb.af_443 hu.ms.un_650  eo.hr.un_220 pl.az.un_320 
  0x330806ee, 0x023e1b04, 0x33003e12, 0x283d4408,   // de.no.nn_422 tr.rm.da_332  rm.nn.un_640 kk.ku.sd_443 
  // [155d0]
  0x05230b04, 0x4a002522, 0x0a0411a7, 0x211c2f55,   // es.ca.fr_332 eu.yo.un_870  ro.ru.mk_532 su.id.jw_442 
  0x5e287812, 0x52000704, 0x3e220f0c, 0x48001602,   // ve.sw.ts_654 it.ha.un_320  lv.oc.rm_543 hr.tt.un_220 
  0x2f054c05, 0x34304aee, 0x2d321655, 0x213d3c0c,   // wo.fr.su_333 yo.uz.xh_422  hr.bs.sk_442 ug.ku.fa_543 
  0x73024d0e, 0x1c5d2a07, 0x68433107, 0x300735a0,   // aa.da.ny_555 mt.ss.id_432  az.ie.ig_432 tg.bg.uz_322 
  // [155e0]
  0x480a1504, 0x43001d2b, 0xfc006505, 0x39000207,   // un.mk.tt_332 la.ie.un_980  gv.zzp.un_330 da.br.un_420 
  0x30211207, 0x48130c04, 0x5d7335a4, 0x3e351bee,   // ur.fa.uz_432 sv.et.tt_332  zu.ny.ss_433 tr.zu.rm_422 
  0x48064005, 0x024efc12, 0x30fc13a0, 0x04064004,   // lb.de.tt_333 zzp.ay.da_654  et.zzp.uz_322 lb.de.fi_332 
  0x21442308, 0x0c00620d, 0x1e393007, 0x0e133807,   // ky.kk.fa_443 kha.sv.un_540  uz.br.ms_432 tk.et.is_432 
  // [155f0]
  0x0c33080b, 0x0640485a, 0x40000c0d, 0x040c40a7,   // no.nn.sv_542 tt.lb.de_553  sv.lb.un_540 lb.sv.fi_532 
  0x21182811, 0x303d12ec, 0x083302a0, 0x233c11ad,   // sd.ar.fa_653 ur.ku.uz_644  da.nn.no_322 ro.ug.ky_643 
  0x12210402, 0x210413a0, 0x3c483512, 0x37234808,   // fi.jw.hu_222 et.fi.jw_322  tg.tt.ug_654 tt.ky.ba_443 
  0x3600110b, 0x19220b0c, 0x04000607, 0x13643805,   // ro.ab.un_520 es.oc.gl_543  de.fi.un_420 tk.lg.et_333 
  // [15600]
  0x48352307, 0x562223ec, 0x3e060ca0, 0x4423370e,   // ky.tg.tt_432 ca.oc.mg_644  sv.de.rm_322 ba.ky.kk_555 
  0x0600480d, 0x48040c05, 0x38000c0b, 0x5c474207,   // tt.de.un_540 sv.fi.tt_333  sv.tk.un_520 co.sn.sa_432 
  0x311b4508, 0x30350a12, 0x33020eee, 0x24111307,   // ln.tr.az_443 mk.tg.uz_654  is.da.nn_422 et.ro.eo_432 
  0x11364602, 0x0400060c, 0x0c044804, 0x211e2fa7,   // qu.gn.ro_222 de.fi.un_530  tt.fi.sv_332 su.ms.jw_532 
  // [15610]
  0x38064813, 0x0c473e07, 0x51004c02, 0x380c0407,   // tt.de.tk_665 rm.sn.sv_432  wo.kl.un_220 fi.sv.tk_432 
  0x2c0a5bad, 0x2f626b12, 0x732765a9, 0x3b004b02,   // sg.pt.fy_643 ceb.kha.su_654  gv.gd.ny_544 mi.so.un_220 
  0x3f20465e, 0x11003111, 0x25231507, 0x53004007,   // qu.sq.af_652 az.ro.un_630  un.ky.mn_432 lb.ht.un_420 
  0x23004004, 0x20005b19, 0x04480aee, 0x6527020c,   // lb.ca.un_320 sg.sq.un_750  mk.tt.ru_422 da.gd.gv_543 
  // [15620]
  0x2765180d, 0x6527180c, 0x234020ad, 0x20005307,   // ga.gv.gd_554 ga.gd.gv_543  sq.lb.ca_643 ht.sq.un_420 
  0x23001216, 0x45004818, 0x1700fc05, 0x5e00570d,   // hu.ca.un_720 tt.ln.un_740  zzp.sr.un_330 na.ts.un_540 
  0x1d1bfcad, 0x12004008, 0x46193ea4, 0x0e232ea0,   // zzp.tr.la_643 lb.hu.un_430  rm.gl.qu_433 fo.ca.is_322 
  0x2f12400c, 0x2f0b21a0, 0x18001d1a, 0x0b401204,   // lb.hu.su_543 jw.es.su_322  la.ga.un_760 hu.lb.es_332 
  // [15630]
  0x1b512f04, 0x0f190b0d, 0x2739020c, 0x171325ee,   // su.kl.tr_332 es.gl.lv_554  da.br.gd_543 eu.et.sr_422 
  0x033f690c, 0x190a0f0e, 0x133121a0, 0x1f395ca0,   // mfe.af.nl_543 lv.pt.gl_555  jw.az.et_322 sa.br.cy_322 
  0x27003605, 0x6b000e13, 0x33000c10, 0x6b791a12,   // gn.gd.un_330 is.ceb.un_650  sv.nn.un_620 tl.war.ceb_654 
  0x25092da0, 0x02000e19, 0x2e0e02a7, 0x27000f05,   // sk.pl.eu_322 is.da.un_750  da.is.fo_532 lv.gd.un_330 
  // [15640]
  0x02001a12, 0x036b79ec, 0x304a4dad, 0x37007512,   // tl.da.un_640 war.ceb.nl_644  aa.yo.uz_643 nso.st.un_640 
  0x23002b04, 0x101711ee, 0x07370407, 0x73011fa0,   // vi.ca.un_320 ro.sr.be_422  ru.ba.bg_432 cy.en.ny_322 
  0x64285507, 0x3f0279ee, 0x34005302, 0x126e6b04,   // rw.sw.lg_432 war.da.af_422  ht.xh.un_220 ceb.hmn.hu_332 
  0x65002e1b, 0x1d003604, 0x19002d0d, 0x04080714,   // fo.gv.un_770 gn.la.un_320  sk.gl.un_540 bg.uk.ru_666 
  // [15650]
  0x0a12195a, 0x6b002412, 0x23364204, 0x0722420d,   // gl.hu.pt_553 eo.ceb.un_640  co.gn.ca_332 co.oc.it_554 
  0x22074207, 0x460f5aa0, 0x220742ec, 0x3010fe07,   // co.it.oc_432 sm.lv.qu_322  co.it.oc_644 tlh.lt.uz_432 
  0x420736ac, 0x06000c10, 0x0b00360b, 0x060c1504,   // gn.it.co_632 sv.de.un_620  gn.es.un_520 un.sv.de_332 
  0x303b120c, 0x36000a12, 0x2e193604, 0x102d0d55,   // ur.ks.uz_543 pt.gn.un_640  gn.gl.fo_332 cs.sk.lt_442 
  // [15660]
  0x790a010c, 0x4200070e, 0x0b00090c, 0x5f330808,   // en.pt.war_543 it.co.un_550  pl.es.un_530 no.nn.tn_443 
  0x23420704, 0xfc595508, 0x0b42070c, 0x4825110c,   // it.co.ca_332 rw.rn.zzp_443  it.co.es_543 ro.mn.tt_543 
  0x23220704, 0x0c004821, 0x19002d08, 0x595534ec,   // it.oc.ca_332 tt.sv.un_860  sk.gl.un_430 xh.rw.rn_644 
  0x5528730d, 0x576455a4, 0x04100d07, 0x5d0a3b04,   // ny.sw.rw_554 rw.lg.na_433  cs.lt.fi_432 so.pt.ss_332 
  // [15670]
  0x590a55ec, 0x06000410, 0x650a1da4, 0x0a364a02,   // rw.pt.rn_644 fi.de.un_620  la.pt.gv_433 yo.gn.pt_222 
  0x020a0505, 0x06755fa4, 0x500c0209, 0x0b001919,   // fr.pt.da_333 tn.nso.de_433  da.sv.fj_444 gl.es.un_750 
  0x5f46150c, 0x5e00010d, 0x6b001819, 0x134004a0,   // un.qu.tn_543 en.ts.un_540  ga.ceb.un_750 fi.lb.et_322 
  0x056e2208, 0x2f1b1ea0, 0x30001223, 0x35303ca7,   // oc.hmn.fr_443 ms.tr.su_322  ur.uz.un_880 ug.uz.tg_532 
  // [15680]
  0x38650a07, 0x330f0805, 0x251007ad, 0x1b48041a,   // pt.gv.tk_432 no.lv.nn_333  bg.be.mn_643 fi.tt.tr_776 
  0x2310445a, 0x080c2ea0, 0x40480c5a, 0x1b20050c,   // kk.be.ky_553 fo.sv.no_322  sv.tt.lb_553 fr.sq.tr_543 
  0x3f001107, 0x0a000616, 0x22000a19, 0x52344ca7,   // ro.af.un_420 de.pt.un_720  pt.oc.un_750 wo.xh.ha_532 
  0x2a002207, 0x03290fad, 0x40600613, 0x042535a4,   // oc.mt.un_420 lv.sl.nl_643  de.vo.lb_665 tg.mn.ru_433 
  // [15690]
  0x32002911, 0x170a36a9, 0x304448a9, 0x040711a6,   // sl.bs.un_630 ab.mk.sr_544  tt.kk.uz_544 ro.bg.ru_521 
  0x1d00571a, 0x641d68ee, 0x2408330c, 0x132e0e11,   // na.la.un_760 ig.la.lg_422  nn.no.eo_543 is.fo.et_653 
  0x4b005008, 0x270f1da0, 0x043715ee, 0x2f2421ad,   // fj.mi.un_430 la.lv.gd_322  un.ba.ru_422 jw.eo.su_643 
  0x083c30ec, 0x5d601ea9, 0x35215da4, 0x39500955,   // uz.ug.uk_644 ms.vo.ss_544  ss.jw.zu_433 pl.fj.br_442 
  // [156a0]
  0x7300601a, 0x1800330e, 0x64675d11, 0x3f2f1a07,   // vo.ny.un_760 nn.ga.un_550  ss.ak.lg_653 tl.su.af_432 
  0x231d1e07, 0x28005120, 0x1c47570c, 0x64685d09,   // ms.la.ca_432 kl.sw.un_850  na.sn.id_543 ss.ig.lg_444 
  0x51000c02, 0x6a4b5413, 0x482344a4, 0x022e0e5a,   // sv.kl.un_220 ik.mi.haw_665  kk.ky.tt_433 is.fo.da_553 
  0x025128af, 0x12130ead, 0x233509a7, 0x2f033f04,   // sw.kl.da_655 is.et.hu_643  pl.zu.ca_532 af.nl.su_332 
  // [156b0]
  0x32101704, 0x650507a0, 0x3124fcee, 0x6b016304,   // sr.lt.bs_332 it.fr.gv_322  zzp.eo.az_422 sco.en.ceb_332 
  0x09290f0c, 0x07425311, 0x2e1b25ad, 0x42005319,   // lv.sl.pl_543 ht.co.it_653  eu.tr.fo_643 ht.co.un_750 
  0x39000d07, 0x3537150c, 0x56400b04, 0x425322a0,   // cs.br.un_420 un.ba.tg_543  es.lb.mg_332 oc.ht.co_322 
  0x7900121a, 0x1504100e, 0x4a00531a, 0x0722530b,   // hu.war.un_760 be.ru.un_555  ht.yo.un_760 ht.oc.it_542 
  // [156c0]
  0x4a2153ec, 0x44003c18, 0x25001b05, 0x42534a12,   // ht.jw.yo_644 ug.kk.un_740  tr.eu.un_330 yo.ht.co_654 
  0x3e534a05, 0x04234404, 0x3100600c, 0x48001221,   // yo.ht.rm_333 kk.ky.ru_332  vo.az.un_530 hu.tt.un_860 
  0x3f0c03a4, 0x4d00431a, 0x0b004816, 0x38442360,   // nl.sv.af_433 ie.aa.un_760  tt.es.un_720 ky.kk.tk_664 
  0x37251008, 0x190e0aee, 0x385706a4, 0x06026907,   // be.mn.ba_443 pt.is.gl_422  de.na.tk_433 mfe.da.de_432 
  // [156d0]
  0x232257ad, 0x06193605, 0x58344aa4, 0x48230aa6,   // na.oc.ca_643 gn.gl.de_333  yo.xh.om_433 mk.ky.tt_521 
  0x40001217, 0x0e0922ee, 0x5d007321, 0x233c380e,   // hu.lb.un_730 oc.pl.is_422  ny.ss.un_860 tk.ug.ky_555 
  0x36197808, 0x42023004, 0x3478735a, 0x07041105,   // ve.gl.gn_443 uz.da.co_332  ny.ve.xh_553 ro.ru.bg_333 
  0x1f003f0d, 0x5d6b600c, 0x33000208, 0x65003b19,   // af.cy.un_540 vo.ceb.ss_543  da.nn.un_430 so.gv.un_750 
  // [156e0]
  0x58653bad, 0x02083304, 0x643b65a9, 0x0e2e0702,   // so.gv.om_643 nn.no.da_332  gv.so.lg_544 it.fo.is_222 
  0x12343c07, 0x583f3b09, 0x0d004202, 0x051143a4,   // ug.ps.ur_432 so.af.om_444  co.cs.un_220 ie.ro.fr_433 
  0x2a586407, 0x1d5451ad, 0x20103013, 0x044501a4,   // lg.om.mt_432 kl.ik.la_643  uz.lt.sq_665 en.ln.fi_433 
  0x104437a7, 0x035d6a08, 0xfc583402, 0x4c653f04,   // ba.kk.be_532 haw.ss.nl_443  xh.om.zzp_222 af.gv.wo_332 
  // [156f0]
  0x26006008, 0x651c3b04, 0x391d49a9, 0x08170a55,   // vo.ia.un_430 so.id.gv_332  to.la.br_544 mk.sr.uk_442 
  0x6b004005, 0x2d001814, 0x583b4c0b, 0x48371004,   // lb.ceb.un_330 ga.sk.un_660  wo.so.om_542 be.ba.tt_332 
  0x013658ee, 0x565c3013, 0x0e002e35, 0x122130a6,   // om.gn.en_422 uz.sa.mg_665  fo.is.un_A90 uz.fa.ur_521 
  0x16134fa4, 0x061348a0, 0x3e4311af, 0x23001112,   // bi.et.hr_433 tt.et.de_322  ro.ie.rm_655 ro.ca.un_640 
  // [15700]
  0x105e5613, 0x6700030d, 0x1d3901a0, 0x070811a0,   // mg.ts.lt_665 nl.ak.un_540  en.br.la_322 ro.uk.bg_322 
  0x08073c05, 0x6a5c470c, 0x233830ec, 0x60495c0c,   // ug.bg.uk_333 sn.sa.haw_543  uz.tk.ky_644 sa.to.vo_543 
  0x40000413, 0x461e1c07, 0x6b494bad, 0x4e5c3608,   // fi.lb.un_650 id.ms.qu_432  mi.to.ceb_643 gn.sa.ay_443 
  0x0e004519, 0x3600530c, 0x1f00600e, 0x7300190d,   // ln.is.un_750 ht.gn.un_530  vo.cy.un_550 gl.ny.un_540 
  // [15710]
  0x464e5c05, 0x2e054365, 0x13475cad, 0x65000621,   // sa.ay.qu_333 ie.fr.fo_763  sa.sn.et_643 de.gv.un_860 
  0x28736804, 0x01002e04, 0x21004d23, 0x07425ea9,   // ig.ny.sw_332 fo.en.un_320  aa.jw.un_880 ts.co.it_544 
  0x044f6712, 0x1d402f02, 0x73381b0d, 0x043646a4,   // ak.bi.fi_654 su.lb.la_222  tr.tk.ny_554 qu.gn.fi_433 
  0x0a0738ee, 0x403e06ad, 0x385247ad, 0x40002f07,   // tk.bg.mk_422 de.rm.lb_643  sn.ha.tk_643 su.lb.un_420 
  // [15720]
  0x171125a7, 0x3900250c, 0x1c212f11, 0x64571ea9,   // mn.ro.sr_532 eu.br.un_530  su.jw.id_653 ms.na.lg_544 
  0x50291ea4, 0x6a1d2f12, 0x4255110c, 0x1d232fad,   // ms.sl.fj_433 su.la.haw_654  ro.rw.co_543 su.ca.la_643 
  0x232f1707, 0x56005f04, 0x3f390607, 0x12645e0c,   // sr.su.ca_432 tn.mg.un_320  de.br.af_432 ts.lg.hu_543 
  0x471157ad, 0x4a121902, 0x0e003204, 0x1223440d,   // na.ro.sn_643 gl.hu.yo_222  bs.is.un_320 kk.ky.ur_554 
  // [15730]
  0x25005504, 0x3525080c, 0x342555a0, 0x351e2f02,   // rw.eu.un_320 uk.mn.tg_543  rw.eu.xh_322 su.ms.zu_222 
  0x36461207, 0x2f0328a0, 0x63032fee, 0x443604a0,   // hu.qu.gn_432 sw.nl.su_322  su.nl.sco_422 ru.ab.kk_322 
  0x4a002709, 0x5e250307, 0x381036af, 0x0c134002,   // gd.yo.un_440 nl.eu.ts_432  ab.be.tk_655 lb.et.sv_222 
  0x0c134e12, 0x502f04a7, 0x0f2d0d02, 0x08002f08,   // ay.et.sv_654 fi.su.fj_532  cs.sk.lv_222 su.no.un_430 
  // [15740]
  0x032f3f0d, 0x492f0455, 0x34231207, 0x06576060,   // af.su.nl_554 fi.su.to_442  ur.ky.ps_432 vo.na.de_664 
  0x04170709, 0x21303408, 0x12005c0d, 0x0d20460c,   // bg.sr.ru_444 ps.uz.fa_443  sa.hu.un_540 qu.sq.cs_543 
  0x55000a12, 0x2b002002, 0x383c080c, 0x21052ca0,   // pt.rw.un_640 sq.vi.un_220  uk.ug.tk_543 fy.fr.jw_322 
  0x2769760d, 0x0e27185a, 0x3e495aa0, 0x02006023,   // crs.mfe.gd_554 ga.gd.is_553  sm.to.rm_322 vo.da.un_880 
  // [15750]
  0x6b020e55, 0x0e5c5311, 0x12460d0c, 0x0e1365a4,   // is.da.ceb_442 ht.sa.is_653  cs.qu.hu_543 gv.et.is_433 
  0x27185305, 0x28180407, 0x0f040ea0, 0x287336a9,   // ht.ga.gd_333 fi.ga.sw_432  is.fi.lv_322 gn.ny.sw_544 
  0x1107420c, 0x46105ca9, 0x0a085a08, 0x6939180c,   // co.it.ro_543 sa.lt.qu_544  sm.no.pt_443 ga.br.mfe_543 
  0x5a474911, 0x07040a0e, 0x1f5f1308, 0x1853390c,   // to.sn.sm_653 mk.ru.bg_555  et.tn.cy_443 br.ht.ga_543 
  // [15760]
  0x27021812, 0x63375fa4, 0x182701a0, 0x1f0e2e5a,   // ga.da.gd_654 tn.st.sco_433  en.gd.ga_322 fo.is.cy_553 
  0x302812af, 0x655a2cad, 0x06606508, 0x1d0b5aec,   // ur.sd.uz_655 fy.sm.gv_643  gv.vo.de_443 sm.es.la_644 
  0x53006908, 0x79002604, 0x030660a4, 0x5c0c5305,   // mfe.ht.un_430 ia.war.un_320  vo.de.nl_433 ht.sv.sa_333 
  0x53400612, 0x69765305, 0x276953a9, 0x5a002405,   // de.lb.ht_654 ht.crs.mfe_333  ht.mfe.gd_544 eo.sm.un_330 
  // [15770]
  0x02765308, 0x180465ad, 0x1f270807, 0x0210180c,   // ht.crs.da_443 gv.fi.ga_643  no.gd.cy_432 ga.lt.da_543 
  0x3f0350a9, 0x30003e21, 0x1318060c, 0x54635a05,   // fj.nl.af_544 rm.uz.un_860  de.ga.et_543 sm.sco.ik_333 
  0x69765108, 0x2c033fee, 0x3b190bad, 0x104c5307,   // kl.crs.mfe_443 af.nl.fy_422  es.gl.so_643 ht.wo.lt_432 
  0x4d006020, 0x3b2f3004, 0x4d631813, 0x021969a4,   // vo.aa.un_850 uz.su.so_332  ga.sco.aa_665 mfe.gl.da_433 
  // [15780]
  0x343d44a7, 0x791809ec, 0x47007905, 0x38303e12,   // kk.ku.ps_532 pl.ga.war_644  war.sn.un_330 rm.uz.tk_654 
  0x30003e19, 0x483704a0, 0x271d01a0, 0x19004c05,   // rm.uz.un_750 ru.ba.tt_322  en.la.gd_322 wo.gl.un_330 
  0x10211c07, 0x30583b08, 0x42134708, 0x1c213007,   // id.jw.lt_432 so.om.uz_443  sn.et.co_443 uz.jw.id_432 
  0x3000470d, 0x3065470b, 0x383e13af, 0x4f2a1ea0,   // sn.uz.un_540 sn.gv.uz_542  et.rm.tk_655 ms.mt.bi_322 
  // [15790]
  0x1f6713a9, 0x330e0ca0, 0x4f21080c, 0x4667040b,   // et.ak.cy_544 sv.is.nn_322  no.jw.bi_543 fi.ak.qu_542 
  0x4d641f0c, 0x1d3b2da4, 0x12391b0d, 0x1276690d,   // cy.lg.aa_543 sk.so.la_433  tr.br.hu_554 mfe.crs.hu_554 
  0x0c4c15a4, 0x120a01a4, 0x033f2aa9, 0x3c3748a9,   // un.wo.sv_433 en.pt.hu_433  mt.af.nl_544 tt.ba.ug_544 
  0x06393f07, 0x4f13760d, 0x65fc0eaf, 0x65620e0d,   // af.br.de_432 crs.et.bi_554  is.zzp.gv_655 is.kha.gv_554 
  // [157a0]
  0x0a001207, 0x0c651f55, 0x102c65ad, 0x10096507,   // hu.pt.un_420 cy.gv.sv_442  gv.fy.lt_643 gv.pl.lt_432 
  0x30213da4, 0x65621fad, 0x10002c0b, 0x0e1f6512,   // ku.fa.uz_433 cy.kha.gv_643  fy.lt.un_520 gv.cy.is_654 
  0x3d2330a4, 0x33003807, 0x557364ad, 0x24007304,   // uz.ky.ku_433 tk.nn.un_420  lg.ny.rw_643 ny.eo.un_320 
  0x040962a9, 0x0c1f04a4, 0x3500280b, 0x27011fa6,   // kha.pl.fi_544 fi.cy.sv_433  sw.zu.un_520 cy.en.gd_521 
  // [157b0]
  0x04606512, 0x0c0802a9, 0x1f2c0408, 0x3b1223a4,   // gv.vo.fi_654 da.no.sv_544  fi.fy.cy_443 ky.ur.ks_433 
  0x13000617, 0x0c0e4c08, 0x47025504, 0x080a11a6,   // de.et.un_730 wo.is.sv_443  rw.da.sn_332 ro.mk.uk_521 
  0x48403604, 0x17000f02, 0x2e000d04, 0x281d0bee,   // gn.lb.tt_332 lv.sr.un_220  cs.fo.un_320 es.la.sw_422 
  0x23443c04, 0x17000409, 0xfc495a0c, 0x04303505,   // ug.kk.ky_332 ru.sr.un_440  sm.to.zzp_543 tg.uz.ru_333 
  // [157c0]
  0x79686baf, 0x3c251507, 0x30254808, 0x6b00680d,   // ceb.ig.war_655 un.mn.ug_432  tt.mn.uz_443 ig.ceb.un_540 
  0x2e0e02a9, 0x13555a04, 0x48135aec, 0x55130e12,   // da.is.fo_544 sm.rw.et_332  sm.et.tt_644 is.et.rw_654 
  0x0b361904, 0x55001307, 0x5f2f59a4, 0x5a006419,   // gl.gn.es_332 et.rw.un_420  rn.su.tn_433 lg.sm.un_750 
  0x73133505, 0x485564af, 0x4a005a19, 0x23074807,   // zu.et.ny_333 lg.rw.tt_655  sm.yo.un_750 tt.bg.ky_432 
  // [157d0]
  0x4800111b, 0x48595504, 0x13485aa4, 0x135a0211,   // ro.tt.un_770 rw.rn.tt_332  sm.tt.et_433 da.sm.et_653 
  0x68135aa4, 0x183421a6, 0x1f00360c, 0x36080404,   // sm.et.ig_433 fa.ps.ar_521  gn.cy.un_530 ru.uk.ab_332 
  0x482337a7, 0x46001804, 0x3b005829, 0x234835ad,   // ba.ky.tt_532 ga.qu.un_320  om.so.un_960 tg.tt.ky_643 
  0x03022160, 0x4200200d, 0x3e002016, 0x422120a7,   // jw.da.nl_664 sq.co.un_540  sq.rm.un_720 sq.jw.co_532 
  // [157e0]
  0x37384407, 0x20002105, 0x22212302, 0x291a24a6,   // kk.tk.ba_432 jw.sq.un_330  ca.jw.oc_222 eo.tl.sl_521 
  0x17100807, 0x13061e04, 0x0b422302, 0x0e0f620c,   // uk.be.sr_432 ms.de.et_332  ca.co.es_222 kha.lv.is_543 
  0x1c002202, 0x641a55ad, 0x651e1c11, 0x13095c0b,   // oc.id.un_220 rw.tl.lg_643  id.ms.gv_653 sa.hi.bh_542 
  0x2f00020b, 0x1e003902, 0x4b005c13, 0x10440408,   // da.su.un_520 br.ms.un_220  sa.mi.un_650 ru.kk.be_443 
  // [157f0]
  0x165642a0, 0x0a190bad, 0x21230ba0, 0x3e1f28ee,   // co.mg.hr_322 es.gl.pt_643  es.ca.jw_322 sw.cy.rm_422 
  0x05005b16, 0x220b2304, 0x17001019, 0x0b23210c,   // sg.fr.un_720 ca.es.oc_332  be.sr.un_750 jw.ca.es_543 
  0x56390c07, 0x13561dee, 0x24283607, 0x15002e02,   // sv.br.mg_432 la.mg.et_422  gn.sw.eo_432 fo.un.un_220 
  0x3004350c, 0x35344aec, 0x0a3035ec, 0x1d1226a4,   // tg.ru.uz_543 yo.xh.zu_644  tg.uz.mk_644 ia.hu.la_433 
  
  // [15800]
  0x1000190e, 0x5a35fcec, 0x330c0809, 0x0e003004,   // gl.lt.un_550 zzp.zu.sm_644  no.sv.nn_444 uz.is.un_320 
  0x440a2505, 0x2f420705, 0x1a002f08, 0x3600020c,   // mn.mk.kk_333 it.co.su_333  su.tl.un_430 da.gn.un_530 
  0x1e54560c, 0x23353807, 0x286b1a60, 0x5d305608,   // mg.ik.ms_543 tk.tg.ky_432  tl.ceb.sw_664 mg.uz.ss_443 
  0x0e2e0202, 0x79561a08, 0x6b4c6407, 0x114f45a9,   // da.fo.is_222 tl.mg.war_443  lg.wo.ceb_432 ln.bi.ro_544 
  // [15810]
  0x2e4a2d0c, 0x1d421f08, 0x51006405, 0x0e003610,   // sk.yo.fo_543 cy.co.la_443  lg.kl.un_330 gn.is.un_620 
  0x305e56a4, 0x391a52a9, 0x07080455, 0x06074205,   // mg.ts.uz_433 ha.tl.br_544  ru.uk.bg_442 co.it.de_333 
  0x313b5eec, 0x3b54510c, 0x31005504, 0x305e4d0d,   // ts.so.az_644 kl.ik.so_543  rw.az.un_320 aa.ts.uz_554 
  0x1d00510d, 0x07000904, 0x07110a55, 0xfc2c1bee,   // kl.la.un_540 pl.it.un_320  mk.ro.bg_442 tr.fy.zzp_422 
  // [15820]
  0x224223a9, 0x3d183412, 0x42222355, 0x350423a0,   // ca.co.oc_544 ps.ar.ku_654  ca.oc.co_442 ky.ru.tg_322 
  0x2223420c, 0x42792308, 0x22233618, 0x22362360,   // co.ca.oc_543 ca.war.co_443  gn.ca.oc_764 ca.gn.oc_664 
  0xfc2536a0, 0x19002208, 0x213d34ad, 0x23420b0c,   // gn.eu.zzp_322 oc.gl.un_430  ps.ku.fa_643 es.co.ca_543 
  0x42222311, 0x0b0a23af, 0x5b4c61af, 0x4a2223ad,   // ca.oc.co_653 ca.pt.es_655  za.wo.sg_655 ca.oc.yo_643 
  // [15830]
  0x23123c12, 0x0a362211, 0x5d006707, 0x0a190b60,   // ug.ur.ky_654 oc.gn.pt_653  ak.ss.un_420 es.gl.pt_664 
  0x345558a0, 0x0c022cee, 0x0700420b, 0x36040708,   // om.rw.xh_322 fy.da.sv_422  co.it.un_520 bg.ru.ab_443 
  0x34355907, 0x04653604, 0xfc1f0904, 0x04406511,   // rn.zu.xh_432 gn.gv.fi_332  pl.cy.zzp_332 gv.lb.fi_653 
  0x654015a0, 0x09003f0d, 0x05630112, 0x1716fca4,   // un.lb.gv_322 af.pl.un_540  en.sco.fr_654 zzp.hr.sr_433 
  // [15840]
  0x171615a0, 0x353420ee, 0x4620fc07, 0xfe07fca4,   // un.hr.sr_322 sq.xh.zu_422  zzp.sq.qu_432 zzp.it.tlh_433 
  0x25fc69a9, 0x343c180c, 0x4815230b, 0x3c0a2504,   // mfe.zzp.eu_544 ar.ug.ps_543  ky.tt.un_520 mn.mk.ug_332 
  0x0b210504, 0x4a122ba0, 0x5d004a22, 0x0e2e4a13,   // fr.jw.es_332 vi.hu.yo_322  yo.ss.un_870 yo.fo.is_665 
  0x6a285108, 0x1f000d04, 0x5d184a12, 0x10005608,   // kl.sw.haw_443 cs.cy.un_320  yo.ga.ss_654 mg.lt.un_430 
  // [15850]
  0x36004902, 0x1f5a6a0c, 0x5d2b4a0b, 0x180a2bec,   // to.gn.un_220 haw.sm.cy_543  yo.vi.ss_542 vi.pt.ga_644 
  0x73281d5a, 0x182d4a0c, 0x084817a0, 0x2b001907,   // la.sw.ny_553 yo.sk.ga_543  sr.tt.uk_322 gl.vi.un_420 
  0x5a2213ee, 0x27653e0c, 0x480444a4, 0x4a0e2dec,   // et.oc.sm_422 rm.gv.gd_543  kk.ru.tt_433 sk.is.yo_644 
  0x301723a9, 0x5d347307, 0x06003704, 0x246560a0,   // ky.sr.uz_544 ny.xh.ss_432  st.de.un_320 vo.gv.eo_322 
  // [15860]
  0x4d182e60, 0x732a16a0, 0x34356412, 0x1a007908,   // fo.ga.aa_664 hr.mt.ny_322  lg.zu.xh_654 war.tl.un_430 
  0x553e64ee, 0x6b5a50ee, 0x342f35a0, 0x081536a4,   // lg.rm.rw_422 fj.sm.ceb_422  zu.su.xh_322 ab.uk.un_430 
  0x4500730d, 0x18001908, 0x1e1c59ee, 0x455d3408,   // ny.ln.un_540 gl.ga.un_430  rn.id.ms_422 xh.ss.ln_443 
  0x79005e0d, 0x294a6455, 0x50000c0c, 0x15012c11,   // ts.war.un_540 lg.yo.sl_442  sv.fj.un_530 fy.en.un_653 
  // [15870]
  0x303507a7, 0x0a5f50a4, 0x09016205, 0x0e3925a9,   // bg.tg.uz_532 fj.tn.pt_433  kha.en.pl_333 eu.br.is_544 
  0x12212814, 0x010965a0, 0x153515a0, 0x595528ec,   // sd.fa.ur_666 gv.pl.en_322  un.tg.un_322 sw.rw.rn_644 
  0x442315ee, 0x27001f1b, 0x367905a4, 0x3b12280d,   // un.ky.kk_422 cy.gd.un_770  fr.war.gn_433 sd.ur.ks_554 
  0x342321ee, 0x113bfca7, 0x623f180c, 0x1d4dfc07,   // fa.ky.ps_422 zzp.so.ro_532  ga.af.kha_543 zzp.aa.la_432 
  // [15880]
  0x16001104, 0x0c000f02, 0x153b0255, 0x0e3f33a0,   // ro.hr.un_320 lv.sv.un_220  da.so.un_442 nn.af.is_322 
  0x37006b07, 0x06033fee, 0x18283d02, 0x557364a4,   // ceb.st.un_420 af.nl.de_422  ku.sd.ar_222 lg.ny.rw_433 
  0x222f64af, 0x353025ad, 0x4a0b4207, 0x45400507,   // lg.su.oc_655 mn.uz.tg_643  co.es.yo_432 fr.lb.ln_432 
  0x03042c07, 0x2e005710, 0x4d00230c, 0x0704085a,   // fy.fi.nl_432 na.fo.un_620  ca.aa.un_530 uk.ru.bg_553 
  // [15890]
  0x30153812, 0x343c3ba4, 0x40065712, 0x434d450c,   // tk.uz.un_640 ks.ug.ps_433  na.de.lb_654 ln.aa.ie_543 
  0x2c2b0207, 0x1d000912, 0x3b064da7, 0x1025080d,   // da.vi.fy_432 pl.la.un_640  aa.de.so_532 uk.mn.be_554 
  0x04003802, 0x12343060, 0x380410a4, 0x07150805,   // tk.fi.un_220 uz.ps.ur_664  be.ru.tk_433 uk.bg.un_330 
  0x29006309, 0x3000070d, 0x21001218, 0x0a00120d,   // sco.sl.un_440 bg.uz.un_540  ur.fa.un_740 hu.pt.un_540 
  // [158a0]
  0x2a433012, 0x59551ea4, 0x400c06af, 0x1e1c2ea4,   // uz.ie.mt_654 ms.rw.rn_433  de.sv.lb_655 fo.id.ms_433 
  0x1a000202, 0x4d554ba9, 0x17001105, 0x3044235a,   // da.tl.un_220 mi.rw.aa_544  ro.sr.un_330 ky.kk.uz_553 
  0x13005104, 0x10070809, 0x11522812, 0x1015075a,   // kl.et.un_320 uk.bg.be_444  sw.ha.ro_654 bg.be.un_530 
  0x28001a0d, 0x1d314c04, 0x1130350e, 0x25001d02,   // tl.sw.un_540 wo.az.la_332  tg.uz.ro_555 la.eu.un_220 
  // [158b0]
  0x464c300c, 0x0a383507, 0x100430a9, 0x2d0d0409,   // uz.wo.qu_543 tg.tk.mk_432  uz.ru.be_544 fi.cs.sk_444 
  0x1000150d, 0x1d583404, 0x0e6b3fee, 0x58004904,   // un.be.un_540 xh.om.la_332  af.ceb.is_422 to.om.un_320 
  0x0a3c3008, 0x4400300b, 0x65631555, 0x04546a04,   // uz.ug.mk_443 uz.kk.un_520  un.sco.gv_442 haw.ik.fi_332 
  0x365257a4, 0x39006a07, 0x506a49af, 0x10040faf,   // na.ha.gn_433 haw.br.un_420  to.haw.fj_655 lv.fi.lt_655 
  // [158c0]
  0x25505212, 0x0c3f06ee, 0x49000708, 0x0e731004,   // ha.fj.eu_654 de.af.sv_422  it.to.un_430 lt.ny.is_332 
  0x0a5f1d04, 0x0a2579ee, 0x365c0455, 0x28fc73a7,   // la.tn.pt_332 war.eu.pt_422  fi.sa.gn_442 ny.zzp.sw_532 
  0x68504ba4, 0x21001508, 0x040f1013, 0x5c730f0c,   // mi.fj.ig_433 un.jw.un_430  lt.lv.fi_665 lv.ny.sa_543 
  0x0a00fc0c, 0x2d2947a0, 0x1d004b04, 0x250730ee,   // zzp.pt.un_530 sn.sl.sk_322  mi.la.un_320 uz.bg.mn_422 
  // [158d0]
  0x06570c11, 0x42fe21a4, 0x13044755, 0x04130207,   // sv.na.de_653 jw.tlh.co_433  sn.fi.et_442 da.et.fi_432 
  0x244218a6, 0x40060c08, 0x0f3b1304, 0x17003b02,   // ga.co.eo_521 sv.de.lb_443  et.so.lv_332 so.sr.un_220 
  0x10170a13, 0x40583b5a, 0x381b1e55, 0x100a33a0,   // mk.sr.be_665 so.om.lb_553  ms.tr.tk_442 nn.pt.lt_322 
  0x301017ad, 0x100f2f0c, 0x0313045a, 0x583b130c,   // sr.be.uz_643 su.lv.lt_543  fi.et.nl_553 et.so.om_543 
  // [158e0]
  0x13044ca6, 0x26000804, 0x53007619, 0x101a0404,   // wo.fi.et_521 no.ia.un_320  crs.ht.un_750 fi.tl.lt_332 
  0x44233705, 0x0c123907, 0x33215b0c, 0x46005b13,   // ba.ky.kk_333 br.hu.sv_432  sg.jw.nn_543 sg.qu.un_650 
  0x2112280e, 0x2400260c, 0x0c1306ad, 0x480407a0,   // sd.ur.fa_555 ia.eo.un_530  de.et.sv_643 bg.ru.tt_322 
  0x08041112, 0x39353414, 0x651f39a0, 0x2300080d,   // ro.ru.uk_654 xh.zu.br_666  br.cy.gv_322 uk.ky.un_540 
  // [158f0]
  0x17003e07, 0x4d1f60a9, 0x214c010c, 0x13033f08,   // rm.sr.un_420 vo.cy.aa_544  en.wo.jw_543 af.nl.et_443 
  0x4d6b01a4, 0x4d1801a9, 0x39000f02, 0x29121e07,   // en.ceb.aa_433 en.ga.aa_544  lv.br.un_220 ms.hu.sl_432 
  0x4d690107, 0x4d004c2a, 0x651a4ca9, 0x48003613,   // en.mfe.aa_432 wo.aa.un_970  wo.tl.gv_544 ab.tt.un_650 
  0x3534300e, 0x073c25ad, 0x3c231255, 0x483744a9,   // uz.xh.zu_555 mn.ug.bg_643  ur.ky.ug_442 kk.ba.tt_544 
  // [15900]
  0x1d004d0c, 0x531910ee, 0x0f1710a0, 0x73281c0c,   // aa.la.un_530 lt.gl.ht_422  lt.sr.lv_322 id.sw.ny_543 
  0x2112340d, 0x48060caf, 0x522102a0, 0x681a6b55,   // ps.ur.fa_554 sv.de.tt_655  da.jw.ha_322 ceb.tl.ig_442 
  0x1e0446a9, 0x08024f0c, 0x25040aa0, 0x24006212,   // qu.fi.ms_544 bi.da.no_543  mk.ru.mn_322 kha.eo.un_640 
  0x15002505, 0x64005908, 0x53645b0c, 0x10250707,   // mn.un.un_330 rn.lg.un_430  sg.lg.ht_543 bg.mn.be_432 
  // [15910]
  0x645553a0, 0x47005304, 0x48060c04, 0x203f1ca4,   // ht.rw.lg_322 ht.sn.un_320  sv.de.tt_332 id.af.sq_433 
  0x151511ee, 0x0f1a1307, 0x041044a0, 0x23000809,   // ro.un.un_420 et.tl.lv_432  kk.be.ru_322 uk.ky.un_440 
  0x3500120d, 0x07004902, 0x5d355ea4, 0x3f125da9,   // hu.zu.un_540 to.it.un_220  ts.zu.ss_433 ss.hu.af_544 
  0x68581dee, 0x40332e05, 0x495860ad, 0x1ffc18ee,   // la.om.ig_422 fo.nn.lb_333  vo.om.to_643 ga.zzp.cy_422 
  // [15920]
  0x303f030c, 0x101d24a0, 0x3e1d1004, 0x10190bee,   // nl.af.uz_543 eo.la.lt_322  lt.la.rm_332 es.gl.lt_422 
  0x5e6455a4, 0x2e276504, 0x30253607, 0x0a30170c,   // rw.lg.ts_433 gv.gd.fo_332  ab.mn.uz_432 sr.uz.mk_543 
  0x35341ba7, 0x1a001107, 0x58425107, 0x1a1d1004,   // tr.xh.zu_532 ro.tl.un_420  kl.co.om_432 lt.la.tl_332 
  0x103530ec, 0x212f12ad, 0x5300510d, 0x55005e04,   // uz.tg.be_644 hu.su.jw_643  kl.ht.un_540 ts.rw.un_320 
  // [15930]
  0x2d243008, 0x302d76a7, 0x5d3555a6, 0x795c1ba7,   // uz.eo.sk_443 crs.sk.uz_532  rw.zu.ss_521 tr.sa.war_532 
  0x01000302, 0x5c51fcee, 0x33380855, 0x21382f09,   // nl.en.un_220 zzp.kl.sa_422  no.tk.nn_442 su.tk.jw_444 
  0x18766907, 0x106001a0, 0x25000802, 0x2d21670b,   // mfe.crs.ga_432 en.vo.lt_322  no.eu.un_220 ak.jw.sk_542 
  0x0b1b19a0, 0x761233a0, 0x063f0312, 0x3c1228a4,   // gl.tr.es_322 nn.hu.crs_322  nl.af.de_654 sd.ur.ug_433 
  // [15940]
  0x397609a4, 0x354734a0, 0x222d230c, 0x1f1648a0,   // pl.crs.br_433 xh.sn.zu_322  ca.sk.oc_543 tt.hr.cy_322 
  0x0a00300c, 0x1a7921a9, 0x35000a23, 0x24001d04,   // uz.mk.un_530 jw.war.tl_544  mk.tg.un_880 la.eo.un_320 
  0x20001e2a, 0x04251007, 0x19000c02, 0x061210ee,   // am.ti.un_970 be.mn.ru_432  sv.gl.un_220 lt.hu.de_422 
  0x190b260d, 0x40130ca0, 0x08301002, 0x43001512,   // ia.es.gl_554 sv.et.lb_322  be.uz.uk_222 un.ie.un_640 
  // [15950]
  0xfe170aa7, 0x4b005a2c, 0x0a1047a0, 0x49000408,   // pt.sr.tlh_532 sm.mi.un_990  sn.lt.pt_322 fi.to.un_430 
  0x3f4d580c, 0x693076af, 0x58494da4, 0x2a581507,   // om.aa.af_543 crs.uz.mfe_655  aa.to.om_433 un.om.mt_432 
  0x4f1808a0, 0x643b5807, 0x18213da7, 0x024c585a,   // no.ga.bi_322 om.so.lg_432  ku.fa.ar_532 om.wo.da_553 
  0x475636ec, 0x321729ee, 0x643b5811, 0x473473a9,   // gn.mg.sn_644 sl.sr.bs_422  om.so.lg_653 ny.xh.sn_544 
  // [15960]
  0x132473a9, 0x134d58a9, 0x58005a1a, 0x1a6449ad,   // ny.eo.et_544 om.aa.et_544  sm.om.un_760 to.lg.tl_643 
  0x4247450c, 0x075d01a4, 0x17003208, 0x4810110b,   // ln.sn.co_543 en.ss.it_433  bs.sr.un_430 ro.be.tt_542 
  0x47350308, 0x304c2502, 0x3e56030c, 0x73033fa4,   // nl.zu.sn_443 eu.wo.uz_222  nl.mg.rm_543 af.nl.ny_433 
  0x34475bec, 0x56006413, 0x033f40a0, 0x4573050c,   // sg.sn.xh_644 lg.mg.un_650  lb.af.nl_322 fr.ny.ln_543 
  // [15970]
  0x0f1e1207, 0xfc004d11, 0x2300361a, 0x32160905,   // hu.ms.lv_432 aa.zzp.un_630  ab.ky.un_760 pl.hr.bs_333 
  0x121d2607, 0x1500101a, 0x2e004312, 0x234404a4,   // ia.la.hu_432 be.un.un_760  ie.fo.un_640 ru.kk.ky_433 
  0x330801a4, 0x4c004012, 0x025c420e, 0x42072704,   // en.no.nn_433 lb.wo.un_640  co.sa.da_555 gd.it.co_332 
  0x4d074205, 0x0c003305, 0x656b6308, 0x04081109,   // co.it.aa_333 nn.sv.un_330  sco.ceb.gv_443 ro.uk.ru_444 
  // [15980]
  0x26074213, 0x1d4263a4, 0x0242075a, 0x1e6e57ee,   // co.it.ia_665 sco.co.la_433  it.co.da_553 na.hmn.ms_422 
  0x025c1207, 0x072a42a7, 0x79461d05, 0x384860a4,   // hu.sa.da_432 co.mt.it_532  la.qu.war_333 vo.tt.tk_433 
  0x21183b08, 0x35fa5c12, 0x12245c0c, 0x02006319,   // ks.ar.fa_443 sa.nr.zu_654  sa.eo.hu_543 sco.da.un_750 
  0x53125ca7, 0x0e2e150c, 0x79095c07, 0x21135ca0,   // sa.hu.ht_532 un.fo.is_543  sa.pl.war_432 sa.et.jw_322 
  // [15990]
  0x60005c14, 0x2d1c5cee, 0x346035ec, 0x2a000c05,   // sa.vo.un_660 sa.id.sk_422  zu.vo.xh_644 sv.mt.un_330 
  0x09292504, 0x13475c07, 0x0e00180e, 0x08025ca7,   // eu.sl.pl_332 sa.sn.et_432  ga.is.un_550 sa.da.no_532 
  0x28116aad, 0x303b2805, 0x2e205c0b, 0x6a4b5707,   // haw.ro.sw_643 sd.ks.uz_333  sa.sq.fo_542 na.mi.haw_432 
  0x48152304, 0x0a5c0fa4, 0x1d190a13, 0x23105c07,   // ky.tt.un_320 lv.sa.pt_433  pt.gl.la_665 sa.lt.ca_432 
  // [159a0]
  0x625049a4, 0x4b182804, 0x22256008, 0x234448af,   // to.fj.kha_433 sw.ga.mi_332  vo.eu.oc_443 tt.kk.ky_655 
  0x1f004a12, 0x4b007908, 0x5000250c, 0x4b495a02,   // yo.cy.un_640 war.mi.un_430  eu.fj.un_530 sm.to.mi_222 
  0x475a4908, 0x6a4b020e, 0x47494b55, 0x072510ad,   // to.sm.sn_443 da.mi.haw_555  mi.to.sn_442 be.mn.bg_643 
  0x12024aa6, 0x3400250c, 0x0e2e2d04, 0x1b314805,   // yo.da.hu_521 eu.xh.un_530  sk.fo.is_332 tt.az.tr_333 
  // [159b0]
  0x33081009, 0x34512f02, 0x3e3963a0, 0x34001e02,   // lt.no.nn_444 su.kl.xh_222  sco.br.rm_322 ms.xh.un_220 
  0x1d343707, 0x12004413, 0x04111704, 0x2a006305,   // st.xh.la_432 kk.ur.un_650  sr.ro.ru_332 sco.mt.un_330 
  0x0f1910ee, 0x23431107, 0x2e330e11, 0x26230a13,   // lt.gl.lv_422 ro.ie.ca_432  is.nn.fo_653 pt.ca.ia_665 
  0x25151104, 0x360a11a9, 0x5300762b, 0x30443cee,   // ro.mn.un_320 ro.mk.ab_544  crs.ht.un_980 ug.kk.uz_422 
  // [159c0]
  0x0e001307, 0x13005a1a, 0x3f00100e, 0x102e0ea0,   // et.is.un_420 sm.et.un_760  lt.af.un_550 is.fo.lt_322 
  0x1836120c, 0x170a10ad, 0x481515a7, 0x353446a0,   // hu.gn.ga_543 be.mk.sr_643  un.tt.un_520 qu.xh.zu_322 
  0x442336a4, 0x3d303407, 0x223f2ca0, 0x39493807,   // ab.ky.kk_433 ps.uz.ku_432  fy.af.oc_322 tk.to.br_432 
  0x2c006012, 0x5d4833a0, 0x1d0cfc04, 0x1d007909,   // vo.fy.un_640 nn.tt.ss_322  zzp.sv.la_332 war.la.un_440 
  // [159d0]
  0x25791ba9, 0x35fa5daf, 0x17290955, 0x10020904,   // tr.war.eu_544 ss.nr.zu_655  pl.sl.sr_442 pl.da.lt_332 
  0x1b2101a4, 0x03fc5807, 0x2134300d, 0x0f245cee,   // en.jw.tr_433 om.zzp.nl_432  uz.ps.fa_554 sa.eo.lv_422 
  0x08002311, 0x734532a4, 0x3f0e0205, 0x54004e1a,   // ky.uk.un_630 bs.ln.ny_433  da.is.af_333 ay.ik.un_760 
  0x671b310d, 0x04191c07, 0x341d04a4, 0x240705ee,   // az.tr.ak_554 id.gl.fi_432  fi.la.xh_433 fr.it.eo_422 
  // [159e0]
  0x31003504, 0x475804af, 0x5769560c, 0x0a300705,   // zu.az.un_320 fi.om.sn_655  mg.mfe.na_543 bg.uz.mk_333 
  0x2f73060c, 0x765623a9, 0x08021daf, 0x0a330802,   // de.ny.su_543 ca.mg.crs_544  la.da.no_655 no.nn.pt_222 
  0x30000105, 0x0a00232b, 0x48373009, 0x5f5833a4,   // en.uz.un_330 ky.mk.un_980  uz.ba.tt_444 nn.om.tn_433 
  0x253e19a4, 0x330f0ea4, 0x40570655, 0x0735370b,   // gl.rm.eu_433 is.lv.nn_433  de.na.lb_442 ba.tg.bg_542 
  // [159f0]
  0x4006790c, 0x153048a4, 0x212830ee, 0x31541b08,   // war.de.lb_543 tt.uz.un_433  uz.sd.fa_422 tr.ik.az_443 
  0x48000712, 0x5c005422, 0x5c300605, 0x523830ad,   // bg.tt.un_640 ik.sa.un_870  de.uz.sa_333 uz.tk.ha_643 
  0x1c000b04, 0x1b380ba0, 0x17001d02, 0x311b0eee,   // es.id.un_320 es.tk.tr_322  la.sr.un_220 is.tr.az_422 
  0x00004a37, 0x1a306ba4, 0x34003034, 0x351d73ee,   // yo.un.un_B00 ceb.uz.tl_433  uz.ps.un_A80 ny.la.zu_422 
  // [15a00]
  0x35001d04, 0x1d00730c, 0x4c004d08, 0x17150a07,   // la.zu.un_320 ny.la.un_530  aa.wo.un_430 mk.sr.un_420 
  0x0e0c2aad, 0x2d2a0904, 0x5100300d, 0x5a090407,   // mt.sv.is_643 pl.mt.sk_332  uz.kl.un_540 fi.pl.sm_432 
  0x38151505, 0x491028a4, 0x10003605, 0x1f561104,   // un.tk.un_330 sw.lt.to_433  gn.lt.un_330 ro.mg.cy_332 
  0x24074207, 0x0d394007, 0x1d0502ee, 0x0b3604a0,   // co.it.eo_432 lb.br.cs_432  da.fr.la_422 fi.gn.es_322 
  // [15a10]
  0x42552ca0, 0x020450ec, 0x2c690504, 0x560631a9,   // fy.rw.co_322 fj.fi.da_644  fr.mfe.fy_332 az.de.mg_544 
  0x13202507, 0x33045aa4, 0x38001e1a, 0x5a5f3704,   // eu.sq.et_432 sm.fi.nn_433  ms.tk.un_760 st.tn.sm_332 
  0x1b5d350c, 0x0d004013, 0x317335a9, 0x6431520c,   // zu.ss.tr_543 lb.cs.un_650  zu.ny.az_544 ha.az.lg_543 
  0x2a002411, 0x05537608, 0x461931ad, 0x05000907,   // eo.mt.un_630 crs.ht.fr_443  az.gl.qu_643 pl.fr.un_420 
  // [15a20]
  0x7328470d, 0x31003018, 0x24001b16, 0x48004005,   // sn.sw.ny_554 uz.az.un_740  tr.eo.un_720 lb.tt.un_330 
  0x541a79a4, 0x4c1828a4, 0x52214a07, 0x2f005102,   // war.tl.ik_433 sw.ga.wo_433  yo.jw.ha_432 kl.su.un_220 
  0x363738ec, 0x1b004b07, 0x23081007, 0x0e2a04a0,   // tk.ba.ab_644 mi.tr.un_420  be.uk.ky_432 fi.mt.is_322 
  0x0e1e1c02, 0x066b1a0c, 0x2d0d0c02, 0x2a23200c,   // id.ms.is_222 tl.ceb.de_543  sv.cs.sk_222 sq.ca.mt_543 
  // [15a30]
  0x44182312, 0x262410a4, 0x1500690e, 0x122e20ee,   // ky.ar.kk_654 lt.eo.ia_433  mfe.un.un_550 sq.fo.hu_422 
  0x0d321605, 0x442325ad, 0x05001f08, 0x1a4b15ee,   // hr.bs.cs_333 mn.ky.kk_643  cy.fr.un_430 un.mi.tl_422 
  0x5d00430c, 0x10001a02, 0x23250aa9, 0x191a2107,   // ie.ss.un_530 tl.lt.un_220  mk.mn.ky_544 jw.tl.gl_432 
  0x17300702, 0x21004a05, 0x5a6a450c, 0x6a56230e,   // bg.uz.sr_222 yo.jw.un_330  ln.haw.sm_543 ca.mg.haw_555 
  // [15a40]
  0x6a5456ec, 0x35000a0c, 0x73284704, 0x283d2302,   // mg.ik.haw_644 mk.tg.un_530  sn.sw.ny_332 ky.ku.sd_222 
  0x5a2347a9, 0x46000907, 0x56600107, 0x235e30ee,   // sn.ca.sm_544 pl.qu.un_420  en.vo.mg_432 uz.ts.ca_422 
  0x075e56a4, 0x09340c0c, 0x4a004d0c, 0x34123b07,   // mg.ts.it_433 sv.xh.pl_543  aa.yo.un_530 ks.ur.ps_432 
  0x3d213009, 0x4a29450c, 0x0246090c, 0x5a005004,   // uz.fa.ku_444 ln.sl.yo_543  pl.qu.da_543 fj.sm.un_320 
  // [15a50]
  0x1f030ea6, 0x633f090c, 0x483738a9, 0x1500090c,   // is.nl.cy_521 pl.af.sco_543  tk.ba.tt_544 pl.un.un_530 
  0x53000309, 0x37043505, 0x2e000c13, 0x2e0820a0,   // nl.ht.un_440 tg.ru.ba_333  sv.fo.un_650 sq.no.fo_322 
  0x213d30af, 0x0c120e5e, 0x202c0355, 0x3e00130d,   // uz.ku.fa_655 is.hu.sv_652  nl.fy.sq_442 et.rm.un_540 
  0x442336a9, 0x17073704, 0x36004619, 0x102344a4,   // ab.ky.kk_544 ba.bg.sr_332  qu.gn.un_750 kk.ky.be_433 
  // [15a60]
  0x233c3009, 0x123d3460, 0x2f007905, 0x5000fc0b,   // uz.ug.ky_444 ps.ku.ur_664  war.su.un_330 zzp.fj.un_520 
  0x0b1dfca0, 0x04003519, 0xfc220a07, 0x5f0a0daf,   // zzp.la.es_322 tg.ru.un_750  pt.oc.zzp_432 cs.pt.tn_655 
  0x5d00350d, 0x5e7337a4, 0x5c2158ee, 0xfe28735a,   // zu.ss.un_540 st.ny.ts_433  om.jw.sa_422 ny.sw.tlh_553 
  0x7900021a, 0x51003e02, 0x244207a4, 0x04006a08,   // da.war.un_760 rm.kl.un_220  it.co.eo_433 haw.fi.un_430 
  // [15a70]
  0x370c340c, 0x3530230c, 0x020428ee, 0x583428ee,   // xh.sv.st_543 ky.uz.tg_543  sw.fi.da_422 sw.xh.om_422 
  0x30483caf, 0x02000e0b, 0x13040c02, 0x3f650207,   // ug.tt.uz_655 is.da.un_520  sv.fi.et_222 da.gv.af_432 
  0x06040eee, 0xfc001214, 0x49002411, 0x1652090c,   // is.fi.de_422 hu.zzp.un_660  eo.to.un_630 pl.ha.hr_543 
  0xfe005813, 0x3b322fa0, 0x1300401a, 0x5052280d,   // om.tlh.un_650 su.bs.so_322  lb.et.un_760 sw.ha.fj_554 
  // [15a80]
  0x19630aec, 0x3b1d500c, 0x4c4a500c, 0x6b5f1da4,   // pt.sco.gl_644 fj.la.so_543  fj.yo.wo_543 la.tn.ceb_433 
  0x08043707, 0x2b002e04, 0x3c23440b, 0x122d2007,   // ba.ru.uk_432 fo.vi.un_320  kk.ky.ug_542 sq.sk.hu_432 
  0x5c2d0d07, 0x333f0cee, 0x4b003b08, 0x4840060c,   // cs.sk.sa_432 sv.af.nn_422  so.mi.un_430 de.lb.tt_543 
  0x373c480e, 0x361548a9, 0x23374412, 0x651dfc0b,   // tt.ug.ba_555 tt.ab.un_540  kk.ba.ky_654 zzp.la.gv_542 
  // [15a90]
  0x0c1a4f55, 0x4830230e, 0x2f1b4fa7, 0xfc2e0955,   // bi.tl.sv_442 ky.uz.tt_555  bi.tr.su_532 pl.fo.zzp_442 
  0x08232512, 0xfc095c0c, 0x282134a4, 0x10081713,   // mn.ky.uk_654 sa.pl.zzp_543  ps.fa.sd_433 sr.uk.be_665 
  0x1f2e38a0, 0x0a3515ee, 0x0a371104, 0x29000907,   // tk.fo.cy_322 un.tg.mk_422  ro.ba.mk_332 pl.sl.un_420 
  0x4c2718ee, 0x0e3b045a, 0x07372307, 0x21443d0c,   // ga.gd.wo_422 fi.so.is_553  ky.ba.bg_432 ku.kk.fa_543 
  // [15aa0]
  0x10081712, 0x213c2304, 0x2a093b07, 0x07301555,   // sr.uk.be_654 ky.ug.fa_332  so.pl.mt_432 un.uz.bg_442 
  0x3b041002, 0x040f1207, 0x042d0d02, 0x04025813,   // lt.fi.so_222 hu.lv.fi_432  cs.sk.fi_222 om.da.fi_665 
  0x2e620e08, 0x58000f0d, 0x134b36ee, 0x2e002007,   // is.kha.fo_443 lv.om.un_540  gn.mi.et_422 sq.fo.un_420 
  0x17003611, 0x160f29a9, 0x3c483711, 0x09004d19,   // ab.sr.un_630 sl.lv.hr_544  ba.tt.ug_653 aa.pl.un_750 
  // [15ab0]
  0x1634180c, 0x4006090c, 0x4800121e, 0x2344100c,   // ar.ps.th_543 pl.de.lb_543  hu.tt.un_830 be.kk.ky_543 
  0x2f5009ee, 0x40000912, 0x0e1204a0, 0x01630907,   // pl.fj.su_422 pl.lb.un_640  fi.hu.is_322 pl.sco.en_432 
  0x353007ee, 0x4b000908, 0x15002318, 0x0a3748a0,   // bg.uz.tg_422 pl.mi.un_430  ky.un.un_740 tt.ba.mk_322 
  0x364205a9, 0x1f3809a0, 0x314d1b04, 0xfc0163a4,   // fr.co.gn_544 pl.tk.cy_322  tr.aa.az_332 sco.en.zzp_433 
  // [15ac0]
  0x32090fa7, 0xfc2e0cee, 0x45595204, 0x07350aee,   // lv.pl.bs_532 sv.fo.zzp_422  ha.rn.ln_332 mk.tg.bg_422 
  0x120522a0, 0x76001c08, 0x35796707, 0x56003408,   // oc.fr.hu_322 id.crs.un_430  ak.war.zu_432 xh.mg.un_430 
  0x59532808, 0x5e583b0c, 0x1d764208, 0x225856a4,   // sw.ht.rn_443 so.om.ts_543  co.crs.la_443 mg.om.oc_433 
  0x123b3405, 0x5d374ca4, 0x476455a0, 0x281850ad,   // ps.ks.ur_333 wo.st.ss_433  rw.lg.sn_322 fj.ga.sw_643 
  // [15ad0]
  0x56520d07, 0x22fc3f04, 0x6434110c, 0x0f0462a9,   // cs.ha.mg_432 af.zzp.oc_332  ro.xh.lg_543 kha.fi.lv_544 
  0xfe00590d, 0x28647907, 0x1f001208, 0x1c2f61a6,   // rn.tlh.un_540 war.lg.sw_432  hu.cy.un_430 za.su.id_521 
  0x46003508, 0x46025104, 0x1d420209, 0x170b5608,   // zu.qu.un_430 kl.da.qu_332  da.co.la_444 mg.es.sr_443 
  0x2d004204, 0x28fa5907, 0x02434d04, 0x5e003b0e,   // co.sk.un_320 rn.nr.sw_432  aa.ie.da_332 so.ts.un_550 
  // [15ae0]
  0x0a2511a0, 0x3b2d5ca0, 0x28443404, 0xfa28040c,   // ro.mn.mk_322 sa.sk.so_322  ps.kk.sd_332 fi.sw.nr_543 
  0x5c28fe5a, 0x212ffe0c, 0xfe173b05, 0x02080ea4,   // tlh.sw.sa_553 tlh.su.jw_543  so.sr.tlh_333 is.no.da_433 
  0x465d45a0, 0x1d000216, 0x12005c13, 0x2d0d5ca4,   // ln.ss.qu_322 da.la.un_720  sa.hu.un_650 sa.cs.sk_433 
  0x48381b11, 0x5c00fe0d, 0x02000811, 0x47003721,   // tr.tk.tt_653 tlh.sa.un_540  no.da.un_630 st.sn.un_860 
  // [15af0]
  0x154906ec, 0x425664a9, 0x224973a7, 0x0a2e56ad,   // de.to.un_644 lg.mg.co_544  ny.to.oc_532 mg.fo.pt_643 
  0x0e5a060c, 0x30132f08, 0x022e0e07, 0x4b6a500d,   // de.sm.is_543 su.et.uz_443  is.fo.da_432 fj.haw.mi_554 
  0x552e1ea0, 0x3748300e, 0x1a00460d, 0x101f5a0e,   // ms.fo.rw_322 uz.tt.ba_555  qu.tl.un_540 sm.cy.lt_555 
  0x231d6355, 0x1a041308, 0x0ffe10af, 0x0e5022ec,   // sco.la.ca_442 et.fi.tl_443  lt.tlh.lv_655 oc.fj.is_644 
  // [15b00]
  0x6a005a2b, 0x482536ad, 0x57581e07, 0x06295ca0,   // sm.haw.un_980 ab.mn.tt_643  ms.om.na_432 sa.sl.de_322 
  0x7300090e, 0x5e64670c, 0x06406307, 0x576a4e0d,   // pl.ny.un_550 ak.lg.ts_543  sco.lb.de_432 ay.haw.na_554 
  0x644656ec, 0x5a491ca0, 0x34004e23, 0x6b595508,   // mg.qu.lg_644 id.to.sm_322  ay.xh.un_880 rw.rn.ceb_443 
  0x33002e22, 0x5e5245a4, 0x4c477312, 0x2e001b07,   // fo.nn.un_870 ln.ha.ts_433  ny.sn.wo_654 tr.fo.un_420 
  // [15b10]
  0x3600fc07, 0x3600640c, 0x09000702, 0x21001823,   // zzp.gn.un_420 lg.gn.un_530  it.pl.un_220 ar.fa.un_880 
  0x110417af, 0x080435a4, 0x24285e04, 0x37001514,   // sr.ru.ro_655 tg.ru.uk_433  ts.sw.eo_332 un.ba.un_660 
  0x3519fc0c, 0x03502ca7, 0x1710380c, 0x331d08a0,   // zzp.gl.zu_543 fy.fj.nl_532  tk.be.sr_543 no.la.nn_322 
  0x332e08a0, 0x0e022e13, 0x28004405, 0x25000707,   // no.fo.nn_322 fo.da.is_665  kk.sd.un_330 bg.mn.un_420 
  // [15b20]
  0x10351107, 0x33000209, 0x4000210e, 0x3f000907,   // ro.tg.be_432 da.nn.un_440  jw.lb.un_550 pl.af.un_420 
  0x303511af, 0x30483c14, 0x52734704, 0x020e2ea7,   // ro.tg.uz_655 ug.tt.uz_666  sn.ny.ha_332 fo.is.da_532 
  0x0f005804, 0x17080709, 0x25244207, 0x3c001e20,   // om.lv.un_320 bg.uk.sr_444  co.eo.eu_432 am.ug.un_850 
  0x0c001a02, 0x08111507, 0x5d004d0c, 0x4a004d13,   // tl.sv.un_220 un.ro.uk_432  aa.ss.un_530 aa.yo.un_650 
  // [15b30]
  0x44382313, 0x2d480dac, 0x1300fc04, 0x21301209,   // ky.tk.kk_665 cs.tt.sk_632  zzp.et.un_320 ur.uz.fa_444 
  0x47354555, 0x3200fe07, 0x353445ee, 0x1b321608,   // ln.zu.sn_442 tlh.bs.un_420  ln.xh.zu_422 hr.bs.tr_443 
  0x342321af, 0x09002407, 0x512e02ac, 0x0a0d180c,   // fa.ky.ps_655 eo.pl.un_420  da.fo.kl_632 ga.cs.pt_543 
  0x3738440c, 0x08023304, 0x5000020c, 0x08000213,   // kk.tk.ba_543 nn.da.no_332  da.fj.un_530 da.no.un_650 
  // [15b40]
  0x330a6504, 0x1f620a0d, 0x491d50a0, 0x070a1107,   // gv.pt.nn_332 pt.kha.cy_554  fj.la.to_322 ro.mk.bg_432 
  0x30382307, 0x5cfe2a08, 0x462030a4, 0x3b002f0d,   // ky.tk.uz_432 mt.tlh.sa_443  uz.sq.qu_433 su.so.un_540 
  0xfe3e0dec, 0x19360da0, 0x563f030d, 0x23053712,   // cs.rm.tlh_644 cs.gn.gl_322  nl.af.mg_554 st.fr.ca_654 
  0x6300230e, 0x07301705, 0x05222304, 0x286962a4,   // ca.sco.un_550 sr.uz.bg_333  ca.oc.fr_332 kha.mfe.sw_433 
  // [15b50]
  0x636001a0, 0x3e3f63a7, 0x35150aa4, 0x180360a7,   // en.vo.sco_322 sco.af.rm_532  mk.tg.un_430 vo.nl.ga_532 
  0x221f1907, 0x3b240ba4, 0x4f5f750c, 0x07244da4,   // gl.cy.oc_432 es.eo.so_433  nso.tn.bi_543 aa.eo.it_433 
  0x08173ca9, 0x76005335, 0x0e3f0304, 0x64257511,   // ug.sr.uk_544 ht.crs.un_A90  nl.af.is_332 nso.eu.lg_653 
  0x22606308, 0x04151104, 0x79766307, 0x75001a22,   // sco.vo.oc_443 ro.ru.un_320  sco.crs.war_432 tl.nso.un_870 
  // [15b60]
  0x3e330804, 0x353f63a9, 0x500b3ba4, 0x564d2512,   // no.nn.rm_332 sco.af.zu_544  so.es.fj_433 eu.aa.mg_654 
  0x1a631508, 0x0700350e, 0x241975ad, 0x75005f2a,   // un.sco.tl_443 tg.bg.un_550  nso.gl.eo_643 tn.nso.un_970 
  0x27004702, 0x4a00501a, 0x234436a7, 0x24654ca9,   // sn.gd.un_220 fj.yo.un_760  ab.kk.ky_532 wo.gv.eo_544 
  0x5a000b09, 0x222d0d0c, 0x05002223, 0x3b5a24af,   // es.sm.un_440 cs.sk.oc_543  oc.fr.un_880 eo.sm.so_655 
  // [15b70]
  0x24004013, 0x69007619, 0x55002f04, 0xfe000408,   // lb.eo.un_650 crs.mfe.un_750  su.rw.un_320 fi.tlh.un_430 
  0x211d3602, 0x243340ee, 0x5d3568ad, 0x1f080204,   // gn.la.jw_222 lb.nn.eo_422  ig.zu.ss_643 da.no.cy_332 
  0x401d4b07, 0x1a002108, 0x025a1da0, 0x42fc3b04,   // mi.la.lb_432 jw.tl.un_430  la.sm.da_322 so.zzp.co_332 
  0x182112a4, 0x021d01a0, 0x381a4010, 0x19220504,   // ur.fa.ar_433 en.la.da_322  lb.tl.tk_642 fr.oc.gl_332 
  // [15b80]
  0x072536a0, 0x1a4e2c07, 0x15100808, 0x02001d0e,   // ab.mn.bg_322 fy.ay.tl_432  uk.be.un_443 la.da.un_550 
  0x423b0204, 0xfe000411, 0x5900280d, 0x30001902,   // da.so.co_332 fi.tlh.un_630  sw.rn.un_540 gl.uz.un_220 
  0x59355512, 0x1d0208a4, 0x356434a0, 0x101632ee,   // rw.zu.rn_654 no.da.la_433  xh.lg.zu_322 bs.hr.lt_422 
  0x631ffe55, 0x062b5804, 0x2b006b12, 0x0c081dee,   // tlh.cy.sco_442 om.vi.de_332  ceb.vi.un_640 la.no.sv_422 
  // [15b90]
  0x4200fe21, 0x321c2aee, 0x6528fe14, 0x2b5e0a5a,   // tlh.co.un_860 mt.id.bs_422  tlh.sw.gv_666 pt.ts.vi_553 
  0x1b001a07, 0x2b0a5e07, 0x1b4630ee, 0x04443007,   // tl.tr.un_420 ts.pt.vi_432  uz.qu.tr_422 uz.kk.ru_432 
  0x1a684255, 0x2a2b1a07, 0x42006512, 0x0a796b13,   // co.ig.tl_442 tl.vi.mt_432  gv.co.un_640 ceb.war.pt_665 
  0x06000e21, 0x6b61795a, 0x304835ee, 0x355e61a4,   // is.de.un_860 war.za.ceb_553  zu.tt.uz_422 za.ts.zu_433 
  // [15ba0]
  0x30fe4607, 0x2b155e04, 0x68fe42a7, 0x5cfe4208,   // qu.tlh.uz_432 ts.vi.un_320  co.tlh.ig_532 co.tlh.sa_443 
  0x0a475e04, 0x392267a4, 0x1f6b420c, 0x2e201fec,   // ts.sn.pt_332 ak.oc.br_433  co.ceb.cy_543 cy.sq.fo_644 
  0x79220a0e, 0x425e03a0, 0x2b0a220c, 0x65682755,   // pt.oc.war_555 nl.ts.co_322  oc.pt.vi_543 gd.ig.gv_442 
  0x0a5e5d13, 0x091f63ee, 0x3046fea9, 0x48300412,   // ss.ts.pt_665 sco.cy.pl_422  tlh.qu.uz_544 ru.uz.tt_654 
  // [15bb0]
  0x2e0e2daf, 0x482315a7, 0x2a0e4cad, 0x3c3644a9,   // sk.is.fo_655 un.ky.tt_532  wo.is.mt_643 kk.ab.ug_544 
  0x050176a0, 0x10233807, 0x09004805, 0x1748110c,   // crs.en.fr_322 tk.ky.be_432  tt.pl.un_330 ro.tt.sr_543 
  0x383c300c, 0x12004811, 0x07042504, 0x04072355,   // uz.ug.tk_543 tt.hu.un_630  mn.ru.bg_332 ky.bg.ru_442 
  0x602401a0, 0x2205390d, 0x21000204, 0x24004607,   // en.eo.vo_322 br.fr.oc_554  da.jw.un_320 qu.eo.un_420 
  // [15bc0]
  0x0a071ca4, 0x343011a7, 0x25170812, 0x101511a4,   // id.it.pt_433 ro.uz.xh_532  uk.sr.mn_654 ro.be.un_430 
  0x4800110e, 0x332e0e13, 0x42590507, 0x2e004d08,   // ro.tt.un_550 is.fo.nn_665  fr.rn.co_432 aa.fo.un_430 
  0x0a00430c, 0x0a004308, 0x2d424c04, 0x6b00110d,   // ie.pt.un_530 ie.pt.un_430  wo.co.sk_332 ro.ceb.un_540 
  0x0602faa4, 0x0d0a4da6, 0x11004c13, 0x1e1113ee,   // nr.da.de_433 aa.pt.cs_521  wo.ro.un_650 et.ro.ms_422 
  // [15bd0]
  0x2d0d4dec, 0x07370404, 0x52006412, 0x4c002e12,   // aa.cs.sk_644 ru.ba.bg_332  lg.ha.un_640 fo.wo.un_640 
  0x17250aa0, 0x436011a9, 0x04505a04, 0x3c3d44a0,   // mk.mn.sr_322 ro.vo.ie_544  sm.fj.fi_332 kk.ku.ug_322 
  0x0f00fe0c, 0xfe000413, 0x0f2410a0, 0x072a4da0,   // tlh.lv.un_530 fi.tlh.un_650  lt.eo.lv_322 aa.mt.it_322 
  0x171108ad, 0x653e11a0, 0x28002b07, 0x0e182ca0,   // uk.ro.sr_643 ro.rm.gv_322  vi.sw.un_420 fy.ga.is_322 
  // [15be0]
  0x58222b07, 0x0f1a1da4, 0x0e3326ee, 0x392249a7,   // vi.oc.om_432 la.tl.lv_433  ia.nn.is_422 to.oc.br_532 
  0x0700480b, 0x25004e1a, 0x21301211, 0x08250404,   // tt.bg.un_520 ay.eu.un_760  ur.uz.fa_653 ru.mn.uk_332 
  0x08003019, 0x0708045a, 0x11000707, 0x0c08330b,   // uz.uk.un_750 ru.uk.bg_553  it.ro.un_420 nn.no.sv_542 
  0x04173604, 0x171515a7, 0x34283d04, 0x5e003505,   // ab.sr.ru_332 un.sr.un_520  ku.sd.ps_332 zu.ts.un_330 
  // [15bf0]
  0x2b003104, 0x10081705, 0x23353c12, 0x04001311,   // az.vi.un_320 sr.uk.be_333  ug.tg.ky_654 et.fi.un_630 
  0x492535a4, 0x513807af, 0xfc070308, 0x683045a4,   // zu.eu.to_433 it.tk.kl_655  nl.it.zzp_443 ln.uz.ig_433 
  0x3e232202, 0x45732814, 0x060c01a0, 0x231508a4,   // oc.ca.rm_222 sw.ny.ln_666  en.sv.de_322 uk.ky.un_430 
  0x40060cad, 0x4338fc0c, 0x190b1ba0, 0xfc126905,   // sv.de.lb_643 zzp.tk.ie_543  tr.es.gl_322 mfe.hu.zzp_333 
  
  // [15c00]
  0x3f031da4, 0x40766907, 0x24003707, 0x3848fc04,   // la.nl.af_433 mfe.crs.lb_432  st.eo.un_420 zzp.tt.tk_332 
  0x064003ee, 0x695176ad, 0x73565f04, 0x465d49a7,   // nl.lb.de_422 crs.kl.mfe_643  tn.mg.ny_332 to.ss.qu_532 
  0x37440a02, 0x080206a0, 0x032223a0, 0x08304855,   // mk.kk.ba_222 de.da.no_322  ca.oc.nl_322 tt.uz.uk_442 
  0x01003204, 0x11000705, 0x03080e04, 0xfc1a79ee,   // bs.en.un_320 bg.ro.un_330  is.no.nl_332 war.tl.zzp_422 
  // [15c10]
  0x2c0333ee, 0x65000f04, 0x794006a9, 0x033f3e08,   // nn.nl.fy_422 lv.gv.un_320  de.lb.war_544 rm.af.nl_443 
  0x651d02ee, 0x403e06a4, 0x3f003302, 0x18123b04,   // da.la.gv_422 de.rm.lb_433  nn.af.un_220 ks.ur.ar_332 
  0x074202ee, 0x044838a4, 0x07024c05, 0x0a12360d,   // da.co.it_422 tk.tt.ru_433  wo.da.it_333 gn.hu.pt_554 
  0x5a001f0b, 0x4307420c, 0x1508150e, 0x65000713,   // cy.sm.un_520 co.it.ie_543  un.uk.un_555 it.gv.un_650 
  // [15c20]
  0x4202070d, 0x2f133ba7, 0x20003305, 0x182a67a7,   // it.da.co_554 so.et.su_532  nn.sq.un_330 ak.mt.ga_532 
  0x3b6b6808, 0x20003205, 0x0a005a02, 0x6b1d02a4,   // ig.ceb.so_443 bs.sq.un_330  sm.pt.un_220 da.la.ceb_433 
  0x20002e07, 0x4200020d, 0x2d360d07, 0x3e07420c,   // fo.sq.un_420 da.co.un_540  cs.gn.sk_432 co.it.rm_543 
  0x5800fe0e, 0x375f36a9, 0x233444ee, 0x2d1d2002,   // tlh.om.un_550 gn.tn.st_544  kk.ps.ky_422 sq.la.sk_222 
  // [15c30]
  0x524c6404, 0x0b006709, 0x13002f04, 0x4b042102,   // lg.wo.ha_332 ak.es.un_440  su.et.un_320 jw.fi.mi_222 
  0x12130404, 0x5c00120d, 0x0a344705, 0xfc5e1902,   // fi.et.hu_332 hu.sa.un_540  sn.xh.pt_333 gl.ts.zzp_222 
  0x350810ee, 0x114025a0, 0x1310fe07, 0x080347a0,   // be.uk.tg_422 eu.lb.ro_322  tlh.lt.et_432 sn.nl.no_322 
  0x4812020c, 0x0b233607, 0x0613360d, 0x09fe2409,   // da.hu.tt_543 gn.ca.es_432  gn.et.de_554 eo.tlh.pl_444 
  // [15c40]
  0x133f45a9, 0x425c2c0c, 0x02644611, 0x25041305,   // ln.af.et_544 fy.sa.co_543  qu.lg.da_653 et.fi.eu_333 
  0x13002307, 0x3f0306a4, 0x5e063502, 0x06232511,   // ca.et.un_420 de.nl.af_433  zu.de.ts_222 eu.ca.de_653 
  0x25000619, 0x46005512, 0x480a25a9, 0x550b73ec,   // de.eu.un_750 rw.qu.un_640  eu.pt.tt_544 ny.es.rw_644 
  0x2a190a02, 0x027808a4, 0x684c1d07, 0x101504ec,   // pt.gl.mt_222 no.ve.da_433  la.wo.ig_432 ru.be.un_640 
  // [15c50]
  0x063f6409, 0x36005c12, 0x02005418, 0x20003418,   // lg.af.de_444 sa.gn.un_640  ik.da.un_740 xh.sq.un_740 
  0x5c46020e, 0x5c004612, 0x2d291707, 0x0b004d08,   // da.qu.sa_555 qu.sa.un_640  sr.sl.sk_432 aa.es.un_430 
  0x0b2d0d14, 0x1c211e04, 0x11001e08, 0x6a4b5eaf,   // cs.sk.es_666 ms.jw.id_332  ms.ro.un_430 ts.mi.haw_655 
  0x4a461302, 0x13022007, 0x11003807, 0x2f001107,   // et.qu.yo_222 sq.da.et_432  tk.ro.un_420 ro.su.un_420 
  // [15c60]
  0x5e002113, 0x0b2d0d04, 0x103638a4, 0x10003818,   // jw.ts.un_650 cs.sk.es_332  tk.ab.be_433 tk.be.un_740 
  0x304811a6, 0x095559ee, 0x522959ee, 0x421d07a4,   // ro.tt.uz_521 rn.rw.pl_422  rn.sl.ha_422 it.la.co_433 
  0x135e0204, 0x5e00282b, 0x150415ee, 0x0f005204,   // da.ts.et_332 sw.ts.un_980  un.ru.un_422 ha.lv.un_320 
  0x190b05ee, 0x1d112608, 0x0b392005, 0x4a000f04,   // fr.es.gl_422 ia.ro.la_443  sq.br.es_333 lv.yo.un_320 
  // [15c70]
  0x0b53200c, 0x04001119, 0x2d005504, 0x16000504,   // sq.ht.es_543 ro.ru.un_750  rw.sk.un_320 fr.hr.un_320 
  0x53005919, 0x0f150504, 0x20fe3912, 0x283b2111,   // rn.ht.un_750 fr.lv.un_320  br.tlh.sq_654 fa.ks.sd_653 
  0x11fe20ee, 0x341355ee, 0x37004a1a, 0x19554a0b,   // sq.tlh.ro_422 rw.et.xh_422  yo.st.un_760 yo.rw.gl_542 
  0x353456ec, 0x30173508, 0x2d0e2e0c, 0x38000c07,   // mg.xh.zu_644 tg.sr.uz_443  fo.is.sk_543 sv.tk.un_420 
  // [15c80]
  0x59645513, 0x0e02080c, 0x02136404, 0x0c003002,   // rw.lg.rn_665 no.da.is_543  lg.et.da_332 uz.sv.un_220 
  0x53003007, 0x13004811, 0x55003905, 0x02285509,   // uz.ht.un_420 tt.et.un_630  br.rw.un_330 rw.sw.da_444 
  0x063860ac, 0x080210a0, 0x6b006504, 0x203865a0,   // vo.tk.de_632 lt.da.no_322  gv.ceb.un_320 gv.tk.sq_322 
  0x336538a4, 0x20653807, 0x206538a0, 0x42650d12,   // tk.gv.nn_433 tk.gv.sq_432  tk.gv.sq_322 cs.gv.co_654 
  // [15c90]
  0x182e0e55, 0x3500780e, 0x58150102, 0x211834a6,   // is.fo.ga_442 ve.zu.un_550  en.om.un_220 ps.ar.fa_521 
  0x2c653f07, 0x2c386555, 0x01386504, 0x2e0e2baf,   // af.gv.fy_432 gv.tk.fy_442  gv.tk.en_332 vi.is.fo_655 
  0x26232260, 0x1d57fc60, 0x0c4055ee, 0x030f40ee,   // oc.ca.ia_664 zzp.na.la_664  rw.lb.sv_422 lb.lv.nl_422 
  0x030640a0, 0x030d3402, 0x633e65a0, 0x3f03020c,   // lb.de.nl_322 xh.cs.nl_222  gv.rm.sco_322 da.nl.af_543 
  // [15ca0]
  0x4438250c, 0x27186304, 0x12405dee, 0x08020c14,   // mn.tk.kk_543 sco.ga.gd_332  ss.lb.hu_422 sv.da.no_666 
  0x13034007, 0x15032c07, 0x342812ee, 0x3900190b,   // lb.nl.et_432 fy.nl.un_432  ur.sd.ps_422 gl.br.un_520 
  0xfc004e18, 0x40003807, 0x0c400613, 0x60000c21,   // ay.zzp.un_740 tk.lb.un_420  de.lb.sv_665 sv.vo.un_860 
  0x0a253655, 0x3728fca0, 0x1d110209, 0x38044004,   // ab.mn.mk_442 zzp.sw.st_322  da.ro.la_444 lb.fi.tk_332 
  // [15cb0]
  0x04130ca7, 0x4000380b, 0x393b1fa9, 0xfc5d35a4,   // sv.et.fi_532 tk.lb.un_520  cy.so.br_544 zu.ss.zzp_433 
  0x0e23180c, 0x49004b2a, 0x3c2536a4, 0x153c3507,   // ga.ca.is_543 mi.to.un_970  ab.mn.ug_433 tg.ug.un_432 
  0x0c00132a, 0x2e114204, 0x5c003514, 0x0500600b,   // et.sv.un_970 co.ro.fo_332  zu.sa.un_660 vo.fr.un_520 
  0x1c2f21a0, 0x021629a0, 0x0e2e02a4, 0x123034ee,   // jw.su.id_322 sl.hr.da_322  da.fo.is_433 ps.uz.ur_422 
  // [15cc0]
  0x201b32a9, 0x2d0d1e02, 0x45002805, 0x5a4b5bec,   // bs.tr.sq_544 ms.cs.sk_222  sw.ln.un_330 sg.mi.sm_644 
  0x3e00480b, 0x06056511, 0x604838ec, 0x15240204,   // tt.rm.un_520 gv.fr.de_653  tk.tt.vo_644 da.eo.un_332 
  0x15291704, 0x292439a0, 0x20002d08, 0x3000510e,   // sr.sl.un_332 br.eo.sl_322  sk.sq.un_430 kl.uz.un_550 
  0x4800600b, 0x21343ba4, 0x1f002705, 0x5a0657ee,   // vo.tt.un_520 ks.ps.fa_433  gd.cy.un_330 na.de.sm_422 
  // [15cd0]
  0x79000d09, 0x490639a4, 0x48130460, 0x044838ad,   // cs.war.un_440 br.de.to_433  fi.et.tt_664 tk.tt.fi_643 
  0x0e2d2c0d, 0x3d4423ee, 0x2e006312, 0x0c0e2aa7,   // fy.sk.is_554 ky.kk.ku_422  sco.fo.un_640 mt.is.sv_532 
  0x0e2e2d12, 0x3b002a13, 0x180e2da6, 0x3c3044a4,   // sk.fo.is_654 mt.so.un_650  sk.is.ga_521 kk.uz.ug_433 
  0x3b235804, 0x2e003b0b, 0x2d2322ee, 0x632a3307,   // om.ca.so_332 so.fo.un_520  oc.ca.sk_422 nn.mt.sco_432 
  // [15ce0]
  0x474c28ee, 0x12303dad, 0x48000c0b, 0x3600120d,   // sw.wo.sn_422 ku.uz.ur_643  sv.tt.un_520 hu.gn.un_540 
  0x0c130412, 0x3e06480b, 0x0c000418, 0x21003c11,   // fi.et.sv_654 tt.de.rm_542  fi.sv.un_740 ug.fa.un_630 
  0x1b4831eb, 0x65004605, 0x171511ad, 0x427307ad,   // az.tt.tr_662 qu.gv.un_330  ro.sr.un_630 it.ny.co_643 
  0x49201a07, 0x0a0725ac, 0x104709a4, 0x5e5564a4,   // tl.sq.to_432 mn.bg.mk_632  pl.sn.lt_433 lg.rw.ts_433 
  // [15cf0]
  0x02006821, 0x09382a07, 0x7300370d, 0x5e00550d,   // ig.da.un_860 mt.tk.pl_432  st.ny.un_540 rw.ts.un_540 
  0x47fc280d, 0x4f595508, 0x5300590b, 0x03006407,   // sw.zzp.sn_554 rw.rn.bi_443  rn.ht.un_520 lg.nl.un_420 
  0x25004e0e, 0x59554da9, 0xfe595560, 0x31254e0c,   // ay.eu.un_550 aa.rw.rn_544  rw.rn.tlh_664 ay.eu.az_543 
  0x3f0627a0, 0x091229a4, 0x21fe6111, 0x275a1304,   // gd.de.af_322 sl.hu.pl_433  za.tlh.jw_653 et.sm.gd_332 
  // [15d00]
  0x27005105, 0x494b5a08, 0x04024cad, 0x42004f12,   // kl.gd.un_330 sm.mi.to_443  wo.da.fi_643 bi.co.un_640 
  0x69537609, 0x647833af, 0x2d321704, 0x19110b55,   // crs.ht.mfe_444 nn.ve.lg_655  sr.bs.sk_332 es.ro.gl_442 
  0x6327650c, 0x4b471a08, 0x6b791fec, 0x5600fc04,   // gv.gd.sco_543 tl.sn.mi_443  cy.war.ceb_644 zzp.mg.un_320 
  0x073e2708, 0x65511304, 0x3e000722, 0x3f5955ad,   // gd.rm.it_443 et.kl.gv_332  it.rm.un_870 rw.rn.af_643 
  // [15d10]
  0x2a675eec, 0x27004223, 0x03653ea7, 0x25353409,   // ts.ak.mt_644 co.gd.un_880  rm.gv.nl_532 xh.zu.eu_444 
  0x2e00210c, 0x17113504, 0x3d282107, 0x313b4812,   // jw.fo.un_530 tg.ro.sr_332  fa.sd.ku_432 tt.so.az_654 
  0x3c3708a7, 0x65520204, 0x13002702, 0x484c25a0,   // uk.ba.ug_532 da.ha.gv_332  gd.et.un_220 eu.wo.tt_322 
  0x0e030607, 0x0a003405, 0x27033f05, 0x40061d07,   // de.nl.is_432 xh.pt.un_330  af.nl.gd_333 la.de.lb_432 
  // [15d20]
  0x6300331a, 0x27130412, 0x54005814, 0x63406760,   // nn.sco.un_760 fi.et.gd_654  om.ik.un_660 ak.lb.sco_664 
  0x32001618, 0x04001712, 0x7669580c, 0x48311ba4,   // hr.bs.un_740 sr.ru.un_640  om.mfe.crs_543 tr.az.tt_433 
  0x30381504, 0x09006204, 0x4d583b12, 0x3b583e0c,   // un.tk.uz_332 kha.pl.un_320  so.om.aa_654 rm.om.so_543 
  0x07651d02, 0x1b02030b, 0x2a025c07, 0x2a000302,   // la.gv.it_222 nl.da.tr_542  sa.da.mt_432 nl.mt.un_220 
  // [15d30]
  0x02270708, 0x420765a7, 0x30231709, 0x0c0833a7,   // it.gd.da_443 gv.it.co_532  sr.ky.uz_444 nn.no.sv_532 
  0x58123ba4, 0x6907420c, 0x074202a9, 0x070804ee,   // so.hu.om_433 co.it.mfe_543  da.co.it_544 ru.uk.bg_422 
  0x4d655cec, 0x4d006e20, 0x0500070c, 0x03005108,   // sa.gv.aa_644 hmn.aa.un_850  it.fr.un_530 kl.nl.un_430 
  0x4c00521a, 0x075c1512, 0x13203002, 0x124418ad,   // ha.wo.un_760 un.sa.it_654  uz.sq.et_222 ar.kk.ur_643 
  // [15d40]
  0x2efe0c05, 0x330c0804, 0x481b3110, 0x382efea7,   // sv.tlh.fo_333 no.sv.nn_332  az.tr.tt_642 tlh.fo.tk_532 
  0x2500110d, 0x22124007, 0x4700fc12, 0x31003e0c,   // ro.mn.un_540 lb.hu.oc_432  zzp.sn.un_640 rm.az.un_530 
  0x4437230c, 0x4408040b, 0x27004008, 0x5c735613,   // ky.ba.kk_543 ru.uk.kk_542  lb.gd.un_430 mg.ny.sa_665 
  0x5c5e78a9, 0x27004007, 0x130e020c, 0x542804ec,   // ve.ts.sa_544 lb.gd.un_420  da.is.et_543 fi.sw.ik_644 
  // [15d50]
  0x482330ec, 0x48382307, 0x3b4a62a4, 0x23360b05,   // uz.ky.tt_644 ky.tk.tt_432  kha.yo.so_433 es.gn.ca_333 
  0x4d581308, 0x40330855, 0x04006b2a, 0x0800400d,   // et.om.aa_443 no.nn.lb_442  ceb.fi.un_970 lb.no.un_540 
  0x53232104, 0x17250d0c, 0x67355c0c, 0x0b23360c,   // jw.ca.ht_332 cs.eu.sr_543  sa.zu.ak_543 gn.ca.es_543 
  0x64003418, 0x0a4a1904, 0x175c500c, 0x372f50a4,   // xh.lg.un_740 gl.yo.pt_332  fj.sa.sr_543 fj.su.st_433 
  // [15d60]
  0x685c670c, 0x0e002702, 0x37561cec, 0x3548300d,   // ak.sa.ig_543 gd.is.un_220  id.mg.st_644 uz.tt.tg_554 
  0x04135ea9, 0x254273a9, 0x3b134707, 0x51002707,   // ts.et.fi_544 ny.co.eu_544  sn.et.so_432 gd.kl.un_420 
  0x3b044d0d, 0x28130455, 0x21001108, 0x35344555,   // aa.fi.so_554 fi.et.sw_442  ro.jw.un_430 ln.xh.zu_442 
  0x02582f04, 0x4d134704, 0x11004f08, 0x10000e09,   // su.om.da_332 sn.et.aa_332  bi.ro.un_430 is.lt.un_440 
  // [15d70]
  0x23444802, 0x17005d04, 0x1204060e, 0x0602430c,   // tt.kk.ky_222 ss.sr.un_320  de.fi.hu_555 ie.da.de_543 
  0x370735a0, 0x443c250c, 0x2f0643a0, 0x0b2319a7,   // tg.bg.ba_322 mn.ug.kk_543  ie.de.su_322 gl.ca.es_532 
  0x1924750c, 0x21007519, 0x0a755f60, 0x0e0c61ee,   // nso.eo.gl_543 nso.jw.un_750  tn.nso.pt_664 za.sv.is_422 
  0x73006819, 0x0b2f05af, 0x49007304, 0x4831115a,   // ig.ny.un_750 fr.su.es_655  ny.to.un_320 ro.az.tt_553 
  // [15d80]
  0x494a6404, 0x0e612012, 0x53003e05, 0x342812ac,   // lg.yo.to_332 sq.za.is_654  rm.ht.un_330 ur.sd.ps_632 
  0x12343004, 0x0a002711, 0x2800020e, 0x4c450507,   // uz.ps.ur_332 gd.pt.un_630  da.sw.un_550 fr.ln.wo_432 
  0x211823ee, 0x253008ad, 0x370444ee, 0x0a111712,   // ky.ar.fa_422 uk.uz.mn_643  kk.ru.ba_422 sr.ro.mk_654 
  0x7900051a, 0x48384411, 0x55336ba0, 0x3d003b0b,   // fr.war.un_760 kk.tk.tt_653  ceb.nn.rw_322 ks.ku.un_520 
  // [15d90]
  0x212f450c, 0x64133604, 0x2e5568a0, 0x1836fead,   // ln.su.jw_543 gn.et.lg_332  ig.rw.fo_322 tlh.gn.ga_643 
  0x2b001808, 0x1c135c0b, 0x39531fa6, 0x2800522a,   // ga.vi.un_430 sa.bh.mr_542  cy.ht.br_521 ha.sw.un_970 
  0x04291304, 0x302337a0, 0x21123d5a, 0x332e0ea4,   // et.sl.fi_332 ba.ky.uz_322  ku.ur.fa_553 is.fo.nn_433 
  0x2c00110e, 0x48fe5c0c, 0x1b385ca9, 0x30002e07,   // ro.fy.un_550 sa.tlh.tt_543  sa.tk.tr_544 fo.uz.un_420 
  // [15da0]
  0x2e0e2da4, 0x080a3707, 0x482e54ee, 0x5257250c,   // sk.is.fo_433 ba.mk.uk_432  ik.fo.tt_422 eu.na.ha_543 
  0x5c0b3105, 0x38545207, 0x0b0a2da7, 0x045c02a4,   // az.es.sa_333 ha.ik.tk_432  sk.pt.es_532 da.sa.fi_433 
  0x462f5204, 0x7600380c, 0x46361207, 0x4e305112,   // ha.su.qu_332 tk.crs.un_530  hu.gn.qu_432 kl.uz.ay_654 
  0x183d21ad, 0x0c0e3307, 0x0e2d1802, 0x490c1da0,   // fa.ku.ar_643 nn.is.sv_432  ga.sk.is_222 la.sv.to_322 
  // [15db0]
  0x162969a0, 0x18004008, 0x10292a04, 0x35002f02,   // mfe.sl.hr_322 lb.ga.un_430  mt.sl.lt_332 su.zu.un_220 
  0x580b380c, 0x12004d22, 0x5300360d, 0x3f1d0a0c,   // tk.es.om_543 aa.hu.un_870  gn.ht.un_540 pt.la.af_543 
  0x0a150460, 0x0400081a, 0x34005a02, 0xfc042c07,   // ru.mk.un_640 uk.ru.un_760  sm.xh.un_220 fy.fi.zzp_432 
  0x4c003005, 0x11550b02, 0x321609a4, 0x3f00581a,   // uz.wo.un_330 es.rw.ro_222  pl.hr.bs_433 om.af.un_760 
  // [15dc0]
  0x24003704, 0x381722af, 0x05006408, 0x73625c12,   // st.eo.un_320 oc.sr.tk_655  lg.fr.un_430 sa.kha.ny_654 
  0x58007308, 0x0b003608, 0x3f1352ee, 0x08170405,   // ny.om.un_430 gn.es.un_430  ha.et.af_422 ru.sr.uk_333 
  0x29242d11, 0x3f156404, 0x174c36ee, 0x65633f55,   // sk.eo.sl_653 lg.af.un_320  gn.wo.sr_422 af.sco.gv_442 
  0x3f076407, 0x3b30fe07, 0x080711a7, 0x1c001d04,   // lg.it.af_432 tlh.uz.so_432  ro.bg.uk_532 la.id.un_320 
  // [15dd0]
  0x375c2ba0, 0x1827470c, 0x0c002002, 0x4c570c08,   // vi.sa.st_322 sn.gd.ga_543  sq.sv.un_220 sv.na.wo_443 
  0x64004b08, 0x2b4767a9, 0x73305aee, 0x4663490c,   // mi.lg.un_430 ak.sn.vi_544  sm.uz.ny_422 to.sco.qu_543 
  0x1c1d4307, 0x18275ca7, 0x684701a4, 0x18565fa0,   // ie.la.id_432 sa.gd.ga_532  en.sn.ig_433 tn.mg.ga_322 
  0x3667fc07, 0x504b4faf, 0x271878ac, 0x27fe18a4,   // zzp.ak.gn_432 bi.mi.fj_655  ve.ga.gd_632 ga.tlh.gd_433 
  // [15de0]
  0x080a1702, 0x2100200b, 0x46003404, 0x5a5f1302,   // sr.mk.uk_222 sq.jw.un_520  xh.qu.un_320 et.tn.sm_222 
  0x1f007919, 0x02590107, 0x5e78730d, 0x5e007814,   // war.cy.un_750 en.rn.da_432  ny.ve.ts_554 ve.ts.un_660 
  0x654b6305, 0x190a3302, 0x78453307, 0x5a645507,   // sco.mi.gv_333 nn.pt.gl_222  nn.ln.ve_432 rw.lg.sm_432 
  0x0c7352af, 0x56454c14, 0x4f005613, 0x301a6412,   // ha.ny.sv_655 wo.ln.mg_666  mg.bi.un_650 lg.tl.uz_654 
  // [15df0]
  0x494b56a0, 0x21303dec, 0x21000508, 0x0a17480b,   // mg.mi.to_322 ku.uz.fa_644  fr.jw.un_430 tt.sr.mk_542 
  0x0a1d34a9, 0x220a0505, 0x794d2204, 0x102e0e12,   // xh.la.pt_544 fr.pt.oc_333  oc.aa.war_332 is.fo.lt_654 
  0x55644712, 0x130223a7, 0x0c36330c, 0x0a052155,   // sn.lg.rw_654 ca.da.et_532  nn.gn.sv_543 jw.fr.pt_442 
  0x2e2d0507, 0x02082da0, 0x15040711, 0x5200640c,   // fr.sk.fo_432 sk.no.da_322  bg.ru.un_653 lg.ha.un_530 
  // [15e00]
  0x190b7905, 0x0708300b, 0x730278ec, 0x5c001207,   // war.es.gl_333 uz.uk.bg_542  ve.da.ny_644 hu.sa.un_420 
  0x39000314, 0x122123a0, 0x0d001114, 0x1707040d,   // nl.br.un_660 ky.fa.ur_322  ro.cs.un_660 ru.bg.sr_554 
  0x3b000804, 0xfc001b04, 0x19003502, 0x05261104,   // no.so.un_320 tr.zzp.un_320  zu.gl.un_220 ro.ia.fr_332 
  0x23353704, 0x0b0a2305, 0x221959ee, 0x3d213409,   // ba.tg.ky_332 ca.pt.es_333  rn.gl.oc_422 ps.fa.ku_444 
  // [15e10]
  0x23004216, 0x15003709, 0x1834280b, 0x042530a9,   // co.ca.un_720 ba.un.un_440  sd.ps.ar_542 uz.mn.ru_544 
  0x06001902, 0x3c2344a0, 0x19110d04, 0x42000d0c,   // gl.de.un_220 kk.ky.ug_322  cs.ro.gl_332 cs.co.un_530 
  0x34123bad, 0x10480407, 0x1b00220b, 0x3600790d,   // ks.ur.ps_643 ru.tt.be_432  oc.tr.un_520 war.gn.un_540 
  0x423e3619, 0x23005c07, 0x05004a12, 0x35597311,   // gn.rm.co_765 sa.ca.un_420  yo.fr.un_640 ny.rn.zu_653 
  // [15e20]
  0x44302309, 0x0e004202, 0x06122d0c, 0x07000e04,   // ky.uz.kk_444 co.is.un_220  sk.hu.de_543 is.it.un_320 
  0x6a005014, 0x350817a9, 0x2d0d22ee, 0x0a190ba7,   // fj.haw.un_660 sr.uk.tg_544  oc.cs.sk_422 es.gl.pt_532 
  0x1b00382a, 0x401f3913, 0x460742a7, 0x0e3e4204,   // tk.tr.un_970 br.cy.lb_665  co.it.qu_532 co.rm.is_332 
  0x632a01a0, 0x55356a07, 0x68001a0e, 0x123d2160,   // en.mt.sco_322 haw.zu.rw_432  tl.ig.un_550 fa.ku.ur_664 
  // [15e30]
  0x0a2223a0, 0x05001214, 0x21120107, 0x331e08a7,   // ca.oc.pt_322 hu.fr.un_660  iw.ur.fa_432 no.ms.nn_532 
  0x17071505, 0x08110a55, 0x5636470d, 0x330825ee,   // un.bg.sr_333 mk.ro.uk_442  sn.gn.mg_554 eu.no.nn_422 
  0x2a0315a0, 0x53007612, 0x34004309, 0x3f655807,   // un.nl.mt_322 crs.ht.un_640  ie.xh.un_440 om.gv.af_432 
  0x04360704, 0x1a796b05, 0x5d2a3508, 0x07004c0d,   // bg.ab.ru_332 ceb.war.tl_333  zu.mt.ss_443 wo.it.un_540 
  // [15e40]
  0x060e0c0c, 0x404622a0, 0x170a04ee, 0x1a002b02,   // sv.is.de_543 oc.qu.lb_322  ru.mk.sr_422 vi.tl.un_220 
  0x34563504, 0x1efc560c, 0x3c442308, 0x3800640d,   // zu.mg.xh_332 mg.zzp.ms_543  ky.kk.ug_443 lg.tk.un_540 
  0x0f290707, 0x190a15a0, 0x624f1c0b, 0x4f34130e,   // it.sl.lv_432 un.pt.gl_322  id.bi.kha_542 et.xh.bi_555 
  0x384cfea0, 0x5e0253a0, 0x78556408, 0x1300420d,   // tlh.wo.tk_322 ht.da.ts_322  lg.rw.ve_443 co.et.un_540 
  // [15e50]
  0x02004f0d, 0x1d000e02, 0x59fe5507, 0x190b5bed,   // bi.da.un_540 is.la.un_220  rw.tlh.rn_432 sg.es.gl_622 
  0x08023e0c, 0x1b0411a0, 0x1e0f4d0c, 0x58384d04,   // rm.da.no_543 ro.fi.tr_322  aa.lv.ms_543 aa.tk.om_332 
  0x43002a13, 0x020330a0, 0x2e0e2a0b, 0x0d1c6907,   // mt.ie.un_650 uz.nl.da_322  mt.is.fo_542 mfe.id.cs_432 
  0x595552ad, 0x1e2521a0, 0x183d12a0, 0x11006402,   // ha.rw.rn_643 jw.eu.ms_322  ur.ku.ar_322 lg.ro.un_220 
  // [15e60]
  0x25000208, 0x5d355508, 0x34482804, 0x29162da4,   // da.eu.un_430 rw.zu.ss_443  sw.tt.xh_332 sk.hr.sl_433 
  0x5500350e, 0x4afc1aec, 0x4925645a, 0x212e65a9,   // zu.rw.un_550 tl.zzp.yo_644  lg.eu.to_553 gv.fo.jw_544 
  0x30044807, 0x4a003007, 0x05006514, 0x3418300e,   // tt.ru.uz_432 uz.yo.un_420  gv.fr.un_660 uz.ar.ps_555 
  0x101b4c04, 0x55093607, 0x2500041a, 0x2800130d,   // wo.tr.lt_332 gn.pl.rw_432  fi.eu.un_760 et.sw.un_540 
  // [15e70]
  0x1700082c, 0x251054a7, 0xfc605108, 0x790b1ca4,   // uk.sr.un_990 ik.lt.eu_532  kl.vo.zzp_443 id.es.war_433 
  0x6b1079a4, 0x0a004819, 0x4c002513, 0x05652e08,   // war.lt.ceb_433 tt.mk.un_750  eu.wo.un_650 fo.gv.fr_443 
  0x40005119, 0x345547ee, 0x626301ee, 0x3e000f02,   // kl.lb.un_750 sn.rw.xh_422  en.sco.kha_422 lv.rm.un_220 
  0x104c460b, 0x01233ea0, 0x484425ad, 0x4c5152a4,   // qu.wo.lt_542 rm.ca.en_322  mn.kk.tt_643 ha.kl.wo_433 
  // [15e80]
  0x63330802, 0x511e250c, 0x6025040c, 0x2529fc08,   // no.nn.sco_222 eu.ms.kl_543  fi.eu.vo_543 zzp.sl.eu_443 
  0x17292d0b, 0x22033fee, 0x65002304, 0x6000231a,   // sk.sl.sr_542 af.nl.oc_422  ca.gv.un_320 ca.vo.un_760 
  0x2200232a, 0x0b4306ad, 0x353c30ec, 0x546953ad,   // ca.oc.un_970 de.ie.es_643  uz.ug.tg_644 ht.mfe.ik_643 
  0x44104813, 0x11170808, 0x0c30360c, 0x1d053909,   // tt.be.kk_665 uk.sr.ro_443  gn.uz.sv_543 br.fr.la_444 
  // [15e90]
  0x575e7912, 0x53333904, 0x4a5a3609, 0x15765313,   // war.ts.na_654 br.nn.ht_332  gn.sm.yo_444 ht.crs.un_665 
  0x5e003029, 0x584c3b08, 0x04080709, 0x65080208,   // uz.ts.un_960 so.wo.om_443  bg.uk.ru_444 da.no.gv_443 
  0x3c35300c, 0x15002402, 0x0715040b, 0x30233ca7,   // uz.tg.ug_543 eo.un.un_220  ru.bg.un_520 ug.ky.uz_532 
  0x33005809, 0x4f011dee, 0x026b640c, 0x2e00220d,   // om.nn.un_440 la.en.bi_422  lg.ceb.da_543 oc.fo.un_540 
  // [15ea0]
  0x24026711, 0x53653902, 0x12026407, 0x092a4808,   // ak.da.eo_653 br.gv.ht_222  lg.da.hu_432 tt.mt.pl_443 
  0x01003505, 0x2b003b02, 0x3d1230a7, 0x21274605,   // zu.en.un_330 so.vi.un_220  uz.ur.ku_532 qu.gd.jw_333 
  0x4705020c, 0xfe6267ec, 0x38364414, 0x2e00650e,   // da.fr.sn_543 ak.kha.tlh_644  kk.ab.tk_666 gv.fo.un_550 
  0x42640707, 0x3b583fee, 0x3200fe05, 0x22610aec,   // it.lg.co_432 af.om.so_422  tlh.bs.un_330 pt.za.oc_644 
  // [15eb0]
  0x19220a08, 0x073025a0, 0x213c3dad, 0x3c183404,   // pt.oc.gl_443 mn.uz.bg_322  ku.ug.fa_643 ps.ar.ug_332 
  0x6542fc04, 0x28001312, 0x13004d1a, 0x343715a0,   // zzp.co.gv_332 et.sw.un_640  aa.et.un_760 un.st.xh_322 
  0x2a00111b, 0x2a47110c, 0x28554b0c, 0x595536a9,   // ro.mt.un_770 ro.sn.mt_543  mi.rw.sw_543 gn.rw.rn_544 
  0x52112a08, 0x52117805, 0x13005a12, 0x5e1128a9,   // mt.ro.ha_443 ve.ro.ha_333  sm.et.un_640 sw.ro.ts_544 
  // [15ec0]
  0x062e7907, 0x112a5e07, 0x1f390d04, 0x10112a0d,   // war.fo.de_432 ts.mt.ro_432  cs.br.cy_332 mt.ro.lt_554 
  0x11375fa9, 0x201a110c, 0x602f6ba4, 0x15004308,   // tn.st.ro_544 ro.tl.sq_543  ceb.su.vo_433 ie.un.un_430 
  0x02114b09, 0x08511508, 0x18191204, 0x03202ca0,   // mi.ro.da_444 un.kl.no_443  hu.gl.ga_332 fy.sq.nl_322 
  0x3f32290c, 0x483573a0, 0x402b01a0, 0x35463009,   // sl.bs.af_543 ny.zu.tt_322  en.vi.lb_322 uz.qu.zu_444 
  // [15ed0]
  0x524c1a08, 0x481735ee, 0x37001d02, 0x2f001e08,   // tl.wo.ha_443 tg.sr.tt_422  la.st.un_220 ms.su.un_430 
  0x2f361ca4, 0x374808a4, 0x73640407, 0x190b1205,   // id.gn.su_433 uk.tt.ba_433  fi.lg.ny_432 hu.es.gl_333 
  0x56007304, 0x516404a4, 0x3b001e13, 0x20007307,   // ny.mg.un_320 fi.lg.kl_433  ms.so.un_650 ny.sq.un_420 
  0x1122435a, 0x04796407, 0x294cfe5a, 0x04676405,   // ie.oc.ro_553 lg.war.fi_432  tlh.wo.sl_553 lg.ak.fi_333 
  // [15ee0]
  0x041708ec, 0x2344385a, 0x5d475ca6, 0x51647907,   // uk.sr.ru_644 tk.kk.ky_553  sa.sn.ss_521 war.lg.kl_432 
  0x081504ee, 0x40002505, 0x440738a6, 0x212f3e09,   // ru.uk.un_420 eu.lb.un_330  tk.bg.kk_521 rm.su.jw_444 
  0x5100fe13, 0x0f001323, 0x4c192512, 0x3b1c1ea4,   // tlh.kl.un_650 et.lv.un_880  eu.gl.wo_654 ms.id.so_433 
  0x083810ec, 0x33001d04, 0x58046404, 0x120d2d12,   // be.tk.uk_644 la.nn.un_320  lg.fi.om_332 sk.cs.hu_654 
  // [15ef0]
  0x6400040c, 0x0a00080e, 0x4a00391a, 0x082504ee,   // fi.lg.un_530 uk.mk.un_550  br.yo.un_760 ru.mn.uk_422 
  0x35301508, 0x0a07080c, 0x21687307, 0x0e3b5809,   // un.uz.tg_443 uk.bg.mk_543  ny.ig.jw_432 om.so.is_444 
  0x02464a05, 0x58002513, 0x4d001219, 0x3711285a,   // yo.qu.da_333 eu.om.un_650  hu.aa.un_750 sw.ro.st_553 
  0x1d5622a0, 0x253f6ba0, 0x04150704, 0x5e6a560d,   // oc.mg.la_322 ceb.af.eu_322  bg.ru.un_320 mg.haw.ts_554 
  // [15f00]
  0x28004f09, 0x3b351ca0, 0x18030507, 0x10270408,   // bi.sw.un_440 id.zu.so_322  fr.nl.ga_432 fi.gd.lt_443 
  0x072311ac, 0x2e2d12ad, 0x6527010c, 0x186527a4,   // ro.ky.bg_632 hu.sk.fo_643  en.gd.gv_543 gd.gv.ga_433 
  0x12044c0d, 0x6500272b, 0x735d560d, 0x6500631b,   // wo.fi.hu_554 gd.gv.un_980  mg.ss.ny_554 sco.gv.un_770 
  0x50650107, 0x585e3b08, 0x5a475612, 0x152304a4,   // en.gv.fj_432 so.ts.om_443  mg.sn.sm_654 ru.ky.un_433 
  // [15f10]
  0x0a796a04, 0x3738235a, 0x504e46a4, 0x1d1827a0,   // haw.war.pt_332 ky.tk.ba_553  qu.ay.fj_433 gd.ga.la_322 
  0x275139a0, 0x330829af, 0x3f0365a4, 0x28381b04,   // br.kl.gd_322 sl.no.nn_655  gv.nl.af_433 tr.tk.sw_332 
  0x1827630d, 0x216b1dad, 0x07153012, 0x135136a4,   // sco.gd.ga_554 la.ceb.jw_643  uz.bg.un_640 gn.kl.et_433 
  0x30002311, 0x17113508, 0x31004823, 0x04522555,   // ky.uz.un_630 tg.ro.sr_443  tt.az.un_880 eu.ha.fi_442 
  // [15f20]
  0x3d23180c, 0x48234402, 0x533f0da4, 0x39530d11,   // ar.ky.ku_543 kk.ky.tt_222  cs.af.ht_433 cs.ht.br_653 
  0x1900390d, 0xfc003407, 0x39401107, 0x026323a4,   // br.gl.un_540 xh.zzp.un_420  ro.lb.br_432 ca.sco.da_433 
  0x300704a4, 0x4c6011a9, 0x4c11600d, 0x0d1218ad,   // ru.bg.uz_433 ro.vo.wo_544  vo.ro.wo_554 ga.hu.cs_643 
  0x4c616955, 0x2d0309a7, 0x2f40130c, 0x2f621c0c,   // mfe.za.wo_442 pl.nl.sk_532  et.lb.su_543 id.kha.su_543 
  // [15f30]
  0x2f13110c, 0x400d3f04, 0x1c312f04, 0x48201ba4,   // ro.et.su_543 af.cs.lb_332  su.az.id_332 tr.sq.tt_433 
  0x1157010c, 0x765421ec, 0x1d431112, 0x48154411,   // en.na.ro_543 jw.ik.crs_644  ro.ie.la_654 kk.tt.un_630 
  0x361d2dac, 0x39116012, 0x4d114c0c, 0x3f6011a4,   // sk.la.gn_632 vo.ro.br_654  wo.ro.aa_543 ro.vo.af_433 
  0x1e2a11ec, 0x2e0c60ee, 0x1e4c11ad, 0x3043110c,   // ro.mt.ms_644 vo.sv.fo_422  ro.wo.ms_643 ro.ie.uz_543 
  // [15f40]
  0x303bfe05, 0x12002e09, 0x2d001211, 0x64005e0e,   // tlh.so.uz_333 fo.hu.un_440  hu.sk.un_630 ts.lg.un_550 
  0x08371505, 0x170a1111, 0x200a31a4, 0x200a1ba0,   // un.ba.uk_333 ro.mk.sr_653  az.pt.sq_433 tr.pt.sq_322 
  0x3300031b, 0x21100fa7, 0x30043504, 0x06002a04,   // nl.nn.un_770 lv.lt.jw_532  tg.ru.uz_332 mt.de.un_320 
  0x0600380d, 0x30005f0d, 0x124c0709, 0x07234208,   // tk.de.un_540 tn.uz.un_540  it.wo.hu_444 co.ca.it_443 
  // [15f50]
  0x345c0207, 0x30232511, 0x6507420e, 0x4c4262ee,   // da.sa.xh_432 mn.ky.uz_653  co.it.gv_555 kha.co.wo_422 
  0x123021ad, 0x42004c0d, 0x4c001b02, 0x230438a0,   // fa.uz.ur_643 wo.co.un_540  tr.wo.un_220 tk.ru.ky_322 
  0x30343ba4, 0x064038ee, 0x07424c04, 0x65261d0c,   // ks.ps.uz_433 tk.lb.de_422  wo.co.it_332 la.ia.gv_543 
  0x1b004004, 0x3f4002ee, 0x3e1242ee, 0x2c120eaf,   // lb.tr.un_320 da.lb.af_422  co.hu.rm_422 is.hu.fy_655 
  // [15f60]
  0x3f005807, 0x4c002912, 0x0e002a08, 0x12233ca7,   // om.af.un_420 sl.wo.un_640  mt.is.un_430 ug.ky.ur_532 
  0x042338ee, 0x19001813, 0x33002f02, 0x190b1809,   // tk.ky.ru_422 ga.gl.un_650  su.nn.un_220 ga.es.gl_444 
  0x301707a0, 0x0d190b02, 0x12302804, 0x3d3b3407,   // bg.sr.uz_322 es.gl.cs_222  sd.uz.ur_332 ps.ks.ku_432 
  0x28006508, 0x594757a4, 0x28355dec, 0x3f2e24ee,   // gv.sw.un_430 na.sn.rn_433  ss.zu.sw_644 eo.fo.af_422 
  // [15f70]
  0x25004704, 0x5d02390c, 0x59005d0d, 0x5d0235af,   // sn.eu.un_320 br.da.ss_543  ss.rn.un_540 zu.da.ss_655 
  0x73040da4, 0x130402a0, 0x211c0107, 0x2f04130e,   // cs.fi.ny_433 da.fi.et_322  en.id.jw_432 et.fi.su_555 
  0x73375f07, 0x6b080204, 0x4a04fc09, 0x4835110c,   // tn.st.ny_432 da.no.ceb_332  zzp.fi.yo_444 ro.tg.tt_543 
  0x521a56af, 0x1123225a, 0x64003602, 0x0000792d,   // mg.tl.ha_655 oc.ca.ro_553  gn.lg.un_220 war.un.un_A00 
  // [15f80]
  0x0b2539a4, 0x761b690c, 0x651d2604, 0x0d092a04,   // br.eu.es_433 mfe.tr.crs_543  ia.la.gv_332 mt.pl.cs_332 
  0x39045ea7, 0x3f0373af, 0x021139a4, 0x10483004,   // ts.fi.br_532 ny.nl.af_655  br.ro.da_433 uz.tt.be_332 
  0x7334020c, 0x02250107, 0x1e1c51ee, 0x32002a07,   // da.xh.ny_543 en.eu.da_432  kl.id.ms_422 mt.bs.un_420 
  0x21392aa4, 0xfc1a02a4, 0x25081708, 0x15482355,   // mt.br.jw_433 da.tl.zzp_433  sr.uk.mn_443 ky.tt.un_442 
  // [15f90]
  0x6a004922, 0x4006fca4, 0x29162d55, 0x1b0f3413,   // to.haw.un_870 zzp.de.lb_433  sk.hr.sl_442 xh.lv.tr_665 
  0x5e005d23, 0x0a0810a4, 0x3b004902, 0x354b34ad,   // ss.ts.un_880 be.uk.mk_433  to.so.un_220 xh.mi.zu_643 
  0x0f63fe05, 0x06401b04, 0x1015230c, 0x40002213,   // tlh.sco.lv_333 tr.lb.de_332  ky.be.un_530 oc.lb.un_650 
  0x4c4a3407, 0x170c4aee, 0x371504a4, 0x29003604,   // xh.yo.wo_432 yo.sv.sr_422  ru.ba.un_430 gn.sl.un_320 
  // [15fa0]
  0x4735340c, 0x31002009, 0x32174bec, 0x60100f13,   // xh.zu.sn_543 sq.az.un_440  mi.sr.bs_644 lv.lt.vo_665 
  0x1752200b, 0x1b002008, 0x3360fe0d, 0x3e006911,   // sq.ha.sr_542 sq.tr.un_430  tlh.vo.nn_554 mfe.rm.un_630 
  0x041707ee, 0x39002005, 0x0d131c04, 0x233c34a0,   // bg.sr.ru_422 sq.br.un_330  mr.bh.ne_332 ps.ug.ky_322 
  0x3e222613, 0x364c10ee, 0x18004d10, 0x0800041b,   // ia.oc.rm_665 lt.wo.gn_422  aa.ga.un_620 ru.uk.un_770 
  // [15fb0]
  0x3e0e2e07, 0x13060407, 0x5c00fc08, 0x4f00021a,   // fo.is.rm_432 fi.de.et_432  zzp.sa.un_430 da.bi.un_760 
  0x0c4e1204, 0x0300fc08, 0x22002605, 0x0a0407ad,   // hu.ay.sv_332 zzp.nl.un_430  ia.oc.un_330 bg.ru.mk_643 
  0x042b61a0, 0x73002c08, 0x476b5e09, 0x4f792005,   // za.vi.fi_322 fy.ny.un_430  ts.ceb.sn_444 sq.war.bi_333 
  0x2b1f6104, 0x38007302, 0x3579470d, 0x61000a1b,   // za.cy.vi_332 ny.tk.un_220  sn.war.zu_554 pt.za.un_770 
  // [15fc0]
  0x790a61ee, 0x2b224707, 0x61220aad, 0x470c19a0,   // za.pt.war_422 sn.oc.vi_432  pt.oc.za_643 gl.sv.sn_322 
  0x5e3647a0, 0x4c0319a0, 0x030c19ee, 0xfc403f0d,   // sn.gn.ts_322 gl.nl.wo_322  gl.sv.nl_422 af.lb.zzp_554 
  0x33084704, 0xfe611aa4, 0x30233ca9, 0x6b477912,   // sn.no.nn_332 tl.za.tlh_433  ug.ky.uz_544 war.sn.ceb_654 
  0x52001005, 0x04475e60, 0x67005e05, 0x12000b14,   // lt.ha.un_330 ts.sn.fi_664  ts.ak.un_330 es.hu.un_660 
  // [15fd0]
  0x233844ec, 0x344a6411, 0x2d120d05, 0x19480aa4,   // kk.tk.ky_644 lg.yo.xh_653  cs.hu.sk_333 pt.tt.gl_433 
  0x6500110d, 0x3e00650c, 0x64341304, 0x06240e13,   // ro.gv.un_540 gv.rm.un_530  et.xh.lg_332 is.eo.de_665 
  0x0e190beb, 0x320265ee, 0x2e1912ad, 0x353025a0,   // es.gl.is_662 gv.da.bs_422  hu.gl.fo_643 mn.uz.tg_322 
  0x04103507, 0x35481504, 0x0e37155a, 0x06000209,   // tg.be.ru_432 un.tt.tg_332  un.st.is_553 da.de.un_440 
  // [15fe0]
  0x29003504, 0x17000713, 0x4a001908, 0x5a006208,   // zu.sl.un_320 bg.sr.un_650  gl.yo.un_430 kha.sm.un_430 
  0x0700300b, 0x3b002108, 0x2e003610, 0x430f5c0c,   // uz.bg.un_520 fa.ks.un_430  gn.fo.un_620 sa.lv.ie_543 
  0x35342aee, 0x232515a0, 0x35001302, 0x364438af,   // mt.xh.zu_422 un.mn.ky_322  et.zu.un_220 tk.kk.ab_655 
  0x04171105, 0x2300150b, 0x0e5c0a04, 0x22fe5ca0,   // ro.sr.ru_333 un.ky.un_520  pt.sa.is_332 sa.tlh.oc_322 
  // [15ff0]
  0x0f111055, 0x34193fa0, 0x65023907, 0x071008af,   // lt.ro.lv_442 af.gl.xh_322  br.da.gv_432 uk.be.bg_655 
  0x53000d13, 0x393e1d04, 0x04473904, 0x6500051b,   // cs.ht.un_650 la.rm.br_332  br.sn.fi_332 fr.gv.un_770 
  0x0d00610d, 0x483723af, 0x0d632208, 0x091a6ba4,   // za.cs.un_540 ky.ba.tt_655  oc.sco.cs_443 ceb.tl.pl_433 
  0x09056708, 0xfe3101a0, 0x46231fad, 0x48000d08,   // ak.fr.pl_443 en.az.tlh_322  cy.ca.qu_643 cs.tt.un_430 
  
  // [16000]
  0x64304513, 0x581351a4, 0x5664450d, 0x116501a4,   // ln.uz.lg_665 kl.et.om_433  ln.lg.mg_554 en.gv.ro_433 
  0x0e1579a0, 0x625701a0, 0x09006507, 0x0400fc0e,   // war.is.un_320 en.na.kha_322  gv.pl.un_420 zzp.fi.un_550 
  0x4c000209, 0x11293e08, 0x3f0315af, 0x213739a0,   // da.wo.un_440 rm.sl.ro_443  un.nl.af_655 br.st.jw_322 
  0x3e201c07, 0x0d001c18, 0x3b0f46a0, 0x3e001b04,   // id.sq.rm_432 mr.ne.un_740  qu.lv.so_322 tr.rm.un_320 
  // [16010]
  0x4600690d, 0x033ffca0, 0x44154808, 0x38234412,   // mfe.qu.un_540 zzp.af.nl_322  tt.kk.un_430 kk.ky.tk_654 
  0x1a102f02, 0x122328a4, 0x53003704, 0x351634ee,   // su.lt.tl_222 sd.ky.ur_433  st.ht.un_320 xh.hr.zu_422 
  0x48152504, 0x2b001109, 0x4a005713, 0x0b0a4802,   // mn.tt.un_320 ro.vi.un_440  na.yo.un_650 tt.pt.es_222 
  0x34004a09, 0x11002b04, 0x3c000813, 0x460e10a0,   // yo.xh.un_440 vi.ro.un_320  uk.ug.un_650 lt.is.qu_322 
  // [16020]
  0x130f04ee, 0x20001222, 0x391302a4, 0x02522aec,   // fi.lv.et_422 hu.sq.un_870  da.et.br_433 mt.ha.da_644 
  0x2000121a, 0x2e045ea9, 0x031e010c, 0xfc002509,   // hu.sq.un_760 ts.fi.fo_544  en.ms.nl_543 eu.zzp.un_440 
  0x46023b0d, 0x25042fa0, 0x370408a4, 0x754d5209,   // so.da.qu_554 su.fi.eu_322  uk.ru.ba_433 ha.aa.nso_444 
  0x060e2e13, 0x0c2425ad, 0x10007921, 0x603573a4,   // fo.is.de_665 eu.eo.sv_643  war.lt.un_860 ny.zu.vo_433 
  // [16030]
  0x123d3013, 0x330820af, 0x520210ad, 0x2e4e02a4,   // uz.ku.ur_665 sq.no.nn_655  lt.da.ha_643 da.ay.fo_433 
  0x5d46100d, 0x4c001912, 0x15303812, 0x44100804,   // lt.qu.ss_554 gl.wo.un_640  tk.uz.un_654 uk.be.kk_332 
  0x0725385a, 0x63006509, 0x39004c12, 0x6539020c,   // tk.mn.bg_553 gv.sco.un_440  wo.br.un_640 da.br.gv_543 
  0x283969a4, 0x154838ee, 0x654c39a4, 0x0900670d,   // mfe.br.sw_433 tk.tt.un_422  br.wo.gv_433 ak.pl.un_540 
  // [16040]
  0x28003905, 0x1f00fe13, 0x343d12af, 0x3f636504,   // br.sw.un_330 tlh.cy.un_650  ur.ku.ps_655 gv.sco.af_332 
  0x474c5fa7, 0x260401a0, 0x0a3715a0, 0x650539a0,   // tn.wo.sn_532 en.fi.ia_322  un.ba.mk_322 br.fr.gv_322 
  0x403e39a0, 0x634001a0, 0x3b50010c, 0x12283d02,   // br.rm.lb_322 en.lb.sco_322  en.fj.so_543 ku.sd.ur_222 
  0x423b0207, 0x233d21a7, 0x4f050107, 0x630105a0,   // da.so.co_432 fa.ku.ky_532  en.fr.bi_432 fr.en.sco_322 
  // [16050]
  0x1f00650c, 0x396302a4, 0x57630108, 0x6900401b,   // gv.cy.un_530 da.sco.br_433  en.sco.na_443 lb.mfe.un_770 
  0x5100011a, 0x3902650d, 0x5d005e0c, 0x3b585e07,   // en.kl.un_760 gv.da.br_554  ts.ss.un_530 ts.om.so_432 
  0x02435708, 0x40005302, 0x0239010c, 0x514701af,   // na.ie.da_443 ht.lb.un_220  en.br.da_543 en.sn.kl_655 
  0x5100341a, 0xfc252755, 0x0f1024a0, 0x762523a4,   // xh.kl.un_760 gd.eu.zzp_442  eo.lt.lv_322 ca.eu.crs_433 
  // [16060]
  0x730efc07, 0x18271fa4, 0x621ffca9, 0x65001814,   // zzp.is.ny_432 cy.gd.ga_433  zzp.cy.kha_544 ga.gv.un_660 
  0x42102755, 0x0a00230d, 0x1f270107, 0x0c264312,   // gd.lt.co_442 ky.mk.un_540  en.gd.cy_432 ie.ia.sv_654 
  0x32202207, 0x042f2a04, 0x0d1f3907, 0x2e002102,   // oc.sq.bs_432 mt.su.fi_332  br.cy.cs_432 jw.fo.un_220 
  0x3d3c1204, 0x25350705, 0x4d005814, 0x3b001502,   // ur.ug.ku_332 bg.tg.mn_333  om.aa.un_660 un.so.un_220 
  // [16070]
  0x3138300d, 0x30311b09, 0x1b0e4807, 0x2f0e2e07,   // uz.tk.az_554 tr.az.uz_444  tt.is.tr_432 fo.is.su_432 
  0x07043505, 0x17042504, 0x5d003707, 0x091158ad,   // tg.ru.bg_333 mn.ru.sr_332  st.ss.un_420 om.ro.pl_643 
  0x3b003902, 0x10373807, 0x3900240c, 0x0b000302,   // br.so.un_220 tk.ba.be_432  eo.br.un_530 nl.es.un_220 
  0x330cfca6, 0x0a00400b, 0x20005316, 0x06002512,   // zzp.sv.nn_521 lb.pt.un_520  ht.sq.un_720 eu.de.un_640 
  // [16080]
  0x23202219, 0x32131607, 0x606a4b0c, 0x1805010c,   // oc.sq.ca_765 hr.et.bs_432  mi.haw.vo_543 en.fr.ga_543 
  0x4245050c, 0x0206fca7, 0x122f2d07, 0x27186a08,   // fr.ln.co_543 zzp.de.da_532  sk.su.hu_432 haw.ga.gd_443 
  0x2f003609, 0x0c064812, 0x22041505, 0x20002522,   // gn.su.un_440 tt.de.sv_654  un.fi.oc_333 eu.sq.un_870 
  0x5300231d, 0x27185a12, 0x185f3708, 0x0718275a,   // ca.ht.un_820 sm.ga.gd_654  st.tn.ga_443 gd.ga.it_553 
  // [16090]
  0x0600251b, 0x112501a7, 0x42050a55, 0x0a2d0d08,   // eu.de.un_770 en.eu.ro_532  pt.fr.co_442 cs.sk.pt_443 
  0x30006508, 0x5c0d13a6, 0x105c0fad, 0x02052508,   // gv.uz.un_430 bh.ne.sa_521  lv.sa.lt_643 eu.fr.da_443 
  0x766a010c, 0x192f220c, 0x561104af, 0x6326fc04,   // en.haw.crs_543 oc.su.gl_543  fi.ro.mg_655 zzp.ia.sco_332 
  0x04006a12, 0x1e1c2104, 0x16003604, 0x53321702,   // haw.fi.un_640 jw.id.ms_332  gn.hr.un_320 sr.bs.ht_222 
  // [160a0]
  0x52004b08, 0x5d1a4ba4, 0x3900760c, 0x51004907,   // mi.ha.un_430 mi.tl.ss_433  crs.br.un_530 to.kl.un_420 
  0x1e5079af, 0x21311b0c, 0x180e1904, 0x5e7346ec,   // war.fj.ms_655 tr.az.jw_543  gl.is.ga_332 qu.ny.ts_644 
  0x525559ee, 0x52205f04, 0x16000a02, 0x13004d05,   // rn.rw.ha_422 tn.sq.ha_332  pt.hr.un_220 aa.et.un_330 
  0x5955530e, 0x29175307, 0x59556209, 0x12495e07,   // ht.rw.rn_555 ht.sr.sl_432  kha.rw.rn_444 ts.to.hu_432 
  // [160b0]
  0x4b735e04, 0x0704250c, 0x1c522404, 0x452d0d0e,   // ts.ny.mi_332 mn.ru.bg_543  eo.ha.id_332 cs.sk.ln_555 
  0x53322912, 0x52201e04, 0x557936ec, 0x36190a05,   // sl.bs.ht_654 ms.sq.ha_332  gn.war.rw_644 pt.gl.gn_333 
  0x55005220, 0x0d005202, 0x0f4b5ca9, 0x0e123607,   // ha.rw.un_850 ha.cs.un_220  sa.mi.lv_544 gn.hu.is_432 
  0x23213407, 0x4b0f5c60, 0x101535a0, 0x353c38a0,   // ps.fa.ky_432 sa.lv.mi_664  tg.be.un_320 tk.ug.tg_322 
  // [160c0]
  0x09041012, 0x033f1d04, 0x5b00041a, 0x02033f13,   // lt.fi.pl_654 la.af.nl_332  fi.sg.un_760 af.nl.da_665 
  0x4c035f04, 0x04fc13a0, 0x28121813, 0x17292da4,   // tn.nl.wo_332 et.zzp.fi_322  ar.ur.sd_665 sk.sl.sr_433 
  0x12190ea9, 0xfc40060c, 0x152338ad, 0x18612713,   // is.gl.hu_544 de.lb.zzp_543  tk.ky.un_643 gd.za.ga_665 
  0x0e006112, 0x185778a4, 0x49fc28ad, 0x215c1e07,   // za.is.un_640 ve.na.ga_433  sw.zzp.to_643 ms.sa.jw_432 
  // [160d0]
  0x43033f08, 0x18fe65a4, 0x023f03af, 0x464a520c,   // af.nl.ie_443 gv.tlh.ga_433  nl.af.da_655 ha.yo.qu_543 
  0x033f5f08, 0x180165ee, 0x23006e07, 0x2c0e2e13,   // tn.af.nl_443 gv.en.ga_422  hmn.ca.un_420 fo.is.fy_665 
  0x1d020313, 0x33000219, 0x3f034fee, 0x190b60a0,   // nl.da.la_665 da.nn.un_750  bi.nl.af_422 vo.es.gl_322 
  0x30000a05, 0x0413380c, 0x1b0d105e, 0x11001010,   // mk.uz.un_330 tk.et.fi_543  lt.cs.tr_652 lt.ro.un_620 
  // [160e0]
  0x1f520207, 0x18122302, 0x170a4805, 0x1f6b0e0b,   // da.ha.cy_432 ky.ur.ar_222  tt.mk.sr_333 is.ceb.cy_542 
  0x041d58ee, 0x1f400e08, 0x2e000504, 0x5a005804,   // om.la.fi_422 is.lb.cy_443  fr.fo.un_320 om.sm.un_320 
  0x4a004714, 0x491d5807, 0x09420d07, 0x586a5a55,   // sn.yo.un_660 om.la.to_432  cs.co.pl_432 sm.haw.om_442 
  0x64004722, 0x2d1109a0, 0x534a5204, 0x390c36ec,   // sn.lg.un_870 pl.ro.sk_322  ha.yo.ht_332 gn.sv.br_644 
  // [160f0]
  0x5565640c, 0x1c361ea4, 0x302144b4, 0x0f0d2dad,   // lg.gv.rw_543 ms.gn.id_433  kk.fa.uz_754 sk.cs.lv_643 
  0x032f3f55, 0x18443c0d, 0x24000b04, 0x170b295a,   // af.su.nl_442 ug.kk.ar_554  es.eo.un_320 sl.es.sr_553 
  0x1e01fca0, 0x28355955, 0x2036300c, 0x0b305c07,   // zzp.en.ms_322 rn.zu.sw_442  uz.gn.sq_543 sa.uz.es_432 
  0x070417ad, 0x35001713, 0x345d35a0, 0x574a67af,   // sr.ru.bg_643 sr.tg.un_650  zu.ss.xh_322 ak.yo.na_655 
  // [16100]
  0x04111712, 0x4d4f51ec, 0x027639a4, 0x2800300d,   // sr.ro.ru_654 kl.bi.aa_644  br.crs.da_433 uz.sd.un_540 
  0x56355d0c, 0x4c00040e, 0x2f004c02, 0x44041555,   // ss.zu.mg_543 fi.wo.un_550  wo.su.un_220 un.ru.kk_442 
  0x0e2e2c0c, 0x462c3008, 0x6b1d0408, 0x57003013,   // fy.fo.is_543 uz.fy.qu_443  fi.la.ceb_443 uz.na.un_650 
  0x2a792d04, 0x650612a9, 0x05006907, 0x300a3cac,   // sk.war.mt_332 hu.de.gv_544  mfe.fr.un_420 ug.mk.uz_632 
  // [16110]
  0x3f123302, 0x2f00300d, 0x12330804, 0x51151104,   // nn.hu.af_222 uz.su.un_540  no.nn.hu_332 ro.kl.un_320 
  0x0476390c, 0x300c510b, 0x283038ee, 0x041f1d07,   // br.crs.fi_543 kl.sv.uz_542  tk.uz.sw_422 la.cy.fi_432 
  0x513012af, 0x31005108, 0x15002013, 0x360b19ad,   // hu.uz.kl_655 kl.az.un_430  sq.un.un_650 gl.es.gn_643 
  0x24304812, 0x082d0d04, 0x48000f0b, 0x573f03a4,   // tt.uz.eo_654 cs.sk.no_332  lv.tt.un_520 nl.af.na_433 
  // [16120]
  0x0d000204, 0x31301bad, 0x15003605, 0x0e31300c,   // da.cs.un_320 tr.uz.az_643  gn.un.un_330 uz.az.is_543 
  0x51791bee, 0x151dfca7, 0x0a483860, 0x3032560c,   // tr.war.kl_422 zzp.la.un_532  tk.tt.mk_664 mg.bs.uz_543 
  0x22000913, 0x391d02a6, 0x2100470b, 0x1f007907,   // pl.oc.un_650 da.la.br_521  sn.jw.un_520 war.cy.un_420 
  0x4b00240b, 0x212f10a0, 0x05227308, 0x58001608,   // eo.mi.un_520 lt.su.jw_322  ny.oc.fr_443 hr.om.un_430 
  // [16130]
  0x07644d07, 0x571827a4, 0x6b3e0704, 0x0d004008,   // aa.lg.it_432 gd.ga.na_433  it.rm.ceb_332 lb.cs.un_430 
  0x2c00fe0e, 0x585b5707, 0x431d220c, 0x3b004805,   // tlh.fy.un_550 na.sg.om_432  oc.la.ie_543 tt.so.un_330 
  0x2f216e02, 0x42004904, 0x4a002c02, 0x284423ee,   // hmn.jw.su_222 to.co.un_320  fy.yo.un_220 ky.kk.sd_422 
  0x3d003034, 0x12420707, 0x2c00fe0c, 0x64650713,   // uz.ku.un_A80 it.co.hu_432  tlh.fy.un_530 it.gv.lg_665 
  // [16140]
  0x40000d04, 0x2205120c, 0x481e5707, 0x3510480c,   // cs.lb.un_320 hu.fr.oc_543  na.ms.tt_432 tt.be.tg_543 
  0x59004f0e, 0x031a64a4, 0x31022507, 0x5e025504,   // bi.rn.un_550 lg.tl.nl_433  eu.da.az_432 rw.da.ts_332 
  0x38766904, 0x38044809, 0x0400481b, 0x59645508,   // mfe.crs.tk_332 tt.fi.tk_444  tt.fi.un_770 rw.lg.rn_443 
  0x3b003412, 0x0200600c, 0x3b1134a4, 0x131a6b12,   // xh.so.un_640 vo.da.un_530  xh.ro.so_433 ceb.tl.et_654 
  // [16150]
  0x29022ca4, 0x0e2e2c11, 0x22005a1a, 0x5e4d4eaf,   // fy.da.sl_433 fy.fo.is_653  sm.oc.un_760 ay.aa.ts_655 
  0x675564af, 0x3b4c4e0c, 0x5a0e0107, 0x255c3b0b,   // lg.rw.ak_655 ay.wo.so_543  en.is.sm_432 so.sa.eu_542 
  0x0d242d0d, 0x3b484d11, 0x17083c07, 0x500e61a4,   // sk.eo.cs_554 aa.tt.so_653  ug.uk.sr_432 za.is.fj_433 
  0x6e63010c, 0x69375312, 0x10000113, 0x254c3b07,   // en.sco.hmn_543 ht.st.mfe_654  en.lt.un_650 so.wo.eu_432 
  // [16160]
  0x33225aa0, 0x47005e04, 0x595567a6, 0x641f2a0c,   // sm.oc.nn_322 ts.sn.un_320  ak.rw.rn_521 mt.cy.lg_543 
  0x48005c0d, 0x2b315ea7, 0x483804ee, 0x4c304e13,   // sa.tt.un_540 ts.az.vi_532  fi.tk.tt_422 ay.uz.wo_665 
  0x6e100f04, 0x796b21a4, 0x314c3b13, 0x05012204,   // lv.lt.hmn_332 jw.ceb.war_433  so.wo.az_665 oc.en.fr_332 
  0x6300280d, 0x36234807, 0x482c30a0, 0x33085302,   // sw.sco.un_540 tt.ky.ab_432  uz.fy.tt_322 ht.no.nn_222 
  // [16170]
  0x30007909, 0x4c007312, 0x2e006519, 0x071525ee,   // war.uz.un_440 ny.wo.un_640  gv.fo.un_750 mn.bg.un_420 
  0x07042507, 0x0c5f1d04, 0x032415a4, 0x5e003404,   // mn.ru.bg_432 la.tn.sv_332  un.eo.nl_433 xh.ts.un_320 
  0x38002d08, 0x06340304, 0x0e2e2ca9, 0x03110504,   // sk.tk.un_430 nl.xh.de_332  fy.fo.is_544 fr.ro.nl_332 
  0x5c091c09, 0x3d2130af, 0x0500110e, 0x06003b04,   // mr.hi.sa_444 uz.fa.ku_655  ro.fr.un_550 so.de.un_320 
  // [16180]
  0x110b20a0, 0x01021fa4, 0x11153005, 0x4b004304,   // sq.es.ro_322 cy.da.en_433  uz.ro.un_330 ie.mi.un_320 
  0x1507110d, 0x5300290c, 0x20001907, 0x2d195eee,   // ro.bg.un_554 sl.ht.un_530  gl.sq.un_420 ts.gl.sk_422 
  0x11051908, 0x73004c19, 0xfe534c0c, 0x12211805,   // gl.fr.ro_443 wo.ny.un_750  wo.ht.tlh_543 ar.fa.ur_333 
  0x46004c19, 0x01001c08, 0x171138a4, 0x694c76ad,   // wo.qu.un_750 id.en.un_430  tk.ro.sr_433 crs.wo.mfe_643 
  // [16190]
  0x384437a4, 0x69004629, 0xfe4c53a4, 0x48303511,   // ba.kk.tk_433 qu.mfe.un_960  ht.wo.tlh_433 tg.uz.tt_653 
  0x22002013, 0x53003004, 0x38fe4c11, 0x5625650d,   // sq.oc.un_650 uz.ht.un_320  wo.tlh.tk_653 gv.eu.mg_554 
  0x5225620c, 0x21402f04, 0x046b1ca9, 0x1b0c12a9,   // kha.eu.ha_543 su.lb.jw_332  id.ceb.fi_544 hu.sv.tr_544 
  0x0c022ca0, 0x5a476508, 0x3e182511, 0x47457813,   // fy.da.sv_322 gv.sn.sm_443  eu.ga.rm_653 ve.ln.sn_665 
  // [161a0]
  0x5265100c, 0x0c001505, 0x394c5e02, 0x25091ea4,   // lt.gv.ha_543 un.sv.un_330  ts.wo.br_222 ms.pl.eu_433 
  0x287347ad, 0x044f010c, 0x0f6547a4, 0x4b506aa4,   // sn.ny.sw_643 en.bi.fi_543  sn.gv.lv_433 haw.fj.mi_433 
  0x0e120cad, 0x5a182707, 0x04303c04, 0x36484407,   // sv.hu.is_643 gd.ga.sm_432  ug.uz.ru_332 kk.tt.ab_432 
  0x0c532ca7, 0x030c04ee, 0x35253012, 0x63080c12,   // fy.ht.sv_532 fi.sv.nl_422  uz.mn.tg_654 sv.no.sco_654 
  // [161b0]
  0x130560ec, 0x63370105, 0x02130807, 0x53004b04,   // vo.fr.et_644 en.st.sco_333  no.et.da_432 mi.ht.un_320 
  0x0f226004, 0x0415150d, 0x2c031307, 0x070408ec,   // vo.oc.lv_332 un.ru.un_540  et.nl.fy_432 uk.ru.bg_644 
  0x233c3ba4, 0x302311a7, 0x0d005b0e, 0x1f2c3f0b,   // ks.ug.ky_433 ro.ky.uz_532  sg.cs.un_550 af.fy.cy_542 
  0x0a00231b, 0x15003712, 0x04363811, 0x0d0b3605,   // ca.pt.un_770 ba.un.un_640  tk.gn.fi_653 gn.es.cs_333 
  // [161c0]
  0x0e00521b, 0x1001fcee, 0x020e2e14, 0x0e00540d,   // ha.is.un_770 zzp.en.lt_422  fo.is.da_666 ik.is.un_540 
  0x04002312, 0x1d115807, 0x34213daf, 0x3b5958ec,   // ky.ru.un_640 om.ro.la_432  ku.fa.ps_655 om.rn.so_644 
  0x0e003e13, 0x1d3b58ad, 0x113b5811, 0x22005205,   // rm.is.un_650 om.so.la_643  om.so.ro_653 ha.oc.un_330 
  0x04083ca0, 0x53004b0d, 0x0e00790d, 0x31000405,   // ug.uk.ru_322 mi.ht.un_540  war.is.un_540 fi.az.un_330 
  // [161d0]
  0x46790e07, 0x093b58ee, 0x2304085a, 0x12000b05,   // is.war.qu_432 om.so.pl_422  uk.ru.ky_553 es.hu.un_330 
  0x49005804, 0x1d5a110c, 0x58001112, 0x5e000813,   // om.to.un_320 ro.sm.la_543  ro.om.un_640 no.ts.un_650 
  0x1c004619, 0x12002b07, 0x391761ee, 0x3f0b0107,   // qu.id.un_750 vi.hu.un_420  za.sr.br_422 en.es.af_432 
  0x35fe5d07, 0x1ffe600c, 0x35470a0c, 0x21494002,   // ss.tlh.zu_432 vo.tlh.cy_543  pt.sn.zu_543 lb.to.jw_222 
  // [161e0]
  0x25735207, 0x114230a4, 0x1d3b42a4, 0x036779ad,   // ha.ny.eu_432 uz.co.ro_433  co.so.la_433 war.ak.nl_643 
  0x28521c0c, 0x40033f12, 0x0f002205, 0x1f00611a,   // id.ha.sw_543 af.nl.lb_654  oc.lv.un_330 za.cy.un_760 
  0x18233412, 0x380c1a07, 0x06220702, 0x47355daf,   // ps.ky.ar_654 tl.sv.tk_432  it.oc.de_222 ss.zu.sn_655 
  0x481b38a9, 0x4a0e2e02, 0x61220aa9, 0x26595505,   // tk.tr.tt_544 fo.is.yo_222  pt.oc.za_544 rw.rn.ia_333 
  // [161f0]
  0x304804a0, 0x39470a0d, 0x2100010d, 0x5d3547a4,   // ru.tt.uz_322 pt.sn.br_554  en.jw.un_540 sn.zu.ss_433 
  0x0d5d0aad, 0x545101a0, 0x13580412, 0x23081704,   // pt.ss.cs_643 en.kl.ik_322  fi.om.et_654 sr.uk.ky_332 
  0x15253c12, 0x4648380c, 0x48382da0, 0x0a222360,   // ug.mn.un_654 tk.tt.qu_543  sk.tk.tt_322 ca.oc.pt_664 
  0x48001112, 0x54311ba4, 0x201923a9, 0x38483012,   // ro.tt.un_640 tr.az.ik_433  ca.gl.sq_544 uz.tt.tk_654 
  // [16200]
  0x1b0e31a4, 0xfc5e370d, 0x303802ee, 0x2f2521a0,   // az.is.tr_433 st.ts.zzp_554  da.tk.uz_422 jw.eu.su_322 
  0x2700650c, 0x2e5102ad, 0x061b49ee, 0x31480b04,   // gv.gd.un_530 da.kl.fo_643  to.tr.de_422 es.tt.az_332 
  0x10001b04, 0x31003023, 0x311b2ea0, 0x480e2e09,   // tr.lt.un_320 uz.az.un_880  fo.tr.az_322 fo.is.tt_444 
  0x64554ca4, 0x763e1d04, 0x1b0e3108, 0x68006421,   // wo.rw.lg_433 la.rm.crs_332  az.is.tr_443 lg.ig.un_860 
  // [16210]
  0x48313808, 0x21396807, 0x31483004, 0x4a00020e,   // tk.az.tt_443 ig.br.jw_432  uz.tt.az_332 da.yo.un_550 
  0x5d646808, 0x39002a35, 0x0a122f02, 0x2000570e,   // ig.lg.ss_443 bo.dz.un_A90  su.hu.pt_222 na.sq.un_550 
  0x073e42ee, 0x460e42ad, 0x4e005c0e, 0x07224fa4,   // co.rm.it_422 co.is.qu_643  sa.ay.un_550 bi.oc.it_433 
  0x20003e08, 0x2f201cee, 0x4a3e2413, 0x343c44a0,   // rm.sq.un_430 id.sq.su_422  eo.rm.yo_665 kk.ug.ps_322 
  // [16220]
  0x07354804, 0x6b211c04, 0x04003904, 0x79000a0d,   // tt.tg.bg_332 id.jw.ceb_332  br.fi.un_320 pt.war.un_540 
  0x2b4626a7, 0x024311ad, 0x31575607, 0x3e001c13,   // ia.qu.vi_532 ro.ie.da_643  mg.na.az_432 id.rm.un_650 
  0x011d67a6, 0x1b2b63a4, 0x2118340b, 0x64313007,   // ak.la.en_521 sco.vi.tr_433  ps.ar.fa_542 uz.az.lg_432 
  0x554759a4, 0x2d003613, 0x123d30a4, 0x1517110c,   // rn.sn.rw_433 gn.sk.un_650  uz.ku.ur_433 ro.sr.un_543 
  // [16230]
  0x2e0e38af, 0x2e0e38ad, 0x02000e12, 0x38006223,   // tk.is.fo_655 tk.is.fo_643  is.da.un_640 kha.tk.un_880 
  0x10443812, 0x025c5307, 0x02003822, 0x62003819,   // tk.kk.be_654 ht.sa.da_432  tk.da.un_870 tk.kha.un_750 
  0x0b121907, 0x190960c1, 0x62003822, 0x4c001908,   // gl.hu.es_432 vo.pl.gl_942  tk.kha.un_870 gl.wo.un_430 
  0x1a595513, 0x2d381208, 0x44383ca9, 0x12382d0c,   // rw.rn.tl_665 hu.tk.sk_443  ug.tk.kk_544 sk.tk.hu_543 
  // [16240]
  0x78284c0c, 0x0b193608, 0x2f1a6b11, 0x4a00601b,   // wo.sw.ve_543 gn.gl.es_443  ceb.tl.su_653 vo.yo.un_770 
  0x2f2112a4, 0x623f510c, 0x52004d23, 0x4d4c51a4,   // hu.jw.su_433 kl.af.kha_543  aa.ha.un_880 kl.wo.aa_433 
  0x3f001204, 0x2f57120c, 0x65033f12, 0x60676412,   // hu.af.un_320 hu.na.su_543  af.nl.gv_654 lg.ak.vo_654 
  0x0e022e02, 0x5113030c, 0x3b4d6507, 0x4d511313,   // fo.da.is_222 nl.et.kl_543  gv.aa.so_432 et.kl.aa_665 
  // [16250]
  0x61122d08, 0x124d61a9, 0x033643a0, 0x4d006114,   // sk.hu.za_443 za.aa.hu_544  ie.gn.nl_322 za.aa.un_660 
  0x2d000108, 0x1c4d2f14, 0x1a122d11, 0x46001f0d,   // en.sk.un_430 su.aa.id_666  sk.hu.tl_653 cy.qu.un_540 
  0x1c1a1212, 0x76691ca4, 0x1d5528a6, 0x65135108,   // hu.tl.id_654 id.mfe.crs_433  sw.rw.la_521 kl.et.gv_443 
  0x5800470d, 0x033f510b, 0x033f580c, 0x51004d0d,   // sn.om.un_540 kl.af.nl_542  om.af.nl_543 aa.kl.un_540 
  // [16260]
  0x44374811, 0x441536ad, 0x35384455, 0x121d0d04,   // tt.ba.kk_653 ab.kk.un_630  kk.tk.tg_442 cs.la.hu_332 
  0x452f0512, 0x122830a4, 0x35153055, 0x52002008,   // fr.su.ln_654 uz.sd.ur_433  uz.tg.un_420 sq.ha.un_430 
  0x6a494bec, 0x0f1d4b07, 0x0f004b1b, 0x352530ad,   // mi.to.haw_644 mi.la.lv_432  mi.lv.un_770 uz.mn.tg_643 
  0x3903020c, 0x35300aa7, 0x170725a7, 0x07005a0c,   // da.nl.br_543 mk.uz.tg_532  mn.bg.sr_532 sm.it.un_530 
  // [16270]
  0x12213ba0, 0x582d6502, 0x05002c0c, 0x080a0404,   // ks.fa.ur_322 gv.sk.om_222  fy.fr.un_530 ru.mk.uk_332 
  0x2d0d19a0, 0x28343ba0, 0x150435a4, 0x230a0755,   // gl.cs.sk_322 ks.ps.sd_322  tg.ru.un_433 bg.mk.ky_442 
  0x79000a19, 0x5649360c, 0x301715a4, 0x203b21ac,   // pt.war.un_750 gn.to.mg_543  un.sr.uz_433 jw.so.sq_632 
  0x3e1343a0, 0x64383607, 0x10043508, 0x362d5605,   // ie.et.rm_322 gn.tk.lg_432  tg.ru.be_443 mg.sk.gn_333 
  // [16280]
  0x023e460c, 0x73024708, 0x3b00582b, 0x493b5807,   // qu.rm.da_543 sn.da.ny_443  om.so.un_980 om.so.to_432 
  0x4711580c, 0x33001f08, 0x02683ba6, 0x02466213,   // om.ro.sn_543 cy.nn.un_430  so.ig.da_521 kha.qu.da_665 
  0x2e020ea6, 0x11005808, 0x58023b12, 0x2d3435ee,   // is.da.fo_521 om.ro.un_430  so.da.om_654 zu.xh.sk_422 
  0x5c5dfc09, 0x1744350b, 0x651d1507, 0x170925a7,   // zzp.ss.sa_444 tg.kk.sr_542  un.la.gv_432 eu.pl.sr_532 
  // [16290]
  0x69005b0e, 0x4a001308, 0x23001302, 0x52475d0b,   // sg.mfe.un_550 et.yo.un_430  et.ca.un_220 ss.sn.ha_542 
  0x322a09a4, 0x1e004a19, 0x05006508, 0x0b434005,   // pl.mt.bs_433 yo.ms.un_750  gv.fr.un_430 lb.ie.es_333 
  0x29204a13, 0x5f0220af, 0x36291704, 0x49366aee,   // yo.sq.sl_665 sq.da.tn_655  sr.sl.gn_332 haw.gn.to_422 
  0x20001014, 0x17002d12, 0x39373ea4, 0x4b5d4704,   // lt.sq.un_660 sk.sr.un_640  rm.st.br_433 sn.ss.mi_332 
  // [162a0]
  0x5d2952a7, 0x0b002d0d, 0x512f02ee, 0x15651211,   // ha.sl.ss_532 sk.es.un_540  da.su.kl_422 hu.gv.un_653 
  0x022012a9, 0x0d002002, 0x03000707, 0x330830ee,   // hu.sq.da_544 sq.cs.un_220  it.nl.un_420 uz.no.nn_422 
  0x021d0ca4, 0x44152309, 0x13095ca7, 0x332e0802,   // sv.la.da_433 ky.kk.un_440  sa.hi.bh_532 no.fo.nn_222 
  0x21022905, 0x162d2007, 0x202902ee, 0x1d074213,   // sl.da.jw_333 sq.sk.hr_432  da.sl.sq_422 co.it.la_665 
  // [162b0]
  0x58471d07, 0x0b002002, 0x51002902, 0x16000a04,   // la.sn.om_432 sq.es.un_220  sl.kl.un_220 pt.hr.un_320 
  0x0f002e05, 0x350a1760, 0x482304ee, 0x020e2ea9,   // fo.lv.un_330 sr.mk.tg_664  ru.ky.tt_422 fo.is.da_544 
  0x15030107, 0x65fc0113, 0x1f003b02, 0x08103611,   // en.nl.un_432 en.zzp.gv_665  so.cy.un_220 ab.be.uk_653 
  0x15021305, 0x016b65a0, 0x79074dee, 0x30253c0c,   // et.da.un_333 gv.ceb.en_322  aa.it.war_422 ug.mn.uz_543 
  // [162c0]
  0x0f1173a9, 0x644d070c, 0x311b3002, 0x3957730c,   // ny.ro.lv_544 it.aa.lg_543  uz.tr.az_222 ny.na.br_543 
  0x04380e04, 0x2a366555, 0x25005a04, 0x5e2578a9,   // is.tk.fi_332 gv.gn.mt_442  sm.eu.un_320 ve.eu.ts_544 
  0x1a004f08, 0x4a0204a4, 0x07586509, 0x25005205,   // bi.tl.un_430 fi.da.yo_433  gv.om.it_444 ha.eu.un_330 
  0x2e020e13, 0x52020ea4, 0x523b64ad, 0x11061fa4,   // is.da.fo_665 is.da.ha_433  lg.so.ha_643 cy.de.ro_433 
  // [162d0]
  0x3b0264a7, 0x58003b21, 0x49005808, 0x5c12640b,   // lg.da.so_532 so.om.un_860  om.to.un_430 lg.hu.sa_542 
  0x30343d12, 0x127625a4, 0x390722a4, 0x251119ee,   // ku.ps.uz_654 eu.crs.hu_433  oc.it.br_433 gl.ro.eu_422 
  0x64005214, 0x07641511, 0x424d07a4, 0x5c640712,   // ha.lg.un_660 un.lg.it_653  it.aa.co_433 it.lg.sa_654 
  0x34121810, 0x2548560d, 0x020e2007, 0x073015a4,   // ar.ur.ps_642 mg.tt.eu_554  sq.is.da_432 un.uz.bg_433 
  // [162e0]
  0x3b00040c, 0x36574c12, 0x79480412, 0x33000211,   // fi.so.un_530 wo.na.gn_654  fi.tt.war_654 da.nn.un_630 
  0x30253704, 0x794804ad, 0x384815a4, 0x084810a4,   // ba.mn.uz_332 fi.tt.war_643  un.tt.tk_433 be.tt.uk_433 
  0x4c28780d, 0x170708a0, 0x040a08ee, 0x69605112,   // ve.sw.wo_554 uk.bg.sr_322  uk.mk.ru_422 kl.vo.mfe_654 
  0x112f4a0c, 0x546051af, 0x4d0246ad, 0x191368a7,   // yo.su.ro_543 kl.vo.ik_655  qu.da.aa_643 ig.et.gl_532 
  // [162f0]
  0x12006021, 0x381b5309, 0x12006034, 0x1d4b5107,   // vo.hu.un_860 ht.tr.tk_444  vo.hu.un_A80 kl.mi.la_432 
  0x4300510d, 0x53601c07, 0x36024e04, 0x483060a9,   // kl.ie.un_540 id.vo.ht_432  ay.da.gn_332 vo.uz.tt_544 
  0x214c1c02, 0x1d114ba0, 0x1a4d60ad, 0x4b2551a9,   // id.wo.jw_222 mi.ro.la_322  vo.aa.tl_643 kl.eu.mi_544 
  0x1b1e21a4, 0x28004207, 0x35735808, 0x36251d07,   // jw.ms.tr_433 co.sw.un_420  om.ny.zu_443 la.eu.gn_432 
  // [16300]
  0x23070204, 0x46005712, 0x69121ea4, 0x314d12a9,   // da.it.ca_332 na.qu.un_640  ms.hu.mfe_433 hu.aa.az_544 
  0x1d000918, 0x1e002702, 0x09111d0b, 0x69004d0c,   // pl.la.un_740 gd.ms.un_220  la.ro.pl_542 aa.mfe.un_530 
  0x19432512, 0x5100602c, 0x15001914, 0x074227ac,   // eu.ie.gl_654 vo.kl.un_990  gl.un.un_660 gd.co.it_632 
  0x21601c0c, 0x42092508, 0x211c60a9, 0x46557307,   // id.vo.jw_543 eu.pl.co_443  vo.id.jw_544 ny.rw.qu_432 
  // [16310]
  0x0e002002, 0x25181d02, 0x34464d04, 0x01fc1d05,   // sq.is.un_220 la.ga.eu_222  aa.qu.xh_332 la.zzp.en_333 
  0x36007305, 0x512f28a0, 0x1e4c73a0, 0x27091f07,   // ny.gn.un_330 sw.su.kl_322  ny.wo.ms_322 cy.pl.gd_432 
  0x19003505, 0x57561daf, 0x25001d07, 0x285451a4,   // zu.gl.un_330 la.mg.na_655  la.eu.un_420 kl.ik.sw_433 
  0x05001909, 0x34303d0e, 0x254c190c, 0x2800510d,   // gl.fr.un_440 ku.uz.ps_555  gl.wo.eu_543 kl.sw.un_540 
  // [16320]
  0x0444370c, 0x20004c0e, 0x463621a4, 0x1f1038ad,   // ba.kk.ru_543 wo.sq.un_550  jw.gn.qu_433 tk.lt.cy_643 
  0x15150704, 0x15003805, 0x34002309, 0x4c002022,   // bg.un.un_320 tk.un.un_330  ky.ps.un_440 sq.wo.un_870 
  0x04083c07, 0x0f0410ec, 0x042338a0, 0x17004811,   // ug.uk.ru_432 lt.fi.lv_644  tk.ky.ru_322 tt.sr.un_630 
  0x09003819, 0x5600382a, 0x213d3b0b, 0x170a11a0,   // tk.pl.un_750 tk.mg.un_970  ks.ku.fa_542 ro.mk.sr_322 
  // [16330]
  0x3400212b, 0x4d1a3b09, 0x442128ee, 0xfc1d4f02,   // fa.ps.un_980 so.tl.aa_444  sd.fa.kk_422 bi.la.zzp_222 
  0x01795104, 0x40653f02, 0x055540a0, 0x282a61a7,   // kl.war.en_332 af.gv.lb_222  lb.rw.fr_322 za.mt.sw_532 
  0x423f0302, 0x0e5c040d, 0x25353011, 0x040e4707,   // nl.af.co_222 fi.sa.is_554  uz.tg.mn_653 sn.is.fi_432 
  0x47000302, 0x347347a9, 0x1d50fcaf, 0x25563ea9,   // nl.sn.un_220 sn.ny.xh_544  zzp.fj.la_655 rm.mg.eu_544 
  // [16340]
  0x3c170aa6, 0x57001f19, 0x291b01a0, 0x103004ad,   // mk.sr.ug_521 cy.na.un_750  en.tr.sl_322 fi.uz.lt_643 
  0x07083507, 0x3000790d, 0x04182704, 0x0a4817a4,   // tg.uk.bg_432 war.uz.un_540  gd.ga.fi_332 sr.tt.mk_433 
  0x392404a0, 0xfc001302, 0x2c40040c, 0x182328ec,   // fi.eo.br_322 et.zzp.un_220  fi.lb.fy_543 sd.ky.ar_644 
  0x0267010b, 0x343b0407, 0x680235a4, 0x3008070e,   // en.ak.da_542 fi.so.xh_432  zu.da.ig_433 bg.uk.uz_555 
  // [16350]
  0x634f02a0, 0x033f620c, 0x3b005209, 0x3800580e,   // da.bi.sco_322 kha.af.nl_543  ha.so.un_440 om.tk.un_550 
  0x0f004b13, 0x46190ba7, 0x65024c55, 0x39025dec,   // mi.lv.un_650 es.gl.qu_532  wo.da.gv_442 ss.da.br_644 
  0x230804a4, 0x3b3421ac, 0x18303404, 0x050b5304,   // ru.uk.ky_433 fa.ps.ks_632  ps.uz.ar_332 ht.es.fr_332 
  0x042515ee, 0x1f005307, 0x4700fe0c, 0x76005313,   // un.mn.ru_422 ht.cy.un_420  tlh.sn.un_530 ht.crs.un_650 
  // [16360]
  0x5f003704, 0x08332eb2, 0x76005319, 0x64475da0,   // st.tn.un_320 fo.nn.no_732  ht.crs.un_750 ss.sn.lg_322 
  0x22002721, 0x230430ee, 0x321665a4, 0x53017507,   // gd.oc.un_860 uz.ru.ky_422  gv.hr.bs_433 nso.en.ht_432 
  0x12034c07, 0x024737ee, 0x4500530d, 0x21283c04,   // wo.nl.hu_432 st.sn.da_422  ht.ln.un_540 ug.sd.fa_332 
  0x25443ca9, 0x42002f08, 0x0a0738a6, 0x2f655aa7,   // ug.kk.mn_544 su.co.un_430  tk.bg.mk_521 sm.gv.su_532 
  // [16370]
  0x032f5a07, 0x3044370b, 0x0a00480d, 0x23224812,   // sm.su.nl_432 ba.kk.uz_542  tt.pt.un_540 tt.oc.ca_654 
  0x23224813, 0x380a480b, 0x0a002209, 0x0a4838a4,   // tt.oc.ca_665 tt.pt.tk_542  oc.pt.un_440 tk.tt.pt_433 
  0x221b48ee, 0x230a48af, 0x06120eac, 0x5c1c0d11,   // tt.tr.oc_422 tt.pt.ca_655  is.hu.de_632 ne.mr.sa_653 
  0x4d1f1808, 0x0a2247a4, 0x1f2015a0, 0x2000471a,   // ga.cy.aa_443 sn.oc.pt_433  un.sq.cy_322 sn.sq.un_760 
  // [16380]
  0x190a20a0, 0x0618790c, 0x1f5cfea4, 0x1200670c,   // sq.pt.gl_322 war.ga.de_543  tlh.sa.cy_433 ak.hu.un_530 
  0x5d344712, 0x27653ea4, 0x606501a0, 0x68004c12,   // sn.xh.ss_654 rm.gv.gd_433  en.gv.vo_322 wo.ig.un_640 
  0x19230aee, 0x2d00220c, 0x463020a9, 0x3b005802,   // pt.ca.gl_422 oc.sk.un_530  sq.uz.qu_544 om.so.un_220 
  0xfc5e01a4, 0x37005d02, 0x26005e09, 0x085605a0,   // en.ts.zzp_433 ss.st.un_220  ts.ia.un_440 fr.mg.no_322 
  // [16390]
  0x5b02390c, 0x1f2802ee, 0x390365a0, 0x36002011,   // br.da.sg_543 da.sw.cy_422  gv.nl.br_322 sq.gn.un_630 
  0x02222305, 0x0600051a, 0x2500650c, 0x40023ba0,   // ca.oc.da_333 fr.de.un_760  gv.eu.un_530 so.da.lb_322 
  0x2e06330c, 0x051939a0, 0x575f2e5a, 0x18003904,   // nn.de.fo_543 br.gl.fr_322  fo.tn.na_553 br.ga.un_320 
  0x47110e55, 0x120553ad, 0x0e2e010c, 0x181f0507,   // is.ro.sn_442 ht.fr.hu_643  en.fo.is_543 fr.cy.ga_432 
  // [163a0]
  0x1d6506a9, 0x062349ad, 0x026540a4, 0x0c001005,   // de.gv.la_544 to.ca.de_643  lb.gv.da_433 lt.sv.un_330 
  0x3e1813af, 0x062e33a9, 0x0b65050c, 0x050a12ad,   // et.ga.rm_655 nn.fo.de_544  fr.gv.es_543 hu.pt.fr_643 
  0x2e0a0e0e, 0x135001a0, 0x4b135a0d, 0x39495a0d,   // is.pt.fo_555 en.fj.et_322  sm.et.mi_554 sm.to.br_554 
  0x3c34440b, 0x3523380c, 0x384804ec, 0x38003719,   // kk.ps.ug_542 tk.ky.tg_543  fi.tt.tk_644 ba.tk.un_750 
  // [163b0]
  0x04004820, 0x30353cec, 0x15002c02, 0x13004d0d,   // tt.fi.un_850 ug.tg.uz_644  fy.un.un_220 aa.et.un_540 
  0x314820a0, 0x0e3217a6, 0x4804380c, 0x13003e0c,   // sq.tt.az_322 sr.bs.is_521  tk.fi.tt_543 rm.et.un_530 
  0x0a071509, 0x0e0c3e04, 0x2700130c, 0x1100481a,   // un.bg.mk_444 rm.sv.is_332  et.gd.un_530 tt.ro.un_760 
  0x4a2d0d04, 0x19360d07, 0x2a5c0fad, 0x343c18a7,   // cs.sk.yo_332 cs.gn.gl_432  lv.sa.mt_643 ar.ug.ps_532 
  // [163c0]
  0x35002c0e, 0x1b000a02, 0x07374855, 0x253738a6,   // fy.zu.un_550 pt.tr.un_220  tt.ba.bg_442 tk.ba.mn_521 
  0x0200670e, 0x3900300c, 0x1258510c, 0x64020907,   // ak.da.un_550 uz.br.un_530  kl.om.hu_543 pl.da.lg_432 
  0x1d0934a0, 0x17000904, 0x0c293008, 0x5c0147a7,   // xh.pl.la_322 pl.sr.un_320  uz.sl.sv_443 sn.en.sa_532 
  0x071530a7, 0x4b006402, 0x04100704, 0x090c3607,   // uz.bg.un_520 lg.mi.un_220  bg.be.ru_332 gn.sv.pl_432 
  // [163d0]
  0x29302507, 0x21466504, 0x364612ee, 0x0e0c02a4,   // eu.uz.sl_432 gv.qu.jw_332  hu.qu.gn_422 da.sv.is_433 
  0x344709a9, 0x2a042d07, 0x0f001207, 0x38005302,   // pl.sn.xh_544 sk.fi.mt_432  hu.lv.un_420 ht.tk.un_220 
  0x6b002608, 0x65045ca0, 0x21000409, 0x080936a0,   // ia.ceb.un_430 sa.fi.gv_322  fi.jw.un_440 gn.pl.no_322 
  0x122821a7, 0x04231004, 0x08003302, 0x12190bad,   // fa.sd.ur_532 be.ky.ru_332  nn.no.un_220 es.gl.hu_643 
  // [163e0]
  0x232530ec, 0x3823300e, 0x08332e60, 0x33082e16,   // uz.mn.ky_644 uz.ky.tk_555  fo.nn.no_664 fo.no.nn_752 
  0x10234808, 0x0a3536ee, 0x303d21af, 0x35302514,   // tt.ky.be_443 ab.tg.mk_422  fa.ku.uz_655 mn.uz.tg_666 
  0x1548040d, 0x31003207, 0x6400fc09, 0x0400450c,   // ru.tt.un_554 bs.az.un_420  zzp.lg.un_440 ln.fi.un_530 
  0x1b736204, 0x080a4804, 0x6b321d07, 0x4d6a5112,   // kha.ny.tr_332 tt.mk.uk_332  la.bs.ceb_432 kl.haw.aa_654 
  // [163f0]
  0x63001205, 0x213c18ee, 0x12000719, 0x58044aad,   // hu.sco.un_330 ar.ug.fa_422  it.hu.un_750 yo.fi.om_643 
  0x11073805, 0x1715100b, 0x2b003804, 0x01656304,   // tk.bg.ro_333 be.sr.un_520  tk.vi.un_320 sco.gv.en_332 
  0x15002f07, 0x04005208, 0x24006712, 0x1e3b52ee,   // su.un.un_420 ha.fi.un_430  ak.eo.un_640 ha.so.ms_422 
  0x3b0958a0, 0x091d58ad, 0x36004d0c, 0x28002704,   // om.pl.so_322 om.la.pl_643  aa.gn.un_530 gd.sw.un_320 
  
  // [16400]
  0x0a00790c, 0x10253812, 0x05000407, 0x27002502,   // war.pt.un_530 tk.mn.be_654  fi.fr.un_420 eu.gd.un_220 
  0x09001d07, 0x17484409, 0x3f355804, 0x580f12ee,   // la.pl.un_420 kk.tt.sr_444  om.zu.af_332 hu.lv.om_422 
  0x245c5804, 0x30233855, 0x10041560, 0x496b7907,   // om.sa.eo_332 tk.ky.uz_442  un.ru.be_664 war.ceb.to_432 
  0x04110807, 0x01650302, 0x08004812, 0x0d2512a7,   // uk.ro.ru_432 nl.gv.en_222  tt.uk.un_640 hu.eu.cs_532 
  // [16410]
  0x23605713, 0x4a3560a0, 0x1800020d, 0x5c0458a4,   // na.vo.ca_665 vo.zu.yo_322  da.ga.un_540 om.fi.sa_433 
  0x123430a4, 0x0f1210a9, 0x23002218, 0xfe2b6e12,   // uz.ps.ur_433 lt.hu.lv_544  oc.ca.un_740 hmn.vi.tlh_654 
  0x0f381012, 0x2b00fe0d, 0x3f404c12, 0x29000d11,   // lt.tk.lv_654 tlh.vi.un_540  wo.lb.af_654 cs.sl.un_630 
  0x420911a6, 0x6e002b2a, 0x47065ea9, 0x2dfe2912,   // ro.pl.co_521 vi.hmn.un_970  ts.de.sn_544 sl.tlh.sk_654 
  // [16420]
  0x5d356e12, 0x0a0456a7, 0x5604520c, 0x38040cec,   // hmn.zu.ss_654 mg.fi.pt_532  ha.fi.mg_543 sv.fi.tk_644 
  0x5d2835a9, 0x46351c07, 0x10172d07, 0x567301a0,   // zu.sw.ss_544 id.zu.qu_432  sk.sr.lt_432 en.ny.mg_322 
  0x040a23ee, 0x5d73560c, 0x28343ba9, 0x3b3f0314,   // ky.mk.ru_422 mg.ny.ss_543  ks.ps.sd_544 nl.af.so_666 
  0x33004f19, 0x24063f09, 0x5543240c, 0x2c3b560c,   // bi.nn.un_750 af.de.eo_444  eo.ie.rw_543 mg.so.fy_543 
  // [16430]
  0x25101555, 0x29577304, 0x34213d09, 0x21002e05,   // un.be.mn_442 ny.na.sl_332  ku.fa.ps_444 fo.jw.un_330 
  0x2900fe08, 0x21fc0607, 0x021001a0, 0x103f65a0,   // tlh.sl.un_430 de.zzp.jw_432  en.lt.da_322 gv.af.lt_322 
  0x73004e0d, 0x132d04a4, 0x52464f5a, 0x10006513,   // ay.ny.un_540 fi.sk.et_433  bi.qu.ha_553 gv.lt.un_650 
  0x080c530c, 0x23150411, 0x230e22ec, 0x332a6307,   // ht.sv.no_543 ru.ky.un_630  oc.is.ca_644 sco.mt.nn_432 
  // [16440]
  0x1f0465a9, 0x28003919, 0x07081007, 0x39002805,   // gv.fi.cy_544 br.sw.un_750  be.uk.bg_432 sw.br.un_330 
  0x356b57ee, 0x65001109, 0x5f6537a9, 0x64006813,   // na.ceb.zu_422 ro.gv.un_440  st.gv.tn_544 ig.lg.un_650 
  0x2134fe12, 0x1c481e08, 0x03511b08, 0x0b48510c,   // tlh.xh.jw_654 ms.tt.id_443  tr.kl.nl_443 kl.tt.es_543 
  0x5f000808, 0x5c211304, 0x46fc38ad, 0x65005112,   // no.tn.un_430 et.jw.sa_332  tk.zzp.qu_643 kl.gv.un_640 
  // [16450]
  0x2e080255, 0x481b2da0, 0x795c3e07, 0x3c003613,   // da.no.fo_442 sk.tr.tt_322  rm.sa.war_432 ab.ug.un_650 
  0x44172304, 0x25210e05, 0x3430230b, 0x2a423e0c,   // ky.sr.kk_332 is.jw.eu_333  ky.uz.ps_542 rm.co.mt_543 
  0x38300e07, 0x1d481b0c, 0x5c12480c, 0x31190b11,   // is.uz.tk_432 tr.tt.la_543  tt.hu.sa_543 es.gl.az_653 
  0x5268600e, 0x23003612, 0x082507ee, 0x381b48a4,   // vo.ig.ha_555 ab.ky.un_640  bg.mn.uk_422 tt.tr.tk_433 
  // [16460]
  0x13370107, 0xfc311b05, 0x462051a0, 0x654840a7,   // en.st.et_432 tr.az.zzp_333  kl.sq.qu_322 lb.tt.gv_532 
  0x2e045ca4, 0x06483855, 0xfc511f55, 0x300413a0,   // sa.fi.fo_433 tk.tt.de_442  cy.kl.zzp_442 et.fi.uz_322 
  0x2c00031b, 0x30070aec, 0x374415ee, 0x23001113,   // nl.fy.un_770 mk.bg.uz_644  un.kk.ba_422 ro.ky.un_650 
  0x373530ee, 0x4a002f04, 0x0d003809, 0x25002007,   // uz.tg.ba_422 su.yo.un_320  tk.cs.un_440 sq.eu.un_420 
  // [16470]
  0x11006308, 0x2f003f1a, 0x49001107, 0x6a285a04,   // sco.ro.un_430 af.su.un_760  ro.to.un_420 sm.sw.haw_332 
  0x0b00562b, 0x2344210e, 0x04101512, 0x532827a0,   // mg.es.un_980 fa.kk.ky_555  un.be.ru_654 gd.sw.ht_322 
  0x30fe4c04, 0x1304580c, 0x7931fe0c, 0x4d281d0c,   // wo.tlh.uz_332 om.fi.et_543  tlh.az.war_543 la.sw.aa_543 
  0x3e100460, 0x30630107, 0x1d002702, 0x0bfe4c0c,   // fi.lt.rm_664 en.sco.uz_432  gd.la.un_220 wo.tlh.es_543 
  // [16480]
  0x13045805, 0x04695c0c, 0x0556430c, 0x2713400c,   // om.fi.et_333 sa.mfe.fi_543  ie.mg.fr_543 lb.et.gd_543 
  0x0409fc12, 0x533138a6, 0x5c21fc09, 0xfe004c13,   // zzp.pl.fi_654 tk.az.ht_521  zzp.jw.sa_444 wo.tlh.un_650 
  0x475c0412, 0x19271d07, 0x04643412, 0xfc345c13,   // fi.sa.sn_654 la.gd.gl_432  xh.lg.fi_654 sa.xh.zzp_665 
  0x3f001009, 0x1d4e0b0c, 0x3e56420c, 0x654027a0,   // lt.af.un_440 es.ay.la_543  co.mg.rm_543 gd.lb.gv_322 
  // [16490]
  0x13002414, 0x3100fe1a, 0x38641b0c, 0x19300bad,   // eo.et.un_660 tlh.az.un_760  tr.lg.tk_543 es.uz.gl_643 
  0x096402a9, 0x025cfc12, 0x53004c19, 0x211b3109,   // da.lg.pl_544 zzp.sa.da_654  wo.ht.un_750 az.tr.jw_444 
  0xfe56010c, 0x5e550807, 0x1a00791a, 0x07100411,   // en.mg.tlh_543 no.rw.ts_432  war.tl.un_760 fi.lt.it_653 
  0x3e2b070c, 0x0400101b, 0x10003419, 0x313e2507,   // it.vi.rm_543 lt.fi.un_770  xh.lt.un_750 eu.rm.az_432 
  // [164a0]
  0x1a002802, 0xfc00041b, 0x1a001013, 0x5b02250c,   // sw.tl.un_220 fi.zzp.un_770  lt.tl.un_650 eu.da.sg_543 
  0x5cfc3409, 0x3e261d0d, 0x6934040c, 0x65fc25ad,   // xh.zzp.sa_444 la.ia.rm_554  fi.xh.mfe_543 eu.zzp.gv_643 
  0x27004202, 0x25381ba0, 0x1b591aa4, 0x293009ac,   // co.gd.un_220 tr.tk.eu_322  tl.rn.tr_433 pl.uz.sl_632 
  0x3c444814, 0x3100250e, 0x365559ec, 0x38481b60,   // tt.kk.ug_666 eu.az.un_550  rn.rw.gn_644 tr.tt.tk_664 
  // [164b0]
  0x793121a4, 0x31111bee, 0x36004d0d, 0x0a2d0d0d,   // jw.az.war_433 tr.ro.az_422  aa.gn.un_540 cs.sk.pt_554 
  0x0a492207, 0x45004d08, 0x4a000a05, 0x0d4d2d11,   // oc.to.pt_432 aa.ln.un_430  pt.yo.un_330 sk.aa.cs_653 
  0x35074809, 0x0d494507, 0x48001102, 0x0e4936ee,   // tt.bg.tg_444 ln.to.cs_432  ro.tt.un_220 gn.to.is_422 
  0x0b0a4da0, 0x11005612, 0x44233755, 0x0a190b0b,   // aa.pt.es_322 mg.ro.un_640  ba.ky.kk_442 es.gl.pt_542 
  // [164c0]
  0x0a004d12, 0x1d0b24ec, 0x4a004d0e, 0x3e4207af,   // aa.pt.un_640 eo.es.la_644  aa.yo.un_550 it.co.rm_655 
  0x364a0a04, 0x495c0f12, 0x20001e05, 0x56074207,   // pt.yo.gn_332 lv.sa.to_654  ms.sq.un_330 co.it.mg_432 
  0x2400012b, 0x10004d07, 0x5c0f5a13, 0x2b530305,   // iw.yi.un_980 aa.lt.un_420  sm.lv.sa_665 nl.ht.vi_333 
  0x4b005807, 0x40001b1a, 0x46400605, 0x171809ee,   // om.mi.un_420 tr.lb.un_760  de.lb.qu_333 pl.ga.sr_422 
  // [164d0]
  0x2c00610c, 0x58003607, 0x03006112, 0x5c003307,   // za.fy.un_530 gn.om.un_420  za.nl.un_640 nn.sa.un_420 
  0x4b5658a0, 0x01000a04, 0x0f005c2b, 0x62001e13,   // om.mg.mi_322 pt.en.un_320  sa.lv.un_980 ms.kha.un_650 
  0x0f5c4baf, 0x5c4b0f60, 0x0d005204, 0x0a350704,   // mi.sa.lv_655 lv.mi.sa_664  ha.cs.un_320 bg.tg.mk_332 
  0x35004f08, 0x481b0e07, 0x645a6804, 0x013f03a0,   // bi.zu.un_430 is.tr.tt_432  ig.sm.lg_332 nl.af.en_322 
  // [164e0]
  0xfc2105ee, 0x5c331805, 0x0c05265a, 0x4c330808,   // fr.jw.zzp_422 ga.nn.sa_333  ia.fr.sv_553 no.nn.wo_443 
  0x18630107, 0x181221ee, 0x483831a4, 0x442312a7,   // en.sco.ga_432 fa.ur.ar_422  az.tk.tt_433 ur.ky.kk_532 
  0x12001704, 0x170a23ee, 0x0b00330e, 0x0c13045a,   // sr.hu.un_320 ky.mk.sr_422  as.bn.un_550 fi.et.sv_553 
  0x37003c11, 0x51005821, 0x044811ee, 0x2e020807,   // ug.ba.un_630 om.kl.un_860  ro.tt.ru_422 no.da.fo_432 
  // [164f0]
  0x313848a9, 0x11005112, 0x070804a7, 0x3c2330a9,   // tt.tk.az_544 kl.ro.un_640  ru.uk.bg_532 uz.ky.ug_544 
  0x154448a4, 0x48000419, 0x44342807, 0x56003907,   // tt.kk.un_433 fi.tt.un_750  sd.ps.kk_432 br.mg.un_420 
  0x073011a6, 0x30002008, 0x38006323, 0x21462702,   // ro.uz.bg_521 sq.uz.un_430  sco.tk.un_880 gd.qu.jw_222 
  0x6a00020d, 0x791d5b07, 0x28006504, 0x1f0679a7,   // da.haw.un_540 sg.la.war_432  gv.sw.un_320 war.de.cy_532 
  // [16500]
  0x1f005b22, 0x2d0d3fa4, 0x68002513, 0x42003e02,   // sg.cy.un_870 af.cs.sk_433  eu.ig.un_650 rm.co.un_220 
  0x1e1c68a4, 0x21382c04, 0x273e2b0c, 0x46006013,   // ig.id.ms_433 fy.tk.jw_332  vi.rm.gd_543 vo.qu.un_650 
  0x23044404, 0x062430ee, 0x10000721, 0x20002e14,   // kk.ru.ky_332 uz.eo.de_422  bg.be.un_860 fo.sq.un_660 
  0x44373812, 0x240c0f04, 0x400d050c, 0x73675812,   // tk.ba.kk_654 lv.sv.eo_332  fr.cs.lb_543 om.ak.ny_654 
  // [16510]
  0x5c00fe13, 0x58006213, 0x07103511, 0x04102904,   // tlh.sa.un_650 kha.om.un_650  tg.be.bg_653 sl.lt.fi_332 
  0x2b002713, 0x38004818, 0x30384802, 0x5128580d,   // gd.vi.un_650 tt.tk.un_740  tt.tk.uz_222 om.sw.kl_554 
  0x51005809, 0x08352308, 0x37044705, 0x4200051a,   // om.kl.un_440 ky.tg.uk_443  sn.fi.st_333 fr.co.un_760 
  0x3b4d5812, 0x010305a7, 0xfe3e10ad, 0x22040fee,   // om.aa.so_654 fr.nl.en_532  lt.rm.tlh_643 lv.fi.oc_422 
  // [16520]
  0x042a5855, 0x49580204, 0x35002902, 0x100836a7,   // om.mt.fi_442 da.om.to_332  sl.zu.un_220 ab.uk.be_532 
  0x481360a7, 0x442336ad, 0x3600491a, 0x49361207,   // vo.et.tt_532 ab.ky.kk_643  to.gn.un_760 hu.gn.to_432 
  0x2dfe0d11, 0x08234807, 0x65306305, 0x08252302,   // cs.tlh.sk_653 tt.ky.uk_432  sco.uz.gv_333 ky.mn.uk_222 
  0x171329ee, 0x0c2a290c, 0x380e1b04, 0x28254a11,   // sl.et.sr_422 sl.mt.sv_543  tr.is.tk_332 yo.eu.sw_653 
  // [16530]
  0x1c212fa9, 0x183c23a4, 0x4a002505, 0x4c584907,   // su.jw.id_544 ky.ug.ar_433  eu.yo.un_330 to.om.wo_432 
  0x1c2f4c04, 0x17104860, 0x230a38ee, 0x48005307,   // wo.su.id_332 tt.be.sr_664  tk.mk.ky_422 ht.tt.un_420 
  0x250715a9, 0x2e0e0107, 0x58090da9, 0x17383c0c,   // un.bg.mn_544 en.is.fo_432  cs.pl.om_544 ug.tk.sr_543 
  0x06000408, 0x2d006402, 0x734778af, 0x68353460,   // fi.de.un_430 lg.sk.un_220  ve.sn.ny_655 xh.zu.ig_664 
  // [16540]
  0x531510ad, 0x04004b02, 0x355c59a4, 0x2f001219,   // lt.ht.un_630 mi.fi.un_220  rn.sa.zu_433 hu.su.un_750 
  0x6400550b, 0x2e00330e, 0x23002812, 0x33080302,   // rw.lg.un_520 nn.fo.un_550  sd.ky.un_640 nl.no.nn_222 
  0x0704440c, 0x48373607, 0x1b380daf, 0x253912a9,   // kk.ru.bg_543 ab.ba.tt_432  cs.tk.tr_655 hu.br.eu_544 
  0x29394d08, 0x1b391ca0, 0x32161ea4, 0x2e001104,   // aa.br.sl_443 id.br.tr_322  ms.hr.bs_433 ro.fo.un_320 
  // [16550]
  0x69393f05, 0x396112ac, 0x03061804, 0x39006308,   // af.br.mfe_333 hu.za.br_632  ga.de.nl_332 sco.br.un_430 
  0x3339080c, 0x171504af, 0x02001809, 0x3800310d,   // no.br.nn_543 ru.sr.un_650  ga.da.un_440 az.tk.un_540 
  0x2325440b, 0x020675a4, 0x0d1238a9, 0x4d121ca4,   // kk.mn.ky_542 nso.de.da_433  tk.hu.cs_544 id.hu.aa_433 
  0x18283460, 0x2f1c0908, 0x39120da9, 0x2500390d,   // ps.sd.ar_664 pl.id.su_443  cs.hu.br_544 br.eu.un_540 
  // [16560]
  0x1b121ca4, 0x0d21120c, 0x10040812, 0x251118ee,   // id.hu.tr_433 hu.jw.cs_543  uk.ru.be_654 ga.ro.eu_422 
  0x3d3c230c, 0x190b4b09, 0x380b2307, 0x4369760c,   // ky.ug.ku_543 mi.es.gl_444  ca.es.tk_432 crs.mfe.ie_543 
  0x231169ee, 0x483130a0, 0x1d511aa7, 0xfc5657a6,   // mfe.ro.ca_422 uz.az.tt_322  tl.kl.la_532 na.mg.zzp_521 
  0x3b0b2b0d, 0x46001e08, 0x10043709, 0x4c0163ad,   // vi.es.so_554 ms.qu.un_430  ba.ru.be_444 sco.en.wo_643 
  // [16570]
  0x37480404, 0x1a02790c, 0x6b4c3b0c, 0x2b530107,   // ru.tt.ba_332 war.da.tl_543  so.wo.ceb_543 en.ht.vi_432 
  0x0302fc55, 0x3b4c2ba4, 0x4c630112, 0x40512c55,   // zzp.da.nl_442 vi.wo.so_433  en.sco.wo_654 fy.kl.lb_442 
  0x69004c22, 0x43150111, 0x27002c04, 0x1d00561a,   // wo.mfe.un_870 en.ie.un_630  fy.gd.un_320 mg.la.un_760 
  0x31fe0104, 0x4d2b4c0c, 0x224273a9, 0x3000fe20,   // en.tlh.az_332 wo.vi.aa_543  ny.co.oc_544 tlh.uz.un_850 
  // [16580]
  0x17151105, 0x692bfead, 0x382e6aad, 0x2a001d04,   // ro.sr.un_330 tlh.vi.mfe_643  haw.fo.tk_643 la.mt.un_320 
  0x1b315ea9, 0x4cfe2baf, 0x045146a9, 0x3e6a6b0d,   // ts.az.tr_544 vi.tlh.wo_655  qu.kl.fi_544 ceb.haw.rm_554 
  0x420651a7, 0x50004633, 0xfa005908, 0x2f211608,   // kl.de.co_532 qu.fj.un_A70  rn.nr.un_430 hr.jw.su_443 
  0x025601a0, 0x73524c0c, 0x1d4251ee, 0x04514205,   // en.mg.da_322 wo.ha.ny_543  kl.co.la_422 co.kl.fi_333 
  // [16590]
  0x3e002f07, 0x6400730d, 0x475651a9, 0x253b1ea4,   // su.rm.un_420 ny.lg.un_540  kl.mg.sn_544 ms.so.eu_433 
  0x3800110c, 0x4b56790c, 0x4a643409, 0x28006713,   // ro.tk.un_530 war.mg.mi_543  xh.lg.yo_444 ak.sw.un_650 
  0x48113508, 0x506457ac, 0x202f56a4, 0xfc616408,   // tg.ro.tt_443 na.lg.fj_632  mg.su.sq_433 lg.za.zzp_443 
  0x1f5f375a, 0x5f302d07, 0x45022511, 0x1d1102a6,   // st.tn.cy_553 sk.uz.tn_432  eu.da.ln_653 da.ro.la_521 
  // [165a0]
  0x31003b09, 0x2e5d5008, 0x386452a0, 0x522f45a9,   // so.az.un_440 fj.ss.fo_443  ha.lg.tk_322 ln.su.ha_544 
  0x0d472d07, 0x1b002511, 0x28595505, 0x496a4b13,   // sk.sn.cs_432 eu.tr.un_630  rw.rn.sw_333 mi.haw.to_665 
  0x315b46ec, 0x045d46a0, 0x1a57500c, 0x12565008,   // qu.sg.az_644 qu.ss.fi_322  fj.na.tl_543 fj.mg.hu_443 
  0x33000105, 0x30005005, 0x341223a0, 0x043748a4,   // en.nn.un_330 fj.uz.un_330  ky.ur.ps_322 tt.ba.ru_433 
  // [165b0]
  0x18213cee, 0x50004907, 0x55645e0c, 0x242d0d09,   // ug.fa.ar_422 to.fj.un_420  ts.lg.rw_543 cs.sk.eo_444 
  0x5600551a, 0x6a4b64a9, 0x642159a0, 0x374556af,   // rw.mg.un_760 lg.mi.haw_544  rn.jw.lg_322 mg.ln.st_655 
  0x4d6473a9, 0x3e3156a0, 0x1000330d, 0x130456a9,   // ny.lg.aa_544 mg.az.rm_322  nn.lt.un_540 mg.fi.et_544 
  0x6400452b, 0x2e023eee, 0x115673a4, 0x0f000412,   // ln.lg.un_980 rm.da.fo_422  ny.mg.ro_433 fi.lv.un_640 
  // [165c0]
  0x2460070d, 0x5c53250d, 0x45644d08, 0x5973640c,   // it.vo.eo_554 eu.ht.sa_554  aa.lg.ln_443 lg.ny.rn_543 
  0x490cfca4, 0x1d003605, 0x33003e0d, 0x1a3b7905,   // zzp.sv.to_433 gn.la.un_330  rm.nn.un_540 war.so.tl_333 
  0x024b470c, 0x0b491aa9, 0x13003e26, 0x3e020812,   // sn.mi.da_543 tl.to.es_544  rm.et.un_930 no.da.rm_654 
  0x55280907, 0x5a004b2b, 0x043508a4, 0x28033407,   // pl.sw.rw_432 mi.sm.un_980  uk.tg.ru_433 xh.nl.sw_432 
  // [165d0]
  0x1a5807a0, 0x480425ad, 0x301548ad, 0x481511a9,   // it.om.tl_322 mn.ru.tt_643  tt.uz.un_630 ro.tt.un_540 
  0x33082ea7, 0x6b6a1507, 0x2a761f0c, 0x240302ee,   // fo.no.nn_532 un.haw.ceb_432  cy.crs.mt_543 da.nl.eo_422 
  0x24001f04, 0x35381008, 0x15126707, 0x040836a4,   // cy.eo.un_320 be.tk.tg_443  ak.hu.un_432 ab.uk.ru_433 
  0x303844ad, 0x080e33a0, 0x18303d04, 0x630115ee,   // kk.tk.uz_643 nn.is.no_322  ku.uz.ar_332 un.en.sco_422 
  // [165e0]
  0x0200010c, 0x06130c04, 0x3138430c, 0x10002309,   // en.da.un_530 sv.et.de_332  ie.tk.az_543 ky.be.un_440 
  0x170708af, 0x05001105, 0x391351ee, 0x0e512e0c,   // uk.bg.sr_655 ro.fr.un_330  kl.et.br_422 fo.kl.is_543 
  0x205113a4, 0x38fe3008, 0x0e0b2ea7, 0x4d00360e,   // et.kl.sq_433 uz.tlh.tk_443  fo.es.is_532 gn.aa.un_550 
  0x1a00790e, 0x313038ad, 0x51001307, 0x381b3005,   // war.tl.un_550 tk.uz.az_643  et.kl.un_420 uz.tr.tk_333 
  // [165f0]
  0x4600360c, 0x484c380e, 0x18123404, 0x381b5108,   // gn.qu.un_530 tk.wo.tt_555  ps.ur.ar_332 kl.tr.tk_443 
  0x1b2e380c, 0x51002007, 0x30342813, 0x473152a0,   // tk.fo.tr_543 sq.kl.un_420  sd.ps.uz_665 ha.az.sn_322 
  0x133f4ca7, 0x3f4c6307, 0x4f00630e, 0x13006507,   // wo.af.et_532 sco.wo.af_432  sco.bi.un_550 gv.et.un_420 
  0x4c5b1305, 0x330e2e02, 0x3f4c4d04, 0x03000113,   // et.sg.wo_333 fo.is.nn_222  aa.wo.af_332 en.nl.un_650 
  // [16600]
  0x393e0e12, 0x04067909, 0x3e002504, 0x796a1aec,   // is.rm.br_654 war.de.fi_444  eu.rm.un_320 tl.haw.war_644 
  0x2f4f5760, 0x3b6563ec, 0x651d01a4, 0x3e6357af,   // na.bi.su_664 sco.gv.so_644  en.la.gv_433 na.sco.rm_655 
  0x3f000334, 0x49004709, 0x0a150414, 0x2f001f0c,   // nl.af.un_A80 sn.to.un_440  ru.mk.un_660 cy.su.un_530 
  0x21632fa4, 0x4f473ba9, 0x13003e12, 0x1a476a0c,   // su.sco.jw_433 so.sn.bi_544  rm.et.un_640 haw.sn.tl_543 
  // [16610]
  0x5a004712, 0x50004704, 0x5a6a010b, 0x78122ea4,   // sn.sm.un_640 sn.fj.un_320  en.haw.sm_542 fo.hu.ve_433 
  0x5e00fc0c, 0x12004a2b, 0x18004a2c, 0x2e007608,   // zzp.ts.un_530 yo.hu.un_980  yo.ga.un_990 crs.fo.un_430 
  0x2b00182c, 0x374825ad, 0x443548a4, 0x2b004904,   // ga.vi.un_990 mn.tt.ba_643  tt.tg.kk_433 to.vi.un_320 
  0x1100fc08, 0x18004a1b, 0x4635fa12, 0x1d005e0e,   // zzp.ro.un_430 yo.ga.un_770  nr.zu.qu_654 ts.la.un_550 
  // [16620]
  0x4c004a07, 0x45784aad, 0x045b4864, 0x18004a1a,   // yo.wo.un_420 yo.ve.ln_643  tt.sg.fi_762 yo.ga.un_760 
  0x3c0717a0, 0x373048a0, 0x4a190a13, 0x0a004a14,   // sr.bg.ug_322 tt.uz.ba_322  pt.gl.yo_665 yo.pt.un_660 
  0x03002c1a, 0x0a2b0e02, 0x2e005302, 0x04060ca0,   // fy.nl.un_760 is.vi.pt_222  ht.fo.un_220 sv.de.fi_322 
  0x0817110e, 0x0c006308, 0x56003613, 0x174836a0,   // ro.sr.uk_555 sco.sv.un_430  gn.mg.un_650 ab.tt.sr_322 
  // [16630]
  0x36005608, 0x3537300e, 0x3f4d4e07, 0x3423445a,   // mg.gn.un_430 uz.ba.tg_555  ay.aa.af_432 kk.ky.ps_553 
  0x476473a7, 0x5c634ead, 0x20360407, 0x480744a4,   // ny.lg.sn_532 ay.sco.sa_643  fi.gn.sq_432 kk.bg.tt_433 
  0x0e002f07, 0x32174e0c, 0xfe650ca7, 0x10004e11,   // su.is.un_420 ay.sr.bs_543  sv.gv.tlh_532 ay.lt.un_630 
  0x34232107, 0x1e381b04, 0x32006502, 0x30001d1a,   // fa.ky.ps_432 tr.tk.ms_332  gv.bs.un_220 la.uz.un_760 
  // [16640]
  0x0b422318, 0x2f6931a4, 0x63000509, 0xfc005104,   // ca.co.es_764 az.mfe.su_433  fr.sco.un_440 kl.zzp.un_320 
  0xfc2e735a, 0x481525ec, 0x5f00751b, 0x321730a4,   // ny.fo.zzp_553 mn.tt.un_640  nso.tn.un_770 uz.sr.bs_433 
  0x531b69a9, 0x4c6976a7, 0x514d58a7, 0x3b122805,   // mfe.tr.ht_544 crs.mfe.wo_532  om.aa.kl_532 sd.ur.ks_333 
  0x0410150d, 0x39670208, 0x73041d04, 0x67021ca0,   // un.be.ru_554 da.ak.br_443  la.fi.ny_332 id.da.ak_322 
  // [16650]
  0x046b6107, 0x303525af, 0x1b001707, 0x40030609,   // za.ceb.fi_432 mn.tg.uz_655  sr.tr.un_420 de.nl.lb_444 
  0x343ffaaf, 0x32004c05, 0x02000219, 0x303d210c,   // nr.af.xh_655 wo.bs.un_330  da.da.un_750 fa.ku.uz_543 
  0x3d1230a0, 0x333f2ca0, 0x1b3924a9, 0x125d33a0,   // uz.ur.ku_322 fy.af.nn_322  eo.br.tr_544 nn.ss.hu_322 
  0x04104c60, 0x690d2412, 0x4f33080c, 0x1834300c,   // wo.lt.fi_664 eo.cs.mfe_654  no.nn.bi_543 uz.ps.ar_543 
  // [16660]
  0x044837a4, 0x07442304, 0x071008a7, 0x12303ba9,   // ba.tt.ru_433 ky.kk.bg_332  uk.be.bg_532 ks.uz.ur_544 
  0x30350755, 0x071536ad, 0x30247304, 0x12245c07,   // bg.tg.uz_442 ab.bg.un_630  ny.eo.uz_332 sa.eo.hu_432 
  0x0a17350b, 0x4b1802a4, 0x2330570c, 0x644857a7,   // tg.sr.mk_542 da.ga.mi_433  na.uz.ca_543 na.tt.lg_532 
  0x0b19240c, 0x5859550e, 0x5c3b19a0, 0x4726100b,   // eo.gl.es_543 rw.rn.om_555  gl.so.sa_322 lt.ia.sn_542 
  // [16670]
  0x197902a0, 0x302344a0, 0x1142580e, 0x5d733509,   // da.war.gl_322 kk.ky.uz_322  om.co.ro_555 zu.ny.ss_444 
  0x1320510d, 0x79246b04, 0x23001712, 0x400406ad,   // kl.sq.et_554 ceb.eo.war_332  sr.ky.un_640 de.fi.lb_643 
  0x58004607, 0x58005207, 0x51003202, 0x09000f09,   // qu.om.un_420 ha.om.un_420  bs.kl.un_220 lv.pl.un_440 
  0x04092804, 0x79336b0c, 0x170a1112, 0x3e002a0c,   // sw.pl.fi_332 ceb.nn.war_543  ro.mk.sr_654 mt.rm.un_530 
  // [16680]
  0x1e00620c, 0x30104d07, 0x48152505, 0x42517307,   // kha.ms.un_530 aa.lt.uz_432  mn.tt.un_330 ny.kl.co_432 
  0x1d584207, 0x512e1ea7, 0x1500130c, 0x112a7612,   // co.om.la_432 ms.fo.kl_532  et.un.un_530 crs.mt.ro_654 
  0x231821a4, 0x44000813, 0x3e636504, 0x2a227655,   // fa.ar.ky_433 uk.kk.un_650  gv.sco.rm_332 crs.oc.mt_442 
  0x05220107, 0x3e3069a0, 0x08101707, 0x57003913,   // en.oc.fr_432 mfe.uz.rm_322  sr.be.uk_432 br.na.un_650 
  // [16690]
  0x016355ad, 0x29002304, 0x032c5007, 0x232b0555,   // rw.sco.en_643 ca.sl.un_320  fj.fy.nl_432 fr.vi.ca_442 
  0x07001804, 0x31151304, 0x0b002321, 0x023f150b,   // ga.it.un_320 et.az.un_320  ca.es.un_860 un.af.da_542 
  0x070c6707, 0x0c150605, 0x0a005e08, 0x0c1215a0,   // ak.sv.it_432 de.sv.un_330  ts.pt.un_430 un.hu.sv_322 
  0x3e00fc0c, 0x04484e0c, 0x041044ec, 0xfc000f07,   // zzp.rm.un_530 ay.tt.fi_543  kk.be.ru_644 lv.zzp.un_420 
  // [166a0]
  0x10371704, 0x0742231d, 0x2c630307, 0x02000805,   // sr.ba.be_332 ca.co.it_852  nl.sco.fy_432 no.da.un_330 
  0x13581d05, 0x64002402, 0x04071513, 0x071d0555,   // la.om.et_333 eo.lg.un_220  un.bg.ru_665 fr.la.it_442 
  0x170d2d0b, 0x0a2336a0, 0x094d23a7, 0x3f1b4dec,   // sk.cs.sr_542 ab.ky.mk_322  ca.aa.pl_532 aa.tr.af_644 
  0x36044902, 0x04002712, 0x370408a0, 0x5a470407,   // to.fi.gn_222 gd.fi.un_640  uk.ru.ba_322 fi.sn.sm_432 
  // [166b0]
  0x2c1b3104, 0x5c21580d, 0x59001812, 0x3b3421ec,   // az.tr.fy_332 om.jw.sa_554  ga.rn.un_640 fa.ps.ks_644 
  0x50000204, 0x35233cec, 0x08330e07, 0x472528a0,   // da.fj.un_320 ug.ky.tg_644  is.nn.no_432 sw.eu.sn_322 
  0x321704ec, 0x1713040b, 0x36041804, 0x3b00281a,   // fi.sr.bs_644 fi.et.sr_542  ga.fi.gn_332 sd.ks.un_760 
  0x3c301504, 0x12004402, 0x04081513, 0x016b3ea0,   // un.uz.ug_332 kk.ur.un_220  un.uk.ru_665 rm.ceb.en_322 
  // [166c0]
  0x2d110d07, 0x04443705, 0x35151007, 0x1b4831a9,   // cs.ro.sk_432 ba.kk.ru_333  be.tg.un_420 az.tt.tr_544 
  0x115d0502, 0x58004205, 0x311b1e09, 0x40221104,   // fr.ss.ro_222 co.om.un_330  ms.tr.az_444 ro.oc.lb_332 
  0x071d24a7, 0x6100181a, 0x0810230c, 0x183c340b,   // eo.la.it_532 ga.za.un_760  ky.be.uk_543 ps.ug.ar_542 
  0x345d5ea4, 0x02001802, 0xfc4065a4, 0x34375da9,   // ts.ss.xh_433 ga.da.un_220  gv.lb.zzp_433 ss.st.xh_544 
  // [166d0]
  0x01242cee, 0x30382312, 0x2c033faf, 0x213012ad,   // fy.eo.en_422 ky.tk.uz_654  af.nl.fy_655 ur.uz.fa_643 
  0x16000f12, 0x32291602, 0x03753faf, 0x30382309,   // lv.hr.un_640 hr.sl.bs_222  af.nso.nl_655 ky.tk.uz_444 
  0x48004002, 0x291b0da0, 0x33030ca0, 0x39330808,   // lb.tt.un_220 cs.tr.sl_322  sv.nl.nn_322 no.nn.br_443 
  0x03083f07, 0x060448af, 0x4d251e0c, 0x4e1225af,   // af.no.nl_432 tt.fi.de_655  ms.eu.aa_543 eu.hu.ay_655 
  // [166e0]
  0x4d1e1c0d, 0x4c003f08, 0x30004a05, 0x012565a0,   // id.ms.aa_554 af.wo.un_430  yo.uz.un_330 gv.eu.en_322 
  0x251b4d07, 0x1e251c0c, 0x1c2f4dee, 0x56184b02,   // aa.tr.eu_432 id.eu.ms_543  aa.su.id_422 mi.ga.mg_222 
  0x214d2c12, 0x10045c55, 0x47024b0c, 0x4d211baf,   // fy.aa.jw_654 sa.fi.lt_442  mi.da.sn_543 tr.jw.aa_655 
  0x25000608, 0x344609ee, 0x5600020e, 0x04095c05,   // de.eu.un_430 pl.qu.xh_422  da.mg.un_550 sa.pl.fi_333 
  // [166f0]
  0x5c000412, 0x254006ad, 0x5e005c04, 0x164b0dee,   // fi.sa.un_640 de.lb.eu_643  sa.ts.un_320 cs.mi.hr_422 
  0x65182705, 0x2f211e02, 0x15005607, 0x1e1a57a9,   // gd.ga.gv_333 ms.jw.su_222  mg.un.un_420 na.tl.ms_544 
  0x4636150c, 0x254d1ca9, 0x4d1b1ea9, 0x2c090c0c,   // un.gn.qu_543 id.aa.eu_544  ms.tr.aa_544 sv.pl.fy_543 
  0x28125007, 0x56005004, 0x51003b04, 0x501e4ba0,   // fj.hu.sw_432 fj.mg.un_320  so.kl.un_320 mi.ms.fj_322 
  // [16700]
  0x332a0707, 0x1536350c, 0x283b64a0, 0x1e025607,   // it.mt.nn_432 tg.ab.un_543  lg.so.sw_322 mg.da.ms_432 
  0x56004b12, 0x04005c07, 0x354423ad, 0x5c040913,   // mi.mg.un_640 sa.fi.un_420  ky.kk.tg_643 pl.fi.sa_665 
  0xfc000f02, 0x2c095c04, 0x07250607, 0x096451a7,   // lv.zzp.un_220 sa.pl.fy_332  de.eu.it_432 kl.lg.pl_532 
  0x4a005608, 0x0715110c, 0x332e08af, 0x63480107,   // mg.yo.un_430 ro.bg.un_530  no.fo.nn_655 en.tt.sco_432 
  // [16710]
  0x1d0613a9, 0x266301a4, 0x2a21510c, 0x25651b11,   // et.de.la_544 en.sco.ia_433  kl.jw.mt_543 tr.gv.eu_653 
  0x5830060c, 0x1008440d, 0x485c070d, 0x634d1b0c,   // de.uz.om_543 kk.uk.be_554  it.sa.tt_554 tr.aa.sco_543 
  0x42280312, 0x36150412, 0x2a630107, 0x1213670c,   // nl.sw.co_654 ru.ab.un_640  en.sco.mt_432 ak.et.hu_543 
  0x483051a0, 0x2f003608, 0x48233c0b, 0x0c4d0807,   // kl.uz.tt_322 gn.su.un_430  ug.ky.tt_542 no.aa.sv_432 
  // [16720]
  0x38005622, 0x033f6013, 0x300a02af, 0x02004008,   // mg.tk.un_870 vo.af.nl_665  da.pt.uz_655 lb.da.un_430 
  0x16005e08, 0x13000917, 0x016567a7, 0x30230ba0,   // ts.hr.un_430 pl.et.un_730  ak.gv.en_532 es.ca.uz_322 
  0x32495e0c, 0x5a003104, 0x022d65a4, 0x48303f07,   // ts.to.bs_543 az.sm.un_320  gv.sk.da_433 af.uz.tt_432 
  0x022e1104, 0x38001d02, 0x393f0c07, 0x38005713,   // ro.fo.da_332 la.tk.un_220  sv.af.br_432 na.tk.un_650 
  // [16730]
  0x29003b0d, 0x0d292d0d, 0x2c3b2914, 0x13005608,   // so.sl.un_540 sk.sl.cs_554  sl.so.fy_666 mg.et.un_430 
  0x0f4a10a4, 0x1a00672a, 0x102e0e04, 0x2900200d,   // lt.yo.lv_433 ak.tl.un_970  is.fo.lt_332 sq.sl.un_540 
  0x16293bad, 0x57001d2b, 0x381206ad, 0x2c063ba4,   // so.sl.hr_643 la.na.un_980  de.hu.tk_643 so.de.fy_433 
  0x183b3e07, 0x51584da0, 0x1800390e, 0x3b002913,   // rm.so.ga_432 aa.om.kl_322  br.ga.un_550 sl.so.un_650 
  // [16740]
  0x29003b04, 0x38003607, 0x383744a4, 0x09242d0d,   // so.sl.un_320 gn.tk.un_420  kk.ba.tk_433 sk.eo.pl_554 
  0x320dfea0, 0x44044804, 0x510a04a4, 0x313b4604,   // tlh.cs.bs_322 tt.ru.kk_332  fi.pt.kl_433 qu.so.az_332 
  0x51002914, 0xfe000d12, 0x585051a0, 0x23001102,   // sl.kl.un_660 cs.tlh.un_640  kl.fj.om_322 ro.ca.un_220 
  0x2d29fe07, 0x1d001534, 0x46003b08, 0x103811a4,   // tlh.sl.sk_432 un.la.un_A80  so.qu.un_430 ro.tk.be_433 
  // [16750]
  0x081007a7, 0x34233cac, 0x36002e09, 0x1e002b02,   // bg.be.uk_532 ug.ky.ps_632  fo.gn.un_440 vi.ms.un_220 
  0x5e36470c, 0x0302250c, 0x2f292d02, 0x68002b0d,   // sn.gn.ts_543 eu.da.nl_543  sk.sl.su_222 vi.ig.un_540 
  0x302d2912, 0x0e020c07, 0x30006b05, 0x4800312b,   // sl.sk.uz_654 sv.da.is_432  ceb.uz.un_330 az.tt.un_980 
  0x11483109, 0x023f0ea4, 0x65124aa0, 0x292d30a9,   // az.tt.ro_444 is.af.da_433  yo.hu.gv_322 uz.sk.sl_544 
  // [16760]
  0x2e0e1807, 0x642148ee, 0xfe0f0cee, 0x0c0230a9,   // ga.is.fo_432 tt.jw.lg_422  sv.lv.tlh_422 uz.da.sv_544 
  0x3708230c, 0x40063b0c, 0x2d000c08, 0x07424c07,   // ky.uk.ba_543 so.de.lb_543  sv.sk.un_430 wo.co.it_432 
  0x0207420b, 0x5c000702, 0x13103ba4, 0x3e264209,   // co.it.da_542 it.sa.un_220  so.lt.et_433 co.ia.rm_444 
  0x124207af, 0x2b074202, 0x523130a4, 0x071d02a7,   // it.co.hu_655 co.it.vi_222  uz.az.ha_433 da.la.it_532 
  // [16770]
  0x070102a6, 0x043b64a7, 0x02074213, 0x51794d07,   // da.en.it_521 lg.so.fi_532  co.it.da_665 aa.war.kl_432 
  0x78003b14, 0x023b4d08, 0x58283b08, 0x3b6478a9,   // so.ve.un_660 aa.so.da_443  so.sw.om_443 ve.lg.so_544 
  0x52462504, 0x025c1805, 0x5c3e4212, 0x03004609,   // eu.qu.ha_332 ga.sa.da_333  co.rm.sa_654 qu.nl.un_440 
  0x1b004821, 0x131e1c04, 0x0f736404, 0x13043b05,   // tt.tr.un_860 id.ms.et_332  lg.ny.lv_332 so.fi.et_333 
  // [16780]
  0x583b64ad, 0x4d106412, 0x632b01a4, 0x5a00130e,   // lg.so.om_643 lg.lt.aa_654  en.vi.sco_433 et.sm.un_550 
  0xfe003621, 0x6343feaf, 0x2e000b08, 0x49202107,   // gn.tlh.un_860 tlh.ie.sco_655  es.fo.un_430 jw.sq.to_432 
  0x69004c08, 0x314d6311, 0x4c3b4da4, 0xfe76690c,   // wo.mfe.un_430 sco.aa.az_653  aa.so.wo_433 mfe.crs.tlh_543 
  0x637669af, 0x3100fe0b, 0x3b6963ec, 0x4c002e2b,   // mfe.crs.sco_655 tlh.az.un_520  sco.mfe.so_644 fo.wo.un_980 
  // [16790]
  0x48153605, 0x0e12180b, 0x18343d0d, 0x09000412,   // ab.tt.un_330 ga.hu.is_542  ku.ps.ar_554 fi.pl.un_640 
  0x0a370404, 0x384831ee, 0x690d76a4, 0x482310a9,   // ru.ba.mk_332 az.tt.tk_422  crs.cs.mfe_433 be.ky.tt_544 
  0x27000a02, 0x44170a05, 0x11292da0, 0x0f5c10a7,   // pt.gd.un_220 mk.sr.kk_333  sk.sl.ro_322 lt.sa.lv_532 
  0x38001102, 0x1d005809, 0x734c47a4, 0x11001b0c,   // ro.tk.un_220 om.la.un_440  sn.wo.ny_433 tr.ro.un_530 
  // [167a0]
  0x07043055, 0x4a581d04, 0x12200404, 0x63007905,   // uz.fi.it_442 la.om.yo_332  fi.sq.hu_332 war.sco.un_330 
  0x01136055, 0x200440a4, 0x041334a4, 0x2c3413ac,   // vo.et.en_442 lb.fi.sq_433  xh.et.fi_433 et.xh.fy_632 
  0x122d18a4, 0x64583405, 0x04104207, 0x51006502,   // ga.sk.hu_433 xh.om.lg_333  co.lt.fi_432 gv.kl.un_220 
  0x5c100fa7, 0x5e1a3e02, 0x55065a02, 0x3f004d07,   // lv.lt.sa_532 rm.tl.ts_222  sm.de.rw_222 aa.af.un_420 
  // [167b0]
  0x330876a0, 0x63006e0d, 0x63006e12, 0x22005a2a,   // crs.no.nn_322 hmn.sco.un_540  hmn.sco.un_640 sm.oc.un_970 
  0x6e652004, 0x2a0b0aa4, 0x21624fad, 0x232207a0,   // sq.gv.hmn_332 pt.es.mt_433  bi.kha.jw_643 it.oc.ca_322 
  0x5600130d, 0x43004a19, 0x6800301a, 0x32002007,   // et.mg.un_540 yo.ie.un_750  uz.ig.un_760 sq.bs.un_420 
  0x300f520c, 0x341811ec, 0x2f2e50af, 0x28005313,   // ha.lv.uz_543 ro.ar.ps_644  fj.fo.su_655 ht.sw.un_650 
  // [167c0]
  0x2e001312, 0x402756ee, 0x221f56a0, 0x5a1c1e0c,   // et.fo.un_640 mg.gd.lb_422  mg.cy.oc_322 ms.id.sm_543 
  0x13006e0d, 0x02006508, 0x52655b07, 0x5e001105,   // hmn.et.un_540 gv.da.un_430  sg.gv.ha_432 ro.ts.un_330 
  0x03243f08, 0x40156502, 0x106215af, 0x42072302,   // af.eo.nl_443 gv.lb.un_220  un.kha.lt_655 ca.it.co_222 
  0x1b000c04, 0x315e3455, 0x403102ee, 0x212f60ee,   // sv.tr.un_320 xh.ts.az_442  da.az.lb_422 vo.su.jw_422 
  // [167d0]
  0x39794c07, 0x22071908, 0x3400190c, 0x11582007,   // wo.war.br_432 gl.it.oc_443  gl.xh.un_530 sq.om.ro_432 
  0x341dfca4, 0x03394707, 0x0f2d0d09, 0x39003605,   // zzp.la.xh_433 sn.br.nl_432  cs.sk.lv_444 gn.br.un_330 
  0x351736a0, 0x11004811, 0x11004816, 0x2134125a,   // ab.sr.tg_322 tt.ro.un_630  tt.ro.un_720 ur.ps.fa_553 
  0x0e00120b, 0x1b001105, 0x480715ad, 0x0400601f,   // hu.is.un_520 ro.tr.un_330  un.bg.tt_643 vo.fi.un_840 
  // [167e0]
  0x2d1609ee, 0x1e201a05, 0x481138af, 0x320f100b,   // pl.hr.sk_422 tl.sq.ms_333  tk.ro.tt_655 lt.lv.bs_542 
  0x0c400605, 0x3e001b08, 0x3b122112, 0x2d0f10ee,   // de.lb.sv_333 tr.rm.un_430  fa.ur.ks_654 lt.lv.sk_422 
  0x24001b12, 0x30244205, 0x0a0823a7, 0x24001304,   // tr.eo.un_640 co.eo.uz_333  ky.uk.mk_532 et.eo.un_320 
  0x1b00240d, 0x33082409, 0x3c213455, 0x301828a0,   // eo.tr.un_540 eo.no.nn_444  ps.fa.ug_442 sw.ga.uz_322 
  // [167f0]
  0x0a00540c, 0x020479ec, 0x0e061307, 0x100f1fa0,   // ik.pt.un_530 war.fi.da_644  et.de.is_432 cy.lv.lt_322 
  0x045254ee, 0x060d03ee, 0x28205c09, 0x3f2c0eac,   // ik.ha.fi_422 nl.cs.de_422  sa.sq.sw_444 is.fy.af_632 
  0xfe796b11, 0x04000c10, 0x30313202, 0x0c4006af,   // ceb.war.tlh_653 sv.fi.un_620  bs.az.uz_222 de.lb.sv_655 
  0x1b002407, 0x330e0fa7, 0x04003102, 0x2a004209,   // eo.tr.un_420 lv.is.nn_532  az.fi.un_220 co.mt.un_440 
  
  // [16800]
  0x20183508, 0x1c541e08, 0x354e73af, 0x2e006a09,   // zu.ga.sq_443 ms.ik.id_443  ny.ay.zu_655 haw.fo.un_440 
  0x0c2e0e07, 0x350c4007, 0x1100180e, 0x11003113,   // is.fo.sv_432 lb.sv.zu_432  ga.ro.un_550 az.ro.un_650 
  0x2f1d0207, 0x3e005a02, 0x44301504, 0x0e1d50a7,   // da.la.su_432 sm.rm.un_220  un.uz.kk_332 fj.la.is_532 
  0x22235604, 0x4830690d, 0x0c00601a, 0x350730ad,   // mg.ca.oc_332 mfe.uz.tt_554  vo.sv.un_760 uz.bg.tg_643 
  // [16810]
  0x0c4006a9, 0x3c2134a0, 0x400660ec, 0x04081714,   // de.lb.sv_544 ps.fa.ug_322  vo.de.lb_644 sr.uk.ru_666 
  0x23043005, 0x33063f07, 0x48002908, 0x49000404,   // uz.ru.ky_333 af.de.nn_432  sl.tt.un_430 fi.to.un_320 
  0x35065d09, 0x0d2910a4, 0x213d12af, 0x4201fcad,   // ss.de.zu_444 lt.sl.cs_433  ur.ku.fa_655 zzp.en.co_643 
  0x22401bee, 0x23fc0107, 0x29fc0804, 0x25554a0c,   // tr.lb.oc_422 en.zzp.ca_432  no.zzp.sl_332 yo.rw.eu_543 
  // [16820]
  0x092004a0, 0x1d0765a0, 0x31002d08, 0x190b4702,   // fi.sq.pl_322 gv.it.la_322  sk.az.un_430 sn.es.gl_222 
  0x1f002102, 0x13554a02, 0x30000d07, 0x400c3f07,   // jw.cy.un_220 yo.rw.et_222  cs.uz.un_420 af.sv.lb_432 
  0x060c48ee, 0x571d0213, 0x3c4837a4, 0x34472912,   // tt.sv.de_422 da.la.na_665  ba.tt.ug_433 sl.sn.xh_654 
  0x653339a7, 0x36595513, 0x091e1c09, 0x64531f02,   // br.nn.gv_532 rw.rn.gn_665  id.ms.pl_444 cy.ht.lg_222 
  // [16830]
  0x48000417, 0x0d5004a7, 0x02003419, 0x033f47a4,   // fi.tt.un_730 fi.fj.cs_532  xh.da.un_750 sn.af.nl_433 
  0x553258ee, 0x645965ec, 0x1500060c, 0x3f000320,   // om.bs.rw_422 gv.rn.lg_644  de.un.un_530 nl.af.un_850 
  0x645202a7, 0x202a0807, 0x50005708, 0x09130404,   // da.ha.lg_532 no.mt.sq_432  na.fj.un_430 fi.et.pl_332 
  0x4e001008, 0x3d00302a, 0x0553390c, 0x20556105,   // lt.ay.un_430 uz.ku.un_970  br.ht.fr_543 za.rw.sq_333 
  // [16840]
  0x28131008, 0x32006108, 0x04201305, 0x04511314,   // lt.et.sw_443 za.bs.un_430  et.sq.fi_333 et.kl.fi_666 
  0x39023f04, 0x03390507, 0x09292404, 0x611c0205,   // af.da.br_332 fr.br.nl_432  eo.sl.pl_332 da.id.za_333 
  0x0a2315a0, 0x564b6a07, 0x44003402, 0x3f033908,   // un.ky.mk_322 haw.mi.mg_432  ps.kk.un_220 br.nl.af_443 
  0x3f530302, 0x02044704, 0xfe522060, 0x202a2408,   // nl.ht.af_222 sn.fi.da_332  sq.ha.tlh_664 eo.mt.sq_443 
  // [16850]
  0x62000908, 0x5a005602, 0x201c1e11, 0x3f390305,   // pl.kha.un_430 mg.sm.un_220  ms.id.sq_653 nl.br.af_333 
  0x12302902, 0x2000461a, 0x340f3307, 0x04530504,   // sl.uz.hu_222 qu.sq.un_760  nn.lv.xh_432 fr.ht.fi_332 
  0x0400090e, 0x13042e08, 0x1e001b09, 0x383148a0,   // pl.fi.un_550 fo.fi.et_443  tr.ms.un_440 tt.az.tk_322 
  0x6100020e, 0x4f6512a4, 0x1f127604, 0x182134a6,   // da.za.un_550 hu.gv.bi_433  crs.hu.cy_332 ps.fa.ar_521 
  // [16860]
  0x0d3f0404, 0x233430a0, 0x03100911, 0x111004a4,   // fi.af.cs_332 uz.ps.ky_322  pl.lt.nl_653 fi.lt.ro_433 
  0x0c3315a0, 0x483e06a0, 0x3d344411, 0x102056a9,   // un.nn.sv_322 de.rm.tt_322  kk.ps.ku_653 mg.sq.lt_544 
  0x0c1340a4, 0x790221ec, 0x234430a4, 0x0c000f19,   // lb.et.sv_433 jw.da.war_644  uz.kk.ky_433 lv.sv.un_750 
  0xfc5556af, 0x64404d04, 0x2a0309a4, 0x57651d05,   // mg.rw.zzp_655 aa.lb.lg_332  pl.nl.mt_433 la.gv.na_333 
  // [16870]
  0x0e4003ee, 0x4900630e, 0x0213640d, 0x02041305,   // nl.lb.is_422 sco.to.un_550  lg.et.da_554 et.fi.da_333 
  0x65791d07, 0x630236a7, 0x650358a0, 0x05033f0d,   // la.war.gv_432 gn.da.sco_532  om.nl.gv_322 af.nl.fr_554 
  0x1732160c, 0x48311b05, 0x64003b05, 0x07300aee,   // hr.bs.sr_543 tr.az.tt_333  so.lg.un_330 mk.uz.bg_422 
  0x034c3ba0, 0x531ffc04, 0x362a20ad, 0x01002104,   // so.wo.nl_322 zzp.cy.ht_332  sq.mt.gn_643 jw.en.un_320 
  // [16880]
  0x53033faf, 0x48441555, 0x40500c07, 0x40006309,   // af.nl.ht_655 un.kk.tt_442  sv.fj.lb_432 sco.lb.un_440 
  0x04002b04, 0x03574007, 0x30fc0107, 0x5a006402,   // vi.fi.un_320 lb.na.nl_432  en.zzp.uz_432 lg.sm.un_220 
  0x3f2c390e, 0x083025a0, 0x4d6540a4, 0x5a002802,   // br.fy.af_555 mn.uz.uk_322  lb.gv.aa_433 sw.sm.un_220 
  0x5a644d0b, 0x65045607, 0x3f4053a4, 0x5a002813,   // aa.lg.sm_542 mg.fi.gv_432  ht.lb.af_433 sw.sm.un_650 
  // [16890]
  0x0a15480e, 0x65007607, 0x65394055, 0x63000d12,   // tt.mk.un_550 crs.gv.un_420  lb.br.gv_442 cs.sco.un_640 
  0x6300530d, 0x38001105, 0x2b005a07, 0x2000510e,   // ht.sco.un_540 ro.tk.un_330  sm.vi.un_420 kl.sq.un_550 
  0x1b383108, 0x381048af, 0x38001205, 0x633b4cad,   // az.tk.tr_443 tt.be.tk_655  hu.tk.un_330 wo.so.sco_643 
  0x3410090c, 0x0c332e0c, 0x345c3813, 0x5c384707,   // pl.lt.xh_543 fo.nn.sv_543  tk.sa.xh_665 sn.tk.sa_432 
  // [168a0]
  0xfc00530c, 0x1d001b07, 0x09360404, 0x385c0209,   // ht.zzp.un_530 tr.la.un_420  fi.gn.pl_332 da.sa.tk_444 
  0x5300fc11, 0x34385302, 0x5c093808, 0x3464380c,   // zzp.ht.un_630 ht.tk.xh_222  tk.pl.sa_443 tk.lg.xh_543 
  0x2b005719, 0x2b394ca0, 0x1d004a04, 0x1500111b,   // na.vi.un_750 wo.br.vi_322  yo.la.un_320 ro.un.un_770 
  0x33060cee, 0x10475cec, 0x76346905, 0x645c100c,   // sv.de.nn_422 sa.sn.lt_644  mfe.xh.crs_333 lt.sa.lg_543 
  // [168b0]
  0x21303d08, 0x105c3812, 0x475c380c, 0x1b105ca4,   // ku.uz.fa_443 tk.sa.lt_654  tk.sa.sn_543 sa.lt.tr_433 
  0x381b310b, 0x22695708, 0x5200020e, 0x21183d55,   // az.tr.tk_542 na.mfe.oc_443  da.ha.un_550 ku.ar.fa_442 
  0x2b001f05, 0x23004820, 0x4a00580c, 0x2d0a0dec,   // cy.vi.un_330 tt.ky.un_850  om.yo.un_530 cs.pt.sk_644 
  0x73645811, 0x2b001304, 0x082335a4, 0x56004934,   // om.lg.ny_653 et.vi.un_320  tg.ky.uk_433 to.mg.un_A80 
  // [168c0]
  0x643b58a7, 0x341844a7, 0x6a215b13, 0x56105faf,   // om.so.lg_532 kk.ar.ps_532  sg.jw.haw_665 tn.lt.mg_655 
  0x5f006a18, 0x304815a4, 0x264060a4, 0x2c2021ee,   // haw.tn.un_740 un.tt.uz_433  vo.lb.ia_433 jw.sq.fy_422 
  0x4b006a33, 0x50005605, 0x372348a0, 0x111b31a4,   // haw.mi.un_A70 mg.fj.un_330  tt.ky.ba_322 az.tr.ro_433 
  0x184428ec, 0x582a30a0, 0x22000f07, 0x36630ba4,   // sd.kk.ar_644 uz.mt.om_322  lv.oc.un_420 es.sco.gn_433 
  // [168d0]
  0x1e303860, 0x233c3da9, 0x7300281a, 0x443c3007,   // tk.uz.ms_664 ku.ug.ky_544  sw.ny.un_760 uz.ug.kk_432 
  0x73645e04, 0x13353413, 0x5b000514, 0x2cfc0204,   // ts.lg.ny_332 xh.zu.et_665  fr.sg.un_660 da.zzp.fy_332 
  0x4d0b6405, 0x51003008, 0x576415a4, 0x64097313,   // lg.es.aa_333 uz.kl.un_430  un.lg.na_433 ny.pl.lg_665 
  0x375f4b0c, 0x1f004d0c, 0x57785da9, 0x47fc0112,   // mi.tn.st_543 aa.cy.un_530  ss.ve.na_544 en.zzp.sn_654 
  // [168e0]
  0x20005113, 0x041511ee, 0x0800102b, 0x12343dee,   // kl.sq.un_650 ro.ru.un_420  be.uk.un_980 ku.ps.ur_422 
  0x04440804, 0x3d34210d, 0x44213d0e, 0x48002321,   // uk.kk.ru_332 fa.ps.ku_554  ku.fa.kk_555 ky.tt.un_860 
  0x23384460, 0x29131fa0, 0x1b002505, 0x37003521,   // kk.tk.ky_664 cy.et.sl_322  eu.tr.un_330 tg.ba.un_860 
  0x111b480b, 0x1d260111, 0x0d292d0c, 0x2e025107,   // tt.tr.ro_542 en.ia.la_653  sk.sl.cs_543 kl.da.fo_432 
  // [168f0]
  0x1d0420ad, 0x10000b04, 0x65091f0c, 0x1d244307,   // sq.fi.la_643 es.lt.un_320  cy.pl.gv_543 ie.eo.la_432 
  0x100711a4, 0x392718ac, 0x0307420b, 0x534c5505,   // ro.bg.be_433 ga.gd.br_632  co.it.nl_542 rw.wo.ht_333 
  0x09512809, 0xfe3b5209, 0xfc0612ad, 0x06000818,   // sw.kl.pl_444 ha.so.tlh_444  hu.de.zzp_643 no.de.un_740 
  0x5100fe08, 0x02286ba7, 0x400c48c1, 0x1a005109,   // tlh.kl.un_430 ceb.sw.da_532  tt.sv.lb_942 kl.tl.un_440 
  // [16900]
  0x05005c02, 0x202f1e07, 0x47000709, 0x06020812,   // sa.fr.un_220 ms.su.sq_432  it.sn.un_440 no.da.de_654 
  0x1042fea4, 0x1279060e, 0x01386207, 0x423e0711,   // tlh.co.lt_433 de.war.hu_555  kha.tk.en_432 it.rm.co_653 
  0x2f514ca4, 0x50274da7, 0x0a006013, 0x48303b09,   // wo.kl.su_433 aa.gd.fj_532  vo.pt.un_650 so.uz.tt_444 
  0x212f16ee, 0x12531ba0, 0x21281805, 0x222123af,   // hr.su.jw_422 tr.ht.hu_322  ar.sd.fa_333 ca.jw.oc_655 
  // [16910]
  0x325e1704, 0x28fe3607, 0x06003e09, 0x1b4838af,   // sr.ts.bs_332 gn.tlh.sw_432  rm.de.un_440 tk.tt.tr_655 
  0x42002019, 0x350704ad, 0x151504af, 0x4837070d,   // sq.co.un_750 ru.bg.tg_643  ru.un.un_650 bg.ba.tt_554 
  0x4800310b, 0x23374405, 0x3d2112ec, 0x4a005609,   // az.tt.un_520 kk.ba.ky_333  ur.fa.ku_644 mg.yo.un_440 
  0x42004a12, 0x426357a4, 0x254a1a12, 0x2873565a,   // yo.co.un_640 na.sco.co_433  tl.yo.eu_654 mg.ny.sw_553 
  // [16920]
  0x077601a0, 0x261d0714, 0x48292da7, 0x392146a0,   // en.crs.it_322 it.la.ia_666  sk.sl.tt_532 qu.jw.br_322 
  0x1d0926a4, 0x39003313, 0x24292d07, 0x3f0c1f14,   // ia.pl.la_433 nn.br.un_650  sk.sl.eo_432 cy.sv.af_666 
  0x071318a9, 0x05691507, 0x0c100404, 0x2500560e,   // ga.et.it_544 un.mfe.fr_432  fi.lt.sv_332 mg.eu.un_550 
  0x3831480c, 0x2f0b27a0, 0x181228ee, 0x18420704,   // tt.az.tk_543 gd.es.su_322  sd.ur.ar_422 it.co.ga_332 
  // [16930]
  0x27184504, 0x03001802, 0x29482dec, 0x09002f04,   // ln.ga.gd_332 ga.nl.un_220  sk.tt.sl_644 su.pl.un_320 
  0x65002d04, 0x461a0b08, 0x0c4d6412, 0x2e0e64a4,   // sk.gv.un_320 es.tl.qu_443  lg.aa.sv_654 lg.is.fo_433 
  0x10600107, 0x302e7908, 0x21442804, 0x1b42070b,   // en.vo.lt_432 war.fo.uz_443  sd.kk.fa_332 it.co.tr_542 
  0x0d292dad, 0x0c006407, 0x3e495aa4, 0x4254280c,   // sk.sl.cs_643 lg.sv.un_420  sm.to.rm_433 sw.ik.co_543 
  // [16940]
  0x2e001904, 0x49524ba4, 0x041d2608, 0x10044908,   // gl.fo.un_320 mi.ha.to_433  ia.la.fi_443 to.fi.lt_443 
  0x27004f21, 0x022d2905, 0x04001d0e, 0x43276905,   // bi.gd.un_860 sl.sk.da_333  la.fi.un_550 mfe.gd.ie_333 
  0x016b64a0, 0x1c00560b, 0x284b49ee, 0x2b1e1ca0,   // lg.ceb.en_322 mg.id.un_520  to.mi.sw_422 id.ms.vi_322 
  0x2308150c, 0x5e283611, 0x0100fc1b, 0x3f460302,   // un.uk.ky_543 gn.sw.ts_653  zzp.en.un_770 nl.qu.af_222 
  // [16950]
  0x494b39ec, 0x1c135ca0, 0x373536a7, 0x08440409,   // br.mi.to_644 sa.bh.mr_322  ab.tg.ba_532 ru.kk.uk_444 
  0x3573340b, 0x1b3856a0, 0x13002017, 0x38313011,   // xh.ny.zu_542 mg.tk.tr_322  sq.et.un_730 uz.az.tk_653 
  0x170118a4, 0x37003819, 0x27004a05, 0x3d21180b,   // ar.iw.sr_433 tk.ba.un_750  yo.gd.un_330 ar.fa.ku_542 
  0x7600391a, 0x17230a08, 0x08002509, 0x11481ba4,   // br.crs.un_760 mk.ky.sr_443  mn.uk.un_440 tr.tt.ro_433 
  // [16960]
  0x402647a4, 0x080248a7, 0x2173460c, 0x2f007313,   // sn.ia.lb_433 tt.da.no_532  qu.ny.jw_543 ny.su.un_650 
  0x024e780e, 0x12002904, 0x11481b05, 0x1d006322,   // ve.ay.da_555 sl.hu.un_320  tr.tt.ro_333 sco.la.un_870 
  0x79000213, 0x3e136ea9, 0x1b007908, 0x25000805,   // da.war.un_650 hmn.et.rm_544  war.tr.un_430 uk.mn.un_330 
  0x46551ba7, 0x33633e07, 0x10442312, 0x40000c0e,   // tr.rw.qu_532 rm.sco.nn_432  ky.kk.be_654 sv.lb.un_550 
  // [16970]
  0x46395304, 0x0e382e04, 0x0f1333ad, 0x38006e19,   // ht.br.qu_332 fo.tk.is_332  nn.et.lv_643 hmn.tk.un_750 
  0x08071707, 0x224c23a0, 0x52003e19, 0x303564ee,   // sr.bg.uk_432 ca.wo.oc_322  rm.ha.un_750 lg.zu.uz_422 
  0x5f3573ec, 0x561273a4, 0x475c58a0, 0x0a20450d,   // ny.zu.tn_644 ny.hu.mg_433  om.sa.sn_322 ln.sq.pt_554 
  0x2d4211ad, 0x102718a4, 0x44342355, 0x5d095e08,   // ro.co.sk_643 ga.gd.lt_433  ky.ps.kk_442 ts.pl.ss_443 
  // [16980]
  0x512e3f5a, 0x085142ec, 0x330302ee, 0x03002904,   // af.fo.kl_553 co.kl.no_644  da.nl.nn_422 sl.nl.un_320 
  0x644c1304, 0x3b003009, 0x10483707, 0x01004202,   // et.wo.lg_332 uz.so.un_440  ba.tt.be_432 co.en.un_220 
  0x07422607, 0x4423250d, 0x225c78af, 0x0415100e,   // ia.co.it_432 mn.ky.kk_554  ve.sa.oc_655 be.ru.un_550 
  0x40005204, 0x381030a9, 0xfa354e12, 0x11002d0d,   // ha.lb.un_320 uz.lt.tk_544  ay.zu.nr_654 sk.ro.un_540 
  // [16990]
  0x48303114, 0x435101a4, 0x2e0e0c07, 0x10001519,   // az.uz.tt_666 en.kl.ie_433  sv.is.fo_432 un.be.un_750 
  0x0f6261a4, 0x361535ee, 0x3534510e, 0x3f15fc07,   // za.kha.lv_433 tg.ab.un_420  kl.xh.zu_555 zzp.af.un_420 
  0x0f033f04, 0x17002008, 0x15002708, 0x24041b07,   // af.nl.lv_332 sq.sr.un_430  gd.un.un_430 tr.fi.eo_432 
  0x3f4303a0, 0x22033f07, 0x033f23a0, 0x15483cee,   // nl.ie.af_322 af.nl.oc_432  ca.af.nl_322 ug.tt.un_422 
  // [169a0]
  0x04002514, 0x2c005304, 0x232203a0, 0x13002c0c,   // mn.ru.un_660 ht.fy.un_320  nl.oc.ca_322 fy.et.un_530 
  0x36594c08, 0x043e225a, 0x16000f05, 0x0c1601a4,   // wo.rn.gn_443 oc.rm.fi_553  lv.hr.un_330 en.hr.sv_433 
  0x0f2205a7, 0x2d1209ee, 0x4a000d09, 0x013f63ee,   // fr.oc.lv_532 pl.hu.sk_422  cs.yo.un_440 sco.af.en_422 
  0x595549af, 0x6452620c, 0x332e0e14, 0x3b5c2da0,   // to.rw.rn_655 kha.ha.lg_543  is.fo.nn_666 sk.sa.so_322 
  // [169b0]
  0x31330804, 0x64000704, 0x1f0618a0, 0x20171107,   // no.nn.az_332 it.lg.un_320  ga.de.cy_322 ro.sr.sq_432 
  0x643b5a07, 0x595f640b, 0x1d004714, 0x6e2f3807,   // sm.so.lg_432 lg.tn.rn_542  sn.la.un_660 tk.su.hmn_432 
  0x60003e1b, 0x18220aa7, 0x1537040b, 0x0c001202,   // rm.vo.un_770 pt.oc.ga_532  ru.ba.un_542 hu.sv.un_220 
  0x79220a04, 0x565a5fa4, 0x4d645212, 0x6e005d0d,   // pt.oc.war_332 tn.sm.mg_433  ha.lg.aa_654 ss.hmn.un_540 
  // [169c0]
  0x69004719, 0x13000e0b, 0x0600180d, 0x22003004,   // sn.mfe.un_750 is.et.un_520  ga.de.un_540 uz.oc.un_320 
  0x1709560c, 0x352d0d04, 0x5c002708, 0x24043b0c,   // mg.pl.sr_543 cs.sk.zu_332  gd.sa.un_430 so.fi.eo_543 
  0x5c18fe11, 0x1a47735a, 0x4f003305, 0x0b470704,   // tlh.ga.sa_653 ny.sn.tl_553  nn.bi.un_330 it.sn.es_332 
  0x43285e0c, 0x011c1a04, 0x353734ac, 0x25284904,   // ts.sw.ie_543 tl.id.en_332  xh.st.zu_632 to.sw.eu_332 
  // [169d0]
  0x5c091c11, 0x15003404, 0x35001522, 0x030604a0,   // mr.hi.sa_653 xh.un.un_320  un.zu.un_870 fi.de.nl_322 
  0x343d125a, 0x5d355204, 0x5f351808, 0x013527a0,   // ur.ku.ps_553 ha.zu.ss_332  ga.zu.tn_443 gd.zu.en_322 
  0x5e35345a, 0x583464a0, 0x240449a7, 0x421d2512,   // xh.zu.ts_553 lg.xh.om_322  to.fi.eo_532 eu.la.co_654 
  0x5a6a49a0, 0x1a6b47ee, 0x5e00472c, 0x2f005d07,   // to.haw.sm_322 sn.ceb.tl_422  sn.ts.un_990 ss.su.un_420 
  // [169e0]
  0x0a001920, 0x2b001c12, 0x65330804, 0x021cfea4,   // gl.pt.un_850 id.vi.un_640  no.nn.gv_332 tlh.id.da_433 
  0x0531300c, 0x49005104, 0x1d002802, 0x04004405,   // uz.az.fr_543 kl.to.un_320  sw.la.un_220 kk.ru.un_330 
  0x29fe470c, 0x15300412, 0x041544ee, 0x4400151a,   // sn.tlh.sl_543 ru.uz.un_654  kk.ru.un_420 un.kk.un_760 
  0x131b3807, 0x0a234402, 0x23001119, 0x442337a9,   // tk.tr.et_432 kk.ky.mk_222  ro.ky.un_750 ba.ky.kk_544 
  // [169f0]
  0x15042707, 0x121304ee, 0x12173207, 0x18271f07,   // gd.fi.un_432 fi.et.hu_422  bs.sr.hu_432 cy.gd.ga_432 
  0x38006518, 0x171610a4, 0x50003602, 0x271d04a4,   // gv.tk.un_740 lt.hr.sr_433  gn.fj.un_220 fi.la.gd_433 
  0x022160a4, 0x36000404, 0x08280207, 0x04005f04,   // vo.jw.da_433 fi.gn.un_320  da.sw.no_432 tn.fi.un_320 
  0x1035345a, 0x042847a7, 0x07251702, 0x332a0455,   // xh.zu.lt_553 sn.sw.fi_532  sr.mn.bg_222 fi.mt.nn_442 
  // [16a00]
  0x0c212fa0, 0x0c002d05, 0x121830ac, 0x3e422304,   // su.jw.sv_322 sk.sv.un_330  uz.ar.ur_632 ca.co.rm_332 
  0x5a002809, 0x6b1a1c07, 0x4b2849a7, 0x16120407,   // sw.sm.un_440 id.tl.ceb_432  to.sw.mi_532 fi.hu.hr_432 
  0x3d3012ac, 0x49000413, 0x4a005819, 0x56644904,   // ur.uz.ku_632 fi.to.un_650  om.yo.un_750 to.lg.mg_332 
  0x55001c02, 0x302f3ba0, 0x4253050c, 0x58005204,   // id.rw.un_220 so.su.uz_322  fr.ht.co_543 ha.om.un_320 
  // [16a10]
  0x22001d09, 0x04004b0e, 0x35004b02, 0x5a004913,   // la.oc.un_440 mi.fi.un_550  mi.zu.un_220 to.sm.un_650 
  0x790246af, 0x28002305, 0x44303c0c, 0x13585ba7,   // qu.da.war_655 ky.sd.un_330  ug.uz.kk_543 sg.om.et_532 
  0x4c000408, 0x0463580e, 0x02420713, 0x6315010b,   // fi.wo.un_430 om.sco.fi_555  it.co.da_665 en.sco.un_520 
  0x65070107, 0x33070ca4, 0x330842a0, 0x3e0663a4,   // en.it.gv_432 sv.it.nn_433  co.no.nn_322 sco.de.rm_433 
  // [16a20]
  0x30070404, 0x4c42070d, 0x303c34a4, 0x3c0a170e,   // ru.bg.uz_332 it.co.wo_554  ps.ug.uz_433 sr.mk.ug_555 
  0x0e760107, 0x5800fe13, 0x33080eec, 0x021804a4,   // en.crs.is_432 tlh.om.un_650  is.no.nn_644 fi.ga.da_433 
  0x203912a4, 0x30100f0b, 0x3021fc0c, 0x373c440d,   // hu.br.sq_433 lv.lt.uz_542  zzp.jw.uz_543 kk.ug.ba_554 
  0x100f48a7, 0x6b00fe07, 0x13651807, 0x64005e0c,   // tt.lv.lt_532 tlh.ceb.un_420  ga.gv.et_432 ts.lg.un_530 
  // [16a30]
  0x17000a2a, 0x30004819, 0x34006e0c, 0x0c2e33a9,   // mk.sr.un_970 tt.uz.un_750  hmn.xh.un_530 nn.fo.sv_544 
  0x183d3460, 0x56003402, 0x47783655, 0x6e001e08,   // ps.ku.ar_664 xh.mg.un_220  gn.ve.sn_442 ms.hmn.un_430 
  0x362330a9, 0x6e006509, 0x2500440e, 0x49001304,   // uz.ky.ab_544 gv.hmn.un_440  kk.mn.un_550 et.to.un_320 
  0x1c006407, 0x4e004b14, 0x0a171011, 0x42001308,   // lg.id.un_420 mi.ay.un_660  be.sr.mk_653 et.co.un_430 
  // [16a40]
  0x18276e13, 0x3e00530c, 0x15005204, 0x17000205,   // hmn.gd.ga_665 ht.rm.un_530  ha.un.un_320 da.sr.un_330 
  0x5b2027a4, 0x2500100b, 0x17043807, 0x2f6521a4,   // gd.sq.sg_433 be.mn.un_520  tk.ru.sr_432 jw.gv.su_433 
  0x6e271809, 0x483844ad, 0x170810a4, 0x444830a7,   // ga.gd.hmn_444 kk.tk.tt_643  be.uk.sr_433 uz.tt.kk_532 
  0x0e00470b, 0x6500240c, 0x35170408, 0x3c4838a4,   // sn.is.un_520 eo.gv.un_530  ru.sr.tg_443 tk.tt.ug_433 
  // [16a50]
  0x19004b08, 0x604b560c, 0x48043055, 0x42300ba4,   // mi.gl.un_430 mg.mi.vo_543  uz.ru.tt_442 es.uz.co_433 
  0x013f0304, 0x04004008, 0x190b02af, 0x020602ec,   // nl.af.en_332 lb.fi.un_430  da.es.gl_655 da.de.da_644 
  0x05193eee, 0x48593107, 0x04153c12, 0x48192508,   // rm.gl.fr_422 az.rn.tt_432  ug.ru.un_640 eu.gl.tt_443 
  0x4b003904, 0x52595709, 0x2d4857a4, 0x273f18a0,   // br.mi.un_320 na.rn.ha_444  na.tt.sk_433 ga.af.gd_322 
  // [16a60]
  0x5c50240c, 0x40fc65a0, 0x2d0c29a0, 0x3e040204,   // eo.fj.sa_543 gv.zzp.lb_322  sl.sv.sk_322 da.fi.rm_332 
  0x650963ee, 0x48000e12, 0x0245050c, 0x2900fc0c,   // sco.pl.gv_422 is.tt.un_640  fr.ln.da_543 zzp.sl.un_530 
  0x08040714, 0x2300fc0c, 0xfc0165a4, 0x0a00350e,   // bg.ru.uk_666 zzp.ca.un_530  gv.en.zzp_433 tg.mk.un_550 
  0x350415a0, 0x1d311b14, 0x300f24a0, 0x203f0309,   // un.ru.tg_322 tr.az.la_666  eo.lv.uz_322 nl.af.sq_444 
  // [16a70]
  0x36120c07, 0x0e005b13, 0x7502120c, 0x0f292da4,   // sv.hu.gn_432 sg.is.un_650  hu.da.nso_543 sk.sl.lv_433 
  0x73755fec, 0x2900fe0e, 0x31001d02, 0x1f5c5f07,   // tn.nso.ny_644 tlh.sl.un_550  la.az.un_220 tn.sa.cy_432 
  0xfc290255, 0x2e020ca4, 0x2f213607, 0x382f1fa4,   // da.sl.zzp_442 sv.da.fo_433  gn.jw.su_432 cy.su.tk_433 
  0x0c5a12af, 0x2d00fe07, 0x0c003109, 0x0c001216,   // hu.sm.sv_655 tlh.sk.un_420  az.sv.un_440 hu.sv.un_720 
  // [16a80]
  0x68552fa4, 0x23423ea0, 0x253003a0, 0x202a2907,   // su.rw.ig_433 rm.co.ca_322  nl.uz.eu_322 sl.mt.sq_432 
  0x29312d04, 0x565947a4, 0x21545ca7, 0x19540aa4,   // sk.az.sl_332 sn.rn.mg_433  sa.ik.jw_532 pt.ik.gl_433 
  0x1629470c, 0x21531fa0, 0x50021207, 0x125f5aa0,   // sn.sl.hr_543 cy.ht.jw_322  hu.da.fj_432 sm.tn.hu_322 
  0x121b3eee, 0x081048a0, 0x0900120b, 0x38000713,   // rm.tr.hu_422 tt.be.uk_322  hu.pl.un_520 bg.tk.un_650 
  // [16a90]
  0x0b3009a0, 0x07561aa0, 0x230f22a4, 0x202503ad,   // pl.uz.es_322 tl.mg.it_322  oc.lv.ca_433 nl.eu.sq_643 
  0x1a006807, 0x5a004b14, 0x477302ec, 0x39611d07,   // ig.tl.un_420 mi.sm.un_660  da.ny.sn_644 la.za.br_432 
  0x3d3012ad, 0x472878a4, 0x6202200c, 0x1e671ca4,   // ur.uz.ku_643 ve.sw.sn_433  sq.da.kha_543 id.ak.ms_433 
  0x75003714, 0x55596808, 0x22001d05, 0x2e063311,   // st.nso.un_660 ig.rn.rw_443  la.oc.un_330 nn.de.fo_653 
  // [16aa0]
  0x4423280e, 0x253544ee, 0x04033f0c, 0x13250407,   // sd.ky.kk_555 kk.tg.mn_422  af.nl.fi_543 fi.eu.et_432 
  0x12672e60, 0x06120ea7, 0x06003e12, 0x37484404,   // fo.ak.hu_664 is.hu.de_532  rm.de.un_640 kk.tt.ba_332 
  0x4844370c, 0x213c12a4, 0x23483755, 0xfe4728ac,   // ba.kk.tt_543 ur.ug.fa_433  ba.tt.ky_442 sw.sn.tlh_632 
  0x102d16a0, 0x2d29160c, 0x0f001307, 0x164b52ad,   // hr.sk.lt_322 hr.sl.sk_543  et.lv.un_420 ha.mi.hr_643 
  // [16ab0]
  0x04006a0c, 0x6a4b490c, 0x0c001217, 0x0e003902,   // haw.fi.un_530 to.mi.haw_543  hu.sv.un_730 br.is.un_220 
  0x080217a0, 0x46005004, 0x55005305, 0x330a07a0,   // sr.da.no_322 fj.qu.un_320  ht.rw.un_330 it.pt.nn_322 
  0x1100180c, 0x5532fe02, 0x1f5a23a0, 0x1a6b61af,   // ga.ro.un_530 tlh.bs.rw_222  ca.sm.cy_322 za.ceb.tl_655 
  0x153b3605, 0x1c2f210c, 0x4a00400e, 0x36006808,   // gn.so.un_333 jw.su.id_543  lb.yo.un_550 ig.gn.un_430 
  // [16ac0]
  0x5c06025a, 0x23003521, 0x37443c0d, 0x5a003b0c,   // da.de.sa_553 tg.ky.un_860  ug.kk.ba_554 so.sm.un_530 
  0x214b4911, 0x540713a4, 0x15111505, 0x511013a9,   // to.mi.jw_653 et.it.ik_433  un.ro.un_333 et.lt.kl_544 
  0x5c1a2608, 0x17483807, 0x12305a04, 0x0a072505,   // ia.tl.sa_443 tk.tt.sr_432  sm.uz.hu_332 mn.bg.mk_333 
  0x6a435f08, 0x4d00381a, 0x6b0b0104, 0x36190bac,   // tn.ie.haw_443 tk.aa.un_760  en.es.ceb_332 es.gl.gn_632 
  // [16ad0]
  0x58475711, 0x29005919, 0x79380208, 0x4c423307,   // na.sn.om_653 rn.sl.un_750  da.tk.war_443 nn.co.wo_432 
  0x1a796b13, 0x0e424707, 0x04003813, 0x12796b07,   // ceb.war.tl_665 sn.co.is_432  tk.ru.un_650 ceb.war.hu_432 
  0x23002109, 0x0c031dee, 0x6501fca4, 0x3c4823a4,   // fa.ky.un_440 la.nl.sv_422  zzp.en.gv_433 ky.tt.ug_433 
  0x3f1f0ea0, 0x49365112, 0x3e22230b, 0x24781f0c,   // is.cy.af_322 kl.gn.to_654  ca.oc.rm_542 cy.ve.eo_543 
  // [16ae0]
  0x15116004, 0x64366707, 0x46042507, 0x1e676a08,   // vo.ro.un_332 ak.gn.lg_432  eu.fi.qu_432 haw.ak.ms_443 
  0x57004e08, 0x514213a4, 0x734f34ac, 0x091f25a6,   // ay.na.un_430 et.co.kl_433  xh.bi.ny_632 eu.cy.pl_521 
  0x190165ee, 0x69287309, 0x651d3907, 0x5123250c,   // gv.en.gl_422 ny.sw.mfe_444  br.la.gv_432 eu.ca.kl_543 
  0x05002c05, 0x321e29ee, 0x23432607, 0xfc6a4eac,   // fy.fr.un_330 sl.ms.bs_422  ia.ie.ca_432 ay.haw.zzp_632 
  // [16af0]
  0x033f67a4, 0xfc4557a4, 0x04300a02, 0x31003822,   // ak.af.nl_433 na.ln.zzp_433  mk.uz.ru_222 tk.az.un_870 
  0x1f0939a4, 0x05005b0e, 0x355e60ee, 0x35345eee,   // br.pl.cy_433 sg.fr.un_550  vo.ts.zu_422 ts.xh.zu_422 
  0x0400540e, 0x0951250c, 0x042520a4, 0x0442110c,   // ik.fi.un_550 eu.kl.pl_543  sq.eu.fi_433 ro.co.fi_543 
  0x1a042511, 0x55006913, 0x2f552804, 0x0a074804,   // eu.fi.tl_653 mfe.rw.un_650  sw.rw.su_332 tt.bg.mk_332 
  // [16b00]
  0x041715a7, 0x28006a04, 0x35110755, 0x4a006509,   // un.sr.ru_532 haw.sw.un_320  bg.ro.tg_442 gv.yo.un_440 
  0x44304812, 0x17234455, 0x04001208, 0x0d0f390e,   // tt.uz.kk_654 kk.ky.sr_442  hu.fi.un_430 br.lv.cs_555 
  0x1b001114, 0x2c391fa0, 0x017615ec, 0x05761808,   // ro.tr.un_660 cy.br.fy_322  un.crs.en_644 ga.crs.fr_443 
  0x0f007908, 0x68005708, 0x2b004907, 0x62545112,   // war.lv.un_430 na.ig.un_430  to.vi.un_420 kl.ik.kha_654 
  // [16b10]
  0xfe615b12, 0x5d006b02, 0x2c0362ec, 0x1827630c,   // sg.za.tlh_654 ceb.ss.un_220  kha.nl.fy_644 sco.gd.ga_543 
  0x485a6402, 0x0d00060c, 0x253f03ad, 0x2c0838a0,   // lg.sm.tt_222 de.cs.un_530  nl.af.eu_643 tk.no.fy_322 
  0x1f602508, 0x2c3f38ec, 0x5a57510c, 0x033f050c,   // eu.vo.cy_443 tk.af.fy_644  kl.na.sm_543 fr.af.nl_543 
  0x62796ba4, 0x400539a0, 0x382c10a4, 0x54271ca4,   // ceb.war.kha_433 br.fr.lb_322  lt.fy.tk_433 id.gd.ik_433 
  // [16b20]
  0x616b7905, 0x10383f12, 0x2c003820, 0x29094807,   // war.ceb.za_333 af.tk.lt_654  tk.fy.un_850 tt.pl.sl_432 
  0x1b113808, 0x0e152007, 0x2c482ea0, 0x32002c04,   // tk.ro.tr_443 sq.is.un_420  fo.tt.fy_322 fy.bs.un_320 
  0xfc001a0c, 0x48006513, 0x6bfe7912, 0x27650cee,   // tl.zzp.un_530 gv.tt.un_650  war.tlh.ceb_654 sv.gv.gd_422 
  0x51475408, 0x51fe62a4, 0x3f3b05a0, 0xfe7961a9,   // ik.sn.kl_443 kha.tlh.kl_433  fr.so.af_322 za.war.tlh_544 
  // [16b30]
  0x3b00550c, 0x09382caf, 0x2c023fa4, 0x2c3810a0,   // rw.so.un_530 fy.tk.pl_655  af.da.fy_433 lt.tk.fy_322 
  0x555b5405, 0x30314707, 0x2e0c02af, 0x5c001e12,   // ik.sg.rw_333 sn.az.uz_432  da.sv.fo_655 ms.sa.un_640 
  0x49005504, 0x2c2e0e07, 0x5528020c, 0x3d002813,   // rw.to.un_320 is.fo.fy_432  da.sw.rw_543 sd.ku.un_650 
  0x2a1d3508, 0x250e1307, 0x5528590c, 0x253035ec,   // zu.la.mt_443 et.is.eu_432  rn.sw.rw_543 tg.uz.mn_644 
  // [16b40]
  0x1d000408, 0x08010bee, 0x1b3811a7, 0x39005802,   // fi.la.un_430 es.en.no_422  ro.tk.tr_532 om.br.un_220 
  0x2f00450c, 0x654e2a07, 0x52285712, 0x420401a0,   // ln.su.un_530 mt.ay.gv_432  na.sw.ha_654 en.fi.co_322 
  0x04515812, 0x424301a4, 0x4d0701a0, 0x3e5c08a4,   // om.kl.fi_654 en.ie.co_433  en.it.aa_322 no.sa.rm_433 
  0x2a074212, 0x13222305, 0x5707420c, 0x0e3e400b,   // co.it.mt_654 ca.oc.et_333  co.it.na_543 lb.rm.is_542 
  // [16b50]
  0x1b291da6, 0x645c4e0c, 0x3b48300d, 0x321e1c14,   // la.sl.tr_521 ay.sa.lg_543  uz.tt.so_554 id.ms.bs_666 
  0x1d11040c, 0x045c0807, 0x330242a0, 0x424001a4,   // fi.ro.la_543 no.sa.fi_432  co.da.nn_322 en.lb.co_433 
  0x50001304, 0x512a3012, 0x151b3107, 0x4c3f63af,   // et.fj.un_320 uz.mt.kl_654  az.tr.un_432 sco.af.wo_655 
  0x48240102, 0x5c520107, 0x291d31a7, 0x52001504,   // en.eo.tt_222 en.ha.sa_432  az.la.sl_532 un.ha.un_320 
  // [16b60]
  0x570c49af, 0x15002207, 0x5c001c02, 0x1d1a685a,   // to.sv.na_655 oc.un.un_420  mr.sa.un_220 ig.tl.la_553 
  0x2e00491a, 0x171004a6, 0x733649ec, 0x67684512,   // to.fo.un_760 ru.be.sr_521  to.gn.ny_644 ln.ig.ak_654 
  0x57560e08, 0x12211811, 0x1d001911, 0x5e5d68a9,   // is.mg.na_443 ar.fa.ur_653  gl.la.un_630 ig.ss.ts_544 
  0x3b1936a0, 0x595534a4, 0x54000108, 0x1a5157a9,   // gn.gl.so_322 xh.rw.rn_433  en.ik.un_430 na.kl.tl_544 
  // [16b70]
  0x0c3049ad, 0x2e2a7907, 0x22002f04, 0x1f0c30a9,   // to.uz.sv_643 war.mt.fo_432  su.oc.un_320 uz.sv.cy_544 
  0x555a1d08, 0x0e332ead, 0x5d73530c, 0x5d025107,   // la.sm.rw_443 fo.nn.is_643  ht.ny.ss_543 kl.da.ss_432 
  0x0d382e07, 0x20212fa0, 0x65475aa4, 0x38251aa9,   // fo.tk.cs_432 su.jw.sq_322  sm.sn.gv_433 tl.eu.tk_544 
  0x36244804, 0x536105af, 0x3e041dee, 0x5d595505,   // tt.eo.gn_332 fr.za.ht_655  la.fi.rm_422 rw.rn.ss_333 
  // [16b80]
  0x24002012, 0x15222cad, 0x1b006404, 0x232134a0,   // sq.eo.un_640 fy.oc.un_643  lg.tr.un_320 ps.fa.ky_322 
  0x51655a0c, 0x6b001205, 0x1e100902, 0x2f6b28a4,   // sm.gv.kl_543 hu.ceb.un_330  pl.lt.ms_222 sw.ceb.su_433 
  0x24253007, 0x615b530c, 0x15295604, 0x12295612,   // uz.eu.eo_432 ht.sg.za_543  mg.sl.un_332 mg.sl.hu_654 
  0x532a7307, 0x201063a0, 0x65155302, 0x28645513,   // ny.mt.ht_432 sco.lt.sq_322  ht.gv.un_220 rw.lg.sw_665 
  // [16b90]
  0x070a11a9, 0x30310404, 0x54003b08, 0x032e3304,   // ro.mk.bg_544 fi.az.uz_332  so.ik.un_430 nn.fo.nl_332 
  0x1c2f1304, 0x47281308, 0x58001304, 0x18582705,   // et.su.id_332 et.sw.sn_443  et.om.un_320 gd.om.ga_333 
  0x4a513ba4, 0x02000f08, 0x79fc6b07, 0x37555f09,   // so.kl.yo_433 lv.da.un_430  ceb.zzp.war_432 tn.rw.st_444 
  0x1f002d02, 0x0711360b, 0x2e0f0e04, 0x20006107,   // sk.cy.un_220 ab.ro.bg_542  is.lv.fo_332 za.sq.un_420 
  // [16ba0]
  0x12004d0b, 0x19362e04, 0x2d2e0e07, 0x27001f07,   // aa.hu.un_520 fo.gn.gl_332  is.fo.sk_432 cy.gd.un_420 
  0x04003b05, 0x51023b12, 0x5100130c, 0x01636512,   // so.fi.un_330 so.da.kl_654  et.kl.un_530 gv.sco.en_654 
  0x63736508, 0x3b4d5a08, 0x0e653605, 0x56276507,   // gv.ny.sco_443 sm.aa.so_443  gn.gv.is_333 gv.gd.mg_432 
  0x28302107, 0x6301150d, 0x2f2163a0, 0x1b1e30a0,   // fa.uz.sd_432 un.en.sco_554  sco.jw.su_322 uz.ms.tr_322 
  // [16bb0]
  0x22000d0c, 0x282112ad, 0x39002712, 0x322909a7,   // cs.oc.un_530 ur.fa.sd_643  gd.br.un_640 pl.sl.bs_532 
  0x1f2f3902, 0x39001f11, 0x39020407, 0x09fe6112,   // br.su.cy_222 cy.br.un_630  fi.da.br_432 za.tlh.pl_654 
  0x2f3904af, 0x3508150c, 0x0b022fee, 0x27001f0d,   // fi.br.su_655 un.uk.tg_543  su.da.es_422 cy.gd.un_540 
  0x224c42a4, 0x5c6a1807, 0x6800340d, 0x18277304,   // co.wo.oc_433 ga.haw.sa_432  xh.ig.un_540 ny.gd.ga_332 
  // [16bc0]
  0x495a18a0, 0x162d0da0, 0x46005c08, 0x12253955,   // ga.sm.to_322 cs.sk.hr_322  sa.qu.un_430 br.eu.hu_442 
  0xfc102504, 0x06022f07, 0x1e027307, 0x13104705,   // eu.lt.zzp_332 su.da.de_432  ny.da.ms_432 sn.lt.et_333 
  0x495a5214, 0x6a003304, 0x18210fa4, 0x1a796aa0,   // ha.sm.to_666 nn.haw.un_320  lv.jw.ga_433 haw.war.tl_322 
  0x3e422307, 0x285c4a08, 0x22001909, 0x303735ee,   // ca.co.rm_432 yo.sa.sw_443  gl.oc.un_440 tg.ba.uz_422 
  // [16bd0]
  0x33082105, 0x4b006a29, 0x4b280408, 0x13182708,   // jw.no.nn_333 haw.mi.un_960  fi.sw.mi_443 gd.ga.et_443 
  0x511827ee, 0x50276508, 0x2e0e1da0, 0x6527230c,   // gd.ga.kl_422 gv.gd.fj_443  la.is.fo_322 ca.gd.gv_543 
  0x60271860, 0x062c4007, 0x27651812, 0x15303caf,   // ga.gd.vo_664 lb.fy.de_432  ga.gv.gd_654 ug.uz.un_655 
  0x0600401a, 0x5f00020c, 0x0e2e180c, 0x483804a4,   // lb.de.un_760 da.tn.un_530  ga.fo.is_543 ru.tk.tt_433 
  // [16be0]
  0x04652708, 0x5e00650c, 0x231b22a0, 0x354837a7,   // gd.gv.fi_443 gv.ts.un_530  oc.tr.ca_322 ba.tt.tg_532 
  0x0715380b, 0x2523300b, 0x040a17af, 0x18482904,   // tk.bg.un_520 uz.ky.mn_542  sr.mk.ru_655 sl.tt.ga_332 
  0x172d2904, 0x1d041304, 0x1d131ba4, 0x390243a7,   // sl.sk.sr_332 et.fi.la_332  tr.et.la_433 ie.da.br_532 
  0x0a0e235a, 0x326b1dee, 0x3f2223ee, 0x25170a02,   // ca.is.pt_553 la.ceb.bs_422  ca.oc.af_422 mk.sr.mn_222 
  // [16bf0]
  0x2a0b5808, 0x5b5f3b0c, 0x561f37a4, 0x495a4fa0,   // om.es.mt_443 so.tn.sg_543  st.cy.mg_433 bi.sm.to_322 
  0x78571209, 0x3b00331a, 0x44373c0d, 0x10072d0c,   // hu.na.ve_444 nn.so.un_760  ug.ba.kk_554 sk.it.lt_543 
  0x3b5f75a9, 0x58004c05, 0x73192812, 0x5a003b04,   // nso.tn.so_544 wo.om.un_330  sw.gl.ny_654 so.sm.un_320 
  0x111a7905, 0x42383b04, 0x043b4c07, 0x6e006712,   // war.tl.ro_333 so.tk.co_332  wo.so.fi_432 ak.hmn.un_640 
  
  // [16c00]
  0x3e2425ee, 0x335a1955, 0x4a56400c, 0x0b0a5202,   // eu.eo.rm_422 gl.sm.nn_442  lb.mg.yo_543 ha.pt.es_222 
  0x4c001b05, 0x282469a0, 0x18000e11, 0x18005307,   // tr.wo.un_330 mfe.eo.sw_322  is.ga.un_630 ht.ga.un_420 
  0x09001c18, 0x532460a6, 0x1f2305a0, 0x430a2307,   // mr.hi.un_740 vo.eo.ht_521  fr.ca.cy_322 ca.pt.ie_432 
  0x292421a0, 0x39242902, 0x235e0b02, 0x5a00510e,   // jw.eo.sl_322 sl.eo.br_222  es.ts.ca_222 kl.sm.un_550 
  // [16c10]
  0x0a182204, 0x44353009, 0x48440402, 0x170708a7,   // oc.ga.pt_332 uz.tg.kk_444  ru.kk.tt_222 uk.bg.sr_532 
  0x061f3007, 0x10070804, 0x440817ee, 0x481708ee,   // uz.cy.de_432 uk.bg.be_332  sr.uk.kk_422 uk.sr.tt_422 
  0x5e00250d, 0x4438480b, 0x191236ad, 0x495a4b04,   // eu.ts.un_540 tt.tk.kk_542  gn.hu.gl_643 mi.sm.to_332 
  0x3800232b, 0x64475e04, 0x33082ea6, 0x190a2da0,   // ky.tk.un_980 ts.sn.lg_332  fo.no.nn_521 sk.pt.gl_322 
  // [16c20]
  0x040810a7, 0x0a07080b, 0x64581d04, 0x1d391fee,   // be.uk.ru_532 uk.bg.mk_542  la.om.lg_332 cy.br.la_422 
  0x33022e09, 0x34684a0c, 0x1d001004, 0x1b314da6,   // fo.da.nn_444 yo.ig.xh_543  lt.la.un_320 aa.az.tr_521 
  0x454a57a4, 0x10132014, 0x23190bad, 0x193901a4,   // na.yo.ln_433 sq.et.lt_666  es.gl.ca_643 en.br.gl_433 
  0x533969ad, 0x38003912, 0x533263a0, 0x443817a0,   // mfe.br.ht_643 br.tk.un_640  sco.bs.ht_322 sr.tk.kk_322 
  // [16c30]
  0x061d6502, 0x38003902, 0x483130ee, 0x303237a6,   // gv.la.de_222 br.tk.un_220  uz.az.tt_422 st.bs.uz_521 
  0x3f0465a0, 0x2f21360c, 0x37234812, 0x182130a4,   // gv.fi.af_322 gn.jw.su_543  tt.ky.ba_654 uz.fa.ar_433 
  0x212f28ee, 0x20002107, 0x64284704, 0x38004823,   // sw.su.jw_422 jw.sq.un_420  sn.sw.lg_332 tt.tk.un_880 
  0x5e001e0d, 0x2253050e, 0x04070aee, 0x28183dec,   // ms.ts.un_540 fr.ht.oc_555  mk.bg.ru_422 ku.ar.sd_644 
  // [16c40]
  0x34213cec, 0x02002e11, 0x441823af, 0x59552e09,   // ug.fa.ps_644 fo.da.un_630  ky.ar.kk_655 fo.rw.rn_444 
  0x28123b12, 0x47004905, 0x37003818, 0x5b5d45a9,   // ks.ur.sd_654 to.sn.un_330  tk.ba.un_740 ln.ss.sg_544 
  0x6b54790c, 0x030624a0, 0x025313a0, 0x3f1106a0,   // war.ik.ceb_543 eo.de.nl_322  et.ht.da_322 de.ro.af_322 
  0x34fa3508, 0x5c060e07, 0x5500450d, 0x03243f04,   // zu.nr.xh_443 is.de.sa_432  ln.rw.un_540 af.eo.nl_332 
  // [16c50]
  0x424d0555, 0x34305eee, 0x305e5655, 0x1f1d4d0c,   // fr.aa.co_442 ts.uz.xh_422  mg.ts.uz_442 aa.la.cy_543 
  0x031d3f02, 0x033f2402, 0x474933a0, 0x5c0a790c,   // af.la.nl_222 eo.af.nl_222  nn.to.sn_322 war.pt.sa_543 
  0x063f0305, 0x4b4f0107, 0x5e6408a4, 0x481738a0,   // nl.af.de_333 en.bi.mi_432  no.lg.ts_433 tk.sr.tt_322 
  0x2d0d47a0, 0x08110405, 0x12000521, 0x6728250c,   // sn.cs.sk_322 ru.ro.uk_333  fr.hu.un_860 eu.sw.ak_543 
  // [16c60]
  0x35001a04, 0x16002d0c, 0x0e005414, 0x3b2858ad,   // tl.zu.un_320 sk.hr.un_530  ik.is.un_660 om.sw.so_643 
  0x33007912, 0x030624a4, 0x11005812, 0x36002008,   // war.nn.un_640 eo.de.nl_433  om.ro.un_640 sq.gn.un_430 
  0x113b5813, 0x58005712, 0x791209af, 0x0a007912,   // om.so.ro_665 na.om.un_640  pl.hu.war_655 war.pt.un_640 
  0x11005813, 0x11005818, 0x544d52a4, 0x081011a6,   // om.ro.un_650 om.ro.un_740  ha.aa.ik_433 ro.be.uk_521 
  // [16c70]
  0x0e311f11, 0x11002208, 0x00002042, 0x583b1109,   // cy.az.is_653 oc.ro.un_430  ti.un.un_C00 ro.so.om_444 
  0x3c304414, 0x080a07ec, 0x304835a0, 0x2b190a0c,   // kk.uz.ug_666 bg.mk.uk_644  tg.tt.uz_322 pt.gl.vi_543 
  0x0a3011a0, 0x00003c37, 0x3848350c, 0x18001a07,   // ro.uz.mk_322 ug.un.un_B00  tg.tt.tk_543 tl.ga.un_420 
  0x3f6e1312, 0x3f033eee, 0x2700fe19, 0x03693f05,   // et.hmn.af_654 rm.nl.af_422  tlh.gd.un_750 af.mfe.nl_333 
  // [16c80]
  0x6e006305, 0x3f6e0307, 0x080a38a4, 0x18273bee,   // sco.hmn.un_330 nl.hmn.af_432  tk.mk.uk_433 so.gd.ga_422 
  0x3b4c6eac, 0x343835a0, 0x3b562f08, 0x174815a0,   // hmn.wo.so_632 zu.tk.xh_322  su.mg.so_443 un.tt.sr_322 
  0x561e1c13, 0x3f036ea0, 0x406e4c04, 0x213f5802,   // id.ms.mg_665 hmn.nl.af_322  wo.hmn.lb_332 om.af.jw_222 
  0x7300210d, 0x196e0a07, 0x6100521a, 0x4a001902,   // jw.ny.un_540 pt.hmn.gl_432  ha.za.un_760 gl.yo.un_220 
  // [16c90]
  0x566553a4, 0x61005622, 0x46001904, 0x31483813,   // ht.gv.mg_433 mg.za.un_870  gl.qu.un_320 tk.tt.az_665 
  0x42584da9, 0x40301f07, 0x21003308, 0x54005129,   // aa.om.co_544 cy.uz.lb_432  nn.jw.un_430 kl.ik.un_960 
  0x133b58ec, 0x303bfe0b, 0x32163fa4, 0x2f56170c,   // om.so.et_644 tlh.so.uz_542  af.hr.bs_433 sr.mg.su_543 
  0x08042302, 0x11fc5aa4, 0x0720240c, 0x1c006e07,   // ky.ru.uk_222 sm.zzp.ro_433  eo.sq.it_543 hmn.id.un_420 
  // [16ca0]
  0x020833a7, 0x1d1824a9, 0x081511ad, 0x24606e60,   // nn.no.da_532 eo.ga.la_544  ro.uk.un_630 hmn.vo.eo_664 
  0x100a0704, 0x6a5a4911, 0x15300407, 0x36005711,   // bg.mk.be_332 to.sm.haw_653  ru.uz.un_432 na.gn.un_630 
  0x642965a4, 0x5f027511, 0x08003318, 0x0c006012,   // gv.sl.lg_433 nso.da.tn_653  nn.no.un_740 vo.sv.un_640 
  0x15043c13, 0x56595513, 0x43311ba4, 0x36484e11,   // ug.ru.un_665 rw.rn.mg_665  tr.az.ie_433 ay.tt.gn_653 
  // [16cb0]
  0x33005f08, 0x0e2e25ee, 0x36005635, 0x1e4238a4,   // tn.nn.un_430 eu.fo.is_422  mg.gn.un_A90 tk.co.ms_433 
  0x310e5ca4, 0x2e003319, 0x6400562b, 0x1b0e3804,   // sa.is.az_433 nn.fo.un_750  mg.lg.un_980 tk.is.tr_332 
  0x0d5c1c0e, 0x225f2fa0, 0x103547a0, 0x30481ba0,   // mr.sa.ne_555 su.tn.oc_322  sn.zu.lt_322 tr.tt.uz_322 
  0x3100540d, 0x1300570c, 0x130640ee, 0x480b460c,   // ik.az.un_540 na.et.un_530  lb.de.et_422 qu.es.tt_543 
  // [16cc0]
  0x1f650d02, 0x6763010b, 0x3034210d, 0x0a302304,   // cs.gv.cy_222 en.sco.ak_542  fa.ps.uz_554 ky.uz.mk_332 
  0x016355a0, 0x471f730c, 0x2d4735a6, 0x30213b08,   // rw.sco.en_322 ny.cy.sn_543  zu.sn.sk_521 ks.fa.uz_443 
  0x65005d05, 0x11103609, 0x187909ee, 0x656806ee,   // ss.gv.un_330 ab.be.ro_444  pl.war.ga_422 de.ig.gv_422 
  0x12230ba0, 0x011d1508, 0x043b5813, 0x6b06010c,   // es.ca.hu_322 un.la.en_443  om.so.fi_665 en.de.ceb_543 
  // [16cd0]
  0x5800041b, 0x17150855, 0x25482007, 0x3b045807,   // fi.om.un_770 uk.sr.un_420  sq.tt.eu_432 om.fi.so_432 
  0x0b0a4805, 0x0167fc07, 0x18213da4, 0x790458ec,   // tt.pt.es_333 zzp.ak.en_432  ku.fa.ar_433 om.fi.war_644 
  0x65006112, 0x40061e02, 0x28546a60, 0x0e2e390b,   // za.gv.un_640 ms.de.lb_222  haw.ik.sw_664 br.fo.is_542 
  0x3404faad, 0x0a08360c, 0x2f6a2807, 0x46002e0c,   // nr.fi.xh_643 ab.uk.mk_543  sw.haw.su_432 fo.qu.un_530 
  // [16ce0]
  0x79353408, 0x475d2ea0, 0x482e0419, 0x25001502,   // xh.zu.war_443 fo.ss.sn_322  fi.fo.tt_765 un.eu.un_220 
  0x1c1e2104, 0x0900040b, 0x1f002007, 0x2335150c,   // jw.ms.id_332 fi.pl.un_520  sq.cy.un_420 un.tg.ky_543 
  0x11001522, 0x37041108, 0x111715a4, 0x36000907,   // un.ro.un_870 ro.ru.ba_443  un.sr.ro_433 pl.gn.un_420 
  0x0a110708, 0x4a000213, 0x40023ea7, 0x084837a7,   // bg.ro.mk_443 da.yo.un_650  rm.da.lb_532 ba.tt.uk_532 
  // [16cf0]
  0x3e2e0ea0, 0x4b0d6a05, 0x28005807, 0x5800110d,   // is.fo.rm_322 haw.cs.mi_333  om.sw.un_420 ro.om.un_540 
  0x11285808, 0x111d58ad, 0x46004007, 0x0e2a3e07,   // om.sw.ro_443 om.la.ro_643  lb.qu.un_420 rm.mt.is_432 
  0x382552af, 0x091d1104, 0x3b0312a9, 0x25002f02,   // ha.eu.tk_655 ro.la.pl_332  hu.nl.so_544 su.eu.un_220 
  0x2f383ba7, 0x2800590e, 0x34000302, 0x22003f07,   // so.tk.su_532 rn.sw.un_550  nl.xh.un_220 af.oc.un_420 
  // [16d00]
  0x2e0e3307, 0x063f0304, 0x40060c0c, 0x0c005b19,   // nn.is.fo_432 nl.af.de_332  sv.de.lb_543 sg.sv.un_750 
  0x0c5b1312, 0x5b060cec, 0x56003618, 0x33005604,   // et.sg.sv_654 sv.de.sg_644  gn.mg.un_740 mg.nn.un_320 
  0x34301813, 0x0c065b21, 0x060c5b13, 0x37100404,   // ar.uz.ps_665 sg.de.sv_876  sg.sv.de_665 ru.be.ba_332 
  0x16190b0c, 0x480613a7, 0x38485b10, 0x4b005b12,   // es.gl.hr_543 et.de.tt_532  sg.tt.tk_642 sg.mi.un_640 
  // [16d10]
  0x3600380c, 0x0648400d, 0x04134802, 0x48231012,   // tk.gn.un_530 lb.tt.de_554  tt.et.fi_222 be.ky.tt_654 
  0x3900631a, 0x4b395bee, 0x542e01a0, 0x533905a7,   // sco.br.un_760 sg.br.mi_422  en.fo.ik_322 fr.br.ht_532 
  0x6505280c, 0x52490502, 0x796939a7, 0x3f003312,   // sw.fr.gv_543 fr.to.ha_222  br.mfe.war_532 nn.af.un_640 
  0x0c06130c, 0x00005637, 0x4bfe1c0c, 0x054a1da0,   // et.de.sv_543 mg.un.un_B00  id.tlh.mi_543 la.yo.fr_322 
  // [16d20]
  0xfc351ca0, 0x48130c12, 0x400638a9, 0x0565630c,   // id.zu.zzp_322 sv.et.tt_654  tk.de.lb_544 sco.gv.fr_543 
  0x0e48450c, 0x65021807, 0x61003409, 0x3900020e,   // ln.tt.is_543 ga.da.gv_432  xh.za.un_440 da.br.un_550 
  0x1c001320, 0x28355d12, 0x65003921, 0xfc26020c,   // bh.mr.un_850 ss.zu.sw_654  br.gv.un_860 da.ia.zzp_543 
  0x1d3ffc5a, 0x2cfc01a0, 0x51003f07, 0x36003508,   // zzp.af.la_553 en.zzp.fy_322  af.kl.un_420 tg.ab.un_430 
  // [16d30]
  0x64471ea4, 0xfc133307, 0xfe000c08, 0x615e34a4,   // ms.sn.lg_433 nn.et.zzp_432  sv.tlh.un_430 xh.ts.za_433 
  0x36004708, 0x07350a0d, 0x1115040c, 0xfc584a07,   // sn.gn.un_430 mk.tg.bg_554  ru.ro.un_530 yo.om.zzp_432 
  0x4a270fa0, 0x0f402c02, 0x130264ad, 0x174410a7,   // lv.gd.yo_322 fy.lb.lv_222  lg.da.et_643 be.kk.sr_532 
  0x4a2c400c, 0x23000a0d, 0x09003e14, 0x402807ee,   // lb.fy.yo_543 mk.ky.un_540  rm.pl.un_660 it.sw.lb_422 
  // [16d40]
  0x132c10a4, 0x5a003404, 0x40390204, 0x1a134204,   // lt.fy.et_433 xh.sm.un_320  da.br.lb_332 co.et.tl_332 
  0x39024c0c, 0x2308110c, 0x4a52480c, 0x122d2212,   // wo.da.br_543 ro.uk.ky_543  tt.ha.yo_543 oc.sk.hu_654 
  0x3c00442a, 0x2f4859ad, 0x44000707, 0x060333a9,   // kk.ug.un_970 rn.tt.su_643  bg.kk.un_420 nn.nl.de_544 
  0x2d1d2704, 0x3e00091b, 0x64433ea4, 0x09003e19,   // gd.la.sk_332 pl.rm.un_770  rm.ie.lg_433 rm.pl.un_750 
  // [16d50]
  0x173015ee, 0x400413a7, 0x0e422e07, 0x40060ca9,   // un.uz.sr_422 et.fi.lb_532  fo.co.is_432 sv.de.lb_544 
  0x02003313, 0x76130208, 0x34282113, 0x27480107,   // nn.da.un_650 da.et.crs_443  fa.sd.ps_665 en.tt.gd_432 
  0x04401307, 0x1d0218a4, 0x13004821, 0x3412185a,   // et.lb.fi_432 ga.da.la_433  tt.et.un_860 ar.ur.ps_553 
  0x480a1055, 0x3e105c07, 0x24631b07, 0x311b38ad,   // be.mk.tt_442 sa.lt.rm_432  tr.sco.eo_432 tk.tr.az_643 
  // [16d60]
  0x614b6a12, 0x1e1363ee, 0x587904a9, 0x1347040c,   // haw.mi.za_654 sco.et.ms_422  fi.war.om_544 fi.sn.et_543 
  0x510e02ad, 0x4f1b0407, 0x0f0410a6, 0x33250f11,   // da.is.kl_643 fi.tr.bi_432  lt.fi.lv_521 lv.eu.nn_653 
  0x223e1004, 0x4b00040b, 0x4a1158af, 0x2f0e2108,   // lt.rm.oc_332 fi.mi.un_520  om.ro.yo_655 jw.is.su_443 
  0x10610f07, 0x3748305a, 0x04005812, 0x50190ba0,   // lv.za.lt_432 uz.tt.ba_553  om.fi.un_640 es.gl.fj_322 
  // [16d70]
  0x63110a04, 0x2d2004af, 0x25000f0d, 0x5c455407,   // pt.ro.sco_332 fi.sq.sk_655  lv.eu.un_540 ik.ln.sa_432 
  0x1b300204, 0x10224712, 0x034728a0, 0x25045004,   // da.uz.tr_332 sn.oc.lt_654  sw.sn.nl_322 fj.fi.eu_332 
  0x10040fa4, 0x4b650408, 0x04470fee, 0x0452070c,   // lv.fi.lt_433 fi.gv.mi_443  lv.sn.fi_422 it.ha.fi_543 
  0x0f041008, 0x27044b07, 0x19460a60, 0x39001c04,   // lt.fi.lv_443 mi.fi.gd_432  pt.qu.gl_664 id.br.un_320 
  // [16d80]
  0x0c1d30a0, 0x040c13ee, 0x110458a4, 0x020c2902,   // uz.la.sv_322 et.sv.fi_422  om.fi.ro_433 sl.sv.da_222 
  0x233e2209, 0x02425804, 0x2a001f0e, 0x30253860,   // oc.rm.ca_444 om.co.da_332  cy.mt.un_550 tk.mn.uz_664 
  0x06400c0c, 0x040c40ac, 0x024358a7, 0x4c3308ad,   // sv.lb.de_543 lb.sv.fi_632  om.ie.da_532 no.nn.wo_643 
  0x53002d0d, 0x0a286404, 0x0c000812, 0x04000c13,   // sk.ht.un_540 lg.sw.pt_332  no.sv.un_640 sv.fi.un_650 
  // [16d90]
  0x030458a9, 0x44482302, 0x04000c1e, 0x2c3f060c,   // om.fi.nl_544 ky.tt.kk_222  sv.fi.un_830 de.af.fy_543 
  0x6000031b, 0x646330ee, 0x0600020e, 0x10374811,   // nl.vo.un_770 uz.sco.lg_422  da.de.un_550 tt.ba.be_653 
  0x3f0308a4, 0x5a061855, 0x1306020d, 0x640206a0,   // no.nl.af_433 ga.de.sm_442  da.de.et_554 de.da.lg_322 
  0x3f2c0608, 0x07331208, 0x36005c1b, 0x2c036404,   // de.fy.af_443 hu.nn.it_443  sa.gn.un_770 lg.nl.fy_332 
  // [16da0]
  0x21003612, 0x2403530c, 0x38130c0b, 0x5c1c0d09,   // gn.jw.un_640 ht.nl.eo_543  sv.et.tk_542 ne.mr.sa_444 
  0x02000e0d, 0x04002104, 0x6e002d0c, 0x1e285304,   // is.da.un_540 jw.fi.un_320  sk.hmn.un_530 ht.sw.ms_332 
  0x13022807, 0x32174f11, 0x275613ee, 0x6e002d0d,   // sw.da.et_432 bi.sr.bs_653  et.mg.gd_422 sk.hmn.un_540 
  0x13002e08, 0x13005a08, 0x0b074304, 0x2b002104,   // fo.et.un_430 sm.et.un_430  ie.it.es_332 jw.vi.un_320 
  // [16db0]
  0x37360407, 0x192c3604, 0x434226af, 0x68584d55,   // ru.ab.ba_432 gn.fy.gl_332  ia.co.ie_655 aa.om.ig_442 
  0x2f2104a4, 0x11156eee, 0x40001310, 0x56215a02,   // fi.jw.su_433 hmn.ro.un_420  et.lb.un_620 sm.jw.mg_222 
  0x0400640d, 0x291e4da0, 0x19001304, 0x04000c14,   // lg.fi.un_540 aa.ms.sl_322  et.gl.un_320 sv.fi.un_660 
  0x4c586455, 0x181a3904, 0x04000c12, 0x0c043eee,   // lg.om.wo_442 br.tl.ga_332  sv.fi.un_640 rm.fi.sv_422 
  // [16dc0]
  0x2b004a0e, 0x1d00510e, 0xfc0c0204, 0x2b005b13,   // yo.vi.un_550 kl.la.un_550  da.sv.zzp_332 sg.vi.un_650 
  0x67005721, 0x04132c08, 0x3b4028a0, 0x4c001f0c,   // na.ak.un_860 fy.et.fi_443  sw.lb.so_322 cy.wo.un_530 
  0x67001e04, 0x2b004a0c, 0x68004a21, 0x56364205,   // ms.ak.un_320 yo.vi.un_530  yo.ig.un_860 co.gn.mg_333 
  0x791c2fad, 0x28546409, 0x5200fe14, 0x734521a9,   // su.id.war_643 lg.ik.sw_444  tlh.ha.un_660 jw.ln.ny_544 
  // [16dd0]
  0x122128a6, 0x48114407, 0x79000c12, 0x575a4ba4,   // sd.fa.ur_521 kk.ro.tt_432  sv.war.un_640 mi.sm.na_433 
  0x5c000202, 0x3ffc7605, 0x5f2f25ec, 0x0e572eaf,   // da.sa.un_220 crs.zzp.af_333  eu.su.tn_644 fo.na.is_655 
  0x211c2008, 0x595525a9, 0x5500fe12, 0x0a003c14,   // sq.id.jw_443 eu.rw.rn_544  tlh.rw.un_640 ug.mk.un_660 
  0x04212f0c, 0x5028fe0c, 0x4659fead, 0x04070a55,   // su.jw.fi_543 tlh.sw.fj_543  tlh.rn.qu_643 mk.bg.ru_442 
  // [16de0]
  0x0c007907, 0x3f2153a0, 0x734a6412, 0x154301a9,   // war.sv.un_420 ht.jw.af_322  lg.yo.ny_654 en.ie.un_544 
  0x3400fc18, 0x25234814, 0x7378475a, 0x2f214d09,   // zzp.xh.un_740 tt.ky.mn_666  sn.ve.ny_553 aa.jw.su_444 
  0x0c5c290e, 0x010302a4, 0x21004d21, 0x21121e09,   // sl.sa.sv_555 da.nl.en_433  aa.jw.un_860 ms.hu.jw_444 
  0x230e2e02, 0x4d1e1c0c, 0x24fc3eee, 0x2d0d4da0,   // fo.is.ca_222 id.ms.aa_543  rm.zzp.eo_422 aa.cs.sk_322 
  // [16df0]
  0x28357307, 0x12514d0c, 0x28182105, 0x3e004704,   // ny.zu.sw_432 aa.kl.hu_543  fa.ar.sd_333 sn.rm.un_320 
  0x57604d5a, 0x25470407, 0x211b4d0c, 0x2e1d3ead,   // aa.vo.na_553 fi.sn.eu_432  aa.tr.jw_543 rm.la.fo_643 
  0x16000907, 0x4d001f19, 0x300408ad, 0x21301804,   // pl.hr.un_420 cy.aa.un_750  uk.ru.uz_643 ar.uz.fa_332 
  0x1b1225a4, 0x61304d08, 0x08002c0b, 0x02003e19,   // eu.hu.tr_433 aa.uz.za_443  fy.no.un_520 rm.da.un_750 
  // [16e00]
  0x213b3407, 0x070411ee, 0x34001b08, 0x212f38af,   // ps.ks.fa_432 ro.ru.bg_422  tr.xh.un_430 tk.su.jw_655 
  0x1e001c36, 0x51212f02, 0x514d1ea4, 0xfe290da4,   // id.ms.un_AA0 su.jw.kl_222  ms.aa.kl_433 cs.sl.tlh_433 
  0x04103709, 0x462f4ba4, 0x04003e14, 0xfe003b14,   // ba.be.ru_444 mi.su.qu_433  rm.fi.un_660 so.tlh.un_660 
  0x3200fe09, 0x21001602, 0x1d255708, 0x3e00040d,   // tlh.bs.un_440 hr.jw.un_220  na.eu.la_443 fi.rm.un_540 
  // [16e10]
  0x07571d12, 0x30123b12, 0x17374811, 0x4b6a1a12,   // la.na.it_654 ks.ur.uz_654  tt.ba.sr_653 tl.haw.mi_654 
  0x36044808, 0x64002e04, 0x11004307, 0x25001518,   // tt.fi.gn_443 fo.lg.un_320  ie.ro.un_420 un.mn.un_740 
  0x171015a0, 0x0d2e0807, 0x232226a9, 0x370410ee,   // un.be.sr_322 no.fo.cs_432  ia.oc.ca_544 be.ru.ba_422 
  0x292312a9, 0x494a2d10, 0x02002210, 0x043e4dad,   // hu.ca.sl_544 sk.yo.to_642  oc.da.un_620 aa.rm.fi_643 
  // [16e20]
  0x233525a4, 0x38002204, 0x29232207, 0x460c5108,   // mn.tg.ky_433 oc.tk.un_320  oc.ca.sl_432 kl.sv.qu_443 
  0x122d0d11, 0x51000c04, 0x4547360c, 0x0e0c51a7,   // cs.sk.hu_653 sv.kl.un_320  gn.sn.ln_543 kl.sv.is_532 
  0x2d360d11, 0x0c006b08, 0x092c40ee, 0x373f3008,   // cs.gn.sk_653 ceb.sv.un_430  lb.fy.pl_422 uz.af.st_443 
  0x043736a7, 0x32164702, 0x652c40a6, 0x0d2d22a9,   // ab.ba.ru_532 sn.hr.bs_222  lb.fy.gv_521 oc.sk.cs_544 
  // [16e30]
  0x11000d04, 0x162d0d5a, 0x22292307, 0x1a001d04,   // cs.ro.un_320 cs.sk.hr_553  ca.sl.oc_432 la.tl.un_320 
  0x29231207, 0x0e006514, 0x33081da0, 0x23021d04,   // hu.ca.sl_432 gv.is.un_660  la.no.nn_322 la.da.ca_332 
  0x0c00190d, 0x30350402, 0x132d0d0b, 0x362d0d14,   // gl.sv.un_540 ru.tg.uz_222  cs.sk.et_542 cs.sk.gn_666 
  0x21794eee, 0x301d0c05, 0x320c5104, 0x1e211ca0,   // ay.war.jw_422 sv.la.uz_333  kl.sv.bs_332 id.jw.ms_322 
  // [16e40]
  0x082d0d0b, 0x3b006b07, 0x30003f02, 0x1e1c54ee,   // cs.sk.no_542 ceb.so.un_420  af.uz.un_220 ik.id.ms_422 
  0x0c032c09, 0x115842ec, 0x23443811, 0x4b004a02,   // fy.nl.sv_444 co.om.ro_644  tk.kk.ky_653 yo.mi.un_220 
  0x321e1c04, 0x3e1c1ea7, 0x40004207, 0x1c001104,   // id.ms.bs_332 ms.id.rm_532  co.lb.un_420 ro.id.un_320 
  0x1f4c1ca4, 0x0e3e2aac, 0x3e00610d, 0x215f190c,   // id.wo.cy_433 mt.rm.is_632  za.rm.un_540 gl.tn.jw_543 
  // [16e50]
  0x2d002702, 0x33212a0c, 0x402a0e12, 0x336957a4,   // gd.sk.un_220 mt.jw.nn_543  is.mt.lb_654 na.mfe.nn_433 
  0x2f07750c, 0x0e002a33, 0x5a632fee, 0x13271812,   // nso.it.su_543 mt.is.un_A70  su.sco.sm_422 ga.gd.et_654 
  0x1730290c, 0x03233fa0, 0x04425807, 0x28755f55,   // sl.uz.sr_543 af.ca.nl_322  om.co.fi_432 tn.nso.sw_442 
  0x693b53a4, 0x30234414, 0x63674055, 0x5d5e20a0,   // ht.so.mfe_433 kk.ky.uz_666  lb.ak.sco_442 sq.ts.ss_322 
  // [16e60]
  0x112d0d02, 0xfc3909ee, 0x332e0e02, 0x553564a0,   // cs.sk.ro_222 pl.br.zzp_422  is.fo.nn_222 lg.zu.rw_322 
  0x3e0657a6, 0x351925a7, 0x040a0755, 0x2f006419,   // na.de.rm_521 eu.gl.zu_532  bg.mk.ru_442 lg.su.un_750 
  0x1f00550d, 0x43214707, 0x5f025a08, 0x2f003408,   // rw.cy.un_540 sn.jw.ie_432  sm.da.tn_443 xh.su.un_430 
  0x0e402760, 0x27651804, 0x68004713, 0x182769af,   // gd.lb.is_664 ga.gv.gd_332  sn.ig.un_650 mfe.gd.ga_655 
  // [16e70]
  0x112522a0, 0x0b2d1904, 0x2e0d2d07, 0x57600612,   // oc.eu.ro_322 gl.sk.es_332  sk.cs.fo_432 de.vo.na_654 
  0x23362511, 0x6a654b05, 0x6a4b0408, 0x5a00282b,   // mn.ab.ky_653 mi.gv.haw_333  fi.mi.haw_443 sw.sm.un_980 
  0x12000d1a, 0x5a041308, 0x25361509, 0x221d54a9,   // cs.hu.un_760 et.fi.sm_443  un.ab.mn_444 ik.la.oc_544 
  0x191b22a0, 0x0d003622, 0x341218ac, 0x1a1e06ee,   // oc.tr.gl_322 gn.cs.un_870  ar.ur.ps_632 de.ms.tl_422 
  // [16e80]
  0x36000d0c, 0x1d2265a4, 0x50252207, 0x50255a0d,   // cs.gn.un_530 gv.oc.la_433  oc.eu.fj_432 sm.eu.fj_554 
  0x21123013, 0x1000370c, 0x2d360da7, 0x22006508,   // uz.ur.fa_665 ba.be.un_530  cs.gn.sk_532 gv.oc.un_430 
  0x13004b0e, 0x65005a14, 0x12213d02, 0x2f000802,   // mi.et.un_550 sm.gv.un_660  ku.fa.ur_222 no.su.un_220 
  0x06580f08, 0x4b495aec, 0x09003405, 0x252f1ca0,   // lv.om.de_443 sm.to.mi_644  xh.pl.un_330 id.su.eu_322 
  // [16e90]
  0x3723100c, 0x02003b12, 0x020c08af, 0x183c34ec,   // be.ky.ba_543 so.da.un_640  no.sv.da_655 ps.ug.ar_644 
  0x6b1a7912, 0x4c6a3bad, 0x17104404, 0x27003b07,   // war.tl.ceb_654 so.haw.wo_643  kk.be.sr_332 so.gd.un_420 
  0x7500371a, 0x4b000602, 0x31045108, 0x794a5404,   // st.nso.un_760 de.mi.un_220  kl.fi.az_443 ik.yo.war_332 
  0x2e490e07, 0x24005f04, 0x3008350c, 0x240d3107,   // is.to.fo_432 tn.eo.un_320  tg.uk.uz_543 az.cs.eo_432 
  // [16ea0]
  0x3b644dee, 0x42021304, 0x13005112, 0xfe002407,   // aa.lg.so_422 et.da.co_332  kl.et.un_640 eo.tlh.un_420 
  0x12004609, 0x040912ee, 0x48125404, 0x5100130d,   // qu.hu.un_440 hu.pl.fi_422  ik.hu.tt_332 et.kl.un_540 
  0x241251a4, 0x3c1015a7, 0x5102330c, 0x33003905,   // kl.hu.eo_433 un.be.ug_532  nn.da.kl_543 br.nn.un_330 
  0x2c333409, 0x2c1039a7, 0x5d095a07, 0x0a1229ee,   // xh.nn.fy_444 br.lt.fy_532  sm.pl.ss_432 sl.hu.pt_422 
  // [16eb0]
  0x1200230c, 0x0a25150c, 0x0c203304, 0x483902a0,   // ky.ur.un_530 un.mn.mk_543  nn.sq.sv_332 da.br.tt_322 
  0x49004512, 0x400e0602, 0x37495a0b, 0x154973a0,   // ln.to.un_640 de.is.lb_222  sm.to.st_542 ny.to.un_322 
  0x04351707, 0x120742a0, 0x11001212, 0x63794808,   // sr.tg.ru_432 co.it.hu_322  hu.ro.un_640 tt.war.sco_443 
  0x79002c08, 0x5a494b0e, 0x480833ad, 0x5a13490d,   // fy.war.un_430 mi.to.sm_555  nn.no.tt_643 to.et.sm_554 
  // [16ec0]
  0x47357304, 0x733528af, 0x02365208, 0x6a494b12,   // ny.zu.sn_332 sw.zu.ny_655  ha.gn.da_443 mi.to.haw_654 
  0x49004b1b, 0x50496a0c, 0x47565111, 0x475a0e07,   // mi.to.un_770 haw.to.fj_543  kl.mg.sn_653 is.sm.sn_432 
  0x04006121, 0x5c1e65a4, 0x12006011, 0x4b5a49a4,   // za.fi.un_860 gv.ms.sa_433  vo.hu.un_630 to.sm.mi_433 
  0x275c61a7, 0x65006121, 0x5c276502, 0x5c00610d,   // za.sa.gd_532 za.gv.un_860  gv.gd.sa_222 za.sa.un_540 
  // [16ed0]
  0x131c0d5a, 0x4f004b07, 0x3e4b25af, 0x36066a07,   // ne.mr.bh_553 mi.bi.un_420  eu.mi.rm_655 haw.de.gn_432 
  0x65022512, 0x046a4b11, 0x5a6a4b07, 0x5d004a05,   // eu.da.gv_654 mi.haw.fi_653  mi.haw.sm_432 yo.ss.un_330 
  0x5c006111, 0x04120c12, 0x02004b14, 0x1e1c6508,   // za.sa.un_630 sv.hu.fi_654  mi.da.un_660 gv.id.ms_443 
  0x51005805, 0x554a1305, 0x6b374514, 0x29004c07,   // om.kl.un_330 et.yo.rw_333  ln.st.ceb_666 wo.sl.un_420 
  // [16ee0]
  0x2d0d57af, 0x043738a0, 0x4c647307, 0x362d0dad,   // na.cs.sk_655 tk.ba.ru_322  ny.lg.wo_432 cs.sk.gn_643 
  0x3e2d0d08, 0x791d20ee, 0x07001714, 0x40003e19,   // cs.sk.rm_443 sq.la.war_422  sr.bg.un_660 rm.lb.un_750 
  0x10151110, 0x5c1c130c, 0x65002404, 0x1b38310d,   // ro.be.un_620 bh.mr.sa_543  eo.gv.un_320 az.tk.tr_554 
  0x350704a0, 0x353c1105, 0x19050a0b, 0x15353612,   // ru.bg.tg_322 ro.ug.tg_333  pt.fr.gl_542 ab.tg.un_654 
  // [16ef0]
  0x582f210e, 0x042e0e0c, 0x2f001807, 0x33615612,   // jw.su.om_555 is.fo.fi_543  ga.su.un_420 mg.za.nn_654 
  0x30026504, 0x38211c07, 0x12000808, 0x53115da4,   // gv.da.uz_332 id.jw.tk_432  no.hu.un_430 ss.ro.ht_433 
  0x79000102, 0x34183ca4, 0x52002d08, 0x521729a9,   // en.war.un_220 ug.ar.ps_433  sk.ha.un_430 sl.sr.ha_544 
  0x02204f0e, 0x1b523105, 0x43520655, 0x0b002309,   // bi.sq.da_555 az.ha.tr_333  de.ha.ie_442 ca.es.un_440 
  // [16f00]
  0x19534ab3, 0x38206107, 0x383152a9, 0x4600521b,   // yo.ht.gl_743 za.sq.tk_432  ha.az.tk_544 ha.qu.un_770 
  0x4423480e, 0x100c0407, 0x4d4a100c, 0x48233755,   // tt.ky.kk_555 fi.sv.lt_432  lt.yo.aa_543 ba.ky.tt_442 
  0x0f400811, 0x35342cec, 0x162f02ee, 0x4e001e04,   // no.lb.lv_653 fy.xh.zu_644  da.su.hr_422 ms.ay.un_320 
  0x0b4a0555, 0x23170405, 0x08174802, 0x1b003811,   // fr.yo.es_442 ru.sr.ky_333  tt.sr.uk_222 tk.tr.un_630 
  // [16f10]
  0x2e004607, 0x0d062da9, 0x0a440404, 0x2e2f5404,   // qu.fo.un_420 sk.de.cs_544  ru.kk.mk_332 ik.su.fo_332 
  0x2d120d02, 0x540e2ea4, 0x123430a9, 0x0e2e2f04,   // cs.hu.sk_222 fo.is.ik_433  uz.ps.ur_544 su.fo.is_332 
  0x36381fa0, 0x203802ac, 0x09794712, 0x42000e04,   // cy.tk.gn_322 da.tk.sq_632  sn.war.pl_654 is.co.un_320 
  0x0e2e4d08, 0x6337010c, 0x050c2255, 0x121d10ee,   // aa.fo.is_443 en.st.sco_543  oc.sv.fr_442 lt.la.hu_422 
  // [16f20]
  0x231004a4, 0x0c0d2dee, 0xfc647307, 0x0423150c,   // ru.be.ky_433 sk.cs.sv_422  ny.lg.zzp_432 un.ky.ru_543 
  0x30001604, 0x3b462fa7, 0x0e2e540c, 0x451867a4,   // hr.uz.un_320 su.qu.so_532  ik.fo.is_543 ak.ga.ln_433 
  0x381020a7, 0x40000513, 0x3b154607, 0x64456711,   // sq.lt.tk_532 fr.lb.un_650  qu.so.un_420 ak.ln.lg_653 
  0x5c0f5a04, 0x403605ad, 0x25003302, 0x490f6aee,   // sm.lv.sa_332 fr.gn.lb_643  nn.eu.un_220 haw.lv.to_422 
  // [16f30]
  0x343835a4, 0x4b000f19, 0x063b02ee, 0x110737a4,   // zu.tk.xh_433 lv.mi.un_750  da.so.de_422 ba.bg.ro_433 
  0x1b311a07, 0x31373008, 0x38131bee, 0x13045104,   // tl.az.tr_432 uz.st.az_443  tr.et.tk_422 kl.fi.et_332 
  0x1e1c3eee, 0x2f324da6, 0x024804a0, 0x491d39a7,   // rm.id.ms_422 aa.bs.su_521  fi.tt.da_322 br.la.to_532 
  0x30001b0c, 0x37385f05, 0x05023904, 0x38511b05,   // tr.uz.un_530 tn.tk.st_333  br.da.fr_332 tr.kl.tk_333 
  // [16f40]
  0x1c1e4d07, 0x05393fa0, 0x64130404, 0x493f39a7,   // aa.ms.id_432 af.br.fr_322  fi.et.lg_332 br.af.to_532 
  0x21443c5a, 0x584d0204, 0x1d0539ee, 0x3b655804,   // ug.kk.fa_553 da.aa.om_332  br.fr.la_422 om.gv.so_332 
  0x043b130c, 0x3c182355, 0x5f1e1c08, 0x3e7909a9,   // et.so.fi_543 ky.ar.ug_442  id.ms.tn_443 pl.war.rm_544 
  0x33002702, 0x332e0c13, 0x1a4a540c, 0x360d0aee,   // gd.nn.un_220 sv.fo.nn_665  ik.yo.tl_543 pt.cs.gn_422 
  // [16f50]
  0x190a3609, 0x400539a7, 0x3f403908, 0x04007304,   // gn.pt.gl_444 br.fr.lb_532  br.lb.af_443 ny.fi.un_320 
  0x3f4039ee, 0x13044612, 0x63003918, 0x135e04a0,   // br.lb.af_422 qu.fi.et_654  br.sco.un_740 fi.ts.et_322 
  0x0a362d07, 0x11002e02, 0x302d5602, 0x10151155,   // sk.gn.pt_432 fo.ro.un_220  mg.sk.uz_222 ro.be.un_420 
  0x39001e07, 0x510263ee, 0x5b00481b, 0x3d2134a6,   // ms.br.un_420 sco.da.kl_422  tt.sg.un_770 ps.fa.ku_521 
  // [16f60]
  0x2a604308, 0x04230704, 0x37040813, 0x213412ac,   // ie.vo.mt_443 bg.ky.ru_332  uk.ru.ba_665 ur.ps.fa_632 
  0x30251555, 0x256976a9, 0x160f10a0, 0x651504ee,   // un.mn.uz_442 crs.mfe.eu_544  lt.lv.hr_322 fi.gv.un_420 
  0x012f7904, 0x3f041502, 0x12556ba0, 0x1f002c07,   // war.su.en_332 un.fi.af_222  ceb.rw.hu_322 fy.cy.un_420 
  0x1200212b, 0x51001e02, 0x631a36ee, 0x150c43a0,   // fa.ur.un_980 ms.kl.un_220  gn.tl.sco_422 ie.sv.un_322 
  // [16f70]
  0x1a0115a0, 0x42164704, 0x33761b0c, 0x0436150c,   // un.en.tl_322 sn.hr.co_332  tr.crs.nn_543 un.ab.ru_543 
  0x4c001213, 0x796a55a9, 0x15045ca0, 0x02006412,   // hu.wo.un_650 rw.haw.war_544  sa.fi.un_322 lg.da.un_640 
  0x15070aa0, 0x39003f07, 0x42530511, 0x534c0507,   // mk.bg.un_322 af.br.un_420  fr.ht.co_653 fr.wo.ht_432 
  0x1d001f02, 0x50300405, 0x563704a4, 0x3900650c,   // cy.la.un_220 fi.uz.fj_333  fi.st.mg_433 gv.br.un_530 
  // [16f80]
  0x082e3360, 0x39003f12, 0x5f0465af, 0x25650407,   // nn.fo.no_664 af.br.un_640  gv.fi.tn_655 fi.gv.eu_432 
  0x6500180d, 0x652527ee, 0x650539ad, 0x36003721,   // ga.gv.un_540 gd.eu.gv_422  br.fr.gv_643 ba.ab.un_860 
  0x303d21a4, 0x256501a0, 0x51002e04, 0x110405af,   // fa.ku.uz_433 en.gv.eu_322  fo.kl.un_320 fr.fi.ro_655 
  0x5a6504af, 0x27000108, 0x27300404, 0x25650408,   // fi.gv.sm_655 en.gd.un_430  fi.uz.gd_332 fi.gv.eu_443 
  // [16f90]
  0x302523af, 0x153848ec, 0x370830ee, 0x353402a9,   // ky.mn.uz_655 tt.tk.un_644  uz.uk.ba_422 da.xh.zu_544 
  0x73004714, 0x28640208, 0x35556405, 0x5a004704,   // sn.ny.un_660 da.lg.sw_443  lg.rw.zu_333 sn.sm.un_320 
  0x351015ee, 0x5e005509, 0xfc585da4, 0x190b460c,   // un.be.tg_422 rw.ts.un_440  ss.om.zzp_433 qu.es.gl_543 
  0x1500441a, 0x272129a6, 0x12343cee, 0x273e1807,   // kk.un.un_760 sl.jw.gd_521  ug.ps.ur_422 ga.rm.gd_432 
  // [16fa0]
  0x05002513, 0x120b2302, 0x190b1d09, 0x31306107,   // eu.fr.un_650 ca.es.hu_222  la.es.gl_444 za.uz.az_432 
  0x12001d07, 0x42074db2, 0x640413ee, 0x1536110b,   // la.hu.un_420 aa.it.co_732  et.fi.lg_422 ro.ab.un_542 
  0x64005118, 0x2a151b02, 0x0c007908, 0x361515a4,   // kl.lg.un_740 tr.mt.un_220  war.sv.un_430 un.ab.un_430 
  0x32694e55, 0x4300041a, 0x2d0d60ac, 0x0d000c04,   // ay.mfe.bs_442 fi.ie.un_760  vo.cs.sk_632 sv.cs.un_320 
  // [16fb0]
  0x0e790612, 0x21091c02, 0x6b001b07, 0x046a25ad,   // de.war.is_654 id.pl.jw_222  tr.ceb.un_420 eu.haw.fi_643 
  0x642006a7, 0x20353408, 0x024b6a07, 0x4e47730d,   // de.sq.lg_532 xh.zu.sq_443  haw.mi.da_432 ny.sn.ay_554 
  0x20285c07, 0x4700640e, 0x341015a4, 0x6447340c,   // sa.sw.sq_432 lg.sn.un_550  un.lt.xh_433 xh.sn.lg_543 
  0x055322af, 0x0540250b, 0x3002200c, 0x5f005e08,   // oc.ht.fr_655 eu.lb.fr_542  sq.da.uz_543 ts.tn.un_430 
  // [16fc0]
  0x6b103407, 0x207862af, 0x30200604, 0x3b5846a0,   // xh.lt.ceb_432 kha.ve.sq_655  de.sq.uz_332 qu.om.so_322 
  0x584b250c, 0x4c2f050c, 0x536438ad, 0x78005e08,   // eu.mi.om_543 fr.su.wo_543  tk.lg.ht_643 ts.ve.un_430 
  0x64207308, 0x30001521, 0x5e3325af, 0x4a00130d,   // ny.sq.lg_443 un.uz.un_860  eu.nn.ts_655 et.yo.un_540 
  0x1c791e0c, 0x4c00672a, 0x4a075ba4, 0x31001308,   // ms.war.id_543 ak.wo.un_970  sg.it.yo_433 et.az.un_430 
  // [16fd0]
  0x68003b22, 0x3b002a12, 0x4a000a18, 0x19001213,   // so.ig.un_870 mt.so.un_640  pt.yo.un_740 hu.gl.un_650 
  0x4b00470d, 0x0a0e2e09, 0x190b0da9, 0x1e2868ad,   // sn.mi.un_540 fo.is.pt_444  cs.es.gl_544 ig.sw.ms_643 
  0x38464ba7, 0x23341807, 0xfe291d0c, 0xfe4b2a55,   // mi.qu.tk_532 ar.ps.ky_432  la.sl.tlh_543 mt.mi.tlh_442 
  0x673b47a9, 0x64026207, 0x7800750e, 0x1e1c0fee,   // sn.so.ak_544 kha.da.lg_432  nso.ve.un_550 lv.id.ms_422 
  // [16fe0]
  0x2344250c, 0x4c390f07, 0x68004809, 0x202218a0,   // mn.kk.ky_543 lv.br.wo_432  tt.ig.un_440 ga.oc.sq_322 
  0x29001105, 0x1e4d1c07, 0x48252308, 0x5c00562c,   // ro.sl.un_330 id.aa.ms_432  ky.mn.tt_443 mg.sa.un_990 
  0x484f50ad, 0x08330407, 0x0e040c04, 0x07003c0b,   // fj.bi.tt_643 fi.nn.no_432  sv.fi.is_332 ug.bg.un_520 
  0x43002d19, 0x205636af, 0x52004602, 0x370a0711,   // sk.ie.un_750 gn.mg.sq_655  qu.ha.un_220 bg.mk.ba_653 
  // [16ff0]
  0x096346a0, 0x59570d0e, 0x565c09ec, 0x345d0102,   // qu.sco.pl_322 cs.na.rn_555  pl.sa.mg_644 en.ss.xh_222 
  0x65530102, 0x530357ee, 0x36171104, 0x50001c02,   // en.ht.gv_222 na.nl.ht_422  ro.sr.ab_332 id.fj.un_220 
  0x0d0a2d07, 0x0c121307, 0x190b0dec, 0x3e112912,   // sk.pt.cs_432 et.hu.sv_432  cs.es.gl_644 sl.ro.rm_654 
  0x2b152ca4, 0x115113a4, 0x0e2e51a9, 0x54130ea4,   // fy.vi.un_430 et.kl.ro_433  kl.fo.is_544 is.et.ik_433 
  
  // [17000]
  0x312913ad, 0x292e0e0e, 0x04110902, 0x2e1a29ee,   // et.sl.az_643 is.fo.sl_555  pl.ro.fi_222 sl.tl.fo_422 
  0x13515408, 0x2f00260d, 0x47001812, 0x231017ee,   // ik.kl.et_443 ia.su.un_540  ga.sn.un_640 sr.be.ky_422 
  0x46001704, 0x5a011902, 0x43001d12, 0x0d1729a0,   // sr.qu.un_320 gl.en.sm_222  la.ie.un_640 sl.sr.cs_322 
  0x25006505, 0x0d292ea4, 0x25472112, 0x545559a9,   // gv.eu.un_330 fo.sl.cs_433  jw.sn.eu_654 rn.rw.ik_544 
  // [17010]
  0x49235aee, 0x5f4760a9, 0x0d0e2d04, 0x49733307,   // sm.ca.to_422 vo.sn.tn_544  sk.is.cs_332 nn.ny.to_432 
  0x58511112, 0x6b6456a9, 0x454b59ec, 0x33280809,   // ro.kl.om_654 mg.lg.ceb_544  rn.mi.ln_644 no.sw.nn_444 
  0x10472f5a, 0x57001a0d, 0x49060eee, 0x485559ec,   // su.sn.lt_553 tl.na.un_540  is.de.to_422 rn.rw.tt_644 
  0x19041355, 0x211e1c11, 0x352f5504, 0x1d002004,   // et.fi.gl_442 id.ms.jw_653  rw.su.zu_332 sq.la.un_320 
  // [17020]
  0x64255508, 0x1a64500d, 0x3b251908, 0x5c4754af,   // rw.eu.lg_443 fj.lg.tl_554  gl.eu.so_443 ik.sn.sa_655 
  0x355d5eaf, 0x5279640c, 0x34005e09, 0x474b730d,   // ts.ss.zu_655 lg.war.ha_543  ts.xh.un_440 ny.mi.sn_554 
  0x5f001c08, 0x041711ee, 0x645d45a9, 0x3000510c,   // id.tn.un_430 ro.sr.ru_422  ln.ss.lg_544 kl.uz.un_530 
  0x1d2f23ee, 0x2f005104, 0x3400fe13, 0x68644dac,   // ca.su.la_422 kl.su.un_320  tlh.xh.un_650 aa.lg.ig_632 
  // [17030]
  0x28005004, 0x01573605, 0x653057ec, 0x46004f0d,   // fj.sw.un_320 gn.na.en_333  na.uz.gv_644 bi.qu.un_540 
  0x020c58a0, 0x285873a9, 0x12303b55, 0x441704ee,   // om.sv.da_322 ny.om.sw_544  ks.uz.ur_442 ru.sr.kk_422 
  0x0e002802, 0x0a3023a0, 0x2338480b, 0x480436a0,   // sw.is.un_220 ky.uz.mk_322  tt.tk.ky_542 gn.fi.tt_322 
  0x1c5c2bb4, 0xfc1310a7, 0x67001e13, 0x3f003912,   // vi.sa.id_754 lt.et.zzp_532  ms.ak.un_650 br.af.un_640 
  // [17040]
  0x036539ee, 0x08251007, 0x56003e07, 0x2b004222,   // br.gv.nl_422 lt.eu.no_432  rm.mg.un_420 co.vi.un_870 
  0x3e000c0b, 0x374410ee, 0x05185b07, 0x45033f0d,   // sv.rm.un_520 be.kk.ba_422  sg.ga.fr_432 af.nl.ln_554 
  0x1925feee, 0x541151af, 0x3c28300c, 0x4a606808,   // tlh.eu.gl_422 kl.ro.ik_655  uz.sd.ug_543 ig.vo.yo_443 
  0x51001114, 0x59645512, 0x12510208, 0x11047807,   // ro.kl.un_660 rw.lg.rn_654  da.kl.hu_443 ve.fi.ro_432 
  // [17050]
  0x3b4d1108, 0x11130408, 0x115a5112, 0x6473280c,   // ro.aa.so_443 fi.et.ro_443  kl.sm.ro_654 sw.ny.lg_543 
  0x02002e1a, 0x1d0c36a7, 0x20002210, 0x0c00480e,   // fo.da.un_760 gn.sv.la_532  oc.sq.un_620 tt.sv.un_550 
  0x4736560d, 0x240239a0, 0x36020355, 0x36005907,   // mg.gn.sn_554 br.da.eo_322  nl.da.gn_442 rn.gn.un_420 
  0x1304110c, 0x375528a7, 0x11005122, 0x114a51a4,   // ro.fi.et_543 sw.rw.st_532  kl.ro.un_870 kl.yo.ro_433 
  // [17060]
  0x36003b07, 0xfe002b1a, 0x1845050c, 0x65004c11,   // so.gn.un_420 vi.tlh.un_760  fr.ln.ga_543 wo.gv.un_630 
  0x0b004c2b, 0x10000d19, 0x65004c22, 0x4c150112,   // wo.es.un_980 cs.lt.un_750  wo.gv.un_870 en.wo.un_640 
  0xfe002b1b, 0x27426502, 0x3300020c, 0x0910045a,   // vi.tlh.un_770 gv.co.gd_222  da.nn.un_530 fi.lt.pl_553 
  0x31483802, 0x69334813, 0x0a3665a7, 0x0e153f5a,   // tk.tt.az_222 tt.nn.mfe_665  gv.gn.pt_532 af.is.un_530 
  // [17070]
  0x05466b08, 0x59245f05, 0x5f405e07, 0x090210a4,   // ceb.qu.fr_443 tn.eo.rn_333  ts.lb.tn_432 lt.da.pl_433 
  0x38025f07, 0x455955ad, 0x021357a0, 0x1f6509a4,   // tn.da.tk_432 rw.rn.ln_643  na.et.da_322 pl.gv.cy_433 
  0x5e385fa0, 0x060c4802, 0x060448a0, 0x06000409,   // tn.tk.ts_322 tt.sv.de_222  tt.fi.de_322 fi.de.un_440 
  0x48443ca4, 0x38254713, 0x28645fad, 0x5f000204,   // ug.kk.tt_433 sn.eu.tk_665  tn.lg.sw_643 da.tn.un_320 
  // [17080]
  0x060c045a, 0x4b005a13, 0x20001111, 0x4734200c,   // fi.sv.de_553 sm.mi.un_650  ro.sq.un_630 sq.xh.sn_543 
  0x02004b19, 0x1912360b, 0x583b560c, 0x54005a14,   // mi.da.un_750 gn.hu.gl_542  mg.so.om_543 sm.ik.un_660 
  0x64000405, 0x066549a7, 0x11001314, 0x1d496a0c,   // fi.lg.un_330 to.gv.de_532  et.ro.un_660 haw.to.la_543 
  0x17040aee, 0x08170755, 0x011f6311, 0x04003805,   // mk.ru.sr_422 bg.sr.uk_442  sco.cy.en_653 tk.fi.un_330 
  // [17090]
  0x27005b0e, 0x49006514, 0x0e004312, 0x1e1f2711,   // sg.gd.un_550 gv.to.un_660  ie.is.un_640 gd.cy.ms_653 
  0x3365130b, 0x42005609, 0x0a481505, 0x761d01a0,   // et.gv.nn_542 mg.co.un_440  un.tt.mk_333 en.la.crs_322 
  0x600163ee, 0x38040602, 0x63004f09, 0x27006507,   // sco.en.vo_422 de.fi.tk_222  bi.sco.un_440 gv.gd.un_420 
  0x34004002, 0x19002e04, 0x080a07a9, 0x0a652f55,   // lb.xh.un_220 fo.gl.un_320  bg.mk.uk_544 su.gv.pt_442 
  // [170a0]
  0x0b40200b, 0x21001c12, 0x56004a09, 0x06651f08,   // sq.lb.es_542 id.jw.un_640  yo.mg.un_440 cy.gv.de_443 
  0x27002309, 0x22391f04, 0x2e3943a0, 0x045811a4,   // ca.gd.un_440 cy.br.oc_332  ie.br.fo_322 ro.om.fi_433 
  0x23213ca7, 0x2f005a09, 0x492f3912, 0x3511150d,   // ug.fa.ky_532 sm.su.un_440  br.su.to_654 un.ro.tg_554 
  0x11311b07, 0x11003104, 0x323504ee, 0x233c34ec,   // tr.az.ro_432 az.ro.un_320  fi.zu.bs_422 ps.ug.ky_644 
  // [170b0]
  0x28fc520c, 0x30083508, 0x18233c0e, 0x25390308,   // ha.zzp.sw_543 tg.uk.uz_443  ug.ky.ar_555 nl.br.eu_443 
  0x030213ad, 0x6000481a, 0x21124ca4, 0x03003313,   // et.da.nl_643 tt.vo.un_760  wo.hu.jw_433 nn.nl.un_650 
  0x295a4911, 0x25400507, 0x3f583ba0, 0x025f1808,   // to.sm.sl_653 fr.lb.eu_432  so.om.af_322 ga.tn.da_443 
  0x591d60a4, 0x4f003b07, 0x52435f07, 0x06000312,   // vo.la.rn_433 so.bi.un_420  tn.ie.ha_432 nl.de.un_640 
  // [170c0]
  0x5c006413, 0x33063f13, 0x1a5f60a7, 0xfe4330a7,   // lg.sa.un_650 af.de.nn_665  vo.tn.tl_532 uz.ie.tlh_532 
  0x06032008, 0x065559ee, 0x020201a4, 0x350a1107,   // sq.nl.de_443 rn.rw.de_422  en.da.da_433 ro.mk.tg_432 
  0x0f321604, 0x32037605, 0x5d001802, 0x3f00fe05,   // hr.bs.lv_332 crs.nl.bs_333  ga.ss.un_220 tlh.af.un_330 
  0x38171105, 0x630601af, 0x37630604, 0x3c18440b,   // ro.sr.tk_333 en.de.sco_655  de.sco.st_332 kk.ar.ug_542 
  // [170d0]
  0x4a353408, 0x5c0cfe04, 0x072a4209, 0x0600650c,   // xh.zu.yo_443 tlh.sv.sa_332  co.mt.it_444 gv.de.un_530 
  0x63094a0c, 0x2e390cee, 0x56002921, 0x2a003705,   // yo.pl.sco_543 sv.br.fo_422  sl.mg.un_860 st.mt.un_330 
  0x1e3b280c, 0x202856ee, 0x1e532aee, 0x1a276b09,   // sw.so.ms_543 mg.sw.sq_422  mt.ht.ms_422 ceb.gd.tl_444 
  0x42076ba4, 0x79436107, 0x35234804, 0x5c3534af,   // ceb.it.co_433 za.ie.war_432  tt.ky.tg_332 xh.zu.sa_655 
  // [170e0]
  0x0c0251a9, 0x730330a9, 0xfc1027a0, 0x1c5621ee,   // kl.da.sv_544 uz.nl.ny_544  gd.lt.zzp_322 jw.mg.id_422 
  0x561e1c07, 0x37043404, 0x28004a05, 0x34fe4f0b,   // id.ms.mg_432 xh.fi.st_332  yo.sw.un_330 bi.tlh.xh_542 
  0x61006223, 0xfc026307, 0x40042502, 0x7535345a,   // kha.za.un_880 sco.da.zzp_432  eu.fi.lb_222 xh.zu.nso_553 
  0x2500400d, 0x0c002e08, 0x2a6b62a9, 0x654b4004,   // lb.eu.un_540 fo.sv.un_430  kha.ceb.mt_544 lb.mi.gv_332 
  // [170f0]
  0x072a4213, 0x0400560c, 0x73286a04, 0x044b49ac,   // co.mt.it_665 mg.fi.un_530  haw.sw.ny_332 to.mi.fi_632 
  0x2e0c51a4, 0x271c1ea4, 0x425c48a4, 0x49000a04,   // kl.sv.fo_433 ms.id.gd_433  tt.sa.co_433 pt.to.un_320 
  0x076b3eec, 0x283418a6, 0x0407150e, 0x40066507,   // rm.ceb.it_644 ar.ps.sd_521  un.bg.ru_555 gv.de.lb_432 
  0x0a441107, 0x2000360d, 0x422f2304, 0x4a4d2da9,   // ro.kk.mk_432 gn.sq.un_540  ca.su.co_332 sk.aa.yo_544 
  // [17100]
  0x4e06650c, 0x2b001812, 0x080225a0, 0x070a04af,   // gv.de.ay_543 ga.vi.un_640  eu.da.no_322 ru.mk.bg_655 
  0x25003814, 0x49655604, 0x40212f07, 0x40570607,   // tk.mn.un_660 mg.gv.to_332  su.jw.lb_432 de.na.lb_432 
  0x49002705, 0x044b6512, 0x64001c02, 0x65515aa4,   // gd.to.un_330 gv.mi.fi_654  id.lg.un_220 sm.kl.gv_433 
  0x44000704, 0x22000e05, 0x4844250c, 0x34183b0c,   // bg.kk.un_320 is.oc.un_330  mn.kk.tt_543 ks.ar.ps_543 
  // [17110]
  0x44000708, 0x4800220d, 0x233b3c11, 0x2c000d04,   // bg.kk.un_430 oc.tt.un_540  ug.ks.ky_653 cs.fy.un_320 
  0x30481508, 0x4c004208, 0x40060c13, 0x060c04ee,   // un.tt.uz_443 co.wo.un_430  sv.de.lb_665 fi.sv.de_422 
  0x15001019, 0x24001a09, 0x2e330208, 0x30151155,   // be.un.un_750 tl.eo.un_440  da.nn.fo_443 ro.uz.un_420 
  0x1a1f6912, 0x0e00621a, 0x65006219, 0x343160a0,   // mfe.cy.tl_654 kha.is.un_760  kha.gv.un_750 vo.az.xh_322 
  // [17120]
  0x76695305, 0x1b190b04, 0x790401a0, 0x07153555,   // ht.mfe.crs_333 es.gl.tr_332  en.fi.war_322 tg.bg.un_420 
  0x18005b11, 0x0c000612, 0x516304a4, 0x380e20a9,   // sg.ga.un_630 de.sv.un_640  fi.sco.kl_433 sq.is.tk_544 
  0x0a170811, 0x04015102, 0x2d002b0d, 0x5c2836ad,   // uk.sr.mk_653 kl.en.fi_222  vi.sk.un_540 gn.sw.sa_643 
  0x4a004512, 0x0e006219, 0x2a002508, 0x04311bec,   // ln.yo.un_640 kha.is.un_750  eu.mt.un_430 tr.az.fi_644 
  // [17130]
  0x650e1ea0, 0x0a182b1f, 0x30311ba7, 0x0c023907,   // ms.is.gv_322 vi.ga.pt_864  tr.az.uz_532 br.da.sv_432 
  0x1f114308, 0x292d1108, 0x644313ad, 0x4b285260,   // ie.ro.cy_443 ro.sk.sl_443  et.ie.lg_643 ha.sw.mi_664 
  0x4b004509, 0x3c001213, 0x49250107, 0x0200130e,   // ln.mi.un_440 ur.ug.un_650  en.eu.to_432 et.da.un_550 
  0x0f1d0ea4, 0x48006022, 0x233038ec, 0x754520a4,   // is.la.lv_433 vo.tt.un_870  tk.uz.ky_644 sq.ln.nso_433 
  // [17140]
  0x164a02ee, 0x235a4904, 0x1b3109ee, 0x2059730d,   // da.yo.hr_422 to.sm.ca_332  pl.az.tr_422 ny.rn.sq_554 
  0x73591505, 0x10301155, 0x07491d0c, 0x58004613,   // un.rn.ny_333 ro.uz.lt_442  la.to.it_543 qu.om.un_650 
  0x3e2011a4, 0x213d30a6, 0x221d1108, 0x3d1230a4,   // ro.sq.rm_433 uz.ku.fa_521  ro.la.oc_443 uz.ur.ku_433 
  0x0c04130c, 0x062e0ca0, 0x39005308, 0x2800670d,   // et.fi.sv_543 sv.fo.de_322  ht.br.un_430 ak.sw.un_540 
  // [17150]
  0x2873340d, 0x10070a02, 0x0c08330d, 0x34005102,   // xh.ny.sw_554 mk.bg.be_222  nn.no.sv_554 kl.xh.un_220 
  0x1f0601a4, 0x0c005713, 0x5e2801ee, 0x05002012,   // en.de.cy_433 na.sv.un_650  en.sw.ts_422 sq.fr.un_640 
  0x6440080b, 0x133e0c07, 0x15005707, 0x27007907,   // no.lb.lg_542 sv.rm.et_432  na.un.un_420 war.gd.un_420 
  0x330c08a0, 0x063e4004, 0x04370805, 0x0d091207,   // no.sv.nn_322 lb.rm.de_332  uk.ba.ru_333 hu.pl.cs_432 
  // [17160]
  0x193302ee, 0x355d55a9, 0x4d1351ec, 0x09134d07,   // da.nn.gl_422 rw.ss.zu_544  kl.et.aa_644 aa.et.pl_432 
  0x3f691ea0, 0x15152511, 0x6b1b1d12, 0x07004304,   // ms.mfe.af_322 mn.un.un_630  la.tr.ceb_654 ie.it.un_320 
  0x68002b0e, 0x56122414, 0x0a1715a7, 0xfc004a04,   // vi.ig.un_550 eo.hu.mg_666  un.sr.mk_532 yo.zzp.un_320 
  0x3502640c, 0x5c0d1302, 0x562113a4, 0x1300250d,   // lg.da.zu_543 bh.ne.sa_222  et.jw.mg_433 eu.et.un_540 
  // [17170]
  0x73006414, 0x2300100d, 0xfc0d68ee, 0x380a07af,   // lg.ny.un_660 be.ky.un_540  ig.cs.zzp_422 bg.mk.tk_655 
  0x35006a0c, 0x483844a4, 0x10371502, 0x3b1827ad,   // haw.zu.un_530 kk.tk.tt_433  un.ba.be_222 gd.ga.so_643 
  0x652a2008, 0xfc355e09, 0x2a040a0c, 0x65fe2808,   // sq.mt.gv_443 ts.zu.zzp_444  pt.fi.mt_543 sw.tlh.gv_443 
  0x133e1f07, 0x24430da7, 0x47005104, 0x202d0d0c,   // cy.rm.et_432 cs.ie.eo_532  kl.sn.un_320 cs.sk.sq_543 
  // [17180]
  0x3104130b, 0x16001b04, 0x31253007, 0x051f63a0,   // et.fi.az_542 tr.hr.un_320  uz.eu.az_432 sco.cy.fr_322 
  0x345c2e04, 0x783b3008, 0x51001018, 0x374844af,   // fo.sa.xh_332 uz.so.ve_443  lt.kl.un_740 kk.tt.ba_655 
  0x27345f08, 0x2d2e0e0c, 0x205c1355, 0x042e4705,   // tn.xh.gd_443 is.fo.sk_543  et.sa.sq_442 sn.fo.fi_333 
  0x151737a4, 0x060c36a7, 0x25004e0d, 0x12213baf,   // ba.sr.un_433 gn.sv.de_532  ay.eu.un_540 ks.fa.ur_655 
  // [17190]
  0x22001209, 0x0c003605, 0x30002d02, 0x49004a0b,   // hu.oc.un_440 gn.sv.un_330  sk.uz.un_220 yo.to.un_520 
  0x36510aac, 0x44303707, 0x360c0408, 0xfe0a6e13,   // pt.kl.gn_632 ba.uz.kk_432  fi.sv.gn_443 hmn.pt.tlh_665 
  0x52fe6013, 0x65006e08, 0x1560fe0c, 0x35004905,   // vo.tlh.ha_665 hmn.gv.un_430  tlh.vo.un_543 to.zu.un_330 
  0x3810040e, 0x6000670d, 0x300602a4, 0x35004a11,   // ru.be.tk_555 ak.vo.un_540  da.de.uz_433 yo.zu.un_630 
  // [171a0]
  0x693b6012, 0x0b004c11, 0x23604311, 0x0c4060a7,   // vo.so.mfe_654 wo.es.un_630  ie.vo.ca_653 vo.lb.sv_532 
  0x3b1f60af, 0x35344909, 0x6330600b, 0x672601a0,   // vo.cy.so_655 to.xh.zu_444  vo.uz.sco_542 en.ia.ak_322 
  0x304c6e14, 0x08124a07, 0x0a172307, 0x132f6b07,   // hmn.wo.uz_666 yo.hu.no_432  ky.sr.mk_432 ceb.su.et_432 
  0x60003021, 0x793057a7, 0x79003008, 0x1f6540a0,   // uz.vo.un_860 na.uz.war_532  uz.war.un_430 lb.gv.cy_322 
  // [171b0]
  0x13534c07, 0x020a0c04, 0x533e760c, 0xfc0715a0,   // wo.ht.et_432 sv.pt.da_332  crs.rm.ht_543 un.it.zzp_322 
  0x133f4202, 0x04080aa7, 0x06400ca0, 0x06403ea0,   // co.af.et_222 mk.uk.ru_532  sv.lb.de_322 rm.lb.de_322 
  0x06473e55, 0x531827af, 0x441525ac, 0x35300402,   // rm.sn.de_442 gd.ga.ht_655  mn.kk.un_620 ru.uz.tg_222 
  0x4a000208, 0x69404c0c, 0x2a3e53a4, 0x1d00180d,   // da.yo.un_430 wo.lb.mfe_543  ht.rm.mt_433 ga.la.un_540 
  // [171c0]
  0x480c6007, 0x3e0742ee, 0x13093b11, 0x4b002005,   // vo.sv.tt_432 co.it.rm_422  ks.hi.bh_653 sq.mi.un_330 
  0x30482e02, 0x0900421a, 0x0c005712, 0x3d003b1a,   // fo.tt.uz_222 co.pl.un_760  na.sv.un_640 ks.ku.un_760 
  0x381b0ca4, 0x67003622, 0x4b556baf, 0x4c2f670c,   // sv.tr.tk_433 gn.ak.un_870  ceb.rw.mi_655 ak.su.wo_543 
  0x1b001c02, 0xfe511e07, 0x02292d07, 0x0c0251ad,   // id.tr.un_220 ms.kl.tlh_432  sk.sl.da_432 kl.da.sv_643 
  // [171d0]
  0x56064908, 0x155b1e0c, 0x673e360c, 0x6b204704,   // to.de.mg_443 ms.sg.un_543  gn.rm.ak_543 sn.sq.ceb_332 
  0x5b641ca4, 0x36000505, 0x381b0e07, 0x79391fa7,   // id.lg.sg_433 fr.gn.un_330  is.tr.tk_432 cy.br.war_532 
  0x164713a0, 0x25191ca0, 0x3e1dfc08, 0x790257ad,   // et.sn.hr_322 id.gl.eu_322  zzp.la.rm_443 na.da.war_643 
  0x48025e07, 0x2f641e0c, 0x364207ec, 0x4800120d,   // ts.da.tt_432 ms.lg.su_543  it.co.gn_644 hu.tt.un_540 
  // [171e0]
  0x6b791a14, 0x161024ee, 0x3051fe0b, 0x79766912,   // tl.war.ceb_666 eo.lt.hr_422  tlh.kl.uz_542 mfe.crs.war_654 
  0x3e114f07, 0x214c3f04, 0x48301512, 0x080c0213,   // bi.ro.rm_432 af.wo.jw_332  un.uz.tt_654 da.sv.no_665 
  0x0c025108, 0x4006600c, 0x1d201f07, 0x2000510c,   // kl.da.sv_443 vo.de.lb_543  cy.sq.la_432 kl.sq.un_530 
  0x40000c05, 0x0e004802, 0x65003308, 0x1e001c35,   // sv.lb.un_330 tt.is.un_220  nn.gv.un_430 id.ms.un_A90 
  // [171f0]
  0x360b0a55, 0x04483604, 0x0c69080c, 0x15170705,   // pt.es.gn_442 gn.tt.fi_332  no.mfe.sv_543 bg.sr.un_333 
  0x5d003421, 0x63592fa4, 0x735906af, 0x05645804,   // xh.ss.un_860 su.rn.sco_433  de.rn.ny_655 om.lg.fr_332 
  0x73342808, 0x550359af, 0x183c44a7, 0x04481007,   // sw.xh.ny_443 rn.nl.rw_655  kk.ug.ar_532 be.tt.ru_432 
  0x020621ec, 0x601501a4, 0x23394707, 0x3b0602a9,   // jw.de.da_644 en.vo.un_430  sn.br.ca_432 da.de.so_544 
  // [17200]
  0x5446280c, 0x342344af, 0x2c005e0c, 0x31380f07,   // sw.qu.ik_543 kk.ky.ps_655  ts.fy.un_530 lv.tk.az_432 
  0x1b3f30a4, 0x3035365a, 0x163028a0, 0x64040cad,   // uz.af.tr_433 ab.tg.uz_553  sw.uz.hr_322 sv.fi.lg_643 
  0x12006804, 0x1b3f3009, 0x38283002, 0x60003f19,   // ig.hu.un_320 uz.af.tr_444  uz.sw.tk_222 af.vo.un_750 
  0x34233da7, 0x1b3f4f0c, 0x682a1bee, 0x132c3008,   // ku.ky.ps_532 bi.af.tr_543  tr.mt.ig_422 uz.fy.et_443 
  // [17210]
  0x254604a0, 0x63133f12, 0x3f760c04, 0x1b3f2c08,   // fi.qu.eu_322 af.et.sco_654  sv.crs.af_332 fy.af.tr_443 
  0x250265a9, 0x2c005104, 0x4f691c0b, 0x31002f02,   // gv.da.eu_544 kl.fy.un_320  id.mfe.bi_542 su.az.un_220 
  0x30fc24a0, 0x73005508, 0x3e2a07a0, 0x291633a4,   // eo.zzp.uz_322 rw.ny.un_430  it.mt.rm_322 nn.hr.sl_433 
  0x1b313008, 0x24093807, 0x1a126b08, 0x101525a7,   // uz.az.tr_443 tk.pl.eo_432  ceb.hu.tl_443 mn.be.un_520 
  // [17220]
  0x280833ec, 0x59005536, 0x383f30a9, 0x381b1ca0,   // nn.no.sw_644 rw.rn.un_AA0  uz.af.tk_544 id.tr.tk_322 
  0x1b13305a, 0x5b400613, 0x1b000e13, 0x2c7669a4,   // uz.et.tr_553 de.lb.sg_665  is.tr.un_650 mfe.crs.fy_433 
  0x212f5cee, 0x06005802, 0x07230aa0, 0x4b5d3512,   // sa.su.jw_422 om.de.un_220  pt.ca.it_322 zu.ss.mi_654 
  0x43064804, 0x5d536207, 0x304d280b, 0x3f021007,   // tt.de.ie_332 kha.ht.ss_432  sw.aa.uz_542 lt.da.af_432 
  // [17230]
  0x381b0c0c, 0x35003436, 0x15003508, 0x18122107,   // sv.tr.tk_543 xh.zu.un_AA0  tg.un.un_430 fa.ur.ar_432 
  0x0c003e09, 0x043725a0, 0x24261daf, 0x30002819,   // rm.sv.un_440 mn.ba.ru_322  la.ia.eo_655 sw.uz.un_750 
  0x214c2f0d, 0x023313a0, 0x3f0179ac, 0x531e1c0d,   // su.wo.jw_554 et.nn.da_322  war.en.af_632 id.ms.ht_554 
  0x050633a0, 0x28341260, 0x0800331a, 0x531c2fac,   // nn.de.fr_322 ur.ps.sd_664  nn.no.un_760 su.id.ht_632 
  // [17240]
  0x430255a4, 0x475702a4, 0x03000507, 0x0c13040c,   // rw.da.ie_433 da.na.sn_433  fr.nl.un_420 fi.et.sv_543 
  0x213c3013, 0x0c00130b, 0x13046004, 0x060e3904,   // uz.ug.fa_665 et.sv.un_520  vo.fi.et_332 br.is.de_332 
  0x55000307, 0x4502055a, 0x7655010c, 0x060165a0,   // nl.rw.un_420 fr.da.ln_553  en.rw.crs_543 gv.en.de_322 
  0x21002b04, 0x2500110e, 0x0c2e0e02, 0x0100300b,   // vi.jw.un_320 ro.mn.un_550  is.fo.sv_222 uz.en.un_520 
  // [17250]
  0x2100181b, 0x02002813, 0x02001212, 0x427349ee,   // ar.fa.un_770 sw.da.un_650  hu.da.un_640 to.ny.co_422 
  0x080710a9, 0x35301208, 0x1a2f30a0, 0x68353414,   // be.bg.uk_544 hu.uz.zu_443  uz.su.tl_322 xh.zu.ig_666 
  0x25374813, 0x536b1b08, 0x33022202, 0x060240a0,   // tt.ba.mn_665 tr.ceb.ht_443  oc.da.nn_222 lb.da.de_322 
  0x3007150d, 0x5500020e, 0x79022407, 0x03000e14,   // un.bg.uz_554 da.rw.un_550  eo.da.war_432 is.nl.un_660 
  // [17260]
  0x4a004609, 0x255d0107, 0x6b1a02ec, 0x37735a0c,   // qu.yo.un_440 en.ss.eu_432  da.tl.ceb_644 sm.ny.st_543 
  0x15070a08, 0x25443804, 0x4c2f215a, 0x35232504,   // mk.bg.un_443 tk.kk.mn_332  jw.su.wo_553 mn.ky.tg_332 
  0x48003818, 0x022508a4, 0x21002005, 0x1b583b55,   // tk.tt.un_740 no.eu.da_433  sq.jw.un_330 so.om.tr_442 
  0x2400610c, 0x016523a7, 0x2f284612, 0x1e1c46af,   // za.eo.un_530 ca.gv.en_532  qu.sw.su_654 qu.id.ms_655 
  // [17270]
  0x30395707, 0x040f1da4, 0xfc004907, 0x5a1a7907,   // na.br.uz_432 la.lv.fi_433  to.zzp.un_420 war.tl.sm_432 
  0x522f1c07, 0x36371104, 0x30112cad, 0x73595555,   // id.su.ha_432 ro.ba.ab_332  fy.ro.uz_643 rw.rn.ny_442 
  0x4c003108, 0x3848230d, 0xfe464ead, 0x5e50470c,   // az.wo.un_430 ky.tt.tk_554  ay.qu.tlh_643 sn.fj.ts_543 
  0x0b0a4d0c, 0x2d2223a4, 0x4b001d04, 0x12002d23,   // aa.pt.es_543 ca.oc.sk_433  la.mi.un_320 sk.hu.un_880 
  // [17280]
  0x306013a0, 0x3100302c, 0x311a30a9, 0x46495aaf,   // et.vo.uz_322 uz.az.un_990  uz.tl.az_544 sm.to.qu_655 
  0x31131e07, 0x2d424b02, 0x31003b21, 0x070c3304,   // ms.et.az_432 mi.co.sk_222  so.az.un_860 nn.sv.it_332 
  0x37026807, 0x1e132a09, 0x3b003112, 0x33220504,   // ig.da.st_432 mt.et.ms_444  az.so.un_640 fr.oc.nn_332 
  0x5376300c, 0x393f2ca0, 0x53303160, 0x07000e08,   // uz.crs.ht_543 fy.af.br_322  az.uz.ht_664 is.it.un_430 
  // [17290]
  0x3b316e04, 0x31301312, 0x79004a0e, 0x21313012,   // hmn.az.so_332 et.uz.az_654  yo.war.un_550 uz.az.jw_654 
  0x4b00491b, 0x13003019, 0x3d3c2312, 0x5c4a6804,   // to.mi.un_770 uz.et.un_750  ky.ug.ku_654 ig.yo.sa_332 
  0x3b3130ad, 0x6500540c, 0x025b6a0c, 0x464b3612,   // uz.az.so_643 ik.gv.un_530  haw.sg.da_543 gn.mi.qu_654 
  0x2f001e02, 0x04375fa4, 0x0a2530a7, 0x23330c07,   // ms.su.un_220 tn.st.fi_433  uz.mn.mk_532 sv.nn.ca_432 
  // [172a0]
  0x443738a0, 0x5000360d, 0x0c000505, 0x5f377514,   // tk.ba.kk_322 gn.fj.un_540  fr.sv.un_330 nso.st.tn_666 
  0x4a003413, 0x56002502, 0x03110102, 0x2d1243a0,   // xh.yo.un_650 eu.mg.un_220  en.ro.nl_222 ie.hu.sk_322 
  0x4a6b3f0c, 0x3600040e, 0x0e0d12a0, 0x60000414,   // af.ceb.yo_543 fi.gn.un_550  hu.cs.is_322 fi.vo.un_660 
  0x04023607, 0x64004c13, 0x55002802, 0x2d00061a,   // gn.da.fi_432 wo.lg.un_650  sw.rw.un_220 de.sk.un_760 
  // [172b0]
  0x34001b0c, 0x20735daf, 0x206432a0, 0x46220107,   // tr.xh.un_530 ss.ny.sq_655  bs.lg.sq_322 en.oc.qu_432 
  0x384801a0, 0x303b040c, 0x041810a0, 0x30313808,   // en.tt.tk_322 fi.so.uz_543  lt.ga.fi_322 tk.az.uz_443 
  0x5c20790c, 0x30021fee, 0x13076304, 0x3c251555,   // war.sq.sa_543 cy.da.uz_422  sco.it.et_332 un.mn.ug_442 
  0x302a3ba7, 0x17371507, 0x2e120da4, 0x0d001805,   // so.mt.uz_532 un.ba.sr_432  cs.hu.fo_433 ga.cs.un_330 
  // [172c0]
  0x383130ee, 0x1a011507, 0x31303855, 0x044207a9,   // uz.az.tk_422 un.en.tl_432  tk.uz.az_442 it.co.fi_544 
  0x3400440e, 0x20002609, 0x30005412, 0x373c30a9,   // kk.ps.un_550 ia.sq.un_440  ik.uz.un_640 uz.ug.ba_544 
  0x0d120e0c, 0x381023ec, 0x05015c07, 0x05015c04,   // is.hu.cs_543 ky.be.tk_644  sa.en.fr_432 sa.en.fr_332 
  0x0901fca0, 0x213d3b5a, 0x10005c0d, 0x233f2fee,   // zzp.en.pl_322 ks.ku.fa_553  sa.lt.un_540 su.af.ca_422 
  // [172d0]
  0x1d00390c, 0x104b5cee, 0x01054602, 0x402e0614,   // br.la.un_530 sa.mi.lt_422  qu.fr.en_222 de.fo.lb_666 
  0x3f0e3304, 0x3f2f06a0, 0x06655a04, 0x06000808,   // nn.is.af_332 de.su.af_322  sm.gv.de_332 no.de.un_430 
  0x1839270d, 0x650111a0, 0x55015cee, 0x69007636,   // gd.br.ga_554 ro.en.gv_322  sa.en.rw_422 crs.mfe.un_AA0 
  0x23004435, 0x276357a9, 0x01025c04, 0x690e3307,   // kk.ky.un_A90 na.sco.gd_544  sa.da.en_332 nn.is.mfe_432 
  // [172e0]
  0x68271d07, 0x130d1c14, 0x034006af, 0x35174404,   // la.gd.ig_432 mr.ne.bh_666  de.lb.nl_655 kk.sr.tg_332 
  0x4003600c, 0x763969a9, 0x532769a4, 0x06572f07,   // vo.nl.lb_543 mfe.br.crs_544  mfe.gd.ht_433 su.na.de_432 
  0x3f030a11, 0x063f57ee, 0x231d2f07, 0x3f0318ee,   // pt.nl.af_653 na.af.de_422  su.la.ca_432 ga.nl.af_422 
  0x53692eaf, 0x63000620, 0x2530350b, 0x57130608,   // fo.mfe.ht_655 de.sco.un_850  tg.uz.mn_542 de.et.na_443 
  // [172f0]
  0x113c2311, 0x1609290c, 0x3209290c, 0x343c18ee,   // ky.ug.ro_653 sl.pl.hr_543  sl.pl.bs_543 ar.ug.ps_422 
  0x13545108, 0x13292f04, 0x25006e0b, 0x09004c04,   // kl.ik.et_443 su.sl.et_332  hmn.eu.un_520 wo.pl.un_320 
  0x3610110d, 0x10300402, 0x091729a4, 0x2e0a1904,   // ro.be.ab_554 ru.uz.be_222  sl.sr.pl_433 gl.pt.fo_332 
  0x0d121907, 0x19001208, 0x19122dee, 0x19120e07,   // gl.hu.cs_432 hu.gl.un_430  sk.hu.gl_422 is.hu.gl_432 
  // [17300]
  0x322d2904, 0x093b02a7, 0x37004818, 0x0f171012,   // sl.sk.bs_332 da.so.pl_532  tt.ba.un_740 lt.sr.lv_654 
  0x100f2902, 0x0f5c4b04, 0x4f271108, 0x02050407,   // sl.lv.lt_222 mi.sa.lv_332  ro.gd.bi_443 fi.fr.da_432 
  0x47734912, 0x3f3904a7, 0x1d1545ee, 0x39330ca0,   // to.ny.sn_654 fi.br.af_532  ln.la.un_420 sv.nn.br_322 
  0x572e040c, 0x270318a9, 0x033f04a4, 0x7347360d,   // fi.fo.na_543 ga.nl.gd_544  fi.af.nl_433 gn.sn.ny_554 
  // [17310]
  0x652e0e08, 0x75003723, 0x2130600c, 0x5a601fec,   // is.fo.gv_443 st.nso.un_880  vo.uz.jw_543 cy.vo.sm_644 
  0x29623f07, 0x06651fa0, 0x5a37030b, 0x0b201dee,   // af.kha.sl_432 cy.gv.de_322  nl.st.sm_542 la.sq.es_422 
  0x5c002404, 0x6319220c, 0x03250609, 0xfc060107,   // eo.sa.un_320 oc.gl.sco_543  de.eu.nl_444 en.de.zzp_432 
  0x50001f04, 0x0503500c, 0x06004033, 0x600406a9,   // cy.fj.un_320 fj.nl.fr_543  lb.de.un_A70 de.fi.vo_544 
  // [17320]
  0x1d3ffca0, 0x1d000419, 0x05650408, 0x020425ec,   // zzp.af.la_322 fi.la.un_750  fi.gv.fr_443 eu.fi.da_644 
  0x1d3f0307, 0x191d5707, 0x1d005012, 0x18005d0e,   // nl.af.la_432 na.la.gl_432  fj.la.un_640 ss.ga.un_550 
  0x231d2204, 0x0c3f0355, 0x652e36a0, 0x0c032902,   // oc.la.ca_332 nl.af.sv_442  gn.fo.gv_322 sl.nl.sv_222 
  0x03000c05, 0x223f3407, 0x17090dee, 0x124e7908,   // sv.nl.un_330 xh.af.oc_432  cs.pl.sr_422 war.ay.hu_443 
  // [17330]
  0x012e61a7, 0x35344aaf, 0x563e1511, 0x063f1504,   // za.fo.en_532 yo.xh.zu_655  un.rm.mg_653 un.af.de_332 
  0x33083fa4, 0x0524150c, 0x0f004b0c, 0x13553305,   // af.no.nn_433 un.eo.fr_543  mi.lv.un_530 nn.rw.et_333 
  0x0a373504, 0x0300150e, 0x091c5caf, 0x2b6b1dad,   // tg.ba.mk_332 un.nl.un_550  sa.mr.hi_655 la.ceb.vi_643 
  0x01591555, 0x5955faaf, 0x6455590c, 0x4804150b,   // un.rn.en_442 nr.rw.rn_655  rn.rw.lg_543 un.ru.tt_542 
  // [17340]
  0x35644704, 0x25001d04, 0x1f562da0, 0x4a000409,   // sn.lg.zu_332 la.eu.un_320  sk.mg.cy_322 fi.yo.un_440 
  0x0a1f2508, 0x42202da0, 0x553534a4, 0x55005e14,   // eu.cy.pt_443 sk.sq.co_322  xh.zu.rw_433 ts.rw.un_660 
  0x3b005002, 0x0225100c, 0x17004a05, 0x110742ad,   // fj.so.un_220 lt.eu.da_543  yo.sr.un_330 co.it.ro_643 
  0x1d1d01a0, 0x20301155, 0x40002f0c, 0x1d07420d,   // en.la.la_322 ro.uz.sq_442  su.lb.un_530 co.it.la_554 
  // [17350]
  0x3b25300b, 0x4c003004, 0x32402da4, 0x4c535755,   // uz.eu.so_542 uz.wo.un_320  sk.lb.bs_433 na.ht.wo_442 
  0x101101a0, 0x474a4bac, 0x4f4a4c13, 0x04001f08,   // en.ro.lt_322 mi.yo.sn_632  wo.yo.bi_665 cy.fi.un_430 
  0x58134dec, 0x3bfe5008, 0x51303113, 0x21344413,   // aa.et.om_644 fj.tlh.so_443  az.uz.kl_665 kk.ps.fa_665 
  0x21303d04, 0x374438ad, 0x3031200c, 0x20185605,   // ku.uz.fa_332 tk.kk.ba_643  sq.az.uz_543 mg.ga.sq_333 
  // [17360]
  0x56510707, 0x061d400c, 0x20101b08, 0x30431ba7,   // it.kl.mg_432 lb.la.de_543  tr.lt.sq_443 tr.ie.uz_532 
  0x225357ad, 0x46002a02, 0x200713ee, 0x204d1d08,   // na.ht.oc_643 mt.qu.un_220  et.it.sq_422 la.aa.sq_443 
  0x0b190a5a, 0x19000e0b, 0x0d2d18af, 0x23001708,   // pt.gl.es_553 is.gl.un_520  ga.sk.cs_655 sr.ky.un_430 
  0x2a420714, 0x18361255, 0x3f640305, 0x03003104,   // it.co.mt_666 hu.gn.ga_442  nl.lg.af_333 az.nl.un_320 
  // [17370]
  0x03006a12, 0x15060a07, 0x23343d0c, 0x42002008,   // haw.nl.un_640 pt.de.un_432  ku.ps.ky_543 sq.co.un_430 
  0x360b2f08, 0x2e0d2d0c, 0x5804130c, 0xfc2e0eaf,   // su.es.gn_443 sk.cs.fo_543  et.fi.om_543 is.fo.zzp_655 
  0x0a300402, 0x3600370d, 0x2e0d0ea0, 0x56005019,   // ru.uz.mk_222 ba.ab.un_540  is.cs.fo_322 fj.mg.un_750 
  0x32005d07, 0x254838ad, 0xfc5647a7, 0x215b2f12,   // ss.bs.un_420 tk.tt.mn_643  sn.mg.zzp_532 su.sg.jw_654 
  // [17380]
  0x233444a7, 0x4a2f4c55, 0x04003202, 0x360d2e07,   // kk.ps.ky_532 wo.su.yo_442  bs.fi.un_220 fo.cs.gn_432 
  0x0a0712a4, 0x400e01a0, 0x57102e0c, 0x043c3060,   // hu.it.pt_433 en.is.lb_322  fo.lt.na_543 uz.ug.ru_664 
  0x061f15a4, 0x071dfc11, 0x0d00240d, 0x32330855,   // un.cy.de_433 zzp.la.it_653  eo.cs.un_540 no.nn.bs_442 
  0x080203a0, 0x2f210507, 0x421f5107, 0x0b002323,   // nl.da.no_322 fr.jw.su_432  kl.cy.co_432 ca.es.un_880 
  // [17390]
  0x190e2eb3, 0x2f001f02, 0x1d00fc07, 0x030118ee,   // fo.is.gl_743 cy.su.un_220  zzp.la.un_420 ga.en.nl_422 
  0x08170413, 0x200b5107, 0x09483012, 0x400451ad,   // ru.sr.uk_665 kl.es.sq_432  uz.tt.pl_654 kl.fi.lb_643 
  0x131b040c, 0x16000405, 0x54002f08, 0x512e0e08,   // fi.tr.et_543 fi.hr.un_330  su.ik.un_430 is.fo.kl_443 
  0x080c1fa4, 0x512e0c08, 0x36004d12, 0x5c1309ad,   // cy.sv.no_433 sv.fo.kl_443  aa.gn.un_640 hi.bh.sa_643 
  // [173a0]
  0x2d004a0e, 0x5a1351a7, 0x1c2f5404, 0x51190ca0,   // yo.sk.un_550 kl.et.sm_532  ik.su.id_332 sv.gl.kl_322 
  0x46002108, 0x5100390c, 0x540c2e08, 0x0c2951ad,   // jw.qu.un_430 br.kl.un_530  fo.sv.ik_443 kl.sl.sv_643 
  0x651d5107, 0x25003707, 0x441038ac, 0x4c032c04,   // kl.la.gv_432 ba.mn.un_420  tk.be.kk_632 fy.nl.wo_332 
  0x551d0502, 0x6b6809a0, 0x3f134c02, 0x074223a4,   // fr.la.rw_222 pl.ig.ceb_322  wo.et.af_222 ca.co.it_433 
  // [173b0]
  0x2c033fac, 0x300838a7, 0x123b340d, 0x55002d05,   // af.nl.fy_632 tk.uk.uz_532  ps.ks.ur_554 sk.rw.un_330 
  0x3e42075a, 0x4a00420d, 0x562801a0, 0x6a4f040d,   // it.co.rm_553 co.yo.un_540  en.sw.mg_322 fi.bi.haw_554 
  0x461e23a0, 0x4f100f13, 0x6e284da9, 0x083630a0,   // ca.ms.qu_322 lv.lt.bi_665  aa.sw.hmn_544 uz.ab.uk_322 
  0x02152aee, 0x24515805, 0x51006113, 0x5c101ca0,   // mt.da.un_420 om.kl.eo_333  za.kl.un_650 id.lt.sa_322 
  // [173c0]
  0x4c004f07, 0x0451425a, 0x4c383e0b, 0x43292d60,   // bi.wo.un_420 co.kl.fi_553  rm.tk.wo_542 sk.sl.ie_664 
  0x4e02100c, 0x46000d09, 0x13000f13, 0x122e0ead,   // lt.da.ay_543 cs.qu.un_440  lv.et.un_650 is.fo.hu_643 
  0x35005005, 0x0b0a63a0, 0x567302a9, 0x7300212a,   // fj.zu.un_330 sco.pt.es_322  da.ny.mg_544 jw.ny.un_970 
  0x36000a0c, 0x2e4024ad, 0x424c4007, 0x040256a4,   // pt.gn.un_530 eo.lb.fo_643  lb.wo.co_432 mg.da.fi_433 
  // [173d0]
  0x02562112, 0x561304ad, 0x0400102c, 0x6b00fc0d,   // jw.mg.da_654 fi.et.mg_643  lt.fi.un_990 zzp.ceb.un_540 
  0x0f2d1bee, 0x04100208, 0x51001022, 0x2f1c2804,   // tr.sk.lv_422 da.lt.fi_443  lt.kl.un_870 sw.id.su_332 
  0x5c001604, 0x51071d0d, 0x23002223, 0x066b65a0,   // hr.sa.un_320 la.it.kl_554  oc.ca.un_880 gv.ceb.de_322 
  0x301169ee, 0x46302aaf, 0x27023755, 0x4a345d0d,   // mfe.ro.uz_422 mt.uz.qu_655  st.da.gd_442 ss.xh.yo_554 
  // [173e0]
  0x29002d1b, 0x580c2ea0, 0x24654208, 0x301d58ad,   // sk.sl.un_770 fo.sv.om_322  co.gv.eo_443 om.la.uz_643 
  0x3000461b, 0x1800490c, 0x232515a7, 0x183412a9,   // qu.uz.un_770 to.ga.un_530  un.mn.ky_532 ur.ps.ar_544 
  0x42002b19, 0x17044802, 0x440437a0, 0x531b3e0c,   // vi.co.un_750 tt.ru.sr_222  ba.ru.kk_322 rm.tr.ht_543 
  0x102348a0, 0x59003509, 0x53004707, 0x040c13a6,   // tt.ky.be_322 zu.rn.un_440  sn.ht.un_420 et.sv.fi_521 
  // [173f0]
  0x30070460, 0x12283b0b, 0x0c1304a4, 0x38301b12,   // fi.it.uz_664 ks.sd.ur_542  fi.et.sv_433 tr.uz.tk_654 
  0x55001c07, 0x1d043202, 0x1d00020e, 0x4815150b,   // id.rw.un_420 bs.fi.la_222  da.la.un_550 un.tt.un_520 
  0x5f3f4902, 0x33085c02, 0x04004702, 0x2913170c,   // to.af.tn_222 sa.no.nn_222  sn.fi.un_220 sr.et.sl_543 
  0x440525ee, 0x212e4d0c, 0x07002102, 0x311b1102,   // eu.fr.kk_422 aa.fo.jw_543  jw.it.un_220 ro.tr.az_222 
  
  // [17400]
  0x33241dee, 0x1d2247a0, 0x481b3855, 0x3748100e,   // la.eo.nn_422 sn.oc.la_322  tk.tr.tt_442 be.tt.ba_555 
  0x27001f12, 0x0c003805, 0x1e3f09a0, 0x330e42ee,   // cy.gd.un_640 tk.sv.un_330  pl.af.ms_322 co.is.nn_422 
  0x3f02600b, 0x3d1230ad, 0x48381102, 0x31384804,   // vo.da.af_542 uz.ur.ku_643  ro.tk.tt_222 tt.tk.az_332 
  0x0302400c, 0x49647807, 0x60000c13, 0x0400152c,   // lb.da.nl_543 ve.lg.to_432  sv.vo.un_650 un.ru.un_990 
  // [17410]
  0x475f28a0, 0x49734714, 0x0e005207, 0x2a6b6e0c,   // sw.tn.sn_322 sn.ny.to_666  ha.is.un_420 hmn.ceb.mt_543 
  0x180e12a7, 0x643534a4, 0x596447af, 0x1b54640d,   // hu.is.ga_532 xh.zu.lg_433  sn.lg.rn_655 lg.ik.tr_554 
  0x2364280c, 0x04152509, 0x7659640d, 0x684e4a0c,   // sw.lg.ca_543 mn.ru.un_440  lg.rn.crs_554 yo.ay.ig_543 
  0x51004d13, 0x190a79a0, 0x2f505505, 0x2d002307,   // aa.kl.un_650 war.pt.gl_322  rw.fj.su_333 ca.sk.un_420 
  // [17420]
  0x153038a9, 0x67556408, 0x0e001811, 0x223b4eee,   // tk.uz.un_544 lg.rw.ak_443  ga.is.un_630 ay.so.oc_422 
  0x101b470c, 0x4773590d, 0x08041111, 0x55104ea9,   // sn.tr.lt_543 rn.ny.sn_554  ro.ru.uk_653 ay.lt.rw_544 
  0x4e1a73a9, 0x30004e29, 0x184a0b04, 0x04073509,   // ny.tl.ay_544 ay.uz.un_960  es.yo.ga_332 tg.bg.ru_444 
  0x105127a0, 0x234418af, 0x221d39ad, 0x3e074260,   // gd.kl.lt_322 ar.kk.ky_655  br.la.oc_643 co.it.rm_664 
  // [17430]
  0x04105107, 0x4a00420c, 0x1d186555, 0x34213c0b,   // kl.lt.fi_432 co.yo.un_530  gv.ga.la_442 ug.fa.ps_542 
  0x04001f11, 0xfc4840a7, 0x39122ca4, 0x334c0807,   // cy.fi.un_630 lb.tt.zzp_532  fy.hu.br_433 no.wo.nn_432 
  0x1202080b, 0x2a105107, 0x1c1f1e0c, 0x1d006513,   // no.da.hu_542 kl.lt.mt_432  ms.cy.id_543 gv.la.un_650 
  0x353004a0, 0x6a00390d, 0x3b584012, 0x2c005f04,   // ru.uz.tg_322 br.haw.un_540  lb.om.so_654 tn.fy.un_320 
  // [17440]
  0x3f0306a9, 0x55033907, 0x2d1812ad, 0x18002d13,   // de.nl.af_544 br.nl.rw_432  hu.ga.sk_643 sk.ga.un_650 
  0x1d1279ac, 0x60395f08, 0x332301a4, 0x2c03060c,   // war.hu.la_632 tn.br.vo_443  en.ca.nn_433 de.nl.fy_543 
  0x21031313, 0x3c3b3d13, 0x33021da0, 0x022b65ac,   // et.nl.jw_665 ku.ks.ug_665  la.da.nn_322 gv.vi.da_632 
  0x2c3f3808, 0x4f4062ad, 0x1700fe14, 0x3c343bee,   // tk.af.fy_443 kha.lb.bi_643  tlh.sr.un_660 ks.ps.ug_422 
  // [17450]
  0x222bfe0c, 0x3f000d08, 0x4628fc0c, 0x562b5c0e,   // tlh.vi.oc_543 cs.af.un_430  zzp.sw.qu_543 sa.vi.mg_555 
  0x12182105, 0x2056fea7, 0x112320ee, 0x15360a11,   // fa.ar.ur_333 tlh.mg.sq_532  sq.ca.ro_422 mk.ab.un_653 
  0x42290511, 0x561237a7, 0x3e112f07, 0x36274604,   // fr.sl.co_653 st.hu.mg_532  su.ro.rm_432 qu.gd.gn_332 
  0x390d1912, 0x4f005c14, 0x604ffea4, 0x0b3902a7,   // gl.cs.br_654 sa.bi.un_660  tlh.bi.vo_433 da.br.es_532 
  // [17460]
  0x3f62fe08, 0x2d20560d, 0x05023f04, 0x472d0d04,   // tlh.kha.af_443 mg.sq.sk_554  af.da.fr_332 cs.sk.sn_332 
  0x3e00670c, 0x5d150112, 0x04536a07, 0x3369560e,   // ak.rm.un_530 en.ss.un_640  haw.ht.fi_432 mg.mfe.nn_555 
  0x250428a0, 0x48004314, 0x5e002804, 0x18002d09,   // sw.fi.eu_322 ie.tt.un_660  sw.ts.un_320 sk.ga.un_440 
  0x39560da0, 0x11474d12, 0x02000211, 0x306953a4,   // cs.mg.br_322 aa.sn.ro_654  da.da.un_630 ht.mfe.uz_433 
  // [17470]
  0x2e001205, 0x47001a11, 0x2d3129a0, 0x43190a55,   // hu.fo.un_330 tl.sn.un_630  sl.az.sk_322 pt.gl.ie_442 
  0x591e1c0d, 0x1d2d290b, 0x53051504, 0x11003802,   // id.ms.rn_554 sl.sk.la_542  un.fr.ht_332 tk.ro.un_220 
  0x0d192da0, 0x48336e02, 0x4d285213, 0x5300400e,   // sk.gl.cs_322 hmn.nn.tt_222  ha.sw.aa_665 lb.ht.un_550 
  0x054c53a0, 0x482d2904, 0x1b3148a4, 0x07432a07,   // ht.wo.fr_322 sl.sk.tt_332  tt.az.tr_433 mt.ie.it_432 
  // [17480]
  0x1b131f02, 0x79190a08, 0x464d2a13, 0x0f0747ad,   // cy.et.tr_222 pt.gl.war_443  mt.aa.qu_665 sn.it.lv_643 
  0x4f595514, 0x08292d0c, 0x39120204, 0x21114ba4,   // rw.rn.bi_666 sk.sl.no_543  da.hu.br_332 mi.ro.jw_433 
  0x2d0d0ab6, 0x07045ea4, 0x23261da7, 0x6400450e,   // pt.cs.sk_766 ts.fi.it_433  la.ia.ca_532 ln.lg.un_550 
  0x2d0c3707, 0x79126b13, 0x120d2da0, 0x19002d0b,   // st.sv.sk_432 ceb.hu.war_665  sk.cs.hu_322 sk.gl.un_520 
  // [17490]
  0x18122d55, 0x5d4360ad, 0x4212130d, 0x19001e05,   // sk.hu.ga_442 vo.ie.ss_643  et.hu.co_554 ms.gl.un_330 
  0x1000460d, 0x3229170c, 0x040811ee, 0x0e00600c,   // qu.lt.un_540 sr.sl.bs_543  ro.uk.ru_422 vo.is.un_530 
  0x025d5504, 0x51131007, 0x0300180c, 0x04134204,   // rw.ss.da_332 lt.et.kl_432  ga.nl.un_530 co.et.fi_332 
  0x04234402, 0x04152304, 0x12282355, 0x18231902,   // kk.ky.ru_222 ky.ru.un_320  ky.sd.ur_442 gl.ca.ga_222 
  // [174a0]
  0x0a00111a, 0x1ffc10ee, 0x1d400608, 0x40060c11,   // ro.mk.un_760 lt.zzp.cy_422  de.lb.la_443 sv.de.lb_653 
  0x5a0665a0, 0x066a2113, 0x0e003804, 0x343c28a0,   // gv.de.sm_322 jw.haw.de_665  tk.is.un_320 sd.ug.ps_322 
  0x49004b02, 0x1d400612, 0x2515150e, 0x49001d04,   // mi.to.un_220 de.lb.la_654  un.mn.un_550 la.to.un_320 
  0x28001005, 0xfc400655, 0x300748ad, 0x202d04a7,   // lt.sw.un_330 de.lb.zzp_442  tt.bg.uz_643 fi.sk.sq_532 
  // [174b0]
  0x30212fee, 0x12002008, 0x4a000402, 0xfc0c1f02,   // su.jw.uz_422 sq.hu.un_430  fi.yo.un_220 cy.sv.zzp_222 
  0x1f38fc0b, 0x25066555, 0x2300351a, 0x1d003e08,   // zzp.tk.cy_542 gv.de.eu_442  tg.ky.un_760 rm.la.un_430 
  0x36055dee, 0x12000a0d, 0x2a420713, 0x49041304,   // ss.fr.gn_422 pt.hu.un_540  it.co.mt_665 et.fi.to_332 
  0x443710a0, 0x1b4c5304, 0x0e003707, 0x01002005,   // be.ba.kk_322 ht.wo.tr_332  st.is.un_420 sq.en.un_330 
  // [174c0]
  0x12000405, 0x4f006b12, 0x2a002004, 0x20005c19,   // fi.hu.un_330 ceb.bi.un_640  sq.mt.un_320 sa.sq.un_750 
  0x0c003909, 0x1228340e, 0x1c101e0c, 0x18001e0d,   // br.sv.un_440 ps.sd.ur_555  ms.lt.id_543 ms.ga.un_540 
  0x2f5c200c, 0x571d10a9, 0x69432ea4, 0x5c182707,   // sq.sa.su_543 lt.la.na_544  fo.ie.mfe_433 gd.ga.sa_432 
  0x1d64100c, 0x0e1e67a9, 0x17384455, 0x0f001e08,   // lt.lg.la_543 ak.ms.is_544  kk.tk.sr_442 ms.lv.un_430 
  // [174d0]
  0x0b1d6855, 0x04fc570b, 0x52495a09, 0x033f0e11,   // ig.la.es_442 na.zzp.fi_542  sm.to.ha_444 is.af.nl_653 
  0x280564ee, 0x181f270d, 0x30006713, 0x765c3011,   // lg.fr.sw_422 gd.cy.ga_554  ak.uz.un_650 uz.sa.crs_653 
  0x4600120b, 0x625d18af, 0x192e3604, 0x6915010c,   // hu.qu.un_520 ga.ss.kha_655  gn.fo.gl_332 en.mfe.un_530 
  0x0a002d12, 0x60211ea4, 0x1d24260c, 0x4c646855,   // sk.pt.un_640 ms.jw.vo_433  ia.eo.la_543 ig.lg.wo_442 
  // [174e0]
  0x210264ec, 0x25080702, 0x4b001d0b, 0x36120a0c,   // lg.da.jw_644 bg.uk.mn_222  la.mi.un_520 pt.hu.gn_543 
  0x12000a09, 0x0a0b1907, 0x0a00360e, 0x44071107,   // pt.hu.un_440 gl.es.pt_432  gn.pt.un_550 ro.bg.kk_432 
  0x0e000218, 0x0a000808, 0x3b005b0c, 0x04475813,   // da.is.un_740 uk.mk.un_430  sg.so.un_530 om.sn.fi_665 
  0x395328ee, 0x3b136b08, 0x552f59ec, 0x6b584d04,   // sw.ht.br_422 ceb.et.so_443  rn.su.rw_644 aa.om.ceb_332 
  // [174f0]
  0x3b005814, 0x130447a7, 0x04276aa9, 0x3b045805,   // om.so.un_660 sn.fi.et_532  haw.gd.fi_544 om.fi.so_333 
  0x04506aad, 0x2000301a, 0x07381502, 0x183927a4,   // haw.fj.fi_643 uz.sq.un_760  un.tk.it_222 gd.br.ga_433 
  0x473b58ad, 0x40003b20, 0x584d64af, 0x1b525907,   // om.so.sn_643 so.lb.un_850  lg.aa.om_655 rn.ha.tr_432 
  0x172718a4, 0x04501a08, 0x1100010d, 0x062c0ea0,   // ga.gd.sr_433 tl.fj.fi_443  en.ro.un_540 is.fy.de_322 
  // [17500]
  0x17041304, 0x0e06fc07, 0x5f375d08, 0x102527a9,   // et.fi.sr_332 zzp.de.is_432  ss.st.tn_443 gd.eu.lt_544 
  0x2c036707, 0x181502ee, 0x18275013, 0x5c2718ad,   // ak.nl.fy_432 da.ga.un_420  fj.gd.ga_665 ga.gd.sa_643 
  0x58644c04, 0x13045814, 0x58043b14, 0x272d76ec,   // wo.lg.om_332 om.fi.et_666  so.fi.om_666 crs.sk.gd_644 
  0x5d000508, 0x39005e04, 0x0539650c, 0x655a040c,   // fr.ss.un_430 ts.br.un_320  gv.br.fr_543 fi.sm.gv_543 
  // [17510]
  0x5c00571a, 0x046a39a4, 0x23373c0c, 0x48003c34,   // na.sa.un_760 br.haw.fi_433  ug.ba.ky_543 ug.tt.un_A80 
  0x79392c05, 0x5d001805, 0x360d18af, 0x080d0ca0,   // fy.br.war_333 ga.ss.un_330  ga.cs.gn_655 sv.cs.no_322 
  0x33003507, 0x330c62ee, 0x5c2a0e07, 0x03243f02,   // zu.nn.un_420 kha.sv.nn_422  is.mt.sa_432 af.eo.nl_222 
  0x2d180d04, 0x0c0601a0, 0x25002912, 0x2d0d360e,   // cs.ga.sk_332 en.de.sv_322  sl.eu.un_640 gn.cs.sk_555 
  // [17520]
  0x25004214, 0x33032c08, 0x13002807, 0x212f32a0,   // co.eu.un_660 fy.nl.nn_443  sw.et.un_420 bs.su.jw_322 
  0x0d2d3607, 0x2f0232a0, 0x13004509, 0x26043905,   // gn.sk.cs_432 bs.da.su_322  ln.et.un_440 br.fi.ia_333 
  0x0a042505, 0x02653807, 0x34213dac, 0x09000807,   // mn.ru.mk_333 tk.gv.da_432  ku.fa.ps_632 no.pl.un_420 
  0x09006314, 0x094c1da0, 0x25232404, 0x523e1007,   // sco.pl.un_660 la.wo.pl_322  eo.ca.eu_332 lt.rm.ha_432 
  // [17530]
  0x123d30ad, 0x2e2202a0, 0x48042302, 0x691f2e5a,   // uz.ku.ur_643 da.oc.fo_322  ky.ru.tt_222 fo.cy.mfe_553 
  0x30170404, 0x431d420d, 0x6500390c, 0x4c003907,   // ru.sr.uz_332 co.la.ie_554  br.gv.un_530 br.wo.un_420 
  0x10263907, 0x1d000a08, 0x643773a9, 0x4c00531a,   // br.ia.lt_432 pt.la.un_430  ny.st.lg_544 ht.wo.un_760 
  0x240910a7, 0x3e4c395a, 0x644773ec, 0x0b1d1007,   // lt.pl.eo_532 br.wo.rm_553  ny.sn.lg_644 lt.la.es_432 
  // [17540]
  0x7824640c, 0x02101308, 0x06404ca0, 0x4c00392c,   // lg.eo.ve_543 et.lt.da_443  wo.lb.de_322 br.wo.un_990 
  0x43006913, 0x5900641b, 0x39000622, 0x12394c12,   // mfe.ie.un_650 lg.rn.un_770  de.br.un_870 wo.br.hu_654 
  0x764801a4, 0x67694cad, 0x25483707, 0x2d0d18ed,   // en.tt.crs_433 wo.mfe.ak_643  ba.tt.mn_432 ga.cs.sk_622 
  0x403e690c, 0x47045508, 0x2d0d18ba, 0x60002414,   // mfe.rm.lb_543 rw.fi.sn_443  ga.cs.sk_843 eo.vo.un_660 
  // [17550]
  0x533308ad, 0x13033f12, 0x39000102, 0x104844a4,   // no.nn.ht_643 af.nl.et_654  en.br.un_220 kk.tt.be_433 
  0x2e330807, 0x360d12a9, 0x250a07af, 0x0a0d18b3,   // no.nn.fo_432 hu.cs.gn_544  bg.mk.mn_655 ga.cs.pt_743 
  0x3c2330a7, 0x0d7909a7, 0x2d003405, 0x0f1a6bee,   // uz.ky.ug_532 pl.war.cs_532  xh.sk.un_330 ceb.tl.lv_422 
  0x0a040712, 0x0d4a12a7, 0x4e3f030c, 0x0c000f05,   // bg.ru.mk_654 hu.yo.cs_532  nl.af.ay_543 lv.sv.un_330 
  // [17560]
  0x30443c14, 0x1d0408a0, 0x02004819, 0x371a3f02,   // ug.kk.uz_666 no.fi.la_322  tt.da.un_750 af.tl.st_222 
  0x0f0576a0, 0x36000d14, 0x443848a7, 0x011a0502,   // crs.fr.lv_322 cs.gn.un_660  tt.tk.kk_532 fr.tl.en_222 
  0x12000d11, 0x17304504, 0x182e0ea7, 0x2f216211,   // cs.hu.un_630 ln.uz.sr_332  is.fo.ga_532 kha.jw.su_653 
  0x35341ea4, 0x1a036ba0, 0x1f001322, 0x0d1a0205,   // ms.xh.zu_433 ceb.nl.tl_322  et.cy.un_870 da.tl.cs_333 
  // [17570]
  0x2a136e0c, 0x120d3604, 0x1d37070c, 0x212a2fee,   // hmn.et.mt_543 gn.cs.hu_332  it.st.la_543 su.mt.jw_422 
  0x4c321604, 0x4c2a60ee, 0x6b791aa4, 0x314c1507,   // hr.bs.wo_332 vo.mt.wo_422  tl.war.ceb_433 un.wo.az_432 
  0x5d2d3611, 0x2f003b07, 0x060239a4, 0x12021812,   // gn.sk.ss_653 so.su.un_420  br.da.de_433 ga.da.hu_654 
  0x0c2c06a4, 0x0d004f13, 0x2a1ffea9, 0x02004c0c,   // de.fy.sv_433 bi.cs.un_650  tlh.cy.mt_544 wo.da.un_530 
  // [17580]
  0x0c000f1a, 0x1f132a55, 0x0d0306a4, 0x4000fc09,   // lv.sv.un_760 mt.et.cy_442  de.nl.cs_433 zzp.lb.un_440 
  0x6e00130e, 0xfc3f070c, 0x021d51a4, 0x06353404,   // et.hmn.un_550 it.af.zzp_543  kl.la.da_433 xh.zu.de_332 
  0x46624fec, 0x1200530c, 0x4e204614, 0x531262a9,   // bi.kha.qu_644 ht.hu.un_530  qu.sq.ay_666 kha.hu.ht_544 
  0x53124fa9, 0x033f5107, 0x69210f0c, 0x383e630e,   // bi.hu.ht_544 kl.af.nl_432  lv.jw.mfe_543 sco.rm.tk_555 
  // [17590]
  0x1d22230d, 0x535dfe04, 0xfe621e07, 0x2b1f61ad,   // ca.oc.la_554 tlh.ss.ht_332  ms.kha.tlh_432 za.cy.vi_643 
  0x2f321608, 0x0a004019, 0x32130fa0, 0x151911af,   // hr.bs.su_443 lb.pt.un_750  lv.et.bs_322 ro.gl.un_655 
  0x24001f13, 0x373c480c, 0x1802fca9, 0x2d53560b,   // cy.eo.un_650 tt.ug.ba_543  zzp.da.ga_544 mg.ht.sk_542 
  0x13006b22, 0x05016304, 0x09465cec, 0x1d2b5313,   // ceb.et.un_870 sco.en.fr_332  sa.qu.pl_644 ht.vi.la_665 
  // [175a0]
  0x640f02a0, 0x215c56a7, 0x30233cad, 0x65100607,   // da.lv.lg_322 mg.sa.jw_532  ug.ky.uz_643 de.lt.gv_432 
  0x2b6e7911, 0x65225007, 0x094c46a0, 0x2d4d5c11,   // war.hmn.vi_653 fj.oc.gv_432  qu.wo.pl_322 sa.aa.sk_653 
  0x29006e09, 0x6e400607, 0x15000502, 0x07043ca0,   // hmn.sl.un_440 de.lb.hmn_432  fr.un.un_220 ug.ru.bg_322 
  0x11071dee, 0x223e5704, 0x13400c11, 0x6e736b04,   // la.it.ro_422 na.rm.oc_332  sv.lb.et_653 ceb.ny.hmn_332 
  // [175b0]
  0x095c1ca6, 0x3d1821ec, 0x5b1e50a4, 0x021302ad,   // mr.sa.hi_521 fa.ar.ku_644  fj.ms.sg_433 da.et.da_643 
  0x05231d02, 0x582269af, 0x113905a7, 0x671d250c,   // la.ca.fr_222 mfe.oc.om_655  fr.br.ro_532 eu.la.ak_543 
  0x6b4a68a0, 0x044b250d, 0x301234a0, 0x1b3060a4,   // ig.yo.ceb_322 eu.mi.fi_554  ps.ur.uz_322 vo.uz.tr_433 
  0x2f003708, 0x73004a09, 0x204773ec, 0x18697655,   // st.su.un_430 yo.ny.un_440  ny.sn.sq_644 crs.mfe.ga_442 
  // [175c0]
  0x1b38250c, 0x29624d11, 0x1700360e, 0x1a2503a0,   // eu.tk.tr_543 aa.kha.sl_653  ab.sr.un_550 nl.eu.tl_322 
  0x1e1c5605, 0x035d3f05, 0x25005a19, 0x4c033f5a,   // mg.id.ms_333 af.ss.nl_333  sm.eu.un_750 af.nl.wo_553 
  0x231f1e05, 0x5c294d0d, 0x222311a0, 0x2f330802,   // ms.cy.ca_333 aa.sl.sa_554  ro.ca.oc_322 no.nn.su_222 
  0x291704a0, 0x043f4da9, 0x1a001308, 0x441538af,   // fi.sr.sl_322 aa.af.fi_544  et.tl.un_430 tk.kk.un_650 
  // [175d0]
  0x250410ee, 0x5b214ca4, 0x4500120e, 0x07000420,   // be.ru.mn_422 wo.jw.sg_433  hu.ln.un_550 fi.it.un_850 
  0x5a4904ee, 0x1e1c25a4, 0x20042512, 0x1d690107,   // fi.to.sm_422 eu.id.ms_433  eu.fi.sq_654 en.mfe.la_432 
  0x122e15ee, 0x20251d5a, 0x033f3e0d, 0x35342808,   // un.fo.hu_422 la.eu.sq_553  rm.af.nl_554 sw.xh.zu_443 
  0x40001322, 0x1b313005, 0x29674dec, 0x1c1b30a0,   // et.lb.un_870 uz.az.tr_333  aa.ak.sl_644 uz.tr.id_322 
  // [175e0]
  0x12000d12, 0x22003e0c, 0x03023faf, 0x533e22ad,   // cs.hu.un_640 rm.oc.un_530  af.da.nl_655 oc.rm.ht_643 
  0x3f031a0c, 0x6211010c, 0x0a104402, 0x3e000318,   // tl.nl.af_543 en.ro.kha_543  kk.be.mk_222 nl.rm.un_740 
  0x643e0304, 0x3f034008, 0x3e403faf, 0x536505ac,   // nl.rm.lg_332 lb.nl.af_443  af.lb.rm_655 fr.gv.ht_632 
  0x33001c07, 0x18012113, 0x33790c07, 0x24004305,   // id.nn.un_420 fa.iw.ar_665  sv.war.nn_432 ie.eo.un_330 
  // [175f0]
  0x6b4a1d55, 0x2f1304ee, 0x441735a0, 0x6b001a05,   // la.yo.ceb_442 fi.et.su_422  tg.sr.kk_322 tl.ceb.un_330 
  0x1c00210d, 0x1830340c, 0x213d12ee, 0x375f47ee,   // jw.id.un_540 ps.uz.ar_543  ur.ku.fa_422 sn.tn.st_422 
  0x1e1c20ee, 0x423b1ba7, 0x3f522a05, 0x38241b02,   // sq.id.ms_422 tr.so.co_532  mt.ha.af_333 tr.eo.tk_222 
  0x17005604, 0x08253007, 0x1d0742a0, 0x0b2322a0,   // mg.sr.un_320 uz.mn.uk_432  co.it.la_322 oc.ca.es_322 
  // [17600]
  0x4400121a, 0x31002102, 0x1b313805, 0x0e003202,   // ur.kk.un_760 jw.az.un_220  tk.az.tr_333 bs.is.un_220 
  0x17291607, 0x06001f0c, 0x44000819, 0x0e2e020e,   // hr.sl.sr_432 cy.de.un_530  uk.kk.un_750 da.fo.is_555 
  0x0e2e12ac, 0x23002d0c, 0x5b002b19, 0x15003705,   // hu.fo.is_632 sk.ca.un_530  vi.sg.un_750 ba.un.un_330 
  0x42002b0c, 0x1f562ba0, 0x1f4765a9, 0x5e003709,   // vi.co.un_530 vi.mg.cy_322  gv.sn.cy_544 st.ts.un_440 
  // [17610]
  0x0a004207, 0x0c002a0c, 0x02512ea0, 0x2e200eee,   // co.pt.un_420 mt.sv.un_530  fo.kl.da_322 is.sq.fo_422 
  0x0a3e2ba0, 0x3c48440c, 0x1d181f0c, 0x5b4d2b0c,   // vi.rm.pt_322 kk.tt.ug_543  cy.ga.la_543 vi.aa.sg_543 
  0x22234214, 0x06490408, 0x23041504, 0x02006a2b,   // co.ca.oc_666 fi.to.de_443  un.ru.ky_332 haw.da.un_980 
  0x6000361a, 0x49512804, 0x2c020407, 0x11004314,   // gn.vo.un_760 sw.kl.to_332  fi.da.fy_432 ie.ro.un_660 
  // [17620]
  0x13005821, 0x2c470e08, 0x304807a4, 0x65fe5808,   // om.et.un_860 is.sn.fy_443  bg.tt.uz_433 om.tlh.gv_443 
  0x17383605, 0x20316904, 0x06120ea0, 0x62007613,   // ab.tk.sr_333 mfe.az.sq_332  is.hu.de_322 crs.kha.un_650 
  0x190b230e, 0x040e2c09, 0xfc0263ec, 0x0f1248a0,   // ca.es.gl_555 fy.is.fi_444  sco.da.zzp_644 tt.hu.lv_322 
  0xfe5807a0, 0x381b52a9, 0x233848ec, 0x51285aa0,   // it.om.tlh_322 ha.tr.tk_544  tt.tk.ky_644 sm.sw.kl_322 
  // [17630]
  0x023610a9, 0x130402ec, 0x2e3633ec, 0x0f1050af,   // lt.gn.da_544 da.fi.et_644  nn.gn.fo_644 fj.lt.lv_655 
  0x5d002c04, 0x100f33a4, 0x0f6976a4, 0x10000f2c,   // fy.ss.un_320 nn.lv.lt_433  crs.mfe.lv_433 lv.lt.un_990 
  0x12000305, 0x08250a05, 0x0e000225, 0x362338a9,   // nl.hu.un_330 mk.mn.uk_333  da.is.un_920 tk.ky.ab_544 
  0x15003818, 0x48006e08, 0x1b003f02, 0x09003912,   // tk.un.un_740 hmn.tt.un_430  af.tr.un_220 br.pl.un_640 
  // [17640]
  0x4004010c, 0x0f044da7, 0x1b003f04, 0x010315a0,   // en.fi.lb_543 aa.fi.lv_532  af.tr.un_320 un.nl.en_322 
  0x43001d0d, 0x1a390502, 0x15004413, 0x1a591e0e,   // la.ie.un_540 fr.br.tl_222  kk.un.un_650 ms.rn.tl_555 
  0x21684c12, 0x5f232f02, 0x4b0213ec, 0x182427a4,   // wo.ig.jw_654 su.ca.tn_222  et.da.mi_644 gd.eo.ga_433 
  0x42182711, 0x1f5065ee, 0x27251d04, 0x0c1d24ad,   // gd.ga.co_653 gv.fj.cy_422  la.eu.gd_332 eo.la.sv_643 
  // [17650]
  0x2718200c, 0x27004b07, 0x2508330c, 0x4404150c,   // sq.ga.gd_543 mi.gd.un_420  nn.no.eu_543 un.ru.kk_543 
  0x27021807, 0x372718ee, 0x5100200b, 0x4200040c,   // ga.da.gd_432 ga.gd.st_422  sq.kl.un_520 fi.co.un_530 
  0x09074204, 0x204f27a4, 0x421d24a0, 0x792046a0,   // co.it.pl_332 gd.bi.sq_433  eo.la.co_322 qu.sq.war_322 
  0x4c002519, 0x0420250c, 0x5600450c, 0x464e0b05,   // eu.wo.un_750 eu.sq.fi_543  ln.mg.un_530 es.ay.qu_333 
  // [17660]
  0x072718ee, 0x13001a34, 0x345d1dee, 0x4a2a0d12,   // ga.gd.it_422 tl.et.un_A80  la.ss.xh_422 cs.mt.yo_654 
  0x5c003b0d, 0xfe0212ec, 0x393f1d09, 0x696033a4,   // so.sa.un_540 hu.da.tlh_644  la.af.br_444 nn.vo.mfe_433 
  0x240119a0, 0x6021480c, 0x794209ec, 0x37005307,   // gl.en.eo_322 tt.jw.vo_543  pl.co.war_644 ht.st.un_420 
  0x19270aad, 0x39041055, 0x524c01a4, 0x4c00390d,   // pt.gd.gl_643 lt.fi.br_442  en.wo.ha_433 br.wo.un_540 
  // [17670]
  0x0a0c27a7, 0x062c01a4, 0x4c00790d, 0x353644a0,   // gd.sv.pt_532 en.fy.de_433  war.wo.un_540 kk.ab.tg_322 
  0x30585e0c, 0x170f10a9, 0x4f691ea0, 0x05002802,   // ts.om.uz_543 lt.lv.sr_544  ms.mfe.bi_322 sw.fr.un_220 
  0x2000581a, 0x0500520c, 0x235e5d0d, 0x231008a7,   // om.sq.un_760 ha.fr.un_530  ss.ts.ca_554 uk.be.ky_532 
  0x25002405, 0x343d1212, 0x2e650404, 0x043025a0,   // eo.eu.un_330 ur.ku.ps_654  fi.gv.fo_332 mn.uz.ru_322 
  // [17680]
  0x48441007, 0x331f62ad, 0x48001520, 0x213c300b,   // be.kk.tt_432 kha.cy.nn_643  un.tt.un_850 uz.ug.fa_542 
  0x07190107, 0x151004a7, 0x330825a4, 0x48006014,   // en.gl.it_432 fi.lt.un_532  eu.no.nn_433 vo.tt.un_660 
  0x022e0fa0, 0x322d6ea0, 0x6b791a05, 0x37345d04,   // lv.fo.da_322 hmn.sk.bs_322  tl.war.ceb_333 ss.xh.st_332 
  0x475078ec, 0x15240aee, 0x2900760e, 0x093f6309,   // ve.fj.sn_644 pt.eo.un_422  crs.sl.un_550 sco.af.pl_444 
  // [17690]
  0x4b595555, 0x5c00560d, 0x4f002608, 0x230701a0,   // rw.rn.mi_442 mg.sa.un_540  ia.bi.un_430 en.it.ca_322 
  0x13101807, 0x796b1a60, 0x26000113, 0x0d000304,   // ga.lt.et_432 tl.ceb.war_664  en.ia.un_650 nl.cs.un_320 
  0x3625080c, 0x10003c14, 0x5e134b07, 0x0c0208af,   // uk.mn.ab_543 ug.be.un_660  mi.et.ts_432 no.da.sv_655 
  0x444823ec, 0x0e080255, 0x205c6504, 0x073e2312,   // ky.tt.kk_644 da.no.is_442  gv.sa.sq_332 ca.rm.it_654 
  // [176a0]
  0x02005504, 0x44004819, 0x01000908, 0x681101a0,   // rw.da.un_320 tt.kk.un_750  pl.en.un_430 en.ro.ig_322 
  0x32292dad, 0x133f0e07, 0x43001f0e, 0x32001b08,   // sk.sl.bs_643 is.af.et_432  cy.ie.un_550 tr.bs.un_430 
  0xfe001112, 0x130108a4, 0x65000411, 0x2531040b,   // ro.tlh.un_640 no.en.et_433  fi.gv.un_630 fi.az.eu_542 
  0x04082502, 0x2f205708, 0x11000204, 0x0a2304af,   // mn.uk.ru_222 na.sq.su_443  da.ro.un_320 ru.ky.mk_655 
  // [176b0]
  0x0800480c, 0x1100180d, 0x1538250d, 0x340311a4,   // tt.uk.un_530 ga.ro.un_540  mn.tk.un_554 ro.nl.xh_433 
  0x11003f0e, 0x330811ee, 0x02111f11, 0x2e0211a4,   // af.ro.un_550 ro.no.nn_422  cy.ro.da_653 ro.da.fo_433 
  0x0211130c, 0x343f0ca0, 0x23113c12, 0x374505a9,   // et.ro.da_543 sv.af.xh_322  ug.ro.ky_654 fr.ln.st_544 
  0x04151009, 0x40000408, 0xfc030508, 0x43007805,   // be.ru.un_440 fi.lb.un_430  fr.nl.zzp_443 ve.ie.un_330 
  // [176c0]
  0x4500fc12, 0x5051fc0b, 0x25005802, 0x1530355a,   // zzp.ln.un_640 zzp.kl.fj_542  om.eu.un_220 tg.uz.un_553 
  0x5100040c, 0x204f040c, 0x43110760, 0x52474a04,   // fi.kl.un_530 fi.bi.sq_543  it.ro.ie_664 yo.sn.ha_332 
  0x030240ac, 0x5100671a, 0x79420705, 0x4400040d,   // lb.da.nl_632 ak.kl.un_760  it.co.war_333 ru.kk.un_540 
  0x2f1d2307, 0x1b301ea4, 0x0c000707, 0x111f4ca9,   // ca.la.su_432 ms.uz.tr_433  it.sv.un_420 wo.cy.ro_544 
  // [176d0]
  0x11001b02, 0x1b7920ad, 0x1e1c5102, 0x0e311b08,   // tr.ro.un_220 sq.war.tr_643  kl.id.ms_222 tr.az.is_443 
  0x642520a0, 0x21003d20, 0x045a5004, 0x45045104,   // sq.eu.lg_322 ku.fa.un_850  fj.sm.fi_332 kl.fi.ln_332 
  0x5e004b0c, 0x69531ea4, 0x1b003135, 0x56233e11,   // mi.ts.un_530 ms.ht.mfe_433  az.tr.un_A90 rm.ca.mg_653 
  0x64004b05, 0x5b3064a4, 0x73004a08, 0x644e5805,   // mi.lg.un_330 lg.uz.sg_433  yo.ny.un_430 om.ay.lg_333 
  // [176e0]
  0x1213040c, 0x04000108, 0x3e222308, 0x42052e0c,   // fi.et.hu_543 en.fi.un_430  ca.oc.rm_443 fo.fr.co_543 
  0x0c01fca0, 0x3f035808, 0x3f2a42a7, 0x1b000212,   // zzp.en.sv_322 om.nl.af_443  co.mt.af_532 da.tr.un_640 
  0x28353408, 0x2d0d1805, 0x0c423e08, 0x42600107,   // xh.zu.sw_443 ga.cs.sk_333  rm.co.sv_443 en.vo.co_432 
  0x15001120, 0x58510412, 0x78001c04, 0x47182711,   // ro.un.un_850 fi.kl.om_654  id.ve.un_320 gd.ga.sn_653 
  // [176f0]
  0x0d193608, 0x330d65ad, 0x0c004b08, 0x2500671a,   // gn.gl.cs_443 gv.cs.nn_643  mi.sv.un_430 ak.eu.un_760 
  0x185c2704, 0xfe27730d, 0x25044904, 0x2a0e2ea4,   // gd.sa.ga_332 ny.gd.tlh_554  to.fi.eu_332 fo.is.mt_433 
  0x34211811, 0x026301ee, 0x400201af, 0x392856a0,   // ar.fa.ps_653 en.sco.da_422  en.da.lb_655 mg.sw.br_322 
  0x5e007822, 0x375f20ec, 0x35372a07, 0x1236455a,   // ve.ts.un_870 sq.tn.st_644  mt.st.zu_432 ln.gn.hu_553 
  // [17700]
  0x13044004, 0x04001322, 0x254430af, 0x381b0da9,   // lb.fi.et_332 et.fi.un_870  uz.kk.mn_655 cs.tr.tk_544 
  0x4600580e, 0x3f111307, 0x13004014, 0x5e380107,   // om.qu.un_550 et.ro.af_432  lb.et.un_660 en.tk.ts_432 
  0x395e01a0, 0x563952ad, 0x2f353405, 0x0400401b,   // en.ts.br_322 ha.br.mg_643  xh.zu.su_333 lb.fi.un_770 
  0x18003613, 0x04370802, 0x10395e08, 0x061b5e0c,   // gn.ga.un_650 uk.ba.ru_222  ts.br.lt_443 ts.tr.de_543 
  // [17710]
  0x0c5e1d08, 0x0f003e0d, 0x0ffc3ea7, 0x39633fa4,   // la.ts.sv_443 rm.lv.un_540  rm.zzp.lv_532 af.sco.br_433 
  0xfc003e1b, 0x1d003919, 0x081d570c, 0x13044008,   // rm.zzp.un_770 br.la.un_750  na.la.no_543 lb.fi.et_443 
  0x5600fe0d, 0x0a171004, 0x46002012, 0x48004013,   // tlh.mg.un_540 be.sr.mk_332  sq.qu.un_640 lb.tt.un_650 
  0x3e3f0304, 0x231234a7, 0x0a173005, 0x23213c07,   // nl.af.rm_332 ps.ur.ky_532  uz.sr.mk_333 ug.fa.ky_432 
  // [17720]
  0x10440805, 0x166306a4, 0x0a1538a4, 0x483046a0,   // uk.kk.be_333 de.sco.hr_433  tk.mk.un_430 qu.uz.tt_322 
  0x1d3e01a4, 0x09001f1b, 0x76fc3ea7, 0x37444812,   // en.rm.la_433 cy.pl.un_770  rm.zzp.crs_532 tt.kk.ba_654 
  0x2b005204, 0x0a1517a9, 0x171504ee, 0x42694c04,   // ha.vi.un_320 sr.mk.un_540  ru.sr.un_420 wo.mfe.co_332 
  0x30001e13, 0x286504a7, 0x62632505, 0xfe136ea9,   // ms.uz.un_650 fi.gv.sw_532  eu.sco.kha_333 hmn.et.tlh_544 
  // [17730]
  0x120d43a7, 0x7913020c, 0x5a004304, 0x3bfe130c,   // ie.cs.hu_532 da.et.war_543  ie.sm.un_320 et.tlh.so_543 
  0x3602090c, 0x79571308, 0x070e2e07, 0x3308150c,   // pl.da.gn_543 et.na.war_443  fo.is.it_432 un.no.nn_543 
  0x0a072304, 0x31793baf, 0x5c002913, 0x5c002912,   // ky.bg.mk_332 so.war.az_655  sl.sa.un_650 sl.sa.un_640 
  0x29400e0c, 0x5c00291a, 0x76005b08, 0x691331ad,   // is.lb.sl_543 sl.sa.un_760  sg.crs.un_430 az.et.mfe_643 
  // [17740]
  0x7669130d, 0x51004209, 0x4c4d760d, 0x4a006b0c,   // et.mfe.crs_554 co.kl.un_440  crs.aa.wo_554 ceb.yo.un_530 
  0x13314d0c, 0x6e3b4da0, 0x1100040e, 0x4c002308,   // aa.az.et_543 aa.so.hmn_322  ru.ro.un_550 ca.wo.un_430 
  0x2e0e45a9, 0x1800361f, 0x38303c0d, 0x1c5d350b,   // ln.is.fo_544 gn.ga.un_840  ug.uz.tk_554 zu.ss.id_542 
  0x29005c12, 0x5c002921, 0x125c2907, 0x2500640d,   // sa.sl.un_640 sl.sa.un_860  sl.sa.hu_432 lg.eu.un_540 
  // [17750]
  0x23253509, 0x18194604, 0x0d00fe0d, 0x4a0c6bee,   // tg.mn.ky_444 qu.gl.ga_332  tlh.cs.un_540 ceb.sv.yo_422 
  0xfe00290c, 0x68001a08, 0x0a001809, 0x4830350d,   // sl.tlh.un_530 tl.ig.un_430  ga.pt.un_440 tg.uz.tt_554 
  0x07442307, 0x10170a02, 0x07483704, 0x32002205,   // ky.kk.bg_432 mk.sr.be_222  ba.tt.bg_332 oc.bs.un_330 
  0x04070a60, 0x321e17ee, 0x391d0955, 0x31001508,   // mk.bg.ru_664 sr.ms.bs_422  pl.la.br_442 un.az.un_430 
  // [17760]
  0x3e241dee, 0x3e0a0604, 0x391d4304, 0x232d0d04,   // la.eo.rm_422 de.pt.rm_332  ie.la.br_332 cs.sk.ca_332 
  0x7578fa08, 0x04321608, 0x59524a07, 0x251511ec,   // nr.ve.nso_443 hr.bs.fi_443  yo.ha.rn_432 ro.mn.un_640 
  0x59004505, 0x47006b08, 0x0a001804, 0x04071107,   // ln.rn.un_330 ceb.sn.un_430  ga.pt.un_320 ro.bg.ru_432 
  0x68002508, 0x29002f08, 0xfc006a08, 0x47004b0d,   // eu.ig.un_430 su.sl.un_430  haw.zzp.un_430 mi.sn.un_540 
  // [17770]
  0x360704a4, 0x622a2604, 0x1e001a07, 0x10150410,   // ru.bg.ab_433 ia.mt.kha_332  tl.ms.un_420 ru.be.un_620 
  0x4c12540c, 0x31391b04, 0x1f344705, 0x1d4d6707,   // ik.hu.wo_543 tr.br.az_332  sn.xh.cy_333 ak.aa.la_432 
  0x73504513, 0x1c2f6208, 0x0e006713, 0x55674511,   // ln.fj.ny_665 kha.su.id_443  ak.is.un_650 ln.ak.rw_653 
  0x6776450c, 0x163b35a0, 0x06011fee, 0x1200181f,   // ln.crs.ak_543 zu.so.hr_322  cy.en.de_422 ga.hu.un_840 
  // [17780]
  0x6b1a78a9, 0x64000412, 0x6b5a5ca4, 0x1d005a13,   // ve.tl.ceb_544 fi.lg.un_640  sa.sm.ceb_433 sm.la.un_650 
  0x6b540e5a, 0x02003105, 0x46005e2b, 0x64024708,   // is.ik.ceb_553 az.da.un_330  ts.qu.un_980 sn.da.lg_443 
  0x5000080d, 0x2efc51a7, 0x32796b12, 0x2f2125a4,   // no.fj.un_540 kl.zzp.fo_532  ceb.war.bs_654 eu.jw.su_433 
  0x130c5eec, 0x4c785aad, 0x04126b08, 0x6928730c,   // ts.sv.et_644 sm.ve.wo_643  ceb.hu.fi_443 ny.sw.mfe_543 
  // [17790]
  0x12040f0d, 0x330e2eee, 0x5a10190c, 0x5a1019a0,   // lv.fi.hu_554 fo.is.nn_422  gl.lt.sm_543 gl.lt.sm_322 
  0x28046aec, 0x68005219, 0x32165502, 0x0a001817,   // haw.fi.sw_644 ha.ig.un_750  rw.hr.bs_222 ga.pt.un_730 
  0x4c502f12, 0x5a0e2ead, 0x52273bee, 0x214d520b,   // su.fj.wo_654 fo.is.sm_643  so.gd.ha_422 ha.aa.jw_542 
  0x285973ad, 0x5c546405, 0x64595512, 0x4b002f02,   // ny.rn.sw_643 lg.ik.sa_333  rw.rn.lg_654 su.mi.un_220 
  // [177a0]
  0x52114d07, 0x02791a08, 0x4a1e57a7, 0x521501a4,   // aa.ro.ha_432 tl.war.da_443  na.ms.yo_532 en.ha.un_430 
  0x01655704, 0x284955ee, 0x353446a6, 0x48100808,   // na.gv.en_332 rw.to.sw_422  qu.xh.zu_521 uk.be.tt_443 
  0x5e007323, 0x011f6507, 0x455a2f0d, 0x1f33085a,   // ny.ts.un_880 gv.cy.en_432  su.sm.ln_554 no.nn.cy_553 
  0x213c3d55, 0x6500091b, 0x070436ec, 0x451f6305,   // ku.ug.fa_442 pl.gv.un_770  ab.ru.bg_644 sco.cy.ln_333 
  // [177b0]
  0x4400180b, 0x07041055, 0x1500480e, 0x25004413,   // ar.kk.un_520 be.ru.bg_442  tt.un.un_550 kk.mn.un_650 
  0xfc001d0d, 0x3b3903a0, 0x2325440c, 0x6e000209,   // la.zzp.un_540 nl.br.so_322  kk.mn.ky_543 da.hmn.un_440 
  0x04150811, 0x3100130b, 0x15353008, 0x222342a0,   // uk.ru.un_630 et.az.un_520  uz.tg.un_443 co.ca.oc_322 
  0x12183407, 0x483035ad, 0x37231509, 0x0c0802ee,   // ps.ar.ur_432 tg.uz.tt_643  un.ky.ba_444 da.no.sv_422 
  // [177c0]
  0x30152514, 0x1107230c, 0x40060307, 0x1b003922,   // mn.uz.un_660 ky.bg.ro_543  nl.de.lb_432 br.tr.un_870 
  0x12635308, 0x4004200c, 0x25000c05, 0x23341208,   // ht.sco.hu_443 sq.fi.lb_543  sv.eu.un_330 ur.ps.ky_443 
  0x2d005611, 0x2130345a, 0x4cfe39ad, 0x1c215604,   // mg.sk.un_630 ps.uz.fa_553  br.tlh.wo_643 mg.jw.id_332 
  0x34003212, 0x172102a4, 0x2f0a1b08, 0x332b6212,   // bs.ps.un_640 da.jw.sr_433  tr.pt.su_443 kha.vi.nn_654 
  // [177d0]
  0x2f002502, 0x195a36a0, 0x2f613855, 0x6a006014,   // eu.su.un_220 gn.sm.gl_322  tk.za.su_442 vo.haw.un_660 
  0x1300fc0e, 0x30003c29, 0x121f56ad, 0x1d002f14,   // zzp.et.un_550 ug.uz.un_960  mg.cy.hu_643 su.la.un_660 
  0x7900020d, 0xfe070104, 0x53397612, 0x3f03050c,   // da.war.un_540 en.it.tlh_332  crs.br.ht_654 fr.nl.af_543 
  0x47353402, 0x2f005f0e, 0x2100530e, 0x39790604,   // xh.zu.sn_222 tn.su.un_550  ht.jw.un_550 de.war.br_332 
  // [177e0]
  0x1d0a13ee, 0xfe00620d, 0x1d004213, 0x69050107,   // et.pt.la_422 kha.tlh.un_540  co.la.un_650 en.fr.mfe_432 
  0x2f563ea4, 0x03623f14, 0x0f00261a, 0x051127a4,   // rm.mg.su_433 af.kha.nl_666  ia.lv.un_760 gd.ro.fr_433 
  0x0c0e600d, 0x3f033502, 0x12003202, 0x1b486012,   // vo.is.sv_554 zu.nl.af_222  bs.hu.un_220 vo.tt.tr_654 
  0x2344360c, 0x431d4fa4, 0x506a2755, 0x23392fa7,   // ab.kk.ky_543 bi.la.ie_433  gd.haw.fj_442 su.br.ca_532 
  // [177f0]
  0x16002707, 0x4c002b22, 0x251c1e11, 0x303812a0,   // gd.hr.un_420 vi.wo.un_870  ms.id.eu_653 hu.tk.uz_322 
  0x20002f02, 0x190a1da0, 0x343d300b, 0x230742a4,   // su.sq.un_220 la.pt.gl_322  uz.ku.ps_542 co.it.ca_433 
  0x030e0f07, 0x3e0612a0, 0x0c0343ee, 0x1200540d,   // lv.is.nl_432 hu.de.rm_322  ie.nl.sv_422 ik.hu.un_540 
  0x25635004, 0x342123a7, 0x3c443811, 0x52354aee,   // fj.sco.eu_332 ky.fa.ps_532  tk.kk.ug_653 yo.zu.ha_422 
  
  // [17800]
  0xfc097307, 0x483815a4, 0x53002112, 0x645e3507,   // ny.pl.zzp_432 un.tk.tt_433  jw.ht.un_640 zu.ts.lg_432 
  0x65001f19, 0x52005504, 0x2873260e, 0x25000718,   // cy.gv.un_750 rw.ha.un_320  ia.ny.sw_555 it.eu.un_740 
  0x2a09180c, 0x481711a0, 0x55686408, 0x10001d18,   // ga.pl.mt_543 ro.sr.tt_322  lg.ig.rw_443 la.lt.un_740 
  0x12343ca7, 0x5f003408, 0x4b477308, 0x1a6b5608,   // ug.ps.ur_532 xh.tn.un_430  ny.sn.mi_443 mg.ceb.tl_443 
  // [17810]
  0x02695f0c, 0x477873ad, 0x40000704, 0x780256a9,   // tn.mfe.da_543 ny.ve.sn_643  it.lb.un_320 mg.da.ve_544 
  0x375f75ad, 0x30377809, 0x5ffc4704, 0x21000802,   // nso.tn.st_643 ve.st.uz_444  sn.zzp.tn_332 no.jw.un_220 
  0x025f370c, 0x5c5d48a0, 0x75375f60, 0x37005720,   // st.tn.da_543 tt.ss.sa_322  tn.st.nso_664 na.st.un_850 
  0x1b3855a4, 0x11002811, 0x022efc07, 0x020cfc07,   // rw.tk.tr_433 sw.ro.un_630  zzp.fo.da_432 zzp.sv.da_432 
  // [17820]
  0xfe005e05, 0x06791f09, 0x28644702, 0x16005805,   // ts.tlh.un_330 cy.war.de_444  sn.lg.sw_222 om.hr.un_330 
  0x4e001c13, 0x0c02fca9, 0x022e0ea7, 0x5d36450d,   // id.ay.un_650 zzp.da.sv_544  is.fo.da_532 ln.gn.ss_554 
  0x4c1e02ad, 0x11094207, 0x6b3e51a9, 0x2e020c07,   // da.ms.wo_643 co.pl.ro_432  kl.rm.ceb_544 sv.da.fo_432 
  0x355d65a0, 0x48563307, 0x3e6561a7, 0x345d5e0c,   // gv.ss.zu_322 nn.mg.tt_432  za.gv.rm_532 ts.ss.xh_543 
  // [17830]
  0x642a6107, 0x25371508, 0x2efc1fa7, 0x1e1c2ba0,   // za.mt.lg_432 un.ba.mn_443  cy.zzp.fo_532 vi.id.ms_322 
  0x42fc0604, 0x0c0efc07, 0x52fe4c04, 0x0e00200d,   // de.zzp.co_332 zzp.is.sv_432  wo.tlh.ha_332 sq.is.un_540 
  0x4800372c, 0x44233708, 0x1c171ea4, 0x12004519,   // ba.tt.un_990 ba.ky.kk_443  ms.sr.id_433 ln.hu.un_750 
  0x44041709, 0x48373012, 0x3800111a, 0x30122812,   // sr.ru.kk_444 uz.ba.tt_654  ro.tk.un_760 sd.ur.uz_654 
  // [17840]
  0x22002804, 0x390a1fa0, 0x151f38a0, 0x0407110d,   // sw.oc.un_320 cy.pt.br_322  tk.cy.un_322 ro.bg.ru_554 
  0x36003904, 0x480a2c07, 0x1f000a04, 0x12214dee,   // br.gn.un_320 fy.pt.tt_432  pt.cy.un_320 aa.jw.hu_422 
  0x370448a0, 0x0b001808, 0x5cfc0204, 0x2100440c,   // tt.ru.ba_322 ga.es.un_430  da.zzp.sa_332 kk.fa.un_530 
  0x114d1260, 0x55093bec, 0x5520feee, 0x02000918,   // hu.aa.ro_664 so.pl.rw_644  tlh.sq.rw_422 pl.da.un_740 
  // [17850]
  0x170a0802, 0x385509a0, 0x34213da6, 0x09553bec,   // uk.mk.sr_222 pl.rw.tk_322  ku.fa.ps_521 so.rw.pl_644 
  0x551b4aa0, 0x34123ca9, 0x55000913, 0x2e00180d,   // yo.tr.rw_322 ug.ur.ps_544  pl.rw.un_650 ga.fo.un_540 
  0x38550207, 0x47005e2b, 0x2c4603ee, 0x3b5509ad,   // da.rw.tk_432 ts.sn.un_980  nl.qu.fy_422 pl.rw.so_643 
  0x2e1236a7, 0xfc095513, 0x35004a19, 0x73006a04,   // gn.hu.fo_532 rw.pl.zzp_665  yo.zu.un_750 haw.ny.un_320 
  // [17860]
  0x3c233008, 0x15170a55, 0x08151012, 0x04004c0b,   // uz.ky.ug_443 mk.sr.un_442  be.uk.un_640 wo.fi.un_520 
  0x38002904, 0x05426302, 0x1e2f6502, 0x3f03690c,   // sl.tk.un_320 sco.co.fr_222  gv.su.ms_222 mfe.nl.af_543 
  0x153c4804, 0x2d0d6905, 0x58007912, 0x11080709,   // tt.ug.un_332 mfe.cs.sk_333  war.om.un_640 bg.uk.ro_444 
  0x10440804, 0x311137a0, 0x790105a0, 0x033f2e08,   // uk.kk.be_332 st.ro.az_322  fr.en.war_322 fo.af.nl_443 
  // [17870]
  0x01005404, 0x07fc2f05, 0x28733ba9, 0x12190e05,   // ik.en.un_320 su.zzp.it_333  so.ny.sw_544 is.gl.hu_333 
  0x235622a0, 0x44041560, 0x025d35a4, 0x75645f14,   // oc.mg.ca_322 un.ru.kk_664  zu.ss.da_433 tn.lg.nso_666 
  0xfc5736a9, 0x5a4d4905, 0xfc400107, 0x0e332ea9,   // gn.na.zzp_544 to.aa.sm_333  en.lb.zzp_432 fo.nn.is_544 
  0x52001b0c, 0x4b004008, 0x126a1307, 0x53005d07,   // tr.ha.un_530 lb.mi.un_430  et.haw.hu_432 ss.ht.un_420 
  // [17880]
  0x16003502, 0x30153c07, 0x34355d60, 0x2e00290d,   // zu.hr.un_220 ug.uz.un_420  ss.zu.xh_664 sl.fo.un_540 
  0x2e2864a0, 0x0b407904, 0x185d2704, 0x0a043707,   // lg.sw.fo_322 war.lb.es_332  gd.ss.ga_332 ba.ru.mk_432 
  0x0d1f2d07, 0x1e00430d, 0x3f633bee, 0x342b4ead,   // sk.cy.cs_432 ie.ms.un_540  so.sco.af_422 ay.vi.xh_643 
  0x443d23a4, 0x1d276007, 0x12343055, 0x15100409,   // ky.ku.kk_433 vo.gd.la_432  uz.ps.ur_442 ru.be.un_444 
  // [17890]
  0x38153607, 0x150a10a4, 0x564b1ca4, 0x25433012,   // ab.tk.un_420 be.mk.un_433  id.mi.mg_433 uz.ie.eu_654 
  0x35040aa0, 0x480c0655, 0x35380404, 0x0e3028a9,   // mk.ru.tg_322 de.sv.tt_442  ru.tk.tg_332 sw.uz.is_544 
  0x0a353012, 0x2a474da9, 0x1300511a, 0x3d3c23a4,   // uz.tg.mk_654 aa.sn.mt_544  kl.et.un_760 ky.ug.ku_433 
  0x10081105, 0x2b001108, 0x230460a7, 0x2f006e04,   // ro.uk.be_333 ro.vi.un_430  vo.fi.ca_532 hmn.su.un_320 
  // [178a0]
  0x2f2160ac, 0x541a465a, 0x310a3ba7, 0x032f43a0,   // vo.jw.su_632 qu.tl.ik_553  so.pt.az_532 ie.su.nl_322 
  0x037901a0, 0x190b51a9, 0x475c01a0, 0x3000462b,   // en.war.nl_322 kl.es.gl_544  en.sa.sn_322 qu.uz.un_980 
  0x09103eac, 0x440737a9, 0x40200ea0, 0x1a00601a,   // rm.lt.pl_632 ba.bg.kk_544  is.sq.lb_322 vo.tl.un_760 
  0x2d005c08, 0x04351509, 0x3048380b, 0x21002a02,   // sa.sk.un_430 un.tg.ru_444  tk.tt.uz_542 mt.jw.un_220 
  // [178b0]
  0x155dfc04, 0x35254d07, 0x53002c04, 0x024c0404,   // zzp.ss.un_332 aa.eu.zu_432  fy.ht.un_320 fi.wo.da_332 
  0x1b3e2155, 0x6b121a04, 0x12040f08, 0x0f00040c,   // jw.rm.tr_442 tl.hu.ceb_332  lv.fi.hu_443 fi.lv.un_530 
  0x07443811, 0x6900760d, 0x060563a0, 0x2f211c05,   // tk.kk.bg_653 crs.mfe.un_540  sco.fr.de_322 id.jw.su_333 
  0x0a002804, 0x432a0f05, 0x375d3504, 0x2948300b,   // sw.pt.un_320 lv.mt.ie_333  zu.ss.st_332 uz.tt.sl_542 
  // [178c0]
  0x6a002813, 0x5e097305, 0x5f3749ad, 0x21003d21,   // sw.haw.un_650 ny.pl.ts_333  to.st.tn_643 ku.fa.un_860 
  0x283020ad, 0x08031c04, 0x2f1c13ad, 0x2c036007,   // sq.uz.sw_643 id.nl.no_332  et.id.su_643 vo.nl.fy_432 
  0x6053250c, 0x3b4c6b0d, 0x182328ac, 0x353425a6,   // eu.ht.vo_543 ceb.wo.so_554  sd.ky.ar_632 eu.xh.zu_521 
  0x1a004b02, 0x0900290e, 0x2932160e, 0x251504ad,   // mi.tl.un_220 sl.pl.un_550  hr.bs.sl_555 ru.mn.un_630 
  // [178d0]
  0x08250407, 0x42001f08, 0x183021ad, 0x08004413,   // ru.mn.uk_432 cy.co.un_430  fa.uz.ar_643 kk.uk.un_650 
  0x2e0c0ead, 0x374823a4, 0x07002404, 0x1d07620c,   // is.sv.fo_643 ky.tt.ba_433  eo.it.un_320 kha.it.la_543 
  0x30003204, 0x351048a7, 0x5e0e37af, 0x42000721,   // bs.uz.un_320 tt.be.tg_532  st.is.ts_655 it.co.un_860 
  0x09003502, 0x2220230c, 0x4a045aa4, 0x1f00610e,   // zu.pl.un_220 ca.sq.oc_543  sm.fi.yo_433 za.cy.un_550 
  // [178e0]
  0x3f0c79a4, 0x12004907, 0x330e40a9, 0x02061fa0,   // war.sv.af_433 to.hu.un_420  lb.is.nn_544 cy.de.da_322 
  0x13110107, 0x080f0e0c, 0x066257a4, 0x1515040e,   // en.ro.et_432 is.lv.no_543  na.kha.de_433 ru.un.un_550 
  0x1020010b, 0x35231705, 0x033f4804, 0x65026055,   // en.sq.lt_542 sr.ky.tg_333  tt.af.nl_332 vo.da.gv_442 
  0x090430a4, 0x0a0f6ba0, 0x30134812, 0x5d007311,   // uz.fi.pl_433 ceb.lv.pt_322  tt.et.uz_654 ny.ss.un_630 
  // [178f0]
  0x303d120d, 0x1d003e1a, 0x47216ba9, 0x1d002412,   // ur.ku.uz_554 rm.la.un_760  ceb.jw.sn_544 eo.la.un_640 
  0x685e020d, 0x5d00730c, 0x421001ad, 0x6b792f09,   // da.ts.ig_554 ny.ss.un_530  en.lt.co_643 su.war.ceb_444 
  0x2f40610c, 0x552847af, 0x731c1ea9, 0x1d001014,   // za.lb.su_543 sn.sw.rw_655  ms.id.ny_544 lt.la.un_660 
  0x12342114, 0x35071107, 0x355e51a4, 0x182334a0,   // fa.ps.ur_666 ro.bg.tg_432  kl.ts.zu_433 ps.ky.ar_322 
  // [17900]
  0x2f5106ee, 0x04443702, 0x35345105, 0x46005508,   // de.kl.su_422 ba.kk.ru_222  kl.xh.zu_333 rw.qu.un_430 
  0x30483707, 0x21303ba9, 0x0c5748a4, 0x20130412,   // ba.tt.uz_432 ks.uz.fa_544  tt.na.sv_433 fi.et.sq_654 
  0x100415ee, 0x480c1305, 0x401306af, 0x3f0301af,   // un.ru.be_422 et.sv.tt_333  de.et.lb_655 en.nl.af_655 
  0x19122d0c, 0x2c003313, 0x3f0601a0, 0x400c4802,   // sk.hu.gl_543 nn.fy.un_650  en.de.af_322 tt.sv.lb_222 
  // [17910]
  0x48000c16, 0xfa4736ec, 0x400206ac, 0x3e200305,   // sv.tt.un_720 gn.sn.nr_644  de.da.lb_632 nl.sq.rm_333 
  0x03403f13, 0x05030107, 0x190b0aec, 0x3f0333a0,   // af.lb.nl_665 en.nl.fr_432  pt.es.gl_644 nn.nl.af_322 
  0x4804600b, 0xfc005a21, 0x52001e0c, 0x52002802,   // vo.fi.tt_542 sm.zzp.un_860  ms.ha.un_530 sw.ha.un_220 
  0x2e5d450c, 0x540a515a, 0x5a04490c, 0x10353011,   // ln.ss.fo_543 kl.pt.ik_553  to.fi.sm_543 uz.tg.be_653 
  // [17920]
  0x2b2e18ec, 0x190b18a4, 0x285afc0c, 0x4a55280d,   // ga.fo.vi_644 ga.es.gl_433  zzp.sm.sw_543 sw.rw.yo_554 
  0x3400040c, 0x33001504, 0x293b380c, 0x0e3b12a7,   // fi.xh.un_530 un.nn.un_320  tk.so.sl_543 hu.so.is_532 
  0x07043c08, 0x2a003019, 0x79196507, 0x29301ba0,   // ug.ru.bg_443 uz.mt.un_750  gv.gl.war_432 tr.uz.sl_322 
  0x23001808, 0x0400340d, 0xfc5528a7, 0x2a583b07,   // ar.ky.un_430 xh.fi.un_540  sw.rw.zzp_532 so.om.mt_432 
  // [17930]
  0x3f031313, 0x1327480c, 0x37483c08, 0x30172555,   // et.nl.af_665 tt.gd.et_543  ug.tt.ba_443 mn.sr.uz_442 
  0x04234811, 0x384804ee, 0x0c0640ec, 0x4800601a,   // tt.ky.ru_653 fi.tt.tk_422  lb.de.sv_644 vo.tt.un_760 
  0x5f001305, 0x07353012, 0x2f2103ee, 0x0c000417,   // et.tn.un_330 uz.tg.bg_654  nl.jw.su_422 fi.sv.un_730 
  0x0a0823ee, 0x6413020b, 0x024a16a4, 0x28023b08,   // ky.uk.mk_422 da.et.lg_542  hr.yo.da_433 so.da.sw_443 
  // [17940]
  0x4b375cee, 0x12003611, 0x67595513, 0x0c0413b3,   // sa.st.mi_422 gn.hu.un_630  rw.rn.ak_665 et.fi.sv_743 
  0x3510300d, 0x34584b14, 0x5d175e04, 0x34001308,   // uz.be.tg_554 mi.om.xh_666  ts.sr.ss_332 et.xh.un_430 
  0x684c3408, 0x02002a0d, 0x65464c07, 0x63404c0c,   // xh.wo.ig_443 mt.da.un_540  wo.qu.gv_432 wo.lb.sco_543 
  0x531501a4, 0x041035a0, 0x02005819, 0x11483404,   // en.ht.un_430 tg.be.ru_322  om.da.un_750 xh.tt.ro_332 
  // [17950]
  0x285834ad, 0x53466aa0, 0x3f2515a0, 0x78531ca4,   // xh.om.sw_643 haw.qu.ht_322  un.eu.af_322 id.ht.ve_433 
  0xfe30330c, 0x5d123505, 0x041510ac, 0x4d003020,   // nn.uz.tlh_543 zu.hu.ss_333  be.ru.un_620 uz.aa.un_850 
  0xfc343fa7, 0x021d250c, 0x0c046010, 0x654b63a7,   // af.xh.zzp_532 eu.la.da_543  vo.fi.sv_642 sco.mi.gv_532 
  0x18280a04, 0x58004c19, 0x694553ec, 0x136568ee,   // pt.sw.ga_332 wo.om.un_750  ht.ln.mfe_644 ig.gv.et_422 
  // [17960]
  0x3f030ba9, 0x4a5a13ad, 0x2a000705, 0x1d070aa0,   // es.nl.af_544 et.sm.yo_643  it.mt.un_330 pt.it.la_322 
  0x73001211, 0x0900480d, 0x63fe30ee, 0x06650c04,   // hu.ny.un_630 tt.pl.un_540  uz.tlh.sco_422 sv.gv.de_332 
  0x3b3d30a4, 0x0d292daf, 0x345d350d, 0x03001509,   // uz.ku.ks_433 sk.sl.cs_655  zu.ss.xh_554 un.nl.un_440 
  0x3e063fa9, 0x190a39ec, 0x313058af, 0x07006a1a,   // af.de.rm_544 br.pt.gl_644  om.uz.az_655 haw.it.un_760 
  // [17970]
  0x633f010b, 0x28003e09, 0x27026312, 0x292d0daf,   // en.af.sco_542 rm.sw.un_440  sco.da.gd_654 cs.sk.sl_655 
  0x45006819, 0x556406a0, 0x18123413, 0x22260505,   // ig.ln.un_750 de.lg.rw_322  ps.ur.ar_665 fr.ia.oc_333 
  0x2600570e, 0x5c07fca0, 0x1500180c, 0x48041004,   // na.ia.un_550 zzp.it.sa_322  ar.un.un_530 be.ru.tt_332 
  0x55001e02, 0x511328ac, 0x512804ec, 0xfc2d0104,   // ms.rw.un_220 sw.et.kl_632  fi.sw.kl_644 en.sk.zzp_332 
  // [17980]
  0x180b190c, 0x515a6aa4, 0x230726a0, 0x0c000613,   // gl.es.ga_543 haw.sm.kl_433  ia.it.ca_322 de.sv.un_650 
  0x111d01a4, 0x080a110c, 0x1b31480e, 0x06006e0c,   // en.la.ro_433 ro.mk.uk_543  tt.az.tr_555 hmn.de.un_530 
  0x483c385a, 0x190b18a0, 0x7300491a, 0x3d3b2107,   // tk.ug.tt_553 ga.es.gl_322  to.ny.un_760 fa.ks.ku_432 
  0x4b003702, 0x53004b0c, 0x4b5a495a, 0x18496a04,   // st.mi.un_220 mi.ht.un_530  to.sm.mi_553 haw.to.ga_332 
  // [17990]
  0x122d0ca4, 0x162d10ee, 0x79321608, 0x56496aa0,   // sv.sk.hu_433 lt.sk.hr_422  hr.bs.war_443 haw.to.mg_322 
  0x30443504, 0x42395aee, 0x123028a9, 0x384423a4,   // tg.kk.uz_332 sm.br.co_422  sd.uz.ur_544 ky.kk.tk_433 
  0x31481bac, 0x48373808, 0x29101704, 0x25190a04,   // tr.tt.az_632 tk.ba.tt_443  sr.lt.sl_332 pt.gl.eu_332 
  0x254b07ee, 0x343c300d, 0x734a6811, 0x1c000404,   // it.mi.eu_422 uz.ug.ps_554  ig.yo.ny_653 fi.id.un_320 
  // [179a0]
  0x23213405, 0x551573ee, 0x212964ee, 0x5e003411,   // ps.fa.ky_333 ny.rw.un_420  lg.sl.jw_422 xh.ts.un_630 
  0x55004a0c, 0x1a465302, 0x210126ee, 0x31000808,   // yo.rw.un_530 ht.qu.tl_222  ia.en.jw_422 no.az.un_430 
  0x350425ee, 0x181234ad, 0x1f003302, 0x181230a7,   // mn.ru.tg_422 ps.ur.ar_643  nn.cy.un_220 uz.ur.ar_532 
  0x58002a0c, 0x3f00260e, 0x55645ea0, 0x0d0c2da4,   // mt.om.un_530 ia.af.un_550  ts.lg.rw_322 sk.sv.cs_433 
  // [179b0]
  0x043019a0, 0x52284ca9, 0x5d002c05, 0x044b2807,   // gl.uz.fi_322 wo.sw.ha_544  fy.ss.un_330 sw.mi.fi_432 
  0x17082304, 0x23303c07, 0x332e08ac, 0x3723150c,   // ky.uk.sr_332 ug.uz.ky_432  no.fo.nn_632 un.ky.ba_543 
  0x172d2912, 0x2a004b07, 0x04004b07, 0x23003509,   // sl.sk.sr_654 mi.mt.un_420  mi.fi.un_420 tg.ky.un_440 
  0x4b004c13, 0x23353004, 0x124d57a4, 0x345347a0,   // wo.mi.un_650 uz.tg.ky_332  na.aa.hu_433 sn.ht.xh_322 
  // [179c0]
  0x016540a0, 0x070830ee, 0x64733ba0, 0x08003c14,   // lb.gv.en_322 uz.uk.bg_422  so.ny.lg_322 ug.uk.un_660 
  0x39103804, 0x04110708, 0x4407360c, 0x21341210,   // tk.lt.br_332 bg.ro.ru_443  ab.bg.kk_543 ur.ps.fa_642 
  0x1d003002, 0x05511d07, 0x1f4d38a4, 0x373547ad,   // uz.la.un_220 la.kl.fr_432  tk.aa.cy_433 sn.zu.st_643 
  0x0a00380e, 0x64573507, 0xfc470112, 0x20311a07,   // tk.mk.un_550 zu.na.lg_432  en.sn.zzp_654 tl.az.sq_432 
  // [179d0]
  0x03351b04, 0x46fc290c, 0x4b000f07, 0x06003f07,   // tr.zu.nl_332 sl.zzp.qu_543  lv.mi.un_420 af.de.un_420 
  0x300a51a7, 0x277653a4, 0x2f0833a0, 0x22000204,   // kl.pt.uz_532 ht.crs.gd_433  nn.no.su_322 da.oc.un_320 
  0xfc2542a0, 0x6700690e, 0x3f2451ee, 0x070a3512,   // co.eu.zzp_322 mfe.ak.un_550  kl.eo.af_422 tg.mk.bg_654 
  0x330206a0, 0x321755a0, 0x73595509, 0x5e4702ad,   // de.da.nn_322 rw.sr.bs_322  rw.rn.ny_444 da.sn.ts_643 
  // [179e0]
  0x0200330b, 0x34005d2a, 0x2a003907, 0x534c2807,   // nn.da.un_520 ss.xh.un_970  dz.bo.un_420 sw.wo.ht_432 
  0x11001713, 0x36040805, 0x0408170d, 0x070a100e,   // sr.ro.un_650 uk.ru.ab_333  sr.uk.ru_554 be.mk.bg_555 
  0x24004a12, 0x3c122807, 0x233844af, 0x23302107,   // yo.eo.un_640 sd.ur.ug_432  kk.tk.ky_655 fa.uz.ky_432 
  0x48004004, 0x16001008, 0x304501a4, 0x57475608,   // lb.tt.un_320 lt.hr.un_430  en.ln.uz_433 mg.sn.na_443 
  // [179f0]
  0x09001e04, 0x355557a4, 0x10332aad, 0x0c692c07,   // ms.pl.un_320 na.rw.zu_433  mt.nn.lt_643 fy.mfe.sv_432 
  0x561f1008, 0x5a732109, 0x503b51a7, 0x4a000909,   // lt.cy.mg_443 jw.ny.sm_444  kl.so.fj_532 pl.yo.un_440 
  0x494d5c0c, 0x233b2708, 0x0c76690c, 0x0f1502ee,   // sa.aa.to_543 gd.so.ca_443  mfe.crs.sv_543 da.lv.un_420 
  0x2a135ca0, 0x31001502, 0x48583808, 0x012b1507,   // sa.et.mt_322 un.az.un_220  tk.om.tt_443 un.vi.en_432 
  // [17a00]
  0x212f090c, 0x5e56120c, 0x07000504, 0x65fc2cee,   // pl.su.jw_543 hu.mg.ts_543  fr.it.un_320 fy.zzp.gv_422 
  0x642173a7, 0x304d0107, 0x4c1d01a0, 0x150a0813,   // ny.jw.lg_532 en.aa.uz_432  en.la.wo_322 uk.mk.un_665 
  0x28554aa4, 0x39005b08, 0x4f2501a4, 0x31483060,   // yo.rw.sw_433 sg.br.un_430  en.eu.bi_433 uz.tt.az_664 
  0x063f0204, 0x063f02ee, 0xfe694312, 0x3151fe07,   // da.af.de_332 da.af.de_422  ie.mfe.tlh_654 tlh.kl.az_432 
  // [17a10]
  0x40033f13, 0x464e01a9, 0x65483009, 0x351234ee,   // af.nl.lb_665 en.ay.qu_544  uz.tt.gv_444 xh.hu.zu_422 
  0x096365a4, 0x240f0e07, 0x025c10ee, 0x056b6307,   // gv.sco.pl_433 is.lv.eo_432  lt.sa.da_422 sco.ceb.fr_432 
  0x382530a4, 0x043e51a9, 0x08000c09, 0x51054004,   // uz.mn.tk_433 kl.rm.fi_544  sv.no.un_440 lb.fr.kl_332 
  0x10000d07, 0x301834a4, 0x2d0d32a9, 0x1138300c,   // cs.lt.un_420 ps.ar.uz_433  bs.cs.sk_544 uz.tk.ro_543 
  // [17a20]
  0x172d0d04, 0x58005b21, 0x0a071505, 0x343d210b,   // cs.sk.sr_332 sg.om.un_860  un.bg.mk_333 fa.ku.ps_542 
  0x23304408, 0x10150455, 0x271828a0, 0x02001319,   // kk.uz.ky_443 ru.be.un_420  sw.ga.gd_322 et.da.un_750 
  0x5f375a0c, 0x3c170755, 0x2b273907, 0x2b2243ee,   // sm.st.tn_543 bg.sr.ug_442  br.gd.vi_432 ie.oc.vi_422 
  0x185a2705, 0x1f5a6a07, 0x5e6b56ee, 0x492537ad,   // gd.sm.ga_333 haw.sm.cy_432  mg.ceb.ts_422 st.eu.to_643 
  // [17a30]
  0x785e6a12, 0x56421ca9, 0x454b37a9, 0x5f375a12,   // haw.ts.ve_654 id.co.mg_544  st.mi.ln_544 sm.st.tn_654 
  0x735a3712, 0x5e005612, 0x6a005034, 0x1d2307ee,   // st.sm.ny_654 mg.ts.un_640  fj.haw.un_A80 it.ca.la_422 
  0x39271812, 0x49003919, 0x2f451c0c, 0x18295907,   // ga.gd.br_654 br.to.un_750  id.ln.su_543 rn.sl.ga_432 
  0x0a5258ad, 0x2d1024a4, 0x4b5a1360, 0xfc3e1daf,   // om.ha.pt_643 eo.lt.sk_433  et.sm.mi_664 la.rm.zzp_655 
  // [17a40]
  0x450256ad, 0x09006708, 0x020f5607, 0x5f5075a9,   // mg.da.ln_643 ak.pl.un_430  mg.lv.da_432 nso.fj.tn_544 
  0x75375ea9, 0x230b220c, 0x342a5e12, 0x230b220d,   // ts.st.nso_544 oc.es.ca_543  ts.mt.xh_654 oc.es.ca_554 
  0x102916a4, 0x5e375f60, 0x07003514, 0x75263708,   // hr.sl.lt_433 tn.st.ts_664  tg.bg.un_660 st.ia.nso_443 
  0x3b006305, 0x4d003023, 0x24001d14, 0x790d09ec,   // sco.so.un_330 uz.aa.un_880  la.eo.un_660 pl.cs.war_644 
  // [17a50]
  0x2d171605, 0x035b52ad, 0x5d755e0c, 0x5f5e4ba9,   // hr.sr.sk_333 ha.sg.nl_643  ts.nso.ss_543 mi.ts.tn_544 
  0x1f4623ee, 0x1b345913, 0x3848310c, 0x0b23220c,   // ca.qu.cy_422 rn.xh.tr_665  az.tt.tk_543 oc.ca.es_543 
  0x093b5755, 0x081504a0, 0x65000312, 0x1b003507,   // na.so.pl_442 ru.uk.un_320  nl.gv.un_640 zu.tr.un_420 
  0x311b12a6, 0x481b3805, 0x13384807, 0x3b3e2f08,   // hu.tr.az_521 tk.tr.tt_333  tt.tk.et_432 su.rm.so_443 
  // [17a60]
  0x460e2ea4, 0x1c420e04, 0x0a0411ec, 0x48006010,   // fo.is.qu_433 is.co.id_332  ro.ru.mk_644 vo.tt.un_620 
  0x5c2f54ac, 0x65fc01a4, 0x23100407, 0x2e0efea4,   // ik.su.sa_632 en.zzp.gv_433  ru.be.ky_432 tlh.is.fo_433 
  0x0e003611, 0x212e0e07, 0x352330a9, 0x0d5c0913,   // gn.is.un_630 is.fo.jw_432  uz.ky.tg_544 hi.sa.ne_665 
  0x23371508, 0x60004f13, 0x162910a0, 0x134020a0,   // un.ba.ky_443 bi.vo.un_650  lt.sl.hr_322 sq.lb.et_322 
  // [17a70]
  0x13035307, 0x29321755, 0x2f4f790d, 0x200111a6,   // ht.nl.et_432 sr.bs.sl_442  war.bi.su_554 ro.en.sq_521 
  0x321710ee, 0x37265fa4, 0x343f06a0, 0x5e791fa0,   // lt.sr.bs_422 tn.ia.st_433  de.af.xh_322 cy.war.ts_322 
  0x3b004807, 0x552a34a0, 0x110425a4, 0x342c0311,   // tt.so.un_420 xh.mt.rw_322  mn.ru.ro_433 nl.fy.xh_653 
  0x6343fc05, 0x340311ad, 0x355e7305, 0x131102ee,   // zzp.ie.sco_333 ro.nl.xh_643  ny.ts.zu_333 da.ro.et_422 
  // [17a80]
  0x1dfc0fec, 0x345d35a7, 0x17162da6, 0x11330805,   // lv.zzp.la_644 zu.ss.xh_532  sk.hr.sr_521 no.nn.ro_333 
  0x01113308, 0x0e000302, 0x524815a0, 0x343f4655,   // nn.ro.en_443 nl.is.un_220  un.tt.ha_322 qu.af.xh_442 
  0xfc650508, 0x65545112, 0x28003205, 0x23443d09,   // fr.gv.zzp_443 kl.ik.gv_654  bs.sw.un_330 ku.kk.ky_444 
  0x5e2c3f04, 0x17102aa4, 0x100444a7, 0x076548a6,   // af.fy.ts_332 mt.lt.sr_433  kk.ru.be_532 tt.gv.it_521 
  // [17a90]
  0x13300304, 0x2718510e, 0x64322808, 0x10170807,   // nl.uz.et_332 kl.ga.gd_555  sw.bs.lg_443 uk.sr.be_432 
  0x533903ad, 0x6e61fead, 0x345f620c, 0x30234860,   // nl.br.ht_643 tlh.za.hmn_643  kha.tn.xh_543 tt.ky.uz_664 
  0x39002007, 0x100744ec, 0x651f62ec, 0x0c060e0e,   // sq.br.un_420 kk.bg.be_644  kha.cy.gv_644 is.de.sv_555 
  0x0e00480e, 0x582f5107, 0x0e0c1304, 0x0332165a,   // tt.is.un_550 kl.su.om_432  et.sv.is_332 hr.bs.nl_553 
  // [17aa0]
  0x301821ee, 0x0d290304, 0x12060e04, 0x32281609,   // fa.ar.uz_422 nl.sl.cs_332  is.de.hu_332 hr.sw.bs_444 
  0x0c120ea0, 0xfe00391a, 0x6100fe1b, 0x060e04ee,   // is.hu.sv_322 br.tlh.un_760  tlh.za.un_770 fi.is.de_422 
  0x0e000613, 0x480640a0, 0x04301112, 0x084837ee,   // de.is.un_650 lb.de.tt_322  ro.uz.ru_654 ba.tt.uk_422 
  0x48182111, 0x1200480b, 0x08153507, 0x2f614fa4,   // fa.ar.tt_653 tt.hu.un_520  tg.uk.un_420 bi.za.su_433 
  // [17ab0]
  0x381008a4, 0x442337a4, 0x1b4006a7, 0x64504a04,   // uk.be.tk_433 ba.ky.kk_433  de.lb.tr_532 yo.fj.lg_332 
  0x040e1304, 0x380460a6, 0x09574d0c, 0x793e020d,   // et.is.fi_332 vo.fi.tk_521  aa.na.pl_543 da.rm.war_554 
  0x1d005112, 0x755f3708, 0x0c375f5a, 0x230f60ac,   // kl.la.un_640 st.tn.nso_443  tn.st.sv_553 vo.lv.ca_632 
  0x230f60ee, 0x255f5d08, 0x11001a02, 0x1d005105,   // vo.lv.ca_422 ss.tn.eu_443  tl.ro.un_220 kl.la.un_330 
  // [17ac0]
  0x02fc63ec, 0x0f006021, 0x5c005607, 0x12303407,   // sco.zzp.da_644 vo.lv.un_860  mg.sa.un_420 ps.uz.ur_432 
  0x060f6055, 0x372873a4, 0x5c023ead, 0x380c0e0c,   // vo.lv.de_442 ny.sw.st_433  rm.da.sa_643 is.sv.tk_543 
  0x3e0f6013, 0x13483007, 0x475f02ee, 0x34006418,   // vo.lv.rm_665 uz.tt.et_432  da.tn.sn_422 lg.xh.un_740 
  0x390253ec, 0x5815600c, 0x39055307, 0x0a4e565a,   // ht.da.br_644 vo.om.un_530  ht.fr.br_432 mg.ay.pt_553 
  // [17ad0]
  0x19400a07, 0x2353470c, 0x5b05530c, 0x791d0bec,   // pt.lb.gl_432 sn.ht.ca_543  ht.fr.sg_543 es.la.war_644 
  0x5f237309, 0x2221010c, 0x5a286407, 0x304637ac,   // ny.ca.tn_444 en.jw.oc_543  lg.sw.sm_432 st.qu.uz_632 
  0x47566507, 0x420628a4, 0x1e121a04, 0x0f00601a,   // gv.mg.sn_432 sw.de.co_433  tl.hu.ms_332 vo.lv.un_760 
  0x233f0205, 0x46391f07, 0x0e007307, 0x47000212,   // da.af.ca_333 cy.br.qu_432  ny.is.un_420 da.sn.un_640 
  // [17ae0]
  0x63000f13, 0x463933a0, 0x1200600d, 0x1a3430a0,   // lv.sco.un_650 nn.br.qu_322  vo.hu.un_540 uz.xh.tl_322 
  0x48002e0d, 0x314e670c, 0x4c21455a, 0x5e3b19ec,   // fo.tt.un_540 ak.ay.az_543  ln.jw.wo_553 gl.so.ts_644 
  0x63450507, 0x32005012, 0x55fc64ee, 0x10604ea9,   // fr.ln.sco_432 fj.bs.un_640  lg.zzp.rw_422 ay.vo.lt_544 
  0x5267450b, 0x530501a4, 0x273615a0, 0x4e000104,   // ln.ak.ha_542 en.fr.ht_433  un.gn.gd_322 en.ay.un_320 
  // [17af0]
  0x091a795a, 0x5e456707, 0x3953600c, 0x48695355,   // war.tl.pl_553 ak.ln.ts_432  vo.ht.br_543 ht.mfe.tt_442 
  0x56025907, 0x040810ec, 0x401304ee, 0x53621007,   // rn.da.mg_432 be.uk.ru_644  fi.et.lb_422 lt.kha.ht_432 
  0x60630107, 0x07421fa0, 0x260b1da6, 0x15003905,   // en.sco.vo_432 cy.co.it_322  la.es.ia_521 br.un.un_330 
  0x024a64a4, 0x1f114a07, 0x383048ec, 0x4b595560,   // lg.yo.da_433 yo.ro.cy_432  tt.uz.tk_644 rw.rn.mi_664 
  // [17b00]
  0x42110507, 0x6b001607, 0x64020408, 0x026020a4,   // fr.ro.co_432 hr.ceb.un_420  fi.da.lg_443 sq.vo.da_433 
  0x2e56600c, 0x074004a0, 0x052501a0, 0x20402508,   // vo.mg.fo_543 fi.lb.it_322  en.eu.fr_322 eu.lb.sq_443 
  0x2f622108, 0x253920a0, 0x65544da4, 0x024c2a07,   // jw.kha.su_443 sq.br.eu_322  aa.ik.gv_433 mt.wo.da_432 
  0x2211430c, 0x554759a7, 0x233c250c, 0x23001809,   // ie.ro.oc_543 rn.sn.rw_532  mn.ug.ky_543 ar.ky.un_440 
  // [17b10]
  0x4d004c2c, 0x6b654d55, 0x3f1f6204, 0x40035b04,   // wo.aa.un_990 aa.gv.ceb_442  kha.cy.af_332 sg.nl.lb_332 
  0x083525a7, 0x2e4c0e07, 0x0a04250c, 0x102344a0,   // mn.tg.uk_532 is.wo.fo_432  mn.ru.mk_543 kk.ky.be_322 
  0x2300110e, 0x1d001f0c, 0x31001702, 0x3f1ffc0b,   // ro.ky.un_550 cy.la.un_530  sr.az.un_220 zzp.cy.af_542 
  0x2335110b, 0x28125ca4, 0x10005c19, 0x2e000d08,   // ro.tg.ky_542 sa.hu.sw_433  sa.lt.un_750 cs.fo.un_430 
  // [17b20]
  0x1100020b, 0x29005c0d, 0x2b005c0d, 0xfc121fa0,   // da.ro.un_520 sa.sl.un_540  sa.vi.un_540 cy.hu.zzp_322 
  0x3530150d, 0x12105ca9, 0x49065a07, 0x481b3804,   // un.uz.tg_554 sa.lt.hu_544  sm.de.to_432 tk.tr.tt_332 
  0x495a06ad, 0x0e1506a0, 0x3400211b, 0x285a060c,   // de.sm.to_643 de.is.un_320  fa.ps.un_770 de.sm.sw_543 
  0x03050604, 0x49570612, 0x5300210b, 0x0e0622a0,   // de.fr.nl_332 de.na.to_654  jw.ht.un_520 oc.de.is_322 
  // [17b30]
  0x06105c07, 0x06005f0b, 0x12005c19, 0x12105cad,   // sa.lt.de_432 tn.de.un_520  sa.hu.un_750 sa.lt.hu_643 
  0x06303107, 0x5a490604, 0x4057060d, 0x30353709,   // az.uz.de_432 de.to.sm_332  de.na.lb_554 ba.tg.uz_444 
  0x1200390c, 0x0411130b, 0x51001308, 0x5413240c,   // br.hu.un_530 et.ro.fi_542  et.kl.un_430 eo.et.ik_543 
  0x2a2446a4, 0x1812090c, 0x2d0f13a0, 0x0d006112,   // qu.eo.mt_433 pl.hu.ga_543  et.lv.sk_322 za.cs.un_640 
  // [17b40]
  0x37444813, 0x28005108, 0x150a15a4, 0x510a0107,   // tt.kk.ba_665 kl.sw.un_430  un.mk.un_433 en.pt.kl_432 
  0x050312ee, 0x2412025a, 0x2e0e0207, 0x3d003421,   // hu.nl.fr_422 da.hu.eo_553  da.is.fo_432 ps.ku.un_860 
  0x21402f60, 0x4b496a0c, 0x2c5103a0, 0x520e6aec,   // su.lb.jw_664 haw.to.mi_543  nl.kl.fy_322 haw.is.ha_644 
  0x2d0d280c, 0x68461e0c, 0x49006b04, 0x3b255aad,   // sw.cs.sk_543 ms.qu.ig_543  ceb.to.un_320 sm.eu.so_643 
  // [17b50]
  0x11005b12, 0x2c3711ad, 0x674b6aad, 0x2800731a,   // sg.ro.un_640 ro.st.fy_643  haw.mi.ak_643 ny.sw.un_760 
  0x033f63ee, 0x2763010c, 0x375f450d, 0x114d5c07,   // sco.af.nl_422 en.sco.gd_543  ln.tn.st_554 sa.aa.ro_432 
  0x345d560d, 0x36002711, 0x78375e14, 0x05182704,   // mg.ss.xh_554 gd.gn.un_630  ts.st.ve_666 gd.ga.fr_332 
  0x1f000a0c, 0x182763ec, 0x341218a4, 0x7968520d,   // pt.cy.un_530 sco.gd.ga_644  ar.ur.ps_433 ha.ig.war_554 
  // [17b60]
  0x5f00670d, 0x12182802, 0x1a213ea4, 0x575e56af,   // ak.tn.un_540 sd.ar.ur_222  rm.jw.tl_433 mg.ts.na_655 
  0x01000508, 0x7930fe07, 0x5747110c, 0x37003007,   // fr.en.un_430 tlh.uz.war_432  ro.sn.na_543 uz.ba.un_420 
  0x135e4760, 0x78455e12, 0x3e0523a4, 0x272463ee,   // sn.ts.et_664 ts.ln.ve_654  ca.fr.rm_433 sco.eo.gd_422 
  0x58524b12, 0x42000a12, 0x785673a9, 0x05004309,   // mi.ha.om_654 pt.co.un_640  ny.mg.ve_544 ie.fr.un_440 
  // [17b70]
  0x08002707, 0x47732809, 0x5c3b27a7, 0x275c1808,   // gd.no.un_420 sw.ny.sn_444  gd.so.sa_532 ga.sa.gd_443 
  0x2000300d, 0x3e061809, 0x353730af, 0x24004807,   // uz.sq.un_540 ga.de.rm_444  uz.ba.tg_655 tt.eo.un_420 
  0x09006e0c, 0x231507a7, 0x6218fc08, 0x653046a4,   // hmn.pl.un_530 bg.ky.un_520  zzp.ga.kha_443 qu.uz.gv_433 
  0x3548170c, 0x2c090304, 0x130d1c09, 0xfc000114,   // sr.tt.tg_543 nl.pl.fy_332  mr.ne.bh_444 en.zzp.un_660 
  // [17b80]
  0x04072307, 0x44373555, 0x09135c02, 0x2e00280b,   // ky.bg.ru_432 tg.ba.kk_442  sa.bh.hi_222 sw.fo.un_520 
  0x352548ee, 0x12002b1a, 0x08022e0e, 0x23003820,   // tt.mn.tg_422 vi.hu.un_760  fo.da.no_555 tk.ky.un_850 
  0x4437480d, 0x25005b12, 0x1d402007, 0x04253604,   // tt.ba.kk_554 sg.eu.un_640  sq.lb.la_432 ab.mn.ru_332 
  0x08351508, 0x051dfcee, 0x0e002512, 0x132225a0,   // un.tg.uk_443 zzp.la.fr_422  eu.is.un_640 eu.oc.et_322 
  // [17b90]
  0x251d20a0, 0x3e002002, 0x51540405, 0x17040a0d,   // sq.la.eu_322 sq.rm.un_220  fi.ik.kl_333 mk.ru.sr_554 
  0x3f044907, 0x28000402, 0x27500407, 0x65491804,   // to.fi.af_432 fi.sw.un_220  fi.fj.gd_432 ga.to.gv_332 
  0x073617a0, 0x1100270c, 0x3900280e, 0x39045a11,   // sr.ab.bg_322 gd.ro.un_530  sw.br.un_550 sm.fi.br_653 
  0x044a515a, 0x2a000307, 0x2700040c, 0x134e2060,   // kl.yo.fi_553 nl.mt.un_420  fi.gd.un_530 sq.ay.et_664 
  // [17ba0]
  0x232201a9, 0x23226307, 0x2144230d, 0x2a1a13a0,   // en.oc.ca_544 sco.oc.ca_432  ky.kk.fa_554 et.tl.mt_322 
  0x3e1e1cee, 0x796201ee, 0x0c232213, 0x03321608,   // id.ms.rm_422 en.kha.war_422  oc.ca.sv_665 hr.bs.nl_443 
  0x09080ca0, 0x390efc04, 0x572301a9, 0x0c12fc0c,   // sv.no.pl_322 zzp.is.br_332  en.ca.na_544 zzp.hu.sv_543 
  0x233e05a0, 0xfc0e4c05, 0x6435fca0, 0x04232504,   // fr.rm.ca_322 wo.is.zzp_333  zzp.zu.lg_322 mn.ky.ru_332 
  // [17bb0]
  0x5e2234a0, 0x6b130c04, 0x6bfe6012, 0x4523050c,   // xh.oc.ts_322 sv.et.ceb_332  vo.tlh.ceb_654 fr.ca.ln_543 
  0x12005e11, 0x1e122104, 0x39001908, 0x5e00110c,   // ts.hu.un_630 jw.hu.ms_332  gl.br.un_430 ro.ts.un_530 
  0x0c2e3309, 0x393f11a4, 0x2d000605, 0x123f0e05,   // nn.fo.sv_444 ro.af.br_433  de.sk.un_330 is.af.hu_333 
  0x482713ee, 0x36005502, 0x5f4c37a0, 0x132d0904,   // et.gd.tt_422 rw.gn.un_220  st.wo.tn_322 pl.sk.et_332 
  // [17bc0]
  0x2d0d4fa0, 0x45735613, 0x290913a4, 0x46044507,   // bi.cs.sk_322 mg.ny.ln_665  et.pl.sl_433 ln.fi.qu_432 
  0x21002409, 0x111304a0, 0x453621a0, 0x160b25a4,   // eo.jw.un_440 fi.et.ro_322  jw.gn.ln_322 eu.es.hr_433 
  0x495a45a4, 0x130411ee, 0x38000a05, 0x2a000e04,   // ln.sm.to_433 ro.fi.et_422  pt.tk.un_330 is.mt.un_320 
  0x13201d07, 0x48002207, 0x63261d04, 0x28600107,   // la.sq.et_432 oc.tt.un_420  la.ia.sco_332 en.vo.sw_432 
  // [17bd0]
  0x0e302e04, 0x241b31af, 0x133325a7, 0x62132da0,   // fo.uz.is_332 az.tr.eo_655  eu.nn.et_532 sk.et.kha_322 
  0x50790e04, 0x1100130e, 0x21283402, 0x0e0c51a0,   // is.war.fj_332 et.ro.un_550  ps.sd.fa_222 kl.sv.is_322 
  0x07083707, 0x36000b07, 0x153c30af, 0x1b4838a4,   // ba.uk.bg_432 es.gn.un_420  uz.ug.un_655 tk.tt.tr_433 
  0x0b2d4204, 0x15374804, 0x041025ee, 0x52025613,   // co.sk.es_332 tt.ba.un_332  mn.be.ru_422 mg.da.ha_665 
  // [17be0]
  0x025e040d, 0x2512feac, 0x5e00520d, 0x735d5608,   // fi.ts.da_554 tlh.hu.eu_632  ha.ts.un_540 mg.ss.ny_443 
  0x025d1c07, 0x62375fa9, 0x22023ea7, 0x2c6302a4,   // id.ss.da_432 tn.st.kha_544  rm.da.oc_532 da.sco.fy_433 
  0x46201bad, 0xfc005714, 0x5f373e0c, 0x552057a4,   // tr.sq.qu_643 na.zzp.un_660  rm.st.tn_543 na.sq.rw_433 
  0x064763a4, 0x38000e0d, 0x210952ee, 0x0f105704,   // sco.sn.de_433 is.tk.un_540  ha.pl.jw_422 na.lt.lv_332 
  // [17bf0]
  0x22500204, 0x0e003e12, 0x1008170d, 0x07051d0c,   // da.fj.oc_332 rm.is.un_640  sr.uk.be_554 la.fr.it_543 
  0x0413560c, 0x630652a4, 0x330c340c, 0x4713730c,   // mg.et.fi_543 ha.de.sco_433  xh.sv.nn_543 ny.et.sn_543 
  0x4036500c, 0x5c475e0c, 0x05631dad, 0x5d5226ec,   // fj.gn.lb_543 ts.sn.sa_543  la.sco.fr_643 ia.ha.ss_644 
  0x45420507, 0x065c02a9, 0x6e00510e, 0x4a6857ec,   // fr.co.ln_432 da.sa.de_544  kl.hmn.un_550 na.ig.yo_644 
  
  // [17c00]
  0x642f1cee, 0x1d3e0612, 0x4c006111, 0x263e1daf,   // id.su.lg_422 de.rm.la_654  za.wo.un_630 la.rm.ia_655 
  0x173c10ee, 0x12213daf, 0x452028a4, 0x05795007,   // be.ug.sr_422 ku.fa.ur_655  sw.sq.ln_433 fj.war.fr_432 
  0x072a1208, 0x64001f05, 0x40000107, 0x403e5108,   // hu.mt.it_443 cy.lg.un_330  en.lb.un_420 kl.rm.lb_443 
  0x1d0a51a4, 0x2e0e19ee, 0x040c31ac, 0x48071004,   // kl.pt.la_433 gl.is.fo_422  az.sv.fi_632 be.bg.tt_332 
  // [17c10]
  0x0a1704a6, 0x15112504, 0x237669a9, 0x45000522,   // ru.sr.mk_521 mn.ro.un_332  mfe.crs.ca_544 fr.ln.un_870 
  0x78000113, 0x045f2d07, 0x214210a9, 0x752453a4,   // en.ve.un_650 sk.tn.fi_432  lt.co.jw_544 ht.eo.nso_433 
  0x0351010b, 0x422150a4, 0x60130107, 0x016a58ee,   // en.kl.nl_542 fj.jw.co_433  en.et.vo_432 om.haw.en_422 
  0x0376540c, 0x3b1b61a4, 0x070942a4, 0x121e10a7,   // ik.crs.nl_543 za.tr.so_433  co.pl.it_433 lt.ms.hu_532 
  // [17c20]
  0x40065e11, 0x20306155, 0x071535a4, 0x46002412,   // ts.de.lb_653 za.uz.sq_442  tg.bg.un_430 eo.qu.un_640 
  0x796b6108, 0x6953010c, 0x36074207, 0x43192305,   // za.ceb.war_443 en.ht.mfe_543  co.it.gn_432 ca.gl.ie_333 
  0x1b023107, 0x06004808, 0x425f01a0, 0x350417a0,   // az.da.tr_432 tt.de.un_430  en.tn.co_322 sr.ru.tg_322 
  0x330849a4, 0x311b61a4, 0x1b303302, 0x4351100d,   // to.no.nn_433 za.tr.az_433  nn.uz.tr_222 lt.kl.ie_554 
  // [17c30]
  0x443823ec, 0x13001208, 0x2338350c, 0x20404c07,   // ky.tk.kk_644 hu.et.un_430  tg.tk.ky_543 wo.lb.sq_432 
  0x041008ec, 0x1510080b, 0x30482314, 0x2800611a,   // uk.be.ru_644 uk.be.un_542  ky.tt.uz_666 za.sw.un_760 
  0x040f02a0, 0x2b1c2109, 0x3d3c3ba6, 0x731b3108,   // da.lv.fi_322 jw.id.vi_444  ks.ug.ku_521 az.tr.ny_443 
  0x4a006112, 0x110468a0, 0x52684a0c, 0x13510455,   // za.yo.un_640 ig.fi.ro_322  yo.ig.ha_543 fi.kl.et_442 
  // [17c40]
  0x04006107, 0x2f29040c, 0x2d0d6105, 0x46004707,   // za.fi.un_420 fi.sl.su_543  za.cs.sk_333 sn.qu.un_420 
  0x3f002c0b, 0x3200020c, 0x04133402, 0x3400510d,   // fy.af.un_520 da.bs.un_530  xh.et.fi_222 kl.xh.un_540 
  0x381e1c0e, 0x021e1c08, 0x5a1351ee, 0x3bfe120c,   // id.ms.tk_555 id.ms.da_443  kl.et.sm_422 hu.tlh.so_543 
  0x262401a4, 0x063e69ee, 0x3d1812a4, 0x04000208,   // en.eo.ia_433 mfe.rm.de_422  ur.ar.ku_433 da.fi.un_430 
  // [17c50]
  0x751d010c, 0x07371702, 0x1b04fca4, 0x475c0408,   // en.la.nso_543 sr.ba.bg_222  zzp.fi.tr_433 fi.sa.sn_443 
  0x036306a9, 0x50002804, 0x5c0257a4, 0x041f4ca0,   // de.sco.nl_544 sw.fj.un_320  na.da.sa_433 wo.cy.fi_322 
  0x350a17ac, 0x797851a4, 0x511d01a0, 0x46045aee,   // sr.mk.tg_632 kl.ve.war_433  en.la.kl_322 sm.fi.qu_422 
  0x51003e09, 0x13514d08, 0x321704a4, 0x0e1f2ea4,   // rm.kl.un_440 aa.kl.et_443  fi.sr.bs_433 fo.cy.is_433 
  // [17c60]
  0x3e0c04a0, 0x2f002b07, 0x07001105, 0x46002a1a,   // fi.sv.rm_322 vi.su.un_420  ro.bg.un_330 mt.qu.un_760 
  0x01001902, 0x1d002b08, 0x21302305, 0x20005502,   // gl.en.un_220 vi.la.un_430  ky.uz.fa_333 rw.sq.un_220 
  0x291017a0, 0x2d0e2e07, 0x0d161755, 0x2e0b0ea0,   // sr.lt.sl_322 fo.is.sk_432  sr.hr.cs_442 is.es.fo_322 
  0x38005134, 0x1342640c, 0x651b79ee, 0x1b38545a,   // kl.tk.un_A80 lg.co.et_543  war.tr.gv_422 ik.tk.tr_553 
  // [17c70]
  0x0d002e0d, 0x213d3cee, 0x32000902, 0x24020ea4,   // fo.cs.un_540 ug.ku.fa_422  pl.bs.un_220 is.da.eo_433 
  0x3744230d, 0x542e0e08, 0x040736a9, 0x11002a0e,   // ky.kk.ba_554 is.fo.ik_443  ab.bg.ru_544 mt.ro.un_550 
  0x21004a02, 0x121828ee, 0x53001b04, 0x1d420755,   // yo.jw.un_220 sd.ar.ur_422  tr.ht.un_320 it.co.la_442 
  0x5a2701a0, 0x2d0e0a07, 0x391727ee, 0x5a00420d,   // en.gd.sm_322 pt.is.sk_432  gd.sr.br_422 co.sm.un_540 
  // [17c80]
  0x08235407, 0x18655aa7, 0x073943a7, 0x2847fcec,   // ik.ca.no_432 sm.gv.ga_532  ie.br.it_532 zzp.sn.sw_644 
  0x021b1c0c, 0x25001c13, 0x370213a7, 0x243913a0,   // id.tr.da_543 id.eu.un_650  et.da.st_532 et.br.eo_322 
  0x28474813, 0x2422230b, 0x03343fa4, 0x0c000504,   // tt.sn.sw_665 ca.oc.eo_542  af.xh.nl_433 fr.sv.un_320 
  0x3d1823a7, 0x221e1ca9, 0x1f004208, 0x36780107,   // ky.ar.ku_532 id.ms.oc_544  co.cy.un_430 en.ve.gn_432 
  // [17c90]
  0x33002807, 0x17153605, 0x3b2821a4, 0x16003212,   // sw.nn.un_420 ab.sr.un_330  fa.sd.ks_433 bs.hr.un_640 
  0x44481507, 0x3c233813, 0x2d1729af, 0x04371504,   // un.tt.kk_432 tk.ky.ug_665  sl.sr.sk_655 un.ba.ru_332 
  0x17083009, 0x345d3713, 0x1e6b1dad, 0x2d290da6,   // uz.uk.sr_444 st.ss.xh_665  la.ceb.ms_643 cs.sl.sk_521 
  0x04002a05, 0x0efe2ead, 0x060c0f55, 0x2d0d39a4,   // mt.fi.un_330 fo.tlh.is_643  lv.sv.de_442 br.cs.sk_433 
  // [17ca0]
  0x6b1c1d07, 0x1f2e0eaf, 0x2d3f0d0c, 0x1d651008,   // la.id.ceb_432 is.fo.cy_655  cs.af.sk_543 lt.gv.la_443 
  0x1a5e58a4, 0x1d354702, 0x190a4cee, 0x232d0d55,   // om.ts.tl_433 sn.zu.la_222  wo.pt.gl_422 cs.sk.ca_442 
  0x0600580e, 0x344a6807, 0x2e0c39a7, 0x042d1055,   // om.de.un_550 ig.yo.xh_432  br.sv.fo_532 lt.sk.fi_442 
  0x6e160da4, 0x10201f0c, 0x2d0d61af, 0x360b2208,   // cs.hr.hmn_433 cy.sq.lt_543  za.cs.sk_655 oc.es.gn_443 
  // [17cb0]
  0x523479a4, 0x591d02a4, 0x38000708, 0x3f2d0d60,   // war.xh.ha_433 da.la.rn_433  it.tk.un_430 cs.sk.af_664 
  0x0a2d0d13, 0x272265ad, 0x16005804, 0x232d0dec,   // cs.sk.pt_665 gv.oc.gd_643  om.hr.un_320 cs.sk.ca_644 
  0x4a1d6812, 0x13005814, 0x3f276aa4, 0x16091b08,   // ig.la.yo_654 om.et.un_660  haw.gd.af_433 tr.pl.hr_443 
  0x35615708, 0x022061a0, 0x375e5d04, 0x3e0742ec,   // na.za.zu_443 za.sq.da_322  ss.ts.st_332 co.it.rm_644 
  // [17cc0]
  0x481b2307, 0x69004c13, 0x44081008, 0x384837af,   // ca.tr.tt_432 wo.mfe.un_650  be.uk.kk_443 ba.tt.tk_655 
  0x5900550c, 0x20004802, 0x3800611a, 0x15100107,   // rw.rn.un_530 tt.sq.un_220  za.tk.un_760 en.lt.un_432 
  0x31150ca0, 0x5e007507, 0x33150c0c, 0xfc005d04,   // sv.az.un_320 nso.ts.un_420  sv.nn.un_530 ss.zzp.un_320 
  0x150601a4, 0x3515300c, 0x49604ba4, 0x43260112,   // en.de.un_433 uz.tg.un_530  mi.vo.to_433 en.ia.ie_654 
  // [17cd0]
  0x6063fea4, 0x01003b02, 0x6478130c, 0x1821345a,   // tlh.sco.vo_433 so.en.un_220  et.ve.lg_543 ps.fa.ar_553 
  0x46315407, 0x02394705, 0xfc002514, 0x12283b14,   // ik.az.qu_432 sn.br.da_333  eu.zzp.un_660 ks.sd.ur_666 
  0x016b39ee, 0x331d0613, 0x05230aee, 0x47096712,   // br.ceb.en_422 de.la.nn_665  pt.ca.fr_422 ak.pl.sn_654 
  0xfc130408, 0x2031480c, 0x292d100c, 0x0c003908,   // fi.et.zzp_443 tt.az.sq_543  lt.sk.sl_543 br.sv.un_430 
  // [17ce0]
  0x11180107, 0x08021dee, 0x58545112, 0x58643e07,   // en.ga.ro_432 la.da.no_422  kl.ik.om_654 rm.lg.om_432 
  0x09285302, 0x22201bee, 0x1d490107, 0x3534250c,   // ht.sw.pl_222 tr.sq.oc_422  en.to.la_432 eu.xh.zu_543 
  0x1b5efeaf, 0x19235e11, 0x0a000208, 0x51420709,   // tlh.ts.tr_655 ts.ca.gl_653  da.pt.un_430 it.co.kl_444 
  0x5e4b47a4, 0x51391ca0, 0x132360a4, 0x6a5101a4,   // sn.mi.ts_433 id.br.kl_322  vo.ca.et_433 en.kl.haw_433 
  // [17cf0]
  0x39005e19, 0x440448a4, 0x11fe010b, 0x55134f08,   // ts.br.un_750 tt.ru.kk_433  en.tlh.ro_542 bi.et.rw_443 
  0xfe00010d, 0x32101712, 0x32172907, 0x125c4602,   // en.tlh.un_540 sr.lt.bs_654  sl.sr.bs_432 qu.sa.hu_222 
  0x08173507, 0x5d4a1208, 0x160d1707, 0x281218af,   // tg.sr.uk_432 hu.yo.ss_443  sr.cs.hr_432 ar.ur.sd_655 
  0x46003b0d, 0x25233cec, 0x5a494ba0, 0x011863a4,   // so.qu.un_540 ug.ky.mn_644  mi.to.sm_322 sco.ga.en_433 
  // [17d00]
  0x21fe20ec, 0x13240f04, 0x21791d07, 0x0a2d39ee,   // sq.tlh.jw_644 lv.eo.et_332  la.war.jw_432 br.sk.pt_422 
  0x55645308, 0x51000804, 0x100807ad, 0x39004c1a,   // ht.lg.rw_443 no.kl.un_320  bg.uk.be_643 wo.br.un_760 
  0x0f1324ee, 0x5c1c09ac, 0x4c2d39a0, 0x046a5107,   // eo.et.lv_422 hi.mr.sa_632  br.sk.wo_322 kl.haw.fi_432 
  0x3e0a2d0c, 0x530522a4, 0x2d2739ee, 0x05532255,   // sk.pt.rm_543 oc.fr.ht_433  br.gd.sk_422 oc.ht.fr_442 
  // [17d10]
  0x190a2dec, 0x592613af, 0x2d00390d, 0x786a4b13,   // sk.pt.gl_644 et.ia.rn_655  br.sk.un_540 mi.haw.ve_665 
  0x0a510d0c, 0x330854af, 0x0f004009, 0x23402255,   // cs.kl.pt_543 ik.no.nn_655  lb.lv.un_440 oc.lb.ca_442 
  0x04053608, 0x182d39ec, 0x5a4901a9, 0x56275a0c,   // gn.fr.fi_443 br.sk.ga_644  en.to.sm_544 sm.gd.mg_543 
  0x073801a4, 0x2f0512a4, 0x190a2dee, 0x04565aa9,   // en.tk.it_433 hu.fr.su_433  sk.pt.gl_422 sm.mg.fi_544 
  // [17d20]
  0x084436a0, 0x18270408, 0x4b6a04a7, 0x47050107,   // ab.kk.uk_322 fi.gd.ga_443  fi.haw.mi_532 en.fr.sn_432 
  0x530b0a04, 0x18565a12, 0x01fc5a0c, 0x0a052355,   // pt.es.ht_332 sm.mg.ga_654  sm.zzp.en_543 ca.fr.pt_442 
  0xfe005607, 0x122334a9, 0x201b3812, 0x05381b5a,   // mg.tlh.un_420 ps.ky.ur_544  tk.tr.sq_654 tr.tk.fr_553 
  0x5a296a0c, 0x25002808, 0x241104ee, 0x04184fa9,   // haw.sl.sm_543 sw.eu.un_430  fi.ro.eo_422 bi.ga.fi_544 
  // [17d30]
  0x36190a0d, 0x0e4836a4, 0x16001c08, 0x0d5c09ec,   // pt.gl.gn_554 gn.tt.is_433  id.hr.un_430 hi.sa.ne_644 
  0x02632ea0, 0x12050fee, 0x11151d55, 0x1d004321,   // fo.sco.da_322 lv.fr.hu_422  la.ro.un_420 ie.la.un_860 
  0x11431704, 0x09155e02, 0x4a005d0d, 0x11186307,   // sr.ie.ro_332 ts.pl.un_220  ss.yo.un_540 sco.ga.ro_432 
  0x2500fc08, 0x1a5559ad, 0x19005d04, 0x06001d07,   // zzp.eu.un_430 rn.rw.tl_643  ss.gl.un_320 la.de.un_420 
  // [17d40]
  0x36180b0c, 0x28343bee, 0x644a67ee, 0x151536ad,   // es.ga.gn_543 ks.ps.sd_422  ak.yo.lg_422 ab.un.un_630 
  0x36000b02, 0x28006708, 0x2e002305, 0x07006405,   // es.gn.un_220 ak.sw.un_430  ca.fo.un_330 lg.it.un_330 
  0x29152da0, 0x3e002908, 0x100a38a4, 0x1d003414,   // sk.sl.un_320 sl.rm.un_430  tk.mk.be_433 xh.la.un_660 
  0x23192508, 0x59555605, 0x0b361912, 0x34007302,   // eu.gl.ca_443 mg.rw.rn_333  gl.gn.es_654 ny.xh.un_220 
  // [17d50]
  0x2000610c, 0x4d7367ad, 0x375702af, 0x5a0640a0,   // za.sq.un_530 ak.ny.aa_643  da.na.st_655 lb.de.sm_322 
  0x125010ee, 0x790e2ea4, 0x152e0e07, 0x33510ea7,   // lt.fj.hu_422 fo.is.war_433  is.fo.un_432 is.kl.nn_532 
  0x0810230b, 0x08222310, 0x09000705, 0x065e4011,   // ky.be.uk_542 ca.oc.no_642  it.pl.un_330 lb.ts.de_653 
  0x0200370e, 0x190d22a0, 0x0c0460a0, 0x12313ba9,   // st.da.un_550 oc.cs.gl_322  vo.fi.sv_322 so.az.hu_544 
  // [17d60]
  0x2d0d690e, 0x475228a4, 0x647328a9, 0x505d3504,   // mfe.cs.sk_555 sw.ha.sn_433  sw.ny.lg_544 zu.ss.fj_332 
  0x13400ca7, 0x0c1f2ea4, 0x35250aa6, 0x1d212f0c,   // sv.lb.et_532 fo.cy.sv_433  mk.mn.tg_521 su.jw.la_543 
  0x4d3b5212, 0x2a330cee, 0x330e0805, 0x062502ad,   // ha.so.aa_654 sv.nn.mt_422  no.is.nn_333 da.eu.de_643 
  0x1b4f30a7, 0x5d3335a0, 0x10595508, 0x52104ca4,   // uz.bi.tr_532 zu.nn.ss_322  rw.rn.lt_443 wo.lt.ha_433 
  // [17d70]
  0x31464e0c, 0x395e5011, 0x214c6713, 0x06005308,   // ay.qu.az_543 fj.ts.br_653  ak.wo.jw_665 ht.de.un_430 
  0x37003502, 0xfc061509, 0x33120d0b, 0x1c2a0d02,   // tg.ba.un_220 un.de.zzp_444  cs.hu.nn_542 cs.mt.id_222 
  0x2d060d11, 0x302536ad, 0x4a0e2e08, 0x0e004a0c,   // cs.de.sk_653 ab.mn.uz_643  fo.is.yo_443 yo.is.un_530 
  0x1a5f7907, 0x07003904, 0x40060404, 0x25073908,   // war.tn.tl_432 br.it.un_320  fi.de.lb_332 br.it.eu_443 
  // [17d80]
  0x1827020c, 0x10730908, 0x30113c11, 0x3900070d,   // da.gd.ga_543 pl.ny.lt_443  ug.ro.uz_653 it.br.un_540 
  0x25074213, 0x1a003f09, 0x27002004, 0x380e42a7,   // co.it.eu_665 af.tl.un_440  sq.gd.un_320 co.is.tk_532 
  0x373644af, 0x1510085a, 0x34005d08, 0x535605a7,   // kk.ab.ba_655 uk.be.un_553  ss.xh.un_430 fr.mg.ht_532 
  0x02000518, 0x42390707, 0x0d000e08, 0x38006013,   // fr.da.un_740 it.br.co_432  is.cs.un_430 vo.tk.un_650 
  // [17d90]
  0x1c003508, 0x58463455, 0x39092205, 0x0215fc04,   // zu.id.un_430 xh.qu.om_442  oc.pl.br_333 zzp.da.un_320 
  0x29321613, 0x06080c07, 0x4804130c, 0x283d3407,   // hr.bs.sl_665 sv.no.de_432  et.fi.tt_543 ps.ku.sd_432 
  0x23253813, 0x31302a07, 0x2a005118, 0x0c1c5707,   // tk.mn.ky_665 mt.uz.az_432  kl.mt.un_740 na.id.sv_432 
  0x12183409, 0x0d122da4, 0x08060ca4, 0x37480407,   // ps.ar.ur_444 sk.hu.cs_433  sv.de.no_433 ru.tt.ba_432 
  // [17da0]
  0x04441007, 0x48005d05, 0x2d002319, 0x1e002804,   // be.kk.ru_432 ss.tt.un_330  ca.sk.un_750 sw.ms.un_320 
  0x1e7315a0, 0x1e290fee, 0x0800332b, 0x393f0aad,   // un.ny.ms_322 lv.sl.ms_422  nn.no.un_980 pt.af.br_643 
  0x2b0a5d04, 0x01004b04, 0x3f000a14, 0x182e0e05,   // ss.pt.vi_332 mi.en.un_320  pt.af.un_660 is.fo.ga_333 
  0x21670102, 0x13564cee, 0x0f10fca4, 0x2100020b,   // en.ak.jw_222 wo.mg.et_422  zzp.lt.lv_433 da.jw.un_520 
  // [17db0]
  0x250a35a0, 0x153038a4, 0x2d4a2e07, 0x1c2f26a0,   // tg.mk.mn_322 tk.uz.un_433  fo.yo.sk_432 ia.su.id_322 
  0x392a5207, 0x2b2d15a0, 0x2e0e0c14, 0x0d00020e,   // ha.mt.br_432 un.sk.vi_322  sv.is.fo_666 da.cs.un_550 
  0x300e33a4, 0x0e300c0d, 0x3f000219, 0x275c180d,   // nn.is.uz_433 sv.uz.is_554  da.af.un_750 ga.sa.gd_554 
  0x2315fca7, 0x2e0e010c, 0x0c5c30a6, 0x5c1c13ac,   // zzp.ca.un_520 en.is.fo_543  uz.sa.sv_521 bh.mr.sa_632 
  // [17dc0]
  0x29020c08, 0x02033ba0, 0x556825ad, 0x75375fec,   // sv.da.sl_443 so.nl.da_322  eu.ig.rw_643 tn.st.nso_644 
  0x30000e1a, 0x060e1f0c, 0x28645d04, 0x070411ac,   // is.uz.un_760 cy.is.de_543  ss.lg.sw_332 ro.ru.bg_632 
  0x4d56010c, 0x02003008, 0x0a3044ee, 0x49fe3708,   // en.mg.aa_543 uz.da.un_430  kk.uz.mk_422 st.tlh.to_443 
  0x345537a7, 0x47556407, 0x2f306004, 0x532c2804,   // st.rw.xh_532 lg.rw.sn_432  vo.uz.su_332 sw.fy.ht_332 
  // [17dd0]
  0x2146fcee, 0x5f6b1dee, 0xfc554708, 0xfc572512,   // zzp.qu.jw_422 la.ceb.tn_422  sn.rw.zzp_443 eu.na.zzp_654 
  0x556459a9, 0x55fc5d13, 0x686546a7, 0x515a5408,   // rn.lg.rw_544 ss.zzp.rw_665  qu.gv.ig_532 ik.sm.kl_443 
  0x42515455, 0x07001d13, 0x6a5625a4, 0x1e3750ad,   // ik.kl.co_442 la.it.un_650  eu.mg.haw_433 fj.st.ms_643 
  0x3f001e08, 0x2e30010c, 0x16605911, 0x06472407,   // ms.af.un_430 en.uz.fo_543  rn.vo.hr_653 eo.sn.de_432 
  // [17de0]
  0x29000c08, 0x185a3713, 0x59553409, 0x543046ec,   // sv.sl.un_430 st.sm.ga_665  xh.rw.rn_444 qu.uz.ik_644 
  0x2800301b, 0x06795604, 0x28005509, 0x1f274209,   // uz.sw.un_770 mg.war.de_332  rw.sw.un_440 co.gd.cy_444 
  0x37302c05, 0x6759550e, 0x082a4507, 0x203f03a0,   // fy.uz.st_333 rw.rn.ak_555  ln.mt.no_432 nl.af.sq_322 
  0x65400804, 0x68634055, 0x5557590d, 0x3b6b7912,   // no.lb.gv_332 lb.sco.ig_442  rn.na.rw_554 war.ceb.so_654 
  // [17df0]
  0x32001b13, 0x43264ca4, 0x4033080d, 0x330865ee,   // tr.bs.un_650 wo.ia.ie_433  no.nn.lb_554 gv.no.nn_422 
  0x0a002514, 0x5c005e12, 0x3f2a1d55, 0x312519a7,   // eu.pt.un_660 ts.sa.un_640  la.mt.af_442 gl.eu.az_532 
  0x2f4c4ba4, 0x10005105, 0x65063908, 0x5f372a13,   // mi.wo.su_433 kl.lt.un_330  br.de.gv_443 mt.st.tn_665 
  0x5c6201a0, 0x7325600c, 0x655154ee, 0x2e3308ad,   // en.kha.sa_322 vo.eu.ny_543  ik.kl.gv_422 no.nn.fo_643 
  // [17e00]
  0x3b4c13a9, 0x10516bad, 0x78005e23, 0x5f005e0d,   // et.wo.so_544 ceb.kl.lt_643  ts.ve.un_880 ts.tn.un_540 
  0x285c56ec, 0x2344300c, 0x2b005813, 0x052a55ee,   // mg.sa.sw_644 uz.kk.ky_543  om.vi.un_650 rw.mt.fr_422 
  0x0955590c, 0x220b0a05, 0x37230a07, 0x0a2d18a0,   // rn.rw.pl_543 pt.es.oc_333  mk.ky.ba_432 ga.sk.pt_322 
  0x250407a0, 0x2d000a09, 0x0800170b, 0x48100407,   // bg.ru.mn_322 pt.sk.un_440  sr.uk.un_520 ru.be.tt_432 
  // [17e10]
  0x353723a4, 0xfc321605, 0x390c0302, 0x192301a4,   // ky.ba.tg_433 hr.bs.zzp_333  nl.sv.br_222 en.ca.gl_433 
  0x4d4c310c, 0x37650309, 0x13001f08, 0x30134d0c,   // az.wo.aa_543 nl.gv.st_444  cy.et.un_430 aa.et.uz_543 
  0x4c132912, 0x693b13a4, 0x03280c02, 0x794c1313,   // sl.et.wo_654 et.so.mfe_433  sv.sw.nl_222 et.wo.war_665 
  0x4c000212, 0x654c130e, 0x2e0e4708, 0x3b006107,   // da.wo.un_640 et.wo.gv_555  sn.is.fo_443 za.so.un_420 
  // [17e20]
  0x39534555, 0x21314c11, 0x4c006e1b, 0x6e4c13a4,   // ln.ht.br_442 wo.az.jw_653  hmn.wo.un_770 et.wo.hmn_433 
  0x05000308, 0x313b4ca9, 0x653f0307, 0x151d13a0,   // nl.fr.un_430 wo.so.az_544  nl.af.gv_432 et.la.un_322 
  0x314dfea7, 0x4d5a510c, 0x3f003921, 0x533f0d07,   // tlh.aa.az_532 kl.sm.aa_543  br.af.un_860 cs.af.ht_432 
  0x18002f0e, 0x5a033fa4, 0x1a4a68ad, 0x4c001808,   // su.ga.un_550 af.nl.sm_433  ig.yo.tl_643 ga.wo.un_430 
  // [17e30]
  0x0e003602, 0x3b785812, 0x53055b55, 0x043b4d0c,   // gn.is.un_220 om.ve.so_654  sg.fr.ht_442 aa.so.fi_543 
  0x64285807, 0x350d40a0, 0x58643b0c, 0x4d5811a4,   // om.sw.lg_432 lb.cs.zu_322  so.lg.om_543 ro.om.aa_433 
  0x052202a7, 0x4d5a51ec, 0x22210502, 0x584d64ec,   // da.oc.fr_532 kl.sm.aa_644  fr.jw.oc_222 lg.aa.om_644 
  0x113b4d07, 0x033f680c, 0x13000f04, 0x2d0d1308,   // aa.so.ro_432 ig.af.nl_543  lv.et.un_320 et.cs.sk_443 
  // [17e40]
  0x64003413, 0x4d543baf, 0x584c3b0d, 0x13510404,   // xh.lg.un_650 so.ik.aa_655  so.wo.om_554 fi.kl.et_332 
  0x2d0e2e09, 0x2f180504, 0x404505a0, 0x5a511305,   // fo.is.sk_444 fr.ga.su_332  fr.ln.lb_322 et.kl.sm_333 
  0x043608ac, 0x17110708, 0x071108af, 0x5c003908,   // uk.ab.ru_632 bg.ro.sr_443  uk.ro.bg_655 br.sa.un_430 
  0x04080202, 0x0b001507, 0x2b00110c, 0x465750a4,   // da.no.fi_222 un.es.un_420  ro.vi.un_530 fj.na.qu_433 
  // [17e50]
  0x5c000402, 0x64004c05, 0x78004514, 0x211e1c0b,   // fi.sa.un_220 wo.lg.un_330  ln.ve.un_660 id.ms.jw_542 
  0x25004d13, 0x56002904, 0x2f454fad, 0x3d12210b,   // aa.eu.un_650 sl.mg.un_320  bi.ln.su_643 fa.ur.ku_542 
  0x69601ca0, 0x160f38ac, 0x2f251302, 0x51254d0e,   // id.vo.mfe_322 tk.lv.hr_632  et.eu.su_222 aa.eu.kl_555 
  0x1d000d07, 0x48004d12, 0x5d004d07, 0x40251bee,   // cs.la.un_420 aa.tt.un_640  aa.ss.un_420 tr.eu.lb_422 
  // [17e60]
  0x2a002509, 0x1c5154ee, 0x1628185a, 0x69765109,   // eu.mt.un_440 ik.kl.id_422  ar.sd.th_553 kl.crs.mfe_444 
  0x1b2176ee, 0x10081709, 0x4d2d0d60, 0x0146fca6,   // crs.jw.tr_422 sr.uk.be_444  cs.sk.aa_664 zzp.qu.en_521 
  0x11001719, 0x0e007904, 0x30003905, 0x025c2e02,   // sr.ro.un_750 war.is.un_320  br.uz.un_330 fo.sa.da_222 
  0x21583b04, 0x1f002b0c, 0xfc033f0b, 0x3f08560c,   // so.om.jw_332 vi.cy.un_530  af.nl.zzp_542 mg.no.af_543 
  // [17e70]
  0x3d301805, 0x3076370c, 0x135f370d, 0x5d5f3713,   // ar.uz.ku_333 st.crs.uz_543  st.tn.et_554 st.tn.ss_665 
  0x182724a7, 0x13044809, 0x2c57560d, 0x3f005c04,   // eo.gd.ga_532 tt.fi.et_444  mg.na.fy_554 sa.af.un_320 
  0x57132daf, 0x565f3e08, 0x032e0e12, 0x21790504,   // sk.et.na_655 rm.tn.mg_443  is.fo.nl_654 fr.war.jw_332 
  0x02472812, 0x43005718, 0x02153105, 0x3c303804,   // sw.sn.da_654 na.ie.un_740  az.da.un_330 tk.uz.ug_332 
  // [17e80]
  0x305d470d, 0x1d1d0608, 0x11000a04, 0x13023ea9,   // sn.ss.uz_554 de.la.la_443  pt.ro.un_320 rm.da.et_544 
  0x50232f0c, 0x6b791a07, 0x23183d09, 0x1d6527ad,   // su.ca.fj_543 tl.war.ceb_432  ku.ar.ky_444 gd.gv.la_643 
  0x585337a0, 0x065727ec, 0x5602120c, 0x04136011,   // st.ht.om_322 gd.na.de_644  hu.da.mg_543 vo.et.fi_653 
  0x47002b07, 0x041360ec, 0x1ffc7307, 0x102338af,   // vi.sn.un_420 vo.et.fi_644  ny.zzp.cy_432 tk.ky.be_655 
  // [17e90]
  0xfc650102, 0x3f001f0e, 0x0a041560, 0x2a293907,   // en.gv.zzp_222 cy.af.un_550  un.ru.mk_664 br.sl.mt_432 
  0x3412300b, 0x39462105, 0x0e6558af, 0x21002309,   // uz.ur.ps_542 jw.qu.br_333  om.gv.is_655 ky.fa.un_440 
  0x033f5808, 0x3f4c0c0b, 0x65003b1b, 0x654c6307,   // om.af.nl_443 sv.wo.af_542  so.gv.un_770 sco.wo.gv_432 
  0x53790707, 0x02005313, 0x1b004c04, 0x47003507,   // it.war.ht_432 ht.da.un_650  wo.tr.un_320 zu.sn.un_420 
  // [17ea0]
  0x18530560, 0x79420704, 0x53394ca9, 0x23003b0c,   // fr.ht.ga_664 it.co.war_332  wo.br.ht_544 ks.ky.un_530 
  0x15024ca4, 0x2d001214, 0x271847ee, 0x790a6ba4,   // wo.da.un_433 hu.sk.un_660  sn.ga.gd_422 ceb.pt.war_433 
  0x355e5d0c, 0x123d21a7, 0x46791fa4, 0x20003b08,   // ss.ts.zu_543 fa.ku.ur_532  cy.war.qu_433 so.sq.un_430 
  0x2c270407, 0x5c5d4e08, 0x47275c08, 0x36003819,   // fi.gd.fy_432 ay.ss.sa_443  sa.gd.sn_443 tk.ab.un_750 
  // [17eb0]
  0x0c1308a4, 0x2700010d, 0x23440aa4, 0x56003b19,   // no.et.sv_433 en.gd.un_540  mk.kk.ky_433 so.mg.un_750 
  0x18005c08, 0x4746010c, 0x24002005, 0x3e42230c,   // sa.ga.un_430 en.qu.sn_543  sq.eo.un_330 ca.co.rm_543 
  0x42000520, 0x5c007907, 0x080260a4, 0x3e450507,   // fr.co.un_850 war.sa.un_420  vo.da.no_433 fr.ln.rm_432 
  0x041038ee, 0x20004721, 0x3e000c08, 0x475e78ad,   // tk.be.ru_422 sn.sq.un_860  sv.rm.un_430 ve.ts.sn_643 
  // [17ec0]
  0x225b0207, 0xfc1a540d, 0x230105a4, 0x02000313,   // da.sg.oc_432 ik.tl.zzp_554  fr.en.ca_433 nl.da.un_650 
  0x65050ea6, 0x18053807, 0x06005e0c, 0x34001604,   // is.fr.gv_521 tk.fr.ga_432  ts.de.un_530 hr.xh.un_320 
  0x5955010c, 0x50040304, 0x04006a13, 0x044002a4,   // en.rw.rn_543 nl.fi.fj_332  haw.fi.un_650 da.lb.fi_433 
  0x28736a0c, 0x3e1d3b0c, 0x543435a4, 0x0c2e3305,   // haw.ny.sw_543 so.la.rm_543  zu.xh.ik_433 nn.fo.sv_333 
  // [17ed0]
  0x03570208, 0xfc060c04, 0x0c0304ac, 0x03026304,   // da.na.nl_443 sv.de.zzp_332  fi.nl.sv_632 sco.da.nl_332 
  0x24381b07, 0x13476407, 0x610a5208, 0x39633007,   // tr.tk.eo_432 lg.sn.et_432  ha.pt.za_443 uz.sco.br_432 
  0x503f0307, 0x0c3e08a4, 0x2c6502a4, 0x3f0350af,   // nl.af.fj_432 no.rm.sv_433  da.gv.fy_433 fj.nl.af_655 
  0x2f5c21a6, 0xfe0a19ec, 0x1b312307, 0x17044407,   // jw.sa.su_521 gl.pt.tlh_644  ca.az.tr_432 kk.ru.sr_432 
  // [17ee0]
  0x51002504, 0x09002205, 0x1000020e, 0x5a004707,   // eu.kl.un_320 oc.pl.un_330  da.lt.un_550 sn.sm.un_420 
  0x351023a4, 0x34303ba9, 0x15003e0c, 0x150201a4,   // ky.be.tg_433 ks.uz.ps_544  rm.un.un_530 en.da.un_433 
  0x0e3e1812, 0x03040204, 0x043f030c, 0x0f001020,   // ga.rm.is_654 da.fi.nl_332  nl.af.fi_543 lt.lv.un_850 
  0x593130a4, 0x1d3879ee, 0x6500400c, 0x0a2311ee,   // uz.az.rn_433 war.tk.la_422  lb.gv.un_530 ro.ky.mk_422 
  // [17ef0]
  0x37113cad, 0x1000152b, 0x104437ee, 0x23001013,   // ug.ro.ba_643 un.be.un_980  ba.kk.be_422 be.ky.un_650 
  0x51000214, 0x130d5ca0, 0x2c00610d, 0x30113c14,   // da.kl.un_660 sa.ne.bh_322  za.fy.un_540 ug.ro.uz_666 
  0x1b034d05, 0x1c2f6107, 0x5e003504, 0x0f004202,   // aa.nl.tr_333 za.su.id_432  zu.ts.un_320 co.lv.un_220 
  0x79026455, 0x1d4243a0, 0x51002507, 0xfc352109,   // lg.da.war_442 ie.co.la_322  eu.kl.un_420 jw.zu.zzp_444 
  // [17f00]
  0x214728ec, 0x1d000209, 0x5d3035a0, 0x55536407,   // sw.sn.jw_644 da.la.un_440  zu.uz.ss_322 lg.ht.rw_432 
  0x041360a6, 0x2f204a0d, 0x622c65a4, 0x5c2769ad,   // vo.et.fi_521 yo.sq.su_554  gv.fy.kha_433 mfe.gd.sa_643 
  0x204d25af, 0x2e656212, 0x2e0e0812, 0x30483813,   // eu.aa.sq_655 kha.gv.fo_654  no.is.fo_654 tk.tt.uz_665 
  0x792e6204, 0x3e002e08, 0x2e0401a4, 0x01024b04,   // kha.fo.war_332 fo.rm.un_430  en.fi.fo_433 mi.da.en_332 
  // [17f10]
  0x3d18345a, 0x30315ea4, 0x5c1d3ea0, 0x5625100c,   // ps.ar.ku_553 ts.az.uz_433  rm.la.sa_322 lt.eu.mg_543 
  0x04004613, 0x7359280b, 0x5800490e, 0x354b31ec,   // qu.fi.un_650 sw.rn.ny_542  to.om.un_550 az.mi.zu_644 
  0x2e0c3e13, 0x063820ee, 0x30382507, 0x38651f04,   // rm.sv.fo_665 sq.tk.de_422  eu.tk.uz_432 cy.gv.tk_332 
  0x6b1a7905, 0x1e224a08, 0x02650107, 0x282a180d,   // war.tl.ceb_333 yo.oc.ms_443  en.gv.da_432 ga.mt.sw_554 
  // [17f20]
  0x4a00fe08, 0x021d2e0d, 0x481b6907, 0x2e001604,   // tlh.yo.un_430 fo.la.da_554  mfe.tr.tt_432 hr.fo.un_320 
  0x20125a05, 0x5e353b12, 0x10000d0c, 0x013f1fa0,   // sm.hu.sq_333 so.zu.ts_654  cs.lt.un_530 cy.af.en_322 
  0x29161b07, 0x65044e0c, 0x780262af, 0x510e10ad,   // tr.hr.sl_432 ay.fi.gv_543  kha.da.ve_655 lt.is.kl_643 
  0x01032ea9, 0x4600080d, 0x01321704, 0x1b005e04,   // fo.nl.en_544 no.qu.un_540  sr.bs.en_332 ts.tr.un_320 
  // [17f30]
  0x495060a4, 0x5a4b49a4, 0x064048a6, 0x30003535,   // vo.fj.to_433 to.mi.sm_433  tt.lb.de_521 tg.uz.un_A90 
  0x13063807, 0x13000612, 0x1d000213, 0x3c23300c,   // tk.de.et_432 de.et.un_640  da.la.un_650 uz.ky.ug_543 
  0x3f00fe08, 0x2d000c04, 0x0b005b10, 0x06151ba6,   // tlh.af.un_430 sv.sk.un_320  sg.es.un_620 tr.de.un_510 
  0x231844ac, 0x3e0412a7, 0x2e0c08a0, 0x03450507,   // kk.ar.ky_632 hu.fi.rm_532  no.sv.fo_322 fr.ln.nl_432 
  // [17f40]
  0xfe002f04, 0x331d3704, 0x182b13a0, 0x371320ec,   // su.tlh.un_320 st.la.nn_332  et.vi.ga_322 sq.et.st_644 
  0x0c1a3707, 0x08370607, 0x37001a05, 0x49003905,   // st.tl.sv_432 de.st.no_432  tl.st.un_330 br.to.un_330 
  0x25483713, 0x12006b19, 0x0d171002, 0x0105fc0c,   // ba.tt.mn_665 ceb.hu.un_750  lt.sr.cs_222 zzp.fr.en_543 
  0x0810150c, 0x47090207, 0x4b004807, 0x211237a0,   // un.be.uk_543 da.pl.sn_432  tt.mi.un_420 st.hu.jw_322 
  // [17f50]
  0x3900490d, 0x1d372a05, 0x1c212f0c, 0x2a00370c,   // to.br.un_540 mt.st.la_333  su.jw.id_543 st.mt.un_530 
  0x13001d02, 0x2a006513, 0x09005508, 0x467679af,   // la.et.un_220 gv.mt.un_650  rw.pl.un_430 war.crs.qu_655 
  0x653f6302, 0x0d49fca7, 0x370448a7, 0x21443411,   // sco.af.gv_222 zzp.to.cs_532  tt.ru.ba_532 ps.kk.fa_653 
  0x40063807, 0x381f6307, 0x1008480c, 0x1e000704,   // tk.de.lb_432 sco.cy.tk_432  tt.uk.be_543 it.ms.un_320 
  // [17f60]
  0x21002b08, 0x332e025a, 0x100d2d0b, 0x0f291605,   // vi.jw.un_430 da.fo.nn_553  sk.cs.lt_542 hr.sl.lv_333 
  0x13004207, 0x120b2d0c, 0x23220aa0, 0x51003605,   // co.et.un_420 sk.es.hu_543  pt.oc.ca_322 gn.kl.un_330 
  0x2118280b, 0x43262a0d, 0x150410ee, 0x48002205,   // sd.ar.fa_542 mt.ia.ie_554  be.ru.un_422 oc.tt.un_330 
  0x0b000402, 0x43190b08, 0x15003c0e, 0x09000611,   // fi.es.un_220 es.gl.ie_443  ug.un.un_550 de.pl.un_630 
  // [17f70]
  0x512e02a9, 0x04423908, 0x2f1a0702, 0x47004b21,   // da.fo.kl_544 br.co.fi_443  it.tl.su_222 mi.sn.un_860 
  0x2f006107, 0x0f59550d, 0x46212a07, 0x4b595513,   // za.su.un_420 rw.rn.lv_554  mt.jw.qu_432 rw.rn.mi_665 
  0x2f531a08, 0xfe4e7804, 0x69001e04, 0x47521d55,   // tl.ht.su_443 ve.ay.tlh_332  ms.mfe.un_320 la.ha.sn_442 
  0x525955ad, 0x16001e04, 0x4c004d0e, 0x17000902,   // rw.rn.ha_643 ms.hr.un_320  aa.wo.un_550 pl.sr.un_220 
  // [17f80]
  0x07132504, 0x33021502, 0x11003b04, 0x03094907,   // eu.et.it_332 un.da.nn_222  so.ro.un_320 to.pl.nl_432 
  0x4d003b08, 0x20282507, 0x40064d0d, 0x5e001104,   // so.aa.un_430 eu.sw.sq_432  aa.de.lb_554 ro.ts.un_320 
  0x092d290c, 0x10483860, 0x1a004208, 0x211c690e,   // sl.sk.pl_543 tk.tt.be_664  co.tl.un_430 mfe.id.jw_555 
  0x37444809, 0x48314da4, 0x0100150c, 0x07330805,   // tt.kk.ba_444 aa.az.tt_433  un.en.un_530 no.nn.it_333 
  // [17f90]
  0x21005219, 0x4b2a100c, 0x0d16290c, 0x120901a0,   // ha.jw.un_750 lt.mt.mi_543  sl.hr.cs_543 en.pl.hu_322 
  0x15003307, 0x36004a05, 0x25044802, 0x150708a0,   // nn.un.un_420 yo.gn.un_330  tt.ru.mn_222 uk.bg.un_322 
  0x27003304, 0x0e120d07, 0x2e1d0207, 0x3044230d,   // nn.gd.un_320 cs.hu.is_432  da.la.fo_432 ky.kk.uz_554 
  0x480a30a0, 0x3e004b0b, 0x2d0d18a4, 0x394a1cee,   // uz.mk.tt_322 mi.rm.un_520  ga.cs.sk_433 id.yo.br_422 
  // [17fa0]
  0x2e021da6, 0x21004a12, 0x2d583904, 0x5c52580c,   // la.da.fo_521 yo.jw.un_640  br.om.sk_332 om.ha.sa_543 
  0x53001104, 0x1d510212, 0x332d1307, 0x21002f19,   // ro.ht.un_320 da.kl.la_654  et.sk.nn_432 su.jw.un_750 
  0x1f002a04, 0x5d000212, 0x46000d04, 0x292e330c,   // mt.cy.un_320 da.ss.un_640  cs.qu.un_320 nn.fo.sl_543 
  0x5d29330c, 0x043715a9, 0x5d212f07, 0x103b540c,   // nn.sl.ss_543 un.ba.ru_544  su.jw.ss_432 ik.so.lt_543 
  // [17fb0]
  0x04111705, 0x250f33ee, 0x4a2f4c0c, 0x21515ca9,   // sr.ro.ru_333 nn.lv.eu_422  wo.su.yo_543 sa.kl.jw_544 
  0x583f2cad, 0x5c52600d, 0x3435590d, 0x5d5647a9,   // fy.af.om_643 vo.ha.sa_554  rn.zu.xh_554 sn.mg.ss_544 
  0x11542e0c, 0x52343507, 0x58516b0c, 0x3f030ca4,   // fo.ik.ro_543 zu.xh.ha_432  ceb.kl.om_543 sv.nl.af_433 
  0x465559ec, 0x59795c0c, 0x2c000b02, 0x104d390c,   // rn.rw.qu_644 sa.war.rn_543  es.fy.un_220 br.aa.lt_543 
  // [17fc0]
  0x081536a0, 0x5e062ca0, 0x0e475508, 0x38561ea0,   // ab.uk.un_320 fy.de.ts_322  rw.sn.is_443 ms.mg.tk_322 
  0x061e1c05, 0x315815a4, 0x110501a9, 0x4e003304,   // id.ms.de_333 un.om.az_433  en.fr.ro_544 nn.ay.un_320 
  0x2f655a04, 0x4e211fa9, 0x5d59550d, 0x1a464eec,   // sm.gv.su_332 cy.jw.ay_544  rw.rn.ss_554 ay.qu.tl_644 
  0x35595509, 0x34464e0c, 0x304602a4, 0x573ffc08,   // rw.rn.zu_444 ay.qu.xh_543  da.qu.uz_433 zzp.af.na_443 
  // [17fd0]
  0xfa405e08, 0x42555e0c, 0x2834300d, 0x02001d09,   // ts.lb.nr_443 ts.rw.co_543  uz.ps.sd_554 la.da.un_440 
  0x11200107, 0x3000150e, 0x022e470c, 0x20304607,   // en.sq.ro_432 un.uz.un_550  sn.fo.da_543 qu.uz.sq_432 
  0x3034210e, 0x12360a0d, 0x123d3c07, 0x53006913,   // fa.ps.uz_555 pt.gn.hu_554  ug.ku.ur_432 mfe.ht.un_650 
  0x4d65630c, 0x3f546404, 0x63074d12, 0x0e655804,   // sco.gv.aa_543 lg.ik.af_332  aa.it.sco_654 om.gv.is_332 
  // [17fe0]
  0x34002120, 0x4d6b510d, 0x640202a4, 0x3f4c4da4,   // fa.ps.un_850 kl.ceb.aa_554  da.da.lg_433 aa.wo.af_433 
  0x4c5865a7, 0x6552580c, 0x38481b0b, 0x10374404,   // gv.om.wo_532 om.ha.gv_543  tr.tt.tk_542 kk.ba.be_332 
  0x73001f09, 0x530d1505, 0x4c644d60, 0x0d00fc12,   // cy.ny.un_440 un.cs.ht_333  aa.lg.wo_664 zzp.cs.un_640 
  0x20003107, 0x423b0708, 0x022239a7, 0x40053f07,   // az.sq.un_420 it.so.co_443  br.oc.da_532 af.fr.lb_432 
  // [17ff0]
  0x0e0c6507, 0x4d645813, 0x35345302, 0x396563a4,   // gv.sv.is_432 om.lg.aa_665  ht.xh.zu_222 sco.gv.br_433 
  0x050165a0, 0x483735af, 0x2e0b0a0d, 0x18000d1a,   // gv.en.fr_322 tg.ba.tt_655  pt.es.fo_554 cs.ga.un_760 
  0x2d0a0da0, 0x3b003e02, 0x116539a7, 0x2d000a2b,   // cs.pt.sk_322 rm.so.un_220  br.gv.ro_532 pt.sk.un_980 
  0x3b5865ec, 0x06002007, 0x0400490d, 0x35496809,   // gv.om.so_644 sq.de.un_420  to.fi.un_540 ig.to.zu_444 
  
  // [18000]
  0x2c582512, 0x36000a11, 0x4704730b, 0x65582cad,   // eu.om.fy_654 pt.gn.un_630  ny.fi.sn_542 fy.om.gv_643 
  0x0a362ea9, 0x1c5c1355, 0x2d0d1811, 0x2d0d12ac,   // fo.gn.pt_544 bh.sa.mr_442  ga.cs.sk_653 hu.cs.sk_632 
  0x63204da9, 0x25000308, 0x17153707, 0x44230a07,   // aa.sq.sco_544 nl.eu.un_430  ba.sr.un_420 mk.ky.kk_432 
  0x300a3604, 0x5d213504, 0x10113855, 0x0f643502,   // ab.mk.uz_332 zu.jw.ss_332  tk.ro.be_442 zu.lg.lv_222 
  // [18010]
  0x0a232209, 0x0a003808, 0x151038a7, 0x150704a0,   // oc.ca.pt_444 tk.pt.un_430  tk.be.un_532 ru.bg.un_322 
  0x0d190b04, 0x2e003908, 0x192d0deb, 0x39256a04,   // es.gl.cs_332 br.fo.un_430  cs.sk.gl_662 haw.eu.br_332 
  0x02601204, 0x532138ec, 0x542e5108, 0x190a5002,   // hu.vo.da_332 tk.jw.ht_644  kl.fo.ik_443 fj.pt.gl_222 
  0x51251e07, 0x46190bad, 0x60630caf, 0x185627ad,   // ms.eu.kl_432 es.gl.qu_643  sv.sco.vo_655 gd.mg.ga_643 
  // [18020]
  0x1e2f0f12, 0x033f2a0c, 0x27025605, 0x0500560d,   // lv.su.ms_654 mt.af.nl_543  mg.da.gd_333 mg.fr.un_540 
  0x313969a0, 0x182709a4, 0x271118af, 0x69005e19,   // mfe.br.az_322 pl.gd.ga_433  ga.ro.gd_655 ts.mfe.un_750 
  0x021e3912, 0x15230808, 0x341373ec, 0x44003805,   // br.ms.da_654 uk.ky.un_443  ny.et.xh_644 tk.kk.un_330 
  0x6a35080c, 0x36000d07, 0x454d4f0c, 0x455e080c,   // no.zu.haw_543 cs.gn.un_420  bi.aa.ln_543 no.ts.ln_543 
  // [18030]
  0x33084504, 0x2d001220, 0x46004f19, 0x480f10a9,   // ln.no.nn_332 hu.sk.un_850  bi.qu.un_750 lt.lv.tt_544 
  0x2a200704, 0x20080607, 0x52003904, 0x060859ec,   // it.sq.mt_332 de.no.sq_432  br.ha.un_320 rn.no.de_644 
  0x211c240c, 0x02512760, 0x090a5107, 0x065d450c,   // eo.id.jw_543 gd.kl.da_664  kl.pt.pl_432 ln.ss.de_543 
  0x0200110e, 0x33001705, 0x5e420505, 0x0a083ca7,   // ro.da.un_550 sr.nn.un_330  fr.co.ts_333 ug.uk.mk_532 
  // [18040]
  0x091b02ee, 0x1b18670c, 0x13093b14, 0x2647080c,   // da.tr.pl_422 ak.ga.tr_543  ks.hi.bh_666 no.sn.ia_543 
  0x5a5b08a9, 0x3e0701a4, 0x065a0807, 0x454b08a4,   // no.sg.sm_544 en.it.rm_433  no.sm.de_432 no.mi.ln_433 
  0x424001a0, 0x5700501b, 0x35002005, 0x103025a0,   // en.lb.co_322 fj.na.un_770  sq.zu.un_330 mn.uz.be_322 
  0x151a21a4, 0x054502a0, 0x06096955, 0x68005713,   // jw.tl.un_433 da.ln.fr_322  mfe.pl.de_442 na.ig.un_650 
  // [18050]
  0x55796b08, 0x182d0d14, 0x0b00fe04, 0x0d1219a0,   // ceb.war.rw_443 cs.sk.ga_666  tlh.es.un_320 gl.hu.cs_322 
  0x57000804, 0x2317150c, 0x64001102, 0x58595505,   // no.na.un_320 un.sr.ky_543  ro.lg.un_220 rw.rn.om_333 
  0x44232112, 0x07083007, 0x6900572a, 0x1b5154ad,   // fa.ky.kk_654 uz.uk.bg_432  na.mfe.un_970 ik.kl.tr_643 
  0x31301b11, 0x1a00670d, 0x4d313b0c, 0x0b192eee,   // tr.uz.az_653 ak.tl.un_540  so.az.aa_543 fo.gl.es_422 
  // [18060]
  0x62003f19, 0x0e003b04, 0x1f381102, 0x63006508,   // af.kha.un_750 so.is.un_320  ro.tk.cy_222 gv.sco.un_430 
  0x19000d04, 0x1b382e07, 0x6b362ea4, 0x64581f14,   // cs.gl.un_320 fo.tk.tr_432  fo.gn.ceb_433 cy.om.lg_666 
  0x79006b22, 0x31006b07, 0x0d122d55, 0x2c1827a0,   // ceb.war.un_870 ceb.az.un_420  sk.hu.cs_442 gd.ga.fy_322 
  0x2e36125e, 0x0d2d18ee, 0x1800121d, 0x2110180c,   // hu.gn.fo_652 ga.sk.cs_422  hu.ga.un_820 ar.be.fa_543 
  // [18070]
  0x07110405, 0x36005b12, 0x35002534, 0x0d0a12ac,   // ru.ro.bg_333 sg.gn.un_640  mn.tg.un_A80 hu.pt.cs_632 
  0x30312a08, 0x0a001210, 0x441015ee, 0x362d0d1b,   // mt.az.uz_443 hu.pt.un_620  un.be.kk_422 cs.sk.gn_777 
  0x23004c04, 0x36001d02, 0xfc021107, 0x25000113,   // wo.ca.un_320 la.gn.un_220  ro.da.zzp_432 en.eu.un_650 
  0x0445010c, 0x0a083808, 0xfc00730d, 0x0b2322a9,   // en.ln.fi_543 tk.uk.mk_443  ny.zzp.un_540 oc.ca.es_544 
  // [18080]
  0x17233005, 0x17231d0c, 0x36394308, 0x154837ad,   // uz.ky.sr_333 la.ca.sr_543  ie.br.gn_443 ba.tt.un_643 
  0x190e2e05, 0x731101a0, 0x69024c11, 0x482e0e0c,   // fo.is.gl_333 en.ro.ny_322  wo.da.mfe_653 is.fo.tt_543 
  0x204f3f04, 0x3343390c, 0x21283d02, 0x39205e07,   // af.bi.sq_332 br.ie.nn_543  ku.sd.fa_222 ts.sq.br_432 
  0x48081555, 0x734c03a4, 0x390333a0, 0x28003c0e,   // un.uk.tt_442 nl.wo.ny_433  nn.nl.br_322 ug.sd.un_550 
  // [18090]
  0x32096908, 0x560176a0, 0x1d4304ac, 0x20481bec,   // mfe.pl.bs_443 crs.en.mg_322  fi.ie.la_632 tr.tt.sq_644 
  0x034d3f09, 0x60fe4ead, 0x31046107, 0x480a2304,   // af.aa.nl_444 ay.tlh.vo_643  za.fi.az_432 ca.pt.tt_332 
  0x011d630b, 0xfe004f04, 0x2d0d0e0d, 0x0300611a,   // sco.la.en_542 bi.tlh.un_320  is.cs.sk_554 za.nl.un_760 
  0x333f04a0, 0x2a2f5cee, 0x1544380c, 0x1d00630c,   // fi.af.nn_322 sa.su.mt_422  tk.kk.un_543 sco.la.un_530 
  // [180a0]
  0x220c2308, 0x1862fe12, 0x1a102ea7, 0x2260230d,   // ca.sv.oc_443 tlh.kha.ga_654  fo.lt.tl_532 ca.vo.oc_554 
  0x013b1507, 0x4300011a, 0x0e2e1904, 0x050a2305,   // un.so.en_432 en.ie.un_760  gl.fo.is_332 ca.pt.fr_333 
  0x223e0507, 0x3e052213, 0x05fc01a9, 0x0c4e0f0d,   // fr.rm.oc_432 oc.fr.rm_665  en.zzp.fr_544 lv.ay.sv_554 
  0xfe232207, 0x104c2004, 0x23223e14, 0x63421155,   // oc.ca.tlh_432 sq.wo.lt_332  rm.oc.ca_666 ro.co.sco_442 
  // [180b0]
  0x420a4fee, 0x1d27fc07, 0x37000808, 0x3e23220c,   // bi.pt.co_422 zzp.gd.la_432  no.st.un_430 oc.ca.rm_543 
  0x61171005, 0x23005804, 0x134d58a4, 0x31fe3ba7,   // lt.sr.za_333 om.ca.un_320  om.aa.et_433 so.tlh.az_532 
  0x01056307, 0x05222313, 0x20332e07, 0x0c001d08,   // sco.fr.en_432 ca.oc.fr_665  fo.nn.sq_432 la.sv.un_430 
  0x3e22230c, 0x0a00220d, 0x3061480c, 0x10033f0c,   // ca.oc.rm_543 oc.pt.un_540  tt.za.uz_543 af.nl.lt_543 
  // [180c0]
  0x1d0c0407, 0xfc000508, 0x6348feac, 0x18006b02,   // fi.sv.la_432 fr.zzp.un_430  tlh.tt.sco_632 ceb.ga.un_220 
  0x757337a9, 0x1505010c, 0x643b4d07, 0x215c1ca4,   // st.ny.nso_544 en.fr.un_543  aa.so.lg_432 id.sa.jw_433 
  0x1b483160, 0x223e2313, 0x02007304, 0x3e232205,   // az.tt.tr_664 ca.rm.oc_665  ny.da.un_320 oc.ca.rm_333 
  0x5955350e, 0x2f000602, 0x625e5d08, 0x01005c0b,   // zu.rw.rn_555 de.su.un_220  ss.ts.kha_443 sa.en.un_520 
  // [180d0]
  0x29551502, 0x190a12a6, 0x1f472705, 0x02254b05,   // un.rw.sl_222 hu.pt.gl_521  gd.sn.cy_333 mi.eu.da_333 
  0x64133bac, 0x0b00672b, 0x27184713, 0x0a220504,   // so.et.lg_632 ak.es.un_980  sn.ga.gd_665 fr.oc.pt_332 
  0x18275807, 0x39000f0c, 0x10084407, 0x4a002004,   // om.gd.ga_432 lv.br.un_530  kk.uk.be_432 sq.yo.un_320 
  0x1b3805b3, 0x31001b10, 0x2e003612, 0x01261508,   // fr.tk.tr_743 tr.az.un_620  gn.fo.un_640 un.ia.en_443 
  // [180e0]
  0x185e0107, 0x55002d0d, 0x0437480c, 0xfc285da4,   // en.ts.ga_432 sk.rw.un_540  tt.ba.ru_543 ss.sw.zzp_433 
  0x2e190b02, 0x372a4707, 0x0d0e1808, 0xfc5d6755,   // es.gl.fo_222 sn.mt.st_432  ga.is.cs_443 ak.ss.zzp_442 
  0x03232fa0, 0x233c15a7, 0x39000912, 0x2f0302a0,   // su.ca.nl_322 un.ug.ky_532  pl.br.un_640 da.nl.su_322 
  0x1707040b, 0x28002f0c, 0x441507ad, 0xfc556707,   // ru.bg.sr_542 su.sw.un_530  bg.kk.un_630 ak.rw.zzp_432 
  // [180f0]
  0x38001b11, 0x3400fc13, 0x6453470c, 0x17253002,   // tr.tk.un_630 zzp.xh.un_650  sn.ht.lg_543 uz.mn.sr_222 
  0x43000619, 0x201b48a0, 0x2f002709, 0x060257a7,   // de.ie.un_750 tt.tr.sq_322  gd.su.un_440 na.da.de_532 
  0x18002e07, 0x31002423, 0xfe794fec, 0x3d004414,   // fo.ga.un_420 eo.az.un_880  bi.war.tlh_644 kk.ku.un_660 
  0x46001f02, 0x400e0655, 0x65003505, 0x041a1108,   // cy.qu.un_220 de.is.lb_442  zu.gv.un_330 ro.tl.fi_443 
  // [18100]
  0x1f326312, 0x3c001808, 0x391f3e08, 0x201b3104,   // sco.bs.cy_654 ar.ug.un_430  rm.cy.br_443 az.tr.sq_332 
  0x1b3120a4, 0x56000e07, 0x09003b08, 0x104804a9,   // sq.az.tr_433 is.mg.un_420  ks.hi.un_430 ru.tt.be_544 
  0x2000460e, 0x254838ac, 0x46202fad, 0x21472f02,   // qu.sq.un_550 tk.tt.mn_632  su.sq.qu_643 su.sn.jw_222 
  0x04002c0b, 0x0a101104, 0x36000a19, 0x4825150c,   // fy.fi.un_520 ro.be.mk_332  pt.gn.un_750 un.mn.tt_543 
  // [18110]
  0x080a1014, 0x3c212305, 0x0d2d5c04, 0x23174404,   // be.mk.uk_666 ky.fa.ug_333  sa.sk.cs_332 kk.sr.ky_332 
  0x651d01a0, 0x56635707, 0x5c5338ad, 0x2d2e0ea7,   // en.la.gv_322 na.sco.mg_432  tk.ht.sa_643 is.fo.sk_532 
  0x07373007, 0x21190aa7, 0x4b4c5311, 0x2800301a,   // uz.ba.bg_432 pt.gl.jw_532  ht.wo.mi_653 uz.sd.un_760 
  0x2d090207, 0x150a300c, 0x0900381a, 0x30170705,   // da.pl.sk_432 uz.mk.un_543  tk.pl.un_760 bg.sr.uz_333 
  // [18120]
  0x1b3148a6, 0x3809690c, 0x402021a0, 0x79052204,   // tt.az.tr_521 mfe.pl.tk_543  jw.sq.lb_322 oc.fr.war_332 
  0x30070aa9, 0x0e125d05, 0x380d0907, 0x0e122e08,   // mk.bg.uz_544 ss.hu.is_333  pl.cs.tk_432 fo.hu.is_443 
  0x0408070d, 0x5a0513a6, 0x0e063307, 0x065a2ca9,   // bg.uk.ru_554 et.fr.sm_521  nn.de.is_432 fy.sm.de_544 
  0x04110607, 0x1d5a6a09, 0x6540060c, 0x05470212,   // de.ro.fi_432 haw.sm.la_444  de.lb.gv_543 da.sn.fr_654 
  // [18130]
  0x06005a08, 0x1100390c, 0x3efc0212, 0x40034707,   // sm.de.un_430 br.ro.un_530  da.zzp.rm_654 sn.nl.lb_432 
  0x13057955, 0x31124813, 0x09122507, 0x39281207,   // war.fr.et_442 tt.hu.az_665  eu.hu.pl_432 hu.sw.br_432 
  0x06401fad, 0x12000a19, 0x04495a55, 0x5804fc5a,   // cy.lb.de_643 pt.hu.un_750  sm.to.fi_442 zzp.fi.om_553 
  0x22191da0, 0x17300f05, 0xfc51080c, 0x0c002004,   // la.gl.oc_322 lv.uz.sr_333  no.kl.zzp_543 sq.sv.un_320 
  // [18140]
  0x2d000204, 0x483c3807, 0x39031f07, 0xfc51630c,   // da.sk.un_320 tk.ug.tt_432  cy.nl.br_432 sco.kl.zzp_543 
  0x2a42050c, 0x6000481b, 0x1b48120e, 0x60384812,   // fr.co.mt_543 tt.vo.un_770  hu.tt.tr_555 tt.tk.vo_654 
  0x353430ee, 0x12290407, 0x100f17a4, 0x55353405,   // uz.xh.zu_422 fi.sl.hu_432  sr.lv.lt_433 xh.zu.rw_333 
  0x08000e04, 0x25162f04, 0x091224a0, 0x1f0e4308,   // is.no.un_320 su.hr.eu_332  eo.hu.pl_322 ie.is.cy_443 
  // [18150]
  0x223b1b0c, 0x55000404, 0x166b2dee, 0x1dfc0208,   // tr.so.oc_543 fi.rw.un_320  sk.ceb.hr_422 da.zzp.la_443 
  0x3b0e58a0, 0x64001d0d, 0x404205ad, 0x5a005605,   // om.is.so_322 la.lg.un_540  fr.co.lb_643 mg.sm.un_330 
  0x1d1f18a0, 0x0b0a1fa0, 0x06001305, 0x100b1304,   // ga.cy.la_322 cy.pt.es_322  et.de.un_330 et.es.lt_332 
  0x0463390b, 0x2a005109, 0x18001f07, 0x1c2e0211,   // br.sco.fi_542 kl.mt.un_440  cy.ga.un_420 da.fo.id_653 
  // [18160]
  0x362d68ee, 0x59556760, 0x1d001805, 0x1b323007,   // ig.sk.gn_422 ak.rw.rn_664  ga.la.un_330 uz.bs.tr_432 
  0x57001e08, 0x101730ee, 0x120b190c, 0x010705a0,   // ms.na.un_430 uz.sr.be_422  gl.es.hu_543 fr.it.en_322 
  0x42760107, 0x0a173611, 0x1d1339a0, 0x263601a0,   // en.crs.co_432 ab.sr.mk_653  br.et.la_322 en.gn.ia_322 
  0x3500040c, 0x22422311, 0x07003811, 0x5d343708,   // fi.zu.un_530 ca.co.oc_653  tk.bg.un_630 st.xh.ss_443 
  // [18170]
  0x3559550c, 0x02003608, 0x044838a0, 0x15241c04,   // rw.rn.zu_543 gn.da.un_430  tk.tt.ru_322 id.eo.un_332 
  0x15000f05, 0x0d0913a6, 0x2330380e, 0x38000414,   // lv.un.un_330 bh.hi.ne_521  tk.uz.ky_555 fi.tk.un_660 
  0x04130c02, 0x31003811, 0xfc0c02a0, 0x19004002,   // sv.et.fi_222 tk.az.un_630  da.sv.zzp_322 lb.gl.un_220 
  0x255302a0, 0x0c00fe04, 0x1c2f54a0, 0xfc620255,   // da.ht.eu_322 tlh.sv.un_320  ik.su.id_322 da.kha.zzp_442 
  // [18180]
  0x282a010c, 0x512e0655, 0x05530604, 0x391d01a0,   // en.mt.sw_543 de.fo.kl_442  de.ht.fr_332 en.la.br_322 
  0x18504307, 0x1333020c, 0x0c0413a7, 0x28003c0d,   // ie.fj.ga_432 da.nn.et_543  et.fi.sv_532 ug.sd.un_540 
  0x0d000922, 0x38001305, 0x56056507, 0x0c130408,   // hi.ne.un_870 et.tk.un_330  gv.fr.mg_432 fi.et.sv_443 
  0x02fc0c55, 0x17000413, 0xfe001d11, 0x2739650c,   // sv.zzp.da_442 ru.sr.un_650  la.tlh.un_630 gv.br.gd_543 
  // [18190]
  0x184505a4, 0x21451cee, 0x0c003314, 0x4817380c,   // fr.ln.ga_433 id.ln.jw_422  nn.sv.un_660 tk.sr.tt_543 
  0x48316707, 0x01023b07, 0x1c341e04, 0x1d0179ad,   // ak.az.tt_432 so.da.en_432  ms.xh.id_332 war.en.la_643 
  0x49043bec, 0x30103511, 0x791b0eec, 0x150e510c,   // so.fi.to_644 tg.be.uz_653  is.tr.war_644 kl.is.un_543 
  0x313930a4, 0xfa5e0e05, 0x131e2a09, 0x01633811,   // uz.br.az_433 is.ts.nr_333  mt.ms.et_444 tk.sco.en_653 
  // [181a0]
  0x5800511b, 0x0e2efa0c, 0x1f6301ec, 0x25003808,   // kl.om.un_770 nr.fo.is_543  en.sco.cy_644 tk.mn.un_430 
  0x5800041a, 0x51005804, 0x38000113, 0x34005e2a,   // fi.om.un_760 om.kl.un_320  en.tk.un_650 ts.xh.un_970 
  0x040918a4, 0x04514da9, 0x2d010d07, 0x10003912,   // ga.pl.fi_433 aa.kl.fi_544  cs.en.sk_432 br.lt.un_640 
  0x385c2e04, 0x10001113, 0x15000609, 0x0d630107,   // fo.sa.tk_332 ro.be.un_650  de.un.un_440 en.sco.cs_432 
  // [181b0]
  0x025e0e0d, 0x0e5c5ea7, 0x1d004d12, 0x18002b09,   // is.ts.da_554 ts.sa.is_532  aa.la.un_640 vi.ga.un_440 
  0x44182107, 0x5600380e, 0x04513b04, 0x653f010b,   // fa.ar.kk_432 tk.mg.un_550  so.kl.fi_332 en.af.gv_542 
  0x073523ec, 0x250a08a4, 0x2b001319, 0x5c345e08,   // ky.tg.bg_644 uk.mk.mn_433  et.vi.un_750 ts.xh.sa_443 
  0x0d6338ec, 0x5c001204, 0x0e5c04a4, 0x34132eee,   // tk.sco.cs_644 hu.sa.un_320  fi.sa.is_433 fo.et.xh_422 
  // [181c0]
  0x386301af, 0x04585111, 0x38780da0, 0x2f3f010c,   // en.sco.tk_655 kl.om.fi_653  cs.ve.tk_322 en.af.su_543 
  0x23384804, 0x5a003904, 0x07001307, 0x6a004b14,   // tt.tk.ca_332 br.sm.un_320  et.it.un_420 mi.haw.un_660 
  0x6a121fa9, 0x281355af, 0x25113608, 0x1d290a0c,   // cy.hu.haw_544 rw.et.sw_655  ab.ro.mn_443 pt.sl.la_543 
  0x5d4f250c, 0x39006904, 0xfc1137ee, 0x512e02ee,   // eu.bi.ss_543 mfe.br.un_320  st.ro.zzp_422 da.fo.kl_422 
  // [181d0]
  0x736a5608, 0x5b003919, 0x0e1a6b04, 0x430701a4,   // mg.haw.ny_443 br.sg.un_750  ceb.tl.is_332 en.it.ie_433 
  0x1d731fad, 0x3929fe09, 0x1f49560c, 0x13006013,   // cy.ny.la_643 tlh.sl.br_444  mg.to.cy_543 vo.et.un_650 
  0x490539a0, 0x2469200c, 0x56785e12, 0x1a120fa4,   // br.fr.to_322 sq.mfe.eo_543  ts.ve.mg_654 lv.hu.tl_433 
  0x23381ba7, 0x5000390d, 0x1309270b, 0x06000a07,   // tr.tk.ca_532 br.fj.un_540  gd.pl.et_542 pt.de.un_420 
  // [181e0]
  0x04695104, 0x67212f5a, 0x51fe4d0d, 0x4700131b,   // kl.mfe.fi_332 su.jw.ak_553  aa.tlh.kl_554 et.sn.un_770 
  0x056b01ee, 0x485713a9, 0x5100101a, 0x2251010c,   // en.ceb.fr_422 et.na.tt_544  lt.kl.un_760 en.kl.oc_543 
  0x23373812, 0x4c3120ad, 0x30120ca4, 0x12190b55,   // tk.ba.ky_654 sq.az.wo_643  sv.hu.uz_433 es.gl.hu_442 
  0x1a130408, 0x12220fa4, 0x0f220413, 0x1500081a,   // fi.et.tl_443 lv.oc.hu_433  fi.oc.lv_665 uk.un.un_760 
  // [181f0]
  0x235319a0, 0x2d123655, 0x0b0a250c, 0x1004235a,   // gl.ht.ca_322 gn.hu.sk_442  eu.pt.es_543 ky.ru.be_553 
  0x08005102, 0x07081009, 0x2c2b1bee, 0x650263ee,   // kl.no.un_220 be.uk.bg_444  tr.vi.fy_422 sco.da.gv_422 
  0x3300170b, 0x06006305, 0x0c4a3607, 0xfc00512a,   // sr.nn.un_520 sco.de.un_330  gn.yo.sv_432 kl.zzp.un_970 
  0x214817a0, 0x4a003508, 0x10001122, 0x0e004807,   // sr.tt.jw_322 zu.yo.un_430  ro.be.un_870 tt.is.un_420 
  // [18200]
  0x395346ee, 0x13020ea4, 0x60fe1aad, 0x1a79fe08,   // qu.ht.br_422 is.da.et_433  tl.tlh.vo_643 tlh.war.tl_443 
  0x4d4c1a08, 0xfe230107, 0x343b120b, 0x4d60fe08,   // tl.wo.aa_443 en.ca.tlh_432  ur.ks.ps_542 tlh.vo.aa_443 
  0x171011a0, 0x1a604d0b, 0x01654d04, 0x56007908,   // ro.be.sr_322 aa.vo.tl_542  aa.gv.en_332 war.mg.un_430 
  0x3b1a4d07, 0x69766008, 0x6537110c, 0x2134330c,   // aa.tl.so_432 vo.crs.mfe_443  ro.st.gv_543 nn.xh.jw_543 
  // [18210]
  0x30fe0b09, 0xfe4d2ea4, 0x6a3733a4, 0x3b0933a4,   // es.tlh.uz_444 fo.aa.tlh_433  nn.st.haw_433 nn.pl.so_433 
  0x1afe6bad, 0x3638250c, 0x2e003005, 0x3f250ea4,   // ceb.tlh.tl_643 mn.tk.ab_543  uz.fo.un_330 is.eu.af_433 
  0x212801a0, 0x34003712, 0x303c4411, 0x09355d08,   // en.sw.jw_322 st.xh.un_640  kk.ug.uz_653 ss.zu.pl_443 
  0x38006112, 0x0917350c, 0x330801ee, 0x6e75210c,   // za.tk.un_640 zu.sr.pl_543  en.no.nn_422 jw.nso.hmn_543 
  // [18220]
  0x103723a0, 0x013b4011, 0x481b3105, 0x09005d0e,   // ky.ba.be_322 lb.so.en_653  az.tr.tt_333 ss.pl.un_550 
  0x5f523311, 0x213733a4, 0x3b3720a9, 0x1b3031a9,   // nn.ha.tn_653 nn.st.jw_433  sq.st.so_544 az.uz.tr_544 
  0x38303eaf, 0x0e5110ad, 0x57007914, 0x403842a0,   // rm.uz.tk_655 lt.kl.is_643  war.na.un_660 co.tk.lb_322 
  0x79001609, 0x56002402, 0x04585255, 0x20525711,   // hr.war.un_440 eo.mg.un_220  ha.om.fi_442 na.ha.sq_653 
  // [18230]
  0x2f56630b, 0x380a3608, 0x481504ad, 0x30103c07,   // sco.mg.su_542 ab.mk.tk_443  ru.tt.un_630 ug.be.uz_432 
  0x1710080c, 0x371707a0, 0x0f3b100b, 0x29461ba0,   // uk.be.sr_543 bg.sr.ba_322  lt.so.lv_542 tr.qu.sl_322 
  0x101c3b04, 0x3b020fa0, 0x2e0208a4, 0x06003b14,   // so.id.lt_332 lv.da.so_322  no.da.fo_433 so.de.un_660 
  0x3b2e1c05, 0x330860ee, 0x4d04510c, 0x4500680e,   // id.fo.so_333 vo.no.nn_422  kl.fi.aa_543 ig.ln.un_550 
  // [18240]
  0x586404ad, 0x1a4004a7, 0x5a006a0e, 0x3b400404,   // fi.lg.om_643 fi.lb.tl_532  haw.sm.un_550 fi.lb.so_332 
  0x103e1aa4, 0x58131dee, 0x2b003e04, 0x303511a9,   // tl.rm.lt_433 la.et.om_422  rm.vi.un_320 ro.tg.uz_544 
  0x58045107, 0x0b0d2dad, 0x10003e02, 0x6500540d,   // kl.fi.om_432 sk.cs.es_643  rm.lt.un_220 ik.gv.un_540 
  0x4d1351a4, 0x213312ad, 0x2e00070d, 0x4d130408,   // kl.et.aa_433 hu.nn.jw_643  it.fo.un_540 fi.et.aa_443 
  // [18250]
  0x584c6402, 0x037601a0, 0x123018a0, 0x3b4c58af,   // lg.wo.om_222 en.crs.nl_322  ar.uz.ur_322 om.wo.so_655 
  0x0c0202a0, 0x11433e12, 0x34654c07, 0x0e005820,   // da.da.sv_322 rm.ie.ro_654  wo.gv.xh_432 om.is.un_850 
  0x65071208, 0x13000e05, 0x4c071204, 0x364c0707,   // hu.it.gv_443 is.et.un_330  hu.it.wo_332 it.wo.gn_432 
  0x0c020608, 0x08653307, 0x0a002511, 0x2d000f04,   // de.da.sv_443 nn.gv.no_432  mn.mk.un_630 lv.sk.un_320 
  // [18260]
  0x250435a7, 0x30320d09, 0x37150407, 0x153848a4,   // tg.ru.mn_532 cs.bs.uz_444  ru.ba.un_420 tt.tk.un_433 
  0x0cfc3b07, 0x162d0d64, 0x1b796b07, 0x0a053604,   // so.zzp.sv_432 cs.sk.hr_762  ceb.war.tr_432 gn.fr.pt_332 
  0x12003320, 0x1a450204, 0x3f000d07, 0x1f3039a4,   // nn.hu.un_850 da.ln.tl_332  cs.af.un_420 br.uz.cy_433 
  0x3f025304, 0x43486555, 0x2d0e0d09, 0x380c3011,   // ht.da.af_332 gv.tt.ie_442  cs.is.sk_444 uz.sv.tk_653 
  // [18270]
  0x34304404, 0x221165a4, 0x53fe24a0, 0x24050da7,   // kk.uz.ps_332 gv.ro.oc_433  eo.tlh.ht_322 cs.fr.eo_532 
  0xfc4b2507, 0x2b00fc05, 0x51fc01ec, 0x37254b0c,   // eu.mi.zzp_432 zzp.vi.un_330  en.zzp.kl_644 mi.eu.st_543 
  0x3f024807, 0x23381508, 0x2e623307, 0x0e0c01a4,   // tt.da.af_432 un.tk.ky_443  nn.kha.fo_432 en.sv.is_433 
  0x07652207, 0x38003012, 0x24692aa4, 0x103f0312,   // oc.gv.it_432 uz.tk.un_640  mt.mfe.eo_433 nl.af.lt_654 
  // [18280]
  0x1b002a05, 0x522d0d05, 0x086551a4, 0x307969af,   // mt.tr.un_330 cs.sk.ha_333  kl.gv.no_433 mfe.war.uz_655 
  0x2e006712, 0x5130fe0c, 0x391d010c, 0x42006107,   // ak.fo.un_640 tlh.uz.kl_543  en.la.br_543 za.co.un_420 
  0x122efea0, 0x0d2d3f04, 0x24064da7, 0x2f320fee,   // tlh.fo.hu_322 af.sk.cs_332  aa.de.eo_532 lv.bs.su_422 
  0xfc060ea0, 0x63012f0c, 0x19530b0c, 0x2b330804,   // is.de.zzp_322 su.en.sco_543  es.ht.gl_543 no.nn.vi_332 
  // [18290]
  0x273e0605, 0x55321602, 0x1b040e04, 0x35073cee,   // de.rm.gd_333 hr.bs.rw_222  is.fi.tr_332 ug.bg.tg_422 
  0x441548a9, 0x2a186705, 0xfc001105, 0x3c1828a7,   // tt.kk.un_540 ak.ga.mt_333  ro.zzp.un_330 sd.ar.ug_532 
  0x3c2844a0, 0x071744a0, 0x0e061d05, 0x2e000908,   // kk.sd.ug_322 kk.sr.bg_322  la.de.is_333 pl.fo.un_430 
  0x2f1e13ee, 0x05001004, 0x514204a0, 0x022c09a4,   // et.ms.su_422 lt.fr.un_320  fi.co.kl_322 pl.fy.da_433 
  // [182a0]
  0x02637613, 0x091f5611, 0x0d092d11, 0x170a3007,   // crs.sco.da_665 mg.cy.pl_653  sk.pl.cs_653 uz.mk.sr_432 
  0x35040a05, 0x0579380c, 0x0a000102, 0x0a000405,   // mk.ru.tg_333 tk.war.fr_543  en.pt.un_220 ru.mk.un_330 
  0x0900382b, 0x5b630912, 0x040a08a7, 0x022d0907,   // tk.pl.un_980 pl.sco.sg_654  uk.mk.ru_532 pl.sk.da_432 
  0x0d002202, 0x3f000909, 0x373530a4, 0x08150aaf,   // oc.cs.un_220 pl.af.un_440  uz.tg.ba_433 mk.uk.un_650 
  // [182b0]
  0x55284e0c, 0x5553760d, 0x25231504, 0x555e345a,   // ay.sw.rw_543 crs.ht.rw_554  un.ky.mn_332 xh.ts.rw_553 
  0x1a284705, 0x08444807, 0x13330855, 0x57005a1a,   // sn.sw.tl_333 tt.kk.uk_432  no.nn.et_442 sm.na.un_760 
  0x480e5a0c, 0x04303c0c, 0x5c005a18, 0x350a040b,   // sm.is.tt_543 ug.uz.ru_543  sm.sa.un_740 ru.mk.tg_542 
  0x6379250c, 0x51330804, 0x136b1a04, 0x10005412,   // eu.war.sco_543 no.nn.kl_332  tl.ceb.et_332 ik.lt.un_640 
  // [182c0]
  0x211501a4, 0x55594e04, 0x016b100c, 0x1c4f1ea9,   // en.jw.un_430 ay.rn.rw_332  lt.ceb.en_543 ms.bi.id_544 
  0x051f27a4, 0x28005904, 0x2600fe0e, 0xfc0650ee,   // gd.cy.fr_433 rn.sw.un_320  tlh.ia.un_550 fj.de.zzp_422 
  0x2e450e08, 0x482337a9, 0x57624008, 0x4b456a12,   // is.ln.fo_443 ba.ky.tt_544  lb.kha.na_443 haw.ln.mi_654 
  0x5efc280c, 0x5a4a49ec, 0x113e63ad, 0x040830a4,   // sw.zzp.ts_543 to.yo.sm_644  sco.rm.ro_643 uz.uk.ru_433 
  // [182d0]
  0x28251e07, 0x34450204, 0x0a4502a9, 0x0f531d55,   // ms.eu.sw_432 da.ln.xh_332  da.ln.pt_544 la.ht.lv_442 
  0x06005a12, 0x480e0fa4, 0x56152fa0, 0x05630108,   // sm.de.un_640 lv.is.tt_433  su.mg.un_320 en.sco.fr_443 
  0x633e0411, 0x1e1f62a0, 0x27566704, 0x4a604507,   // fi.rm.sco_653 kha.cy.ms_322  ak.mg.gd_332 ln.vo.yo_432 
  0x4c114207, 0x153615a4, 0x3e536907, 0x07041002,   // co.ro.wo_432 un.ab.un_433  mfe.ht.rm_432 be.ru.bg_222 
  // [182e0]
  0x17162909, 0x53002904, 0x153c25ec, 0x353715ee,   // sl.hr.sr_444 sl.ht.un_320  mn.ug.un_644 un.ba.tg_422 
  0x44041704, 0x102530ec, 0x352337ad, 0x38003110,   // sr.ru.kk_332 uz.mn.be_644  ba.ky.tg_643 az.tk.un_620 
  0x4c4d30ad, 0x4d4830ad, 0x0704170d, 0x4c4d300c,   // uz.aa.wo_643 uz.tt.aa_643  sr.ru.bg_554 uz.aa.wo_543 
  0x3048460c, 0x190a61ee, 0x20384804, 0x7300300d,   // qu.tt.uz_543 za.pt.gl_422  tt.tk.sq_332 uz.ny.un_540 
  // [182f0]
  0x50682507, 0x12684504, 0x454a6707, 0x1b003823,   // eu.ig.fj_432 ln.ig.hu_332  ak.yo.ln_432 tk.tr.un_880 
  0x45fc0505, 0x075a6807, 0x02304608, 0x20001b0d,   // fr.zzp.ln_333 ig.sm.it_432  qu.uz.da_443 tr.sq.un_540 
  0x645867ad, 0x053e010c, 0x56003604, 0x40573e0c,   // ak.om.lg_643 en.rm.fr_543  gn.mg.un_320 rm.na.lb_543 
  0x450523a0, 0x1b310ca4, 0x120a2f02, 0xfc001104,   // ca.fr.ln_322 sv.az.tr_433  su.pt.hu_222 ro.zzp.un_320 
  // [18300]
  0x27005a07, 0x56274f0d, 0xfe135cee, 0x37565faf,   // sm.gd.un_420 bi.gd.mg_554  sa.et.tlh_422 tn.mg.st_655 
  0x33085c0c, 0x25002709, 0x50003504, 0x561f5a08,   // sa.no.nn_543 gd.eu.un_440  zu.fj.un_320 sm.cy.mg_443 
  0x54275a5a, 0x212322a0, 0x21052208, 0x5b0501a0,   // sm.gd.ik_553 oc.ca.jw_322  oc.fr.jw_443 en.fr.sg_322 
  0x041b480d, 0x0f25560c, 0x170a48a0, 0x56040fa4,   // tt.tr.fi_554 mg.eu.lv_543  tt.mk.sr_322 lv.fi.mg_433 
  // [18310]
  0x471a6a08, 0x27fc0107, 0x440a1705, 0x562701a0,   // haw.tl.sn_443 en.zzp.gd_432  sr.mk.kk_333 en.gd.mg_322 
  0x131856a9, 0x4b0425a9, 0x3c3d180c, 0x2a00460e,   // mg.ga.et_544 eu.fi.mi_544  ar.ku.ug_543 qu.mt.un_550 
  0x4500050d, 0x331d18a0, 0x20002208, 0x21342811,   // fr.ln.un_540 ga.la.nn_322  oc.sq.un_430 sd.ps.fa_653 
  0x30311b0d, 0x1200040b, 0x51004a0e, 0x0f003707,   // tr.az.uz_554 fi.hu.un_520  yo.kl.un_550 st.lv.un_420 
  // [18320]
  0x125204ac, 0x44043507, 0x060715ee, 0x1f0b2307,   // fi.ha.hu_632 tg.ru.kk_432  un.it.de_422 ca.es.cy_432 
  0x2c3f0313, 0xfc004a21, 0x303d1207, 0x7605260d,   // nl.af.fy_665 yo.zzp.un_860  ur.ku.uz_432 ia.fr.crs_554 
  0x1c002112, 0x2b007907, 0x39fe25ee, 0x224205ee,   // jw.id.un_640 war.vi.un_420  eu.tlh.br_422 fr.co.oc_422 
  0x151508ad, 0x64422107, 0x2e001a02, 0x0a004a04,   // uk.un.un_630 jw.co.lg_432  tl.fo.un_220 yo.pt.un_320 
  // [18330]
  0x10002608, 0x3c1523a9, 0x04005509, 0x0e2d0d13,   // ia.lt.un_430 ky.ug.un_540  rw.fi.un_440 cs.sk.is_665 
  0x111d5807, 0x27036302, 0x0e2d3608, 0x041358a4,   // om.la.ro_432 sco.nl.gd_222  gn.sk.is_443 om.et.fi_433 
  0x30001712, 0x544d51a9, 0x084423ad, 0x04515807,   // sr.uz.un_640 kl.aa.ik_544  ky.kk.uk_643 om.kl.fi_432 
  0x2d0e36ee, 0x585404ad, 0x522a6409, 0x2a232207,   // gn.is.sk_422 fi.ik.om_643  lg.mt.ha_444 oc.ca.mt_432 
  // [18340]
  0x56002207, 0x54515812, 0x24060ea0, 0x05003613,   // oc.mg.un_420 om.kl.ik_654  is.de.eo_322 gn.fr.un_650 
  0x1b300605, 0x0e424009, 0x0e360ba0, 0x301738a0,   // de.uz.tr_333 lb.co.is_444  es.gn.is_322 tk.sr.uz_322 
  0x0e180da0, 0x51135412, 0x12360ea0, 0x222e0e11,   // cs.ga.is_322 ik.et.kl_654  is.gn.hu_322 is.fo.oc_653 
  0x2000380d, 0x131c5cac, 0x12342813, 0x360e2e07,   // tk.sq.un_540 sa.mr.bh_632  sd.ps.ur_665 fo.is.gn_432 
  // [18350]
  0x070815ee, 0x2d00790e, 0x3148380d, 0x043c1708,   // un.uk.bg_422 war.sk.un_550  tk.tt.az_554 sr.ug.ru_443 
  0x30360707, 0x04134ba4, 0x38130455, 0x1223440c,   // bg.ab.uz_432 mi.et.fi_433  fi.et.tk_442 kk.ky.ur_543 
  0x0a222311, 0x1515170d, 0x335c0cee, 0x17150aa0,   // ca.oc.pt_653 sr.un.un_540  sv.sa.nn_422 mk.sr.un_320 
  0x1b002005, 0x17003c19, 0x30080a0c, 0x0c1304a0,   // sq.tr.un_330 ug.sr.un_750  mk.uk.uz_543 fi.et.sv_322 
  // [18360]
  0x73456705, 0x15083012, 0x1d573607, 0x52004f19,   // ak.ln.ny_333 uz.uk.un_654  gn.na.la_432 bi.ha.un_750 
  0x311a10a4, 0x4a002f0c, 0x255379a4, 0x27606105,   // lt.tl.az_433 su.yo.un_530  war.ht.eu_433 za.vo.gd_333 
  0x35230a0d, 0x2e5b6b04, 0x44250455, 0x3b001013,   // mk.ky.tg_554 ceb.sg.fo_332  ru.mn.kk_442 lt.so.un_650 
  0x6000571a, 0x281c5ca4, 0x65734309, 0x5c003808,   // na.vo.un_760 sa.id.sw_433  ie.ny.gv_444 tk.sa.un_430 
  // [18370]
  0x104436a0, 0x62150108, 0x3037440b, 0x23384812,   // ab.kk.be_322 en.kha.un_430  kk.ba.uz_542 tt.tk.ky_654 
  0x37351507, 0x04103004, 0x440448ee, 0x2d290dec,   // un.tg.ba_432 uz.be.ru_332  tt.ru.kk_422 cs.sl.sk_644 
  0x48103704, 0x05000a08, 0x13005507, 0x0c030fee,   // ba.be.tt_332 pt.fr.un_430  rw.et.un_420 lv.nl.sv_422 
  0x2f003202, 0x432d0d60, 0x20004807, 0x48080209,   // bs.su.un_220 cs.sk.ie_664  tt.sq.un_420 da.no.tt_444 
  // [18380]
  0x23301508, 0x1f1827ec, 0x0c0e0da4, 0x0c510ea0,   // un.uz.ky_443 gd.ga.cy_644  cs.is.sv_433 is.kl.sv_322 
  0x24330805, 0x040f1c04, 0x311b27a0, 0x1b5138a0,   // no.nn.eo_333 id.lv.fi_332  gd.tr.az_322 tk.kl.tr_322 
  0x305553a0, 0x5100651a, 0x0d1331a7, 0x38483307,   // ht.rw.uz_322 gv.kl.un_760  az.et.cs_532 nn.tt.tk_432 
  0x13000e0c, 0x130e23a7, 0x190b1fec, 0x47364505,   // is.et.un_530 ca.is.et_532  cy.es.gl_644 ln.gn.sn_333 
  // [18390]
  0x534c0505, 0x381001a0, 0x02003712, 0x23000e07,   // fr.wo.ht_333 en.lt.tk_322  st.da.un_640 is.ca.un_420 
  0x532857a0, 0x076542a0, 0x42510405, 0x0a0725ec,   // na.sw.ht_322 co.gv.it_322  fi.kl.co_333 mn.bg.mk_644 
  0x183412a4, 0x054c30a0, 0x030202a0, 0x394c63ad,   // ur.ps.ar_433 uz.wo.fr_322  da.da.nl_322 sco.wo.br_643 
  0x2f240104, 0x3100481a, 0x322457a7, 0x2e0c38a4,   // en.eo.su_332 tt.az.un_760  na.eo.bs_532 tk.sv.fo_433 
  // [183a0]
  0x4f031d07, 0x1c4d2113, 0x4d6a3605, 0x1f0e18a6,   // la.nl.bi_432 jw.aa.id_665  gn.haw.aa_333 ga.is.cy_521 
  0x0f001707, 0x2953fc0c, 0x180e3612, 0x030e08a4,   // sr.lv.un_420 zzp.ht.sl_543  gn.is.ga_654 no.is.nl_433 
  0x3b3f030c, 0x06025604, 0x650115ee, 0x513b5804,   // nl.af.so_543 mg.da.de_332  un.en.gv_422 om.so.kl_332 
  0x3b3f5808, 0x34134aa0, 0x1203530c, 0x033f13a9,   // om.af.so_443 yo.et.xh_322  ht.nl.hu_543 et.af.nl_544 
  // [183b0]
  0x380357ee, 0x384d1b0d, 0x4d3b5809, 0x21240102,   // na.nl.tk_422 tr.aa.tk_554  om.so.aa_444 en.eo.jw_222 
  0x0e0c1207, 0x04001321, 0x4d3b4ca9, 0x21122f11,   // hu.sv.is_432 et.fi.un_860  wo.so.aa_544 su.hu.jw_653 
  0x69572f0c, 0x583e1da7, 0x23481512, 0x15173660,   // su.na.mfe_543 la.rm.om_532  un.tt.ky_654 ab.sr.un_664 
  0x33084fec, 0x5c001c20, 0x47586508, 0x033f51a9,   // bi.no.nn_644 mr.sa.un_850  gv.om.sn_443 kl.af.nl_544 
  // [183c0]
  0x51003b0d, 0x60033f0c, 0x07100405, 0x481537ad,   // so.kl.un_540 af.nl.vo_543  ru.be.bg_333 ba.tt.un_630 
  0x3704155a, 0x23363505, 0x382d0dec, 0x0a0811af,   // un.ru.ba_553 tg.ab.ky_333  cs.sk.tk_644 ro.uk.mk_655 
  0x2d0d63a0, 0x0d002d2b, 0x48041707, 0x0e004b02,   // sco.cs.sk_322 sk.cs.un_980  sr.ru.tt_432 mi.is.un_220 
  0x2d0d02ec, 0x13000e04, 0x15233c12, 0x28473fa0,   // da.cs.sk_644 is.et.un_320  ug.ky.un_654 af.sn.sw_322 
  // [183d0]
  0x55005605, 0x382d0d0d, 0x382d0d60, 0x180f2712,   // mg.rw.un_330 cs.sk.tk_554  cs.sk.tk_664 gd.lv.ga_654 
  0x1a1c1ea9, 0x10611708, 0x30005221, 0x352f20a6,   // ms.id.tl_544 sr.za.lt_443  ha.uz.un_860 sq.su.zu_521 
  0x04153c08, 0x0a100808, 0x203b10a0, 0x4a5d35a7,   // ug.ru.un_430 uk.be.mk_443  lt.so.sq_322 zu.ss.yo_532 
  0x52003b0d, 0x1b594daf, 0x426069ec, 0x103548ee,   // so.ha.un_540 aa.rn.tr_655  mfe.vo.co_644 tt.tg.be_422 
  // [183e0]
  0x5200430e, 0x1d3601a0, 0x1d1801a0, 0x53002f1b,   // ie.ha.un_550 en.gn.la_322  en.ga.la_322 su.ht.un_770 
  0x292d60af, 0x095d3511, 0x49045d05, 0x232144a0,   // vo.sk.sl_655 zu.ss.pl_653  ss.fi.to_333 kk.fa.ky_322 
  0x0a080702, 0x444830ad, 0xfe002a0e, 0x17080aaf,   // bg.uk.mk_222 uz.tt.kk_643  mt.tlh.un_550 mk.uk.sr_655 
  0x40475811, 0x3f004307, 0x3b581aa0, 0x2c5a0fee,   // om.sn.lb_653 ie.af.un_420  tl.om.so_322 lv.sm.fy_422 
  // [183f0]
  0x394b78a4, 0x3b00631b, 0x4c6a2fa9, 0x605321a9,   // ve.mi.br_433 sco.so.un_770  su.haw.wo_544 jw.ht.vo_544 
  0x02583bad, 0x4000530c, 0x15113613, 0x04003404,   // so.om.da_643 ht.lb.un_530  ab.ro.un_665 xh.fi.un_320 
  0x28390211, 0x6404250c, 0x22003b04, 0x29091faf,   // da.br.sw_653 eu.fi.lg_543  so.oc.un_320 cy.pl.sl_655 
  0x02fe4a08, 0x06251ba9, 0x2530355a, 0x03fc4004,   // yo.tlh.da_443 tr.eu.de_544  tg.uz.mn_553 lb.zzp.nl_332 
  
  // [18400]
  0x053720ad, 0x4c1b2608, 0x565c4c13, 0x1269765a,   // sq.st.fr_643 ia.tr.wo_443  wo.sa.mg_665 crs.mfe.hu_553 
  0x07024a04, 0x4d4c7813, 0x245f2fa4, 0x5b565808,   // yo.da.it_332 ve.wo.aa_665  su.tn.eo_433 om.mg.sg_443 
  0x2225230c, 0x39000108, 0x2102080c, 0x5559300c,   // ca.eu.oc_543 en.br.un_430  no.da.jw_543 uz.rn.rw_543 
  0xfe2037ac, 0x3c003d19, 0x30581902, 0x0b4b330c,   // st.sq.tlh_632 ku.ug.un_750  gl.om.uz_222 nn.mi.es_543 
  // [18410]
  0x28001d12, 0x1234180d, 0x02594b05, 0x02125808,   // la.sw.un_640 ar.ps.ur_554  mi.rn.da_333 om.hu.da_443 
  0x3d21340e, 0x09002104, 0x305f4bad, 0x1e1a6b08,   // ps.fa.ku_555 jw.pl.un_320  mi.tn.uz_643 ceb.tl.ms_443 
  0x464d200c, 0x213f0f55, 0x022043a4, 0x353830ad,   // sq.aa.qu_543 lv.af.jw_442  ie.sq.da_433 uz.tk.tg_643 
  0x48383155, 0x254436ee, 0x331510af, 0x34584c02,   // az.tk.tt_442 ab.kk.mn_422  lt.nn.un_650 wo.om.xh_222 
  // [18420]
  0xfc254708, 0x1c1e6704, 0x12182160, 0x5706fc12,   // sn.eu.zzp_443 ak.ms.id_332  fa.ar.ur_664 zzp.de.na_654 
  0x694276a9, 0x0302fc0c, 0x5751470c, 0x173c3007,   // crs.co.mfe_544 zzp.da.nl_543  sn.kl.na_543 uz.ug.sr_432 
  0x1e002b07, 0x09002419, 0x1b1f31af, 0x33000f0e,   // vi.ms.un_420 eo.pl.un_750  az.cy.tr_655 lv.nn.un_550 
  0x46590da0, 0x3034215a, 0x63000619, 0xfc681d04,   // cs.rn.qu_322 fa.ps.uz_553  de.sco.un_750 la.ig.zzp_332 
  // [18430]
  0x0a081109, 0x07000907, 0x2500fc05, 0x081147a7,   // ro.uk.mk_444 pl.it.un_420  zzp.eu.un_330 sn.ro.no_532 
  0x79590908, 0x2a00020c, 0x06581809, 0x443c370c,   // pl.rn.war_443 da.mt.un_530  ga.om.de_444 ba.ug.kk_543 
  0x190769a6, 0x4d003b22, 0x792a0aee, 0x04006a07,   // mfe.it.gl_521 so.aa.un_870  pt.mt.war_422 haw.fi.un_420 
  0x58043b5a, 0x38005621, 0x273efca4, 0x0e40060d,   // so.fi.om_553 mg.tk.un_860  zzp.rm.gd_433 de.lb.is_554 
  // [18440]
  0x283012ad, 0x2400581a, 0x07423e08, 0x57190b13,   // ur.uz.sd_643 om.eo.un_760  rm.co.it_443 es.gl.na_665 
  0x244d3b0c, 0x4c043ba4, 0x07250aa0, 0x3b00231a,   // so.aa.eo_543 so.fi.wo_433  mk.mn.bg_322 ky.ks.un_760 
  0x1065fc08, 0x381012a4, 0x653812a0, 0x38651fee,   // zzp.gv.lt_443 hu.lt.tk_433  hu.tk.gv_322 cy.gv.tk_422 
  0x0953fc02, 0xfc3865af, 0x6509fca4, 0x381d5604,   // zzp.ht.pl_222 gv.tk.zzp_655  zzp.pl.gv_433 mg.la.tk_332 
  // [18450]
  0x0a350709, 0x4d213b0c, 0x392718a7, 0x550f59ee,   // bg.tg.mk_444 so.jw.aa_543  ga.gd.br_532 rn.lv.rw_422 
  0x2c200313, 0x0e003319, 0x08336507, 0x20004a04,   // nl.sq.fy_665 nn.is.un_750  gv.nn.no_432 yo.sq.un_320 
  0x56255213, 0x2a321604, 0x67311b08, 0x11321608,   // ha.eu.mg_665 hr.bs.mt_332  tr.az.ak_443 hr.bs.ro_443 
  0x1f000407, 0x1821280d, 0x30000a07, 0x03321614,   // fi.cy.un_420 sd.fa.ar_554  mk.uz.un_420 hr.bs.nl_666 
  // [18460]
  0x0f102ca4, 0x3e1c2fad, 0x083511af, 0x25354407,   // fy.lt.lv_433 su.id.rm_643  ro.tg.uk_655 kk.tg.mn_432 
  0x2e001902, 0x4b5c0f07, 0x04001719, 0x12283dad,   // gl.fo.un_220 lv.sa.mi_432  sr.ru.un_750 ku.sd.ur_643 
  0x48004418, 0x21342860, 0x441504ee, 0x1f003007,   // kk.tt.un_740 sd.ps.fa_664  ru.kk.un_420 uz.cy.un_420 
  0x0613fcec, 0x654001a4, 0x30006509, 0xfc001b08,   // zzp.et.de_644 en.lb.gv_433  gv.uz.un_440 tr.zzp.un_430 
  // [18470]
  0x652d0d05, 0x2c00fc12, 0x4c00400d, 0x4e005b1a,   // cs.sk.gv_333 zzp.fy.un_640  lb.wo.un_540 sg.ay.un_760 
  0x4448300c, 0x18000d05, 0x65751fa4, 0x19420207,   // uz.tt.kk_543 cs.ga.un_330  cy.nso.gv_433 da.co.gl_432 
  0x0f004c17, 0x351710ee, 0x2c000205, 0x16003602,   // wo.lv.un_730 be.sr.tg_422  da.fy.un_330 gn.hr.un_220 
  0x56000f19, 0x11464e08, 0x5c60fc0d, 0x35153607,   // lv.mg.un_750 ay.qu.ro_443  zzp.vo.sa_554 ab.tg.un_420 
  // [18480]
  0x11000a09, 0x0a00110e, 0x30626a11, 0x4e090d11,   // pt.ro.un_440 ro.pt.un_550  haw.kha.uz_653 cs.pl.ay_653 
  0x3f0e030e, 0x4f631e0c, 0x29000312, 0x3917620c,   // nl.is.af_555 ms.sco.bi_543  nl.sl.un_640 kha.sr.br_543 
  0x6b5e0107, 0xfc002907, 0xfe202604, 0x4b000222,   // en.ts.ceb_432 sl.zzp.un_420  ia.sq.tlh_332 da.mi.un_870 
  0x306b4bad, 0x622a1ca4, 0x3f2c58a7, 0x21611cad,   // mi.ceb.uz_643 id.mt.kha_433  om.fy.af_532 id.za.jw_643 
  // [18490]
  0x56005b0d, 0x1c784808, 0x02222708, 0x15301507,   // sg.mg.un_540 tt.ve.id_443  gd.oc.da_443 un.uz.un_432 
  0x39182704, 0x1721390c, 0x112c0a12, 0x210d200d,   // gd.ga.br_332 br.jw.sr_543  pt.fy.ro_654 sq.cs.jw_554 
  0x04004e14, 0x0347390c, 0x4d465713, 0x08001514,   // ay.fi.un_660 br.sn.nl_543  na.qu.aa_665 un.uk.un_660 
  0x2f006402, 0x474f4b55, 0x27021814, 0x17024bec,   // lg.su.un_220 mi.bi.sn_442  ga.da.gd_666 mi.da.sr_644 
  // [184a0]
  0x504765a0, 0x2800460c, 0x070256a7, 0x0a3525a4,   // gv.sn.fj_322 qu.sw.un_530  mg.da.it_532 mn.tg.mk_433 
  0x10002914, 0x2e0408a4, 0x6062060c, 0x2d0640a0,   // sl.lt.un_660 no.fi.fo_433  de.kha.vo_543 lb.de.sk_322 
  0x3940060c, 0x393e1f0c, 0x795316a4, 0x0e000619,   // de.lb.br_543 cy.rm.br_543  hr.ht.war_433 de.is.un_750 
  0x16202c11, 0x623e630c, 0x530d2804, 0x09062cee,   // fy.sq.hr_653 sco.rm.kha_543  sw.cs.ht_332 fy.de.pl_422 
  // [184b0]
  0x2f0c0204, 0x40572708, 0x25150aec, 0x1830345a,   // da.sv.su_332 gd.na.lb_443  mk.mn.un_640 ps.uz.ar_553 
  0x4e000c0e, 0x3c44300d, 0x1b691204, 0x07360407,   // sv.ay.un_550 uz.kk.ug_554  hu.mfe.tr_332 ru.ab.bg_432 
  0x2c0506ac, 0x2f2c4fa0, 0x2c065707, 0x32162914,   // de.fr.fy_632 bi.fy.su_322  na.de.fy_432 sl.hr.bs_666 
  0x3f000607, 0x3b1b0804, 0x40450408, 0x30234812,   // de.af.un_420 no.tr.so_332  fi.ln.lb_443 tt.ky.uz_654 
  // [184c0]
  0x32002804, 0x12182304, 0x67004d2a, 0x295c20a0,   // sw.bs.un_320 ky.ar.ur_332  aa.ak.un_970 sq.sa.sl_322 
  0x040811ec, 0x38480a04, 0x4c212fad, 0x384830a9,   // ro.uk.ru_644 pt.tt.tk_332  su.jw.wo_643 uz.tt.tk_544 
  0x37004420, 0x370410a7, 0x0a4822a0, 0x36253807,   // kk.ba.un_850 be.ru.ba_532  oc.tt.pt_322 tk.mn.ab_432 
  0x20000a04, 0x1c135c07, 0x07380aa4, 0x3d002120,   // pt.sq.un_320 sa.bh.mr_432  mk.tk.bg_433 fa.ku.un_850 
  // [184d0]
  0x79114660, 0x36001121, 0x2a1a57ee, 0x3f2a0908,   // qu.ro.war_664 ro.ab.un_860  na.tl.mt_422 pl.mt.af_443 
  0x61004913, 0x08004005, 0xfe00200c, 0x4a006712,   // to.za.un_650 lb.no.un_330  sq.tlh.un_530 ak.yo.un_640 
  0x0e2e3311, 0x5300640e, 0x40330813, 0x0306790c,   // nn.fo.is_653 lg.ht.un_550  no.nn.lb_665 war.de.nl_543 
  0x1f005304, 0x46030607, 0x42fc1d0b, 0x0b190a0c,   // ht.cy.un_320 de.nl.qu_432  la.zzp.co_542 pt.gl.es_543 
  // [184e0]
  0x25000614, 0x33790607, 0x440810ad, 0x12000c12,   // de.eu.un_660 de.war.nn_432  be.uk.kk_643 sv.hu.un_640 
  0x383601a4, 0x09006304, 0x223f0607, 0x041f0dad,   // en.gn.tk_433 sco.pl.un_320  de.af.oc_432 cs.cy.fi_643 
  0x6553590c, 0x635801a0, 0x045860a0, 0x096129ec,   // rn.ht.gv_543 en.om.sco_322  vo.om.fi_322 sl.za.pl_644 
  0x38630107, 0x60632d07, 0x2a2c0608, 0x6b0325ee,   // en.sco.tk_432 sk.sco.vo_432  de.fy.mt_443 eu.nl.ceb_422 
  // [184f0]
  0x1f3809ec, 0x48122ba0, 0x06000307, 0x64000804,   // pl.tk.cy_644 vi.hu.tt_322  nl.de.un_420 no.lg.un_320 
  0x066043a4, 0x6b606507, 0x3f0c2c13, 0x09380d0b,   // ie.vo.de_433 gv.vo.ceb_432  fy.sv.af_665 cs.tk.pl_542 
  0x40600608, 0x0d04380b, 0x55100cee, 0x38630904,   // de.vo.lb_443 tk.fi.cs_542  sv.lt.rw_422 pl.sco.tk_332 
  0x1800380d, 0x0c2c6308, 0x121f3810, 0x0651fe0b,   // tk.ga.un_540 sco.fy.sv_443  tk.cy.hu_642 tlh.kl.de_542 
  // [18500]
  0x30514d09, 0x04020c04, 0x5c1c13ee, 0x630c515a,   // aa.kl.uz_444 sv.da.fi_332  bh.mr.sa_422 kl.sv.sco_553 
  0x30103505, 0x34123d0e, 0x65001802, 0x3600fc09,   // tg.be.uz_333 ku.ur.ps_555  ga.gv.un_220 zzp.gn.un_440 
  0x130457ee, 0x0200610d, 0x215822a0, 0x376301a0,   // na.fi.et_422 za.da.un_540  oc.om.jw_322 en.sco.st_322 
  0x65576304, 0x3c1823ee, 0x39003802, 0x605301a4,   // sco.na.gv_332 ky.ar.ug_422  tk.br.un_220 en.ht.vo_433 
  // [18510]
  0x3c001821, 0x1d4f3b0c, 0x1b2a4304, 0x0a04080c,   // ar.ug.un_860 so.bi.la_543  ie.mt.tr_332 uk.ru.mk_543 
  0x11002c05, 0x070a30af, 0x17290307, 0x520c0502,   // fy.ro.un_330 uz.mk.bg_655  nl.sl.sr_432 fr.sv.ha_222 
  0x16000c04, 0x21283b12, 0xfc4a30a7, 0xfe002507,   // sv.hr.un_320 ks.sd.fa_654  uz.yo.zzp_532 eu.tlh.un_420 
  0x3d003c05, 0x20480dee, 0x32265704, 0x07003204,   // ug.ku.un_330 cs.tt.sq_422  na.ia.bs_332 bs.it.un_320 
  // [18520]
  0x11292d07, 0x59365bad, 0x07420d04, 0x12fc280c,   // sk.sl.ro_432 sg.gn.rn_643  cs.co.it_332 sw.zzp.hu_543 
  0x254823ad, 0x124c050c, 0x0d210504, 0x5800130c,   // ky.tt.mn_643 fr.wo.hu_543  fr.jw.cs_332 et.om.un_530 
  0x13006707, 0x30315205, 0x230a175a, 0x4c4305ad,   // ak.et.un_420 ha.az.uz_333  sr.mk.ky_553 fr.ie.wo_643 
  0x220523a0, 0x55005007, 0x050b23a0, 0x3b483002,   // ca.fr.oc_322 fj.rw.un_420  ca.es.fr_322 uz.tt.so_222 
  // [18530]
  0x475b6755, 0x531331a0, 0x49005719, 0x36111505,   // ak.sg.sn_442 az.et.ht_322  na.to.un_750 un.ro.ab_333 
  0x6500fe2a, 0x1d00300c, 0x63650112, 0x65005711,   // tlh.gv.un_970 uz.la.un_530  en.gv.sco_654 na.gv.un_630 
  0x3bfe65ec, 0x3b006523, 0x1f002c0c, 0x27002202,   // gv.tlh.so_644 gv.so.un_880  fy.cy.un_530 oc.gd.un_220 
  0x3b2e40a0, 0x76004c05, 0x4d3b650c, 0x28183c04,   // lb.fo.so_322 wo.crs.un_330  gv.so.aa_543 ug.ar.sd_332 
  // [18540]
  0x653b01a0, 0x655b3ba4, 0x30481b08, 0x766960a4,   // en.so.gv_322 so.sg.gv_433  tr.tt.uz_443 vo.mfe.crs_433 
  0x4c656307, 0x433b65ec, 0x6965760d, 0x3b1d65a9,   // sco.gv.wo_432 gv.so.ie_644  crs.gv.mfe_554 gv.la.so_544 
  0x76696508, 0xfe4d3b0d, 0x08351002, 0x0a3615a0,   // gv.mfe.crs_443 so.aa.tlh_554  be.tg.uk_222 un.ab.mk_322 
  0x23443502, 0x06001d05, 0x3b0f58a0, 0x4c5864ec,   // tg.kk.ky_222 la.de.un_330  om.lv.so_322 lg.om.wo_644 
  // [18550]
  0x27002b02, 0x3b004d09, 0x150415ad, 0x641d3ba4,   // vi.gd.un_220 aa.so.un_440  un.ru.un_643 so.la.lg_433 
  0x1a003204, 0x1536080c, 0x291632a7, 0x0c041205,   // bs.tl.un_320 uk.ab.un_543  bs.hr.sl_532 hu.fi.sv_333 
  0x3b584d05, 0x041260ad, 0x5b00602b, 0x0e133907,   // aa.om.so_333 vo.hu.fi_643  vo.sg.un_980 br.et.is_432 
  0x043230a7, 0x0c001213, 0x581e1b07, 0x0c33510c,   // uz.bs.fi_532 hu.sv.un_650  tr.ms.om_432 kl.nn.sv_543 
  // [18560]
  0x043842a4, 0x183963af, 0x4a006028, 0x11196507,   // co.tk.fi_433 sco.br.ga_655  vo.yo.un_950 gv.gl.ro_432 
  0x38101b55, 0x5c1b38ac, 0x132402ee, 0x630e2caf,   // tr.lt.tk_442 tk.tr.sa_632  da.eo.et_422 fy.is.sco_655 
  0x42583ea9, 0x3b385808, 0x19fe0aad, 0x384806a0,   // rm.om.co_544 om.tk.so_443  pt.tlh.gl_643 de.tt.tk_322 
  0x31303ba9, 0x0400602a, 0x30153c11, 0x120c6011,   // so.uz.az_544 vo.fi.un_970  ug.uz.un_630 vo.sv.hu_653 
  // [18570]
  0x3c382512, 0x0400120e, 0x2e001e08, 0x211c1eec,   // mn.tk.ug_654 hu.fi.un_550  ms.fo.un_430 ms.id.jw_644 
  0x13003e09, 0x432622a7, 0xfe3031a4, 0x651b3112,   // rm.et.un_440 oc.ia.ie_532  az.uz.tlh_433 az.tr.gv_654 
  0x481e1c12, 0x06003f0c, 0x0c00790c, 0x20005c14,   // id.ms.tt_654 af.de.un_530  war.sv.un_530 sa.sq.un_660 
  0xfc3602ad, 0x0c004505, 0x40006521, 0x1b114805,   // da.gn.zzp_643 ln.sv.un_330  gv.lb.un_860 tt.ro.tr_333 
  // [18580]
  0x23190a11, 0x0236fcad, 0x35480402, 0x09004504,   // pt.gl.ca_653 zzp.gn.da_643  ru.tt.tg_222 ln.pl.un_320 
  0x18205c05, 0x302062af, 0x652b3502, 0x4830350c,   // sa.sq.ga_333 kha.sq.uz_655  zu.vi.gv_222 tg.uz.tt_543 
  0x5500200b, 0x686b1d0c, 0x3530380e, 0x02471905,   // sq.rw.un_520 la.ceb.ig_543  tk.uz.tg_555 gl.sn.da_333 
  0x444808a0, 0x1f002b10, 0x35482313, 0x28213402,   // uk.tt.kk_322 vi.cy.un_620  ky.tt.tg_665 ps.fa.sd_222 
  // [18590]
  0x391940a7, 0x3048150c, 0x3e00041a, 0x3e001021,   // lb.gl.br_532 un.tt.uz_543  fi.rm.un_760 lt.rm.un_860 
  0x0e5e5812, 0x01630204, 0x0700041a, 0x050902a6,   // om.ts.is_654 da.sco.en_332  fi.it.un_760 da.pl.fr_521 
  0x04003e13, 0x3e2f42ad, 0x044b1004, 0x0118010c,   // rm.fi.un_650 co.su.rm_643  lt.mi.fi_332 en.ga.en_543 
  0x25006512, 0x07000421, 0x0b3e420c, 0x3e00042a,   // gv.eu.un_640 fi.it.un_860  co.rm.es_543 fi.rm.un_970 
  // [185a0]
  0x3800201b, 0x472f1d11, 0x0263010b, 0x4760520c,   // sq.tk.un_770 la.su.sn_653  en.sco.da_542 ha.vo.sn_543 
  0x37002521, 0x124d05af, 0x52004804, 0x430105a0,   // mn.ba.un_860 fr.aa.hu_655  tt.ha.un_320 fr.en.ie_322 
  0x524a20a4, 0x2f211b0b, 0x2e022fad, 0x0f450d07,   // sq.yo.ha_433 tr.jw.su_542  su.da.fo_643 cs.ln.lv_432 
  0x1b004a04, 0x5830feee, 0x5e247805, 0x05004c0d,   // yo.tr.un_320 tlh.uz.om_422  ve.eo.ts_333 wo.fr.un_540 
  // [185b0]
  0x595506a4, 0x5220130c, 0x0e00040b, 0x280279a9,   // de.rw.rn_433 et.sq.ha_543  fi.is.un_520 war.da.sw_544 
  0x0b4c050c, 0x05003609, 0x65630109, 0x0d004a02,   // fr.wo.es_543 gn.fr.un_440  en.sco.gv_444 yo.cs.un_220 
  0x054c0da4, 0x070a3c0e, 0x1708230d, 0x0d2d4da7,   // cs.wo.fr_433 ug.mk.bg_555  ky.uk.sr_554 aa.sk.cs_532 
  0x6500110c, 0x0d39050b, 0x2d0d4d0e, 0x172d0da4,   // ro.gv.un_530 fr.br.cs_542  aa.cs.sk_555 cs.sk.sr_433 
  // [185c0]
  0x18213c0c, 0x32003108, 0x153c25af, 0x04003009,   // ug.fa.ar_543 az.bs.un_430  mn.ug.un_655 uz.ru.un_440 
  0x35253055, 0x5a6a33af, 0x48300907, 0x211046ee,   // uz.mn.tg_442 nn.haw.sm_655  pl.uz.tt_432 qu.lt.jw_422 
  0x4b000208, 0x56004f07, 0x1d130402, 0x32000905,   // da.mi.un_430 bi.mg.un_420  fi.et.la_222 pl.bs.un_330 
  0x0e120404, 0x30092904, 0x022046ec, 0x5813040b,   // fi.hu.is_332 sl.pl.uz_332  qu.sq.da_644 fi.et.om_542 
  // [185d0]
  0x38102007, 0x44002318, 0x1834210d, 0x2d0d2b02,   // sq.lt.tk_432 ky.kk.un_740  fa.ps.ar_554 vi.cs.sk_222 
  0x0e000413, 0x534c61ad, 0x2c28fca0, 0x18001c14,   // fi.is.un_650 za.wo.ht_643  zzp.sw.fy_322 mr.ar.un_660 
  0x352308a7, 0x0d2b2e07, 0x04000e12, 0x024d5811,   // uk.ky.tg_532 fo.vi.cs_432  is.fi.un_640 om.aa.da_653 
  0x0f3b13a7, 0x440704a4, 0x73fc1b07, 0x3b4c680c,   // et.so.lv_532 ru.bg.kk_433  tr.zzp.ny_432 ig.wo.so_543 
  // [185e0]
  0x651d1f0c, 0x65021fa0, 0x21583b0c, 0x100807ec,   // cy.la.gv_543 cy.da.gv_322  so.om.jw_543 bg.uk.be_644 
  0x1300580d, 0x48381b0b, 0x48381ba0, 0x4c0413ad,   // om.et.un_540 tr.tk.tt_542  tr.tk.tt_322 et.fi.wo_643 
  0x13733b05, 0x4d041308, 0x481b38a6, 0x13002c12,   // so.ny.et_333 et.fi.aa_443  tk.tr.tt_521 fy.et.un_640 
  0x2e1c2fa0, 0x3600010d, 0x17153005, 0x0a5cfeee,   // su.id.fo_322 en.gn.un_540  uz.sr.un_330 tlh.sa.pt_422 
  // [185f0]
  0x07060212, 0x03423fa4, 0x343f03af, 0x121338ee,   // da.de.it_654 af.co.nl_433  nl.af.xh_655 tk.et.hu_422 
  0x632546ad, 0x33000902, 0x393f2c07, 0x15006304,   // qu.eu.sco_643 pl.nn.un_220  fy.af.br_432 sco.un.un_320 
  0x31481b04, 0x111b31a0, 0x39765312, 0x07040805,   // tr.tt.az_332 az.tr.ro_322  ht.crs.br_654 uk.ru.bg_333 
  0x033f53a0, 0x53002808, 0x071715a4, 0x07004808,   // ht.af.nl_322 sw.ht.un_430  un.sr.bg_433 tt.bg.un_430 
  // [18600]
  0x1b004212, 0x3800120e, 0x0f5e4207, 0x532f02ad,   // co.tr.un_640 hu.tk.un_550  co.ts.lv_432 da.su.ht_643 
  0x1a0201a0, 0x23380aec, 0x48002a19, 0x40001102,   // en.da.tl_322 mk.tk.ky_644  mt.tt.un_750 ro.lb.un_220 
  0x0f63010b, 0x152a0212, 0x20001819, 0x223943a4,   // en.sco.lv_542 da.mt.un_654  ga.sq.un_750 ie.br.oc_433 
  0x183d2102, 0x79630107, 0x0a2c11ee, 0x34233ca0,   // fa.ku.ar_222 en.sco.war_432  ro.fy.pt_422 ug.ky.ps_322 
  // [18610]
  0x2d1263a0, 0x0e6365a0, 0x01005202, 0x27405bee,   // sco.hu.sk_322 gv.sco.is_322  ha.en.un_220 sg.lb.gd_422 
  0x11000207, 0x10022060, 0x1b3831ec, 0x2e000e35,   // da.ro.un_420 sq.da.lt_664  az.tk.tr_644 is.fo.un_A90 
  0x30005722, 0x19000102, 0x28002a02, 0x102063a4,   // na.uz.un_870 en.gl.un_220  mt.sw.un_220 sco.sq.lt_433 
  0xfc5e57ad, 0x5539200c, 0x64005805, 0x58005122,   // na.ts.zzp_643 sq.br.rw_543  om.lg.un_330 kl.om.un_870 
  // [18620]
  0x25100aa0, 0x51586404, 0x30350aaf, 0x5a645807,   // mk.be.mn_322 lg.om.kl_332  mk.tg.uz_655 om.lg.sm_432 
  0x584d115a, 0x48373ca0, 0x1e4e25ad, 0x2529580c,   // ro.aa.om_553 ug.ba.tt_322  eu.ay.ms_643 om.sl.eu_543 
  0x4c3b52af, 0x51001d07, 0x09002508, 0x1c003204,   // ha.so.wo_655 la.kl.un_420  eu.pl.un_430 bs.id.un_320 
  0x09251b07, 0x3b312508, 0x3f0410a0, 0x1e1c0909,   // tr.eu.pl_432 eu.az.so_443  lt.fi.af_322 pl.id.ms_444 
  // [18630]
  0x1215fc04, 0x0c1e1c5a, 0x0c0610a0, 0x30004611,   // zzp.hu.un_320 id.ms.sv_553  lt.de.sv_322 qu.uz.un_630 
  0x3d303412, 0x2f2648ad, 0x6558180c, 0x04150a05,   // ps.uz.ku_654 tt.ia.su_643  ga.om.gv_543 mk.ru.un_330 
  0x32175cee, 0x03fc1509, 0x460724a0, 0x5c321614,   // sa.sr.bs_422 un.zzp.nl_444  eo.it.qu_322 hr.bs.sa_666 
  0x120c2112, 0x334838a4, 0x173844ad, 0x301515a4,   // jw.sv.hu_654 tk.tt.nn_433  kk.tk.sr_643 un.uz.un_430 
  // [18640]
  0xfe15020c, 0x11001b1a, 0x211830ec, 0x11311ba6,   // da.tlh.un_530 tr.ro.un_760  uz.ar.fa_644 tr.az.ro_521 
  0x3b5b1ead, 0x03070aa0, 0x28001004, 0x100356a9,   // ms.sg.so_643 pt.it.nl_322  lt.sw.un_320 mg.nl.lt_544 
  0x5c00271a, 0x11001b13, 0x47007323, 0x03002507,   // gd.sa.un_760 tr.ro.un_650  ny.sn.un_880 eu.nl.un_420 
  0x3b2728ad, 0x311b1155, 0x78095da9, 0x1000670e,   // sw.gd.so_643 ro.tr.az_442  ss.pl.ve_544 ak.lt.un_550 
  // [18650]
  0x272a1112, 0x46005302, 0x283b5208, 0x1100150d,   // ro.mt.gd_654 ht.qu.un_220  ha.so.sw_443 un.ro.un_540 
  0x2c420755, 0x670e2e07, 0x060e6707, 0x7906250c,   // it.co.fy_442 fo.is.ak_432  ak.is.de_432 eu.de.war_543 
  0x2d3b30ad, 0x35001605, 0x451c4a04, 0x5c5325a4,   // uz.so.sk_643 hr.zu.un_330  yo.id.ln_332 eu.ht.sa_433 
  0x303b02a0, 0x52024a04, 0x171138af, 0x4c0d2dad,   // da.so.uz_322 yo.da.ha_332  tk.ro.sr_655 sk.cs.wo_643 
  // [18660]
  0x032b16a0, 0x42004902, 0x052d0d13, 0x1000fc12,   // hr.vi.nl_322 to.co.un_220  cs.sk.fr_665 zzp.lt.un_640 
  0x48311bac, 0x212d0d0e, 0x424c05ec, 0x6e00fe12,   // tr.az.tt_632 cs.sk.jw_555  fr.wo.co_644 tlh.hmn.un_640 
  0x11170408, 0x02003502, 0x44361507, 0x395361a0,   // ru.sr.ro_443 zu.da.un_220  un.ab.kk_432 za.ht.br_322 
  0x052d0d11, 0x79001819, 0x1e1c2f08, 0x1c396507,   // cs.sk.fr_653 ga.war.un_750  su.id.ms_443 gv.br.id_432 
  // [18670]
  0x31392408, 0x0f1613a7, 0x113918a9, 0x2c210304,   // eo.br.az_443 et.hr.lv_532  ga.br.ro_544 nl.jw.fy_332 
  0x39686aad, 0x1e315da0, 0x39181dec, 0x604301a4,   // haw.ig.br_643 ss.az.ms_322  la.ga.br_644 en.ie.vo_433 
  0x694c2f11, 0x2f001b1a, 0x0e0b19a7, 0x1a793f07,   // su.wo.mfe_653 tr.su.un_760  gl.es.is_532 af.war.tl_432 
  0x1b20330c, 0x76264b0c, 0x6a00600b, 0x62514d13,   // nn.sq.tr_543 mi.ia.crs_543  vo.haw.un_520 aa.kl.kha_665 
  // [18680]
  0x1723485a, 0x3b4c4daf, 0x0f1710a9, 0x23003412,   // tt.ky.sr_553 aa.wo.so_655  lt.sr.lv_544 ps.ky.un_640 
  0x343b120c, 0x114d58a4, 0x64002902, 0x4412180e,   // ur.ks.ps_543 om.aa.ro_433  sl.lg.un_220 ar.ur.kk_555 
  0x3800110b, 0x62006119, 0x0e1b515a, 0x111e6b0c,   // ro.tk.un_520 za.kha.un_750  kl.tr.is_553 ceb.ms.ro_543 
  0x3004150c, 0x6a3e6bad, 0x4b6a78a9, 0x5f24370c,   // un.ru.uz_543 ceb.rm.haw_643  ve.haw.mi_544 st.eo.tn_543 
  // [18690]
  0x2400520d, 0x07002408, 0x1a5247a9, 0x2f253e0c,   // ha.eo.un_540 eo.it.un_430  sn.ha.tl_544 rm.eu.su_543 
  0x595503ee, 0x42116aa9, 0x3e136a0b, 0x55005719,   // nl.rw.rn_422 haw.ro.co_544  haw.et.rm_542 na.rw.un_750 
  0x2451520c, 0x69006313, 0x6b6a5204, 0x25001a02,   // ha.kl.eo_543 sco.mfe.un_650  ha.haw.ceb_332 tl.eu.un_220 
  0x55005614, 0x68574faf, 0x360b3b05, 0x3e1262af,   // mg.rw.un_660 bi.na.ig_655  so.es.gn_333 kha.hu.rm_655 
  // [186a0]
  0x5e00691a, 0x55000b02, 0x2128680c, 0x643478ad,   // mfe.ts.un_760 es.rw.un_220  ig.sw.jw_543 ve.xh.lg_643 
  0x24556809, 0x11002521, 0x2f1a4e0c, 0x071902ad,   // ig.rw.eo_444 eu.ro.un_860  ay.tl.su_543 da.gl.it_643 
  0x2c09030b, 0x5d50640c, 0x52216705, 0x0a0408a6,   // nl.pl.fy_542 lg.fj.ss_543  ak.jw.ha_333 uk.ru.mk_521 
  0x25004623, 0x5100522a, 0x50000722, 0x51464e12,   // qu.eu.un_880 ha.kl.un_970  it.fj.un_870 ay.qu.kl_654 
  // [186b0]
  0x4a596812, 0x49005019, 0x5a001314, 0x4b7901a0,   // ig.rn.yo_654 fj.to.un_750  et.sm.un_660 en.war.mi_322 
  0x47005712, 0x5a003b13, 0x042713a0, 0x555b47ec,   // na.sn.un_640 so.sm.un_650  et.gd.fi_322 sn.sg.rw_644 
  0x4b68550c, 0x4d00500e, 0x303548a9, 0x253035ac,   // rw.ig.mi_543 fj.aa.un_550  tt.tg.uz_544 tg.uz.mn_632 
  0x04001802, 0x023427a4, 0x4c0549ad, 0x1536040d,   // ga.fi.un_220 gd.xh.da_433  to.fr.wo_643 ru.ab.un_554 
  // [186c0]
  0x18464e11, 0x0e180dee, 0x18073e07, 0x182d0d09,   // ay.qu.ga_653 cs.ga.is_422  rm.it.ga_432 cs.sk.ga_444 
  0x38000721, 0x0b2205a7, 0x5a274908, 0x38303713,   // bg.tk.un_860 fr.oc.es_532  to.gd.sm_443 ba.uz.tk_665 
  0x18213ca7, 0x27460955, 0x42450512, 0x024c05ee,   // ug.fa.ar_532 pl.qu.gd_442  fr.ln.co_654 fr.wo.da_422 
  0x49004c0c, 0x4c050ba0, 0x100a0712, 0x0c3613a7,   // wo.to.un_530 es.fr.wo_322  bg.mk.be_654 et.gn.sv_532 
  // [186d0]
  0x0727510b, 0x290d15a4, 0x4d46fcec, 0xfc3f2ca0,   // kl.gd.it_542 un.cs.sl_433  zzp.qu.aa_644 fy.af.zzp_322 
  0x4623190c, 0x3bfc010c, 0x1afc6b60, 0x3105300c,   // gl.ca.qu_543 en.zzp.so_543  ceb.zzp.tl_664 uz.fr.az_543 
  0x51003909, 0x1a3bfcad, 0x1f171602, 0x2d0d0ea9,   // br.kl.un_440 zzp.so.tl_643  hr.sr.cy_222 is.cs.sk_544 
  0x4c00fc11, 0x2d000e08, 0x3bfc0112, 0x3b00fc34,   // zzp.wo.un_630 is.sk.un_430  en.zzp.so_654 zzp.so.un_A80 
  // [186e0]
  0x2d0e0da4, 0x53fc5612, 0x48004504, 0x3b00fc2c,   // cs.is.sk_433 mg.zzp.ht_654  ln.tt.un_320 zzp.so.un_990 
  0x1a3bfc12, 0x5500570b, 0x3bfc0111, 0x7946fcec,   // zzp.so.tl_654 na.rw.un_520  en.zzp.so_653 zzp.qu.war_644 
  0x3bfc46af, 0xfc012604, 0x16021304, 0x12052da0,   // qu.zzp.so_655 ia.en.zzp_332  et.da.hr_332 sk.fr.hu_322 
  0x281e52a4, 0x1c4c2fa0, 0x55006112, 0x04006713,   // ha.ms.sw_433 su.wo.id_322  za.rw.un_640 ak.fi.un_650 
  // [186f0]
  0x5f002105, 0x04005502, 0xfc012f12, 0x25006413,   // jw.tn.un_330 rw.fi.un_220  su.en.zzp_654 lg.eu.un_650 
  0x5901fc08, 0x4c000d08, 0x55005e1a, 0x56005719,   // zzp.en.rn_443 cs.wo.un_430  ts.rw.un_760 na.mg.un_750 
  0x084404a0, 0x78024ca4, 0x4c5b58a7, 0x502f4b0c,   // ru.kk.uk_322 wo.da.ve_433  om.sg.wo_532 mi.su.fj_543 
  0x5e000407, 0x30505808, 0x48505607, 0x73554c04,   // fi.ts.un_420 om.fj.uz_443  mg.fj.tt_432 wo.rw.ny_332 
  // [18700]
  0x655501a0, 0x5c330805, 0x35071504, 0x12231807,   // en.rw.gv_322 no.nn.sa_333  un.bg.tg_332 ar.ky.ur_432 
  0x151708ad, 0x23004e11, 0x212f5c07, 0x1200450e,   // uk.sr.un_643 ay.ca.un_630  sa.su.jw_432 ln.hu.un_550 
  0x0c510210, 0x54485c12, 0x17101108, 0x3b3c210c,   // da.kl.sv_642 sa.tt.ik_654  ro.be.sr_443 fa.ug.ks_543 
  0x15154808, 0x233025ec, 0x301b2008, 0x380430a0,   // tt.un.un_430 mn.uz.ky_644  sq.tr.uz_443 uz.fi.tk_322 
  // [18710]
  0x5d024aa7, 0x4f002a08, 0x18002d02, 0x21233411,   // yo.da.ss_532 mt.bi.un_430  sk.ga.un_220 ps.ky.fa_653 
  0x321603ec, 0x31301ba9, 0x31383013, 0x054012a4,   // nl.hr.bs_644 tr.uz.az_544  uz.tk.az_665 hu.lb.fr_433 
  0x38313007, 0x0e002a0c, 0x790719a0, 0x1e1b5302,   // uz.az.tk_432 mt.is.un_530  gl.it.war_322 ht.tr.ms_222 
  0x25040c0b, 0x1c0143a0, 0x793724a4, 0x08002d05,   // sv.fi.eu_542 ie.en.id_322  eo.st.war_433 sk.no.un_330 
  // [18720]
  0x150835a7, 0x1b301704, 0x345d4a08, 0x213b1212,   // tg.uk.un_532 sr.uz.tr_332  yo.ss.xh_443 ur.ks.fa_654 
  0x38003e08, 0x2f1815a0, 0x17006704, 0x5f00632b,   // rm.tk.un_430 un.ga.su_322  ak.sr.un_320 sco.tn.un_980 
  0x4311fc12, 0x5300670c, 0x420c2a04, 0x4b006807,   // zzp.ro.ie_654 ak.ht.un_530  mt.sv.co_332 ig.mi.un_420 
  0x2d3f0da4, 0x3e422a05, 0x190a0da0, 0x256a6708,   // cs.af.sk_433 mt.co.rm_333  cs.pt.gl_322 ak.haw.eu_443 
  // [18730]
  0x18344402, 0x49006821, 0x21303da0, 0x18276eaf,   // kk.ps.ar_222 ig.to.un_860  ku.uz.fa_322 hmn.gd.ga_655 
  0x475f25af, 0x301d5802, 0x73475dec, 0x1c460204,   // eu.tn.sn_655 om.la.uz_222  ss.sn.ny_644 da.qu.id_332 
  0x785e4714, 0x34375da4, 0x6bfc010b, 0x3f525155,   // sn.ts.ve_666 ss.st.xh_433  en.zzp.ceb_542 kl.ha.af_442 
  0x5c574f55, 0x5d573705, 0x5537520b, 0x286473a4,   // bi.na.sa_442 st.na.ss_333  ha.st.rw_542 ny.lg.sw_433 
  // [18740]
  0x326e2b04, 0x47287304, 0x47734c0c, 0x06fc6904,   // vi.hmn.bs_332 ny.sw.sn_332  wo.ny.sn_543 mfe.zzp.de_332 
  0x2b4c6e0c, 0x4d004019, 0x55524705, 0x3308fc0c,   // hmn.wo.vi_543 lb.aa.un_750  sn.ha.rw_333 zzp.no.nn_543 
  0xfe4e3e04, 0x0c0437a4, 0x6e006b04, 0x3f000c07,   // rm.ay.tlh_332 st.fi.sv_433  ceb.hmn.un_320 sv.af.un_420 
  0x524c5e0c, 0x2d000205, 0x3473780c, 0x02fc3baf,   // ts.wo.ha_543 da.sk.un_330  ve.ny.xh_543 so.zzp.da_655 
  // [18750]
  0x0f000402, 0x033f5ca4, 0x045c2504, 0x27501807,   // fi.lv.un_220 sa.af.nl_433  eu.sa.fi_332 ga.fj.gd_432 
  0x03fc2708, 0x651801a0, 0x1d150ca4, 0x1dfe010c,   // gd.zzp.nl_443 en.ga.gv_322  sv.la.un_430 en.tlh.la_543 
  0x632d0d08, 0x673437a9, 0x30000221, 0x201801af,   // cs.sk.sco_443 st.xh.ak_544  da.uz.un_860 en.ga.sq_655 
  0x03400504, 0x04343507, 0x0a0b0da4, 0x3d123b5a,   // fr.lb.nl_332 zu.xh.fi_432  cs.es.pt_433 ks.ur.ku_553 
  // [18760]
  0x4404250d, 0x4b00200c, 0x505a6a0b, 0x5a1a6a07,   // mn.ru.kk_554 sq.mi.un_530  haw.sm.fj_542 haw.tl.sm_432 
  0x274f6a0c, 0x1a026a07, 0x0d1c13af, 0x0408370c,   // haw.bi.gd_543 haw.da.tl_432  bh.mr.ne_655 ba.uk.ru_543 
  0x5a000214, 0x36685712, 0x0a440755, 0x113e18ee,   // da.sm.un_660 na.ig.gn_654  bg.kk.mk_442 ga.rm.ro_422 
  0x3800680c, 0x3b002302, 0x0300400e, 0x08006907,   // ig.tk.un_530 ca.so.un_220  lb.nl.un_550 mfe.no.un_420 
  // [18770]
  0x3e02230c, 0x1b001e07, 0x5c385507, 0x22fc39a4,   // ca.da.rm_543 ms.tr.un_420  rw.tk.sa_432 br.zzp.oc_433 
  0x4c385502, 0x385c5504, 0x080430a4, 0x48005b1d,   // rw.tk.wo_222 rw.sa.tk_332  uz.ru.uk_433 sg.tt.un_820 
  0x253048a4, 0x222301ee, 0x3b30190d, 0x7347640c,   // tt.uz.mn_433 en.ca.oc_422  gl.uz.so_554 lg.sn.ny_543 
  0x64007323, 0x0347280d, 0x1f124fee, 0x0400470d,   // ny.lg.un_880 sw.sn.nl_554  bi.hu.cy_422 sn.fi.un_540 
  // [18780]
  0x12002702, 0x63000205, 0x30351514, 0x595502ec,   // gd.hu.un_220 da.sco.un_330  un.tg.uz_666 da.rw.rn_644 
  0x392a2402, 0x647355a9, 0x3515360d, 0x233e2205,   // eo.mt.br_222 rw.ny.lg_544  ab.tg.un_540 oc.rm.ca_333 
  0x793b0207, 0x475f750c, 0x47000a07, 0x182757ac,   // da.so.war_432 nso.tn.sn_543  pt.sn.un_420 na.gd.ga_632 
  0x4755640c, 0x022a01a0, 0x101117af, 0x5c025505,   // lg.rw.sn_543 en.mt.da_322  sr.ro.be_655 rw.da.sa_333 
  // [18790]
  0x30211204, 0x0e001f04, 0x2e1f33a0, 0x73642404,   // ur.fa.uz_332 cy.is.un_320  nn.cy.fo_322 eo.lg.ny_332 
  0x6400471b, 0x733b4708, 0x755f4b0d, 0x0b7946ee,   // sn.lg.un_770 sn.so.ny_443  mi.tn.nso_554 qu.war.es_422 
  0x5f64470b, 0x13004f07, 0x330c38ee, 0x171625ee,   // sn.lg.tn_542 bi.et.un_420  tk.sv.nn_422 eu.hr.sr_422 
  0x021e1c02, 0x375f7560, 0x09002b04, 0x164a5707,   // id.ms.da_222 nso.tn.st_664  vi.pl.un_320 na.yo.hr_432 
  // [187a0]
  0x21004a07, 0x4c002014, 0x1f190a09, 0x4435300c,   // yo.jw.un_420 sq.wo.un_660  pt.gl.cy_444 uz.tg.kk_543 
  0x39685704, 0x7915290c, 0x2b001b0d, 0x27071f0c,   // na.ig.br_332 sl.war.un_530  tr.vi.un_540 cy.it.gd_543 
  0x15003e07, 0x47351202, 0x0d00210d, 0x2d210d55,   // rm.un.un_420 hu.zu.sn_222  jw.cs.un_540 cs.jw.sk_442 
  0x3d4423a4, 0x03403ea0, 0x13023f0c, 0x033e3f04,   // ky.kk.ku_433 rm.lb.nl_322  af.da.et_543 af.rm.nl_332 
  // [187b0]
  0x0e3308a4, 0x4418280c, 0x10371507, 0x332e670b,   // no.nn.is_433 sd.ar.kk_543  un.ba.be_432 ak.fo.nn_542 
  0x0e007613, 0x32171611, 0x212f04a7, 0x074204a4,   // crs.is.un_650 hr.sr.bs_653  fi.su.jw_532 fi.co.it_433 
  0x4838150d, 0x65090204, 0x02270407, 0x5c000408,   // un.tk.tt_554 da.pl.gv_332  fi.gd.da_432 fi.sa.un_430 
  0x2a045ca4, 0x2310150d, 0x042a0713, 0x65007608,   // sa.fi.mt_433 un.be.ky_554  it.mt.fi_665 crs.gv.un_430 
  // [187c0]
  0x30000908, 0x05005c08, 0x5c0e04ec, 0x584d120c,   // pl.uz.un_430 sa.fr.un_430  fi.is.sa_644 hu.aa.om_543 
  0x49515611, 0x2a041205, 0x070817ad, 0x17153004,   // mg.kl.to_653 hu.fi.mt_333  sr.uk.bg_643 uz.sr.un_320 
  0x2336480c, 0x42553e07, 0x1300580c, 0x13001817,   // tt.ab.ky_543 rm.rw.co_432  om.et.un_530 ga.et.un_730 
  0x2d2009a9, 0x170a35ad, 0x4a3655ee, 0x0415070c,   // pl.sq.sk_544 tg.mk.sr_643  rw.gn.yo_422 bg.ru.un_530 
  // [187d0]
  0x3b4c5855, 0x67124508, 0x67353414, 0x674a45a9,   // om.wo.so_442 ln.hu.ak_443  xh.zu.ak_666 ln.yo.ak_544 
  0x30083807, 0x13044da0, 0x0a002d07, 0x090e39ee,   // tk.uk.uz_432 aa.fi.et_322  sk.pt.un_420 br.is.pl_422 
  0x0c006021, 0x1d003507, 0x28182102, 0x1d002a09,   // vo.sv.un_860 zu.la.un_420  fa.ar.sd_222 mt.la.un_440 
  0x56005d05, 0x150e100c, 0x35170a04, 0x04486013,   // ss.mg.un_330 lt.is.un_543  mk.sr.tg_332 vo.tt.fi_665 
  // [187e0]
  0x1f003709, 0x63006a07, 0x4b000c07, 0x2a4c070c,   // st.cy.un_440 haw.sco.un_420  sv.mi.un_420 it.wo.mt_543 
  0x0e2e570d, 0x0200052b, 0x170408ad, 0x2f2d0d08,   // na.fo.is_554 fr.da.un_980  uk.ru.sr_643 cs.sk.su_443 
  0x353408a4, 0xfc00330c, 0x51000a04, 0x05fe4605,   // no.xh.zu_433 nn.zzp.un_530  pt.kl.un_320 qu.tlh.fr_333 
  0x5f73020c, 0x30480aa0, 0x2f05fcad, 0x0413050c,   // da.ny.tn_543 mk.tt.uz_322  zzp.fr.su_643 fr.et.fi_543 
  // [187f0]
  0x733256ee, 0x24000d13, 0x50002d04, 0x69761aa4,   // mg.bs.ny_422 cs.eo.un_650  sk.fj.un_320 tl.crs.mfe_433 
  0x04004c04, 0x67000108, 0x2c053fa4, 0x62000d08,   // wo.fi.un_320 en.ak.un_430  af.fr.fy_433 cs.kha.un_430 
  0xfe005f09, 0x1600300c, 0x3e050112, 0x302e5f0c,   // tn.tlh.un_440 uz.hr.un_530  en.fr.rm_654 tn.fo.uz_543 
  0x02fc0ba4, 0x0a223ba9, 0x0700752a, 0x12fefca7,   // es.zzp.da_433 so.oc.pt_544  nso.it.un_970 zzp.tlh.hu_532 
  
  // [18800]
  0x2e0c0255, 0x233b3004, 0x4630fe07, 0x5737610c,   // da.sv.fo_442 uz.so.ca_332  tlh.uz.qu_432 za.st.na_543 
  0x1230560c, 0x5026430d, 0x2c330807, 0x58003021,   // mg.uz.hu_543 ie.ia.fj_554  no.nn.fy_432 uz.om.un_860 
  0x130562a4, 0x04470da0, 0x594c4513, 0x0250520d,   // kha.fr.et_433 cs.sn.fi_322  ln.wo.rn_665 ha.fj.da_554 
  0x2e350e07, 0x6b005a07, 0x101d2608, 0x13001013,   // is.zu.fo_432 sm.ceb.un_420  ia.la.lt_443 lt.et.un_650 
  // [18810]
  0x1004fca4, 0x123034a4, 0x0c310404, 0x154404ad,   // zzp.fi.lt_433 ps.uz.ur_433  fi.az.sv_332 ru.kk.un_643 
  0x17441004, 0x3421185a, 0x0e542ead, 0x5c002407,   // be.kk.sr_332 ar.fa.ps_553  fo.ik.is_643 eo.sa.un_420 
  0x56005108, 0x383148a6, 0x3e630f04, 0x30153c13,   // kl.mg.un_430 tt.az.tk_521  lv.sco.rm_332 ug.uz.un_650 
  0x0f6323ad, 0x2e331005, 0x33391fee, 0x5e005105,   // ca.sco.lv_643 lt.nn.fo_333  cy.br.nn_422 kl.ts.un_330 
  // [18820]
  0x2e540107, 0x2b003e02, 0x171544ad, 0x4404150b,   // en.ik.fo_432 rm.vi.un_220  kk.sr.un_630 un.ru.kk_542 
  0x65150214, 0x22010fa7, 0x443c300d, 0x100437ad,   // da.gv.un_660 lv.en.oc_532  uz.ug.kk_554 ba.ru.be_643 
  0x350738ee, 0x29103802, 0x1e006308, 0x160c13ad,   // tk.bg.tg_422 tk.lt.sl_222  sco.ms.un_430 et.sv.hr_643 
  0x39006911, 0x13482d07, 0x330e2e05, 0x02033f11,   // mfe.br.un_630 sk.tt.et_432  fo.is.nn_333 af.nl.da_653 
  // [18830]
  0x211c1ea0, 0x3c233009, 0x44102307, 0x10000f23,   // ms.id.jw_322 uz.ky.ug_444  ky.be.kk_432 lv.lt.un_880 
  0x15002305, 0x041338ee, 0x3530070c, 0x5800520e,   // ky.un.un_330 tk.et.fi_422  bg.uz.tg_543 ha.om.un_550 
  0x4a002502, 0x28342114, 0x5b002113, 0x58004d0b,   // eu.yo.un_220 fa.ps.sd_666  jw.sg.un_650 aa.om.un_520 
  0x4c1d24a4, 0x531f6707, 0x02266907, 0x53190a08,   // eo.la.wo_433 ak.cy.ht_432  mfe.ia.da_432 pt.gl.ht_443 
  // [18840]
  0x19500aa6, 0x0400fc02, 0x04004202, 0x08071502,   // pt.fj.gl_521 zzp.fi.un_220  co.fi.un_220 un.bg.uk_222 
  0x64000a04, 0x28644fa0, 0x42001212, 0x2d0d4cee,   // pt.lg.un_320 bi.lg.sw_322  hu.co.un_640 wo.cs.sk_422 
  0x40584d07, 0x2d132905, 0x1d00240c, 0x2d0a0da4,   // aa.om.lb_432 sl.et.sk_333  eo.la.un_530 cs.pt.sk_433 
  0x0a2d190c, 0x27000c07, 0x0f132907, 0x33292d0b,   // gl.sk.pt_543 sv.gd.un_420  sl.et.lv_432 sk.sl.nn_542 
  // [18850]
  0x162467a7, 0x4630fe04, 0x5c001e02, 0x62004f2b,   // ak.eo.hr_532 tlh.uz.qu_332  ms.sa.un_220 bi.kha.un_980 
  0x5c003402, 0x0e34fa60, 0x5e000e0d, 0x1115360c,   // xh.sa.un_220 nr.xh.is_664  is.ts.un_540 ab.ro.un_530 
  0x55004a0e, 0x56255904, 0x340e5e04, 0x03003202,   // yo.rw.un_550 rn.eu.mg_332  ts.is.xh_332 bs.nl.un_220 
  0x33003502, 0x0e003308, 0x2800360b, 0x59005b13,   // zu.nn.un_220 nn.is.un_430  gn.sw.un_520 sg.rn.un_650 
  // [18860]
  0x364a0404, 0x597969ad, 0x175247a7, 0x344768a0,   // fi.yo.gn_332 mfe.war.rn_643  sn.ha.sr_532 ig.sn.xh_322 
  0x46002202, 0x30002007, 0x09001218, 0x185d36ee,   // oc.qu.un_220 sq.uz.un_420  hu.pl.un_740 gn.ss.ga_422 
  0x11001034, 0x0a361705, 0x38353060, 0x5e5d35a9,   // be.ro.un_A80 sr.ab.mk_333  uz.tg.tk_664 zu.ss.ts_544 
  0x23213dad, 0x57061ea4, 0x09fc3fa0, 0x47153505,   // ku.fa.ky_643 ms.de.na_433  af.zzp.pl_322 zu.sn.un_330 
  // [18870]
  0x3b004307, 0x13002b11, 0x5e3578a4, 0x34153fa0,   // ie.so.un_420 vi.et.un_630  ve.zu.ts_433 af.xh.un_320 
  0x0d5c09ad, 0x2a581504, 0x27283207, 0x5f785e08,   // hi.sa.ne_643 un.om.mt_332  bs.sw.gd_432 ts.ve.tn_443 
  0x1d64fca7, 0x34123b13, 0x64fc2808, 0x43353413,   // zzp.lg.la_532 ks.ur.ps_665  sw.zzp.lg_443 xh.zu.ie_665 
  0x5c580107, 0x113848a9, 0x5258510d, 0x351107a4,   // en.om.sa_432 tt.tk.ro_544  kl.om.ha_554 bg.ro.tg_433 
  // [18880]
  0x514d580d, 0x305804a4, 0x04514dad, 0x042c4260,   // om.aa.kl_554 fi.om.uz_433  aa.kl.fi_643 co.fy.fi_664 
  0x762c0107, 0x60633e0e, 0x58024da7, 0x424d5c0c,   // en.fy.crs_432 rm.sco.vo_555  aa.da.om_532 sa.aa.co_543 
  0x35022805, 0x0711150c, 0x48580307, 0x58fe4d11,   // sw.da.zu_333 un.ro.bg_543  nl.om.tt_432 aa.tlh.om_653 
  0x5c51040c, 0x2239050c, 0x2a514da9, 0x07424d13,   // fi.kl.sa_543 fr.br.oc_543  aa.kl.mt_544 aa.co.it_665 
  // [18890]
  0x25002a07, 0x514d0409, 0x2e004208, 0x51544daf,   // mt.eu.un_420 fi.aa.kl_444  co.fo.un_430 aa.ik.kl_655 
  0x12220504, 0x24003e02, 0x443530af, 0x03000505,   // fr.oc.hu_332 rm.eo.un_220  uz.tg.kk_655 fr.nl.un_330 
  0x105c0f12, 0xfc3058af, 0x02003104, 0x25043604,   // lv.sa.lt_654 om.uz.zzp_655  az.da.un_320 ab.ru.mn_332 
  0x08004019, 0x2c003f20, 0x6e321604, 0x02042c07,   // lb.no.un_750 af.fy.un_850  hr.bs.hmn_332 fy.fi.da_432 
  // [188a0]
  0x4a535904, 0x211c2ba4, 0x091c1e11, 0x1c2b02a6,   // rn.ht.yo_332 vi.id.jw_433  ms.id.pl_653 da.vi.id_521 
  0x3f022c07, 0x35005e05, 0x33002c08, 0x4e2f470c,   // fy.da.af_432 ts.zu.un_330  fy.nn.un_430 sn.su.ay_543 
  0x3646fca4, 0x63005512, 0x644a3404, 0x5e0779ad,   // zzp.qu.gn_433 rw.sco.un_640  xh.yo.lg_332 war.it.ts_643 
  0x211365a0, 0x2c003f14, 0x301504a9, 0x381311ee,   // gv.et.jw_322 af.fy.un_660  ru.uz.un_540 ro.et.tk_422 
  // [188b0]
  0x332c080c, 0x11001002, 0x352c3fad, 0x1300210d,   // no.fy.nn_543 lt.ro.un_220  af.fy.zu_643 jw.et.un_540 
  0xfc000d04, 0x21251308, 0x552d0d02, 0x0700051b,   // cs.zzp.un_320 et.eu.jw_443  cs.sk.rw_222 fr.it.un_770 
  0x381b480d, 0x25080aa7, 0x25380204, 0x48216408,   // tt.tr.tk_554 mk.uk.mn_532  da.tk.eu_332 lg.jw.tt_443 
  0x55001305, 0x52342104, 0x0221570c, 0x13212507,   // et.rw.un_330 jw.xh.ha_332  na.jw.da_543 eu.jw.et_432 
  // [188c0]
  0x161d11a4, 0x481b3814, 0x060c03a0, 0x18190b0c,   // ro.la.hr_433 tk.tr.tt_666  nl.sv.de_322 es.gl.ga_543 
  0x51000221, 0x1707150b, 0x2f4207a4, 0x1b4246a4,   // da.kl.un_860 un.bg.sr_542  it.co.su_433 qu.co.tr_433 
  0x3c4437ec, 0x26001d19, 0x4246300c, 0x1b4630ad,   // ba.kk.ug_644 la.ia.un_750  uz.qu.co_543 uz.qu.tr_643 
  0x2d024204, 0x32110da0, 0x42fc07ee, 0x1b350207,   // co.da.sk_332 cs.ro.bs_322  it.zzp.co_422 da.zu.tr_432 
  // [188d0]
  0x04005a1a, 0x0e004c07, 0x513e5a08, 0x31002213,   // sm.fi.un_760 wo.is.un_420  sm.rm.kl_443 oc.az.un_650 
  0x5d4f6705, 0x2d0d630c, 0x0d00390c, 0x4234350c,   // ak.bi.ss_333 sco.cs.sk_543  br.cs.un_530 zu.xh.co_543 
  0x1b5d30a4, 0x3900020b, 0x092f4607, 0x40392ca0,   // uz.ss.tr_433 da.br.un_520  qu.su.pl_432 fy.br.lb_322 
  0x43005d0d, 0xfc3901a9, 0x39636908, 0x465d0d07,   // ss.ie.un_540 en.br.zzp_544  mfe.sco.br_443 cs.ss.qu_432 
  // [188e0]
  0x190a0d05, 0xfe656308, 0x2f2146a0, 0x6300391a,   // cs.pt.gl_333 sco.gv.tlh_443  qu.jw.su_322 br.sco.un_760 
  0x11395704, 0x3008040e, 0x65392c55, 0x0540010c,   // na.br.ro_332 ru.uk.uz_555  fy.br.gv_442 en.lb.fr_543 
  0x23483060, 0x22054202, 0x48fe2a55, 0x79686b07,   // uz.tt.ky_664 co.fr.oc_222  mt.tlh.tt_442 ceb.ig.war_432 
  0x2e002504, 0x092d02ee, 0x172909a0, 0x51006402,   // eu.fo.un_320 da.sk.pl_422  pl.sl.sr_322 lg.kl.un_220 
  // [188f0]
  0x202615a7, 0x49005004, 0x0e2c06a0, 0x07223607,   // un.ia.sq_532 fj.to.un_320  de.fy.is_322 gn.oc.it_432 
  0x3044350d, 0x63016204, 0x07510e05, 0x2a00540e,   // tg.kk.uz_554 kha.en.sco_332  is.kl.it_333 ik.mt.un_550 
  0x3b005109, 0x2e026b0c, 0x596455a9, 0x1623fcee,   // kl.so.un_440 ceb.da.fo_543  rw.lg.rn_544 zzp.ca.hr_422 
  0x0f104bec, 0x30522fec, 0x594d1c07, 0x1517080c,   // mi.lt.lv_644 su.ha.uz_644  id.aa.rn_432 uk.sr.un_543 
  // [18900]
  0x22000804, 0x13000b04, 0x40001d04, 0x42004f04,   // no.oc.un_320 es.et.un_320  la.lb.un_320 bi.co.un_320 
  0x5a472205, 0x25595509, 0x034008ee, 0x4804070b,   // oc.sn.sm_333 rw.rn.eu_444  no.lb.nl_422 bg.ru.tt_542 
  0x054d42a4, 0x43006b0c, 0x2e0d18a0, 0x3b595555,   // co.aa.fr_433 ceb.ie.un_530  ga.cs.fo_322 rw.rn.so_442 
  0x5e193baf, 0x4a003905, 0x4d054a09, 0x2a522409,   // so.gl.ts_655 br.yo.un_330  yo.fr.aa_444 eo.ha.mt_444 
  // [18910]
  0x481b11ec, 0x15070a12, 0x265143a4, 0x374438a7,   // ro.tr.tt_644 mk.bg.un_654  ie.kl.ia_433 tk.kk.ba_532 
  0x305afca0, 0x252330a9, 0x1b483802, 0x38442512,   // zzp.sm.uz_322 uz.ky.mn_544  tk.tt.tr_222 mn.kk.tk_654 
  0x11004814, 0x40330814, 0x120c4ea4, 0x2d0d05ee,   // tt.ro.un_660 no.nn.lb_666  ay.sv.hu_433 fr.cs.sk_422 
  0x406301a0, 0x336508a0, 0x0a100812, 0x40003308,   // en.sco.lb_322 no.gv.nn_322  uk.be.mk_654 nn.lb.un_430 
  // [18920]
  0x4c2a69ee, 0x3530250d, 0x1e004c0c, 0x08100705,   // mfe.mt.wo_422 mn.uz.tg_554  wo.ms.un_530 bg.be.uk_333 
  0x15070aaf, 0x13026208, 0x0e0c08a7, 0x4c402a07,   // mk.bg.un_655 kha.da.et_443  no.sv.is_532 mt.lb.wo_432 
  0x6004650c, 0x07010604, 0x3730580d, 0x02275fa0,   // gv.fi.vo_543 de.en.it_332  om.uz.st_554 tn.gd.da_322 
  0x033f260c, 0x0a006113, 0x58004d23, 0x30002704,   // ia.af.nl_543 za.pt.un_650  aa.om.un_880 gd.uz.un_320 
  // [18930]
  0x2c514d0d, 0x13001507, 0x0a071511, 0x0b000207,   // aa.kl.fy_554 un.et.un_420  un.bg.mk_653 da.es.un_420 
  0x15351007, 0x2700230d, 0x076526a4, 0x0535fc0c,   // be.tg.un_432 ca.gd.un_540  ia.gv.it_433 zzp.zu.fr_543 
  0x58003304, 0x1923055a, 0x024265a0, 0x48000d13,   // nn.om.un_320 fr.ca.gl_553  gv.co.da_322 cs.tt.un_650 
  0x4858750d, 0x3900020d, 0x1b2a6455, 0x04692704,   // nso.om.tt_554 da.br.un_540  lg.mt.tr_442 gd.mfe.fi_332 
  // [18940]
  0x0500191a, 0x586452ec, 0x4c304da4, 0x226504ad,   // gl.fr.un_760 ha.lg.om_644  aa.uz.wo_433 fi.gv.oc_643 
  0x400603a7, 0x190b22af, 0x654315a9, 0x212305ee,   // nl.de.lb_532 oc.es.gl_655  un.ie.gv_544 fr.ca.jw_422 
  0x46fe4d08, 0x3904fe0c, 0x0e100107, 0x162e01a0,   // aa.tlh.qu_443 tlh.fi.br_543  en.lt.is_432 en.fo.hr_322 
  0x6b3f2e13, 0x0d6e5604, 0x2f051205, 0x51000113,   // fo.af.ceb_665 mg.hmn.cs_332  hu.fr.su_333 en.kl.un_650 
  // [18950]
  0x29383b04, 0x2601fc08, 0x06002507, 0x310e2e5a,   // so.tk.sl_332 zzp.en.ia_443  eu.de.un_420 fo.is.az_553 
  0x2e4d010c, 0x0e5451ad, 0x21301204, 0x102c01a4,   // en.aa.fo_543 kl.ik.is_643  ur.uz.fa_332 en.fy.lt_433 
  0x0e1046ad, 0x30465412, 0x1200560c, 0x6e182711,   // qu.lt.is_643 ik.qu.uz_654  mg.hu.un_530 gd.ga.hmn_653 
  0x20033f04, 0x271d18ee, 0x30100455, 0x37041009,   // af.nl.sq_332 ga.la.gd_422  ru.be.uz_442 be.ru.ba_444 
  // [18960]
  0x18004f14, 0x651e1da7, 0x4f00130d, 0x27671808,   // bi.ga.un_660 la.ms.gv_532  et.bi.un_540 ga.ak.gd_443 
  0x18005718, 0x15443760, 0x2d001012, 0x26001d1a,   // na.ga.un_740 ba.kk.un_664  lt.sk.un_640 la.ia.un_760 
  0x2b00271b, 0x5d351dee, 0x61000d1a, 0x2e0e01a0,   // gd.vi.un_770 la.zu.ss_422  cs.za.un_760 en.is.fo_322 
  0x37005e04, 0x47642812, 0x2c001d07, 0x5f005509,   // ts.st.un_320 sw.lg.sn_654  la.fy.un_420 rw.tn.un_440 
  // [18970]
  0x58003708, 0x480437a0, 0x45002812, 0x4000fc1a,   // st.om.un_430 ba.ru.tt_322  sw.ln.un_640 zzp.lb.un_760 
  0x11000c0c, 0x55645d08, 0x51133ba0, 0x1800580c,   // sv.ro.un_530 ss.lg.rw_443  so.et.kl_322 om.ga.un_530 
  0x79005a12, 0x4a02510d, 0x190a4002, 0x533365a0,   // sm.war.un_640 kl.da.yo_554  lb.pt.gl_222 gv.nn.ht_322 
  0x4c5b0aa4, 0x3b582011, 0x024c2e55, 0x121b250d,   // pt.sg.wo_433 sq.om.so_653  fo.wo.da_442 eu.tr.hu_554 
  // [18980]
  0x190d50a0, 0x220a2305, 0x1d0a0e07, 0x230a22a4,   // fj.cs.gl_322 ca.pt.oc_333  is.pt.la_432 oc.pt.ca_433 
  0x3b0a64ee, 0x5c004308, 0x17441507, 0x51005a12,   // lg.pt.so_422 ie.sa.un_430  un.kk.sr_432 sm.kl.un_640 
  0x27004a04, 0x3b005111, 0xfe0d0aee, 0x435a240c,   // yo.gd.un_320 kl.so.un_630  pt.cs.tlh_422 eo.sm.ie_543 
  0x34302304, 0x514936a0, 0x5a1d240d, 0x0b003e04,   // ky.uz.ps_332 gn.to.kl_322  eo.la.sm_554 rm.es.un_320 
  // [18990]
  0x2a00310c, 0x6e002412, 0x484437ee, 0x6b002f12,   // az.mt.un_530 eo.hmn.un_640  ba.kk.tt_422 su.ceb.un_640 
  0x506a4907, 0x48362305, 0x48230aa0, 0x302118a4,   // to.haw.fj_432 ky.ab.tt_333  mk.ky.tt_322 ar.fa.uz_433 
  0x4c054508, 0x54002a14, 0xfc4a6007, 0x49001210,   // ln.fr.wo_443 mt.ik.un_660  vo.yo.zzp_432 hu.to.un_620 
  0x46231fa7, 0x23044a04, 0x37005308, 0x40630255,   // cy.ca.qu_532 yo.fi.ca_332  ht.st.un_430 da.sco.lb_442 
  // [189a0]
  0x2500151b, 0x6302010c, 0x27002f0d, 0x042512a9,   // un.mn.un_770 en.da.sco_543  su.gd.un_540 hu.eu.fi_544 
  0x081723a7, 0x44233007, 0x36251008, 0x4f000208,   // ky.sr.uk_532 uz.ky.kk_432  be.mn.ab_443 da.bi.un_430 
  0x02290f05, 0x4202230d, 0x12006b02, 0x033e02ee,   // lv.sl.da_333 ca.da.co_554  ceb.hu.un_220 da.rm.nl_422 
  0x73000413, 0x0c002008, 0x38134807, 0x20380ca0,   // fi.ny.un_650 sq.sv.un_430  tt.et.tk_432 sv.tk.sq_322 
  // [189b0]
  0x1548230c, 0x386563a0, 0x21425ca0, 0x36450e14,   // ky.tt.un_543 sco.gv.tk_322  sa.co.jw_322 is.ln.gn_666 
  0x51275a07, 0x275a51af, 0x505a01a4, 0x4b492708,   // sm.gd.kl_432 kl.sm.gd_655  en.sm.fj_433 gd.to.mi_443 
  0x232760a4, 0x23190a5a, 0x2f113304, 0x08111504,   // vo.gd.ca_433 pt.gl.ca_553  nn.ro.su_332 un.ro.uk_332 
  0x04515a0c, 0x306a1c04, 0x100717ad, 0xfc5a5107,   // sm.kl.fi_543 id.haw.uz_332  sr.bg.be_643 kl.sm.zzp_432 
  // [189c0]
  0x044b5a07, 0x525620ee, 0x02400507, 0x30244a11,   // sm.mi.fi_432 sq.mg.ha_422  fr.lb.da_432 yo.eo.uz_653 
  0x580267a6, 0x02003e04, 0x29201111, 0x5c002902,   // ak.da.om_521 rm.da.un_320  ro.sq.sl_653 sl.sa.un_220 
  0x291304ee, 0x30232902, 0x12002907, 0x530d76a9,   // fi.et.sl_422 sl.ca.uz_222  sl.hu.un_420 crs.cs.ht_544 
  0x0553450c, 0x20292a60, 0x132029ad, 0x4a00522a,   // ln.ht.fr_543 mt.sl.sq_664  sl.sq.et_643 ha.yo.un_970 
  // [189d0]
  0x0726560c, 0x792901a4, 0x07220c08, 0x65010da7,   // mg.ia.it_543 en.sl.war_433  sv.oc.it_443 cs.en.gv_532 
  0x39004a2a, 0x064a02ee, 0x21004408, 0x254a3ba4,   // yo.br.un_970 da.yo.de_422  kk.fa.un_430 so.yo.eu_433 
  0x3e051fee, 0x032211a7, 0x0800560d, 0x22061f13,   // cy.fr.rm_422 ro.oc.nl_532  mg.no.un_540 cy.de.oc_665 
  0x65034a12, 0x1d011fa7, 0x56000702, 0x671d100c,   // yo.nl.gv_654 cy.en.la_532  it.mg.un_220 lt.la.ak_543 
  // [189e0]
  0x396b1dec, 0x6524fc08, 0x2f7930ee, 0x301e6704,   // la.ceb.br_644 zzp.eo.gv_443  uz.war.su_422 ak.ms.uz_332 
  0x104230a4, 0x021d4c07, 0x693e1fa4, 0x04002b02,   // uz.co.lt_433 wo.la.da_432  cy.rm.mfe_433 vi.fi.un_220 
  0x652c0107, 0x33101307, 0x110f0107, 0x6e003013,   // en.fy.gv_432 et.lt.nn_432  en.lv.ro_432 uz.hmn.un_650 
  0x082e02a0, 0x4b005e04, 0x1e1c20a6, 0x25206e07,   // da.fo.no_322 ts.mi.un_320  sq.id.ms_521 hmn.sq.eu_432 
  // [189f0]
  0x054c4da4, 0x301035af, 0x0a351707, 0x4838090b,   // aa.wo.fr_433 tg.be.uz_655  sr.tg.mk_432 pl.tk.tt_542 
  0x06035307, 0x443c3713, 0x072e0e07, 0x4b00492b,   // ht.nl.de_432 ba.ug.kk_665  is.fo.it_432 to.mi.un_980 
  0x110a2308, 0x0c0e130b, 0x49192307, 0x3600510c,   // ca.pt.ro_443 et.is.sv_542  ca.gl.to_432 kl.gn.un_530 
  0x2a1125ee, 0x3c0a080c, 0x515202a4, 0x5a114207,   // eu.ro.mt_422 uk.mk.ug_543  da.ha.kl_433 co.ro.sm_432 
  // [18a00]
  0x22135155, 0x4b00420d, 0x4c002f0e, 0x130c06a7,   // kl.et.oc_442 co.mi.un_540  su.wo.un_550 de.sv.et_532 
  0x4418120c, 0x4c000504, 0x493b6312, 0x044d1312,   // ur.ar.kk_543 fr.wo.un_320  sco.so.to_654 et.aa.fi_654 
  0x19052207, 0x13400107, 0x48383712, 0x28182308,   // oc.fr.gl_432 en.lb.et_432  ba.tk.tt_654 ky.ar.sd_443 
  0x4d3b0107, 0x4c650255, 0x03656705, 0x654d3b08,   // en.so.aa_432 da.gv.wo_442  ak.gv.nl_333 so.aa.gv_443 
  // [18a10]
  0x3b630214, 0x0f5f75a4, 0x40346e0c, 0x3538360c,   // da.sco.so_666 nso.tn.lv_433  hmn.xh.lb_543 ab.tk.tg_543 
  0x63136508, 0x5d190b5a, 0x68134ca4, 0x4c5865a6,   // gv.et.sco_443 es.gl.ss_553  wo.et.ig_433 gv.om.wo_521 
  0x1100620c, 0x30110705, 0x111b2004, 0x0a1504ad,   // kha.ro.un_530 bg.ro.uz_333  sq.tr.ro_332 ru.mk.un_630 
  0x634d3b12, 0x2d0d1da0, 0x563b7908, 0x0d314c02,   // so.aa.sco_654 la.cs.sk_322  war.so.mg_443 wo.az.cs_222 
  // [18a20]
  0x311b20a0, 0x3c343da7, 0x0e2d4a07, 0x12283ba7,   // sq.tr.az_322 ku.ps.ug_532  yo.sk.is_432 ks.sd.ur_532 
  0x0435380c, 0x043707a0, 0x35041508, 0x0e18190d,   // tk.tg.ru_543 bg.ba.ru_322  un.ru.tg_443 gl.ga.is_554 
  0x1b4831a0, 0x3300200b, 0x4c4d5809, 0x02781ca0,   // az.tt.tr_322 sq.nn.un_520  om.aa.wo_444 id.ve.da_322 
  0x462519ee, 0x27106012, 0x0e0c04a9, 0x6a220f0c,   // gl.eu.qu_422 vo.lt.gd_654  fi.sv.is_544 lv.oc.haw_543 
  // [18a30]
  0x2b4a0407, 0x4c021ea9, 0x4a005e09, 0x405636a9,   // fi.yo.vi_432 ms.da.wo_544  ts.yo.un_440 gn.mg.lb_544 
  0x0427510c, 0x2f360b05, 0x2c004704, 0x100f570c,   // kl.gd.fi_543 es.gn.su_333  sn.fy.un_320 na.lv.lt_543 
  0x216b1505, 0x5f5e690c, 0x0b271812, 0x21001507,   // un.ceb.jw_333 mfe.ts.tn_543  ga.gd.es_654 un.jw.un_420 
  0x5002520c, 0x3f372ca0, 0x2c460304, 0x18272813,   // ha.da.fj_543 fy.st.af_322  nl.qu.fy_332 sw.gd.ga_665 
  // [18a40]
  0x10133f0c, 0x2c001502, 0x4f0f2711, 0x2a000e1a,   // af.et.lt_543 un.fy.un_220  gd.lv.bi_653 is.mt.un_760 
  0x2e0e275a, 0x4a1d0708, 0x361d2d07, 0x0e315805,   // gd.is.fo_553 it.la.yo_443  sk.la.gn_432 om.az.is_333 
  0x092502ee, 0x73524a04, 0x47072408, 0x31611b07,   // da.eu.pl_422 yo.ha.ny_332  eo.it.sn_443 tr.za.az_432 
  0x0e3f3307, 0x42314804, 0x47105c09, 0x79475005,   // nn.af.is_432 tt.az.co_332  sa.lt.sn_444 fj.sn.war_333 
  // [18a50]
  0x1b001507, 0x5f374bec, 0x0102610c, 0x21473604,   // un.tr.un_420 mi.st.tn_644  za.da.en_543 gn.sn.jw_332 
  0x184704a7, 0x0b474d0c, 0x28051e07, 0x18005708,   // fi.sn.ga_532 aa.sn.es_543  ms.fr.sw_432 na.ga.un_430 
  0x51005a09, 0x47005107, 0x13006304, 0x311b5112,   // sm.kl.un_440 kl.sn.un_420  sco.et.un_320 kl.tr.az_654 
  0x0351010c, 0x101b2108, 0x4b572c0c, 0x24361c11,   // en.kl.nl_543 jw.tr.lt_443  fy.na.mi_543 id.gn.eo_653 
  // [18a60]
  0x614d46af, 0x35442307, 0x2f22210d, 0x214c050b,   // qu.aa.za_655 ky.kk.tg_432  jw.oc.su_554 fr.wo.jw_542 
  0x020c4f0c, 0x4f79130c, 0x2d0d050e, 0x23342813,   // bi.sv.da_543 et.war.bi_543  fr.cs.sk_555 sd.ps.ky_665 
  0x4d000508, 0x45000509, 0x1131485e, 0x542051af,   // fr.aa.un_430 fr.ln.un_440  tt.az.ro_652 kl.sq.ik_655 
  0x27182ba4, 0x04002513, 0x27186ba7, 0x206e545a,   // vi.ga.gd_433 eu.fi.un_650  ceb.ga.gd_532 ik.hmn.sq_553 
  // [18a70]
  0x1b483805, 0x041718ad, 0x06301ba9, 0x300e3ba4,   // tk.tt.tr_333 ar.sr.ru_643  tr.uz.de_544 so.is.uz_433 
  0x281030ee, 0x36000b05, 0x271f1104, 0x650553a0,   // uz.lt.sw_422 es.gn.un_330  ro.cy.gd_332 ht.fr.gv_322 
  0x18000e0d, 0x301c1ea4, 0x084807a0, 0x39021f04,   // is.ga.un_540 ms.id.uz_433  bg.tt.uk_322 cy.da.br_332 
  0x0c0e2ea7, 0x31671b04, 0x026976ad, 0x230e0aee,   // fo.is.sv_532 tr.ak.az_332  crs.mfe.da_643 pt.is.ca_422 
  // [18a80]
  0x3c00360d, 0x0415480c, 0x1f002222, 0x1f1302a0,   // ab.ug.un_540 tt.ru.un_530  oc.cy.un_870 da.et.cy_322 
  0x23052255, 0x1b3831ad, 0x284b6aac, 0x1b384855,   // oc.fr.ca_442 az.tk.tr_643  haw.mi.sw_632 tt.tk.tr_442 
  0x184a3604, 0x28096bad, 0x170a25ee, 0x23480ea0,   // gn.yo.ga_332 ceb.pl.sw_643  mn.mk.sr_422 is.tt.ca_322 
  0x35003618, 0x3d003411, 0x0a083c07, 0x1200230d,   // ab.tg.un_740 ps.ku.un_630  ug.uk.mk_432 ky.ur.un_540 
  // [18a90]
  0x0c001309, 0x21302304, 0x3015380b, 0x29002a04,   // et.sv.un_440 ky.uz.fa_332  tk.uz.un_520 mt.sl.un_320 
  0x305c20ad, 0x4e041360, 0x0c336212, 0x0c00021f,   // sq.sa.uz_643 et.fi.ay_664  kha.nn.sv_654 da.sv.un_840 
  0x38295c02, 0x3d12300c, 0x5600471a, 0x1b114807,   // sa.sl.tk_222 uz.ur.ku_543  sn.mg.un_760 tt.ro.tr_432 
  0x5c383008, 0x080e6207, 0x42002f04, 0x060c48ec,   // uz.tk.sa_443 kha.is.no_432  su.co.un_320 tt.sv.de_644 
  // [18aa0]
  0x30372312, 0x5c2920a0, 0x0c57060c, 0x57065b13,   // ky.ba.uz_654 sq.sl.sa_322  de.na.sv_543 sg.de.na_665 
  0x5b060c08, 0x48385bec, 0x48060c0d, 0x0d005c23,   // sv.de.sg_443 sg.tk.tt_644  sv.de.tt_554 sa.ne.un_880 
  0x07001f0c, 0x3b000f07, 0x2f002a02, 0x28734555,   // cy.it.un_530 lv.so.un_420  mt.su.un_220 ln.ny.sw_442 
  0x3b006b18, 0x48381ba9, 0x0a1511a7, 0x065b4804,   // ceb.so.un_740 tr.tk.tt_544  ro.mk.un_520 tt.sg.de_332 
  // [18ab0]
  0x0c005b21, 0x2e005119, 0x0f390707, 0x04003b08,   // sg.sv.un_860 kl.fo.un_750  it.br.lv_432 so.fi.un_430 
  0x06480c07, 0x39496aa0, 0x0e1d65a4, 0x6b62340c,   // sv.tt.de_432 haw.to.br_322  gv.la.is_433 xh.kha.ceb_543 
  0x58004f09, 0x1e491c0c, 0x49001d02, 0x1e001c19,   // bi.om.un_440 id.to.ms_543  la.to.un_220 id.ms.un_750 
  0x4b510107, 0x3e4d6408, 0x39006a13, 0x13600c1f,   // en.kl.mi_432 lg.aa.rm_443  haw.br.un_650 sv.vo.et_864 
  // [18ac0]
  0x61451e0c, 0x43001e04, 0x28002202, 0x40480655,   // ms.ln.za_543 ms.ie.un_320  oc.sw.un_220 de.tt.lb_442 
  0x055539ee, 0x48060c67, 0x62fc470c, 0x61001508,   // br.rw.fr_422 sv.de.tt_775  sn.zzp.kha_543 un.za.un_430 
  0xfc2e0613, 0x1265070c, 0x632e0107, 0x61000108,   // de.fo.zzp_665 it.gv.hu_543  en.fo.sco_432 en.za.un_430 
  0x17004405, 0x3b0a5ead, 0x111b48a9, 0x650563a4,   // kk.sr.un_330 ts.pt.so_643  tt.tr.ro_544 sco.fr.gv_433 
  // [18ad0]
  0x19360a07, 0x072601a4, 0x155305a0, 0x330863a0,   // pt.gn.gl_432 en.ia.it_433  fr.ht.un_322 sco.no.nn_322 
  0x51001e13, 0x530539a0, 0x28fe0807, 0x21022da0,   // ms.kl.un_650 br.fr.ht_322  no.tlh.sw_432 sk.da.jw_322 
  0x63640ca9, 0x282101a0, 0x4b002819, 0x11004808,   // sv.lg.sco_544 en.jw.sw_322  sw.mi.un_750 tt.ro.un_430 
  0x100f75ad, 0x0a00790d, 0x38081508, 0x48111055,   // nso.lv.lt_643 war.pt.un_540  un.uk.tk_443 be.ro.tt_442 
  // [18ae0]
  0x2b007908, 0x46006019, 0x60004621, 0x46000c0d,   // war.vi.un_430 vo.qu.un_750  qu.vo.un_860 sv.qu.un_540 
  0x06480c04, 0x040c46af, 0x044048a4, 0x58685508,   // sv.tt.de_332 qu.sv.fi_655  tt.lb.fi_433 rw.ig.om_443 
  0x124205ec, 0x644c68ad, 0x2d30150c, 0x38006012,   // fr.co.hu_644 ig.wo.lg_643  un.uz.sk_543 vo.tk.un_640 
  0x11100107, 0x2a00680e, 0x162d29a0, 0x565231a4,   // en.lt.ro_432 ig.mt.un_550  sl.sk.hr_322 az.ha.mg_433 
  // [18af0]
  0x10284702, 0x1036440c, 0x242a0304, 0x64006808,   // sn.sw.lt_222 kk.ab.be_543  nl.mt.eo_332 ig.lg.un_430 
  0x04484004, 0x65030107, 0x4840040c, 0x2e005807,   // lb.tt.fi_332 en.nl.gv_432  fi.lb.tt_543 om.fo.un_420 
  0x480c4004, 0x05001c16, 0x2a4207af, 0xfc531f07,   // lb.sv.tt_332 mr.zh.un_720  it.co.mt_655 cy.ht.zzp_432 
  0x380460ac, 0x3f2e4ea7, 0x15004204, 0x46254007,   // vo.fi.tk_632 ay.fo.af_532  co.un.un_320 lb.eu.qu_432 
  // [18b00]
  0x0a2322af, 0x2e100f0c, 0x792e010c, 0x6a00040e,   // oc.ca.pt_655 lv.lt.fo_543  en.fo.war_543 fi.haw.un_550 
  0x35004004, 0x0a080707, 0x4936040b, 0x044b6aad,   // lb.zu.un_320 bg.uk.mk_432  fi.gn.to_542 haw.mi.fi_643 
  0x3600040d, 0x48004b0d, 0x4b000412, 0x35070aa9,   // fi.gn.un_540 mi.tt.un_540  fi.mi.un_640 mk.bg.tg_544 
  0x0e060c07, 0x04480c05, 0x0c060e07, 0x152301a4,   // sv.de.is_432 sv.tt.fi_333  is.de.sv_432 en.ca.un_433 
  // [18b10]
  0x04386010, 0x53005808, 0x38006020, 0x1600020c,   // vo.tk.fi_642 om.ht.un_430  vo.tk.un_850 da.hr.un_530 
  0x331357a6, 0x605a2608, 0x0f1324a0, 0x135a230e,   // na.et.nn_521 ia.sm.vo_443  eo.et.lv_322 ca.sm.et_555 
  0x043860ad, 0x55182704, 0x60004823, 0x072211a4,   // vo.tk.fi_643 gd.ga.rw_332  tt.vo.un_880 ro.oc.it_433 
  0x2f3e0107, 0x012223a4, 0x3515150d, 0x40001320,   // en.rm.su_432 ca.oc.en_433  un.tg.un_540 et.lb.un_850 
  // [18b20]
  0x022c4d14, 0x2761180e, 0x4a005d02, 0x6b1a020c,   // aa.fy.da_666 ga.za.gd_555  ss.yo.un_220 da.tl.ceb_543 
  0x0a1708a0, 0x39fc0507, 0x25153011, 0x1c490a55,   // uk.sr.mk_322 fr.zzp.br_432  uz.mn.un_630 pt.to.id_442 
  0x6a4f5aad, 0x3505fc02, 0x380c60af, 0x3e00190d,   // sm.bi.haw_643 zzp.fr.zu_222  vo.sv.tk_655 gl.rm.un_540 
  0x114b5a5a, 0x04004e0b, 0x04004e11, 0x56041308,   // sm.mi.ro_553 ay.fi.un_520  ay.fi.un_630 et.fi.mg_443 
  // [18b30]
  0x5a003007, 0x6a133908, 0x4400250c, 0x18003907,   // uz.sm.un_420 br.et.haw_443  mn.kk.un_530 br.ga.un_420 
  0x0f5c4b55, 0xfc2a15a0, 0x47000502, 0x136b790c,   // mi.sa.lv_442 un.mt.zzp_322  fr.sn.un_220 war.ceb.et_543 
  0x2c055904, 0x051363a7, 0x392f210c, 0x395a56a0,   // rn.fr.fy_332 sco.et.fr_532  jw.su.br_543 mg.sm.br_322 
  0x7300560c, 0x530522a0, 0x5a135e07, 0x0c0448ee,   // mg.ny.un_530 oc.fr.ht_322  ts.et.sm_432 tt.fi.sv_422 
  // [18b40]
  0x282f210c, 0x18274f07, 0x22052f02, 0x01002429,   // jw.su.sw_543 bi.gd.ga_432  su.fr.oc_222 yi.iw.un_960 
  0x09182160, 0x23381109, 0x40044e0b, 0x055322ee,   // fa.ar.hi_664 ro.tk.ky_444  ay.fi.lb_542 oc.ht.fr_422 
  0x480c600d, 0x05221302, 0x05224508, 0x06003420,   // vo.sv.tt_554 et.oc.fr_222  ln.oc.fr_443 xh.de.un_850 
  0x0e1867a4, 0x23483009, 0x20fe04a7, 0x0c00400d,   // ak.ga.is_433 uz.tt.ky_444  fi.tlh.sq_532 lb.sv.un_540 
  // [18b50]
  0x51006419, 0x0c6340a4, 0x0f47730e, 0x13402e55,   // lg.kl.un_750 lb.sco.sv_433  ny.sn.lv_555 fo.lb.et_442 
  0x330812af, 0x403308a9, 0x48000908, 0x420704a9,   // hu.no.nn_655 no.nn.lb_544  pl.tt.un_430 fi.it.co_544 
  0x1c001321, 0x330842a4, 0x42070409, 0x422a07af,   // bh.mr.un_860 co.no.nn_433  fi.it.co_444 it.mt.co_655 
  0x0c570805, 0xfc42070c, 0x0c00401a, 0x30253505,   // no.na.sv_333 it.co.zzp_543  lb.sv.un_760 tg.mn.uz_333 
  // [18b60]
  0x63004c0e, 0x420507af, 0x48083702, 0x374835a9,   // wo.sco.un_550 it.fr.co_655  ba.uk.tt_222 tg.tt.ba_544 
  0x2e0833a9, 0x421201a0, 0x5c1b60a7, 0x190a790c,   // nn.no.fo_544 en.hu.co_322  vo.tr.sa_532 war.pt.gl_543 
  0x2a063fa4, 0x071204ec, 0x54315808, 0x33081214,   // af.de.mt_433 fi.hu.it_644  om.az.ik_443 hu.no.nn_666 
  0x2a0c38a9, 0xfc0a01a4, 0x072a330c, 0x3e4f2aee,   // tk.sv.mt_544 en.pt.zzp_433  nn.mt.it_543 mt.bi.rm_422 
  // [18b70]
  0x32290908, 0x4d04130c, 0x21002013, 0x123b18af,   // pl.sl.bs_443 et.fi.aa_543  sq.jw.un_650 ar.ks.ur_655 
  0x5800510c, 0x19005207, 0x79586104, 0x0702050d,   // kl.om.un_530 ha.gl.un_420  za.om.war_332 fr.da.it_554 
  0x58fe5d0d, 0x1f2743a0, 0x375f120c, 0x30312007,   // ss.tlh.om_554 ie.gd.cy_322  hu.tn.st_543 sq.az.uz_432 
  0x1c1d65a6, 0x392f05a0, 0x2e00fe08, 0x5d00fe08,   // gv.la.id_521 fr.su.br_322  tlh.fo.un_430 tlh.ss.un_430 
  // [18b80]
  0x2a3e1b0c, 0x1735100c, 0x0c006018, 0x070435a4,   // tr.rm.mt_543 be.tg.sr_543  vo.sv.un_740 tg.ru.bg_433 
  0x44150704, 0x28002f2b, 0x13044da7, 0x734513af,   // bg.kk.un_320 su.sw.un_980  aa.fi.et_532 et.ln.ny_655 
  0x0efe1009, 0x50114cac, 0x490f5aee, 0x290d3ba6,   // lt.tlh.is_444 wo.ro.fj_632  sm.lv.to_422 so.cs.sl_521 
  0xfe502f0e, 0x24000f1b, 0x2f6925ec, 0x25104907,   // su.fj.tlh_555 lv.eo.un_770  eu.mfe.su_644 to.lt.eu_432 
  // [18b90]
  0x0e495aa4, 0x581e1ca7, 0x2226240d, 0x273e23a9,   // sm.to.is_433 id.ms.om_532  eo.ia.oc_554 ca.rm.gd_544 
  0x5a2849a4, 0x27001002, 0xfc1b20a7, 0x29200d0c,   // to.sw.sm_433 lt.gd.un_220  sq.tr.zzp_532 cs.sq.sl_543 
  0x2f004b04, 0x42001d07, 0x32492107, 0x5100200c,   // mi.su.un_320 la.co.un_420  jw.to.bs_432 sq.kl.un_530 
  0x1d01fc5a, 0x10002008, 0xfc200d04, 0x452123ad,   // zzp.en.la_553 sq.lt.un_430  cs.sq.zzp_332 ca.jw.ln_643 
  // [18ba0]
  0x3509610b, 0x515a1d05, 0x1d515a11, 0x08790c04,   // za.pl.zu_542 la.sm.kl_333  sm.kl.la_653 sv.war.no_332 
  0x08000223, 0x29000202, 0x36000a13, 0x23210504,   // da.no.un_880 da.sl.un_220  mk.ab.un_650 fr.jw.ca_332 
  0x04482507, 0x09150cee, 0x20004610, 0x1b00380b,   // mn.tt.ru_432 sv.pl.un_420  qu.sq.un_620 tk.tr.un_520 
  0x19000a1a, 0x4b00360d, 0x04003613, 0x481301a0,   // pt.gl.un_760 gn.mi.un_540  gn.fi.un_650 en.et.tt_322 
  // [18bb0]
  0x074411ee, 0x174804a0, 0x1100681a, 0x25fc4807,   // ro.kk.bg_422 ru.tt.sr_322  ig.ro.un_760 tt.zzp.eu_432 
  0x071735ac, 0x37041511, 0x23154809, 0x5d004519,   // tg.sr.bg_632 un.ru.ba_653  tt.ky.un_440 ln.ss.un_750 
  0x38483712, 0x2e004904, 0x65001b02, 0x5800680d,   // ba.tt.tk_654 to.fo.un_320  tr.gv.un_220 ig.om.un_540 
  0x5800641a, 0x4a00471a, 0x2118360d, 0x063f150c,   // lg.om.un_760 sn.yo.un_760  gn.ga.jw_554 un.af.de_543 
  // [18bc0]
  0x68114508, 0x4a2557a4, 0x18006709, 0x4b5736a4,   // ln.ro.ig_443 na.eu.yo_433  ak.ga.un_440 gn.na.mi_433 
  0x35001f19, 0x43112512, 0x1e000408, 0x170708a4,   // cy.zu.un_750 eu.ro.ie_654  fi.ms.un_430 uk.bg.sr_433 
  0x15006305, 0x18441204, 0x27004a08, 0x360a48a0,   // sco.un.un_330 ur.kk.ar_332  yo.gd.un_430 tt.mk.ab_322 
  0x080a17ad, 0x5d356804, 0x3012210e, 0x23002721,   // sr.mk.uk_643 ig.zu.ss_332  fa.ur.uz_555 gd.ca.un_860 
  // [18bd0]
  0x0d3836ec, 0x24565509, 0x791a2412, 0x4c135bee,   // gn.tk.cs_644 rw.mg.eo_444  eo.tl.war_654 sg.et.wo_422 
  0x470724a4, 0x07041708, 0x112330af, 0x56594ba4,   // eo.it.sn_433 sr.ru.bg_443  uz.ky.ro_655 mi.rn.mg_433 
  0x4b5059af, 0x180e4d0d, 0x103844a4, 0x10574711,   // rn.fj.mi_655 aa.is.ga_554  kk.tk.be_433 sn.na.lt_653 
  0x4635470c, 0x391802ee, 0x595c55af, 0x49055307,   // sn.zu.qu_543 da.ga.br_422  rw.sa.rn_655 ht.fr.to_432 
  // [18be0]
  0x244778a4, 0x3b6455ac, 0x05002502, 0x2e004602,   // ve.sn.eo_433 rw.lg.so_632  eu.fr.un_220 qu.fo.un_220 
  0x4b595e0c, 0x76692e05, 0x79003012, 0x081110af,   // ts.rn.mi_543 fo.mfe.crs_333  uz.war.un_640 be.ro.uk_655 
  0x28002b04, 0x29684a08, 0x476873ec, 0x2e001602,   // vi.sw.un_320 yo.ig.sl_443  ny.ig.sn_644 hr.fo.un_220 
  0x6b0f100d, 0x150410ad, 0x571d67a4, 0x150448ad,   // lt.lv.ceb_554 be.ru.un_643  ak.la.na_433 tt.ru.un_643 
  // [18bf0]
  0x0a302302, 0x02430f04, 0x353e3407, 0x394c05ee,   // ky.uz.mk_222 lv.ie.da_332  xh.rm.zu_432 fr.wo.br_422 
  0x10004812, 0x1e002205, 0x5279150d, 0x0a1e2f02,   // tt.be.un_640 oc.ms.un_330  un.war.ha_554 su.ms.pt_222 
  0x183012a9, 0x1821200c, 0x160f29a0, 0x4b000a07,   // ur.uz.ar_544 sq.jw.ga_543  sl.lv.hr_322 pt.mi.un_420 
  0x3f003007, 0x1e003002, 0x522420ee, 0x20006e0d,   // uz.af.un_420 uz.ms.un_220  sq.eo.ha_422 hmn.sq.un_540 
  
  // [18c00]
  0x041515a7, 0x396e20ec, 0x0a226ea0, 0x654c1da0,   // un.ru.un_520 sq.hmn.br_644  hmn.oc.pt_322 la.wo.gv_322 
  0x452205af, 0x0400380b, 0x44043cee, 0x6100270e,   // fr.oc.ln_655 tk.ru.un_520  ug.ru.kk_422 gd.za.un_550 
  0x35170a07, 0x0e2e0aa7, 0x381536a4, 0x0500460c,   // mk.sr.tg_432 pt.fo.is_532  ab.tk.un_430 qu.fr.un_530 
  0x22420708, 0x0e004812, 0x0e484eee, 0x05000f02,   // it.co.oc_443 tt.is.un_640  ay.tt.is_422 lv.fr.un_220 
  // [18c10]
  0x0e0c31a4, 0x344935a4, 0x48000e1b, 0x684a51a4,   // az.sv.is_433 zu.to.xh_433  is.tt.un_770 kl.yo.ig_433 
  0x0e005b14, 0x17005004, 0x49642807, 0x020531a0,   // sg.is.un_660 fj.sr.un_320  sw.lg.to_432 az.fr.da_322 
  0x532545a0, 0x483736a7, 0x307925ee, 0x08062004,   // ln.eu.ht_322 ab.ba.tt_532  eu.war.uz_422 sq.de.no_332 
  0x01004307, 0x345f3707, 0x55006712, 0x1b0e5bb6,   // ie.en.un_420 st.tn.xh_432  ak.rw.un_640 sg.is.tr_766 
  // [18c20]
  0x1200690e, 0x47285e04, 0x0e311b6c, 0x02363b09,   // mfe.hu.un_550 ts.sw.sn_332  tr.az.is_873 so.gn.da_444 
  0x3645020c, 0x220a3812, 0x60000c14, 0x0c0f0e07,   // da.ln.gn_543 tk.pt.oc_654  sv.vo.un_660 is.lv.sv_432 
  0x15023b07, 0x1b310ca7, 0x121821a6, 0x061332ad,   // so.da.un_432 sv.az.tr_532  fa.ar.ur_521 bs.et.de_643 
  0x28000e08, 0x3e420704, 0x275a0209, 0x48310c08,   // is.sw.un_430 it.co.rm_332  da.sm.gd_444 sv.az.tt_443 
  // [18c30]
  0x182761af, 0x31004208, 0x68283504, 0x48005b13,   // za.gd.ga_655 co.az.un_430  zu.sw.ig_332 sg.tt.un_650 
  0x3b5a120c, 0x1b3848b4, 0x5600521a, 0x52025807,   // hu.sm.so_543 tt.tk.tr_754  ha.mg.un_760 om.da.ha_432 
  0x21182311, 0x52207308, 0x735c0260, 0x08113607,   // ky.ar.fa_653 ny.sq.ha_443  da.sa.ny_664 ab.ro.uk_432 
  0x0c001b04, 0x381b0c07, 0x7838060c, 0x36001811,   // tr.sv.un_320 sv.tr.tk_432  de.tk.ve_543 ga.gn.un_630 
  // [18c40]
  0x193039a7, 0x473973ee, 0x5f5a270c, 0x13003e19,   // br.uz.gl_532 ny.br.sn_422  gd.sm.tn_543 rm.et.un_750 
  0x131c09a7, 0x21004904, 0x17070a0b, 0x56495007,   // hi.mr.bh_532 to.jw.un_320  mk.bg.sr_542 fj.to.mg_432 
  0x3b4935a0, 0x5c3b2812, 0x0c0265a0, 0x2f001209,   // zu.to.so_322 sw.so.sa_654  gv.da.sv_322 hu.su.un_440 
  0xfe791a12, 0x02004714, 0x25001e13, 0x3b200255,   // tl.war.tlh_654 sn.da.un_660  ms.eu.un_650 da.sq.so_442 
  // [18c50]
  0x4a572b12, 0x04515411, 0x2f2460a4, 0x20532264,   // vi.na.yo_654 ik.kl.fi_653  vo.eo.su_433 oc.ht.sq_762 
  0x0bfe600c, 0x032c04a4, 0x536957ec, 0x523e600c,   // vo.tlh.es_543 fi.fy.nl_433  na.mfe.ht_644 vo.rm.ha_543 
  0x2c3e1fa4, 0x02005618, 0x04580604, 0x5a006a04,   // cy.rm.fy_433 mg.da.un_740  de.om.fi_332 haw.sm.un_320 
  0x13216307, 0x2c2a3b12, 0x42001210, 0x030618a9,   // sco.jw.et_432 so.mt.fy_654  hu.co.un_620 ga.de.nl_544 
  // [18c60]
  0x63654a60, 0x27005722, 0x17465ca0, 0x312125a7,   // yo.gv.sco_664 na.gd.un_870  sa.qu.sr_322 eu.jw.az_532 
  0x1f00570c, 0x1f005705, 0x3800522b, 0x1000231b,   // na.cy.un_530 na.cy.un_330  ha.tk.un_980 ky.be.un_770 
  0x656b4dad, 0x31431d05, 0x042028a0, 0x4800420e,   // aa.ceb.gv_643 la.ie.az_333  sw.sq.fi_322 co.tt.un_550 
  0x20003619, 0x2f002202, 0x100e6307, 0x48000e16,   // gn.sq.un_750 oc.su.un_220  sco.is.lt_432 is.tt.un_720 
  // [18c70]
  0x12480612, 0x1e005412, 0x10320f04, 0x1e1c2014,   // de.tt.hu_654 ik.ms.un_640  lv.bs.lt_332 sq.id.ms_666 
  0x2a112009, 0x04202511, 0x69005e21, 0x133e1faf,   // sq.ro.mt_444 eu.sq.fi_653  ts.mfe.un_860 cy.rm.et_655 
  0x10500fa9, 0x354c5ea7, 0x22002005, 0x0400181a,   // lv.fj.lt_544 ts.wo.zu_532  sq.oc.un_330 ga.fi.un_760 
  0x210258ad, 0x44371008, 0x6b2d0da7, 0x130440a0,   // om.da.jw_643 be.ba.kk_443  cs.sk.ceb_532 lb.fi.et_322 
  // [18c80]
  0x362d0d11, 0x62007914, 0x190a5da4, 0x4c001313,   // cs.sk.gn_653 war.kha.un_660  ss.pt.gl_433 et.wo.un_650 
  0x341823ac, 0x1e313008, 0x0c150255, 0x190a0505,   // ky.ar.ps_632 uz.az.ms_443  da.sv.un_420 fr.pt.gl_333 
  0x0e040cee, 0x23005305, 0x0e00480d, 0x1b000908,   // sv.fi.is_422 ht.ca.un_330  tt.is.un_540 pl.tr.un_430 
  0x18000911, 0x094639a9, 0x32172d02, 0x4437040c,   // pl.ga.un_630 br.qu.pl_544  sk.sr.bs_222 ru.ba.kk_543 
  // [18c90]
  0x360715a4, 0x23221207, 0x44000405, 0x04003104,   // un.bg.ab_433 hu.oc.ca_432  ru.kk.un_330 az.fi.un_320 
  0x190512ac, 0x25381507, 0x09000f0c, 0x4f150107,   // hu.fr.gl_632 un.tk.mn_432  lv.pl.un_530 en.bi.un_420 
  0x03651bee, 0x28003002, 0x3e4006ad, 0x16130407,   // tr.gv.nl_422 uz.sw.un_220  de.lb.rm_643 fi.et.hr_432 
  0x4f001c05, 0x1204fca4, 0x16001e02, 0x1e000207,   // id.bi.un_330 zzp.fi.hu_433  ms.hr.un_220 da.ms.un_420 
  // [18ca0]
  0x1d201ba0, 0x02032b07, 0x126b7955, 0x2a59550e,   // tr.sq.la_322 vi.nl.da_432  war.ceb.hu_442 rw.rn.mt_555 
  0x321618a0, 0x3600fc22, 0x350a1704, 0x2c3f1fa0,   // ga.hr.bs_322 zzp.gn.un_870  sr.mk.tg_332 cy.af.fy_322 
  0x1e1c25ee, 0x1053430d, 0x0e130408, 0x1e1c5305,   // eu.id.ms_422 ie.ht.lt_554  fi.et.is_443 ht.id.ms_333 
  0x0000292d, 0x4830fe0c, 0x21465aa0, 0x48150455,   // sl.un.un_A00 tlh.uz.tt_543  sm.qu.jw_322 ru.tt.un_420 
  // [18cb0]
  0x38000e02, 0x233025ee, 0x053f0211, 0x3f00390d,   // is.tk.un_220 mn.uz.ky_422  da.af.fr_653 br.af.un_540 
  0x19071da0, 0x1f190704, 0x23003b13, 0x174365ad,   // la.it.gl_322 it.gl.cy_332  ks.ky.un_650 gv.ie.sr_643 
  0x0c001b19, 0x28443ca0, 0x65180107, 0x311b0eac,   // tr.sv.un_750 ug.kk.sd_322  en.ga.gv_432 is.tr.az_632 
  0x15152308, 0x65003014, 0x230b65ee, 0x2e35340d,   // ky.un.un_430 uz.gv.un_660  gv.es.ca_422 xh.zu.fo_554 
  // [18cc0]
  0x2f645102, 0x071d2604, 0x6800791b, 0x1f0a3ea0,   // kl.lg.su_222 ia.la.it_332  war.ig.un_770 rm.pt.cy_322 
  0x4b5701a0, 0x46431a13, 0x0d452d0c, 0x0d003e04,   // en.na.mi_322 tl.ie.qu_665  sk.ln.cs_543 rm.cs.un_320 
  0x2e5e1b02, 0x1264280b, 0x0278280b, 0x15153812,   // tr.ts.fo_222 sw.lg.hu_542  sw.ve.da_542 tk.un.un_640 
  0x5d355504, 0x20735905, 0x353433a4, 0x28733408,   // rw.zu.ss_332 rn.ny.sq_333  nn.xh.zu_433 xh.ny.sw_443 
  // [18cd0]
  0x6800020d, 0x42245e08, 0x35344c0c, 0x36002307,   // da.ig.un_540 ts.eo.co_443  wo.xh.zu_543 ky.ab.un_420 
  0x735e5d07, 0x59550aa0, 0x475b200c, 0x0b3e25ee,   // ss.ts.ny_432 pt.rw.rn_322  sq.sg.sn_543 eu.rm.es_422 
  0x25001520, 0x16fc2504, 0x282a1802, 0x232544ad,   // un.mn.un_850 eu.zzp.hr_332  ga.mt.sw_222 kk.mn.ky_643 
  0x202a650c, 0x1d0413a4, 0x3c3044ec, 0x13005412,   // gv.mt.sq_543 et.fi.la_433  kk.uz.ug_644 ik.et.un_640 
  // [18ce0]
  0x34000919, 0x48252304, 0x58044dec, 0x0458510c,   // pl.xh.un_750 ky.mn.tt_332  aa.fi.om_644 kl.om.fi_543 
  0x5451580d, 0x51420455, 0x5815640d, 0x221d690d,   // om.kl.ik_554 fi.co.kl_442  lg.om.un_540 mfe.la.oc_554 
  0x3e4207a4, 0x49006405, 0x04585412, 0x5c581ba4,   // it.co.rm_433 lg.to.un_330  ik.om.fi_654 tr.om.sa_433 
  0x640663a0, 0x082e33ad, 0x5c52150c, 0x072a5812,   // sco.de.lg_322 nn.fo.no_643  un.ha.sa_543 om.mt.it_654 
  // [18cf0]
  0x5c00081a, 0x073704a0, 0x51544d09, 0x3544305a,   // no.sa.un_760 ru.ba.bg_322  aa.ik.kl_444 uz.kk.tg_553 
  0x19001d08, 0x0d000a12, 0x56004a08, 0x201b40ee,   // la.gl.un_430 pt.cs.un_640  yo.mg.un_430 lb.tr.sq_422 
  0x5f375daf, 0x49002804, 0x48001222, 0x21303d5a,   // ss.st.tn_655 sw.to.un_320  hu.tt.un_870 ku.uz.fa_553 
  0x2a0720a4, 0x55fc020b, 0x28003b02, 0x37001113,   // sq.it.mt_433 da.zzp.rw_542  so.sw.un_220 ro.ba.un_650 
  // [18d00]
  0x6355280c, 0x355534ad, 0x0d0f2807, 0x526428ad,   // sw.rw.sco_543 xh.rw.zu_643  sw.lv.cs_432 sw.lg.ha_643 
  0x25153555, 0x55fc1f60, 0x35304413, 0x184a0da4,   // tg.mn.un_420 cy.zzp.rw_664  kk.uz.tg_665 cs.yo.ga_433 
  0x22000608, 0x4804070c, 0x09001802, 0x2d006507,   // de.oc.un_430 bg.ru.tt_543  ga.pl.un_220 gv.sk.un_420 
  0x05004c05, 0x30002e0e, 0x25004409, 0x0742650c,   // wo.fr.un_330 fo.uz.un_550  kk.mn.un_440 gv.co.it_543 
  // [18d10]
  0x0e000d02, 0x2b006219, 0x30121812, 0x2846010c,   // cs.is.un_220 kha.vi.un_750  ar.ur.uz_654 en.qu.sw_543 
  0x626501a0, 0x3e574212, 0x5200010d, 0x201b29ee,   // en.gv.kha_322 co.na.rm_654  en.ha.un_540 sl.tr.sq_422 
  0x420a490c, 0x6342050c, 0x461e1c05, 0x300952a4,   // to.pt.co_543 fr.co.sco_543  id.ms.qu_333 ha.pl.uz_433 
  0x130a3312, 0x29001c13, 0x2400040c, 0x253b4e07,   // nn.pt.et_654 id.sl.un_650  fi.eo.un_530 ay.so.eu_432 
  // [18d20]
  0x0400630c, 0x0f4625a4, 0x100e3ba4, 0x0e632704,   // sco.fi.un_530 eu.qu.lv_433  so.is.lt_433 gd.sco.is_332 
  0x0423110c, 0x0a492312, 0x080a150c, 0x31002302,   // ro.ky.ru_543 ca.to.pt_654  un.mk.uk_543 ca.az.un_220 
  0x150a0712, 0x46005222, 0x32055212, 0xfe7963a0,   // bg.mk.un_654 ha.qu.un_870  ha.fr.bs_654 sco.war.tlh_322 
  0x212f46a7, 0x240925a0, 0x3e5a3312, 0xfe4e46ad,   // qu.su.jw_532 eu.pl.eo_322  nn.sm.rm_654 qu.ay.tlh_643 
  // [18d30]
  0x0a0b010c, 0x12290e0c, 0x6a4b4905, 0x12132a08,   // en.es.pt_543 is.sl.hu_543  to.mi.haw_333 mt.et.hu_443 
  0x22231d13, 0x0f402fa4, 0x17373c07, 0x0a224b11,   // la.ca.oc_665 su.lb.lv_433  ug.ba.sr_432 mi.oc.pt_653 
  0x633f0312, 0x426505ad, 0x3e00290b, 0x132e4d08,   // nl.af.sco_654 fr.gv.co_643  sl.rm.un_520 aa.fo.et_443 
  0x21656307, 0x092d13a0, 0x221812ee, 0x65005a08,   // sco.gv.jw_432 et.sk.pl_322  hu.ga.oc_422 sm.gv.un_430 
  // [18d40]
  0x310343a4, 0x3b59550d, 0x341a55a9, 0x21135ca9,   // ie.nl.az_433 rw.rn.so_554  rw.tl.xh_544 sa.et.jw_544 
  0x3b000104, 0x2d0d23a0, 0x3b6933a4, 0x442311a7,   // en.so.un_320 ca.cs.sk_322  nn.mfe.so_433 ro.ky.kk_532 
  0x13006522, 0x1a4d6507, 0x4c342c05, 0x0a171104,   // gv.et.un_870 gv.aa.tl_432  fy.xh.wo_333 ro.sr.mk_332 
  0x57271812, 0x085a5808, 0x1709520c, 0x02004d0c,   // ga.gd.na_654 om.sm.no_443  ha.pl.sr_543 aa.da.un_530 
  // [18d50]
  0x1a135a12, 0x5d0a36a0, 0x1d5134a0, 0x3b4c2c12,   // sm.et.tl_654 gn.pt.ss_322  xh.kl.la_322 fy.wo.so_654 
  0x30183412, 0x19000b20, 0x17152507, 0x070a08ee,   // ps.ar.uz_654 es.gl.un_850  mn.sr.un_420 uk.mk.bg_422 
  0x3100fc09, 0x36170a0c, 0x4a255bee, 0x1e002502,   // zzp.az.un_440 mk.sr.ab_543  sg.eu.yo_422 eu.ms.un_220 
  0x04630107, 0x352f21a4, 0x01366ba4, 0x022e0c07,   // en.sco.fi_432 jw.su.zu_433  ceb.gn.en_433 sv.fo.da_432 
  // [18d60]
  0x4a4d3e0d, 0x0d00041a, 0x302a5207, 0x6500621a,   // rm.aa.yo_554 fi.cs.un_760  ha.mt.uz_432 kha.gv.un_760 
  0xfe002a13, 0x090203a4, 0x2a003502, 0x15630107,   // mt.tlh.un_650 nl.da.pl_433  zu.mt.un_220 en.sco.un_432 
  0x630936a7, 0x101517a4, 0x3800650d, 0x0a17040c,   // gn.pl.sco_532 sr.be.un_430  gv.tk.un_540 ru.sr.mk_543 
  0x0c653812, 0x0409360c, 0x182863ee, 0x04630112,   // tk.gv.sv_654 gn.pl.fi_543  sco.sw.ga_422 en.sco.fi_654 
  // [18d70]
  0x32171ca0, 0x6309010c, 0x0c00620e, 0x091501a4,   // id.sr.bs_322 en.pl.sco_543  kha.sv.un_550 en.pl.un_430 
  0x2d0d01a4, 0x2d000a13, 0x0c1b2a0c, 0x2335070c,   // en.cs.sk_433 pt.sk.un_650  mt.tr.sv_543 bg.tg.ky_543 
  0x224253a0, 0x34234405, 0x2b655802, 0x584c3b11,   // ht.co.oc_322 kk.ky.ps_333  om.gv.vi_222 so.wo.om_653 
  0x383930a9, 0x23442507, 0x4e003614, 0x12002f0c,   // uz.br.tk_544 mn.kk.ky_432  gn.ay.un_660 su.hu.un_530 
  // [18d80]
  0x13003b1a, 0x25070807, 0x2400530b, 0x5300110c,   // so.et.un_760 uk.bg.mn_432  ht.eo.un_520 ro.ht.un_530 
  0x401358a7, 0x4c1a3b04, 0x073035a9, 0x1f002304,   // om.et.lb_532 so.tl.wo_332  tg.uz.bg_544 ca.cy.un_320 
  0x40001505, 0x3e560504, 0x40000c12, 0x29001504,   // un.lb.un_330 fr.mg.rm_332  sv.lb.un_640 un.sl.un_320 
  0x4e00571a, 0x28343da4, 0x28002a0b, 0x2d000914,   // na.ay.un_760 ku.ps.sd_433  mt.sw.un_520 pl.sk.un_660 
  // [18d90]
  0x4c1028ad, 0x011f23a7, 0x48441004, 0x04303560,   // sw.lt.wo_643 ca.cy.en_532  be.kk.tt_332 tg.uz.ru_664 
  0x23122804, 0x123c28a6, 0x3f002c33, 0x1723110b,   // sd.ur.ky_332 sd.ug.ur_521  fy.af.un_A70 ro.ky.sr_542 
  0x1e2025a9, 0x250928a7, 0x3600460d, 0x3f1129a0,   // eu.sq.ms_544 sw.pl.eu_532  qu.gn.un_540 sl.ro.af_322 
  0x041048a7, 0x3823440e, 0x2212050d, 0x20002504,   // tt.be.ru_532 kk.ky.tk_555  fr.hu.oc_554 eu.sq.un_320 
  // [18da0]
  0x33000b29, 0x300601a0, 0x05001208, 0x17111055,   // bn.as.un_960 en.de.uz_322  hu.fr.un_430 be.ro.sr_442 
  0x766169a4, 0x40005309, 0x48151712, 0x37104809,   // mfe.za.crs_433 ht.lb.un_440  sr.tt.un_640 tt.be.ba_444 
  0x4d4c460c, 0x464d2fad, 0x1d0a6010, 0x4c004623,   // qu.wo.aa_543 su.aa.qu_643  vo.pt.la_642 qu.wo.un_880 
  0x2000600d, 0x0b466309, 0x2000180b, 0x1e004c05,   // vo.sq.un_540 sco.qu.es_444  ga.sq.un_520 wo.ms.un_330 
  // [18db0]
  0x376b1ca0, 0x5f1a620e, 0x491827a6, 0x621a37a9,   // id.ceb.st_322 kha.tl.tn_555  gd.ga.to_521 st.tl.kha_544 
  0x367946ec, 0x37621ea4, 0x135305a0, 0x5f2f6208,   // qu.war.gn_644 ms.kha.st_433  fr.ht.et_322 kha.su.tn_443 
  0x462f4da7, 0x2160205e, 0x75735f0d, 0x792f1aa9,   // aa.su.qu_532 sq.vo.jw_652  tn.ny.nso_554 tl.su.war_544 
  0x79004608, 0x6b004619, 0x375f40af, 0x49fc3404,   // qu.war.un_430 qu.ceb.un_750  lb.tn.st_655 xh.zzp.to_332 
  // [18dc0]
  0x5f2c1a0e, 0x20222311, 0x1827490c, 0x02004a04,   // tl.fy.tn_555 ca.oc.sq_653  to.gd.ga_543 yo.da.un_320 
  0x1b0e0307, 0x283745a9, 0x37001a0d, 0x2f2162a0,   // nl.is.tr_432 ln.st.sw_544  tl.st.un_540 kha.jw.su_322 
  0x2500570c, 0x3f001705, 0x562e4555, 0x5f2e33af,   // na.eu.un_530 sr.af.un_330  ln.fo.mg_442 nn.fo.tn_655 
  0x44381508, 0x1500371b, 0x347345a4, 0x24523e0c,   // un.tk.kk_443 ba.un.un_770  ln.ny.xh_433 rm.ha.eo_543 
  // [18dd0]
  0x2f6b1a12, 0x56001302, 0x2f6b5708, 0x1d36300c,   // tl.ceb.su_654 et.mg.un_220  na.ceb.su_443 uz.gn.la_543 
  0x1a003304, 0x11074aa0, 0x61004b2b, 0x1123fc07,   // nn.tl.un_320 yo.it.ro_322  mi.za.un_980 zzp.ca.ro_432 
  0x22054011, 0x013378ad, 0x375f08a4, 0x0b49fead,   // lb.fr.oc_653 ve.nn.en_643  no.tn.st_433 tlh.to.es_643 
  0x01002e02, 0x22004008, 0x21005e08, 0x56490107,   // fo.en.un_220 lb.oc.un_430  ts.jw.un_430 en.to.mg_432 
  // [18de0]
  0x4732170e, 0x0d562d08, 0x3b006407, 0x362f22ad,   // sr.bs.sn_555 sk.mg.cs_443  lg.so.un_420 oc.su.gn_643 
  0x3b00060e, 0x2c5804ec, 0x56001a08, 0x045a5812,   // de.so.un_550 fi.om.fy_644  tl.mg.un_430 om.sm.fi_654 
  0x15246402, 0x544d13a4, 0x2c583bad, 0x1a4d3b0d,   // lg.eo.un_222 et.aa.ik_433  so.om.fy_643 so.aa.tl_554 
  0x36004e18, 0x153508a4, 0x04004d21, 0x58044d60,   // ay.gn.un_740 uk.tg.un_433  aa.fi.un_860 aa.fi.om_664 
  // [18df0]
  0x545158af, 0x58005109, 0x581304a4, 0x13111d05,   // om.kl.ik_655 kl.om.un_440  fi.et.om_433 la.ro.et_333 
  0x1d001f1a, 0x095601ee, 0x353c4411, 0x0f2e1ba0,   // cy.la.un_760 en.mg.pl_422  kk.ug.tg_653 tr.fo.lv_322 
  0x502d0d05, 0x30002402, 0x0d121802, 0x632c1504,   // cs.sk.fj_333 eo.uz.un_220  ga.hu.cs_222 un.fy.sco_332 
  0x313048af, 0x3f63380c, 0x086b33ad, 0x3e656304,   // tt.uz.az_655 tk.sco.af_543  nn.ceb.no_643 sco.gv.rm_332 
  // [18e00]
  0x5c0d13ad, 0x530d3fee, 0x42533e0c, 0x5600011a,   // bh.ne.sa_643 af.cs.ht_422  rm.ht.co_543 en.mg.un_760 
  0x5400fe19, 0x243e01a0, 0x02657907, 0x18006b09,   // tlh.ik.un_750 en.rm.eo_322  war.gv.da_432 ceb.ga.un_440 
  0x0b192208, 0x1e2721a0, 0xfe033008, 0x79003609,   // oc.gl.es_443 jw.gd.ms_322  uz.nl.tlh_443 gn.war.un_440 
  0x483610a9, 0x1f002f0e, 0x1d1f2f07, 0x122d0a04,   // be.ab.tt_544 su.cy.un_550  su.cy.la_432 pt.sk.hu_332 
  // [18e10]
  0x65693005, 0x0a001f07, 0x01004304, 0x2f005a02,   // uz.mfe.gv_333 cy.pt.un_420  ie.en.un_320 sm.su.un_220 
  0x2b002807, 0x25464211, 0x2f001f0d, 0x132758ee,   // sw.vi.un_420 co.qu.eu_653  cy.su.un_540 om.gd.et_422 
  0x2934350c, 0x1c002f05, 0x25007308, 0x250b0fa0,   // zu.xh.sl_543 su.id.un_330  ny.eu.un_430 lv.es.eu_322 
  0x02000319, 0x04373604, 0x3f002a0c, 0x29174c07,   // nl.da.un_750 ab.ba.ru_332  mt.af.un_530 wo.sr.sl_432 
  // [18e20]
  0x1c0309a9, 0x05002607, 0x5f00330d, 0x1d0b520b,   // pl.nl.id_544 ia.fr.un_420  nn.tn.un_540 ha.es.la_542 
  0x1d545e0e, 0x0d001318, 0x5a000a07, 0x5e28490c,   // ts.ik.la_555 bh.ne.un_740  pt.sm.un_420 to.sw.ts_543 
  0x35005207, 0x1c214aa0, 0x373c15a6, 0x49001108,   // ha.zu.un_420 yo.jw.id_322  un.ug.ba_521 ro.to.un_430 
  0x1a524dec, 0x0200780c, 0x0212470c, 0x0d5c090d,   // aa.ha.tl_644 ve.da.un_530  sn.hu.da_543 hi.sa.ne_554 
  // [18e30]
  0x104804ee, 0x1e6a46ee, 0x21025107, 0x062b1802,   // ru.tt.be_422 qu.haw.ms_422  kl.da.jw_432 ga.vi.de_222 
  0x6a5a4f04, 0x3400681a, 0x5d430207, 0x0d093bec,   // bi.sm.haw_332 ig.xh.un_760  da.ie.ss_432 ks.hi.ne_644 
  0x2b005504, 0x353468af, 0x3f002104, 0x5900550d,   // rw.vi.un_320 ig.xh.zu_655  jw.af.un_320 rw.rn.un_540 
  0xfc005704, 0x130d5c13, 0x30043512, 0x49000402,   // na.zzp.un_320 sa.ne.bh_665  tg.ru.uz_654 fi.to.un_220 
  // [18e40]
  0x4c53690d, 0x364904a0, 0x47004902, 0x1d2751ee,   // mfe.ht.wo_554 fi.to.gn_322  to.sn.un_220 kl.gd.la_422 
  0x04004b09, 0x25695355, 0x4d3163a0, 0x3d1823a4,   // mi.fi.un_440 ht.mfe.eu_442  sco.az.aa_322 ky.ar.ku_433 
  0x213d3060, 0x35361704, 0x17004407, 0xfc00550e,   // uz.ku.fa_664 sr.ab.tg_332  kk.sr.un_420 rw.zzp.un_550 
  0x36002502, 0x650436a0, 0x27006b05, 0x0a003c12,   // eu.gn.un_220 gn.fi.gv_322  ceb.gd.un_330 ug.mk.un_640 
  // [18e50]
  0x252e6904, 0x124004ee, 0x041351a0, 0x42001d0c,   // mfe.fo.eu_332 fi.lb.hu_422  kl.et.fi_322 la.co.un_530 
  0x016538ee, 0x543751af, 0xfc5f37ee, 0x40002010,   // tk.gv.en_422 kl.st.ik_655  st.tn.zzp_422 sq.lb.un_620 
  0x04000909, 0x1d494b0c, 0x07443004, 0x40002018,   // pl.fi.un_440 mi.to.la_543  uz.kk.bg_332 sq.lb.un_740 
  0x56003802, 0x041d47af, 0x4b4904ee, 0x0449020c,   // tk.mg.un_220 sn.la.fi_655  fi.to.mi_422 da.to.fi_543 
  // [18e60]
  0x1d100412, 0x135c0dac, 0x135a490d, 0x35302508,   // fi.lt.la_654 ne.sa.bh_632  to.sm.et_554 mn.uz.tg_443 
  0x360f67a4, 0x633809a4, 0x2b003904, 0x08380955,   // ak.lv.gn_433 pl.tk.sco_433  br.vi.un_320 pl.tk.no_442 
  0x59001b08, 0x30153505, 0x4700280e, 0x2e045007,   // tr.rn.un_430 tg.uz.un_330  sw.sn.un_550 fj.fi.fo_432 
  0x13041155, 0x38486007, 0x092504a4, 0x38005508,   // ro.fi.et_442 vo.tt.tk_432  fi.eu.pl_433 rw.tk.un_430 
  // [18e70]
  0x353457a9, 0x3038480e, 0x3435300c, 0x270402ee,   // na.xh.zu_544 tt.tk.uz_555  uz.zu.xh_543 da.fi.gd_422 
  0x04132405, 0x10443604, 0x041339ee, 0x1510040b,   // eo.et.fi_333 ab.kk.be_332  br.et.fi_422 ru.be.un_542 
  0x58513ba4, 0x4c3b13a4, 0x483837ec, 0x024d5812,   // so.kl.om_433 et.so.wo_433  ba.tk.tt_644 om.aa.da_654 
  0x28005a02, 0x1d043ba0, 0x2a004d1a, 0x134d2ca4,   // sm.sw.un_220 so.fi.la_322  aa.mt.un_760 fy.aa.et_433 
  // [18e80]
  0x58131da0, 0x3b4d585a, 0x405813ad, 0x150a070c,   // la.et.om_322 om.aa.so_553  et.om.lb_643 bg.mk.un_543 
  0x17233504, 0x2a005602, 0x13004f04, 0x29004b0c,   // tg.ky.sr_332 mg.mt.un_220  bi.et.un_320 mi.sl.un_530 
  0x1800600b, 0x4c00520b, 0x79000412, 0x4f49500e,   // vo.ga.un_520 ha.wo.un_520  fi.war.un_640 fj.to.bi_555 
  0x1b00240e, 0x1b25feac, 0x1a00011a, 0x5d000504,   // eo.tr.un_550 tlh.eu.tr_632  en.tl.un_760 fr.ss.un_320 
  // [18e90]
  0x033f3311, 0x011a21af, 0x36000911, 0x4b040f08,   // nn.af.nl_653 jw.tl.en_655  pl.gn.un_630 lv.fi.mi_443 
  0x23374812, 0x2e650109, 0x48375f04, 0x3f1a010b,   // tt.ba.ky_654 en.gv.fo_444  tn.st.tt_332 en.tl.af_542 
  0x13480204, 0x46005807, 0x04002d0e, 0x50004214,   // da.tt.et_332 om.qu.un_420  sk.fi.un_550 co.fj.un_660 
  0x52002811, 0x1a006b2b, 0x2e000c12, 0x49485711,   // sw.ha.un_630 ceb.tl.un_980  sv.fo.un_640 na.tt.to_653 
  // [18ea0]
  0x3e051ca0, 0x393028ec, 0x5200600c, 0xfc5e0205,   // id.fr.rm_322 sw.uz.br_644  vo.ha.un_530 da.ts.zzp_333 
  0x00002d2d, 0x627301a4, 0x686b01ee, 0x033301a9,   // sk.un.un_A00 en.ny.kha_433  en.ceb.ig_422 en.nn.nl_544 
  0x53795709, 0x1a3f0112, 0x1a4f0112, 0x52791512,   // na.war.ht_444 en.af.tl_654  en.bi.tl_654 un.war.ha_654 
  0x554a680d, 0x6700512b, 0x51002e02, 0x2f01210c,   // ig.yo.rw_554 kl.ak.un_980  fo.kl.un_220 jw.en.su_543 
  // [18eb0]
  0x24422aad, 0x092d0faf, 0x4d5e4aad, 0x57002522,   // mt.co.eo_643 lv.sk.pl_655  yo.ts.aa_643 eu.na.un_870 
  0x513308a0, 0x172b20a0, 0x08022e12, 0x622d0911,   // no.nn.kl_322 sq.vi.sr_322  fo.da.no_654 pl.sk.kha_653 
  0x4a3b2402, 0x13041b02, 0x0c5649ec, 0x48233055,   // eo.so.yo_222 tr.fi.et_222  to.mg.sv_644 uz.ky.tt_442 
  0x3300600d, 0x06005707, 0x080c0209, 0x30483708,   // vo.nn.un_540 na.de.un_420  da.sv.no_444 ba.tt.uz_443 
  // [18ec0]
  0x20000d02, 0x29622aa4, 0x44044805, 0x252a2907,   // cs.sq.un_220 mt.kha.sl_433  tt.ru.kk_333 sl.mt.eu_432 
  0x4c04135a, 0x29002a1b, 0x09130408, 0x303802a0,   // et.fi.wo_553 mt.sl.un_770  fi.et.pl_443 da.tk.uz_322 
  0x20002a22, 0x2a2029af, 0x30292aa0, 0x29225ca0,   // mt.sq.un_870 sl.sq.mt_655  mt.sl.uz_322 sa.oc.sl_322 
  0x233b29a9, 0x20002909, 0x2a322912, 0x123820a0,   // sl.so.ca_544 sl.sq.un_440  sl.bs.mt_654 sq.tk.hu_322 
  // [18ed0]
  0x045c290c, 0x2c002a0d, 0x2f042a0c, 0x13215c07,   // sl.sa.fi_543 mt.fy.un_540  mt.fi.su_543 sa.jw.et_432 
  0x30292aec, 0x5c290408, 0x13005108, 0x29004e19,   // mt.sl.uz_644 fi.sl.sa_443  kl.et.un_430 ay.sl.un_750 
  0x4000120c, 0x53004c09, 0x2a004c05, 0x59007305,   // hu.lb.un_530 wo.ht.un_440  wo.mt.un_330 ny.rn.un_330 
  0x5e35340c, 0x36254508, 0xfc5662a4, 0x2615010c,   // xh.zu.ts_543 ln.eu.gn_443  kha.mg.zzp_433 en.ia.un_530 
  // [18ee0]
  0x2c574913, 0x4d005820, 0x09001904, 0x3b044d05,   // to.na.fy_665 om.aa.un_850  gl.pl.un_320 aa.fi.so_333 
  0x58033f60, 0x49045804, 0x133b5808, 0x212f61a9,   // af.nl.om_664 om.fi.to_332  om.so.et_443 za.su.jw_544 
  0x3b00041b, 0x52610107, 0x5458040c, 0x182c57ec,   // fi.so.un_770 en.za.ha_432  fi.om.ik_543 na.fy.ga_644 
  0x614933a4, 0x15006112, 0x640458a0, 0x4c3b5855,   // nn.to.za_433 za.un.un_640  om.fi.lg_322 om.so.wo_442 
  // [18ef0]
  0x04104404, 0x4d304512, 0x0400180c, 0x5e341d04,   // kk.be.ru_332 ln.uz.aa_654  ga.fi.un_530 la.xh.ts_332 
  0x645851ec, 0x4d3b58ec, 0x78624b12, 0x10111d05,   // kl.om.lg_644 om.so.aa_644  mi.kha.ve_654 la.ro.lt_333 
  0x251d20a7, 0x51fe4da9, 0x1d580412, 0x04511360,   // sq.la.eu_532 aa.tlh.kl_544  fi.om.la_654 et.kl.fi_664 
  0x0f58510b, 0x440415a9, 0x513b58ad, 0x04514d5a,   // kl.om.lv_542 un.ru.kk_544  om.so.kl_643 aa.kl.fi_553 
  // [18f00]
  0x2916fc04, 0x3504070c, 0x51000409, 0x08000220,   // zzp.hr.sl_332 bg.ru.tg_543  fi.kl.un_440 da.no.un_850 
  0x11041d07, 0x2445390c, 0x253008ec, 0x152d5ea6,   // la.fi.ro_432 br.ln.eo_543  uk.uz.mn_644 ts.sk.un_521 
  0x0519220c, 0x12213b08, 0x04250804, 0x21002f11,   // oc.gl.fr_543 ks.fa.ur_443  uk.mn.ru_332 su.jw.un_630 
  0x2d0402a0, 0x4745350b, 0x59007309, 0x453559ee,   // da.fi.sk_322 zu.ln.sn_542  ny.rn.un_440 rn.zu.ln_422 
  // [18f10]
  0x4535340d, 0x03000d07, 0x19000a13, 0x35003804,   // xh.zu.ln_554 cs.nl.un_420  pt.gl.un_650 tk.zu.un_320 
  0x122318a7, 0x68091da4, 0x2a1209ee, 0x4f0c5707,   // ar.ky.ur_532 la.pl.ig_433  pl.hu.mt_422 na.sv.bi_432 
  0x46104eec, 0x354437ee, 0x6a4f4daf, 0x13000e18,   // ay.lt.qu_644 ba.kk.tg_422  aa.bi.haw_655 is.et.un_740 
  0x47000405, 0x47045013, 0x2c3e0713, 0x44183ca4,   // fi.sn.un_330 fj.fi.sn_665  it.rm.fy_665 ug.ar.kk_433 
  // [18f20]
  0x3e100412, 0x1c30480c, 0x3e002c13, 0x07003e22,   // fi.lt.rm_654 tt.uz.id_543  fy.rm.un_650 rm.it.un_870 
  0x1d002c13, 0x073e2caf, 0x2d463f07, 0x211234a9,   // fy.la.un_650 fy.rm.it_655  af.qu.sk_432 ps.ur.fa_544 
  0x494d57a4, 0x1d000421, 0x6b354b0c, 0x3e004b12,   // na.aa.to_433 fi.la.un_860  mi.zu.ceb_543 mi.rm.un_640 
  0x22001d1a, 0x503b5502, 0x1d3e0412, 0x1a212e07,   // la.oc.un_760 rw.so.fj_222  fi.rm.la_654 fo.jw.tl_432 
  // [18f30]
  0x4c69520c, 0x3c18340c, 0x35fc34ee, 0x1150280e,   // ha.mfe.wo_543 ps.ar.ug_543  xh.zzp.zu_422 sw.fj.ro_555 
  0x2d2a57a9, 0x62002d19, 0x65231f05, 0x393f02a4,   // na.mt.sk_544 sk.kha.un_750  cy.ca.gv_333 da.af.br_433 
  0x34231855, 0x42002107, 0x40062a05, 0x4815040b,   // ar.ky.ps_442 jw.co.un_420  mt.de.lb_333 ru.tt.un_520 
  0x5047fc0c, 0x451d040c, 0x12003e08, 0x23154411,   // zzp.sn.fj_543 fi.la.ln_543  rm.hu.un_430 kk.ky.un_630 
  // [18f40]
  0x794b1c07, 0x08150aee, 0x2011500c, 0x30001f08,   // id.mi.war_432 mk.uk.un_420  fj.ro.sq_543 cy.uz.un_430 
  0x20251d0c, 0x102e0e02, 0x23441108, 0x3e2d10a4,   // la.eu.sq_543 is.fo.lt_222  ro.kk.ky_443 lt.sk.rm_433 
  0x23191d0c, 0x52000208, 0x35282aee, 0x33085309,   // la.gl.ca_543 da.ha.un_430  mt.sw.zu_422 ht.no.nn_444 
  0x15441507, 0x4e005c0c, 0x1d255ea4, 0x51330204,   // un.kk.un_432 sa.ay.un_530  ts.eu.la_433 da.nn.kl_332 
  // [18f50]
  0x5c0413a4, 0x11026309, 0x28123460, 0x4d5202ec,   // et.fi.sa_433 sco.da.ro_444  ps.ur.sd_664 da.ha.aa_644 
  0x11001204, 0x35303804, 0x015705a0, 0x311b2009,   // hu.ro.un_320 tk.uz.tg_332  fr.na.en_322 sq.tr.az_444 
  0x12001e04, 0x341230a6, 0x264d520c, 0x1500010d,   // ms.hu.un_320 uz.ur.ps_521  ha.aa.ia_543 en.un.un_540 
  0x24002902, 0x0600021b, 0x63760107, 0x230c2213,   // sl.eo.un_220 da.de.un_770  en.crs.sco_432 oc.sv.ca_665 
  // [18f60]
  0x134d30a4, 0x30281209, 0x5e6501ee, 0xfc000408,   // uz.aa.et_433 ur.sd.uz_444  en.gv.ts_422 fi.zzp.un_430 
  0x56603fad, 0x30001b14, 0x304a3504, 0x3f001312,   // af.vo.mg_643 tr.uz.un_660  zu.yo.uz_332 et.af.un_640 
  0x1d1c43ee, 0x532c3f07, 0x25150107, 0x64280405,   // ie.id.la_422 af.fy.ht_432  en.eu.un_420 fi.sw.lg_333 
  0x63004014, 0xfc2501a4, 0x12005d02, 0x6b453504,   // lb.sco.un_660 en.eu.zzp_433  ss.hu.un_220 zu.ln.ceb_332 
  // [18f70]
  0x190b22ac, 0x531a6ba4, 0xfc0c1fa0, 0x100430a4,   // oc.es.gl_632 ceb.tl.ht_433  cy.sv.zzp_322 uz.fi.lt_433 
  0x343635a7, 0x15081712, 0x65003005, 0x65384c04,   // zu.gn.xh_532 sr.uk.un_654  uz.gv.un_330 wo.tk.gv_332 
  0x583925a7, 0x021e1c55, 0x303f130c, 0x3000020c,   // eu.br.om_532 id.ms.da_442  et.af.uz_543 da.uz.un_530 
  0x2c123fee, 0x21004007, 0x3000130d, 0x3f2a2cad,   // af.hu.fy_422 lb.jw.un_420  et.uz.un_540 fy.mt.af_643 
  // [18f80]
  0x442317a0, 0x595502af, 0x1d001312, 0x59630107,   // sr.ky.kk_322 da.rw.rn_655  et.la.un_640 en.sco.rn_432 
  0x3b303913, 0x195a4ca4, 0x18213c07, 0x25390908,   // br.uz.so_665 wo.sm.gl_433  ug.fa.ar_432 pl.br.eu_443 
  0x244cfc04, 0xfe0e230c, 0x352164a4, 0x3004080c,   // zzp.wo.eo_332 ca.is.tlh_543  lg.jw.zu_433 uk.ru.uz_543 
  0x0800071a, 0x16003208, 0x044408a4, 0x0800221d,   // bg.uk.un_760 bs.hr.un_430  uk.kk.ru_433 oc.no.un_820 
  // [18f90]
  0x2623220c, 0x1218300d, 0x452d0d12, 0x0207080c,   // oc.ca.ia_543 uz.ar.ur_554  cs.sk.ln_654 no.it.da_543 
  0x3b001921, 0x22656304, 0x303bfeaf, 0x420458a4,   // gl.so.un_860 sco.gv.oc_332  tlh.so.uz_655 om.fi.co_433 
  0x30396ea4, 0x36441007, 0x6e4cfe12, 0x1d5330a9,   // hmn.br.uz_433 be.kk.ab_432  tlh.wo.hmn_654 uz.ht.la_544 
  0x5a5f0e0d, 0x6e001609, 0x6e00fe07, 0x64495aa9,   // is.tn.sm_554 hr.hmn.un_440  tlh.hmn.un_420 sm.to.lg_544 
  // [18fa0]
  0x100a4455, 0x60005313, 0x616e4c14, 0xfe4c3bad,   // kk.mk.be_442 ht.vo.un_650  wo.hmn.za_666 so.wo.tlh_643 
  0x391f0ea4, 0x65064da4, 0x30006e12, 0xfe6e3011,   // is.cy.br_433 aa.de.gv_433  hmn.uz.un_640 uz.hmn.tlh_653 
  0x4f181f14, 0x2a002204, 0x1d001909, 0x235553a0,   // cy.ga.bi_666 oc.mt.un_320  gl.la.un_440 ht.rw.ca_322 
  0x6b004a09, 0x392542a9, 0x455d5504, 0x4a002a08,   // yo.ceb.un_440 co.eu.br_544  rw.ss.ln_332 mt.yo.un_430 
  // [18fb0]
  0x30fe6e13, 0x58045102, 0x58041307, 0xfe211cee,   // hmn.tlh.uz_665 kl.fi.om_222  et.fi.om_432 id.jw.tlh_422 
  0x02580405, 0x082333a9, 0x2863470c, 0x292b15ee,   // fi.om.da_333 nn.ca.no_544  sn.sco.sw_543 un.vi.sl_422 
  0x53396955, 0x34632808, 0x4a5c3fa9, 0x232d0d0c,   // mfe.br.ht_442 sw.sco.xh_443  af.sa.yo_544 cs.sk.ca_543 
  0x30122108, 0x39002a07, 0x50000402, 0x23441511,   // fa.ur.uz_443 mt.br.un_420  fi.fj.un_220 un.kk.ky_653 
  // [18fc0]
  0x1800341a, 0x0402255a, 0x02020508, 0x20360205,   // ps.ar.un_760 eu.da.fi_553  fr.da.da_443 da.gn.sq_333 
  0x562504ad, 0x283604a7, 0x1d1c4304, 0x4c132e08,   // fi.eu.mg_643 fi.gn.sw_532  ie.id.la_332 fo.et.wo_443 
  0x234f67a4, 0x1e13180c, 0x1a004f0d, 0x49001e02,   // ak.bi.ca_433 ga.et.ms_543  bi.tl.un_540 ms.to.un_220 
  0x4b284604, 0x176e20ad, 0x5c172102, 0x5a0f490c,   // qu.sw.mi_332 sq.hmn.sr_643  jw.sr.sa_222 to.lv.sm_543 
  // [18fd0]
  0x42490f12, 0x301120a7, 0x5c1d420c, 0x2d001307,   // lv.to.co_654 sq.ro.uz_532  co.la.sa_543 et.sk.un_420 
  0x65002a19, 0x353446ee, 0x1a002902, 0x49005805,   // mt.gv.un_750 qu.xh.zu_422  sl.tl.un_220 om.to.un_330 
  0x2f00450d, 0x3700fe12, 0x17442304, 0x42fe0f09,   // ln.su.un_540 tlh.st.un_640  ky.kk.sr_332 lv.tlh.co_444 
  0x49005712, 0x05621d04, 0x5a001c0d, 0x4c005012,   // na.to.un_640 la.kha.fr_332  id.sm.un_540 fj.wo.un_640 
  // [18fe0]
  0x5c001b13, 0x5a497907, 0x2d0d13af, 0x23201d0c,   // tr.sa.un_650 war.to.sm_432  et.cs.sk_655 la.sq.ca_543 
  0x490a4b04, 0x2f215009, 0x50496aa4, 0x5305230c,   // mi.pt.to_332 fj.jw.su_444  haw.to.fj_433 ca.fr.ht_543 
  0x3000540c, 0x07004904, 0x4f005012, 0x3e2d0d09,   // ik.uz.un_530 to.it.un_320  fj.bi.un_640 cs.sk.rm_444 
  0x022311ad, 0x2f21280c, 0x111e1c04, 0x051165a7,   // ro.ca.da_643 sw.jw.su_543  id.ms.ro_332 gv.ro.fr_532 
  // [18ff0]
  0x18282ba0, 0x30170a07, 0x4b495a5a, 0x251e5aa0,   // vi.sw.ga_322 mk.sr.uz_432  sm.to.mi_553 sm.ms.eu_322 
  0x65000513, 0x22006a0c, 0x113605a9, 0x180640ad,   // fr.gv.un_650 haw.oc.un_530  fr.gn.ro_544 lb.de.ga_643 
  0x22002317, 0x4b653902, 0x53560502, 0x28582012,   // ca.oc.un_730 br.gv.mi_222  fr.mg.ht_222 sq.om.sw_654 
  0x79402ba9, 0x34442313, 0x0a420507, 0x12060c07,   // vi.lb.war_544 ky.kk.ps_665  fr.co.pt_432 sv.de.hu_432 
  
  // [19000]
  0x44122807, 0x374825ee, 0x383c1508, 0x0e3f3304,   // sd.ur.kk_432 mn.tt.ba_422  un.ug.tk_443 nn.af.is_332 
  0x4973450c, 0x025f3708, 0x18122109, 0x73455daf,   // ln.ny.to_543 st.tn.da_443  fa.ur.ar_444 ss.ln.ny_655 
  0x213412ec, 0x4500371a, 0x153c1508, 0x791d010c,   // ur.ps.fa_644 st.ln.un_760  un.ug.un_443 en.la.war_543 
  0x0b054007, 0x0a15230e, 0x0d0165a0, 0x04794b04,   // lb.fr.es_432 ky.mk.un_550  gv.en.cs_322 mi.war.fi_332 
  // [19010]
  0x11173c05, 0x4c352ea0, 0x4b54040d, 0x36006a13,   // ug.sr.ro_333 fo.zu.wo_322  fi.ik.mi_554 haw.gn.un_650 
  0x6a024ba0, 0x5a454905, 0x1b380ca6, 0x36000418,   // mi.da.haw_322 to.ln.sm_333  sv.tk.tr_521 fi.gn.un_740 
  0x524b6aa7, 0x02004b05, 0x364b65af, 0x12000409,   // haw.mi.ha_532 mi.da.un_330  gv.mi.gn_655 fi.hu.un_440 
  0x40005802, 0x124b4902, 0x2f000a07, 0x3c070a07,   // om.lb.un_220 to.mi.hu_222  pt.su.un_420 mk.bg.ug_432 
  // [19020]
  0x190b53a0, 0x25005804, 0x2e000907, 0x100f4b07,   // ht.es.gl_322 om.eu.un_320  pl.fo.un_420 mi.lv.lt_432 
  0x01192402, 0x25234808, 0x1d050208, 0x390227ad,   // eo.gl.en_222 tt.ky.mn_443  da.fr.la_443 gd.da.br_643 
  0x150a0755, 0x18650308, 0x11456804, 0x15330807,   // bg.mk.un_442 nl.gv.ga_443  ig.ln.ro_332 no.nn.un_432 
  0x21183008, 0x02004b04, 0x054502a4, 0x061f7904,   // uz.ar.fa_443 mi.da.un_320  da.ln.fr_433 war.cy.de_332 
  // [19030]
  0x33004f07, 0x65270613, 0x13114fec, 0x652705a4,   // bi.nn.un_420 de.gd.gv_665  bi.ro.et_644 fr.gd.gv_433 
  0x3f274faf, 0x6500271a, 0x0a622305, 0x353634a7,   // bi.gd.af_655 gd.gv.un_760  ca.kha.pt_333 xh.gn.zu_532 
  0x54135108, 0x48373c08, 0x202135ee, 0x10000208,   // kl.et.ik_443 ug.ba.tt_443  zu.jw.sq_422 da.lt.un_430 
  0x3f5c37a0, 0x471351a0, 0x4f20fcee, 0x1900150c,   // st.sa.af_322 kl.et.sn_322  zzp.sq.bi_422 un.gl.un_530 
  // [19040]
  0x170929a4, 0x042e46ee, 0x51507307, 0x540951a9,   // sl.pl.sr_433 qu.fo.fi_422  ny.fj.kl_432 kl.pl.ik_544 
  0x290201a0, 0x4703590c, 0x45000513, 0x343d3b0c,   // en.da.sl_322 rn.nl.sn_543  fr.ln.un_650 ks.ku.ps_543 
  0x23071d05, 0x0b2d0aa0, 0x374417a0, 0x3f606208,   // la.it.ca_333 pt.sk.es_322  sr.kk.ba_322 kha.vo.af_443 
  0x123d3407, 0x374817ad, 0x57006314, 0x22fc57ee,   // ps.ku.ur_432 sr.tt.ba_643  sco.na.un_660 na.zzp.oc_422 
  // [19050]
  0x301b20ee, 0x7300fc08, 0x0f001d04, 0x79093e0e,   // sq.tr.uz_422 zzp.ny.un_430  la.lv.un_320 rm.pl.war_555 
  0x1e222007, 0x6b3320a0, 0x0f2d0910, 0x65620f0c,   // sq.oc.ms_432 sq.nn.ceb_322  pl.sk.lv_642 lv.kha.gv_543 
  0x092a7908, 0x0d2002ee, 0x093f0308, 0x631d2055,   // war.mt.pl_443 da.sq.cs_422  nl.af.pl_443 sq.la.sco_442 
  0x51083311, 0x2d001507, 0x1d002012, 0x20693e13,   // nn.no.kl_653 un.sk.un_420  sq.la.un_640 rm.mfe.sq_665 
  // [19060]
  0x36371507, 0x072d5011, 0x342321a0, 0x0d000508,   // un.ba.ab_432 fj.sk.it_653  fa.ky.ps_322 fr.cs.un_430 
  0x422d0511, 0x1a2f3613, 0x3b1a6b08, 0x436301ee,   // fr.sk.co_653 gn.su.tl_665  ceb.tl.so_443 en.sco.ie_422 
  0x2b005205, 0x18234402, 0x2a123bee, 0x23001e04,   // ha.vi.un_330 kk.ky.ar_222  so.hu.mt_422 ms.ca.un_320 
  0x63001f05, 0x05793904, 0x012f15a6, 0x521b1ca0,   // cy.sco.un_330 br.war.fr_332  un.su.en_521 id.tr.ha_322 
  // [19070]
  0x31481b11, 0x2e3b58ac, 0x21001c1a, 0x5c104ba9,   // tr.tt.az_653 om.so.fo_632  id.jw.un_760 mi.lt.sa_544 
  0x045164af, 0x584d6555, 0x640204a4, 0x4cfc6404,   // lg.kl.fi_655 gv.aa.om_442  fi.da.lg_433 lg.zzp.wo_332 
  0x544964ac, 0x060cfca7, 0x04515413, 0x1b026411,   // lg.to.ik_632 zzp.sv.de_532  ik.kl.fi_665 lg.da.tr_653 
  0x212f1217, 0x231564a0, 0x73006418, 0x2e6b5804,   // hu.su.jw_753 lg.ca.un_320  lg.ny.un_740 om.ceb.fo_332 
  // [19080]
  0x6446040c, 0x4d640412, 0x6400040d, 0x30341804,   // fi.qu.lg_543 fi.lg.aa_654  fi.lg.un_540 ar.ps.uz_332 
  0x42002202, 0x23390507, 0x0715100b, 0x0807100e,   // oc.co.un_220 fr.br.ca_432  be.bg.un_520 be.bg.uk_555 
  0x53021fa0, 0x1c002012, 0x3d003c02, 0x04151508,   // cy.da.ht_322 sq.id.un_640  ug.ku.un_220 un.ru.un_430 
  0x2e2d0d13, 0x3324120c, 0x1e2ffea7, 0x42272b08,   // cs.sk.fo_665 hu.eo.nn_543  tlh.su.ms_532 vi.gd.co_443 
  // [19090]
  0x35343005, 0x04136504, 0x4d2d0d0e, 0x1233fe07,   // uz.xh.zu_333 gv.et.fi_332  cs.sk.aa_555 tlh.nn.hu_432 
  0x652715a0, 0x18fc0107, 0x30000d14, 0x11100fee,   // un.gd.gv_322 en.zzp.ga_432  cs.uz.un_660 lv.lt.ro_422 
  0x4300200d, 0x0a07040c, 0x190b2209, 0x482d0d0d,   // sq.ie.un_540 ru.bg.mk_543  oc.es.gl_444 cs.sk.tt_554 
  0x56003b04, 0x13004e22, 0x2f121ca4, 0x23212211,   // so.mg.un_320 ay.et.un_870  id.hu.su_433 oc.jw.ca_653 
  // [190a0]
  0x0d2d0e55, 0x51313ba4, 0x16622907, 0x19000508,   // is.sk.cs_442 so.az.kl_433  sl.kha.hr_432 fr.gl.un_430 
  0x1e1c01ee, 0x2e2d0e08, 0x4846fe04, 0x13511008,   // en.id.ms_422 is.sk.fo_443  tlh.qu.tt_332 lt.kl.et_443 
  0x22002d04, 0x3f000f02, 0x212746a0, 0x49000f0e,   // sk.oc.un_320 lv.af.un_220  qu.gd.jw_322 lv.to.un_550 
  0x1500260c, 0x15003909, 0x262d010b, 0x0807350c,   // ia.un.un_530 br.un.un_440  en.sk.ia_542 tg.bg.uk_543 
  // [190b0]
  0x29021d07, 0x50003f02, 0x0f006e13, 0x1d4f610c,   // la.da.sl_432 af.fj.un_220  hmn.lv.un_650 za.bi.la_543 
  0x18004f0c, 0x100313a0, 0x462c03a7, 0x36230d5a,   // bi.ga.un_530 et.nl.lt_322  nl.fy.qu_532 cs.ca.gn_553 
  0x551d5c05, 0x21001307, 0x0a370ca6, 0x040710af,   // sa.la.rw_333 et.jw.un_420  sv.st.pt_521 be.bg.ru_655 
  0x3800610c, 0x38233008, 0x12006111, 0x2d0d3d11,   // za.tk.un_530 uz.ky.tk_443  za.hu.un_630 ku.ne.syr_653 
  // [190c0]
  0x5600610e, 0x4839310b, 0x231d435a, 0x123428ad,   // za.mg.un_550 az.br.tt_542  ie.la.ca_553 sd.ps.ur_643 
  0x302a610b, 0x18003d18, 0x1d000514, 0x2d0d2c09,   // za.mt.uz_542 ku.ar.un_740  fr.la.un_660 fy.cs.sk_444 
  0x3e00251a, 0x024b2504, 0x3e371d07, 0x1c002302,   // eu.rm.un_760 eu.mi.da_332  la.st.rm_432 ca.id.un_220 
  0x6a00131b, 0x3e000a07, 0x56000d0b, 0x21000213,   // et.haw.un_770 pt.rm.un_420  cs.mg.un_520 ja.fa.un_650 
  // [190d0]
  0x0d562d04, 0x62251108, 0x330859a0, 0x1d2311ee,   // sk.mg.cs_332 ro.eu.kha_443  rn.no.nn_322 ro.ca.la_422 
  0x615702af, 0x65002512, 0x47136507, 0x62051012,   // da.na.za_655 eu.gv.un_640  gv.et.sn_432 lt.fr.kha_654 
  0x134736a4, 0x50004702, 0x39114b07, 0x5c0f4bad,   // gn.sn.et_433 sn.fj.un_220  mi.ro.br_432 mi.lv.sa_643 
  0x22005312, 0x230522ea, 0x39006114, 0x34000104,   // ht.oc.un_640 oc.fr.ca_822  za.br.un_660 en.xh.un_320 
  // [190e0]
  0x2e0c0ea7, 0xfc004207, 0x0e5852a9, 0x643e79a7,   // is.sv.fo_532 co.zzp.un_420  ha.om.is_544 war.rm.lg_532 
  0x0813600c, 0x0d003504, 0x0c01fc07, 0x041a47ee,   // vo.et.no_543 zu.cs.un_320  zzp.en.sv_432 sn.tl.fi_422 
  0x6b391d07, 0xfe6e13a0, 0x651d0107, 0x5c355da0,   // la.br.ceb_432 et.hmn.tlh_322  en.la.gv_432 ss.zu.sa_322 
  0x190a43a0, 0x28215c5a, 0x351730a0, 0x6b796804,   // ie.pt.gl_322 sa.jw.sw_553  uz.sr.tg_322 ig.war.ceb_332 
  // [190f0]
  0x6452730c, 0x11002a0d, 0x28735a0d, 0x5d355c12,   // ny.ha.lg_543 mt.ro.un_540  sm.ny.sw_554 sa.zu.ss_654 
  0x695d1fa4, 0x45642805, 0x091e1c04, 0x2e130e0e,   // cy.ss.mfe_433 sw.lg.ln_333  id.ms.pl_332 is.et.fo_555 
  0x4a005212, 0x64555aa4, 0x043908a4, 0x202f300c,   // ha.yo.un_640 sm.rw.lg_433  no.br.fi_433 uz.su.sq_543 
  0x1e1a5eee, 0x280259ec, 0x401e1c60, 0x735d3508,   // ts.tl.ms_422 rn.da.sw_644  id.ms.lb_664 zu.ss.ny_443 
  // [19100]
  0x4a13340e, 0x58026805, 0x4b582509, 0x58301ca4,   // xh.et.yo_555 ig.da.om_333  eu.om.mi_444 id.uz.om_433 
  0x205b73ec, 0x212f6108, 0x68023b0c, 0x3403fc0e,   // ny.sg.sq_644 za.su.jw_443  so.da.ig_543 zzp.nl.xh_555 
  0x1c020e0c, 0x2a565407, 0x531b3408, 0x02102708,   // is.da.id_543 ik.mg.mt_432  xh.tr.ht_443 gd.lt.da_443 
  0x1f276509, 0x582d01a0, 0x52645508, 0x211e1c13,   // gv.gd.cy_444 en.sk.om_322  rw.lg.ha_443 id.ms.jw_665 
  // [19110]
  0x5e003008, 0x5e003b21, 0x124006ee, 0x07fe22a9,   // uz.ts.un_430 so.ts.un_860  de.lb.hu_422 oc.tlh.it_544 
  0x216228ad, 0x4b5e5711, 0x4b003304, 0x20305005,   // sw.kha.jw_643 na.ts.mi_653  nn.mi.un_320 fj.uz.sq_333 
  0x551f3908, 0x1d002713, 0x190b4605, 0x35252305,   // br.cy.rw_443 gd.la.un_650  qu.es.gl_333 ky.mn.tg_333 
  0x33000408, 0x100a0404, 0x0d131ca7, 0x442337af,   // fi.nn.un_430 ru.mk.be_332  mr.bh.ne_532 ba.ky.kk_655 
  // [19120]
  0x50765d04, 0x1d0549a0, 0x11311b12, 0x48070a0c,   // ss.crs.fj_332 to.fr.la_322  tr.az.ro_654 mk.bg.tt_543 
  0x205013a4, 0x501d4755, 0x12000f1a, 0x291647a6,   // et.fj.sq_433 sn.la.fj_442  lv.hu.un_760 sn.hr.sl_521 
  0x230804a0, 0x24004905, 0x475e0709, 0x6b021dee,   // ru.uk.ky_322 to.eo.un_330  it.ts.sn_444 la.da.ceb_422 
  0x2a2e0708, 0x0817360c, 0x4f07500c, 0x483007ee,   // it.fo.mt_443 ab.sr.uk_543  fj.it.bi_543 bg.uz.tt_422 
  // [19130]
  0x28005a1b, 0x15253612, 0x1f006412, 0x1c005608,   // sm.sw.un_770 ab.mn.un_654  lg.cy.un_640 mg.id.un_430 
  0x463f62ee, 0x472834a4, 0x28476408, 0x172a56a0,   // kha.af.qu_422 xh.sw.sn_433  lg.sn.sw_443 mg.mt.sr_322 
  0x1a6b3f05, 0x4900180c, 0x28004d0c, 0x5c00561a,   // af.ceb.tl_333 ga.to.un_530  aa.sw.un_530 mg.sa.un_760 
  0x2f4556ee, 0x0c2930ee, 0x5a005207, 0x352240ee,   // mg.ln.su_422 uz.sl.sv_422  ha.sm.un_420 lb.oc.zu_422 
  // [19140]
  0x5632170e, 0x79645aa9, 0x55735607, 0x40375f13,   // sr.bs.mg_555 sm.lg.war_544  mg.ny.rw_432 tn.st.lb_665 
  0x21375f60, 0x606b1a08, 0x21375f0e, 0x22390d04,   // tn.st.jw_664 tl.ceb.vo_443  tn.st.jw_555 cs.br.oc_332 
  0x50005104, 0x37005f23, 0x212f1a08, 0x6360fe0c,   // kl.fj.un_320 tn.st.un_880  tl.su.jw_443 tlh.vo.sco_543 
  0x02622fa4, 0x79375f07, 0x5d004904, 0x21755fa9,   // su.kha.da_433 tn.st.war_432  to.ss.un_320 tn.nso.jw_544 
  // [19150]
  0x491f1813, 0x074b5aa4, 0x2d005618, 0x475e2807,   // ga.cy.to_665 sm.mi.it_433  mg.sk.un_740 sw.ts.sn_432 
  0x594679a4, 0x30352513, 0x28006809, 0x212f61ee,   // war.qu.rn_433 mn.tg.uz_665  ig.sw.un_440 za.su.jw_422 
  0x04001b02, 0x4c04510c, 0x111b310b, 0x19560b5a,   // tr.fi.un_220 kl.fi.wo_543  az.tr.ro_542 es.mg.gl_553 
  0x092d11a4, 0x1a007913, 0x37755f08, 0x046402a0,   // ro.sk.pl_433 war.tl.un_650  tn.nso.st_443 da.lg.fi_322 
  // [19160]
  0x5f3721a9, 0x5f212fa9, 0x2f5f3708, 0x390d0204,   // jw.st.tn_544 su.jw.tn_544  st.tn.su_443 da.cs.br_332 
  0x37041107, 0x1b044ea9, 0x04483504, 0x30483704,   // ro.ru.ba_432 ay.fi.tr_544  tg.tt.ru_332 ba.tt.uz_332 
  0x083f2c11, 0x56004f0d, 0x123130a0, 0x17042304,   // fy.af.no_653 bi.mg.un_540  uz.az.hu_322 ky.ru.sr_332 
  0x030625ee, 0x2e0efeac, 0x10002514, 0x2818340b,   // eu.de.nl_422 tlh.is.fo_632  mn.be.un_660 ps.ar.sd_542 
  // [19170]
  0x3c1823a0, 0x20311b12, 0x48063604, 0x5e293f07,   // ky.ar.ug_322 tr.az.sq_654  gn.de.tt_332 af.sl.ts_432 
  0x385f0aa0, 0x5800400d, 0x2800030c, 0x37041755,   // pt.tn.tk_322 lb.om.un_540  nl.sw.un_530 sr.ru.ba_442 
  0x38003704, 0x17290207, 0x48004c13, 0x3b2a570b,   // st.tk.un_320 da.sl.sr_432  wo.tt.un_650 na.mt.so_542 
  0x2f002a07, 0x35080a07, 0x02402104, 0x2a206112,   // mt.su.un_420 mk.uk.tg_432  jw.lb.da_332 za.sq.mt_654 
  // [19180]
  0x09112da0, 0x59fc5708, 0x130b670c, 0x42232708,   // sk.ro.pl_322 na.zzp.rn_443  ak.es.et_543 gd.ca.co_443 
  0x636520a0, 0x33014f0c, 0x07424f05, 0x32170da4,   // sq.gv.sco_322 bi.en.nn_543  bi.co.it_333 cs.sr.bs_433 
  0x29322d14, 0x1d4509ad, 0x100e1f0c, 0x33003007,   // sk.bs.sl_666 pl.ln.la_643  cy.is.lt_543 uz.nn.un_420 
  0x11311b0d, 0x1b30fc07, 0x20091fa0, 0x480a10ee,   // tr.az.ro_554 zzp.uz.tr_432  cy.pl.sq_322 be.mk.tt_422 
  // [19190]
  0x07040a0c, 0x794c05a9, 0x11001b10, 0x4c2305a9,   // mk.ru.bg_543 fr.wo.war_544  tr.ro.un_620 fr.ca.wo_544 
  0x4c400507, 0x4c00220e, 0x4c002104, 0x05003602,   // fr.lb.wo_432 oc.wo.un_550  jw.wo.un_320 gn.fr.un_220 
  0x234a4c07, 0x1b00fc0e, 0x05004c07, 0x2300430b,   // wo.yo.ca_432 zzp.tr.un_550  wo.fr.un_420 ie.ca.un_520 
  0x3c073812, 0x360b1307, 0x0a001805, 0x2d00fe14,   // tk.bg.ug_654 et.es.gn_432  ga.pt.un_330 tlh.sk.un_660 
  // [191a0]
  0x230b13a0, 0x0c4333a0, 0x17202d07, 0x4c4205ad,   // et.es.ca_322 nn.ie.sv_322  sk.sq.sr_432 fr.co.wo_643 
  0x05000d1a, 0x3f1d010c, 0x18275ca4, 0x0e171355,   // cs.fr.un_760 en.la.af_543  sa.gd.ga_433 et.sr.is_442 
  0x181f2708, 0x30001111, 0x48044404, 0x31481b60,   // gd.cy.ga_443 ro.uz.un_630  kk.ru.tt_332 tr.tt.az_664 
  0x2325150b, 0x2f3330a9, 0x2800302a, 0xfe623011,   // un.mn.ky_542 uz.nn.su_544  uz.sw.un_970 uz.kha.tlh_653 
  // [191b0]
  0x0d1b30a0, 0x1f1b650d, 0x31301b05, 0x0d2d5d04,   // uz.tr.cs_322 gv.tr.cy_554  tr.uz.az_333 ss.sk.cs_332 
  0x1b000d05, 0x443418ec, 0xfe484d04, 0x0cfe1e07,   // cs.tr.un_330 ar.ps.kk_644  aa.tt.tlh_332 ms.tlh.sv_432 
  0x0a001d05, 0xfe0d7307, 0x28fe35a0, 0x1b0ffe07,   // la.pt.un_330 ny.cs.tlh_432  zu.tlh.sw_322 tlh.lv.tr_432 
  0x312a1c09, 0x0b002307, 0x653260ac, 0x6e00300d,   // id.mt.az_444 ca.es.un_420  vo.bs.gv_632 uz.hmn.un_540 
  // [191c0]
  0x6b4c1dec, 0x21280207, 0x2101fca4, 0x0a3618a9,   // la.wo.ceb_644 da.sw.jw_432  zzp.en.jw_433 ga.gn.pt_544 
  0x3900220e, 0x1f472ba7, 0x39400255, 0x5a005002,   // oc.br.un_550 vi.sn.cy_532  da.lb.br_442 fj.sm.un_220 
  0x4a001505, 0x52002a05, 0x65066aec, 0x65490607,   // un.yo.un_330 mt.ha.un_330  haw.de.gv_644 de.to.gv_432 
  0x0200270c, 0x0b0a23a0, 0x302a200c, 0x02212714,   // gd.da.un_530 ca.pt.es_322  sq.mt.uz_543 gd.jw.da_666 
  // [191d0]
  0x11182712, 0x24003e05, 0x28213413, 0x5c0c6aec,   // gd.ga.ro_654 rm.eo.un_330  ps.fa.sd_665 haw.sv.sa_644 
  0x0e062e12, 0x48271f05, 0x79652712, 0x27006905,   // fo.de.is_654 cy.gd.tt_333  gd.gv.war_654 mfe.gd.un_330 
  0x42004c12, 0x182a06ee, 0x0600320c, 0x4b4967ad,   // wo.co.un_640 de.mt.ga_422  bs.de.un_530 ak.to.mi_643 
  0x03243fa0, 0x3f2224a4, 0x73fe01a0, 0x220665a0,   // af.eo.nl_322 eo.oc.af_433  en.tlh.ny_322 gv.de.oc_322 
  // [191e0]
  0x18fc56a0, 0x30314812, 0x651a6304, 0x431501a4,   // mg.zzp.ga_322 tt.az.uz_654  sco.tl.gv_332 en.ie.un_430 
  0x1d2e0e07, 0x3148650c, 0x251827ac, 0x27366507,   // is.fo.la_432 gv.tt.az_543  gd.ga.eu_632 gv.gn.gd_432 
  0x352e3404, 0x17002e07, 0x5f1f7807, 0x564773a4,   // xh.fo.zu_332 fo.sr.un_420  ve.cy.tn_432 ny.sn.mg_433 
  0x0b000f07, 0x2f2036a4, 0x36182b12, 0x1d21100c,   // lv.es.un_420 gn.sq.su_433  vi.ga.gn_654 lt.jw.la_543 
  // [191f0]
  0x202813a4, 0x1d135a0c, 0x5c00131b, 0x32170f14,   // et.sw.sq_433 sm.et.la_543  et.sa.un_770 lv.sr.bs_666 
  0x16426755, 0x50003704, 0x335c20ee, 0x11131d13,   // ak.co.hr_442 st.fj.un_320  sq.sa.nn_422 la.et.ro_665 
  0x0400580c, 0x5a00491a, 0x591d11a4, 0x1d006712,   // om.fi.un_530 to.sm.un_760  ro.la.rn_433 ak.la.un_640 
  0x110a1dad, 0x38005411, 0x2500441a, 0x56382102,   // la.pt.ro_643 ik.tk.un_630  kk.mn.un_760 jw.tk.mg_222 
  // [19200]
  0x3b330804, 0x1c005c23, 0x28002a08, 0x171d24af,   // no.nn.so_332 sa.mr.un_880  mt.sw.un_430 eo.la.sr_655 
  0x4c002822, 0x0d003507, 0x2a4c6407, 0x4c23220c,   // sw.wo.un_870 zu.cs.un_420  lg.wo.mt_432 oc.ca.wo_543 
  0x0b051d55, 0x04104804, 0x5c630107, 0x2100181a,   // la.fr.es_442 tt.be.ru_332  en.sco.sa_432 ar.fa.un_760 
  0x202873ad, 0x34fc355a, 0x070d4a05, 0x3b045fa0,   // ny.sw.sq_643 zu.zzp.xh_553  yo.cs.it_333 tn.fi.so_322 
  // [19210]
  0x58484dec, 0x42001f19, 0x29284fec, 0x1f002a2a,   // aa.tt.om_644 cy.co.un_750  bi.sw.sl_644 mt.cy.un_970 
  0x23001f1b, 0x2443010c, 0x452f1fa6, 0x10324004,   // cy.ca.un_770 en.ie.eo_543  cy.su.ln_521 lb.bs.lt_332 
  0x5f00560e, 0x2a672904, 0x20072ea0, 0x38353013,   // mg.tn.un_550 sl.ak.mt_332  fo.it.sq_322 uz.tg.tk_665 
  0x2305120c, 0x04371702, 0x3d303455, 0x18004802,   // hu.fr.ca_543 sr.ba.ru_222  ps.uz.ku_442 tt.ga.un_220 
  // [19220]
  0x230b05ac, 0x12003c04, 0x283b58a4, 0x0a070811,   // fr.es.ca_632 ug.ur.un_320  om.so.sw_433 uk.bg.mk_653 
  0x5146600c, 0x51384f0d, 0x0c000a05, 0x1a38515a,   // vo.qu.kl_543 bi.tk.kl_554  pt.sv.un_330 kl.tk.tl_553 
  0x5d00181e, 0x5300512a, 0x611b380c, 0x1a0238a0,   // ga.ss.un_830 kl.ht.un_970  tk.tr.za_543 tk.da.tl_322 
  0x17253807, 0x45005619, 0x221b48a0, 0x04113c0b,   // tk.mn.sr_432 mg.ln.un_750  tt.tr.oc_322 ug.ro.ru_542 
  // [19230]
  0x215322a9, 0x0a1059a0, 0x0a360707, 0x1b381d08,   // oc.ht.jw_544 rn.lt.pt_322  bg.ab.mk_432 la.tk.tr_443 
  0x541b3811, 0x05215ca7, 0x48005102, 0x23004c08,   // tk.tr.ik_653 sa.jw.fr_532  kl.tt.un_220 wo.ca.un_430 
  0x62511ea4, 0x385101a4, 0x34005612, 0x51384607,   // ms.kl.kha_433 en.kl.tk_433  mg.xh.un_640 qu.tk.kl_432 
  0x5c003409, 0xfe4620af, 0x4c00230c, 0x20002309,   // xh.sa.un_440 sq.qu.tlh_655  ca.wo.un_530 ca.sq.un_440 
  // [19240]
  0x1a215604, 0x0200340e, 0x12002f0e, 0x122118ac,   // mg.jw.tl_332 xh.da.un_550  su.hu.un_550 ar.fa.ur_632 
  0x0200490d, 0x10005621, 0x05245613, 0x480437a6,   // to.da.un_540 mg.lt.un_860  mg.eo.fr_665 ba.ru.tt_521 
  0x12212fa7, 0x12244dee, 0x02576bad, 0x21232204,   // su.jw.hu_532 aa.eo.hu_422  ceb.na.da_643 oc.ca.jw_332 
  0x6b006a05, 0x2059fea4, 0x765369ad, 0x4d697612,   // haw.ceb.un_330 tlh.rn.sq_433  mfe.ht.crs_643 crs.mfe.aa_654 
  // [19250]
  0x0a5602ee, 0x39256ba0, 0x321709a4, 0x30584d11,   // da.mg.pt_422 ceb.eu.br_322  pl.sr.bs_433 aa.om.uz_653 
  0x154c05ee, 0x68420755, 0x120d22ee, 0xfe005f0c,   // fr.wo.un_422 it.co.ig_442  oc.cs.hu_422 tn.tlh.un_530 
  0x51006013, 0x2b5d1804, 0x195cfe0b, 0x283435a4,   // vo.kl.un_650 ga.ss.vi_332  tlh.sa.gl_542 zu.xh.sw_433 
  0x201a38a0, 0x11002704, 0x0e0205a0, 0x0c2402a7,   // tk.tl.sq_322 gd.ro.un_320  fr.da.is_322 da.eo.sv_532 
  // [19260]
  0x422305ee, 0x462d180b, 0x2a006519, 0x3b2830ac,   // fr.ca.co_422 ga.sk.qu_542  gv.mt.un_750 uz.sd.ks_632 
  0x34001805, 0x0407175a, 0x0c254d08, 0x080c2507,   // ar.ps.un_330 sr.bg.ru_553  aa.eu.sv_443 eu.sv.no_432 
  0x442134a0, 0x18003611, 0x3c233007, 0x1c000302,   // ps.fa.kk_322 gn.ga.un_630  uz.ky.ug_432 nl.id.un_220 
  0x122e0e05, 0x20791107, 0x10374805, 0x2e003904,   // is.fo.hu_333 ro.war.sq_432  tt.ba.be_333 br.fo.un_320 
  // [19270]
  0x3415680c, 0x23192d02, 0x122219a0, 0x05221207,   // ig.xh.un_530 sk.gl.ca_222  gl.oc.hu_322 hu.oc.fr_432 
  0x5c130da7, 0x0b190a07, 0x0b0a0714, 0x1a00500c,   // ne.bh.sa_532 pt.gl.es_432  it.pt.es_666 fj.tl.un_530 
  0x0500260b, 0x18190b04, 0x262568ec, 0x394dfc14,   // ia.fr.un_520 es.gl.ga_332  ig.eu.ia_644 zzp.aa.br_666 
  0x4a221d02, 0x222d0d08, 0x3748365a, 0x390522a0,   // la.oc.yo_222 cs.sk.oc_443  ab.tt.ba_553 oc.fr.br_322 
  // [19280]
  0x5f373408, 0x23420a0d, 0x17303ca0, 0x0b290d0c,   // xh.st.tn_443 pt.co.ca_554  ug.uz.sr_322 cs.sl.es_543 
  0x64002a08, 0x630a0ca4, 0x30100f14, 0x241d2607,   // mt.lg.un_430 sv.pt.sco_433  lv.lt.uz_666 ia.la.eo_432 
  0x367345a7, 0x73375f02, 0x302812ee, 0x5e00fc07,   // ln.ny.gn_532 tn.st.ny_222  ur.sd.uz_422 zzp.ts.un_420 
  0x3e004a09, 0x38000608, 0x48060c0b, 0x6502070b,   // yo.rm.un_440 de.tk.un_430  sv.de.tt_542 it.da.gv_542 
  // [19290]
  0x38000c19, 0x231d24af, 0x202578ee, 0x3e480607,   // sv.tk.un_750 eo.la.ca_655  ve.eu.sq_422 de.tt.rm_432 
  0x1d002408, 0x28443d07, 0x1d080208, 0x353432a0,   // eo.la.un_430 ku.kk.sd_432  da.no.la_443 bs.xh.zu_322 
  0x48043704, 0x39650e0c, 0x0c041308, 0x13006014,   // ba.ru.tt_332 is.gv.br_543  et.fi.sv_443 vo.et.un_660 
  0x1b0712a4, 0x3e271f0c, 0x070a0804, 0x060f1fa7,   // hu.it.tr_433 cy.gd.rm_543  uk.mk.bg_332 cy.lv.de_532 
  // [192a0]
  0x220425a7, 0x120a4aaf, 0x123b3408, 0x31384ca9,   // eu.fi.oc_532 yo.pt.hu_655  ps.ks.ur_443 wo.tk.az_544 
  0x181f0807, 0x36004e08, 0x48443cee, 0x38233612,   // no.cy.ga_432 ay.gn.un_430  ug.kk.tt_422 ab.ky.tk_654 
  0x0e2e0d0c, 0x12360eaf, 0x46002c02, 0x08441507,   // cs.fo.is_543 is.gn.hu_655  fy.qu.un_220 un.kk.uk_432 
  0x0a2e0ea9, 0x55001e13, 0x13095cee, 0x400660ad,   // is.fo.pt_544 ms.rw.un_650  sa.hi.bh_422 vo.de.lb_643 
  // [192b0]
  0x53004202, 0x691d250c, 0xfc0f68a0, 0x17004408,   // co.ht.un_220 eu.la.mfe_543  ig.lv.zzp_322 kk.sr.un_430 
  0x18004421, 0x2200420e, 0x4a0545a4, 0x23190a05,   // kk.ar.un_860 co.oc.un_550  ln.fr.yo_433 pt.gl.ca_333 
  0x15043760, 0x37003808, 0x3e07fcad, 0x65002b02,   // ba.ru.un_664 tk.ba.un_430  zzp.it.rm_643 vi.gv.un_220 
  0x1500251b, 0x42054c55, 0x4c12050c, 0x081748a0,   // mn.un.un_770 wo.fr.co_442  fr.hu.wo_543 tt.sr.uk_322 
  // [192c0]
  0x797601a9, 0x28003508, 0x03061812, 0x21004704,   // en.crs.war_544 zu.sw.un_430  ga.de.nl_654 sn.jw.un_320 
  0x373848a4, 0x09001b0c, 0x1c1b6207, 0x5c00280d,   // tt.tk.ba_433 tr.pl.un_530  kha.tr.id_432 sw.sa.un_540 
  0x4c002a08, 0x2f212005, 0x6b2f1c07, 0x0d364a07,   // mt.wo.un_430 sq.jw.su_333  id.su.ceb_432 yo.gn.cs_432 
  0x23000207, 0x17114407, 0x357834a9, 0x38353ca4,   // da.ca.un_420 kk.ro.sr_432  xh.ve.zu_544 ug.tg.tk_433 
  // [192d0]
  0x383031ad, 0x104616a0, 0x134c1007, 0x1b1321a4,   // az.uz.tk_643 hr.qu.lt_322  lt.wo.et_432 jw.et.tr_433 
  0x095a49ee, 0x0c0206a4, 0x1c003302, 0x5524020e,   // to.sm.pl_422 de.da.sv_433  nn.id.un_220 da.eo.rw_555 
  0x0c2206ee, 0x24001f12, 0x2e003802, 0x4000110b,   // de.oc.sv_422 cy.eo.un_640  tk.fo.un_220 ro.lb.un_520 
  0x5d067909, 0x1a4b50ee, 0x5a00040e, 0x62604708,   // war.de.ss_444 fj.mi.tl_422  fi.sm.un_550 sn.vo.kha_443 
  // [192e0]
  0x39060ca4, 0x59670209, 0x4a47020d, 0x17080204,   // sv.de.br_433 da.ak.rn_444  da.sn.yo_554 da.no.sr_332 
  0x0a004c23, 0x20121702, 0x1c301eaf, 0x551f4a0c,   // wo.pt.un_880 sr.hu.sq_222  ms.uz.id_655 yo.cy.rw_543 
  0x06002422, 0x19473008, 0x2a23060c, 0xfc1f2ca7,   // eo.de.un_870 uz.sn.gl_443  de.ca.mt_543 fy.cy.zzp_532 
  0x0c570614, 0x513469a7, 0x504f4905, 0x304c10ec,   // de.na.sv_666 mfe.xh.kl_532  to.bi.fj_333 lt.wo.uz_644 
  // [192f0]
  0x3900630c, 0x22001214, 0x4a3612ad, 0x1c481ea4,   // sco.br.un_530 hu.oc.un_660  hu.gn.yo_643 ms.tt.id_433 
  0x0c2c0607, 0x0257625a, 0x26111d07, 0x7669050d,   // de.fy.sv_432 kha.na.da_553  la.ro.ia_432 fr.mfe.crs_554 
  0x163e42a9, 0x20793e0c, 0x2c005102, 0x0e126012,   // co.rm.hr_544 rm.war.sq_543  kl.fy.un_220 vo.hu.is_654 
  0x1906260c, 0x2506020c, 0x521a5cee, 0x06006005,   // ia.de.gl_543 da.de.eu_543  sa.tl.ha_422 vo.de.un_330 
  // [19300]
  0x526206a4, 0x29472412, 0x30006519, 0x4a5e6012,   // de.kha.ha_433 eo.sn.sl_654  gv.uz.un_750 vo.ts.yo_654 
  0x48041307, 0x15170708, 0x0e230b02, 0x061f3905,   // et.fi.tt_432 bg.sr.un_443  es.ca.is_222 br.cy.de_333 
  0x0e18120e, 0x08400607, 0x5f00561a, 0x1f3f0607,   // hu.ga.is_555 de.lb.no_432  mg.tn.un_760 de.af.cy_432 
  0x2109620c, 0x390628a0, 0x1b00180b, 0x063e21ac,   // kha.pl.jw_543 sw.de.br_322  ga.tr.un_520 jw.rm.de_632 
  // [19310]
  0x691c1e0b, 0x1d006a19, 0x066e6304, 0x442337ec,   // ms.id.mfe_542 haw.la.un_750  sco.hmn.de_332 ba.ky.kk_644 
  0x12002f1a, 0x6e005314, 0x0215010c, 0x1c003005,   // su.hu.un_760 ht.hmn.un_660  en.da.un_530 uz.id.un_330 
  0xfe016ea0, 0x066efea4, 0x4600530b, 0x04505505,   // hmn.en.tlh_322 tlh.hmn.de_433  ht.qu.un_520 rw.fj.fi_333 
  0x766efeec, 0x121857ec, 0x063f1fa7, 0x12091812,   // tlh.hmn.crs_644 na.ga.hu_644  cy.af.de_532 ga.pl.hu_654 
  // [19320]
  0x462425a0, 0x65006e18, 0x2c00670c, 0x683545af,   // eu.eo.qu_322 hmn.gv.un_740  ak.fy.un_530 ln.zu.ig_655 
  0x2b000a08, 0x4d65460c, 0x154069a0, 0x09602907,   // pt.vi.un_430 qu.gv.aa_543  mfe.lb.un_322 sl.vo.pl_432 
  0x02001f0c, 0x4c006e19, 0xfc006704, 0x29000a08,   // cy.da.un_530 hmn.wo.un_750  ak.zzp.un_320 pt.sl.un_430 
  0x1f006e23, 0x034a02ee, 0x36004d1b, 0x6e00fe14,   // hmn.cy.un_880 da.yo.nl_422  aa.gn.un_770 tlh.hmn.un_660 
  // [19330]
  0x1b190aa4, 0x65004a04, 0x182763af, 0x404a04a7,   // pt.gl.tr_433 yo.gv.un_320  sco.gd.ga_655 fi.yo.lb_532 
  0x0d190aa9, 0x4a006802, 0x351007a7, 0x131c0dac,   // pt.gl.cs_544 ig.yo.un_220  bg.be.tg_532 ne.mr.bh_632 
  0x442338a0, 0x19362da9, 0x303635a7, 0x23190a55,   // tk.ky.kk_322 sk.gn.gl_544  tg.ab.uz_532 pt.gl.ca_442 
  0x080e3304, 0x19122da7, 0x1a001c0d, 0x5f371aaf,   // nn.is.no_332 sk.hu.gl_532  id.tl.un_540 tl.st.tn_655 
  // [19340]
  0x3b2873ad, 0x375f1e0c, 0x0c400604, 0x67006408,   // ny.sw.so_643 ms.tn.st_543  de.lb.sv_332 lg.ak.un_430 
  0x1a371e07, 0x4b003613, 0xfe2f1e07, 0x39004008,   // ms.st.tl_432 gn.mi.un_650  ms.su.tlh_432 lb.br.un_430 
  0x46242a55, 0x0200401a, 0x24002c04, 0x331302a4,   // mt.eo.qu_442 lb.da.un_760  fy.eo.un_320 da.et.nn_433 
  0x19240bee, 0x08403f13, 0x0b2d0aa4, 0x52003e08,   // es.eo.gl_422 af.lb.no_665  pt.sk.es_433 rm.ha.un_430 
  // [19350]
  0x40000f1b, 0x09003b13, 0x2c424007, 0x1b79280c,   // lv.lb.un_770 ks.hi.un_650  lb.co.fy_432 sw.war.tr_543 
  0x1f1d40a4, 0x13292807, 0x1e2f1c11, 0x230640af,   // lb.la.cy_433 sw.sl.et_432  id.su.ms_653 lb.de.ca_655 
  0x78535fac, 0x01004204, 0x062540a0, 0x2f211aaf,   // tn.ht.ve_632 co.en.un_320  lb.eu.de_322 tl.jw.su_655 
  0x36351511, 0x32507308, 0x3ffe6109, 0x1b005502,   // un.tg.ab_653 ny.fj.bs_443  za.tlh.af_444 rw.tr.un_220 
  // [19360]
  0x371a5f0e, 0x793b5c09, 0x3b524da4, 0x3b523eee,   // tn.tl.st_555 sa.so.war_444  aa.ha.so_433 rm.ha.so_422 
  0x0d1c130d, 0x2f006e09, 0x1a2f62a9, 0x111d3905,   // bh.mr.ne_554 hmn.su.un_440  kha.su.tl_544 br.la.ro_333 
  0x520f5808, 0x0608330c, 0x332308ad, 0x25151004,   // om.lv.ha_443 nn.no.de_543  no.ca.nn_643 be.mn.un_320 
  0x42331304, 0x30584d12, 0x222d0d05, 0x213b67a4,   // et.nn.co_332 aa.om.uz_654  cs.sk.oc_333 ak.so.jw_433 
  // [19370]
  0x0d001313, 0x2e0e1904, 0x19180da7, 0x36100402,   // bh.ne.un_650 gl.is.fo_332  cs.ga.gl_532 fi.lt.gn_222 
  0x040336ee, 0x10026aa4, 0x330838ee, 0x481007a0,   // gn.nl.fi_422 haw.da.lt_433  tk.no.nn_422 bg.be.tt_322 
  0x330e2ea9, 0x06001002, 0x0e0f1011, 0x380e2008,   // fo.is.nn_544 lt.de.un_220  lt.lv.is_653 sq.is.tk_443 
  0x03001009, 0x120402ee, 0x0b191812, 0x100844ad,   // lt.nl.un_440 da.fi.hu_422  ga.gl.es_654 kk.uk.be_643 
  // [19380]
  0x11625a0c, 0x05223e04, 0x362218a4, 0x4c5d370c,   // sm.kha.ro_543 rm.oc.fr_332  ga.oc.gn_433 st.ss.wo_543 
  0x342d0d05, 0x06353408, 0x3e4c1d08, 0x2d420708,   // cs.sk.xh_333 xh.zu.de_443  la.wo.rm_443 it.co.sk_443 
  0x1f5a49a7, 0x400e06af, 0x190a2305, 0x792d43ec,   // to.sm.cy_532 de.is.lb_655  ca.pt.gl_333 ie.sk.war_644 
  0x3f006511, 0x2d002707, 0x3e430107, 0x11375a0c,   // gv.af.un_630 gd.sk.un_420  en.ie.rm_432 sm.st.ro_543 
  // [19390]
  0x5a007304, 0x641f7304, 0x0c381fa0, 0x583b4dad,   // ny.sm.un_320 ny.cy.lg_332  cy.tk.sv_322 aa.so.om_643 
  0x0e644907, 0x1f2e3f55, 0x190b2ea0, 0x2f214d07,   // to.lg.is_432 af.fo.cy_442  fo.es.gl_322 aa.jw.su_432 
  0x06001b13, 0x514c5807, 0x682045ad, 0x05212f04,   // tr.de.un_650 om.wo.kl_432  ln.sq.ig_643 su.jw.fr_332 
  0x1f006221, 0x3b6b1dad, 0x5c130d0d, 0x30005808,   // kha.cy.un_860 la.ceb.so_643  ne.bh.sa_554 om.uz.un_430 
  // [193a0]
  0x074804a0, 0x05000d05, 0x124c05ad, 0x09534207,   // ru.tt.bg_322 cs.fr.un_330  fr.wo.hu_643 co.ht.pl_432 
  0x204c4007, 0x30182109, 0x313013a7, 0x06630111,   // lb.wo.sq_432 fa.ar.uz_444  et.uz.az_532 en.sco.de_653 
  0x136301a4, 0x0e6920a4, 0x1f1e4f07, 0x1a382ba0,   // en.sco.et_433 sq.mfe.is_433  bi.ms.cy_432 vi.tk.tl_322 
  0x2e000313, 0x1502010c, 0x3f53690c, 0x375d3faf,   // nl.fo.un_650 en.da.un_543  mfe.ht.af_543 af.ss.st_655 
  // [193b0]
  0x484004ee, 0x53004305, 0x116357a0, 0x32003302,   // fi.lb.tt_422 ie.ht.un_330  na.sco.ro_322 nn.bs.un_220 
  0x333f030c, 0x530b39a4, 0x4a00fc11, 0x0e112e07,   // nl.af.nn_543 br.es.ht_433  zzp.yo.un_630 fo.ro.is_432 
  0x30000d02, 0xfc4afea4, 0x33072b02, 0x1e001509,   // cs.uz.un_220 tlh.yo.zzp_433  vi.it.nn_222 un.ms.un_440 
  0xfe005b22, 0x1f063e07, 0x3648040c, 0x5d0e2d08,   // sg.tlh.un_870 rm.de.cy_432  fi.tt.gn_543 sk.is.ss_443 
  // [193c0]
  0x190a360b, 0x44383708, 0x0a2d0e0b, 0x30383560,   // gn.pt.gl_542 ba.tk.kk_443  is.sk.pt_542 tg.tk.uz_664 
  0x080a2307, 0x16201104, 0x0e1e1c5a, 0x645c30a0,   // ky.mk.uk_432 ro.sq.hr_332  id.ms.is_553 uz.sa.lg_322 
  0x313028a0, 0x083023ee, 0x342830ec, 0x5013510d,   // sw.uz.az_322 ky.uz.uk_422  uz.sd.ps_644 kl.et.fj_554 
  0x33512aa6, 0x5a1d01a0, 0x0a1508ec, 0x42002504,   // mt.kl.nn_521 en.la.sm_322  uk.mk.un_640 eu.co.un_320 
  // [193d0]
  0x6b2f1309, 0x04441707, 0x1d25130c, 0x19220a11,   // et.su.ceb_444 sr.kk.ru_432  et.eu.la_543 pt.oc.gl_653 
  0x15001d08, 0x1e1c3ba0, 0x0d0e2ead, 0x250415ec,   // la.un.un_430 so.id.ms_322  fo.is.cs_643 un.ru.mn_644 
  0x11031da9, 0x3f005d04, 0x511c1e12, 0x3f004705,   // la.nl.ro_544 ss.af.un_320  ms.id.kl_654 sn.af.un_330 
  0x351723a0, 0x30552509, 0x251d4ca9, 0x1013500c,   // ky.sr.tg_322 eu.rw.uz_444  wo.la.eu_544 fj.et.lt_543 
  // [193e0]
  0x08020cad, 0x1d2513a9, 0x58514c08, 0x190e2e55,   // sv.da.no_643 et.eu.la_544  wo.kl.om_443 fo.is.gl_442 
  0x081510ec, 0x33025102, 0x2a4a600c, 0x0e2e2dac,   // be.uk.un_640 kl.da.nn_222  vo.yo.mt_543 sk.fo.is_632 
  0x3534fca4, 0xfc1d5ca4, 0x5c001602, 0x10005c0e,   // zzp.xh.zu_433 sa.la.zzp_433  hr.sa.un_220 sa.lt.un_550 
  0x61002419, 0x123d3b05, 0x010a2b04, 0x2a116502,   // eo.za.un_750 ks.ku.ur_333  vi.pt.en_332 gv.ro.mt_222 
  // [193f0]
  0x2e452d0c, 0x34283da7, 0x05005c04, 0x320d2d07,   // sk.ln.fo_543 ku.sd.ps_532  sa.fr.un_320 sk.cs.bs_432 
  0x184a0e0c, 0x342818a0, 0x40000419, 0x23443607,   // is.yo.ga_543 ar.sd.ps_322  fi.lb.un_750 ab.kk.ky_432 
  0x04442308, 0x2d00450c, 0x36001313, 0x52253102,   // ky.kk.ru_443 ln.sk.un_530  et.gn.un_650 az.eu.ha_222 
  0x5d2d45a0, 0x4000360c, 0x10000719, 0x484a0a5a,   // ln.sk.ss_322 gn.lb.un_530  bg.be.un_750 pt.yo.tt_553 
  
  // [19400]
  0x40000411, 0x13040660, 0x30000302, 0x3b581809,   // fi.lb.un_630 de.fi.et_664  nl.uz.un_220 ga.om.so_444 
  0x33084eee, 0x64585c09, 0x044013a0, 0x0251080c,   // ay.no.nn_422 sa.om.lg_444  et.lb.fi_322 no.kl.da_543 
  0x12242302, 0x230b0a04, 0x58030407, 0x123d28a4,   // ca.eo.hu_222 pt.es.ca_332  fi.nl.om_432 sd.ku.ur_433 
  0x2a64040c, 0x2e0e5d04, 0x2c045108, 0x422a0709,   // fi.lg.mt_543 ss.is.fo_332  kl.fi.fy_443 it.mt.co_444 
  // [19410]
  0x06425805, 0x20300107, 0x15230409, 0x08004021,   // om.co.de_333 en.uz.sq_432  ru.ky.un_444 lb.no.un_860 
  0x58545107, 0x07581505, 0x21401b07, 0x213b12a7,   // kl.ik.om_432 un.om.it_333  tr.lb.jw_432 ur.ks.fa_532 
  0x2e0e4aaf, 0x42004912, 0x1b5c5404, 0x0a1707ac,   // yo.is.fo_655 to.co.un_640  ik.sa.tr_332 bg.sr.mk_632 
  0xfe000c12, 0x482138a0, 0x13042aec, 0x355d780c,   // sv.tlh.un_640 tk.jw.tt_322  mt.fi.et_644 ve.ss.zu_543 
  // [19420]
  0x512a0709, 0x29003819, 0x4258510c, 0x52006513,   // it.mt.kl_444 tk.sl.un_750  kl.om.co_543 gv.ha.un_650 
  0x32381b07, 0x043e520c, 0x5cfc0407, 0xfc002a0d,   // tr.tk.bs_432 ha.rm.fi_543  fi.zzp.sa_432 mt.zzp.un_540 
  0x4d654212, 0x381b4c0c, 0x1d2e0204, 0x46002705,   // co.gv.aa_654 wo.tr.tk_543  da.fo.la_332 gd.qu.un_330 
  0x061d6302, 0x1b003408, 0x17240708, 0x1bfe5d0d,   // sco.la.de_222 xh.tr.un_430  it.eo.sr_443 ss.tlh.tr_554 
  // [19430]
  0x64005208, 0x64001d1a, 0x0e4a12b6, 0x0d000e0c,   // ha.lg.un_430 la.lg.un_760  hu.yo.is_766 is.cs.un_530 
  0x1d2e01a9, 0x32073ea0, 0x3b51fe11, 0xfe005d0e,   // en.fo.la_544 rm.it.bs_322  tlh.kl.so_653 ss.tlh.un_550 
  0x361b4708, 0x2b656207, 0x2e044d0c, 0x4d61060c,   // sn.tr.gn_443 kha.gv.vi_432  aa.fi.fo_543 de.za.aa_543 
  0x183412a7, 0x23003818, 0x51005822, 0x6e001c0d,   // ur.ps.ar_532 tk.ky.un_740  om.kl.un_870 id.hmn.un_540 
  // [19440]
  0x18693b0d, 0x1f396e0c, 0x100807a0, 0x6efe0107,   // so.mfe.ga_554 hmn.br.cy_543  bg.uk.be_322 en.tlh.hmn_432 
  0x4dfe6e5a, 0x581502ee, 0x1f0e1808, 0x3e00210d,   // hmn.tlh.aa_553 da.om.un_420  ga.is.cy_443 jw.rm.un_540 
  0x65156e07, 0x5300390d, 0xfe226e11, 0x6500571a,   // hmn.gv.un_420 br.ht.un_540  hmn.oc.tlh_653 na.gv.un_760 
  0x796306a4, 0x2200300d, 0x55641b04, 0x02030dee,   // de.sco.war_433 uz.oc.un_540  tr.lg.rw_332 cs.nl.da_422 
  // [19450]
  0x01006808, 0x550a53a0, 0x34475eec, 0x4d4c6ea4,   // ig.en.un_430 ht.pt.rw_322  ts.sn.xh_644 hmn.wo.aa_433 
  0x48233711, 0x1d005c04, 0xfe006e2a, 0x12001818,   // ba.ky.tt_653 sa.la.un_320  hmn.tlh.un_970 ar.ur.un_740 
  0x136e3955, 0x6300fe14, 0x1d156ead, 0x53050eaf,   // br.hmn.et_442 tlh.sco.un_660  hmn.la.un_630 is.fr.ht_655 
  0x2f380204, 0x5e1c1e0c, 0x51001304, 0x042536a0,   // da.tk.su_332 ms.id.ts_543  et.kl.un_320 ab.mn.ru_322 
  // [19460]
  0x1d470e0c, 0x352325a4, 0x5e284d07, 0x4a004905,   // is.sn.la_543 mn.ky.tg_433  aa.sw.ts_432 to.yo.un_330 
  0x29032408, 0x3c2338a4, 0x49000f0b, 0x2e006b11,   // eo.nl.sl_443 tk.ky.ug_433  lv.to.un_520 ceb.fo.un_630 
  0x5a6a4aee, 0xfc296aa0, 0x336b3804, 0x3e116904,   // yo.haw.sm_422 haw.sl.zzp_322  tk.ceb.nn_332 mfe.ro.rm_332 
  0x02005c02, 0x650457ee, 0x4a796b07, 0x3012215a,   // sa.da.un_220 na.fi.gv_422  ceb.war.yo_432 fa.ur.uz_553 
  // [19470]
  0x232e33ad, 0x2e60010b, 0x030c11a4, 0x4b0438ee,   // nn.fo.ca_643 en.vo.fo_542  ro.sv.nl_433 tk.fi.mi_422 
  0x2a0f100c, 0x17002520, 0x104a0fac, 0x012118ec,   // lt.lv.mt_543 mn.sr.un_850  lv.yo.lt_632 ar.fa.iw_644 
  0x0e2e0da0, 0x0a17110d, 0x30352307, 0x1e1c52a4,   // cs.fo.is_322 ro.sr.mk_554  ky.tg.uz_432 ha.id.ms_433 
  0x341c520c, 0x15170a0c, 0x26074312, 0x2b000209,   // ha.id.xh_543 mk.sr.un_543  ie.it.ia_654 da.vi.un_440 
  // [19480]
  0x3e071155, 0x5d3452a9, 0x15005712, 0x0a363805,   // ro.it.rm_442 ha.xh.ss_544  na.un.un_640 tk.ab.mk_333 
  0x442338ec, 0x28555907, 0x04093f04, 0x291c30ee,   // tk.ky.kk_644 rn.rw.sw_432  af.pl.fi_332 uz.id.sl_422 
  0x35345d55, 0x43194212, 0x39464d0c, 0x1b3136a4,   // ss.xh.zu_442 co.gl.ie_654  aa.qu.br_543 gn.az.tr_433 
  0x31461ba4, 0x48000e0d, 0x34005d12, 0x46005208,   // tr.qu.az_433 is.tt.un_540  ss.xh.un_640 ha.qu.un_430 
  // [19490]
  0x111b46a4, 0x371548a0, 0x6e001e12, 0x0d004a10,   // qu.tr.ro_433 tt.ba.un_320  ms.hmn.un_640 yo.cs.un_620 
  0x12311bee, 0x04130ca0, 0x15353807, 0x03052205,   // tr.az.hu_422 sv.et.fi_322  tk.tg.un_432 oc.fr.nl_333 
  0x2e180ea0, 0x0d001816, 0x110a0405, 0x484415a4,   // is.ga.fo_322 ga.cs.un_720  ru.mk.ro_333 un.kk.tt_433 
  0x23052204, 0x311b13a4, 0x0c130402, 0x0a000d05,   // oc.fr.ca_332 et.tr.az_433  fi.et.sv_222 cs.pt.un_330 
  // [194a0]
  0x2e0d2db4, 0x23190aa0, 0x0b0a2daf, 0x5afc0255,   // sk.cs.fo_754 pt.gl.ca_322  sk.pt.es_655 da.zzp.sm_442 
  0x12043b0b, 0x272322a0, 0x580225a9, 0x04150713,   // so.fi.hu_542 oc.ca.gd_322  eu.da.om_544 bg.ru.un_650 
  0x055801a0, 0x032a30a7, 0x316428a6, 0x260269a9,   // en.om.fr_322 uz.mt.nl_532  sw.lg.az_521 mfe.da.ia_544 
  0x0d001309, 0x636551a0, 0x0f0210a9, 0x3f0f0da4,   // bh.ne.un_440 kl.gv.sco_322  lt.da.lv_544 cs.lv.af_433 
  // [194b0]
  0x672a580c, 0x0240110c, 0x2e0e18ee, 0xfc182707,   // om.mt.ak_543 ro.lb.da_543  ga.is.fo_422 gd.ga.zzp_432 
  0x24122da4, 0x58676407, 0x4c02300c, 0x0436590c,   // sk.hu.eo_433 lg.ak.om_432  uz.da.wo_543 rn.gn.fi_543 
  0x251d2e0c, 0x24005c13, 0x495528a7, 0x32162d0c,   // fo.la.eu_543 sa.eo.un_650  sw.rw.to_532 sk.hr.bs_543 
  0x303b58a4, 0x55363ba7, 0x170a1109, 0x0e3f030c,   // om.so.uz_433 so.gn.rw_532  ro.mk.sr_444 nl.af.is_543 
  // [194c0]
  0x4c470602, 0x582a52a0, 0xfe004d12, 0x0802fc02,   // de.sn.wo_222 ha.mt.om_322  aa.tlh.un_640 zzp.da.no_222 
  0x295c1004, 0x63063e07, 0xfe3052a4, 0x08151104,   // lt.sa.sl_332 rm.de.sco_432  ha.uz.tlh_433 ro.uk.un_320 
  0x0a2e18ba, 0x43111d0c, 0x12005012, 0x27003e12,   // ga.fo.pt_843 la.ro.ie_543  fj.hu.un_640 rm.gd.un_640 
  0x11001d13, 0x3f790dee, 0x3e2b23af, 0x42023e04,   // la.ro.un_650 cs.war.af_422  ca.vi.rm_655 rm.da.co_332 
  // [194d0]
  0x3e00220c, 0x171602a0, 0x10001d08, 0x195509a4,   // oc.rm.un_530 da.hr.sr_322  la.lt.un_430 pl.rw.gl_433 
  0x383023ad, 0x032305a4, 0x17073507, 0x0c001802,   // ky.uz.tk_643 fr.ca.nl_433  tg.bg.sr_432 ga.sv.un_220 
  0xfc35780d, 0x52002907, 0x291f65ad, 0x4c071f12,   // ve.zu.zzp_554 sl.ha.un_420  gv.cy.sl_643 cy.it.wo_654 
  0x0e2d0d0b, 0x251710a7, 0x1c090d0b, 0x0438110c,   // cs.sk.is_542 be.sr.mn_532  ne.hi.mr_542 ro.tk.ru_543 
  // [194e0]
  0x5c5610ec, 0x2c0304a0, 0x735f6a07, 0x08003818,   // lt.mg.sa_644 fi.nl.fy_322  haw.tn.ny_432 tk.uk.un_740 
  0x322160a4, 0x283421a6, 0x300a17ee, 0x48317307,   // vo.jw.bs_433 fa.ps.sd_521  sr.mk.uz_422 ny.az.tt_432 
  0x37234809, 0x38153608, 0x04024b07, 0x404973ee,   // tt.ky.ba_444 ab.tk.un_430  mi.da.fi_432 ny.to.lb_422 
  0x52001b05, 0x4858020c, 0x213473a0, 0x1c000f02,   // tr.ha.un_330 da.om.tt_543  ny.xh.jw_322 lv.id.un_220 
  // [194f0]
  0x29654cee, 0x345d500c, 0x03000a04, 0x38443708,   // wo.gv.sl_422 fj.ss.xh_543  pt.nl.un_320 ba.kk.tk_443 
  0x15633904, 0x423e22ad, 0x3940050c, 0x39005f07,   // br.sco.un_332 oc.rm.co_643  fr.lb.br_543 tn.br.un_420 
  0x32171ea4, 0x05001813, 0x39002b0b, 0x48174404,   // ms.sr.bs_433 ga.fr.un_650  vi.br.un_520 kk.sr.tt_332 
  0x11431512, 0x3b2558ad, 0x23002712, 0x44251002,   // un.ie.ro_654 om.eu.so_643  gd.ca.un_640 be.mn.kk_222 
  // [19500]
  0x192d0d5a, 0x46304208, 0x37231507, 0x11005907,   // cs.sk.gl_553 co.uz.qu_443  un.ky.ba_432 rn.ro.un_420 
  0x2b10fe0b, 0x351523a4, 0x343c18a9, 0x2f191208,   // tlh.lt.vi_542 ky.tg.un_430  ar.ug.ps_544 hu.gl.su_443 
  0x390948a9, 0x2ffe4808, 0x42401f13, 0xfe216207,   // tt.pl.br_544 tt.tlh.su_443  cy.lb.co_665 kha.jw.tlh_432 
  0x1c212f60, 0x38321604, 0x62732f07, 0x482f21ec,   // su.jw.id_664 hr.bs.tk_332  su.ny.kha_432 jw.su.tt_644 
  // [19510]
  0x43586205, 0x48fe1b12, 0x42003308, 0x03063fa4,   // kha.om.ie_333 tr.tlh.tt_654  nn.co.un_430 af.de.nl_433 
  0x090348a7, 0x330206a4, 0x0345050e, 0x12210ba0,   // tt.nl.pl_532 de.da.nn_433  fr.ln.nl_555 es.jw.hu_322 
  0x07fc63a0, 0x2f001904, 0x482f6209, 0x2f124ca4,   // sco.zzp.it_322 gl.su.un_320  kha.su.tt_444 wo.hu.su_433 
  0x622148a9, 0x3e232f0c, 0x40120955, 0x25496a0c,   // tt.jw.kha_544 su.ca.rm_543  pl.hu.lb_442 haw.to.eu_543 
  // [19520]
  0x5c002004, 0x2800100d, 0x5c00250c, 0x256a3605,   // sq.sa.un_320 lt.sw.un_540  eu.sa.un_530 gn.haw.eu_333 
  0x0e000d08, 0x12563607, 0x1d00560c, 0x131c0daf,   // cs.is.un_430 gn.mg.hu_432  mg.la.un_530 ne.mr.bh_655 
  0x4900280e, 0x101e1c05, 0x5c00500c, 0x2400560b,   // sw.to.un_550 id.ms.lt_333  fj.sa.un_530 mg.eo.un_520 
  0x46735c07, 0x5c1004a4, 0x686a4ba4, 0x5c0410a7,   // sa.ny.qu_432 fi.lt.sa_433  mi.haw.ig_433 lt.fi.sa_532 
  // [19530]
  0x251e5608, 0x2d000f0e, 0x6a6b040c, 0x1d030ca4,   // mg.ms.eu_443 lv.sk.un_550  fi.ceb.haw_543 sv.nl.la_433 
  0x0f00092b, 0x027669a4, 0xfe24120c, 0x21183ca7,   // pl.lv.un_980 mfe.crs.da_433  hu.eo.tlh_543 ug.ar.fa_532 
  0x43006312, 0x2c2e0e14, 0x1d041312, 0x4600570e,   // sco.ie.un_640 is.fo.fy_666  et.fi.la_654 na.qu.un_550 
  0x273f030e, 0x3e65500d, 0x3300620d, 0x033f5014,   // nl.af.gd_555 fj.gv.rm_554  kha.nn.un_540 fj.af.nl_666 
  // [19540]
  0x1715070d, 0x0763010c, 0x1d1f4207, 0x1f2e0e0b,   // bg.sr.un_540 en.sco.it_543  co.cy.la_432 is.fo.cy_542 
  0x35443cee, 0x3f002722, 0x13001914, 0x42001d2a,   // ug.kk.tg_422 gd.af.un_870  gl.et.un_660 la.co.un_970 
  0x041d1fa4, 0x0a00600c, 0x1a003002, 0x23004c02,   // cy.la.fi_433 vo.pt.un_530  uz.tl.un_220 wo.ca.un_220 
  0x272b73ee, 0x5559470b, 0x4a00670d, 0x15043c07,   // ny.vi.gd_422 sn.rn.rw_542  ak.yo.un_540 ug.ru.un_432 
  // [19550]
  0x21002214, 0x0a003802, 0xfc103bee, 0x2b00260c,   // oc.jw.un_660 tk.pt.un_220  so.lt.zzp_422 ia.vi.un_530 
  0x42596904, 0x10461fec, 0x3510070c, 0x0f002b07,   // mfe.rn.co_332 cy.qu.lt_644  bg.be.tg_543 vi.lv.un_420 
  0x55003808, 0x1d095508, 0x4c6b1dad, 0x47595512,   // tk.rw.un_430 rw.pl.la_443  la.ceb.wo_643 rw.rn.sn_654 
  0x274dfc0c, 0x36005512, 0x381b06a0, 0x251044a0,   // zzp.aa.gd_543 rw.gn.un_640  de.tr.tk_322 kk.be.mn_322 
  // [19560]
  0x55003b13, 0x3f734904, 0x23173512, 0x35002907,   // so.rw.un_650 to.ny.af_332  tg.sr.ky_654 sl.zu.un_420 
  0x3c4808a4, 0x37150808, 0x21341804, 0x23000511,   // uk.tt.ug_433 uk.ba.un_430  ar.ps.fa_332 fr.ca.un_630 
  0x4c120204, 0x0a111705, 0x12052208, 0x301738af,   // da.hu.wo_332 sr.ro.mk_333  oc.fr.hu_443 tk.sr.uz_655 
  0x3b3358ee, 0x1200050d, 0x0200200c, 0x5e123808,   // om.nn.so_422 fr.hu.un_540  sq.da.un_530 tk.hu.ts_443 
  // [19570]
  0x35230a12, 0x4830230b, 0x2f003e1e, 0x52004d12,   // mk.ky.tg_654 ky.uz.tt_542  rm.su.un_830 aa.ha.un_640 
  0x61002f23, 0x1a1e39a0, 0x08003513, 0x01083307,   // su.za.un_880 br.ms.tl_322  tg.uk.un_650 nn.no.en_432 
  0x67231f0c, 0x175f6907, 0x04150804, 0x33310809,   // cy.ca.ak_543 mfe.tn.sr_432  uk.ru.un_320 no.az.nn_444 
  0x7325670c, 0x5c1724a0, 0x31301b13, 0x071f1204,   // ak.eu.ny_543 eo.sr.sa_322  tr.uz.az_665 hu.cy.it_332 
  // [19580]
  0x3b2143ee, 0x76697313, 0x1b006719, 0x0b1905a9,   // ie.jw.so_422 ny.mfe.crs_665  ak.tr.un_750 fr.gl.es_544 
  0x380a3613, 0x40000519, 0x69674f0c, 0x170775a7,   // ab.mk.tk_665 fr.lb.un_750  bi.ak.mfe_543 nso.it.sr_532 
  0x4736730d, 0x75375f08, 0x48100e04, 0x4f2f6055,   // ny.gn.sn_554 tn.st.nso_443  is.lt.tt_332 vo.su.bi_442 
  0x25484404, 0x4c641207, 0x103e20ec, 0x1b000805,   // kk.tt.mn_332 hu.lg.wo_432  sq.rm.lt_644 no.tr.un_330 
  // [19590]
  0x28003d19, 0x17150704, 0x251035a7, 0x041511ad,   // ku.sd.un_750 bg.sr.un_320  tg.be.mn_532 ro.ru.un_630 
  0x5a1d45a9, 0x6e006718, 0x5a006708, 0x30153709,   // ln.la.sm_544 ak.hmn.un_740  ak.sm.un_430 ba.uz.un_440 
  0xfe000313, 0x0d2d3604, 0x300423a0, 0x421107a0,   // nl.tlh.un_650 gn.sk.cs_332  ky.ru.uz_322 it.ro.co_322 
  0xfc566255, 0x2f4f1ea4, 0x0449245a, 0x6a45600d,   // kha.mg.zzp_442 ms.bi.su_433  eo.to.fi_553 vo.ln.haw_554 
  // [195a0]
  0x5c000305, 0x69004f09, 0x364c02a0, 0x5a4b02a9,   // nl.sa.un_330 bi.mfe.un_440  da.wo.gn_322 da.mi.sm_544 
  0x4a505905, 0x64350204, 0x0f000312, 0x4302240d,   // rn.fj.yo_333 da.zu.lg_332  nl.lv.un_640 eo.da.ie_554 
  0x58004a14, 0x24371c0c, 0x072f1e0c, 0x29007304,   // yo.om.un_660 id.st.eo_543  ms.su.it_543 ny.sl.un_320 
  0x294d1ead, 0x5f00452a, 0x45fc6055, 0xfc6557af,   // ms.aa.sl_643 ln.tn.un_970  vo.zzp.ln_442 na.gv.zzp_655 
  // [195b0]
  0x0d124d0b, 0x45106709, 0x6a5f6707, 0x69562d0c,   // aa.hu.cs_542 ak.lt.ln_444  ak.tn.haw_432 sk.mg.mfe_543 
  0x4a001811, 0x3b4c310c, 0x2534350c, 0x3f24450d,   // ga.yo.un_630 az.wo.so_543  zu.xh.eu_543 ln.eo.af_554 
  0x4502300c, 0x1d565208, 0x56251aa9, 0x15044405,   // uz.da.ln_543 ha.mg.la_443  tl.eu.mg_544 kk.ru.un_333 
  0x342144ee, 0x36003e22, 0x4d305408, 0x3f0302ec,   // kk.fa.ps_422 rm.gn.un_870  ik.uz.aa_443 da.nl.af_644 
  // [195c0]
  0x2a00580d, 0x04003713, 0xfc100f12, 0x02300107,   // om.mt.un_540 ba.ru.un_650  lv.lt.zzp_654 en.uz.da_432 
  0x071008ac, 0x6b794dee, 0x0a0436ee, 0x30373cad,   // uk.be.bg_632 aa.war.ceb_422  ab.ru.mk_422 ug.ba.uz_643 
  0x19232209, 0x0b0e5ca0, 0x6e001e07, 0x1d025d07,   // oc.ca.gl_444 sa.is.es_322  ms.hmn.un_420 ss.da.la_432 
  0x29605008, 0x27002305, 0x6000021b, 0x5c245e07,   // fj.vo.sl_443 ca.gd.un_330  da.vo.un_770 ts.eo.sa_432 
  // [195d0]
  0x211c2f0d, 0x4f2950ad, 0x36110a0c, 0x50601bec,   // su.id.jw_554 fj.sl.bi_643  mk.ro.ab_543 tr.vo.fj_644 
  0x23120513, 0x071d5012, 0x042523ee, 0x6929760c,   // fr.hu.ca_665 fj.la.it_654  ky.mn.ru_422 crs.sl.mfe_543 
  0x044823ac, 0x3229500c, 0x322950ac, 0x50003e08,   // ky.tt.ru_632 fj.sl.bs_543  fj.sl.bs_632 rm.fj.un_430 
  0x31693014, 0x56002f0d, 0x2ffc625a, 0x020d2d12,   // uz.mfe.az_666 su.mg.un_540  kha.zzp.su_553 sk.cs.da_654 
  // [195e0]
  0x2b00450b, 0x2b0727a0, 0x041025ad, 0x39420504,   // ln.vi.un_520 gd.it.vi_322  mn.be.ru_643 fr.co.br_332 
  0x482336ad, 0x3c4430a4, 0x024b5a04, 0x0f001504,   // ab.ky.tt_643 uz.kk.ug_433  sm.mi.da_332 un.lv.un_320 
  0x355d52ec, 0x64006b0d, 0x34125d0c, 0x09564804,   // ha.ss.zu_644 ceb.lg.un_540  ss.hu.xh_543 tt.mg.pl_332 
  0x30003d18, 0x09391504, 0x2f22230e, 0x10230aee,   // ku.uz.un_740 un.br.pl_332  ca.oc.su_555 mk.ky.be_422 
  // [195f0]
  0x23220502, 0x20003913, 0xfc001d0b, 0x05190b04,   // fr.oc.ca_222 br.sq.un_650  la.zzp.un_520 es.gl.fr_332 
  0x22230555, 0x150a15a0, 0x4838230e, 0x6a4f4bec,   // fr.ca.oc_442 un.mk.un_322  ky.tk.tt_555 mi.bi.haw_644 
  0x5a6a4bec, 0x49394b0c, 0x205c2907, 0x190a1d02,   // mi.haw.sm_644 mi.br.to_543  sl.sa.sq_432 la.pt.gl_222 
  0x08001105, 0x0a2336a9, 0x29000d0b, 0x0a2338ad,   // ro.uk.un_330 gn.ca.pt_544  cs.sl.un_520 tk.ky.mk_643 
  // [19600]
  0x4b005a18, 0x5c006a08, 0x1d106a55, 0x1d00070e,   // sm.mi.un_740 haw.sa.un_430  haw.lt.la_442 it.la.un_550 
  0x101d1f0c, 0x321609ec, 0x1d101f04, 0x28000407,   // cy.la.lt_543 pl.hr.bs_644  cy.lt.la_332 fi.sw.un_420 
  0x2128040c, 0x521f04a0, 0x6a00530d, 0x3e103004,   // fi.sw.jw_543 fi.cy.ha_322  ht.haw.un_540 uz.lt.rm_332 
  0x1f001009, 0x103e040d, 0x0423100b, 0x5e000421,   // lt.cy.un_440 fi.rm.lt_554  lt.ca.fi_542 fi.ts.un_860 
  // [19610]
  0x0410365a, 0x34284908, 0xfe240ea0, 0x03393f07,   // ab.be.ru_553 to.sw.xh_443  is.eo.tlh_322 af.br.nl_432 
  0x190b43a4, 0x4d2428a4, 0x6b76010b, 0x1f3534a4,   // ie.es.gl_433 sw.eo.aa_433  en.crs.ceb_542 xh.zu.cy_433 
  0x0802270d, 0xfe002014, 0x48081013, 0x3046fe07,   // gd.da.no_554 sq.tlh.un_660  be.uk.tt_665 tlh.qu.uz_432 
  0x0106fc02, 0x0c651f04, 0x39004013, 0x3744480e,   // zzp.de.en_222 cy.gv.sv_332  lb.br.un_650 tt.kk.ba_555 
  // [19620]
  0x1c1a01a0, 0x58002304, 0x402e02a7, 0x353038ec,   // en.tl.id_322 ca.om.un_320  da.fo.lb_532 tk.uz.tg_644 
  0x43003912, 0x21001104, 0x25003404, 0x6a1f0312,   // br.ie.un_640 ro.jw.un_320  xh.eu.un_320 nl.cy.haw_654 
  0x1e006e07, 0x422018ee, 0x391f6e0c, 0x15592555,   // hmn.ms.un_420 ga.sq.co_422  hmn.cy.br_543 eu.rn.un_442 
  0x1efe3904, 0x6e301e07, 0x3f242c02, 0x22151f08,   // br.tlh.ms_332 ms.uz.hmn_432  fy.eo.af_222 cy.oc.un_430 
  // [19630]
  0x15106ea4, 0x19005308, 0x070601ad, 0x06006019,   // hmn.lt.un_433 ht.gl.un_430  en.de.it_643 vo.de.un_750 
  0x21001b07, 0x532223ad, 0x16002004, 0xfe4c300c,   // tr.jw.un_420 ca.oc.ht_643  sq.hr.un_320 uz.wo.tlh_543 
  0x1d263807, 0x0f136ead, 0x124a530e, 0x480a07a4,   // tk.ia.la_432 hmn.et.lv_643  ht.yo.hu_555 bg.mk.tt_433 
  0x40052213, 0x212253ba, 0x08212fa0, 0x0c004a07,   // oc.fr.lb_665 ht.oc.jw_843  su.jw.no_322 yo.sv.un_420 
  // [19640]
  0x35001f05, 0x331b2c07, 0x0f3f10a0, 0x0227180d,   // cy.zu.un_330 fy.tr.nn_432  lt.af.lv_322 ga.gd.da_554 
  0x441823ad, 0x13033f0c, 0x790163ad, 0x02133f0c,   // ky.ar.kk_643 af.nl.et_543  sco.en.war_643 af.et.da_543 
  0x4b006a18, 0x48383708, 0x233744a0, 0x2d00291b,   // haw.mi.un_740 ba.tk.tt_443  kk.ba.ky_322 sl.sk.un_770 
  0x0704375a, 0x35340a07, 0x481508a4, 0x34003612,   // ba.ru.bg_553 pt.xh.zu_432  uk.tt.un_430 gn.xh.un_640 
  // [19650]
  0x09352d02, 0x06343507, 0x1d0420a4, 0x0d002918,   // sk.zu.pl_222 zu.xh.de_432  sq.fi.la_433 sl.cs.un_740 
  0x5a0a25a9, 0x2b20130c, 0x4837150d, 0x6300050d,   // eu.pt.sm_544 et.sq.vi_543  un.ba.tt_554 fr.sco.un_540 
  0x206e7907, 0x51255a0c, 0x0a002319, 0x3e005713,   // war.hmn.sq_432 sm.eu.kl_543  ky.mk.un_750 na.rm.un_650 
  0x2b003604, 0x01152607, 0x330e0855, 0x0407510c,   // gn.vi.un_320 ia.en.un_420  no.is.nn_442 kl.it.fi_543 
  // [19660]
  0x254b0404, 0x25002022, 0x782520a4, 0x5d006108,   // fi.mi.eu_332 sq.eu.un_870  sq.eu.ve_433 za.ss.un_430 
  0x4400250e, 0x1b3e0604, 0x0d292d10, 0x0c001318,   // mn.kk.un_550 de.rm.tr_332  sk.sl.cs_642 et.sv.un_740 
  0x0a151555, 0x121823ee, 0x15514fad, 0x384f1ea4,   // un.mk.un_420 ky.ar.ur_422  bi.kl.un_643 ms.bi.tk_433 
  0x4f461a0e, 0x1c2f1ea4, 0x2f1c1ead, 0x301515ee,   // tl.qu.bi_555 ms.su.id_433  ms.id.su_643 un.uz.un_420 
  // [19670]
  0x125c56a4, 0x1d006114, 0x1a381ea4, 0x282118ec,   // mg.sa.hu_433 za.la.un_660  ms.tk.tl_433 ar.fa.sd_644 
  0x5c2056ad, 0x53125612, 0x36000713, 0x07125c07,   // mg.sq.sa_643 mg.hu.ht_654  bg.ab.un_650 sa.hu.it_432 
  0x070436a4, 0x21343ca0, 0x796146ad, 0x231156a4,   // ab.ru.bg_433 ug.ps.fa_322  qu.za.war_643 mg.ro.ca_433 
  0x1e000619, 0x43464808, 0x1a002502, 0x1d6e0604,   // de.ms.un_750 tt.qu.ie_443  eu.tl.un_220 de.hmn.la_332 
  // [19680]
  0x376b1312, 0x12005613, 0x6b1b5c11, 0x05002b02,   // et.ceb.st_654 mg.hu.un_650  sa.tr.ceb_653 vi.fr.un_220 
  0x51fe4612, 0x5d730708, 0x5a0e1804, 0x1d5c560c,   // qu.tlh.kl_654 it.ny.ss_443  ga.is.sm_332 mg.sa.la_543 
  0x130d09a7, 0x1934fcee, 0x40161807, 0x797656ad,   // hi.ne.bh_532 zzp.xh.gl_422  ga.hr.lb_432 mg.crs.war_643 
  0x50000604, 0x30004c23, 0x0e215607, 0x0a4005ee,   // de.fj.un_320 wo.uz.un_880  mg.jw.is_432 fr.lb.pt_422 
  // [19690]
  0x27004902, 0x306b58ec, 0x1d6905af, 0x02fe3e0c,   // to.gd.un_220 om.ceb.uz_644  fr.mfe.la_655 rm.tlh.da_543 
  0x500654ad, 0x43581a07, 0x065750af, 0x0952300c,   // ik.de.fj_643 tl.om.ie_432  fj.na.de_655 uz.ha.pl_543 
  0x1d065ca0, 0x73024ca7, 0x1a006b0c, 0x18003011,   // sa.de.la_322 wo.da.ny_532  ceb.tl.un_530 uz.ga.un_630 
  0x09005a12, 0x37304404, 0x107328ad, 0x584d3012,   // sm.pl.un_640 kk.uz.ba_332  sw.ny.lt_643 uz.aa.om_654 
  // [196a0]
  0x28186ba7, 0x1a3b5e55, 0x521e1c04, 0x44253808,   // ceb.ga.sw_532 ts.so.tl_442  id.ms.ha_332 tk.mn.kk_443 
  0x1b001312, 0x033f04a6, 0x013f6504, 0x36000a0e,   // et.tr.un_640 fi.af.nl_521  gv.af.en_332 mk.ab.un_550 
  0x033f4c12, 0x233c3007, 0x63050111, 0x35170704,   // wo.af.nl_654 uz.ug.ky_432  en.fr.sco_653 bg.sr.tg_332 
  0x153637a4, 0x2a5c0407, 0x69532208, 0x1f532e07,   // ba.ab.un_433 fi.sa.mt_432  oc.ht.mfe_443 fo.ht.cy_432 
  // [196b0]
  0x5c000404, 0x2b1c01ee, 0x102d2905, 0x651a63ee,   // fi.sa.un_320 en.id.vi_422  sl.sk.lt_333 sco.tl.gv_422 
  0x44483713, 0x23364807, 0x101629ee, 0x053f030c,   // ba.tt.kk_665 tt.ab.ky_432  sl.hr.lt_422 nl.af.fr_543 
  0x102517a0, 0x0e3903a6, 0x53033f55, 0x10320dee,   // sr.mn.be_322 nl.br.is_521  af.nl.ht_442 cs.bs.lt_422 
  0x062e5855, 0x393f5807, 0x12283404, 0x1d020755,   // om.fo.de_442 om.af.br_432  ps.sd.ur_332 it.da.la_442 
  // [196c0]
  0x1d00260d, 0x0b0a11ec, 0x25043704, 0x34213b05,   // ia.la.un_540 ro.pt.es_644  ba.ru.mn_332 ks.fa.ps_333 
  0x07474cee, 0x68280212, 0x3e003807, 0x20045107,   // wo.sn.it_422 da.sw.ig_654  tk.rm.un_420 kl.fi.sq_432 
  0x260701a4, 0x25002607, 0x0d192dee, 0x0a003c11,   // en.it.ia_433 ia.eu.un_420  sk.gl.cs_422 ug.mk.un_630 
  0x12005a04, 0xfc002a0c, 0x15003109, 0x42000202,   // sm.hu.un_320 mt.zzp.un_530  az.un.un_440 da.co.un_220 
  // [196d0]
  0x2a0705ad, 0x1500210e, 0x05192f02, 0x1f076508,   // fr.it.mt_643 jw.un.un_550  su.gl.fr_222 gv.it.cy_443 
  0x205a5107, 0x1f1d0504, 0x48071107, 0x0804075a,   // kl.sm.sq_432 fr.la.cy_332  ro.bg.tt_432 bg.ru.uk_553 
  0x3704110e, 0x5c003b11, 0x480708ee, 0x07002518,   // ro.ru.ba_555 ks.sa.un_630  uk.bg.tt_422 mn.bg.un_740 
  0x17442308, 0x21313002, 0x50002008, 0x1a00791b,   // ky.kk.sr_443 uz.az.jw_222  sq.fj.un_430 war.tl.un_770 
  // [196e0]
  0xfe7643af, 0x0c2420a0, 0x1d0720a7, 0x2701fcee,   // ie.crs.tlh_655 sq.eo.sv_322  sq.it.la_532 zzp.en.gd_422 
  0x100a11a4, 0x23081002, 0x4b002004, 0x2000251b,   // ro.mk.be_433 be.uk.ky_222  sq.mi.un_320 eu.sq.un_770 
  0x3e002013, 0x3c151004, 0x352325a0, 0x04006807,   // sq.rm.un_650 be.ug.un_320  mn.ky.tg_322 ig.fi.un_420 
  0x102f21ee, 0x04004b0c, 0x04494b09, 0x427905ec,   // jw.su.lt_422 mi.fi.un_530  mi.to.fi_444 fr.war.co_644 
  // [196f0]
  0x251024ac, 0x39004608, 0x0e2e2da0, 0x49003509,   // eo.lt.eu_632 qu.br.un_430  sk.fo.is_322 zu.to.un_440 
  0x0e00fc0c, 0x1b003005, 0x2243010c, 0x0e122aa6,   // zzp.is.un_530 uz.tr.un_330  en.ie.oc_543 mt.hu.is_521 
  0x1f241504, 0x32290d55, 0x48000c20, 0x301233a7,   // un.eo.cy_332 cs.sl.bs_442  sv.tt.un_850 nn.hu.uz_532 
  0x101507a4, 0x0817110c, 0x65635704, 0x07fc01a4,   // bg.be.un_430 ro.sr.uk_543  na.sco.gv_332 en.zzp.it_433 
  // [19700]
  0x1c1d42a4, 0x1515045a, 0x11763004, 0x30033f12,   // co.la.id_433 ru.un.un_530  uz.crs.ro_332 af.nl.uz_654 
  0x160d29ad, 0x3930fca4, 0x0c006014, 0x33000104,   // sl.cs.hr_643 zzp.uz.br_433  vo.sv.un_660 en.nn.un_320 
  0x13002314, 0x65023f02, 0x283034ad, 0x06001c04,   // ca.et.un_660 af.da.gv_222  ps.uz.sd_643 id.de.un_320 
  0x5c562011, 0x2a00060b, 0x01401804, 0x56000602,   // sq.mg.sa_653 de.mt.un_520  ga.lb.en_332 de.mg.un_220 
  // [19710]
  0x10001f0c, 0x04133b07, 0x27006b04, 0x04001c07,   // cy.lt.un_530 so.et.fi_432  ceb.gd.un_320 id.fi.un_420 
  0x3e001902, 0x06001607, 0x05223e0c, 0x295620a0,   // gl.rm.un_220 hr.de.un_420  rm.oc.fr_543 sq.mg.sl_322 
  0x5e340604, 0x3b132f04, 0x011506a7, 0x273bfca0,   // de.xh.ts_332 su.et.so_332  de.en.un_520 zzp.so.gd_322 
  0x032c01ee, 0x2e132a07, 0x0c7669af, 0x09003e0d,   // en.fy.nl_422 mt.et.fo_432  mfe.crs.sv_655 rm.pl.un_540 
  // [19720]
  0x30354408, 0x2e0e63a0, 0x1d2a5a05, 0x030657ee,   // kk.tg.uz_443 sco.is.fo_322  sm.mt.la_333 na.de.nl_422 
  0x652b0107, 0x37250aac, 0x253c1504, 0x3217290c,   // en.vi.gv_432 mk.mn.ba_632  un.ug.mn_332 sl.sr.bs_543 
  0x06016312, 0x21534f12, 0x1e253004, 0x131b310b,   // sco.en.de_654 bi.ht.jw_654  uz.eu.ms_332 az.tr.et_542 
  0x15001d12, 0x36004821, 0x29321708, 0x1f0203ad,   // la.un.un_640 tt.ab.un_860  sr.bs.sl_443 nl.da.cy_643 
  // [19730]
  0x083015ee, 0x35000207, 0x1d1d1e07, 0x34003711,   // un.uz.uk_422 da.zu.un_420  ms.la.la_432 st.xh.un_630 
  0x302548ee, 0x04516308, 0x0a001e0c, 0x53003b08,   // tt.mn.uz_422 sco.kl.fi_443  ms.pt.un_530 so.ht.un_430 
  0x47733612, 0x0f002507, 0x516e25a4, 0x111e1912,   // gn.ny.sn_654 eu.lv.un_420  eu.hmn.kl_433 gl.ms.ro_654 
  0x0a002312, 0x16172da4, 0x130751ad, 0x4423180c,   // ky.mk.un_640 sk.sr.hr_433  kl.it.et_643 ar.ky.kk_543 
  // [19740]
  0x1f000705, 0x160d2dee, 0x09001221, 0x17162d04,   // it.cy.un_330 sk.cs.hr_422  hu.pl.un_860 sk.hr.sr_332 
  0x3c00280c, 0x21303460, 0x0804440c, 0x2b004a1a,   // sd.ug.un_530 ps.uz.fa_664  kk.ru.uk_543 yo.vi.un_760 
  0x0a481707, 0x160d2d04, 0x21182812, 0x1130380c,   // sr.tt.mk_432 sk.cs.hr_332  sd.ar.fa_654 tk.uz.ro_543 
  0x09203207, 0x4a2e0ea9, 0x302515ee, 0x18343dac,   // bs.sq.pl_432 is.fo.yo_544  un.mn.uz_422 ku.ps.ar_632 
  // [19750]
  0x4a0e2e13, 0x30152307, 0x2e002b1b, 0x071048a0,   // fo.is.yo_665 ky.uz.un_420  vi.fo.un_770 tt.be.bg_322 
  0x081711ad, 0x3e231da4, 0x250f135a, 0xfc090d55,   // ro.sr.uk_643 la.ca.rm_433  et.lv.eu_553 cs.pl.zzp_442 
  0x13185c07, 0x46001802, 0x011d0da0, 0x252f2411,   // sa.ga.et_432 ga.qu.un_220  cs.la.en_322 eo.su.eu_653 
  0x250715a0, 0x472852a7, 0x1e2252a0, 0x475a60ee,   // un.bg.mn_322 ha.sw.sn_532  ha.oc.ms_322 vo.sm.sn_422 
  // [19760]
  0x3038350d, 0x1d6a0f55, 0x25565e5a, 0x55fc1da0,   // tg.tk.uz_554 lv.haw.la_442  ts.mg.eu_553 la.zzp.rw_322 
  0x041a4604, 0x69525308, 0x2e0e3612, 0x76695e0c,   // qu.tl.fi_332 ht.ha.mfe_443  gn.is.fo_654 ts.mfe.crs_543 
  0x79041aa0, 0x18001f1a, 0x106551a9, 0x0d163208,   // tl.fi.war_322 cy.ga.un_760  kl.gv.lt_544 bs.hr.cs_443 
  0x014f1555, 0x5f00fe11, 0x30031ea9, 0x7328470c,   // un.bi.en_442 tlh.tn.un_630  ms.nl.uz_544 sn.sw.ny_543 
  // [19770]
  0x0e10390d, 0x20692507, 0x473e6a08, 0x21303d60,   // br.lt.is_554 eu.mfe.sq_432  haw.rm.sn_443 ku.uz.fa_664 
  0x611e02a4, 0x73474002, 0x5a004713, 0x2847020c,   // da.ms.za_433 lb.sn.ny_222  sn.sm.un_650 da.sn.sw_543 
  0x47182811, 0x043756ac, 0xfe2051a0, 0x310e01a0,   // sw.ga.sn_653 mg.st.fi_632  kl.sq.tlh_322 en.is.az_322 
  0x102e4f07, 0x3e30fcec, 0x1000fe07, 0x1e1c01a0,   // bi.fo.lt_432 zzp.uz.rm_644  tlh.lt.un_420 en.id.ms_322 
  // [19780]
  0x51fc1d07, 0x3000fc22, 0x15443c04, 0x4f002f19,   // la.zzp.kl_432 zzp.uz.un_870  ug.kk.un_332 su.bi.un_750 
  0x38330812, 0x55434055, 0x010663af, 0x061357ad,   // no.nn.tk_654 lb.ie.rw_442  sco.de.en_655 na.et.de_643 
  0x3428120e, 0x1c007904, 0x58001105, 0x1e1c1a0c,   // ur.sd.ps_555 war.id.un_320  ro.om.un_330 tl.id.ms_543 
  0x1f066313, 0x482338ad, 0x11003913, 0x2a005302,   // sco.de.cy_665 tk.ky.tt_643  br.ro.un_650 ht.mt.un_220 
  // [19790]
  0x393003a9, 0x0200111b, 0x01066307, 0x2b3f43a0,   // nl.uz.br_544 ro.da.un_770  sco.de.en_432 ie.af.vi_322 
  0x0307650c, 0x3e3f79a0, 0x0c00090d, 0x34400602,   // gv.it.nl_543 war.af.rm_322  pl.sv.un_540 de.lb.xh_222 
  0x51002c07, 0x796a6008, 0x0e2e5d07, 0x32650307,   // fy.kl.un_420 vo.haw.war_443  ss.fo.is_432 nl.gv.bs_432 
  0x3203feee, 0x421d43a0, 0x303119a0, 0x36003f0c,   // tlh.nl.bs_422 ie.la.co_322  gl.az.uz_322 af.gn.un_530 
  // [197a0]
  0x47010208, 0x050601a9, 0x21123da4, 0x151710a7,   // da.en.sn_443 en.de.fr_544  ku.ur.fa_433 be.sr.un_532 
  0x233725a0, 0x232507a4, 0x18001221, 0x04300855,   // mn.ba.ky_322 bg.mn.ky_433  ur.ar.un_860 uk.uz.ru_442 
  0x232b3e08, 0x17440aa9, 0x5c131c04, 0x2e450e11,   // rm.vi.ca_443 mk.kk.sr_544  mr.bh.sa_332 is.ln.fo_653 
  0x1d0410a0, 0x1523100d, 0x10006404, 0x35000814,   // lt.fi.la_322 be.ky.un_554  lg.lt.un_320 uk.tg.un_660 
  // [197b0]
  0x4a2e0e09, 0x04374402, 0x2407420c, 0x1d57560c,   // is.fo.yo_444 kk.ba.ru_222  co.it.eo_543 mg.na.la_543 
  0x1b315cec, 0x26001d23, 0x305c12a4, 0x6759550d,   // sa.az.tr_644 la.ia.un_880  hu.sa.uz_433 rw.rn.ak_554 
  0x19220b07, 0x3809100d, 0x4838370e, 0x30311008,   // es.oc.gl_432 lt.pl.tk_554  ba.tk.tt_555 lt.az.uz_443 
  0x07502613, 0x400625a4, 0x350a11a6, 0x3b2134af,   // ia.fj.it_665 eu.de.lb_433  ro.mk.tg_521 ps.fa.ks_655 
  // [197c0]
  0x47025707, 0x03222307, 0x182927a0, 0x321b3104,   // na.da.sn_432 ca.oc.nl_432  gd.sl.ga_322 az.tr.bs_332 
  0x00005937, 0x5755470c, 0x061b31ec, 0x100f31a7,   // rn.un.un_B00 sn.rw.na_543  az.tr.de_644 az.lv.lt_532 
  0x79003009, 0x2a00300d, 0x03172a07, 0x480a07a9,   // uz.war.un_440 uz.mt.un_540  mt.sr.nl_432 bg.mk.tt_544 
  0x0300041b, 0x37555fa4, 0x2a200307, 0x35375fa9,   // fi.nl.un_770 tn.rw.st_433  nl.sq.mt_432 tn.st.zu_544 
  // [197d0]
  0x530f1005, 0x2000fc04, 0x025f470c, 0x5f0237a9,   // lt.lv.ht_333 zzp.sq.un_320  sn.tn.da_543 st.da.tn_544 
  0x355c56a0, 0x311922a0, 0x3e005904, 0x5a001a07,   // mg.sa.zu_322 oc.gl.az_322  rn.rm.un_320 tl.sm.un_420 
  0x47255f07, 0x1c001e12, 0x0400fe0b, 0x5f56750c,   // tn.eu.sn_432 ms.id.un_640  tlh.fi.un_520 nso.mg.tn_543 
  0x53020dad, 0x3200fe04, 0x0a0d50a0, 0x511d5a07,   // cs.da.ht_643 tlh.bs.un_320  fj.cs.pt_322 sm.la.kl_432 
  // [197e0]
  0x18003804, 0x2e0e6b05, 0x1a345804, 0x6b1a46a9,   // tk.ga.un_320 ceb.is.fo_333  om.xh.tl_332 qu.tl.ceb_544 
  0x530d02a4, 0x1a496b12, 0x1e230ba9, 0xfe460d0c,   // da.cs.ht_433 ceb.to.tl_654  es.ca.ms_544 cs.qu.tlh_543 
  0x2f0221a9, 0x390d02a7, 0x3f533904, 0x5d004708,   // jw.da.su_544 da.cs.br_532  br.ht.af_332 sn.ss.un_430 
  0x1d3b10a7, 0x555c30a0, 0x02286a0c, 0x5a1910a4,   // lt.so.la_532 uz.sa.rw_322  haw.sw.da_543 lt.gl.sm_433 
  // [197f0]
  0x5c5620a0, 0x6a00040c, 0x345e5509, 0x274d2308,   // sq.mg.sa_322 fi.haw.un_530  rw.ts.xh_444 ca.aa.gd_443 
  0x1a2801a0, 0x4c796baf, 0x58483108, 0x231538ec,   // en.sw.tl_322 ceb.war.wo_655  az.tt.om_443 tk.ky.un_640 
  0x135956a4, 0x1d072702, 0x65530504, 0x30134813,   // mg.rn.et_433 gd.it.la_222  fr.ht.gv_332 tt.et.uz_665 
  0x6542050c, 0x47375f5a, 0x642925a0, 0x1a004c2c,   // fr.co.gv_543 tn.st.sn_553  eu.sl.lg_322 wo.tl.un_990 
  
  // [19800]
  0x20033f55, 0x69590605, 0x52732812, 0x645c48a9,   // af.nl.sq_442 de.rn.mfe_333  sw.ny.ha_654 tt.sa.lg_544 
  0x35fe79ad, 0x40005308, 0x3b790107, 0x394d1aa9,   // war.tlh.zu_643 ht.lb.un_430  en.war.so_432 tl.aa.br_544 
  0x6b1a1e07, 0x53050d02, 0x595e390c, 0x485146a0,   // ms.tl.ceb_432 cs.fr.ht_222  br.ts.rn_543 qu.kl.tt_322 
  0x3e2e50ec, 0x484c1c0c, 0x504b1aa9, 0x513b1a0c,   // fj.fo.rm_644 id.wo.tt_543  tl.mi.fj_544 tl.so.kl_543 
  // [19810]
  0x0200fc12, 0x2d121d02, 0x4a00571a, 0x3e53220c,   // zzp.da.un_640 la.hu.sk_222  na.yo.un_760 oc.ht.rm_543 
  0x57060f0c, 0x21002d0c, 0x155955ad, 0x62000113,   // lv.de.na_543 sk.jw.un_530  rw.rn.un_643 en.kha.un_650 
  0x200c22a4, 0x44253608, 0x3e02fca6, 0x31301f0d,   // oc.sv.sq_433 ab.mn.kk_443  zzp.da.rm_521 cy.uz.az_554 
  0x326428a6, 0x28004d0d, 0x024967a4, 0x300a1507,   // sw.lg.bs_521 aa.sw.un_540  ak.to.da_433 un.mk.uz_432 
  // [19820]
  0x10002a09, 0x0f2d10af, 0x2c3f0360, 0x3f792a07,   // mt.lt.un_440 lt.sk.lv_655  nl.af.fy_664 mt.war.af_432 
  0x022d0da7, 0x390242a0, 0x1e1c2fec, 0x32043302,   // cs.sk.da_532 co.da.br_322  su.id.ms_644 nn.fi.bs_222 
  0x2e04020b, 0x373848af, 0x475a64a7, 0x472803a9,   // da.fi.fo_542 tt.tk.ba_655  lg.sm.sn_532 nl.sw.sn_544 
  0x287364ee, 0x3f002207, 0x01181213, 0x073e53a7,   // lg.ny.sw_422 oc.af.un_420  ur.ar.iw_665 ht.rm.it_532 
  // [19830]
  0x651c01a0, 0x250548a0, 0x1d005302, 0x0410080e,   // en.id.gv_322 tt.fr.eu_322  ht.la.un_220 uk.be.ru_555 
  0x65006708, 0x07353060, 0x13694dad, 0x376563a7,   // ak.gv.un_430 uz.tg.bg_664  aa.mfe.et_643 sco.gv.st_532 
  0x0a00050b, 0x1d3e42a7, 0x3e2353af, 0x23220ba0,   // fr.pt.un_520 co.rm.la_532  ht.ca.rm_655 es.oc.ca_322 
  0x635301a0, 0x4c2d0d04, 0x2d0d690c, 0x0600220c,   // en.ht.sco_322 cs.sk.wo_332  mfe.cs.sk_543 oc.de.un_530 
  // [19840]
  0x13073e07, 0x634c08a0, 0x671d260c, 0x4d022e08,   // rm.it.et_432 no.wo.sco_322  ia.la.ak_543 fo.da.aa_443 
  0x30341208, 0xfc017904, 0x60330805, 0x21001107,   // ur.ps.uz_443 war.en.zzp_332  no.nn.vo_333 ro.jw.un_420 
  0x07421d07, 0x5a004a08, 0x01002f02, 0x27fc0e05,   // la.co.it_432 yo.sm.un_430  su.en.un_220 is.zzp.gd_333 
  0x1d053eec, 0x201d420c, 0x1004085a, 0xfc4006a4,   // rm.fr.la_644 co.la.sq_543  uk.ru.be_553 de.lb.zzp_433 
  // [19850]
  0x48002f04, 0x23080455, 0x38353009, 0x313054ad,   // su.tt.un_320 ru.uk.ky_442  uz.tg.tk_444 ik.uz.az_643 
  0x343d440d, 0x40066707, 0xfc5634a4, 0x0a05fe0c,   // kk.ku.ps_554 ak.de.lb_432  xh.mg.zzp_433 tlh.fr.pt_543 
  0x34fc3e14, 0xfc2c56ad, 0xfc2d5602, 0x1f0742a0,   // rm.zzp.xh_666 mg.fy.zzp_643  mg.sk.zzp_222 co.it.cy_322 
  0x17291604, 0x383c48af, 0x05374eac, 0x47736414,   // hr.sl.sr_332 tt.ug.tk_655  ay.st.fr_632 lg.ny.sn_666 
  // [19860]
  0x18270207, 0x643456ee, 0x34376e07, 0x3e00580b,   // da.gd.ga_432 mg.xh.lg_422  hmn.st.xh_432 om.rm.un_520 
  0x7300472b, 0x185c275a, 0x46fc4eac, 0x3c1218a4,   // sn.ny.un_980 gd.sa.ga_553  ay.zzp.qu_632 ar.ur.ug_433 
  0x1e00250e, 0x150962a9, 0x4c002a07, 0x48386007,   // eu.ms.un_550 kha.pl.un_544  mt.wo.un_420 vo.tk.tt_432 
  0x04790908, 0x3c0a0713, 0x390b6aa9, 0x455f490c,   // pl.war.fi_443 bg.mk.ug_665  haw.es.br_544 to.tn.ln_543 
  // [19870]
  0x2a39fea0, 0x02002905, 0x2100201a, 0x5f7601a0,   // tlh.br.mt_322 sl.da.un_330  sq.jw.un_760 en.crs.tn_322 
  0x680f45a0, 0xfe697612, 0x35384304, 0x0e0c120b,   // ln.lv.ig_322 crs.mfe.tlh_654  ie.tk.zu_332 hu.sv.is_542 
  0x226901a4, 0x3b1d5104, 0x636a40ec, 0x5a654904,   // en.mfe.oc_433 kl.la.so_332  lb.haw.sco_644 to.gv.sm_332 
  0x31002702, 0x10483612, 0x40033faf, 0x040142a0,   // gd.az.un_220 ab.tt.be_654  af.nl.lb_655 co.en.fi_322 
  // [19880]
  0x2d3440a9, 0x47005d05, 0x375f570c, 0x1f00271a,   // lb.xh.sk_544 ss.sn.un_330  na.tn.st_543 gd.cy.un_760 
  0x1e1c36a4, 0xfe574da4, 0x02675cec, 0x12fe0fa0,   // gn.id.ms_433 aa.na.tlh_433  sa.ak.da_644 lv.tlh.hu_322 
  0x3b002c07, 0x38001312, 0x34283b0c, 0x1d4222a0,   // fy.so.un_420 et.tk.un_640  ks.sd.ps_543 oc.co.la_322 
  0x21000f0d, 0x2a001a02, 0x6400732c, 0x27631107,   // lv.jw.un_540 tl.mt.un_220  ny.lg.un_990 ro.sco.gd_432 
  // [19890]
  0x27003f05, 0x083504a7, 0x4b006408, 0x555659a9,   // af.gd.un_330 ru.tg.uk_532  lg.mi.un_430 rn.mg.rw_544 
  0x2a00fe0b, 0x5a000a04, 0x732852a4, 0x190a3305,   // tlh.mt.un_520 pt.sm.un_320  ha.sw.ny_433 nn.pt.gl_333 
  0x273f63ad, 0x79190a13, 0x03133fa0, 0x384423a9,   // sco.af.gd_643 pt.gl.war_665  af.et.nl_322 ky.kk.tk_544 
  0x320a4707, 0x646755a9, 0x30194c12, 0x2a003933,   // sn.pt.bs_432 rw.ak.lg_544  wo.gl.uz_654 dz.bo.un_A70 
  // [198a0]
  0x2a001809, 0x436447ad, 0x55477308, 0x0a00240d,   // ga.mt.un_440 sn.lg.ie_643  ny.sn.rw_443 eo.pt.un_540 
  0x17003612, 0x46790b04, 0x10000902, 0x04132aa0,   // ab.sr.un_640 es.war.qu_332  pl.lt.un_220 mt.et.fi_322 
  0x73025da9, 0x3713730d, 0x517348a9, 0x24fcfea0,   // ss.da.ny_544 ny.et.st_554  tt.ny.kl_544 tlh.zzp.eo_322 
  0x2f215ead, 0x785956a9, 0x515d73ec, 0x48375fa9,   // ts.jw.su_643 mg.rn.ve_544  ny.ss.kl_644 tn.st.tt_544 
  // [198b0]
  0x5113fc08, 0x135c0955, 0x1537485a, 0x47001808,   // zzp.et.kl_443 hi.sa.bh_442  tt.ba.un_553 ga.sn.un_430 
  0x5700370d, 0x595d5508, 0x1f006112, 0x041108a4,   // st.na.un_540 rw.ss.rn_443  za.cy.un_640 uk.ro.ru_433 
  0x73482508, 0x735d55a4, 0x04515608, 0x55007319,   // eu.tt.ny_443 rw.ss.ny_433  mg.kl.fi_443 ny.rw.un_750 
  0x7334510d, 0x4700730d, 0x074211ee, 0x565f7309,   // kl.xh.ny_554 ny.sn.un_540  ro.co.it_422 ny.tn.mg_444 
  // [198c0]
  0x35513411, 0x15113cec, 0x4a004208, 0x070448a4,   // xh.kl.zu_653 ug.ro.un_644  co.yo.un_430 tt.ru.bg_433 
  0x080220ee, 0x30041507, 0x4200530d, 0x01650507,   // sq.da.no_422 un.ru.uz_432  ht.co.un_540 fr.gv.en_432 
  0x2d0a2505, 0x05002005, 0x37002d08, 0x364e4da4,   // eu.pt.sk_333 sq.fr.un_330  sk.st.un_430 aa.ay.gn_433 
  0x5e0147a0, 0x0a3c110c, 0x430cfcec, 0x48002f02,   // sn.en.ts_322 ro.ug.mk_543  zzp.sv.ie_644 su.tt.un_220 
  // [198d0]
  0x56001907, 0xfc2d09ec, 0x0ffc22a0, 0x1d503fa0,   // gl.mg.un_420 pl.sk.zzp_644  oc.zzp.lv_322 af.fj.la_322 
  0x4400081b, 0x0f07060c, 0x10250713, 0x352d09a9,   // uk.kk.un_770 de.it.lv_543  bg.mn.be_665 pl.sk.zu_544 
  0x2d092ea9, 0x29461307, 0x5e2847af, 0x5500360e,   // fo.pl.sk_544 et.qu.sl_432  sn.sw.ts_655 gn.rw.un_550 
  0x0f3b4c0d, 0x5c4734a0, 0x55005e12, 0x482523a4,   // wo.so.lv_554 xh.sn.sa_322  ts.rw.un_640 ky.mn.tt_433 
  // [198e0]
  0x0f003b12, 0x233c28a9, 0x120434ac, 0x0f3b6404,   // so.lv.un_640 sd.ug.ky_544  xh.fi.hu_632 lg.so.lv_332 
  0x361e1c04, 0x23070aa0, 0x07001f0e, 0x313b4807,   // id.ms.gn_332 pt.it.ca_322  cy.it.un_550 tt.so.az_432 
  0x3b003d1b, 0x4759550e, 0x3c3d21a9, 0x300704a0,   // ku.ks.un_770 rw.rn.sn_555  fa.ku.ug_544 ru.bg.uz_322 
  0x37443c13, 0x64733408, 0x36424aee, 0x18205ca0,   // ug.kk.ba_665 xh.ny.lg_443  yo.co.gn_422 sa.sq.ga_322 
  // [198f0]
  0x37232507, 0x6100471a, 0x55004713, 0x1ffe180d,   // mn.ky.ba_432 sn.za.un_760  sn.rw.un_650 ga.tlh.cy_554 
  0x4830230d, 0x01005102, 0x131827a0, 0x30003120,   // ky.uz.tt_554 kl.en.un_220  gd.ga.et_322 az.uz.un_850 
  0x212f1a04, 0x53422204, 0x652c0302, 0x10443704,   // tl.su.jw_332 oc.co.ht_332  nl.fy.gv_222 ba.kk.be_332 
  0x3f651fa0, 0x2a3e69a4, 0x0a3511a4, 0x281221a6,   // cy.gv.af_322 mfe.rm.mt_433  ro.tg.mk_433 fa.ur.sd_521 
  // [19900]
  0x2500020b, 0x654701ee, 0x58260104, 0x2c030608,   // da.eu.un_520 en.sn.gv_422  en.ia.om_332 de.nl.fy_443 
  0x79004808, 0x13001e20, 0x070a48a6, 0x232a1355,   // tt.war.un_430 ms.et.un_850  tt.mk.bg_521 et.mt.ca_442 
  0x11002322, 0x3500460d, 0x63000118, 0x082311a7,   // ky.ro.un_870 qu.zu.un_540  en.sco.un_740 ro.ky.uk_532 
  0x3f002304, 0x3c2312a7, 0x2b732708, 0x0a173009,   // ca.af.un_320 ur.ky.ug_532  gd.ny.vi_443 uz.sr.mk_444 
  // [19910]
  0x5d02fe0c, 0x03005605, 0x0a07110e, 0x151738a0,   // tlh.da.ss_543 mg.nl.un_330  ro.bg.mk_555 tk.sr.un_322 
  0x5d001208, 0x30352507, 0x2c3f0e04, 0x044807a7,   // hu.ss.un_430 mn.tg.uz_432  is.af.fy_332 bg.tt.ru_532 
  0x3f000e02, 0x3bfc400c, 0x043515a4, 0x34155d0c,   // is.af.un_220 lb.zzp.so_543  un.tg.ru_433 ss.xh.un_530 
  0x100724ee, 0x33001212, 0x40006502, 0x2a000e12,   // eo.it.lt_422 hu.nn.un_640  gv.lb.un_220 is.mt.un_640 
  // [19920]
  0x05032308, 0x441230a0, 0x24353404, 0x101f1d02,   // ca.nl.fr_443 uz.ur.kk_322  xh.zu.eo_332 la.cy.lt_222 
  0x0d2a0e07, 0x79072408, 0x1f004205, 0x40004813,   // is.mt.cs_432 eo.it.war_443  co.cy.un_330 tt.lb.un_650 
  0x21fe1e04, 0x463b24af, 0x044415a7, 0x4830130c,   // ms.tlh.jw_332 eo.so.qu_655  un.kk.ru_532 et.uz.tt_543 
  0x205cfea7, 0x470203af, 0x11483708, 0x10000818,   // tlh.sa.sq_532 nl.da.sn_655  ba.tt.ro_443 uk.be.un_740 
  // [19930]
  0x46000607, 0x655c0302, 0x40736104, 0x26100608,   // de.qu.un_420 nl.sa.gv_222  za.ny.lb_332 de.lt.ia_443 
  0x1c281ea9, 0x2d290da7, 0x2c1f490c, 0x405a0ea4,   // ms.sw.id_544 cs.sl.sk_532  to.cy.fy_543 is.sm.lb_433 
  0x402d0d55, 0x28473e04, 0x28737912, 0x026578ec,   // cs.sk.lb_442 rm.sn.sw_332  war.ny.sw_654 ve.gv.da_644 
  0x40180608, 0x24fe610c, 0x1f000a02, 0x18634004,   // de.ga.lb_443 za.tlh.eo_543  pt.cy.un_220 lb.sco.ga_332 
  // [19940]
  0x2f63010c, 0xfc472fa7, 0x56002112, 0x1f004012,   // en.sco.su_543 su.sn.zzp_532  jw.mg.un_640 lb.cy.un_640 
  0x6500fc0e, 0x1b46305a, 0x1a583805, 0x23195ea7,   // zzp.gv.un_550 uz.qu.tr_553  tk.om.tl_333 ts.gl.ca_532 
  0x5a575004, 0x2e000e34, 0x10331fa6, 0x105e4bec,   // fj.na.sm_332 is.fo.un_A80  cy.nn.lt_521 mi.ts.lt_644 
  0x0e1806ad, 0x4d00510e, 0x5e005b1a, 0x21552f12,   // de.ga.is_643 kl.aa.un_550  sg.ts.un_760 su.rw.jw_654 
  // [19950]
  0x32291605, 0x28005113, 0x526208a0, 0x1d0104ee,   // hr.sl.bs_333 kl.sw.un_650  no.kha.ha_322 fi.en.la_422 
  0x290d17a4, 0x362325a9, 0x1700530c, 0x18005607,   // sr.cs.sl_433 mn.ky.ab_544  ht.sr.un_530 mg.ga.un_420 
  0x303523ee, 0x20022e05, 0x1c254ca0, 0x52632060,   // ky.tg.uz_422 fo.da.sq_333  wo.eu.id_322 sq.sco.ha_664 
  0x04130c04, 0x31304cec, 0x3e004c0c, 0x12570504,   // sv.et.fi_332 wo.uz.az_644  wo.rm.un_530 fr.na.hu_332 
  // [19960]
  0x1305200c, 0x2c433f04, 0x20050107, 0x16170dad,   // sq.fr.et_543 af.ie.fy_332  en.fr.sq_432 cs.sr.hr_643 
  0x17080413, 0x480a2508, 0x0d17290b, 0x2f40210c,   // ru.uk.sr_665 mn.mk.tt_443  sl.sr.cs_542 jw.lb.su_543 
  0x3e003805, 0x06211e07, 0x3f0522ee, 0x021c1ea6,   // tk.rm.un_330 ms.jw.de_432  oc.fr.af_422 ms.id.da_521 
  0x64121307, 0x40063708, 0x68041311, 0x10130404,   // et.hu.lg_432 st.de.lb_443  et.fi.ig_653 fi.et.lt_332 
  // [19970]
  0x2a04100c, 0x791302ad, 0x13042a0d, 0x212f6112,   // lt.fi.mt_543 da.et.war_643  mt.fi.et_554 za.su.jw_654 
  0x03002a09, 0x12643ba0, 0x1a212f08, 0x21002f1a,   // mt.nl.un_440 so.lg.hu_322  su.jw.tl_443 su.jw.un_760 
  0x2f06400e, 0x2f21060d, 0x4d001321, 0x13005a13,   // lb.de.su_555 de.jw.su_554  et.aa.un_860 sm.et.un_650 
  0x530304ad, 0x513b130c, 0x10032aaf, 0x04482355,   // fi.nl.ht_643 et.so.kl_543  mt.nl.lt_655 ky.tt.ru_442 
  // [19980]
  0x2f1c2108, 0x53003e1b, 0x290d16eb, 0x534c3955,   // jw.id.su_443 rm.ht.un_770  hr.cs.sl_662 br.wo.ht_442 
  0x1d0f0307, 0x0600480e, 0x4d4b7908, 0x05004c20,   // nl.lv.la_432 tt.de.un_550  war.mi.aa_443 wo.fr.un_850 
  0x5c0d6307, 0x020520a6, 0x5d63010c, 0x041347ec,   // sco.cs.sa_432 sq.fr.da_521  en.sco.ss_543 sn.et.fi_644 
  0x655911ad, 0x190b11a9, 0x3808020d, 0x2d0d0b0e,   // ro.rn.gv_643 ro.es.gl_544  da.no.tk_554 es.cs.sk_555 
  // [19990]
  0x111d6007, 0x0f001d05, 0x4c4d5211, 0x0f00031a,   // vo.la.ro_432 la.lv.un_330  ha.aa.wo_653 nl.lv.un_760 
  0x0a082304, 0x34255905, 0x0810110c, 0x04004d13,   // ky.uk.mk_332 rn.eu.xh_333  ro.be.uk_543 aa.fi.un_650 
  0x515842ec, 0x7800471a, 0x040e58a0, 0x694311a4,   // co.om.kl_644 sn.ve.un_760  om.is.fi_322 ro.ie.mfe_433 
  0x1517070e, 0x476311a9, 0x5d3534af, 0x58005113,   // bg.sr.un_555 ro.sco.sn_544  xh.zu.ss_655 kl.om.un_650 
  // [199a0]
  0x27004714, 0x101729a0, 0x34fe3511, 0x292d10ee,   // sn.gd.un_660 sl.sr.lt_322  zu.tlh.xh_653 lt.sk.sl_422 
  0x38000819, 0x3c003609, 0x30003619, 0x0f5c0407,   // uk.tk.un_750 ab.ug.un_440  ab.uz.un_750 fi.sa.lv_432 
  0x483c380d, 0x0b0a1d02, 0x1d001120, 0x432301a4,   // tk.ug.tt_554 la.pt.es_222  ro.la.un_850 en.ca.ie_433 
  0x63002d05, 0x1dfc01a9, 0x36190dee, 0x0d0b18a4,   // sk.sco.un_330 en.zzp.la_544  cs.gl.gn_422 ga.es.cs_433 
  // [199b0]
  0x3e022a04, 0x04083608, 0x35342ca0, 0x112d0d55,   // mt.da.rm_332 ab.uk.ru_443  fy.xh.zu_322 cs.sk.ro_442 
  0x194e0ba9, 0x1900450c, 0x4c004e09, 0x1d001d09,   // es.ay.gl_544 ln.gl.un_530  ay.wo.un_440 la.la.un_440 
  0x35343eee, 0x23fc01a4, 0x20005b1b, 0x374436a7,   // rm.xh.zu_422 en.zzp.ca_433  sg.sq.un_770 ab.kk.ba_532 
  0x4d005d09, 0x2555060c, 0x351538a7, 0x1c062f02,   // ss.aa.un_440 de.rw.eu_543  tk.tg.un_520 su.de.id_222 
  // [199c0]
  0x04000e08, 0x55537607, 0x30480707, 0x0c330ea0,   // is.fi.un_430 crs.ht.rw_432  bg.tt.uz_432 is.nn.sv_322 
  0x5c0c0208, 0x0a232211, 0x46002a07, 0x0900060d,   // da.sv.sa_443 oc.ca.pt_653  mt.qu.un_420 de.pl.un_540 
  0x48303b55, 0x2d0d0e05, 0x23002709, 0x54130408,   // so.uz.tt_442 is.cs.sk_333  gd.ca.un_440 fi.et.ik_443 
  0x30003b1a, 0x0c2b02a0, 0x2a00480d, 0x2e4e0e12,   // ks.uz.un_760 da.vi.sv_322  tt.mt.un_540 is.ay.fo_654 
  // [199d0]
  0x100823ad, 0x3b004a04, 0x0f2410a7, 0x33000c21,   // ky.uk.be_643 yo.so.un_320  lt.eo.lv_532 sv.nn.un_860 
  0x442504a0, 0x10393e08, 0x38002e02, 0x2d0f10ec,   // ru.mn.kk_322 rm.br.lt_443  fo.tk.un_220 lt.lv.sk_644 
  0x08332e0b, 0x45052204, 0x0f002d19, 0x20254d55,   // fo.nn.no_542 oc.fr.ln_332  sk.lv.un_750 aa.eu.sq_442 
  0x110830af, 0x301b25ad, 0x1d4305a4, 0x48370404,   // uz.uk.ro_655 eu.tr.uz_643  fr.ie.la_433 ru.ba.tt_332 
  // [199e0]
  0x050b1d05, 0x3800600e, 0x256a4907, 0x6a000712,   // la.es.fr_333 vo.tk.un_550  to.haw.eu_432 it.haw.un_640 
  0x23443ca7, 0x563907ee, 0x38006011, 0x0a051dad,   // ug.kk.ky_532 it.br.mg_422  vo.tk.un_630 la.fr.pt_643 
  0x3000690d, 0x50396aec, 0x2d00290d, 0x1d000b02,   // mfe.uz.un_540 haw.br.fj_644  sl.sk.un_540 es.la.un_220 
  0x05561da0, 0x053522a0, 0x051d010b, 0x6a005a14,   // la.mg.fr_322 oc.zu.fr_322  en.la.fr_542 sm.haw.un_660 
  // [199f0]
  0x190a6aa4, 0x0b006a0b, 0x5817290b, 0x162b12a0,   // haw.pt.gl_433 haw.es.un_520  sl.sr.om_542 hu.vi.hr_322 
  0x024773ad, 0x59555205, 0x322a17a0, 0x2f1b450c,   // ny.sn.da_643 ha.rw.rn_333  sr.mt.bs_322 ln.tr.su_543 
  0x35342502, 0xfe0f130c, 0x0742fe04, 0x0ffe2004,   // eu.xh.zu_222 et.lv.tlh_543  tlh.co.it_332 sq.tlh.lv_332 
  0x1d04135a, 0x5000fe22, 0x32005a0c, 0x4b28130b,   // et.fi.la_553 tlh.fj.un_870  sm.bs.un_530 et.sw.mi_542 
  // [19a00]
  0x044b50a9, 0x1000451a, 0x1d0413a0, 0x47fe28a9,   // fj.mi.fi_544 ln.lt.un_760  et.fi.la_322 sw.tlh.sn_544 
  0x5e001f08, 0x0200522b, 0x281d5207, 0x135a5905,   // cy.ts.un_430 ha.da.un_980  ha.la.sw_432 rn.sm.et_333 
  0x47495aad, 0x10005a04, 0x0e0d0a08, 0x0e2318a0,   // sm.to.sn_643 sm.lt.un_320  pt.cs.is_443 ga.ca.is_322 
  0x06381ba9, 0x2e164ba0, 0x1b005413, 0xfc4007a7,   // tr.tk.de_544 mi.hr.fo_322  ik.tr.un_650 it.lb.zzp_532 
  // [19a10]
  0x041350ec, 0x0c1f3855, 0x5d5559a4, 0x1b481207,   // fj.et.fi_644 tk.cy.sv_442  rn.rw.ss_433 hu.tt.tr_432 
  0x390833a0, 0x150448a9, 0x02511313, 0x3d3c28a4,   // nn.no.br_322 tt.ru.un_544  et.kl.da_665 sd.ug.ku_433 
  0x31464e04, 0x43fc1d0c, 0x230a170c, 0x53050207,   // ay.qu.az_332 la.zzp.ie_543  sr.mk.ky_543 da.fr.ht_432 
  0x1b693007, 0x04083612, 0x48024055, 0x182d36a0,   // uz.mfe.tr_432 ab.uk.ru_654  lb.da.tt_442 gn.sk.ga_322 
  // [19a20]
  0x5c3138ee, 0x190b4311, 0x021a1355, 0x4b002907,   // tk.az.sa_422 ie.es.gl_653  et.tl.da_442 sl.mi.un_420 
  0x6b6830ee, 0x01000512, 0x04001f04, 0x4428345a,   // uz.ig.ceb_422 fr.en.un_640  cy.fi.un_320 ps.sd.kk_553 
  0x0e5233a4, 0x1f1827a7, 0x4d002019, 0x4b00290d,   // nn.ha.is_433 gd.ga.cy_532  sq.aa.un_750 sl.mi.un_540 
  0x0d1143ad, 0x151707a7, 0x15005a04, 0x4b002904,   // ie.ro.cs_643 bg.sr.un_532  sm.un.un_320 sl.mi.un_320 
  // [19a30]
  0x04083c0e, 0x0a154407, 0x392405ee, 0x290d090c,   // ug.uk.ru_555 kk.mk.un_420  fr.eo.br_422 pl.cs.sl_543 
  0x44003711, 0x38520ea0, 0x481b3007, 0x2c471a04,   // ba.kk.un_630 is.ha.tk_322  uz.tr.tt_432 tl.sn.fy_332 
  0x25003c0b, 0x7300471b, 0x1e52280c, 0x033f5104,   // ug.mn.un_520 sn.ny.un_770  sw.ha.ms_543 kl.af.nl_332 
  0x43631d12, 0x0d361810, 0x345d3511, 0x283412ee,   // la.sco.ie_654 ga.gn.cs_642  zu.ss.xh_653 ur.ps.sd_422 
  // [19a40]
  0x55033f0c, 0x2d2e0ea9, 0x303544ee, 0x2d0d4a0c,   // af.nl.rw_543 is.fo.sk_544  kk.tg.uz_422 yo.cs.sk_543 
  0x37313f07, 0x1c00fc04, 0x10080a0e, 0x370810a0,   // af.az.st_432 zzp.id.un_320  mk.uk.be_555 be.uk.ba_322 
  0x0c2038a4, 0x135c0902, 0x79330804, 0x4600fc0c,   // tk.sq.sv_433 hi.sa.bh_222  no.nn.war_332 zzp.qu.un_530 
  0x40092a0b, 0x392a0905, 0x7857090c, 0x39fc30a0,   // mt.pl.lb_542 pl.mt.br_333  pl.na.ve_543 uz.zzp.br_322 
  // [19a50]
  0x2d001f08, 0x38003523, 0x2c2a5e0c, 0x092a3f12,   // cy.sk.un_430 tg.tk.un_880  ts.mt.fy_543 af.mt.pl_654 
  0x33005504, 0x1f0e61ee, 0x4c0140ee, 0x1d657307,   // rw.nn.un_320 za.is.cy_422  lb.en.wo_422 ny.gv.la_432 
  0x1c00fe07, 0x53211ca4, 0x30171507, 0x3400670c,   // tlh.id.un_420 id.jw.ht_433  un.sr.uz_432 ak.xh.un_530 
  0x0a1044a0, 0x2b005109, 0x304835a9, 0x2e0e3311,   // kk.be.mk_322 kl.vi.un_440  tg.tt.uz_544 nn.is.fo_653 
  // [19a60]
  0x200c56ad, 0x12000f09, 0x2b005802, 0x34213d14,   // mg.sv.sq_643 lv.hu.un_440  om.vi.un_220 ku.fa.ps_666 
  0x322d0d60, 0x09003307, 0x0b001819, 0x33003f0e,   // cs.sk.bs_664 nn.pl.un_420  ga.es.un_750 af.nn.un_550 
  0x1044150c, 0x59555105, 0x10234805, 0x510602a7,   // un.kk.be_543 kl.rw.rn_333  tt.ky.be_333 da.de.kl_532 
  0x2b001d07, 0x0b2b22a0, 0x361101a4, 0x2b00fc02,   // la.vi.un_420 oc.vi.es_322  en.ro.gn_433 zzp.vi.un_220 
  // [19a70]
  0x041523ee, 0x376542a0, 0x035c3e55, 0x013e1da7,   // ky.ru.un_420 co.gv.st_322  rm.sa.nl_442 la.rm.en_532 
  0x34283009, 0x04060fa4, 0x0e2e0faf, 0x032d17a4,   // uz.sd.ps_444 lv.de.fi_433  lv.fo.is_655 sr.sk.nl_433 
  0x07431d55, 0x241d1007, 0x03060202, 0x0a000505,   // la.ie.it_442 lt.la.eo_432  da.de.nl_222 fr.pt.un_330 
  0x4202050d, 0x042e090c, 0x016e150b, 0x0c571307,   // fr.da.co_554 pl.fo.fi_543  un.hmn.en_542 et.na.sv_432 
  // [19a80]
  0x1d0e1005, 0x36170a07, 0x42053f07, 0x20033f0c,   // lt.is.la_333 mk.sr.ab_432  af.fr.co_432 af.nl.sq_543 
  0x46fc6207, 0x2a00622a, 0x2839450c, 0x5f00570c,   // kha.zzp.qu_432 kha.mt.un_970  ln.br.sw_543 na.tn.un_530 
  0x0f0bfca7, 0x053f5505, 0x3b005108, 0x55005f08,   // zzp.es.lv_532 rw.af.fr_333  kl.so.un_430 tn.rw.un_430 
  0x073c2507, 0x40002c0d, 0x5f005908, 0x1f271813,   // mn.ug.bg_432 fy.lb.un_540  rn.tn.un_430 ga.gd.cy_665 
  // [19a90]
  0x672549a9, 0x65002a0c, 0x35071012, 0x78242da4,   // to.eu.ak_544 mt.gv.un_530  be.bg.tg_654 sk.eo.ve_433 
  0xfc002d0e, 0x34212305, 0x35041707, 0x04583b04,   // sk.zzp.un_550 ky.fa.ps_333  sr.ru.tg_432 so.om.fi_332 
  0x100a07a6, 0x10154807, 0x50005a07, 0x375f1ca0,   // it.pt.lt_521 tt.be.un_420  sm.fj.un_420 id.tn.st_322 
  0x100b3607, 0x1d65180c, 0x652b02a0, 0x0d0e0ba0,   // gn.es.lt_432 ga.gv.la_543  da.vi.gv_322 es.is.cs_322 
  // [19aa0]
  0x39562308, 0x5253570c, 0x11000f04, 0x44253707,   // ca.mg.br_443 na.ht.ha_543  lv.ro.un_320 ba.mn.kk_432 
  0x30024c07, 0x2e1830af, 0x0a001f04, 0x0302070c,   // wo.da.uz_432 uz.ga.fo_655  cy.pt.un_320 it.da.nl_543 
  0x394c260c, 0x0e125e13, 0x733457ee, 0x3e5f600c,   // ia.wo.br_543 ts.hu.is_665  na.xh.ny_422 vo.tn.rm_543 
  0x0340060c, 0x3c00361a, 0x07001d14, 0x24190b02,   // de.lb.nl_543 ab.ug.un_760  la.it.un_660 es.gl.eo_222 
  // [19ab0]
  0x4c002e08, 0x2000130d, 0x1c4f1e0c, 0x101347ac,   // fo.wo.un_430 et.sq.un_540  ms.bi.id_543 sn.et.lt_632 
  0x5c002a0c, 0x04205104, 0x2a323b04, 0x30006b07,   // mt.sa.un_530 kl.sq.fi_332  so.bs.mt_332 ceb.uz.un_420 
  0x310f2504, 0x48302909, 0x384c2aa0, 0x045c2a09,   // eu.lv.az_332 sl.uz.tt_444  mt.wo.tk_322 mt.sa.fi_444 
  0x3048230c, 0x542f51a4, 0x13241ea4, 0x37150408,   // ky.tt.uz_543 kl.su.ik_433  ms.eo.et_433 ru.ba.un_430 
  // [19ac0]
  0x303c04ad, 0x252373a9, 0x25000b14, 0x554b59a9,   // ru.ug.uz_643 ny.ca.eu_544  es.eu.un_660 rn.mi.rw_544 
  0x642573a9, 0x6b1a46a0, 0x303148a9, 0x0630feee,   // ny.eu.lg_544 qu.tl.ceb_322  tt.az.uz_544 tlh.uz.de_422 
  0x0c002609, 0x651d600c, 0x3e65420d, 0x11690107,   // ia.sv.un_440 vo.la.gv_543  co.gv.rm_554 en.mfe.ro_432 
  0x652a38a4, 0x73000d08, 0x2900691a, 0x6700730c,   // tk.mt.gv_433 cs.ny.un_430  mfe.sl.un_760 ny.ak.un_530 
  // [19ad0]
  0x23192512, 0x6036470c, 0x644b730c, 0x6915010b,   // eu.gl.ca_654 sn.gn.vo_543  ny.mi.lg_543 en.mfe.un_520 
  0x735626a9, 0x654c13a4, 0x2f2162a4, 0x07040855,   // ia.mg.ny_544 et.wo.gv_433  kha.jw.su_433 uk.ru.bg_442 
  0x632401a4, 0x0417100c, 0x160d32a7, 0x575f370d,   // en.eo.sco_433 be.sr.ru_543  bs.cs.hr_532 st.tn.na_554 
  0x5f003735, 0x73005f0d, 0x0c5637a9, 0x73fc370c,   // st.tn.un_A90 tn.ny.un_540  st.mg.sv_544 st.zzp.ny_543 
  // [19ae0]
  0x3e321614, 0x207357ad, 0x37151104, 0x5f595514,   // hr.bs.rm_666 na.ny.sq_643  ro.ba.un_320 rw.rn.tn_666 
  0x5f0c37ec, 0x1d1d0655, 0x20127307, 0x57377308,   // st.sv.tn_644 de.la.la_442  ny.hu.sq_432 ny.st.na_443 
  0x35375f12, 0x502f2208, 0x375f7309, 0x2b15010c,   // tn.st.zu_654 oc.su.fj_443  ny.tn.st_444 en.vi.un_530 
  0x37153555, 0x2f000905, 0x320d295e, 0x55685907,   // tg.ba.un_420 pl.su.un_330  sl.cs.bs_652 rn.ig.rw_432 
  // [19af0]
  0x3444180c, 0x183d28ac, 0x2d170d09, 0x444837a7,   // ar.kk.ps_543 sd.ku.ar_632  cs.sr.sk_444 ba.tt.kk_532 
  0x0f2d0d18, 0x282c3f12, 0x0c381b07, 0x1d002207,   // cs.sk.lv_764 af.fy.sw_654  tr.tk.sv_432 oc.la.un_420 
  0x5f2c03a0, 0x27003b08, 0x230e2eee, 0x1922230c,   // nl.fy.tn_322 so.gd.un_430  fo.is.ca_422 ca.oc.gl_543 
  0x192f2702, 0x11003f02, 0x42111307, 0x0b00010d,   // gd.su.gl_222 af.ro.un_220  et.ro.co_432 en.es.un_540 
  // [19b00]
  0x283e4902, 0x362538a9, 0x08000723, 0x04113c0c,   // to.rm.sw_222 tk.mn.ab_544  bg.uk.un_880 ug.ro.ru_543 
  0x39270ca4, 0x10003307, 0x5e355d04, 0x1707150e,   // sv.gd.br_433 nn.lt.un_420  ss.zu.ts_332 un.bg.sr_555 
  0x32332aa0, 0x0a15250c, 0x0a395fa0, 0x560f6302,   // mt.nn.bs_322 mn.mk.un_530  tn.br.pt_322 sco.lv.mg_222 
  0x1e1c0205, 0x15000e13, 0x291617a9, 0x0a101513,   // da.id.ms_333 is.un.un_650  sr.hr.sl_544 un.be.mk_665 
  // [19b10]
  0x3d21340b, 0x26004308, 0x2f330804, 0x1c000a04,   // ps.fa.ku_542 ie.ia.un_430  no.nn.su_332 pt.id.un_320 
  0x48080455, 0x09003704, 0x03430407, 0x271e1cee,   // ru.uk.tt_442 st.pl.un_320  fi.ie.nl_432 id.ms.gd_422 
  0x04602804, 0x51047355, 0x0d1029a4, 0x29171614,   // sw.vo.fi_332 ny.fi.kl_442  sl.lt.cs_433 hr.sr.sl_666 
  0x733f6a55, 0x033f1009, 0x05651dad, 0x384006ec,   // haw.af.ny_442 lt.af.nl_444  la.gv.fr_643 de.lb.tk_644 
  // [19b20]
  0x23212202, 0x3418210d, 0x04005008, 0x2e4d330c,   // oc.jw.ca_222 fa.ar.ps_554  fj.fi.un_430 nn.aa.fo_543 
  0x495004ee, 0x2d646aee, 0x04033f04, 0x041044a7,   // fi.fj.to_422 haw.lg.sk_422  af.nl.fi_332 kk.be.ru_532 
  0x0212fc0c, 0x3e550804, 0x1d2e0e0c, 0x32162d02,   // zzp.hu.da_543 no.rw.rm_332  is.fo.la_543 sk.hr.bs_222 
  0x7600330d, 0x3964650d, 0x3b001d09, 0x2a420ca0,   // nn.crs.un_540 gv.lg.br_554  la.so.un_440 sv.co.mt_322 
  // [19b30]
  0x3c1821a0, 0x283d21ee, 0x1f4c2c07, 0x7328340d,   // fa.ar.ug_322 fa.ku.sd_422  fy.wo.cy_432 xh.sw.ny_554 
  0x23005309, 0x6447780c, 0x5a7349a0, 0x5500640b,   // ht.ca.un_440 ve.sn.lg_543  to.ny.sm_322 lg.rw.un_520 
  0x03094d07, 0x67495808, 0x58595508, 0x551d59ee,   // aa.pl.nl_432 om.to.ak_443  rw.rn.om_443 rn.la.rw_422 
  0x22464d04, 0x5a2852ad, 0x73005913, 0xfc001522,   // aa.qu.oc_332 ha.sw.sm_643  rn.ny.un_650 un.zzp.un_870 
  // [19b40]
  0x0500fc08, 0x685a64a4, 0x21283b0e, 0x07481555,   // zzp.fr.un_430 lg.sm.ig_433  ks.sd.fa_555 un.tt.bg_442 
  0x07233807, 0x216761a4, 0x243308a4, 0x73034607,   // tk.ky.bg_432 za.ak.jw_433  no.nn.eo_433 qu.nl.ny_432 
  0x0e2c3fee, 0x3308560c, 0x27360555, 0x13584daf,   // af.fy.is_422 mg.no.nn_543  fr.gn.gd_442 aa.om.et_655 
  0x5e00691b, 0x134b2c0e, 0x2d462e07, 0x2e20130c,   // mfe.ts.un_770 fy.mi.et_555  fo.qu.sk_432 et.sq.fo_543 
  // [19b50]
  0x3f004608, 0x252f1355, 0x332a25ad, 0x0438600b,   // qu.af.un_430 et.su.eu_442  eu.mt.nn_643 vo.tk.fi_542 
  0x2e0e1fa9, 0x46021504, 0x212344ee, 0x555d2ca0,   // cy.is.fo_544 un.da.qu_332  kk.ky.fa_422 fy.ss.rw_322 
  0x1508100d, 0x59001c08, 0x3c213407, 0x16001509,   // be.uk.un_554 id.rn.un_430  ps.fa.ug_432 un.hr.un_440 
  0x510b0a0d, 0x48000e0b, 0x19206408, 0x17150807,   // pt.es.kl_554 is.tt.un_520  lg.sq.gl_443 uk.sr.un_420 
  // [19b60]
  0x2d004b02, 0x302344ec, 0x09652aee, 0x100830a4,   // mi.sk.un_220 kk.ky.uz_644  mt.gv.pl_422 uz.uk.be_433 
  0x1a357904, 0x183d28a0, 0x0a5349ad, 0x232515ad,   // war.zu.tl_332 sd.ku.ar_322  to.ht.pt_643 un.mn.ky_643 
  0x044810a7, 0x2e650e07, 0x233e4504, 0x01000507,   // be.tt.ru_532 is.gv.fo_432  ln.rm.ca_332 fr.en.un_420 
  0x4c1d58ad, 0x1b38520d, 0x184c01ee, 0x1b39fc08,   // om.la.wo_643 ha.tk.tr_554  en.wo.ga_422 zzp.br.tr_443 
  // [19b70]
  0x221f30a4, 0x18000608, 0x1500181a, 0x3036350b,   // uz.cy.oc_433 de.ga.un_430  ga.un.un_760 tg.ab.uz_542 
  0x47000505, 0x4c4005ad, 0x33080c07, 0x302401a0,   // fr.sn.un_330 fr.lb.wo_643  sv.no.nn_432 en.eo.uz_322 
  0x31203011, 0x08151008, 0x4a000508, 0x520c1d07,   // uz.sq.az_653 be.uk.un_430  fr.yo.un_430 la.sv.ha_432 
  0x054a2f12, 0x32000612, 0x060413ad, 0x1e1c5d09,   // su.yo.fr_654 de.bs.un_640  et.fi.de_643 ss.id.ms_444 
  // [19b80]
  0x46586aaf, 0x23183c08, 0x5559685a, 0x11003708,   // haw.om.qu_655 ug.ar.ky_443  ig.rn.rw_553 st.ro.un_430 
  0x4a000509, 0x1a0256a9, 0x5d28730c, 0x28041304,   // fr.yo.un_440 mg.da.tl_544  ny.sw.ss_543 et.fi.sw_332 
  0x471304a4, 0x4c005719, 0x5a4d560e, 0x28464e0d,   // fi.et.sn_433 na.wo.un_750  mg.aa.sm_555 ay.qu.sw_554 
  0x126b1a08, 0x3b4c15ad, 0x783b28ad, 0x1c6b1e0c,   // tl.ceb.hu_443 un.wo.so_643  sw.so.ve_643 ms.ceb.id_543 
  // [19b90]
  0x655c0908, 0x47735612, 0x05532208, 0x104713a4,   // pl.sa.gv_443 mg.ny.sn_654  oc.ht.fr_443 et.sn.lt_433 
  0x40005e11, 0x23005313, 0x23530555, 0x213d2804,   // ts.lb.un_630 ht.ca.un_650  fr.ht.ca_442 sd.ku.fa_332 
  0x23440aee, 0x735022a0, 0x30005012, 0x305c1304,   // mk.kk.ky_422 oc.fj.ny_322  fj.uz.un_640 et.sa.uz_332 
  0x31002808, 0x21312da0, 0x3f204004, 0x47500fa4,   // sw.az.un_430 sk.az.jw_322  lb.sq.af_332 lv.fj.sn_433 
  // [19ba0]
  0x44003411, 0x29fe4807, 0x0c023e07, 0x2033fea0,   // ps.kk.un_630 tt.tlh.sl_432  rm.da.sv_432 tlh.nn.sq_322 
  0x043c150e, 0x300723ec, 0x52005509, 0x2d4a36a7,   // un.ug.ru_555 ky.bg.uz_644  rw.ha.un_440 gn.yo.sk_532 
  0x070408ac, 0x16102909, 0x1a5a7908, 0x7500231a,   // uk.ru.bg_632 sl.lt.hr_444  war.sm.tl_443 ca.nso.un_760 
  0x37080a02, 0x6b4001ee, 0x3422230c, 0x17370702,   // mk.uk.ba_222 en.lb.ceb_422  ca.oc.xh_543 bg.ba.sr_222 
  // [19bb0]
  0x0a6e0504, 0x380230ee, 0x3e270112, 0x0a00fe19,   // fr.hmn.pt_332 uz.da.tk_422  en.gd.rm_654 tlh.pt.un_750 
  0x30022404, 0x30002a13, 0x31000a19, 0x350534ad,   // eo.da.uz_332 mt.uz.un_650  pt.az.un_750 xh.fr.zu_643 
  0x340b1da4, 0x05540208, 0x2300fe22, 0x05230a04,   // la.es.xh_433 da.ik.fr_443  tlh.ca.un_870 pt.ca.fr_332 
  0x3f565309, 0x20005b1a, 0x23006518, 0x30100404,   // ht.mg.af_444 sg.sq.un_760  gv.ca.un_740 ru.be.uz_332 
  // [19bc0]
  0x053f40a0, 0x07481004, 0x103517a0, 0x1821235a,   // lb.af.fr_322 be.tt.bg_332  sr.tg.be_322 ky.fa.ar_553 
  0xfc652512, 0x1b180102, 0xfc6525a4, 0x0e6b1ba0,   // eu.gv.zzp_654 en.ga.tr_222  eu.gv.zzp_433 tr.ceb.is_322 
  0x0e2d0d5a, 0x12005d12, 0x342f3508, 0x0efc25ad,   // cs.sk.is_553 ss.hu.un_640  zu.su.xh_443 eu.zzp.is_643 
  0x083817ec, 0x36001809, 0x0a120d09, 0x202832a0,   // sr.tk.uk_644 ga.gn.un_440  cs.hu.pt_444 bs.sw.sq_322 
  // [19bd0]
  0x1f020fad, 0x190d1807, 0x20005b0c, 0x3028120d,   // lv.da.cy_643 ga.cs.gl_432  sg.sq.un_530 ur.sd.uz_554 
  0x04363704, 0x0e0c5302, 0x2b00181b, 0x34125ea0,   // ba.ab.ru_332 ht.sv.is_222  ga.vi.un_770 ts.hu.xh_322 
  0x5e00340e, 0x33301f0b, 0x34003f12, 0x33345e04,   // xh.ts.un_550 cy.uz.nn_542  af.xh.un_640 ts.xh.nn_332 
  0xfc4a4707, 0x2a000d05, 0x123448a0, 0x304c610c,   // sn.yo.zzp_432 cs.mt.un_330  tt.xh.hu_322 za.wo.uz_543 
  // [19be0]
  0x3435fe0c, 0x0c43fcad, 0xfc4658a0, 0x3c3430a7,   // tlh.zu.xh_543 zzp.ie.sv_643  om.qu.zzp_322 uz.ps.ug_532 
  0x2d0d3b0c, 0x364a4d55, 0x15006512, 0x217640ad,   // so.cs.sk_543 aa.yo.gn_442  gv.un.un_640 lb.crs.jw_643 
  0x1120220c, 0xfc000702, 0x24004d0c, 0x240c25a0,   // oc.sq.ro_543 it.zzp.un_220  aa.eo.un_530 eu.sv.eo_322 
  0x2a002f02, 0x3412fe04, 0x1a6452a7, 0x2a314d08,   // su.mt.un_220 tlh.hu.xh_332  ha.lg.tl_532 aa.az.mt_443 
  // [19bf0]
  0x6b007908, 0x48001502, 0x0d002e05, 0x081744a0,   // war.ceb.un_430 un.tt.un_220  fo.cs.un_330 kk.sr.uk_322 
  0x2f0d2da0, 0x3640050c, 0x06004d12, 0x21254608,   // sk.cs.su_322 fr.lb.gn_543  aa.de.un_640 qu.eu.jw_443 
  0x5700fc0e, 0x4b684712, 0x124a36ee, 0x0e121804,   // zzp.na.un_550 sn.ig.mi_654  gn.yo.hu_422 ga.hu.is_332 
  0x1c310205, 0x1b024d07, 0x251c1e07, 0x1b002402,   // da.az.id_333 aa.da.tr_432  ms.id.eu_432 eo.tr.un_220 
  
  // [19c00]
  0x1b00220d, 0x122d0d0c, 0x2e044c11, 0x526504a9,   // oc.tr.un_540 cs.sk.hu_543  wo.fi.fo_653 fi.gv.ha_544 
  0x253b6308, 0x3f53020c, 0x424a560c, 0x383b1b07,   // sco.so.eu_443 da.ht.af_543  mg.yo.co_543 tr.so.tk_432 
  0x1c4d1e04, 0x32462007, 0x4c4d47a9, 0x2a0302a4,   // ms.aa.id_332 sq.qu.bs_432  sn.aa.wo_544 da.nl.mt_433 
  0x3b00020c, 0x0d001212, 0x3b5463a4, 0x3b360204,   // da.so.un_530 hu.cs.un_640  sco.ik.so_433 da.gn.so_332 
  // [19c10]
  0x4a005208, 0x1b312012, 0x31462ea0, 0x2d1218af,   // ha.yo.un_430 sq.az.tr_654  fo.qu.az_322 ga.hu.sk_655 
  0x2f201b04, 0x522168a9, 0x220463a0, 0x18002e0e,   // tr.sq.su_332 ig.jw.ha_544  sco.fi.oc_322 fo.ga.un_550 
  0x17080aee, 0x04005c0c, 0x4d48505a, 0x29002d21,   // mk.uk.sr_422 sa.fi.un_530  fj.tt.aa_553 sk.sl.un_860 
  0x3b004609, 0x19001205, 0x08361255, 0x19000d09,   // qu.so.un_440 hu.gl.un_330  hu.gn.no_442 cs.gl.un_440 
  // [19c20]
  0x564e510d, 0x375d5614, 0x4e32fea4, 0x18342111,   // kl.ay.mg_554 mg.ss.st_666  tlh.bs.ay_433 fa.ps.ar_653 
  0x35527307, 0x48355f0c, 0x07374808, 0x555d47ad,   // ny.ha.zu_432 tn.zu.tt_543  tt.ba.bg_443 sn.ss.rw_643 
  0x22005c02, 0x155052a6, 0x27616511, 0x73483008,   // sa.oc.un_220 ha.fj.un_521  gv.za.gd_653 uz.tt.ny_443 
  0x6500050d, 0x5c4050a4, 0x070a44a0, 0x083312ee,   // fr.gv.un_540 fj.lb.sa_433  kk.mk.bg_322 hu.nn.no_422 
  // [19c30]
  0x1327180b, 0x18003702, 0x06650507, 0x22005008,   // ga.gd.et_542 st.ga.un_220  fr.gv.de_432 fj.oc.un_430 
  0x05002714, 0x375f730c, 0x305134ee, 0x3400300b,   // gd.fr.un_660 ny.tn.st_543  xh.kl.uz_422 uz.ps.un_520 
  0x5c000212, 0x07250407, 0x2105500c, 0x1d000d04,   // da.sa.un_640 ru.mn.bg_432  fj.fr.jw_543 cs.la.un_320 
  0x06525007, 0x153c3012, 0x0f630608, 0x29270507,   // fj.ha.de_432 uz.ug.un_654  de.sco.lv_443 fr.gd.sl_432 
  // [19c40]
  0x06020fad, 0x16000507, 0x2700651a, 0x16005c02,   // lv.da.de_643 fr.hr.un_420  gv.gd.un_760 sa.hr.un_220 
  0x48153708, 0x481025a6, 0x0b2e2da4, 0x1d472ba0,   // ba.tt.un_430 mn.be.tt_521  sk.fo.es_433 vi.sn.la_322 
  0x7800692b, 0x07001018, 0x20505faf, 0x496967af,   // mfe.ve.un_980 be.bg.un_740  tn.fj.sq_655 ak.mfe.to_655 
  0x40190a02, 0x245f01ee, 0x2e2d0d60, 0x534c01a4,   // pt.gl.lb_222 en.tn.eo_422  cs.sk.fo_664 en.wo.ht_433 
  // [19c50]
  0x041525ec, 0x53001d02, 0x694f0aa4, 0x44042302,   // mn.ru.un_640 la.ht.un_220  pt.bi.mfe_433 ky.ru.kk_222 
  0x07050108, 0x38785faf, 0x21341209, 0x182e0e09,   // en.fr.it_443 tn.ve.tk_655  ur.ps.fa_444 is.fo.ga_444 
  0x180e0d5a, 0x69005f0d, 0x2e0e0aec, 0x65205e11,   // cs.is.ga_553 tn.mfe.un_540  pt.is.fo_644 ts.sq.gv_653 
  0x122834af, 0x78674caf, 0x732847a9, 0x103744a0,   // ps.sd.ur_655 wo.ak.ve_655  sn.sw.ny_544 kk.ba.be_322 
  // [19c60]
  0x182e0a12, 0x15005114, 0x0e181912, 0x393e38ad,   // pt.fo.ga_654 kl.un.un_660  gl.ga.is_654 tk.rm.br_643 
  0x381b51a4, 0x5c006222, 0x0a4a0207, 0x330c0fa0,   // kl.tr.tk_433 kha.sa.un_870  da.yo.pt_432 lv.sv.nn_322 
  0x25485c04, 0x1d572604, 0x1c00fe08, 0x1100420d,   // sa.tt.eu_332 ia.na.la_332  tlh.id.un_430 co.ro.un_540 
  0x30383114, 0x63004505, 0x4000150b, 0x1b466b0c,   // az.tk.uz_666 ln.sco.un_330  un.lb.un_520 ceb.qu.tr_543 
  // [19c70]
  0x64003b0e, 0x6501380c, 0x3b00540d, 0x37443055,   // so.lg.un_550 tk.en.gv_543  ik.so.un_540 uz.kk.ba_442 
  0x2f00510e, 0x06403e10, 0x134d6455, 0x18512f5a,   // kl.su.un_550 rm.lb.de_642  lg.aa.et_442 su.kl.ga_553 
  0x686b15a7, 0x3500590c, 0xfe4620ad, 0x042f0207,   // un.ceb.ig_532 rn.zu.un_530  sq.qu.tlh_643 da.su.fi_432 
  0x0b051104, 0x4c45050c, 0x130c1da0, 0x0a021107,   // ro.fr.es_332 fr.ln.wo_543  la.sv.et_322 ro.da.pt_432 
  // [19c80]
  0x21005c11, 0x381548af, 0x0e0d2e0c, 0x11030604,   // sa.jw.un_630 tt.tk.un_650  fo.cs.is_543 de.nl.ro_332 
  0x31000102, 0x58644d07, 0x47003604, 0x0f6402a0,   // en.az.un_220 aa.lg.om_432  gn.sn.un_320 da.lg.lv_322 
  0x153308ee, 0x0d000612, 0x03066504, 0x3c343dee,   // no.nn.un_422 de.cs.un_640  gv.de.nl_332 ku.ps.ug_422 
  0x443637af, 0x2504230c, 0x072a1212, 0x35380811,   // ba.ab.kk_655 ky.ru.mn_543  hu.mt.it_654 uk.tk.tg_653 
  // [19c90]
  0x23044809, 0x03003e0c, 0x06003102, 0x0a3626a4,   // tt.ru.ky_444 rm.nl.un_530  az.de.un_220 ia.gn.pt_433 
  0x10442311, 0x2a004c21, 0x08003c21, 0x154206ad,   // ky.kk.be_653 wo.mt.un_860  ug.uk.un_860 de.co.un_643 
  0x0b2e190c, 0x0d002204, 0x180452a0, 0x400e060c,   // gl.fo.es_543 oc.cs.un_320  ha.fi.ga_322 de.is.lb_543 
  0x0d346007, 0x52656308, 0x27046304, 0x060902a0,   // vo.xh.cs_432 sco.gv.ha_443  sco.fi.gd_332 da.pl.de_322 
  // [19ca0]
  0x500c4da7, 0x4c2f210c, 0x35296ba0, 0x34633b04,   // aa.sv.fj_532 jw.su.wo_543  ceb.sl.zu_322 so.sco.xh_332 
  0x03110208, 0x0e006304, 0x2e0e3ea0, 0x633b0404,   // da.ro.nl_443 sco.is.un_320  rm.is.fo_322 fi.so.sco_332 
  0x18790908, 0x110522ee, 0x10040711, 0x4f34fc04,   // pl.war.ga_443 oc.fr.ro_422  bg.ru.be_653 zzp.xh.bi_332 
  0x15005502, 0x3d4421a7, 0x0815250c, 0x60001508,   // rw.un.un_220 fa.kk.ku_532  mn.uk.un_530 un.vo.un_430 
  // [19cb0]
  0x401006a4, 0x036b1dee, 0x21046504, 0x223924a4,   // de.lt.lb_433 la.ceb.nl_422  gv.fi.jw_332 eo.br.oc_433 
  0x6b634c04, 0x2a003b08, 0x170a1008, 0x3d3b2812,   // wo.sco.ceb_332 so.mt.un_430  be.mk.sr_443 sd.ks.ku_654 
  0x20006e0c, 0x12343b08, 0x02fc4aa7, 0x3b006723,   // hmn.sq.un_530 ks.ps.ur_443  yo.zzp.da_532 ak.so.un_880 
  0x0e0c5ca0, 0x23222107, 0x13212307, 0x13005302,   // sa.sv.is_322 jw.oc.ca_432  ca.jw.et_432 ht.et.un_220 
  // [19cc0]
  0x06793ea0, 0x0b1d01a0, 0x0a110804, 0x40120508,   // rm.war.de_322 en.la.es_322  uk.ro.mk_332 fr.hu.lb_443 
  0x4000051b, 0x12054008, 0x2d6957af, 0x4d00521a,   // fr.lb.un_770 lb.fr.hu_443  na.mfe.sk_655 ha.aa.un_760 
  0x5f3736a0, 0x56003f09, 0x4c4d6707, 0x36674aa4,   // gn.st.tn_322 af.mg.un_440  ak.aa.wo_432 yo.ak.gn_433 
  0x534969ad, 0x4a6a360c, 0x43064004, 0x3e2f3912,   // mfe.to.ht_643 gn.haw.yo_543  lb.de.ie_332 br.su.rm_654 
  // [19cd0]
  0x04060b05, 0x0a1d4202, 0x453b2e0d, 0x55640908,   // es.de.fi_333 co.la.pt_222  fo.so.ln_554 pl.lg.rw_443 
  0x43260da0, 0x0a1c2f08, 0x1d55590c, 0x4d00090c,   // cs.ia.ie_322 su.id.pt_443  rn.rw.la_543 pl.aa.un_530 
  0x0440050c, 0x1205400e, 0x401205af, 0x321752a0,   // fr.lb.fi_543 lb.fr.hu_555  fr.hu.lb_655 ha.sr.bs_322 
  0x1d2d2904, 0x17005008, 0x03fe020d, 0x06050105,   // sl.sk.la_332 fj.sr.un_430  da.tlh.nl_554 en.fr.de_333 
  // [19ce0]
  0x1f006e21, 0x073913ec, 0x32092907, 0x1f297905,   // hmn.cy.un_860 et.br.it_644  sl.pl.bs_432 war.sl.cy_333 
  0x03000f02, 0x6e003f04, 0x060c1f10, 0x1f007304,   // lv.nl.un_220 af.hmn.un_320  cy.sv.de_642 ny.cy.un_320 
  0x03122aa7, 0x45fc57a4, 0x37005104, 0x032a130c,   // mt.hu.nl_532 na.zzp.ln_433  kl.st.un_320 et.mt.nl_543 
  0x0c004202, 0x121e1da4, 0x27050411, 0x1f005d05,   // co.sv.un_220 la.ms.hu_433  fi.fr.gd_653 ss.cy.un_330 
  // [19cf0]
  0x36122fee, 0x6b560412, 0x081517a9, 0x47653002,   // su.hu.gn_422 fi.mg.ceb_654  sr.uk.un_540 uz.gv.sn_222 
  0x211812a6, 0xfe6b0402, 0x465604a7, 0x1c005607,   // ur.ar.fa_521 fi.ceb.tlh_222  fi.mg.qu_532 mg.id.un_420 
  0x070810ee, 0x0e00360c, 0x362515a9, 0x342024a0,   // be.uk.bg_422 gn.is.un_530  un.mn.ab_544 eo.sq.xh_322 
  0x3c3d2304, 0x27250407, 0x56656207, 0x35040aec,   // ky.ku.ug_332 fi.eu.gd_432  kha.gv.mg_432 mk.ru.tg_644 
  // [19d00]
  0x6945050c, 0x38314809, 0x1d071304, 0x2e181f07,   // fr.ln.mfe_543 tt.az.tk_444  et.it.la_332 cy.ga.fo_432 
  0x1506fcee, 0x2e0e2409, 0x060e3fa0, 0x012d15a4,   // zzp.de.un_422 eo.is.fo_444  af.is.de_322 un.sk.en_433 
  0x6b002805, 0x2e150e04, 0x421e1c0d, 0x12362d04,   // sw.ceb.un_330 is.fo.un_320  id.ms.co_554 sk.gn.hu_332 
  0x391546a0, 0x29090f0e, 0x2e1ffc04, 0x482d0d0c,   // qu.br.un_320 lv.pl.sl_555  zzp.cy.fo_332 cs.sk.tt_543 
  // [19d10]
  0x04345e12, 0x13fe61a9, 0x2e0e34a4, 0x52305e08,   // ts.xh.fi_654 za.tlh.et_544  xh.is.fo_433 ts.uz.ha_443 
  0x1d393e08, 0x3e353413, 0x516502ad, 0x02381fa4,   // rm.br.la_443 xh.zu.rm_665  da.gv.kl_643 cy.tk.da_433 
  0xfe5d3404, 0x2a302813, 0x2a3420a7, 0x11000d0d,   // xh.ss.tlh_332 sw.uz.mt_665  sq.xh.mt_532 cs.ro.un_540 
  0x1b5f02a7, 0x34001e07, 0x0b005e02, 0x4d002e20,   // da.tn.tr_532 ms.xh.un_420  ts.es.un_220 fo.aa.un_850 
  // [19d20]
  0x5c150305, 0x1f1b3005, 0xfe1f0414, 0x5a505804,   // nl.sa.un_330 uz.tr.cy_333  fi.cy.tlh_666 om.fj.sm_332 
  0x5e000d08, 0x182e2dec, 0x52005c0c, 0x0e001819,   // cs.ts.un_430 sk.fo.ga_644  sa.ha.un_530 ga.is.un_750 
  0x0e00380c, 0x12303d12, 0x0d00360b, 0x072348a0,   // tk.is.un_530 ku.uz.ur_654  gn.cs.un_520 tt.ky.bg_322 
  0x233c370c, 0x352536a7, 0x36464e13, 0x38000714,   // ba.ug.ky_543 ab.mn.tg_532  ay.qu.gn_665 bg.tk.un_660 
  // [19d30]
  0x071510a4, 0x38311bad, 0x483738ee, 0x36001204,   // be.bg.un_430 tr.az.tk_643  tk.ba.tt_422 hu.gn.un_320 
  0x4200510c, 0x600c13a4, 0x3e280755, 0x0910780d,   // kl.co.un_530 et.sv.vo_433  it.sw.rm_442 ve.lt.pl_554 
  0x111d5dad, 0x3c071108, 0x630b1da4, 0x2d0d18ee,   // ss.la.ro_643 ro.bg.ug_443  la.es.sco_433 ga.cs.sk_422 
  0x59111d07, 0x1d110508, 0x465055a0, 0x42003b0b,   // la.ro.rn_432 fr.ro.la_443  rw.fj.qu_322 so.co.un_520 
  // [19d40]
  0x104825a9, 0x0742260b, 0x11021d04, 0x55361da4,   // mn.tt.be_544 ia.co.it_542  la.da.ro_332 la.gn.rw_433 
  0x1861130c, 0x2022070c, 0x12180d09, 0x551135ee,   // et.za.ga_543 it.oc.sq_543  cs.ga.hu_444 zu.ro.rw_422 
  0x2f001c0d, 0x687965ec, 0x0a201b12, 0x36211d07,   // id.su.un_540 gv.war.ig_644  tr.sq.pt_654 la.jw.gn_432 
  0x3b1030a4, 0x4342260d, 0x050f100c, 0x2500020c,   // uz.lt.so_433 ia.co.ie_554  lt.lv.fr_543 da.eu.un_530 
  // [19d50]
  0x6523180b, 0x611a02a9, 0x18275a12, 0x11421d08,   // ga.ca.gv_542 da.tl.za_544  sm.gd.ga_654 la.co.ro_443 
  0x1c3308a6, 0x161029a4, 0x68162507, 0x1b3848ad,   // no.nn.id_521 sl.lt.hr_433  eu.hr.ig_432 tt.tk.tr_643 
  0x0200470d, 0x31105907, 0xfe192307, 0x05232209,   // sn.da.un_540 rn.lt.az_432  ca.gl.tlh_432 oc.ca.fr_444 
  0x471363a0, 0x021827a4, 0x5a0f47ee, 0x472850a4,   // sco.et.sn_322 gd.ga.da_433  sn.lv.sm_422 fj.sw.sn_433 
  // [19d60]
  0x1810270c, 0x5a1827af, 0x50001705, 0x0d001218,   // gd.lt.ga_543 gd.ga.sm_655  sr.fj.un_330 hu.cs.un_740 
  0x330f1002, 0x4600650d, 0x33390807, 0x53003907,   // lt.lv.nn_222 gv.qu.un_540  no.br.nn_432 br.ht.un_420 
  0x65000409, 0x08044804, 0x253511ac, 0x4000180d,   // fi.gv.un_440 tt.ru.uk_332  ro.tg.mn_632 ga.lb.un_540 
  0x20006233, 0x5a2c3755, 0x39181f07, 0x2865630c,   // kha.sq.un_A70 st.fy.sm_442  cy.ga.br_432 sco.gv.sw_543 
  // [19d70]
  0x3f005304, 0x655867ad, 0x2d0901a0, 0x78693708,   // ht.af.un_320 ak.om.gv_643  en.pl.sk_322 st.mfe.ve_443 
  0x4c635208, 0x18001f08, 0x0f005219, 0x1b213702,   // ha.sco.wo_443 cy.ga.un_430  ha.lv.un_750 st.jw.tr_222 
  0x52671da4, 0x426a4711, 0x655c47ad, 0x4c785209,   // la.ak.ha_433 sn.haw.co_653  sn.sa.gv_643 ha.ve.wo_444 
  0x4b1b5a09, 0x0e2e4c0c, 0x180e3604, 0x522920a0,   // sm.tr.mi_444 wo.fo.is_543  gn.is.ga_332 sq.sl.ha_322 
  // [19d80]
  0x29462004, 0x3b042007, 0x6352650d, 0x042e63a4,   // sq.qu.sl_332 sq.fi.so_432  gv.ha.sco_554 sco.fo.fi_433 
  0x13005309, 0x48303714, 0x0e462eaf, 0x2a202902,   // ht.et.un_440 ba.uz.tt_666  fo.qu.is_655 sl.sq.mt_222 
  0x2d0d2a0e, 0x3b046307, 0x0e153e08, 0x58006308,   // mt.cs.sk_555 sco.fi.so_432  rm.is.un_430 sco.om.un_430 
  0x3b00462a, 0x04634609, 0x2a202ea0, 0x2cfc0f07,   // qu.so.un_970 qu.sco.fi_444  fo.sq.mt_322 lv.zzp.fy_432 
  // [19d90]
  0x4b1839a4, 0x0e5263ad, 0x491c1ea9, 0x0e63525a,   // br.ga.mi_433 sco.ha.is_643  ms.id.to_544 ha.sco.is_553 
  0x381e60ec, 0x0e204660, 0x755f37a9, 0x522e08a4,   // vo.ms.tk_644 qu.sq.is_664  st.tn.nso_544 no.fo.ha_433 
  0x600f2fa9, 0x2a0d3b07, 0x1716580c, 0x25672909,   // su.lv.vo_544 so.cs.mt_432  om.hr.sr_543 sl.ak.eu_444 
  0x65493e07, 0x1c214607, 0x253b3808, 0x072548a4,   // rm.to.gv_432 qu.jw.id_432  tk.so.eu_443 tt.mn.bg_433 
  // [19da0]
  0x01222aa7, 0x29004d21, 0x08005218, 0x40602507,   // mt.oc.en_532 aa.sl.un_860  ha.no.un_740 eu.vo.lb_432 
  0x0d002e04, 0x2f21fa07, 0x21001d09, 0x040f1012,   // fo.cs.un_320 nr.jw.su_432  la.jw.un_440 lt.lv.fi_654 
  0x172310a4, 0x234418a9, 0x2e0208a9, 0x634006af,   // be.ky.sr_433 ar.kk.ky_544  no.da.fo_544 de.lb.sco_655 
  0x17350405, 0x381b1807, 0x0c130404, 0x11736408,   // ru.tg.sr_333 ga.tr.tk_432  fi.et.sv_332 lg.ny.ro_443 
  // [19db0]
  0x261d11a4, 0x5f3775a9, 0x061c21ee, 0x523b11a4,   // ro.la.ia_433 nso.st.tn_544  jw.id.de_422 ro.so.ha_433 
  0x312d4802, 0x155f0111, 0x1942fc05, 0x36253812,   // tt.sk.az_222 en.tn.un_653  zzp.co.gl_333 tk.mn.ab_654 
  0x33086204, 0x47052707, 0x32301602, 0x641155a4,   // kha.no.nn_332 gd.fr.sn_432  hr.uz.bs_222 rw.ro.lg_433 
  0x0e192e02, 0x2f581105, 0x313029a0, 0x256457a4,   // fo.gl.is_222 ro.om.su_333  sl.uz.az_322 na.lg.eu_433 
  // [19dc0]
  0x111b60a4, 0x755f0107, 0x1c791a07, 0x34330804,   // vo.tr.ro_433 en.tn.nso_432  tl.war.id_432 no.nn.xh_332 
  0x1110010c, 0x536b79ee, 0x34002009, 0x313016ee,   // en.lt.ro_543 war.ceb.ht_422  sq.xh.un_440 hr.uz.az_422 
  0x3148fea7, 0x6bfe6e0d, 0x09006e34, 0xfe006e0e,   // tlh.tt.az_532 hmn.tlh.ceb_554  hmn.pl.un_A80 hmn.tlh.un_550 
  0x350715a0, 0x3f40fca0, 0x2f036e0e, 0x4c000602,   // un.bg.tg_322 zzp.lb.af_322  hmn.nl.su_555 de.wo.un_220 
  // [19dd0]
  0x50001e04, 0x0d6e600c, 0x072d42a7, 0x1d002305,   // ms.fj.un_320 vo.hmn.cs_543  co.sk.it_532 ca.la.un_330 
  0x294c4da9, 0x572206af, 0x043c30af, 0x64245504,   // aa.wo.sl_544 de.oc.na_655  uz.ug.ru_655 rw.eo.lg_332 
  0x21422204, 0x06585712, 0x016e6309, 0x11000611,   // oc.co.jw_332 na.om.de_654  sco.hmn.en_444 de.ro.un_630 
  0x6b005309, 0x05156ead, 0x37443caf, 0x02002a19,   // ht.ceb.un_440 hmn.fr.un_630  ug.kk.ba_655 mt.da.un_750 
  // [19de0]
  0xfe2a0209, 0x3f4a3ba9, 0x0c45180c, 0x3b0458af,   // da.mt.tlh_444 so.yo.af_544  ga.ln.sv_543 om.fi.so_655 
  0x63016ea9, 0x4d4c58a9, 0x1f023ba9, 0x3b0458ad,   // hmn.en.sco_544 om.wo.aa_544  so.da.cy_544 om.fi.so_643 
  0x4a001a05, 0x1825fc0b, 0x69190b08, 0x04583bec,   // tl.yo.un_330 zzp.eu.ga_542  es.gl.mfe_443 so.om.fi_644 
  0x02521fec, 0x0e00061a, 0x553537a0, 0x043b5855,   // cy.ha.da_644 de.is.un_760  st.zu.rw_322 om.so.fi_442 
  // [19df0]
  0x6b4d7911, 0x4a4c58ad, 0x043b5804, 0x04583ba4,   // war.aa.ceb_653 om.wo.yo_643  om.so.fi_332 so.om.fi_433 
  0x633f2208, 0xfe6130a4, 0x79004a22, 0x25006913,   // oc.af.sco_443 uz.za.tlh_433  yo.war.un_870 mfe.eu.un_650 
  0x4c583bec, 0x1b006b0c, 0x583b4ca7, 0x31fe2a55,   // so.om.wo_644 ceb.tr.un_530  wo.so.om_532 mt.tlh.az_442 
  0x2e2d0e05, 0x3d342808, 0x581a4cec, 0x4d045812,   // is.sk.fo_333 sd.ps.ku_443  wo.tl.om_644 om.fi.aa_654 
  // [19e00]
  0x1a04580c, 0x4c58040c, 0x3c001819, 0x58000408,   // om.fi.tl_543 fi.om.wo_543  ar.ug.un_750 fi.om.un_430 
  0x522d0907, 0x5a503407, 0x37150412, 0x3b00350d,   // pl.sk.ha_432 xh.fj.sm_432  ru.ba.un_640 zu.so.un_540 
  0x35341daf, 0x04073604, 0x1a595560, 0x64553607,   // la.xh.zu_655 ab.bg.ru_332  rw.rn.tl_664 gn.rw.lg_432 
  0xfc640655, 0x7955590c, 0x2a481f0c, 0x361245ad,   // de.lg.zzp_442 rn.rw.war_543  cy.tt.mt_543 ln.hu.gn_643 
  // [19e10]
  0x63330808, 0x68006422, 0x0704110b, 0x5efc6407,   // no.nn.sco_443 lg.ig.un_870  ro.ru.bg_542 lg.zzp.ts_432 
  0x20002a07, 0x100730b2, 0x42201f0c, 0x302128a4,   // mt.sq.un_420 uz.bg.be_732  cy.sq.co_543 sd.fa.uz_433 
  0x24064fa4, 0x4055fc0c, 0x08351705, 0x0200521b,   // bi.de.eo_433 zzp.rw.lb_543  sr.tg.uk_333 ha.da.un_770 
  0x3c48370d, 0x5a100207, 0x0d5c13a9, 0x4500022b,   // ba.tt.ug_554 da.lt.sm_432  bh.sa.ne_544 da.ln.un_980 
  // [19e20]
  0x3c0708a4, 0x2a0f095a, 0x69100faf, 0x5a685604,   // uk.bg.ug_433 pl.lv.mt_553  lv.lt.mfe_655 mg.ig.sm_332 
  0x38003622, 0x060e2e07, 0x10000213, 0x32164002,   // ab.tk.un_870 fo.is.de_432  da.lt.un_650 lb.hr.bs_222 
  0x02453411, 0x1c2f040b, 0x3e070204, 0x39004004,   // xh.ln.da_653 fi.su.id_542  da.it.rm_332 lb.br.un_320 
  0x034f3fa0, 0x481b7304, 0x12183ca0, 0x3021020c,   // af.bi.nl_322 ny.tr.tt_332  ug.ar.ur_322 da.jw.uz_543 
  // [19e30]
  0x595528af, 0x190a05ec, 0x35005309, 0x02005e23,   // sw.rw.rn_655 fr.pt.gl_644  ht.zu.un_440 ts.da.un_880 
  0x56070fa9, 0x5c7602a4, 0x50286405, 0x65003f0d,   // lv.it.mg_544 da.crs.sa_433  lg.sw.fj_333 af.gv.un_540 
  0x2f634307, 0x17111507, 0x073015ee, 0x095601a4,   // ie.sco.su_432 un.ro.sr_432  un.uz.bg_422 en.mg.pl_433 
  0x6a025608, 0x12005611, 0x56090dec, 0x12560902,   // mg.da.haw_443 mg.hu.un_630  cs.pl.mg_644 pl.mg.hu_222 
  // [19e40]
  0x40004a07, 0x540c3307, 0x65000913, 0x564c400c,   // yo.lb.un_420 nn.sv.ik_432  pl.gv.un_650 lb.wo.mg_543 
  0x2f333e11, 0xfe303ba4, 0x48381b08, 0x2858330c,   // rm.nn.su_653 so.uz.tlh_433  tr.tk.tt_443 nn.om.sw_543 
  0x63001e08, 0x43005612, 0x520e58ee, 0x286e02a0,   // ms.sco.un_430 mg.ie.un_640  om.is.ha_422 da.hmn.sw_322 
  0x3311fe04, 0x48383514, 0x33240e0c, 0x2f4773ee,   // tlh.ro.nn_332 tg.tk.tt_666  is.eo.nn_543 ny.sn.su_422 
  // [19e50]
  0x371548a4, 0xfe00580e, 0x47006e0d, 0x57000d04,   // tt.ba.un_430 om.tlh.un_550  hmn.sn.un_540 cs.na.un_320 
  0x65033f07, 0x4d67fea9, 0x73345d0d, 0x10003612,   // af.nl.gv_432 tlh.ak.aa_544  ss.xh.ny_554 ab.be.un_640 
  0x28493ba0, 0x024afe0c, 0x1f276513, 0x211e29ee,   // so.to.sw_322 tlh.yo.da_543  gv.gd.cy_665 sl.ms.jw_422 
  0x2924fe0c, 0x3b00fe19, 0x341827af, 0x65061f08,   // tlh.eo.sl_543 tlh.so.un_750  gd.ga.xh_655 cy.de.gv_443 
  // [19e60]
  0x5a3424a0, 0x24023b05, 0x07002d1a, 0x5c004e0c,   // eo.xh.sm_322 so.da.eo_333  sk.it.un_760 ay.sa.un_530 
  0x0f2d39a0, 0x271f185a, 0x1ffe100c, 0x464a4907,   // br.sk.lv_322 ga.cy.gd_553  lt.tlh.cy_543 to.yo.qu_432 
  0x3b105c07, 0x3b00fe20, 0x3e424d0b, 0x190a05a7,   // sa.lt.so_432 tlh.so.un_850  aa.co.rm_542 fr.pt.gl_532 
  0x420a0504, 0x1a001812, 0x1f041aad, 0x583b20af,   // fr.pt.co_332 ga.tl.un_640  tl.fi.cy_643 sq.so.om_655 
  // [19e70]
  0x63186507, 0x343b3dad, 0x2001635a, 0x5400021a,   // gv.ga.sco_432 ku.ks.ps_643  sco.en.sq_553 da.ik.un_760 
  0x315206a4, 0x6320520d, 0x40004608, 0x2335370c,   // de.ha.az_433 ha.sq.sco_554  qu.lb.un_430 ba.tg.ky_543 
  0x384804a0, 0xfa34350c, 0x624c4605, 0x3d3b2104,   // fi.tt.tk_322 zu.xh.nr_543  qu.wo.kha_333 fa.ks.ku_332 
  0x072afcee, 0x1f6539ad, 0x15001d07, 0x180b43a9,   // zzp.mt.it_422 br.gv.cy_643  la.un.un_420 ie.es.ga_544 
  // [19e80]
  0x3000100d, 0x18564807, 0x3f342aa7, 0x400669a4,   // be.uz.un_540 tt.mg.ga_432  mt.xh.af_532 mfe.de.lb_433 
  0x4006610d, 0x2a3327a0, 0x15000719, 0x405606a0,   // za.de.lb_554 gd.nn.mt_322  bg.un.un_750 de.mg.lb_322 
  0x2e002405, 0x0c001e05, 0x39400607, 0x681801a0,   // eo.fo.un_330 ms.sv.un_330  de.lb.br_432 en.ga.ig_322 
  0x32001f04, 0x330809ee, 0x3e2a0607, 0x1100101b,   // cy.bs.un_320 pl.no.nn_422  de.mt.rm_432 be.ro.un_770 
  // [19e90]
  0x21066007, 0x06696108, 0x653e3fa4, 0x63006214,   // vo.de.jw_432 za.mfe.de_443  af.rm.gv_433 kha.sco.un_660 
  0x33060804, 0x483130a9, 0x490c0255, 0x30483105,   // no.de.nn_332 uz.az.tt_544  da.sv.to_442 az.tt.uz_333 
  0x17162eee, 0x342812ad, 0x190a36a0, 0x530269ad,   // fo.hr.sr_422 ur.sd.ps_643  gn.pt.gl_322 mfe.da.ht_643 
  0x12060ca0, 0x344a73a7, 0x3400fe19, 0x1d353402,   // sv.de.hu_322 ny.yo.xh_532  tlh.xh.un_750 xh.zu.la_222 
  // [19ea0]
  0x2c1d03ee, 0x101dfc0c, 0x12282114, 0x384830af,   // nl.la.fy_422 zzp.la.lt_543  fa.sd.ur_666 uz.tt.tk_655 
  0x4f3b2e60, 0x3c001212, 0x2e6352ad, 0x0d5d2dec,   // fo.so.bi_664 ur.ug.un_640  ha.sco.fo_643 sk.ss.cs_644 
  0x5e006508, 0x63520413, 0x795c4da4, 0x25562e08,   // gv.ts.un_430 fi.ha.sco_665  aa.sa.war_433 fo.mg.eu_443 
  0xfc344d07, 0x0200630d, 0x2e5263a9, 0x3b52fe07,   // aa.xh.zzp_432 sco.da.un_540  sco.ha.fo_544 tlh.ha.so_432 
  // [19eb0]
  0xfc002e13, 0x0d022f0d, 0x32000209, 0x6300251a,   // fo.zzp.un_650 su.da.cs_554  da.bs.un_440 eu.sco.un_760 
  0x04006314, 0x7345fe08, 0x304852a0, 0x4c2e4202,   // sco.fi.un_660 tlh.ln.ny_443  ha.tt.uz_322 co.fo.wo_222 
  0x2f391007, 0x0a173007, 0x171015ee, 0x305e48ad,   // lt.br.su_432 uz.sr.mk_432  un.be.sr_422 tt.ts.uz_643 
  0x015204a0, 0x184701a0, 0x04635208, 0x020742a4,   // fi.ha.en_322 en.sn.ga_322  ha.sco.fi_443 co.it.da_433 
  // [19ec0]
  0x0746010b, 0x5e0b780e, 0x304654ec, 0x65fe19a4,   // en.qu.it_542 ve.es.ts_555  ik.qu.uz_644 gl.tlh.gv_433 
  0x3530360b, 0x5500fe05, 0x115401a0, 0x2e4a0e55,   // ab.uz.tg_542 tlh.rw.un_330  en.ik.ro_322 is.yo.fo_442 
  0x04353604, 0x041f09a6, 0x33000e05, 0x3c2330ad,   // ab.tg.ru_332 pl.cy.fi_521  is.nn.un_330 uz.ky.ug_643 
  0x07080a0e, 0x33341faf, 0x37075f0c, 0x12544aa4,   // mk.uk.bg_555 cy.xh.nn_655  tn.it.st_543 yo.ik.hu_433 
  // [19ed0]
  0x1724fe12, 0x2d0d6ba9, 0x054645a0, 0x0844100c,   // tlh.eo.sr_654 ceb.cs.sk_544  ln.qu.fr_322 be.kk.uk_543 
  0x0b24020c, 0x1f6b4d0c, 0x532469ee, 0x5f372da4,   // da.eo.es_543 aa.ceb.cy_543  mfe.eo.ht_422 sk.st.tn_433 
  0x24647305, 0x0b000723, 0xfc004d04, 0x042315a0,   // ny.lg.eo_333 it.es.un_880  aa.zzp.un_320 un.ky.ru_322 
  0x153523a9, 0x1100fc07, 0x1c3b0d55, 0x4709550c,   // ky.tg.un_544 zzp.ro.un_420  ne.ks.mr_442 rw.pl.sn_543 
  // [19ee0]
  0x36001b0c, 0x655c550c, 0x3918050c, 0x55005304,   // tr.gn.un_530 rw.sa.gv_543  fr.ga.br_543 ht.rw.un_320 
  0x300717ee, 0x762901a4, 0x290c1d08, 0x333908a0,   // sr.bg.uz_422 en.sl.crs_433  la.sv.sl_443 no.br.nn_322 
  0x21192f04, 0x31023608, 0x06016307, 0x35572d07,   // su.gl.jw_332 gn.da.az_443  sco.en.de_432 sk.na.zu_432 
  0x78453008, 0x5300620e, 0x382029a4, 0x5145200c,   // uz.ln.ve_443 kha.ht.un_550  sl.sq.tk_433 sq.ln.kl_543 
  // [19ef0]
  0x201d2dee, 0x20305eaf, 0x5e003105, 0x5e201d12,   // sk.la.sq_422 ts.uz.sq_655  az.ts.un_330 la.sq.ts_654 
  0x201029a4, 0x0a390705, 0x48233c0e, 0x48374409,   // sl.lt.sq_433 it.br.pt_333  ug.ky.tt_555 kk.ba.tt_444 
  0x21301808, 0x0e004d0d, 0x07fe0504, 0x26231dad,   // ar.uz.fa_443 aa.is.un_540  fr.tlh.it_332 la.ca.ia_643 
  0x0a00fe08, 0x1d4005a4, 0x39000404, 0x0d562daf,   // tlh.pt.un_430 fr.lb.la_433  fi.br.un_320 sk.mg.cs_655 
  // [19f00]
  0x313430a7, 0x09560da4, 0x0b00230e, 0x0b0a510c,   // uz.xh.az_532 cs.mg.pl_433  ca.es.un_550 kl.pt.es_543 
  0x562d0d14, 0x2a006807, 0x37000a09, 0x560d2d11,   // cs.sk.mg_666 ig.mt.un_420  mk.ba.un_440 sk.cs.mg_653 
  0x25104808, 0x3b213012, 0x255d36a0, 0x21006b07,   // tt.be.mn_443 uz.fa.ks_654  gn.ss.eu_322 ceb.jw.un_420 
  0x64614c0c, 0x753758ec, 0x2318120c, 0x79683b0c,   // wo.za.lg_543 om.st.nso_644  ur.ar.ky_543 so.ig.war_543 
  // [19f10]
  0x224301a0, 0x39004507, 0x584c4005, 0x67583bad,   // en.ie.oc_322 ln.br.un_420  lb.wo.om_333 so.om.ak_643 
  0x4c4d3b0c, 0x30352360, 0xfc651808, 0x4d000214,   // so.aa.wo_543 ky.tg.uz_664  ga.gv.zzp_443 da.aa.un_660 
  0x04110855, 0x182d0d5a, 0x3b4c5808, 0x4d6e4ca4,   // uk.ro.ru_442 cs.sk.ga_553  om.wo.so_443 wo.hmn.aa_433 
  0x13500407, 0x02674c5a, 0x450a0dee, 0x1a6701a0,   // fi.fj.et_432 wo.ak.da_553  cs.pt.ln_422 en.ak.tl_322 
  // [19f20]
  0x4c6558ad, 0x4d4c3ba9, 0x49044ca4, 0x4d584caf,   // om.gv.wo_643 so.wo.aa_544  wo.fi.to_433 wo.om.aa_655 
  0x0a000e0d, 0x081723a0, 0x322e2a07, 0x2a52020b,   // is.pt.un_540 ky.sr.uk_322  mt.fo.bs_432 da.ha.mt_542 
  0x2a00582a, 0x04383ba0, 0x2a002c08, 0x52002e05,   // om.mt.un_970 so.tk.fi_322  fy.mt.un_430 fo.ha.un_330 
  0x20003202, 0x033f1b0c, 0x22651dad, 0x2f3b4b0c,   // bs.sq.un_220 tr.af.nl_543  la.gv.oc_643 mi.so.su_543 
  // [19f30]
  0x2a043912, 0x10002f14, 0x2f381b0c, 0x0f1101a0,   // br.fi.mt_654 su.lt.un_660  tr.tk.su_543 en.ro.lv_322 
  0x240dfea9, 0x0c002c14, 0xfe4e460c, 0x190afca0,   // tlh.cs.eo_544 fy.sv.un_660  qu.ay.tlh_543 zzp.pt.gl_322 
  0x4733340c, 0x5d003404, 0x0100fc08, 0x3534fea0,   // xh.nn.sn_543 xh.ss.un_320  zzp.en.un_430 tlh.xh.zu_322 
  0x625801a4, 0x1b322cec, 0x5e631f07, 0x651118ee,   // en.om.kha_433 fy.bs.tr_644  cy.sco.ts_432 ga.ro.gv_422 
  // [19f40]
  0x524f3b0c, 0x1e5225a4, 0x46023009, 0x3b2c63ee,   // so.bi.ha_543 eu.ha.ms_433  uz.da.qu_444 sco.fy.so_422 
  0x255819a0, 0x1b34380c, 0x47550208, 0x4e460107,   // gl.om.eu_322 tk.xh.tr_543  da.rw.sn_443 en.qu.ay_432 
  0x46003021, 0x2cfa3460, 0x351ffe04, 0x121e1c0d,   // uz.qu.un_860 xh.nr.fy_664  tlh.cy.zu_332 id.ms.hu_554 
  0x292d0da9, 0x3e2107ee, 0x17532902, 0x111d26a6,   // cs.sk.sl_544 it.jw.rm_422  sl.ht.sr_222 ia.la.ro_521 
  // [19f50]
  0x4800311b, 0x330e02ee, 0x0817250b, 0x0e003812,   // az.tt.un_770 da.is.nn_422  mn.sr.uk_542 tk.is.un_640 
  0x20311ba9, 0x07080aa0, 0x08110404, 0x122348a7,   // tr.az.sq_544 mk.uk.bg_322  ru.ro.uk_332 tt.ca.hu_532 
  0x04002512, 0x0f005c21, 0x2f004c13, 0x2f2205ac,   // mn.ru.un_640 sa.lv.un_860  wo.su.un_650 fr.oc.su_632 
  0x730449af, 0x2f4c05a0, 0x0dfe5507, 0x0a07360c,   // to.fi.ny_655 fr.wo.su_322  rw.tlh.cs_432 ab.bg.mk_543 
  // [19f60]
  0x202322a0, 0x05002f05, 0x03002302, 0x052f4a0c,   // oc.ca.sq_322 su.fr.un_330  ca.nl.un_220 yo.su.fr_543 
  0x6435550c, 0x4a4c2f07, 0x30213405, 0x276502ad,   // rw.zu.lg_543 su.wo.yo_432  ps.fa.uz_333 da.gv.gd_643 
  0x65001020, 0x130240a4, 0x051001a4, 0x0e362e12,   // lt.gv.un_850 lb.da.et_433  en.lt.fr_433 fo.gn.is_654 
  0x30462012, 0x06650f0c, 0x33572708, 0x3e495707,   // sq.qu.uz_654 lv.gv.de_543  gd.na.nn_443 na.to.rm_432 
  // [19f70]
  0x3b21440c, 0x01633e0c, 0x3600450d, 0x531240a0,   // kk.fa.ks_543 rm.sco.en_543  ln.gn.un_540 lb.hu.ht_322 
  0x182d0da0, 0x05632705, 0x220a01a0, 0x2e00100b,   // cs.sk.ga_322 gd.sco.fr_333  en.pt.oc_322 lt.fo.un_520 
  0x182e2bee, 0x39003807, 0x39003808, 0x33022e0c,   // vi.fo.ga_422 tk.br.un_420  tk.br.un_430 fo.da.nn_543 
  0x1d4346a4, 0x6700652a, 0x3721490c, 0x062420af,   // qu.ie.la_433 gv.ak.un_970  to.jw.st_543 sq.eo.de_655 
  // [19f80]
  0x23003b0e, 0x6538690c, 0x53003905, 0x213d300b,   // ks.ky.un_550 mfe.tk.gv_543  br.ht.un_330 uz.ku.fa_542 
  0x2d172913, 0x1b4021ec, 0x3b000712, 0x794d02af,   // sl.sr.sk_665 jw.lb.tr_644  it.so.un_640 da.aa.war_655 
  0x4c192004, 0x697921a4, 0x154823ad, 0x32242908,   // sq.gl.wo_332 jw.war.mfe_433  ky.tt.un_643 sl.eo.bs_443 
  0x674d38a4, 0x10295fa9, 0x2600070d, 0x2013425a,   // tk.aa.ak_433 tn.sl.lt_544  it.ia.un_540 co.et.sq_553 
  // [19f90]
  0x373f4b07, 0x494d5bec, 0x2c002304, 0x101f3b5a,   // mi.af.st_432 sg.aa.to_644  ca.fy.un_320 so.cy.lt_553 
  0x154810a7, 0x180d2d1e, 0x393035a0, 0x2344210c,   // be.tt.un_532 sk.cs.ga_863  zu.uz.br_322 fa.kk.ky_543 
  0x1e651004, 0x3b4e30a4, 0x092c3f09, 0x1c004d07,   // lt.gv.ms_332 uz.ay.so_433  af.fy.pl_444 aa.id.un_420 
  0x1b002404, 0x330c38a7, 0x3f3662a9, 0x0748380e,   // eo.tr.un_320 tk.sv.nn_532  kha.gn.af_544 tk.tt.bg_555 
  // [19fa0]
  0x022d0d0b, 0x304e4811, 0x04171007, 0x28123da4,   // cs.sk.da_542 tt.ay.uz_653  be.sr.ru_432 ku.ur.sd_433 
  0x5d003507, 0x0e00fc09, 0x5e000108, 0x1f001108,   // zu.ss.un_420 zzp.is.un_440  en.ts.un_430 ro.cy.un_430 
  0x1234215a, 0x24190ba7, 0x23303d08, 0x2c0302a7,   // fa.ps.ur_553 es.gl.eo_532  ku.uz.ky_443 da.nl.fy_532 
  0x0c041304, 0x364205a0, 0x301725a0, 0x06391fa0,   // et.fi.sv_332 fr.co.gn_322  mn.sr.uz_322 cy.br.de_322 
  // [19fb0]
  0x33000108, 0x562201a4, 0x330818af, 0x04080aee,   // en.nn.un_430 en.oc.mg_433  ga.no.nn_655 mk.uk.ru_422 
  0x01651f02, 0x06401f07, 0x401565a4, 0x495a4ba4,   // cy.gv.en_222 cy.lb.de_432  gv.lb.un_430 mi.sm.to_433 
  0x0f000305, 0x060e0307, 0x2410285a, 0x230408a4,   // nl.lv.un_330 nl.is.de_432  sw.lt.eo_553 uk.ru.ky_433 
  0x63681d07, 0x24001f22, 0x02112607, 0x4b490707,   // la.ig.sco_432 cy.eo.un_870  ia.ro.da_432 it.to.mi_432 
  // [19fc0]
  0x24072512, 0x20020807, 0x35fc1d02, 0x1d0219a4,   // eu.it.eo_654 no.da.sq_432  la.zzp.zu_222 gl.da.la_433 
  0x05555304, 0x03402e07, 0x032223ad, 0x49001c04,   // ht.rw.fr_332 fo.lb.nl_432  ca.oc.nl_643 id.to.un_320 
  0x21003418, 0xfc01fe0c, 0x43111d08, 0x0b002502,   // ps.fa.un_740 tlh.en.zzp_543  la.ro.ie_443 eu.es.un_220 
  0x2537230d, 0x6b4d4c11, 0x2e0e2fa0, 0x250e2ea9,   // ky.ba.mn_554 wo.aa.ceb_653  su.is.fo_322 fo.is.eu_544 
  // [19fd0]
  0x321f0ca0, 0x04633b09, 0x241f040c, 0x212f570d,   // sv.cy.bs_322 so.sco.fi_444  fi.cy.eo_543 na.su.jw_554 
  0x241d1f08, 0x18634da4, 0x17440a04, 0x653b6304,   // cy.la.eo_443 aa.sco.ga_433  mk.kk.sr_332 sco.so.gv_332 
  0x041d240e, 0x0a004e08, 0x2a021dad, 0x1805fe0c,   // eo.la.fi_555 ay.pt.un_430  la.da.mt_643 tlh.fr.ga_543 
  0x58190a55, 0x171661a4, 0x1b3b6905, 0x190afeaf,   // pt.gl.om_442 za.hr.sr_433  mfe.so.tr_333 tlh.pt.gl_655 
  // [19fe0]
  0x0c001d07, 0x1b312e04, 0x0d003612, 0x3e0a3ba0,   // la.sv.un_420 fo.az.tr_332  gn.cs.un_640 so.pt.rm_322 
  0x071d0cee, 0x52051ea0, 0x241d26af, 0x46483104,   // sv.la.it_422 ms.fr.ha_322  ia.la.eo_655 az.tt.qu_332 
  0x04241da4, 0x193b4dad, 0x302a3b07, 0x563efe0c,   // la.eo.fi_433 aa.so.gl_643  so.mt.uz_432 tlh.rm.mg_543 
  0x432322a0, 0x35344609, 0x211718ec, 0x55244aee,   // oc.ca.ie_322 qu.xh.zu_444  ar.sr.fa_644 yo.eo.rw_422 
  // [19ff0]
  0x10005a02, 0x0913120c, 0x110a020b, 0x0a00090c,   // sm.lt.un_220 hu.et.pl_543  da.pt.ro_542 pl.pt.un_530 
  0x42631d09, 0x0f170eee, 0x40002f05, 0x12054202,   // la.sco.co_444 is.sr.lv_422  su.lb.un_330 co.fr.hu_222 
  0x29000c02, 0x05195908, 0x11001013, 0x113723a9,   // sv.sl.un_220 rn.gl.fr_443  be.ro.un_650 ky.ba.ro_544 
  0x291603ee, 0x18122812, 0x45004c0e, 0x230a1b07,   // nl.hr.sl_422 sd.ur.ar_654  wo.ln.un_550 tr.pt.ca_432 
  
  // [1a000]
  0x321703a0, 0x220a230e, 0x37483809, 0x074438ee,   // nl.sr.bs_322 ca.pt.oc_555  tk.tt.ba_444 tk.kk.bg_422 
  0x15000819, 0x230a220d, 0x05002105, 0x0c001b07,   // uk.un.un_750 oc.pt.ca_554  jw.fr.un_330 tr.sv.un_420 
  0x081140a7, 0x0c002208, 0xfe4d3bad, 0x731a57a4,   // lb.ro.no_532 oc.sv.un_430  so.aa.tlh_643 na.tl.ny_433 
  0x1b000a21, 0x481b31ac, 0xfe115d0b, 0x5cfe4712,   // pt.tr.un_860 az.tr.tt_632  ss.ro.tlh_542 sn.tlh.sa_654 
  // [1a010]
  0x2464300c, 0x615d3312, 0x47000d08, 0x02111d09,   // uz.lg.eo_543 nn.ss.za_654  cs.sn.un_430 la.ro.da_444 
  0x636a5a04, 0x35395dad, 0x184a0daf, 0x55001a0c,   // sm.haw.sco_332 ss.br.zu_643  cs.yo.ga_655 tl.rw.un_530 
  0x332c13a4, 0x11400605, 0x21423eee, 0x42052fa0,   // et.fy.nn_433 de.lb.ro_333  rm.co.jw_422 su.fr.co_322 
  0x333e220b, 0x311f4dec, 0x1d022604, 0x595567a9,   // oc.rm.nn_542 aa.cy.az_644  ia.da.la_332 ak.rw.rn_544 
  // [1a020]
  0x032319a0, 0x2d0d0faf, 0x394701a4, 0x3173600c,   // gl.ca.nl_322 lv.cs.sk_655  en.sn.br_433 vo.ny.az_543 
  0x64730107, 0x343135a4, 0x40063912, 0x2d004d0e,   // en.ny.lg_432 zu.az.xh_433  br.de.lb_654 aa.sk.un_550 
  0x08370402, 0x0626080c, 0x04002309, 0x5f1d73a9,   // ru.ba.uk_222 no.ia.de_543  ky.ru.un_440 ny.la.tn_544 
  0x123d345a, 0x5d001121, 0x1d0701a0, 0x0665fe07,   // ps.ku.ur_553 ro.ss.un_860  en.it.la_322 tlh.gv.de_432 
  // [1a030]
  0xfe0210a4, 0x1a02420c, 0xfe005d19, 0x29005d08,   // lt.da.tlh_433 co.da.tl_543  ss.tlh.un_750 ss.sl.un_430 
  0x0d004d13, 0x09353404, 0x05002f09, 0x4239050c,   // aa.cs.un_650 xh.zu.pl_332  su.fr.un_440 fr.br.co_543 
  0x122f05a7, 0x03063ead, 0x062c2709, 0x63040604,   // fr.su.hu_532 rm.de.nl_643  gd.fy.de_444 de.fi.sco_332 
  0x4700fe0e, 0x21386304, 0x5e000a2a, 0x3e6240a9,   // tlh.sn.un_550 sco.tk.jw_332  pt.ts.un_970 lb.kha.rm_544 
  // [1a040]
  0x05002d08, 0x2c3f0412, 0x786a370b, 0x67470aad,   // sk.fr.un_430 fi.af.fy_654  st.haw.ve_542 pt.sn.ak_643 
  0x20383308, 0x25494b0c, 0x5d026107, 0x38122108,   // nn.tk.sq_443 mi.to.eu_543  za.da.ss_432 jw.hu.tk_443 
  0x03003e0d, 0x61fa2dac, 0x215c3b09, 0x46793607,   // rm.nl.un_540 sk.nr.za_632  so.sa.jw_444 gn.war.qu_432 
  0x10333805, 0x57003e1a, 0x732468a4, 0x3c3515ad,   // tk.nn.lt_333 rm.na.un_760  ig.eo.ny_433 un.tg.ug_643 
  // [1a050]
  0x6a007821, 0x5c004709, 0x3f002f02, 0x0b36470d,   // ve.haw.un_860 sn.sa.un_440  su.af.un_220 sn.gn.es_554 
  0x2e0d0e0c, 0x2c0663ec, 0x093820ad, 0x302d0d5a,   // is.cs.fo_543 sco.de.fy_644  sq.tk.pl_643 cs.sk.uz_553 
  0x5f7537af, 0x3e0304a0, 0x231538a7, 0x3c003d12,   // st.nso.tn_655 fi.nl.rm_322  tk.ky.un_520 ku.ug.un_640 
  0xfa5d3512, 0x483823af, 0x043710ee, 0x36101705,   // zu.ss.nr_654 ky.tk.tt_655  be.ba.ru_422 sr.be.ab_333 
  // [1a060]
  0x12233da0, 0x5955340b, 0x5d2f3508, 0x5a116407,   // ku.ky.ur_322 xh.rw.rn_542  zu.su.ss_443 lg.ro.sm_432 
  0x48002005, 0x3b2821ac, 0x214005a6, 0x0500fc07,   // sq.tt.un_330 fa.sd.ks_632  fr.lb.jw_521 zzp.fr.un_420 
  0x10170a09, 0x2812230e, 0x05001205, 0x402c55ad,   // mk.sr.be_444 ky.ur.sd_555  hu.fr.un_330 rw.fy.lb_643 
  0x48133807, 0x35303cee, 0x370430a9, 0x21241d07,   // tk.et.tt_432 ug.uz.tg_422  uz.ru.ba_544 la.eo.jw_432 
  // [1a070]
  0x05190b02, 0x48381212, 0x1d000721, 0x381b0604,   // es.gl.fr_222 hu.tk.tt_654  it.la.un_860 de.tr.tk_332 
  0x21281812, 0x10005c05, 0x30004004, 0x0d492da6,   // ar.sd.fa_654 sa.lt.un_330  lb.uz.un_320 sk.to.cs_521 
  0x2e2d0d08, 0x180615a0, 0x08020609, 0x13001b0d,   // cs.sk.fo_443 un.de.ga_322  de.da.no_444 tr.et.un_540 
  0x29342855, 0x0429090c, 0x1f4764a0, 0x49255608,   // sw.xh.sl_442 pl.sl.fi_543  lg.sn.cy_322 mg.eu.to_443 
  // [1a080]
  0x26051f0c, 0x02045812, 0x2d092908, 0x29164cee,   // cy.fr.ia_543 om.fi.da_654  sl.pl.sk_443 wo.hr.sl_422 
  0x6b217907, 0x4b4925a9, 0x25301507, 0x322d0da4,   // war.jw.ceb_432 eu.to.mi_544  un.uz.mn_432 cs.sk.bs_433 
  0x253610ad, 0x250810a0, 0x04162da9, 0x29006009,   // lt.gn.eu_643 be.uk.mn_322  sk.hr.fi_544 vo.sl.un_440 
  0x2d0d3b08, 0x3b1b040c, 0x09202404, 0x58001008,   // so.cs.sk_443 fi.tr.so_543  eo.sq.pl_332 lt.om.un_430 
  // [1a090]
  0x13343b0c, 0xfe6530a4, 0x5300280d, 0x28023b0c,   // so.xh.et_543 uz.gv.tlh_433  sw.ht.un_540 so.da.sw_543 
  0x4d65fc0c, 0x0f5d0da4, 0x12365604, 0x4a2404a4,   // zzp.gv.aa_543 cs.ss.lv_433  mg.gn.hu_332 fi.eo.yo_433 
  0xfe59680c, 0x0a483607, 0x482538ec, 0x0f006b04,   // ig.rn.tlh_543 ab.tt.mk_432  tk.eu.tt_644 ceb.lv.un_320 
  0x2a646504, 0x3e2430a0, 0x6b3e2555, 0x5900fe13,   // gv.lg.mt_332 uz.eo.rm_322  eu.rm.ceb_442 tlh.rn.un_650 
  // [1a0a0]
  0x1a240404, 0x2a5907ee, 0x030e06ad, 0x4d3b1ca4,   // fi.eo.tl_332 it.rn.mt_422  de.is.nl_643 id.so.aa_433 
  0x637901ac, 0x04426007, 0x04602255, 0xfe282408,   // en.war.sco_632 vo.co.fi_432  oc.vo.fi_442 eo.sw.tlh_443 
  0x34fc4d05, 0x5efe6013, 0x27650107, 0x11002c0e,   // aa.zzp.xh_333 vo.tlh.ts_665  en.gv.gd_432 fy.ro.un_550 
  0x110a05a4, 0x3b004a13, 0x465c4e0b, 0x321b30a9,   // fr.pt.ro_433 yo.so.un_650  ay.sa.qu_542 uz.tr.bs_544 
  // [1a0b0]
  0x44233709, 0x23114411, 0x0a103504, 0x0e3e5212,   // ba.ky.kk_444 kk.ro.ky_653  tg.be.mk_332 ha.rm.is_654 
  0x0800442a, 0x082304a0, 0x23281208, 0x5d001f0e,   // kk.uk.un_970 ru.ky.uk_322  ur.sd.ky_443 cy.ss.un_550 
  0x111025ec, 0xfe00020e, 0x23362512, 0x57540ca4,   // mn.be.ro_644 da.tlh.un_550  mn.ab.ky_654 sv.ik.na_433 
  0x3000fe11, 0x53452402, 0x13001c0b, 0x30102305,   // tlh.uz.un_630 eo.ln.ht_222  mr.bh.un_520 ky.be.uz_333 
  // [1a0c0]
  0xfe250212, 0x1800220d, 0x1d2410ee, 0x241d1faf,   // da.eu.tlh_654 oc.ga.un_540  lt.eo.la_422 cy.la.eo_655 
  0x044c2407, 0x53002512, 0x2532530c, 0x0a230da0,   // eo.wo.fi_432 eu.ht.un_640  ht.bs.eu_543 cs.ca.pt_322 
  0x276339ad, 0x313f1b04, 0x4a00fe05, 0x1c004a04,   // br.sco.gd_643 tr.af.az_332  tlh.yo.un_330 yo.id.un_320 
  0x01021dee, 0x25113812, 0x1d04240b, 0x26071d07,   // la.da.en_422 tk.ro.mn_654  eo.fi.la_542 la.it.ia_432 
  // [1a0d0]
  0x063f5707, 0x104063a7, 0x1b063107, 0x2d00200b,   // na.af.de_432 sco.lb.lt_532  az.de.tr_432 sq.sk.un_520 
  0x23184408, 0x063e310c, 0x3e1206a7, 0x3e004b07,   // kk.ar.ky_443 az.rm.de_543  de.hu.rm_532 mi.rm.un_420 
  0x42070107, 0x070423a6, 0x190a0daf, 0x1b133e04,   // en.it.co_432 ky.ru.bg_521  cs.pt.gl_655 rm.et.tr_332 
  0x1736150c, 0x330e15ee, 0x3f1bfea7, 0x3e131ba0,   // un.ab.sr_543 un.is.nn_422  tlh.tr.af_532 tr.et.rm_322 
  // [1a0e0]
  0x060c0ea0, 0x276359ee, 0x533ffea0, 0x033e3f02,   // is.sv.de_322 rn.sco.gd_422  tlh.af.ht_322 af.rm.nl_222 
  0x223e21a0, 0x630c1fec, 0x2e005307, 0x3600180e,   // jw.rm.oc_322 cy.sv.sco_644  ht.fo.un_420 ga.gn.un_550 
  0x213c34a9, 0x443c1555, 0x1b003304, 0x120c1ba7,   // ps.ug.fa_544 un.ug.kk_442  nn.tr.un_320 tr.sv.hu_532 
  0x283b210d, 0x1c2e4002, 0x35001118, 0x6b794cad,   // fa.ks.sd_554 lb.fo.id_222  ro.tg.un_740 wo.war.ceb_643 
  // [1a0f0]
  0x40003104, 0x301b0e04, 0x072511a7, 0x4a001013,   // az.lb.un_320 is.tr.uz_332  ro.mn.bg_532 lt.yo.un_650 
  0x65634f0b, 0x20243304, 0x652e630c, 0x21303c07,   // bi.sco.gv_542 nn.eo.sq_332  sco.fo.gv_543 ug.uz.fa_432 
  0x29002a13, 0x4a102404, 0x1b48315a, 0x21002008,   // mt.sl.un_650 eo.lt.yo_332  az.tt.tr_553 sq.jw.un_430 
  0x4c001e04, 0x0b5c29a7, 0x350715ac, 0x653953a0,   // ms.wo.un_320 sl.sa.es_532  un.bg.tg_632 ht.br.gv_322 
  // [1a100]
  0x52150107, 0x3000290c, 0x6835345a, 0x2c0a10ad,   // en.ha.un_420 sl.uz.un_530  xh.zu.ig_553 lt.pt.fy_643 
  0x48120d04, 0x29211ca4, 0xfe2926ee, 0x290f20a0,   // cs.hu.tt_332 id.jw.sl_433  ia.sl.tlh_422 sq.lv.sl_322 
  0x0452300c, 0x55686407, 0x35346811, 0x30004204,   // uz.ha.fi_543 lg.ig.rw_432  ig.xh.zu_653 co.uz.un_320 
  0x23003c2c, 0x435202a4, 0x48243107, 0x303c1555,   // ug.ky.un_990 da.ha.ie_433  az.eo.tt_432 un.ug.uz_442 
  // [1a110]
  0x733f28ee, 0x2d001809, 0x12560ea0, 0x1d5a4907,   // sw.af.ny_422 ga.sk.un_440  is.mg.hu_322 to.sm.la_432 
  0x331f0cee, 0x515a02a7, 0x083336ee, 0x30363511,   // sv.cy.nn_422 da.sm.kl_532  gn.nn.no_422 tg.ab.uz_653 
  0x10482311, 0x34001502, 0x2b003e07, 0x3e001a04,   // ky.tt.be_653 un.xh.un_220  rm.vi.un_420 tl.rm.un_320 
  0x2537480c, 0x0400350b, 0x3e00202a, 0x2d00101a,   // tt.ba.mn_543 tg.ru.un_520  sq.rm.un_970 lt.sk.un_760 
  // [1a120]
  0x2b1a3e11, 0x1d21790c, 0x1c060204, 0x15003b0c,   // rm.tl.vi_653 war.jw.la_543  da.de.id_332 so.un.un_530 
  0x483845a0, 0x1b64455a, 0x43002d0d, 0x51001b08,   // ln.tk.tt_322 ln.lg.tr_553  sk.ie.un_540 tr.kl.un_430 
  0x280720a6, 0x0c352a04, 0x36292807, 0x5100210d,   // sq.it.sw_521 mt.zu.sv_332  sw.sl.gn_432 jw.kl.un_540 
  0x0e330205, 0x0e2e6307, 0x13004c02, 0x4825100c,   // da.nn.is_333 sco.fo.is_432  wo.et.un_220 be.mn.tt_543 
  // [1a130]
  0x13004c13, 0x651a0102, 0x0d005105, 0x36004507,   // wo.et.un_650 en.tl.gv_222  kl.cs.un_330 ln.gn.un_420 
  0x0f335ca0, 0x55111da0, 0x46595504, 0x55005013,   // sa.nn.lv_322 la.ro.rw_322  rw.rn.qu_332 fj.rw.un_650 
  0x1d195502, 0x33560d07, 0x12001104, 0x21553bee,   // rw.gl.la_222 cs.mg.nn_432  ro.hu.un_320 so.rw.jw_422 
  0x18002318, 0x3e005505, 0x35306405, 0x0d005619,   // ky.ar.un_740 rw.rm.un_330  lg.uz.zu_333 mg.cs.un_750 
  // [1a140]
  0x1d790204, 0x1d0a4204, 0x3e0b4ca0, 0x68356407,   // da.war.la_332 co.pt.la_332  wo.es.rm_322 lg.zu.ig_432 
  0x230956ec, 0x560923a4, 0x1511440d, 0x1f79070c,   // mg.pl.ca_644 ca.pl.mg_433  kk.ro.un_554 it.war.cy_543 
  0x23304455, 0x24006a12, 0x292d16a0, 0x100a3505,   // kk.uz.ky_442 haw.eo.un_640  hr.sk.sl_322 tg.mk.be_333 
  0x10006a07, 0x082e33af, 0x2d161008, 0x3216100c,   // haw.lt.un_420 nn.fo.no_655  lt.hr.sk_443 lt.hr.bs_543 
  // [1a150]
  0x563079ad, 0x65124c08, 0x3f006308, 0x28003f07,   // war.uz.mg_643 wo.hu.gv_443  sco.af.un_430 af.sw.un_420 
  0x20016307, 0x04154809, 0x10002918, 0x173638a4,   // sco.en.sq_432 tt.ru.un_440  sl.lt.un_740 tk.ab.sr_433 
  0x1d762604, 0x0b092304, 0x35003705, 0x0b43010c,   // ia.crs.la_332 ca.pl.es_332  ba.tg.un_330 en.ie.es_543 
  0xfe003b05, 0x283d12ec, 0x232536ad, 0x04441504,   // so.tlh.un_330 ur.ku.sd_644  ab.mn.ky_643 un.kk.ru_332 
  // [1a160]
  0x0458525a, 0x0462520c, 0x1d00262c, 0x3b004e14,   // ha.om.fi_553 ha.kha.fi_543  ia.la.un_990 ay.so.un_660 
  0x012730a0, 0x2c024508, 0x49025a08, 0x3e4301a4,   // uz.gd.en_322 ln.da.fy_443  sm.da.to_443 en.ie.rm_433 
  0x02005820, 0x524c08a0, 0x290d1755, 0x1f6045a4,   // om.da.un_850 no.wo.ha_322  sr.cs.sl_442 ln.vo.cy_433 
  0x1b00522b, 0x1d5201a4, 0x0f524d0c, 0x534860ee,   // ha.tr.un_980 en.ha.la_433  aa.ha.lv_543 vo.tt.ht_422 
  // [1a170]
  0x3b484c02, 0x0f42520c, 0x110224a4, 0x0f600608,   // wo.tt.so_222 ha.co.lv_543  eo.da.ro_433 de.vo.lv_443 
  0x3b4d2012, 0x634d3b09, 0x583004a9, 0x695760a4,   // sq.aa.so_654 so.aa.sco_444  fi.uz.om_544 vo.na.mfe_433 
  0x06006705, 0x1e00fc02, 0x13000e09, 0x32165cac,   // ak.de.un_330 zzp.ms.un_220  is.et.un_440 sa.hr.bs_632 
  0x06000e07, 0x481b3802, 0x223f23a4, 0x5c0f3912,   // is.de.un_420 tk.tr.tt_222  ca.af.oc_433 br.lv.sa_654 
  // [1a180]
  0x11255612, 0x33002512, 0x56362f09, 0x42113608,   // mg.eu.ro_654 eu.nn.un_640  su.gn.mg_444 gn.ro.co_443 
  0x251f65a7, 0x4c4d0c08, 0x0a001307, 0x1d1b110c,   // gv.cy.eu_532 sv.aa.wo_443  et.pt.un_420 ro.tr.la_543 
  0x36004809, 0x0f11250d, 0x55001b20, 0x1507300c,   // tt.ab.un_440 eu.ro.lv_554  tr.rw.un_850 uz.bg.un_543 
  0x5f00570d, 0x521125a9, 0x36473307, 0x3100511a,   // na.tn.un_540 eu.ro.ha_544  nn.sn.gn_432 kl.az.un_760 
  // [1a190]
  0x1528fea0, 0x2a001112, 0xfc156508, 0x53620207,   // tlh.sw.un_322 ro.mt.un_640  gv.zzp.un_430 da.kha.ht_432 
  0x6902300c, 0x766925a4, 0x573e010b, 0x6b7910a9,   // uz.da.mfe_543 eu.mfe.crs_433  en.rm.na_542 lt.war.ceb_544 
  0x1e271c0c, 0x6b1f270c, 0x670252a4, 0x021030a4,   // id.gd.ms_543 gd.cy.ceb_543  ha.da.ak_433 uz.lt.da_433 
  0x18274f0c, 0x603b2b05, 0x254f1a0c, 0x02253b0c,   // bi.gd.ga_543 vi.so.vo_333  tl.bi.eu_543 so.eu.da_543 
  // [1a1a0]
  0x4a103ba0, 0x120462ee, 0x02190b14, 0x1c6b02a0,   // so.lt.yo_322 kha.fi.hu_422  es.gl.da_666 da.ceb.id_322 
  0x3e1f27ad, 0x04003b18, 0x3b250255, 0x10290dad,   // gd.cy.rm_643 so.fi.un_740  da.eu.so_442 cs.sl.lt_643 
  0x4f1f57a4, 0x293224a0, 0x3b1f4d0d, 0xfc634d07,   // na.cy.bi_433 eo.bs.sl_322  aa.cy.so_554 aa.sco.zzp_432 
  0x00006006, 0x31483b0c, 0x58002b05, 0x4c1d05a4,   // vo.un.un_400 so.tt.az_543  vi.om.un_330 fr.la.wo_433 
  // [1a1b0]
  0x33104d07, 0x2d0b3604, 0x4d005c09, 0x1f69530e,   // aa.lt.nn_432 gn.es.sk_332  sa.aa.un_440 ht.mfe.cy_555 
  0x0276530c, 0x2500561b, 0x0317fea0, 0x54001a0e,   // ht.crs.da_543 mg.eu.un_770  tlh.sr.nl_322 tl.ik.un_550 
  0x3f2b4fa7, 0x3e606905, 0x4d00222a, 0x1f001a1b,   // bi.vi.af_532 mfe.vo.rm_333  oc.aa.un_970 tl.cy.un_770 
  0x1f3b30a4, 0x180401af, 0x1c021aa4, 0x02007918,   // uz.so.cy_433 en.fi.ga_655  tl.da.id_433 war.da.un_740 
  // [1a1c0]
  0x2200360d, 0x4000fe1a, 0x04253cee, 0x10003107,   // gn.oc.un_540 tlh.lb.un_760  ug.mn.ru_422 az.lt.un_420 
  0x13066504, 0x0b0a79a7, 0x42340507, 0x373035a7,   // gv.de.et_332 war.pt.es_532  fr.xh.co_432 tg.uz.ba_532 
  0x21233402, 0x23000614, 0x22001d07, 0x1b3113a0,   // ps.ky.fa_222 de.ca.un_660  la.oc.un_420 et.az.tr_322 
  0x1b311f02, 0x1b5c315a, 0x1d0b010c, 0x35344704,   // cy.az.tr_222 az.sa.tr_553  en.es.la_543 sn.xh.zu_332 
  // [1a1d0]
  0x361d5b05, 0x30583e07, 0x3700232a, 0x483b25a0,   // sg.la.gn_333 rm.om.uz_432  ky.ba.un_970 eu.so.tt_322 
  0x17230a09, 0x1b303113, 0x48311907, 0x38002c13,   // mk.ky.sr_444 az.uz.tr_665  gl.az.tt_432 fy.tk.un_650 
  0x465c01a4, 0x2e002507, 0x482335ec, 0x17370402,   // en.sa.qu_433 eu.fo.un_420  tg.ky.tt_644 ru.ba.sr_222 
  0x0700370c, 0x15153808, 0x0355fead, 0xfe00030d,   // ba.bg.un_530 tk.un.un_430  tlh.rw.nl_643 nl.tlh.un_540 
  // [1a1e0]
  0x03595504, 0x443423ec, 0x44004818, 0x5500fe07,   // rw.rn.nl_332 ky.ps.kk_644  tt.kk.un_740 tlh.rw.un_420 
  0x0300fe09, 0x55035904, 0xfe00571a, 0x036b15ad,   // tlh.nl.un_440 rn.nl.rw_332  na.tlh.un_760 un.ceb.nl_643 
  0x15044404, 0x03fe2a0e, 0x04110a07, 0x48371514,   // kk.ru.un_332 mt.tlh.nl_555  mk.ro.ru_432 un.ba.tt_666 
  0x3f030602, 0x33083f05, 0x0c652a04, 0x205302a0,   // de.nl.af_222 af.no.nn_333  mt.gv.sv_332 da.ht.sq_322 
  // [1a1f0]
  0x0700261a, 0x15232507, 0x235424af, 0x3f00540c,   // ia.it.un_760 mn.ky.un_432  eo.ik.ca_655 ik.af.un_530 
  0x301517a4, 0x05003f02, 0x633f0355, 0x22230a11,   // sr.uz.un_430 af.fr.un_220  nl.af.sco_442 pt.ca.oc_653 
  0x42003f13, 0x250711ad, 0x30074402, 0x17200655,   // af.co.un_650 ro.bg.mn_643  kk.bg.uz_222 de.sq.sr_442 
  0x54001521, 0x1d265705, 0x24000c07, 0x0c00fe09,   // un.ik.un_860 na.ia.la_333  sv.eo.un_420 tlh.sv.un_440 
  // [1a200]
  0x48004904, 0x1b5d1fad, 0x10290d07, 0x020c01a0,   // to.tt.un_320 cy.ss.tr_643  cs.sl.lt_432 en.sv.da_322 
  0x634c21ec, 0x5e003007, 0x19482f02, 0x211c1eee,   // jw.wo.sco_644 uz.ts.un_420  su.tt.gl_222 ms.id.jw_422 
  0x2d0d50af, 0x20526108, 0x1b6563a0, 0x08000d08,   // fj.cs.sk_655 za.ha.sq_443  sco.gv.tr_322 cs.no.un_430 
  0x63093f04, 0x522a0209, 0x076324a4, 0x78285aa9,   // af.pl.sco_332 da.mt.ha_444  eo.sco.it_433 sm.sw.ve_544 
  // [1a210]
  0x103216ee, 0x2b786a0c, 0x246a285a, 0x32002807,   // hr.bs.lt_422 haw.ve.vi_543  sw.haw.eo_553 sw.bs.un_420 
  0x213c3407, 0x152c010c, 0x07002405, 0x656352af,   // ps.ug.fa_432 en.fy.un_543  eo.it.un_330 ha.sco.gv_655 
  0x15005202, 0x30061b0c, 0x16002407, 0x281821af,   // ha.un.un_220 tr.de.uz_543  eo.hr.un_420 fa.ar.sd_655 
  0x301535a6, 0x47190b04, 0x46004508, 0x763152a4,   // tg.uz.un_510 es.gl.sn_332  ln.qu.un_430 ha.az.crs_433 
  // [1a220]
  0x7800670d, 0x65005509, 0x19004607, 0x57000102,   // ak.ve.un_540 rw.gv.un_440  qu.gl.un_420 en.na.un_220 
  0x18190b08, 0x18343c07, 0x65471d04, 0x11000a1b,   // es.gl.ga_443 ug.ps.ar_432  la.sn.gv_332 mk.ro.un_770 
  0x4804110b, 0x20561308, 0x222763a0, 0x1d0e2004,   // ro.ru.tt_542 et.mg.sq_443  sco.gd.oc_322 sq.is.la_332 
  0x1d4256a7, 0x22001605, 0x212a1d04, 0x35113008,   // mg.co.la_532 hr.oc.un_330  la.mt.jw_332 uz.ro.tg_443 
  // [1a230]
  0x06404809, 0x190b18a6, 0x630c1d07, 0x5c0c0507,   // tt.lb.de_444 ga.es.gl_521  la.sv.sco_432 fr.sv.sa_432 
  0x39002719, 0x23122004, 0x56791da9, 0x3c122814,   // gd.br.un_750 sq.hu.ca_332  la.war.mg_544 sd.ur.ug_666 
  0x21232808, 0x21181202, 0x30123414, 0x314326af,   // sd.ky.fa_443 ur.ar.fa_222  ps.ur.uz_666 ia.ie.az_655 
  0x250e510c, 0x38484408, 0x21162f07, 0x650742a0,   // kl.is.eu_543 kk.tt.tk_443  su.hr.jw_432 co.it.gv_322 
  // [1a240]
  0x16424e07, 0x213444a0, 0x79002d1a, 0x18232802,   // ay.co.hr_432 kk.ps.fa_322  sk.war.un_760 sd.ky.ar_222 
  0x36303c07, 0x5e023e04, 0x3e2301a0, 0x3965fc0d,   // ug.uz.ab_432 rm.da.ts_332  en.ca.rm_322 zzp.gv.br_554 
  0x481035a7, 0xfc7943a0, 0xfc021dee, 0xfe003e04,   // tg.be.tt_532 ie.war.zzp_322  la.da.zzp_422 rm.tlh.un_320 
  0x4000360d, 0x0d0b4804, 0x0c3e3308, 0x44371512,   // gn.lb.un_540 tt.es.cs_332  nn.rm.sv_443 un.ba.kk_654 
  // [1a250]
  0x250415a7, 0x025905a7, 0x29003e04, 0x3e001707,   // un.ru.mn_532 fr.rn.da_532  rm.sl.un_320 sr.rm.un_420 
  0x0a403608, 0x232d0d13, 0x213946a4, 0x3b302a02,   // gn.lb.pt_443 cs.sk.ca_665  qu.br.jw_433 mt.uz.so_222 
  0x242252ee, 0x2479670c, 0x3b375aa0, 0x155467a9,   // ha.oc.eo_422 ak.war.eo_543  sm.st.so_322 ak.ik.un_544 
  0x5230285a, 0x3f003204, 0x64675a05, 0x30002a12,   // sw.uz.ha_553 bs.af.un_320  sm.ak.lg_333 mt.uz.un_640 
  // [1a260]
  0x311a2d07, 0x3f032ca0, 0x184d3b0c, 0x2064450c,   // sk.tl.az_432 fy.nl.af_322  so.aa.ga_543 ln.lg.sq_543 
  0x30074d07, 0x3b4d525a, 0x3b1a060c, 0x101a6b0d,   // aa.it.uz_432 ha.aa.so_553  de.tl.so_543 ceb.tl.lt_554 
  0x35004005, 0x48043004, 0x16090d07, 0x110a17af,   // lb.zu.un_330 uz.ru.tt_332  cs.pl.hr_432 sr.mk.ro_655 
  0x283b58a0, 0x3b304d07, 0x62001f0e, 0x40060304,   // om.so.sw_322 aa.uz.so_432  cy.kha.un_550 nl.de.lb_332 
  // [1a270]
  0x073642a0, 0x520922a4, 0x48514ea4, 0x604847af,   // co.gn.it_322 oc.pl.ha_433  ay.kl.tt_433 sn.tt.vo_655 
  0x52006707, 0x4c4d56ad, 0x2a100f09, 0x2e3f35a0,   // ak.ha.un_420 mg.aa.wo_643  lv.lt.mt_444 zu.af.fo_322 
  0x13000308, 0x403906ec, 0x3200031a, 0x44001122,   // nl.et.un_430 de.br.lb_644  nl.bs.un_760 ro.kk.un_870 
  0x483806ee, 0x04522aad, 0x16032a08, 0x2f3e2a0c,   // de.tk.tt_422 mt.ha.fi_643  mt.nl.hr_443 mt.rm.su_543 
  // [1a280]
  0x114255ee, 0x4359550d, 0x16595555, 0x5902550b,   // rw.co.ro_422 rw.rn.ie_554  rw.rn.hr_442 rw.da.rn_542 
  0x440715a0, 0x2f4a52a0, 0x36101508, 0x37462004,   // un.bg.kk_322 ha.yo.su_322  un.be.ab_443 sq.qu.st_332 
  0x2e2d0dee, 0x5d73785a, 0x51595508, 0x47345dec,   // cs.sk.fo_422 ve.ny.ss_553  rw.rn.kl_443 ss.xh.sn_644 
  0x0c555104, 0x6e553807, 0x5d373412, 0x51134714,   // kl.rw.sv_332 tk.rw.hmn_432  xh.st.ss_654 sn.et.kl_666 
  // [1a290]
  0x02005512, 0x23441811, 0x596255ad, 0x21003d23,   // rw.da.un_640 ar.kk.ky_653  rw.kha.rn_643 ku.fa.un_880 
  0x04006b07, 0x5e5d55ec, 0x4b000212, 0x0e4d4605,   // ceb.fi.un_420 rw.ss.ts_644  da.mi.un_640 qu.aa.is_333 
  0x5c6e55ad, 0x21006413, 0x5e345dec, 0x285955a9,   // rw.hmn.sa_643 lg.jw.un_650  ss.xh.ts_644 rw.rn.sw_544 
  0x02563b11, 0x0859555a, 0x0245505a, 0x73005109,   // so.mg.da_653 rw.rn.no_553  fj.ln.da_553 kl.ny.un_440 
  // [1a2a0]
  0x73251b08, 0x475f370c, 0x4a4c3e04, 0x6964590c,   // tr.eu.ny_443 st.tn.sn_543  rm.wo.yo_332 rn.lg.mfe_543 
  0x1d243bad, 0x382130a0, 0x43000f18, 0x46553812,   // so.eo.la_643 uz.jw.tk_322  lv.ie.un_740 tk.rw.qu_654 
  0x1a09100c, 0x42586904, 0x25151512, 0x15001002,   // lt.pl.tl_543 mfe.om.co_332  un.mn.un_640 lt.un.un_220 
  0x19003b0d, 0x09452905, 0x2d0929a4, 0x231738a7,   // so.gl.un_540 sl.ln.pl_333  sl.pl.sk_433 tk.sr.ky_532 
  // [1a2b0]
  0x2a4b3605, 0x0f093107, 0x1d242613, 0x30213d07,   // gn.mi.mt_333 az.pl.lv_432  ia.eo.la_665 ku.fa.uz_432 
  0x455302a4, 0x51003402, 0x75675fa9, 0x58003e05,   // da.ht.ln_433 xh.kl.un_220  tn.ak.nso_544 rm.om.un_330 
  0x040a1110, 0x07231107, 0x09511aa9, 0x5109450c,   // ro.mk.ru_642 ro.ky.bg_432  tl.kl.pl_544 ln.pl.kl_543 
  0x372348af, 0x305146af, 0x18255855, 0x33000f07,   // tt.ky.ba_655 qu.kl.uz_655  om.eu.ga_442 lv.nn.un_420 
  // [1a2c0]
  0x353008ee, 0x373435a4, 0x23385613, 0x09385611,   // uk.uz.tg_422 zu.xh.st_433  mg.tk.ca_665 mg.tk.pl_653 
  0x093856ad, 0x563809ec, 0x082530a7, 0x095b5611,   // mg.tk.pl_643 pl.tk.mg_644  uz.mn.uk_532 mg.sg.pl_653 
  0x560938a4, 0x44373c12, 0x11000a19, 0x15060308,   // tk.pl.mg_433 ug.ba.kk_654  mk.ro.un_750 nl.de.un_443 
  0x5c002908, 0x0d2d500c, 0x4356505a, 0x23385611,   // sl.sa.un_430 fj.sk.cs_543  fj.mg.ie_553 mg.tk.ca_653 
  // [1a2d0]
  0x1d006022, 0x09005621, 0x673856a4, 0x3e002c02,   // vo.la.un_870 mg.pl.un_860  mg.tk.ak_433 fy.rm.un_220 
  0x0424fca0, 0x32500607, 0x1d0626a0, 0x1d2529a4,   // zzp.eo.fi_322 de.fj.bs_432  ia.de.la_322 sl.eu.la_433 
  0x07005f04, 0x113c380d, 0x78004519, 0x060f79a4,   // tn.it.un_320 tk.ug.ro_554  ln.ve.un_750 war.lv.de_433 
  0x43246ba6, 0x375f750c, 0x24001702, 0x0a303b02,   // ceb.eo.ie_521 nso.tn.st_543  sr.eo.un_220 so.uz.pt_222 
  // [1a2e0]
  0x1a3b090c, 0x15644dad, 0x462519a9, 0x1b000304,   // pl.so.tl_543 aa.lg.un_643  gl.eu.qu_544 nl.tr.un_320 
  0x55454a07, 0x040710a7, 0x42000612, 0x190b73a7,   // yo.ln.rw_432 be.bg.ru_532  de.co.un_640 ny.es.gl_532 
  0x1f790207, 0x17360755, 0x19021011, 0x0b001f09,   // da.war.cy_432 bg.ab.sr_442  lt.da.gl_653 cy.es.un_440 
  0x353825a9, 0x21030407, 0x51004705, 0x15364405,   // mn.tk.tg_544 fi.nl.jw_432  sn.kl.un_330 kk.ab.un_333 
  // [1a2f0]
  0x15171055, 0x103c3812, 0x0a00fe0d, 0x28180155,   // be.sr.un_442 tk.ug.be_654  tlh.pt.un_540 iw.ar.sd_442 
  0x182823a0, 0x36000d0d, 0x0f124309, 0x0312450d,   // ky.sd.ar_322 cs.gn.un_540  ie.hu.lv_444 ln.hu.nl_554 
  0x17070807, 0x321629ec, 0x0c3804a7, 0x2d004a1a,   // uk.bg.sr_432 sl.hr.bs_644  fi.tk.sv_532 yo.sk.un_760 
  0x18240104, 0x6048040c, 0x60004834, 0x044860af,   // en.eo.ga_332 fi.tt.vo_543  tt.vo.un_A80 vo.tt.fi_655 
  // [1a300]
  0x125139a0, 0x4800602b, 0x04604814, 0x511f390d,   // br.kl.hu_322 vo.tt.un_980  tt.vo.fi_666 br.cy.kl_554 
  0x373044ad, 0x12002407, 0x01063902, 0x405106a7,   // kk.uz.ba_643 eo.hu.un_420  br.de.en_222 de.kl.lb_532 
  0x38486012, 0x0c3ffc55, 0x0c000421, 0x24005102,   // vo.tt.tk_654 zzp.af.sv_442  fi.sv.un_860 kl.eo.un_220 
  0x04486060, 0x48600412, 0x170f03ac, 0x53282c07,   // vo.tt.fi_664 fi.vo.tt_654  nl.lv.sr_632 fy.sw.ht_432 
  // [1a310]
  0x03001109, 0x1f126307, 0x2a001604, 0x063e4002,   // ro.nl.un_440 sco.hu.cy_432  hr.mt.un_320 lb.rm.de_222 
  0x130c12a4, 0x122a2e04, 0x2a00121b, 0x2e571208,   // hu.sv.et_433 fo.mt.hu_332  hu.mt.un_770 hu.na.fo_443 
  0xfe0112ee, 0x5e150204, 0x03002a05, 0x3b00690e,   // hu.en.tlh_422 da.ts.un_320  mt.nl.un_330 mfe.so.un_550 
  0x03002a14, 0x321603a0, 0x12000c18, 0x3f0c12a6,   // mt.nl.un_660 nl.hr.bs_322  sv.hu.un_740 hu.sv.af_521 
  // [1a320]
  0x5f2c060c, 0x353044af, 0x1339fe07, 0x230e18a0,   // de.fy.tn_543 kk.uz.tg_655  tlh.br.et_432 ga.is.ca_322 
  0x4b045ba7, 0x1304480b, 0x0a3036ad, 0x032c02a0,   // sg.fi.mi_532 tt.fi.et_542  ab.uz.mk_643 da.fy.nl_322 
  0x03fefaad, 0x312230ad, 0x23343c0c, 0x3c1821a9,   // nr.tlh.nl_643 uz.oc.az_643  ug.ps.ky_543 fa.ar.ug_544 
  0x30000408, 0x33086714, 0x44233c55, 0x18130409,   // fi.uz.un_430 ak.no.nn_666  ug.ky.kk_442 fi.et.ga_444 
  // [1a330]
  0x353830ec, 0x04486007, 0x40305204, 0x06032eee,   // uz.tk.tg_644 vo.tt.fi_432  ha.uz.lb_332 fo.nl.de_422 
  0x5c0602a7, 0x36483704, 0x482d0404, 0x3900090c,   // da.de.sa_532 ba.tt.ab_332  fi.sk.tt_332 pl.br.un_530 
  0x0900390d, 0x06004e13, 0x13044808, 0x2c00110d,   // br.pl.un_540 ay.de.un_650  tt.fi.et_443 ro.fy.un_540 
  0x4e000413, 0x651354af, 0x38301307, 0x303f0304,   // fi.ay.un_650 ik.et.gv_655  et.uz.tk_432 nl.af.uz_332 
  // [1a340]
  0x27003008, 0x3e510605, 0x06674012, 0x03003007,   // uz.gd.un_430 de.kl.rm_333  lb.ak.de_654 uz.nl.un_420 
  0x1d001307, 0x2e003704, 0x18343dad, 0x2d162904,   // et.la.un_420 st.fo.un_320  ku.ps.ar_643 sl.hr.sk_332 
  0x2d1610ee, 0x043744ee, 0x5c0f4ba9, 0x04360705,   // lt.hr.sk_422 kk.ba.ru_422  mi.lv.sa_544 bg.ab.ru_333 
  0x6400130c, 0x0330150c, 0x3412280b, 0x10250408,   // et.lg.un_530 un.uz.nl_543  sd.ur.ps_542 ru.mn.be_443 
  // [1a350]
  0x303c445a, 0x18362b04, 0x355134a0, 0x2d001013,   // kk.ug.uz_553 vi.gn.ga_332  xh.kl.zu_322 lt.sk.un_650 
  0x44373ca4, 0x2d1610a0, 0x29602d07, 0x3d343055,   // ug.ba.kk_433 lt.hr.sk_322  sk.vo.sl_432 uz.ps.ku_442 
  0x0c486011, 0x3d343b07, 0x2f32170d, 0x100f1708,   // vo.tt.sv_653 ks.ps.ku_432  sr.bs.su_554 sr.lv.lt_443 
  0x03041b08, 0x04364607, 0x573f2008, 0x0f13040c,   // tr.fi.nl_443 qu.gn.fi_432  sq.af.na_443 fi.et.lv_543 
  // [1a360]
  0x48044655, 0x0448460c, 0x24000208, 0x2f000907,   // qu.fi.tt_442 qu.tt.fi_543  da.eo.un_430 pl.su.un_420 
  0x094a4507, 0x1e1c21af, 0x19360b12, 0x172129a7,   // ln.yo.pl_432 jw.id.ms_655  es.gn.gl_654 sl.jw.sr_532 
  0x38031bee, 0x1016170c, 0x2c381004, 0x67502d07,   // tr.nl.tk_422 sr.hr.lt_543  lt.tk.fy_332 sk.fj.ak_432 
  0x1b006505, 0x63121fa0, 0x123423ad, 0x353403a4,   // gv.tr.un_330 cy.hu.sco_322  ky.ps.ur_643 nl.xh.zu_433 
  // [1a370]
  0x3500020c, 0x13045712, 0x1b6938a4, 0x2f211ea9,   // da.zu.un_530 na.fi.et_654  tk.mfe.tr_433 ms.jw.su_544 
  0x04132a0c, 0x0a102da0, 0x2538445a, 0x481e1c0d,   // mt.et.fi_543 sk.lt.pt_322  kk.tk.mn_553 id.ms.tt_554 
  0x1b004818, 0x0c480407, 0x44370aa7, 0x184a45ad,   // tt.tr.un_740 fi.tt.sv_432  mk.ba.kk_532 ln.yo.ga_643 
  0x46002004, 0x2a1d0107, 0x37151507, 0x0d1c18ac,   // sq.qu.un_320 en.la.mt_432  un.ba.un_420 ar.mr.ne_632 
  // [1a380]
  0x18001913, 0x17100fa0, 0x08332e04, 0xfe00481a,   // gl.ga.un_650 lv.lt.sr_322  fo.nn.no_332 tt.tlh.un_760 
  0x2e630304, 0x0f4b10a4, 0x6a005635, 0x4b5f6a0c,   // nl.sco.fo_332 lt.mi.lv_433  mg.haw.un_A90 haw.tn.mi_543 
  0x65001505, 0x5a00020d, 0x32000a08, 0x73027904,   // un.gv.un_330 da.sm.un_540  pt.bs.un_430 war.da.ny_332 
  0x1f390207, 0x02005320, 0x6a4b5fa4, 0x321a56a9,   // da.br.cy_432 ht.da.un_850  tn.mi.haw_433 mg.tl.bs_544 
  // [1a390]
  0x353615ec, 0x2a3b25ad, 0x35002311, 0x57000213,   // un.ab.tg_644 eu.so.mt_643  ky.tg.un_630 da.na.un_650 
  0x1d002d02, 0x25000234, 0x3f2c5204, 0x532b02ad,   // sk.la.un_220 da.eu.un_A80  ha.fy.af_332 da.vi.ht_643 
  0x3e0b0a08, 0x12003b18, 0x3d1221a9, 0x36001804,   // pt.es.rm_443 ks.ur.un_740  fa.ur.ku_544 ga.gn.un_320 
  0x4b005c14, 0x212f4207, 0x0807105a, 0x18480e55,   // sa.mi.un_660 co.su.jw_432  be.bg.uk_553 is.tt.ga_442 
  // [1a3a0]
  0x44004811, 0x46002b07, 0x304437a0, 0x04370704,   // tt.kk.un_630 vi.qu.un_420  ba.kk.uz_322 bg.ba.ru_332 
  0x361327ee, 0x0d003004, 0x07150a12, 0x2e004007,   // gd.et.gn_422 uz.cs.un_320  mk.bg.un_640 lb.fo.un_420 
  0x0d084dee, 0x0f4a5ca7, 0x23401d55, 0x06793b11,   // aa.no.cs_422 sa.yo.lv_532  la.lb.ca_442 so.war.de_653 
  0x3e002214, 0x211d22ee, 0x130a40ad, 0x0600571b,   // oc.rm.un_660 oc.la.jw_422  lb.pt.et_643 na.de.un_770 
  // [1a3b0]
  0x2a000e19, 0x0f1b30ee, 0x22005707, 0x1b303e04,   // is.mt.un_750 uz.tr.lv_422  na.oc.un_420 rm.uz.tr_332 
  0x3308400c, 0x3b285807, 0x0b5a5012, 0x31381b05,   // lb.no.nn_543 om.sw.so_432  fj.sm.es_654 tr.tk.az_333 
  0x306579ee, 0x2f214eee, 0x05113e0c, 0x1800fc0b,   // war.gv.uz_422 ay.jw.su_422  rm.ro.fr_543 zzp.ga.un_520 
  0x2f4612ec, 0xfc006314, 0x1e005221, 0xfe330805,   // hu.qu.su_644 sco.zzp.un_660  ha.ms.un_860 no.nn.tlh_333 
  // [1a3c0]
  0x1b3111a4, 0x23020b04, 0x34510404, 0x11190b04,   // ro.az.tr_433 es.da.ca_332  fi.kl.xh_332 es.gl.ro_332 
  0x1b353414, 0x042c58a7, 0x540452ac, 0x350447a0,   // xh.zu.tr_666 om.fy.fi_532  ha.fi.ik_632 sn.fi.zu_322 
  0x30045fee, 0x465d010c, 0x34302105, 0x301d5daf,   // tn.fi.uz_422 en.ss.qu_543  fa.uz.ps_333 ss.la.uz_655 
  0x12600611, 0x58044dad, 0x04005121, 0x6551040c,   // de.vo.hu_653 aa.fi.om_643  kl.fi.un_860 fi.kl.gv_543 
  // [1a3d0]
  0x1c2101a4, 0x3bfe510d, 0x120d2dad, 0x2f6401a4,   // en.jw.id_433 kl.tlh.so_554  sk.cs.hu_643 en.lg.su_433 
  0x224a4cad, 0x35373002, 0x37443cec, 0x23003b11,   // wo.yo.oc_643 uz.ba.tg_222  ug.kk.ba_644 ks.ky.un_630 
  0x193b25a4, 0x344c3bee, 0x69024a08, 0x1d003b0c,   // eu.so.gl_433 so.wo.xh_422  yo.da.mfe_443 so.la.un_530 
  0x6b001a19, 0x0529fe07, 0x3b002919, 0x3700671a,   // tl.ceb.un_750 tlh.sl.fr_432  sl.so.un_750 ak.st.un_760 
  // [1a3e0]
  0x68004a35, 0x4a5b3b55, 0x424c5b08, 0x481508af,   // yo.ig.un_A90 so.sg.yo_442  sg.wo.co_443 uk.tt.un_650 
  0x0c3b0802, 0x0c0229ee, 0x0b19180c, 0x241001a0,   // no.so.sv_222 sl.da.sv_422  ga.gl.es_543 en.lt.eo_322 
  0x3b294d55, 0x21276807, 0x36000208, 0x0b2d0ead,   // aa.sl.so_442 ig.gd.jw_432  da.gn.un_430 is.sk.es_643 
  0x652e1f05, 0x3e1d64a4, 0x29092d12, 0x1d2633a0,   // cy.fo.gv_333 lg.la.rm_433  sk.pl.sl_654 nn.ia.la_322 
  // [1a3f0]
  0x11074608, 0x1000480b, 0x0b00fc04, 0x3035110d,   // qu.it.ro_443 tt.be.un_520  zzp.es.un_320 ro.tg.uz_554 
  0x3035250e, 0x03321605, 0x04032a07, 0x29041804,   // mn.tg.uz_555 hr.bs.nl_333  mt.nl.fi_432 ga.fi.sl_332 
  0x074204a9, 0x4a041311, 0x6b131d07, 0x17300404,   // fi.co.it_544 et.fi.yo_653  la.et.ceb_432 ru.uz.sr_332 
  0x3f236307, 0x443738a6, 0x40002c2a, 0x4f392c07,   // sco.ca.af_432 tk.ba.kk_521  fy.lb.un_970 fy.br.bi_432 
  
  // [1a400]
  0x6b000407, 0x28000409, 0x18004804, 0x2ffc0404,   // fi.ceb.un_420 fi.sw.un_440  tt.ga.un_320 fi.zzp.su_332 
  0x3537480b, 0x79220509, 0x36301107, 0x69053fa4,   // tt.ba.tg_542 fr.oc.war_444  ro.uz.ab_432 af.fr.mfe_433 
  0x25000212, 0x30282109, 0x25153c14, 0x1730380c,   // da.eu.un_640 fa.sd.uz_444  ug.mn.un_660 tk.uz.sr_543 
  0x18123b07, 0xfe2d0d5a, 0x1b4811a7, 0x353015ad,   // ks.ur.ar_432 cs.sk.tlh_553  ro.tt.tr_532 un.uz.tg_643 
  // [1a410]
  0x2e00fe13, 0x4900181a, 0x49001813, 0x460a49a4,   // tlh.fo.un_650 ga.to.un_760  ga.to.un_650 to.pt.qu_433 
  0x394006a0, 0x06395755, 0x122118a6, 0x0e264c0e,   // de.lb.br_322 na.br.de_442  ar.fa.ur_521 wo.ia.is_555 
  0x0c395707, 0x0e514cee, 0x0c394c07, 0x63396907,   // na.br.sv_432 wo.kl.is_422  wo.br.sv_432 mfe.br.sco_432 
  0x2e0e4a60, 0x4c3913a9, 0x0a360760, 0x243b2905,   // yo.is.fo_664 et.br.wo_544  bg.ab.mk_664 sl.so.eo_333 
  // [1a420]
  0x1d2402af, 0x1d0702a0, 0x07251508, 0x260207a9,   // da.eo.la_655 da.it.la_322  un.mn.bg_443 it.da.ia_544 
  0x61000b08, 0x381b0c12, 0x4b000402, 0x040a1505,   // es.za.un_430 sv.tr.tk_654  fi.mi.un_220 un.mk.ru_333 
  0x35345114, 0x5d003005, 0x0a070107, 0x0c650204,   // kl.xh.zu_666 uz.ss.un_330  en.it.pt_432 da.gv.sv_332 
  0x55645912, 0x6000121a, 0x38364fa9, 0x5955110c,   // rn.lg.rw_654 hu.vo.un_760  bi.gn.tk_544 ro.rw.rn_543 
  // [1a430]
  0x2a386207, 0x024d39a4, 0x392146ee, 0x491e1cad,   // kha.tk.mt_432 br.aa.da_433  qu.jw.br_422 id.ms.to_643 
  0x0402210c, 0x3b122814, 0x2f562a55, 0x341b1905,   // jw.da.fi_543 sd.ur.ks_666  mt.mg.su_442 gl.tr.xh_333 
  0x3e3b1108, 0xfc004a05, 0x4d0a2111, 0x1d031ea0,   // ro.so.rm_443 yo.zzp.un_330  jw.pt.aa_653 ms.nl.la_322 
  0x65fc57ec, 0x1b00040e, 0x1f005204, 0x2d353408,   // na.zzp.gv_644 fi.tr.un_550  ha.cy.un_320 xh.zu.sk_443 
  // [1a440]
  0x520f6108, 0x04124802, 0x3d442305, 0x025dfaaf,   // za.lv.ha_443 tt.hu.fi_222  ky.kk.ku_333 nr.ss.da_655 
  0x56390507, 0x42180507, 0x58475207, 0x213039a4,   // fr.br.mg_432 fr.ga.co_432  ha.sn.om_432 br.uz.jw_433 
  0x530f215a, 0x30fe4d11, 0x5d1b36a9, 0x470f100c,   // jw.lv.ht_553 aa.tlh.uz_653  gn.tr.ss_544 lt.lv.sn_543 
  0x3b2821af, 0x10170fa4, 0x53004009, 0x3600130d,   // jw.sw.so_655 lv.sr.lt_433  lb.ht.un_440 et.gn.un_540 
  // [1a450]
  0x3c21230c, 0x30353604, 0x17162402, 0x3b1d58a0,   // ky.fa.ug_543 ab.tg.uz_332  eo.hr.sr_222 om.la.so_322 
  0x25234813, 0x2b150107, 0x100f32a0, 0x181225a7,   // tt.ky.mn_665 en.vi.un_420  bs.lv.lt_322 eu.hu.ga_532 
  0x0c006013, 0x04170aa4, 0x041d51a4, 0x13046aa0,   // vo.sv.un_650 mk.sr.ru_433  kl.la.fi_433 haw.fi.et_322 
  0x3b001314, 0x6a4f28ec, 0x37004827, 0x42001f02,   // et.so.un_660 sw.bi.haw_644  tt.ba.un_940 cy.co.un_220 
  // [1a460]
  0x07423e13, 0x13045aa4, 0x3b13640e, 0x4e28450c,   // rm.co.it_665 sm.fi.et_433  lg.et.so_555 ln.sw.ay_543 
  0x110b23ad, 0x1b005307, 0x13005007, 0x0b000a07,   // ca.es.ro_643 ht.tr.un_420  fj.et.un_420 pt.es.un_420 
  0x233625ee, 0x301e27a4, 0x28001f02, 0x48313821,   // mn.ab.ky_422 gd.ms.uz_433  cy.sw.un_220 tk.az.tt_876 
  0x36004d18, 0x48441009, 0x2d004a11, 0x381b0cac,   // aa.gn.un_740 be.kk.tt_444  yo.sk.un_630 sv.tr.tk_632 
  // [1a470]
  0x0e004d11, 0x1200310d, 0x321720ee, 0x04000e02,   // aa.is.un_630 az.hu.un_540  sq.sr.bs_422 is.fi.un_220 
  0x28181ba4, 0x48120ea0, 0x2d232ea0, 0x04000e07,   // tr.ga.sw_433 is.hu.tt_322  fo.ca.sk_322 is.fi.un_420 
  0x120e04ee, 0x480a17ee, 0x0a073ca0, 0x054012ec,   // fi.is.hu_422 sr.mk.tt_422  ug.bg.mk_322 hu.lb.fr_644 
  0x07000812, 0x213b1807, 0x17070805, 0x48285507,   // uk.bg.un_640 ga.so.jw_432  uk.bg.sr_333 rw.sw.tt_432 
  // [1a480]
  0x27005c02, 0x24020302, 0x031d5d0c, 0x442118a4,   // sa.gd.un_220 nl.da.eo_222  ss.la.nl_543 ar.fa.kk_433 
  0x35252312, 0x08113511, 0x0742400c, 0x28005413,   // ky.mn.tg_654 tg.ro.uk_653  lb.co.it_543 ik.sw.un_650 
  0x30081055, 0x583b13a9, 0x0f3b1307, 0x03793faf,   // be.uk.uz_442 et.so.om_544  et.so.lv_432 af.war.nl_655 
  0x04581355, 0x64583b07, 0x381b0e11, 0x4b256aec,   // et.om.fi_442 so.om.lg_432  is.tr.tk_653 haw.eu.mi_644 
  // [1a490]
  0x311b0c0c, 0x13003b09, 0x075a2507, 0x1b000c12,   // sv.tr.az_543 so.et.un_440  eu.sm.it_432 sv.tr.un_640 
  0x0a36350b, 0x380e1b55, 0x073715a0, 0x390711ee,   // tg.ab.mk_542 tr.is.tk_442  un.ba.bg_322 ro.it.br_422 
  0x045813ac, 0x13582c04, 0x5a4b2507, 0x17041007,   // et.om.fi_632 fy.om.et_332  eu.mi.sm_432 be.ru.sr_432 
  0x3b135813, 0x3b7313ee, 0x380c48a0, 0x31000402,   // om.et.so_665 et.ny.so_422  tt.sv.tk_322 fi.az.un_220 
  // [1a4a0]
  0x3800361b, 0x3c00120c, 0x113e2205, 0x030f2004,   // ab.tk.un_770 ur.ug.un_530  oc.rm.ro_333 sq.lv.nl_332 
  0x21004908, 0x173011a7, 0x3b460305, 0x21233c5a,   // to.jw.un_430 ro.uz.sr_532  nl.qu.so_333 ug.ky.fa_553 
  0x153530a9, 0x48370408, 0x4d000d13, 0x35043002,   // uz.tg.un_544 ru.ba.tt_443  cs.aa.un_650 uz.ru.tg_222 
  0x37444814, 0x18000d12, 0x30153604, 0x30005112,   // tt.kk.ba_666 cs.ga.un_640  ab.uz.un_320 kl.uz.un_640 
  // [1a4b0]
  0x2d2e0e60, 0x1000481b, 0x25041507, 0x233530a0,   // is.fo.sk_664 tt.lt.un_770  un.ru.mn_432 uz.tg.ky_322 
  0x2400fc19, 0x182d0dec, 0x53fc1dee, 0x094006a6,   // zzp.eo.un_750 cs.sk.ga_644  la.zzp.ht_422 de.lb.pl_521 
  0x621e1c08, 0x29006508, 0x151f01a0, 0x441048ec,   // id.ms.kha_443 gv.sl.un_430  en.cy.un_322 tt.be.kk_644 
  0x271518a0, 0x38483ca4, 0x28521ea0, 0x23251512,   // ga.gd.un_320 ug.tt.tk_433  ms.ha.sw_322 un.mn.ky_654 
  // [1a4c0]
  0x5001630d, 0x0a173caf, 0x39483402, 0x5600630c,   // sco.en.fj_554 ug.sr.mk_655  xh.tt.br_222 sco.mg.un_530 
  0x2b002204, 0x03004904, 0x48153755, 0x2a633ea9,   // oc.vi.un_320 to.nl.un_320  ba.tt.un_420 rm.sco.mt_544 
  0x04252304, 0x23303809, 0x480339a0, 0x362d5c05,   // ca.eu.fi_332 tk.uz.ky_444  br.nl.tt_322 sa.sk.gn_333 
  0x35301702, 0x60033f60, 0x3f06600c, 0x072405af,   // sr.uz.tg_222 af.nl.vo_664  vo.de.af_543 fr.eo.it_655 
  // [1a4d0]
  0x40001807, 0x224a1904, 0x071336ee, 0x2a500705,   // ga.lb.un_420 gl.yo.oc_332  gn.et.it_422 it.fj.mt_333 
  0x13006007, 0x07084804, 0x343b3dec, 0x18190b13,   // vo.et.un_420 tt.uk.bg_332  ku.ks.ps_644 es.gl.ga_665 
  0x276539a4, 0x42006504, 0x480a0704, 0x36000d17,   // br.gv.gd_433 gv.co.un_320  bg.mk.tt_332 cs.gn.un_730 
  0x37234860, 0x28122304, 0x082747a0, 0x2f2112a7,   // tt.ky.ba_664 ky.ur.sd_332  sn.gd.no_322 hu.jw.su_532 
  // [1a4e0]
  0x28220aa4, 0x04435aee, 0x190b0a5a, 0x47241b04,   // pt.oc.sw_433 sm.ie.fi_422  pt.es.gl_553 tr.eo.sn_332 
  0x0442250e, 0x1b002802, 0x09006213, 0x5c007304,   // eu.co.fi_555 sw.tr.un_220  kha.pl.un_650 ny.sa.un_320 
  0x275c3b08, 0x4c052fad, 0x09391308, 0x0900360b,   // so.sa.gd_443 su.fr.wo_643  et.br.pl_443 gn.pl.un_520 
  0x27005c0d, 0x29000d17, 0x190b0902, 0x253723ee,   // sa.gd.un_540 cs.sl.un_730  pl.es.gl_222 ky.ba.mn_422 
  // [1a4f0]
  0x4b002911, 0x201209ec, 0x18020907, 0x34001504,   // sl.mi.un_630 pl.hu.sq_644  pl.da.ga_432 un.xh.un_320 
  0x53631507, 0x791209ec, 0x1a6a5aad, 0x10151505,   // un.sco.ht_432 pl.hu.war_644  sm.haw.tl_643 un.be.un_330 
  0x35464e12, 0x3b02300c, 0x30483807, 0x122009ee,   // ay.qu.zu_654 uz.da.so_543  tk.tt.uz_432 pl.sq.hu_422 
  0x64464e12, 0xfe646a5a, 0x3904fc07, 0x54005136,   // ay.qu.lg_654 haw.lg.tlh_553  zzp.fi.br_432 kl.ik.un_AA0 
  // [1a500]
  0x1300042c, 0x57001d22, 0x583e180c, 0x620c33ec,   // fi.et.un_990 la.na.un_870  ga.rm.om_543 nn.sv.kha_644 
  0x203e3b07, 0x60006b2a, 0x0e042eaf, 0x2527760c,   // so.rm.sq_432 ceb.vo.un_970  fo.fi.is_655 crs.gd.eu_543 
  0x49027808, 0x25313005, 0x07423ea0, 0x53001c07,   // ve.da.to_443 uz.az.eu_333  rm.co.it_322 id.ht.un_420 
  0x0a005202, 0x04020cee, 0x51521e07, 0x6a215ca9,   // ha.pt.un_220 sv.da.fi_422  ms.ha.kl_432 sa.jw.haw_544 
  // [1a510]
  0x465848ec, 0x521a28a9, 0x3b1a5a11, 0x32132a5a,   // tt.om.qu_644 sw.tl.ha_544  sm.tl.so_653 mt.et.bs_553 
  0x100a305a, 0x1e00380c, 0x0400621a, 0x3000560c,   // uz.mk.be_553 tk.ms.un_530  kha.fi.un_760 mg.uz.un_530 
  0x21002a12, 0x0d000e0e, 0x10443808, 0x4200070b,   // mt.jw.un_640 is.cs.un_550  tk.kk.be_443 it.co.un_520 
  0x0e00450d, 0x304003a0, 0x0400120c, 0x090d1c60,   // ln.is.un_540 nl.lb.uz_322  hu.fi.un_530 mr.ne.hi_664 
  // [1a520]
  0x1f0c3612, 0x47002502, 0x1c507904, 0x20230aa4,   // gn.sv.cy_654 eu.sn.un_220  war.fj.id_332 pt.ca.sq_433 
  0x0e00220e, 0x020c20a4, 0x656336ee, 0x00001e37,   // oc.is.un_550 sq.sv.da_433  gn.sco.gv_422 am.un.un_B00 
  0x230a22af, 0x1800400c, 0x06000c11, 0x22000e0c,   // oc.pt.ca_655 lb.ga.un_530  sv.de.un_630 is.oc.un_530 
  0x484438ad, 0x0d002e0b, 0x64355d55, 0x311b53a0,   // tk.kk.tt_643 fo.cs.un_520  ss.zu.lg_442 ht.tr.az_322 
  // [1a530]
  0x6300690d, 0x181d1507, 0x524b2408, 0x02132508,   // mfe.sco.un_540 un.la.ga_432  eo.mi.ha_443 eu.et.da_443 
  0x2450675a, 0x73136413, 0x565507ad, 0x2c004202,   // ak.fj.eo_553 lg.et.ny_665  it.rw.mg_643 co.fy.un_220 
  0x64001313, 0x21000723, 0x10296805, 0x34023fa4,   // et.lg.un_650 it.jw.un_880  ig.sl.lt_333 af.da.xh_433 
  0x512724a0, 0x444838ad, 0x672f5b0c, 0x4700681a,   // eo.gd.kl_322 tk.tt.kk_643  sg.su.ak_543 ig.sn.un_760 
  // [1a540]
  0x22006504, 0x19670b0c, 0x255668ad, 0x79005b12,   // gv.oc.un_320 es.ak.gl_543  ig.mg.eu_643 sg.war.un_640 
  0x080430ee, 0x1e1c52a0, 0x4a794b04, 0x685b670d,   // uz.ru.uk_422 ha.id.ms_322  mi.war.yo_332 ak.sg.ig_554 
  0x12046907, 0x13396407, 0x4b214faf, 0x25381308,   // mfe.fi.hu_432 lg.br.et_432  bi.jw.mi_655 et.tk.eu_443 
  0x50003b13, 0x56005b07, 0x04006919, 0x42006a07,   // so.fj.un_650 sg.mg.un_420  mfe.fi.un_750 haw.co.un_420 
  // [1a550]
  0x214a6808, 0x162f30a7, 0x2f313ba0, 0x2d3923a0,   // ig.yo.jw_443 uz.su.hr_532  so.az.su_322 ca.br.sk_322 
  0x190a120c, 0x0638480c, 0x11002b0c, 0x130c480b,   // hu.pt.gl_543 tt.tk.de_543  vi.ro.un_530 tt.sv.et_542 
  0x0b0a36a0, 0x0d0a0eed, 0x4423380e, 0x0a4815a0,   // gn.pt.es_322 is.pt.cs_622  tk.ky.kk_555 un.tt.mk_322 
  0x60004e1a, 0x1c004807, 0xfc353404, 0x3e004f07,   // ay.vo.un_760 tt.id.un_420  xh.zu.zzp_332 bi.rm.un_420 
  // [1a560]
  0x653963a0, 0x60004e13, 0x3c4438a4, 0x07152513,   // sco.br.gv_322 ay.vo.un_650  tk.kk.ug_433 mn.bg.un_650 
  0x190b57ec, 0x0b3919a7, 0x100408ad, 0x2505190c,   // na.es.gl_644 gl.br.es_532  uk.ru.be_643 gl.fr.eu_543 
  0x5c0f4ead, 0x383748a4, 0x30125ca0, 0x07481508,   // ay.lv.sa_643 tt.ba.tk_433  sa.hu.uz_322 un.tt.bg_443 
  0x55005204, 0x0e003908, 0x38070a08, 0x73003509,   // ha.rw.un_320 br.is.un_430  mk.bg.tk_443 zu.ny.un_440 
  // [1a570]
  0x6b5c4e12, 0x10000202, 0x341844ee, 0x080c5c07,   // ay.sa.ceb_654 da.lt.un_220  kk.ar.ps_422 sa.sv.no_432 
  0x23073804, 0x234e5c12, 0x460c4e07, 0x5c001605,   // tk.bg.ky_332 sa.ay.ca_654  ay.sv.qu_432 hr.sa.un_330 
  0x48233014, 0x36002d04, 0x51002c05, 0x4a190b05,   // uz.ky.tt_666 sk.gn.un_320  fy.kl.un_330 es.gl.yo_333 
  0x4a4c36a0, 0x2548100c, 0x5c1029a4, 0x3b12fca9,   // gn.wo.yo_322 be.tt.mn_543  sl.lt.sa_433 zzp.hu.so_544 
  // [1a580]
  0x12fc3b07, 0x0112fca7, 0x1200fc0c, 0xfc124da7,   // so.zzp.hu_432 zzp.hu.en_532  zzp.hu.un_530 aa.hu.zzp_532 
  0x4804380b, 0x0448380c, 0x1700120c, 0x6b6801ee,   // tk.fi.tt_542 tk.tt.fi_543  hu.sr.un_530 en.ig.ceb_422 
  0x28150204, 0xfefc0307, 0x135c3ba0, 0x330c02a4,   // da.sw.un_320 nl.zzp.tlh_432  ks.sa.bh_322 da.sv.nn_433 
  0x62006e21, 0x2500670e, 0x5e220aad, 0x0b0a3609,   // hmn.kha.un_860 ak.eu.un_550  pt.oc.ts_643 gn.pt.es_444 
  // [1a590]
  0x4300620d, 0x47282160, 0x272118af, 0x1d00201e,   // kha.ie.un_540 jw.sw.sn_664  ga.jw.gd_655 sq.la.un_830 
  0x4207650b, 0x072b1102, 0x18472704, 0x1d283e0c,   // gv.it.co_542 ro.vi.it_222  gd.sn.ga_332 rm.sw.la_543 
  0x1a6e1f12, 0x10080a04, 0x20006e08, 0x1f3567a0,   // cy.hmn.tl_654 mk.uk.be_332  hmn.sq.un_430 ak.zu.cy_322 
  0x301735ad, 0x131104a9, 0x6468280c, 0x583b30a4,   // tg.sr.uz_643 fi.ro.et_544  sw.ig.lg_543 uz.so.om_433 
  // [1a5a0]
  0x5b1d26ec, 0x0339fcee, 0x02fc5105, 0x0651fc04,   // ia.la.sg_644 zzp.br.nl_422  kl.zzp.da_333 zzp.kl.de_332 
  0x0e56fc07, 0x03062c02, 0x0cfc0205, 0x2d0d3205,   // zzp.mg.is_432 fy.de.nl_222  da.zzp.sv_333 bs.cs.sk_333 
  0x36003804, 0x06400108, 0x1dfc01a4, 0x3f080202,   // tk.ab.un_320 en.lb.de_443  en.zzp.la_433 da.no.af_222 
  0x1d2201a0, 0x253748af, 0x6b003e04, 0x120c1304,   // en.oc.la_322 tt.ba.mn_655  rm.ceb.un_320 et.sv.hu_332 
  // [1a5b0]
  0x33082a0c, 0x0c2a1207, 0x2a4c0604, 0x0a1038ee,   // mt.no.nn_543 hu.mt.sv_432  de.wo.mt_332 tk.be.mk_422 
  0x07040a11, 0x51022e04, 0x2a330813, 0x3015380d,   // mk.ru.bg_653 fo.da.kl_332  no.nn.mt_665 tk.uz.un_540 
  0x0e1353a0, 0x2a001213, 0x23213455, 0x3e00390d,   // ht.et.is_322 hu.mt.un_650  ps.fa.ky_442 br.rm.un_540 
  0x0e670455, 0x04391b0c, 0x3e050455, 0x554007a0,   // fi.ak.is_442 tr.br.fi_543  fi.fr.rm_442 it.lb.rw_322 
  // [1a5c0]
  0x12fe3907, 0x6300390d, 0x1d3f20ac, 0x323534ee,   // br.tlh.hu_432 br.sco.un_540  sq.af.la_632 xh.zu.bs_422 
  0x0a230404, 0x064067ee, 0x076704a4, 0x0a071004,   // ru.ky.mk_332 ak.lb.de_422  fi.ak.it_433 be.bg.mk_332 
  0x083710a4, 0x59556808, 0x3e000e0e, 0x15073005,   // be.ba.uk_433 ig.rw.rn_443  is.rm.un_550 uz.bg.un_333 
  0x593455af, 0x10282507, 0x0b041007, 0x28102508,   // rw.xh.rn_655 eu.sw.lt_432  lt.fi.es_432 eu.lt.sw_443 
  // [1a5d0]
  0x2f1c4da4, 0x3965060b, 0x0cfe6eee, 0x02005602,   // aa.id.su_433 de.gv.br_542  hmn.tlh.sv_422 mg.da.un_220 
  0x4718270c, 0x4f00730e, 0x4d00601a, 0x2d2009a0,   // gd.ga.sn_543 ny.bi.un_550  vo.aa.un_760 pl.sq.sk_322 
  0x6534fcee, 0x48002805, 0x2f003f0c, 0x30040aa0,   // zzp.xh.gv_422 sw.tt.un_330  af.su.un_530 mk.ru.uz_322 
  0x361f5ead, 0x63285507, 0x28001012, 0x5e006112,   // ts.cy.gn_643 rw.sw.sco_432  lt.sw.un_640 za.ts.un_640 
  // [1a5e0]
  0x350c5c0c, 0x36001f09, 0x1c210207, 0x0760430c,   // sa.sv.zu_543 cy.gn.un_440  da.jw.id_432 ie.vo.it_543 
  0x2d600da4, 0x1d002017, 0x17003705, 0x371560a4,   // cs.vo.sk_433 sq.la.un_730  ba.sr.un_330 vo.st.un_430 
  0x4800fc07, 0x4a005909, 0x0f101704, 0x51005707,   // zzp.tt.un_420 rn.yo.un_440  sr.lt.lv_332 na.kl.un_420 
  0x4c002017, 0x65003911, 0x3f395ea0, 0x29003f04,   // sq.wo.un_730 br.gv.un_630  ts.br.af_322 af.sl.un_320 
  // [1a5f0]
  0x04084808, 0x2307040b, 0x39001708, 0x3e003f04,   // tt.uk.ru_443 ru.bg.ky_542  sr.br.un_430 af.rm.un_320 
  0x562851ad, 0x2d0d0407, 0x523b21ec, 0x28024b05,   // kl.sw.mg_643 fi.cs.sk_432  jw.so.ha_644 mi.da.sw_333 
  0x244d56ec, 0x4b003704, 0x644925ad, 0x044a790b,   // mg.aa.eo_644 st.mi.un_320  eu.to.lg_643 war.yo.fi_542 
  0x4d103b08, 0x0d362da7, 0x341821af, 0x3b4752a4,   // so.lt.aa_443 sk.gn.cs_532  fa.ar.ps_655 ha.sn.so_433 
  // [1a600]
  0x0865390c, 0x44230404, 0x3e564d07, 0x28545113,   // br.gv.no_543 ru.ky.kk_332  aa.mg.rm_432 kl.ik.sw_665 
  0x3b583007, 0x4b00470e, 0x4b505209, 0x05004c09,   // uz.om.so_432 sn.mi.un_550  ha.fj.mi_444 wo.fr.un_440 
  0x2d09360c, 0x530b1507, 0x6300040d, 0x0a2348a0,   // gn.pl.sk_543 un.es.ht_432  fi.sco.un_540 tt.ky.mk_322 
  0x081023a4, 0x233c3008, 0x1234210e, 0x1035300c,   // ky.be.uk_433 uz.ug.ky_443  fa.ps.ur_555 uz.tg.be_543 
  // [1a610]
  0x35482502, 0x2e000402, 0x2b001102, 0x05004c0e,   // mn.tt.tg_222 fi.fo.un_220  ro.vi.un_220 wo.fr.un_550 
  0x2d0d510c, 0x49505aa9, 0x10563e0c, 0x13245611,   // kl.cs.sk_543 sm.fj.to_544  rm.mg.lt_543 mg.eo.et_653 
  0x3960500c, 0x51100307, 0x12441811, 0x0a004a07,   // fj.vo.br_543 nl.lt.kl_432  ar.kk.ur_653 yo.pt.un_420 
  0x131036ee, 0x55007302, 0x50000f0d, 0x56575007,   // gn.lt.et_422 ny.rw.un_220  lv.fj.un_540 fj.na.mg_432 
  // [1a620]
  0x10030ead, 0x30555aa4, 0x30005d0c, 0x65fc1807,   // is.nl.lt_643 sm.rw.uz_433  ss.uz.un_530 ga.zzp.gv_432 
  0x182f05ee, 0x02001819, 0x2f00fe07, 0x1800790b,   // fr.su.ga_422 ga.da.un_750  tlh.su.un_420 war.ga.un_520 
  0x5d005505, 0x05fe2204, 0x023407a4, 0x3635250c,   // rw.ss.un_330 oc.tlh.fr_332  it.xh.da_433 mn.tg.ab_543 
  0x371b2f05, 0x22000522, 0x1bfe34ec, 0x5a00530c,   // su.tr.st_333 fr.oc.un_870  xh.tlh.tr_644 ht.sm.un_530 
  // [1a630]
  0x211234af, 0x4b004c04, 0xfe4e29a4, 0x05022208,   // ps.ur.fa_655 wo.mi.un_320  sl.ay.tlh_433 oc.da.fr_443 
  0x28171605, 0x644717a0, 0x32002809, 0x2b001308,   // hr.sr.sw_333 sr.sn.lg_322  sw.bs.un_440 et.vi.un_430 
  0x1b31300d, 0x2a1d3ba4, 0x79001a0e, 0x221d46ee,   // uz.az.tr_554 so.la.mt_433  tl.war.un_550 qu.la.oc_422 
  0x3b3e1304, 0x3b301d05, 0x153607a7, 0x79003019,   // et.rm.so_332 la.uz.so_333  bg.ab.un_532 uz.war.un_750 
  // [1a640]
  0xfc460ba0, 0x0d0833ee, 0x04563907, 0x304807a0,   // es.qu.zzp_322 nn.no.cs_422  br.mg.fi_432 bg.tt.uz_322 
  0x210118a4, 0x30567912, 0x10003407, 0x04005e1a,   // ar.iw.fa_433 war.mg.uz_654  xh.lt.un_420 ts.fi.un_760 
  0x1d002623, 0x212f1c5a, 0x5e006008, 0x1900180b,   // ia.la.un_880 id.su.jw_553  vo.ts.un_430 ga.gl.un_520 
  0x38102da7, 0x42003e12, 0x302c2404, 0x152510ec,   // sk.lt.tk_532 rm.co.un_640  eo.fy.uz_332 be.mn.un_644 
  // [1a650]
  0x03001313, 0x06576308, 0x69005719, 0x7900070e,   // et.nl.un_650 sco.na.de_443  na.mfe.un_750 it.war.un_550 
  0x1e2139a0, 0x64392402, 0x783534a9, 0x131f65a7,   // br.jw.ms_322 eo.br.lg_222  xh.zu.ve_544 gv.cy.et_532 
  0x3831200c, 0x73784760, 0x3d3418ee, 0x56641008,   // sq.az.tk_543 sn.ve.ny_664  ar.ps.ku_422 lt.lg.mg_443 
  0x276b06ee, 0x095369ad, 0x3e081807, 0x65271360,   // de.ceb.gd_422 mfe.ht.pl_643  ga.no.rm_432 et.gd.gv_664 
  // [1a660]
  0x47004f12, 0x06296502, 0x234425a0, 0x152325a0,   // bi.sn.un_640 gv.sl.de_222  mn.kk.ky_322 eu.ca.un_322 
  0x07190b14, 0x36051211, 0x212f4a04, 0x0810350c,   // es.gl.it_666 hu.fr.gn_653  yo.su.jw_332 tg.be.uk_543 
  0x0b0522a0, 0x373830a4, 0x653f1802, 0x2800131a,   // oc.fr.es_322 uz.tk.ba_433  ga.af.gv_222 et.sw.un_760 
  0x0c002210, 0x050a4ca0, 0x224c05ee, 0x213c2305,   // oc.sv.un_620 wo.pt.fr_322  fr.wo.oc_422 ky.ug.fa_333 
  // [1a670]
  0x040723a7, 0x184f02ec, 0x44000a0c, 0x3f0365ec,   // ky.bg.ru_532 da.bi.ga_644  mk.kk.un_530 gv.nl.af_644 
  0x204033a0, 0x0b36121e, 0x3e182705, 0x2223430c,   // nn.lb.sq_322 hu.gn.es_863  gd.ga.rm_333 ie.ca.oc_543 
  0x420540a4, 0x150a1505, 0x10360707, 0x512354af,   // lb.fr.co_433 un.mk.un_333  bg.ab.be_432 ik.ca.kl_655 
  0x4f006509, 0x6b182711, 0x054c4008, 0x054c4007,   // gv.bi.un_440 gd.ga.ceb_653  lb.wo.fr_443 lb.wo.fr_432 
  // [1a680]
  0x36002f09, 0x6b011507, 0x4000190d, 0x303c3d05,   // su.gn.un_440 un.en.ceb_432  gl.lb.un_540 ku.ug.uz_333 
  0x4b00780c, 0x502447a9, 0x084815a7, 0x5c5e470c,   // ve.mi.un_530 sn.eo.fj_544  un.tt.uk_532 sn.ts.sa_543 
  0x434278a4, 0x10000309, 0x32245207, 0x1f5704a4,   // ve.co.ie_433 nl.lt.un_440  ha.eo.bs_432 fi.na.cy_433 
  0x3f031f09, 0x04003f13, 0x373623a0, 0x4c007804,   // cy.nl.af_444 af.fi.un_650  ky.ab.ba_322 ve.wo.un_320 
  // [1a690]
  0x08071514, 0x1f3e10ec, 0x1800050e, 0x33004602,   // un.bg.uk_666 lt.rm.cy_644  fr.ga.un_550 qu.nn.un_220 
  0x39004802, 0x0a0b1960, 0x3e004b08, 0x63495255,   // tt.br.un_220 gl.es.pt_664  mi.rm.un_430 ha.to.sco_442 
  0x1100201b, 0x12652805, 0x26016305, 0x3f401f07,   // sq.ro.un_770 sw.gv.hu_333  sco.en.ia_333 cy.lb.af_432 
  0x53001804, 0x1f040f55, 0x1822120c, 0x303548a4,   // ga.ht.un_320 lv.fi.cy_442  hu.oc.ga_543 tt.tg.uz_433 
  // [1a6a0]
  0x06120aa4, 0x290d12af, 0x460dfea9, 0x0b1912a9,   // pt.hu.de_433 hu.cs.sl_655  tlh.cs.qu_544 hu.gl.es_544 
  0x1b476411, 0x050a4002, 0x641124a4, 0x21303d55,   // lg.sn.tr_653 lb.pt.fr_222  eo.ro.lg_433 ku.uz.fa_442 
  0x64474207, 0x29000d19, 0x230438a6, 0x120d2012,   // co.sn.lg_432 cs.sl.un_750  tk.ru.ky_521 sq.cs.hu_654 
  0x0d2012ee, 0x170810a7, 0x103638ad, 0x59355513,   // hu.sq.cs_422 be.uk.sr_532  tk.ab.be_643 rw.zu.rn_665 
  // [1a6b0]
  0x2d120daf, 0x0c1213a0, 0x05001211, 0x2e630604,   // cs.hu.sk_655 et.hu.sv_322  hu.fr.un_630 de.sco.fo_332 
  0x151525a4, 0x0c3031a0, 0x213c3d02, 0x43633007,   // mn.un.un_430 az.uz.sv_322  ku.ug.fa_222 uz.sco.ie_432 
  0x19004d0b, 0x13004b02, 0x304831ee, 0x25304855,   // aa.gl.un_520 mi.et.un_220  az.tt.uz_422 tt.uz.mn_442 
  0x2f1218ee, 0x18004018, 0x63003113, 0x02004321,   // ga.hu.su_422 lb.ga.un_740  az.sco.un_650 ie.da.un_860 
  // [1a6c0]
  0x18404aee, 0x053f230c, 0x18004013, 0x69000d04,   // yo.lb.ga_422 ca.af.fr_543  lb.ga.un_650 cs.mfe.un_320 
  0x023b6805, 0x57473b08, 0x033f0607, 0x305c0208,   // ig.so.da_333 so.sn.na_443  de.af.nl_432 da.sa.uz_443 
  0x6400022b, 0x033f62ee, 0x3b5c02ec, 0x5c55590c,   // da.lg.un_980 kha.af.nl_422  da.sa.so_644 rn.rw.sa_543 
  0x154318a7, 0x64003b14, 0x1a79020c, 0x05001b12,   // ga.ie.un_532 so.lg.un_660  da.war.tl_543 tr.fr.un_640 
  // [1a6d0]
  0x3b6b6414, 0x2f3534ee, 0x5e6455a9, 0x3b005522,   // lg.ceb.so_666 xh.zu.su_422  rw.lg.ts_544 rw.so.un_870 
  0x3b3242a0, 0x55311d07, 0x3f1f0807, 0x11005504,   // co.bs.so_322 la.az.rw_432  no.cy.af_432 rw.ro.un_320 
  0x351e1d02, 0x5c592811, 0x0f330804, 0x3b641f0c,   // la.ms.zu_222 sw.rn.sa_653  no.nn.lv_332 cy.lg.so_543 
  0x6400360d, 0x475364a4, 0x5955790e, 0x5a04020c,   // gn.lg.un_540 lg.ht.sn_433  war.rw.rn_555 da.fi.sm_543 
  // [1a6e0]
  0x221101a0, 0x55005d08, 0x42111ba7, 0x67125eaf,   // en.ro.oc_322 ss.rw.un_430  tr.ro.co_532 ts.hu.ak_655 
  0x4200500d, 0x150411ee, 0x0954510b, 0x2f6b4c04,   // fj.co.un_540 ro.ru.un_422  kl.ik.pl_542 wo.ceb.su_332 
  0x2f000516, 0x1936120c, 0x24005212, 0x234f25ad,   // fr.su.un_720 hu.gn.gl_543  ha.eo.un_640 eu.bi.ca_643 
  0x1a4f4dad, 0x632e2aa4, 0x381023af, 0x0458630c,   // aa.bi.tl_643 mt.fo.sco_433  ky.be.tk_655 sco.om.fi_543 
  // [1a6f0]
  0x26530107, 0x221d28ec, 0x1a2f6b07, 0x0e180404,   // en.ht.ia_432 sw.la.oc_644  ceb.su.tl_432 fi.ga.is_332 
  0x602e20a4, 0x2a20460e, 0x37005504, 0x1f002209,   // sq.fo.vo_433 qu.sq.mt_555  rw.st.un_320 oc.cy.un_440 
  0x1d005807, 0x191d1308, 0x631131a4, 0x10083707,   // om.la.un_420 et.la.gl_443  az.ro.sco_433 ba.uk.be_432 
  0x135856a4, 0x04635855, 0x28123da0, 0x29002a02,   // mg.om.et_433 om.sco.fi_442  ku.ur.sd_322 mt.sl.un_220 
  // [1a700]
  0x51003005, 0x2812180d, 0x1b2e630c, 0x2200580c,   // uz.kl.un_330 ar.ur.sd_554  sco.fo.tr_543 om.oc.un_530 
  0x1538040e, 0x15004712, 0x1f2c0e07, 0x202b460c,   // ru.tk.un_555 sn.un.un_640  is.fy.cy_432 qu.vi.sq_543 
  0x30002320, 0x0e082e05, 0x54004614, 0x512e0ead,   // ky.uz.un_850 fo.no.is_333  qu.ik.un_660 is.fo.kl_643 
  0x355534a4, 0x18400607, 0x060e2e0e, 0x23353005,   // xh.rw.zu_433 de.lb.ga_432  fo.is.de_555 uz.tg.ky_333 
  // [1a710]
  0x2d0d0b02, 0x332e0ea0, 0x13052205, 0x23382512,   // es.cs.sk_222 is.fo.nn_322  oc.fr.et_333 mn.tk.ky_654 
  0x10483811, 0x5d002d0c, 0x51000e1a, 0x0a36350c,   // tk.tt.be_653 sk.ss.un_530  is.kl.un_760 tg.ab.mk_543 
  0x0e5158a0, 0x05422ead, 0x342318ad, 0x17003813,   // om.kl.is_322 fo.co.fr_643  ar.ky.ps_643 tk.sr.un_650 
  0x134005a7, 0x0b000d07, 0x20006508, 0x33584004,   // fr.lb.et_532 cs.es.un_420  gv.sq.un_430 lb.om.nn_332 
  // [1a720]
  0x125806a0, 0x2e0c4e04, 0x33005802, 0x0c134ca0,   // de.om.hu_322 ay.sv.fo_332  om.nn.un_220 wo.et.sv_322 
  0xfc00110c, 0x21460d0c, 0x213f4eee, 0x18002f02,   // ro.zzp.un_530 cs.qu.jw_543  ay.af.jw_422 su.ga.un_220 
  0x054222a0, 0x58006509, 0x583308a7, 0x0c582a08,   // oc.co.fr_322 gv.om.un_440  no.nn.om_532 mt.om.sv_443 
  0x246301a4, 0xfc00270e, 0x520e51a4, 0x33002a12,   // en.sco.eo_433 gd.zzp.un_550  kl.is.ha_433 mt.nn.un_640 
  // [1a730]
  0x4c612fa7, 0x54514da4, 0x05461207, 0x080425a0,   // su.za.wo_532 aa.kl.ik_433  hu.qu.fr_432 mn.ru.uk_322 
  0x34672ca4, 0x02005219, 0x23005e02, 0x020451a4,   // fy.ak.xh_433 ha.da.un_750  ts.ca.un_220 kl.fi.da_433 
  0x581d3baf, 0x422f01a0, 0x12585107, 0x4c1d01a4,   // so.la.om_655 en.su.co_322  kl.om.hu_432 en.la.wo_433 
  0x3b30460d, 0x12000518, 0x3400670b, 0x21522f08,   // qu.uz.so_554 fr.hu.un_740  ak.xh.un_520 su.ha.jw_443 
  // [1a740]
  0x6435340e, 0x3605120c, 0x083525ee, 0x34393504,   // xh.zu.lg_555 hu.fr.gn_543  mn.tg.uk_422 zu.br.xh_332 
  0x35110a0b, 0x043064a0, 0x20110907, 0xfe0405a4,   // mk.ro.tg_542 lg.uz.fi_322  pl.ro.sq_432 fr.fi.tlh_433 
  0x0c06520d, 0x13002e0b, 0x3bfe510c, 0x2c0e13a7,   // ha.de.sv_554 fo.et.un_520  kl.tlh.so_543 et.is.fy_532 
  0x28003b23, 0x18213c04, 0x13000a09, 0x04002511,   // ks.sd.un_880 ug.fa.ar_332  pt.et.un_440 mn.ru.un_630 
  // [1a750]
  0x2f00210b, 0x4c4205a7, 0x051dfca7, 0x21004c0d,   // jw.su.un_520 fr.co.wo_532  zzp.la.fr_532 wo.jw.un_540 
  0x4b472fa4, 0x4811440e, 0x5d3462ec, 0x58390107,   // su.sn.mi_433 kk.ro.tt_555  kha.xh.ss_644 en.br.om_432 
  0x55025da0, 0x2201230c, 0x62003e19, 0x5cfc05a0,   // ss.da.rw_322 ca.en.oc_543  rm.kha.un_750 fr.zzp.sa_322 
  0x34002505, 0x053e5055, 0x05fc010c, 0x404205ac,   // eu.xh.un_330 fj.rm.fr_442  en.zzp.fr_543 fr.co.lb_632 
  // [1a760]
  0x1100fe0e, 0x39052fee, 0x2f4c0504, 0x48150a07,   // tlh.ro.un_550 su.fr.br_422  fr.wo.su_332 mk.tt.un_420 
  0x440708a0, 0x2d054c55, 0x44482312, 0x0a10170c,   // uk.bg.kk_322 wo.fr.sk_442  ky.tt.kk_654 sr.be.mk_543 
  0x3e0a11ad, 0x2f004c0b, 0x041c0204, 0x302e13a4,   // ro.pt.rm_643 wo.su.un_520  da.id.fi_332 et.fo.uz_433 
  0x05212f07, 0x5a4b6aee, 0x1a436304, 0x3e4b6aee,   // su.jw.fr_432 haw.mi.sm_422  sco.ie.tl_332 haw.mi.rm_422 
  // [1a770]
  0x03276507, 0x021c25a0, 0x5e3419a4, 0x193e0aa4,   // gv.gd.nl_432 eu.id.da_322  gl.xh.ts_433 pt.rm.gl_433 
  0x23190aad, 0x2d600404, 0x3b001309, 0x21183bee,   // pt.gl.ca_643 fi.vo.sk_332  et.so.un_440 ks.ar.fa_422 
  0x3e02490c, 0x7900230d, 0x3e1a62a7, 0x35004c07,   // to.da.rm_543 ca.war.un_540  kha.tl.rm_532 wo.zu.un_420 
  0x30003405, 0x443d1807, 0x4d003813, 0x1221180e,   // ps.uz.un_330 ar.ku.kk_432  tk.aa.un_650 ar.fa.ur_555 
  // [1a780]
  0x3e5a2302, 0x1b30310c, 0x3e495a07, 0x031b3ea7,   // ca.sm.rm_222 az.uz.tr_543  sm.to.rm_432 rm.tr.nl_532 
  0x2f1a02a4, 0x28002422, 0x031a3f04, 0x3f1003a0,   // da.tl.su_433 eo.sw.un_870  af.tl.nl_332 nl.lt.af_322 
  0x1f3e0a02, 0x0c004f07, 0x6a190a09, 0x05005708,   // pt.rm.cy_222 bi.sv.un_420  pt.gl.haw_444 na.fr.un_430 
  0x3b001907, 0x27002805, 0x303b1904, 0x3e002c0e,   // gl.so.un_420 sw.gd.un_330  gl.so.uz_332 fy.rm.un_550 
  // [1a790]
  0xfc511007, 0x20000605, 0x281d24ec, 0x12001507,   // lt.kl.zzp_432 de.sq.un_330  eo.la.sw_644 un.hu.un_420 
  0x2d3e6507, 0x2225650c, 0x1d005411, 0x48001d0b,   // gv.rm.sk_432 gv.eu.oc_543  ik.la.un_630 la.tt.un_520 
  0x25153ca0, 0x18276205, 0x1d00540c, 0x6e002422,   // ug.mn.un_320 kha.gd.ga_333  ik.la.un_530 eo.hmn.un_870 
  0x44300404, 0x1d31fea0, 0x0f002005, 0x653925ad,   // ru.uz.kk_332 tlh.az.la_322  sq.lv.un_330 eu.br.gv_643 
  // [1a7a0]
  0xfc3628ee, 0x23081d02, 0x3f004a04, 0x2f0a05a4,   // sw.gn.zzp_422 la.no.ca_222  yo.af.un_320 fr.pt.su_433 
  0x37384404, 0x21220502, 0x03273e04, 0x07005308,   // kk.tk.ba_332 fr.oc.jw_222  rm.gd.nl_332 ht.it.un_430 
  0x0e120509, 0x3c302104, 0x0a001204, 0x05120eee,   // fr.hu.is_444 fa.uz.ug_332  hu.pt.un_320 is.hu.fr_422 
  0x2a0e2007, 0x02004a2a, 0x212f1f07, 0x1f6304a0,   // sq.is.mt_432 yo.da.un_970  cy.su.jw_432 fi.sco.cy_322 
  // [1a7b0]
  0x1e3b1b07, 0x312a6b04, 0x032f02a4, 0x202e1f04,   // tr.so.ms_432 ceb.mt.az_332  da.su.nl_433 cy.fo.sq_332 
  0x5c005602, 0x200463a7, 0x07001907, 0x0a154807,   // mg.sa.un_220 sco.fi.sq_532  gl.it.un_420 tt.mk.un_420 
  0x37253560, 0x63562004, 0x315220a7, 0x15002518,   // tg.mn.ba_664 sq.mg.sco_332  sq.ha.az_532 mn.un.un_740 
  0x31611e07, 0x393069a0, 0x054c12ad, 0x0420430c,   // ms.za.az_432 mfe.uz.br_322  hu.wo.fr_643 ie.sq.fi_543 
  // [1a7c0]
  0x052d0d0b, 0x2f2b6e04, 0x21002f0b, 0x0d4018a9,   // cs.sk.fr_542 hmn.vi.su_332  su.jw.un_520 ga.lb.cs_544 
  0x18004009, 0x402d0d60, 0x023905ee, 0x42184007,   // lb.ga.un_440 cs.sk.lb_664  fr.br.da_422 lb.ga.co_432 
  0x03393fa0, 0x25300808, 0x530d0213, 0x0c063e5a,   // af.br.nl_322 uk.uz.mn_443  da.cs.ht_665 rm.de.sv_553 
  0x5e003905, 0x021939ec, 0x395361ac, 0x380613ad,   // br.ts.un_330 br.gl.da_644  za.ht.br_632 et.de.tk_643 
  // [1a7d0]
  0x283c2307, 0x25003522, 0x37070407, 0x190276a4,   // ky.ug.sd_432 tg.mn.un_870  ru.bg.ba_432 crs.da.gl_433 
  0x283c23a0, 0x0553610c, 0x31003905, 0x304c39ad,   // ky.ug.sd_322 za.ht.fr_543  br.az.un_330 br.wo.uz_643 
  0x05534004, 0x233c44a4, 0x01533908, 0x360b2207,   // lb.ht.fr_332 kk.ug.ky_433  br.ht.en_443 oc.es.gn_432 
  0x57633b0c, 0x3f032ea7, 0x175339ee, 0x760a0207,   // so.sco.na_543 fo.nl.af_532  br.ht.sr_422 da.pt.crs_432 
  // [1a7e0]
  0x0b0a43a0, 0x3b6b1b08, 0x150807a4, 0x2f050aa4,   // ie.pt.es_322 tr.ceb.so_443  bg.uk.un_433 pt.fr.su_433 
  0x071704a7, 0x150738ec, 0x08020c04, 0x0c2a79ee,   // ru.sr.bg_532 tk.bg.un_644  sv.da.no_332 war.mt.sv_422 
  0x5e330407, 0x53460e0c, 0x2d022955, 0x092a6307,   // fi.nn.ts_432 is.qu.ht_543  sl.da.sk_442 sco.mt.pl_432 
  0x070a2302, 0x18004904, 0x05002d0b, 0x084410a0,   // ca.pt.it_222 to.ga.un_320  sk.fr.un_520 be.kk.uk_322 
  // [1a7f0]
  0x505142a4, 0x18003b1b, 0x100a07ee, 0x4a5a130d,   // co.kl.fj_433 ks.ar.un_770  bg.mk.be_422 et.sm.yo_554 
  0x07150aa7, 0x0a002d0b, 0x251136ad, 0x332e0604,   // mk.bg.un_520 sk.pt.un_520  ab.ro.mn_643 de.fo.nn_332 
  0x0e000609, 0x21281209, 0x510602a4, 0x424a3eec,   // de.is.un_440 ur.sd.fa_444  da.de.kl_433 rm.yo.co_644 
  0x25154407, 0x53003120, 0x06044602, 0x0c330304,   // kk.mn.un_420 az.ht.un_850  qu.fi.de_222 nl.nn.sv_332 
  
  // [1a800]
  0x0c016555, 0x3e006010, 0x2a48300c, 0x3b302a0d,   // gv.en.sv_442 vo.rm.un_620  uz.tt.mt_543 mt.uz.so_554 
  0x08170a5a, 0x3f001105, 0x1536380d, 0x4b251da0,   // mk.sr.uk_553 ro.af.un_330  tk.ab.un_554 la.eu.mi_322 
  0x6500131a, 0x190b4a05, 0x25560a0c, 0x392349a4,   // et.gv.un_760 yo.es.gl_333  pt.mg.eu_543 to.ca.br_433 
  0x1b2a5207, 0x5a3e11a0, 0x65006a07, 0xfe63010b,   // ha.mt.tr_432 ro.rm.sm_322  haw.gv.un_420 en.sco.tlh_542 
  // [1a810]
  0x3b560407, 0x4c285705, 0x6300570d, 0x04001822,   // fi.mg.so_432 na.sw.wo_333  na.sco.un_540 ga.fi.un_870 
  0x21002f21, 0x10073609, 0x4a5e730c, 0x060107ee,   // su.jw.un_860 gn.it.lt_444  ny.ts.yo_543 it.en.de_422 
  0x19475607, 0x1044485a, 0x30002a1a, 0x0a79250e,   // mg.sn.gl_432 tt.kk.be_553  mt.uz.un_760 eu.war.pt_555 
  0x020c2507, 0xfe005d14, 0x045863a0, 0x04002a04,   // eu.sv.da_432 ss.tlh.un_660  sco.om.fi_322 mt.fi.un_320 
  // [1a820]
  0x1d682407, 0x151801a0, 0x49001502, 0x07471004,   // eo.ig.la_432 en.ga.un_322  un.to.un_220 lt.sn.it_332 
  0xfe2478ec, 0x0c083f07, 0x526b58a0, 0x22003e04,   // ve.eo.tlh_644 af.no.sv_432  om.ceb.ha_322 rm.oc.un_320 
  0x4c000419, 0x4c4e3111, 0x5e595560, 0x04024e04,   // fi.wo.un_750 az.ay.wo_653  rw.rn.ts_664 ay.da.fi_332 
  0x1352570c, 0x2b5342ad, 0x1036feaf, 0x47211da0,   // na.ha.et_543 co.ht.vi_643  tlh.gn.lt_655 la.jw.sn_322 
  // [1a830]
  0x190b1a0e, 0x246515a7, 0x24071d11, 0x634d1ea0,   // tl.es.gl_555 un.gv.eo_532  la.it.eo_653 ms.aa.sco_322 
  0x23113612, 0x16292da9, 0x24003622, 0x53001007,   // ab.ro.ky_654 sk.sl.hr_544  gn.eo.un_870 lt.ht.un_420 
  0x462a30a0, 0x29fe240c, 0x1047fe05, 0x532b07a0,   // uz.mt.qu_322 eo.tlh.sl_543  tlh.sn.lt_333 it.vi.ht_322 
  0x48100aa0, 0x120b0aa9, 0x0b1905ee, 0x052d0d5e,   // mk.be.tt_322 pt.es.hu_544  fr.gl.es_422 cs.sk.fr_652 
  // [1a840]
  0x38001313, 0x050d43a0, 0x2d48300b, 0x302d0d55,   // et.tk.un_650 ie.cs.fr_322  uz.tt.sk_542 cs.sk.uz_442 
  0x38170a08, 0x1b13040c, 0x2f0b36a7, 0x44070804,   // mk.sr.tk_443 fi.et.tr_543  gn.es.su_532 uk.bg.kk_332 
  0x4438480d, 0x18233ca9, 0x23483811, 0x2a002907,   // tt.tk.kk_554 ug.ky.ar_544  tk.tt.ky_653 sl.mt.un_420 
  0xfe003012, 0x083c1507, 0x08040aad, 0x21443c0c,   // uz.tlh.un_640 un.ug.uk_432  mk.ru.uk_643 ug.kk.fa_543 
  // [1a850]
  0x080a075a, 0x0d000b02, 0x10250807, 0x24002a02,   // bg.mk.uk_553 es.cs.un_220  uk.mn.be_432 mt.eo.un_220 
  0x651f1204, 0x01431504, 0x233c4455, 0x1f00230c,   // hu.cy.gv_332 un.ie.en_332  kk.ug.ky_442 ca.cy.un_530 
  0x211f270c, 0x0f10270d, 0x393e3307, 0x35004808,   // gd.cy.jw_543 gd.lt.lv_554  nn.rm.br_432 tt.tg.un_430 
  0x1f18270c, 0x0402500c, 0x2547270c, 0x2728180c,   // gd.ga.cy_543 fj.da.fi_543  gd.sn.eu_543 ga.sw.gd_543 
  // [1a860]
  0x3e002312, 0x4279070c, 0x0f272512, 0x361f27a6,   // ca.rm.un_640 it.war.co_543  eu.gd.lv_654 gd.cy.gn_521 
  0x15253c08, 0x3d00340b, 0x10475c04, 0x041f270c,   // ug.mn.un_443 ps.ku.un_520  sa.sn.lt_332 gd.cy.fi_543 
  0x223e2b12, 0x27002823, 0x443423ee, 0x245d3502,   // vi.rm.oc_654 sw.gd.un_880  ky.ps.kk_422 zu.ss.eo_222 
  0x3517070c, 0x12fe2d07, 0x32163002, 0x29fe1704,   // bg.sr.tg_543 sk.tlh.hu_432  uz.hr.bs_222 sr.tlh.sl_332 
  // [1a870]
  0x6e2d1255, 0x3e002505, 0x56004c05, 0x2d2012a6,   // hu.sk.hmn_442 eu.rm.un_330  wo.mg.un_330 hu.sq.sk_521 
  0x161229ee, 0x2f2105a0, 0x562205a7, 0x124423ad,   // sl.hu.hr_422 fr.jw.su_322  fr.oc.mg_532 ky.kk.ur_643 
  0x084811a4, 0x16002008, 0x0d172dee, 0x23282113,   // ro.tt.uk_433 sq.hr.un_430  sk.sr.cs_422 fa.sd.ky_665 
  0x3444230e, 0x170c4604, 0x0e001f21, 0x17462904,   // ky.kk.ps_555 qu.sv.sr_332  cy.is.un_860 sl.qu.sr_332 
  // [1a880]
  0x300a3504, 0x5764680c, 0x79006412, 0x12343005,   // tg.mk.uz_332 ig.lg.na_543  lg.war.un_640 uz.ps.ur_333 
  0x0807040c, 0x59000921, 0x3b55470c, 0x2800342a,   // ru.bg.uk_543 pl.rn.un_860  sn.rw.so_543 ps.sd.un_970 
  0x51480f0c, 0x600f50a9, 0x52fa280c, 0x470f640d,   // lv.tt.kl_543 fj.lv.vo_544  sw.nr.ha_543 lg.lv.sn_554 
  0x34001818, 0x100f1a12, 0x025e4708, 0x17000604,   // ar.ps.un_740 tl.lv.lt_654  sn.ts.da_443 de.sr.un_320 
  // [1a890]
  0x5447020c, 0x18004012, 0x42555002, 0x561a5ba4,   // da.sn.ik_543 lb.ga.un_640  fj.rw.co_222 sg.tl.mg_433 
  0x03000221, 0x54000222, 0x243f1da4, 0x1d3034a0,   // da.nl.un_860 da.ik.un_870  la.af.eo_433 xh.uz.la_322 
  0x5d0f540c, 0x7669380c, 0x132002a9, 0x5e510213,   // ik.lv.ss_543 tk.mfe.crs_543  da.sq.et_544 da.kl.ts_665 
  0x292d3f05, 0x240e06a7, 0x2a65fca0, 0x103e0907,   // af.sk.sl_333 de.is.eo_532  zzp.gv.mt_322 pl.rm.lt_432 
  // [1a8a0]
  0x042510a0, 0x1a001508, 0x62006514, 0x01692b07,   // be.mn.ru_322 un.tl.un_430  gv.kha.un_660 vi.mfe.en_432 
  0x4b431f05, 0x072a010c, 0x3831480d, 0x090d38ee,   // cy.ie.mi_333 en.mt.it_543  tt.az.tk_554 tk.cs.pl_422 
  0x302afeee, 0x12300c07, 0x20fe4207, 0x0f003004,   // tlh.mt.uz_422 sv.uz.hu_432  co.tlh.sq_432 uz.lv.un_320 
  0x020536a0, 0x30240312, 0x05001210, 0x19fc3e08,   // gn.fr.da_322 nl.eo.uz_654  hu.fr.un_620 rm.zzp.gl_443 
  // [1a8b0]
  0x1c3330ee, 0x0e003309, 0x31001102, 0x05563e0c,   // uz.nn.id_422 nn.is.un_440  ro.az.un_220 rm.mg.fr_543 
  0x6478470c, 0x2e3e6307, 0x3048235a, 0x3f2a2512,   // sn.ve.lg_543 sco.rm.fo_432  ky.tt.uz_553 eu.mt.af_654 
  0x15046307, 0x6b464a07, 0x25180aaf, 0x35230aee,   // sco.fi.un_432 yo.qu.ceb_432  pt.ga.eu_655 mk.ky.tg_422 
  0x28001e07, 0x4b5a490c, 0x5a4950ec, 0x092efc07,   // ms.sw.un_420 to.sm.mi_543  fj.to.sm_644 zzp.fo.pl_432 
  // [1a8c0]
  0x02001a02, 0x054236a4, 0x10730fad, 0x386465a0,   // tl.da.un_220 gn.co.fr_433  lv.ny.lt_643 gv.lg.tk_322 
  0x2d0d4b09, 0x270515ee, 0x35361107, 0x10420f0c,   // mi.cs.sk_444 un.fr.gd_422  ro.ab.tg_432 lv.co.lt_543 
  0x440a0713, 0x07545111, 0x044e46a4, 0x2d0d05af,   // bg.mk.kk_665 kl.ik.it_653  qu.ay.fi_433 fr.cs.sk_655 
  0x0a100408, 0x500cfe04, 0x1363610c, 0x2500390e,   // ru.be.mk_443 tlh.sv.fj_332  za.sco.et_543 br.eu.un_550 
  // [1a8d0]
  0x07250107, 0x020c25ee, 0x522130a7, 0x30fe37a9,   // en.eu.it_432 eu.sv.da_422  uz.jw.ha_532 st.tlh.uz_544 
  0x13001e04, 0x22055712, 0x61002f13, 0x3f6237a9,   // ms.et.un_320 na.fr.oc_654  su.za.un_650 st.kha.af_544 
  0x0f0a25a0, 0x056506a0, 0x40060308, 0x73302bec,   // eu.pt.lv_322 de.gv.fr_322  nl.de.lb_443 vi.uz.ny_644 
  0xfe00350d, 0x36003405, 0x307922a4, 0x2d3365a0,   // zu.tlh.un_540 xh.gn.un_330  oc.war.uz_433 gv.nn.sk_322 
  // [1a8e0]
  0x1e000908, 0x42004c0c, 0x070a11ee, 0x05003408,   // pl.ms.un_430 wo.co.un_530  ro.mk.bg_422 xh.fr.un_430 
  0x4a004c0d, 0x100817a9, 0x2d0d400c, 0x48301509,   // wo.yo.un_540 sr.uk.be_544  lb.cs.sk_543 un.uz.tt_444 
  0x285247ee, 0x234a4c04, 0x202d0d55, 0x4a004c0e,   // sn.ha.sw_422 wo.yo.ca_332  cs.sk.sq_442 wo.yo.un_550 
  0x28006113, 0x25730fa0, 0x080436a4, 0x303421a7,   // za.sw.un_650 lv.ny.eu_322  ab.ru.uk_433 fa.ps.uz_532 
  // [1a8f0]
  0x08250409, 0x5c3b58a0, 0x392220ee, 0x23004c0c,   // ru.mn.uk_444 om.so.sa_322  sq.oc.br_422 wo.ca.un_530 
  0x2c212fad, 0x4844100c, 0x32162911, 0x48190b04,   // su.jw.fy_643 be.kk.tt_543  sl.hr.bs_653 es.gl.tt_332 
  0x0a1205af, 0x28732202, 0x213b18a4, 0x67271811,   // fr.hu.pt_655 oc.ny.sw_222  ar.ks.fa_433 ga.gd.ak_653 
  0x4d353413, 0x2113040c, 0x21045ca0, 0x353427af,   // xh.zu.aa_665 fi.et.jw_543  sa.fi.jw_322 gd.xh.zu_655 
  // [1a900]
  0x132a0ca9, 0x0b00040c, 0x0d271860, 0x16102911,   // sv.mt.et_544 fi.es.un_530  ga.gd.cs_664 sl.lt.hr_653 
  0x150a150d, 0x100425ee, 0x0e2e0ca0, 0x40021505,   // un.mk.un_554 mn.ru.be_422  sv.fo.is_322 un.da.lb_333 
  0x65431da7, 0x56272307, 0x30213d0e, 0x04420f13,   // la.ie.gv_532 ca.gd.mg_432  ku.fa.uz_555 lv.co.fi_665 
  0x3100611a, 0x63090409, 0x391d0a08, 0x04106207,   // za.az.un_760 fi.pl.sco_444  pt.la.br_443 kha.lt.fi_432 
  // [1a910]
  0x3c112307, 0x04100b04, 0x042515a0, 0x0f2d09ec,   // ky.ro.ug_432 es.lt.fi_332  un.mn.ru_322 pl.sk.lv_644 
  0x350415ee, 0x0f003f04, 0x2b190b09, 0x0f2d04a4,   // un.ru.tg_422 af.lv.un_320  es.gl.vi_444 fi.sk.lv_433 
  0x1700250e, 0x4c002709, 0x48194a0b, 0x08352304,   // mn.sr.un_550 gd.wo.un_440  yo.gl.tt_542 ky.tg.uk_332 
  0x4212050c, 0x49566aee, 0x620225ec, 0x496a5aa4,   // fr.hu.co_543 haw.mg.to_422  eu.da.kha_644 sm.haw.to_433 
  // [1a920]
  0x495a6aaf, 0x3e0213a7, 0x1e31300c, 0x6b254ba0,   // haw.sm.to_655 et.da.rm_532  uz.az.ms_543 mi.eu.ceb_322 
  0x0f2d0d5a, 0x301b2a08, 0x4b256aa7, 0x15004907,   // cs.sk.lv_553 mt.tr.uz_443  haw.eu.mi_532 to.un.un_420 
  0x2407260d, 0x0a116208, 0x104a5a05, 0x250542ee,   // ia.it.eo_554 kha.ro.pt_443  sm.yo.lt_333 co.fr.eu_422 
  0x17004409, 0x22422507, 0x47780a0c, 0x02495aa9,   // kk.sr.un_440 eu.co.oc_432  pt.ve.sn_543 sm.to.da_544 
  // [1a930]
  0x5c042d12, 0x246b2da9, 0x430225ec, 0x4b5a25a0,   // sk.fi.sa_654 sk.ceb.eo_544  eu.da.ie_644 eu.sm.mi_322 
  0x24002d20, 0x6b00792c, 0x4d2d5c08, 0x3b244d05,   // sk.eo.un_850 war.ceb.un_990  sa.sk.aa_443 aa.eo.so_333 
  0x796b3ba4, 0x023b070c, 0x31361007, 0x26003b1a,   // so.ceb.war_433 it.so.da_543  lt.gn.az_432 so.ia.un_760 
  0x190b260e, 0x02285605, 0x49622508, 0x25004202,   // ia.es.gl_555 mg.sw.da_333  eu.kha.to_443 co.eu.un_220 
  // [1a940]
  0x56006a04, 0x42495aa7, 0x6a004b20, 0x4b006a19,   // haw.mg.un_320 sm.to.co_532  mi.haw.un_850 haw.mi.un_750 
  0x115a4baf, 0x4b005a1a, 0x46127907, 0x252d0d60,   // mi.sm.ro_655 sm.mi.un_760  war.hu.qu_432 cs.sk.eu_664 
  0x3b694da7, 0x284b25a4, 0x1d0a3113, 0x674f5009,   // aa.mfe.so_532 eu.mi.sw_433  az.pt.la_665 fj.bi.ak_444 
  0x4c004a0e, 0x30315102, 0x2a005c04, 0x0a3bfea0,   // yo.wo.un_550 kl.az.uz_222  sa.mt.un_320 tlh.so.pt_322 
  // [1a950]
  0x3b4dfe07, 0x3436fea4, 0x11466304, 0x303bfe07,   // tlh.aa.so_432 tlh.gn.xh_433  sco.qu.ro_332 tlh.so.uz_432 
  0x300435a4, 0x234205a7, 0x233b5802, 0x58303bec,   // tg.ru.uz_433 fr.co.ca_532  om.so.ca_222 so.uz.om_644 
  0x46530502, 0x4623fead, 0x5850540c, 0x544e580c,   // fr.ht.qu_222 tlh.ca.qu_643  ik.fj.om_543 om.ay.ik_543 
  0x56003f05, 0x1d420f11, 0x08173602, 0x0d003f02,   // af.mg.un_330 lv.co.la_653  ab.sr.uk_222 af.cs.un_220 
  // [1a960]
  0x423b64a4, 0x10003522, 0x10000a09, 0x03023f05,   // lg.so.co_433 tg.be.un_870  mk.be.un_440 af.da.nl_333 
  0x45262455, 0x23374407, 0x552853a0, 0x44233d0c,   // eo.ia.ln_442 kk.ba.ky_432  ht.sw.rw_322 ku.ky.kk_543 
  0x284423a9, 0x5505220c, 0x24006213, 0x1f220507,   // ky.kk.sd_544 oc.fr.rw_543  kha.eo.un_650 fr.oc.cy_432 
  0x4200fc11, 0x6361010c, 0x1f002205, 0x0a1e1c0d,   // zzp.co.un_630 en.za.sco_543  oc.cy.un_330 id.ms.pt_554 
  // [1a970]
  0x121d5d0c, 0x234830ee, 0x425222a0, 0xfc3463af,   // ss.la.hu_543 uz.tt.ky_422  oc.ha.co_322 sco.xh.zzp_655 
  0x23690504, 0x49000f12, 0x3e050105, 0x35341bec,   // fr.mfe.ca_332 lv.to.un_640  en.fr.rm_333 tr.xh.zu_644 
  0x34615d08, 0x080407a6, 0x65002a02, 0x3946fca0,   // ss.za.xh_443 bg.ru.uk_521  mt.gv.un_220 zzp.qu.br_322 
  0x1c051e07, 0x525d01a0, 0x261b0207, 0x3e004c0d,   // ms.fr.id_432 en.ss.ha_322  da.tr.ia_432 wo.rm.un_540 
  // [1a980]
  0x48370409, 0x2300270b, 0x3e004a04, 0x343d3b12,   // ru.ba.tt_444 gd.ca.un_520  yo.rm.un_320 ks.ku.ps_654 
  0x181f27ee, 0x1507045a, 0x5c003012, 0x471b30a7,   // gd.cy.ga_422 ru.bg.un_553  uz.sa.un_640 uz.tr.sn_532 
  0x0d483012, 0x321729a9, 0x42005202, 0x281853a7,   // uz.tt.cs_654 sl.sr.bs_544  ha.co.un_220 ht.ga.sw_532 
  0x2a005e05, 0x590e7904, 0x0c0dfe07, 0x35fe5dad,   // ts.mt.un_330 war.is.rn_332  tlh.cs.sv_432 ss.tlh.zu_643 
  // [1a990]
  0x0d1ffe07, 0x25005305, 0x5c0f3007, 0x040710ec,   // tlh.cy.cs_432 ht.eu.un_330  uz.lv.sa_432 be.bg.ru_644 
  0x343d1213, 0x112025a4, 0x2d0d40ee, 0x2e2d2914,   // ur.ku.ps_665 eu.sq.ro_433  lb.cs.sk_422 sl.sk.fo_666 
  0x636261a4, 0x6b30fe08, 0x13023902, 0x3f2c6207,   // za.kha.sco_433 tlh.uz.ceb_443  br.da.et_222 kha.fy.af_432 
  0x25005b0e, 0x2a5efe0c, 0x6257060c, 0x1a001014,   // sg.eu.un_550 tlh.ts.mt_543  de.na.kha_543 lt.tl.un_660 
  // [1a9a0]
  0x281d24a7, 0x3f0f1307, 0x0f2a6155, 0x272d2a07,   // eo.la.sw_532 et.lv.af_432  za.mt.lv_442 mt.sk.gd_432 
  0x243928a7, 0x3e3f06a0, 0x42073e13, 0x76026705,   // sw.br.eo_532 de.af.rm_322  rm.it.co_665 ak.da.crs_333 
  0x6800240e, 0x426a50ec, 0x104c040c, 0x05033f09,   // eo.ig.un_550 fj.haw.co_644  fi.wo.lt_543 af.nl.fr_444 
  0x42000714, 0x28686755, 0x584225ad, 0x4e252fec,   // it.co.un_660 ak.ig.sw_442  eu.co.om_643 su.eu.ay_644 
  // [1a9b0]
  0x2f252a08, 0x64006a07, 0x67241a08, 0x0e495a07,   // mt.eu.su_443 haw.lg.un_420  tl.eo.ak_443 sm.to.is_432 
  0x071d0a04, 0x251e1c11, 0x04001f05, 0x2b4b5a07,   // pt.la.it_332 id.ms.eu_653  cy.fi.un_330 sm.mi.vi_432 
  0x2a1d420c, 0x2d033f0d, 0x422d0d05, 0x400f6107,   // co.la.mt_543 af.nl.sk_554  cs.sk.co_333 za.lv.lb_432 
  0x122b3b0d, 0x393f1007, 0x062d0f07, 0x531d15ad,   // so.vi.hu_554 lt.af.br_432  lv.sk.de_432 un.la.ht_643 
  // [1a9c0]
  0x2bfc010c, 0x681d28a4, 0x45252404, 0x584e4c55,   // en.zzp.vi_543 sw.la.ig_433  eo.eu.ln_332 wo.ay.om_442 
  0x2d0d50a4, 0x02472408, 0x46000313, 0x30fe79a9,   // fj.cs.sk_433 eo.sn.da_443  nl.qu.un_650 war.tlh.uz_544 
  0x4e256a0c, 0x1a4246a9, 0x291d42a6, 0x46003407,   // haw.eu.ay_543 qu.co.tl_544  co.la.sl_521 xh.qu.un_420 
  0x49000f04, 0x21303ba0, 0x1d425307, 0x401836ec,   // lv.to.un_320 ks.uz.fa_322  ht.co.la_432 gn.ga.lb_644 
  // [1a9d0]
  0x10006a0d, 0x400518ee, 0x2f021f07, 0x1d021fa4,   // haw.lt.un_540 ga.fr.lb_422  cy.da.su_432 cy.da.la_433 
  0x35081702, 0x322024a7, 0x0a3656a9, 0x18343b07,   // sr.uk.tg_222 eo.sq.bs_532  mg.gn.pt_544 ks.ps.ar_432 
  0x070b570d, 0x071f40a4, 0x24564ba9, 0x3b3610ee,   // na.es.it_554 lb.cy.it_433  mi.mg.eo_544 lt.gn.so_422 
  0x300a390c, 0x1f383b0c, 0x073b5705, 0x5a4d5c04,   // br.pt.uz_543 so.tk.cy_543  na.so.it_333 sa.aa.sm_332 
  // [1a9e0]
  0x6a68250c, 0x303d12af, 0x6400670c, 0x0800481a,   // eu.ig.haw_543 ur.ku.uz_655  ak.lg.un_530 tt.uk.un_760 
  0x2f004211, 0x1d001105, 0x15231108, 0x42650707,   // co.su.un_630 ro.la.un_330  ro.ky.un_443 it.gv.co_432 
  0x3c18345a, 0x7600050e, 0x232540a0, 0x5a2565a9,   // ps.ar.ug_553 fr.crs.un_550  lb.eu.ca_322 gv.eu.sm_544 
  0x04303702, 0x2f1a6bee, 0x113922a0, 0x05004c19,   // ba.uz.ru_222 ceb.tl.su_422  oc.br.ro_322 wo.fr.un_750 
  // [1a9f0]
  0x403e05a4, 0x02464e08, 0x21122fec, 0x234a1812,   // fr.rm.lb_433 ay.qu.da_443  su.hu.jw_644 ga.yo.ca_654 
  0x0a08040c, 0x30232504, 0x05006519, 0x11255707,   // ru.uk.mk_543 mn.ky.uz_332  gv.fr.un_750 na.eu.ro_432 
  0x11000514, 0x113605a4, 0x310525a0, 0x250f6507,   // fr.ro.un_660 fr.gn.ro_433  eu.fr.az_322 gv.lv.eu_432 
  0x2d0d4d12, 0x23180d0c, 0x0f4a0404, 0x280f2504,   // aa.cs.sk_654 cs.ga.ca_543  fi.yo.lv_332 eu.lv.sw_332 
  // [1aa00]
  0x3c112313, 0x104a0f11, 0x11100fa0, 0x35380aad,   // ky.ro.ug_665 lv.yo.lt_653  lv.lt.ro_322 mk.tk.tg_643 
  0x360f4a0e, 0x091d0209, 0x0f002807, 0x10234407,   // yo.lv.gn_555 da.la.pl_444  sw.lv.un_420 kk.ky.be_432 
  0x470218a4, 0x24002d19, 0x3b285214, 0x13100f13,   // ga.da.sn_433 sk.eo.un_750  ha.sw.so_666 lv.lt.et_665 
  0xfe004705, 0x19001d05, 0x27002e04, 0x07041011,   // sn.tlh.un_330 la.gl.un_330  fo.gd.un_320 be.ru.bg_653 
  // [1aa10]
  0x10360fec, 0x356134a4, 0x18233c11, 0x280f0d04,   // lv.gn.lt_644 xh.za.zu_433  ug.ky.ar_653 cs.lv.sw_332 
  0x42001113, 0x17071011, 0x15150805, 0x0a4415a6,   // ro.co.un_650 be.bg.sr_653  uk.un.un_330 un.kk.mk_521 
  0x273918af, 0x18276107, 0x35285da0, 0x27fe18a0,   // ga.br.gd_655 za.gd.ga_432  ss.sw.zu_322 ga.tlh.gd_322 
  0x0c271809, 0x21004009, 0x4c4a2f07, 0x1812215a,   // ga.gd.sv_444 lb.jw.un_440  su.yo.wo_432 fa.ur.ar_553 
  // [1aa20]
  0x443035a0, 0x220519a7, 0x1738110d, 0x39000702,   // tg.uz.kk_322 gl.fr.oc_532  ro.tk.sr_554 it.br.un_220 
  0x1d003204, 0x0e2e4ead, 0x34006719, 0x67457313,   // bs.la.un_320 ay.fo.is_643  ak.xh.un_750 ny.ln.ak_665 
  0x2f12360d, 0x2b3b06a0, 0x1a102408, 0x0b1d1f11,   // gn.hu.su_554 de.so.vi_322  eo.lt.tl_443 cy.la.es_653 
  0x273b3302, 0x3b1a7907, 0x67645a12, 0x10003b0d,   // nn.so.gd_222 war.tl.so_432  sm.lg.ak_654 so.lt.un_540 
  // [1aa30]
  0x1f122b07, 0x1f4d3b11, 0x045f3760, 0x260a0713,   // vi.hu.cy_432 so.aa.cy_653  st.tn.fi_664 it.pt.ia_665 
  0x736e1511, 0x5e79630c, 0x183640ad, 0x1d00fc19,   // un.hmn.ny_653 sco.war.ts_543  lb.gn.ga_643 zzp.la.un_750 
  0x46004813, 0x65006312, 0x1d422408, 0x534a42a0,   // tt.qu.un_650 sco.gv.un_640  eo.co.la_443 co.yo.ht_322 
  0x4a005308, 0x56001d02, 0x1861270d, 0x18342160,   // ht.yo.un_430 la.mg.un_220  gd.za.ga_554 fa.ps.ar_664 
  // [1aa40]
  0x5a005809, 0x1f345da7, 0x20422210, 0x0b2312ec,   // om.sm.un_440 ss.xh.cy_532  oc.co.sq_642 hu.ca.es_644 
  0x2100360b, 0x151504a0, 0x054a59ee, 0x0c290da4,   // gn.jw.un_520 ru.un.un_320  rn.yo.fr_422 cs.sl.sv_433 
  0x49230a04, 0x68495a55, 0x23213c05, 0x2d0d40a9,   // pt.ca.to_332 sm.to.ig_442  ug.fa.ky_333 lb.cs.sk_544 
  0x23432208, 0x2336480e, 0x4f020ca4, 0x4200220d,   // oc.ie.ca_443 tt.ab.ky_555  sv.da.bi_433 oc.co.un_540 
  // [1aa50]
  0x365312a4, 0x343c230c, 0x033f5704, 0x09000f22,   // hu.ht.gn_433 ky.ug.ps_543  na.af.nl_332 lv.pl.un_870 
  0x09100faf, 0x05361007, 0x12213604, 0x044835a6,   // lv.lt.pl_655 lt.gn.fr_432  gn.jw.hu_332 tg.tt.ru_521 
  0x2325380b, 0x25040604, 0x21001210, 0x3f620e04,   // tk.mn.ky_542 de.fi.eu_332  hu.jw.un_620 is.kha.af_332 
  0x4400120e, 0x092a0f13, 0x0f000922, 0x0f4009a4,   // ur.kk.un_550 lv.mt.pl_665  pl.lv.un_870 pl.lb.lv_433 
  // [1aa60]
  0x3e000507, 0x093f3e0c, 0x154404a4, 0x43090fa4,   // fr.rm.un_420 rm.af.pl_543  ru.kk.un_433 lv.pl.ie_433 
  0x2a090fad, 0x0118fca7, 0x1d430107, 0x23170aa9,   // lv.pl.mt_643 zzp.ga.en_532  en.ie.la_432 mk.sr.ky_544 
  0x35002511, 0x5800090c, 0x09000f21, 0x104809ee,   // mn.tg.un_630 pl.om.un_530  lv.pl.un_860 pl.tt.lt_422 
  0x09000f1b, 0x1923010c, 0x100f39ac, 0x033f0d07,   // lv.pl.un_770 en.ca.gl_543  br.lv.lt_632 cs.af.nl_432 
  // [1aa70]
  0x09620fad, 0x09790fec, 0x016b1504, 0x39283004,   // lv.kha.pl_643 lv.war.pl_644  un.ceb.en_332 uz.sw.br_332 
  0x100f2e04, 0x0315fc07, 0x2a002e05, 0x65183e08,   // fo.lv.lt_332 zzp.nl.un_420  fo.mt.un_330 rm.ga.gv_443 
  0x73004604, 0x35345d02, 0x08361504, 0x52006807,   // qu.ny.un_320 ss.xh.zu_222  un.ab.uk_332 ig.ha.un_420 
  0x23113011, 0x2d353404, 0x374410a4, 0x5d732fa7,   // uz.ro.ky_653 xh.zu.sk_332  be.kk.ba_433 su.ny.ss_532 
  // [1aa80]
  0x242d2b02, 0x0e006208, 0x441037a0, 0x0e004d07,   // vi.sk.eo_222 kha.is.un_430  ba.be.kk_322 aa.is.un_420 
  0x39003f09, 0x3c3418ee, 0x0d002305, 0x0d122d60,   // af.br.un_440 ar.ps.ug_422  ca.cs.un_330 sk.hu.cs_664 
  0x68005b1a, 0x192d120d, 0x68003514, 0x3800151b,   // sg.ig.un_760 hu.sk.gl_554  zu.ig.un_660 un.tk.un_770 
  0x283d3ba4, 0x27005e04, 0x28183baf, 0x6b00300d,   // ks.ku.sd_433 ts.gd.un_320  ks.ar.sd_655 uz.ceb.un_540 
  // [1aa90]
  0x33054204, 0x302afe0c, 0xfc290c04, 0x3600450e,   // co.fr.nn_332 tlh.mt.uz_543  sv.sl.zzp_332 ln.gn.un_550 
  0x123031a0, 0x441223ac, 0x1b3530a0, 0x30283502,   // az.uz.hu_322 ky.ur.kk_632  uz.zu.tr_322 zu.sw.uz_222 
  0x5d001211, 0x0d003007, 0x3021280d, 0x042f17a0,   // hu.ss.un_630 uz.cs.un_420  sd.fa.uz_554 sr.su.fi_322 
  0x1028160c, 0x02101705, 0x23253cec, 0x3c2311ad,   // hr.sw.lt_543 sr.lt.da_333  ug.mn.ky_644 ro.ky.ug_643 
  // [1aaa0]
  0x130447a4, 0x2a132807, 0x2b00530b, 0x230722ee,   // sn.fi.et_433 sw.et.mt_432  ht.vi.un_520 oc.it.ca_422 
  0x51101307, 0x45000d19, 0x550f4a55, 0x18343d02,   // et.lt.kl_432 cs.ln.un_750  yo.lv.rw_442 ku.ps.ar_222 
  0x321728a0, 0x2607240c, 0x28375a0c, 0x5564570c,   // sw.sr.bs_322 eo.it.ia_543  sm.st.sw_543 na.lg.rw_543 
  0x0f135da0, 0x692502a9, 0x101701a0, 0x48001509,   // ss.et.lv_322 da.eu.mfe_544  en.sr.lt_322 un.tt.un_440 
  // [1aab0]
  0x79302507, 0x5c004f05, 0x1a696aa7, 0x27000505,   // eu.uz.war_432 bi.sa.un_330  haw.mfe.tl_532 fr.gd.un_330 
  0x56002604, 0x26020713, 0x4c18470c, 0x190afca4,   // ia.mg.un_320 it.da.ia_665  sn.ga.wo_543 zzp.pt.gl_433 
  0x362325af, 0x05112408, 0x23190bee, 0x1b024807,   // mn.ky.ab_655 eo.ro.fr_443  es.gl.ca_422 tt.da.tr_432 
  0x484a18ad, 0x35342d02, 0x190a60a4, 0x060565a4,   // ga.yo.tt_643 sk.xh.zu_222  vo.pt.gl_433 gv.fr.de_433 
  // [1aac0]
  0x11763fad, 0xfc003e02, 0x184843ec, 0x234d22ad,   // af.crs.ro_643 rm.zzp.un_220  ie.tt.ga_644 oc.aa.ca_643 
  0x051365a4, 0x071e65a6, 0x115a0504, 0x2c652aa7,   // gv.et.fr_433 gv.ms.it_521  fr.sm.ro_332 mt.gv.fy_532 
  0x0f003921, 0x443c2309, 0x05002305, 0x032c39a0,   // br.lv.un_860 ky.ug.kk_444  ca.fr.un_330 br.fy.nl_322 
  0x04382907, 0x010e4eee, 0x29002105, 0x1309040e,   // sl.tk.fi_432 ay.is.en_422  jw.sl.un_330 fi.pl.et_555 
  // [1aad0]
  0x2c001e22, 0x24033904, 0x23183c04, 0x204806a0,   // ms.fy.un_870 br.nl.eo_332  ug.ar.ky_332 de.tt.sq_322 
  0x3b523807, 0x2e2c3307, 0x122c6507, 0x3b321ba0,   // tk.ha.so_432 nn.fy.fo_432  gv.fy.hu_432 tr.bs.so_322 
  0x10060ca0, 0x0c02090c, 0x24020407, 0x131004a7,   // sv.de.lt_322 pl.da.sv_543  fi.da.eo_432 fi.lt.et_532 
  0x3f2e2908, 0x4c2c03ec, 0x381e1c5a, 0x303801a0,   // sl.fo.af_443 nl.fy.wo_644  id.ms.tk_553 en.tk.uz_322 
  // [1aae0]
  0x2f054c09, 0x3d342105, 0x37233c0c, 0x30350405,   // wo.fr.su_444 fa.ps.ku_333  ug.ky.ba_543 ru.tg.uz_333 
  0x354415a4, 0x5f5e3705, 0x2b002a04, 0x2a652207,   // un.kk.tg_433 st.ts.tn_333  mt.vi.un_320 oc.gv.mt_432 
  0x22042ba0, 0x120e04a0, 0x39002b02, 0x34503ba0,   // vi.fi.oc_322 fi.is.hu_322  vi.br.un_220 so.fj.xh_322 
  0x2b005313, 0x062a4002, 0x24420707, 0x0410155a,   // ht.vi.un_650 lb.mt.de_222  it.co.eo_432 un.be.ru_553 
  // [1aaf0]
  0x27002a08, 0x2f4c050c, 0x2c0440a0, 0x192d0d55,   // mt.gd.un_430 fr.wo.su_543  lb.fi.fy_322 cs.sk.gl_442 
  0x213340ec, 0x135a6a07, 0x30fe0207, 0x2e0a49ec,   // lb.nn.jw_644 haw.sm.et_432  da.tlh.uz_432 to.pt.fo_644 
  0x1f133312, 0x5800fe19, 0x39221207, 0x4b000207,   // nn.et.cy_654 tlh.om.un_750  hu.oc.br_432 da.mi.un_420 
  0x6327fe12, 0x382b0355, 0x44372313, 0x0a336504,   // tlh.gd.sco_654 nl.vi.tk_442  ky.ba.kk_665 gv.nn.pt_332 
  // [1ab00]
  0x133e2507, 0x04135908, 0x39004d12, 0x47006507,   // eu.rm.et_432 rn.et.fi_443  aa.br.un_640 gv.sn.un_420 
  0x222e5dee, 0x42005102, 0x231148a4, 0x13004907,   // ss.fo.oc_422 kl.co.un_220  tt.ro.ky_433 to.et.un_420 
  0x3b4a02ad, 0x65001807, 0x333e1fa4, 0x50001d05,   // da.yo.so_643 ga.gv.un_420  cy.rm.nn_433 la.fj.un_330 
  0x470ffe0c, 0x23441007, 0x50403ea4, 0x4b1f3e04,   // tlh.lv.sn_543 be.kk.ky_432  rm.lb.fj_433 rm.cy.mi_332 
  // [1ab10]
  0x1d0416a0, 0x29504911, 0x2d0d790c, 0x48303504,   // hr.fi.la_322 to.fj.sl_653  war.cs.sk_543 tg.uz.tt_332 
  0x422402a4, 0x212b5e0c, 0x37364407, 0x47585ea4,   // da.eo.co_433 ts.vi.jw_543  kk.ab.ba_432 ts.om.sn_433 
  0x52321705, 0x5a493711, 0x49002a12, 0x37006414,   // sr.bs.ha_333 st.to.sm_653  mt.to.un_640 lg.st.un_660 
  0x52284da7, 0x48005908, 0x34181205, 0x382344af,   // aa.sw.ha_532 rn.tt.un_430  ur.ar.ps_333 kk.ky.tk_655 
  // [1ab20]
  0x0b384c0c, 0x4c4528ad, 0x254423a4, 0x4c5328ee,   // wo.tk.es_543 sw.ln.wo_643  ky.kk.mn_433 sw.ht.wo_422 
  0x044810a9, 0x1008070b, 0x350710a0, 0x070a3007,   // be.tt.ru_544 bg.uk.be_542  be.bg.tg_322 uz.mk.bg_432 
  0x170a3613, 0x3b5813a0, 0x56002804, 0x13583b12,   // ab.mk.sr_665 et.om.so_322  sw.mg.un_320 so.om.et_654 
  0x25020907, 0x081517af, 0x04003f1b, 0x514c6712,   // pl.da.eu_432 sr.uk.un_650  af.fi.un_770 ak.wo.kl_654 
  // [1ab30]
  0x4c2f58a0, 0x520105a0, 0x031262a9, 0x30383105,   // om.su.wo_322 fr.en.ha_322  kha.hu.nl_544 az.tk.uz_333 
  0x6306090c, 0x31003019, 0x3d3412a9, 0x100925ad,   // pl.de.sco_543 uz.az.un_750  ur.ps.ku_544 eu.pl.lt_643 
  0x134c3bee, 0x04000908, 0x3b04130c, 0x2c093fa9,   // so.wo.et_422 pl.fi.un_430  et.fi.so_543 af.pl.fy_544 
  0x1b3031af, 0x3f000904, 0x1b30310e, 0x1600090b,   // az.uz.tr_655 pl.af.un_320  az.uz.tr_555 pl.hr.un_520 
  // [1ab40]
  0x052f21ee, 0x31431b0c, 0x181f53a0, 0x22462304,   // jw.su.fr_422 tr.ie.az_543  ht.cy.ga_322 ca.qu.oc_332 
  0x3c003b1a, 0x1f0115a4, 0x020c1312, 0x08101704,   // ks.ug.un_760 un.en.cy_433  et.sv.da_654 sr.be.uk_332 
  0x16291d04, 0x050b0a05, 0x3421180e, 0x213418ec,   // la.sl.hr_332 pt.es.fr_333  ar.fa.ps_555 ar.ps.fa_644 
  0x0c0e2eaf, 0x2242230c, 0x20001102, 0x153625a4,   // fo.is.sv_655 ca.co.oc_543  ro.sq.un_220 mn.ab.un_433 
  // [1ab50]
  0x30001e07, 0x1b3148a7, 0x481537a4, 0x23000e04,   // ms.uz.un_420 tt.az.tr_532  ba.tt.un_430 is.ca.un_320 
  0x04084402, 0x58033f09, 0x0d4a45ad, 0x3e22730d,   // kk.uk.ru_222 af.nl.om_444  ln.yo.cs_643 ny.oc.rm_554 
  0x05004c02, 0x040848a9, 0x3d00440c, 0x041708a9,   // wo.fr.un_220 tt.uk.ru_544  kk.ku.un_530 uk.sr.ru_544 
  0x39002207, 0x1d4830a0, 0x1d00480c, 0x21122307,   // oc.br.un_420 uz.tt.la_322  tt.la.un_530 ky.ur.fa_432 
  // [1ab60]
  0x190b0e09, 0x48001d07, 0x1218210d, 0x3c003d11,   // is.es.gl_444 la.tt.un_420  fa.ar.ur_554 ku.ug.un_630 
  0x35300a12, 0x11074207, 0x6b006212, 0x3530150c,   // mk.uz.tg_654 co.it.ro_432  kha.ceb.un_640 un.uz.tg_543 
  0x61016355, 0x33621aad, 0x60006234, 0x2b1a3712,   // sco.en.za_442 tl.kha.nn_643  kha.vo.un_A80 st.tl.vi_654 
  0x1dfe620c, 0x28344402, 0x18792b11, 0x621c2b0c,   // kha.tlh.la_543 kk.ps.sd_222  vi.war.ga_653 vi.id.kha_543 
  // [1ab70]
  0x1f531e07, 0x60501da4, 0x355f6955, 0x03534008,   // ms.ht.cy_432 la.fj.vo_433  mfe.tn.zu_442 lb.ht.nl_443 
  0x4c301a08, 0x65016b04, 0x5f1f6008, 0x5d675faf,   // tl.uz.wo_443 ceb.en.gv_332  vo.cy.tn_443 tn.ak.ss_655 
  0x37287508, 0x62214fa9, 0x041515ee, 0x355264a0,   // nso.sw.st_443 bi.jw.kha_544  un.ru.un_420 lg.ha.zu_322 
  0x1a00fe21, 0x6035680c, 0x07000508, 0x2b1a2f0c,   // tlh.tl.un_860 ig.zu.vo_543  fr.it.un_430 su.tl.vi_543 
  // [1ab80]
  0x32006008, 0x6e003b04, 0x34304c07, 0x2c0f2aa7,   // vo.bs.un_430 so.hmn.un_320  wo.uz.xh_432 mt.lv.fy_532 
  0x2c002a0e, 0x303128a4, 0x042810a0, 0x2c0f2aad,   // mt.fy.un_550 sw.az.uz_433  lt.sw.fi_322 mt.lv.fy_643 
  0x24392807, 0x072a6008, 0x64007305, 0x553b6ba4,   // sw.br.eo_432 vo.mt.it_443  ny.lg.un_330 ceb.so.rw_433 
  0x47005c07, 0x47730214, 0x375f24a0, 0x2c2a3fa6,   // sa.sn.un_420 da.ny.sn_666  eo.tn.st_322 af.mt.fy_521 
  // [1ab90]
  0x65fe2707, 0x3704150b, 0x1b384802, 0x5c1c0911,   // gd.tlh.gv_432 un.ru.ba_542  tt.tk.tr_222 hi.mr.sa_653 
  0x30006818, 0x02006222, 0x5c004f09, 0x1f3f65a0,   // ig.uz.un_740 kha.da.un_870  bi.sa.un_440 gv.af.cy_322 
  0x40004c08, 0x2a003f21, 0x1b64380c, 0x68552804,   // wo.lb.un_430 af.mt.un_860  tk.lg.tr_543 sw.rw.ig_332 
  0x075564a0, 0x39003007, 0x48102208, 0x044801a0,   // lg.rw.it_322 uz.br.un_420  oc.lt.tt_443 en.tt.fi_322 
  // [1aba0]
  0x2500681a, 0xfc256304, 0x250848a0, 0x330238a9,   // ig.eu.un_760 sco.eu.zzp_332  tt.no.eu_322 tk.da.nn_544 
  0xfe631f07, 0x2046feee, 0x47003804, 0x02100405,   // cy.sco.tlh_432 tlh.qu.sq_422  tk.sn.un_320 fi.lt.da_333 
  0x24524708, 0x02004805, 0x111a01a0, 0x5d004721,   // sn.ha.eo_443 tt.da.un_330  en.tl.ro_322 sn.ss.un_860 
  0x0e003608, 0x3f003607, 0x0d005c29, 0x61005d0e,   // gn.is.un_430 gn.af.un_420  sa.ne.un_960 ss.za.un_550 
  // [1abb0]
  0x1e571aa4, 0x2d0d21a0, 0x3b421108, 0x58323b07,   // tl.na.ms_433 jw.cs.sk_322  ro.co.so_443 so.bs.om_432 
  0x5e1902ad, 0x1a12580c, 0x47005d1a, 0x061b3855,   // da.gl.ts_643 om.hu.tl_543  ss.sn.un_760 tk.tr.de_442 
  0x38024007, 0x2f1c2102, 0x5d00470e, 0x4700fe13,   // lb.da.tk_432 jw.id.su_222  sn.ss.un_550 tlh.sn.un_650 
  0x46571aad, 0x3b465002, 0x47005d14, 0x2d0d29a7,   // tl.na.qu_643 fj.qu.so_222  ss.sn.un_660 sl.cs.sk_532 
  // [1abc0]
  0xfe005d0c, 0x67211a09, 0x3b006321, 0x1a3b51a0,   // ss.tlh.un_530 tl.jw.ak_444  sco.so.un_860 kl.so.tl_322 
  0x033f23a7, 0x4e32165a, 0x2d0e59a0, 0x3e007907,   // ca.af.nl_532 hr.bs.ay_553  rn.is.sk_322 war.rm.un_420 
  0x5d00420c, 0x4400251a, 0x15000818, 0x2d360d12,   // co.ss.un_530 mn.kk.un_760  uk.un.un_740 cs.gn.sk_654 
  0x4c2873a9, 0x284c21a0, 0x104c42a4, 0x17150aaf,   // ny.sw.wo_544 jw.wo.sw_322  co.wo.lt_433 mk.sr.un_650 
  // [1abd0]
  0x0810370d, 0x220b3604, 0x344418ee, 0x4418230d,   // ba.be.uk_554 gn.es.oc_332  ar.kk.ps_422 ky.ar.kk_554 
  0x070501ad, 0x511206ec, 0x23004c2a, 0x30443407,   // en.fr.it_643 de.hu.kl_644  wo.ca.un_970 ps.kk.uz_432 
  0x1b001d09, 0x15115ca7, 0x38631ba4, 0x0863fe07,   // la.tr.un_440 sa.ro.un_532  tr.sco.tk_433 tlh.sco.no_432 
  0x482b3002, 0x55006e08, 0x463962af, 0x20692eec,   // uz.vi.tt_222 hmn.rw.un_430  kha.br.qu_655 fo.mfe.sq_644 
  // [1abe0]
  0x6200450e, 0x15002e0d, 0x79256b0c, 0x2b005202,   // ln.kha.un_550 fo.un.un_540  ceb.eu.war_543 ha.vi.un_220 
  0x44364855, 0x5c004609, 0x12570c0d, 0x3e422712,   // tt.ab.kk_442 qu.sa.un_440  sv.na.hu_554 gd.co.rm_654 
  0x2e0e4307, 0x18303d07, 0x353c2355, 0x48384f07,   // ie.is.fo_432 ku.uz.ar_432  ky.ug.tg_442 bi.tk.tt_432 
  0x172d1007, 0x190a3102, 0x12343da4, 0x31305e12,   // lt.sk.sr_432 az.pt.gl_222  ku.ps.ur_433 ts.uz.az_654 
  // [1abf0]
  0x272b22a0, 0x0b004a0d, 0x480c065a, 0x053918a7,   // oc.vi.gd_322 yo.es.un_540  de.sv.tt_553 ga.br.fr_532 
  0x4c002b09, 0x21003707, 0x34003020, 0x24033fa0,   // vi.wo.un_440 st.jw.un_420  uz.ps.un_850 af.nl.eo_322 
  0x29792da0, 0x390e6912, 0x47070ea6, 0x20404cea,   // sk.war.sl_322 mfe.is.br_654  is.it.sn_521 wo.lb.sq_822 
  0x420e1855, 0x16101704, 0x471d1312, 0x28343da7,   // ga.is.co_442 sr.lt.hr_332  et.la.sn_654 ku.ps.sd_532 
  
  // [1ac00]
  0x07021d05, 0x046b1a08, 0x1c7364a4, 0x47251da0,   // la.da.it_333 tl.ceb.fi_443  lg.ny.id_433 la.eu.sn_322 
  0x3b5834a0, 0x2818440b, 0x525601a0, 0x53522808,   // xh.om.so_322 kk.ar.sd_542  en.mg.ha_322 sw.ha.ht_443 
  0xfe005314, 0x68205608, 0x0a3523a0, 0x330c4f07,   // ht.tlh.un_660 mg.sq.ig_443  ky.tg.mk_322 bi.sv.nn_432 
  0x56004f1b, 0x4c5f52a9, 0x0c0660a7, 0x27001f0e,   // bi.mg.un_770 ha.tn.wo_544  vo.de.sv_532 cy.gd.un_550 
  // [1ac10]
  0x21003c08, 0x521e58a4, 0x5e003b14, 0x53000b04,   // ug.fa.un_430 om.ms.ha_433  so.ts.un_660 es.ht.un_320 
  0x114f01a4, 0x3b4d0107, 0x040b13a4, 0x172910a6,   // en.bi.ro_433 en.aa.so_432  et.es.fi_433 lt.sl.sr_521 
  0x42004307, 0x5e000c0c, 0x4a00690e, 0x65fc1d0c,   // ie.co.un_420 sv.ts.un_530  mfe.yo.un_550 la.zzp.gv_543 
  0x151504ec, 0x2a000212, 0x09005c1b, 0x233625af,   // ru.un.un_640 da.mt.un_640  sa.hi.un_770 mn.ab.ky_655 
  // [1ac20]
  0x440407a6, 0x0f102d02, 0x1800440e, 0x1008440e,   // bg.ru.kk_521 sk.lt.lv_222  kk.ar.un_550 kk.uk.be_555 
  0x40420507, 0x482537a9, 0x443c37ad, 0x23484407,   // fr.co.lb_432 ba.mn.tt_544  ba.ug.kk_643 kk.tt.ky_432 
  0x044837ac, 0x44041104, 0x303c1508, 0x321646ec,   // ba.tt.ru_632 ro.ru.kk_332  un.ug.uz_443 qu.hr.bs_644 
  0x2507380c, 0x23123004, 0x3c002512, 0x08002b04,   // tk.bg.mn_543 uz.ur.ky_332  mn.ug.un_640 vi.no.un_320 
  // [1ac30]
  0x76006709, 0x1c001a04, 0x12002204, 0x283039a0,   // ak.crs.un_440 tl.id.un_320  oc.hu.un_320 br.uz.sw_322 
  0x64354504, 0x2a1632a6, 0x46346708, 0x4a2a6013,   // ln.zu.lg_332 bs.hr.mt_521  ak.xh.qu_443 vo.mt.yo_665 
  0x483860a7, 0x376828ee, 0x34007318, 0x6000060e,   // vo.tk.tt_532 sw.ig.st_422  ny.xh.un_740 de.vo.un_550 
  0x303715ee, 0x120536ee, 0x3900281a, 0x2000300e,   // un.ba.uz_422 gn.fr.hu_422  sw.br.un_760 uz.sq.un_550 
  // [1ac40]
  0x250f0107, 0x6076070c, 0x2a285504, 0x251001a0,   // en.lv.eu_432 it.crs.vo_543  rw.sw.mt_332 en.lt.eu_322 
  0x3e280709, 0x311d47ee, 0x2f486212, 0x592862a4,   // it.sw.rm_444 sn.la.az_422  kha.tt.su_654 kha.sw.rn_433 
  0x183d2108, 0x3e372fa4, 0x03002d07, 0x63152a0c,   // fa.ku.ar_443 su.st.rm_433  sk.nl.un_420 mt.sco.un_530 
  0x071d1307, 0x483f6107, 0x07683e05, 0x2a000f0d,   // et.la.it_432 za.af.tt_432  rm.ig.it_333 lv.mt.un_540 
  // [1ac50]
  0x2d2b0f07, 0x56004a18, 0x5d3435a0, 0x070442a0,   // lv.vi.sk_432 yo.mg.un_740  zu.xh.ss_322 co.fi.it_322 
  0x0f002a08, 0x032a2d02, 0x321712ee, 0x18494aee,   // mt.lv.un_430 sk.mt.nl_222  hu.sr.bs_422 yo.to.ga_422 
  0x05001816, 0x020f1004, 0x0f2c08a4, 0x391028a0,   // ga.fr.un_720 lt.lv.da_332  no.fy.lv_433 sw.lt.br_322 
  0x03100f08, 0x12192f04, 0xfe002905, 0x0d482ead,   // lv.lt.nl_443 su.gl.hu_332  sl.tlh.un_330 fo.tt.cs_643 
  // [1ac60]
  0x2e00080d, 0x20001210, 0x3d2821a0, 0x3229160e,   // no.fo.un_540 hu.sq.un_620  fa.sd.ku_322 hr.sl.bs_555 
  0x353419a4, 0x36514207, 0x131030ad, 0x33120cee,   // gl.xh.zu_433 co.kl.gn_432  uz.lt.et_643 sv.hu.nn_422 
  0x214012a6, 0x2e001005, 0x48002905, 0x1d353405,   // hu.lb.jw_521 lt.fo.un_330  sl.tt.un_330 xh.zu.la_333 
  0x350a3407, 0xfe483012, 0x0b181904, 0x2e2d0daf,   // xh.pt.zu_432 uz.tt.tlh_654  gl.ga.es_332 cs.sk.fo_655 
  // [1ac70]
  0x306010ad, 0x2e505107, 0x3f604cad, 0x440438a7,   // lt.vo.uz_643 kl.fj.fo_432  wo.vo.af_643 tk.ru.kk_532 
  0x2e003e07, 0x0a0410ec, 0x180e3608, 0x2f226ba4,   // rm.fo.un_420 be.ru.mk_644  gn.is.ga_443 ceb.oc.su_433 
  0x37016311, 0xfe2f5fa9, 0x75001c04, 0x072508af,   // sco.en.st_653 tn.su.tlh_544  id.nso.un_320 uk.mn.bg_655 
  0x3000600c, 0x631a330c, 0x033f60a4, 0x2b003704,   // vo.uz.un_530 nn.tl.sco_543  vo.af.nl_433 st.vi.un_320 
  // [1ac80]
  0x5f371a0d, 0x42330807, 0x436930a4, 0x2f007312,   // tl.st.tn_554 no.nn.co_432  uz.mfe.ie_433 ny.su.un_640 
  0x37000108, 0x2b4c6108, 0x612b62ad, 0x37001f1a,   // en.st.un_430 za.wo.vi_443  kha.vi.za_643 cy.st.un_760 
  0x010663a0, 0x52037302, 0x736b1aa9, 0x401365a0,   // sco.de.en_322 ny.nl.ha_222  tl.ceb.ny_544 gv.et.lb_322 
  0x1d5201a0, 0x2d041508, 0x56001d04, 0x42052212,   // en.ha.la_322 un.ru.syr_443  la.mg.un_320 oc.fr.co_654 
  // [1ac90]
  0x28004a07, 0x24203905, 0x284d3b07, 0x0a18400d,   // yo.sw.un_420 br.sq.eo_333  so.aa.sw_432 lb.ga.pt_554 
  0x05026502, 0x073c0405, 0x3f00040c, 0x48005e02,   // gv.da.fr_222 ru.ug.bg_333  fi.af.un_530 ts.tt.un_220 
  0x28001e05, 0x3b301904, 0x1e006407, 0x371544a0,   // ms.sw.un_330 gl.uz.so_332  lg.ms.un_420 kk.ba.un_320 
  0x3b4421a4, 0x4700610c, 0x05004007, 0x2d0d59a9,   // fa.kk.ks_433 za.sn.un_530  lb.fr.un_420 rn.cs.sk_544 
  // [1aca0]
  0x0500190b, 0x3b21280c, 0x0500530d, 0x34183b04,   // gl.fr.un_520 sd.fa.ks_543  ht.fr.un_540 ks.ar.ps_332 
  0x04006514, 0x10041707, 0x0a000414, 0x12212fa0,   // gv.fi.un_660 sr.ru.be_432  ru.mk.un_660 su.jw.hu_322 
  0x2a003607, 0x251336ad, 0x25190a0b, 0x4a002e09,   // gn.mt.un_420 gn.et.eu_643  pt.gl.eu_542 fo.yo.un_440 
  0x440a070c, 0x1b00061a, 0x3f40390c, 0x6a00400d,   // bg.mk.kk_543 de.tr.un_760  br.lb.af_543 lb.haw.un_540 
  // [1acb0]
  0x10042512, 0x25394004, 0x390840a0, 0x06311b11,   // mn.ru.be_654 lb.br.eu_332  lb.no.br_322 tr.az.de_653 
  0x311b38a7, 0x1700440b, 0x2200190e, 0x1139400d,   // tk.tr.az_532 kk.sr.un_520  gl.oc.un_550 lb.br.ro_554 
  0x403308a4, 0x403f5711, 0x3f400655, 0x3f0840a4,   // no.nn.lb_433 na.af.lb_653  de.lb.af_442 lb.no.af_433 
  0x33083105, 0x2b00020d, 0x2f281ca4, 0x15310cad,   // az.no.nn_333 da.vi.un_540  id.sw.su_433 sv.az.un_643 
  // [1acc0]
  0x05001809, 0x0f3202a9, 0x192322a7, 0x362343a7,   // ga.fr.un_440 da.bs.lv_544  oc.ca.gl_532 ie.ca.gn_532 
  0x23002219, 0x13042802, 0x30041704, 0x1e1c28ee,   // oc.ca.un_750 sw.fi.et_222  sr.ru.uz_332 sw.id.ms_422 
  0x4f005b08, 0x3f30250c, 0x13555dad, 0x101e1c04,   // sg.bi.un_430 eu.uz.af_543  ss.rw.et_643 id.ms.lt_332 
  0x56055305, 0x2f002802, 0x022e0907, 0x100f25a7,   // ht.fr.mg_333 sw.su.un_220  pl.fo.da_432 eu.lv.lt_532 
  // [1acd0]
  0x180e2e0c, 0x33003907, 0x23002814, 0x3c284404,   // fo.is.ga_543 br.nn.un_420  sw.ca.un_660 kk.sd.ug_332 
  0x43006318, 0x13100207, 0x650e02ee, 0x364a02ee,   // sco.ie.un_740 da.lt.et_432  da.is.gv_422 da.yo.gn_422 
  0x13023504, 0x336301a4, 0x57fe39af, 0x0a002d10,   // zu.da.et_332 en.sco.nn_433  br.tlh.na_655 sk.pt.un_620 
  0x2a392307, 0x1ffe3905, 0x17043504, 0x1a00152a,   // ca.br.mt_432 br.tlh.cy_333  tg.ru.sr_332 un.tl.un_970 
  // [1ace0]
  0x201d2207, 0x1b0118a0, 0x07480a07, 0x18002321,   // oc.la.sq_432 ga.en.tr_322  mk.tt.bg_432 ky.ar.un_860 
  0x35005a02, 0x3b001d0e, 0x35341fa0, 0x4c003118,   // sm.zu.un_220 la.so.un_550  cy.xh.zu_322 az.wo.un_740 
  0x0a192bb2, 0x1d004c08, 0x3f1033a0, 0x1f005d07,   // vi.gl.pt_732 wo.la.un_430  nn.lt.af_322 ss.cy.un_420 
  0x47000602, 0x060e3f04, 0x083f1004, 0x121f670c,   // de.sn.un_220 af.is.de_332  lt.af.no_332 ak.cy.hu_543 
  // [1acf0]
  0x19232ea4, 0x234a1907, 0x44001707, 0x2e360ea7,   // fo.ca.gl_433 gl.yo.ca_432  sr.kk.un_420 is.gn.fo_532 
  0x3b001e07, 0x192d4a04, 0x4a2e18ad, 0xfc451208,   // ms.so.un_420 yo.sk.gl_332  ga.fo.yo_643 hu.ln.zzp_443 
  0x69353414, 0x12004a13, 0x15003718, 0x0a11100c,   // xh.zu.mfe_666 yo.hu.un_650  ba.un.un_740 be.ro.mk_543 
  0x5f0d0907, 0x30382404, 0x464e2bec, 0x2e0e1905,   // pl.cs.tn_432 eo.tk.uz_332  vi.ay.qu_644 gl.is.fo_333 
  // [1ad00]
  0x360b43ad, 0x0d2c2404, 0x53052207, 0x0b365504,   // ie.es.gn_643 eo.fy.cs_332  oc.fr.ht_432 rw.gn.es_332 
  0x4e002b34, 0x12190a0c, 0x10092cad, 0x39002308,   // vi.ay.un_A80 pt.gl.hu_543  fy.pl.lt_643 ca.br.un_430 
  0xfc011502, 0x01006207, 0x0e122d07, 0x025c29a4,   // un.en.zzp_222 kha.en.un_420  sk.hu.is_432 sl.sa.da_433 
  0x3ffc3605, 0x1d792d07, 0x48070a07, 0x24005c0e,   // gn.zzp.af_333 sk.war.la_432  mk.bg.tt_432 sa.eo.un_550 
  // [1ad10]
  0x026546af, 0x13102405, 0x6300010e, 0x080702a4,   // qu.gv.da_655 eo.lt.et_333  en.sco.un_550 da.it.no_433 
  0x24694007, 0x4c004019, 0x353c1107, 0x17006104,   // lb.mfe.eo_432 lb.wo.un_750  ro.ug.tg_432 za.sr.un_320 
  0x3f2c2aa4, 0x10040755, 0x0e2f1508, 0x483001a9,   // mt.fy.af_433 bg.ru.be_442  un.su.is_443 en.uz.tt_544 
  0x0a1730ad, 0x2e2d1909, 0x1a6b2507, 0x0f004c0b,   // uz.sr.mk_643 gl.sk.fo_444  eu.ceb.tl_432 wo.lv.un_520 
  // [1ad20]
  0x232227a9, 0x2e483907, 0x38443714, 0x19480ba4,   // gd.oc.ca_544 br.tt.fo_432  ba.kk.tk_666 es.tt.gl_433 
  0x22190b09, 0x15173604, 0x3d342111, 0x0f3048a0,   // es.gl.oc_444 ab.sr.un_332  fa.ps.ku_653 tt.uz.lv_322 
  0x2e1b4807, 0x13105ca4, 0x21002f1b, 0x314858a4,   // tt.tr.fo_432 sa.lt.et_433  su.jw.un_770 om.tt.az_433 
  0x38310ea0, 0x405706af, 0x58316008, 0x42130da4,   // is.az.tk_322 de.na.lb_655  vo.az.om_443 cs.et.co_433 
  // [1ad30]
  0x5842250c, 0x31004002, 0x2d330ea4, 0x42495a0d,   // eu.co.om_543 lb.az.un_220  is.nn.sk_433 sm.to.co_554 
  0x5c554b0c, 0x46005202, 0x49253613, 0x73004214,   // mi.rw.sa_543 ha.qu.un_220  gn.eu.to_665 co.ny.un_660 
  0x5842250d, 0x5a005819, 0x051560ec, 0x2c00fc19,   // eu.co.om_554 om.sm.un_750  vo.fr.un_640 zzp.fy.un_750 
  0x42255808, 0x1f5c1207, 0x10170713, 0x537660ad,   // om.eu.co_443 hu.sa.cy_432  bg.sr.be_665 vo.crs.ht_643 
  // [1ad40]
  0x35344dac, 0x314c1b04, 0x12001f13, 0x11422512,   // aa.xh.zu_632 tr.wo.az_332  cy.hu.un_650 eu.co.ro_654 
  0x4b735004, 0x2e0e360d, 0x483031a7, 0x734225a9,   // fj.ny.mi_332 gn.is.fo_554  az.uz.tt_532 eu.co.ny_544 
  0x4225640c, 0x4b251c07, 0x4c465812, 0x3b1e1c04,   // lg.eu.co_543 id.eu.mi_432  om.qu.wo_654 id.ms.so_332 
  0x1c215c11, 0x0e001907, 0x25004605, 0x18232dac,   // sa.jw.id_653 gl.is.un_420  qu.eu.un_330 sk.ca.ga_632 
  // [1ad50]
  0x180e2e5e, 0x083530ee, 0x182e0ea4, 0x2e004a0b,   // fo.is.ga_652 uz.tg.uk_422  is.fo.ga_433 yo.fo.un_520 
  0x37151012, 0x1d2e0407, 0x0f123302, 0x0c004204,   // be.ba.un_640 fi.fo.la_432  nn.hu.lv_222 co.sv.un_320 
  0x443412a4, 0x0c386011, 0x030e2e04, 0x13311b05,   // ur.ps.kk_433 vo.tk.sv_653  fo.is.nl_332 tr.az.et_333 
  0x19232204, 0x44001022, 0x3e1358a0, 0x06405805,   // oc.ca.gl_332 be.kk.un_870  om.et.rm_322 om.lb.de_333 
  // [1ad60]
  0x3c004402, 0x13330807, 0x33084008, 0x18004a05,   // kk.ug.un_220 no.nn.et_432  lb.no.nn_443 yo.ga.un_330 
  0x3e00610c, 0x3f001a05, 0x102262a4, 0x017915ec,   // za.rm.un_530 tl.af.un_330  kha.oc.lt_433 un.war.en_644 
  0x270f3e07, 0x3500070b, 0x56004504, 0x2a0947af,   // rm.lv.gd_432 bg.tg.un_520  ln.mg.un_320 sn.pl.mt_655 
  0x40132aa4, 0x12583ea0, 0x51fc5812, 0x540458a4,   // mt.et.lb_433 rm.om.hu_322  om.zzp.kl_654 om.fi.ik_433 
  // [1ad70]
  0x2a1d3fa4, 0x5d081b07, 0x2a007312, 0x0c00260c,   // af.la.mt_433 tr.no.ss_432  ny.mt.un_640 ia.sv.un_530 
  0x40005808, 0x48341b07, 0x5c0d13a7, 0x1f001d12,   // om.lb.un_430 tr.xh.tt_432  bh.ne.sa_532 la.cy.un_640 
  0x1c515807, 0x584d5214, 0x400658ee, 0x5834510c,   // om.kl.id_432 ha.aa.om_666  om.de.lb_422 kl.xh.om_543 
  0x02005812, 0x0f006307, 0x3f003e13, 0x0a006305,   // om.da.un_640 sco.lv.un_420  rm.af.un_650 sco.pt.un_330 
  // [1ad80]
  0x46001505, 0x7328360e, 0x15002c19, 0x4000391b,   // un.qu.un_330 gn.sw.ny_555  fy.un.un_750 br.lb.un_770 
  0x065d76ee, 0x5d352802, 0x51fe54ec, 0x4c5213ee,   // crs.ss.de_422 sw.zu.ss_222  ik.tlh.kl_644 et.ha.wo_422 
  0xfe1b15ad, 0x536430a4, 0x58006418, 0x39001302,   // un.tr.tlh_643 uz.lg.ht_433  lg.om.un_740 et.br.un_220 
  0x395158a9, 0x344835a0, 0x3e40585a, 0x51fe5455,   // om.kl.br_544 zu.tt.xh_322  om.lb.rm_553 ik.tlh.kl_442 
  // [1ad90]
  0x11353409, 0x63026055, 0x284c3b07, 0x46027307,   // xh.zu.ro_444 vo.da.sco_442  so.wo.sw_432 ny.da.qu_432 
  0x303c250c, 0x10020d07, 0x0b2319a4, 0x64557309,   // mn.ug.uz_543 cs.da.lt_432  gl.ca.es_433 ny.rw.lg_444 
  0x31001507, 0x4410300e, 0x342318ee, 0x12131bee,   // un.az.un_420 uz.be.kk_555  ar.ky.ps_422 tr.et.hu_422 
  0x4a474da4, 0x132924ee, 0x0c000d08, 0x601d24ac,   // aa.sn.yo_433 eo.sl.et_422  cs.sv.un_430 eo.la.vo_632 
  // [1ada0]
  0x35303704, 0x53570455, 0x6b3260ee, 0x50090d0d,   // ba.uz.tg_332 fi.na.ht_442  vo.bs.ceb_422 cs.pl.fj_554 
  0x360bfea0, 0x112d0d13, 0x3e003b22, 0x18213013,   // tlh.es.gn_322 cs.sk.ro_665  so.rm.un_870 uz.fa.ar_665 
  0x085729a4, 0x220d1707, 0x1d000414, 0x31004c02,   // sl.na.no_433 sr.cs.oc_432  fi.la.un_660 wo.az.un_220 
  0x5a500107, 0x11031260, 0x0f102a07, 0x1511350c,   // en.fj.sm_432 hu.nl.ro_664  mt.lt.lv_432 tg.ro.un_543 
  // [1adb0]
  0x0400251a, 0x10070407, 0x180d0e07, 0x0200670d,   // mn.ru.un_760 ru.bg.be_432  is.cs.ga_432 ak.da.un_540 
  0x6b00650d, 0x2700fe04, 0x28443413, 0x17164e05,   // gv.ceb.un_540 tlh.gd.un_320  ps.kk.sd_665 ay.hr.sr_333 
  0x1530310c, 0x2b1b15a9, 0x213d340e, 0x40001308,   // az.uz.un_543 un.tr.vi_544  ps.ku.fa_555 et.lb.un_430 
  0x396515a0, 0x2f5501ee, 0x3400302a, 0x396563ee,   // un.gv.br_322 en.rw.su_422  uz.ps.un_970 sco.gv.br_422 
  // [1adc0]
  0x301c2f02, 0x402305a7, 0x394c1fa7, 0x31005104,   // su.id.uz_222 fr.ca.lb_532  cy.wo.br_532 kl.az.un_320 
  0x244315a4, 0x5d6301ee, 0x4732500c, 0x0f007907,   // un.ie.eo_433 en.sco.ss_422  fj.bs.sn_543 war.lv.un_420 
  0x05405305, 0x53003802, 0x79602205, 0x2e00040c,   // ht.lb.fr_333 tk.ht.un_220  oc.vo.war_333 fi.fo.un_530 
  0x07592307, 0x43245a0d, 0x48150855, 0x045a4905,   // ca.rn.it_432 sm.eo.ie_554  uk.tt.un_420 to.sm.fi_333 
  // [1add0]
  0x301711a7, 0x64104704, 0x23344404, 0x39280f07,   // ro.sr.uz_532 sn.lt.lg_332  kk.ps.ky_332 lv.sw.br_432 
  0x42543e13, 0x373c23a0, 0x353623a4, 0x08022e11,   // rm.ik.co_665 ky.ug.ba_322  ky.ab.tg_433 fo.da.no_653 
  0x060758a4, 0x364c0e5a, 0x162e29ad, 0x2400fe07,   // om.it.de_433 is.wo.gn_553  sl.fo.hr_643 tlh.eo.un_420 
  0x534c1207, 0x48373807, 0x4c002f1a, 0x3c3418af,   // hu.wo.ht_432 tk.ba.tt_432  su.wo.un_760 ar.ps.ug_655 
  // [1ade0]
  0x30353712, 0x46796bac, 0x5d003612, 0x30001808,   // ba.tg.uz_654 ceb.war.qu_632  gn.ss.un_640 ga.uz.un_430 
  0x08171508, 0x07043804, 0x07182707, 0x2d0d1ca4,   // un.sr.uk_443 tk.ru.bg_332  gd.ga.it_432 id.cs.sk_433 
  0x463418ee, 0x15006404, 0x5d35faa7, 0x27002507,   // ga.xh.qu_422 lg.un.un_320  nr.zu.ss_532 eu.gd.un_420 
  0x3c341809, 0x0c5239a0, 0x2e08020b, 0x55641055,   // ar.ps.ug_444 br.ha.sv_322  da.no.fo_542 lt.lg.rw_442 
  // [1adf0]
  0x2d0d5bed, 0x443c2504, 0x34393f04, 0x3473090b,   // sg.cs.sk_622 mn.ug.kk_332  af.br.xh_332 pl.ny.xh_542 
  0x28733404, 0x271318a4, 0x044410ad, 0x242e0e0c,   // xh.ny.sw_332 ga.et.gd_433  be.kk.ru_643 is.fo.eo_543 
  0x474f735a, 0x21121813, 0x4c004009, 0x34007321,   // ny.bi.sn_553 ar.ur.fa_665  lb.wo.un_440 ny.xh.un_860 
  0x080c13a4, 0x29285255, 0x0e004304, 0x234404a7,   // et.sv.no_433 ha.sw.sl_442  ie.is.un_320 ru.kk.ky_532 
  // [1ae00]
  0x2a34620d, 0x13002509, 0x080710a4, 0x2d0d4809,   // kha.xh.mt_554 eu.et.un_440  be.bg.uk_433 tt.cs.sk_444 
  0x22050fa0, 0x080533a0, 0x300e15a0, 0x0c3b330b,   // lv.fr.oc_322 nn.fr.no_322  un.is.uz_322 nn.so.sv_542 
  0x0e2d2e07, 0x3064130c, 0x23221904, 0x1d2e43a0,   // fo.sk.is_432 et.lg.uz_543  gl.oc.ca_332 ie.fo.la_322 
  0x05002220, 0x42220511, 0x2d120d55, 0x10150711,   // oc.fr.un_850 fr.oc.co_653  cs.hu.sk_442 bg.be.un_630 
  // [1ae10]
  0x0e005710, 0x42220513, 0x0b1219a0, 0x03001e05,   // na.is.un_620 fr.oc.co_665  gl.hu.es_322 ms.nl.un_330 
  0x48083060, 0x17083502, 0x25053904, 0x13001821,   // uz.uk.tt_664 tg.uk.sr_222  br.fr.eu_332 ga.et.un_860 
  0x133f03a0, 0x39250504, 0x39652504, 0x13022ead,   // nl.af.et_322 fr.eu.br_332  eu.gv.br_332 fo.da.et_643 
  0x39330207, 0x121a39a7, 0x05392507, 0x51116511,   // da.nn.br_432 br.tl.hu_532  eu.br.fr_432 gv.ro.kl_653 
  // [1ae20]
  0x2c1d030c, 0x392540a9, 0x23001108, 0x03002508,   // nl.la.fy_543 lb.eu.br_544  ro.ca.un_430 eu.nl.un_430 
  0x423605a0, 0x475039a0, 0x3605250c, 0x055a49a4,   // fr.gn.co_322 br.fj.sn_322  eu.fr.gn_543 to.sm.fr_433 
  0x05390f05, 0x40560504, 0x40060c04, 0x15351dee,   // lv.br.fr_333 fr.mg.lb_332  sv.de.lb_332 la.zu.un_422 
  0x533e4202, 0x1f0e2e12, 0x303c25a9, 0x112f1e04,   // co.rm.ht_222 fo.is.cy_654  mn.ug.uz_544 ms.su.ro_332 
  // [1ae30]
  0x170228a4, 0x51006005, 0x21004a0c, 0x392f05ee,   // sw.da.sr_433 vo.kl.un_330  yo.jw.un_530 fr.su.br_422 
  0x10583655, 0x1823210b, 0x5c28020d, 0x20044704,   // gn.om.lt_442 fa.ky.ar_542  da.sw.sa_554 sn.fi.sq_332 
  0x530540a0, 0x29005c07, 0x51604fa4, 0x645613ac,   // lb.fr.ht_322 sa.sl.un_420  bi.vo.kl_433 et.mg.lg_632 
  0x5d424307, 0x35004721, 0x58343507, 0x10374407,   // ie.co.ss_432 sn.zu.un_860  zu.xh.om_432 kk.ba.be_432 
  // [1ae40]
  0x1d3031a0, 0x5d2435a4, 0x32002b0c, 0x5035510c,   // az.uz.la_322 zu.eo.ss_433  vi.bs.un_530 kl.zu.fj_543 
  0x135c04ee, 0x0e0240a6, 0x1500371a, 0x183d300c,   // fi.sa.et_422 lb.da.is_521  ba.un.un_760 uz.ku.ar_543 
  0x070835ee, 0x3d212807, 0x084033ee, 0x37304012,   // tg.uk.bg_422 sd.fa.ku_432  nn.lb.no_422 lb.uz.st_654 
  0x2c005604, 0x214c2f07, 0x48201ba7, 0x56000409,   // mg.fy.un_320 su.wo.jw_432  tr.sq.tt_532 fi.mg.un_440 
  // [1ae50]
  0x1b4831a4, 0x3f374012, 0xfe5f3713, 0x21375f0d,   // az.tt.tr_433 lb.st.af_654  st.tn.tlh_665 tn.st.jw_554 
  0x2c020304, 0x3f0403a4, 0x5f6937af, 0x3e502705,   // nl.da.fy_332 nl.fi.af_433  st.mfe.tn_655 gd.fj.rm_333 
  0x61004022, 0x40003708, 0x033f50af, 0x40001e08,   // lb.za.un_870 st.lb.un_430  fj.af.nl_655 ms.lb.un_430 
  0x30230707, 0x37635fa0, 0x3e190b05, 0x225f3708,   // bg.ky.uz_432 tn.sco.st_322  es.gl.rm_333 st.tn.oc_443 
  // [1ae60]
  0x5f37620d, 0x2000fe08, 0x562d0d55, 0x28033fa7,   // kha.st.tn_554 tlh.sq.un_430  cs.sk.mg_442 af.nl.sw_532 
  0x0a1d1aa0, 0x0b3e27a7, 0x10022c08, 0x19002712,   // tl.la.pt_322 gd.rm.es_532  fy.da.lt_443 gd.gl.un_640 
  0x04133908, 0x1f0a4aad, 0x1a796755, 0x1f313004,   // br.et.fi_443 yo.pt.cy_643  ak.war.tl_442 uz.az.cy_332 
  0x1d584dac, 0x22003508, 0x463001a0, 0x09190b13,   // aa.om.la_632 zu.oc.un_430  en.uz.qu_322 es.gl.pl_665 
  // [1ae70]
  0x2d0d46a4, 0x2d0d2005, 0x20001707, 0x791a250c,   // qu.cs.sk_433 sq.cs.sk_333  sr.sq.un_420 eu.tl.war_543 
  0x5a1d36a7, 0x46300fa9, 0x12004602, 0x172d0d14,   // gn.la.sm_532 lv.uz.qu_544  qu.hu.un_220 cs.sk.sr_666 
  0x374838ee, 0x48070a55, 0x2344380b, 0x210542ee,   // tk.tt.ba_422 mk.bg.tt_442  tk.kk.ky_542 co.fr.jw_422 
  0x10062aee, 0x27002802, 0x2c402f0d, 0x40006113,   // mt.de.lt_422 sw.gd.un_220  su.lb.fy_554 za.lb.un_650 
  // [1ae80]
  0x65182707, 0x0c390207, 0x090118a0, 0x0c2213ad,   // gd.ga.gv_432 da.br.sv_432  ga.en.pl_322 et.oc.sv_643 
  0x26403908, 0x511027a7, 0x031b3107, 0x01122a0c,   // br.lb.ia_443 gd.lt.kl_532  az.tr.nl_432 mt.hu.en_543 
  0x48291707, 0x22003107, 0x48000207, 0x3e003019,   // sr.sl.tt_432 az.oc.un_420  da.tt.un_420 uz.rm.un_750 
  0x3f612aa4, 0x02302cee, 0x3b031304, 0x2c4006ee,   // mt.za.af_433 fy.uz.da_422  et.nl.so_332 de.lb.fy_422 
  // [1ae90]
  0x5a023608, 0x755f0da0, 0x0d5ffeac, 0x5f006008,   // gn.da.sm_443 cs.tn.nso_322  tlh.tn.cs_632 vo.tn.un_430 
  0x5c00030c, 0x0f02090c, 0x5020090c, 0x5c002d07,   // nl.sa.un_530 pl.da.lv_543  pl.sq.fj_543 sk.sa.un_420 
  0x18000510, 0x11001723, 0x24006018, 0x5f7510af,   // fr.ga.un_620 sr.ro.un_880  vo.eo.un_740 lt.nso.tn_655 
  0x1f1239a0, 0x5f1260ac, 0x291f07ad, 0x19000a2a,   // br.hu.cy_322 vo.hu.tn_632  it.cy.sl_643 pt.gl.un_970 
  // [1aea0]
  0x4a053608, 0x55001204, 0x7338690c, 0x6700121a,   // gn.fr.yo_443 hu.rw.un_320  mfe.tk.ny_543 hu.ak.un_760 
  0x643509a4, 0x5f7550ac, 0x285f6407, 0x4568290c,   // pl.zu.lg_433 fj.nso.tn_632  lg.tn.sw_432 sl.ig.ln_543 
  0x5f37600c, 0x29697613, 0x347537a4, 0x31003508,   // vo.st.tn_543 crs.mfe.sl_665  st.nso.xh_433 zu.az.un_430 
  0x040844a0, 0x57fe01ad, 0x0d003b0d, 0x2c3660ac,   // kk.uk.ru_322 en.tlh.na_643  ks.ne.un_540 vo.gn.fy_632 
  // [1aeb0]
  0x251501ee, 0x25374407, 0x28016311, 0x76006936,   // en.eu.un_420 kk.ba.mn_432  sco.en.sw_653 mfe.crs.un_AA0 
  0x30fe4d12, 0x2b003002, 0x07480408, 0x4053200c,   // aa.tlh.uz_654 uz.vi.un_220  ru.tt.bg_443 sq.ht.lb_543 
  0x231101a9, 0x102515a0, 0x0d000e05, 0x12242e12,   // en.ro.ca_544 un.mn.be_322  is.cs.un_330 fo.eo.hu_654 
  0x162e3604, 0x20311b0c, 0x06071507, 0x3e0afe04,   // gn.fo.hr_332 tr.az.sq_543  un.it.de_432 tlh.pt.rm_332 
  // [1aec0]
  0x1500080c, 0x2f002b05, 0x28123411, 0x5e002307,   // uk.un.un_530 vi.su.un_330  ps.ur.sd_653 ca.ts.un_420 
  0x353715a4, 0x2144180b, 0x4300280e, 0x31483804,   // un.ba.tg_433 ar.kk.fa_542  sw.ie.un_550 tk.tt.az_332 
  0x394f23a4, 0x0a1d260d, 0x2e503fad, 0x0400540d,   // ca.bi.br_433 ia.la.pt_554  af.fj.fo_643 ik.fi.un_540 
  0x08022b0c, 0x5a004b19, 0x134b67a4, 0x20000808,   // vi.da.no_543 mi.sm.un_750  ak.mi.et_433 no.sq.un_430 
  // [1aed0]
  0x18011dad, 0x283018ad, 0x20003908, 0x1d262da0,   // la.en.ga_643 ar.uz.sd_643  br.sq.un_430 sk.ia.la_322 
  0x182f0ea0, 0x241d11ee, 0xfe422aa0, 0x01433007,   // is.su.ga_322 ro.la.eo_422  mt.co.tlh_322 uz.ie.en_432 
  0x071036a7, 0x4437150c, 0x37172311, 0x0a074405,   // ab.be.bg_532 un.ba.kk_543  ky.sr.ba_653 kk.bg.mk_333 
  0x1000070c, 0x212f05af, 0x2205fca7, 0x4837250e,   // bg.be.un_530 fr.su.jw_655  zzp.fr.oc_532 mn.ba.tt_555 
  // [1aee0]
  0x10364804, 0x21052f04, 0x440a25a4, 0x6b571aad,   // tt.ab.be_332 su.fr.jw_332  mn.mk.kk_433 tl.na.ceb_643 
  0x69330c0c, 0x65604a04, 0x0a130209, 0x1a6b2808,   // sv.nn.mfe_543 yo.vo.gv_332  da.et.pt_444 sw.ceb.tl_443 
  0x03230107, 0x566a4fa9, 0x24006112, 0x43370d0c,   // en.ca.nl_432 bi.haw.mg_544  za.eo.un_640 cs.st.ie_543 
  0x79271812, 0x7961090c, 0x1b3848a9, 0x02276112,   // ga.gd.war_654 pl.za.war_543  tt.tk.tr_544 za.gd.da_654 
  // [1aef0]
  0x0b005307, 0x332c08a4, 0x5f2201a4, 0x424305a7,   // ht.es.un_420 no.fy.nn_433  en.oc.tn_433 fr.ie.co_532 
  0x465202a0, 0x1a790207, 0x1f033f5a, 0x041511af,   // da.ha.qu_322 da.war.tl_432  af.nl.cy_553 ro.ru.un_650 
  0x34303107, 0x2800470d, 0x300e1ba4, 0x2a004207,   // az.uz.xh_432 sn.sw.un_540  tr.is.uz_433 co.mt.un_420 
  0x56273907, 0x1b383007, 0x1f002a13, 0x4326070c,   // br.gd.mg_432 uz.tk.tr_432  mt.cy.un_650 it.ia.ie_543 
  // [1af00]
  0x352e380c, 0x02180a08, 0x3b3002a4, 0x1b345da0,   // tk.fo.zu_543 pt.ga.da_443  da.uz.so_433 ss.xh.tr_322 
  0x13004713, 0x504728a0, 0x4a641b08, 0x59271804,   // sn.et.un_650 sw.sn.fj_322  tr.lg.yo_443 ga.gd.rn_332 
  0x6356730c, 0x1d0502a4, 0x302112a0, 0x4a6434a0,   // ny.mg.sco_543 da.fr.la_433  ur.fa.uz_322 xh.lg.yo_322 
  0x303831ac, 0x281a1bee, 0x0a560411, 0xfe3130a4,   // az.tk.uz_632 tr.tl.sw_422  fi.mg.pt_653 uz.az.tlh_433 
  // [1af10]
  0x22002b08, 0x53003011, 0x36002108, 0x303604a0,   // vi.oc.un_430 uz.ht.un_630  jw.gn.un_430 ru.ab.uz_322 
  0x38201b0e, 0x2e0e2d09, 0x19220bec, 0x24330809,   // tr.sq.tk_555 sk.is.fo_444  es.oc.gl_644 no.nn.eo_444 
  0x0a173807, 0x24010ca0, 0x36484412, 0x12004409,   // tk.sr.mk_432 sv.en.eo_322  kk.tt.ab_654 kk.ur.un_440 
  0x0e162e07, 0x2b002f09, 0x53080207, 0x391205ee,   // fo.hr.is_432 su.vi.un_440  da.no.ht_432 fr.hu.br_422 
  // [1af20]
  0x360a1708, 0x08350a07, 0x28006a14, 0x6a4b5aec,   // sr.mk.ab_443 mk.tg.uk_432  haw.sw.un_660 sm.mi.haw_644 
  0x2a3901a0, 0x7578faa4, 0x5d5f5ea0, 0x1c3413ad,   // en.br.mt_322 nr.ve.nso_433  ts.tn.ss_322 et.xh.id_643 
  0x0c220511, 0x23240a0d, 0x30001e04, 0x69101ca0,   // fr.oc.sv_653 pt.eo.ca_554  ms.uz.un_320 id.lt.mfe_322 
  0x0a3611ad, 0x02154505, 0x33086e02, 0x0a3905a0,   // ro.gn.pt_643 ln.da.un_330  hmn.no.nn_222 fr.br.pt_322 
  // [1af30]
  0x2e0e0da7, 0x4b115aec, 0x4b001112, 0x0b2e19ee,   // cs.is.fo_532 sm.ro.mi_644  ro.mi.un_640 gl.fo.es_422 
  0x220b19a4, 0x070a4602, 0x421d1104, 0x08302304,   // gl.es.oc_433 qu.pt.it_222  ro.la.co_332 ky.uz.uk_332 
  0x38374812, 0x2e360e13, 0x253508a9, 0x2d0d3902,   // tt.ba.tk_654 is.gn.fo_665  uk.tg.mn_544 br.cs.sk_222 
  0x1330310e, 0x305542a0, 0x423926a0, 0x02513008,   // az.uz.et_555 co.rw.uz_322  ia.br.co_322 uz.kl.da_443 
  // [1af40]
  0x40640704, 0x130a260c, 0x12004205, 0x060e020b,   // it.lg.lb_332 ia.pt.et_543  co.hu.un_330 da.is.de_542 
  0x103048a4, 0x6300fc04, 0x190f0b0c, 0x0b422308,   // tt.uz.lt_433 zzp.sco.un_320  es.lv.gl_543 ca.co.es_443 
  0x02392205, 0x420a0ca7, 0x230a2205, 0x15172512,   // oc.br.da_333 sv.pt.co_532  oc.pt.ca_333 mn.sr.un_654 
  0x091702a7, 0x15000214, 0x2a000911, 0x024379af,   // da.sr.pl_532 da.un.un_660  pl.mt.un_630 war.ie.da_655 
  // [1af50]
  0x20003e07, 0x56002d13, 0x21182304, 0x0e1f02ee,   // rm.sq.un_420 sk.mg.un_650  ky.ar.fa_332 da.cy.is_422 
  0x23041dac, 0xfc0e01a0, 0x111d0708, 0x06001b05,   // la.fi.ca_632 en.is.zzp_322  it.la.ro_443 tr.de.un_330 
  0x080279ee, 0x0f000911, 0x6b5579a9, 0x18443d04,   // war.da.no_422 pl.lv.un_630  war.rw.ceb_544 ku.kk.ar_332 
  0x43245b08, 0x1037730c, 0x0f203209, 0x315f6bad,   // sg.eo.ie_443 ny.st.lt_543  bs.sq.lv_444 ceb.tn.az_643 
  // [1af60]
  0x2e0efeec, 0x4a043605, 0x2f454a07, 0x1057020c,   // tlh.is.fo_644 gn.fi.yo_333  yo.ln.su_432 da.na.lt_543 
  0x73532402, 0x78755fec, 0x37004d12, 0x48005804,   // eo.ht.ny_222 tn.nso.ve_644  aa.st.un_640 om.tt.un_320 
  0x2f004a08, 0x0c004d0b, 0x30003d09, 0x10000821,   // yo.su.un_430 aa.sv.un_520  ku.uz.un_440 uk.be.un_860 
  0x3569290e, 0x190b0205, 0x1d190b55, 0x23004d07,   // sl.mfe.zu_555 da.es.gl_333  es.gl.la_442 aa.ca.un_420 
  // [1af70]
  0x25153608, 0x4a556407, 0x191d4807, 0x190b5ca4,   // ab.mn.un_430 lg.rw.yo_432  tt.la.gl_432 sa.es.gl_433 
  0x1900300d, 0x04245d0c, 0x315b1b12, 0x603033a4,   // uz.gl.un_540 ss.eo.fi_543  tr.sg.az_654 nn.uz.vo_433 
  0x5100570d, 0x485030a0, 0x2f420505, 0x6945fcaf,   // na.kl.un_540 uz.fj.tt_322  fr.co.su_333 zzp.ln.mfe_655 
  0x3d232109, 0x530269a7, 0x48100807, 0x05655360,   // fa.ky.ku_444 mfe.da.ht_532  uk.be.tt_432 ht.gv.fr_664 
  // [1af80]
  0x5300651b, 0x4b001005, 0x0e2e1ea9, 0x47650207,   // gv.ht.un_770 lt.mi.un_330  ms.fo.is_544 da.gv.sn_432 
  0x172315a0, 0x47536508, 0x65534702, 0x2a3748af,   // un.ky.sr_322 gv.ht.sn_443  sn.ht.gv_222 tt.ba.bo_655 
  0x1228210d, 0x47005308, 0x7669530b, 0x10440807,   // fa.sd.ur_554 ht.sn.un_430  ht.mfe.crs_542 uk.kk.be_432 
  0x65002d0d, 0x685564af, 0x1d006402, 0x67006819,   // sk.gv.un_540 lg.rw.ig_655  lg.la.un_220 ig.ak.un_750 
  // [1af90]
  0x0a2313a0, 0x39001f1b, 0x4625040b, 0x595567ec,   // et.ca.pt_322 cy.br.un_770  fi.eu.qu_542 ak.rw.rn_644 
  0x2d0d48a4, 0x561f155a, 0x23420aad, 0x685e64ec,   // tt.cs.sk_433 un.cy.mg_553  pt.co.ca_643 lg.ts.ig_644 
  0xfc571355, 0x37152504, 0x0c023ea4, 0x0e005802,   // et.na.zzp_442 mn.ba.un_320  rm.da.sv_433 om.is.un_220 
  0x4c330860, 0x641f1b05, 0x1f10fcee, 0x602a1507,   // no.nn.wo_664 tr.cy.lg_333  zzp.lt.cy_422 un.mt.vo_432 
  // [1afa0]
  0x25483c07, 0x2d3965a9, 0x76692d07, 0x182301a4,   // ug.tt.mn_432 gv.br.sk_544  sk.mfe.crs_432 en.ca.ga_433 
  0x3500550b, 0x3e251107, 0x190b13a4, 0x58003605,   // rw.zu.un_520 ro.eu.rm_432  et.es.gl_433 gn.om.un_330 
  0x01481fad, 0x1b673f08, 0x15383507, 0x3e311b07,   // cy.tt.en_643 af.ak.tr_443  tg.tk.un_432 tr.az.rm_432 
  0x424a3e05, 0x05245aa4, 0x28005f0c, 0x384844ad,   // rm.yo.co_333 sm.eo.fr_433  tn.sw.un_530 kk.tt.tk_643 
  // [1afb0]
  0x6013480e, 0x2c0601a0, 0x4c1e6209, 0x396a4012,   // tt.et.vo_555 en.de.fy_322  kha.ms.wo_444 lb.haw.br_654 
  0x630962a9, 0x0a3511a0, 0x44170a07, 0xfe6326a0,   // kha.pl.sco_544 ro.tg.mk_322  mk.sr.kk_432 ia.sco.tlh_322 
  0x3f030da4, 0x3f595508, 0x210338a9, 0x4c3048a4,   // cs.nl.af_433 rw.rn.af_443  tk.nl.jw_544 tt.uz.wo_433 
  0x15382512, 0x36001709, 0x531062ec, 0x3130fe08,   // mn.tk.un_654 sr.ab.un_440  kha.lt.ht_644 tlh.uz.az_443 
  // [1afc0]
  0x3f3960a9, 0x0400670e, 0x5c2a6013, 0x6a104aa9,   // vo.br.af_544 ak.fi.un_550  vo.mt.sa_665 yo.lt.haw_544 
  0x0b0a24a4, 0x2d006e0d, 0x39792c13, 0x1d5a26af,   // eo.pt.es_433 hmn.sk.un_540  fy.war.br_665 ia.sm.la_655 
  0x281844a4, 0x59002c14, 0x07170aac, 0x06634355,   // kk.ar.sd_433 fy.rn.un_660  mk.sr.bg_632 ie.sco.de_442 
  0x1d3e1fa0, 0x0b794a0c, 0x072d1fa0, 0x470a3b0c,   // cy.rm.la_322 yo.war.es_543  cy.sk.it_322 so.pt.sn_543 
  // [1afd0]
  0x3b1f1aa7, 0x0d553504, 0x28525ea7, 0x2e1812a4,   // tl.cy.so_532 zu.rw.cs_332  ts.ha.sw_532 hu.ga.fo_433 
  0x04001f02, 0x13001019, 0x04222007, 0x3e43420c,   // cy.fi.un_220 lt.et.un_750  sq.oc.fi_432 co.ie.rm_543 
  0x0839330c, 0x25200407, 0x1f3f390c, 0x1a246aa4,   // nn.br.no_543 fi.sq.eu_432  br.af.cy_543 haw.eo.tl_433 
  0x53003002, 0x5d002105, 0x383723a4, 0x061b3802,   // uz.ht.un_220 jw.ss.un_330  ky.ba.tk_433 tk.tr.de_222 
  // [1afe0]
  0x29170f0c, 0x0a0410a7, 0x17381160, 0x3500250b,   // lv.sr.sl_543 be.ru.mk_532  ro.tk.sr_664 mn.tg.un_520 
  0x213d3ca0, 0x12184404, 0x17100812, 0xfe003908,   // ug.ku.fa_322 kk.ar.ur_332  uk.be.sr_654 br.tlh.un_430 
  0x00000e37, 0x282112a7, 0x2d006e07, 0x170a110d,   // is.un.un_B00 ur.fa.sd_532  hmn.sk.un_420 ro.mk.sr_554 
  0x04100709, 0x1c566804, 0x150962ad, 0x26002019,   // bg.be.ru_444 ig.mg.id_332  kha.pl.un_643 sq.ia.un_750 
  // [1aff0]
  0x04111555, 0x496867ee, 0x15040107, 0x52621c0c,   // un.ro.ru_442 ak.ig.to_422  en.fi.un_432 id.kha.ha_543 
  0x2c003804, 0x1f016ba0, 0x05000d0c, 0x13006721,   // tk.fy.un_320 ceb.en.cy_322  cs.fr.un_530 ak.et.un_860 
  0x2e125d07, 0x3e300107, 0x583b5b04, 0x2c153fa0,   // ss.hu.fo_432 en.uz.rm_432  sg.so.om_332 af.fy.un_320 
  0x255f4da9, 0x231d2608, 0x25605208, 0x0c2c0304,   // aa.tn.eu_544 ia.la.ca_443  ha.vo.eu_443 nl.fy.sv_332 
  
  // [1b000]
  0x3e56520c, 0x01654da7, 0x072a1d04, 0x30315c04,   // ha.mg.rm_543 aa.gv.en_532  la.mt.it_332 sa.az.uz_332 
  0x4c313b13, 0x56006e22, 0x5500fc04, 0x070a1105,   // so.az.wo_665 hmn.mg.un_870  zzp.rw.un_320 ro.mk.bg_333 
  0x0804370c, 0x400d03a0, 0x6718580c, 0x55106009,   // ba.ru.uk_543 nl.cs.lb_322  om.ga.ak_543 vo.lt.rw_444 
  0x3b3130a4, 0x34005d13, 0x1b005d0c, 0x2f561e07,   // uz.az.so_433 ss.xh.un_650  ss.tr.un_530 ms.mg.su_432 
  // [1b010]
  0x1d00280c, 0x5300240b, 0x213d1807, 0x0a002d13,   // sw.la.un_530 eo.ht.un_520  ar.ku.fa_432 sk.pt.un_650 
  0x4823300d, 0x043608a7, 0xfc001113, 0x30213da9,   // uz.ky.tt_554 uk.ab.ru_532  ro.zzp.un_650 ku.fa.uz_544 
  0x08381507, 0x3c00340c, 0x4c171611, 0x07480a05,   // un.tk.uk_432 ps.ug.un_530  hr.sr.wo_653 mk.tt.bg_333 
  0x234435a0, 0x6200611a, 0x1b002804, 0x10484411,   // tg.kk.ky_322 za.kha.un_760  sw.tr.un_320 kk.tt.be_653 
  // [1b020]
  0x58004902, 0x63330805, 0x760c3307, 0x0a000d09,   // to.om.un_220 no.nn.sco_333  nn.sv.crs_432 cs.pt.un_440 
  0x2a000912, 0x30001719, 0x76600107, 0x30672109,   // pl.mt.un_640 sr.uz.un_750  en.vo.crs_432 jw.ak.uz_444 
  0x534530ec, 0x153f4004, 0x733e30ad, 0x30375208,   // uz.ln.ht_644 lb.af.un_332  uz.rm.ny_643 ha.st.uz_443 
  0x21732805, 0x1c2f1e55, 0x303537a4, 0x5f677511,   // sw.ny.jw_333 ms.su.id_442  ba.tg.uz_433 nso.ak.tn_653 
  // [1b030]
  0x5f347508, 0x3f012ca9, 0x23422207, 0x383525ec,   // nso.xh.tn_443 fy.en.af_544  oc.co.ca_432 mn.tg.tk_644 
  0x73003008, 0x253b4cee, 0x2f53300c, 0x2829305a,   // uz.ny.un_430 wo.so.eu_422  uz.ht.su_543 uz.sl.sw_553 
  0x31755fa9, 0x42003e0c, 0x1c2b0207, 0x2b000c04,   // tn.nso.az_544 rm.co.un_530  da.vi.id_432 sv.vi.un_320 
  0x31120ca0, 0x2d2a5eee, 0x2b002607, 0x364204a4,   // sv.hu.az_322 ts.mt.sk_422  ia.vi.un_420 fi.co.gn_433 
  // [1b040]
  0x3b4610ee, 0x4b424912, 0x2b003304, 0x3d341211,   // lt.qu.so_422 to.co.mi_654  nn.vi.un_320 ur.ps.ku_653 
  0x1f00120c, 0x1f1d12a0, 0x1537040d, 0x04420708,   // hu.cy.un_530 hu.la.cy_322  ru.ba.un_554 it.co.fi_443 
  0x02001213, 0x285851ec, 0x080267a4, 0x12006712,   // hu.da.un_650 kl.om.sw_644  ak.da.no_433 ak.hu.un_640 
  0x5a3b5855, 0x12183cee, 0x122c6404, 0x121f6704,   // om.so.sm_442 ug.ar.ur_422  lg.fy.hu_332 ak.cy.hu_332 
  // [1b050]
  0x08000414, 0x1f00620c, 0x3b584d12, 0x12184aec,   // ru.uk.un_660 kha.cy.un_530  aa.om.so_654 yo.ga.hu_644 
  0x3021180c, 0x54005219, 0x481b3108, 0x3736230c,   // ar.fa.uz_543 ha.ik.un_750  az.tr.tt_443 ky.ab.ba_543 
  0x4750610c, 0x043711ee, 0x2f005219, 0x194a3607,   // za.fj.sn_543 ro.ba.ru_422  ha.su.un_750 gn.yo.gl_432 
  0x19182207, 0x792d4a07, 0x52005019, 0x0b191807,   // oc.ga.gl_432 yo.sk.war_432  fj.ha.un_750 ga.gl.es_432 
  // [1b060]
  0x044815ee, 0x23304407, 0x5f344a07, 0x222f050c,   // un.tt.ru_422 kk.uz.ky_432  yo.xh.tn_432 fr.su.oc_543 
  0x190b4aa4, 0x190e1807, 0x184a2d0b, 0x34006804,   // yo.es.gl_433 ga.is.gl_432  sk.yo.ga_542 ig.xh.un_320 
  0x73643408, 0x073025a7, 0x3400310b, 0x1d3b580c,   // xh.lg.ny_443 eu.uz.it_532  az.xh.un_520 om.so.la_543 
  0x4a4207a4, 0x251d26ad, 0x4c303113, 0x17381508,   // it.co.yo_433 ia.la.eu_643  az.uz.wo_665 un.tk.sr_443 
  // [1b070]
  0x063176ee, 0x3e003407, 0x363015a4, 0x051d0107,   // crs.az.de_422 xh.rm.un_420  un.uz.ab_433 en.la.fr_432 
  0x1815010c, 0x100a36ee, 0x343b210b, 0x50300b02,   // en.ga.un_530 ab.mk.be_422  fa.ks.ps_542 es.uz.fj_222 
  0x192802a0, 0x0d362e07, 0x100a17ad, 0x4415045a,   // da.sw.gl_322 fo.gn.cs_432  sr.mk.be_643 ru.kk.un_530 
  0x050b01af, 0x0e0d2da0, 0x5d630107, 0x12281804,   // en.es.fr_655 sk.cs.is_322  en.sco.ss_432 ar.sd.ur_332 
  // [1b080]
  0x53002b02, 0x18007905, 0x202a32a4, 0x2821300d,   // vi.ht.un_220 war.ga.un_330  bs.mt.sq_433 uz.fa.sd_554 
  0x0d2d0ea0, 0x0417300d, 0x29230202, 0x4a2d36a4,   // is.sk.cs_322 uz.sr.ru_554  da.ca.sl_222 gn.sk.yo_433 
  0x2b152704, 0x3400550d, 0x081d22a0, 0x04105607,   // gd.vi.un_320 rw.xh.un_540  oc.la.no_322 mg.lt.fi_432 
  0x3f2e030c, 0x1b42fe0d, 0x32001d0c, 0x32080204,   // nl.fo.af_543 tlh.co.tr_554  la.bs.un_530 da.no.bs_332 
  // [1b090]
  0x4207240c, 0x17002913, 0x425c0708, 0x63007909,   // eo.it.co_543 sl.sr.un_650  it.sa.co_443 war.sco.un_440 
  0x12004c04, 0x051d39ee, 0x5633260c, 0x04300aa4,   // wo.hu.un_320 br.la.fr_422  ia.nn.mg_543 mk.uz.ru_433 
  0x3217600c, 0x36765307, 0x5c010fa4, 0x69530f0c,   // vo.sr.bs_543 ht.crs.gn_432  lv.en.sa_433 lv.ht.mfe_543 
  0x114f0fec, 0x0a08100d, 0x1218280d, 0x17040a0b,   // lv.bi.ro_644 be.uk.mk_554  sd.ar.ur_554 mk.ru.sr_542 
  // [1b0a0]
  0x44231812, 0x12190508, 0x2508300c, 0x4c2f19a9,   // ar.ky.kk_654 fr.gl.hu_443  uz.uk.mn_543 gl.su.wo_544 
  0x3b5828ee, 0x1f7347af, 0x12fe24ad, 0x1c095cad,   // sw.om.so_422 sn.ny.cy_655  eo.tlh.hu_643 sa.hi.mr_643 
  0x5b003413, 0x274057a0, 0x23002217, 0x40021fa4,   // xh.sg.un_650 na.lb.gd_322  oc.ca.un_730 cy.da.lb_433 
  0x01024007, 0x1e1c11a9, 0x0c2f0107, 0x3727180c,   // lb.da.en_432 ro.id.ms_544  en.su.sv_432 ga.gd.st_543 
  // [1b0b0]
  0x2b01fc0c, 0x4000210d, 0x39001222, 0xfc3e63af,   // zzp.en.vi_543 jw.lb.un_540  hu.br.un_870 sco.rm.zzp_655 
  0x1b133007, 0x2a003b0c, 0x302f01a0, 0x1f5f75ad,   // uz.et.tr_432 so.mt.un_530  en.su.uz_322 nso.tn.cy_643 
  0x1d004222, 0x0f2039a4, 0x36001905, 0x38005c19,   // co.la.un_870 br.sq.lv_433  gl.gn.un_330 sa.tk.un_750 
  0x1b022707, 0x02271811, 0x651c02ee, 0x22004814,   // gd.da.tr_432 ga.gd.da_653  da.id.gv_422 tt.oc.un_660 
  // [1b0c0]
  0x1f27fcee, 0x1b3801a0, 0x02631ea0, 0x43060f05,   // zzp.gd.cy_422 en.tk.tr_322  ms.sco.da_322 lv.de.ie_333 
  0x11261ea4, 0x101f0204, 0x58fe460c, 0x655e610c,   // ms.ia.ro_433 da.cy.lt_332  qu.tlh.om_543 za.ts.gv_543 
  0x610850ec, 0x40060208, 0xfe791b07, 0x181357ad,   // fj.no.za_644 da.de.lb_443  tr.war.tlh_432 na.et.ga_643 
  0x3b300f0c, 0x2321220c, 0x104240a4, 0x4c006321,   // lv.uz.so_543 oc.jw.ca_543  lb.co.lt_433 sco.wo.un_860 
  // [1b0d0]
  0x30214407, 0x0d4a0e08, 0x37361704, 0x1715075a,   // kk.fa.uz_432 is.yo.cs_443  sr.ab.ba_332 bg.sr.un_530 
  0xfa005905, 0x232535a4, 0x785e730c, 0x07151005,   // rn.nr.un_330 tg.mn.ky_433  ny.ts.ve_543 be.bg.un_330 
  0x102308a9, 0x375860a0, 0x03001e04, 0x1b001f08,   // uk.ky.be_544 vo.om.st_322  ms.nl.un_320 cy.tr.un_430 
  0x15382360, 0x1f604d0c, 0x153b4da0, 0x5d00550d,   // ky.tk.un_664 aa.vo.cy_543  aa.so.un_322 rw.ss.un_540 
  // [1b0e0]
  0x1000090e, 0x65001507, 0x53001e02, 0x32001b02,   // pl.lt.un_550 un.gv.un_420  ms.ht.un_220 tr.bs.un_220 
  0x5800020e, 0x30731fad, 0x403b02ee, 0x3b13090d,   // da.om.un_550 cy.ny.uz_643  da.so.lb_422 hi.bh.ks_554 
  0x161b310c, 0x041258a7, 0x0d0910a0, 0x2f00110d,   // az.tr.hr_543 om.hu.fi_532  lt.pl.cs_322 ro.su.un_540 
  0x11003b1a, 0x0d5c1c02, 0x18342113, 0x7300400d,   // so.ro.un_760 mr.sa.ne_222  fa.ps.ar_665 lb.ny.un_540 
  // [1b0f0]
  0x48232507, 0x48103712, 0x0f004e19, 0x52006805,   // mn.ky.tt_432 ba.be.tt_654  ay.lv.un_750 ig.ha.un_330 
  0x0804350c, 0x441015a0, 0x0a074404, 0x24276507,   // tg.ru.uk_543 un.be.kk_322  kk.bg.mk_332 gv.gd.eo_432 
  0x322916ee, 0x25001e05, 0x2b454e07, 0x51736907,   // hr.sl.bs_422 ms.eu.un_330  ay.ln.vi_432 mfe.ny.kl_432 
  0x3b500105, 0x38170a60, 0x341c2ba0, 0x213d3011,   // en.fj.so_333 mk.sr.tk_664  vi.id.xh_322 uz.ku.fa_653 
  // [1b100]
  0x056b01a0, 0x2b000f04, 0x23004308, 0x480a3502,   // en.ceb.fr_322 lv.vi.un_320  ie.ca.un_430 tg.mk.tt_222 
  0x363708a9, 0x07081004, 0x051d5812, 0x17071112,   // uk.ba.ab_544 be.uk.bg_332  om.la.fr_654 ro.bg.sr_654 
  0x4c000513, 0x584d300c, 0x174448a0, 0x08103c04,   // fr.wo.un_650 uz.aa.om_543  tt.kk.sr_322 ug.be.uk_332 
  0x03005602, 0x3c152314, 0x484437a7, 0x08000b02,   // mg.nl.un_220 ky.ug.un_660  ba.kk.tt_532 es.no.un_220 
  // [1b110]
  0x48070a02, 0x0c00fe0b, 0x08104411, 0x35443c5a,   // mk.bg.tt_222 tlh.sv.un_520  kk.be.uk_653 ug.kk.tg_553 
  0x2400790b, 0x53004319, 0x351015a0, 0x33080aaf,   // war.eo.un_520 ie.ht.un_750  un.be.tg_322 pt.no.nn_655 
  0x0723440c, 0x17083507, 0x1b005005, 0x5afc510c,   // kk.ky.bg_543 tg.uk.sr_432  fj.tr.un_330 kl.zzp.sm_543 
  0x12222f04, 0x275322a7, 0x23225308, 0x2a1b3108,   // su.oc.hu_332 oc.ht.gd_532  ht.oc.ca_443 az.tr.mt_443 
  // [1b120]
  0x35300a0d, 0x10040712, 0x2d0d23ee, 0x0500fc04,   // mk.uz.tg_554 bg.ru.be_654  ca.cs.sk_422 zzp.fr.un_320 
  0x3c6a11ec, 0xfc52010c, 0x423e2d08, 0x07360a04,   // ro.haw.ug_644 en.ha.zzp_543  sk.rm.co_443 mk.ab.bg_332 
  0x2f1222ad, 0x4a12195a, 0x5a002d04, 0x39155355,   // oc.hu.su_643 gl.hu.yo_553  sk.sm.un_320 ht.br.un_420 
  0x170a35a7, 0x3bfc5c0c, 0x05630da0, 0x19003602,   // tg.mk.sr_532 sa.zzp.so_543  cs.sco.fr_322 gn.gl.un_220 
  // [1b130]
  0x12004309, 0x35073004, 0x46002b04, 0x39632aee,   // ie.hu.un_440 uz.bg.tg_332  vi.qu.un_320 mt.sco.br_422 
  0x2a5856af, 0x0f003911, 0x33512e0b, 0x614f0f13,   // mg.om.mt_655 br.lv.un_630  fo.kl.nn_542 lv.bi.za_665 
  0x5c00270b, 0x3f000336, 0x0bfe01a4, 0x0f00092a,   // gd.sa.un_520 nl.af.un_AA0  en.tlh.es_433 pl.lv.un_970 
  0x6800fc13, 0x763f0313, 0x0d6301a4, 0x21122f08,   // zzp.ig.un_650 nl.af.crs_665  en.sco.cs_433 su.hu.jw_443 
  // [1b140]
  0x1100390d, 0x6300391b, 0x0f3901a0, 0x05000804,   // br.ro.un_540 br.sco.un_770  en.br.lv_322 no.fr.un_320 
  0x57033f0c, 0x536923a9, 0x3b34650c, 0x65184e04,   // af.nl.na_543 ca.mfe.ht_544  gv.xh.so_543 ay.ga.gv_332 
  0x06000704, 0x7669030c, 0x685559ad, 0x6300012a,   // it.de.un_320 nl.mfe.crs_543  rn.rw.ig_643 en.sco.un_970 
  0x030625af, 0x0f000308, 0xfe02395a, 0x7663010c,   // eu.de.nl_655 nl.lv.un_430  br.da.tlh_553 en.sco.crs_543 
  // [1b150]
  0x080c3909, 0x5256790c, 0x6b301307, 0x53004d2a,   // br.sv.no_444 war.mg.ha_543  et.uz.ceb_432 aa.ht.un_970 
  0x0d001217, 0x20fe1ba4, 0x4a50790c, 0x44003c35,   // hu.cs.un_730 tr.tlh.sq_433  war.fj.yo_543 ug.kk.un_A90 
  0x17352307, 0x1840360c, 0x081511a4, 0x2d0d40a0,   // ky.tg.sr_432 gn.lb.ga_543  ro.uk.un_430 lb.cs.sk_322 
  0x52345ca0, 0x75255f13, 0x361f3ead, 0x0c5823a4,   // sa.xh.ha_322 tn.eu.nso_665  rm.cy.gn_643 ca.om.sv_433 
  // [1b160]
  0x3c003418, 0x4000360b, 0x1b005213, 0x0d2d36a9,   // ps.ug.un_740 gn.lb.un_520  ha.tr.un_650 gn.sk.cs_544 
  0x3d3b34ec, 0x303b19a9, 0x2348440d, 0x2136790c,   // ps.ks.ku_644 gl.so.uz_544  kk.tt.ky_554 war.gn.jw_543 
  0x240afea4, 0x30123404, 0x1800400d, 0x05401811,   // tlh.pt.eo_433 ps.ur.uz_332  lb.ga.un_540 ga.lb.fr_653 
  0x1200400e, 0x170a040c, 0x5c091c02, 0x53052202,   // lb.hu.un_550 ru.mk.sr_543  mr.hi.sa_222 oc.fr.ht_222 
  // [1b170]
  0x240a26a4, 0x02002d05, 0x3849375a, 0x49600b08,   // ia.pt.eo_433 sk.da.un_330  st.to.tk_553 es.vo.to_443 
  0x4b1056a0, 0x020815a4, 0x103508a4, 0x2f001220,   // mg.lt.mi_322 un.no.da_433  uk.tg.be_433 hu.su.un_850 
  0x090a2daf, 0x12050eee, 0x47190a08, 0x305f2108,   // sk.pt.pl_655 is.fr.hu_422  pt.gl.sn_443 jw.tn.uz_443 
  0x38234807, 0xfe003b0d, 0x0c361d08, 0x0a000518,   // tt.ky.tk_432 so.tlh.un_540  la.gn.sv_443 fr.pt.un_740 
  // [1b180]
  0x2f0512ee, 0x07111509, 0x15113505, 0x651a380b,   // hu.fr.su_422 un.ro.bg_444  tg.ro.un_333 tk.tl.gv_542 
  0x651238ee, 0x651a12af, 0x421205a4, 0x64651204,   // tk.hu.gv_422 hu.tl.gv_655  fr.hu.co_433 hu.gv.lg_332 
  0x2a5d35a7, 0x22050a08, 0x402d0d0b, 0x34000913,   // zu.ss.mt_532 pt.fr.oc_443  cs.sk.lb_542 pl.xh.un_650 
  0x23441512, 0x25103704, 0x05214504, 0x35250209,   // un.kk.ky_654 ba.be.mn_332  ln.jw.fr_332 da.eu.zu_444 
  // [1b190]
  0x1a382104, 0x402f36b2, 0xfa5d350c, 0x0500190c,   // jw.tk.tl_332 gn.su.lb_732  zu.ss.nr_543 gl.fr.un_530 
  0x1d002405, 0x2f00380d, 0x31521b0c, 0x30006309,   // eo.la.un_330 tk.su.un_540  tr.ha.az_543 sco.uz.un_440 
  0x17484412, 0x645d3507, 0x64125ca4, 0x0276690d,   // kk.tt.sr_654 zu.ss.lg_432  sa.hu.lg_433 mfe.crs.da_554 
  0x04151014, 0x40050ba0, 0x1f3909ad, 0x5c5e1207,   // be.ru.un_660 es.fr.lb_322  pl.br.cy_643 hu.ts.sa_432 
  // [1b1a0]
  0x101bfe0c, 0x3800670d, 0x09007813, 0x5c023807,   // tlh.tr.lt_543 ak.tk.un_540  ve.pl.un_650 tk.da.sa_432 
  0x4d003819, 0x30234307, 0x33000504, 0x10793804,   // tk.aa.un_750 ie.ca.uz_432  fr.nn.un_320 tk.war.lt_332 
  0x6300fc13, 0x10313f5a, 0x46095eaf, 0x402534a9,   // zzp.sco.un_650 af.az.lt_553  ts.pl.qu_655 xh.eu.lb_544 
  0x31341ba4, 0x29003505, 0x1a00280d, 0x111c1e0c,   // tr.xh.az_433 zu.sl.un_330  sw.tl.un_540 ms.id.ro_543 
  // [1b1b0]
  0x35345fee, 0x22364012, 0x2f3640a4, 0x073735ee,   // tn.xh.zu_422 lb.gn.oc_654  lb.gn.su_433 tg.ba.bg_422 
  0x40000514, 0x170823ad, 0x0b5605ee, 0x04081108,   // fr.lb.un_660 ky.uk.sr_643  fr.mg.es_422 ro.uk.ru_443 
  0x37233508, 0x0b00550c, 0x31002308, 0x595568af,   // tg.ky.ba_443 rw.es.un_530  ca.az.un_430 ig.rw.rn_655 
  0x645569ee, 0x4844235a, 0x36004008, 0x443530a4,   // mfe.rw.lg_422 ky.kk.tt_553  lb.gn.un_430 uz.tg.kk_433 
  // [1b1c0]
  0x390742a9, 0x5300421b, 0x0d2d36b3, 0x07041560,   // co.it.br_544 co.ht.un_770  gn.sk.cs_743 un.ru.bg_664 
  0x2d002104, 0x290e2cad, 0x382d0da4, 0x32160209,   // jw.sk.un_320 fy.is.sl_643  cs.sk.tk_433 da.hr.bs_444 
  0x1c130da9, 0x4655590c, 0x2f612304, 0x28000205,   // ne.bh.mr_544 rn.rw.qu_543  ca.za.su_332 da.sw.un_330 
  0x0b0a40a0, 0x12000505, 0x03433fec, 0x230512a6,   // lb.pt.es_322 fr.hu.un_330  af.ie.nl_644 hu.fr.ca_521 
  // [1b1d0]
  0x15070a13, 0x0d362307, 0x3d1230ee, 0x12003630,   // mk.bg.un_665 ca.gn.cs_432  uz.ur.ku_422 gn.hu.un_A40 
  0x36001218, 0x181236bb, 0x565c01a4, 0x605650a9,   // hu.gn.un_740 gn.hu.ga_854  en.sa.mg_433 fj.mg.vo_544 
  0x2240180c, 0x3600151b, 0x0b004026, 0x655763ad,   // ga.lb.oc_543 un.ab.un_770  lb.es.un_930 sco.na.gv_643 
  0x0d2312b2, 0x30601008, 0x1d5c510c, 0x3600400d,   // hu.ca.cs_732 lt.vo.uz_443  kl.sa.la_543 lb.gn.un_540 
  // [1b1e0]
  0x1b121da0, 0x080423ad, 0x50261da7, 0x210b4007,   // la.hu.tr_322 ky.ru.uk_643  la.ia.fj_532 lb.es.jw_432 
  0x5c003f0d, 0x3700230b, 0x10175ea4, 0x30005c1b,   // af.sa.un_540 ky.ba.un_520  ts.sr.lt_433 sa.uz.un_770 
  0x51fc560c, 0x5c1d5eac, 0x58001502, 0x4005121d,   // mg.zzp.kl_543 ts.la.sa_632  un.om.un_220 hu.fr.lb_852 
  0x73355eee, 0x400a12ac, 0x4000121f, 0x0a40120c,   // ts.zu.ny_422 hu.pt.lb_632  hu.lb.un_840 hu.lb.pt_543 
  // [1b1f0]
  0x101d5ca4, 0x67006e29, 0x30513108, 0x3e005a04,   // sa.la.lt_433 hmn.ak.un_960  az.kl.uz_443 sm.rm.un_320 
  0xfc624508, 0x26001d2b, 0x48443604, 0x0a081005,   // ln.kha.zzp_443 la.ia.un_980  ab.kk.tt_332 be.uk.mk_333 
  0xfc6531ec, 0x10233605, 0x250a1005, 0x37003c22,   // az.gv.zzp_644 ab.ky.be_333  be.mk.mn_333 ug.ba.un_870 
  0x39002518, 0x4f2d65ad, 0x281830ec, 0x070415ad,   // eu.br.un_740 gv.sk.bi_643  uz.ar.sd_644 un.ru.bg_643 
  // [1b200]
  0x28002d02, 0x2f000510, 0x2a001a04, 0x491d2409,   // sk.sw.un_220 fr.su.un_620  tl.mt.un_320 eo.la.to_444 
  0x2f796aaf, 0x4f504b0c, 0x40604a04, 0x5e244f11,   // haw.war.su_655 mi.fj.bi_543  yo.vo.lb_332 bi.eo.ts_653 
  0x124c0eac, 0x455f2960, 0x5e007514, 0x1e00470b,   // is.wo.hu_632 sl.tn.ln_664  nso.ts.un_660 sn.ms.un_520 
  0x16005202, 0x404c2004, 0x120e4308, 0x35080a02,   // ha.hr.un_220 sq.wo.lb_332  ie.is.hu_443 mk.uk.tg_222 
  // [1b210]
  0x252124ee, 0x5c4528a4, 0x1905400c, 0x600426af,   // eo.jw.eu_422 sw.ln.sa_433  lb.fr.gl_543 ia.fi.vo_655 
  0x42360e12, 0x132446a0, 0x57024b08, 0x347347a4,   // is.gn.co_654 qu.eo.et_322  mi.da.na_443 sn.ny.xh_433 
  0x4d581f12, 0x380a0704, 0x53004a0b, 0x28584d0e,   // cy.om.aa_654 bg.mk.tk_332  yo.ht.un_520 aa.om.sw_555 
  0x214667ee, 0x1535300e, 0x15220507, 0x044430ee,   // ak.qu.jw_422 uz.tg.un_555  fr.oc.un_432 uz.kk.ru_422 
  // [1b220]
  0x12343d09, 0x2a101304, 0x2c162904, 0x28584d0c,   // ku.ps.ur_444 et.lt.mt_332  sl.hr.fy_332 aa.om.sw_543 
  0x38215ca4, 0x58523bee, 0xfe1230a0, 0x2000480e,   // sa.jw.tk_433 so.ha.om_422  uz.hu.tlh_322 tt.sq.un_550 
  0x04005309, 0x3d4423a7, 0x36122da0, 0xfe002405,   // ht.fi.un_440 ky.kk.ku_532  sk.hu.gn_322 eo.tlh.un_330 
  0x3d3c34a4, 0x34123005, 0x3464350c, 0x07001e02,   // ps.ug.ku_433 uz.ur.ps_333  zu.lg.xh_543 ms.it.un_220 
  // [1b230]
  0x32311bee, 0x3900530b, 0x380a0760, 0x15081108,   // tr.az.bs_422 ht.br.un_520  bg.mk.tk_664 ro.uk.un_443 
  0x15000c0c, 0x15003f12, 0x05422304, 0x20004014,   // sv.un.un_530 af.un.un_640  ca.co.fr_332 lb.sq.un_660 
  0x240715ee, 0x6b002304, 0x2e006e04, 0x1d000a09,   // un.it.eo_422 ca.ceb.un_320  hmn.fo.un_320 pt.la.un_440 
  0x17150808, 0x2e246707, 0x3c040708, 0x51005a0e,   // uk.sr.un_430 ak.eo.fo_432  bg.ru.ug_443 sm.kl.un_550 
  // [1b240]
  0x53000505, 0x13515aa0, 0x16002f02, 0x30003c2a,   // fr.ht.un_330 sm.kl.et_322  su.hr.un_220 ug.uz.un_970 
  0x444837a9, 0x22004205, 0x233825ad, 0x48061b04,   // ba.tt.kk_544 co.oc.un_330  mn.tk.ky_643 tr.de.tt_332 
  0x171507a4, 0x443c3755, 0x1f060eee, 0x420522ad,   // bg.sr.un_430 ba.ug.kk_442  is.de.cy_422 oc.fr.co_643 
  0x49007904, 0x3e563f02, 0x3e130607, 0x5a000604,   // war.to.un_320 af.mg.rm_222  de.et.rm_432 de.sm.un_320 
  // [1b250]
  0x0323226d, 0x123418ec, 0x3e3806ad, 0x31384813,   // oc.ca.nl_874 ar.ps.ur_644  de.tk.rm_643 tt.tk.az_665 
  0x06001104, 0x23002808, 0x3e00601a, 0x53004a07,   // ro.de.un_320 sd.ky.un_430  vo.rm.un_760 yo.ht.un_420 
  0x213418ac, 0x35001019, 0x401f0608, 0x381b1205,   // ar.ps.fa_632 be.tg.un_750  de.cy.lb_443 hu.tr.tk_333 
  0x13003813, 0x2c0b4055, 0x3e00060b, 0x06481ba7,   // tk.et.un_650 lb.es.fy_442  de.rm.un_520 tr.tt.de_532 
  // [1b260]
  0x463054ad, 0x1d000302, 0x38211b12, 0x052322a0,   // ik.uz.qu_643 nl.la.un_220  tr.jw.tk_654 oc.ca.fr_322 
  0x06003104, 0x45006804, 0x2f2155ee, 0x386b790c,   // az.de.un_320 ig.ln.un_320  rw.jw.su_422 war.ceb.tk_543 
  0x3000540b, 0x31353408, 0x0800fe12, 0xfe004609,   // ik.uz.un_520 xh.zu.az_443  tlh.no.un_640 qu.tlh.un_440 
  0x403e0607, 0x5535340d, 0x48301507, 0x153e010c,   // de.rm.lb_432 xh.zu.rw_554  un.uz.tt_432 en.rm.un_543 
  // [1b270]
  0x3e0301a7, 0x134b600c, 0x4000130d, 0x79066055,   // en.nl.rm_532 vo.mi.et_543  et.lb.un_540 vo.de.war_442 
  0x463e0107, 0x150165a0, 0x35003707, 0x3800440c,   // en.rm.qu_432 gv.en.un_322  ba.tg.un_420 kk.tk.un_530 
  0x29005305, 0x18212fee, 0x23374809, 0x233c380c,   // ht.sl.un_330 su.jw.ga_422  tt.ba.ky_444 tk.ug.ky_543 
  0x073548a9, 0x61000308, 0x283b12a4, 0x5300290e,   // tt.tg.bg_544 nl.za.un_430  ur.ks.sd_433 sl.ht.un_550 
  // [1b280]
  0x17002002, 0x3e696404, 0x3e004722, 0x122f1902,   // sq.sr.un_220 lg.mfe.rm_332  sn.rm.un_870 gl.su.hu_222 
  0x12212f05, 0x733435a4, 0x477345ec, 0x03321704,   // su.jw.hu_333 zu.xh.ny_433  ln.ny.sn_644 sr.bs.nl_332 
  0x0a1744a4, 0x07473e0c, 0x06223e04, 0x29004307,   // kk.sr.mk_433 rm.sn.it_543  rm.oc.de_332 ie.sl.un_420 
  0x55476407, 0x22fc0707, 0x114745a0, 0x063138ad,   // lg.sn.rw_432 it.zzp.oc_432  ln.sn.ro_322 tk.az.de_643 
  // [1b290]
  0x45594712, 0x0e2e25a0, 0x481b3102, 0x081723a4,   // sn.rn.ln_654 eu.fo.is_322  az.tr.tt_222 ky.sr.uk_433 
  0x07593e08, 0x0458420c, 0x2d28120c, 0x42005807,   // rm.rn.it_443 co.om.fi_543  hu.sw.sk_543 om.co.un_420 
  0x353436a9, 0x655801a0, 0x020f2b0e, 0x35042ba0,   // gn.xh.zu_544 en.om.gv_322  vi.lv.da_555 vi.fi.zu_322 
  0x2b060402, 0x1b13040b, 0x022d0305, 0x122f21a0,   // fi.de.vi_222 fi.et.tr_542  nl.sk.da_333 jw.su.hu_322 
  // [1b2a0]
  0x42002f02, 0x081723ad, 0x1b1379a0, 0x15000f12,   // su.co.un_220 ky.sr.uk_643  war.et.tr_322 lv.un.un_640 
  0x2b001002, 0x0f152b08, 0x15253caf, 0x2d0f15a4,   // lt.vi.un_220 vi.lv.un_430  ug.mn.un_655 un.lv.sk_433 
  0x102b04a0, 0x43066008, 0x10396907, 0x0f0301a4,   // fi.vi.lt_322 vo.de.ie_443  mfe.br.lt_432 en.nl.lv_433 
  0x100f0455, 0x48221da0, 0x0700100e, 0x0f002b04,   // fi.lv.lt_442 la.oc.tt_322  be.bg.un_550 vi.lv.un_320 
  // [1b2b0]
  0x31384810, 0x18004005, 0x231218a9, 0x373c250e,   // tt.tk.az_642 lb.ga.un_330  ar.ur.ky_544 mn.ug.ba_555 
  0x25311b0c, 0x15040a04, 0x311b0604, 0x12381b12,   // tr.az.eu_543 mk.ru.un_332  de.tr.az_332 tr.tk.hu_654 
  0x48040707, 0x1b1331a0, 0x03053f04, 0x12067908,   // bg.ru.tt_432 az.et.tr_322  af.fr.nl_332 war.de.hu_443 
  0x192306a0, 0x0d362d0c, 0x36052d07, 0x0d000e09,   // de.ca.gl_322 sk.gn.cs_543  sk.fr.gn_432 is.cs.un_440 
  // [1b2c0]
  0x061b570d, 0x063e38ee, 0x570679ec, 0x31381ba6,   // na.tr.de_554 tk.rm.de_422  war.de.na_644 tr.tk.az_521 
  0x424005ad, 0x0d0e2d07, 0x492f6aa4, 0x39030502,   // fr.lb.co_643 sk.is.cs_432  haw.su.to_433 fr.nl.br_222 
  0x79006b08, 0x1328020c, 0x29366a0c, 0x3049390c,   // ceb.war.un_430 da.sw.et_543  haw.gn.sl_543 br.to.uz_543 
  0x535e4aa0, 0x6b5c1014, 0x48063ea4, 0x752056a4,   // yo.ts.ht_322 lt.sa.ceb_666  rm.de.tt_433 mg.sq.nso_433 
  // [1b2d0]
  0x024b490c, 0x580b100c, 0x1b0638b2, 0x1afe790c,   // to.mi.da_543 lt.es.om_543  tk.de.tr_732 war.tlh.tl_543 
  0x0e0d2dee, 0x074924a6, 0x1a1958a4, 0x190b5805,   // sk.cs.is_422 eo.to.it_521  om.gl.tl_433 om.es.gl_333 
  0x332e030c, 0x28005c08, 0x1b133102, 0x1108380c,   // nl.fo.nn_543 sa.sw.un_430  az.et.tr_222 tk.uk.ro_543 
  0x0a196055, 0x5f6402a7, 0x1007150d, 0x5efc0aec,   // vo.gl.pt_442 da.lg.tn_532  un.bg.be_554 pt.zzp.ts_644 
  // [1b2e0]
  0x556b5904, 0x5d452b12, 0x555936ad, 0x373615ad,   // rn.ceb.rw_332 vi.ln.ss_654  gn.rn.rw_643 un.ab.ba_643 
  0x37253507, 0x20000f07, 0xfe002505, 0x0e4625ee,   // tg.mn.ba_432 lv.sq.un_420  eu.tlh.un_330 eu.qu.is_422 
  0x182a47a0, 0x475d3409, 0x48443805, 0x5c0e2e13,   // sn.mt.ga_322 xh.ss.sn_444  tk.kk.tt_333 fo.is.sa_665 
  0x18004719, 0x52300e04, 0x1d421109, 0x47002b08,   // sn.ga.un_750 is.uz.ha_332  ro.co.la_444 vi.sn.un_430 
  // [1b2f0]
  0x1b182713, 0x020c1802, 0x2200270c, 0x1c095cac,   // gd.ga.tr_665 ga.sv.da_222  gd.oc.un_530 sa.hi.mr_632 
  0x49734b08, 0x422445a4, 0x37422511, 0x28595512,   // mi.ny.to_443 ln.eo.co_433  eu.co.st_653 rw.rn.sw_654 
  0x130f02ad, 0x47425f55, 0x393622a0, 0x5a25590c,   // da.lv.et_643 tn.co.sn_442  oc.gn.br_322 rn.eu.sm_543 
  0x231d265a, 0x354634ad, 0x45005205, 0x36004208,   // ia.la.ca_553 xh.qu.zu_643  ha.ln.un_330 co.gn.un_430 
  // [1b300]
  0x30373507, 0x0b361d04, 0x73001b0c, 0x35002322,   // tg.ba.uz_432 la.gn.es_332  tr.ny.un_530 ky.tg.un_870 
  0x51033507, 0x35647307, 0x4b0225a4, 0x3f392a0b,   // zu.nl.kl_432 ny.lg.zu_432  eu.da.mi_433 mt.br.af_542 
  0x02285005, 0x495a4ba7, 0x58002e08, 0x2a002c02,   // fj.sw.da_333 mi.sm.to_532  fo.om.un_430 fy.mt.un_220 
  0x2a003f08, 0x18443b0c, 0x23374813, 0x2a004012,   // af.mt.un_430 ks.kk.ar_543  tt.ba.ky_665 lb.mt.un_640 
  // [1b310]
  0x2a004e13, 0x2a4009ec, 0x1d28fca4, 0x0a3707ee,   // ay.mt.un_650 pl.lb.mt_644  zzp.sw.la_433 bg.ba.mk_422 
  0x092c4004, 0x220126a0, 0x34301260, 0x3e00060c,   // lb.fy.pl_332 ia.en.oc_322  ur.uz.ps_664 de.rm.un_530 
  0x170c060c, 0x1ffe2ca0, 0x630c0107, 0x0c001e08,   // de.sv.sr_543 fy.tlh.cy_322  en.sv.sco_432 ms.sv.un_430 
  0x180233a7, 0x290916a4, 0x0200042b, 0x056501a0,   // nn.da.ga_532 hr.pl.sl_433  fi.da.un_980 en.gv.fr_322 
  // [1b320]
  0x38304e0d, 0x0c0d2d0c, 0x5c1c0dac, 0x190556a0,   // ay.uz.tk_554 sk.cs.sv_543  ne.mr.sa_632 mg.fr.gl_322 
  0x2c00200b, 0x583031af, 0x11016b04, 0x3500481a,   // sq.fy.un_520 az.uz.om_655  ceb.en.ro_332 tt.tg.un_760 
  0x1a001007, 0x15202ca0, 0x2c001f13, 0x0d0e2da0,   // lt.tl.un_420 fy.sq.un_322  cy.fy.un_650 sk.is.cs_322 
  0x180e1905, 0x27003204, 0x30004c04, 0x13004807,   // gl.is.ga_333 bs.gd.un_320  wo.uz.un_320 tt.et.un_420 
  // [1b330]
  0x2912fc11, 0x374436a0, 0x3200fc04, 0x10001719,   // zzp.hu.sl_653 ab.kk.ba_322  zzp.bs.un_320 sr.be.un_750 
  0x2e020507, 0x4778550c, 0x182a6904, 0x0c00400c,   // fr.da.fo_432 rw.ve.sn_543  mfe.mt.ga_332 lb.sv.un_530 
  0x067969a4, 0x0a020555, 0x05000204, 0x4b003402,   // mfe.war.de_433 fr.da.pt_442  da.fr.un_320 xh.mi.un_220 
  0x1233580c, 0x3b7613a9, 0x3f40030d, 0x20005822,   // om.nn.hu_543 et.crs.so_544  nl.lb.af_554 om.sq.un_870 
  // [1b340]
  0x0320fca4, 0x03fc3faf, 0x3b002a1a, 0x2d001e02,   // zzp.sq.nl_433 af.zzp.nl_655  mt.so.un_760 ms.sk.un_220 
  0x2e3302a0, 0x1d43260d, 0x3b285c12, 0xfe032205,   // da.nn.fo_322 ia.ie.la_554  sa.sw.so_654 oc.nl.tlh_333 
  0x42063ea0, 0x27182860, 0x24000802, 0x42555d08,   // rm.de.co_322 sw.ga.gd_664  no.eo.un_220 ss.rw.co_443 
  0x2721280c, 0x1500fe0e, 0x585c21ad, 0x3f057904,   // sw.jw.gd_543 tlh.un.un_550  jw.sa.om_643 war.fr.af_332 
  // [1b350]
  0x67fe30ac, 0x40000311, 0x42472808, 0x184727ee,   // uz.tlh.ak_632 nl.lb.un_630  sw.sn.co_443 gd.sn.ga_422 
  0x10001f05, 0x130724a7, 0x0300011a, 0x21285caf,   // cy.lt.un_330 eo.it.et_532  en.nl.un_760 sa.sw.jw_655 
  0x21205c09, 0x1c213b0c, 0x1f003f02, 0x5d45670c,   // sa.sq.jw_444 so.jw.id_543  af.cy.un_220 ak.ln.ss_543 
  0x18344404, 0x2c3f030d, 0x2c001114, 0x043515ee,   // kk.ps.ar_332 nl.af.fy_554  ro.fy.un_660 un.tg.ru_422 
  // [1b360]
  0x23480755, 0x3c3723ec, 0x22425360, 0x351523af,   // bg.tt.ky_442 ky.ba.ug_644  ht.co.oc_664 ky.tg.un_650 
  0x30443711, 0x153837a4, 0x3c301511, 0x0e000f1a,   // ba.kk.uz_653 ba.tk.un_433  un.uz.ug_653 lv.is.un_760 
  0x37001112, 0x1d26fcec, 0x0f4204a4, 0x09320f0c,   // ro.ba.un_640 zzp.ia.la_644  fi.co.lv_433 lv.bs.pl_543 
  0x343d2812, 0x09100fa0, 0x18002b02, 0x5002360d,   // sd.ku.ps_654 lv.lt.pl_322  vi.ga.un_220 gn.da.fj_554 
  // [1b370]
  0x50000913, 0x0c000502, 0x2f482104, 0x07001102,   // pl.fj.un_650 fr.sv.un_220  jw.tt.su_332 ro.it.un_220 
  0x0f0e2e60, 0x1800611b, 0x201e4807, 0x0e000f08,   // fo.is.lv_664 za.ga.un_770  tt.ms.sq_432 lv.is.un_430 
  0x186427a4, 0x4e005713, 0x605301a0, 0x52001f08,   // gd.lg.ga_433 na.ay.un_650  en.ht.vo_322 cy.ha.un_430 
  0x18273b02, 0x1234440c, 0x0f003908, 0x10043fa0,   // so.gd.ga_222 kk.ps.ur_543  br.lv.un_430 af.fi.lt_322 
  // [1b380]
  0x63421507, 0x2a000419, 0x3f0f2da4, 0x153038ac,   // un.co.sco_432 fi.mt.un_750  sk.lv.af_433 tk.uz.un_632 
  0x63fc0f0d, 0x633f2a07, 0x033f2aa4, 0x11000321,   // lv.zzp.sco_554 mt.af.sco_432  mt.af.nl_433 nl.ro.un_860 
  0x152508af, 0x31551ba0, 0x042d2b02, 0x063f0b0c,   // uk.mn.un_655 tr.rw.az_322  vi.sk.fi_222 es.af.de_543 
  0x5d2923ee, 0x08002402, 0x2c3f030b, 0x170a0711,   // ca.sl.ss_422 eo.no.un_220  nl.af.fy_542 bg.mk.sr_653 
  // [1b390]
  0x3f00030b, 0x37231005, 0xfe2d0daf, 0x1108175a,   // nl.af.un_520 be.ky.ba_333  cs.sk.tlh_655 sr.uk.ro_553 
  0x170a040b, 0x370407ec, 0x47001102, 0x130a11a0,   // ru.mk.sr_542 bg.ru.ba_644  ro.sn.un_220 ro.pt.et_322 
  0x28005219, 0x0b001d02, 0x3e5a28ad, 0x18001f19,   // ha.sw.un_750 la.es.un_220  sw.sm.rm_643 cy.ga.un_750 
  0x291109a4, 0x0d2911af, 0x15483705, 0x39432655,   // pl.ro.sl_433 ro.sl.cs_655  ba.tt.un_333 ia.ie.br_442 
  // [1b3a0]
  0x4f011107, 0xfc066507, 0x11000904, 0x6518fcee,   // ro.en.bi_432 gv.de.zzp_432  pl.ro.un_320 zzp.ga.gv_422 
  0x014f5802, 0x29110dee, 0x3e222307, 0x11290904,   // om.bi.en_222 cs.ro.sl_422  ca.oc.rm_432 pl.sl.ro_332 
  0x0d11290c, 0x1500610c, 0x1109290c, 0x4c2911a4,   // sl.ro.cs_543 za.un.un_530  sl.pl.ro_543 ro.sl.wo_433 
  0x234428af, 0x290d110c, 0x52004608, 0x4000200d,   // sd.kk.ky_655 ro.cs.sl_543  qu.ha.un_430 sq.lb.un_540 
  // [1b3b0]
  0x42360512, 0x371015a0, 0x2c005b11, 0x65271d05,   // fr.gn.co_654 un.be.ba_322  sg.fy.un_630 la.gd.gv_333 
  0x372548ec, 0x654226a0, 0x0d00fe05, 0x261d01a9,   // tt.mn.ba_644 ia.co.gv_322  tlh.cs.un_330 en.la.ia_544 
  0x36002005, 0x12343dec, 0x0600110d, 0x301737a4,   // sq.gn.un_330 ku.ps.ur_644  ro.de.un_540 ba.sr.uz_433 
  0x2c363fa0, 0x1f3e010c, 0x19360bad, 0x233c1012,   // af.gn.fy_322 en.rm.cy_543  es.gn.gl_643 be.ug.ky_654 
  // [1b3c0]
  0x3e0311a0, 0x28001102, 0x5a113fa7, 0x3f1d11a0,   // ro.nl.rm_322 ro.sw.un_220  af.ro.sm_532 ro.la.af_322 
  0x5a0663ee, 0xfc00680e, 0x27004c04, 0x37000802,   // sco.de.sm_422 ig.zzp.un_550  wo.gd.un_320 uk.ba.un_220 
  0x1e4759a4, 0x04135d04, 0x1c281e55, 0x03154307,   // rn.sn.ms_433 ss.et.fi_332  ms.sw.id_442 ie.nl.un_420 
  0x2f555104, 0x355902a0, 0x56470107, 0x11300b08,   // kl.rw.su_332 da.rn.zu_322  en.sn.mg_432 es.uz.ro_443 
  // [1b3d0]
  0x4a003805, 0x11004507, 0x364815ad, 0x25005208,   // tk.yo.un_330 ln.ro.un_420  un.tt.ab_643 ha.eu.un_430 
  0x212925a4, 0x1e2151a9, 0x63001d08, 0x1c0b27ee,   // eu.sl.jw_433 kl.jw.ms_544  la.sco.un_430 gd.es.id_422 
  0x30fe280c, 0x34443ca0, 0x08002522, 0x1c305c55,   // sw.tlh.uz_543 ug.kk.ps_322  mn.uk.un_870 sa.uz.id_442 
  0x196543a0, 0x2456070c, 0x2f094aee, 0x4b5636a0,   // ie.gv.gl_322 it.mg.eo_543  yo.pl.su_422 gn.mg.mi_322 
  // [1b3e0]
  0x023e2f0c, 0x196056a9, 0xfc361ea4, 0x10001e04,   // su.rm.da_543 mg.vo.gl_544  ms.gn.zzp_433 ms.lt.un_320 
  0x303b51af, 0x7900230e, 0x4f005712, 0x2a232da0,   // kl.so.uz_655 ca.war.un_550  na.bi.un_640 sk.ca.mt_322 
  0x06000f04, 0x58005304, 0x65606211, 0x18122860,   // lv.de.un_320 ht.om.un_320  kha.vo.gv_653 sd.ur.ar_664 
  0x10000505, 0x2d6206ec, 0x06690f05, 0x33003908,   // fr.lt.un_330 de.kha.sk_644  lv.mfe.de_333 br.nn.un_430 
  // [1b3f0]
  0x011506a4, 0x2a610fa4, 0x1d0625a0, 0x050311a4,   // de.en.un_430 lv.za.mt_433  eu.de.la_322 ro.nl.fr_433 
  0x2e33080c, 0x3b002109, 0x35345d04, 0x3800041a,   // no.nn.fo_543 fa.ks.un_440  ss.xh.zu_332 fi.tk.un_760 
  0x100817ec, 0x021f6260, 0x032d050c, 0x454958af,   // sr.uk.be_644 kha.cy.da_664  fr.sk.nl_543 om.to.ln_655 
  0x272a1fad, 0x0f06010b, 0x32000c02, 0x30442355,   // cy.mt.gd_643 en.de.lv_542  sv.bs.un_220 ky.kk.uz_442 
  
  // [1b400]
  0x2a2501a4, 0x35000308, 0x28064c04, 0x5a004207,   // en.eu.mt_433 nl.zu.un_430  wo.de.sw_332 co.sm.un_420 
  0x171123ad, 0x10363507, 0x3c002521, 0x30390504,   // ky.ro.sr_643 tg.ab.be_432  mn.ug.un_860 fr.br.uz_332 
  0x3c3d44ee, 0x351711a7, 0x0500250d, 0x07360409,   // kk.ku.ug_422 ro.sr.tg_532  eu.fr.un_540 ru.ab.bg_444 
  0x05211809, 0x530539ee, 0x3e30520c, 0x2cfc6560,   // ga.jw.fr_444 br.fr.ht_422  ha.uz.rm_543 gv.zzp.fy_664 
  // [1b410]
  0x10294dee, 0x392c65a0, 0x203b4d0c, 0x48002102,   // aa.sl.lt_422 gv.fy.br_322  aa.so.sq_543 jw.tt.un_220 
  0x02fc2caf, 0x12001604, 0x3076690c, 0x1d6301a0,   // fy.zzp.da_655 hr.hu.un_320  mfe.crs.uz_543 en.sco.la_322 
  0x481b01a0, 0x3b001912, 0x58006e09, 0x0c571308,   // en.tr.tt_322 gl.so.un_640  hmn.om.un_440 et.na.sv_443 
  0x1b553004, 0x0a1017ad, 0x692610a9, 0x3bfe310c,   // uz.rw.tr_332 sr.be.mk_643  lt.ia.mfe_544 az.tlh.so_543 
  // [1b420]
  0x46001807, 0x0a4417a7, 0x04250813, 0x13243bad,   // ga.qu.un_420 sr.kk.mk_532  uk.mn.ru_665 so.eo.et_643 
  0x3b302404, 0x37483504, 0x13303b04, 0x380e3f12,   // eo.uz.so_332 tg.tt.ba_332  so.uz.et_332 af.is.tk_654 
  0x561205a0, 0x15040a0d, 0x17072304, 0x08153007,   // fr.hu.mg_322 mk.ru.un_554  ky.bg.sr_332 uz.uk.un_420 
  0x18613604, 0x50520210, 0x46006309, 0x11000214,   // gn.za.ga_332 da.ha.fj_642  sco.qu.un_440 da.ro.un_660 
  // [1b430]
  0x0f612a0d, 0x083f2a04, 0x503440a4, 0x023f620c,   // mt.za.lv_554 mt.af.no_332  lb.xh.fj_433 kha.af.da_543 
  0x05003f0e, 0x1f18600c, 0x0f043f14, 0x2d006111,   // af.fr.un_550 vo.ga.cy_543  af.fi.lv_666 za.sk.un_630 
  0x092c2d55, 0x0910670e, 0x44251507, 0x27006112,   // sk.fy.pl_442 ak.lt.pl_555  un.mn.kk_432 za.gd.un_640 
  0x3f000f08, 0x46284755, 0x02006314, 0x47001805,   // lv.af.un_430 sn.sw.qu_442  sco.da.un_660 ga.sn.un_330 
  // [1b440]
  0x2d001f04, 0x470f36a4, 0x21003023, 0x2847500c,   // cy.sk.un_320 gn.lv.sn_433  uz.fa.un_880 fj.sn.sw_543 
  0x43022712, 0x2513570c, 0x63005713, 0x390f1055,   // gd.da.ie_654 na.et.eu_543  na.sco.un_650 lt.lv.br_442 
  0x032a3fa4, 0x19110b09, 0x1d00fc21, 0x180627ee,   // af.mt.nl_433 es.ro.gl_444  zzp.la.un_860 gd.de.ga_422 
  0x0c04fcee, 0x65030407, 0x02fc2e0c, 0x213034a4,   // zzp.fi.sv_422 fi.nl.gv_432  fo.zzp.da_543 ps.uz.fa_433 
  // [1b450]
  0x090c3308, 0x6b012108, 0x0c002c12, 0x42002322,   // nn.sv.pl_443 jw.en.ceb_443  fy.sv.un_640 ca.co.un_870 
  0x330c2aa9, 0x3c3444a0, 0x220553a7, 0x08101709,   // mt.sv.nn_544 kk.ps.ug_322  ht.fr.oc_532 sr.be.uk_444 
  0x53003909, 0x213428a9, 0x23371007, 0x04374804,   // br.ht.un_440 sd.ps.fa_544  be.ba.ky_432 tt.ba.ru_332 
  0x30380aa4, 0x34583511, 0x4d495f08, 0x07253604,   // mk.tk.uz_433 zu.om.xh_653  tn.to.aa_443 ab.mn.bg_332 
  // [1b460]
  0x4a4029a4, 0x4a52370c, 0x03000f05, 0x40261d08,   // sl.lb.yo_433 st.ha.yo_543  lv.nl.un_330 la.ia.lb_443 
  0x79fe6705, 0x08170407, 0x4648fea0, 0x036bfe55,   // ak.tlh.war_333 ru.sr.uk_432  tlh.tt.qu_322 tlh.ceb.nl_442 
  0x381b3105, 0x13003811, 0x5d000f08, 0x135cfea0,   // az.tr.tk_333 tk.et.un_630  lv.ss.un_430 tlh.sa.et_322 
  0x32470fa0, 0x34474aa0, 0x193e3607, 0x074c24a0,   // lv.sn.bs_322 yo.sn.xh_322  gn.rm.gl_432 eo.wo.it_322 
  // [1b470]
  0x374975a9, 0x31001b29, 0x0624feee, 0x13313009,   // nso.to.st_544 tr.az.un_960  tlh.eo.de_422 uz.az.et_444 
  0x2d005c11, 0x3430fe0d, 0x0d5c095a, 0x04303cad,   // sa.sk.un_630 tlh.uz.xh_554  hi.sa.ne_553 ug.uz.ru_643 
  0x171504ad, 0x1e1a59ec, 0x55591c11, 0x283b52a4,   // ru.sr.un_630 rn.tl.ms_644  id.rn.rw_653 ha.so.sw_433 
  0x79190a0d, 0x2d003502, 0x592555a9, 0x32006304,   // pt.gl.war_554 zu.sk.un_220  rw.eu.rn_544 sco.bs.un_320 
  // [1b480]
  0x675455a9, 0x2e0e3b0c, 0x213d3b12, 0x3b3020a4,   // rw.ik.ak_544 so.is.fo_543  ks.ku.fa_654 sq.uz.so_433 
  0x2e300c08, 0x304832a0, 0x4700780c, 0x2d00470d,   // sv.uz.fo_443 bs.tt.uz_322  ve.sn.un_530 sn.sk.un_540 
  0x06fc3005, 0x2e0c3808, 0x25001111, 0x02000c22,   // uz.zzp.de_333 tk.sv.fo_443  ro.mn.un_630 sv.da.un_870 
  0x213c300c, 0x3100200c, 0x0000192d, 0x242a0708,   // uz.ug.fa_543 sq.az.un_530  gl.un.un_A00 it.mt.eo_443 
  // [1b490]
  0x154817ee, 0x2e004804, 0x283b34a4, 0x131079a0,   // sr.tt.un_422 tt.fo.un_320  ps.ks.sd_433 war.lt.et_322 
  0x30001e08, 0x09135c55, 0x38003b0d, 0x1c0c0807,   // ms.uz.un_430 sa.bh.hi_442  so.tk.un_540 no.sv.id_432 
  0x5a003f04, 0x022e08a4, 0x22020c07, 0x30003b14,   // af.sm.un_320 no.fo.da_433  sv.da.oc_432 so.uz.un_660 
  0x16092904, 0x0d022dec, 0x09002007, 0x17002a05,   // sl.pl.hr_332 sk.da.cs_644  sq.pl.un_420 mt.sr.un_330 
  // [1b4a0]
  0x6100340e, 0x18003c0b, 0x37041002, 0x12301809,   // xh.za.un_550 ug.ar.un_520  be.ru.ba_222 ar.uz.ur_444 
  0x48003022, 0x37443805, 0x170a04af, 0x4b001102,   // uz.tt.un_870 tk.kk.ba_333  ru.mk.sr_655 ro.mi.un_220 
  0x4b003723, 0x3b6852a9, 0x58242a08, 0x4d286814,   // st.mi.un_880 ha.ig.so_544  mt.eo.om_443 ig.sw.aa_666 
  0x21fe4a09, 0x3e313b07, 0x3517080b, 0x4a005808,   // yo.tlh.jw_444 so.az.rm_432  uk.sr.tg_542 om.yo.un_430 
  // [1b4b0]
  0x580e1ca0, 0x2f1e1ca9, 0x184a4c0d, 0x256858a9,   // id.is.om_322 id.ms.su_544  wo.yo.ga_554 om.ig.eu_544 
  0x685625a4, 0x3b4a520c, 0x44002102, 0x505f4a09,   // eu.mg.ig_433 ha.yo.so_543  fa.kk.un_220 yo.tn.fj_444 
  0x0a001c0d, 0x040a11a6, 0x25595555, 0xfe483108,   // id.pt.un_540 ro.mk.ru_521  rw.rn.eu_442 az.tt.tlh_443 
  0x13110cad, 0x4c2a5b0d, 0x4c362804, 0x10020ca0,   // sv.ro.et_643 sg.mt.wo_554  sw.gn.wo_332 sv.da.lt_322 
  // [1b4c0]
  0x591d55a4, 0x63656707, 0x1d076507, 0x09240204,   // rw.la.rn_433 ak.gv.sco_432  gv.it.la_432 da.eo.pl_332 
  0x34006407, 0x425e64ec, 0x22793e55, 0x43020fad,   // lg.xh.un_420 lg.ts.co_644  rm.war.oc_442 lv.da.ie_643 
  0x0f471512, 0x26230b0c, 0x531d01a0, 0x5525590b,   // un.sn.lv_654 es.ca.ia_543  en.la.ht_322 rn.eu.rw_542 
  0x010b09ee, 0x2d0f06a9, 0x0a081055, 0x3e3f0107,   // pl.es.en_422 de.lv.sk_544  be.uk.mk_442 en.af.rm_432 
  // [1b4d0]
  0x225605ad, 0x13271807, 0x2b1865ee, 0x17202aa4,   // fr.mg.oc_643 ga.gd.et_432  gv.ga.vi_422 mt.sq.sr_433 
  0x253c150c, 0x28002502, 0x481710ee, 0x37003c05,   // un.ug.mn_543 eu.sw.un_220  be.sr.tt_422 ug.ba.un_330 
  0x44380a08, 0x38004408, 0x343c4404, 0x233015ac,   // mk.tk.kk_443 kk.tk.un_430  kk.ug.ps_332 un.uz.ky_632 
  0x0a0817a7, 0x34004c05, 0x36005b0c, 0x1f003821,   // sr.uk.mk_532 wo.xh.un_330  sg.gn.un_530 tk.cy.un_860 
  // [1b4e0]
  0x4800232a, 0x28003013, 0x1c32160d, 0x3200fe0b,   // ky.tt.un_970 uz.sw.un_650  hr.bs.id_554 tlh.bs.un_520 
  0x48442305, 0x48001719, 0x5d245c04, 0x25374408,   // ky.kk.tt_333 sr.tt.un_750  sa.eo.ss_332 kk.ba.mn_443 
  0x080d2904, 0x5d62fa0c, 0x5c1f18a9, 0xfc271fa9,   // sl.cs.no_332 nr.kha.ss_543  ga.cy.sa_544 cy.gd.zzp_544 
  0x12000b07, 0x17374808, 0x2718fcaf, 0x2d000e04,   // es.hu.un_420 tt.ba.sr_443  zzp.ga.gd_655 is.sk.un_320 
  // [1b4f0]
  0xfc625c05, 0x0717080e, 0x06311ba0, 0x35001113,   // sa.kha.zzp_333 uk.sr.bg_555  tr.az.de_322 ro.tg.un_650 
  0x0b000e0d, 0x37003609, 0x18342308, 0x28211860,   // is.es.un_540 ab.ba.un_440  ky.ps.ar_443 ar.fa.sd_664 
  0x12000c11, 0x480444a0, 0x12303b04, 0x18005904,   // sv.hu.un_630 kk.ru.tt_322  ks.uz.ur_332 rn.ga.un_320 
  0x653560a0, 0x4000630d, 0x0e0657ad, 0x11182807,   // vo.zu.gv_322 sco.lb.un_540  na.de.is_643 sw.ga.ro_432 
  // [1b500]
  0x2a00640e, 0x73525f0c, 0x28123013, 0x183c2805,   // lg.mt.un_550 tn.ha.ny_543  uz.ur.sd_665 sd.ug.ar_333 
  0x0735230c, 0x072538a7, 0x13004f05, 0x40061307,   // ky.tg.bg_543 tk.mn.bg_532  bi.et.un_330 et.de.lb_432 
  0x03101302, 0x3138300c, 0x3f400ea0, 0x52000802,   // et.lt.nl_222 uz.tk.az_543  is.lb.af_322 no.ha.un_220 
  0x06fc0ca0, 0x10690407, 0x230b0aa9, 0x03203f08,   // sv.zzp.de_322 fi.mfe.lt_432  pt.es.ca_544 af.sq.nl_443 
  // [1b510]
  0x08033f04, 0x380f48a6, 0x435a1304, 0x104437a9,   // af.nl.no_332 tt.lv.tk_521  et.sm.ie_332 ba.kk.be_544 
  0x183f39a9, 0x15002e04, 0x123418a7, 0x04102e07,   // br.af.ga_544 fo.un.un_320  ar.ps.ur_532 fo.lt.fi_432 
  0x430306a0, 0x391f1804, 0x0300240c, 0x15015705,   // de.nl.ie_322 ga.cy.br_332  eo.nl.un_530 na.en.un_333 
  0x182443a0, 0x0a0811a4, 0x073b27a0, 0x04081709,   // ie.eo.ga_322 ro.uk.mk_433  gd.so.it_322 sr.uk.ru_444 
  // [1b520]
  0x170738a4, 0x78003522, 0x3b00060c, 0x3534470e,   // tk.bg.sr_433 zu.ve.un_870  de.so.un_530 sn.xh.zu_555 
  0x636101a0, 0x47282aa7, 0x05002a02, 0xfe2f2112,   // en.za.sco_322 mt.sw.sn_532  mt.fr.un_220 jw.su.tlh_654 
  0xfe005412, 0x3e59550d, 0xfe611a0c, 0x4f001c0d,   // ik.tlh.un_640 rw.rn.rm_554  tl.za.tlh_543 id.bi.un_540 
  0x1d112007, 0x1d2542a4, 0x61002b22, 0x62fe2bec,   // sq.ro.la_432 co.eu.la_433  vi.za.un_870 vi.tlh.kha_644 
  // [1b530]
  0x4563010c, 0x1c3e2fee, 0x2f214009, 0x4735345a,   // en.sco.ln_543 su.rm.id_422  lb.jw.su_444 xh.zu.sn_553 
  0x4215050c, 0x420a0502, 0x46180555, 0x542b620c,   // fr.co.un_530 fr.pt.co_222  fr.ga.qu_442 kha.vi.ik_543 
  0x241720ee, 0xfe0163ee, 0x6020280c, 0x481004af,   // sq.sr.eo_422 sco.en.tlh_422  sw.sq.vo_543 ru.be.tt_655 
  0x65004705, 0x024207a9, 0x080c2b07, 0x33083ba0,   // sn.gv.un_330 it.co.da_544  vi.sv.no_432 so.no.nn_322 
  // [1b540]
  0x1d07200c, 0x595520af, 0x364005a4, 0x0a381108,   // sq.it.la_543 sq.rw.rn_655  fr.lb.gn_433 ro.tk.mk_443 
  0x1215fc07, 0x0e00fc1a, 0x1c000911, 0x0a004407,   // zzp.hu.un_420 zzp.is.un_760  hi.mr.un_630 kk.mk.un_420 
  0x35080a0c, 0x15384413, 0x30274802, 0x431503ee,   // mk.uk.tg_543 kk.tk.un_665  tt.gd.uz_222 nl.ie.un_420 
  0x1a1e10a9, 0x180c0609, 0x632e0e5a, 0x03004308,   // lt.ms.tl_544 de.sv.ga_444  is.fo.sco_553 ie.nl.un_430 
  // [1b550]
  0x1c0d13a9, 0x07351508, 0x150444a4, 0x10000102,   // bh.ne.mr_544 un.tg.bg_443  kk.ru.un_433 en.lt.un_220 
  0x160329a4, 0x0a1936ac, 0x11003e05, 0x22111da0,   // sl.nl.hr_433 gn.gl.pt_632  rm.ro.un_330 la.ro.oc_322 
  0x0559220d, 0x0f2451a9, 0x04135808, 0x0f5124ee,   // oc.rn.fr_554 kl.eo.lv_544  om.et.fi_443 eo.kl.lv_422 
  0x2e00450d, 0x28241304, 0x56003707, 0x22305d0c,   // ln.fo.un_540 et.eo.sw_332  st.mg.un_420 ss.uz.oc_543 
  // [1b560]
  0x1e1c29a0, 0x243b51ee, 0x2700200c, 0x3d123012,   // sl.id.ms_322 kl.so.eo_422  sq.gd.un_530 uz.ur.ku_654 
  0x58261da4, 0x3d123b08, 0x1e1c28a4, 0x30753713,   // la.ia.om_433 ks.ur.ku_443  sw.id.ms_433 st.nso.uz_665 
  0x343b2855, 0x341d28a0, 0x0f3924a4, 0x21527811,   // sd.ks.ps_442 sw.la.xh_322  eo.br.lv_433 ve.ha.jw_653 
  0x512413a7, 0x3035fa0c, 0x510264a7, 0x07041008,   // et.eo.kl_532 nr.zu.uz_543  lg.da.kl_532 be.ru.bg_443 
  // [1b570]
  0x120905ee, 0x50002007, 0x3400641a, 0x29222360,   // fr.pl.hu_422 sq.fj.un_420  lg.xh.un_760 ca.oc.sl_664 
  0x0d2909af, 0x5b00360e, 0x16002807, 0x350730a9,   // pl.sl.cs_655 gn.sg.un_550  sw.hr.un_420 uz.bg.tg_544 
  0x30fe5812, 0x3c003414, 0x4c054a0c, 0x304c5108,   // om.tlh.uz_654 ps.ug.un_660  yo.fr.wo_543 kl.wo.uz_443 
  0x10083509, 0x6b181d07, 0x48003c04, 0x2800340b,   // tg.uk.be_444 la.ga.ceb_432  ug.tt.un_320 ps.sd.un_520 
  // [1b580]
  0x170823a0, 0x0a232513, 0x0f2d1005, 0x2f464812,   // ky.uk.sr_322 mn.ky.mk_665  lt.sk.lv_333 tt.qu.su_654 
  0x212322ad, 0x236563a7, 0x213d12ec, 0x2367220b,   // oc.ca.jw_643 sco.gv.ca_532  ur.ku.fa_644 oc.ak.ca_542 
  0x34734711, 0x11190a0c, 0x42001c08, 0x42162da0,   // sn.ny.xh_653 pt.gl.ro_543  id.co.un_430 sk.hr.co_322 
  0x353b3404, 0x32164202, 0x255e3b11, 0x5d551107,   // xh.so.zu_332 co.hr.bs_222  so.ts.eu_653 ro.rw.ss_432 
  // [1b590]
  0x2d0d01ee, 0x5d231d04, 0x1f004207, 0x271142a4,   // en.cs.sk_422 la.ca.ss_332  co.cy.un_420 co.ro.gd_433 
  0x2dfc3207, 0x2d1d42a0, 0x2f001d08, 0x36461d04,   // bs.zzp.sk_432 co.la.sk_322  la.su.un_430 la.qu.gn_332 
  0x25005808, 0x5d004222, 0x10043611, 0x42071d14,   // om.eu.un_430 co.ss.un_870  ab.ru.be_653 la.it.co_666 
  0x16425d55, 0x42461da9, 0x55003f08, 0x11465da0,   // ss.co.hr_442 la.qu.co_544  af.rw.un_430 ss.qu.ro_322 
  // [1b5a0]
  0x304438a7, 0x13003e07, 0x0e402f07, 0x2f002118,   // tk.kk.uz_532 rm.et.un_420  su.lb.is_432 jw.su.un_740 
  0x402f4c04, 0x2f404c0c, 0x1f003009, 0x5c003b0e,   // wo.su.lb_332 wo.lb.su_543  uz.cy.un_440 so.sa.un_550 
  0x28301204, 0x170715ee, 0x4a2f2907, 0x4c2f40ec,   // ur.uz.sd_332 un.bg.sr_422  sl.su.yo_432 lb.su.wo_644 
  0x271015a0, 0x40190b05, 0x2a465407, 0x1d000536,   // un.lt.gd_322 es.gl.lb_333  ik.qu.mt_432 fr.la.un_AA0 
  // [1b5b0]
  0x1004480c, 0x214c40ac, 0x402f210c, 0x4d005413,   // tt.ru.be_543 lb.wo.jw_632  jw.su.lb_543 ik.aa.un_650 
  0x40063902, 0x36002105, 0x15000707, 0x63193fa4,   // br.de.lb_222 jw.gn.un_330  it.un.un_420 af.gl.sco_433 
  0x12394855, 0x2c026907, 0x3900610e, 0x060209a4,   // tt.br.hu_442 mfe.da.fy_432  za.br.un_550 pl.da.de_433 
  0x5800200e, 0x38251bee, 0x206521ad, 0x47002104,   // sq.om.un_550 tr.eu.tk_422  jw.gv.sq_643 jw.sn.un_320 
  // [1b5c0]
  0x05124008, 0x1d001b14, 0x2718210c, 0x4d00541a,   // lb.hu.fr_443 tr.la.un_660  jw.ga.gd_543 ik.aa.un_760 
  0x2000fe1a, 0x1c381ea9, 0x48005422, 0x46360b07,   // tlh.sq.un_760 ms.tk.id_544  ik.tt.un_870 es.gn.qu_432 
  0x23001f0c, 0x33082c14, 0x39241f0c, 0x13001c1b,   // cy.ca.un_530 fy.no.nn_666  cy.eo.br_543 mr.bh.un_770 
  0x1b313009, 0x2100582a, 0x4a002221, 0x1b0938af,   // uz.az.tr_444 om.jw.un_970  oc.yo.un_860 tk.pl.tr_655 
  // [1b5d0]
  0x1d2322ee, 0x0300062a, 0x3f404eee, 0x2d0d21a4,   // oc.ca.la_422 de.nl.un_970  ay.lb.af_422 jw.cs.sk_433 
  0x1c003b02, 0x190a1d05, 0xfe2718ad, 0x183c305a,   // so.id.un_220 la.pt.gl_333  ga.gd.tlh_643 uz.ug.ar_553 
  0x15000714, 0x212f05a4, 0x18000505, 0x212f050c,   // bg.un.un_660 fr.su.jw_433  fr.ga.un_330 fr.su.jw_543 
  0x25000822, 0x48130c07, 0x23483705, 0x2f124ca0,   // uk.mn.un_870 sv.et.tt_432  ba.tt.ky_333 wo.hu.su_322 
  // [1b5e0]
  0x22006509, 0x212253a9, 0x6b021f12, 0x0522230c,   // gv.oc.un_440 ht.oc.jw_544  cy.da.ceb_654 ca.oc.fr_543 
  0x5c003b1a, 0x252315a0, 0x15100aee, 0x73470107,   // so.sa.un_760 un.ky.mn_322  mk.be.un_422 en.sn.ny_432 
  0x79292d13, 0x37383612, 0x20002d07, 0x043015a4,   // sk.sl.war_665 ab.tk.ba_654  sk.sq.un_420 un.uz.ru_433 
  0x15042313, 0x27187307, 0x654205ee, 0x29005804,   // ky.ru.un_665 ny.ga.gd_432  fr.co.gv_422 om.sl.un_320 
  // [1b5f0]
  0x0259300c, 0x184063ad, 0x18736413, 0x471f18ee,   // uz.rn.da_543 sco.lb.ga_643  lg.ny.ga_665 ga.cy.sn_422 
  0x05271807, 0x57180660, 0x61004013, 0x01001104,   // ga.gd.fr_432 de.ga.na_664  lb.za.un_650 ro.en.un_320 
  0x564001a0, 0x59557309, 0x603b5811, 0x525c1107,   // en.lb.mg_322 ny.rw.rn_444  om.so.vo_653 ro.sa.ha_432 
  0x481d6908, 0x42571f12, 0x19645da0, 0x526e3b04,   // mfe.la.tt_443 cy.na.co_654  ss.lg.gl_322 so.hmn.ha_332 
  // [1b600]
  0x1d182755, 0x4a5638a4, 0x631f180c, 0xfe000204,   // gd.ga.la_442 tk.mg.yo_433  ga.cy.sco_543 da.tlh.un_320 
  0x2d0920a9, 0x45180555, 0x3855480c, 0x01002f0c,   // sq.pl.sk_544 fr.ga.ln_442  tt.rw.tk_543 su.en.un_530 
  0x2f481caf, 0x333905a7, 0x36222705, 0x554c0507,   // id.tt.su_655 fr.br.nn_532  gd.oc.gn_333 fr.wo.rw_432 
  0x595525ec, 0x67125509, 0x024205a7, 0x3459550d,   // eu.rw.rn_644 rw.hu.ak_444  fr.co.da_532 rw.rn.xh_554 
  // [1b610]
  0x02186308, 0x055311ee, 0x07500f09, 0x73530107,   // sco.ga.da_443 ro.ht.fr_422  lv.fj.it_444 en.ht.ny_432 
  0x406306ec, 0x0f182713, 0x02553605, 0x11000f07,   // de.sco.lb_644 gd.ga.lv_665  gn.rw.da_333 lv.ro.un_420 
  0x695f3708, 0x041115ec, 0x36070107, 0x4c002009,   // st.tn.mfe_443 un.ro.ru_644  en.it.gn_432 sq.wo.un_440 
  0x27001f0c, 0x20003b07, 0x621d6008, 0x1d4b0107,   // cy.gd.un_530 so.sq.un_420  vo.la.kha_443 en.mi.la_432 
  // [1b620]
  0x3600111a, 0x5f00010d, 0x181d27ad, 0x3c44230b,   // ro.ab.un_760 en.tn.un_540  gd.la.ga_643 ky.kk.ug_542 
  0x06003502, 0x344423ac, 0x25003c19, 0x17101508,   // zu.de.un_220 ky.kk.ps_632  ug.mn.un_750 un.be.sr_443 
  0x4a1e1507, 0x4a000507, 0x76000107, 0x15002b13,   // un.ms.yo_432 fr.yo.un_420  en.crs.un_420 vi.un.un_650 
  0x190523a0, 0x1b000c02, 0x3f0305a0, 0x05007907,   // ca.fr.gl_322 sv.tr.un_220  fr.nl.af_322 war.fr.un_420 
  // [1b630]
  0x48101504, 0x32004612, 0x1716460c, 0x4f1f4304,   // un.be.tt_332 qu.bs.un_640  qu.hr.sr_543 ie.cy.bi_332 
  0x330807ee, 0x30253c12, 0x59554ea0, 0x1b321605,   // it.no.nn_422 ug.mn.uz_654  ay.rw.rn_322 hr.bs.tr_333 
  0x3b301204, 0x25243b04, 0x05190b05, 0x3d1828a0,   // hu.uz.so_332 so.eo.eu_332  es.gl.fr_333 sd.ar.ku_322 
  0x343048ad, 0x30321605, 0x12364c04, 0x2f304804,   // tt.uz.xh_643 hr.bs.uz_333  wo.gn.hu_332 tt.uz.su_332 
  // [1b640]
  0x20651fa0, 0x0e002f08, 0x1000021a, 0x192f4ca4,   // cy.gv.sq_322 su.is.un_430  da.lt.un_760 wo.su.gl_433 
  0x24253b05, 0x130c2455, 0x351e3007, 0x01000904,   // so.eu.eo_333 eo.sv.et_442  uz.ms.zu_432 pl.en.un_320 
  0x18360207, 0x3e2d30a4, 0x210e2fa4, 0x213b0213,   // da.gn.ga_432 uz.sk.rm_433  su.is.jw_433 da.so.jw_665 
  0x5cfc2113, 0x21005e1a, 0x37384412, 0x2123180c,   // jw.zzp.sa_665 ts.jw.un_760  kk.tk.ba_654 ar.ky.fa_543 
  // [1b650]
  0x2f361208, 0x40002009, 0x3711440b, 0x3c3748ad,   // hu.gn.su_443 sq.lb.un_440  kk.ro.ba_542 tt.ba.ug_643 
  0x105c56ec, 0x070f0a04, 0x38001112, 0x0302fcee,   // mg.sa.lt_644 pt.lv.it_332  ro.tk.un_640 zzp.da.nl_422 
  0x6502fca4, 0x623e0107, 0xfc203e04, 0x4c00420d,   // zzp.da.gv_433 en.rm.kha_432  rm.sq.zzp_332 co.wo.un_540 
  0x4000100d, 0x50023ba0, 0x0436070b, 0x5c1f5004,   // lt.lb.un_540 so.da.fj_322  bg.ab.ru_542 fj.cy.sa_332 
  // [1b660]
  0x0203fca7, 0x213d3b05, 0x1c4c1e04, 0x584c3bee,   // zzp.nl.da_532 ks.ku.fa_333  ms.wo.id_332 so.wo.om_422 
  0x062a1c07, 0x08003c12, 0x282130a0, 0x233725af,   // id.mt.de_432 ug.uk.un_640  uz.fa.sd_322 mn.ba.ky_655 
  0x06002d0e, 0x185c27a7, 0x18302112, 0x4415100d,   // sk.de.un_550 gd.sa.ga_532  fa.uz.ar_654 be.kk.un_540 
  0x2700650d, 0xfe584d12, 0x18276512, 0x51302aa0,   // gv.gd.un_540 aa.om.tlh_654  gv.gd.ga_654 mt.uz.kl_322 
  // [1b670]
  0x2a4c51a7, 0x2a005811, 0x4d002a13, 0x276501a0,   // kl.wo.mt_532 om.mt.un_630  mt.aa.un_650 en.gv.gd_322 
  0x1d656205, 0x4c483012, 0x48373814, 0x4a523607,   // kha.gv.la_333 uz.tt.wo_654  tk.ba.tt_666 gn.ha.yo_432 
  0x170c500c, 0x4a5e6907, 0x5851fe13, 0x420710a4,   // fj.sv.sr_543 mfe.ts.yo_432  tlh.kl.om_665 lt.it.co_433 
  0x180a2e08, 0x58002a11, 0x3051fea4, 0x255033a0,   // fo.pt.ga_443 mt.om.un_630  tlh.kl.uz_433 nn.fj.eu_322 
  // [1b680]
  0x6b63010c, 0x7300222a, 0x0300400d, 0x100e2e60,   // en.sco.ceb_543 oc.ny.un_970  lb.nl.un_540 fo.is.lt_664 
  0x233d4412, 0x6a4725a4, 0x59556905, 0x4600350d,   // kk.ku.ky_654 eu.sn.haw_433  mfe.rw.rn_333 zu.qu.un_540 
  0x0a0710ee, 0x224b1a09, 0x552a4baf, 0x53212355,   // be.bg.mk_422 tl.mi.oc_444  mi.mt.rw_655 ca.jw.ht_442 
  0x4b00fe2b, 0x28005d04, 0x51121d08, 0x18225308,   // tlh.mi.un_980 ss.sw.un_320  la.hu.kl_443 ht.oc.ga_443 
  // [1b690]
  0x181d5c04, 0x37000807, 0x222321ad, 0x46352804,   // sa.la.ga_332 uk.ba.un_420  jw.ca.oc_643 sw.zu.qu_332 
  0x38073c0c, 0x07153508, 0x061b3812, 0x3b2a64ee,   // ug.bg.tk_543 tg.bg.un_430  tk.tr.de_654 lg.mt.so_422 
  0x190a3807, 0x104408af, 0x04060c04, 0x05214204,   // tk.pt.gl_432 uk.kk.be_655  sv.de.fi_332 co.jw.fr_332 
  0x5300210e, 0x18283bad, 0x4045470c, 0x0b362aa4,   // jw.ht.un_550 ks.sd.ar_643  sn.ln.lb_543 mt.gn.es_433 
  // [1b6a0]
  0x436907a4, 0x2f006919, 0x251f51a9, 0x110f25ad,   // it.mfe.ie_433 mfe.su.un_750  kl.cy.eu_544 eu.lv.ro_643 
  0x3200430c, 0x56004004, 0x69285da4, 0x283b1ea0,   // ie.bs.un_530 lb.mg.un_320  ss.sw.mfe_433 ms.so.sw_322 
  0x21285808, 0x0600402b, 0x55591e0b, 0x28205c0d,   // om.sw.jw_443 lb.de.un_980  ms.rn.rw_542 sa.sq.sw_554 
  0xfe3b28a4, 0x0f3353a0, 0xfc1d0ca9, 0x47fe280c,   // sw.so.tlh_433 ht.nn.lv_322  sv.la.zzp_544 sw.tlh.sn_543 
  // [1b6b0]
  0x69472a08, 0x554547af, 0x28595514, 0x3b58210d,   // mt.sn.mfe_443 sn.ln.rw_655  rw.rn.sw_666 jw.om.so_554 
  0x39fe69a4, 0x63183b05, 0x4d5c5811, 0x69006129,   // mfe.tlh.br_433 so.ga.sco_333  om.sa.aa_653 za.mfe.un_960 
  0x59552da9, 0x28183b5a, 0x3b58215a, 0x19251da4,   // sk.rw.rn_544 so.ga.sw_553  jw.om.so_553 la.eu.gl_433 
  0x3e00690c, 0x404606ee, 0x39061d0b, 0x111508a4,   // mfe.rm.un_530 de.qu.lb_422  la.de.br_542 uk.ro.un_430 
  // [1b6c0]
  0x15482308, 0x6b1101a0, 0x28182008, 0x38304802,   // ky.tt.un_443 en.ro.ceb_322  sq.ga.sw_443 tt.uz.tk_222 
  0x185c210b, 0x38001708, 0x5d0e2c02, 0x35002c05,   // jw.sa.ga_542 sr.tk.un_430  fy.is.ss_222 fy.zu.un_330 
  0x47282107, 0x181a27ad, 0x1700fe0c, 0x1000170b,   // jw.sw.sn_432 gd.tl.ga_643  tlh.sr.un_530 sr.be.un_520 
  0x0a001509, 0x15381007, 0x183c23ec, 0x460658ee,   // un.mk.un_440 be.tk.un_432  ky.ug.ar_644 om.de.qu_422 
  // [1b6d0]
  0x23003722, 0x30213b0e, 0x38000a1f, 0x34005304,   // ba.ky.un_870 ks.fa.uz_555  pt.tk.un_840 ht.xh.un_320 
  0x4b6a49ad, 0x422205ec, 0x13310a5a, 0x23052260,   // to.haw.mi_643 fr.oc.co_644  pt.az.et_553 oc.fr.ca_664 
  0x34595514, 0x61595505, 0x2f5d3508, 0x07153507,   // rw.rn.xh_666 rw.rn.za_333  zu.ss.su_443 tg.bg.un_420 
  0x4a005e05, 0x2a003407, 0x1655fca7, 0x32092d5a,   // ts.yo.un_330 xh.mt.un_420  zzp.rw.hr_532 sk.pl.bs_553 
  // [1b6e0]
  0x1e212f05, 0x070438a9, 0x08230405, 0x373844a4,   // su.jw.ms_333 tk.ru.bg_544  ru.ky.uk_333 kk.tk.ba_433 
  0x18273b12, 0x442523ec, 0x44234805, 0x523b2ca0,   // so.gd.ga_654 ky.mn.kk_644  tt.ky.kk_333 fy.so.ha_322 
  0x48060c07, 0x1500110e, 0x36003905, 0x23001804,   // sv.de.tt_432 ro.un.un_550  br.gn.un_330 ga.ca.un_320 
  0x06fc2e0b, 0xfc791504, 0xfc763108, 0x120cfc0b,   // fo.zzp.de_542 un.war.zzp_332  az.crs.zzp_443 zzp.sv.hu_542 
  // [1b6f0]
  0x401ffc07, 0x532e3308, 0x06002405, 0x2308040e,   // zzp.cy.lb_432 nn.fo.ht_443  eo.de.un_330 ru.uk.ky_555 
  0x33000602, 0x1d00430e, 0xfc001f1a, 0x38001309,   // de.nn.un_220 ie.la.un_550  cy.zzp.un_760 et.tk.un_440 
  0x174815a9, 0x1504075a, 0x2f003304, 0x15030da0,   // un.tt.sr_544 bg.ru.un_553  nn.su.un_320 cs.nl.un_322 
  0x38002a04, 0x151dfc08, 0x791d5705, 0x08040a0c,   // mt.tk.un_320 zzp.la.un_443  na.la.war_333 mk.ru.uk_543 
  // [1b700]
  0x6b005412, 0x2415fca0, 0x0d005609, 0x09004007,   // ik.ceb.un_640 zzp.eo.un_320  mg.cs.un_440 lb.pl.un_420 
  0x301d0a07, 0x5c000c05, 0x641e2807, 0x22003502,   // pt.la.uz_432 sv.sa.un_330  sw.ms.lg_432 zu.oc.un_220 
  0x50151dee, 0x34123011, 0x1d000a21, 0x3b000c0d,   // la.fj.un_420 uz.ur.ps_653  pt.la.un_860 sv.so.un_540 
  0x05731dee, 0x6a491c07, 0x64006b0c, 0x24003b0c,   // la.ny.fr_422 id.to.haw_432  ceb.lg.un_530 so.eo.un_530 
  // [1b710]
  0x10006a11, 0x5a496a07, 0x38001020, 0x2f0c3b02,   // haw.lt.un_630 haw.to.sm_432  lt.tk.un_850 so.sv.su_222 
  0x242e3308, 0x05232211, 0x49001008, 0x2d100dad,   // nn.fo.eo_443 oc.ca.fr_653  lt.to.un_430 cs.lt.sk_643 
  0x5a1d10a0, 0x2a1716eb, 0x23170407, 0x61002513,   // lt.la.sm_322 hr.sr.mt_662  ru.sr.ky_432 eu.za.un_650 
  0x3900180b, 0x65002b04, 0x100844af, 0x34062304,   // ga.br.un_520 vi.gv.un_320  kk.uk.be_655 ca.de.xh_332 
  // [1b720]
  0x15374860, 0x300a07a6, 0x560a4904, 0x07001120,   // tt.ba.un_664 bg.mk.uz_521  to.pt.mg_332 ro.bg.un_850 
  0x4823105a, 0x5d021bad, 0x3d2123ee, 0x35373ca7,   // be.ky.tt_553 tr.da.ss_643  ky.fa.ku_422 ug.ba.tg_532 
  0x53001a05, 0x5d57310c, 0x1f001520, 0x47555d0c,   // tl.ht.un_330 az.na.ss_543  un.cy.un_850 ss.rw.sn_543 
  0x20005b23, 0x00003137, 0x6000310e, 0x33004702,   // sg.sq.un_880 az.un.un_B00  az.vo.un_550 sn.nn.un_220 
  // [1b730]
  0x095dfe04, 0x30351755, 0x350cfe08, 0x0c0d09ee,   // tlh.ss.pl_332 sr.tg.uz_442  tlh.sv.zu_443 pl.cs.sv_422 
  0x295d3508, 0x5d005e05, 0x2b003605, 0x31003507,   // zu.ss.sl_443 ts.ss.un_330  gn.vi.un_330 zu.az.un_420 
  0x25133b04, 0x1ffe385a, 0x180639ec, 0x3031fe04,   // so.et.eu_332 tk.tlh.cy_553  br.de.ga_644 tlh.az.uz_332 
  0x36383b05, 0x0c121fa9, 0x524d3ba9, 0x133b1f12,   // so.tk.gn_333 cy.hu.sv_544  so.aa.ha_544 cy.so.et_654 
  // [1b740]
  0x1b3138a4, 0x3f003019, 0x2538150c, 0x38234304,   // tk.az.tr_433 uz.af.un_750  un.tk.mn_543 ie.ca.tk_332 
  0x24fc1807, 0x21005318, 0x21fe6304, 0x7962fca9,   // ga.zzp.eo_432 ht.jw.un_740  sco.tlh.jw_332 zzp.kha.war_544 
  0x3f002902, 0x02322404, 0x5c29fca4, 0x10170aa0,   // sl.af.un_220 eo.bs.da_332  zzp.sl.sa_433 mk.sr.be_322 
  0x3e065708, 0x08441008, 0x790c0207, 0x30425c55,   // na.de.rm_443 be.kk.uk_443  da.sv.war_432 sa.co.uz_442 
  // [1b750]
  0x35045d0c, 0x2724fcee, 0x42002e05, 0x0e1342ee,   // ss.fi.zu_543 zzp.eo.gd_422  fo.co.un_330 co.et.is_422 
  0x3e2343ee, 0x233c4407, 0x63fc1da4, 0x4a005c05,   // ie.ca.rm_422 kk.ug.ky_432  la.zzp.sco_433 sa.yo.un_330 
  0x64003005, 0x48001f07, 0x3300fc19, 0x17422307,   // uz.lg.un_330 cy.tt.un_420  zzp.nn.un_750 ca.co.sr_432 
  0x3308fca4, 0x2b003409, 0x0f0b10ac, 0x24384d04,   // zzp.no.nn_433 xh.vi.un_440  lt.es.lv_632 aa.tk.eo_332 
  // [1b760]
  0x4230360c, 0x2f1205a0, 0x04301307, 0x2f4a1207,   // gn.uz.co_543 fr.hu.su_322  et.uz.fi_432 hu.yo.su_432 
  0x0f001305, 0x21052f11, 0x4a052fa4, 0x203229ad,   // et.lv.un_330 su.fr.jw_653  su.fr.yo_433 sl.bs.sq_643 
  0x37595555, 0x5d005308, 0x054a1207, 0x1efe2aa4,   // rw.rn.st_442 ht.ss.un_430  hu.yo.fr_432 mt.tlh.ms_433 
  0x17441504, 0x351708a4, 0x2e003312, 0x3e001213,   // un.kk.sr_332 uk.sr.tg_433  nn.fo.un_640 hu.rm.un_650 
  // [1b770]
  0x10004609, 0x1f001c07, 0x1f2861ad, 0x2b00470e,   // qu.lt.un_440 id.cy.un_420  za.sw.cy_643 sn.vi.un_550 
  0x46282b08, 0x49003612, 0x18005e02, 0x47002812,   // vi.sw.qu_443 gn.to.un_640  ts.ga.un_220 sw.sn.un_640 
  0x2b006221, 0x33021f05, 0x5018270b, 0x0f090204,   // kha.vi.un_860 cy.da.nn_333  gd.ga.fj_542 da.pl.lv_332 
  0x0500690c, 0x351008a4, 0x1508100c, 0x330c1fa7,   // mfe.fr.un_530 uk.be.tg_433  be.uk.un_543 cy.sv.nn_532 
  // [1b780]
  0x2e1f38a0, 0x1900270c, 0x103832a4, 0x3800620e,   // tk.cy.fo_322 gd.gl.un_530  bs.tk.lt_433 kha.tk.un_550 
  0x0a2338ac, 0x2300170e, 0x39004e19, 0x08441013,   // tk.ky.mk_632 sr.ky.un_550  ay.br.un_750 be.kk.uk_665 
  0x424d05ec, 0x1004250c, 0x3b000d05, 0x2e004e1e,   // fr.aa.co_644 mn.ru.be_543  ne.ks.un_330 ay.fo.un_830 
  0x4448370b, 0x40330ea7, 0x37173c07, 0x37254807,   // ba.tt.kk_542 is.nn.lb_532  ug.sr.ba_432 tt.mn.ba_432 
  // [1b790]
  0x6800150d, 0x036465ee, 0x33002719, 0x18005f0d,   // un.ig.un_540 gv.lg.nl_422  gd.nn.un_750 tn.ga.un_540 
  0x402533a0, 0x4a001913, 0x652e0fec, 0x0e006004,   // nn.eu.lb_322 gl.yo.un_650  lv.fo.gv_644 vo.is.un_320 
  0x100f0608, 0x79100107, 0x400e05a4, 0x13360ca9,   // de.lv.lt_443 en.lt.war_432  fr.is.lb_433 sv.gn.et_544 
  0x05005a02, 0x232722a0, 0x18004d14, 0x3e1b31a0,   // sm.fr.un_220 oc.gd.ca_322  aa.ga.un_660 az.tr.rm_322 
  // [1b7a0]
  0x210f2f07, 0x1d000704, 0x020634ee, 0x401b06a0,   // su.lv.jw_432 it.la.un_320  xh.de.da_422 de.tr.lb_322 
  0x05002d04, 0x6e051d0c, 0x011d050c, 0x345e0112,   // sk.fr.un_320 la.fr.hmn_543  fr.la.en_543 en.ts.xh_654 
  0x561d050c, 0x36303507, 0x231d050c, 0x230a0508,   // fr.la.mg_543 tg.uz.ab_432  fr.la.ca_543 fr.pt.ca_443 
  0x0223050b, 0x1500400d, 0x55001b13, 0x191d36a4,   // fr.ca.da_542 lb.un.un_540  tr.rw.un_650 gn.la.gl_433 
  // [1b7b0]
  0x55212fee, 0x795106a7, 0x35343009, 0x0b353404,   // su.jw.rw_422 de.kl.war_532  uz.xh.zu_444 xh.zu.es_332 
  0x023f29a6, 0x4b004607, 0x23050107, 0x3b391f05,   // sl.af.da_521 qu.mi.un_420  en.fr.ca_432 cy.br.so_333 
  0x1d46055a, 0x2300051a, 0x55230507, 0x1b003913,   // fr.qu.la_553 fr.ca.un_760  fr.ca.rw_432 br.tr.un_650 
  0x796b2aa0, 0x13581d0e, 0x15234412, 0x2305330c,   // mt.ceb.war_322 la.om.et_555  kk.ky.un_654 nn.fr.ca_543 
  // [1b7c0]
  0x1b003120, 0x186a2804, 0x2042075a, 0x28564004,   // az.tr.un_850 sw.haw.ga_332  it.co.sq_553 lb.mg.sw_332 
  0x0242070c, 0x56606a08, 0x396a42a0, 0x28213d02,   // it.co.da_543 haw.vo.mg_443  co.haw.br_322 ku.fa.sd_222 
  0x0d490aad, 0x25020704, 0x06313ea0, 0x2800492a,   // pt.to.cs_643 it.da.eu_332  rm.az.de_322 to.sw.un_970 
  0x600c24ad, 0x32004202, 0x58001222, 0x3233085a,   // eo.sv.vo_643 co.bs.un_220  hu.om.un_870 no.nn.bs_553 
  // [1b7d0]
  0x1c005204, 0x40002804, 0x1307120c, 0x02001c08,   // ha.id.un_320 sw.lb.un_320  hu.it.et_543 id.da.un_430 
  0x2e004e10, 0x0c003322, 0x02002d07, 0x0c00081a,   // ay.fo.un_620 nn.sv.un_870  sk.da.un_420 no.sv.un_760 
  0x48071707, 0x43072612, 0x17383607, 0x0f0d2da0,   // sr.bg.tt_432 ia.it.ie_654  ab.tk.sr_432 sk.cs.lv_322 
  0x65041d07, 0x27005713, 0x042b1005, 0x0c0f4707,   // la.fi.gv_432 na.gd.un_650  lt.vi.fi_333 sn.lv.sv_432 
  // [1b7e0]
  0x3e2f1ba0, 0x04054555, 0x190b7955, 0x330c0ea0,   // tr.su.rm_322 ln.fr.fi_442  war.es.gl_442 is.sv.nn_322 
  0x0f004e1b, 0x17461da0, 0x303525a7, 0x343b3d04,   // ay.lv.un_770 la.qu.sr_322  mn.tg.uz_532 ku.ks.ps_332 
  0x38002329, 0x35073807, 0x2a793107, 0x302d0d0d,   // ky.tk.un_960 tk.bg.tg_432  az.war.mt_432 cs.sk.uz_554 
  0x49361204, 0x65002307, 0x49005214, 0x355d6ba0,   // hu.gn.to_332 ca.gv.un_420  ha.to.un_660 ceb.ss.zu_322 
  // [1b7f0]
  0x05402f07, 0x380a1107, 0x2a00180d, 0x5c094902,   // su.lb.fr_432 ro.mk.tk_432  ga.mt.un_540 to.pl.sa_222 
  0x37071107, 0x17070407, 0x21231804, 0x07041d04,   // ro.bg.ba_432 ru.bg.sr_432  ar.ky.fa_332 la.fi.it_332 
  0x424005ee, 0x2d003005, 0x1a353405, 0x012d0d0e,   // fr.lb.co_422 uz.sk.un_330  xh.zu.tl_333 cs.sk.en_555 
  0x0415250b, 0x1b003204, 0x1828230d, 0x251507a9,   // mn.ru.un_520 bs.tr.un_320  ky.sd.ar_554 bg.mn.un_540 
  
  // [1b800]
  0x2f1c03a0, 0x1d27420c, 0x083011a0, 0x42002104,   // nl.id.su_322 co.gd.la_543  ro.uz.uk_322 jw.co.un_320 
  0x020647ee, 0x46561e0c, 0x17083008, 0x255133a7,   // sn.de.da_422 ms.mg.qu_543  uz.uk.sr_443 nn.kl.eu_532 
  0x5250330c, 0x311b1304, 0x4f59550e, 0x42001f21,   // nn.fj.ha_543 et.tr.az_332  rw.rn.bi_555 cy.co.un_860 
  0x1f001104, 0x655136a9, 0x522f1ea9, 0x235c36ec,   // ro.cy.un_320 gn.kl.gv_544  ms.su.ha_544 gn.sa.ca_644 
  // [1b810]
  0x02255608, 0x3b314e0c, 0x10150a04, 0x5c251ca4,   // mg.eu.da_443 ay.az.so_543  mk.be.un_320 id.eu.sa_433 
  0x48370a12, 0x121828af, 0x30515012, 0x5d12050c,   // mk.ba.tt_654 sd.ar.ur_655  fj.kl.uz_654 fr.hu.ss_543 
  0x13432a07, 0x061360a7, 0x2f004512, 0x401b060c,   // mt.ie.et_432 vo.et.de_532  ln.su.un_640 de.tr.lb_543 
  0x1b3e31ad, 0x19004807, 0x36190d12, 0x45002f13,   // az.rm.tr_643 tt.gl.un_420  cs.gl.gn_654 su.ln.un_650 
  // [1b820]
  0x1b3e31a0, 0x06314004, 0x21303daf, 0x30383111,   // az.rm.tr_322 lb.az.de_332  ku.uz.fa_655 az.tk.uz_653 
  0x0a151707, 0x380631ec, 0x3b00fc13, 0x3e0613b2,   // sr.mk.un_420 az.de.tk_644  zzp.so.un_650 et.de.rm_732 
  0x311b13ed, 0x19052107, 0x5c0c33ac, 0x40063e0b,   // et.tr.az_622 jw.fr.gl_432  nn.sv.sa_632 rm.de.lb_542 
  0x7900310d, 0x071d08a4, 0x401108a4, 0x36050d02,   // az.war.un_540 no.la.it_433  no.ro.lb_433 cs.fr.gn_222 
  // [1b830]
  0x20684b0d, 0x12004522, 0x5968080c, 0x0703080c,   // mi.ig.sq_554 ln.hu.un_870  no.ig.rn_543 no.nl.it_543 
  0x12004513, 0x6408020d, 0x40480607, 0x12000605,   // ln.hu.un_650 da.no.lg_554  de.tt.lb_432 de.hu.un_330 
  0x3e00130c, 0x11501d13, 0x131238a4, 0x343c2812,   // et.rm.un_530 la.fj.ro_665  tk.hu.et_433 sd.ug.ps_654 
  0x47735508, 0x67680812, 0x19111dee, 0x736768ec,   // rw.ny.sn_443 no.ig.ak_654  la.ro.gl_422 ig.ak.ny_644 
  // [1b840]
  0x06682612, 0x4b57550d, 0x190d0aee, 0x0607080c,   // ia.ig.de_654 rw.na.mi_554  pt.cs.gl_422 no.it.de_543 
  0xfe0630ee, 0x230522a0, 0x07004007, 0x65420504,   // uz.de.tlh_422 oc.fr.ca_322  lb.it.un_420 fr.co.gv_332 
  0x38fe01a4, 0x6900620d, 0x514a1207, 0x046251a9,   // en.tlh.tk_433 kha.mfe.un_540  hu.yo.kl_432 kl.kha.fi_544 
  0x0962fe11, 0x050d21a0, 0x46003b12, 0x51016307,   // tlh.kha.pl_653 jw.cs.fr_322  so.qu.un_640 sco.en.kl_432 
  // [1b850]
  0x022412ad, 0x0d4f1dad, 0xfe00510e, 0x38444808,   // hu.eo.da_643 la.bi.cs_643  kl.tlh.un_550 tt.kk.tk_443 
  0x0a04110c, 0x422005a4, 0x064f0107, 0x5800fe09,   // ro.ru.mk_543 fr.sq.co_433  en.bi.de_432 tlh.om.un_440 
  0x48234c07, 0x21052204, 0x52353404, 0x151530a4,   // wo.ca.tt_432 oc.fr.jw_332  xh.zu.ha_332 uz.un.un_430 
  0x32000108, 0xfe3e61a7, 0x33200cad, 0x43063eac,   // en.bs.un_430 za.rm.tlh_532  sv.sq.nn_643 rm.de.ie_632 
  // [1b860]
  0x19220ba0, 0x371011a7, 0x1900050e, 0x1d104309,   // es.oc.gl_322 ro.be.ba_532  fr.gl.un_550 ie.lt.la_444 
  0x5c2b6ead, 0x27006208, 0x4b49360c, 0x33082bec,   // hmn.vi.sa_643 kha.gd.un_430  gn.to.mi_543 vi.no.nn_644 
  0x35001008, 0x1e000e05, 0x52003804, 0x65272bad,   // be.tg.un_430 is.ms.un_330  tk.ha.un_320 vi.gd.gv_643 
  0x185821a0, 0x01006e02, 0x360c63a0, 0x023830a4,   // jw.om.ga_322 hmn.en.un_220  sco.sv.gn_322 uz.tk.da_433 
  // [1b870]
  0x34006e29, 0x456301ad, 0x212b630c, 0x291649ee,   // hmn.xh.un_960 en.sco.ln_643  sco.vi.jw_543 to.hr.sl_422 
  0x2e004e0e, 0x26001120, 0x1d001123, 0x111b5755,   // ay.fo.un_550 ro.ia.un_850  ro.la.un_880 na.tr.ro_442 
  0x2315010b, 0x1501400c, 0x0e301302, 0x2d001914,   // en.ca.un_520 lb.en.un_543  et.uz.is_222 gl.sk.un_660 
  0x253744a4, 0x25074804, 0x37456312, 0x5c240f07,   // kk.ba.mn_433 tt.bg.mn_332  sco.ln.st_654 lv.eo.sa_432 
  // [1b880]
  0x422d1d07, 0x5d5a10a4, 0x1a0c4da0, 0x6b5c24ad,   // la.sk.co_432 lt.sm.ss_433  aa.sv.tl_322 eo.sa.ceb_643 
  0x5a1351a0, 0x125d48a0, 0x600f520c, 0x3d001221,   // kl.et.sm_322 tt.ss.hu_322  ha.lv.vo_543 ur.ku.un_860 
  0x30005f07, 0xfe2f4804, 0x4737025a, 0x107802a4,   // tn.uz.un_420 tt.su.tlh_332  da.st.sn_553 da.ve.lt_433 
  0x3c114808, 0x2d1224a0, 0x0542220c, 0x0408300c,   // tt.ro.ug_443 eo.hu.sk_322  oc.co.fr_543 uz.uk.ru_543 
  // [1b890]
  0x0f160da0, 0x321202ee, 0x4829feee, 0x5369fca4,   // cs.hr.lv_322 da.hu.bs_422  tlh.sl.tt_422 zzp.mfe.ht_433 
  0x48005d07, 0x2f190507, 0x4b022455, 0x08101107,   // ss.tt.un_420 fr.gl.su_432  eo.da.mi_442 ro.be.uk_432 
  0x29122408, 0x3e110d07, 0x10256007, 0x335cfc07,   // eo.hu.sl_443 cs.ro.rm_432  vo.eu.lt_432 zzp.sa.nn_432 
  0x2815120d, 0x13063e05, 0x2821340d, 0x03020807,   // ur.sd.un_540 rm.de.et_333  ps.fa.sd_554 no.da.nl_432 
  // [1b8a0]
  0x213d2302, 0x2f18050c, 0x18274704, 0x17234802,   // ky.ku.fa_222 fr.ga.su_543  sn.gd.ga_332 tt.ky.sr_222 
  0x07006522, 0x5300230b, 0x28003c07, 0x29110f07,   // gv.it.un_870 ca.ht.un_520  ug.sd.un_420 lv.ro.sl_432 
  0xfc001f0e, 0x10001e05, 0xfc0a3b04, 0xfc2734a0,   // cy.zzp.un_550 ms.lt.un_330  so.pt.zzp_332 xh.gd.zzp_322 
  0x063e69ac, 0x203f1507, 0x343b35a0, 0x2000051a,   // mfe.rm.de_632 un.af.sq_432  zu.so.xh_322 fr.sq.un_760 
  // [1b8b0]
  0x2f006807, 0x20002c02, 0x482d0d09, 0x28002018,   // ig.su.un_420 fy.sq.un_220  cs.sk.tt_444 sq.sw.un_740 
  0x482d0d55, 0x0c002905, 0x4c210555, 0x47355208,   // cs.sk.tt_442 sl.sv.un_330  fr.jw.wo_442 ha.zu.sn_443 
  0x0d482da9, 0x215c2008, 0x471f420c, 0x35495aa9,   // sk.tt.cs_544 sq.sa.jw_443  co.cy.sn_543 sm.to.zu_544 
  0x53003f07, 0x4700210d, 0x0a083708, 0x7328350c,   // af.ht.un_420 jw.sn.un_540  ba.uk.mk_443 zu.sw.ny_543 
  // [1b8c0]
  0x20423eaf, 0x24393e04, 0x07423e0d, 0x58002823,   // rm.co.sq_655 rm.br.eo_332  rm.co.it_554 sw.om.un_880 
  0x436821a4, 0x5f1d1fa0, 0x495a07ee, 0x35205fad,   // jw.ig.ie_433 cy.la.tn_322  it.sm.to_422 tn.sq.zu_643 
  0x20004708, 0x2d3812ac, 0x5c0d3b13, 0x215e2fa0,   // sn.sq.un_430 hu.tk.sk_632  ks.ne.sa_665 su.ts.jw_322 
  0x31001912, 0x286430a0, 0x071142a0, 0x1e211513,   // gl.az.un_640 uz.lg.sw_322  co.ro.it_322 un.jw.ms_665 
  // [1b8d0]
  0x3e0b4208, 0x30006819, 0x482d0d08, 0x5e3002ad,   // co.es.rm_443 ig.uz.un_750  cs.sk.tt_443 da.uz.ts_643 
  0x5e131002, 0x30101255, 0x420705ee, 0x106443a0,   // lt.et.ts_222 hu.lt.uz_442  fr.it.co_422 ie.lg.lt_322 
  0x34435d13, 0x19231807, 0x2b003407, 0x48151505,   // ss.ie.xh_665 ga.ca.gl_432  xh.vi.un_420 un.tt.un_330 
  0x390c2004, 0x0a3530a0, 0x0d004909, 0x0c1312ee,   // sq.sv.br_332 uz.tg.mk_322  to.cs.un_440 hu.et.sv_422 
  // [1b8e0]
  0x2d490dee, 0x233b3da9, 0x466b5555, 0x370a480c,   // cs.to.sk_422 ku.ks.ky_544  rw.ceb.qu_442 tt.mk.ba_543 
  0x04570c05, 0x5e28550c, 0x17303c07, 0x30001814,   // sv.na.fi_333 rw.sw.ts_543  ug.uz.sr_432 ar.uz.un_660 
  0x42003e13, 0x343018a0, 0x594655ad, 0x1b001302,   // rm.co.un_650 ar.uz.ps_322  rw.qu.rn_643 et.tr.un_220 
  0x084804a0, 0x56006a19, 0xfe233b09, 0x205f4011,   // ru.tt.uk_322 haw.mg.un_750  so.ca.tlh_444 lb.tn.sq_653 
  // [1b8f0]
  0x295f370d, 0x365e1da9, 0x4a653fa4, 0x39002b07,   // st.tn.sl_554 la.ts.gn_544  af.gv.yo_433 vi.br.un_420 
  0x5a394b02, 0x13311b0c, 0x43111ea0, 0x201157ad,   // mi.br.sm_222 tr.az.et_543  ms.ro.ie_322 na.ro.sq_643 
  0x3400fc0b, 0x29536911, 0x464c38ec, 0x30483bad,   // zzp.xh.un_520 mfe.ht.sl_653  tk.wo.qu_644 so.tt.uz_643 
  0x4b026104, 0xfe583b12, 0x040815a6, 0x094067ad,   // za.da.mi_332 so.om.tlh_654  un.uk.ru_521 ak.lb.pl_643 
  // [1b900]
  0x0929575a, 0x31000a07, 0x526850ad, 0x040f6404,   // na.sl.pl_553 pt.az.un_420  fj.ig.ha_643 lg.lv.fi_332 
  0x29005002, 0x3d3b2105, 0x240420a0, 0x5955670c,   // fj.sl.un_220 fa.ks.ku_333  sq.fi.eo_322 ak.rw.rn_543 
  0x161a2d12, 0x384804a7, 0x19001302, 0x38150805,   // sk.tl.hr_654 fi.tt.tk_532  et.gl.un_220 uk.tk.un_330 
  0x2b00690c, 0x0d302504, 0x17150a08, 0x562d0504,   // mfe.vi.un_530 eu.uz.cs_332  mk.sr.un_430 fr.sk.mg_332 
  // [1b910]
  0x3663fc08, 0x2ffc2155, 0x08020e09, 0x2d002204,   // zzp.sco.gn_443 jw.zzp.su_442  is.da.no_444 oc.sk.un_320 
  0x1801fcee, 0x3748235a, 0x293216ec, 0x243f0255,   // zzp.en.ga_422 ky.tt.ba_553  hr.bs.sl_644 da.af.eo_442 
  0x095c1302, 0x655104ad, 0x48372311, 0x0d001909,   // bh.sa.hi_222 fi.kl.gv_643  ky.ba.tt_653 gl.cs.un_440 
  0x222f3e07, 0x1801fc08, 0x1867fca4, 0x193e0b5a,   // rm.su.oc_432 zzp.en.ga_443  zzp.ak.ga_433 es.rm.gl_553 
  // [1b920]
  0x33084705, 0x54005113, 0x2b4c2d0c, 0x381b115a,   // sn.no.nn_333 kl.ik.un_650  sk.wo.vi_543 ro.tr.tk_553 
  0x5d5759a4, 0x13040cad, 0x1b004b04, 0x3735480c,   // rn.na.ss_433 sv.fi.et_643  mi.tr.un_320 tt.tg.ba_543 
  0x37443804, 0x0a2d1204, 0x15000709, 0x39276e07,   // tk.kk.ba_332 hu.sk.pt_332  bg.un.un_440 hmn.gd.br_432 
  0x063e1b07, 0x3900630d, 0x20001b12, 0x64004a02,   // tr.rm.de_432 sco.br.un_540  tr.sq.un_640 yo.lg.un_220 
  // [1b930]
  0x1a006e12, 0x49005108, 0x1d2524a0, 0x2d0d2f09,   // hmn.tl.un_640 kl.to.un_430  eo.eu.la_322 su.cs.sk_444 
  0x5e005005, 0x18000114, 0x400e0c07, 0x401905a9,   // fj.ts.un_330 iw.ar.un_660  sv.is.lb_432 fr.gl.lb_544 
  0x054a45ee, 0x22004721, 0x4d190b12, 0x08044404,   // ln.yo.fr_422 sn.oc.un_860  es.gl.aa_654 kk.ru.uk_332 
  0x383f1fee, 0x0c00380d, 0x36002f05, 0x0b212fa7,   // cy.af.tk_422 tk.sv.un_540  su.gn.un_330 su.jw.es_532 
  // [1b940]
  0x37002522, 0x0e00690c, 0x112305a4, 0x0e005807,   // mn.ba.un_870 mfe.is.un_530  fr.ca.ro_433 om.is.un_420 
  0x25301508, 0x190b5bb3, 0x2f1d580b, 0x0f002a07,   // un.uz.mn_443 sg.es.gl_743  om.la.su_542 mt.lv.un_420 
  0x213b1c02, 0x182a01a6, 0x69430107, 0x052b390b,   // id.so.jw_222 en.mt.ga_521  en.ie.mfe_432 br.vi.fr_542 
  0x091c5c13, 0x12004c0d, 0x25111555, 0x190d2da6,   // sa.mr.hi_665 wo.hu.un_540  un.ro.mn_442 sk.cs.gl_521 
  // [1b950]
  0x1e1c3b0c, 0x3d283b07, 0x3e004c07, 0x4a000a0d,   // so.id.ms_543 ks.sd.ku_432  wo.rm.un_420 pt.yo.un_540 
  0x6b182704, 0x275a18ec, 0x5a2718ec, 0x13001814,   // gd.ga.ceb_332 ga.sm.gd_644  ga.gd.sm_644 ga.et.un_660 
  0x1a042407, 0x6b007907, 0x18003e05, 0x022718ad,   // eo.fi.tl_432 war.ceb.un_420  rm.ga.un_330 ga.gd.da_643 
  0x18005a21, 0x18615aad, 0x2404fea0, 0x2e360b02,   // sm.ga.un_860 sm.za.ga_643  tlh.fi.eo_322 es.gn.fo_222 
  // [1b960]
  0x2723180c, 0x2d0d0caf, 0x2500120c, 0x28473607,   // ga.ca.gd_543 sv.cs.sk_655  hu.eu.un_530 gn.sn.sw_432 
  0x286506a4, 0x105a18a9, 0x5a006508, 0x18fc1307,   // de.gv.sw_433 ga.sm.lt_544  gv.sm.un_430 et.zzp.ga_432 
  0x0c431112, 0x06536908, 0x3823480e, 0x232515ee,   // ro.ie.sv_654 mfe.ht.de_443  tt.ky.tk_555 un.mn.ky_422 
  0x19360aa7, 0xfc570107, 0x192e0aa7, 0x57214aa9,   // pt.gn.gl_532 en.na.zzp_432  pt.fo.gl_532 yo.jw.na_544 
  // [1b970]
  0x28214405, 0x36214a0c, 0x21183414, 0x736829a4,   // kk.fa.sd_333 yo.jw.gn_543  ps.ar.fa_666 sl.ig.ny_433 
  0x4a00202a, 0x5e30285a, 0x755e45a9, 0x281b3812,   // sq.yo.un_970 sw.uz.ts_553  ln.ts.nso_544 tk.tr.sw_654 
  0x5f371ca4, 0x24595508, 0x0442050c, 0x3400450d,   // id.st.tn_433 rw.rn.eo_443  fr.co.fi_543 ln.xh.un_540 
  0x3021120d, 0x345e5da9, 0x53595e08, 0x21355d0c,   // ur.fa.uz_554 ss.ts.xh_544  ts.rn.ht_443 ss.zu.jw_543 
  // [1b980]
  0x28734508, 0x43682404, 0x0c062a02, 0x3035310c,   // ln.ny.sw_443 eo.ig.ie_332  mt.de.sv_222 az.zu.uz_543 
  0x231821a0, 0x24004213, 0x3b004204, 0x55005811,   // fa.ar.ky_322 co.eo.un_650  co.so.un_320 om.rw.un_630 
  0x30003208, 0x1e212f04, 0x3d00230e, 0x29791dee,   // bs.uz.un_430 su.jw.ms_332  ky.ku.un_550 la.war.sl_422 
  0x36321702, 0x02111d12, 0x071517ad, 0x0a441507,   // sr.bs.gn_222 la.ro.da_654  sr.bg.un_630 un.kk.mk_432 
  // [1b990]
  0x2b004312, 0x55173402, 0x46001d0b, 0x55284d13,   // ie.vi.un_640 xh.sr.rw_222  la.qu.un_520 aa.sw.rw_665 
  0x55003818, 0x283f7304, 0x1d212f04, 0x1d264308,   // tk.rw.un_740 ny.af.sw_332  su.jw.la_332 ie.ia.la_443 
  0x215559a0, 0x361d4d07, 0x182b1da0, 0x343012a4,   // rn.rw.jw_322 aa.la.gn_432  la.vi.ga_322 ur.uz.ps_433 
  0x23074404, 0x083704ee, 0x08001c05, 0x130e1b55,   // kk.bg.ky_332 ru.ba.uk_422  id.no.un_330 tr.is.et_442 
  // [1b9a0]
  0x44043702, 0x1e1c09ec, 0x080220a0, 0x30040704,   // ba.ru.kk_222 pl.id.ms_644  sq.da.no_322 bg.ru.uz_332 
  0x33006a11, 0x46390bee, 0x21123d09, 0x1704380c,   // haw.nn.un_630 es.br.qu_422  ku.ur.fa_444 tk.ru.sr_543 
  0x4a2d490c, 0x1f002505, 0x071242ee, 0x1200fe0b,   // to.sk.yo_543 eu.cy.un_330  co.hu.it_422 tlh.hu.un_520 
  0x4f003e0e, 0x12001b12, 0x33003013, 0x24003102,   // rm.bi.un_550 tr.hu.un_640  uz.nn.un_650 az.eo.un_220 
  // [1b9b0]
  0x30697655, 0x2e24fe55, 0x04173602, 0x65311107,   // crs.mfe.uz_442 tlh.eo.fo_442  ab.sr.ru_222 ro.az.gv_432 
  0x09001902, 0x1805535e, 0x3b2436a4, 0x06303bec,   // gl.pl.un_220 ht.fr.ga_652  gn.eo.so_433 so.uz.de_644 
  0x2122230c, 0x0300061a, 0x0e3f4f07, 0x06001f22,   // ca.oc.jw_543 de.nl.un_760  bi.af.is_432 cy.de.un_870 
  0x53692c07, 0x3b1364a0, 0x3b000c13, 0x51285804,   // fy.mfe.ht_432 lg.et.so_322  sv.so.un_650 om.sw.kl_332 
  // [1b9c0]
  0x070a6707, 0x48313b0c, 0x343d2102, 0x150301af,   // ak.pt.it_432 so.az.tt_543  fa.ku.ps_222 en.nl.un_655 
  0xfc6506a0, 0x014d2a08, 0x400e26a0, 0x21003d2b,   // de.gv.zzp_322 mt.aa.en_443  ia.is.lb_322 ku.fa.un_980 
  0x0c081308, 0x3610520c, 0x342318a0, 0x6501430c,   // et.no.sv_443 ha.lt.gn_543  ar.ky.ps_322 ie.en.gv_543 
  0x265d5f0c, 0x5d7659a9, 0x1747100c, 0x110210a4,   // tn.ss.ia_543 rn.crs.ss_544  lt.sn.sr_543 lt.da.ro_433 
  // [1b9d0]
  0x4400171a, 0x564730a4, 0x35280204, 0x48214202,   // sr.kk.un_760 uz.sn.mg_433  da.sw.zu_332 co.jw.tt_222 
  0x02000905, 0x30103cad, 0x041050a4, 0x162d09a4,   // pl.da.un_330 ug.be.uz_643  fj.lt.fi_433 pl.sk.hr_433 
  0x151715a0, 0x69fe795a, 0x28006512, 0x0c1107a9,   // un.sr.un_322 war.tlh.mfe_553  gv.sw.un_640 it.ro.sv_544 
  0x38371caf, 0x071133a4, 0x3600230d, 0x0c5547af,   // id.st.tk_655 nn.ro.it_433  ky.ab.un_540 sn.rw.sv_655 
  // [1b9e0]
  0x4f551ca9, 0x2136030c, 0x5d350907, 0x470c330c,   // id.rw.bi_544 nl.gn.jw_543  pl.zu.ss_432 nn.sv.sn_543 
  0x3969760c, 0x4c07420c, 0x37112c0b, 0x69531208,   // crs.mfe.br_543 co.it.wo_543  fy.ro.st_542 hu.ht.mfe_443 
  0x071008ec, 0x5d5c68a4, 0x1d07110d, 0xfc2c570c,   // uk.be.bg_644 ig.sa.ss_433  ro.it.la_554 na.fy.zzp_543 
  0x0976110c, 0x64007322, 0x1b28730c, 0x3b590207,   // ro.crs.pl_543 ny.lg.un_870  ny.sw.tr_543 da.rn.so_432 
  // [1b9f0]
  0x1d4c1107, 0x360c070c, 0x07252fa9, 0x260c11a4,   // ro.wo.la_432 it.sv.gn_543  su.eu.it_544 ro.sv.ia_433 
  0x536933a0, 0x0b56280c, 0x16100da7, 0x1d6b4aa4,   // nn.mfe.ht_322 sw.mg.es_543  cs.lt.hr_532 yo.ceb.la_433 
  0x652e2805, 0x50202704, 0x49574a11, 0x233d28a4,   // sw.fo.gv_333 gd.sq.fj_332  yo.na.to_653 sd.ku.ky_433 
  0x00007937, 0x56003b0c, 0x231548a7, 0x49281309,   // war.un.un_B00 so.mg.un_530  tt.ky.un_520 et.sw.to_444 
  // [1ba00]
  0x2c580304, 0x60477305, 0x123018ec, 0x44213ba4,   // nl.om.fy_332 ny.sn.vo_333  ar.uz.ur_644 ks.fa.kk_433 
  0x0d102904, 0x231048a7, 0x4836230d, 0x4c203605,   // sl.lt.cs_332 tt.be.ky_532  ky.ab.tt_554 gn.sq.wo_333 
  0x380e2eee, 0x21183d0d, 0x11233808, 0x07422407,   // fo.is.tk_422 ku.ar.fa_554  tk.ky.ro_443 eo.co.it_432 
  0x040835a9, 0x2e5876a4, 0x3100520d, 0x210458a0,   // tg.uk.ru_544 crs.om.fo_433  ha.az.un_540 om.fi.jw_322 
  // [1ba10]
  0x1c005811, 0x19005607, 0x3f2b02ee, 0x580c5407,   // om.id.un_630 mg.gl.un_420  da.vi.af_422 ik.sv.om_432 
  0x492b6a0c, 0x0f005808, 0x4b2c4904, 0x3b3058ee,   // haw.vi.to_543 om.lv.un_430  to.fy.mi_332 om.uz.so_422 
  0x32002d0d, 0x330c5304, 0x12005808, 0x560601a0,   // sk.bs.un_540 ht.sv.nn_332  om.hu.un_430 en.de.mg_322 
  0x35585d55, 0x0f341c02, 0x512608a0, 0x13565107,   // ss.om.zu_442 id.xh.lv_222  no.ia.kl_322 kl.mg.et_432 
  // [1ba20]
  0x1e1c6909, 0x124218ee, 0x2f005407, 0x0a2a0107,   // mfe.id.ms_444 ga.co.hu_422  ik.su.un_420 en.mt.pt_432 
  0x32005807, 0x58fe0eaf, 0xfe30580c, 0x3e033f60,   // om.bs.un_420 is.tlh.om_655  om.uz.tlh_543 af.nl.rm_664 
  0x5a005712, 0x08043c04, 0x06002e04, 0x301221af,   // na.sm.un_640 ug.ru.uk_332  fo.de.un_320 fa.ur.uz_655 
  0x213d305a, 0x234434ad, 0x21131cee, 0x58000418,   // uz.ku.fa_553 ps.kk.ky_643  id.et.jw_422 fi.om.un_740 
  // [1ba30]
  0x25455307, 0x10136904, 0x420712a9, 0x79001d0d,   // ht.ln.eu_432 mfe.et.lt_332  hu.it.co_544 la.war.un_540 
  0x08004420, 0x0a405107, 0x221d0a04, 0x050320ee,   // kk.uk.un_850 kl.lb.pt_432  pt.la.oc_332 sq.nl.fr_422 
  0x0d362d11, 0x062322a0, 0x28213d0c, 0x231d570c,   // sk.gn.cs_653 oc.ca.de_322  ku.fa.sd_543 na.la.ca_543 
  0x23fc1d0c, 0x64001c05, 0x1c65090c, 0x070436ee,   // la.zzp.ca_543 id.lg.un_330  pl.gv.id_543 ab.ru.bg_422 
  // [1ba40]
  0x440a150c, 0x091f6507, 0x302548a4, 0x12003c08,   // un.mk.kk_543 gv.cy.pl_432  tt.mn.uz_433 ug.ur.un_430 
  0x2f00090d, 0x123d210e, 0x073035ec, 0x321b5c0c,   // pl.su.un_540 fa.ku.ur_555  tg.uz.bg_644 sa.tr.bs_543 
  0x2e0e105a, 0x233d3ba4, 0x3007181d, 0x1c00042a,   // lt.is.fo_553 ks.ku.ky_433  ar.bg.uz_852 fi.id.un_970 
  0x65284955, 0x1f001904, 0x1e1c1fa0, 0x044844ac,   // to.sw.gv_442 gl.cy.un_320  cy.id.ms_322 kk.tt.ru_632 
  // [1ba50]
  0x496a5aa9, 0x291540a4, 0x344a40a9, 0x53024aa7,   // sm.haw.to_544 lb.sl.un_430  lb.yo.xh_544 yo.da.ht_532 
  0x021f3fad, 0x25363807, 0x33082909, 0x34321ba0,   // af.cy.da_643 tk.ab.mn_432  sl.no.nn_444 tr.bs.xh_322 
  0x5f377507, 0x1800201a, 0x6b1a680c, 0x1729230c,   // nso.st.tn_432 sq.ga.un_760  ig.tl.ceb_543 ca.sl.sr_543 
  0x23102508, 0x42683908, 0x253736a4, 0x420501a4,   // mn.be.ky_443 br.ig.co_443  ab.ba.mn_433 en.fr.co_433 
  // [1ba60]
  0x1f3e42a0, 0x0a003009, 0x070a08a7, 0x1d6442ad,   // co.rm.cy_322 uz.mk.un_440  uk.mk.bg_532 co.lg.la_643 
  0x2a00090b, 0x230a1002, 0x04001805, 0x57312008,   // pl.mt.un_520 be.mk.ky_222  ga.fi.un_330 sq.az.na_443 
  0xfc5c42a0, 0x2800230e, 0x0165fca7, 0x57380da0,   // co.sa.zzp_322 ky.sd.un_550  zzp.gv.en_532 cs.tk.na_322 
  0x5d01fcee, 0x5a00180c, 0x6020450c, 0x35005e0e,   // zzp.en.ss_422 ga.sm.un_530  ln.sq.vo_543 ts.zu.un_550 
  // [1ba70]
  0x0935fc08, 0x200b1308, 0x553473ad, 0x156563a0,   // zzp.zu.pl_443 et.es.sq_443  ny.xh.rw_643 sco.gv.un_322 
  0x203001a0, 0x17004607, 0x021f35af, 0x0807360c,   // en.uz.sq_322 qu.sr.un_420  zu.cy.da_655 ab.bg.uk_543 
  0x5d2051a9, 0xfc00021a, 0x31304855, 0x1e006a0d,   // kl.sq.ss_544 da.zzp.un_760  tt.uz.az_442 haw.ms.un_540 
  0x12183bad, 0x505a470c, 0x25006a08, 0x73597809,   // ks.ar.ur_643 sn.sm.fj_543  haw.eu.un_430 ve.rn.ny_444 
  // [1ba80]
  0x08102507, 0x652f1c08, 0x37355d5a, 0x220576a9,   // mn.be.uk_432 id.su.gv_443  ss.zu.st_553 crs.fr.oc_544 
  0x213012ac, 0x5d5534a4, 0x3b000702, 0x25444805,   // ur.uz.fa_632 xh.rw.ss_433  it.so.un_220 tt.kk.mn_333 
  0x68353413, 0x1f5a25ec, 0x3600400e, 0x5d53680c,   // xh.zu.ig_665 eu.sm.cy_644  lb.gn.un_550 ig.ht.ss_543 
  0x36002322, 0x32301ca0, 0x5d4735a9, 0x36000d11,   // ky.ab.un_870 id.uz.bs_322  zu.sn.ss_544 cs.gn.un_630 
  // [1ba90]
  0x5d001c0d, 0x40003621, 0x651e1c08, 0x47766908,   // id.ss.un_540 gn.lb.un_860  id.ms.gv_443 mfe.crs.sn_443 
  0x182834af, 0x27595504, 0x39534007, 0x0444170b,   // ps.sd.ar_655 rw.rn.gd_332  lb.ht.br_432 sr.kk.ru_542 
  0x0f321705, 0x42595555, 0x011f62a4, 0x401236ac,   // sr.bs.lv_333 rw.rn.co_442  kha.cy.en_433 gn.hu.lb_632 
  0x65020cad, 0x0a17230c, 0x04082511, 0x3215010c,   // sv.da.gv_643 ky.sr.mk_543  mn.uk.ru_653 en.bs.un_530 
  // [1baa0]
  0x46352904, 0x04405105, 0x23070a04, 0x254423ad,   // sl.zu.qu_332 kl.lb.fi_333  mk.bg.ky_332 ky.kk.mn_643 
  0x17100811, 0x17002309, 0x123b1807, 0x68004a0e,   // uk.be.sr_653 ky.sr.un_440  ar.ks.ur_432 yo.ig.un_550 
  0x303510a0, 0x174830a0, 0x0a113655, 0x0a071160,   // be.tg.uz_322 uz.tt.sr_322  ab.ro.mk_442 ro.bg.mk_664 
  0x100844a7, 0x151710a4, 0x303c15a4, 0x65271814,   // kk.uk.be_532 be.sr.un_433  un.ug.uz_433 ga.gd.gv_666 
  // [1bab0]
  0x40273ba0, 0x53001b07, 0x37634914, 0x321709ee,   // so.gd.lb_322 tr.ht.un_420  to.sco.st_666 pl.sr.bs_422 
  0x58045f08, 0x37004c0e, 0x343b5a60, 0x52000b02,   // tn.fi.om_443 wo.st.un_550  sm.so.xh_664 es.ha.un_220 
  0x69374c12, 0x4d4c655a, 0x4c0163ee, 0x636e01a0,   // wo.st.mfe_654 gv.wo.aa_553  sco.en.wo_422 en.hmn.sco_322 
  0x4d4a5812, 0x794c65a7, 0x636a5a5a, 0x4408100b,   // om.yo.aa_654 gv.wo.war_532  sm.haw.sco_553 be.uk.kk_542 
  // [1bac0]
  0x03190a04, 0x754c4dad, 0x494d0111, 0x07100aa9,   // pt.gl.nl_332 aa.wo.nso_643  en.aa.to_653 mk.be.bg_544 
  0x4a003e0d, 0x213012a0, 0x3800442a, 0x12213b07,   // rm.yo.un_540 ur.uz.fa_322  kk.tk.un_970 ks.fa.ur_432 
  0x0804115a, 0x30353455, 0x36002013, 0x400906a4,   // ro.ru.uk_553 xh.zu.uz_442  sq.gn.un_650 de.pl.lb_433 
  0x40004c05, 0x3800561b, 0x3f402104, 0x3500342a,   // wo.lb.un_330 mg.tk.un_770  jw.lb.af_332 xh.zu.un_970 
  // [1bad0]
  0x283444a9, 0x2d0d380c, 0x5738010c, 0x07173004,   // kk.ps.sd_544 tk.cs.sk_543  en.tk.na_543 uz.sr.bg_332 
  0x05022807, 0x03273f07, 0x46622007, 0x53094007,   // sw.da.fr_432 af.gd.nl_432  sq.kha.qu_432 lb.pl.ht_432 
  0x465dfc07, 0x21002007, 0x3e003605, 0x5300380b,   // zzp.ss.qu_432 sq.jw.un_420  gn.rm.un_330 tk.ht.un_520 
  0x33005612, 0x08352302, 0x3f2c6aa0, 0x0c3f0312,   // mg.nn.un_640 ky.tg.uk_222  haw.fy.af_322 nl.af.sv_654 
  // [1bae0]
  0x32175609, 0x222d53af, 0x092d560d, 0x08003705,   // mg.sr.bs_444 ht.sk.oc_655  mg.sk.pl_554 ba.uk.un_330 
  0x630afe04, 0x44233dec, 0x09005308, 0x150711ec,   // tlh.pt.sco_332 ku.ky.kk_644  ht.pl.un_430 ro.bg.un_644 
  0x0a003813, 0x030c36ee, 0x60002313, 0x2c495aad,   // tk.mk.un_650 gn.sv.nl_422  ca.vo.un_650 sm.to.fy_643 
  0x100e06a0, 0x34234404, 0x213b3412, 0x27123fee,   // de.is.lt_322 kk.ky.ps_332  ps.ks.fa_654 af.hu.gd_422 
  // [1baf0]
  0x5800510d, 0x083736ee, 0x5c00650b, 0x5607300c,   // kl.om.un_540 ab.ba.uk_422  gv.sa.un_520 uz.it.mg_543 
  0x1c651e04, 0x09002c07, 0x3efe2408, 0x3f004905,   // ms.gv.id_332 fy.pl.un_420  eo.tlh.rm_443 to.af.un_330 
  0x50625e55, 0x5a493f04, 0x442118af, 0x4a00490d,   // ts.kha.fj_442 af.to.sm_332  ar.fa.kk_655 to.yo.un_540 
  0x1c00650c, 0x53000302, 0x51330202, 0x371711a7,   // gv.id.un_530 nl.ht.un_220  da.nn.kl_222 ro.sr.ba_532 
  // [1bb00]
  0x271d180c, 0x16005704, 0x49002305, 0x30343b08,   // ga.la.gd_543 na.hr.un_320  ca.to.un_330 ks.ps.uz_443 
  0x04360a04, 0x2d0d5d08, 0x223f23a0, 0x0a000d07,   // mk.ab.ru_332 ss.cs.sk_443  ca.af.oc_322 cs.pt.un_420 
  0x2c003f0b, 0x043c1502, 0x63002719, 0x48001014,   // af.fy.un_520 un.ug.ru_222  gd.sco.un_750 be.tt.un_660 
  0x1b386012, 0x1b3860ec, 0x2338250c, 0x1b38600d,   // vo.tk.tr_654 vo.tk.tr_644  mn.tk.ky_543 vo.tk.tr_554 
  // [1bb10]
  0x0a003614, 0x58002712, 0x301221ac, 0x0a2d36ee,   // gn.pt.un_660 gd.om.un_640  fa.ur.uz_632 gn.sk.pt_422 
  0x53003f05, 0x601b3812, 0x12302812, 0x1b002e0e,   // af.ht.un_330 tk.tr.vo_654  sd.uz.ur_654 fo.tr.un_550 
  0x172515a4, 0x211e2f04, 0x2e003629, 0x17100a0c,   // un.mn.sr_433 su.ms.jw_332  gn.fo.un_960 mk.be.sr_543 
  0x06216ea0, 0x1004360c, 0x0c022a04, 0x6700641b,   // hmn.jw.de_322 ab.ru.be_543  mt.da.sv_332 lg.ak.un_770 
  // [1bb20]
  0x1a4b6a0d, 0x2700690c, 0x395f64a9, 0x36001f1a,   // haw.mi.tl_554 mfe.gd.un_530  lg.tn.br_544 cy.gn.un_760 
  0x29007904, 0x150c45a0, 0x07003e08, 0x462b03a0,   // war.sl.un_320 ln.sv.un_322  rm.it.un_430 nl.vi.qu_322 
  0x260b07a9, 0x562057a4, 0x1dfc420c, 0x053f0d0c,   // it.es.ia_544 na.sq.mg_433  co.zzp.la_543 cs.af.fr_543 
  0x190a18ee, 0x3f002e02, 0x4a1219ec, 0x30000605,   // ga.pt.gl_422 fo.af.un_220  gl.hu.yo_644 de.uz.un_330 
  // [1bb30]
  0x070242a4, 0x11002621, 0x35631155, 0x211d1102,   // co.da.it_433 ia.ro.un_860  ro.sco.zu_442 ro.la.jw_222 
  0x111d3e5a, 0x43001d05, 0x2d021112, 0x3d343060,   // rm.la.ro_553 la.ie.un_330  ro.da.sk_654 uz.ps.ku_664 
  0x43421d0c, 0x25080704, 0x42111dec, 0x0e122eee,   // la.co.ie_543 bg.uk.mn_332  la.ro.co_644 fo.hu.is_422 
  0x35304807, 0x443d3c5a, 0x5b00201a, 0x2e0e7955,   // tt.uz.tg_432 ug.ku.kk_553  sq.sg.un_760 war.is.fo_442 
  // [1bb40]
  0x4a2322a4, 0x1300651a, 0x65001313, 0x3b2713ee,   // oc.ca.yo_433 gv.et.un_760  et.gv.un_650 et.gd.so_422 
  0x5b005221, 0x1e063ead, 0x3c113507, 0x18136507,   // ha.sg.un_860 rm.de.ms_643  tg.ro.ug_432 gv.et.ga_432 
  0x3b281205, 0x1b002f0e, 0x28181607, 0xfc2f0504,   // ur.sd.ks_333 su.tr.un_550  th.ar.sd_432 fr.su.zzp_332 
  0x15136513, 0x21011302, 0x2d00610c, 0x480804ee,   // gv.et.un_665 et.en.jw_222  za.sk.un_530 ru.uk.tt_422 
  // [1bb50]
  0x060521a6, 0x61005b14, 0x0755570c, 0x5b60500c,   // jw.fr.de_521 sg.za.un_660  na.rw.it_543 fj.vo.sg_543 
  0x100a17af, 0x11002c0d, 0x292d0d5a, 0x44483ca0,   // sr.mk.be_655 fy.ro.un_540  cs.sk.sl_553 ug.tt.kk_322 
  0x08151708, 0x241f2f08, 0x4c002d0c, 0x0a174405,   // sr.uk.un_430 su.cy.eo_443  sk.wo.un_530 kk.sr.mk_333 
  0x091057a9, 0x24092d08, 0x46344da4, 0x211828ec,   // na.lt.pl_544 sk.pl.eo_443  aa.xh.qu_433 sd.ar.fa_644 
  // [1bb60]
  0x191d4604, 0x11634307, 0x20465708, 0x05004605,   // qu.la.gl_332 ie.sco.ro_432  na.qu.sq_443 qu.fr.un_330 
  0x4d002014, 0x04380a0c, 0x0a1d22a0, 0x405a6a08,   // sq.aa.un_660 mk.tk.ru_543  oc.la.pt_322 haw.sm.lb_443 
  0x4b3801a4, 0x026856a9, 0x671e1c60, 0x35460ba0,   // en.tk.mi_433 mg.ig.da_544  id.ms.ak_664 es.qu.zu_322 
  0x03212f09, 0x0d171307, 0x1d0b0a05, 0x37002c11,   // su.jw.nl_444 et.sr.cs_432  pt.es.la_333 fy.st.un_630 
  // [1bb70]
  0x2f005b13, 0x461d0508, 0x401d070c, 0x463e1d04,   // sg.su.un_650 fr.la.qu_443  it.la.lb_543 la.rm.qu_332 
  0x26110107, 0x790b46a4, 0x58650aa0, 0x261d4da4,   // en.ro.ia_432 qu.es.war_433  pt.gv.om_322 aa.la.ia_433 
  0x031b4012, 0x201b3808, 0x595525a4, 0x3b194c07,   // lb.tr.nl_654 tk.tr.sq_443  eu.rw.rn_433 wo.gl.so_432 
  0x5a731ca4, 0x38674a0c, 0x36504ba9, 0x07201b0b,   // id.ny.sm_433 yo.ak.tk_543  mi.fj.gn_544 tr.sq.it_542 
  // [1bb80]
  0x1b2f21ee, 0x3c38250d, 0x605703a9, 0x13483e0c,   // jw.su.tr_422 mn.tk.ug_554  nl.na.vo_544 rm.tt.et_543 
  0x44230a12, 0x09381bad, 0x601b4a0c, 0x173510a4,   // mk.ky.kk_654 tr.tk.pl_643  yo.tr.vo_543 be.tg.sr_433 
  0x211c68a4, 0x55071b0c, 0x3e000e08, 0x5a4f5704,   // ig.id.jw_433 tr.it.rw_543  is.rm.un_430 na.bi.sm_332 
  0x49283712, 0x2838450c, 0x01796b04, 0x692b495a,   // st.sw.to_654 ln.tk.sw_543  ceb.war.en_332 to.vi.mfe_553 
  // [1bb90]
  0x280a4f0d, 0xfe495aee, 0x2b377514, 0x64002505,   // bi.pt.sw_554 sm.to.tlh_422  nso.st.vi_666 eu.lg.un_330 
  0x75003308, 0x56286013, 0x75002822, 0x5a562bec,   // nn.nso.un_430 vo.sw.mg_665  sw.nso.un_870 vi.mg.sm_644 
  0x5a2b560c, 0x56001a2c, 0x0e00181a, 0x301008a4,   // mg.vi.sm_543 tl.mg.un_990  ga.is.un_760 uk.be.uz_433 
  0x384837a4, 0x38482308, 0x48381008, 0x464267ee,   // ba.tt.tk_433 ky.tt.tk_443  be.tk.tt_443 ak.co.qu_422 
  // [1bba0]
  0x5400fe0e, 0x46005413, 0x5a1d13ee, 0x495154ac,   // tlh.ik.un_550 ik.qu.un_650  et.la.sm_422 ik.kl.to_632 
  0x4a002805, 0x10001102, 0x12001f07, 0x0b1d28a7,   // sw.yo.un_330 ro.lt.un_220  cy.hu.un_420 sw.la.es_532 
  0x4600541a, 0x495f7960, 0x37252407, 0x33004005,   // ik.qu.un_760 war.tn.to_664  eo.eu.st_432 lb.nn.un_330 
  0x2d3b6ba4, 0x0d342d07, 0x2d0d310e, 0x040a17a9,   // ceb.so.sk_433 sk.xh.cs_432  az.cs.sk_555 sr.mk.ru_544 
  // [1bbb0]
  0x4a00491a, 0x081507a0, 0x3b000d0d, 0x563905a4,   // to.yo.un_760 bg.uk.un_320  cs.so.un_540 fr.br.mg_433 
  0x19240aa6, 0x243940ee, 0x0d00310e, 0x65131f09,   // pt.eo.gl_521 lb.br.eo_422  az.cs.un_550 cy.et.gv_444 
  0x312d0d13, 0x213b4aee, 0x13006512, 0x292dfe04,   // cs.sk.az_665 yo.so.jw_422  gv.et.un_640 tlh.sk.sl_332 
  0x2d3531a0, 0x653b1307, 0x23004904, 0x321629a7,   // az.zu.sk_322 et.so.gv_432  to.ca.un_320 sl.hr.bs_532 
  // [1bbc0]
  0x12213b14, 0x1b321702, 0x2c0313ee, 0x65003819,   // ks.fa.ur_666 sr.bs.tr_222  et.nl.fy_422 tk.gv.un_750 
  0x17083cad, 0xfc102007, 0x65381f12, 0x38fc6508,   // ug.uk.sr_643 sq.lt.zzp_432  cy.tk.gv_654 gv.zzp.tk_443 
  0xfc0c1005, 0x381f650e, 0xfc026507, 0x20fc65a4,   // lt.sv.zzp_333 gv.cy.tk_555  gv.da.zzp_432 gv.zzp.sq_433 
  0x48150812, 0x342830a9, 0x254c28a7, 0x404c39a0,   // uk.tt.un_640 uz.sd.ps_544  sw.wo.eu_532 br.wo.lb_322 
  // [1bbd0]
  0x37002518, 0x103b07a0, 0x371011ee, 0x170830a0,   // mn.ba.un_740 it.so.lt_322  ro.be.ba_422 uz.uk.sr_322 
  0x331f62a4, 0x30151705, 0x5c1c1312, 0x11001714,   // kha.cy.nn_433 sr.uz.un_330  bh.mr.sa_654 sr.ro.un_660 
  0x38480c04, 0x15362507, 0x11080408, 0x2a005713,   // sv.tt.tk_332 mn.ab.un_432  ru.uk.ro_443 na.mt.un_650 
  0x3c15250b, 0x016b1304, 0x38004811, 0x6a5c4b12,   // mn.ug.un_520 et.ceb.en_332  tt.tk.un_630 mi.sa.haw_654 
  // [1bbe0]
  0x01002b04, 0x2330350b, 0x681834a4, 0x02390e05,   // vi.en.un_320 tg.uz.ky_542  xh.ga.ig_433 is.br.da_333 
  0x174423a0, 0x15001f11, 0x37041707, 0x5d5e35ee,   // ky.kk.sr_322 cy.un.un_630  sr.ru.ba_432 zu.ts.ss_422 
  0x29002202, 0x40003504, 0x252315ad, 0x52604a07,   // oc.sl.un_220 zu.lb.un_320  un.ky.mn_643 yo.vo.ha_432 
  0x6b3e1dee, 0x7800362b, 0x190b3655, 0x191f0b0c,   // la.rm.ceb_422 gn.ve.un_980  gn.es.gl_442 es.cy.gl_543 
  // [1bbf0]
  0x360b07a0, 0x54566a0c, 0x4c345b04, 0x034a670c,   // it.es.gn_322 haw.mg.ik_543  sg.xh.wo_332 ak.yo.nl_543 
  0x01565308, 0x250260a7, 0xfe006819, 0x2f360ba0,   // ht.mg.en_443 vo.da.eu_532  ig.tlh.un_750 es.gn.su_322 
  0x1d006005, 0x4cfe64ee, 0x56456ea4, 0x1d006507,   // vo.la.un_330 lg.tlh.wo_422  hmn.ln.mg_433 gv.la.un_420 
  0x30241d07, 0x345d3705, 0x422f270b, 0x5a006008,   // la.eo.uz_432 st.ss.xh_333  gd.su.co_542 vo.sm.un_430 
  
  // [1bc00]
  0x532f6905, 0x190afe05, 0x190a0baf, 0x340a0da4,   // mfe.su.ht_333 tlh.pt.gl_333  es.pt.gl_655 cs.pt.xh_433 
  0x36790b04, 0x24006008, 0x295c24ee, 0x0959570e,   // es.war.gn_332 vo.eo.un_430  eo.sa.sl_422 na.rn.pl_555 
  0x0a001e05, 0x5a075f0d, 0x3f005812, 0x342328a4,   // ms.pt.un_330 tn.it.sm_554  om.af.un_640 sd.ky.ps_433 
  0x39007904, 0x1c511eee, 0x4b246eaf, 0x1300241a,   // war.br.un_320 ms.kl.id_422  hmn.eo.mi_655 eo.et.un_760 
  // [1bc10]
  0x4700300c, 0x0e4a19a9, 0x483c300b, 0x07481507,   // uz.sn.un_530 gl.yo.is_544  uz.ug.tt_542 un.tt.bg_432 
  0x0a441705, 0x130c54a9, 0x53005712, 0x3900fe08,   // sr.kk.mk_333 ik.sv.et_544  na.ht.un_640 tlh.br.un_430 
  0x36004908, 0x534a57a7, 0x18282308, 0xfe00691a,   // to.gn.un_430 na.yo.ht_532  ky.sd.ar_443 mfe.tlh.un_760 
  0x2b5322a4, 0x23004902, 0x5300571a, 0x213f0304,   // oc.ht.vi_433 to.ca.un_220  na.ht.un_760 nl.af.jw_332 
  // [1bc20]
  0x5376690e, 0x1c122e02, 0x21000505, 0x0c5c2607,   // mfe.crs.ht_555 fo.hu.id_222  fr.jw.un_330 ia.sa.sv_432 
  0x3efe33a7, 0x32005c04, 0x13003805, 0x20004729,   // nn.tlh.rm_532 sa.bs.un_320  tk.et.un_330 sn.sq.un_960 
  0x04110809, 0x4500360d, 0x303715a7, 0x083736a0,   // uk.ro.ru_444 gn.ln.un_540  un.ba.uz_532 ab.ba.uk_322 
  0x48004902, 0x2d4948a4, 0x23381007, 0x04103755,   // to.tt.un_220 tt.to.sk_433  be.tk.ky_432 ba.be.ru_442 
  // [1bc30]
  0x556406a7, 0x0f735d07, 0x483008ec, 0x233837ad,   // de.lg.rw_532 ss.ny.lv_432  uk.uz.tt_644 ba.tk.ky_643 
  0x06002519, 0x060d57a7, 0x42300604, 0x4803fe04,   // eu.de.un_750 na.cs.de_532  de.uz.co_332 tlh.nl.tt_332 
  0x03330b5e, 0x56530508, 0x0ffc2909, 0x1ffc06a4,   // bn.as.ko_652 fr.ht.mg_443  sl.zzp.lv_444 de.zzp.cy_433 
  0x2000211a, 0x084417ac, 0x69fc1d0c, 0x3f1d060c,   // jw.sq.un_760 sr.kk.uk_632  la.zzp.mfe_543 de.la.af_543 
  // [1bc40]
  0x3e1f2704, 0x68401507, 0x0e002507, 0x171023a7,   // gd.cy.rm_332 un.lb.ig_432  eu.is.un_420 ky.be.sr_532 
  0x17131555, 0x13006514, 0x6500130e, 0x13006513,   // un.et.sr_442 gv.et.un_660  et.gv.un_550 gv.et.un_650 
  0x013365a0, 0x5a501904, 0x2e003907, 0x65001309,   // gv.nn.en_322 gl.fj.sm_332  br.fo.un_420 et.gv.un_440 
  0x1f2e1304, 0x63003e33, 0x36101507, 0x503964a7,   // et.fo.cy_332 rm.sco.un_A70  un.be.ab_432 lg.br.fj_532 
  // [1bc50]
  0x3e381bee, 0x75000104, 0x13002c2b, 0x03004d04,   // tr.tk.rm_422 en.nso.un_320  fy.et.un_980 aa.nl.un_320 
  0x1b6420ec, 0x014760ee, 0x605d1baf, 0x341c45a4,   // sq.lg.tr_644 vo.sn.en_422  tr.ss.vo_655 ln.id.xh_433 
  0x25373807, 0x2b274a0c, 0x423905ec, 0x04361014,   // tk.ba.mn_432 yo.gd.vi_543  fr.br.co_644 be.ab.ru_666 
  0x183d3412, 0x62371ea4, 0x18005f04, 0x18005b0d,   // ps.ku.ar_654 ms.st.kha_433  tn.ga.un_320 sg.ga.un_540 
  // [1bc60]
  0xfc3435ad, 0x4a002b21, 0x73005904, 0x5d004702,   // zu.xh.zzp_643 vi.yo.un_860  rn.ny.un_320 sn.ss.un_220 
  0x2f345d08, 0x55594707, 0x20283bad, 0x353e64a7,   // ss.xh.su_443 sn.rn.rw_432  so.sw.sq_643 lg.rm.zu_532 
  0x0275640b, 0x2a423e5a, 0x65732a07, 0x2812590c,   // lg.nso.da_542 rm.co.mt_553  mt.ny.gv_432 rn.hu.sw_543 
  0x59475508, 0x1c783b07, 0x59345513, 0x30123d0c,   // rw.sn.rn_443 so.ve.id_432  rw.xh.rn_665 ku.ur.uz_543 
  // [1bc70]
  0x31022009, 0x42004a0e, 0x5e5f1f05, 0x55782812,   // sq.da.az_444 yo.co.un_550  cy.tn.ts_333 sw.ve.rw_654 
  0x10596408, 0x322d1760, 0x55474504, 0x1f605e12,   // lg.rn.lt_443 sr.sk.bs_664  ln.sn.rw_332 ts.vo.cy_654 
  0x68006721, 0x3f2f5302, 0x4a2b4211, 0x5efa5d12,   // ak.ig.un_860 ht.su.af_222  co.vi.yo_653 ss.nr.ts_654 
  0x35345b14, 0x3031380c, 0x060702a0, 0x24003011,   // sg.xh.zu_666 tk.az.uz_543  da.it.de_322 uz.eo.un_630 
  // [1bc80]
  0x737828a4, 0x35697607, 0x790657ec, 0x5564680c,   // sw.ve.ny_433 crs.mfe.zu_432  na.de.war_644 ig.lg.rw_543 
  0x0f006113, 0x37125d04, 0x3f003b05, 0x69005619,   // za.lv.un_650 ss.hu.st_332  so.af.un_330 mg.mfe.un_750 
  0x55785908, 0x56532d07, 0x63005e18, 0x17080705,   // rn.ve.rw_443 sk.ht.mg_432  ts.sco.un_740 bg.uk.sr_333 
  0x65005a09, 0x351b6112, 0x40005b0b, 0x0a083008,   // sm.gv.un_440 za.tr.zu_654  sg.lb.un_520 uz.uk.mk_443 
  // [1bc90]
  0x23001709, 0x291827ee, 0x4a00480d, 0x113e65a0,   // sr.ky.un_440 gd.ga.sl_422  tt.yo.un_540 gv.rm.ro_322 
  0x4c2c1355, 0x133b4cee, 0x032e3fee, 0x653f03ad,   // et.fy.wo_442 wo.so.et_422  af.fo.nl_422 nl.af.gv_643 
  0x15040a0e, 0x183d2105, 0x431d2614, 0x01151d0c,   // mk.ru.un_555 fa.ku.ar_333  ia.la.ie_666 la.en.un_530 
  0x2000030d, 0x65290207, 0x0c3f03a4, 0x1d00431a,   // nl.sq.un_540 da.sl.gv_432  nl.af.sv_433 ie.la.un_760 
  // [1bca0]
  0x5e002005, 0x170a3509, 0x283d21a9, 0x6b656302,   // sq.ts.un_330 tg.mk.sr_444  fa.ku.sd_544 sco.gv.ceb_222 
  0x0f1710ad, 0x2c03fe07, 0x2d0d28a0, 0x360e2e12,   // lt.sr.lv_643 tlh.nl.fy_432  sw.cs.sk_322 fo.is.gn_654 
  0x55003b0d, 0x0100760d, 0x5a010604, 0x07150a05,   // so.rw.un_540 crs.en.un_540  de.en.sm_332 mk.bg.un_330 
  0x332d0d5a, 0x331008a6, 0x625101ee, 0x76003e0e,   // cs.sk.nn_553 no.lt.nn_521  en.kl.kha_422 rm.crs.un_550 
  // [1bcb0]
  0x0a073002, 0x3e05650c, 0x30153513, 0x057601a7,   // uz.bg.mk_222 gv.fr.rm_543  tg.uz.un_650 en.crs.fr_532 
  0x65003913, 0x48104412, 0x76000536, 0x49001109,   // br.gv.un_650 kk.be.tt_654  fr.crs.un_AA0 ro.to.un_440 
  0x30451ca9, 0x4e103008, 0x4930280c, 0x0221130c,   // id.ln.uz_544 uz.lt.ay_443  sw.uz.to_543 et.jw.da_543 
  0x5d5c29a0, 0x1b46fc07, 0x3000471a, 0x48313011,   // sl.sa.ss_322 zzp.qu.tr_432  sn.uz.un_760 uz.az.tt_653 
  // [1bcc0]
  0x557959af, 0x43220107, 0x21305a0c, 0x22fc4607,   // rn.war.rw_655 en.oc.ie_432  sm.uz.jw_543 qu.zzp.oc_432 
  0x07004c02, 0x45004708, 0x3e071108, 0x584e300c,   // wo.it.un_220 sn.ln.un_430  ro.it.rm_443 uz.ay.om_543 
  0x112643a4, 0xfc28200c, 0x3738040d, 0x0a0807a9,   // ie.ia.ro_433 sq.sw.zzp_543  ru.tk.ba_554 bg.uk.mk_544 
  0x2f00430e, 0x2e5c02ee, 0x22002905, 0x43000d04,   // ie.su.un_550 da.sa.fo_422  sl.oc.un_330 cs.ie.un_320 
  // [1bcd0]
  0x6b00430c, 0x0d003611, 0x34212811, 0x526043a9,   // ie.ceb.un_530 gn.cs.un_630  sd.fa.ps_653 ie.vo.ha_544 
  0x58684aa7, 0x78005b2b, 0x3052570c, 0x021f4d0c,   // yo.ig.om_532 sg.ve.un_980  na.ha.uz_543 aa.cy.da_543 
  0x6800252a, 0x102307ee, 0x07291ba0, 0x3d18210e,   // eu.ig.un_970 bg.ky.be_422  tr.sl.it_322 fa.ar.ku_555 
  0x37003811, 0x4000180e, 0x33001102, 0x6200200e,   // tk.ba.un_630 ga.lb.un_550  ro.nn.un_220 sq.kha.un_550 
  // [1bce0]
  0x1629680c, 0x0a00200e, 0x2a0e1008, 0x0a001e02,   // ig.sl.hr_543 sq.pt.un_550  lt.is.mt_443 ms.pt.un_220 
  0x06006812, 0x371038a0, 0x73474e0c, 0x404d2fa4,   // ig.de.un_640 tk.be.ba_322  ay.sn.ny_543 su.aa.lb_433 
  0x3512245a, 0x182740a7, 0x5c00091a, 0x3b2cfe08,   // eo.hu.zu_553 lb.gd.ga_532  hi.sa.un_760 tlh.fy.so_443 
  0x40001812, 0x231004ee, 0x09fc1fad, 0x3e00390e,   // ga.lb.un_640 ru.be.ky_422  cy.zzp.pl_643 br.rm.un_550 
  // [1bcf0]
  0x085c33ee, 0x083101a0, 0x65423e07, 0x08441060,   // nn.sa.no_422 en.az.no_322  rm.co.gv_432 be.kk.uk_664 
  0x5c1b3808, 0x63425805, 0x253938a4, 0x190b4804,   // tk.tr.sa_443 om.co.sco_333  tk.br.eu_433 tt.es.gl_332 
  0xfc1f6b07, 0x18004011, 0x151ffc07, 0x1d243ea7,   // ceb.cy.zzp_432 lb.ga.un_630  zzp.cy.un_432 rm.eo.la_532 
  0x68621d04, 0x3b3031ad, 0x06002c2c, 0x38113007,   // la.kha.ig_332 az.uz.so_643  fy.de.un_990 uz.ro.tk_432 
  // [1bd00]
  0x1a001513, 0x1118fea4, 0x44183cad, 0x250830ad,   // un.tl.un_650 tlh.ga.ro_433  ug.ar.kk_643 uz.uk.mn_643 
  0x3b2865a4, 0x233d2104, 0x616254a9, 0x21182809,   // gv.sw.so_433 fa.ku.ky_332  ik.kha.za_544 sd.ar.fa_444 
  0x36002212, 0x4000180b, 0x0c0638a9, 0x1836050c,   // oc.gn.un_640 ga.lb.un_520  tk.de.sv_544 fr.gn.ga_543 
  0x18003614, 0x23384811, 0x371038a4, 0x071508a7,   // gn.ga.un_660 tt.tk.ky_653  tk.be.ba_433 uk.bg.un_520 
  // [1bd10]
  0x36020107, 0x2718650c, 0x12002019, 0x02002002,   // en.da.gn_432 gv.ga.gd_543  sq.hu.un_750 sq.da.un_220 
  0x33022002, 0x3f651da0, 0x3011480c, 0x0c002a09,   // sq.da.nn_222 la.gv.af_322  tt.ro.uz_543 mt.sv.un_440 
  0x08330213, 0x0b0a18ec, 0x22260208, 0x18190ba7,   // da.nn.no_665 ga.pt.es_644  da.ia.oc_443 es.gl.ga_532 
  0x16006504, 0x3e1b60af, 0x43003607, 0x4000181a,   // gv.hr.un_320 vo.tr.rm_655  gn.ie.un_420 ga.lb.un_760 
  // [1bd20]
  0x041110a4, 0x19400b5a, 0x18400b0c, 0x4000180c,   // be.ro.ru_433 es.lb.gl_553  es.lb.ga_543 ga.lb.un_530 
  0x1f00090c, 0x070a35a4, 0x56002b13, 0x50572ba4,   // pl.cy.un_530 tg.mk.bg_433  vi.mg.un_650 vi.na.fj_433 
  0x0b00180e, 0x492b1dad, 0x40180b04, 0x18000a0d,   // ga.es.un_550 la.vi.to_643  es.ga.lb_332 pt.ga.un_540 
  0x11330808, 0x2f27180b, 0x2f002a0c, 0x171d26af,   // no.nn.ro_443 ga.gd.su_542  mt.su.un_530 ia.la.sr_655 
  // [1bd30]
  0x01003702, 0x240b56a7, 0x752718af, 0x2e006502,   // st.en.un_220 mg.es.eo_532  ga.gd.nso_655 gv.fo.un_220 
  0x5f375614, 0x13156504, 0x680b1d55, 0x483007a4,   // mg.st.tn_666 gv.et.un_320  la.es.ig_442 bg.uz.tt_433 
  0x170a15a7, 0x2e1e6507, 0x073015a6, 0x176513a0,   // un.mk.sr_532 gv.ms.fo_432  un.uz.bg_521 et.gv.sr_322 
  0x631d01a0, 0x4300260d, 0x39000c02, 0x0f3e0b0c,   // en.la.sco_322 ia.ie.un_540  sv.br.un_220 es.rm.lv_543 
  // [1bd40]
  0x69006713, 0x4b001307, 0x67565c5a, 0x13007305,   // ak.mfe.un_650 et.mi.un_420  sa.mg.ak_553 ny.et.un_330 
  0x4c212807, 0x35550405, 0x52130407, 0x31302a55,   // sw.jw.wo_432 fi.rw.zu_333  fi.et.ha_432 mt.uz.az_442 
  0x2a210eee, 0x2e002a0b, 0x23260107, 0x60001b19,   // is.jw.mt_422 mt.fo.un_520  en.ia.ca_432 tr.vo.un_750 
  0x65002207, 0x557364a0, 0x320165a0, 0x38565c04,   // oc.gv.un_420 lg.ny.rw_322  gv.en.bs_322 sa.mg.tk_332 
  // [1bd50]
  0x58006220, 0x28524513, 0xfe295207, 0x3528fa07,   // kha.om.un_850 ln.ha.sw_665  ha.sl.tlh_432 nr.sw.zu_432 
  0x294930af, 0x560d2d0c, 0x650d2d07, 0x494a22a0,   // uz.to.sl_655 sk.cs.mg_543  sk.cs.gv_432 oc.yo.to_322 
  0x033f30a0, 0x501024ac, 0x292d1007, 0x1f006507,   // uz.af.nl_322 eo.lt.fj_632  lt.sk.sl_432 gv.cy.un_420 
  0x07420aa4, 0x02fe6007, 0x505e1007, 0x37255da0,   // pt.co.it_433 vo.tlh.da_432  lt.ts.fj_432 ss.eu.st_322 
  // [1bd60]
  0x4c005204, 0x5624fe55, 0x190b40a0, 0x4c595ea7,   // ha.wo.un_320 tlh.eo.mg_442  lb.es.gl_322 ts.rn.wo_532 
  0x440a1504, 0xfc0b02a0, 0x46424b0c, 0x1267450c,   // un.mk.kk_332 da.es.zzp_322  mi.co.qu_543 ln.ak.hu_543 
  0x28005e0c, 0x30502aa9, 0x5528fe0b, 0x364018a4,   // ts.sw.un_530 mt.fj.uz_544  tlh.sw.rw_542 ga.lb.gn_433 
  0x29002e12, 0x49510407, 0x18054004, 0x56005014,   // fo.sl.un_640 fi.kl.to_432  lb.fr.ga_332 fj.mg.un_660 
  // [1bd70]
  0x40001809, 0x0600730d, 0x29565008, 0x120ffeee,   // ga.lb.un_440 ny.de.un_540  fj.mg.sl_443 tlh.lv.hu_422 
  0x0f00fe12, 0x06480cec, 0x0d0c15a0, 0x1f461da0,   // tlh.lv.un_640 sv.tt.de_644  un.sv.cs_322 la.qu.cy_322 
  0x343b300b, 0x3e050107, 0x267901a4, 0x31002204,   // uz.ks.ps_542 en.fr.rm_432  en.war.ia_433 oc.az.un_320 
  0x10182aad, 0x18004a09, 0x2a30690c, 0x34183c08,   // mt.ga.lt_643 yo.ga.un_440  mfe.uz.mt_543 ug.ar.ps_443 
  // [1bd80]
  0x25003013, 0x39022407, 0x562b0607, 0x0602fcad,   // uz.mn.un_650 eo.da.br_432  de.vi.mg_432 zzp.da.de_643 
  0x202e06a7, 0x45fc27a0, 0x24011dee, 0x6500fc1b,   // de.fo.sq_532 gd.zzp.ln_322  la.en.eo_422 zzp.gv.un_770 
  0x35233c11, 0x153c07a4, 0x360c1dee, 0x152a0204,   // ug.ky.tg_653 bg.ug.un_433  la.sv.gn_422 da.mt.un_332 
  0x03193eee, 0x06fc01a4, 0x0c3e02ee, 0x20004612,   // rm.gl.nl_422 en.zzp.de_433  da.rm.sv_422 qu.sq.un_640 
  // [1bd90]
  0x30250802, 0x0d00180d, 0x303517a0, 0x3c040802,   // uk.mn.uz_222 ga.cs.un_540  sr.tg.uz_322 uk.ru.ug_222 
  0x082515ee, 0x135a51ec, 0x11070aa9, 0x48443714,   // un.mn.uk_422 kl.sm.et_644  mk.bg.ro_544 ba.kk.tt_666 
  0x303b4c04, 0x1100120e, 0x2f002518, 0x12002704,   // wo.so.uz_332 hu.ro.un_550  eu.su.un_740 gd.hu.un_320 
  0x1d132fa0, 0x2f5c630c, 0x51003904, 0x3e60540c,   // su.et.la_322 sco.sa.su_543  br.kl.un_320 ik.vo.rm_543 
  // [1bda0]
  0x061563a0, 0x0f00631a, 0x332e0c02, 0x1c2f63a4,   // sco.de.un_320 sco.lv.un_760  sv.fo.nn_222 sco.su.id_433 
  0x0625fe0b, 0x6b015d07, 0x25004b1a, 0x0f284ba9,   // tlh.eu.de_542 ss.en.ceb_432  mi.eu.un_760 mi.sw.lv_544 
  0x2f020ea9, 0x522a3e13, 0x2d300605, 0x33105ca4,   // is.da.su_544 rm.mt.ha_665  de.uz.sk_333 sa.lt.nn_433 
  0x15001004, 0x52fe24a4, 0x053e57af, 0x16314d0b,   // be.un.un_320 eo.tlh.ha_433  na.rm.fr_655 aa.az.hr_542 
  // [1bdb0]
  0x1d073ea9, 0x3e2f220d, 0x4257580c, 0x12114aa4,   // rm.it.la_544 oc.su.rm_554  om.na.co_543 yo.ro.hu_433 
  0x3e001109, 0x25005207, 0x0a003511, 0x332412a0,   // ro.rm.un_440 ha.eu.un_420  tg.mk.un_630 hu.eo.nn_322 
  0x1d6326ad, 0x5c130608, 0x52091da0, 0x353c1004,   // ia.sco.la_643 de.et.sa_443  la.pl.ha_322 be.ug.tg_332 
  0x60000a1a, 0x2211420c, 0x30004c02, 0x31463ba0,   // pt.vo.un_760 co.ro.oc_543  wo.uz.un_220 so.qu.az_322 
  // [1bdc0]
  0x50203104, 0x4800360e, 0x1c2f65a7, 0x17081005,   // az.sq.fj_332 ab.tt.un_550  gv.su.id_532 be.uk.sr_333 
  0x48001313, 0x4a182dad, 0x201b310c, 0x495a6813,   // et.tt.un_650 sk.ga.yo_643  az.tr.sq_543 ig.sm.to_665 
  0x5e34670d, 0x5237280c, 0x4a5a49af, 0x4a006707,   // ak.xh.ts_554 sw.st.ha_543  to.sm.yo_655 ak.yo.un_420 
  0x3e1f39a0, 0x51001502, 0x1a4d13a4, 0x37645fa9,   // br.cy.rm_322 un.kl.un_220  et.aa.tl_433 tn.lg.st_544 
  // [1bdd0]
  0x0b006504, 0x351357a4, 0x261a6b0d, 0x375f5d0e,   // gv.es.un_320 na.et.zu_433  ceb.tl.ia_554 ss.tn.st_555 
  0x53681f12, 0x02645905, 0x47345da4, 0x3b0c34ad,   // cy.ig.ht_654 rn.lg.da_333  ss.xh.sn_433 xh.sv.so_643 
  0x285d350c, 0x33000502, 0x551d5907, 0x5d341307,   // zu.ss.sw_543 fr.nn.un_220  rn.la.rw_432 et.xh.ss_432 
  0x35513004, 0x3f031f05, 0x431d2407, 0x0e33080d,   // uz.kl.zu_332 cy.nl.af_333  eo.la.ie_432 no.nn.is_554 
  // [1bde0]
  0x27003007, 0x033ffc14, 0x440a11ec, 0x0e2cfc04,   // uz.gd.un_420 zzp.af.nl_666  ro.mk.kk_644 zzp.fy.is_332 
  0x3c342104, 0x4950345a, 0x2c1f03a6, 0x03001f08,   // fa.ps.ug_332 xh.fj.to_553  nl.cy.fy_521 cy.nl.un_430 
  0x230a05ad, 0x65381ea4, 0x09004e0e, 0x1c3864a9,   // fr.pt.ca_643 ms.tk.gv_433  ay.pl.un_550 lg.tk.id_544 
  0x47375e5a, 0x78002833, 0x55755fa9, 0x170a04ad,   // ts.st.sn_553 sw.ve.un_A70  tn.nso.rw_544 ru.mk.sr_643 
  // [1bdf0]
  0x342862ad, 0x0e080c04, 0x05042fee, 0x3906300d,   // kha.sw.xh_643 sv.no.is_332  su.fi.fr_422 uz.de.br_554 
  0x38595509, 0x18233ba0, 0x645e340d, 0x1c551e0c,   // rw.rn.tk_444 ks.ky.ar_322  xh.ts.lg_554 ms.rw.id_543 
  0x0b2e36a7, 0x1e641c0c, 0xfc231ea4, 0x11022404,   // gn.fo.es_532 id.lg.ms_543  ms.ca.zzp_433 eo.da.ro_332 
  0x46003b05, 0x25004c1a, 0x54503e12, 0x435501a0,   // so.qu.un_330 wo.eu.un_760  rm.fj.ik_654 en.rw.ie_322 
  // [1be00]
  0x464b470c, 0x343d3bec, 0x48303c0b, 0x083515ee,   // sn.mi.qu_543 ks.ku.ps_644  ug.uz.tt_542 un.tg.uk_422 
  0x303d3412, 0x06791f05, 0x59005714, 0x34441807,   // ps.ku.uz_654 cy.war.de_333  na.rn.un_660 ar.kk.ps_432 
  0x2c0339a4, 0x19582708, 0x4c00120d, 0x3bfc580b,   // br.nl.fy_433 gd.om.gl_443  hu.wo.un_540 om.zzp.so_542 
  0x062558ee, 0x1827580c, 0x27002002, 0x381f6511,   // om.eu.de_422 om.gd.ga_543  sq.gd.un_220 gv.cy.tk_653 
  // [1be10]
  0x3900581a, 0x35150707, 0x430679a4, 0x2c2d5004,   // om.br.un_760 bg.tg.un_420  war.de.ie_433 fj.sk.fy_332 
  0x07005c04, 0x3400240c, 0x1d4346a7, 0x43244e0b,   // sa.it.un_320 eo.xh.un_530  qu.ie.la_532 ay.eo.ie_542 
  0x1d0e12a4, 0x340679a7, 0x4f002507, 0x2d0d3809,   // hu.is.la_433 war.de.xh_532  eu.bi.un_420 tk.cs.sk_444 
  0x27050a07, 0x1312220c, 0x3207560c, 0x05533908,   // pt.fr.gd_432 oc.hu.et_543  mg.it.bs_543 br.ht.fr_443 
  // [1be20]
  0x25192304, 0x292d1604, 0x604f1ca0, 0x084e33a0,   // ca.gl.eu_332 hr.sk.sl_332  id.bi.vo_322 nn.ay.no_322 
  0x574a68a4, 0x591d68ad, 0x03000504, 0x041710a4,   // ig.yo.na_433 ig.la.rn_643  fr.nl.un_320 be.sr.ru_433 
  0x10003512, 0x303b3d0c, 0x250835a0, 0x49000204,   // tg.be.un_640 ku.ks.uz_543  tg.uk.mn_322 da.to.un_320 
  0x15373fa0, 0x2b004a23, 0x68572107, 0x4a2b2713,   // af.st.un_322 yo.vi.un_880  jw.na.ig_432 gd.vi.yo_665 
  // [1be30]
  0x2400380c, 0x271f29a4, 0x60231f08, 0x27002b21,   // tk.eo.un_530 sl.cy.gd_433  cy.ca.vo_443 vi.gd.un_860 
  0x386839a7, 0x27002b07, 0x2b002714, 0x75673308,   // br.ig.tk_532 vi.gd.un_420  gd.vi.un_660 nn.ak.nso_443 
  0x11004d12, 0x2b004a1b, 0x534a3e05, 0x254009a0,   // aa.ro.un_640 yo.vi.un_770  rm.yo.ht_333 pl.lb.eu_322 
  0x241d570c, 0x60000d08, 0x152060ad, 0x1b4838a7,   // na.la.eo_543 cs.vo.un_430  vo.sq.un_643 tk.tt.tr_532 
  // [1be40]
  0x23396007, 0x6a5051a4, 0x47002107, 0x2e2d0e0c,   // vo.br.ca_432 kl.fj.haw_433  jw.sn.un_420 is.sk.fo_543 
  0x451b3008, 0x3f000a07, 0x04765308, 0x44282304,   // uz.tr.ln_443 pt.af.un_420  ht.crs.fi_443 ky.sd.kk_332 
  0x69055308, 0x213f35a0, 0x45001309, 0x5305760e,   // ht.fr.mfe_443 zu.af.jw_322  et.ln.un_440 crs.fr.ht_555 
  0x631702a6, 0x53012202, 0x09003007, 0x65153102,   // da.sr.sco_521 oc.en.ht_222  uz.pl.un_420 az.gv.un_220 
  // [1be50]
  0x2900430d, 0x3e005313, 0x05537611, 0x29002108,   // ie.sl.un_540 ht.rm.un_650  crs.ht.fr_653 jw.sl.un_430 
  0x43033f05, 0x10011dee, 0x2e0c2a07, 0x1c731e08,   // af.nl.ie_333 la.en.lt_422  mt.sv.fo_432 ms.ny.id_443 
  0x50103912, 0x11121f04, 0x53057609, 0x6953050d,   // br.lt.fj_654 cy.hu.ro_332  crs.fr.ht_444 fr.ht.mfe_554 
  0x73505ea9, 0x3e3007ec, 0x1c2f210d, 0x5a004202,   // ts.fj.ny_544 it.uz.rm_644  jw.su.id_554 co.sm.un_220 
  // [1be60]
  0x39530502, 0x0d385608, 0x07003e13, 0x063e3013,   // fr.ht.br_222 mg.tk.cs_443  rm.it.un_650 uz.rm.de_665 
  0x123c23a0, 0x102239af, 0x365047a0, 0x51003b02,   // ky.ug.ur_322 br.oc.lt_655  sn.fj.gn_322 so.kl.un_220 
  0x06573913, 0x32172102, 0x2c0c020c, 0x2a32165a,   // br.na.de_665 jw.sr.bs_222  da.sv.fy_543 hr.bs.mt_553 
  0x565030af, 0x3e30055a, 0x53001c02, 0x30fe5007,   // uz.fj.mg_655 fr.uz.rm_553  id.ht.un_220 fj.tlh.uz_432 
  // [1be70]
  0x477350ad, 0x37483ca6, 0x24070408, 0x18123b0c,   // fj.ny.sn_643 ug.tt.ba_521  fi.it.eo_443 ks.ur.ar_543 
  0x443736a0, 0x0e0cfcee, 0xfc002718, 0x04354712,   // ab.ba.kk_322 zzp.sv.is_422  gd.zzp.un_740 sn.zu.fi_654 
  0x03001602, 0x333ffc05, 0x24194304, 0x3c304812,   // hr.nl.un_220 zzp.af.nn_333  ie.gl.eo_332 tt.uz.ug_654 
  0x4437250b, 0xfe06fc07, 0x0c0ffca7, 0x30352302,   // mn.ba.kk_542 zzp.de.tlh_432  zzp.lv.sv_532 ky.tg.uz_222 
  // [1be80]
  0x48151007, 0x34001821, 0x65fe130c, 0x4c2a1f04,   // be.tt.un_420 ar.ps.un_860  et.tlh.gv_543 cy.mt.wo_332 
  0x56052204, 0x15001319, 0x08003722, 0x171008a0,   // oc.fr.mg_332 et.un.un_750  ba.uk.un_870 uk.be.sr_322 
  0x170725ee, 0x10041712, 0x0c24060c, 0x3b301f04,   // mn.bg.sr_422 sr.ru.be_654  de.eo.sv_543 cy.uz.so_332 
  0x191d24a4, 0x51065455, 0x130306ad, 0x24033f07,   // eo.la.gl_433 ik.de.kl_442  de.nl.et_643 af.nl.eo_432 
  // [1be90]
  0x6b3f0212, 0x44073704, 0x54005123, 0x24001e04,   // da.af.ceb_654 ba.bg.kk_332  kl.ik.un_880 ms.eo.un_320 
  0x34182307, 0x79602cec, 0x241b5407, 0x54003b1a,   // ky.ar.ps_432 fy.vo.war_644  ik.tr.eo_432 so.ik.un_760 
  0x100715a0, 0x151855a0, 0x0d1c5c14, 0x48173002,   // un.bg.be_322 rw.ga.un_322  sa.mr.ne_666 uz.sr.tt_222 
  0x48153855, 0x01005a02, 0x230a07a9, 0x0a151708,   // tk.tt.un_420 sm.en.un_220  bg.mk.ky_544 sr.mk.un_430 
  // [1bea0]
  0x56002208, 0x10292455, 0x0a071da9, 0x24264304,   // oc.mg.un_430 eo.sl.lt_442  la.it.pt_544 ie.ia.eo_332 
  0x2b564b02, 0x2f4d29ec, 0x5f373608, 0x694a6708,   // mi.mg.vi_222 sl.aa.su_644  gn.st.tn_443 ak.yo.mfe_443 
  0x3b2047ee, 0x3d4423a9, 0x656311ee, 0x4a21100c,   // sn.sq.so_422 ky.kk.ku_544  ro.sco.gv_422 lt.jw.yo_543 
  0x074a10a7, 0x19002113, 0x5000291a, 0x521e1c07,   // lt.yo.it_532 jw.gl.un_650  sl.fj.un_760 id.ms.ha_432 
  // [1beb0]
  0x4f561904, 0x5a561112, 0x65151d04, 0x3400460b,   // gl.mg.bi_332 ro.mg.sm_654  la.gv.un_320 qu.xh.un_520 
  0x42005c04, 0xfc004e0c, 0x631513a7, 0x133f030c,   // sa.co.un_320 ay.zzp.un_530  et.sco.un_520 nl.af.et_543 
  0x651513a7, 0x3f00130e, 0x48071507, 0x73595560,   // et.gv.un_520 et.af.un_550  un.bg.tt_432 rw.rn.ny_664 
  0x1300150d, 0x2c063fa0, 0x3f33085a, 0x45006821,   // un.et.un_540 af.de.fy_322  no.nn.af_553 ig.ln.un_860 
  // [1bec0]
  0x131510ad, 0x455b56ec, 0x39032c07, 0x45643408,   // lt.et.un_630 mg.sg.ln_644  fy.nl.br_432 xh.lg.ln_443 
  0x343b2160, 0x63151312, 0x633f13a4, 0x121527ac,   // fa.ks.ps_664 et.sco.un_640  et.af.sco_433 gd.hu.un_620 
  0x24006822, 0x3f2e0e07, 0x233044ec, 0x0c172aee,   // ig.eo.un_870 is.fo.af_432  kk.uz.ky_644 mt.sr.sv_422 
  0x0a303cad, 0x285a18a0, 0x24002704, 0x13182707,   // ug.uz.mk_643 ga.sm.sw_322  gd.eo.un_320 gd.ga.et_432 
  // [1bed0]
  0x014f6211, 0x033f220c, 0x0a1c5c07, 0x0a4807a7,   // kha.bi.en_653 oc.af.nl_543  sa.mr.mk_432 bg.tt.mk_532 
  0x793f03a4, 0xfc0b0a0d, 0xfc53690d, 0x5c00620c,   // nl.af.war_433 pt.es.zzp_554  mfe.ht.zzp_554 kha.sa.un_530 
  0x332f5c07, 0x0600fc0c, 0x15233855, 0x5c00fc0b,   // sa.su.nn_432 zzp.de.un_530  tk.ky.un_442 zzp.sa.un_520 
  0x17300402, 0x0200fc21, 0x0ffc5c0b, 0xfc000902,   // ru.uz.sr_222 zzp.da.un_860  sa.zzp.lv_542 pl.zzp.un_220 
  // [1bee0]
  0xfe3efc0c, 0x3260fc0c, 0x160711a0, 0x3c213dee,   // zzp.rm.tlh_543 zzp.vo.bs_543  ro.it.hr_322 ku.fa.ug_422 
  0x1004480d, 0x102504a4, 0x791d0107, 0x2d790907,   // tt.ru.be_554 ru.mn.be_433  en.la.war_432 pl.war.sk_432 
  0x070a38a0, 0x230715a4, 0x0b46fcee, 0x202d01a0,   // tk.mk.bg_322 un.bg.ky_433  zzp.qu.es_422 en.sk.sq_322 
  0x190bfca0, 0x6200020e, 0x230507a4, 0x653b2704,   // zzp.es.gl_322 da.kha.un_550  it.fr.ca_433 gd.so.gv_332 
  // [1bef0]
  0x055301a4, 0x151d57ad, 0x2b00050d, 0x02022708,   // en.ht.fr_433 na.la.un_643  fr.vi.un_540 gd.da.da_443 
  0x24125c02, 0x27183ba9, 0x330c6007, 0x63001f21,   // sa.hu.eo_222 so.ga.gd_544  vo.sv.nn_432 cy.sco.un_860 
  0x59553bec, 0x5c2b1c04, 0x133f0607, 0x11001f0e,   // so.rw.rn_644 id.vi.sa_332  de.af.et_432 cy.ro.un_550 
  0x154224ee, 0x40064804, 0x011b4507, 0x13514c04,   // eo.co.un_422 tt.de.lb_332  ln.tr.en_432 wo.kl.et_332 
  // [1bf00]
  0x64004534, 0x5c641a0c, 0x6b59550d, 0x1c2f5502,   // ln.lg.un_A80 tl.lg.sa_543  rw.rn.ceb_554 rw.su.id_222 
  0x645e5513, 0x64001b02, 0x2d5d4207, 0x1200330d,   // rw.ts.lg_665 tr.lg.un_220  co.ss.sk_432 nn.hu.un_540 
  0x4a006421, 0x1b00640d, 0x0c000523, 0x0c300204,   // lg.yo.un_860 lg.tr.un_540  fr.sv.un_880 da.uz.sv_332 
  0x032c24a0, 0x242001a0, 0x232226af, 0x233308ee,   // eo.fy.nl_322 en.sq.eo_322  ia.oc.ca_655 no.nn.ca_422 
  // [1bf10]
  0x27023bee, 0x422115a0, 0x311b5007, 0x30350711,   // so.da.gd_422 un.jw.co_322  fj.tr.az_432 bg.tg.uz_653 
  0x597347a9, 0x48003e02, 0x03102402, 0x352348a4,   // sn.ny.rn_544 rm.tt.un_220  eo.lt.nl_222 tt.ky.tg_433 
  0x3e1b31ad, 0x0e2539a0, 0x244a2512, 0x46676411,   // az.tr.rm_643 br.eu.is_322  eu.yo.eo_654 lg.ak.qu_653 
  0x31212f05, 0x28046e07, 0x49005013, 0x15000b02,   // su.jw.az_333 hmn.fi.sw_432  fj.to.un_650 es.un.un_220 
  // [1bf20]
  0x57001309, 0x5a0f33a0, 0x50005408, 0x30fc3812,   // et.na.un_440 nn.lv.sm_322  ik.fj.un_430 tk.zzp.uz_654 
  0x22503e0c, 0x2a000a04, 0x42005004, 0x1f301b0c,   // rm.fj.oc_543 pt.mt.un_320  fj.co.un_320 tr.uz.cy_543 
  0x0e3952ad, 0x292715a4, 0x23581155, 0x5d00fe09,   // ha.br.is_643 un.gd.sl_433  ro.om.ca_442 tlh.ss.un_440 
  0x1c302e07, 0x2800510c, 0x3035340e, 0x564205a4,   // fo.uz.id_432 kl.sw.un_530  xh.zu.uz_555 fr.co.mg_433 
  // [1bf30]
  0x583152af, 0x5c22050c, 0x073b1f04, 0x280652a4,   // ha.az.om_655 fr.oc.sa_543  cy.so.it_332 ha.de.sw_433 
  0x42690512, 0x2250feee, 0x07695207, 0x1d0c380c,   // fr.mfe.co_654 tlh.fj.oc_422  ha.mfe.it_432 tk.sv.la_543 
  0x0a1f4d07, 0x5a00501b, 0x20391ba4, 0x4d5130a4,   // aa.cy.pt_432 fj.sm.un_770  tr.br.sq_433 uz.kl.aa_433 
  0x11200c11, 0x344423ee, 0x3c2311af, 0x30004012,   // sv.sq.ro_653 ky.kk.ps_422  ro.ky.ug_655 lb.uz.un_640 
  // [1bf40]
  0x3f001f07, 0x3d3c21ee, 0x42625155, 0x1d041fee,   // cy.af.un_420 fa.ug.ku_422  kl.kha.co_442 cy.fi.la_422 
  0x31002a09, 0x016357a0, 0x5200540c, 0x48041509,   // mt.az.un_440 na.sco.en_322  ik.ha.un_530 un.ru.tt_444 
  0x4200120d, 0x031205a0, 0x48652007, 0x08001208,   // hu.co.un_540 fr.hu.nl_322  sq.gv.tt_432 hu.no.un_430 
  0x07101f08, 0x102d1ea0, 0x396901a4, 0x321637a0,   // cy.lt.it_443 ms.sk.lt_322  en.mfe.br_433 st.hr.bs_322 
  // [1bf50]
  0x3800480d, 0x210501ee, 0x240218ad, 0x265559a4,   // tt.tk.un_540 en.fr.jw_422  ga.da.eo_643 rn.rw.ia_433 
  0x554b590c, 0x55475908, 0x513f1804, 0x133024a9,   // rn.mi.rw_543 rn.sn.rw_443  ga.af.kl_332 eo.uz.et_544 
  0x110501a4, 0x463b020b, 0x12201704, 0x4d0201a4,   // en.fr.ro_433 da.so.qu_542  sr.sq.hu_332 en.da.aa_433 
  0x0c303ba7, 0x796b3b55, 0x0259550d, 0x645a51ec,   // so.uz.sv_532 so.ceb.war_442  rw.rn.da_554 kl.sm.lg_644 
  // [1bf60]
  0x43003b18, 0x071809ee, 0x05000e13, 0x0536500c,   // so.ie.un_740 pl.ga.it_422  is.fr.un_650 fj.gn.fr_543 
  0x1f003b21, 0x21124c05, 0x5955360c, 0x0a043505,   // so.cy.un_860 wo.hu.jw_333  gn.rw.rn_543 tg.ru.mk_333 
  0x47005123, 0x22005105, 0x3b025108, 0x5c0207a7,   // kl.sn.un_880 kl.oc.un_330  kl.da.so_443 it.da.sa_532 
  0xfc00420d, 0x11360808, 0x234838a7, 0x120553ee,   // co.zzp.un_540 uk.ab.ro_443  tk.tt.ky_532 ht.fr.hu_422 
  // [1bf70]
  0x0a4407a4, 0x2f2d12a6, 0x604205ac, 0x1f002502,   // bg.kk.mk_433 hu.sk.su_521  fr.co.vo_632 eu.cy.un_220 
  0x27003913, 0x033f270e, 0x152e13a7, 0x0c181ba0,   // br.gd.un_650 gd.af.nl_555  et.fo.un_532 tr.ga.sv_322 
  0x07302302, 0x180227a0, 0x2e28650c, 0x3058fe09,   // ky.uz.bg_222 gd.da.ga_322  gv.sw.fo_543 tlh.om.uz_444 
  0x16003904, 0x3b136507, 0x392f0404, 0x423905ad,   // br.hr.un_320 gv.et.so_432  fi.su.br_332 fr.br.co_643 
  // [1bf80]
  0x18343c08, 0x0a004012, 0x46004002, 0x203e4204,   // ug.ps.ar_443 lb.pt.un_640  lb.qu.un_220 co.rm.sq_332 
  0x3b002204, 0x13271809, 0x2900390c, 0x2d0d24af,   // oc.so.un_320 ga.gd.et_444  br.sl.un_530 eo.cs.sk_655 
  0x0d093507, 0x064013a4, 0x060e39ee, 0x42054ca0,   // zu.pl.cs_432 et.lb.de_433  br.is.de_422 wo.fr.co_322 
  0x0b2a25a0, 0x173523a7, 0x552511a7, 0x2a002c05,   // eu.mt.es_322 ky.tg.sr_532  ro.eu.rw_532 fy.mt.un_330 
  // [1bf90]
  0x05124a0c, 0x20524da6, 0x353415a9, 0x530536a4,   // yo.hu.fr_543 aa.ha.sq_521  un.xh.zu_544 gn.fr.ht_433 
  0x4568fea4, 0x47584907, 0x1c4d1911, 0x424d0507,   // tlh.ig.ln_433 to.om.sn_432  gl.aa.id_653 fr.aa.co_432 
  0x134d730c, 0x39190a05, 0x3b004c23, 0x34002f08,   // ny.aa.et_543 pt.gl.br_333  wo.so.un_880 su.xh.un_430 
  0x3c443013, 0x49673ba9, 0x244d500c, 0x3b1d4ca0,   // uz.kk.ug_665 so.ak.to_544  fj.aa.eo_543 wo.la.so_322 
  // [1bfa0]
  0x644c3b05, 0x4775510c, 0x564c1904, 0x29353404,   // so.wo.lg_333 kl.nso.sn_543  gl.wo.mg_332 xh.zu.sl_332 
  0x2f005208, 0x37234411, 0x28123d0b, 0x3c443da0,   // ha.su.un_430 kk.ky.ba_653  ku.ur.sd_542 ku.kk.ug_322 
  0x193b58a4, 0x583b4da0, 0x28584d12, 0x05302007,   // om.so.gl_433 aa.so.om_322  aa.om.sw_654 sq.uz.fr_432 
  0x023b30a4, 0x10392404, 0x05212fa4, 0x120a05a0,   // uz.so.da_433 eo.br.lt_332  su.jw.fr_433 fr.pt.hu_322 
  // [1bfb0]
  0x1d1007ee, 0x643435ee, 0x505268a7, 0x0ffc1da0,   // it.lt.la_422 zu.xh.lg_422  ig.ha.fj_532 la.zzp.lv_322 
  0x58132a13, 0x580413ad, 0x1a001005, 0x0a234fa9,   // mt.et.om_665 et.fi.om_643  lt.tl.un_330 bi.ca.pt_544 
  0x0c001314, 0x58675108, 0x58005123, 0x2d2f21ad,   // et.sv.un_660 kl.ak.om_443  kl.om.un_880 jw.su.sk_643 
  0x195a47a0, 0x284d58af, 0x3b00300e, 0x4d005135,   // sn.sm.gl_322 om.aa.sw_655  uz.so.un_550 kl.aa.un_A90 
  // [1bfc0]
  0x3810440c, 0x4d4026ac, 0x321b670b, 0x212f1ca7,   // kk.be.tk_543 ia.lb.aa_632  ak.tr.bs_542 id.su.jw_532 
  0x063e0aa0, 0x301b1855, 0x183d3411, 0x16000702,   // pt.rm.de_322 ga.tr.uz_442  ps.ku.ar_653 it.hr.un_220 
  0x1e272204, 0x065279a4, 0x42005209, 0x322916a0,   // oc.gd.ms_332 war.ha.de_433  ha.co.un_440 hr.sl.bs_322 
  0x374838a6, 0x2b005908, 0x3000520c, 0x47582808,   // tk.tt.ba_521 rn.vi.un_430  ha.uz.un_530 sw.om.sn_443 
  // [1bfd0]
  0x58472108, 0x1d004209, 0x283e1d04, 0x0a000718,   // jw.sn.om_443 co.la.un_440  la.rm.sw_332 bg.mk.un_740 
  0x3f2205a0, 0x5cfe580c, 0x1820300b, 0x023b2155,   // fr.oc.af_322 om.tlh.sa_543  uz.sq.ga_542 jw.so.da_442 
  0x21fe5c0c, 0x2d0d640c, 0x20303105, 0x5c003b02,   // sa.tlh.jw_543 lg.cs.sk_543  az.uz.sq_333 so.sa.un_220 
  0x07000f02, 0x21275cad, 0x3b215cec, 0x103e2704,   // lv.it.un_220 sa.gd.jw_643  sa.jw.so_644 gd.rm.lt_332 
  // [1bfe0]
  0x261f010c, 0x162932a7, 0x1d3e180c, 0x25101fa7,   // en.cy.ia_543 bs.sl.hr_532  ga.rm.la_543 cy.lt.eu_532 
  0x3e002d0d, 0x213b12ee, 0x313020ec, 0x65202113,   // sk.rm.un_540 hu.so.jw_422  sq.uz.az_644 jw.sq.gv_665 
  0x1f1d1d07, 0x5736fc0c, 0x1f106907, 0x07423e14,   // la.la.cy_432 zzp.gn.na_543  mfe.lt.cy_432 rm.co.it_666 
  0x2e464eec, 0x1d002707, 0x650625ec, 0x160d2da4,   // ay.qu.fo_644 gd.la.un_420  eu.de.gv_644 sk.cs.hr_433 
  // [1bff0]
  0x15043711, 0x071d0b05, 0x06480c60, 0x22003907,   // ba.ru.un_653 es.la.it_333  sv.tt.de_664 br.oc.un_420 
  0x63765304, 0xfc4211ad, 0x1f541b07, 0x480c13a9,   // ht.crs.sco_332 ro.co.zzp_643  tr.ik.cy_432 et.sv.tt_544 
  0x1e1f10a7, 0x26510107, 0x070a38ad, 0x6525fc09,   // lt.cy.ms_532 en.kl.ia_432  tk.mk.bg_643 zzp.eu.gv_444 
  0x37253811, 0x150d02a0, 0x19003907, 0x2f002209,   // tk.mn.ba_653 da.cs.un_322  br.gl.un_420 oc.su.un_440 
  
  // [1c000]
  0x07001511, 0x5c130912, 0x79000612, 0x0e004d0b,   // un.bg.un_630 hi.bh.sa_654  de.war.un_640 aa.is.un_520 
  0x10150aa0, 0x534a05ad, 0x05283e0c, 0x31480a12,   // mk.be.un_320 fr.yo.ht_643  rm.sw.fr_543 pt.tt.az_654 
  0x44001505, 0x28123d13, 0x07044808, 0x2e330ea4,   // un.kk.un_330 ku.ur.sd_665  tt.ru.bg_443 is.nn.fo_433 
  0x05243ea4, 0x0c403904, 0x11255e04, 0x495a2507,   // rm.eo.fr_433 br.lb.sv_332  ts.eu.ro_332 eu.sm.to_432 
  // [1c010]
  0x4b6a67a4, 0x0c6333a4, 0x0c00060b, 0x075a25ee,   // ak.haw.mi_433 nn.sco.sv_433  de.sv.un_520 eu.sm.it_422 
  0x053e4c0b, 0x4b002507, 0x4430230e, 0x25655708,   // wo.rm.fr_542 eu.mi.un_420  ky.uz.kk_555 na.gv.eu_443 
  0x30005812, 0x1100250b, 0x53000d07, 0x12590513,   // om.uz.un_640 eu.ro.un_520  cs.ht.un_420 fr.rn.hu_665 
  0x0a1015ad, 0x052d1212, 0x37041005, 0x443c3d08,   // un.be.mk_643 hu.sk.fr_654  be.ru.ba_333 ku.ug.kk_443 
  // [1c020]
  0x0a303512, 0x483530ee, 0x4c5d05a4, 0x180b2202,   // tg.uz.mk_654 uz.tg.tt_422  fr.ss.wo_433 oc.es.ga_222 
  0x212f4507, 0x3428215a, 0x182427ad, 0x1d1f3011,   // ln.su.jw_432 fa.sd.ps_553  gd.eo.ga_643 uz.cy.la_653 
  0x2849240c, 0x2e0e73ec, 0x73304fa0, 0x0b00121a,   // eo.to.sw_543 ny.is.fo_644  bi.uz.ny_322 hu.es.un_760 
  0x40000f09, 0x17006907, 0x2f4950ac, 0x2b30fe07,   // lv.lb.un_440 mfe.sr.un_420  fj.to.su_632 tlh.uz.vi_432 
  // [1c030]
  0x525d35ad, 0x39003504, 0x1900222a, 0x1b4d1fa7,   // zu.ss.ha_643 zu.br.un_320  oc.gl.un_970 cy.aa.tr_532 
  0x39301aad, 0x18002205, 0x20001123, 0x23043ca0,   // tl.uz.br_643 oc.ga.un_330  ro.sq.un_880 ug.ru.ky_322 
  0x44232512, 0x0b55520c, 0x35005611, 0x1e354dee,   // mn.ky.kk_654 ha.rw.es_543  mg.zu.un_630 aa.zu.ms_422 
  0x17000104, 0x39002f07, 0x691a0305, 0x35344702,   // en.sr.un_320 su.br.un_420  nl.tl.mfe_333 sn.xh.zu_222 
  // [1c040]
  0x55285c0c, 0x532e33a0, 0x22236707, 0x06380c5a,   // sa.sw.rw_543 nn.fo.ht_322  ak.ca.oc_432 sv.tk.de_553 
  0x58156708, 0x0f1d38ee, 0x2700fe07, 0x10000834,   // ak.om.un_430 tk.la.lv_422  tlh.gd.un_420 uk.be.un_A80 
  0x3804250e, 0x3f495008, 0x211e4d55, 0x1f3479ee,   // mn.ru.tk_555 fj.to.af_443  aa.ms.jw_442 war.xh.cy_422 
  0x7356780c, 0x27630113, 0x29160d04, 0x353413ee,   // ve.mg.ny_543 en.sco.gd_665  cs.hr.sl_332 et.xh.zu_422 
  // [1c050]
  0x4838110c, 0x0213275a, 0x132701a0, 0x06003605,   // ro.tk.tt_543 gd.et.da_553  en.gd.et_322 gn.de.un_330 
  0x65271fee, 0x5a532707, 0x420b4ea9, 0x46000510,   // cy.gd.gv_422 gd.ht.sm_432  ay.es.co_544 fr.qu.un_620 
  0x6527010b, 0x353015a9, 0x13002708, 0x45001818,   // en.gd.gv_542 un.uz.tg_544  gd.et.un_430 ga.ln.un_740 
  0x0e2e0a07, 0x0e4c4eb3, 0x1d0b180c, 0x20002a09,   // pt.fo.is_432 ay.wo.is_743  ga.es.la_543 mt.sq.un_440 
  // [1c060]
  0x18000a0c, 0x0d4b29a0, 0x46001813, 0x2afe12ec,   // pt.ga.un_530 sl.mi.cs_322  ga.qu.un_650 hu.tlh.mt_644 
  0x24462907, 0x190a18ac, 0x433e0fa7, 0x2d0920ec,   // sl.qu.eo_432 ga.pt.gl_632  lv.rm.ie_532 sq.pl.sk_644 
  0x206efea9, 0x070a44ec, 0x0a002e07, 0x0f1029a0,   // tlh.hmn.sq_544 kk.mk.bg_644  fo.pt.un_420 sl.lt.lv_322 
  0x0e2e18a9, 0x28121808, 0x6e20120c, 0x190a07af,   // ga.fo.is_544 ar.ur.sd_443  hu.sq.hmn_543 it.pt.gl_655 
  // [1c070]
  0x34303d11, 0x0700240c, 0x12002422, 0x20002a0d,   // ku.uz.ps_653 eo.it.un_530  eo.hu.un_870 mt.sq.un_540 
  0x0c12170c, 0x0f120c0c, 0x040b18a7, 0x360415ad,   // sr.hu.sv_543 sv.hu.lv_543  ga.es.fi_532 un.ru.ab_643 
  0x6e1720a4, 0xfe0afc0c, 0x48450507, 0x20006e13,   // sq.sr.hmn_433 zzp.pt.tlh_543  fr.ln.tt_432 hmn.sq.un_650 
  0x5c2956a4, 0x254ffc55, 0x0cfe2aa0, 0x10020fee,   // mg.sl.sa_433 zzp.bi.eu_442  mt.tlh.sv_322 lv.da.lt_422 
  // [1c080]
  0x573f01a0, 0x2400070e, 0x0646fcee, 0x0f381014,   // en.af.na_322 it.eo.un_550  zzp.qu.de_422 lt.tk.lv_666 
  0x19000709, 0x2a513009, 0x3c302807, 0x09fc0d02,   // it.gl.un_440 uz.kl.mt_444  sd.uz.ug_432 cs.zzp.pl_222 
  0x17024712, 0x483544a0, 0x4f00fc05, 0x0413fca7,   // sn.da.sr_654 kk.tg.tt_322  zzp.bi.un_330 zzp.et.fi_532 
  0x1379fc04, 0x3000070e, 0x11002302, 0x0115120b,   // zzp.war.et_332 bg.uz.un_550  ca.ro.un_220 hu.en.un_520 
  // [1c090]
  0x1f122713, 0x20002e04, 0x1f00110c, 0x18306505,   // gd.hu.cy_665 fo.sq.un_320  ro.cy.un_530 gv.uz.ga_333 
  0x6530010c, 0x07231504, 0x121f18a4, 0x206530a6,   // en.uz.gv_543 un.ky.bg_332  ga.cy.hu_433 uz.gv.sq_521 
  0x466530ee, 0x65002209, 0x576502a4, 0x30074807,   // uz.gv.qu_422 oc.gv.un_440  da.gv.na_433 tt.bg.uz_432 
  0x17103807, 0x1f1d09ec, 0x384630ad, 0x57300105,   // tk.be.sr_432 pl.la.cy_644  uz.qu.tk_643 en.uz.na_333 
  // [1c0a0]
  0x1f545108, 0x021e6212, 0x290f1707, 0x30000113,   // kl.ik.cy_443 kha.ms.da_654  sr.lv.sl_432 en.uz.un_650 
  0x20006713, 0x170229a9, 0x101f09a7, 0x100f17ee,   // ak.sq.un_650 sl.da.sr_544  pl.cy.lt_532 sr.lv.lt_422 
  0x65463007, 0x26093e08, 0x67135108, 0x2d096e08,   // uz.qu.gv_432 rm.pl.ia_443  kl.et.ak_443 hmn.pl.sk_443 
  0x09100207, 0x1f1540a0, 0x2d00170d, 0x08fc390d,   // da.lt.pl_432 lb.cy.un_320  sr.sk.un_540 br.zzp.no_554 
  // [1c0b0]
  0x1f620912, 0x395451ec, 0x106029a9, 0x2300112a,   // pl.kha.cy_654 kl.ik.br_644  sl.vo.lt_544 ro.ca.un_970 
  0x1c511e0c, 0x25572aa4, 0x29fc2da7, 0x38114860,   // ms.kl.id_543 mt.na.eu_433  sk.zzp.sl_532 tt.ro.tk_664 
  0xfc005907, 0x79003604, 0x355d5904, 0x1535fc0c,   // rn.zzp.un_420 gn.war.un_320  rn.ss.zu_332 zzp.zu.un_543 
  0x3b13650b, 0x17081014, 0x15043512, 0x4a002f08,   // gv.et.so_542 be.uk.sr_666  tg.ru.un_654 su.yo.un_430 
  // [1c0c0]
  0x56530504, 0x31221ba0, 0x153b1302, 0x3b2a65ee,   // fr.ht.mg_332 tr.oc.az_322  et.so.un_222 gv.mt.so_422 
  0x3b1e2f07, 0x2f1c56a7, 0x382031a4, 0x3216290d,   // su.ms.so_432 mg.id.su_532  az.sq.tk_433 sl.hr.bs_554 
  0x69006505, 0x15381508, 0x42620507, 0x390d2da7,   // gv.mfe.un_330 un.tk.un_443  fr.kha.co_432 sk.cs.br_532 
  0x4804150e, 0x4c002b12, 0x4c002b19, 0x17070809,   // un.ru.tt_555 vi.wo.un_640  vi.wo.un_750 uk.bg.sr_444 
  // [1c0d0]
  0x10004420, 0x0e000608, 0x4a23220c, 0x0e3f03a7,   // kk.be.un_850 de.is.un_430  oc.ca.yo_543 nl.af.is_532 
  0x0c066502, 0x4c002b0d, 0x0d00092c, 0x2b004c14,   // gv.de.sv_222 vi.wo.un_540  hi.ne.un_990 wo.vi.un_660 
  0x37443ca9, 0x4a2723a4, 0x3e002802, 0x4a00230c,   // ug.kk.ba_544 ca.gd.yo_433  sw.rm.un_220 ca.yo.un_530 
  0x35125d07, 0x03345e11, 0x053f23a4, 0x35004705,   // ss.hu.zu_432 ts.xh.nl_653  ca.af.fr_433 sn.zu.un_330 
  // [1c0e0]
  0x53000b05, 0x47000202, 0x38083505, 0x0a2e0e0b,   // es.ht.un_330 da.sn.un_220  tg.uk.tk_333 is.fo.pt_542 
  0x0e000a11, 0x0e190b13, 0x44070a12, 0x5063010c,   // pt.is.un_630 es.gl.is_665  mk.bg.kk_654 en.sco.fj_543 
  0x1510480d, 0x633f15a4, 0x35171007, 0x310a38a7,   // tt.be.un_554 un.af.sco_433  be.sr.tg_432 tk.pt.az_532 
  0x30003407, 0x303534ee, 0x190b3614, 0x0a443808,   // xh.uz.un_420 xh.zu.uz_422  gn.es.gl_666 tk.kk.mk_443 
  // [1c0f0]
  0x31202a0c, 0x15113612, 0x050f0911, 0x48002d0c,   // mt.sq.az_543 ab.ro.un_654  pl.lv.fr_653 sk.tt.un_530 
  0x251504a9, 0x79004f1a, 0x4b00360e, 0x231f3e04,   // ru.mn.un_540 bi.war.un_760  gn.mi.un_550 rm.cy.ca_332 
  0x40174f07, 0x10001108, 0x111d1f02, 0x4500051b,   // bi.sr.lb_432 ro.lt.un_430  cy.la.ro_222 fr.ln.un_770 
  0x2b006223, 0x31655ca4, 0x483637a0, 0x2c002802,   // kha.vi.un_880 sa.gv.az_433  ba.ab.tt_322 sw.fy.un_220 
  // [1c100]
  0x2d483111, 0x2c357355, 0x07003804, 0x290d2d12,   // az.tt.sk_653 ny.zu.fy_442  tk.bg.un_320 sk.cs.sl_654 
  0x064079a0, 0x19180a07, 0x20000f12, 0x0f000907,   // war.lb.de_322 pt.ga.gl_432  lv.sq.un_640 pl.lv.un_420 
  0x733534ac, 0x351730a7, 0x2c00120e, 0x50003412,   // xh.zu.ny_632 uz.sr.tg_532  hu.fy.un_550 xh.fj.un_640 
  0x2c0345a0, 0x4c002b20, 0x0e2e1207, 0x100735a0,   // ln.nl.fy_322 vi.wo.un_850  hu.fo.is_432 tg.bg.be_322 
  // [1c110]
  0x44231504, 0x67471c07, 0x685228ec, 0x65002a05,   // un.ky.kk_332 id.sn.ak_432  sw.ha.ig_644 mt.gv.un_330 
  0x02002104, 0x0c1f2c0c, 0x1e1c5ea9, 0x43fe24ad,   // jw.da.un_320 fy.cy.sv_543  ts.id.ms_544 eo.tlh.ie_643 
  0x05401fa0, 0x24001811, 0x1f1e1c13, 0x060802a7,   // cy.lb.fr_322 ga.eo.un_630  id.ms.cy_665 da.no.de_532 
  0x64051fee, 0x5a5022a4, 0x355952a7, 0x730b0a08,   // cy.fr.lg_422 oc.fj.sm_433  ha.rn.zu_532 pt.es.ny_443 
  // [1c120]
  0x4c4d52a9, 0x69002c19, 0x05004209, 0x24006504,   // ha.aa.wo_544 fy.mfe.un_750  co.fr.un_440 gv.eo.un_320 
  0x1d2452af, 0x0b2804ee, 0x1152580c, 0x5e005212,   // ha.eo.la_655 fi.sw.es_422  om.ha.ro_543 ha.ts.un_640 
  0x0e033f0c, 0x032c3f08, 0x3f652eee, 0x4b2120a4,   // af.nl.is_543 af.fy.nl_443  fo.gv.af_422 sq.jw.mi_433 
  0x23070b02, 0x405706a9, 0x690579a4, 0x5048fead,   // es.it.ca_222 de.na.lb_544  war.fr.mfe_433 tlh.tt.fj_643 
  // [1c130]
  0x1e1c1f0c, 0x35673413, 0x0c2c02a0, 0x01004004,   // cy.id.ms_543 xh.ak.zu_665  da.fy.sv_322 lb.en.un_320 
  0x5c4a73a4, 0x3b1d1fee, 0x3d2130ac, 0x30211ea0,   // ny.yo.sa_433 cy.la.so_422  uz.fa.ku_632 ms.jw.uz_322 
  0x1f006414, 0x0200570d, 0x0c48060d, 0x0a353602,   // lg.cy.un_660 na.da.un_540  de.tt.sv_554 ab.tg.mk_222 
  0x23003e13, 0x371525ec, 0x563e23a7, 0x343b3d05,   // rm.ca.un_650 mn.ba.un_640  ca.rm.mg_532 ku.ks.ps_333 
  // [1c140]
  0x0e004813, 0x3b007307, 0x0e004e10, 0x3e00060e,   // tt.is.un_650 ny.so.un_420  ay.is.un_620 de.rm.un_550 
  0x23483814, 0x4c003e09, 0x3e004c08, 0x48043505,   // tk.tt.ky_666 rm.wo.un_440  wo.rm.un_430 tg.ru.tt_333 
  0x6e00180e, 0x6b0a620c, 0x362f4a0c, 0x47212804,   // ga.hmn.un_550 kha.pt.ceb_543  yo.su.gn_543 sw.jw.sn_332 
  0x3e071104, 0x540b46af, 0x1d7946a9, 0x303546a7,   // ro.it.rm_332 qu.es.ik_655  qu.war.la_544 qu.zu.uz_532 
  // [1c150]
  0x0e00600d, 0x3e1d1f0c, 0x026e6512, 0x65fc1d07,   // vo.is.un_540 cy.la.rm_543  gv.hmn.da_654 la.zzp.gv_432 
  0x5e4201a0, 0x521330a4, 0x06005c19, 0x063f5712,   // en.co.ts_322 uz.et.ha_433  sa.de.un_750 na.af.de_654 
  0x48313009, 0x2c005e04, 0x50004612, 0x10631fee,   // uz.az.tt_444 ts.fy.un_320  qu.fj.un_640 cy.sco.lt_422 
  0x31345714, 0x40524d0c, 0x2a0f52a7, 0x0c130eee,   // na.xh.az_666 aa.ha.lb_543  ha.lv.mt_532 is.et.sv_422 
  // [1c160]
  0x0f005214, 0x13fe1013, 0x20651308, 0x30000f21,   // ha.lv.un_660 lt.tlh.et_665  et.gv.sq_443 lv.uz.un_860 
  0x496b630c, 0x032e0207, 0x48384412, 0x10000a13,   // sco.ceb.to_543 da.fo.nl_432  kk.tk.tt_654 mk.be.un_650 
  0x27632d0c, 0x3e000e07, 0x42070da4, 0x1e501cee,   // sk.sco.gd_543 is.rm.un_420  cs.it.co_433 id.fj.ms_422 
  0x11000518, 0x0a2530a4, 0x040711af, 0x274d1207,   // fr.ro.un_740 uz.mn.mk_433  ro.bg.ru_655 hu.aa.gd_432 
  // [1c170]
  0x0e003e08, 0x044436a7, 0x122b3e04, 0x5440630c,   // rm.is.un_430 ab.kk.ru_532  rm.vi.hu_332 sco.lb.ik_543 
  0x22050207, 0x1f2302a0, 0x042315a4, 0x21281811,   // da.fr.oc_432 da.ca.cy_322  un.ky.ru_433 ar.sd.fa_653 
  0x184d3b55, 0x211c5c0b, 0x233504a4, 0x070a2311,   // so.aa.ga_442 sa.id.jw_542  ru.tg.ky_433 ky.mk.bg_653 
  0x161b4808, 0x3f232205, 0x040825a4, 0x60000e0e,   // tt.tr.hr_443 oc.ca.af_333  mn.uk.ru_433 is.vo.un_550 
  // [1c180]
  0x56251055, 0x1e2510a7, 0x02045111, 0x0b204da7,   // lt.eu.mg_442 lt.eu.ms_532  kl.fi.da_653 aa.sq.es_532 
  0x3b002907, 0x16190a55, 0x04651d09, 0x76106908,   // sl.so.un_420 pt.gl.hr_442  la.gv.fi_444 mfe.lt.crs_443 
  0x355d6bac, 0x355d31a0, 0x13004b0d, 0x2b3047ee,   // ceb.ss.zu_632 az.ss.zu_322  mi.et.un_540 sn.uz.vi_422 
  0x50006308, 0x22180208, 0x2d00790d, 0x5f5a5b04,   // sco.fj.un_430 da.ga.oc_443  war.sk.un_540 sg.sm.tn_332 
  // [1c190]
  0x190a1105, 0x301c1ea0, 0x5e003b09, 0x2e0210a4,   // ro.pt.gl_333 ms.id.uz_322  so.ts.un_440 lt.da.fo_433 
  0x340235ee, 0x063f01a0, 0x1865275a, 0x24002708,   // zu.da.xh_422 en.af.de_322  gd.gv.ga_553 gd.eo.un_430 
  0x106525af, 0x39000907, 0x40390405, 0x342111ee,   // eu.gv.lt_655 pl.br.un_420  fi.br.lb_333 ro.jw.xh_422 
  0x511009a7, 0x4700650d, 0x18001905, 0x032f0ba0,   // pl.lt.kl_532 gv.sn.un_540  gl.ga.un_330 es.su.nl_322 
  // [1c1a0]
  0x5c290708, 0x103604a4, 0x11766507, 0x30183b02,   // it.sl.sa_443 fi.gn.lt_433  gv.crs.ro_432 so.ga.uz_222 
  0x24294a07, 0x1d181108, 0x5c652aa9, 0x470b4908,   // yo.sl.eo_432 ro.ga.la_443  mt.gv.sa_544 to.es.sn_443 
  0xfe026b0c, 0x0102240c, 0x35303813, 0x190b3613,   // ceb.da.tlh_543 eo.da.en_543  tk.uz.tg_665 gn.es.gl_665 
  0x3015040d, 0x011a1da0, 0x0e2e0aad, 0x65093807,   // ru.uz.un_540 la.tl.en_322  pt.fo.is_643 tk.pl.gv_432 
  // [1c1b0]
  0x07234408, 0x24006304, 0x07650207, 0x070830a0,   // kk.ky.bg_443 sco.eo.un_320  da.gv.it_432 uz.uk.bg_322 
  0x65043812, 0x2c1d19a0, 0x2f004d0c, 0x790511ec,   // tk.fi.gv_654 gl.la.fy_322  aa.su.un_530 ro.fr.war_644 
  0x321029ad, 0x3e073307, 0x1c004707, 0x2a000f10,   // sl.lt.bs_643 nn.it.rm_432  sn.id.un_420 lv.mt.un_620 
  0x0f254aec, 0x20000f09, 0x230748a0, 0x174838ac,   // yo.eu.lv_644 lv.sq.un_440  tt.bg.ky_322 tk.tt.sr_632 
  // [1c1c0]
  0x0f1009a7, 0x63183002, 0x160f2904, 0x194005ac,   // pl.lt.lv_532 uz.ga.sco_222  sl.lv.hr_332 fr.lb.gl_632 
  0x4a0f1012, 0x29090fa4, 0x25006707, 0x0a2a1fa0,   // lt.lv.yo_654 lv.pl.sl_433  ak.eu.un_420 cy.mt.pt_322 
  0x153738a0, 0x07104a0c, 0x044368a4, 0x0e2d2e0c,   // tk.ba.un_322 yo.lt.it_543  ig.ie.fi_433 fo.sk.is_543 
  0x244b570c, 0x1f003911, 0x4c190b5a, 0x16266504,   // na.mi.eo_543 br.cy.un_630  es.gl.wo_553 gv.ia.hr_332 
  // [1c1d0]
  0x39000813, 0x5c002502, 0x431f40af, 0x4f7669a9,   // no.br.un_650 eu.sa.un_220  lb.cy.ie_655 mfe.crs.bi_544 
  0x6435340c, 0x383610ec, 0x6a524b0d, 0x28004602,   // xh.zu.lg_543 be.ab.tk_644  mi.ha.haw_554 qu.sw.un_220 
  0x5f375da9, 0x600d26af, 0x45000518, 0x441504a9,   // ss.st.tn_544 ia.cs.vo_655  fr.ln.un_740 ru.kk.un_540 
  0x18001013, 0x524662ec, 0x07353c0b, 0x44371002,   // be.ar.un_650 kha.qu.ha_644  ug.tg.bg_542 be.ba.kk_222 
  // [1c1e0]
  0x0a001d0d, 0x043615a9, 0x40061dec, 0x25483ca9,   // la.pt.un_540 un.ab.ru_544  la.de.lb_644 ug.tt.mn_544 
  0x0a001d13, 0x480804a4, 0x27401813, 0x10483855,   // la.pt.un_650 ru.uk.tt_433  ga.lb.gd_665 tk.tt.be_442 
  0x2d1056a0, 0x295e5008, 0x304829a4, 0x5c3910a4,   // mg.lt.sk_322 fj.ts.sl_443  sl.tt.uz_433 lt.br.sa_433 
  0x5e5c2411, 0x29105008, 0x1a305cee, 0x4202050c,   // eo.sa.ts_653 fj.lt.sl_443  sa.uz.tl_422 fr.da.co_543 
  // [1c1f0]
  0x2d1029ad, 0x5000101a, 0x5c004e05, 0x5c001011,   // sl.lt.sk_643 lt.fj.un_760  ay.sa.un_330 lt.sa.un_630 
  0x4e5c69a4, 0x0e005c07, 0xfe000709, 0x312f69ad,   // mfe.sa.ay_433 sa.is.un_420  it.tlh.un_440 mfe.su.az_643 
  0x561029ec, 0x4600fc02, 0x125c4e12, 0x0f5c1204,   // sl.lt.mg_644 zzp.qu.un_220  ay.sa.hu_654 hu.sa.lv_332 
  0x3f530307, 0x5c254e13, 0x1900361a, 0x1e5c4e05,   // nl.ht.af_432 ay.eu.sa_665  gn.gl.un_760 ay.sa.ms_333 
  // [1c200]
  0x642f0e04, 0x3d1834ec, 0x5f1ffc07, 0x35641f08,   // is.su.lg_332 ps.ar.ku_644  zzp.cy.tn_432 cy.lg.zu_443 
  0x18283004, 0x28341805, 0x1f5f550c, 0x15040a5a,   // uz.sd.ar_332 ar.ps.sd_333  rw.tn.cy_543 mk.ru.un_553 
  0x4400082b, 0x35556407, 0x53001f02, 0x18343d08,   // uk.kk.un_980 lg.rw.zu_432  cy.ht.un_220 ku.ps.ar_443 
  0xfc001204, 0x30234404, 0x04001713, 0x4a001218,   // hu.zzp.un_320 kk.ky.uz_332  sr.ru.un_650 hu.yo.un_740 
  // [1c210]
  0x5e284712, 0x0d321704, 0x1e563907, 0x2f1bfc04,   // sn.sw.ts_654 sr.bs.cs_332  br.mg.ms_432 zzp.tr.su_332 
  0x21123daf, 0x1f3efca4, 0x3f381b07, 0x0b2942a7,   // ku.ur.fa_655 zzp.rm.cy_433  tr.tk.af_432 co.sl.es_532 
  0x1c38485a, 0x38003f0e, 0x076b1dee, 0x29006514,   // tt.tk.id_553 af.tk.un_550  la.ceb.it_422 gv.sl.un_660 
  0x125d4707, 0x12fe63a7, 0xfc004509, 0x63654d12,   // sn.ss.hu_432 sco.tlh.hu_532  ln.zzp.un_440 aa.gv.sco_654 
  // [1c220]
  0x2622070d, 0x213c4407, 0x37235da0, 0x214005af,   // it.oc.ia_554 kk.ug.fa_432  ss.ca.st_322 fr.lb.jw_655 
  0x53034fa0, 0x39001f1a, 0x242d0d13, 0x480711ee,   // bi.nl.ht_322 cy.br.un_760  cs.sk.eo_665 ro.bg.tt_422 
  0x4c005304, 0x2d0d03a7, 0x2d0115ee, 0x1dfc0107,   // ht.wo.un_320 nl.cs.sk_532  un.en.sk_422 en.zzp.la_432 
  0x020c2e0c, 0x072302a4, 0x0a374804, 0x021047a4,   // fo.sv.da_543 da.ca.it_433  tt.ba.mk_332 sn.lt.da_433 
  // [1c230]
  0x0f212f0c, 0x17592a07, 0x2f1c3907, 0x473b1ca0,   // su.jw.lv_543 mt.rn.sr_432  br.id.su_432 id.so.sn_322 
  0x07150809, 0x132f65af, 0x11430907, 0x0a00670e,   // uk.bg.un_440 gv.su.et_655  pl.ie.ro_432 ak.pt.un_550 
  0x1c2113ad, 0x5dfe4711, 0x28105dee, 0x47630107,   // et.jw.id_643 sn.tlh.ss_653  ss.lt.sw_422 en.sco.sn_432 
  0x4c392fa0, 0x39005408, 0x3f090f08, 0x11093fa0,   // su.br.wo_322 ik.br.un_430  lv.pl.af_443 af.pl.ro_322 
  // [1c240]
  0x24006e0c, 0x3f000912, 0x1940210d, 0x3b2f65a7,   // hmn.eo.un_530 pl.af.un_640  jw.lb.gl_554 gv.su.so_532 
  0x070905a4, 0x052f12a4, 0x7900151a, 0x4d5a25ad,   // fr.pl.it_433 hu.su.fr_433  un.war.un_760 eu.sm.aa_643 
  0x68006734, 0x34285ea6, 0x30381b04, 0x44153604,   // ak.ig.un_A80 ts.sw.xh_521  tr.tk.uz_332 ab.kk.un_320 
  0x5a472b04, 0x340b50a9, 0x471669ad, 0x63096908,   // vi.sn.sm_332 fj.es.xh_544  mfe.hr.sn_643 mfe.pl.sco_443 
  // [1c250]
  0x63000908, 0x48004512, 0x094947ee, 0x081123a4,   // pl.sco.un_430 ln.tt.un_640  sn.to.pl_422 ky.ro.uk_433 
  0x30381705, 0x5a000d07, 0x386825a9, 0x08004429,   // sr.tk.uz_333 cs.sm.un_420  eu.ig.tk_544 kk.uk.un_960 
  0x090d2404, 0x281a73ee, 0x2900fe05, 0x0d00fe0e,   // eo.cs.pl_332 ny.tl.sw_422  tlh.sl.un_330 tlh.cs.un_550 
  0x35386411, 0x5e643707, 0x2a20fe0c, 0x3564730c,   // lg.tk.zu_653 st.lg.ts_432  tlh.sq.mt_543 ny.lg.zu_543 
  // [1c260]
  0x0a003907, 0x320d2aa4, 0x42232707, 0x17002a08,   // br.pt.un_420 mt.cs.bs_433  gd.ca.co_432 mt.sr.un_430 
  0x130d5c07, 0x17202a04, 0x4c68340c, 0xfe58020c,   // sa.ne.bh_432 mt.sq.sr_332  xh.ig.wo_543 da.om.tlh_543 
  0x28004809, 0x171008ee, 0x25fe570c, 0x28484508,   // tt.sw.un_440 uk.be.sr_422  na.tlh.eu_543 ln.tt.sw_443 
  0x530c1208, 0x32001212, 0x1729460c, 0xfc2705a4,   // hu.sv.ht_443 hu.bs.un_640  qu.sl.sr_543 fr.gd.zzp_433 
  // [1c270]
  0xfe595508, 0x183606a0, 0x3e5653ee, 0x230f5eee,   // rw.rn.tlh_443 de.gn.ga_322  ht.mg.rm_422 ts.lv.ca_422 
  0x30000805, 0x2800732a, 0xfe005e22, 0x56220507,   // uk.uz.un_330 ny.sw.un_970  ts.tlh.un_870 fr.oc.mg_432 
  0x0c13060d, 0x2800fe1a, 0xfc4207ec, 0x631d2605,   // de.et.sv_554 tlh.sw.un_760  it.co.zzp_644 ia.la.sco_333 
  0x443530a6, 0x115e02a7, 0x041530a6, 0x072515ee,   // uz.tg.kk_521 da.ts.ro_532  uz.ru.un_510 un.mn.bg_422 
  // [1c280]
  0x0415080c, 0x276531ee, 0x2018390c, 0x37006402,   // uk.ru.un_530 az.gv.gd_422  br.ga.sq_543 lg.st.un_220 
  0x4a004012, 0x274018a0, 0x052311a4, 0x183927a0,   // lb.yo.un_640 ga.lb.gd_322  ro.ca.fr_433 gd.br.ga_322 
  0x525f37a7, 0x430c6905, 0x2a1169ee, 0x18002b2b,   // st.tn.ha_532 mfe.sv.ie_333  mfe.ro.mt_422 vi.ga.un_980 
  0x5d5f3460, 0x2d3839ac, 0x31001d04, 0x0b002c04,   // xh.tn.ss_664 br.tk.sk_632  la.az.un_320 fy.es.un_320 
  // [1c290]
  0x591262a0, 0x2f001d05, 0x59552fa4, 0x19021da0,   // kha.hu.rn_322 la.su.un_330  su.rw.rn_433 la.da.gl_322 
  0x25375f0d, 0x35642804, 0x0a110f11, 0x551d4211,   // tn.st.eu_554 sw.lg.zu_332  lv.ro.pt_653 co.la.rw_653 
  0x79002d09, 0x271d42a4, 0x0c000309, 0x64282a02,   // sk.war.un_440 co.la.gd_433  nl.sv.un_440 mt.sw.lg_222 
  0x3300790b, 0x011528a0, 0x23005713, 0x36284a0c,   // war.nn.un_520 sw.en.un_320  na.ca.un_650 yo.sw.gn_543 
  // [1c2a0]
  0x47005d02, 0x2f1e21af, 0x5b006814, 0x55353413,   // ss.sn.un_220 jw.ms.su_655  ig.sg.un_660 xh.zu.rw_665 
  0x233836ad, 0x67004534, 0x42501b07, 0x282312a7,   // ab.tk.ky_643 ln.ak.un_A80  tr.fj.co_432 ur.ky.sd_532 
  0x555f3704, 0x49214a13, 0x0b0a46a9, 0x5521fea6,   // st.tn.rw_332 yo.jw.to_665  qu.pt.es_544 tlh.jw.rw_521 
  0x5d006e08, 0x342b2804, 0x4736200e, 0x420d0e07,   // hmn.ss.un_430 sw.vi.xh_332  sq.gn.sn_555 is.cs.co_432 
  // [1c2b0]
  0x1c026907, 0x2a084aa0, 0x57004a1b, 0x15001904,   // mfe.da.id_432 yo.no.mt_322  yo.na.un_770 gl.un.un_320 
  0x3055280c, 0x5c001504, 0x0d004a0b, 0x06093f02,   // sw.rw.uz_543 un.sa.un_320  yo.cs.un_520 af.pl.de_222 
  0x20007908, 0x07274204, 0x25100407, 0x1a6328af,   // war.sq.un_430 co.gd.it_332  ru.be.mn_432 sw.sco.tl_655 
  0x5a1e5504, 0x48002105, 0x2c426302, 0x40396304,   // rw.ms.sm_332 jw.tt.un_330  sco.co.fy_222 sco.br.lb_332 
  // [1c2c0]
  0x422305ec, 0x07006304, 0x395319ad, 0x48424cee,   // fr.ca.co_644 sco.it.un_320  gl.ht.br_643 wo.co.tt_422 
  0x0d4005a7, 0x65394004, 0x425305ad, 0x4c003011,   // fr.lb.cs_532 lb.br.gv_332  fr.ht.co_643 uz.wo.un_630 
  0x080a3007, 0x30001804, 0x37070a07, 0x354415ee,   // uz.mk.uk_432 ga.uz.un_320  mk.bg.ba_432 un.kk.tg_422 
  0x183d44a6, 0x3d21120e, 0x48041505, 0x5d354712,   // kk.ku.ar_521 ur.fa.ku_555  un.ru.tt_333 sn.zu.ss_654 
  // [1c2d0]
  0x1e4d2f12, 0x55681f60, 0x55007814, 0x1f375fa0,   // su.aa.ms_654 cy.ig.rw_664  ve.rw.un_660 tn.st.cy_322 
  0x28182111, 0x2a645509, 0x316b1dad, 0x30341255,   // fa.ar.sd_653 rw.lg.mt_444  la.ceb.az_643 ur.ps.uz_442 
  0x68357307, 0x0802fe55, 0x16003008, 0x555364a0,   // ny.zu.ig_432 tlh.da.no_442  uz.hr.un_430 lg.ht.rw_322 
  0x1600090c, 0x5c00390d, 0x284a4c5a, 0x1038040e,   // pl.hr.un_530 br.sa.un_540  wo.yo.sw_553 ru.tk.be_555 
  // [1c2e0]
  0x793963a0, 0x122979a4, 0x1d1307a0, 0x1e1d1ca0,   // sco.br.war_322 war.sl.hu_433  it.et.la_322 id.la.ms_322 
  0x34001b04, 0x2f221904, 0x212f1207, 0x47554ca9,   // tr.xh.un_320 gl.oc.su_332  hu.su.jw_432 wo.rw.sn_544 
  0x0d004a16, 0x22521d08, 0x63002013, 0x33002004,   // yo.cs.un_720 la.ha.oc_443  sq.sco.un_650 sq.nn.un_320 
  0x7900600d, 0x4713780c, 0x5e00200c, 0x0311580c,   // vo.war.un_540 ve.et.sn_543  sq.ts.un_530 om.ro.nl_543 
  // [1c2f0]
  0x5862200d, 0x2a2f2508, 0x47355907, 0x3b022512,   // sq.kha.om_554 eu.su.mt_443  rn.zu.sn_432 eu.da.so_654 
  0x2c0120a7, 0x47100fa4, 0x017962a7, 0x4a100f11,   // sq.en.fy_532 lv.lt.sn_433  kha.war.en_532 lv.lt.yo_653 
  0x133550a4, 0x1a1b38ac, 0x4c3b5807, 0x215a4907,   // fj.zu.et_433 tk.tr.tl_632  om.so.wo_432 to.sm.jw_432 
  0x3500210c, 0x02554713, 0x321720a0, 0x394250a0,   // jw.zu.un_530 sn.rw.da_665  sq.sr.bs_322 fj.co.br_322 
  // [1c300]
  0x2e332a0d, 0x482065a7, 0x3b405804, 0x35305d02,   // mt.nn.fo_554 gv.sq.tt_532  om.lb.so_332 ss.uz.zu_222 
  0x645e68ee, 0x115a135a, 0x69206208, 0x28001c02,   // ig.ts.lg_422 et.sm.ro_553  kha.sq.mfe_443 id.sw.un_220 
  0x67281e0b, 0x6b00310d, 0x630768a4, 0x4700360e,   // ms.sw.ak_542 az.ceb.un_540  ig.it.sco_433 gn.sn.un_550 
  0x6340680c, 0x110a0705, 0x30083c5a, 0x055a4907,   // ig.lb.sco_543 bg.mk.ro_333  ug.uk.uz_553 to.sm.fr_432 
  // [1c310]
  0x033928a0, 0x634c65a4, 0x780263a4, 0x6005430c,   // sw.br.nl_322 gv.wo.sco_433  sco.da.ve_433 ie.fr.vo_543 
  0x0500451a, 0x48001b11, 0x0a002b19, 0x391f2b0c,   // ln.fr.un_760 tr.tt.un_630  vi.pt.un_750 vi.cy.br_543 
  0x03390604, 0x4f000512, 0x3d211209, 0x2344380d,   // de.br.nl_332 fr.bi.un_640  ur.fa.ku_444 tk.kk.ky_554 
  0x213d300d, 0x071d51a4, 0x51075807, 0x3000490d,   // uz.ku.fa_554 kl.la.it_433  om.it.kl_432 to.uz.un_540 
  // [1c320]
  0x1000390c, 0x2f002807, 0x67284b08, 0x53420507,   // br.lt.un_530 sw.su.un_420  mi.sw.ak_443 fr.co.ht_432 
  0x5d3067a6, 0x30476aee, 0x1f0c0202, 0x40001c08,   // ak.uz.ss_521 haw.sn.uz_422  da.sv.cy_222 id.lb.un_430 
  0x47005d04, 0x19002a05, 0x76001d0e, 0x23483713,   // ss.sn.un_320 mt.gl.un_330  la.crs.un_550 ba.tt.ky_665 
  0xfe085907, 0x28604507, 0x0e001f09, 0x081511a9,   // rn.no.tlh_432 ln.vo.sw_432  cy.is.un_440 ro.uk.un_540 
  // [1c330]
  0x32080c04, 0x1d2811ee, 0x496a33a7, 0x6300090c,   // sv.no.bs_332 ro.sw.la_422  nn.haw.to_532 pl.sco.un_530 
  0x63001512, 0x251f6aa0, 0x3f00270c, 0x3e250aee,   // un.sco.un_640 haw.cy.eu_322  gd.af.un_530 pt.eu.rm_422 
  0x4a000c11, 0x03453f0b, 0x043008a4, 0x040823a6,   // sv.yo.un_630 af.ln.nl_542  uk.uz.ru_433 ky.uk.ru_521 
  0x370a07ad, 0x2063090c, 0x492506a0, 0x790f0912,   // bg.mk.ba_643 pl.sco.sq_543  de.eu.to_322 pl.lv.war_654 
  // [1c340]
  0x3444230b, 0x35734504, 0x1b007305, 0x327847af,   // ky.kk.ps_542 ln.ny.zu_332  ny.tr.un_330 sn.ve.bs_655 
  0x25233613, 0xfc001c02, 0x0e2e2a13, 0x4d0f1060,   // ab.ky.mn_665 id.zzp.un_220  mt.fo.is_665 lt.lv.aa_664 
  0x52006213, 0x735228a0, 0x24381bec, 0x0810070c,   // kha.ha.un_650 sw.ha.ny_322  tr.tk.eo_644 bg.be.uk_543 
  0x4b506a55, 0x2f3630a4, 0x20112407, 0x1e1b3002,   // haw.fj.mi_442 uz.gn.su_433  eo.ro.sq_432 uz.tr.ms_222 
  // [1c350]
  0x2800620d, 0x651f1208, 0x375d5ea0, 0x1f231207,   // kha.sw.un_540 hu.cy.gv_443  ts.ss.st_322 hu.ca.cy_432 
  0x55286b04, 0x282a180c, 0x2d122004, 0x120a1fee,   // ceb.sw.rw_332 ga.mt.sw_543  sq.hu.sk_332 cy.pt.hu_422 
  0x1f520ba0, 0x15040a09, 0x39115e02, 0x38483108,   // es.ha.cy_322 mk.ru.un_444  ts.ro.br_222 az.tt.tk_443 
  0x070a4805, 0x38150460, 0x600e2305, 0x2118230b,   // tt.mk.bg_333 ru.tk.un_640  ca.is.vo_333 ky.ar.fa_542 
  // [1c360]
  0x0f1040a0, 0x110410a4, 0x15183ba0, 0x24651209,   // lb.lt.lv_322 be.ru.ro_433  so.ga.un_322 hu.gv.eo_444 
  0x23001019, 0x650956ec, 0x37455007, 0x186301ad,   // be.ky.un_750 mg.pl.gv_644  fj.ln.st_432 en.sco.ga_643 
  0x18275655, 0x64027312, 0x5a136a0c, 0x556461af,   // mg.gd.ga_442 ny.da.lg_654  haw.et.sm_543 za.lg.rw_655 
  0x69455ea4, 0x2d0d56a4, 0x45fa64a4, 0x42076508,   // ts.ln.mfe_433 mg.cs.sk_433  lg.nr.ln_433 gv.it.co_443 
  // [1c370]
  0x4f616405, 0x21005b08, 0x23104804, 0x653f1f07,   // lg.za.bi_333 sg.jw.un_430  tt.be.ky_332 cy.af.gv_432 
  0x65420705, 0x7359285a, 0x071f510b, 0x5a005e04,   // it.co.gv_333 sw.rn.ny_553  kl.cy.it_542 ts.sm.un_320 
  0x34123dad, 0x24371204, 0x084410ec, 0x066e4f0d,   // ku.ur.ps_643 hu.st.eo_332  be.kk.uk_644 bi.hmn.de_554 
  0x1c0e6ead, 0x40574fa4, 0x3d123b12, 0x22236eec,   // hmn.is.id_643 bi.na.lb_433  ks.ur.ku_654 hmn.ca.oc_644 
  // [1c380]
  0x1f125112, 0x1b2b250c, 0x1d0a120b, 0x1bfc5213,   // kl.hu.cy_654 eu.vi.tr_543  hu.pt.la_542 ha.zzp.tr_665 
  0x43006e0e, 0x3e6e220c, 0x39262507, 0x221801a0,   // hmn.ie.un_550 oc.hmn.rm_543  eu.ia.br_432 en.ga.oc_322 
  0x22006e11, 0x30fe180c, 0x400e10a7, 0x24004204,   // hmn.oc.un_630 ga.tlh.uz_543  lt.is.lb_532 co.eo.un_320 
  0x48401ba0, 0x45601308, 0x071209a7, 0x01fc1f07,   // tr.lb.tt_322 et.vo.ln_443  pl.hu.it_532 cy.zzp.en_432 
  // [1c390]
  0x30fe19ee, 0x1e1b3111, 0x6e400660, 0x4200110c,   // gl.tlh.uz_422 az.tr.ms_653  de.lb.hmn_664 ro.co.un_530 
  0x21406e0c, 0x3e006e08, 0x22006e1a, 0x29005205,   // hmn.lb.jw_543 hmn.rm.un_430  hmn.oc.un_760 ha.sl.un_330 
  0x5c005213, 0x235c0704, 0x52000913, 0x121c0909,   // ha.sa.un_650 it.sa.ca_332  pl.ha.un_650 pl.id.hu_444 
  0x03071105, 0x0b420907, 0x020c08a7, 0x4c00fe0e,   // ro.it.nl_333 pl.co.es_432  no.sv.da_532 tlh.wo.un_550 
  // [1c3a0]
  0x3f005205, 0x1630fea4, 0x1e001c13, 0x10003719,   // ha.af.un_330 tlh.uz.hr_433  id.ms.un_650 ba.be.un_750 
  0x735a4707, 0x083336a0, 0x58004604, 0x483b3107,   // sn.sm.ny_432 gn.nn.no_322  qu.om.un_320 az.so.tt_432 
  0x331c0ca0, 0x46204ead, 0x5a1e490d, 0x0c1c31a0,   // sv.id.nn_322 ay.sq.qu_643  to.ms.sm_554 az.id.sv_322 
  0x50004b02, 0x55285912, 0x5d375e02, 0x123d2804,   // mi.fj.un_220 rn.sw.rw_654  ts.st.ss_222 sd.ku.ur_332 
  // [1c3b0]
  0x11073eaf, 0x1600470d, 0x33321609, 0x234844ad,   // rm.it.ro_655 sn.hr.un_540  hr.bs.nn_444 kk.tt.ky_643 
  0x4600580c, 0x563647af, 0x5e30520c, 0x23283b0c,   // om.qu.un_530 sn.gn.mg_655  ha.uz.ts_543 ks.sd.ky_543 
  0x030121a0, 0x25153c5a, 0x0d2e2d07, 0x190b0e02,   // jw.en.nl_322 ug.mn.un_530  sk.fo.cs_432 is.es.gl_222 
  0x64007813, 0x21342307, 0x362d0e0c, 0x3f032a0c,   // ve.lg.un_650 ky.ps.fa_432  is.sk.gn_543 mt.nl.af_543 
  // [1c3c0]
  0x0f321702, 0x33580ead, 0x363517a0, 0x39001909,   // sr.bs.lv_222 is.om.nn_643  sr.zu.gn_322 gl.br.un_440 
  0x10112308, 0x643f0302, 0x1a6b3955, 0x1c001329,   // ky.ro.be_443 nl.af.lg_222  br.ceb.tl_442 bh.mr.un_960 
  0x3418440b, 0x28003704, 0x13042e05, 0x2f2442a7,   // kk.ar.ps_542 st.sw.un_320  fo.fi.et_333 co.eo.su_532 
  0x17150a05, 0x5c2224a0, 0x2f240ea7, 0x2e5c0e07,   // mk.sr.un_330 eo.oc.sa_322  is.eo.su_532 is.sa.fo_432 
  // [1c3d0]
  0x0e00380e, 0x2324fead, 0x24007904, 0x215c2f02,   // tk.is.un_550 tlh.eo.ca_643  war.eo.un_320 su.sa.jw_222 
  0x00003337, 0x15443614, 0x44001809, 0x3c18230c,   // as.un.un_B00 ab.kk.un_666  ar.kk.un_440 ky.ar.ug_543 
  0x2b003e09, 0x393e1055, 0x10006212, 0x13001211,   // rm.vi.un_440 lt.rm.br_442  kha.lt.un_640 hu.et.un_630 
  0x3e101f0d, 0x2b001e07, 0x23304807, 0x23444855,   // cy.lt.rm_554 ms.vi.un_420  tt.uz.ky_432 tt.kk.ky_442 
  // [1c3e0]
  0x10251f05, 0xfc001205, 0x023607a7, 0x395d670c,   // cy.eu.lt_333 hu.zzp.un_330  it.gn.da_532 ak.ss.br_543 
  0x44003621, 0x784728ad, 0x02510fad, 0x5e0264a4,   // ab.kk.un_860 sw.sn.ve_643  lv.kl.da_643 lg.da.ts_433 
  0x38001109, 0x04571355, 0x222b3e08, 0x2b1d1004,   // ro.tk.un_440 et.na.fi_442  rm.vi.oc_443 lt.la.vi_332 
  0x3e1f4211, 0x32160909, 0x58006411, 0x47fe0209,   // co.cy.rm_653 pl.hr.bs_444  lg.om.un_630 da.tlh.sn_444 
  // [1c3f0]
  0x053919ee, 0x5d006708, 0x735128a9, 0x38004702,   // gl.br.fr_422 ak.ss.un_430  sw.kl.ny_544 sn.tk.un_220 
  0x73000408, 0x4a001b07, 0x5e5c1ea4, 0x5c002a04,   // fi.ny.un_430 tr.yo.un_420  ms.sa.ts_433 mt.sa.un_320 
  0x4a2a1f08, 0x4d73250c, 0x47355d0d, 0x353423a9,   // cy.mt.yo_443 eu.ny.aa_543  ss.zu.sn_554 ca.xh.zu_544 
  0x212f36a0, 0x3549fc07, 0x6b003812, 0x78002719,   // gn.su.jw_322 zzp.to.zu_432  tk.ceb.un_640 gd.ve.un_750 
  
  // [1c400]
  0xfe272a0c, 0x25353402, 0x12353408, 0x44081108,   // mt.gd.tlh_543 xh.zu.eu_222  xh.zu.hu_443 ro.uk.kk_443 
  0x35150412, 0x475d34a9, 0x2c002321, 0x2f4d58ad,   // ru.tg.un_640 xh.ss.sn_544  ca.fy.un_860 om.aa.su_643 
  0x5d643413, 0x35341905, 0x78355da4, 0x62735c0c,   // xh.lg.ss_665 gl.xh.zu_333  ss.zu.ve_433 sa.ny.kha_543 
  0x1e1c5d05, 0x22005e08, 0x4600370e, 0x21000c0c,   // ss.id.ms_333 ts.oc.un_430  st.qu.un_550 sv.jw.un_530 
  // [1c410]
  0x1c002002, 0x32172aa9, 0x22020c0c, 0x494b6aad,   // sq.id.un_220 mt.sr.bs_544  sv.da.oc_543 haw.mi.to_643 
  0x2c650302, 0x1e1c4608, 0x4b6a1daf, 0x3b4d6aaf,   // nl.gv.fy_222 qu.id.ms_443  la.haw.mi_655 haw.aa.so_655 
  0x462f21a4, 0x33006512, 0x6523260c, 0x083f33a4,   // jw.su.qu_433 gv.nn.un_640  ia.ca.gv_543 nn.af.no_433 
  0x07264212, 0x2d2448a4, 0x3c003d20, 0x21002a04,   // co.ia.it_654 tt.eo.sk_433  ku.ug.un_850 mt.jw.un_320 
  // [1c420]
  0x2f00610c, 0x15042560, 0x5a001e0c, 0x4b005e19,   // za.su.un_530 mn.ru.un_664  ms.sm.un_530 ts.mi.un_750 
  0x474a7311, 0x597864a4, 0x276318ad, 0x103736a4,   // ny.yo.sn_653 lg.ve.rn_433  ga.sco.gd_643 ab.ba.be_433 
  0x64007819, 0x0e000b04, 0x21004a04, 0x73644a0e,   // ve.lg.un_750 es.is.un_320  yo.jw.un_320 yo.lg.ny_555 
  0x2c545111, 0x6400532a, 0x12001012, 0x3c12440c,   // kl.ik.fy_653 ht.lg.un_970  lt.hu.un_640 kk.ur.ug_543 
  // [1c430]
  0x1000020b, 0x034006a4, 0x301e52a0, 0x4c002109,   // da.lt.un_520 de.lb.nl_433  ha.ms.uz_322 jw.wo.un_440 
  0x4f00051b, 0x5a00150c, 0x1c00760b, 0x0e1260a0,   // fr.bi.un_770 un.sm.un_530  crs.id.un_520 vo.hu.is_322 
  0x08103504, 0x30573b12, 0x3f032cee, 0x3f2c03ad,   // tg.be.uk_332 so.na.uz_654  fy.nl.af_422 nl.fy.af_643 
  0x370a17ee, 0x27001105, 0x3b1712ec, 0x13330ca0,   // sr.mk.ba_422 ro.gd.un_330  hu.sr.so_644 sv.nn.et_322 
  // [1c440]
  0x364657a4, 0x276976a9, 0x33000829, 0x2c00fc20,   // na.qu.gn_433 crs.mfe.gd_544  no.nn.un_960 zzp.fy.un_850 
  0x2c390307, 0x0c2e36a0, 0x19422da0, 0x53004b09,   // nl.br.fy_432 gn.fo.sv_322  sk.co.gl_322 mi.ht.un_440 
  0x631201a4, 0x64004023, 0x431d01a0, 0x09240312,   // en.hu.sco_433 lb.lg.un_880  en.la.ie_322 nl.eo.pl_654 
  0x38131b07, 0x3b233d0c, 0x3308480c, 0x5c0d1c0e,   // tr.et.tk_432 ku.ky.ks_543  tt.no.nn_543 mr.ne.sa_555 
  // [1c450]
  0x1f003402, 0x283b5304, 0x35170805, 0x0a052ba0,   // xh.cy.un_220 ht.so.sw_332  uk.sr.tg_333 vi.fr.pt_322 
  0x3058200d, 0x203046a9, 0x383020a0, 0x4800170c,   // sq.om.uz_554 qu.uz.sq_544  sq.uz.tk_322 sr.tt.un_530 
  0x20302204, 0x480a1704, 0x12232809, 0x08151009,   // oc.uz.sq_332 sr.mk.tt_332  sd.ky.ur_444 be.uk.un_440 
  0x05693609, 0x28006308, 0x3020460b, 0x0200631b,   // gn.mfe.fr_444 sco.sw.un_430  qu.sq.uz_542 sco.da.un_770 
  // [1c460]
  0x632030a4, 0x27003702, 0x10007307, 0x110f7307,   // uz.sq.sco_433 st.gd.un_220  ny.lt.un_420 ny.lv.ro_432 
  0x27656307, 0x73002807, 0x63003f2a, 0x252873a6,   // sco.gv.gd_432 sw.ny.un_420  af.sco.un_970 ny.sw.eu_521 
  0x0708110d, 0x00001a2d, 0x20092d11, 0x49561a08,   // ro.uk.bg_554 tl.un.un_A00  sk.pl.sq_653 tl.mg.to_443 
  0x450a2860, 0x2a4d6412, 0x5a001c04, 0x676e34a9,   // sw.pt.ln_664 lg.aa.mt_654  id.sm.un_320 xh.hmn.ak_544 
  // [1c470]
  0x280635ee, 0x736a380c, 0x13000f07, 0x5e643407,   // zu.de.sw_422 tk.haw.ny_543  lv.et.un_420 xh.lg.ts_432 
  0x0f4725ad, 0x4a00560e, 0x6a005a22, 0x041518b3,   // eu.sn.lv_643 mg.yo.un_550  sm.haw.un_870 ar.ru.un_730 
  0x303804a0, 0x0a004d0d, 0x0f04100c, 0x3b442308,   // fi.tk.uz_322 aa.pt.un_540  lt.fi.lv_543 ky.kk.ks_443 
  0x7609690c, 0x44382309, 0x0b2b4da7, 0x2a001702,   // mfe.pl.crs_543 ky.tk.kk_444  aa.vi.es_532 sr.mt.un_220 
  // [1c480]
  0x286a7355, 0x2f253902, 0x1e0c1ca0, 0x1a2f3904,   // ny.haw.sw_442 br.eu.su_222  id.sv.ms_322 br.su.tl_332 
  0x04231505, 0x1c000c04, 0x52001d02, 0x1c00100d,   // un.ky.ru_333 sv.id.un_320  la.ha.un_220 lt.id.un_540 
  0x2130280c, 0x283d12a0, 0x35171505, 0x0b4a1908,   // sd.uz.fa_543 ur.ku.sd_322  un.sr.tg_333 gl.yo.es_443 
  0x02060ca0, 0x04251008, 0x15000605, 0x6a1e1c08,   // sv.de.da_322 be.mn.ru_443  de.un.un_330 id.ms.haw_443 
  // [1c490]
  0x0410070c, 0x5a6a2505, 0x1d362555, 0x621e1c13,   // bg.be.ru_543 eu.haw.sm_333  eu.gn.la_442 id.ms.kha_665 
  0x42252f02, 0x1e62250c, 0x0a5a490c, 0x1c1e25a7,   // su.eu.co_222 eu.kha.ms_543  to.sm.pt_543 eu.ms.id_532 
  0x112f4204, 0x37384805, 0x2f2105ee, 0x025a03a4,   // co.su.ro_332 tt.tk.ba_333  fr.jw.su_422 nl.sm.da_433 
  0x052d0d14, 0x255a4ba7, 0x501e2508, 0x36194e04,   // cs.sk.fr_666 mi.sm.eu_532  eu.ms.fj_443 ay.gl.gn_332 
  // [1c4a0]
  0x5a6a1e07, 0x2144230b, 0x35004a07, 0x2a00040c,   // ms.haw.sm_432 ky.kk.fa_542  yo.zu.un_420 fi.mt.un_530 
  0x311b185a, 0x1017080e, 0x5242fea4, 0x0700480e,   // ga.tr.az_553 uk.sr.be_555  tlh.co.ha_433 tt.bg.un_550 
  0x251d4604, 0x65330807, 0x231510a4, 0x32005207,   // qu.la.eu_332 no.nn.gv_432  be.ky.un_430 ha.bs.un_420 
  0x07252304, 0x30281212, 0x34000a04, 0x36193902,   // ky.mn.bg_332 ur.sd.uz_654  pt.xh.un_320 br.gl.gn_222 
  // [1c4b0]
  0x650633ec, 0x35001b04, 0x046810af, 0x0f491002,   // nn.de.gv_644 tr.zu.un_320  lt.ig.fi_655 lt.to.lv_222 
  0x21490455, 0x3c183408, 0x102344ad, 0x49004509,   // fi.to.jw_442 ps.ar.ug_443  kk.ky.be_643 ln.to.un_440 
  0x30383c08, 0x170f10ee, 0x1d5a6a0b, 0x681a6712,   // ug.tk.uz_443 lt.lv.sr_422  haw.sm.la_542 ak.tl.ig_654 
  0x283b120e, 0x39000422, 0xfc000314, 0x4a000f02,   // ur.ks.sd_555 fi.br.un_870  nl.zzp.un_660 lv.yo.un_220 
  // [1c4c0]
  0x68006014, 0x4436355a, 0x44373c07, 0x213b120c,   // vo.ig.un_660 tg.ab.kk_553  ug.ba.kk_432 ur.ks.fa_543 
  0x1d00432c, 0x4a003607, 0x25004e14, 0x30040802,   // ie.la.un_990 gn.yo.un_420  ay.eu.un_660 uk.ru.uz_222 
  0x233c280e, 0x343021a7, 0x35004a0c, 0x060c12a0,   // sd.ug.ky_555 fa.uz.ps_532  yo.zu.un_530 hu.sv.de_322 
  0x020e2e05, 0x3f066304, 0x0e002012, 0x04000b07,   // fo.is.da_333 sco.de.af_332  sq.is.un_640 es.fi.un_420 
  // [1c4d0]
  0x0428130c, 0x602e0e13, 0x212a20ad, 0x330e200c,   // et.sw.fi_543 is.fo.vo_665  sq.mt.jw_643 sq.is.nn_543 
  0x020e0c05, 0x23214404, 0x0a150402, 0xfe001d07,   // sv.is.da_333 kk.fa.ky_332  ru.mk.un_220 la.tlh.un_420 
  0x2d0d5102, 0x375d19a0, 0x3079fea0, 0x150c0607,   // kl.cs.sk_222 gl.ss.st_322  tlh.war.uz_322 de.sv.un_432 
  0x48293007, 0x06000f0e, 0x22006012, 0x3e24fe04,   // uz.sl.tt_432 lv.de.un_550  vo.oc.un_640 tlh.eo.rm_332 
  // [1c4e0]
  0x4c160d07, 0x5c1e5607, 0x02650da0, 0x16fe3007,   // cs.hr.wo_432 mg.ms.sa_432  cs.gv.da_322 uz.tlh.hr_432 
  0x17360aa0, 0x19224304, 0x04361507, 0x22003612,   // mk.ab.sr_322 ie.oc.gl_332  un.ab.ru_432 gn.oc.un_640 
  0x2e001018, 0x28003014, 0x302d0d13, 0x25006219,   // lt.fo.un_740 uz.sd.un_660  cs.sk.uz_665 kha.eu.un_750 
  0x2e00fe04, 0x52002702, 0x172d0d07, 0x42120708,   // tlh.fo.un_320 gd.ha.un_220  cs.sk.sr_432 it.hu.co_443 
  // [1c4f0]
  0x100823a0, 0x2f473504, 0x281f59a0, 0x685f750b,   // ky.uk.be_322 zu.sn.su_332  rn.cy.sw_322 nso.tn.ig_542 
  0x1d001129, 0x47005f04, 0x6736100c, 0x2a007305,   // ro.la.un_960 tn.sn.un_320  lt.gn.ak_543 ny.mt.un_330 
  0x21004a11, 0x35001f02, 0x43000508, 0x12005d18,   // yo.jw.un_630 cy.zu.un_220  fr.ie.un_430 ss.hu.un_740 
  0x3435fa07, 0x0a002004, 0x281f5505, 0x5500682a,   // nr.zu.xh_432 sq.pt.un_320  rw.cy.sw_333 ig.rw.un_970 
  // [1c500]
  0x23301709, 0x0d2d4aee, 0x48004a08, 0x21001113,   // sr.uz.ky_444 yo.sk.cs_422  yo.tt.un_430 ro.jw.un_650 
  0x09023fa0, 0x050a67ee, 0x082d02a7, 0x1b000702,   // af.da.pl_322 ak.pt.fr_422  da.sk.no_532 it.tr.un_220 
  0x07033f55, 0x171108a4, 0x521d1302, 0x18211260,   // af.nl.it_442 uk.ro.sr_433  et.la.ha_222 ur.fa.ar_664 
  0x52284ba4, 0x4b506aaf, 0x2e3130a0, 0x1a735755,   // mi.sw.ha_433 haw.fj.mi_655  uz.az.fo_322 na.ny.tl_442 
  // [1c510]
  0x032c6a07, 0x1e1a03ec, 0x2e0c1307, 0x06402112,   // haw.fy.nl_432 nl.tl.ms_644  et.sv.fo_432 jw.lb.de_654 
  0x21341213, 0x504052a0, 0x180205a4, 0x1e3b1cec,   // ur.ps.fa_665 ha.lb.fj_322  fr.da.ga_433 id.so.ms_644 
  0x39251b0c, 0xfc002412, 0x2f2a65ee, 0x0a4301a4,   // tr.eu.br_543 eo.zzp.un_640  gv.mt.su_422 en.ie.pt_433 
  0x0e1501a0, 0x1520010c, 0x49735d07, 0x03fc0204,   // en.is.un_320 en.sq.un_543  ss.ny.to_432 da.zzp.nl_332 
  // [1c520]
  0x063b7911, 0x03004b05, 0x061f580c, 0x03001a07,   // war.so.de_653 mi.nl.un_330  om.cy.de_543 tl.nl.un_420 
  0x275efc08, 0x5208330c, 0x2e190b0d, 0x227601a0,   // zzp.ts.gd_443 nn.no.ha_543  es.gl.fo_554 en.crs.oc_322 
  0x3b5258ad, 0x60231908, 0x50004b18, 0x6125480c,   // om.ha.so_643 gl.ca.vo_443  mi.fj.un_740 tt.eu.za_543 
  0x154d1bec, 0x3c283ba4, 0x347303ad, 0x15003b0d,   // tr.aa.un_644 ks.sd.ug_433  nl.ny.xh_643 so.un.un_540 
  // [1c530]
  0x735302a0, 0x0a234704, 0x5f373312, 0x65221305,   // da.ht.ny_322 sn.ca.pt_332  nn.st.tn_654 et.oc.gv_333 
  0x0d122dee, 0x2463010c, 0x3b4d1ca4, 0x3158fe04,   // sk.hu.cs_422 en.sco.eo_543  id.aa.so_433 tlh.om.az_332 
  0x15001c08, 0x7815010c, 0x11300a05, 0x052f4a07,   // id.un.un_430 en.ve.un_530  mk.uz.ro_333 yo.su.fr_432 
  0x53600c0d, 0x041038a7, 0x1b4f6007, 0x46005907,   // sv.vo.ht_554 tk.be.ru_532  vo.bi.tr_432 rn.qu.un_420 
  // [1c540]
  0x080223a0, 0x27310c02, 0x123c28ee, 0x560259a7,   // ca.da.no_322 sv.az.gd_222  sd.ug.ur_422 rn.da.mg_532 
  0x5265600c, 0x12483b04, 0x4f1f0704, 0x3f0e69a4,   // vo.gv.ha_543 so.tt.hu_332  it.cy.bi_332 mfe.is.af_433 
  0x17303c0d, 0x154448a0, 0x5a002c02, 0x34375d05,   // ug.uz.sr_554 tt.kk.un_322  fy.sm.un_220 ss.st.xh_333 
  0x4423350b, 0x3d212307, 0x152511ec, 0x2409390c,   // tg.ky.kk_542 ky.fa.ku_432  ro.mn.un_644 br.pl.eo_543 
  // [1c550]
  0x3900121a, 0x3e003908, 0x0c4e0e60, 0x3e40060b,   // hu.br.un_760 br.rm.un_430  is.ay.sv_664 de.lb.rm_542 
  0x21134c07, 0x105f4a04, 0x04004a11, 0x233038ee,   // wo.et.jw_432 yo.tn.lt_332  yo.fi.un_630 tk.uz.ky_422 
  0x15073ca4, 0x4a2d0d0e, 0x44170409, 0x24067907,   // ug.bg.un_433 cs.sk.yo_555  ru.sr.kk_444 war.de.eo_432 
  0x361d0707, 0x170730a4, 0x0b631004, 0x091d2dee,   // it.la.gn_432 uz.bg.sr_433  lt.sco.es_332 sk.la.pl_422 
  // [1c560]
  0x63091da4, 0x27001a05, 0x3d304455, 0x35341812,   // la.pl.sco_433 tl.gd.un_330  kk.uz.ku_442 ga.xh.zu_654 
  0x244c09a0, 0x27186bee, 0x130456a4, 0x6b2779ee,   // pl.wo.eo_322 ceb.ga.gd_422  mg.fi.et_433 war.gd.ceb_422 
  0x73301e0c, 0x34005d11, 0x2b2253a4, 0x645dfea0,   // ms.uz.ny_543 ss.xh.un_630  ht.oc.vi_433 tlh.ss.lg_322 
  0x3000690c, 0x27180eee, 0x18000c1a, 0x60150112,   // mfe.uz.un_530 is.ga.gd_422  sv.ga.un_760 en.vo.un_640 
  // [1c570]
  0x5a000311, 0x1a004608, 0x0100600c, 0xfc0c0202,   // nl.sm.un_630 qu.tl.un_430  vo.en.un_530 da.sv.zzp_222 
  0x5a005009, 0x2e633304, 0x3d2134ec, 0x03000d02,   // fj.sm.un_440 nn.sco.fo_332  ps.fa.ku_644 cs.nl.un_220 
  0x5a016004, 0x40031d04, 0x35344ea9, 0x231d0a08,   // vo.en.sm_332 la.nl.lb_332  ay.xh.zu_544 pt.la.ca_443 
  0x033f3905, 0x22002f13, 0x221d39a9, 0x33000e19,   // br.af.nl_333 su.oc.un_650  br.la.oc_544 is.nn.un_750 
  // [1c580]
  0x630228ee, 0x271863a0, 0x38005b12, 0x61003914,   // sw.da.sco_422 sco.ga.gd_322  sg.tk.un_640 br.za.un_660 
  0x153f6308, 0x3f1d2311, 0x23222b0b, 0x23190a14,   // sco.af.un_443 ca.la.af_653  vi.oc.ca_542 pt.gl.ca_666 
  0x432239a4, 0x18004912, 0x1500042a, 0x6420730c,   // br.oc.ie_433 to.ga.un_640  ru.un.un_970 ny.sq.lg_543 
  0x39192355, 0x5e357305, 0x40060fee, 0x39006113,   // ca.gl.br_442 ny.zu.ts_333  lv.de.lb_422 za.br.un_650 
  // [1c590]
  0x203b4da6, 0x55002809, 0x20007304, 0x69075908,   // aa.so.sq_521 sw.rw.un_440  ny.sq.un_320 rn.it.mfe_443 
  0x23071508, 0x230a0708, 0x30647302, 0x09006405,   // un.bg.ky_443 bg.mk.ky_443  ny.lg.uz_222 lg.pl.un_330 
  0x20735504, 0x0f292d05, 0x0e00480c, 0x2800240d,   // rw.ny.sq_332 sk.sl.lv_333  tt.is.un_530 eo.sw.un_540 
  0x303b18a4, 0x04100814, 0x1823340c, 0x33000102,   // ar.ks.uz_433 uk.be.ru_666  ps.ky.ar_543 en.nn.un_220 
  // [1c5a0]
  0x190b4314, 0x0817150c, 0x154804af, 0x0602760d,   // ie.es.gl_666 un.sr.uk_543  ru.tt.un_655 crs.da.de_554 
  0x655324a6, 0x15002b0d, 0x231812ec, 0x40006b09,   // eo.ht.gv_521 vi.un.un_540  ur.ar.ky_644 ceb.lb.un_440 
  0x1b1a79ee, 0x0e302ea4, 0x32175307, 0x213d285a,   // war.tl.tr_422 fo.uz.is_433  ht.sr.bs_432 sd.ku.fa_553 
  0x1a6b4a55, 0x353f6502, 0x1b101355, 0x6421685a,   // yo.ceb.tl_442 gv.af.zu_222  et.lt.tr_442 ig.jw.lg_553 
  // [1c5b0]
  0x09006421, 0x201638ee, 0x37fc6455, 0x33005c12,   // lg.pl.un_860 tk.hr.sq_422  lg.zzp.st_442 sa.nn.un_640 
  0x34381dee, 0x1e560802, 0x0b003002, 0x15241a0b,   // la.tk.xh_422 no.mg.ms_222  uz.es.un_220 tl.eo.un_542 
  0x3e003502, 0x46001f11, 0x392f1b02, 0x122438ad,   // zu.rm.un_220 cy.qu.un_630  tr.su.br_222 tk.eo.hu_643 
  0x15241d04, 0x09201da7, 0x30101b07, 0x79246b07,   // la.eo.un_332 la.sq.pl_532  tr.lt.uz_432 ceb.eo.war_432 
  // [1c5c0]
  0x1d006413, 0x4f434208, 0x381523af, 0x34003023,   // lg.la.un_650 co.ie.bi_443  ky.tk.un_650 uz.ps.un_880 
  0x69004222, 0x130c20a6, 0x11302312, 0x36005507,   // co.mfe.un_870 sq.sv.et_521  ky.uz.ro_654 rw.gn.un_420 
  0x15001719, 0x040948a0, 0x0c245407, 0x241e1c08,   // sr.un.un_750 tt.pl.fi_322  ik.eo.sv_432 id.ms.eo_443 
  0x3c374413, 0x21303405, 0x34123b04, 0x28383b05,   // kk.ba.ug_665 ps.uz.fa_333  ks.ur.ps_332 so.tk.sw_333 
  // [1c5d0]
  0x1f005022, 0x080c0d0c, 0x240b6012, 0x171639af,   // fj.cy.un_870 cs.sv.no_543  vo.es.eo_654 br.hr.sr_655 
  0x3b1a09a0, 0x392d58a7, 0x5d02fa13, 0x6563fcad,   // pl.tl.so_322 om.sk.br_532  nr.da.ss_665 zzp.sco.gv_643 
  0x1f00600c, 0x0300fc13, 0x30001e0d, 0x040838ee,   // vo.cy.un_530 zzp.nl.un_650  ms.uz.un_540 tk.uk.ru_422 
  0x370444ad, 0x1912020b, 0x483002a7, 0x2e2831a0,   // kk.ru.ba_643 da.hu.gl_542  da.uz.tt_532 az.sw.fo_322 
  // [1c5e0]
  0x0c31330c, 0x1265fc04, 0x7900680d, 0x1f601908,   // nn.az.sv_543 zzp.gv.hu_332  ig.war.un_540 gl.vo.cy_443 
  0x5d2f280c, 0x02000213, 0x586a1a0c, 0x5e75375a,   // sw.su.ss_543 da.da.un_650  tl.haw.om_543 st.nso.ts_553 
  0x1f464ea9, 0x3b1b6a07, 0x161f2aa4, 0x346a35a4,   // ay.qu.cy_544 haw.tr.so_432  mt.cy.hr_433 zu.haw.xh_433 
  0x20005308, 0x56004602, 0x091f18af, 0x38004909,   // ht.sq.un_430 qu.mg.un_220  ga.cy.pl_655 to.tk.un_440 
  // [1c5f0]
  0x212f1260, 0x1e2f1c07, 0x21005102, 0x2f4c12ad,   // hu.su.jw_664 id.su.ms_432  kl.jw.un_220 hu.wo.su_643 
  0x3900530c, 0x2e0208af, 0x1e002f07, 0x1c2125ec,   // ht.br.un_530 no.da.fo_655  su.ms.un_420 eu.jw.id_644 
  0x07383011, 0x353038af, 0x2f4012a9, 0x0e400611,   // uz.tk.bg_653 tk.uz.tg_655  hu.lb.su_544 de.lb.is_653 
  0x082315a7, 0x07004708, 0x40000309, 0x06634004,   // un.ky.uk_532 sn.it.un_430  nl.lb.un_440 lb.sco.de_332 
  // [1c600]
  0x2d0d3ea0, 0x0c0e2e13, 0x0c63620c, 0x64001a12,   // rm.cs.sk_322 fo.is.sv_665  kha.sco.sv_543 tl.lg.un_640 
  0x33004507, 0x052279a9, 0x1e005605, 0x6700021a,   // ln.nn.un_420 war.oc.fr_544  mg.ms.un_330 da.ak.un_760 
  0x3c30380e, 0x25002805, 0x37003c29, 0x18005005,   // tk.uz.ug_555 sw.eu.un_330  ug.ba.un_960 fj.ga.un_330 
  0x0c3b1507, 0x0c006509, 0x18233c05, 0x2c151f12,   // un.so.sv_432 gv.sv.un_440  ug.ky.ar_333 cy.fy.un_640 
  // [1c610]
  0x08481107, 0x0c15130c, 0x3963560c, 0x48101505,   // ro.tt.uk_432 et.sv.un_530  mg.sco.br_543 un.be.tt_333 
  0x1d7601a4, 0x6900602a, 0x15070a5a, 0x4f2901a4,   // en.crs.la_433 vo.mfe.un_970  mk.bg.un_553 en.sl.bi_433 
  0x400c0e05, 0x04134cac, 0x59554509, 0xfc572c07,   // is.sv.lb_333 wo.et.fi_632  ln.rw.rn_444 fy.na.zzp_432 
  0x051d560c, 0x2b1d010c, 0x242d43a9, 0x595528a4,   // mg.la.fr_543 en.la.vi_543  ie.sk.eo_544 sw.rw.rn_433 
  // [1c620]
  0x30443509, 0x033b3307, 0x73001504, 0x2b00fe13,   // tg.kk.uz_444 nn.so.nl_432  un.ny.un_320 tlh.vi.un_650 
  0x115e4704, 0x43241da9, 0x0c082ca4, 0x1d242da0,   // sn.ts.ro_332 la.eo.ie_544  fy.no.sv_433 sk.eo.la_322 
  0x0c5c215a, 0x130f1007, 0x24132504, 0x3e364207,   // jw.sa.sv_553 lt.lv.et_432  eu.et.eo_332 co.gn.rm_432 
  0x0708170e, 0x59551ba9, 0x0d094208, 0x3e266555,   // sr.uk.bg_555 tr.rw.rn_544  co.pl.cs_443 gv.ia.rm_442 
  // [1c630]
  0x4a002e07, 0x4257250c, 0x3e2c060c, 0x24604312,   // fo.yo.un_420 eu.na.co_543  de.fy.rm_543 ie.vo.eo_654 
  0x3035100e, 0x42115aa0, 0x11006508, 0x46004209,   // be.tg.uz_555 sm.ro.co_322  gv.ro.un_430 co.qu.un_440 
  0x20005f04, 0x21105c0d, 0x09302da0, 0x074215a9,   // tn.sq.un_320 sa.lt.jw_554  sk.uz.pl_322 un.co.it_544 
  0x28004808, 0x311b280c, 0x7364280c, 0x73311b0c,   // tt.sw.un_430 sw.tr.az_543  sw.lg.ny_543 tr.az.ny_543 
  // [1c640]
  0x59552807, 0x28005921, 0x30280704, 0x34593eec,   // sw.rw.rn_432 rn.sw.un_860  it.sw.uz_332 rm.rn.xh_644 
  0x481544af, 0x64452805, 0x11240d07, 0x3c48150c,   // kk.tt.un_650 sw.ln.lg_333  cs.eo.ro_432 un.tt.ug_543 
  0x25595507, 0x73645908, 0x64553508, 0x3e1153a0,   // rw.rn.eu_432 rn.lg.ny_443  zu.rw.lg_443 ht.ro.rm_322 
  0x2335305a, 0x132804a4, 0x64516208, 0x23170705,   // uz.tg.ky_553 fi.sw.et_433  kha.kl.lg_443 bg.sr.ky_333 
  // [1c650]
  0x08230702, 0x4cfe4aa4, 0x24124cac, 0x4a6467ac,   // bg.ky.uk_222 yo.tlh.wo_433  wo.hu.eo_632 ak.lg.yo_632 
  0x645c4707, 0x361c04ee, 0x0f2f51a4, 0x79404304,   // sn.sa.lg_432 fi.id.gn_422  kl.su.lv_433 ie.lb.war_332 
  0x134c10a4, 0x4e3f2408, 0x07021c07, 0x56004714,   // lt.wo.et_433 eo.af.ay_443  id.da.it_432 sn.mg.un_660 
  0x503749a4, 0x13041e07, 0x5a005012, 0x5c5651af,   // to.st.fj_433 ms.fi.et_432  fj.sm.un_640 kl.mg.sa_655 
  // [1c660]
  0x0f4754a9, 0x0802feaf, 0x115f65a4, 0x4f000113,   // ik.sn.lv_544 tlh.da.no_655  gv.tn.ro_433 en.bi.un_650 
  0x272f1504, 0x11650107, 0x1704080b, 0x38154808,   // un.su.gd_332 en.gv.ro_432  uk.ru.sr_542 tt.tk.un_430 
  0x5f566805, 0x605451ec, 0x211c1e0b, 0x112c6a12,   // ig.mg.tn_333 kl.ik.vo_644  ms.id.jw_542 haw.fy.ro_654 
  0x063f7908, 0x40005e09, 0x2f002404, 0x27001836,   // war.af.de_443 ts.lb.un_440  eo.su.un_320 ga.gd.un_AA0 
  // [1c670]
  0x1813570c, 0x152713a9, 0x633001a0, 0x271862ad,   // na.et.ga_543 et.gd.un_544  en.uz.sco_322 kha.ga.gd_643 
  0x62001319, 0x1000480e, 0x0c064012, 0x0b006304,   // et.kha.un_750 tt.be.un_550  lb.de.sv_654 sco.es.un_320 
  0x12231307, 0x2e2c3fa0, 0x651827a4, 0x401d060c,   // et.ca.hu_432 af.fy.fo_322  gd.ga.gv_433 de.la.lb_543 
  0x030212ee, 0x0e000802, 0x15000e02, 0x03001308,   // hu.da.nl_422 no.is.un_220  is.un.un_220 et.nl.un_430 
  // [1c680]
  0x626313af, 0x0e00650c, 0x1d00010d, 0x0811360c,   // et.sco.kha_655 gv.is.un_530  en.la.un_540 ab.ro.uk_543 
  0x39432155, 0x10040a0b, 0x02634e55, 0x13001002,   // jw.ie.br_442 mk.ru.be_542  ay.sco.da_442 lt.et.un_220 
  0x063308a0, 0x2f1918ee, 0x3e5c1d07, 0x58643ba0,   // no.nn.de_322 ga.gl.su_422  la.sa.rm_432 so.lg.om_322 
  0x23190b60, 0x0b194aa0, 0x35301713, 0x43060c60,   // es.gl.ca_664 yo.gl.es_322  sr.uz.tg_665 sv.de.ie_664 
  // [1c690]
  0x1a6b7307, 0x28213012, 0x5559730b, 0x65421da0,   // ny.ceb.tl_432 uz.fa.sd_654  ny.rn.rw_542 la.co.gv_322 
  0x6b007313, 0x64357307, 0x10002d14, 0x173035ec,   // ny.ceb.un_650 ny.zu.lg_432  sk.lt.un_660 tg.uz.sr_644 
  0x2f4c210d, 0x4a002204, 0x454e0e13, 0x5500730d,   // jw.wo.su_554 oc.yo.un_320  is.ay.ln_665 ny.rw.un_540 
  0x28556409, 0x213018ec, 0x551a350c, 0x5f736405,   // lg.rw.sw_444 ar.uz.fa_644  zu.tl.rw_543 lg.ny.tn_333 
  // [1c6a0]
  0x1a002004, 0x5e647307, 0x231548a9, 0x73020d07,   // sq.tl.un_320 ny.lg.ts_432  tt.ky.un_540 cs.da.ny_432 
  0x1004440c, 0x734559a4, 0x351015a4, 0x34375d04,   // kk.ru.be_543 rn.ln.ny_433  un.be.tg_433 ss.st.xh_332 
  0x0d001e02, 0x123d2808, 0x4c212f0d, 0x132e6502,   // ms.cs.un_220 sd.ku.ur_443  su.jw.wo_554 gv.fo.et_222 
  0x131827a7, 0x1300650d, 0x52375f11, 0x021363a7,   // gd.ga.et_532 gv.et.un_540  tn.st.ha_653 sco.et.da_532 
  // [1c6b0]
  0x120e2e08, 0x01186305, 0x40000511, 0x3b1365ad,   // fo.is.hu_443 sco.ga.en_333  fr.lb.un_630 gv.et.so_643 
  0x484301a0, 0x211e1c02, 0x19001608, 0x12212813,   // en.ie.tt_322 id.ms.jw_222  hr.gl.un_430 sd.fa.ur_665 
  0x4c0157a9, 0x302402a7, 0x21007307, 0x281a52a7,   // na.en.wo_544 da.eo.uz_532  ny.jw.un_420 ha.tl.sw_532 
  0x1e004704, 0x1744150b, 0x0f002a09, 0x133f6502,   // sn.ms.un_320 un.kk.sr_542  mt.lv.un_440 gv.af.et_222 
  // [1c6c0]
  0x150e2e07, 0xfe1d62a9, 0x600f040d, 0x30136009,   // fo.is.un_432 kha.la.tlh_544  fi.lv.vo_554 vo.et.uz_444 
  0x121a0ca9, 0x17150411, 0x4a001b0d, 0x76003021,   // sv.tl.hu_544 ru.sr.un_630  tr.yo.un_540 uz.crs.un_860 
  0x0f6402ad, 0x4c024dee, 0x2f404da0, 0x0f00300d,   // da.lg.lv_643 aa.da.wo_422  aa.lb.su_322 uz.lv.un_540 
  0x3b644dec, 0x2f0f400c, 0x0e0b18a0, 0x1a3b4d0c,   // aa.lg.so_644 lb.lv.su_543  ga.es.is_322 aa.so.tl_543 
  // [1c6d0]
  0x64003b0c, 0x08044455, 0x56002704, 0x0c3869ad,   // so.lg.un_530 kk.ru.uk_442  gd.mg.un_320 mfe.tk.sv_643 
  0x3b644d04, 0x21002308, 0x0e182ea0, 0x30152308,   // aa.lg.so_332 ca.jw.un_430  fo.ga.is_322 ky.uz.un_430 
  0x1d202e0b, 0x406539ee, 0x234c2007, 0x2073010c,   // fo.sq.la_542 br.gv.lb_422  sq.wo.ca_432 en.ny.sq_543 
  0x532d0d5a, 0x393f2ca9, 0x35fc7560, 0x2d0d2507,   // cs.sk.ht_553 fy.af.br_544  nso.zzp.zu_664 eu.cs.sk_432 
  // [1c6e0]
  0x54736008, 0x4430340c, 0x3f392c08, 0x434b4960,   // vo.ny.ik_443 ps.uz.kk_543  fy.br.af_443 to.mi.ie_664 
  0x496a04af, 0x1e004d21, 0x30174802, 0x13004b05,   // fi.haw.to_655 aa.ms.un_860  tt.sr.uz_222 mi.et.un_330 
  0x4d006a0e, 0x13004929, 0x6b4a1a55, 0x68005b21,   // haw.aa.un_550 to.et.un_960  tl.yo.ceb_442 sg.ig.un_860 
  0x455556af, 0x30733607, 0x73464508, 0x1d00470c,   // mg.rw.ln_655 gn.ny.uz_432  ln.qu.ny_443 sn.la.un_530 
  // [1c6f0]
  0x30070a05, 0x136569a9, 0x05001304, 0x1b003121,   // mk.bg.uz_333 mfe.gv.et_544  et.fr.un_320 az.tr.un_860 
  0x3b27130c, 0x5f50600d, 0x5c212fad, 0x56604709,   // et.gd.so_543 vo.fj.tn_554  su.jw.sa_643 sn.vo.mg_444 
  0x65001308, 0x3700670d, 0x07004211, 0x1f001512,   // et.gv.un_430 ak.st.un_540  co.it.un_630 un.cy.un_640 
  0x24102aa6, 0x56601f07, 0x34123ba4, 0x5cfc01a0,   // mt.lt.eo_521 cy.vo.mg_432  ks.ur.ps_433 en.zzp.sa_322 
  // [1c700]
  0x483013ac, 0x632d090c, 0x152113ac, 0x42000913,   // et.uz.tt_632 pl.sk.sco_543  et.jw.un_632 pl.co.un_650 
  0x651315af, 0x12473507, 0x012f1304, 0x604c3505,   // un.et.gv_655 zu.sn.hu_432  et.su.en_332 zu.wo.vo_333 
  0x6453350c, 0x32172daf, 0x22004a0c, 0x1260300d,   // zu.ht.lg_543 sk.sr.bs_655  yo.oc.un_530 uz.vo.hu_554 
  0x24005f0c, 0x1d11250e, 0x371d34ee, 0x442325ee,   // tn.eo.un_530 eu.ro.la_555  xh.la.st_422 mn.ky.kk_422 
  // [1c710]
  0x11001508, 0x7965060d, 0x2f001f04, 0x0657fe08,   // un.ro.un_430 de.gv.war_554  cy.su.un_320 tlh.na.de_443 
  0x39481360, 0x211001a0, 0x1f002c0e, 0x1b2a03ee,   // et.tt.br_664 en.lt.jw_322  fy.cy.un_550 nl.mt.tr_422 
  0x6502390c, 0x02000502, 0x56051e04, 0x0f001507,   // br.da.gv_543 fr.da.un_220  ms.fr.mg_332 un.lv.un_420 
  0x03201b14, 0x03583fa9, 0x652a2ca4, 0x1b121ea9,   // tr.sq.nl_666 af.om.nl_544  fy.mt.gv_433 ms.hu.tr_544 
  // [1c720]
  0x070410a9, 0x3860250b, 0x211823ad, 0x10483808,   // be.ru.bg_544 eu.vo.tk_542  ky.ar.fa_643 tk.tt.lt_443 
  0x2c004c07, 0x1d1e1c08, 0x1b301e07, 0x761269a7,   // wo.fy.un_420 id.ms.la_443  ms.uz.tr_432 mfe.hu.crs_532 
  0x0738480d, 0x37440407, 0x3f000319, 0x4c033ba0,   // tt.tk.bg_554 ru.kk.ba_432  nl.af.un_750 so.nl.wo_322 
  0x502e5604, 0x3f4c1304, 0x4c283bad, 0x3b033f60,   // mg.fo.fj_332 et.wo.af_332  so.sw.wo_643 af.nl.so_664 
  // [1c730]
  0x321623a0, 0x4c003b12, 0x152e4fa7, 0x153704ec,   // ca.hr.bs_322 so.wo.un_640  bi.fo.un_532 ru.ba.un_644 
  0x066b1dec, 0x11000e05, 0x340c3307, 0x0d5c1312,   // la.ceb.de_644 is.ro.un_330  nn.sv.xh_432 bh.sa.ne_654 
  0x6315270c, 0x061840a9, 0x1f2718a9, 0x4c1303a9,   // gd.sco.un_530 lb.ga.de_544  ga.gd.cy_544 nl.et.wo_544 
  0x29000207, 0x374811ee, 0x6340050c, 0x5b004c08,   // da.sl.un_420 ro.tt.ba_422  fr.lb.sco_543 wo.sg.un_430 
  // [1c740]
  0x120e0cad, 0x1b4d4612, 0x2e651f0c, 0x022e0812,   // sv.is.hu_643 qu.aa.tr_654  cy.gv.fo_543 no.fo.da_654 
  0x53190ba7, 0x1f001a13, 0x282b18a0, 0x350410af,   // es.gl.ht_532 tl.cy.un_650  ga.vi.sw_322 be.ru.tg_655 
  0x5c5f5d04, 0x3b5c2812, 0x730247a9, 0x08003402,   // ss.tn.sa_332 sw.sa.so_654  sn.da.ny_544 xh.no.un_220 
  0x373528a4, 0x1e1c1da0, 0x300215a0, 0x443023ad,   // sw.zu.st_433 la.id.ms_322  un.da.uz_322 ky.uz.kk_643 
  // [1c750]
  0x37000709, 0x25231512, 0x19002704, 0x406a5812,   // bg.ba.un_440 un.ky.mn_654  gd.gl.un_320 om.haw.lb_654 
  0x1e003109, 0x2d0d3b0e, 0x4d3b580d, 0x29536707,   // az.ms.un_440 so.cs.sk_555  om.so.aa_554 ak.ht.sl_432 
  0x17000817, 0x35005102, 0x6a58640c, 0x35004e12,   // uk.sr.un_730 kl.zu.un_220  lg.om.haw_543 ay.zu.un_640 
  0x684c3b13, 0x2f123ba0, 0x583b5aac, 0x0d091cad,   // so.wo.ig_665 so.hu.su_322  sm.so.om_632 mr.hi.ne_643 
  // [1c760]
  0x4c003b23, 0x07154804, 0x2f003302, 0x79584c08,   // so.wo.un_880 tt.bg.un_320  nn.su.un_220 wo.om.war_443 
  0x3f6a1a07, 0x58003b14, 0x3f5a0408, 0x4c643b08,   // tl.haw.af_432 so.om.un_660  fi.sm.af_443 so.lg.wo_443 
  0x4d5a4ca9, 0x21321602, 0x17303cad, 0x081510a9,   // wo.sm.aa_544 hr.bs.jw_222  ug.uz.sr_643 be.uk.un_540 
  0x65001a08, 0x0d131c0d, 0x3c2130a4, 0x483831ee,   // tl.gv.un_430 mr.bh.ne_554  uz.fa.ug_433 az.tk.tt_422 
  // [1c770]
  0x38483109, 0x38481bad, 0x44001714, 0x6b2001a0,   // az.tt.tk_444 tr.tt.tk_643  sr.kk.un_660 en.sq.ceb_322 
  0x3f2c6307, 0x0e533904, 0x0e1f250c, 0x1d2f5102,   // sco.fy.af_432 br.ht.is_332  eu.cy.is_543 kl.su.la_222 
  0x3c304407, 0x651a1c07, 0x6b1a1ea9, 0x0d206108,   // kk.uz.ug_432 id.tl.gv_432  ms.tl.ceb_544 za.sq.cs_443 
  0x17003013, 0x0d1d01a4, 0x65036207, 0x1f000e1a,   // uz.sr.un_650 en.la.cs_433  kha.nl.gv_432 is.cy.un_760 
  // [1c780]
  0x48313855, 0x2e003009, 0x1a5451ec, 0x475b280c,   // tk.az.tt_442 uz.fo.un_440  kl.ik.tl_644 sw.sg.sn_543 
  0x05650305, 0x381d0107, 0x115c1d0c, 0x314838a4,   // nl.gv.fr_333 en.la.tk_432  la.sa.ro_543 tk.tt.az_433 
  0x1b313860, 0x200d61a9, 0xfe694ca4, 0x4c010607,   // tk.az.tr_664 za.cs.sq_544  wo.mfe.tlh_433 de.en.wo_432 
  0x391d6508, 0x2f005912, 0x30204e0b, 0x0e1236ad,   // gv.la.br_443 rn.su.un_640  ay.sq.uz_542 gn.hu.is_643 
  // [1c790]
  0x5600360b, 0x0a5347ee, 0x25313012, 0x25393408,   // gn.mg.un_520 sn.ht.pt_422  uz.az.eu_654 xh.br.eu_443 
  0x0e1236ec, 0x3d233404, 0x2f122105, 0x371023a0,   // gn.hu.is_644 ps.ky.ku_332  jw.hu.su_333 ky.be.ba_322 
  0x041b0c08, 0x04134b04, 0x092e0eec, 0x13003307,   // sv.tr.fi_443 mi.et.fi_332  is.fo.pl_644 nn.et.un_420 
  0x1600100d, 0x25002402, 0x15150413, 0x371510ec,   // lt.hr.un_540 eo.eu.un_220  ru.un.un_650 be.ba.un_640 
  // [1c7a0]
  0x48380ca0, 0x3e004005, 0x21001802, 0x17292d55,   // sv.tk.tt_322 lb.rm.un_330  ga.jw.un_220 sk.sl.sr_442 
  0x303e5807, 0x3e6923a4, 0x022e3307, 0x0e15fcee,   // om.rm.uz_432 ca.mfe.rm_433  nn.fo.da_432 zzp.is.un_420 
  0x03fc3fa0, 0x33080fa0, 0x1800430c, 0x063f4004,   // af.zzp.nl_322 lv.no.nn_322  ie.ga.un_530 lb.af.de_332 
  0x373815a9, 0x23193604, 0x420c3307, 0x180e2e64,   // un.tk.ba_544 gn.gl.ca_332  nn.sv.co_432 fo.is.ga_762 
  // [1c7b0]
  0x08fc2e07, 0x52005012, 0x384a0207, 0x101d560c,   // fo.zzp.no_432 fj.ha.un_640  da.yo.tk_432 mg.la.lt_543 
  0x47002c02, 0x2f1e39a4, 0x370a070c, 0x31006707,   // fy.sn.un_220 br.ms.su_433  bg.mk.ba_543 ak.az.un_420 
  0x0a1748a4, 0x150444a7, 0x303b3105, 0x3d301213,   // tt.sr.mk_433 kk.ru.un_532  az.so.uz_333 ur.uz.ku_665 
  0x0a00110b, 0x08002e08, 0x39006e09, 0x557359a4,   // ro.mk.un_520 fo.no.un_430  hmn.br.un_440 rn.ny.rw_433 
  // [1c7c0]
  0x23fe0707, 0x6b004933, 0x39045002, 0x6b401dee,   // it.tlh.ca_432 to.ceb.un_A70  fj.fi.br_222 la.lb.ceb_422 
  0x0d421011, 0x240c0da0, 0x286b580c, 0x44081009,   // lt.co.cs_653 cs.sv.eo_322  om.ceb.sw_543 be.uk.kk_444 
  0x290253a4, 0xfe17290c, 0x5a503f04, 0x330d2e07,   // ht.da.sl_433 sl.sr.tlh_543  af.fj.sm_332 fo.cs.nn_432 
  0x13005e0e, 0x5e4b6aad, 0x6b005008, 0x0d00290e,   // ts.et.un_550 haw.mi.ts_643  fj.ceb.un_430 sl.cs.un_550 
  // [1c7d0]
  0x73284513, 0x30040aa7, 0x396864a9, 0x22332cad,   // ln.sw.ny_665 mk.ru.uz_532  lg.ig.br_544 fy.nn.oc_643 
  0x162a2d07, 0x100411a0, 0x4006650c, 0x0b002702,   // sk.mt.hr_432 ro.ru.be_322  gv.de.lb_543 gd.es.un_220 
  0x65150112, 0x3b003014, 0xfe18275a, 0x126502a0,   // en.gv.un_640 uz.ks.un_660  gd.ga.tlh_553 da.gv.hu_322 
  0x3d123b0b, 0x423e0713, 0x6500202c, 0x21001e07,   // ks.ur.ku_542 it.rm.co_665  sq.gv.un_990 ms.jw.un_420 
  // [1c7e0]
  0x10002911, 0x423e07a9, 0x42073e55, 0x25003e07,   // sl.lt.un_630 it.rm.co_544  rm.it.co_442 rm.eu.un_420 
  0x424c3e04, 0x6a000f19, 0x3f1b25a9, 0x213d3012,   // rm.wo.co_332 lv.haw.un_750  eu.tr.af_544 uz.ku.fa_654 
  0x1e523b04, 0x1e1c39ec, 0x391e1c0d, 0x694d60ad,   // so.ha.ms_332 br.id.ms_644  id.ms.br_554 vo.aa.mfe_643 
  0x03392da4, 0x2105230c, 0x6e000f08, 0x04fe1304,   // sk.br.nl_433 ca.fr.jw_543  lv.hmn.un_430 et.tlh.fi_332 
  // [1c7f0]
  0x4e002109, 0x0c0d2912, 0x4018050c, 0x1b7608a0,   // jw.ay.un_440 sl.cs.sv_654  fr.ga.lb_543 no.crs.tr_322 
  0x0c1b5cad, 0x06006017, 0x0440fcac, 0x0b23110c,   // sa.tr.sv_643 vo.de.un_730  zzp.lb.fi_632 ro.ca.es_543 
  0xfe001d0d, 0x20000f0c, 0x460f1311, 0xfc033f0c,   // la.tlh.un_540 lv.sq.un_530  et.lv.qu_653 af.nl.zzp_543 
  0x1015360b, 0x0c0325ee, 0x2676010c, 0x1e1c76a9,   // ab.be.un_520 eu.nl.sv_422  en.crs.ia_543 crs.id.ms_544 
  
  // [1c800]
  0x1b006007, 0x17150805, 0x19100bec, 0x070448a0,   // vo.tr.un_420 uk.sr.un_330  es.lt.gl_644 tt.ru.bg_322 
  0x233d3c04, 0x21383fee, 0x18000514, 0x3831fc60,   // ug.ku.ky_332 af.tk.jw_422  fr.ga.un_660 zzp.az.tk_664 
  0x1b1304a0, 0x464e13af, 0x0a000c04, 0xfc4f1207,   // fi.et.tr_322 et.ay.qu_655  sv.pt.un_320 hu.bi.zzp_432 
  0x3960690e, 0x1e1137a0, 0x0e3f690c, 0x22055307,   // mfe.vo.br_555 st.ro.ms_322  mfe.af.is_543 ht.fr.oc_432 
  // [1c810]
  0x35003205, 0x1b000202, 0x3e151fac, 0x40634cee,   // bs.zu.un_330 da.tr.un_220  cy.rm.un_620 wo.sco.lb_422 
  0x5c135108, 0xfe004c05, 0x47355cec, 0x40003f0d,   // kl.et.sa_443 wo.tlh.un_330  sa.zu.sn_644 af.lb.un_540 
  0x306976a4, 0x025c0c0e, 0x28125d02, 0x2f135dee,   // crs.mfe.uz_433 sv.sa.da_555  ss.hu.sw_222 ss.et.su_422 
  0x3008115a, 0x5d352807, 0x65003802, 0x2a003929,   // ro.uk.uz_553 sw.zu.ss_432  tk.gv.un_220 dz.bo.un_960 
  // [1c820]
  0x37003c19, 0x40002105, 0x2e2522a0, 0x383909a7,   // ug.ba.un_750 jw.lb.un_330  oc.eu.fo_322 pl.br.tk_532 
  0x382065a0, 0x28181212, 0x06030fa4, 0x030640ec,   // gv.sq.tk_322 ur.ar.sd_654  lv.nl.de_433 lb.de.nl_644 
  0x330e03ad, 0x40000e12, 0x090348ec, 0x2102360c,   // nl.is.nn_643 is.lb.un_640  tt.nl.pl_644 gn.da.jw_543 
  0xfe2a1808, 0xfc650302, 0x25100704, 0x021827af,   // ga.mt.tlh_443 nl.gv.zzp_222  bg.be.mn_332 gd.ga.da_655 
  // [1c830]
  0x4800382c, 0x0630fea7, 0x03005102, 0x521579a0,   // tk.tt.un_990 tlh.uz.de_532  kl.nl.un_220 war.ha.un_320 
  0x47546b12, 0x48681107, 0x381504af, 0x48372313,   // ceb.ik.sn_654 ro.ig.tt_432  ru.tk.un_650 ky.ba.tt_665 
  0x3200170d, 0x3f2f2407, 0x3530100c, 0xfa00341a,   // sr.bs.un_540 eo.su.af_432  be.uz.tg_543 xh.nr.un_760 
  0x181d2ba0, 0x2e0c4e14, 0x10204702, 0x340833a4,   // vi.la.ga_322 ay.sv.fo_666  sn.sq.lt_222 nn.no.xh_433 
  // [1c840]
  0x0900fc18, 0x35205d05, 0x695c5da4, 0x283435a7,   // zzp.pl.un_740 ss.sq.zu_333  ss.sa.mfe_433 zu.xh.sw_532 
  0x355d34a9, 0x0c002a02, 0x275d1807, 0x5d005e22,   // xh.ss.zu_544 mt.sv.un_220  ga.ss.gd_432 ts.ss.un_870 
  0x07420107, 0x553534ec, 0x31005d08, 0x2f6b1a08,   // en.co.it_432 xh.zu.rw_644  ss.az.un_430 tl.ceb.su_443 
  0x0c251e0c, 0x17081105, 0x531e2ca4, 0x29033fa4,   // ms.eu.sv_543 ro.uk.sr_333  fy.ms.ht_433 af.nl.sl_433 
  // [1c850]
  0x233c3555, 0x0a3015ad, 0x36005020, 0x55305aa0,   // tg.ug.ky_442 un.uz.mk_643  fj.gn.un_850 sm.uz.rw_322 
  0x470430ad, 0x1200650c, 0x5c423e12, 0x2f390207,   // uz.fi.sn_643 gv.hu.un_530  rm.co.sa_654 da.br.su_432 
  0x28597311, 0x3f002a05, 0x5e006812, 0x170f3204,   // ny.rn.sw_653 mt.af.un_330  ig.ts.un_640 bs.lv.sr_332 
  0x28006421, 0x100f2da4, 0x04151108, 0x531e1c02,   // lg.sw.un_860 sk.lv.lt_433  ro.ru.un_430 id.ms.ht_222 
  // [1c860]
  0x284755a4, 0x033f31ee, 0x18122160, 0x3b2d0d05,   // rw.sn.sw_433 az.af.nl_422  fa.ur.ar_664 cs.sk.so_333 
  0x766053af, 0x53390507, 0x36190a55, 0x39002502,   // ht.vo.crs_655 fr.br.ht_432  pt.gl.gn_442 eu.br.un_220 
  0x100723ac, 0x405005a7, 0x30002204, 0x2e0e380d,   // ky.bg.be_632 fr.fj.lb_532  oc.uz.un_320 tk.is.fo_554 
  0x070a30ec, 0x19120b04, 0x536301a0, 0x2800350d,   // uz.mk.bg_644 es.hu.gl_332  en.sco.ht_322 zu.sw.un_540 
  // [1c870]
  0x11007321, 0x64355ea7, 0x65322202, 0x35121104,   // ny.ro.un_860 ts.zu.lg_532  oc.bs.gv_222 ro.hu.zu_332 
  0x11123e09, 0x18190b07, 0x11353ea7, 0x555d64ec,   // rm.hu.ro_444 es.gl.ga_432  rm.zu.ro_532 lg.ss.rw_644 
  0x23221855, 0x64733504, 0x47341107, 0x59647312,   // ga.oc.ca_442 zu.ny.lg_332  ro.xh.sn_432 ny.lg.rn_654 
  0x34001105, 0x2504155a, 0x6400280d, 0x69762808,   // ro.xh.un_330 un.ru.mn_553  sw.lg.un_540 sw.crs.mfe_443 
  // [1c880]
  0x40000e04, 0x55001105, 0x11126807, 0x095706a4,   // is.lb.un_320 ro.rw.un_330  ig.hu.ro_432 de.na.pl_433 
  0x65006713, 0x3025355a, 0x0a003c0c, 0x2d0d650c,   // ak.gv.un_650 tg.mn.uz_553  ug.mk.un_530 gv.cs.sk_543 
  0x65212607, 0x50732804, 0x234425ad, 0x6a5f5412,   // ia.jw.gv_432 sw.ny.fj_332  mn.kk.ky_643 ik.tn.haw_654 
  0x4f7347a4, 0x0d002f04, 0x55472807, 0x2b00460c,   // sn.ny.bi_433 su.cs.un_320  sw.sn.rw_432 qu.vi.un_530 
  // [1c890]
  0x070a380c, 0x4205360d, 0x0f003404, 0x47346409,   // tk.mk.bg_543 gn.fr.co_554  xh.lv.un_320 lg.xh.sn_444 
  0x1d1327a0, 0x2a643b0d, 0x3b6b1a08, 0x0a270504,   // gd.et.la_322 so.lg.mt_554  tl.ceb.so_443 fr.gd.pt_332 
  0xfc190bad, 0x15462b04, 0x55465d11, 0x15483707,   // es.gl.zzp_643 vi.qu.un_332  ss.qu.rw_653 ba.tt.un_432 
  0x19391dee, 0x3e004a07, 0x30000e04, 0x332058a0,   // la.br.gl_422 yo.rm.un_420  is.uz.un_320 om.sq.nn_322 
  // [1c8a0]
  0x403e0611, 0x521142a0, 0x3133040d, 0x1e1c4802,   // de.rm.lb_653 co.ro.ha_322  fi.nn.az_554 tt.id.ms_222 
  0x1f734712, 0x0358060e, 0x01181507, 0x42583ba0,   // sn.ny.cy_654 de.om.nl_555  un.ga.en_432 so.om.co_322 
  0x2f002504, 0x30681112, 0x464e5812, 0x05000802,   // eu.su.un_320 ro.ig.uz_654  om.ay.qu_654 no.fr.un_220 
  0x2f006811, 0x6b0502a0, 0x240501a4, 0x1f2142a0,   // ig.su.un_630 da.fr.ceb_322  en.fr.eo_433 co.jw.cy_322 
  // [1c8b0]
  0x190b36ee, 0x4a4d7312, 0x47732805, 0x28007314,   // gn.es.gl_422 ny.aa.yo_654  sw.ny.sn_333 ny.sw.un_660 
  0x34731b07, 0x5b207311, 0x1232610c, 0x640225a4,   // tr.ny.xh_432 ny.sq.sg_653  za.bs.hu_543 eu.da.lg_433 
  0x595567af, 0x731e1c14, 0x21003002, 0x1f006421,   // ak.rw.rn_655 id.ms.ny_666  uz.jw.un_220 lg.cy.un_860 
  0x292d6205, 0x18006b04, 0x02006712, 0x622032af,   // kha.sk.sl_333 ceb.ga.un_320  ak.da.un_640 bs.sq.kha_655 
  // [1c8c0]
  0x12006719, 0x2d00381d, 0x5c211c08, 0x73252d0b,   // ak.hu.un_750 tk.sk.un_820  id.jw.sa_443 sk.eu.ny_542 
  0x4600211a, 0x2a5c64a4, 0x28213ba4, 0x24004e10,   // jw.qu.un_760 lg.sa.mt_433  ks.fa.sd_433 ay.eo.un_620 
  0x0a2705a0, 0x11153808, 0x6300062b, 0x386012af,   // fr.gd.pt_322 tk.ro.un_430  de.sco.un_980 hu.vo.tk_655 
  0x374436af, 0x0c436504, 0x44183c0c, 0x525946ee,   // ab.kk.ba_655 gv.ie.sv_332  ug.ar.kk_543 qu.rn.ha_422 
  // [1c8d0]
  0x05232204, 0x081015ee, 0x306367a4, 0xfc1d5412,   // oc.ca.fr_332 un.be.uk_422  ak.sco.uz_433 ik.la.zzp_654 
  0x21522f55, 0x1f2e0e0d, 0x15000704, 0x3800fc12,   // su.ha.jw_442 is.fo.cy_554  bg.un.un_320 zzp.tk.un_640 
  0x23480404, 0x46006b07, 0x38391d02, 0x3023070c,   // ru.tt.ky_332 ceb.qu.un_420  la.br.tk_222 bg.ky.uz_543 
  0x0e4f1f12, 0x3644380c, 0x1e211caf, 0x53602a07,   // cy.bi.is_654 tk.kk.ab_543  id.jw.ms_655 mt.vo.ht_432 
  // [1c8e0]
  0x010360ee, 0x3b1b6005, 0x230438a4, 0x3b2a60a4,   // vo.nl.en_422 vo.tr.so_333  tk.ru.ky_433 vo.mt.so_433 
  0x404c580c, 0x17002319, 0x52304cee, 0x0a253705,   // om.wo.lb_543 ky.sr.un_750  wo.uz.ha_422 ba.mn.mk_333 
  0x56154c0c, 0x43030e55, 0x23150a13, 0x240579a0,   // wo.mg.un_530 is.nl.ie_442  mk.ky.un_650 war.fr.eo_322 
  0x65790612, 0x1e005104, 0x6000470e, 0x37042504,   // de.war.gv_654 kl.ms.un_320  sn.vo.un_550 mn.ru.ba_332 
  // [1c8f0]
  0x4c1f2aa7, 0x2c006107, 0x17151012, 0x02570607,   // mt.cy.wo_532 za.fy.un_420  be.sr.un_640 de.na.da_432 
  0x5c0d1c11, 0x25151011, 0x300738a0, 0x1f3029ad,   // mr.ne.sa_653 be.mn.un_630  tk.bg.uz_322 sl.uz.cy_643 
  0x4d002013, 0x2e560407, 0x49290409, 0x392c6aad,   // sq.aa.un_650 fi.mg.fo_432  fi.sl.to_444 haw.fy.br_643 
  0x4600540d, 0x6a00281b, 0x59000104, 0x28000b02,   // ik.qu.un_540 sw.haw.un_770  en.rn.un_320 es.sw.un_220 
  // [1c900]
  0x30005a22, 0x025a6a08, 0x5f1f5604, 0x244a6407,   // sm.uz.un_870 haw.sm.da_443  mg.cy.tn_332 lg.yo.eo_432 
  0x2300040c, 0x1f003208, 0x3e2718ad, 0x1d006011,   // ru.ky.un_530 bs.cy.un_430  ga.gd.rm_643 vo.la.un_630 
  0x0f625c55, 0x1c2f2102, 0x553534ad, 0x27655a08,   // sa.kha.lv_442 jw.su.id_222  xh.zu.rw_643 sm.gv.gd_443 
  0x325634ee, 0x27005a0c, 0x011d2407, 0x350928a0,   // xh.mg.bs_422 sm.gd.un_530  eo.la.en_432 sw.pl.zu_322 
  // [1c910]
  0x281a020b, 0x043608ad, 0x2912500c, 0x4a006719,   // da.tl.sw_542 uk.ab.ru_643  fj.hu.sl_543 ak.yo.un_750 
  0x1327010c, 0x391e1c5a, 0x04fe130b, 0x13fe61af,   // en.gd.et_543 id.ms.br_553  et.tlh.fi_542 za.tlh.et_655 
  0x18022004, 0x6e285aa0, 0x16002513, 0x040e0c12,   // sq.da.ga_332 sm.sw.hmn_322  eu.hr.un_650 sv.is.fi_654 
  0x29211c08, 0x370708a0, 0x12302805, 0x30362307,   // id.jw.sl_443 uk.bg.ba_322  sd.uz.ur_333 ky.ab.uz_432 
  // [1c920]
  0x3c082312, 0x653612ad, 0x48363814, 0x0a251107,   // ky.uk.ug_654 hu.gn.gv_643  tk.ab.tt_666 ro.mn.mk_432 
  0x381f12ee, 0x0f004e13, 0x1f6467a7, 0x1f00650b,   // hu.cy.tk_422 ay.lv.un_650  ak.lg.cy_532 gv.cy.un_520 
  0x46002f04, 0x5c3b2105, 0x38002402, 0x050453ee,   // su.qu.un_320 jw.so.sa_333  eo.tk.un_220 ht.fi.fr_422 
  0x01054307, 0x03002704, 0x12fe5ea4, 0x06330307,   // ie.fr.en_432 gd.nl.un_320  ts.tlh.hu_433 nl.nn.de_432 
  // [1c930]
  0x22005711, 0x033f0402, 0x2c034012, 0x03004008,   // na.oc.un_630 fi.af.nl_222  lb.nl.fy_654 lb.nl.un_430 
  0x3600630c, 0x24020c02, 0x121936a9, 0x044810ac,   // sco.gn.un_530 sv.da.eo_222  gn.gl.hu_544 be.tt.ru_632 
  0x5110540c, 0x082c0311, 0x21183011, 0x300715a9,   // ik.lt.kl_543 nl.fy.no_653  uz.ar.fa_653 un.bg.uz_544 
  0x1d002c02, 0x0e001314, 0x24000707, 0x3f005b12,   // fy.la.un_220 et.is.un_660  it.eo.un_420 sg.af.un_640 
  // [1c940]
  0x3010370c, 0x0b232604, 0x22006308, 0x2c003f12,   // ba.be.uz_543 ia.ca.es_332  sco.oc.un_430 af.fy.un_640 
  0x373004ee, 0x0600200d, 0x33002207, 0x313815ac,   // ru.uz.ba_422 sq.de.un_540  oc.nn.un_420 un.tk.az_632 
  0x12656304, 0x0465fea0, 0x1a1812a0, 0x0a04255a,   // sco.gv.hu_332 tlh.gv.fi_322  hu.ga.tl_322 mn.ru.mk_553 
  0x28072d08, 0x25153107, 0x3f007905, 0x51330802,   // sk.it.sw_443 az.eu.un_420  war.af.un_330 no.nn.kl_222 
  // [1c950]
  0x041048a9, 0x25005a08, 0x11002d0c, 0x3704080b,   // tt.be.ru_544 sm.eu.un_430  sk.ro.un_530 uk.ru.ba_542 
  0x483008ac, 0x123d3012, 0x1e1c34a0, 0x5a001504,   // uk.uz.tt_632 uz.ku.ur_654  xh.id.ms_322 un.sm.un_320 
  0x123b3d55, 0x347328a7, 0x2e000604, 0x73000212,   // ku.ks.ur_442 sw.ny.xh_532  de.fo.un_320 da.ny.un_640 
  0x16002e02, 0x2f3b1ea9, 0x1e002e09, 0x04440aa0,   // fo.hr.un_220 ms.so.su_544  fo.ms.un_440 mk.kk.ru_322 
  // [1c960]
  0x1e1c3009, 0x134b6a11, 0x2f353404, 0x3605190c,   // uz.id.ms_444 haw.mi.et_653  xh.zu.su_332 gl.fr.gn_543 
  0x68735a08, 0x47003918, 0x17154807, 0x3b3534a0,   // sm.ny.ig_443 br.sn.un_740  tt.sr.un_420 xh.zu.so_322 
  0x081035a4, 0x5d002807, 0x0e062ea4, 0x23303c08,   // tg.be.uk_433 sw.ss.un_420  fo.de.is_433 ug.uz.ky_443 
  0x3b003402, 0x28001604, 0x344421ee, 0x3f1f0f07,   // xh.so.un_220 hr.sw.un_320  fa.kk.ps_422 lv.cy.af_432 
  // [1c970]
  0x0c180204, 0x1e001b02, 0x4a1d0107, 0x03054604,   // da.ga.sv_332 tr.ms.un_220  en.la.yo_432 qu.fr.nl_332 
  0x3b381fad, 0x533901a0, 0x3f0358a0, 0x583b15ad,   // cy.tk.so_643 en.br.ht_322  om.nl.af_322 un.so.om_643 
  0x3f003e04, 0x1e2130a0, 0x652342a0, 0xfe002414,   // rm.af.un_320 uz.jw.ms_322  co.ca.gv_322 eo.tlh.un_660 
  0x3e15fe04, 0x3c3d23a4, 0x1b302c08, 0x4c5f13ee,   // tlh.rm.un_320 ky.ku.ug_433  fy.uz.tr_443 et.tn.wo_422 
  // [1c980]
  0x03003f2a, 0x332f7907, 0x4900130c, 0x563b26ec,   // af.nl.un_970 war.su.nn_432  et.to.un_530 ia.so.mg_644 
  0x4c004004, 0x1e1142ee, 0x5c002507, 0x170a10a9,   // lb.wo.un_320 co.ro.ms_422  eu.sa.un_420 be.mk.sr_544 
  0x3100fe05, 0x2c00571a, 0x25382311, 0x17110804,   // tlh.az.un_330 na.fy.un_760  ky.tk.mn_653 uk.ro.sr_332 
  0x4c2c3fec, 0x40136b04, 0x39374ba7, 0x56490c07,   // af.fy.wo_644 ceb.et.lb_332  mi.st.br_532 sv.to.mg_432 
  // [1c990]
  0x12200812, 0x0a230709, 0x39201ea0, 0x49361fa7,   // no.sq.hu_654 bg.ky.mk_444  ms.sq.br_322 cy.gn.to_532 
  0x4f4c6909, 0x430d1dac, 0x121a3808, 0x38001a07,   // mfe.wo.bi_444 la.cs.ie_632  tk.tl.hu_443 tl.tk.un_420 
  0x691239a9, 0x575c1b0d, 0x60364807, 0x1b072e02,   // br.hu.mfe_544 tr.sa.na_554  tt.gn.vo_432 fo.it.tr_222 
  0x1a793812, 0x3809570d, 0x1a3564a4, 0x02003920,   // tk.war.tl_654 na.pl.tk_554  lg.zu.tl_433 br.da.un_850 
  // [1c9a0]
  0x065e780c, 0x39044312, 0x2300020e, 0x64380204,   // ve.ts.de_543 ie.fi.br_654  da.ca.un_550 da.tk.lg_332 
  0x074d6407, 0x18212804, 0x314830a7, 0x3b3812a6,   // lg.aa.it_432 sd.fa.ar_332  uz.tt.az_532 hu.tk.so_521 
  0x791a10a4, 0x10001221, 0x38006714, 0x64003807,   // lt.tl.war_433 hu.lt.un_860  ak.tk.un_660 tk.lg.un_420 
  0x17002912, 0x120e2eec, 0x480737a0, 0x10380408,   // sl.sr.un_640 fo.is.hu_644  ba.bg.tt_322 ru.tk.be_443 
  // [1c9b0]
  0x73523ba0, 0x10070a0e, 0x1e3f15a4, 0x25114908,   // so.ha.ny_322 mk.bg.be_555  un.af.ms_433 to.ro.eu_443 
  0x783756a4, 0x640251a4, 0x3700250e, 0x09401d07,   // mg.st.ve_433 kl.da.lg_433  mn.ba.un_550 la.lb.pl_432 
  0x2c000904, 0x01063b02, 0x27391f02, 0x4c1f4011,   // pl.fy.un_320 so.de.en_222  cy.br.gd_222 lb.cy.wo_653 
  0x375a30ac, 0x21282307, 0x521504a0, 0x15003702,   // uz.sm.st_632 ky.sd.fa_432  fi.ha.un_320 st.un.un_220 
  // [1c9c0]
  0x341550ee, 0x42001204, 0x041517a0, 0x100a08a4,   // fj.xh.un_420 hu.co.un_320  sr.ru.un_320 uk.mk.be_433 
  0x05003605, 0x0d2205a0, 0x1e001502, 0x30363507,   // gn.fr.un_330 fr.oc.cs_322  un.ms.un_220 tg.ab.uz_432 
  0x05000a09, 0x22420504, 0x0539150c, 0x05392255,   // pt.fr.un_440 fr.co.oc_332  un.br.fr_543 oc.br.fr_442 
  0x372504ee, 0x2f050a04, 0x38122f04, 0x45357307,   // ru.mn.ba_422 pt.fr.su_332  su.hu.tk_332 ny.zu.ln_432 
  // [1c9d0]
  0x75605f08, 0x5e645d02, 0x1d0c2407, 0x3400730e,   // tn.vo.nso_443 ss.lg.ts_222  eo.sv.la_432 ny.xh.un_550 
  0x1a004619, 0x1b313e04, 0x151238ee, 0x19051da0,   // qu.tl.un_750 rm.az.tr_332  tk.hu.un_422 la.fr.gl_322 
  0x353428ec, 0x375f1f13, 0x15002007, 0x1b00602b,   // sw.xh.zu_644 cy.tn.st_665  sq.un.un_420 vo.tr.un_980 
  0x15300404, 0x1b002807, 0x381f01a0, 0x765f37a9,   // ru.uz.un_332 sw.tr.un_420  en.cy.tk_322 st.tn.crs_544 
  // [1c9e0]
  0x53353414, 0x3900760d, 0x3946010c, 0x3100350c,   // xh.zu.ht_666 crs.br.un_540  en.qu.br_543 zu.az.un_530 
  0x2500690c, 0x59005b19, 0x3900370c, 0x3e00730d,   // mfe.eu.un_530 sg.rn.un_750  st.br.un_530 ny.rm.un_540 
  0x3e093902, 0x051822a0, 0x0b0536a0, 0x4a005a0c,   // br.pl.rm_222 oc.ga.fr_322  gn.fr.es_322 sm.yo.un_530 
  0x40002208, 0x2f211c13, 0x464d1ead, 0x395604a0,   // oc.lb.un_430 id.jw.su_665  ms.aa.qu_643 fi.mg.br_322 
  // [1c9f0]
  0x48fc29a7, 0x485339ad, 0x64790404, 0x27391812,   // sl.zzp.tt_532 br.ht.tt_643  fi.war.lg_332 ga.br.gd_654 
  0x640430a0, 0x0e00fc02, 0x354823ee, 0x36115b07,   // uz.fi.lg_322 zzp.is.un_220  ky.tt.tg_422 sg.ro.gn_432 
  0x5b00591a, 0x27003902, 0x010e64a4, 0x0e030608,   // rn.sg.un_760 br.gd.un_220  lg.is.en_433 de.nl.is_443 
  0x64634007, 0x232401af, 0x1050090c, 0x51341305,   // lb.sco.lg_432 en.eo.ca_655  pl.fj.lt_543 et.xh.kl_333 
  // [1ca00]
  0x2a004013, 0x1d5e470c, 0x060e40af, 0x765653a9,   // lb.mt.un_650 sn.ts.la_543  lb.is.de_655 ht.mg.crs_544 
  0x6b002705, 0x480304a0, 0x33222cec, 0x1b3b3113,   // gd.ceb.un_330 fi.nl.tt_322  fy.oc.nn_644 az.so.tr_665 
  0x40581faf, 0x645a3b04, 0x041369a0, 0x40150313,   // cy.om.lb_655 so.sm.lg_332  mfe.et.fi_322 nl.lb.un_650 
  0x04136507, 0x06401f13, 0x185a6408, 0x574d580c,   // gv.et.fi_432 cy.lb.de_665  lg.sm.ga_443 om.aa.na_543 
  // [1ca10]
  0x032c400c, 0x643031a4, 0x071d1507, 0x092a2504,   // lb.fy.nl_543 az.uz.lg_433  un.la.it_432 eu.mt.pl_332 
  0x18000511, 0x475c50a0, 0x39235e08, 0x3b025c0c,   // fr.ga.un_630 fj.sa.sn_322  ts.ca.br_443 sa.da.so_543 
  0x2c0c0e0c, 0x33085cee, 0x3e0f10a9, 0x63404daf,   // is.sv.fy_543 sa.no.nn_422  lt.lv.rm_544 aa.lb.sco_655 
  0x030e400c, 0x5d286304, 0x4035060c, 0x3b251a05,   // lb.is.nl_543 sco.sw.ss_332  de.zu.lb_543 tl.eu.so_333 
  // [1ca20]
  0x041025a7, 0x311b2f02, 0x210522a9, 0x30211213,   // mn.be.ru_532 su.tr.az_222  oc.fr.jw_544 ur.fa.uz_665 
  0x24001502, 0x37153cad, 0x5a4b0213, 0x24090208,   // un.eo.un_220 ug.ba.un_630  da.mi.sm_665 da.pl.eo_443 
  0x375e7507, 0x475d3508, 0x375e5f08, 0x4236055a,   // nso.ts.st_432 zu.ss.sn_443  tn.ts.st_443 fr.gn.co_553 
  0x574502a4, 0x475f3712, 0x08480409, 0x36210408,   // da.ln.na_433 st.tn.sn_654  ru.tt.uk_444 fi.jw.gn_443 
  // [1ca30]
  0x05002110, 0x2f004d12, 0x216b1ba0, 0x382330ec,   // jw.fr.un_620 aa.su.un_640  tr.ceb.jw_322 uz.ky.tk_644 
  0x4a00050c, 0x48170a08, 0x15380404, 0x360518a9,   // fr.yo.un_530 mk.sr.tt_443  ru.tk.un_332 ga.fr.gn_544 
  0x0a37480b, 0x39004010, 0x18004021, 0x4838310b,   // tt.ba.mk_542 lb.br.un_620  lb.ga.un_860 az.tk.tt_542 
  0x1f6b6508, 0x261d1e0c, 0x0540180c, 0x48005b29,   // gv.ceb.cy_443 ms.la.ia_543  ga.lb.fr_543 sg.tt.un_960 
  // [1ca40]
  0x251d1804, 0x1e041ca0, 0x76002f08, 0x1d2d6355,   // ga.la.eu_332 id.fi.ms_322  su.crs.un_430 sco.sk.la_442 
  0x1d1162a7, 0x190b36a6, 0x36350aa4, 0x230417ad,   // kha.ro.la_532 gn.es.gl_521  mk.tg.ab_433 sr.ru.ky_643 
  0x06006307, 0x22001f04, 0x0704540c, 0x1d6026a4,   // sco.de.un_420 cy.oc.un_320  ik.fi.it_543 ia.vo.la_433 
  0x180a055e, 0x0163fe04, 0x014c63ee, 0x171004ad,   // fr.pt.ga_652 tlh.sco.en_332  sco.wo.en_422 ru.be.sr_643 
  // [1ca50]
  0x22203007, 0x05001908, 0x3d34230d, 0x30005208,   // uz.sq.oc_432 gl.fr.un_430  ky.ps.ku_554 ha.uz.un_430 
  0x2118440c, 0x434620ad, 0x683f1dee, 0x20795d04,   // kk.ar.fa_543 sq.qu.ie_643  la.af.ig_422 ss.war.sq_332 
  0x1e212ea0, 0x4042050c, 0x35230a04, 0x0f00fe08,   // fo.jw.ms_322 fr.co.lb_543  mk.ky.tg_332 tlh.lv.un_430 
  0x4c225ba9, 0x224a230d, 0x0602080c, 0x303401ac,   // sg.oc.wo_544 ca.yo.oc_554  no.da.de_543 en.xh.uz_632 
  // [1ca60]
  0x36004a0d, 0x10442355, 0x0e430507, 0x40060fa4,   // yo.gn.un_540 ky.kk.be_442  fr.ie.is_432 lv.de.lb_433 
  0x0c060e05, 0x184205ec, 0x280227a4, 0x27284704,   // is.de.sv_333 fr.co.ga_644  gd.da.sw_433 sn.sw.gd_332 
  0x030f06a7, 0x060e0309, 0x79501a0c, 0x470827a0,   // de.lv.nl_532 nl.is.de_444  tl.fj.war_543 gd.no.sn_322 
  0x1e252707, 0x181e2707, 0x364438ad, 0x527302ec,   // gd.eu.ms_432 gd.ms.ga_432  tk.kk.ab_643 da.ny.ha_644 
  // [1ca70]
  0x180b2707, 0x553773ee, 0x47123602, 0x391505a0,   // gd.es.ga_432 ny.st.rw_422  gn.hu.sn_222 fr.br.un_320 
  0x42220555, 0x5c134709, 0x390215ee, 0x050b0702,   // fr.oc.co_442 sn.et.sa_444  un.da.br_422 it.es.fr_222 
  0x12462707, 0x08370407, 0x323e06ee, 0x281227a0,   // gd.qu.hu_432 ru.ba.uk_432  de.rm.bs_422 gd.hu.sw_322 
  0x353615a4, 0x400a05a0, 0x552515ec, 0x22404312,   // un.ab.tg_433 fr.pt.lb_322  un.eu.rw_644 ie.lb.oc_654 
  // [1ca80]
  0x482325a4, 0x113823ec, 0x651228ee, 0x2710500c,   // mn.ky.tt_433 ky.tk.ro_644  sw.hu.gv_422 fj.lt.gd_543 
  0x495a4f0c, 0x49000702, 0x4f276b07, 0x5e002a2b,   // bi.sm.to_543 it.to.un_220  ceb.gd.bi_432 mt.ts.un_980 
  0x58695212, 0x4e2852a4, 0x523e4702, 0x73003f12,   // ha.mfe.om_654 ha.sw.ay_433  sn.rm.ha_222 af.ny.un_640 
  0x07002718, 0x27495111, 0x2707420c, 0x33000305,   // gd.it.un_740 kl.to.gd_653  co.it.gd_543 nl.nn.un_330 
  // [1ca90]
  0x754c4da9, 0x49245aad, 0x211c2fec, 0x4c7960a0,   // aa.wo.nso_544 sm.eo.to_643  su.id.jw_644 vo.war.wo_322 
  0x1b310655, 0x373b5e0c, 0x3e4b2a07, 0x67114eac,   // de.az.tr_442 ts.so.st_543  mt.mi.rm_432 ay.ro.ak_632 
  0x30443cad, 0x063857ad, 0x5f5a2807, 0x301163a0,   // ug.kk.uz_643 na.tk.de_643  sw.sm.tn_432 sco.ro.uz_322 
  0x1b313013, 0x6008025a, 0x2f3922a4, 0x1b063813,   // uz.az.tr_665 da.no.vo_553  oc.br.su_433 tk.de.tr_665 
  // [1caa0]
  0x15001018, 0x30073cee, 0x044410a4, 0x1b3e31a4,   // be.un.un_740 ug.bg.uz_422  be.kk.ru_433 az.rm.tr_433 
  0x2a000714, 0x02002714, 0x25072a07, 0x49001104,   // it.mt.un_660 gd.da.un_660  mt.it.eu_432 ro.to.un_320 
  0x3523300b, 0x2c003904, 0x1b0613a0, 0x37001007,   // uz.ky.tg_542 br.fy.un_320  et.de.tr_322 be.ba.un_420 
  0x02002a14, 0x5a001104, 0x61622e08, 0x42251107,   // mt.da.un_660 ro.sm.un_320  fo.kha.za_443 ro.eu.co_432 
  // [1cab0]
  0x341228a7, 0x233c21af, 0x11002802, 0x11391da7,   // sd.ur.ps_532 fa.ug.ky_655  sw.ro.un_220 la.br.ro_532 
  0x4b5a11a0, 0x071d11a0, 0x1c112107, 0x11515a0c,   // ro.sm.mi_322 ro.la.it_322  jw.ro.id_432 sm.kl.ro_543 
  0x190a2209, 0x01000605, 0x360411a0, 0x31001304,   // oc.pt.gl_444 de.en.un_330  ro.ru.ab_322 et.az.un_320 
  0x03102e02, 0x10230455, 0x09002a13, 0x5245340c,   // fo.lt.nl_222 ru.ky.be_442  mt.pl.un_650 xh.ln.ha_543 
  // [1cac0]
  0x353428af, 0x38004529, 0x25004534, 0x5d737807,   // sw.xh.zu_655 ln.tk.un_960  ln.eu.un_A80 ve.ny.ss_432 
  0x2f420510, 0x36350408, 0x44003412, 0x31003e13,   // fr.co.su_642 ru.tg.ab_443  ps.kk.un_640 rm.az.un_650 
  0x31005602, 0x08041012, 0x3f1a0302, 0x30353812,   // mg.az.un_220 be.ru.uk_654  nl.tl.af_222 tk.tg.uz_654 
  0x3106130c, 0x40083307, 0x643879ee, 0x1d135107,   // et.de.az_543 nn.no.lb_432  war.tk.lg_422 kl.et.la_432 
  // [1cad0]
  0x06311b08, 0x1f001014, 0x2d1862ec, 0x241e10ad,   // tr.az.de_443 lt.cy.un_660  kha.ga.sk_644 lt.ms.eo_643 
  0x56003308, 0x1d006407, 0x134d5107, 0x79001a20,   // nn.mg.un_430 lg.la.un_420  kl.aa.et_432 tl.war.un_850 
  0x4f0210a0, 0x250251a7, 0x1f034cee, 0x221d0aa0,   // lt.da.bi_322 kl.da.eu_532  wo.nl.cy_422 pt.la.oc_322 
  0x03003e04, 0x05003113, 0x20000308, 0x0f536907,   // rm.nl.un_320 az.fr.un_650  nl.sq.un_430 mfe.ht.lv_432 
  // [1cae0]
  0x1b3138ad, 0x6100031a, 0x1f041007, 0x1b000619,   // tk.az.tr_643 nl.za.un_760  lt.fi.cy_432 de.tr.un_750 
  0x15004908, 0x111b3812, 0x3b0e6005, 0x13393004,   // to.un.un_430 tk.tr.ro_654  vo.is.so_333 uz.br.et_332 
  0x0c026502, 0x222d1da4, 0x393520a0, 0x28101d07,   // gv.da.sv_222 la.sk.oc_433  sq.zu.br_322 la.lt.sw_432 
  0xfe000a0d, 0x031d33a0, 0x20000309, 0x120b0702,   // pt.tlh.un_540 nn.la.nl_322  nl.sq.un_440 it.es.hu_222 
  // [1caf0]
  0x082e3308, 0x3f03610b, 0x1100362b, 0x761f69a9,   // nn.fo.no_443 za.nl.af_542  ab.ro.un_980 mfe.cy.crs_544 
  0x3b00200d, 0x0f000e13, 0x09361008, 0x3e4c60ad,   // sq.so.un_540 is.lv.un_650  lt.gn.pl_443 vo.wo.rm_643 
  0x1745370d, 0x061b3111, 0x2c460311, 0x3b6b100d,   // st.ln.sr_554 az.tr.de_653  nl.qu.fy_653 lt.ceb.so_554 
  0x310560a4, 0x1b311305, 0x2e000223, 0x57001023,   // vo.fr.az_433 et.az.tr_333  da.fo.un_880 lt.na.un_880 
  // [1cb00]
  0x45006004, 0x2f4603a7, 0x032c4607, 0x29004a1a,   // vo.ln.un_320 nl.qu.su_532  qu.fy.nl_432 yo.sl.un_760 
  0x23005714, 0x171510a0, 0x1729100c, 0x55343ba0,   // na.ca.un_660 be.sr.un_320  lt.sl.sr_543 so.xh.rw_322 
  0x591055ad, 0x2d0d3302, 0x15000202, 0x60134805,   // rw.lt.rn_643 nn.cs.sk_222  da.un.un_220 tt.et.vo_333 
  0x1218300c, 0x1827280c, 0x063e3802, 0x473f63ee,   // uz.ar.ur_543 sw.gd.ga_543  tk.rm.de_222 sco.af.sn_422 
  // [1cb10]
  0x38311b55, 0x35113005, 0x18220507, 0x0837040c,   // tr.az.tk_442 uz.ro.tg_333  fr.oc.ga_432 ru.ba.uk_543 
  0x103523a0, 0x30073507, 0x44104807, 0x2400610d,   // ky.tg.be_322 tg.bg.uz_432  tt.be.kk_432 za.eo.un_540 
  0x5057520e, 0x3800130d, 0x5700531a, 0x233b130c,   // ha.na.fj_555 et.tk.un_540  ht.na.un_760 et.so.ca_543 
  0x43304f11, 0x311050a6, 0x4a505213, 0x52006420,   // bi.uz.ie_653 fj.lt.az_521  ha.fj.yo_665 lg.ha.un_850 
  // [1cb20]
  0x074404ee, 0x6b1a6005, 0x306564ad, 0x1b000213,   // ru.kk.bg_422 vo.tl.ceb_333  lg.gv.uz_643 da.tr.un_650 
  0x1bfc3055, 0x67584da4, 0x4b005504, 0x4d25520c,   // uz.zzp.tr_442 aa.om.ak_433  rw.mi.un_320 ha.eu.aa_543 
  0x16733007, 0x5e00641a, 0x472827a0, 0x35006420,   // uz.ny.hr_432 lg.ts.un_760  gd.sw.sn_322 lg.zu.un_850 
  0x044513ec, 0x47002b04, 0x126461af, 0x4f006707,   // et.ln.fi_644 vi.sn.un_320  za.lg.hu_655 ak.bi.un_420 
  // [1cb30]
  0x55004b02, 0x39191da0, 0x133057a4, 0x08101555,   // mi.rw.un_220 la.gl.br_322  na.uz.et_433 un.be.uk_442 
  0x553b330c, 0x38000b05, 0x3534670e, 0x55005a08,   // nn.so.rw_543 es.tk.un_330  ak.xh.zu_555 sm.rw.un_430 
  0x1a3547ee, 0x73005c09, 0x5e001f0d, 0x0844380c,   // sn.zu.tl_422 sa.ny.un_440  cy.ts.un_540 tk.kk.uk_543 
  0x58002707, 0x3d21345a, 0x420227a9, 0x151036af,   // gd.om.un_420 ps.fa.ku_553  gd.da.co_544 ab.be.un_655 
  // [1cb40]
  0x2344110d, 0x1d634604, 0x17380aaf, 0x2d001111,   // ro.kk.ky_554 qu.sco.la_332  mk.tk.sr_655 ro.sk.un_630 
  0x2c046507, 0x1c1e2107, 0x434d1e0c, 0x08053607,   // gv.fi.fy_432 jw.ms.id_432  ms.aa.ie_543 gn.fr.no_432 
  0x51001113, 0x1c121ea9, 0x08381704, 0x3f000d0d,   // ro.kl.un_650 ms.hu.id_544  sr.tk.uk_332 cs.af.un_540 
  0x4c211c0d, 0x6e1246a0, 0x043951a6, 0x4d1d1ea9,   // id.jw.wo_554 qu.hu.hmn_322  kl.br.fi_521 ms.la.aa_544 
  // [1cb50]
  0x2343110e, 0x392f3e07, 0x12250da4, 0x4d301e0c,   // ro.ie.ca_555 rm.su.br_432  cs.eu.hu_433 ms.uz.aa_543 
  0x1e6e1007, 0x5c0d040d, 0x42100711, 0x022e0855,   // lt.hmn.ms_432 fi.cs.sa_554  it.lt.co_653 no.fo.da_442 
  0x2a222360, 0x33005412, 0x4f511e0c, 0x1a1e1caf,   // ca.oc.mt_664 ik.nn.un_640  ms.kl.bi_543 id.ms.tl_655 
  0x3151300c, 0x5c2534a0, 0x10001a05, 0x513f10a0,   // uz.kl.az_543 xh.eu.sa_322  tl.lt.un_330 lt.af.kl_322 
  // [1cb60]
  0x12001f02, 0x170423a0, 0x12092da7, 0x67001f1b,   // cy.hu.un_220 ky.ru.sr_322  sk.pl.hu_532 cy.ak.un_770 
  0x1723100e, 0x032f100c, 0x07261d07, 0x62510107,   // be.ky.sr_555 lt.su.nl_543  la.ia.it_432 en.kl.kha_432 
  0x1d560404, 0x0b123607, 0x234810a0, 0x151508a4,   // fi.mg.la_332 gn.hu.es_432  be.tt.ky_322 uk.un.un_430 
  0x032f3f02, 0x4c00790c, 0x4a2e0ea4, 0x084410a7,   // af.su.nl_222 war.wo.un_530  is.fo.yo_433 be.kk.uk_532 
  // [1cb70]
  0x3100060c, 0x0a150708, 0x28005307, 0x12322002,   // de.az.un_530 bg.mk.un_430  ht.sw.un_420 sq.bs.hu_222 
  0x23073e02, 0x121730ee, 0x1b3130a0, 0x044410a7,   // rm.it.ca_222 uz.sr.hu_422  uz.az.tr_322 be.kk.ru_532 
  0x1d3726a7, 0x21123da7, 0x2e0e35a0, 0x56500107,   // ia.st.la_532 ku.ur.fa_532  zu.is.fo_322 en.fj.mg_432 
  0x0c005a18, 0x6a000409, 0x754750ad, 0x6515010c,   // sm.sv.un_740 fi.haw.un_440  fj.sn.nso_643 en.gv.un_530 
  // [1cb80]
  0x33520807, 0x523b600c, 0x37605fa4, 0x3e0c1502,   // no.ha.nn_432 vo.so.ha_543  tn.vo.st_433 un.sv.rm_222 
  0x3f00150e, 0x48381b04, 0x564d05ad, 0x5c4c3b0c,   // un.af.un_550 tr.tk.tt_332  fr.aa.mg_643 so.wo.sa_543 
  0x0f561008, 0x252e56a0, 0x4a755fa4, 0x022b3e0c,   // lt.mg.lv_443 mg.fo.eu_322  tn.nso.yo_433 rm.vi.da_543 
  0x17555c55, 0x1b002812, 0x473564ad, 0x645e670c,   // sa.rw.sr_442 sw.tr.un_640  lg.zu.sn_643 ak.ts.lg_543 
  // [1cb90]
  0x443007a0, 0x315e30a4, 0x30330804, 0x31321704,   // bg.uz.kk_322 uz.ts.az_433  no.nn.uz_332 sr.bs.az_332 
  0x390430a4, 0x593435ad, 0x05004904, 0x2100060b,   // uz.fi.br_433 zu.xh.rn_643  to.fr.un_320 de.jw.un_520 
  0x080e2aa6, 0x533225a0, 0x36003408, 0x52004a02,   // mt.is.no_521 eu.bs.ht_322  xh.gn.un_430 yo.ha.un_220 
  0x35213fa0, 0x6e000619, 0x150627a9, 0x76011da4,   // af.jw.zu_322 de.hmn.un_750  gd.de.un_544 la.en.crs_433 
  // [1cba0]
  0x0600291a, 0x0f1006a9, 0x1b1e2fa0, 0x2d0d06ec,   // sl.de.un_760 de.lt.lv_544  su.ms.tr_322 de.cs.sk_644 
  0x190b2fa9, 0x1a6301a7, 0xfc000608, 0x1c402fa0,   // su.es.gl_544 en.sco.tl_532  de.zzp.un_430 su.lb.id_322 
  0x1d001521, 0x15074804, 0x0a1504a0, 0xfc0301a4,   // un.la.un_860 tt.bg.un_332  ru.mk.un_320 en.nl.zzp_433 
  0x46004b0e, 0x1b002504, 0x63043ba9, 0x2b005c02,   // mi.qu.un_550 eu.tr.un_320  so.fi.sco_544 sa.vi.un_220 
  // [1cbb0]
  0x571d06ac, 0xfa003414, 0x150748a0, 0x406106ec,   // de.la.na_632 xh.nr.un_660  tt.bg.un_322 de.za.lb_644 
  0x300306ad, 0x0d0657a4, 0x28002a07, 0x487861a9,   // de.nl.uz_643 na.de.cs_433  mt.sw.un_420 za.ve.tt_544 
  0x42615207, 0x1f1012af, 0x34025504, 0x670208a9,   // ha.za.co_432 hu.lt.cy_655  rw.da.xh_332 no.da.ak_544 
  0x6900131a, 0x64455104, 0x19070aec, 0x766301a4,   // et.mfe.un_760 kl.ln.lg_332  pt.it.gl_644 en.sco.crs_433 
  // [1cbc0]
  0x07422cee, 0x052333a4, 0x0200611b, 0x4c00670c,   // fy.co.it_422 nn.ca.fr_433  za.da.un_770 ak.wo.un_530 
  0x2c3b5804, 0x353442a0, 0x69180807, 0x45006121,   // om.so.fy_332 co.xh.zu_322  no.ga.mfe_432 za.ln.un_860 
  0x2a19180c, 0x48252307, 0x31651804, 0x17380707,   // ga.gl.mt_543 ky.mn.tt_432  ga.gv.az_332 bg.tk.sr_432 
  0x0b0742a7, 0x42113e0d, 0x2c475d0b, 0x3f6301a7,   // co.it.es_532 rm.ro.co_554  ss.sn.fy_542 en.sco.af_532 
  // [1cbd0]
  0x2b004905, 0x043623ee, 0x27224aa7, 0x25041002,   // to.vi.un_330 ky.ab.ru_422  yo.oc.gd_532 be.ru.mn_222 
  0x303423a7, 0x2f190b08, 0x3c34440c, 0x1213380c,   // ky.ps.uz_532 es.gl.su_443  kk.ps.ug_543 tk.et.hu_543 
  0x30231555, 0x080227a4, 0x336301a0, 0x03333f07,   // un.ky.uz_442 gd.da.no_433  en.sco.nn_322 af.nn.nl_432 
  0x01003e07, 0x0300020b, 0x21003c09, 0x0100260c,   // rm.en.un_420 da.nl.un_520  ug.fa.un_440 ia.en.un_530 
  // [1cbe0]
  0x371723a0, 0x1d074207, 0x51004208, 0x3c344405,   // ky.sr.ba_322 co.it.la_432  co.kl.un_430 kk.ps.ug_333 
  0x2325370c, 0x190b02ee, 0x016357ee, 0x40002b04,   // ba.mn.ky_543 da.es.gl_422  na.sco.en_422 vi.lb.un_320 
  0x4c2b40a0, 0x48381302, 0x0730350d, 0x1d005005,   // lb.vi.wo_322 et.tk.tt_222  tg.uz.bg_554 fj.la.un_330 
  0x023940ee, 0x19004205, 0x122f4a07, 0xfc5d76a0,   // lb.br.da_422 co.gl.un_330  yo.su.hu_432 crs.ss.zzp_322 
  // [1cbf0]
  0x43185007, 0x35483c09, 0x39402b02, 0x28000f07,   // fj.ga.ie_432 ug.tt.tg_444  vi.lb.br_222 lv.sw.un_420 
  0x3f630f04, 0x122b19ad, 0x11034312, 0x39001108,   // lv.sco.af_332 gl.vi.hu_643  ie.nl.ro_654 ro.br.un_430 
  0x02030f07, 0x63000213, 0x6300480d, 0x01113e08,   // lv.nl.da_432 da.sco.un_650  tt.sco.un_540 rm.ro.en_443 
  0x150a07a9, 0x63110304, 0x11000322, 0x1a001004,   // bg.mk.un_544 nl.ro.sco_332  nl.ro.un_870 lt.tl.un_320 
  
  // [1cc00]
  0x021a3f0d, 0xfc004708, 0x29003e0b, 0x06003b0c,   // af.tl.da_554 sn.zzp.un_430  rm.sl.un_520 so.de.un_530 
  0x5000630d, 0xfc024a04, 0x6b00541a, 0x3b063f0c,   // sco.fj.un_540 yo.da.zzp_332  ik.ceb.un_760 af.de.so_543 
  0x11052da0, 0x6b00470d, 0x7300460c, 0x6b5047ec,   // sk.fr.ro_322 sn.ceb.un_540  qu.ny.un_530 sn.fj.ceb_644 
  0x03001113, 0x1200450d, 0x1a002702, 0x34644702,   // ro.nl.un_650 ln.hu.un_540  gd.tl.un_220 sn.lg.xh_222 
  // [1cc10]
  0x300e2ea0, 0x586752ad, 0x442504a9, 0x520833ee,   // fo.is.uz_322 ha.ak.om_643  ru.mn.kk_544 nn.no.ha_422 
  0x287367ee, 0x6239560c, 0x0d002a0d, 0x21003c12,   // ak.ny.sw_422 mg.br.kha_543  mt.cs.un_540 ug.fa.un_640 
  0x3e003204, 0x0c526704, 0x024d3fec, 0x0d0f2d0c,   // bs.rm.un_320 ak.ha.sv_332  af.aa.da_644 sk.lv.cs_543 
  0x02003f1a, 0xfc1d61a7, 0x37000209, 0x35000912,   // af.da.un_760 za.la.zzp_532  da.st.un_440 pl.zu.un_640 
  // [1cc20]
  0x11005212, 0x02003f08, 0x1600fe0c, 0x17680cee,   // ha.ro.un_640 af.da.un_430  tlh.hr.un_530 sv.ig.sr_422 
  0x5123110c, 0x6000010d, 0x311b4f0d, 0x471cfea0,   // ro.ca.kl_543 en.vo.un_540  bi.tr.az_554 tlh.id.sn_322 
  0x333e39a0, 0x36504909, 0x0d13fead, 0x1d001e04,   // br.rm.nn_322 to.fj.gn_444  tlh.et.cs_643 ms.la.un_320 
  0x3645055a, 0x17000c04, 0x2c002a12, 0x0415170d,   // fr.ln.gn_553 sv.sr.un_320  mt.fy.un_640 sr.ru.un_540 
  // [1cc30]
  0x38007908, 0x12004a18, 0x2f4a12a7, 0x2d00240d,   // war.tk.un_430 yo.hu.un_740  hu.yo.su_532 eo.sk.un_540 
  0x0d2d240c, 0x100a1705, 0x213418a0, 0x3600250c,   // eo.sk.cs_543 sr.mk.be_333  ar.ps.fa_322 eu.gn.un_530 
  0x56004d18, 0x52002807, 0x21392fa9, 0x2f214c05,   // aa.mg.un_740 sw.ha.un_420  su.br.jw_544 wo.jw.su_333 
  0x4b001304, 0x361515ee, 0x2415670c, 0x122f210d,   // et.mi.un_320 un.ab.un_420  ak.eo.un_530 jw.su.hu_554 
  // [1cc40]
  0x20006305, 0x76002005, 0x34003c0b, 0x16203308,   // sco.sq.un_330 sq.crs.un_330  ug.ps.un_520 nn.sq.hr_443 
  0x233f02a4, 0x09112da4, 0x442317ee, 0x4800510c,   // da.af.ca_433 sk.ro.pl_433  sr.ky.kk_422 kl.tt.un_530 
  0x6773200c, 0x391d02ad, 0x5d3320ee, 0x0f001f02,   // sq.ny.ak_543 da.la.br_643  sq.nn.ss_422 cy.lv.un_220 
  0x234837ec, 0x530d4c07, 0x212f4c02, 0x28341204,   // ba.tt.ky_644 wo.cs.ht_432  wo.su.jw_222 ur.ps.sd_332 
  // [1cc50]
  0x28213d5a, 0x05430a04, 0x23351702, 0x17000414,   // ku.fa.sd_553 pt.ie.fr_332  sr.tg.ky_222 ru.sr.un_660 
  0x122f2109, 0x2f4021a0, 0x05001108, 0x30123408,   // jw.su.hu_444 jw.lb.su_322  ro.fr.un_430 ps.ur.uz_443 
  0x11003f13, 0x4c085d07, 0x11003f05, 0x3f1105a4,   // af.ro.un_650 ss.no.wo_432  af.ro.un_330 fr.ro.af_433 
  0x11000508, 0x27652cad, 0x58112704, 0x27fc11a9,   // fr.ro.un_430 fy.gv.gd_643  gd.ro.om_332 ro.zzp.gd_544 
  // [1cc60]
  0x071d69a4, 0x176b1d10, 0x79420905, 0x3e225804,   // mfe.la.it_433 la.ceb.sr_642  pl.co.war_333 om.oc.rm_332 
  0x120e4c5a, 0x390603ee, 0x10481505, 0x03060409,   // wo.is.hu_553 nl.de.br_422  un.tt.be_333 fi.de.nl_444 
  0x0206080c, 0x375e65a7, 0x06033907, 0x4c000e0d,   // no.de.da_543 gv.ts.st_532  br.nl.de_432 is.wo.un_540 
  0x10153c07, 0x3d3418ad, 0x03001205, 0x391046a4,   // ug.be.un_420 ar.ps.ku_643  hu.nl.un_330 qu.lt.br_433 
  // [1cc70]
  0x042c03a0, 0x2d00630c, 0x6b020507, 0x06002005,   // nl.fy.fi_322 sco.sk.un_530  fr.da.ceb_432 sq.de.un_330 
  0x05006307, 0x073f1111, 0x29001b09, 0x30442109,   // sco.fr.un_420 ro.af.it_653  tr.sl.un_440 fa.kk.uz_444 
  0x2f5568a0, 0x1d07260c, 0x472f5e07, 0x1200211b,   // ig.rw.su_322 ia.it.la_543  ts.su.sn_432 fa.ur.un_770 
  0x10042508, 0x17480aa6, 0x203642ee, 0x17594707,   // mn.ru.be_443 mk.tt.sr_521  co.gn.sq_422 sn.rn.sr_432 
  // [1cc80]
  0x443023af, 0x35482007, 0x1b003820, 0x32172009,   // ky.uz.kk_655 sq.tt.zu_432  tk.tr.un_850 sq.sr.bs_444 
  0x1d17360c, 0x38fe3307, 0x311b3811, 0x64734713,   // gn.sr.la_543 nn.tlh.tk_432  tk.tr.az_653 sn.ny.lg_665 
  0x480838ad, 0x59007308, 0x091b3108, 0x2a001b07,   // tk.uk.tt_643 ny.rn.un_430  az.tr.pl_443 tr.mt.un_420 
  0xfc00640c, 0x28233da0, 0x6400590d, 0x64006514,   // lg.zzp.un_530 ku.ky.sd_322  rn.lg.un_540 gv.lg.un_660 
  // [1cc90]
  0x1a2a6ba7, 0x0d004a19, 0x402758a0, 0x60392a07,   // ceb.mt.tl_532 yo.cs.un_750  om.gd.lb_322 mt.br.vo_432 
  0x0d470fa6, 0x2b6b010b, 0x1d003b0d, 0x35006807,   // lv.sn.cs_521 en.ceb.vi_542  so.la.un_540 ig.zu.un_420 
  0x32160fec, 0x3376695a, 0x594768a4, 0x3d2128a4,   // lv.hr.bs_644 mfe.crs.nn_553  ig.sn.rn_433 sd.fa.ku_433 
  0x21183b07, 0x4000461b, 0x58004012, 0x58002104,   // ks.ar.fa_432 qu.lb.un_770  lb.om.un_640 jw.om.un_320 
  // [1cca0]
  0x3e2e6504, 0x3e004309, 0x48081008, 0x2537480b,   // gv.fo.rm_332 ie.rm.un_440  be.uk.tt_443 tt.ba.mn_542 
  0x30002c04, 0x40005d04, 0x46001b09, 0x151011a4,   // fy.uz.un_320 ss.lb.un_320  tr.qu.un_440 ro.be.un_433 
  0x0436110b, 0x4a0d450c, 0x10251507, 0x16130404,   // ro.ab.ru_542 ln.cs.yo_543  un.mn.be_432 fi.et.hr_332 
  0x0e00fc04, 0x30001012, 0x2d002212, 0x07363cad,   // zzp.is.un_320 be.uz.un_640  oc.sk.un_640 ug.ab.bg_643 
  // [1ccb0]
  0x48364407, 0x11234813, 0x0e003f14, 0x0a003811,   // kk.ab.tt_432 tt.ky.ro_665  af.is.un_660 tk.mk.un_630 
  0x381044af, 0x0d0540ee, 0x0d004307, 0x0d004a0d,   // kk.be.tk_655 lb.fr.cs_422  ie.cs.un_420 yo.cs.un_540 
  0x3635150d, 0x03006304, 0x11033f0c, 0x3f00050e,   // un.tg.ab_554 sco.nl.un_320  af.nl.ro_543 fr.af.un_550 
  0x2d006307, 0x07003908, 0x3f002d05, 0x3f00370e,   // sco.sk.un_420 br.it.un_430  sk.af.un_330 st.af.un_550 
  // [1ccc0]
  0x4815380b, 0x693f03a4, 0x03633f09, 0x2d003f14,   // tk.tt.un_520 nl.af.mfe_433  af.sco.nl_444 af.sk.un_660 
  0x110522a0, 0x15282f07, 0x1b123e05, 0x173707a0,   // oc.fr.ro_322 su.sw.un_432  rm.hu.tr_333 bg.ba.sr_322 
  0x4d65300c, 0x1a00790c, 0xfcfe1707, 0x631f6511,   // uz.gv.aa_543 war.tl.un_530  sr.tlh.zzp_432 gv.cy.sco_653 
  0x6e001022, 0x17083004, 0x631d4255, 0x1300fe08,   // lt.hmn.un_870 uz.uk.sr_332  co.la.sco_442 tlh.et.un_430 
  // [1ccd0]
  0x461b23a4, 0x1351fc05, 0x11fe5b07, 0x23514604,   // ca.tr.qu_433 zzp.kl.et_333  sg.tlh.ro_432 qu.kl.ca_332 
  0x30213ba6, 0x63651fa7, 0x63400607, 0x1d000512,   // so.jw.uz_521 cy.gv.sco_532  de.lb.sco_432 fr.la.un_640 
  0x2100050e, 0x650c0907, 0x45121305, 0x272253ec,   // fr.jw.un_550 pl.sv.gv_432  et.hu.ln_333 ht.oc.gd_644 
  0x2d172907, 0x2a3b34a7, 0x4a1218a4, 0x2ffe3b55,   // sl.sr.sk_432 xh.so.mt_532  ga.hu.yo_433 so.tlh.su_442 
  // [1cce0]
  0x305cfeee, 0x3d3b1255, 0x1a137307, 0x2d000f11,   // tlh.sa.uz_422 ur.ks.ku_442  ny.et.tl_432 lv.sk.un_630 
  0x0500400c, 0x135c0d09, 0x37215ea0, 0x493450a4,   // lb.fr.un_530 ne.sa.bh_444  ts.jw.st_322 fj.xh.to_433 
  0x477318af, 0x39007319, 0x220a2e0c, 0x2b000a07,   // ga.ny.sn_655 ny.br.un_750  fo.pt.oc_543 pt.vi.un_420 
  0x03006207, 0x0500180c, 0x13221d05, 0x4c001d12,   // kha.nl.un_420 ga.fr.un_530  la.oc.et_333 la.wo.un_640 
  // [1ccf0]
  0x2334120d, 0x31000a02, 0x27002c02, 0x07040812,   // ur.ps.ky_554 pt.az.un_220  fy.gd.un_220 uk.ru.bg_654 
  0x3b5c2711, 0x1811270c, 0x27005c1a, 0xfc001007,   // gd.sa.so_653 gd.ro.ga_543  sa.gd.un_760 lt.zzp.un_420 
  0x18000207, 0x270918a4, 0x025d30a4, 0x12230dee,   // da.ga.un_420 ga.pl.gd_433  uz.ss.da_433 cs.ca.hu_422 
  0x341501a4, 0x100a350c, 0x1a3b5404, 0x20004c18,   // en.xh.un_430 tg.mk.be_543  ik.so.tl_332 wo.sq.un_740 
  // [1cd00]
  0x3b581ea4, 0x102325a7, 0x37251ba4, 0x44112308,   // ms.om.so_433 mn.ky.be_532  tr.eu.st_433 ky.ro.kk_443 
  0x5000fc02, 0x02565c0c, 0x22001e04, 0x5955580e,   // zzp.fj.un_220 sa.mg.da_543  ms.oc.un_320 om.rw.rn_555 
  0x2f3b5c08, 0x245f1e0b, 0x133e650c, 0x394c360c,   // sa.so.su_443 ms.tn.eo_542  gv.rm.et_543 gn.wo.br_543 
  0x4c525609, 0x4a4d4f0c, 0x33002c0c, 0x443615a0,   // mg.ha.wo_444 bi.aa.yo_543  fy.nn.un_530 un.ab.kk_322 
  // [1cd10]
  0x36151507, 0x193905a0, 0x762101a4, 0x370a0804,   // un.ab.un_420 fr.br.gl_322  en.jw.crs_433 uk.mk.ba_332 
  0x31203b07, 0xfe044fad, 0x2f214609, 0x0c004609,   // so.sq.az_432 bi.fi.tlh_643  qu.jw.su_444 qu.sv.un_440 
  0x20004c29, 0x10231504, 0x2818125a, 0x3d2344a7,   // wo.sq.un_960 un.ky.be_332  ur.ar.sd_553 kk.ky.ku_532 
  0x21001b02, 0x170835a4, 0x370a170c, 0x5d365ca4,   // tr.jw.un_220 tg.uk.sr_433  sr.mk.ba_543 sa.gn.ss_433 
  // [1cd20]
  0x5d2902a4, 0x5f00372b, 0x336420a0, 0x092d0d0b,   // da.sl.ss_433 st.tn.un_980  sq.lg.nn_322 cs.sk.pl_542 
  0x366a4b11, 0x291d26a4, 0x5f736407, 0x495d3502,   // mi.haw.gn_653 ia.la.sl_433  lg.ny.tn_432 zu.ss.to_222 
  0x26006014, 0x191b47a0, 0x363e470c, 0x2616130c,   // vo.ia.un_660 sn.tr.gl_322  sn.rm.gn_543 et.hr.ia_543 
  0x162950ee, 0x181138a0, 0x32004711, 0x321855a4,   // fj.sl.hr_422 tk.ro.ga_322  sn.bs.un_630 rw.ga.bs_433 
  // [1cd30]
  0x5e002304, 0x073642ee, 0x322960ee, 0x5500281a,   // ca.ts.un_320 co.gn.it_422  vo.sl.bs_422 sw.rw.un_760 
  0x55004721, 0x07004908, 0x24290708, 0x16360407,   // sn.rw.un_860 to.it.un_430  it.sl.eo_443 fi.gn.hr_432 
  0x28295507, 0xfc00fe12, 0x17293604, 0x152c01a4,   // rw.sl.sw_432 tlh.zzp.un_640  gn.sl.sr_332 en.fy.un_433 
  0x070435a7, 0x4d00460c, 0x2c005814, 0x29000f0e,   // tg.ru.bg_532 qu.aa.un_530  om.fy.un_660 lv.sl.un_550 
  // [1cd40]
  0xfe304da0, 0x0c1009a4, 0x5b423fa4, 0x243f63a7,   // aa.uz.tlh_322 pl.lt.sv_433  af.co.sg_433 sco.af.eo_532 
  0x20005d08, 0x30330c07, 0x01124ba0, 0x38132402,   // ss.sq.un_430 sv.nn.uz_432  mi.hu.en_322 eo.et.tk_222 
  0x250e48a7, 0x300e48a7, 0x5a00490e, 0x2c3f03a4,   // tt.is.eu_532 tt.is.uz_532  to.sm.un_550 nl.af.fy_433 
  0x02534b11, 0x49530107, 0x04191108, 0x09423fa9,   // mi.ht.da_653 en.ht.to_432  ro.gl.fi_443 af.co.pl_544 
  // [1cd50]
  0x63054308, 0x05004310, 0x69005308, 0x22003608,   // ie.fr.sco_443 ie.fr.un_620  ht.mfe.un_430 gn.oc.un_430 
  0x2d002a0c, 0x15111708, 0x0d4b530c, 0x78373ea4,   // mt.sk.un_530 sr.ro.un_443  ht.mi.cs_543 rm.st.ve_433 
  0x6e00241a, 0x534905ec, 0x430545a4, 0x24006e22,   // eo.hmn.un_760 fr.to.ht_644  ln.fr.ie_433 hmn.eo.un_870 
  0x1b002104, 0x1c122f0c, 0x38481b55, 0x12100f08,   // jw.tr.un_320 su.hu.id_543  tr.tt.tk_442 lv.lt.hu_443 
  // [1cd60]
  0x443704af, 0x436e2412, 0x2a000c08, 0x25071007,   // ru.ba.kk_655 eo.hmn.ie_654  sv.mt.un_430 be.bg.mn_432 
  0x1c004802, 0x254844af, 0x0b0a36ac, 0x301036a6,   // tt.id.un_220 kk.tt.mn_655  gn.pt.es_632 ab.be.uz_521 
  0x30183ba4, 0x060e36ee, 0x36483712, 0x211e1b07,   // ks.ar.uz_433 gn.is.de_422  ba.tt.ab_654 tr.ms.jw_432 
  0x081738a6, 0x32290fa4, 0x5c271813, 0x44303511,   // tk.sr.uk_521 lv.sl.bs_433  ga.gd.sa_665 tg.uz.kk_653 
  // [1cd70]
  0x5c271804, 0x3e003104, 0x0500600d, 0x053e4060,   // ga.gd.sa_332 az.rm.un_320  vo.fr.un_540 lb.rm.fr_664 
  0x182729ad, 0x10480455, 0x08000f12, 0x271f630c,   // sl.gd.ga_643 ru.tt.be_442  lv.no.un_640 sco.cy.gd_543 
  0x233e60ad, 0x042d0d0d, 0x236001a4, 0x473032a4,   // vo.rm.ca_643 cs.sk.fi_554  en.vo.ca_433 bs.uz.sn_433 
  0x1a73510c, 0x3529600c, 0x3e05600c, 0x121b3804,   // kl.ny.tl_543 vo.sl.zu_543  vo.fr.rm_543 tk.tr.hu_332 
  // [1cd80]
  0x4f6715a0, 0x1805600c, 0x12561f5a, 0x3549500c,   // un.ak.bi_322 vo.fr.ga_543  cy.mg.hu_553 fj.to.zu_543 
  0x602205a4, 0x22050107, 0x25675508, 0x765301a0,   // fr.oc.vo_433 en.fr.oc_432  rw.ak.eu_443 en.ht.crs_322 
  0x69766011, 0x44213d02, 0x12550904, 0x355564ee,   // vo.crs.mfe_653 ku.fa.kk_222  pl.rw.hu_332 lg.rw.zu_422 
  0x25344cad, 0x0b23190d, 0x53001207, 0x736450a4,   // wo.xh.eu_643 gl.ca.es_554  hu.ht.un_420 fj.lg.ny_433 
  // [1cd90]
  0x08101112, 0x0c060e04, 0x025125a7, 0x2d091aaf,   // ro.be.uk_654 is.de.sv_332  eu.kl.da_532 tl.pl.sk_655 
  0x69387605, 0x51005811, 0x25fc365a, 0x0436170d,   // crs.tk.mfe_333 om.kl.un_630  gn.zzp.eu_553 sr.ab.ru_554 
  0x1b1f7812, 0x322d29a7, 0x22005605, 0xfc251311,   // ve.cy.tr_654 sl.sk.bs_532  mg.oc.un_330 et.eu.zzp_653 
  0x0c400a07, 0x09231904, 0x092d20a0, 0x535c10a4,   // pt.lb.sv_432 gl.ca.pl_332  sq.sk.pl_322 lt.sa.ht_433 
  // [1cda0]
  0x12fc46a4, 0x48373005, 0x07042305, 0x456428ad,   // qu.zzp.hu_433 uz.ba.tt_333  ky.ru.bg_333 sw.lg.ln_643 
  0x480437a9, 0x73470955, 0x04005c19, 0x0400131d,   // ba.ru.tt_544 pl.sn.ny_442  sa.fi.un_750 et.fi.un_820 
  0x02042e07, 0x045c02a0, 0x11006408, 0x04425c05,   // fo.fi.da_432 da.sa.fi_322  lg.ro.un_430 sa.co.fi_333 
  0x392e5c09, 0xfe394f12, 0xfc002304, 0x311b0c07,   // sa.fo.br_444 bi.br.tlh_654  ca.zzp.un_320 sv.tr.az_432 
  // [1cdb0]
  0x33083baf, 0x30022a02, 0x643b52a4, 0x63522908,   // so.no.nn_655 mt.da.uz_222  ha.so.lg_433 sl.ha.sco_443 
  0x08005608, 0x4c2a52ad, 0x311b4d09, 0x094252a0,   // mg.no.un_430 ha.mt.wo_643  aa.tr.az_444 ha.co.pl_322 
  0x0c6301a4, 0x1ffe64a7, 0xfe007820, 0x38300204,   // en.sco.sv_433 lg.tlh.cy_532  ve.tlh.un_850 da.uz.tk_332 
  0x3b644da9, 0x392e5ca0, 0x1807420b, 0x5cfc0c09,   // aa.lg.so_544 sa.fo.br_322  co.it.ga_542 sv.zzp.sa_444 
  // [1cdc0]
  0x39006419, 0x07fc51a9, 0x4a000a12, 0x52584d0c,   // lg.br.un_750 kl.zzp.it_544  pt.yo.un_640 aa.om.ha_543 
  0x316452ad, 0x2a00510d, 0x4000670d, 0x4f005d08,   // ha.lg.az_643 kl.mt.un_540  ak.lb.un_540 ss.bi.un_430 
  0x1f004d0d, 0x3b5c01a0, 0x3b2a4d0c, 0x12426507,   // aa.cy.un_540 en.sa.so_322  aa.mt.so_543 gv.co.hu_432 
  0x67000914, 0x425c4d0c, 0x05007607, 0x482e33a0,   // pl.ak.un_660 aa.sa.co_543  crs.fr.un_420 nn.fo.tt_322 
  // [1cdd0]
  0x3e065709, 0x78005e13, 0x300a07a7, 0x133e06ee,   // na.de.rm_444 ts.ve.un_650  bg.mk.uz_532 de.rm.et_422 
  0x5300fe19, 0x37234804, 0x2000620c, 0x304823a9,   // tlh.ht.un_750 tt.ky.ba_332  kha.sq.un_530 ky.tt.uz_544 
  0x3302fead, 0x08103702, 0x083007a4, 0x064057a7,   // tlh.da.nn_643 ba.be.uk_222  bg.uz.uk_433 na.lb.de_532 
  0x082307a0, 0x350e29a0, 0x4408100e, 0x1008150e,   // bg.ky.uk_322 sl.is.zu_322  be.uk.kk_555 un.uk.be_555 
  // [1cde0]
  0x2300340e, 0x18004a0d, 0x101b46a4, 0x4838440c,   // ps.ky.un_550 yo.ga.un_540  qu.tr.lt_433 kk.tk.tt_543 
  0x0e2e45a7, 0x0e3530a7, 0x5a1a4aa7, 0x2a732807,   // ln.fo.is_532 uz.zu.is_532  yo.tl.sm_532 sw.ny.mt_432 
  0x450413a9, 0x2e0802a0, 0x5e736408, 0x2f2145a9,   // et.fi.ln_544 da.no.fo_322  lg.ny.ts_443 ln.jw.su_544 
  0x253745ec, 0x61001b14, 0x5f5e5213, 0x5a13280c,   // ln.st.eu_644 tr.za.un_660  ha.ts.tn_665 sw.et.sm_543 
  // [1cdf0]
  0x233748ec, 0x174404ec, 0x15233813, 0x0e025104,   // tt.ba.ky_644 ru.kk.sr_644  tk.ky.un_665 kl.da.is_332 
  0x03000508, 0x1500431b, 0x111d5704, 0x2200fe08,   // fr.nl.un_430 ie.un.un_770  na.la.ro_332 tlh.oc.un_430 
  0x4844100b, 0x551a4609, 0x28647307, 0x233038a7,   // be.kk.tt_542 qu.tl.rw_444  ny.lg.sw_432 tk.uz.ky_532 
  0x5830510d, 0x3b003f04, 0x3f1506ee, 0x0f1210a0,   // kl.uz.om_554 af.so.un_320  de.af.un_420 lt.hu.lv_322 
  // [1ce00]
  0x10044407, 0x10040a0d, 0x34126404, 0x44170a12,   // kk.ru.be_432 mk.ru.be_554  lg.hu.xh_332 mk.sr.kk_654 
  0x4600300c, 0x48305107, 0x12003f19, 0x50005a12,   // uz.qu.un_530 kl.uz.tt_432  af.hu.un_750 sm.fj.un_640 
  0x2f1849a4, 0x38005a07, 0x041044a4, 0x27000207,   // to.ga.su_433 sm.tk.un_420  kk.be.ru_433 da.gd.un_420 
  0x2d101602, 0x250804a4, 0x3d00301b, 0x595552ec,   // hr.lt.sk_222 ru.uk.mn_433  uz.ku.un_770 ha.rw.rn_644 
  // [1ce10]
  0x481c1e11, 0x121121a0, 0x0a340fa7, 0x0449500d,   // ms.id.tt_653 jw.ro.hu_322  lv.xh.pt_532 fj.to.fi_554 
  0x3e2363a4, 0x10000f21, 0x73495a0c, 0x065a600c,   // sco.ca.rm_433 lv.lt.un_860  sm.to.ny_543 vo.sm.de_543 
  0x633e2304, 0x32005502, 0x49225409, 0x50633ea7,   // ca.rm.sco_332 rw.bs.un_220  ik.oc.to_444 rm.sco.fj_532 
  0x0ffe63ee, 0x3f002a0d, 0x11005502, 0x60005014,   // sco.tlh.lv_422 mt.af.un_540  rw.ro.un_220 fj.vo.un_660 
  // [1ce20]
  0x23630e04, 0x1d3e0107, 0x63055a0c, 0x041511a6,   // is.sco.ca_332 en.rm.la_432  sm.fr.sco_543 ro.ru.un_510 
  0x05006119, 0x3e001e0d, 0x01221004, 0x1d2630ec,   // za.fr.un_750 ms.rm.un_540  lt.oc.en_332 uz.ia.la_644 
  0x09007304, 0x11220507, 0x0f0603a0, 0x044b50af,   // ny.pl.un_320 fr.oc.ro_432  nl.de.lv_322 fj.mi.fi_655 
  0x6e016ba0, 0x1e004202, 0x1a6b1e0c, 0x65004e07,   // ceb.en.hmn_322 co.ms.un_220  ms.ceb.tl_543 ay.gv.un_420 
  // [1ce30]
  0x631123a4, 0x36527307, 0x494b5a0d, 0x11690ea4,   // ca.ro.sco_433 ny.ha.gn_432  sm.mi.to_554 is.mfe.ro_433 
  0x052e0ead, 0x1c005f04, 0x0b191207, 0x40452f0d,   // is.fo.fr_643 tn.id.un_320  hu.gl.es_432 su.ln.lb_554 
  0x20001708, 0x23081060, 0x2f004012, 0x40002f19,   // sr.sq.un_430 be.uk.ky_664  lb.su.un_640 su.lb.un_750 
  0x30073509, 0x344a1a13, 0x68005b13, 0x2f5d19a4,   // tg.bg.uz_444 tl.yo.xh_665  sg.ig.un_650 gl.ss.su_433 
  // [1ce40]
  0x2f251ca7, 0x214c4060, 0x345e49af, 0x19002f02,   // id.eu.su_532 lb.wo.jw_664  to.ts.xh_655 su.gl.un_220 
  0x3e470d07, 0x40362fa4, 0x0d00092a, 0x45790705,   // cs.sn.rm_432 su.gn.lb_433  hi.ne.un_970 it.war.ln_333 
  0x2f4019a9, 0x0773420b, 0x4c001212, 0x2236210c,   // gl.lb.su_544 co.ny.it_542  hu.wo.un_640 jw.gn.oc_543 
  0x61003e0e, 0x483831a9, 0x1100100c, 0x234761ee,   // rm.za.un_550 az.tk.tt_544  lt.ro.un_530 za.sn.ca_422 
  // [1ce50]
  0x13002607, 0x0a001c02, 0x48173708, 0x07422204,   // ia.et.un_420 id.pt.un_220  ba.sr.tt_443 oc.co.it_332 
  0x0b004202, 0x0b2f12ad, 0x113148a0, 0xfe004714,   // co.es.un_220 hu.su.es_643  tt.az.ro_322 sn.tlh.un_660 
  0x061240af, 0x214728a0, 0x12004709, 0x215c2004,   // lb.hu.de_655 sw.sn.jw_322  sn.hu.un_440 sq.sa.jw_332 
  0x234835a4, 0x21004702, 0x21004714, 0x3e001212,   // tg.tt.ky_433 sn.jw.un_220  sn.jw.un_660 hu.rm.un_640 
  // [1ce60]
  0x64473407, 0x05233faf, 0x0d22125a, 0x063f03ad,   // xh.sn.lg_432 af.ca.fr_655  hu.oc.cs_553 nl.af.de_643 
  0x28004708, 0x182c27ad, 0x5c3b210c, 0x12004711,   // sn.sw.un_430 gd.fy.ga_643  jw.so.sa_543 sn.hu.un_630 
  0x0200581a, 0x28215c0c, 0x2f063bee, 0x28004705,   // om.da.un_760 sa.jw.sw_543  so.de.su_422 sn.sw.un_330 
  0x353934a0, 0x21000511, 0x56004c04, 0x481b1304,   // xh.br.zu_322 fr.jw.un_630  wo.mg.un_320 et.tr.tt_332 
  // [1ce70]
  0x05192fa6, 0x033f10a7, 0x380f2505, 0x4c2f21a0,   // su.gl.fr_521 lt.af.nl_532  eu.lv.tk_333 jw.su.wo_322 
  0x384813a7, 0x06607908, 0x37004c0c, 0x1f42110c,   // et.tt.tk_532 war.vo.de_443  wo.st.un_530 ro.co.cy_543 
  0x21425cee, 0x283830ad, 0x5257580c, 0x52002505,   // sa.co.jw_422 uz.tk.sw_643  om.na.ha_543 eu.ha.un_330 
  0x1c003004, 0x3b002509, 0x52003002, 0x30481304,   // uz.id.un_320 eu.so.un_440  uz.ha.un_220 et.tt.uz_332 
  // [1ce80]
  0x39651bad, 0x1018300c, 0x122f2d08, 0x052d0d08,   // tr.gv.br_643 uz.ga.lt_543  sk.su.hu_443 cs.sk.fr_443 
  0x2f2d0d0b, 0x28183413, 0x16296eee, 0x40630107,   // cs.sk.su_542 ps.ar.sd_665  hmn.sl.hr_422 en.sco.lb_432 
  0x6912200c, 0x5939050c, 0x27000405, 0x5f5a5608,   // sq.hu.mfe_543 fr.br.rn_543  fi.gd.un_330 mg.sm.tn_443 
  0x290d09a0, 0x4c1b6404, 0x484352a4, 0x0f5549ad,   // pl.cs.sl_322 lg.tr.wo_332  ha.ie.tt_433 to.rw.lv_643 
  // [1ce90]
  0x0f00290c, 0x253918a0, 0x59552955, 0x3b00670c,   // sl.lv.un_530 ga.br.eu_322  sl.rw.rn_442 ak.so.un_530 
  0x32165505, 0x05364b13, 0x396953a7, 0x042337a0,   // rw.hr.bs_333 mi.gn.fr_665  ht.mfe.br_532 ba.ky.ru_322 
  0x630501ee, 0x55002813, 0x5d785508, 0x1d002605,   // en.fr.sco_422 sw.rw.un_650  rw.ve.ss_443 ia.la.un_330 
  0x2955365a, 0x2344250e, 0x06006112, 0x44080408,   // gn.rw.sl_553 mn.kk.ky_555  za.de.un_640 ru.uk.kk_443 
  // [1cea0]
  0x1d2c3fa0, 0x2f0d12a0, 0x18213c0d, 0x2f193602,   // af.fy.la_322 hu.cs.su_322  ug.fa.ar_554 gn.gl.su_222 
  0x25006212, 0x3e002514, 0x322850ad, 0x05004607,   // kha.eu.un_640 eu.rm.un_660  fj.sw.bs_643 qu.fr.un_420 
  0x12054204, 0x5338fc07, 0xfa00540c, 0x1d003f10,   // co.fr.hu_332 zzp.tk.ht_432  ik.nr.un_530 af.la.un_620 
  0x79004c1b, 0x52254d14, 0x45220507, 0x481044a7,   // wo.war.un_770 aa.eu.ha_666  fr.oc.ln_432 kk.be.tt_532 
  // [1ceb0]
  0x201b3008, 0x0413fea4, 0x27185214, 0xfe00061a,   // uz.tr.sq_443 tlh.et.fi_433  ha.ga.gd_666 de.tlh.un_760 
  0x0d512d07, 0x1b202a07, 0x3b1efe04, 0x11171508,   // sk.kl.cs_432 mt.sq.tr_432  tlh.ms.so_332 un.sr.ro_443 
  0x64001d04, 0x28fe5b07, 0x5b041313, 0x0400fe0c,   // la.lg.un_320 sg.tlh.sw_432  et.fi.sg_665 tlh.fi.un_530 
  0x111738a4, 0x23384412, 0x19362faf, 0x401506ad,   // tk.sr.ro_433 kk.tk.ky_654  su.gn.gl_655 de.lb.un_630 
  // [1cec0]
  0x060b1da0, 0x09006913, 0x6300180e, 0x2f005d09,   // la.es.de_322 mfe.pl.un_650  ga.sco.un_550 ss.su.un_440 
  0x1f001102, 0x2d362fa4, 0xfa686b08, 0x070411a4,   // ro.cy.un_220 su.gn.sk_433  ceb.ig.nr_443 ro.ru.bg_433 
  0x380823a6, 0x29006429, 0x362f19a9, 0x06003e13,   // ky.uk.tk_521 lg.sl.un_960  gl.su.gn_544 rm.de.un_650 
  0x5d2f3604, 0x4a00680b, 0x08040aa6, 0x2f000e08,   // gn.su.ss_332 ig.yo.un_520  mk.ru.uk_521 is.su.un_430 
  // [1ced0]
  0x09001329, 0x092c38a0, 0x56103202, 0x12000422,   // bh.hi.un_960 tk.fy.pl_322  bs.lt.mg_222 fi.hu.un_870 
  0x2d0d04ee, 0x0b5d1907, 0x0438100c, 0x041009ad,   // fi.cs.sk_422 gl.ss.es_432  lt.tk.fi_543 pl.lt.fi_643 
  0x73fc650c, 0x444825a7, 0x2c1f09a4, 0x3f10040c,   // gv.zzp.ny_543 mn.tt.kk_532  pl.cy.fy_433 fi.lt.af_543 
  0x2c100407, 0x09362dee, 0xfc683bee, 0x1c211eee,   // fi.lt.fy_432 sk.gn.pl_422  so.ig.zzp_422 ms.jw.id_422 
  // [1cee0]
  0x3c08300d, 0x3c2334a0, 0x44283409, 0x100815ad,   // uz.uk.ug_554 ps.ky.ug_322  ps.sd.kk_444 un.uk.be_643 
  0x024d690d, 0x10041511, 0x30002d05, 0x2144340d,   // mfe.aa.da_554 un.ru.be_653  sk.uz.un_330 ps.kk.fa_554 
  0x125c11a0, 0x29306913, 0x430f1004, 0x062e0fa0,   // ro.sa.hu_322 mfe.uz.sl_665  lt.lv.ie_332 lv.fo.de_322 
  0x3018210c, 0x033f13ee, 0x3f062e04, 0x1044385a,   // fa.ar.uz_543 et.af.nl_422  fo.de.af_332 tk.kk.be_553 
  // [1cef0]
  0x53fc340c, 0x0b00191a, 0x34032ca0, 0x06351f07,   // xh.zzp.ht_543 gl.es.un_760  fy.nl.xh_322 cy.zu.de_432 
  0x5e09340c, 0x47fc1fee, 0x2a001f02, 0x3534fca7,   // xh.pl.ts_543 cy.zzp.sn_422  cy.mt.un_220 zzp.xh.zu_532 
  0x2820580c, 0x0c2e6507, 0x332e0212, 0x47463407,   // om.sq.sw_543 gv.fo.sv_432  da.fo.nn_654 xh.qu.sn_432 
  0x275c5808, 0x4b5665ad, 0x27215c60, 0x515e560c,   // om.sa.gd_443 gv.mg.mi_643  sa.jw.gd_664 mg.ts.kl_543 
  // [1cf00]
  0x492f6211, 0x20585ca0, 0x49002505, 0x626b56af,   // kha.su.to_653 sa.om.sq_322  eu.to.un_330 mg.ceb.kha_655 
  0x4734fc07, 0x28005812, 0x2f37210b, 0x134b0205,   // zzp.xh.sn_432 om.sw.un_640  jw.st.su_542 da.mi.et_333 
  0x5c3b4704, 0x390762a9, 0x284a0207, 0x272f1c07,   // sn.so.sa_332 kha.it.br_544  da.yo.sw_432 id.su.gd_432 
  0x110836ad, 0x182756ad, 0x072b0107, 0x562860a0,   // ab.uk.ro_643 mg.gd.ga_643  en.vi.it_432 vo.sw.mg_322 
  // [1cf10]
  0x35285dac, 0x47003b0c, 0x450a1d07, 0x18192708,   // ss.sw.zu_632 so.sn.un_530  la.pt.ln_432 gd.gl.ga_443 
  0x5c282708, 0x471a21a4, 0x3e052da4, 0x6252560c,   // gd.sw.sa_443 jw.tl.sn_433  sk.fr.rm_433 mg.ha.kha_543 
  0x230b3ba7, 0x08073005, 0x34005d02, 0x43261da4,   // so.es.ca_532 uz.bg.uk_333  ss.xh.un_220 la.ia.ie_433 
  0x3c003d1a, 0x1d2611a4, 0x32001304, 0x442337ac,   // ku.ug.un_760 ro.ia.la_433  et.bs.un_320 ba.ky.kk_632 
  // [1cf20]
  0x564205ee, 0x2f1a1ca0, 0x06381ba4, 0x3c1515a9,   // fr.co.mg_422 id.tl.su_322  tr.tk.de_433 un.ug.un_540 
  0x35027808, 0x61190b08, 0x6100421b, 0x28000313,   // ve.da.zu_443 es.gl.za_443  co.za.un_770 nl.sw.un_650 
  0x523e4208, 0x06004022, 0x0700442a, 0x182823af,   // co.rm.ha_443 lb.de.un_870  kk.bg.un_970 ky.sd.ar_655 
  0x694576af, 0x424547a9, 0x2e051fa0, 0x4761115a,   // crs.ln.mfe_655 sn.ln.co_544  cy.fr.fo_322 ro.za.sn_553 
  // [1cf30]
  0x55735207, 0x283b1213, 0x56033fa0, 0xfc00280b,   // ha.ny.rw_432 ur.ks.sd_665  af.nl.mg_322 sw.zzp.un_520 
  0x0a482304, 0x44002809, 0x58001512, 0x50000a04,   // ky.tt.mk_332 sd.kk.un_440  un.om.un_640 pt.fj.un_320 
  0xfc2412a9, 0x252304ee, 0x2900160c, 0x45004a12,   // hu.eo.zzp_544 ru.ky.mn_422  hr.sl.un_530 yo.ln.un_640 
  0x02265c0c, 0x35735da9, 0x4913260c, 0x1100260d,   // sa.ia.da_543 ss.ny.zu_544  ia.et.to_543 ia.ro.un_540 
  // [1cf40]
  0x2a423e08, 0x11263e04, 0x3f00530d, 0x04365007,   // rm.co.mt_443 rm.ia.ro_332  ht.af.un_540 fj.gn.fi_432 
  0x44373cee, 0x405c26ec, 0x1b2e13a0, 0x3e004223,   // ug.ba.kk_422 ia.sa.lb_644  et.fo.tr_322 co.rm.un_880 
  0x31fe1b04, 0x3e132608, 0x1d004508, 0x0d0c1307,   // tr.tlh.az_332 ia.et.rm_443  ln.la.un_430 et.sv.cs_432 
  0x3e050705, 0x461325a0, 0x0f1d130c, 0x192506a0,   // it.fr.rm_333 eu.et.qu_322  et.la.lv_543 de.eu.gl_322 
  // [1cf50]
  0x6000021a, 0x2d291607, 0x23253b0c, 0x4838fe05,   // da.vo.un_760 hr.sl.sk_432  so.eu.ca_543 tlh.tk.tt_333 
  0x5c303108, 0x3e2978a4, 0x21422f08, 0x363e260c,   // az.uz.sa_443 ve.sl.rm_433  su.co.jw_443 ia.rm.gn_543 
  0x1f003e09, 0x080a040c, 0x36112612, 0x2826470c,   // rm.cy.un_440 ru.mk.uk_543  ia.ro.gn_654 sn.ia.sw_543 
  0x285f370d, 0xfe2e13a4, 0x3104130c, 0x15042505,   // st.tn.sw_554 et.fo.tlh_433  et.fi.az_543 mn.ru.un_333 
  // [1cf60]
  0x31301b0e, 0x0f1a6bac, 0x441015a4, 0x15170414,   // tr.uz.az_555 ceb.tl.lv_632  un.be.kk_433 ru.sr.un_666 
  0x0a1301a0, 0x08000e07, 0x15351012, 0x17000d02,   // en.et.pt_322 is.no.un_420  be.tg.un_654 cs.sr.un_220 
  0x37005907, 0x1a00240b, 0x50005c02, 0x64002a05,   // rn.st.un_420 eo.tl.un_520  sa.fj.un_220 mt.lg.un_330 
  0x04173608, 0x4400350d, 0x02002c0c, 0x274d4212,   // ab.sr.ru_443 tg.kk.un_540  fy.da.un_530 co.aa.gd_654 
  // [1cf70]
  0x330e0ca4, 0x2a001f09, 0x332a20a0, 0x0e2e3502,   // sv.is.nn_433 cy.mt.un_440  sq.mt.nn_322 zu.fo.is_222 
  0x08000304, 0x0d002c08, 0x0400562a, 0x5e274709,   // nl.no.un_320 fy.cs.un_430  mg.fi.un_970 sn.gd.ts_444 
  0x656b1dec, 0x30026aad, 0x02123f12, 0x1d301ea4,   // la.ceb.gv_644 haw.da.uz_643  af.hu.da_654 ms.uz.la_433 
  0x2800131b, 0x08023fa4, 0x3e5301a9, 0x383f1aec,   // et.sw.un_770 af.da.no_433  en.ht.rm_544 tl.af.tk_644 
  // [1cf80]
  0x283b5c5a, 0x0bfe4ca0, 0x2311250d, 0x1f005e22,   // sa.so.sw_553 wo.tlh.es_322  mn.ro.ky_554 ts.cy.un_870 
  0xfe512fa4, 0x67001e08, 0x3f00020d, 0x46595855,   // su.kl.tlh_433 ms.ak.un_430  da.af.un_540 om.rn.qu_442 
  0x2f55590c, 0x183d3004, 0x3b3002ee, 0x6b1a0202,   // rn.rw.su_543 uz.ku.ar_332  da.uz.so_422 da.tl.ceb_222 
  0x2f733807, 0x3b001522, 0x1f005e2b, 0x476278ec,   // tk.ny.su_432 un.so.un_870  ts.cy.un_980 ve.kha.sn_644 
  // [1cf90]
  0x021f5812, 0x65124d0c, 0x2a1e65a0, 0x0c001f2b,   // om.cy.da_654 aa.hu.gv_543  gv.ms.mt_322 cy.sv.un_980 
  0x732b010c, 0x0c00630c, 0x212f1eaf, 0x1200020b,   // en.vi.ny_543 sco.sv.un_530  ms.su.jw_655 da.hu.un_520 
  0x4d00640c, 0x38003f0d, 0x633b4208, 0x38023f0c,   // lg.aa.un_530 af.tk.un_540  co.so.sco_443 af.da.tk_543 
  0x5c4c400c, 0x023f0607, 0x3b00fc0e, 0x4c1f6512,   // lb.wo.sa_543 de.af.da_432  zzp.so.un_550 gv.cy.wo_654 
  // [1cfa0]
  0x5800650c, 0x31460208, 0x2a27fea4, 0x4c6431ec,   // gv.om.un_530 da.qu.az_443  tlh.gd.mt_433 az.lg.wo_644 
  0x1d6508af, 0x1f3b4c0c, 0x2e426511, 0x1f4c01a4,   // no.gv.la_655 wo.so.cy_543  gv.co.fo_653 en.wo.cy_433 
  0x5b024ca4, 0x2e0c1d07, 0x1c002e04, 0x083530a0,   // wo.da.sg_433 la.sv.fo_432  fo.id.un_320 uz.tg.uk_322 
  0x52563ba0, 0x2c005b19, 0x31005019, 0x18392e02,   // so.mg.ha_322 sg.fy.un_750  fj.az.un_750 fo.br.ga_222 
  // [1cfb0]
  0x63001508, 0x39001107, 0x532122ed, 0x6e1b53a9,   // un.sco.un_430 ro.br.un_420  oc.jw.ht_622 ht.tr.hmn_544 
  0x0a2538ee, 0x556445a0, 0x0c4804a7, 0x55425bec,   // tk.mn.mk_422 ln.lg.rw_322  fi.tt.sv_532 sg.co.rw_644 
  0x06190bec, 0x10040aa0, 0x442823a0, 0x12002b18,   // es.gl.de_644 mk.ru.be_322  ky.sd.kk_322 vi.hu.un_740 
  0x4437230b, 0x230522ec, 0x11692008, 0xfc461aa0,   // ky.ba.kk_542 oc.fr.ca_644  sq.mfe.ro_443 tl.qu.zzp_322 
  // [1cfc0]
  0x55fc4602, 0x0a0810ad, 0x7800fc1a, 0x55464ea0,   // qu.zzp.rw_222 be.uk.mk_643  zzp.ve.un_760 ay.qu.rw_322 
  0x3e353409, 0x3555fc02, 0x3415fca6, 0x4b276a05,   // xh.zu.rm_444 zzp.rw.zu_222  zzp.xh.un_510 haw.gd.mi_333 
  0x4d36670c, 0x38751ea0, 0x341d3b5a, 0x69255f0c,   // ak.gn.aa_543 ms.nso.tk_322  so.la.xh_553 tn.eu.mfe_543 
  0x28122508, 0x363f65ee, 0x0f255608, 0x2a406805,   // eu.hu.sw_443 gv.af.gn_422  mg.eu.lv_443 ig.lb.mt_333 
  // [1cfd0]
  0x38310da4, 0x27004b0e, 0x37301ea4, 0x355d3411,   // cs.az.tk_433 mi.gd.un_550  ms.uz.st_433 xh.ss.zu_653 
  0x3d3444af, 0x78465008, 0x57001814, 0x27050107,   // kk.ps.ku_655 fj.qu.ve_443  ga.na.un_660 en.fr.gd_432 
  0xfc5e46a0, 0x251f38a9, 0x64732813, 0x216348a0,   // qu.ts.zzp_322 tk.cy.eu_544  sw.ny.lg_665 tt.sco.jw_322 
  0x5e004604, 0x1f1d2c11, 0x6800781b, 0x394c5707,   // qu.ts.un_320 fy.la.cy_653  ve.ig.un_770 na.wo.br_432 
  // [1cfe0]
  0x384d1baf, 0x313b3012, 0x6400731b, 0x357309a0,   // tr.aa.tk_655 uz.so.az_654  ny.lg.un_770 pl.ny.zu_322 
  0x6a006414, 0x79003304, 0x48382f09, 0x090d2d0c,   // lg.haw.un_660 nn.war.un_320  su.tk.tt_444 sk.cs.pl_543 
  0x1f6439af, 0x30583ba9, 0x03097811, 0x43500608,   // br.lg.cy_655 so.om.uz_544  ve.pl.nl_653 de.fj.ie_443 
  0x595806a0, 0x0200480d, 0x07361104, 0xfc001d1b,   // de.om.rn_322 tt.da.un_540  ro.ab.bg_332 la.zzp.un_770 
  // [1cff0]
  0x642801a0, 0x53645e08, 0x09006a04, 0x130c0407,   // en.sw.lg_322 ts.lg.ht_443  haw.pl.un_320 fi.sv.et_432 
  0x12360aa4, 0x0c653955, 0x02003907, 0x1f000602,   // pt.gn.hu_433 br.gv.sv_442  br.da.un_420 de.cy.un_220 
  0x33001b04, 0x643528a9, 0x69357312, 0x7900390d,   // tr.nn.un_320 sw.zu.lg_544  ny.zu.mfe_654 br.war.un_540 
  0x73552804, 0x402205ad, 0x556428ec, 0x330851a0,   // sw.rw.ny_332 fr.oc.lb_643  sw.lg.rw_644 kl.no.nn_322 
  
  // [1d000]
  0x026964a7, 0x3530440b, 0x32000d0c, 0x0438130c,   // lg.mfe.da_532 kk.uz.tg_542  cs.bs.un_530 et.tk.fi_543 
  0x33650ca0, 0x34455d0c, 0x35645511, 0x55647311,   // sv.gv.nn_322 ss.ln.xh_543  rw.lg.zu_653 ny.lg.rw_653 
  0x55280204, 0x24005504, 0x6957020c, 0x1e56570c,   // da.sw.rw_332 rw.eo.un_320  da.na.mfe_543 na.mg.ms_543 
  0x1663090c, 0x48005714, 0x28231205, 0x3648380c,   // pl.sco.hr_543 na.tt.un_660  ur.ky.sd_333 tk.tt.ab_543 
  // [1d010]
  0x6b4f69a4, 0x36005f0c, 0x1225480d, 0x5e5d5f04,   // mfe.bi.ceb_433 tn.gn.un_530  tt.eu.hu_554 tn.ss.ts_332 
  0x3c3530ec, 0x28007319, 0x0c005a07, 0x56001502,   // uz.tg.ug_644 ny.sw.un_750  sm.sv.un_420 un.mg.un_220 
  0x34420a04, 0x5730450c, 0x0a2e5605, 0x18003f05,   // pt.co.xh_332 ln.uz.na_543  mg.fo.pt_333 af.ga.un_330 
  0x1b380c04, 0x1d1c2804, 0x102f1da0, 0x652c1fad,   // sv.tk.tr_332 sw.id.la_332  la.su.lt_322 cy.fy.gv_643 
  // [1d020]
  0x2800550e, 0x280d1ea0, 0x0e001d0c, 0xfc201f0c,   // rw.sw.un_550 ms.cs.sw_322  la.is.un_530 cy.sq.zzp_543 
  0x796b2509, 0x64251da4, 0x151d4355, 0x2f00fc05,   // eu.ceb.war_444 la.eu.lg_433  ie.la.un_442 zzp.su.un_330 
  0x0500220e, 0x5a062f0c, 0x075c64a4, 0x2f430107,   // oc.fr.un_550 su.de.sm_543  lg.sa.it_433 en.ie.su_432 
  0x1d001d0c, 0x06222f0c, 0x600601a4, 0x22055a07,   // la.la.un_530 su.oc.de_543  en.de.vo_433 sm.fr.oc_432 
  // [1d030]
  0x0804150b, 0x052322a2, 0xfe1024ec, 0x5d002c08,   // un.ru.uk_542 oc.ca.fr_421  eo.lt.tlh_644 fy.ss.un_430 
  0x1c5a0404, 0x03002f20, 0x47002f09, 0x2f5a490c,   // fi.sm.id_332 su.nl.un_850  su.sn.un_440 to.sm.su_543 
  0x0e002705, 0x071035ee, 0x151704a9, 0x22005307,   // gd.is.un_330 tg.be.bg_422  ru.sr.un_544 ht.oc.un_420 
  0x64332e55, 0x21225360, 0x534205ad, 0x081725ee,   // fo.nn.lg_442 ht.oc.jw_664  fr.co.ht_643 mn.sr.uk_422 
  // [1d040]
  0x4d42640c, 0x3e45fc0b, 0x64455e13, 0x17111508,   // lg.co.aa_543 zzp.ln.rm_542  ts.ln.lg_665 un.ro.sr_443 
  0xfc004522, 0x0e0d2e08, 0x016327a6, 0x36002719,   // ln.zzp.un_870 fo.cs.is_443  gd.sco.en_521 gd.gn.un_750 
  0x40032cad, 0x105052ad, 0x52002721, 0x08122855,   // fy.nl.lb_643 ha.fj.lt_643  gd.ha.un_860 sw.hu.no_442 
  0x5218270c, 0x46000404, 0x151511a0, 0x105c36ee,   // gd.ga.ha_543 fi.qu.un_320  ro.un.un_320 gn.sa.lt_422 
  // [1d050]
  0x46182707, 0x440738a7, 0x572242ec, 0x532b0404,   // gd.ga.qu_432 tk.bg.kk_532  co.oc.na_644 fi.vi.ht_332 
  0x33001602, 0x08230404, 0x2f001d07, 0x0423250d,   // hr.nn.un_220 ru.ky.uk_332  la.su.un_420 mn.ky.ru_554 
  0x51004908, 0x382348ec, 0x084d2f11, 0x070a2307,   // to.kl.un_430 tt.ky.tk_644  su.aa.no_653 ky.mk.bg_432 
  0x273f0602, 0x61002721, 0x2e0c0855, 0x2f0c0212,   // de.af.gd_222 gd.za.un_860  no.sv.fo_442 da.sv.su_654 
  // [1d060]
  0x610c08a7, 0x2d002920, 0x063e3104, 0x35345ea4,   // no.sv.za_532 sl.sk.un_850  az.rm.de_332 ts.xh.zu_433 
  0x2d0c0207, 0x0f04210d, 0x015a3b0c, 0x0c022012,   // da.sv.sk_432 jw.fi.lv_554  so.sm.en_543 sq.da.sv_654 
  0x564207ee, 0x0c0208ad, 0x08233508, 0x0c2e08a4,   // it.co.mg_422 no.da.sv_643  tg.ky.uk_443 no.fo.sv_433 
  0x083f0c0c, 0x0c0902a0, 0x132412a4, 0x481b06a0,   // sv.af.no_543 da.pl.sv_322  hu.eo.et_433 de.tr.tt_322 
  // [1d070]
  0x34003511, 0x460d02ec, 0x2242fc07, 0x23071da0,   // zu.xh.un_630 da.cs.qu_644  zzp.co.oc_432 la.it.ca_322 
  0x2a020d07, 0x302c1bee, 0x12004613, 0x28000704,   // cs.da.mt_432 tr.fy.uz_422  qu.hu.un_650 it.sw.un_320 
  0x30001713, 0x0b231da0, 0x34005d22, 0x53045908,   // sr.uz.un_650 la.ca.es_322  ss.xh.un_870 rn.fi.ht_443 
  0x21534c55, 0x202158a9, 0x043044a0, 0x44001711,   // wo.ht.jw_442 om.jw.sq_544  kk.uz.ru_322 sr.kk.un_630 
  // [1d080]
  0x432a3faf, 0x0c0a080b, 0x18302308, 0x18213212,   // af.mt.ie_655 no.pt.sv_542  ky.uz.ar_443 bs.fa.ar_654 
  0x0a061da4, 0x0c231da7, 0x32002a19, 0x2e064002,   // la.de.pt_433 la.ca.sv_532  mt.bs.un_750 lb.de.fo_222 
  0x17001c04, 0x2c0e2ea0, 0x67005022, 0x162d2f04,   // id.sr.un_320 fo.is.fy_322  fj.ak.un_870 su.sk.hr_332 
  0x1d000c02, 0x6a02460e, 0x53763fa7, 0x2a2f1ca4,   // sv.la.un_220 qu.da.haw_555  af.crs.ht_532 id.su.mt_433 
  // [1d090]
  0x0c04135a, 0x5000300c, 0x24005e04, 0x355e3408,   // et.fi.sv_553 uz.fj.un_530  ts.eo.un_320 xh.ts.zu_443 
  0x5dfa3708, 0x10185104, 0x103e4d07, 0x3534fe05,   // st.nr.ss_443 kl.ga.lt_332  aa.rm.lt_432 tlh.xh.zu_333 
  0x48182755, 0x27190b11, 0x1b18270c, 0x55345907,   // gd.ga.tt_442 es.gl.gd_653  gd.ga.tr_543 rn.xh.rw_432 
  0x421e1ca4, 0x422f3e07, 0xfa00611b, 0x2a003505,   // id.ms.co_433 rm.su.co_432  za.nr.un_770 zu.mt.un_330 
  // [1d0a0]
  0x40580907, 0x425c2da4, 0x35212fa0, 0x0d132d12,   // pl.om.lb_432 sk.sa.co_433  su.jw.zu_322 sk.et.cs_654 
  0x32171205, 0x3100281b, 0x03fe2fee, 0x2528240b,   // hu.sr.bs_333 sw.az.un_770  su.tlh.nl_422 eo.sw.eu_542 
  0x51006a19, 0x09122707, 0x0413fe0d, 0x3e2450a9,   // haw.kl.un_750 gd.hu.pl_432  tlh.et.fi_554 fj.eo.rm_544 
  0x23004a08, 0xfe006118, 0x54020faf, 0x3b271da7,   // yo.ca.un_430 za.tlh.un_740  lv.da.ik_655 la.gd.so_532 
  // [1d0b0]
  0x1d002e07, 0x4c00310d, 0x1e1c29a4, 0x0b070aee,   // fo.la.un_420 az.wo.un_540  sl.id.ms_433 pt.it.es_422 
  0x25260107, 0x1a1c6ba4, 0x303b315a, 0x30073605,   // en.ia.eu_432 ceb.id.tl_433  az.so.uz_553 ab.bg.uz_333 
  0x17043cee, 0x15172308, 0x5a004513, 0x67004513,   // ug.ru.sr_422 ky.sr.un_443  ln.sm.un_650 ln.ak.un_650 
  0x36003b04, 0x183c44a4, 0x15073ca0, 0x285a0204,   // so.gn.un_320 kk.ug.ar_433  ug.bg.un_322 da.sm.sw_332 
  // [1d0c0]
  0x1a214602, 0x0a100702, 0x5627620c, 0x4f00631a,   // qu.jw.tl_222 bg.be.mk_222  kha.gd.mg_543 sco.bi.un_760 
  0x37573613, 0x295c4fec, 0xfe3534ad, 0x02001a22,   // gn.na.st_665 bi.sa.sl_644  xh.zu.tlh_643 tl.da.un_870 
  0x1b2a100e, 0x38002407, 0x3e65570c, 0x56521ea4,   // lt.mt.tr_555 eo.tk.un_420  na.gv.rm_543 ms.ha.mg_433 
  0x30652b04, 0x32162da9, 0x51004711, 0x313b4c0c,   // vi.gv.uz_332 sk.hr.bs_544  sn.kl.un_630 wo.so.az_543 
  // [1d0d0]
  0x34004814, 0x2f4b50a9, 0x2335340c, 0x3b00581b,   // tt.xh.un_660 fj.mi.su_544  xh.zu.ca_543 om.so.un_770 
  0x18302108, 0x150a040d, 0x330e58a0, 0x38315712,   // fa.uz.ar_443 ru.mk.un_554  om.is.nn_322 na.az.tk_654 
  0x311b0655, 0x303b020c, 0x4b000a02, 0x12000f07,   // de.tr.az_442 da.so.uz_543  pt.mi.un_220 lv.hu.un_420 
  0x31061ba7, 0x38061ba0, 0x383106a0, 0x343626a4,   // tr.de.az_532 tr.de.tk_322  de.az.tk_322 ia.gn.xh_433 
  // [1d0e0]
  0x0a005a07, 0x473659a4, 0x474950a9, 0x300a38ee,   // sm.pt.un_420 rn.gn.sn_433  fj.to.sn_544 tk.mk.uz_422 
  0x3d2118ad, 0x2300600c, 0x0a3648a0, 0x51005a04,   // ar.fa.ku_643 vo.ca.un_530  tt.ab.mk_322 sm.kl.un_320 
  0x3e001308, 0x4226505a, 0x2900560d, 0x0a2326a4,   // et.rm.un_430 fj.ia.co_553  mg.sl.un_540 ia.ca.pt_433 
  0x5e42260c, 0x5047640c, 0x3c300714, 0x47505e12,   // ia.co.ts_543 lg.sn.fj_543  bg.uz.ug_666 ts.fj.sn_654 
  // [1d0f0]
  0x3715045a, 0x183034ad, 0x054a090c, 0x22004708,   // ru.ba.un_530 ps.uz.ar_643  pl.yo.fr_543 sn.oc.un_430 
  0x02361312, 0x0a232da0, 0x054a365a, 0x37081507,   // et.gn.da_654 sk.ca.pt_322  gn.yo.fr_553 un.uk.ba_432 
  0x120b0a04, 0x1d2e6504, 0x28306ea0, 0x170a08af,   // pt.es.hu_332 gv.fo.la_332  hmn.uz.sw_322 uk.mk.sr_655 
  0x1d1564a0, 0x47025913, 0x28321655, 0x4659550d,   // lg.la.un_320 rn.da.sn_665  hr.bs.sw_442 rw.rn.qu_554 
  // [1d100]
  0x36106708, 0x3b5664a0, 0x7364680c, 0x6413360c,   // ak.lt.gn_443 lg.mg.so_322  ig.lg.ny_543 gn.et.lg_543 
  0x391a46a0, 0x5d251caf, 0x070a3702, 0x251c2fa0,   // qu.tl.br_322 id.eu.ss_655  ba.mk.bg_222 su.id.eu_322 
  0x5f37570c, 0x36fc3002, 0x1b001205, 0x342a5ca0,   // na.st.tn_543 uz.zzp.gn_222  hu.tr.un_330 sa.mt.xh_322 
  0x313837ee, 0x08000f18, 0x554751a0, 0x4b5d4908,   // st.tk.az_422 lv.no.un_740  kl.sn.rw_322 to.ss.mi_443 
  // [1d110]
  0x05000302, 0x03004204, 0x47002512, 0x313f0fa7,   // nl.fr.un_220 co.nl.un_320  eu.sn.un_640 lv.af.az_532 
  0x32020fec, 0x15083004, 0x594d1ea0, 0x291a4b02,   // lv.da.bs_644 uz.uk.un_332  ms.aa.rn_322 mi.tl.sl_222 
  0x20007305, 0x0a2337a0, 0x25083709, 0x391f0e0d,   // ny.sq.un_330 ba.ky.mk_322  ba.uk.mn_444 is.cy.br_554 
  0x1f002714, 0x51004c07, 0x31305205, 0x29005e05,   // gd.cy.un_660 wo.kl.un_420  ha.uz.az_333 ts.sl.un_330 
  // [1d120]
  0x494b6a13, 0x6b625111, 0x432304a9, 0x151d3913,   // haw.mi.to_665 kl.kha.ceb_653  fi.ca.ie_544 br.la.un_665 
  0x04510d0c, 0x4d20210c, 0x201e1c0d, 0x4c024d07,   // cs.kl.fi_543 jw.sq.aa_543  id.ms.sq_554 aa.da.wo_432 
  0x544f5112, 0x47005907, 0x476902a4, 0x07383ea4,   // kl.bi.ik_654 rn.sn.un_420  da.mfe.sn_433 rm.tk.it_433 
  0x34007608, 0x25001120, 0x04515412, 0x2f384ca7,   // crs.xh.un_430 ro.eu.un_850  ik.kl.fi_654 wo.tk.su_532 
  // [1d130]
  0x2f545112, 0x1151150d, 0x02006119, 0x54004d09,   // kl.ik.su_654 un.kl.ro_554  za.da.un_750 aa.ik.un_440 
  0x61353409, 0x15005112, 0x07003819, 0x4a00230d,   // xh.zu.za_444 kl.un.un_640  tk.bg.un_750 ca.yo.un_540 
  0x3c21235a, 0x550728a4, 0x3e07420d, 0x3217450c,   // ky.fa.ug_553 sw.it.rw_433  co.it.rm_554 ln.sr.bs_543 
  0x42473ead, 0x35342814, 0x63470304, 0x2d0f2ead,   // rm.sn.co_643 sw.xh.zu_666  nl.sn.sco_332 fo.lv.sk_643 
  // [1d140]
  0x18002404, 0x0c2e1ba7, 0x51004a07, 0x443d2311,   // eo.ga.un_320 tr.fo.sv_532  yo.kl.un_420 ky.ku.kk_653 
  0x47000107, 0x73645108, 0x1510480e, 0x08111711,   // en.sn.un_420 kl.lg.ny_443  tt.be.un_555 sr.ro.uk_653 
  0x2d360807, 0x3f686708, 0x3f1d03a4, 0x02002d08,   // no.gn.sk_432 ak.ig.af_443  nl.la.af_433 sk.da.un_430 
  0x0a123904, 0x4829470b, 0x464e2eaf, 0x34515007,   // br.hu.pt_332 sn.sl.tt_542  fo.ay.qu_655 fj.kl.xh_432 
  // [1d150]
  0x03362da4, 0x1c2f1a02, 0x111c4d07, 0x09004d12,   // sk.gn.nl_433 tl.su.id_222  aa.id.ro_432 aa.pl.un_640 
  0x1c5d35a0, 0x2d230204, 0x032d20a4, 0x3b064d0c,   // zu.ss.id_322 da.ca.sk_332  sq.sk.nl_433 aa.de.so_543 
  0x17292d11, 0x464d2f0e, 0x2d0d0405, 0x182067a4,   // sk.sl.sr_653 su.aa.qu_555  fi.cs.sk_333 ak.sq.ga_433 
  0x312f2908, 0x0e0c06ee, 0x1f091d04, 0xfc4e4607,   // sl.su.az_443 de.sv.is_422  la.pl.cy_332 qu.ay.zzp_432 
  // [1d160]
  0x123b1855, 0x1c6563a0, 0x27345eee, 0x350a0755,   // ar.ks.ur_442 sco.gv.id_322  ts.xh.gd_422 bg.mk.tg_442 
  0x3b003734, 0x30001a07, 0x042f40a7, 0x5a5201ec,   // st.so.un_A80 tl.uz.un_420  lb.su.fi_532 en.ha.sm_644 
  0x01631ca0, 0x21585c07, 0x154201a4, 0x18fc2007,   // id.sco.en_322 sa.om.jw_432  en.co.un_433 sq.zzp.ga_432 
  0x69205511, 0x47002114, 0x20003907, 0x124721a6,   // rw.sq.mfe_653 jw.sn.un_660  br.sq.un_420 jw.sn.hu_521 
  // [1d170]
  0x1f631da4, 0x523028a4, 0x75005f35, 0x5800280c,   // la.sco.cy_433 sw.uz.ha_433  tn.nso.un_A90 sw.om.un_530 
  0xfc2147a4, 0x79004312, 0x1f591d04, 0x25786013,   // sn.jw.zzp_433 ie.war.un_640  la.rn.cy_332 vo.ve.eu_665 
  0x546225a4, 0x585e21a7, 0x13340f02, 0x1d004b0d,   // eu.kha.ik_433 jw.ts.om_532  lv.xh.et_222 mi.la.un_540 
  0x34002204, 0x12283455, 0x0c2b1aa0, 0x4700fc09,   // oc.xh.un_320 ps.sd.ur_442  tl.vi.sv_322 zzp.sn.un_440 
  // [1d180]
  0x330813a4, 0x5828470c, 0x1e120f0b, 0x512854a4,   // et.no.nn_433 sn.sw.om_543  lv.hu.ms_542 ik.sw.kl_433 
  0x200c3304, 0x21fc5805, 0x585e3502, 0x2579280c,   // nn.sv.sq_332 om.zzp.jw_333  zu.ts.om_222 sw.war.eu_543 
  0x165228a4, 0x47fc215a, 0x37101dee, 0x511a6ba9,   // sw.ha.hr_433 jw.zzp.sn_553  la.lt.st_422 ceb.tl.kl_544 
  0x37fa5e5a, 0x32031e07, 0x2b6b7908, 0x1d285102,   // ts.nr.st_553 ms.nl.bs_432  war.ceb.vi_443 kl.sw.la_222 
  // [1d190]
  0x301f4612, 0x211a4a07, 0x6a1b6bec, 0x27652da4,   // qu.cy.uz_654 yo.tl.jw_432  ceb.tr.haw_644 sk.gv.gd_433 
  0x3953240c, 0x302823a0, 0x181f01a0, 0xfe0230a9,   // eo.ht.br_543 ky.sd.uz_322  en.cy.ga_322 uz.da.tlh_544 
  0x3c18230e, 0x27003009, 0x0817650c, 0x1e1c380c,   // ky.ar.ug_555 uz.gd.un_440  gv.sr.no_543 tk.id.ms_543 
  0x0a000d12, 0x5b1e1c05, 0x30007819, 0x4d006b0e,   // cs.pt.un_640 id.ms.sg_333  ve.uz.un_750 ceb.aa.un_550 
  // [1d1a0]
  0x2f00421a, 0x122f0d0c, 0x15fe7811, 0x1c3b1ea4,   // co.su.un_760 cs.su.hu_543  ve.tlh.un_653 ms.so.id_433 
  0x5e3047a9, 0x2f000a0c, 0x283b3004, 0x1d004c09,   // sn.uz.ts_544 pt.su.un_530  uz.ks.sd_332 wo.la.un_440 
  0x2f004814, 0x44303502, 0x6b00460d, 0x0c3302ee,   // tt.su.un_660 tg.uz.kk_222  qu.ceb.un_540 da.nn.sv_422 
  0x0200780d, 0x0a000d0e, 0x5e00470e, 0x0a000d13,   // ve.da.un_540 cs.pt.un_550  sn.ts.un_550 cs.pt.un_650 
  // [1d1b0]
  0x5c631807, 0x360625ee, 0x1b0346a0, 0x5c2e4e07,   // ga.sco.sa_432 eu.de.gn_422  qu.nl.tr_322 ay.fo.sa_432 
  0x2e033f08, 0x4c1d2e04, 0x65002e0c, 0x34122811,   // af.nl.fo_443 fo.la.wo_332  fo.gv.un_530 sd.ur.ps_653 
  0x611d1513, 0x68631d0c, 0x303511ac, 0x0a00100e,   // un.la.za_665 la.sco.ig_543  ro.tg.uz_632 be.mk.un_550 
  0x44303702, 0x03133e07, 0x273918a9, 0x0f33080c,   // ba.uz.kk_222 rm.et.nl_432  ga.br.gd_544 no.nn.lv_543 
  // [1d1c0]
  0x2902030c, 0x23000113, 0x5d1c2e0c, 0x2c030e0b,   // nl.da.sl_543 en.ca.un_650  fo.id.ss_543 is.nl.fy_542 
  0x35001807, 0x15065704, 0x46026ba7, 0x55022504,   // ga.zu.un_420 na.de.un_332  ceb.da.qu_532 eu.da.rw_332 
  0x232f02a0, 0x064222a4, 0x545122a4, 0x13332ead,   // da.su.ca_322 oc.co.de_433  oc.kl.ik_433 fo.nn.et_643 
  0x1f004e21, 0x300a07ee, 0x2e032c08, 0x330e395a,   // ay.cy.un_860 bg.mk.uz_422  fy.nl.fo_443 br.is.nn_553 
  // [1d1d0]
  0x734f68a0, 0x33003002, 0xfc2718a7, 0x2e064007,   // ig.bi.ny_322 uz.nn.un_220  ga.gd.zzp_532 lb.de.fo_432 
  0x645534a4, 0x595535af, 0x5c360504, 0x514601a0,   // xh.rw.lg_433 zu.rw.rn_655  fr.gn.sa_332 en.qu.kl_322 
  0x400511a4, 0x24003502, 0x65611f5a, 0x021b6b07,   // ro.fr.lb_433 zu.eo.un_220  cy.za.gv_553 ceb.tr.da_432 
  0x5136210c, 0x233d300d, 0x381f6112, 0x250268a9,   // jw.gn.kl_543 uz.ku.ky_554  za.cy.tk_654 ig.da.eu_544 
  // [1d1e0]
  0x6b0e2e12, 0x12006913, 0x68001213, 0x06730e0c,   // fo.is.ceb_654 mfe.hu.un_650  hu.ig.un_650 is.ny.de_543 
  0x282130a6, 0x05005312, 0x4b002508, 0x0c003e13,   // uz.fa.sd_521 ht.fr.un_640  eu.mi.un_430 rm.sv.un_650 
  0x214f390e, 0x38231705, 0x46183908, 0x27171804,   // br.bi.jw_555 sr.ky.tk_333  br.ga.qu_443 ga.sr.gd_332 
  0x22273907, 0x3e062ca4, 0x3918270d, 0x103615af,   // br.gd.oc_432 fy.de.rm_433  gd.ga.br_554 un.ab.be_655 
  // [1d1f0]
  0x33060ea0, 0x321613a0, 0x520f620c, 0x52001014,   // is.de.nn_322 et.hr.bs_322  kha.lv.ha_543 lt.ha.un_660 
  0x252b0207, 0x4910470b, 0x2000100b, 0x5a003f08,   // da.vi.eu_432 sn.lt.to_542  lt.sq.un_520 af.sm.un_430 
  0x27213ba6, 0x05002b0e, 0x3e0f2204, 0x105c6212,   // so.jw.gd_521 vi.fr.un_550  oc.lv.rm_332 kha.sa.lt_654 
  0x30390609, 0x30001607, 0x64007907, 0x1f005713,   // de.br.uz_444 hr.uz.un_420  war.lg.un_420 na.cy.un_650 
  // [1d200]
  0x30374813, 0x47005412, 0x211218a9, 0x0a080411,   // tt.ba.uz_665 ik.sn.un_640  ar.ur.fa_544 ru.uk.mk_653 
  0x18003104, 0x54373905, 0x5625370c, 0x2d001502,   // az.ga.un_320 br.st.ik_333  st.eu.mg_543 un.sk.un_220 
  0x510f6304, 0x605045ec, 0x374356a0, 0x50495aaf,   // sco.lv.kl_332 ln.fj.vo_644  mg.ie.st_322 sm.to.fj_655 
  0x5a564902, 0x565f6507, 0x0d000f0c, 0x321d5a11,   // to.mg.sm_222 gv.tn.mg_432  lv.cs.un_530 sm.la.bs_653 
  // [1d210]
  0x1c002b21, 0x494a1d05, 0x45782f0c, 0xfe004308,   // vi.id.un_860 la.yo.to_333  su.ve.ln_543 ie.tlh.un_430 
  0x3b31610b, 0x11396507, 0x55222004, 0x2e003e12,   // za.az.so_542 gv.br.ro_432  sq.oc.rw_332 rm.fo.un_640 
  0x2073490b, 0x5a4c430b, 0x19002b09, 0x08101514,   // to.ny.sq_542 ie.wo.sm_542  vi.gl.un_440 un.be.uk_666 
  0x55005e05, 0x56054bee, 0x0c000a0e, 0x2f495608,   // ts.rw.un_330 mi.fr.mg_422  pt.sv.un_550 mg.to.su_443 
  // [1d220]
  0x16395607, 0x4900fe05, 0x655356ee, 0x672f28a9,   // mg.br.hr_432 tlh.to.un_330  mg.ht.gv_422 sw.su.ak_544 
  0x062c6711, 0x2b372c07, 0x425a4608, 0x30005002,   // ak.fy.de_653 fy.st.vi_432  qu.sm.co_443 fj.uz.un_220 
  0x58551da7, 0x5e4953a0, 0x215055a0, 0x3c304455,   // la.rw.om_532 ht.to.ts_322  rw.fj.jw_322 kk.uz.ug_442 
  0x11421d55, 0x3d3c23ee, 0x76690107, 0x766960a9,   // la.co.ro_442 ky.ug.ku_422  en.mfe.crs_432 vo.mfe.crs_544 
  // [1d230]
  0x472322a0, 0x53006011, 0x601f760c, 0x5c006b19,   // oc.ca.sn_322 vo.ht.un_630  crs.cy.vo_543 ceb.sa.un_750 
  0x3e005512, 0x0a11170e, 0x0423250c, 0x03344c04,   // rw.rm.un_640 sr.ro.mk_555  mn.ky.ru_543 wo.xh.nl_332 
  0x222360a4, 0x29120404, 0x365601a7, 0x374804a4,   // vo.ca.oc_433 fi.hu.sl_332  en.mg.gn_532 ru.tt.ba_433 
  0x5e375da0, 0x32211c02, 0x53607614, 0x50004202,   // ss.st.ts_322 id.jw.bs_222  crs.vo.ht_666 co.fj.un_220 
  // [1d240]
  0x2253600c, 0x211c025a, 0x2800630e, 0x227660a9,   // vo.ht.oc_543 da.id.jw_553  sco.sw.un_550 vo.crs.oc_544 
  0x044811a6, 0x7669605a, 0x13321607, 0x5d005e08,   // ro.tt.ru_521 vo.mfe.crs_553  hr.bs.et_432 ts.ss.un_430 
  0x220a5ca4, 0x10004e0b, 0x100ffc0d, 0x192b0b07,   // sa.pt.oc_433 ay.lt.un_520  zzp.lv.lt_554 es.vi.gl_432 
  0x44372504, 0x5f150355, 0x405d1f0c, 0x304c3b04,   // mn.ba.kk_332 nl.tn.un_420  cy.ss.lb_543 so.wo.uz_332 
  // [1d250]
  0x28030604, 0x48003e07, 0x35000604, 0x033402a0,   // de.nl.sw_332 rm.tt.un_420  de.zu.un_320 da.xh.nl_322 
  0x213c30a7, 0x063160a0, 0x06031f04, 0x065903a4,   // uz.ug.fa_532 vo.az.de_322  cy.nl.de_332 nl.rn.de_433 
  0x01002f07, 0x121b310b, 0x251008ad, 0x2f026b0c,   // su.en.un_420 az.tr.hu_542  uk.be.mn_643 ceb.da.su_543 
  0xfc4003a0, 0x10480711, 0x0603fcec, 0xfc030655,   // nl.lb.zzp_322 bg.tt.be_653  zzp.nl.de_644 de.nl.zzp_442 
  // [1d260]
  0x03fc0602, 0x56735a12, 0x100a07ec, 0x24390c07,   // de.zzp.nl_222 sm.ny.mg_654  bg.mk.be_644 sv.br.eo_432 
  0x55003807, 0x0d5c13af, 0x274a3604, 0x16292a07,   // tk.rw.un_420 bh.sa.ne_655  gn.yo.gd_332 mt.sl.hr_432 
  0x47001813, 0x2e0e3908, 0x15004707, 0x312d3804,   // ga.sn.un_650 br.is.fo_443  sn.un.un_420 tk.sk.az_332 
  0x30003809, 0x635001a0, 0x3f004a02, 0x473b5807,   // tk.uz.un_440 en.fj.sco_322  yo.af.un_220 om.so.sn_432 
  // [1d270]
  0x35003811, 0x01004e21, 0x332c03ad, 0x3b581aaf,   // tk.tg.un_630 ay.en.un_860  nl.fy.nn_643 tl.om.so_655 
  0x0f2c030c, 0x0e4a2e0e, 0x05392ba0, 0x1e212f13,   // nl.fy.lv_543 fo.yo.is_555  vi.br.fr_322 su.jw.ms_665 
  0x17004605, 0x112d1207, 0x3365fca7, 0x0300fc14,   // qu.sr.un_330 hu.sk.ro_432  zzp.gv.nn_532 zzp.nl.un_660 
  0x4c003e07, 0x20521fad, 0x11000717, 0x3e0858a0,   // rm.wo.un_420 cy.ha.sq_643  it.ro.un_730 om.no.rm_322 
  // [1d280]
  0x42072aa9, 0x05005608, 0x072a42ac, 0x40022404,   // mt.it.co_544 mg.fr.un_430  co.mt.it_632 eo.da.lb_332 
  0x39220502, 0x153e0704, 0x3210160d, 0x52000804,   // fr.oc.br_222 it.rm.un_332  hr.lt.bs_554 no.ha.un_320 
  0x032a6955, 0x36213fa4, 0x204a2107, 0x11002c21,   // mfe.mt.nl_442 af.jw.gn_433  jw.yo.sq_432 fy.ro.un_860 
  0x134c4aec, 0x103508a7, 0x1d1026ee, 0x3e001004,   // yo.wo.et_644 uk.tg.be_532  ia.lt.la_422 lt.rm.un_320 
  // [1d290]
  0x79106213, 0x1c4f2304, 0x2c005719, 0x525f75a9,   // kha.lt.war_665 ca.bi.id_332  na.fy.un_750 nso.tn.ha_544 
  0x4c3b67a4, 0x252f3ba4, 0x3b5020a4, 0x1100522a,   // ak.so.wo_433 so.su.eu_433  sq.fj.so_433 ha.ro.un_970 
  0x08303c0b, 0x351030a7, 0x28123ba4, 0x44004814,   // ug.uz.uk_542 uz.be.tg_532  ks.ur.sd_433 tt.kk.un_660 
  0x64675f60, 0x46001b05, 0x06656307, 0x3b34210c,   // tn.ak.lg_664 tr.qu.un_330  sco.gv.de_432 fa.ps.ks_543 
  // [1d2a0]
  0x461a3914, 0x353418ee, 0x303748a9, 0x42341da0,   // br.tl.qu_666 ga.xh.zu_422  tt.ba.uz_544 la.xh.co_322 
  0x0d431207, 0x070a36a9, 0x0600fe1a, 0x5a4a2504,   // hu.ie.cs_432 ab.mk.bg_544  tlh.de.un_760 eu.yo.sm_332 
  0x233025a0, 0x15230a60, 0x0e120d04, 0x2c0249a9,   // mn.uz.ky_322 mk.ky.un_664  cs.hu.is_332 to.da.fy_544 
  0x2b00370d, 0x2b005a04, 0x10003208, 0x28005a04,   // st.vi.un_540 sm.vi.un_320  bs.lt.un_430 sm.sw.un_320 
  // [1d2b0]
  0xfe4d510d, 0x2a585155, 0x2a51540c, 0x2a31fead,   // kl.aa.tlh_554 kl.om.mt_442  ik.kl.mt_543 tlh.az.mt_643 
  0x765369a4, 0x2d0d4c0c, 0x11220fad, 0x06361ca4,   // mfe.ht.crs_433 wo.cs.sk_543  lv.oc.ro_643 id.gn.de_433 
  0x1c301ead, 0x03022e09, 0x0375370c, 0x1f2c2f55,   // ms.uz.id_643 fo.da.nl_444  st.nso.nl_543 su.fy.cy_442 
  0x56030b0d, 0x181d65a4, 0x251e1c0e, 0x6b121aad,   // es.nl.mg_554 gv.la.ga_433  id.ms.eu_555 tl.hu.ceb_643 
  // [1d2c0]
  0x1f400f0c, 0x3100510e, 0x5400511b, 0x34655813,   // lv.lb.cy_543 kl.az.un_550  kl.ik.un_770 om.gv.xh_665 
  0x34302808, 0x15460107, 0x53382504, 0x1f0a0205,   // sd.uz.ps_443 en.qu.un_432  eu.tk.ht_332 da.pt.cy_333 
  0x3167690c, 0x135851a4, 0x073b60a4, 0x023656a4,   // mfe.ak.az_543 kl.om.et_433  vo.so.it_433 mg.gn.da_433 
  0x42211e0c, 0x644951a0, 0x51312008, 0x2a4b4ca4,   // ms.jw.co_543 kl.to.lg_322  sq.az.kl_443 wo.mi.mt_433 
  // [1d2d0]
  0x0d002304, 0x1d1360ec, 0x565305a7, 0x36404ca4,   // ca.cs.un_320 vo.et.la_644  fr.ht.mg_532 wo.lb.gn_433 
  0x495a4dad, 0x05004509, 0x2321120c, 0x10480408,   // aa.sm.to_643 ln.fr.un_440  ur.fa.ky_543 ru.tt.be_443 
  0x33030fa0, 0x3f0610ee, 0x030c06ee, 0x31001202,   // lv.nl.nn_322 lt.de.af_422  de.sv.nl_422 hu.az.un_220 
  0x344423a7, 0x10000e07, 0x2d0f1bee, 0x2d100fa0,   // ky.kk.ps_532 is.lt.un_420  tr.lv.sk_422 lv.lt.sk_322 
  // [1d2e0]
  0x0d001819, 0x2000fe19, 0xfe002008, 0x10361508,   // ga.cs.un_750 tlh.sq.un_750  sq.tlh.un_430 un.ab.be_443 
  0x20fe36ad, 0x203b4ca0, 0x3038485a, 0x61100912,   // gn.tlh.sq_643 wo.so.sq_322  tt.tk.uz_553 pl.lt.za_654 
  0x5d002302, 0x07231102, 0x4630fe0d, 0x650113a0,   // ca.ss.un_220 ro.ca.it_222  tlh.uz.qu_554 et.en.gv_322 
  0x20fe460c, 0x1000251a, 0x30532aa0, 0x46005414,   // qu.tlh.sq_543 eu.lt.un_760  mt.ht.uz_322 ik.qu.un_660 
  // [1d2f0]
  0x04154404, 0x2a005c12, 0x1e5c1c07, 0x585c21af,   // kk.ru.un_320 sa.mt.un_640  id.sa.ms_432 jw.sa.om_655 
  0x27003322, 0x1a004905, 0x42652307, 0x28fe5c08,   // nn.gd.un_870 to.tl.un_330  ca.gv.co_432 sa.tlh.sw_443 
  0x49474d5a, 0x232210ad, 0x02001022, 0x7900580d,   // aa.sn.to_553 lt.oc.ca_643  lt.da.un_870 om.war.un_540 
  0x0b114604, 0x13005f22, 0x47285c0b, 0x28475c11,   // qu.ro.es_332 tn.et.un_870  sa.sw.sn_542 sa.sn.sw_653 
  // [1d300]
  0x49001a04, 0x3b00400c, 0x52002213, 0x24004205,   // tl.to.un_320 lb.so.un_530  oc.ha.un_650 co.eo.un_330 
  0x58005c1a, 0x6b58680d, 0x0a004309, 0x586467a9,   // sa.om.un_760 ig.om.ceb_554  ie.pt.un_440 ak.lg.om_544 
  0x2f003b1a, 0x654c58a9, 0x5c583b0c, 0x1b1e1c05,   // so.su.un_760 om.wo.gv_544  so.om.sa_543 id.ms.tr_333 
  0x42005c02, 0x583b5aa9, 0x134658ad, 0x28030955,   // sa.co.un_220 sm.so.om_544  om.qu.et_643 pl.nl.sw_442 
  // [1d310]
  0x58284d12, 0x241040a0, 0x583b4c07, 0x2a00760e,   // aa.sw.om_654 lb.lt.eo_322  wo.so.om_432 crs.mt.un_550 
  0x47585cad, 0x44044802, 0x0723170b, 0x47212807,   // sa.om.sn_643 tt.ru.kk_222  sr.ky.bg_542 sw.jw.sn_432 
  0x5f476507, 0x28585cad, 0x47491aec, 0x47585ca4,   // gv.sn.tn_432 sa.om.sw_643  tl.to.sn_644 sa.om.sn_433 
  0xfc5c2160, 0x3f0347a0, 0x58283b13, 0x5300231a,   // jw.sa.zzp_664 sn.nl.af_322  so.sw.om_665 ca.ht.un_760 
  // [1d320]
  0x46001307, 0x353744a4, 0x1c420307, 0x15110708,   // et.qu.un_420 kk.ba.tg_433  nl.co.id_432 bg.ro.un_443 
  0x6b5609ec, 0x096356a0, 0x50090d04, 0x155301af,   // pl.mg.ceb_644 mg.sco.pl_322  cs.pl.fj_332 en.ht.un_655 
  0x211e2fa6, 0x043815a4, 0x0118090c, 0x4e000f13,   // su.ms.jw_521 un.tk.ru_433  pl.ga.en_543 lv.ay.un_650 
  0x2f465d0b, 0x2d023607, 0x08250aa4, 0x52002507,   // ss.qu.su_542 gn.da.sk_432  mk.mn.uk_433 eu.ha.un_420 
  // [1d330]
  0x2f491e0c, 0x1f003e0c, 0x0f1210ac, 0x3e47100b,   // ms.to.su_543 rm.cy.un_530  lt.hu.lv_632 lt.sn.rm_542 
  0x1f0262a4, 0x0f100e12, 0x0f4910ee, 0x483725a0,   // kha.da.cy_433 is.lt.lv_654  lt.to.lv_422 mn.ba.tt_322 
  0x10423ea0, 0x5900640d, 0x4a0d52ee, 0x6b281a0b,   // rm.co.lt_322 lg.rn.un_540  ha.cs.yo_422 tl.sw.ceb_542 
  0x65004713, 0x022f52a0, 0x372f750c, 0x4400341b,   // sn.gv.un_650 ha.su.da_322  nso.su.st_543 ps.kk.un_770 
  // [1d340]
  0x73673707, 0x23795304, 0x5a103e07, 0x4a005d08,   // st.ak.ny_432 ht.war.ca_332  rm.lt.sm_432 ss.yo.un_430 
  0x10006b12, 0x343b2805, 0x55095e0c, 0x5e685daf,   // ceb.lt.un_640 sd.ks.ps_333  ts.pl.rw_543 ss.ig.ts_655 
  0x110d2911, 0x0a00450d, 0x02002c04, 0x39001807,   // sl.cs.ro_653 ln.pt.un_540  fy.da.un_320 ga.br.un_420 
  0x40000209, 0x37001804, 0x233548a4, 0x013f3402,   // da.lb.un_440 ga.st.un_320  tt.tg.ky_433 xh.af.en_222 
  // [1d350]
  0x2400460b, 0x08153504, 0x46321608, 0x25233808,   // qu.eo.un_520 tg.uk.un_320  hr.bs.qu_443 tk.ky.mn_443 
  0x402b23a0, 0xfc5367a4, 0x5e56370d, 0x37005107,   // ca.vi.lb_322 ak.ht.zzp_433  st.mg.ts_554 kl.st.un_420 
  0x335102ee, 0x063f5102, 0x073e4207, 0x3c3036ec,   // da.kl.nn_422 kl.af.de_222  co.rm.it_432 ab.uz.ug_644 
  0x2f3b6011, 0x27004905, 0x4b1f5611, 0x286a4960,   // vo.so.su_653 to.gd.un_330  mg.cy.mi_653 to.haw.sw_664 
  // [1d360]
  0x021210a7, 0x5a0105a0, 0x50373ba0, 0x18213bee,   // lt.hu.da_532 fr.en.sm_322  so.st.fj_322 ks.fa.ar_422 
  0x0e2e18ad, 0x6a025a12, 0x076a02a4, 0x6a00101a,   // ga.fo.is_643 sm.da.haw_654  da.haw.it_433 lt.haw.un_760 
  0x5c5f1e04, 0x27004719, 0x1f00120d, 0x23003d1a,   // ms.tn.sa_332 sn.gd.un_750  hu.cy.un_540 ku.ky.un_760 
  0x3e121012, 0x09697660, 0x2b003e0e, 0x67004b08,   // lt.hu.rm_654 crs.mfe.pl_664  rm.vi.un_550 mi.ak.un_430 
  // [1d370]
  0x5c2747a9, 0x071210ad, 0x4e4601af, 0x5c3b200c,   // sn.gd.sa_544 lt.hu.it_643  en.qu.ay_655 sq.so.sa_543 
  0x04480805, 0x3f33080c, 0x2500470e, 0x27007812,   // uk.tt.ru_333 no.nn.af_543  sn.eu.un_550 ve.gd.un_640 
  0x1000491a, 0x123e10ad, 0x3b0c13a4, 0x044b5002,   // to.lt.un_760 lt.rm.hu_643  et.sv.so_433 fj.mi.fi_222 
  0x33001813, 0x65785da9, 0x5a7901a4, 0x52552811,   // ga.nn.un_650 ss.ve.gv_544  en.war.sm_433 sw.rw.ha_653 
  // [1d380]
  0x2b004611, 0x0a0710a7, 0x040a10ec, 0x2b1d490b,   // qu.vi.un_630 be.bg.mk_532  be.mk.ru_644 to.la.vi_542 
  0x475d04a9, 0x223336a0, 0x30fe375a, 0x321b5e11,   // fi.ss.sn_544 gn.nn.oc_322  st.tlh.uz_553 ts.tr.bs_653 
  0x4700421b, 0x64635da0, 0x353406af, 0x470d2dad,   // co.sn.un_770 ss.sco.lg_322  de.xh.zu_655 sk.cs.sn_643 
  0x75370d0c, 0x37005d1a, 0xfe353413, 0x64301004,   // cs.st.nso_543 ss.st.un_760  xh.zu.tlh_665 lt.uz.lg_332 
  // [1d390]
  0x3e001119, 0x3e420a60, 0x7500372c, 0x0f005412,   // ro.rm.un_750 pt.co.rm_664  st.nso.un_990 ik.lv.un_640 
  0x43620d05, 0x1000060d, 0x48004707, 0x07100812,   // cs.kha.ie_333 de.lt.un_540  sn.tt.un_420 uk.be.bg_654 
  0x480a070c, 0x0d3534a9, 0x47007811, 0x42003614,   // bg.mk.tt_543 xh.zu.cs_544  ve.sn.un_630 gn.co.un_660 
  0x2d060d07, 0x47000c04, 0x3d001808, 0x2dfe0d0c,   // cs.de.sk_432 sv.sn.un_320  ar.ku.un_430 cs.tlh.sk_543 
  // [1d3a0]
  0x360f0ba4, 0xfa001a0d, 0x0d092da4, 0x092739a7,   // es.lv.gn_433 tl.nr.un_540  sk.pl.cs_433 br.gd.pl_532 
  0x214561ec, 0x38311da0, 0x39224d08, 0x11005204,   // za.ln.jw_644 la.az.tk_322  aa.oc.br_443 ha.ro.un_320 
  0x34002a19, 0x2f1922ee, 0x3600050e, 0x39432a13,   // mt.xh.un_750 oc.gl.su_422  fr.gn.un_550 mt.ie.br_665 
  0x05005907, 0x11053912, 0x0b000511, 0x6b1b53a4,   // rn.fr.un_420 br.fr.ro_654  fr.es.un_630 ht.tr.ceb_433 
  // [1d3b0]
  0x2a003602, 0x52006b09, 0x48372309, 0x283d3bec,   // gn.mt.un_220 ceb.ha.un_440  ky.ba.tt_444 ks.ku.sd_644 
  0x4773090b, 0x04483804, 0x07004219, 0xfc4637a7,   // pl.ny.sn_542 tk.tt.ru_332  co.it.un_750 st.qu.zzp_532 
  0x781f46a4, 0x5d464eee, 0x361d43ee, 0x4e00470c,   // qu.cy.ve_433 ay.qu.ss_422  ie.la.gn_422 sn.ay.un_530 
  0x1106030c, 0x4a00470e, 0x554d59ec, 0x05000b0c,   // nl.de.ro_543 sn.yo.un_550  rn.aa.rw_644 es.fr.un_530 
  // [1d3c0]
  0x5955fcee, 0x4800681a, 0x08002521, 0x620d5312,   // zzp.rw.rn_422 ig.tt.un_760  mn.uk.un_860 ht.cs.kha_654 
  0x632f10a4, 0x554e6811, 0x3900fc0d, 0x033ffe0c,   // lt.su.sco_433 ig.ay.rw_653  zzp.br.un_540 tlh.af.nl_543 
  0x79511aa4, 0x3453fc07, 0x462f1013, 0x46024705,   // tl.kl.war_433 zzp.ht.xh_432  lt.su.qu_665 sn.da.qu_333 
  0x555e4e08, 0x2a0661ee, 0x482307a7, 0x523f230c,   // ay.ts.rw_443 za.de.mt_422  bg.ky.tt_532 ca.af.ha_543 
  // [1d3d0]
  0x2f001205, 0x1700100b, 0x68007608, 0x024f57a4,   // hu.su.un_330 lt.sr.un_520  crs.ig.un_430 na.bi.da_433 
  0x22555204, 0x252d0da7, 0x3f2f10a4, 0x3b125904,   // ha.rw.oc_332 cs.sk.eu_532  lt.su.af_433 rn.hu.so_332 
  0x3bfc460c, 0x07422704, 0x2900fc08, 0x3b006a0c,   // qu.zzp.so_543 gd.co.it_332  zzp.sl.un_430 haw.so.un_530 
  0x5d452aa9, 0x3b211b0c, 0x3e101e07, 0x39004e13,   // mt.ln.ss_544 tr.jw.so_543  ms.lt.rm_432 ay.br.un_650 
  // [1d3e0]
  0xfe005d0d, 0x483bfe09, 0x033f26a9, 0x73673b07,   // ss.tlh.un_540 tlh.so.tt_444  ia.af.nl_544 so.ak.ny_432 
  0x36095c07, 0x292d1705, 0x0200100c, 0x5d005902,   // sa.pl.gn_432 sr.sk.sl_333  lt.da.un_530 rn.ss.un_220 
  0x13046408, 0x12005108, 0x101cfc0d, 0x2f5142a9,   // lg.fi.et_443 kl.hu.un_430  zzp.id.lt_554 co.kl.su_544 
  0x2d170d07, 0x6b5f1204, 0x441008ee, 0x2c400c07,   // cs.sr.sk_432 hu.tn.ceb_332  uk.be.kk_422 sv.lb.fy_432 
  // [1d3f0]
  0x5a3b4ba0, 0x13093ba4, 0x56005a0c, 0x13005c18,   // mi.so.sm_322 ks.hi.bh_433  sm.mg.un_530 sa.bh.un_740 
  0x2700650e, 0x65233f0c, 0x212813a7, 0x18233411,   // gv.gd.un_550 af.ca.gv_543  et.sw.jw_532 ps.ky.ar_653 
  0x062365a4, 0x63232704, 0x080423a7, 0x371538ad,   // gv.ca.de_433 gd.ca.sco_332  ky.ru.uk_532 tk.ba.un_630 
  0x044b5c05, 0x37381007, 0x1d621e07, 0x30003714,   // sa.mi.fi_333 be.tk.ba_432  ms.kha.la_432 ba.uz.un_660 
  
  // [1d400]
  0x44001019, 0x472b43ee, 0x6b001f05, 0x256a6405,   // be.kk.un_750 ie.vi.sn_422  cy.ceb.un_330 lg.haw.eu_333 
  0x472718af, 0x472701a4, 0x1828270c, 0x35366a0c,   // ga.gd.sn_655 en.gd.sn_433  gd.sw.ga_543 haw.gn.zu_543 
  0x69000208, 0x2c5851ee, 0x186527a9, 0x3c300808,   // da.mfe.un_430 kl.om.fy_422  gd.gv.ga_544 uk.uz.ug_443 
  0x550424a4, 0x17164605, 0x47456708, 0x63625208,   // eo.fi.rw_433 qu.hr.sr_333  ak.ln.sn_443 ha.kha.sco_443 
  // [1d410]
  0x20616e0d, 0x18344455, 0x65004b22, 0x5c4a6207,   // hmn.za.sq_554 kk.ps.ar_442  mi.gv.un_870 kha.yo.sa_432 
  0x591d34ec, 0x78626e0d, 0x5042350c, 0x550f39ad,   // xh.la.rn_644 hmn.kha.ve_554  zu.co.fj_543 br.lv.rw_643 
  0x30561504, 0x08000a0b, 0x120c50a0, 0x08171014,   // un.mg.uz_332 mk.uk.un_520  fj.sv.hu_322 be.sr.uk_666 
  0x35005d23, 0x58003409, 0x300438a7, 0x42321704,   // ss.zu.un_880 xh.om.un_440  tk.ru.uz_532 sr.bs.co_332 
  // [1d420]
  0x35002b08, 0x5d5e3513, 0x32174210, 0x32001718,   // vi.zu.un_430 zu.ts.ss_665  co.sr.bs_642 sr.bs.un_740 
  0x1110150c, 0x320f42a7, 0x36181f07, 0x22232408,   // un.be.ro_543 co.lv.bs_532  cy.ga.gn_432 eo.ca.oc_443 
  0x39330802, 0x2e3f0e07, 0x3f03610c, 0x1f000e07,   // no.nn.br_222 is.af.fo_432  za.nl.af_543 is.cy.un_420 
  0x08021809, 0x231828a0, 0x29000802, 0x0a0738ad,   // ga.da.no_444 sd.ar.ky_322  no.sl.un_220 tk.bg.mk_643 
  // [1d430]
  0x28023612, 0x19400e0c, 0x304423ee, 0x23592213,   // gn.da.sw_654 is.lb.gl_543  ky.kk.uz_422 oc.rn.ca_665 
  0x59257804, 0x104435a0, 0x650e01a0, 0x3d3418ec,   // ve.eu.rn_332 tg.kk.be_322  en.is.gv_322 ar.ps.ku_644 
  0x230621a4, 0x02003312, 0x023536a0, 0x3f331208,   // jw.de.ca_433 nn.da.un_640  gn.zu.da_322 hu.nn.af_443 
  0x58595555, 0x34001002, 0x552509a0, 0x0e2e36a4,   // rw.rn.om_442 lt.xh.un_220  pl.eu.rw_322 gn.fo.is_433 
  // [1d440]
  0x466503ec, 0x2d190d09, 0x380d2da7, 0x123b3d08,   // nl.gv.qu_644 cs.gl.sk_444  sk.cs.tk_532 ku.ks.ur_443 
  0x644006a4, 0x1000180c, 0x120f10ee, 0x496a100b,   // de.lb.lg_433 ga.lt.un_530  lt.lv.hu_422 lt.haw.to_542 
  0x52510204, 0x21343b0d, 0x04581e04, 0x07482307,   // da.kl.ha_332 ks.ps.fa_554  ms.om.fi_332 ky.tt.bg_432 
  0x494b6aac, 0x0c061fac, 0x10000214, 0x04084809,   // haw.mi.to_632 cy.de.sv_632  da.lt.un_660 tt.uk.ru_444 
  // [1d450]
  0x1e1c10ee, 0x123028a0, 0x0a495a07, 0x2f000607,   // lt.id.ms_422 sd.uz.ur_322  sm.to.pt_432 de.su.un_420 
  0x27495aa0, 0x0a00081b, 0x0e0c3309, 0x330e0c5a,   // sm.to.gd_322 uk.mk.un_770  nn.sv.is_444 sv.is.nn_553 
  0x1d5a1a04, 0x23183404, 0x2e0c0e5a, 0x220405a0,   // tl.sm.la_332 ps.ar.ky_332  is.sv.fo_553 fr.fi.oc_322 
  0x4417230d, 0x4b495a0c, 0x153010ec, 0x0c005108,   // ky.sr.kk_554 sm.to.mi_543  be.uz.un_644 kl.sv.un_430 
  // [1d460]
  0x330e0c55, 0x332e0ca4, 0x330e0c04, 0x2311010c,   // sv.is.nn_442 sv.fo.nn_433  sv.is.nn_332 en.ro.ca_543 
  0x262743a9, 0x23003419, 0x17004304, 0x020b6b08,   // ie.gd.ia_544 ps.ky.un_750  ie.sr.un_320 ceb.es.da_443 
  0x430201a4, 0x5c007904, 0x22006b08, 0x090d1104,   // en.da.ie_433 war.sa.un_320  ceb.oc.un_430 ro.cs.pl_332 
  0x43002c05, 0x0d420505, 0x232622a4, 0x3f4b01a0,   // fy.ie.un_330 fr.co.cs_333  oc.ia.ca_433 en.mi.af_322 
  // [1d470]
  0x321701a0, 0x36685305, 0x5c09130b, 0x6800022c,   // en.sr.bs_322 ht.ig.gn_333  bh.hi.sa_542 da.ig.un_990 
  0x431501a9, 0x221543a9, 0x070c25a4, 0x2b1c01a4,   // en.ie.un_540 ie.oc.un_540  eu.sv.it_433 en.id.vi_433 
  0x401d26a4, 0x20256711, 0x29165c07, 0x50001119,   // ia.la.lb_433 ak.eu.sq_653  sa.hr.sl_432 ro.fj.un_750 
  0x68000822, 0x67001d08, 0x53287307, 0x6e6b6807,   // no.ig.un_870 la.ak.un_430  ny.sw.ht_432 ig.ceb.hmn_432 
  // [1d480]
  0x34103555, 0x12025707, 0x39006808, 0x381b6712,   // zu.lt.xh_442 na.da.hu_432  ig.br.un_430 ak.tr.tk_654 
  0x593655af, 0x2856475a, 0x0e004604, 0x2f453607,   // rw.gn.rn_655 sn.mg.sw_553  qu.is.un_320 gn.ln.su_432 
  0x5c255713, 0x153507a4, 0x4a654ba9, 0x6853500c,   // na.eu.sa_665 bg.tg.un_433  mi.gv.yo_544 fj.ht.ig_543 
  0x210c4c0d, 0x23303707, 0x1d2433ad, 0x0a0723ec,   // wo.sv.jw_554 ba.uz.ky_432  nn.eo.la_643 ky.bg.mk_644 
  // [1d490]
  0x08100ca0, 0x63016813, 0x68134ba4, 0x172e0c55,   // sv.lt.no_322 ig.en.sco_665  mi.et.ig_433 sv.fo.sr_442 
  0x630f1012, 0x35284704, 0x33240c07, 0x481b31a7,   // lt.lv.sco_654 sn.sw.zu_332  sv.eo.nn_432 az.tr.tt_532 
  0x4d002614, 0x0a000902, 0x481b31ee, 0x07173007,   // ia.aa.un_660 pl.pt.un_220  az.tr.tt_422 uz.sr.bg_432 
  0x17000f0b, 0x135c63a4, 0x12390107, 0x03565e08,   // lv.sr.un_520 sco.sa.et_433  en.br.hu_432 ts.mg.nl_443 
  // [1d4a0]
  0x12083311, 0x01250207, 0x0c001012, 0x325c23a4,   // nn.no.hu_653 da.eu.en_432  lt.sv.un_640 ca.sa.bs_433 
  0x44183ca9, 0x3310620c, 0xfe5e37a9, 0x025e030c,   // ug.ar.kk_544 kha.lt.nn_543  st.ts.tlh_544 nl.ts.da_543 
  0x30fe3b0d, 0x755e370d, 0x1105070c, 0x08006508,   // so.tlh.uz_554 st.ts.nso_554  it.fr.ro_543 gv.no.un_430 
  0x47003908, 0x130c37a0, 0x6500750c, 0x3534060c,   // br.sn.un_430 st.sv.et_322  nso.gv.un_530 de.xh.zu_543 
  // [1d4b0]
  0x47000113, 0x1c000d2b, 0x61005e13, 0x53764a08,   // en.sn.un_650 ne.mr.un_980  ts.za.un_650 yo.crs.ht_443 
  0x1b3730a4, 0x6100730e, 0x255a4b11, 0x1c73670d,   // uz.st.tr_433 ny.za.un_550  mi.sm.eu_653 ak.ny.id_554 
  0x4a255704, 0x021018a0, 0x100423a0, 0x093f0da0,   // na.eu.yo_332 ga.lt.da_322  ky.ru.be_322 cs.af.pl_322 
  0x38302702, 0x271839ad, 0x090d3fa0, 0x4437480b,   // gd.uz.tk_222 br.ga.gd_643  af.cs.pl_322 tt.ba.kk_542 
  // [1d4c0]
  0x481123ad, 0x3b18210e, 0x190b2ba0, 0x1823300c,   // ky.ro.tt_643 fa.ar.ks_555  vi.es.gl_322 uz.ky.ar_543 
  0x12006207, 0x37233004, 0x20380c09, 0x02653855,   // kha.hu.un_420 uz.ky.ba_332  sv.tk.sq_444 tk.gv.da_442 
  0x0e005002, 0xfc652ead, 0x0b000102, 0x1c001208,   // fj.is.un_220 fo.gv.zzp_643  en.es.un_220 hu.id.un_430 
  0x38000e0e, 0x3c3823ad, 0x44152313, 0x63381da0,   // is.tk.un_550 ky.tk.ug_643  ky.kk.un_650 la.tk.sco_322 
  // [1d4d0]
  0x63601d08, 0x3c444813, 0x49385a04, 0x484438ec,   // la.vo.sco_443 tt.kk.ug_665  sm.tk.to_332 tk.kk.tt_644 
  0x3d23215a, 0x18270e02, 0x116563ee, 0x35241004,   // fa.ky.ku_553 is.gd.ga_222  sco.gv.ro_422 lt.eo.zu_332 
  0x5e5d3508, 0x4a1024ad, 0x34301212, 0x5f3475a6,   // zu.ss.ts_443 eo.lt.yo_643  ur.uz.ps_654 nso.xh.tn_521 
  0x5f34600c, 0x35375fa4, 0x10001208, 0x5e072807,   // vo.xh.tn_543 tn.st.zu_433  hu.lt.un_430 sw.it.ts_432 
  // [1d4e0]
  0x02471060, 0x556825af, 0x10002413, 0x4c00640e,   // lt.sn.da_664 eu.ig.rw_655  eo.lt.un_650 lg.wo.un_550 
  0x24001d02, 0x4d643ba9, 0x1ffc13a4, 0x50095c07,   // la.eo.un_220 so.lg.aa_544  et.zzp.cy_433 sa.pl.fj_432 
  0x1d1368ee, 0x36107508, 0xfc1f06a0, 0x75241009,   // ig.et.la_422 nso.lt.gn_443  de.cy.zzp_322 lt.eo.nso_444 
  0x0a171114, 0x13330805, 0x466b42a4, 0x0d4f0107,   // ro.sr.mk_666 no.nn.et_333  co.ceb.qu_433 en.bi.cs_432 
  // [1d4f0]
  0x04004a04, 0x471b6404, 0x38001211, 0x5e4750a0,   // yo.fi.un_320 lg.tr.sn_332  hu.tk.un_630 fj.sn.ts_322 
  0x25003602, 0x69102208, 0x5a1149a9, 0x18656aa0,   // gn.eu.un_220 oc.lt.mfe_443  to.ro.sm_544 haw.gv.ga_322 
  0x2b1e1c04, 0x4bfe56a4, 0x1228490c, 0x0d305214,   // id.ms.vi_332 mg.tlh.mi_433  to.sw.hu_543 ha.uz.cs_666 
  0x34621fa7, 0x4929670c, 0x5e0256a4, 0x78072f0c,   // cy.kha.xh_532 ak.sl.to_543  mg.da.ts_433 su.it.ve_543 
  // [1d500]
  0x6a6b37a4, 0x5f504508, 0x560230a4, 0x24081fa9,   // st.ceb.haw_433 ln.fj.tn_443  uz.da.mg_433 cy.no.eo_544 
  0x6956760c, 0x25006a07, 0x1876270c, 0x5f1e3707,   // crs.mg.mfe_543 haw.eu.un_420  gd.crs.ga_543 st.ms.tn_432 
  0x56305fa4, 0x5f2860a4, 0x272c6512, 0x502307a0,   // tn.uz.mg_433 vo.sw.tn_433  gv.fy.gd_654 it.ca.fj_322 
  0x56002a1a, 0x5c0d1c0d, 0x6a595504, 0x342d25ee,   // mt.mg.un_760 mr.ne.sa_554  rw.rn.haw_332 eu.sk.xh_422 
  // [1d510]
  0x49475aa0, 0x34476508, 0x35552507, 0x2835300c,   // sm.sn.to_322 gv.sn.xh_443  eu.rw.zu_432 uz.zu.sw_543 
  0x6b5f1a09, 0x2018275a, 0x27264308, 0x022f49a4,   // tl.tn.ceb_444 gd.ga.sq_553  ie.ia.gd_443 to.su.da_433 
  0x4b005a08, 0x08026705, 0x5043fea4, 0xfe6a4baf,   // sm.mi.un_430 ak.da.no_333  tlh.ie.fj_433 mi.haw.tlh_655 
  0x372718ad, 0x422343ee, 0x0400fe19, 0x4b55fea7,   // ga.gd.st_643 ie.ca.co_422  tlh.fi.un_750 tlh.rw.mi_532 
  // [1d520]
  0x2afe5e0c, 0x4902040c, 0x62006e2b, 0x53006e12,   // ts.tlh.mt_543 fi.da.to_543  hmn.kha.un_980 hmn.ht.un_640 
  0x1e1c1d0c, 0x1d60125a, 0x6e00621a, 0x1e006e08,   // la.id.ms_543 hu.vo.la_553  kha.hmn.un_760 hmn.ms.un_430 
  0x073530a0, 0x10350408, 0x04081105, 0x301723a0,   // uz.tg.bg_322 ru.tg.be_443  ro.uk.ru_333 ky.sr.uz_322 
  0x3f001502, 0x312e0e60, 0x2c1b5c0b, 0x481523ec,   // un.af.un_220 is.fo.az_664  sa.tr.fy_542 ky.tt.un_640 
  // [1d530]
  0x31211ca4, 0x05004602, 0x041110ad, 0x31002e1a,   // id.jw.az_433 qu.fr.un_220  be.ro.ru_643 fo.az.un_760 
  0x630e2e07, 0x2d2e21ee, 0x22113eee, 0x011d430c,   // fo.is.sco_432 jw.fo.sk_422  rm.ro.oc_422 ie.la.en_543 
  0x05395305, 0x21000b04, 0x691e1c05, 0x421f05ee,   // ht.br.fr_333 es.jw.un_320  id.ms.mfe_333 fr.cy.co_422 
  0x1d000708, 0x32162904, 0x420a05ee, 0x690502a4,   // it.la.un_430 sl.hr.bs_332  fr.pt.co_422 da.fr.mfe_433 
  // [1d540]
  0x0467130c, 0x531c05ee, 0x303c35a4, 0x2b003302,   // et.ak.fi_543 fr.id.ht_422  tg.ug.uz_433 nn.vi.un_220 
  0x4d1c290c, 0x4835365a, 0x1b290d0b, 0x2a0833a4,   // sl.id.aa_543 ab.tg.tt_553  cs.sl.tr_542 nn.no.mt_433 
  0x6b1a1f04, 0x52025e55, 0x13504e07, 0x1e1f1ca0,   // cy.tl.ceb_332 ts.da.ha_442  ay.fj.et_432 id.cy.ms_322 
  0x481c2f02, 0x2d0979a7, 0x17040a12, 0x11001213,   // su.id.tt_222 war.pl.sk_532  mk.ru.sr_654 hu.ro.un_650 
  // [1d550]
  0x466b2faf, 0x462f1c08, 0xfc1f2aa4, 0x29170d02,   // su.ceb.qu_655 id.su.qu_443  mt.cy.zzp_433 cs.sr.sl_222 
  0x1f2d2908, 0x6a494baf, 0x1b3133a9, 0x4800390c,   // sl.sk.cy_443 mi.to.haw_655  nn.az.tr_544 br.tt.un_530 
  0x26fc010c, 0x5a104b05, 0x18311b04, 0x5c6a4b08,   // en.zzp.ia_543 mi.lt.sm_333  tr.az.ga_332 mi.haw.sa_443 
  0x4d00641b, 0x110a380e, 0x152504af, 0x656e2707,   // lg.aa.un_770 tk.mk.ro_555  ru.mn.un_655 gd.hmn.gv_432 
  // [1d560]
  0x0f104ba7, 0x1a002705, 0x4b006a22, 0xfc020c04,   // mi.lt.lv_532 gd.tl.un_330  haw.mi.un_870 sv.da.zzp_332 
  0x2900480d, 0x65271a04, 0x36560255, 0x26002405,   // tt.sl.un_540 tl.gd.gv_332  da.mg.gn_442 eo.ia.un_330 
  0x34391ea0, 0x6a04fc08, 0x482e36a0, 0x7327250c,   // ms.br.xh_322 zzp.fi.haw_443  gn.fo.tt_322 eu.gd.ny_543 
  0x0a054aa7, 0x46210c55, 0x22001219, 0x4a311baf,   // yo.fr.pt_532 sv.jw.qu_442  hu.oc.un_750 tr.az.yo_655 
  // [1d570]
  0x56001507, 0x65271f08, 0x4a003e13, 0x652723a4,   // un.mg.un_420 cy.gd.gv_443  rm.yo.un_650 ca.gd.gv_433 
  0x15010307, 0x1f003613, 0x2500130e, 0x63653eac,   // nl.en.un_432 gn.cy.un_650  et.eu.un_550 rm.gv.sco_632 
  0x460342a0, 0x02210f13, 0x052f0aa0, 0x1500020c,   // co.nl.qu_322 lv.jw.da_665  pt.su.fr_322 da.un.un_530 
  0x56003e05, 0x181e02a0, 0x0d322da0, 0x2e330814,   // rm.mg.un_330 da.ms.ga_322  sk.bs.cs_322 no.nn.fo_666 
  // [1d580]
  0x530e69a4, 0x580e1804, 0x3b595804, 0x2e40060c,   // mfe.is.ht_433 ga.is.om_332  om.rn.so_332 de.lb.fo_543 
  0x13fe0407, 0x40581d04, 0x01582eee, 0x44101511,   // fi.tlh.et_432 la.om.lb_332  fo.om.en_422 un.be.kk_653 
  0x4400350b, 0x047664ec, 0x4c052f08, 0x212f2e07,   // tg.kk.un_520 lg.crs.fi_644  su.fr.wo_443 fo.su.jw_432 
  0x10006113, 0x69001f14, 0x28006309, 0x65403ea9,   // za.lt.un_650 cy.mfe.un_660  sco.sw.un_440 rm.lb.gv_544 
  // [1d590]
  0x2e0e1508, 0x556367ad, 0x52002405, 0x3e1f10a0,   // un.is.fo_443 ak.sco.rw_643  eo.ha.un_330 lt.cy.rm_322 
  0x3000fc0c, 0x652463ee, 0x4c2f2104, 0x222f0560,   // zzp.uz.un_530 sco.eo.gv_422  jw.su.wo_332 fr.su.oc_664 
  0x2d0d300e, 0x233c1112, 0x272c1fad, 0x0602520c,   // uz.cs.sk_555 ro.ug.ky_654  cy.fy.gd_643 ha.da.de_543 
  0x52003e04, 0x2f362112, 0x0a04070b, 0x5d561f5a,   // rm.ha.un_320 jw.gn.su_654  bg.ru.mk_542 cy.mg.ss_553 
  // [1d5a0]
  0x5e002823, 0x1500172a, 0x2b00fe0c, 0x36001912,   // sw.ts.un_880 sr.un.un_970  tlh.vi.un_530 gl.gn.un_640 
  0x27000308, 0x5e1f2b07, 0x3459550e, 0x6509fc04,   // nl.gd.un_430 vi.cy.ts_432  rw.rn.xh_555 zzp.pl.gv_332 
  0x6e002b2c, 0x5d284008, 0x3c123da7, 0x0900101b,   // vi.hmn.un_990 lb.sw.ss_443  ku.ur.ug_532 lt.pl.un_770 
  0x55000609, 0x06000907, 0x200e2e09, 0x55006804,   // de.rw.un_440 pl.de.un_420  fo.is.sq_444 ig.rw.un_320 
  // [1d5b0]
  0x5a00680c, 0x68005405, 0x3d2821ec, 0x1368fc0d,   // ig.sm.un_530 ik.ig.un_330  fa.sd.ku_644 zzp.ig.et_554 
  0x3e2e0ea7, 0x17482307, 0x074842ee, 0x510254ec,   // is.fo.rm_532 ky.tt.sr_432  co.tt.it_422 ik.da.kl_644 
  0x64512509, 0x55283612, 0x38366455, 0x080a05a9,   // eu.kl.lg_444 gn.sw.rw_654  lg.gn.tk_442 fr.pt.no_544 
  0x102e0e0c, 0x59223609, 0x0f000320, 0x1e021c07,   // is.fo.lt_543 gn.oc.rn_444  nl.lv.un_850 id.da.ms_432 
  // [1d5c0]
  0x2d0d06a9, 0x55002514, 0x033e38a9, 0x5c555207,   // de.cs.sk_544 eu.rw.un_660  tk.rm.nl_544 ha.rw.sa_432 
  0x08022cec, 0x254c0a08, 0x03006011, 0x5154360c,   // fy.da.no_644 pt.wo.eu_443  vo.nl.un_630 gn.ik.kl_543 
  0x21000512, 0x131a360c, 0x554f79ec, 0x5e001d12,   // fr.jw.un_640 gn.tl.et_543  war.bi.rw_644 la.ts.un_640 
  0x01271f04, 0x5e4e540d, 0x391d570c, 0x5e283808,   // cy.gd.en_332 ik.ay.ts_554  na.la.br_543 tk.sw.ts_443 
  // [1d5d0]
  0x58fc3b0c, 0x5f51580d, 0x5d1bfa55, 0x04362255,   // so.zzp.om_543 om.kl.tn_554  nr.tr.ss_442 oc.gn.fi_442 
  0x0a0736ad, 0x21004422, 0x1d391ca0, 0x2a003112,   // ab.bg.mk_643 kk.fa.un_870  id.br.la_322 az.mt.un_640 
  0x07112d0c, 0x64355e5a, 0x3b5e4dee, 0x07422908,   // sk.ro.it_543 ts.zu.lg_553  aa.ts.so_422 sl.co.it_443 
  0x211f47a9, 0x1b0e3107, 0x531e3fad, 0x65005107,   // sn.cy.jw_544 az.is.tr_432  af.ms.ht_643 kl.gv.un_420 
  // [1d5e0]
  0x4c000512, 0x0e003f08, 0x314d5105, 0x124c0c07,   // fr.wo.un_640 af.is.un_430  kl.aa.az_333 sv.wo.hu_432 
  0x01000202, 0x08003305, 0x394206a0, 0x100a3ca4,   // da.en.un_220 nn.no.un_330  de.co.br_322 ug.mk.be_433 
  0x422a2f07, 0x21123d0b, 0x3b12fc04, 0x332e08ee,   // su.mt.co_432 ku.ur.fa_542  zzp.hu.so_332 no.fo.nn_422 
  0x02001305, 0x2f00fc07, 0x3b002f02, 0x11005008,   // et.da.un_330 zzp.su.un_420  su.so.un_220 fj.ro.un_430 
  // [1d5f0]
  0x02006a0d, 0x4c006405, 0x2f583bec, 0x0810045a,   // haw.da.un_540 lg.wo.un_330  so.om.su_644 ru.be.uk_553 
  0x51080204, 0x2e2a0202, 0x50566a5a, 0x1c002113,   // da.no.kl_332 da.mt.fo_222  haw.mg.fj_553 jw.id.un_650 
  0x10001c0d, 0xfe00612a, 0x5a006502, 0x250f6aa4,   // id.lt.un_540 za.tlh.un_970  gv.sm.un_220 haw.lv.eu_433 
  0x39015108, 0x564a6aad, 0x766953a9, 0x27261f0c,   // kl.en.br_443 haw.yo.mg_643  ht.mfe.crs_544 cy.ia.gd_543 
  // [1d600]
  0x05006108, 0x05000122, 0x6100fe1a, 0x63390107,   // za.fr.un_430 en.fr.un_870  tlh.za.un_760 en.br.sco_432 
  0x403f0ca0, 0x3f796b07, 0x69397612, 0x390501a0,   // sv.af.lb_322 ceb.war.af_432  crs.br.mfe_654 en.fr.br_322 
  0x3902050c, 0x0a396109, 0x633e39a7, 0x0518390c,   // fr.da.br_543 za.br.pt_444  br.rm.sco_532 br.ga.fr_543 
  0x653e390c, 0x0251790b, 0x48fe30a7, 0x130f2707,   // br.rm.gv_543 war.kl.da_542  uz.tlh.tt_532 gd.lv.et_432 
  // [1d610]
  0x65fe2a07, 0x39071d0c, 0x6263390c, 0x3e0501a4,   // mt.tlh.gv_432 la.it.br_543  br.sco.kha_543 en.fr.rm_433 
  0x630201a4, 0x1276250c, 0x2a2c620e, 0x185a27a0,   // en.da.sco_433 eu.crs.hu_543  kha.fy.mt_555 gd.sm.ga_322 
  0x23003304, 0x396976ec, 0x6505010c, 0x375f7514,   // nn.ca.un_320 crs.mfe.br_644  en.fr.gv_543 nso.tn.st_666 
  0x5cfe6207, 0x1808020d, 0x347328a0, 0x595525af,   // kha.tlh.sa_432 da.no.ga_554  sw.ny.xh_322 eu.rw.rn_655 
  // [1d620]
  0x79023f05, 0x5e1a4512, 0x7639050c, 0x36534f08,   // af.da.war_333 ln.tl.ts_654  fr.br.crs_543 bi.ht.gn_443 
  0x760501a4, 0x78215b12, 0x47004a12, 0x5062490c,   // en.fr.crs_433 sg.jw.ve_654  yo.sn.un_640 to.kha.fj_543 
  0x053976a0, 0x42072204, 0x73005d09, 0x2f5efcee,   // crs.br.fr_322 oc.it.co_332  ss.ny.un_440 zzp.ts.su_422 
  0x04283b07, 0x7328450d, 0x07420b09, 0xfe314807,   // so.sw.fi_432 ln.sw.ny_554  es.co.it_444 tt.az.tlh_432 
  // [1d630]
  0x29003008, 0x06001122, 0x4c495a08, 0x151137a4,   // uz.sl.un_430 ro.de.un_870  sm.to.wo_443 ba.ro.un_433 
  0x425e11ee, 0x47003008, 0x50304802, 0x206921a4,   // ro.ts.co_422 uz.sn.un_430  tt.uz.fj_222 jw.mfe.sq_433 
  0x452047a9, 0x504d4611, 0x42072907, 0x285e46ec,   // sn.sq.ln_544 qu.aa.fj_653  sl.it.co_432 qu.ts.sw_644 
  0x42286ea7, 0x3735480b, 0x3f005c08, 0x0e5a5ea9,   // hmn.sw.co_532 tt.tg.ba_542  sa.af.un_430 ts.sm.is_544 
  // [1d640]
  0x15154805, 0x49005009, 0x6056690c, 0x02150807,   // tt.un.un_330 fj.to.un_440  mfe.mg.vo_543 no.da.un_420 
  0x5c003407, 0x13002905, 0x5d2d0d11, 0x23fc1da4,   // xh.sa.un_420 sl.et.un_330  cs.sk.ss_653 la.zzp.ca_433 
  0x20575c11, 0x12302109, 0x04073ca7, 0x39122907,   // sa.na.sq_653 fa.uz.ur_444  ug.bg.ru_532 sl.hu.br_432 
  0x30005c05, 0x1d5e2302, 0x5c395e0c, 0x04154802,   // sa.uz.un_330 ca.ts.la_222  ts.br.sa_543 tt.ru.un_220 
  // [1d650]
  0x15000812, 0x10000a0e, 0x48040705, 0x3e281e0b,   // uk.un.un_640 mk.be.un_550  bg.ru.tt_333 ms.sw.rm_542 
  0x0a081113, 0xfc185704, 0x3700020c, 0x453412a4,   // ro.uk.mk_665 na.ga.zzp_332  da.st.un_530 hu.xh.ln_433 
  0x452f37a9, 0x5d7334ee, 0x39002808, 0x22002c0c,   // st.su.ln_544 xh.ny.ss_422  sw.br.un_430 fy.oc.un_530 
  0x0b235907, 0x1048370c, 0x505f470c, 0x27184055,   // rn.ca.es_432 ba.tt.be_543  sn.tn.fj_543 lb.ga.gd_442 
  // [1d660]
  0x2c00260c, 0x64281e04, 0x353836ec, 0x5b0268a4,   // ia.fy.un_530 ms.sw.lg_332  ab.tk.tg_644 ig.da.sg_433 
  0x690253a4, 0x033f20ad, 0x12004705, 0x734a6711,   // ht.da.mfe_433 sq.af.nl_643  sn.hu.un_330 ak.yo.ny_653 
  0x64231d07, 0x65000512, 0x40000a02, 0x2c2720a7,   // la.ca.lg_432 fr.gv.un_640  pt.lb.un_220 sq.gd.fy_532 
  0x076563a0, 0x582c15ec, 0x52001f04, 0x2c420708,   // sco.gv.it_322 un.fy.om_644  cy.ha.un_320 it.co.fy_443 
  // [1d670]
  0x30790605, 0x2f005602, 0x15041011, 0x65093fa0,   // de.war.uz_333 mg.su.un_220  be.ru.un_653 af.pl.gv_322 
  0x363f01a9, 0x522d6211, 0x6b090109, 0x1510080d,   // en.af.gn_544 kha.sk.ha_653  en.pl.ceb_444 uk.be.un_554 
  0x56090da0, 0x3f650907, 0x63095608, 0x3f005611,   // cs.pl.mg_322 pl.gv.af_432  mg.pl.sco_443 mg.af.un_630 
  0x0a184007, 0x096301a0, 0x65003f07, 0x3f000a08,   // lb.ga.pt_432 en.sco.pl_322  af.gv.un_420 pt.af.un_430 
  // [1d680]
  0x08231002, 0x48083c55, 0x0c00300c, 0x03023f14,   // be.ky.uk_222 ug.uk.tt_442  uz.sv.un_530 af.da.nl_666 
  0x40180504, 0x11003821, 0x38000813, 0x35250802,   // fr.ga.lb_332 tk.ro.un_860  uk.tk.un_650 uk.mn.tg_222 
  0x170a1002, 0x253035af, 0x08330c11, 0x25053604,   // be.mk.sr_222 tg.uz.mn_655  sv.nn.no_653 gn.fr.eu_332 
  0x65392c12, 0x4b2c4908, 0x65562ca4, 0x11006507,   // fy.br.gv_654 to.fy.mi_443  fy.mg.gv_433 gv.ro.un_420 
  // [1d690]
  0x28001c05, 0x271c65ac, 0x65115a12, 0x3e1b25a4,   // id.sw.un_330 gv.id.gd_632  sm.ro.gv_654 eu.tr.rm_433 
  0x18005c13, 0x2e003e13, 0x08004204, 0x02006513,   // sa.ga.un_650 rm.fo.un_650  co.no.un_320 gv.da.un_650 
  0x55004504, 0x6500560e, 0x40003608, 0xfc032804,   // ln.rw.un_320 mg.gv.un_550  gn.lb.un_430 sw.nl.zzp_332 
  0x5c002e07, 0x42002a0e, 0x28443412, 0x350730a0,   // fo.sa.un_420 mt.co.un_550  ps.kk.sd_654 uz.bg.tg_322 
  // [1d6a0]
  0x2100370b, 0x313f2008, 0xfe005e11, 0x02564711,   // st.jw.un_520 sq.af.az_443  ts.tlh.un_630 sn.mg.da_653 
  0x75375d0c, 0x0d00fe07, 0x3f125607, 0x52124702,   // ss.st.nso_543 tlh.cs.un_420  mg.hu.af_432 sn.hu.ha_222 
  0x3f1320a9, 0x1d4006ec, 0x2f004008, 0x06103ea0,   // sq.et.af_544 de.lb.la_644  lb.su.un_430 rm.lt.de_322 
  0x1744480c, 0x48000a0c, 0xfe75375a, 0x06001e04,   // tt.kk.sr_543 mk.tt.un_530  st.nso.tlh_553 ms.de.un_320 
  // [1d6b0]
  0x0f481207, 0x5d2d1ba4, 0x24692005, 0x3738250c,   // hu.tt.lv_432 tr.sk.ss_433  sq.mfe.eo_333 mn.tk.ba_543 
  0x305c4ca0, 0x11151713, 0x0f002f02, 0x36004005,   // wo.sa.uz_322 sr.ro.un_650  su.lv.un_220 lb.gn.un_330 
  0x054018ad, 0x651d2704, 0x47005204, 0x231907a4,   // ga.lb.fr_643 gd.la.gv_332  ha.sn.un_320 it.gl.ca_433 
  0x081017a7, 0x1800400b, 0x1000250e, 0x40182212,   // sr.be.uk_532 lb.ga.un_520  eu.lt.un_550 oc.ga.lb_654 
  // [1d6c0]
  0x051840a7, 0x455036a6, 0x271d6808, 0x10515aa4,   // lb.ga.fr_532 gn.fj.ln_521  ig.la.gd_443 sm.kl.lt_433 
  0x2257430c, 0x6567120c, 0x401836a9, 0x12656412,   // ie.na.oc_543 hu.ak.gv_543  gn.ga.lb_544 lg.gv.hu_654 
  0x214018a4, 0x30212812, 0x25005635, 0x283734a0,   // ga.lb.jw_433 sd.fa.uz_654  mg.eu.un_A90 xh.st.sw_322 
  0x1b534504, 0x36401808, 0x73477812, 0x353445af,   // ln.ht.tr_332 ga.lb.gn_443  ve.sn.ny_654 ln.xh.zu_655 
  // [1d6d0]
  0x17113605, 0x36184008, 0x40183604, 0x311b240c,   // ab.ro.sr_333 lb.ga.gn_443  gn.ga.lb_332 eo.tr.az_543 
  0x79330808, 0x28182155, 0x170a100c, 0x1d00580c,   // no.nn.war_443 fa.ar.sd_442  be.mk.sr_543 om.la.un_530 
  0x1f2706a0, 0x40003009, 0x634d5807, 0x1f654708,   // de.gd.cy_322 uz.lb.un_440  om.aa.sco_432 sn.gv.cy_443 
  0x2d0d1d05, 0x04000c0b, 0x39292d07, 0x291d0d0c,   // la.cs.sk_333 sv.fi.un_520  sk.sl.br_432 cs.la.sl_543 
  // [1d6e0]
  0x19002219, 0x220543a7, 0x0d292dec, 0x0e0901a0,   // oc.gl.un_750 ie.fr.oc_532  sk.sl.cs_644 en.pl.is_322 
  0x23223908, 0x632f02a0, 0x031b29ee, 0x15654212,   // br.oc.ca_443 da.su.sco_322  sl.tr.nl_422 co.gv.un_654 
  0x03020655, 0x470229a4, 0x03000608, 0x10002d1b,   // de.da.nl_442 sl.da.sn_433  de.nl.un_430 sk.lt.un_770 
  0x1500020d, 0x4b003604, 0x29182da4, 0x38302309,   // da.un.un_540 gn.mi.un_320  sk.ga.sl_433 ky.uz.tk_444 
  // [1d6f0]
  0x22191d08, 0x482336a0, 0x292d48a0, 0x253848a9,   // la.gl.oc_443 ab.ky.tt_322  tt.sk.sl_322 tt.tk.eu_544 
  0x30357307, 0x1b3125ad, 0x3b586412, 0x4a00640e,   // ny.zu.uz_432 eu.az.tr_643  lg.om.so_654 lg.yo.un_550 
  0x35005e19, 0x4b6a1109, 0x3761feec, 0x51fe4ead,   // ts.zu.un_750 ro.haw.mi_444  tlh.za.st_644 ay.tlh.kl_643 
  0x4b2527a0, 0x37170aa4, 0x4b2523a9, 0x5100fe04,   // gd.eu.mi_322 mk.sr.ba_433  ca.eu.mi_544 tlh.kl.un_320 
  // [1d700]
  0x4b1d690d, 0x04002702, 0x504001a0, 0x64351fee,   // mfe.la.mi_554 gd.fi.un_220  en.lb.fj_322 cy.zu.lg_422 
  0x4f045712, 0x48615805, 0x230f5008, 0x48003b18,   // na.fi.bi_654 om.za.tt_333  fj.lv.ca_443 so.tt.un_740 
  0x22635208, 0x11001813, 0x22633f55, 0x115c25a4,   // ha.sco.oc_443 ga.ro.un_650  af.sco.oc_442 eu.sa.ro_433 
  0x61fe4dad, 0x4826fea4, 0x464a4708, 0x4011fc05,   // aa.tlh.za_643 tlh.ia.tt_433  sn.yo.qu_443 zzp.ro.lb_333 
  // [1d710]
  0xfe464da4, 0x4c46fead, 0x50285a05, 0x465c4ba7,   // aa.qu.tlh_433 tlh.qu.wo_643  sm.sw.fj_333 mi.sa.qu_532 
  0x472f52ec, 0x4a596b0c, 0x58100f12, 0x5c4247a9,   // ha.su.sn_644 ceb.rn.yo_543  lv.lt.om_654 sn.co.sa_544 
  0x5c0221a4, 0xfc2147a0, 0x520264ec, 0x2cfc2712,   // jw.da.sa_433 sn.jw.zzp_322  lg.da.ha_644 gd.zzp.fy_654 
  0x09062dad, 0x4700040e, 0x59553609, 0x52476355,   // sk.de.pl_643 fi.sn.un_550  gn.rw.rn_444 sco.sn.ha_442 
  // [1d720]
  0x582501a0, 0x104b500d, 0x53696407, 0x453173a4,   // en.eu.om_322 fj.mi.lt_554  lg.mfe.ht_432 ny.az.ln_433 
  0x2a383012, 0x521b6705, 0x3b2a4c07, 0x6455330c,   // uz.tk.mt_654 ak.tr.ha_333  wo.mt.so_432 nn.rw.lg_543 
  0x0000552d, 0x07031da7, 0x6400450c, 0x6b2511a4,   // rw.un.un_A00 la.nl.it_532  ln.lg.un_530 ro.eu.ceb_433 
  0x35475da4, 0x1263610c, 0x483bfeec, 0x240c0f0c,   // ss.sn.zu_433 za.sco.hu_543  tlh.so.tt_644 lv.sv.eo_543 
  // [1d730]
  0x1711380c, 0x5230130d, 0x35080402, 0x1a695308,   // tk.ro.sr_543 et.uz.ha_554  ru.uk.tg_222 ht.mfe.tl_443 
  0x3f5359a4, 0x5c000213, 0x1b004621, 0x12212812,   // rn.ht.af_433 da.sa.un_650  qu.tr.un_860 sd.fa.ur_654 
  0x1004150e, 0x0a043002, 0x170f2da0, 0x392d0d60,   // un.ru.be_555 uz.ru.mk_222  sk.lv.sr_322 cs.sk.br_664 
  0x674656a4, 0x07303cee, 0x35302555, 0x100a1507,   // mg.qu.ak_433 ug.uz.bg_422  mn.uz.tg_442 un.mk.be_432 
  // [1d740]
  0x13004309, 0x150a110c, 0x354844ad, 0x3d211812,   // ie.et.un_440 ro.mk.un_543  kk.tt.tg_643 ar.fa.ku_654 
  0x11001802, 0x1e521ca9, 0x351a5daf, 0x08300405,   // ga.ro.un_220 id.ha.ms_544  ss.tl.zu_655 ru.uz.uk_333 
  0x5c385212, 0x1c2f690c, 0x1a00640d, 0x1e681ca9,   // ha.tk.sa_654 mfe.su.id_543  lg.tl.un_540 id.ig.ms_544 
  0x582206a4, 0x53002309, 0x1f2301a0, 0x527909a4,   // de.oc.om_433 ca.ht.un_440  en.ca.cy_322 pl.war.ha_433 
  // [1d750]
  0x166546ee, 0x28781f0c, 0x2d0d46a9, 0x52381aa4,   // qu.gv.hr_422 cy.ve.sw_543  qu.cs.sk_544 tl.tk.ha_433 
  0x24001704, 0x1f121809, 0x172338a7, 0x532147a0,   // sr.eo.un_320 ga.hu.cy_444  tk.ky.sr_532 sn.jw.ht_322 
  0x3858520d, 0x5e534708, 0x28006709, 0x1f7901a4,   // ha.om.tk_554 sn.ht.ts_443  ak.sw.un_440 en.war.cy_433 
  0x3521fca0, 0x0600422b, 0x30fe67a4, 0x3e27185a,   // zzp.jw.zu_322 co.de.un_980  ak.tlh.uz_433 ga.gd.rm_553 
  // [1d760]
  0x213d1805, 0x55345d02, 0x3b3f58ee, 0x5d004508,   // ar.ku.fa_333 ss.xh.rw_222  om.af.so_422 ln.ss.un_430 
  0x68004514, 0x135e2dee, 0x50004213, 0x5e0436a9,   // ln.ig.un_660 sk.ts.et_422  co.fj.un_650 gn.fi.ts_544 
  0x04475eec, 0x101142ee, 0x5830510c, 0x58311b0c,   // ts.sn.fi_644 co.ro.lt_422  kl.uz.om_543 tr.az.om_543 
  0x500f47af, 0x791b0208, 0x01564707, 0x73005908,   // sn.lv.fj_655 da.tr.war_443  sn.mg.en_432 rn.ny.un_430 
  // [1d770]
  0x13021004, 0x135d64a0, 0x321750a0, 0x392425a0,   // lt.da.et_332 lg.ss.et_322  fj.sr.bs_322 eu.eo.br_322 
  0x461c1bee, 0x30482004, 0x52351107, 0x5955120e,   // tr.id.qu_422 sq.tt.uz_332  ro.zu.ha_432 hu.rw.rn_555 
  0x56586755, 0x2900260c, 0x0f000502, 0x0c005d04,   // ak.om.mg_442 ia.sl.un_530  fr.lv.un_220 ss.sv.un_320 
  0x3610500d, 0x0c473612, 0x36495007, 0x645335ad,   // fj.lt.gn_554 gn.sn.sv_654  fj.to.gn_432 zu.ht.lg_643 
  // [1d780]
  0x2410390c, 0x311b4eee, 0x021b3105, 0x022835a4,   // br.lt.eo_543 ay.tr.az_422  az.tr.da_333 zu.sw.da_433 
  0x16024711, 0x5c52570c, 0x2e040e0e, 0x13093b02,   // sn.da.hr_653 na.ha.sa_543  is.fi.fo_555 so.pl.et_222 
  0x1a093b07, 0x03473f04, 0x0d3b1e07, 0x28355d02,   // so.pl.tl_432 af.sn.nl_332  ms.so.cs_432 ss.zu.sw_222 
  0x2c041313, 0x5a3f0207, 0x536976a9, 0x65003f0e,   // et.fi.fy_665 da.af.sm_432  crs.mfe.ht_544 af.gv.un_550 
  // [1d790]
  0x791a0ba9, 0x2302fe04, 0x1d005c05, 0x3f004907,   // es.tl.war_544 tlh.da.ca_332  sa.la.un_330 to.af.un_420 
  0x63006519, 0x3f653b07, 0x31423ba7, 0x32004707,   // gv.sco.un_750 so.gv.af_432  so.co.az_532 sn.bs.un_420 
  0x515a3fa0, 0x34023f07, 0x4d004713, 0x133e5607,   // af.sm.kl_322 af.da.xh_432  sn.aa.un_650 mg.rm.et_432 
  0x473f65af, 0x100a15a0, 0x3f471008, 0x24070104,   // gv.af.sn_655 un.mk.be_322  lt.sn.af_443 en.it.eo_332 
  // [1d7a0]
  0x0f00292b, 0x2900090c, 0x47655a12, 0x2c034704,   // sl.lv.un_980 pl.sl.un_530  sm.gv.sn_654 sn.nl.fy_332 
  0x53110c0c, 0x09006505, 0x5a005107, 0xfe313012,   // sv.ro.ht_543 gv.pl.un_330  kl.sm.un_420 uz.az.tlh_654 
  0x025c0f11, 0x03513fec, 0x25002a08, 0x2c001b02,   // lv.sa.da_653 af.kl.nl_644  mt.eu.un_430 tr.fy.un_220 
  0x112a4d04, 0x6b2a300d, 0x515a2c02, 0x6e000d09,   // aa.mt.ro_332 uz.mt.ceb_554  fy.sm.kl_222 cs.hmn.un_440 
  // [1d7b0]
  0x11000a17, 0x2e0e0904, 0x033f2355, 0x040a0808,   // pt.ro.un_730 pl.is.fo_332  ca.af.nl_442 uk.mk.ru_443 
  0x130e2ead, 0xfc1d6912, 0x130e2e04, 0x0a35150c,   // fo.is.et_643 mfe.la.zzp_654  fo.is.et_332 un.tg.mk_543 
  0x12283da7, 0x29002d19, 0x0c30fe05, 0x0c3f640c,   // ku.sd.ur_532 sk.sl.un_750  tlh.uz.sv_333 lg.af.sv_543 
  0x07040aac, 0x27005607, 0x75fe5f12, 0x424d6407,   // mk.ru.bg_632 mg.gd.un_420  tn.tlh.nso_654 lg.aa.co_432 
  // [1d7c0]
  0x30373807, 0x0e2e46ee, 0xfe0e4207, 0x425c0e55,   // tk.ba.uz_432 qu.fo.is_422  co.is.tlh_432 is.sa.co_442 
  0x151f5ca9, 0x421f63a4, 0x685755af, 0x0e2e6912,   // sa.cy.un_544 sco.cy.co_433  rw.na.ig_655 mfe.fo.is_654 
  0x4c001f07, 0x4c3b5812, 0x183d3b0b, 0x272865a6,   // cy.wo.un_420 om.so.wo_654  ks.ku.ar_542 gv.sw.gd_521 
  0x4c21360c, 0x096468ac, 0x554d67a4, 0x574d2eaf,   // gn.jw.wo_543 ig.lg.pl_632  ak.aa.rw_433 fo.aa.na_655 
  // [1d7d0]
  0x630701a0, 0x65426307, 0x1d576807, 0x09000e0d,   // en.it.sco_322 sco.co.gv_432  ig.na.la_432 is.pl.un_540 
  0x3e224a5a, 0x64004c21, 0x2d0911a7, 0x582565a4,   // yo.oc.rm_553 wo.lg.un_860  ro.pl.sk_532 gv.eu.om_433 
  0x652501a4, 0x303f2c04, 0x2b181fa0, 0x4300250d,   // en.eu.gv_433 fy.af.uz_332  cy.ga.vi_322 eu.ie.un_540 
  0x2f1a1c0c, 0x4f21fca4, 0x053e76a4, 0x1e1c2a0c,   // id.tl.su_543 zzp.jw.bi_433  crs.rm.fr_433 mt.id.ms_543 
  // [1d7e0]
  0x21225302, 0x530576af, 0x080a35a7, 0x23001719,   // ht.oc.jw_222 crs.fr.ht_655  tg.mk.uk_532 sr.ky.un_750 
  0x04073004, 0x182527ec, 0x056201a0, 0x09306ead,   // uz.bg.ru_332 gd.eu.ga_644  en.kha.fr_322 hmn.uz.pl_643 
  0x1a211e07, 0x530576ad, 0x1a5a5012, 0x05530d0c,   // ms.jw.tl_432 crs.fr.ht_643  fj.sm.tl_654 cs.ht.fr_543 
  0x48353008, 0x4a006820, 0x04646855, 0x51000d02,   // uz.tg.tt_443 ig.yo.un_850  ig.lg.fi_442 cs.kl.un_220 
  // [1d7f0]
  0x0e2e27a9, 0x213568a0, 0x233b3d11, 0x3b003d2b,   // gd.fo.is_544 ig.zu.jw_322  ku.ks.ky_653 ku.ks.un_980 
  0x02621fa4, 0x25001b04, 0x08006304, 0x53001002,   // cy.kha.da_433 tr.eu.un_320  sco.no.un_320 lt.ht.un_220 
  0x1f0c62ee, 0x1f00620b, 0x021d1907, 0x15232555,   // kha.sv.cy_422 kha.cy.un_520  gl.la.da_432 mn.ky.un_442 
  0x281546ee, 0x2134120b, 0x0815040e, 0x132e0e0c,   // qu.sw.un_420 ur.ps.fa_542  ru.uk.un_550 is.fo.et_543 
  
  // [1d800]
  0x62000804, 0x381b3008, 0x30000219, 0x5e0913a0,   // no.kha.un_320 uz.tr.tk_443  da.uz.un_750 et.pl.ts_322 
  0x28185808, 0x1d56010b, 0x2c4206a0, 0x636b01ee,   // om.ga.sw_443 en.mg.la_542  de.co.fy_322 en.ceb.sco_422 
  0x38625660, 0x27003307, 0x1b303eee, 0x47093804,   // mg.kha.tk_664 nn.gd.un_420  rm.uz.tr_422 tk.pl.sn_332 
  0x375f1e07, 0x03643955, 0x38005614, 0x40001019,   // ms.tn.st_432 br.lg.nl_442  mg.tk.un_660 lt.lb.un_750 
  // [1d810]
  0x28003823, 0x560d3804, 0x222d0d0e, 0x0100560c,   // tk.sw.un_880 tk.cs.mg_332  cs.sk.oc_555 mg.en.un_530 
  0x081037ee, 0x62385608, 0x204b5bec, 0x4c4b200c,   // ba.be.uk_422 mg.tk.kha_443  sg.mi.sq_644 sq.mi.wo_543 
  0x20005b21, 0x0e001d02, 0x48442313, 0x5059550d,   // sg.sq.un_860 la.is.un_220  ky.kk.tt_665 rw.rn.fj_554 
  0x40005b19, 0x1b38480d, 0xfc190b0c, 0x29002204,   // sg.lb.un_750 tt.tk.tr_554  es.gl.zzp_543 oc.sl.un_320 
  // [1d820]
  0x59551da0, 0x100415a7, 0x1e30670c, 0x496a4b08,   // la.rw.rn_322 un.ru.be_532  ak.uz.ms_543 mi.haw.to_443 
  0x046a490c, 0x2cfc1b0c, 0x02041e11, 0x642d0d04,   // to.haw.fi_543 tr.zzp.fy_543  ms.fi.da_653 cs.sk.lg_332 
  0x38555907, 0x564b6a0d, 0xfa50350c, 0x4d2f370b,   // rn.rw.tk_432 haw.mi.mg_554  zu.fj.nr_543 st.su.aa_542 
  0x01651d0b, 0x1e1c670c, 0x62211c07, 0x32001108,   // la.gv.en_542 ak.id.ms_543  id.jw.kha_432 ro.bs.un_430 
  // [1d830]
  0x5a494aa4, 0x4000280e, 0x022d1e07, 0x2e200eaf,   // yo.to.sm_433 sw.lb.un_550  ms.sk.da_432 is.sq.fo_655 
  0x16001b08, 0x1300290d, 0x441828a0, 0x5e2f2b04,   // tr.hr.un_430 sl.et.un_540  sd.ar.kk_322 vi.su.ts_332 
  0x672169a4, 0xfe003709, 0x153511ee, 0x074945a7,   // mfe.jw.ak_433 st.tlh.un_440  ro.tg.un_422 ln.to.it_532 
  0x4b000d0c, 0x350413a4, 0x79002512, 0x5d342155,   // cs.mi.un_530 et.fi.zu_433  eu.war.un_640 jw.xh.ss_442 
  // [1d840]
  0x3661180c, 0x18270aa9, 0x13044c08, 0x58513f11,   // ga.za.gn_543 pt.gd.ga_544  wo.fi.et_443 af.kl.om_653 
  0x233538af, 0x48111507, 0x0f4d58a7, 0x213d3b0d,   // tk.tg.ky_655 un.ro.tt_432  om.aa.lv_532 ks.ku.fa_554 
  0x64584c0d, 0x0b071da4, 0x0a00370d, 0xfc523ea0,   // wo.om.lg_554 la.it.es_433  ba.mk.un_540 rm.ha.zzp_322 
  0x242f60ad, 0x303707ad, 0x04135813, 0x35602460,   // vo.su.eo_643 bg.ba.uz_643  om.et.fi_665 eo.vo.zu_664 
  // [1d850]
  0x5a004c08, 0x193646a0, 0x49650404, 0x0402360d,   // wo.sm.un_430 qu.gn.gl_322  fi.gv.to_332 gn.da.fi_554 
  0x212f3902, 0x3b005004, 0x656b01a0, 0x130e2e08,   // br.su.jw_222 fj.so.un_320  en.ceb.gv_322 fo.is.et_443 
  0x5f566a07, 0x0a005108, 0x1b00500e, 0x391928a4,   // haw.mg.tn_432 kl.pt.un_430  fj.tr.un_550 sw.gl.br_433 
  0x04384807, 0x457810ad, 0x47295f07, 0x56240404,   // tt.tk.ru_432 lt.ve.ln_643  tn.sl.sn_432 fi.eo.mg_332 
  // [1d860]
  0x13040204, 0x360b0a5a, 0x65225604, 0x284b5005,   // da.fi.et_332 pt.es.gn_553  mg.oc.gv_332 fj.mi.sw_333 
  0x351511a9, 0x2e2c1b0b, 0x29241602, 0x09292da4,   // ro.tg.un_540 tr.fy.fo_542  hr.eo.sl_222 sk.sl.pl_433 
  0x213012a7, 0x6e002a0d, 0x6a5d5a0d, 0x2a00240c,   // ur.uz.fa_532 mt.hmn.un_540  sm.ss.haw_554 eo.mt.un_530 
  0x2000380c, 0x1e101104, 0x303c23a9, 0x11190b5a,   // tk.sq.un_530 ro.lt.ms_332  ky.ug.uz_544 es.gl.ro_553 
  // [1d870]
  0x39001e04, 0x3d213ba6, 0x25380907, 0x20001b09,   // ms.br.un_320 ks.fa.ku_521  pl.tk.eu_432 tr.sq.un_440 
  0x5d201b08, 0x123d3402, 0x695338a4, 0x37483cac,   // tr.sq.ss_443 ps.ku.ur_222  tk.ht.mfe_433 ug.tt.ba_632 
  0x040a11a0, 0x2f64020c, 0x02002f0d, 0x58023bec,   // ro.mk.ru_322 da.lg.su_543  su.da.un_540 so.da.om_644 
  0x3028340c, 0x04104807, 0x08300a12, 0x0437380c,   // ps.sd.uz_543 tt.be.ru_432  mk.uz.uk_654 tk.ba.ru_543 
  // [1d880]
  0x3c342312, 0x253035a9, 0xfcfe3604, 0x46002902,   // ky.ps.ug_654 tg.uz.mn_544  gn.tlh.zzp_332 sl.qu.un_220 
  0x3b09120c, 0x352e5ca4, 0x465c4ea4, 0x3b437907,   // hu.pl.so_543 sa.fo.zu_433  ay.sa.qu_433 war.ie.so_432 
  0x49511055, 0x0e5c2eee, 0x5100490c, 0x1d2e5c04,   // lt.kl.to_442 fo.sa.is_422  to.kl.un_530 sa.fo.la_332 
  0x20006112, 0x5c0e60ee, 0x16004208, 0x484d31ee,   // za.sq.un_640 vo.is.sa_422  co.hr.un_430 az.aa.tt_422 
  // [1d890]
  0x3b000912, 0x02310308, 0x25444807, 0x16765355,   // pl.so.un_640 nl.az.da_443  tt.kk.mn_432 ht.crs.hr_442 
  0x1a6b5ca6, 0x13105ca0, 0x2a21220d, 0x694301a0,   // sa.ceb.tl_521 sa.lt.et_322  oc.jw.mt_554 en.ie.mfe_322 
  0x5c1a1005, 0x181b27ac, 0x1000510e, 0x27005c04,   // lt.tl.sa_333 gd.tr.ga_632  kl.lt.un_550 sa.gd.un_320 
  0x27003202, 0x636518ad, 0x343f0313, 0x2e330e07,   // bs.gd.un_220 ga.gv.sco_643  nl.af.xh_665 is.nn.fo_432 
  // [1d8a0]
  0x30000212, 0x23220a05, 0x3e002219, 0x27004005,   // da.uz.un_640 pt.oc.ca_333  oc.rm.un_750 lb.gd.un_330 
  0x0b5e2305, 0x21183ca4, 0x23000a1b, 0x3e220a55,   // ca.ts.es_333 ug.ar.fa_433  pt.ca.un_770 pt.oc.rm_442 
  0x05791107, 0x2f00470d, 0x3868300c, 0x1e1c28a9,   // ro.war.fr_432 sn.su.un_540  uz.ig.tk_543 sw.id.ms_544 
  0x166afe04, 0x19006304, 0x254d0b08, 0x3e000a0d,   // tlh.haw.hr_332 sco.gl.un_320  es.aa.eu_443 pt.rm.un_540 
  // [1d8b0]
  0x254a57ad, 0x0f003e07, 0x5200782b, 0x5c0d1ca6,   // na.yo.eu_643 rm.lv.un_420  ve.ha.un_980 mr.ne.sa_521 
  0x78676408, 0x16094a02, 0x554a5b07, 0x154a670c,   // lg.ak.ve_443 yo.pl.hr_222  sg.yo.rw_432 ak.yo.un_543 
  0x5d256804, 0x32002f07, 0x2d5c3107, 0x3f002e04,   // ig.eu.ss_332 su.bs.un_420  az.sa.sk_432 fo.af.un_320 
  0x15003108, 0x2f38300d, 0x645158a9, 0x07190b0c,   // az.un.un_430 uz.tk.su_554  om.kl.lg_544 es.gl.it_543 
  // [1d8c0]
  0x473e0aa4, 0x274d4c0c, 0x6130380c, 0x16006107,   // pt.rm.sn_433 wo.aa.gd_543  tk.uz.za_543 za.hr.un_420 
  0x153133ee, 0x043f1007, 0x32060ea0, 0x073e4208,   // nn.az.un_422 lt.af.fi_432  is.de.bs_322 co.rm.it_443 
  0x56274d11, 0x17080a0d, 0x2d0d6109, 0x64001d02,   // aa.gd.mg_653 mk.uk.sr_554  za.cs.sk_444 la.lg.un_220 
  0x0f2e0d04, 0x091f15a7, 0x5d003013, 0x040a1509,   // cs.fo.lv_332 un.cy.pl_532  uz.ss.un_650 un.mk.ru_444 
  // [1d8d0]
  0x672b380c, 0x0b601d12, 0x33131807, 0x3f3815a0,   // tk.vi.ak_543 la.vo.es_654  ga.et.nn_432 un.tk.af_322 
  0x03003e08, 0x350a1707, 0x30353402, 0x3c374855,   // rm.nl.un_430 sr.mk.tg_432  xh.zu.uz_222 tt.ba.ug_442 
  0x041007a9, 0x3011255a, 0x12300c04, 0x3421180b,   // bg.be.ru_544 mn.ro.uz_553  sv.uz.hu_332 ar.fa.ps_542 
  0x245f560c, 0xfe5d200d, 0x3e6029a4, 0x24693f0c,   // mg.tn.eo_543 sq.ss.tlh_554  sl.vo.rm_433 af.mfe.eo_543 
  // [1d8e0]
  0x3b005b07, 0x4a5f1205, 0x0410360b, 0x556434a0,   // sg.so.un_420 hu.tn.yo_333  ab.be.ru_542 xh.lg.rw_322 
  0x302a31a7, 0x30204dad, 0x12043ea4, 0x6b151dee,   // az.mt.uz_532 aa.sq.uz_643  rm.fi.hu_433 la.ceb.un_420 
  0x5e2167a4, 0x215d350c, 0x193e12a4, 0x0e312ea4,   // ak.jw.ts_433 zu.ss.jw_543  hu.rm.gl_433 fo.az.is_433 
  0x473502a6, 0x202e0e0d, 0x3f003407, 0x0e2e4d0c,   // da.zu.sn_521 is.fo.sq_554  xh.af.un_420 aa.fo.is_543 
  // [1d8f0]
  0x04101555, 0x4648fe09, 0x231834a4, 0x56004205,   // un.be.ru_442 tlh.tt.qu_444  ps.ar.ky_433 co.mg.un_330 
  0x30000a09, 0x026b2f07, 0x49105108, 0x19360b55,   // mk.uz.un_440 su.ceb.da_432  kl.lt.to_443 es.gn.gl_442 
  0x0709100c, 0x3b0724a0, 0x78075fec, 0x260b0a14,   // lt.pl.it_543 eo.it.so_322  tn.it.ve_644 pt.es.ia_666 
  0x4200280d, 0xfc0746ad, 0x254437a0, 0x2d230704,   // sw.co.un_540 qu.it.zzp_643  ba.kk.mn_322 it.ca.sk_332 
  // [1d900]
  0x5413100c, 0x150a360c, 0x24000a09, 0x0a303ca7,   // lt.et.ik_543 ab.mk.un_543  pt.eo.un_440 ug.uz.mk_532 
  0x030639a7, 0x08006b04, 0x060339a4, 0x08441712,   // br.de.nl_532 ceb.no.un_320  br.nl.de_433 sr.kk.uk_654 
  0x102307a4, 0x281d0705, 0x5607100c, 0x51105f09,   // it.ca.lt_433 it.la.sw_333  lt.it.mg_543 tn.lt.kl_444 
  0x2afe200b, 0x53006e04, 0xfe003714, 0x40651102,   // sq.tlh.mt_542 hmn.ht.un_320  st.tlh.un_660 ro.gv.lb_222 
  // [1d910]
  0x35342b02, 0x17072308, 0x1d51fe08, 0x5e040c0c,   // vi.xh.zu_222 ky.bg.sr_443  tlh.kl.la_443 sv.fi.ts_543 
  0x2d0d0509, 0x47003021, 0x3f420304, 0x2f00280c,   // fr.cs.sk_444 uz.sn.un_860  nl.co.af_332 sw.su.un_530 
  0x212f395a, 0x016525a9, 0x06795704, 0x27002f0e,   // br.su.jw_553 eu.gv.en_544  na.war.de_332 su.gd.un_550 
  0x301548a4, 0x79430604, 0x27003907, 0x40001108,   // tt.uz.un_430 de.ie.war_332  br.gd.un_420 ro.lb.un_430 
  // [1d920]
  0x25652fa9, 0x02003808, 0x1c0115a0, 0x03002512,   // su.gv.eu_544 tk.da.un_430  un.en.id_322 eu.nl.un_640 
  0x631efe04, 0xfe002013, 0x6b2521a4, 0x2418390c,   // tlh.ms.sco_332 sq.tlh.un_650  jw.eu.ceb_433 br.ga.eo_543 
  0x23652f11, 0x2f390412, 0x2b005319, 0x28183b05,   // su.gv.ca_653 fi.br.su_654  ht.vi.un_750 ks.ar.sd_333 
  0x24421faf, 0x0c0115a0, 0x03fc3f0d, 0x15060ca0,   // cy.co.eo_655 un.en.sv_322  af.zzp.nl_554 sv.de.un_322 
  // [1d930]
  0x37794b0d, 0x1f00730c, 0x1c1f1008, 0x47002f0c,   // mi.war.st_554 ny.cy.un_530  lt.cy.id_443 su.sn.un_530 
  0x15040260, 0x02376aac, 0x57002521, 0x6b361d07,   // ja.ru.un_664 haw.st.da_632  eu.na.un_860 la.gn.ceb_432 
  0x1f000205, 0x78000d22, 0x491a6507, 0x56373009,   // da.cy.un_330 cs.ve.un_870  gv.tl.to_432 uz.st.mg_444 
  0x100825af, 0x470559ee, 0xfe6b560c, 0x37001108,   // mn.uk.be_655 rn.fr.sn_422  mg.ceb.tlh_543 ro.ba.un_430 
  // [1d940]
  0x6700561a, 0x6579555a, 0x1f004c0b, 0x593029ee,   // mg.ak.un_760 rw.war.gv_553  wo.cy.un_520 sl.uz.rn_422 
  0x2f1d15a0, 0x172d29a9, 0x303b3404, 0x560452ec,   // un.la.su_322 sl.sk.sr_544  ps.ks.uz_332 ha.fi.mg_644 
  0x301a5605, 0x2722530c, 0x0e482704, 0x296a04a4,   // mg.tl.uz_333 ht.oc.gd_543  gd.tt.is_332 fi.haw.sl_433 
  0x305e56ad, 0x1f005508, 0x15211808, 0x233044a4,   // mg.ts.uz_643 rw.cy.un_430  ga.jw.un_443 kk.uz.ky_433 
  // [1d950]
  0x4700362b, 0x1f287312, 0x57005021, 0x15370408,   // gn.sn.un_980 ny.sw.cy_654  fj.na.un_860 ru.ba.un_443 
  0x041017a4, 0x48002704, 0x796e4cad, 0x4c006e05,   // sr.be.ru_433 gd.tt.un_320  wo.hmn.war_643 hmn.wo.un_330 
  0x134c2ca0, 0x033f2ca4, 0x17100408, 0x0f6e3b02,   // fy.wo.et_322 fy.af.nl_433  ru.be.sr_443 so.hmn.lv_222 
  0x080415a6, 0x38103608, 0x496b0412, 0x281304af,   // un.ru.uk_521 ab.be.tk_443  fi.ceb.to_654 fi.et.sw_655 
  // [1d960]
  0x46544d0d, 0x3f02050c, 0x04455a04, 0x370408a7,   // aa.ik.qu_554 fr.da.af_543  sm.ln.fi_332 uk.ru.ba_532 
  0x12130455, 0x5a504f08, 0x2f6b0507, 0x1a473607,   // fi.et.hu_442 bi.fj.sm_443  fr.ceb.su_432 gn.sn.tl_432 
  0x2f4505a0, 0x3f002f14, 0x375f7509, 0x47005b0d,   // fr.ln.su_322 su.af.un_660  nso.tn.st_444 sg.sn.un_540 
  0x3c303607, 0x052c40a0, 0x3f052fad, 0x0267080c,   // ab.uz.ug_432 lb.fy.fr_322  su.fr.af_643 no.ak.da_543 
  // [1d970]
  0x111b38ad, 0x55450204, 0x675368a4, 0x3132110c,   // tk.tr.ro_643 da.ln.rw_332  ig.ht.ak_433 ro.bs.az_543 
  0x31465411, 0x2a07780d, 0x063e7904, 0x23001f02,   // ik.qu.az_653 ve.it.mt_554  war.rm.de_332 cy.ca.un_220 
  0x03fc630c, 0x30fe54ac, 0x42000718, 0x67472809,   // sco.zzp.nl_543 ik.tlh.uz_632  it.co.un_740 sw.sn.ak_444 
  0x03005305, 0x5a1051ad, 0x02fe1507, 0x222851a0,   // ht.nl.un_330 kl.lt.sm_643  un.tlh.da_432 kl.sw.oc_322 
  // [1d980]
  0x65503b0c, 0x150540af, 0x2a042407, 0x010a3ea0,   // so.fj.gv_543 lb.fr.un_655  eo.fi.mt_432 rm.pt.en_322 
  0x361e1c14, 0x423f05a7, 0x5200610c, 0x03052f08,   // id.ms.gn_666 fr.af.co_532  za.ha.un_530 su.fr.nl_443 
  0x233815af, 0x52002805, 0x2e00270b, 0x63304005,   // un.tk.ky_655 sw.ha.un_330  gd.fo.un_520 lb.uz.sco_333 
  0x38481505, 0x31000f05, 0x07fe3e07, 0x254837a4,   // un.tt.tk_333 lv.az.un_330  rm.tlh.it_432 ba.tt.mn_433 
  // [1d990]
  0x44381513, 0x20002507, 0x0d362d12, 0x20462a0c,   // un.tk.kk_665 eu.sq.un_420  sk.gn.cs_654 mt.qu.sq_543 
  0x37443008, 0x47001804, 0x220a5ea4, 0x03025e0c,   // uz.kk.ba_443 ga.sn.un_320  ts.pt.oc_433 ts.da.nl_543 
  0x47000f09, 0x0a47220c, 0x23150a07, 0x5c2858ec,   // lv.sn.un_440 oc.sn.pt_543  mk.ky.un_420 om.sw.sa_644 
  0x2d003402, 0x0a362da7, 0x13006407, 0x20004707,   // xh.sk.un_220 sk.gn.pt_532  lg.et.un_420 sn.sq.un_420 
  // [1d9a0]
  0x0f1e1c04, 0x735f5c09, 0x381b30a4, 0x472158a4,   // id.ms.lv_332 sa.tn.ny_444  uz.tr.tk_433 om.jw.sn_433 
  0x301e5e14, 0x2847590d, 0x1b303855, 0x1e006509,   // ts.ms.uz_666 rn.sn.sw_554  tk.uz.tr_442 gv.ms.un_440 
  0x215c2808, 0x18006514, 0x491865a4, 0x47100faf,   // sw.sa.jw_443 gv.ga.un_660  gv.ga.to_433 lv.lt.sn_655 
  0x38301005, 0x2800580c, 0x283b5802, 0xfc000208,   // lt.uz.tk_333 om.sw.un_530  om.so.sw_222 da.zzp.un_430 
  // [1d9b0]
  0x1827110c, 0x3b585c07, 0x21fe5c13, 0x0c5c3307,   // ro.gd.ga_543 sa.om.so_432  sa.tlh.jw_665 nn.sa.sv_432 
  0x65190aaf, 0x37002502, 0x285c58ec, 0x20311ba0,   // pt.gl.gv_655 mn.ba.un_220  om.sa.sw_644 tr.az.sq_322 
  0x4700180d, 0x0200fc1b, 0x471327a7, 0x20585ca4,   // ga.sn.un_540 zzp.da.un_770  gd.et.sn_532 sa.om.sq_433 
  0x08100a0c, 0x5c00581a, 0xfc002405, 0x0c0efca7,   // mk.be.uk_543 om.sa.un_760  eo.zzp.un_330 zzp.is.sv_532 
  // [1d9c0]
  0x04103ba9, 0x0c064860, 0x042718af, 0x3110120c,   // so.lt.fi_544 tt.de.sv_664  ga.gd.fi_655 hu.lt.az_543 
  0x3b105d08, 0x3b11100d, 0x0f0665a7, 0x251d1013,   // ss.lt.so_443 lt.ro.so_554  gv.de.lv_532 lt.la.eu_665 
  0x171030a0, 0x3e002713, 0x301828a4, 0x1135340d,   // uz.be.sr_322 gd.rm.un_650  sd.ar.uz_433 xh.zu.ro_554 
  0x2f124c07, 0x122f4c07, 0x5e003b19, 0x4404080c,   // wo.hu.su_432 wo.su.hu_432  so.ts.un_750 uk.ru.kk_543 
  // [1d9d0]
  0x42110408, 0x67105d09, 0x2f4c4d0d, 0x65000402,   // fi.ro.co_443 ss.lt.ak_444  aa.wo.su_554 fi.gv.un_220 
  0x48000619, 0x4d2f0da0, 0x594a6812, 0x0e124da7,   // de.tt.un_750 cs.su.aa_322  ig.yo.rn_654 aa.hu.is_532 
  0x52000209, 0x016b0eee, 0x0e004a14, 0x6758550c,   // da.ha.un_440 is.ceb.en_422  yo.is.un_660 rw.om.ak_543 
  0x0e1f2e07, 0x4c122f0d, 0x2f124c08, 0x29433e12,   // fo.cy.is_432 su.hu.wo_554  wo.hu.su_443 rm.ie.sl_654 
  // [1d9e0]
  0x06614712, 0x44341211, 0x2a423e12, 0x48fc1b04,   // sn.za.de_654 ur.ps.kk_653  rm.co.mt_654 tr.zzp.tt_332 
  0x280e52a4, 0x0a153805, 0x431d0605, 0x20033f02,   // ha.is.sw_433 tk.mk.un_330  de.la.ie_333 af.nl.sq_222 
  0x25084802, 0x373c3012, 0x06001704, 0x18002009,   // tt.uk.mn_222 uz.ug.ba_654  sr.de.un_320 sq.ga.un_440 
  0x295650ac, 0x370438ac, 0x215f1809, 0x6400450d,   // fj.mg.sl_632 tk.ru.ba_632  ga.tn.jw_444 ln.lg.un_540 
  // [1d9f0]
  0x42090fee, 0x36000e14, 0x483008ee, 0x0d1710a7,   // lv.pl.co_422 is.gn.un_660  uk.uz.tt_422 lt.sr.cs_532 
  0x303c1702, 0x135851a9, 0x60734560, 0x32003702,   // sr.ug.uz_222 kl.om.et_544  ln.ny.vo_664 st.bs.un_220 
  0x2d3f03a4, 0x185e2804, 0x583f0fee, 0x042e13a4,   // nl.af.sk_433 sw.ts.ga_332  lv.af.om_422 et.fo.fi_433 
  0x073004a0, 0x15151012, 0x47646a07, 0x4a005905,   // ru.uz.bg_322 be.un.un_640  haw.lg.sn_432 rn.yo.un_330 
  // [1da00]
  0x352864a0, 0x1827fe09, 0x3b212708, 0x6459670c,   // lg.sw.zu_322 tlh.gd.ga_444  gd.jw.so_443 ak.rn.lg_543 
  0x183425ba, 0x4224fea9, 0x36005109, 0x0d092d04,   // mn.ps.ar_843 tlh.eo.co_544  kl.gn.un_440 sk.pl.cs_332 
  0x4a296707, 0x48003b20, 0x2d0d2e05, 0x4600090d,   // ak.sl.yo_432 so.tt.un_850  fo.cs.sk_333 pl.qu.un_540 
  0x644710ad, 0x46304ea9, 0x02282608, 0x2d0d4eee,   // lt.sn.lg_643 ay.uz.qu_544  ia.sw.da_443 ay.cs.sk_422 
  // [1da10]
  0x78004e1a, 0x3748230d, 0x5f377813, 0x330c0e02,   // ay.ve.un_760 ky.tt.ba_554  ve.st.tn_665 is.sv.nn_222 
  0x04131ba0, 0x4d00671a, 0x0e1f10a0, 0x171004a7,   // tr.et.fi_322 ak.aa.un_760  lt.cy.is_322 ru.be.sr_532 
  0x04080713, 0x39021907, 0x396976a4, 0x1d360907,   // bg.uk.ru_665 gl.da.br_432  crs.mfe.br_433 pl.gn.la_432 
  0x10304e5a, 0x2068390c, 0x4a6030a4, 0x242939a7,   // ay.uz.lt_553 br.ig.sq_543  uz.vo.yo_433 br.sl.eo_532 
  // [1da20]
  0x53060355, 0x03fa35a4, 0x17153809, 0x1007040b,   // nl.de.ht_442 zu.nr.nl_433  tk.sr.un_440 ru.bg.be_542 
  0x30004e0e, 0x0a371707, 0x31304eec, 0x1234390d,   // ay.uz.un_550 sr.ba.mk_432  ay.uz.az_644 br.xh.hu_554 
  0x474201a0, 0x3546280c, 0x29003919, 0x31304e0c,   // en.co.sn_322 sw.qu.zu_543  br.sl.un_750 ay.uz.az_543 
  0x092419ee, 0x3d213005, 0x2a1220a9, 0x2f214a02,   // gl.eo.pl_422 uz.fa.ku_333  sq.hu.mt_544 yo.jw.su_222 
  // [1da30]
  0x041736a4, 0x1d42250d, 0x10333802, 0x080417a9,   // ab.sr.ru_433 eu.co.la_554  tk.nn.lt_222 sr.ru.uk_544 
  0x4b000f13, 0x1f00631a, 0x24122a0b, 0x320c1708,   // lv.mi.un_650 sco.cy.un_760  mt.hu.eo_542 sr.sv.bs_443 
  0x02001009, 0x0c002a08, 0x1e2f4dee, 0x123b34af,   // lt.da.un_440 mt.sv.un_430  aa.su.ms_422 ps.ks.ur_655 
  0x212ffe07, 0x281830a0, 0x123d3404, 0x355d47ac,   // tlh.su.jw_432 uz.ar.sd_322  ps.ku.ur_332 sn.ss.zu_632 
  // [1da40]
  0x4730730c, 0x233c3b0d, 0x2f00fe12, 0x5c002f09,   // ny.uz.sn_543 ks.ug.ky_554  tlh.su.un_640 su.sa.un_440 
  0x292f4d07, 0x2f1efead, 0x1d000a0c, 0x5955fc0c,   // aa.su.sl_432 tlh.ms.su_643  pt.la.un_530 zzp.rw.rn_543 
  0x1b2e0ea0, 0x366438a7, 0x34212f08, 0x021025a4,   // is.fo.tr_322 tk.lg.gn_532  su.jw.xh_443 eu.lt.da_433 
  0x48384460, 0x07100aee, 0x210e2e0c, 0x7900670d,   // kk.tk.tt_664 mk.be.bg_422  fo.is.jw_543 ak.war.un_540 
  // [1da50]
  0x38481ba9, 0x1f023b0c, 0x48fc210d, 0x3e27400d,   // tr.tt.tk_544 so.da.cy_543  jw.zzp.tt_554 lb.gd.rm_554 
  0x074415a4, 0x6800471b, 0x39001f19, 0x302220a7,   // un.kk.bg_433 sn.ig.un_770  cy.br.un_750 sq.oc.uz_532 
  0x20786511, 0x15181fa0, 0x6200301a, 0x5e736807,   // gv.ve.sq_653 cy.ga.un_322  uz.kha.un_760 ig.ny.ts_432 
  0x1f005802, 0x20fe29ec, 0x68181f0c, 0x32160f0e,   // om.cy.un_220 sl.tlh.sq_644  cy.ga.ig_543 lv.hr.bs_555 
  // [1da60]
  0x571d63a4, 0x653f5e09, 0x170804ad, 0x46302004,   // sco.la.na_433 ts.af.gv_444  ru.uk.sr_643 sq.uz.qu_332 
  0x533973a4, 0x28001f08, 0x232d0d11, 0x30122814,   // ny.br.ht_433 cy.sw.un_430  cs.sk.ca_653 sd.ur.uz_666 
  0x49561fa4, 0x480410a9, 0x18233409, 0x082515a0,   // cy.mg.to_433 be.ru.tt_544  ps.ky.ar_444 un.mn.uk_322 
  0x0a001518, 0x10080202, 0x016b1d07, 0x2a001902,   // un.mk.un_740 da.no.lt_222  la.ceb.en_432 gl.mt.un_220 
  // [1da70]
  0x650e5802, 0x20311004, 0x04283011, 0x13060c0c,   // om.is.gv_222 lt.az.sq_332  uz.sw.fi_653 sv.de.et_543 
  0x5c001d0b, 0x0442130d, 0x0e004e19, 0x73551fa0,   // la.sa.un_520 et.co.fi_554  ay.is.un_750 cy.rw.ny_322 
  0x465d1f0b, 0x6e005809, 0x293564ad, 0x736455af,   // cy.ss.qu_542 om.hmn.un_440  lg.zu.sl_643 rw.lg.ny_655 
  0x21382e07, 0x240e1207, 0x1a5e47ee, 0x130410a4,   // fo.tk.jw_432 hu.is.eo_432  sn.ts.tl_422 lt.fi.et_433 
  // [1da80]
  0x4a00470c, 0x3b003414, 0x02605812, 0x496928a9,   // sn.yo.un_530 xh.so.un_660  om.vo.da_654 sw.mfe.to_544 
  0x56021ba4, 0x306b1004, 0x2e60730d, 0x22234e14,   // tr.da.mg_433 lt.ceb.uz_332  ny.vo.fo_554 ay.ca.oc_666 
  0x303b2909, 0x292f4e08, 0x130e3eee, 0x55fe59af,   // sl.so.uz_444 ay.su.sl_443  rm.is.et_422 rn.tlh.rw_655 
  0x1c2f58ec, 0x1e691c0c, 0x56523ea9, 0x796b1c0b,   // om.su.id_644 id.mfe.ms_543  rm.ha.mg_544 id.ceb.war_542 
  // [1da90]
  0x647345a4, 0xfe003b0c, 0x3b155eee, 0x18003b19,   // ln.ny.lg_433 so.tlh.un_530  ts.so.un_420 ks.ar.un_750 
  0x69102509, 0x465e5408, 0x3000511a, 0x5502fe07,   // eu.lt.mfe_444 ik.ts.qu_443  kl.uz.un_760 tlh.da.rw_432 
  0x5e733307, 0x07353604, 0x281304a4, 0x47525e09,   // nn.ny.ts_432 ab.tg.bg_332  fi.et.sw_433 ts.ha.sn_444 
  0x44232502, 0x151035ec, 0x3023440d, 0x3e002705,   // mn.ky.kk_222 tg.be.un_644  kk.ky.uz_554 gd.rm.un_330 
  // [1daa0]
  0x48000e07, 0x183d3ba0, 0x3e0f0b0c, 0x5b6967af,   // is.tt.un_420 ks.ku.ar_322  es.lv.rm_543 ak.mfe.sg_655 
  0x02006918, 0x06402fa9, 0x18000209, 0xfe1e1c0d,   // mfe.da.un_740 su.lb.de_544  da.ga.un_440 id.ms.tlh_554 
  0x1e1cfeac, 0x3f1c2aa0, 0x1efe4d55, 0x1b595508,   // tlh.id.ms_632 mt.id.af_322  aa.tlh.ms_442 rw.rn.tr_443 
  0x4d005b05, 0x04083509, 0x48091daf, 0x645559ac,   // sg.aa.un_330 tg.uk.ru_444  la.pl.tt_655 rn.rw.lg_632 
  // [1dab0]
  0xfe004d1a, 0x1cfe1e12, 0x254f0255, 0x1e1cfeec,   // aa.tlh.un_760 ms.tlh.id_654  da.bi.eu_442 tlh.id.ms_644 
  0x1e1cfeaf, 0x49005007, 0x09431ea0, 0x64003605,   // tlh.id.ms_655 fj.to.un_420  ms.ie.pl_322 gn.lg.un_330 
  0x6100570e, 0x56002407, 0x3e4024a4, 0x021745a4,   // na.za.un_550 eo.mg.un_420  eo.lb.rm_433 ln.sr.da_433 
  0x180f1d04, 0x39fc57ad, 0x102e1310, 0x3f4f3007,   // la.lv.ga_332 na.zzp.br_643  et.fo.lt_642 uz.bi.af_432 
  // [1dac0]
  0x13363413, 0x2915fea0, 0x2864550d, 0x64734caf,   // xh.gn.et_665 tlh.sl.un_320  rw.lg.sw_554 wo.ny.lg_655 
  0x04000c20, 0x0e434807, 0x464d7312, 0x2d005308,   // sv.fi.un_850 tt.ie.is_432  ny.aa.qu_654 ht.sk.un_430 
  0x04170802, 0x19240a12, 0x27004214, 0x0a4956a0,   // uk.sr.ru_222 pt.eo.gl_654  co.gd.un_660 mg.to.pt_322 
  0x2700390e, 0x03fe22a7, 0x1f00280e, 0x12211812,   // br.gd.un_550 oc.tlh.nl_532  sw.cy.un_550 ar.fa.ur_654 
  // [1dad0]
  0x1548fe0b, 0x190b39a4, 0x3e1013ee, 0x2e003905,   // tlh.tt.un_542 br.es.gl_433  et.lt.rm_422 br.fo.un_330 
  0x06026004, 0x03126107, 0x350810ad, 0x271b38ee,   // vo.da.de_332 za.hu.nl_432  be.uk.tg_643 tk.tr.gd_422 
  0x4a1a6ba4, 0x2100fe02, 0x286756ad, 0x5700731b,   // ceb.tl.yo_433 tlh.jw.un_220  mg.ak.sw_643 ny.na.un_770 
  0x1a080208, 0x025e2107, 0x172315ad, 0x6b4006a7,   // da.no.tl_443 jw.ts.da_432  un.ky.sr_643 de.lb.ceb_532 
  // [1dae0]
  0x68691d07, 0x694557a4, 0x6b006305, 0x532321a4,   // la.mfe.ig_432 na.ln.mfe_433  sco.ceb.un_330 jw.ca.ht_433 
  0x29123902, 0x2048380c, 0x5c281aad, 0x2146150c,   // br.hu.sl_222 tk.tt.sq_543  tl.sw.sa_643 un.qu.jw_543 
  0x03000612, 0x016563ee, 0x60003f14, 0x55682505,   // de.nl.un_640 sco.gv.en_422  af.vo.un_660 eu.ig.rw_333 
  0x16000c0b, 0x02524605, 0x12292aa9, 0x1e4a1ca4,   // sv.hr.un_520 qu.ha.da_333  mt.sl.hu_544 id.yo.ms_433 
  // [1daf0]
  0x24300211, 0xfc136712, 0x21000c08, 0x025228ee,   // da.uz.eo_653 ak.et.zzp_654  sv.jw.un_430 sw.ha.da_422 
  0x08002102, 0x2f1122a9, 0x31006013, 0x532411a4,   // jw.no.un_220 oc.ro.su_544  vo.az.un_650 ro.eo.ht_433 
  0x373815ec, 0x252f63a6, 0x44040807, 0x19002e0b,   // un.tk.ba_644 sco.su.eu_521  uk.ru.kk_432 fo.gl.un_520 
  0x1c271dad, 0x0e2f6ba4, 0x1e544b08, 0x1b003919,   // la.gd.id_643 ceb.su.is_433  mi.ik.ms_443 br.tr.un_750 
  // [1db00]
  0x3e6560a4, 0x1e1d05a4, 0x311b59a9, 0x05652255,   // vo.gv.rm_433 fr.la.ms_433  rn.tr.az_544 oc.gv.fr_442 
  0x3b25380c, 0x1e2448a0, 0x224e60a7, 0x30461e07,   // tk.eu.so_543 tt.eo.ms_322  vo.ay.oc_532 ms.qu.uz_432 
  0x31195808, 0x0a001120, 0x4600010d, 0x025c360c,   // om.gl.az_443 ro.mk.un_850  en.qu.un_540 gn.sa.da_543 
  0x3d34120b, 0x6700521a, 0x525850a9, 0x467958a7,   // ur.ps.ku_542 ha.ak.un_760  fj.om.ha_544 om.war.qu_532 
  // [1db10]
  0x0c060412, 0x31005004, 0x010504ad, 0x34005013,   // fi.de.sv_654 fj.az.un_320  fi.fr.en_643 fj.xh.un_650 
  0x4844230b, 0x2d260511, 0x3568380c, 0x0738130c,   // ky.kk.tt_542 fr.ia.sk_653  tk.ig.zu_543 et.tk.it_543 
  0x2a00670d, 0x58001019, 0x47210207, 0x3e001002,   // ak.mt.un_540 lt.om.un_750  da.jw.sn_432 lt.rm.un_220 
  0x041b270b, 0x55353407, 0x1c003002, 0x3b52640c,   // gd.tr.fi_542 xh.zu.rw_432  uz.id.un_220 lg.ha.so_543 
  // [1db20]
  0x0200480e, 0x6553fcad, 0x581a6ba4, 0x283b52a9,   // tt.da.un_550 zzp.ht.gv_643  ceb.tl.om_433 ha.so.sw_544 
  0x273e580c, 0x545b1d05, 0x65021211, 0x301f1007,   // om.rm.gd_543 la.sg.ik_333  hu.da.gv_653 lt.cy.uz_432 
  0x1f271dee, 0x1f005b0c, 0x35464eee, 0x3f0510ee,   // la.gd.cy_422 sg.cy.un_530  ay.qu.zu_422 lt.fr.af_422 
  0x2a4b6aad, 0x5c021ea7, 0x1f020c02, 0x1e1c04af,   // haw.mi.mt_643 ms.da.sa_532  sv.da.cy_222 fi.id.ms_655 
  // [1db30]
  0x68000d08, 0x28005908, 0x0c331f02, 0x2f753712,   // cs.ig.un_430 rn.sw.un_430  cy.nn.sv_222 st.nso.su_654 
  0x25753708, 0x3537340c, 0x472d0d08, 0x033f080c,   // st.nso.eu_443 xh.st.zu_543  cs.sk.sn_443 no.af.nl_543 
  0x3020620c, 0x1f0539af, 0x51003508, 0x03403fa9,   // kha.sq.uz_543 br.fr.cy_655  zu.kl.un_430 af.lb.nl_544 
  0x5e677813, 0x0a3507a4, 0x23003107, 0x49123755,   // ve.ak.ts_665 bg.tg.mk_433  az.ca.un_420 st.hu.to_442 
  // [1db40]
  0x4736fe05, 0x5534470c, 0x2d00041a, 0x35043705,   // tlh.gn.sn_333 sn.xh.rw_543  fi.sk.un_760 ba.ru.tg_333 
  0x35041002, 0x27361807, 0x6e002018, 0x121830ee,   // be.ru.tg_222 ga.gn.gd_432  sq.hmn.un_740 uz.ar.ur_422 
  0x13004a07, 0x652c01a0, 0x041340a4, 0x20246e08,   // yo.et.un_420 en.fy.gv_322  lb.et.fi_433 hmn.eo.sq_443 
  0x2765115a, 0x40001d08, 0x0f001312, 0x5700650e,   // ro.gv.gd_553 la.lb.un_430  et.lv.un_640 gv.na.un_550 
  // [1db50]
  0x46206ead, 0x331e0eee, 0x630601ad, 0x25560f07,   // hmn.sq.qu_643 is.ms.nn_422  en.de.sco_643 lv.mg.eu_432 
  0x3007150c, 0x3f0313a0, 0x3b00791a, 0x6b483ba9,   // un.bg.uz_543 et.nl.af_322  war.so.un_760 so.tt.ceb_544 
  0x29001e05, 0x5f673712, 0x34283b07, 0x02002a0e,   // ms.sl.un_330 st.ak.tn_654  ks.sd.ps_432 mt.da.un_550 
  0x20005e07, 0x353423a4, 0x35476407, 0x35002a02,   // ts.sq.un_420 ca.xh.zu_433  lg.sn.zu_432 mt.zu.un_220 
  // [1db60]
  0x212818a7, 0x1b007907, 0x1e001704, 0x20004d18,   // ar.sd.fa_532 war.tr.un_420  sr.ms.un_320 aa.sq.un_740 
  0x27003e02, 0x1f2038ee, 0x19001d0c, 0x4d1e1c04,   // rm.gd.un_220 tk.sq.cy_422  la.gl.un_530 id.ms.aa_332 
  0x34006114, 0x3038540c, 0x231e58a7, 0x1f0657af,   // za.xh.un_660 ik.tk.uz_543  om.ms.ca_532 na.de.cy_655 
  0x0c002405, 0x35595560, 0x353419ee, 0x2315380c,   // eo.sv.un_330 rw.rn.zu_664  gl.xh.zu_422 tk.ky.un_530 
  // [1db70]
  0x095c3ba4, 0x4065fea7, 0x29004802, 0x2c001308,   // ks.sa.hi_433 tlh.gv.lb_532  tt.sl.un_220 et.fy.un_430 
  0x171b2902, 0x5e59470d, 0x2348040d, 0x36004c0d,   // sl.tr.sr_222 sn.rn.ts_554  ru.tt.ky_554 wo.gn.un_540 
  0x46245707, 0x17481002, 0x69307609, 0x5c006813,   // na.eo.qu_432 be.tt.sr_222  crs.uz.mfe_444 ig.sa.un_650 
  0x5a192812, 0x3b64240b, 0x2c271808, 0x0d4756ad,   // sw.gl.sm_654 eo.lg.so_542  ga.gd.fy_443 mg.sn.cs_643 
  // [1db80]
  0x5900470c, 0x1060730d, 0x01fc0b02, 0x2c00040e,   // sn.rn.un_530 ny.vo.lt_554  es.zzp.en_222 fi.fy.un_550 
  0x181d2705, 0x094712ee, 0x5a002302, 0x28002707,   // gd.la.ga_333 hu.sn.pl_422  ca.sm.un_220 gd.sw.un_420 
  0x55355907, 0x0b003204, 0x061d3f07, 0x18271d04,   // rn.zu.rw_432 bs.es.un_320  af.la.de_432 la.gd.ga_332 
  0x2b056b07, 0x12483804, 0x32470da4, 0x18292405,   // ceb.fr.vi_432 tk.tt.hu_332  cs.sn.bs_433 eo.sl.ga_333 
  // [1db90]
  0x28006912, 0x595556a4, 0x0d3547af, 0x35303812,   // mfe.sw.un_640 mg.rw.rn_433  sn.zu.cs_655 tk.uz.tg_654 
  0x131811a7, 0x03400207, 0x0a000412, 0x08040aa9,   // ro.ga.et_532 da.lb.nl_432  fi.pt.un_640 mk.ru.uk_544 
  0x39581d05, 0x13101d07, 0x40061308, 0x1c001b02,   // la.om.br_333 la.lt.et_432  et.de.lb_443 tr.id.un_220 
  0x47003004, 0x30003909, 0x6e005c09, 0x0a5369a4,   // uz.sn.un_320 br.uz.un_440  sa.hmn.un_440 mfe.ht.pt_433 
  // [1dba0]
  0x10001d0d, 0x0a36070b, 0x1d006e08, 0x155c0207,   // la.lt.un_540 bg.ab.mk_542  hmn.la.un_430 da.sa.un_432 
  0x2a5465af, 0x18212805, 0x03473012, 0x39295304,   // gv.ik.mt_655 sd.fa.ar_333  uz.sn.nl_654 ht.sl.br_332 
  0x422a05ad, 0x50564707, 0xfe1f1007, 0x565e5012,   // fr.mt.co_643 sn.mg.fj_432  lt.cy.tlh_432 fj.ts.mg_654 
  0x26fe5aa4, 0x1e2012a0, 0x6e105c0c, 0x5c1112a7,   // sm.tlh.ia_433 hu.sq.ms_322  sa.lt.hmn_543 hu.ro.sa_532 
  // [1dbb0]
  0x4a1e62a7, 0x5c212fee, 0x1d000711, 0x2f0f18ee,   // kha.ms.yo_532 su.jw.sa_422  it.la.un_630 ga.lv.su_422 
  0x50003e1a, 0x2f00370d, 0x32172aa0, 0x33136504,   // rm.fj.un_760 st.su.un_540  mt.sr.bs_322 gv.et.nn_332 
  0x39001012, 0x2f211ea0, 0x2b006b08, 0x032f21a0,   // lt.br.un_640 ms.jw.su_322  ceb.vi.un_430 jw.su.nl_322 
  0x0b3647ee, 0x1c2f2da7, 0x030657ad, 0x2a21540b,   // sn.gn.es_422 sk.su.id_532  na.de.nl_643 ik.jw.mt_542 
  // [1dbc0]
  0x5c005208, 0x28301ea4, 0x3e001019, 0x5c214eee,   // ha.sa.un_430 ms.uz.sw_433  lt.rm.un_750 ay.jw.sa_422 
  0x2d004b09, 0x3f000223, 0x3f12fea0, 0x36034fa4,   // mi.sk.un_440 da.af.un_880  tlh.hu.af_322 bi.nl.gn_433 
  0x4afe2fee, 0x38311b5a, 0x3b00fc0b, 0x10002d18,   // su.tlh.yo_422 tr.az.tk_553  zzp.so.un_520 sk.lt.un_740 
  0x600206a4, 0x3037440c, 0x080711af, 0x4700781b,   // de.da.vo_433 kk.ba.uz_543  ro.bg.uk_655 ve.sn.un_770 
  // [1dbd0]
  0x373648a0, 0x480e0ca0, 0x100a04ee, 0x041048ad,   // tt.ab.ba_322 sv.is.tt_322  ru.mk.be_422 tt.be.ru_643 
  0x1f00150c, 0x40004c10, 0x0e1330a9, 0x595e47ad,   // un.cy.un_530 wo.lb.un_620  uz.et.is_544 sn.ts.rn_643 
  0x3c233811, 0x23070a08, 0x25030f55, 0x23461fee,   // tk.ky.ug_653 mk.bg.ky_443  lv.nl.eu_442 cy.qu.ca_422 
  0x780413af, 0x13001f0d, 0x3b001e04, 0x4b005a04,   // et.fi.ve_655 cy.et.un_540  ms.so.un_320 sm.mi.un_320 
  // [1dbe0]
  0x34005808, 0x6000581b, 0x063e58af, 0x38301b0c,   // om.xh.un_430 om.vo.un_770  om.rm.de_655 tr.uz.tk_543 
  0x47005819, 0x212f58a7, 0x18303b11, 0x303715ad,   // om.sn.un_750 om.su.jw_532  ks.uz.ar_653 un.ba.uz_643 
  0x2f462402, 0x18283ca0, 0x6b2834a6, 0x2f1dfeec,   // eo.qu.su_222 ug.sd.ar_322  xh.sw.ceb_521 tlh.la.su_644 
  0x0c006805, 0x36460b07, 0x12131c04, 0x2c002305,   // ig.sv.un_330 es.qu.gn_432  id.et.hu_332 ca.fy.un_330 
  // [1dbf0]
  0x35483c55, 0x63064f07, 0x42530555, 0x3e3148ec,   // ug.tt.tg_442 bi.de.sco_432  fr.ht.co_442 tt.az.rm_644 
  0x65003012, 0x652376a0, 0x67002a13, 0x450c3312,   // uz.gv.un_640 crs.ca.gv_322  mt.ak.un_650 nn.sv.ln_654 
  0x320d2a08, 0x32174709, 0x276b7908, 0x48fe1ba0,   // mt.cs.bs_443 sn.sr.bs_444  war.ceb.gd_443 tr.tlh.tt_322 
  0x33001b12, 0x3308540c, 0x011a79a7, 0x1b484f0c,   // tr.nn.un_640 ik.no.nn_543  war.tl.en_532 bi.tt.tr_543 
  
  // [1dc00]
  0x273f230c, 0x29382d02, 0x18122112, 0x37303c0d,   // ca.af.gd_543 sk.tk.sl_222  fa.ur.ar_654 ug.uz.ba_554 
  0x04451d0c, 0x1d5813a0, 0x796b3fa4, 0x283934a4,   // la.ln.fi_543 et.om.la_322  af.ceb.war_433 xh.br.sw_433 
  0x046a51af, 0x351bfea0, 0x5a002308, 0x151b10a0,   // kl.haw.fi_655 tlh.tr.zu_322  ca.sm.un_430 lt.tr.un_322 
  0x13651fad, 0x6b383fee, 0x48330e11, 0x426428a4,   // cy.gv.et_643 af.tk.ceb_422  is.nn.tt_653 sw.lg.co_433 
  // [1dc10]
  0x041310a7, 0x04170a13, 0x300a350c, 0x3525340c,   // lt.et.fi_532 mk.sr.ru_665  tg.mk.uz_543 xh.eu.zu_543 
  0x38004423, 0x76305308, 0x55791a07, 0xfe1f6055,   // kk.tk.un_880 ht.uz.crs_443  tl.war.rw_432 vo.cy.tlh_442 
  0x78003719, 0x403e0602, 0x49003602, 0x183d3405,   // st.ve.un_750 de.rm.lb_222  gn.to.un_220 ps.ku.ar_333 
  0x6a00280d, 0x03153fa0, 0x354936a0, 0x21003e14,   // sw.haw.un_540 af.nl.un_320  gn.to.zu_322 rm.jw.un_660 
  // [1dc20]
  0x25231fee, 0x39043e0c, 0x16352807, 0x123004a9,   // cy.ca.eu_422 rm.fi.br_543  sw.zu.hr_432 fi.uz.hu_544 
  0x2a00420d, 0x0200fe13, 0x04254804, 0x28301e07,   // co.mt.un_540 tlh.da.un_650  tt.mn.ru_332 ms.uz.sw_432 
  0x5c002120, 0x0a005504, 0x1d2519ad, 0x5c1e62ad,   // jw.sa.un_850 rw.pt.un_320  gl.eu.la_643 kha.ms.sa_643 
  0x180e2ea4, 0xfe006807, 0x1a5d680d, 0x1d2101a4,   // fo.is.ga_433 ig.tlh.un_420  ig.ss.tl_554 en.jw.la_433 
  // [1dc30]
  0x4a0163a0, 0x38234460, 0x06001d02, 0x655e1f55,   // sco.en.yo_322 kk.ky.tk_664  la.de.un_220 cy.ts.gv_442 
  0x27685c04, 0x0c271f07, 0x27023f05, 0x081511af,   // sa.ig.gd_332 cy.gd.sv_432  af.da.gd_333 ro.uk.un_650 
  0x023f270c, 0x2a000605, 0x69020c13, 0x3f03060e,   // gd.af.da_543 de.mt.un_330  sv.da.mfe_665 de.nl.af_555 
  0x0500392a, 0x0f092f02, 0x0f005002, 0x212f1c14,   // br.fr.un_970 su.pl.lv_222  fj.lv.un_220 id.su.jw_666 
  // [1dc40]
  0x33083960, 0x391f0205, 0x3f060307, 0x431f3f08,   // br.no.nn_664 da.cy.br_333  nl.de.af_432 af.cy.ie_443 
  0x18002118, 0x07003c09, 0x5b36050c, 0x2b6b79a0,   // fa.ar.un_740 ug.bg.un_440  fr.gn.sg_543 war.ceb.vi_322 
  0x13090d07, 0x42002007, 0x0a3b13a4, 0x345c62a7,   // ne.hi.bh_432 sq.co.un_420  et.so.pt_433 kha.sa.xh_532 
  0x6827185a, 0x33155cee, 0x07580da0, 0x1a006b23,   // ga.gd.ig_553 sa.nn.un_420  cs.om.it_322 ceb.tl.un_880 
  // [1dc50]
  0x040c0612, 0x635942a0, 0x20006920, 0x276451a9,   // de.sv.fi_654 co.rn.sco_322  mfe.sq.un_850 kl.lg.gd_544 
  0x202313a4, 0x46022b04, 0x3d122808, 0x58630111,   // et.ca.sq_433 vi.da.qu_332  sd.ur.ku_443 en.sco.om_653 
  0x17103802, 0x30481bad, 0x40054c07, 0x2b103eac,   // tk.lt.sr_222 tr.tt.uz_643  wo.fr.lb_432 rm.lt.vi_632 
  0x1051540e, 0x5c000604, 0x1800301a, 0x0d3902af,   // ik.kl.lt_555 de.sa.un_320  uz.ar.un_760 da.br.cs_655 
  // [1dc60]
  0x2c043f0b, 0x380a04a4, 0x0a020107, 0x651969a4,   // af.fi.fy_542 ru.mk.tk_433  en.da.pt_432 mfe.gl.gv_433 
  0x570104a4, 0x07351707, 0xfa365513, 0x4700041a,   // fi.en.na_433 sr.tg.bg_432  rw.gn.nr_665 fi.sn.un_760 
  0x02650105, 0x1b525508, 0x69025308, 0x533f04a9,   // en.gv.da_333 rw.ha.tr_443  ht.da.mfe_443 fi.af.ht_544 
  0x054519a4, 0x39536955, 0x33085caf, 0x58650107,   // gl.ln.fr_433 mfe.ht.br_442  sa.no.nn_655 en.gv.om_432 
  // [1dc70]
  0x63004012, 0x24003f08, 0x65005713, 0x400539a6,   // lb.sco.un_640 af.eo.un_430  na.gv.un_650 br.fr.lb_521 
  0x51074da9, 0x1b5d590d, 0x79122007, 0x12060f09,   // aa.it.kl_544 rn.ss.tr_554  sq.hu.war_432 lv.de.hu_444 
  0x026162a4, 0x23396907, 0x30110507, 0x190b26a0,   // kha.za.da_433 mfe.br.ca_432  fr.ro.uz_432 ia.es.gl_322 
  0x0b2908a0, 0x4d3b630e, 0x42fc3011, 0x362555ad,   // no.sl.es_322 sco.so.aa_555  uz.zzp.co_653 rw.eu.gn_643 
  // [1dc80]
  0x64554da9, 0x79006308, 0x321b31a4, 0x045158a9,   // aa.rw.lg_544 sco.war.un_430  az.tr.bs_433 om.kl.fi_544 
  0x18421908, 0x59515512, 0x7605530c, 0x30182755,   // gl.co.ga_443 rw.kl.rn_654  ht.fr.crs_543 gd.ga.uz_442 
  0x79255908, 0x015346a0, 0x052001a4, 0x53004011,   // rn.eu.war_443 qu.ht.en_322  en.sq.fr_433 lb.ht.un_630 
  0x1e1c290c, 0x63766505, 0x3651130c, 0x291e1c13,   // sl.id.ms_543 gv.crs.sco_333  et.kl.gn_543 id.ms.sl_665 
  // [1dc90]
  0x51365505, 0x65634dad, 0x5e786812, 0x62055307,   // rw.gn.kl_333 aa.sco.gv_643  ig.ve.ts_654 ht.fr.kha_432 
  0x25002320, 0x02641ea0, 0x39006908, 0x285573a9,   // ky.mn.un_850 ms.lg.da_322  mfe.br.un_430 ny.rw.sw_544 
  0x032a63a4, 0x2f096407, 0x051865a4, 0x4226390c,   // sco.mt.nl_433 lg.pl.su_432  gv.ga.fr_433 br.ia.co_543 
  0x1f52640c, 0x78000309, 0x0a07100c, 0x65434fa7,   // lg.ha.cy_543 nl.ve.un_440  be.bg.mk_543 bi.ie.gv_532 
  // [1dca0]
  0x5e0c3302, 0x584d1e11, 0x21000108, 0x59285511,   // nn.sv.ts_222 ms.aa.om_653  en.jw.un_430 rw.sw.rn_653 
  0x53692811, 0x1e1c2909, 0x64555e08, 0x47522808,   // sw.mfe.ht_653 sl.id.ms_444  ts.rw.lg_443 sw.ha.sn_443 
  0x5c001320, 0x3d002319, 0x4778590e, 0x5d3f730c,   // bh.sa.un_850 ky.ku.un_750  rn.ve.sn_555 ny.af.ss_543 
  0x23005107, 0x02594fa7, 0x22461dee, 0x3d002302,   // kl.ca.un_420 bi.rn.da_532  la.qu.oc_422 ky.ku.un_220 
  // [1dcb0]
  0x64735904, 0x0a003014, 0x48001713, 0x59002a19,   // rn.ny.lg_332 uz.mk.un_660  sr.tt.un_650 mt.rn.un_750 
  0x3f5d35ee, 0x73535d09, 0x23301507, 0x4400482a,   // zu.ss.af_422 ss.ht.ny_444  un.uz.ky_432 tt.kk.un_970 
  0x28000c0b, 0x3e4006ee, 0x33006e0d, 0x4c215d05,   // sv.sw.un_520 de.lb.rm_422  hmn.nn.un_540 ss.jw.wo_333 
  0x45615607, 0x5c005007, 0x3600760d, 0x20002513,   // mg.za.ln_432 fj.sa.un_420  crs.gn.un_540 eu.sq.un_650 
  // [1dcc0]
  0x47595707, 0x0c1f3f04, 0x27063fee, 0x1d294307,   // na.rn.sn_432 af.cy.sv_332  af.de.gd_422 ie.sl.la_432 
  0x390650a0, 0x3f1326a4, 0x630801a0, 0x02002705,   // fj.de.br_322 ia.et.af_433  en.no.sco_322 gd.da.un_330 
  0x3343520c, 0x6b556aa0, 0x462f0207, 0x3f26280c,   // ha.ie.nn_543 haw.rw.ceb_322  da.su.qu_432 sw.ia.af_543 
  0x5c005419, 0x631601a0, 0x227906a4, 0x0c33025a,   // ik.sa.un_750 en.hr.sco_322  de.war.oc_433 da.nn.sv_553 
  // [1dcd0]
  0x3f366a13, 0x5a545012, 0x645e55a9, 0x21596a0c,   // haw.gn.af_665 fj.ik.sm_654  rw.ts.lg_544 haw.rn.jw_543 
  0x044050a0, 0x735629a9, 0x49356aad, 0x08070aec,   // fj.lb.fi_322 sl.mg.ny_544  haw.zu.to_643 mk.bg.uk_644 
  0x0c003f12, 0x1a1d01ad, 0x34293f07, 0x63070105,   // af.sv.un_640 en.la.tl_643  af.sl.xh_432 en.it.sco_333 
  0x57330808, 0x203f5008, 0x4b00582b, 0x122844a9,   // no.nn.na_443 fj.af.sq_443  om.mi.un_980 kk.sd.ur_544 
  // [1dce0]
  0x635313ee, 0x0b360504, 0x10495aa4, 0x3600510e,   // et.ht.sco_422 fr.gn.es_332  sm.to.lt_433 kl.gn.un_550 
  0x122e47ee, 0x5e500e05, 0x5c1336ac, 0x3e5c10a0,   // sn.fo.hu_422 is.fj.ts_333  gn.et.sa_632 lt.sa.rm_322 
  0x0e004219, 0x36130ea0, 0x110e0f04, 0x47003419,   // co.is.un_750 is.et.gn_322  lv.is.ro_332 xh.sn.un_750 
  0x21003607, 0x5c355da9, 0x39360504, 0x10600f12,   // gn.jw.un_420 ss.zu.sa_544  fr.gn.br_332 lv.vo.lt_654 
  // [1dcf0]
  0x4a59550d, 0x39001507, 0x08003902, 0x68004513,   // rw.rn.yo_554 un.br.un_420  br.no.un_220 ln.ig.un_650 
  0x645b02a4, 0x6b4e600d, 0x02330ca0, 0x43fc51a4,   // da.sg.lg_433 vo.ay.ceb_554  sv.nn.da_322 kl.zzp.ie_433 
  0x23170a07, 0x65581d0c, 0x0f101d0d, 0x38fc4d05,   // mk.sr.ky_432 la.om.gv_543  la.lt.lv_554 aa.zzp.tk_333 
  0x23041508, 0x10215cee, 0x24006e09, 0x131d0f07,   // un.ru.ky_443 sa.jw.lt_422  hmn.eo.un_440 lv.la.et_432 
  // [1dd00]
  0x32004304, 0x135804a9, 0x653f0305, 0x30311b60,   // ie.bs.un_320 fi.om.et_544  nl.af.gv_333 tr.az.uz_664 
  0x4c000d04, 0x30002913, 0x062765a0, 0x0b000509,   // cs.wo.un_320 sl.uz.un_650  gv.gd.de_322 fr.es.un_440 
  0x2f002905, 0x330313a0, 0x10006b04, 0x1c2a1ea0,   // sl.su.un_330 et.nl.nn_322  ceb.lt.un_320 ms.mt.id_322 
  0x353010a0, 0x2b005f04, 0x071017a0, 0x0a6976af,   // be.uz.tg_322 tn.vi.un_320  sr.be.bg_322 crs.mfe.pt_655 
  // [1dd10]
  0x2d004908, 0x202e0e60, 0x30000f07, 0x15041514,   // to.sk.un_430 is.fo.sq_664  lv.uz.un_420 un.ru.un_666 
  0x62001e12, 0x0c002c08, 0x30370407, 0x3b3d3011,   // ms.kha.un_640 fy.sv.un_430  ru.ba.uz_432 uz.ku.ks_653 
  0x10070a05, 0x18233b04, 0x73281e0c, 0x120742a4,   // mk.bg.be_333 ks.ky.ar_332  ms.sw.ny_543 co.it.hu_433 
  0x31001e08, 0x373c30ec, 0x1800121b, 0x1704080d,   // ms.az.un_430 uz.ug.ba_644  ur.ar.un_770 uk.ru.sr_554 
  // [1dd20]
  0xfa00450d, 0x03150107, 0x3b355d0c, 0x29330814,   // ln.nr.un_540 en.nl.un_420  ss.zu.so_543 no.nn.sl_666 
  0x79002408, 0x603e2813, 0x584d3b0d, 0x4a0b0a14,   // eo.war.un_430 sw.rm.vo_665  so.aa.om_554 pt.es.yo_666 
  0x556413a4, 0x243b0a05, 0x040358a7, 0x506a6211,   // et.lg.rw_433 pt.so.eo_333  om.nl.fi_532 kha.haw.fj_653 
  0x47005f09, 0x12003d19, 0x4700521a, 0x03585aee,   // tn.sn.un_440 ku.ur.un_750  ha.sn.un_760 sm.om.nl_422 
  // [1dd30]
  0x104d3ba7, 0x2a3e07a9, 0x42002208, 0x684d6408,   // so.aa.lt_532 it.rm.mt_544  oc.co.un_430 lg.aa.ig_443 
  0x34002134, 0x4b3528ee, 0x60004511, 0x0300641a,   // fa.ps.un_A80 sw.zu.mi_422  ln.vo.un_630 lg.nl.un_760 
  0x36452812, 0x04006419, 0x6400281b, 0x044d5108,   // sw.ln.gn_654 lg.fi.un_750  sw.lg.un_770 kl.aa.fi_443 
  0x13644da4, 0x3b4c51ad, 0x13002104, 0x02101d04,   // aa.lg.et_433 kl.wo.so_643  jw.et.un_320 la.lt.da_332 
  // [1dd40]
  0x392f21a0, 0x12101d0d, 0x35002f04, 0x1d003e0d,   // jw.su.br_322 la.lt.hu_554  su.zu.un_320 rm.la.un_540 
  0x3e1d0208, 0x101d3ea4, 0x221d3e55, 0x52101da4,   // da.la.rm_443 rm.la.lt_433  rm.la.oc_442 la.lt.ha_433 
  0x53212205, 0x20023007, 0x02203ba7, 0x103e3908,   // oc.jw.ht_333 uz.da.sq_432  so.sq.da_532 br.rm.lt_443 
  0xfe024712, 0x1d002313, 0x10221d14, 0x4500361b,   // sn.da.tlh_654 ca.la.un_650  la.oc.lt_666 gn.ln.un_770 
  // [1dd50]
  0x23691d0d, 0x3b1162ee, 0x1d005b0c, 0x01431104,   // la.mfe.ca_554 kha.ro.so_422  sg.la.un_530 ro.ie.en_332 
  0x1d1008a9, 0x5c203007, 0x671d105a, 0x11163211,   // no.lt.la_544 uz.sq.sa_432  lt.la.ak_553 bs.hr.ro_653 
  0x39101da7, 0x02006e04, 0x233b02ee, 0x18054aa0,   // la.lt.br_532 hmn.da.un_320  da.so.ca_422 yo.fr.ga_322 
  0x1e432f08, 0x3b025d07, 0x53002f0b, 0x20006507,   // su.ie.ms_443 ss.da.so_432  su.ht.un_520 gv.sq.un_420 
  // [1dd60]
  0x0b79230c, 0x1e1830a0, 0x250a4207, 0x0a0735ec,   // ca.war.es_543 uz.ga.ms_322  co.pt.eu_432 tg.bg.mk_644 
  0x48520207, 0x39302ba7, 0x59004708, 0x06650c02,   // da.ha.tt_432 vi.uz.br_532  sn.rn.un_430 sv.gv.de_222 
  0x3528020c, 0x7800301a, 0x360412ee, 0x281d02a9,   // da.sw.zu_543 uz.ve.un_760  hu.fi.gn_422 da.la.sw_544 
  0x215b3ea7, 0x6a001b1a, 0x02595509, 0x5e2050af,   // rm.sg.jw_532 tr.haw.un_760  rw.rn.da_444 fj.sq.ts_655 
  // [1dd70]
  0x3500521a, 0x3428200e, 0x3b353460, 0x384448af,   // ha.zu.un_760 sq.sw.xh_555  xh.zu.so_664 tt.kk.tk_655 
  0x34000804, 0x1f633007, 0x123c23ee, 0x3c44300c,   // no.xh.un_320 uz.sco.cy_432  ky.ug.ur_422 uz.kk.ug_543 
  0x333812a0, 0x644c520c, 0x04303513, 0x083f03a0,   // hu.tk.nn_322 ha.wo.lg_543  tg.uz.ru_665 nl.af.no_322 
  0x08030e07, 0x2e0c0e55, 0x3f150607, 0x3f330e04,   // is.nl.no_432 is.sv.fo_442  de.af.un_420 is.nn.af_332 
  // [1dd80]
  0x334012ad, 0x3f0c0805, 0x12333f07, 0x27000904,   // hu.lb.nn_643 no.sv.af_333  af.nn.hu_432 pl.gd.un_320 
  0x063f0ea0, 0x0e3f330c, 0x31006404, 0x2f676e07,   // is.af.de_322 nn.af.is_543  lg.az.un_320 hmn.ak.su_432 
  0x1e1c5c09, 0x27653ea0, 0x18272209, 0x320f290c,   // sa.id.ms_444 rm.gv.gd_322  oc.gd.ga_444 sl.lv.bs_543 
  0x0306470c, 0x2f1c6905, 0x00006203, 0x3e370102,   // sn.de.nl_543 mfe.id.su_333  kha.un.un_300 en.st.rm_222 
  // [1dd90]
  0x38301aa0, 0x2d0d0a55, 0x23043704, 0x0652330c,   // tl.uz.tk_322 pt.cs.sk_442  ba.ru.ky_332 nn.ha.de_543 
  0x222510a7, 0x400f2105, 0x221d01a4, 0x52405007,   // lt.eu.oc_532 jw.lv.lb_333  en.la.oc_433 fj.lb.ha_432 
  0x42635a0c, 0x2260100c, 0x1f1b12a4, 0x52767360,   // sm.sco.co_543 lt.vo.oc_543  hu.tr.cy_433 ny.crs.ha_664 
  0x477352a6, 0x462302a0, 0x5350760d, 0x5000602c,   // ha.ny.sn_521 da.ca.qu_322  crs.fj.ht_554 vo.fj.un_990 
  // [1dda0]
  0x493b3407, 0x370448a9, 0x40064fec, 0x360f100c,   // xh.so.to_432 tt.ru.ba_544  bi.de.lb_644 lt.lv.gn_543 
  0x4b002704, 0x072d3ea7, 0x112327a9, 0x1800fc1a,   // gd.mi.un_320 rm.sk.it_532  gd.ca.ro_544 zzp.ga.un_760 
  0x23071fa4, 0x73184704, 0x42004d1b, 0x535a6012,   // cy.it.ca_433 sn.ga.ny_332  aa.co.un_770 vo.sm.ht_654 
  0x3e005213, 0x07170a11, 0x03007308, 0x02007307,   // ha.rm.un_650 mk.sr.bg_653  ny.nl.un_430 ny.da.un_420 
  // [1ddb0]
  0x4c00300d, 0x22420404, 0x792611a4, 0x1b313802,   // uz.wo.un_540 fi.co.oc_332  ro.ia.war_433 tk.az.tr_222 
  0x3710440c, 0x22763bec, 0x075c42a0, 0x044207ad,   // kk.be.ba_543 so.crs.oc_644  co.sa.it_322 it.co.fi_643 
  0x01181f07, 0x081711a0, 0x3e180907, 0x4404080b,   // cy.ga.en_432 ro.sr.uk_322  pl.ga.rm_432 uk.ru.kk_542 
  0x2510400b, 0x233d2112, 0x1537440c, 0x31001104,   // lb.lt.eu_542 fa.ku.ky_654  kk.ba.un_543 ro.az.un_320 
  // [1ddc0]
  0x582e0e14, 0x0c384812, 0x44351507, 0x483010a0,   // is.fo.om_666 tt.tk.sv_654  un.tg.kk_432 be.uz.tt_322 
  0x42002707, 0x61003114, 0x130d5c05, 0x0e00190d,   // gd.co.un_420 az.za.un_660  sa.ne.bh_333 gl.is.un_540 
  0x39001811, 0x18003911, 0x39001808, 0x151730a4,   // ga.br.un_630 br.ga.un_630  ga.br.un_430 uz.sr.un_433 
  0x475625a4, 0x3d21300b, 0x182e0e0d, 0x250f5608,   // eu.mg.sn_433 uz.fa.ku_542  is.fo.ga_554 mg.lv.eu_443 
  // [1ddd0]
  0x470f61ee, 0x1625470b, 0x61002519, 0x39311ba0,   // za.lv.sn_422 sn.eu.hr_542  eu.za.un_750 tr.az.br_322 
  0x311b6b05, 0x31001e0d, 0x2f1a6b13, 0x39002405,   // ceb.tr.az_333 ms.az.un_540  ceb.tl.su_665 eo.br.un_330 
  0x78602113, 0x38651baf, 0x56001b07, 0x190a26af,   // jw.vo.ve_665 tr.gv.tk_655  tr.mg.un_420 ia.pt.gl_655 
  0x0f476112, 0x3559550d, 0x0321fe04, 0x0a5c0708,   // za.sn.lv_654 rw.rn.zu_554  tlh.jw.nl_332 it.sa.pt_443 
  // [1dde0]
  0x61471012, 0x495d5ead, 0x5b004713, 0x17006008,   // lt.sn.za_654 ts.ss.to_643  sn.sg.un_650 vo.sr.un_430 
  0x0f4756a4, 0x58002108, 0x1b00fe0c, 0x0843fe04,   // mg.sn.lv_433 jw.om.un_430  tlh.tr.un_530 tlh.ie.no_332 
  0x53003612, 0x10fe7904, 0x5d5c0202, 0x601d460c,   // gn.ht.un_640 war.tlh.lt_332  da.sa.ss_222 qu.la.vo_543 
  0xfe303108, 0x1b381c07, 0x6029170b, 0x3800080e,   // az.uz.tlh_443 id.tk.tr_432  sr.sl.vo_542 uk.tk.un_550 
  // [1ddf0]
  0x0dfe2da9, 0x01466ba0, 0x080e33a9, 0x331d1f04,   // sk.tlh.cs_544 ceb.qu.en_322  nn.is.no_544 cy.la.nn_332 
  0x63005812, 0x024b10a7, 0x481d7814, 0x4f005b0d,   // om.sco.un_640 lt.mi.da_532  ve.la.tt_666 sg.bi.un_540 
  0x52654dad, 0x20583bad, 0x5c561ea4, 0x431d26a4,   // aa.gv.ha_643 so.om.sq_643  ms.mg.sa_433 ia.la.ie_433 
  0x5c004d0c, 0x04071705, 0x3800070e, 0x10001f0d,   // aa.sa.un_530 sr.bg.ru_333  bg.tk.un_550 cy.lt.un_540 
  // [1de00]
  0x65005807, 0x18000d0c, 0x02513e05, 0x55215c11,   // om.gv.un_420 cs.ga.un_530  rm.kl.da_333 sa.jw.rw_653 
  0x1c101ea9, 0x121f100c, 0x37466714, 0x43241ea0,   // ms.lt.id_544 lt.cy.hu_543  ak.qu.st_666 ms.eo.ie_322 
  0x38000e07, 0x4e00461b, 0x42002321, 0x36120b05,   // is.tk.un_420 qu.ay.un_770  ca.co.un_860 es.hu.gn_333 
  0x0a4838a0, 0x35152309, 0x1a4c6b0d, 0x4c003705,   // tk.tt.pt_322 ky.tg.un_440  ceb.wo.tl_554 st.wo.un_330 
  // [1de10]
  0x23005319, 0x341e01a9, 0x19460bad, 0x341718a4,   // ht.ca.un_750 en.ms.xh_544  es.qu.gl_643 ar.sr.ps_433 
  0x19000b18, 0x462e1e04, 0x63000c0d, 0x23345d5a,   // es.gl.un_740 ms.fo.qu_332  sv.sco.un_540 ss.xh.ca_553 
  0x37383004, 0x250811ad, 0x133f39ad, 0x060203a0,   // uz.tk.ba_332 ro.uk.mn_643  br.af.et_643 nl.da.de_322 
  0x243f03a7, 0x2a6b1d11, 0x44341804, 0x6965fc08,   // nl.af.eo_532 la.ceb.mt_653  ar.ps.kk_332 zzp.gv.mfe_443 
  // [1de20]
  0x190bfca4, 0x130f10a0, 0x394610a6, 0x20001e29,   // zzp.es.gl_433 lt.lv.et_322  lt.qu.br_521 am.ti.un_960 
  0x3c2338ad, 0x46001312, 0x283034a0, 0x1f635c04,   // tk.ky.ug_643 et.qu.un_640  ps.uz.sd_322 sa.sco.cy_332 
  0x2f001a13, 0x651d6a12, 0x08020da4, 0x39472509,   // tl.su.un_650 haw.la.gv_654  cs.da.no_433 eu.sn.br_444 
  0xfe2a4208, 0x1dfe4308, 0x2b000a04, 0x603f0312,   // co.mt.tlh_443 ie.tlh.la_443  pt.vi.un_320 nl.af.vo_654 
  // [1de30]
  0x283001a9, 0x25071005, 0x28300107, 0x13021dee,   // en.uz.sw_544 be.bg.mn_333  en.uz.sw_432 la.da.et_422 
  0x10391d07, 0x0f1310a9, 0x35004a12, 0x22252fa0,   // la.br.lt_432 lt.et.lv_544  yo.zu.un_640 su.eu.oc_322 
  0x1c1304a9, 0x1d020aa7, 0x461d25a4, 0x4d3e39a4,   // fi.et.id_544 pt.da.la_532  eu.la.qu_433 br.rm.aa_433 
  0x205d2805, 0x30595513, 0x33005307, 0x5c00240c,   // sw.ss.sq_333 rw.rn.uz_665  ht.nn.un_420 eo.sa.un_530 
  // [1de40]
  0x73202114, 0x65004504, 0x4762655a, 0x3b00190d,   // jw.sq.ny_666 ln.gv.un_320  gv.kha.sn_553 gl.so.un_540 
  0x4a7968a0, 0x67000113, 0x36574e04, 0x270f1008,   // ig.war.yo_322 en.ak.un_650  ay.na.gn_332 lt.lv.gd_443 
  0x2c104c08, 0x0a3e420c, 0x59283008, 0x34fa35a4,   // wo.lt.fy_443 co.rm.pt_543  uz.sw.rn_443 zu.nr.xh_433 
  0x35303b02, 0x282030a4, 0x133e505a, 0x59552808,   // so.uz.zu_222 uz.sq.sw_433  fj.rm.et_553 sw.rw.rn_443 
  // [1de50]
  0x5528300d, 0x3f001f13, 0x28203012, 0x352820a9,   // uz.sw.rw_554 cy.af.un_650  uz.sq.sw_654 sq.sw.zu_544 
  0x5930280c, 0x2000301b, 0x59553b0c, 0x0a0435ad,   // sw.uz.rn_543 uz.sq.un_770  so.rw.rn_543 tg.ru.mk_643 
  0x21002c02, 0x17042305, 0x2d090da4, 0xfc321613,   // fy.jw.un_220 ky.ru.sr_333  cs.pl.sk_433 hr.bs.zzp_665 
  0x4b032c02, 0x2afc1208, 0x02003b02, 0x02366a0c,   // fy.nl.mi_222 hu.zzp.mt_443  so.da.un_220 haw.gn.da_543 
  // [1de60]
  0x03001702, 0x64005122, 0x1e003605, 0x65090d04,   // sr.nl.un_220 kl.lg.un_870  gn.ms.un_330 cs.pl.gv_332 
  0x04006412, 0x637901a4, 0x32176509, 0x0c292aee,   // lg.fi.un_640 en.war.sco_433  gv.sr.bs_444 mt.sl.sv_422 
  0x491e5aec, 0x1b312fa4, 0x7500372a, 0x5a006a14,   // sm.ms.to_644 su.az.tr_433  st.nso.un_970 haw.sm.un_660 
  0x2800200b, 0x230704af, 0x64584b05, 0x5b6a560c,   // sq.sw.un_520 ru.bg.ky_655  mi.om.lg_333 mg.haw.sg_543 
  // [1de70]
  0x792d0d04, 0x56353404, 0x0e2e0607, 0x170408a7,   // cs.sk.war_332 xh.zu.mg_332  de.fo.is_432 uk.ru.sr_532 
  0x321613ee, 0x5d6a6b0c, 0x28525304, 0x20593007,   // et.hr.bs_422 ceb.haw.ss_543  ht.ha.sw_332 uz.rn.sq_432 
  0x39003009, 0x1d6b0107, 0x47642005, 0x313038a7,   // uz.br.un_440 en.ceb.la_432  sq.lg.sn_333 tk.uz.az_532 
  0x306301a0, 0x40006505, 0x6500200d, 0x29001009,   // en.sco.uz_322 gv.lb.un_330  sq.gv.un_540 lt.sl.un_440 
  // [1de80]
  0x306520ec, 0x1f1050a4, 0x070f05a0, 0x37154407,   // sq.gv.uz_644 fj.lt.cy_433  fr.lv.it_322 kk.ba.un_420 
  0x4b5002a0, 0x053e0704, 0x0f1007a4, 0x37005707,   // da.fj.mi_322 it.rm.fr_332  it.lt.lv_433 na.st.un_420 
  0x070525a0, 0x1b1304ec, 0x042c5102, 0x19050a55,   // eu.fr.it_322 fi.et.tr_644  kl.fy.fi_222 pt.fr.gl_442 
  0x0465620c, 0x1c003f0c, 0x0e004307, 0x25005514,   // kha.gv.fi_543 af.id.un_530  ie.is.un_420 rw.eu.un_660 
  // [1de90]
  0x37005e0c, 0x05250107, 0x1bfc67a6, 0x34002a0c,   // ts.st.un_530 en.eu.fr_432  ak.zzp.tr_521 mt.xh.un_530 
  0x6a5c1ca0, 0x34001918, 0xfc001d0c, 0x1934370b,   // id.sa.haw_322 gl.xh.un_740  la.zzp.un_530 st.xh.gl_542 
  0x1d4624ee, 0x5d1a1ea9, 0x170a36a4, 0x28441807,   // eo.qu.la_422 ms.tl.ss_544  ab.mk.sr_433 ar.kk.sd_432 
  0x513b4d07, 0x0b004004, 0x57520107, 0xfc6557ad,   // aa.so.kl_432 lb.es.un_320  en.ha.na_432 na.gv.zzp_643 
  // [1dea0]
  0x241d560c, 0x464702ec, 0x37361507, 0x1b521ea4,   // mg.la.eo_543 da.sn.qu_644  un.ab.ba_432 ms.ha.tr_433 
  0x3b004c22, 0x0f130c0b, 0x6531690c, 0x30006908,   // wo.so.un_870 sv.et.lv_542  mfe.az.gv_543 mfe.uz.un_430 
  0x58484e0c, 0x47005e22, 0x40203fa0, 0x2130180c,   // ay.tt.om_543 ts.sn.un_870  af.sq.lb_322 ar.uz.fa_543 
  0x17300704, 0x505625a9, 0x2200650d, 0x184f2512,   // bg.uz.sr_332 eu.mg.fj_544  gv.oc.un_540 eu.bi.ga_654 
  // [1deb0]
  0x27006e18, 0x2e00130b, 0x440436ec, 0x651815a0,   // hmn.gd.un_740 et.fo.un_520  ab.ru.kk_644 un.ga.gv_322 
  0x25571faf, 0x303d2309, 0x18220509, 0x65180604,   // cy.na.eu_655 ky.ku.uz_444  fr.oc.ga_444 de.ga.gv_332 
  0x2f210da7, 0x0a080412, 0x102718ec, 0x18002019,   // cs.jw.su_532 ru.uk.mk_654  ga.gd.lt_644 sq.ga.un_750 
  0x38091008, 0x49523007, 0x35370407, 0x054f010c,   // lt.pl.tk_443 uz.ha.to_432  ru.ba.tg_432 en.bi.fr_543 
  // [1dec0]
  0x28001c0d, 0x180d09a4, 0x12362f04, 0x3c344407,   // id.sw.un_540 pl.cs.ga_433  su.gn.hu_332 kk.ps.ug_432 
  0x12003023, 0x3b303414, 0x21003f13, 0x23040a02,   // uz.ur.un_880 ps.uz.ks_666  af.jw.un_650 mk.ru.ky_222 
  0x442530a0, 0x1b311108, 0x5845020c, 0x080a10ad,   // uz.mn.kk_322 ro.az.tr_443  da.ln.om_543 be.mk.uk_643 
  0x324d590d, 0x44483711, 0x37000a0b, 0x4e475ea9,   // rn.aa.bs_554 ba.tt.kk_653  mk.ba.un_520 ts.sn.ay_544 
  // [1ded0]
  0x45286412, 0x56005f02, 0x5f34580c, 0x1f00100c,   // lg.sw.ln_654 tn.mg.un_220  om.xh.tn_543 lt.cy.un_530 
  0x3700751b, 0x166001a0, 0x33231d07, 0x37174402,   // nso.st.un_770 en.vo.hr_322  la.ca.nn_432 kk.sr.ba_222 
  0x300a155a, 0x5d6402ec, 0x511e1c13, 0x34584e0c,   // un.mk.uz_553 da.lg.ss_644  id.ms.kl_665 ay.om.xh_543 
  0x501a450d, 0x56003704, 0x38004b09, 0x375058ee,   // ln.tl.fj_554 st.mg.un_320  mi.tk.un_440 om.fj.st_422 
  // [1dee0]
  0x2b3702a4, 0x5100100b, 0x123e1012, 0x223e5107,   // da.st.vi_433 lt.kl.un_520  lt.rm.hu_654 kl.rm.oc_432 
  0x5c0913af, 0x40360602, 0x35003605, 0x23341804,   // bh.hi.sa_655 de.gn.lb_222  ab.tg.un_330 ar.ps.ky_332 
  0x3d282307, 0x17360aad, 0xfe000419, 0x25364b12,   // ky.sd.ku_432 mk.ab.sr_643  fi.tlh.un_750 mi.gn.eu_654 
  0x12093005, 0x3c213dad, 0x04484407, 0x4e25460c,   // uz.pl.hu_333 ku.fa.ug_643  kk.tt.ru_432 qu.eu.ay_543 
  // [1def0]
  0x5d47760c, 0x0e002a07, 0x440a1708, 0x17290d05,   // crs.sn.ss_543 mt.is.un_420  sr.mk.kk_443 cs.sl.sr_333 
  0x122d3009, 0x036b01ee, 0x136543a0, 0x15001e02,   // uz.sk.hu_444 en.ceb.nl_422  ie.gv.et_322 ms.un.un_220 
  0x331d4fee, 0x04fe0d0d, 0x0e2e01a4, 0x12004208,   // bi.la.nn_422 cs.tlh.fi_554  en.fo.is_433 co.hu.un_430 
  0x33000f02, 0x1537110c, 0x46000f11, 0x332e0e09,   // lv.nn.un_220 ro.ba.un_543  lv.qu.un_630 is.fo.nn_444 
  // [1df00]
  0x28002c0c, 0x2e00200c, 0x2e0c0e09, 0x170a1105,   // fy.sw.un_530 sq.fo.un_530  is.sv.fo_444 ro.mk.sr_333 
  0xfc3f1a0b, 0x312d0d02, 0x44081004, 0x6b060c0c,   // tl.af.zzp_542 cs.sk.az_222  be.uk.kk_332 sv.de.ceb_543 
  0x3f1a02a0, 0x063402a0, 0x73360407, 0x2b00630d,   // da.tl.af_322 da.xh.de_322  fi.gn.ny_432 sco.vi.un_540 
  0x3d1834a0, 0x02565a14, 0x0605010c, 0x060e09ec,   // ps.ar.ku_322 sm.mg.da_666  en.fr.de_543 pl.is.de_644 
  // [1df10]
  0x185256ad, 0x692528a4, 0x5c1b31a0, 0x0a001022,   // mg.ha.ga_643 sw.eu.mfe_433  az.tr.sa_322 be.mk.un_870 
  0x214428a7, 0x215c2fa0, 0x353015af, 0x0448150d,   // sd.kk.fa_532 su.sa.jw_322  un.uz.tg_655 un.tt.ru_554 
  0x6b631a04, 0x21595504, 0x556911a4, 0x3b230207,   // tl.sco.ceb_332 rw.rn.jw_332  ro.mfe.rw_433 da.ca.so_432 
  0x393b1dee, 0x121b55a4, 0xfe00fc08, 0x2b001d19,   // la.so.br_422 rw.tr.hu_433  zzp.tlh.un_430 la.vi.un_750 
  // [1df20]
  0x133455ee, 0x05551104, 0x42053908, 0x46120e04,   // rw.xh.et_422 ro.rw.fr_332  br.fr.co_443 is.hu.qu_332 
  0x2f215c12, 0x3b13095a, 0x2e003402, 0x11002204,   // sa.jw.su_654 hi.bh.ks_553  xh.fo.un_220 oc.ro.un_320 
  0x3e38060c, 0x03560107, 0x5f7856a4, 0x2e423504,   // de.tk.rm_543 en.mg.nl_432  mg.ve.tn_433 zu.co.fo_332 
  0x330f2908, 0x12302304, 0x12114fee, 0x25100455,   // sl.lv.nn_443 ky.uz.ur_332  bi.ro.hu_422 ru.be.mn_442 
  // [1df30]
  0x183021a0, 0x4200460d, 0x384803a0, 0x35007305,   // fa.uz.ar_322 qu.co.un_540  nl.tt.tk_322 ny.zu.un_330 
  0x341b35ee, 0x19005e08, 0x3e007320, 0x645343a0,   // zu.tr.xh_422 ts.gl.un_430  ny.rm.un_850 ie.ht.lg_322 
  0x4563640c, 0x47000d09, 0x35003105, 0x150810a9,   // lg.sco.ln_543 cs.sn.un_440  az.zu.un_330 be.uk.un_544 
  0x37286b55, 0x1b1110a4, 0x311d0404, 0x0b091007,   // ceb.sw.st_442 lt.ro.tr_433  fi.la.az_332 lt.pl.es_432 
  // [1df40]
  0x111d57ee, 0x28122160, 0x1b1011a4, 0x04311207,   // na.la.ro_422 fa.ur.sd_664  ro.lt.tr_433 hu.az.fi_432 
  0x11495a0c, 0x300a0702, 0x2734020b, 0x201d0907,   // sm.to.ro_543 bg.mk.uz_222  da.xh.gd_542 pl.la.sq_432 
  0x313b46a6, 0x09003905, 0x1d0f135a, 0x39182755,   // qu.so.az_521 br.pl.un_330  et.lv.la_553 gd.ga.br_442 
  0x051d135a, 0x101d0fa0, 0x2e48180c, 0x28123413,   // et.la.fr_553 lv.la.lt_322  ga.tt.fo_543 ps.ur.sd_665 
  // [1df50]
  0x301b2504, 0x3f331f07, 0x5369615a, 0x34734713,   // eu.tr.uz_332 cy.nn.af_432  za.mfe.ht_553 sn.ny.xh_665 
  0x56002505, 0x58001308, 0x103611a9, 0x2a072508,   // eu.mg.un_330 et.om.un_430  ro.ab.be_544 eu.it.mt_443 
  0x6e151da7, 0x36796b04, 0x10001f07, 0x0f103907,   // la.hmn.un_520 ceb.war.gn_332  cy.lt.un_420 br.lt.lv_432 
  0x251c0207, 0x27006e07, 0x364c4aa4, 0x57fc250c,   // da.id.eu_432 hmn.gd.un_420  yo.wo.gn_433 eu.zzp.na_543 
  // [1df60]
  0x31396904, 0x4c004a0d, 0x47002404, 0x17003308,   // mfe.br.az_332 yo.wo.un_540  eo.sn.un_320 nn.sr.un_430 
  0x07190a09, 0x17164aa0, 0x5c00540e, 0x1b005104,   // pt.gl.it_444 yo.hr.sr_322  ik.sa.un_550 kl.tr.un_320 
  0x04004a08, 0x10005112, 0x16003f12, 0x304c4a07,   // yo.fi.un_430 kl.lt.un_640  af.hr.un_640 yo.wo.uz_432 
  0x53000a0e, 0x1e304ca9, 0x1331430d, 0x73460312,   // pt.ht.un_550 wo.uz.ms_544  ie.az.et_554 nl.qu.ny_654 
  // [1df70]
  0x32004719, 0x37787311, 0x03616007, 0x2f573f0c,   // sn.bs.un_750 ny.ve.st_653  vo.za.nl_432 af.na.su_543 
  0x2f0579ee, 0x3f3e39ee, 0x274c2fec, 0x190a250c,   // war.fr.su_422 br.rm.af_422  su.wo.gd_644 eu.pt.gl_543 
  0xfc004013, 0x4c275aa9, 0x652060ad, 0x2b004d0e,   // lb.zzp.un_650 sm.gd.wo_544  vo.sq.gv_643 aa.vi.un_550 
  0x054001a4, 0x2b4765a0, 0x2600690e, 0x04001014,   // en.lb.fr_433 gv.sn.vi_322  mfe.ia.un_550 be.ru.un_660 
  // [1df80]
  0x546301a0, 0x273e1108, 0x651c1e0c, 0x0a0738af,   // en.sco.ik_322 ro.rm.gd_443  ms.id.gv_543 tk.bg.mk_655 
  0x02fc4da7, 0x4a4c3ead, 0x172d2902, 0x3f2f4708,   // aa.zzp.da_532 rm.wo.yo_643  sl.sk.sr_222 sn.su.af_443 
  0x1d001f18, 0x19226a0c, 0x5c6563a4, 0x1d2019a9,   // cy.la.un_740 haw.oc.gl_543  sco.gv.sa_433 gl.sq.la_544 
  0x2019230c, 0x38003402, 0x34005d09, 0x5e00350c,   // ca.gl.sq_543 xh.tk.un_220  ss.xh.un_440 zu.ts.un_530 
  // [1df90]
  0x1900020d, 0x1f094312, 0x123b280d, 0x10350402,   // da.gl.un_540 ie.pl.cy_654  sd.ks.ur_554 ru.tg.be_222 
  0x405f73ad, 0x5f347309, 0x5f001f08, 0x29003021,   // ny.tn.lb_643 ny.xh.tn_444  cy.tn.un_430 uz.sl.un_860 
  0x171209ee, 0x526551a9, 0x1b38215a, 0x5a000408,   // pl.hu.sr_422 kl.gv.ha_544  jw.tk.tr_553 fi.sm.un_430 
  0x345a04a0, 0x06575c04, 0x38302fa4, 0x34134905,   // fi.sm.xh_322 sa.na.de_332  su.uz.tk_433 to.et.xh_333 
  // [1dfa0]
  0x48123007, 0x30172dee, 0x483811ad, 0x1b380907,   // uz.hu.tt_432 sk.sr.uz_422  ro.tk.tt_643 pl.tk.tr_432 
  0x3e0c4fa0, 0x65005d02, 0x30291204, 0x0e087607,   // bi.sv.rm_322 ss.gv.un_220  hu.sl.uz_332 crs.no.is_432 
  0x0d0e5102, 0x111823a4, 0x08022cee, 0x461d2fee,   // kl.is.cs_222 ca.ga.ro_433  fy.da.no_422 su.la.qu_422 
  0x1d002202, 0x1d230405, 0x524d460e, 0x634006a4,   // oc.la.un_220 fi.ca.la_333  qu.aa.ha_555 de.lb.sco_433 
  // [1dfb0]
  0x02032c05, 0x25003913, 0xfc017909, 0x06396107,   // fy.nl.da_333 br.eu.un_650  war.en.zzp_444 za.br.de_432 
  0x11002514, 0x0a3c4855, 0x53321704, 0x043b6a55,   // mn.ro.un_660 tt.ug.mk_442  sr.bs.ht_332 haw.so.fi_442 
  0x01251fa0, 0x04003b0d, 0x1e043b0c, 0x4d2f1ea4,   // cy.eu.en_322 so.fi.un_540  so.fi.ms_543 ms.su.aa_433 
  0x221d23a0, 0x284d3baf, 0x29126ea4, 0x3f0a2fa4,   // ca.la.oc_322 so.aa.sw_655  hmn.hu.sl_433 su.pt.af_433 
  // [1dfc0]
  0x495354a4, 0x393f2a02, 0x030f390d, 0x2f231d04,   // ik.ht.to_433 mt.af.br_222  br.lv.nl_554 la.ca.su_332 
  0x21005212, 0x12001709, 0x0a1d2307, 0x373b4d13,   // ha.jw.un_640 sr.hu.un_440  ca.la.pt_432 aa.so.st_665 
  0x2f04230e, 0x471069a0, 0x1e004d12, 0x270b1808,   // ca.fi.su_555 mfe.lt.sn_322  aa.ms.un_640 ga.es.gd_443 
  0x4f4d42a4, 0x3b4967af, 0x39000f19, 0x06274004,   // co.aa.bi_433 ak.to.so_655  lv.br.un_750 lb.gd.de_332 
  // [1dfd0]
  0x58002813, 0x2e580402, 0x541f51ec, 0x313048ad,   // sw.om.un_650 fi.om.fo_222  kl.cy.ik_644 tt.uz.az_643 
  0x655104ee, 0x044b6a12, 0x12321705, 0x5e000408,   // fi.kl.gv_422 haw.mi.fi_654  sr.bs.hu_333 fi.ts.un_430 
  0x3b584b07, 0x1b316b0c, 0x651b4907, 0x31000f18,   // mi.om.so_432 ceb.az.tr_543  to.tr.gv_432 lv.az.un_740 
  0x210902a0, 0x135e2a04, 0x234415a4, 0x15170811,   // da.pl.jw_322 mt.ts.et_332  un.kk.ky_433 uk.sr.un_653 
  // [1dfe0]
  0x15081007, 0x57005d0e, 0x13524cec, 0x36003f0d,   // be.uk.un_432 ss.na.un_550  wo.ha.et_644 af.gn.un_540 
  0x373010a9, 0x676e5fec, 0x5d005714, 0x431d0414,   // be.uz.ba_544 tn.hmn.ak_644  na.ss.un_660 fi.la.ie_666 
  0x43000418, 0x23002f07, 0x0d4d5305, 0x18272c07,   // fi.ie.un_740 su.ca.un_420  ht.aa.cs_333 fy.gd.ga_432 
  0x595520a4, 0x07430a0c, 0x57005e22, 0x38002d05,   // sq.rw.rn_433 pt.ie.it_543  ts.na.un_870 sk.tk.un_330 
  // [1dff0]
  0x34005509, 0x45005e1b, 0x3c00280d, 0x0d004604,   // rw.xh.un_440 ts.ln.un_770  sd.ug.un_540 qu.cs.un_320 
  0x014006a7, 0x1d132e0c, 0x3e796b0c, 0x17472ea4,   // de.lb.en_532 fo.et.la_543  ceb.war.rm_543 fo.sn.sr_433 
  0x114d1d08, 0x480f1155, 0x36646b02, 0x1d005e04,   // la.aa.ro_443 ro.lv.tt_442  ceb.lg.gn_222 ts.la.un_320 
  0x1d132ea4, 0x1d4b5707, 0x13512e0c, 0x2e00602a,   // fo.et.la_433 na.mi.la_432  fo.kl.et_543 vo.fo.un_970 
  
  // [1e000]
  0x3e3f6302, 0x645a230d, 0x4255590b, 0xfe00fc11,   // sco.af.rm_222 ca.sm.lg_554  rn.rw.co_542 zzp.tlh.un_630 
  0x3b1228ec, 0x375ffe05, 0xfc003908, 0x645f3704,   // sd.ur.ks_644 tlh.tn.st_333  br.zzp.un_430 st.tn.lg_332 
  0x10070a14, 0x6b007304, 0x394260ee, 0x154813ee,   // mk.bg.be_666 ny.ceb.un_320  vo.co.br_422 et.tt.un_422 
  0x7902200c, 0x134856a9, 0x305d35a4, 0xfc033fa4,   // sq.da.war_543 mg.tt.et_544  zu.ss.uz_433 af.nl.zzp_433 
  // [1e010]
  0x15370807, 0x30134811, 0x6b1a7914, 0xfc3528a0,   // uk.ba.un_432 tt.et.uz_653  war.tl.ceb_666 sw.zu.zzp_322 
  0x6b004d07, 0xfc3843a0, 0x253757ad, 0x47005f05,   // aa.ceb.un_420 ie.tk.zzp_322  na.st.eu_643 tn.sn.un_330 
  0x021a6e07, 0x79121a12, 0x58006e0c, 0xfe5e0607,   // hmn.tl.da_432 tl.hu.war_654  hmn.om.un_530 de.ts.tlh_432 
  0x131a5a0c, 0x3b005411, 0xfc023108, 0x483736af,   // sm.tl.et_543 ik.so.un_630  az.da.zzp_443 ab.ba.tt_655 
  // [1e020]
  0x271530ee, 0x1b4d1a55, 0x154751ad, 0x130c250c,   // uz.gd.un_420 tl.aa.tr_442  kl.sn.un_643 eu.sv.et_543 
  0x0e133307, 0x3048130e, 0x225a49a4, 0x511e1c12,   // nn.et.is_432 et.tt.uz_555  to.sm.oc_433 id.ms.kl_654 
  0x34004605, 0x4b005613, 0x0d792d0c, 0x040c34a4,   // qu.xh.un_330 mg.mi.un_650  sk.war.cs_543 xh.sv.fi_433 
  0x08041755, 0x5e5628ec, 0x374649a7, 0x4c6a560c,   // sr.ru.uk_442 sw.mg.ts_644  to.qu.st_532 mg.haw.wo_543 
  // [1e030]
  0x2500130d, 0x4b560204, 0x495b5aa4, 0x5a004007,   // et.eu.un_540 da.mg.mi_332  sm.sg.to_433 lb.sm.un_420 
  0x56004b22, 0x110a0812, 0x53001d0d, 0x06020cee,   // mi.mg.un_870 uk.mk.ro_654  la.ht.un_540 sv.da.de_422 
  0x18561d08, 0x3d122811, 0x387967a4, 0x220903a0,   // la.mg.ga_443 sd.ur.ku_653  ak.war.tk_433 nl.pl.oc_322 
  0x53316307, 0x1d0a1113, 0x0d000202, 0x12004812,   // sco.az.ht_432 ro.pt.la_665  da.cs.un_220 tt.hu.un_640 
  // [1e040]
  0x1f00110d, 0x152b02a6, 0x0d212fa9, 0x4006fea7,   // ro.cy.un_540 da.vi.un_521  su.jw.cs_544 tlh.de.lb_532 
  0x306520ad, 0x2000651a, 0x096b46ee, 0x5b000613,   // sq.gv.uz_643 gv.sq.un_760  qu.ceb.pl_422 de.sg.un_650 
  0x4c051907, 0x551b5907, 0x5a4950a0, 0x345529a9,   // gl.fr.wo_432 rn.tr.rw_432  fj.to.sm_322 sl.rw.xh_544 
  0x052f4ca7, 0x10001c04, 0x050a2210, 0x1b3825a4,   // wo.su.fr_532 id.lt.un_320  oc.pt.fr_642 eu.tk.tr_433 
  // [1e050]
  0x323050ee, 0x1b006307, 0x0a484407, 0x425a4955,   // fj.uz.bs_422 sco.tr.un_420  kk.tt.mk_432 to.sm.co_442 
  0x345369ec, 0x2f211c0e, 0x094715a0, 0x65005302,   // mfe.ht.xh_644 id.jw.su_555  un.sn.pl_322 ht.gv.un_220 
  0x06fe5ba9, 0xfe2d0d09, 0x20174c0c, 0x6b791d07,   // sg.tlh.de_544 cs.sk.tlh_444  wo.sr.sq_543 la.war.ceb_432 
  0x490f4e08, 0x59551aac, 0x3f503507, 0x120d0705,   // ay.lv.to_443 tl.rw.rn_632  zu.fj.af_432 it.cs.hu_333 
  // [1e060]
  0x42450504, 0x215b20a4, 0x353421a0, 0x58003608,   // fr.ln.co_332 sq.sg.jw_433  jw.xh.zu_322 gn.om.un_430 
  0x1c1e2f07, 0x202910ee, 0x2d290d0d, 0x355f45a0,   // su.ms.id_432 lt.sl.sq_422  cs.sl.sk_554 ln.tn.zu_322 
  0x135029ee, 0x65002f22, 0x5a37300b, 0x33565aa6,   // sl.fj.et_422 su.gv.un_870  uz.st.sm_542 sm.mg.nn_521 
  0x29006921, 0x12372c11, 0x4c485fa0, 0x65016311,   // mfe.sl.un_860 fy.st.hu_653  tn.tt.wo_322 sco.en.gv_653 
  // [1e070]
  0x2556370b, 0x11135aee, 0x016333a4, 0x0b2279a4,   // st.mg.eu_542 sm.et.ro_422  nn.sco.en_433 war.oc.es_433 
  0x22566812, 0x5c002904, 0x51004802, 0x1160650d,   // ig.mg.oc_654 sl.sa.un_320  tt.kl.un_220 gv.vo.ro_554 
  0x02244809, 0x4300130d, 0x18002014, 0x0d233607,   // tt.eo.da_444 et.ie.un_540  sq.ga.un_660 gn.ca.cs_432 
  0x362102a0, 0x0143fead, 0x431d13a4, 0x4c4564ac,   // da.jw.gn_322 tlh.ie.en_643  et.la.ie_433 lg.ln.wo_632 
  // [1e080]
  0x2f205d09, 0x1300101b, 0x38674a12, 0x130f1002,   // ss.sq.su_444 lt.et.un_770  yo.ak.tk_654 lt.lv.et_222 
  0x21521c0c, 0x584a67ec, 0x34001102, 0x43fc5705,   // id.ha.jw_543 ak.yo.om_644  ro.xh.un_220 na.zzp.ie_333 
  0x2e004c02, 0x0f033f13, 0x381e06a4, 0x571e1c14,   // wo.fo.un_220 af.nl.lv_665  de.ms.tk_433 id.ms.na_666 
  0x215d1ca4, 0x4a005b0c, 0x635c4dee, 0x04113605,   // id.ss.jw_433 sg.yo.un_530  aa.sa.sco_422 ab.ro.ru_333 
  // [1e090]
  0xfa3f5d08, 0x265d0107, 0x595530a9, 0x21001b05,   // ss.af.nr_443 en.ss.ia_432  uz.rw.rn_544 tr.jw.un_330 
  0x26760107, 0x2820590c, 0x2f214602, 0x5a6301a4,   // en.crs.ia_432 rn.sq.sw_543  qu.jw.su_222 en.sco.sm_433 
  0x28002022, 0x5d000d04, 0x02282c08, 0x10502208,   // sq.sw.un_870 cs.ss.un_320  fy.sw.da_443 oc.fj.lt_443 
  0x6b003304, 0x4a35020d, 0x6428550d, 0x5f783755,   // nn.ceb.un_320 da.zu.yo_554  rw.sw.lg_554 st.ve.tn_442 
  // [1e0a0]
  0x28555da4, 0x2b001905, 0x232201a0, 0x1351250c,   // ss.rw.sw_433 gl.vi.un_330  en.oc.ca_322 eu.kl.et_543 
  0x59556514, 0x5d4f35a9, 0x37005502, 0x383031a0,   // gv.rw.rn_666 zu.bi.ss_544  rw.st.un_220 az.uz.tk_322 
  0x111d0104, 0x2d006e08, 0x275e29a0, 0x205c1807,   // en.la.ro_332 hmn.sk.un_430  sl.ts.gd_322 ga.sa.sq_432 
  0x040735a4, 0x2d0d18af, 0x57475d12, 0x1c091ea4,   // tg.bg.ru_433 ga.cs.sk_655  ss.sn.na_654 ms.pl.id_433 
  // [1e0b0]
  0x0f3020a0, 0x30644e04, 0x5c2b2007, 0x23070404,   // sq.uz.lv_322 ay.lg.uz_332  sq.vi.sa_432 ru.bg.ky_332 
  0x0f5e100c, 0x38315a0c, 0x595501a9, 0x355d20a4,   // lt.ts.lv_543 sm.az.tk_543  en.rw.rn_544 sq.ss.zu_433 
  0x203534ad, 0x6e785f0d, 0x79103612, 0x073e56a0,   // xh.zu.sq_643 tn.ve.hmn_554  gn.lt.war_654 mg.rm.it_322 
  0x551f590c, 0x3e005c13, 0x3100230d, 0x480a3005,   // rn.cy.rw_543 sa.rm.un_650  ca.az.un_540 uz.mk.tt_333 
  // [1e0c0]
  0x5973640e, 0x1a00470c, 0x53736b07, 0x15442311,   // lg.ny.rn_555 sn.tl.un_530  ceb.ny.ht_432 ky.kk.un_653 
  0x0f004722, 0x6b641a07, 0x596475a4, 0x5c100faf,   // sn.lv.un_870 tl.lg.ceb_432  nso.lg.rn_433 lv.lt.sa_655 
  0x75005f2c, 0x2b002207, 0x5564730d, 0x35005614,   // tn.nso.un_990 oc.vi.un_420  ny.lg.rw_554 mg.zu.un_660 
  0x52651fa0, 0x1a5e735a, 0x476b1a12, 0x5e004705,   // cy.gv.ha_322 ny.ts.tl_553  tl.ceb.sn_654 sn.ts.un_330 
  // [1e0d0]
  0x2f216209, 0x6439520b, 0x040823a7, 0x1b483155,   // kha.jw.su_444 ha.br.lg_542  ky.uk.ru_532 az.tt.tr_442 
  0x55004b08, 0x3f005119, 0x2758180c, 0x45003e09,   // mi.rw.un_430 kl.af.un_750  ga.om.gd_543 rm.ln.un_440 
  0x46477312, 0x2400690d, 0x21583bad, 0x47730f13,   // ny.sn.qu_654 mfe.eo.un_540  so.om.jw_643 lv.ny.sn_665 
  0x5e023607, 0x55fa3511, 0x79fa34a4, 0x5045280c,   // gn.da.ts_432 zu.nr.rw_653  xh.nr.war_433 sw.ln.fj_543 
  // [1e0e0]
  0x2a4c280c, 0x28735e08, 0x42072504, 0x75374e0c,   // sw.wo.mt_543 ts.ny.sw_443  eu.it.co_332 ay.st.nso_543 
  0x36007312, 0x2d0a1807, 0x17351007, 0x15106207,   // ny.gn.un_640 ga.pt.sk_432  be.tg.sr_432 kha.lt.un_432 
  0x1b0903a7, 0x1873470c, 0x1c071e07, 0x73524cad,   // nl.pl.tr_532 sn.ny.ga_543  ms.it.id_432 wo.ha.ny_643 
  0x1d284512, 0x040723a0, 0x23355ea7, 0x15020604,   // ln.sw.la_654 ky.bg.ru_322  ts.zu.ca_532 de.da.un_332 
  // [1e0f0]
  0x2a075e0c, 0x234838a0, 0x1500fe12, 0x34734707,   // ts.it.mt_543 tk.tt.ky_322  tlh.un.un_640 sn.ny.xh_432 
  0x2f005e0c, 0x2330355a, 0x083517a9, 0x53330804,   // ts.su.un_530 tg.uz.ky_553  sr.tg.uk_544 no.nn.ht_332 
  0x360b1911, 0x022d0d08, 0x213c12a9, 0x17041002,   // gl.es.gn_653 cs.sk.da_443  ur.ug.fa_544 be.ru.sr_222 
  0x213d34a6, 0x2d130d04, 0x1a57250c, 0x1d002b05,   // ps.ku.fa_521 cs.et.sk_332  eu.na.tl_543 vi.la.un_330 
  // [1e100]
  0x571b3809, 0x12362da0, 0xfc541ca4, 0x0457fc0c,   // tk.tr.na_444 sk.gn.hu_322  id.ik.zzp_433 zzp.na.fi_543 
  0x1b00600d, 0x310b22a0, 0x1b00530d, 0x5300130c,   // vo.tr.un_540 oc.es.az_322  ht.tr.un_540 et.ht.un_530 
  0x023401a4, 0x133e4a07, 0x1dfe11ad, 0x0f003802,   // en.xh.da_433 yo.rm.et_432  ro.tlh.la_643 tk.lv.un_220 
  0x234a22a0, 0x59fc5508, 0x182223b4, 0x353f0255,   // oc.yo.ca_322 rw.zzp.rn_443  ca.oc.ga_754 da.af.zu_442 
  // [1e110]
  0x3f003b02, 0x104423ad, 0x04004d07, 0x2e05070c,   // so.af.un_220 ky.kk.be_643  aa.fi.un_420 it.fr.fo_543 
  0x15005f04, 0x2d353405, 0x36002702, 0x17303555,   // tn.un.un_320 xh.zu.sk_333  gd.gn.un_220 tg.uz.sr_442 
  0x63006012, 0x22532311, 0x0e002019, 0x160a5ca0,   // vo.sco.un_640 ca.ht.oc_653  sq.is.un_750 sa.pt.hr_322 
  0x394b0207, 0x73524712, 0x65003f11, 0x0b6b1dee,   // da.mi.br_432 sn.ha.ny_654  af.gv.un_630 la.ceb.es_422 
  // [1e120]
  0x37004923, 0x396a1f12, 0x174815ee, 0x026a4bad,   // to.st.un_880 cy.haw.br_654  un.tt.sr_422 mi.haw.da_643 
  0x63fc01a0, 0x02494b12, 0x557359ad, 0x382d0d13,   // en.zzp.sco_322 mi.to.da_654  rn.ny.rw_643 cs.sk.tk_665 
  0x0e3f09a0, 0x635a6205, 0x44081704, 0x1e1cfca0,   // pl.af.is_322 kha.sm.sco_333  sr.uk.kk_332 zzp.id.ms_322 
  0x18420512, 0x13004b12, 0x3c0407a6, 0x3c4436a4,   // fr.co.ga_654 mi.et.un_640  bg.ru.ug_521 ab.kk.ug_433 
  // [1e130]
  0x21341809, 0x1d515707, 0x23002511, 0x650251a4,   // ar.ps.fa_444 na.kl.la_432  mn.ky.un_630 kl.da.gv_433 
  0x462e1dad, 0x0e631da9, 0x334d65ad, 0x63003e21,   // la.fo.qu_643 la.sco.is_544  gv.aa.nn_643 rm.sco.un_860 
  0x0c130411, 0x08103509, 0x0a081760, 0x020e3ba0,   // fi.et.sv_653 tg.be.uk_444  sr.uk.mk_664 so.is.da_322 
  0x25000f0c, 0x200e2e0e, 0x4063430d, 0x0448155a,   // lv.eu.un_530 fo.is.sq_555  ie.sco.lb_554 un.tt.ru_553 
  // [1e140]
  0x2a0e2e14, 0x620e2eaf, 0x330c08af, 0x07003705,   // fo.is.mt_666 fo.is.kha_655  no.sv.nn_655 ba.bg.un_330 
  0x352330a4, 0x04353002, 0x55025c07, 0x5c64120c,   // uz.ky.tg_433 uz.tg.ru_222  sa.da.rw_432 hu.lg.sa_543 
  0x026a3612, 0x6467590c, 0x34301805, 0x071d6a05,   // gn.haw.da_654 rn.ak.lg_543  ar.uz.ps_333 haw.la.it_333 
  0x041a39a4, 0x61555c13, 0x5c00641a, 0x025c5511,   // br.tl.fi_433 sa.rw.za_665  lg.sa.un_760 rw.sa.da_653 
  // [1e150]
  0x5c4557a4, 0x5e005c1a, 0x51540707, 0x394205a0,   // na.ln.sa_433 sa.ts.un_760  it.ik.kl_432 fr.co.br_322 
  0x1a5c64a0, 0x64001307, 0x02555c0d, 0x1200250b,   // lg.sa.tl_322 et.lg.un_420  sa.rw.da_554 eu.hu.un_520 
  0x063e25a9, 0x481023a7, 0x0526fca4, 0x284e7304,   // eu.rm.de_544 ky.be.tt_532  zzp.ia.fr_433 ny.ay.sw_332 
  0x45005c08, 0x73000209, 0x59555c14, 0x043e0905,   // sa.ln.un_430 da.ny.un_440  sa.rw.rn_666 pl.rm.fi_333 
  // [1e160]
  0x2b006119, 0xfe004608, 0x5800fe14, 0x69613ba4,   // za.vi.un_750 qu.tlh.un_430  tlh.om.un_660 so.za.mfe_433 
  0x3b3f03a7, 0x1563050d, 0x2a3bfe0b, 0x394205ad,   // nl.af.so_532 fr.sco.un_554  tlh.so.mt_542 fr.co.br_643 
  0x3e0422a4, 0x1530155a, 0x4c583baf, 0x40065709,   // oc.fi.rm_433 un.uz.un_553  so.om.wo_655 na.de.lb_444 
  0x39100407, 0x3b4c03a9, 0x04221013, 0x0415350c,   // fi.lt.br_432 nl.wo.so_544  lt.oc.fi_665 tg.ru.un_530 
  // [1e170]
  0x4c5321ec, 0x223e1012, 0x3b58020c, 0x304c46a0,   // jw.ht.wo_644 lt.rm.oc_654  da.om.so_543 qu.wo.uz_322 
  0xfe002a21, 0x06103e04, 0x0c2f2107, 0x6e3e22af,   // mt.tlh.un_860 rm.lt.de_332  jw.su.sv_432 oc.rm.hmn_655 
  0x3b025807, 0x114015ee, 0x532221a0, 0x2f2138ee,   // om.da.so_432 un.lb.ro_422  jw.oc.ht_322 tk.jw.su_422 
  0x4e00fe1b, 0x10603b0c, 0x2c684c07, 0x3b041312,   // tlh.ay.un_770 so.vo.lt_543  wo.ig.fy_432 et.fi.so_654 
  // [1e180]
  0x05202212, 0x6b421104, 0x3e0643ac, 0x3e100408,   // oc.sq.fr_654 ro.co.ceb_332  ie.de.rm_632 fi.lt.rm_443 
  0x3e074209, 0x585238ad, 0x2057310c, 0x3e221005,   // co.it.rm_444 tk.ha.om_643  az.na.sq_543 lt.oc.rm_333 
  0x134c3b55, 0x4c2f5d02, 0x3e04220c, 0x1d065b08,   // so.wo.et_442 ss.su.wo_222  oc.fi.rm_543 sg.de.la_443 
  0x212253a4, 0x6500230d, 0x53212304, 0x052223ad,   // ht.oc.jw_433 ca.gv.un_540  ca.jw.ht_332 ca.oc.fr_643 
  // [1e190]
  0x20212fa7, 0x3e002104, 0x3b3031af, 0x0a124ca0,   // su.jw.sq_532 jw.rm.un_320  az.uz.so_655 wo.hu.pt_322 
  0xfe005b13, 0x1d1d0107, 0x48071002, 0x1e1330ad,   // sg.tlh.un_650 en.la.la_432  be.bg.tt_222 uz.et.ms_643 
  0x301b5b0c, 0x51052f0c, 0x40065b12, 0x3b1e5b08,   // sg.tr.uz_543 su.fr.kl_543  sg.de.lb_654 sg.ms.so_443 
  0x42052207, 0xfc2836ee, 0x3534fe07, 0x64735aa0,   // oc.fr.co_432 gn.sw.zzp_422  tlh.xh.zu_432 sm.ny.lg_322 
  // [1e1a0]
  0x57006e13, 0x553b590c, 0x2728490c, 0x5c05fc12,   // hmn.na.un_650 rn.so.rw_543  to.sw.gd_543 zzp.fr.sa_654 
  0x276318af, 0x28024baf, 0x403f4d0c, 0x133b580c,   // ga.sco.gd_655 mi.da.sw_655  aa.af.lb_543 om.so.et_543 
  0x2f001f0e, 0x4c406214, 0x2d450d55, 0x3f654c07,   // cy.su.un_550 kha.lb.wo_666  cs.ln.sk_442 wo.gv.af_432 
  0x3b654cec, 0x303c3811, 0x2c222308, 0x35736807,   // wo.gv.so_644 tk.ug.uz_653  ca.oc.fy_443 ig.ny.zu_432 
  // [1e1b0]
  0x133f4c07, 0x48000d07, 0x3f0365a9, 0x13373fa6,   // wo.af.et_432 cs.tt.un_420  gv.nl.af_544 af.st.et_521 
  0x3b3f63ee, 0x65304ca4, 0x08000602, 0x56050dee,   // sco.af.so_422 wo.uz.gv_433  de.no.un_220 cs.fr.mg_422 
  0x13033f04, 0x02212fa4, 0x55683507, 0x73473412,   // af.nl.et_332 su.jw.da_433  zu.ig.rw_432 xh.sn.ny_654 
  0x08000a21, 0x21021aad, 0x3b340305, 0x28003c1b,   // mk.uk.un_860 tl.da.jw_643  nl.xh.so_333 ug.sd.un_770 
  // [1e1c0]
  0x48006304, 0x55002702, 0x13033f0d, 0x23564aa6,   // sco.tt.un_320 gd.rw.un_220  af.nl.et_554 yo.mg.ca_521 
  0x0a00561a, 0x3b003f07, 0x6b3b320d, 0x19006305,   // mg.pt.un_760 af.so.un_420  bs.so.ceb_554 sco.gl.un_330 
  0x2f00300e, 0x2f006512, 0x657358a4, 0x124d4507,   // uz.su.un_550 gv.su.un_640  om.ny.gv_433 ln.aa.hu_432 
  0x073537a7, 0x5c2102a4, 0x3b30fc04, 0x0d2d120b,   // ba.tg.bg_532 da.jw.sa_433  zzp.uz.so_332 hu.sk.cs_542 
  // [1e1d0]
  0x133f0313, 0x5f5547a4, 0x2e124a07, 0x120a0d14,   // nl.af.et_665 sn.rw.tn_433  yo.hu.fo_432 cs.pt.hu_666 
  0x183c4407, 0xfc006b08, 0x101123a9, 0x48363808,   // kk.ug.ar_432 ceb.zzp.un_430  ky.ro.be_544 tk.ab.tt_443 
  0x44001519, 0x5100020e, 0x381b48a7, 0x23000a1a,   // un.kk.un_750 da.kl.un_550  tt.tr.tk_532 pt.ca.un_760 
  0x482315af, 0x0a17085a, 0x18233c5a, 0x6531380c,   // un.ky.tt_655 uk.sr.mk_553  ug.ky.ar_553 tk.az.gv_543 
  // [1e1e0]
  0x48006011, 0x19030204, 0x25001d0c, 0x25170407,   // vo.tt.un_630 da.nl.gl_332  la.eu.un_530 ru.sr.mn_432 
  0x133f1da0, 0x150411a7, 0x2f001808, 0x2100440b,   // la.af.et_322 ro.ru.un_532  ga.su.un_430 kk.fa.un_520 
  0x306a1dee, 0x30481004, 0x2e0e1813, 0x370e2802,   // la.haw.uz_422 lt.tt.uz_332  ga.is.fo_665 sw.is.st_222 
  0x080704ad, 0x1500250c, 0x133638a0, 0x061f330c,   // ru.bg.uk_643 eu.un.un_530  tk.gn.et_322 nn.cy.de_543 
  // [1e1f0]
  0x6473560d, 0x1d0f1008, 0x17303cec, 0x04361311,   // mg.ny.lg_554 lt.lv.la_443  ug.uz.sr_644 et.gn.fi_653 
  0x4d355dad, 0x2127280d, 0x212a53af, 0x333f0402,   // ss.zu.aa_643 sw.gd.jw_554  ht.mt.jw_655 fi.af.nn_222 
  0x06007812, 0x1227625a, 0x5900350d, 0x3c181207,   // ve.de.un_640 kha.gd.hu_553  zu.rn.un_540 ur.ar.ug_432 
  0x79391504, 0x35203407, 0x383b58a7, 0x3f0f0eee,   // un.br.war_332 xh.sq.zu_432  om.so.tk_532 is.lv.af_422 
  // [1e200]
  0x1d3e36a0, 0x2e372f02, 0x175135ad, 0x30000608,   // gn.rm.la_322 su.st.fo_222  zu.kl.sr_643 de.uz.un_430 
  0x5d735c0c, 0x56496aec, 0x04022407, 0x36286aad,   // sa.ny.ss_543 haw.to.mg_644  eo.da.fi_432 haw.sw.gn_643 
  0x4b285408, 0x652702a0, 0x4b0456ec, 0x6a271812,   // ik.sw.mi_443 da.gd.gv_322  mg.fi.mi_644 ga.gd.haw_654 
  0x02004b13, 0x122d0408, 0x3b6a1a07, 0x56261d60,   // mi.da.un_650 fi.sk.hu_443  tl.haw.so_432 la.ia.mg_664 
  // [1e210]
  0x044b54ee, 0x02494baf, 0x183e27af, 0x5a182713,   // ik.mi.fi_422 mi.to.da_655  gd.rm.ga_655 gd.ga.sm_665 
  0x0c2e3f07, 0x226536a4, 0x52495607, 0x06137907,   // af.fo.sv_432 gn.gv.oc_433  mg.to.ha_432 war.et.de_432 
  0x59551b0e, 0x1c5e1eaf, 0x123209ee, 0x6b023707,   // tr.rw.rn_555 ms.ts.id_655  pl.bs.hu_422 st.da.ceb_432 
  0x3f1f3804, 0x49136aec, 0x0f2f040c, 0x494b540c,   // tk.cy.af_332 haw.et.to_644  fi.su.lv_543 ik.mi.to_543 
  // [1e220]
  0x2f001307, 0x13fe5c55, 0x4b2718ad, 0x4b005507,   // et.su.un_420 sa.tlh.et_442  ga.gd.mi_643 rw.mi.un_420 
  0x5e2f2104, 0x4d004b0e, 0x4b323b0b, 0x40060108,   // jw.su.ts_332 mi.aa.un_550  so.bs.mi_542 en.de.lb_443 
  0x4b521baf, 0x0e00620d, 0x0a0730ec, 0x2c2e1fee,   // tr.ha.mi_655 kha.is.un_540  uz.bg.mk_644 cy.fo.fy_422 
  0x20001f05, 0x214418ee, 0x09471da0, 0x3b3012a4,   // cy.sq.un_330 ar.kk.fa_422  la.sn.pl_322 ur.uz.ks_433 
  // [1e230]
  0x36124d07, 0x0b00380b, 0x46003810, 0x60003e0e,   // aa.hu.gn_432 tk.es.un_520  tk.qu.un_620 rm.vo.un_550 
  0x170a115a, 0x123e380c, 0x67fe6e08, 0x04fe1f07,   // ro.mk.sr_553 tk.rm.hu_543  hmn.tlh.ak_443 cy.tlh.fi_432 
  0x16002411, 0x5a041807, 0x3229240c, 0x61002421,   // eo.hr.un_630 ga.fi.sm_432  eo.sl.bs_543 eo.za.un_860 
  0x3c303512, 0x20002420, 0xfe6e205a, 0x1600240d,   // tg.uz.ug_654 eo.sq.un_850  sq.hmn.tlh_553 eo.hr.un_540 
  // [1e240]
  0x24002d1a, 0xfe002421, 0x2046fe0b, 0x15656aa0,   // sk.eo.un_760 eo.tlh.un_860  tlh.qu.sq_542 haw.gv.un_322 
  0x3456520c, 0x3118fca7, 0x2e0f040e, 0x4d514c0d,   // ha.mg.xh_543 zzp.ga.az_532  fi.lv.fo_555 wo.kl.aa_554 
  0x29242004, 0x136445a0, 0x04443709, 0x3815230e,   // sq.eo.sl_332 ln.lg.et_322  ba.kk.ru_444 ky.tk.un_550 
  0x1530350e, 0x290f25ee, 0x6b0930ee, 0x300f480d,   // tg.uz.un_555 eu.lv.sl_422  uz.pl.ceb_422 tt.lv.uz_554 
  // [1e250]
  0x50384610, 0x0e6a7307, 0x5d130107, 0x29250d12,   // qu.tk.fj_642 ny.haw.is_432  en.et.ss_432 cs.eu.sl_654 
  0x1e1c4da0, 0x0300130b, 0x3f2e0e04, 0x15442312,   // aa.id.ms_322 et.nl.un_520  is.fo.af_332 ky.kk.un_654 
  0x373048ee, 0x5d6530a9, 0x09350da0, 0x5900780d,   // tt.uz.ba_422 uz.gv.ss_544  cs.zu.pl_322 ve.rn.un_540 
  0x555d4709, 0x59553b09, 0x033e1d07, 0x2a2e3ea4,   // sn.ss.rw_444 so.rw.rn_444  la.rm.nl_432 rm.fo.mt_433 
  // [1e260]
  0x38480a08, 0x2e003f04, 0x2e130e04, 0x2411200d,   // mk.tt.tk_443 af.fo.un_320  is.et.fo_332 sq.ro.eo_554 
  0x2900481a, 0x0d003502, 0x301d5507, 0x55460209,   // tt.sl.un_760 zu.cs.un_220  rw.la.uz_432 da.qu.rw_444 
  0x2d100da0, 0x58002d0c, 0x5c12470c, 0x52280208,   // cs.lt.sk_322 sk.om.un_530  sn.hu.sa_543 da.sw.ha_443 
  0x10254809, 0x17083c0c, 0x284634af, 0x12001608,   // tt.mn.be_444 ug.uk.sr_543  xh.qu.sw_655 hr.hu.un_430 
  // [1e270]
  0x427302a0, 0x134006ad, 0x4c006b0c, 0x343d2160,   // da.ny.co_322 de.lb.et_643  ceb.wo.un_530 fa.ku.ps_664 
  0x233c250d, 0x02467308, 0x6b7368a0, 0x38514d11,   // mn.ug.ky_554 ny.qu.da_443  ig.ny.ceb_322 aa.kl.tk_653 
  0x121b380c, 0x4f381b08, 0x57255da9, 0x1a2538a0,   // tk.tr.hu_543 tr.tk.bi_443  ss.eu.na_544 tk.eu.tl_322 
  0x353b55a0, 0x02381b55, 0x34005c07, 0xfe0273ec,   // rw.so.zu_322 tr.tk.da_442  sa.xh.un_420 ny.da.tlh_644 
  // [1e280]
  0x28003902, 0x251b385a, 0x041744a6, 0x38311e04,   // br.sw.un_220 tk.tr.eu_553  kk.sr.ru_521 ms.az.tk_332 
  0x33080e14, 0x0a303704, 0x2855fe07, 0x300252ad,   // is.no.nn_666 ba.uz.mk_332  tlh.rw.sw_432 ha.da.uz_643 
  0x5c13fe07, 0x46373fee, 0x2d002c1b, 0x24001302,   // tlh.et.sa_432 af.st.qu_422  fy.sk.un_770 et.eo.un_220 
  0x04004204, 0x4700fe0b, 0x0415350d, 0x09652d55,   // co.fi.un_320 tlh.sn.un_520  tg.ru.un_540 sk.gv.pl_442 
  // [1e290]
  0x1b000f1b, 0x322e0207, 0x1000fe11, 0x0c0e3905,   // lv.tr.un_770 da.fo.bs_432  tlh.lt.un_630 br.is.sv_333 
  0x29fe5c0c, 0x04135c0c, 0x0413feaf, 0xfc4230a0,   // sa.tlh.sl_543 sa.et.fi_543  tlh.et.fi_655 uz.co.zzp_322 
  0x4c6946a4, 0x3e40065a, 0x28005608, 0x39004611,   // qu.mfe.wo_433 de.lb.rm_553  mg.sw.un_430 qu.br.un_630 
  0x441025a7, 0x1c1536a0, 0x0e005605, 0x084807ee,   // mn.be.kk_532 gn.id.un_320  mg.is.un_330 bg.tt.uk_422 
  // [1e2a0]
  0x0735150c, 0x53054004, 0x06001c07, 0x2d204c05,   // un.tg.bg_543 lb.fr.ht_332  id.de.un_420 wo.sq.sk_333 
  0x5d2f35a4, 0x36054508, 0x0a792004, 0x125238a0,   // zu.su.ss_433 ln.fr.gn_443  sq.war.pt_332 tk.ha.hu_322 
  0x3f00050d, 0x1c4a36a7, 0x4b000108, 0x345d2002,   // fr.af.un_540 gn.yo.id_532  en.mi.un_430 sq.ss.xh_222 
  0x3e2f5cee, 0x201b4c07, 0x4a360f5a, 0x053447a4,   // sa.su.rm_422 wo.tr.sq_432  lv.gn.yo_553 sn.xh.fr_433 
  // [1e2b0]
  0x493765ad, 0x100f2d0b, 0x4300190d, 0x2e621308,   // gv.st.to_643 sk.lv.lt_542  gl.ie.un_540 et.kha.fo_443 
  0x36694baf, 0x176925a4, 0x1b5955ec, 0x193620a4,   // mi.mfe.gn_655 eu.mfe.sr_433  rw.rn.tr_644 sq.gn.gl_433 
  0x430501a4, 0x0d002007, 0x052601a4, 0x133e2cad,   // en.fr.ie_433 sq.cs.un_420  en.ia.fr_433 fy.rm.et_643 
  0x216834a7, 0x300748a7, 0x271520ee, 0x29000d0e,   // xh.ig.jw_532 tt.bg.uz_532  sq.gd.un_420 cs.sl.un_550 
  // [1e2c0]
  0x13280407, 0x444804ee, 0x42130413, 0x1d5a1307,   // fi.sw.et_432 ru.tt.kk_422  fi.et.co_665 et.sm.la_432 
  0x32006507, 0x511d130c, 0x30351507, 0x202e0ea4,   // gv.bs.un_420 et.la.kl_543  un.tg.uz_432 is.fo.sq_433 
  0x064b78ee, 0x3f4b04ee, 0x1c164207, 0x5113040d,   // ve.mi.de_422 fi.mi.af_422  co.hr.id_432 fi.et.kl_554 
  0x38463002, 0x48101107, 0x13005d19, 0x6b0140ee,   // uz.qu.tk_222 ro.be.tt_432  ss.et.un_750 lb.en.ceb_422 
  // [1e2d0]
  0x28005909, 0x0e132c07, 0x1d190ca4, 0x464efcaf,   // rn.sw.un_440 fy.et.is_432  sv.gl.la_433 zzp.ay.qu_655 
  0x375d0107, 0x330c0f0c, 0x64556aa4, 0x130f46ec,   // en.ss.st_432 lv.sv.nn_543  haw.rw.lg_433 qu.lv.et_644 
  0x100c4e0c, 0x2e005304, 0x43001f12, 0x08070aa9,   // ay.sv.lt_543 ht.fo.un_320  cy.ie.un_640 mk.bg.uk_544 
  0x0f000914, 0x36000902, 0x02151dee, 0x250f2908,   // pl.lv.un_660 pl.gn.un_220  la.da.un_420 sl.lv.eu_443 
  // [1e2e0]
  0x2d00330d, 0x46311bee, 0x394e09a7, 0x332e0fa9,   // nn.sk.un_540 tr.az.qu_422  pl.ay.br_532 lv.fo.nn_544 
  0x1c2a46a0, 0x1723150b, 0x1f5f7507, 0x15071504,   // qu.mt.id_322 un.ky.sr_542  nso.tn.cy_432 un.bg.un_332 
  0x53001f08, 0x0d093bad, 0x3400031a, 0x47005309,   // cy.ht.un_430 ks.hi.ne_643  nl.xh.un_760 ht.sn.un_440 
  0x182a7508, 0x2873570d, 0x1f346407, 0x40091207,   // nso.mt.ga_443 na.ny.sw_554  lg.xh.cy_432 hu.pl.lb_432 
  // [1e2f0]
  0x55372aa9, 0x470603a0, 0x065f40a0, 0x02120307,   // mt.st.rw_544 nl.de.sn_322  lb.tn.de_322 nl.hu.da_432 
  0x33000907, 0x64355507, 0x23004818, 0x55006419,   // pl.nn.un_420 rw.zu.lg_432  tt.ky.un_740 lg.rw.un_750 
  0x3d3b210d, 0x4559550d, 0x3f637304, 0x46000913,   // fa.ks.ku_554 rw.rn.ln_554  ny.sco.af_332 pl.qu.un_650 
  0x52005813, 0x030912a7, 0x6a62500c, 0x0e5e370c,   // om.ha.un_650 hu.pl.nl_532  fj.kha.haw_543 st.ts.is_543 
  // [1e300]
  0x2e002423, 0x03205704, 0x40005e04, 0x614ffea9,   // eo.fo.un_880 na.sq.nl_332  ts.lb.un_320 tlh.bi.za_544 
  0x167321a6, 0x295709a9, 0x34123ca4, 0x10332407,   // jw.ny.hr_521 pl.na.sl_544  ug.ur.ps_433 eo.nn.lt_432 
  0x324d2512, 0x0300570d, 0x1c311ea4, 0x244f0ea0,   // eu.aa.bs_654 na.nl.un_540  ms.az.id_433 is.bi.eo_322 
  0x2b2f1aec, 0x61002905, 0x0e062ea0, 0x19000c04,   // tl.su.vi_644 sl.za.un_330  fo.de.is_322 sv.gl.un_320 
  // [1e310]
  0x0c0446a0, 0x070e2e12, 0x28123d02, 0x205329ec,   // qu.fi.sv_322 fo.is.it_654  ku.ur.sd_222 sl.ht.sq_644 
  0x2900610c, 0x390569ee, 0x45001e0d, 0x0f1225a4,   // za.sl.un_530 mfe.fr.br_422  ms.ln.un_540 eu.hu.lv_433 
  0x0f2c03a7, 0xfc304604, 0x2500510e, 0x5340760c,   // nl.fy.lv_532 qu.uz.zzp_332  kl.eu.un_550 crs.lb.ht_543 
  0xfc1030ee, 0x3c283007, 0x0e462e05, 0x356455a6,   // uz.lt.zzp_422 uz.sd.ug_432  fo.qu.is_333 rw.lg.zu_521 
  // [1e320]
  0x02004a09, 0x09003207, 0x0e1d30ad, 0x301b3805,   // yo.da.un_440 bs.pl.un_420  uz.la.is_643 tk.tr.uz_333 
  0x69222008, 0x0f29200c, 0x4c000905, 0x0d5e2d07,   // sq.oc.mfe_443 sq.sl.lv_543  pl.wo.un_330 sk.ts.cs_432 
  0x49356a0d, 0x29615755, 0x0d0c3807, 0x596b55a9,   // haw.zu.to_554 na.za.sl_442  tk.sv.cs_432 rw.ceb.rn_544 
  0x12511b07, 0x301b79ad, 0x37007522, 0x5d3554af,   // tr.kl.hu_432 war.tr.uz_643  nso.st.un_870 ik.zu.ss_655 
  // [1e330]
  0x01386bee, 0x10173505, 0x655530ad, 0x276539ee,   // ceb.tk.en_422 tg.sr.be_333  uz.rw.gv_643 br.gv.gd_422 
  0x5d351d07, 0x4a4602ee, 0x30363b55, 0x4b592fa9,   // la.zu.ss_432 da.qu.yo_422  so.gn.uz_442 su.rn.mi_544 
  0x377335a7, 0x033ffeee, 0x376e5e0d, 0x10041307,   // zu.ny.st_532 tlh.af.nl_422  ts.hmn.st_554 et.fi.lt_432 
  0xfc595504, 0x0b00270c, 0x0442100c, 0x17200c04,   // rw.rn.zzp_332 gd.es.un_530  lt.co.fi_543 sv.sq.sr_332 
  // [1e340]
  0x103809a7, 0x020e43ee, 0x79113007, 0x100436ad,   // pl.tk.lt_532 ie.is.da_422  uz.ro.war_432 gn.fi.lt_643 
  0x5dfc35a4, 0x090c1e0c, 0x1b22fead, 0xfe003805,   // zu.zzp.ss_433 ms.sv.pl_543  tlh.oc.tr_643 tk.tlh.un_330 
  0x134204ac, 0x1b601214, 0x483725ec, 0x0a072312,   // fi.co.et_632 hu.vo.tr_666  mn.ba.tt_644 ky.bg.mk_654 
  0x301735ee, 0x38301560, 0x34281809, 0x0b1218ee,   // tg.sr.uz_422 un.uz.tk_664  ar.sd.ps_444 ga.hu.es_422 
  // [1e350]
  0xfa35fc0c, 0x5e3435ee, 0x6e37730c, 0xfa35630c,   // zzp.zu.nr_543 zu.xh.ts_422  ny.st.hmn_543 sco.zu.nr_543 
  0x2c5e03a4, 0x351ffc0c, 0x3d443c07, 0x340835ec,   // nl.ts.fy_433 zzp.cy.zu_543  ug.kk.ku_432 zu.no.xh_644 
  0x2837570c, 0x1500fc0e, 0x2c0203ee, 0x150804ee,   // na.st.sw_543 zzp.un.un_550  nl.da.fy_422 ru.uk.un_422 
  0x52005002, 0x562f2507, 0x38002d20, 0x53002302,   // fj.ha.un_220 eu.su.mg_432  sk.tk.un_850 ca.ht.un_220 
  // [1e360]
  0x313b4da4, 0x302344ad, 0x3920060c, 0x0d162da0,   // aa.so.az_433 kk.ky.uz_643  de.sq.br_543 sk.hr.cs_322 
  0x3b4d3960, 0x46383105, 0x5c005713, 0x39000a05,   // br.aa.so_664 az.tk.qu_333  na.sa.un_650 pt.br.un_330 
  0x11003607, 0x033f1104, 0x53004a09, 0x2d100faf,   // gn.ro.un_420 ro.af.nl_332  yo.ht.un_440 lv.lt.sk_655 
  0x0a100404, 0x0a001013, 0x294b02ee, 0x5f676aa4,   // ru.be.mk_332 be.mk.un_650  da.mi.sl_422 haw.ak.tn_433 
  // [1e370]
  0x73630112, 0x52005604, 0x56004b07, 0x0f000407,   // en.sco.ny_654 mg.ha.un_320  mi.mg.un_420 fi.lv.un_420 
  0x5f00670e, 0x15001807, 0x6b150104, 0x43025111,   // ak.tn.un_550 ga.un.un_420  en.ceb.un_320 kl.da.ie_653 
  0x016549a0, 0x0a11385a, 0x1349560c, 0x283b18a7,   // to.gv.en_322 tk.ro.mk_553  mg.to.et_543 ar.ks.sd_532 
  0x18000202, 0x3e0c3fa4, 0x3312580c, 0x04484fa4,   // da.ga.un_220 af.sv.rm_433  om.hu.nn_543 bi.tt.fi_433 
  // [1e380]
  0x0a002704, 0x106409a0, 0x47580aee, 0x5c1304ec,   // gd.pt.un_320 pl.lg.lt_322  pt.om.sn_422 fi.et.sa_644 
  0x10465c08, 0x11001807, 0x092912ec, 0x464e3b0e,   // sa.qu.lt_443 ga.ro.un_420  hu.sl.pl_644 so.ay.qu_555 
  0x0e00541a, 0xfc0c080c, 0x221a6ba4, 0x4f004b21,   // ik.is.un_760 no.sv.zzp_543  ceb.tl.oc_433 mi.bi.un_860 
  0x3b002e05, 0x6508fcad, 0x73304804, 0x13585a04,   // fo.so.un_330 zzp.no.gv_643  tt.uz.ny_332 sm.om.et_332 
  // [1e390]
  0x1e003b08, 0x48082502, 0x08041714, 0x0a151755,   // so.ms.un_430 mn.uk.tt_222  sr.ru.uk_666 sr.mk.un_420 
  0x4448230d, 0x205321a0, 0x23150460, 0x1e002907,   // ky.tt.kk_554 jw.ht.sq_322  ru.ky.un_640 sl.ms.un_420 
  0x094d4604, 0x302d15a0, 0x39006107, 0x4c22020c,   // qu.aa.pl_332 un.sk.uz_322  za.br.un_420 da.oc.wo_543 
  0x310e330c, 0x48373c0b, 0x1e791c0c, 0x2e336008,   // nn.is.az_543 ug.ba.tt_542  id.war.ms_543 vo.nn.fo_443 
  // [1e3a0]
  0x0c3f03ee, 0x0f04130d, 0x323e0708, 0x565c11af,   // nl.af.sv_422 et.fi.lv_554  it.rm.bs_443 ro.sa.mg_655 
  0x5d284705, 0x406130ad, 0x1c4b1e04, 0x0c5c2d55,   // sn.sw.ss_333 uz.za.lb_643  ms.mi.id_332 sk.sa.sv_442 
  0x57006209, 0x4778300c, 0x25123504, 0x32592807,   // kha.na.un_440 uz.ve.sn_543  zu.hu.eu_332 sw.rn.bs_432 
  0x21124a07, 0x5b002d1a, 0x3f5d2804, 0x3f005604,   // yo.hu.jw_432 sk.sg.un_760  sw.ss.af_332 mg.af.un_320 
  // [1e3b0]
  0x6a58fe05, 0x7300120c, 0x0d05225a, 0x34000211,   // tlh.om.haw_333 hu.ny.un_530  oc.fr.cs_553 da.xh.un_630 
  0x2f005b11, 0x5e557807, 0x35250708, 0x556b1aa9,   // sg.su.un_630 ve.rw.ts_432  it.eu.zu_443 tl.ceb.rw_544 
  0x42065bad, 0x3640120c, 0x192d0d12, 0x25561104,   // sg.de.co_643 hu.lb.gn_543  cs.sk.gl_654 ro.mg.eu_332 
  0x230a0712, 0x4a002317, 0x3100481f, 0x28680204,   // bg.mk.ky_654 ca.yo.un_730  tt.az.un_840 da.ig.sw_332 
  // [1e3c0]
  0x330540ee, 0x30310604, 0x5c3e5012, 0x28003807,   // lb.fr.nn_422 de.az.uz_332  fj.rm.sa_654 tk.sw.un_420 
  0x080e2cee, 0x35284713, 0x1a00680c, 0x02283504,   // fy.is.no_422 sn.sw.zu_665  ig.tl.un_530 zu.sw.da_332 
  0x16293007, 0x212f0404, 0x30555912, 0x06000d0e,   // uz.sl.hr_432 fi.su.jw_332  rn.rw.uz_654 cs.de.un_550 
  0x0c3f2c07, 0x12304704, 0x79291604, 0x494b3607,   // fy.af.sv_432 sn.uz.hu_332  hr.sl.war_332 gn.mi.to_432 
  // [1e3d0]
  0x2d212f05, 0x69110d07, 0x286869a0, 0x4b1a04a4,   // su.jw.sk_333 cs.ro.mfe_432  mfe.ig.sw_322 fi.tl.mi_433 
  0x48003110, 0x69004208, 0x153604a4, 0x3e4f42a4,   // az.tt.un_620 co.mfe.un_430  ru.ab.un_433 co.bi.rm_433 
  0x10443702, 0x100ffc07, 0x52006e0c, 0x2763010b,   // ba.kk.be_222 zzp.lv.lt_432  hmn.ha.un_530 en.sco.gd_542 
  0x0a3963a6, 0x5a5039ad, 0x463e1804, 0x2d230a0c,   // sco.br.pt_521 br.fj.sm_643  ga.rm.qu_332 pt.ca.sk_543 
  // [1e3e0]
  0x0b63010c, 0x631301ee, 0x6b2c13a7, 0x1d004335,   // en.sco.es_543 en.et.sco_422  et.fy.ceb_532 ie.la.un_A90 
  0x170115a7, 0x1d006e22, 0x4d39120d, 0x12002514,   // un.en.sr_532 hmn.la.un_870  hu.br.aa_554 eu.hu.un_660 
  0x525655ee, 0x1e1c5ea0, 0x56353413, 0x1e1c54ac,   // rw.mg.ha_422 ts.id.ms_322  xh.zu.mg_665 ik.id.ms_632 
  0x384312ec, 0x121b4d0c, 0x23284404, 0x21303cad,   // hu.ie.tk_644 aa.tr.hu_543  kk.sd.ky_332 ug.uz.fa_643 
  // [1e3f0]
  0x2500121a, 0x233730a0, 0x0408105a, 0x4f69420d,   // hu.eu.un_760 uz.ba.ky_322  be.uk.ru_553 co.mfe.bi_554 
  0x52fc2aa0, 0x380c1b0c, 0x2040060b, 0x0a240ba4,   // mt.zzp.ha_322 tr.sv.tk_543  de.lb.sq_542 es.eo.pt_433 
  0x6b000b07, 0x2200420c, 0x164812a0, 0x27185a04,   // es.ceb.un_420 co.oc.un_530  hu.tt.hr_322 sm.ga.gd_332 
  0x286a5aaf, 0x475d02ad, 0x04006021, 0x37040755,   // sm.haw.sw_655 da.ss.sn_643  vo.fi.un_860 bg.ru.ba_442 
  
  // [1e400]
  0x6a18270c, 0x3848040c, 0x456a04a4, 0x3b290204,   // gd.ga.haw_543 fi.tt.tk_543  fi.haw.ln_433 da.sl.so_332 
  0x13003904, 0x48000902, 0x18005a05, 0x16272504,   // br.et.un_320 pl.tt.un_220  sm.ga.un_330 eu.gd.hr_332 
  0x5a006e08, 0x07235107, 0x09112705, 0x0700370d,   // hmn.sm.un_430 kl.ca.it_432  gd.ro.pl_333 ba.bg.un_540 
  0x190a1d09, 0x09112504, 0x00006803, 0x515428a4,   // la.pt.gl_444 eu.ro.pl_332  ig.un.un_300 sw.ik.kl_433 
  // [1e410]
  0x285046a9, 0x1311270c, 0x1e135004, 0x1315010c,   // qu.fj.sw_544 gd.ro.et_543  fj.et.ms_332 en.et.un_530 
  0x07001d0c, 0x6b00280d, 0x73464e0d, 0x3500290b,   // la.it.un_530 sw.ceb.un_540  ay.qu.ny_554 sl.zu.un_520 
  0x303837a7, 0x301715a0, 0x365e0b0c, 0x534645a0,   // ba.tk.uz_532 un.sr.uz_322  es.ts.gn_543 ln.qu.ht_322 
  0x45205e12, 0x214c1ca0, 0x47365611, 0xfc003f19,   // ts.sq.ln_654 id.wo.jw_322  mg.gn.sn_653 af.zzp.un_750 
  // [1e420]
  0x050b1ea4, 0x08022ead, 0x353479a0, 0x79000804,   // ms.es.fr_433 fo.da.no_643  war.xh.zu_322 no.war.un_320 
  0x080215a0, 0x125425a7, 0x38002809, 0x211b4da7,   // un.da.no_322 eu.ik.hu_532  sw.tk.un_440 aa.tr.jw_532 
  0x29162a04, 0x455212a4, 0x4d30380c, 0x02372f0c,   // mt.hr.sl_332 hu.ha.ln_433  tk.uz.aa_543 su.st.da_543 
  0x61001c04, 0x13004b07, 0x2500540e, 0x551e1c55,   // id.za.un_320 mi.et.un_420  ik.eu.un_550 id.ms.rw_442 
  // [1e430]
  0x55004c08, 0x3e0c40a0, 0x591a5512, 0x602501a4,   // wo.rw.un_430 lb.sv.rm_322  rw.tl.rn_654 en.eu.vo_433 
  0x2f5c1ea0, 0x1a5e15a7, 0x18213bad, 0x35341aa7,   // ms.sa.su_322 un.ts.tl_532  ks.fa.ar_643 tl.xh.zu_532 
  0x4b6a360d, 0x1115045a, 0x0912250c, 0x1b633007,   // gn.haw.mi_554 ru.ro.un_530  eu.hu.pl_543 uz.sco.tr_432 
  0x36003907, 0x27215c02, 0x47003609, 0x425601a0,   // br.gn.un_420 sa.jw.gd_222  gn.sn.un_440 en.mg.co_322 
  // [1e440]
  0x386e1ba0, 0x1e1c79a4, 0x4d003019, 0x5c5559ad,   // tr.hmn.tk_322 war.id.ms_433  uz.aa.un_750 rn.rw.sa_643 
  0x0ffe100c, 0x081711a6, 0x3f3011ee, 0x120925ad,   // lt.tlh.lv_543 ro.sr.uk_521  ro.uz.af_422 eu.pl.hu_643 
  0x28200204, 0x5e5f37ad, 0x462025ee, 0x34065304,   // da.sq.sw_332 st.tn.ts_643  eu.sq.qu_422 ht.de.xh_332 
  0x18005419, 0x37007322, 0x51000712, 0x4b004604,   // ik.ga.un_750 ny.st.un_870  it.kl.un_640 qu.mi.un_320 
  // [1e450]
  0x4f21620c, 0x21675c0c, 0x07003e0e, 0x46203255,   // kha.jw.bi_543 sa.ak.jw_543  rm.it.un_550 bs.sq.qu_442 
  0x0a300804, 0x09645807, 0x0e2e3914, 0x3e2a07a4,   // uk.uz.mk_332 om.lg.pl_432  br.fo.is_666 it.mt.rm_433 
  0x284c4d0c, 0x075158ec, 0x0a370408, 0x44233012,   // aa.wo.sw_543 om.kl.it_644  ru.ba.mk_443 uz.ky.kk_654 
  0x08103511, 0x5c00610c, 0x5c311bee, 0x075c560c,   // tg.be.uk_653 za.sa.un_530  tr.az.sa_422 mg.sa.it_543 
  // [1e460]
  0x3e002311, 0x29165cee, 0x283b20a0, 0x604812ec,   // ca.rm.un_630 sa.hr.sl_422  sq.so.sw_322 hu.tt.vo_644 
  0x19183612, 0x2300601e, 0x0a363005, 0x4b005302,   // gn.ga.gl_654 vo.ca.un_830  uz.ab.mk_333 ht.mi.un_220 
  0x303b230d, 0x22004d0c, 0x0c2f46a0, 0x190b120c,   // ky.ks.uz_554 aa.oc.un_530  qu.su.sv_322 hu.es.gl_543 
  0x40000e08, 0x27001307, 0x422afa0c, 0x08351004,   // is.lb.un_430 et.gd.un_420  nr.mt.co_543 be.tg.uk_332 
  // [1e470]
  0x17073807, 0x150a1307, 0x5f56580c, 0x58070a0c,   // tk.bg.sr_432 et.pt.un_432  om.mg.tn_543 pt.it.om_543 
  0x195e3bec, 0x09001c20, 0x112322a9, 0x60001219,   // so.ts.gl_644 mr.hi.un_850  oc.ca.ro_544 hu.vo.un_750 
  0x3b0e06a0, 0x2e0e0608, 0x06005a07, 0x0c006019,   // de.is.so_322 de.is.fo_443  sm.de.un_420 vo.sv.un_750 
  0x51000d04, 0x4b515008, 0x06006b04, 0x3b1228af,   // cs.kl.un_320 fj.kl.mi_443  ceb.de.un_320 sd.ur.ks_655 
  // [1e480]
  0x5a005f12, 0x595c1309, 0x4438070c, 0x4d001d05,   // tn.sm.un_640 et.sa.rn_444  bg.tk.kk_543 la.aa.un_330 
  0x4d481ba4, 0x21181255, 0x2e060eaf, 0x48113ea0,   // tr.tt.aa_433 ur.ar.fa_442  is.de.fo_655 rm.ro.tt_322 
  0x505c7808, 0x064f0205, 0x483b5102, 0x5e005022,   // ve.sa.fj_443 da.bi.de_333  kl.so.tt_222 fj.ts.un_870 
  0x79005e13, 0x440a040c, 0x3000111b, 0x04003907,   // ts.war.un_650 ru.mk.kk_543  ro.uz.un_770 br.fi.un_420 
  // [1e490]
  0x2b004b04, 0x47115d08, 0x1d1351a4, 0x56647308,   // mi.vi.un_320 ss.ro.sn_443  kl.et.la_433 ny.lg.mg_443 
  0x31481b05, 0x5046510c, 0x3e420709, 0x6455250c,   // tr.tt.az_333 kl.qu.fj_543  it.co.rm_444 eu.rw.lg_543 
  0x35361004, 0x5864350c, 0x553834a4, 0x6442070c,   // be.ab.tg_332 zu.lg.om_543  xh.tk.rw_433 it.co.lg_543 
  0x3907640c, 0x07454204, 0x041324ec, 0x35302007,   // lg.it.br_543 co.ln.it_332  eo.et.fi_644 sq.uz.zu_432 
  // [1e4a0]
  0x10001802, 0x0f1bfe02, 0x791b31ee, 0x1a4a640c,   // ga.lt.un_220 tlh.tr.lv_222  az.tr.war_422 lg.yo.tl_543 
  0x35000f12, 0x5f13030c, 0xfc3b6204, 0x04643bec,   // lv.zu.un_640 nl.et.tn_543  kha.so.zzp_332 so.lg.fi_644 
  0xfe5630ad, 0x332e2408, 0x280464a4, 0x070a5807,   // uz.mg.tlh_643 eo.fo.nn_443  lg.fi.sw_433 om.pt.it_432 
  0x21371e0c, 0x6800fe12, 0x735658a9, 0x374b21a7,   // ms.st.jw_543 tlh.ig.un_640  om.mg.ny_544 jw.mi.st_532 
  // [1e4b0]
  0x45585604, 0x645f6713, 0x06006107, 0x0c50fc07,   // mg.om.ln_332 ak.tn.lg_665  za.de.un_420 zzp.fj.sv_432 
  0x04132108, 0x300d56a7, 0x6a003719, 0x3b58670c,   // jw.et.fi_443 mg.cs.uz_532  st.haw.un_750 ak.om.so_543 
  0x215c6a07, 0x2e130207, 0x5a2c67af, 0x39346405,   // haw.sa.jw_432 da.et.fo_432  ak.fy.sm_655 lg.xh.br_333 
  0x4c7328ad, 0x1a006b22, 0x03096412, 0x536b7612,   // sw.ny.wo_643 ceb.tl.un_870  lg.pl.nl_654 crs.ceb.ht_654 
  // [1e4c0]
  0x47644c0c, 0x5118270e, 0x1f005613, 0x55004c1a,   // wo.lg.sn_543 gd.ga.kl_555  mg.cy.un_650 wo.rw.un_760 
  0x023b5811, 0x64003012, 0x38355d02, 0x5535fea7,   // om.so.da_653 uz.lg.un_640  ss.zu.tk_222 tlh.zu.rw_532 
  0x133b4da9, 0x496a47a9, 0x38120fa4, 0x33024da0,   // aa.so.et_544 sn.haw.to_544  lv.hu.tk_433 aa.da.nn_322 
  0x424f070c, 0x3b476407, 0x230b51ad, 0x1d5c21a0,   // it.bi.co_543 lg.sn.so_432  kl.es.ca_643 jw.sa.la_322 
  // [1e4d0]
  0x2910fea9, 0x5c374bad, 0x5d5e29a4, 0x0c0e1bec,   // tlh.lt.sl_544 mi.st.sa_643  sl.ts.ss_433 tr.is.sv_644 
  0x373c4860, 0x37006a1a, 0x233034a9, 0x4c00610e,   // tt.ug.ba_664 haw.st.un_760  ps.uz.ky_544 za.wo.un_550 
  0x363573a4, 0x42471dee, 0x522c280c, 0x1d340107,   // ny.zu.gn_433 la.sn.co_422  sw.fy.ha_543 en.xh.la_432 
  0x61004c22, 0x36000212, 0x5d283055, 0x30363812,   // wo.za.un_870 da.gn.un_640  uz.sw.ss_442 tk.ab.uz_654 
  // [1e4e0]
  0x1c3673a7, 0x5d2504a9, 0x26004c19, 0x0b43420c,   // ny.gn.id_532 fi.eu.ss_544  wo.ia.un_750 co.ie.es_543 
  0x53304607, 0x04251d07, 0x07226707, 0x230b250d,   // qu.uz.ht_432 la.eu.fi_432  ak.oc.it_432 eu.es.ca_554 
  0x08151713, 0x1b483104, 0x421d3e11, 0x014c1d07,   // sr.uk.un_650 az.tt.tr_332  rm.la.co_653 la.wo.en_432 
  0x314c1d04, 0x30004618, 0x5e5d3409, 0x4f5504a4,   // la.wo.az_332 qu.uz.un_740  xh.ss.ts_444 fi.rw.bi_433 
  // [1e4f0]
  0x3235340d, 0x6800250d, 0x38766308, 0x2c4863a0,   // xh.zu.bs_554 eu.ig.un_540  sco.crs.tk_443 sco.tt.fy_322 
  0x5a0f08a0, 0xfe005c0c, 0x3c30230e, 0x073e7307,   // no.lv.sm_322 sa.tlh.un_530  ky.uz.ug_555 ny.rm.it_432 
  0x424c0107, 0x58013ea4, 0x16003908, 0x321b55a4,   // en.wo.co_432 rm.en.om_433  br.hr.un_430 rw.tr.bs_433 
  0x42fc35a4, 0x1b353405, 0x0500fc02, 0x3600200d,   // zu.zzp.co_433 xh.zu.tr_333  zzp.fr.un_220 sq.gn.un_540 
  // [1e500]
  0x402cfcee, 0x04153505, 0x64002e05, 0x31fe23a0,   // zzp.fy.lb_422 tg.ru.un_330  fo.lg.un_330 ca.tlh.az_322 
  0x0a101105, 0x2400690c, 0x28123d09, 0x2e0e06a0,   // ro.be.mk_333 mfe.eo.un_530  ku.ur.sd_444 de.is.fo_322 
  0x0a173ca7, 0x3400fe08, 0x10515aa0, 0x37385fad,   // ug.sr.mk_532 tlh.xh.un_430  sm.kl.lt_322 tn.tk.st_643 
  0x363b5ca4, 0xfe2a65ad, 0x40766909, 0x54645160,   // sa.so.gn_433 gv.mt.tlh_643  mfe.crs.lb_444 kl.lg.ik_664 
  // [1e510]
  0x19000f05, 0x170a0409, 0x691238a4, 0x0f001b07,   // lv.gl.un_330 ru.mk.sr_444  tk.hu.mfe_433 tr.lv.un_420 
  0x3e0f100c, 0x6b515408, 0x11233c09, 0x194d3860,   // lt.lv.rm_543 ik.kl.ceb_443  ug.ky.ro_444 tk.aa.gl_664 
  0x5c0f4b07, 0x3e053607, 0x187909ec, 0x511b4ca9,   // mi.lv.sa_432 gn.fr.rm_432  pl.war.ga_644 wo.tr.kl_544 
  0x5d002512, 0x30600107, 0x53693904, 0x65563ea7,   // eu.ss.un_640 en.vo.uz_432  br.mfe.ht_332 rm.mg.gv_532 
  // [1e520]
  0xfc642504, 0x382521a4, 0x2d0d3f0b, 0x0c03020c,   // eu.lg.zzp_332 jw.eu.tk_433  af.cs.sk_542 da.nl.sv_543 
  0x27183709, 0x18791aee, 0x06423904, 0x423e02a0,   // st.ga.gd_444 tl.war.ga_422  br.co.de_332 da.rm.co_322 
  0x0d2c3f0c, 0x3f001f0c, 0x301708a0, 0x351708a0,   // af.fy.cs_543 cy.af.un_530  uk.sr.uz_322 uk.sr.tg_322 
  0x334c400c, 0x4000310c, 0x10480aa0, 0x343c23a4,   // lb.wo.nn_543 az.lb.un_530  mk.tt.be_322 ky.ug.ps_433 
  // [1e530]
  0x07230a04, 0x4d005b13, 0x383c1504, 0x0800230b,   // mk.ky.bg_332 sg.aa.un_650  un.ug.tk_332 ky.uk.un_520 
  0x093567ee, 0x5a5268a4, 0x25353002, 0x3534fca9,   // ak.zu.pl_422 ig.ha.sm_433  uz.tg.mn_222 zzp.xh.zu_544 
  0x58365eac, 0x10040707, 0x364f5eec, 0x2f281e07,   // ts.gn.om_632 bg.ru.be_432  ts.bi.gn_644 ms.sw.su_432 
  0x364d5b12, 0x454728a9, 0x21004f0d, 0x581a08a0,   // sg.aa.gn_654 sw.sn.ln_544  bi.jw.un_540 no.tl.om_322 
  // [1e540]
  0x2e002a04, 0x30564b07, 0x475b3ba9, 0x49024b0c,   // mt.fo.un_320 mi.mg.uz_432  so.sg.sn_544 mi.da.to_543 
  0x37304b0c, 0x5c0449a4, 0x463435ee, 0x794573ad,   // mi.uz.st_543 to.fi.sa_433  zu.xh.qu_422 ny.ln.war_643 
  0x02564ba0, 0x4d455b0c, 0x234418ad, 0x235e3bac,   // mi.mg.da_322 sg.ln.aa_543  ar.kk.ky_643 so.ts.ca_632 
  0x59295ea4, 0x302f40ad, 0x68002112, 0x1e781ca4,   // ts.sl.rn_433 lb.su.uz_643  jw.ig.un_640 id.ve.ms_433 
  // [1e550]
  0x4956300c, 0x23133607, 0x30001f0d, 0x734745a9,   // uz.mg.to_543 gn.et.ca_432  cy.uz.un_540 ln.sn.ny_544 
  0x651d3f0c, 0x5efe4da7, 0x5600300e, 0x20366804,   // af.la.gv_543 aa.tlh.ts_532  uz.mg.un_550 ig.gn.sq_332 
  0x02002804, 0xfc2343ee, 0x4a565c04, 0x15150455,   // sw.da.un_320 ie.ca.zzp_422  sa.mg.yo_332 ru.un.un_420 
  0x6a492914, 0x30005612, 0x06674d0c, 0x4d495608,   // sl.to.haw_666 mg.uz.un_640  aa.ak.de_543 mg.to.aa_443 
  // [1e560]
  0x3400570c, 0x644c21a4, 0x5c004613, 0x64450204,   // na.xh.un_530 jw.wo.lg_433  qu.sa.un_650 da.ln.lg_332 
  0x46791aa4, 0x26230a08, 0x0f2d12a0, 0x301b29a4,   // tl.war.qu_433 pt.ca.ia_443  hu.sk.lv_322 sl.tr.uz_433 
  0x03132c55, 0x355528ee, 0x3d183c0c, 0x5c00290c,   // fy.et.nl_442 sw.rw.zu_422  ug.ar.ku_543 sl.sa.un_530 
  0x09004604, 0x130426a7, 0x47000207, 0x301821a4,   // qu.pl.un_320 ia.fi.et_532  da.sn.un_420 fa.ar.uz_433 
  // [1e570]
  0x095c1cac, 0x48383114, 0x28005e02, 0x3576690c,   // mr.sa.hi_632 az.tk.tt_666  ts.sw.un_220 mfe.crs.zu_543 
  0x392f0408, 0x79420755, 0x2a420705, 0x0d2f02a0,   // fi.su.br_443 it.co.war_442  it.co.mt_333 da.su.cs_322 
  0x33002508, 0x38002322, 0x3c351508, 0x172412a9,   // eu.nn.un_430 ky.tk.un_870  un.tg.ug_443 hu.eo.sr_544 
  0x11001b11, 0x122e380b, 0x2e090e07, 0x3217120c,   // tr.ro.un_630 tk.fo.hu_542  is.pl.fo_432 hu.sr.bs_543 
  // [1e580]
  0x17293807, 0x122038ac, 0x04483007, 0x080a30af,   // tk.sl.sr_432 tk.sq.hu_632  uz.tt.ru_432 uz.mk.uk_655 
  0x161238ad, 0x15443813, 0x1200380c, 0x0a231513,   // tk.hu.hr_643 tk.kk.un_665  tk.hu.un_530 un.ky.mk_665 
  0x254546ad, 0x30481702, 0x34002502, 0x0900fe21,   // qu.ln.eu_643 sr.tt.uz_222  eu.xh.un_220 tlh.pl.un_860 
  0x09002d22, 0xfe202daf, 0x2d001e13, 0x1b006011,   // sk.pl.un_870 sk.sq.tlh_655  ms.sk.un_650 vo.tr.un_630 
  // [1e590]
  0x06042fa0, 0x30312504, 0x400608a7, 0x20003004,   // su.fi.de_322 eu.az.uz_332  no.de.lb_532 uz.sq.un_320 
  0x18470604, 0x2961feec, 0x292d0909, 0x03006004,   // de.sn.ga_332 tlh.za.sl_644  pl.sk.sl_444 vo.nl.un_320 
  0x09002105, 0x06001f18, 0x1629090c, 0x23040805,   // jw.pl.un_330 cy.de.un_740  pl.sl.hr_543 uk.ru.ky_333 
  0x5c002008, 0x02002d21, 0x58240f0c, 0x5800350d,   // sq.sa.un_430 sk.da.un_860  lv.eo.om_543 zu.om.un_540 
  // [1e5a0]
  0x4f6e1e0b, 0x2458500c, 0x5000590e, 0x4600200b,   // ms.hmn.bi_542 fj.om.eo_543  rn.fj.un_550 sq.qu.un_520 
  0x0f587812, 0x13513bec, 0x060348a7, 0x3b4d51ec,   // ve.om.lv_654 so.kl.et_644  tt.nl.de_532 kl.aa.so_644 
  0x0f00280c, 0x04030604, 0x2d001b0c, 0x511358a9,   // sw.lv.un_530 de.nl.fi_332  tr.sk.un_530 om.et.kl_544 
  0x73583708, 0x3400570d, 0x063f02a0, 0x584003a4,   // st.om.ny_443 na.xh.un_540  da.af.de_322 nl.lb.om_433 
  // [1e5b0]
  0x1c2f5c02, 0x1c621e0c, 0x283b5105, 0x584d3b09,   // sa.su.id_222 ms.kha.id_543  kl.so.sw_333 so.aa.om_444 
  0x50550f07, 0x1b216905, 0x643b400c, 0x4d583baf,   // lv.rw.fj_432 mfe.jw.tr_333  lb.so.lg_543 so.om.aa_655 
  0x1a461ba4, 0x4d3b64a9, 0x1d314cee, 0x02004a13,   // tr.qu.tl_433 lg.so.aa_544  wo.az.la_422 yo.da.un_650 
  0x5159550d, 0x0800250e, 0x64583b0c, 0x511b0407,   // rw.rn.kl_554 mn.uk.un_550  so.om.lg_543 fi.tr.kl_432 
  // [1e5c0]
  0x3446355a, 0x1e006212, 0x04583b0c, 0x3f5103a4,   // zu.qu.xh_553 kha.ms.un_640  so.om.fi_543 nl.kl.af_433 
  0x51583bad, 0x044a350c, 0x6b0665a0, 0x10083702,   // so.om.kl_643 zu.yo.fi_543  gv.de.ceb_322 ba.uk.be_222 
  0x633b310c, 0x30153c08, 0x5a477307, 0x04153511,   // az.so.sco_543 ug.uz.un_430  ny.sn.sm_432 tg.ru.un_630 
  0x63614c12, 0x213b310b, 0x4c3b01a4, 0x44254804,   // wo.za.sco_654 az.so.jw_542  en.so.wo_433 tt.mn.kk_332 
  // [1e5d0]
  0x28123c05, 0x3b0a1907, 0xfc001c04, 0x043e11a0,   // ug.ur.sd_333 gl.pt.so_432  id.zzp.un_320 ro.rm.fi_322 
  0x2057fca7, 0x213c2302, 0x04133912, 0x25005a02,   // zzp.na.sq_532 ky.ug.fa_222  br.et.fi_654 sm.eu.un_220 
  0x163942ee, 0xfe48110c, 0x2d000604, 0x3f2c0eee,   // co.br.hr_422 ro.tt.tlh_543  de.sk.un_320 is.fy.af_422 
  0x1512060d, 0x35340cec, 0xfc345dee, 0x6e005205,   // de.hu.un_554 sv.xh.zu_644  ss.xh.zzp_422 ha.hmn.un_330 
  // [1e5e0]
  0x52002204, 0x3b3f02a4, 0x21004b07, 0x0a003402,   // oc.ha.un_320 da.af.so_433  mi.jw.un_420 xh.pt.un_220 
  0x1c00380c, 0x4006070c, 0x0301fc04, 0x35345802,   // tk.id.un_530 it.de.lb_543  zzp.en.nl_332 om.xh.zu_222 
  0x58122c0c, 0x11383c12, 0x3d301207, 0x2535150c,   // fy.hu.om_543 ug.tk.ro_654  ur.uz.ku_432 un.tg.mn_543 
  0x18443c12, 0x192d12ee, 0x3036100c, 0x3c374409,   // ug.kk.ar_654 hu.sk.gl_422  be.ab.uz_543 kk.ba.ug_444 
  // [1e5f0]
  0x1a000107, 0x020146a0, 0x44303c0d, 0x44373cec,   // en.tl.un_420 qu.en.da_322  ug.uz.kk_554 ug.ba.kk_644 
  0x17290d0c, 0x07082505, 0x3b3058a4, 0x1d1627a0,   // cs.sl.sr_543 mn.uk.bg_333  om.uz.so_433 gd.hr.la_322 
  0x6b4a30a4, 0x3c3530a7, 0x1e036ba0, 0x482d0d05,   // uz.yo.ceb_433 uz.tg.ug_532  ceb.nl.ms_322 cs.sk.tt_333 
  0x5c321711, 0x64000f04, 0x794a6b0c, 0x38000410,   // sr.bs.sa_653 lv.lg.un_320  ceb.yo.war_543 fi.tk.un_620 
  // [1e600]
  0x1a3764ee, 0x584c6408, 0x070a10ee, 0x10373804,   // lg.st.tl_422 lg.wo.om_443  be.mk.bg_422 tk.ba.be_332 
  0x300817a7, 0x242d0d05, 0x01024dee, 0x1708440d,   // sr.uk.uz_532 cs.sk.eo_333  aa.da.en_422 kk.uk.sr_554 
  0x281230a7, 0x25244d07, 0x3b396a11, 0x04283904,   // uz.ur.sd_532 aa.eo.eu_432  haw.br.so_653 br.sw.fi_332 
  0x08173502, 0x130439ad, 0x13002b04, 0x5c006508,   // tg.sr.uk_222 br.fi.et_643  vi.et.un_320 gv.sa.un_430 
  // [1e610]
  0x3c00071a, 0x283c3b07, 0x65002b08, 0x56043904,   // bg.ug.un_760 ks.ug.sd_432  vi.gv.un_430 br.fi.mg_332 
  0x4253070d, 0x02005718, 0x1a5273a0, 0x52504a55,   // it.ht.co_554 na.da.un_740  ny.ha.tl_322 yo.fj.ha_442 
  0x5c024705, 0x3b4d31ec, 0x2a2c4e07, 0x653308a4,   // sn.da.sa_333 az.aa.so_644  ay.fy.mt_432 no.nn.gv_433 
  0x48307604, 0x214d1ca0, 0x1c004704, 0x42050711,   // crs.uz.tt_332 id.aa.jw_322  sn.id.un_320 it.fr.co_653 
  // [1e620]
  0x5955560c, 0x2c2113ad, 0x6b1a6a0e, 0xfe345d0c,   // mg.rw.rn_543 et.jw.fy_643  haw.tl.ceb_555 ss.xh.tlh_543 
  0x310976a4, 0x13521ca0, 0x49004b23, 0x510a1311,   // crs.pl.az_433 id.ha.et_322  mi.to.un_880 et.pt.kl_653 
  0xfe0c3304, 0x6b6a49ac, 0x0dfe0912, 0x4a4750a0,   // nn.sv.tlh_332 to.haw.ceb_632  pl.tlh.cs_654 fj.sn.yo_322 
  0x6b493504, 0x25796ba9, 0x49254b55, 0x052f21a9,   // zu.to.ceb_332 ceb.war.eu_544  mi.eu.to_442 jw.su.fr_544 
  // [1e630]
  0x043f4fa0, 0x1a004704, 0x36376aa0, 0x00006a37,   // bi.af.fi_322 sn.tl.un_320  haw.st.gn_322 haw.un.un_B00 
  0x131c21ee, 0x311b0505, 0x644a3408, 0x02005414,   // jw.id.et_422 fr.tr.az_333  xh.yo.lg_443 ik.da.un_660 
  0x5600521b, 0x42003b12, 0x3100490d, 0x0f626908,   // ha.mg.un_770 so.co.un_640  to.az.un_540 mfe.kha.lv_443 
  0x4a645aa0, 0x033f29af, 0x3b004907, 0x3b59550c,   // sm.lg.yo_322 sl.af.nl_655  to.so.un_420 rw.rn.so_543 
  // [1e640]
  0x52283b07, 0x345d135a, 0x13fe2cee, 0x48524c55,   // so.sw.ha_432 et.ss.xh_553  fy.tlh.et_422 wo.ha.tt_442 
  0x030f2cee, 0x3e002a07, 0x6a6b1a0c, 0x05000722,   // fy.lv.nl_422 mt.rm.un_420  tl.ceb.haw_543 it.fr.un_870 
  0x79312107, 0x0f190b11, 0x67381b0c, 0x403e18a6,   // jw.az.war_432 es.gl.lv_653  tr.tk.ak_543 ga.rm.lb_521 
  0x483176a4, 0x04315609, 0x3125fe05, 0x5c051305,   // crs.az.tt_433 mg.az.fi_444  tlh.eu.az_333 et.fr.sa_333 
  // [1e650]
  0x286a2112, 0x6a004b23, 0x36041060, 0x1b3176a0,   // jw.haw.sw_654 mi.haw.un_880  be.ru.ab_664 crs.az.tr_322 
  0x170833ee, 0x21284b0c, 0x45430555, 0x1e1c79a0,   // nn.no.sr_422 mi.sw.jw_543  fr.ie.ln_442 war.id.ms_322 
  0x29003b07, 0x03251bee, 0x4700452c, 0x5a492107,   // so.sl.un_420 tr.eu.nl_422  ln.sn.un_990 jw.to.sm_432 
  0x671e73a9, 0x1e1a2f04, 0x625c4d0e, 0x2a00640b,   // ny.ms.ak_544 su.tl.ms_332  aa.sa.kha_555 lg.mt.un_520 
  // [1e660]
  0x5e5d64a0, 0x00006b01, 0x350a07ee, 0x2f282a02,   // lg.ss.ts_322 ceb.un.un_200  bg.mk.tg_422 mt.sw.su_222 
  0x30370802, 0x05004c1a, 0x5cfe4d07, 0x1a383fa0,   // uk.ba.uz_222 wo.fr.un_760  aa.tlh.sa_432 af.tk.tl_322 
  0x2953fe0c, 0x0a002c0c, 0x3d002320, 0x303536a0,   // tlh.ht.sl_543 fy.pt.un_530  ky.ku.un_850 ab.tg.uz_322 
  0x212b7855, 0x78004722, 0x2b2867a4, 0x2f420507,   // ve.vi.jw_442 sn.ve.un_870  ak.sw.vi_433 fr.co.su_432 
  // [1e670]
  0x350430ee, 0x154223a0, 0x37351002, 0x15002f12,   // uz.ru.tg_422 ca.co.un_322  be.tg.ba_222 su.un.un_640 
  0x5d003411, 0x3b074da6, 0x05274207, 0x36005d08,   // xh.ss.un_630 aa.it.so_521  co.gd.fr_432 ss.gn.un_430 
  0x0b004507, 0x22360ba0, 0x0a112308, 0x23003104,   // ln.es.un_420 es.gn.oc_322  ky.ro.mk_443 az.ca.un_320 
  0x4404380c, 0x2d000f1a, 0x30083c09, 0x4d00050b,   // tk.ru.kk_543 lv.sk.un_760  ug.uk.uz_444 fr.aa.un_520 
  // [1e680]
  0x082310ee, 0x0438200b, 0x374811a6, 0x6e6b1dee,   // be.ky.uk_422 sq.tk.fi_542  ro.tt.ba_521 la.ceb.hmn_422 
  0x030240a4, 0x09103202, 0x10fc0f12, 0x484d60a7,   // lb.da.nl_433 bs.lt.pl_222  lv.zzp.lt_654 vo.aa.tt_532 
  0x09100f0c, 0x5d005e2b, 0x5b001b14, 0x5f003904,   // lv.lt.pl_543 ts.ss.un_980  tr.sg.un_660 br.tn.un_320 
  0x730f47a4, 0x32004702, 0x5f63370c, 0x4c000508,   // sn.lv.ny_433 sn.bs.un_220  st.sco.tn_543 fr.wo.un_430 
  // [1e690]
  0x2d003805, 0x320f090b, 0x0648570c, 0x09004705,   // tk.sk.un_330 pl.lv.bs_542  na.tt.de_543 sn.pl.un_330 
  0x182847ee, 0x1b365bac, 0x4b485b0c, 0x12003e12,   // sn.sw.ga_422 sg.gn.tr_632  sg.tt.mi_543 rm.hu.un_640 
  0x2100280b, 0x47100f05, 0x0f000921, 0x5f37180c,   // sw.jw.un_520 lv.lt.sn_333  pl.lv.un_860 ga.st.tn_543 
  0x5b006719, 0x04001f18, 0x284f180c, 0x63014307,   // ak.sg.un_750 cy.fi.un_740  ga.bi.sw_543 ie.en.sco_432 
  // [1e6a0]
  0x0c2f6304, 0x2f00250c, 0x08020605, 0x52001514,   // sco.su.sv_332 eu.su.un_530  de.da.no_333 un.ha.un_660 
  0xfc354007, 0x2d0d2cac, 0x30005502, 0x49001321,   // lb.zu.zzp_432 fy.cs.sk_632  rw.uz.un_220 et.to.un_860 
  0x47001307, 0x122c1304, 0x1e1c2f04, 0x6354250c,   // et.sn.un_420 et.fy.hu_332  su.id.ms_332 eu.ik.sco_543 
  0x4a0d2d07, 0x062e3505, 0x01004002, 0x396a0d55,   // sk.cs.yo_432 zu.fo.de_333  lb.en.un_220 cs.haw.br_442 
  // [1e6b0]
  0x60530da9, 0x0d0563a4, 0x1d002107, 0x0c2c3f02,   // cs.ht.vo_544 sco.fr.cs_433  jw.la.un_420 af.fy.sv_222 
  0xfe05010b, 0x043f0d07, 0x070547ad, 0x2b6b1dee,   // en.fr.tlh_542 cs.af.fi_432  sn.fr.it_643 la.ceb.vi_422 
  0x19760a0c, 0x53050da4, 0x4b63490c, 0x214c2fa7,   // pt.crs.gl_543 cs.fr.ht_433  to.sco.mi_543 su.wo.jw_532 
  0x212f1213, 0x12002f1b, 0x1b091304, 0x21122f55,   // hu.su.jw_665 su.hu.un_770  et.pl.tr_332 su.hu.jw_442 
  // [1e6c0]
  0x42530dad, 0x2f00121a, 0x0a173c04, 0x34311ba0,   // cs.ht.co_643 hu.su.un_760  ug.sr.mk_332 tr.az.xh_322 
  0x1b043ea4, 0x2335360b, 0x5d1b5e13, 0x10001305,   // rm.fi.tr_433 ab.tg.ky_542  ts.tr.ss_665 et.lt.un_330 
  0x35005e08, 0x34006914, 0x0b191211, 0x232f120c,   // ts.zu.un_430 mfe.xh.un_660  hu.gl.es_653 hu.su.ca_543 
  0x12192f14, 0x1310390c, 0x2c4639a4, 0x3200110c,   // su.gl.hu_666 br.lt.et_543  br.qu.fy_433 ro.bs.un_530 
  // [1e6d0]
  0x2f1e21a4, 0x34005e02, 0x34002709, 0x06131dee,   // jw.ms.su_433 ts.xh.un_220  gd.xh.un_440 la.et.de_422 
  0x0e0302a4, 0x5d355ca4, 0x791a3fa4, 0x31001213,   // da.nl.is_433 sa.zu.ss_433  af.tl.war_433 hu.az.un_650 
  0x1c1e4d04, 0x1715380b, 0x0a21690c, 0x07003520,   // aa.ms.id_332 tk.sr.un_520  mfe.jw.pt_543 tg.bg.un_850 
  0x361a02a0, 0x3b023faf, 0x443836a7, 0x51020e04,   // da.tl.gn_322 af.da.so_655  ab.tk.kk_532 is.da.kl_332 
  // [1e6e0]
  0x2f211c09, 0x3f000221, 0x634d02a4, 0x1a000204,   // id.jw.su_444 da.af.un_860  da.aa.sco_433 da.tl.un_320 
  0x47005602, 0x79006b21, 0x0a00072a, 0x5506520c,   // mg.sn.un_220 ceb.war.un_860  bg.mk.un_970 ha.de.rw_543 
  0x302338ad, 0x2f022107, 0x52000605, 0x30350702,   // tk.ky.uz_643 jw.da.su_432  de.ha.un_330 bg.tg.uz_222 
  0x213b3012, 0x17233655, 0x44374809, 0x480415a9,   // uz.ks.fa_654 ab.ky.sr_442  tt.ba.kk_444 un.ru.tt_544 
  // [1e6f0]
  0x28397608, 0x46004807, 0x1e254604, 0x0e4e255a,   // crs.br.sw_443 tt.qu.un_420  qu.eu.ms_332 eu.ay.is_553 
  0x30000214, 0x0e1e4ea4, 0x301f42a4, 0x113e5605,   // da.uz.un_660 ay.ms.is_433  co.cy.uz_433 mg.rm.ro_333 
  0x393512ad, 0x4628300d, 0x165d3507, 0x50000219,   // hu.zu.br_643 uz.sw.qu_554  zu.ss.hr_432 da.fj.un_750 
  0x1c0e2f02, 0x470165a0, 0x354207a4, 0x464e3012,   // su.is.id_222 gv.en.sn_322  it.co.zu_433 uz.ay.qu_654 
  // [1e700]
  0x033564a4, 0x42005204, 0x342535a4, 0x423e07ad,   // lg.zu.nl_433 ha.co.un_320  zu.eu.xh_433 it.rm.co_643 
  0x40122f08, 0x42685807, 0x42070214, 0x1b5c4e07,   // su.hu.lb_443 om.ig.co_432  da.it.co_666 ay.sa.tr_432 
  0x09353408, 0x34613508, 0x2e0e4e0c, 0x245311ee,   // xh.zu.pl_443 zu.za.xh_443  ay.is.fo_543 ro.ht.eo_422 
  0x3925550d, 0x3b464ead, 0x110625a7, 0x4e7330a4,   // rw.eu.br_554 ay.qu.so_643  eu.de.ro_532 uz.ny.ay_433 
  // [1e710]
  0x21592f09, 0x30420708, 0x07423eaf, 0x02004e0e,   // su.rn.jw_444 it.co.uz_443  rm.co.it_655 ay.da.un_550 
  0x4e00301a, 0x16003607, 0x2e0c0214, 0x030c060c,   // uz.ay.un_760 gn.hr.un_420  da.sv.fo_666 de.sv.nl_543 
  0x06253602, 0x06020c0c, 0x0c0e0208, 0x2f4c2102,   // gn.eu.de_222 sv.da.de_543  da.is.sv_443 jw.wo.su_222 
  0x2d5c0d0c, 0x26131da4, 0x020c0660, 0x02000c1a,   // cs.sa.sk_543 la.et.ia_433  de.sv.da_664 sv.da.un_760 
  // [1e720]
  0x36154807, 0x362f2112, 0x2f0d1208, 0x1100230d,   // tt.ab.un_420 jw.su.gn_654  hu.cs.su_443 ca.ro.un_540 
  0x20033f07, 0x214c12ad, 0x290f2dad, 0x46fe240c,   // af.nl.sq_432 hu.wo.jw_643  sk.lv.sl_643 eo.tlh.qu_543 
  0xfe3924ec, 0x0700fc0c, 0x53fe24ac, 0xfe006e35,   // eo.br.tlh_644 zzp.it.un_530  eo.tlh.ht_632 hmn.tlh.un_A90 
  0x092429af, 0x2429fe0c, 0x37003512, 0x01fc33a0,   // sl.eo.pl_655 tlh.sl.eo_543  tg.ba.un_640 nn.zzp.en_322 
  // [1e730]
  0x1e006508, 0x532024a7, 0x112924a7, 0x0300fc21,   // gv.ms.un_430 eo.sq.ht_532  eo.sl.ro_532 zzp.nl.un_860 
  0x33460e04, 0x1e6b5107, 0x3534670c, 0xfc1273a0,   // is.qu.nn_332 kl.ceb.ms_432  ak.xh.zu_543 ny.hu.zzp_322 
  0x35344605, 0x0c480e02, 0x24292d0c, 0x61fe5308,   // qu.xh.zu_333 is.tt.sv_222  sk.sl.eo_543 ht.tlh.za_443 
  0x1b55590c, 0x175324ad, 0x391e1c0c, 0x2f0d120c,   // rn.rw.tr_543 eo.ht.sr_643  id.ms.br_543 hu.cs.su_543 
  // [1e740]
  0x094624ec, 0x2f5e1c0c, 0x1629240d, 0x24462913,   // eo.qu.pl_644 id.ts.su_543  eo.sl.hr_554 sl.qu.eo_665 
  0x30024714, 0x466268ec, 0x4c453b07, 0x1a003408,   // sn.da.uz_666 ig.kha.qu_644  so.ln.wo_432 xh.tl.un_430 
  0x644765a9, 0x1130685a, 0x67622160, 0x553559ee,   // gv.sn.lg_544 ig.uz.ro_553  jw.kha.ak_664 rn.zu.rw_422 
  0x685a51ee, 0x687328ad, 0x12353407, 0x510f40a0,   // kl.sm.ig_422 sw.ny.ig_643  xh.zu.hu_432 lb.lv.kl_322 
  // [1e750]
  0xfe000f0c, 0x46734712, 0x1e002902, 0x30353755,   // lv.tlh.un_530 sn.ny.qu_654  sl.ms.un_220 ba.tg.uz_442 
  0x4711680d, 0x217836ec, 0x45431e0c, 0x1a005c1b,   // ig.ro.sn_554 gn.ve.jw_644  ms.ie.ln_543 sa.tl.un_770 
  0x451e1c11, 0xfe354d60, 0x1347fe04, 0x3000fc08,   // id.ms.ln_653 aa.zu.tlh_664  tlh.sn.et_332 zzp.uz.un_430 
  0x475d45a4, 0x21003613, 0x174823ad, 0x4539730b,   // ln.ss.sn_433 gn.jw.un_650  ky.tt.sr_643 ny.br.ln_542 
  // [1e760]
  0xfa005d09, 0x3802470c, 0x2f384dee, 0x24464308,   // ss.nr.un_440 sn.da.tk_543  aa.tk.su_422 ie.qu.eo_443 
  0x5d005612, 0x15071009, 0x353449af, 0x28184408,   // mg.ss.un_640 be.bg.un_444  to.xh.zu_655 kk.ar.sd_443 
  0x3d18300c, 0x2a1518a9, 0x483735a4, 0x172d290e,   // uz.ar.ku_543 ga.mt.un_540  tg.ba.tt_433 sl.sk.sr_555 
  0x1d00230c, 0x321713ee, 0x2f1221a4, 0x5d21780b,   // ca.la.un_530 et.sr.bs_422  jw.hu.su_433 ve.jw.ss_542 
  // [1e770]
  0x695534ec, 0x212f1255, 0x1c5302ad, 0x09482da0,   // xh.rw.mfe_644 hu.su.jw_442  da.ht.id_643 sk.tt.pl_322 
  0x09003909, 0x1e0413a4, 0x5d5f370d, 0x215637ee,   // br.pl.un_440 et.fi.ms_433  st.tn.ss_554 st.mg.jw_422 
  0x50454aa4, 0x63002309, 0x5955470d, 0x5c1a0207,   // yo.ln.fj_433 ca.sco.un_440  sn.rw.rn_554 da.tl.sa_432 
  0x10170405, 0x5f190a04, 0x2c475507, 0x190b07a0,   // ru.sr.be_333 pt.gl.tn_332  rw.sn.fy_432 it.es.gl_322 
  // [1e780]
  0x4d001c13, 0x451a6b04, 0x1c7321a0, 0x5a6750a4,   // id.aa.un_650 ceb.tl.ln_332  jw.ny.id_322 fj.ak.sm_433 
  0x36734505, 0x2326450c, 0x3617100e, 0x523756ee,   // ln.ny.gn_333 ln.ia.ca_543  be.sr.ab_555 mg.st.ha_422 
  0x182812ec, 0x0a370704, 0x30041505, 0xfc5a4aee,   // ur.sd.ar_644 bg.ba.mk_332  un.ru.uz_333 yo.sm.zzp_422 
  0x150804a0, 0x0f004205, 0x33083ea4, 0x1c2f510c,   // ru.uk.un_322 co.lv.un_330  rm.no.nn_433 kl.su.id_543 
  // [1e790]
  0x21461eee, 0x52121307, 0x65152607, 0x1b3206a0,   // ms.qu.jw_422 et.hu.ha_432  ia.gv.un_420 de.bs.tr_322 
  0x0d1629a7, 0x59551305, 0x21560255, 0x451720ec,   // sl.hr.cs_532 et.rw.rn_333  da.mg.jw_442 sq.sr.ln_644 
  0x68023604, 0x5600360e, 0x3b00340b, 0x5900651a,   // gn.da.ig_332 gn.mg.un_550  xh.so.un_520 gv.rn.un_760 
  0x49002a04, 0x58001f0c, 0x2d007312, 0x527302ad,   // mt.to.un_320 cy.om.un_530  ny.sk.un_640 da.ny.ha_643 
  // [1e7a0]
  0x2515380c, 0x32000b05, 0x083c23a4, 0x37002908,   // tk.mn.un_530 es.bs.un_330  ky.ug.uk_433 sl.st.un_430 
  0xfe001309, 0x373b2a12, 0x050207a0, 0x597367a4,   // et.tlh.un_440 mt.so.st_654  it.da.fr_322 ak.ny.rn_433 
  0x644550a4, 0x2d0413ee, 0x611d2a08, 0x4b60060c,   // fj.ln.lg_433 et.fi.sk_422  mt.la.za_443 de.vo.mi_543 
  0x0e044b0d, 0x22002004, 0x79001c1a, 0x123b3413,   // mi.fi.is_554 sq.oc.un_320  id.war.un_760 ps.ks.ur_665 
  // [1e7b0]
  0x0f5a130c, 0x01114cad, 0x1d403e05, 0x5c221da0,   // et.sm.lv_543 wo.ro.en_643  rm.lb.la_333 la.oc.sa_322 
  0x56056004, 0x2b004c08, 0x5c330804, 0x60001d1a,   // vo.fr.mg_332 wo.vi.un_430  no.nn.sa_332 la.vo.un_760 
  0x233810ec, 0x0f004b19, 0x21222fa4, 0x6a3e1d0c,   // be.tk.ky_644 mi.lv.un_750  su.oc.jw_433 la.rm.haw_543 
  0x24126107, 0x48083c0c, 0x0f6e1004, 0x0f101dec,   // za.hu.eo_432 ug.uk.tt_543  lt.hmn.lv_332 la.lt.lv_644 
  // [1e7c0]
  0x5900fc0e, 0x24466e0c, 0x35000812, 0x391d1307,   // zzp.rn.un_550 hmn.qu.eo_543  uk.tg.un_640 et.la.br_432 
  0x47001b08, 0x3976690e, 0x0f106ea7, 0x39475304,   // tr.sn.un_430 mfe.crs.br_555  hmn.lt.lv_532 ht.sn.br_332 
  0x58131d55, 0x1a6b36af, 0x3b2728ee, 0x6e1d4308,   // la.et.om_442 gn.ceb.tl_655  sw.gd.so_422 ie.la.hmn_443 
  0xfc18650c, 0x5e345607, 0xfc001b05, 0x1d511307,   // gv.ga.zzp_543 mg.xh.ts_432  tr.zzp.un_330 et.kl.la_432 
  // [1e7d0]
  0x041d1504, 0x13101d09, 0x42323eee, 0x211d5c0c,   // un.la.fi_332 la.lt.et_444  rm.bs.co_422 sa.la.jw_543 
  0x13101da6, 0x36003708, 0x21005c02, 0x224755a4,   // la.lt.et_521 st.gn.un_430  sa.jw.un_220 rw.sn.oc_433 
  0x39697607, 0xfe000209, 0x05001102, 0x32393f04,   // crs.mfe.br_432 da.tlh.un_440  ro.fr.un_220 af.br.bs_332 
  0x16322004, 0x305c65a0, 0x64003014, 0x1a1e5cee,   // sq.bs.hr_332 gv.sa.uz_322  uz.lg.un_660 sa.ms.tl_422 
  // [1e7e0]
  0x5c001f12, 0x64005b19, 0x0e4a0b08, 0x5c1f4d04,   // cy.sa.un_640 sg.lg.un_750  es.yo.is_443 aa.cy.sa_332 
  0x12005302, 0x5c3064ad, 0x480708a0, 0x64000c04,   // ht.hu.un_220 lg.uz.sa_643  uk.bg.tt_322 sv.lg.un_320 
  0x465e3404, 0x3864fe0b, 0x65321602, 0x5c421fa7,   // xh.ts.qu_332 tlh.lg.tk_542  hr.bs.gv_222 cy.co.sa_532 
  0x35041514, 0x2c005c02, 0x1c30fea7, 0x2d0f2907,   // un.ru.tg_666 sa.fy.un_220  tlh.uz.id_532 sl.lv.sk_432 
  // [1e7f0]
  0x04000212, 0x13580414, 0x473b130c, 0x044d4004,   // da.fi.un_640 fi.om.et_666  et.so.sn_543 lb.aa.fi_332 
  0x6b00540d, 0x49513f0c, 0x4c4d58a7, 0x404c3b05,   // ik.ceb.un_540 af.kl.to_543  om.aa.wo_532 so.wo.lb_333 
  0x043b4007, 0x40240605, 0x673b4aaf, 0x181263a0,   // lb.so.fi_432 de.eo.lb_333  yo.so.ak_655 sco.hu.ga_322 
  0x1b170907, 0x1b21fea0, 0x3b044dec, 0x1b303baf,   // pl.sr.tr_432 tlh.jw.tr_322  aa.fi.so_644 so.uz.tr_655 
  
  // [1e800]
  0x045113af, 0x1000441b, 0x68041304, 0x343d2305,   // et.kl.fi_655 kk.be.un_770  et.fi.ig_332 ky.ku.ps_333 
  0x045a5104, 0x053efe08, 0x1542010c, 0x123c2104,   // kl.sm.fi_332 tlh.rm.fr_443  en.co.un_543 fa.ug.ur_332 
  0x3815350c, 0x3500110e, 0x12302114, 0x1c000d21,   // tg.tk.un_530 ro.tg.un_550  fa.uz.ur_666 ne.mr.un_860 
  0x1b222fa0, 0x3e006035, 0x1800441b, 0x08001f0e,   // su.oc.tr_322 vo.rm.un_A90  kk.ar.un_770 cy.no.un_550 
  // [1e810]
  0x2c003507, 0x2c006b04, 0x5400040e, 0x35340eec,   // zu.fy.un_420 ceb.fy.un_320  fi.ik.un_550 is.xh.zu_644 
  0x3e064fa7, 0x6b2a2e55, 0x330c1f02, 0x020e2e60,   // bi.de.rm_532 fo.mt.ceb_442  cy.sv.nn_222 fo.is.da_664 
  0x791a6b07, 0x130e0cad, 0x51585a07, 0x230b22ee,   // ceb.tl.war_432 sv.is.et_643  sm.om.kl_432 oc.es.ca_422 
  0x482310ec, 0x0d172904, 0x291d430b, 0x1107300c,   // be.ky.tt_644 sl.sr.cs_332  ie.la.sl_542 uz.it.ro_543 
  // [1e820]
  0x115c3eaf, 0x6b004f09, 0xfc00381b, 0x3b580412,   // rm.sa.ro_655 bi.ceb.un_440  tk.zzp.un_770 fi.om.so_654 
  0x0a080409, 0x041d58a0, 0x581d3fa4, 0xfc006421,   // ru.uk.mk_444 om.la.fi_322  af.la.om_433 lg.zzp.un_860 
  0x04025804, 0x20532804, 0x03250aee, 0x3b1304a0,   // om.da.fi_332 sw.ht.sq_332  pt.eu.nl_422 fi.et.so_322 
  0x300a6204, 0x475761ec, 0x03005805, 0x391d3609,   // kha.pt.uz_332 za.na.sn_644  om.nl.un_330 gn.la.br_444 
  // [1e830]
  0xfc00fe0c, 0x130f58a4, 0x5e355d09, 0x51640455,   // tlh.zzp.un_530 om.lv.et_433  ss.zu.ts_444 fi.lg.kl_442 
  0x3bfc6307, 0x5000570b, 0x4f642ea7, 0x3b007907,   // sco.zzp.so_432 na.fj.un_520  fo.lg.bi_532 war.so.un_420 
  0x1e1c0414, 0x483e26a0, 0x343b370c, 0x5e353409,   // fi.id.ms_666 ia.rm.tt_322  st.so.xh_543 xh.zu.ts_444 
  0x4a255612, 0x4c514d07, 0x32556404, 0x202d0d0d,   // mg.eu.yo_654 aa.kl.wo_432  lg.rw.bs_332 cs.sk.sq_554 
  // [1e840]
  0x371b4704, 0x47026555, 0x583b04ad, 0x375d35af,   // sn.tr.st_332 gv.da.sn_442  fi.so.om_643 zu.ss.st_655 
  0x37003423, 0x1d5c56ec, 0x070a34ec, 0x55475907,   // xh.st.un_880 mg.sa.la_644  xh.pt.it_644 rn.sn.rw_432 
  0x492a5612, 0x4c034da6, 0x3447670c, 0x5d473408,   // mg.mt.to_654 aa.nl.wo_521  ak.sn.xh_543 xh.sn.ss_443 
  0x55073e07, 0x35005e21, 0x3e5e5a14, 0x79075e5a,   // rm.it.rw_432 ts.zu.un_860  sm.ts.rm_666 ts.it.war_553 
  // [1e850]
  0x5f5d5ea9, 0x5e5f5a14, 0x4b00390e, 0x37355ea4,   // ts.ss.tn_544 sm.tn.ts_666  br.mi.un_550 ts.zu.st_433 
  0x3f000209, 0x645f3712, 0x1d560107, 0x3f004d04,   // da.af.un_440 st.tn.lg_654  en.mg.la_432 aa.af.un_320 
  0x384b6a04, 0x08033f08, 0x564913af, 0x132c3fee,   // haw.mi.tk_332 af.nl.no_443  et.to.mg_655 af.fy.et_422 
  0x25362307, 0x122e0e5a, 0x170815ee, 0x6b3568ee,   // ky.ab.mn_432 is.fo.hu_553  un.uk.sr_422 ig.zu.ceb_422 
  // [1e860]
  0x69330808, 0x186315ad, 0x13001009, 0x5c001007,   // no.nn.mfe_443 un.sco.ga_643  lt.et.un_440 lt.sa.un_420 
  0x351568ec, 0x0f1f1307, 0x132f4fee, 0x21051da0,   // ig.zu.un_640 et.cy.lv_432  bi.su.et_422 la.fr.jw_322 
  0x4cfe10ee, 0x69003113, 0x100f3e02, 0x34553511,   // lt.tlh.wo_422 az.mfe.un_650  rm.lv.lt_222 zu.rw.xh_653 
  0x457355a9, 0x4a5a5609, 0x391d1304, 0x45735507,   // rw.ny.ln_544 mg.sm.yo_444  et.la.br_332 rw.ny.ln_432 
  // [1e870]
  0x05500404, 0x20003405, 0x04570207, 0x0d4bfca7,   // fi.fj.fr_332 xh.sq.un_330  da.na.fi_432 zzp.mi.cs_532 
  0x0a000512, 0x122e1802, 0xfc1505a0, 0x035a0204,   // fr.pt.un_640 ga.fo.hu_222  fr.zzp.un_320 da.sm.nl_332 
  0x46536904, 0x103715ee, 0x5f3b76a4, 0x0c0515a4,   // mfe.ht.qu_332 un.ba.be_422  crs.so.tn_433 un.fr.sv_433 
  0x55381ba4, 0x39035304, 0x4715010b, 0x1f381005,   // tr.tk.rw_433 ht.nl.br_332  en.sn.un_520 lt.tk.cy_333 
  // [1e880]
  0x25154e07, 0x02690404, 0x05180208, 0x1500471a,   // ay.eu.un_420 fi.mfe.da_332  da.ga.fr_443 sn.un.un_760 
  0x644b49ee, 0x371504ec, 0x63360904, 0x081504a7,   // to.mi.lg_422 ru.ba.un_640  pl.gn.sco_332 ru.uk.un_520 
  0x234430a0, 0x102d0d0d, 0x1f0d2d11, 0x121f1002,   // uz.kk.ky_322 cs.sk.lt_554  sk.cs.cy_653 lt.cy.hu_222 
  0x372544a0, 0x02005a13, 0x283220a0, 0xfc001002,   // kk.mn.ba_322 sm.da.un_650  sq.bs.sw_322 lt.zzp.un_220 
  // [1e890]
  0x2573070c, 0x3942600b, 0x233738a9, 0x25646809,   // it.ny.eu_543 vo.co.br_542  tk.ba.ky_544 ig.lg.eu_444 
  0x12234455, 0x4200250d, 0x313e480e, 0x25073e0d,   // kk.ky.ur_442 eu.co.un_540  tt.rm.az_555 rm.it.eu_554 
  0x34423eec, 0xfc303ea0, 0x0e270c55, 0x25073e09,   // rm.co.xh_644 rm.uz.zzp_322  sv.gd.is_442 rm.it.eu_444 
  0x310f1b05, 0x4f211e07, 0x062e5f09, 0x38fc30af,   // tr.lv.az_333 ms.jw.bi_432  tn.fo.de_444 uz.zzp.tk_655 
  // [1e8a0]
  0x250361ec, 0x13002a09, 0x6e00200e, 0x393f0305,   // za.nl.eu_644 mt.et.un_440  sq.hmn.un_550 nl.af.br_333 
  0x34005f0c, 0x2e6273a7, 0x03532c04, 0x530c08a9,   // tn.xh.un_530 ny.kha.fo_532  fy.ht.nl_332 no.sv.ht_544 
  0x4363650d, 0x6b3f1d07, 0x30733507, 0x5356050c,   // gv.sco.ie_554 la.af.ceb_432  zu.ny.uz_432 fr.mg.ht_543 
  0x17123555, 0x690105ee, 0x57002a0e, 0x16291208,   // zu.hu.sr_442 fr.en.mfe_422  mt.na.un_550 hu.sl.hr_443 
  // [1e8b0]
  0x5376630c, 0x382e0ea7, 0x16290c07, 0x08002308,   // sco.crs.ht_543 is.fo.tk_532  sv.sl.hr_432 ky.uk.un_430 
  0x53033f08, 0x2348080d, 0x52fc45a0, 0x4e000c08,   // af.nl.ht_443 uk.tt.ky_554  ln.zzp.ha_322 sv.ay.un_430 
  0x303b64ec, 0x53004013, 0x03002505, 0x35345208,   // lg.so.uz_644 lb.ht.un_650  eu.nl.un_330 ha.xh.zu_443 
  0x4dfe640c, 0x5d201607, 0x5c023612, 0x6400521b,   // lg.tlh.aa_543 hr.sq.ss_432  gn.da.sa_654 ha.lg.un_770 
  // [1e8c0]
  0x5622120c, 0x05005335, 0x192959a9, 0x642f3b0c,   // hu.oc.mg_543 ht.fr.un_A90  rn.sl.gl_544 so.su.lg_543 
  0x633b5207, 0x0667fcaf, 0x300125ad, 0xfe6e2407,   // ha.so.sco_432 zzp.ak.de_655  eu.en.uz_643 eo.hmn.tlh_432 
  0x595575a9, 0xfc730513, 0x3b304da0, 0x3b7669af,   // nso.rw.rn_544 fr.ny.zzp_665  aa.uz.so_322 mfe.crs.so_655 
  0x4d3b6412, 0x1b460209, 0x5e645513, 0x3b4d64a7,   // lg.so.aa_654 da.qu.tr_444  rw.lg.ts_665 lg.aa.so_532 
  // [1e8d0]
  0x3008070d, 0x535e4507, 0x3b005c0e, 0x45643708,   // bg.uk.uz_554 ln.ts.ht_432  sa.so.un_550 st.lg.ln_443 
  0x64001220, 0x4000fe02, 0x0e4264ad, 0x303b64ad,   // hu.lg.un_850 tlh.lb.un_220  lg.co.is_643 lg.so.uz_643 
  0x1e1c02ee, 0x64005c0c, 0x24000b0d, 0x567922a4,   // da.id.ms_422 sa.lg.un_530  es.eo.un_540 oc.war.mg_433 
  0x40004209, 0x285c5908, 0x3f252208, 0x20001c04,   // co.lb.un_440 rn.sa.sw_443  oc.eu.af_443 id.sq.un_320 
  // [1e8e0]
  0x73502808, 0x3e001a0c, 0x60311baf, 0x443536a0,   // sw.fj.ny_443 tl.rm.un_530  tr.az.vo_655 ab.tg.kk_322 
  0x1000130d, 0x10131d12, 0x42005a04, 0x36004013,   // et.lt.un_540 la.et.lt_654  sm.co.un_320 lb.gn.un_650 
  0x1d600107, 0x581013a0, 0x1b3038a4, 0x08021305,   // en.vo.la_432 et.lt.om_322  tk.uz.tr_433 et.da.no_333 
  0x2b006b04, 0x10290d08, 0x1d106304, 0x31301b08,   // ceb.vi.un_320 cs.sl.lt_443  sco.lt.la_332 tr.uz.az_443 
  // [1e8f0]
  0x1b613055, 0x1f004307, 0x3e652404, 0x301b3155,   // uz.za.tr_442 ie.cy.un_420  eo.gv.rm_332 az.tr.uz_442 
  0x43004819, 0x11004414, 0x041b130c, 0x10001d09,   // tt.ie.un_750 kk.ro.un_660  et.tr.fi_543 la.lt.un_440 
  0x031e1d0c, 0x4e00fe0e, 0x43051d0c, 0x22131dee,   // la.ms.nl_543 tlh.ay.un_550  la.fr.ie_543 la.et.oc_422 
  0x25301b0c, 0x1b303114, 0x383020a4, 0x381b30a9,   // tr.uz.eu_543 az.uz.tr_666  sq.uz.tk_433 uz.tr.tk_544 
  // [1e900]
  0x4a001b09, 0x1c6301a0, 0x29650107, 0x0e003905,   // tr.yo.un_440 en.sco.id_322  en.gv.sl_432 br.is.un_330 
  0x2c0e40a0, 0x530f0509, 0x396364a0, 0x3d3421ec,   // lb.is.fy_322 fr.lv.ht_444  lg.sco.br_322 fa.ps.ku_644 
  0x65003922, 0x120f50af, 0x2d170d0c, 0x026047ec,   // br.gv.un_870 fj.lv.hu_655  cs.sr.sk_543 sn.vo.da_644 
  0x2c5a0aa0, 0x02130907, 0x5735340d, 0x695333a0,   // pt.sm.fy_322 pl.et.da_432  xh.zu.na_554 nn.ht.mfe_322 
  // [1e910]
  0x5c53fead, 0x02fe0207, 0x28533fee, 0x0d395ca0,   // tlh.ht.sa_643 da.tlh.da_432  af.ht.sw_422 sa.br.cs_322 
  0x13237904, 0x23153ba0, 0x0e04510c, 0x0d002d20,   // war.ca.et_332 so.ca.un_320  kl.fi.is_543 sk.cs.un_850 
  0x027930a4, 0x061513a0, 0x734a57ee, 0x242d0d0b,   // uz.war.da_433 et.de.un_320  na.yo.ny_422 cs.sk.eo_542 
  0x5e457305, 0x214a60ec, 0x0c4006a7, 0x04284e11,   // ny.ln.ts_333 vo.yo.jw_644  de.lb.sv_532 ay.sw.fi_653 
  // [1e920]
  0x6473470d, 0x5a2f1aa9, 0x3f4547a4, 0x601b11a9,   // sn.ny.lg_554 tl.su.sm_544  sn.ln.af_433 ro.tr.vo_544 
  0x15301fad, 0x344f5da9, 0x78685d05, 0x5e791a0c,   // cy.uz.un_643 ss.bi.xh_544  ss.ig.ve_333 tl.war.ts_543 
  0x182721a9, 0x20285c08, 0x37595514, 0x32200f08,   // jw.gd.ga_544 sa.sw.sq_443  rw.rn.st_666 lv.sq.bs_443 
  0x13550913, 0x5b06250c, 0x282a3555, 0x0400200d,   // pl.rw.et_665 eu.de.sg_543  zu.mt.sw_442 sq.fi.un_540 
  // [1e930]
  0x35002d04, 0x3e1c1eaf, 0x79461a0c, 0x231735a0,   // sk.zu.un_320 ms.id.rm_655  tl.qu.war_543 tg.sr.ky_322 
  0x28000213, 0x38025555, 0x552830ee, 0x041362a4,   // da.sw.un_650 rw.da.tk_442  uz.sw.rw_422 kha.et.fi_433 
  0x46202804, 0x3020340c, 0x56495502, 0x3f343607,   // sw.sq.qu_332 xh.sq.uz_543  rw.to.mg_222 gn.xh.af_432 
  0x10170a0c, 0x49565ca0, 0x183d210b, 0x34125d08,   // mk.sr.be_543 sa.mg.to_322  fa.ku.ar_542 ss.hu.xh_443 
  // [1e940]
  0x0c6a1f0b, 0x2f001309, 0x68330808, 0x305831ee,   // cy.haw.sv_542 et.su.un_440  no.nn.ig_443 az.om.uz_422 
  0x212f69a0, 0x5d3528a4, 0x2a001f12, 0x17250a0c,   // mfe.su.jw_322 sw.zu.ss_433  cy.mt.un_640 mk.mn.sr_543 
  0x56003605, 0x1d000d0d, 0x376562ee, 0x123f1aa0,   // gn.mg.un_330 cs.la.un_540  kha.gv.st_422 tl.af.hu_322 
  0x464753a4, 0x303848a0, 0x51005413, 0x1051505a,   // ht.sn.qu_433 tt.tk.uz_322  ik.kl.un_650 fj.kl.lt_553 
  // [1e950]
  0x2d735d11, 0x180f3ba0, 0x52595505, 0x31007304,   // ss.ny.sk_653 so.lv.ga_322  rw.rn.ha_333 ny.az.un_320 
  0x3f0e02a0, 0x045f75a9, 0x04285102, 0x2d002508,   // da.is.af_322 nso.tn.fi_544  kl.sw.fi_222 eu.sk.un_430 
  0x273b62ee, 0x30204302, 0x25420704, 0x51091055,   // kha.so.gd_422 ie.sq.uz_222  it.co.eu_332 lt.pl.kl_442 
  0x1007420b, 0x2d0d3009, 0x462d0d04, 0x0800231a,   // co.it.lt_542 uz.cs.sk_444  cs.sk.qu_332 ky.uk.un_760 
  // [1e960]
  0x0b2225ac, 0x34002908, 0x27006b07, 0x631d0204,   // eu.oc.es_632 sl.xh.un_430  ceb.gd.un_420 da.la.sco_332 
  0x796b1aec, 0x172d2404, 0x042751a4, 0x100451ec,   // tl.ceb.war_644 eo.sk.sr_332  kl.gd.fi_433 kl.fi.lt_644 
  0x42006513, 0x05001814, 0x3600620e, 0x091f360c,   // gv.co.un_650 ar.zh.un_660  kha.gn.un_550 gn.cy.pl_543 
  0x2d0d31ee, 0x4a0e2ba9, 0x12303d11, 0x040a4405,   // az.cs.sk_422 vi.is.yo_544  ku.uz.ur_653 kk.mk.ru_333 
  // [1e970]
  0x11430107, 0x371504a0, 0x28341205, 0x73474f55,   // en.ie.ro_432 ru.ba.un_320  ur.ps.sd_333 bi.sn.ny_442 
  0x483017a4, 0x1c5d4aa7, 0x10242eee, 0x02782705,   // sr.uz.tt_433 yo.ss.id_532  fo.eo.lt_422 gd.ve.da_333 
  0x1a0e24a0, 0x2807470d, 0x073017a4, 0x1d3e110c,   // eo.is.tl_322 sn.it.sw_554  sr.uz.bg_433 ro.rm.la_543 
  0x080233ed, 0x28522ca4, 0x05010c08, 0x2f2c3007,   // nn.da.no_622 fy.ha.sw_433  sv.en.fr_443 uz.fy.su_432 
  // [1e980]
  0x583752a4, 0x3e100f08, 0x522979ac, 0x08025107,   // ha.st.om_433 lv.lt.rm_443  war.sl.ha_632 kl.da.no_432 
  0x1b3160a9, 0x3e5b2805, 0x23002233, 0x31200eee,   // vo.az.tr_544 sw.sg.rm_333  oc.ca.un_A70 is.sq.az_422 
  0x192223af, 0x285250a4, 0x3b60fe08, 0x3b3e130d,   // ca.oc.gl_655 fj.ha.sw_433  tlh.vo.so_443 et.rm.so_554 
  0x0d4018a0, 0x0300350c, 0x304f730c, 0x58005208,   // ga.lb.cs_322 zu.nl.un_530  ny.bi.uz_543 ha.om.un_430 
  // [1e990]
  0x5c263b0c, 0x2f5e47ee, 0x10471307, 0x16735d0c,   // so.ia.sa_543 sn.ts.su_422  et.sn.lt_432 ss.ny.hr_543 
  0x59251c0c, 0x76190a13, 0x08043008, 0x33101fad,   // id.eu.rn_543 pt.gl.crs_665  uz.ru.uk_443 cy.lt.nn_643 
  0x6a00210c, 0x2f291ca0, 0x057601a0, 0x256b520c,   // jw.haw.un_530 id.sl.su_322  en.crs.fr_322 ha.ceb.eu_543 
  0x22052308, 0x2f004608, 0x013f63af, 0x3025730c,   // ca.fr.oc_443 qu.su.un_430  sco.af.en_655 ny.eu.uz_543 
  // [1e9a0]
  0x58005205, 0x4c5952a7, 0x2f131c11, 0x31004d1a,   // ha.om.un_330 ha.rn.wo_532  id.et.su_653 aa.az.un_760 
  0x0cfe330c, 0xfe092f08, 0x1c001e35, 0x2f004009,   // nn.tlh.sv_543 su.pl.tlh_443  ms.id.un_A90 lb.su.un_440 
  0x596a5555, 0x52004c08, 0x06000e22, 0x464c4ead,   // rw.haw.rn_442 wo.ha.un_430  is.de.un_870 ay.wo.qu_643 
  0x1a001e0d, 0x0f00400b, 0x40212fac, 0x2d2f3612,   // ms.tl.un_540 lb.lv.un_520  su.jw.lb_632 gn.su.sk_654 
  // [1e9b0]
  0x08300a13, 0x2e000222, 0x44003618, 0x25004405,   // mk.uz.uk_665 da.fo.un_870  ab.kk.un_740 kk.mn.un_330 
  0x23343d0e, 0x02002e2e, 0x04233007, 0x4000050e,   // ku.ps.ky_555 fo.da.un_A20  uz.ky.ru_432 fr.lb.un_550 
  0x40000f04, 0x1e1c63a4, 0x022e08ee, 0x0e002218,   // lv.lb.un_320 sco.id.ms_433  no.fo.da_422 oc.is.un_740 
  0x151548ee, 0x2d2f4c04, 0x1c110604, 0x5e431111,   // tt.un.un_420 wo.su.sk_332  de.ro.id_332 ro.ie.ts_653 
  // [1e9c0]
  0x303523a7, 0x6345050c, 0x3523300d, 0x0b00300c,   // ky.tg.uz_532 fr.ln.sco_543  uz.ky.tg_554 uz.es.un_530 
  0x0b303b0c, 0x285554ac, 0x0b3b300c, 0x0522630c,   // so.uz.es_543 ik.rw.sw_632  uz.so.es_543 sco.oc.fr_543 
  0x1e2f63a0, 0x08332e0c, 0x0247300c, 0x643b30ee,   // sco.su.ms_322 fo.nn.no_543  uz.sn.da_543 uz.so.lg_422 
  0x19003008, 0x6030750c, 0x5f751ca4, 0x0b30220c,   // uz.gl.un_430 nso.uz.vo_543  id.nso.tn_433 oc.uz.es_543 
  // [1e9d0]
  0x2d0d2fa9, 0x0e382e08, 0x304809ee, 0x25383c11,   // su.cs.sk_544 fo.tk.is_443  pl.tt.uz_422 ug.tk.mn_653 
  0x332e0204, 0x593055ec, 0x5e645507, 0x022e33a0,   // da.fo.nn_332 rw.uz.rn_644  rw.lg.ts_432 nn.fo.da_322 
  0x5e5730a7, 0x5c005813, 0x23301955, 0x0a6a78a9,   // uz.na.ts_532 om.sa.un_650  gl.uz.ca_442 ve.haw.pt_544 
  0x3b092aa0, 0x285cfe55, 0x0a3330ad, 0x52300107,   // mt.pl.so_322 tlh.sa.sw_442  uz.nn.pt_643 en.uz.ha_432 
  // [1e9e0]
  0x223330ad, 0x5d000608, 0x58384d12, 0x28554eec,   // uz.nn.oc_643 de.ss.un_430  aa.tk.om_654 ay.rw.sw_644 
  0x20005e12, 0x5c001b07, 0x1c1e5e08, 0x2f001e12,   // ts.sq.un_640 tr.sa.un_420  ts.ms.id_443 ms.su.un_640 
  0x35543413, 0x47282f08, 0x5a002f12, 0x3c080409,   // xh.ik.zu_665 su.sw.sn_443  su.sm.un_640 ru.uk.ug_444 
  0x1f002f05, 0x47004c0e, 0x231035a0, 0x2f005a0e,   // su.cy.un_330 wo.sn.un_550  tg.be.ky_322 sm.su.un_550 
  // [1e9f0]
  0x2b3e57af, 0x2f450505, 0x5a002f07, 0x0b011904,   // na.rm.vi_655 fr.ln.su_333  su.sm.un_420 gl.en.es_332 
  0x33082e08, 0x254811ee, 0x285578a4, 0x5556590c,   // fo.no.nn_443 ro.tt.mn_422  ve.rw.sw_433 rn.mg.rw_543 
  0x3b00120c, 0x304844ee, 0x384f3f0b, 0x023b3702,   // hu.so.un_530 kk.tt.uz_422  af.bi.tk_542 st.so.da_222 
  0x2e080207, 0x58006412, 0x2d060d0c, 0x280255ee,   // da.no.fo_432 lg.om.un_640  cs.de.sk_543 rw.da.sw_422 
  // [1ea00]
  0x021079a0, 0x270838a0, 0x1e003b0c, 0x302348a4,   // war.lt.da_322 tk.no.gd_322  so.ms.un_530 tt.ky.uz_433 
  0x040a3507, 0x07154807, 0x4a2f21a4, 0x0815230c,   // tg.mk.ru_432 tt.bg.un_420  jw.su.yo_433 ky.uk.un_530 
  0x2a3b0404, 0x171536a4, 0x4b5a5007, 0x12732807,   // fi.so.mt_332 ab.sr.un_430  fj.sm.mi_432 sw.ny.hu_432 
  0x12460405, 0x6902460c, 0x031dfea0, 0x0a07085a,   // fi.qu.hu_333 qu.da.mfe_543  tlh.la.nl_322 uk.bg.mk_553 
  // [1ea10]
  0x544c51a9, 0x1d006112, 0x2f6b1c07, 0x64155104,   // kl.wo.ik_544 za.la.un_640  id.ceb.su_432 kl.lg.un_320 
  0x2d0d12bb, 0x100454ee, 0x10041b04, 0x123d2114,   // hu.cs.sk_854 ik.fi.lt_422  tr.fi.lt_332 fa.ku.ur_666 
  0x04234807, 0x4b005204, 0x035852a0, 0x231035ee,   // tt.ky.ru_432 ha.mi.un_320  ha.om.nl_322 tg.be.ky_422 
  0x0735100c, 0x353711ee, 0x49005f04, 0x0413feac,   // be.tg.bg_543 ro.ba.tg_422  tn.to.un_320 tlh.et.fi_632 
  // [1ea20]
  0x4f5a4907, 0x06130c05, 0x21443c07, 0x3b18210c,   // to.sm.bi_432 sv.et.de_333  ug.kk.fa_432 fa.ar.ks_543 
  0x2700220d, 0x3534360e, 0x754f01a0, 0x18001c13,   // oc.gd.un_540 gn.xh.zu_555  en.bi.nso_322 mr.ar.un_650 
  0x3400581a, 0x650363a0, 0x441038ad, 0x212f20a0,   // om.xh.un_760 sco.nl.gv_322  tk.be.kk_643 sq.su.jw_322 
  0x3000270e, 0x341b4d12, 0x19230907, 0x35646807,   // gd.uz.un_550 aa.tr.xh_654  pl.ca.gl_432 ig.lg.zu_432 
  // [1ea30]
  0x60133814, 0x6735340e, 0x0b2a19af, 0x2e2c2007,   // tk.et.vo_666 xh.zu.ak_555  gl.mt.es_655 sq.fy.fo_432 
  0x2500090c, 0x356434ec, 0x0a0438a0, 0x28513507,   // pl.eu.un_530 xh.lg.zu_644  tk.ru.mk_322 zu.kl.sw_432 
  0x383c30a4, 0x2f4b6aa7, 0x044958a0, 0x2b004004,   // uz.ug.tk_433 haw.mi.su_532  om.to.fi_322 lb.vi.un_320 
  0x2430fe04, 0x1e496a0e, 0x56001d07, 0x120d2902,   // tlh.uz.eo_332 haw.to.ms_555  la.mg.un_420 sl.cs.hu_222 
  // [1ea40]
  0x35001c02, 0x07062a07, 0x0f383013, 0x69000908,   // id.zu.un_220 mt.de.it_432  uz.tk.lv_665 pl.mfe.un_430 
  0x302061ee, 0x31091b55, 0x1d001505, 0x072a39a4,   // za.sq.uz_422 tr.pl.az_442  un.la.un_330 br.mt.it_433 
  0x34355504, 0x3820530d, 0x16133207, 0x28004b0c,   // rw.zu.xh_332 ht.sq.tk_554  bs.et.hr_432 mi.sw.un_530 
  0x20001604, 0x2700fe0c, 0x21123dac, 0x16003005,   // hr.sq.un_320 tlh.gd.un_530  ku.ur.fa_632 uz.hr.un_330 
  // [1ea50]
  0x24290d0c, 0x1501fca4, 0x5c003b12, 0x18443c0c,   // cs.sl.eo_543 zzp.en.un_433  ks.sa.un_640 ug.kk.ar_543 
  0xfc002b05, 0x1afcfea7, 0x3c0a1713, 0x38311209,   // vi.zzp.un_330 tlh.zzp.tl_532  sr.mk.ug_665 hu.az.tk_444 
  0x0848350b, 0x2348370e, 0x38211aa9, 0x07100402,   // tg.tt.uk_542 ba.tt.ky_555  tl.jw.tk_544 ru.be.bg_222 
  0x25044807, 0x3500fe12, 0xfc1b1aad, 0x4817230c,   // tt.ru.mn_432 tlh.zu.un_640  tl.tr.zzp_643 ky.sr.tt_543 
  // [1ea60]
  0x524737ec, 0x4200130d, 0x2e0e0c0c, 0x0c3f2ca0,   // st.sn.ha_644 et.co.un_540  sv.is.fo_543 fy.af.sv_322 
  0x3046fe13, 0x321754ec, 0x09300204, 0x401b38a4,   // tlh.qu.uz_665 ik.sr.bs_644  da.uz.pl_332 tk.tr.lb_433 
  0x15033fa6, 0x76234308, 0x430110a4, 0x39564704,   // af.nl.un_521 ie.ca.crs_443  lt.en.ie_433 sn.mg.br_332 
  0x2b003908, 0x0e0815a0, 0x2c04130d, 0x7600011b,   // br.vi.un_430 un.no.is_322  et.fi.fy_554 en.crs.un_770 
  // [1ea70]
  0x01fc43a6, 0x09003805, 0x283418af, 0x0a1530a0,   // ie.zzp.en_521 tk.pl.un_330  ar.ps.sd_655 uz.mk.un_320 
  0x08253c04, 0x4379010c, 0x4400070e, 0x0d003914,   // ug.mn.uk_332 en.war.ie_543  bg.kk.un_550 br.cs.un_660 
  0x21004409, 0x3b343d05, 0x233837a9, 0x350717a0,   // kk.fa.un_440 ku.ps.ks_333  ba.tk.ky_544 sr.bg.tg_322 
  0x040a38a4, 0x11234307, 0x0d001c22, 0x18233404,   // tk.mk.ru_433 ie.ca.ro_432  mr.ne.un_870 ps.ky.ar_332 
  // [1ea80]
  0x103704a4, 0x1c003404, 0x5d342804, 0x5f244712,   // ru.ba.be_433 xh.id.un_320  sw.xh.ss_332 sn.eo.tn_654 
  0x65001108, 0x564347a4, 0x160268a9, 0x6100fe14,   // ro.gv.un_430 sn.ie.mg_433  ig.da.hr_544 tlh.za.un_660 
  0x3700450d, 0x5600390d, 0x171e1c04, 0x5f372d07,   // ln.st.un_540 br.mg.un_540  id.ms.sr_332 sk.st.tn_432 
  0x735f4708, 0x554259a6, 0x5a595504, 0x35340da4,   // sn.tn.ny_443 rn.co.rw_521  rw.rn.sm_332 cs.xh.zu_433 
  // [1ea90]
  0x2461fe12, 0x35135d04, 0x1d263907, 0x375f45af,   // tlh.za.eo_654 ss.et.zu_332  br.ia.la_432 ln.tn.st_655 
  0x07001902, 0x65135808, 0x283455a6, 0x3b002404,   // gl.it.un_220 om.et.gv_443  rw.xh.sw_521 eo.so.un_320 
  0x3f004023, 0x4035345a, 0x17280804, 0x0e4d4c07,   // lb.af.un_880 xh.zu.lb_553  no.sw.sr_332 wo.aa.is_432 
  0x2a001708, 0x64345504, 0x07002813, 0x6576010c,   // sr.mt.un_430 rw.xh.lg_332  sw.it.un_650 en.crs.gv_543 
  // [1eaa0]
  0x12003f09, 0x3700080d, 0x0b7953a9, 0x73070ba0,   // af.hu.un_440 no.st.un_540  ht.war.es_544 es.it.ny_322 
  0x35342fa0, 0x39fe24ad, 0x4722290d, 0x5d093505,   // su.xh.zu_322 eo.tlh.br_643  sl.oc.sn_554 zu.pl.ss_333 
  0xfe002413, 0x080e2ea0, 0x18442314, 0x040e540c,   // eo.tlh.un_650 fo.is.no_322  ky.kk.ar_666 ik.is.fi_543 
  0x37016304, 0x43003e0e, 0x3f041d08, 0x6b687309,   // sco.en.st_332 rm.ie.un_550  la.fi.af_443 ny.ig.ceb_444 
  // [1eab0]
  0x0c1333a6, 0x072d1d04, 0x5d212f55, 0x73000f13,   // nn.et.sv_521 la.sk.it_332  su.jw.ss_442 lv.ny.un_650 
  0x2a0f15ac, 0x5e4715a0, 0x03151002, 0x30122114,   // un.lv.mt_632 un.sn.ts_322  lt.nl.un_220 fa.ur.uz_666 
  0x17001307, 0x39080213, 0x3f000214, 0x16005002,   // et.sr.un_420 da.no.br_665  da.af.un_660 fj.hr.un_220 
  0x02003818, 0x24225ea0, 0x4b495ead, 0x0c0239af,   // tk.da.un_740 ts.oc.eo_322  ts.to.mi_643 br.da.sv_655 
  // [1eac0]
  0x51735507, 0x355d3412, 0x4219110c, 0x5d007809,   // rw.ny.kl_432 xh.ss.zu_654  ro.gl.co_543 ve.ss.un_440 
  0x210f42a0, 0x023f0613, 0x5e2824ec, 0x25303ca0,   // co.lv.jw_322 de.af.da_665  eo.sw.ts_644 ug.uz.mn_322 
  0x3e240507, 0x5d345e13, 0x19004208, 0x3800020e,   // fr.eo.rm_432 ts.xh.ss_665  co.gl.un_430 da.tk.un_550 
  0x4d003822, 0x183b38a4, 0x302821a7, 0x595e3309,   // tk.aa.un_870 tk.so.ga_433  fa.sd.uz_532 nn.ts.rn_444 
  // [1ead0]
  0x02002b09, 0x4215010c, 0x17004705, 0x2d17290c,   // vi.da.un_440 en.co.un_530  sn.sr.un_330 sl.sr.sk_543 
  0x1a026b07, 0x28342105, 0x35555d0c, 0x37575f12,   // ceb.da.tl_432 fa.ps.sd_333  ss.rw.zu_543 tn.na.st_654 
  0x631328ac, 0x0e35340d, 0x33656e07, 0x1b3830a0,   // sw.et.sco_632 xh.zu.is_554  hmn.gv.nn_432 uz.tk.tr_322 
  0x04153504, 0x79212408, 0x240e2e05, 0x16313002,   // tg.ru.un_320 eo.jw.war_443  fo.is.eo_333 uz.az.hr_222 
  // [1eae0]
  0x4d132108, 0x441004a6, 0x64005a05, 0x64003102,   // jw.et.aa_443 ru.be.kk_521  sm.lg.un_330 az.lg.un_220 
  0x31351ba0, 0x63790108, 0x2d0d5609, 0x6bfe5ca0,   // tr.zu.az_322 en.war.sco_443  mg.cs.sk_444 sa.tlh.ceb_322 
  0x3d343b13, 0x311b5413, 0x01003302, 0x641b2e04,   // ks.ps.ku_665 ik.tr.az_665  nn.en.un_220 fo.tr.lg_332 
  0x20330855, 0x2d0d5aec, 0x1b2e3109, 0x47510da0,   // no.nn.sq_442 sm.cs.sk_644  az.fo.tr_444 cs.kl.sn_322 
  // [1eaf0]
  0x6b3121a4, 0x042c09ec, 0x31344611, 0x3b584307,   // jw.az.ceb_433 pl.fy.fi_644  qu.xh.az_653 ie.om.so_432 
  0x18122805, 0x3f0c2cee, 0x28355da0, 0x30353c04,   // sd.ur.ar_333 fy.sv.af_422  ss.zu.sw_322 ug.tg.uz_332 
  0x24fe300b, 0x0d202d0c, 0x13330811, 0x31305004,   // uz.tlh.eo_542 sk.sq.cs_543  no.nn.et_653 fj.uz.az_332 
  0x480435ee, 0x2c000414, 0x0e002013, 0x2c000913,   // tg.ru.tt_422 fi.fy.un_660  sq.is.un_650 pl.fy.un_650 
  // [1eb00]
  0x040c2ca6, 0x2c292e05, 0x6b075807, 0x513b2ca0,   // fy.sv.fi_521 fo.sl.fy_333  om.it.ceb_432 fy.so.kl_322 
  0x551a4607, 0x64475908, 0x69fe780c, 0x1511440c,   // qu.tl.rw_432 rn.sn.lg_443  ve.tlh.mfe_543 kk.ro.un_543 
  0x157864a4, 0x4700fc05, 0x1f4a3707, 0x2e001218,   // lg.ve.un_433 zzp.sn.un_330  st.yo.cy_432 hu.fo.un_740 
  0x421f64a4, 0x421ffc13, 0x46002f14, 0x17000607,   // lg.cy.co_433 zzp.cy.co_665  su.qu.un_660 de.sr.un_420 
  // [1eb10]
  0x42fc1fa6, 0x380602a9, 0x0800061a, 0x1f005e0d,   // cy.zzp.co_521 da.de.tk_544  de.no.un_760 ts.cy.un_540 
  0x3842fc07, 0x4c4a7604, 0x062a7808, 0x1f00fe07,   // zzp.co.tk_432 crs.yo.wo_332  ve.mt.de_443 tlh.cy.un_420 
  0xfc006419, 0x4c007311, 0x685f5e60, 0x643bfc0c,   // lg.zzp.un_750 ny.wo.un_630  ts.tn.ig_664 zzp.so.lg_543 
  0x64375f5a, 0x392a7308, 0xfc004205, 0x64097908,   // tn.st.lg_553 ny.mt.br_443  co.zzp.un_330 war.pl.lg_443 
  // [1eb20]
  0x2a1a78a0, 0x33630813, 0x38fc6407, 0x1f004c1a,   // ve.tl.mt_322 no.sco.nn_665  lg.zzp.tk_432 wo.cy.un_760 
  0x644573ad, 0x5c64fc13, 0x5c42fc07, 0x64001f22,   // ny.ln.lg_643 zzp.lg.sa_665  zzp.co.sa_432 cy.lg.un_870 
  0x12004c19, 0x6442fc60, 0x641f01a0, 0x02fc1f08,   // wo.hu.un_750 zzp.co.lg_664  en.cy.lg_322 cy.zzp.da_443 
  0x340901a4, 0x537369af, 0x2a524da0, 0x4d2a6412,   // en.pl.xh_433 mfe.ny.ht_655  aa.ha.mt_322 lg.mt.aa_654 
  // [1eb30]
  0x2a6353af, 0x30004a0b, 0x5f000609, 0x3700290e,   // ht.sco.mt_655 yo.uz.un_520  de.tn.un_440 sl.st.un_550 
  0x645e2813, 0x20100fee, 0x45000209, 0x282129ec,   // sw.ts.lg_665 lv.lt.sq_422  da.ln.un_440 sl.jw.sw_644 
  0x1c2f20a7, 0x4a291212, 0x233034af, 0x134a3805,   // sq.su.id_532 hu.sl.yo_654  ps.uz.ky_655 tk.yo.et_333 
  0x532420a4, 0x6e00610e, 0x24005304, 0x092d2407,   // sq.eo.ht_433 za.hmn.un_550  ht.eo.un_320 eo.sk.pl_432 
  // [1eb40]
  0x1b115302, 0x11322407, 0x2a1029a0, 0x1f00620d,   // ht.ro.tr_222 eo.bs.ro_432  sl.lt.mt_322 kha.cy.un_540 
  0x1b6e24ec, 0x1800341b, 0x1b2211af, 0x0b002a05,   // eo.hmn.tr_644 ps.ar.un_770  ro.oc.tr_655 mt.es.un_330 
  0x57123605, 0x22001704, 0x53001102, 0xfe002914,   // gn.hu.na_333 sr.oc.un_320  ro.ht.un_220 sl.tlh.un_660 
  0x073e2904, 0x422319a4, 0x02003207, 0x2e002519,   // sl.rm.it_332 gl.ca.co_433  bs.da.un_420 eu.fo.un_750 
  // [1eb50]
  0x4200580c, 0x502e0ca4, 0x2b004709, 0x103836a4,   // om.co.un_530 sv.fo.fj_433  sn.vi.un_440 ab.tk.be_433 
  0x071125a4, 0x303b3f0e, 0x18343ca7, 0x48383608,   // eu.ro.it_433 af.so.uz_555  ug.ps.ar_532 ab.tk.tt_443 
  0x300825a0, 0x39002d02, 0x285368ec, 0x02695309,   // mn.uk.uz_322 sk.br.un_220  ig.ht.sw_644 ht.mfe.da_444 
  0x3c281255, 0x1b63255a, 0x584a4811, 0x76534dad,   // ur.sd.ug_442 eu.sco.tr_553  tt.yo.om_653 aa.ht.crs_643 
  // [1eb60]
  0x34006911, 0x634201af, 0x190a2ba4, 0x3b63010c,   // mfe.xh.un_630 en.co.sco_655  vi.pt.gl_433 en.sco.so_543 
  0x1d002905, 0x10112504, 0x2353220e, 0x0f002a10,   // sl.la.un_330 mn.ro.be_332  oc.ht.ca_555 mt.lv.un_620 
  0x35100a02, 0x48353407, 0x3835170c, 0x28001f07,   // mk.be.tg_222 xh.zu.tt_432  sr.tg.tk_543 cy.sw.un_420 
  0xfc1b2aee, 0x46733007, 0x100708a4, 0x16003b04,   // mt.tr.zzp_422 uz.ny.qu_432  uk.bg.be_433 so.hr.un_320 
  // [1eb70]
  0x282bfea7, 0x352b02a7, 0x033f08a4, 0x333f1204,   // tlh.vi.sw_532 da.vi.zu_532  no.af.nl_433 hu.af.nn_332 
  0x341b1fac, 0x150118a0, 0x170a3ca9, 0x311f3ba9,   // cy.tr.xh_632 ga.en.un_322  ug.mk.sr_544 so.cy.az_544 
  0x3934fe07, 0x38003b02, 0x5d001704, 0x352873a0,   // tlh.xh.br_432 so.tk.un_220  sr.ss.un_320 ny.sw.zu_322 
  0x63fc6507, 0x35304409, 0x092dfeee, 0x7978fc12,   // gv.zzp.sco_432 kk.uz.tg_444  tlh.sk.pl_422 zzp.ve.war_654 
  // [1eb80]
  0x5c007305, 0x3046fe0d, 0x480420a0, 0x170429a0,   // ny.sa.un_330 tlh.qu.uz_554  sq.fi.tt_322 sl.fi.sr_322 
  0x0e2e0f07, 0x013476a4, 0x330813a9, 0x0448170b,   // lv.fo.is_432 crs.xh.en_433  et.no.nn_544 sr.tt.ru_542 
  0x043f46a0, 0x565225ad, 0x5e001207, 0x180e090c,   // qu.af.fi_322 eu.ha.mg_643  hu.ts.un_420 pl.is.ga_543 
  0x210545ee, 0x04033fee, 0x0c005207, 0x251f2213,   // ln.fr.jw_422 af.nl.fi_422  ha.sv.un_420 oc.cy.eu_665 
  // [1eb90]
  0x13002522, 0x372515a6, 0x100645a0, 0x0a0830ee,   // eu.et.un_870 un.mn.ba_521  ln.de.lt_322 uz.uk.mk_422 
  0x083710a0, 0x205f2aa4, 0x5c212902, 0x3f092c02,   // be.ba.uk_322 mt.tn.sq_433  sl.jw.sa_222 fy.pl.af_222 
  0x04595508, 0x231234a0, 0x35071708, 0x301221ee,   // rw.rn.fi_443 ps.ur.ky_322  sr.bg.tg_443 fa.ur.uz_422 
  0x0a00150d, 0x28022f0c, 0x042f1f04, 0x30115204,   // un.mk.un_540 su.da.sw_543  cy.su.fi_332 ha.ro.uz_332 
  // [1eba0]
  0x4c202f0c, 0x492f0460, 0x431f06a7, 0x080a15ee,   // su.sq.wo_543 fi.su.to_664  de.cy.ie_532 un.mk.uk_422 
  0x38124807, 0x062f39a6, 0x3f034ca0, 0x23481055,   // tt.hu.tk_432 br.su.de_521  wo.nl.af_322 be.tt.ky_442 
  0x282b2fa0, 0x2f490412, 0x2f21fea6, 0x27330805,   // su.vi.sw_322 fi.to.su_654  tlh.jw.su_521 no.nn.gd_333 
  0x1b4006ad, 0x3f000407, 0x0400fe0d, 0x1e001807,   // de.lb.tr_643 fi.af.un_420  tlh.fi.un_540 ga.ms.un_420 
  // [1ebb0]
  0x33080f02, 0x3723480e, 0x31301f55, 0x6300790d,   // lv.no.nn_222 tt.ky.ba_555  cy.uz.az_442 war.sco.un_540 
  0x08021205, 0x27650ca0, 0x25000305, 0x07023e05,   // hu.da.no_333 sv.gv.gd_322  nl.eu.un_330 rm.da.it_333 
  0x136504a4, 0x481b150c, 0x12460205, 0x04033f02,   // fi.gv.et_433 un.tr.tt_543  da.qu.hu_333 af.nl.fi_222 
  0x1a381208, 0x12395105, 0x46000207, 0x3b304004,   // hu.tk.tl_443 kl.br.hu_333  da.qu.un_420 lb.uz.so_332 
  // [1ebc0]
  0x420522ee, 0x1f0e0cee, 0x1715370c, 0x13290408,   // oc.fr.co_422 sv.is.cy_422  ba.sr.un_530 fi.sl.et_443 
  0x304c310d, 0x5458500c, 0x2a524c0d, 0x5c5456a9,   // az.wo.uz_554 fj.om.ik_543  wo.ha.mt_554 mg.ik.sa_544 
  0x12545a12, 0x2033080b, 0x511208a4, 0x13435ca4,   // sm.ik.hu_654 no.nn.sq_542  no.hu.kl_433 sa.ie.et_433 
  0x03120907, 0x463048ad, 0x510c540c, 0xfe005b0e,   // pl.hu.nl_432 tt.uz.qu_643  ik.sv.kl_543 sg.tlh.un_550 
  // [1ebd0]
  0x29001309, 0x23483804, 0x152d0da7, 0x122b47ee,   // et.sl.un_440 tk.tt.ky_332  cs.sk.un_532 sn.vi.hu_422 
  0x5e5323ad, 0x245c100c, 0x561304a7, 0x35111508,   // ca.ht.ts_643 lt.sa.eo_543  fi.et.mg_532 un.ro.tg_443 
  0x1300fe07, 0x3823250c, 0x36173508, 0x75000e0c,   // tlh.et.un_420 mn.ky.tk_543  tg.sr.ab_443 is.nso.un_530 
  0x2c0203a4, 0x3f1d3402, 0xfc000f08, 0x08350a04,   // nl.da.fy_433 xh.la.af_222  lv.zzp.un_430 mk.tg.uk_332 
  // [1ebe0]
  0x0219600d, 0x08252304, 0x1673060c, 0x071d01a4,   // vo.gl.da_554 ky.mn.uk_332  de.ny.hr_543 en.la.it_433 
  0x254823a0, 0x061529a4, 0x060c1902, 0x1a033fa4,   // ky.tt.mn_322 sl.de.un_430  gl.sv.de_222 af.nl.tl_433 
  0x2f1e1ca7, 0x7335280d, 0x6473670c, 0x3e001e05,   // id.ms.su_532 sw.zu.ny_554  ak.ny.lg_543 ms.rm.un_330 
  0x070438a7, 0x34453507, 0x231827a9, 0x0d004208,   // tk.ru.bg_532 zu.ln.xh_432  gd.ga.ca_544 co.cs.un_430 
  // [1ebf0]
  0x15073705, 0x1b2f31a7, 0x183b48a6, 0x0a2326a9,   // ba.bg.un_333 az.su.tr_532  tt.so.ga_521 ia.ca.pt_544 
  0x5e00522b, 0x6b4702a4, 0x384825ad, 0x24001107,   // ha.ts.un_980 da.sn.ceb_433  eu.tt.tk_643 ro.eo.un_420 
  0x0e31480c, 0x2400530c, 0x24fe610e, 0x65002c02,   // tt.az.is_543 ht.eo.un_530  za.tlh.eo_555 fy.gv.un_220 
  0x131c5c0d, 0x0953240c, 0x1823441f, 0x65001509,   // sa.mr.bh_554 eo.ht.pl_543  kk.ky.ar_864 un.gv.un_440 
  
  // [1ec00]
  0x0748200b, 0x65001004, 0x07000a0b, 0x035d30a0,   // sq.tt.it_542 lt.gv.un_320  mk.bg.un_520 uz.ss.nl_322 
  0x0c2e02ee, 0x32291307, 0x35340cee, 0x265c070c,   // da.fo.sv_422 et.sl.bs_432  sv.xh.zu_422 it.sa.ia_543 
  0x3b0350a4, 0x6a791ea4, 0x33003404, 0xfc0701a0,   // fj.nl.so_433 ms.war.haw_433  xh.nn.un_320 en.it.zzp_322 
  0x13005721, 0x35005d19, 0x496a25af, 0x1917570c,   // na.et.un_860 ss.zu.un_750  eu.haw.to_655 na.sr.gl_543 
  // [1ec10]
  0x190b340e, 0xfc0901af, 0x07004811, 0x52025704,   // xh.es.gl_555 en.pl.zzp_655  tt.bg.un_630 na.da.ha_332 
  0x44483c07, 0x1950290c, 0x1a002f02, 0x333f5da0,   // ug.tt.kk_432 sl.fj.gl_543  su.tl.un_220 ss.af.nn_322 
  0x0c2d570c, 0x1609110c, 0x2920600c, 0x230411ee,   // na.sk.sv_543 ro.pl.hr_543  vo.sq.sl_543 ro.ru.ky_422 
  0x4a2f2812, 0x1e002808, 0x686428ad, 0xfc0b29a0,   // sw.su.yo_654 sw.ms.un_430  sw.lg.ig_643 sl.es.zzp_322 
  // [1ec20]
  0x36110809, 0x3200090c, 0x315e2ead, 0x162949a4,   // uk.ro.ab_444 pl.bs.un_530  fo.ts.az_643 to.sl.hr_433 
  0x67735609, 0x681d01ee, 0x36473e07, 0x495e5a13,   // mg.ny.ak_444 en.la.ig_422  rm.sn.gn_432 sm.ts.to_665 
  0x355c67a4, 0x09002412, 0x6e2024a9, 0x355d3407,   // ak.sa.zu_433 eo.pl.un_640  eo.sq.hmn_544 xh.ss.zu_432 
  0x48313002, 0x0900240e, 0x566459a4, 0x311b260c,   // uz.az.tt_222 eo.pl.un_550  rn.lg.mg_433 ia.tr.az_543 
  // [1ec30]
  0x5f55560c, 0x736875a7, 0x79190b04, 0x2d0d0fa6,   // mg.rw.tn_543 nso.ig.ny_532  es.gl.war_332 lv.cs.sk_521 
  0x506447af, 0x0b5c7302, 0x56004713, 0x68000f09,   // sn.lg.fj_655 ny.sa.es_222  sn.mg.un_650 lv.ig.un_440 
  0x025a470d, 0x5c000709, 0x4c465308, 0x525e6704,   // sn.sm.da_554 it.sa.un_440  ht.qu.wo_443 ak.ts.ha_332 
  0x5e474908, 0x12283dec, 0x536447ac, 0x0a365c08,   // to.sn.ts_443 ku.sd.ur_644  sn.lg.ht_632 sa.gn.pt_443 
  // [1ec40]
  0x251a55a4, 0x022b0e07, 0x25003b13, 0x5c796b0b,   // rw.tl.eu_433 is.vi.da_432  so.eu.un_650 ceb.war.sa_542 
  0x115324ad, 0x756b1a12, 0x1c2f21a7, 0x452873af,   // eo.ht.ro_643 tl.ceb.nso_654  jw.su.id_532 ny.sw.ln_655 
  0x275c4802, 0x2b2034a7, 0x4a1c1ea4, 0x1f2718a0,   // tt.sa.gd_222 xh.sq.vi_532  ms.id.yo_433 ga.gd.cy_322 
  0x245c3002, 0x352034ad, 0x1123480c, 0x47356aee,   // uz.sa.eo_222 xh.sq.zu_643  tt.ky.ro_543 haw.zu.sn_422 
  // [1ec50]
  0x0e001b04, 0x0a07100b, 0x65005114, 0x2d0d130c,   // tr.is.un_320 be.bg.mk_542  kl.gv.un_660 et.cs.sk_543 
  0x07653ea0, 0x32160e04, 0x070a1113, 0x15482507,   // rm.gv.it_322 is.hr.bs_332  ro.mk.bg_665 mn.tt.un_432 
  0x4f2e40a7, 0x583830ee, 0x093b38a7, 0x21495ca4,   // lb.fo.bi_532 uz.tk.om_422  tk.so.pl_532 sa.to.jw_433 
  0x0425135a, 0x07105c07, 0x1d1f18ec, 0x36382312,   // et.eu.fi_553 sa.lt.it_432  ga.cy.la_644 ky.tk.ab_654 
  // [1ec60]
  0x300744a0, 0x48130402, 0x2f004902, 0x474046ee,   // kk.bg.uz_322 fi.et.tt_222  to.su.un_220 qu.lb.sn_422 
  0x080212ec, 0x48381bee, 0x232513a9, 0x236b5ea9,   // hu.da.no_644 tr.tk.tt_422  et.eu.ca_544 ts.ceb.ca_544 
  0x22001305, 0x30004007, 0x1d2a69a4, 0x0522fe05,   // et.oc.un_330 lb.uz.un_420  mfe.mt.la_433 tlh.oc.fr_333 
  0x3e5369a7, 0x0500221a, 0x2f1a4ca0, 0x230a05a4,   // mfe.ht.rm_532 oc.fr.un_760  wo.tl.su_322 fr.pt.ca_433 
  // [1ec70]
  0x1304600c, 0x11002707, 0x02131008, 0x1d2223a4,   // vo.fi.et_543 gd.ro.un_420  lt.et.da_443 ca.oc.la_433 
  0x4afe5607, 0x2f7327a4, 0x3b001318, 0x35500f0c,   // mg.tlh.yo_432 gd.ny.su_433  et.so.un_740 lv.fj.zu_543 
  0x212812a6, 0x124a4c0c, 0x183b5c08, 0x29090d0c,   // ur.sd.fa_521 wo.yo.hu_543  sa.so.ga_443 cs.pl.sl_543 
  0x42061f02, 0x1f580a02, 0x3b5857a4, 0x4800090c,   // cy.de.co_222 pt.om.cy_222  na.om.so_433 pl.tt.un_530 
  // [1ec80]
  0x7300031a, 0x1d583f0d, 0x48583b0d, 0x392e1d08,   // nl.ny.un_760 af.om.la_554  so.om.tt_554 la.fo.br_443 
  0x09677307, 0x1a10fc04, 0x690263a4, 0x1f000605,   // ny.ak.pl_432 zzp.lt.tl_332  sco.da.mfe_433 de.cy.un_330 
  0x043717ee, 0x170408af, 0x20420fac, 0x44483608,   // sr.ba.ru_422 uk.ru.sr_655  lv.co.sq_632 ab.tt.kk_443 
  0x330824a0, 0x0100fc09, 0x0f000212, 0x300736a9,   // eo.no.nn_322 zzp.en.un_440  da.lv.un_640 ab.bg.uz_544 
  // [1ec90]
  0x422f050b, 0x43135804, 0x7600460d, 0x0f4b4da7,   // fr.su.co_542 om.et.ie_332  qu.crs.un_540 aa.mi.lv_532 
  0x215c38a4, 0x38462114, 0xfc3e0604, 0x676056ad,   // tk.sa.jw_433 jw.qu.tk_666  de.rm.zzp_332 mg.vo.ak_643 
  0x0a073702, 0x2433130b, 0x13303108, 0x094e46ec,   // ba.bg.mk_222 et.nn.eo_542  az.uz.et_443 qu.ay.pl_644 
  0x051548a4, 0x0c0224a4, 0x184428a0, 0x225c230d,   // tt.fr.un_430 eo.da.sv_433  sd.kk.ar_322 ca.sa.oc_554 
  // [1eca0]
  0x391247ad, 0x2624010c, 0x0e0c1ba4, 0x2f054cb2,   // sn.hu.br_643 en.eo.ia_543  tr.sv.is_433 wo.fr.su_732 
  0x23006122, 0x64403bad, 0x6100231a, 0x1ffe3b0c,   // za.ca.un_870 so.lb.lg_643  ca.za.un_760 so.tlh.cy_543 
  0x0f2f5107, 0x3b024c09, 0x302a3b04, 0x5238640c,   // kl.su.lv_432 wo.da.so_444  so.mt.uz_332 lg.tk.ha_543 
  0x4c00041b, 0x524c42a0, 0x0c006304, 0x12326907,   // fi.wo.un_770 co.wo.ha_322  sco.sv.un_320 mfe.bs.hu_432 
  // [1ecb0]
  0x211a6b07, 0x3b4c510c, 0x1f003b1a, 0x3f00340c,   // ceb.tl.jw_432 kl.wo.so_543  so.cy.un_760 xh.af.un_530 
  0xfc51780d, 0x02004305, 0x5c4d64a7, 0x17162ea0,   // ve.kl.zzp_554 ie.da.un_330  lg.aa.sa_532 fo.hr.sr_322 
  0x513b58ec, 0x3500460b, 0x16043055, 0x5c20fea7,   // om.so.kl_644 qu.zu.un_520  uz.fi.hr_442 tlh.sq.sa_532 
  0x5c3b6412, 0x4a3b4ca4, 0x42052204, 0x211c4fa9,   // lg.so.sa_654 wo.so.yo_433  oc.fr.co_332 bi.id.jw_544 
  // [1ecc0]
  0x791a6b60, 0x4c006e04, 0x02004c07, 0x64003b21,   // ceb.tl.war_664 hmn.wo.un_320  wo.da.un_420 so.lg.un_860 
  0x28796b12, 0x0f5c4211, 0x5c2e64a4, 0x3b515812,   // ceb.war.sw_654 co.sa.lv_653  lg.fo.sa_433 om.kl.so_654 
  0x044c13ee, 0x341930a4, 0x35301755, 0x4d1f3b0c,   // et.wo.fi_422 uz.gl.xh_433  sr.uz.tg_442 so.cy.aa_543 
  0x3f020c0c, 0x04004c07, 0x04464d05, 0x30643b0c,   // sv.da.af_543 wo.fi.un_420  aa.qu.fi_333 so.lg.uz_543 
  // [1ecd0]
  0xfe272f02, 0xfc001907, 0x2a3b3008, 0x01652a07,   // su.gd.tlh_222 gl.zzp.un_420  uz.so.mt_443 mt.gv.en_432 
  0x2f466304, 0x1a002913, 0x2a113808, 0x5f5e520d,   // sco.qu.su_332 sl.tl.un_650  tk.ro.mt_443 ha.ts.tn_554 
  0x541e4bad, 0x30241ea4, 0x462163ec, 0x3852510c,   // mi.ms.ik_643 ms.eo.uz_433  sco.jw.qu_644 kl.ha.tk_543 
  0x2f1622a0, 0x21005e19, 0x3600230c, 0x361538a4,   // oc.hr.su_322 ts.jw.un_750  ky.ab.un_530 tk.ab.un_430 
  // [1ece0]
  0x3808170d, 0x233b3c0c, 0x0946fe0c, 0x362e0e07,   // sr.uk.tk_554 ug.ks.ky_543  tlh.qu.pl_543 is.fo.gn_432 
  0x6e002008, 0x12281809, 0x19180a55, 0x3d3b2111,   // sq.hmn.un_430 ar.sd.ur_444  pt.ga.gl_442 fa.ks.ku_653 
  0x15300708, 0x4c000511, 0x06001219, 0x17002519,   // bg.uz.un_443 fr.wo.un_630  hu.de.un_750 mn.sr.un_750 
  0x212f53a0, 0x10003b13, 0x454305a4, 0x22194204,   // ht.su.jw_322 so.lt.un_650  fr.ie.ln_433 co.gl.oc_332 
  // [1ecf0]
  0x15360107, 0x164324a4, 0x1600360c, 0x232d4202,   // en.gn.un_432 eo.ie.hr_433  gn.hr.un_530 co.sk.ca_222 
  0x4928680b, 0x284b2ba9, 0x2e1530ee, 0x083f3307,   // ig.sw.to_542 vi.mi.sw_544  uz.fo.un_420 nn.af.no_432 
  0x2d005507, 0x083504a9, 0x212f0504, 0x10003023,   // rw.sk.un_420 ru.tg.uk_544  fr.su.jw_332 uz.be.un_880 
  0x564005a7, 0x122f05ee, 0x0c08021a, 0x2b083fa4,   // fr.lb.mg_532 fr.su.hu_422  da.no.sv_776 af.no.vi_433 
  // [1ed00]
  0x33000c1b, 0x08351155, 0x056101a0, 0x2b001505,   // sv.nn.un_770 ro.tg.uk_442  en.za.fr_322 un.vi.un_330 
  0x10000823, 0x3038440c, 0x02595507, 0x0a0415a9,   // uk.be.un_880 kk.tk.uz_543  rw.rn.da_432 un.ru.mk_544 
  0x1d004702, 0x21005c0c, 0x305d69a0, 0x21005002,   // sn.la.un_220 sa.jw.un_530  mfe.ss.uz_322 fj.jw.un_220 
  0x15584307, 0x1b4764ec, 0x332e2c05, 0x080a3c60,   // ie.om.un_432 lg.sn.tr_644  fy.fo.nn_333 ug.mk.uk_664 
  // [1ed10]
  0x330c2e07, 0x32003f07, 0x331706a0, 0x561864a0,   // fo.sv.nn_432 af.bs.un_420  de.sr.nn_322 lg.ga.mg_322 
  0x69765c0c, 0x0c060804, 0x020e2e11, 0x6b027955,   // sa.crs.mfe_543 no.de.sv_332  fo.is.da_653 war.da.ceb_442 
  0x1f4c2408, 0x062c3f07, 0x623833a4, 0x5c4653ee,   // eo.wo.cy_443 af.fy.de_432  nn.tk.kha_433 ht.qu.sa_422 
  0x581a62ad, 0x58135504, 0x150b11ee, 0x22236a0d,   // kha.tl.om_643 rw.et.om_332  ro.es.un_422 haw.ca.oc_554 
  // [1ed20]
  0x0f2f5904, 0x48362312, 0x48323005, 0x796b4a13,   // rn.su.lv_332 ky.ab.tt_654  uz.bs.tt_333 yo.ceb.war_665 
  0x614331af, 0x311b33ee, 0x2c330204, 0x55255955,   // az.ie.za_655 nn.tr.az_422  da.nn.fy_332 rn.eu.rw_442 
  0x631f09a4, 0x0c2d0d08, 0x553559ad, 0x48647304,   // pl.cy.sco_433 cs.sk.sv_443  rn.zu.rw_643 ny.lg.tt_332 
  0x3b002902, 0x05283ea4, 0x150a17a0, 0x546b5112,   // sl.so.un_220 rm.sw.fr_433  sr.mk.un_322 kl.ceb.ik_654 
  // [1ed30]
  0x4835440b, 0x48073808, 0x33081f0c, 0x171036a9,   // kk.tg.tt_542 tk.bg.tt_443  cy.no.nn_543 ab.be.sr_544 
  0x48372308, 0x475a490c, 0x605a04a9, 0x500549a9,   // ky.ba.tt_443 to.sm.sn_543  fi.sm.vo_544 to.fr.fj_544 
  0x06544b07, 0x4b044fec, 0x17100f08, 0x2300610d,   // mi.ik.de_432 bi.fi.mi_644  lv.lt.sr_443 za.ca.un_540 
  0x18343d09, 0x5f541008, 0x1e001304, 0x1d265007,   // ku.ps.ar_444 lt.ik.tn_443  et.ms.un_320 fj.ia.la_432 
  // [1ed40]
  0x20303f05, 0x444837ad, 0x030620a7, 0x17002402,   // af.uz.sq_333 ba.tt.kk_643  sq.de.nl_532 eo.sr.un_220 
  0x055054ad, 0x04fe615a, 0x04541012, 0x2d0d2e02,   // ik.fj.fr_643 za.tlh.fi_553  lt.ik.fi_654 fo.cs.sk_222 
  0x37002a07, 0x2028525a, 0x524b50a9, 0x0422500c,   // mt.st.un_420 ha.sw.sq_553  fj.mi.ha_544 fj.oc.fi_543 
  0x2b000509, 0x5c6b04a4, 0x59003012, 0x0f002002,   // fr.vi.un_440 fi.ceb.sa_433  uz.rn.un_640 sq.lv.un_220 
  // [1ed50]
  0x1e3b5202, 0x3000130e, 0x39214607, 0x32311b0c,   // ha.so.ms_222 et.uz.un_550  qu.jw.br_432 tr.az.bs_543 
  0x3734785a, 0x5262300c, 0x17004002, 0x64212da7,   // ve.xh.st_553 uz.kha.ha_543  lb.sr.un_220 sk.jw.lg_532 
  0x04606205, 0x0b6459a9, 0x243b2e0c, 0x3b102412,   // kha.vo.fi_333 rn.lg.es_544  fo.so.eo_543 eo.lt.so_654 
  0x17004604, 0x0d092e04, 0x55003b04, 0x24002511,   // qu.sr.un_320 fo.pl.cs_332  so.rw.un_320 eu.eo.un_630 
  // [1ed60]
  0x090f25a0, 0x046315a7, 0x23040804, 0x31105cee,   // eu.lv.pl_322 un.sco.fi_532  uk.ru.ky_332 sa.lt.az_422 
  0x0d0e6a04, 0x2d2953a6, 0x1369510c, 0x3b514c55,   // haw.is.cs_332 ht.sl.sk_521  kl.mfe.et_543 wo.kl.so_442 
  0x04514c09, 0x6a5a4b08, 0x11563713, 0x51243ba0,   // wo.kl.fi_444 mi.sm.haw_443  st.mg.ro_665 so.eo.kl_322 
  0x375a560c, 0x3820310c, 0x374b560c, 0x285f3708,   // mg.sm.st_543 az.sq.tk_543  mg.mi.st_543 st.tn.sw_443 
  // [1ed70]
  0x562f3707, 0x2b5b5707, 0x49561108, 0x37116b04,   // st.su.mg_432 na.sg.vi_432  ro.mg.to_443 ceb.ro.st_332 
  0x5f67560c, 0x0d2d2955, 0x07021104, 0x48113c0d,   // mg.ak.tn_543 sl.sk.cs_442  ro.da.it_332 ug.ro.tt_554 
  0x112856ac, 0x08330ca7, 0x57002c19, 0x374956ec,   // mg.sw.ro_632 sv.nn.no_532  fy.na.un_750 mg.to.st_644 
  0x651156a7, 0x37565a12, 0x3f20400c, 0x49112807,   // mg.ro.gv_532 sm.mg.st_654  lb.sq.af_543 sw.ro.to_432 
  // [1ed80]
  0x2821180d, 0x69537312, 0x51040807, 0x34352808,   // ar.fa.sd_554 ny.ht.mfe_654  no.fi.kl_432 sw.zu.xh_443 
  0x233c300e, 0x0f3f60ec, 0x69525309, 0x060939ec,   // uz.ug.ky_555 vo.af.lv_644  ht.ha.mfe_444 br.pl.de_644 
  0x4e691f0c, 0x0976690d, 0x222369a0, 0x0757420c,   // cy.mfe.ay_543 mfe.crs.pl_554  mfe.ca.oc_322 co.na.it_543 
  0x73003022, 0x090306a0, 0x31644aa0, 0x42000534,   // uz.ny.un_870 de.nl.pl_322  yo.lg.az_322 fr.co.un_A80 
  // [1ed90]
  0x06000321, 0x4d523bec, 0x242b0204, 0x033f43a0,   // nl.de.un_860 so.ha.aa_644  da.vi.eo_332 ie.af.nl_322 
  0x13003412, 0x230556af, 0x17122d07, 0x0412500c,   // xh.et.un_640 mg.fr.ca_655  sk.hu.sr_432 fj.hu.fi_543 
  0x57005914, 0x0f3639a0, 0x193b5804, 0x19000907,   // rn.na.un_660 br.gn.lv_322  om.so.gl_332 pl.gl.un_420 
  0x1200562a, 0x76002d04, 0x20005912, 0x68095208,   // mg.hu.un_970 sk.crs.un_320  rn.sq.un_640 ha.pl.ig_443 
  // [1eda0]
  0x584c3b14, 0x253b1e0c, 0x25483804, 0x1f3b0a5a,   // so.wo.om_666 ms.so.eu_543  tk.tt.mn_332 pt.so.cy_553 
  0x3b2f4dec, 0x73521ca4, 0x2c330802, 0x53694a0e,   // aa.su.so_644 id.ha.ny_433  no.nn.fy_222 yo.mfe.ht_555 
  0x5369325a, 0x04252e08, 0x350228ad, 0x6509520c,   // bs.mfe.ht_553 fo.eu.fi_443  sw.da.zu_643 ha.pl.gv_543 
  0x1a7308a0, 0x420cfea4, 0x0200302a, 0x07431dad,   // no.ny.tl_322 tlh.sv.co_433  uz.da.un_970 la.ie.it_643 
  // [1edb0]
  0x25001318, 0x4d004e19, 0x330809af, 0x390940af,   // et.eu.un_740 ay.aa.un_750  pl.no.nn_655 lb.pl.br_655 
  0x15fc05ad, 0x554959a9, 0x06091108, 0x0a025607,   // fr.zzp.un_643 rn.to.rw_544  ro.pl.de_443 mg.da.pt_432 
  0x52475c07, 0x0c01020c, 0x17071104, 0x06005504,   // sa.sn.ha_432 da.en.sv_543  ro.bg.sr_332 rw.de.un_320 
  0x3217090c, 0x5f4852a0, 0x5700271b, 0x58601ca4,   // pl.sr.bs_543 ha.tt.tn_322  gd.na.un_770 id.vo.om_433 
  // [1edc0]
  0x31304da9, 0x10475ca4, 0x072401a4, 0x5d000208,   // aa.uz.az_544 sa.sn.lt_433  en.eo.it_433 da.ss.un_430 
  0x3b00522c, 0x635d5ea4, 0x02215c0c, 0x20084ea7,   // ha.so.un_990 ts.ss.sco_433  sa.jw.da_543 ay.no.sq_532 
  0x13041ea4, 0x5e190a09, 0x04241eee, 0x5f6e78ec,   // ms.fi.et_433 pt.gl.ts_444  ms.eo.fi_422 ve.hmn.tn_644 
  0x3229fea7, 0x5c47360c, 0x11152313, 0x3217fe0e,   // tlh.sl.bs_532 gn.sn.sa_543  ky.ro.un_650 tlh.sr.bs_555 
  // [1edd0]
  0x112338af, 0x44111555, 0x2900fe13, 0x2d004c08,   // tk.ky.ro_655 un.ro.kk_442  tlh.sl.un_650 wo.sk.un_430 
  0x022b790e, 0x4a001305, 0x0afe1504, 0x10003820,   // war.vi.da_555 et.yo.un_330  un.tlh.pt_332 tk.be.un_850 
  0x020315a0, 0x58084d04, 0x2d290da9, 0x123c18a7,   // un.nl.da_322 aa.no.om_332  cs.sl.sk_544 ar.ug.ur_532 
  0x20fe0904, 0xfe000908, 0x150c0204, 0x33422a07,   // pl.tlh.sq_332 pl.tlh.un_430  da.sv.un_332 mt.co.nn_432 
  // [1ede0]
  0xfe2d0d04, 0x2000091b, 0x52006108, 0x08093fee,   // cs.sk.tlh_332 pl.sq.un_770  za.ha.un_430 af.pl.no_422 
  0x0961fea4, 0x09006112, 0x092c2daf, 0x4800290d,   // tlh.za.pl_433 za.pl.un_640  sk.fy.pl_655 sl.tt.un_540 
  0x2144340c, 0x2d0d38ed, 0x172d0907, 0x29000205,   // ps.kk.fa_543 tk.cs.sk_622  pl.sk.sr_432 da.sl.un_330 
  0x2029360e, 0x1d025d0c, 0x2d006108, 0x206e090c,   // gn.sl.sq_555 ss.da.la_543  za.sk.un_430 pl.hmn.sq_543 
  // [1edf0]
  0x33390c08, 0x0a233bad, 0x170d2904, 0xfe096e0c,   // sv.br.nn_443 so.ca.pt_643  sl.cs.sr_332 hmn.pl.tlh_543 
  0x29200904, 0x3e190a05, 0x481779ec, 0x2000020d,   // pl.sq.sl_332 pt.gl.rm_333  war.sr.tt_644 da.sq.un_540 
  0x35000212, 0x6b007912, 0x21060207, 0x0a003b0d,   // da.zu.un_640 war.ceb.un_640  da.de.jw_432 so.pt.un_540 
  0x35002a04, 0x48002f08, 0x201143ec, 0x22233b0c,   // mt.zu.un_320 su.tt.un_430  ie.ro.sq_644 so.ca.oc_543 
  // [1ee00]
  0x20472408, 0x011957a0, 0x23441508, 0x30313ba9,   // eo.sn.sq_443 na.gl.en_322  un.kk.ky_443 so.az.uz_544 
  0x024201a0, 0x38023ba4, 0x223b13a9, 0x484630a4,   // en.co.da_322 so.da.tk_433  et.so.oc_544 uz.qu.tt_433 
  0x4d303b0c, 0x3b483012, 0x315851ec, 0x11003721,   // so.uz.aa_543 uz.tt.so_654  kl.om.az_644 ba.ro.un_860 
  0x070a350d, 0x1f002b08, 0x3e003905, 0x283b2104,   // tg.mk.bg_554 vi.cy.un_430  br.rm.un_330 fa.ks.sd_332 
  // [1ee10]
  0x344657a7, 0x5400530e, 0x150c23a4, 0x151f65ad,   // na.qu.xh_532 ht.ik.un_550  ca.sv.un_433 gv.cy.un_643 
  0x030115a0, 0x44483808, 0x0e4c3808, 0x012a0307,   // un.en.nl_322 tk.tt.kk_443  tk.wo.is_443 nl.mt.en_432 
  0x375e7312, 0x066a56ec, 0x62613ea7, 0x353462ec,   // ny.ts.st_654 mg.haw.de_644  rm.za.kha_532 kha.xh.zu_644 
  0x6533250c, 0x04515808, 0x644704a4, 0x48373612,   // eu.nn.gv_543 om.kl.fi_443  fi.sn.lg_433 ab.ba.tt_654 
  // [1ee20]
  0x3b314e07, 0x34004419, 0x017365ee, 0x1d292da4,   // ay.az.so_432 kk.ps.un_750  gv.ny.en_422 sk.sl.la_433 
  0x0e331aa0, 0x0551260d, 0x65042107, 0x4a026a0c,   // tl.nn.is_322 ia.kl.fr_554  jw.fi.gv_432 haw.da.yo_543 
  0x1e1c240e, 0x6224180c, 0x595528a9, 0x24002f1b,   // eo.id.ms_555 ga.eo.kha_543  sw.rw.rn_544 su.eo.un_770 
  0x5a647304, 0x583b0413, 0x302538ad, 0x0a1736ad,   // ny.lg.sm_332 fi.so.om_665  tk.mn.uz_643 ab.sr.mk_643 
  // [1ee30]
  0x3f04130b, 0x27656ba0, 0x2f182704, 0x27182f07,   // et.fi.af_542 ceb.gv.gd_322  gd.ga.su_332 su.ga.gd_432 
  0x35096404, 0x24275605, 0x68006414, 0x7800030e,   // lg.pl.zu_332 mg.gd.eo_333  lg.ig.un_660 nl.ve.un_550 
  0x1c271855, 0x3f005e1a, 0x18650408, 0x2100600d,   // ga.gd.id_442 ts.af.un_760  fi.gv.ga_443 vo.jw.un_540 
  0x56461ea0, 0x02285508, 0x5d004a1a, 0x2c13040b,   // ms.qu.mg_322 rw.sw.da_443  yo.ss.un_760 fi.et.fy_542 
  // [1ee40]
  0x2d005c05, 0x20005b13, 0x1f7962ad, 0x2200500c,   // sa.sk.un_330 sg.sq.un_650  kha.war.cy_643 fj.oc.un_530 
  0x0a300808, 0x2200610d, 0x100a17a9, 0x303412a9,   // uk.uz.mk_443 za.oc.un_540  sr.mk.be_544 ur.ps.uz_544 
  0x05006e07, 0x0efc2e55, 0x0c242e07, 0x05004608,   // hmn.fr.un_420 fo.zzp.is_442  fo.eo.sv_432 qu.fr.un_430 
  0x2e0c3304, 0x3e26110c, 0x21006b04, 0x1b00540e,   // nn.sv.fo_332 ro.ia.rm_543  ceb.jw.un_320 ik.tr.un_550 
  // [1ee50]
  0x28301804, 0xfc004a07, 0x170836a4, 0x320929ee,   // ar.uz.sd_332 yo.zzp.un_420  ab.uk.sr_433 sl.pl.bs_422 
  0x28581c07, 0x03025112, 0x483635ec, 0x4c093855,   // id.om.sw_432 kl.da.nl_654  tg.ab.tt_644 tk.pl.wo_442 
  0x69375305, 0x074830a9, 0x35004a02, 0x353c2307,   // ht.st.mfe_333 uz.tt.bg_544  yo.zu.un_220 ky.ug.tg_432 
  0x040708a7, 0x26601f0c, 0x1f005f09, 0x0229650c,   // uk.bg.ru_532 cy.vo.ia_543  tn.cy.un_440 gv.sl.da_543 
  // [1ee60]
  0x1909360c, 0x5e4f0807, 0x483f0302, 0x072801a4,   // gn.pl.gl_543 no.bi.ts_432  nl.af.tt_222 en.sw.it_433 
  0x285662a9, 0x3f345604, 0x0c2e0205, 0x392960a7,   // kha.mg.sw_544 mg.xh.af_332  da.fo.sv_333 vo.sl.br_532 
  0x10562809, 0x5256280c, 0x2d0603ee, 0x1f5601a0,   // sw.mg.lt_444 sw.mg.ha_543  nl.de.sk_422 en.mg.cy_322 
  0x56001808, 0x224308a4, 0x303715a4, 0x07394209,   // ga.mg.un_430 no.ie.oc_433  un.ba.uz_433 co.br.it_444 
  // [1ee70]
  0x2e122da9, 0xfc402dee, 0x016008a0, 0x251902a0,   // sk.hu.fo_544 sk.lb.zzp_422  no.vo.en_322 da.gl.eu_322 
  0x42515608, 0x0900571b, 0x4b561808, 0x56000d04,   // mg.kl.co_443 na.pl.un_770  ga.mg.mi_443 cs.mg.un_320 
  0x392851a9, 0x2821120e, 0x152510ad, 0x3e134912,   // kl.sw.br_544 ur.fa.sd_555  be.mn.un_643 to.et.rm_654 
  0x49003309, 0x49390407, 0x02135c0c, 0x3e3023a7,   // nn.to.un_440 fi.br.to_432  sa.et.da_543 ca.uz.rm_532 
  // [1ee80]
  0x39230504, 0x4f5a49ad, 0x456e4907, 0x28104f07,   // fr.ca.br_332 to.sm.bi_643  to.hmn.ln_432 bi.lt.sw_432 
  0x52355d55, 0x121b255a, 0x11003826, 0x0c350207,   // ss.zu.ha_442 eu.tr.hu_553  tk.ro.un_930 da.zu.sv_432 
  0x39303408, 0x50001121, 0x693e5ca4, 0x50004902,   // xh.uz.br_443 ro.fj.un_860  sa.rm.mfe_433 to.fj.un_220 
  0x1c002a04, 0x35315c55, 0xfc493e08, 0x311b2908,   // mt.id.un_320 sa.az.zu_442  rm.to.zzp_443 sl.tr.az_443 
  // [1ee90]
  0x2f2527ee, 0x346447a0, 0x17295008, 0x4f004308,   // gd.eu.su_422 sn.lg.xh_322  fj.sl.sr_443 ie.bi.un_430 
  0x041360a4, 0x291317a0, 0x32361707, 0x3d234405,   // vo.et.fi_433 sr.et.sl_322  sr.gn.bs_432 kk.ky.ku_333 
  0x132a4d11, 0xfe00300c, 0x022210ad, 0x2a132f04,   // aa.mt.et_653 uz.tlh.un_530  lt.oc.da_643 su.et.mt_332 
  0x4e36280c, 0x2400fe19, 0x20fe24af, 0x4c003623,   // sw.gn.ay_543 tlh.eo.un_750  eo.tlh.sq_655 gn.wo.un_880 
  // [1eea0]
  0x4d3f1ca4, 0x53734a0c, 0x08123312, 0x5d302504,   // id.af.aa_433 yo.ny.ht_543  nn.hu.no_654 eu.uz.ss_332 
  0x2e0e12a9, 0x222d0a08, 0x120a2da9, 0x233530ad,   // hu.is.fo_544 pt.sk.oc_443  sk.pt.hu_544 uz.tg.ky_643 
  0x0b003f11, 0x06050112, 0x4a002d0d, 0x154301ee,   // af.es.un_630 en.fr.de_654  sk.yo.un_540 en.ie.un_422 
  0x0363250c, 0x2d4a6304, 0x29102d04, 0x0a006913,   // eu.sco.nl_543 sco.yo.sk_332  sk.lt.sl_332 mfe.pt.un_650 
  // [1eeb0]
  0x54585111, 0x49005109, 0x4a32100e, 0x51005819,   // kl.om.ik_653 kl.to.un_440  lt.bs.yo_555 om.kl.un_750 
  0x321016a4, 0x6a005c13, 0x2d1629ee, 0x1d6201a0,   // hr.lt.bs_433 sa.haw.un_650  sl.hr.sk_422 en.kha.la_322 
  0x2f6b79a9, 0x27001e08, 0x3b002723, 0x384812a7,   // war.ceb.su_544 ms.gd.un_430  gd.so.un_880 hu.tt.tk_532 
  0xfe2a6707, 0x16292da6, 0x07301104, 0x36000b23,   // ak.mt.tlh_432 sk.sl.hr_521  ro.uz.bg_332 es.gn.un_880 
  // [1eec0]
  0x3b5852af, 0x0d000f18, 0x04297907, 0x343d3055,   // ha.om.so_655 lv.cs.un_740  war.sl.fi_432 uz.ku.ps_442 
  0x5c004a09, 0x3b48fc02, 0x483810a4, 0x1b00fc0c,   // yo.sa.un_440 zzp.tt.so_222  be.tk.tt_433 zzp.tr.un_530 
  0x37482302, 0x44384808, 0x253530ee, 0x04082555,   // ky.tt.ba_222 tt.tk.kk_443  uz.tg.mn_422 mn.uk.ru_442 
  0x1900fe0c, 0x364e2111, 0x2efe0212, 0x761f2aa4,   // tlh.gl.un_530 jw.ay.gn_653  da.tlh.fo_654 mt.cy.crs_433 
  // [1eed0]
  0x24400204, 0x38002302, 0x1708040d, 0xfc00360d,   // da.lb.eo_332 ca.tk.un_220  ru.uk.sr_554 gn.zzp.un_540 
  0x0c355d0c, 0x100408ee, 0x033e6304, 0x69004008,   // ss.zu.sv_543 uk.ru.be_422  sco.rm.nl_332 lb.mfe.un_430 
  0x46004220, 0x6118470c, 0x225e0a0c, 0x03006118,   // co.qu.un_850 sn.ga.za_543  pt.ts.oc_543 za.nl.un_740 
  0x47032809, 0xfe690207, 0x06404ba0, 0x6365fea0,   // sw.nl.sn_444 da.mfe.tlh_432  mi.lb.de_322 tlh.gv.sco_322 
  // [1eee0]
  0x390861a7, 0x215c580d, 0x3b006a08, 0x17370a08,   // za.no.br_532 om.sa.jw_554  haw.so.un_430 mk.ba.sr_443 
  0x033f7812, 0x651a6bad, 0x2d100d04, 0x3b4b5604,   // ve.af.nl_654 ceb.tl.gv_643  cs.lt.sk_332 mg.mi.so_332 
  0x04380707, 0x6000621b, 0x0e2e3f08, 0x125e02a6,   // bg.tk.ru_432 kha.vo.un_770  af.fo.is_443 da.ts.hu_521 
  0x63004b18, 0x066a0255, 0x785d4712, 0x62001313,   // mi.sco.un_740 da.haw.de_442  sn.ss.ve_654 et.kha.un_650 
  // [1eef0]
  0x34471107, 0x283b1207, 0x6b496a55, 0x0200450e,   // ro.sn.xh_432 ur.ks.sd_432  haw.to.ceb_442 ln.da.un_550 
  0x24002f05, 0x25006b09, 0x530a6507, 0x46004b0d,   // su.eo.un_330 ceb.eu.un_440  gv.pt.ht_432 mi.qu.un_540 
  0x6a4b4912, 0x50005e13, 0x50004b19, 0x172d29a4,   // to.mi.haw_654 ts.fj.un_650  mi.fj.un_750 sl.sk.sr_433 
  0x041538a0, 0x182123ad, 0x794339ee, 0x3f393e0c,   // tk.ru.un_320 ky.fa.ar_643  br.ie.war_422 rm.br.af_543 
  // [1ef00]
  0x42003907, 0x1b393004, 0x1b003110, 0x30166402,   // br.co.un_420 uz.br.tr_332  az.tr.un_620 lg.hr.uz_222 
  0x28004014, 0x42643eee, 0x0438085a, 0x3000250e,   // lb.sw.un_660 rm.lg.co_422  uk.tk.ru_553 mn.uz.un_550 
  0x120959ad, 0x1d482d07, 0x69595505, 0x190a08a4,   // rn.pl.hu_643 sk.tt.la_432  rw.rn.mfe_333 no.pt.gl_433 
  0x0206200c, 0x55002504, 0x3f2f1c05, 0x15354804,   // sq.de.da_543 eu.rw.un_320  id.su.af_333 tt.tg.un_332 
  // [1ef10]
  0x1000020d, 0x382d0d04, 0x1b3848a4, 0x4a1e1c13,   // da.lt.un_540 cs.sk.tk_332  tt.tk.tr_433 id.ms.yo_665 
  0x366504ee, 0x131b40a9, 0x514d25ad, 0x38002f02,   // fi.gv.gn_422 lb.tr.et_544  eu.aa.kl_643 su.tk.un_220 
  0x381b2f08, 0x2f021107, 0x4e46340c, 0x1b13255a,   // su.tr.tk_443 ro.da.su_432  xh.qu.ay_543 eu.et.tr_553 
  0x1b384aad, 0x5d007507, 0x26fc1d08, 0x49000f09,   // yo.tk.tr_643 nso.ss.un_420  la.zzp.ia_443 lv.to.un_440 
  // [1ef20]
  0x521e1c12, 0x57236808, 0x461e1c13, 0x35fe3005,   // id.ms.ha_654 ig.ca.na_443  id.ms.qu_665 uz.tlh.zu_333 
  0x3775fe0c, 0x0d353404, 0x2200071a, 0x242c3bee,   // tlh.nso.st_543 xh.zu.cs_332  it.oc.un_760 so.fy.eo_422 
  0x09643704, 0x3b3f4dee, 0xfe000d05, 0x06003508,   // st.lg.pl_332 aa.af.so_422  cs.tlh.un_330 zu.de.un_430 
  0x35343055, 0x31380da4, 0x17650ca4, 0x61003714,   // uz.xh.zu_442 cs.tk.az_433  sv.gv.sr_433 st.za.un_660 
  // [1ef30]
  0x02fc0107, 0xfc3859a4, 0x290c2504, 0x09200f07,   // en.zzp.da_432 rn.tk.zzp_433  eu.sv.sl_332 lv.sq.pl_432 
  0x4e463bec, 0x0d343511, 0x5d3735a4, 0x3b384607,   // so.qu.ay_644 zu.xh.cs_653  zu.st.ss_433 qu.tk.so_432 
  0x1e1c09a4, 0xfe3435ee, 0x52254eac, 0x29524612,   // pl.id.ms_433 zu.xh.tlh_422  ay.eu.ha_632 qu.ha.sl_654 
  0x1c2f1111, 0x483c305a, 0x79001212, 0x063909a9,   // ro.su.id_653 uz.ug.tt_553  hu.war.un_640 pl.br.de_544 
  // [1ef40]
  0x642a790c, 0x12003913, 0x42073e04, 0x352d73a9,   // war.mt.lg_543 br.hu.un_650  rm.it.co_332 ny.sk.zu_544 
  0x23303855, 0x04023305, 0x1a510207, 0x060a070d,   // tk.uz.ky_442 nn.da.fi_333  da.kl.tl_432 it.pt.de_554 
  0x391109a4, 0x584264ee, 0x0f123904, 0x3517110b,   // pl.ro.br_433 lg.co.om_422  br.hu.lv_332 ro.sr.tg_542 
  0x392a09a0, 0x55073ea4, 0x030c10a0, 0x34645e02,   // pl.mt.br_322 rm.it.rw_433  lt.sv.nl_322 ts.lg.xh_222 
  // [1ef50]
  0x1b65fc08, 0x35004207, 0x553573a0, 0x13330860,   // zzp.gv.tr_443 co.zu.un_420  ny.zu.rw_322 no.nn.et_664 
  0x12003919, 0x734707a4, 0x096529a9, 0x12004708,   // br.hu.un_750 it.sn.ny_433  sl.gv.pl_544 sn.hu.un_430 
  0x481004a4, 0x1f584d12, 0x0430380c, 0x3c150aa4,   // ru.be.tt_433 aa.om.cy_654  tk.uz.ru_543 mk.ug.un_430 
  0x044808ee, 0x11151708, 0x2e004704, 0x471f3b07,   // uk.tt.ru_422 sr.ro.un_430  sn.fo.un_320 so.cy.sn_432 
  // [1ef60]
  0x1f781a08, 0x764f6913, 0x6b6879ee, 0x1f4c37a4,   // tl.ve.cy_443 mfe.bi.crs_665  war.ig.ceb_422 st.wo.cy_433 
  0x5f001f0d, 0x68fe4505, 0x48003119, 0x471f4aee,   // cy.tn.un_540 ln.tlh.ig_333  az.tt.un_750 yo.cy.sn_422 
  0x02fe4a0c, 0x1c004608, 0x392f1f0c, 0x30350a05,   // yo.tlh.da_543 qu.id.un_430  cy.su.br_543 mk.tg.uz_333 
  0x401b3802, 0x3b003f0c, 0x2821300e, 0x33002e14,   // tk.tr.lb_222 af.so.un_530  uz.fa.sd_555 fo.nn.un_660 
  // [1ef70]
  0x58640408, 0x3f3b58a7, 0x463b090b, 0x3f583ba4,   // fi.lg.om_443 om.so.af_532  pl.so.qu_542 so.om.af_433 
  0x34183d13, 0x2000782b, 0x47625e12, 0x47000808,   // ku.ar.ps_665 ve.sq.un_980  ts.kha.sn_654 no.sn.un_430 
  0x793e1ea0, 0x2f13010c, 0x28fc4704, 0x63423e0c,   // ms.rm.war_322 en.et.su_543  sn.zzp.sw_332 rm.co.sco_543 
  0x46381b0c, 0x48383055, 0x457873a4, 0x612f3008,   // tr.tk.qu_543 uz.tk.tt_442  ny.ve.ln_433 uz.su.za_443 
  // [1ef80]
  0x3b5e4c07, 0x3f791aee, 0x455201a0, 0x2100780e,   // wo.ts.so_432 tl.war.af_422  en.ha.ln_322 ve.jw.un_550 
  0x1336fe08, 0x584dfe07, 0x35345e09, 0x38121ba0,   // tlh.gn.et_443 tlh.aa.om_432  ts.xh.zu_444 tr.hu.tk_322 
  0x304d1ba4, 0x51004d04, 0x084425a7, 0x1723385a,   // tr.aa.uz_433 aa.kl.un_320  mn.kk.uk_532 tk.ky.sr_553 
  0x3c2123a7, 0x522f0c11, 0x1d404a5a, 0x5002620c,   // ky.fa.ug_532 sv.su.ha_653  yo.lb.la_553 kha.da.fj_543 
  // [1ef90]
  0x5d00390d, 0x51022b02, 0x07263ba4, 0x3f002b04,   // br.ss.un_540 vi.da.kl_222  so.ia.it_433 vi.af.un_320 
  0x50005321, 0x23383005, 0x3b6a58a9, 0x070a04a9,   // ht.fj.un_860 uz.tk.ky_333  om.haw.so_544 ru.mk.bg_544 
  0x324d2d07, 0x04225aa0, 0x0c504d08, 0x083525a4,   // sk.aa.bs_432 sm.oc.fi_322  aa.fj.sv_443 mn.tg.uk_433 
  0x295c4a12, 0x1d1b2655, 0x3f004904, 0x2a005d0d,   // yo.sa.sl_654 ia.tr.la_442  to.af.un_320 ss.mt.un_540 
  // [1efa0]
  0x39134fee, 0x241e4d04, 0x39353404, 0x13000c13,   // bi.et.br_422 aa.ms.eo_332  xh.zu.br_332 sv.et.un_650 
  0x02631504, 0x34443c0c, 0x28004202, 0x315e39a4,   // un.sco.da_332 ug.kk.ps_543  co.sw.un_220 br.ts.az_433 
  0x22530412, 0x65271860, 0x13420412, 0x4e210ea4,   // fi.ht.oc_654 ga.gd.gv_664  fi.co.et_654 is.jw.ay_433 
  0x0e003502, 0x5c644c14, 0x15001708, 0x2a321708,   // zu.is.un_220 wo.lg.sa_666  sr.un.un_430 sr.bs.mt_443 
  // [1efb0]
  0x32200ea7, 0x5d35faac, 0x6300221a, 0x2e0251a4,   // is.sq.bs_532 nr.zu.ss_632  oc.sco.un_760 kl.da.fo_433 
  0x5f2a75a0, 0x3f600107, 0x3e114705, 0x441823a9,   // nso.mt.tn_322 en.vo.af_432  sn.ro.rm_333 ky.ar.kk_544 
  0x29002a12, 0x652223ee, 0x46524e07, 0x0e384ea0,   // mt.sl.un_640 ca.oc.gv_422  ay.ha.qu_432 ay.tk.is_322 
  0x2200080d, 0x403f03ad, 0xfe00251a, 0x3800300d,   // no.oc.un_540 nl.af.lb_643  eu.tlh.un_760 uz.tk.un_540 
  // [1efc0]
  0x292e3307, 0x1d2305a4, 0x2e2333a0, 0x39000c0d,   // nn.fo.sl_432 fr.ca.la_433  nn.ca.fo_322 sv.br.un_540 
  0x1c003412, 0x09003305, 0x20372a08, 0x23fc1307,   // xh.id.un_640 nn.pl.un_330  mt.st.sq_443 et.zzp.ca_432 
  0x57671ea0, 0x2a6562a7, 0x2a0522a9, 0x39532408,   // ms.ak.na_322 kha.gv.mt_532  oc.fr.mt_544 eo.ht.br_443 
  0x1b1f6004, 0x063f0309, 0x045851a4, 0x2300020c,   // vo.cy.tr_332 nl.af.de_444  kl.om.fi_433 da.ca.un_530 
  // [1efd0]
  0xfc634ba7, 0x24602d0c, 0x3800060d, 0x0a135c0c,   // mi.sco.zzp_532 sk.vo.eo_543  de.tk.un_540 sa.et.pt_543 
  0x29601b12, 0x0200fc1a, 0x35344ba4, 0x795142a4,   // tr.vo.sl_654 zzp.da.un_760  mi.xh.zu_433 co.kl.war_433 
  0xfc1a27a0, 0x6500fc23, 0x1530380d, 0x303c36ad,   // gd.tl.zzp_322 zzp.gv.un_880  tk.uz.un_554 ab.ug.uz_643 
  0x0afc2404, 0x5f006805, 0x24000117, 0x060312a9,   // eo.zzp.pt_332 ig.tn.un_330  iw.yi.un_730 hu.nl.de_544 
  // [1efe0]
  0x11131bee, 0x0603120c, 0x123d3b11, 0x123d1812,   // tr.et.ro_422 hu.nl.de_543  ks.ku.ur_653 ar.ku.ur_654 
  0x0c153ba7, 0x58fe52a0, 0x67000e19, 0x5d212fad,   // so.sv.un_520 ha.tlh.om_322  is.ak.un_750 su.jw.ss_643 
  0x3800521a, 0x33fe0e07, 0xfe2d0d0e, 0x313035a0,   // ha.tk.un_760 is.tlh.nn_432  cs.sk.tlh_555 zu.uz.az_322 
  0x34007512, 0x12003507, 0x16330808, 0xfe00240d,   // nso.xh.un_640 zu.hu.un_420  no.nn.hr_443 eo.tlh.un_540 
  // [1eff0]
  0x482d0907, 0x48fe0955, 0x0d2dfea7, 0xfe0e1b60,   // pl.sk.tt_432 pl.tlh.tt_442  tlh.sk.cs_532 tr.is.tlh_664 
  0x48001808, 0x10084460, 0x381d260d, 0x07fe2a02,   // ga.tt.un_430 kk.uk.be_664  ia.la.tk_554 mt.tlh.it_222 
  0x1d1140a4, 0x28791ea0, 0x2d090d0c, 0x427605ac,   // lb.ro.la_433 ms.war.sw_322  cs.pl.sk_543 fr.crs.co_632 
  0x2b452704, 0x5c1f1da0, 0x3b2f2a0c, 0x25007304,   // gd.ln.vi_332 la.cy.sa_322  mt.su.so_543 ny.eu.un_320 
  
  // [1f000]
  0x311f43a0, 0x22054fa0, 0x393e11ad, 0x02004818,   // ie.cy.az_322 bi.fr.oc_322  ro.rm.br_643 tt.da.un_740 
  0x5c6050a9, 0x63001d0e, 0x63101508, 0x24565c0d,   // fj.vo.sa_544 la.sco.un_550  un.lt.sco_443 sa.mg.eo_554 
  0x53005a02, 0x201f13ee, 0x3b235802, 0x202a42ee,   // sm.ht.un_220 et.cy.sq_422  om.ca.so_222 co.mt.sq_422 
  0x10640e02, 0x0f135cad, 0x2a5261a7, 0x2e4d0e08,   // is.lg.lt_222 sa.et.lv_643  za.ha.mt_532 is.aa.fo_443 
  // [1f010]
  0x24071da0, 0x08335cad, 0x3212560c, 0x64505cad,   // la.it.eo_322 sa.nn.no_643  mg.hu.bs_543 sa.fj.lg_643 
  0x37303c12, 0x5a34560d, 0x64504704, 0x045c13ec,   // ug.uz.ba_654 mg.xh.sm_554  sn.fj.lg_332 et.sa.fi_644 
  0x21182855, 0x3b5e5502, 0x6300fc0c, 0x3d3c2309,   // sd.ar.fa_442 rw.ts.so_222  zzp.sco.un_530 ky.ug.ku_444 
  0x3f036904, 0x1834120b, 0x2f461a0c, 0x49006a13,   // mfe.nl.af_332 ur.ps.ar_542  tl.qu.su_543 haw.to.un_650 
  // [1f020]
  0x35343b09, 0x55467305, 0x170436a0, 0x183034ec,   // so.xh.zu_444 ny.qu.rw_333  ab.ru.sr_322 ps.uz.ar_644 
  0x04001113, 0x27005c07, 0x65005c22, 0x13033fa0,   // ro.ru.un_650 sa.gd.un_420  sa.gv.un_870 af.nl.et_322 
  0x28353460, 0x1c003905, 0x52fc2a55, 0x525630a4,   // xh.zu.sw_664 br.id.un_330  mt.zzp.ha_442 uz.mg.ha_433 
  0x2e046708, 0x53001a0c, 0x4f1e5bee, 0x4d002608,   // ak.fi.fo_443 tl.ht.un_530  sg.ms.bi_422 ia.aa.un_430 
  // [1f030]
  0x57002523, 0x04134504, 0xfc0564a4, 0x33000611,   // eu.na.un_880 ln.et.fi_332  lg.fr.zzp_433 de.nn.un_630 
  0x2b000d07, 0x49005713, 0x0a040809, 0x2f1c69a9,   // cs.vi.un_420 na.to.un_650  uk.ru.mk_444 mfe.id.su_544 
  0xfc041313, 0x534651a0, 0x062643ec, 0x083f330d,   // et.fi.zzp_665 kl.qu.ht_322  ie.ia.de_644 nn.af.no_554 
  0x1900fc12, 0xfc240e0c, 0x042e0308, 0x64583baf,   // zzp.gl.un_640 is.eo.zzp_543  nl.fo.fi_443 so.om.lg_655 
  // [1f040]
  0x65120807, 0x04084804, 0x1e3f4dee, 0x6702130c,   // no.hu.gv_432 tt.uk.ru_332  aa.af.ms_422 et.da.ak_543 
  0x1b4831ee, 0x734a0a05, 0x09453805, 0x025e20a4,   // az.tt.tr_422 pt.yo.ny_333  tk.ln.pl_333 sq.ts.da_433 
  0x59207308, 0x4373200c, 0x597301a4, 0x08203611,   // ny.sq.rn_443 sq.ny.ie_543  en.ny.rn_433 gn.sq.no_653 
  0x365020ad, 0x5c202907, 0x2000470d, 0x23223609,   // sq.fj.gn_643 sl.sq.sa_432  sn.sq.un_540 gn.oc.ca_444 
  // [1f050]
  0x32074207, 0x73006714, 0x640236ee, 0x534720ee,   // co.it.bs_432 ak.ny.un_660  gn.da.lg_422 sq.sn.ht_422 
  0x4900361a, 0x2336200c, 0x1b362011, 0x5e203655,   // gn.to.un_760 sq.gn.ca_543  sq.gn.tr_653 gn.sq.ts_442 
  0x03001b04, 0x13103ba9, 0x560418a4, 0x291a61a9,   // tr.nl.un_320 so.lt.et_544  ga.fi.mg_433 za.tl.sl_544 
  0x2461480c, 0x023b1f0d, 0x1d003b05, 0xfc002e04,   // tt.za.eo_543 cy.so.da_554  so.la.un_330 fo.zzp.un_320 
  // [1f060]
  0x3b130407, 0x6b006109, 0x3b095807, 0x5c1e6105,   // fi.et.so_432 za.ceb.un_440  om.pl.so_432 za.ms.sa_333 
  0x04545109, 0x1b313b0e, 0x03136407, 0x190a2314,   // kl.ik.fi_444 so.az.tr_555  lg.et.nl_432 ca.pt.gl_666 
  0x0a1923ad, 0x38330814, 0x53005204, 0x276b62ee,   // ca.gl.pt_643 no.nn.tk_666  ha.ht.un_320 kha.ceb.gd_422 
  0x25133907, 0x31023809, 0x2d0d1502, 0x314d61a7,   // br.et.eu_432 tk.da.az_444  un.cs.sk_222 za.aa.az_532 
  // [1f070]
  0x6a002805, 0x29286aa9, 0x2d0d25a0, 0x285230a9,   // sw.haw.un_330 haw.sw.sl_544  eu.cs.sk_322 uz.ha.sw_544 
  0x3f1304ad, 0x2a003509, 0x2f20fea0, 0x6b595509,   // fi.et.af_643 zu.mt.un_440  tlh.sq.su_322 rw.rn.ceb_444 
  0x79002307, 0xfe555c12, 0x25122d05, 0x17370a02,   // ca.war.un_420 sa.rw.tlh_654  sk.hu.eu_333 mk.ba.sr_222 
  0x15043812, 0x352a4dac, 0x29257904, 0x464b6a05,   // tk.ru.un_654 aa.mt.zu_632  war.eu.sl_332 haw.mi.qu_333 
  // [1f080]
  0x2d250d02, 0x2f00fe05, 0x342c3fee, 0x0a10170b,   // cs.eu.sk_222 tlh.su.un_330  af.fy.xh_422 sr.be.mk_542 
  0x04104407, 0x1a001b22, 0x042508a0, 0x53001f05,   // kk.be.ru_432 tr.tl.un_870  uk.mn.ru_322 cy.ht.un_330 
  0x070415ec, 0x603801a0, 0x1d695312, 0x55003813,   // un.ru.bg_644 en.tk.vo_322  ht.mfe.la_654 tk.rw.un_650 
  0x13003119, 0x32170faf, 0x291827a6, 0x0100060c,   // az.et.un_750 lv.sr.bs_655  gd.ga.sl_521 de.en.un_530 
  // [1f090]
  0x34001d0b, 0x386b1aa4, 0x1844230e, 0x17005504,   // la.xh.un_520 tl.ceb.tk_433  ky.kk.ar_555 rw.sr.un_320 
  0x0b0a2309, 0x1d4301a4, 0x016002a9, 0x6b4d3855,   // ca.pt.es_444 en.ie.la_433  da.vo.en_544 tk.aa.ceb_442 
  0x0c3140ad, 0x7923010c, 0x731c0912, 0x32000308,   // lb.az.sv_643 en.ca.war_543  pl.id.ny_654 nl.bs.un_430 
  0x28583b11, 0x0f1017a0, 0x23071d07, 0x60224fa4,   // so.om.sw_653 sr.lt.lv_322  la.it.ca_432 bi.oc.vo_433 
  // [1f0a0]
  0xfc001005, 0x021d1004, 0x01630207, 0x52000905,   // lt.zzp.un_330 lt.la.da_332  da.sco.en_432 pl.ha.un_330 
  0x0d3f4f04, 0x211e2f08, 0x04000a0e, 0x2c400302,   // bi.af.cs_332 su.ms.jw_443  mk.ru.un_550 nl.lb.fy_222 
  0x2e5862ad, 0x2a302e07, 0x313f04a0, 0x4000030b,   // kha.om.fo_643 fo.uz.mt_432  fi.af.az_322 nl.lb.un_520 
  0x47002e04, 0x21123d05, 0x0a230755, 0x1a5c79a0,   // fo.sn.un_320 ku.ur.fa_333  bg.ky.mk_442 war.sa.tl_322 
  // [1f0b0]
  0x5800280e, 0x2e4d310d, 0x2000390c, 0x63281808,   // sw.om.un_550 az.aa.fo_554  br.sq.un_530 ga.sw.sco_443 
  0x13113102, 0x511d18a4, 0x65182760, 0x13046aa4,   // az.ro.et_222 ga.la.kl_433  gd.ga.gv_664 haw.fi.et_433 
  0x30651104, 0x432718a4, 0x154423a4, 0x051801a4,   // ro.gv.uz_332 ga.gd.ie_433  ky.kk.un_433 en.ga.fr_433 
  0x2e353413, 0x271d1808, 0x5d51540c, 0x12004707,   // xh.zu.fo_665 ga.la.gd_443  ik.kl.ss_543 sn.hu.un_420 
  // [1f0c0]
  0x040a1709, 0x02182711, 0x18fc11a4, 0x34002321,   // sr.mk.ru_444 gd.ga.da_653  ro.zzp.ga_433 ky.ps.un_860 
  0x0900fe12, 0x1200240c, 0x4d161fa4, 0x2900130e,   // tlh.pl.un_640 eo.hu.un_530  cy.hr.aa_433 et.sl.un_550 
  0x4a5c0204, 0x5500611a, 0xfe00620c, 0x3c2335a4,   // da.sa.yo_332 za.rw.un_760  kha.tlh.un_530 tg.ky.ug_433 
  0x06651fad, 0x251f17a0, 0x5c005913, 0x5c4d0fad,   // cy.gv.de_643 sr.cy.eu_322  rn.sa.un_650 lv.aa.sa_643 
  // [1f0d0]
  0x5600430c, 0x79002d0e, 0x42000912, 0x35231155,   // ie.mg.un_530 sk.war.un_550  pl.co.un_640 ro.ky.tg_442 
  0x56000408, 0x02396007, 0x1700730b, 0x480a2302,   // fi.mg.un_430 vo.br.da_432  ny.sr.un_520 ky.mk.tt_222 
  0x2d0329a0, 0x0f001705, 0x0b2d1907, 0x191242a0,   // sl.nl.sk_322 sr.lv.un_330  gl.sk.es_432 co.hu.gl_322 
  0x39002907, 0x0a25430c, 0x4410080e, 0x10170fa0,   // sl.br.un_420 ie.eu.pt_543  uk.be.kk_555 lv.sr.lt_322 
  // [1f0e0]
  0x170d29a4, 0x735d28ee, 0x1d1f1112, 0x2b005614,   // sl.cs.sr_433 sw.ss.ny_422  ro.cy.la_654 mg.vi.un_660 
  0x650839a0, 0x3000680b, 0x351a3e04, 0x35645da0,   // br.no.gv_322 ig.uz.un_520  rm.tl.zu_332 ss.lg.zu_322 
  0x24006507, 0x652b2512, 0x56003905, 0x2f050dac,   // gv.eo.un_420 eu.vi.gv_654  br.mg.un_330 cs.fr.su_632 
  0x3e000a0c, 0x562b2cac, 0x5c002e05, 0x2b005613,   // pt.rm.un_530 fy.vi.mg_632  fo.sa.un_330 mg.vi.un_650 
  // [1f0f0]
  0x2b002c1a, 0x3f031fee, 0x4f052f09, 0x053b1fa7,   // fy.vi.un_760 cy.nl.af_422  su.fr.bi_444 cy.so.fr_532 
  0x33026402, 0x033f1f55, 0x3315650d, 0x35525e0d,   // lg.da.nn_222 cy.af.nl_442  gv.nn.un_540 ts.ha.zu_554 
  0x100f1707, 0x56002813, 0x69023908, 0x246106a4,   // sr.lv.lt_432 sw.mg.un_650  br.da.mfe_443 de.za.eo_433 
  0x5a004708, 0x5300690b, 0x6700780e, 0xfc1f02a0,   // sn.sm.un_430 mfe.ht.un_520  ve.ak.un_550 da.cy.zzp_322 
  // [1f100]
  0x65002c0c, 0x0e1f1b11, 0x39570608, 0x2544100c,   // fy.gv.un_530 tr.cy.is_653  de.na.br_443 be.kk.mn_543 
  0x36000f13, 0x0e52580c, 0x07430e04, 0x0900250d,   // lv.gn.un_650 om.ha.is_543  is.ie.it_332 eu.pl.un_540 
  0x050426a9, 0x18042709, 0x3e5c1812, 0x65002e09,   // ia.fi.fr_544 gd.fi.ga_444  ga.sa.rm_654 fo.gv.un_440 
  0x18023e07, 0x04251108, 0x183e27a4, 0x36670a04,   // rm.da.ga_432 ro.eu.fi_443  gd.rm.ga_433 pt.ak.gn_332 
  // [1f110]
  0x0a1015a4, 0x0f1009ee, 0x1f6336a0, 0x40051107,   // un.be.mk_433 pl.lt.lv_422  gn.sco.cy_322 ro.fr.lb_432 
  0x110522a9, 0x6b611d12, 0x0f153eac, 0x132306a0,   // oc.fr.ro_544 la.za.ceb_654  rm.lv.un_620 de.ca.et_322 
  0x2f1c25a6, 0x693b01a0, 0x111e24ee, 0x0e2e0ca6,   // eu.id.su_521 en.so.mfe_322  eo.ms.ro_422 sv.fo.is_521 
  0x3f0e2e55, 0x2f1a210c, 0x4a1d360c, 0x1f00390e,   // fo.is.af_442 jw.tl.su_543  gn.la.yo_543 br.cy.un_550 
  // [1f120]
  0x37003913, 0x793b25ad, 0xfe00690d, 0x2307370c,   // br.st.un_650 eu.so.war_643  mfe.tlh.un_540 ba.bg.ky_543 
  0xfc003609, 0x5d691f12, 0x23181204, 0x0b005904,   // gn.zzp.un_440 cy.mfe.ss_654  ur.ar.ky_332 rn.es.un_320 
  0x4d0e2e08, 0x53631f04, 0x2d0a05a4, 0x2e5a22a7,   // fo.is.aa_443 cy.sco.ht_332  fr.pt.sk_433 oc.sm.fo_532 
  0x1a0a64a0, 0x07042312, 0x012769a7, 0x2a1f39a4,   // lg.pt.tl_322 ky.ru.bg_654  mfe.gd.en_532 br.cy.mt_433 
  // [1f130]
  0x4a005204, 0x253b4d0c, 0x06002e0c, 0x075236a4,   // ha.yo.un_320 aa.so.eu_543  fo.de.un_530 gn.ha.it_433 
  0x56284908, 0x28514f12, 0x682afea4, 0x3ffe5fa9,   // to.sw.mg_443 bi.kl.sw_654  tlh.mt.ig_433 tn.tlh.af_544 
  0x39001802, 0x170a37a4, 0x270402ad, 0x4035550c,   // ga.br.un_220 ba.mk.sr_433  da.fi.gd_643 rw.zu.lb_543 
  0x48153808, 0x1d35fc0b, 0x1025220c, 0x31431b04,   // tk.tt.un_430 zzp.zu.la_542  oc.eu.lt_543 tr.ie.az_332 
  // [1f140]
  0x691c1ea4, 0x1f272eec, 0x56221ca4, 0xfe5e3508,   // ms.id.mfe_433 fo.gd.cy_644  id.oc.mg_433 zu.ts.tlh_443 
  0x052f210d, 0x39062eee, 0x51211ea0, 0x13564707,   // jw.su.fr_554 fo.de.br_422  ms.jw.kl_322 sn.mg.et_432 
  0x312a3004, 0x09003008, 0x73475e55, 0xfc1d63ad,   // uz.mt.az_332 uz.pl.un_430  ts.sn.ny_442 sco.la.zzp_643 
  0x0a1730a4, 0x231711ee, 0x5c003405, 0x78584705,   // uz.sr.mk_433 ro.sr.ky_422  xh.sa.un_330 sn.om.ve_333 
  // [1f150]
  0x07083008, 0x52281304, 0x34282314, 0x3b404c0c,   // uz.uk.bg_443 et.sw.ha_332  ky.sd.ps_666 wo.lb.so_543 
  0x101b30ad, 0x483055ee, 0x21052fa4, 0x02545c13,   // uz.tr.lt_643 rw.uz.tt_422  su.fr.jw_433 sa.ik.da_665 
  0x23443855, 0x21285ea7, 0x4c0928a0, 0x465c6b55,   // tk.kk.ky_442 ts.sw.jw_532  sw.pl.wo_322 ceb.sa.qu_442 
  0x4c00130e, 0x384b6a12, 0x22007909, 0x024b5705,   // et.wo.un_550 haw.mi.tk_654  war.oc.un_440 na.mi.da_333 
  // [1f160]
  0x390a2b07, 0x47004c0d, 0x51001d09, 0x04073805,   // vi.pt.br_432 wo.sn.un_540  la.kl.un_440 tk.bg.ru_333 
  0x095e2808, 0x30313807, 0x5300090d, 0x50002107,   // sw.ts.pl_443 tk.az.uz_432  pl.ht.un_540 jw.fj.un_420 
  0x1c215ea0, 0x27004002, 0x481b4504, 0x4e285eaf,   // ts.jw.id_322 lb.gd.un_220  ln.tr.tt_332 ts.sw.ay_655 
  0x070a30ad, 0x55345104, 0x023b5155, 0x3046fe12,   // uz.mk.bg_643 kl.xh.rw_332  kl.so.da_442 tlh.qu.uz_654 
  // [1f170]
  0x355c34ee, 0x154b3955, 0x764205ac, 0x3e113908,   // xh.sa.zu_422 br.mi.un_442  fr.co.crs_632 br.ro.rm_443 
  0x0f001a04, 0x533905a0, 0x10053911, 0x7600390c,   // tl.lv.un_320 fr.br.ht_322  br.fr.lt_653 br.crs.un_530 
  0x30004621, 0xfe005129, 0x21024aad, 0x32000608,   // qu.uz.un_860 kl.tlh.un_960  yo.da.jw_643 de.bs.un_430 
  0x1b0c5708, 0x033f67ec, 0x52003b0c, 0x080203af,   // na.sv.tr_443 ak.af.nl_644  so.ha.un_530 nl.da.no_655 
  // [1f180]
  0x3f00080d, 0x4d2a300c, 0x170208a4, 0x693976af,   // no.af.un_540 uz.mt.aa_543  no.da.sr_433 crs.br.mfe_655 
  0x30fe5111, 0x3e006512, 0x25001304, 0x035102af,   // kl.tlh.uz_653 gv.rm.un_640  et.eu.un_320 da.kl.nl_655 
  0x0800340c, 0x162a5507, 0x33090207, 0x391b1204,   // xh.no.un_530 rw.mt.hr_432  da.pl.nn_432 hu.tr.br_332 
  0x3b48300c, 0x07424dee, 0x760539a9, 0x50001c04,   // uz.tt.so_543 aa.co.it_422  br.fr.crs_544 id.fj.un_320 
  // [1f190]
  0x07264205, 0x4b1139ad, 0x0e2465a0, 0x06306108,   // co.ia.it_333 br.ro.mi_643  gv.eo.is_322 za.uz.de_443 
  0x4d2f1c11, 0x1576010b, 0x42054bee, 0x07033bee,   // id.su.aa_653 en.crs.un_542  mi.fr.co_422 so.nl.it_422 
  0x13480cec, 0x65275fa4, 0x3f190a14, 0x73005a08,   // sv.tt.et_644 tn.gd.gv_433  pt.gl.af_666 sm.ny.un_430 
  0x6a123808, 0x26451d08, 0x38121b07, 0x2900420c,   // tk.hu.haw_443 la.ln.ia_443  tr.hu.tk_432 co.sl.un_530 
  // [1f1a0]
  0xfc00040d, 0x0b570807, 0x48307314, 0x1b38570c,   // fi.zzp.un_540 no.na.es_432  ny.uz.tt_666 na.tk.tr_543 
  0x28183ba6, 0x211228af, 0x031f3011, 0x110e39a0,   // ks.ar.sd_521 sd.ur.fa_655  uz.cy.nl_653 br.is.ro_322 
  0x30761c0c, 0x1b3b570c, 0x537957ad, 0x28004908,   // id.crs.uz_543 na.so.tr_543  na.war.ht_643 to.sw.un_430 
  0x1d4924a7, 0x526b670c, 0x2e0e62ec, 0x402558a0,   // eo.to.la_532 ak.ceb.ha_543  kha.is.fo_644 om.eu.lb_322 
  // [1f1b0]
  0x042c38a0, 0x0e3f6204, 0x115a45a0, 0x62003322,   // tk.fy.fi_322 kha.af.is_332  ln.sm.ro_322 nn.kha.un_870 
  0x5a4022a0, 0x044939af, 0x09005105, 0x3b3830a7,   // oc.lb.sm_322 br.to.fi_655  kl.pl.un_330 uz.tk.so_532 
  0x565e73a4, 0x76000808, 0x48fc4d0c, 0x383f2c08,   // ny.ts.mg_433 no.crs.un_430  aa.zzp.tt_543 fy.af.tk_443 
  0x650451ee, 0x083362ad, 0x691d3e08, 0x60393e0c,   // kl.fi.gv_422 kha.nn.no_643  rm.la.mfe_443 rm.br.vo_543 
  // [1f1c0]
  0x5700fc13, 0x1d76690c, 0x080239af, 0x583b64af,   // zzp.na.un_650 mfe.crs.la_543  br.da.no_655 lg.so.om_655 
  0x19215eee, 0x1007360c, 0x62020c05, 0x10480404,   // ts.jw.gl_422 ab.bg.be_543  sv.da.kha_333 ru.tt.be_332 
  0x36001021, 0x58006b0c, 0x3e390107, 0x0d0f10a4,   // be.ab.un_860 ceb.om.un_530  en.br.rm_432 lt.lv.cs_433 
  0x495a4708, 0x270401a0, 0x62046b0c, 0x3b033fa9,   // sn.sm.to_443 en.fi.gd_322  ceb.fi.kha_543 af.nl.so_544 
  // [1f1d0]
  0x27000402, 0x27621813, 0x3b040307, 0x0f004f09,   // fi.gd.un_220 ga.kha.gd_665  nl.fi.so_432 bi.lv.un_440 
  0x1f6b3ea0, 0x0f181008, 0x0418270c, 0x27101f0e,   // rm.ceb.cy_322 lt.ga.lv_443  gd.ga.fi_543 cy.lt.gd_555 
  0x01632707, 0x3000361a, 0x65041fa0, 0x57001922,   // gd.sco.en_432 ab.uz.un_760  cy.fi.gv_322 gl.na.un_870 
  0x22100f04, 0x425a2707, 0x1e18270c, 0x63fc010c,   // lv.lt.oc_332 gd.sm.co_432  gd.ga.ms_543 en.zzp.sco_543 
  // [1f1e0]
  0x18282113, 0x30001818, 0x30073c08, 0x30002120,   // fa.sd.ar_665 ar.uz.un_740  ug.bg.uz_443 fa.uz.un_850 
  0x20005d22, 0x495a5d0d, 0x2d002019, 0x47492008,   // ss.sq.un_870 ss.sm.to_554  sq.sk.un_750 sq.to.sn_443 
  0x103b38a6, 0x15005e08, 0x501020ee, 0x04132f07,   // tk.so.lt_521 ts.un.un_430  sq.lt.fj_422 su.et.fi_432 
  0x12532007, 0x47020807, 0x2913040b, 0x2000420e,   // sq.ht.hu_432 no.da.sn_432  fi.et.sl_542 co.sq.un_550 
  // [1f1f0]
  0x170423ad, 0x5a49360c, 0x430115ee, 0x0c003813,   // ky.ru.sr_643 gn.to.sm_543  un.en.ie_422 tk.sv.un_650 
  0x2920365a, 0x29322008, 0x295d20a4, 0x362d20ee,   // gn.sq.sl_553 sq.bs.sl_443  sq.ss.sl_433 sq.sk.gn_422 
  0x302f2360, 0x33380cee, 0x0462025a, 0x0b074fa0,   // ca.su.uz_664 sv.tk.nn_422  da.kha.fi_553 bi.it.es_322 
  0x291531a4, 0x423907a0, 0x226b1dee, 0x475113a4,   // az.sl.un_430 it.br.co_322  la.ceb.oc_422 et.kl.sn_433 
  // [1f200]
  0x735f780c, 0x271f63ad, 0x1d0163a0, 0x4b005107,   // ve.tn.ny_543 sco.cy.gd_643  sco.en.la_322 kl.mi.un_420 
  0x0a0735af, 0x391ffc07, 0x25040aa4, 0x154f0104,   // tg.bg.mk_655 zzp.cy.br_432  mk.ru.mn_433 en.bi.un_332 
  0x65631fad, 0x116a5a07, 0x046a5a0c, 0x5f552804,   // cy.sco.gv_643 sm.haw.ro_432  sm.haw.fi_543 sw.rw.tn_332 
  0x49025aee, 0x04000205, 0x1e0e2e0c, 0x01002e0c,   // sm.da.to_422 da.fi.un_330  fo.is.ms_543 fo.en.un_530 
  // [1f210]
  0x2e423e5a, 0x28251102, 0x115a0411, 0x4b1165a0,   // rm.co.fo_553 ro.eu.sw_222  fi.sm.ro_653 gv.ro.mi_322 
  0x25115a0b, 0x04001102, 0x07300aa7, 0x2f5a1304,   // sm.ro.eu_542 ro.fi.un_220  mk.uz.bg_532 et.sm.su_332 
  0x2d12360d, 0x5f005e04, 0x3f2c4d07, 0x4c2c1308,   // gn.hu.sk_554 ts.tn.un_320  aa.fy.af_432 et.fy.wo_443 
  0x3b0440a4, 0x2f004202, 0x34330607, 0x3c001713,   // lb.fi.so_433 co.su.un_220  de.nn.xh_432 sr.ug.un_650 
  // [1f220]
  0x3f033b0c, 0x6b1a4ca9, 0x3f4a7907, 0x210e2fa9,   // so.nl.af_543 wo.tl.ceb_544  war.yo.af_432 su.is.jw_544 
  0x07110a07, 0x4a033f12, 0x1a003b12, 0x65330808,   // mk.ro.bg_432 af.nl.yo_654  so.tl.un_640 no.nn.gv_443 
  0x04131aec, 0x404c6b02, 0x44081055, 0x583b4c0d,   // tl.et.fi_644 ceb.wo.lb_222  be.uk.kk_442 wo.so.om_554 
  0x370436a0, 0x444810ac, 0x022031a4, 0x4d3054ec,   // ab.ru.ba_322 be.tt.kk_632  az.sq.da_433 ik.uz.aa_644 
  // [1f230]
  0x54463013, 0x61004614, 0x3031fead, 0x2a30315a,   // uz.qu.ik_665 qu.za.un_660  tlh.az.uz_643 az.uz.mt_553 
  0x46111d07, 0x11005408, 0x252336a7, 0x024f4b08,   // la.ro.qu_432 ik.ro.un_430  ab.ky.mn_532 mi.bi.da_443 
  0x314861a6, 0x3e024205, 0x30006114, 0x46303111,   // za.tt.az_521 co.da.rm_333  za.uz.un_660 az.uz.qu_653 
  0x30542055, 0x31304612, 0x2300370b, 0x0c300807,   // sq.ik.uz_442 qu.uz.az_654  ba.ky.un_520 no.uz.sv_432 
  // [1f240]
  0x4630fe0c, 0x61463108, 0x2247230d, 0x47105002,   // tlh.uz.qu_543 az.qu.za_443  ca.sn.oc_554 fj.lt.sn_222 
  0x35040aaf, 0x5d1e0da4, 0x3f00510b, 0x3b4d58a4,   // mk.ru.tg_655 cs.ms.ss_433  kl.af.un_520 om.aa.so_433 
  0x47101d04, 0x3500fe0c, 0x37005e07, 0x3b584d09,   // la.lt.sn_332 tlh.zu.un_530  ts.st.un_420 aa.om.so_444 
  0x404c640c, 0x64513b14, 0x2f653b55, 0x2d5d35a4,   // lg.wo.lb_543 so.kl.lg_666  so.gv.su_442 zu.ss.sk_433 
  // [1f250]
  0x12302111, 0x4d003b2a, 0x0451540c, 0x643b4ca9,   // fa.uz.ur_653 so.aa.un_970  ik.kl.fi_543 wo.so.lg_544 
  0x644d51a9, 0x31005d14, 0x2efc3804, 0x31fe3709,   // kl.aa.lg_544 ss.az.un_660  tk.zzp.fo_332 st.tlh.az_444 
  0x4d3b51a9, 0x01361f08, 0x2d360daf, 0x0d6b79a0,   // kl.so.aa_544 cy.gn.en_443  cs.gn.sk_655 war.ceb.cs_322 
  0x115e0702, 0x6b1a1509, 0x09385305, 0x1e110ba0,   // it.ts.ro_222 un.tl.ceb_444  ht.tk.pl_333 es.ro.ms_322 
  // [1f260]
  0x5c796b04, 0x1b4810ad, 0x68011da4, 0x10002c12,   // ceb.war.sa_332 lt.tt.tr_643  la.en.ig_433 fy.lt.un_640 
  0x3e0d0fa4, 0x505212ee, 0x28733509, 0x0e2a1004,   // lv.cs.rm_433 hu.ha.fj_422  zu.ny.sw_444 lt.mt.is_332 
  0x224034a0, 0xfc6b45a4, 0x152202a4, 0x56000911,   // xh.lb.oc_322 ln.ceb.zzp_433  da.oc.un_433 pl.mg.un_630 
  0x07002b02, 0x01001e07, 0x56366308, 0x271861a4,   // vi.it.un_220 ms.en.un_420  sco.gn.mg_443 za.ga.gd_433 
  // [1f270]
  0x253456ad, 0x565f37a9, 0x020f10a9, 0x19270aa4,   // mg.xh.eu_643 st.tn.mg_544  lt.lv.da_544 pt.gd.gl_433 
  0x186a5404, 0x244213ad, 0x13004712, 0x54006113,   // ik.haw.ga_332 et.co.eo_643  sn.et.un_640 za.ik.un_650 
  0x5f732504, 0x5e006e22, 0x1f0410ee, 0xfc2573a7,   // eu.ny.tn_332 hmn.ts.un_870  lt.fi.cy_422 ny.eu.zzp_532 
  0x0a173008, 0x65053ea7, 0xfc656ea0, 0x021f100d,   // uz.sr.mk_443 rm.fr.gv_532  hmn.gv.zzp_322 lt.cy.da_554 
  // [1f280]
  0x185c61ac, 0x18042707, 0x37087312, 0x1b003608,   // za.sa.ga_632 gd.fi.ga_432  ny.no.st_654 gn.tr.un_430 
  0x08481504, 0x5a004619, 0x39024204, 0x40005a08,   // un.tt.uk_332 qu.sm.un_750  co.da.br_332 sm.lb.un_430 
  0x04fc2fee, 0x3600fe08, 0x2bfc4604, 0x1d15fc11,   // su.zzp.fi_422 tlh.gn.un_430  qu.zzp.vi_332 zzp.la.un_630 
  0x0115fcee, 0x534f0207, 0x22001121, 0x3000fc19,   // zzp.en.un_420 da.bi.ht_432  ro.oc.un_860 zzp.uz.un_750 
  // [1f290]
  0xfe3602a9, 0x104436ee, 0x443418ee, 0x38276508,   // da.gn.tlh_544 ab.kk.be_422  ar.ps.kk_422 gv.gd.tk_443 
  0x2734640c, 0x3b331a05, 0x4d006722, 0x1e1c30a0,   // lg.xh.gd_543 tl.nn.so_333  ak.aa.un_870 uz.id.ms_322 
  0x2e001a07, 0x34303baf, 0x65641dee, 0x67002513,   // tl.fo.un_420 ks.uz.ps_655  la.lg.gv_422 eu.ak.un_650 
  0x15796ba4, 0x20001b14, 0x6b586408, 0x12655808,   // ceb.war.un_433 tr.sq.un_660  lg.om.ceb_443 om.gv.hu_443 
  // [1f2a0]
  0x040a0805, 0x311b61ee, 0x1e1c6b0e, 0x3b006114,   // uk.mk.ru_333 za.tr.az_422  ceb.id.ms_555 za.so.un_660 
  0x02300c02, 0x62006b29, 0x630e01a4, 0x101f0407,   // sv.uz.da_222 ceb.kha.un_960  en.is.sco_433 fi.cy.lt_432 
  0x101f1809, 0x1f106212, 0x65272c04, 0x1f040707,   // ga.cy.lt_444 kha.lt.cy_654  fy.gd.gv_332 it.fi.cy_432 
  0x18002711, 0x046a1012, 0x28524709, 0x251c1fee,   // gd.ga.un_630 lt.haw.fi_654  sn.ha.sw_444 cy.id.eu_422 
  // [1f2b0]
  0x051f5aad, 0x791d4707, 0x2a003f0d, 0x101f3eee,   // sm.cy.fr_643 sn.la.war_432  af.mt.un_540 rm.cy.lt_422 
  0x17001111, 0x5c3446ad, 0x07190a5a, 0x27007813,   // ro.sr.un_630 qu.xh.sa_643  pt.gl.it_553 ve.gd.un_650 
  0x10003e0c, 0x19051004, 0x1f5a04af, 0x190a1fa4,   // rm.lt.un_530 lt.fr.gl_332  fi.sm.cy_655 cy.pt.gl_433 
  0x045a100c, 0x2046300d, 0x39205ea0, 0x560436a7,   // lt.sm.fi_543 uz.qu.sq_554  ts.sq.br_322 gn.fi.mg_532 
  // [1f2c0]
  0x65003604, 0x44001819, 0x04035e04, 0x4e5e78a4,   // gn.gv.un_320 ar.kk.un_750  ts.nl.fi_332 ve.ts.ay_433 
  0x1d516407, 0x02004602, 0x073823ad, 0x51645805,   // lg.kl.la_432 qu.da.un_220  ky.tk.bg_643 om.lg.kl_333 
  0x48350407, 0x0200fe0c, 0x020ffea0, 0x3b5f35a0,   // ru.tg.tt_432 tlh.da.un_530  tlh.lv.da_322 zu.tn.so_322 
  0x1b00670d, 0x280d6a07, 0x1b301eaf, 0x68001f0e,   // ak.tr.un_540 haw.cs.sw_432  ms.uz.tr_655 cy.ig.un_550 
  // [1f2d0]
  0x1300292a, 0x5d245aee, 0x562859ee, 0x1f204707,   // sl.et.un_970 sm.eo.ss_422  rn.sw.mg_422 sn.sq.cy_432 
  0x22001e02, 0x2d390da4, 0x352479ee, 0x206202ee,   // ms.oc.un_220 cs.br.sk_433  war.eo.zu_422 da.kha.sq_422 
  0x0264fe0c, 0x76003514, 0x0f0d1b04, 0x351630a4,   // tlh.lg.da_543 zu.crs.un_660  tr.cs.lv_332 uz.hr.zu_433 
  0x5c0220ad, 0x3f1720a4, 0x5afc1d07, 0x375d35a9,   // sq.da.sa_643 sq.sr.af_433  la.zzp.sm_432 zu.ss.st_544 
  // [1f2e0]
  0x3f556407, 0x070a1da0, 0x1176390c, 0x53033f07,   // lg.rw.af_432 la.pt.it_322  br.crs.ro_543 af.nl.ht_432 
  0x52002519, 0x34495004, 0x1b093807, 0x1e006211,   // eu.ha.un_750 fj.to.xh_332  tk.pl.tr_432 kha.ms.un_630 
  0x6410240b, 0x10792404, 0x20003809, 0x302a59a6,   // eo.lt.lg_542 eo.war.lt_332  tk.sq.un_440 rn.mt.uz_521 
  0x1a006b19, 0x101a51ad, 0x1a375fa4, 0x5f1a37a4,   // ceb.tl.un_750 kl.tl.lt_643  tn.st.tl_433 st.tl.tn_433 
  // [1f2f0]
  0x647335af, 0x5c221d14, 0x1b041305, 0x022176a0,   // zu.ny.lg_655 la.oc.sa_666  et.fi.tr_333 crs.jw.da_322 
  0x6e002012, 0x5347390c, 0x2b391dec, 0x1b000902,   // sq.hmn.un_640 br.sn.ht_543  la.br.vi_644 pl.tr.un_220 
  0x4315110c, 0x56005a08, 0x191d2a07, 0x420522a0,   // ro.ie.un_530 sm.mg.un_430  mt.la.gl_432 oc.fr.co_322 
  0x79001108, 0x58001205, 0x456b02a4, 0x02190b60,   // ro.war.un_430 hu.om.un_330  da.ceb.ln_433 es.gl.da_664 
  // [1f300]
  0x22112360, 0x213034a6, 0x0c340f0c, 0x20272b04,   // ca.ro.oc_664 ps.uz.fa_521  lv.xh.sv_543 vi.gd.sq_332 
  0x070a35ad, 0x1b5438ad, 0x23004322, 0x2b36230d,   // tg.mk.bg_643 tk.ik.tr_643  ie.ca.un_870 ca.gn.vi_554 
  0x23380aa0, 0x3038180c, 0x24000134, 0x1844230d,   // pt.tk.ca_322 ga.tk.uz_543  iw.yi.un_A80 ky.kk.ar_554 
  0x083704a9, 0x2b6473a0, 0x331239a7, 0x552a24ad,   // ru.ba.uk_544 ny.lg.vi_322  br.hu.nn_532 eo.mt.rw_643 
  // [1f310]
  0x04132002, 0x55003e09, 0x3f31300c, 0x55006505,   // sq.et.fi_222 rm.rw.un_440  uz.az.af_543 gv.rw.un_330 
  0x021115a7, 0x15103505, 0x600c330c, 0x55005809,   // un.ro.da_532 tg.be.un_333  nn.sv.vo_543 om.rw.un_440 
  0x23481f04, 0x233913a4, 0x5c5424a4, 0x3e150b02,   // cy.tt.ca_332 et.br.ca_433  eo.ik.sa_433 es.rm.un_220 
  0x0c1f3b07, 0x2e005c04, 0x3e392308, 0x6a006221,   // so.cy.sv_432 sa.fo.un_320  ca.br.rm_443 kha.haw.un_860 
  // [1f320]
  0x4d006113, 0x151827a7, 0x1c095c5a, 0x65001805,   // za.aa.un_650 gd.ga.un_532  sa.hi.mr_553 ga.gv.un_330 
  0x60233b08, 0x0b272f0c, 0x42260708, 0x43293955,   // so.ca.vo_443 su.gd.es_543  it.ia.co_443 br.sl.ie_442 
  0x651827af, 0x215c3b0c, 0x3b432304, 0x50683b04,   // gd.ga.gv_655 so.sa.jw_543  ca.ie.so_332 so.ig.fj_332 
  0x23003908, 0x553b390c, 0x09735c08, 0x342a3ba4,   // br.ca.un_430 br.so.rw_543  sa.ny.pl_443 so.mt.xh_433 
  // [1f330]
  0x2b0c4807, 0x3c000a1a, 0x0b007907, 0x5a001e05,   // tt.sv.vi_432 mk.ug.un_760  war.es.un_420 ms.sm.un_330 
  0x65fc6e09, 0x32001104, 0x303c0804, 0x5c131c0e,   // hmn.zzp.gv_444 ro.bs.un_320  uk.ug.uz_332 mr.bh.sa_555 
  0x3c381008, 0x1a0464a0, 0x04365c0c, 0x5c3846a0,   // be.tk.ug_443 lg.fi.tl_322  sa.gn.fi_543 qu.tk.sa_322 
  0x09556404, 0x302003ee, 0x2f552104, 0x46385c04,   // lg.rw.pl_332 nl.sq.uz_422  jw.rw.su_332 sa.tk.qu_332 
  // [1f340]
  0x042855a0, 0x20002c09, 0x0464105a, 0x09003005,   // rw.sw.fi_322 fy.sq.un_440  lt.lg.fi_553 uz.pl.un_330 
  0x33000b34, 0x30353cac, 0x04002c13, 0x282134ad,   // bn.as.un_A80 ug.tg.uz_632  fy.fi.un_650 ps.fa.sd_643 
  0x48443705, 0x2c000122, 0x0a7922ad, 0x133e1da0,   // ba.kk.tt_333 en.fy.un_870  oc.war.pt_643 la.rm.et_322 
  0x271361ad, 0x625c540c, 0x185c27ec, 0x2e000a05,   // za.et.gd_643 ik.sa.kha_543  gd.sa.ga_644 pt.fo.un_330 
  // [1f350]
  0x233048a4, 0x5300360c, 0x5318275a, 0x3f032aa9,   // tt.uz.ky_433 gn.ht.un_530  gd.ga.ht_553 mt.nl.af_544 
  0x47271813, 0x36182712, 0x510413ad, 0x676301a0,   // ga.gd.sn_665 gd.ga.gn_654  et.fi.kl_643 en.sco.ak_322 
  0x0b2350ee, 0x4a005821, 0x4c000e12, 0x3f211011,   // fj.ca.es_422 om.yo.un_860  is.wo.un_640 lt.jw.af_653 
  0x0458130b, 0x61004b19, 0x40345904, 0x5c00020d,   // et.om.fi_542 mi.za.un_750  rn.xh.lb_332 da.sa.un_540 
  // [1f360]
  0x6a154c60, 0x55476705, 0x1e5c640c, 0x37fe5fad,   // wo.haw.un_640 ak.sn.rw_333  lg.sa.ms_543 tn.tlh.st_643 
  0x1f1e64a7, 0x1f390412, 0xfe642fa4, 0x094301a4,   // lg.ms.cy_532 fi.br.cy_654  su.lg.tlh_433 en.ie.pl_433 
  0x10002a13, 0x031e1fa7, 0x080264af, 0x33001f19,   // mt.lt.un_650 cy.ms.nl_532  lg.da.no_655 cy.nn.un_750 
  0x36001e0d, 0x5c304d07, 0x2e220ea4, 0x58000412,   // ms.gn.un_540 aa.uz.sa_432  is.oc.fo_433 fi.om.un_640 
  // [1f370]
  0x553447ee, 0x640e1308, 0x333f60a7, 0x025864ec,   // sn.xh.rw_422 et.is.lg_443  vo.af.nn_532 lg.om.da_644 
  0x39041308, 0x62645cec, 0x355d7302, 0x65004204,   // et.fi.br_443 sa.lg.kha_644  ny.ss.zu_222 co.gv.un_320 
  0x5c1e64a7, 0x394c1f0b, 0xfc000219, 0x5c02640d,   // lg.ms.sa_532 cy.wo.br_542  da.zzp.un_750 lg.da.sa_554 
  0x30001208, 0x30213d04, 0x35342ea4, 0x0200fc18,   // ur.uz.un_430 ku.fa.uz_332  fo.xh.zu_433 zzp.da.un_740 
  // [1f380]
  0x231b3808, 0x1d00690c, 0x5d353fee, 0x0a0435a0,   // tk.tr.ca_443 mfe.la.un_530  af.zu.ss_422 tg.ru.mk_322 
  0x5c0246a0, 0x4600040e, 0x15044607, 0x1b006304,   // qu.da.sa_322 fi.qu.un_550  qu.fi.un_432 sco.tr.un_320 
  0x230437a4, 0x281a62ad, 0x02001804, 0x79462ea0,   // ba.ru.ky_433 kha.tl.sw_643  ga.da.un_320 fo.qu.war_322 
  0x1c2f56a0, 0x3856095a, 0x381b0902, 0x1b321705,   // mg.su.id_322 pl.mg.tk_553  pl.tr.tk_222 sr.bs.tr_333 
  // [1f390]
  0x38655608, 0x48306204, 0x1b382202, 0x1f3f2204,   // mg.gv.tk_443 kha.uz.tt_332  oc.tk.tr_222 oc.af.cy_332 
  0x4a004605, 0x53016ba0, 0x311828ee, 0x20044607,   // qu.yo.un_330 ceb.en.ht_322  sw.ga.az_422 qu.fi.sq_432 
  0x1d2201a4, 0x38005611, 0xfc044aa7, 0x46211c02,   // en.oc.la_433 mg.tk.un_630  yo.fi.zzp_532 id.jw.qu_222 
  0x5100570e, 0x78fa430d, 0x38005620, 0x5c2d090b,   // na.kl.un_550 ie.nr.ve_554  mg.tk.un_850 pl.sk.sa_542 
  // [1f3a0]
  0x22001505, 0x464925a7, 0x091c69ee, 0x53fc220b,   // un.oc.un_330 eu.to.qu_532  mfe.id.pl_422 oc.zzp.ht_542 
  0x013f63a0, 0x0e0833a0, 0x530a3e0c, 0x3e001d0d,   // sco.af.en_322 nn.no.is_322  rm.pt.ht_543 la.rm.un_540 
  0x2600070e, 0x4700611b, 0x61002919, 0x23002608,   // it.ia.un_550 za.sn.un_770  sl.za.un_750 ia.ca.un_430 
  0x3600090c, 0x514207af, 0x2500520d, 0x1d512509,   // pl.gn.un_530 it.co.kl_655  ha.eu.un_540 eu.kl.la_444 
  // [1f3b0]
  0x6155780c, 0xfc0e0207, 0x65011d02, 0x10044402,   // ve.rw.za_543 da.is.zzp_432  la.en.gv_222 kk.ru.be_222 
  0x253036a0, 0x135c0d02, 0x02000420, 0x37306aaf,   // ab.uz.mn_322 ne.sa.bh_222  fi.da.un_850 haw.uz.st_655 
  0x0200041a, 0x0255fe0c, 0x796b1aad, 0x2f55360c,   // fi.da.un_760 tlh.rw.da_543  tl.ceb.war_643 gn.rw.su_543 
  0x020e0c04, 0xfc1f0107, 0x150a0704, 0x56355907,   // sv.is.da_332 en.cy.zzp_432  bg.mk.un_332 rn.zu.mg_432 
  // [1f3c0]
  0x35796bee, 0x4936100b, 0x234411ac, 0x13100f5a,   // ceb.war.zu_422 lt.gn.to_542  ro.kk.ky_632 lv.lt.et_553 
  0x56003609, 0x2f595560, 0x303c0807, 0x2f652aee,   // gn.mg.un_440 rw.rn.su_664  uk.ug.uz_432 mt.gv.su_422 
  0x350704a4, 0x130479ee, 0x08250704, 0x13005a09,   // ru.bg.tg_433 war.fi.et_422  bg.mn.uk_332 sm.et.un_440 
  0x13501aa0, 0x07233504, 0x3d3c23af, 0xfc000f0d,   // tl.fj.et_322 tg.ky.bg_332  ky.ug.ku_655 lv.zzp.un_540 
  // [1f3d0]
  0x56394faf, 0x043912a7, 0x39002313, 0x1b12250c,   // bi.br.mg_655 hu.br.fi_532  ca.br.un_650 eu.hu.tr_543 
  0x15fc03a0, 0x396301a9, 0x536556a0, 0x2643010c,   // nl.zzp.un_322 en.sco.br_544  mg.gv.ht_322 en.ie.ia_543 
  0x5a001a02, 0x0434fca7, 0x393f0312, 0x48040aee,   // tl.sm.un_220 zzp.xh.fi_532  nl.af.br_654 mk.ru.tt_422 
  0x203903af, 0x561d5b07, 0x16294204, 0x49395a0c,   // nl.br.sq_655 sg.la.mg_432  co.sl.hr_332 sm.br.to_543 
  // [1f3e0]
  0x47033405, 0x4f230308, 0x554a59ad, 0x531d1fa0,   // xh.nl.sn_333 nl.ca.bi_443  rn.yo.rw_643 cy.la.ht_322 
  0x5c00300c, 0x20691b05, 0x50002407, 0x1a5367a4,   // uz.sa.un_530 tr.mfe.sq_333  eo.fj.un_420 ak.ht.tl_433 
  0x25002704, 0x01651fee, 0x2f672105, 0x56211704,   // gd.eu.un_320 cy.gv.en_422  jw.ak.su_333 sr.jw.mg_332 
  0x24574f12, 0x10231507, 0x290948a4, 0x290dfe04,   // bi.na.eo_654 un.ky.be_432  tt.pl.sl_433 tlh.cs.sl_332 
  // [1f3f0]
  0x2730760c, 0x5c00290d, 0x215c1c0c, 0x11005c13,   // crs.uz.gd_543 sl.sa.un_540  id.sa.jw_543 sa.ro.un_650 
  0x25002113, 0x55590207, 0x212812ac, 0x04173002,   // jw.eu.un_650 da.rn.rw_432  ur.sd.fa_632 uz.sr.ru_222 
  0x7336470c, 0x0d000f04, 0x17350702, 0x63656205,   // sn.gn.ny_543 lv.cs.un_320  bg.tg.sr_222 kha.gv.sco_333 
  0x13580413, 0x042f400c, 0x045854a4, 0x546404ad,   // fi.om.et_665 lb.su.fi_543  ik.om.fi_433 fi.lg.ik_643 
  
  // [1f400]
  0x0f796b12, 0x045154a7, 0xfe003b13, 0x3b025ca9,   // ceb.war.lv_654 ik.kl.fi_532  so.tlh.un_650 sa.da.so_544 
  0x0d5c09af, 0x213c3455, 0x2dfe1604, 0x583b540c,   // hi.sa.ne_655 ps.ug.fa_442  hr.tlh.sk_332 ik.so.om_543 
  0x31563bad, 0x1f013ba0, 0x38fc300c, 0x38002802,   // so.mg.az_643 so.en.cy_322  uz.zzp.tk_543 sw.tk.un_220 
  0x51580408, 0x5355280b, 0x1b3731a4, 0x6413040d,   // fi.om.kl_443 sw.rw.ht_542  az.st.tr_433 fi.et.lg_554 
  // [1f410]
  0x35005d22, 0x0e00fe0b, 0x53003008, 0x4000370c,   // ss.zu.un_870 tlh.is.un_520  uz.ht.un_430 st.lb.un_530 
  0x1c2120ad, 0x211812ad, 0x1e246905, 0x18005c14,   // sq.jw.id_643 ur.ar.fa_643  mfe.eo.ms_333 sa.ga.un_660 
  0x3f025c0c, 0x5c301e0b, 0x0c3308af, 0x2300081a,   // sa.da.af_543 ms.uz.sa_542  no.nn.sv_655 uk.ky.un_760 
  0x353406ec, 0x17100a0b, 0x06fe5d04, 0x0e064308,   // de.xh.zu_644 mk.be.sr_542  ss.tlh.de_332 ie.de.is_443 
  // [1f420]
  0x393830ad, 0x051d76ac, 0x1b3b5c0e, 0x39656211,   // uz.tk.br_643 crs.la.fr_632  sa.so.tr_555 kha.gv.br_653 
  0x4c0105ee, 0xfc001514, 0x014348ad, 0x24000912,   // fr.en.wo_422 un.zzp.un_660  tt.ie.en_643 pl.eo.un_640 
  0x21790e05, 0x05182bad, 0x7669080b, 0x55762805,   // is.war.jw_333 vi.ga.fr_643  no.mfe.crs_542 sw.crs.rw_333 
  0x151d110c, 0x102c3fa4, 0x59395c12, 0x34233005,   // ro.la.un_543 af.fy.lt_433  sa.br.rn_654 uz.ky.ps_333 
  // [1f430]
  0x4c2b48ec, 0x031f2e04, 0x27001820, 0x43612112,   // tt.vi.wo_644 fo.cy.nl_332  ga.gd.un_850 jw.za.ie_654 
  0x3831300d, 0x0900160d, 0x65004314, 0x312b5c0c,   // uz.az.tk_554 hr.pl.un_540  ie.gv.un_660 sa.vi.az_543 
  0x480410ee, 0x631d4308, 0x796b10a9, 0x4d79270c,   // be.ru.tt_422 ie.la.sco_443  lt.ceb.war_544 gd.war.aa_543 
  0x45642c55, 0x036b3b0c, 0x160c4da7, 0x0c203f55,   // fy.lg.ln_442 so.ceb.nl_543  aa.sv.hr_532 af.sq.sv_442 
  // [1f440]
  0x033b3f0d, 0x27185c04, 0x48100404, 0x32172405,   // af.so.nl_554 sa.ga.gd_332  ru.be.tt_332 eo.sr.bs_333 
  0x3e505cee, 0xfc001014, 0x10072a07, 0x1249fc0b,   // sa.fj.rm_422 lt.zzp.un_660  mt.it.lt_432 zzp.to.hu_542 
  0x045610ee, 0x36001009, 0x11053e08, 0x0c005412,   // lt.mg.fi_422 lt.gn.un_440  rm.fr.ro_443 ik.sv.un_640 
  0x13120411, 0x2a190a09, 0x21125607, 0x3b0f5807,   // fi.hu.et_653 pt.gl.mt_444  mg.hu.jw_432 om.lv.so_432 
  // [1f450]
  0x33082aaf, 0x242a03a0, 0x23150807, 0x13003b1e,   // mt.no.nn_655 nl.mt.eo_322  uk.ky.un_420 so.et.un_830 
  0x063f1ba0, 0x55114212, 0x22136255, 0x1c6b0108,   // tr.af.de_322 co.ro.rw_654  kha.et.oc_442 en.ceb.id_443 
  0x1c12040c, 0x2e030207, 0x065852a0, 0x18016307,   // fi.hu.id_543 da.nl.fo_432  ha.om.de_322 sco.en.ga_432 
  0x644e52a4, 0x4a1b5205, 0x04272502, 0x4f645207,   // ha.ay.lg_433 ha.tr.yo_333  eu.gd.fi_222 ha.lg.bi_432 
  // [1f460]
  0x2a6428a0, 0x530c27a0, 0x271801ee, 0x212513ec,   // sw.lg.mt_322 gd.sv.ht_322  en.ga.gd_422 et.eu.jw_644 
  0x59001309, 0x0b653e60, 0x5d006312, 0x5c1d1a04,   // et.rn.un_440 rm.gv.es_664  sco.ss.un_640 tl.la.sa_332 
  0x22110a0c, 0x4c5c4d08, 0x1a4c5607, 0x1d624daf,   // pt.ro.oc_543 aa.sa.wo_443  mg.wo.tl_432 aa.kha.la_655 
  0x5c4d1dec, 0x56004d12, 0x070a3cee, 0x38464da7,   // la.aa.sa_644 aa.mg.un_640  ug.mk.bg_422 aa.qu.tk_532 
  // [1f470]
  0x0400072a, 0x0a1d0f08, 0x4d00621a, 0x314838ec,   // bg.ru.un_970 lv.la.pt_443  kha.aa.un_760 tk.tt.az_644 
  0x044417a4, 0x38483160, 0x043023a4, 0x3f0e0204,   // sr.kk.ru_433 az.tt.tk_664  ky.uz.ru_433 da.is.af_332 
  0x04595555, 0x3b281212, 0x0e645807, 0x64005119,   // rw.rn.fi_442 ur.sd.ks_654  om.lg.is_432 kl.lg.un_750 
  0x53006412, 0x3e481304, 0x09130dac, 0x0a44070c,   // lg.ht.un_640 et.tt.rm_332  ne.bh.hi_632 bg.kk.mk_543 
  // [1f480]
  0x30116aa4, 0x027830a4, 0x674550a9, 0x5f5d35a4,   // haw.ro.uz_433 uz.ve.da_433  fj.ln.ak_544 zu.ss.tn_433 
  0x5c470207, 0x17162209, 0x792a6bad, 0x1a2213ee,   // da.sn.sa_432 oc.hr.sr_444  ceb.mt.war_643 et.oc.tl_422 
  0x0e5c6b55, 0x2c1d0411, 0x02007819, 0x481012a4,   // ceb.sa.is_442 fi.la.fy_653  ve.da.un_750 hu.lt.tt_433 
  0x3450fca6, 0x5100580e, 0x19790ba7, 0x12024b07,   // zzp.fj.xh_521 om.kl.un_550  es.war.gl_532 mi.da.hu_432 
  // [1f490]
  0x04102a11, 0x1350470c, 0x3f670909, 0x556b59a0,   // mt.lt.fi_653 sn.fj.et_543  pl.ak.af_444 rn.ceb.rw_322 
  0x090f6112, 0x6b005505, 0x0a0f4809, 0x302d73ad,   // za.lv.pl_654 rw.ceb.un_330  tt.lv.pt_444 ny.sk.uz_643 
  0x5e457814, 0x341224ee, 0x30027355, 0xfa004c14,   // ve.ln.ts_666 eo.hu.xh_422  ny.da.uz_442 wo.nr.un_660 
  0x06090faf, 0x0a001308, 0x1f392514, 0x48131ca0,   // lv.pl.de_655 et.pt.un_430  eu.br.cy_666 id.et.tt_322 
  // [1f4a0]
  0x22000208, 0x3e1d0b0c, 0x73674f14, 0x311b38ac,   // da.oc.un_430 es.la.rm_543  bi.ak.ny_666 tk.tr.az_632 
  0x794c0f0c, 0x2d264b07, 0x0245040c, 0x04136ba7,   // lv.wo.war_543 mi.ia.sk_432  fi.ln.da_543 ceb.et.fi_532 
  0x10005a0d, 0x2f4b6a04, 0x04002d12, 0x6b00090d,   // sm.lt.un_540 haw.mi.su_332  sk.fi.un_640 pl.ceb.un_540 
  0x364e0ba9, 0x06313804, 0x2e33420c, 0x37152304,   // es.ay.gn_544 tk.az.de_332  co.nn.fo_543 ky.ba.un_320 
  // [1f4b0]
  0x13585107, 0x150415a9, 0x1e00690c, 0x3313040b,   // kl.om.et_432 un.ru.un_544  mfe.ms.un_530 fi.et.nn_542 
  0x052279af, 0x024505a7, 0x0c336b04, 0x6518270d,   // war.oc.fr_655 fr.ln.da_532  ceb.nn.sv_332 gd.ga.gv_554 
  0x44001822, 0x651d2d07, 0x10241d0d, 0x02517308,   // ar.kk.un_870 sk.la.gv_432  la.eo.lt_554 ny.kl.da_443 
  0x421805a6, 0x330c5107, 0x2f1d6e07, 0x1d033b07,   // fr.ga.co_521 kl.sv.nn_432  hmn.la.su_432 so.nl.la_432 
  // [1f4c0]
  0x564f10ad, 0x13090402, 0x564f1dee, 0x1b2d0d09,   // lt.bi.mg_643 fi.pl.et_222  la.bi.mg_422 cs.sk.tr_444 
  0x0a101dad, 0x0a1d09a9, 0x0a2d1d0c, 0x44253c0c,   // la.lt.pt_643 pl.la.pt_544  la.sk.pt_543 ug.mn.kk_543 
  0x30100407, 0x2a004e18, 0x020a1d07, 0x48001105,   // ru.be.uz_432 ay.mt.un_740  la.pt.da_432 ro.tt.un_330 
  0x3e3125a4, 0x18101d55, 0x253b1f0c, 0x5c004a02,   // eu.az.rm_433 la.lt.ga_442  cy.so.eu_543 yo.sa.un_220 
  // [1f4d0]
  0x1f3e3904, 0x180a3ea4, 0x39003e0d, 0x383130af,   // br.rm.cy_332 rm.pt.ga_433  rm.br.un_540 uz.az.tk_655 
  0x1100381a, 0x3e063902, 0x122215af, 0x3e4039ad,   // tk.ro.un_760 br.de.rm_222  un.oc.hu_655 br.lb.rm_643 
  0x3e12390c, 0x09005304, 0x123e06a0, 0x433e050d,   // br.hu.rm_543 ht.pl.un_320  de.rm.hu_322 fr.rm.ie_554 
  0x03171604, 0x24000102, 0x730369ec, 0x227312a7,   // hr.sr.nl_332 en.eo.un_220  mfe.nl.ny_644 hu.ny.oc_532 
  // [1f4e0]
  0x3607300c, 0x52271507, 0x122818a6, 0x3e1558ad,   // uz.bg.ab_543 un.gd.ha_432  ar.sd.ur_521 om.rm.un_630 
  0x1efc06a0, 0x213d28ec, 0x29172d05, 0x3c44180d,   // de.zzp.ms_322 sd.ku.fa_644  sk.sr.sl_333 ar.kk.ug_554 
  0x5a3b7612, 0x55006502, 0x2e330809, 0x343c2855,   // crs.so.sm_654 gv.rw.un_220  no.nn.fo_444 sd.ug.ps_442 
  0x5427300c, 0x061f570c, 0x2a00fe22, 0x213b1804,   // uz.gd.ik_543 na.cy.de_543  tlh.mt.un_870 ar.ks.fa_332 
  // [1f4f0]
  0x381f0d07, 0x2f651fee, 0x0d180604, 0x15380712,   // cs.cy.tk_432 cy.gv.su_422  de.ga.cs_332 bg.tk.un_654 
  0x42121108, 0x1f582204, 0x46fe2008, 0x2000510d,   // ro.hu.co_443 oc.om.cy_332  sq.tlh.qu_443 kl.sq.un_540 
  0x37303804, 0x11390507, 0x393f05a4, 0x3f2f03af,   // tk.uz.ba_332 fr.br.ro_432  fr.af.br_433 nl.su.af_655 
  0x47052f07, 0x152f0504, 0x070425ad, 0x10073008,   // su.fr.sn_432 fr.su.un_332  mn.ru.bg_643 uz.bg.be_443 
  // [1f500]
  0x2f3f0313, 0x05112f08, 0x5100fe12, 0x2515390c,   // nl.af.su_665 su.ro.fr_443  tlh.kl.un_640 br.eu.un_530 
  0x23053907, 0x150501a4, 0x0d1029a0, 0x042f3908,   // br.fr.ca_432 en.fr.un_433  sl.lt.cs_322 br.su.fi_443 
  0x30483755, 0x50004f04, 0x0f071007, 0x18282707,   // ba.tt.uz_442 bi.fj.un_320  lt.it.lv_432 gd.sw.ga_432 
  0x731e3704, 0xfc006023, 0x2a004705, 0x5c421fad,   // st.ms.ny_332 vo.zzp.un_880  sn.mt.un_330 cy.co.sa_643 
  // [1f510]
  0x480a070b, 0x5300490d, 0x1a7906ee, 0x2c006512,   // bg.mk.tt_542 to.ht.un_540  de.war.tl_422 gv.fy.un_640 
  0x2a112402, 0x36002b21, 0x0f1027ee, 0x286220a4,   // eo.ro.mt_222 vi.gn.un_860  gd.lt.lv_422 sq.kha.sw_433 
  0x243922a0, 0x3065570c, 0x48460607, 0x200601a4,   // oc.br.eo_322 na.gv.uz_543  de.qu.tt_432 en.de.sq_433 
  0x21620d11, 0xfcfe3007, 0x230415ec, 0x0a0408a9,   // cs.kha.jw_653 uz.tlh.zzp_432  un.ru.ky_644 uk.ru.mk_544 
  // [1f520]
  0x383130a0, 0x5304130b, 0x080411a9, 0x56002608,   // uz.az.tk_322 et.fi.ht_542  ro.ru.uk_544 ia.mg.un_430 
  0x22fe0a07, 0x45370a08, 0x42080207, 0x2e625c12,   // pt.tlh.oc_432 pt.st.ln_443  da.no.co_432 sa.kha.fo_654 
  0x07040a5a, 0x0c0864a9, 0x686738a4, 0x502118ec,   // mk.ru.bg_553 lg.no.sv_544  tk.ak.ig_433 ga.jw.fj_644 
  0x3e234307, 0x180162ad, 0x02094607, 0x10040a08,   // ie.ca.rm_432 kha.en.ga_643  qu.pl.da_432 mk.ru.be_443 
  // [1f530]
  0x170a0809, 0x38111ba9, 0x08172507, 0x26005c20,   // uk.mk.sr_444 tr.ro.tk_544  mn.sr.uk_432 sa.ia.un_850 
  0x301e60a4, 0x305c21ad, 0x210a7302, 0x1d732b07,   // vo.ms.uz_433 jw.sa.uz_643  ny.pt.jw_222 vi.ny.la_432 
  0x04254aad, 0x382c1bee, 0x170f2da7, 0x100817a4,   // yo.eu.fi_643 tr.fy.tk_422  sk.lv.sr_532 sr.uk.be_433 
  0x23020a05, 0x1b001804, 0x51251ca0, 0x060401a4,   // pt.da.ca_333 ga.tr.un_320  id.eu.kl_322 en.fi.de_433 
  // [1f540]
  0x10003b04, 0x62522aad, 0x483e5e0d, 0x0a0744a4,   // so.lt.un_320 mt.ha.kha_643  ts.rm.tt_554 kk.bg.mk_433 
  0x3f3b020d, 0x37691e07, 0x1d002509, 0x511a7907,   // da.so.af_554 ms.mfe.st_432  eu.la.un_440 war.tl.kl_432 
  0x253efc13, 0x2d121804, 0x3c00302c, 0x5c1c1e0c,   // zzp.rm.eu_665 ga.hu.sk_332  uz.ug.un_990 ms.id.sa_543 
  0x573f06a9, 0x1a10790c, 0x35fe345a, 0x04fe21a9,   // de.af.na_544 war.lt.tl_543  xh.tlh.zu_553 jw.tlh.fi_544 
  // [1f550]
  0xfe2f79ad, 0x73005d22, 0x3b4734ee, 0x6b1a180c,   // war.su.tlh_643 ss.ny.un_870  xh.sn.so_422 ga.tl.ceb_543 
  0x2a5e5da9, 0x4d555205, 0x5a4a5704, 0x24260e07,   // ss.ts.mt_544 ha.rw.aa_333  na.yo.sm_332 is.ia.eo_432 
  0x3d122112, 0x033b34a0, 0x2a423ba4, 0x03003004,   // fa.ur.ku_654 xh.so.nl_322  so.co.mt_433 uz.nl.un_320 
  0x2a051faf, 0x12004404, 0x0e113ba0, 0x2b000e04,   // cy.fr.mt_655 kk.ur.un_320  so.ro.is_322 is.vi.un_320 
  // [1f560]
  0x3f0362a7, 0x0a3b11a4, 0x2a3e420c, 0x557847af,   // kha.nl.af_532 ro.so.pt_433  co.rm.mt_543 sn.ve.rw_655 
  0x36002d1a, 0x084404ee, 0x1b002509, 0x130465a9,   // sk.gn.un_760 ru.kk.uk_422  eu.tr.un_440 gv.fi.et_544 
  0x1a3802a0, 0x6a005a19, 0x2400622b, 0x03021f04,   // da.tk.tl_322 sm.haw.un_750  kha.eo.un_980 cy.da.nl_332 
  0x0d252dad, 0x3000621b, 0x041f6aa0, 0x651304ee,   // sk.eu.cs_643 kha.uz.un_770  haw.cy.fi_322 fi.et.gv_422 
  // [1f570]
  0x19004e12, 0x09131ca7, 0x29332da0, 0x4c2d62a0,   // ay.gl.un_640 mr.bh.hi_532  sk.nn.sl_322 kha.sk.wo_322 
  0x0c5e19a4, 0x63190a02, 0x1f005a07, 0x5a131fad,   // gl.ts.sv_433 pt.gl.sco_222  sm.cy.un_420 cy.et.sm_643 
  0x13fc2cad, 0x13002c0d, 0x022c120c, 0x1108480c,   // fy.zzp.et_643 fy.et.un_540  hu.fy.da_543 tt.uk.ro_543 
  0x1d2c1f08, 0x06002c05, 0x271565a0, 0x10022307,   // cy.fy.la_443 fy.de.un_330  gv.gd.un_320 ca.da.lt_432 
  // [1f580]
  0x2c0e3fee, 0x02003604, 0x39461804, 0x102c23a4,   // af.is.fy_422 gn.da.un_320  ga.qu.br_332 ca.fy.lt_433 
  0x0e00100c, 0x12032309, 0x36003102, 0x273e1804,   // lt.is.un_530 ca.nl.hu_444  az.gn.un_220 ga.rm.gd_332 
  0x23121008, 0x083e0c04, 0x0c132cec, 0x2c080205,   // lt.hu.ca_443 sv.rm.no_332  fy.et.sv_644 da.no.fy_333 
  0x39111207, 0x39005614, 0x330823ee, 0x655612af,   // hu.ro.br_432 mg.br.un_660  ca.no.nn_422 hu.mg.gv_655 
  // [1f590]
  0x34006207, 0x0b223e04, 0x1d120107, 0x083615a9,   // kha.xh.un_420 rm.oc.es_332  en.hu.la_432 un.ab.uk_544 
  0x6b205608, 0x1d2c18af, 0x3e4227ec, 0x231e1c07,   // mg.sq.ceb_443 ga.fy.la_655  gd.co.rm_644 id.ms.ca_432 
  0x136551a4, 0x2700561a, 0x2b6b3e0c, 0x163629ee,   // kl.gv.et_433 mg.gd.un_760  rm.ceb.vi_543 sl.gn.hr_422 
  0x3b020107, 0x0e4afe07, 0x2d002814, 0x63fc0112,   // en.da.so_432 tlh.yo.is_432  sw.sk.un_660 en.zzp.sco_654 
  // [1f5a0]
  0x69764fa9, 0x2900110c, 0x21233d04, 0x19002702,   // bi.crs.mfe_544 ro.sl.un_530  ku.ky.fa_332 gd.gl.un_220 
  0x5e006a0c, 0x322d0908, 0x313b4c08, 0x09183ea0,   // haw.ts.un_530 pl.sk.bs_443  wo.so.az_443 rm.ga.pl_322 
  0x0a005613, 0x0a053ea7, 0x2f354e08, 0x18000921,   // mg.pt.un_650 rm.fr.pt_532  ay.zu.su_443 pl.ga.un_860 
  0x104f1caf, 0x17290fa9, 0x4d512a08, 0x3100470d,   // id.bi.lt_655 lv.sl.sr_544  mt.kl.aa_443 sn.az.un_540 
  // [1f5b0]
  0x3b28460e, 0x08005504, 0x3c303707, 0x38005c05,   // qu.sw.so_555 rw.no.un_320  ba.uz.ug_432 sa.tk.un_330 
  0x635f3ea0, 0x27421fa0, 0x0a006508, 0x21630111,   // rm.tn.sco_322 cy.co.gd_322  gv.pt.un_430 en.sco.jw_653 
  0x1c2156ee, 0x190a63af, 0x2f4621ad, 0x0f653e55,   // mg.jw.id_422 sco.pt.gl_655  jw.qu.su_643 rm.gv.lv_442 
  0x4e00732a, 0x34183d55, 0x681e4e04, 0x5c001f14,   // ny.ay.un_970 ku.ar.ps_442  ay.ms.ig_332 cy.sa.un_660 
  // [1f5c0]
  0x094e2113, 0xfe001e04, 0x1f562d0c, 0x56630112,   // jw.ay.pl_665 ms.tlh.un_320  sk.mg.cy_543 en.sco.mg_654 
  0x1a796b0e, 0x58004e18, 0x28004e08, 0x1a15210c,   // ceb.war.tl_555 ay.om.un_740  ay.sw.un_430 jw.tl.un_530 
  0x521a4704, 0x1a004e19, 0x0b3b5c0c, 0x3725380c,   // sn.tl.ha_332 ay.tl.un_750  sa.so.es_543 tk.mn.ba_543 
  0x0e2f4dee, 0x641142a0, 0x37000805, 0x2b007607,   // aa.su.is_422 co.ro.lg_322  uk.ba.un_330 crs.vi.un_420 
  // [1f5d0]
  0x0a005809, 0x52624755, 0x06136ba0, 0x621d590c,   // om.pt.un_440 sn.kha.ha_442  ceb.et.de_322 rn.la.kha_543 
  0x3715640e, 0x64554507, 0x32157907, 0x102615a9,   // lg.st.un_550 ln.rw.lg_432  war.bs.un_420 un.ia.lt_544 
  0x2b1502ac, 0x23194d05, 0x05651807, 0x1f0518ec,   // da.vi.un_620 aa.gl.ca_333  ga.gv.fr_432 ga.fr.cy_644 
  0x02005c0d, 0x04631fa0, 0x62101f05, 0x18006e04,   // sa.da.un_540 cy.sco.fi_322  cy.lt.kha_333 hmn.ga.un_320 
  // [1f5e0]
  0x09005205, 0x65fc1004, 0x65007913, 0x19003405,   // ha.pl.un_330 lt.zzp.gv_332  war.gv.un_650 xh.gl.un_330 
  0x1b5365ad, 0x4e00340e, 0x103f6507, 0x01001f0b,   // gv.ht.tr_643 xh.ay.un_550  gv.af.lt_432 cy.en.un_520 
  0x34285d13, 0x791f6908, 0x42002a11, 0x73001b05,   // ss.sw.xh_665 mfe.cy.war_443  mt.co.un_630 tr.ny.un_330 
  0x35341960, 0x0218050c, 0x18450507, 0x24640207,   // gl.xh.zu_664 fr.ga.da_543  fr.ln.ga_432 da.lg.eo_432 
  // [1f5f0]
  0x06001804, 0x732434ec, 0x1e005c02, 0x24004704,   // ga.de.un_320 xh.eo.ny_644  sa.ms.un_220 sn.eo.un_320 
  0x345573a0, 0x1b000909, 0x09003907, 0x21123b04,   // ny.rw.xh_322 pl.tr.un_440  br.pl.un_420 ks.ur.fa_332 
  0xfe00fc1a, 0x24007307, 0x300408a9, 0x5800fc0d,   // zzp.tlh.un_760 ny.eo.un_420  uk.ru.uz_544 zzp.om.un_540 
  0x0c0e13ee, 0x08071007, 0x244655a0, 0x0d3bfe05,   // et.is.sv_422 be.bg.uk_432  rw.qu.eo_322 tlh.so.cs_333 
  // [1f600]
  0x554728a0, 0x04330808, 0x027355ec, 0x04331308,   // sw.sn.rw_322 no.nn.fi_443  rw.ny.da_644 et.nn.fi_443 
  0x245973ee, 0x73005509, 0x0a074408, 0x164e290c,   // ny.rn.eo_422 rw.ny.un_440  kk.bg.mk_443 sl.ay.hr_543 
  0x0f006a07, 0x12183da6, 0x175c1011, 0x22004e0d,   // haw.lv.un_420 ku.ar.ur_521  lt.sa.sr_653 ay.oc.un_540 
  0x30294ea7, 0x0f0d1007, 0x1044080d, 0x51002819,   // ay.sl.uz_532 lt.cs.lv_432  uk.kk.be_554 sw.kl.un_750 
  // [1f610]
  0x30003d2b, 0x420228a4, 0x2e0c02ad, 0x221d63ee,   // ku.uz.un_980 sw.da.co_433  da.sv.fo_643 sco.la.oc_422 
  0x3e290d07, 0x2afc580c, 0x2335100c, 0x783b620c,   // cs.sl.rm_432 om.zzp.mt_543  be.tg.ky_543 kha.so.ve_543 
  0x44343b07, 0x281827ec, 0x42077955, 0x64635608,   // ks.ps.kk_432 gd.ga.sw_644  war.it.co_442 mg.sco.lg_443 
  0x47002813, 0x4700280d, 0x4d00280c, 0x311e6955,   // sw.sn.un_650 sw.sn.un_540  sw.aa.un_530 mfe.ms.az_442 
  // [1f620]
  0x04003821, 0x03045304, 0x58213baf, 0x040660ee,   // tk.fi.un_860 ht.fi.nl_332  so.jw.om_655 vo.de.fi_422 
  0x08172355, 0x321b3909, 0x642836a0, 0x28522a07,   // ky.sr.uk_442 br.tr.bs_444  gn.sw.lg_322 mt.ha.sw_432 
  0x073e2807, 0x25697612, 0x08000305, 0x04004605,   // sw.rm.it_432 crs.mfe.eu_654  nl.no.un_330 qu.fi.un_330 
  0x2d095607, 0x5b002013, 0x234421a9, 0x233c3812,   // mg.pl.sk_432 sq.sg.un_650  fa.kk.ky_544 tk.ug.ky_654 
  // [1f630]
  0x3308200d, 0x5c5e1fa0, 0x1242070c, 0x62786514,   // sq.no.nn_554 cy.ts.sa_322  it.co.hu_543 gv.ve.kha_666 
  0x310969a9, 0x5e000c04, 0x102d63ee, 0x5f276205,   // mfe.pl.az_544 sv.ts.un_320  sco.sk.lt_422 kha.gd.tn_333 
  0x06202307, 0x69093008, 0x12000918, 0x0603040d,   // ca.sq.de_432 uz.pl.mfe_443  pl.hu.un_740 fi.nl.de_554 
  0x56021207, 0x12192da0, 0x3900020c, 0x4500301b,   // hu.da.mg_432 sk.gl.hu_322  da.br.un_530 uz.ln.un_770 
  // [1f640]
  0x17381155, 0x35372304, 0xfc650105, 0x2d0d40a4,   // ro.tk.sr_442 ky.ba.tg_332  en.gv.zzp_333 lb.cs.sk_433 
  0x47450209, 0x58242d07, 0x174745ad, 0x311d39af,   // da.ln.sn_444 sk.eo.om_432  ln.sn.sr_643 br.la.az_655 
  0x0a657904, 0x2d601d12, 0x05113907, 0x123e6008,   // war.gv.pt_332 la.vo.sk_654  br.ro.fr_432 vo.rm.hu_443 
  0x1b433107, 0x322847a0, 0x36041504, 0x04170855,   // az.ie.tr_432 sn.sw.bs_322  un.ru.ab_332 uk.sr.ru_442 
  // [1f650]
  0x2b002308, 0x766b01a4, 0x303d2160, 0x4b5c0f11,   // ca.vi.un_430 en.ceb.crs_433  fa.ku.uz_664 lv.sa.mi_653 
  0x47343602, 0x1e002302, 0x76430107, 0x182725a4,   // gn.xh.sn_222 ca.ms.un_220  en.ie.crs_432 eu.gd.ga_433 
  0x04353004, 0x5a002713, 0x33082902, 0x40033fee,   // uz.tg.ru_332 gd.sm.un_650  sl.no.nn_222 af.nl.lb_422 
  0x5a001f05, 0x04372307, 0x5a271813, 0x1d004e1a,   // cy.sm.un_330 ky.ba.ru_432  ga.gd.sm_665 ay.la.un_760 
  // [1f660]
  0x2b1940ee, 0x2c005507, 0x100f2504, 0x10fc5ca0,   // lb.gl.vi_422 rw.fy.un_420  eu.lv.lt_332 sa.zzp.lt_322 
  0x1f271011, 0x25002721, 0x3b342305, 0x25234412,   // lt.gd.cy_653 gd.eu.un_860  ky.ps.ks_333 kk.ky.mn_654 
  0x62135ca4, 0x22006b04, 0x524a1aa7, 0x4900670e,   // sa.et.kha_433 ceb.oc.un_320  tl.yo.ha_532 ak.to.un_550 
  0x01060da0, 0x15003b09, 0x645528a9, 0x35645d07,   // cs.de.en_322 so.un.un_440  sw.rw.lg_544 ss.lg.zu_432 
  // [1f670]
  0x364837a4, 0x021a67af, 0x17361107, 0x311a3b55,   // ba.tt.ab_433 ak.tl.da_655  ro.ab.sr_432 so.tl.az_442 
  0x69001a13, 0x6700630e, 0x1d00fe0c, 0x305369a6,   // tl.mfe.un_650 sco.ak.un_550  tlh.la.un_530 mfe.ht.uz_521 
  0x2a645504, 0x2317360b, 0x016b4307, 0x07304807,   // rw.lg.mt_332 ab.sr.ky_542  ie.ceb.en_432 tt.uz.bg_432 
  0x152b02ee, 0x0c0e33ee, 0x7951020d, 0x3f022ea9,   // da.vi.un_422 nn.is.sv_422  da.kl.war_554 fo.da.af_544 
  // [1f680]
  0x636502a0, 0x3f0c3304, 0x3c4830ec, 0x0e3308a0,   // da.gv.sco_322 nn.sv.af_332  uz.tt.ug_644 no.nn.is_322 
  0x35113c55, 0x070a11ad, 0x3b211205, 0x4d46310d,   // ug.ro.tg_442 ro.mk.bg_643  ur.fa.ks_333 az.qu.aa_554 
  0x312a51ac, 0x31514612, 0x5846fead, 0x4d2046ad,   // kl.mt.az_632 qu.kl.az_654  tlh.qu.om_643 qu.sq.aa_643 
  0x08040a05, 0x4b694faf, 0x0f2211a4, 0x794b46ee,   // mk.ru.uk_333 bi.mfe.mi_655  ro.oc.lv_433 qu.mi.war_422 
  // [1f690]
  0x54514daf, 0x383023a7, 0x0400071b, 0x784b280c,   // aa.kl.ik_655 ky.uz.tk_532  bg.ru.un_770 sw.mi.ve_543 
  0x79474bec, 0x36003c0e, 0x483146a4, 0x500f5ca0,   // mi.sn.war_644 ug.ab.un_550  qu.az.tt_433 sa.lv.fj_322 
  0x545146ad, 0x484631af, 0x16796b08, 0xfe465114,   // qu.kl.ik_643 az.qu.tt_655  ceb.war.hr_443 kl.qu.tlh_666 
  0x544e46a4, 0x4700040d, 0x36647905, 0x4b004f07,   // qu.ay.ik_433 fi.sn.un_540  war.lg.gn_333 bi.mi.un_420 
  // [1f6a0]
  0x4b004734, 0x1b380212, 0x5c736407, 0x50474ba4,   // sn.mi.un_A80 da.tk.tr_654  lg.ny.sa_432 mi.sn.fj_433 
  0x5d28360c, 0x255060ad, 0x3b001e05, 0x795c47af,   // gn.sw.ss_543 vo.fj.eu_643  ms.so.un_330 sn.sa.war_655 
  0x204205a7, 0x1a646ba4, 0x5c6155ad, 0x7900041a,   // fr.co.sq_532 ceb.lg.tl_433  rw.za.sa_643 fi.war.un_760 
  0x5c1a6b09, 0xfa5c57ac, 0x29024504, 0x12591a07,   // ceb.tl.sa_444 na.sa.nr_632  ln.da.sl_332 tl.rn.hu_432 
  // [1f6b0]
  0x28674505, 0x3b4664a0, 0x645e5555, 0x02555ca4,   // ln.ak.sw_333 lg.qu.so_322  rw.ts.lg_442 sa.rw.da_433 
  0x57fc45a4, 0x3c443060, 0x38536105, 0x64345c0c,   // ln.zzp.na_433 uz.kk.ug_664  za.ht.tk_333 sa.xh.lg_543 
  0x28477355, 0x3f03190c, 0x07172907, 0x21005c07,   // ny.sn.sw_442 gl.nl.af_543  sl.sr.it_432 sa.jw.un_420 
  0x1e46fe0b, 0x023528ad, 0x3f212aac, 0x15120c04,   // tlh.qu.ms_542 sw.zu.da_643  mt.jw.af_632 sv.hu.un_332 
  // [1f6c0]
  0x0a483c07, 0x2a695c11, 0x0a23170c, 0x2700580e,   // ug.tt.mk_432 sa.mfe.mt_653  sr.ky.mk_543 om.gd.un_550 
  0x3f2c1f04, 0x5c213b0c, 0x022c3f0e, 0x34182355,   // cy.fy.af_332 so.jw.sa_543  af.fy.da_555 ky.ar.ps_442 
  0x02091fa0, 0x42695c07, 0x13045c05, 0x243902ee,   // cy.pl.da_322 sa.mfe.co_432  sa.fi.et_333 da.br.eo_422 
  0x03203304, 0x28022404, 0x29242808, 0x17301307,   // nn.sq.nl_332 eo.da.sw_332  sw.eo.sl_443 et.uz.sr_432 
  // [1f6d0]
  0x49500a0e, 0x59247312, 0x476413ee, 0x73642807,   // pt.fj.to_555 ny.eo.rn_654  et.lg.sn_422 sw.lg.ny_432 
  0x55596407, 0x35101304, 0x17005007, 0x25552404,   // lg.rn.rw_432 et.lt.zu_332  fj.sr.un_420 eo.rw.eu_332 
  0x321742ee, 0x52732807, 0x2c3f1f04, 0x64470f0d,   // co.sr.bs_422 sw.ny.ha_432  cy.af.fy_332 lv.sn.lg_554 
  0x291247a7, 0x5c311ba4, 0x555d3504, 0x55004708,   // sn.hu.sl_532 tr.az.sa_433  zu.ss.rw_332 sn.rw.un_430 
  // [1f6e0]
  0x733464af, 0x3e13500b, 0x31135c05, 0x3920240c,   // lg.xh.ny_655 fj.et.rm_542  sa.et.az_333 eo.sq.br_543 
  0x5e00300c, 0x79365007, 0x24595513, 0x2800351a,   // uz.ts.un_530 fj.gn.war_432  rw.rn.eo_665 zu.sw.un_760 
  0x28364a0b, 0x1d151a12, 0x4c001d0d, 0x18002509,   // yo.gn.sw_542 tl.la.un_640  la.wo.un_540 eu.ga.un_440 
  0x321630a0, 0x465324ec, 0xfcfe3108, 0x553828a0,   // uz.hr.bs_322 eo.ht.qu_644  az.tlh.zzp_443 sw.tk.rw_322 
  // [1f6f0]
  0x24004612, 0x532a11ee, 0x39241104, 0x170438ac,   // qu.eo.un_640 ro.mt.ht_422  ro.eo.br_332 tk.ru.sr_632 
  0x38301ba4, 0x46000919, 0x380330a9, 0x4e280d07,   // tr.uz.tk_433 pl.qu.un_750  uz.nl.tk_544 cs.sw.ay_432 
  0x1b312408, 0x300804a7, 0x440715ec, 0x68531d0c,   // eo.az.tr_443 ru.uk.uz_532  un.bg.kk_644 la.ht.ig_543 
  0x34213c55, 0x321615a0, 0xfc400e02, 0x30112504,   // ug.fa.ps_442 un.hr.bs_322  is.lb.zzp_222 mn.ro.uz_332 
  // [1f700]
  0x3f020ea4, 0x15650102, 0x3f003e02, 0x18052709,   // is.da.af_433 en.gv.un_222  rm.af.un_220 gd.fr.ga_444 
  0xfc003202, 0x44233809, 0x6558680c, 0x6800651a,   // bs.zzp.un_220 tk.ky.kk_444  ig.om.gv_543 gv.ig.un_760 
  0x5c2d0d0d, 0x5c033f02, 0x1e283b05, 0x3710480b,   // cs.sk.sa_554 af.nl.sa_222  so.sw.ms_333 tt.be.ba_542 
  0x3c302308, 0x1103250c, 0x25790107, 0x0668600c,   // ky.uz.ug_443 eu.nl.ro_543  en.war.eu_432 vo.ig.de_543 
  // [1f710]
  0x01fc30a0, 0x371544ad, 0x1d79680c, 0x3b472502,   // uz.zzp.en_322 kk.ba.un_630  ig.war.la_543 eu.sn.so_222 
  0x3f021b09, 0x35603f0c, 0x0a073804, 0x046a1314,   // tr.da.af_444 af.vo.zu_543  tk.bg.mk_332 et.haw.fi_666 
  0x3f006a08, 0x131701ee, 0x37002609, 0x5a2c03a4,   // haw.af.un_430 en.sr.et_422  ia.st.un_440 nl.fy.sm_433 
  0x0c56080c, 0x33004904, 0x253b5802, 0x5d473513,   // no.mg.sv_543 to.nn.un_320  om.so.eu_222 zu.sn.ss_665 
  // [1f720]
  0x567669a4, 0x63044d07, 0x3f5a13a0, 0x103f6aad,   // mfe.crs.mg_433 aa.fi.sco_432  et.sm.af_322 haw.af.lt_643 
  0x671a0107, 0x760156a7, 0x392937a0, 0x2873fcee,   // en.tl.ak_432 mg.en.crs_532  st.sl.br_322 zzp.ny.sw_422 
  0x2d006502, 0x1c212f04, 0x730413ec, 0x23227911,   // gv.sk.un_220 su.jw.id_332  et.fi.ny_644 war.oc.ca_653 
  0x566518a0, 0x1f000107, 0x6908025a, 0x2a003611,   // ga.gv.mg_322 en.cy.un_420  da.no.mfe_553 gn.mt.un_630 
  // [1f730]
  0x48314e55, 0x2a4d58ad, 0x312548a7, 0x31234805,   // ay.az.tt_442 om.aa.mt_643  tt.eu.az_532 tt.ca.az_333 
  0x38fc3b02, 0x48004e1b, 0x203628a9, 0x11001d08,   // so.zzp.tk_222 ay.tt.un_770  sw.gn.sq_544 la.ro.un_430 
  0x243f1da9, 0x2832730c, 0x27111d11, 0x30595655,   // la.af.eo_544 ny.bs.sw_543  la.ro.gd_653 mg.rn.uz_442 
  0x59240208, 0x292530ad, 0x1d11270e, 0x2c002402,   // da.eo.rn_443 uz.eu.sl_643  gd.ro.la_555 eo.fy.un_220 
  // [1f740]
  0x45003008, 0x24203e5a, 0x27005812, 0x354559a9,   // uz.ln.un_430 rm.sq.eo_553  om.gd.un_640 rn.ln.zu_544 
  0x2c1d1d07, 0x271d1155, 0x115309a4, 0x6b004702,   // la.la.fy_432 ro.la.gd_442  pl.ht.ro_433 sn.ceb.un_220 
  0x3f1902a9, 0x20116e08, 0x17197307, 0x3e0201a4,   // da.gl.af_544 hmn.ro.sq_443  ny.gl.sr_432 en.da.rm_433 
  0x241047a4, 0x6b561d55, 0x18005e04, 0x13375f08,   // sn.lt.eo_433 la.mg.ceb_442  ts.ga.un_320 tn.st.et_443 
  // [1f750]
  0xfc002a09, 0x151d5712, 0x2f001507, 0x132564a0,   // mt.zzp.un_440 na.la.un_654  un.su.un_420 lg.eu.et_322 
  0x47001308, 0x13060404, 0x514a64ee, 0x27313ba4,   // et.sn.un_430 fi.de.et_332  lg.yo.kl_422 so.az.gd_433 
  0x4835380c, 0x3f130404, 0x1f63fe02, 0x1f630207,   // tk.tg.tt_543 fi.et.af_332  tlh.sco.cy_222 da.sco.cy_432 
  0x020c0ea9, 0x183d210d, 0x44001107, 0x5c0c47ec,   // is.sv.da_544 fa.ku.ar_554  ro.kk.un_420 sn.sv.sa_644 
  // [1f760]
  0xfc00040c, 0x2300170c, 0x1e24fea6, 0x33083ea9,   // fi.zzp.un_530 sr.ky.un_530  tlh.eo.ms_521 rm.no.nn_544 
  0x2400090e, 0x352330af, 0x4c00360e, 0x532429a4,   // pl.eo.un_550 uz.ky.tg_655  gn.wo.un_550 sl.eo.ht_433 
  0x23003619, 0x6a493708, 0x132f490c, 0x264211a9,   // ab.ky.un_750 st.to.haw_443  to.su.et_543 ro.co.ia_544 
  0x564b6a13, 0x6a006809, 0x653802a4, 0x2515370c,   // haw.mi.mg_665 ig.haw.un_440  da.tk.gv_433 ba.mn.un_530 
  // [1f770]
  0x04101110, 0x03645807, 0x34232519, 0x10005302,   // ro.be.ru_642 om.lg.nl_432  mn.ky.ps_765 ht.lt.un_220 
  0x04000f02, 0x365528a7, 0x0f0102ee, 0x3f1f02a4,   // lv.fi.un_220 sw.rw.gn_532  da.en.lv_422 da.cy.af_433 
  0x2f006a1b, 0x492d0d13, 0x0600620d, 0x27361ca0,   // haw.su.un_770 cs.sk.to_665  kha.de.un_540 id.gn.gd_322 
  0x1e5273a4, 0x65001e0c, 0x651827ee, 0x27005204,   // ny.ha.ms_433 ms.gv.un_530  gd.ga.gv_422 ha.gd.un_320 
  // [1f780]
  0x30766907, 0x365c38ad, 0x5321380c, 0x383010ec,   // mfe.crs.uz_432 tk.sa.gn_643  tk.jw.ht_543 lt.uz.tk_644 
  0x38021fad, 0x3800540d, 0x1c181ea4, 0x595538ee,   // cy.da.tk_643 ik.tk.un_540  ms.ga.id_433 tk.rw.rn_422 
  0x20004702, 0x101b5c60, 0x09023804, 0x79fc3808,   // sn.sq.un_220 sa.tr.lt_664  tk.da.pl_332 tk.zzp.war_443 
  0x0d793805, 0x38005c23, 0x48001210, 0x37170402,   // tk.war.cs_333 sa.tk.un_880  hu.tt.un_620 ru.sr.ba_222 
  // [1f790]
  0x4a2205a4, 0x2b004a07, 0x170a440b, 0x30380f08,   // fr.oc.yo_433 yo.vi.un_420  kk.mk.sr_542 lv.tk.uz_443 
  0x104844a9, 0x5c6e63af, 0x495004a4, 0x5c000b02,   // kk.tt.be_544 sco.hmn.sa_655  fi.fj.to_433 es.sa.un_220 
  0x56476e08, 0x30001a02, 0x04105008, 0x26005c0c,   // hmn.sn.mg_443 tl.uz.un_220  fj.lt.fi_443 sa.ia.un_530 
  0x0430080e, 0xfe3e605a, 0x3e105ca4, 0x3e5a495a,   // uk.uz.ru_555 vo.rm.tlh_553  sa.lt.rm_433 to.sm.rm_553 
  // [1f7a0]
  0x190a10ac, 0x0f001119, 0x26432e0c, 0x1c1e1b5a,   // lt.pt.gl_632 ro.lv.un_750  fo.ie.ia_543 tr.ms.id_553 
  0x3e301312, 0x30006808, 0x4a460907, 0x50044709,   // et.uz.rm_654 ig.uz.un_430  pl.qu.yo_432 sn.fi.fj_444 
  0x1e1c2d0c, 0x5c045414, 0x5d002d04, 0x3e494708,   // sk.id.ms_543 ik.fi.sa_666  sk.ss.un_320 sn.to.rm_443 
  0x01264712, 0x47355da4, 0x031361a7, 0x3f2c010b,   // sn.ia.en_654 ss.zu.sn_433  za.et.nl_532 en.fy.af_542 
  // [1f7b0]
  0x475404a4, 0x464b0307, 0x05404c07, 0x22054c08,   // fi.ik.sn_433 nl.mi.qu_432  wo.lb.fr_432 wo.fr.oc_443 
  0x63134a07, 0x38301fad, 0x063f4011, 0x033f20a0,   // yo.et.sco_432 cy.uz.tk_643  lb.af.de_653 sq.af.nl_322 
  0x5c020f07, 0x18002821, 0x73003b0c, 0x45032ca7,   // lv.da.sa_432 sd.ar.un_860  so.ny.un_530 fy.nl.ln_532 
  0x13220408, 0x21614fad, 0x251b5d08, 0x192401a0,   // fi.oc.et_443 bi.za.jw_643  ss.tr.eu_443 en.eo.gl_322 
  // [1f7c0]
  0x33fc0e04, 0x3b2330ec, 0x4600fe1b, 0xfe5c30a4,   // is.zzp.nn_332 uz.ky.ks_644  tlh.qu.un_770 uz.sa.tlh_433 
  0xfe0446a4, 0x080e24a7, 0x123224a0, 0x28303b0c,   // qu.fi.tlh_433 eo.is.no_532  eo.bs.hu_322 ks.uz.sd_543 
  0x1d002d14, 0x20044604, 0x2e00611a, 0x460469a4,   // sk.la.un_660 qu.fi.sq_332  za.fo.un_760 mfe.fi.qu_433 
  0x47537607, 0x2e00332a, 0x340e3f07, 0x2a002f05,   // crs.ht.sn_432 nn.fo.un_970  af.is.xh_432 su.mt.un_330 
  // [1f7d0]
  0x34001702, 0x3e00180c, 0x323f035a, 0x421d0504,   // sr.xh.un_220 ga.rm.un_530  nl.af.bs_553 fr.la.co_332 
  0xfc5c46a7, 0x045c13a4, 0x163ffea0, 0x021d46ad,   // qu.sa.zzp_532 et.sa.fi_433  tlh.af.hr_322 qu.la.da_643 
  0x300246af, 0x42044607, 0x460238a4, 0x33652707,   // qu.da.uz_655 qu.fi.co_432  tk.da.qu_433 gd.gv.nn_432 
  0x532d24a6, 0x333e220c, 0x132e1ba6, 0x63392ead,   // eo.sk.ht_521 oc.rm.nn_543  tr.fo.et_521 fo.br.sco_643 
  // [1f7e0]
  0x2d3836a9, 0x57000608, 0x0c0f13a4, 0x421d1307,   // gn.tk.sk_544 de.na.un_430  et.lv.sv_433 et.la.co_432 
  0x39064da4, 0x13420ea4, 0x043c23ee, 0x045113a9,   // aa.de.br_433 is.co.et_433  ky.ug.ru_422 et.kl.fi_544 
  0x134c4d0c, 0x5a1f0407, 0x2e130e07, 0xfc3113ec,   // aa.wo.et_543 fi.cy.sm_432  is.et.fo_432 et.az.zzp_644 
  0x0600690d, 0x111205a0, 0x2a65fea9, 0xfe1f1c07,   // mfe.de.un_540 fr.hu.ro_322  tlh.gv.mt_544 id.cy.tlh_432 
  // [1f7f0]
  0x272f61a7, 0x3500fa19, 0x65425c07, 0x6b0c1d07,   // za.su.gd_532 nr.zu.un_750  sa.co.gv_432 la.sv.ceb_432 
  0x060c3004, 0x190a180c, 0x5c00fe09, 0x303c15a0,   // uz.sv.de_332 ga.pt.gl_543  tlh.sa.un_440 un.ug.uz_322 
  0x58000414, 0x23226304, 0x3f004e14, 0x13001d0b,   // fi.om.un_660 sco.oc.ca_332  ay.af.un_660 la.et.un_520 
  0x133b4d0b, 0xfe006511, 0x5f003b11, 0x34443c09,   // aa.so.et_542 gv.tlh.un_630  so.tn.un_630 ug.kk.ps_444 
  
  // [1f800]
  0x171960ad, 0x2c002f05, 0x2d0d3005, 0x30002329,   // vo.gl.sr_643 su.fy.un_330  uz.cs.sk_333 ky.uz.un_960 
  0x1504380c, 0x1d006a22, 0x322d30a4, 0x19006014,   // tk.ru.un_543 haw.la.un_870  uz.sk.bs_433 vo.gl.un_660 
  0x2f003821, 0x1d004c13, 0x73524714, 0x63003e13,   // tk.su.un_860 wo.la.un_650  sn.ha.ny_666 rm.sco.un_650 
  0x1c3b1e0c, 0x2d79fe05, 0xfe002422, 0x37225fa9,   // ms.so.id_543 tlh.war.sk_333  eo.tlh.un_870 tn.oc.st_544 
  // [1f810]
  0x586520ad, 0xfe2e6ba0, 0x3e431da4, 0x122f1c0c,   // sq.gv.om_643 ceb.fo.tlh_322  la.ie.rm_433 id.su.hu_543 
  0x0a1b69a0, 0x375f7307, 0x6045280c, 0x322752ee,   // mfe.tr.pt_322 ny.tn.st_432  sw.ln.vo_543 ha.gd.bs_422 
  0x0b251f0c, 0x0b0a42a0, 0x0b00fa07, 0x30313ea9,   // cy.eu.es_543 co.pt.es_322  nr.es.un_420 rm.az.uz_544 
  0x4c1302ee, 0x27583ba0, 0x3e3b5212, 0x073c30a4,   // da.et.wo_422 so.om.gd_322  ha.so.rm_654 uz.ug.bg_433 
  // [1f820]
  0x235f5604, 0x1d001319, 0xfe60670c, 0x5f366005,   // mg.tn.ca_332 et.la.un_750  ak.vo.tlh_543 vo.gn.tn_333 
  0x4c002f14, 0x37154412, 0x521e1cad, 0x6b791dee,   // su.wo.un_660 kk.ba.un_640  id.ms.ha_643 la.war.ceb_422 
  0x603e3809, 0x3d12230c, 0x162d7907, 0x1b1a640c,   // tk.rm.vo_444 ky.ur.ku_543  war.sk.hr_432 lg.tl.tr_543 
  0x50003e1b, 0x4f121f0c, 0x33000e1a, 0x382e1da0,   // rm.fj.un_770 cy.hu.bi_543  is.nn.un_760 la.fo.tk_322 
  // [1f830]
  0x1200350d, 0x1d7901a0, 0x562237ee, 0x4600fc07,   // zu.hu.un_540 en.war.la_322  st.oc.mg_422 zzp.qu.un_420 
  0x4523730c, 0x5c110fad, 0x1d0f5c04, 0x09110a0c,   // ny.ca.ln_543 lv.ro.sa_643  sa.lv.la_332 pt.ro.pl_543 
  0x0640250c, 0x01004804, 0x1f4205ad, 0x39403e08,   // eu.lb.de_543 tt.en.un_320  fr.co.cy_643 rm.lb.br_443 
  0x0419fcee, 0x6303300c, 0x2c3f6904, 0x1d0102a4,   // zzp.gl.fi_422 uz.nl.sco_543  mfe.af.fy_332 da.en.la_433 
  // [1f840]
  0x06766904, 0x04020d12, 0x5c001311, 0x53000409,   // mfe.crs.de_332 cs.da.fi_654  bh.sa.un_630 fi.ht.un_440 
  0x120339ee, 0x19000219, 0xfc1939a4, 0x10001d0c,   // br.nl.hu_422 da.gl.un_750  br.gl.zzp_433 la.lt.un_530 
  0x0c43010c, 0x3f023904, 0x05fc19ee, 0x40110608,   // en.ie.sv_543 br.da.af_332  gl.zzp.fr_422 de.ro.lb_443 
  0x43313005, 0x4000190c, 0x1d0523a7, 0x696876a4,   // uz.az.ie_333 gl.lb.un_530  ca.fr.la_532 crs.ig.mfe_433 
  // [1f850]
  0x0c080212, 0x19fc04a9, 0x64000912, 0x190d5ba0,   // da.no.sv_654 fi.zzp.gl_544  pl.lg.un_640 sg.cs.gl_322 
  0x1a5f470c, 0x1f375f12, 0x645f3707, 0x17080712,   // sn.tn.tl_543 tn.st.cy_654  st.tn.lg_432 bg.uk.sr_654 
  0x6400090c, 0x594564a9, 0x46005421, 0x475864ee,   // pl.lg.un_530 lg.ln.rn_544  ik.qu.un_860 lg.om.sn_422 
  0x78456409, 0x3515110b, 0x23213d09, 0x46000922,   // lg.ln.ve_444 ro.tg.un_520  ku.fa.ky_444 pl.qu.un_870 
  // [1f860]
  0x45005d0e, 0xfc3b30a9, 0x30001005, 0x215955ac,   // ss.ln.un_550 uz.so.zzp_544  be.uz.un_330 rw.rn.jw_632 
  0x2d0d60a4, 0x7500370d, 0x34463512, 0x30231f11,   // vo.cs.sk_433 st.nso.un_540  zu.qu.xh_654 cy.ca.uz_653 
  0x34283ba7, 0x4a003019, 0x54004619, 0x174a3808,   // ks.sd.ps_532 uz.yo.un_750  qu.ik.un_750 tk.yo.sr_443 
  0x1d1127a4, 0x361312ad, 0x39020208, 0x2d003009,   // gd.ro.la_433 hu.et.gn_643  da.da.br_443 uz.sk.un_440 
  // [1f870]
  0x6a0401a9, 0x39600213, 0x18381f0b, 0x343d1202,   // en.fi.haw_544 da.vo.br_665  cy.tk.ga_542 ur.ku.ps_222 
  0x73001807, 0x0e292da0, 0x28301212, 0x642055a0,   // ga.ny.un_420 sk.sl.is_322  ur.uz.sd_654 rw.sq.lg_322 
  0x5955130e, 0x10443811, 0x135451ec, 0x73005107,   // et.rw.rn_555 tk.kk.be_653  kl.ik.et_644 kl.ny.un_420 
  0x543b6413, 0x1b25570c, 0x0a0435ee, 0x253256a0,   // lg.so.ik_665 na.eu.tr_543  tg.ru.mk_422 mg.bs.eu_322 
  // [1f880]
  0x1b3459ee, 0x1b00590c, 0x4a004005, 0x4a004c12,   // rn.xh.tr_422 rn.tr.un_530  lb.yo.un_330 wo.yo.un_640 
  0x2500760c, 0x4c40050c, 0x5955250c, 0x3b2c04ee,   // crs.eu.un_530 fr.lb.wo_543  eu.rw.rn_543 fi.fy.so_422 
  0x28005309, 0x040a36a4, 0x04585108, 0x325647af,   // ht.sw.un_440 ab.mk.ru_433  kl.om.fi_443 sn.mg.bs_655 
  0x232544a6, 0x02330812, 0x250f02ee, 0x292011a0,   // kk.mn.ky_521 no.nn.da_654  da.lv.eu_422 ro.sq.sl_322 
  // [1f890]
  0x7600670e, 0x5851fc13, 0x313038a4, 0x46241755,   // ak.crs.un_550 zzp.kl.om_665  tk.uz.az_433 sr.eo.qu_442 
  0x460c240b, 0x0730350b, 0x07442504, 0x2439020c,   // eo.sv.qu_542 tg.uz.bg_542  mn.kk.bg_332 da.br.eo_543 
  0x351704ee, 0x040cfead, 0x34006307, 0x211c0205,   // ru.sr.tg_422 tlh.sv.fi_643  sco.xh.un_420 da.id.jw_333 
  0x024c20a4, 0x46006e14, 0x025f39a4, 0x341b020c,   // sq.wo.da_433 hmn.qu.un_660  br.tn.da_433 da.tr.xh_543 
  // [1f8a0]
  0x460c2407, 0x30654c04, 0x494b37ee, 0x3b2036a4,   // eo.sv.qu_432 wo.gv.uz_332  st.mi.to_422 gn.sq.so_433 
  0x1c122105, 0x494c5807, 0x56190a05, 0x67002133,   // jw.hu.id_333 om.wo.to_432  pt.gl.mg_333 jw.ak.un_A70 
  0x4c00560e, 0x1a553007, 0x2118440d, 0x30784d5a,   // mg.wo.un_550 uz.rw.tl_432  kk.ar.fa_554 aa.ve.uz_553 
  0x2955560c, 0x56003702, 0x303525ad, 0x5800490c,   // mg.rw.sl_543 st.mg.un_220  mn.tg.uz_643 to.om.un_530 
  // [1f8b0]
  0x4300240d, 0x04005207, 0x1c04180c, 0x17054c07,   // eo.ie.un_540 ha.fi.un_420  ga.fi.id_543 wo.fr.sr_432 
  0x251d38a0, 0x56030455, 0x2c000607, 0x2344100b,   // tk.la.eu_322 fi.nl.mg_442  de.fy.un_420 be.kk.ky_542 
  0x5c090d0e, 0x0b4236ee, 0x6300fc09, 0x58000404,   // ne.hi.sa_555 gn.co.es_422  zzp.sco.un_440 fi.om.un_320 
  0x584d3bad, 0x183d3ba7, 0x3c2318a7, 0x1d2812a0,   // so.aa.om_643 ks.ku.ar_532  ar.ky.ug_532 hu.sw.la_322 
  // [1f8c0]
  0x42130408, 0x35170a0b, 0x35150405, 0x5b003614,   // fi.et.co_443 mk.sr.tg_542  ru.tg.un_330 gn.sg.un_660 
  0x1c135c11, 0x0e135107, 0x135c0d55, 0x2d004519,   // sa.bh.mr_653 kl.et.is_432  ne.sa.bh_442 ln.sk.un_750 
  0x2b56390c, 0x5d473607, 0x2c392512, 0x632b010c,   // br.mg.vi_543 gn.sn.ss_432  eu.br.fy_654 en.vi.sco_543 
  0x3b123208, 0x1d07240d, 0x65232ca9, 0x1a212fa0,   // bs.hu.so_443 eo.it.la_554  fy.ca.gv_544 su.jw.tl_322 
  // [1f8d0]
  0x11006519, 0x3b133709, 0x30002f07, 0x4b004923,   // gv.ro.un_750 st.et.so_444  su.uz.un_420 to.mi.un_880 
  0x420a19a9, 0x79603bee, 0x13392c04, 0x303b56ac,   // gl.pt.co_544 so.vo.war_422  fy.br.et_332 mg.so.uz_632 
  0x55795908, 0x4c00380d, 0x1d00611a, 0x360b0f05,   // rn.war.rw_443 tk.wo.un_540  za.la.un_760 lv.es.gn_333 
  0x13003602, 0x2c001902, 0x12555604, 0x3b006b05,   // gn.et.un_220 gl.fy.un_220  mg.rw.hu_332 ceb.so.un_330 
  // [1f8e0]
  0x190a56ee, 0x01001107, 0x321038ee, 0x670d56a4,   // mg.pt.gl_422 ro.en.un_420  tk.lt.bs_422 mg.cs.ak_433 
  0x131617ad, 0x10204b04, 0x6b782da4, 0x565c4ba0,   // sr.hr.et_643 mi.sq.lt_332  sk.ve.ceb_433 mi.sa.mg_322 
  0x48475aa9, 0x5a491c05, 0x63734b0c, 0x181e04a4,   // sm.sn.tt_544 id.to.sm_333  mi.ny.sco_543 fi.ms.ga_433 
  0x32004608, 0x64094ba4, 0x27584bad, 0x3b4d6b08,   // qu.bs.un_430 mi.pl.lg_433  mi.om.gd_643 ceb.aa.so_443 
  // [1f8f0]
  0x483644a7, 0x05223ea4, 0x094e3307, 0x304c4e05,   // kk.ab.tt_532 rm.oc.fr_433  nn.ay.pl_432 ay.wo.uz_333 
  0x18233008, 0x213423a0, 0x02004d12, 0x474b6b08,   // uz.ky.ar_443 ky.ps.fa_322  aa.da.un_640 ceb.mi.sn_443 
  0x1e1c010c, 0x300a080b, 0x3b475107, 0x03003305,   // en.id.ms_543 uk.mk.uz_542  kl.sn.so_432 nn.nl.un_330 
  0x3b024ca9, 0x5e5837a4, 0x3b4d28a9, 0x06355dee,   // wo.da.so_544 st.om.ts_433  sw.aa.so_544 ss.zu.de_422 
  // [1f900]
  0x5d003b08, 0x785f370d, 0x355d28a4, 0x0f2c4c07,   // so.ss.un_430 st.tn.ve_554  sw.ss.zu_433 wo.fy.lv_432 
  0x5a645f08, 0x0f134c12, 0x584c3b13, 0x372845a9,   // tn.lg.sm_443 wo.et.lv_654  so.wo.om_665 ln.sw.st_544 
  0x032c4ca7, 0x10083c04, 0x1517110d, 0x190b1105,   // wo.fy.nl_532 ug.uk.be_332  ro.sr.un_554 ro.es.gl_333 
  0x42640708, 0x475e1ca0, 0x454e5e09, 0x4c4d58a4,   // it.lg.co_443 id.ts.sn_322  ts.ay.ln_444 om.aa.wo_433 
  // [1f910]
  0x5e475f14, 0x37475ea9, 0x0f0711a0, 0x330d09ee,   // tn.sn.ts_666 ts.sn.st_544  ro.it.lv_322 pl.cs.nn_422 
  0x3e01fc55, 0x354d4e12, 0x47002a02, 0x202225a0,   // zzp.en.rm_442 ay.aa.zu_654  mt.sn.un_220 eu.oc.sq_322 
  0x134c3f07, 0x166360ee, 0x384423ad, 0x0839130c,   // af.wo.et_432 vo.sco.hr_422  ky.kk.tk_643 et.br.no_543 
  0x3e00fc05, 0x1767fcad, 0x29477308, 0x0212510c,   // zzp.rm.un_330 zzp.ak.sr_643  ny.sn.sl_443 kl.hu.da_543 
  // [1f920]
  0x42fc3b55, 0x07796bec, 0x251711a6, 0x44003d0d,   // so.zzp.co_442 ceb.war.it_644  ro.sr.mn_521 ku.kk.un_540 
  0x301035a4, 0x24005e0d, 0x51073e08, 0x5300390c,   // tg.be.uz_433 ts.eo.un_540  rm.it.kl_443 br.ht.un_530 
  0x0e766960, 0x193e4fee, 0x0a231fee, 0xfc001904,   // mfe.crs.is_664 bi.rm.gl_422  cy.ca.pt_422 gl.zzp.un_320 
  0x25351107, 0x10393e0c, 0x213044a7, 0x1d6a51af,   // ro.tg.mn_432 rm.br.lt_543  kk.uz.fa_532 kl.haw.la_655 
  // [1f930]
  0x1d095108, 0x0210510e, 0x253507a7, 0x3d1218a7,   // kl.pl.la_443 kl.lt.da_555  bg.tg.mn_532 ar.ur.ku_532 
  0x27001b07, 0x51543b12, 0x1236180c, 0x49005819,   // tr.gd.un_420 so.ik.kl_654  ga.gn.hu_543 om.to.un_750 
  0x21181209, 0x173523ee, 0x2330370c, 0x65002814,   // ur.ar.fa_444 ky.tg.sr_422  ba.uz.ky_543 sw.gv.un_660 
  0x183021ec, 0x2d002b02, 0x1a6b2404, 0x070430ee,   // fa.uz.ar_644 vi.sk.un_220  eo.ceb.tl_332 uz.ru.bg_422 
  // [1f940]
  0x3d182809, 0x070a3804, 0x033f64a0, 0x330810ee,   // sd.ar.ku_444 tk.mk.bg_332  lg.af.nl_322 lt.no.nn_422 
  0x37004307, 0x040a2307, 0x280f5804, 0x76693607,   // ie.st.un_420 ky.mk.ru_432  om.lv.sw_332 gn.mfe.crs_432 
  0x305650a9, 0x025c30a7, 0x281e1c5a, 0x026053a4,   // fj.mg.uz_544 uz.sa.da_532  id.ms.sw_553 ht.vo.da_433 
  0x28006507, 0x64001b05, 0x555d4555, 0x2f1349a4,   // gv.sw.un_420 tr.lg.un_330  ln.ss.rw_442 to.et.su_433 
  // [1f950]
  0x16642c55, 0x36235108, 0x21300207, 0x0b1d46a4,   // fy.lg.hr_442 kl.ca.gn_443  da.uz.jw_432 qu.la.es_433 
  0x30005020, 0x1a547907, 0x482b3104, 0x4551fcec,   // fj.uz.un_850 war.ik.tl_432  az.vi.tt_332 zzp.kl.ln_644 
  0x466a4904, 0x0a1d43a9, 0x2a00280c, 0x18101d04,   // to.haw.qu_332 ie.la.pt_544  sw.mt.un_530 la.lt.ga_332 
  0x1b233007, 0x646867ee, 0x4600fe05, 0x131c5c0b,   // uz.ca.tr_432 ak.ig.lg_422  tlh.qu.un_330 sa.mr.bh_542 
  // [1f960]
  0x46003409, 0x081538a4, 0x1b2a31a4, 0x1d620faf,   // xh.qu.un_440 tk.uk.un_430  az.mt.tr_433 lv.kha.la_655 
  0x34fe3507, 0x19005521, 0x172d2908, 0x59287307,   // zu.tlh.xh_432 rw.gl.un_860  sl.sk.sr_443 ny.sw.rn_432 
  0x23441011, 0x735528ad, 0x347328a4, 0x35002402,   // be.kk.ky_653 sw.rw.ny_643  sw.ny.xh_433 eo.zu.un_220 
  0x393024a4, 0x24001902, 0x34697612, 0x2d353409,   // eo.uz.br_433 gl.eo.un_220  crs.mfe.xh_654 xh.zu.sk_444 
  // [1f970]
  0x645528af, 0x24000323, 0x200603ec, 0x477836af,   // sw.rw.lg_655 nl.eo.un_880  nl.de.sq_644 gn.ve.sn_655 
  0x3435735a, 0x293934a4, 0x286473a0, 0x024773a4,   // ny.zu.xh_553 xh.br.sl_433  ny.lg.sw_322 ny.sn.da_433 
  0x48004712, 0x1959550d, 0x0a15100b, 0x300408a4,   // sn.tt.un_640 rw.rn.gl_554  be.mk.un_520 uk.ru.uz_433 
  0x27186113, 0x0b002405, 0x4831520c, 0x3d233ca4,   // za.ga.gd_665 eo.es.un_330  ha.az.tt_543 ug.ky.ku_433 
  // [1f980]
  0x070a0811, 0x534060a7, 0x2a240204, 0x0a173c05,   // uk.mk.bg_653 vo.lb.ht_532  da.eo.mt_332 ug.sr.mk_333 
  0x4657390c, 0x05220d02, 0x1656210c, 0x1d0964a4,   // br.na.qu_543 cs.oc.fr_222  jw.mg.hr_543 lg.pl.la_433 
  0x353429a0, 0x76001f08, 0x18613955, 0x38466207,   // sl.xh.zu_322 cy.crs.un_430  br.za.ga_442 kha.qu.tk_432 
  0x38517907, 0x392a1ca4, 0x4600310e, 0x08023502,   // war.kl.tk_432 id.mt.br_433  az.qu.un_550 zu.da.no_222 
  // [1f990]
  0x28000c0e, 0x3d343011, 0x44371007, 0x0c5d340c,   // sv.sw.un_550 uz.ps.ku_653  be.ba.kk_432 xh.ss.sv_543 
  0x05001910, 0x215c3308, 0x081517a0, 0xfe46600c,   // gl.fr.un_620 nn.sa.jw_443  sr.uk.un_320 vo.qu.tlh_543 
  0x0c003502, 0x30290f07, 0x5f3701a0, 0x35007813,   // zu.sv.un_220 lv.sl.uz_432  en.st.tn_322 ve.zu.un_650 
  0x510802ee, 0x1dfc5607, 0x39371e0c, 0x4f211c0c,   // da.no.kl_422 mg.zzp.la_432  ms.st.br_543 id.jw.bi_543 
  // [1f9a0]
  0x37002c12, 0x67421c0c, 0x3b3f03a9, 0x645d1c0c,   // fy.st.un_640 id.co.ak_543  nl.af.so_544 id.ss.lg_543 
  0x56004d2b, 0x755f39a9, 0x73695308, 0x68477313,   // aa.mg.un_980 br.tn.nso_544  ht.mfe.ny_443 ny.sn.ig_665 
  0x431ffea4, 0x2046fea4, 0x68470aaf, 0x584f010c,   // tlh.cy.ie_433 tlh.qu.sq_433  pt.sn.ig_655 en.bi.om_543 
  0x6e00fc1a, 0x090dfe5a, 0x47092da4, 0x654d5807,   // zzp.hmn.un_760 tlh.cs.pl_553  sk.pl.sn_433 om.aa.gv_432 
  // [1f9b0]
  0x27090107, 0x5c022708, 0x11182dee, 0x05000212,   // en.pl.gd_432 gd.da.sa_443  sk.ga.ro_422 da.fr.un_640 
  0x32172955, 0x03010207, 0x443c1204, 0x0103150b,   // sl.sr.bs_442 da.en.nl_432  ur.ug.kk_332 un.nl.en_542 
  0x441228a0, 0x03383f0c, 0x3b022712, 0x0c271507,   // sd.ur.kk_322 af.tk.nl_543  gd.da.so_654 un.gd.sv_432 
  0x0c620604, 0x0c153307, 0x37004002, 0x04393b07,   // de.kha.sv_332 nn.sv.un_420  lb.st.un_220 so.br.fi_432 
  // [1f9c0]
  0x1b651102, 0x18004308, 0x306b5cee, 0x3b4925a7,   // ro.gv.tr_222 ie.ga.un_430  sa.ceb.uz_422 eu.to.so_532 
  0x1d000f0c, 0x6500610d, 0x49563b0c, 0x6b691da4,   // lv.la.un_530 za.gv.un_540  so.mg.to_543 la.mfe.ceb_433 
  0x3f00fc13, 0x5c00fe04, 0x38322a02, 0x2c006a02,   // zzp.af.un_650 tlh.sa.un_320  mt.bs.tk_222 haw.fy.un_220 
  0x6b795c08, 0x0679fcee, 0x1d110a04, 0x13043bec,   // sa.war.ceb_443 zzp.war.de_422  pt.ro.la_332 so.fi.et_644 
  // [1f9d0]
  0x1b003205, 0x7347340c, 0x2c4ffca0, 0x6976390d,   // bs.tr.un_330 xh.sn.ny_543  zzp.bi.fy_322 br.crs.mfe_554 
  0x554610a4, 0x381142a0, 0x102825ad, 0x0259555a,   // lt.qu.rw_433 co.ro.tk_322  eu.sw.lt_643 rw.rn.da_553 
  0x222310ec, 0x044063ee, 0x4d5113a9, 0x65353405,   // lt.ca.oc_644 sco.lb.fi_422  et.kl.aa_544 xh.zu.gv_333 
  0x0d006402, 0x1d392308, 0x2e1304a4, 0x133e6307,   // lg.cs.un_220 ca.br.la_443  fi.et.fo_433 sco.rm.et_432 
  // [1f9e0]
  0x79031d0c, 0x76693307, 0x1a466408, 0x3e00600e,   // la.nl.war_543 nn.mfe.crs_432  lg.qu.tl_443 vo.rm.un_550 
  0x19635707, 0x011ffea6, 0x3e105004, 0x4a007812,   // na.sco.gl_432 tlh.cy.en_521  fj.lt.rm_332 ve.yo.un_640 
  0x22766912, 0x62056914, 0x472c5808, 0x05432307,   // mfe.crs.oc_654 mfe.fr.kha_666  om.fy.sn_443 ca.ie.fr_432 
  0x4a684dad, 0x10004619, 0x1f004c0d, 0x283b4d13,   // aa.ig.yo_643 qu.lt.un_750  wo.cy.un_540 aa.so.sw_665 
  // [1f9f0]
  0x2c3b3407, 0x65041308, 0x615873a4, 0x1e3b02a0,   // xh.so.fy_432 et.fi.gv_443  ny.om.za_433 da.so.ms_322 
  0x283020a9, 0x1b1304a7, 0x01794aa0, 0x224305a4,   // sq.uz.sw_544 fi.et.tr_532  yo.war.en_322 fr.ie.oc_433 
  0x02646307, 0x676b3b08, 0x4647780c, 0x19002308,   // sco.lg.da_432 so.ceb.ak_443  ve.sn.qu_543 ca.gl.un_430 
  0x355d300c, 0x4f636005, 0x31002005, 0x3b4d2812,   // uz.ss.zu_543 vo.sco.bi_333  sq.az.un_330 sw.aa.so_654 
  // [1fa00]
  0x3c3038a9, 0x213b61ee, 0x04382355, 0x28024608,   // tk.uz.ug_544 za.so.jw_422  ky.tk.ru_442 qu.da.sw_443 
  0x674a3ba4, 0x2847650c, 0x080c3b0c, 0x3f00400d,   // so.yo.ak_433 gv.sn.sw_543  so.sv.no_543 lb.af.un_540 
  0x276725af, 0x58006205, 0x4d00530e, 0x5d3b350c,   // eu.ak.gd_655 kha.om.un_330  ht.aa.un_550 zu.so.ss_543 
  0x533b2a04, 0x1a0e3b08, 0x2c002102, 0x76693ba4,   // mt.so.ht_332 so.is.tl_443  jw.fy.un_220 so.mfe.crs_433 
  // [1fa10]
  0x11183ba4, 0x2a281807, 0x233e42ad, 0x3b041311,   // so.ga.ro_433 ga.sw.mt_432  co.rm.ca_643 et.fi.so_653 
  0x4a6b1304, 0x3b004d2c, 0x1b693b0c, 0x23002f02,   // et.ceb.yo_332 aa.so.un_990  so.mfe.tr_543 su.ca.un_220 
  0x59553009, 0x31023bad, 0x305d3508, 0x2c4d5808,   // uz.rw.rn_444 so.da.az_643  zu.ss.uz_443 om.aa.fy_443 
  0x3000210c, 0x04002107, 0x3b1f4611, 0x0f584daf,   // jw.uz.un_530 jw.fi.un_420  qu.cy.so_653 aa.om.lv_655 
  // [1fa20]
  0x2a4630ad, 0x5e00520e, 0x190b790c, 0x57650107,   // uz.qu.mt_643 ha.ts.un_550  war.es.gl_543 en.gv.na_432 
  0x070551ec, 0x09003f19, 0x38480da4, 0x190b3608,   // kl.fr.it_644 af.pl.un_750  cs.tt.tk_433 gn.es.gl_443 
  0x38483707, 0x443738af, 0x39003702, 0x59392508,   // ba.tt.tk_432 tk.ba.kk_655  st.br.un_220 eu.br.rn_443 
  0x6431305a, 0x340246a4, 0x47136705, 0x47350aee,   // uz.az.lg_553 qu.da.xh_433  ak.et.sn_333 pt.zu.sn_422 
  // [1fa30]
  0x026b54a9, 0x11227904, 0x45101ca0, 0x5c223507,   // ik.ceb.da_544 war.oc.ro_332  id.lt.ln_322 zu.oc.sa_432 
  0x170d2d0c, 0x56493bec, 0x11420ca4, 0x104d690c,   // sk.cs.sr_543 so.to.mg_644  sv.co.ro_433 mfe.aa.lt_543 
  0x4d3b13a4, 0x4d000107, 0x1302670c, 0x5d5f78ee,   // et.so.aa_433 en.aa.un_420  ak.da.et_543 ve.tn.ss_422 
  0x23001314, 0x34654c0c, 0x2d3825a7, 0x69002513,   // et.ca.un_660 wo.gv.xh_543  eu.tk.sk_532 eu.mfe.un_650 
  // [1fa40]
  0x4f50100c, 0x174c24ee, 0x1b060207, 0x020b0a04,   // lt.fj.bi_543 eo.wo.sr_422  da.de.tr_432 pt.es.da_332 
  0x5d54010c, 0x500c3307, 0x35586807, 0x502851ec,   // en.ik.ss_543 nn.sv.fj_432  ig.om.zu_432 kl.sw.fj_644 
  0x4c004f0e, 0x25101509, 0x070811a7, 0x135c0208,   // bi.wo.un_550 un.lt.eu_444  ro.uk.bg_532 da.sa.et_443 
  0x571d1305, 0x6a3b5804, 0x44000811, 0x644968ee,   // et.la.na_333 om.so.haw_332  uk.kk.un_630 ig.to.lg_422 
  // [1fa50]
  0x2e5c0ba0, 0x190b4eac, 0x5029490b, 0x3446310c,   // es.sa.fo_322 ay.es.gl_632  to.sl.fj_542 az.qu.xh_543 
  0x4f1d5d07, 0x4d001e0e, 0x31344607, 0x11006008,   // ss.la.bi_432 ms.aa.un_550  qu.xh.az_432 vo.ro.un_430 
  0x3e2f050c, 0x08111013, 0x342411ee, 0x313435ad,   // fr.su.rm_543 be.ro.uk_665  ro.eo.xh_422 zu.xh.az_643 
  0xfe353405, 0x04000811, 0x362f0508, 0x4600340c,   // xh.zu.tlh_333 uk.ru.un_630  fr.su.gn_443 xh.qu.un_530 
  // [1fa60]
  0x4600311a, 0x1d314612, 0x463435ad, 0x2f21fc11,   // az.qu.un_760 qu.az.la_654  zu.xh.qu_643 zzp.jw.su_653 
  0x3d3b445a, 0x3f581308, 0x5a58490d, 0x3f5413af,   // kk.ks.ku_553 et.om.af_443  to.om.sm_554 et.ik.af_655 
  0x04006408, 0x3b3f580b, 0x36212fec, 0x1d000313,   // lg.fi.un_430 om.af.so_542  su.jw.gn_644 nl.la.un_650 
  0x36002f0d, 0x2e0e08a0, 0x3f1503ec, 0x022e0e0e,   // su.gn.un_540 no.is.fo_322  nl.af.un_640 is.fo.da_555 
  // [1fa70]
  0x1c1a2fee, 0x2d0d060e, 0x1d033b0c, 0x581d51ad,   // su.tl.id_422 de.cs.sk_555  so.nl.la_543 kl.la.om_643 
  0x5d37fe0d, 0x2f006b22, 0x0a152304, 0x251517a0,   // tlh.st.ss_554 ceb.su.un_870  ky.mk.un_320 sr.mn.un_320 
  0x2d0dfeaf, 0x0e2a3b04, 0x6bfe1a07, 0x15042aa4,   // tlh.cs.sk_655 so.mt.is_332  tl.tlh.ceb_432 bo.ru.un_433 
  0x79fe6b08, 0x0f0c33a0, 0xfe003b19, 0x3700fe13,   // ceb.tlh.war_443 nn.sv.lv_322  so.tlh.un_750 tlh.st.un_650 
  // [1fa80]
  0xfe1e1c14, 0x30fe380c, 0x130efead, 0x443c38af,   // id.ms.tlh_666 tk.tlh.uz_543  tlh.is.et_643 tk.ug.kk_655 
  0x42001321, 0x1b100d55, 0x04081760, 0x060325a7,   // et.co.un_860 cs.lt.tr_442  sr.uk.ru_664 eu.nl.de_532 
  0x53005104, 0x042e1307, 0x480a1707, 0x370a0708,   // kl.ht.un_320 et.fo.fi_432  sr.mk.tt_432 bg.mk.ba_443 
  0x1f233f07, 0x3035360d, 0x3504110d, 0x104804ac,   // af.ca.cy_432 ab.tg.uz_554  ro.ru.tg_554 ru.tt.be_632 
  // [1fa90]
  0x39000402, 0x636204ad, 0x33002102, 0x46245ca7,   // fi.br.un_220 fi.kha.sco_643  jw.nn.un_220 sa.eo.qu_532 
  0x104844af, 0x1600fa08, 0x7667690c, 0x461c02ee,   // kk.tt.be_655 nr.hr.un_430  mfe.ak.crs_543 da.id.qu_422 
  0x275e01a4, 0x0c2168a0, 0x63181fec, 0x64005719,   // en.ts.gd_433 ig.jw.sv_322  cy.ga.sco_644 na.lg.un_750 
  0x0d60fc07, 0x73007829, 0xfc190b14, 0x292d090c,   // zzp.vo.cs_432 ve.ny.un_960  es.gl.zzp_666 pl.sk.sl_543 
  // [1faa0]
  0x33003f13, 0x07223e04, 0xfc1b680c, 0x11003602,   // af.nn.un_650 rm.oc.it_332  ig.tr.zzp_543 gn.ro.un_220 
  0x09002504, 0x462e1da4, 0x120e5da0, 0x35283b07,   // eu.pl.un_320 la.fo.qu_433  ss.is.hu_322 so.sw.zu_432 
  0x1e1c620c, 0x532401a0, 0x631ffea4, 0x032e4f04,   // kha.id.ms_543 en.eo.ht_322  tlh.cy.sco_433 bi.fo.nl_332 
  0x3b2834ad, 0x11006222, 0x6a4b67a4, 0x28003b0b,   // ps.sd.ks_643 kha.ro.un_870  ak.mi.haw_433 ks.sd.un_520 
  // [1fab0]
  0x4647730c, 0x4b005611, 0x37005604, 0x5c183b04,   // ny.sn.qu_543 mg.mi.un_630  mg.st.un_320 so.ga.sa_332 
  0x3d21220d, 0x6300fe18, 0x52004607, 0x5cfc58a0,   // si.fa.ku_554 tlh.sco.un_740  qu.ha.un_420 om.zzp.sa_322 
  0xfcfe0614, 0x5e1f2108, 0x464c4e12, 0x7963fcaf,   // de.tlh.zzp_666 jw.cy.ts_443  ay.wo.qu_654 zzp.sco.war_655 
  0x2138300c, 0x1700610b, 0x4b5f40ee, 0x2e0e3305,   // uz.tk.jw_543 za.sr.un_520  lb.tn.mi_422 nn.is.fo_333 
  // [1fac0]
  0x383152ee, 0xfe000905, 0x374b0407, 0x080710ee,   // ha.az.tk_422 pl.tlh.un_330  fi.mi.st_432 be.bg.uk_422 
  0x43003b0d, 0x030c6007, 0x132f3708, 0x39000f09,   // so.ie.un_540 vo.sv.nl_432  st.su.et_443 lv.br.un_440 
  0x1546fcee, 0x3b584608, 0x2c2710a7, 0x53005c05,   // zzp.qu.un_422 qu.om.so_443  lt.gd.fy_532 sa.ht.un_330 
  0x20303904, 0x09fe6505, 0x4600290d, 0x68002b21,   // br.uz.sq_332 gv.tlh.pl_333  sl.qu.un_540 vi.ig.un_860 
  // [1fad0]
  0x29301709, 0x233004ec, 0x1257fc55, 0x1f48feee,   // sr.uz.sl_444 fi.uz.ca_644  zzp.na.hu_442 tlh.tt.cy_422 
  0x1d4d1a05, 0x33fc2e12, 0x3700560b, 0x2533fc05,   // tl.aa.la_333 fo.zzp.nn_654  mg.st.un_520 zzp.nn.eu_333 
  0x4b003608, 0x58131fa0, 0x3831fc55, 0x2d00040c,   // gn.mi.un_430 cy.et.om_322  zzp.az.tk_442 fi.sk.un_530 
  0x2e002f07, 0x10011502, 0x2e610e13, 0x05392fee,   // su.fo.un_420 un.en.lt_222  is.za.fo_665 su.br.fr_422 
  // [1fae0]
  0x381a0212, 0x082e0e0c, 0x30483504, 0x53360aa0,   // da.tl.tk_654 is.fo.no_543  tg.tt.uz_332 pt.gn.ht_322 
  0x27060207, 0x33005a08, 0x34233da4, 0x131d0407,   // da.de.gd_432 sm.nn.un_430  ku.ky.ps_433 fi.la.et_432 
  0x3e050204, 0x13007907, 0x35170405, 0x13004f0b,   // da.fr.rm_332 war.et.un_420  ru.sr.tg_333 bi.et.un_520 
  0x59551cee, 0x23443d0c, 0x041536a9, 0x5d35feaf,   // id.rw.rn_422 ku.kk.ky_543  ab.ru.un_540 tlh.zu.ss_655 
  // [1faf0]
  0x076422a6, 0x42073eee, 0x55002f08, 0x0f1b1307,   // oc.lg.it_521 rm.it.co_422  su.rw.un_430 et.tr.lv_432 
  0x64006013, 0x22000304, 0x3b61fe07, 0x554830a0,   // vo.lg.un_650 nl.oc.un_320  tlh.za.so_432 uz.tt.rw_322 
  0x173c35ad, 0x46003423, 0x49034007, 0x1e466b09,   // tg.ug.sr_643 xh.qu.un_880  lb.nl.to_432 ceb.qu.ms_444 
  0x65634c55, 0xfe6234a4, 0x34374d09, 0x5d00fc0c,   // wo.sco.gv_442 xh.kha.tlh_433  aa.st.xh_444 zzp.ss.un_530 
  // [1fb00]
  0x3412285a, 0x28033408, 0x151834a0, 0x34646505,   // sd.ur.ps_553 xh.nl.sw_443  xh.ga.un_322 gv.lg.xh_333 
  0x351e1c02, 0x21491e07, 0x2c6e4c0c, 0x061b30a4,   // id.ms.zu_222 ms.to.jw_432  wo.hmn.fy_543 uz.tr.de_433 
  0x07113e14, 0x036e34ec, 0x644c3412, 0x6e004c0d,   // rm.ro.it_666 xh.hmn.nl_644  xh.wo.lg_654 wo.hmn.un_540 
  0x3f002a02, 0x4800fe0e, 0x3b003104, 0x5e005d1b,   // mt.af.un_220 tlh.tt.un_550  az.so.un_320 ss.ts.un_770 
  // [1fb10]
  0x5f6301a4, 0x30fe51a9, 0x1704080e, 0x4d6463a4,   // en.sco.tn_433 kl.tlh.uz_544  uk.ru.sr_555 sco.lg.aa_433 
  0x4c0413ec, 0x0a174804, 0x37070402, 0x15000a21,   // et.fi.wo_644 tt.sr.mk_332  ru.bg.ba_222 mk.un.un_860 
  0x30002a05, 0x73005921, 0x5d34fa0c, 0x355624ee,   // mt.uz.un_330 rn.ny.un_860  nr.xh.ss_543 eo.mg.zu_422 
  0x190b59ee, 0x3c3d2312, 0x350417ad, 0x0b003411,   // rn.es.gl_422 ky.ku.ug_654  sr.ru.tg_643 xh.es.un_630 
  // [1fb20]
  0x55025904, 0x5e28730c, 0x39632a08, 0x3b00060d,   // rn.da.rw_332 ny.sw.ts_543  mt.sco.br_443 de.so.un_540 
  0x060e2ea4, 0x42072a14, 0x4b0e3ba7, 0x12311b55,   // fo.is.de_433 mt.it.co_666  so.is.mi_532 tr.az.hu_442 
  0x0e000612, 0x57002821, 0x283b6aec, 0x482a38ad,   // de.is.un_640 sw.na.un_860  haw.so.sw_644 tk.mt.tt_643 
  0x645e280c, 0x4a42230c, 0x5c0602a0, 0x1a6b2fee,   // sw.ts.lg_543 ca.co.yo_543  da.de.sa_322 su.ceb.tl_422 
  // [1fb30]
  0x401e0655, 0x2e0e400c, 0x2e001321, 0x04000f05,   // de.ms.lb_442 lb.is.fo_543  et.fo.un_860 lv.fi.un_330 
  0x6b1a790e, 0x23001107, 0x29001302, 0x1013390c,   // war.tl.ceb_555 ro.ky.un_420  et.sl.un_220 br.et.lt_543 
  0x04581308, 0x07302aa0, 0x045158af, 0x303848af,   // et.om.fi_443 mt.uz.it_322  om.kl.fi_655 tt.tk.uz_655 
  0x5800040e, 0x45000520, 0x2f4f2307, 0x6b005809,   // fi.om.un_550 fr.ln.un_850  ca.bi.su_432 om.ceb.un_440 
  // [1fb40]
  0x3000051a, 0x58005114, 0x3b005811, 0x05000a21,   // fr.uz.un_760 kl.om.un_660  om.so.un_630 pt.fr.un_860 
  0x3216020c, 0x18001d05, 0x1d10560c, 0x792d0d0d,   // da.hr.bs_543 la.ga.un_330  mg.lt.la_543 cs.sk.war_554 
  0x590f0205, 0x370411a4, 0x37205307, 0x16005507,   // da.lv.rn_333 ro.ru.ba_433  ht.sq.st_432 rw.hr.un_420 
  0x190527ee, 0x170437ad, 0x043f51a0, 0x190a0409,   // gd.fr.gl_422 ba.ru.sr_643  kl.af.fi_322 fi.pt.gl_444 
  // [1fb50]
  0x376301a4, 0x04000514, 0x3b584d11, 0x0415440c,   // en.sco.st_433 fr.fi.un_660  aa.om.so_653 kk.ru.un_530 
  0x271d0402, 0x59001007, 0x2b1e0107, 0x635f0107,   // fi.la.gd_222 lt.rn.un_420  en.ms.vi_432 en.tn.sco_432 
  0x3c30230d, 0x47222307, 0x3f000205, 0x4a005805,   // ky.uz.ug_554 ca.oc.sn_432  da.af.un_330 om.yo.un_330 
  0x1827fca0, 0x643b670c, 0x1b4249ec, 0x310d42a0,   // zzp.gd.ga_322 ak.so.lg_543  to.co.tr_644 co.cs.az_322 
  // [1fb60]
  0x100f42a0, 0x5a001112, 0x36001909, 0x36004405,   // co.lv.lt_322 ro.sm.un_640  gl.gn.un_440 kk.ab.un_330 
  0xfc5c30a0, 0x49005a2c, 0x090f42ee, 0x045c12a9,   // uz.sa.zzp_322 sm.to.un_990  co.lv.pl_422 hu.sa.fi_544 
  0x54626aaf, 0x0f1b4204, 0x2a0f1007, 0x4b566707,   // haw.kha.ik_655 co.tr.lv_332  lt.lv.mt_432 ak.mg.mi_432 
  0x28004b02, 0x5c00040e, 0x1e1c15a0, 0x390501ee,   // mi.sw.un_220 fi.sa.un_550  un.id.ms_322 en.fr.br_422 
  // [1fb70]
  0x2b001302, 0x34001904, 0x5c001209, 0x07001604,   // et.vi.un_220 gl.xh.un_320  hu.sa.un_440 hr.it.un_320 
  0x52552807, 0x223923a7, 0x37040aad, 0x6100360e,   // sw.rw.ha_432 ca.br.oc_532  mk.ru.ba_643 gn.za.un_550 
  0x39004304, 0x2500110b, 0x2a0773ec, 0x40390609,   // ie.br.un_320 ro.mn.un_520  ny.it.mt_644 de.br.lb_444 
  0x0c00fc09, 0x300764ad, 0x54003613, 0x351504a4,   // zzp.sv.un_440 lg.it.uz_643  gn.ik.un_650 ru.tg.un_430 
  // [1fb80]
  0x2d00361a, 0x61005321, 0x6254360c, 0x28792b04,   // gn.sk.un_760 ht.za.un_860  gn.ik.kha_543 vi.war.sw_332 
  0x371f1102, 0x15363507, 0x07022a0d, 0x04304804,   // ro.cy.st_222 tg.ab.un_432  mt.da.it_554 tt.uz.ru_332 
  0x48170a12, 0x2d000f0c, 0x372978a9, 0x2d00100c,   // mk.sr.tt_654 lv.sk.un_530  ve.sl.st_544 lt.sk.un_530 
  0x4c00210e, 0x12653307, 0x376a3660, 0x131e4c08,   // jw.wo.un_550 nn.gv.hu_432  gn.haw.st_664 wo.ms.et_443 
  // [1fb90]
  0x3217200c, 0x64204707, 0xfe6b02a0, 0x0200061a,   // sq.sr.bs_543 sn.sq.lg_432  da.ceb.tlh_322 de.da.un_760 
  0x321642a6, 0x3b1304ad, 0x6a4723a4, 0x3052fe04,   // co.hr.bs_521 fi.et.so_643  ca.sn.haw_433 tlh.ha.uz_332 
  0x211a1ea7, 0x02004312, 0x30292d04, 0x20001e04,   // ms.tl.jw_532 ie.da.un_640  sk.sl.uz_332 ms.sq.un_320 
  0xfe00620e, 0x321625ee, 0x4c654daf, 0x20001f12,   // kha.tlh.un_550 eu.hr.bs_422  aa.gv.wo_655 cy.sq.un_640 
  // [1fba0]
  0x251708a0, 0x6b537308, 0x19472907, 0x0e083312,   // uk.sr.mn_322 ny.ht.ceb_443  sl.sn.gl_432 nn.no.is_654 
  0x25677811, 0x3e100d04, 0x6800452a, 0x6100301a,   // ve.ak.eu_653 cs.lt.rm_332  ln.ig.un_970 uz.za.un_760 
  0xfe100fa4, 0x190a28af, 0x791501a4, 0x016506ee,   // lv.lt.tlh_433 sw.pt.gl_655  en.war.un_430 de.gv.en_422 
  0x0b36190d, 0x20314802, 0x1b00350e, 0x47002108,   // gl.gn.es_554 tt.az.sq_222  zu.tr.un_550 jw.sn.un_430 
  // [1fbb0]
  0x67527311, 0x250b6007, 0x42040507, 0x052f40a0,   // ny.ha.ak_653 vo.es.eu_432  fr.fi.co_432 lb.su.fr_322 
  0x2f3f04ad, 0x560542ac, 0x4808040e, 0x190a09a0,   // fi.af.su_643 co.fr.mg_632  ru.uk.tt_555 pl.pt.gl_322 
  0x1f006407, 0x45052fa0, 0x17082504, 0x120905a0,   // lg.cy.un_420 su.fr.ln_322  mn.uk.sr_332 fr.pl.hu_322 
  0x552f05ee, 0x370a0407, 0x33002f07, 0x2f050904,   // fr.su.rw_422 ru.mk.ba_432  su.nn.un_420 pl.fr.su_332 
  // [1fbc0]
  0x134205a7, 0x22052f04, 0x2f3604ec, 0x15251507,   // fr.co.et_532 su.fr.oc_332  fi.gn.su_644 un.mn.un_432 
  0x21732808, 0x100411ad, 0x5e4778a4, 0x254837ee,   // sw.ny.jw_443 ro.ru.be_643  ve.sn.ts_433 ba.tt.mn_422 
  0x39332f0d, 0x33081ea0, 0x0a3e0107, 0xfc340304,   // su.nn.br_554 ms.no.nn_322  en.rm.pt_432 nl.xh.zzp_332 
  0x39121fa4, 0x19360b08, 0x340625a4, 0x34675da9,   // cy.hu.br_433 es.gn.gl_443  eu.de.xh_433 ss.ak.xh_544 
  // [1fbd0]
  0x09000a04, 0x09345d0c, 0x391a18a4, 0x0a084802,   // pt.pl.un_320 ss.xh.pl_543  ga.tl.br_433 tt.uk.mk_222 
  0xfe005807, 0x76006513, 0x40004504, 0x3e002404,   // om.tlh.un_420 gv.crs.un_650  ln.lb.un_320 eo.rm.un_320 
  0x35172507, 0x062832a0, 0x450105ac, 0x79006304,   // mn.sr.tg_432 bs.sw.de_322  fr.en.ln_632 sco.war.un_320 
  0x1e2243ee, 0x0f653e07, 0x190b39a0, 0x1900150b,   // ie.oc.ms_422 rm.gv.lv_432  br.es.gl_322 un.gl.un_520 
  // [1fbe0]
  0x1530150c, 0x06003107, 0x38006512, 0x08103505,   // un.uz.un_543 az.de.un_420  gv.tk.un_640 tg.be.uk_333 
  0x653638af, 0x580413a0, 0x072039a0, 0x39250faf,   // tk.gn.gv_655 et.fi.om_322  br.sq.it_322 lv.eu.br_655 
  0x2c030208, 0x3b581f12, 0x34353707, 0x043f13a0,   // da.nl.fy_443 cy.om.so_654  st.zu.xh_432 et.af.fi_322 
  0x581804ad, 0x5c3b2112, 0x6b0e36a4, 0x511a7908,   // fi.ga.om_643 jw.so.sa_654  gn.is.ceb_433 war.tl.kl_443 
  // [1fbf0]
  0x300a35a0, 0x2e796bad, 0x79001a22, 0x23200ba4,   // tg.mk.uz_322 ceb.war.fo_643  tl.war.un_870 es.sq.ca_433 
  0x214c52a0, 0x19641355, 0x46fe36ad, 0x0200360e,   // ha.wo.jw_322 et.lg.gl_442  gn.tlh.qu_643 gn.da.un_550 
  0x2f4a1aa4, 0x4c57250c, 0x2f003e04, 0x231d3604,   // tl.yo.su_433 eu.na.wo_543  rm.su.un_320 gn.la.ca_332 
  0x782137ad, 0x0a006b05, 0x25006e08, 0x554cfe0c,   // st.jw.ve_643 ceb.pt.un_330  hmn.eu.un_430 tlh.wo.rw_543 
  
  // [1fc00]
  0x28625509, 0x1f2f1a08, 0x37755da9, 0xfc186505,   // rw.kha.sw_444 tl.su.cy_443  ss.nso.st_544 gv.ga.zzp_333 
  0x69270107, 0x79074208, 0x024013af, 0x23002f22,   // en.gd.mfe_432 co.it.war_443  et.lb.da_655 su.ca.un_870 
  0x1a0401a0, 0x2f211a09, 0x1d0efea4, 0x28001a02,   // en.fi.tl_322 tl.jw.su_444  tlh.is.la_433 tl.sw.un_220 
  0x57600107, 0x34351d04, 0x5d285204, 0x0e0c1507,   // en.vo.na_432 la.zu.xh_332  ha.sw.ss_332 un.sv.is_432 
  // [1fc10]
  0x0e132e0d, 0x3f033e04, 0x531f39ad, 0x49003e08,   // fo.et.is_554 rm.nl.af_332  br.cy.ht_643 rm.to.un_430 
  0x24212f07, 0x5d3565af, 0x22001b07, 0x27001321,   // su.jw.eo_432 gv.zu.ss_655  tr.oc.un_420 et.gd.un_860 
  0x1f002814, 0x18133904, 0x0a3e6502, 0x21000304,   // sw.cy.un_660 br.et.ga_332  gv.rm.pt_222 nl.jw.un_320 
  0x124c65a4, 0x1b3330a7, 0x011dfc05, 0x120e2e09,   // gv.wo.hu_433 uz.nn.tr_532  zzp.la.en_333 fo.is.hu_444 
  // [1fc20]
  0x050b63a0, 0x250437a0, 0x36004d04, 0x4800020c,   // sco.es.fr_322 ba.ru.mn_322  aa.gn.un_320 da.tt.un_530 
  0x48102055, 0x1042020c, 0x102d20ee, 0x20456907,   // sq.lt.tt_442 da.co.lt_543  sq.sk.lt_422 mfe.ln.sq_432 
  0x044837a0, 0x2d1b20ee, 0x11002604, 0x1b3173a4,   // ba.tt.ru_322 sq.tr.sk_422  ia.ro.un_320 ny.az.tr_433 
  0x191d2609, 0x20101304, 0x20101308, 0x65fc02a0,   // ia.la.gl_444 et.lt.sq_332  et.lt.sq_443 da.zzp.gv_322 
  // [1fc30]
  0x48251004, 0x0e42090c, 0x18fc6507, 0x17420e08,   // be.mn.tt_332 pl.co.is_543  gv.zzp.ga_432 is.co.sr_443 
  0x320e42a4, 0x4b6a42a4, 0x104d0e60, 0x10420ea7,   // co.is.bs_433 co.haw.mi_433  is.aa.lt_664 is.co.lt_532 
  0x1700250d, 0x23003f04, 0x36072504, 0xfc465f0c,   // mn.sr.un_540 af.ca.un_320  mn.bg.ab_332 tn.qu.zzp_543 
  0x46002107, 0x420521ad, 0x33000c0b, 0x2a4c4604,   // jw.qu.un_420 jw.fr.co_643  sv.nn.un_520 qu.wo.mt_332 
  // [1fc40]
  0x320e4208, 0x044f2ea0, 0x160e42a4, 0x0e12560c,   // co.is.bs_443 fo.bi.fi_322  co.is.hr_433 mg.hu.is_543 
  0x174c0ea4, 0x06003013, 0x19002004, 0x04253504,   // is.wo.sr_433 uz.de.un_650  sq.gl.un_320 tg.mn.ru_332 
  0x1e041b08, 0x300e0407, 0x2f3062a0, 0x791a6bac,   // tr.fi.ms_443 fi.is.uz_432  kha.uz.su_322 ceb.tl.war_632 
  0x10005305, 0x79001a05, 0x21006505, 0x03085aa0,   // ht.lt.un_330 tl.war.un_330  gv.jw.un_330 sm.no.nl_322 
  // [1fc50]
  0x551234a7, 0x1c062fa0, 0x240c36ec, 0x1863150c,   // xh.hu.rw_532 su.de.id_322  gn.sv.eo_644 un.sco.ga_543 
  0x0143600c, 0xfe002f0d, 0x2d00300d, 0x403e065a,   // vo.ie.en_543 su.tlh.un_540  uz.sk.un_540 de.rm.lb_553 
  0x13040e04, 0x190a05ee, 0x0d000505, 0x03002a07,   // is.fi.et_332 fr.pt.gl_422  fr.cs.un_330 mt.nl.un_420 
  0x45002307, 0x1c6b0107, 0x23110aa4, 0x58001d0c,   // ca.ln.un_420 en.ceb.id_432  mk.ro.ky_433 la.om.un_530 
  // [1fc60]
  0x1e001012, 0x1f3e6eec, 0x196e1a0c, 0x3848370e,   // lt.ms.un_640 hmn.rm.cy_644  tl.hmn.gl_543 ba.tt.tk_555 
  0x6e001f22, 0x0b006e07, 0x230c1fa7, 0x0e1a30a7,   // cy.hmn.un_870 hmn.es.un_420  cy.sv.ca_532 uz.tl.is_532 
  0xfc315207, 0x0b23260c, 0x783e47a4, 0x380e27ee,   // ha.az.zzp_432 ia.ca.es_543  sn.rm.ve_433 gd.is.tk_422 
  0x78605012, 0x760569af, 0x34003c1a, 0x1069420c,   // fj.vo.ve_654 mfe.fr.crs_655  ug.ps.un_760 co.mfe.lt_543 
  // [1fc70]
  0x303d2104, 0x05792208, 0x4504050c, 0x055d10a0,   // fa.ku.uz_332 oc.war.fr_443  fr.fi.ln_543 lt.ss.fr_322 
  0x190a26ec, 0x05113eee, 0x3f2c4207, 0x6e00050d,   // ia.pt.gl_644 rm.ro.fr_422  co.fy.af_432 fr.hmn.un_540 
  0x551169ec, 0x31305504, 0x2d000b04, 0x47045e0e,   // mfe.ro.rw_644 rw.uz.az_332  es.sk.un_320 ts.fi.sn_555 
  0xfe3e13a4, 0x31382707, 0x460a05ee, 0x3500170c,   // et.rm.tlh_433 gd.tk.az_432  fr.pt.qu_422 sr.tg.un_530 
  // [1fc80]
  0x014615a6, 0x190d2d0c, 0x554a3707, 0x0e3013a7,   // un.qu.en_521 sk.cs.gl_543  st.yo.rw_432 et.uz.is_532 
  0x59002c08, 0x063f2cee, 0x2d002911, 0x06002c0c,   // fy.rn.un_430 fy.af.de_422  sl.sk.un_630 fy.de.un_530 
  0x10001307, 0x3f2c68ad, 0x0f001313, 0x4c642eee,   // et.lt.un_420 ig.fy.af_643  et.lv.un_650 fo.lg.wo_422 
  0x3e0163ee, 0x4835150c, 0x0e0c330c, 0x0f4710a7,   // sco.en.rm_422 un.tg.tt_543  nn.sv.is_543 lt.sn.lv_532 
  // [1fc90]
  0x1000130b, 0x20004307, 0x3f062c12, 0x3f062ca4,   // et.lt.un_520 ie.sq.un_420  fy.de.af_654 fy.de.af_433 
  0x44040a02, 0x0825150d, 0x233710ad, 0x443d2113,   // mk.ru.kk_222 un.mn.uk_554  be.ba.ky_643 fa.ku.kk_665 
  0x28213b08, 0x1d5e26ad, 0x12001107, 0x44303ca9,   // ks.fa.sd_443 ia.ts.la_643  ro.hu.un_420 ug.uz.kk_544 
  0x5a560402, 0x05000413, 0x36005c05, 0x2a526107,   // fi.mg.sm_222 fi.fr.un_650  sa.gn.un_330 za.ha.mt_432 
  // [1fca0]
  0x5c13615a, 0x31630204, 0x10045aee, 0x31040ca0,   // za.et.sa_553 da.sco.az_332  sm.fi.lt_422 sv.fi.az_322 
  0x150817ee, 0x03004005, 0x130f5c0c, 0x222405ee,   // sr.uk.un_422 lb.nl.un_330  sa.lv.et_543 fr.eo.oc_422 
  0x39765ca4, 0x27004a02, 0x10040f08, 0x03064204,   // sa.crs.br_433 yo.gd.un_220  lv.fi.lt_443 co.de.nl_332 
  0x07043612, 0x46004207, 0x17303507, 0x2f3b1ea0,   // ab.ru.bg_654 co.qu.un_420  tg.uz.sr_432 ms.so.su_322 
  // [1fcb0]
  0x292d30a0, 0x3b285904, 0x09000f1a, 0x35173002,   // uz.sk.sl_322 rn.sw.so_332  lv.pl.un_760 uz.sr.tg_222 
  0x36005013, 0x30735da9, 0x021e01a0, 0x28004819,   // fj.gn.un_650 ss.ny.uz_544  en.ms.da_322 tt.sw.un_750 
  0x2c482da9, 0x6a26130c, 0x02046a0c, 0x17353ca4,   // sk.tt.fy_544 et.ia.haw_543  haw.fi.da_543 ug.tg.sr_433 
  0x330829ec, 0x573e0107, 0x343b1804, 0x482c2d0b,   // sl.no.nn_644 en.rm.na_432  ar.ks.ps_332 sk.fy.tt_542 
  // [1fcc0]
  0x393052a7, 0x346a28ad, 0x253469a4, 0x2f1c21ac,   // ha.uz.br_532 sw.haw.xh_643  mfe.xh.eu_433 jw.id.su_632 
  0x40646a05, 0x1f00461a, 0x515360ad, 0x4c640907,   // haw.lg.lb_333 qu.cy.un_760  vo.ht.kl_643 pl.lg.wo_432 
  0x3800340b, 0x1879090c, 0x37007818, 0x0e130604,   // xh.tk.un_520 pl.war.ga_543  ve.st.un_740 de.et.is_332 
  0x30005607, 0x070a3ca4, 0x48351dee, 0x37571fa7,   // mg.uz.un_420 ug.mk.bg_433  la.zu.tt_422 cy.na.st_532 
  // [1fcd0]
  0x4b5c0fee, 0x23353e07, 0x18006523, 0x07173507,   // lv.sa.mi_422 rm.zu.ca_432  gv.ga.un_880 tg.sr.bg_432 
  0x043b1302, 0x1e002004, 0x190b380c, 0x2a353460,   // et.so.fi_222 sq.ms.un_320  tk.es.gl_543 xh.zu.mt_664 
  0x340635ee, 0x1d001f09, 0x1d753712, 0x2c375f55,   // zu.de.xh_422 cy.la.un_440  st.nso.la_654 tn.st.fy_442 
  0x2b353405, 0x0e0406a9, 0x1304060c, 0x4600060d,   // xh.zu.vi_333 de.fi.is_544  de.fi.et_543 de.qu.un_540 
  // [1fce0]
  0x371c65ee, 0x182b20a4, 0x46002305, 0x59002804,   // gv.id.st_422 sq.vi.ga_433  ca.qu.un_330 sw.rn.un_320 
  0x1e255107, 0x18273913, 0x20182707, 0x672420a4,   // kl.eu.ms_432 br.gd.ga_665  gd.ga.sq_432 sq.eo.ak_433 
  0x170415af, 0x30002b07, 0x0a3f200b, 0x18791b04,   // un.ru.sr_655 vi.uz.un_420  sq.af.pt_542 tr.war.ga_332 
  0x1b001e13, 0x57232b11, 0x5d36120c, 0x3900200d,   // ms.tr.un_650 vi.ca.na_653  hu.gn.ss_543 sq.br.un_540 
  // [1fcf0]
  0x2b1c1e0c, 0x230a0b5a, 0x53232207, 0x173736a9,   // ms.id.vi_543 es.pt.ca_553  oc.ca.ht_432 ab.ba.sr_544 
  0x53fe1107, 0x48303107, 0x53131b0c, 0x13002308,   // ro.tlh.ht_432 az.uz.tt_432  tr.et.ht_543 ca.et.un_430 
  0x3500070e, 0x1312fea7, 0x192d1204, 0x17001209,   // bg.tg.un_550 tlh.hu.et_532  hu.sk.gl_332 hu.sr.un_440 
  0x36654dad, 0x582f20a4, 0x2e0e1219, 0x1222230c,   // aa.gv.gn_643 sq.su.om_433  hu.is.fo_765 ca.oc.hu_543 
  // [1fd00]
  0x274c4d0c, 0x0651fc08, 0x46000305, 0x21383ba0,   // aa.wo.gd_543 zzp.kl.de_443  nl.qu.un_330 so.tk.jw_322 
  0x53232204, 0x0526010c, 0x0912feee, 0xfc0a3eee,   // oc.ca.ht_332 en.ia.fr_543  tlh.hu.pl_422 rm.pt.zzp_422 
  0x47001f18, 0x0e2e33ee, 0x21002820, 0x52473504,   // cy.sn.un_740 nn.fo.is_422  sd.fa.un_850 zu.sn.ha_332 
  0x2f1e1c07, 0x08056304, 0x20220e55, 0x3b3447a0,   // id.ms.su_432 sco.fr.no_332  is.oc.sq_442 sn.xh.so_322 
  // [1fd10]
  0x2000020c, 0x2763180c, 0x65000222, 0x343044a0,   // da.sq.un_530 ga.sco.gd_543  da.gv.un_870 kk.uz.ps_322 
  0x3f390208, 0x6b792f0d, 0x05001804, 0x5f372009,   // da.br.af_443 su.war.ceb_554  ga.fr.un_320 sq.st.tn_444 
  0x632c6011, 0x4768240c, 0x78655da4, 0x554a5907,   // vo.fy.sco_653 eo.ig.sn_543  ss.gv.ve_433 rn.yo.rw_432 
  0x2809040c, 0x1c001d08, 0x04fe5b0d, 0x59001508,   // fi.pl.sw_543 la.id.un_430  sg.tlh.fi_554 un.rn.un_430 
  // [1fd20]
  0x0910040c, 0x05004a0b, 0x1b1120ee, 0x5305220d,   // fi.lt.pl_543 yo.fr.un_520  sq.ro.tr_422 oc.fr.ht_554 
  0x2e022da4, 0x217873a4, 0x185265ee, 0x63092d0c,   // sk.da.fo_433 ny.ve.jw_433  gv.ha.ga_422 sk.pl.sco_543 
  0x45733507, 0x4e0238a4, 0x5f2c2d11, 0x34005909,   // zu.ny.ln_432 tk.da.ay_433  sk.fy.tn_653 rn.xh.un_440 
  0x02650c02, 0x4030020d, 0x11151d0d, 0x491501a4,   // sv.gv.da_222 da.uz.lb_554  la.ro.un_540 en.to.un_430 
  // [1fd30]
  0x2a402c55, 0x0e112e12, 0x5964610d, 0x4844375a,   // fy.lb.mt_442 fo.ro.is_654  za.lg.rn_554 ba.kk.tt_553 
  0x40060909, 0x1763010b, 0x02fe650c, 0x2d1c02ee,   // pl.de.lb_444 en.sco.sr_542  gv.tlh.da_543 da.id.sk_422 
  0x3f02fc07, 0xfe686505, 0x302820ad, 0x0c0a050c,   // zzp.da.af_432 gv.ig.tlh_333  sq.sw.uz_643 fr.pt.sv_543 
  0x0b072304, 0x1e1c2f07, 0x655d47a0, 0x103f04a9,   // ca.it.es_332 su.id.ms_432  sn.ss.gv_322 fi.af.lt_544 
  // [1fd40]
  0x2d0d34ac, 0x09110f14, 0x653015a4, 0x1a2d0d04,   // xh.cs.sk_632 lv.ro.pl_666  un.uz.gv_433 cs.sk.tl_332 
  0x2204060d, 0x2f00290c, 0x037909ad, 0x59002813,   // de.fi.oc_554 sl.su.un_530  pl.war.nl_643 sw.rn.un_650 
  0x04242aa4, 0x400208a0, 0x2a00460b, 0x2432160b,   // mt.eo.fi_433 no.da.lb_322  qu.mt.un_520 hr.bs.eo_542 
  0x08003609, 0x024e1e0c, 0x18564ea9, 0x4300150c,   // ab.uk.un_440 ms.ay.da_543  ay.mg.ga_544 un.ie.un_530 
  // [1fd50]
  0x5c616ea4, 0x454e670d, 0x32004e07, 0x312f5cee,   // hmn.za.sa_433 ak.ay.ln_554  ay.bs.un_420 sa.su.az_422 
  0x11016502, 0x2d003913, 0x565a43ee, 0x5a0264a4,   // gv.en.ro_222 br.sk.un_650  ie.sm.mg_422 lg.da.sm_433 
  0x641b30a7, 0x390143ee, 0x5c006e14, 0x026847a9,   // uz.tr.lg_532 ie.en.br_422  hmn.sa.un_660 sn.ig.da_544 
  0x531b43ee, 0x12675c5a, 0x1b006107, 0x014d62a4,   // ie.tr.ht_422 sa.ak.hu_553  za.tr.un_420 kha.aa.en_433 
  // [1fd60]
  0x383161ec, 0x48101112, 0x18004909, 0x1800450c,   // za.az.tk_644 ro.be.tt_654  to.ga.un_440 ln.ga.un_530 
  0x1b00520c, 0x0d792d07, 0x40253e08, 0x35524e0c,   // ha.tr.un_530 sk.war.cs_432  rm.eu.lb_443 ay.ha.zu_543 
  0x191d430c, 0x2f281ea4, 0x45344e0c, 0x1d005c1a,   // ie.la.gl_543 ms.sw.su_433  ay.xh.ln_543 sa.la.un_760 
  0x4d584e12, 0x5b525ca4, 0x24230f02, 0x133143a0,   // ay.om.aa_654 sa.ha.sg_433  lv.ca.eo_222 ie.az.et_322 
  // [1fd70]
  0x2e000b05, 0x5f47fea9, 0x1b00320c, 0x2c2319a0,   // es.fo.un_330 tlh.sn.tn_544  bs.tr.un_530 gl.ca.fy_322 
  0x23342804, 0x10040e08, 0x4815300d, 0x041006a4,   // sd.ps.ky_332 is.fi.lt_443  uz.tt.un_540 de.lt.fi_433 
  0x48233002, 0x790601a0, 0x101a040c, 0x394b0208,   // uz.ky.tt_222 en.de.war_322  fi.tl.lt_543 da.mi.br_443 
  0x73006a08, 0x400f10a0, 0x5a281da0, 0x1a0610ee,   // haw.ny.un_430 lt.lv.lb_322  la.sw.sm_322 lt.de.tl_422 
  // [1fd80]
  0x23424aa7, 0x06104012, 0x12003805, 0x1500520c,   // yo.co.ca_532 lb.lt.de_654  tk.hu.un_330 ha.un.un_530 
  0x30512a0c, 0x04065a08, 0x15480414, 0x026757af,   // mt.kl.uz_543 sm.de.fi_443  ru.tt.un_666 na.ak.da_655 
  0x682847ec, 0x105006a4, 0x0b002f0c, 0x07fc4d08,   // sn.sw.ig_644 de.fj.lt_433  su.es.un_530 aa.zzp.it_443 
  0x0a51010c, 0x21182f04, 0xfc6426ad, 0x18002f05,   // en.kl.pt_543 su.ga.jw_332  ia.lg.zzp_643 su.ga.un_330 
  // [1fd90]
  0x18212f0c, 0x2e0212ac, 0x182f2112, 0x135c0909,   // su.jw.ga_543 hu.da.fo_632  jw.su.ga_654 hi.sa.bh_444 
  0x5d003607, 0x07002c07, 0x282547a4, 0x4213fc04,   // gn.ss.un_420 fy.it.un_420  sn.eu.sw_433 zzp.et.co_332 
  0x231704a0, 0x18212f08, 0x38044855, 0x350a30ee,   // ru.sr.ky_322 su.jw.ga_443  tt.fi.tk_442 uz.mk.tg_422 
  0x4d697613, 0x34375daf, 0x30103504, 0x532f05ee,   // crs.mfe.aa_665 ss.st.xh_655  tg.be.uz_332 fr.su.ht_422 
  // [1fda0]
  0x044860ec, 0x3930610c, 0x351c2f02, 0x3b28340c,   // vo.tt.fi_644 za.uz.br_543  su.id.zu_222 ps.sd.ks_543 
  0x2a315414, 0x04584704, 0x0413580c, 0x644a6b0c,   // ik.az.mt_666 sn.om.fi_332  om.et.fi_543 ceb.yo.lg_543 
  0x04544707, 0x313bfeee, 0x250f5612, 0x03134d11,   // sn.ik.fi_432 tlh.so.az_422  mg.lv.eu_654 aa.et.nl_653 
  0x560f1004, 0x47005821, 0x685202a4, 0x023556ec,   // lt.lv.mg_332 om.sn.un_860  da.ha.ig_433 mg.zu.da_644 
  // [1fdb0]
  0x5400462b, 0x03583bec, 0x1a62fc5a, 0x46fe540b,   // qu.ik.un_980 so.om.nl_644  zzp.kha.tl_553 ik.tlh.qu_542 
  0x3bfe4611, 0x03473f02, 0x33080c04, 0x47001019,   // qu.tlh.so_653 af.sn.nl_222  sv.no.nn_332 lt.sn.un_750 
  0x47025612, 0x0b00180d, 0x2b000c07, 0x05002f13,   // mg.da.sn_654 ga.es.un_540  sv.vi.un_420 su.fr.un_650 
  0x250f47a0, 0x082e3311, 0x1842050c, 0x2b0115a0,   // sn.lv.eu_322 nn.fo.no_653  fr.co.ga_543 un.en.vi_322 
  // [1fdc0]
  0x07000204, 0x3f00130d, 0x3065550c, 0x21131807,   // da.it.un_320 et.af.un_540  rw.gv.uz_543 ga.et.jw_432 
  0x0f134fee, 0x293b0e04, 0x042718a9, 0x101827ad,   // bi.et.lv_422 is.so.sl_332  ga.gd.fi_544 gd.ga.lt_643 
  0x2f001812, 0x10057907, 0x080213a4, 0x795e3707,   // ga.su.un_640 war.fr.lt_432  et.da.no_433 st.ts.war_432 
  0x3b0265af, 0x1f091855, 0x40631007, 0x5e00040c,   // gv.da.so_655 ga.pl.cy_442  lt.sco.lb_432 fi.ts.un_530 
  // [1fdd0]
  0x332e6b02, 0x5d7664a4, 0x371213ec, 0x49182713,   // ceb.fo.nn_222 lg.crs.ss_433  et.hu.st_644 gd.ga.to_665 
  0x65276e0c, 0x3b20210b, 0x190527ad, 0x2a65fe55,   // hmn.gd.gv_543 jw.sq.so_542  gd.fr.gl_643 tlh.gv.mt_442 
  0x2f0f250b, 0xfc103607, 0x3b2a18a0, 0x08005107,   // eu.lv.su_542 gn.lt.zzp_432  ga.mt.so_322 kl.no.un_420 
  0x352348ee, 0x543e040c, 0x18000522, 0x275a5413,   // tt.ky.tg_422 fi.rm.ik_543  fr.ga.un_870 ik.sm.gd_665 
  // [1fde0]
  0x052701a4, 0x786501a4, 0x5e75370c, 0x04180107,   // en.gd.fr_433 en.gv.ve_433  st.nso.ts_543 en.ga.fi_432 
  0x313048a9, 0x01634f0c, 0x5255fca0, 0x37004613,   // tt.uz.az_544 bi.sco.en_543  zzp.rw.ha_322 qu.st.un_650 
  0x65005e08, 0x371f20a4, 0x02003908, 0x0c134fee,   // ts.gv.un_430 sq.cy.st_433  br.da.un_430 bi.et.sv_422 
  0x335002a0, 0x1a0c6ba4, 0x30004d22, 0x09004a08,   // da.fj.nn_322 ceb.sv.tl_433  aa.uz.un_870 yo.pl.un_430 
  // [1fdf0]
  0x2f210502, 0x3637480e, 0x031827a0, 0x0d391ea0,   // fr.jw.su_222 tt.ba.ab_555  gd.ga.nl_322 ms.br.cs_322 
  0x0a792207, 0x5c423e04, 0x10001a07, 0x120c33a0,   // oc.war.pt_432 rm.co.sa_332  tl.lt.un_420 nn.sv.hu_322 
  0x46250505, 0x1f1b3fa4, 0x5d001817, 0x21002714,   // fr.eu.qu_333 af.tr.cy_433  ga.ss.un_730 gd.jw.un_660 
  0x33001807, 0x19002e08, 0x0f4e10ac, 0x796527ad,   // ga.nn.un_420 fo.gl.un_430  lt.ay.lv_632 gd.gv.war_643 
  // [1fe00]
  0x18003302, 0xfefc4304, 0x401b31a4, 0x03686507,   // nn.ga.un_220 ie.zzp.tlh_332  az.tr.lb_433 gv.ig.nl_432 
  0x474c1aec, 0x3d00281a, 0x182128ac, 0x35674f07,   // tl.wo.sn_644 sd.ku.un_760  sd.fa.ar_632 bi.ak.zu_432 
  0x25321704, 0x0e002b02, 0x17303c04, 0x38483111,   // sr.bs.eu_332 vi.is.un_220  ug.uz.sr_332 az.tt.tk_653 
  0x2a003e04, 0x73475d5a, 0x041710a7, 0x18122307,   // rm.mt.un_320 ss.sn.ny_553  be.sr.ru_532 ky.ur.ar_432 
  // [1fe10]
  0x13001808, 0x04001811, 0x022efea7, 0x47375fac,   // ga.et.un_430 ga.fi.un_630  tlh.fo.da_532 tn.st.sn_632 
  0x3831240c, 0x675f1109, 0x435f6008, 0x22244807,   // eo.az.tk_543 ro.tn.ak_444  vo.tn.ie_443 tt.eo.oc_432 
  0x02284508, 0x5d3547af, 0x6b4b4ca7, 0x620401a4,   // ln.sw.da_443 sn.zu.ss_655  wo.mi.ceb_532 en.fi.kha_433 
  0x49006808, 0x6362330c, 0x215615a0, 0x38492813,   // ig.to.un_430 nn.kha.sco_543  un.mg.jw_322 sw.to.tk_665 
  // [1fe20]
  0x5f002007, 0x28454905, 0xfe5028a0, 0x49381d02,   // sq.tn.un_420 to.ln.sw_333  sw.fj.tlh_322 la.tk.to_222 
  0x135e5a02, 0x474535a4, 0x0d001c29, 0x5a5249ec,   // sm.ts.et_222 zu.ln.sn_433  mr.ne.un_960 to.ha.sm_644 
  0x0b00360d, 0x37335f07, 0x073811ad, 0x5e1f4fa9,   // gn.es.un_540 tn.nn.st_432  ro.tk.bg_643 bi.cy.ts_544 
  0x78005a29, 0x67002219, 0x5a286aaf, 0x3000110d,   // sm.ve.un_960 oc.ak.un_750  haw.sw.sm_655 ro.uz.un_540 
  // [1fe30]
  0x1a6a50ad, 0x28000905, 0x49733008, 0x041138a9,   // fj.haw.tl_643 pl.sw.un_330  uz.ny.to_443 tk.ro.ru_544 
  0x61001813, 0x5e37faee, 0x0f6512a7, 0x64000a02,   // ga.za.un_650 nr.st.ts_422  hu.gv.lv_532 pt.lg.un_220 
  0xfc000205, 0x2f492807, 0x34003305, 0x0427180d,   // da.zzp.un_330 sw.to.su_432  nn.xh.un_330 ga.gd.fi_554 
  0x37040704, 0x653f6907, 0x4b1378a9, 0x65035712,   // bg.ru.ba_332 mfe.af.gv_432  ve.et.mi_544 na.nl.gv_654 
  // [1fe40]
  0x190a05a6, 0x130a4bee, 0x4c001223, 0x6a001813,   // fr.pt.gl_521 mi.pt.et_422  hu.wo.un_880 ga.haw.un_650 
  0x04366a12, 0x242d0d02, 0x1600fc02, 0x0f000404,   // haw.gn.fi_654 cs.sk.eo_222  zzp.hr.un_220 fi.lv.un_320 
  0x190a13ee, 0x18005a14, 0x3e4f360c, 0x0c020e02,   // et.pt.gl_422 sm.ga.un_660  gn.bi.rm_543 is.da.sv_222 
  0x1d05420b, 0x155cfca4, 0x5c006a09, 0x24323b04,   // co.fr.la_542 zzp.sa.un_433  haw.sa.un_440 so.bs.eo_332 
  // [1fe50]
  0x48301ba0, 0x0c0e0207, 0x1b130dee, 0x4b001b09,   // tr.uz.tt_322 da.is.sv_432  cs.et.tr_422 tr.mi.un_440 
  0x0a195a0b, 0x6b024ba9, 0x25001c08, 0x2f000402,   // sm.gl.pt_542 mi.da.ceb_544  id.eu.un_430 fi.su.un_220 
  0x17303c60, 0x0500420c, 0x35311b02, 0x1b00420d,   // ug.uz.sr_664 co.fr.un_530  tr.az.zu_222 co.tr.un_540 
  0x110e2e07, 0x22003e02, 0x1e6304a4, 0x022a13a0,   // fo.is.ro_432 rm.oc.un_220  fi.sco.ms_433 et.mt.da_322 
  // [1fe60]
  0x48382360, 0x1a1c7907, 0x30071704, 0x23374404,   // ky.tk.tt_664 war.id.tl_432  sr.bg.uz_332 kk.ba.ky_332 
  0x1d025c0c, 0x5955780c, 0x0246520d, 0x3b644802,   // sa.da.la_543 ve.rw.rn_543  ha.qu.da_554 tt.lg.so_222 
  0x1a6b0208, 0x3020520c, 0x1e3e110b, 0x263e010c,   // da.ceb.tl_443 ha.sq.uz_543  ro.rm.ms_542 en.rm.ia_543 
  0x35593bad, 0x5955200e, 0x255f6a07, 0x3b6502af,   // so.rn.zu_643 sq.rw.rn_555  haw.tn.eu_432 da.gv.so_655 
  // [1fe70]
  0x45003713, 0x2000010d, 0x5e6a45a4, 0x52553b08,   // st.ln.un_650 en.sq.un_540  ln.haw.ts_433 so.rw.ha_443 
  0x230815af, 0x453768a4, 0x3559550e, 0x48005505,   // un.uk.ky_655 ig.st.ln_433  rw.rn.zu_555 rw.tt.un_330 
  0x2102520c, 0x350252ad, 0x02080dee, 0x6220475a,   // ha.da.jw_543 ha.da.zu_643  cs.no.da_422 sn.sq.kha_553 
  0xfe3b30a4, 0x3f30470c, 0x287801a4, 0x4f100107,   // uz.so.tlh_433 sn.uz.af_543  en.ve.sw_433 en.lt.bi_432 
  // [1fe80]
  0x02523012, 0x2800200d, 0x0817300c, 0x28356aa0,   // uz.ha.da_654 sq.sw.un_540  uz.sr.uk_543 haw.zu.sw_322 
  0x62271813, 0x0a281207, 0x056561a9, 0x475c10a0,   // ga.gd.kha_665 ur.sd.mk_432  za.gv.fr_544 lt.sa.sn_322 
  0x0556275a, 0x05360404, 0x161732a7, 0x0e0818a7,   // gd.mg.fr_553 fi.gn.fr_332  bs.sr.hr_532 ga.no.is_532 
  0x3015080d, 0x36021f07, 0x30282104, 0x1800060b,   // uk.uz.un_540 cy.da.gn_432  fa.sd.uz_332 de.ga.un_520 
  // [1fe90]
  0x56055c08, 0x30481505, 0x05472702, 0x65015707,   // sa.fr.mg_443 un.tt.uz_333  gd.sn.fr_222 na.en.gv_432 
  0x275c67a4, 0x150a36a0, 0x02200209, 0x080a10ee,   // ak.sa.gd_433 gn.pt.un_322  da.sq.da_444 be.mk.uk_422 
  0x085c33a4, 0x12002c07, 0x100738a7, 0x47281eaf,   // nn.sa.no_433 fy.hu.un_420  tk.bg.be_532 ms.sw.sn_655 
  0x526a4bec, 0x73471a0b, 0x09621a07, 0x42112404,   // mi.haw.ha_644 tl.sn.ny_542  tl.kha.pl_432 eo.ro.co_332 
  // [1fea0]
  0x37000409, 0x5700521a, 0x1b1a1ea9, 0x47461e0c,   // ru.ba.un_440 ha.na.un_760  ms.tl.tr_544 ms.qu.sn_543 
  0x5c00fe23, 0x485d3513, 0x564e1e0c, 0x1dfe5c0b,   // tlh.sa.un_880 zu.ss.tt_665  ms.ay.mg_543 sa.tlh.la_542 
  0x50491ea0, 0x285247a0, 0x3e103ba9, 0x56005821,   // ms.to.fj_322 sn.ha.sw_322  so.lt.rm_544 om.mg.un_860 
  0x2b001604, 0x47504b05, 0x42391fa6, 0x36797304,   // hr.vi.un_320 mi.fj.sn_333  cy.br.co_521 ny.war.gn_332 
  // [1feb0]
  0x64582da0, 0x3e552108, 0x2a2e0ea7, 0x29312b07,   // sk.om.lg_322 jw.rw.rm_443  is.fo.mt_532 vi.az.sl_432 
  0x33020ea6, 0x735c59a9, 0x0b0501a4, 0x34193bee,   // is.da.nn_521 rn.sa.ny_544  en.fr.es_433 so.gl.xh_422 
  0x135c540c, 0x46004304, 0x38571ea4, 0x1e6579ee,   // ik.sa.et_543 ie.qu.un_320  ms.na.tk_433 war.gv.ms_422 
  0x4202690c, 0x02692705, 0x620205a4, 0x060163a7,   // mfe.da.co_543 gd.mfe.da_333  fr.da.kha_433 sco.en.de_532 
  // [1fec0]
  0x0600280d, 0x3b400604, 0x2400030c, 0x0c1d6107,   // sw.de.un_540 de.lb.so_332  nl.eo.un_530 za.la.sv_432 
  0x3b5606a0, 0x35463460, 0x06001e02, 0x46fe3b07,   // de.mg.so_322 xh.qu.zu_664  ms.de.un_220 so.tlh.qu_432 
  0x0c0833ac, 0x650851ee, 0x352b460c, 0x40104fa4,   // nn.no.sv_632 kl.no.gv_422  qu.vi.zu_543 bi.lt.lb_433 
  0x04004609, 0x3e001d14, 0x222718af, 0x080e6204,   // qu.fi.un_440 la.rm.un_660  ga.gd.oc_655 kha.is.no_332 
  // [1fed0]
  0x311b3202, 0x24131f05, 0x385c54ee, 0x35343bee,   // bs.tr.az_222 cy.et.eo_333  ik.sa.tk_422 so.xh.zu_422 
  0x12052e0c, 0x04113007, 0x1f000102, 0x012e0eee,   // fo.fr.hu_543 uz.ro.ru_432  en.cy.un_220 is.fo.en_422 
  0x46381004, 0x3e18220c, 0x406506ee, 0x184027a0,   // lt.tk.qu_332 oc.ga.rm_543  de.gv.lb_422 gd.lb.ga_322 
  0x3b5706ec, 0x38595511, 0x0c510407, 0x38131ba4,   // de.na.so_644 rw.rn.tk_653  fi.kl.sv_432 tr.et.tk_433 
  // [1fee0]
  0x03211ba4, 0x2200460c, 0x22193ea4, 0x63135ca4,   // tr.jw.nl_433 qu.oc.un_530  rm.gl.oc_433 sa.et.sco_433 
  0x08223e07, 0x3f135ca0, 0x38005505, 0xfc5c0905,   // rm.oc.no_432 sa.et.af_322  rw.tk.un_330 pl.sa.zzp_333 
  0x191327a0, 0x380259ad, 0x21007905, 0x122d3655,   // gd.et.gl_322 rn.da.tk_643  war.jw.un_330 gn.sk.hu_442 
  0x1b380fa7, 0x484c1bee, 0x1b385ca4, 0x380f1bec,   // lv.tk.tr_532 tr.wo.tt_422  sa.tk.tr_433 tr.lv.tk_644 
  // [1fef0]
  0x13002913, 0x32005e04, 0x0e2e130c, 0x1c1e1204,   // sl.et.un_650 ts.bs.un_320  et.fo.is_543 hu.ms.id_332 
  0x3000391a, 0x08003612, 0x38001307, 0x29132a12,   // br.uz.un_760 ab.uk.un_640  et.tk.un_420 mt.et.sl_654 
  0x2c001a09, 0x130f28ee, 0x46481255, 0x2a534e12,   // tl.fy.un_440 sw.lv.et_422  hu.tt.qu_442 ay.ht.mt_654 
  0x180427a0, 0x44373ca7, 0x292d25a0, 0x044f0f08,   // gd.fi.ga_322 ug.ba.kk_532  eu.sk.sl_322 lv.bi.fi_443 
  // [1ff00]
  0x23441702, 0x270f1304, 0x4437110d, 0x3f0f0302,   // sr.kk.ky_222 et.lv.gd_332  ro.ba.kk_554 nl.lv.af_222 
  0x1a002708, 0x2e001c04, 0x62562713, 0x0e0833ec,   // gd.tl.un_430 id.fo.un_320  gd.mg.kha_665 nn.no.is_644 
  0x1218270d, 0x397669af, 0x443c23a7, 0x0b003111,   // gd.ga.hu_554 mfe.crs.br_655  ky.ug.kk_532 az.es.un_630 
  0x16044ea4, 0x4f005609, 0x0f13100c, 0x053e270c,   // ay.fi.hr_433 mg.bi.un_440  lt.et.lv_543 gd.rm.fr_543 
  // [1ff10]
  0x393f4e08, 0x043e0509, 0x39290d0c, 0x2f004f13,   // ay.af.br_443 fr.rm.fi_444  cs.sl.br_543 bi.su.un_650 
  0x48371555, 0x20130402, 0x23442509, 0x35344a05,   // un.ba.tt_442 fi.et.sq_222  mn.kk.ky_444 yo.xh.zu_333 
  0x08003321, 0x6800260d, 0x44253c09, 0x242033a0,   // nn.no.un_860 ia.ig.un_540  ug.mn.kk_444 nn.sq.eo_322 
  0x2000210d, 0x0a173505, 0x1e000411, 0x17073c07,   // jw.sq.un_540 tg.sr.mk_333  fi.ms.un_630 ug.bg.sr_432 
  // [1ff20]
  0x385d3512, 0x20330860, 0x21003b21, 0x5d3645a4,   // zu.ss.tk_654 no.nn.sq_664  ks.fa.un_860 ln.gn.ss_433 
  0x190553a0, 0x1b00570c, 0x46001a13, 0xfa5d3508,   // ht.fr.gl_322 na.tr.un_530  tl.qu.un_650 zu.ss.nr_443 
  0x572d0d08, 0x37005e0e, 0x12006113, 0x285d4207,   // cs.sk.na_443 ts.st.un_550  za.hu.un_650 co.ss.sw_432 
  0x5f60130c, 0x32001722, 0x33083fa9, 0x04132c04,   // et.vo.tn_543 sr.bs.un_870  af.no.nn_544 fy.et.fi_332 
  // [1ff30]
  0x5f13780c, 0x222d0d04, 0x15013805, 0x050418ad,   // ve.et.tn_543 cs.sk.oc_332  tk.en.un_333 ga.fi.fr_643 
  0x23005d04, 0x1d0e2407, 0x31304c07, 0xfe00420e,   // ss.ca.un_320 eo.is.la_432  wo.uz.az_432 co.tlh.un_550 
  0x264d01a0, 0x5c0402a0, 0x2d0d0f09, 0x093216a4,   // en.aa.ia_322 da.fi.sa_322  lv.cs.sk_444 hr.bs.pl_433 
  0x5c1b5da0, 0x5e353414, 0x45225e08, 0x132842a4,   // ss.tr.sa_322 xh.zu.ts_666  ts.oc.ln_443 co.sw.et_433 
  // [1ff40]
  0xfc3440ee, 0x350a0711, 0x5e5d04a9, 0x0d092d0d,   // lb.xh.zzp_422 bg.mk.tg_653  fi.ss.ts_544 sk.pl.cs_554 
  0x23000211, 0x2e3646ee, 0xfc651502, 0x65001d19,   // da.ca.un_630 qu.gn.fo_422  un.gv.zzp_222 la.gv.un_750 
  0x09fe2cee, 0x37001708, 0x182b6505, 0xfe530311,   // fy.tlh.pl_422 sr.ba.un_430  gv.vi.ga_333 nl.ht.tlh_653 
  0x2142050c, 0x402b390c, 0x4a5a42a4, 0x6efe6112,   // fr.co.jw_543 br.vi.lb_543  co.sm.yo_433 za.tlh.hmn_654 
  // [1ff50]
  0x2b001104, 0x2b113e11, 0x0e0662a4, 0x045d3502,   // ro.vi.un_320 rm.ro.vi_653  kha.de.is_433 zu.ss.fi_222 
  0x65466312, 0x235e4704, 0x2061fe0c, 0x164a4207,   // sco.qu.gv_654 sn.ts.ca_332  tlh.za.sq_543 co.yo.hr_432 
  0x02001507, 0x4f005719, 0x212c39ee, 0x21102fa4,   // un.da.un_420 na.bi.un_750  br.fy.jw_422 su.lt.jw_433 
  0x21506eee, 0x3f005f05, 0x1b384602, 0x290f42a0,   // hmn.fj.jw_422 tn.af.un_330  qu.tk.tr_222 co.lv.sl_322 
  // [1ff60]
  0x0817110b, 0x2e0e06ad, 0x18022302, 0x4f5b0312,   // ro.sr.uk_542 de.is.fo_643  ca.da.ga_222 nl.sg.bi_654 
  0x11000612, 0x61006e23, 0x4a00fe0c, 0x022b6507,   // de.ro.un_640 hmn.za.un_880  tlh.yo.un_530 gv.vi.da_432 
  0x6b0cfca0, 0xfe206e11, 0xfe000323, 0x6e00202b,   // zzp.sv.ceb_322 hmn.sq.tlh_653  nl.tlh.un_880 sq.hmn.un_980 
  0x2c420507, 0x3b0e5807, 0x325c1007, 0x466102ec,   // fr.co.fy_432 om.is.so_432  lt.sa.bs_432 da.za.qu_644 
  // [1ff70]
  0x160942a0, 0x7500371b, 0x6b4a1d07, 0x315c3ba0,   // co.pl.hr_322 st.nso.un_770  la.yo.ceb_432 so.sa.az_322 
  0x2f0c6b04, 0x384417a4, 0xfc080204, 0x013efc07,   // ceb.sv.su_332 sr.kk.tk_433  da.no.zzp_332 zzp.rm.en_432 
  0x08303c12, 0x381368ad, 0x0c006319, 0x401f1da0,   // ug.uz.uk_654 ig.et.tk_643  sco.sv.un_750 la.cy.lb_322 
  0x23392508, 0x2f3b1c04, 0x30000c07, 0x554a3405,   // eu.br.ca_443 id.so.su_332  sv.uz.un_420 xh.yo.rw_333 
  // [1ff80]
  0x556059ad, 0x100f1b02, 0x21006408, 0x07041160,   // rn.vo.rw_643 tr.lv.lt_222  lg.jw.un_430 ro.ru.bg_664 
  0x1b00680c, 0x64595f05, 0x5669765a, 0x072229a0,   // ig.tr.un_530 tn.rn.lg_333  crs.mfe.mg_553 sl.oc.it_322 
  0x13fc5e08, 0x2338445a, 0x4e52460d, 0x25455f0e,   // ts.zzp.et_443 kk.tk.ky_553  qu.ha.ay_554 tn.ln.eu_555 
  0x211a3807, 0x4a5056a0, 0x755d35a9, 0x1e5e21ac,   // tk.tl.jw_432 mg.fj.yo_322  zu.ss.nso_544 jw.ts.ms_632 
  // [1ff90]
  0x120f24ee, 0x2c6901a9, 0x2d004804, 0x6b005e20,   // eo.lv.hu_422 en.mfe.fy_544  tt.sk.un_320 ts.ceb.un_850 
  0x2500450d, 0x2e2c0ea0, 0x2f124da0, 0x18283d12,   // ln.eu.un_540 is.fy.fo_322  aa.hu.su_322 ku.sd.ar_654 
  0x09320da0, 0x301a6302, 0x466b0909, 0x12377509,   // cs.bs.pl_322 sco.tl.uz_222  pl.ceb.qu_444 nso.st.hu_444 
  0x0a350702, 0x5615050c, 0x4f1b390c, 0x30002909,   // bg.tg.mk_222 fr.mg.un_530  br.tr.bi_543 sl.uz.un_440 
  // [1ffa0]
  0x04003712, 0x2c2711ec, 0x2e0e6a13, 0x2e0e1bad,   // ba.ru.un_640 ro.gd.fy_644  haw.is.fo_665 tr.is.fo_643 
  0x463158af, 0x4b001804, 0x3e001d19, 0x3c1535ee,   // om.az.qu_655 ga.mi.un_320  la.rm.un_750 tg.ug.un_420 
  0x2e1b38a7, 0x100730a0, 0x2e311b11, 0x162d29a9,   // tk.tr.fo_532 uz.bg.be_322  tr.az.fo_653 sl.sk.hr_544 
  0x1329780c, 0x20120e0e, 0x5a494b55, 0x68375f0c,   // ve.sl.et_543 is.hu.sq_555  mi.to.sm_442 tn.st.ig_543 
  // [1ffb0]
  0x6306010c, 0x46395302, 0x5c2704ad, 0x3e353455,   // en.de.sco_543 ht.br.qu_222  fi.gd.sa_643 xh.zu.rm_442 
  0x5d002d08, 0x79042511, 0x010302a0, 0x3721620c,   // sk.ss.un_430 eu.fi.war_653  da.nl.en_322 kha.jw.st_543 
  0x57016307, 0x122a6e02, 0x6079065a, 0x2a6b1dad,   // sco.en.na_432 hmn.mt.hu_222  de.war.vo_553 la.ceb.mt_643 
  0x2344370b, 0x341837ee, 0x2a006e08, 0x1d2b2702,   // ba.kk.ky_542 st.ga.xh_422  hmn.mt.un_430 gd.vi.la_222 
  // [1ffc0]
  0x1f4f20a7, 0x04182711, 0x33120807, 0x10000c12,   // sq.bi.cy_532 gd.ga.fi_653  no.hu.nn_432 ml.be.un_640 
  0x040f27a9, 0x125c1f0c, 0x022a0808, 0xfe00540e,   // gd.lv.fi_544 cy.sa.hu_543  no.mt.da_443 ik.tlh.un_550 
  0x366a56af, 0x566a49af, 0x470456ee, 0x0d382da9,   // mg.haw.gn_655 to.haw.mg_655  mg.fi.sn_422 sk.tk.cs_544 
  0x56004912, 0x2f4b54ad, 0x2b00420d, 0x21005605,   // to.mg.un_640 ik.mi.su_643  co.vi.un_540 mg.jw.un_330 
  // [1ffd0]
  0x34213ba0, 0x024b56a4, 0x0a3635a0, 0x34002b04,   // ks.fa.ps_322 mg.mi.da_433  tg.ab.mk_322 vi.xh.un_320 
  0x792d0dad, 0x37562507, 0x56004914, 0x6533120c,   // cs.sk.war_643 eu.mg.st_432  to.mg.un_660 hu.nn.gv_543 
  0x5c0a0f04, 0x1a00210d, 0x62004d0e, 0x12465c0c,   // lv.pt.sa_332 jw.tl.un_540  aa.kha.un_550 sa.qu.hu_543 
  0x0f001d07, 0x1e002304, 0x4d001d1a, 0x09464d11,   // la.lv.un_420 ca.ms.un_320  la.aa.un_760 aa.qu.pl_653 
  // [1ffe0]
  0x5c124daf, 0x1d124d08, 0x27330809, 0x38330805,   // aa.hu.sa_655 aa.hu.la_443  no.nn.gd_444 no.nn.tk_333 
  0x4d004621, 0xfc000909, 0x56481307, 0x481038ee,   // qu.aa.un_860 pl.zzp.un_440  et.tt.mg_432 tk.be.tt_422 
  0x23043c0c, 0x3e00240d, 0x101538ad, 0x1d240102,   // ug.ru.ky_543 eo.rm.un_540  tk.be.un_630 en.eo.la_222 
  0x12104ca0, 0x21fe2b07, 0x1f003921, 0x1530230e,   // wo.lt.hu_322 vi.tlh.jw_432  br.cy.un_860 ky.uz.un_555 
  // [1fff0]
  0x33002e1b, 0x1500130d, 0x343b2105, 0x0e794202,   // fo.nn.un_770 et.un.un_540  fa.ks.ps_333 co.war.is_222 
  0x11006404, 0x05202204, 0x0f004602, 0x68753b0c,   // lg.ro.un_320 oc.sq.fr_332  qu.lv.un_220 so.nso.ig_543 
  0xfe0662a4, 0x2000120b, 0x3b506aa4, 0x2a001a05,   // kha.de.tlh_433 hu.sq.un_520  haw.fj.so_433 tl.mt.un_330 
  0x20000604, 0x6a5d020c, 0x2a1379a0, 0x643b49a0,   // de.sq.un_320 da.ss.haw_543  war.et.mt_322 to.so.lg_322 
  
  // [20000]
  0x22215305, 0x55137909, 0x2f002d0e, 0x355d1aa4,   // ht.jw.oc_333 war.et.rw_444  sk.su.un_550 tl.ss.zu_433 
  0x484430a0, 0x0413640c, 0x460602ee, 0x683b4b04,   // uz.kk.tt_322 lg.et.fi_543  da.de.qu_422 mi.so.ig_332 
  0x2d2f2155, 0x2d0d0205, 0x0d000604, 0x796b0207,   // jw.su.sk_442 da.cs.sk_333  de.cs.un_320 da.ceb.war_432 
  0x25300a07, 0x050d12ee, 0x4012050b, 0x5f5a68a4,   // mk.uz.mn_432 hu.cs.fr_422  fr.hu.lb_542 ig.sm.tn_433 
  // [20010]
  0x04350708, 0x40020504, 0x28002a10, 0x540e51ec,   // bg.tg.ru_443 fr.da.lb_332  mt.sw.un_620 kl.is.ik_644 
  0x491937a7, 0x63006912, 0x376a68a4, 0x303428ee,   // st.gl.to_532 mfe.sco.un_640  ig.haw.st_433 sd.ps.uz_422 
  0x1b765308, 0x5e375f14, 0x11201d08, 0x110a1d04,   // ht.crs.tr_443 tn.st.ts_666  la.sq.ro_443 la.pt.ro_332 
  0x180227ec, 0x2d0f17a0, 0x67006e21, 0x117618ee,   // gd.da.ga_644 sr.lv.sk_322  hmn.ak.un_860 ga.crs.ro_422 
  // [20020]
  0x20001d08, 0x01392704, 0x1d671e0c, 0x443c3d0c,   // la.sq.un_430 gd.br.en_332  ms.ak.la_543 ku.ug.kk_543 
  0x425327ee, 0x0a001d07, 0x306138a4, 0xfe182711,   // gd.ht.co_422 la.pt.un_420  tk.za.uz_433 gd.ga.tlh_653 
  0x20001d0e, 0x181d2708, 0x1d002009, 0x010213a4,   // la.sq.un_550 gd.la.ga_443  sq.la.un_440 et.da.en_433 
  0x080c33ec, 0x34355da7, 0x5f005712, 0x48005604,   // nn.sv.no_644 ss.zu.xh_532  na.tn.un_640 mg.tt.un_320 
  // [20030]
  0x6a2556ee, 0x0d0e2dee, 0x0457130d, 0x2d5c4da7,   // mg.eu.haw_422 sk.is.cs_422  et.na.fi_554 aa.sa.sk_532 
  0x25006a0c, 0x5610570d, 0x2e1a3804, 0x22005607,   // haw.eu.un_530 na.lt.mg_554  tk.tl.fo_332 mg.oc.un_420 
  0x56005e13, 0x310457ad, 0x46001b19, 0x475636ad,   // ts.mg.un_650 na.fi.az_643  tr.qu.un_750 gn.mg.sn_643 
  0x21004802, 0x2f005c08, 0x6b512fa9, 0x2d000a07,   // tt.jw.un_220 sa.su.un_430  su.kl.ceb_544 pt.sk.un_420 
  // [20040]
  0x5e565d0c, 0x0f2d1004, 0x5c002f04, 0x28557304,   // ss.mg.ts_543 lt.sk.lv_332  su.sa.un_320 ny.rw.sw_332 
  0x12594707, 0x5d330807, 0x56005d08, 0x0435080c,   // sn.rn.hu_432 no.nn.ss_432  ss.mg.un_430 uk.tg.ru_543 
  0x4255450c, 0xfa473508, 0x355d6407, 0x35736408,   // ln.rw.co_543 zu.sn.nr_443  lg.ss.zu_432 lg.ny.zu_443 
  0x345d4509, 0x29477805, 0x2d003302, 0x2d190d04,   // ln.ss.xh_444 ve.sn.sl_333  nn.sk.un_220 cs.gl.sk_332 
  // [20050]
  0x1d002813, 0x1704110e, 0x27004c08, 0x01652807,   // sw.la.un_650 ro.ru.sr_555  wo.gd.un_430 sw.gv.en_432 
  0x645a6aa7, 0x561d5cee, 0x09001d05, 0x2e1b0eee,   // haw.sm.lg_532 sa.la.mg_422  la.pl.un_330 is.tr.fo_422 
  0x39241da0, 0x795301a4, 0x560a4cad, 0x0a001d0e,   // la.eo.br_322 en.ht.war_433  wo.pt.mg_643 la.pt.un_550 
  0x31004810, 0x380448a9, 0x1b004810, 0x5c111b08,   // tt.az.un_620 tt.fi.tk_544  tt.tr.un_620 tr.ro.sa_443 
  // [20060]
  0x060c4807, 0x64004604, 0x0f5c150c, 0x28004f1a,   // tt.sv.de_432 qu.lg.un_320  un.sa.lv_543 bi.sw.un_760 
  0x27001d0c, 0x20002802, 0x291d5cee, 0x2f2c39ee,   // la.gd.un_530 sw.sq.un_220  sa.la.sl_422 br.fy.su_422 
  0x1c034202, 0x0c004816, 0x0c00481a, 0x653f0302,   // co.nl.id_222 tt.sv.un_720  tt.sv.un_760 nl.af.gv_222 
  0x48043812, 0x4438235a, 0x47006707, 0x63002d04,   // tk.fi.tt_654 ky.tk.kk_553  ak.sn.un_420 sk.sco.un_320 
  // [20070]
  0x10003f13, 0x0c082c02, 0x1a063b07, 0x066b79a4,   // af.lt.un_650 fy.no.sv_222  so.de.tl_432 war.ceb.de_433 
  0x60595555, 0x0e4a1d04, 0x3306390c, 0x1b003b1b,   // rw.rn.vo_442 la.yo.is_332  br.de.nn_543 so.tr.un_770 
  0x031d39a7, 0xfc57250c, 0x34214408, 0x3b001b07,   // br.la.nl_532 eu.na.zzp_543  kk.fa.ps_443 tr.so.un_420 
  0x38301a55, 0x484437ad, 0x5f002012, 0x25022d55,   // tl.uz.tk_442 ba.kk.tt_643  sq.tn.un_640 sk.da.eu_442 
  // [20080]
  0x5625515a, 0x284759a4, 0x496a2513, 0x204b5605,   // kl.eu.mg_553 rn.sn.sw_433  eu.haw.to_665 mg.mi.sq_333 
  0x21043002, 0x25005605, 0x54581b08, 0x1b3b30ad,   // uz.fi.jw_222 mg.eu.un_330  tr.om.ik_443 uz.so.tr_643 
  0x1225670e, 0x045636a7, 0x45364b13, 0x56501ea0,   // ak.eu.hu_555 gn.mg.fi_532  mi.gn.ln_665 ms.fj.mg_322 
  0x045660a4, 0x65000505, 0x56200404, 0x1d5a11a4,   // vo.mg.fi_433 fr.gv.un_330  fi.sq.mg_332 ro.sm.la_433 
  // [20090]
  0x386b1ea0, 0x1b120c0c, 0x1b130c04, 0x5a494c55,   // ms.ceb.tk_322 sv.hu.tr_543  sv.et.tr_332 wo.to.sm_442 
  0x481b0c07, 0x1a3b5807, 0x060c12ec, 0x37302507,   // sv.tr.tt_432 om.so.tl_432  hu.sv.de_644 mn.uz.ba_432 
  0x1d424da4, 0x0c001209, 0x3efe4ca4, 0x1b0e0cad,   // aa.co.la_433 hu.sv.un_440  wo.tlh.rm_433 sv.is.tr_643 
  0x17521aa7, 0x12093e04, 0x4650600c, 0x12002c05,   // tl.ha.sr_532 rm.pl.hu_332  vo.fj.qu_543 fy.hu.un_330 
  // [200a0]
  0x27005314, 0x1f5d35a9, 0x28653ba9, 0x2800471b,   // ht.gd.un_660 zu.ss.cy_544  so.gv.sw_544 sn.sw.un_770 
  0x6528200c, 0x20652812, 0x45003921, 0x2700530d,   // sq.sw.gv_543 sw.gv.sq_654  br.ln.un_860 ht.gd.un_540 
  0x650220af, 0x48315412, 0x5f653708, 0x6a0337a0,   // sq.da.gv_655 ik.az.tt_654  st.gv.tn_443 st.nl.haw_322 
  0x35004307, 0x4f00502c, 0x7369530c, 0x4c5d4f0c,   // ie.zu.un_420 fj.bi.un_990  ht.mfe.ny_543 bi.ss.wo_543 
  // [200b0]
  0x6a3f0308, 0xfa5d690c, 0x370a4007, 0x28465e60,   // nl.af.haw_443 mfe.ss.nr_543  lb.pt.st_432 ts.qu.sw_664 
  0x051f37ee, 0x5a491012, 0x3930180c, 0x154f62a4,   // st.cy.fr_422 lt.to.sm_654  ga.uz.br_543 kha.bi.un_433 
  0x130c1b08, 0x67353008, 0x060c1b5a, 0x6400010c,   // tr.sv.et_443 uz.zu.ak_443  tr.sv.de_553 en.lg.un_530 
  0x560f4712, 0x34005607, 0x382569a9, 0x37000314,   // sn.lv.mg_654 mg.xh.un_420  mfe.eu.tk_544 nl.st.un_660 
  // [200c0]
  0x423e7902, 0x385550a7, 0x3f001a08, 0x39071b0c,   // war.rm.co_222 fj.rw.tk_532  tl.af.un_430 tr.it.br_543 
  0x190a1da4, 0x64002509, 0x032c3f14, 0x03342011,   // la.pt.gl_433 eu.lg.un_440  af.fy.nl_666 sq.xh.nl_653 
  0x395f7507, 0x35733408, 0x31004f1a, 0x55523fa0,   // nso.tn.br_432 xh.ny.zu_443  bi.az.un_760 af.ha.rw_322 
  0x20524705, 0x65345fa4, 0x10001c08, 0x68302012,   // sn.ha.sq_333 tn.xh.gv_433  id.lt.un_430 sq.uz.ig_654 
  // [200d0]
  0x383173a9, 0x42791e07, 0x023b6205, 0x5f003423,   // ny.az.tk_544 ms.war.co_432  kha.so.da_333 xh.tn.un_880 
  0x6e007822, 0x39375f08, 0x205b3004, 0x35686707,   // ve.hmn.un_870 tn.st.br_443  uz.sg.sq_332 ak.ig.zu_432 
  0x28025aad, 0x55392cad, 0x151d200c, 0x48033f08,   // sm.da.sw_643 fy.br.rw_643  sq.la.un_543 af.nl.tt_443 
  0x186327a4, 0x48440a07, 0x05182711, 0x60580208,   // gd.sco.ga_433 mk.kk.tt_432  gd.ga.fr_653 da.om.vo_443 
  // [200e0]
  0x73205aa4, 0x53152cec, 0x39274c07, 0x2d005909,   // sm.sq.ny_433 fy.ht.un_640  wo.gd.br_432 rn.sk.un_440 
  0x135810ad, 0x1d3038a4, 0x58002d08, 0x58555712,   // lt.om.et_643 tk.uz.la_433  sk.om.un_430 na.rw.om_654 
  0x4c005612, 0x080417ec, 0x1002580b, 0x3b016360,   // mg.wo.un_640 sr.ru.uk_644  om.da.lt_542 sco.en.so_664 
  0x0e007304, 0x1c004c07, 0x180727a0, 0x066b380b,   // ny.is.un_320 wo.id.un_420  gd.it.ga_322 tk.ceb.de_542 
  // [200f0]
  0x1a4c56af, 0x575c670c, 0x190a5805, 0x5d2d3508,   // mg.wo.tl_655 ak.sa.na_543  om.pt.gl_333 zu.sk.ss_443 
  0x55005207, 0x1013580c, 0x1d581508, 0x103f58a4,   // ha.rw.un_420 om.et.lt_543  un.om.la_443 om.af.lt_433 
  0x105f36a0, 0x35005808, 0x73000208, 0x0a1d4d0c,   // gn.tn.lt_322 om.zu.un_430  da.ny.un_430 aa.la.pt_543 
  0x084602ee, 0x42504c5a, 0x062040a7, 0x11426aa0,   // da.qu.no_422 wo.fj.co_553  lb.sq.de_532 haw.co.ro_322 
  // [20100]
  0x491f5504, 0x0c4006ad, 0x25181d08, 0x46594ca7,   // rw.cy.to_332 de.lb.sv_643  la.ga.eu_443 wo.rn.qu_532 
  0x1f424aa7, 0x2c004b04, 0x152c0111, 0x0b0502a6,   // yo.co.cy_532 mi.fy.un_320  en.fy.un_653 da.fr.es_521 
  0x2c405f04, 0x53007907, 0x11004218, 0x06005f07,   // tn.lb.fy_332 war.ht.un_420  co.ro.un_740 tn.de.un_420 
  0x282c4007, 0x100a110c, 0x1773470c, 0x5c121f05,   // lb.fy.sw_432 ro.mk.be_543  sn.ny.sr_543 cy.hu.sa_333 
  // [20110]
  0x4a46500b, 0x15071108, 0x09003b09, 0x1d11610c,   // fj.qu.yo_542 ro.bg.un_443  so.pl.un_440 za.ro.la_543 
  0x0f004221, 0x38231107, 0x42595509, 0x5a4913a7,   // co.lv.un_860 ro.ky.tk_432  rw.rn.co_444 et.to.sm_532 
  0x48370aa0, 0x25006507, 0x1700420d, 0x0b303602,   // mk.ba.tt_322 gv.eu.un_420  co.sr.un_540 gn.uz.es_222 
  0x11427311, 0x4b004005, 0x02015ca0, 0x4700020c,   // ny.co.ro_653 lb.mi.un_330  sa.en.da_322 da.sn.un_530 
  // [20120]
  0x28002a1a, 0x50402c02, 0x4b002c02, 0x2a736707,   // mt.sw.un_760 fy.lb.fj_222  fy.mi.un_220 ak.ny.mt_432 
  0x0c5c02a0, 0xfe001814, 0x0d003b12, 0x351507a0,   // da.sa.sv_322 ga.tlh.un_660  ks.ne.un_640 bg.tg.un_320 
  0x73045e07, 0x18123004, 0x2a431da9, 0x0d095c60,   // ts.fi.ny_432 uz.ur.ar_332  la.ie.mt_544 sa.hi.ne_664 
  0x400e0404, 0x230717a0, 0x12005d09, 0x0e0b460c,   // fi.is.lb_332 sr.bg.ky_322  ss.hu.un_440 qu.es.is_543 
  // [20130]
  0x30691d08, 0x2d0d1207, 0x584d2012, 0x3b135304,   // la.mfe.uz_443 hu.cs.sk_432  sq.aa.om_654 ht.et.so_332 
  0x2f4c27a9, 0x06271d0c, 0x3b1b3107, 0x3b6554a7,   // gd.wo.su_544 la.gd.de_543  az.tr.so_432 ik.gv.so_532 
  0x303b1b05, 0x317653a4, 0x38483007, 0x18343b04,   // tr.so.uz_333 ht.crs.az_433  uz.tt.tk_432 ks.ps.ar_332 
  0x69531aa9, 0x64313bee, 0x06652a07, 0x1b6131ad,   // tl.ht.mfe_544 so.az.lg_422  mt.gv.de_432 az.za.tr_643 
  // [20140]
  0x35785d08, 0x47215c13, 0x11001d12, 0x5f1b31ee,   // ss.ve.zu_443 sa.jw.sn_665  la.ro.un_640 az.tr.tn_422 
  0x1a5c6b04, 0x374815af, 0x3b1b310c, 0x47364612,   // ceb.sa.tl_332 un.tt.ba_655  az.tr.so_543 qu.gn.sn_654 
  0x3e2305a0, 0x23220a13, 0x33085e02, 0x1a2873a9,   // fr.ca.rm_322 pt.oc.ca_665  ts.no.nn_222 ny.sw.tl_544 
  0x5c213509, 0x303504a0, 0x041e5e0c, 0x1100780d,   // zu.jw.sa_444 ru.tg.uz_322  ts.ms.fi_543 ve.ro.un_540 
  // [20150]
  0x355528ec, 0x4a00490c, 0x343735a9, 0x5673470c,   // sw.rw.zu_644 to.yo.un_530  zu.st.xh_544 sn.ny.mg_543 
  0x03001d0c, 0x23220a08, 0x5c5b4511, 0x48441507,   // la.nl.un_530 pt.oc.ca_443  ln.sg.sa_653 un.kk.tt_432 
  0x3900620d, 0x735e640c, 0x5d004711, 0x5d005e2c,   // kha.br.un_540 lg.ts.ny_543  sn.ss.un_630 ts.ss.un_990 
  0x2e00650b, 0x595b550c, 0x55364509, 0x0e1e2ea4,   // gv.fo.un_520 rw.sg.rn_543  ln.gn.rw_444 fo.ms.is_433 
  // [20160]
  0x115dfc0c, 0x49fc34a0, 0x0415370d, 0x020e2ea0,   // zzp.ss.ro_543 xh.zzp.to_322  ba.ru.un_540 fo.is.da_322 
  0x05001b09, 0x2b003107, 0x060e0ca0, 0x6900630e,   // tr.fr.un_440 az.vi.un_420  sv.is.de_322 sco.mfe.un_550 
  0x400c06a0, 0x130c4007, 0x060c40a0, 0x061d4d07,   // de.sv.lb_322 lb.sv.et_432  lb.sv.de_322 aa.la.de_432 
  0x4a124c0c, 0xfc00060c, 0x330827a0, 0x281d15a0,   // wo.hu.yo_543 de.zzp.un_530  gd.no.nn_322 un.la.sw_322 
  // [20170]
  0x02606e07, 0x15652b04, 0x2b005302, 0x15001804,   // hmn.vo.da_432 vi.gv.un_332  ht.vi.un_220 ga.un.un_320 
  0x67456813, 0x36736707, 0x2b6b01a0, 0x02003404,   // ig.ln.ak_665 ak.ny.gn_432  en.ceb.vi_322 xh.da.un_320 
  0x47457355, 0x37003f04, 0x28123007, 0x33081309,   // ny.ln.sn_442 af.st.un_320  uz.ur.sd_432 et.no.nn_444 
  0x1d631507, 0x04102502, 0x15006212, 0x42001d02,   // un.sco.la_432 mn.be.ru_222  kha.un.un_640 la.co.un_220 
  // [20180]
  0x4a003009, 0x46357308, 0x65fc01ee, 0x04462e08,   // uz.yo.un_440 ny.zu.qu_443  en.zzp.gv_422 fo.qu.fi_443 
  0x375c02a0, 0x371a6b08, 0x5c002807, 0x5c642ea0,   // da.sa.st_322 ceb.tl.st_443  sw.sa.un_420 fo.lg.sa_322 
  0x4b49560c, 0x51640408, 0x332e08a9, 0x02254ba7,   // mg.to.mi_543 fi.lg.kl_443  no.fo.nn_544 mi.eu.da_532 
  0x39384c09, 0x32000607, 0x3c373004, 0x245630ee,   // wo.tk.br_444 de.bs.un_420  uz.ba.ug_332 uz.mg.eo_422 
  // [20190]
  0x375e56ad, 0x0f003912, 0x0c10460c, 0x16285907,   // mg.ts.st_643 br.lv.un_640  qu.lt.sv_543 rn.sw.hr_432 
  0x355e28a7, 0x101304ee, 0x59006a13, 0x4e462508,   // sw.ts.zu_532 fi.et.lt_422  haw.rn.un_650 eu.qu.ay_443 
  0x093f4ea4, 0x4b285604, 0x46106704, 0x465c1d5a,   // ay.af.pl_433 mg.sw.mi_332  ak.lt.qu_332 la.sa.qu_553 
  0x0912060c, 0x05422fa0, 0x341823af, 0x04170a0b,   // de.hu.pl_543 su.co.fr_322  ky.ar.ps_655 mk.sr.ru_542 
  // [201a0]
  0x1c2f4e05, 0x10200f02, 0x40005002, 0x240679a7,   // ay.su.id_333 lv.sq.lt_222  fj.lb.un_220 war.de.eo_532 
  0x24080204, 0x1f494fa9, 0x50295255, 0x1e53050c,   // da.no.eo_332 bi.to.cy_544  ha.sl.fj_442 fr.ht.ms_543 
  0x495a5008, 0x5a246aa4, 0x201dfea4, 0x11162da7,   // fj.sm.to_443 haw.eo.sm_433  tlh.la.sq_433 sk.hr.ro_532 
  0x23173808, 0x1d4c2007, 0x4220530d, 0x5d245cee,   // tk.sr.ky_443 sq.wo.la_432  ht.sq.co_554 sa.eo.ss_422 
  // [201b0]
  0x434d01ee, 0x12766911, 0x30004c0e, 0xfc024204,   // en.aa.ie_422 mfe.crs.hu_653  wo.uz.un_550 co.da.zzp_332 
  0x25315908, 0x090d2005, 0x792d0da7, 0x0742500c,   // rn.az.eu_443 sq.cs.pl_333  cs.sk.war_532 fj.co.it_543 
  0x1642500c, 0x496745a4, 0x563f1f08, 0x23fc76ee,   // fj.co.hr_543 ln.ak.to_433  cy.af.mg_443 crs.zzp.ca_422 
  0x12002705, 0x25006e07, 0x21422707, 0x095c1012,   // gd.hu.un_330 hmn.eu.un_420  gd.co.jw_432 lt.sa.pl_654 
  // [201c0]
  0x21003802, 0x040c1208, 0x074838ac, 0x442834a9,   // tk.jw.un_220 hu.sv.fi_443  tk.tt.bg_632 ps.sd.kk_544 
  0x123d300d, 0x2a645ea0, 0x2b00680d, 0x2e000c0c,   // uz.ku.ur_554 ts.lg.mt_322  ig.vi.un_540 sv.fo.un_530 
  0x60150208, 0x2a694ea4, 0x34462aee, 0x2a3b1d05,   // da.vo.un_430 ay.mfe.mt_433  mt.qu.xh_422 la.so.mt_333 
  0x17004419, 0x052223a7, 0x40200c04, 0x20000a05,   // kk.sr.un_750 ca.oc.fr_532  sv.sq.lb_332 pt.sq.un_330 
  // [201d0]
  0x18282aa0, 0x262a4da4, 0x12341805, 0x614e02af,   // mt.sw.ga_322 aa.mt.ia_433  ar.ps.ur_333 da.ay.za_655 
  0x37136011, 0x20232205, 0x405a1504, 0x37132608,   // vo.et.st_653 oc.ca.sq_333  un.sm.lb_332 ia.et.st_443 
  0x054a2107, 0x4f13455a, 0x40202255, 0x2f0d20ee,   // jw.yo.fr_432 ln.et.bi_553  oc.sq.lb_442 sq.cs.su_422 
  0x1f376a08, 0x6b002f07, 0x6a135f0c, 0x55676907,   // haw.st.cy_443 su.ceb.un_420  tn.et.haw_543 mfe.ak.rw_432 
  // [201e0]
  0x2a006111, 0x12061f08, 0x21006304, 0xfe1e1c0e,   // za.mt.un_630 cy.de.hu_443  sco.jw.un_320 id.ms.tlh_555 
  0x4a375f08, 0xfc003809, 0x20241105, 0x054253b3,   // tn.st.yo_443 tk.zzp.un_440  ro.eo.sq_333 ht.co.fr_743 
  0x6a133f04, 0x5340250c, 0x061e5bac, 0x6b002f04,   // af.et.haw_332 eu.lb.ht_543  sg.ms.de_632 su.ceb.un_320 
  0x5f3745a9, 0x692024a9, 0x22532d17, 0x39004f0e,   // ln.st.tn_544 eo.sq.mfe_544  sk.ht.oc_753 bi.br.un_550 
  // [201f0]
  0x0940640c, 0x1c005e02, 0x1235730d, 0x124c2f02,   // lg.lb.pl_543 ts.id.un_220  ny.zu.hu_554 su.wo.hu_222 
  0x355d060c, 0x28003904, 0x3308120c, 0x15002b23,   // de.ss.zu_543 br.sw.un_320  hu.no.nn_543 vi.un.un_880 
  0x13697611, 0x165c2904, 0x1f3f020b, 0x63025faf,   // crs.mfe.et_653 sl.sa.hr_332  da.af.cy_542 tn.da.sco_655 
  0x0dfe2fa0, 0x362d0dee, 0x1d132304, 0x47045a0d,   // su.tlh.cs_322 cs.sk.gn_422  ca.et.la_332 sm.fi.sn_554 
  // [20200]
  0x2f281f07, 0x694f6308, 0x3900fe0c, 0x300708a9,   // cy.sw.su_432 sco.bi.mfe_443  tlh.br.un_530 uk.bg.uz_544 
  0x10480760, 0x3000060d, 0x0e0c26a0, 0x3b13035a,   // bg.tt.be_664 de.uz.un_540  ia.sv.is_322 nl.et.so_553 
  0x3400460d, 0x40033f0c, 0x102e40a0, 0x2c3f4c09,   // qu.xh.un_540 af.nl.lb_543  lb.fo.lt_322 wo.af.fy_444 
  0x2d0d49a9, 0x3f653b0c, 0x403b3fa0, 0x4d583ba4,   // to.cs.sk_544 so.gv.af_543  af.so.lb_322 so.om.aa_433 
  // [20210]
  0x3b000308, 0x30525da7, 0x0a000e04, 0x524d4608,   // nl.so.un_430 ss.ha.uz_532  is.pt.un_320 qu.aa.ha_443 
  0x23005805, 0x301b3b07, 0x130e3fa0, 0x583f4c04,   // om.ca.un_330 so.tr.uz_432  af.is.et_322 wo.af.om_332 
  0x4c033fa9, 0x3f574c0c, 0x2f005d02, 0x492d0d04,   // af.nl.wo_544 wo.na.af_543  ss.su.un_220 cs.sk.to_332 
  0x163813a4, 0x56000808, 0x23190e02, 0x230b19ad,   // et.tk.hr_433 no.mg.un_430  is.gl.ca_222 gl.es.ca_643 
  // [20220]
  0x58005b12, 0x0e2e6007, 0x321330a0, 0x1c0c2e07,   // sg.om.un_640 vo.fo.is_432  uz.et.bs_322 fo.sv.id_432 
  0x58314604, 0x483146a7, 0x0e083307, 0x59345512,   // qu.az.om_332 qu.az.tt_532  nn.no.is_432 rw.xh.rn_654 
  0x0200641a, 0x2c000407, 0x1a4830a0, 0x215d3507,   // lg.da.un_760 fi.fy.un_420  uz.tt.tl_322 zu.ss.jw_432 
  0x64005f13, 0x203813a4, 0x2d0d4d14, 0x15002802,   // tn.lg.un_650 et.tk.sq_433  aa.cs.sk_666 sw.un.un_220 
  // [20230]
  0x64124f04, 0x65190b02, 0x1a000207, 0x023673a4,   // bi.hu.lg_332 es.gl.gv_222  da.tl.un_420 ny.gn.da_433 
  0x47233502, 0x55002c0d, 0x532342a0, 0x2e45120d,   // zu.ca.sn_222 fy.rw.un_540  co.ca.ht_322 hu.ln.fo_554 
  0x482031a0, 0x380e2e55, 0x1b006b07, 0x130c04ee,   // az.sq.tt_322 fo.is.tk_442  ceb.tr.un_420 fi.sv.et_422 
  0x1b002c02, 0x2b00680e, 0x3d3c2804, 0x0c003105,   // fy.tr.un_220 ig.vi.un_550  sd.ug.ku_332 az.sv.un_330 
  // [20240]
  0x30001a05, 0x371048ee, 0x2c2122ee, 0x35301005,   // tl.uz.un_330 tt.be.ba_422  oc.jw.fy_422 be.uz.tg_333 
  0x070a440d, 0x42560507, 0x49002d07, 0x40002302,   // kk.mk.bg_554 fr.mg.co_432  sk.to.un_420 ca.lb.un_220 
  0x060c1507, 0x230a36a6, 0x52005811, 0x1b005505,   // un.sv.de_432 ab.mk.ky_521  om.ha.un_630 rw.tr.un_330 
  0x305c3b0c, 0x3b304d55, 0x050a36a0, 0x3b1a6a0d,   // so.sa.uz_543 aa.uz.so_442  gn.pt.fr_322 haw.tl.so_554 
  // [20250]
  0x56541a08, 0x58003407, 0x6a1a490c, 0x024b6aa4,   // tl.ik.mg_443 xh.om.un_420  to.tl.haw_543 haw.mi.da_433 
  0x552802a9, 0x5d3b02a0, 0x3b564909, 0x64594c04,   // da.sw.rw_544 da.so.ss_322  to.mg.so_444 wo.rn.lg_332 
  0x3b005407, 0x64583b12, 0x553b1a0c, 0x5e003b05,   // ik.so.un_420 so.om.lg_654  tl.so.rw_543 so.ts.un_330 
  0x21532205, 0x283555a6, 0x2e040213, 0x35003b0c,   // oc.ht.jw_333 rw.zu.sw_521  da.fi.fo_665 so.zu.un_530 
  // [20260]
  0x28045cee, 0x3b554b02, 0x440a15a0, 0x382c09ee,   // sa.fi.sw_422 mi.rw.so_222  un.mk.kk_322 pl.fy.tk_422 
  0x521b4b09, 0x2f4c6b0c, 0x4b5c56a0, 0x6b003f05,   // mi.tr.ha_444 ceb.wo.su_543  mg.sa.mi_322 af.ceb.un_330 
  0x2c001b09, 0x18274c0c, 0x124c6560, 0x35000822,   // tr.fy.un_440 wo.gd.ga_543  gv.wo.hu_664 uk.tg.un_870 
  0x15110812, 0x3f032c02, 0x4404150d, 0x01154308,   // uk.ro.un_654 fy.nl.af_222  un.ru.kk_554 ie.en.un_430 
  // [20270]
  0x400b23ee, 0x35004019, 0x34246407, 0x5935470d,   // ca.es.lb_422 lb.zu.un_750  lg.eo.xh_432 sn.zu.rn_554 
  0x35553407, 0x4c00530e, 0x5c1c1360, 0x2d5930a4,   // xh.rw.zu_432 ht.wo.un_550  bh.mr.sa_664 uz.rn.sk_433 
  0x45357912, 0x32006807, 0x555e5960, 0xfc1d0a0c,   // war.zu.ln_654 ig.bs.un_420  rn.ts.rw_664 pt.la.zzp_543 
  0x19000905, 0x10175507, 0x5e005d0e, 0x48290d12,   // pl.gl.un_330 rw.sr.lt_432  ss.ts.un_550 cs.sl.tt_654 
  // [20280]
  0x552d5907, 0x025973a4, 0x3e403902, 0x28002407,   // rn.sk.rw_432 ny.rn.da_433  br.lb.rm_222 eo.sw.un_420 
  0x6b4a02a9, 0x50005807, 0xfc001814, 0x305559ad,   // da.yo.ceb_544 om.fj.un_420  ga.zzp.un_660 rn.rw.uz_643 
  0xfe0c61ad, 0x35346808, 0x1508350c, 0x4c45280c,   // za.sv.tlh_643 ig.xh.zu_443  tg.uk.un_543 sw.ln.wo_543 
  0x22182d11, 0x294517a4, 0x3300400d, 0x55005d0b,   // sk.ga.oc_653 sr.ln.sl_433  lb.nn.un_540 ss.rw.un_520 
  // [20290]
  0x4c00fe1a, 0x683745ec, 0x210102a4, 0x07002208,   // tlh.wo.un_760 ln.st.ig_644  da.en.jw_433 oc.it.un_430 
  0x39003719, 0x60260209, 0x3023480e, 0x0f006504,   // st.br.un_750 da.ia.vo_444  tt.ky.uz_555 gv.lv.un_320 
  0x02fe6ead, 0x616efead, 0x2b246e07, 0xfe000914,   // hmn.tlh.da_643 tlh.hmn.za_643  hmn.eo.vi_432 pl.tlh.un_660 
  0x16006e08, 0x18311b14, 0x3540280e, 0x3b00122b,   // hmn.hr.un_430 tr.az.ga_666  sw.lb.zu_555 ur.ks.un_980 
  // [202a0]
  0x3530080c, 0x6169760c, 0x111b4802, 0x181221ad,   // uk.uz.tg_543 crs.mfe.za_543  tt.tr.ro_222 fa.ur.ar_643 
  0x32161002, 0x3000310b, 0x15080a07, 0x38091507,   // lt.hr.bs_222 az.uz.un_520  mk.uk.un_432 un.pl.tk_432 
  0x153736a4, 0x3efc06a0, 0x090f0602, 0x2d560911,   // ab.ba.un_433 de.zzp.rm_322  de.lv.pl_222 pl.mg.sk_653 
  0x055302a0, 0x05195d02, 0x0c0e60a7, 0x0c0660a0,   // da.ht.fr_322 ss.gl.fr_222  vo.is.sv_532 vo.de.sv_322 
  // [202b0]
  0x080213a9, 0x130c0807, 0x06003005, 0x060313ee,   // et.da.no_544 no.sv.et_432  uz.de.un_330 et.nl.de_422 
  0x305228a9, 0x601c1ea9, 0x357362ee, 0x5a502108,   // sw.ha.uz_544 ms.id.vo_544  kha.ny.zu_422 jw.fj.sm_443 
  0x55136407, 0x51005a13, 0x0b603bad, 0x57001b0e,   // lg.et.rw_432 sm.kl.un_650  so.vo.es_643 tr.na.un_550 
  0x16006b0c, 0x644d10ad, 0x553045a7, 0x385064ad,   // ceb.hr.un_530 lt.aa.lg_643  ln.uz.rw_532 lg.fj.tk_643 
  // [202c0]
  0x330213a0, 0x4a001d02, 0x121f7807, 0x40063ea9,   // et.da.nn_322 la.yo.un_220  ve.cy.hu_432 rm.de.lb_544 
  0x166a73ad, 0x494213a4, 0x29002504, 0x2a5a4911,   // ny.haw.hr_643 et.co.to_433  eu.sl.un_320 to.sm.mt_653 
  0x1d671f12, 0x17080707, 0x182128a9, 0x48000907,   // cy.ak.la_654 bg.uk.sr_432  sd.fa.ar_544 pl.tt.un_420 
  0x1b002408, 0x3c1510a4, 0x38326ba4, 0x47007908,   // eo.tr.un_430 be.ug.un_430  ceb.bs.tk_433 war.sn.un_430 
  // [202d0]
  0x35005405, 0x21004208, 0x47213b09, 0x7300091a,   // ik.zu.un_330 co.jw.un_430  so.jw.sn_444 pl.ny.un_760 
  0x346435af, 0x181923a4, 0x38001a04, 0x7302465a,   // zu.lg.xh_655 ca.gl.ga_433  tl.tk.un_320 qu.da.ny_553 
  0xfc0c3fa4, 0x38132508, 0x06003407, 0x45381ea9,   // af.sv.zzp_433 eu.et.tk_443  xh.de.un_420 ms.tk.ln_544 
  0x04135a02, 0x2e0e04a0, 0x5c3164ac, 0x32080205,   // sm.et.fi_222 fi.is.fo_322  lg.az.sa_632 da.no.bs_333 
  // [202e0]
  0x1f1b4ba0, 0x38796b07, 0x2a5839a0, 0x2f1c68a0,   // mi.tr.cy_322 ceb.war.tk_432  br.om.mt_322 ig.id.su_322 
  0x151e1c60, 0x34005411, 0x196518ee, 0x1100181a,   // id.ms.un_664 ik.xh.un_630  ga.gv.gl_422 ga.ro.un_760 
  0x033f06ac, 0x20110fa4, 0x0b0a05a0, 0x2b001004,   // de.af.nl_632 lv.ro.sq_433  fr.pt.es_322 lt.vi.un_320 
  0x42495a07, 0x1d11050d, 0x500361af, 0x1d2501a0,   // sm.to.co_432 fr.ro.la_554  za.nl.fj_655 en.eu.la_322 
  // [202f0]
  0x42032511, 0x03004902, 0x34005004, 0x642718a7,   // eu.nl.co_653 to.nl.un_220  fj.xh.un_320 ga.gd.lg_532 
  0x2a3534a4, 0x35002a0d, 0x3e3f10a4, 0x02000a0d,   // xh.zu.mt_433 mt.zu.un_540  lt.af.rm_433 pt.da.un_540 
  0x09004b04, 0x63001d05, 0x1d004b0c, 0x230d2d07,   // mi.pl.un_320 la.sco.un_330  mi.la.un_530 sk.cs.ca_432 
  0x49005005, 0x39001007, 0x0a42110c, 0x39353408,   // fj.to.un_330 lt.br.un_420  ro.co.pt_543 xh.zu.br_443 
  // [20300]
  0x435d3508, 0x2a003007, 0x5f1a6b0c, 0x586b1dee,   // zu.ss.ie_443 uz.mt.un_420  ceb.tl.tn_543 la.ceb.om_422 
  0x42071d13, 0x481b6012, 0x061260ee, 0x153c0409,   // la.it.co_665 vo.tr.tt_654  vo.hu.de_422 ru.ug.un_444 
  0x30001313, 0x1b365b0c, 0x0f004607, 0x08172302,   // et.uz.un_650 sg.gn.tr_543  qu.lv.un_420 ky.sr.uk_222 
  0x302311ac, 0x365b4811, 0x1b005b0c, 0x3e004b05,   // ro.ky.uz_632 tt.sg.gn_653  sg.tr.un_530 mi.rm.un_330 
  // [20310]
  0x0c202507, 0x350410a0, 0x0a005508, 0x371510ad,   // eu.sq.sv_432 be.ru.tg_322  rw.pt.un_430 be.ba.un_630 
  0x2219180c, 0x79050d05, 0x111510a4, 0x47005908,   // ga.gl.oc_543 cs.fr.war_333  be.ro.un_430 rn.sn.un_430 
  0x3b1b31a4, 0x52733b05, 0x642f680b, 0x35344eee,   // az.tr.so_433 so.ny.ha_333  ig.su.lg_542 ay.xh.zu_422 
  0x024d5213, 0xfc6305ee, 0x3810fca4, 0x46386507,   // ha.aa.da_665 fr.sco.zzp_422  zzp.lt.tk_433 gv.tk.qu_432 
  // [20320]
  0x47005307, 0xfc02100c, 0x62355d12, 0x1ffc12a4,   // ht.sn.un_420 lt.da.zzp_543  ss.zu.kha_654 hu.zzp.cy_433 
  0x5d627312, 0x5a005711, 0x1c1b1ea0, 0x2c1f02a0,   // ny.kha.ss_654 na.sm.un_630  ms.tr.id_322 da.cy.fy_322 
  0x16001d04, 0x35007819, 0x3b003409, 0x46005221,   // la.hr.un_320 ve.zu.un_750  xh.so.un_440 ha.qu.un_860 
  0x09fc1013, 0x04300702, 0x6400350e, 0x1f46fca4,   // lt.zzp.pl_665 bg.uz.ru_222  zu.lg.un_550 zzp.qu.cy_433 
  // [20330]
  0xfc101f11, 0x100451a4, 0xfc001008, 0x4e001e21,   // cy.lt.zzp_653 kl.fi.lt_433  lt.zzp.un_430 ms.ay.un_860 
  0x53005713, 0x55002a0e, 0x123e1304, 0x13463904,   // na.ht.un_650 mt.rw.un_550  et.rm.hu_332 br.qu.et_332 
  0x40480cad, 0x53004f07, 0x38400ca0, 0x06134012,   // sv.tt.lb_643 bi.ht.un_420  sv.lb.tk_322 lb.et.de_654 
  0x21004819, 0x40000c2a, 0x43004012, 0x03003f21,   // tt.jw.un_750 sv.lb.un_970  lb.ie.un_640 af.nl.un_860 
  // [20340]
  0x476a4907, 0x12253607, 0x13044907, 0x210225ad,   // to.haw.sn_432 gn.eu.hu_432  to.fi.et_432 eu.da.jw_643 
  0x0817075a, 0x08001108, 0x632549ee, 0x08001305,   // bg.sr.uk_553 ro.uk.un_430  to.eu.sco_422 et.no.un_330 
  0x6b1375ad, 0x060e0c02, 0x30083505, 0x1c004902,   // nso.et.ceb_643 sv.is.de_222  tg.uk.uz_333 to.id.un_220 
  0x32170d05, 0x44003b12, 0x56001308, 0x790252a6,   // cs.sr.bs_333 ks.kk.un_640  et.mg.un_430 ha.da.war_521 
  // [20350]
  0x33246402, 0x38441507, 0x4f460811, 0x13040d0b,   // lg.eo.nn_222 un.kk.tk_432  no.qu.bi_653 cs.fi.et_542 
  0x524a6804, 0x2f241e07, 0x4b00570c, 0x0f1b0107,   // ig.yo.ha_332 ms.eo.su_432  na.mi.un_530 en.tr.lv_432 
  0x6e635aa0, 0x52243904, 0x07001207, 0x12422007,   // sm.sco.hmn_322 br.eo.ha_332  hu.it.un_420 sq.co.hu_432 
  0x24491f02, 0x04081713, 0x041308a4, 0x40250fec,   // cy.to.eo_222 sr.uk.ru_665  no.et.fi_433 lv.eu.lb_644 
  // [20360]
  0x10531ca4, 0x2c3946a6, 0x0f001104, 0x0f004802,   // id.ht.lt_433 qu.br.fy_521  ro.lv.un_320 tt.lv.un_220 
  0x09131c5a, 0x233035a4, 0x5a1013a4, 0x42231d07,   // mr.bh.hi_553 tg.uz.ky_433  et.lt.sm_433 la.ca.co_432 
  0x192a0714, 0x1b483813, 0x28021309, 0x25003402,   // it.mt.gl_666 tk.tt.tr_665  et.da.sw_444 xh.eu.un_220 
  0x13324204, 0x371360a4, 0x40001e0c, 0x390e60af,   // co.bs.et_332 vo.et.st_433  ms.lb.un_530 vo.is.br_655 
  // [20370]
  0x19093404, 0x5d1b48ec, 0x19004c07, 0x480a3707,   // xh.pl.gl_332 tt.tr.ss_644  wo.gl.un_420 ba.mk.tt_432 
  0x353450a4, 0x10040aa7, 0x40461505, 0x560b01a0,   // fj.xh.zu_433 mk.ru.be_532  un.qu.lb_333 en.es.mg_322 
  0x50005813, 0x126e61ad, 0x29002433, 0xfc004813,   // om.fj.un_650 za.hmn.hu_643  eo.sl.un_A70 tt.zzp.un_650 
  0x571501a4, 0x61536ea9, 0x2d6e295a, 0x3317fc0c,   // en.na.un_430 hmn.ht.za_544  sl.hmn.sk_553 zzp.sr.nn_543 
  // [20380]
  0x08171105, 0x01fe26a7, 0x4500211b, 0x67594507,   // ro.sr.uk_333 ia.tlh.en_532  jw.ln.un_770 ln.rn.ak_432 
  0xfe001214, 0x4a79020d, 0x600b08a0, 0x616e1ea9,   // hu.tlh.un_660 da.war.yo_554  no.es.vo_322 ms.hmn.za_544 
  0x4831300e, 0x6e61fe12, 0x4f76230b, 0x30283ba7,   // uz.az.tt_555 tlh.za.hmn_654  ca.crs.bi_542 ks.sd.uz_532 
  0x39636907, 0x204c6e0c, 0x79007612, 0x5e5d57a4,   // mfe.sco.br_432 hmn.wo.sq_543  crs.war.un_640 na.ss.ts_433 
  // [20390]
  0x653f0313, 0x0c18275a, 0x4c006e1a, 0x1c4a53a0,   // nl.af.gv_665 gd.ga.sv_553  hmn.wo.un_760 ht.yo.id_322 
  0x38351009, 0x29002023, 0x6e00532c, 0xfc004a0d,   // be.tg.tk_444 sq.sl.un_880  ht.hmn.un_990 yo.zzp.un_540 
  0x6e00fe34, 0x46000213, 0x29006214, 0x024a07a4,   // tlh.hmn.un_A80 da.qu.un_650  kha.sl.un_660 it.yo.da_433 
  0x02292da9, 0x0e321713, 0x46311b08, 0x5c2e1304,   // sk.sl.da_544 sr.bs.is_665  tr.az.qu_443 et.fo.sa_332 
  // [203a0]
  0x4a595514, 0x085c1304, 0x242d6e07, 0x353044ac,   // rw.rn.yo_666 et.sa.no_332  hmn.sk.eo_432 kk.uz.tg_632 
  0x0f002d0e, 0x2c2a1b07, 0x35fa3760, 0x334831a4,   // sk.lv.un_550 tr.mt.fy_432  st.nr.zu_664 az.tt.nn_433 
  0x475955ad, 0x2d04290b, 0x18283cb2, 0x292055a0,   // rw.rn.sn_643 sl.fi.sk_542  ug.sd.ar_732 rw.sq.sl_322 
  0x3f0f3002, 0x6b1afea0, 0x0f006b02, 0x25033f07,   // uz.lv.af_222 tlh.tl.ceb_322  ceb.lv.un_220 af.nl.eu_432 
  // [203b0]
  0x2f003707, 0x330824a4, 0x32002102, 0x0b1a6bee,   // st.su.un_420 eo.no.nn_433  jw.bs.un_220 ceb.tl.es_422 
  0x032c61ac, 0x79311d07, 0x2c033f13, 0x123b2108,   // za.fy.nl_632 la.az.war_432  af.nl.fy_665 fa.ks.ur_443 
  0x1a005c05, 0x3000232b, 0x0c220402, 0x30313802,   // sa.tl.un_330 ky.uz.un_980  fi.oc.sv_222 tk.az.uz_222 
  0x31304e07, 0x12005004, 0x07002904, 0x5a001f12,   // ay.uz.az_432 fj.hu.un_320  sl.it.un_320 cy.sm.un_640 
  // [203c0]
  0x13315c08, 0xfc1d0205, 0x35002c04, 0x325c2da4,   // sa.az.et_443 da.la.zzp_333  fy.zu.un_320 sk.sa.bs_433 
  0x64353402, 0x18290111, 0x21532ca0, 0x28555912,   // xh.zu.lg_222 en.sl.ga_653  fy.ht.jw_322 rn.rw.sw_654 
  0x5947640c, 0x3b5e4708, 0x64004507, 0x47552c02,   // lg.sn.rn_543 sn.ts.so_443  ln.lg.un_420 fy.rw.sn_222 
  0x060a7308, 0x2c004714, 0x35647304, 0x472164af,   // ny.pt.de_443 sn.fy.un_660  ny.lg.zu_332 lg.jw.sn_655 
  // [203d0]
  0x47737813, 0x3c303860, 0x3b00370d, 0x5d190b04,   // ve.ny.sn_665 tk.uz.ug_664  st.so.un_540 es.gl.ss_332 
  0x55062805, 0x2700570c, 0x1e4f28ee, 0x2e074211,   // sw.de.rw_333 na.gd.un_530  sw.bi.ms_422 co.it.fo_653 
  0x212830a0, 0x1f003409, 0x585a2a05, 0x4400152a,   // uz.sd.fa_322 xh.cy.un_440  mt.sm.om_333 un.kk.un_970 
  0x325206ee, 0x16005107, 0x34005604, 0x09000209,   // de.ha.bs_422 kl.hr.un_420  mg.xh.un_320 da.pl.un_440 
  // [203e0]
  0x186861a9, 0x3b0e180c, 0x1630690c, 0x34094707,   // za.ig.ga_544 ga.is.so_543  mfe.uz.hr_543 sn.pl.xh_432 
  0x633b650b, 0x653b1311, 0x69104808, 0x353463ee,   // gv.so.sco_542 et.so.gv_653  tt.lt.mfe_443 sco.xh.zu_422 
  0x3e300f08, 0x47096402, 0x04006112, 0x243b6007,   // lv.uz.rm_443 lg.pl.sn_222  za.fi.un_640 vo.so.eo_432 
  0x34755f0c, 0x09004c0c, 0x2c584c02, 0x09006414,   // tn.nso.xh_543 wo.pl.un_530  wo.om.fy_222 lg.pl.un_660 
  // [203f0]
  0x52424505, 0x32006808, 0x654a7307, 0x3b004d2a,   // ln.co.ha_333 ig.bs.un_430  ny.yo.gv_432 aa.so.un_970 
  0x09393007, 0x300afe55, 0x4a7309a9, 0xfc063907,   // uz.br.pl_432 tlh.pt.uz_442  pl.ny.yo_544 br.de.zzp_432 
  0x4c00360c, 0x0c340307, 0x65343b0c, 0x291e30ee,   // gn.wo.un_530 nl.xh.sv_432  so.xh.gv_543 uz.ms.sl_422 
  0x6e356407, 0x354837a4, 0x37635fa4, 0x02006019,   // lg.zu.hmn_432 ba.tt.tg_433  tn.sco.st_433 vo.da.un_750 
  
  // [20400]
  0x3e04135a, 0x092f6412, 0x360b1d11, 0x136303a4,   // et.fi.rm_553 lg.su.pl_654  la.es.gn_653 nl.sco.et_433 
  0x4d003022, 0x63004d0d, 0x094a6404, 0x2e3b020c,   // uz.aa.un_870 aa.sco.un_540  lg.yo.pl_332 da.so.fo_543 
  0x3f240807, 0x30073c07, 0x30006e1b, 0x3423440c,   // no.eo.af_432 ug.bg.uz_432  hmn.uz.un_770 kk.ky.ps_543 
  0x283021a4, 0x641302a6, 0x75005f13, 0x512554ad,   // fa.uz.sd_433 da.et.lg_521  tn.nso.un_650 ik.eu.kl_643 
  // [20410]
  0x1c4053a4, 0x080417ad, 0x431d4aaf, 0x084f3307,   // ht.lb.id_433 sr.ru.uk_643  yo.la.ie_655 nn.bi.no_432 
  0x12343ba4, 0x3e033f07, 0x5c1e13a4, 0x135f3712,   // ks.ps.ur_433 af.nl.rm_432  et.ms.sa_433 st.tn.et_654 
  0x56255d14, 0x17126eee, 0x25477308, 0x12255607,   // ss.eu.mg_666 hmn.hu.sr_422  ny.sn.eu_443 mg.eu.hu_432 
  0x0d002913, 0x52006502, 0x0c06120d, 0x2e0c02a0,   // sl.cs.un_650 gv.ha.un_220  hu.de.sv_554 da.sv.fo_322 
  // [20420]
  0x2a685f0c, 0x552873a7, 0x15041707, 0x571861af,   // tn.ig.mt_543 ny.sw.rw_532  sr.ru.un_432 za.ga.na_655 
  0x093538ec, 0x644a5b07, 0x556453a4, 0x4a6421a0,   // tk.zu.pl_644 sg.yo.lg_432  ht.lg.rw_433 jw.lg.yo_322 
  0x1d021bee, 0x233738a4, 0x4c00020c, 0x521f780c,   // tr.da.la_422 tk.ba.ky_433  da.wo.un_530 ve.cy.ha_543 
  0x092046a6, 0x1000130c, 0x0e202e04, 0x1a003305,   // qu.sq.pl_521 et.lt.un_530  fo.sq.is_332 nn.tl.un_330 
  // [20430]
  0x555f47a4, 0x2818210b, 0x695363af, 0x534a6307,   // sn.tn.rw_433 fa.ar.sd_542  sco.ht.mfe_655 sco.yo.ht_432 
  0x381dfc07, 0x3b0957ad, 0x0e13510c, 0x4e041312,   // zzp.la.tk_432 na.pl.so_643  kl.et.is_543 et.fi.ay_654 
  0x30002e02, 0x0e1113ee, 0x043e06a0, 0x20381ba0,   // fo.uz.un_220 et.ro.is_422  de.rm.fi_322 tr.tk.sq_322 
  0x231710a4, 0x3c3d230c, 0x081e4f0c, 0x4c3848a9,   // be.sr.ky_433 ky.ku.ug_543  bi.ms.no_543 tt.tk.wo_544 
  // [20440]
  0x214022a7, 0x3b6b4607, 0x382a6bee, 0x30383ca7,   // oc.lb.jw_532 qu.ceb.so_432  ceb.mt.tk_422 ug.tk.uz_532 
  0x07004005, 0x482a46a4, 0x2a384807, 0x4615010b,   // lb.it.un_330 qu.mt.tt_433  tt.tk.mt_432 en.qu.un_520 
  0x08150aad, 0x3f221dee, 0x311e1bee, 0x1800750b,   // mk.uk.un_630 la.oc.af_422  tr.ms.az_422 nso.ga.un_520 
  0x172330ee, 0x303c1112, 0x0a37365a, 0x49287307,   // uz.ky.sr_422 ro.ug.uz_654  ab.ba.mk_553 ny.sw.to_432 
  // [20450]
  0x2a181d08, 0x1e2f3b5a, 0xfc1828ad, 0x5e5c3b07,   // la.ga.mt_443 so.su.ms_553  sw.ga.zzp_643 so.sa.ts_432 
  0x5c213b07, 0x52002812, 0xfa35340c, 0x154811ec,   // so.jw.sa_432 sw.ha.un_640  xh.zu.nr_543 ro.tt.un_644 
  0x3b7955ee, 0x3b311ba7, 0x58003b07, 0x313460a9,   // rw.war.so_422 tr.az.so_532  so.om.un_420 vo.xh.az_544 
  0xfe006b07, 0x0e0c0807, 0x39004704, 0x3b003111,   // ceb.tlh.un_420 no.sv.is_432  sn.br.un_320 az.so.un_630 
  // [20460]
  0x3e46fe05, 0x25060fa0, 0x126b5c0c, 0x6b5c3ba7,   // tlh.qu.rm_333 lv.de.eu_322  sa.ceb.hu_543 so.sa.ceb_532 
  0x64303b02, 0x6b1a360c, 0x03595508, 0x3773350c,   // so.uz.lg_222 gn.tl.ceb_543  rw.rn.nl_443 zu.ny.st_543 
  0x5c3b21a9, 0x5c475fa6, 0x06006713, 0x0300fa08,   // jw.so.sa_544 tn.sn.sa_521  ak.de.un_650 nr.nl.un_430 
  0x5c000108, 0x6407420c, 0x072a4255, 0x3b1858a4,   // en.sa.un_430 co.it.lg_543  co.mt.it_442 om.ga.so_433 
  // [20470]
  0x79003122, 0x15003f14, 0x480407ee, 0x681d570c,   // az.war.un_870 af.un.un_660  bg.ru.tt_422 na.la.ig_543 
  0x28583baf, 0x194c0b07, 0x3b005c19, 0x2f0f1ca0,   // so.om.sw_655 es.wo.gl_432  sa.so.un_750 id.lv.su_322 
  0x4f791012, 0x64356208, 0x7378450d, 0x585c3b0c,   // lt.war.bi_654 kha.zu.lg_443  ln.ve.ny_554 so.sa.om_543 
  0x4724530b, 0x1d6853ee, 0x35000302, 0x5f287855,   // ht.eo.sn_542 ht.ig.la_422  nl.zu.un_220 ve.sw.tn_442 
  // [20480]
  0x173542a0, 0x52071105, 0x020728a4, 0x353044ee,   // co.zu.sr_322 ro.it.ha_333  sw.it.da_433 kk.uz.tg_422 
  0xfa5d3509, 0x5c130d12, 0x464e6407, 0x0d30fe0b,   // zu.ss.nr_444 ne.bh.sa_654  lg.ay.qu_432 tlh.uz.cs_542 
  0x5d355012, 0x50005a0c, 0x3418285a, 0x1a004e0c,   // fj.zu.ss_654 sm.fj.un_530  sd.ar.ps_553 ay.tl.un_530 
  0x47567304, 0x79004c08, 0x17041004, 0x594567ee,   // ny.mg.sn_332 wo.war.un_430  be.ru.sr_332 ak.ln.rn_422 
  // [20490]
  0x494afcac, 0x7367fc0c, 0x2e003507, 0x0a2312a4,   // zzp.yo.to_632 zzp.ak.ny_543  zu.fo.un_420 hu.ca.pt_433 
  0x5c003022, 0x04586404, 0xfc355aa0, 0x0a00280c,   // uz.sa.un_870 lg.om.fi_332  sm.zu.zzp_322 sw.pt.un_530 
  0x390458a7, 0x645104af, 0x135104a0, 0x491f3704,   // om.fi.br_532 fi.kl.lg_655  fi.kl.et_322 st.cy.to_332 
  0x3b6458a9, 0x1a4a5104, 0x03586412, 0x5e00780d,   // om.lg.so_544 kl.yo.tl_332  lg.om.nl_654 ve.ts.un_540 
  // [204a0]
  0x29000b02, 0x645a2404, 0x1a5164ad, 0x21283d07,   // es.sl.un_220 eo.sm.lg_332  lg.kl.tl_643 ku.sd.fa_432 
  0x0a6b2da0, 0x04153708, 0x25083507, 0x197356ec,   // sk.ceb.pt_322 ba.ru.un_430  tg.uk.mn_432 mg.ny.gl_644 
  0x4825370c, 0x35005a05, 0x3500fe0e, 0x4a074f07,   // ba.mn.tt_543 sm.zu.un_330  tlh.zu.un_550 bi.it.yo_432 
  0x02604aa4, 0xfe0710a7, 0x2d245aa0, 0x3e002708,   // yo.vo.da_433 lt.it.tlh_532  sm.eo.sk_322 gd.rm.un_430 
  // [204b0]
  0x3d12300b, 0x28004307, 0x20006a12, 0x622046ad,   // uz.ur.ku_542 ie.sw.un_420  haw.sq.un_640 qu.sq.kha_643 
  0x63600107, 0x46042aa9, 0x230b0a09, 0x51041304,   // en.vo.sco_432 mt.fi.qu_544  pt.es.ca_444 et.fi.kl_332 
  0x734e42a4, 0x111d2414, 0x1a126b0c, 0xfc496307,   // co.ay.ny_433 eo.la.ro_666  ceb.hu.tl_543 sco.to.zzp_432 
  0x18423e60, 0x0f1d6307, 0x3e42250c, 0x084835a0,   // rm.co.ga_664 sco.la.lv_432  eu.co.rm_543 tg.tt.uk_322 
  // [204c0]
  0x2a00250d, 0x36004607, 0x4c002f0c, 0x17300aac,   // eu.mt.un_540 qu.gn.un_420  su.wo.un_530 mk.uz.sr_632 
  0x170443a0, 0x462f3b08, 0x21001e22, 0x64000908,   // ie.fi.sr_322 so.su.qu_443  ms.jw.un_870 pl.lg.un_430 
  0x5e133ba4, 0x5010600c, 0x5e00670d, 0x2f003907,   // so.et.ts_433 vo.lt.fj_543  ak.ts.un_540 br.su.un_420 
  0x044a1ca4, 0x1a3b5102, 0x4c640207, 0x34fa350c,   // id.yo.fi_433 kl.so.tl_222  da.lg.wo_432 zu.nr.xh_543 
  // [204d0]
  0x1c612fec, 0xfe006220, 0x04482fa0, 0x5e341311,   // su.za.id_644 kha.tlh.un_850  su.tt.fi_322 et.xh.ts_653 
  0x510413ee, 0x2b1c6107, 0x171e1c08, 0x61002f1a,   // et.fi.kl_422 za.id.vi_432  id.ms.sr_443 su.za.un_760 
  0x293b42a4, 0x0e3e1304, 0x171b290c, 0x133f510b,   // co.so.sl_433 et.rm.is_332  sl.tr.sr_543 kl.af.et_542 
  0x033f42a0, 0x21420ea0, 0x29453b07, 0x2f4213ee,   // co.af.nl_322 is.co.jw_322  so.ln.sl_432 et.co.su_422 
  // [204e0]
  0x643509a0, 0x4a733508, 0x3b103607, 0x04080a12,   // pl.zu.lg_322 zu.ny.yo_443  gn.lt.so_432 mk.uk.ru_654 
  0x0b04370b, 0x4c434f04, 0x6a383b0c, 0x101279ee,   // st.fi.es_542 bi.ie.wo_332  so.tk.haw_543 war.hu.lt_422 
  0x1b124807, 0x154d1307, 0x35003e07, 0x3e001107,   // tt.hu.tr_432 et.aa.un_432  rm.zu.un_420 ro.rm.un_420 
  0x36351504, 0x07000302, 0x733f03af, 0x20002505,   // un.tg.ab_332 nl.it.un_220  nl.af.ny_655 eu.sq.un_330 
  // [204f0]
  0x1900360d, 0x3f5103ec, 0x28003714, 0x6b1a370c,   // gn.gl.un_540 nl.kl.af_644  st.sw.un_660 st.tl.ceb_543 
  0x490237a4, 0x495803a0, 0x494b4d11, 0x20376a04,   // st.da.to_433 nl.om.to_322  aa.mi.to_653 haw.st.sq_332 
  0x51046404, 0x65005005, 0x464a640d, 0x3300560c,   // lg.fi.kl_332 fj.gv.un_330  lg.yo.qu_554 mg.nn.un_530 
  0x584964af, 0x4c005107, 0x650257a9, 0x36025605,   // lg.to.om_655 kl.wo.un_420  na.da.gv_544 mg.da.gn_333 
  // [20500]
  0x511a2f0c, 0x3b640fa0, 0x4a21370d, 0x4f290908,   // su.tl.kl_543 lv.lg.so_322  st.jw.yo_554 pl.sl.bi_443 
  0x17006e08, 0x3c173007, 0x4a000102, 0x0454640b,   // hmn.sr.un_430 uz.sr.ug_432  en.yo.un_220 lg.ik.fi_542 
  0x024c64a4, 0x1d0a53a6, 0x49561155, 0x64210407,   // lg.wo.da_433 ht.pt.la_521  ro.mg.to_442 fi.jw.lg_432 
  0x4a4b6a07, 0x4d3b6407, 0x5468460c, 0x322e0ea9,   // haw.mi.yo_432 lg.so.aa_432  qu.ig.ik_543 is.fo.bs_544 
  // [20510]
  0x4a371355, 0x5800510b, 0x02090808, 0x1d240aa0,   // et.st.yo_442 kl.om.un_520  no.pl.da_443 pt.eo.la_322 
  0x2e0d620c, 0xfc5a5607, 0x4b005802, 0x281304ec,   // kha.cs.fo_543 mg.sm.zzp_432  om.mi.un_220 fi.et.sw_644 
  0x120633a0, 0x272c1807, 0x120413af, 0x46004712,   // nn.de.hu_322 ga.fy.gd_432  et.fi.hu_655 sn.qu.un_640 
  0x2e001c02, 0x12fc1104, 0x272f5fad, 0x3b5668a4,   // id.fo.un_220 ro.zzp.hu_332  tn.su.gd_643 ig.mg.so_433 
  // [20520]
  0x10002802, 0x65361104, 0x252820a4, 0x321b28a0,   // sw.lt.un_220 ro.gn.gv_332  sq.sw.eu_433 sw.tr.bs_322 
  0x0a0848a0, 0x4d5a0412, 0x303b2d04, 0x045a51ee,   // tt.uk.mk_322 fi.sm.aa_654  sk.so.uz_332 kl.sm.fi_422 
  0x531925a0, 0x485727a4, 0x2d0d100c, 0x04131114,   // eu.gl.ht_322 gd.na.tt_433  lt.cs.sk_543 ro.et.fi_666 
  0x47134ca4, 0x21345da9, 0x7300680d, 0x11313205,   // wo.et.sn_433 ss.xh.jw_544  ig.ny.un_540 bs.az.ro_333 
  // [20530]
  0x405f5aa4, 0x303931a4, 0x02005a04, 0x64190a09,   // sm.tn.lb_433 az.br.uz_433  sm.da.un_320 pt.gl.lg_444 
  0x3e321dee, 0x1e003105, 0x0a1d01a0, 0x56303eac,   // la.bs.rm_422 az.ms.un_330  en.la.pt_322 rm.uz.mg_632 
  0x2f3322a0, 0x31000f09, 0x39002213, 0x312030ec,   // oc.nn.su_322 lv.az.un_440  oc.br.un_650 uz.sq.az_644 
  0x470a30ad, 0x60000f13, 0x0731570c, 0xfc0740a0,   // uz.pt.sn_643 lv.vo.un_650  na.az.it_543 lb.it.zzp_322 
  // [20540]
  0x08390212, 0x39000d20, 0x3f033905, 0x39000213,   // da.br.no_654 cs.br.un_850  br.nl.af_333 da.br.un_650 
  0x3f530304, 0x4f5776a4, 0x440408ad, 0x07150604,   // nl.ht.af_332 crs.na.bi_433  uk.ru.kk_643 de.it.un_320 
  0x34000b02, 0x02060507, 0x3e000421, 0x0100530c,   // es.xh.un_220 fr.de.da_432  fi.rm.un_860 ht.en.un_530 
  0x17000820, 0x69763912, 0x053f4fee, 0x58000422,   // uk.sr.un_850 br.crs.mfe_654  bi.af.fr_422 fi.om.un_870 
  // [20550]
  0x2f21fc07, 0x6b3701a0, 0x1a00fc04, 0x6b00fe08,   // zzp.jw.su_432 en.st.ceb_322  zzp.tl.un_320 tlh.ceb.un_430 
  0x0c334d07, 0x1f001005, 0x353413a9, 0x17362504,   // aa.nn.sv_432 lt.cy.un_330  et.xh.zu_544 mn.ab.sr_332 
  0x0e2e13af, 0x13796708, 0x1b283808, 0x482337a4,   // et.fo.is_655 ak.war.et_443  tk.sw.tr_443 ba.ky.tt_433 
  0x10351104, 0x07001719, 0x443c3bad, 0x484d310e,   // ro.tg.be_332 sr.bg.un_750  ks.ug.kk_643 az.aa.tt_555 
  // [20560]
  0x02001322, 0x09001f0b, 0x2f006123, 0xfc005607,   // et.da.un_870 cy.pl.un_520  za.su.un_880 mg.zzp.un_420 
  0x00005737, 0x4200fe05, 0x4c4830a0, 0x135136a7,   // na.un.un_B00 tlh.co.un_330  uz.tt.wo_322 gn.kl.et_532 
  0x5376fc0c, 0x0600600c, 0x07350aa7, 0x28004c04,   // zzp.crs.ht_543 vo.de.un_530  mk.tg.bg_532 wo.sw.un_320 
  0x1500fc14, 0x02002519, 0x2e00130d, 0x1b241aa0,   // zzp.un.un_660 eu.da.un_750  et.fo.un_540 tl.eo.tr_322 
  // [20570]
  0x4c000205, 0x1a6b4a08, 0x122e5204, 0x09400607,   // da.wo.un_330 yo.ceb.tl_443  ha.fo.hu_332 de.lb.pl_432 
  0x33084cee, 0x583b4c5a, 0x4b006404, 0x440830a0,   // wo.no.nn_422 wo.so.om_553  lg.mi.un_320 uz.uk.kk_322 
  0x0a6436a0, 0x0c621f04, 0x2a000909, 0x5f00490c,   // gn.lg.pt_322 cy.kha.sv_332  pl.mt.un_440 to.tn.un_530 
  0x67584912, 0x53644cee, 0x0e00110d, 0x1b383507,   // to.om.ak_654 wo.lg.ht_422  ro.is.un_540 zu.tk.tr_432 
  // [20580]
  0x16003211, 0x611b35a4, 0x3e076455, 0x22002802,   // bs.hr.un_630 zu.tr.za_433  lg.it.rm_442 sw.oc.un_220 
  0x381b300c, 0x691b7605, 0x791a47ac, 0x15642b04,   // uz.tr.tk_543 crs.tr.mfe_333  sn.tl.war_632 vi.lg.un_332 
  0x5e7345ec, 0x00005b42, 0x2873590c, 0x735c4707,   // ln.ny.ts_644 sg.un.un_C00  rn.ny.sw_543 sn.sa.ny_432 
  0x3300390c, 0x5e004723, 0x55645913, 0x532a0d0c,   // br.nn.un_530 sn.ts.un_880  rn.lg.rw_665 cs.mt.ht_543 
  // [20590]
  0x396e1c0c, 0x597355a9, 0x0f252da4, 0x134b5aa0,   // id.hmn.br_543 rw.ny.rn_544  sk.eu.lv_433 sm.mi.et_322 
  0x3f2c080c, 0x040a10ad, 0x322d0d07, 0x0d25390c,   // no.fy.af_543 be.mk.ru_643  cs.sk.bs_432 br.eu.cs_543 
  0x21647312, 0x37001d05, 0x31641b05, 0x1b303804,   // ny.lg.jw_654 la.st.un_330  tr.lg.az_333 tk.uz.tr_332 
  0x5e475613, 0x094339a7, 0x34001508, 0x44253812,   // mg.sn.ts_665 br.ie.pl_532  un.xh.un_430 tk.mn.kk_654 
  // [205a0]
  0x4b55560c, 0x45287308, 0x475373a9, 0x3b5c27ad,   // mg.rw.mi_543 ny.sw.ln_443  ny.ht.sn_544 gd.sa.so_643 
  0x300f0da0, 0x172939af, 0x2a1827a0, 0x492e730d,   // cs.lv.uz_322 br.sl.sr_655  gd.ga.mt_322 ny.fo.to_554 
  0x79311b12, 0x21003f0d, 0x060cfc05, 0x02206212,   // tr.az.war_654 af.jw.un_540  zzp.sv.de_333 kha.sq.da_654 
  0x02005f19, 0x4b1501a4, 0x28165504, 0x02002e0b,   // tn.da.un_750 en.mi.un_430  rw.hr.sw_332 fo.da.un_520 
  // [205b0]
  0x2300190e, 0x0e004007, 0x131c5c5a, 0x04135c07,   // gl.ca.un_550 lb.is.un_420  sa.mr.bh_553 sa.et.fi_432 
  0x1e006402, 0x330810a6, 0x4f182704, 0x54045112,   // lg.ms.un_220 lt.no.nn_521  gd.ga.bi_332 kl.fi.ik_654 
  0x04545112, 0x16005407, 0x3b283d13, 0x440810ee,   // kl.ik.fi_654 ik.hr.un_420  ku.sd.ks_665 be.uk.kk_422 
  0x28003102, 0x320c020c, 0x173929a0, 0x02006e19,   // az.sw.un_220 da.sv.bs_543  sl.br.sr_322 hmn.da.un_750 
  // [205c0]
  0x6e002d1a, 0x0600520d, 0x2000fe21, 0x6e00120d,   // sk.hmn.un_760 ha.de.un_540  tlh.sq.un_860 hu.hmn.un_540 
  0x48301ba4, 0x63650202, 0x595552af, 0x1f00650d,   // tr.uz.tt_433 da.gv.sco_222  ha.rw.rn_655 gv.cy.un_540 
  0x6efe6111, 0x650f790c, 0x30123e5a, 0x023308ad,   // za.tlh.hmn_653 war.lv.gv_543  rm.hu.uz_553 no.nn.da_643 
  0x503431a9, 0x020c2912, 0x30fe38a0, 0x5a00600d,   // az.xh.fj_544 sl.sv.da_654  tk.tlh.uz_322 vo.sm.un_540 
  // [205d0]
  0x18796b5a, 0x096e2d11, 0x510f3009, 0x351379a4,   // ceb.war.ga_553 sk.hmn.pl_653  uz.lv.kl_444 war.et.zu_433 
  0x123d300e, 0x5e783411, 0x19240212, 0x58500a09,   // uz.ku.ur_555 xh.ve.ts_653  da.eo.gl_654 pt.fj.om_444 
  0x2e651f07, 0x1800fe09, 0x0f423e05, 0x1530350b,   // cy.gv.fo_432 tlh.ga.un_440  rm.co.lv_333 tg.uz.un_542 
  0x3148300b, 0x5c074207, 0x33001305, 0x35313ba0,   // uz.tt.az_542 co.it.sa_432  et.nn.un_330 so.az.zu_322 
  // [205e0]
  0x48102307, 0x67541e0c, 0x625058a9, 0x5100460e,   // ky.be.tt_432 ms.ik.ak_543  om.fj.kha_544 qu.kl.un_550 
  0x1c201e0b, 0x48003831, 0x35003919, 0xfe460711,   // ms.sq.id_542 tk.tt.un_A50  br.zu.un_750 it.qu.tlh_653 
  0x07423413, 0x08230413, 0x1b3445a9, 0x3534460c,   // xh.co.it_665 ru.ky.uk_665  ln.xh.tr_544 qu.xh.zu_543 
  0x080723ec, 0x353446af, 0x251245a6, 0x30004811,   // ky.bg.uk_644 qu.xh.zu_655  ln.hu.eu_521 tt.uz.un_630 
  // [205f0]
  0x5c006404, 0x353412a4, 0x04005c0d, 0x641304ee,   // lg.sa.un_320 hu.xh.zu_433  sa.fi.un_540 fi.et.lg_422 
  0x1d002619, 0x13670e07, 0x5c001902, 0x530e58ec,   // ia.la.un_750 is.ak.et_432  gl.sa.un_220 om.is.ht_644 
  0x17295607, 0x37041312, 0x42002a18, 0x55295607,   // mg.sl.sr_432 et.fi.st_654  mt.co.un_740 mg.sl.rw_432 
  0x2a005e20, 0x79256b08, 0x134742a6, 0x6b3e7907,   // ts.mt.un_850 ceb.eu.war_443  co.sn.et_521 war.rm.ceb_432 
  // [20600]
  0x49002a1b, 0x4900300c, 0x1e001002, 0x28002d09,   // mt.to.un_770 uz.to.un_530  lt.ms.un_220 sk.sw.un_440 
  0x2200271a, 0x555e59ee, 0x04354804, 0x49675a5a,   // gd.oc.un_760 rn.ts.rw_422  tt.tg.ru_332 sm.ak.to_553 
  0x370206ee, 0x280256ec, 0x3b275108, 0x420f0404,   // de.da.st_422 mg.da.sw_644  kl.gd.so_443 fi.lv.co_332 
  0x202f510d, 0x6202210c, 0x330e2e60, 0x061f0ea4,   // kl.su.sq_554 jw.da.kha_543  fo.is.nn_664 is.cy.de_433 
  // [20610]
  0x51005d05, 0x46456b5a, 0x213b30a4, 0x302a280c,   // ss.kl.un_330 ceb.ln.qu_553  uz.ks.fa_433 sw.mt.uz_543 
  0x0c1a2cec, 0x20005102, 0x60002a05, 0x13fc050c,   // fy.tl.sv_644 kl.sq.un_220  mt.vo.un_330 fr.zzp.et_543 
  0x02001a05, 0x021845ee, 0x033b3904, 0x20060ca0,   // tl.da.un_330 ln.ga.da_422  br.so.nl_332 sv.de.sq_322 
  0x653f0309, 0x2e0e06a9, 0x0c573308, 0x6b65790c,   // nl.af.gv_444 de.is.fo_544  nn.na.sv_443 war.gv.ceb_543 
  // [20620]
  0x02063507, 0x37007820, 0x61004d0e, 0x2418020c,   // zu.de.da_432 ve.st.un_850  aa.za.un_550 da.ga.eo_543 
  0x181a4208, 0x55007819, 0x20005108, 0x5d643702,   // co.tl.ga_443 ve.rw.un_750  kl.sq.un_430 st.lg.ss_222 
  0x5e2a5dec, 0x17230aa0, 0x37795507, 0x5a005608,   // ss.mt.ts_644 mk.ky.sr_322  rw.war.st_432 mg.sm.un_430 
  0x590655ec, 0x0678280d, 0x20001f19, 0x1d024e5a,   // rw.de.rn_644 sw.ve.de_554  cy.sq.un_750 ay.da.la_553 
  // [20630]
  0x4e001529, 0x00004e06, 0x350411a0, 0x1d003b12,   // un.ay.un_960 ay.un.un_400  ro.ru.tg_322 so.la.un_640 
  0x3b004c1a, 0x1a002807, 0x68023908, 0x45676809,   // wo.so.un_760 sw.tl.un_420  br.da.ig_443 ig.ak.ln_444 
  0x02285108, 0x1f1649a0, 0x0e2e48ee, 0x023b4ead,   // kl.sw.da_443 to.hr.cy_322  tt.fo.is_422 ay.so.da_643 
  0x2500642b, 0x49285aa0, 0x230810a6, 0x2a4c4e08,   // lg.eu.un_980 sm.sw.to_322  be.uk.ky_521 ay.wo.mt_443 
  // [20640]
  0x4c433ba9, 0x0a374808, 0x46283607, 0x4e2528a4,   // so.ie.wo_544 tt.ba.mk_443  gn.sw.qu_432 sw.eu.ay_433 
  0x5f12780d, 0x4b460207, 0x45354aad, 0x53005e12,   // ve.hu.tn_554 da.qu.mi_432  yo.zu.ln_643 ts.ht.un_640 
  0x30000b04, 0x59554a14, 0x21001f07, 0x64004014,   // es.uz.un_320 yo.rw.rn_666  cy.jw.un_420 lb.lg.un_660 
  0x052d0d02, 0x355d1ba0, 0x400c3804, 0x2f1c21a9,   // cs.sk.fr_222 tr.ss.zu_322  tk.sv.lb_332 jw.id.su_544 
  // [20650]
  0x2c0e3f05, 0x3f0e0214, 0xfc554704, 0x062a39a0,   // af.is.fy_333 da.is.af_666  sn.rw.zzp_332 br.mt.de_322 
  0x12536911, 0x18404cee, 0x303d2111, 0x32000b04,   // mfe.ht.hu_653 wo.lb.ga_422  fa.ku.uz_653 es.bs.un_320 
  0x3e02050c, 0x69004d19, 0x124423a4, 0x01003421,   // fr.da.rm_543 aa.mfe.un_750  ky.kk.ur_433 ps.iw.un_860 
  0x23373808, 0x1e000c02, 0x330efc0c, 0x24760408,   // tk.ba.ky_443 sv.ms.un_220  zzp.is.nn_543 fi.crs.eo_443 
  // [20660]
  0x21151007, 0x3d343012, 0x090203a0, 0x3ffc0f12,   // lt.jw.un_420 uz.ps.ku_654  nl.da.pl_322 lv.zzp.af_654 
  0x51004611, 0x2f3e4c04, 0x00006106, 0x0c2e3304,   // qu.kl.un_630 wo.rm.su_332  za.un.un_400 nn.fo.sv_332 
  0x15fc62ee, 0x27fc6208, 0x073736a0, 0x04fc1004,   // kha.zzp.un_422 kha.zzp.gd_443  ab.ba.bg_322 lt.zzp.fi_332 
  0x5776fc0c, 0x2c067904, 0x1b00510c, 0x3048350e,   // zzp.crs.na_543 war.de.fy_332  kl.tr.un_530 tg.tt.uz_555 
  // [20670]
  0x1c002204, 0x203703a4, 0x443c38a9, 0x033e2d04,   // oc.id.un_320 nl.st.sq_433  tk.ug.kk_544 sk.rm.nl_332 
  0x065e0407, 0x06792204, 0x0d3b0907, 0x4b003809,   // fi.ts.de_432 oc.war.de_332  hi.ks.ne_432 tk.mi.un_440 
  0x30343d0c, 0x52003113, 0x2f0931a0, 0x79546b0b,   // ku.ps.uz_543 az.ha.un_650  az.pl.su_322 ceb.ik.war_542 
  0x6500540e, 0x4a474ea4, 0x21005707, 0x5f3435ad,   // ik.gv.un_550 ay.sn.yo_433  na.jw.un_420 zu.xh.tn_643 
  // [20680]
  0x2d0d06ee, 0x6a494b09, 0x281a560d, 0x3756670c,   // de.cs.sk_422 mi.to.haw_444  mg.tl.sw_554 ak.mg.st_543 
  0x52005412, 0x5e28370c, 0x496b6aa9, 0x47522802,   // ik.ha.un_640 st.sw.ts_543  haw.ceb.to_544 sw.ha.sn_222 
  0x50520205, 0x733428a9, 0x2c004e12, 0x1a00020d,   // da.ha.fj_333 sw.xh.ny_544  ay.fy.un_640 da.tl.un_540 
  0x2100231a, 0x2c040b04, 0x53285c0d, 0x04173504,   // ky.fa.un_760 es.fi.fy_332  sa.sw.ht_554 tg.sr.ru_332 
  // [20690]
  0x5e004c07, 0x284b6aaf, 0x172523a0, 0x5b00fe19,   // wo.ts.un_420 haw.mi.sw_655  ky.mn.sr_322 tlh.sg.un_750 
  0x6b00fe1a, 0x1f5a490c, 0x480c1307, 0x0534fc08,   // tlh.ceb.un_760 to.sm.cy_543  et.sv.tt_432 zzp.xh.fr_443 
  0x0e002c0c, 0x6b1a54a4, 0x2820020c, 0x340cfc08,   // fy.is.un_530 ik.tl.ceb_433  da.sq.sw_543 zzp.sv.xh_443 
  0x793b6ba4, 0x02340c04, 0x032c53a0, 0x34020b05,   // ceb.so.war_433 sv.xh.da_332  ht.fy.nl_322 es.da.xh_333 
  // [206a0]
  0x0700430c, 0xfe00360e, 0x2e0efe0b, 0x1b002304,   // ie.it.un_530 gn.tlh.un_550  tlh.is.fo_542 ca.tr.un_320 
  0x5c4b4907, 0xfe1e1ca4, 0x2c060ea4, 0x1a30feec,   // to.mi.sa_432 id.ms.tlh_433  is.de.fy_433 tlh.uz.tl_644 
  0x301229ec, 0x0c004010, 0x5e2325a4, 0x131b0c0d,   // sl.hu.uz_644 lb.sv.un_620  eu.ca.ts_433 sv.tr.et_554 
  0x3f00630d, 0x08303705, 0x3c383014, 0xfc007519,   // sco.af.un_540 ba.uz.uk_333  uz.tk.ug_666 nso.zzp.un_750 
  // [206b0]
  0x735d09a4, 0x5800fc0b, 0x73290914, 0x222004a0,   // pl.ss.ny_433 zzp.om.un_520  pl.sl.ny_666 fi.sq.oc_322 
  0x5d4773ec, 0x54006213, 0x47247812, 0x381b1108,   // ny.sn.ss_644 kha.ik.un_650  ve.eo.sn_654 ro.tr.tk_443 
  0x35443ca7, 0x735d0911, 0x04005421, 0x360810a7,   // ug.kk.tg_532 pl.ss.ny_653  ik.fi.un_860 be.uk.ab_532 
  0x04203812, 0x044d24a6, 0x44481004, 0x08172307,   // tk.sq.fi_654 eo.aa.fi_521  be.tt.kk_332 ky.sr.uk_432 
  // [206c0]
  0x070a30a4, 0x1218300b, 0x5c003702, 0x034d63ec,   // uz.mk.bg_433 uz.ar.ur_542  st.sa.un_220 sco.aa.nl_644 
  0x232544ee, 0x1e002f08, 0x03004d0e, 0x0848150c,   // kk.mn.ky_422 su.ms.un_430  aa.nl.un_550 un.tt.uk_543 
  0x58034c07, 0x52583ba0, 0xfc00470e, 0x131263a0,   // wo.nl.om_432 so.om.ha_322  sn.zzp.un_550 sco.hu.et_322 
  0x79006b20, 0x08000a0e, 0x2c4c63ec, 0x53690212,   // ceb.war.un_850 mk.uk.un_550  sco.wo.fy_644 da.mfe.ht_654 
  // [206d0]
  0x64583ba7, 0x30004d2a, 0x056301ad, 0x5e5c6214,   // so.om.lg_532 aa.uz.un_970  en.sco.fr_643 kha.sa.ts_666 
  0x275c18a7, 0x09004704, 0x22130c02, 0x02275c08,   // ga.sa.gd_532 sn.pl.un_320  sv.et.oc_222 sa.gd.da_443 
  0x630103a4, 0x31001704, 0x49001e0c, 0x6a006b05,   // nl.en.sco_433 sr.az.un_320  ms.to.un_530 ceb.haw.un_330 
  0x0a4b6a0c, 0x1d0522a0, 0x01155302, 0x51006e07,   // haw.mi.pt_543 oc.fr.la_322  ht.en.un_220 hmn.kl.un_420 
  // [206e0]
  0x0f585311, 0x2d005604, 0x242f1ca0, 0x2f284b04,   // ht.om.lv_653 mg.sk.un_320  id.su.eo_322 mi.sw.su_332 
  0x1e2f4ba0, 0x644b6aee, 0x1f287308, 0x1f000802,   // mi.su.ms_322 haw.mi.lg_422  ny.sw.cy_443 no.cy.un_220 
  0x37645f0c, 0x1710040c, 0x043736ee, 0x083523ee,   // tn.lg.st_543 ru.be.sr_543  ab.ba.ru_422 ky.tg.uk_422 
  0xfc7328a6, 0x17081012, 0x3d23440d, 0x35003821,   // sw.ny.zzp_521 be.uk.sr_654  kk.ky.ku_554 tk.tg.un_860 
  // [206f0]
  0x0a3748af, 0x24382508, 0x76690d0c, 0xfe00262b,   // tt.ba.mk_655 eu.tk.eo_443  cs.mfe.crs_543 ia.tlh.un_980 
  0xfc00300b, 0x0f35340d, 0x02fe4f08, 0x69240da0,   // uz.zzp.un_520 xh.zu.lv_554  bi.tlh.da_443 cs.eo.mfe_322 
  0x6400fc07, 0x381b030c, 0xfe1b5705, 0x3407350c,   // zzp.lg.un_420 nl.tr.tk_543  na.tr.tlh_333 zu.it.xh_543 
  0x47762d07, 0x24303fa0, 0x26004335, 0x35343814,   // sk.crs.sn_432 af.uz.eo_322  ie.ia.un_A90 tk.xh.zu_666 
  // [20700]
  0x2907fe04, 0x64005614, 0x0640610c, 0x0e2f21ad,   // tlh.it.sl_332 mg.lg.un_660  za.lb.de_543 jw.su.is_643 
  0x2c3f0207, 0x270646ee, 0x12291307, 0x4b5c1ea4,   // da.af.fy_432 qu.de.gd_422  et.sl.hu_432 ms.sa.mi_433 
  0x200e2ea6, 0x2e020ea0, 0x1c5c1e0b, 0x132f5c0c,   // fo.is.sq_521 is.da.fo_322  ms.sa.id_542 sa.su.et_543 
  0x52394a5a, 0x561e3b05, 0x6b475c0b, 0x1d26560c,   // yo.br.ha_553 so.ms.mg_333  sa.sn.ceb_542 mg.ia.la_543 
  // [20710]
  0x381536a9, 0x33080c10, 0x1508480c, 0x081035af,   // ab.tk.un_540 sv.no.nn_642  tt.uk.un_543 tg.be.uk_655 
  0x2c381ba7, 0x2c00130b, 0x151517a0, 0x44183c08,   // tr.tk.fy_532 et.fy.un_520  sr.un.un_320 ug.ar.kk_443 
  0x03463f08, 0x4c1c1eee, 0x172d29a6, 0x064001af,   // af.qu.nl_443 ms.id.wo_422  sl.sk.sr_521 en.lb.de_655 
  0x33003004, 0x2d000105, 0x1b003b09, 0x1b003b07,   // uz.nn.un_320 en.sk.un_330  so.tr.un_440 so.tr.un_420 
  // [20720]
  0x3b1b52a4, 0x301b1202, 0x3f033307, 0x0c332e07,   // ha.tr.so_433 hu.tr.uz_222  nn.nl.af_432 fo.nn.sv_432 
  0x732730a7, 0x304258a9, 0x5c4613a0, 0x46000113,   // uz.gd.ny_532 om.co.uz_544  et.qu.sa_322 en.qu.un_650 
  0x06270205, 0x0c120404, 0x464e3011, 0x6e464ea0,   // da.gd.de_333 fi.hu.sv_332  uz.ay.qu_653 ay.qu.hmn_322 
  0xfc6530ee, 0x65630604, 0x4c581d07, 0x1b313ba7,   // uz.gv.zzp_422 de.sco.gv_332  la.om.wo_432 so.az.tr_532 
  // [20730]
  0x466e02a0, 0x53004c02, 0x5c4207a9, 0x3e3830ee,   // da.hmn.qu_322 wo.ht.un_220  it.co.sa_544 uz.tk.rm_422 
  0x091f460c, 0x4c007302, 0x403001a4, 0x4773fea0,   // qu.cy.pl_543 ny.wo.un_220  en.uz.lb_433 tlh.ny.sn_322 
  0x4c182f07, 0x301846a7, 0x65003407, 0x3200620c,   // su.ga.wo_432 qu.ga.uz_532  xh.gv.un_420 kha.bs.un_530 
  0x2d2a2e07, 0x1e3f0307, 0x03003e05, 0x27051da0,   // fo.mt.sk_432 nl.af.ms_432  rm.nl.un_330 la.fr.gd_322 
  // [20740]
  0x311b30a9, 0x20557307, 0x0451fe04, 0x463055ee,   // uz.tr.az_544 ny.rw.sq_432  tlh.kl.fi_332 rw.uz.qu_422 
  0xfe1338a4, 0x483025a7, 0xfe5c3804, 0x390327ee,   // tk.et.tlh_433 mn.uz.tt_532  tk.sa.tlh_332 gd.nl.br_422 
  0x1d000523, 0x11305608, 0x42450511, 0x0a001d21,   // fr.la.un_880 mg.uz.ro_443  fr.ln.co_653 la.pt.un_860 
  0x28005e0d, 0x1d003f1b, 0x35645507, 0x232538a7,   // ts.sw.un_540 af.la.un_770  rw.lg.zu_432 tk.mn.ky_532 
  // [20750]
  0x3f001104, 0x170730ee, 0x73645904, 0x09fe4ea9,   // ro.af.un_320 uz.bg.sr_422  rn.lg.ny_332 ay.tlh.pl_544 
  0x13295cee, 0x135c0f0c, 0x3000060b, 0x2530230c,   // sa.sl.et_422 lv.sa.et_543  de.uz.un_520 ky.uz.mn_543 
  0x32313008, 0x303644a0, 0x13fc58ee, 0x58494707,   // uz.az.bs_443 kk.ab.uz_322  om.zzp.et_422 sn.to.om_432 
  0x15697604, 0x23380aaf, 0x4c001e08, 0x4d40580c,   // crs.mfe.un_332 mk.tk.ky_655  ms.wo.un_430 om.lb.aa_543 
  // [20760]
  0x1b1c28a0, 0x0e203f07, 0x513b4c05, 0x676b1a08,   // sw.id.tr_322 af.sq.is_432  wo.so.kl_333 tl.ceb.ak_443 
  0x2a3308a0, 0x3b281a04, 0x29003305, 0x3b645811,   // no.nn.mt_322 tl.sw.so_332  nn.sl.un_330 om.lg.so_653 
  0x5e002f07, 0x330820a9, 0x0c3f2c02, 0x512854a9,   // su.ts.un_420 sq.no.nn_544  fy.af.sv_222 ik.sw.kl_544 
  0x053665a0, 0x06001a0b, 0x64001b08, 0x40000f19,   // gv.gn.fr_322 tl.de.un_520  tr.lg.un_430 lv.lb.un_750 
  // [20770]
  0x58005e02, 0x082a33a0, 0x582d0d04, 0x21110fa0,   // ts.om.un_220 nn.mt.no_322  cs.sk.om_332 lv.ro.jw_322 
  0x4423180d, 0x6458fc08, 0x04000911, 0xfa1d2808,   // ar.ky.kk_554 zzp.om.lg_443  pl.fi.un_630 sw.la.nr_443 
  0x674c51a4, 0x5733085a, 0x0a1d1555, 0x353401a9,   // kl.wo.ak_433 no.nn.na_553  un.la.pt_442 en.xh.zu_544 
  0x0c3921a0, 0x2e330ca9, 0x49544d07, 0x5c56375a,   // jw.br.sv_322 sv.nn.fo_544  aa.ik.to_432 st.mg.sa_553 
  // [20780]
  0x09007904, 0x791e1c55, 0x100d2d12, 0x1710350b,   // war.pl.un_320 id.ms.war_442  sk.cs.lt_654 tg.be.sr_542 
  0x693e7613, 0x1538040c, 0x2a00210d, 0x36170a08,   // crs.rm.mfe_665 ru.tk.un_543  jw.mt.un_540 mk.sr.ab_443 
  0x0200380d, 0x38483060, 0x38002f07, 0x286824ec,   // tk.da.un_540 uz.tt.tk_664  su.tk.un_420 eo.ig.sw_644 
  0x11006413, 0x642259a0, 0x1230340d, 0x4711590b,   // lg.ro.un_650 rn.oc.lg_322  ps.uz.ur_554 rn.ro.sn_542 
  // [20790]
  0x2a6b1aec, 0x2d113407, 0x19425da9, 0x21183d12,   // tl.ceb.mt_644 xh.ro.sk_432  ss.co.gl_544 ku.ar.fa_654 
  0x2810640c, 0x021047ad, 0x011d1555, 0x52002a07,   // lg.lt.sw_543 sn.lt.da_643  un.la.en_442 mt.ha.un_420 
  0x6b005308, 0x2536155a, 0x1c2b020c, 0x4c1b3108,   // ht.ceb.un_430 un.ab.mn_553  da.vi.id_543 az.tr.wo_443 
  0x1b423408, 0x36312aaf, 0x4c1642ee, 0x15361511,   // xh.co.tr_443 mt.az.gn_655  co.hr.wo_422 un.ab.un_653 
  // [207a0]
  0x42311b05, 0x333f0804, 0x4c42670c, 0x0f1b4c07,   // tr.az.co_333 no.af.nn_332  ak.co.wo_543 wo.tr.lv_432 
  0x36070809, 0x28341202, 0x311b4207, 0x1b4048ee,   // uk.bg.ab_444 ur.ps.sd_222  co.tr.az_432 tt.lb.tr_422 
  0x42311b0d, 0x31004c0d, 0x1b494c05, 0x56002105,   // tr.az.co_554 wo.az.un_540  wo.to.tr_333 jw.mg.un_330 
  0x0f421ba4, 0x5f7553a4, 0x42311ba4, 0x67001919,   // tr.co.lv_433 ht.nso.tn_433  tr.az.co_433 gl.ak.un_750 
  // [207b0]
  0x605021a4, 0x21006707, 0x30123bad, 0x2b004805,   // jw.fj.vo_433 ak.jw.un_420  ks.ur.uz_643 tt.vi.un_330 
  0x04154805, 0x2d1918a7, 0x171b5dad, 0x523038a0,   // tt.ru.un_330 ga.gl.sk_532  ss.tr.sr_643 tk.uz.ha_322 
  0x44480402, 0x562421ee, 0x45565a09, 0x12182813,   // ru.tt.kk_222 jw.eo.mg_422  sm.mg.ln_444 sd.ar.ur_665 
  0x5a005021, 0x110b2cee, 0x442834a0, 0x33081fa6,   // fj.sm.un_860 fy.es.ro_422  ps.sd.kk_322 cy.no.nn_521 
  // [207c0]
  0x05183304, 0x110c1fa7, 0x483c300e, 0x2e00fc05,   // nn.ga.fr_332 cy.sv.ro_532  uz.ug.tt_555 zzp.fo.un_330 
  0x271819a9, 0x29005d05, 0x10482304, 0x3b001209,   // gl.ga.gd_544 ss.sl.un_330  ky.tt.be_332 hu.so.un_440 
  0x38042155, 0x13290407, 0x38212905, 0x423e07af,   // jw.fi.tk_442 fi.sl.et_432  sl.jw.tk_333 it.rm.co_655 
  0x55002707, 0x10350409, 0x1b0b24ee, 0x17103c0e,   // gd.rw.un_420 ru.tg.be_444  eo.es.tr_422 ug.be.sr_555 
  // [207d0]
  0x183b3d12, 0x3e004712, 0x0c392aa0, 0x38000902,   // ku.ks.ar_654 sn.rm.un_640  mt.br.sv_322 pl.tk.un_220 
  0x35233ca4, 0x381e51a0, 0x1e000404, 0x06124308,   // ug.ky.tg_433 kl.ms.tk_322  fi.ms.un_320 ie.hu.de_443 
  0x08130c07, 0x13001102, 0x2d3829a7, 0x2a002009,   // sv.et.no_432 ro.et.un_220  sl.tk.sk_532 sq.mt.un_440 
  0x27002218, 0x44040805, 0x230425a0, 0x222311af,   // oc.gd.un_740 uk.ru.kk_333  mn.ru.ky_322 ro.ca.oc_655 
  // [207e0]
  0x5c5a790c, 0x5a1e1c5a, 0x302315ad, 0x170807a0,   // war.sm.sa_543 id.ms.sm_553  un.ky.uz_643 bg.uk.sr_322 
  0x434b0607, 0x4b020407, 0x375f195a, 0x1a005c02,   // de.mi.ie_432 fi.da.mi_432  gl.tn.st_553 sa.tl.un_220 
  0x04190a13, 0x015a1804, 0x152718af, 0x5f697804,   // pt.gl.fi_665 ga.sm.en_332  ga.gd.un_655 ve.mfe.tn_332 
  0x115a5602, 0x12004e12, 0x1100480c, 0x4700020d,   // mg.sm.ro_222 ay.hu.un_640  tt.ro.un_530 da.sn.un_540 
  // [207f0]
  0x37043807, 0x651efe0c, 0xfe00040c, 0x0f254ba0,   // tk.ru.ba_432 tlh.ms.gv_543  fi.tlh.un_530 mi.eu.lv_322 
  0x182704ad, 0x4b057955, 0x6b5a79a0, 0x390c2807,   // fi.gd.ga_643 war.fr.mi_442  war.sm.ceb_322 sw.sv.br_432 
  0x05000422, 0x48521b08, 0x0c00241b, 0x494b13a4,   // fi.fr.un_870 tr.ha.tt_443  eo.sv.un_770 et.mi.to_433 
  0x3b305307, 0x3d3b2113, 0x284d580b, 0x3b385812,   // ht.uz.so_432 fa.ks.ku_665  om.aa.sw_542 om.tk.so_654 
  
  // [20800]
  0xfc005e0d, 0x0400fe13, 0x3500550e, 0x21183c04,   // ts.zzp.un_540 tlh.fi.un_650  rw.zu.un_550 ug.ar.fa_332 
  0x0e003907, 0x13484fac, 0x21561e07, 0x3b4831ad,   // br.is.un_420 bi.tt.et_632  ms.mg.jw_432 az.tt.so_643 
  0x0f13040d, 0x343012ad, 0x5c000405, 0x233430af,   // fi.et.lv_554 ur.uz.ps_643  fi.sa.un_330 uz.ps.ky_655 
  0x2718430c, 0x4a393602, 0x12004009, 0x3f391f07,   // ie.ga.gd_543 gn.br.yo_222  lb.hu.un_440 cy.br.af_432 
  // [20810]
  0x252f1309, 0x394f4008, 0x1d003922, 0x1d004a13,   // et.su.eu_444 lb.bi.br_443  br.la.un_870 yo.la.un_650 
  0x08303504, 0x0c120ea7, 0x212f4c04, 0x4f131dad,   // tg.uz.uk_332 is.hu.sv_532  wo.su.jw_332 la.et.bi_643 
  0x06300e0c, 0x181f4f0c, 0x55003508, 0x5c1e1c02,   // is.uz.de_543 bi.cy.ga_543  zu.rw.un_430 id.ms.sa_222 
  0x421823ee, 0x64287309, 0x21321604, 0x23361507,   // ca.ga.co_422 ny.sw.lg_444  hr.bs.jw_332 un.ab.ky_432 
  // [20820]
  0x04002802, 0x6959730c, 0x0d004002, 0x05000309,   // sw.fi.un_220 ny.rn.mfe_543  lb.cs.un_220 nl.fr.un_440 
  0x1b00fc0b, 0x11002404, 0xfe00130d, 0x25351507,   // zzp.tr.un_520 eo.ro.un_320  et.tlh.un_540 un.tg.mn_432 
  0x28641502, 0x47005514, 0x04232802, 0x120c0e0c,   // un.lg.sw_222 rw.sn.un_660  sw.ca.fi_222 is.sv.hu_543 
  0x2b006809, 0x0600450c, 0x230e0c12, 0x39003f0c,   // ig.vi.un_440 ln.de.un_530  sv.is.ca_654 af.br.un_530 
  // [20830]
  0x5b5628ec, 0x0343010c, 0x65633ea9, 0x2900650d,   // sw.mg.sg_644 en.ie.nl_543  rm.sco.gv_544 gv.sl.un_540 
  0x39004c13, 0x1851670c, 0x4c000305, 0x03384cad,   // wo.br.un_650 ak.kl.ga_543  nl.wo.un_330 wo.tk.nl_643 
  0x0f002e07, 0x22640404, 0x3f240304, 0x2f004c0d,   // fo.lv.un_420 fi.lg.oc_332  nl.eo.af_332 wo.su.un_540 
  0x12393f04, 0x071704ee, 0x2b2e0805, 0x32170fa4,   // af.br.hu_332 ru.sr.bg_422  no.fo.vi_333 lv.sr.bs_433 
  // [20840]
  0x34fc5109, 0x545612a9, 0x4d4c1209, 0x12045455,   // kl.zzp.xh_444 hu.mg.ik_544  hu.wo.aa_444 ik.fi.hu_442 
  0x170a3605, 0x0d001a02, 0xfc006712, 0x5c00fe19,   // gn.pt.sr_333 tl.cs.un_220  ak.zzp.un_640 tlh.sa.un_750 
  0x0e3306a0, 0x01370da0, 0x11041005, 0x1336040c,   // de.nn.is_322 cs.st.en_322  be.ru.ro_333 fi.gn.et_543 
  0x425c565a, 0x071517ec, 0x39220504, 0x30441512,   // mg.sa.co_553 sr.bg.un_640  fr.oc.br_332 un.kk.uz_654 
  // [20850]
  0x470f040c, 0x2900fe09, 0x420623a0, 0x0d0e2d0c,   // fi.lv.sn_543 tlh.sl.un_440  ca.de.co_322 sk.is.cs_543 
  0x04001904, 0x334f0c0c, 0x555efead, 0x044423a7,   // gl.fi.un_320 sv.bi.nn_543  tlh.ts.rw_643 ky.kk.ru_532 
  0x693e5e0c, 0x5600541b, 0x0c00fc11, 0xfe5d5e07,   // ts.rm.mfe_543 ik.mg.un_770  zzp.sv.un_630 ts.ss.tlh_432 
  0x6b2a0a55, 0x0d005f05, 0x21004205, 0x06002f14,   // pt.mt.ceb_442 tn.cs.un_330  co.jw.un_330 su.de.un_660 
  // [20860]
  0x233738ee, 0x2f003919, 0x12180202, 0x20062f10,   // tk.ba.ky_422 br.su.un_750  da.ga.hu_222 su.de.sq_642 
  0x0e2e0208, 0x3c23355a, 0x37003c18, 0x2a000e02,   // da.fo.is_443 tg.ky.ug_553  ug.ba.un_740 is.mt.un_220 
  0x122823a0, 0x035d730c, 0x09000307, 0x200c4808,   // ky.sd.ur_322 ny.ss.nl_543  nl.pl.un_420 tt.sv.sq_443 
  0x223f2c0c, 0x213064a0, 0x1e0903ee, 0x20002205,   // fy.af.oc_543 lg.uz.jw_322  nl.pl.ms_422 oc.sq.un_330 
  // [20870]
  0x0a00350b, 0x5559785a, 0x404c0508, 0x50005a02,   // tg.mk.un_520 ve.rn.rw_553  fr.wo.lb_443 sm.fj.un_220 
  0x5e002108, 0x052d0d0d, 0x332c0814, 0x37231504,   // jw.ts.un_430 cs.sk.fr_554  no.fy.nn_666 un.ky.ba_332 
  0x4f0c1309, 0x65000e05, 0x01637904, 0x05400d04,   // et.sv.bi_444 is.gv.un_330  war.sco.en_332 cs.lb.fr_332 
  0x02fc4a08, 0x2c00050d, 0x255c630c, 0x42073e07,   // yo.zzp.da_443 fr.fy.un_540  sco.sa.eu_543 rm.it.co_432 
  // [20880]
  0x1d044a0b, 0x0e293e02, 0x2f1cfe04, 0x05004009,   // yo.fi.la_542 rm.sl.is_222  tlh.id.su_332 lb.fr.un_440 
  0x2f005b08, 0x16fe2f07, 0x23342104, 0x50002b07,   // sg.su.un_430 su.tlh.hr_432  fa.ps.ky_332 vi.fj.un_420 
  0x09005907, 0x6a4712ad, 0x393e2c05, 0x38002d04,   // rn.pl.un_420 hu.sn.haw_643  fy.rm.br_333 sk.tk.un_320 
  0x3f4a3b07, 0x46003605, 0x1e2f1cec, 0x05005207,   // so.yo.af_432 gn.qu.un_330  id.su.ms_644 ha.fr.un_420 
  // [20890]
  0x071548a4, 0x39210507, 0x2e3f0e12, 0x3710040c,   // tt.bg.un_430 fr.jw.br_432  is.af.fo_654 ru.be.ba_543 
  0x433601a4, 0x123f650c, 0x2c000a05, 0x2e0efc55,   // en.gn.ie_433 gv.af.hu_543  pt.fy.un_330 zzp.is.fo_442 
  0x0a1d0107, 0x3e004314, 0x78375f0c, 0x11002807,   // en.la.pt_432 ie.rm.un_660  tn.st.ve_543 sw.ro.un_420 
  0x645c13a0, 0x04000f07, 0x65001908, 0x3534fc05,   // et.sa.lg_322 lv.fi.un_420  gl.gv.un_430 zzp.xh.zu_333 
  // [208a0]
  0x375e6ea9, 0x78353405, 0x3100fc07, 0x095c24a0,   // hmn.ts.st_544 xh.zu.ve_333  zzp.az.un_420 eo.sa.pl_322 
  0x2e0e38a4, 0x242d0d08, 0x525673a9, 0x38121b08,   // tk.is.fo_433 cs.sk.eo_443  ny.mg.ha_544 tr.hu.tk_443 
  0x4a356905, 0x1b0d12ec, 0x6b751ca0, 0x120a43a0,   // mfe.zu.yo_333 hu.cs.tr_644  id.nso.ceb_322 ie.pt.hu_322 
  0x4a53fe0c, 0x3900240d, 0x12002e0d, 0x362d12ac,   // tlh.ht.yo_543 eo.br.un_540  fo.hu.un_540 hu.sk.gn_632 
  // [208b0]
  0x190b6014, 0x04524f0c, 0x29311b07, 0x2a290f08,   // vo.es.gl_666 bi.ha.fi_543  tr.az.sl_432 lv.sl.mt_443 
  0x1bfe13a7, 0x65021aad, 0x0c353402, 0x4c002d04,   // et.tlh.tr_532 tl.da.gv_643  xh.zu.sv_222 sk.wo.un_320 
  0x64004218, 0x4c1a650c, 0x040802eb, 0x01653ea0,   // co.lg.un_740 gv.tl.wo_543  da.no.fi_662 rm.gv.en_322 
  0x301515ec, 0x05073ea4, 0x48016504, 0x134d01a0,   // un.uz.un_640 rm.it.fr_433  gv.en.tt_332 en.aa.et_322 
  // [208c0]
  0x231544af, 0x132f5307, 0x13204908, 0x64000f19,   // kk.ky.un_650 ht.su.et_432  to.sq.et_443 lv.lg.un_750 
  0x376a5611, 0x2f7321ad, 0x37124004, 0x2f356b04,   // mg.haw.st_653 jw.ny.su_643  lb.hu.st_332 ceb.zu.su_332 
  0x1d330804, 0x2d0d5eaf, 0x0900620c, 0x340973a4,   // no.nn.la_332 ts.cs.sk_655  kha.pl.un_530 ny.pl.xh_433 
  0x5d2756ee, 0x09002f0c, 0x34731f0d, 0x27040ca7,   // mg.gd.ss_422 su.pl.un_530  cy.ny.xh_554 sv.fi.gd_532 
  // [208d0]
  0x215873a4, 0x25303c08, 0x53645d07, 0x30233ca4,   // ny.om.jw_433 ug.uz.mn_443  ss.lg.ht_432 ug.ky.uz_433 
  0xfc4628a0, 0x36301207, 0x36006a0e, 0x09735da4,   // sw.qu.zzp_322 hu.uz.gn_432  haw.gn.un_550 ss.ny.pl_433 
  0x2f564b04, 0x0e060c04, 0x64730207, 0x526b090c,   // mi.mg.su_332 sv.de.is_332  da.ny.lg_432 pl.ceb.ha_543 
  0x06180c07, 0x4a095307, 0x536b67ee, 0x18750107,   // sv.ga.de_432 ht.pl.yo_432  ak.ceb.ht_422 en.nso.ga_432 
  // [208e0]
  0x550a4aa0, 0x4f381fee, 0x16000e08, 0xfc001819,   // yo.pt.rw_322 cy.tk.bi_422  is.hr.un_430 ga.zzp.un_750 
  0x24114608, 0x46000205, 0x53761ca9, 0x330e2e55,   // qu.ro.eo_443 da.qu.un_330  id.crs.ht_544 fo.is.nn_442 
  0x11002905, 0x290f1f0c, 0x45597312, 0x602947a4,   // sl.ro.un_330 cy.lv.sl_543  ny.rn.ln_654 sn.sl.vo_433 
  0x161f5ca4, 0x100428ee, 0x36025c0c, 0x3f63060c,   // sa.cy.hr_433 sw.fi.lt_422  sa.da.gn_543 de.sco.af_543 
  // [208f0]
  0x102409ee, 0x21731ca4, 0x4200fc0d, 0x3200600c,   // pl.eo.lt_422 id.ny.jw_433  zzp.co.un_540 vo.bs.un_530 
  0x5e5c55ad, 0x7300671b, 0x5c0264af, 0x17001f0c,   // rw.sa.ts_643 ak.ny.un_770  lg.da.sa_655 cy.sr.un_530 
  0x281224a0, 0x5c7321a4, 0x24000909, 0x2813240c,   // eo.hu.sw_322 jw.ny.sa_433  pl.eo.un_440 eo.et.sw_543 
  0x1d004e19, 0x79211c08, 0x2f006404, 0x132409a6,   // ay.la.un_750 id.jw.war_443  lg.su.un_320 pl.eo.et_521 
  // [20900]
  0x55365e04, 0x28305c07, 0x792d0d09, 0x171610ee,   // ts.gn.rw_332 sa.uz.sw_432  cs.sk.war_444 lt.hr.sr_422 
  0x35730907, 0x28002408, 0x17100a07, 0x4f600208,   // pl.ny.zu_432 eo.sw.un_430  mk.be.sr_432 da.vo.bi_443 
  0x2d240d07, 0x54005c1a, 0x21465cad, 0x200424a0,   // cs.eo.sk_432 sa.ik.un_760  sa.qu.jw_643 eo.fi.sq_322 
  0x025c590c, 0x24001004, 0x5c1e460e, 0x301523af,   // rn.sa.da_543 lt.eo.un_320  qu.ms.sa_555 ky.uz.un_650 
  // [20910]
  0x1f001e22, 0x284e530c, 0x21052f09, 0x02134b0d,   // ms.cy.un_870 ht.ay.sw_543  su.fr.jw_444 mi.et.da_554 
  0x623625af, 0x785f180d, 0x625a04a9, 0x2f21190c,   // eu.gn.kha_655 ga.tn.ve_554  fi.sm.kha_544 gl.jw.su_543 
  0x6202630c, 0x5f6325a9, 0x12213b0d, 0x275c1812,   // sco.da.kha_543 eu.sco.tn_544  ks.fa.ur_554 ga.sa.gd_654 
  0x1f63250c, 0x635a01a4, 0x0f63250c, 0x4002250c,   // eu.sco.cy_543 en.sm.sco_433  eu.sco.lv_543 eu.da.lb_543 
  // [20920]
  0x06080205, 0x2b273e04, 0x30042a0c, 0x04073605,   // da.no.de_333 rm.gd.vi_332  mt.fi.uz_543 ab.bg.ru_333 
  0x453b040c, 0x6204feaf, 0x3d342807, 0x57634fec,   // fi.so.ln_543 tlh.fi.kha_655  sd.ps.ku_432 bi.sco.na_644 
  0x02000f09, 0xfe7801a0, 0x3604650c, 0x47005a22,   // lv.da.un_440 en.ve.tlh_322  gv.fi.gn_543 sm.sn.un_870 
  0x3055fe04, 0xfe633bad, 0x4b1f01a4, 0x4b185aa9,   // tlh.rw.uz_332 so.sco.tlh_643  en.cy.mi_433 sm.ga.mi_544 
  // [20930]
  0x5a1827a9, 0x3b3256a0, 0x52782012, 0x20595560,   // gd.ga.sm_544 mg.bs.so_322  sq.ve.ha_654 rw.rn.sq_664 
  0x523043a9, 0x0704080d, 0x121b2e04, 0x30fe61ee,   // ie.uz.ha_544 uk.ru.bg_554  fo.tr.hu_332 za.tlh.uz_422 
  0x4620010c, 0x2a043055, 0x5500730e, 0x463b30ac,   // en.sq.qu_543 uz.fi.mt_442  ny.rw.un_550 uz.so.qu_632 
  0x65002009, 0x23221d02, 0x526530ec, 0x3b0458ee,   // sq.gv.un_440 la.oc.ca_222  uz.gv.ha_644 om.fi.so_422 
  // [20940]
  0xfc00120c, 0x21344705, 0x4d00730c, 0x224f23af,   // hu.zzp.un_530 sn.xh.jw_333  ny.aa.un_530 ca.bi.oc_655 
  0x1e191fa0, 0x0f000508, 0x4c000520, 0x5c1309a9,   // cy.gl.ms_322 fr.lv.un_430  fr.wo.un_850 hi.bh.sa_544 
  0x7300550e, 0x08101712, 0x0e311ba6, 0x32001a07,   // rw.ny.un_550 sr.be.uk_654  tr.az.is_521 tl.bs.un_420 
  0x51650602, 0x13652707, 0x1b4d2004, 0x3b016504,   // de.gv.kl_222 gd.gv.et_432  sq.aa.tr_332 gv.en.so_332 
  // [20950]
  0x3046310e, 0x3d34215a, 0x2e002c0b, 0x01001a02,   // az.qu.uz_555 fa.ps.ku_553  fy.fo.un_520 tl.en.un_220 
  0x4d2a120c, 0x2c006013, 0x1535230c, 0x28523fee,   // hu.mt.aa_543 vo.fy.un_650  ky.tg.un_543 af.ha.sw_422 
  0x29001613, 0x0a080709, 0x2d050a55, 0x3035440d,   // hr.sl.un_650 bg.uk.mk_444  pt.fr.sk_442 kk.tg.uz_554 
  0x4a351308, 0x33002407, 0x21005004, 0x5e4a6905,   // et.zu.yo_443 eo.nn.un_420  fj.jw.un_320 mfe.yo.ts_333 
  // [20960]
  0x231748ee, 0x170723a4, 0x2d31290c, 0x4425480c,   // tt.sr.ky_422 ky.bg.sr_433  sl.az.sk_543 tt.mn.kk_543 
  0x171601a0, 0x37254408, 0x301c1eee, 0x233f01a0,   // en.hr.sr_322 kk.mn.ba_443  ms.id.uz_422 en.af.ca_322 
  0x22230107, 0x37012307, 0x044436a0, 0x221d0507,   // en.ca.oc_432 ca.en.st_432  ab.kk.ru_322 fr.la.oc_432 
  0x762a69af, 0x170a0855, 0x04080a55, 0x230163a7,   // mfe.mt.crs_655 uk.mk.sr_442  mk.uk.ru_442 sco.en.ca_532 
  // [20970]
  0x051d2205, 0x42053607, 0x09001112, 0x49284ba4,   // oc.la.fr_333 gn.fr.co_432  ro.pl.un_640 mi.sw.to_433 
  0x012b0fee, 0x23000102, 0x697623a4, 0x0f22010c,   // lv.vi.en_422 en.ca.un_220  ca.crs.mfe_433 en.oc.lv_543 
  0x33082709, 0x2f3905a0, 0x6e554eec, 0x272e6704,   // gd.no.nn_444 fr.br.su_322  ay.rw.hmn_644 ak.fo.gd_332 
  0x0a171005, 0x08736107, 0x0e02270c, 0x0efc3455,   // be.sr.mk_333 za.ny.no_432  gd.da.is_543 xh.zzp.is_442 
  // [20980]
  0x5b00611b, 0x3407130c, 0x61fc3313, 0x58286b07,   // za.sg.un_770 et.it.xh_543  nn.zzp.za_665 ceb.sw.om_432 
  0x20005c0d, 0x27330807, 0x5d345ca4, 0x213c3408,   // sa.sq.un_540 no.nn.gd_432  sa.xh.ss_433 ps.ug.fa_443 
  0x650e38a9, 0x34283d07, 0x3e6b63a4, 0x48394c07,   // tk.is.gv_544 ku.sd.ps_432  sco.ceb.rm_433 wo.br.tt_432 
  0x2a125c0b, 0x1c121ea0, 0x18495a0c, 0x5a632c07,   // sa.hu.mt_542 ms.hu.id_322  sm.to.ga_543 fy.sco.sm_432 
  // [20990]
  0x113347a0, 0x34004708, 0x0d3009ee, 0x475776a4,   // sn.nn.ro_322 sn.xh.un_430  pl.uz.cs_422 crs.na.sn_433 
  0x756960a4, 0x47496502, 0x3400470c, 0x11001207,   // vo.mfe.nso_433 gv.to.sn_222  sn.xh.un_530 hu.ro.un_420 
  0x0417440c, 0x0e06035a, 0x080a170b, 0x0c00602b,   // kk.sr.ru_543 nl.de.is_553  sr.mk.uk_542 vo.sv.un_980 
  0x2c032e02, 0x79365e04, 0x16000108, 0x2105225a,   // fo.nl.fy_222 ts.gn.war_332  en.hr.un_430 oc.fr.jw_553 
  // [209a0]
  0x150a1713, 0x2d0929a0, 0x01792b08, 0x37006502,   // sr.mk.un_665 sl.pl.sk_322  vi.war.en_443 gv.st.un_220 
  0x13255da9, 0x04371307, 0x03126e07, 0x12180555,   // ss.eu.et_544 et.st.fi_432  hmn.hu.nl_432 fr.ga.hu_442 
  0x0c020811, 0x495f4a08, 0x37035fa4, 0x352834a9,   // no.da.sv_653 yo.tn.to_443  tn.nl.st_433 xh.sw.zu_544 
  0x343b21a4, 0x234837ee, 0x19007913, 0x154006a7,   // fa.ks.ps_433 ba.tt.ky_422  war.gl.un_650 de.lb.un_532 
  // [209b0]
  0x03330ca9, 0x5002220c, 0x02285707, 0x1c651ead,   // sv.nn.nl_544 oc.da.fj_543  na.sw.da_432 ms.gv.id_643 
  0x12022dee, 0x2f215dee, 0x07601ea0, 0x25102807,   // sk.da.hu_422 ss.jw.su_422  ms.vo.it_322 sw.lt.eu_432 
  0x234804a0, 0x3e2230a4, 0x5afc1305, 0x68073e07,   // ru.tt.ky_322 uz.oc.rm_433  et.zzp.sm_333 rm.it.ig_432 
  0x2c000702, 0x46001602, 0x3e006b12, 0x57305809,   // it.fy.un_220 hr.qu.un_220  ceb.rm.un_640 om.uz.na_444 
  // [209c0]
  0x212f2a04, 0x1c19300c, 0x07421c07, 0x5f6e0a04,   // mt.su.jw_332 uz.gl.id_543  id.co.it_432 pt.hmn.tn_332 
  0x091304a0, 0x3600280c, 0x122429a0, 0x292d0f0c,   // fi.et.pl_322 sw.gn.un_530  sl.eo.hu_322 lv.sk.sl_543 
  0x13005d05, 0x0e060cee, 0x07080409, 0x222d3607,   // ss.et.un_330 sv.de.is_422  ru.uk.bg_444 gn.sk.oc_432 
  0x44173502, 0x0efc13a7, 0x2a001305, 0x5c2e0e14,   // tg.sr.kk_222 et.zzp.is_532  et.mt.un_330 is.fo.sa_666 
  // [209d0]
  0x4c002512, 0x33041304, 0x0e332ea0, 0x132e0e04,   // eu.wo.un_640 et.fi.nn_332  fo.nn.is_322 is.fo.et_332 
  0x681d150b, 0x3100610e, 0x353644ec, 0x1c651ea0,   // un.la.ig_542 za.az.un_550  kk.ab.tg_644 ms.gv.id_322 
  0x1b383eaf, 0x654c1214, 0x376a4b0d, 0x585e3608,   // rm.tk.tr_655 hu.wo.gv_666  mi.haw.st_554 gn.ts.om_443 
  0x1200390d, 0x2e00540c, 0x2f00372b, 0x32160d14,   // br.hu.un_540 ik.fo.un_530  st.su.un_980 cs.hr.bs_666 
  // [209e0]
  0x2a001304, 0x370d48ee, 0x04132ea4, 0x584d38a4,   // et.mt.un_320 tt.cs.st_422  fo.et.fi_433 tk.aa.om_433 
  0x31001b2c, 0x2e3354a4, 0x29160ca6, 0x13045ca4,   // tr.az.un_990 ik.nn.fo_433  sv.hr.sl_521 sa.fi.et_433 
  0x302e5ca4, 0x49005620, 0x55003b05, 0x3848300b,   // sa.fo.uz_433 mg.to.un_850  so.rw.un_330 uz.tt.tk_542 
  0x13005634, 0x215c2f13, 0x4c002a0d, 0x135649a7,   // mg.et.un_A80 su.sa.jw_665  mt.wo.un_540 to.mg.et_532 
  // [209f0]
  0x12393104, 0x784b6a60, 0x364b4912, 0x1e544fa7,   // az.br.hu_332 haw.mi.ve_664  to.mi.gn_654 bi.ik.ms_532 
  0x05227907, 0x09004f21, 0x761108a4, 0x10004004,   // war.oc.fr_432 bi.pl.un_860  no.ro.crs_433 lb.lt.un_320 
  0xfc002c13, 0x6b605712, 0x22000514, 0x58033f0c,   // fy.zzp.un_650 na.vo.ceb_654  fr.oc.un_660 af.nl.om_543 
  0x33107904, 0x451a2d0c, 0x2e5102a9, 0x40064faf,   // war.lt.nn_332 sk.tl.ln_543  da.kl.fo_544 bi.de.lb_655 
  // [20a00]
  0x05113ea0, 0x52202ca4, 0x1b525914, 0x79060ea4,   // rm.ro.fr_322 fy.sq.ha_433  rn.ha.tr_666 is.de.war_433 
  0x73690da0, 0x21220555, 0x5308330b, 0x283444ee,   // cs.mfe.ny_322 fr.oc.jw_442  nn.no.ht_542 kk.ps.sd_422 
  0x1b313055, 0x73004719, 0x0c213702, 0x172510a9,   // uz.az.tr_442 sn.ny.un_750  st.jw.sv_222 be.mn.sr_544 
  0x5c04135a, 0x48313007, 0x0e000311, 0x51005608,   // et.fi.sa_553 uz.az.tt_432  nl.is.un_630 mg.kl.un_430 
  // [20a10]
  0x0f004708, 0x182128ec, 0x155c4202, 0x03105c07,   // sn.lv.un_430 sd.fa.ar_644  co.sa.un_222 sa.lt.nl_432 
  0x03381b0b, 0x11135e11, 0x48135c0c, 0x785d130c,   // tr.tk.nl_542 ts.et.ro_653  sa.et.tt_543 et.ss.ve_543 
  0x0c332e04, 0x0a001319, 0x33003408, 0x3833080b,   // fo.nn.sv_332 et.pt.un_750  xh.nn.un_430 no.nn.tk_542 
  0x30fe270e, 0x420c1304, 0x18421dee, 0x3e2f05a7,   // gd.tlh.uz_555 et.sv.co_332  la.co.ga_422 fr.su.rm_532 
  // [20a20]
  0x0e041ea0, 0x054301a0, 0x302a1ea9, 0x2c2f1207,   // ms.fi.is_322 en.ie.fr_322  ms.mt.uz_544 hu.su.fy_432 
  0x242302a9, 0xfc4201ee, 0x47005e02, 0x6948fe08,   // da.ca.eo_544 en.co.zzp_422  ts.sn.un_220 tlh.tt.mfe_443 
  0x1253fea4, 0x0911060c, 0x13005d09, 0x15005d08,   // tlh.ht.hu_433 de.ro.pl_543  ss.et.un_440 ss.un.un_430 
  0x0c3f035a, 0x02136809, 0x19004c0d, 0x511334a9,   // nl.af.sv_553 ig.et.da_444  wo.gl.un_540 xh.et.kl_544 
  // [20a30]
  0x110f0404, 0x5100181a, 0x27301f04, 0x650f13a0,   // fi.lv.ro_332 ga.kl.un_760  cy.uz.gd_332 et.lv.gv_322 
  0x3b565aac, 0x13365a08, 0x475a36a6, 0x06037909,   // sm.mg.so_632 sm.gn.et_443  gn.sm.sn_521 war.nl.de_444 
  0x55641307, 0x02006a08, 0x10002208, 0x637901a0,   // et.lg.rw_432 haw.da.un_430  oc.lt.un_430 en.war.sco_322 
  0x10003e09, 0x22000519, 0x33080c12, 0x30123d04,   // rm.lt.un_440 fr.oc.un_750  sv.no.nn_654 ku.ur.uz_332 
  // [20a40]
  0x1b00150c, 0x44231807, 0x5d1d4360, 0x0711300b,   // un.tr.un_530 ar.ky.kk_432  ie.la.ss_664 uz.ro.bg_542 
  0x4226430c, 0x5d470a08, 0x22182304, 0x250407a4,   // ie.ia.co_543 pt.sn.ss_443  ca.ga.oc_332 bg.ru.mn_433 
  0x36555911, 0x2b00610d, 0x52003b07, 0x281827a4,   // rn.rw.gn_653 za.vi.un_540  so.ha.un_420 gd.ga.sw_433 
  0x51033f04, 0xfe28650c, 0x0f00471a, 0xfe002734,   // af.nl.kl_332 gv.sw.tlh_543  sn.lv.un_760 gd.tlh.un_A80 
  // [20a50]
  0x5100130e, 0x65fe68ee, 0x2100fc04, 0x021ffcec,   // et.kl.un_550 ig.tlh.gv_422  zzp.jw.un_320 zzp.cy.da_644 
  0x5200650d, 0x01657507, 0x3f051355, 0x330e2007,   // gv.ha.un_540 nso.gv.en_432  et.fr.af_442 sq.is.nn_432 
  0x041329ee, 0x0c3f0313, 0x100437ee, 0x17110a0e,   // sl.et.fi_422 nl.af.sv_665  ba.ru.be_422 mk.ro.sr_555 
  0x23123405, 0x17110a5a, 0x2b004a19, 0x181b2004,   // ps.ur.ky_333 mk.ro.sr_553  yo.vi.un_750 sq.tr.ga_332 
  // [20a60]
  0x480a3c04, 0x201f23a7, 0x0f102a0e, 0x233421ec,   // ug.mk.tt_332 ca.cy.sq_532  mt.lt.lv_555 fa.ps.ky_644 
  0x792d1607, 0x3900180e, 0x113530ec, 0x64345da4,   // hr.sk.war_432 ga.br.un_550  uz.tg.ro_644 ss.xh.lg_433 
  0x59025d05, 0x44213dec, 0x47735f04, 0x591a64a9,   // ss.da.rn_333 ku.fa.kk_644  tn.ny.sn_332 lg.tl.rn_544 
  0x20003f05, 0x4500641b, 0x35457814, 0x64094608,   // af.sq.un_330 lg.ln.un_770  ve.ln.zu_666 qu.pl.lg_443 
  // [20a70]
  0x52004d13, 0x5e005d08, 0x21645908, 0x5d005e34,   // aa.ha.un_650 ss.ts.un_430  rn.lg.jw_443 ts.ss.un_A80 
  0x04350804, 0x290f690b, 0x394809a4, 0x301038a0,   // uk.tg.ru_332 mfe.lv.sl_542  pl.tt.br_433 tk.lt.uz_322 
  0x5a555108, 0x11291207, 0x313010ee, 0x393747ee,   // kl.rw.sm_443 hu.sl.ro_432  lt.uz.az_422 sn.st.br_422 
  0x39474fad, 0x79690908, 0x493578a4, 0x2c0439af,   // bi.sn.br_643 pl.mfe.war_443  ve.zu.to_433 br.fi.fy_655 
  // [20a80]
  0x0f003209, 0x40000213, 0x02002a13, 0x6005610c,   // bs.lv.un_440 da.lb.un_650  mt.da.un_650 za.fr.vo_543 
  0x0907610c, 0x07093908, 0x321620ee, 0x42054704,   // za.it.pl_543 br.pl.it_443  sq.hr.bs_422 sn.fr.co_332 
  0x0b0561ec, 0x190b61ec, 0x100f1ca0, 0x08003f1b,   // za.fr.es_644 za.es.gl_644  id.lv.lt_322 af.no.un_770 
  0x61000804, 0x2c656111, 0x311003a7, 0x6e005e12,   // no.za.un_320 za.gv.fy_653  nl.lt.az_532 ts.hmn.un_640 
  // [20a90]
  0xfe000912, 0x22002c11, 0x100f380e, 0x5a005509,   // pl.tlh.un_640 fy.oc.un_630  tk.lv.lt_555 rw.sm.un_440 
  0x285f2c02, 0x0700610c, 0x100b61ec, 0x2b001c0c,   // fy.tn.sw_222 za.it.un_530  za.es.lt_644 id.vi.un_530 
  0x3500fe09, 0x07100f12, 0x56192804, 0x06602c0c,   // tlh.zu.un_440 lv.lt.it_654  sw.gl.mg_332 fy.vo.de_543 
  0x190b25a4, 0x4b00380c, 0x3f2a0bad, 0x52002b04,   // eu.es.gl_433 tk.mi.un_530  es.mt.af_643 vi.ha.un_320 
  // [20aa0]
  0x37170a07, 0x033f25ec, 0x0a34280c, 0x1300400d,   // mk.sr.ba_432 eu.af.nl_644  sw.xh.pt_543 lb.et.un_540 
  0x22055709, 0x73283509, 0x792c03ec, 0x321673ee,   // na.fr.oc_444 zu.sw.ny_444  nl.fy.war_644 ny.hr.bs_422 
  0x533048a0, 0x4057580c, 0x0a2973ee, 0x5d003514,   // tt.uz.ht_322 om.na.lb_543  ny.sl.pt_422 zu.ss.un_660 
  0x2859550c, 0x64190b08, 0x175657ee, 0x4f767804,   // rw.rn.sw_543 es.gl.lg_443  na.mg.sr_422 ve.crs.bi_332 
  // [20ab0]
  0x65001d09, 0x47595505, 0x4734730c, 0xfc1d25a4,   // la.gv.un_440 rw.rn.sn_333  ny.xh.sn_543 eu.la.zzp_433 
  0x6400282a, 0x055140a4, 0x0a230811, 0x1135150c,   // sw.lg.un_970 lb.kl.fr_433  uk.ky.mk_653 un.tg.ro_543 
  0x073c1712, 0xfc075c07, 0x22211ea0, 0x39fc1009,   // sr.ug.bg_654 sa.it.zzp_432  ms.jw.oc_322 lt.zzp.br_444 
  0x200c1a08, 0xfc6402ee, 0x2322110c, 0x17353407,   // tl.sv.sq_443 da.lg.zzp_422  ro.oc.ca_543 xh.zu.sr_432 
  // [20ac0]
  0x5e245ca0, 0x20370ba0, 0x64346707, 0x694c070e,   // sa.eo.ts_322 es.st.sq_322  ak.xh.lg_432 it.wo.mfe_555 
  0x4a344304, 0x070b0a08, 0x59285508, 0x35373404,   // ie.xh.yo_332 pt.es.it_443  rw.sw.rn_443 xh.st.zu_332 
  0x3e030e08, 0x76533307, 0x32001014, 0x23690207,   // is.nl.rm_443 nn.ht.crs_432  lt.bs.un_660 da.mfe.ca_432 
  0x0f004a07, 0x65153f07, 0x36004621, 0x48004b02,   // yo.lv.un_420 af.gv.un_420  qu.gn.un_860 mi.tt.un_220 
  // [20ad0]
  0x4200370e, 0x303b68ee, 0x6e683708, 0x280a68a4,   // st.co.un_550 ig.so.uz_422  st.ig.hmn_443 ig.pt.sw_433 
  0x29002b02, 0x09360ba0, 0x131c430c, 0x33002e18,   // vi.sl.un_220 es.gn.pl_322  ie.id.et_543 fo.nn.un_740 
  0x1f434e0c, 0xfc00560d, 0x5c00280e, 0x0b001b07,   // ay.ie.cy_543 mg.zzp.un_540  sw.sa.un_550 tr.es.un_420 
  0x30231507, 0x2f373902, 0xfc00fe0d, 0x56003304,   // un.ky.uz_432 br.st.su_222  tlh.zzp.un_540 nn.mg.un_320 
  // [20ae0]
  0x0a3507a9, 0x29100e07, 0x40394fa0, 0x3922050c,   // bg.tg.mk_544 is.lt.sl_432  bi.br.lb_322 fr.oc.br_543 
  0x0d303102, 0x353429a4, 0x0e0c27a0, 0x4e003013,   // az.uz.cs_222 sl.xh.zu_433  gd.sv.is_322 uz.ay.un_650 
  0x2e280e08, 0xfe001319, 0x36281309, 0x5828250c,   // is.sw.fo_443 et.tlh.un_750  et.sw.gn_444 eu.sw.om_543 
  0x34002005, 0x49595555, 0x0e284b04, 0x65005e12,   // sq.xh.un_330 rw.rn.to_442  mi.sw.is_332 ts.gv.un_640 
  // [20af0]
  0x46132807, 0x6100200e, 0x2d1246a7, 0x47001f13,   // sw.et.qu_432 sq.za.un_550  qu.hu.sk_532 cy.sn.un_650 
  0x061b2a07, 0x5e6747ad, 0x2e6b1a05, 0x46674d08,   // mt.tr.de_432 sn.ak.ts_643  tl.ceb.fo_333 aa.ak.qu_443 
  0x28582414, 0x6b7967ec, 0x12215005, 0x302f24ad,   // eo.om.sw_666 ak.war.ceb_644  fj.jw.hu_333 eo.su.uz_643 
  0x50475da0, 0x4765fe0d, 0x36250a0c, 0x3b24520c,   // ss.sn.fj_322 tlh.gv.sn_554  pt.eu.gn_543 ha.eo.so_543 
  // [20b00]
  0x2c180f09, 0x215c2012, 0x4600450b, 0x4c5bfe07,   // lv.ga.fy_444 sq.sa.jw_654  ln.qu.un_520 tlh.sg.wo_432 
  0x214b6a0c, 0x73651104, 0x0e500107, 0x111b310d,   // haw.mi.jw_543 ro.gv.ny_332  en.fj.is_432 az.tr.ro_554 
  0x286b52a0, 0x423b110d, 0x12250255, 0x63182713,   // ha.ceb.sw_322 ro.so.co_554  da.eu.hu_442 gd.ga.sco_665 
  0x4c4e4613, 0xfe212f07, 0x571f2508, 0x1d5e1fa4,   // qu.ay.wo_665 su.jw.tlh_432  eu.cy.na_443 cy.ts.la_433 
  // [20b10]
  0x330829a0, 0x190a49a9, 0x50212f0c, 0x36003004,   // sl.no.nn_322 to.pt.gl_544  su.jw.fj_543 uz.ab.un_320 
  0x1d1f5ea4, 0x0b132404, 0x21343c5a, 0x7820650d,   // ts.cy.la_433 eo.et.es_332  ug.ps.fa_553 gv.sq.ve_554 
  0x132501a0, 0x1f150107, 0x5400462a, 0x4b00010d,   // en.eu.et_322 en.cy.un_420  qu.ik.un_970 en.mi.un_540 
  0xfe1b31ee, 0x782001a4, 0x55285904, 0x73005905,   // az.tr.tlh_422 en.sq.ve_433  rn.sw.rw_332 rn.ny.un_330 
  // [20b20]
  0x6b4c1b14, 0x13020611, 0x4b1a20a4, 0x040a5aac,   // tr.wo.ceb_666 de.da.et_653  sq.tl.mi_433 sm.pt.fi_632 
  0x464e5107, 0x5e00390d, 0x0e2e50af, 0x1f00062b,   // kl.ay.qu_432 br.ts.un_540  fj.fo.is_655 de.cy.un_980 
  0x04303cee, 0x4b501f0c, 0x04000d13, 0x34303c0c,   // ug.uz.ru_422 cy.fj.mi_543  cs.fi.un_650 ug.uz.ps_543 
  0x2c3f02a4, 0x10081714, 0x36004a09, 0x1d00220e,   // da.af.fy_433 sr.uk.be_666  yo.gn.un_440 oc.la.un_550 
  // [20b30]
  0x1b005508, 0x3600380e, 0x2100641a, 0x64134a55,   // rw.tr.un_430 tk.gn.un_550  lg.jw.un_760 yo.et.lg_442 
  0x3922420c, 0x0b555612, 0x3c070aa4, 0x327347a0,   // co.oc.br_543 mg.rw.es_654  mk.bg.ug_433 sn.ny.bs_322 
  0x352847a7, 0x1700300d, 0x55001f12, 0x341830ac,   // sn.sw.zu_532 uz.sr.un_540  cy.rw.un_640 uz.ar.ps_632 
  0x47002a07, 0x5955fc09, 0x3c303408, 0x563660af,   // mt.sn.un_420 zzp.rw.rn_444  ps.uz.ug_443 vo.gn.mg_655 
  // [20b40]
  0x04455aa9, 0x5f5955ee, 0x3700170d, 0x021d240b,   // sm.ln.fi_544 rw.rn.tn_422  sr.ba.un_540 eo.la.da_542 
  0x12005614, 0x12134905, 0x071710ee, 0x122f56ad,   // mg.hu.un_660 to.et.hu_333  be.sr.bg_422 mg.su.hu_643 
  0x42203707, 0x5500110c, 0x25006405, 0x200256ad,   // st.sq.co_432 ro.rw.un_530  lg.eu.un_330 mg.da.sq_643 
  0x51003702, 0x395e7505, 0x3e1110ad, 0x28345d14,   // st.kl.un_220 nso.ts.br_333  lt.ro.rm_643 ss.xh.sw_666 
  // [20b50]
  0xfc004709, 0x2a005f04, 0x5c326107, 0x2f0d6107,   // sn.zzp.un_440 tn.mt.un_320  za.bs.sa_432 za.cs.su_432 
  0x647328ec, 0x17000e02, 0x5e7578a4, 0x75002008,   // sw.ny.lg_644 is.sr.un_220  ve.nso.ts_433 sq.nso.un_430 
  0x55fc4713, 0x39347360, 0xfc5559af, 0x685f78a4,   // sn.zzp.rw_665 ny.xh.br_664  rn.rw.zzp_655 ve.tn.ig_433 
  0x6a007818, 0x29205504, 0x04361212, 0x24506905,   // ve.haw.un_740 rw.sq.sl_332  hu.gn.fi_654 mfe.fj.eo_333 
  // [20b60]
  0x1f00392c, 0x25003511, 0x555e5907, 0x47001511,   // br.cy.un_990 tg.mn.un_630  rn.ts.rw_432 un.sn.un_630 
  0x03353f0d, 0x4773340c, 0x30362d0c, 0x206a1207,   // af.zu.nl_554 xh.ny.sn_543  sk.gn.uz_543 hu.haw.sq_432 
  0x16301fa0, 0x0420fe0c, 0x5d0c33ad, 0x2a55fe0c,   // cy.uz.hr_322 tlh.sq.fi_543  nn.sv.ss_643 tlh.rw.mt_543 
  0x03073f04, 0x755f7813, 0x53007813, 0x1b031d07,   // af.it.nl_332 ve.tn.nso_665  ve.ht.un_650 la.nl.tr_432 
  // [20b70]
  0x796b01a0, 0x30213da7, 0x03073fa9, 0x2d0d4fa4,   // en.ceb.war_322 ku.fa.uz_532  af.it.nl_544 bi.cs.sk_433 
  0x33024ca0, 0x1d110608, 0x2c064cad, 0x21004b12,   // wo.da.nn_322 de.ro.la_443  wo.de.fy_643 mi.jw.un_640 
  0x516a730b, 0x04516a04, 0x2d00091b, 0x4b1e6a07,   // ny.haw.kl_542 haw.kl.fi_332  pl.sk.un_770 haw.ms.mi_432 
  0x49006a1b, 0x070a25ee, 0x5100361a, 0x34fe6160,   // haw.to.un_770 mn.mk.bg_422  gn.kl.un_760 za.tlh.xh_664 
  // [20b80]
  0x353461af, 0x280413a0, 0x4b2549a0, 0x514b2fee,   // za.xh.zu_655 et.fi.sw_322  to.eu.mi_322 su.mi.kl_422 
  0x2a005c08, 0x51003509, 0x2000260c, 0x5c006b08,   // sa.mt.un_430 zu.kl.un_440  ia.sq.un_530 ceb.sa.un_430 
  0x070a3c08, 0x30170702, 0x065239ad, 0x09523807,   // ug.mk.bg_443 bg.sr.uz_222  br.ha.de_643 tk.ha.pl_432 
  0x07190b09, 0x550f03ee, 0x2000580d, 0x06103904,   // es.gl.it_444 nl.lv.rw_422  om.sq.un_540 br.lt.de_332 
  // [20b90]
  0x39090f07, 0x103615a4, 0x793609ad, 0x02005508,   // lv.pl.br_432 un.ab.be_433  pl.gn.war_643 rw.da.un_430 
  0x556a480c, 0x18002502, 0x35344a12, 0x55646160,   // tt.haw.rw_543 eu.ga.un_220  yo.xh.zu_654 za.lg.rw_664 
  0x2c330860, 0x556859af, 0x2a073ea4, 0xfc554508,   // no.nn.fy_664 rn.ig.rw_655  rm.it.mt_433 ln.rw.zzp_443 
  0x113921a4, 0x33023902, 0x36170aee, 0x3836230e,   // jw.br.ro_433 br.da.nn_222  mk.sr.ab_422 ky.ab.tk_555 
  // [20ba0]
  0x2c290955, 0x11303c12, 0x3f201ca0, 0x2c2f03a0,   // pl.sl.fy_442 ug.uz.ro_654  id.sq.af_322 nl.su.fy_322 
  0x5c464e55, 0x3f0e12ee, 0x25005609, 0x4e311b08,   // ay.qu.sa_442 hu.is.af_422  mg.eu.un_440 tr.az.ay_443 
  0x4d460fa4, 0x3823150c, 0x5c462009, 0x56005c07,   // lv.qu.aa_433 un.ky.tk_543  sq.qu.sa_444 sa.mg.un_420 
  0x3d18300b, 0x64251307, 0x4423480b, 0x212834ad,   // uz.ar.ku_542 et.eu.lg_432  tt.ky.kk_542 ps.sd.fa_643 
  // [20bb0]
  0x1b46360c, 0x3b213413, 0x2c3846a0, 0x085c560c,   // gn.qu.tr_543 ps.fa.ks_665  qu.tk.fy_322 mg.sa.no_543 
  0x3f4b04a0, 0x251b13ec, 0x2f045c07, 0x031b5c0c,   // fi.mi.af_322 et.tr.eu_644  sa.fi.su_432 sa.tr.nl_543 
  0x76110208, 0x1b25130c, 0x1b4a1307, 0x3f2c03a9,   // da.ro.crs_443 et.eu.tr_543  et.yo.tr_432 nl.fy.af_544 
  0x114a5f07, 0x4d26680c, 0x2c3f0309, 0x2a00551a,   // tn.yo.ro_432 ig.ia.aa_543  nl.af.fy_444 rw.mt.un_760 
  // [20bc0]
  0x2b004202, 0x736755a4, 0x30fc5808, 0x5d3501a4,   // co.vi.un_220 rw.ak.ny_433  om.zzp.uz_443 en.zu.ss_433 
  0x013b1504, 0x2a4a5508, 0x6963130c, 0x302128af,   // un.so.en_332 rw.yo.mt_443  et.sco.mfe_543 sd.fa.uz_655 
  0x5a4d55af, 0x025501a4, 0x25052408, 0x34002129,   // rw.aa.sm_655 en.rw.da_433  eo.fr.eu_443 fa.ps.un_960 
  0x4800782b, 0x32562aee, 0x5a7355ec, 0x4a5f2aa0,   // ve.tt.un_980 mt.mg.bs_422  rw.ny.sm_644 mt.tn.yo_322 
  // [20bd0]
  0x043510ee, 0x1e2e630c, 0x04375f09, 0x1b122f07,   // be.tg.ru_422 sco.fo.ms_543  tn.st.fi_444 su.hu.tr_432 
  0x2e1c0e02, 0x48382012, 0x483308a7, 0x123016a4,   // is.id.fo_222 sq.tk.tt_654  no.nn.tt_532 th.uz.ur_433 
  0x1b301da7, 0x0b0a15ec, 0x5c5a4b07, 0x16202912,   // la.uz.tr_532 un.pt.es_644  mi.sm.sa_432 sl.sq.hr_654 
  0x4d5f75af, 0x0d003002, 0x28003433, 0x07575a05,   // nso.tn.aa_655 uz.cs.un_220  ps.sd.un_A70 sm.na.it_333 
  // [20be0]
  0x04330805, 0x252f31a0, 0x3c212308, 0xfa5d57ad,   // no.nn.fi_333 az.su.eu_322  ky.fa.ug_443 na.ss.nr_643 
  0x651f3607, 0x19002804, 0x46365207, 0x020f6508,   // gn.cy.gv_432 sw.gl.un_320  ha.gn.qu_432 gv.lv.da_443 
  0x4773070c, 0x421101a4, 0x79351aa4, 0x18422707,   // it.ny.sn_543 en.ro.co_433  tl.zu.war_433 gd.co.ga_432 
  0x301ffc07, 0x02060307, 0x652e0ea9, 0x330827a9,   // zzp.cy.uz_432 nl.de.da_432  is.fo.gv_544 gd.no.nn_544 
  // [20bf0]
  0x305c53ad, 0x581224a4, 0x1ffc3b07, 0x20276512,   // ht.sa.uz_643 eo.hu.om_433  so.zzp.cy_432 gv.gd.sq_654 
  0x1f58fc08, 0x4b4913ee, 0x0c001f1a, 0xfc000202,   // zzp.om.cy_443 et.to.mi_422  cy.sv.un_760 da.zzp.un_220 
  0x5c331f0c, 0x2a0918ee, 0x4b6a13ec, 0x5e003722,   // cy.nn.sa_543 ga.pl.mt_422  et.haw.mi_644 st.ts.un_870 
  0x295c37ad, 0x4d00371a, 0x110f5c07, 0x1b2f5ca0,   // st.sa.sl_643 st.aa.un_760  sa.lv.ro_432 sa.su.tr_322 
  
  // [20c00]
  0x3b00480c, 0x3b5a580b, 0x1e563709, 0x4b1e3609,   // tt.so.un_530 om.sm.so_542  st.mg.ms_444 gn.ms.mi_444 
  0x3d002811, 0x585a6a0c, 0x2c00fc0d, 0x390208a4,   // sd.ku.un_630 haw.sm.om_543  zzp.fy.un_540 no.da.br_433 
  0x2e510208, 0x1869760c, 0x1b4006a4, 0x360b0a04,   // da.kl.fo_443 crs.mfe.ga_543  de.lb.tr_433 pt.es.gn_332 
  0x3d283b0d, 0x080a0405, 0x55532107, 0x583ffc12,   // ks.sd.ku_554 ru.mk.uk_333  jw.ht.rw_432 zzp.af.om_654 
  // [20c10]
  0x5240060b, 0x0239610c, 0x48474505, 0x3d21125a,   // de.lb.ha_542 za.br.da_543  ln.sn.tt_333 ur.fa.ku_553 
  0x34640107, 0x4c677304, 0x735578a9, 0x59575512,   // en.lg.xh_432 ny.ak.wo_332  ve.rw.ny_544 rw.na.rn_654 
  0x552859af, 0x28355d05, 0x080205a4, 0x423911ee,   // rn.sw.rw_655 ss.zu.sw_333  fr.da.no_433 ro.br.co_422 
  0x2100130d, 0x56454707, 0x551c2f02, 0xfc630104,   // et.jw.un_540 sn.ln.mg_432  su.id.rw_222 en.sco.zzp_332 
  // [20c20]
  0x210c2f05, 0x403f03a4, 0x281801a0, 0x55464704,   // su.sv.jw_333 nl.af.lb_433  en.ga.sw_322 sn.qu.rw_332 
  0x025d78a4, 0x52005e04, 0x7355640c, 0x64735e0c,   // ve.ss.da_433 ts.ha.un_320  lg.rw.ny_543 ts.ny.lg_543 
  0x7345590c, 0x371048ad, 0x2f2847a4, 0x2112185a,   // rn.ln.ny_543 tt.be.ba_643  sn.sw.su_433 ar.ur.fa_553 
  0x12000f08, 0x47fe2804, 0x631a4d04, 0x2e00182a,   // lv.hu.un_430 sw.tlh.sn_332  aa.tl.sco_332 ga.fo.un_970 
  // [20c30]
  0x082933a0, 0x5e5d56ec, 0x4435150c, 0x13516407,   // nn.sl.no_322 mg.ss.ts_644  un.tg.kk_543 lg.kl.et_432 
  0x082151a4, 0x044d5109, 0x336313a0, 0x3d213b0d,   // kl.jw.no_433 kl.aa.fi_444  et.sco.nn_322 ks.fa.ku_554 
  0x57006014, 0x28321613, 0x643504a7, 0x1d59550d,   // vo.na.un_660 hr.bs.sw_665  fi.zu.lg_532 rw.rn.la_554 
  0x4c5339a0, 0x5d024f09, 0x3c3048ec, 0x640257ad,   // br.ht.wo_322 bi.da.ss_444  tt.uz.ug_644 na.da.lg_643 
  // [20c40]
  0x20083312, 0x1a355d08, 0x47595560, 0x475f750d,   // nn.no.sq_654 ss.zu.tl_443  rw.rn.sn_664 nso.tn.sn_554 
  0x47645508, 0x2e1342ee, 0x0e426bad, 0x234417a0,   // rw.lg.sn_443 co.et.fo_422  ceb.co.is_643 sr.kk.ky_322 
  0x0e3f1f04, 0x20321608, 0x42006b13, 0x37020812,   // cy.af.is_332 hr.bs.sq_443  ceb.co.un_650 no.da.st_654 
  0x12006119, 0x35002818, 0x3b096012, 0x1b002105,   // za.hu.un_750 sw.zu.un_740  vo.pl.so_654 jw.tr.un_330 
  // [20c50]
  0x6a0b400c, 0x25002a12, 0x4800281b, 0x0e006b04,   // lb.es.haw_543 mt.eu.un_640  sw.tt.un_770 ceb.is.un_320 
  0x010209a7, 0x64554708, 0x51460112, 0x3e006b08,   // pl.da.en_532 sn.rw.lg_443  en.qu.kl_654 ceb.rm.un_430 
  0x47004622, 0x15fc09ee, 0x230b42ed, 0x5d00250c,   // qu.sn.un_870 pl.zzp.un_422  co.es.ca_622 eu.ss.un_530 
  0x0c46510b, 0x0a0417a7, 0xfc1d5aa6, 0x0500271b,   // kl.qu.sv_542 sr.ru.mk_532  sm.la.zzp_521 gd.fr.un_770 
  // [20c60]
  0x375f25af, 0x2a0201a4, 0x22480bee, 0x5f00252b,   // eu.tn.st_655 en.da.mt_433  es.tt.oc_422 eu.tn.un_980 
  0x4d182707, 0x1c125f04, 0x3b094da7, 0x010222a0,   // gd.ga.aa_432 tn.hu.id_332  aa.pl.so_532 oc.da.en_322 
  0x39fc65ac, 0x22794207, 0x05200107, 0x270c2612,   // gv.zzp.br_632 co.war.oc_432  en.sq.fr_432 ia.sv.gd_654 
  0x40002519, 0x0e4227ad, 0x2d002002, 0x18fe270c,   // eu.lb.un_750 gd.co.is_643  sq.sk.un_220 gd.tlh.ga_543 
  // [20c70]
  0x5b190bec, 0x3ffc0907, 0x5163045a, 0x02001d12,   // es.gl.sg_644 pl.zzp.af_432  fi.sco.kl_553 la.da.un_640 
  0x4651010b, 0x4600011a, 0x040817af, 0x443035ee,   // en.kl.qu_542 en.qu.un_760  sr.uk.ru_655 tg.uz.kk_422 
  0x0c2960a9, 0x60fc1f08, 0x3e5c1308, 0x332f1ca4,   // vo.sl.sv_544 cy.zzp.vo_443  et.sa.rm_443 id.su.nn_433 
  0x521324a7, 0xfc531014, 0x3ffc60a4, 0x64162807,   // eo.et.ha_532 lt.ht.zzp_666  vo.zzp.af_433 sw.hr.lg_432 
  // [20c80]
  0x47005207, 0x351b30ec, 0x6459550c, 0x601dfca4,   // ha.sn.un_420 uz.tr.zu_644  rw.rn.lg_543 zzp.la.vo_433 
  0x09005107, 0x34302812, 0x58fc090c, 0x5c292d0c,   // kl.pl.un_420 sd.uz.ps_654  pl.zzp.om_543 sk.sl.sa_543 
  0x0a440712, 0x34565507, 0x2f211f09, 0x3160fc08,   // bg.kk.mk_654 rw.mg.xh_432  cy.jw.su_444 zzp.vo.az_443 
  0x3f003913, 0x343044b4, 0x73286408, 0x4e5e590c,   // br.af.un_650 kk.uz.ps_754  lg.sw.ny_443 rn.ts.ay_543 
  // [20c90]
  0x602f0708, 0x20313504, 0x1a545113, 0x1a5a4a08,   // it.su.vo_443 zu.az.sq_332  kl.ik.tl_665 yo.sm.tl_443 
  0x360a0707, 0x636965ad, 0x2900300d, 0x082311a6,   // bg.mk.ab_432 gv.mfe.sco_643  uz.sl.un_540 ro.ky.uk_521 
  0x300723a0, 0x49285111, 0x0a3607ec, 0x03162907,   // ky.bg.uz_322 kl.sw.to_653  bg.ab.mk_644 sl.hr.nl_432 
  0x34283d0b, 0x566afcad, 0x472454af, 0x5e3654a9,   // ku.sd.ps_542 zzp.haw.mg_643  ik.eo.sn_655 ik.gn.ts_544 
  // [20ca0]
  0x561d15ec, 0x3700fa0c, 0x29470d07, 0x5a005108,   // un.la.mg_644 nr.st.un_530  cs.sn.sl_432 kl.sm.un_430 
  0x5600790c, 0x57005e13, 0x23313e0d, 0x074249ee,   // war.mg.un_530 ts.na.un_650  rm.az.ca_554 to.co.it_422 
  0x12250605, 0x12295611, 0x1b475009, 0x23000f12,   // de.eu.hu_333 mg.sl.hu_653  fj.sn.tr_444 lv.ca.un_640 
  0x3e47560c, 0x51fe3007, 0x47565e08, 0x1b002002,   // mg.sn.rm_543 uz.tlh.kl_432  ts.mg.sn_443 sq.tr.un_220 
  // [20cb0]
  0x304423ad, 0x321679ee, 0x29002005, 0x0d124c0c,   // ky.kk.uz_643 war.hr.bs_422  sq.sl.un_330 wo.hu.cs_543 
  0x31001e07, 0x17383504, 0x21536907, 0x230a25ee,   // ms.az.un_420 tg.tk.sr_332  mfe.ht.jw_432 mn.mk.ky_422 
  0x31002a07, 0x1b005b0e, 0x08351012, 0x2f016307,   // mt.az.un_420 sg.tr.un_550  be.tg.uk_654 sco.en.su_432 
  0x303831a0, 0x57011d05, 0x42610555, 0x42210511,   // az.tk.uz_322 la.en.na_333  fr.za.co_442 fr.jw.co_653 
  // [20cc0]
  0x2a001812, 0x2f211aa4, 0x033f1c04, 0x2a3b4ead,   // ga.mt.un_640 tl.jw.su_433  id.af.nl_332 ay.so.mt_643 
  0x2a004609, 0x322973a9, 0x0e002b04, 0x0e152a55,   // qu.mt.un_440 ny.sl.bs_544  vi.is.un_320 mt.is.un_420 
  0x03001c02, 0x0d001c2b, 0x697301a4, 0x1520095a,   // id.nl.un_220 mr.ne.un_980  en.ny.mfe_433 pl.sq.un_553 
  0x48383014, 0xfc2a34a0, 0x1b0430a0, 0x33023fa0,   // uz.tk.tt_666 xh.mt.zzp_322  uz.fi.tr_322 af.da.nn_322 
  // [20cd0]
  0x30483ba4, 0x6b1a3ba9, 0x04353c08, 0x38465c07,   // so.tt.uz_433 so.tl.ceb_544  ug.tg.ru_443 sa.qu.tk_432 
  0x1c152aee, 0x3e732da4, 0x037902a4, 0x016304a0,   // mt.id.un_420 sk.ny.rm_433  da.war.nl_433 fi.sco.en_322 
  0x27181fad, 0x1a4e5407, 0x274662ee, 0x35002018,   // cy.ga.gd_643 ik.ay.tl_432  kha.qu.gd_422 sq.zu.un_740 
  0x651f6307, 0x252a1da0, 0x3f690309, 0x1f1a580d,   // sco.cy.gv_432 la.mt.eu_322  nl.mfe.af_444 om.tl.cy_554 
  // [20ce0]
  0x1d01635a, 0x3e0301a4, 0x46002e13, 0x633f01a7,   // sco.en.la_553 en.nl.rm_433  fo.qu.un_650 en.af.sco_532 
  0xfc016312, 0x03004608, 0x2e0354ee, 0x33020808,   // sco.en.zzp_654 qu.nl.un_430  ik.nl.fo_422 no.da.nn_443 
  0x1f6562a9, 0x73017907, 0x06005c08, 0x511c1e0c,   // kha.gv.cy_544 war.en.ny_432  sa.de.un_430 ms.id.kl_543 
  0x0a0911a7, 0x041339a4, 0x201f5c08, 0x0e510408,   // ro.pl.pt_532 br.et.fi_433  sa.cy.sq_443 fi.kl.is_443 
  // [20cf0]
  0x65002008, 0x046352a9, 0x03215cad, 0x0d2d1260,   // sq.gv.un_430 ha.sco.fi_544  sa.jw.nl_643 hu.sk.cs_664 
  0x04635807, 0x7646530d, 0x04004d0e, 0x39111507,   // om.sco.fi_432 ht.qu.crs_554  aa.fi.un_550 un.ro.br_432 
  0x382f1e07, 0x4f691ca0, 0x324653a7, 0x120d2daf,   // ms.su.tk_432 id.mfe.bi_322  ht.qu.bs_532 sk.cs.hu_655 
  0x433f010b, 0x633e010c, 0x63003f14, 0x013f43ee,   // en.af.ie_542 en.rm.sco_543  af.sco.un_660 ie.af.en_422 
  // [20d00]
  0x634b010b, 0x4d672705, 0x1f67300d, 0x304e4612,   // en.mi.sco_542 gd.ak.aa_333  uz.ak.cy_554 qu.ay.uz_654 
  0x483b630e, 0x76694fa9, 0x36124d55, 0x15100805,   // sco.so.tt_555 bi.mfe.crs_544  aa.hu.gn_442 uk.be.un_333 
  0x276b57a0, 0x7653690e, 0x4e190bad, 0x1e5b46a7,   // na.ceb.gd_322 mfe.ht.crs_555  es.gl.ay_643 qu.sg.ms_532 
  0x3b58020e, 0x1253690d, 0x3e03070c, 0x100a080d,   // da.om.so_555 mfe.ht.hu_554  it.nl.rm_543 uk.mk.be_554 
  // [20d10]
  0x372338af, 0x091304a4, 0x6b005f19, 0x65005f1a,   // tk.ky.ba_655 fi.et.pl_433  tn.ceb.un_750 tn.gv.un_760 
  0x1d5865ee, 0x0900fc0c, 0x29001c02, 0x1c130d12,   // gv.om.la_422 zzp.pl.un_530  id.sl.un_220 ne.bh.mr_654 
  0x11350405, 0x25083812, 0x64552812, 0x6500110e,   // ru.tg.ro_333 tk.uk.mn_654  sw.rw.lg_654 ro.gv.un_550 
  0x26006513, 0x09281807, 0x65275aee, 0x3b420fec,   // gv.ia.un_650 ga.sw.pl_432  sm.gd.gv_422 lv.co.so_644 
  // [20d20]
  0x353c3060, 0x31381b0d, 0x25004c14, 0x3f00470d,   // uz.ug.tg_664 tr.tk.az_554  wo.eu.un_660 sn.af.un_540 
  0x250347a0, 0x44182805, 0x22000f0c, 0x0d00550d,   // sn.nl.eu_322 sd.ar.kk_333  lv.oc.un_530 rw.cs.un_540 
  0x25080407, 0x0373640c, 0x27006812, 0x09001a04,   // ru.uk.mn_432 lg.ny.nl_543  ig.gd.un_640 tl.pl.un_320 
  0x1a006a22, 0x6a5573a4, 0x2500730e, 0xfe206407,   // haw.tl.un_870 ny.rw.haw_433  ny.eu.un_550 lg.sq.tlh_432 
  // [20d30]
  0x350d64ad, 0x5a006a07, 0x5a004319, 0x344c45a0,   // lg.cs.zu_643 haw.sm.un_420  ie.sm.un_750 ln.wo.xh_322 
  0x355e34ee, 0x495a4da9, 0x30436455, 0x292d0dee,   // xh.ts.zu_422 aa.sm.to_544  lg.ie.uz_442 cs.sk.sl_422 
  0x02002512, 0x06000d0c, 0x532d2407, 0x55002004,   // eu.da.un_640 cs.de.un_530  eo.sk.ht_432 sq.rw.un_320 
  0x545a51ec, 0x730d2902, 0x1630490c, 0x5e005021,   // kl.sm.ik_644 sl.cs.ny_222  to.uz.hr_543 fj.ts.un_860 
  // [20d40]
  0x03004702, 0x2d2916a7, 0x13640409, 0x51005a0b,   // sn.nl.un_220 hr.sl.sk_532  fi.lg.et_444 sm.kl.un_520 
  0x4d5804af, 0x074810a0, 0x61002313, 0x54005713,   // fi.om.aa_655 be.tt.bg_322  ca.za.un_650 na.ik.un_650 
  0xfcfe6b13, 0x1a005508, 0x0f3b5104, 0x28006a19,   // ceb.tlh.zzp_665 rw.tl.un_430  kl.so.lv_332 haw.sw.un_750 
  0x3400462b, 0x58003b18, 0x1a494ba4, 0x02496aa4,   // qu.xh.un_980 so.om.un_740  mi.to.tl_433 haw.to.da_433 
  // [20d50]
  0x19002319, 0x551a5c0c, 0x13513b07, 0x3d003418,   // ca.gl.un_750 sa.tl.rw_543  so.kl.et_432 ps.ku.un_740 
  0x092d60bb, 0x6b790204, 0x6000091a, 0x3500380e,   // vo.sk.pl_854 da.war.ceb_332  pl.vo.un_760 tk.tg.un_550 
  0x1348600c, 0x51000411, 0x6b1a5907, 0x082e330c,   // vo.tt.et_543 fi.kl.un_630  rn.tl.ceb_432 nn.fo.no_543 
  0x040f51a4, 0x3b51040c, 0x5564210c, 0x51003b08,   // kl.lv.fi_433 fi.kl.so_543  jw.lg.rw_543 so.kl.un_430 
  // [20d60]
  0x51044a04, 0x51003b0c, 0x6b1a0212, 0x28183004,   // yo.fi.kl_332 so.kl.un_530  da.tl.ceb_654 uz.ar.sd_332 
  0x13214bec, 0x1b060c12, 0x485f3711, 0x1260130d,   // mi.jw.et_644 sv.de.tr_654  st.tn.tt_653 et.vo.hu_554 
  0x37345e0c, 0x2d006012, 0x28217311, 0x0b1f23af,   // ts.xh.st_543 vo.sk.un_640  ny.jw.sw_653 ca.cy.es_655 
  0x25041308, 0x027308a4, 0x595557ee, 0x0411150e,   // et.fi.eu_443 no.ny.da_433  na.rw.rn_422 un.ro.ru_555 
  // [20d70]
  0x0d093b55, 0x2e006008, 0x6260650c, 0x2178120c,   // ks.hi.ne_442 vo.fo.un_430  gv.vo.kha_543 hu.ve.jw_543 
  0x5e6453ad, 0x64004a0d, 0x1d240107, 0x39002008,   // ht.lg.ts_643 yo.lg.un_540  en.eo.la_432 sq.br.un_430 
  0x08350408, 0x09005f0d, 0x52000f04, 0x315c3bee,   // ru.tg.uk_443 tn.pl.un_540  lv.ha.un_320 so.sa.az_422 
  0x69005c1b, 0x1c3b2102, 0x76305c0b, 0x3b4d580e,   // sa.mfe.un_770 jw.so.id_222  sa.uz.crs_542 om.aa.so_555 
  // [20d80]
  0x0f293955, 0x3b001b05, 0x47002022, 0x531b4dee,   // br.sl.lv_442 tr.so.un_330  sq.sn.un_870 aa.tr.ht_422 
  0x0e3827a6, 0x65460ca9, 0x6b1a0208, 0x1200600b,   // gd.tk.is_521 sv.qu.gv_544  da.tl.ceb_443 vo.hu.un_520 
  0x13046011, 0x522125a0, 0x1c3b2704, 0x38251c07,   // vo.fi.et_653 eu.jw.ha_322  gd.so.id_332 id.eu.tk_432 
  0x791a3bee, 0x763153ec, 0x1f0e3eee, 0x36534da9,   // so.tl.war_422 ht.az.crs_644  rm.is.cy_422 aa.ht.gn_544 
  // [20d90]
  0x54003b19, 0x3b0b24a7, 0x5c6b3b04, 0x03212760,   // so.ik.un_750 eo.es.so_532  so.ceb.sa_332 gd.jw.nl_664 
  0x111354a9, 0x35070408, 0x381e25a9, 0x791b38ad,   // ik.et.ro_544 ru.bg.tg_443  eu.ms.tk_544 tk.tr.war_643 
  0x253823ac, 0x080c3907, 0x1f383b0b, 0x632e120c,   // ky.tk.mn_632 br.sv.no_432  so.tk.cy_542 hu.fo.sco_543 
  0x364837af, 0x13006016, 0x2b63010c, 0x13600411,   // ba.tt.ab_655 vo.et.un_720  en.sco.vi_543 fi.vo.et_653 
  // [20da0]
  0x1700260d, 0x341230af, 0x08695308, 0x43002912,   // ia.sr.un_540 uz.ur.ps_655  ht.mfe.no_443 sl.ie.un_640 
  0x1b001a02, 0x593e3b08, 0x1d300255, 0x6b6864a9,   // tl.tr.un_220 so.rm.rn_443  da.uz.la_442 lg.ig.ceb_544 
  0x1004080e, 0x73fc680c, 0x2c3f0302, 0xfc657907,   // uk.ru.be_555 ig.zzp.ny_543  nl.af.fy_222 war.gv.zzp_432 
  0x3035040d, 0x36111704, 0x08100702, 0x35340ea0,   // ru.tg.uz_554 sr.ro.ab_332  bg.be.uk_222 is.xh.zu_322 
  // [20db0]
  0x51026aad, 0x4d47350c, 0x3c48300e, 0x1c215355,   // haw.da.kl_643 zu.sn.aa_543  uz.tt.ug_555 ht.jw.id_442 
  0x062a1dee, 0x340e3511, 0x27001502, 0x265843af,   // la.mt.de_422 zu.is.xh_653  un.gd.un_220 ie.om.ia_655 
  0x0e000a07, 0x381b1107, 0x060e2e04, 0x17001e04,   // pt.is.un_420 ro.tr.tk_432  fo.is.de_332 ms.sr.un_320 
  0x04083c09, 0x0d1706a0, 0x17350a09, 0x1c005604,   // ug.uk.ru_444 de.sr.cs_322  mk.tg.sr_444 mg.id.un_320 
  // [20dc0]
  0x21002e07, 0x734bfc0d, 0x0c001902, 0x57002414,   // fo.jw.un_420 zzp.mi.ny_554  gl.sv.un_220 eo.na.un_660 
  0x58005c02, 0x39191812, 0x1965530c, 0x6539fcad,   // sa.om.un_220 ga.gl.br_654  ht.gv.gl_543 zzp.br.gv_643 
  0x111f39a0, 0x2c000609, 0x230b19ec, 0x252f5a07,   // br.cy.ro_322 de.fy.un_440  gl.es.ca_644 sm.su.eu_432 
  0x2556020c, 0x30566ba4, 0x65001820, 0x792f5608,   // da.mg.eu_543 ceb.mg.uz_433  ga.gv.un_850 mg.su.war_443 
  // [20dd0]
  0x796525a4, 0x56252c0c, 0x2f252112, 0x566b25ec,   // eu.gv.war_433 fy.eu.mg_543  jw.eu.su_654 eu.ceb.mg_644 
  0x25005614, 0x33081f08, 0x1900250c, 0x2f255608,   // mg.eu.un_660 cy.no.nn_443  eu.gl.un_530 mg.eu.su_443 
  0x2b2556a4, 0x3f40030b, 0x2c002508, 0x32000604,   // mg.eu.vi_433 nl.lb.af_542  eu.fy.un_430 de.bs.un_320 
  0x526b1ba0, 0x344c1ba0, 0x395706a4, 0x47003b08,   // tr.ceb.ha_322 tr.wo.xh_322  de.na.br_433 so.sn.un_430 
  // [20de0]
  0x422039a4, 0x1c130d09, 0x30533ba7, 0x1e003908,   // br.sq.co_433 ne.bh.mr_444  so.ht.uz_532 br.ms.un_430 
  0x39400611, 0x474c31a0, 0x39002c13, 0x121b39a7,   // de.lb.br_653 az.wo.sn_322  fy.br.un_650 br.tr.hu_532 
  0x030833ee, 0x52134608, 0x36386507, 0x13005307,   // nn.no.nl_422 qu.et.ha_443  gv.tk.gn_432 ht.et.un_420 
  0x1c3e2004, 0x58002802, 0x2c6a4911, 0x29003918,   // sq.rm.id_332 sw.om.un_220  to.haw.fy_653 br.sl.un_740 
  // [20df0]
  0x224f2e08, 0x330efea0, 0x3b001012, 0x13613913,   // fo.bi.oc_443 tlh.is.nn_322  lt.so.un_640 br.za.et_665 
  0x31301baf, 0x46583007, 0x252d29ad, 0x0f100607,   // tr.uz.az_655 uz.om.qu_432  sl.sk.eu_643 de.lt.lv_432 
  0x65016307, 0x4800302c, 0x38070a04, 0x220e25a0,   // sco.en.gv_432 uz.tt.un_990  mk.bg.tk_332 eu.is.oc_322 
  0x65173fa0, 0x63002012, 0x615f0ca4, 0x1a30310c,   // af.sr.gv_322 sq.sco.un_640  sv.tn.za_433 az.uz.tl_543 
  // [20e00]
  0x46543b13, 0x67003b0e, 0x391d61a9, 0x15273ba7,   // so.ik.qu_665 so.ak.un_550  za.la.br_544 so.gd.un_532 
  0xfc001908, 0x49004702, 0x1b106b55, 0x265e1d08,   // gl.zzp.un_430 sn.to.un_220  ceb.lt.tr_442 la.ts.ia_443 
  0x30080202, 0x65633b04, 0x5f347812, 0x2f2c61ac,   // da.no.uz_222 so.sco.gv_332  ve.xh.tn_654 za.fy.su_632 
  0x09042c0b, 0x58fc01a4, 0x4700390d, 0x4b3f49a4,   // fy.fi.pl_542 en.zzp.om_433  br.sn.un_540 to.af.mi_433 
  // [20e10]
  0x30463bad, 0x46004e21, 0x182d1211, 0x443c23ac,   // so.qu.uz_643 ay.qu.un_860  hu.sk.ga_653 ky.ug.kk_632 
  0x4c002d13, 0x01fc69a4, 0x0e190b05, 0x11fc01a4,   // sk.wo.un_650 mfe.zzp.en_433  es.gl.is_333 en.zzp.ro_433 
  0x354759a0, 0x556a4505, 0xfc645507, 0x4f000212,   // rn.sn.zu_322 ln.haw.rw_333  rw.lg.zzp_432 da.bi.un_640 
  0x355955ad, 0x5c1239ad, 0x2c595560, 0x18002e0b,   // rw.rn.zu_643 br.hu.sa_643  rw.rn.fy_664 fo.ga.un_520 
  // [20e20]
  0x04150a0c, 0x11002c1a, 0x53004607, 0x3b4cfe55,   // mk.ru.un_530 fy.ro.un_760  qu.ht.un_420 tlh.wo.so_442 
  0x24464aec, 0x1e0f610c, 0x69007635, 0x6e003204,   // yo.qu.eo_644 za.lv.ms_543  crs.mfe.un_A90 bs.hmn.un_320 
  0x63272607, 0x6100fe2b, 0x2e3308a4, 0x1800650e,   // ia.gd.sco_432 tlh.za.un_980  no.nn.fo_433 gv.ga.un_550 
  0x1b6e1604, 0x796efeec, 0x3b796b08, 0x4c136507,   // hr.hmn.tr_332 tlh.hmn.war_644  ceb.war.so_443 gv.et.wo_432 
  // [20e30]
  0x6b1b470d, 0x130365a4, 0x6efe240b, 0x42002408,   // sn.tr.ceb_554 gv.nl.et_433  eo.tlh.hmn_542 eo.co.un_430 
  0x0a3b30af, 0x320201a0, 0x4d19220c, 0x3800232c,   // uz.so.pt_655 en.da.bs_322  oc.gl.aa_543 ky.tk.un_990 
  0x13004a0b, 0x655f6460, 0x654c4dac, 0x65583fa4,   // yo.et.un_520 lg.tn.gv_664  aa.wo.gv_632 af.om.gv_433 
  0x4d655a5a, 0x3b6458a4, 0x1050515a, 0x110a1760,   // sm.gv.aa_553 om.lg.so_433  kl.fj.lt_553 sr.mk.ro_664 
  // [20e40]
  0x0300640d, 0x1032165a, 0xfc190b02, 0x65644d07,   // lg.nl.un_540 hr.bs.lt_553  es.gl.zzp_222 aa.lg.gv_432 
  0x30313b09, 0x3e313ba0, 0x19005c08, 0x0e231d04,   // so.az.uz_444 so.az.rm_322  sa.gl.un_430 la.ca.is_332 
  0x653b4dec, 0x10281d0c, 0x4c651355, 0x10002c18,   // aa.so.gv_644 la.sw.lt_543  et.gv.wo_442 fy.lt.un_740 
  0x5a796bad, 0x3e1d2707, 0x5d003608, 0x5c6b0da4,   // ceb.war.sm_643 gd.la.rm_432  gn.ss.un_430 cs.ceb.sa_433 
  // [20e50]
  0x3f136504, 0x3f3b4d08, 0x514d3b60, 0x3e001009,   // gv.et.af_332 aa.so.af_443  so.aa.kl_664 lt.rm.un_440 
  0x0b002902, 0x3844230c, 0x15073504, 0x2f2a4602,   // sl.es.un_220 ky.kk.tk_543  tg.bg.un_332 qu.mt.su_222 
  0x275f18a4, 0x153c1108, 0x4b5057ee, 0x103e650b,   // ga.tn.gd_433 ro.ug.un_443  na.fj.mi_422 gv.rm.lt_542 
  0x21004c02, 0x187952a4, 0x3b4813ee, 0x285a6a11,   // wo.jw.un_220 ha.war.ga_433  et.tt.so_422 haw.sm.sw_653 
  // [20e60]
  0x285a1fee, 0x3b001e1a, 0x370a11a4, 0x35100412,   // cy.sm.sw_422 ms.so.un_760  ro.mk.ba_433 ru.be.tg_654 
  0x3b001321, 0x10383611, 0x42004d0d, 0x1f005a13,   // et.so.un_860 ab.tk.be_653  aa.co.un_540 sm.cy.un_650 
  0x18000507, 0x5e00fe2c, 0x521e1c13, 0x182e0e07,   // fr.ga.un_420 tlh.ts.un_990  id.ms.ha_665 is.fo.ga_432 
  0x48000c11, 0x5cfcfe04, 0x6a5c49a7, 0x172916a0,   // sv.tt.un_630 tlh.zzp.sa_332  to.sa.haw_532 hr.sl.sr_322 
  // [20e70]
  0x1a4852a4, 0x190b0405, 0x27485212, 0x561e1c14,   // ha.tt.tl_433 fi.es.gl_333  ha.tt.gd_654 id.ms.mg_666 
  0x18233dee, 0x2e00791a, 0x100711ec, 0x6b2e7909,   // ku.ky.ar_422 war.fo.un_760  ro.bg.be_644 war.fo.ceb_444 
  0x23103804, 0x2f3b04a0, 0x0e004d14, 0x303848ee,   // tk.be.ky_332 fi.so.su_322  aa.is.un_660 tt.tk.uz_422 
  0x1a003e29, 0x250a3005, 0x0e2e620c, 0x67276ba4,   // rm.tl.un_960 uz.mk.mn_333  kha.fo.is_543 ceb.gd.ak_433 
  // [20e80]
  0x400413ac, 0x3b1e1b08, 0x17000818, 0x4c584a11,   // et.fi.lb_632 tr.ms.so_443  uk.sr.un_740 yo.om.wo_653 
  0x044c0204, 0x11381b07, 0x09291807, 0x3b463807,   // da.wo.fi_332 tr.tk.ro_432  ga.sl.pl_432 tk.qu.so_432 
  0x753b4ca9, 0x5c120212, 0x3f2c02ec, 0x2e000e2a,   // wo.so.nso_544 da.hu.sa_654  da.fy.af_644 is.fo.un_970 
  0x534a1aa0, 0x1a042fee, 0x3b4d4c07, 0x6b1a2107,   // tl.yo.ht_322 su.fi.tl_422  wo.aa.so_432 jw.tl.ceb_432 
  // [20e90]
  0x34004004, 0x644c4a0b, 0x3f092ca0, 0x0800620c,   // lb.xh.un_320 yo.wo.lg_542  fy.pl.af_322 kha.no.un_530 
  0x134d040c, 0x0f401307, 0x58004013, 0x133b4d0c,   // fi.aa.et_543 et.lb.lv_432  lb.om.un_650 aa.so.et_543 
  0x73002922, 0xfc002508, 0x68645f0d, 0x3534570c,   // sl.ny.un_870 eu.zzp.un_430  tn.lg.ig_554 na.xh.zu_543 
  0x482e0ead, 0x1b50680c, 0x02783f11, 0x03073fa4,   // is.fo.tt_643 ig.fj.tr_543  af.ve.da_653 af.it.nl_433 
  // [20ea0]
  0x2300080b, 0x3216380c, 0x071b6004, 0x2f025008,   // uk.ky.un_520 tk.hr.bs_543  vo.tr.it_332 fj.da.su_443 
  0x3f1768a4, 0x46433e0c, 0x1b000c0e, 0x481b09ee,   // ig.sr.af_433 rm.ie.qu_543  sv.tr.un_550 pl.tr.tt_422 
  0x4a381ba7, 0x25003807, 0x15081504, 0x69007629,   // tr.tk.yo_532 tk.mn.un_420  un.uk.un_332 crs.mfe.un_960 
  0x4c5e1a0c, 0x303b58a0, 0x1b007904, 0x680208af,   // tl.ts.wo_543 om.so.uz_322  war.tr.un_320 no.da.ig_655 
  // [20eb0]
  0x5c3811a4, 0x2f122d04, 0x27005305, 0x466e5d0c,   // ro.tk.sa_433 sk.hu.su_332  ht.gd.un_330 ss.hmn.qu_543 
  0x510e42a4, 0x03000212, 0x58606308, 0x46510f07,   // co.is.kl_433 da.nl.un_640  sco.vo.om_443 lv.kl.qu_432 
  0x4b5a6a0c, 0x03065714, 0x6500620e, 0x6976220c,   // haw.sm.mi_543 na.de.nl_666  kha.gv.un_550 oc.crs.mfe_543 
  0x53694e08, 0x0f103fa7, 0x3e00540c, 0x39000f05,   // ay.mfe.ht_443 af.lt.lv_532  ik.rm.un_530 lv.br.un_330 
  // [20ec0]
  0x0e630f07, 0x22230504, 0x08fc0c02, 0x1d394eac,   // lv.sco.is_432 fr.ca.oc_332  sv.zzp.no_222 ay.br.la_632 
  0x330c0f55, 0x5c004912, 0x2f1805ee, 0x430201ec,   // lv.sv.nn_442 to.sa.un_640  fr.ga.su_422 en.da.ie_644 
  0x233f15ac, 0x11221804, 0x5d4702a9, 0x5302490c,   // un.af.ca_632 ga.oc.ro_332  da.sn.ss_544 to.da.ht_543 
  0x3c37480c, 0x47580207, 0x39000408, 0x3f060313,   // tt.ba.ug_543 da.om.sn_432  fi.br.un_430 nl.de.af_665 
  // [20ed0]
  0x795625a4, 0x251e1c08, 0x2200180e, 0x360e2e0c,   // eu.mg.war_433 id.ms.eu_443  ga.oc.un_550 fo.is.gn_543 
  0x2f1c1ea9, 0x3e2201a0, 0x08020105, 0x24561e07,   // ms.id.su_544 en.oc.rm_322  en.da.no_333 ms.mg.eo_432 
  0x53345da0, 0x390f2304, 0x36004713, 0x2f151ca0,   // ss.xh.ht_322 ca.lv.br_332  sn.gn.un_650 id.su.un_320 
  0x6724220c, 0x01634707, 0x3300470b, 0x392025a4,   // oc.eo.ak_543 sn.sco.en_432  sn.nn.un_520 eu.sq.br_433 
  // [20ee0]
  0x475a4914, 0x1c002504, 0x204710af, 0x2f0413a6,   // to.sm.sn_666 eu.id.un_320  lt.sn.sq_655 et.fi.su_521 
  0x30042312, 0x014302a0, 0xfe3949af, 0x135c50ec,   // ky.ru.uz_654 da.ie.en_322  to.br.tlh_655 fj.sa.et_644 
  0x35443011, 0x172a6004, 0x475030ec, 0x4b5906a4,   // uz.kk.tg_653 vo.mt.sr_332  uz.fj.sn_644 de.rn.mi_433 
  0x024b20a4, 0x150a10a0, 0x401d36a0, 0x0f47010b,   // sq.mi.da_433 be.mk.un_322  gn.la.lb_322 en.sn.lv_542 
  // [20ef0]
  0x02364907, 0x04436a07, 0x303c4414, 0x130479a0,   // to.gn.da_432 haw.ie.fi_432  kk.ug.uz_666 war.fi.et_322 
  0x395a4907, 0x1f004f19, 0x43534708, 0x49476008,   // to.sm.br_432 bi.cy.un_750  sn.ht.ie_443 vo.sn.to_443 
  0x47391709, 0x59133608, 0x3e394714, 0x36004004,   // sr.br.sn_444 gn.et.rn_443  sn.br.rm_666 lb.gn.un_320 
  0x39004b0c, 0x5500060d, 0x4a595505, 0xfc5559a0,   // mi.br.un_530 de.rw.un_540  rw.rn.yo_333 rn.rw.zzp_322 
  // [20f00]
  0x39000e12, 0x282a6408, 0x07fc02a0, 0x4a006405,   // is.br.un_640 lg.mt.sw_443  da.zzp.it_322 lg.yo.un_330 
  0x1b06380c, 0x63561f0c, 0x08020205, 0x555928ad,   // tk.de.tr_543 cy.mg.sco_543  da.da.no_333 sw.rn.rw_643 
  0x11070a05, 0x25003f02, 0x12004814, 0x59004b20,   // mk.bg.ro_333 af.eu.un_220  tt.hu.un_660 mi.rn.un_850 
  0x120640a4, 0x73374e08, 0x3f002512, 0x01002307,   // lb.de.hu_433 ay.st.ny_443  eu.af.un_640 ca.en.un_420 
  // [20f10]
  0x1f00300e, 0x4b022fa4, 0x47005c0d, 0x3f002505,   // uz.cy.un_550 su.da.mi_433  sa.sn.un_540 eu.af.un_330 
  0x583b2108, 0x1b483855, 0x43000613, 0x075cfe07,   // jw.so.om_443 tk.tt.tr_442  de.ie.un_650 tlh.sa.it_432 
  0x253f57a7, 0x080a35a0, 0x3b520107, 0x464e73a4,   // na.af.eu_532 tg.mk.uk_322  en.ha.so_432 ny.ay.qu_433 
  0x2063010c, 0x35005905, 0x1f554708, 0x0451670b,   // en.sco.sq_543 rn.zu.un_330  sn.rw.cy_443 ak.kl.fi_542 
  // [20f20]
  0x64400608, 0x2b002307, 0x2f390507, 0xfc4764a4,   // de.lb.lg_443 ca.vi.un_420  fr.br.su_432 lg.sn.zzp_433 
  0x2e005107, 0x56002504, 0x1b381218, 0x03fc01a0,   // kl.fo.un_420 eu.mg.un_320  hu.tk.tr_764 en.zzp.nl_322 
  0x372cfc0c, 0xfc645508, 0x2d001608, 0x5955fca4,   // zzp.fy.st_543 rw.lg.zzp_443  hr.sk.un_430 zzp.rw.rn_433 
  0x581b0f0c, 0x1f023e07, 0x12003102, 0x23190a0e,   // lv.tr.om_543 rm.da.cy_432  az.hu.un_220 pt.gl.ca_555 
  // [20f30]
  0x2500fc0e, 0x0c004211, 0x595509a4, 0x4b495107,   // zzp.eu.un_550 co.sv.un_630  pl.rw.rn_433 kl.to.mi_432 
  0x51fc2ead, 0x5547fc07, 0x2f5c790b, 0x6a4f60a4,   // fo.zzp.kl_643 zzp.sn.rw_432  war.sa.su_542 vo.bi.haw_433 
  0xfc644004, 0x5a006a05, 0xfc00210e, 0x1f5e28a9,   // lb.lg.zzp_332 haw.sm.un_330  jw.zzp.un_550 sw.ts.cy_544 
  0x6913610c, 0x103608a9, 0x3f47090c, 0x494065a4,   // za.et.mfe_543 uk.ab.be_544  pl.sn.af_543 gv.lb.to_433 
  // [20f40]
  0x402f1a02, 0x4f006122, 0x282f29ee, 0x0c3ffc0c,   // tl.su.lb_222 za.bi.un_870  sl.su.sw_422 zzp.af.sv_543 
  0x1f0c25a7, 0x1000fc09, 0x1234fc02, 0x61003905,   // eu.sv.cy_532 zzp.lt.un_440  zzp.xh.hu_222 br.za.un_330 
  0x2f37610c, 0x4b491d09, 0x13476109, 0x286a4b12,   // za.st.su_543 la.to.mi_444  za.sn.et_444 mi.haw.sw_654 
  0x1d494ba7, 0x190b05a4, 0x4800350e, 0x2100560b,   // mi.to.la_532 fr.es.gl_433  tg.tt.un_550 mg.jw.un_520 
  // [20f50]
  0x48001209, 0x2400fc07, 0x0f1dfe07, 0x51031dee,   // hu.tt.un_440 zzp.eo.un_420  tlh.la.lv_432 la.nl.kl_422 
  0x47182760, 0x31001216, 0x226b1a14, 0x04003b02,   // gd.ga.sn_664 hu.az.un_720  tl.ceb.oc_666 so.fi.un_220 
  0x6b220408, 0x2f1c65a0, 0x4301fe05, 0x501165ec,   // fi.oc.ceb_443 gv.id.su_322  tlh.en.ie_333 gv.ro.fj_644 
  0x3b2758a9, 0x2b023e07, 0x525a500c, 0x19004904,   // om.gd.so_544 rm.da.vi_432  fj.sm.ha_543 to.gl.un_320 
  // [20f60]
  0x65006b12, 0x4f5a500d, 0x25000f19, 0x6b1a27ad,   // ceb.gv.un_640 fj.sm.bi_554  lv.eu.un_750 gd.tl.ceb_643 
  0x27000213, 0x226123ad, 0x232118a4, 0x115a49a4,   // da.gd.un_650 ca.za.oc_643  ar.fa.ky_433 to.sm.ro_433 
  0x65073eec, 0x381b39a9, 0x190b0504, 0x1800050d,   // rm.it.gv_644 br.tr.tk_544  fr.es.gl_332 fr.ga.un_540 
  0x42054011, 0x6b007922, 0x5118270c, 0x30001821,   // lb.fr.co_653 war.ceb.un_870  gd.ga.kl_543 ar.uz.un_860 
  // [20f70]
  0x190a0504, 0x22236509, 0x2b493ead, 0x1940050c,   // fr.pt.gl_332 gv.ca.oc_444  rm.to.vi_643 fr.lb.gl_543 
  0x38441105, 0x48080408, 0x311b42a0, 0x64004904,   // ro.kk.tk_333 ru.uk.tt_443  co.tr.az_322 to.lg.un_320 
  0x390521a0, 0x040725a0, 0x224205ac, 0x1a001d1a,   // jw.fr.br_322 mn.bg.ru_322  fr.co.oc_632 la.tl.un_760 
  0x07421812, 0x10081507, 0x1b00120b, 0x3f2601a0,   // ga.co.it_654 un.uk.be_432  hu.tr.un_520 en.ia.af_322 
  // [20f80]
  0x0400120d, 0x040e0c04, 0x651f57a4, 0x111d3e0c,   // hu.fi.un_540 sv.is.fi_332  na.cy.gv_433 rm.la.ro_543 
  0x0a05195a, 0x0c001211, 0x560d2d07, 0x03003312,   // gl.fr.pt_553 hu.sv.un_630  sk.cs.mg_432 nn.nl.un_640 
  0x016306a0, 0x33033f08, 0x12040c07, 0x212f1c55,   // de.sco.en_322 af.nl.nn_443  sv.fi.hu_432 id.su.jw_442 
  0x360d5607, 0x58006e0b, 0x63001309, 0x11005719,   // mg.cs.gn_432 hmn.om.un_520  et.sco.un_440 na.ro.un_750 
  // [20f90]
  0x17100a0d, 0x5259555a, 0x0f0a1102, 0x026468a7,   // mk.be.sr_554 rw.rn.ha_553  ro.pt.lv_222 ig.lg.da_532 
  0x074423ee, 0x2400020d, 0x6a114bad, 0x1000620c,   // ky.kk.bg_422 da.eo.un_540  mi.ro.haw_643 kha.lt.un_530 
  0x3b1e1c13, 0x04004a09, 0x13006213, 0x041e1c09,   // id.ms.so_665 yo.fi.un_440  kha.et.un_650 id.ms.fi_444 
  0x11072cec, 0x1000620d, 0x1000010d, 0x1c521eec,   // fy.it.ro_644 kha.lt.un_540  en.lt.un_540 ms.ha.id_644 
  // [20fa0]
  0x1e1c3b14, 0x11122207, 0x37006304, 0x22000908,   // so.id.ms_666 oc.hu.ro_432  sco.st.un_320 pl.oc.un_430 
  0x2f001e09, 0x65000c22, 0x234c45ac, 0x302134a4,   // ms.su.un_440 sv.gv.un_870  ln.wo.ca_632 ps.fa.uz_433 
  0x0a19490c, 0x38463b12, 0x1304290b, 0x52252fa6,   // to.gl.pt_543 so.qu.tk_654  sl.fi.et_542 su.eu.ha_521 
  0x4e1e1c60, 0x193e2204, 0x0a190508, 0x041c2f07,   // id.ms.ay_664 oc.rm.gl_332  fr.gl.pt_443 su.id.fi_432 
  // [20fb0]
  0x343b3013, 0x2e002419, 0x2e041309, 0x103c045a,   // uz.ks.ps_665 eo.fo.un_750  et.fi.fo_444 ru.ug.be_553 
  0x391d600c, 0x0a073c5a, 0x2f365104, 0x12fc1802,   // vo.la.br_543 ug.bg.mk_553  kl.gn.su_332 ga.zzp.hu_222 
  0x0a0723a4, 0x150c20a0, 0x0e2a23a6, 0x1b323907,   // ky.bg.mk_433 sq.sv.un_322  ca.mt.is_521 br.bs.tr_432 
  0x2c39010b, 0x2e001302, 0x19001502, 0x480c2aec,   // en.br.fy_542 et.fo.un_220  un.gl.un_220 mt.sv.tt_644 
  // [20fc0]
  0x6540040c, 0x534739a0, 0x73112511, 0x11420aad,   // fi.lb.gv_543 br.sn.ht_322  eu.ro.ny_653 pt.co.ro_643 
  0x073e01a9, 0x18276507, 0x09642504, 0x314c0107,   // en.rm.it_544 gv.gd.ga_432  eu.lg.pl_332 en.wo.az_432 
  0x092d6a04, 0x30484c09, 0x25371002, 0x47203908,   // haw.sk.pl_332 wo.tt.uz_444  be.ba.mn_222 br.sq.sn_443 
  0x47003912, 0x31464ea4, 0x6400300c, 0x060301a0,   // br.sn.un_640 ay.qu.az_433  uz.lg.un_530 en.nl.de_322 
  // [20fd0]
  0x064001a0, 0x131d4c0c, 0x551a3407, 0x735b2112,   // en.lb.de_322 wo.la.et_543  xh.tl.rw_432 jw.sg.ny_654 
  0x44233014, 0x35670208, 0x381708a4, 0x2a004509,   // uz.ky.kk_666 da.ak.zu_443  uk.sr.tk_433 ln.mt.un_440 
  0x38041307, 0x381304ee, 0x070a1008, 0x4a005b13,   // et.fi.tk_432 fi.et.tk_422  be.mk.bg_443 sg.yo.un_650 
  0x42005602, 0x0f005a0c, 0x5c12fea0, 0x6a4b68ec,   // mg.co.un_220 sm.lv.un_530  tlh.hu.sa_322 ig.mi.haw_644 
  // [20fe0]
  0x08043755, 0x0c1240a0, 0x2522110c, 0x5e002a04,   // ba.ru.uk_442 lb.hu.sv_322  ro.oc.eu_543 mt.ts.un_320 
  0x676a6808, 0x57001122, 0x4b686709, 0x25005712,   // ig.haw.ak_443 ro.na.un_870  ak.ig.mi_444 na.eu.un_640 
  0x2b46feec, 0x1d2511a7, 0x6a256708, 0x12085c07,   // tlh.qu.vi_644 ro.eu.la_532  ak.eu.haw_443 sa.no.hu_432 
  0x1700320c, 0x0a1d115a, 0x5c1229a4, 0x386230af,   // bs.sr.un_530 ro.la.pt_553  sl.hu.sa_433 uz.kha.tk_655 
  // [20ff0]
  0x6e002b19, 0x2a001107, 0x2b271e0c, 0x46494755,   // vi.hmn.un_750 ro.mt.un_420  ms.gd.vi_543 sn.to.qu_442 
  0x11005718, 0x1f30690b, 0x046a0208, 0x040a1104,   // na.ro.un_740 mfe.uz.cy_542  da.haw.fi_443 ro.mk.ru_332 
  0x0a083502, 0x15040755, 0x39221d07, 0x555659a7,   // tg.uk.mk_222 bg.ru.un_442  la.oc.br_432 rn.mg.rw_532 
  0x13006a22, 0x293b130c, 0x471113a0, 0x366a3708,   // haw.et.un_870 et.so.sl_543  et.ro.sn_322 st.haw.gn_443 
  
  // [21000]
  0x5a00470d, 0x02003e05, 0x5a4902a0, 0x55595812,   // sn.sm.un_540 rm.da.un_330  da.to.sm_322 om.rn.rw_654 
  0x3b595514, 0x641c5207, 0x6a56670c, 0x4749130c,   // rw.rn.so_666 ha.id.lg_432  ak.mg.haw_543 et.to.sn_543 
  0x4430150c, 0x47552807, 0x731a4a0d, 0x79061505,   // un.uz.kk_543 sw.rw.sn_432  yo.tl.ny_554 un.de.war_333 
  0x53000905, 0x64005712, 0x554757ad, 0x09004c02,   // pl.ht.un_330 na.lg.un_640  na.sn.rw_643 wo.pl.un_220 
  // [21010]
  0x3b000207, 0x1257730c, 0x64004d13, 0x1a211fa7,   // da.so.un_420 ny.na.hu_543  aa.lg.un_650 cy.jw.tl_532 
  0x60005713, 0x12002f13, 0x4200280c, 0x612f1fa9,   // na.vo.un_650 su.hu.un_650  sw.co.un_530 cy.su.za_544 
  0xfe121f04, 0x61212f05, 0x2e003004, 0x0417070b,   // cy.hu.tlh_332 su.jw.za_333  uz.fo.un_320 bg.sr.ru_542 
  0x04483508, 0x0a300709, 0x13061ba0, 0x1036150b,   // tg.tt.ru_443 bg.uz.mk_444  tr.de.et_322 un.ab.be_542 
  // [21020]
  0x68007322, 0x0a07170b, 0x06003604, 0x5e633107,   // ny.ig.un_870 sr.bg.mk_542  gn.de.un_320 az.sco.ts_432 
  0x33082c02, 0x202e0e02, 0x0d003f05, 0x36003c0d,   // fy.no.nn_222 is.fo.sq_222  af.cs.un_330 ug.ab.un_540 
  0x651f570c, 0x2a212e07, 0x3b002807, 0x4b006a05,   // na.cy.gv_543 fo.jw.mt_432  sw.so.un_420 haw.mi.un_330 
  0x040815ac, 0x18652712, 0x02645907, 0x64025513,   // un.uk.ru_632 gd.gv.ga_654  rn.lg.da_432 rw.da.lg_665 
  // [21030]
  0x1535150c, 0x1a0964a0, 0x555c5612, 0x23fe2e0b,   // un.tg.un_543 lg.pl.tl_322  mg.sa.rw_654 fo.tlh.ca_542 
  0x0c042ea9, 0x79061faf, 0x09334ea0, 0x65271ea0,   // fo.fi.sv_544 cy.de.war_655  ay.nn.pl_322 ms.gd.gv_322 
  0x18651f08, 0x122a20a4, 0x1f6465a0, 0x381525a9,   // cy.gv.ga_443 sq.mt.hu_433  gv.lg.cy_322 mn.tk.un_540 
  0x6500780d, 0x4b006511, 0x49003505, 0x09645507,   // ve.gv.un_540 gv.mi.un_630  zu.to.un_330 rw.lg.pl_432 
  // [21040]
  0x5900fc1a, 0x07374805, 0x17233007, 0x29092da4,   // zzp.rn.un_760 tt.ba.bg_333  uz.ky.sr_432 sk.pl.sl_433 
  0x1b025c55, 0x5d00fc19, 0x153823ad, 0x08171107,   // sa.da.tr_442 zzp.ss.un_750  ky.tk.un_643 ro.sr.uk_432 
  0x49000f0d, 0x484425a4, 0x1137480c, 0x22000707,   // lv.to.un_540 mn.kk.tt_433  tt.ba.ro_543 it.oc.un_420 
  0x1f001908, 0x1f002321, 0x2e00450c, 0x150425af,   // gl.cy.un_430 ca.cy.un_860  ln.fo.un_530 mn.ru.un_655 
  // [21050]
  0x580213a4, 0x620c2d0c, 0x43002b05, 0x340c35a9,   // et.da.om_433 sk.sv.kha_543  vi.ie.un_330 zu.sv.xh_544 
  0x0a432405, 0x13004a1a, 0x19000a36, 0x0a0411ee,   // eo.ie.pt_333 yo.et.un_760  pt.gl.un_AA0 ro.ru.mk_422 
  0x1b310c12, 0x19001f08, 0x641913a4, 0x2c212feb,   // sv.az.tr_654 cy.gl.un_430  et.gl.lg_433 su.jw.fy_662 
  0x21007904, 0x31190a55, 0x19000c0c, 0x630c13a4,   // war.jw.un_320 pt.gl.az_442  sv.gl.un_530 et.sv.sco_433 
  // [21060]
  0x190a0c0c, 0x28003b14, 0x550c2da0, 0x0c672da4,   // sv.pt.gl_543 ks.sd.un_660  sk.sv.rw_322 sk.ak.sv_433 
  0x73005d05, 0x5e005d35, 0x130d1c13, 0x4a4921ad,   // ss.ny.un_330 ss.ts.un_A90  mr.ne.bh_665 jw.to.yo_643 
  0x48002802, 0x51000407, 0x646a6807, 0x1e1c6aec,   // sw.tt.un_220 fi.kl.un_420  ig.haw.lg_432 haw.id.ms_644 
  0x373823ad, 0x5e00492b, 0x53003e02, 0x08002407,   // ky.tk.ba_643 to.ts.un_980  rm.ht.un_220 eo.no.un_420 
  // [21070]
  0x440804a7, 0x0e180d07, 0x030f0912, 0x47002508,   // ru.uk.kk_532 cs.ga.is_432  pl.lv.nl_654 eu.sn.un_430 
  0x65275704, 0x5a180107, 0x0200fe19, 0x0c001a07,   // na.gd.gv_332 en.ga.sm_432  tlh.da.un_750 tl.sv.un_420 
  0x371d620c, 0x52006a0d, 0x24256955, 0x02fe4aaf,   // kha.la.st_543 haw.ha.un_540  mfe.eu.eo_442 yo.tlh.da_655 
  0x0c2bfea0, 0x65005a20, 0x0300650e, 0x036518a4,   // tlh.vi.sv_322 sm.gv.un_850  gv.nl.un_550 ga.gv.nl_433 
  // [21080]
  0xfe006213, 0x0e2e24ad, 0x251710af, 0x29006707,   // kha.tlh.un_650 eo.fo.is_643  lt.sr.eu_655 ak.sl.un_420 
  0x49004c07, 0x0a3c2555, 0x1c242f02, 0x0f00130c,   // wo.to.un_420 mn.ug.mk_442  su.eo.id_222 et.lv.un_530 
  0x28377307, 0x0e00420d, 0x10134c0c, 0x69025305,   // ny.st.sw_432 co.is.un_540  wo.et.lt_543 ht.da.mfe_333 
  0x6b272fa9, 0x653f03a0, 0x37006b04, 0x62376112,   // su.gd.ceb_544 nl.af.gv_322  ceb.st.un_320 za.st.kha_654 
  // [21090]
  0x3510040b, 0x5f1a6ba0, 0x37621e0c, 0x654b1d05,   // ru.be.tg_542 ceb.tl.tn_322  ms.kha.st_543 la.mi.gv_333 
  0xfc592508, 0x1f3308ad, 0x234404a0, 0x06202aa9,   // eu.rn.zzp_443 no.nn.cy_643  ru.kk.ky_322 mt.sq.de_544 
  0x631f38a0, 0x61001f22, 0xfc2e0ca0, 0x1c003707,   // tk.cy.sco_322 cy.za.un_870  sv.fo.zzp_322 st.id.un_420 
  0x03006305, 0x345e3555, 0x1a34350c, 0x345c3508,   // sco.nl.un_330 zu.ts.xh_442  zu.xh.tl_543 zu.sa.xh_443 
  // [210a0]
  0x400806ee, 0x366520ad, 0x156301a9, 0x062c40a0,   // de.no.lb_422 sq.gv.gn_643  en.sco.un_544 lb.fy.de_322 
  0x07483607, 0x1859550d, 0x30371507, 0x6700682a,   // ab.tt.bg_432 rw.rn.ga_554  un.ba.uz_432 ig.ak.un_970 
  0x16fe2e04, 0x3500380b, 0x374448a9, 0x31007613,   // fo.tlh.hr_332 tk.tg.un_520  tt.kk.ba_544 crs.az.un_650 
  0x461252a4, 0x380264ad, 0x5c001607, 0x1f2e0e04,   // ha.hu.qu_433 lg.da.tk_643  hr.sa.un_420 is.fo.cy_332 
  // [210b0]
  0x4a00450c, 0x3231205a, 0x2e5d0ea4, 0x251002ad,   // ln.yo.un_530 sq.az.bs_553  is.ss.fo_433 da.lt.eu_643 
  0x5a4976a6, 0x30443502, 0x17165c05, 0x3b2717ee,   // crs.to.sm_521 tg.kk.uz_222  sa.hr.sr_333 sr.gd.so_422 
  0x650e2e0c, 0x09004d0d, 0x33003f08, 0x13044dec,   // fo.is.gv_543 aa.pl.un_540  af.nn.un_430 aa.fi.et_644 
  0x651d1faf, 0x471f52a4, 0x521ffcec, 0x42001f0b,   // cy.la.gv_655 ha.cy.sn_433  zzp.cy.ha_644 cy.co.un_520 
  // [210c0]
  0x1f4755ee, 0x555247af, 0x4d005219, 0x2d790d0d,   // rw.sn.cy_422 sn.ha.rw_655  ha.aa.un_750 cs.war.sk_554 
  0x52471f04, 0x280955a4, 0x5d584207, 0x421d38a0,   // cy.sn.ha_332 rw.pl.sw_433  co.om.ss_432 tk.la.co_322 
  0x340d3508, 0x555939a4, 0x13251f04, 0x0f002513,   // zu.cs.xh_443 br.rn.rw_433  cy.eu.et_332 eu.lv.un_650 
  0x393512ee, 0xfc005508, 0x3e21690c, 0x5d731208,   // hu.zu.br_422 rw.zzp.un_430  mfe.jw.rm_543 hu.ny.ss_443 
  // [210d0]
  0x6a1239a4, 0x271f6b02, 0x650139a4, 0x35344fee,   // br.hu.haw_433 ceb.cy.gd_222  br.en.gv_433 bi.xh.zu_422 
  0x4d4752ad, 0x065548a4, 0x58654e08, 0x42000f08,   // ha.sn.aa_643 tt.rw.de_433  ay.gv.om_443 lv.co.un_430 
  0x5200581b, 0x47525fee, 0x0c045107, 0x544d51ec,   // om.ha.un_770 tn.ha.sn_422  kl.fi.sv_432 kl.aa.ik_644 
  0x073e010c, 0x0e2e020d, 0x1827fcad, 0x647312a7,   // en.rm.it_543 da.fo.is_554  zzp.gd.ga_643 hu.ny.lg_532 
  // [210e0]
  0x2d364a13, 0x1f3901a4, 0x12003922, 0x0364280c,   // yo.gn.sk_665 en.br.cy_433  br.hu.un_870 sw.lg.nl_543 
  0x48383760, 0x52483007, 0x4c464dec, 0x27254207,   // ba.tk.tt_664 uz.tt.ha_432  aa.qu.wo_644 co.eu.gd_432 
  0x19313b0d, 0x64397309, 0x0659555a, 0x52461ea4,   // so.az.gl_554 ny.br.lg_444  rw.rn.de_553 ms.qu.ha_433 
  0x3b003c14, 0x12000a0e, 0x464c01a4, 0x231f1aa4,   // ug.ks.un_660 pt.hu.un_550  en.wo.qu_433 tl.cy.ca_433 
  // [210f0]
  0x02270812, 0x1d002719, 0x271a33a0, 0x79126b09,   // no.gd.da_654 gd.la.un_750  nn.tl.gd_322 ceb.hu.war_444 
  0x36510207, 0x0d1219a7, 0x21002907, 0x65002308,   // da.kl.gn_432 gl.hu.cs_532  sl.jw.un_420 ca.gv.un_430 
  0x0600181a, 0x020612a4, 0x2718650d, 0x5739030c,   // ga.de.un_760 hu.de.da_433  gv.ga.gd_554 nl.br.na_543 
  0x12796e04, 0x33084faf, 0x6e000c0e, 0x15033955,   // hmn.war.hu_332 bi.no.nn_655  sv.hmn.un_550 br.nl.un_442 
  // [21100]
  0x5000fe04, 0x431a3f13, 0x36002908, 0x0a69530c,   // tlh.fj.un_320 af.tl.ie_665  sl.gn.un_430 ht.mfe.pt_543 
  0x3f4c08a4, 0x576e3f0d, 0x08126b0c, 0xfc00021b,   // no.wo.af_433 af.hmn.na_554  ceb.hu.no_543 da.zzp.un_770 
  0x122e0eec, 0x34000705, 0x070a43a9, 0x19252007,   // is.fo.hu_644 it.xh.un_330  ie.pt.it_544 sq.eu.gl_432 
  0x36684cad, 0x42366804, 0x36697607, 0x57496908,   // wo.ig.gn_643 ig.gn.co_332  crs.mfe.gn_432 mfe.to.na_443 
  // [21110]
  0x363949af, 0x39430607, 0x1cfe60a7, 0x38303307,   // to.br.gn_655 de.ie.br_432  vo.tlh.id_532 nn.uz.tk_432 
  0x1b381ea0, 0x2f3568ad, 0x1a195207, 0x520225a4,   // ms.tk.tr_322 ig.zu.su_643  ha.gl.tl_432 eu.da.ha_433 
  0x313027ad, 0x150646ec, 0x1f3b6508, 0x2f15340b,   // gd.uz.az_643 qu.de.un_644  gv.so.cy_443 xh.su.un_520 
  0x3831300b, 0x38116ba4, 0x3b58650c, 0x315830af,   // uz.az.tk_542 ceb.ro.tk_433  gv.om.so_543 uz.om.az_655 
  // [21120]
  0x350a0804, 0x7650fc0c, 0x5e5d6408, 0x205c1309,   // uk.mk.tg_332 zzp.fj.crs_543  lg.ss.ts_443 et.sa.sq_444 
  0x1b383009, 0x20085ca4, 0x11104202, 0x2e313007,   // uz.tk.tr_444 sa.no.sq_433  co.lt.ro_222 uz.az.fo_432 
  0x483879af, 0x09005619, 0x0410360c, 0x08300aee,   // war.tk.tt_655 mg.pl.un_750  ab.be.ru_543 mk.uz.uk_422 
  0x53000908, 0x1a27300c, 0x6b790a04, 0xfc006820,   // pl.ht.un_430 uz.gd.tl_543  pt.war.ceb_332 ig.zzp.un_850 
  // [21130]
  0x79386b08, 0xfc3830a4, 0x631501af, 0x0d0160a0,   // ceb.tk.war_443 uz.tk.zzp_433  en.sco.un_650 vo.en.cs_322 
  0x1100730c, 0x241d420e, 0x5c00540d, 0x190a0509,   // ny.ro.un_530 co.la.eo_555  ik.sa.un_540 fr.pt.gl_444 
  0x0d180e08, 0xfc004202, 0x6500682c, 0x3713570c,   // is.ga.cs_443 co.zzp.un_220  ig.gv.un_990 na.et.st_543 
  0x051320a0, 0x231715a7, 0x53394309, 0x28471f0c,   // sq.et.fr_322 un.sr.ky_532  ie.br.ht_444 cy.sn.sw_543 
  // [21140]
  0x0a100807, 0x3b000d08, 0x3c003705, 0x13185a02,   // uk.be.mk_432 ne.ks.un_430  ba.ug.un_330 sm.ga.et_222 
  0x4410230c, 0x28301207, 0x043f0355, 0x18002a0c,   // ky.be.kk_543 ur.uz.sd_432  nl.af.fi_442 mt.ga.un_530 
  0x0f005104, 0x03793f07, 0x5a4802a0, 0x23003023,   // kl.lv.un_320 af.war.nl_432  da.tt.sm_322 uz.ky.un_880 
  0x3f1351a4, 0x135879a0, 0x20122fac, 0x322820a6,   // kl.et.af_433 war.om.et_322  su.hu.sq_632 sq.sw.bs_521 
  // [21150]
  0x1f0e2e0c, 0x2e231f0c, 0x735864ee, 0x0e2f6907,   // fo.is.cy_543 cy.ca.fo_543  lg.om.ny_422 mfe.su.is_432 
  0x27201f5a, 0xfa00241a, 0x1f000e02, 0x0e2e3e5a,   // cy.sq.gd_553 eo.nr.un_760  is.cy.un_220 rm.fo.is_553 
  0x22697608, 0x302335af, 0x44233404, 0x4300280d,   // crs.mfe.oc_443 tg.ky.uz_655  ps.ky.kk_332 sw.ie.un_540 
  0x24693eec, 0x09002d1b, 0x483844a7, 0x28001a08,   // rm.mfe.eo_644 sk.pl.un_770  kk.tk.tt_532 tl.sw.un_430 
  // [21160]
  0x3e2223ee, 0x1544040c, 0x35082304, 0x190b12af,   // ca.oc.rm_422 ru.kk.un_543  ky.uk.tg_332 hu.es.gl_655 
  0x30000911, 0x270209a7, 0x013ffc0c, 0x6a494d0c,   // pl.uz.un_630 pl.da.gd_532  zzp.af.en_543 aa.to.haw_543 
  0x3b4d58af, 0x11003407, 0x250b5e0c, 0x3f3b65ec,   // om.aa.so_655 xh.ro.un_420  ts.es.eu_543 gv.so.af_644 
  0x13634008, 0x3b34580c, 0x5830feec, 0x79020913,   // lb.sco.et_443 om.xh.so_543  tlh.uz.om_644 pl.da.war_665 
  // [21170]
  0x4cfa3412, 0x73004523, 0x103f0d11, 0x2d1b25ec,   // xh.nr.wo_654 ln.ny.un_880  cs.af.lt_653 eu.tr.sk_644 
  0x1a5e39a4, 0x6a4a5aad, 0x2f211c0d, 0x19584d07,   // br.ts.tl_433 sm.yo.haw_643  id.jw.su_554 aa.om.gl_432 
  0x2d0d09a6, 0x2c586311, 0x5800341b, 0x4cfa3408,   // pl.cs.sk_521 sco.om.fy_653  xh.om.un_770 xh.nr.wo_443 
  0x34fe3512, 0x36305e0c, 0x58004c2b, 0x52000907,   // zu.tlh.xh_654 ts.uz.gn_543  wo.om.un_980 pl.ha.un_420 
  // [21180]
  0x1d007907, 0x180209a4, 0xfc000920, 0x650313a4,   // war.la.un_420 pl.da.ga_433  pl.zzp.un_850 et.nl.gv_433 
  0x343f4d09, 0x655009a0, 0x60fe30af, 0x3f130107,   // aa.af.xh_444 pl.fj.gv_322  uz.tlh.vo_655 en.et.af_432 
  0x6a00fe19, 0x0c112fa0, 0x2a070a09, 0x443711af,   // tlh.haw.un_750 su.ro.sv_322  mk.bg.bo_444 ro.ba.kk_655 
  0x2500272b, 0x1d272512, 0x25042fa4, 0x2f25275a,   // gd.eu.un_980 eu.gd.la_654  su.fi.eu_433 gd.eu.su_553 
  // [21190]
  0x18002c09, 0x311b3e07, 0x252f18a4, 0x5f3773a4,   // fy.ga.un_440 rm.tr.az_432  ga.su.eu_433 ny.st.tn_433 
  0x2f6525ee, 0xfc5a7314, 0x3130460b, 0x11006513,   // eu.gv.su_422 ny.sm.zzp_666  qu.uz.az_542 gv.ro.un_650 
  0x01fc53a7, 0x2700252b, 0x4a1236a9, 0x0e36450b,   // ht.zzp.en_532 eu.gd.un_980  gn.hu.yo_544 ln.gn.is_542 
  0x252701a9, 0x4a07790c, 0x2e006402, 0x06001c02,   // en.gd.eu_544 war.it.yo_543  lg.fo.un_220 id.de.un_220 
  // [211a0]
  0x480c60a4, 0x4200642b, 0x332e4a0d, 0x67584909,   // vo.sv.tt_433 lg.co.un_980  yo.fo.nn_554 to.om.ak_444 
  0x15081105, 0x42646712, 0x271505ee, 0x353b6807,   // ro.uk.un_333 ak.lg.co_654  fr.gd.un_420 ig.so.zu_432 
  0x3200260c, 0x0c0413ec, 0x3c1844ec, 0x60000413,   // ia.bs.un_530 et.fi.sv_644  kk.ar.ug_644 fi.vo.un_650 
  0x0c383116, 0x400648a7, 0x64732807, 0x364a5708,   // az.tk.sv_752 tt.de.lb_532  sw.ny.lg_432 na.yo.gn_443 
  // [211b0]
  0x47006808, 0xfe572f12, 0x68005a23, 0x3453640c,   // ig.sn.un_430 su.na.tlh_654  sm.ig.un_880 lg.ht.xh_543 
  0x424c05a0, 0x092930a0, 0x55050212, 0x042338a9,   // fr.wo.co_322 uz.sl.pl_322  da.fr.rw_654 tk.ky.ru_544 
  0x1304360c, 0x5f002802, 0x104408a9, 0x3100fc02,   // gn.fi.et_543 sw.tn.un_220  uk.kk.be_544 zzp.az.un_220 
  0x283555a4, 0x15083505, 0x09001c2b, 0x380c4b04,   // rw.zu.sw_433 tg.uk.un_333  mr.hi.un_980 mi.sv.tk_332 
  // [211c0]
  0x38000c09, 0x2f560a04, 0x23001509, 0x192e0e0c,   // sv.tk.un_440 pt.mg.su_332  un.ky.un_440 is.fo.gl_543 
  0x302310a9, 0x4b000c08, 0x384006ee, 0x083017a4,   // be.ky.uz_544 sv.mi.un_430  de.lb.tk_422 sr.uz.uk_433 
  0x48fe1508, 0x402b2ca9, 0x3b481fa9, 0x48002b13,   // un.tlh.tt_443 fy.vi.lb_544  cy.tt.so_544 vi.tt.un_650 
  0x1f00460b, 0x0c000222, 0x2a4c58a0, 0x48092b07,   // qu.cy.un_520 da.sv.un_870  om.wo.mt_322 vi.pl.tt_432 
  // [211d0]
  0x2000670d, 0x2b611daf, 0x2d004b04, 0xfc001d0e,   // ak.sq.un_540 la.za.vi_655  mi.sk.un_320 la.zzp.un_550 
  0x231828ad, 0xfc001d19, 0x5c21270c, 0x4c00091b,   // sd.ar.ky_643 la.zzp.un_750  gd.jw.sa_543 pl.wo.un_770 
  0x406709ad, 0x190b36ec, 0xfc21430c, 0x3800480b,   // pl.ak.lb_643 gn.es.gl_644  ie.jw.zzp_543 tt.tk.un_520 
  0x4b040807, 0x36276512, 0x050a79a9, 0x4522050b,   // no.fi.mi_432 gv.gd.gn_654  war.pt.fr_544 fr.oc.ln_542 
  // [211e0]
  0x30170a05, 0x65182708, 0x182730af, 0x0527180c,   // mk.sr.uz_333 gd.ga.gv_443  uz.gd.ga_655 ga.gd.fr_543 
  0x4a00090c, 0x213b20ad, 0x44003d0c, 0x12045ca0,   // pl.yo.un_530 sq.so.jw_643  ku.kk.un_530 sa.fi.hu_322 
  0x5c1c28a4, 0x13492807, 0x051822ec, 0x2204510c,   // sw.id.sa_433 sw.to.et_432  oc.ga.fr_644 kl.fi.oc_543 
  0x19004604, 0x57272813, 0x09133607, 0x57005f1b,   // qu.gl.un_320 sw.gd.na_665  gn.et.pl_432 tn.na.un_770 
  // [211f0]
  0x48002e04, 0x48092e07, 0x65006019, 0x04003513,   // fo.tt.un_320 fo.pl.tt_432  vo.gv.un_750 tg.ru.un_650 
  0x53000907, 0x520c1f07, 0x48040c02, 0xfe2f35a0,   // pl.ht.un_420 cy.sv.ha_432  sv.fi.tt_222 zu.su.tlh_322 
  0x36091208, 0x57004e22, 0x44342307, 0x27003502,   // hu.pl.gn_443 ay.na.un_870  ky.ps.kk_432 zu.gd.un_220 
  0x0e000c0e, 0x182765ad, 0x0e1f2c08, 0x523b20a4,   // sv.is.un_550 gv.gd.ga_643  fy.cy.is_443 sq.so.ha_433 
  // [21200]
  0x04133e08, 0x1d652704, 0x13006008, 0x13002d09,   // rm.et.fi_443 gd.gv.la_332  vo.et.un_430 sk.et.un_440 
  0x5f1f3704, 0x0f171002, 0x48040802, 0x733528ee,   // st.cy.tn_332 lt.sr.lv_222  uk.ru.tt_222 sw.zu.ny_422 
  0x3b2830a0, 0x2800730e, 0x13400611, 0x49006407,   // uz.sw.so_322 ny.sw.un_550  de.lb.et_653 lg.to.un_420 
  0x130c0413, 0x5a2873af, 0x564a67af, 0x371bfc08,   // fi.sv.et_665 ny.sw.sm_655  ak.yo.mg_655 zzp.tr.st_443 
  // [21210]
  0x201f01a4, 0x13380c04, 0x1b123655, 0x3e130c16,   // en.cy.sq_433 sv.tk.et_332  gn.hu.tr_442 sv.et.rm_752 
  0x13004008, 0x1b243eee, 0x121b0e07, 0x39063202,   // lb.et.un_430 rm.eo.tr_422  is.tr.hu_432 bs.de.br_222 
  0x12006004, 0x4c383905, 0x682a4aad, 0x23384860,   // vo.hu.un_320 br.tk.wo_333  yo.mt.ig_643 tt.tk.ky_664 
  0x691e6008, 0x0f1f51af, 0x1340060d, 0x18000208,   // vo.ms.mfe_443 kl.cy.lv_655  de.lb.et_554 da.ga.un_430 
  // [21220]
  0x6a3468a9, 0x3f004a09, 0x36005b0d, 0x485a4912,   // ig.xh.haw_544 yo.af.un_440  sg.gn.un_540 to.sm.tt_654 
  0x271e1c04, 0x1300682b, 0x1f2e0e14, 0x1f000e13,   // id.ms.gd_332 ig.et.un_980  is.fo.cy_666 is.cy.un_650 
  0x2e0e3eec, 0x0c324004, 0x60004335, 0x32003f04,   // rm.is.fo_644 lb.bs.sv_332  ie.vo.un_A90 af.bs.un_320 
  0x5a6a490d, 0x15041704, 0x3c3004a4, 0x112c0fa7,   // to.haw.sm_554 sr.ru.un_332  ru.uz.ug_433 lv.fy.ro_532 
  // [21230]
  0x472c610c, 0x2c004020, 0x4900130d, 0x11006219,   // za.fy.sn_543 lb.fy.un_850  et.to.un_540 kha.ro.un_750 
  0x1e1c490c, 0x65003621, 0x131f4ba9, 0x13251260,   // to.id.ms_543 gn.gv.un_860  mi.cy.et_544 hu.eu.et_664 
  0x02005e0d, 0x12783709, 0x734e50a4, 0x251d5a0c,   // ts.da.un_540 st.ve.hu_444  fj.ay.ny_433 sm.la.eu_543 
  0x094b5eee, 0x4b5e73a4, 0x1d6a5eaf, 0x225c2a07,   // ts.mi.pl_422 ny.ts.mi_433  ts.haw.la_655 mt.sa.oc_432 
  // [21240]
  0x361a6b02, 0x2a1f5607, 0x092d56a0, 0x1a472f02,   // ceb.tl.gn_222 mg.cy.mt_432  mg.sk.pl_322 su.sn.tl_222 
  0x2f00090e, 0x073c3811, 0x2a0628a9, 0x376a49a9,   // pl.su.un_550 tk.ug.bg_653  sw.de.mt_544 to.haw.st_544 
  0x47097355, 0x5e121d08, 0x35005e0c, 0x3b6a4b13,   // ny.pl.sn_442 la.hu.ts_443  ts.zu.un_530 mi.haw.so_665 
  0x4b1312a7, 0x2f57210b, 0x5e3f4a08, 0x1c005e0c,   // hu.et.mi_532 jw.na.su_542  yo.af.ts_443 ts.id.un_530 
  // [21250]
  0x154e5e12, 0x5c000d20, 0x46003504, 0x19182da0,   // ts.ay.un_654 ne.sa.un_850  zu.qu.un_320 sk.ga.gl_322 
  0x04110705, 0x1100fe04, 0x35100a08, 0x48003035,   // bg.ro.ru_333 tlh.ro.un_320  mk.be.tg_443 uz.tt.un_A90 
  0x6e6301a9, 0x19005804, 0x0c3b650c, 0x1a4a54a4,   // en.sco.hmn_544 om.gl.un_320  gv.so.sv_543 ik.yo.tl_433 
  0x34301812, 0x25004a18, 0x18364a0d, 0x0f30610c,   // ar.uz.ps_654 yo.eu.un_740  yo.gn.ga_554 za.uz.lv_543 
  // [21260]
  0x582373a4, 0x3b304813, 0x020c24af, 0x38006b0e,   // ny.ca.om_433 tt.uz.so_665  eo.sv.da_655 ceb.tk.un_550 
  0x374844ad, 0x3e005c07, 0x2f392708, 0x763001a0,   // kk.tt.ba_643 sa.rm.un_420  gd.br.su_443 en.uz.crs_322 
  0x255535ad, 0x306b2707, 0x2f041c05, 0xfe375fa9,   // zu.rw.eu_643 gd.ceb.uz_432  id.fi.su_333 tn.st.tlh_544 
  0x040a3004, 0x355f3707, 0x55006813, 0x36002804,   // uz.mk.ru_332 st.tn.zu_432  ig.rw.un_650 sw.gn.un_320 
  // [21270]
  0x033f0614, 0x486855af, 0x1f00231b, 0x19006a13,   // de.af.nl_666 rw.ig.tt_655  ca.cy.un_770 haw.gl.un_650 
  0x0a1508a0, 0x261f65a4, 0x250a1d08, 0x1f57060c,   // uk.mk.un_320 gv.cy.ia_433  la.pt.eu_443 de.na.cy_543 
  0x3b1340a4, 0x30173c08, 0x3b4c5804, 0x2e0e2c04,   // lb.et.so_433 ug.sr.uz_443  om.wo.so_332 fy.is.fo_332 
  0x3b004009, 0x0c022e05, 0x3800550e, 0x584c20af,   // lb.so.un_440 fo.da.sv_333  rw.tk.un_550 sq.wo.om_655 
  // [21280]
  0x281b6707, 0x403f6511, 0x1b472855, 0x2431fe04,   // ak.tr.sw_432 gv.af.lb_653  sw.sn.tr_442 tlh.az.eo_332 
  0x0255590c, 0x02001019, 0x10353402, 0x5300370b,   // rn.rw.da_543 lt.da.un_750  xh.zu.lt_222 st.ht.un_520 
  0x294f6408, 0x133b4ca0, 0x16001504, 0x401029a0,   // lg.bi.sl_443 wo.so.et_322  un.hr.un_320 sl.lt.lb_322 
  0x06004a04, 0x020c080c, 0x1d4063a4, 0x302d1e08,   // yo.de.un_320 no.sv.da_543  sco.lb.la_433 ms.sk.uz_443 
  // [21290]
  0x2a003e07, 0x48004608, 0x2c40120b, 0x3f0363a0,   // rm.mt.un_420 qu.tt.un_430  hu.lb.fy_542 sco.nl.af_322 
  0x2a380a07, 0x391163ee, 0x25350709, 0x1800390d,   // pt.tk.mt_432 sco.ro.br_422  bg.tg.mn_444 br.ga.un_540 
  0x35550aa4, 0x1c002704, 0x39022cad, 0x0d345da4,   // pt.rw.zu_433 gd.id.un_320  fy.da.br_643 ss.xh.cs_433 
  0x5d60350c, 0x3d2334a0, 0x793b290d, 0x2c036313,   // zu.vo.ss_543 ps.ky.ku_322  sl.so.war_554 sco.nl.fy_665 
  // [212a0]
  0x5328690c, 0x11002505, 0x443704a7, 0x45006912,   // mfe.sw.ht_543 eu.ro.un_330  ru.ba.kk_532 mfe.ln.un_640 
  0x63006905, 0x05002d07, 0x0d092908, 0x69340d07,   // mfe.sco.un_330 sk.fr.un_420  sl.pl.cs_443 cs.xh.mfe_432 
  0x04004409, 0x4b3f6aec, 0x53003f35, 0x534c5aad,   // kk.ru.un_440 haw.af.mi_644  af.ht.un_A90 sm.wo.ht_643 
  0x395349a0, 0x693f4c0c, 0x055763ec, 0x61655012,   // to.ht.br_322 wo.af.mfe_543  sco.na.fr_644 fj.gv.za_654 
  // [212b0]
  0x23635a5a, 0x393f61a9, 0x350a1755, 0x40000321,   // sm.sco.ca_553 za.af.br_544  sr.mk.tg_442 nl.lb.un_860 
  0x15000a14, 0xfc65385a, 0x113f400e, 0x3802fc0c,   // mk.un.un_660 tk.gv.zzp_553  lb.af.ro_555 zzp.da.tk_543 
  0x3f405312, 0x233044ad, 0x38fe65ad, 0x65006413,   // ht.lb.af_654 kk.uz.ky_643  gv.tlh.tk_643 lg.gv.un_650 
  0x0a005022, 0x3f004033, 0x2f0264ad, 0x68735507,   // fj.pt.un_870 lb.af.un_A70  lg.da.su_643 rw.ny.ig_432 
  // [212c0]
  0x383b6411, 0xfc1038a0, 0x6400551a, 0x3525300c,   // lg.so.tk_653 tk.lt.zzp_322  rw.lg.un_760 uz.mn.tg_543 
  0x21285e02, 0x2cfc02a0, 0x4c2f2107, 0x1100380d,   // ts.sw.jw_222 da.zzp.fy_322  jw.su.wo_432 tk.ro.un_540 
  0xfc000509, 0x641a0904, 0x0c10fcec, 0x011ffc0c,   // fr.zzp.un_440 pl.tl.lg_332  zzp.lt.sv_644 zzp.cy.en_543 
  0x38fc10a4, 0x30482355, 0x5c001a02, 0x0a0448a0,   // lt.zzp.tk_433 ky.tt.uz_442  tl.sa.un_220 tt.ru.mk_322 
  // [212d0]
  0x1a4c28ee, 0x12515407, 0x06fe1f12, 0x0d001812,   // sw.wo.tl_422 ik.kl.hu_432  cy.tlh.de_654 ga.cs.un_640 
  0x35003814, 0x1f190b55, 0x2f000d05, 0x5c1d26ee,   // tk.tg.un_660 es.gl.cy_442  cs.su.un_330 ia.la.sa_422 
  0x1213600c, 0x305a51a0, 0x0c0833ad, 0x40653302,   // vo.et.hu_543 kl.sm.uz_322  nn.no.sv_643 nn.gv.lb_222 
  0x28004507, 0x5a006404, 0x1b2d3105, 0x233525a0,   // ln.sw.un_420 lg.sm.un_320  az.sk.tr_333 mn.tg.ky_322 
  // [212e0]
  0x06033fec, 0x02000e14, 0x0f5c1707, 0x222763a9,   // af.nl.de_644 is.da.un_660  sr.sa.lv_432 sco.gd.oc_544 
  0x570a63ec, 0x18631c07, 0x311b57a9, 0x18050107,   // sco.pt.na_644 id.sco.ga_432  na.tr.az_544 en.fr.ga_432 
  0x23221809, 0x40554507, 0x5c47630d, 0x0247500c,   // ga.oc.ca_444 ln.rw.lb_432  sco.sn.sa_554 fj.sn.da_543 
  0x633e04af, 0x2f2263ec, 0x4b27180c, 0x032c3fac,   // fi.rm.sco_655 sco.oc.su_644  ga.gd.mi_543 af.fy.nl_632 
  // [212f0]
  0x18275c55, 0x25040804, 0x1800fe0e, 0x5c00272b,   // sa.gd.ga_442 uk.ru.mn_332  tlh.ga.un_550 gd.sa.un_980 
  0x3f6a0aa9, 0x30051f04, 0x320f0da0, 0x2b5a0212,   // pt.haw.af_544 cy.fr.uz_332  cs.lv.bs_322 da.sm.vi_654 
  0x13120b04, 0x3500361a, 0x25070aee, 0x381b065a,   // es.hu.et_332 ab.tg.un_760  mk.bg.mn_422 de.tr.tk_553 
  0x29003209, 0x1e6327a4, 0x10172404, 0x0e0c1fa4,   // bs.sl.un_440 gd.sco.ms_433  eo.sr.lt_332 cy.sv.is_433 
  // [21300]
  0x29004714, 0x2d0d040c, 0x32175ca0, 0x5c101304,   // sn.sl.un_660 fi.cs.sk_543  sa.sr.bs_322 et.lt.sa_332 
  0x0807150c, 0x553f2aa0, 0x122a130d, 0x20043b0c,   // un.bg.uk_543 mt.af.rw_322  et.mt.hu_554 so.fi.sq_543 
  0x2c03120c, 0x191233a9, 0x0c041309, 0x654c07ad,   // hu.nl.fy_543 nn.hu.gl_544  et.fi.sv_444 it.wo.gv_643 
  0x083656a7, 0x13005809, 0x016506a0, 0x65391f0c,   // mg.gn.no_532 om.et.un_440  de.gv.en_322 cy.br.gv_543 
  // [21310]
  0x42241d05, 0x39600607, 0x154c0107, 0x1b116911,   // la.eo.co_333 de.vo.br_432  en.wo.un_432 mfe.ro.tr_653 
  0x3913010b, 0x2a3f0304, 0x4620fe08, 0x401f01a4,   // en.et.br_542 nl.af.mt_332  tlh.sq.qu_443 en.cy.lb_433 
  0x20fc1dee, 0xfe004805, 0x35083c04, 0x27002a0c,   // la.zzp.sq_422 tt.tlh.un_330  ug.uk.tg_332 mt.gd.un_530 
  0x0e1f5b0d, 0xfe52fc04, 0x042c0302, 0x1b005207,   // sg.cy.is_554 zzp.ha.tlh_332  nl.fy.fi_222 ha.tr.un_420 
  // [21320]
  0x0f5d5207, 0x3b58040d, 0x10252305, 0x21581e0e,   // ha.ss.lv_432 fi.om.so_554  ky.mn.be_333 ms.om.jw_555 
  0x6a734aa9, 0x0f005d04, 0x6b1c58ad, 0x58041e0b,   // yo.ny.haw_544 ss.lv.un_320  om.id.ceb_643 ms.fi.om_542 
  0x042f1ea9, 0x1500340d, 0x1b31680d, 0x4d422fec,   // ms.su.fi_544 xh.un.un_540  ig.az.tr_554 su.co.aa_644 
  0x2f1e3b08, 0x1e004d1a, 0x582f3bec, 0x543f04a4,   // so.ms.su_443 aa.ms.un_760  so.su.om_644 fi.af.ik_433 
  // [21330]
  0x4c3b58a9, 0x330802a7, 0x65041a08, 0x3b1a28ee,   // om.so.wo_544 da.no.nn_532  tl.fi.gv_443 sw.tl.so_422 
  0x4268240d, 0x34352511, 0x070811af, 0x4059550d,   // eo.ig.co_554 eu.zu.xh_653  ro.uk.bg_655 rw.rn.lb_554 
  0x7347780c, 0x285557af, 0x422a3ead, 0x214a1aee,   // ve.sn.ny_543 na.rw.sw_655  rm.mt.co_643 tl.yo.jw_422 
  0x302e0ea7, 0xfc2d3502, 0x400612ec, 0x440437a4,   // is.fo.uz_532 zu.sk.zzp_222  hu.de.lb_644 ba.ru.kk_433 
  // [21340]
  0x2d0e3804, 0x0d35340e, 0x65006819, 0x1f005e21,   // tk.is.sk_332 xh.zu.cs_555  ig.gv.un_750 ts.cy.un_860 
  0x5e000113, 0x114265ee, 0x0e2e1c12, 0x460e2e11,   // en.ts.un_650 gv.co.ro_422  id.fo.is_654 fo.is.qu_653 
  0x28003c09, 0x332d0d0d, 0x5efc3e08, 0x0a440704,   // ug.sd.un_440 cs.sk.nn_554  rm.zzp.ts_443 bg.kk.mk_332 
  0x65631da0, 0x251a79ec, 0x06383e02, 0x29006821,   // la.sco.gv_322 war.tl.eu_644  rm.tk.de_222 ig.sl.un_860 
  // [21350]
  0x22005004, 0x081017af, 0x02162ea6, 0x552809a7,   // fj.oc.un_320 sr.be.uk_655  fo.hr.da_521 pl.sw.rw_532 
  0x283435ee, 0x36002b0d, 0x2b003609, 0x45002b1a,   // zu.xh.sw_422 vi.gn.un_540  gn.vi.un_440 vi.ln.un_760 
  0x47000214, 0x35005904, 0x281809ad, 0xfc00290d,   // da.sn.un_660 rn.zu.un_320  pl.ga.sw_643 sl.zzp.un_540 
  0x34123da9, 0x4b000604, 0x27000e07, 0x023f5707,   // ku.ur.ps_544 de.mi.un_320  is.gd.un_420 na.af.da_432 
  // [21360]
  0x06004f04, 0x09363b60, 0x48001f04, 0x532e2907,   // bi.de.un_320 so.gn.pl_664  cy.tt.un_320 sl.fo.ht_432 
  0x650e2c07, 0x021d65ec, 0x240802ee, 0x07300405,   // fy.is.gv_432 gv.la.da_644  da.no.eo_422 ru.uz.bg_333 
  0x65020ea4, 0x211f3807, 0x062223ee, 0x5d4d73a4,   // is.da.gv_433 tk.cy.jw_432  ca.oc.de_422 ny.aa.ss_433 
  0x361c26ee, 0x20006408, 0x0b3473a7, 0x2173590c,   // ia.id.gn_422 lg.sq.un_430  ny.xh.es_532 rn.ny.jw_543 
  // [21370]
  0x2c000d07, 0x73474ca9, 0x1a005304, 0x1d644aa0,   // cs.fy.un_420 wo.sn.ny_544  ht.tl.un_320 yo.lg.la_322 
  0x2400390c, 0x616412af, 0x62561208, 0x22181207,   // br.eo.un_530 hu.lg.za_655  hu.mg.kha_443 hu.ga.oc_432 
  0x0262125a, 0x611d39a4, 0x39003312, 0x5a0742ee,   // hu.kha.da_553 br.la.za_433  nn.br.un_640 co.it.sm_422 
  0x53006207, 0x2439120c, 0x39211fa4, 0x0b002f05,   // kha.ht.un_420 hu.br.eo_543  cy.jw.br_433 su.es.un_330 
  // [21380]
  0x401f39a9, 0x12005223, 0x50005611, 0x04004912,   // br.cy.lb_544 ha.hu.un_880  mg.fj.un_630 to.fi.un_640 
  0x2f38390c, 0x18282112, 0x23003511, 0x0912390c,   // br.tk.su_543 fa.sd.ar_654  tg.ky.un_630 br.hu.pl_543 
  0x12396baf, 0x456b0207, 0x15004c07, 0x3f330e0c,   // ceb.br.hu_655 da.ceb.ln_432  wo.un.un_420 is.nn.af_543 
  0x4f00121a, 0x394c400c, 0x6a551b04, 0x3f39330c,   // hu.bi.un_760 lb.wo.br_543  tr.rw.haw_332 nn.br.af_543 
  // [21390]
  0x55642808, 0x2a5d64ee, 0x190a35a4, 0x56043608,   // sw.lg.rw_443 lg.ss.mt_422  zu.pt.gl_433 gn.fi.mg_443 
  0x50360409, 0x0400560d, 0x28005e07, 0x67595508,   // fi.gn.fj_444 mg.fi.un_540  ts.sw.un_420 rw.rn.ak_443 
  0x35595514, 0x21001502, 0x34007313, 0x2d0d11ee,   // rw.rn.zu_666 un.jw.un_220  ny.xh.un_650 ro.cs.sk_422 
  0x152718a7, 0x5d4968ad, 0x230815a0, 0x4f111f12,   // ga.gd.un_532 ig.to.ss_643  un.uk.ky_322 cy.ro.bi_654 
  // [213a0]
  0x4b6e25a9, 0x506a4912, 0x3e100f60, 0x220963a0,   // eu.hmn.mi_544 to.haw.fj_654  lv.lt.rm_664 sco.pl.oc_322 
  0x2c05150c, 0x496a1c11, 0x255a4912, 0x1f2223ad,   // un.fr.fy_543 id.haw.to_653  to.sm.eu_654 ca.oc.cy_643 
  0x4f004935, 0x5d1d34a7, 0xfe495a07, 0x2f00500c,   // to.bi.un_A90 xh.la.ss_532  sm.to.tlh_432 fj.su.un_530 
  0x692402af, 0x3430120d, 0x22501c07, 0x0d000a07,   // da.eo.mfe_655 ur.uz.ps_554  id.fj.oc_432 pt.cs.un_420 
  // [213b0]
  0x010269ee, 0x3e49050c, 0x225a490c, 0x252c1fa4,   // mfe.da.en_422 fr.to.rm_543  to.sm.oc_543 cy.fy.eu_433 
  0x230937a0, 0x116e4504, 0x506e52a9, 0x112b6e04,   // st.pl.ca_322 ln.hmn.ro_332  ha.hmn.fj_544 hmn.vi.ro_332 
  0x4b506eac, 0x2508150e, 0x2b6e110e, 0x5a496aec,   // hmn.fj.mi_632 un.uk.mn_555  ro.hmn.vi_555 haw.to.sm_644 
  0x20586e02, 0x506e22a4, 0x78216aaf, 0x190b22a4,   // hmn.om.sq_222 oc.hmn.fj_433  haw.jw.ve_655 oc.es.gl_433 
  // [213c0]
  0x4b496eaf, 0x32160ba0, 0x0b002822, 0x695302a4,   // hmn.to.mi_655 es.hr.bs_322  sw.es.un_870 da.ht.mfe_433 
  0x35005602, 0x5553290c, 0x3536255a, 0x4a00fe0d,   // mg.zu.un_220 sl.ht.rw_543  mn.ab.tg_553 tlh.yo.un_540 
  0x643055a9, 0x2a00650c, 0x34684ca4, 0x2a18fc02,   // rw.uz.lg_544 gv.mt.un_530  wo.ig.xh_433 zzp.ga.mt_222 
  0x53001e05, 0x0e003b09, 0x196b1aad, 0x30002405,   // ms.ht.un_330 so.is.un_440  tl.ceb.gl_643 eo.uz.un_330 
  // [213d0]
  0x1a375faf, 0x355369ee, 0x3500231b, 0x39000512,   // tn.st.tl_655 mfe.ht.zu_422  ky.tg.un_770 fr.br.un_640 
  0x30041707, 0x04350805, 0x422f4504, 0x15043808,   // sr.ru.uz_432 uk.tg.ru_333  ln.su.co_332 tk.ru.un_443 
  0x4c1d3e0c, 0x3f1b57ee, 0xfe182c02, 0x4f001b14,   // rm.la.wo_543 na.tr.af_422  fy.ga.tlh_222 tr.bi.un_660 
  0x190b1baf, 0x652c0307, 0x15001308, 0x10040a09,   // tr.es.gl_655 nl.fy.gv_432  et.un.un_430 mk.ru.be_444 
  // [213e0]
  0x1b002704, 0x31041ba9, 0x17006908, 0x6b630107,   // gd.tr.un_320 tr.fi.az_544  mfe.sr.un_430 en.sco.ceb_432 
  0x19001b07, 0x48130c0c, 0x5955110d, 0x37233609,   // tr.gl.un_420 sv.et.tt_543  ro.rw.rn_554 ab.ky.ba_444 
  0x23190e04, 0x38483104, 0x362b5608, 0x2bfc3fa9,   // is.gl.ca_332 az.tt.tk_332  mg.vi.gn_443 af.zzp.vi_544 
  0x4a181208, 0x311f480c, 0x080a070b, 0x3b1127a0,   // hu.ga.yo_443 tt.cy.az_543  bg.mk.uk_542 gd.ro.so_322 
  // [213f0]
  0x42071da6, 0x132c4002, 0x2f1c1e11, 0x1515350e,   // la.it.co_521 lb.fy.et_222  ms.id.su_653 tg.un.un_550 
  0x55003409, 0x22272f07, 0x62006508, 0x5700631a,   // xh.rw.un_440 su.gd.oc_432  gv.kha.un_430 sco.na.un_760 
  0x12213b13, 0x103035ad, 0x1b190ba9, 0x35442504,   // ks.fa.ur_665 tg.uz.be_643  es.gl.tr_544 mn.kk.tg_332 
  0x471009ad, 0x2b003b07, 0x111b65a7, 0x393e10a0,   // pl.lt.sn_643 so.vi.un_420  gv.tr.ro_532 lt.rm.br_322 
  
  // [21400]
  0x100f285a, 0x2a582409, 0x2c5a49ee, 0x0b240408,   // sw.lv.lt_553 eo.om.mt_444  to.sm.fy_422 fi.eo.es_443 
  0x282404ec, 0x1d512612, 0x09240f07, 0x44150404,   // fi.eo.sw_644 ia.kl.la_654  lv.eo.pl_432 ru.kk.un_320 
  0x1d650ca7, 0x13002402, 0x3065fc0c, 0x39321ba0,   // sv.gv.la_532 eo.et.un_220  zzp.gv.uz_543 tr.bs.br_322 
  0x284b6507, 0x36002e18, 0x28044712, 0x304201a4,   // gv.mi.sw_432 fo.gn.un_740  sn.fi.sw_654 en.co.uz_433 
  // [21410]
  0x04000a2a, 0x03045aee, 0x19fc0b0c, 0x4b545008,   // pt.fi.un_970 sm.fi.nl_422  es.zzp.gl_543 fj.ik.mi_443 
  0x190b23ec, 0x19000a0d, 0x5a421d04, 0x10033f0d,   // ca.es.gl_644 pt.gl.un_540  la.co.sm_332 af.nl.lt_554 
  0x04440704, 0x1d2305ee, 0x040f13a0, 0x250804a0,   // bg.kk.ru_332 fr.ca.la_422  et.lv.fi_322 ru.uk.mn_322 
  0x245c02a0, 0x380431a0, 0x632201a4, 0x2b0123ee,   // da.sa.eo_322 az.fi.tk_322  en.oc.sco_433 ca.en.vi_422 
  // [21420]
  0x495a6508, 0x1e003202, 0x08441009, 0x313038a9,   // gv.sm.to_443 bs.ms.un_220  be.kk.uk_444 tk.uz.az_544 
  0x080c12ee, 0xfe000414, 0x03130404, 0x5c263e0d,   // hu.sv.no_422 fi.tlh.un_660  fi.et.nl_332 rm.ia.sa_554 
  0x13006312, 0x17043655, 0x3139130c, 0x30173cad,   // sco.et.un_640 ab.ru.sr_442  et.br.az_543 ug.sr.uz_643 
  0x0d242907, 0x08303ca9, 0x32162c05, 0x381517a4,   // sl.eo.cs_432 ug.uz.uk_544  fy.hr.bs_333 sr.tk.un_430 
  // [21430]
  0x0c24125a, 0x50001104, 0x3d004407, 0x135c0cee,   // hu.eo.sv_553 ro.fj.un_320  kk.ku.un_420 sv.sa.et_422 
  0x23000805, 0x370830a0, 0x48383105, 0x0e001d08,   // uk.ky.un_330 uz.uk.ba_322  az.tk.tt_333 la.is.un_430 
  0x471a1da0, 0x5a001d07, 0x170408ec, 0x1248130e,   // la.tl.sn_322 la.sm.un_420  uk.ru.sr_644 et.tt.hu_555 
  0x20000411, 0xfe64680c, 0x3033680c, 0x6700520d,   // fi.sq.un_630 ig.lg.tlh_543  ig.nn.uz_543 ha.ak.un_540 
  // [21440]
  0x46001c02, 0x390702a0, 0x6768570c, 0x1c685104,   // id.qu.un_220 da.it.br_322  na.ig.ak_543 kl.ig.id_332 
  0x15151104, 0x230a3702, 0x5900552b, 0x01fc0307,   // ro.un.un_320 ba.mk.ky_222  rw.rn.un_980 nl.zzp.en_432 
  0x3f35fea4, 0x014006a4, 0x131b3805, 0x04135aa4,   // tlh.zu.af_433 de.lb.en_433  tk.tr.et_333 sm.et.fi_433 
  0x043817a4, 0x063840ad, 0x221b0a04, 0x1f3f6309,   // sr.tk.ru_433 lb.tk.de_643  pt.tr.oc_332 sco.af.cy_444 
  // [21450]
  0x383f1b0c, 0x56692f0d, 0x59006119, 0x1d051f02,   // tr.af.tk_543 su.mfe.mg_554  za.rn.un_750 cy.fr.la_222 
  0x495164a7, 0x13045112, 0x05536909, 0x58005005,   // lg.kl.to_532 kl.fi.et_654  mfe.ht.fr_444 fj.om.un_330 
  0x5a6405ad, 0x1d02fc07, 0x36002321, 0x121b3813,   // fr.lg.sm_643 zzp.da.la_432  ky.ab.un_860 tk.tr.hu_665 
  0x484d1ba7, 0x2c680307, 0x5e3813a4, 0x494b3705,   // tr.aa.tt_532 nl.ig.fy_432  et.tk.ts_433 st.mi.to_333 
  // [21460]
  0x1b042004, 0x05007309, 0x78003722, 0x2f212004,   // sq.fi.tr_332 ny.fr.un_440  st.ve.un_870 sq.jw.su_332 
  0x133f1b07, 0x6a782da0, 0x041328a4, 0x48070a0b,   // tr.af.et_432 sk.ve.haw_322  sw.et.fi_433 mk.bg.tt_542 
  0x6a2d0d08, 0x2800360d, 0x5a640404, 0x28132407,   // cs.sk.haw_443 gn.sw.un_540  fi.lg.sm_332 eo.et.sw_432 
  0x15233c0c, 0x2d362012, 0x04135112, 0x59375ead,   // ug.ky.un_543 sq.gn.sk_654  kl.et.fi_654 ts.st.rn_643 
  // [21470]
  0x2118340e, 0x1e004607, 0x3c44120c, 0x49673712,   // ps.ar.fa_555 qu.ms.un_420  ur.kk.ug_543 st.ak.to_654 
  0x2f37280c, 0xfe00730e, 0x374b6a07, 0x354273ee,   // sw.st.su_543 ny.tlh.un_550  haw.mi.st_432 ny.co.zu_422 
  0x07300aa4, 0x73005c2a, 0x48005a07, 0x60381b55,   // mk.uz.bg_433 sa.ny.un_970  sm.tt.un_420 tr.tk.vo_442 
  0x595538a4, 0x69530107, 0x090238a0, 0x5955100c,   // tk.rw.rn_433 en.ht.mfe_432  tk.da.pl_322 lt.rw.rn_543 
  // [21480]
  0x7638790c, 0x1d1f5c07, 0x303b10af, 0x35fe730c,   // war.tk.crs_543 sa.cy.la_432  lt.so.uz_655 ny.tlh.zu_543 
  0x30006505, 0x48381b09, 0x103c1505, 0x38095904,   // gv.uz.un_330 tr.tk.tt_444  un.ug.be_333 rn.pl.tk_332 
  0x0d002521, 0x04005c04, 0x24002505, 0x2e50fcac,   // eu.cs.un_860 sa.fi.un_320  eu.eo.un_330 zzp.fj.fo_632 
  0x495e6a0d, 0x23190a02, 0x5a49500d, 0x383669a4,   // haw.ts.to_554 pt.gl.ca_222  fj.to.sm_554 mfe.gn.tk_433 
  // [21490]
  0x105c465a, 0xfc000204, 0x376a3b0c, 0x3b1e3104,   // qu.sa.lt_553 da.zzp.un_320  so.haw.st_543 az.ms.so_332 
  0x76536955, 0x153511af, 0x5c001321, 0xfc495a07,   // mfe.ht.crs_442 ro.tg.un_655  bh.sa.un_860 sm.to.zzp_432 
  0x455f37a9, 0x10003822, 0x30310e0c, 0x0715010b,   // st.tn.ln_544 tk.lt.un_870  is.az.uz_543 en.it.un_520 
  0x380e1b09, 0x12291da9, 0x382e0e0d, 0x647347ac,   // tr.is.tk_444 la.sl.hu_544  is.fo.tk_554 sn.ny.lg_632 
  // [214a0]
  0x5f491112, 0x051827a0, 0x15480455, 0x30383108,   // ro.to.tn_654 gd.ga.fr_322  ru.tt.un_442 az.tk.uz_443 
  0x48347304, 0x4d0e1fa4, 0x73615ea4, 0x64001f13,   // ny.xh.tt_332 cy.is.aa_433  ts.za.ny_433 cy.lg.un_650 
  0x3f2847ac, 0x0b4c30ee, 0x10001502, 0x301f31a0,   // sn.sw.af_632 uz.wo.es_422  un.lt.un_220 az.cy.uz_322 
  0x38152ead, 0x4d3b580e, 0x0a2624a4, 0x291b30ee,   // fo.tk.un_630 om.so.aa_555  eo.ia.pt_433 uz.tr.sl_422 
  // [214b0]
  0xfe3b5805, 0x2924fe0b, 0x735e4c12, 0x343c180b,   // om.so.tlh_333 tlh.eo.sl_542  wo.ts.ny_654 ar.ug.ps_542 
  0x044a2404, 0x495a10a0, 0x462d0d08, 0x1b3130af,   // eo.yo.fi_332 lt.sm.to_322  cs.sk.qu_443 uz.az.tr_655 
  0x11004705, 0xfe002908, 0x38303112, 0x23241f07,   // sn.ro.un_330 sl.tlh.un_430  az.uz.tk_654 cy.eo.ca_432 
  0x362d0907, 0x3b006812, 0x40060211, 0x245c29ee,   // pl.sk.gn_432 ig.so.un_640  da.de.lb_653 sl.sa.eo_422 
  // [214c0]
  0x05281905, 0x303138af, 0x13513bee, 0x35345e04,   // gl.sw.fr_333 tk.az.uz_655  so.kl.et_422 ts.xh.zu_332 
  0x103035a7, 0x10170804, 0x56002d07, 0x36005612,   // tg.uz.be_532 uk.sr.be_332  sk.mg.un_420 mg.gn.un_640 
  0x1c5c3bad, 0x5c1304a9, 0x21245ca4, 0x2140060b,   // ks.sa.mr_643 fi.et.sa_544  sa.eo.jw_433 de.lb.jw_542 
  0x562d0d0e, 0x4b005a21, 0x183430ec, 0x151030a4,   // cs.sk.mg_555 sm.mi.un_860  uz.ps.ar_644 uz.be.un_433 
  // [214d0]
  0x5d00340d, 0x37001307, 0x370811ee, 0x34373fee,   // xh.ss.un_540 et.st.un_420  ro.uk.ba_422 af.st.xh_422 
  0x0a0417a0, 0x2f005f02, 0x30233c55, 0x0b19020b,   // sr.ru.mk_322 tn.su.un_220  ug.ky.uz_442 da.gl.es_542 
  0x2330440b, 0x19002402, 0x25004607, 0x436e420d,   // kk.uz.ky_542 eo.gl.un_220  qu.eu.un_420 co.hmn.ie_554 
  0x53256914, 0x4a38460c, 0x25766912, 0x0200180d,   // mfe.eu.ht_666 qu.tk.yo_543  mfe.crs.eu_654 ga.da.un_540 
  // [214e0]
  0x25001805, 0x15006907, 0x1000350e, 0x4a464f0c,   // ga.eu.un_330 mfe.un.un_420  tg.be.un_550 bi.qu.yo_543 
  0x2900202a, 0x28000a04, 0x697602af, 0x31501b04,   // sq.sl.un_970 pt.sw.un_320  da.crs.mfe_655 tr.fj.az_332 
  0x79026ba4, 0x38091f08, 0x300254a4, 0x3025350d,   // ceb.da.war_433 cy.pl.tk_443  ik.da.uz_433 tg.mn.uz_554 
  0x01632ca9, 0x3f2c0904, 0x03381fa4, 0xfe2f4c09,   // fy.sco.en_544 pl.fy.af_332  cy.tk.nl_433 wo.su.tlh_444 
  // [214f0]
  0x06033fad, 0x092f0204, 0x1c1f21a4, 0x3530100b,   // af.nl.de_643 da.su.pl_332  jw.cy.id_433 be.uz.tg_542 
  0x0f30fcad, 0x15400609, 0x30342105, 0x1f4c4ba9,   // zzp.uz.lv_643 de.lb.un_444  fa.ps.uz_333 mi.wo.cy_544 
  0x3000400c, 0x331506ee, 0x38313012, 0x06303104,   // lb.uz.un_530 de.nn.un_420  uz.az.tk_654 az.uz.de_332 
  0x15073c04, 0x36002d23, 0x0f3038a4, 0x041530ad,   // ug.bg.un_332 sk.gn.un_880  tk.uz.lv_433 uz.ru.un_630 
  // [21500]
  0x584d39a9, 0x04380812, 0x2916040e, 0x273b13a0,   // br.aa.om_544 uk.tk.ru_654  fi.hr.sl_555 et.so.gd_322 
  0x552932a0, 0x3b190a0d, 0x0d003609, 0x135c1fa4,   // bs.sl.rw_322 pt.gl.so_554  gn.cs.un_440 cy.sa.et_433 
  0x3b1b1008, 0x554d5904, 0x6b007923, 0x070a100d,   // lt.tr.so_443 rn.aa.rw_332  war.ceb.un_880 be.mk.bg_554 
  0x080725ee, 0x13653ba0, 0x2f595513, 0x481b3005,   // mn.bg.uk_422 so.gv.et_322  rw.rn.su_665 uz.tr.tt_333 
  // [21510]
  0xfe4b12a7, 0x3b00310d, 0x2e124907, 0x3b022755,   // hu.mi.tlh_532 az.so.un_540  to.hu.fo_432 gd.da.so_442 
  0x15033f0c, 0x01006312, 0x0b4701a4, 0x3f020313,   // af.nl.un_543 sco.en.un_640  en.sn.es_433 nl.da.af_665 
  0x283547ee, 0x650250ec, 0x2b1c02ec, 0x4e59555a,   // sn.zu.sw_422 fj.da.gv_644  da.id.vi_644 rw.rn.ay_553 
  0x5e00540c, 0x3e001a09, 0x483e52a0, 0x0c033e0c,   // ik.ts.un_530 tl.rm.un_440  ha.rm.tt_322 rm.nl.sv_543 
  // [21520]
  0x02005008, 0x183e1fee, 0x27fc6307, 0x271f3e0c,   // fj.da.un_430 cy.rm.ga_422  sco.zzp.gd_432 rm.cy.gd_543 
  0x18191f08, 0x3e004221, 0x1f001813, 0x27183312,   // cy.gl.ga_443 co.rm.un_860  ga.cy.un_650 nn.ga.gd_654 
  0x023e730c, 0x180a0807, 0x0e1f330c, 0x303d21ec,   // ny.rm.da_543 no.pt.ga_432  nn.cy.is_543 fa.ku.uz_644 
  0x46001207, 0x024304a4, 0x32002909, 0x65004b2a,   // hu.qu.un_420 fi.ie.da_433  sl.bs.un_440 mi.gv.un_970 
  // [21530]
  0x03633fa4, 0x0a0201a9, 0x231a10a0, 0x181f2208,   // af.sco.nl_433 en.da.pt_544  lt.tl.ca_322 oc.cy.ga_443 
  0x15103607, 0x16240405, 0x0e502211, 0x230738a4,   // ab.be.un_432 fi.eo.hr_333  oc.fj.is_653 tk.bg.ky_433 
  0x043e1104, 0x18272e5a, 0x110f1207, 0x07632407,   // ro.rm.fi_332 fo.gd.ga_553  hu.lv.ro_432 eo.sco.it_432 
  0x15071004, 0x27001d0e, 0x3e00270c, 0xfe162905,   // be.bg.un_332 la.gd.un_550  gd.rm.un_530 sl.hr.tlh_333 
  // [21540]
  0x2d0d5ca9, 0xfe3e0608, 0x333e1ea0, 0x4c00fe07,   // sa.cs.sk_544 de.rm.tlh_443  ms.rm.nn_322 tlh.wo.un_420 
  0x02000f07, 0x3b000c19, 0x64004808, 0x0a4830a0,   // lv.da.un_420 sv.so.un_750  tt.lg.un_430 uz.tt.mk_322 
  0x120f11a7, 0x110c03af, 0x033f15ad, 0x0b0a24ee,   // ro.lv.hu_532 nl.sv.ro_655  un.af.nl_643 eo.pt.es_422 
  0x3544370b, 0x0400622b, 0x650462a7, 0x100a1107,   // ba.kk.tg_542 kha.fi.un_980  kha.fi.gv_532 ro.mk.be_432 
  // [21550]
  0x201f650c, 0x3d3b30ec, 0x0c651fa4, 0x3d2818a7,   // gv.cy.sq_543 uz.ks.ku_644  cy.gv.sv_433 ar.sd.ku_532 
  0x6a005c1b, 0x5c5a6aec, 0x621d01a0, 0x201f620c,   // sa.haw.un_770 haw.sm.sa_644  en.la.kha_322 kha.cy.sq_543 
  0x37002f02, 0x5a00650b, 0x5300212a, 0x61006508,   // su.st.un_220 gv.sm.un_520  jw.ht.un_970 gv.za.un_430 
  0x293f0308, 0x0305020d, 0x2f3f0fa6, 0x024f01ee,   // nl.af.sl_443 da.fr.nl_554  lv.af.su_521 en.bi.da_422 
  // [21560]
  0x58000213, 0x402851a9, 0x33084c05, 0x583b510c,   // da.om.un_650 kl.sw.lb_544  wo.no.nn_333 kl.so.om_543 
  0x2f613b04, 0x40563b0c, 0x683b13a4, 0x422905ee,   // so.za.su_332 so.mg.lb_543  et.so.ig_433 fr.sl.co_422 
  0x2f003b19, 0x10006408, 0x5a005c08, 0x5a1c47a0,   // so.su.un_750 lg.lt.un_430  sa.sm.un_430 sn.id.sm_322 
  0x3b4004ad, 0x3d003420, 0x4300110e, 0x39120304,   // fi.lb.so_643 ps.ku.un_850  ro.ie.un_550 nl.hu.br_332 
  // [21570]
  0x1a6b7914, 0x3b004005, 0x5c1c1ea4, 0x3b516ba7,   // war.ceb.tl_666 lb.so.un_330  ms.id.sa_433 ceb.kl.so_532 
  0x12030209, 0x150711af, 0x0a4811a0, 0x0c796b12,   // da.nl.hu_444 ro.bg.un_655  ro.tt.mk_322 ceb.war.sv_654 
  0x1f1b0e0c, 0x2263120c, 0x2f5852af, 0x132d2907,   // is.tr.cy_543 hu.sco.oc_543  ha.om.su_655 sl.sk.et_432 
  0x0c002108, 0x55786aa4, 0x4c130408, 0x043b13a9,   // jw.sv.un_430 haw.ve.rw_433  fi.et.wo_443 et.so.fi_544 
  // [21580]
  0x4b005605, 0x522322ee, 0x510413a7, 0x3b402c0c,   // mg.mi.un_330 oc.ca.ha_422  et.fi.kl_532 fy.lb.so_543 
  0x2c04370c, 0x25000204, 0x0c0f33a9, 0x385835a4,   // st.fi.fy_543 da.eu.un_320  nn.lv.sv_544 zu.om.tk_433 
  0x190a0ea4, 0x79282f0c, 0x35070a12, 0x55005e0d,   // is.pt.gl_433 su.sw.war_543  mk.bg.tg_654 ts.rw.un_540 
  0x531e1c05, 0x4006480c, 0x18002319, 0x4c4205ec,   // id.ms.ht_333 tt.de.lb_543  ky.ar.un_750 fr.co.wo_644 
  // [21590]
  0x564c050c, 0x42000522, 0x4c00461b, 0x425605ee,   // fr.wo.mg_543 fr.co.un_870  qu.wo.un_770 fr.mg.co_422 
  0x48170804, 0x054a4ca7, 0x300a17a7, 0x4c360507,   // uk.sr.tt_332 wo.yo.fr_532  sr.mk.uz_532 fr.gn.wo_432 
  0x394c05ad, 0x2f0d48a4, 0x5b006819, 0x461d4207,   // fr.wo.br_643 tt.cs.su_433  ig.sg.un_750 co.la.qu_432 
  0x67525ba9, 0x155701ee, 0x4800550c, 0x3c302314,   // sg.ha.ak_544 en.na.un_422  rw.tt.un_530 ky.uz.ug_666 
  // [215a0]
  0x40000520, 0x2e2a3e07, 0x02003204, 0x382930a4,   // fr.lb.un_850 rm.mt.fo_432  bs.da.un_320 uz.sl.tk_433 
  0x3b271812, 0x50006804, 0x58005419, 0x48233caf,   // ga.gd.so_654 ig.fj.un_320  ik.om.un_750 ug.ky.tt_655 
  0x02031fec, 0x495a5ca0, 0x02000c0e, 0x0c1830a4,   // cy.nl.da_644 sa.sm.to_322  sv.da.un_550 uz.ga.sv_433 
  0x383130ad, 0x5e393b0c, 0x02093ba7, 0x38004f12,   // uz.az.tk_643 so.br.ts_543  so.pl.da_532 bi.tk.un_640 
  // [215b0]
  0x233b27a9, 0x21222312, 0x211c2f0c, 0x09290d0c,   // gd.so.ca_544 ca.oc.jw_654  su.id.jw_543 cs.sl.pl_543 
  0x0a212955, 0x0835360c, 0x0c00310c, 0x1b483808,   // sl.jw.pt_442 ab.tg.uk_543  az.sv.un_530 tk.tt.tr_443 
  0x48190b08, 0x6e006402, 0x0200601b, 0x093f1007,   // es.gl.tt_443 lg.hmn.un_220  vo.da.un_770 lt.af.pl_432 
  0x48006021, 0x0910020e, 0x043f10a7, 0x2d0c61ee,   // vo.tt.un_860 da.lt.pl_555  lt.af.fi_532 za.sv.sk_422 
  // [215c0]
  0x2c0d49ad, 0x10613f05, 0x360f0b0c, 0x370a08ad,   // to.cs.fy_643 af.za.lt_333  es.lv.gn_543 uk.mk.ba_643 
  0x5c0f5aac, 0x1b4209ee, 0x1d260b0c, 0x360310a4,   // sm.lv.sa_632 pl.co.tr_422  es.ia.la_543 lt.nl.gn_433 
  0x3f07105a, 0x421d0fee, 0x35233cad, 0x07040aaf,   // lt.it.af_553 lv.la.co_422  ug.ky.tg_643 mk.ru.bg_655 
  0x20183404, 0x351f73a0, 0x56116a07, 0x3b2050ad,   // ps.ar.ti_332 ny.cy.zu_322  haw.ro.mg_432 fj.sq.so_643 
  // [215d0]
  0x1a625a0c, 0x01584a07, 0x79091212, 0x32365855,   // sm.kha.tl_543 yo.om.en_432  hu.pl.war_654 om.gn.bs_442 
  0x4a002a04, 0x300a5f08, 0x1f3901a0, 0x150605a0,   // mt.yo.un_320 tn.pt.uz_443  en.br.cy_322 fr.de.un_322 
  0x355d50ec, 0x1b003209, 0x4838670c, 0x55592560,   // fj.ss.zu_644 bs.tr.un_440  ak.tk.tt_543 eu.rn.rw_664 
  0x7500781a, 0x17003f1a, 0x605a490c, 0x4dfe3755,   // ve.nso.un_760 af.sr.un_760  to.sm.vo_543 st.tlh.aa_442 
  // [215e0]
  0x24135c04, 0x0538fc07, 0x56045a0d, 0x120a2508,   // sa.et.eo_332 zzp.tk.fr_432  sm.fi.mg_554 eu.pt.hu_443 
  0x1d506a04, 0x28000b04, 0x020e6508, 0x0a182805,   // haw.fj.la_332 es.sw.un_320  gv.is.da_443 sd.ar.mk_333 
  0x17110107, 0x471861af, 0x22003912, 0x766939ec,   // en.ro.sr_432 za.ga.sn_655  br.oc.un_640 br.mfe.crs_644 
  0x5c2a19ad, 0x03391fee, 0x0100051a, 0x23081512,   // gl.mt.sa_643 cy.br.nl_422  fr.en.un_760 un.uk.ky_654 
  // [215f0]
  0x5c1c21a9, 0x46006e12, 0x0e232204, 0x181f3fa0,   // jw.id.sa_544 hmn.qu.un_640  oc.ca.is_332 af.cy.ga_322 
  0x3e003912, 0x245559a7, 0x0f10690b, 0x2b000107,   // br.rm.un_640 rn.rw.eo_532  mfe.lt.lv_542 en.vi.un_420 
  0x3b0458a7, 0x1253390c, 0x13651508, 0x233912a4,   // om.fi.so_532 br.ht.hu_543  un.gv.et_443 hu.br.ca_433 
  0x0e053911, 0x25002c08, 0x290afe55, 0x4c003914,   // br.fr.is_653 fy.eu.un_430  tlh.pt.sl_442 br.wo.un_660 
  // [21600]
  0x630f3e0c, 0x3e306907, 0x6555590c, 0x3e0f2a02,   // rm.lv.sco_543 mfe.uz.rm_432  rn.rw.gv_543 mt.lv.rm_222 
  0x2c5619ad, 0x1e5d5e04, 0x4a182712, 0x35002e02,   // gl.mg.fy_643 ts.ss.ms_332  gd.ga.yo_654 fo.zu.un_220 
  0x7963010b, 0x47185ca0, 0xfe4773a9, 0x21003b22,   // en.sco.war_542 sa.ga.sn_322  ny.sn.tlh_544 so.jw.un_870 
  0x65560a04, 0x4c5813a0, 0x075b4207, 0x730239ee,   // pt.mg.gv_332 et.om.wo_322  co.sg.it_432 br.da.ny_422 
  // [21610]
  0x110267ec, 0x044c13ec, 0x395e1f08, 0x303b620c,   // ak.da.ro_644 et.wo.fi_644  cy.ts.br_443 kha.so.uz_543 
  0x2f6123a4, 0x46004e1a, 0x6a004929, 0x65053e14,   // ca.za.su_433 ay.qu.un_760  to.haw.un_960 rm.fr.gv_666 
  0x110a500d, 0x53113e0c, 0x370415a9, 0x65061fad,   // fj.pt.ro_554 rm.ro.ht_543  un.ru.ba_544 cy.de.gv_643 
  0x03202fee, 0x1d002f13, 0x05002314, 0x2f2561a7,   // su.sq.nl_422 su.la.un_650  ca.fr.un_660 za.eu.su_532 
  // [21620]
  0x112539ad, 0x313848a4, 0x081d330c, 0x032417ee,   // br.eu.ro_643 tt.tk.az_433  nn.la.no_543 sr.eo.nl_422 
  0x3c28180d, 0x2a002707, 0x51001a12, 0x025e2812,   // ar.sd.ug_554 gd.mt.un_420  tl.kl.un_640 sw.ts.da_654 
  0xfc330c13, 0x40004b0d, 0x19492fec, 0x5264530c,   // sv.nn.zzp_665 mi.lb.un_540  su.to.gl_644 ht.lg.ha_543 
  0x35083007, 0x44254808, 0x13060107, 0x0f001b08,   // uz.uk.tg_432 tt.mn.kk_443  en.de.et_432 tr.lv.un_430 
  // [21630]
  0x0f171505, 0x1f0e1b04, 0x5b522a0c, 0x35004402,   // un.sr.lv_333 tr.is.cy_332  mt.ha.sg_543 kk.tg.un_220 
  0x3f3002a0, 0x212f1caf, 0x232e0e0c, 0x6b591d07,   // da.uz.af_322 id.su.jw_655  is.fo.ca_543 la.rn.ceb_432 
  0x5f111d07, 0x5a5525ad, 0x4c5e4d0c, 0x15004704,   // la.ro.tn_432 eu.rw.sm_643  aa.ts.wo_543 sn.un.un_320 
  0x2916fea6, 0x10fc1da9, 0x5e0b42a4, 0x0233fca4,   // tlh.hr.sl_521 la.zzp.lt_544  co.es.ts_433 zzp.nn.da_433 
  // [21640]
  0x1e1c56a4, 0x074262ad, 0x0f100cad, 0x30081712,   // mg.id.ms_433 kha.co.it_643  sv.lt.lv_643 sr.uk.uz_654 
  0x2a785ea4, 0x4f285e0c, 0x3e491d08, 0x10290f07,   // ts.ve.mt_433 ts.sw.bi_543  la.to.rm_443 lv.sl.lt_432 
  0x48353ca7, 0x3f2465a0, 0x03083fa4, 0x48170705,   // ug.tg.tt_532 gv.eo.af_322  af.no.nl_433 bg.sr.tt_333 
  0x6000630e, 0x08102307, 0x342130ac, 0x0a000209,   // sco.vo.un_550 ky.be.uk_432  uz.fa.ps_632 da.pt.un_440 
  // [21650]
  0x22380a04, 0x4700041b, 0x68595560, 0x5c202104,   // pt.tk.oc_332 fi.sn.un_770  rw.rn.ig_664 jw.sq.sa_332 
  0x101536ad, 0x59552514, 0x2d183607, 0x5c00350d,   // ab.be.un_630 eu.rw.rn_666  gn.ga.sk_432 zu.sa.un_540 
  0x730547a4, 0x38645712, 0x5f003b2a, 0x282a1804,   // sn.fr.ny_433 na.lg.tk_654  so.tn.un_970 ga.mt.sw_332 
  0x21000f02, 0x2635340d, 0xfc7325ec, 0x1c381e04,   // lv.jw.un_220 xh.zu.ia_554  eu.ny.zzp_644 ms.tk.id_332 
  // [21660]
  0x55656404, 0x59555ea4, 0x735a3b08, 0x63006518,   // lg.gv.rw_332 ts.rw.rn_433  so.sm.ny_443 gv.sco.un_740 
  0x4207600e, 0x65000613, 0x3d213ba4, 0x462a64a7,   // vo.it.co_555 de.gv.un_650  ks.fa.ku_433 lg.mt.qu_532 
  0x3523170e, 0x587952ee, 0x02050107, 0x23006509,   // sr.ky.tg_555 ha.war.om_422  en.fr.da_432 gv.ca.un_440 
  0x1c492fa0, 0x0c004307, 0x134a6307, 0x2c0345ee,   // su.to.id_322 ie.sv.un_420  sco.yo.et_432 ln.nl.fy_422 
  // [21670]
  0x2efc5104, 0x511f3814, 0x26651da4, 0x08005108,   // kl.zzp.fo_332 tk.cy.kl_666  la.gv.ia_433 kl.no.un_430 
  0x0d120c02, 0x251b51ec, 0x1f001d1b, 0x25002d0e,   // sv.hu.cs_222 kl.tr.eu_644  la.cy.un_770 sk.eu.un_550 
  0x1d1124a4, 0x0140060c, 0x250f51a9, 0x400e27a4,   // eo.ro.la_433 de.lb.en_543  kl.lv.eu_544 gd.is.lb_433 
  0x7651010c, 0x3b005121, 0x21283008, 0x60193e08,   // en.kl.crs_543 kl.so.un_860  uz.sd.fa_443 rm.gl.vo_443 
  // [21680]
  0x240c330c, 0x4a2d0eee, 0x673b3911, 0x2e2a300c,   // nn.sv.eo_543 is.sk.yo_422  br.so.ak_653 uz.mt.fo_543 
  0x3f0e0aa0, 0x391f6b04, 0x301f2707, 0x16330809,   // pt.is.af_322 ceb.cy.br_332  gd.cy.uz_432 no.nn.hr_444 
  0x64000702, 0x182120a9, 0x03fc2aa0, 0x3b000402,   // it.lg.un_220 sq.jw.ga_544  mt.zzp.nl_322 fi.so.un_220 
  0x183b27ec, 0x19002513, 0x15083508, 0x13004812,   // gd.so.ga_644 eu.gl.un_650  tg.uk.un_443 tt.et.un_640 
  // [21690]
  0x47645e04, 0x2d1236ec, 0x1502240e, 0x022851ad,   // ts.lg.sn_332 gn.hu.sk_644  eo.da.un_555 kl.sw.da_643 
  0x0d4031a0, 0x0f5c5a55, 0x385c3307, 0x0d3b27ee,   // az.lb.cs_322 sm.sa.lv_442  nn.sa.tk_432 gd.so.cs_422 
  0x5c330cee, 0x2e0433ee, 0x364a2d0c, 0x04332a0c,   // sv.nn.sa_422 nn.fi.fo_422  sk.yo.gn_543 mt.nn.fi_543 
  0x4810440d, 0x24023504, 0x595528ee, 0x13001b19,   // kk.be.tt_554 zu.da.eo_332  sw.rw.rn_422 tr.et.un_750 
  // [216a0]
  0x1200360e, 0x2c490302, 0x1e1c4809, 0x15073805,   // gn.hu.un_550 nl.to.fy_222  tt.id.ms_444 tk.bg.un_333 
  0x0f16290b, 0x483538a7, 0x4e215713, 0x55594d08,   // sl.hr.lv_542 tk.tg.tt_532  na.jw.ay_665 aa.rn.rw_443 
  0x1a1f79ad, 0x211a090b, 0x5e4e7309, 0x21004e0d,   // war.cy.tl_643 pl.tl.jw_542  ny.ay.ts_444 ay.jw.un_540 
  0x49685a12, 0x09004e1b, 0x28731a0c, 0x01000704,   // sm.ig.to_654 ay.pl.un_770  tl.ny.sw_543 it.en.un_320 
  // [216b0]
  0x2c4228ee, 0x04073811, 0x381027a0, 0x73094e05,   // sw.co.fy_422 tk.bg.ru_653  gd.lt.tk_322 ay.pl.ny_333 
  0x4a6b1a0c, 0x214e09af, 0x233c21ad, 0x57094e12,   // tl.ceb.yo_543 pl.ay.jw_655  fa.ug.ky_643 ay.pl.na_654 
  0x3b1a47ee, 0x211a4e12, 0x0f5d1002, 0x18000e05,   // sn.tl.so_422 ay.tl.jw_654  lt.ss.lv_222 is.ga.un_330 
  0x15364aa4, 0x28006804, 0x2100560d, 0x380448ee,   // yo.gn.un_433 ig.sw.un_320  mg.jw.un_540 tt.fi.tk_422 
  // [216c0]
  0x20282107, 0x2d0e12ee, 0x1dfc130c, 0x20400807,   // jw.sw.sq_432 hu.is.sk_422  et.zzp.la_543 no.lb.sq_432 
  0x303615a7, 0xfc405755, 0x0b0a01a4, 0x42073908,   // un.ab.uz_532 na.lb.zzp_442  en.pt.es_433 br.it.co_443 
  0x150737ee, 0x19120e02, 0x195623a4, 0x3900180c,   // ba.bg.un_422 is.hu.gl_222  ca.mg.gl_433 ga.br.un_530 
  0x31002a04, 0x39271f0d, 0x1f006b23, 0x30124807,   // mt.az.un_320 cy.gd.br_554  ceb.cy.un_880 tt.hu.uz_432 
  // [216d0]
  0x2e4a3607, 0x1f003e22, 0x1d391fa0, 0x46361307,   // gn.yo.fo_432 rm.cy.un_870  cy.br.la_322 et.gn.qu_432 
  0x3c1008ee, 0x36000723, 0x3b283005, 0x2a5c07a9,   // uk.be.ug_422 it.gn.un_880  uz.sd.ks_333 it.sa.mt_544 
  0x234434a4, 0x1f000921, 0x4904670d, 0x1f392d12,   // ps.kk.ky_433 pl.cy.un_860  ak.fi.to_554 sk.br.cy_654 
  0x5d003702, 0x63627904, 0x22231108, 0x012120a0,   // st.ss.un_220 war.kha.sco_332  ro.ca.oc_443 sq.jw.en_322 
  // [216e0]
  0x47783513, 0x3e154507, 0x27185c05, 0x55004512,   // zu.ve.sn_665 ln.rm.un_420  sa.ga.gd_333 ln.rw.un_640 
  0x5c1f1808, 0x35004511, 0x05000f07, 0x484209a0,   // ga.cy.sa_443 ln.zu.un_630  lv.fr.un_420 pl.co.tt_322 
  0x3e1f27ec, 0x1f103604, 0x01266307, 0x53fc760c,   // gd.cy.rm_644 gn.lt.cy_332  sco.ia.en_432 crs.zzp.ht_543 
  0x5c1827a4, 0x3735faa7, 0x1076690c, 0x64271804,   // gd.ga.sa_433 nr.zu.st_532  mfe.crs.lt_543 ga.gd.lg_332 
  // [216f0]
  0x1e2718a4, 0x1b005309, 0x1f3f69a0, 0x246542ee,   // ga.gd.ms_433 ht.tr.un_440  mfe.af.cy_322 co.gv.eo_422 
  0x2c0313ac, 0x7900060d, 0x31002104, 0x5d000219,   // et.nl.fy_632 de.war.un_540  jw.az.un_320 da.ss.un_750 
  0x365c3e0c, 0x185c27af, 0x1a766908, 0x23275c08,   // rm.sa.gn_543 gd.sa.ga_655  mfe.crs.tl_443 sa.gd.ca_443 
  0x69531f08, 0x183e2707, 0x06423ea4, 0x3f651504,   // cy.ht.mfe_443 gd.rm.ga_432  rm.co.de_433 un.gv.af_332 
  // [21700]
  0x5c430107, 0x64092c55, 0x352f0207, 0x64090212,   // en.ie.sa_432 fy.pl.lg_442  da.su.zu_432 da.pl.lg_654 
  0x382d11a0, 0x2c6503a7, 0x10321608, 0x20292a07,   // ro.sk.tk_322 nl.gv.fy_532  hr.bs.lt_443 mt.sl.sq_432 
  0x3e651d04, 0x64330802, 0x4300391a, 0x1b004c19,   // la.gv.rm_332 no.nn.lg_222  br.ie.un_760 wo.tr.un_750 
  0x46694c55, 0x2311695a, 0x39002c1b, 0x1f1b4ca7,   // wo.mfe.qu_442 mfe.ro.ca_553  fy.br.un_770 wo.tr.cy_532 
  // [21710]
  0x11003622, 0x3e6301ee, 0x1f691d05, 0x4039690c,   // ab.ro.un_870 en.sco.rm_422  la.mfe.cy_333 mfe.br.lb_543 
  0x070a4402, 0x3b2c63a9, 0x3b4c6809, 0x5e150607,   // kk.mk.bg_222 sco.fy.so_544  ig.wo.so_444 de.ts.un_420 
  0x3b00130e, 0x3b036507, 0x3b004d29, 0x6953080c,   // et.so.un_550 gv.nl.so_432  aa.so.un_960 no.ht.mfe_543 
  0x01006323, 0x2d001002, 0x033b3f04, 0x505559a4,   // sco.en.un_880 lt.sk.un_220  af.so.nl_332 rn.rw.fj_433 
  // [21720]
  0x5659550d, 0x3b000307, 0x4f536812, 0x02004a14,   // rw.rn.mg_554 nl.so.un_420  ig.ht.bi_654 yo.da.un_660 
  0x59005307, 0x3f7913a4, 0x09000502, 0x044813a6,   // ht.rn.un_420 et.war.af_433  fr.pl.un_220 et.tt.fi_521 
  0x30483904, 0x3e222a04, 0x7355450c, 0x68503baf,   // br.tt.uz_332 mt.oc.rm_332  ln.rw.ny_543 so.fj.ig_655 
  0x07440a09, 0x0f68640e, 0x3d12210e, 0x55280dee,   // mk.kk.bg_444 lg.ig.lv_555  fa.ur.ku_555 cs.sw.rw_422 
  // [21730]
  0x52345507, 0x063848a4, 0x25195607, 0x62697612,   // rw.xh.ha_432 tt.tk.de_433  mg.gl.eu_432 crs.mfe.kha_654 
  0x1e0a05a9, 0x69765360, 0x2f0c02ee, 0x53251c07,   // fr.pt.ms_544 ht.crs.mfe_664  da.sv.su_422 id.eu.ht_432 
  0x5800690c, 0x272e02ad, 0x032c29a0, 0x76532408,   // mfe.om.un_530 da.fo.gd_643  sl.fy.nl_322 eo.ht.crs_443 
  0x3600190e, 0x4f022560, 0xfc00450c, 0x73285555,   // gl.gn.un_550 eu.da.bi_664  ln.zzp.un_530 rw.sw.ny_442 
  // [21740]
  0x67044508, 0x24002905, 0x2a255b07, 0xfc004512,   // ln.fi.ak_443 sl.eo.un_330  sg.eu.mt_432 ln.zzp.un_640 
  0x35534504, 0x2e0e12ec, 0x35152508, 0x2800450b,   // ln.ht.zu_332 hu.is.fo_644  mn.tg.un_430 ln.sw.un_520 
  0x153538ec, 0x23101708, 0x32002808, 0x35341d14,   // tk.tg.un_644 sr.be.ky_443  sw.bs.un_430 la.xh.zu_666 
  0x0415070d, 0x07100412, 0x3b1b1004, 0x130410a7,   // bg.ru.un_540 ru.be.bg_654  lt.tr.so_332 lt.fi.et_532 
  // [21750]
  0x3b00620e, 0x36003e0c, 0x4d383e04, 0x12103e08,   // kha.so.un_550 rm.gn.un_530  rm.tk.aa_332 rm.lt.hu_443 
  0x0f000b04, 0x3b122860, 0x043c38a9, 0x06123eee,   // es.lv.un_320 sd.ur.ks_664  tk.ug.ru_544 rm.hu.de_422 
  0x496150ad, 0x2e0e10a7, 0x06043e04, 0x12003b09,   // fj.za.to_643 lt.is.fo_532  rm.fi.de_332 so.hu.un_440 
  0x10633ea4, 0x0f2a200b, 0x36123e0c, 0x23003d18,   // rm.sco.lt_433 sq.mt.lv_542  rm.hu.gn_543 ku.ky.un_740 
  // [21760]
  0x15070407, 0x12363ea7, 0x30311eaf, 0x5c300202,   // ru.bg.un_432 rm.gn.hu_532  ms.az.uz_655 da.uz.sa_222 
  0x273b18a9, 0x2a220a0c, 0x3b5804af, 0x221f0a09,   // ga.so.gd_544 pt.oc.mt_543  fi.om.so_655 pt.cy.oc_444 
  0x3b495804, 0x582f4dec, 0x5c007808, 0x58007909,   // om.to.so_332 aa.su.om_644  ve.sa.un_430 war.om.un_440 
  0x4830310c, 0x5c3b58a4, 0x233b34a4, 0xfa00341b,   // az.uz.tt_543 om.so.sa_433  ps.ks.ky_433 xh.nr.un_770 
  // [21770]
  0x6b003b18, 0x5531590d, 0x35005e07, 0x3504080c,   // so.ceb.un_740 rn.az.rw_554  ts.zu.un_420 uk.ru.tg_543 
  0x2afe46ad, 0x732f550c, 0x040a10af, 0x200a230c,   // qu.tlh.mt_643 rw.su.ny_543  be.mk.ru_655 ca.pt.sq_543 
  0x67304ea4, 0x23004d18, 0x374c3b04, 0x18782708,   // ay.uz.ak_433 aa.ca.un_740  so.wo.st_332 gd.ve.ga_443 
  0x58653b07, 0x3534fe12, 0x305d3ba9, 0x214c3b0c,   // so.gv.om_432 tlh.xh.zu_654  so.ss.uz_544 so.wo.jw_543 
  // [21780]
  0x58737504, 0x353420a4, 0x21281855, 0x4d2afe0c,   // nso.ny.om_332 sq.xh.zu_433  ar.sd.fa_442 tlh.mt.aa_543 
  0x57626112, 0x0a122d0d, 0x3004080d, 0x34183b17,   // za.kha.na_654 sk.hu.pt_554  uk.ru.uz_554 ks.ar.ps_753 
  0x472913a0, 0x19000e07, 0x3c182108, 0x35526707,   // et.sl.sn_322 is.gl.un_420  fa.ar.ug_443 ak.ha.zu_432 
  0x07101107, 0x421321ec, 0x284d1307, 0x472d0d5a,   // ro.be.bg_432 jw.et.co_644  et.aa.sw_432 cs.sk.sn_553 
  // [21790]
  0x091f37a7, 0x28342160, 0x1d113e13, 0x101350ee,   // st.cy.pl_532 fa.ps.sd_664  rm.ro.la_665 fj.et.lt_422 
  0x2742100c, 0x10652ca7, 0x3e790755, 0x1133fea0,   // lt.co.gd_543 fy.gv.lt_532  it.war.rm_442 tlh.nn.ro_322 
  0x16001d0b, 0x592845ec, 0x214d1e0c, 0x3bfe625a,   // la.hr.un_520 ln.sw.rn_644  ms.aa.jw_543 kha.tlh.so_553 
  0x475e3504, 0x245a0a0c, 0x1e004d0d, 0x1d151f07,   // zu.ts.sn_332 pt.sm.eo_543  aa.ms.un_540 cy.la.un_420 
  // [217a0]
  0x62131da4, 0x345f6707, 0x5304130c, 0x3e580408,   // la.et.kha_433 ak.tn.xh_432  et.fi.ht_543 fi.om.rm_443 
  0x38fc5760, 0x27311b07, 0x0f1013a7, 0x49456aec,   // na.zzp.tk_664 tr.az.gd_432  et.lt.lv_532 haw.ln.to_644 
  0x2e000108, 0x510449ec, 0x4d001c08, 0x0e495104,   // en.fo.un_430 to.fi.kl_644  id.aa.un_430 kl.to.is_332 
  0x3b1238a4, 0x08233004, 0x506a6b07, 0x28004722,   // tk.hu.so_433 uz.ky.uk_332  ceb.haw.fj_432 sn.sw.un_870 
  // [217b0]
  0x6702520c, 0x124a0d02, 0x02003509, 0x4900670d,   // ha.da.ak_543 cs.yo.hu_222  zu.da.un_440 ak.to.un_540 
  0x0a1708ec, 0x382f0208, 0x0c001702, 0x04004908,   // uk.sr.mk_644 da.su.tk_443  sr.sv.un_220 to.fi.un_430 
  0x04005819, 0x532f7604, 0x1a796b60, 0x6b1a125a,   // om.fi.un_750 crs.su.ht_332  ceb.war.tl_664 hu.tl.ceb_553 
  0x3b5804ad, 0x485279ee, 0x27513fa7, 0x09102504,   // fi.om.so_643 war.ha.tt_422  af.kl.gd_532 eu.lt.pl_332 
  // [217c0]
  0x49005811, 0x523038a4, 0x38570660, 0x0a00040e,   // om.to.un_630 tk.uz.ha_433  de.na.tk_664 ru.mk.un_550 
  0x21183b12, 0x04004909, 0x79380255, 0x510204a9,   // ks.ar.fa_654 to.fi.un_440  da.tk.war_442 fi.da.kl_544 
  0x0c253908, 0x692138a4, 0x49045104, 0x3153690c,   // br.eu.sv_443 tk.jw.mfe_433  kl.fi.to_332 mfe.ht.az_543 
  0x51580407, 0x12443d04, 0x5c002114, 0x043b58ac,   // fi.om.kl_432 ku.kk.ur_332  jw.sa.un_660 om.so.fi_632 
  // [217d0]
  0x253035a6, 0x07083807, 0x51001208, 0x36070304,   // tg.uz.mn_521 tk.uk.bg_432  hu.kl.un_430 nl.it.gn_332 
  0x215c3b5a, 0x1b1e2f07, 0x3f355602, 0x304728a0,   // so.sa.jw_553 su.ms.tr_432  mg.zu.af_222 sw.sn.uz_322 
  0x3447045a, 0x08041da0, 0x5e473008, 0x78fe04a4,   // fi.sn.xh_553 la.fi.no_322  uz.sn.ts_443 fi.tlh.ve_433 
  0x233548a0, 0x10006414, 0x53391ba4, 0x12003e13,   // tt.tg.ky_322 lg.lt.un_660  tr.br.ht_433 rm.hu.un_650 
  // [217e0]
  0x22234307, 0x2d003002, 0x071004ac, 0x5c5547ee,   // ie.ca.oc_432 uz.sk.un_220  ru.be.bg_632 sn.rw.sa_422 
  0x105c69a9, 0x3efe4208, 0x5e00501b, 0x1300500c,   // mfe.sa.lt_544 co.tlh.rm_443  fj.ts.un_770 fj.et.un_530 
  0x17354804, 0x04083005, 0x0a304855, 0x1707150c,   // tt.tg.sr_332 uz.uk.ru_333  tt.uz.mk_442 un.bg.sr_543 
  0x233725ec, 0x31006812, 0x3744360c, 0x5e483107,   // mn.ba.ky_644 ig.az.un_640  ab.kk.ba_543 az.tt.ts_432 
  // [217f0]
  0x181009a0, 0x16481d0c, 0x2a6824a4, 0x083035a4,   // pl.lt.ga_322 la.tt.hr_543  eo.ig.mt_433 tg.uz.uk_433 
  0x34213ba4, 0x214c4507, 0x49005102, 0x4b002e04,   // ks.fa.ps_433 ln.wo.jw_432  kl.to.un_220 fo.mi.un_320 
  0x55004714, 0x510f33a0, 0x1f4755a9, 0x28095105,   // sn.rw.un_660 nn.lv.kl_322  rw.sn.cy_544 kl.pl.sw_333 
  0x471f5207, 0x24001002, 0x471f5e02, 0x34135d04,   // ha.cy.sn_432 lt.eo.un_220  ts.cy.sn_222 ss.et.xh_332 
  
  // [21800]
  0x46005c09, 0x644755a9, 0x1a304208, 0x1b2d12ad,   // sa.qu.un_440 rw.sn.lg_544  co.uz.tl_443 hu.sk.tr_643 
  0x131f6ba4, 0x1a1b08ee, 0xfc5d580c, 0x28205e08,   // ceb.cy.et_433 no.tr.tl_422  om.ss.zzp_543 ts.sq.sw_443 
  0x256b790d, 0x1d264e07, 0xfc3564ee, 0x5b3956a4,   // war.ceb.eu_554 ay.ia.la_432  lg.zu.zzp_422 mg.br.sg_433 
  0x38061b08, 0x60002d04, 0x0647550d, 0x3f003705,   // tr.de.tk_443 sk.vo.un_320  rw.sn.de_554 st.af.un_330 
  // [21810]
  0x212f4705, 0x301744a0, 0x173f010c, 0x11292da4,   // sn.su.jw_333 kk.sr.uz_322  en.af.sr_543 sk.sl.ro_433 
  0x11172911, 0x4f1249a4, 0x213c3d04, 0x354326a7,   // sl.sr.ro_653 to.hu.bi_433  ku.ug.fa_332 ia.ie.zu_532 
  0x130f6b0c, 0x34006007, 0x3f3042a0, 0x2818120d,   // ceb.lv.et_543 vo.xh.un_420  co.uz.af_322 ur.ar.sd_554 
  0x170a1007, 0x0b15760c, 0xfc3b3505, 0x7553050c,   // be.mk.sr_432 crs.es.un_530  zu.so.zzp_333 fr.ht.nso_543 
  // [21820]
  0x381f39a4, 0x3e125c55, 0x0c08020c, 0x07512ea7,   // br.cy.tk_433 sa.hu.rm_442  da.no.sv_543 fo.kl.it_532 
  0x2c270302, 0x2d5537a0, 0x2d003719, 0x642d37a0,   // nl.gd.fy_222 st.rw.sk_322  st.sk.un_750 st.sk.lg_322 
  0x37002d1b, 0x080c3ea4, 0x283051ad, 0x016e02ee,   // sk.st.un_770 rm.sv.no_433  kl.uz.sw_643 da.hmn.en_422 
  0x080c45a7, 0x04131d0c, 0x30000423, 0x1d131008,   // ln.sv.no_532 la.et.fi_543  fi.uz.un_880 lt.et.la_443 
  // [21830]
  0x2e1b2ca0, 0x102713a0, 0x076511a4, 0x026518a4,   // fy.tr.fo_322 et.gd.lt_322  ro.gv.it_433 ga.gv.da_433 
  0x3800400b, 0x13421d04, 0x080220a4, 0x552d0d55,   // lb.tk.un_520 la.co.et_332  sq.da.no_433 cs.sk.rw_442 
  0x481e3104, 0x4d4f630c, 0x042d5504, 0x3b6b4dad,   // az.ms.tt_332 sco.bi.aa_543  rw.sk.fi_332 aa.ceb.so_643 
  0x32006e04, 0x131a1daf, 0x6b005508, 0x054d2407,   // hmn.bs.un_320 la.tl.et_655  rw.ceb.un_430 eo.aa.fr_432 
  // [21840]
  0x0c134007, 0x2f3828a0, 0x303b3107, 0x4d6a3bec,   // lb.et.sv_432 sw.tk.su_322  az.so.uz_432 so.haw.aa_644 
  0x527957ec, 0x2600fe20, 0x5c00470e, 0x02476508,   // na.war.ha_644 tlh.ia.un_850  sn.sa.un_550 gv.sn.da_443 
  0x2f2b1cee, 0x2d525808, 0x3b285812, 0x09212fee,   // id.vi.su_422 om.ha.sk_443  om.sw.so_654 su.jw.pl_422 
  0x182c1e07, 0x113e47a0, 0x32003f08, 0x403b58ee,   // ms.fy.ga_432 sn.rm.ro_322  af.bs.un_430 om.so.lb_422 
  // [21850]
  0x574c2108, 0x0a1511a6, 0x555a5004, 0x6800582b,   // jw.wo.na_443 ro.mk.un_510  fj.sm.rw_332 om.ig.un_980 
  0x23005502, 0x0b0a25a4, 0x121c61a7, 0x4b006514,   // rw.ca.un_220 eu.pt.es_433  za.id.hu_532 gv.mi.un_660 
  0x65007807, 0x2f222307, 0x1e0c1c0c, 0x3b3148ec,   // ve.gv.un_420 ca.oc.su_432  id.sv.ms_543 tt.az.so_644 
  0x3630350e, 0x213b3daf, 0x0725150c, 0x595624a4,   // tg.uz.ab_555 ku.ks.fa_655  un.mn.bg_543 eo.mg.rn_433 
  // [21860]
  0x1725300c, 0x17690f07, 0x04371004, 0x302924a9,   // uz.eu.sr_543 lv.mfe.sr_432  be.ba.ru_332 eo.sl.uz_544 
  0x152515a7, 0x52353408, 0x0a0748ad, 0x1b2456a0,   // un.mn.un_532 xh.zu.ha_443  tt.bg.mk_643 mg.eo.tr_322 
  0x153830a9, 0x52005609, 0x5a00100e, 0x13002407,   // uz.tk.un_544 mg.ha.un_440  lt.sm.un_550 eo.et.un_420 
  0x483035a0, 0x493b4d55, 0x043f0fa0, 0x67033faf,   // tg.uz.tt_322 aa.so.to_442  lv.af.fi_322 af.nl.ak_655 
  // [21870]
  0x033426a4, 0x04fc13ee, 0x4c006e21, 0x2e4f6a07,   // ia.xh.nl_433 et.zzp.fi_422  hmn.wo.un_860 haw.bi.fo_432 
  0x40244da0, 0x38150aad, 0x1100360d, 0x636e01af,   // aa.eo.lb_322 mk.tk.un_630  ab.ro.un_540 en.hmn.sco_655 
  0x3400640c, 0x64584da9, 0x65000a05, 0x34656404,   // lg.xh.un_530 aa.om.lg_544  pt.gv.un_330 lg.gv.xh_332 
  0x5f4d13a4, 0x357873a7, 0x4d3bfca4, 0x2c353408,   // et.aa.tn_433 ny.ve.zu_532  zzp.so.aa_433 xh.zu.fy_443 
  // [21880]
  0x423e2010, 0x62353408, 0x226505a0, 0x51001f0b,   // sq.rm.co_642 xh.zu.kha_443  fr.gv.oc_322 cy.kl.un_520 
  0x24054204, 0x01450508, 0x4a123611, 0x010226a4,   // co.fr.eo_332 fr.ln.en_443  gn.hu.yo_653 ia.da.en_433 
  0x42050204, 0x182758ad, 0x19000505, 0x04583b60,   // da.fr.co_332 om.gd.ga_643  fr.gl.un_330 so.om.fi_664 
  0x735564af, 0x21003c0c, 0x5d006407, 0x58043bec,   // lg.rw.ny_655 ug.fa.un_530  lg.ss.un_420 so.fi.om_644 
  // [21890]
  0x64006807, 0x4c58045a, 0x733564ee, 0x5e000422,   // ig.lg.un_420 fi.om.wo_553  lg.zu.ny_422 fi.ts.un_870 
  0x1e00050c, 0x2d376504, 0x42221d07, 0x30001909,   // fr.ms.un_530 gv.st.sk_332  la.oc.co_432 gl.uz.un_440 
  0x3500171a, 0xfc6465a4, 0x64395208, 0x48381bec,   // sr.tg.un_760 gv.lg.zzp_433  ha.br.lg_443 tr.tk.tt_644 
  0x46016e0c, 0x044968a6, 0x26000a21, 0x2a393707,   // hmn.en.qu_543 ig.to.fi_521  pt.ia.un_860 st.br.mt_432 
  // [218a0]
  0x015365a0, 0x636569a0, 0x300e1307, 0x2202feec,   // gv.ht.en_322 mfe.gv.sco_322  et.is.uz_432 tlh.da.oc_644 
  0x4c006e0d, 0x595509ad, 0x3b000412, 0x27fe4fa4,   // hmn.wo.un_540 pl.rw.rn_643  fi.so.un_640 bi.tlh.gd_433 
  0x3c304813, 0x5e2a3704, 0xfe3b2a5a, 0x07003521,   // tt.uz.ug_665 st.mt.ts_332  mt.so.tlh_553 tg.bg.un_860 
  0x483638a4, 0x20003914, 0x205347ee, 0x0912135a,   // tk.ab.tt_433 br.sq.un_660  sn.ht.sq_422 et.hu.pl_553 
  // [218b0]
  0x01002410, 0x07173cad, 0x38203907, 0x203902ad,   // yi.iw.un_620 ug.sr.bg_643  br.sq.tk_432 da.br.sq_643 
  0x08173807, 0x20004712, 0x18003c19, 0x353430a6,   // tk.sr.uk_432 sn.sq.un_640  ug.ar.un_750 uz.xh.zu_521 
  0x500402ee, 0x0400580d, 0x36004e12, 0x49040508,   // da.fi.fj_422 om.fi.un_540  ay.gn.un_640 fr.fi.to_443 
  0x01040208, 0x12433ea7, 0x2718020e, 0x090560a4,   // da.fi.en_443 rm.ie.hu_532  da.ga.gd_555 vo.fr.pl_433 
  // [218c0]
  0x18270aaf, 0x4c003612, 0x541a51a4, 0x510f64ee,   // pt.gd.ga_655 gn.wo.un_640  kl.tl.ik_433 lg.lv.kl_422 
  0x350415a7, 0x15043007, 0x64586aa4, 0x0a0723ad,   // un.ru.tg_532 uz.ru.un_432  haw.om.lg_433 ky.bg.mk_643 
  0x05046512, 0x04643b0b, 0x47006509, 0x18270412,   // gv.fi.fr_654 so.lg.fi_542  gv.sn.un_440 fi.gd.ga_654 
  0x4c003302, 0x522a62a7, 0x40334cac, 0x4700120c,   // nn.wo.un_220 kha.mt.ha_532  wo.nn.lb_632 hu.sn.un_530 
  // [218d0]
  0x40054c0c, 0x2e2c3f0c, 0x49002805, 0x0c2e3e07,   // wo.fr.lb_543 af.fy.fo_543  sw.to.un_330 rm.fo.sv_432 
  0x13003408, 0xfe5c39ee, 0x4c003305, 0x226b53a0,   // xh.et.un_430 br.sa.tlh_422  nn.wo.un_330 ht.ceb.oc_322 
  0x301b3160, 0x334005a0, 0x1a0b6b09, 0x5c1b76ee,   // az.tr.uz_664 fr.lb.nn_322  ceb.es.tl_444 crs.tr.sa_422 
  0x38484da6, 0x181234a4, 0x19004f08, 0x225604a0,   // aa.tt.tk_521 ps.ur.ar_433  bi.gl.un_430 fi.mg.oc_322 
  // [218e0]
  0x1748150c, 0x08353608, 0x312e1b13, 0x17083655,   // un.tt.sr_543 ab.tg.uk_443  tr.fo.az_665 ab.uk.sr_442 
  0x210234a0, 0x533e04a4, 0x5c033f0c, 0x23443011,   // xh.da.jw_322 fi.rm.ht_433  af.nl.sa_543 uz.kk.ky_653 
  0x171639a4, 0x44373804, 0x0a1738af, 0x17750f0b,   // br.hr.sr_433 tk.ba.kk_332  tk.sr.mk_655 lv.nso.sr_542 
  0x4b5a38a4, 0x285955a4, 0x344ffcec, 0xfc080214,   // tk.sm.mi_433 rw.rn.sw_433  zzp.bi.xh_644 da.no.zzp_666 
  // [218f0]
  0x3c2348a9, 0x50565c0e, 0x503e5c0c, 0x5c3e3614,   // tt.ky.ug_544 sa.mg.fj_555  sa.rm.fj_543 gn.rm.sa_666 
  0x490450a6, 0x5a735507, 0x56005007, 0x10000e13,   // fj.fi.to_521 rw.ny.sm_432  fj.mg.un_420 is.lt.un_650 
  0x245b5e11, 0x3e5c500c, 0x365c3e05, 0x123e5c05,   // ts.sg.eo_653 fj.sa.rm_543  rm.sa.gn_333 sa.rm.hu_333 
  0x122834ee, 0x132d0d0c, 0x231dfe0c, 0x100ffeec,   // ps.sd.ur_422 cs.sk.et_543  tlh.la.ca_543 tlh.lv.lt_644 
  // [21900]
  0x58131dad, 0x04070aaf, 0x5706feec, 0x132d0d05,   // la.et.om_643 mk.bg.ru_655  tlh.de.na_644 cs.sk.et_333 
  0x210e1ca4, 0x2400fe22, 0x0f2cfe11, 0x1d3f5813,   // id.is.jw_433 tlh.eo.un_870  tlh.fy.lv_653 om.af.la_665 
  0x0e003f13, 0xfe241d0c, 0x080723a7, 0x27000c0c,   // af.is.un_650 la.eo.tlh_543  ky.bg.uk_532 sv.gd.un_530 
  0x1d135812, 0xfe00061b, 0x062d0deb, 0x3e311b04,   // om.et.la_654 de.tlh.un_770  cs.sk.de_662 tr.az.rm_332 
  // [21910]
  0x0f000411, 0x1913790d, 0x580f04ee, 0x172d53a4,   // fi.lv.un_630 war.et.gl_554  fi.lv.om_422 ht.sk.sr_433 
  0x1c006e02, 0x0e10fe07, 0x0c523b08, 0x393b0a60,   // hmn.id.un_220 tlh.lt.is_432  so.ha.sv_443 pt.so.br_664 
  0x4053fcee, 0x57fe0608, 0x48791a07, 0x483b1804,   // zzp.ht.lb_422 de.tlh.na_443  tl.war.tt_432 ga.so.tt_332 
  0x0f00fe19, 0x31005c07, 0x30473604, 0x5c283b04,   // tlh.lv.un_750 sa.az.un_420  gn.sn.uz_332 so.sw.sa_332 
  // [21920]
  0x3800111b, 0x3e0b39a0, 0x28205208, 0x27793fa4,   // ro.tk.un_770 br.es.rm_322  ha.sq.sw_443 af.war.gd_433 
  0x38091f05, 0x34003d1b, 0x040730a9, 0x54000104,   // cy.pl.tk_333 ku.ps.un_770  uz.bg.ru_544 en.ik.un_320 
  0x09363807, 0x05334508, 0x05004c13, 0x533e79a0,   // tk.gn.pl_432 ln.nn.fr_443  wo.fr.un_650 war.rm.ht_322 
  0x2d2910a4, 0x084c0207, 0x4c000519, 0x35321704,   // lt.sl.sk_433 da.wo.no_432  fr.wo.un_750 sr.bs.zu_332 
  // [21930]
  0x05004c0c, 0x2e00390c, 0x033963ec, 0x353048a7,   // wo.fr.un_530 br.fo.un_530  sco.br.nl_644 tt.uz.tg_532 
  0x10030107, 0x050601ee, 0x2d461007, 0x394c2308,   // en.nl.lt_432 en.de.fr_422  lt.qu.sk_432 ca.wo.br_443 
  0x2203230c, 0x13150112, 0x4b000107, 0x694f570c,   // ca.nl.oc_543 en.et.un_640  en.mi.un_420 na.bi.mfe_543 
  0x45630107, 0x5d384f07, 0x016308a0, 0x02464f11,   // en.sco.ln_432 bi.tk.ss_432  no.sco.en_322 bi.qu.da_653 
  // [21940]
  0x58001a04, 0x02004607, 0x4600671a, 0x461c2aa9,   // tl.om.un_320 qu.da.un_420  ak.qu.un_760 mt.id.qu_544 
  0x1340065a, 0x53672f07, 0x5d007304, 0x79fc510c,   // de.lb.et_553 su.ak.ht_432  ny.ss.un_320 kl.zzp.war_543 
  0x21582f04, 0x013ffc05, 0x024a300c, 0x1737110c,   // su.om.jw_332 zzp.af.en_333  uz.yo.da_543 ro.ba.sr_543 
  0x6318010c, 0x51675608, 0x271332a0, 0x1300650e,   // en.ga.sco_543 mg.ak.kl_443  bs.et.gd_322 gv.et.un_550 
  // [21950]
  0x0c573e04, 0x02002102, 0x4f00461a, 0x31003f05,   // rm.na.sv_332 jw.da.un_220  qu.bi.un_760 af.az.un_330 
  0x04153012, 0x03130508, 0x51583bee, 0x03023fee,   // uz.ru.un_640 fr.et.nl_443  so.om.kl_422 af.da.nl_422 
  0x04004902, 0x581d3b04, 0x4d1d4c5a, 0x241d5813,   // to.fi.un_220 so.la.om_332  wo.la.aa_553 om.la.eo_665 
  0x1d3b5811, 0x40040c07, 0x133b1d11, 0x0e2c2ea0,   // om.so.la_653 sv.fi.lb_432  la.so.et_653 fo.fy.is_322 
  // [21960]
  0x4c583ba0, 0x3b001d13, 0x60255a0c, 0x282a5202,   // so.om.wo_322 la.so.un_650  sm.eu.vo_543 ha.mt.sw_222 
  0x24001d1a, 0x383625a7, 0x6a006708, 0x3e6e5aad,   // la.eo.un_760 mn.ab.tk_532  ak.haw.un_430 sm.hmn.rm_643 
  0x0f003704, 0x162856ad, 0x640245a4, 0x5a006b07,   // st.lv.un_320 mg.sw.hr_643  ln.da.lg_433 ceb.sm.un_420 
  0x02fa21af, 0x5a5f56a4, 0x041011a0, 0x3e274204,   // jw.nr.da_655 mg.tn.sm_433  ro.be.ru_322 co.gd.rm_332 
  // [21970]
  0x696428ec, 0x060c3302, 0x36455f0c, 0x17305fee,   // sw.lg.mfe_644 nn.sv.de_222  tn.ln.gn_543 tn.uz.sr_422 
  0x581a1da7, 0x35344014, 0x49275a02, 0x133b1d0c,   // la.tl.om_532 lb.xh.zu_666  sm.gd.to_222 la.so.et_543 
  0x5e15670c, 0x375619a0, 0x24001d12, 0x233458ad,   // ak.ts.un_530 gl.mg.st_322  la.eo.un_640 om.xh.ca_643 
  0x42003607, 0x284547a4, 0x0228300c, 0x353f0908,   // gn.co.un_420 sn.ln.sw_433  uz.sw.da_543 pl.af.zu_443 
  // [21980]
  0xfc17500c, 0x401f3911, 0x2f027304, 0x697678ad,   // fj.sr.zzp_543 br.cy.lb_653  ny.da.su_332 ve.crs.mfe_643 
  0x6b420709, 0x4223450b, 0x25370107, 0x37003b04,   // it.co.ceb_444 ln.ca.co_542  en.st.eu_432 so.st.un_320 
  0x1b3120ad, 0x5f635e07, 0x40353404, 0x0e004b14,   // sq.az.tr_643 ts.sco.tn_432  xh.zu.lb_332 mi.is.un_660 
  0x43001323, 0x213b130b, 0x424c4d04, 0x343c3da0,   // et.ie.un_880 et.so.jw_542  aa.wo.co_332 ku.ug.ps_322 
  // [21990]
  0x130e0f12, 0x5200781a, 0x454a3b07, 0x11422f13,   // lv.is.et_654 ve.ha.un_760  so.yo.ln_432 su.co.ro_665 
  0x1c004002, 0x0a355a07, 0x164c42a6, 0x42000f12,   // lb.id.un_220 sm.zu.pt_432  co.wo.hr_521 lv.co.un_640 
  0x044411a4, 0x650a19a4, 0x4527185a, 0x1017480c,   // ro.kk.ru_433 gl.pt.gv_433  ga.gd.ln_553 tt.sr.be_543 
  0x28134da4, 0x4a1845af, 0x424a135a, 0x0b27180c,   // aa.et.sw_433 ln.ga.yo_655  et.yo.co_553 ga.gd.es_543 
  // [219a0]
  0x4a2a42a0, 0x1815270c, 0x0a3e0ba0, 0x191860a4,   // co.mt.yo_322 gd.ga.un_530  es.rm.pt_322 vo.ga.gl_433 
  0x183e270c, 0x2f0a21ee, 0x4318270d, 0x0a023908,   // gd.rm.ga_543 jw.pt.su_422  gd.ga.ie_554 br.da.pt_443 
  0x270a13a4, 0x10292d08, 0x182701af, 0x27001308,   // et.pt.gd_433 sk.sl.lt_443  en.gd.ga_655 et.gd.un_430 
  0x0b133ea0, 0x131c5caf, 0x130d1c12, 0x230d0a04,   // rm.et.es_322 sa.mr.bh_655  mr.ne.bh_654 pt.cs.ca_332 
  // [219b0]
  0x35346e05, 0xfa003009, 0x350f340c, 0x081507a9,   // hmn.xh.zu_333 uz.nr.un_440  xh.lv.zu_543 bg.uk.un_540 
  0x04153008, 0x15253ca9, 0x3534fa11, 0x31386205,   // uz.ru.un_430 ug.mn.un_544  nr.xh.zu_653 kha.tk.az_333 
  0x56003708, 0x3e00fe07, 0xfc4a21a0, 0x0d2d13ee,   // st.mg.un_430 tlh.rm.un_420  jw.yo.zzp_322 et.sk.cs_422 
  0x0e2d0d1b, 0x1000fe02, 0x12002707, 0x0e090dac,   // cs.sk.is_777 tlh.lt.un_220  gd.hu.un_420 cs.pl.is_632 
  // [219c0]
  0x46000302, 0x081711a9, 0x18122811, 0x0a0711a0,   // nl.qu.un_220 ro.sr.uk_544  sd.ur.ar_653 ro.bg.mk_322 
  0x30123ba7, 0x0a08175a, 0x404c58a7, 0x2e121809,   // ks.ur.uz_532 sr.uk.mk_553  om.wo.lb_532 ga.hu.fo_444 
  0x244735a0, 0x393525ee, 0x5e2c0d04, 0x18001909,   // zu.sn.eo_322 eu.zu.br_422  cs.fy.ts_332 gl.ga.un_440 
  0x35001104, 0x18004a07, 0x5d06faee, 0x1d023e12,   // ro.zu.un_320 yo.ga.un_420  nr.de.ss_422 rm.da.la_654 
  // [219d0]
  0x59554505, 0x120e2e0d, 0x1c003804, 0x213d1814,   // ln.rw.rn_333 fo.is.hu_554  tk.id.un_320 ar.ku.fa_666 
  0x57360aaf, 0x10fc62a6, 0x360225a9, 0x12004508,   // pt.gn.na_655 kha.zzp.lt_521  eu.da.gn_544 ln.hu.un_430 
  0x042545ad, 0x1d202402, 0x65002c09, 0x05452708,   // ln.eu.fi_643 eo.sq.la_222  fy.gv.un_440 gd.ln.fr_443 
  0x402202ec, 0x052718af, 0x105f0f08, 0x583b51a9,   // da.oc.lb_644 ga.gd.fr_655  lv.tn.lt_443 kl.so.om_544 
  // [219e0]
  0x5c134708, 0x28484712, 0x17072055, 0x3f361fa0,   // sn.et.sa_443 sn.tt.sw_654  sq.it.sr_442 cy.gn.af_322 
  0x55644707, 0x45635013, 0x0d2e19a4, 0x120e0c0c,   // sn.lg.rw_432 fj.sco.ln_665  gl.fo.cs_433 sv.is.hu_543 
  0x360a5307, 0x3f021fa9, 0x5e00782c, 0x22361210,   // ht.pt.gn_432 cy.da.af_544  ve.ts.un_990 hu.gn.oc_642 
  0x2a0807a9, 0x300501a4, 0x04050fa9, 0x583b640c,   // it.no.mt_544 en.fr.uz_433  lv.fr.fi_544 lg.so.om_543 
  // [219f0]
  0x5500782a, 0x21053607, 0x7800371b, 0x5e47105a,   // ve.rw.un_970 gn.fr.jw_432  st.ve.un_770 lt.sn.ts_553 
  0x02557808, 0x475e49a0, 0x49182707, 0x5500781b,   // ve.rw.da_443 to.ts.sn_322  gd.ga.to_432 ve.rw.un_770 
  0x43071da4, 0x791a6b09, 0x17001312, 0x18001302,   // la.it.ie_433 ceb.tl.war_444  et.sr.un_640 et.ga.un_220 
  0x5500780d, 0x5c213b09, 0x440a1704, 0x64590b07,   // ve.rw.un_540 so.jw.sa_444  sr.mk.kk_332 es.rn.lg_432 
  // [21a00]
  0x4b6a7811, 0x1a6b4daf, 0x272418af, 0x55006709,   // ve.haw.mi_653 aa.ceb.tl_655  ga.eo.gd_655 ak.rw.un_440 
  0x55003102, 0x597855af, 0x183bfc08, 0x58001119,   // az.rw.un_220 rw.ve.rn_655  zzp.so.ga_443 ro.om.un_750 
  0x430401a0, 0x6b006909, 0x58183bee, 0x387601a0,   // en.fi.ie_322 mfe.ceb.un_440  so.ga.om_422 en.crs.tk_322 
  0x652858a9, 0x58001808, 0x031205ee, 0x2e1c1ead,   // om.sw.gv_544 ga.om.un_430  fr.hu.nl_422 ms.id.fo_643 
  // [21a10]
  0xfc005807, 0x1b654d55, 0x481a1ba9, 0x795e09ee,   // om.zzp.un_420 aa.gv.tr_442  tr.tl.tt_544 pl.ts.war_422 
  0x3b4d58ad, 0x24463204, 0x4e4f67ac, 0x27005805,   // om.aa.so_643 bs.qu.eo_332  ak.bi.ay_632 om.gd.un_330 
  0x1d6e27a6, 0x3e0c5807, 0x4d796b0c, 0x0903400b,   // gd.hmn.la_521 om.sv.rm_432  ceb.war.aa_543 lb.nl.pl_542 
  0x05246eee, 0x3b586712, 0x581e1c09, 0x07005109,   // hmn.eo.fr_422 ak.om.so_654  id.ms.om_444 kl.it.un_440 
  // [21a20]
  0x4d796ba4, 0x08111002, 0x25064008, 0x3b2e0ea0,   // ceb.war.aa_433 lt.ro.no_222  lb.de.eu_443 is.fo.so_322 
  0x25062605, 0x050b36ad, 0xfc007605, 0x484c4e12,   // ia.de.eu_333 gn.es.fr_643  crs.zzp.un_330 ay.wo.tt_654 
  0x483b58a0, 0x3b4e5205, 0x39532fa0, 0x69257614,   // om.so.tt_322 ha.ay.so_333  su.ht.br_322 crs.eu.mfe_666 
  0x4600481a, 0x303c44a4, 0x2e120a04, 0x122425a4,   // tt.qu.un_760 kk.ug.uz_433  pt.hu.fo_332 eu.eo.hu_433 
  // [21a30]
  0x08231c0b, 0x032c0111, 0x3f00060b, 0x33081ea4,   // id.ca.no_542 en.fy.nl_653  de.af.un_520 ms.no.nn_433 
  0x1704150b, 0x12000a0c, 0x1c2b36ee, 0x483c3609,   // un.ru.sr_542 pt.hu.un_530  gn.vi.id_422 ab.ug.tt_444 
  0x43002412, 0x4236050d, 0x0b36450b, 0x4b00630c,   // eo.ie.un_640 fr.gn.co_554  ln.gn.es_542 sco.mi.un_530 
  0x190b0a0d, 0x2e0e180e, 0x230817af, 0x0b190eee,   // pt.es.gl_554 ga.is.fo_555  sr.uk.ky_655 is.gl.es_422 
  // [21a40]
  0x1d2f5fa0, 0x23041055, 0xfc494bee, 0x3610250e,   // tn.su.la_322 be.ru.ky_442  mi.to.zzp_422 mn.be.ab_555 
  0x5a650aa0, 0x64120208, 0x30233504, 0x0e5a3708,   // pt.gv.sm_322 da.hu.lg_443  tg.ky.uz_332 st.sm.is_443 
  0x0a000711, 0x68002013, 0x5d36470e, 0x1310240b,   // bg.mk.un_630 sq.ig.un_650  sn.gn.ss_555 eo.lt.et_542 
  0x440410a7, 0x1a006e0d, 0x100f0c09, 0x377858a9,   // be.ru.kk_532 hmn.tl.un_540  sv.lv.lt_444 om.ve.st_544 
  // [21a50]
  0x0e4a2ea4, 0x56285008, 0x476028ac, 0x28004723,   // fo.yo.is_433 fj.sw.mg_443  sw.vo.sn_632 sn.sw.un_880 
  0x3f2f28a0, 0x5747610c, 0x474336ec, 0x042261ad,   // sw.su.af_322 za.sn.na_543  gn.ie.sn_644 za.oc.fi_643 
  0x63434f07, 0x32043fa0, 0x393f0213, 0x43002a14,   // bi.ie.sco_432 af.fi.bs_322  da.af.br_665 mt.ie.un_660 
  0x136324a4, 0x101324a4, 0x06041d04, 0x360b485a,   // eo.sco.et_433 eo.et.lt_433  la.fi.de_332 tt.es.gn_553 
  // [21a60]
  0x36610b0d, 0x334f3807, 0x25006123, 0x4c464ea4,   // es.za.gn_554 tk.bi.nn_432  za.eu.un_880 ay.qu.wo_433 
  0x3020fe07, 0x0a001d0c, 0x360b61a9, 0x5e3b4d0c,   // tlh.sq.uz_432 la.pt.un_530  za.es.gn_544 aa.so.ts_543 
  0x4c006121, 0x0c003b04, 0x5865510c, 0x09005e0c,   // za.wo.un_860 so.sv.un_320  kl.gv.om_543 ts.pl.un_530 
  0x1a097905, 0x35514da4, 0x1d006118, 0x26613e11,   // war.pl.tl_333 aa.kl.zu_433  za.la.un_740 rm.za.ia_653 
  // [21a70]
  0x09100f11, 0x3e190a08, 0x016502ee, 0x0f7610ad,   // lv.lt.pl_653 pt.gl.rm_443  da.gv.en_422 lt.crs.lv_643 
  0x5c005e13, 0x28481d05, 0x05003621, 0x5e095f12,   // ts.sa.un_650 la.tt.sw_333  gn.fr.un_860 tn.pl.ts_654 
  0x1f00280c, 0x091f21a0, 0x40000907, 0x1137485a,   // sw.cy.un_530 jw.cy.pl_322  pl.lb.un_420 tt.ba.ro_553 
  0x033f5807, 0x30483412, 0x3f1827a0, 0x04004911,   // om.af.nl_432 xh.tt.uz_654  gd.ga.af_322 to.fi.un_630 
  // [21a80]
  0x2f391e0c, 0x23440707, 0x201a79a4, 0x24471902,   // ms.br.su_543 bg.kk.ky_432  war.tl.sq_433 gl.sn.eo_222 
  0x1a002722, 0x791e1c0c, 0x252f1c07, 0x0c5c0204,   // gd.tl.un_870 id.ms.war_543  id.su.eu_432 da.sa.sv_332 
  0x3f000312, 0x40002c0c, 0x061348a4, 0x1e362005,   // nl.af.un_640 fy.lb.un_530  tt.et.de_433 sq.gn.ms_333 
  0x52532ca0, 0x06091205, 0x5e2c45a4, 0x070835a6,   // fy.ht.ha_322 hu.pl.de_333  ln.fy.ts_433 tg.uk.bg_521 
  // [21a90]
  0x2dfc0f11, 0x38360ba0, 0x1f0979ee, 0x25002012,   // lv.zzp.sk_653 es.gn.tk_322  war.pl.cy_422 sq.eu.un_640 
  0x6b1e1aa4, 0x20252ba4, 0x0f003e18, 0x0900400c,   // tl.ms.ceb_433 vi.eu.sq_433  rm.lv.un_740 lb.pl.un_530 
  0x4900040c, 0x1e251ca4, 0x0f091212, 0x3b585113,   // fi.to.un_530 id.eu.ms_433  hu.pl.lv_654 kl.om.so_665 
  0x0f0227a4, 0x133f0309, 0x1e2025a7, 0x49000412,   // gd.da.lv_433 nl.af.et_444  eu.sq.ms_532 fi.to.un_640 
  // [21aa0]
  0x1e1c4fa4, 0x370a15a9, 0x472c62ad, 0x2c406507,   // bi.id.ms_433 un.mk.ba_544  kha.fy.sn_643 gv.lb.fy_432 
  0x036540a9, 0x65033f5a, 0x073038a4, 0x0300791b,   // lb.gv.nl_544 af.nl.gv_553  tk.uz.bg_433 war.nl.un_770 
  0x30001014, 0x1a2f110b, 0x5200672c, 0x3c3023ad,   // be.uz.un_660 ro.su.tl_542  ak.ha.un_990 ky.uz.ug_643 
  0x1e1c520e, 0x501156ad, 0x0c604811, 0x521a01a6,   // ha.id.ms_555 mg.ro.fj_643  tt.vo.sv_653 en.tl.ha_521 
  // [21ab0]
  0x3530250e, 0x47212f13, 0x56215207, 0x4b594aa4,   // mn.uz.tg_555 su.jw.sn_665  ha.jw.mg_432 yo.rn.mi_433 
  0x223e1e07, 0x3900690e, 0x5f4d52a4, 0x55004505,   // ms.rm.oc_432 mfe.br.un_550  ha.aa.tn_433 ln.rw.un_330 
  0x0d212da7, 0x11672912, 0x1b505208, 0x56003407,   // sk.jw.cs_532 sl.ak.ro_654  ha.fj.tr_443 xh.mg.un_420 
  0x5a4e2812, 0x680264ad, 0x22695355, 0x64685709,   // sw.ay.sm_654 lg.da.ig_643  ht.mfe.oc_442 na.ig.lg_444 
  // [21ac0]
  0x321d5a07, 0x4f002009, 0x2f5052ac, 0x29002408,   // sm.la.bs_432 sq.bi.un_440  ha.fj.su_632 eo.sl.un_430 
  0x4a026205, 0x58194a07, 0x63122e55, 0x5d594507,   // kha.da.yo_333 yo.gl.om_432  fo.hu.sco_442 ln.rn.ss_432 
  0x18002902, 0x65231f08, 0x300811a7, 0x560b2555,   // sl.ga.un_220 cy.ca.gv_443  ro.uk.uz_532 eu.es.mg_442 
  0x55321708, 0x05321fee, 0x3b5827ec, 0x4810040c,   // sr.bs.rw_443 cy.bs.fr_422  gd.om.so_644 ru.be.tt_543 
  // [21ad0]
  0x0a353002, 0x4b000209, 0x1b6b38a4, 0xfe386b07,   // uz.tg.mk_222 da.mi.un_440  tk.ceb.tr_433 ceb.tk.tlh_432 
  0x2443560c, 0x272f76a4, 0x65270409, 0x283c18ac,   // mg.ie.eo_543 crs.su.gd_433  fi.gd.gv_444 ar.ug.sd_632 
  0x76692408, 0x09060304, 0x2c00602a, 0x3021120e,   // eo.mfe.crs_443 nl.de.pl_332  vo.fy.un_970 ur.fa.uz_555 
  0x3f005707, 0x052f2107, 0x60020507, 0x202c2d12,   // na.af.un_420 jw.su.fr_432  fr.da.vo_432 sk.fy.sq_654 
  // [21ae0]
  0x3d343c07, 0x032c40ad, 0x02081d0b, 0x03400612,   // ug.ps.ku_432 lb.fy.nl_643  la.no.da_542 de.lb.nl_654 
  0x474b5aa0, 0x1e1c63ee, 0x042c3fee, 0x193f0b11,   // sm.mi.sn_322 sco.id.ms_422  af.fy.fi_422 es.af.gl_653 
  0x353463ec, 0x03000620, 0x733534ec, 0xfc00012b,   // sco.xh.zu_644 de.nl.un_850  xh.zu.ny_644 en.zzp.un_980 
  0x11276511, 0x1e003112, 0xfc3501a0, 0x22232a07,   // gv.gd.ro_653 az.ms.un_640  en.zu.zzp_322 mt.ca.oc_432 
  // [21af0]
  0x2a353405, 0x31fe2207, 0x2d002005, 0x405c5ba7,   // xh.zu.mt_333 oc.tlh.az_432  sq.sk.un_330 sg.sa.lb_532 
  0x173c150d, 0x4600221a, 0x5c286807, 0x3602730c,   // un.ug.sr_554 oc.qu.un_760  ig.sw.sa_432 ny.da.gn_543 
  0xfe584607, 0x31222a07, 0x10381507, 0x392430a4,   // qu.om.tlh_432 mt.oc.az_432  un.tk.be_432 uz.eo.br_433 
  0x5d6835a4, 0x35283407, 0x52001e04, 0x443710a4,   // zu.ig.ss_433 xh.sw.zu_432  ms.ha.un_320 be.ba.kk_433 
  // [21b00]
  0x271861a7, 0x233616a0, 0x2b006111, 0x32463ea0,   // za.ga.gd_532 hr.gn.ca_322  za.vi.un_630 rm.qu.bs_322 
  0x44343c0c, 0x35101507, 0x28355d0d, 0x27003b0d,   // ug.ps.kk_543 un.be.tg_432  ss.zu.sw_554 so.gd.un_540 
  0x081017ec, 0xfe001813, 0x3b3d445a, 0x081715a4,   // sr.be.uk_644 ga.tlh.un_650  kk.ku.ks_553 un.sr.uk_433 
  0x6306fc04, 0x350407a9, 0x0302430b, 0x3465fcad,   // zzp.de.sco_332 bg.ru.tg_544  ie.da.nl_542 zzp.gv.xh_643 
  // [21b10]
  0x081004a7, 0xfc3830a0, 0x1700380e, 0x2f181902,   // ru.be.uk_532 uz.tk.zzp_322  tk.sr.un_550 gl.ga.su_222 
  0x184205ee, 0x212f18a7, 0x183c4413, 0x031302a0,   // fr.co.ga_422 ga.su.jw_532  kk.ug.ar_665 da.et.nl_322 
  0x21182f0c, 0x13003f14, 0x0b1805a7, 0x5d3559ee,   // su.ga.jw_543 af.et.un_660  fr.ga.es_532 rn.zu.ss_422 
  0x3725110c, 0x507864a9, 0x64286807, 0x3e2e33a0,   // ro.mn.ba_543 lg.ve.fj_544  ig.sw.lg_432 nn.fo.rm_322 
  // [21b20]
  0x30351702, 0x2a645ea9, 0xfc193502, 0x4e53760c,   // sr.tg.uz_222 ts.lg.mt_544  zu.gl.zzp_222 crs.ht.ay_543 
  0x1bfc680b, 0x3b4d1da4, 0x383b2e12, 0x3b671a0c,   // ig.zzp.tr_542 la.aa.so_433  fo.so.tk_654 tl.ak.so_543 
  0x1800050c, 0x65571d07, 0x4d4a58a4, 0x65273b05,   // fr.ga.un_530 la.na.gv_432  om.yo.aa_433 so.gd.gv_333 
  0x21041a0c, 0x183b2760, 0x3b395802, 0x52567808,   // tl.fi.jw_543 gd.so.ga_664  om.br.so_222 ve.mg.ha_443 
  // [21b30]
  0x01fc0508, 0x59091105, 0x52003b0e, 0x2e003b21,   // fr.zzp.en_443 ro.pl.rn_333  so.ha.un_550 so.fo.un_860 
  0x342847a4, 0x1b000d09, 0x30583bad, 0x10083504,   // sn.sw.xh_433 cs.tr.un_440  so.om.uz_643 tg.uk.be_332 
  0x304d3bad, 0x52427907, 0x4d303ba4, 0x793b46a0,   // so.aa.uz_643 war.co.ha_432  so.uz.aa_433 qu.so.war_322 
  0x653e15a0, 0x31003b13, 0x04110aa9, 0x020a11a4,   // un.rm.gv_322 so.az.un_650  pt.ro.fi_544 ro.pt.da_433 
  // [21b40]
  0x501047a4, 0x343d3cee, 0x111d27a0, 0x4838445a,   // sn.lt.fj_433 ug.ku.ps_422  gd.la.ro_322 kk.tk.tt_553 
  0x23001018, 0x34233c09, 0x53066207, 0x3f330307,   // be.ky.un_740 ug.ky.ps_444  kha.de.ht_432 nl.nn.af_432 
  0x355d28ee, 0x04004213, 0x5efe5505, 0x443c3009,   // sw.ss.zu_422 co.fi.un_650  rw.tlh.ts_333 uz.ug.kk_444 
  0x73006114, 0x20fe7812, 0x13064005, 0x23000714,   // za.ny.un_660 ve.tlh.sq_654  lb.de.et_333 bg.ky.un_660 
  // [21b50]
  0x0f00110c, 0x5100110c, 0x595539ec, 0x061d0c05,   // ro.lv.un_530 ro.kl.un_530  br.rw.rn_644 sv.la.de_333 
  0x28001f05, 0x6955590c, 0x33060c0c, 0xfe7913a4,   // cy.sw.un_330 rn.rw.mfe_543  sv.de.nn_543 et.war.tlh_433 
  0x302915a0, 0x091230ee, 0x17154805, 0x16004b08,   // un.sl.uz_322 uz.hu.pl_422  tt.sr.un_330 mi.hr.un_430 
  0x3f001f22, 0x3f375d05, 0x1300390b, 0xfe003e12,   // cy.af.un_870 ss.st.af_333  br.et.un_520 rm.tlh.un_640 
  // [21b60]
  0x35002609, 0x050643ee, 0x21002018, 0x0500180d,   // ia.zu.un_440 ie.de.fr_422  sq.jw.un_740 ga.fr.un_540 
  0x2858490c, 0x4d6b3b09, 0x06190b55, 0x2f001c09,   // to.om.sw_543 so.ceb.aa_444  es.gl.de_442 id.su.un_440 
  0x17041511, 0x6b794da4, 0x555f1007, 0x673b4d11,   // un.ru.sr_653 aa.war.ceb_433  lt.tn.rw_432 aa.so.ak_653 
  0x6959500c, 0x68583b0c, 0x1c5c2f11, 0x3b51580c,   // fj.rn.mfe_543 so.om.ig_543  su.sa.id_653 om.kl.so_543 
  // [21b70]
  0x07044855, 0x10555304, 0x557302a7, 0x531047ee,   // tt.ru.bg_442 ht.rw.lt_332  da.ny.rw_532 sn.lt.ht_422 
  0x03681207, 0x642610a7, 0x58643b60, 0x47022608,   // hu.ig.nl_432 lt.ia.lg_532  so.lg.om_664 ia.da.sn_443 
  0x636513ec, 0x645f10ee, 0x58133ba9, 0x2f1e1cad,   // et.gv.sco_644 lt.tn.lg_422  so.et.om_544 id.ms.su_643 
  0x133f6704, 0x07483002, 0x3c302311, 0x2112300e,   // ak.af.et_332 uz.tt.bg_222  ky.uz.ug_653 uz.ur.fa_555 
  // [21b80]
  0x35792f08, 0x231e2fa0, 0x484410af, 0x040737ad,   // su.war.zu_443 su.ms.ca_322  be.kk.tt_655 ba.bg.ru_643 
  0x350d6a0b, 0x24684a5a, 0x091110a4, 0x4a4268ec,   // haw.cs.zu_542 yo.ig.eo_553  lt.ro.pl_433 ig.co.yo_644 
  0x0a3536a7, 0x13684ea9, 0x08633307, 0x562873af,   // gn.zu.pt_532 ay.ig.et_544  nn.sco.no_432 ny.sw.mg_655 
  0x392040ad, 0x44042507, 0x366a670e, 0x4f100907,   // lb.sq.br_643 mn.ru.kk_432  ak.haw.gn_555 pl.lt.bi_432 
  // [21b90]
  0x4b002519, 0x49004004, 0x4f003313, 0x4b00680d,   // eu.mi.un_750 lb.to.un_320  nn.bi.un_650 ig.mi.un_540 
  0x27391f07, 0x0c0e63a0, 0x6800580e, 0x15233804,   // cy.br.gd_432 sco.is.sv_322  om.ig.un_550 tk.ky.un_332 
  0x5e005805, 0x1a005802, 0x391f6eee, 0x48002518,   // om.ts.un_330 om.tl.un_220  hmn.cy.br_422 mn.tt.un_740 
  0x040e33a0, 0x3b007908, 0x1a006e04, 0x36000a1a,   // nn.is.fi_322 war.so.un_430  hmn.tl.un_320 pt.gn.un_760 
  // [21ba0]
  0x52000502, 0x581a3b0d, 0x28343d02, 0x0c0802a0,   // fr.ha.un_220 so.tl.om_554  ku.ps.sd_222 da.no.sv_322 
  0x2d002807, 0x64033fec, 0x674d64af, 0x4d6764a9,   // sw.sk.un_420 af.nl.lg_644  lg.aa.ak_655 lg.ak.aa_544 
  0x3e230a0c, 0x51002813, 0x372535a0, 0x5a003302,   // pt.ca.rm_543 sw.kl.un_650  tg.mn.ba_322 nn.sm.un_220 
  0x30004319, 0x0f0e13af, 0x7334470c, 0x100a04a4,   // ie.uz.un_750 et.is.lv_655  sn.xh.ny_543 ru.mk.be_433 
  // [21bb0]
  0x1d001304, 0x5e652aee, 0x53042fa4, 0x103e0fa0,   // et.la.un_320 mt.gv.ts_422  su.fi.ht_433 lv.rm.lt_322 
  0x304823ad, 0x1d3e1304, 0x476456a4, 0x561e1c0c,   // ky.tt.uz_643 et.rm.la_332  mg.lg.sn_433 id.ms.mg_543 
  0x25133bee, 0x3b002707, 0x65390e12, 0x46006308,   // so.et.eu_422 gd.so.un_420  is.br.gv_654 sco.qu.un_430 
  0x792439a9, 0x081f65a0, 0x05fc5708, 0x3b684aee,   // br.eo.war_544 gv.cy.no_322  na.zzp.fr_443 yo.ig.so_422 
  // [21bc0]
  0x101d130c, 0x1d3e24a4, 0x1707360c, 0x273b6413,   // et.la.lt_543 eo.rm.la_433  ab.bg.sr_543 lg.so.gd_665 
  0x1a3e6b12, 0x1b235c0c, 0x0c583b14, 0x1f790a04,   // ceb.rm.tl_654 sa.ca.tr_543  so.om.sv_666 pt.war.cy_332 
  0x63183912, 0x233c15a9, 0x58001e02, 0x480410a7,   // br.ga.sco_654 un.ug.ky_544  ms.om.un_220 be.ru.tt_532 
  0x23182709, 0x0e2e390c, 0x11000e21, 0x180e51ac,   // gd.ga.ca_444 br.fo.is_543  is.ro.un_860 kl.is.ga_632 
  // [21bd0]
  0x2506fcad, 0x180633a4, 0x27001c08, 0x21251cec,   // zzp.de.eu_643 nn.de.ga_433  id.gd.un_430 id.eu.jw_644 
  0x0b0e5107, 0x2e255c08, 0x11003f07, 0x0c521fa4,   // kl.is.es_432 sa.eu.fo_443  af.ro.un_420 cy.ha.sv_433 
  0x2e185108, 0x3b10580c, 0x04212fa9, 0x3b06270e,   // kl.ga.fo_443 om.lt.so_543  su.jw.fi_544 gd.de.so_555 
  0x3f464308, 0x291f060d, 0x2e650ca4, 0x3700670c,   // ie.qu.af_443 de.cy.sl_554  sv.gv.fo_433 ak.st.un_530 
  // [21be0]
  0x1100070c, 0x2e6539ad, 0x0722620c, 0x521b25ec,   // it.ro.un_530 br.gv.fo_643  kha.oc.it_543 eu.tr.ha_644 
  0x2e525caf, 0x06363304, 0x2500071a, 0x25513107,   // sa.ha.fo_655 nn.gn.de_332  it.eu.un_760 az.kl.eu_432 
  0x0a3748ee, 0x21073fad, 0x4d511c0b, 0x020d4fee,   // tt.ba.mk_422 af.it.jw_643  id.kl.aa_542 bi.cs.da_422 
  0x48006b07, 0x3c4418ad, 0x4a182707, 0x3f001812,   // ceb.tt.un_420 ar.kk.ug_643  gd.ga.yo_432 ga.af.un_640 
  // [21bf0]
  0x40002108, 0x473b1e0c, 0x163362ee, 0x653f0308,   // jw.lb.un_430 ms.so.sn_543  kha.nn.hr_422 nl.af.gv_443 
  0x01001004, 0x67004a19, 0x3b61580c, 0x46054e08,   // lt.en.un_320 yo.ak.un_750  om.za.so_543 ay.fr.qu_443 
  0x5b4e6709, 0x15040aaf, 0x08005105, 0x063669ee,   // ak.ay.sg_444 mk.ru.un_655  kl.no.un_330 mfe.gn.de_422 
  0x46401da0, 0x10005a1b, 0x050e42a0, 0x613505a4,   // la.lb.qu_322 sm.lt.un_770  co.is.fr_322 fr.zu.za_433 
  
  // [21c00]
  0x23120d09, 0x58616708, 0x65000705, 0x4c4e4608,   // cs.hu.ca_444 ak.za.om_443  it.gv.un_330 qu.ay.wo_443 
  0x1c070fa0, 0x303c3508, 0x30233707, 0x0825100c,   // lv.it.id_322 tg.ug.uz_443  ba.ky.uz_432 be.mn.uk_543 
  0x31460207, 0x2f006e07, 0x1d5a4208, 0x0532200d,   // da.qu.az_432 hmn.su.un_420  co.sm.la_443 sq.bs.fr_554 
  0x03051f04, 0x63fe02a9, 0x3b3435ee, 0x05002312,   // cy.fr.nl_332 da.tlh.sco_544  zu.xh.so_422 ca.fr.un_640 
  // [21c10]
  0x30233412, 0x19222307, 0x3e291e08, 0x383f245a,   // ps.ky.uz_654 ca.oc.gl_432  ms.sl.rm_443 eo.af.tk_553 
  0x1f003808, 0x1000fe0c, 0x7900fe1a, 0x1710080b,   // tk.cy.un_430 tlh.lt.un_530  tlh.war.un_760 uk.be.sr_542 
  0x123073ac, 0x1d080204, 0x3000730c, 0x0f00730d,   // ny.uz.hu_632 da.no.la_332  ny.uz.un_530 ny.lv.un_540 
  0x637347a0, 0x1b300f04, 0x524d1b12, 0x4e3f4c0d,   // sn.ny.sco_322 lv.uz.tr_332  tr.aa.ha_654 wo.af.ay_554 
  // [21c20]
  0x35071002, 0xfc0556a0, 0x07261d12, 0x653e4209,   // be.bg.tg_222 mg.fr.zzp_322  la.ia.it_654 co.rm.gv_444 
  0x15253508, 0x651f5808, 0x30001921, 0x1800442a,   // tg.mn.un_443 om.cy.gv_443  gl.uz.un_860 kk.ar.un_970 
  0x460973a9, 0x13510712, 0x181621a4, 0x04080aa9,   // ny.pl.qu_544 it.kl.et_654  fa.th.ar_433 mk.uk.ru_544 
  0x650320a4, 0x51005808, 0x7835345a, 0x33021008,   // sq.nl.gv_433 om.kl.un_430  xh.zu.ve_553 lt.da.nn_443 
  // [21c30]
  0x103f3307, 0x10060107, 0x4f13400c, 0x191d2255,   // nn.af.lt_432 en.de.lt_432  lb.et.bi_543 oc.la.gl_442 
  0x48303513, 0x2f3e27ad, 0x654006af, 0x44482355,   // tg.uz.tt_665 gd.rm.su_643  de.lb.gv_655 ky.tt.kk_442 
  0x22271808, 0x1d2c0b04, 0x05120b05, 0x06571fa4,   // ga.gd.oc_443 es.fy.la_332  es.hu.fr_333 cy.na.de_433 
  0x21302807, 0x0d09fe07, 0x240b1907, 0x055565ee,   // sd.uz.fa_432 tlh.pl.cs_432  gl.es.eo_432 gv.rw.fr_422 
  // [21c40]
  0x34654704, 0x3b00fe0e, 0x1d000a07, 0x56215e08,   // sn.gv.xh_332 tlh.so.un_550  pt.la.un_420 ts.jw.mg_443 
  0x1712640c, 0x4846fea9, 0x133308a4, 0x581d01a0,   // lg.hu.sr_543 tlh.qu.tt_544  no.nn.et_433 en.la.om_322 
  0x60211ca0, 0x492710ee, 0x3e112205, 0x2056290c,   // id.jw.vo_322 lt.gd.to_422  oc.ro.rm_333 sl.mg.sq_543 
  0x635f1307, 0x3e190aad, 0x4306400d, 0x18275a08,   // et.tn.sco_432 pt.gl.rm_643  lb.de.ie_554 sm.gd.ga_443 
  // [21c50]
  0x421805a7, 0x1000132c, 0x64201108, 0x0b003b04,   // fr.ga.co_532 et.lt.un_990  ro.sq.lg_443 so.es.un_320 
  0x271843a0, 0x270519a0, 0x190a020b, 0x0603400c,   // ie.ga.gd_322 gl.fr.gd_322  da.pt.gl_542 lb.nl.de_543 
  0x18273bec, 0x19401307, 0x47000a08, 0x39205607,   // so.gd.ga_644 et.lb.gl_432  pt.sn.un_430 mg.sq.br_432 
  0x3e190a04, 0x55004c1b, 0x42263e55, 0x6b003e12,   // pt.gl.rm_332 wo.rw.un_770  rm.ia.co_442 rm.ceb.un_640 
  // [21c60]
  0x484d5e12, 0x0a150804, 0x5e135aa4, 0x3e115a07,   // ts.aa.tt_654 uk.mk.un_320  sm.et.ts_433 sm.ro.rm_432 
  0x63074f0c, 0x20004d08, 0x2300181b, 0x505d5e08,   // bi.it.sco_543 aa.sq.un_430  ar.ky.un_770 ts.ss.fj_443 
  0x58483060, 0x5f1f180c, 0x1d1122a7, 0x40002212,   // uz.tt.om_664 ga.cy.tn_543  oc.ro.la_532 oc.lb.un_640 
  0x020a57af, 0x38482513, 0x3830350c, 0x1715480c,   // na.pt.da_655 mn.tt.tk_665  tg.uz.tk_543 tt.sr.un_530 
  // [21c70]
  0x5a6a3608, 0x230a0709, 0x621c5b0e, 0x060a21a0,   // gn.haw.sm_443 bg.mk.ky_444  sg.id.kha_555 jw.pt.de_322 
  0x6a00361b, 0x46364308, 0x1e5a360c, 0x42005311,   // gn.haw.un_770 ie.gn.qu_443  gn.sm.ms_543 ht.co.un_630 
  0x190d2da0, 0x2e0d2dee, 0x0a002d02, 0x33082005,   // sk.cs.gl_322 sk.cs.fo_422  sk.pt.un_220 sq.no.nn_333 
  0x443428ee, 0x391a79ec, 0x352834a0, 0x20fc65a9,   // sd.ps.kk_422 war.tl.br_644  xh.sw.zu_322 gv.zzp.sq_544 
  // [21c80]
  0x30350a0b, 0x0a0408a7, 0x0d33085a, 0x2ffe6211,   // mk.tg.uz_542 uk.ru.mk_532  no.nn.cs_553 kha.tlh.su_653 
  0x46094ead, 0x320216a4, 0x1015080c, 0x2d6a37ec,   // ay.pl.qu_643 hr.da.bs_433  uk.be.un_530 st.haw.sk_644 
  0x15153012, 0x4b490209, 0x07003902, 0x562f1c04,   // uz.un.un_640 da.to.mi_444  br.it.un_220 id.su.mg_332 
  0x2d005c14, 0x083037a7, 0x48103cec, 0x32290f07,   // sa.sk.un_660 ba.uz.uk_532  ug.be.tt_644 lv.sl.bs_432 
  // [21c90]
  0x133435ee, 0x07083c0c, 0x534f1304, 0xfc003313,   // zu.xh.et_422 ug.uk.bg_543  et.bi.ht_332 nn.zzp.un_650 
  0x4c582812, 0x3902630c, 0x375e5d14, 0x32583b0b,   // sw.om.wo_654 sco.da.br_543  ss.ts.st_666 so.om.bs_542 
  0x273961ad, 0x0f3b5808, 0x3b3ffc0d, 0x796b4c0c,   // za.br.gd_643 om.so.lv_443  zzp.af.so_554 wo.ceb.war_543 
  0x40064c11, 0x08006b20, 0x363f63a0, 0x1f005811,   // wo.de.lb_653 ceb.no.un_850  sco.af.gn_322 om.cy.un_630 
  // [21ca0]
  0x300410a4, 0x212f4cec, 0x0a000e13, 0x2f003b09,   // be.ru.uz_433 wo.su.jw_644  is.pt.un_650 so.su.un_440 
  0x6900020e, 0x1b30315a, 0x21796b0c, 0x30213d05,   // da.mfe.un_550 az.uz.tr_553  ceb.war.jw_543 ku.fa.uz_333 
  0x02000305, 0x1b633011, 0x5f613760, 0x1d391304,   // nl.da.un_330 uz.sco.tr_653  st.za.tn_664 et.br.la_332 
  0x403f1304, 0x55003005, 0x06180807, 0x2f0e4c0c,   // et.af.lb_332 uz.rw.un_330  no.ga.de_432 wo.is.su_543 
  // [21cb0]
  0x6e6b4c08, 0x40000312, 0x1048445a, 0x1f001002,   // wo.ceb.hmn_443 nl.lb.un_640  kk.tt.be_553 lt.cy.un_220 
  0x36002e1a, 0x2a005f09, 0x752e0e0c, 0x34002312,   // fo.gn.un_760 tn.mt.un_440  is.fo.nso_543 ky.ps.un_640 
  0x1f195214, 0x16131e08, 0x39000e08, 0x173720ee,   // ha.gl.cy_666 ms.et.hr_443  is.br.un_430 sq.st.sr_422 
  0x4a2a5912, 0x56001508, 0x49005204, 0x2a005912,   // rn.mt.yo_654 un.mg.un_430  ha.to.un_320 rn.mt.un_640 
  // [21cc0]
  0x3f182755, 0x28115908, 0x36585c07, 0x0c365614,   // gd.ga.af_442 rn.ro.sw_443  sa.om.gn_432 mg.gn.sv_666 
  0x24206708, 0x1c6967ad, 0x5c001019, 0x4228455a,   // ak.sq.eo_443 ak.mfe.id_643  lt.sa.un_750 ln.sw.co_553 
  0x50043e07, 0x58004a07, 0x3e423607, 0x403905a4,   // rm.fi.fj_432 yo.om.un_420  gn.co.rm_432 fr.br.lb_433 
  0x15382513, 0x3b4d6412, 0x35004204, 0x3e007813,   // mn.tk.un_665 lg.aa.so_654  co.zu.un_320 ve.rm.un_650 
  // [21cd0]
  0x1d57620c, 0x13006409, 0x3559285a, 0x0d004b04,   // kha.na.la_543 lg.et.un_440  sw.rn.zu_553 mi.cs.un_320 
  0x6a0e1b0c, 0x08025502, 0x10300f05, 0x495a5004,   // tr.is.haw_543 rw.da.no_222  lv.uz.lt_333 fj.sm.to_332 
  0x42245012, 0x08225307, 0x31421b14, 0x53522909,   // fj.eo.co_654 ht.oc.no_432  tr.co.az_666 sl.ha.ht_444 
  0x49004219, 0x5a494bec, 0x1b3802a9, 0x211c20a0,   // co.to.un_750 mi.to.sm_644  da.tk.tr_544 sq.id.jw_322 
  // [21ce0]
  0x042310a0, 0x04007819, 0x13400605, 0x1507100c,   // be.ky.ru_322 ve.fi.un_750  de.lb.et_333 be.bg.un_543 
  0x13002608, 0x67001e12, 0x111233a0, 0x121b3807,   // ia.et.un_430 ms.ak.un_640  nn.hu.ro_322 tk.tr.hu_432 
  0x2c4f2908, 0x13381b08, 0x10004508, 0x17043007,   // sl.bi.fy_443 tr.tk.et_443  ln.lt.un_430 uz.ru.sr_432 
  0x534a2207, 0x5d000d05, 0x38330802, 0x1d1013a0,   // oc.yo.ht_432 cs.ss.un_330  no.nn.tk_222 et.lt.la_322 
  // [21cf0]
  0x1f00760d, 0x12003802, 0x1f697660, 0x10002407,   // crs.cy.un_540 tk.hu.un_220  crs.mfe.cy_664 eo.lt.un_420 
  0x5d002005, 0x5dfa12ad, 0x332f63ad, 0x55007908,   // sq.ss.un_330 hu.nr.ss_643  sco.su.nn_643 war.rw.un_430 
  0x2128360c, 0x37001511, 0x21001e0d, 0xfc761c07,   // gn.sw.jw_543 un.ba.un_630  ms.jw.un_540 id.crs.zzp_432 
  0x07041755, 0x23374811, 0x1c000204, 0x4b002f14,   // sr.ru.bg_442 tt.ba.ky_653  da.id.un_320 su.mi.un_660 
  // [21d00]
  0x3f001313, 0x351e1ca7, 0x1100fc09, 0x1b2039a0,   // et.af.un_650 id.ms.zu_532  zzp.ro.un_440 br.sq.tr_322 
  0x3f4c3eee, 0x2a2838ad, 0x3200390c, 0x58001521,   // rm.wo.af_422 tk.sw.mt_643  br.bs.un_530 un.om.un_860 
  0x23374411, 0x190b2d05, 0x73003608, 0x39005d07,   // kk.ba.ky_653 sk.es.gl_333  gn.ny.un_430 ss.br.un_420 
  0x5d643555, 0x033f600e, 0x0e2e0804, 0x0e2e200c,   // zu.lg.ss_442 vo.af.nl_555  no.fo.is_332 sq.fo.is_543 
  // [21d10]
  0x494b2f08, 0x40064ba0, 0x1c004904, 0x65fc01a0,   // su.mi.to_443 mi.de.lb_322  to.id.un_320 en.zzp.gv_322 
  0x4c00120c, 0x080a3013, 0x34123da7, 0x301511a4,   // hu.wo.un_530 uz.mk.uk_665  ku.ur.ps_532 ro.uz.un_430 
  0x48043705, 0x234410ad, 0x6500090c, 0x024e7355,   // ba.ru.tt_333 be.kk.ky_643  pl.gv.un_530 ny.ay.da_442 
  0x21653902, 0x53fc640b, 0x182b27a6, 0x5d213513,   // br.gv.jw_222 lg.zzp.ht_542  gd.vi.ga_521 zu.jw.ss_665 
  // [21d20]
  0x574e7311, 0x555759ad, 0x1d64fcad, 0x1f00391b,   // ny.ay.na_653 rn.na.rw_643  zzp.lg.la_643 br.cy.un_770 
  0x78005714, 0x2c482aee, 0x1508040b, 0x0c3702a7,   // na.ve.un_660 mt.tt.fy_422  ru.uk.un_542 da.st.sv_532 
  0x76690807, 0x477355a4, 0x343b12af, 0x123428af,   // no.mfe.crs_432 rw.ny.sn_433  ur.ks.ps_655 sd.ps.ur_655 
  0x021d5712, 0x11511d0c, 0x012d1da0, 0x20512e07,   // na.la.da_654 la.kl.ro_543  la.sk.en_322 fo.kl.sq_432 
  // [21d30]
  0x2d1d1d07, 0x02241dee, 0x09004804, 0x02111dad,   // la.la.sk_432 la.eo.da_422  tt.pl.un_320 la.ro.da_643 
  0x2d0d11af, 0x2d001913, 0x47111d07, 0x4b1d1111,   // ro.cs.sk_655 gl.sk.un_650  la.ro.sn_432 ro.la.mi_653 
  0x10111da7, 0x422a4daf, 0x51111d13, 0x43004223,   // la.ro.lt_532 aa.mt.co_655  la.ro.kl_665 co.ie.un_880 
  0x11000d05, 0x650e0605, 0x301123af, 0x28535aa0,   // cs.ro.un_330 de.is.gv_333  ky.ro.uz_655 sm.ht.sw_322 
  // [21d40]
  0x3953050c, 0x17006018, 0x35341b05, 0x4d37130c,   // fr.ht.br_543 vo.sr.un_740  tr.xh.zu_333 et.st.aa_543 
  0x04376aad, 0x12484a0d, 0x105f5a07, 0x75375d0d,   // haw.st.fi_643 yo.tt.hu_554  sm.tn.lt_432 ss.st.nso_554 
  0x0d0e1704, 0x35104807, 0x064068a7, 0x2a1f2508,   // sr.is.cs_332 tt.lt.zu_432  ig.lb.de_532 eu.cy.mt_443 
  0x16292da0, 0x30003f07, 0x06512507, 0x11006a0d,   // sk.sl.hr_322 af.uz.un_420  eu.kl.de_432 haw.ro.un_540 
  // [21d50]
  0x1015fcee, 0x06fc0e0b, 0x3015070d, 0x3f0e39a0,   // zzp.lt.un_420 is.zzp.de_542  bg.uz.un_540 br.is.af_322 
  0x03094307, 0x01002704, 0xfc375f08, 0x73004209,   // ie.pl.nl_432 gd.en.un_320  tn.st.zzp_443 co.ny.un_440 
  0x1e1c48ee, 0x2a106a5a, 0x030402a4, 0x2d100f08,   // tt.id.ms_422 haw.lt.mt_553  da.fi.nl_433 lv.lt.sk_443 
  0x59003609, 0x09102d12, 0x13001b0c, 0x5c0436a7,   // gn.rn.un_440 sk.lt.pl_654  tr.et.un_530 gn.fi.sa_532 
  // [21d60]
  0x052f1902, 0x100a1505, 0x0f022da9, 0x3f00101b,   // gl.su.fr_222 un.mk.be_333  sk.da.lv_544 lt.af.un_770 
  0x0f100404, 0x6a40090c, 0x440804a4, 0x2a0f10af,   // fi.lt.lv_332 pl.lb.haw_543  ru.uk.kk_433 lt.lv.mt_655 
  0x040a15a9, 0x193b235a, 0x19003b04, 0x39222307,   // un.mk.ru_544 ca.so.gl_553  so.gl.un_320 ca.oc.br_432 
  0x0417100d, 0x1655685a, 0x79163305, 0x19003004,   // be.sr.ru_554 ig.rw.hr_553  nn.hr.war_333 uz.gl.un_320 
  // [21d70]
  0x31025709, 0x09002502, 0x4c2a19ee, 0x317669ad,   // na.da.az_444 eu.pl.un_220  gl.mt.wo_422 mfe.crs.az_643 
  0x1c2930a0, 0x5c6967a4, 0x231711a7, 0x691b7613,   // uz.sl.id_322 ak.mfe.sa_433  ro.sr.ky_532 crs.tr.mfe_665 
  0x67fc310c, 0x6913290c, 0x19233b02, 0x4964280c,   // az.zzp.ak_543 sl.et.mfe_543  so.ca.gl_222 sw.lg.to_543 
  0x2e3b12ee, 0x0e4e2e12, 0x352d0ca4, 0x1b2e0ea9,   // hu.so.fo_422 fo.ay.is_654  sv.sk.zu_433 is.fo.tr_544 
  // [21d80]
  0x2f313007, 0x5c050e0b, 0x321b0e08, 0x353467a7,   // uz.az.su_432 is.fr.sa_542  is.tr.bs_443 ak.xh.zu_532 
  0x2d00200c, 0x20004907, 0x302ffea0, 0x286a3704,   // sq.sk.un_530 to.sq.un_420  tlh.su.uz_322 st.haw.sw_332 
  0x0a3756a0, 0x151f37a0, 0x3f030407, 0x28045655,   // mg.st.pt_322 st.cy.un_322  fi.nl.af_432 mg.fi.sw_442 
  0x191f1da0, 0x3f2c03af, 0x5e004602, 0x050a04ed,   // la.cy.gl_322 nl.fy.af_655  qu.ts.un_220 fi.pt.fr_622 
  // [21d90]
  0x281f470b, 0x395f0204, 0x1138150c, 0x01fc28ee,   // sn.cy.sw_542 da.tn.br_332  un.tk.ro_543 sw.zzp.en_422 
  0x221d6104, 0x07223fa0, 0x381f620c, 0x4021390c,   // za.la.oc_332 af.oc.it_322  kha.cy.tk_543 br.jw.lb_543 
  0x4c395302, 0x1f004007, 0x18276e12, 0x103e0f14,   // ht.br.wo_222 lb.cy.un_420  hmn.gd.ga_654 lv.rm.lt_666 
  0x104f3ea4, 0x4f001f14, 0x0f190a08, 0x302348ee,   // rm.bi.lt_433 cy.bi.un_660  pt.gl.lv_443 tt.ca.uz_422 
  // [21da0]
  0x303635a0, 0x071523ee, 0x29210aee, 0x10190f12,   // tg.ab.uz_322 ky.bg.un_420  pt.jw.sl_422 lv.gl.lt_654 
  0x425c0507, 0x467321a9, 0x0f1005a4, 0x4c1f21a0,   // fr.sa.co_432 jw.ny.qu_544  fr.lt.lv_433 jw.cy.wo_322 
  0x0f1810a9, 0x47463f05, 0x104f0508, 0x191023a7,   // lt.ga.lv_544 af.qu.sn_333  fr.bi.lt_443 ca.lt.gl_532 
  0x463f03a7, 0x383f0c04, 0x584a3bad, 0x44351002,   // nl.af.qu_532 sv.af.tk_332  so.yo.om_643 be.tg.kk_222 
  // [21db0]
  0xfc004b0c, 0x2e330eaf, 0x3b2f2104, 0x496a420c,   // mi.zzp.un_530 is.nn.fo_655  jw.su.so_332 co.haw.to_543 
  0x6a002f1b, 0x130d50a0, 0x36395aa4, 0x735a4c0c,   // su.haw.un_770 fj.cs.et_322  sm.br.gn_433 wo.sm.ny_543 
  0x5c4d4c11, 0x054936ec, 0x4a583bad, 0x32424c0c,   // wo.aa.sa_653 gn.to.fr_644  so.om.yo_643 wo.co.bs_543 
  0x424c0f04, 0x3e2342a0, 0x1a4d1fa4, 0x4d4c7308,   // lv.wo.co_332 co.ca.rm_322  cy.aa.tl_433 ny.wo.aa_443 
  // [21dc0]
  0x0e00100d, 0x04370a07, 0x3537110c, 0x73004219,   // lt.is.un_540 mk.ba.ru_432  ro.ba.tg_543 co.ny.un_750 
  0x09467304, 0x084807ec, 0x330839a4, 0x135a42a4,   // ny.qu.pl_332 bg.tt.uk_644  br.no.nn_433 co.sm.et_433 
  0x46007319, 0x1f00130e, 0x0a350802, 0x5564690c,   // ny.qu.un_750 et.cy.un_550  uk.tg.mk_222 mfe.lg.rw_543 
  0x0a000202, 0x311921a0, 0x4700091b, 0x341230ad,   // da.pt.un_220 jw.gl.az_322  pl.sn.un_770 uz.ur.ps_643 
  // [21dd0]
  0x494c5e02, 0x08071011, 0x344a67ad, 0x174559a4,   // ts.wo.to_222 be.bg.uk_653  ak.yo.xh_643 rn.ln.sr_433 
  0x5e5f6704, 0x0a00080b, 0x214667a4, 0x4b00180e,   // ak.tn.ts_332 uk.mk.un_520  ak.qu.jw_433 ga.mi.un_550 
  0x683047a9, 0x284724ec, 0x2034350c, 0x63271807,   // sn.uz.ig_544 eo.sn.sw_644  zu.xh.sq_543 ga.gd.sco_432 
  0x290f0d07, 0x0a0830a0, 0x353443af, 0x1800630d,   // cs.lv.sl_432 uz.uk.mk_322  ie.xh.zu_655 sco.ga.un_540 
  // [21de0]
  0x276365a4, 0x27002319, 0x3d211809, 0x65002721,   // gv.sco.gd_433 ca.gd.un_750  ar.fa.ku_444 gd.gv.un_860 
  0x393665a0, 0x35346160, 0x2000522a, 0x343c18a4,   // gv.gn.br_322 za.xh.zu_664  ha.sq.un_970 ar.ug.ps_433 
  0x64000708, 0x23223e08, 0x40252355, 0x23004607,   // it.lg.un_430 rm.oc.ca_443  ca.eu.lb_442 qu.ca.un_420 
  0x20090f07, 0x0f0912af, 0x27021813, 0x65276312,   // lv.pl.sq_432 hu.pl.lv_655  ga.da.gd_665 sco.gd.gv_654 
  // [21df0]
  0x502718af, 0x23223e04, 0x441538ec, 0x21303d0e,   // ga.gd.fj_655 rm.oc.ca_332  tk.kk.un_640 ku.uz.fa_555 
  0x4b005304, 0x281e54a4, 0x28002c02, 0x4e1054ec,   // ht.mi.un_320 ik.ms.sw_433  fy.sw.un_220 ik.lt.ay_644 
  0x40005009, 0x30782f0c, 0x4b004707, 0x52422807,   // fj.lb.un_440 su.ve.uz_543  sn.mi.un_420 sw.co.ha_432 
  0x5825300c, 0x112f5bee, 0x2555540c, 0x253544a0,   // uz.eu.om_543 sg.su.ro_422  ik.rw.eu_543 kk.tg.mn_322 
  // [21e00]
  0x46555804, 0x48002a21, 0x09574e55, 0x115c3007,   // om.rw.qu_332 mt.tt.un_860  ay.na.pl_442 uz.sa.ro_432 
  0x48100707, 0x4f292d0c, 0x47004012, 0x30544e0c,   // bg.be.tt_432 sk.sl.bi_543  lb.sn.un_640 ay.ik.uz_543 
  0x213f67ad, 0x1d4f2207, 0x13100f55, 0x12292104,   // ak.af.jw_643 oc.bi.la_432  lv.lt.et_442 jw.sl.hu_332 
  0x30111705, 0x21000209, 0x2e00691a, 0x3b2a1207,   // sr.ro.uz_333 da.jw.un_440  mfe.fo.un_760 hu.mt.so_432 
  // [21e10]
  0x1f395fa0, 0x0e4e2e13, 0x5d36fca0, 0x3313110c,   // tn.br.cy_322 fo.ay.is_665  zzp.gn.ss_322 ro.et.nn_543 
  0x3e4305ad, 0x3e181d0c, 0x351b590e, 0x1f006b05,   // fr.ie.rm_643 la.ga.rm_543  rn.tr.zu_555 ceb.cy.un_330 
  0x054251af, 0x530f69a4, 0x07375804, 0x5f00111a,   // kl.co.fr_655 mfe.lv.ht_433  om.st.it_332 ro.tn.un_760 
  0x343553ad, 0x42515808, 0x07483509, 0x1a005e07,   // ht.zu.xh_643 om.kl.co_443  tg.tt.bg_444 ts.tl.un_420 
  // [21e20]
  0x371d5fa0, 0x03001f0b, 0x302839a7, 0x1d371da4,   // tn.la.st_322 cy.nl.un_520  br.sw.uz_532 la.st.la_433 
  0x15fc2aad, 0x65004704, 0x5e555912, 0x2afe5155,   // mt.zzp.un_643 sn.gv.un_320  rn.rw.ts_654 kl.tlh.mt_442 
  0x3f083307, 0x151a01a7, 0x4700570d, 0x033f4055,   // nn.no.af_432 en.tl.un_532  na.sn.un_540 lb.af.nl_442 
  0x65406304, 0x5a001312, 0x03133f08, 0x1e3f63ee,   // sco.lb.gv_332 et.sm.un_640  af.et.nl_443 sco.af.ms_422 
  // [21e30]
  0x12001b0e, 0x07124955, 0x4207120c, 0x190b4cec,   // tr.hu.un_550 to.hu.it_442  hu.it.co_543 wo.es.gl_644 
  0x10231708, 0x5a1e1c11, 0x040a1007, 0x2f10200d,   // sr.ky.be_443 id.ms.sm_653  be.mk.ru_432 sq.lt.su_554 
  0x59676e0c, 0x3f697611, 0x5a4b4914, 0x2b005005,   // hmn.ak.rn_543 crs.mfe.af_653  to.mi.sm_666 fj.vi.un_330 
  0x5c431c55, 0x0f006913, 0x5c004221, 0x1008380b,   // id.ie.sa_442 mfe.lv.un_650  co.sa.un_860 tk.uk.be_542 
  // [21e40]
  0x6b000105, 0x695e7313, 0x033e7607, 0x173036af,   // en.ceb.un_330 ny.ts.mfe_665  crs.rm.nl_432 ab.uz.sr_655 
  0x53110707, 0x28005602, 0x0964560c, 0x56795255,   // it.ro.ht_432 mg.sw.un_220  mg.lg.pl_543 ha.war.mg_442 
  0x1a566ba0, 0x052d0d05, 0x4a6a68ec, 0x3e673107,   // ceb.mg.tl_322 cs.sk.fr_333  ig.haw.yo_644 az.ak.rm_432 
  0x09044508, 0x5a490f0c, 0x6b536402, 0x40002f0e,   // ln.fi.pl_443 lv.to.sm_543  lg.ht.ceb_222 su.lb.un_550 
  // [21e50]
  0x73526a08, 0x595567ee, 0x5100460d, 0x1d0678ad,   // haw.ha.ny_443 ak.rw.rn_422  qu.kl.un_540 ve.de.la_643 
  0x3e1f4555, 0x5d4a3508, 0x135d350c, 0x530542a0,   // ln.cy.rm_442 zu.yo.ss_443  zu.ss.et_543 co.fr.ht_322 
  0x45672804, 0x73450d07, 0x082c2d07, 0x566757ec,   // sw.ak.ln_332 cs.ln.ny_432  sk.fy.no_432 na.ak.mg_644 
  0x210f42ee, 0x072404ee, 0x2a072704, 0x022d0d0e,   // co.lv.jw_422 fi.eo.it_422  gd.it.mt_332 cs.sk.da_555 
  // [21e60]
  0x19330805, 0x12556405, 0x35732a0c, 0x6e732713,   // no.nn.gl_333 lg.rw.hu_333  mt.ny.zu_543 gd.ny.hmn_665 
  0x3f6803a4, 0x08251004, 0x050c0909, 0x791a55a4,   // nl.ig.af_433 be.mn.uk_332  pl.sv.fr_444 rw.tl.war_433 
  0x09400614, 0x390e1307, 0x126473ad, 0x04005912,   // de.lb.pl_666 et.is.br_432  ny.lg.hu_643 rn.fi.un_640 
  0x044548a4, 0x173c30a0, 0x5373090e, 0x4907450c,   // tt.ln.fi_433 uz.ug.sr_322  pl.ny.ht_555 ln.it.to_543 
  // [21e70]
  0x332d08af, 0x090f06af, 0x231508a9, 0x07003308,   // no.sk.nn_655 de.lv.pl_655  uk.ky.un_540 nn.it.un_430 
  0x644207a7, 0x3000500e, 0x24020ca0, 0x30342807,   // it.co.lg_532 fj.uz.un_550  sv.da.eo_322 sd.ps.uz_432 
  0x3e0126a4, 0x3017150c, 0x0f021d07, 0x21241c07,   // ia.en.rm_433 un.sr.uz_543  la.da.lv_432 id.eo.jw_432 
  0x1c2e7655, 0x024505ad, 0x30234409, 0x350407ee,   // crs.fo.id_442 fr.ln.da_643  kk.ky.uz_444 bg.ru.tg_422 
  // [21e80]
  0x1f002208, 0x4345460c, 0x12107307, 0x365c5614,   // oc.cy.un_430 qu.ln.ie_543  ny.lt.hu_432 mg.sa.gn_666 
  0x4e005c1a, 0x073e42a7, 0x0d005607, 0x30043804,   // sa.ay.un_760 co.rm.it_532  mg.cs.un_420 tk.ru.uz_332 
  0x43005608, 0x122f1cee, 0x1f0e2e07, 0x4d100f13,   // mg.ie.un_430 id.su.hu_422  fo.is.cy_432 lv.lt.aa_665 
  0x6200241b, 0x57001c08, 0x1a004f09, 0x0b631dad,   // eo.kha.un_770 id.na.un_430  bi.tl.un_440 la.sco.es_643 
  // [21e90]
  0x2e050ea4, 0x20002f07, 0x12735504, 0x3b4c4da0,   // is.fr.fo_433 su.sq.un_420  rw.ny.hu_332 aa.wo.so_322 
  0x5e5c50a9, 0x332e20a0, 0x330c3b55, 0x1c5c1ea9,   // fj.sa.ts_544 sq.fo.nn_322  so.sv.nn_442 ms.sa.id_544 
  0x34001a0c, 0x652afead, 0x504e58af, 0x27345ca0,   // tl.xh.un_530 tlh.mt.gv_643  om.ay.fj_655 sa.xh.gd_322 
  0x1865fe08, 0x10440813, 0x4d001221, 0x490e2911,   // tlh.gv.ga_443 uk.kk.be_665  hu.aa.un_860 sl.is.to_653 
  // [21ea0]
  0x1200fc11, 0x5f275004, 0xfc1f18a0, 0x2500fc12,   // zzp.hu.un_630 fj.gd.tn_332  ga.cy.zzp_322 zzp.eu.un_640 
  0x3510250c, 0x4a00671a, 0x202e100c, 0x055f040c,   // mn.be.tg_543 ak.yo.un_760  lt.fo.sq_543 fi.tn.fr_543 
  0x375e130c, 0x12213dac, 0x5f37130c, 0x20004207,   // et.ts.st_543 ku.fa.ur_632  et.st.tn_543 co.sq.un_420 
  0x3f261908, 0x2c000a0d, 0x150438ec, 0x53423704,   // gl.ia.af_443 pt.fy.un_540  tk.ru.un_644 st.co.ht_332 
  // [21eb0]
  0x64212608, 0x5d484aa4, 0x0b000d04, 0x2000730e,   // ia.jw.lg_443 yo.tt.ss_433  cs.es.un_320 ny.sq.un_550 
  0x4800190c, 0x071942a4, 0x64553fa9, 0x4c006908,   // gl.tt.un_530 co.gl.it_433  af.rw.lg_544 mfe.wo.un_430 
  0x48040704, 0x496728ec, 0x3b286aa9, 0x6800282a,   // bg.ru.tt_332 sw.ak.to_644  haw.sw.so_544 sw.ig.un_970 
  0xfc006008, 0x022b4c05, 0x58005a23, 0x24fc01a4,   // vo.zzp.un_430 wo.vi.da_333  sm.om.un_880 en.zzp.eo_433 
  // [21ec0]
  0x734d67a4, 0x483b0204, 0x443423a0, 0x4c001c08,   // ak.aa.ny_433 da.so.tt_332  ky.ps.kk_322 id.wo.un_430 
  0x671322a4, 0x330c20a0, 0x67495aa9, 0x156afc07,   // oc.et.ak_433 sq.sv.nn_322  sm.to.ak_544 zzp.haw.un_432 
  0x4c4a5807, 0x2d00290e, 0x5a64490b, 0x0a073005,   // om.yo.wo_432 sl.sk.un_550  to.lg.sm_542 uz.bg.mk_333 
  0x10696007, 0x23353805, 0x342a5505, 0x1a033fee,   // vo.mfe.lt_432 tk.tg.ky_333  rw.mt.xh_333 af.nl.tl_422 
  // [21ed0]
  0x40285a07, 0x0c40060b, 0x39631f04, 0x2800181b,   // sm.sw.lb_432 de.lb.sv_542  cy.sco.br_332 ar.sd.un_770 
  0x13001514, 0x39564fa0, 0x405c3f02, 0x15083712,   // un.et.un_660 bi.mg.br_322  af.sa.lb_222 ba.uk.un_654 
  0x32001b05, 0x5b003014, 0x0a795155, 0x022538a4,   // tr.bs.un_330 uz.sg.un_660  kl.war.pt_442 tk.eu.da_433 
  0x39224ea7, 0x0b383fa0, 0x13481aa4, 0x5e371eaf,   // ay.oc.br_532 af.tk.es_322  tl.tt.et_433 ms.st.ts_655 
  // [21ee0]
  0x301536a0, 0x271f2aa4, 0x393138ad, 0x37211f0b,   // ab.uz.un_320 mt.cy.gd_433  tk.az.br_643 cy.jw.st_542 
  0x3b211213, 0x2c004f05, 0x621847af, 0x6518730c,   // ur.fa.ks_665 bi.fy.un_330  sn.ga.kha_655 ny.ga.gv_543 
  0x763b580c, 0x315d7312, 0x64003b0b, 0x24151f07,   // om.so.crs_543 ny.ss.az_654  so.lg.un_520 cy.eo.un_420 
  0x21204c07, 0x6546fca0, 0x39001907, 0x40003704,   // wo.sq.jw_432 zzp.qu.gv_322  gl.br.un_420 st.lb.un_320 
  // [21ef0]
  0x1e1c68a0, 0x3e00fe08, 0x28623b0c, 0x5d00352a,   // ig.id.ms_322 tlh.rm.un_430  so.kha.sw_543 zu.ss.un_970 
  0x12023ea4, 0x2b276507, 0x35006e07, 0x3b4006ee,   // rm.da.hu_433 gv.gd.vi_432  hmn.zu.un_420 de.lb.so_422 
  0x3778180d, 0x201534ec, 0x3f2e02a7, 0x12005e2a,   // ga.ve.st_554 xh.sq.un_640  da.fo.af_532 ts.hu.un_970 
  0x584b6aad, 0xfe2f3b05, 0x732849a9, 0x4b6434a0,   // haw.mi.om_643 so.su.tlh_333  to.sw.ny_544 xh.lg.mi_322 
  // [21f00]
  0xfc6a18ad, 0x601a28ad, 0x02fc27a4, 0x0a003304,   // ga.haw.zzp_643 sw.tl.vo_643  gd.zzp.da_433 nn.pt.un_320 
  0x190a05a0, 0x20602114, 0x10181f05, 0x34000309,   // fr.pt.gl_322 jw.vo.sq_666  cy.ga.lt_333 nl.xh.un_440 
  0x0a000608, 0xfe4c30a4, 0x681d3b0b, 0x3e0519a0,   // de.pt.un_430 uz.wo.tlh_433  so.la.ig_542 gl.fr.rm_322 
  0x27494b07, 0x190a65a9, 0x03001305, 0x4f002d04,   // mi.to.gd_432 gv.pt.gl_544  et.nl.un_330 sk.bi.un_320 
  // [21f10]
  0xfe506a12, 0x54043008, 0x495c4b60, 0x5a271807,   // haw.fj.tlh_654 uz.fi.ik_443  mi.sa.to_664 ga.gd.sm_432 
  0x304837a0, 0x35173009, 0x12362204, 0x090b190c,   // ba.tt.uz_322 uz.sr.tg_444  oc.gn.hu_332 gl.es.pl_543 
  0x281844a0, 0x300a15a0, 0x080437a7, 0x40790604,   // kk.ar.sd_322 un.mk.uz_322  ba.ru.uk_532 de.war.lb_332 
  0x343d2307, 0x35040a0c, 0x300c480c, 0x080e020b,   // ky.ku.ps_432 mk.ru.tg_543  tt.sv.uz_543 da.is.no_542 
  // [21f20]
  0x234437a9, 0x3b514dad, 0x1d6a5a13, 0x330845ac,   // ba.kk.ky_544 aa.kl.so_643  sm.haw.la_665 ln.no.nn_632 
  0x5f47370c, 0x18765d08, 0x3b644daf, 0x5f2d29a7,   // st.sn.tn_543 ss.crs.ga_443  aa.lg.so_655 sl.sk.tn_532 
  0x34006b05, 0x40006405, 0x013f03a4, 0x4f0749a9,   // ceb.xh.un_330 lg.lb.un_330  nl.af.en_433 to.it.bi_544 
  0x5f754513, 0x3f56030c, 0x07432308, 0x5600030c,   // ln.nso.tn_665 nl.mg.af_543  ca.ie.it_443 nl.mg.un_530 
  // [21f30]
  0x1e3713ee, 0x0c6a2504, 0x38280107, 0x285045ec,   // et.st.ms_422 eu.haw.sv_332  en.sw.tk_432 ln.fj.sw_644 
  0x3900100c, 0x3200280c, 0x5e6701a0, 0x31001908,   // lt.br.un_530 sw.bs.un_530  en.ak.ts_322 gl.az.un_430 
  0x205a4908, 0x5e2c4504, 0x0c400608, 0x355d2da4,   // to.sm.sq_443 ln.fy.ts_332  de.lb.sv_443 sk.ss.zu_433 
  0x2000370d, 0x29223902, 0x04021ba0, 0x1218210b,   // st.sq.un_540 br.oc.sl_222  tr.da.fi_322 fa.ar.ur_542 
  // [21f40]
  0x04002a1b, 0x500928a9, 0x32281a0c, 0x10481207,   // mt.fi.un_770 sw.pl.fj_544  tl.sw.bs_543 hu.tt.lt_432 
  0x28455aa9, 0x384831a4, 0x10002d11, 0x534205ee,   // sm.ln.sw_544 az.tt.tk_433  sk.lt.un_630 fr.co.ht_422 
  0x17250405, 0x2144180e, 0x151737a7, 0x2b002205,   // ru.mn.sr_333 ar.kk.fa_555  ba.sr.un_532 oc.vi.un_330 
  0x2b005307, 0x3b271804, 0x2b005304, 0x18343b0e,   // ht.vi.un_420 ga.gd.so_332  ht.vi.un_320 ks.ps.ar_555 
  // [21f50]
  0x4b6b7912, 0x2a004b13, 0x48253704, 0x5d001209,   // war.ceb.mi_654 mi.mt.un_650  ba.mn.tt_332 hu.ss.un_440 
  0x1565130c, 0x246b60ec, 0x261f25a4, 0x066b1ca4,   // et.gv.un_543 vo.ceb.eo_644  eu.cy.ia_433 id.ceb.de_433 
  0x22246012, 0x391f57ad, 0x0c2e300c, 0x32100f07,   // vo.eo.oc_654 na.cy.br_643  uz.fo.sv_543 lv.lt.bs_432 
  0x2f5260ec, 0x40240107, 0x695301a4, 0x022f3f55,   // vo.ha.su_644 en.eo.lb_432  en.ht.mfe_433 af.su.da_442 
  // [21f60]
  0x2a002809, 0x385c3b04, 0x6b1a3ba4, 0xfc6402a0,   // sw.mt.un_440 so.sa.tk_332  so.tl.ceb_433 da.lg.zzp_322 
  0x59675513, 0x204c5304, 0x607901a4, 0x4dfe3b13,   // rw.ak.rn_665 ht.wo.sq_332  en.war.vo_433 so.tlh.aa_665 
  0x5c3b0207, 0x3b005c12, 0x0804170e, 0x385c6404,   // da.so.sa_432 sa.so.un_640  sr.ru.uk_555 lg.sa.tk_332 
  0x1b5c3b12, 0x754557ad, 0x5e1656a0, 0x5c3b6712,   // so.sa.tr_654 na.ln.nso_643  mg.hr.ts_322 ak.so.sa_654 
  // [21f70]
  0x4500281a, 0x1a003b11, 0x451b680c, 0x3f0c0e04,   // sw.ln.un_760 so.tl.un_630  ig.tr.ln_543 is.sv.af_332 
  0x46390107, 0x21003b2b, 0x18123ba4, 0x320f2907,   // en.br.qu_432 ks.fa.un_980  ks.ur.ar_433 sl.lv.bs_432 
  0x04151713, 0x40123611, 0x35342d09, 0x130419a7,   // sr.ru.un_650 gn.hu.lb_653  sk.xh.zu_444 gl.fi.et_532 
  0x02004702, 0x42072aec, 0x564c05a7, 0x35371b07,   // sn.da.un_220 mt.it.co_644  fr.wo.mg_532 tr.st.zu_432 
  // [21f80]
  0x44002519, 0x52595509, 0x6500fc2a, 0x2f1038a0,   // mn.kk.un_750 rw.rn.ha_444  zzp.gv.un_970 tk.lt.su_322 
  0x0d003b0c, 0x2f105c05, 0x18276508, 0x39631d04,   // so.cs.un_530 sa.lt.su_333  gv.gd.ga_443 la.sco.br_332 
  0x38003b18, 0x24041307, 0x19211da0, 0x0d352d04,   // so.tk.un_740 et.fi.eo_432  la.jw.gl_322 sk.zu.cs_332 
  0x351511af, 0x5c212f05, 0x385c210c, 0x360e53ba,   // ro.tg.un_650 su.jw.sa_333  jw.sa.tk_543 ht.is.gn_843 
  // [21f90]
  0x4600230c, 0x0d2d02a0, 0x300708a0, 0x504b6a55,   // ca.qu.un_530 da.sk.cs_322  uk.bg.uz_322 haw.mi.fj_442 
  0x50026a0b, 0x303c350d, 0x286a4e0b, 0x4b004702,   // haw.da.fj_542 tg.ug.uz_554  ay.haw.sw_542 sn.mi.un_220 
  0x02002818, 0x0715100c, 0x476446a0, 0x12381baf,   // sw.da.un_740 be.bg.un_530  qu.lg.sn_322 tr.tk.hu_655 
  0x4a4b6a55, 0x47004b0e, 0x13655108, 0x51001a08,   // haw.mi.yo_442 mi.sn.un_550  kl.gv.et_443 tl.kl.un_430 
  // [21fa0]
  0x08003f07, 0x0c2e0e05, 0x091b38ad, 0x28342312,   // af.no.un_420 is.fo.sv_333  tk.tr.pl_643 ky.ps.sd_654 
  0x3965610c, 0x121b3812, 0x123d3055, 0x12321604,   // za.gv.br_543 tk.tr.hu_654  uz.ku.ur_442 hr.bs.hu_332 
  0x32160405, 0x5f00510c, 0x33080414, 0x22001119,   // fi.hr.bs_333 kl.tn.un_530  fi.no.nn_666 ro.oc.un_750 
  0x2c006520, 0x203312ad, 0x3efe3012, 0x0b433907,   // gv.fy.un_850 hu.nn.sq_643  uz.tlh.rm_654 br.ie.es_432 
  // [21fb0]
  0x283c440c, 0x32161214, 0x20005d0c, 0x4a39fe0c,   // kk.ug.sd_543 hu.hr.bs_666  ss.sq.un_530 tlh.br.yo_543 
  0x122c2005, 0x1f004604, 0x23182112, 0x1725380c,   // sq.fy.hu_333 qu.cy.un_320  fa.ar.ky_654 tk.mn.sr_543 
  0x124c4f07, 0x043017a0, 0x04103007, 0x42150107,   // bi.wo.hu_432 sr.uz.ru_322  uz.be.ru_432 en.co.un_420 
  0x37114807, 0x1f4249a0, 0x495063a7, 0x245d3505,   // tt.ro.ba_432 to.co.cy_322  sco.fj.to_532 zu.ss.eo_333 
  // [21fc0]
  0x04301005, 0x04360309, 0x4a001f12, 0x36041304,   // be.uz.ru_333 nl.gn.fi_444  cy.yo.un_640 et.fi.gn_332 
  0x4a3242a0, 0x111d4304, 0x18002323, 0x38006511,   // co.bs.yo_322 ie.la.ro_332  ky.ar.un_880 gv.tk.un_630 
  0x07003612, 0x4c000a05, 0x42052412, 0x5d052407,   // gn.it.un_640 pt.wo.un_330  eo.fr.co_654 eo.fr.ss_432 
  0x59557307, 0x0e1827ad, 0x045054a4, 0x4a5002a0,   // ny.rw.rn_432 gd.ga.is_643  ik.fj.fi_433 da.fj.yo_322 
  // [21fd0]
  0x40001112, 0x405567ad, 0x51040502, 0x5d005e13,   // ro.lb.un_640 ak.rw.lb_643  fr.fi.kl_222 ts.ss.un_650 
  0x04005a0d, 0x02003919, 0x3004100c, 0x3b1221ec,   // sm.fi.un_540 br.da.un_750  be.ru.uz_543 fa.ur.ks_644 
  0x55516408, 0x23003d09, 0x4a005721, 0x0300550d,   // lg.kl.rw_443 ku.ky.un_440  na.yo.un_860 rw.nl.un_540 
  0x53516907, 0x6400350c, 0x21004c1b, 0x684f620c,   // mfe.kl.ht_432 zu.lg.un_530  wo.jw.un_770 kha.bi.ig_543 
  // [21fe0]
  0x34192308, 0x0e375e13, 0x353028a4, 0x353f55a0,   // ca.gl.xh_443 ts.st.is_665  sw.uz.zu_433 rw.af.zu_322 
  0x09291713, 0x32003b05, 0x173611a9, 0x205701ee,   // sr.sl.pl_665 so.bs.un_330  ro.ab.sr_544 en.na.sq_422 
  0x136804a9, 0x400648a0, 0x651d2505, 0x2a13255a,   // fi.ig.et_544 tt.de.lb_322  eu.la.gv_333 eu.et.mt_553 
  0x380c48ec, 0x256523a4, 0x0c384855, 0x4c005f02,   // tt.sv.tk_644 ca.gv.eu_433  tt.tk.sv_442 tn.wo.un_220 
  // [21ff0]
  0x4d00251b, 0x125d350c, 0x40480c12, 0x0a232555,   // eu.aa.un_770 zu.ss.hu_543  sv.tt.lb_654 eu.ca.pt_442 
  0x480c38af, 0x583473a0, 0x19233bec, 0x0c004822,   // tk.sv.tt_655 ny.xh.om_322  so.ca.gl_644 tt.sv.un_870 
  0x495f5e55, 0x0e1208a0, 0x095c1312, 0x5d002f02,   // ts.tn.to_442 no.hu.is_322  bh.sa.hi_654 su.ss.un_220 
  0x584b04ac, 0x1504170d, 0x4a000407, 0x1306250c,   // fi.mi.om_632 sr.ru.un_554  fi.yo.un_420 eu.de.et_543 
  
  // [22000]
  0x3613040c, 0x63383b11, 0x6b3802a9, 0x3534fea4,   // fi.et.gn_543 so.tk.sco_653  da.tk.ceb_544 tlh.xh.zu_433 
  0x190a07ee, 0x0c384807, 0x1b5c6104, 0x785d5eec,   // it.pt.gl_422 tt.tk.sv_432  za.sa.tr_332 ts.ss.ve_644 
  0x65636207, 0x04004704, 0x38003b2a, 0x4e0b600c,   // kha.sco.gv_432 sn.fi.un_320  so.tk.un_970 vo.es.ay_543 
  0x080a11a0, 0x070236ee, 0x56005105, 0x0d102905,   // ro.mk.uk_322 gn.da.it_422  kl.mg.un_330 sl.lt.cs_333 
  // [22010]
  0x133e1704, 0x2307220d, 0x15386308, 0x2d0d53ee,   // sr.rm.et_332 oc.it.ca_554  sco.tk.un_443 ht.cs.sk_422 
  0x19006013, 0x40610d0d, 0x1b0f310d, 0x184615a0,   // vo.gl.un_650 cs.za.lb_554  az.lv.tr_554 un.qu.ga_322 
  0x53311ba0, 0x39001121, 0x18000e19, 0x0f100da0,   // tr.az.ht_322 ro.br.un_860  is.ga.un_750 cs.lt.lv_322 
  0x20003f13, 0x3500170d, 0x10730f07, 0x1b3873ee,   // af.sq.un_650 sr.tg.un_540  lv.ny.lt_432 ny.tk.tr_422 
  // [22020]
  0x1d271307, 0x30007308, 0x3c040808, 0x0f391da0,   // et.gd.la_432 ny.uz.un_430  uk.ru.ug_443 la.br.lv_322 
  0x5a001305, 0x3e005007, 0x13002f08, 0x3f002020,   // et.sm.un_330 fj.rm.un_420  su.et.un_430 ti.os.un_850 
  0x611a6b05, 0x18652713, 0x2a1b4807, 0x1b523113,   // ceb.tl.za_333 gd.gv.ga_665  tt.tr.mt_432 az.ha.tr_665 
  0x484d39a9, 0x1d3f06ee, 0x042552af, 0x65254d0c,   // br.aa.tt_544 de.af.la_422  ha.eu.fi_655 aa.eu.gv_543 
  // [22030]
  0x34375faf, 0x2f21480c, 0x183e6360, 0x1f4a52ec,   // tn.st.xh_655 tt.jw.su_543  sco.rm.ga_664 ha.yo.cy_644 
  0x35105f02, 0x25082aa7, 0x572e010c, 0x21002504,   // tn.lt.zu_222 mt.no.eu_532  en.fo.na_543 eu.jw.un_320 
  0x4a3b520c, 0x0925210c, 0x21394d07, 0x07173008,   // ha.so.yo_543 jw.eu.pl_543  aa.br.jw_432 uz.sr.bg_443 
  0x1b3169af, 0x69111308, 0x31233b0c, 0x3b4a5808,   // mfe.az.tr_655 et.ro.mfe_443  so.ca.az_543 om.yo.so_443 
  // [22040]
  0x57001c04, 0x1c6364ad, 0x24fc6a07, 0x2f02780c,   // id.na.un_320 lg.sco.id_643  haw.zzp.eo_432 ve.da.su_543 
  0x39650207, 0x13150108, 0x2e5233a0, 0x2f214f0d,   // da.gv.br_432 en.et.un_430  nn.ha.fo_322 bi.jw.su_554 
  0x0a3617a4, 0x20135ca0, 0x120c485a, 0x1a000d04,   // sr.ab.mk_433 sa.et.sq_322  tt.sv.hu_553 cs.tl.un_320 
  0x6700582a, 0x672f5811, 0x361165ad, 0x5d5a350c,   // om.ak.un_970 om.su.ak_653  gv.ro.gn_643 zu.sm.ss_543 
  // [22050]
  0x2f003308, 0x06fe6007, 0x6300640d, 0x301035ee,   // nn.su.un_430 vo.tlh.de_432  lg.sco.un_540 tg.be.uz_422 
  0x5c583ba4, 0x115a60a9, 0x35342914, 0x5c0248ad,   // so.om.sa_433 vo.sm.ro_544  sl.xh.zu_666 tt.da.sa_643 
  0x3b4c1912, 0x26135ca4, 0x2102500c, 0x67021907,   // gl.wo.so_654 sa.et.ia_433  fj.da.jw_543 gl.da.ak_432 
  0x5067190c, 0x21130807, 0x2f5a600c, 0x5800500e,   // gl.ak.fj_543 no.et.jw_432  vo.sm.su_543 fj.om.un_550 
  // [22060]
  0x480a2505, 0x5e045a08, 0x13005d0d, 0x0d001322,   // mn.mk.tt_333 sm.fi.ts_443  ss.et.un_540 bh.ne.un_870 
  0x0a00190b, 0x042348a9, 0x122830ee, 0x24130407,   // gl.pt.un_520 tt.ky.ru_544  uz.sd.ur_422 fi.et.eo_432 
  0x12001e02, 0x63515007, 0x5f006714, 0x245d3407,   // ms.hu.un_220 fj.kl.sco_432  ak.tn.un_660 xh.ss.eo_432 
  0x032c3f12, 0x033f4908, 0x03162c02, 0x0e000408,   // af.fy.nl_654 to.af.nl_443  fy.hr.nl_222 fi.is.un_430 
  // [22070]
  0x253f3907, 0x475651ec, 0xfe006e13, 0x39033f07,   // br.af.eu_432 kl.mg.sn_644  hmn.tlh.un_650 af.nl.br_432 
  0x230a1907, 0x393f25a7, 0x35465da7, 0x131004ee,   // gl.pt.ca_432 eu.af.br_532  ss.qu.zu_532 fi.lt.et_422 
  0x4773010c, 0x5c2f58ad, 0x211c3f07, 0x02030ca0,   // en.ny.sn_543 om.su.sa_643  af.id.jw_432 sv.nl.da_322 
  0x38035304, 0x735c0fa0, 0x03563faf, 0x39250304,   // ht.nl.tk_332 lv.sa.ny_322  af.mg.nl_655 nl.eu.br_332 
  // [22080]
  0x1d005e02, 0x03433907, 0x25003f1a, 0x0c020ea4,   // ts.la.un_220 br.ie.nl_432  af.eu.un_760 is.da.sv_433 
  0x30070a02, 0x28002418, 0x240c3fa4, 0x42071f08,   // mk.bg.uz_222 eo.sw.un_740  af.sv.eo_433 cy.it.co_443 
  0x4c00570c, 0x1f00610d, 0x08033fa7, 0x24260107,   // na.wo.un_530 za.cy.un_540  af.nl.no_532 en.ia.eo_432 
  0x5c120e0c, 0x453305a7, 0x041b4d08, 0x1d000604,   // is.hu.sa_543 fr.nn.ln_532  aa.tr.fi_443 de.la.un_320 
  // [22090]
  0x331d51ad, 0x1b020307, 0x51001e1a, 0x03023f0e,   // kl.la.nn_643 nl.da.tr_432  ms.kl.un_760 af.da.nl_555 
  0x13004307, 0x065955a4, 0x33244fa6, 0x15043709,   // ie.et.un_420 rw.rn.de_433  bi.eo.nn_521 ba.ru.un_444 
  0x332e02a0, 0x28473609, 0x11003918, 0x470d0f0c,   // da.fo.nn_322 gn.sn.sw_444  br.ro.un_740 lv.cs.sn_543 
  0x0500261b, 0x0c0e2ea0, 0x48315cee, 0x4c633ba0,   // ia.fr.un_770 fo.is.sv_322  sa.az.tt_422 so.sco.wo_322 
  // [220a0]
  0x020c1da4, 0x102d29a4, 0x1002040c, 0x5c132d07,   // la.sv.da_433 sl.sk.lt_433  fi.da.lt_543 sk.et.sa_432 
  0x3f000107, 0x330846a4, 0x3f030408, 0x180333a4,   // en.af.un_420 qu.no.nn_433  fi.nl.af_443 nn.nl.ga_433 
  0x732834a0, 0x47391d0b, 0x330c3804, 0x212f7312,   // xh.sw.ny_322 la.br.sn_542  tk.sv.nn_332 ny.su.jw_654 
  0x6b304904, 0x24001007, 0x511d06a9, 0x0f004c1b,   // to.uz.ceb_332 lt.eo.un_420  de.la.kl_544 wo.lv.un_770 
  // [220b0]
  0x511d59ad, 0x78643008, 0x08100aa4, 0x5146200b,   // rn.la.kl_643 uz.lg.ve_443  mk.be.uk_433 sq.qu.kl_542 
  0x73225a0b, 0x4d42110d, 0x0c10290c, 0x60421a14,   // sm.oc.ny_542 ro.co.aa_554  sl.lt.sv_543 tl.co.vo_666 
  0x361d6a0b, 0x17001219, 0x0a1a0208, 0x30004c14,   // haw.la.gn_542 hu.sr.un_750  da.tl.pt_443 wo.uz.un_660 
  0x170835a7, 0x083823ad, 0x1c2f210e, 0x12364807,   // tg.uk.sr_532 ky.tk.uk_643  jw.su.id_555 tt.gn.hu_432 
  // [220c0]
  0x5a1a040d, 0x481017a0, 0x36384408, 0x30070804,   // fi.tl.sm_554 sr.be.tt_322  kk.tk.ab_443 uk.bg.uz_332 
  0x49000207, 0x182b1d02, 0x1a556b0c, 0x2b000804,   // da.to.un_420 la.vi.ga_222  ceb.rw.tl_543 no.vi.un_320 
  0x37005507, 0x3b0258ec, 0x06655808, 0x46005105,   // rw.st.un_420 om.da.so_644  om.gv.de_443 kl.qu.un_330 
  0x0735380c, 0x643b58a0, 0x2f3b4da6, 0x0e2afead,   // tk.tg.bg_543 om.so.lg_322  aa.so.su_521 tlh.mt.is_643 
  // [220d0]
  0x2e0c3b02, 0x3b1925a0, 0x2e3e0e04, 0x0e4658af,   // so.sv.fo_222 eu.gl.so_322  is.rm.fo_332 om.qu.is_655 
  0x12282111, 0x640e58ee, 0x2c002e05, 0x03001a02,   // fa.sd.ur_653 om.is.lg_422  fo.fy.un_330 tl.nl.un_220 
  0x040a380b, 0x30173512, 0x0e6b7904, 0xfefc0304,   // tk.mk.ru_542 tg.sr.uz_654  war.ceb.is_332 nl.zzp.tlh_332 
  0x15040a05, 0x3600231a, 0x233710ec, 0x0a153607,   // mk.ru.un_333 ky.ab.un_760  be.ba.ky_644 ab.mk.un_420 
  // [220e0]
  0x11003508, 0x21123c04, 0x2123530c, 0x78641f13,   // tg.ro.un_430 ug.ur.fa_332  ht.ca.jw_543 cy.lg.ve_665 
  0x47615708, 0x1f006721, 0x20210502, 0x48005a04,   // na.za.sn_443 ak.cy.un_860  fr.jw.sq_222 sm.tt.un_320 
  0x526b1d10, 0x3f5713a4, 0x3700610d, 0x5f00472a,   // la.ceb.ha_642 et.na.af_433  za.st.un_540 sn.tn.un_970 
  0x4c004613, 0x044c1308, 0x585f4d08, 0x791f6412,   // qu.wo.un_650 et.wo.fi_443  aa.tn.om_443 lg.cy.war_654 
  // [220f0]
  0x21004902, 0x2100490d, 0x755f0409, 0x42002608,   // to.jw.un_220 to.jw.un_540  fi.tn.nso_444 ia.co.un_430 
  0x5e7378a7, 0x04650304, 0x254d1309, 0x2000360b,   // ve.ny.ts_532 nl.gv.fi_332  et.aa.eu_444 gn.sq.un_520 
  0x403f03af, 0x12005604, 0x42113e08, 0x0d202302,   // nl.af.lb_655 mg.hu.un_320  rm.ro.co_443 ca.sq.cs_222 
  0x684c37a4, 0x033b3f13, 0x13584c07, 0x3f3b030c,   // st.wo.ig_433 af.so.nl_665  wo.om.et_432 nl.so.af_543 
  // [22100]
  0x3b4d1112, 0x2c4d5804, 0x69016307, 0x02791a04,   // ro.aa.so_654 om.aa.fy_332  sco.en.mfe_432 tl.war.da_332 
  0x21052d0c, 0x37007514, 0x645f470c, 0x28002a1b,   // sk.fr.jw_543 nso.st.un_660  sn.tn.lg_543 mt.sw.un_770 
  0x3f6428ee, 0x0a001d23, 0x3f130360, 0x5f3b6804,   // sw.lg.af_422 la.pt.un_880  nl.et.af_664 ig.so.tn_332 
  0x522a30ee, 0x60641b0c, 0x4c5804a4, 0x3f4c13a7,   // uz.mt.ha_422 tr.lg.vo_543  fi.om.wo_433 et.wo.af_532 
  // [22110]
  0x494205a7, 0x043f4c0c, 0x484a01a0, 0x03375faf,   // fr.co.to_532 wo.af.fi_543  en.yo.tt_322 tn.st.nl_655 
  0x02000507, 0x2e330811, 0x021a30a4, 0x276965a4,   // fr.da.un_420 no.nn.fo_653  uz.tl.da_433 gv.mfe.gd_433 
  0x1e2f4005, 0x0c352504, 0x1d0e0204, 0x4d391208,   // lb.su.ms_333 eu.zu.sv_332  da.is.la_332 hu.br.aa_443 
  0x284e550b, 0x3925120d, 0x475c1c07, 0x02306105,   // rw.ay.sw_542 hu.eu.br_554  id.sa.sn_432 za.uz.da_333 
  // [22120]
  0x38002507, 0x766a530c, 0x394d1212, 0x09394d04,   // eu.tk.un_420 ht.haw.crs_543  hu.aa.br_654 aa.br.pl_332 
  0x026a2807, 0x21003909, 0x533076ad, 0x30021da4,   // sw.haw.da_432 br.jw.un_440  crs.uz.ht_643 la.da.uz_433 
  0x5f2a37a9, 0x3500500c, 0x04006011, 0x12094dad,   // st.mt.tn_544 fj.zu.un_530  vo.fi.un_630 aa.pl.hu_643 
  0x5330020b, 0x6b006405, 0x36001e04, 0x391b1207,   // da.uz.ht_542 lg.ceb.un_330  ms.gn.un_320 hu.tr.br_432 
  // [22130]
  0x330e2e0d, 0x12004d1b, 0x3b001f22, 0x4c00460d,   // fo.is.nn_554 aa.hu.un_770  cy.so.un_870 qu.wo.un_540 
  0x1025280c, 0x3bfe6255, 0x17381105, 0x0e2d0d07,   // sw.eu.lt_543 kha.tlh.so_442  ro.tk.sr_333 cs.sk.is_432 
  0x04005612, 0x653435a4, 0x1c674a0c, 0x34fe35a0,   // mg.fi.un_640 zu.xh.gv_433  yo.ak.id_543 zu.tlh.xh_322 
  0x1d530107, 0x3b000902, 0x13643008, 0x46004814,   // en.ht.la_432 pl.so.un_220  uz.lg.et_443 tt.qu.un_660 
  // [22140]
  0x214602a0, 0x38fe61a0, 0x322065a7, 0x1a011da0,   // da.qu.jw_322 za.tlh.tk_322  gv.sq.bs_532 la.en.tl_322 
  0x2100070e, 0xfc5930a4, 0x0500fc1a, 0x151107a7,   // it.jw.un_550 uz.rn.zzp_433  zzp.fr.un_760 bg.ro.un_532 
  0x42080204, 0x1b08020e, 0x0b004c07, 0x190b42ee,   // da.no.co_332 da.no.tr_555  wo.es.un_420 co.es.gl_422 
  0x3d3021b3, 0x3c372312, 0x18330808, 0x05002308,   // fa.uz.ku_743 ky.ba.ug_654  no.nn.ga_443 ca.fr.un_430 
  // [22150]
  0x0b07250c, 0x150802a0, 0x151707ee, 0x043644ee,   // eu.it.es_543 da.no.un_322  bg.sr.un_422 kk.ab.ru_422 
  0x4811150c, 0x25190b0b, 0x30233807, 0x28005c09,   // un.ro.tt_543 es.gl.eu_542  tk.ky.uz_432 sa.sw.un_440 
  0x523b020d, 0x3f033907, 0x392d0f0c, 0x1511480c,   // da.so.ha_554 br.nl.af_432  lv.sk.br_543 tt.ro.un_543 
  0x2d000309, 0x253903a0, 0x351f12a7, 0x123925ee,   // nl.sk.un_440 nl.br.eu_322  hu.cy.zu_532 eu.br.hu_422 
  // [22160]
  0x422205a7, 0x4837250c, 0x25390312, 0x17003b0d,   // fr.oc.co_532 mn.ba.tt_543  nl.br.eu_654 so.sr.un_540 
  0x3f030fa4, 0x39002520, 0x2d093fa7, 0x39002d05,   // lv.nl.af_433 eu.br.un_850  af.pl.sk_532 sk.br.un_330 
  0x0e2e5d04, 0x06002304, 0x482e0e02, 0x302e5e07,   // ss.fo.is_332 ca.de.un_320  is.fo.tt_222 ts.fo.uz_432 
  0x0e122ea9, 0x0e332404, 0x63330804, 0x1dfe2f0c,   // fo.hu.is_544 eo.nn.is_332  no.nn.sco_332 su.tlh.la_543 
  // [22170]
  0x150a04a9, 0x2d002708, 0x0700020b, 0x3c003822,   // ru.mk.un_544 gd.sk.un_430  da.it.un_520 tk.ug.un_870 
  0x19002405, 0x0d2d0e12, 0x3f1f12af, 0x33061207,   // eo.gl.un_330 is.sk.cs_654  hu.cy.af_655 hu.de.nn_432 
  0x06692e0c, 0x330c63ee, 0x120e2ea4, 0x061278ad,   // fo.mfe.de_543 sco.sv.nn_422  fo.is.hu_433 ve.hu.de_643 
  0x30123b55, 0x2425180d, 0x0d190a02, 0x344a68ad,   // ks.ur.uz_442 ga.eu.eo_554  pt.gl.cs_222 ig.yo.xh_643 
  // [22180]
  0x12380c0c, 0x644a6707, 0x0e0c38ee, 0x15126911,   // sv.tk.hu_543 ak.yo.lg_432  tk.sv.is_422 mfe.hu.un_653 
  0x2b003708, 0x39002a04, 0x376a6b08, 0x482330ad,   // st.vi.un_430 mt.br.un_320  ceb.haw.st_443 uz.ky.tt_643 
  0x38000a1b, 0x4f004914, 0x5f00110d, 0x07221155,   // mk.tk.un_770 to.bi.un_660  ro.tn.un_540 ro.oc.it_442 
  0x13484faf, 0x13281bad, 0x6400521a, 0x1a6e560c,   // bi.tt.et_655 tr.sw.et_643  ha.lg.un_760 mg.hmn.tl_543 
  // [22190]
  0x792f6112, 0x47506812, 0x1c390255, 0x630504a7,   // za.su.war_654 ig.fj.sn_654  da.br.id_442 fi.fr.sco_532 
  0x451c61ec, 0x0d05535e, 0x4c554a0c, 0x5300640d,   // za.id.ln_644 ht.fr.cs_652  yo.rw.wo_543 lg.ht.un_540 
  0x23002f05, 0x19003708, 0x212f28a0, 0x3c0730ad,   // su.ca.un_330 st.gl.un_430  sw.su.jw_322 uz.bg.ug_643 
  0x65001213, 0xfe535607, 0x3500fe13, 0x0d001807,   // hu.gv.un_650 mg.ht.tlh_432  tlh.zu.un_650 ga.cs.un_420 
  // [221a0]
  0x53134b04, 0x67731ca4, 0x3e0c10ad, 0x4b006307,   // mi.et.ht_332 id.ny.ak_433  lt.sv.rm_643 sco.mi.un_420 
  0x2d0d2104, 0x04135d09, 0x0a5c19a4, 0x422a050c,   // jw.cs.sk_332 ss.et.fi_444  gl.sa.pt_433 fr.mt.co_543 
  0x18001313, 0xfc1d0107, 0x79241ba9, 0x0a233055,   // et.ga.un_650 en.la.zzp_432  tr.eo.war_544 uz.ky.mk_442 
  0x53131b0b, 0x0f3f2102, 0x301b1fa4, 0x3b00381a,   // tr.et.ht_542 jw.af.lv_222  cy.tr.uz_433 tk.so.un_760 
  // [221b0]
  0xfc6504af, 0x070a0855, 0x2c460112, 0x0a0b18a6,   // fi.gv.zzp_655 uk.mk.bg_442  en.qu.fy_654 ga.es.pt_521 
  0x2efc01a0, 0x48303104, 0x070c2a09, 0x060e3fa7,   // en.zzp.fo_322 az.uz.tt_332  mt.sv.it_444 af.is.de_532 
  0x2322530b, 0x5d000a07, 0x212403ee, 0x28341213,   // ht.oc.ca_542 pt.ss.un_420  nl.eo.jw_422 ur.ps.sd_665 
  0x44233d11, 0x11351511, 0x07250808, 0x6500790c,   // ku.ky.kk_653 un.tg.ro_653  uk.mn.bg_443 war.gv.un_530 
  // [221c0]
  0x2e5d0eac, 0x18123ba9, 0x2d121904, 0x1d0c22a0,   // is.ss.fo_632 ks.ur.ar_544  gl.hu.sk_332 oc.sv.la_322 
  0x466301a7, 0x43464ea9, 0x302142ac, 0x1a4013ec,   // en.sco.qu_532 ay.qu.ie_544  co.jw.uz_632 et.lb.tl_644 
  0x13514c07, 0x0d007907, 0x635b5655, 0x512d4cee,   // wo.kl.et_432 war.cs.un_420  mg.sg.sco_442 wo.sk.kl_422 
  0x32160da4, 0x032c02a4, 0x303879a0, 0x3b584dee,   // cs.hr.bs_433 da.fy.nl_433  war.tk.uz_322 aa.om.so_422 
  // [221d0]
  0x652e0c12, 0x1d00112c, 0x51002f07, 0x28006822,   // sv.fo.gv_654 ro.la.un_990  su.kl.un_420 ig.sw.un_870 
  0x0d232d0d, 0x0248080b, 0x5e45080c, 0x321e31a0,   // sk.ca.cs_554 no.tt.da_542  no.ln.ts_543 az.ms.bs_322 
  0x334006a0, 0x3f385f07, 0x1700030d, 0x45355da9,   // de.lb.nn_322 tn.tk.af_432  nl.sr.un_540 ss.zu.ln_544 
  0x3832160d, 0x01475607, 0x1b2845a7, 0x1b342dee,   // hr.bs.tk_554 mg.sn.en_432  ln.sw.tr_532 sk.xh.tr_422 
  // [221e0]
  0x28006714, 0x103f48a4, 0x28005f07, 0x5d1235a4,   // ak.sw.un_660 tt.af.lt_433  tn.sw.un_420 zu.hu.ss_433 
  0x35081712, 0x34114c04, 0x3f031fa4, 0x13007613,   // sr.uk.tg_654 wo.ro.xh_332  cy.nl.af_433 crs.et.un_650 
  0x10000308, 0x1f031ea4, 0x3450785a, 0x1b4f450c,   // nl.lt.un_430 ms.nl.cy_433  ve.fj.xh_553 ln.bi.tr_543 
  0x3745500c, 0x30233705, 0x182539a0, 0x3e062111,   // fj.ln.st_543 ba.ky.uz_333  br.eu.ga_322 jw.de.rm_653 
  // [221f0]
  0x3f341a02, 0x365046a0, 0x6400561a, 0x09792da0,   // tl.xh.af_222 qu.fj.gn_322  mg.lg.un_760 sk.war.pl_322 
  0x1008175a, 0x01431d0c, 0x4b5c6a07, 0x2137750c,   // sr.uk.be_553 la.ie.en_543  haw.sa.mi_432 nso.st.jw_543 
  0x2a02080c, 0x6b681da9, 0x1d4218a0, 0x3b251855,   // no.da.mt_543 la.ig.ceb_544  ga.co.la_322 ga.eu.so_442 
  0x151602ee, 0x10304402, 0x19233e07, 0x43260baf,   // da.hr.un_422 kk.uz.be_222  rm.ca.gl_432 es.ia.ie_655 
  // [22200]
  0x472420a0, 0x460b36ad, 0x67006120, 0x505f24a7,   // sq.eo.sn_322 gn.es.qu_643  za.ak.un_850 eo.tn.fj_532 
  0x28025908, 0x27002413, 0x070a2355, 0x15373804,   // rn.da.sw_443 eo.gd.un_650  ca.pt.it_442 tk.ba.un_332 
  0x6800641a, 0x73681f09, 0x4d003f13, 0x150804ad,   // lg.ig.un_760 cy.ig.ny_444  af.aa.un_650 ru.uk.un_643 
  0x15fc01ad, 0x4434230d, 0x49734512, 0x6900792a,   // en.zzp.un_643 ky.ps.kk_554  ln.ny.to_654 war.mfe.un_970 
  // [22210]
  0x1a002f07, 0x6435faa4, 0x65fc21a4, 0x3635340d,   // su.tl.un_420 nr.zu.lg_433  jw.zzp.gv_433 xh.zu.gn_554 
  0x3c2818ee, 0x0a004d0b, 0x34006507, 0x071d3e07,   // ar.sd.ug_422 aa.pt.un_520  gv.xh.un_420 rm.la.it_432 
  0x374f01a4, 0x3e6443a0, 0x653bfcec, 0x2c653607,   // en.bi.st_433 ie.lg.rm_322  zzp.so.gv_644 gn.gv.fy_432 
  0x601d0fa4, 0x355c340c, 0x07420a12, 0x08024512,   // lv.la.vo_433 xh.sa.zu_543  pt.co.it_654 ln.da.no_654 
  // [22220]
  0x5100380c, 0x09360204, 0x332163a6, 0x693073a4,   // tk.kl.un_530 da.gn.pl_332  sco.jw.nn_521 ny.uz.mfe_433 
  0x303d2855, 0x48370455, 0x1b002502, 0x20000c08,   // sd.ku.uz_442 ru.ba.tt_442  eu.tr.un_220 sv.sq.un_430 
  0x48171507, 0x285727a7, 0xfe587307, 0x311f18a4,   // un.sr.tt_432 gd.na.sw_532  ny.om.tlh_432 ga.cy.az_433 
  0x190a3ba0, 0x5c523b08, 0x4500780c, 0x08423455,   // so.pt.gl_322 so.ha.sa_443  ve.ln.un_530 xh.co.no_442 
  // [22230]
  0x0a441504, 0x353448a4, 0x530b0aa6, 0x2433080d,   // un.kk.mk_332 tt.xh.zu_433  pt.es.ht_521 no.nn.eo_554 
  0x190b1fee, 0x3b184d0c, 0x1e1c590c, 0x4e5136a4,   // cy.es.gl_422 aa.ga.so_543  rn.id.ms_543 gn.kl.ay_433 
  0x30482307, 0x28234cee, 0x30243e07, 0x232253a9,   // ky.tt.uz_432 wo.ca.sw_422  rm.eo.uz_432 ht.oc.ca_544 
  0x5f005105, 0x52007908, 0x11001d14, 0x135c0ca7,   // kl.tn.un_330 war.ha.un_430  la.ro.un_660 sv.sa.et_532 
  // [22240]
  0x60135c0c, 0x6355470c, 0x464e4708, 0x132047a4,   // sa.et.vo_543 sn.rw.sco_543  sn.ay.qu_443 sn.sq.et_433 
  0x4628590b, 0x4213050c, 0x34442360, 0x253530a0,   // rn.sw.qu_542 fr.et.co_543  ky.kk.ps_664 uz.tg.mn_322 
  0x554e47a9, 0x47004e08, 0x54305113, 0x1900fe04,   // sn.ay.rw_544 ay.sn.un_430  kl.uz.ik_665 tlh.gl.un_320 
  0x62000107, 0x0d1c13ec, 0x2b184e11, 0x46002a08,   // en.kha.un_420 bh.mr.ne_644  ay.ga.vi_653 mt.qu.un_430 
  // [22250]
  0xfc401104, 0x67360da0, 0x381c1e0c, 0x37065da9,   // ro.lb.zzp_332 cs.gn.ak_322  ms.id.tk_543 ss.de.st_544 
  0x4f6976a9, 0x5a634fee, 0x3f2908a0, 0x791b0708,   // crs.mfe.bi_544 bi.sco.sm_422  no.sl.af_322 it.tr.war_443 
  0x4cfc6307, 0x5a4f6904, 0x3f0640ad, 0x6b000612,   // sco.zzp.wo_432 mfe.bi.sm_332  lb.de.af_643 de.ceb.un_640 
  0x643534ac, 0x5bfa34a9, 0x76001e22, 0x3e290f0c,   // xh.zu.lg_632 xh.nr.sg_544  ms.crs.un_870 lv.sl.rm_543 
  // [22260]
  0x3e226aa0, 0x34fa33a0, 0x4c580412, 0x3b005818,   // haw.oc.rm_322 nn.nr.xh_322  fi.om.wo_654 om.so.un_740 
  0x302336a7, 0x3e1825ec, 0x20102514, 0x2e100e0e,   // ab.ky.uz_532 eu.ga.rm_644  eu.lt.sq_666 is.lt.fo_555 
  0x20252a0c, 0x4d5804ad, 0x513b040c, 0x102506a4,   // mt.eu.sq_543 fi.om.aa_643  fi.so.kl_543 de.eu.lt_433 
  0x43423ea4, 0x5200250d, 0x5c4d0f14, 0x3b0206a0,   // rm.co.ie_433 eu.ha.un_540  lv.aa.sa_666 de.da.so_322 
  // [22270]
  0x10070a55, 0x17301505, 0x21183460, 0x2535305a,   // mk.bg.be_442 un.uz.sr_333  ps.ar.fa_664 uz.tg.mn_553 
  0x37341a05, 0x1004130d, 0x303239a7, 0x42230fee,   // tl.xh.st_333 et.fi.lt_554  br.bs.uz_532 lv.ca.co_422 
  0x136458a4, 0x072e100d, 0x0f3b4ca0, 0x4d6b79a9,   // om.lg.et_433 lt.fo.it_554  wo.so.lv_322 war.ceb.aa_544 
  0x0c215304, 0x395c65a0, 0x4836100d, 0x3b001305,   // ht.jw.sv_332 gv.sa.br_322  be.ab.tt_554 et.so.un_330 
  // [22280]
  0x2d0d4ca0, 0x355d4808, 0x3b64670d, 0x443610ac,   // wo.cs.sk_322 tt.ss.zu_443  ak.lg.so_554 be.ab.kk_632 
  0x2f0c380c, 0x654d3ba4, 0x462a1e02, 0x6a375f12,   // tk.sv.su_543 so.aa.gv_433  ms.mt.qu_222 tn.st.haw_654 
  0x4a4c020c, 0x49214dee, 0x28006a1a, 0x215e35a4,   // da.wo.yo_543 aa.jw.to_422  haw.sw.un_760 zu.ts.jw_433 
  0x351a28a4, 0x6b383bad, 0x11005f0c, 0x24455fad,   // sw.tl.zu_433 so.tk.ceb_643  tn.ro.un_530 tn.ln.eo_643 
  // [22290]
  0x0c001c04, 0x041328a0, 0x645355a4, 0x5f754055,   // id.sv.un_320 sw.et.fi_322  rw.ht.lg_433 lb.nso.tn_442 
  0x4c004518, 0x5f5a2707, 0x2e2b0e08, 0x063602a9,   // ln.wo.un_740 gd.sm.tn_432  is.vi.fo_443 da.gn.de_544 
  0x1a732812, 0x68005309, 0x37125fa7, 0x6b006505,   // sw.ny.tl_654 ht.ig.un_440  tn.hu.st_532 gv.ceb.un_330 
  0x0111150c, 0x13004707, 0x03020604, 0x38353408,   // un.ro.en_543 sn.et.un_420  de.da.nl_332 xh.zu.tk_443 
  // [222a0]
  0x473b6412, 0x284d3ba4, 0x13795f11, 0x1f330804,   // lg.so.sn_654 so.aa.sw_433  tn.war.et_653 no.nn.cy_332 
  0x06362a02, 0x492d0d0b, 0x39123b0c, 0x220a3e09,   // mt.gn.de_222 cs.sk.to_542  so.hu.br_543 rm.pt.oc_444 
  0x0c006016, 0x045a13a0, 0x375f3307, 0x0a083cac,   // vo.sv.un_720 et.sm.fi_322  nn.tn.st_432 ug.uk.mk_632 
  0x0c6301a0, 0x3b002f08, 0x2900381a, 0x6b7328af,   // en.sco.sv_322 su.so.un_430  tk.sl.un_760 sw.ny.ceb_655 
  // [222b0]
  0x402c15a0, 0x30253813, 0x390c0107, 0x3f1c1e07,   // un.fy.lb_322 tk.mn.uz_665  en.sv.br_432 ms.id.af_432 
  0x64001104, 0x58fc65a0, 0x02003812, 0x5c3b1c09,   // ro.lg.un_320 gv.zzp.om_322  tk.da.un_640 mr.ks.sa_444 
  0x12fc1f02, 0x28000c08, 0x081535a7, 0xfc3809a0,   // cy.zzp.hu_222 sv.sw.un_430  tg.uk.un_520 pl.tk.zzp_322 
  0x23004d0c, 0x0400fc1a, 0x0265fc0c, 0x253f0305,   // aa.ca.un_530 zzp.fi.un_760  zzp.gv.da_543 nl.af.eu_333 
  // [222c0]
  0x18003304, 0x40200612, 0x34001b07, 0x51002104,   // nn.ga.un_320 de.sq.lb_654  tr.xh.un_420 jw.kl.un_320 
  0x041d1807, 0x0a382308, 0x651504a4, 0x6940060d,   // ga.la.fi_432 ky.tk.mk_443  fi.gv.un_430 de.lb.mfe_554 
  0x38442311, 0x1b00390c, 0x57120612, 0x52190b09,   // ky.kk.tk_653 br.tr.un_530  de.hu.na_654 es.gl.ha_444 
  0x1a125113, 0x233e4204, 0x692c250e, 0x2d0d49a6,   // kl.hu.tl_665 co.rm.ca_332  eu.fy.mfe_555 to.cs.sk_521 
  // [222d0]
  0x4d0c23a4, 0x67405712, 0x0b2d0d08, 0x2339060c,   // ca.sv.aa_433 na.lb.ak_654  cs.sk.es_443 de.br.ca_543 
  0x1c044907, 0x23004d0b, 0x34000d08, 0x4d462014,   // to.fi.id_432 aa.ca.un_520  cs.xh.un_430 sq.qu.aa_666 
  0x1e000c13, 0x350a3807, 0x100825ec, 0x0b491907,   // sv.ms.un_650 tk.mk.tg_432  mn.uk.be_644 gl.to.es_432 
  0x5a4967a0, 0x5a046aee, 0x08363504, 0x36004813,   // ak.to.sm_322 haw.fi.sm_422  tg.ab.uk_332 tt.gn.un_650 
  // [222e0]
  0x443418a9, 0x484006a0, 0x34136ba0, 0x40212fa0,   // ar.ps.kk_544 de.lb.tt_322  ceb.et.xh_322 su.jw.lb_322 
  0x3000131a, 0x59006405, 0x484c1ea0, 0x2f006b07,   // et.uz.un_760 lg.rn.un_330  ms.wo.tt_322 ceb.su.un_420 
  0x2800680b, 0x330823ec, 0x05101307, 0x3f131d07,   // ig.sw.un_520 ca.no.nn_644  et.lt.fr_432 la.et.af_432 
  0x31763b55, 0x13000218, 0x652e520c, 0x352338a9,   // so.crs.az_442 da.et.un_740  ha.fo.gv_543 tk.ky.tg_544 
  // [222f0]
  0x043b5102, 0x4a00020d, 0x32000e02, 0x785e1c0c,   // kl.so.fi_222 da.yo.un_540  is.bs.un_220 id.ts.ve_543 
  0x3f000211, 0x5c5058a0, 0x2c037605, 0x10180c07,   // da.af.un_630 om.fj.sa_322  crs.nl.fy_333 sv.ga.lt_432 
  0x1376690d, 0x51005a07, 0x515b58ec, 0x29110307,   // mfe.crs.et_554 sm.kl.un_420  om.sg.kl_644 nl.ro.sl_432 
  0x40030604, 0x03124aee, 0x18343c0c, 0x5804670e,   // de.nl.lb_332 yo.hu.nl_422  ug.ps.ar_543 ak.fi.om_555 
  // [22300]
  0x40510ea4, 0x02104d07, 0x12033f02, 0x37000307,   // is.kl.lb_433 aa.lt.da_432  af.nl.hu_222 nl.st.un_420 
  0x30153ca0, 0x08153807, 0x04250211, 0x73003e0e,   // ug.uz.un_320 tk.uk.un_420  da.eu.fi_653 rm.ny.un_550 
  0x6538300e, 0x641b1905, 0x461865a6, 0x385365a0,   // uz.tk.gv_555 gl.tr.lg_333  gv.ga.qu_521 gv.ht.tk_322 
  0x59003807, 0x643559a0, 0x59650205, 0x385c1012,   // tk.rn.un_420 rn.zu.lg_322  da.gv.rn_333 lt.sa.tk_654 
  // [22310]
  0x0a173ca9, 0x6a024b04, 0x3b025955, 0x30122809,   // ug.sr.mk_544 mi.da.haw_332  rn.da.so_442 sd.ur.uz_444 
  0x6b041dee, 0x2e0b30a7, 0x06011504, 0x27043655,   // la.fi.ceb_422 uz.es.fo_532  un.en.de_332 gn.fi.gd_442 
  0x7369760d, 0x10005c13, 0x53095c11, 0x6a5121af,   // crs.mfe.ny_554 sa.lt.un_650  sa.pl.ht_653 jw.kl.haw_655 
  0x2efc60a4, 0x65515a0d, 0x601101a4, 0x34355908,   // vo.zzp.fo_433 sm.kl.gv_554  en.ro.vo_433 rn.zu.xh_443 
  // [22320]
  0x3800460d, 0x34001802, 0x3216fc08, 0x5e65fcad,   // qu.tk.un_540 ga.xh.un_220  zzp.hr.bs_443 zzp.gv.ts_643 
  0x48384c07, 0x101901a4, 0x38000814, 0x64002822,   // wo.tk.tt_432 en.gl.lt_433  uk.tk.un_660 sw.lg.un_870 
  0x28183ba7, 0x483b4ca4, 0x5e105c08, 0x0242fca4,   // ks.ar.sd_532 wo.so.tt_433  sa.lt.ts_443 zzp.co.da_433 
  0x57591a0c, 0x0b2342a0, 0x56371004, 0x06403eee,   // tl.rn.na_543 co.ca.es_322  lt.st.mg_332 rm.lb.de_422 
  // [22330]
  0x216455a4, 0x190a1eee, 0x56151ca0, 0x5c3915a7,   // rw.lg.jw_433 ms.pt.gl_422  id.mg.un_320 un.br.sa_532 
  0x35fc5708, 0x4e582812, 0x25006812, 0x4a6979a4,   // na.zzp.zu_443 sw.om.ay_654  ig.eu.un_640 war.mfe.yo_433 
  0x2851fca7, 0x432460a4, 0x5b584c0c, 0x673f6555,   // zzp.kl.sw_532 vo.eo.ie_433  wo.om.sg_543 gv.af.ak_442 
  0x5c1b65a0, 0x15005e07, 0x35005720, 0x642f03ee,   // gv.tr.sa_322 ts.un.un_420  na.zu.un_850 nl.su.lg_422 
  // [22340]
  0x4c6845a9, 0x330c0e07, 0x274a6808, 0x133848ad,   // ln.ig.wo_544 is.sv.nn_432  ig.yo.gd_443 tt.tk.et_643 
  0x17350407, 0x2e000909, 0x653f03af, 0x29000f05,   // ru.tg.sr_432 pl.fo.un_440  nl.af.gv_655 lv.sl.un_330 
  0x2855350c, 0x2c13650c, 0x04586504, 0x0e135c0c,   // zu.rw.sw_543 gv.et.fy_543  gv.om.fi_332 sa.et.is_543 
  0x1d3e0c0b, 0x490a56ee, 0x214418a4, 0x78353460,   // sv.rm.la_542 mg.pt.to_422  ar.kk.fa_433 xh.zu.ve_664 
  // [22350]
  0x332e020e, 0x4700732a, 0x56375aee, 0x06400ca7,   // da.fo.nn_555 ny.sn.un_970  sm.st.mg_422 sv.lb.de_532 
  0x04100a12, 0x0a303502, 0x20575807, 0xfc51250c,   // mk.be.ru_654 tg.uz.mk_222  om.na.sq_432 eu.kl.zzp_543 
  0x1dfc0e08, 0x1204250c, 0x07302504, 0x0938560c,   // is.zzp.la_443 eu.fi.hu_543  mn.uz.bg_332 mg.tk.pl_543 
  0x303736a4, 0x38092d5a, 0xfc600e55, 0x40000c09,   // ab.ba.uz_433 sk.pl.tk_553  is.vo.zzp_442 sv.lb.un_440 
  // [22360]
  0x650938ad, 0x03fe0c0c, 0x22fc60ad, 0x44071704,   // tk.pl.gv_643 sv.tlh.nl_543  vo.zzp.oc_643 sr.bg.kk_332 
  0x2a250504, 0x655804ec, 0x0cfc0504, 0x1b3b0207,   // fr.eu.mt_332 fi.om.gv_644  fr.zzp.sv_332 da.so.tr_432 
  0x250258a0, 0x1b00190d, 0x28184409, 0x4d2325a4,   // om.da.eu_322 gl.tr.un_540  kk.ar.sd_444 eu.ca.aa_433 
  0x732a1e0c, 0x384c09ad, 0x2400310c, 0x1c281e0c,   // ms.mt.ny_543 pl.wo.tk_643  az.eo.un_530 ms.sw.id_543 
  // [22370]
  0x08003b07, 0x6b732da4, 0x285a60a7, 0x102a550d,   // so.no.un_420 sk.ny.ceb_433  vo.sm.sw_532 rw.mt.lt_554 
  0x1e5669ee, 0x020c12a0, 0x344207a4, 0x3f0ffca0,   // mfe.mg.ms_422 hu.sv.da_322  it.co.xh_433 zzp.lv.af_322 
  0x51020404, 0x5100582b, 0x5046640c, 0x02240fa0,   // fi.da.kl_332 om.kl.un_980  lg.qu.fj_543 lv.eo.da_322 
  0x2a0964a9, 0x63006208, 0x420726a4, 0x38301512,   // lg.pl.mt_544 kha.sco.un_430  ia.it.co_433 un.uz.tk_654 
  // [22380]
  0x150810af, 0x0a303ca0, 0x4d3050a9, 0x30482504,   // be.uk.un_655 ug.uz.mk_322  fj.uz.aa_544 eu.tt.uz_332 
  0x2f004d18, 0x5c2f4d0c, 0x1508480e, 0x0912300c,   // aa.su.un_740 aa.su.sa_543  tt.uk.un_555 uz.hu.pl_543 
  0x343018a4, 0x481b0a02, 0x23301504, 0x304824a4,   // ar.uz.ps_433 pt.tr.tt_222  un.uz.ky_332 eo.tt.uz_433 
  0x07001122, 0xfcfe010c, 0x4f694007, 0x300835ee,   // ro.bg.un_870 en.tlh.zzp_543  lb.mfe.bi_432 tg.uk.uz_422 
  // [22390]
  0x35342aa0, 0x04300704, 0x271928af, 0x082e3312,   // mt.xh.zu_322 bg.uz.ru_332  sw.gl.gd_655 nn.fo.no_654 
  0x2a005305, 0x6100280c, 0x1800780b, 0x78005e1a,   // ht.mt.un_330 sw.za.un_530  ve.ga.un_520 ts.ve.un_760 
  0x11005e02, 0x2a004e1a, 0x1a005512, 0x3430180b,   // ts.ro.un_220 ay.mt.un_760  rw.tl.un_640 ar.uz.ps_542 
  0x5d3559a0, 0x18652707, 0x78000621, 0x5f7518a9,   // rn.zu.ss_322 gd.gv.ga_432  de.ve.un_860 ga.nso.tn_544 
  // [223a0]
  0x15393eec, 0x676404a4, 0x0f004608, 0x34303b0c,   // rm.br.un_644 fi.lg.ak_433  qu.lv.un_430 so.uz.xh_543 
  0x49005813, 0x78004508, 0x67644d0c, 0x65646307,   // om.to.un_650 ln.ve.un_430  aa.lg.ak_543 sco.lg.gv_432 
  0x1d4637a6, 0x654d680c, 0x684a4c04, 0x303b3da4,   // st.qu.la_521 ig.aa.gv_543  wo.yo.ig_332 ku.ks.uz_433 
  0x644c34a4, 0x5e5d18a0, 0x2a5e010b, 0x1a1c38a0,   // xh.wo.lg_433 ga.ss.ts_322  en.ts.mt_542 tk.id.tl_322 
  // [223b0]
  0x0300400c, 0x4c006805, 0x28fc4e07, 0x1d6563a4,   // lb.nl.un_530 ig.wo.un_330  ay.zzp.sw_432 sco.gv.la_433 
  0x0300340c, 0x3f136e07, 0x63033f0c, 0x406b3ba0,   // xh.nl.un_530 hmn.et.af_432  af.nl.sco_543 so.ceb.lb_322 
  0x13494b04, 0x3007250c, 0x3f02010c, 0x13495808,   // mi.to.et_332 mn.bg.uz_543  en.da.af_543 om.to.et_443 
  0x04351704, 0x421a54a4, 0x15363514, 0x201d39a4,   // sr.tg.ru_332 ik.tl.co_433  tg.ab.un_666 br.la.sq_433 
  // [223c0]
  0x13211c04, 0x65202a02, 0x0c004c08, 0x1d182704,   // id.jw.et_332 mt.sq.gv_222  wo.sv.un_430 gd.ga.la_332 
  0x081007ec, 0x5c000c02, 0x0c39270e, 0x79000608,   // bg.be.uk_644 sv.sa.un_220  gd.br.sv_555 de.war.un_430 
  0x640e2eaf, 0x44182814, 0x30281805, 0x2a4f4c11,   // fo.is.lg_655 sd.ar.kk_666  ar.sd.uz_333 wo.bi.mt_653 
  0x3e000e05, 0x57005114, 0x4d6b650e, 0x283d1209,   // is.rm.un_330 kl.na.un_660  gv.ceb.aa_555 ur.ku.sd_444 
  // [223d0]
  0x1d014aa0, 0x2d002e09, 0x01005702, 0x18003c22,   // yo.en.la_322 fo.sk.un_440  na.en.un_220 ug.ar.un_870 
  0x24002b02, 0x4200fc21, 0x100c0804, 0x153c38ec,   // vi.eo.un_220 zzp.co.un_860  no.sv.lt_332 tk.ug.un_644 
  0x4c00251a, 0x4c254da9, 0x4c4d25ec, 0x074219a0,   // eu.wo.un_760 aa.eu.wo_544  eu.aa.wo_644 gl.co.it_322 
  0x233730a7, 0x05254c07, 0x034d3f0c, 0x253f4ca4,   // uz.ba.ky_532 wo.eu.fr_432  af.aa.nl_543 wo.af.eu_433 
  // [223e0]
  0x3f2a0704, 0x25033f0c, 0x131230a9, 0x534c15a0,   // it.mt.af_332 af.nl.eu_543  uz.hu.et_544 un.wo.ht_322 
  0x432a30a4, 0x253644ee, 0x37044404, 0x016b46ee,   // uz.mt.ie_433 kk.ab.mn_422  kk.ru.ba_332 qu.ceb.en_422 
  0x183809a4, 0xfc78510c, 0x283d1804, 0x10241d0c,   // pl.tk.ga_433 kl.ve.zzp_543  ar.ku.sd_332 la.eo.lt_543 
  0x1d58100c, 0x24101d13, 0x0f1d10ad, 0x10241c07,   // lt.om.la_543 la.lt.eo_665  lt.la.lv_643 id.eo.lt_432 
  // [223f0]
  0x1d0f10af, 0x4417350b, 0x5f1afc08, 0x58001d0d,   // lt.lv.la_655 tg.sr.kk_542  zzp.tl.tn_443 la.om.un_540 
  0x17083cee, 0x463809a4, 0x150425ec, 0x07043005,   // ug.uk.sr_422 pl.tk.qu_433  mn.ru.un_644 uz.ru.bg_333 
  0x04005002, 0x1a56fc07, 0x160d29a4, 0x1d0e1012,   // fj.fi.un_220 zzp.mg.tl_432  sl.cs.hr_433 lt.is.la_654 
  0x39001d09, 0x131d58a9, 0x16362907, 0x46001708,   // la.br.un_440 om.la.et_544  sl.gn.hr_432 sr.qu.un_430 
  
  // [22400]
  0x481507ad, 0x241d62ec, 0x79392da0, 0x350417a7,   // bg.tt.un_630 kha.la.eo_644  sk.br.war_322 sr.ru.tg_532 
  0x43560660, 0x76000e09, 0x7306040d, 0x130406a0,   // de.mg.ie_664 is.crs.un_440  fi.de.ny_554 de.fi.et_322 
  0x10301504, 0x03652c08, 0x2a204da6, 0x2900fe19,   // un.uz.be_332 fy.gv.nl_443  aa.sq.mt_521 tlh.sl.un_750 
  0x192a63ee, 0x131d4d55, 0x3c10360c, 0x40005c05,   // sco.mt.gl_422 aa.la.et_442  ab.be.ug_543 sa.lb.un_330 
  // [22410]
  0x58130204, 0x261501af, 0x58045108, 0x18001109,   // da.et.om_332 en.ia.un_650  kl.fi.om_443 ro.ga.un_440 
  0x115a6707, 0x56495aad, 0x1300100b, 0x040a23a7,   // ak.sm.ro_432 sm.to.mg_643  lt.et.un_520 ky.mk.ru_532 
  0x273e18ee, 0x790c0612, 0x252330a7, 0x121b0c55,   // ga.rm.gd_422 de.sv.war_654  uz.ky.mn_532 sv.tr.hu_442 
  0x28366a0c, 0x62044b0b, 0x121b0ca4, 0x2f6236ad,   // haw.gn.sw_543 mi.fi.kha_542  sv.tr.hu_433 gn.kha.su_643 
  // [22420]
  0x1a6b78af, 0x0f4a1008, 0x64531fa0, 0x6b361aa4,   // ve.ceb.tl_655 lt.yo.lv_443  cy.ht.lg_322 tl.gn.ceb_433 
  0x10001e09, 0x375f6808, 0x4900100c, 0x2718630b,   // ms.lt.un_440 ig.tn.st_443  lt.to.un_530 sco.ga.gd_542 
  0x37040a04, 0x06480c12, 0x0802200c, 0x04654704,   // mk.ru.ba_332 sv.tt.de_654  sq.da.no_543 sn.gv.fi_332 
  0x0d002a09, 0x4b496aa4, 0x606a4bec, 0x044b36a4,   // mt.cs.un_440 haw.to.mi_433  mi.haw.vo_644 gn.mi.fi_433 
  // [22430]
  0x57400614, 0x31380307, 0x321761a4, 0x382f1c04,   // de.lb.na_666 nl.tk.az_432  za.sr.bs_433 id.su.tk_332 
  0x134c2fee, 0xfe003107, 0x10fe0f07, 0x4a7350af,   // su.wo.et_422 az.tlh.un_420  lv.tlh.lt_432 fj.ny.yo_655 
  0x29161104, 0x3e116304, 0x4a003002, 0x06355da7,   // ro.hr.sl_332 sco.ro.rm_332  uz.yo.un_220 ss.zu.de_532 
  0xfc345d13, 0x736830a9, 0x3b522aa0, 0x60253508,   // ss.xh.zzp_665 uz.ig.ny_544  mt.ha.so_322 zu.eu.vo_443 
  // [22440]
  0x28123b55, 0x31761312, 0x06120c0b, 0x253510a0,   // ks.ur.sd_442 et.crs.az_654  sv.hu.de_542 be.tg.mn_322 
  0x233d3408, 0x1d2f2112, 0x00006301, 0x53691d0c,   // ps.ku.ky_443 jw.su.la_654  sco.un.un_200 la.mfe.ht_543 
  0x0c3e0604, 0x22652512, 0x38001209, 0x251e1c07,   // de.rm.sv_332 eu.gv.oc_654  hu.tk.un_440 id.ms.eu_432 
  0x5147280c, 0x1f256507, 0x0300632a, 0x1f002d08,   // sw.sn.kl_543 gv.eu.cy_432  sco.nl.un_970 sk.cy.un_430 
  // [22450]
  0x2863045a, 0x793001a0, 0x18031dee, 0x03783f08,   // fi.sco.sw_553 en.uz.war_322  la.nl.ga_422 af.ve.nl_443 
  0x1d0324a0, 0x0500fc0c, 0x65271da4, 0x635105a9,   // eo.nl.la_322 zzp.fr.un_530  la.gd.gv_433 fr.kl.sco_544 
  0x273f0355, 0x18375f12, 0x1d6505a4, 0x03063fa7,   // nl.af.gd_442 tn.st.ga_654  fr.gv.la_433 af.de.nl_532 
  0x63434cee, 0x791d2304, 0x3637150d, 0x25313b08,   // wo.ie.sco_422 ca.la.war_332  un.ba.ab_554 so.az.eu_443 
  // [22460]
  0x15231512, 0x081738a0, 0x03003702, 0x0c3f20ee,   // un.ky.un_654 tk.sr.uk_322  st.nl.un_220 sq.af.sv_422 
  0x6b211ea9, 0x2d0d04ec, 0x4e463b0d, 0x56003505,   // ms.jw.ceb_544 fi.cs.sk_644  so.qu.ay_554 zu.mg.un_330 
  0x022704a4, 0x1b3848ac, 0x421d3ea9, 0x173f0355,   // fi.gd.da_433 tt.tk.tr_632  rm.la.co_544 nl.af.sr_442 
  0x63314d05, 0x27183f09, 0x24001d08, 0x2c331fee,   // aa.az.sco_333 af.ga.gd_444  la.eo.un_430 cy.nn.fy_422 
  // [22470]
  0x1e2f1fee, 0x57002c08, 0x3f1d2404, 0x6700560c,   // cy.su.ms_422 fy.na.un_430  eo.la.af_332 mg.ak.un_530 
  0x08651f07, 0x23051d0c, 0x1f023f04, 0x365d355a,   // cy.gv.no_432 la.fr.ca_543  af.da.cy_332 zu.ss.gn_553 
  0x36002d09, 0x36001011, 0x05533fee, 0x0c0d1fa7,   // sk.gn.un_440 lt.gn.un_630  af.ht.fr_422 cy.cs.sv_532 
  0x48370407, 0x09003f09, 0x353848a9, 0x5f375607,   // ru.ba.tt_432 af.pl.un_440  tt.tk.tg_544 mg.st.tn_432 
  // [22480]
  0x3600461a, 0x0c000614, 0x12040c05, 0x0e000c11,   // qu.gn.un_760 de.sv.un_660  sv.fi.hu_333 sv.is.un_630 
  0x130c1b0c, 0x0a3517ee, 0x13004d13, 0x351707ec,   // tr.sv.et_543 sr.tg.mk_422  aa.et.un_650 bg.sr.tg_644 
  0x58182704, 0x185d1f08, 0x24182711, 0x3f134d55,   // gd.ga.om_332 cy.ss.ga_443  gd.ga.eo_653 aa.et.af_442 
  0x1c1309a6, 0x2c2d2402, 0x384804a9, 0x3b6343a0,   // hi.bh.mr_521 eo.sk.fy_222  ru.tt.tk_544 ie.sco.so_322 
  // [22490]
  0x380f3108, 0x0f1d13af, 0x38152312, 0x241d4da4,   // az.lv.tk_443 et.la.lv_655  ky.tk.un_640 aa.la.eo_433 
  0x243e53a4, 0x13002319, 0x1d0f1d0c, 0x4e1d3e13,   // ht.rm.eo_433 ca.et.un_750  la.lv.la_543 rm.la.ay_665 
  0x29431da7, 0x6b005f08, 0x5f40060c, 0x40355da7,   // la.ie.sl_532 tn.ceb.un_430  de.lb.tn_543 ss.zu.lb_532 
  0x040a3702, 0x290d0902, 0x524258ee, 0x21291855,   // ba.mk.ru_222 pl.cs.sl_222  om.co.ha_422 ga.sl.jw_442 
  // [224a0]
  0x53431d09, 0x421373ad, 0x402806a9, 0x260e2e08,   // la.ie.ht_444 ny.et.co_643  de.sw.lb_544 fo.is.ia_443 
  0x053e13a0, 0x34000607, 0x0e0c0604, 0x38234811,   // et.rm.fr_322 de.xh.un_420  de.sv.is_332 tt.ky.tk_653 
  0x070410ad, 0x49003404, 0x4006340c, 0x0c06120c,   // be.ru.bg_643 xh.to.un_320  xh.de.lb_543 hu.de.sv_543 
  0x2c186504, 0x135c1c5a, 0x130c06a0, 0x25271807,   // gv.ga.fy_332 mr.sa.bh_553  de.sv.et_322 ga.gd.eu_432 
  // [224b0]
  0x111825a0, 0x15353005, 0x122f3907, 0x033f65ee,   // eu.ga.ro_322 uz.tg.un_333  br.su.hu_432 gv.af.nl_422 
  0x53007309, 0x4a000907, 0x5d641c07, 0x64404aa0,   // ny.ht.un_440 pl.yo.un_420  id.lg.ss_432 yo.lb.lg_322 
  0x1c0921ad, 0x0e1b31a4, 0x02126804, 0x21021c07,   // jw.pl.id_643 az.tr.is_433  ig.hu.da_332 id.da.jw_432 
  0x2f124d0c, 0x101176a4, 0x4a534fa9, 0x09524aee,   // aa.hu.su_543 crs.ro.lt_433  bi.ht.yo_544 yo.ha.pl_422 
  // [224c0]
  0x1b00432b, 0x0a07430c, 0x09736aa9, 0x094a73af,   // ie.tr.un_980 ie.it.pt_543  haw.ny.pl_544 ny.yo.pl_655 
  0x1b38300c, 0x3b09730c, 0x1b303107, 0x4a020611,   // uz.tk.tr_543 ny.pl.so_543  az.uz.tr_432 de.da.yo_653 
  0x734a090e, 0x0900470d, 0x73000919, 0x1b00301a,   // pl.yo.ny_555 sn.pl.un_540  pl.ny.un_750 uz.tr.un_760 
  0x392512a0, 0x67280213, 0x644a73a0, 0x1b30fe12,   // hu.eu.br_322 da.sw.ak_665  ny.yo.lg_322 tlh.uz.tr_654 
  // [224d0]
  0x15350412, 0x2200390c, 0x396353a9, 0x5968550d,   // ru.tg.un_654 br.oc.un_530  ht.sco.br_544 rw.ig.rn_554 
  0x39206555, 0x20006818, 0x18654c02, 0x55101308,   // gv.sq.br_442 ig.sq.un_740  wo.gv.ga_222 et.lt.rw_443 
  0x64006819, 0x0f345da9, 0x1325060e, 0x25565da9,   // ig.lg.un_750 ss.xh.lv_544  de.eu.et_555 ss.mg.eu_544 
  0x271e2504, 0x33065f07, 0x37003614, 0xfc375f11,   // eu.ms.gd_332 tn.de.nn_432  gn.st.un_660 tn.st.zzp_653 
  // [224e0]
  0x513f0604, 0x4b00fc11, 0x13006212, 0x0c1b3007,   // de.af.kl_332 zzp.mi.un_630  kha.et.un_640 uz.tr.sv_432 
  0x19002705, 0x5f00041a, 0x37364ba0, 0x04004729,   // gd.gl.un_330 fi.tn.un_760  mi.gn.st_322 sn.fi.un_960 
  0x464830a9, 0x360425a9, 0x52330805, 0x1d002705,   // uz.tt.qu_544 eu.fi.gn_544  no.nn.ha_333 gd.la.un_330 
  0x42780511, 0x084752a0, 0x0cfc080c, 0x150640a4,   // fr.ve.co_653 ha.sn.no_322  no.zzp.sv_543 lb.de.un_433 
  // [224f0]
  0x11472504, 0x271f02a0, 0x6b5f47a0, 0x120c13a9,   // eu.sn.ro_332 da.cy.gd_322  sn.tn.ceb_322 et.sv.hu_544 
  0x3e1850a9, 0x52567308, 0x653962a9, 0x65000523,   // fj.ga.rm_544 ny.mg.ha_443  kha.br.gv_544 fr.gv.un_880 
  0x3502345a, 0x18004209, 0x522e0e05, 0x07094204,   // xh.da.zu_553 co.ga.un_440  is.fo.ha_333 co.pl.it_332 
  0x05000421, 0x150a38a4, 0x1156040c, 0x13044707,   // fi.fr.un_860 tk.mk.un_433  fi.mg.ro_543 sn.fi.et_432 
  // [22500]
  0x3f0513af, 0x42271813, 0x282556ee, 0x7960180c,   // et.fr.af_655 ga.gd.co_665  mg.eu.sw_422 ga.vo.war_543 
  0x12420713, 0x13484f0c, 0x171504ec, 0x27006312,   // it.co.hu_665 bi.tt.et_543  ru.sr.un_640 sco.gd.un_640 
  0x253c0404, 0x272342a0, 0x58202509, 0x69001d13,   // ru.ug.mn_332 co.ca.gd_322  eu.sq.om_444 la.mfe.un_650 
  0xfc5825ec, 0x231510a7, 0x0e255813, 0x1d004d08,   // eu.om.zzp_644 be.ky.un_520  om.eu.is_665 aa.la.un_430 
  // [22510]
  0x58024aa0, 0x0c3e0da0, 0x37483805, 0x04460e05,   // yo.da.om_322 cs.rm.sv_322  tk.tt.ba_333 is.qu.fi_333 
  0x13000507, 0x5827250c, 0x23582511, 0x43190b0d,   // fr.et.un_420 eu.gd.om_543  eu.om.ca_653 es.gl.ie_554 
  0x1f461204, 0x113378af, 0x260a250c, 0x6a4652a7,   // hu.qu.cy_332 ve.nn.ro_655  eu.pt.ia_543 ha.qu.haw_532 
  0x3d233b0c, 0x58002504, 0x482a25ee, 0x0a007804,   // ks.ky.ku_543 eu.om.un_320  eu.mt.tt_422 ve.pt.un_320 
  // [22520]
  0x531129a0, 0x4258250c, 0x12000314, 0x131d6bad,   // sl.ro.ht_322 eu.om.co_543  nl.hu.un_660 ceb.la.et_643 
  0xfc121a02, 0x276e13ee, 0x232e2507, 0x733855a0,   // tl.hu.zzp_222 et.hmn.gd_422  eu.fo.ca_432 rw.tk.ny_322 
  0x30582aec, 0x1d6e2d07, 0x652239ee, 0x4c1833ee,   // mt.om.uz_644 sk.hmn.la_432  br.oc.gv_422 nn.ga.wo_422 
  0x5228250b, 0x55593407, 0x525024a4, 0x4f4e5ea4,   // eu.sw.ha_542 xh.rn.rw_432  eo.fj.ha_433 ts.ay.bi_433 
  // [22530]
  0x205948a0, 0x111a5a0c, 0x3837300c, 0x0f587907,   // tt.rn.sq_322 sm.tl.ro_543  uz.ba.tk_543 war.om.lv_432 
  0x0b4753a0, 0x4a002705, 0x37003c14, 0x483708a0,   // ht.sn.es_322 gd.yo.un_330  ug.ba.un_660 uk.ba.tt_322 
  0x120d2fa6, 0x15173004, 0x23004604, 0x100f1702,   // su.cs.hu_521 uz.sr.un_332  qu.ca.un_320 sr.lv.lt_222 
  0x12000e1b, 0x100f17a0, 0x1f3f39a0, 0x17350aad,   // is.hu.un_770 sr.lv.lt_322  br.af.cy_322 mk.tg.sr_643 
  // [22540]
  0x252419a0, 0xfc4a68a7, 0x2c0b23ee, 0x5d2834a4,   // gl.eo.eu_322 ig.yo.zzp_532  ca.es.fy_422 xh.sw.ss_433 
  0x1c00fc0d, 0x0c5d02a0, 0x2f136ba4, 0x2c005302,   // zzp.id.un_540 da.ss.sv_322  ceb.et.su_433 ht.fy.un_220 
  0x18241da4, 0x305513a4, 0x64001004, 0x1b555d02,   // la.eo.ga_433 et.rw.uz_433  lt.lg.un_320 ss.rw.tr_222 
  0x3e432208, 0x3b132da0, 0x01fc0604, 0x1300510d,   // oc.ie.rm_443 sk.et.so_322  de.zzp.en_332 kl.et.un_540 
  // [22550]
  0x30fc380c, 0x261e1ca9, 0x11001304, 0x0a261d08,   // tk.zzp.uz_543 id.ms.ia_544  et.ro.un_320 la.ia.pt_443 
  0x0f605da9, 0x31485da7, 0x1b1e400e, 0x17293b0c,   // ss.vo.lv_544 ss.tt.az_532  lb.ms.tr_555 so.sl.sr_543 
  0x3906025a, 0x46021a07, 0x3b381ba9, 0x50001313,   // da.de.br_553 tl.da.qu_432  tr.tk.so_544 et.fj.un_650 
  0x511e1ca4, 0x60345dad, 0x31342a02, 0x38304e0c,   // id.ms.kl_433 ss.xh.vo_643  mt.xh.az_222 ay.uz.tk_543 
  // [22560]
  0x695d1c07, 0x6b041c07, 0x46fe20ec, 0x1b5d600c,   // id.ss.mfe_432 id.fi.ceb_432  sq.tlh.qu_644 vo.ss.tr_543 
  0x244543a4, 0x345a1d05, 0x04071105, 0x4947640b,   // ie.ln.eo_433 la.sm.xh_333  ro.bg.ru_333 lg.sn.to_542 
  0x2a001f04, 0x35005f09, 0x2100470e, 0x5f004705,   // cy.mt.un_320 tn.zu.un_440  sn.jw.un_550 sn.tn.un_330 
  0x24005508, 0x354415a6, 0x40004707, 0x016b6309,   // rw.eo.un_430 un.kk.tg_521  sn.lb.un_420 sco.ceb.en_444 
  // [22570]
  0x481129a4, 0x13510414, 0x3600351b, 0x2d1806a4,   // sl.ro.tt_433 fi.kl.et_666  tg.ab.un_770 de.ga.sk_433 
  0x1a6b20ee, 0x21283dee, 0x0d162dee, 0x1f3f4004,   // sq.ceb.tl_422 ku.sd.fa_422  sk.hr.cs_422 lb.af.cy_332 
  0x1363580c, 0x3c00170d, 0x06657907, 0x5c002b0c,   // om.sco.et_543 sr.ug.un_540  war.gv.de_432 vi.sa.un_530 
  0x2765fc12, 0x11303ca9, 0x60006714, 0x2500290c,   // zzp.gv.gd_654 ug.uz.ro_544  ak.vo.un_660 sl.eu.un_530 
  // [22580]
  0xfc1d51a4, 0x2e4e4d0c, 0x184727a9, 0x27003b2b,   // kl.la.zzp_433 aa.ay.fo_543  gd.sn.ga_544 so.gd.un_980 
  0x32170fa9, 0x11000d07, 0x582751a4, 0x494751a9,   // lv.sr.bs_544 cs.ro.un_420  kl.gd.om_433 kl.sn.to_544 
  0x2a070107, 0x64596911, 0x283421ac, 0x4600310d,   // en.it.mt_432 mfe.rn.lg_653  fa.ps.sd_632 az.qu.un_540 
  0x79000921, 0x454712a4, 0x0c001312, 0x02006107,   // pl.war.un_860 hu.sn.ln_433  et.sv.un_640 za.da.un_420 
  // [22590]
  0x5d2b18ee, 0x3537480c, 0x33272004, 0x17350811,   // ga.vi.ss_422 tt.ba.tg_543  sq.gd.nn_332 uk.tg.sr_653 
  0xfe005f23, 0x360a07a9, 0x47007318, 0x48353012,   // tn.tlh.un_880 bg.mk.ab_544  ny.sn.un_740 uz.tg.tt_654 
  0x39004f09, 0x52477307, 0x12190507, 0x071508a9,   // bi.br.un_440 ny.sn.ha_432  fr.gl.hu_432 uk.bg.un_540 
  0x473573a7, 0x134c06a0, 0x474a73a4, 0x073735a0,   // ny.zu.sn_532 de.wo.et_322  ny.yo.sn_433 tg.ba.bg_322 
  // [225a0]
  0x5d47730e, 0x1723380c, 0x2f003912, 0x0a35070c,   // ny.sn.ss_555 tk.ky.sr_543  br.su.un_640 bg.tg.mk_543 
  0x0817040d, 0x1507170c, 0x240c4ea4, 0x461d24ee,   // ru.sr.uk_554 sr.bg.un_543  ay.sv.eo_433 eo.la.qu_422 
  0x2400460c, 0x241d4304, 0x10461d12, 0x394f4604,   // qu.eo.un_530 ie.la.eo_332  la.qu.lt_654 qu.bi.br_332 
  0x5458510c, 0x54515813, 0x3913040c, 0x5447780c,   // kl.om.ik_543 om.kl.ik_665  fi.et.br_543 ve.sn.ik_543 
  // [225b0]
  0x12633907, 0x64285805, 0x3b135807, 0x070a115a,   // br.sco.hu_432 om.sw.lg_333  om.et.so_432 ro.mk.bg_553 
  0x0458240b, 0x5d787308, 0x09471704, 0x033f4712,   // eo.om.fi_542 ny.ve.ss_443  sr.sn.pl_332 sn.af.nl_654 
  0x580f24ec, 0x7600692a, 0x6500640e, 0x563637af,   // eo.lv.om_644 mfe.crs.un_970  lg.gv.un_550 st.gn.mg_655 
  0x376a56a9, 0x20000e08, 0x102d3204, 0x2f4902ee,   // mg.haw.st_544 is.sq.un_430  bs.sk.lt_332 da.to.su_422 
  // [225c0]
  0x59644da4, 0x5d353402, 0x58005412, 0x1c365c07,   // aa.lg.rn_433 xh.zu.ss_222  ik.om.un_640 sa.gn.id_432 
  0x6400671b, 0x51005405, 0x4b1336ec, 0x036b1dad,   // ak.lg.un_770 ik.kl.un_330  gn.et.mi_644 la.ceb.nl_643 
  0x654f5ea0, 0x10002213, 0x4d475aa4, 0x0a072aa4,   // ts.bi.gv_322 oc.lt.un_650  sm.sn.aa_433 mt.it.pt_433 
  0x4a6745a4, 0x53005604, 0x212f6805, 0x1151580c,   // ln.ak.yo_433 mg.ht.un_320  ig.su.jw_333 om.kl.ro_543 
  // [225d0]
  0x64215305, 0x58004d09, 0x4c2f53a4, 0x11471ea4,   // ht.jw.lg_333 aa.om.un_440  ht.su.wo_433 ms.sn.ro_433 
  0x09736b08, 0x73005d13, 0x5e003708, 0x64024c08,   // ceb.ny.pl_443 ss.ny.un_650  st.ts.un_430 wo.da.lg_443 
  0x2f001f09, 0x53525707, 0x47735d60, 0x27000708,   // cy.su.un_440 na.ha.ht_432  ss.ny.sn_664 it.gd.un_430 
  0x53096707, 0x1f6473a0, 0x36005505, 0x73380912,   // ak.pl.ht_432 ny.lg.cy_322  rw.gn.un_330 pl.tk.ny_654 
  // [225e0]
  0x647352a7, 0x29305607, 0x35595505, 0x67033f05,   // ha.ny.lg_532 mg.uz.sl_432  rw.rn.zu_333 af.nl.ak_333 
  0x2f4b37a4, 0x124423ee, 0x36003713, 0x46260b07,   // st.mi.su_433 ky.kk.ur_422  st.gn.un_650 es.ia.qu_432 
  0x343d12ec, 0x39574c07, 0x534a2c04, 0x73215355,   // ur.ku.ps_644 wo.na.br_432  fy.yo.ht_332 ht.jw.ny_442 
  0x10005e04, 0x645d73a0, 0x79736ba4, 0x3304fc0b,   // ts.lt.un_320 ny.ss.lg_322  ceb.ny.war_433 zzp.fi.nn_542 
  // [225f0]
  0x3012210b, 0x0451050c, 0x074815ad, 0x020cfcee,   // fa.ur.uz_542 fr.kl.fi_543  un.tt.bg_643 zzp.sv.da_422 
  0x04fc58ad, 0x022efc05, 0x4807110b, 0x1d5d3407,   // om.zzp.fi_643 zzp.fo.da_333  ro.bg.tt_542 xh.ss.la_432 
  0x57211dad, 0xfc3e51ad, 0x1345fca6, 0x1030150d,   // la.jw.na_643 kl.rm.zzp_643  zzp.ln.et_521 un.uz.be_554 
  0x150710a9, 0x443c180d, 0x1c2f4f0b, 0x10170aa4,   // be.bg.un_544 ar.ug.kk_554  bi.su.id_542 mk.sr.be_433 
  // [22600]
  0x302a0204, 0x40002b02, 0x123d2113, 0x63004f18,   // da.mt.uz_332 vi.lb.un_220  fa.ku.ur_665 bi.sco.un_740 
  0x1e0457ad, 0x0e240204, 0x63001305, 0x404f620c,   // na.fi.ms_643 da.eo.is_332  et.sco.un_330 kha.bi.lb_543 
  0x300a1755, 0x42000529, 0x370407a0, 0x6300571a,   // sr.mk.uz_442 fr.co.un_960  bg.ru.ba_322 na.sco.un_760 
  0x472873a0, 0x4000251a, 0x31483007, 0x64005c07,   // ny.sw.sn_322 eu.lb.un_760  uz.tt.az_432 sa.lg.un_420 
  // [22610]
  0x36006807, 0x122530ee, 0x40054fa4, 0x73684709,   // ig.gn.un_420 uz.eu.hu_422  bi.fr.lb_433 sn.ig.ny_444 
  0x622f4fad, 0x0a070814, 0x15003820, 0x634f0107,   // bi.su.kha_643 uk.bg.mk_666  tk.un.un_850 en.bi.sco_432 
  0x4f626313, 0xfc475fa0, 0x4c3f3812, 0x48003f0c,   // sco.kha.bi_665 tn.sn.zzp_322  tk.af.wo_654 af.tt.un_530 
  0x46001f0b, 0x040817ad, 0x35070a55, 0x290d53a0,   // cy.qu.un_520 sr.uk.ru_643  mk.bg.tg_442 ht.cs.sl_322 
  // [22620]
  0xfc4e4c55, 0x211f2fad, 0x1e1c1fa4, 0x1c1efe55,   // wo.ay.zzp_442 su.cy.jw_643  cy.id.ms_433 tlh.ms.id_442 
  0x1b2f3eee, 0x30003818, 0x0a0710a9, 0x131a4cec,   // rm.su.tr_422 tk.uz.un_740  be.bg.mk_544 wo.tl.et_644 
  0x6e006412, 0x174415ad, 0x494c64af, 0x234415a9,   // lg.hmn.un_640 un.kk.sr_643  lg.wo.to_655 un.kk.ky_544 
  0x5c001d05, 0x0a15360e, 0x403f030d, 0x58002805,   // la.sa.un_330 ab.mk.un_550  nl.af.lb_554 sw.om.un_330 
  // [22630]
  0x04101560, 0x351030a9, 0x4b2854a7, 0x2a001b05,   // un.be.ru_664 uz.be.tg_544  ik.sw.mi_532 tr.mt.un_330 
  0x735c7808, 0x203b5c0c, 0x1179fe0b, 0x18400612,   // ve.sa.ny_443 sa.so.sq_543  tlh.war.ro_542 de.lb.ga_654 
  0x5d355c08, 0x47730112, 0xfc0618a0, 0x125e4712,   // sa.zu.ss_443 en.ny.sn_654  ga.de.zzp_322 sn.ts.hu_654 
  0x214e5c5a, 0x06290fa0, 0x03332e07, 0x5f02595a,   // sa.ay.jw_553 lv.sl.de_322  fo.nn.nl_432 rn.da.tn_553 
  // [22640]
  0x3600590e, 0x18044b04, 0x0afe23a7, 0x33004907,   // rn.gn.un_550 mi.fi.ga_332  ca.tlh.pt_532 to.nn.un_420 
  0x475c2a0c, 0x73fe3607, 0x1d2c0204, 0x5e5d7812,   // mt.sa.sn_543 gn.tlh.ny_432  da.fy.la_332 ve.ss.ts_654 
  0x541d2611, 0x2d0d2505, 0x03003912, 0x183647ee,   // ia.la.ik_653 eu.cs.sk_333  br.nl.un_640 sn.gn.ga_422 
  0x20522a04, 0x423e5809, 0xfe2642a9, 0x2c1d1f04,   // mt.ha.sq_332 om.rm.co_444  co.ia.tlh_544 cy.la.fy_332 
  // [22650]
  0x331e1c55, 0x5d372012, 0x07034204, 0x23281209,   // id.ms.nn_442 sq.st.ss_654  co.nl.it_332 ur.sd.ky_444 
  0x3024290b, 0x6b003b09, 0x065703a4, 0x3b00790c,   // sl.eo.uz_542 so.ceb.un_440  nl.na.de_433 war.so.un_530 
  0x06790908, 0x5f021d0e, 0x64583b55, 0x29796b07,   // pl.war.de_443 la.da.tn_555  so.om.lg_442 ceb.war.sl_432 
  0x5f133604, 0x090312ee, 0x40001213, 0x084950ad,   // gn.et.tn_332 hu.nl.pl_422  hu.lb.un_650 fj.to.no_643 
  // [22660]
  0x3d3021a7, 0x18041f07, 0x292f1207, 0x07421112,   // fa.uz.ku_532 cy.fi.ga_432  hu.su.sl_432 ro.co.it_654 
  0x284c3b60, 0x4207540d, 0x40001504, 0x3e564c0c,   // so.wo.sw_664 ik.it.co_554  un.lb.un_320 wo.mg.rm_543 
  0x224223a4, 0x102311ec, 0x644c3b07, 0x5a4b6aa7,   // ca.co.oc_433 ro.ky.be_644  so.wo.lg_432 haw.mi.sm_532 
  0x2d121ba0, 0x1c004202, 0x09066413, 0x150a23a4,   // tr.hu.sk_322 co.id.un_220  lg.de.pl_665 ky.mk.un_433 
  // [22670]
  0x48251008, 0x1d102011, 0x02181307, 0x46023607,   // be.mn.tt_443 sq.lt.la_653  et.ga.da_432 gn.da.qu_432 
  0x0c003702, 0x4a003f09, 0x3f4c5704, 0x37351707,   // st.sv.un_220 af.yo.un_440  na.wo.af_332 sr.tg.ba_432 
  0x18003d14, 0x5c4b6a0c, 0x4b6a5c0c, 0x3f223304,   // ku.ar.un_660 haw.mi.sa_543  sa.haw.mi_543 nn.oc.af_332 
  0x3f13fc04, 0x4837080d, 0x65001f1b, 0x033f02ad,   // zzp.et.af_332 uk.ba.tt_554  cy.gv.un_770 da.af.nl_643 
  // [22680]
  0x732855ad, 0x03054207, 0x02525508, 0x4c000204,   // rw.sw.ny_643 co.fr.nl_432  rw.ha.da_443 da.wo.un_320 
  0x3217470e, 0x40001f07, 0x1512510b, 0x104d0413,   // sn.sr.bs_555 cy.lb.un_420  kl.hu.un_542 fi.aa.lt_665 
  0x4004480c, 0x28100260, 0x03025707, 0x2404100c,   // tt.fi.lb_543 da.lt.sw_664  na.da.nl_432 lt.fi.eo_543 
  0x091251ad, 0x2500561a, 0x04480cad, 0x4b5c495a,   // kl.hu.pl_643 mg.eu.un_760  sv.tt.fi_643 to.sa.mi_553 
  // [22690]
  0x17485108, 0x2e080c04, 0x09193e05, 0x22074255,   // kl.tt.sr_443 sv.no.fo_332  rm.gl.pl_333 co.it.oc_442 
  0x492f1c02, 0x110a07a9, 0x4afe56a4, 0x6a124b0c,   // id.su.to_222 it.pt.ro_544  mg.tlh.yo_433 mi.hu.haw_543 
  0xfe30520c, 0xfe00180d, 0x5a004005, 0x11005609,   // ha.uz.tlh_543 ga.tlh.un_540  lb.sm.un_330 mg.ro.un_440 
  0x51646a04, 0x4b365c0d, 0x041e1c0d, 0x132a4908,   // haw.lg.kl_332 sa.gn.mi_554  id.ms.fi_554 to.mt.et_443 
  // [226a0]
  0x0800351a, 0x25006a21, 0x1b5c5608, 0x46001022,   // tg.uk.un_760 haw.eu.un_860  mg.sa.tr_443 lt.qu.un_870 
  0x20063f0b, 0x320742a0, 0x35475d08, 0x03093f04,   // af.de.sq_542 co.it.bs_322  ss.sn.zu_443 af.pl.nl_332 
  0x25394f12, 0x55494b0c, 0xfc51120c, 0x36003914,   // bi.br.eu_654 mi.to.rw_543  hu.kl.zzp_543 br.gn.un_660 
  0x5107fc09, 0x4a00561a, 0x1004530c, 0x10004e19,   // zzp.it.kl_444 mg.yo.un_760  ht.fi.lt_543 ay.lt.un_750 
  // [226b0]
  0x11173ca4, 0x3e480c07, 0x2a595505, 0x5500fe1a,   // ug.sr.ro_433 sv.tt.rm_432  rw.rn.mt_333 tlh.rw.un_760 
  0x61000604, 0x322924ee, 0x40133811, 0x1d43530d,   // de.za.un_320 eo.sl.bs_422  tk.et.lb_653 ht.ie.la_554 
  0x595530ec, 0x5c39fea9, 0xfefc1dee, 0x5a4c4ba0,   // uz.rw.rn_644 tlh.br.sa_544  la.zzp.tlh_422 mi.wo.sm_322 
  0x64305bee, 0x2f005e08, 0x123752a0, 0x380312a7,   // sg.uz.lg_422 ts.su.un_430  ha.st.hu_322 hu.nl.tk_532 
  // [226c0]
  0x3f5f3704, 0x5e526b05, 0x34375fa4, 0x164b6a07,   // st.tn.af_332 ceb.ha.ts_333  tn.st.xh_433 haw.mi.hr_432 
  0x48400c12, 0x5f3f13a0, 0x0c48400b, 0x0415170e,   // sv.lb.tt_654 et.af.tn_322  lb.tt.sv_542 sr.ru.un_550 
  0x1340385a, 0x3f375faf, 0x4b403807, 0x40134807,   // tk.lb.et_553 tn.st.af_655  tk.lb.mi_432 tt.et.lb_432 
  0x40480c65, 0x13004019, 0x40004807, 0x553713a0,   // sv.tt.lb_763 lb.et.un_750  tt.lb.un_420 et.st.rw_322 
  // [226d0]
  0x044060a0, 0x483e06ee, 0x130c04a7, 0x02002802,   // vo.lb.fi_322 de.rm.tt_422  fi.sv.et_532 sw.da.un_220 
  0x025a18a4, 0x2d00481d, 0x4006485a, 0x270302a0,   // ga.sm.da_433 tt.sk.un_820  tt.de.lb_553 da.nl.gd_322 
  0x0c006011, 0x07004409, 0x2701220c, 0x42023407,   // vo.sv.un_630 kk.bg.un_440  oc.en.gd_543 xh.da.co_432 
  0x5f5e37a4, 0x2f001c12, 0x23151708, 0x28007823,   // st.ts.tn_433 id.su.un_640  sr.ky.un_430 ve.sw.un_880 
  // [226e0]
  0x2e040107, 0x10130405, 0x503efeee, 0x1d39010b,   // en.fi.fo_432 fi.et.lt_333  tlh.rm.fj_422 en.br.la_542 
  0x223308ee, 0x29000d22, 0x46480ca4, 0x0a4301a0,   // no.nn.oc_422 cs.sl.un_870  sv.tt.qu_433 en.ie.pt_322 
  0x3130390b, 0x652e020c, 0x655c1dee, 0x1e151207,   // br.uz.az_542 da.fo.gv_543  la.sa.gv_422 hu.ms.un_420 
  0x30353612, 0x4a004504, 0x682f5508, 0x585633a0,   // ab.tg.uz_654 ln.yo.un_320  rw.su.ig_443 nn.mg.om_322 
  // [226f0]
  0x02fc4a55, 0x0a113505, 0x64005523, 0x26006019,   // yo.zzp.da_442 tg.ro.mk_333  rw.lg.un_880 vo.ia.un_750 
  0x1a1d53ee, 0x121b605a, 0x1d5c26ec, 0x130c3955,   // ht.la.tl_422 vo.tr.hu_553  ia.sa.la_644 br.sv.et_442 
  0x76695e0e, 0x33001104, 0x555c5911, 0x0302185a,   // ts.mfe.crs_555 ro.nn.un_320  rn.sa.rw_653 ga.da.nl_553 
  0x30121b02, 0x02172a04, 0x1b00580d, 0x1b000405,   // tr.hu.uz_222 mt.sr.da_332  om.tr.un_540 fi.tr.un_330 
  // [22700]
  0x15002b02, 0x15002204, 0x69763408, 0x112330ad,   // vi.un.un_220 oc.un.un_320  xh.crs.mfe_443 uz.ky.ro_643 
  0x5c004b20, 0x4311460c, 0x04130c08, 0x117669ad,   // mi.sa.un_850 qu.ro.ie_543  sv.et.fi_443 mfe.crs.ro_643 
  0x0b0a3605, 0x0c001313, 0x0a1730af, 0x1e004c04,   // gn.pt.es_333 et.sv.un_650  uz.sr.mk_655 wo.ms.un_320 
  0x13480c0d, 0x481304a7, 0x2f204c05, 0x20006309,   // sv.tt.et_554 fi.et.tt_532  wo.sq.su_333 sco.sq.un_440 
  // [22710]
  0x2e0d0e07, 0x130c60a9, 0x49634f55, 0x0c001322,   // is.cs.fo_432 vo.sv.et_544  bi.sco.to_442 et.sv.un_870 
  0x173515a4, 0x1d0e390c, 0x6548200c, 0x48040c04,   // un.tg.sr_433 br.is.la_543  sq.tt.gv_543 sv.fi.tt_332 
  0x04130ca9, 0x080a0760, 0x0dfc2da7, 0x4afc20ad,   // sv.et.fi_544 bg.mk.uk_664  sk.zzp.cs_532 sq.zzp.yo_643 
  0x230a35ee, 0x4b36fca9, 0x5e381fa0, 0x38000c11,   // tg.mk.ky_422 zzp.gn.mi_544  cy.tk.ts_322 sv.tk.un_630 
  // [22720]
  0x02734608, 0x406b1a08, 0x64001319, 0x4d133760,   // qu.ny.da_443 tl.ceb.lb_443  et.lg.un_750 st.et.aa_664 
  0x5700060c, 0x7300680c, 0x4800131f, 0x0165630c,   // de.na.un_530 ig.ny.un_530  et.tt.un_840 sco.gv.en_543 
  0x5f550204, 0x64134512, 0x40130417, 0x3c2821ad,   // da.rw.tn_332 ln.et.lg_654  fi.et.lb_753 fa.sd.ug_643 
  0x7318460d, 0x23052208, 0x13001123, 0x423f050d,   // qu.ga.ny_554 oc.fr.ca_443  ro.et.un_880 fr.af.co_554 
  // [22730]
  0x2e302ca6, 0x162053a4, 0x5d346402, 0x091827a4,   // fy.uz.fo_521 ht.sq.hr_433  lg.xh.ss_222 gd.ga.pl_433 
  0x110a44b3, 0x35342102, 0x4e4630af, 0x552113ee,   // kk.mk.ro_743 jw.xh.zu_222  uz.qu.ay_655 et.jw.rw_422 
  0x353413ec, 0x46734ea4, 0x1f1802a0, 0x18442507,   // et.xh.zu_644 ay.ny.qu_433  da.ga.cy_322 mn.kk.ar_432 
  0x0cfc1860, 0x40180612, 0x061923a0, 0x040648a0,   // ga.zzp.sv_664 de.ga.lb_654  ca.gl.de_322 tt.de.fi_322 
  // [22740]
  0x20003013, 0x4800131b, 0x49132a07, 0x1b160fa4,   // uz.sq.un_650 et.tt.un_770  mt.et.to_432 lv.hr.tr_433 
  0x06184002, 0x1f5231ee, 0x2c005c1b, 0x203b3007,   // lb.ga.de_222 az.ha.cy_422  sa.fy.un_770 uz.so.sq_432 
  0x38002c0c, 0x3e006119, 0x34311ea0, 0x4b4006a6,   // fy.tk.un_530 za.rm.un_750  ms.az.xh_322 de.lb.mi_521 
  0x4e46feaf, 0x061304ec, 0x24101302, 0x0f103ea7,   // tlh.qu.ay_655 fi.et.de_644  et.lt.eo_222 rm.lt.lv_532 
  // [22750]
  0x0600fc0e, 0x13380c09, 0x48123002, 0x28001d04,   // zzp.de.un_550 sv.tk.et_444  uz.hu.tt_222 la.sw.un_320 
  0x22001302, 0x02130407, 0x40000c13, 0x233e63a4,   // et.oc.un_220 fi.et.da_432  sv.lb.un_650 sco.rm.ca_433 
  0x400c130c, 0x2c401508, 0x3e004307, 0x1004170b,   // et.sv.lb_543 un.lb.fy_443  ie.rm.un_420 sr.ru.be_542 
  0x38000c16, 0x060701ee, 0x0c00131a, 0x100502ee,   // sv.tk.un_720 en.it.de_422  et.sv.un_760 da.fr.lt_422 
  // [22760]
  0x0f002308, 0x4813045a, 0x441038a0, 0x13190b04,   // ca.lv.un_430 fi.et.tt_553  tk.be.kk_322 es.gl.et_332 
  0x12213d14, 0x05650104, 0x1d5a65a0, 0x1d005713,   // ku.fa.ur_666 en.gv.fr_332  gv.sm.la_322 na.la.un_650 
  0x04fe12af, 0x03480408, 0x3e19fe12, 0x25003412,   // hu.tlh.fi_655 fi.tt.nl_443  tlh.gl.rm_654 xh.eu.un_640 
  0x2300530c, 0x481b12a4, 0xfc3e0a0c, 0x491d5f04,   // ht.ca.un_530 hu.tr.tt_433  pt.rm.zzp_543 tn.la.to_332 
  // [22770]
  0x4812040c, 0x36005919, 0x487612a4, 0x03382307,   // fi.hu.tt_543 rn.gn.un_750  hu.crs.tt_433 ca.tk.nl_432 
  0x35001914, 0x364a5955, 0x0b003802, 0x6bfe3505,   // gl.zu.un_660 rn.yo.gn_442  tk.es.un_220 zu.tlh.ceb_333 
  0x3b301b04, 0x31101b07, 0x0a2d5907, 0x310e2ea4,   // tr.uz.so_332 tr.lt.az_432  rn.sk.pt_432 fo.is.az_433 
  0x15000e07, 0x160b10ad, 0x48190b55, 0x033e0608,   // is.un.un_420 lt.es.hr_643  es.gl.tt_442 de.rm.nl_443 
  // [22780]
  0x420306a9, 0x03460607, 0x0c030655, 0x10423105,   // de.nl.co_544 de.qu.nl_432  de.nl.sv_442 az.co.lt_333 
  0x3e030608, 0x0e2e3b08, 0x252e1f0b, 0x0c0415ee,   // de.nl.rm_443 so.fo.is_443  cy.fo.eu_542 un.fi.sv_422 
  0x311b0e0c, 0x19220aad, 0x094310ee, 0x33302104,   // is.tr.az_543 pt.oc.gl_643  lt.ie.pl_422 jw.uz.nn_332 
  0x1f0afc02, 0x391a0aa4, 0x311bfc07, 0x61002913,   // zzp.pt.cy_222 pt.tl.br_433  zzp.tr.az_432 sl.za.un_650 
  // [22790]
  0x09004513, 0x22003913, 0x22000a1b, 0x03000622,   // ln.pl.un_650 br.oc.un_650  pt.oc.un_770 de.nl.un_870 
  0x04003c0c, 0x037906a4, 0x07421d0c, 0x44100805,   // ug.ru.un_530 de.war.nl_433  la.co.it_543 uk.be.kk_333 
  0x273b4202, 0x65466207, 0x39220a0d, 0x330804a9,   // co.so.gd_222 kha.qu.gv_432  pt.oc.br_554 fi.no.nn_544 
  0x3f004204, 0x1d1f10a0, 0x24000e08, 0x390660a7,   // co.af.un_320 lt.cy.la_322  is.eo.un_430 vo.de.br_532 
  // [227a0]
  0x63091f12, 0x153644ad, 0x091f100b, 0x4830fca0,   // cy.pl.sco_654 kk.ab.un_643  lt.cy.pl_542 zzp.uz.tt_322 
  0x221ffc55, 0x38004b04, 0x09006714, 0xfc06510c,   // zzp.cy.oc_442 mi.tk.un_320  ak.pl.un_660 kl.de.zzp_543 
  0x243efc55, 0x0e480c02, 0x18443d02, 0x245f75ad,   // zzp.rm.eo_442 sv.tt.is_222  ku.kk.ar_222 nso.tn.eo_643 
  0x15233807, 0x5e645805, 0x03002e02, 0x5f002c08,   // tk.ky.un_432 om.lg.ts_333  fo.nl.un_220 fy.tn.un_430 
  // [227b0]
  0x400c03a6, 0x235b4605, 0x12231b08, 0x1f00110e,   // nl.sv.lb_521 qu.sg.ca_333  tr.ca.hu_443 ro.cy.un_550 
  0x300a07af, 0x2700431b, 0x27003504, 0x1517380c,   // bg.mk.uz_655 ie.gd.un_770  zu.gd.un_320 tk.sr.un_543 
  0x090d2d07, 0x65032c55, 0x631101a4, 0x0d2d2707,   // sk.cs.pl_432 fy.nl.gv_442  en.ro.sco_433 gd.sk.cs_432 
  0x373c4813, 0x2300430c, 0x07042309, 0x13004c05,   // tt.ug.ba_665 ie.ca.un_530  ky.ru.bg_444 wo.et.un_330 
  // [227c0]
  0x08153511, 0x26051d05, 0x1115150e, 0x44152314,   // tg.uk.un_630 la.fr.ia_333  un.ro.un_550 ky.kk.un_660 
  0x735d35af, 0x071d13ee, 0x0d38090c, 0x1d202ea0,   // zu.ss.ny_655 et.la.it_422  pl.tk.cs_543 fo.sq.la_322 
  0x62004e13, 0x303723ad, 0x1d00760e, 0x05330809,   // ay.kha.un_650 ky.ba.uz_643  crs.la.un_550 no.nn.fr_444 
  0x35005c0b, 0x054540a4, 0x3d003b1b, 0x30083c0c,   // sa.zu.un_520 lb.ln.fr_433  ks.ku.un_770 ug.uk.uz_543 
  // [227d0]
  0x340206ad, 0x3c232560, 0x0f003104, 0x30084804,   // de.da.xh_643 mn.ky.ug_664  az.lv.un_320 tt.uk.uz_332 
  0x29107507, 0x0835175a, 0x253638a9, 0x483830ad,   // nso.lt.sl_432 sr.tg.uk_553  tk.ab.mn_544 uz.tk.tt_643 
  0x0600030c, 0x533e2208, 0x22005320, 0x07483708,   // nl.de.un_530 oc.rm.ht_443  ht.oc.un_850 ba.tt.bg_443 
  0x21005322, 0x2330340d, 0x0a481705, 0x29101602,   // ht.jw.un_870 ps.uz.ky_554  sr.tt.mk_333 hr.lt.sl_222 
  // [227e0]
  0x35253ca0, 0x02fc2a08, 0x350415a9, 0x29286855,   // ug.mn.tg_322 mt.zzp.da_443  un.ru.tg_544 ig.sw.sl_442 
  0x1200440c, 0x2a002805, 0x212b5304, 0x432601af,   // kk.ur.un_530 sw.mt.un_330  ht.vi.jw_332 en.ia.ie_655 
  0x644c0207, 0x34002a0d, 0x1300250b, 0x532a6855,   // da.wo.lg_432 mt.xh.un_540  eu.et.un_520 ig.mt.ht_442 
  0x40061daf, 0x1b000412, 0x071d4da4, 0x371d5faf,   // la.de.lb_655 fi.tr.un_640  aa.la.it_433 tn.la.st_655 
  // [227f0]
  0x11381b5a, 0x47004c02, 0x0f291704, 0x0700130c,   // tr.tk.ro_553 wo.sn.un_220  sr.sl.lv_332 et.it.un_530 
  0x5c3e1d07, 0x34003d2c, 0x400639a7, 0x4251fca9,   // la.rm.sa_432 ku.ps.un_990  br.de.lb_532 zzp.kl.co_544 
  0x380901a0, 0x171029a0, 0x2f4a5302, 0x3217280c,   // en.pl.tk_322 sl.lt.sr_322  ht.yo.su_222 sw.sr.bs_543 
  0x4c585307, 0x010679a0, 0x231548af, 0x79400607,   // ht.om.wo_432 war.de.en_322  tt.ky.un_650 de.lb.war_432 
  
  // [22800]
  0x21284404, 0x1d3903a0, 0x3e006314, 0x053e2011,   // kk.sd.fa_332 nl.br.la_322  sco.rm.un_660 sq.rm.fr_653 
  0x1b041307, 0x03330808, 0x033f0e07, 0xfa003722,   // et.fi.tr_432 no.nn.nl_443  is.af.nl_432 st.nr.un_870 
  0x39290f07, 0x653f1bee, 0x3f2226ec, 0x6500190c,   // lv.sl.br_432 tr.af.gv_422  ia.oc.af_644 gl.gv.un_530 
  0x193130ad, 0x25233511, 0x2e0e2ca6, 0x0e406211,   // uz.az.gl_643 tg.ky.mn_653  fy.is.fo_521 kha.lb.is_653 
  // [22810]
  0xfc111dee, 0x06403e05, 0x19242b07, 0x4c3b400c,   // la.ro.zzp_422 rm.lb.de_333  vi.eo.gl_432 lb.so.wo_543 
  0x513e1107, 0x3e000e11, 0x05001821, 0x0c3e3855,   // ro.rm.kl_432 is.rm.un_630  ga.fr.un_860 tk.rm.sv_442 
  0x18005321, 0x3e1f57af, 0x402c06ec, 0x0973640c,   // ht.ga.un_860 na.cy.rm_655  de.fy.lb_644 lg.ny.pl_543 
  0x36002404, 0x1d0162a4, 0x302128a7, 0x644773a9,   // eo.gn.un_320 kha.en.la_433  sd.fa.uz_532 ny.sn.lg_544 
  // [22820]
  0x3f09790c, 0x3f035807, 0x21554cee, 0x644a680b,   // war.pl.af_543 om.nl.af_432  wo.rw.jw_422 ig.yo.lg_542 
  0x0b001108, 0x58004c07, 0x213b5ba7, 0x17150412,   // ro.es.un_430 wo.om.un_420  sg.so.jw_532 ru.sr.un_640 
  0x687347af, 0x644c470c, 0x736447a9, 0x477364a9,   // sn.ny.ig_655 sn.wo.lg_543  sn.lg.ny_544 lg.ny.sn_544 
  0x39044fa4, 0x10045a02, 0x39003e1a, 0x5700391a,   // bi.fi.br_433 sm.fi.lt_222  rm.br.un_760 br.na.un_760 
  // [22830]
  0x1d2e250b, 0x18634fa4, 0x47692905, 0x1d184f11,   // eu.fo.la_542 bi.sco.ga_433  sl.mfe.sn_333 bi.ga.la_653 
  0x73125504, 0x28005604, 0x12734508, 0x2b2019a0,   // rw.hu.ny_332 mg.sw.un_320  ln.ny.hu_443 gl.sq.vi_322 
  0x2000560d, 0x6100380e, 0x343759a7, 0x11005608,   // mg.sq.un_540 tk.za.un_550  rn.st.xh_532 mg.ro.un_430 
  0x19005e0b, 0x231530a9, 0x47352804, 0x284564a0,   // ts.gl.un_520 uz.ky.un_540  sw.zu.sn_332 lg.ln.sw_322 
  // [22840]
  0x16305604, 0x03064004, 0x5500250c, 0x11292407,   // mg.uz.hr_332 lb.de.nl_332  eu.rw.un_530 eo.sl.ro_432 
  0x1100091b, 0x47355b5a, 0x083638a4, 0x30004519,   // pl.ro.un_770 sg.zu.sn_553  tk.ab.uk_433 ln.uz.un_750 
  0x1cfc1da0, 0x0f00490d, 0x10fc0fa0, 0x2f006721,   // la.zzp.id_322 to.lv.un_540  lv.zzp.lt_322 ak.su.un_860 
  0x37480405, 0x28042c04, 0x06005009, 0x2f4b49a0,   // ru.tt.ba_333 fy.fi.sw_332  fj.de.un_440 to.mi.su_322 
  // [22850]
  0x5a00041b, 0x33000608, 0x36040a12, 0x571f500c,   // fi.sm.un_770 de.nn.un_430  pt.fi.gn_654 fj.cy.na_543 
  0x0357630e, 0x16674211, 0x600a1f0d, 0x2e1f06a9,   // sco.na.nl_555 co.ak.hr_653  cy.pt.vo_554 de.cy.fo_544 
  0xfa005808, 0x2d0b190c, 0x03583b0c, 0x3b405807,   // om.nr.un_430 gl.es.sk_543  so.om.nl_543 om.lb.so_432 
  0x13005504, 0x584d49af, 0x4f2873a4, 0x1f00061a,   // rw.et.un_320 to.aa.om_655  ny.sw.bi_433 de.cy.un_760 
  // [22860]
  0x5d35fa0c, 0x043f0308, 0x6002065a, 0x1f005708,   // nr.zu.ss_543 nl.af.fi_443  de.da.vo_553 na.cy.un_430 
  0x044925a4, 0x45005d09, 0x5500fe04, 0x1f733407,   // eu.to.fi_433 ss.ln.un_440  tlh.rw.un_320 xh.ny.cy_432 
  0x6b341fee, 0x12132eee, 0x5e00780c, 0x45007313,   // cy.xh.ceb_422 fo.et.hu_422  ve.ts.un_530 ny.ln.un_650 
  0x49126aee, 0x283430a0, 0x28585112, 0x3b675808,   // haw.hu.to_422 uz.ps.sd_322  kl.om.sw_654 om.ak.so_443 
  // [22870]
  0x4b001309, 0x3b5158a4, 0x04002f0e, 0x04391f07,   // et.mi.un_440 om.kl.so_433  su.fi.un_550 cy.br.fi_432 
  0x06345ea0, 0x403f03a7, 0x28004a04, 0x0f2a09ee,   // ts.xh.de_322 nl.af.lb_532  yo.sw.un_320 pl.mt.lv_422 
  0x2f007304, 0x5c0d3b0c, 0x23190ea0, 0x203226a4,   // ny.su.un_320 ks.ne.sa_543  is.gl.ca_322 ia.bs.sq_433 
  0x364a350c, 0x083c15a4, 0x48443513, 0x29172004,   // zu.yo.gn_543 un.ug.uk_433  tg.kk.tt_665 sq.sr.sl_332 
  // [22880]
  0x013b7907, 0x39006e08, 0x242a20a0, 0x3500730e,   // war.so.en_432 hmn.br.un_430  sq.mt.eo_322 ny.zu.un_550 
  0x4a35345a, 0x022a2413, 0x392d20ee, 0x44233019,   // xh.zu.yo_553 eo.mt.da_665  sq.sk.br_422 uz.ky.kk_765 
  0x0e5d2e07, 0x1711120c, 0x0d29090c, 0x092902a0,   // fo.ss.is_432 hu.ro.sr_543  pl.sl.cs_543 da.sl.pl_322 
  0x0a30170b, 0x10000a0b, 0x64002c04, 0x28003304,   // sr.uz.mk_542 mk.be.un_520  fy.lg.un_320 nn.sw.un_320 
  // [22890]
  0x10044802, 0x5d0e4aee, 0x07171005, 0x3c232112,   // tt.ru.be_222 yo.is.ss_422  be.sr.bg_333 fa.ky.ug_654 
  0x02002b04, 0x1f00390c, 0x1d1f13a0, 0x53232807,   // vi.da.un_320 br.cy.un_530  et.cy.la_322 sw.ca.ht_432 
  0x122318a4, 0xfc0336a0, 0x1928730c, 0x0c2a1d04,   // ar.ky.ur_433 gn.nl.zzp_322  ny.sw.gl_543 la.mt.sv_332 
  0x381f6513, 0x1f6501a9, 0x4820300c, 0x1f386512,   // gv.cy.tk_665 en.gv.cy_544  uz.sq.tt_543 gv.tk.cy_654 
  // [228a0]
  0x623f3809, 0x3f061da0, 0x38046512, 0x65001f23,   // tk.af.kha_444 la.de.af_322  gv.fi.tk_654 cy.gv.un_880 
  0x363c300b, 0x01030cee, 0x65381fec, 0xfc732808,   // uz.ug.ab_542 sv.nl.en_422  cy.tk.gv_644 sw.ny.zzp_443 
  0x790938af, 0x472afcec, 0x0c6504ad, 0x100a0855,   // tk.pl.war_655 zzp.mt.sn_644  fi.gv.sv_643 uk.mk.be_442 
  0x2c3f1f0c, 0x3800652b, 0x110139a0, 0x44251012,   // cy.af.fy_543 gv.tk.un_980  br.en.ro_322 be.mn.kk_654 
  // [228b0]
  0x2d2129a0, 0x2308170c, 0x38653311, 0x62691f07,   // sl.jw.sk_322 sr.uk.ky_543  nn.gv.tk_653 cy.mfe.kha_432 
  0x0a042511, 0x1f271860, 0x2d401d07, 0x100448a4,   // mn.ru.mk_653 ga.gd.cy_664  la.lb.sk_432 tt.ru.be_433 
  0x36071eee, 0x24005a02, 0x514d01a0, 0x48002d07,   // ms.it.gn_422 sm.eo.un_220  en.aa.kl_322 sk.tt.un_420 
  0x09221207, 0x125e5607, 0x42003405, 0x27005808,   // hu.oc.pl_432 mg.ts.hu_432  xh.co.un_330 om.gd.un_430 
  // [228c0]
  0x5e212a5a, 0x4a48250c, 0x1d006107, 0x0f242caf,   // mt.jw.ts_553 eu.tt.yo_543  za.la.un_420 fy.eo.lv_655 
  0x343e4755, 0x3f001f21, 0x52215ca4, 0x2500280d,   // sn.rm.xh_442 cy.af.un_860  sa.jw.ha_433 sw.eu.un_540 
  0x5100201b, 0x1f1d3912, 0x4f6308a0, 0x3b1858ec,   // sq.kl.un_770 br.la.cy_654  no.sco.bi_322 om.ga.so_644 
  0x0a5305ee, 0x390e2e08, 0x2a760e0c, 0x242008a0,   // fr.ht.pt_422 fo.is.br_443  is.crs.mt_543 no.sq.eo_322 
  // [228d0]
  0x0e2e2c05, 0x317361ec, 0x56003b07, 0x33073fa0,   // fy.fo.is_333 za.ny.az_644  so.mg.un_420 af.it.nn_322 
  0x1d631fa7, 0x1318470c, 0x3b582007, 0x104f1d07,   // cy.sco.la_532 sn.ga.et_543  sq.om.so_432 la.bi.lt_432 
  0x03330809, 0x12000e11, 0x312855ee, 0x283021af,   // no.nn.nl_444 is.hu.un_630  rw.sw.az_422 fa.uz.sd_655 
  0x2b246512, 0x1538100c, 0x12303d60, 0x3f06390c,   // gv.eo.vi_654 be.tk.un_543  ku.uz.ur_664 br.de.af_543 
  // [228e0]
  0x2e1b39ad, 0x05693908, 0x47003208, 0x0f735d04,   // br.tr.fo_643 br.mfe.fr_443  bs.sn.un_430 ss.ny.lv_332 
  0x65392405, 0x48241ca0, 0x091273ee, 0x0e763905,   // eo.br.gv_333 id.eo.tt_322  ny.hu.pl_422 br.crs.is_333 
  0x150710a4, 0x123209a0, 0x25582004, 0x10007313,   // be.bg.un_433 pl.bs.hu_322  sq.om.eu_332 ny.lt.un_650 
  0x481239a4, 0xfc533e05, 0x11154e04, 0x261d3e09,   // br.hu.tt_433 rm.ht.zzp_333  ay.ro.un_320 rm.la.ia_444 
  // [228f0]
  0x120143ee, 0x12041313, 0x73090d0b, 0xfc395307,   // ie.en.hu_422 et.fi.hu_665  cs.pl.ny_542 ht.br.zzp_432 
  0x2f002a13, 0x0900731a, 0x73004705, 0x766912a4,   // mt.su.un_650 ny.pl.un_760  sn.ny.un_330 hu.mfe.crs_433 
  0x3e43fc0b, 0x5e00190e, 0x213d28ad, 0x3038120c,   // zzp.ie.rm_542 gl.ts.un_550  sd.ku.fa_643 hu.tk.uz_543 
  0x43041308, 0x29241daf, 0x04486ba4, 0x11036005,   // et.fi.ie_443 la.eo.sl_655  ceb.tt.fi_433 vo.nl.ro_333 
  // [22900]
  0x114c1ba4, 0x15102502, 0x18212855, 0x5a780405,   // tr.wo.ro_433 eu.lt.un_222  sd.fa.ar_442 fi.ve.sm_333 
  0x2158470c, 0x113f1307, 0x554e470c, 0x023f1213,   // sn.om.jw_543 et.af.ro_432  sn.ay.rw_543 hu.af.da_665 
  0x1e362f14, 0x4d432da4, 0x21004d0d, 0x472f250c,   // su.gn.ms_666 sk.ie.aa_433  aa.jw.un_540 eu.su.sn_543 
  0x1d5055ec, 0x60033f12, 0x12002520, 0x480409a4,   // rw.fj.la_644 af.nl.vo_654  eu.hu.un_850 pl.fi.tt_433 
  // [22910]
  0x0565510d, 0x0604080c, 0x48007908, 0x5e735608,   // kl.gv.fr_554 no.fi.de_543  war.tt.un_430 mg.ny.ts_443 
  0x5a033faf, 0x36651505, 0x24311b07, 0x54311b08,   // af.nl.sm_655 un.gv.gn_333  tr.az.eo_432 tr.az.ik_443 
  0x30135ca9, 0x03040da4, 0x4854380c, 0x12113f08,   // sa.et.uz_544 cs.fi.nl_433  tk.ik.tt_543 af.ro.hu_443 
  0x1b552855, 0x2f6768af, 0x1d00210d, 0x0e1310a0,   // sw.rw.tr_442 ig.ak.su_655  jw.la.un_540 lt.et.is_322 
  // [22920]
  0x3f6512ee, 0x5c2536a9, 0x17241107, 0x02002d0c,   // hu.gv.af_422 gn.eu.sa_544  ro.eo.sr_432 sk.da.un_530 
  0x270e2e0b, 0x59645307, 0x48303811, 0x634d6555,   // fo.is.gd_542 ht.lg.rn_432  tk.uz.tt_653 gv.aa.sco_442 
  0x313830ad, 0x5430380c, 0x13006b02, 0x30673808,   // uz.tk.az_643 tk.uz.ik_543  ceb.et.un_220 tk.ak.uz_443 
  0x3c281204, 0x48303807, 0x381504ec, 0x1f3937ee,   // ur.sd.ug_332 tk.uz.tt_432  ru.tk.un_640 st.br.cy_422 
  // [22930]
  0x631d050c, 0x4c1c55a0, 0x6451540c, 0x2c00470e,   // fr.la.sco_543 rw.id.wo_322  ik.kl.lg_543 sn.fy.un_550 
  0x1f755f5a, 0x40004d2b, 0x301a6b07, 0x1d004f04,   // tn.nso.cy_553 aa.lb.un_980  ceb.tl.uz_432 bi.la.un_320 
  0x583b4007, 0x4b6a375a, 0x220238ad, 0x434d42a7,   // lb.so.om_432 st.haw.mi_553  tk.da.oc_643 co.aa.ie_532 
  0x5f021f07, 0x5c4b37ac, 0x4f006118, 0x58364d0c,   // cy.da.tn_432 st.mi.sa_632  za.bi.un_740 aa.gn.om_543 
  // [22940]
  0x1f22fea0, 0x364b3755, 0x403b4d0c, 0x021f4208,   // tlh.oc.cy_322 st.mi.gn_442  aa.so.lb_543 co.cy.da_443 
  0x64343511, 0x47005e05, 0x73695ea4, 0x67004508,   // zu.xh.lg_653 ts.sn.un_330  ts.mfe.ny_433 ln.ak.un_430 
  0x3833080c, 0x58000704, 0x5f1f69a4, 0x27000304,   // no.nn.tk_543 it.om.un_320  mfe.cy.tn_433 nl.gd.un_320 
  0x26001d2a, 0x683b400c, 0x404c47a4, 0x05000a23,   // la.ia.un_970 lb.so.ig_543  sn.wo.lb_433 pt.fr.un_880 
  // [22950]
  0x791f3eec, 0x2c5828ee, 0x4d001520, 0x4f00611a,   // rm.cy.war_644 sw.om.fy_422  un.aa.un_850 za.bi.un_760 
  0x5b3736af, 0x101d2f04, 0x04153805, 0x4f006108,   // gn.st.sg_655 su.la.lt_332  tk.ru.un_330 za.bi.un_430 
  0x29174b08, 0x08043005, 0x482b22ad, 0x15441508,   // mi.sr.sl_443 uz.ru.uk_333  oc.vi.tt_643 un.kk.un_443 
  0x322012ad, 0x101517a0, 0x0e021fee, 0x55125912,   // hu.sq.bs_643 sr.be.un_320  cy.da.is_422 rn.hu.rw_654 
  // [22960]
  0x52591baf, 0x450f52a7, 0x123456ee, 0x1e3145a7,   // tr.rn.ha_655 ha.lv.ln_532  mg.xh.hu_422 ln.az.ms_532 
  0x283034a4, 0x795673a9, 0x282452a4, 0x313448a4,   // ps.uz.sd_433 ny.mg.war_544  ha.eo.sw_433 tt.xh.az_433 
  0x64383407, 0x3b483108, 0x59003419, 0x48360ba0,   // xh.tk.lg_432 az.tt.so_443  xh.rn.un_750 es.gn.tt_322 
  0x12234405, 0x0d135c0b, 0x25303508, 0x3900400c,   // kk.ky.ur_333 sa.bh.ne_542  tg.uz.mn_443 lb.br.un_530 
  // [22970]
  0x045a4907, 0x51006a07, 0x0b2240ad, 0x02285fa4,   // to.sm.fi_432 haw.kl.un_420  lb.oc.es_643 tn.sw.da_433 
  0x271f65a7, 0x6b4301ee, 0x236301a4, 0x46455fa0,   // gv.cy.gd_532 en.ie.ceb_422  en.sco.ca_433 tn.ln.qu_322 
  0x36220ba4, 0x34181209, 0x30122805, 0x200c3ea0,   // es.oc.gn_433 ur.ar.ps_444  sd.ur.uz_333 rm.sv.sq_322 
  0x3e004313, 0x130115a6, 0x060c0505, 0x0e400c60,   // ie.rm.un_650 un.en.et_521  fr.sv.de_333 sv.lb.is_664 
  // [22980]
  0x5d005e2a, 0x63000c34, 0x3511300c, 0x09002d14,   // ts.ss.un_970 sv.sco.un_A80  uz.ro.tg_543 sk.pl.un_660 
  0x64002302, 0x2a092d60, 0x2900fc04, 0x09002d21,   // ca.lg.un_220 sk.pl.mt_664  zzp.sl.un_320 sk.pl.un_860 
  0x535e370c, 0x6e092d12, 0x0c3302a0, 0x021743ee,   // st.ts.ht_543 sk.pl.hmn_654  da.nn.sv_322 ie.sr.da_422 
  0x343d3bee, 0x2d0d45a9, 0x42055b55, 0x400306af,   // ks.ku.ps_422 ln.cs.sk_544  sg.fr.co_442 de.nl.lb_655 
  // [22990]
  0x1b004905, 0x65300612, 0x0c020807, 0x0265290c,   // to.tr.un_330 de.uz.gv_654  no.da.sv_432 sl.gv.da_543 
  0x6500751a, 0x286468ad, 0x0a4835a0, 0x120c08a0,   // nso.gv.un_760 ig.lg.sw_643  tg.tt.mk_322 no.sv.hu_322 
  0x16296807, 0x051a650c, 0x6b1a0ca0, 0x1a646507,   // ig.sl.hr_432 gv.tl.fr_543  sv.tl.ceb_322 gv.lg.tl_432 
  0xfc400604, 0x12306505, 0x1a5c7908, 0x37350604,   // de.lb.zzp_332 gv.uz.hu_333  war.sa.tl_443 de.zu.st_332 
  // [229a0]
  0x10342e55, 0x07050aa0, 0x33fc1104, 0x0c3e08a0,   // fo.xh.lt_442 pt.fr.it_322  ro.zzp.nn_332 no.rm.sv_322 
  0x403611a0, 0x0e111ba0, 0x323029ee, 0x0c3f02a0,   // ro.gn.lb_322 tr.ro.is_322  sl.uz.bs_422 da.af.sv_322 
  0xfc333eee, 0x15631b0c, 0x216539ec, 0x0c025113,   // rm.nn.zzp_422 tr.sco.un_543  br.gv.jw_644 kl.da.sv_665 
  0x112d1b07, 0x285c3612, 0x440810a9, 0x1b004205,   // tr.sk.ro_432 gn.sa.sw_654  be.uk.kk_544 co.tr.un_330 
  // [229b0]
  0x21341504, 0x23000c04, 0x2a330ca0, 0x340679a6,   // un.xh.jw_332 sv.ca.un_320  sv.nn.mt_322 war.de.xh_521 
  0x0a233812, 0x0e180da4, 0x18003021, 0x15000911,   // tk.ky.mk_654 cs.ga.is_433  uz.ar.un_860 pl.un.un_630 
  0x3700610c, 0x3d231807, 0x493756a4, 0x4b4913ec,   // za.st.un_530 ar.ky.ku_432  mg.st.to_433 et.to.mi_644 
  0x376a1ea4, 0x370430a4, 0x1c47640c, 0x562d59a9,   // ms.haw.st_433 uz.ru.ba_433  lg.sn.id_543 rn.sk.mg_544 
  // [229c0]
  0x735e64a9, 0x44153704, 0x58370d07, 0x051d6507,   // lg.ts.ny_544 ba.kk.un_320  cs.st.om_432 gv.la.fr_432 
  0x5e00730c, 0x40562504, 0x734764af, 0x38002b07,   // ny.ts.un_530 eu.mg.lb_332  lg.sn.ny_655 vi.tk.un_420 
  0x49005608, 0x47007322, 0x34002d08, 0x785e67a9,   // mg.to.un_430 ny.sn.un_870  sk.xh.un_430 ak.ts.ve_544 
  0x25301007, 0x36122fa4, 0x2f006a22, 0x73005d21,   // be.uz.mn_432 su.hu.gn_433  haw.su.un_870 ss.ny.un_860 
  // [229d0]
  0x135630a0, 0x102515ee, 0x474a64a4, 0x553421a7,   // uz.mg.et_322 un.mn.be_422  lg.yo.sn_433 jw.xh.rw_532 
  0x55005904, 0x544b5608, 0x64475ea9, 0x55592512,   // rn.rw.un_320 mg.mi.ik_443  ts.sn.lg_544 eu.rn.rw_654 
  0x041710a9, 0x73476412, 0x67004713, 0x36001d04,   // be.sr.ru_544 lg.sn.ny_654  sn.ak.un_650 la.gn.un_320 
  0x2335300b, 0x2300302a, 0x0c2a10af, 0x075d3502,   // uz.tg.ky_542 uz.ky.un_970  lt.mt.sv_655 zu.ss.it_222 
  // [229e0]
  0x5700252b, 0x30272aa0, 0x381b43a0, 0x483730a7,   // eu.na.un_980 mt.gd.uz_322  ie.tr.tk_322 uz.ba.tt_532 
  0x04003809, 0x3e133007, 0x272a3eee, 0x3c21180c,   // tk.fi.un_440 uz.et.rm_432  rm.mt.gd_422 ar.fa.ug_543 
  0x5a655fa4, 0x49655f04, 0x5954250e, 0x38304304,   // tn.gv.sm_433 tn.gv.to_332  eu.ik.rn_555 ie.uz.tk_332 
  0x041d10ac, 0x0445050c, 0x134606a6, 0x100e210c,   // lt.la.fi_632 fr.ln.fi_543  de.qu.et_521 jw.is.lt_543 
  // [229f0]
  0x690d2daf, 0x330810a4, 0x6000050c, 0x33006018,   // sk.cs.mfe_655 lt.no.nn_433  fr.vo.un_530 vo.nn.un_740 
  0x260722a9, 0x28002504, 0x12001512, 0x280a5aa7,   // oc.it.ia_544 eu.sw.un_320  un.hu.un_640 sm.pt.sw_532 
  0x1b156304, 0x01fc1b08, 0x235c2207, 0x0a0e220c,   // sco.tr.un_320 tr.zzp.en_443  oc.sa.ca_432 oc.is.pt_543 
  0x2000310c, 0x100a30a0, 0x544b5a12, 0xfc4051ec,   // az.sq.un_530 uz.mk.be_322  sm.mi.ik_654 kl.lb.zzp_644 
  // [22a00]
  0x0400180d, 0x2703fca4, 0x504f18a9, 0x171523a0,   // ga.fi.un_540 zzp.nl.gd_433  ga.bi.fj_544 ky.sr.un_320 
  0x10504712, 0x32784712, 0x5d477307, 0x5c52185a,   // sn.fj.lt_654 sn.ve.bs_654  ny.sn.ss_432 ga.ha.sa_553 
  0x5e4773a9, 0x495a1f0c, 0x25475408, 0x2f735d0b,   // ny.sn.ts_544 cy.sm.to_543  ik.sn.eu_443 ss.ny.su_542 
  0x3e1d40a4, 0x1d11430c, 0x361f570c, 0x3e1140a9,   // lb.la.rm_433 ie.ro.la_543  na.cy.gn_543 lb.ro.rm_544 
  // [22a10]
  0x5c00180e, 0x09475d07, 0x20005507, 0xfc403e0d,   // ga.sa.un_550 ss.sn.pl_432  rw.sq.un_420 rm.lb.zzp_554 
  0xfe041c11, 0x10004005, 0xfe0431af, 0x1a5efea9,   // id.fi.tlh_653 lb.lt.un_330  az.fi.tlh_655 tlh.ts.tl_544 
  0x095e47ad, 0x40102502, 0x475c54a7, 0x0b3e400c,   // sn.ts.pl_643 eu.lt.lb_222  ik.sa.sn_532 lb.rm.es_543 
  0x2b1c020e, 0x4736100c, 0x013f1309, 0x4b5a36a9,   // da.id.vi_555 lt.gn.sn_543  et.af.en_444 gn.sm.mi_544 
  // [22a20]
  0x293f510c, 0x113efc04, 0x4b18500d, 0x08510107,   // kl.af.sl_543 zzp.rm.ro_332  fj.ga.mi_554 en.kl.no_432 
  0x133f040c, 0x5a0436a4, 0x47790907, 0x2d0f7308,   // fi.af.et_543 gn.fi.sm_433  pl.war.sn_432 ny.lv.sk_443 
  0x761b040c, 0x0f477312, 0x0300020d, 0x113e4004,   // fi.tr.crs_543 ny.sn.lv_654  da.nl.un_540 lb.rm.ro_332 
  0xfc073e07, 0x645535ee, 0xfc3e40af, 0x11001308,   // rm.it.zzp_432 zu.rw.lg_422  lb.rm.zzp_655 et.ro.un_430 
  // [22a30]
  0x2d0d5905, 0x3efc1114, 0x40113ea4, 0x17041555,   // rn.cs.sk_333 ro.zzp.rm_666  rm.ro.lb_433 un.ru.sr_442 
  0x643435af, 0x04006207, 0x0c3313a7, 0x2c155f02,   // zu.xh.lg_655 kha.fi.un_420  et.nn.sv_532 tn.fy.un_220 
  0x08332010, 0x046310a0, 0x1104130c, 0x1e1c32a0,   // sq.nn.no_642 lt.sco.fi_322  et.fi.ro_543 bs.id.ms_322 
  0x30000a0e, 0x4200120c, 0xfe00fc0c, 0x443d21a4,   // mk.uz.un_550 hu.co.un_530  zzp.tlh.un_530 fa.ku.kk_433 
  // [22a40]
  0x08073607, 0x0d00361d, 0x15481011, 0x380a1513,   // ab.bg.uk_432 gn.cs.un_820  be.tt.un_653 un.mk.tk_665 
  0x61001f13, 0x61001f0e, 0x48003511, 0x15005302,   // cy.za.un_650 cy.za.un_550  tg.tt.un_630 ht.un.un_220 
  0x100a15ad, 0x436301a0, 0x73256405, 0x1d401fa6,   // un.mk.be_643 en.sco.ie_322  lg.eu.ny_333 cy.lb.la_521 
  0x59556455, 0x353044ad, 0x643435ec, 0x3530170c,   // lg.rw.rn_442 kk.uz.tg_643  zu.xh.lg_644 sr.uz.tg_543 
  // [22a50]
  0x645a6a12, 0x261d5414, 0x5d737808, 0x0b422005,   // haw.sm.lg_654 ik.la.ia_666  ve.ny.ss_443 sq.co.es_333 
  0x551a6a55, 0x42605d12, 0x285a49a4, 0x1d074211,   // haw.tl.rw_442 ss.vo.co_654  to.sm.sw_433 co.it.la_653 
  0x351d4212, 0x56735205, 0x503534ee, 0x595543a4,   // co.la.zu_654 ha.ny.mg_333  xh.zu.fj_422 ie.rw.rn_433 
  0x0600010d, 0x1000230e, 0x023125a4, 0x42005022,   // en.de.un_540 ky.be.un_550  eu.az.da_433 fj.co.un_870 
  // [22a60]
  0x5e000414, 0x5a644908, 0x061f7914, 0x282164a4,   // fi.ts.un_660 to.lg.sm_443  war.cy.de_666 lg.jw.sw_433 
  0x49421d08, 0x31353409, 0xfc01240c, 0xfc05010b,   // la.co.to_443 xh.zu.az_444  eo.en.zzp_543 en.fr.zzp_542 
  0x2a060c0c, 0x0c006e08, 0x023f1da4, 0x27005e07,   // sv.de.mt_543 hmn.sv.un_430  la.af.da_433 ts.gd.un_420 
  0x46092da9, 0x11123f0d, 0x233e22ad, 0x05433f04,   // sk.pl.qu_544 af.hu.ro_554  oc.rm.ca_643 af.ie.fr_332 
  // [22a70]
  0x0f001f08, 0x121d2a07, 0x13233e0b, 0x25003c21,   // cy.lv.un_430 mt.la.hu_432  rm.ca.et_542 ug.mn.un_860 
  0x052223a4, 0x552873a4, 0x22020c55, 0x0c6b1dee,   // ca.oc.fr_433 ny.sw.rw_433  sv.da.oc_442 la.ceb.sv_422 
  0x64131da4, 0x0e2e02ad, 0x0c6b1a04, 0x060343a4,   // la.et.lg_433 da.fo.is_643  tl.ceb.sv_332 ie.nl.de_433 
  0x580242ee, 0xfc0265af, 0x275c6504, 0x370401a4,   // co.da.om_422 gv.da.zzp_655  gv.sa.gd_332 en.fi.st_433 
  // [22a80]
  0x425165ec, 0x5405650c, 0x5d007308, 0x133065ee,   // gv.kl.co_644 gv.fr.ik_543  ny.ss.un_430 gv.uz.et_422 
  0xfc3021ec, 0x5f7313ad, 0x5f5e6e11, 0x5d250f08,   // jw.uz.zzp_644 et.ny.tn_643  hmn.ts.tn_653 lv.eu.ss_443 
  0x2100250c, 0x395f37a0, 0x2a1d3b55, 0x5d38370c,   // eu.jw.un_530 st.tn.br_322  so.la.mt_442 st.tk.ss_543 
  0x12022fa0, 0x355e0da4, 0x04083702, 0x3e313008,   // su.da.hu_322 cs.ts.zu_433  ba.uk.ru_222 uz.az.rm_443 
  // [22a90]
  0x09003708, 0x1b601f0b, 0x1d1f0811, 0x2900300c,   // st.pl.un_430 cy.vo.tr_542  no.cy.la_653 uz.sl.un_530 
  0x402508a0, 0x07003102, 0x081a76ad, 0x152f05ee,   // no.eu.lb_322 az.it.un_220  crs.tl.no_643 fr.su.un_422 
  0x07545160, 0x51022e08, 0x5c6365ee, 0x3048130c,   // kl.ik.it_664 fo.da.kl_443  gv.sco.sa_422 et.tt.uz_543 
  0x65005a19, 0x2e5165a9, 0x0a006507, 0x09fc1b07,   // sm.gv.un_750 gv.kl.fo_544  gv.pt.un_420 tr.zzp.pl_432 
  // [22aa0]
  0x48391ba0, 0x18006e0b, 0x2e00300e, 0x391f38a7,   // tr.br.tt_322 hmn.ga.un_520  uz.fo.un_550 tk.cy.br_532 
  0x394273a0, 0xfc5815a0, 0x052927a0, 0x30151504,   // ny.co.br_322 un.om.zzp_322  gd.sl.fr_322 un.uz.un_320 
  0x184a120c, 0x35173008, 0x284207a4, 0x184a4505,   // hu.yo.ga_543 uz.sr.tg_443  it.co.sw_433 ln.yo.ga_333 
  0x351523ec, 0x181912a4, 0x5d190b08, 0x44123b07,   // ky.tg.un_640 hu.gl.ga_433  es.gl.ss_443 ks.ur.kk_432 
  // [22ab0]
  0x0b18450b, 0x124a0ea4, 0x0f090dec, 0x19361207,   // ln.ga.es_542 is.yo.hu_433  cs.pl.lv_644 hu.gn.gl_432 
  0x443c15ad, 0x043bfe0c, 0x22430aec, 0x22650a11,   // un.ug.kk_643 tlh.so.fi_543  pt.ie.oc_644 pt.gv.oc_653 
  0x2f46620c, 0x512f540b, 0x08002505, 0x1a6b3704,   // kha.qu.su_543 ik.su.kl_542  mn.uk.un_330 st.ceb.tl_332 
  0x2f005108, 0x191812ad, 0x2c3f02a0, 0x2a004a08,   // kl.su.un_430 hu.ga.gl_643  da.af.fy_322 yo.mt.un_430 
  // [22ac0]
  0xfc1c1ead, 0x61003614, 0x5e354f5a, 0x280b5f02,   // ms.id.zzp_643 gn.za.un_660  bi.zu.ts_553 tn.es.sw_222 
  0x4a001914, 0x48373c04, 0x6a004f19, 0x513848a4,   // gl.yo.un_660 ug.ba.tt_332  bi.haw.un_750 tt.tk.kl_433 
  0x630b10a7, 0x03005113, 0x3f0403a0, 0x010451a0,   // lt.es.sco_532 kl.nl.un_650  nl.fi.af_322 kl.fi.en_322 
  0x2e180e12, 0x5a001902, 0x06402aec, 0x65511e07,   // is.ga.fo_654 gl.sm.un_220  mt.lb.de_644 ms.kl.gv_432 
  // [22ad0]
  0x20353205, 0x12002719, 0x032c08a4, 0x120e18ad,   // bs.zu.sq_333 gd.hu.un_750  no.fy.nl_433 ga.is.hu_643 
  0x4b1d3fee, 0x136137a7, 0x02374712, 0x615f030c,   // af.la.mi_422 st.za.et_532  sn.st.da_654 nl.tn.za_543 
  0x1300650b, 0x3f37250c, 0x360942a9, 0x042c37a0,   // gv.et.un_520 eu.st.af_543  co.pl.gn_544 st.fy.fi_322 
  0x033f6112, 0x35003f08, 0x25006122, 0x61001d14,   // za.af.nl_654 af.zu.un_430  za.eu.un_870 la.za.un_660 
  // [22ae0]
  0x25655aee, 0x0205650c, 0x03284713, 0x36255aee,   // sm.gv.eu_422 gv.fr.da_543  sn.sw.nl_665 sm.eu.gn_422 
  0x28006114, 0x3b342108, 0x0f0c6108, 0x613f37a4,   // za.sw.un_660 fa.ps.ks_443  za.sv.lv_443 st.af.za_433 
  0x222d12ad, 0x4a2d0d09, 0x37000b02, 0x48113107,   // hu.sk.oc_643 cs.sk.yo_444  es.st.un_220 az.ro.tt_432 
  0x303c17a4, 0x425c1da0, 0x443418ac, 0x0a381b08,   // sr.ug.uz_433 la.sa.co_322  ar.ps.kk_632 tr.tk.pt_443 
  // [22af0]
  0x40fc0305, 0x0c00790b, 0x6a3b2f0d, 0x563b1a13,   // nl.zzp.lb_333 war.sv.un_520  su.so.haw_554 tl.so.mg_665 
  0x6a5e3b0d, 0x355955af, 0x28394507, 0x53695507,   // so.ts.haw_554 rw.rn.zu_655  ln.br.sw_432 rw.mfe.ht_432 
  0xfc562f02, 0x3c2123ad, 0x37564d0d, 0x3b6a37a9,   // su.mg.zzp_222 ky.fa.ug_643  aa.mg.st_554 st.haw.so_544 
  0x7324690c, 0x4b374909, 0x20430212, 0x293e55a0,   // mfe.eo.ny_543 to.st.mi_444  da.ie.sq_654 rw.rm.sl_322 
  // [22b00]
  0x065afc08, 0x5f2133a4, 0x25020f04, 0x11071d0c,   // zzp.sm.de_443 nn.jw.tn_433  lv.da.eu_332 la.it.ro_543 
  0x39006929, 0x3e694d0d, 0x651b2407, 0x3b00561a,   // mfe.br.un_960 aa.mfe.rm_554  eo.tr.gv_432 mg.so.un_760 
  0x39690aa4, 0x1f1d3607, 0x5611250c, 0x06fc0f05,   // pt.mfe.br_433 gn.la.cy_432  eu.ro.mg_543 lv.zzp.de_333 
  0x450a1211, 0x2f2130a4, 0x251b3107, 0x05005502,   // hu.pt.ln_653 uz.jw.su_433  az.tr.eu_432 rw.fr.un_220 
  // [22b10]
  0x2d0d15a0, 0x3e345904, 0x76595505, 0x354555a4,   // un.cs.sk_322 rn.xh.rm_332  rw.rn.crs_333 rw.ln.zu_433 
  0x76530d12, 0x565c1e0c, 0x53552c07, 0x59553b60,   // cs.ht.crs_654 ms.sa.mg_543  fy.rw.ht_432 so.rw.rn_664 
  0x655369ad, 0x39115507, 0x5c5649a9, 0x56004909,   // mfe.ht.gv_643 rw.ro.br_432  to.mg.sa_544 to.mg.un_440 
  0x6a1b02a0, 0x563b1c0c, 0x595549ec, 0x39055ba4,   // da.tr.haw_322 id.so.mg_543  to.rw.rn_644 sg.fr.br_433 
  // [22b20]
  0x5e784307, 0x562f3b0d, 0x1b111207, 0x79150605,   // ie.ve.ts_432 so.su.mg_554  hu.ro.tr_432 de.war.un_330 
  0x4a002e0c, 0x063e4012, 0x2c5509a0, 0x1e003b12,   // fo.yo.un_530 lb.rm.de_654  pl.rw.fy_322 so.ms.un_640 
  0x02007321, 0x392d120d, 0x295e1702, 0x12004a11,   // ny.da.un_860 hu.sk.br_554  sr.ts.sl_222 yo.hu.un_630 
  0x475e5c0c, 0x343656a9, 0x2d0d2955, 0x23153812,   // sa.ts.sn_543 mg.gn.xh_544  sl.cs.sk_442 tk.ky.un_640 
  // [22b30]
  0x30100a0b, 0x5c000c12, 0x39001211, 0x2e2d12a0,   // mk.be.uz_542 sv.sa.un_640  hu.br.un_630 hu.sk.fo_322 
  0x4a2e120c, 0x5a00200c, 0x65002707, 0x2d124a07,   // hu.fo.yo_543 sq.sm.un_530  gd.gv.un_420 yo.hu.sk_432 
  0x7300780d, 0x4b306502, 0x272916a0, 0x352a3407,   // ve.ny.un_540 gv.uz.mi_222  hr.sl.gd_322 xh.mt.zu_432 
  0x3c3428a9, 0x2a00350d, 0x1e3b63a0, 0x033534ee,   // sd.ps.ug_544 zu.mt.un_540  sco.so.ms_322 xh.zu.nl_422 
  // [22b40]
  0x153811ad, 0x3d12180d, 0x2e004a0d, 0x194a360c,   // ro.tk.un_643 ar.ur.ku_554  yo.fo.un_540 gn.yo.gl_543 
  0x0c120e07, 0x4a004205, 0x44213b07, 0x3525100b,   // is.hu.sv_432 co.yo.un_330  ks.fa.kk_432 be.mn.tg_542 
  0x1d3e510d, 0x1b001d0c, 0x1d105108, 0x46001012,   // kl.rm.la_554 la.tr.un_530  kl.lt.la_443 lt.qu.un_640 
  0x10131dad, 0x18001007, 0x28183b04, 0x2c033f55,   // la.et.lt_643 lt.ga.un_420  ks.ar.sd_332 af.nl.fy_442 
  // [22b50]
  0x1d515412, 0x42102eee, 0x5e005d2c, 0x0c0604ec,   // ik.kl.la_654 fo.lt.co_422  ss.ts.un_990 fi.de.sv_644 
  0x272a1808, 0x1d033fa0, 0x1000610b, 0x03321702,   // ga.mt.gd_443 af.nl.la_322  za.lt.un_520 sr.bs.nl_222 
  0x15003912, 0x0c5c120b, 0x2f521ca9, 0x47090f55,   // br.un.un_640 hu.sa.sv_542  id.ha.su_544 lv.pl.sn_442 
  0x13003505, 0x3b5c5807, 0x57004021, 0x29132dee,   // zu.et.un_330 om.sa.so_432  lb.na.un_860 sk.et.sl_422 
  // [22b60]
  0x1b311ea0, 0x06020c04, 0x0603080c, 0x031a02a0,   // ms.az.tr_322 sv.da.de_332  no.nl.de_543 da.tl.nl_322 
  0x03002207, 0x796b65a4, 0x10005119, 0x464a1c07,   // oc.nl.un_420 gv.ceb.war_433  kl.lt.un_750 id.yo.qu_432 
  0x1b37060c, 0x27005102, 0x10001d1b, 0x682836a9,   // de.st.tr_543 kl.gd.un_220  la.lt.un_770 gn.sw.ig_544 
  0x524a08a0, 0x03002d13, 0x5c002a07, 0x254a01a0,   // no.yo.ha_322 sk.nl.un_650  mt.sa.un_420 en.yo.eu_322 
  // [22b70]
  0x3e0208a7, 0x3e002c0c, 0x120604ad, 0x0e2efc07,   // no.da.rm_532 fy.rm.un_530  fi.de.hu_643 zzp.fo.is_432 
  0x2f5762ad, 0x2c374707, 0x05432612, 0x45002d0d,   // kha.na.su_643 sn.st.fy_432  ia.ie.fr_654 sk.ln.un_540 
  0x345c750c, 0x1b3e250c, 0xfe005f2b, 0x55006512,   // nso.sa.xh_543 eu.rm.tr_543  tn.tlh.un_980 gv.rw.un_640 
  0x54791c07, 0x61001608, 0x01752605, 0x15313ba0,   // id.war.ik_432 hr.za.un_430  ia.nso.en_333 so.az.un_322 
  // [22b80]
  0x40043113, 0x571f210c, 0x022d080b, 0x1d1601a4,   // az.fi.lb_665 jw.cy.na_543  no.sk.da_542 en.hr.la_433 
  0x5200460e, 0x18271da4, 0x65001102, 0x3e5c2d0b,   // qu.ha.un_550 la.gd.ga_433  ro.gv.un_220 sk.sa.rm_542 
  0x58002f08, 0x40394707, 0x39003207, 0x1e1c21ec,   // su.om.un_430 sn.br.lb_432  bs.br.un_420 jw.id.ms_644 
  0x62002d13, 0x54fe46a4, 0x04001216, 0x64475dec,   // sk.kha.un_650 qu.tlh.ik_433  hu.fi.un_720 ss.sn.lg_644 
  // [22b90]
  0x061103ec, 0x3900640c, 0x123d34a4, 0x4a3f68ec,   // nl.ro.de_644 lg.br.un_530  ps.ku.ur_433 ig.af.yo_644 
  0x1803010b, 0x2c182711, 0x271801af, 0x285321a0,   // en.nl.ga_542 gd.ga.fy_653  en.ga.gd_655 jw.ht.sw_322 
  0x17251508, 0x5e006413, 0x5f000105, 0x060501a7,   // un.mn.sr_443 lg.ts.un_650  en.tn.un_330 en.fr.de_532 
  0x69763105, 0x0f056308, 0x18434507, 0x1b595555,   // az.crs.mfe_333 sco.fr.lv_443  ln.ie.ga_432 rw.rn.tr_442 
  // [22ba0]
  0x29323807, 0x73003e04, 0x3f033e08, 0x0e124a07,   // tk.bs.sl_432 rm.ny.un_320  rm.nl.af_443 yo.hu.is_432 
  0x233e2208, 0x27184f13, 0x34375d0d, 0x3e2223a7,   // oc.rm.ca_443 bi.ga.gd_665  ss.st.xh_554 ca.oc.rm_532 
  0x22381d0b, 0x35001d0c, 0x5d3447ee, 0x0c003f13,   // la.tk.oc_542 la.zu.un_530  sn.xh.ss_422 af.sv.un_650 
  0x40390607, 0x114730a7, 0x1f65395a, 0x131147af,   // de.br.lb_432 uz.sn.ro_532  br.gv.cy_553 sn.ro.et_655 
  // [22bb0]
  0x5e1d1305, 0x53005613, 0x79241904, 0x0e060207,   // et.la.ts_333 mg.ht.un_650  gl.eo.war_332 da.de.is_432 
  0x2e150209, 0x5c355e07, 0x0c020607, 0x3534270c,   // da.fo.un_440 ts.zu.sa_432  de.da.sv_432 gd.xh.zu_543 
  0x3f0340a0, 0x322d29a9, 0x36002a08, 0x01261d55,   // lb.nl.af_322 sl.sk.bs_544  mt.gn.un_430 la.ia.en_442 
  0x47002119, 0x27004208, 0x4b6a0612, 0x2000131b,   // jw.sn.un_750 co.gd.un_430  de.haw.mi_654 et.sq.un_770 
  // [22bc0]
  0x48353004, 0x3700362a, 0x6a37200c, 0x353c300b,   // uz.tg.tt_332 gn.st.un_970  sq.st.haw_543 uz.ug.tg_542 
  0x0e5c2ea4, 0x2b004021, 0x0256200c, 0x330351ee,   // fo.sa.is_433 lb.vi.un_860  sq.mg.da_543 kl.nl.nn_422 
  0x4b20020d, 0x092c0b0d, 0x4b3220a7, 0x392b050c,   // da.sq.mi_554 es.fy.pl_554  sq.bs.mi_532 fr.vi.br_543 
  0x18001c02, 0x25452b09, 0x2b371c0c, 0x15205607,   // id.ga.un_220 vi.ln.eu_444  id.st.vi_543 mg.sq.un_432 
  // [22bd0]
  0x1d001109, 0x473e255a, 0x016547a0, 0x552f20ad,   // ro.la.un_440 eu.rm.sn_553  sn.gv.en_322 sq.su.rw_643 
  0x0b69050d, 0x091025a4, 0x280f10ad, 0x0b612da4,   // fr.mfe.es_554 eu.lt.pl_433  lt.lv.sw_643 sk.za.es_433 
  0x0565010b, 0x0f1001a4, 0x2c3f2ba4, 0x012343ee,   // en.gv.fr_542 en.lt.lv_433  vi.af.fy_433 ie.ca.en_422 
  0x600b61a4, 0x1d10610c, 0x652c63ec, 0x3c2310ee,   // za.es.vo_433 za.lt.la_543  sco.fy.gv_644 be.ky.ug_422 
  // [22be0]
  0x25000321, 0x420503a0, 0x48003602, 0x1d0b01a4,   // nl.eu.un_860 nl.fr.co_322  gn.tt.un_220 en.es.la_433 
  0x10003620, 0x5624200c, 0x374b2012, 0x022565ad,   // ab.be.un_850 sq.eo.mg_543  sq.mi.st_654 gv.eu.da_643 
  0x62003f2a, 0x595520a9, 0x030442a0, 0x0b050fec,   // af.kha.un_970 sq.rw.rn_544  co.fi.nl_322 lv.fr.es_644 
  0x2b100faf, 0x20364b04, 0x400643af, 0x62000921,   // lv.lt.vi_655 mi.gn.sq_332  ie.de.lb_655 pl.kha.un_860 
  // [22bf0]
  0x58002007, 0x23484409, 0x07171108, 0x170e510c,   // sq.om.un_420 kk.tt.ky_444  ro.sr.bg_443 kl.is.sr_543 
  0x195133a0, 0x51001a19, 0x383035a4, 0x280e5204,   // nn.kl.gl_322 tl.kl.un_750  tg.uz.tk_433 ha.is.sw_332 
  0x2119560c, 0x42263e0c, 0x2800561a, 0x304658a7,   // mg.gl.jw_543 rm.ia.co_543  mg.sw.un_760 om.qu.uz_532 
  0x1b7952a6, 0x463e23a6, 0x550228a4, 0x47001802,   // ha.war.tr_521 ca.rm.qu_521  sw.da.rw_433 ga.sn.un_220 
  
  // [22c00]
  0x3e30460d, 0x5131190c, 0x39321602, 0x422207a4,   // qu.uz.rm_554 gl.az.kl_543  hr.bs.br_222 it.oc.co_433 
  0x245339ee, 0x28563e0b, 0x2f21520c, 0x4c313012,   // br.ht.eo_422 rm.mg.sw_542  ha.jw.su_543 uz.az.wo_654 
  0x5635faad, 0x4e30460c, 0x22002408, 0x29525108,   // nr.zu.mg_643 qu.uz.ay_543  eo.oc.un_430 kl.ha.sl_443 
  0xfe005112, 0x28581812, 0x1a614fec, 0x126b22ad,   // kl.tlh.un_640 ga.om.sw_654  bi.za.tl_644 oc.ceb.hu_643 
  // [22c10]
  0x52fe1aee, 0x46524dee, 0x64343907, 0x12220aad,   // tl.tlh.ha_422 aa.ha.qu_422  br.xh.lg_432 pt.oc.hu_643 
  0x02063e05, 0x0a073555, 0x423e180c, 0x300946a0,   // rm.de.da_333 tg.bg.mk_442  ga.rm.co_543 qu.pl.uz_322 
  0x31fe150c, 0x35100807, 0x0c3e73a6, 0x73190b09,   // un.tlh.az_543 uk.be.tg_432  ny.rm.sv_521 es.gl.ny_444 
  0x25330802, 0x204e3e08, 0x36000211, 0x1e580205,   // no.nn.eu_222 rm.ay.sq_443  da.gn.un_630 da.om.ms_333 
  // [22c20]
  0x4c182d0c, 0x0a65220c, 0x15003b0b, 0x38000a1a,   // sk.ga.wo_543 oc.gv.pt_543  so.un.un_520 mk.tk.un_760 
  0x2000360e, 0x5f5955a7, 0x4a00fc0d, 0x17480a08,   // gn.sq.un_550 rw.rn.tn_532  zzp.yo.un_540 mk.tt.sr_443 
  0x303c38ad, 0x123d3405, 0x043035a6, 0x0329020c,   // tk.ug.uz_643 ps.ku.ur_333  tg.uz.ru_521 da.sl.nl_543 
  0x2dfc29a0, 0x2a640c07, 0x48100860, 0x04071514,   // sl.zzp.sk_322 sv.lg.mt_432  uk.be.tt_664 un.bg.ru_666 
  // [22c30]
  0x1548375a, 0x2e3f0e09, 0x4c1a3509, 0x25584d0c,   // ba.tt.un_553 is.af.fo_444  zu.tl.wo_444 aa.om.eu_543 
  0x58002511, 0x0833020c, 0x58256507, 0x37352308,   // eu.om.un_630 da.nn.no_543  gv.eu.om_432 ky.tg.ba_443 
  0x2c002502, 0x20005807, 0x0e584d04, 0x58572508,   // eu.fy.un_220 om.sq.un_420  aa.om.is_332 eu.na.om_443 
  0x28443c12, 0x12006b04, 0x474601a4, 0x0c6b25a0,   // ug.kk.sd_654 ceb.hu.un_320  en.qu.sn_433 eu.ceb.sv_322 
  // [22c40]
  0x73002820, 0x36113714, 0xfc023405, 0x07002514,   // sw.ny.un_850 ba.ro.ab_666  xh.da.zzp_333 eu.it.un_660 
  0x5e687305, 0x6500360c, 0x13126b08, 0x17080a14,   // ny.ig.ts_333 gn.gv.un_530  ceb.hu.et_443 mk.uk.sr_666 
  0x461f5ca7, 0x377956a7, 0x58005214, 0x154006af,   // sa.cy.qu_532 mg.war.st_532  ha.om.un_660 de.lb.un_655 
  0x58261d07, 0x190a250d, 0x0a11380d, 0x0a371704,   // la.ia.om_432 eu.pt.gl_554  tk.ro.mk_554 sr.ba.mk_332 
  // [22c50]
  0x3e0608a0, 0x13151204, 0x3ffc2fa0, 0x47284e0d,   // no.de.rm_322 hu.et.un_320  su.zzp.af_322 ay.sw.sn_554 
  0x4000051d, 0x35041755, 0x47005c12, 0x6500220c,   // fr.lb.un_820 sr.ru.tg_442  sa.sn.un_640 oc.gv.un_530 
  0x3933120c, 0x3938120c, 0x123925ac, 0x4f121c07,   // hu.nn.br_543 hu.tk.br_543  eu.br.hu_632 id.hu.bi_432 
  0x09122a0e, 0x33001213, 0x070242a9, 0x09003911,   // mt.hu.pl_555 hu.nn.un_650  co.da.it_544 br.pl.un_630 
  // [22c60]
  0x5300120c, 0x1d4d0d0c, 0x05403607, 0x08100aa0,   // hu.ht.un_530 cs.aa.la_543  gn.lb.fr_432 mk.be.uk_322 
  0x053640a7, 0x23303513, 0x0d003905, 0x2d090205,   // lb.gn.fr_532 tg.uz.ky_665  br.cs.un_330 da.pl.sk_333 
  0x094d1214, 0x1c3912ad, 0x48171008, 0x51101d05,   // hu.aa.pl_666 hu.br.id_643  be.sr.tt_443 la.lt.kl_333 
  0x49000902, 0x2e100ea7, 0x1d003e19, 0x13386511,   // pl.to.un_220 is.lt.fo_532  rm.la.un_750 gv.tk.et_653 
  // [22c70] --- double_langprob_start=22c7b ---
  0x0a250702, 0x651e1c09, 0x156e3fec, 0x6a330808,   // bg.mn.mk_222 id.ms.gv_444  af.hmn.un_644 no.nn.haw_443 
  0x13422004, 0x3f7906a0, 0x47000e13, 0x5e375f09,   // sq.co.et_332 de.war.af_322  is.sn.un_650 tn.st.ts_444 
  0x65001a05, 0x1d004f21, 0x47330814,               // tl.gv.un_330 bi.la.un_860  no.nn.sn_666 
                                                    // 
  };

//  COMPILE_ASSERT(142459 <= 262144, k_indirectbits_too_small);

extern const CLD2TableSummary kQuad_obj = {
  kQuad0122,
  kQuad0122Ind,
  kQuad0122SizeOne,
  kQuad0122Size,
  kQuad0122KeyMask,
  kQuad0122BuildDate,
  kQuad0122RecognizedLangScripts,
};

static const uint32 kQuad0122_2Size = 0;    // Bucket count
static const uint32 kQuad0122_2KeyMask = 0xffffffff;    // Mask hash key

// NOTE: Some compilers will not allow an array of structs to have a constant
//       size of zero. Thus, we tell the code that the size is zero, but
//       actually allocate a single element array that will never be read.
//       More info: https://code.google.com/p/cld2/issues/detail?id=9
static const IndirectProbBucket4 kQuad0122_2[1] = {
  // hash_indirect[4], tokens[4] in UTF-8
  {0x00000000,0x00000000,0x00000000,0x00000000} // UNUSED, see above!
  };
  // table_hash = ffff-ffff, unused_entries = 0 (0.00%)

static const uint32 kQuad0122_2SizeOne = 2;    // Bucket count one-lang
static const uint32 kQuad0122_2Ind[2] = {
  // [0000] --- double_langprob_start=0002 ---
  0x00000000, 0x00000000,                           // -- --  
                                                    // 
  };

extern const CLD2TableSummary kQuad_obj2 = {
  kQuad0122_2,
  kQuad0122_2Ind,
  kQuad0122_2SizeOne,
  kQuad0122_2Size,
  kQuad0122_2KeyMask,
  kQuad0122BuildDate,
  kQuad0122RecognizedLangScripts,
};

}       // End namespace CLD2

// End of generated tables
